#!/bin/sh
#
# Copyright (c) 1999-2005 SWsoft Inc.
# All rights reserved
#

#
# Plesk script
#


set_apache_params()
{
	apache_user="apache"
	apache_UID=80
	apache_group="apache"
	apache_GID=80
	apache_service_name="httpd"
	apache_new="2.0"

	apache_modules_d="/usr/local/psa/apache/libexec/"
	user_apxs="/usr/local/psa/apache/bin/apxs"

	apache_httpd_conf="$HTTPD_CONF_D/httpd.conf"
	apache_httpd_conf2="$HTTPD_CONF_D/httpd2.conf"
	apache_httpd_conf_in="$PRODUCT_ROOT_D/etc/httpd.conf.in"

	apache_httpd_include="$HTTPD_INCLUDE_D/zz010_psa_httpd.conf"

	APACHE_CERT="$HTTPD_CONF_D/httpd.pem"

	apache_pid_file="$APACHE_ROOT/logs/httpd.pid"
	apache_lock_file="$APACHE_ROOT/logs/httpd.lock"
	product_lock_file="$HTTPD_CONF_D/cnf.lock"

	min_suexec_UID=10000
	max_suexec_UID=16000
	min_suexec_GID=$min_suexec_UID
	max_suexec_GID=$max_suexec_UID

	suexec_storage=/usr/local/psa/apache/bin
	suexec=/usr/local/psa/apache/bin/suexec
	suexec_dir=/usr/local/psa/apache/bin
	suexec_file=suexec

	rpm_httpd_bin=/usr/sbin/httpd
}

remove_tmp_state()
{
	if [ -d "/tmp/.state" ]; then
		rm -Rf "/tmp/.state" >> $product_log 2>&1
	fi
}

#admin

set_admin_params()
{

	ADMIN_ROOT=$PRODUCT_ROOT_D/admin

	UTILS_DIR=$ADMIN_ROOT/bin

	admin_user="${product}adm"
	admin_UID=8444
	admin_group="${product}adm"
	admin_GID=8444

	admin_httpsd_conf="$ADMIN_ROOT/conf/httpsd.conf"
	ADMIN_CERT="$ADMIN_ROOT/conf/httpsd.pem"

	admin_pid_file=$ADMIN_ROOT/logs/httpsd.pid
	admin_lock_file=$ADMIN_ROOT/logs/httpsd.lock
}

lock_keyupdate()
{
	export PLESK_KEYUPDATE_DISABLED=installation
}


#fp

set_fp_params()
{
	fp_i_dir="/usr/local/frontpage"
	fp_v="version5.0"
	fpsrvadm="$fp_i_dir/$fp_v/bin/owsadm.exe"
	fp_root_def_port=80
	fp_admin="fpadmin"
	fp_admin_passwd="setup"
	fp_distrib="$PRODUCT_ROOT_D/fp.tar"
	fp_apache_stub_conf="$PRODUCT_ROOT_D/apache_tmp.conf"
#	fp_stub_head="$PRODUCT_ROOT_D/apache/conf/httpd.stub.head"
#	fp_stub_tail="$PRODUCT_ROOT_D/apache/conf/httpd.stub.tail"
}

# Print an error message and exit the program.
error()
{
    die "Exiting due to an error!  Please fix the error and try again." 
}


set_drweb_qmail_params()
{

	drweb_user="drweb"
	drweb_UID=89
	drweb_group="drweb"
	drweb_GID=89

	drweb_distrib="$PRODUCT_ROOT_D/drweb.tar"
	drweb_qmail_distrib="$PRODUCT_ROOT_D/drweb-qmail.tar"

	drweb_var_dir="/var/drweb"
}

get_admin_passwd()
{
	if [ -f "$mysql_passwd_file" ]; then
		admin_passwd=`cat "$mysql_passwd_file"`
	fi

	if [ -z "$admin_passwd" ]; then
		admin_passwd="$default_mysql_passwd"
	fi

}

#courier-imap

set_courier_imap_params()
{
	COURIER_IMAP_ROOT_D="$PRODUCT_ROOT_D/courier-imap"
	courier_imap_start="$PRODUCT_RC_D/courier-imap start"
	courier_imap_stop="$PRODUCT_RC_D/courier-imap stop"

	IMAPD_CERT="$COURIER_IMAP_ROOT_D/share/imapd.pem"
	POP3D_CERT="$COURIER_IMAP_ROOT_D/share/pop3d.pem"

	IMAPD_CONF="$COURIER_IMAP_ROOT_D/etc/imapd"
	POP3D_CONF="$COURIER_IMAP_ROOT_D/etc/pop3d"

	MAILPASSWD="$QMAIL_ROOT_D/users/poppasswd"
}

# db_test test_query awk_script
# Runs test_query and processes it with awk_script. If the output is
# not empty, return 0, otherwise return 1. Hint: supply '1' for
# awk_script to test just for the presence of any output.
db_test()
{
	local any_db=
	eval `sh_get_args '--any-db) any_db=yes;;'`

	local test_query="$1"
	local awk_script="$2"

	if [ -n "$any_db" ]; then
		local output="`mysql_raw_anydb -e \"$test_query\" 2>>\"$product_log\"`"
	else
		local output="`mysql_raw -e \"$test_query\" 2>>\"$product_log\"`"
	fi
	local status=$?
	if [ "$status" -ne 0 ]; then
		p_echo "$output"
		die "run the following SQL query: $1"
	fi

	echo -n "$output" | awk -F '\t' -- "$awk_script" | test `wc -l` -ne 0
}

#proftpd

set_ftpd_params()
{

	anonftp_user="${product}ftp"
	anonftp_group="${product}ftp"

	PROFTPD_ROOT="$PRODUCT_ROOT_D/ftpd"
}

set_jdk_params()
{
	jdk_distrib="$PRODUCT_ROOT_D/j2sdk.bin"
}

set_tomcat_params()
{
    set_common_params
 
    tomcat_distrib="$PRODUCT_ROOT_D/jakarta-tomcat.tar"
    prod_conf_t="/etc/psa/psa.conf"
    tomcat_version="4"
    CATALINA_HOME="/usr/local/psa/tomcat4"
    tomcat_user="tomcat4"
    tomcat_group="tomcat4"

    #basename directory. May be different. 
    dist_name="tomcat4"
 
    tomcat_conf="$CATALINA_HOME/conf/$dist_name.conf"
}


init_log()
{
echo >> $product_log	# initializing new output to log
echo "START LOGGING: `date`" >> $product_log
echo "SCRIPT: $0" >> $product_log
chmod 600 "$product_log"

echo >> $product_problems_log	# initializing new output to problems log
echo "START LOGGING: `date`" >> $product_problems_log
echo "SCRIPT: $0" >> $product_problems_log
chmod 600 "$product_problems_log"

problems_occured=0
}

p_echo()
{
echo "$*" >> "$product_log" 2>&1
echo "$*"
}

pnnl_echo()
{
if [ -z $necho_defined ]; then
	# set up echo
	case "`echo 'x\c'`" in
    	'x\c')
			echo="echo"
			echo_keys=" -n"
			nnl=
		;;
		x)
			echo="echo"
			echo_keys=
			nnl="\c"
		;;
		*)
			echo "ERROR: unable to set up echo."
		;;
	esac
	necho_defined=true
fi

${echo} ${echo_keys} "$*${nnl}" >> "$product_log" 2>&1
${echo} ${echo_keys} "$*${nnl}"
}

keyupdate_failure_report()
{
	if test -z "$KEYUPDATE_FAILURE_INFO"; then
		return
	fi

	p_echo
	p_echo " *****************************************************************************"
	p_echo " *                                                                           *"
	p_echo " *  ERROR:      The $PRODUCT_NAME license failed to upgrade. The failure     *"
	p_echo " *              follows:                                                     *"
	p_echo
	p_echo "$KEYUPDATE_FAILURE_INFO"
	p_echo
	p_echo " *              If you did not request the automatic key upgrade,            *"
	p_echo " *              please contact SWsoft, Inc sales department for assistance:  *"
	p_echo " *              ${sales_email}. If you want to proceed with upgrade without *"
	p_echo " *              the license upgrade, please create an empty file             *"
	p_echo " *				$prodkey                                             *"
	p_echo " *                                                                           *"
	p_echo " *****************************************************************************"
	p_echo
}

die()
{
	if [ "X$trigger_uninstall" != "X1" ]; then
		printf "\a\a"
		p_echo
		p_echo "ERROR while trying to $*"
		echo "Check the error reason(see log file: ${product_log}), fix and try again"
		p_echo
		if [ "X$do_patch" != "X1" -a "X$do_reconfigure" != "X1" ]; then
			p_echo "Aborting..."
			p_echo
		fi
	fi

	smart_undo_install

	keyupdate_failure_report

	selinux_close

	exit 1

}

err()
{

	if [ "X$trigger_uninstall" != "X1" ]; then
		p_echo
		p_echo "ERROR!"
		p_echo "Check the error reason(see log file: ${product_log}), fix and try again"
		p_echo
		if [ "X$do_patch" != "X1" -a "X$do_reconfigure" != "X1" ]; then
			p_echo "Exiting..."
			p_echo
		fi
	fi

	smart_undo_install

	exit 1
}

# This function needs for some print warning when some services cannot restart
# if called with arg, then we add arg to variable SR_WARNING and print warning
# message for arg, else print warning message for SR_WARNING
service_restart_warning()
{
	if [ "X$1" != "X" ]; then
		if [ "X${SR_WARNING}" = "X" ]; then
			SR_WARNING=$1
		else
			for i in ${SR_WARNING}; do
				if [ "$i" = "$1" ]; then
					break
				fi
			done
			if [ "$1" != "$i" ]; then
				SR_WARNING=$SR_WARNING" "$1
			fi
		fi
		p_echo "WARNING!"
		p_echo "Some problems occured when $1 restart, check it after installation/upgrade complete"
	        p_echo
	 	p_echo "Continue..."
		p_echo
	else
		if [ "X${SR_WARNING}" != "X" ]; then
			p_echo "WARNING!"
		        p_echo "Some problems occured when following services restart:"
			for i in ${SR_WARNING}; do
				p_echo $i
			done
			p_echo "Don't forget to check it after installation/upgrade complete"
        		p_echo
	       	        p_echo "More information can be found in log file: ${product_log}"
			p_echo
		fi
	fi
}

warn()
{
local inten
inten="$1"
p_echo
p_echo "WARNING!"
pnnl_echo "During the $inten found some problems"
echo "(see log file: ${product_log})"
p_echo
p_echo "Continue..."
p_echo

}

echo_try()
{
	msg="$*"
	pnnl_echo " Trying to $msg... "
}

suc()
{
	p_echo "done"
}

mk_backup()
{
	target="$1"
	dup="$2"
	opts="$3"

	if [ -L "$target" ]; then
		rm "$target"
	elif [ -$opts "$target" ]; then
		if [ ! -$opts "$target.$product_suffo" ]; then
			case "$dup" in
				mv)
					mv -f $target $target.$product_suffo || die "mv -f $target $target.$product_suff"
					;;
				cp)
					cp -fp $target $target.$product_suffo || die "cp -fp $target $target.$product_suff"
					;;
				*)
					p_echo " mk_backup: wrong option -- must be 'cp' or 'mv'"
					die "mk_backup"
					;;
			esac
		else
			case "$dup" in
				mv)
					mv -f $target $target.$product_suff || die "mv -f $target $target.$product_suff"
					;;
				cp)
					cp -fp $target $target.$product_suff || die "cp -fp $target $target.$product_suff"
					;;
				*)
					p_echo " mk_backup: wrong option -- must be 'cp' or 'mv'"
					die "mk_backup"
					;;
			esac
		fi
	else
		case "$opts" in
			f|d)
				;;
			*)
				p_echo " mk_backup: wrong option -- must be 'f' or 'd'"
				die "mk_backup"
				;;
		esac
	fi
}

# accumulates chown and chmod
set_ac()
{
	u_owner="$1"
	g_owner="$2"
	perms="$3"
	node="$4"

	chown $u_owner:$g_owner $node || die "chown $u_owner:$g_owner $node"
	chmod $perms $node || die "chmod $perms $node"
}

detect_vz()         
{                   
    local vzcheck_file
        
    PLESK_VZ=0
    vzcheck_file="/proc/self/status"
                    
    if [ ! -f ${vzcheck_file} ]; then
        return 1; 
    fi              
                    
    grep -q -E '^envID\:[[:space:]]*([[:digit:]]+)$' < ${vzcheck_file} >/dev/null 2>&1
                    
    if [ $? -eq 0 ]; then
        PLESK_VZ=1  
        return 0;
    fi      
    return 1;
}       

call_optional_function()
{
	local type_output="`type \"$1\" 2>/dev/null | head -n 1`"
	case "$type_output" in
		*function)
			"$@"
			;;
		*)
			return 0
			;;
	esac
}

sh_get_args()
{
	echo 'while true; do case "$1" in '"$1"'*) break;; esac; shift; done'
}

# Super server internet library

super_server_type()
{
	case "$super_server" in

		'xinetd' | 'inetd')
			;;
		*)
			# check what super-server installed
			inten="define super-server internet daemon type"
			echo_try "$inten"
			
			local xinetd_pid=`get_pids_byname "xinetd"`
			local inetd_pid=`get_pids_byname "inetd"`
			
			
			if [ -z "$xinetd_pid" ]; then
				if [ -z "$inetd_pid" ]; then
					if [ -f "$xinetd_conf" ]; then
						super_server="xinetd"
						xinetd_dir=`cat /etc/xinetd.conf |grep includedir| awk '{print $2; exit}' -`
					elif [ -f "$inetd_conf" ]; then
						super_server="inetd"
					else
						die "$inten"
					fi
				else
					super_server="inetd"
				fi
			else 
				super_server="xinetd"
				xinetd_dir=`cat /etc/xinetd.conf |grep includedir| awk '{print $2; exit}' -`
			fi				 
				
			p_echo "$super_server"
			;;
	esac
}

restart_super_server()
{
	if [ -n "$CHROOTISH" ]; then
			return 0
	fi

	# if PLESK_INSTALLER_DEBUG = daemons then print process table and network status.
	# Usefull for research bugs like 63469, 51592 and other with listen/restart services.
	if [ "X$PLESK_INSTALLER_DEBUG" = "Xdaemon" ] ; then
		ps axl
		netstal -pl
	fi

	super_server_type

	case "$super_server" in

		'xinetd')

		    inten="restart xinetd daemon"
		    echo_try "$inten"
		    case "$machine" in

 		        linux)
				$PRODUCT_RC_D/xinetd reload >> $product_log 2>&1
			    ;;
	 
		        *)
	            	    # not Linux
			    xinetd_pid=`$ps | grep xinetd | egrep "\?" | grep -v grep | head -1 | awk '{print $1}' -`
				if [ "X${xinetd_pid}" = "X" ]; then
					service_restart_warning "xinetd"
				else
				    $K_USR2 $xinetd_pid >> $product_log 2>&1 && suc || die "$inten"
				fi
	            	    ;;
								 
	            esac

		;;

		'inetd')

			inetd_pid=`$ps | grep inetd | egrep "\?" | grep -v grep | head -1 | awk '{print $1}' -`
			inten="restart inetd daemon"
			echo_try "$inten"

			if [ "X${inetd_pid}" = "X" ]; then
				 service_restart_warning "inetd"
			else
				$K_HUP $inetd_pid >> $product_log 2>&1 && suc || die "$inten"
			fi
		;;
	esac
}

comment_service_xinetd()
{
	#comment service records
	local dir file service grep_res
	service=$1

	inten="comment out record for service $service"
	echo_try "$inten"

	for dir in $xinetd_dir; do

		for file in $dir/*; do

			grep_res=`grep "$service" $file`
			case "$?" in
				0)
					awk "/^[[:space:]]*service[[:space:]]+$service($|[[:space:]]+)/,/.*}.*/ \
						{ print \"#\"\$0; next; }
						{print}
						" <$file >$file.tmp  &&
					mv -f $file.tmp $file || die "$inten" >> $product_log 2>&1
					restart_super_server
					;;
				*)
					;;
			esac

		done;

	done;

	suc

}

comment_service_inetd()
{
	local grep_res
	service=$1

	inten="comment out record for service $service"
	echo_try "$inten"

	grep_res=`grep "^$service[[:space:]]" $inetd_conf`

	case "$?" in
	
		0)
			sed -e "s|^$service|##commented_by_psa $service|g" < "$inetd_conf" > "$inetd_conf.${product}_tmp" \
			&& mv -f "$inetd_conf.${product}_tmp" "$inetd_conf" \
			&& suc || die >> $product_log 2>&1
			restart_super_server
			;;
		*)
			p_echo " no record for service $service found in the $inetd_conf"
			;;
	esac
}

comment_service()
{
	local service
	service=$1
	
	super_server_type

	case "$super_server" in

		'xinetd')
			comment_service_xinetd "$service"
			;;

		'inetd')
			comment_service_inetd "$service"
			;;

		*)
			die "Super server type is undefined"
			;;
	esac

}


remove_xinetd()
{
	local service file
	service=$1;
	
	rm -f $xinetd_dir/${service}_${product}
	
	#uncomment old records
	inten="comment out ${product} record for service $service"

	for file in $xinetd_dir/*; do
		awk "/^[[:space:]]*#[[:space:]]*service[[:space:]]+$service($|[[:space:]]+)/,/.*}.*/ \
			{ print substr(\$0,2); next; }
			{print}
			" <$file >$file.tmp &&
		mv -f $file.tmp $file >> $product_log 2>&1
	done;

	restart_super_server

}

remove_inetd()
{
	local service
	service=$1;

	case "$service" in

		ftp)
			inten="restore ftp service record in the $inetd_conf"

			sed -e "s|^ftp.*/${product}/ftpd/sbin/proftpd.*||g" \
				-e "s|ftp.*/${prev_product}/ftpd/sbin/proftpd.*||g" \
				< $inetd_conf > $inetd_conf.${product}_tmp \
			&& mv -f $inetd_conf.${product}_tmp $inetd_conf >> $product_log 2>&1
		    ;;

		smtp)
			inten="restore smtp service record in the $inetd_conf"

			sed -e "s|^smtp.*$QMAIL_ROOT_D/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/relaylock.*||g" \
				-e "s|^smtp.*${product}/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/relaylock.*||g" \
				-e "s|smtp.*${prev_product}/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/relaylock.*||g" \
				< $inetd_conf > $inetd_conf.${product}_tmp \
			&& mv -f $inetd_conf.${product}_tmp $inetd_conf >> $product_log 2>&1
		    ;;

		smtps)
			inten="restore smtp service record in the $inetd_conf"

			sed -e "s|^smtps.*$QMAIL_ROOT_D/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/relaylock.*||g" \
				-e "s|^smtps.*${product}/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/relaylock.*||g" \
				-e "s|smtps.*${prev_product}/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/relaylock.*||g" \
				< $inetd_conf > $inetd_conf.${product}_tmp \
			&& mv -f $inetd_conf.${product}_tmp $inetd_conf >> $product_log 2>&1
		    ;;

		pop3)
			inten="restore pop3 service record in the $inetd_conf"

			sed -e "s|^pop[-]*3.*/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/pop3$||g" \
				-e "s|^pop[-]*3.*/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/pop3$||g" \
				< $inetd_conf > $inetd_conf.${product}_tmp \
			&& mv -f $inetd_conf.${product}_tmp $inetd_conf >> $product_log 2>&1
			
		    ;;
		poppassd)
			# poppassd stream tcp nowait root /usr/sbin/tcpd /${PRODUCT_ROOT_D}/admin/bin/poppassd
			inten="restore poppassd service record in the $inetd_conf"

			sed -e "s|^poppassd.*$PRODUCT_ROOT_D/admin/bin/poppassd.*||g" \
				< $inetd_conf > $inetd_conf.${product}_tmp \
			&& mv -f $inetd_conf.${product}_tmp $inetd_conf >> $product_log 2>&1
			;;
		
	esac

	# uncomment old records
	sed -e "s|^##commented_by_psa $service|$service|g" < $inetd_conf > $inetd_conf.${product}_tmp \
	&& mv -f $inetd_conf.${product}_tmp $inetd_conf >> $product_log 2>&1

	restart_super_server

}

remove_super_server()
{
	local service
	service=$1;

	super_server_type

	case "$super_server" in

		xinetd)
			remove_xinetd "$service"
			;;
		inetd)
			remove_inetd "$service"
			;;
	esac
}

setup_xinetd()
{
	local service file rbl_on rbl_server
	service=$1;
	rbl_on=$2;
	rbl_server=$3;
	
	#comment old records
	comment_service "$service"	
	
	#setup
	service=$1;
	inten="set up record for service $service"
	echo_try "$inten"

	case "$service" in

		ftp)
			echo "
service ftp
{
	socket_type		= stream
	protocol		= tcp
	wait			= no
	disable			= no
	user			= root
	instances		= UNLIMITED
	server			= $PRODUCT_ROOT_D/ftpd/sbin/proftpd
	server_args		= -c $PRODUCT_ROOT_D/ftpd/etc/proftpd.conf
}" > "$xinetd_dir/ftp_${product}" || die "$inten"
			;;

		smtp)

			case "$rbl_on" in

				on)				
					echo "
service smtp
{
	socket_type     = stream
	protocol        = tcp
	wait            = no
	disable		= no
	user            = root
	instances       = UNLIMITED
	server          = $QMAIL_ROOT_D/bin/tcp-env
	server_args     = $RBLSMTPD $rbl_server $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $TRUE_BIN $QMAIL_ROOT_D/bin/cmd5checkpw $TRUE_BIN
}" > "$xinetd_dir/smtp_${product}" || die "$inten"
					;;

				*)
					echo "
service smtp
{
	socket_type     = stream
	protocol        = tcp
	wait            = no
	disable		= no
	user            = root
	instances       = UNLIMITED
	server          = $QMAIL_ROOT_D/bin/tcp-env
	server_args     = $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $TRUE_BIN $QMAIL_ROOT_D/bin/cmd5checkpw $TRUE_BIN
}" > "$xinetd_dir/smtp_${product}" || die "$inten"
					;;
			esac	
			;;

		smtps)
			case "$rbl_on" in
				on)				
					echo "
service smtps
{
	socket_type     = stream
	protocol        = tcp
	wait            = no
	disable		= no
	user            = root
	instances       = UNLIMITED
	server          = $QMAIL_ROOT_D/bin/tcp-env
	server_args     = $RBLSMTPD $rbl_server $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $TRUE_BIN $QMAIL_ROOT_D/bin/cmd5checkpw $TRUE_BIN
}" > "$xinetd_dir/smtps_${product}" || die "$inten"
					;;
				*)
					echo "
service smtps
{
	socket_type     = stream
	protocol        = tcp
	wait            = no
	disable		= no
	user            = root
	instances       = UNLIMITED
	server          = $QMAIL_ROOT_D/bin/tcp-env
	server_args     = $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $TRUE_BIN $QMAIL_ROOT_D/bin/cmd5checkpw $TRUE_BIN
}" > "$xinetd_dir/smtps_${product}" || die "$inten"
					;;
			esac	
			;;

		poppassd)
			echo "
service poppassd
{
	socket_type		= stream
	protocol		= tcp
	port			= 106
	wait			= no
	disable			= no
	user			= root
	instances		= 1000
	flags			= KEEPALIVE
	server			= $PRODUCT_ROOT_D/admin/bin/poppassd
}" > "$xinetd_dir/poppassd_${product}" || die "$inten"
			;;
	esac

    case "$machine" in
       Darwin)
echo '#!/bin/sh

name_service='org.xinetd.xinetd'
    
    case "$1" in
        start)
           echo "Plesk: Starting xinetd"
           launchctl start "$name_service"
        ;;
        stop)
           echo "Plesk: Stopping xinetd"
           launchctl stop "$name_service"
        ;;
        restart)
           start
           stop
        ;;
        *)
           echo "Usage: xinetd [start|stop|restart]"
        ;;
    esac 
' > "$PRODUCT_RC_D/xinetd"

     chmod 755 "$PRODUCT_RC_D/xinetd"
       ;;
       *)
       ;;
    esac

	suc
}

setup_inetd()
{
	local service rbl_on rbl_server

	service=$1;
	rbl_on=$2;
	rbl_server=$3;
	
	local ftp_rec smtp_rec pop3_rec 

	ftp_rec="ftp stream tcp nowait root $PRODUCT_ROOT_D/ftpd/sbin/proftpd proftpd -c $PRODUCT_ROOT_D/ftpd/etc/proftpd.conf"
	
	case "$linux_distr" in
		debian)
			maxconn='.1000'
		;;
		*)
		        maxconn=""
		;;
	esac

	case "$rbl_on" in
		on)
			smtp_rec="smtp stream tcp nowait$maxconn root $QMAIL_ROOT_D/bin/tcp-env tcp-env  $RBLSMTPD $rbl_server $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $QMAIL_ROOT_D/bin/true $QMAIL_ROOT_D/bin/cmd5checkpw $QMAIL_ROOT_D/bin/true"
			smtps_rec="smtps stream tcp nowait$maxconn root $QMAIL_ROOT_D/bin/tcp-env tcp-env  $RBLSMTPD $rbl_server $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $QMAIL_ROOT_D/bin/true $QMAIL_ROOT_D/bin/cmd5checkpw $QMAIL_ROOT_D/bin/true"
			;;
		*)
			smtp_rec="smtp stream tcp nowait$maxconn root $QMAIL_ROOT_D/bin/tcp-env tcp-env  $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $QMAIL_ROOT_D/bin/true $QMAIL_ROOT_D/bin/cmd5checkpw $QMAIL_ROOT_D/bin/true"
			smtps_rec="smtps stream tcp nowait$maxconn root $QMAIL_ROOT_D/bin/tcp-env tcp-env  $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $QMAIL_ROOT_D/bin/true $QMAIL_ROOT_D/bin/cmd5checkpw $QMAIL_ROOT_D/bin/true"
			;;
	esac

	case "$machine" in
		BSD*)
			poppassd_rec="poppassd stream tcp nowait/1000 root /usr/libexec/tcpd $PRODUCT_ROOT_D/admin/bin/poppassd"
			;;
		*)
			poppassd_rec="poppassd stream tcp nowait/1000 root /usr/sbin/tcpd $PRODUCT_ROOT_D/admin/bin/poppassd"
			;;
	esac

	case "$service" in

		ftp)
			if [ -x /usr/sbin/update-inetd ]; then

				# Use Debian inetd config manipulation facility
				/usr/sbin/update-inetd --remove "ftp"
				/usr/sbin/update-inetd --add "$ftp_rec"

			else
				grep_res=`egrep "^ftp.*/${product}/ftpd/sbin/proftpd*." $inetd_conf`
				inten="add ftp service (proftpd) record into the $inetd_conf file"
				echo_try $inten

				case "$grep_res" in
					ftp*)
						p_echo
						p_echo " ftp service (proftpd) is already in the $inetd_conf"
						;;
					*)
						comment_service $service
						echo "$ftp_rec" >> $inetd_conf && suc || die
						;;
				esac
			fi
			;;

		smtp)
			if [ -x /usr/sbin/update-inetd ]; then

				# Use Debian inetd config manipulation facility
				/usr/sbin/update-inetd --remove "smtp"
				/usr/sbin/update-inetd --add "$smtp_rec"

			else
				egrep "^smtp.*$QMAIL_ROOT_D/bin/tcp-env.*tcp-env.*$QMAIL_ROOT_D/bin/relaylock.*$" "$inetd_conf" >> $product_log 2>&1
				case "$?" in
					0)
						sed -e "/^smtp/d" < "$inetd_conf" > "$inetd_conf.${product}_tmp" \
						&& mv -f "$inetd_conf.${product}_tmp" "$inetd_conf" || die >> $product_log 2>&1
						;;
					1)
						comment_service $service
						;;
					*)
						err
						;;
				esac

				inten="add smtp service record into the $inetd_conf file"
				echo_try $inten
				echo "$smtp_rec"  >> $inetd_conf  && suc || die $inten
			fi
			;;

		smtps)

			if [ -x /usr/sbin/update-inetd ]; then

				# Use Debian inetd config manipulation facility
				/usr/sbin/update-inetd --remove "smtps"
				/usr/sbin/update-inetd --add "$smtps_rec"

			else

				egrep "^smtps.*$QMAIL_ROOT_D/bin/tcp-env.*tcp-env.*$QMAIL_ROOT_D/bin/relaylock.*$" "$inetd_conf" >> $product_log 2>&1
				case "$?" in
					0)
						sed -e "/^smtps/d" < "$inetd_conf" > "$inetd_conf.${product}_tmp" \
						&& mv -f "$inetd_conf.${product}_tmp" "$inetd_conf" || die >> $product_log 2>&1
						;;
					1)
						comment_service $service
						;;
					*)
						err
						;;
				esac

				inten="add smtps service record into the $inetd_conf file"
				echo_try $inten
				echo "$smtps_rec"  >> $inetd_conf  && suc || die $inten
			fi
			;;

		poppassd)

			if [ -x /usr/sbin/update-inetd ]; then

				# Use Debian inetd config manipulation facility
				/usr/sbin/update-inetd --remove "poppassd"
				/usr/sbin/update-inetd --add "$poppassd_rec"
			else
				#	^poppassd.*$PRODUCT_ROOT_D/admin/bin/poppassd.*
				grep_res=`egrep "^poppassd.*$PRODUCT_ROOT_D/admin/bin/poppassd.*" $inetd_conf`
				inten="add poppassd service record in the $inetd_conf"
				echo_try $inten
		
				case "$grep_res" in
					poppassd*)
						p_echo
						p_echo " poppassd service is already in the $inetd_conf"
						;;
					*)
						comment_service $service
						echo "$poppassd_rec" >> $inetd_conf && suc || die
						;;
				esac
			fi
			;;
	esac

}

setup_super_server()
{
	local service rbl_on rbl_server
	service=$1;
	rbl_on=$2;
	rbl_server=$3;

	super_server_type

	case "$super_server" in

		xinetd)
			setup_xinetd "$service" "$rbl_on" "$rbl_server"
			;;
		inetd)
			setup_inetd "$service" "$rbl_on" "$rbl_server"
			;;
	esac

	restart_super_server
}

get_pid()
{
	local i

	ex_f="$1"
	opt="$2"
	owner="$3"

	min_num=`expr 1`

	case "$opt" in
		false)
			for i in `$ps_long | grep $ex_f | grep -v grep | grep -v httpsdctl | grep -v apachectl | awk '{print $2}' -`; do
				min_num=$i
				break
			done
			;;
		true)
			for i in `$ps_long | grep $ex_f | grep -v grep | grep -v httpsdctl | grep -v apachectl | grep "$owner" | awk '{print $2}' -`; do
				min_num=$i
				break
			done
			;;
		*)
			p_echo "get_pid: wrong parameter"
			die "get_pid $ex_f $opt $owner"
			;;
	esac

	common_var=$min_num
	return $min_num
}

kill_pids()
{
	ex_f="$1"
	owner="$2"

	for i in `$ps_long | grep $ex_f | grep -v grep | grep -v httpsdctl | grep -v apachectl | grep $owner | awk '{print $2}' -`; do
		if [ $i -gt 1 ]; then
			$K_TERM $i >> $product_log 2>&1
		fi
	done
}

get_pids_byname()
{
	proc_name="$1"
	PIDS=`ps axww | awk '$5 ~ "'$proc_name'$" {print $1}'`
	echo $PIDS
}

#lib_test

test_for_root()
{
	my_id="`id`"
	case "$my_id" in
		uid=0\(root\)*)
			;;
		*)	echo "$0: This script must be run as root"
			echo "Log in as root then run this script again."
			echo
			exit 1
			;;
	esac
}
get_userID()
{
# try to get UID
	common_var=`id -u "$1" 2>/dev/null` 

# if id returns 0 the all is ok
	if [ "$?" -eq "0" -a ! -z "$common_var" ]; then
		return 1;
	fi

	return 0;
}

get_groupID()
{
# try to get GID, id -g doesn't show groups without users
    case "$machine" in
       Darwin)
         common_var=`nireport / /groups name gid| grep "$1"| awk '{print $2}'`
       ;;
	   *)
         common_var=`cat /etc/group | awk -F':' '$1 == "'$1'" {print $3}'` 
       ;;
    esac

# We have non-empty value if success
	if [ ! -z "$common_var" ]; then
		return 1;
	fi

	return 0;
}

delete_user()
{
	local rm_user

	rm_user="$1"

	# if it is mailman user, remove its crontab from system
	if [ "X${rm_user}" = "X${mailman_user}" ]; then

		inten="remove crontab of ${rm_user}"
		echo "y" | $crontab -u "${mailman_user}" -r >> $product_log 2>&1 || die "$inten"

	fi

	inten="remove user $rm_user"
	echo_try "$inten"

	case "$machine" in
		BSD)
			echo "y" | pw userdel $rm_user>> $product_log 2>&1 && suc || die "$inten"
			pwd_mkdb /etc/master.passwd >> $product_log 2>&1
		;;
		BSDI)
			rmuser $rm_user>> $product_log 2>&1 && suc || die "$inten"
			pwd_mkdb /etc/master.passwd >> $product_log 2>&1

		;;
		linux|solaris)
			userdel  $rm_user>> $product_log 2>&1 && suc || die "$inten"
		;;
		Darwin)
			niutil -destroy / /users/"$rm_user" >> $product_log 2>&1 && suc || die "$inten"
		;;
	esac
}

delete_group()
{
	local rm_group

	rm_group="$1"

	inten="remove group $rm_group"
	echo_try "$inten"

	case "$machine" in
		BSD)
			pw groupdel $rm_group>> $product_log 2>&1
			pwd_mkdb /etc/master.passwd >> $product_log 2>&1
		;;
		BSDI)
			rmgroup $rm_group>> $product_log 2>&1
			pwd_mkdb /etc/master.passwd >> $product_log 2>&1
		;;
		linux|solaris)
			mk_backup "/etc/group" cp f
			if [ -f "/etc/group" ]; then
				sed -e "/$rm_group/d" < /etc/group > /etc/group.tmp || die $inten
				mv -f /etc/group.tmp /etc/group  >> $product_log 2>&1
				if [ "$?" -ne 0 ]; then
					rsr_backup "/etc/group" cp f
					die $inten
				fi
			fi
#		groupdel  $rm_group>> $product_log 2>&1
		;;
		Darwin)
			niutil -destroy / /groups/"$rm_group" >> $product_log 2>&1 && suc || die "$inten"
		;;
	esac
	suc
}
initial_conf()
{
	DEMO_VERSION="no"
	PRODNAME="psa"
	PRODUCT_NAME="Plesk"
	product_full="Plesk"
	PRODUCT_FULL_NAME="Plesk"

	product_etc="/etc/${PRODNAME}"
	prod_conf_t="/etc/psa/psa.conf"
	prodkey="$product_etc/$PRODNAME.key"

	minimal_changes=""

	MYSQL_VERS="4.1.18"
	POSTGRESQL_VERS="7.4.11"
	EXTERNAL_PACKAGES="expat libiconv"
	EXTERNAL_PACKAGES_DIR=""tmp/packages""

	BUILDER_UID="10007"

	PERL5LIB="/usr/local/psa/lib/perl5/site_perl/5.8.8:/usr/local/psa/lib/perl5/site_perl/5.8.8/mach"
	export PERL5LIB

	product_bs=Plesk
        support_contact="http://www.swsoft.com/support"
	sales_email="sales@swsoft.com"

	product_version="8.0.1"
	product_db_version="0801"
	product_build="80061018.20"
	conceived_os_vendor=FreeBSD
	conceived_os_version="5.4"
	osrels="fr5.4"

	# This variable contains all versions, which is supported by
	# cumulative upgrade
	known_product_versions="71 75 80"

	prev_product="plesk"
	prev_clients_group="${prev_product}cln"

	# GID for mailman
	mm_mailgroup=110

	# plesk default password
	if [ "X$DEMO_VERSION" = "Xyes" ]; then
		PRODUCT_DEFAULT_PASSWORD="plesk"
	else
		PRODUCT_DEFAULT_PASSWORD="setup"
	fi

	my_name_0="`pwd`"
	if [ $? -ne 0 ]; then
		echo "Unable to determine current working directory."
		echo "Please fix the problem and run installation again."
		exit 1
	fi

	my_name_1="`basename ""$0""`"
	my_name_2=`echo ""$0""|sed -e "s/^\.\///"`
	echo $my_name_2 | egrep '^/' >/dev/null 2>&1
	case "$?" in
		0)
			my_name="$my_name_2"
		;;
		1)
			my_name="$my_name_0"/"$my_name_2"
		;;
	    *)
			echo "Unable to determine the name of installer."
			echo "Please fix the problem and run installation again."
			exit 1
		;;
	esac
}

read_conf()
{
	initial_conf

	if [ -s $prod_conf_t ]; then
		tmp_var=`perl -e 'undef $/; $_=<>; s/#.*$//gm;
				s/^\s*(\S+)\s*/$1=/mg;
				print' $prod_conf_t`
		eval $tmp_var
	else
		[ 0$ignore_miss_conf -ne 1 ] && p_echo "Unable to find product configuration file: $prod_conf_t"
		return 1
#		die "find product configuration file: $prod_conf_t"
	fi
	return 0

}

selinux_close()
{
	if [ -z "$SELINUX_ENFORCE" -o "$SELINUX_ENFORCE" = "Disabled" ]; then
		return
	fi

	setenforce "$SELINUX_ENFORCE"
}


#set_params

set_common_params()
{

	PATH=/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/sbin:/usr/local/bin
	LANG=C
	export PATH LANG
	umask 022
	ulimit -n 65535 2>/dev/null

	K_HUP="/bin/kill -HUP"
	K_KILL="/bin/kill -KILL"
	K_TERM="/bin/kill -TERM"
	K_USR2="/bin/kill -USR2"

	users_created=""
	groups_created=""

	certificate_file="$PRODUCT_ROOT_D/etc/httpsd.pem"
	product=${PRODNAME}
	START_SH="$PRODUCT_RC_D/${product}"

	clients_group="${product}cln"
	clients_GID=10001

	services_group="${product}serv"
	services_GID=10003

	product_suff="saved_by_${product}".`date "+%m.%d;%H:%M"`
	product_suffo="saved_by_${product}"

	common_var=0

	services="/etc/services"
	mtab="/etc/mtab"
	xinetd_conf="/etc/xinetd.conf"
	xinetd_dir="/etc/xinetd.d"
	inetd_conf="/etc/inetd.conf"
	syslog_conf="/etc/syslog.conf"
	syslog_conf_ng="/etc/syslog-ng/syslog-ng.conf"
	get_hostname="hostname"
	get_domainname="domainname"

	#VZP used to determine that we're inside SVE
	vza_file="/var/vzagent"

	PREV_PRODUCT_ROOT_D="/usr/local/${prev_product}"

	#default parameters
	tar="tar"
	crontab="/usr/bin/crontab"

	#machine depended parameters
	TARGET_OS="`uname -a`"
	case "$TARGET_OS" in

		BSD/OS*BSDI*i386)
			machine="BSDI"
			sendmail="/usr/sbin/sendmail"
			mail_local="/usr/libexec/mail.local"
			ps="ps axw"
			ps_long="ps axwu"
			dummy_shell="/sbin/nologin"
			dummy_home="/"
			false_shell="/usr/bin/false"
			compress="compress"
			uncompress="uncompress -c"
			uudecode="uudecode -o /dev/stdout"
			uudecode_full="/usr/bin/uudecode"
			ifconfig="/sbin/ifconfig -a"
			inet_str="inet"
			named_osrelease=0
			fstab="/etc/fstab"
			;;

		FreeBSD*i386)
			fstab="/etc/fstab"
			machine="BSD"
			sendmail="/usr/sbin/sendmail"
			mail_local="/usr/libexec/mail.local"
			ps="ps axw"
			ps_long="ps axfwu"
			dummy_shell="/sbin/nologin"
			dummy_home="/"
			false_shell="/usr/bin/false"
			bash_shell="/usr/local/bin/bash"
			rbash_shell="/usr/local/bin/rbash"
			compress="gzip -9 -c"
			uncompress="gunzip -c"
			uudecode="uudecode -p"
			uudecode_full="/usr/bin/uudecode"
			ifconfig="/sbin/ifconfig -a"
			inet_str="inet"
			os_version=`uname -v | sed -e 's/^.*FreeBSD[ \t][ \t]*\([0-9\.][0-9\.]*\)-.*$/\1/'`

			if tar --version | grep bsdtar > /dev/null ; then
				if which gtar > /dev/null; then
				    tar="gtar"
				else
				    echo "Unable to locate gtar on your system."
				    echo "Please, install the archiving software and retry installation."
				    exit 1
				fi
			fi

			named_osrelease=040100 # "must be >= 020218 for  named -u <named> "
			;;
		Darwin*powerpc)
			machine="Darwin"
			sendmail="/usr/sbin/sendmail"
			mail_local=""
			ps="ps axw"
			ps_long="ps axSwu"
			dummy_shell="/usr/bin/false"
			dummy_home="/"
			false_shell="/usr/bin/false"
			bash_shell="/bin/bash"
			rbash_shell="/bin/rbash"
			compress="gzip -9 -c"
			uncompress="gunzip -c"
			uudecode="uudecode -p"
			uudecode_full="/usr/bin/uudecode"
			ifconfig="/sbin/ifconfig -a"
			inet_str="inet"
			named_osrelease=0
			fstab="/etc/fstab.hd"
			;;

		SunOS*5.*sun4*)
			machine="solaris"
			inetd_conf="/etc/inet/inetd.conf"
			services="/etc/inet/services"
			crontab="/bin/crontab"
			useradd_options=""
			sendmail="/usr/lib/sendmail"
			sndml_ini="/etc/init.d/sendmail"
			mail_local="/usr/lib/mail.local"
			ps="ps -e"
			ps_long="ps -aef"
			dummy_shell="/bin/false"
			dummy_home="/"
			false_shell="/bin/false"
			compress="compress"
			uncompress="uncompress"
			uudecode="uudecode -p"
			uudecode_full="/bin/uudecode"
			tar="gtar"
			ifconfig="/usr/sbin/ifconfig -a"
			inet_str="inet"
			named_osrelease=0
			fstab="/etc/fstab"
			;;

		Linux*2.?.*i?86*| \
		Linux*2.?.*x86_64*)
			get_hostname="hostname -f"
			fstab="/etc/fstab"
			if [ -f /etc/slackware-version ]; then
			    machine="linux"
			    linux_distr="slackware"
			    useradd_options=""
			    sendmail="/usr/sbin/sendmail"
			    sndml_ini="/etc/rc.d/init.d/sendmail"
			    mail_local="/usr/libexec/mail.local"
			    ps="ps axw"
			    ps_long="ps axuw"
			    dummy_shell=""
			    dummy_home="/"
			    false_shell="/bin/false"
			    compress="gzip -9 -c"
			    uncompress="gunzip -c"
			    uudecode="uudecode -o /dev/stdout"
			    ifconfig="/sbin/ifconfig -a"
			    inet_str="inet addr"
			    named_osrelease=0
			else
			    machine="linux"
				useradd_options="-M"
				if [ -f /etc/mandrake-release ]; then
			    	linux_distr="mandrake"
				elif [ -f /etc/fedora-release ]; then
			    	linux_distr="fedora"
				elif [ -f /etc/SuSE-release ]; then
			    	linux_distr="suse"
				elif [ -f /etc/debian_version ]; then
			    	linux_distr="debian"
					get_domainname="dnsdomainname"
					useradd_options=""
				else
			    	linux_distr="redhat"
				fi
			    sendmail="/usr/sbin/sendmail"
			    sndml_ini="/etc/init.d/sendmail"
			    mail_local="/usr/libexec/mail.local"
			    ps="ps axw"
			    ps_long="ps axuw"
			    dummy_shell="/bin/false"
			    dummy_home="/"
			    false_shell="/bin/false"
				bash_shell="/bin/bash"
				rbash_shell="/bin/rbash"
			    compress="gzip -9 -c"
			    uncompress="gunzip -c"
			    uudecode="uudecode -o /dev/stdout"
			    uudecode_full="/usr/bin/uudecode"
			    ifconfig="/sbin/ifconfig -a"
			    inet_str="inet addr"
			    named_osrelease=`cat /proc/sys/kernel/osrelease | perl -F"/[.-]/" -n -a  -e 'printf "%02u%02u%02u\n", $F[0],$F[1],$F[2]'`
			fi
			;;
		*)
			echo
			echo "Sorry, but your configuration isn't supported yet"
			echo "uname is $TARGET_OS"
			echo
			echo "For more information, please contact $support_email"
			echo
			;;
	esac

	# setup process
	if [ "X$process" = "X" ]; then
		if   [ "X$do_reconfigure" = "X1" ]; then
	    	process="reconfiguration"
		elif  [ "X$do_upgrade" = "X1" ]; then
	    	process="upgrade"
		else
		    process="installing"
		fi
	fi

#	common_var="real"
#	if [ -f $PRODUCT_ROOT_D/version -a "X$do_patch" = "X" ]; then
#	    common_var=`cat $PRODUCT_ROOT_D/version | tr '[:blank:]' '_'`
	product_log="/tmp/${product}_${product_version}_${conceived_os_vendor}_${conceived_os_version}_build${product_build}_${process}.log"
	product_problems_log="/tmp/${product}_${product_version}_${conceived_os_vendor}_${conceived_os_version}_build${product_build}_problems.log"
	init_log
#	elif [ "X$my_name_1" != "X" ]; then
#	    product_log="/tmp/${my_name_1}.log"
#	else
#	    product_log="/tmp/${product}_default_${process}.log"
#	fi

	detect_vz
}


set_local_params()
{
	set_common_params

	for i in set_apache_params set_admin_params lock_keyupdate set_fp_params set_drweb_qmail_params set_courier_imap_params set_ftpd_params set_jdk_params set_tomcat_params set_logrotate_params set_mailman_params set_mysqld_params set_named_params set_openssl_params set_pgsql_params set_qmail_params set_spamassassin_params set_vhosts_params set_webalizer_params set_horde_params ; do
		$i
		local res="$?"
		if [ "0$res" -gt 0 ]; then
			return "$res"
		fi
	done
}
set_logrotate_params()
{
	# primary Plesk logrotate config file
	logrotate_conf="${product_etc}/logrotate.conf"

	# directory for logrotate configs of virtual hosts
	logrotate_include_d="${PRODUCT_ROOT_D}/etc/logrotate.d"
}

#all functions in this file are valid for Standard builds only
set_mailman_params()
{
	mailman_user="mailman"
	mailman_group="mailman"
	mailman_UID=91
	mailman_GID=91
	MAILMAN_ROOT_D="${PRODUCT_ROOT_D}"/mailman
	MAILMAN_VHOST_D="${HTTPD_VHOSTS_D}"/mailman
}

remove_modules()
{
	p_echo
	p_echo "===> Removing modules"

	local moduledir
	for moduledir in $PRODUCT_ROOT_D/var/modules/*; do
		if [ -d "$moduledir" -a -x "$moduledir/uninstall" ]; then
			local module=`basename $moduledist`
			echo_try "uninstall $module module"
			"$moduledir/uninstall" && suc || warn "uninstallation of $module module"
		fi
	done
}

#mysql

set_mysqld_params()
{
	mysql_user="mysql"
	mysql_UID=3306
	mysql_group="mysql"
	mysql_GID=3306

	product_db_sql="$PRODUCT_ROOT_D/etc/${PRODNAME}_db.sql"

	mysql_passwd_file="$product_etc/.${PRODNAME}.shadow"
	default_mysql_passwd="$PRODUCT_DEFAULT_PASSWORD"
	prev_mysql_passwd_file="$PREV_PRODUCT_ROOT_D/admin/conf/admin.conf"

#	admin_passwd=${default_mysql_passwd}
	get_admin_passwd

	set_mysql_client_params
	set_mysql_server_params
}

## @@constructor set_mysqld_params

set_mysql_server_params()
{
	MYSQL_ROOT="$PRODUCT_ROOT_D/mysql"
	mysql_bindir="$MYSQL_BIN_D"
	mysql_service="mysqld"
}

set_mysql_client_params()
{
	mysql_client="$MYSQL_BIN_D/mysql"

	# Override these variables as needed
	mysql_db_name="$PRODNAME"
	mysql_auth="-uadmin -p$admin_passwd"
	mysql_args="-N"
	mysql_args_raw="-B -r"

	# For backward compatibility only, should use mysql() and mysql_raw() instead
	mysql=mysql
	mysql_raw=mysql_raw
}

# Invoke mysql
mysql()
{
	mysql_anydb -D$mysql_db_name "$@"
}

mysql_anydb()
{
	if test -z "$DB_IS_MYSQL41_COMPATIBLE"; then
		mysql41_init
	fi

	if test "$DB_IS_MYSQL41_COMPATIBLE" != "compatible"; then
		mysql41_exec_wrapper $mysql_client $mysql_auth $mysql_args "$@" 2>>"$product_log"
	else
		$mysql_client $mysql_auth $mysql_args "$@" 2>>"$product_log"
	fi

	local status=$?
	if [ $status -gt 0 ]; then
		$mysql_client $mysql_auth $mysql_args -D$mysql_db_name $mysql_args_raw -e "show innodb status" >>"$product_log" 2>&1
	fi
	return $status
}

# the function removes the "character set xxx" and "collate xxx" construction
# from -e * arguments, if there are any.
# otherwise, it removes the same things from standard input
mysql41_exec_wrapper()
{
	perl -e '$has_command = 0;
		$program = $ARGV[0];
		splice (@ARGV, 0, 1);
		sub remove_chasets($)
		{
			$refStr = shift;
			$$refStr =~ s/\b(medium|long|tiny)?text\s+character\s+set\s+binary(\s+collate\s+[\w]+)?\b/ $1blob /ig;
            $$refStr =~ s/\b(medium|long|tiny)?text\s+character\s+set\s+[\w]+\s+collate\s+[\w]+_bin\b/ $1blob /ig;
			$$refStr =~ s/(\bcharacter\s+set\s+binary(\s+collate\s+[\w]+)?\b)/ binary /ig;
			$$refStr =~ s/(\bcharacter\s+set\s+[\w]+\s+collate\s+[\w]+_bin\b)/ binary /ig;
			$$refStr =~ s/(\b(character\s+set|collate)\s+[\w]+\b)//ig;
		}
		foreach $n (0 .. $#ARGV) {
			if ($ARGV[$n] eq "-e") {
				$has_command = 1;
				remove_chasets \($ARGV[$n + 1]);
			}
		}
		if ($has_command) {
			exec $program, @ARGV or die "Cannot exeecute mysql";
		} else {
			open out_command, "|-", $program, @ARGV or die "Cannot start mysql";
			while (<STDIN>) {
				remove_chasets \($_);
				print out_command $_;
			}
			close out_command or die($! ? "Mysql returned an error: $!" : "Mysq exited with non-zero status $?");
		}' -- "$@"
}

# Invoke mysql in raw mode
mysql_raw()
{
	mysql $mysql_args_raw "$@"
}

mysql_raw_anydb()
{
	mysql_anydb $mysql_args_raw "$@"
}

mysql41_init()
{
	# not_installed is the default state
	# we must init it to avoid endless cycle
	DB_IS_MYSQL41_COMPATIBLE=not_installed
	if ! mysql_anydb </dev/null >>"$product_log" 2>&1; then
		return
	fi

	if db_test --any-db "SHOW VARIABLES LIKE 'version'" '$2 !~ /^(3|4\.0)\./'; then
		# if database is not yet initiailized, assume it compatible
		# otherwise, check the flag
		if
			db_test --any-db "SHOW DATABASES" '/^psa$/' \
			&& db_test "SHOW TABLES" '/^misc$/' \
			&& ! db_test "SELECT val FROM misc WHERE param = 'mysql41_compatible'" '/true/'
		then
			DB_IS_MYSQL41_COMPATIBLE='not_compatible'
		else
			DB_IS_MYSQL41_COMPATIBLE='compatible'
		fi
	fi
}

#named

set_named_params()
{
	# set up default values
	bind_UID=53
	bind_GID=53
	bind_user="bind";
	bind_group="bind";

	# get UID of named user, if exists
	get_userID $bind_user
	if [ $? -ne 0 ]; then
	    bind_UID=$common_var;
        fi

	# get GID of named group, if exists
	get_groupID $bind_group
	if [ $? -ne 0 ]; then
	    bind_GID=$common_var;
	fi

	# old named is not able to run in non-root environment
	if [ 0$named_osrelease -lt 020218 ]; then
	    bind_user="root";
	    bind_UID=0;
	fi

	# path to directory of internal named
	NAMED_ROOT_D="${PRODUCT_ROOT_D:?'PRODUCT_ROOT_D is undefined'}/named"

	# path to directory of named pid file
	bind_run="${NAMED_RUN_ROOT_D:?'NAMED_RUN_ROOT_D is undefined'}/var/run/named"
	# Named start/stop script
	NAMED_RC_SCRIPT="/etc/rc.d/named"
	
	# path to named config file
	named_conf="/etc/named.conf"
	rndc_conf="/etc/rndc.conf"
	rndc_namedb_conf="/etc/namedb/rndc.conf"
	rndc_bind_conf="/etc/bind/rndc.conf"
}
set_openssl_params()
{
    openssl_psa_sbin=${PRODUCT_ROOT_D}/admin/sbin/openssl;
    openssl_psa_bin=${PRODUCT_ROOT_D}/admin/bin/openssl;
    openssl_std_bin=/usr/bin/openssl;
}
set_pgsql_params()
{
	pgsql_user="postgres"
	pgsql_group="postgres"
	pgsql_UID=5432
	pgsql_GID=5432

	# path to postgresql for Standard builds
	PGSQL_ROOT_D="$PRODUCT_ROOT_D/postgresql"
}

#qmail

set_qmail_params()
{
QMAIL_DIR="/usr/local/psa/qmail"
QMAIL_USERS="alias:2021:nofiles:false:alias  qmaild:2020:nofiles:false:  qmaill:2022:nofiles:false:  qmailp:2023:nofiles:false:  qmailq:2520:qmail:  qmailr:2521:qmail:  qmails:2522:qmail:"
QMAIL_GROUPS="qmail:2520  nofiles:2020"
}
#values of variables in set_spamassassin_params are valid for Standard builds only

set_spamassassin_params()
{
	SPAMASSASSIN_ROOT_D=${PRODUCT_ROOT_D}/spamassassin
}

rsr_backup()
{
	target="$1"
	dup="$2"
	opts="$3"
	common_var=0

#	if [ -$opts "$target" ]; then
		if [ -$opts "$target.$product_suff" ]; then
			case "$dup" in
				mv)
					mv -f  $target.$product_suff $target>> $product_log 2>&1
					common_var=1
					return 1
					;;
				cp)
					cp -fp  $target.$product_suff $target>> $product_log 2>&1
					common_var=1
					return 1
					;;
				*)
					p_echo " rsr_backup: wrong option -- must be 'cp' or 'mv'"
					;;
			esac
		else
			if [ -$opts "$target.$product_suffo" ]; then
			    case "$dup" in
				mv)
					mv -f  $target.$product_suffo $target>> $product_log 2>&1
					common_var=1
					return 1
					;;
				cp)
					cp -fp  $target.$product_suffo $target>> $product_log 2>&1
					common_var=1
					return 1
					;;
				*)
					p_echo " rsr_backup: wrong option -- must be 'cp' or 'mv'"
					;;
			    esac
			fi
		fi
#	else
#		case "$opts" in
#			f|d)
#				;;
#			*)
#				p_echo " rsr_backup: wrong option -- must be 'f' or 'd'"
#				;;
#		esac
#	fi
}

restore_named()
{
	cd "$PRODUCT_ROOT_D" >> $product_log 2>&1
	[ -f /etc/sysconfig/named ] && mv -f "/etc/sysconfig/named" "/etc/sysconfig/named.bak"
	rsr_backup "/etc/sysconfig/named" mv f

	[ -L $named_conf ] && rm -f "$named_conf"
	rsr_backup "$named_conf" mv f

	[ -L $rndc_conf ] && rm -f "$rndc_conf"
	rsr_backup "$rndc_conf" mv f

	case "$machine" in
		BSD*)
			rsr_backup /etc/named.boot mv f
			;;
		linux)
		    case "$linux_distr" in
			redhat)
			    chkconfig --add named >> $product_log 2>&1
#			    std_named_sh="/etc/rc.d/init.d/named"
#			    rsr_backup $std_named_sh mv f
#				if [ -f "$std_named_sh" ]; then
#					mv -f "$std_named_sh.${product}" "$std_named_sh"
#				fi
				;;
			slackware)
			    rsr_backup /etc/rc.d/rc.inet2 cp f
				;;
		    esac
			rsr_backup /etc/named.boot mv f
			;;
		solaris)
			rsr_backup /etc/named.boot mv f
			;;
	esac
}


restore_sendmail()
{
	[ -L $sendmail ] && rm -f "$sendmail"
	[ -L /usr/lib/sendmail ] && rm -f "/usr/lib/sendmail"

	rsr_backup "$sendmail" mv f

	case "$machine" in
		BSDI)
			rsr_backup /etc/sendmail.cf mv f
			;;
		*)
			;;
	esac

	if [ -f "$mail_local" ]; then
#		case "$machine" in
#			BSD)
#				chflags schg "$mail_local" >> $product_log 2>&1
#				;;
#			*)
#				;;
#		esac

		rsr_backup "$mail_local" mv f

		chmod 4555 "$mail_local" >> $product_log 2>&1
	fi
	case "$machine" in
		linux )
		    case "$linux_distr" in
			redhat)
			    chkconfig --add sendmail >> $product_log 2>&1
#			    rsr_backup "$sndml_ini" mv f
				;;
			slackware)
			     rsr_backup /etc/rc.d/rc.M mv f
				;;
		    esac
			;;
		solaris)
			rsr_backup "$sndml_ini" mv f
			;;
		*)
			;;
	esac

}

delete_startup_scripts()
{
	cd "$PRODUCT_ROOT_D" >> $product_log 2>&1

	case "$machine" in
		BSD)
			rm -f /usr/local/etc/rc.d/${product}.sh >> $product_log 2>&1
	#		rsr_backup /etc/rc.conf cp f

#			inten="enable standard sendmail & named (within /etc/rc.conf)"
#			echo_try $inten
			sed -e 's/^sendmail_enable="NONE".*//g' \
				-e "s/^#named_enable/named_enable/g" \
				< /etc/rc.conf > /etc/rc.conf.${product}_tmp
			mv -f /etc/rc.conf.${product}_tmp /etc/rc.conf
#			suc
			;;
		BSDI)
			if [ -f /etc/rc.local.${product} ]; then
				cp -p  /etc/rc.local.${product} /etc/rc.local >> $product_log 2>&1
			fi
			;;
		linux)
		    case "$linux_distr" in
			redhat)
			    chkconfig --del ${product}
			    rm -f /etc/rc.d/init.d/${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc0.d/K15${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc1.d/K15${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc2.d/K15${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc3.d/S77${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc4.d/S77${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc5.d/S77${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc6.d/K15${product} >> $product_log 2>&1
				;;
			slackware)
			    if [ -f /etc/rc.d/rc.local.${product} ]; then
				cp -p  /etc/rc.d/rc.local.${product} /etc/rc.d/rc.local >> $product_log 2>&1
			    fi
				;;
		    esac
		    ;;
		solaris)
			rm -f  /etc/init.d/${product} >> $product_log 2>&1
			if [ -f /etc/rc0.d/K01${product} ]; then
				rm -f /etc/rc0.d/K01${product} >> $product_log 2>&1
			fi

			if [ -f /etc/rc1.d/K01${product} ]; then
				rm -f /etc/rc1.d/K01${product} >> $product_log 2>&1
			fi

			if [ -f /etc/rc2.d/S77${product} ]; then
				rm -f /etc/rc2.d/S77${product} >> $product_log 2>&1
			fi
			;;
	esac
}

delete_crontab()
{

	$crontab -l 2>/dev/null > /tmp/crontab.${product}

	sed -e "s/^.*\/${product}\/admin\/sbin\/statistics.*//g" \
		-e "s/^.*\/${product}\/bin\/mysqldump.*//g" \
		-e "s/^.*\/usr\/sbin\/ntpdate.*//g" \
		< /tmp/crontab.${product} > /tmp/crontab.${product}_tmp

	mv -f /tmp/crontab.${product}_tmp /tmp/crontab.${product} >> $product_log 2>&1

	$crontab /tmp/crontab.${product}  >> $product_log 2>&1

	rm -f /tmp/crontab.${product} >> $product_log 2>&1

}

remove_ftpuser()
{
	user=$1
	ftpusers_file="/etc/ftpusers"

	egrep "^$user" $ftpusers_file >> /dev/null 2>&1

	case "$?" in
			0)
				sed -e "/$user/d" < $ftpusers_file > $ftpusers_file.tmp
				mv -f $ftpusers_file.tmp $ftpusers_file
				;;
			1)
				;;
			*)
				;;
	esac

}

remove_product_users_groups()
{

#	delete users of this(unsuccessful) installation
	for i in $users_created; do
		delete_user "$i"
	done
#	delete users with group=psacln (ftpusers and webusers)
	for i in `perl -e '$gid=getgrnam("'$clients_group'"); exit if (($gid eq "") || ($gid == 0)); while(($n,$u,$g) = (getpwent)[0,2,3]) {print "$n\n" if (($gid == $g) && ($u >= 500))}'`
	do
		delete_user "$i"
		remove_ftpuser "$i"
	done
#	delete users psaadm, psaftp
#	delete_user "$admin_user"  >> "$product_log" 2>&1
#	delete_user "$anonftp_user"  >> "$product_log" 2>&1

#	delete groups of this(unsuccessful) installation
	for i in $groups_created; do
		delete_group "$i"
	done
#	delete groups psaadm, psaftp, psacln
	delete_group "$admin_group"  >> "$product_log" 2>&1
	delete_group "$anonftp_group"  >> "$product_log" 2>&1
	delete_group "$clients_group"  >> "$product_log" 2>&1

}


undo_install()
{
	p_echo
	p_echo

	get_pid $PRODUCT_ROOT_D/mysql/bin/safe_mysqld true root
	req_pid=$common_var
	if [ $req_pid -gt 1 ]; then
		p_echo "===>Removing installed ${product_bs} components ... "
		remove_modules

		# kill mysql
		$K_KILL $req_pid >> $product_log 2>&1
		sleep 2
		mysql_pid_file=$mysql_bddir/*.pid
		kill_pids $PRODUCT_ROOT_D/mysql/libexec/mysqld mysql
		sleep 2
		if [ -f "$mysql_pid_file" ]; then
			rm -f "$mysql_pid_file"
		fi
	fi

	$START_SH stop >> "$product_log" 2>&1
	sleep 2

	remove_super_server "ftp"
	remove_super_server "pop3"
	remove_super_server "pop-3"
	remove_super_server "imap4"
	remove_super_server "imap2"
	remove_super_server "imap"
	remove_super_server "smtp"
	remove_super_server "smtps"
	remove_super_server "poppassd"

	remove_product_users_groups

	if [ -f "/etc/ftpchroot" ]; then
	    sed -e "s/^@$clients_group//g" < /etc/ftpchroot > /etc/ftpchroot.tmp
	    mv -f /etc/ftpchroot.tmp /etc/ftpchroot  >> $product_log 2>&1
	fi

	if [ -f /etc/shells ]; then
	    case "$machine" in
		BSD|BSDI)
		    sed -e "s/[/]*sbin[/]*nologin//" < /etc/shells > /etc/shells.tmp
		;;
		linux|solaris)
		    sed -e "s/[/]*bin[/]*false//" < /etc/shells > /etc/shells.tmp
		;;
	    esac
	    mv -f /etc/shells.tmp /etc/shells  >> $product_log 2>&1
	fi

#	remove /tmp/.state for ASP
	remove_tmp_state

	restore_named
	restore_sendmail
#	rsr_backup $inetd_conf mv f
#	rsr_backup /etc/my.cnf mv f
#	rsr_backup /etc/named.boot mv f
	delete_startup_scripts
	delete_crontab

	rm -rf $fp_i_dir  >> $product_log 2>&1
	rsr_backup $fp_i_dir mv d
	cd /usr/local  >> $product_log 2>&1
	rm -Rf $PRODUCT_ROOT_D >> $product_log 2>&1
#	rm -Rf $product_etc
	p_echo "done"

}

smart_undo_install()
{
	[ "X$trigger_uninstall" = "X1" -o "X$do_patch" = "X1" -o "X$do_reconfigure" = "X1" ] && return
	[ "X$PLESK_INSTALLER_NOUNDO" != "X" ] && return
	# trigger_uninstall - trigger what smart_undo_install is already working now(recurrence)
	trigger_uninstall=1

	if [ "X$can_uninstall" = "X1" ]; then
		if [ "X$do_upgrade" = "X1" ]; then
			undo_upgrade
		else
			undo_install
		fi
	fi

	# put suggestions for user what to do
	call_optional_function failure_note
}
undo_upgrade()
{
	p_echo   "    The attempt to upgrade $prev_product_full"
	p_echo   "    from version $prev_version to $product_full $product_version has failed."

	if [ -f "$product_sav_tar" ]; then
	
		p_echo 

		p_echo "    Now restore contents of $product_bs from $product_sav_tar"
		p_echo 
		get_pid $PRODUCT_ROOT_D/mysql/bin/safe_mysqld true root
		req_pid=$common_var
		if [ $req_pid -gt 1 ]; then
			$K_KILL $req_pid >> $product_log 2>&1 
			sleep 2
			mysql_pid_file=$mysql_bddir/*.pid
			kill_pids $PRODUCT_ROOT_D/mysql/libexec/mysqld mysql
			sleep 2
			if [ -f "$mysql_pid_file" ]; then
				rm -f $mysql_pid_file
			fi
		fi

		$START_SH stop >> $product_log 2>&1
		sleep 2

		rm -Rf $PRODUCT_ROOT_D
		setup_super_server "smtp"
		setup_super_server "smtps"
		setup_super_server "ftp"
		setup_super_server "poppassd"
		

		cd /
        	tar xvf $product_sav_tar > /dev/null 2>&1
		case "$?" in
			0)
#				rm -f $product_sav_tar 		
			;;
			*)
				p_echo 
				p_echo 
				p_echo "ERROR: restoration of files from $product_sav_tar has failed."
				p_echo "       Please restore them manually."
				p_echo 
				p_echo "Exiting..."
				p_echo 
				exit 0
			;;
		esac
	fi
	
}

#vhosts

set_vhosts_params()
{
	SKEL_DIR="$HTTPD_VHOSTS_D/.skel"
#	SKEL_CERT_DIR="$SKEL_DIR/0/cert"
#	SKEL_CERT="$SKEL_CERT_DIR/httpd.pem"
	return 0
}

#webalizer

set_webalizer_params()
{
	WEBALIZER_ROOT_D="$PRODUCT_ROOT_D/webalizer"
}
set_horde_params()
{
	horde_datadir="/usr/local/psa/psa-horde"
	horde_confdir="/usr/local/psa/etc/psa-horde"
	horde_sysconfd="$horde_confdir/horde"
	horde_logdir="/usr/local/psa/var/log"
	horde_passwd_file="$product_etc/.webmail.shadow"
	horde_title="Horde Web Based mail client "

	imp_datadir="$horde_datadir/imp"
	imp_sysconfd="$horde_sysconfd/imp"

	turba_datadir="$horde_datadir/turba"
	turba_sysconfd="$horde_sysconfd/turba"

	kronolith_datadir="$horde_datadir/kronolith"
	kronolith_sysconfd="$horde_sysconfd/kronolith"

	ingo_datadir="$horde_datadir/ingo"
	ingo_sysconfd="$horde_sysconfd/ingo"

	mnemo_datadir="$horde_datadir/mnemo"
	mnemo_sysconfd="$horde_sysconfd/mnemo"
	
	passwd_datadir="$horde_datadir/passwd"
	passwd_sysconfd="$horde_sysconfd/passwd"
}

check_opsys()
{
        case "$machine" in
	    BSD)
		dist_os_major_ver=`echo "$conceived_os_version" | \
							sed -e 's/^\(.\).*/\1/'`
		real_os_major_ver=`echo "$os_version" | sed -e 's/^\(.\).*/\1/'`
		dist_os_minor_ver=`echo "$conceived_os_version" | \
					sed -e 's/^[0-9]*\.\([0-9]*\).*/\1/'`
		real_os_minor_ver=`echo "$os_version" | \
					sed -e 's/^[0-9]*\.\([0-9]*\).*/\1/'`
		st=${real_os_major_ver}_${real_os_minor_ver}_${dist_os_major_ver}_${dist_os_minor_ver}
		case $st in
			4_9_4_9|4_10_4_9|4_11_4_9)
				perl_req_ver="5.00503"
			;;
			4_11_4_11)
				perl_req_ver="5.008008"
			;;
			5_3_5_3|5_4_5_4|6_0_6_0|6_1_6_0|6_1_6_1)
				perl_req_ver="5.008008"
			;;
			*)
				p_echo "This installer does not support FreeBSD-$os_version."
				exit 1;
			;;
		esac

		if [ -x /usr/bin/perl ]; then
			perl_ver=`perl -e 'print $]'`
		else
			p_echo "Installation of this Plesk distribution\
			requires that Perl $perl_req_ver version be\
			installed on the server!"
			exit 1;
		fi
		if [ "$perl_req_ver" != "$perl_ver" ]; then
			p_echo "To continue installing, you should install\
			Perl $perl_req_ver (you have Perl $perl_ver\
			installed)"
			exit 1;
		fi
		return
	    ;;
	    BSDI)
	    ;;
	    linux)
	    ;;
	    solaris)
	    ;;
	esac
    p_echo "This installer does not support $machine platform."
    p_echo "Please obtain the appropriate installer for $machine system."
    exit 1
}

hf_files_processing()
{
local inten="set proper permission on hotfixed files"
echo_try $inten

while read line; do
	file=`echo $line |  awk 'NF < 5 || $5 !~ /^nocopy$/ {printf("%s ",$1)}'`
	perms=`echo $line | awk 'NF > 1 {printf("%s %s %s %s",$2,$3,$4,$1)}'`
	[ -z "$perms" ] || eval "set_ac $perms"
done
}

### Some initial parameters
	PATH=/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/sbin:/usr/local/bin
	export PATH

	PRODNAME="psa"
	PRODVERSION="8.0.1"

	build_number="80061018.20"

	read_conf
	product_log="/tmp/${PRODNAME}-hotfix${build_number}.log"
	product_problems_log="/tmp/${PRODNAME}-hotfix${build_number}.log"
	set_local_params
	check_opsys

	test_for_root

### My name define
	my_name_0="`pwd`"
	if [ $? -ne 0 ]; then
                echo "Unable to determine current working directory."
                echo "Please fix the problem and run installation again."
                exit 1
	fi

	my_name_1="`basename ""$0""`"
	my_name_2=`echo ""$0""|sed -e "s/^\.\///"`
	echo $my_name_2 | egrep '^/' >/dev/null 2>&1
	case "$?" in
                0)
                        my_name="$my_name_2"
                ;;
                1)
                        my_name="$my_name_0"/"$my_name_2"
                ;;
            *)
                        err
                ;;
	esac

	if [ -d "$PRODUCT_ROOT_D" ]; then
	    plesk_ver=`awk '{print $1}' $PRODUCT_ROOT_D/version`
	    plesk_rel=`awk '{print $4;}' $PRODUCT_ROOT_D/version`
	    plesk_release=`echo "$plesk_rel" | sed -e 's/\./0/'`
	    PRODRELEASE=`echo "$build_number" | sed -e 's/\./0/'`
	    case "$plesk_ver" in
		$PRODVERSION)
			perl -e "{exit ((\"0$plesk_release\" > \"0$PRODRELEASE\") ? 0 : 1);}"
			if [ 0$? -eq 0 ]; then
				p_echo
				p_echo "The Plesk version ($plesk_ver $plesk_rel) you have does not require this hotfix ($PRODVERSION $build_number)."
				p_echo "Thank you for choosing our products!"
				p_echo
				exit 0
			fi

			START_SH=$PRODUCT_RC_D/${PRODNAME}
			
			### unpack hotfix
			p_echo "Extracting hotfix files"
			cat "$my_name" | $uudecode | tar -x -m -C / -f -

			hf_files_processing < "${PRODUCT_ROOT_D}/tmp/hotfix-80061018.20/filelist"

            sed -e 's/^\(.*\)[ \t][0-9][0-9]*\.[0-9][0-9]*$/\1 '$build_number'/' < "$PRODUCT_ROOT_D/version" > "$PRODUCT_ROOT_D/version.tmp" \
			&& mv -f "$PRODUCT_ROOT_D/version.tmp" "$PRODUCT_ROOT_D/version"

			;;
		*)
			p_echo
			p_echo "You have Plesk version $plesk_ver. In order for this script to work properly,"
			p_echo "please ensure that the version of the Plesk that you're attempting to hotfix"
			p_echo "is $PRODVERSION"
			p_echo "Thank you for choosing our products!"
			p_echo
			exit 0
			;;
	    esac
	else
		p_echo "ERROR: PSA directory '${PRODUCT_ROOT_D}' not found! Install PSA first."
		exit 1
	fi    

	p_echo "Done."
	p_echo
exit 0

begin 644 plesk_patch.tar
M+@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P
M(#$P-3$U-#,S-S(V(#`Q,3(T-P`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,C8@,#$Q-S(S`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;```
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````P
M,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<R
M-B`P,3,P,34`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S80``````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P,#`P(#$P-3$U-#,S-S4T(#`Q,S8P,0`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+V%D;6EN````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````,#`P-S4U(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,C<@,#$T-C<Q`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O861M:6XO:'1D;V-S````````````````````````````````
M````````````````````````````````````````````````````````````
M```````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q
M-30S,S<R-R`P,38Q-34`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,`
M````````````````````````````````````````````````````````````
M`````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S(W(#`Q-S,P-``@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+V%D
M;6EN+VAT9&]C<R]S:VEN<R]A<75A+F-O;7!A8W0`````````````````````
M````````````````````````````````````````````````````,#`P-S4U
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,C8@,#(Q
M-C4W`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K:6YS+V%Q=6$N8V]M<&%C
M="]C<W,`````````````````````````````````````````````````````
M```````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P
M,"`Q,#4Q-30S,S<R-B`P,C(T-#<`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O
M<VMI;G,O87%U82YC;VUP86-T+V-S<R]I92YC<W,`````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`Q,38S(#$P-3$U-#,S-S(V(#`R,S8S-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````O*B`M+2TM+2TM
M+2TM(&)I9R!I8V]N(&)U='1O;G,@("TM+2TM+2TM+2`J+PT*+G1O;VQS07)E
M82`N8V]M;6]N0G5T=&]N('L-"B`@9&ES<&QA>3H@:6YL:6YE.PT*?0T*+F9O
M<FU!<F5A("YT;V]L<T%R96$@+F-O;6UO;D)U='1O;B!S<&%N+`T*+G1O;VQS
M07)E82`N8V]M;6]N0G5T=&]N('-P86X@>PT*("!D:7-P;&%Y.B!I;FQI;F4M
M8FQO8VL[#0I]#0HN<V-R965N0G5T=&]N<R![#0H@('=O<F0M<W!A8VEN9SH@
M,#L-"GT-"@T*+RH@+2TM+2TM+2TM+2!S;6%L;"!I8V]N(&)U='1O;G,@("TM
M+2TM+2TM+2`J+PT*+FQI<W1!<F5A("YB=71T;VYS("YC;VUM;VY"=71T;VX@
M8G5T=&]N+"![#0H@('1E>'0M:6YD96YT.B`R-7!X.PT*?0T*(V1A<VAB;V%R
M9"`N9$)O>"`N8G5T=&]N<R`N8V]M;6]N0G5T=&]N+`T*+F-O;G1R;VQ6:7-I
M8FEL:71Y5&]O;&)A<B`N;6ES8R`N8V]M;6]N0G5T=&]N+`T*+FQI<W1!<F5A
M("YB=71T;VYS("YC;VUM;VY"=71T;VXL#0HN<F5P;W)T5&]O;',@+F-O;6UO
M;D)U='1O;BP-"BYU<&QE=F5L("YC;VUM;VY"=71T;VX@>PT*("!B86-K9W)O
M=6YD+7!O<VET:6]N.B`P(#9P>#L-"GT-"BYU<&QE=F5L("YC;VUM;VY"=71T
M;VX@>PT*("!M87)G:6XM;&5F=#H@-7!X.PT*?0T*#0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]A9&UI;B]H
M=&1O8W,O<VMI;G,O<&QE<VLN<V5A````````````````````````````````
M`````````````````````````````````````````````#`P,#<U-2``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S(V(#`R,3$W,``@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]P;&5S:RYS96$O8W-S````
M````````````````````````````````````````````````````````````
M````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U
M,34T,S,W,C<@,#(Q-S8Q`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K:6YS
M+W!L97-K+G-E82]C<W,O:64N8W-S````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#8P,R`Q,#4Q-30S,S<R-R`P,C,Q-#8`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+RH@+2TM+2TM+2TM+2!B
M:6<@:6-O;B!B=71T;VYS("`M+2TM+2TM+2T@*B\-"BYT;V]L<T%R96$@+F-O
M;6UO;D)U='1O;B![#0H@(&1I<W!L87DZ(&EN;&EN93L-"GT-"BYF;W)M07)E
M82`N=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@<W!A;BP-"BYT;V]L<T%R96$@
M+F-O;6UO;D)U='1O;B!S<&%N('L-"B`@9&ES<&QA>3H@:6YL:6YE+6)L;V-K
M.PT*?0T*+G-C<F5E;D)U='1O;G,@>PT*("!W;W)D+7-P86-I;F<Z(#`[#0I]
M#0H-"B\J(&1E<VMT;W`@=&%B<R`J+PT*(V1A<VAB;V%R9"`C<V-R965N5&%B
M<R`C=&%B<R!A('L-"F1I<W!L87DZ(&EN;&EN92UB;&]C:SL-"GT-"B-D87-H
M8F]A<F0@(W-C<F5E;E1A8G,@(W1A8G,@=6P@>PT*<&%D9&EN9RUB;W1T;VTZ
M(#%P>#L-"GT-"@T*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]A<75A````````
M````````````````````````````````````````````````````````````
M````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P
M,#`@,3`U,34T,S,W,C<@,#(P,C,S`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S
M+W-K:6YS+V%Q=6$O8W-S````````````````````````````````````````
M```````````````````````````````````````P,#`W-34@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<R-R`P,C$P,C,`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O87%U82]C<W,O:64N8W-S````````
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,38U(#$P-3$U-#,S
M-S(W(#`R,C(Q-``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````O*B`M+2TM+2TM+2TM(&)I9R!I8V]N(&)U='1O;G,@("TM+2TM
M+2TM+2`J+PT*+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N('L-"B`@9&ES<&QA
M>3H@:6YL:6YE.PT*?0T*+F9O<FU!<F5A("YT;V]L<T%R96$@+F-O;6UO;D)U
M='1O;B!S<&%N+`T*+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N('-P86X@>PT*
M("!D:7-P;&%Y.B!I;FQI;F4M8FQO8VL[#0I]#0HN<V-R965N0G5T=&]N<R![
M#0H@('=O<F0M<W!A8VEN9SH@,#L-"GT-"@T*+RH@+2TM+2TM+2TM+2!S;6%L
M;"!I8V]N(&)U='1O;G,@("TM+2TM+2TM+2`J+PT*+FQI<W1!<F5A("YB=71T
M;VYS("YC;VUM;VY"=71T;VX@8G5T=&]N+"![#0H@('1E>'0M:6YD96YT.B`R
M-7!X.PT*?0T*(V1A<VAB;V%R9"`N9$)O>"`N8G5T=&]N<R`N8V]M;6]N0G5T
M=&]N+`T*+F-O;G1R;VQ6:7-I8FEL:71Y5&]O;&)A<B`N;6ES8R`N8V]M;6]N
M0G5T=&]N+`T*+FQI<W1!<F5A("YB=71T;VYS("YC;VUM;VY"=71T;VXL#0HN
M<F5P;W)T5&]O;',@+F-O;6UO;D)U='1O;BP-"BYU<&QE=F5L("YC;VUM;VY"
M=71T;VX@>PT*("!B86-K9W)O=6YD+7!O<VET:6]N.B`P(#9P>#L-"GT-"BYU
M<&QE=F5L("YC;VUM;VY"=71T;VX@>PT*("!M87)G:6XM;&5F=#H@-7!X.PT*
M?0T*#0H-"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O<&QE<VLN<VEL=F5R````
M````````````````````````````````````````````````````````````
M`````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P
M-3$U-#,S-S(W(#`R,3<R-0`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN
M<R]P;&5S:RYS:6QV97(O8W-S````````````````````````````````````
M````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,C<@,#(R-3$U`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M861M:6XO:'1D;V-S+W-K:6YS+W!L97-K+G-I;'9E<B]C<W,O:64N8W-S````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#4P-R`Q,#4Q-30S,S<R-R`P
M,C,W,#4`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+RH@+2TM+2TM+2TM+2!B:6<@:6-O;B!B=71T;VYS("`M+2TM+2TM+2T@
M*B\-"BYT;V]L<T%R96$@+F-O;6UO;D)U='1O;B![#0H@(&1I<W!L87DZ(&EN
M;&EN93L-"GT-"BYF;W)M07)E82`N=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@
M<W!A;BP-"BYT;V]L<T%R96$@+F-O;6UO;D)U='1O;B!S<&%N('L-"B`@9&ES
M<&QA>3H@:6YL:6YE+6)L;V-K.PT*?0T*+G-C<F5E;D)U='1O;G,@>PT*("!W
M;W)D+7-P86-I;F<Z(#`[#0I]#0H-"B\J(&1E<VMT;W`@=&%B<R`J+PT*(V1A
M<VAB;V%R9"`C<V-R965N5&%B<R`C=&%B<R!A('L-"F1I<W!L87DZ(&EN;&EN
M92UB;&]C:SL-"GT-"@T*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C
M<R]S:VEN<R]L;VYG:&]R;BYA97)O````````````````````````````````
M````````````````````````````````````````,#`P-S4U(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,C<@,#(R,#4W`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O861M:6XO:'1D;V-S+W-K:6YS+VQO;F=H;W)N+F%E<F\O8W-S````
M````````````````````````````````````````````````````````````
M```P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S
M,S<R-R`P,C(V-#<`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O;&]N
M9VAO<FXN865R;R]C<W,O:64N8W-S````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,S8T(#$P-3$U-#,S-S(W(#`R-#`T,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````O*B`M+2TM+2TM+2TM(&)I9R!I
M8V]N(&)U='1O;G,@("TM+2TM+2TM+2`J+PT*+G1O;VQS07)E82`N8V]M;6]N
M0G5T=&]N('L-"B`@9&ES<&QA>3H@:6YL:6YE.PT*?0T*+F9O<FU!<F5A("YT
M;V]L<T%R96$@+F-O;6UO;D)U='1O;B!S<&%N+`T*+G1O;VQS07)E82`N8V]M
M;6]N0G5T=&]N('-P86X@>PT*("!D:7-P;&%Y.B!I;FQI;F4M8FQO8VL[#0I]
M#0HN<V-R965N0G5T=&]N<R![#0H@('=O<F0M<W!A8VEN9SH@,#L-"GT-"@T*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K:6YS+W!L97-K+G9I;VQE=```
M````````````````````````````````````````````````````````````
M```````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q
M,#4Q-30S,S<R-R`P,C$W,C,`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI
M;G,O<&QE<VLN=FEO;&5T+V-S<P``````````````````````````````````
M`````````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S(W(#`R,C4Q,P`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+V%D;6EN+VAT9&]C<R]S:VEN<R]P;&5S:RYV:6]L970O8W-S+VEE+F-S<P``
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`U,#<@,3`U,34T,S,W,C<@
M,#(S-S`S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"\J("TM+2TM+2TM+2T@8FEG(&EC;VX@8G5T=&]N<R`@+2TM+2TM+2TM
M("HO#0HN=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@>PT*("!D:7-P;&%Y.B!I
M;FQI;F4[#0I]#0HN9F]R;4%R96$@+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N
M('-P86XL#0HN=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@<W!A;B![#0H@(&1I
M<W!L87DZ(&EN;&EN92UB;&]C:SL-"GT-"BYS8W)E96Y"=71T;VYS('L-"B`@
M=V]R9"US<&%C:6YG.B`P.PT*?0T*#0HO*B!D97-K=&]P('1A8G,@*B\-"B-D
M87-H8F]A<F0@(W-C<F5E;E1A8G,@(W1A8G,@82![#0ID:7-P;&%Y.B!I;FQI
M;F4M8FQO8VL[#0I]#0H-"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O
M8W,O<VMI;G,O;&]N9VAO<FXN8FQA8VL`````````````````````````````
M`````````````````````````````````````````#`P,#<U-2``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S(W(#`R,C(P-0`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]L;VYG:&]R;BYB;&%C:R]C<W,`
M````````````````````````````````````````````````````````````
M````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T
M,S,W,C<@,#(R-S<U`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K:6YS+VQO
M;F=H;W)N+F)L86-K+V-S<R]I92YC<W,`````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#,V-"`Q,#4Q-30S,S<R-R`P,C0Q-C8`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+RH@+2TM+2TM+2TM+2!B:6<@
M:6-O;B!B=71T;VYS("`M+2TM+2TM+2T@*B\-"BYT;V]L<T%R96$@+F-O;6UO
M;D)U='1O;B![#0H@(&1I<W!L87DZ(&EN;&EN93L-"GT-"BYF;W)M07)E82`N
M=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@<W!A;BP-"BYT;V]L<T%R96$@+F-O
M;6UO;D)U='1O;B!S<&%N('L-"B`@9&ES<&QA>3H@:6YL:6YE+6)L;V-K.PT*
M?0T*+G-C<F5E;D)U='1O;G,@>PT*("!W;W)D+7-P86-I;F<Z(#`[#0I]#0H-
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]W:6YX<"YB;'5E````
M````````````````````````````````````````````````````````````
M````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@
M,3`U,34T,S,W,C<@,#(Q,S<W`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K
M:6YS+W=I;GAP+F)L=64O8W-S````````````````````````````````````
M```````````````````````````````````P,#`W-34@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<R-R`P,C(Q-C<`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]A9&UI;B]H=&1O8W,O<VMI;G,O=VEN>'`N8FQU92]C<W,O:64N8W-S````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P-S$S(#$P-3$U-#,S-S(W
M(#`R,S,U-@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````O*B`M+2TM+2TM+2TM(&)I9R!I8V]N(&)U='1O;G,@("TM+2TM+2TM
M+2`J+PT*+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N('L-"B`@9&ES<&QA>3H@
M:6YL:6YE.PT*?0T*+F9O<FU!<F5A("YT;V]L<T%R96$@+F-O;6UO;D)U='1O
M;B!S<&%N+`T*+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N('-P86X@>PT*("!D
M:7-P;&%Y.B!I;FQI;F4M8FQO8VL[#0I]#0HN<V-R965N0G5T=&]N<R![#0H@
M('=O<F0M<W!A8VEN9SH@,#L-"GT-"@T*+RH@9&5S:W1O<"!T86)S("HO#0HC
M9&%S:&)O87)D("-S8W)E96Y486)S("-T86)S(&$@>PT*9&ES<&QA>3H@:6YL
M:6YE+6)L;V-K.PT*?0T*(V1A<VAB;V%R9"`C<V-R965N5&%B<R`C=&%B<R!L
M:2![#0IF;&]A=#H@;&5F=#L-"G9E<G1I8V%L+6%L:6=N.B!T;W`[#0I]#0HC
M9&%S:&)O87)D("-S8W)E96Y486)S("-T86)S('5L('L-"G!A9&1I;F<M8F]T
M=&]M.B`Q<'@[#0I]#0H`````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O861M:6XO:'1D
M;V-S+W-K:6YS+VQO;F=H;W)N+GEE;&QO=P``````````````````````````
M```````````````````````````````````````````P,#`W-34@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<R-R`P,C(T-#0`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O;&]N9VAO<FXN>65L;&]W+V-S
M<P``````````````````````````````````````````````````````````
M`````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U
M-#,S-S(W(#`R,S(S-``@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]L
M;VYG:&]R;BYY96QL;W<O8W-S+VEE+F-S<P``````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`S-C0@,3`U,34T,S,W,C<@,#(T-#(U`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"\J("TM+2TM+2TM+2T@8FEG
M(&EC;VX@8G5T=&]N<R`@+2TM+2TM+2TM("HO#0HN=&]O;'-!<F5A("YC;VUM
M;VY"=71T;VX@>PT*("!D:7-P;&%Y.B!I;FQI;F4[#0I]#0HN9F]R;4%R96$@
M+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N('-P86XL#0HN=&]O;'-!<F5A("YC
M;VUM;VY"=71T;VX@<W!A;B![#0H@(&1I<W!L87DZ(&EN;&EN92UB;&]C:SL-
M"GT-"BYS8W)E96Y"=71T;VYS('L-"B`@=V]R9"US<&%C:6YG.B`P.PT*?0T*
M#0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O=VEN>'`N;F5W+F-O
M;7!A8W0`````````````````````````````````````````````````````
M`````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P
M(#$P-3$U-#,S-S(W(#`R,C8V-@`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S
M:VEN<R]W:6YX<"YN97<N8V]M<&%C="]C<W,`````````````````````````
M````````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,C<@,#(S-#4V`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O861M:6XO:'1D;V-S+W-K:6YS+W=I;GAP+FYE=RYC;VUP86-T+V-S<R]I
M92YC<W,````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#<Q,R`Q,#4Q-30S,S<R
M-R`P,C0V-#4`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+RH@+2TM+2TM+2TM+2!B:6<@:6-O;B!B=71T;VYS("`M+2TM+2TM
M+2T@*B\-"BYT;V]L<T%R96$@+F-O;6UO;D)U='1O;B![#0H@(&1I<W!L87DZ
M(&EN;&EN93L-"GT-"BYF;W)M07)E82`N=&]O;'-!<F5A("YC;VUM;VY"=71T
M;VX@<W!A;BP-"BYT;V]L<T%R96$@+F-O;6UO;D)U='1O;B!S<&%N('L-"B`@
M9&ES<&QA>3H@:6YL:6YE+6)L;V-K.PT*?0T*+G-C<F5E;D)U='1O;G,@>PT*
M("!W;W)D+7-P86-I;F<Z(#`[#0I]#0H-"B\J(&1E<VMT;W`@=&%B<R`J+PT*
M(V1A<VAB;V%R9"`C<V-R965N5&%B<R`C=&%B<R!A('L-"F1I<W!L87DZ(&EN
M;&EN92UB;&]C:SL-"GT-"B-D87-H8F]A<F0@(W-C<F5E;E1A8G,@(W1A8G,@
M;&D@>PT*9FQO870Z(&QE9G0[#0IV97)T:6-A;"UA;&EG;CH@=&]P.PT*?0T*
M(V1A<VAB;V%R9"`C<V-R965N5&%B<R`C=&%B<R!U;"![#0IP861D:6YG+6)O
M='1O;3H@,7!X.PT*?0T*````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+V%D;6EN+VAT
M9&]C<R]S:VEN<R]P;&5S:S@N;F5W````````````````````````````````
M````````````````````````````````````````````,#`P-S4U(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,C<@,#(Q,S`R`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K:6YS+W!L97-K."YN97<O8W-S````
M````````````````````````````````````````````````````````````
M```````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q
M-30S,S<R-R`P,C(P-S(`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O
M<&QE<VLX+FYE=R]C<W,O:64N8W-S````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P-3`W(#$P-3$U-#,S-S(W(#`R,S(V,@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````O*B`M+2TM+2TM+2TM(&)I
M9R!I8V]N(&)U='1O;G,@("TM+2TM+2TM+2`J+PT*+G1O;VQS07)E82`N8V]M
M;6]N0G5T=&]N('L-"B`@9&ES<&QA>3H@:6YL:6YE.PT*?0T*+F9O<FU!<F5A
M("YT;V]L<T%R96$@+F-O;6UO;D)U='1O;B!S<&%N+`T*+G1O;VQS07)E82`N
M8V]M;6]N0G5T=&]N('-P86X@>PT*("!D:7-P;&%Y.B!I;FQI;F4M8FQO8VL[
M#0I]#0HN<V-R965N0G5T=&]N<R![#0H@('=O<F0M<W!A8VEN9SH@,#L-"GT-
M"@T*+RH@9&5S:W1O<"!T86)S("HO#0HC9&%S:&)O87)D("-S8W)E96Y486)S
M("-T86)S(&$@>PT*9&ES<&QA>3H@:6YL:6YE+6)L;V-K.PT*?0T*#0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K:6YS+W=I;GAP+FYE=P``
M````````````````````````````````````````````````````````````
M```````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P
M,"`Q,#4Q-30S,S<R-R`P,C$R-#$`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O
M<VMI;G,O=VEN>'`N;F5W+V-S<P``````````````````````````````````
M`````````````````````````````````````#`P,#<U-2``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S(W(#`R,C`S,0`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]W:6YX<"YN97<O8W-S+VEE+F-S<P``
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`W,3,@,3`U,34T,S,W
M,C<@,#(S,C(P`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"\J("TM+2TM+2TM+2T@8FEG(&EC;VX@8G5T=&]N<R`@+2TM+2TM
M+2TM("HO#0HN=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@>PT*("!D:7-P;&%Y
M.B!I;FQI;F4[#0I]#0HN9F]R;4%R96$@+G1O;VQS07)E82`N8V]M;6]N0G5T
M=&]N('-P86XL#0HN=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@<W!A;B![#0H@
M(&1I<W!L87DZ(&EN;&EN92UB;&]C:SL-"GT-"BYS8W)E96Y"=71T;VYS('L-
M"B`@=V]R9"US<&%C:6YG.B`P.PT*?0T*#0HO*B!D97-K=&]P('1A8G,@*B\-
M"B-D87-H8F]A<F0@(W-C<F5E;E1A8G,@(W1A8G,@82![#0ID:7-P;&%Y.B!I
M;FQI;F4M8FQO8VL[#0I]#0HC9&%S:&)O87)D("-S8W)E96Y486)S("-T86)S
M(&QI('L-"F9L;V%T.B!L969T.PT*=F5R=&EC86PM86QI9VXZ('1O<#L-"GT-
M"B-D87-H8F]A<F0@(W-C<F5E;E1A8G,@(W1A8G,@=6P@>PT*<&%D9&EN9RUB
M;W1T;VTZ(#%P>#L-"GT-"@``````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]A9&UI;B]H
M=&1O8W,O<VMI;G,O<&QE<VLN8FQU90``````````````````````````````
M`````````````````````````````````````````````#`P,#<U-2``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S(W(#`R,3,U,``@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]P;&5S:RYB;'5E+V-S<P``
M````````````````````````````````````````````````````````````
M````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U
M,34T,S,W,C<@,#(R,30P`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K:6YS
M+W!L97-K+F)L=64O8W-S+VEE+F-S<P``````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#8P,R`Q,#4Q-30S,S<R-R`P,C,S,C4`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+RH@+2TM+2TM+2TM+2!B
M:6<@:6-O;B!B=71T;VYS("`M+2TM+2TM+2T@*B\-"BYT;V]L<T%R96$@+F-O
M;6UO;D)U='1O;B![#0H@(&1I<W!L87DZ(&EN;&EN93L-"GT-"BYF;W)M07)E
M82`N=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@<W!A;BP-"BYT;V]L<T%R96$@
M+F-O;6UO;D)U='1O;B!S<&%N('L-"B`@9&ES<&QA>3H@:6YL:6YE+6)L;V-K
M.PT*?0T*+G-C<F5E;D)U='1O;G,@>PT*("!W;W)D+7-P86-I;F<Z(#`[#0I]
M#0H-"B\J(&1E<VMT;W`@=&%B<R`J+PT*(V1A<VAB;V%R9"`C<V-R965N5&%B
M<R`C=&%B<R!A('L-"F1I<W!L87DZ(&EN;&EN92UB;&]C:SL-"GT-"B-D87-H
M8F]A<F0@(W-C<F5E;E1A8G,@(W1A8G,@=6P@>PT*<&%D9&EN9RUB;W1T;VTZ
M(#%P>#L-"GT-"@T*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]W:6YX<"YO;&EV
M96=R965N````````````````````````````````````````````````````
M````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P
M,#`@,3`U,34T,S,W,C<@,#(R-C`W`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S
M+W-K:6YS+W=I;GAP+F]L:79E9W)E96XO8W-S````````````````````````
M```````````````````````````````````````P,#`W-34@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<R-R`P,C,S-S<`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O=VEN>'`N;VQI=F5G<F5E;B]C<W,O
M:64N8W-S````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P-C`U(#$P-3$U-#,S
M-S(W(#`R-#4V-@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````O*B`M+2TM+2TM+2TM(&)I9R!I8V]N(&)U='1O;G,@("TM+2TM
M+2TM+2`J+PT*+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N('L-"B`@9&ES<&QA
M>3H@:6YL:6YE.PT*?0T*+F9O<FU!<F5A("YT;V]L<T%R96$@+F-O;6UO;D)U
M='1O;B!S<&%N+`T*+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N('-P86X@>PT*
M("!D:7-P;&%Y.B!I;FQI;F4M8FQO8VL[#0I]#0HN<V-R965N0G5T=&]N<R![
M#0H@('=O<F0M<W!A8VEN9SH@,#L-"GT-"@T*+RH@9&5S:W1O<"!T86)S("HO
M#0HC9&%S:&)O87)D("-S8W)E96Y486)S("-T86)S(&$@>PT*9FQO870Z(&QE
M9G0[#0I]#0HC9&%S:&)O87)D("-S8W)E96Y486)S("-T86)S(&QI('L-"F9L
M;V%T.B!L969T.PT*=F5R=&EC86PM86QI9VXZ('1O<#L-"GT-"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O861M:6XO
M:'1D;V-S+W-K:6YS+W!L97-K+F-L87-S:6,N<VEL=F5R````````````````
M```````````````````````````````````````````````P,#`W-34@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<R-R`P,C,S-#4`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O<&QE<VLN8VQA<W-I8RYS
M:6QV97(O8W-S````````````````````````````````````````````````
M`````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P
M-3$U-#,S-S(W(#`R-#$S-0`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN
M<R]P;&5S:RYC;&%S<VEC+G-I;'9E<B]C<W,O:64N8W-S````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,C<@,#(U,S$Q`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M861M:6XO:'1D;V-S+W-K:6YS+W=I;GAP+G-I;'9E<@``````````````````
M```````````````````````````````````````````````````````P,#`W
M-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<R-R`P
M,C$W-30`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O=VEN>'`N<VEL
M=F5R+V-S<P``````````````````````````````````````````````````
M`````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M,#`P(#$P-3$U-#,S-S(W(#`R,C4T-``@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C
M<R]S:VEN<R]W:6YX<"YS:6QV97(O8W-S+VEE+F-S<P``````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`V,#4@,3`U,34T,S,W,C<@,#(S-S,S`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"\J("TM+2TM
M+2TM+2T@8FEG(&EC;VX@8G5T=&]N<R`@+2TM+2TM+2TM("HO#0HN=&]O;'-!
M<F5A("YC;VUM;VY"=71T;VX@>PT*("!D:7-P;&%Y.B!I;FQI;F4[#0I]#0HN
M9F]R;4%R96$@+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N('-P86XL#0HN=&]O
M;'-!<F5A("YC;VUM;VY"=71T;VX@<W!A;B![#0H@(&1I<W!L87DZ(&EN;&EN
M92UB;&]C:SL-"GT-"BYS8W)E96Y"=71T;VYS('L-"B`@=V]R9"US<&%C:6YG
M.B`P.PT*?0T*#0HO*B!D97-K=&]P('1A8G,@*B\-"B-D87-H8F]A<F0@(W-C
M<F5E;E1A8G,@(W1A8G,@82![#0IF;&]A=#H@;&5F=#L-"GT-"B-D87-H8F]A
M<F0@(W-C<F5E;E1A8G,@(W1A8G,@;&D@>PT*9FQO870Z(&QE9G0[#0IV97)T
M:6-A;"UA;&EG;CH@=&]P.PT*?0T*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O<&QE
M<VLN;F%T=7)E````````````````````````````````````````````````
M`````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,#`P(#$P-3$U-#,S-S(W(#`R,3<Q-P`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+V%D;6EN
M+VAT9&]C<R]S:VEN<R]P;&5S:RYN871U<F4O8W-S````````````````````
M````````````````````````````````````````````````,#`P-S4U(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,C<@,#(R-3`W
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K:6YS+W!L97-K+FYA='5R92]C
M<W,O:64N8W-S````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#,V-"`Q
M,#4Q-30S,S<R-R`P,C,W,#``(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+RH@+2TM+2TM+2TM+2!B:6<@:6-O;B!B=71T;VYS
M("`M+2TM+2TM+2T@*B\-"BYT;V]L<T%R96$@+F-O;6UO;D)U='1O;B![#0H@
M(&1I<W!L87DZ(&EN;&EN93L-"GT-"BYF;W)M07)E82`N=&]O;'-!<F5A("YC
M;VUM;VY"=71T;VX@<W!A;BP-"BYT;V]L<T%R96$@+F-O;6UO;D)U='1O;B!S
M<&%N('L-"B`@9&ES<&QA>3H@:6YL:6YE+6)L;V-K.PT*?0T*+G-C<F5E;D)U
M='1O;G,@>PT*("!W;W)D+7-P86-I;F<Z(#`[#0I]#0H-"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+V%D;6EN+VAT9&]C<R]F:6QE;6%N86=E<@``````````````````````````
M````````````````````````````````````````````````````````,#`P
M-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,C<@
M,#(P-#(W`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S+V9I;&5M86YA9V5R+V9I
M;&5M86YA9V5R+G!H<```````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`T
M-S8T-R`Q,#4Q-30S,S<R-R`P,C,U,3,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*("`@(&1I92@B5&AE(&9I;&4@
M9FEL96UA;F%G97(N<&AP(&ES('!A<G0@;V8@4&QE<VL@9&ES=')I8G5T:6]N
M+B!)="!C86YN;W0@8F4@<G5N(&]U='-I9&4@;V8@4&QE<VL@96YV:7)O;FUE
M;G0N7&XB*3L*("`@(%]?<&QE<VM?;&]A9&5R7W!R86=M85]?*"=")RD["C\^
M"GM0O9X^"?S]H2S"_+_(`)&_O>![^:<M2"MDT4:DN&[-'%[U<97O:2RE^;V;
MH7>>C>@*M57`F!\L7?/8\;\J23<WR!DZQ"OH%M=/*-N[$Z<A7S-+U3!$:)>N
MY>+4V4?`^'MISBHHZT)W@GX/,?Z2ACNWE+Y;*&SG<X^4GO7,V1OT39%SPOP8
MHW4AM-JA`'EV\(JZAZ<0J6(CX4\<3N9%7U>54R6P=TC28W!L*BAJ<SA!Q^ZX
M3R-(,F2'K/!$+\<I]A6H^GZLU7,U]:8B+K&M`001&5=9K#A^#&;,<&\UEF,`
MM@;I9IDT7_B0A.1*W^WX8+D.O*BF88S#^TIX.1T::%&S./6^116@?N.9TGEX
MB1F73JJG"WSW_X<`3@-CP2T1:"1U;)4:]74);P>[/_=T169#KUD<DI*WATVN
M`)KK3!R-)%&&]GFG,]?#=?V<H58-J74T05:V(L,20"I+3[MN5F75HNJX#0OI
M[\9Z35-G^)VUA=\)UB&4B&NF,MIB1([(98\PJB--XTE;I-(][HTMB#"HIQ3`
M(6UC"X_;U0"ZP98YM8X$Z-H8]<LY0,BD/:@_/,+&?)U3Z'*V4R1$QTX1*2M*
M',-C10F$($F:L-HCY,=%6E?N;"?91.(HX9G)G$/-5A'ZJ^M;[%F*2<1X0$L#
M9QG1H=CE9)LA7E<.S<JEUIME=P$;'XZ)Y"I*)55`>DV0'P[^_%,T;+TGS&)J
MPK:RNJH5[Y$S;+LV8B"KF[I2>$N"SZ0*O*<^`-O]FZX++N*HHA,JVZHG)G_P
MF^!4EQSQEI*-7]J.3)9,CC]'*D![T7@;EYU?=@Q=BZ*?(N+GTU\FHO&L&*/,
M[$\&K3,Q`A+E1I?,W-P!/1F5EXFF5,45D<@-`5#5W?8?HG#RPX9P2^YO^^]P
M7,4:'Y\8GP2L'PM[I2I.P&K+L$@`7%MU$3J[GBEYZWAXA'\%VC;B9_$3R)7!
MK`?A,*2<3G3M]+6V[U()Z6_/NF-4C-R%Y>@&%[E.Y1Z-FM>AMF<JE#^TH/.Q
M=?IQGT+!$ZH;3MDHE<[E/.F43=]2!LGIE=?>1G^JZM:\PU`\&@FW+="#,<<E
M$PSTEHGS!L(4JP()UX2$4.]:R'\#X`;D.M!:%N^'UWHMMA@&R96BL(<`^2E?
M\/#1@';?_)>%61OOFFDJR,2>%XV;Y%MH$((H%C0^DY#4CK5&C\/#<T&V,[J-
M6;7BH8GLT<P>6X=MI9;VIB&=\Y@ER(,43:4T^WAI=D$&;$3MB+)+V2Y!),I>
M?;S2P`5@=)N!50PSK&%#`;YFK%H._XW"]8O<UY&/B=RPCZ'L+4\*"Z&3M\(>
M[:SH_TK&&+;%NU36B1:Q%V)R-6D(),CG]#B;6((\[!]@"-5[QY*=$+I?J,?W
M4FT(-R<54[V;4I-0M8>!!;VZO8K,[QO?M/KM,B`,A3,8B1^P&?7DN5U*!%F@
M^J(6ZT'B,M?B.HW]GU-2Q9(0?F\C&.&>K7M*08UCVS-7IF(3$;R[()NR\FP4
M:!3$E0`MZI^Z94:'7"','M')F0%Y\UPRKL)9M?5,9L3;[/!D_A8.4B,8G1,;
MI/")Q!88[9FT1KP1O0KQ5U*;-ZW.B;\U5III150.O)Z6/4(":00%?-F:*<1E
M!TTBPAIE&[M7K]89^%+V]Y"\R)1"%5PM:.0`AYS`S[!YNO)+2%=`OX`MB=_A
MYY00X%MT0YTBR5H[5NI@%K?/R3&2"B+]2"-V_$C5Q">RY]F8JUP53,$J-]0*
M4Z19H]V5.PMLMXMZIR)LJ2:IWB+TRPM#UJR3HG4@K1FA$VLS77Z9R.,@M>4U
M7^`J%\E^T?_M976B/*;K:">Y%\C<4=O!\[KIE[VVOO;EW(-2_R-Z)SF.$C7`
M0DIAL8#<_=4ROBAF(:V&6E1E%"5*?L!=W:[2?X:_=AB\&`)[DO!O*-?'Y5DX
M=(ORJM9GM,JKV83`KC:N+RO9JD),3.4?$&G\1C"HOG]:&_.VHZW*DWLD&4FA
MH&!BPW7>\^4/9Z4X7O-C>\48CNA!IJ2+*\U065,@76GV^L?9KGFR_(<!;*?"
M)Z*[F/OB&KKL+_-_\,DWRK/NO!(2DJZG_Q=TQ?31F2?VP<4#S&O./$Z2.[-X
M7=;;]52W#Y-Z,T;=%,7+-Q!ZPD=">T54C$#F0T)D(#@*ULX.&-]XAGYHB)->
MS]E(VJ%4_<)8C):/H=<J/::V<>@'J4^YF$J9!(14)D5;0?RFJ?CN"\Q4Q6U#
M,868E4I1M)6?MVI03"+6YZ$+/;W3W^LA]+-J`>PPS@;PQ?6RAEM%/TC[)B;*
M[U2BBJ^[*:988UI,57_MUKZ!&]/VXD:9-V26<I_)Q87[H3#!PJK!2V8:_)I(
MM]9G9H73$/<@9ZR5;,9+:K#SY5TP9H6JP(J]VW++;XWE8W8L(D1BHS+_7@#W
M</BTIP7&'FKXZV7B4$T\QD>224$,%6;]%$GM['MS_=6-<2@5S0,IRMSDA-%5
M\9:RSJ=1Z[P<70LN9M<G,3>K/SF<)E/X;#MMJZ]'%V="'-^B=T<UH)5SW%HN
M$7%0"N[Q,`/83TS:$U9M&+K8#3R`O5V(J!5F>C5<XM@;?Z5'VRU]L@RY0S[^
M]'$>3)=7<5J>A[H1@Z\_[(AOW25%0#XX9>BHE?1=2B9385P]!:]!S.NP%7-C
MF?HQ2]Q<*^F`5H12^EX?+@$&=N;,!15[-"S*F!J+5&:EA0%CD;7#5ZH90WM[
M@U$GR?.$=N75`APA@51?!%VB]+5P_S6("9:/\_63%#<)^@471Q;'>T`H7?+,
M;MKSC*:=4`X(T@J$%W3)1L%7OJW,RFM3KR8TW#J&_-P8*V`!32)#4.Z&5,(D
MC`GG6.I$:+1B=Y@3:P0WIIE:PFC;O*9#A_9:K(,(</WX^0I_S-32;WE,R+C`
M9K#E`/KU\%Q2')'4[RIDF6.?H2S45\]5[:S>3EEGP,6YD=\??!\7A*JV&*80
M^ZV)J7U.-O:O/ZKR\5D-4[6\=5OVM&[\,_GA6"CM7]6C8_H1[UO9S_SQ*RH=
M+/1JGM*NOD`=!?U@7?84J`#5W9X?\7FFP\E<%%65<IH*-5SDO;@Q#Z9NBPC.
M<2U:#`S(.2X2(%7PO/IJ1?8&U4YZ_W+!&6+5GW*%=#Z2,G('<[(4MW9X*]SL
M'0D9'X>=2^FQ7U9#%-MJ5N5%QS3IQ3`O5BMP<9IA'<P[M/=-15I6.=,A(D37
M^-J2E1!M#38,6$AN%3'@XE"X#%EF/&>X2',I<C$!,=\9(O3H>K5,@T!K7I)8
M4U!'8`%'Y!3@%OX&]>])A0BRDWU^&A6-8NG).%@`/A9+07Z`$$-]K![*:RK&
M:QYI^9`HEZ$<H5YX)%%T_B+HB$WT)N,20>7K[5ECO!TRJ&2UP_YAJ`I`Y4S(
M:[C]9&HC7'`LHI>$U_8]^K_M$+PAG*HW9KVQF:XV9W4WO>!4V;LB$KWIR6-J
M02'$ZJ'C9#-+GZ':$+V*5Z>\ZO,#$G.-=OCJ:)8$`$I%J20;FE[_AQ%5,Y.R
M0\VA-LH?^:-_,2D'Z16&;KS!"_%[[>6(`CV#7*+]^7GX&E-G(AS,`>AW=1LH
M,U920(S16"=K<C2D!T'ZF?F-@L@@][SP3$Z<:N1@6F#-FE[/2*;/J:)Q_^W:
MH=81')K]-J&+GO_!"^WL&&)9O/K]LMU]9C6OK8MARTA&"U:5SP8.)SO`'2C_
M^4AVB7,9F4*TS,G+\YJV4*VD\JA4.A0'!A$!40`O#RE;99[\'WYN$9%3L\X:
MR'^R39J;]V4:I6BS];%9PZ`")\6;3V.U-6Y)MJ^]<69AMR^=B<GY"CI<J+Q_
M##/TYT?JXXKGN!AFD<'E_MK,XI6X(=^S7P*WP;3NE`=<2)7Z@$'K,^UKQUPE
M@@&KI<,S]K,:]-MY8/9=?X=F4"37FB(M\F+`I86=6AQR1``"?&0*3Y[AS1A0
M]5]FX$6N0\:D%5N1WLN`;VGB`0%WFBM^;;8#$U\KKMFJ[-:=G9G9W%J.!`"]
M1TXD.&,KT-@"?.GN%#/K6E#Y=9H30R5N/;*;Q+=NWL]<V\3L7'\:APKVUP&7
M@A9\KP_@XGOJ!VC<GU#`-C%DEVXAW&T_7PA/1>747A;E(+SLT&A(;E,/K!%(
MZ8,:*][X)4)DP/C&9I>AG<6@^+@4#*LHG-W9C`0UK'7R6E`HL3X1=716\UB(
M?".=^X1@N?Z83CE',[W^<3LV/_^QO^2"G+O0:E='\@8*'+/Q$=Q[&)C>K'UV
M5;>$=PA1'H9*"RL&@F;4\1]XC^V5+O='F2LRV^?/GXODT&@8?&E/8YI@53\/
M6/.G[OT0F5O@!:;1FK%C4DED</<[O*C:.WJ=T=TC5DN@VW;&:N/T6)`B#6]?
M54U(7"-X+YUJ^,!7'-0@9A-F[+(S$-&ZKRK1J4^K=@2OE`G;1R04J*L_4&O+
M(\X@"^"*5L417UNSE_1,DQBCW$!=[QUMK:;]*.`M5PSBTMFJ[L[=VK2F9:3.
MO$87J"2AJ9%A/I04T^DK8+[BV\;SR.C$NT>63Y:,4$?VP%M`Q:2;2F4;S3P%
M<,1?A^LDS+76XS!0YUHS+KPLILR%'O7GEKG0K=EH3Z+U0P,<I][LR#]8:4OJ
MJU8T<U=M?\@:)@1?2(`OZ)(8T#3F$]2:PC^]XNNX+G[+:JX6]NR`A.89,3"4
ML8H%T[9<<L,8&">3GC/"[0HAE"X6Q?DXSK5#TYQF$'*OEGP61[]@$K\8$60@
M427-I((ZN]YCCU"PA(X0=.#2JX^"/'NLA_''=9LUC)80)X6;5*GN<U>UO!'9
M$-O*>F"0KMO0-]\A_R'K@##W".FF/E@?30!=P27$4%I%G\7&Y]#R(4%=JKC3
M1EN+B$<]/[-['(R^PFM@J@=>BJ"4C>+:H[I2;.?KVI7/,!`MY7:1`EV[4/LZ
MQ2E$T/T;K`'#%)EX#^>=-7W=9/UJ-L=0MR76['P8--E:4S;<%`YC!E4@[G!`
M6QM$\K.9!#GQCE59E4Q%QE'3#S_EWU&MM$S_EIZ8%KJC[[[[ZO<3&&_G]AF"
M736U*WI9]VY")VFW,>Q%GNJ%Z*FH.4Q68TYO2&,-G%+"JTOY9WRM")I*+A-?
M&+PE2DF"M\2^Q%@>"W'4"9KN!>SORID=`89XF47<HU!.?H@`-XV,;&LPQ'JT
MI!<9GD#'LO#L<,PFR.5DBO,[V\39\LFIYDJ^RC78_I1^JBRDDTY/F>Q`AB.N
MM`HAM_#/JDN99`P>'CQ1T4(7A?9"H:ESKF!C2-\2J[7;8;OI($25,R;(2\T.
M4'230XHEETJK,]B#$R2BE+\K2I2ML%U;:SN!#35Q!O\\<1M-^C^_`93'I7A*
M&[(MG31E`9%_N)`973>5F"E`-A=-329#[ZZ9^=F0:\:##%LMA8K@6"#XGN]1
M-^Z)6A!.J/@J)Q]MH;07(89PIE5]OFZ:1J4P?I(P!,,[_L=2[$\-I3I_HO.R
MX943SQ9]D!^<7WIK;BAJUH')$=A%,#97]6BHHM@B$]!B?A,BSJ3&"/=SC.HE
MILP!S.%K8P441$(3HU74-\875A\NQ22=?]'2*`389:!":RYL/;])EW;0OTP*
M1K.,9;K2$&3K@:C+TC=K;X*B/.58GH[!K:2&"5$\^T9,RN)2AYO4HQ!LR>8*
M*YTX@K6@4()D##Q,TZ!^RO0WU-'`DY&*5*^AG6+`WN?J[-9_ZZMR1H?`WHTD
MI\&PCZGQ_F8D("=*SR+:^:1>L03:>H\R%)8A7%+0=2T0_S0.GA"I$T=4WZ%H
MGJO)YL#8!-:2'MV,CQ,*+%$W3"2WNSQY!5IX^=UXX?&(5JE2X[A"1715>#.D
M[RIYQ"J0;4G5"C;;K&R$[Y9/ZI!D-BU]^<%WM.04%W(B<C$88,L<L&86-1"Z
MX@B5G\FB"?8RWR>.F6"7Y*4JG/!]]7VV/W:":)+Q1G;G)"F7B]_((U`+_,=.
M9$DO5\\.$S:*(+"`%4=`)#PMN@9CTYUX4U#"*D3-&,$AQCH-4\9&-+8MB&E4
M1<WV!?#'D^@%^.:N*[6:E!1I](?F=A1S[0"*HE[;W(XSBRPW,KH.%^8;%Z?9
M^D(!-31)'>44/>Y0X[AXT6ST+IF:P46E!0!3]IWSZ^]C;PV4(9]&F[T9-Q#>
M20,;QHMT01J.L@-(HL`:]L@5?^'%]%2_E[8H^V%UY++(@GPZ`/"/*[/0[C.Z
MY:5Y_7M)8!<2[=&OL\)F^)D3Z7\XR_`_5"_PI/`,U7-+>A6`/$IXG&S0[4];
MPWG"5UT%D_P[TIBYESV.(K6%RG&YB?:N\S^6>_Y4;Z^BZ0E,"4>4<@\9?BDG
M/GJDNL*)WUS7@UF-(-2,OG!G+2*9\+464S%G;73\.FU\N>)P!AXBF6G>M6'T
M+"^W_%5"$(E/?Q&]`I>U4KP*C$WA:ZAEHDHM-@^:C9TBW38Y9JB8)4T<%"4Z
MH)YWV1^/K65]7H00\<XPI,WX(OD=MSX]5DAU05QWU-.N.RG!MY&%KXRI2'9\
M7?K<`8*2FYRO:,:BNC3/[=<F\/ZFAZ1)ZAV)Z&AZXT=(&?\MWF;XC8@LY)E4
M^6;&IR!-R^"&_&?S0^*%C]<[#N95@3W73@CEJ\I6->=O>_GHMTM@AB6H58)$
MC,93_Y61?V,JIIH*-JX&I"X/`J51KYTF<[&-S*0D4?X;A3A%48YE]Q8?23!M
M2+%H9-8KDGW"6Y,!#`LB7)-W:KO7=-H_-"8T0Z]VA@'AL<&ZE\MQ(BMM*,:_
M-$>L)M>(A>B4IP0A)N?1](J/P8?'1H'X;2DUO9K4_(V7]8(2.&"_<6ZB`&D$
MV+ID@T:IA83/E9V^B428?I,M>XVIU9M/B9:82]^$+@(%S0%)-P%Y#$]3PN)'
M,Y#,2%!H.)"RG2$S(0)M-W:U'FH^&3#H<H$/(PK!.MX:CZKT*B15ZLTYY&T3
M(#/WE=/PU7#LV8T+B_+^I(#__KPA&8%!1JTB,,@@YI=`[>UK#."ESL^6I`WL
MZK!P;"-7L6G3H04ZM`JAIYUUUTQ-\9T?KWR?S/K9K*[+\,LE+4['Q(L9X$4D
MUZT>7$%@HXDZ#05N[EU57`'FXHX,^+U8./=A:V"^YY$$YGT[Y"H7\T^:\N[_
M/Z=W`X,\G<B.D!#NJE#!+(`-A$V%;$FGCEWUJE*0X1<_^*':'.V&@3"M-T92
M,]%\Y9HU)*4'Q&<6H[>DI'U_T\MQ@,KZS]DJ!M>IJL_-:6](.%]BC'S2PLZ8
MBDAO/J!WBAC0HC,#1;K*>KQ5V[^N0OTW]A#*3\@<G\[(`5-_3]73_%*)(^Q8
M&(%KQS7`'D864O;B9$.'?*Z'C"_`Y+'HU99=J@IG1IR(`A/17)\<V9O<[YV.
MPK@*KT81S*LN7BJBR,$)SV`[ROK@Y5[-T/AO2J1GGA&WG%7.N$(>R/;F;*U^
M8"K?I'Y2+AS$SQ,[K0M`@S,ZUJ7_TR\OXZF1L<V%R<*IG8KTR/88*1M':AFM
M0296BH58[_<=T!D^X]50M#D`BZ`Y9T-R3>C+3765O-8WW$4[04\G#+S]3+WK
M+WGT5+XDV1!'RV+WS9/";TJ="%FMO][.F5K(@*_^)S9MWP?JX$3*;_ND*6AN
M1TQ144AMW/]O?@56\?4^CO'W:*C50]=P<A"5%O-!;I#08>-R+?^)X^X:],NM
M`L`;Q[51U@_J?_Z@.Q#7RO/G_"1UH0WO-/:?_%ID4#_\5]P#Y_?SP7W2T1@3
MDWE:I7V_C0BE$G4>D#@0@YD0TJ!JS:W=R177EUQHW$^AG-.6PPAQ=`B1"T+C
M>#!CPBQ3,@VW&3J@:0C4#GTAJ1CR;HX%_[>&8110BFE49?C:%2];-A5N9:R%
MI@3*@HE%AX'BW6.CEC?VFSA1GE;*-]930(^7C3.L@1XFAQ%D>;F4+A9*K#"P
MF(E1B+I`5]G:%H%:)3%#V=;?393>06-,7)*NB`-A<_^OQ6B.CX29_P&ERQ-?
M:)3GPA/-J2]Q05O,QF?*Y%/6SY#X`G2)P"$PWP;+RW;.UVUA)!E=U$>^2EG%
M6SYQ;7V?6_`X@BQ(7%:T]4<%W.^<<-'J+,T4>#!7(5_B0=*0M+=V#?O1J79B
MY)>.RJZ6!V6`WC8Q>28TW^D#LECN':=S1*!/,%']RU#6;)\&YX8R&Y,RE")W
M2?:O>O,'6W_I6W=Y,VT7[>2]<-E@KFT.`JQE3M.O2/QS$A8U)/19>.;.LU'!
M+DV1R9;OE+(.%E[%"7R!V)R"%3T%8[,11.NC!^=0NFIY-YU[?@5?)NS/YM_I
MM'*B<%$',%'A9JF$GJN]-[A8*,T!FL-&^UM>Y.Y#>D`IY&V=`35O7F'?/+2=
MZ;%DWMGXYN%35\R4T2)2[;GS;7#,`&4%<T8#AJG#6G;`LVY96R(?M_2[2&F!
M]XRF)3GS:;37A^O+QR.*230,?!X[!UYB`'DL.W'2N*T7AIA@EM;VI7V<OPK?
M?&#N]<W.(IE?CM19*&/RF8B?`"6!.A;O_Z?5"P`46M.I@0F%YR))$70(E?;)
M#V9;*A;J6RAX:[]Q/XAK9S$W2J.-\-P9'J/9E[Y?H#EGW57]%&KBV1T;TK9?
MPA;T:M<B@<Q;*V)T*8OKL$R=8S8W:!X:".VB[E;`E.I`(F41'=/K6;*-0Q0,
M%JRO!3&35=*4(&W7:Q62S!!]-\&Y#DG/P1BT;(7UP"4A)M/!\Y>$YX)%P<?B
M&G?-EL-UELA_#OT8\<3][Z9UDN>[_I`DTY)4'R4?!!]/T00!27A,IO#),H?_
MG#)5K*?!!E1->JLE5-(S]8.QG_;(2KG07V&25'<K,(3TO<IRN&'@5H7CI4HE
M3T\61&'Q;+\L$(6H.OGGGU+QO*0F=%H719="=Z%*]S<Q646<.ON3K-6,>%JW
M_2%Q7,<;!\%,;(FQ#&9/+,4`:GQ9:94S02!9()RO.9.4[G2I(1X=#D:1@4SJ
MQ/J/4-L@L8(WXMT6\PH9?_P-#;W;=JF6$U1AH?2V\@&*8FD:1C%YD;#I'!SB
MIR9KL>T?'[D<^PVS=L5M+W0JJA)X;0;,+AE?\[C6/(;16K;HWVW4HV#.CD/6
MGA1DTVH*Y"_=)';)_-DDG@JW;*T08`!9?)W_NC%<:!3>X5J1\Q>17F#\'T>+
M%H*E"!@Y;X'>8=01P=C<+"\\IKL/_*[8J,DAWBT"[S\+B$DHRDR/0'Y>TWO.
MNW7H+M7$A/XP62*MD5_>G]"U1)'@QI!^DC)FL!&'.Q!G^\]5'#7@,R`.I3V6
M$FV_EK<(@B7:H%NJ#5P[THD<2)FT?4606[:*?^!_K%P'_7$='U]BY_^07VWA
M2,,6V)<G_X#Q0&M1Z8>KX:<S!/!1&=_#,.>E<'7MALC3B1EN16NJ#2@25,=)
M7PN_VN_J`4J!SFA4,C"U"\4R=C^:YV(*/+A8-O<O<=("QG!\G;H195VZCAHX
M3E.<<@O>7[PD(Q;A]5Z^Z$:TCF)D\(F,4C'U$%=#7$9,MFKHF`8J-U?!)2GY
M)?!:\#")KU:4:^OL^&\^AJ##F1;$J3M'<#YL,<^!^RS97^@4!80W=MHF+T0I
MOB#_?B9JC3QR\).SY8%>UR,^H->U4W1<-O+AA!#K$G8@#9PW!2^I,JMB+H\V
MS"0Q_<$:J38_7]@&&X3,2IZ).\U'*8Z#CWN\7CANR`>-_K2>@%:;8$G2^PB&
M?JE>(J+"#"E5M%\4B:-!ZDHZX\ZO&OWDT`=K04U_#V9C3`8D8LC+`:@'[:;E
MD'GE@HUE*-=4TER?MNW7-_O/XR8B%J%IDU]+M;F)%DU21E\WX11Q`P(=Q.Q;
M%(Z4("]2Y*W6`O;K=F_+7+BL)R.I/RGSM\]8^I^H';).,LZK-^K#,FIQ[K.=
M7&$_1J)J/]>CP^[7G8?AUS!_EFL%U-)\*@&V/>\\T!D1G(_D`J)`CZR=KJH8
M_ZW;A&>$,'P5I.Z4`TD2SZX.M9::E+)%HP`!YETVB1X&",GV;P*G!0!XN*OZ
M?G#":L&/[C0TD<MLTN2^7-B5C1Y0!F\"-2_<5._Z"^`*<IQS5-?9U=1U(I=J
MY3F6R]&-2DBJ#H<U87Z&__[OR[WP---,^"G7_C!B9[>(TLM.8>[G$?-/<D[Y
M-M-E3<]:+\V*WD^].RK6V:>Q/SP&$-.AVO!JV[\-3B@L7<S@SRV_E_%5W<4P
M+XO-$Y`1-DM6Z]9V*^S%4^]63F?P4_V4[3XZ)C^(>8PA[*J/'V0M$3G>ES@%
MN?/[FPK9>ZBC:"45%._TM9MN2`ZB)4-N[T;W`[#(FXV@KL^'9:7G5ZB$5N)6
MQ%G:9603F;_?M!ULJI,L,H?%4Y\NO1:)KXB9:]/3+WVT7A-+N<(L(T@![\RI
M`7BU::%)"@U2`@#X5?4MM%":[O76^?%1I0A;<YGWTSQU5^]T]+)6[PV(?'3<
M72?B,>!]-ESI#DT24N:A_Y=$?FCK'9JP!643#`&QQ,S:2+=!*(4DP[[LX:W>
M=JWMNPRF,RMX0K^$;C2<A;O-ESHKU8*S%YN%W*TVZV<)0FHSN"?^VGRT>N5I
M\CII5HY2,S:2D\ZIK7YK!6E$&<5?N:-')+5-A:/GL,!99#*1!I7>1<]@)A6(
M>"!ZPS;3(+`"&#^QPT[%Z."._LQJ[\J;<R_YQQ@1\+Y@^ULE>.FM,Z3N^**R
M_M<S&\19VHP)6:94)H<%_>'G/OPVL3<J0B&O72M-#-^^B9P<,)Y4%9"FH*\0
M)_A?&V2S>'7#KP04.#7-@]428TZJ5<'@;=5#O+CK+.BLY0%LIJF2@I<HW#:X
M,>GN-:-GFCJFGSD#BV-VA<!(PH"9KA4_V764P<F>DH$-8*O6C*YM:2>+#%9>
M;2[E9>-N=/*_:R=Z0J9][A[+^VAB/,CZMH^Q;,,#H;)PC02V<*H/P>PTA!+/
M87$^BH@@O9EM0=G#V>FF4V^"'F8CEK]+@K8L.+Q#-6;(_2@1]$1+.T#<B=1\
M"@0PJ=JFT&42[L@'P75%-<%4+)LGV[FCO+Z36$:[_DQC.@`6I1A(Z`<JEB7E
M=T.H055P=&UOT!2:4SRO;Z)S)'2H*JZ?]N3L]*4LZ&V0P?W_;MD6]V_87&B)
M_0X5,V?)4O\&>9F21)^2X(#Z!F'!W84(ILZWQTMY<L\'9Z)%P5*2-IJWBV]+
MG:LS]#!]%8NU!O%Y7\G#1:-R-NG0M4!$EN'<="#P#WH7\0]K$-UMY"'\KVV;
M=*A$(6Q`?H3T<V_3^+D5(\^"4.*XS.E(S8-TV:TJ99;9D59Q`_9('Y<?K>V[
ME]02;WK@%U7,6(7W09:O@J0!'NI1Y&4K=H)<5G.+6)'_LB\S\+2%_J(V2PKE
M5_OTD840FJG@1(WZ!#5K`?V;V(0X!*KQ>R8.(,7-0_60!?R47S&M'0S#"7-W
M(EDY4VJJ[IX4?U?PP6T^DF!+55L4/F:_5D.*SMEHQJ/P7G)1OSNN0NV1$\,[
MMM]%^BK9>.%MZD_;1I@8S4%+2M%LIVTK5L"AL,AS/<_K?!1(^&)<=PB9@9J=
MAFXW?UNLI1W^VOM%U2'6[>N9IFTX2/NA*X7;>).BI<7U6YJ9*WZ6$P-BIU+"
M/$)OR^Z@!Z#NX!>N3]ZO#AJZ!H'BXNX<G*(QQHJ5.2`AV[:;(O.MM0P@(%S5
MXF0W$[^EH:P[*[EI)2[-4!2J0V:9.LB>"YA%="$JJA+LM/`]C^`-)BG\)N71
MAQPP+B@KK$V-=Q:2%]9M8CI.TF;QQU:A%6S7@`H9\X&C4^<RI$`J2\LU]\];
M(_/&I31X(K8_QURA#KODU@Q;I:I^6_FMY7D9KL$9==MOBJR2H+@K]V%;#=65
MZN>V=_CNJ/;X6[HT3FJ8<\8`1<9QCL"-K?0SX?7K4&P>E![L-[K^IL\\\]^!
M]P6<[:8%A?G;27,Y!K5@HZ&#?@TH=;\+@]!<.>/>!2/]>(;PG]G4,/<#8R>S
M_C8YVB0-_DZ"Y3AK:+D.BJ07(UM1KB*%,8_Z2Q&]>,F:;&`N7#'9[.U-SP@8
M7;/RTE^%F;5(@H"C8.(L39POD%XL,VCCJ9.[I!R;O^6O`%NJ,/X<#[O!`)QP
MP$B<>@F-@W),VD\<TO@+U`)3'UG<$,\M,J\,`7]V1*QNA.\**$*]FQ>R@S#)
M=!VW+;'^9#8/Y;^J"4D=E@U7PLRB*7=G^H7MXS/F]"K\`L=/X[YM[6ZLXW+^
M5-74.V=)/*4MJ_(DV$8:1-$2I"Z&F4!.B"%H/0G)=M@;-A0?9]D%6S'-:7J>
M5/1=\5H7R5G`1>7Z/&G/JN-URJN8)A$'N+XMQR2Q:(;>WB)_I1.!^)%<,+9<
M-,@U5=AF4QT_.=VC:[\)9%,$`65+Y<B"Y^]^M<["PTH`0"'Q,5ABVB[0M+?`
M%#Q]\E?Z_[^EUJ=7Z1V!MMI")EX[VY&_[4+O<'Z%<JK$-^N9Q988=YSE)`J[
M28-"ZU+.X_568_]K%3<\]KU3;ER$IZE_"$PIT1SVXZQ[O27LY$E`O34_$9X2
MX'T?XD0A%%AL,\N+57?W?HBC(68-5<*RIF9W:\1*Z/C:8M5MUILM79P"*YH3
M*[TXTV$/73P\3;'O8,V@QA;W'GG&IR*\EXO..(.B;9"PVN_Y,WO`>S)$_":$
MV@M*X#[#%.>9EQN0\PP\2?XT]G$^<LV^;&2Q0LQY0IW>ZGV/UJG&B8.UE-;%
MKO$(]*F?,:LML"*'8-'T90>__QP1\*(3K7YLR^]IIV/=.WM11M=[^0]TV]R)
M]6\&/!5["`""OC1^5GF)8NN32T7XKH91&`"M$0<U^06D5%DW@Q%`CW728#\2
M40:+(@JN5D#-@2#&/)+.XZ808;A/%&X?VYE@E&[TL9L!S3'\D%?<CI@@'=V?
M>ROD@?4-KI-K-&T[2AVQ+FN)101)D`3=]NVU4=[[_?U-C^8=XV-M.(_0(X%F
MKTF$CZ\3LU/`.#;T]YW3/9]01M0Z9#`V2E+HCPS-4AK_'!MY7"_Y;P7KZWQ.
M(%W!*P&ARR%@079R7[@>@#%&HJ+*M>#8^M1NWJC(R^HIPP3IIY,*.:1`ZV5>
M#:6_MPI%$=^PZLYY**B`H<1%[@%[YB,]5F+@3XQ!2^Z]MXORF_E>O&B[^DY=
M.!C3M8?CNDS<Y.<TR%V,G)CHNEP4\W#IR>@0Y,IP$1R8\!/`*9<&NV4\'GEV
M&?712NV?'.F)[3W<MIAUW@?GFWI>6JK!9#7ZKK^J"<S>\F7Q/D/=TDU@^M]$
MJ3H368E/LOTK%VB]*AZF(Y/9O".H`GW59!F7&'-5,JT@&29J&P7;\*PK6RP7
MV_?1'Q8)J4BUYHXY;FNY;:.IOP02`[%C(/0MP4W1;^D/&?O7U'-4Q.W0"H(?
MAQGBCB8Q=Y^RT?76/MI))HJ&7/WXJ4#X8LU_)'LN1$[B@(0JX3S6><#`0T&H
M4*ROA13TIH"M:BM1@W>09@I!N,_R]SDIP,\NOGA:YC6W[.#&/NP"_\Z;U5D2
MCHU\=@:H$8P-OL125+1>.%E"?L)H_#_8?Q0@VA/BS"JMO62TOQ7#(]P7@H<:
M!NM<#>9^XS.Y5P&FNA7>#T;I#CE`T)U.YGFQ;23:=R[/Q7]SZ7R`N3)(]OH.
M*R#^5)#Y897)'P[E"QU%S62!(N1V=B(L9Y,M"^<*;0\\FW,DW-3L/W-<CUE,
M!SK8M;]9:Z0/P:$AC,ELM>.W:KV9W>W+!H0U`85-,.5.^G?78XOV-PLG%XS`
M*LEVI<HL_DUR`$G'[#^6`WZL)_V]M-;R!B#E[.27`-?<OX`&T8QC;)]UV6WB
M^OT4[CSLKMY8T%?)*`UV&$BMB?&N?HP?TVM0");K_KO^)#9M)?=V5$QZ5"U;
M4\^]B9LC_P@45RU0A&4KH=UI$\E-,Y<^AA;U_TP8_9$"&M5ZU;21%\E85B3^
M(PB8[!<[V!2\*/RQ5\/A%:NK+L\0#Z:'36]E[1],O:?]]:`T7<8]]4&X0.%S
M+\9`<UMRV>9+(#4=E@P^I@'^6('7+N8`(':`$PBV*'3,2)#,D6*D!S4W+!'D
M.ES%&7/;8^RB9Y)C0KD^[?/PSEQNZUND&XT,?Z0X=EA[C*?(6^CK;5?M*;\9
ME.VSUY\Z9&\F1G=_&8$785.QN*JP&G,\)'>7W26-IJY'$'L5=:!T48V=BT?T
MI=::(IMZAR/-&=_HX%W6/#]P:'`@96-H;R<\/R<[/SX<`(0,_!=&(VT7<[(-
M[W3(P[<XPYU5%URZLRW3)J%+20$43FU)3!_._NL(1BSC7H+37=MRBP<[*;^)
M/681>`4W6<%M]Q$,UE/M<FW"\0YI8\[1Y98X<A4<E@4PLU%M;/Z"R1B='PY%
M'RF$>+(1=<=Y)UN28:SU=-I;-0@^8@L*'D))HJ5UO*!EMN(PQL%J3_;9?MZ;
M)GDX>+<-OS*[M[RL7^F+$1HO,SLHK`>./Z:/0=9=UZY.'I.%<T?<BC8WBL;@
M,D85OOJ(R]MG'*!1]*7&F20'PUWJF34F:C:XJ=K1_1;[2,L</(E^G12+XZHR
M:QV=<W:,71)CZY-%P],3+TW@MA+:]F_WFBJ9?>FW>%-E`"Q_\Y'Z0WDEOL0X
M=7==(;_[PI>.BXAP\+B!AMQJMP]QB$A%4JB]=1&^>(_E=D+GCMH`VZ45X`&V
M`:*IAQW@P7>V0PO7C9H^VMS*>JPB*."3<`E7-0+3`0M3*<0I!5&`=BHRGR+E
M.Y5*&^.TVN9&W+,X;Y2)?/!";[LT(,2S[?5%AF9IE_?KQ:Q`,=`XU09WU,IH
MTJ[D`90`?$"W?7OI-G+)G`^8"T`7DZLO37QS=?[?\PW6YL"B\],]8`/5Y&[Z
MP$\>VRHR"@P;.UXLG'9LQCSVPME?D2(NI>O/^:@(%P!R/AMP>L6OP^BBL5(^
MZ3VBB;,[:%.>W?`:U<8F!@5LE^YSBEY^L_*O'`L,VC5.?Q5*"\GGO]]>"-W!
M1>ZLF,IO?J$-=-`\*?<<^/Z'"`EMI+.(QZ0>8&<4/(ZZ-_SJ57)/R$R*H:G7
MD]I5<+8)AZP-`9O?NT$%VMJP@OUT0(M=)5E\Z0(2^$$8<@>!K,14B=Q^O:Z=
M\T]JUPQMY<0BI.)B;@P'2D15EA0KN*J<.*G-J*H-XIWL"LF!!I&3[D$#*S#O
M$*`LC63A>G=A_`;VGSI`(+(S6]N]2^/#\#EA8RLP^B`F'TUM7.C""T1QG9Y4
M1BI@3T(@KRA%^(VP@-*%(0L-0B`FCF+PQ(C$)+U,=7<%^FB3J5V'GIJ280OG
MRC4$M'WP$])`AHO29_E7N<\K-ME=6O*$&#*&9=W&HPEA*18TCO_P==*RU136
M(AIY&&T(E>#:&9T7+]D*)J<1*_RF=/S$M71@"-4D56O/P!T821![-9D/Y*@^
MYV*4[J6`(TO#K_:HJ8UJ3QN3D*WR]2UR!2&OVSP;:2"E1EFV%)0TZAC;_-^+
M4ICDAC4?U5$411-=E`FC/[.R5ZBR`J!EK?U+O]1^%+->S+CMB6`.V'DO]9+!
M7*ROGF`!;WK4/XK%;:^*QOM-(/2BBA:`4+"^V<).233F?\_D&3/4#/AS%)6/
M=%=X:+U6R`OUE:-H03_A#_K<PO!X48L_-1]5[I(-VQ/I'=/1L_BD0`?%0%\\
MDJF.R5-%0=/_ETP$4;9X#F?(^\X-=3CVV&;R\20964O!)[5:"HQ#[DY\A;_3
M==;0%0\ML['2+KB>Y$C;>T]+$>`EN,X-R*TX2FLMY_*J_,#[HX'29HMUEQ@`
M7FA7I<@R5!,3/W=:./I9;]0UZIB00-*#YR/._D/KBMR8R'<H31C9O^^Z;$V)
MP"RZ`CAW1*8ZS%.Z<$%0?R],DEXO^]8",?Y)(*,#H!VS4QF[@MVG&M:)<?.I
MNH:#4P0;#QK82+8W)G4[=X]*=]'B&Q5C\.IE934C@PR3,@%R>GZ3/L&C<K6#
M36VQMDLM.0X_KJPE);JUJ'-S=G\_YO/.)N.[%*3[T)6_COV,:SN&R@;=_!8Y
M?XZTK6LW<MI0$&-+]U+2<A-&[PE>/MU,#6TS,>G^)+"P%_!IB57J(1<T"W9;
M=JD'O^R>OK&<\FZ8F^`!!NP_V?QUV/;W/,`KR+C;QZF8JF_]1]X1O]?A8&`[
M,4IAHO_A&\%+:D+U#>JSJ?<(^7F=NJDIGYJAOO!N/L`N.4=6LT5M=Q9?EB=Y
MT?38&1_:*`O0HPH-AB*#3<DQ?&'9`(\COA@"RJY<*:LK?P1S=RN-`VW&XEU[
M#3/M(9JTO$,0M)1B)ND6\3`^8B,78IAB])9%GRH,_FX+V(4*)^GR;1+*^SM?
M7?$Z6\:[/W`,E?/EBGY^>Q%CR='EXSGN=95]4=RH+E7V]J[Y_;U3.$"P3>`G
M;`,.#K],+D=^V8@EZ$`!2'V=4^2$&&U=2@QX#'=S8ZS_K4PRP!Z^&Z0X50-;
M+0D1]^=IE7BP)G,7C&49HEMT:[.,T..^[X9'(:YL]6Y\:QNY0J..(1;Y`JUF
M+X4Z#ZH+O5N+B@J"B@17F]8:3$[QMX5XP+Z3^\Y95KV)H&SH^@C)/I0II)"0
MM*2ERJ#1TFYR,-[1SAGF#*O^N[A(!$!.`[ANCQ8-G3I0!1.BUD2ZR9>\O?;F
M)`[@^8G<&O.$3%^RL(,APXC'M*)84@9PCC&=7#7U$E`B1_'DAFX$TW)6+D/'
MQ@<S\[)])1>!%5R2%!P\OTPZ`T=<D^E)&5L!CSC4ZT=/7[G()]"-8VKPC^C_
M%61_AWL=X8Y1ZD'P@I*,_,9=?)_?\NZ##8,%P;F6Z0=OLK'BB$8&09U>J]#Q
M_4HCKTI,E-B^/VTS'J>%HE)V8GV5C-@40Y\<TT=315MLTJ?FQ\.&K&J>B,DB
M'-Y^6YJ1W0-3JM%@/B[M%#OKT+".\MR[$-(KC^M_^9[QZP]_G3%1]MGX2^;Q
MUBF!(\JA!75PO)JX\TQ!AR4<72!'JJR73CQBS]011Y-WJ5.WCQ3"W,)+W]DT
M-21@#>@#_2;I=;3G3,5F!=S7!Z$#,Q`]AO(T8M&,6L>QKX*)8/"=J8/L/R7-
M+Y?6+*?-ZR3L+4+)GYE^A,?,:$YE-/J^Q,+CD*=(7?$;N:@"X7("?+PA]FV+
M<+=,)X4!4?&88AL\68@X5/:0(+60(^]6])!O2`?7R%.3%O)(/21^:/OH-Q6K
M25:3UV]]C/H-J#$)N$7,-^D;<$@OP5`(<QVV+)N1$VIH6!0/&7LX4J0#A["M
M@^<MB9\GOC4Y]X?S#%T'4,^]NE9TKE&4^+5+G2D*K,9C+0[&W.BR>_BCW055
M*V*<B4G[RH``1S:S?(!0"+(,?+^V,8+"'3#LZ_[P;F2D7U\W5,R$4#:8ZWX@
M?A"E)/U2RE6+*)(Z*7>O35F0.LD71"Z4"ZSD,WAJIL349A]3R&,U/ZXPAU-'
MD.,V<E2W5:E#MX4.]GFSY3=[,W,G@YSZXKU"[LM.>Z+F>!T:2^PUEY/F(MDV
M*II2J^(1J9/@A!F2S-M_.=,<##&-DE'JC!I*;]*^E;=775AAD:]'K\IKO@.N
M&@J,<.^W_EJ]4:0#,S]VAW7TQF.#.E69J!95YN0TU`":-(EJG9B*7YM[]S!F
MI];%_;Z(D,Y\95&J@#8K`]#"A;JH<`(M^!3[V7?32/N(=A61$736K#W3S"4X
M`,ZM\B?I^8#1W"L0LU]51GY73-KJ4M[!W0EPV&-8(]T!FFSSP,!\#7\URZ"5
M%+>$B(+``!+%!]ND]F`LQI>+SP&?2FP^A=RJ[X44&G3#<4I9?*HVB$G8^XLD
M<F&Z=MGB-X(YU4!P7$CG`417AMF`S;5FF<\L"S4Q?'^3D*E\Q]5UDW)*T8=B
M&9"+-;%7ZEGWUOEUX.5IEAQC=EUXI:&P/F?-^J-=#<-8,AALA]$R:7!5C_-/
MT6_/`@2#H`Y?_<`8]$V#Y;H1KE;-^G28W<""%'\'.02W64;$G':[OI1_B&4O
M45P9;W[YF<P)_8N2<@HAT;YL:W>]/BQNTR.[>].U`O_-&*4*TW>3Y^#'M9P&
M7S_LE/(AC`WD&(\@72C&B`+VZCHPB*NG:CM;4.$A2GNLU$W1(#L.>!7`XUC6
M/92[V2%8[_^;-^1IL!]=K&JM-28F)OXJ=O^L9^UNB`K\#JEDMY0)+6.0!2+'
M6SI+L[I(Y>A2.+LML"<`68)CSP+'EDB[IU9?2>_:P7@G"5GR=\6%U(G70H@3
M%HP%DAHSE,?T+/2[\3)3YSESU56CH.M_OI-M?<O-(4$$E1%11%7.=LA-SI"0
M3`*<5=";GA[1%F5VD;.6.79`9OS\!%DPP4PSN6D2!&Z-3!$ZP:!A?+N6O,^B
MY\T^,!][#MKCO32D[3+]?11<+1_0?Q7Q@7MW1"N<A[/\LZ?NXF]SI[B4I/E1
MF[=PM\C.:BFP41W*&!1*WA!`"=R+XY5#+B=R*TOV*7:9`\:^25EOB8:=$JD8
M%[L/3SC*?3:_/;)K]_LXI3/-(3F=>ADTM1B@W^5,9=IFFKK-05[7,_&JZ11S
MWM^\\(KEZIVCEYTX.OH406D>.#I><)B;L)900ZFFJQ9ZTT/G*]IR`Z;U%?@[
MAY8:R#M*_%^>RDJN=-6WU]&7&.(LL\<ND[0U",0]HW-DY>:3]*'L5WY@<RV"
MCV<^N"IFI*+=?L92@'-O=Q.";8EP>3K)37(.EXYHL81021K8K97XB)V4:/>N
M;\SQO<-:DUV](PGMR9,5Q=$Z/.IV,U!'B%N?-O"RW*9B67W61%9PL,,]>="O
MG#7!50,H6.;5262J)@I4#/K%<<$U.1UF3AFS13@(^BW=6EBT%ED3^59C:6."
M8]Q;$(:70LJ[ZGKSSP?PR.CYN'5OT]OS[^?H_SO:XA_*P7XT4.=Y,(58#M8X
MH2/=9/W_GL]:/5GL3GP-J$_T^S!G5].^2)N'("=1_A2E.!DZFSUF$NDFU0^)
MWB&@F)33JN#?#VP2SO\3_2H&,"P=.S/;O*ZT6@Q^T5^T1&SY/7T$IJ>5:\@W
M.$0=]X\VGG#.777L]-HV0TX8`P$H730X0#R</D7I.%3OQO!:(-S<:?%;V?!I
MW.0DC4W:&4O3/:=6M!I>Z4D^U\4VFC$0QE.V&NIWT6X]Q&?NX?E3I?OZ2%\O
MUL&E@2(C,E\`Z$H#^D"$=[T)80C7_$6BYTGG^Q6=]6,*TM(1QB^>2%FK=O['
MQJ7_5[=]/=,Y;KO12Y06'Y=3R_C0FOBX7<TG-F!EH.%;5:0R-IC6=^+PV3?W
MV2)4CTD,$OC0VAQE\;!1Z=Y%C2SC+!YE20YYF@=-MFQ;!(>72SCGP-'AYG52
M)QJ8Z])0[[C-Z[FJ3YU^:RC9=1%VJ2B9OL@7UC,19\BH!6BY+!%@?A:96'7*
MU4A0\QG3)9TG_Q]AYM)"OK=I_LSB[=;_8#[Q`?Z+HQO\W08)"VBLY\EEFU:*
M/8SL"^R9//RJPGE3)Z>Z<HH%7?9:1=F50QKJP,GOM=8"_IXT%+A:+.UTNZ_0
MPG_CI6SSVD<.2ZWU.\^8Y&_8A2YAZ8.V>&)ZZV`*$2@+^XT&!UXPFN?\UG2S
M@0V*HR#_OP=E'!]77J26]ZOC"KAPV<39=%S]+,]ZV29VQ5FMZN;H1Y+K5F.2
M.YONJRH9<BCZC[>C'@<X1`<;%7;?;;F5\68'L[Y<1?5(8&^T*+DAOXNV&9YY
MG&BAF]K;:`!^C6[=OA.1;<O#,V]"1-%\,HA\QEKFI#=>DB>[JS4H!":_)8\R
M:U(KD,U/5?BI*E$2FW$14WIK<-4?-B,`]!`.QUTC:[C'5ZB3(N+T8"QIM-B4
MM*L1\$7;B$J+`EPOX"X<#P=PZ<-#[TOR"<!G0TEJ]X]F*RU)=$ZK[YC!/R:[
M#/3]R1#J;&?<.]_*.]D;P,"9W747$Y.T>/<$U-I*CR$T1W61$K1!U][)[YK5
M,\;#HNN/2ST.*?XBAS:V31TJ%TWM@XT@ZBA:X(,%?-5^Z)(^-^3%GK5UTE[0
M&=1RE@JU%[4^]MN-V7V-%YWQWY'4&5P./+C7@!,1?[*14>Z,:4XNCC+M`US2
M/WQDAJRI#E9.<4AHPB%;+4-D9NM\Y07AKXL($?[4>/4+BL6^]#6^X+./`46S
M#N#>WO*921`=5S43&3^*Z=XH_%E_O:\`31;ME\C6L*:K0Y>NBVWL@;&$G`UN
M\UWRQARN2!V[JKA]C'KS\SX46HBO\FPJI!Q):=P)`&%C0$VK-IQT?*^'J'Q`
MC'(=%?LD(!Y-?XL>MUNNS18T>-*B_M%(>_0)1CBKD]:70D/^;%S`\%]'PFRT
MO*S4+!0_K.?4MB4WFV@M/SXW*8:E;M#M]B44GS??B(KM/?SJJ`18KK2R8(CR
M](5P@:=:+?>S&^KK2TVF^ON<V9GM\!)HJF>J#!R$@SB'`VR]4WI\H%44>LDQ
M?=J<:YWSE=,"SK`C*?=X2APD&9QLCU/-<OS%SE87_02C**?_4'R&_^5"(H%X
M6T)`+N2TLL>`ITBDV6R!5%<?940D:TND;[+%OGJACX?://FXJM=@6#TOX&]:
MS'ZJ0D1_H%_\`M9`=O7>]`VZN/I"`I03[R>E98R./E#Q):&P%>T3ML\_:_7Z
M^54L6R8'[Q1_?!ISZ6HMOO6H+PIQ[^Y([P6[J8L>]:.E-BSIYZ/@=_E`MKN8
MZGG">T:_+O!E(7+'4L2?GJ)WU$U5F?(#.;@F+!*P=A9&HY8`M^<>5H!E.STC
M2*C?<=,L<]'Q6G:T1?58[8N.Q;?UCFHW?(:C%$U6/:W$FIW;&'"[XEG\:XIV
MQ-;]R9E;T7Y87]VND3]X27^G*8#SUY1]02,D`W70QZA@\I!L`5#3$7Z[Y4K?
MP+"V`>!@BHEPYBK;H"L2T)$[PVX-QR=B<$=E]!,(&'TI6A:?F;=1-,9*Z5Y1
MZ^H:CBL:[UWDH$W#-WO67E?>DRS$JP`*=3'3'ZJ5^]V?HM_.5QF@C6'_1W6*
M3+]Z8:S-@K%H4]R2HV+,2]?HB7YOH!,.!'ENSW+I59\[]I5;C3],)"[A`Q"P
M*(V_6:,?G;^^K_4E]>.OS6<>;E$UOLZ$MYJ$G8Y&<>DL`FZNIR9(FG7Y)S\R
ME^N@@1XTOH8(MS!:=T&B0N/`CI2&,ZC"XMOR>YTXB-TF^AZ;-[K6_1U)R%0T
M\WMT-ZS74BP"+C=P?B5^=O.<=I.MCLBX^@<R694ZXIK'<-W)A38T"]XI,2^'
MBT``O:7=.*BQ!/[<$KNO_\)^X_*+\''UWI87_?$Y>=&'8^N>A6HE.#*MI!@0
M^%F+FD6(@QX*FK[<?J]@A9V=9T*D'KG[IAZR7\[O(B<7@'J';Y\Q#)Z/1+Y*
M0%EG($OKNDSNQ?J;23W'\&C03RT8'9E,B#R]2:V-LPI&3=Y%-C<)LS$XM[17
M$AQ&$)AW5#@F5U_RK]O#<0]PL<5%>['/>"Y4B$T.L]D'E90$L6]W^(\Q[UCC
M%I8[882_;6ZPV98[7S.E+'`>'\6Q+_?QL:_FOHS@TN/2*=5\WF0?KU',TM@)
M<4='6S&I,1RC7:7&Y%-=BR^+ZC+K5P783$D"8"JCW;805[<R_&K<>:B]6=?V
M8G6D``ZK;.Q?_(X"L`[DE"/+^69&S>,LD&D0'-12XZX;)-#4)D2@<:KJ]H76
M8A.QQPGUV.FRQTI8TQ_AHU,;7TR9EX#W\,Y7%UVK3L/>GO3`[P49Q\KL4)MP
MN3"C%C@>IK)83R+74`K+O*1B^"&/=BLIL1?]74M7)+68^T9M#CJS+O(Z""PG
MXXFN&+%%\I87&#\T<5A^T(ROP-51HTKB3KR;^#77WL8EG/V9YHX<S#(S7-)`
M\9'DPNW,/(-;&FZ&A+N5AT&S=TGOM>W/J"YGB9A`1B(?#<8];49:7<EC^8XL
M,/`?DT.@]Y:SR$%G4Q^9$K(^67L'.*AZ$NI!<7(\Z,=N7NCK8\.T2=:C52-Z
M0&\MN?88.LI]^2[X.*4UU/"UT0:C7YP[>'O9X5)`Q5C")`M@W@,-[!<WB'G$
M::'$&DY(IX1O#B0;`%GA-)Y0I?G[>Q8J;\I,B0%/?;;T'RPE"*<ABF`ODK?E
M;70KW46^?\;-J'%P%S%-9X4P9TT\^P!^F+*+DL5]AZ@I)D)JW<AQ`.`@U#<.
M7WK7$13YB.>"R`'OH-ZE&]^)50K#W&P04X3V6>S?_Q,W#-1XYB%H=_Z_Y7_)
M-\T).XVP;V$.E[NF?`Z"VFP;NZ?`P%_\G5D1@RX[A&0SK;N:\64_%O(GG:/L
MP(%':DE<!;H"81BX98S(G"#2,)-=AHQP<XK06C1A&WM*1A+L=1>`T)*`&TLA
MS<R>BE(G53Z030C]*YM&2=@%%*QU$W00"#(0`JNGUC7TTZ31J_F6W9QF`A-%
M-XV\ZWXC?8-X4<4$'A;;&#*@5>$%VQK1E75.PT4`XXW(N*ATD%W]QD"R*=G+
M]!5(ZIA=?83#)]]"R^>/[^3J#WYM5;87KGI&EX*DN"A\YQ4TZ^8UWZJU$<UA
MW]1XB5B?I5Q(,P7IKWQH:B/S&$ZA>##`!Y4=H6G)#=,BG\_^VQ$\Q"!PO@;$
MR*"[9_GYTI5A?O%&/:RV3RWSDJB5\'*QANDN?%JR&N0U.I(WLQ\,2`1>%(QJ
MVN2*\5S(AQLODRXD5=SF/!J$H[5O\L`H84GR[736*V*<(GDF0DE,WLQNBQ)U
M^#$N(YH3C'2.ZJ/(*V_S.+3$535N\Z]E`CRRC;)@7-`Z?QZS[Y[!$AD4H5S2
M5&0@VZH<)<&2J[G*;MW\)B?,3S20[ST^QW.KOU-+24W]G$-W!LN8@:C*$#_[
MZZ5]E[5K^JM^V[*F:Q"Z-[\G[?(&^<@;$G/8-?.38=$1QKGQL4>Q]18W80"@
MZ295UMQ?6;VPJC&E_@*Z)!U(YQ:E0<M%@JWX"=#6+,M'/<<+C3&<LLDC]J:O
M2(/K[L#5=I8YPW`.-.?((907_APN7TO+(P[+-N-=@`*W10\N51/4Q0360*$N
M=>CFN2-#T$`M4!T@'HN`$B&D7H4PS6!&'5%Y;B="[99W\\,'ABV:GWYS<4.;
MK6(B0[OW3GFJL4%1#;;D'_?OAQ:F5>LO,@N!@].,;Q17M[-)XX55$.44Z`QE
M_2]%H-;S*'-$'H<@Q`FRX48=F-TR=RO3V;XC^&+LJQUNK\(T?7:)";L14B_L
M_&:5=6[(%LW'AW[?:#5=52?979X'SQDHOF"]$*S<!N.#;CRC-7552T&$6E9U
MCCO0U1T)B=V0PE9FO94-0&G8/!RZA+/_ROC/-Z0,KT;:R6!L+90U!D.R:0IZ
MZY2=A\?N"YE7K["O>C1,Y2ZE%@O0#,/;^O$WAE'JA1:+;@4"&I;P@+_IVE@`
MJ!/$@3<RFNDMS21/CB0_L%(%DL_1@[IH4HJVC5+:K?A9^PWY#`^+:[E89$ZD
M@([%PC$YDX.,Q3*0]EYUL63973+.HM28`,(<+BUVF":-_31L-=\=X\OKH08%
M"'NE%7=:.Q#`:(;47\'EG/@UJT7:U3[^96HC.WM31M7%TU0745HV=`<_:/2@
MYA3M\BQC`G%^.[50]/1F+@YKNH,94@#[_WT]1?7FC__:U[NV')H0`J-J`3>=
M&03>E];JV'B^)+KK_."\=OUSIB<$\U-X+H:JH#-)&.`4![[L@_5EH&4\PBPB
MX%FIY#VFOW/:`3MM81T(XL<R(W!Z6P#Z%/5M.Z2G0:H']N7D2+SX-E1(_MX>
MD<E1MA10V(IP`.@WDK)=OT$[>FT.V=^#7_'D_,N/L0=3WV$;$X">@AU+"!X,
MPL5]A3#QZ56U&J^K&J4/L@,>P(C!]=^DX;%D)+42&YPA&E#JID_X!)OL:4`&
M8@6LSC7%]:"//P(8BNH-C.GX"6<QH#K\.BLF0;`A88]QZ8K_"^!`21`MD7\D
MZNG&D$`%3D>*=,R?,!<&JEJ#E1?.R#&AY3+57ILC`C0;`(F`D@LXB@0STQCB
M]P4'WQ3_H1`VB(0%G!./T%7)IT`>8Z\UA&TY;EG(5+<F0.MKI9E+B#`V^,:<
M7358^%3V7OK-:<==AZ4P*(.&+OQ#_D]1.Y<4P13Q1-3$]'=?:0K5#..-<^^6
MD7+=8'UW,^>6(`U'$,%;Z;>VXH&10H"+#M:[Z^UN$<3#LI<=K'W!=+!PK96#
MJHUUT'3Y!KD5U'*,+ZFYS#87Y"D$+6-`@[_[+O'2@>P*DJT9U_GNDBWT@>9E
MPZM2ZV\!B'4=[D;RDIREI,^Y5<1P?$GUJ5*KD+[6.MEL/X-8@?I[_NSX[9.[
M77[>S*!B)2.0=<+)9VP<ZN5HAP$P0__>I(06Q]YG7([1*72QR=]+B-]TC2X,
M>@9+58FVPQ7)9"2FRIRR^4\J^!FLJ%)*[%L+6K"&]QL&@'I`FFR0>"T(06)L
MXNU,.1*)E+.'NO$_L'U;K2\;Q@$4<\RL^/D/N#5@>/7\T0L=[?=/GAN]!7,9
M?A^E)\9>>O/4O5YKK_//#ZH%NCM[4>;["687;?1&:(P[SZ&JG>&G1P,JV[O=
MXH'XH*Z@@_RXH2P%381X]2HG!FA7\QI1'H"V]_U%.T,O@KG2P0YYC=)=I"K(
M-<6F<OAU^5NR]&8/6>",T#0_R0X'P9_#+RJL?Q^#ZSVX!TVQ;+;&^SG#,+Q_
MR:!3!-!J>#X#Q,01VN9M6"_F>S7\?2C,(==K`#PJ_.PD0YB15ODH=J!453Y8
MW[$[K19G&AM76"BU"FSO.V6T[Y!$&ISP*OX'3.`X:?"0I39=."=LT74=?.NL
M@JR80YY@+2V0&%SZL<K6W]6S_/C%A@1)`%0!F\72XU,3P-)H^;=(>T^LP0S&
M?4Y$WBHJMT'],232]_W+PCZMQ.-M:N=*MC8>M/TBIWN>$DL/CVK%M;8]7MO4
M[&&AF:NXEP?5G]FNNHJKQT0@*=I,>,Q,"`<7\KBPM(N_HRV<_T0=#D#[G/0+
M%7N'9@Y9+^1LBXO0G:AA\08W#EN<.I(>V0D,JCO#!M"4#^&'&)&A8EFVQ-5F
ML?L782!"_[2^7EP!N#+(>YRKOI$B7HE3]`%7-5\?8`N0_^:P5)"*;TH<N'SD
M(Q093!52RT@A7?P(XFU^[4II,K]3[TSPY#2ZD8>5#&)4I\-`;C*_@2I76!=L
M99;!-^C$$9Y</_6DK@T[I4+U[2:ZI?0S.EH"2)ISC_[&.6-2UH,":W#M).@L
MC"HG-02I'?6^]PN35[3R<IK=@T"`<IL:@V)UG\K-.HNU=Q/75F&2A(CPB;,*
M+!E%2ZJ(1203MJ"R1,13*J9Q);I"\.\6YW9CZ!X=@%$,%G]'!DSO$@9N'(5O
M2'/0^#E%U^0>T9NX7K^=8[$R7%]D\LN9&3W#B38,P`;IQ`YQ4UO5[,6=;>1X
M:'"2`V@67NZ\>M?4.KT?I6P)_NXY^YG-+C.,+YSXA\SU"VZ6(]EM&)X'<Y-[
M5IS[TR*!6KXW/+CU:HE\?C8B>'HZ149LS3,'NWJ<Y3UT%E2ZL]^V*]:M8<G/
M4/7#TM^$@T)OCQ]4V>FQ;I%T*VZ;=KMP\-@FABA=DA`"(>+KQ@]]RE,KO0*_
MI8G6E7#N5CURVP4V0"?@@@'(WTH)B?BPD3_(K;)M!M6VMC.BW0ZL"%:5Z?/:
M,./5GUSQ$@:>)\.R^K)D,R%KZ*/-7JL:H_>M+(<S0!R$W"_9C%`"_7CB&1A=
M1CV@>")Y`&VJRI9*!XZ\0NJ!DN?_OAFA:']"]M4Z%1>Z&>Q^D9T_+Y2XUP44
MEDE9;2HEG,AYGY%83XJ+13H)_J+&ERF2ASLI\!2<K#(#V2##_]+7[,2([8_V
M<8I1'^)_N2?2'>?/S%*9Q%\/R\@F1VHA2`^+O-"=\:K-6-"F_UP!UF*C'?V$
M`Q[R0-61!#)AQD"_G40""$QJ>!S(NF*[QDT7?><^0YOIRAZL>5\QD"<F5+WU
M3P8KP79YXM40S\69Y?<DCIJ?3I^)@A.*4.(4&*W#/Z,!B*(@M]H8FV2Y#)E>
M08DMLM7O<*5MNDQ>0[:TDF[E,<)=K54K2@DD/4J.G8;L6HD?G3B0:*U&0SOQ
MP0UB4=`2\LVQ_NLX=C-%?*(,D93N99YQ*6@L`CM!4194^CV]&II#9O8I3-CQ
M1MX;]H(C@2-3VG-%H6.W81U<DC33Z^D\:AH$BJ6F$TE89S-"CI?QZ$KJ+F^%
MJBN-M'%8DR;PT(2I(SL*7M;095'KWPQLX3Z^C^MVY$=E?LC@SZV<[7[!-;\,
M`9=&XGSW]5?][^O-I/L'@ILC[1?Q92^3PG!]1H7D="#JK)V0/P`>\7.T(+]<
M,4.^0B;=YTOD+&)Z%0IM0!"49SDJDL^@J=&/5;'*JZ%9;X*<'%(G3@,R&\+Y
M=+3!BV>4WI`_2XD=73#=VUA)X'_%G#F]!!K\MQ_&+`,WL!_WI52:JC9\JSUU
M74K^M6IVCQ^IC.T=(5KY1*IN'_B56487D=:5_L`L<Q)0XVQ>6_U)PHGOP\6Z
M."NF/BF*^[I8@X,6/Y/1$!D+<2]CK_N,DY?XE;0+SNMM/RM-U8C\-P9<L(%^
MENH3A&(UM;GG_AID1BOU+M.H4D0U`'R)'63L)4;L,7#MCYKRU.065!^#U.<]
M-;O$8%LT&9SZR2<$$@[SFJ'^/1WH-`G%"F)_-S2TE5&KY\WLZSY:2PFKE@D>
MQV<40U>>K-!AC0%P?O^>\A_K:@@:ZW6.WSS/(L#V[W6B-_(V@)L>*:-]PI$R
M#&K<;',-9K=(Z';-`R?"WD\X3OYXLE0,5V`MXW_W6_(UZ(5"G>=N_`+$CF[;
MJJ%*@5,O\=(?']>;:%^-25TB8"_H1ZH/:[]`$(,__DG8]([:H],,)O0F;$.=
MO?0;@,[U@O12'&(A#I.OVV3^.OFE4-,GX$L(</N0(R7'?OD9^WQC*9B<WA?Y
M:GLC#0A`*0!%FQYPY/.'\@I%U3@99L\JJH@6[S1-D-_L/G9MBDCE0`_7^+)P
M#NJH.E[.RLE'FB%^68]1[&=6>QEADR@'^CDT)60)SO][-5=/P7C,0Q*H?H\0
M:,*CTO[<N_%;51\6CQCI5.,#$PL^F[LC?2:-^@T'0^@*+LK(7=O:<]V',+X9
M0)O,,D4C:GZ+_&.EC!PK+UYD."/^MAFI)\.:X%R,A*K!3O6R3R^)X-.YSDZO
MO[V32RWEPR[^-E!#]2,8F6RG%@(4IL!-ERQR8XF+^2J'%&`!H>M0UG+R1(_"
M!A_!RK=9L#N.1M4/60#ON+*@4RICSQVQ"YW@SCHQ$]E.G#!"0RQEC\C31$@%
M/>19GY>XD8>C5I[5^KYIU9_5M^[@U_J_Y2Y+)I1V'&703&>5B<IGDXI:[C$U
MWCM9%WT3*"Y"AV:)5^0Z@7QDR_ONSO<[3"?ZA^WYD=0\HY='P-P(\LDT9+@\
M-K`ZD<'0JX"*:\+,.G'8_:G!T!987)#0HLPL8+#NWQ10.7MKE(:@%]!0WI,Q
M?]HJ)+Y?PCLH.-"08Y2T&T-3M!9"5$*]9H$!````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+V%D;6EN
M+W!L:6(`````````````````````````````````````````````````````
M````````````````````````````````````````````````,#`P-S4U(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,C<@,#$U-C$W
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O861M:6XO<&QI8B]C;VUM;VY?9G5N8RYP:'`S````````
M````````````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#,R-38Q-B`Q
M,#4Q-30S,S<R-R`P,C$P,3(`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*("`@(&1I92@B5&AE(&9I;&4@8V]M;6]N
M7V9U;F,N<&AP,R!I<R!P87)T(&]F(%!L97-K(&1I<W1R:6)U=&EO;BX@270@
M8V%N;F]T(&)E(')U;B!O=71S:61E(&]F(%!L97-K(&5N=FER;VYM96YT+EQN
M(BD["B`@("!?7W!L97-K7VQO861E<E]P<F%G;6%?7R@G0B<I.PH_/@I2[O-R
M\-/80T1FZ%)WI+U01@C0Y'>_/GS):5H@DMA'8"-9UH.I<4D,`N:MWODBCYVP
MU#?BB6(M1W/H-EAJ)&_1+`_=2E(D-[8[/S\W1R5#64>2-+<A)!EQ9$T/*/&!
MPB`X#R?JN*UU@H6<CEI>)R7;?$U95`56X:I?),AO%MU[OPA5F6N'">L)\,S:
MDHCE`"")C01@?=O<3?IUT@Q0/U-PVG;-\YO6QN=]`5[?IEC$<2F@U-K5K:$2
M9/\24A6>Z-7__46[[NU\+0F&$%E4T%0I*0\3M61-DF"BMLY25[&:8]A"4*>K
M8S7+^N((L6-O$\K)I8\MJI-6!#I-9L?2P.+7=7G)3)+N?UFI:M_B2GC/E4U%
MK'^HA8&<II1-_Q4JI?'+3A.VC7I_'PJG>\&77^OO89H<*Z&[,@#(^O8(37AN
M#/!<GK.OSNA"KC6#<;B_V$D)<QSI=I"4I+K3%H4-A?0.&(I;H8F?/5=RS5FQ
M5:2BST>8_-Y=<9^._&WWVX$VNOZLQU&7%6$VY@W93?M)S4P+XD!"[!MF/&ZH
M21.,\U#I(;Z?;:GVJ^6F:(/XIN_W80%/?KH^*'^]AN/1+LA5JGY:X'"(<OM*
MZ1,A[#F3LLSK[ER\^N]P\W3)*XX,6&&+P&OV2*F*=0!WURQW.4>YBC_N(TYV
M)J,0?#D#_"ZJ@VTEQA'Q\#"WU#M@P/.)J#7P\(]U.)]6^G#'"QA*TI6'["P9
M=W/3=9MW_E30-US$L\A'KF2HC-W!*W4KFAK7E^!P/K\S=(B:_%&\Z^0#FLBQ
M?GX?N3&8D?@:9GF#P)FI)X3.JSUF#MEJTNJ%/2`S^4!'K+)-/8T#TC,%Z*^@
M#^4"\!B=>K8A"_DU'<"Q)K7(5G4P!@<=Q?>2/7RS@^[LGJ%[4S'+][J7+7"-
MWHU]#YJ;_UN'BR4A^%KFLL'JX!AB&*B$JD-(Z?X2.T0DMNV.26,U>3HWX+'Q
MBDA&#3*NK8IR6#YDD=];'SUYCGS&;X-]'5&?;-D`=B@1,D,7]@Q6AN%.RDP]
MJAW@^WKH=$1R`S26%V416]S^D6"SS5G5=K6EXIUL,).4-RIW#&J+G`43M-)'
MQ-!2FFRCZ<36=\&"&P",#X#=C+B+=9A?W[72Y=>W7.*B'7!>6MR[>1D'97A/
MKW(Y-O\.Y\HJ$9VT[K$4^RT@];/Y$]D^JN-U'K"D/G/GT4)$^_6-#=26UQ3\
M>(DH9YH7J*+2$YR(V3O,2;+PNU/^_\S#?:1YD;S?ID1PM@"I0!L\!:8OUE+6
M38)(3A1I`HV4_K5_*P-L""V$FX.@7E!?%B'95F6X+J.F_18)M5R^\1$\FUM#
M*(-KJM&F(S+-LJ=G*X+D117<$E=#V'\PI/5;]9V4\ZD(F*9(ZO@'_H3EP/AK
M/KW%C![EE)#;TG2##Z@C+%W;6XADD,DYP55C:<@52$J)F%OX=!XV+ZZA."W#
MI4$<W&AF."T'VH?+RJ\:P@8ZB-Z^4?,I_H8!UC1AIU(B_DZWIVQJ>?(_%S4+
MNF+0CZR)2%,MV,U+.CA*1$&&S?"DDH!$!=`W9>*=Y4#^EW4_0S=5!R/V++::
M@M->=4.SF7+-!.AFOV=#;5(G:>#TW(K<(7#IC@V<M>5436^>(E&=X!&,OUW6
M^]2W41KN\Y)!.T]"VKKP[U<VG(CR6\*X`4(;@7V3Q#LZ3\;96.+U(7"1H88!
M)%]*_Q?,.AOU=#KL8EG)6(4H+H[DV-@/_7JKR8=N^NUX3*+R<+]5\#$<=8Z4
M%I"P>*-O@I`J>!1(9K$"UU_)=XT/S/-%;REP1)<^0!]'UHG%+Q0443GT@VL'
MVM-M203Z8Q.ZH0K*A]+U(0?D!X.103=2T'M%W43>^*:XY4B==\VKTV^F,"0"
M=87FVM#Q/(YP7L)=&AJA\`#@&#1"C_,%CV"*+/JLR,03NJ:5FI.<@K;FI![F
M-#K52^7X(34@`C)G_>T=B-4R*:LAXA,;@2915A69J>'*PU!';F&]M757L^N?
M@)&+`=:55@K)N@).#O+FYSHZ+T8ERU2=V/NF\?JM(KXWXN>Y,]_,J3A2G^,)
M4#1^"B':78^C`O4AS/K25FZ4EL/O,%5AICMVS<4DFY]F;7PU<>"WV14`9B_:
M,@(!;58IK-.-,VE;0!(S5#OR5ZJ#"OL]*?_WVL(&#--#DX?R;BO"Y7GG]A<]
M$CYN7+S,TA[OQXZ/IOSC3S5F,D-O!,]?X,J>"WHCFZ@Y4SPGQ[8')?*TZ:3,
MO)TGAN`D2@LRBNVL64)(SEL%D?7`DVK+X./+@ED(-&%;ETD(@C2F$&]ODO5[
M(-4C:N'`LLLS]PBAGNY[6=]-XW,2+Y@53\=GJ<64,"#8",GQU*=#SV0-IW"C
ML">-TP[E"2<J(PA&_%A5OI/ZV"4?`[S^V\G,*E_K/YC*-&[4@FFNZL:$,*Z2
M/9RBMD0KC&1@TFSW!PS]32IQ.L+R<%9'R/NFP]S5B@OQU*J+_9X]LE14)*EY
M8QO.&1L[3RX-@V)'44>79WYAAN&,V!C/*ZUK5*Y[PC=PG'KLKZ9-`<@"LK66
M:<BRPCN4BF3V^.>/=(4C]ARF/>1/X]7-K[%1%F1F`-PQ4,[G1X:NW_!$?U`!
MG9BGTZ&4<4$ZF5T'NQ-M1T#6"^)I!UV]M`FR82^0$"\@.%;9;2;)\O!N=AHR
M7N]SYV8O=_!#OQZ!!)W$/?>`_'6AW._HXXMS9`^C!`N1SJGBWZ$MAZ&GU6I7
M/NV_DREMAE"R5,6<\1TTR%&^RV8-E;"]18U?1Z<Y>5OBI></6K)2/T)>SN!E
MP]6\7H[`OY68M@U0;SLQT[`=?/*):N4!4_2R4#)\7%2^AP+M''C/]GAD.HXG
M+CT07009M.FZ#8HK?XF64VXP2J7OJ9`>6VC$E>P`BXG_)C7`RG/!0T8V.7[&
M*`4%DP%H6*1\L9'O]4@I(<C!P;=J@>Q3%XN,.@S?S0@D4\=G$N?WS@RDKHE@
MH@08@!8VE!?Z/Q9E!;"US/&74#RDL`U-.S;QP&:+^ANX-P'?EZZS(B.<L=@X
M#`9O<CJ!+3=JEG+GFO8$^1]A"[;;OX&IT"%<*$%$\S/\V#%+"2_;RN_9=3,A
M%%;QX*`!R&PM!HA)[4K75N7W*XTGN;?^$&H`J0N/YHZ/P]N$>G'1XDV70DX)
ML]"..TE:ZV(-.]Z2)C[<ZW%>:S6W9,UXG1`RM,T)E$;H;<?2%;JV&?M(PL/E
M,@5Y0*A08'%Q1??C,$K+J!6(K@))&6=7H9O\<XE#W\;J8:@X_[D\VX85;1$$
M.X'*(%@.)<VEVH=6:]NI1U><0T=$A)^*#!+:B_YC&G789C0#9-(P=*EG7ITK
MTL')OHAX]N@:<BX)'YG8G\BBV/^.]'MYGME^2@#&$(*)U8JB1@3SXW8]C%D4
M)V!="V8":>D$O6:"8F]AJV24W3J1\^>)%!B>>+'Q"S^WQ"270.,/XRS5(+C,
M_=`N7.`(ZU.[OU]O'"M4AX^%_X<;%EA7<88!06RU*$+)YXE,5E0>Z66DEJU<
MBY.-D34KKVAJS:4O)P<M"4*L8=J&#\<P`I$T[XJ+I[D?^X;D8&``FA1#+0R0
M2;=9^3-:-/VEFOAZ9MJ-<_>?2*XS]36=LR+>A%@P-6/G+CMDZT309F9EC-FB
M<S+H9@W<R>K/](/7MFQ$HA2-TRAHT2U;JZEJ-K5A'1+40]=_5!BX=E)P*$.+
M;#1O_OBMG/9/L1,Q_[8R00X9U2REGJ,H2?C:);-+S"PQT!1T\_1:X9,F-DUW
MVYW9`Q*7*MQR^&TCE_?]8&1T[E2!3*N:D2&')Y;@'U-"L#X%T@%QQL=Z^FDT
M&FT74283DS!?>HH>>VTQZ#C5!9WJ^\9TO)F`PW:W*)4Y#NEU[1,=CSG[8V$M
M,#="AD=MT_M!0TCY;B<ZCGPGU*93#\(%A/.]F2_3B@1OE6N/QR68N'V#^BK$
M!UAK25Q3=<C5J*H@'7F&*W8G?:NJL!91K?OL`G3\K7GX7#3F>NE-""XVHRR'
M[9+*^,=NU@CB8L!MW<W]*B:)\@/3(7`=,T`CR&CT*&MWI?8B&>P4,)API5+1
M=<`0^>LZ?$F)9XF&1/E_?VWG(&S<`F*<VXMR2)UYIP1"T0)K,7^+``/@68C?
M'/6XGI<Q9?O%E21W>CMUR@66-2&-=]=E8(C=/5;$6':/!-#7'$EY&3[?_K!N
MM+,_JB4VBQNGT7:#]XF/3_S58PB24QFCC4=B_J>7^+6?C*:I^2NJ:[OM_K',
M-I#*%PU#0S5`EU_WUU,A$0Z7!F%W<Z.-K`EDO3T[S9M[7/X/#EG5U&NU0WID
M,`WH9DE%UN@S:1)AF5>QB;O2U-N=W^TLQ%(,.41TW7(K\VX!:GF/IZ'>CWN8
M-V6%%TD>8Q,_'JH<2YI'.:/(9N"U#X@Y;D<696F):-)\3YMW`PF6;E8P7!J&
M0.=:^K-Z9A3N;83Y;\4+IZ_)P:M90_,F\_[(BXU80[\\9&4`'/9$B=2*N*7>
M<@,>SZV>'31=_^WA;W_7J(C@LF!B!1RE3^Z?![G_QMU[@Y_K0A<`K*I[I23.
M`B!=>W#^V:Y(AT'P7Z4'BK!B3%K92+G<0CTLZ"$*GU/1WS,-@$0F?Q+.Y*T(
M8B<9`VROR[V](V'7?.A#<*OD]_=&:/\(^>UW2.E?J]6OIP>6G^N[UF-6L.X6
M*X@`_$\A*)D^?*H,J49,0-5LMM;]8TWB.L'Z&B,<HCR>=X)E-335BS4KUZ^S
M;\RF1)<X@]B2L9B(R-/=4S/18HR!W]M?Q4Z["P6<M>X$ZIM@W=@CI`L(]/+C
MHZ=1A0\96R=O(^F6@54RO%2G"R+'"OK214<?NSN9OX7GO"X7JLKV93>$7P[/
M[9N8HSOY2ALVY+]N*N3GU4+6@*/JFJ9A0R,53M%_9P=LCZ]TU=$UO1]MWP=M
M9W;MP95YN.8+*74=W#^$PU\L@WH'=;$!`=$\MOKAR!50CC1MI.I@";^=51A+
M96M#H[1%\T]H(0(C&Q6_O!0TGZ/!9^_6,5T>G4"(BQF1SM:)[AX4]`RFSM$E
M1F&%NG"H_";*EDTL%(3VU(M[.[9<TU;-L9JB'")=#;C8SGR&6U,DFP?4E-I-
M9U;QO2*49<EM@P%=)4!H]A!;F'[.6\]%UK3XHZ7QM\(XJ_MZG";*_K1+-G2%
MSL5X\I=`&3!G3%$'".LIY/FX@,(4BH;3$8R<.;!PKH/^MTJ_<&'Z]LXE3O+,
M0.>M)(HDB=R(8'HU!#\^S]67;JB2,J&D4%8$VGWC+DX)`&JW^Z)!0_-QJ<W_
M<`E3VA`T#XEVLV3>6DA?%"U[6(V*G(V'[P,AMR_#F[U>FI+**A^2]#%R.<%*
MO$3_G?RUUOPCWM6V/XY:NX%Y=EV$GI9$=_U5/HO26I(H(K`GM\=)WR8+$96?
M"08K'?MFQI4TO7+)(OQ@J.ZILT&F\%;U\D*C..?]Q_UPP"=[Y]_]<%GBK?2P
M!J&G)G#WQ*]Q[)M,-:\TG*"#X0597$?+FI%O9E4DV).XQHU+OJGY'AAPC*-F
M;PM8=00%[C1;4[M^FG[`5\(-R!1$;#!L8Z_7ZB/8"+*>:>_OU.M"2#8].HLE
MJ+#U=S)3.\%^HMW:F>#SD.CQ:^,4EGP457LWO]&<^.MX$T>9[M>`B?B9'MEX
MFRR'BAF6SE(WG?D.%*L>86OY/<IY6_!58S.@MLU4L425.C4!./R&DT1@%EXF
MJ-_)E&(T;3@"OK$9JF4X0[I5YBFKKI$&8'$N+/:Q)7?^?GA@I2;J"X:^&F!S
M-K7*EYB$?+WXKRY-<NT^65(Z,*<A0C0\%FXG;+L-O[N&!J$:UR(P00@^%(02
MA>S9\;HDXU+1<`?3**W'UX%&,[V*8I405&O?"J8"/7JL@O)>6K!,E?;!1Y-#
MOEI!XI$*L@-\V=Z;>-B)I)M06]25_B`"MG3E?I4UTGP8H0RQ!F`"QH>JLV)#
M:*P0/T/=P&0J%NK-DN/EL8_*408M'K&Z>`5;3G2H;$P^DV#$SJ/T<2J)Q"^K
M)Q16U`8NY%"MN_S6^BN&4<VZLB@_;KRD&Z'O;^Y2[&S1.2-V4!K(O`6N<9C]
M78)TU@6OSHNF6]#:*1CKJV^X"?6P<%H>O2O9G&!;B7@E(-P+9><URK=91>CK
M`AL[*F;J']*1-J+JIS`:,]@K,#F?:E#5.\Z\45\K#7'9C]40X$ON=5E1/1G;
MZ+N%T8?FG`A2)<_()O*%6A5HA?_\-@I"!0T-=#J'GAQTXU2DCOW4XHM8!`6\
M<=[QI#@=XPL)-1DWM*,M-#C74)!U)E>COYI3EGG+<P#GKQ_\MU<I[(8)2=I2
MRY(IZC-S8#-[_2X+T-6*=%GSFR`H>2#</RQ'":V%W?BK1UN49O@+*)!Y`Y<1
MWJ3\P86_^&-*%L0VQO:ITC/=@&<J0FXR1/'<`L4LECU2V'0Y17'FWH6A];S%
M$87QD"4+A4<R\B]TNHM[6\4@UP[\&N(8E)E&1>)6<&6E%T#C;+MY&\(_0=@(
MG[\@_(,9:!L4+HGEW.*'PW1JSN-I:-<3!(J;P2XUP82O]S\Q1!5"4V]W!$\>
M[!3+@<V/>^U5**0\>_,!"J)Q(1?#VTW]:'<SX*X:6:,=)G?]#^K,G=BXXTK]
M$UK!9#S"_F-U`UC2`IKUZR9.:@/YHUD3>>5]_X]CC4!?G.*#,\F6S:^$.:LE
M;^DG0W;F"M-\?\/(CHFM)W'*4VW5_,4[RO#`\,/^K#5P$I`'B8?X7Q.%&4PK
M?-V%II4-EY7%BQ^)5_#MX-R%>Z"N"EU`LQD&O#7$CW/0]BU(G8M"5J^6O`M%
MM)&/XB05U8^6M(:I[TRT<[@`%;8O;C]!*W;Y5OZB'%Q%<1;,B2!OHS3_ZO/)
MBCRF`)%#[U!O<)#*#-U3=BK5&95WEFXJK,L+0-\K7`3[/J0EO5R4;WVIGP.G
M$_8"(W]'*;C?EPO?U?6T"+#A((*/@E\6Z;D8V)<\J!;QT>60CDP*8X.!?DG>
M-YJ_5%I2'(P8DRZ:4:\QM8-PTT%W]F`AK<R*!-Y^Q2*;/L:/%4\ZGC=B!,Z[
M9$EO8C9>3B'\;OVXVGA5"KF5C[00OBU$#!X&B&H7P6*YQE%88%L\J:)PJ@KN
M+C:65@%9O/[S7*OM+3Z],*[KJEHP_>N4Q1R"!2PQY[.P0Q?[H(\MYW]$M@D2
M_>T[I5S=<7^`F>`I!5KOF-;M#CH3"3-YM3KH"N+H[J$9!;=KAVU$!XCMNSF.
M\0%.HA3*1,1OM"G:%^\MC-9'>C_2`B<GQA?<M^"&WFL%.WF#?+LYMJ%HUK7A
M23-3$;(QW,8&ER'YNF;@YY2/S$"1D8\K7I/AT\UGJWR540!;_\3#0^;G$([>
MQFVK66@.3TJ[??[;[E,F."*:3J?G5#F"9S&F?&;J.Q6]Q6-[/X=QQQE@U2/Q
MA;=(@Y(&]OBMKC[G@5S\>3%=V[;!^:6:>J=RE^6:&8RK/:&CDC*\0HD``#$N
M]XY=]RK>\"$6^BG[MB(2I0:DIX]GWOU\3Z1<C&<(_;_+G`Z%&?4JD03/4E9-
M<2H(`$]F)C74[2Q^911;YBCJ&1D57*[..4!8=F!_Y%"WSX32&ZNEGF!;_1.O
M^RE';&F=H#:=_I9\\X`BK^H%#$PN?<7')\*ONR^66\K',3_?KA490V.T.%8C
MQ]YP"LJUUD.6]_F`UFQMG[0Q6]+9W3<D-S.WIJ;)9*3&0$CV(MD8PU&H\("`
M=Z&IH$5CTK]:V^Y,!818S[=H_I],@X?!L3##>:79+1^L"6?[K_EJC6-X(]HJ
MC8K""?/^QVHZ[NP9HBD-OW_Q%5Z^7P!$33O<3UE&Z9`%S%X/`>8G7\=VR.N@
MQ[,L!C"7>;64((0O\:YJT=P$[N,KP1?\X?T@L+]#$<YT:?F-3?#V7Z)G!A^`
MYS<+D#$QF["C:$6@W,=A&A:[VN4+FTYG_LM>]GH-PJ*6E@D;8=O\+?Y\=Q$P
MK!9IT2`R$]K6]&;8?9[^<-9,?"_DO6DJ"N%D%\FF$4\%^P&3IJ("G^H:^MA?
MP00`AQJU.00=&RPNZY4>72][W-*&Z]=F'8>]2UED([3Z<NVQSN[7+MQ*@JWH
MS?$+:S2H:[F2,A/#'W#Q4.:['_Q/8"QAKMU@0*J_C^(42+T63S+%O__!/<;R
M'JFY_#%5?@#2C=T$%^XU%!"FL^3%\N3_<&@YL2Z@R;Y"]"V+G>!X1$C#TBO\
M3YDHO)C7//3YBY@?6E\0,'"B)NV`N8W8)%X]&9RQCP5CS!I#CV<S#=#"2PV.
MW(,#%Y2/R6D'P-1O5#).IUG5ZJZ)JJYX&\X4CSU``6FNP-RTD"=^F31W@S9[
M[6BV&GR_<CJ\GHXF/VY66(3*)[S6CSL_D,WVSQQD<6924*)RX,EB$FK1OW>(
M&W4=,05]"7:XUW'=?KOYFEP(Y>5"DW,]Z:(7<OG;FH/"#"8O<UY&H72P0TAU
MQ+W)K=R4<H7)+Y"H`Z)#EO3LJL8A^E:\!B2.9^]F`>>4X0<DP*SE;:YX5AJ.
M7&0TZ_$H??>A%9"C*@N1AUK?R8"!.Q)6'9%XSJ?TFPK*A"D%8\^`Q.!@*\U_
M`DO/QAWV]?O10]P=_Y4NU$@'TD<))KA4SZIJ3<#:4XXR5"LZ>UB#AG/X+UX:
MA^6+JPU"Q_1A>JURNS^@8G::8`<'/U/`*5ACZO.0(#_UH8C"6<FSQY#HNO&K
M7=0NTZW2E@:&5QA3\-.A\WKVBX4T;T6DD3_2Q>>=8G0QD@BTY4.?BUA;%D7?
M^V[S."`]R]>@DS^K4.&(EO]`RQ%\+O8DXQ4F89JW(6@R%BH'%-\)<ZW!]O&[
M9KG?9GK<_3#AB/]BL0SR+!BHP;\:D_U^QR=M6X$WP[@B>OB@YR`L[VO42JTH
M'N/GH%+)PQP@I!K#*F>L[G(9%Q;4E-F[.A&@\R;=-[]XMV:\Y%C@Q+Q*Z7,Q
MSOV6Y&R38[GD7X0G8I*&3@/H;IW($SGS#4C^=FZ=5<A;K!7L9VF<X>FMFNCA
M5V+J^5PUX5B7/`R!&5XG(G5M"ZDH038&H`S4DC?M<(L1[X0=>!P9V5XT@VB`
MF%3]`ECJ&S`!2H<^`D5@H.[`;KI6=')V00:^J/'IZJ/0!P;V^8J#7M=\PUQC
M^.X$=$5SN$(1A54VF844^UL0U#R/$QV<I4E*3':HJ80ST&`SE<.%C_/OB`PG
MB7"I5>EP6(*YUK'(.!%+C`N6UD%1K.H#PB+ZWSFE!K18P5@3[+2UA<0"86[P
M'V0138Z(-4(TZI]K5UU"4\>.V?F&6/G@<7V5I`XB-+X%4*4$*3J2P!C4/'>)
M5!/N//08L\UNO$M"[NB?\=UP;KX?%"KDX,3%68DGG`"W?"^).R,$OMIY18T0
MZ?TVK92DE_Q@.`'M/ZOCGBD\Y?6`?CSCZ3@F#]Q3-9,IZ*O7+7+.#<$)+?,%
MJ##77MW?!RS=)EU%GS8'HYK'%U5'[]K8%#3"(C09W,\!AYV`^XYQS7[W'S;^
M<X(E`:FG;4""R6R34XC1\WS"'@L#Y2RSDTC[:;/`$C<'+`S;C*A3$.N:#BXT
MLL1WG]2#HNB2O"\%IQ__`\1!?!\Q=^2IM![%>@<WUG0C_ITKP8(\2S/@P4T,
M_/XVX1@>55"Z=^\7$I(`-E[F@NXU6:5E$HRX-*6==2QDG4P#HG.&O=`D(HA'
M_$=C5/]2=RE/_9+?^$D8BL[X6[OU9%_%M6WN6Z@0=C$IDO0\.)``N4BWKF"5
M3DCD:U<0A8ERN4*:)$^*-VC_-84YENPP&32T2N:E)`/?:=Z!.0!BZ]'-?)4]
MGK7;OA1E&C15:0P<OG4W:O4M_\'KA9KK;.6HJH/AU5=\/9B,QU:0>^W*#V7U
M%K)N([[=1LG03C7MIZ:?BS1?JK"<TJV`*C376MN$%ENA]#*&?G)%O=\OT8/Z
M,$GZK2[OPBF4<U0"[1['+Y=.4R.VF@J[)>'R20([0J<(('-30=05,`PO7,AW
M"H9`95H<SX*471%;)&!4^IJH;',48\KL%LH6%@N@S5)!F]D<)"#1KE!L:<IT
MO[_NF:30S&4MQX.-+3RHWFX-,D^;`2$79HU*`B0JXM2C0,I&/D^V0D8!W/*K
MC?ERK`[`IAUU!*(JX[-8NFL=:>L'17]'Z_#"\7K.1J1O>?=!O,!_6I)S\?H5
M13`BD??<@6%&Y@W=6IK'1M&#N%T,7?=9__7$L-]@[%"Z4A\WV?R!B1.6-3WN
M].7Z[W9VWL0U@W)3J->2]KUV.+=W&R$9Q$_PGI^?6>/,Z]I.JZ^92LEB!A)V
M8L!OK>WNZ>I9(7*5M$W6<)HH\<HKK8?*!$_&,93C^-+BY"C%?D"LC+H7TKA9
M`;L4\5#!4TO!7A@B&+MU(1T]F8"2CEK`E&W+8SZ[G'LF"89]4Y9-O9HUD4`V
M'U_O!PBC4,G,I_J[9#/[$\.2:^22=U3>S;NS9UL<J0H`I#<SZ02K&9&M8*V9
MB<"K_+W*D%QYM4M^^-I^1)#0D8R8/Z6%CEYR;R&W13172D%#6S8E,5R"@.-T
MG?UE2]W9<9Y3MU[@.61NQBN([:'.V`+HBH.#[B4''+09ANXA`=!&$_`3857<
M82,`Y,@0W=W1[9<"*PSN3?OZFN!NHH*Q+FF)PH%8*PO)!9AE(.WO63`+*GG@
M.2HI*F1J9(`CA;@VX5\ZN-'H2?.I/;(I(^*`60RT&>+;"'ST7W@:@,.\[BJH
M!#M+IXTD_`2YTL2%ML:]O`"QR<(L-/V]?V=#H9UXH_IJ),[L1%30<$-+4=#V
MT&!1XT7",-]&=+;H921UR=W%U26945_L#*/Q5Q\!-L[Y-\#Q__=0VU2;P&X4
MC#Z%8U%TI3>Z0X!!4',O="LLN*FX7&?=UE8(=GL>>3VLT.E;(3B+T6J3>]DL
MYR8L9JX;Q61A.<4W.G`$52DAL,VLIZD(H\J9^5?'9MT;&39+**$@>U?4]&R^
M]51'E3A#7<!5KI$&,E=)7%!H!K?ZM1^TL7P4OL@!;T"+3#]<^7)(.XQZLNCY
M4]??M'!S'G5P"PN*S)UFXV+KFUEBZ9UE@I;0G-H8DJ+?-96;(9-LJ:CI_='B
MS/-NSE^3@[XX<!0Z&K?IB@Z[GSNO,SAQM55'LM10X/`GPK]#L<\DI'M,EW\\
MQ@I39N]4&3:5,12RVB.ZS^J)#:#2//WF0V9G@CPX7RY)Q(**[VS7]E\*)R4`
M-L$I8-GD$%I>;+1S^N-I#"J<8`1\YW2%72*<"CHL%!]5@>\_`XBB%0M/$TF3
MGR":=<:W6YX<&WNUCE5B3*\#IRI.7<5>\MK>LE>\FWGO0XH"?^V!QO%/LWF)
M,$;-AEU8\\R,P!DIX4X]B9,R+?8V/RN.NC8YR3%\H\BV0ZS^._H)_*2/%Q8(
M;0O!H"<C`=GZV)N%)]%C'[TWP9VIC/8;S&(-W-)DKN?`-<LGT]>`_#(1X+#Z
MR!Y5:)):C$A^V`FRN&NL(R><]*G::EPH<TZ+0G&Y)+#>P\`)2.TIP%K#9W*#
M\3&1<]I'=VJ03OI/_**7]>PB8.'K(_@.?,#NM\OE1WS\*CCX1WG0T)LM-.J\
M0TP)I[B9!,W<:ISFKMOTO/<AZI+SGOQ[L!.R78Y2R<LRTQC\X#^`I9-=:(/<
MENNH)RH9;I]WIX@N2R"=UKT]]#%,YG8^",TA!$9=OH8`OA9,&/,ISI;]U(GA
MSQAC#=34/DH5"<.;MIT#7*),ACZL'RJG0JV,85*'BQ$RCFUCG<A($BL@?K5M
MT2^2F*HQ5@*%7#\2&G<`&AON_'%@\XD7DAZ(@@A=C!Y;"(XVY,Q'G&5#U-AB
M(()12!4"0\#P;KR='G(<!(E)^1/EI)W3SINFF;%$!9X;#L$\O@]&I+X-_1=J
M5I=)#W,3Y199J+@C:$\Q7WZX4+ATG4#;CVSX'VX5T60NHT>-[)66*>K(>^W/
M30)_E@8=;@?"M>B_QNC[)-7`Y9(,G@J6UG`&F[KAG-3\SG%LZ)F=Y9(&R=>\
M`NJ,;:+:E&02Z0:WGZDI!="IF""_91.V"G0Q!)EIEPX?=4`45#EPJO"?Z<@+
M[;M$_:TG_$WU$B%R>=C5='SNKIQ![6K"B*"P,&L_K\F"174LV!4*P'W`-5RA
MOI4/PK`!Y#&P]FONN[+-M\:]^CD;8L0P/\3N8L(4!L8S]LN:WX!"#BIL_P>>
M>4SC*"D=>WSY'C<NQ<K4`)@_[:09`<ZBO2KQ"!HAC[3%R%WFT+T^BN.JV$MQ
M_CI;<MMDOL!-ST]"2/;1_:+8^A$+O0%8M0:_N'3`5&QEU>5"I=D0&!KZ;F)>
M"1A$<>&TN]J"K_G.S;_C@-J[38V*S5H-.;**CG!N*U=1SB"%$-BRVK2BB*2_
M"".#G-]_AHZG2/QTEL.RM-4:*VA545A5BD1%(O?.+])FP\OG<M?D7TB4#V=H
M2@BM'WLU$!#8&.-3CV.]Y9#`*ME`$^%PE-X?TZ%SD86A/ZO)OP"\F'^2%0D!
M_5?$W*.SI'*OK3>^"^<-36-G`5(=4SOP;1>0L!!=^*=!_DS8^<OSK(SAFS.`
M&?!6FB#)XP_VNRFJ*3I2MIQ1GSPJ45&#T'&\HU9*KS1K6]5DCC&[C9I$H?E-
M&]*OUF(G$I\F8^/A,E9@A(MD.>2XL!A`]WO&H7])7^TUU-)P-.0"UQ2X>B*O
MV[T(XTJ2ZM[]QC5.O0N(WTO4`PB0ND>J;87D2+6>M[M-H<S8K2<7FYA^QGI(
M8Q?2]()M_>8E3=LZ9K7K\/4+8(./$;7>5HI%Z:!?>>"%'H%!U\QUQ%*O*4?,
M03!4<0Y_--Y6P`*!=ACZLO9LU]ZI%D$J7T]U6D+X9S`5;:N$;\J7$EBH@5@V
MVBK'NW]JL$$E-V4@`V^YT_C1."'3ZG'D4'.Q>P2D+&ZO_Z[K<O@0ZFGG8A5G
M'?D_WZQX<*XC(]\IE'!<OAK<0LRLVJY$RX1"*[H]2.*+T4QM=61_1A.`X"5#
M67;!`U)ZP1YHL2]JN+)IWIGE<_]ID87Z7SSL8Q1U;^RGWPK`37YSX$5>9UI9
M;><+K7<^QOC9%X;[O!$:/OZ_<0HH=,;__Z>M&*QCR<C\:'LTZIN&<BF#[:MJ
M^>KD(D'9;K7(VLO!X>B=2^)CA$"JP_TD>Z3%CXGWL@IB7#!SM>E58')#8:A\
M?L)1?RO"=NN4IH^/?H-IP'MO#^W@H;L`X?!^UH\A:=.&:1$2<3NZY1Y-A(3>
M)WL>V`IH],3O:Y/8=<TXC%+_+OG*&<)%4VJ\#&1BMTL"@E+$E*SV\@'J('GQ
MOCD?`_?O._$^'():(QW2<TG@#/_P<PII-;0,>*BDBFNBM;BO^]+):P^W7F"E
MO%/#U5.+(N`NKPK_Q3AQ/&@5L4"AD7LN`42\Z43#$Q@BR/H$?I*8DX"HHPM5
MCBSA8H?8K-6DCTC$'GB7+_B.F43QGR<;G@E#U.K#MF^&Q9_R:%#@;CW+'>Q'
M@1R"RTCM_C[8NH>[32<"]C;+SFCW"`+V8R(4JSAU<.[#\JR930."$>N%*\$M
MSP)@=9+]_;__UG<&_Y<M<S_Q%5\K#J5IGRJJ.4:5(7QFX(3+AFLR&S5)0T`S
M7_F>HU/'0]AS/,[+>JJ24.0/(;O\5A4WY+I4O9.K']0SF58,:\#Z%]I*XM4;
M1J:3QWZ-H>%<N;W`A*)R'>YH2M=.:[!8JPY3:XYS(K&<7,6&&!$VI:"L'$)+
MT01179&(7LN;Y-#5=1Y7:?`]0400XZBHS>9O7^&@N7P]5+K6L01B?K^R*J(]
M.@^%3CL'A?!WP("\/J^<*B=T_L]ZC*#IJS7S/<Y!M*W97\X0>FA6=6C[^YGD
MAM66X$1S!9*O3`I+V6A23X&),BC^FI],$E(S`RH80,#"3Z6V'4W31GK$8;$(
ML0\HY(V-IY5M#=[`YI5.`43HD2Z5(NHUT16KEA4LS]%&=Z+@-@13:)-6@U+^
MJ8J'?9/G+G)H>_AM^:`S+]-\#JW;M^JJ\4I$3XZ$CUE?9R=CN^B3];Y0/G:#
MMVL8Q3N(:B\,C)2!2XW.L;WF0<UQM6'-LFRI0Z/:WB,GLSG=!)L:"K@#=)65
MK.4N/]&XF']"S<0[E>--^>?[@`&^:TE@3=255NWS=_EJVTWWY(D)KH"UAP8#
M8Z?J"<@M';&6<*"Q1$LDO8<5G;74<`YS1)ME)CI-1`\YE".[D?9#T^IK<3O1
M"6)N>55RK)8N"1ZKP?(I8&_"C*$I%5[_2BL%I,Y=LDI]TYZXY5'BB(L`.NR/
MQJHANE(IL)Y!JZM6P=C3M/G@JB<V%,*5=B2DS^O`7)V"&0$P.R"?C#^,W&<H
M2?*W.U"TH/=]8M:@^[1GE&.#\[HR36N2Q:F2X#@I<A9?C;$Y$5"(B$U/?^.S
M5B78MD!W5,B!V3,I4HJU`)J?&G54AO`#Z<OST](LX]4$<!;W.+F>#P!=E_*!
MO<835W_'5)]_84@JJDZ';:\(_<GP64&_@Y$\^UDY17">@BG`O=HOVHX?^=V6
M1)>+<4]OITP&K[>:%MY*ZRDJ5'XV[P%8)<!IL,6M#MSTWD@.[[EO,[#KN94M
M9TV`19O;Q)(WQ+.@^#8D(>.<!#81[\4PB&+''@#R^R.M9(]V1*;AE<8];V]S
M+R)[^U1+C3/ZR6!0@?6A.IFM,?2$X*_1]8I-BJ>$ZYA1<;2M2@G(NYV/3K^C
M^?=,3GS_T0LKA`_F0-16,E7J_@[)Q/N73J;1P"N:6)/!^E_/K#YR>&14'X#V
M^30UFSUG4!KO\ACP7'(PB.Y+1A8FA\%SN!Y"XA*\%@G!@(,=XXN)(J*79,44
MGV'W`+>[RI)J>-NU@D'O%0*L69M-O4.([\<3V2C``X.G.U;W""'3EQ]TQL."
MJ%'OZ2!:YWZO3!^K$P"GX#)K^FLLNQ0.J8,E[)QXM3/Y!RMW2'+96XZX9LW%
M#S+&Y[@ECX^]4CZ&MJ6N^?ZCZJ%F:25:D\U7L'N6FGU-J>)Y'(UAV7N2,6G^
M_Y78UC1W;G\S7&[TCOVH"??T8ZWF,&999G&`VU3SP?++HR`8>!9(D?\Q0F/M
MBB%+^R`7F+$!3DV**'1/9CS.`IC=HA/`Z<N*-/^BR=(_<#_RF9KT7&(1$6QU
MT*/S/)1)NV=M[CYB-K#NONHV(PP(0RE`A1&#E8P3F:`2@\7Z)YYQ"T"C<_;6
M3T8.S83$FHM@ZH[IV*2V6>KU[+AQ^OC')OOP:74=\O>^T:-(#.?R`WBL59I.
MF.3^E!'PJMR&#VO$DVUU/3'[>F80[VE=LH;6]#@*^Q*?F0"`$$`KVF1F>`/(
M+^J#P("D)TY-9MA@*HX]5M2'U)]-O__&O_\HZPR"3KH#=&I4A'XO<7W\/7K^
M2]4[2S8?@`=V^&W\OZ[.O38E80E5TEW'=L\IPL2M'>A^7)R2<032#WJBPW.A
M;9D"!)J&U3QZV?5!G+(\H#O+%7#4?K"$R6DC*!EA[J,A>9@@K=:9\W^5>:0F
M-UV.[\,'9<%4U-R+DIT/.0(-,T7B3%/I["L^:,OB=,9\3%67A]F\<9A4I59L
M[W,?7-Y>)-J">_6_5G3_#>8*"NF1@$Z$]"#R!*3\T.U=[]D6=@1D,T@%9]P;
M3:RHB[P!\N8:!G.FL-J;[%N%\RZJ=Z/A*J'.9$L\@LX5^MQ9Z'%3C.'/>N<2
MY/9H(U[#=+RC1)?/`(J]0?!"M`TYB#OP`C+!OK/=_$NR;"1)ZY?O^@SBIJ6N
MP1[3DHN_:6?`6DK"'2'8@"4;H4.VGKAOM(S6Q=B43'=3'OI6K9<!K7&*IGT-
M-;B`>9ZQ:O':798,W+11I7)&*`N2>S.6#RWS!,2!&F]Y]KKT*W_G9F(F]#S_
M)0GN:ER88-T%((O(#\EGY<:'//HLJA.P5];,H7HFO:7X-Z=REHM-L0NMKZ--
MIAZ]@7W35MFM=K4J08E>&?@.]SP0H^#(2TD=AYX]_HAZ)#UIX<,=N.$'\]Z-
MM';,91]-IC)$$O^L;W52AS#R'A[O\>(*?A!DCR.<[(])*IQ+`4'H?``GJU$/
MHP?/=:#<S_487%[X@1,:,:^GBSJN06PEJ+7/N5]7MQ<*"5''Y"^]W^5^QA:%
M37W7+#LUY=!FR_*4`?YZG[4*LYP4(?=./EI9"8VX^:_]/H>R]N8X%5B0V>0>
M>D>Y1G\BH56PL>C:QD.NZL$<AV8[I<R.8*GKH>C<EQ=#?9%FK2B=4)D[!$6=
M/YK<3\L!`F>^#B'1SSRM%6I'*H4=K*(5,,+:"+:,(Q@%$)4>+R*LQO_"P)<M
M<RMK5G<`;;-*2H,O#YQT(J.&P8AF5XFP='9A[$#2D%?-8G&K0$R<T'H"C/R*
M#'P<4#B9W1;J?]?XZ6$IF'-K,9A.?=Z_3H0[\7PL8L#I=I.R5WLI+Z*25R8;
M`LU;]@D,;>K-+,+Q>3M_GZT3\9$;_I8W@RH%1QVN<+^OU@J0W]6<CK)V"9_$
M;G__J&CY;F<'+I*81B+EB+<T5':U3`K#%XV>`::`\XU$,H?!"B-+B(CH8O*!
MW:\FJ@PN1_L;:H+PK@C-3])Z?\E`X4>9_9QGO7B#LZMD]^TMV:BOH_*YD\D=
M!RVPBV^BOG_7!7_(S^6(0U)ET&,55FT<KN]HTXF!P<OK,&,-TO)'\_H-)>;L
M"%F4ZAN&<NMR6PRQ3&A-/F[P.[K5SV\TP1F%-<MCM'\'8@V/XHYSC[0\%(WL
MMO\/K,3?OCB>^2U]RH$8*U5/ANSJM!Y+M7EKP-=O"'PB<-CQT6UV,8:5-7O#
M-Q3CTJSL:7H-<8X-5L'*-O0=AD=7$/A?_7$,A%0_Y]*WI`R7A<VJ_VJOL!H3
MZ=NQC^I74=(.D$6].90.YCH\-1D@D]>*FB)O]?$,)96"NHM+O`T(<M_(K:OA
MAT-X1[Q:I;+IH`3V68(B2*);XB=8S]L#!E8XI4VOUP+]\[UCZS^F40=#3)18
MBPPC1#1"]WA^V=$\(2M0V9O>7D:>C)9;]9VP!IRI&!U^!K5!`L\&L#\]WMVN
M)N=)BXA`!)22WA2@,!@Z/*&L`5L>B/%A@*;S0:<=I<NG;L7^P>TS%\3<I54[
MMK-G<:QN-5+;>=5>L3]BCNFKZ!F?QJP[30,$T../GF@LD&;M.DATWX$<(RL1
MYJ=3)O]$)KYWI`7G0:_#>4W%CQ'I9^:A`8;A7O$=V:6)#ZG?$=]&8VY%M(GN
M&3I/M<$@.P])\*IL]L<>4^7]6]UG)\,1A0I5*?7'',2V4$(.U%O6A:HQ4D)]
MX,?8'589YFR!48V;_TX+8B@<FV)+!?OK32YN:@S@_1_7&[`6Y58>U\YDTUR%
MYX=+,Q!=MPD2=?4*1F@)+[06(EB"?<G!P(\KE)#.6U2I"/@)W`W0RL^:/C5K
MX(Z/(?^,`&;_3N0`+FV^_#4RM=0XI[P*3K>](8V8L<GWL2*J$?09-RX0&B`1
MUI(9>:4M9NF%#PO(M*WI;6HID^U?=RI=G2&<F'-A<9&-.Q5A?LEO5O2!=&0)
M(U^]DU')SWL;U1HF&"AXY&8&2MOJ^(6?*JC^;'."0R2,C_1G@+&7JOHL\B12
MY:M0]*YL+\W5H]OMJ_Z?!BXK>'=J#`ZF"JS#OC\7DR72*JSL0VB:5K'N-JQQ
M:$3H@>U\7W6*RW5V;LKZZ6*\D=9[XT0O(0Z=6,!,-0?:`)-SJ+U2O:V0NT[L
M%^3F.-B/LKSEHJ3V[+#\J?P_1G0,!JTRC5I*TGR4'C)RJ5\MS;I^A-TLVJ7,
MFOI[\YI[0NI.Q6A(^,Q5TMZW4?5NM`S+#ZW^=^)ORU@/]W?.PR\!]69P4X\:
M#_BNHWZDYV61HHPTFRH"ZN2-H?3#VZ[Y7.7C3?J@'/GQCW!#5=B)FARI;G8<
MF\)W)2*EN=<3;YSVOV3"S)*C<TL:#4W/`(./2:)0H\ER:WM=R`KD9+;&X5Y,
M_;N4[R;UG;OFA"F_9,67(#(W$0OKCCA>E6$'A`D$R[/)`A_A.IV$]V@@/7E^
MD[-!^G#XV']Y!K:N/4HJS9NC?#&34_`K8YU6B6*&M3XY"$J<CKA?&93QC4/M
MAOSB=\<W<Z8@*%^`78R(67T_-1%Z@/<BC;*R:HSL%;!@(\;01<T+J[D4?"/R
M@!?;G4BO&H9<VW&MU'>=UZE*HPI,9R6R%4Z5:8"61R!V*[2'7Z(!S,KV?&"8
M9LZS@O2S>I!M,!LF?'*Q$@\+TT&EP[BPEU(\-SDPSC_ZT_=WN=_\HI9M$1JQ
M6GF(&0')>\E-'^Z/(O*^!GUWWN-'#FOR^B?QVIK5S]?\M$*>+W50:^)C)NKS
M$UEHR5-0M&0(K'A=Q`-^^&DS"2\,V%H*]-@'@Y!Q:UL+4XD&&E^(SW8JJCJC
M+*N&;CNP6_K0>#88-B,G(BZRGCP/PMD[H@UP2%%$D,TDE^9)Z2!2?FB>(GHG
M<-BPI5%YWNG'+]*VZT0K$-'U.S:]_4!;Y3C^23N;Y1]^E#+O#+1I6DHYS@1;
M19&FO`FFO,(_)>Y7Z`@9,]4!X$"@<!I()^W+.C/Y-Z#@!U6@6A6E6U7>3C`D
MD[V7)21C8G\K2=_+D#F&P4IEE0_%GOQ$^7U[`GG9P#"2H:ORTM%`W8GE6*,%
MP')=RA"#'AL0;\T7I%G\.VS>0ES<4-YP/T5:>='K]@X0/#@E]F,=W=7CY:9>
MV=7SRHFF0KJ:Q(R;NYBSR9/2?3S.S'=4GSN7BG"O*A5A?:+[7IG7<A"`MDAW
ME*>NPC3*Y[8%Z=71`6^GMNUP+4"0!(;^O,95:ETT+V?]LR.\SG=*&3'.)2:N
MV2,D\]!<&'O6AZ[RK&O,WU9[_XW/Q][(6^TW3RX6D3,<UH58.".6NKJ,-S#4
M<:<SHT>CPQC'VV3[LOKOJ#X0:D!<BZG&4"S*;%TW=$0^/AQ8P&0DRU\"KH^P
MY%Q:4TGJ!.)2*73,,[K/9RUNY*G-T^L)33P.R@LZ`K9L*^J'L-;N.*QUQ$C]
MI(DY.W&\6=`)(-DO?2PO#='/-%OF1CC+OB<;K-K'K-)/P;"1<RW!1HDU5?Y/
MY)3KS_&?LC_F8IPQ6!5F80:>NII^<N>M%F$FW=$<6"$E)-2[DV=O%41%&_^7
M&SW]5;4SLAL(&508?7%6V;).7[1F*E$8P*&O$'8')!FY?.^_\^2JM<L#N=>L
M(S&SJ+(G[)T]N/F]W":7I0RF'8EY+ZO[-8`TR&WTJK)*KIQX%,0T;;6K`GW<
MS7>V.P;[JR2LW(DVZ/\7ULIEN"=,_EQRLG3,QX%$U`NM4^:QRA!EMP$7M+%;
MBAUHX':JGTA4^T<1FNJG\5#X]J5]F/PJ&]^IFTJ:-!%7,B!PA%7K%.K_72A_
MVM[?:6T1>02![QH$0%0GC96)XB"`Z"#)**!.W]]-:)Z:[6I4](LF+C*ZM#=I
MW"!8*Z#K+=!LT<U.,],#+51XG`/[6;85(,_7&%<^A#N)+W,QRI/96[XACTI+
M'SJO2N2L[$><6/[X-.SV(G)L^&+:CCK4)U^.4;XM[.!7]&_<Q%>O'.%R2#6_
M29:&^'#IR].S-[L<>,^+<J4$4ZD\_>:;QU/6*&WCUQPT:8/,!^>2/QU0'NP/
M.$1!6ZU;]AH9]=&]J?$O_10)BO=EPD^<$):0#SU!J9^44]G:DO)%"UY$8JQ,
M:,@TM9BQ/XM7*L<T2&B9!_U]=EM[S_7$V4AN+@<^D.[B\%P4:/8'/M/F/[7)
M@RP+19Z#N=K&G\\`U`+!YO8[_7'/Z4:2&;;BI^$#G+)]`IVKIO'YI!5@B,1F
MH`^EM%^/B*P@XVC/$//>6FA<05+Y*W[!8#`LZ%'D#:^U.V'8WZFM=.&PV.8C
M_JVDJI=\V@:D<<\VB;BL@?B\TJ%6DK`/4<@GOW"P[5I1U=".H2`'N-=!"[+#
M#'FA8*%N&L#;*(7E0<KQH]AP[%,V994L14R\Y8L9/<!'2K5==A_LGT!F6)%>
M`)<DI3BS;*%8MR$J)IK.);F]Q,\^"U$GK0_:]A#BE'_;\TWF$'"-S=QTDD1V
MZ2&J.;24TIDF'59R1!J2I;MBK(`9X!@,IRRD%S;<-]KW)A]V,HL(`F6N:GX7
MB!5E!G,FZ'F`UCJW4TW=W;%V19_<Z;07-PBK9J!OAC-7Z.^L1;:6L884J^K-
MTZ6MC1SRPP/$/'Z?2[4*[&T0`IBNX;H)OGZS.,<7B$0#8<JM)\5<\QCCXW]5
MQD#O3$50*0PO-^'J+DU\;Q>\PW)99J\O'A(Z-$QAWZ5I3OTELX&;A`L7IKTH
M"JF)C&`@?006`]GT.$>L4_;6.+VZ*P@H'0LB%8"S+_N4[5Q+4\=7)V5.>=WX
M`K@%B,RN9YM&=;2C45$8JN(-KU3Y^__>Z,,'O8RX23:962'Z,VE5?:N(1\D4
M=NX:!'6XOO.O';>OQJ$QCTU[0=:*FVU"UJ(8D$I#U(XE^W&#VB#(!+*!)M@P
M\S&4DZ#%/PV_`TU$>B:<8DSF&5TYD[59QD:_&+MZ=I-=U4?L"Q4P-EEXX_$#
M]0/7CV#:0/-$_U>4D"NX"L\,-!>B\<M)#,&A@HU7%B&(V3N=T,>1Z0LE+_BJ
M`<(H+9;`UF8G]I`*K]2FE\?UK2JAD>VF^ON-2$!_N%];PA?[CC3I3I^/05F4
M@(PJI;;N;6Q!BKV!.+MVUNE2W?:_ZCB$`2Z=,V268C/>"AS&_`O[_-]41,D1
M&<-=&#L-A$JY59[<T%!XRTKAAD"\G-+NKS4R1?4AXNRDN"&T&VV>TF>7H[7Z
M`4P^YYFA-5'<8LE:-W31=:DF^AIPA.UNF"A,YX31U>0-#B>ESZX5X>TA9FVH
M&K>;.>*X_<_>4%$3-B,:;1//>V5^%G*+V4@WTYB5.$)(8I8<TKW1>L$8Z%.6
MNZI?I)K`+$(W,U=K@!R[">I:TR*1\E+Y:HA6LX7?L)>TPU.USCY.LC_<R>RN
M"R?,E2H*Q:04FW(\=+YZ>")6-0?UI%11UM=JA%=0UO[BCDO)L48-SWJ]J,TT
M3+@M)#"SIP#S;K`WQ+C!3Q,YKKO.^PJ+Y29>8#A'>(`N?6J0!A54&'ON:PYI
M#<)!NE9\XAU(8\=<R%87VP3D'`5Q@(M^39^[Q`94]9/=8MQ_THQ]\:2@WX&A
MN8$E)1<@Y2$;2"1-&%%;95$6.O9R<#`HX;@3Z#WVASKR:'#]:59)II[(LBHH
MPOR^>:K9..B>FW)>%1\>!_/7O%63'#?6$U]76AM22<@=^I+'KW`>%>Z7#6M\
M*,5:GD=8"/B%K&2]1MZX_75QEXTD"K!0+C<Z=QE9_JZ+"KG*;+QRS\&']EQ+
M<Y-2_DLCS2C7W+(("KS0P/'7JHZA8]R\-`U(A.0J7]Y@QK_-KR9'(+4HD-UX
MWO:-QO3D[`JK&&'G9P$4/E0#>/MF<:4/+P:AUM^32%]$)DBU%@ZG@O`F24G>
M8<*0O"CK$A@5QK:*]6V;X9]8]1E\-\Z[CZ.7,M@EYRPN)%OGV4?MHU7PO_J$
M/ST.^.HF;.AU6@//,H;36`N9DLK4UQC$K84K'//D&Z^W;N&QN=SWQF+FA18E
MN;1@8/=/^L_S9RLH%7RRF/#9`+XXOO3"ZB:ST9V?2>I89+F,C8MQM-SJEYZ?
M[I0WX<+(OS/$>VJ[&^B66@-;F)0BDF[;8\F$;E0KJX,Q:FL55,5%;5-U\42W
M#?^*VK.26XW3_Q1&V'I*/'%.0?U7VKIF">EB+4L_CI3(N(Y[TT5QM-Q3U</7
MXK)_];$($-)O3:+T<5;6]+_`6^],:WA`@AF6CN8'2AY.#=F6J)=0NH^BQJ\;
MG\%44H3_B2J)'$H6VN[T*4':8`2ORW$ZSU6`'=$/K1MPMTUK8LI*=YN$0TUM
M!8)U+UR;R&'=RE&*#/V"C^]F#F0+C;UH&W!:YTIB1%C:3(Y1VB&H7OKHI>IZ
M,P%J<?*HMUPH9&V7@P9>LD3$;W_SW0=Y^D7!]+UK;\R'M/KDZ4H4@'&,IZ7C
MP(QB:(?PO-.RDB;6]Y%81S>O36[^UJ]*8SQ/@LE;H^0>KHAP+09&[7&#(JL]
M4JN5J(O_7'D;O9LDTV=B>VRF=!<$=Y1)XI?DY#[-<I!PE,'E@H!428;IO:PT
MZ4!0.WQ4\A<)HD<(\2D18U#&Y^Z$$;/]#SWZPQ(UROT@V@7J+H16`#$.**;T
M+J4A,ET\?#[+!T'%,<W6B'#]$0`;,'4;]"W;D&O%"%@4!&POLOEQ7085FB-=
MO./_IT/UBUG?Z4RK"SE#,E!Q"25U>/C:I-UU4Q5]_WF[0%'>%M1G,.Y\N.TU
M3O%-ACFA@>=L<G9`"@%69*ML_R424@9GA<E18S!UHR.,`E6@LR[[^2;T^26P
M;S=.TG;"M"KF?!LIO89U\Y*\NNW=W%;'Q5VJGUL$3WS]#FSP0W,D^%5@)^<E
M[H;>?$71-MK+;>5>PK.T'A<X,ABO#**\^WJ\3;#0R;8ZY$`HJ]4$)5H+\(#/
MB^UF`9QNNPJ./0N]T(=N^@3T+4O-I.C56\K`#P//*JH=>00Q+F-!ASKG!_!!
M?&9*\P5(RG4$`J9D+>%;+>B?C`WM*1UL4/]$OXBR./X[I5H0FBDQO5@/5,-O
MWO=@EAXB?"\64U;%U:^IYOZ;1FM]^CTM"M#]D]=88'HRW-)K@Q7B)'9?E!Q/
M>LEQ*F?=DZB,+P2:5+Q$9ZIGB#<C"_,5341CFS9L,,$BSHP[VM_%X26@(,.#
MX>*Y/44F.M_W(>6XO#SZR#PC\X<-^KG9DLU1L!(]/$(CFG@+#D//G29TK0S\
M!UR(3)N*23&2_/F0\(J[)-";,/%=R*E"M'\OLA5IF%\%-C9@&UERL5B!PU#U
M;E_=6YQM1FDJE3'`N8<X[F^B-)8/\4)E<QQMXBUT'N\#<NLP>IQ2"7381KL#
M*O-0/FR1W./5C1M:#!DF$XRN6<<=00&8V:41`YYD#>ZH+I2YMG;_D<P+1;Q3
MZP2YCWXD+'V9QZP-R:`#2U0G[L3HJ/26_OZBHF]">L]U@8@W/18S_[C[5_#@
M0(-\8$BDOSS5@_#RB!X2;+_IMEWO-:!"%_E93P?A'L4CD7,N46OLN;RO$=)5
MMH$2+'17F,74)P_W99XJ<YY;9!&TP_U.5?^J$?"`%Y)_4%NM38613VF[\A"+
M;T&2F/]3TJ-9KRN.LGPIU8EP$M:Q[2X`UW1/",;98[+G!J9;SBG1NS=<RM/%
MY`KWC!\-;66D^(TKDDZ`>VDR(8%L$'Z0]9EAY[8`3,(SN"=[0V']*0SSH2S*
M+K81_2_!G@>IPI''J6D'[@MSXV](:6D<WTB_L@"]^&&-BRM!E+0YOK_)KW0.
M/`O/*5S8QJ<KRE/#O$QUW`K'<2.YX;R&>_A_EA66<+%PA\R1`2!`"4E]$J<8
MC[];HB#LA9RS&S8+MIJ6%%VXX/AU43>L"0QJ:`?<_P`PFNWK5K4'&A98G&+F
M]_3NSPSY?&DJXP2"?QF8>4.$;:DO1C"S@W#H.)H%3Z7EJ@H*>Z'9]W^TH+>*
MC5-;JESXA,ZBEV$K88K8=VDRRO^W"JI/4:21[(%DMYLYDA=7T-.I42&8@+D3
M%"I)?647^.#VR2&!WDZVBP$$J;V75B\'I!PD].CLNX*Z*<C!WD\J9-D4SAZC
M;(#)_;KX%[#KL1?7G>D8Y?#8.@-WX7&&WY`YV?WR$$?ID8&35W\%K!W.9A:S
MEZ2[HJT[8!9*,)GOIV`V!36[A$PQ*ID6IJV8(-P$Q5-""K8TT9J,\E&X_5U3
M;<^F:'_2/^.%MY1V]<?$`,*'S<YMO%AQC7O)?."/%?;+J&9`KE7^/9GZW6^#
MOWIM9T^9#+"]7<_-K\6EM\BW#?/_#6YV]]GLCQP1\VBKW7'4(<QZHMR_&*N(
M9*IB8Z-JFXTM6<G>]'$CX5=X;]O.GY,@-T3DEMK)R,$!3#^F#E:7[O5?H^[4
M>);&B@[!\)?>`V]=_\N3EM\_X[.H6M'^U.>R\?399YK&?-">`:#7E'%[Z,?&
M1#@F<+GU;_A&DL\-);$";."7U_:E+Z7^WC6QSR3(@"F:0&(1-A-JA!WV4/,J
M>H44KN?KS+V:D@NZ]*D,R4^2_8]D"'4N180=DTY0F"VM024W]\,0_A@QI9#,
MAC!)BEWP3JOP+Y;0:L.$DT;[YWGT-XR(/FZ/?0E5_(UX`'R%*!E"$JOL,L:+
MENP6\R+M><_6L%RJP5IC7=IB2`QN385625[]E<X)[3;R$$_M&!/#:;YN:LD]
M_1_K[0ONQ*Y+87(35QY+SI*6^C``=>I(NA!5N=?`QGLH+G8SJ:0+=RZ!:&EU
M^2S\A)N15'P(&>!:,>'.143H*L;.89RKMDZ$KI3)([3Z:X^%?;=&2$+P=U)W
M,>W?2N@3&T3HQF1:_J?VS2`@P?LZZ)'Q!5!+'>51=RN'%D=4$4E:3WYC^^,4
MGK1@(4B`(;A16+TN7`:!VY#<R,F+T-E$Z&*0Q#/KEP<JQMIAS5UAS=\7?WTL
M5<A0&>0MD>XF0X&6;L9)G(U8181_"%])H9/?,24A@$95QI\E7(FX]9I[24S-
M/3YX>*Q_CC/XU6=-,Z*@!!0Z4GD(,ZQCA2EE#U,L:*2?F&C]<VW@&PK=I6R7
MUU;7I$LN[?K&MRC"]3(@X3?(Q;A<L6B()/VVG;/?`RA6,SC`DD00%R_@V"46
M/_%U1O\]8Q%8V-M=!D<."9OF>&AH1VD]>3G2P@?6&,(Q8FW9,'KW;!R(91PW
MW41P1R:@(B4B1SRW3>9@78Q.":OO%5X2`5D&R)3K:O`YNC.OSFL92&:&&)BI
MZ9!ZS4O!;5$!^(KA/D(S&&FCHV1R]<>T<&HY-(BGJY^W-AJ^.9QXX^S;[W`C
M,@A*51W-V/%0TA0LZ\HF-;$PXKTD,U_C0>]A[/^$/1/HJ_8T-[?#8BBW#S7B
M#'+?+M03W<:J.W;$@]KO$`LG&XW#E+5*RB>CI8ZU3HJ]1*DJN?ZK\1.?MKW'
M@#?A$^X&"P;__ZLOC,"1>(CY&Y[9O#]3JS=""N\<F0$K>^2;S@PAGNF*/%NU
M=2*5;D'<8K#"*QG,>66C7ED`#'ZU/$*!*M[_T^`IP-3:%`!YIN/&75-&K:4/
M_N.QP-DEYX7\RY"'1ZA0@I$+HIZ3\N6'@L^T-7VXM8X0E)N<\`5EBTL:[&%:
M>RBQ=)2<5>O3XUD>%[P3LPI!@HYY((LN&_!2K83'RR[RN!"9*'J03PE/0+`T
MMUH5CV&%*I2BE0S?WXJ"``O",2>B96IU\J&V))SP7B.#A%T5B)>`QECG@2F,
MSBQ7*=>O6'4(7,LS^`\!-)A7VH-WZVC/:XH7#/X@%UP)XA'PCXTJ@@WBUFA6
MH8I;X^GI61]5=AA1/*3[5^SGRKSWE_.SLXHRZV4!<_;MR,;.H[">Y+WAO%\&
MFZ*@5G.<\X)SII:V'GI27/`[',OSP'*P:``4-_]/8]`V)D;ROLZ&(&YAR[2N
M]G/Y+S%Y2/^;Y$BZ*=/!]T&LF>Z.'M`85<.EO@/?S!#1Z",8ZPN`JJFJNAA-
M_ZW@X'1.S_J\!4-Y'LB+GEN]0VA?F=LV8A80BU0:*?R0#\GS'9XX>$HXAJ>\
M0XMI=U>PMX^,GE)Y,`H+NJ/<&9I+Z0^=0I(5!0UA30T;^Z_E":F6"D1G5W*S
M4W$TZZJ61O<4&(S$XY?@"ZF@(*^80RL1X";(L(931K8^S>C^^E&C!7CP$/U?
M&C?9?OP$XE*LX;32W,],_GRGB8%KL5=&%`K13+`L^K8/VM:@]A0K]>%>%BQ"
M_N8:G+(]Y!>QTK`_<9D!/U'Z\!7(CG)@UM>K%//3PN15&)4T.'$*U\Y$TEUK
M)+WX+=YG&<T?#@TCG7J/6$40T87_Z[<AR/W`5],VOL:+%]I>3]'V\\S(U3^$
M_2VX#]8G_-F[*S08T_SF8E(X)SY$ZK]O"X)F=[VD+!$S$*%?>`*DP0$&#[>I
MT9*6B)9&T8[G32%W-'QB$R!DY0S)^)7.SB,._])^^U:U,.W7E\:Y.$Z3RR#9
M4I[95-)P=B6QK?QN"5(+R\8F>V2U;Z+O\2:7E86<!?*)%5A/1KG]A*P0[S)B
MG.4OFE<0W<=%_(^;>SV\]2($DJ';<!QO#6K$E)0BLC?P"/^-3B^.CX3^D5T4
M$]HYL]J<.EQH?N)*?0^N/Q!RS>GEY9/P%-:NE8$0=5A_?V6(N]K/0+'?/IY/
M'82U15382MD-)B5'/OR/F%=L^1Q5\F#VN,YK??_DP.?DV+Y@;$(4#]>S)V+&
MW;9#%O$`<A&0D]XDU?5QB,B&[0+VUO]`(YJ&2Z%UWJ$\8RGJT\V62FJ^H'WR
MMG3Y`I"W0.=G$J(CW\5'W*?N)4QZUR6'8Z24]X==XQ6W&&U!@$2@'Z\M([&%
MZ(VD%N*YIDS1N?#C0[HZ`RP9[MXON1`FKTIVBF7E/@8Y0@4R).L<!XMP1[L[
M[X-9W'F,16=2E.ICA[-;]O^U*YIW)RJI\'EIY.C8KW)]KSH*NQQ[7B[`AY.+
MI-/O7?.C;"";T/YXW,H0]CG/9:Z;1:>W>W\M0?G$29L,9?^27O87L>P7K*H>
M]D,UR#QN27IHB]JPD/2,@2=4M*3HG$\L^E]X)F70Q!)Y/95T]=8TY?7W+?Z?
M(S/;19YFJD]5>SD!EF\YP^[O\Q\I$-@4=5^M#50=SW$S*GJBZ+"VD:C0=+$_
MG6O!-'66BYS#L14R"8@,<'7NY'5OJO9VR9K97T'EG*#K].MNQZE?Z_""^*W\
MG**3SM-#G_@U+[Y]-EGIP^O"+KGBYK`[G`AE%,%IIKPVC)U&Z1"_[Y0:*SO<
M4ES:'Q>9&+;"6Y2=H-$S.$KPY%Z]:F7X\+K>D^%MPO2]=5=$R6?MY#C9`DYL
M$GL\-DN%=RP:1QWM&WW]YVA^Y/`V$$3+%H)%EU.:)>SW]F^@;Y^YYJ+@^B8N
MF.`).W`#K5'[9M^A:\9AM]C?FL`1H"D'+"6Q-D*0UP0DN"C+8XT3EQ>$A?3Q
MG:SH2EU"]+S8Z1T,S9,U/51]P5"%U:JQK2B<VE%S-H16QN3H9V#,42PMX.9R
MI[BB$:DS2H`F$QX]:CHRNWY;H=*KF?4J)`?Z?[RNA*'Z4%.\.L!0@K#27#5C
M2`*F6:=ZN.:/6@#]#<1.]7!-G563UA'`'A'M+0.&_'3I\BX7@/>SN?)=544]
M,4"%Q5["C]3,`/Z#N?\:]@>.SVJ[*Z=[9A+$^!Y;`C3H6[]4,$L7,@4A`SBF
M:K"WH=J#8%VA_7IKCB1Q^/3DW=$TTKZIHH48:0@30#\^PS["+/U?^#5,_LMF
MUJVR39&OX>K'WR-.BTWX"6_[V`K)S'L#5'1.F1\>NLSR#0@70V>)FUQ0%SR5
M`\Q-K(-ZWF>[DQQ&UYN1,.-`(:&I%<EH*;3OJM[A,UD.QT,-(TU;%,V%\#[#
M,4$]%GKE>`\YHI`+B0H5T6M62JC_WXNS^$;I^O^7$;^&7^"&KICNFG7W*F=C
MI`?3'$36,<7-O2FDGAAJV(O[%)<+KTP-GCG5I0%)\2'%&*'8*;+F-F_:3N6L
M`E]#"8K.X>G.[L&-/]]=(RB$],#L\H2$\3F.$!EDYOX4TQL!:%]\D:7^K+BF
MY"<NL0X]NN<XD52UN#=NV2S?I+?]GEDS9(EN\;@1KRR^#**V:<I:%#CF?L0?
M8)$[KBAZQ/8./6..C/79^H$C=2=)RK0XX1!9DJ4*99=:VAAJ`$/VA7,$4O3S
M.2DH:F"]E@J`^%:$P2'JNA.I]L`N?H-C:5-S3&+&R.(--+2`Y-)-:[_7`T,L
MD=I/+"85QV)/[!MD80ISI!L"^"V8T`?VE,%INI2(%H#F9F&!=_KX#L>UT[ZS
MG4HB7>%/3-9B=\EW;.;[#K>$HRW."7'4^8:S8KUM.%_3-889:S(S-2?9?;`.
M\)@=`2X$B%N[@$:)[:EQM'5_#2(]XNJ\H&3%"L%$YT+6<8X54:GX],LC7^*0
M!8WF8?B0F=AT;2B`I`F2H)[C1-L`+N>6EOKY4-OXS/^CGO[^$@Q>PT=[.70-
ML3J^%,8MA<V0VD7F6LO/5XOGPUUD0L]SX,_<LS6!TXO:./.,)CH[9TE347"%
M]*_Y;G1H@0Y_7T0V)P_F1Q4$VS!$?AV0])=-$RQ=UE?BE3D`)[6Y5,S!6@*E
M.H/#^C7]W.ABIQODQB*8EZ,(@%F$]L`'Q!T..NBJ)CU8G1VQD3S_5$M0FQ)J
M2LAW6-#^9R2TD&S+M[8BRMS+Z\;+T/9A@NV=4]FX%EZ%ZV.3$*W.:-V%;OJ#
M,%D-)HAL[>U5T*?;]5.*_#<_DS@>O:"MKX1-FZ,PF*)Z7#59V]9_L>Q1"XZT
M.^ONI/`K:%^*T8NH%LCO:,*^S1%<9,=$,W78P3@+:*PG.\4N,P)JA2@7Y5_7
M0QVJ%ZTKG_3;1$"+%-"D/;T2/W4;)PZ\Y?;JX*A97+-:@F*D?@NX>)8FOPF"
M85.!RY[(Z&REV`^U>G7<GHA*4P:J5RVS0HETWK&JJ[^I1/EA8<;#"[<:;*^#
MQ3\1A]N_2++,`(I$BO!J&ST.9\<(><D$#&*NSQ`KX3\.<V$C/?BWS<UKV=1X
MFAGZ/^9U%`8F8ZD6LB71M&$AU&MR5\0/FD`^M>2%UIFW^@]-DWCRF)H?3%2'
MN:<76$X%.!%'30>DB2I^I^X%3ZW@*C!G"5>YU<T2#BC>_K8VW`DWUIGJ9!6L
MK:F,;&D,9+0GI?5,"?KI'F!&[[:_=[<_7S`#>.EUU,/).RJD$J)K+0%=6]+5
M@7)L:UD?D!AL>^83$?Y2(.FQ%E:703+?3LT!(-I2L:^:OS&*0,-^'_+63_FD
MK2G/*)7/W7,^=\!%OW-=B6'!IER(F;5RW=X$.@#@O3&^+42IQ)C%8YO4DT$,
MP9G_FH-*BPCD9C2@)6W(H:,GTCM^"L8,?(?;#J_=^QR5!VNH*5WQ)C@*IU4?
M*^PHCE$J=@1,'PEZRM%KAD0'%*!M<E/"J.\A_5`V'7IPI4U1.CV1.QTA.%@J
M?SR1"5GZE(/>O),D9ROI5'>-HH^VTV?H8$M.`U%F:1KN=N/&UKYG+E"CVGQY
M]_7G,?YV??^.<D[3;QO%DBTNGT.@(93U"9H75#4O;?6<),;Y47.@=Z4A_J6T
M0Q*O[308ZCU<:X0GL"4RFHQHM@4D,!2[2?Y"=8Z<2)\X#U&%NJ%`8S)"2FH5
M_=A_980T/XM:@0P9K:8773!.R!T0&-779[+-`KXYH.?3,A$X&%4.T[@O$"TP
MMC5A%T;/!9;H8;-D9)A7@$@1LZ\JBU<S):"RE+*J^H(/XK8XTLLVS0?E7CG/
MI3W!4;8VXB1]>:<>G^.]_3%ZSOGK'!;V2[H&42!00*FR7(V,3T0@B^F<-X?B
MAF?3Y0@G81/SHS:(I]7^G-E<07;8&AEE>&9ILR-WX*14JU)&#3MY6TX[@XCV
MU5GO%Y@*%M'S=$L#;]E>W\-I9G:K&!<?-`,2I>8"1Q(V\PJG3]+$\@OJB>;A
MF$J+UT8MD)C1%WA#OW%BR[#WV04'(PUJ&3[DZQO4V$4,;L%S'P6G(33W;]WJ
MN8[5`T*/=-WV(IQ*H4E38;ZL5.HR*?U,*Z#.Q[;-$:KE#[Q3G")$#(DF&![S
M/24`!,G?VEUQWDP97-G`FI(]\):+_(R</4IA/R3W%^FP3H%D'<$>3FC4[MF:
M@_$U=H;/PSP8*+\T#'?"=AZG$)D>VKP&'30U5.+0&/>V5U&1G1/D'KWLGC;C
M?MA6C;8Z8'O?7%&2`17QQKJ:CZ$&?$!$AF177\O7`<HSQ+O&*QAT3FN\L;W8
MGV`F#QU-<=L=99?0Q3`DCJV+0:R6DR$[UE)=.UXN`&==-3U[$Z7,39V%]]B$
MN.P_KI'5QY.8(\8&P_%2IB\&Z<Z[H3OUFQ^KZG/N4D=)1]#G(?,&=VK.GU>\
M@/,]%P\!A8(Z&R)E12Q993Q6=[HI1T2-,?NEWAFGRTL6DM(&A0)9^!<\*+"0
MXV2Z,JM=B8##!PU-B%&M0Q`83&"T#\\+*VI.5NT9GQ$*R($Q-I8G"1>E@M)6
M".G+$:#X3RG]5:7YD@W9A=M,!5A5=01P<N?IVU>WSY[IH2HB`"PKS7\?X^GB
M?/?&(26O"S?#FP=X_(CX/66][9-7;&2]O&8VF84[I=#]BU!!C?$[YF.?//-D
M8<[)1L\D6R6?5MY?=M868?3ZD1L`OY>H-U!A#D;1<,&L&G;09VW)@`,.Q,W%
MGA7'6.2V5:N-X`[N!&M?!F_P$<'([A1B"',+TK*H!!`5\9*-+A3_2"HT_,KE
MC>\%HRMPC4:RBV72Z1!U/Z+#UJ1SUKE-B_)$;1U<N>1+2+Z,UTI*4.9RCV<V
M?"'1X_LA9N#,^2F2Z9:UG-FST/E:`[_Y]G;%@#9`YUT!@'YV+#1)MI<L^0IM
MJH(M-%IF2[0G]1]X)-/U-3USE-L5]QAINOS5W*:Z__LH3;4]KYY5`5C@4KO2
MI'ZWG,R3^-L?X#821H3/O)1`?"_M`%!)LZ*-#JU;$CR:*SQ/SKC1G<#E.4R$
M)6CE"[]:#>Q([#_#,2].TSBG[SY1<N`T"4)KCU#/ML5'3=!44RD#%^`^.^_-
M)\C,R]1#\T!;,KK$EF+S50:+JX5OW'W"G6:\[4%N8"+^0O(VIJ!R'EU6^V/%
M69LJ>&PW2[P9Y8B]`?F1&AGOU9;L@\%93>N<*Y-M>;3'EN$2`,%%MAH#RG&"
M3M8<8Y2@O/4,K4\\T,@@DM]+2:1FC%=0LX/+3.N1+(22I:[4O[9*PTC(*VM$
M_&4)S1%HT]502,,0]EX>A9;R$34-IU&Q,6[2/_#T,;QNA@9LNE,2MA`!U#HM
MB^S@@.W[WA24^*H*O"?T4NEBV\#&<":Y3!CQ5G<`)C1=FXS<-J>N'+>FIEV[
MKC:>)F6<ZM4]9N_L&U"/HGP/57NCS\/7>&H_+]EF3QH'#2U'^LP0V&D[WSTA
M;@UF"SD8L'<&27ID_>#[&>H6%=DIKBCU4,'\0+3X%>1JTM]HIX]+$0UW5UKX
MTQM-7OY6+QX^?]\(DZ<0,ANWW1J:N[S0A/FZ!_L&TQWULOS,M8_3H$U44Y&`
M;WM;^Z.K^9&&Y+8OKJWM8[>S%+XX<(?17YG<MG`5AS#.21NC8VF8>L]J0$V@
M5`7<*.\,_T(#)(MC.K:[;8/YKM0U)<R:FS)=OG:X5AC9?S`/4X*_VN)=5N:[
M7`U.+79[&_+&UUK*P?+7'L1QM'-D`D"D]&*H"<UA+X<P@+]0J3X(XG):0?"D
M8)Q\ZV5:4+=R+R$*+_3_J-2P=0+-X2S0\P4Q0LKE2#9(;^RIC3]$6%RX1GZI
MHXXL4(=%N3RQD[&Z.$1N%X70J;5HE'_6"J816+Q^RS$Q#[4=<)L=[,2XJFA/
M5?QC&H>>CX2]FJ1)A)5N_5XK-;E+)ZVSQ^FFZQ_&4^(/2[S^\<RB%DC2VKO.
M7WCW[^$G37Q5R)+7%G1?GGT=[1WQS/B@1"OG..&_BT42/QMX7@Q(*DY@-/AS
M(J6!PG1];>P^0=CAW2_3!-CU**DG4@6\*#D,%S<MU,F'TRP/=_QZE0PX*`(S
MRU?50@3:BF=O:M.5ERW3V0L;4Q`=O]0(6F)3JKR0"*OV6+7"LY<3IV8-;;3'
MJI\[O7&,1"Y97**6@DF%WS%*SFV*G$;!Y4ZI05Q]%@OO==XM[=]G]OIQN$+1
M'N0*%75U_E7YE^WT_)W1?_5$B@'TE)\)2Q^82'P$PX[66B:*IY>9<12B14'F
M%)&$)'1QT%N\="V4,S$D6/84?^^)#$7Z<A\^2ISXB0SP*P+OP,D:Y0603WHH
M).G[4X(W$:X25Z.9I>G.(&/2`;J$EDT2BC191IUAAYN<@M+`4"4R"B`N(\T/
MM"_J25ZA*P7K4-:E1GIY_&H-JVSQ<W0UCV==PP`5F)G0$20:\;W=$TZ+96#Q
MPT0GXI&[^W(C)'<*(IN%;(,ZF9-!AVJ+$$)'\$&7DOT9[*T3_O#TW7GB%%U'
M=6EWH.67MWC7<NT`R'_>AV=1?N18B$N9B:VH"`6/Y)_L)Q#6WBK!VL9#<@]Z
MB-OK+BK@Q^@EAE8""`AZEC]A4])/HFFA@0#]=KS,P8:*B1/.TC4-6C,?N<P:
M=!P\*_R^6LHH(%Y%I'8,+,3(Q#E?X-07X6I[QR<,;LE)LR`L[C<<M[F\HA#3
M\8.?`OYM`-_PB&SX6MBZB>US3.UR;&ZZ6'4YG(@6G)%OZKA2+V!G6@T3+_H(
M<&^XG!\^G-G+Y$=;6'8E(2T<YIC*@+T1^XRHT;]K(4,=W*)C>PU(*QX"%H(L
MKXO3YED40\K,V"H@J!K;_:2^89;/_>L&:UTHN!-15[\]G*.R^37JZ];/?-FT
MV@2^6,V2YRL)"$/K<3C6QS^4PG^)U9&:."JR,P8?8T:.5RL*$+Z8:O:0@D`?
M%ZH0-$FNI236RWNG^].TLPSUY;+=37D641J]I80OAVG&8]A[0IH2]K,^Z$[(
M300&`.,'0;I@D!HR@SMLOAUCJDB^<ZE$'*QMW=T5:FOGH6UK*S=$I%\L"L=E
M8:Q#L&S<*4T[L;9(+*<1(.4K%FG2*EH7RT-$WYF'QYOT!__0CU!3MBW,FF*W
MN<FA&:"*'RTQI/7G0V%<R][*[E;C$8V>Y5JDK7MST!H)7&?7[5].C"=5,QNP
MW\36>`6DX5<]A`_:[B:383B8$F8*TGK5YVOJ8GG8ZZ@2X,)H#Q]"2(0%^,R2
M^;@&%#ERZ7BH?NI]&X#3JYQ?ET%"AO7/`OBE:.SCM+YANAVT0X?\'[+G44Q/
MZ-=N_I!+)C7EYA>/<CJTS+LIXVDS?Z94A=BR$,K,U$6MEZ%X]O:$Y7Z]HI*`
MQ*H<>-P%-T\29):(`Y#&"7OB`5&DIV<2%=D+[7P,GTU(D(H/?H")H[KTMG@J
M^*#R"AM&0G^D5WM5<)C56L5B0!3#(VBJLX\6I9A<G,13!*E`J16(+XI-XV%2
M.0"TTL?%-R`[L21"L8Y`J4.(%_K/OPLZ0_X@;2:IRX1@_9]^YWHHEHH6=V,3
M*2I&&1;.L9",JX?NID&S\_IOPC?%1G!/\\*-9-EX+40&5+@J<@3"^NA3BPY%
M__$*/VOA2$<GP9JCHF]C::I++W3\)4<*WER3XC,(K)@B4U7(,7`;1%2P.$?`
MN`V`Y_4\7PQ`!-N2^4"%;11O'JF@E)_YVDS4P9ZS>$XNU"L4@^!`.U<?L[[U
MBEI/+@8__ZLT25]YA`C9]O*4;84EZ@\ET.:9,2`SZ`E]!-CW8QT6L)NPFE?A
M<HT-JN/1RQ*8<H(9&XG';WPP,%6NW#O_09+NE1++<ED,0A;+]XI37(M`$B9R
M('-:>)7:;S6X.4C!$.FL&"#$15K$-YY_F/P>BD_!`L&>1;Y:HJB+;Y)8'%OX
M2^:W9WT,8M;[7ZG#!)I-Z291ISYJK>L4'X@&T(*ZFOPJ"0K6>B*KEC%>S#RG
MD[K%:`K+U=%%J>BSN[>5^&&<<]R?DU8++(Y:/]TAO?0T"="7((>XW#%,-<`+
M[EQ[)P?V&U=9Y-75-OB`TI8M']`F)9]^YVWGA<YKY\$\>LSJV9]EF-O+R`C^
M@S$SA/WC*%T7U6N8WDZ!MHN1E_.>@'Y#(N5)"$8$*VPB&%M5&^2!\>GZNA$K
M.N\)$(3E.<D1]QGB\^R&V-9>7E\GMNUJ-REH:]D`IN[]<`M)!M8&";9JP6H?
M'#J&Q`UI:W_`23L:`*5M(7T2V<;T%%!BF_X18`8D-(=R`2M$7,1W,3">^KR$
M[(PUP1J<1]DIGTH.^@W?C.V47!SA6&_BIT"IY)F]%/Z.J^H(/;@,&5^<4"&7
M;Y'R3D=B2?+/%L_<F47$@)`^IC0.\E=[""VZ8'_:Y*];L7D-F!ASKCLV;1.6
M4ZDSU]1@K//(4O@L[%*N`7X@K'BL2Z]F7?9^?_+NLZ*TBAL^HK!M-YE5S$^6
MIO(1![:%,X)&3/)C$'>X+>&#4FY<37DBM"?8>+)2##7,.HKSE>5T(;;0_?PQ
MK]-PLURB+"]*8N\G@:?^*V;Q:SFM)Z_+TC_V;#JE`N7MOLL?BJ.:83=:#_%&
M]DE4:1#__EOZ]N1318Y><)>"<W6?BIY'&)E#IA5O%&-#V;QXD&&$7++#<K^=
MIGWV'^]X$#5844=5HCS4#2#B+6,#MFNX)UY1JE;;[#X-RD)`1T!!%\/OOD-?
MBQO3H'D51LV*,;U+H$C1R.ET.R%G=$RKU4>65(60[JY94LL88=BQO<`-P42X
MO@X=W6QSL;^32]SH?6A==%81^5N2JQ:9,XUT76I-WN%5>+Y@+FAYEVK(PL!=
M=E'%=)]N\U1D2+6LP$0`91JK^>V7$^\20\N"`T/H*=>8KO/Y`/SYO$>'E+$X
MCM7VL<"FD)\.+3T0,I3N-6QF+V"_6C+!#7D*_ST\%"Z.57]F?,(_[/D;ZB8?
MJ0<2<(=E*%J.5@W(#%`$>NTKEU'KCSXEJ>+[@">8/H<JK$G)&L2O<X5%90[J
MND@.?^EH^#ZZN!F+U,`^B/@(>/;B^R1$B6:I$H=JC2O=F:K5=12`L<[)K2HT
MNC0B/UP;PIX=$M%!WYZ0-B^XZ+PMAJ<-MQ6/M?,MM#$L0.174=VPDNI7N+.6
MK"EZ,_.IP,@:?N4-P9/0>E$A+8(RT&>;FB.,W:B.X*1V$3O7+ZF:_]KY(:L"
M3'R#\_`!A.)D4.88H*3@A=+0GL&>-IRR4@-6.>&L9O2%#=/,=IWKDY:`Y#*E
M0@@V:-4;$OP^,[Q(GJ@D/&'_L!)3UM<<DX11&"B"O^85L58=*PB"P)3;21=,
M<IN[\D<BP58?U,_Y#F%R"96_.,>K)L+E?>":/L3#JTFJSFS5G&"V6<_0N(Y2
MR.$CI_3,ZC9C5HQ[`8P3#1F:ST/O0Z'+B2-"7CFE&=91?2'7UYSEJWO.M\#?
M7G^2*YX$2#J9VOT?;P(1]1M?B"Y\B+X`6!RG8A)-GHED:B<;K.RQ`13CW;0G
M"T8X.MF:B`70B*XT\U*42>V;HPA'&R6QU79=<AI";V&4%2JQ0.$&AG02F;IT
M6F%.H#05X)E];U,\CX0`$G=<'S0-NESX]C)K;H58&\3E;#KN^,%-:-=ZI\SW
M(>7M';[>JVM1X/-TH]+T$IR,`@IS,H0P3I@$O5D</PK:#*XU,FF=:`<S8%GQ
M0"-@1:\Z`LL!]GKK95)SL(3'N;H@__&)OQV0P9&"(LKFB@7<1LOSA%+Q/LEM
M*9(@&B7P'/`DT/MZI`ZAA1\,F5/<T*OIT4_W+`>>^!OL\N_(]+O:3WG%@CDA
M&6S)9@4^8`UMVNWJ=_!7>)(9":UX^./6"I#*[Z2MPZ*G@.^!QA&;07AV3QV&
M0@@FHY84GNL(#$EPR:WWG!=+M#BI6^-%J2R711#C;:]2-D#K,GY#QO6NS@,_
M437LC"OEF7A6ZHC#0#)"0C<<>>W9S-`L-;+>G8QO4E,5K2,KDJG8,D/-(2B6
MK1E9LQ<>6OC-;>X,&TOYM90'B2V#=_%YRZ!&1%_&YUN7EH&[K\(Y%@AN"K2M
MV<,=,90&P_;HOB,=\#I-PR10O2UZ876KLL3ZK$M/)$NXG1ZC<@O>_WF&W5SE
MVA"7.;:>Z1=CME$.+8_RO+%,Y&9G"Z%U@5Z'IG4":Q7)_/V-RM<;^@Y:XFX"
M&\_I(!B78GIJ'!N_A[\>@B=T.%$I$DXUJ*PC+:HC<!H-0SF^KY2$U3&X'!'@
ML`"/9?VAWF9+,)7'<M=N!V?^'L/>(&B>54K=Z:;9P`*7>1=NZH;UK>NL/L1Y
MSU=4C6M%/JNHX#,R!BV%#]2U72R?S<Q?5ZUV)8BE?I8L7=%RW024[!HU)2-O
M!&'MCC!KTJN[-\`B=:,MC&D\(KA_(XI9Z;WN%$4H+!#P2S\PQ\X@#BYEQ(B`
M7,46/I(N[R6;RB>[&@_"ID3*3^-QX.)+<I!E41KK0FC<2G'TKW736HI_[4E?
M)%$R[02Y+C=.\[2YQBK0*"C#OWOM=#^IS2):BXX!YIT@R.._.OG;R`-2@)P8
MF@+[0E@8J392GMFLO1,`'UJ"]#KG"NAJ]2+F[@,3.<GF8O^&Y4O7&<U;M7ZM
M=%]7EZ(^A7>#DIBKBYW00$CFX2:PD1RA[\A`0+M5[L.FJ\ZCA(446VGNJZW0
M-+EUN1<;U6A-1S2F6]<$#*8YS<P/[+('NQ3"4'(,1LD+,8=:$#XLW,2JZZGB
M&F]%!C18337):XDV;IG*E,-5?0SG?\%:1GF5O9N6MG%5O'+$V(KU*0+0)QDB
M6T$-+C(0]XM$)[C6ERN&]NR"O\\0J.82HRQ8Z/ONK&T/%+Y;<JS2&!Q^5E=*
MAVRP/6IHH9RT]Q(?@9:2./AXL!QW_7[:.QQPCX'=S7>FB16R_YRI:?#T?C_-
MC(#/$;R7-0)3:Z`<B%%X/9A>[=%']E`'GT]&ZWF7O5',R@X*C@KQ6E?NM1T#
M,&I^/=<F#]2Y`L((R]8"N<;Y-A"IZ?K!"H!K5N@?3MK_5-R(^'GHGAX1J,I@
MP$M*6_/7ABB7#Z?$ZR<&+[ASBT^C1EH[^GC"`M*9]4]I(>3?FP"U(%!(^E=>
M>TY8%^>BYW.$*G+"YR1-FJC!RKY4X%=F;K=\[)[>R@1I*58D93[\44%$6BI4
M(!1:W1&+9.K\F:@L!&P#S@!5-I7WYH-_+C-73@">>AG\R!(:)#8B&+/)^H]5
MC^.EXT9D4\G8W$@?5@TL")<5!?4#UJ/:,%9VZGM^63^1*8^VN,52D2K:"+6'
M!*.Y\H6%CSMZMC,0Y!(.V!CJ[H?;\[1T6F:A;?[[CEJ-2TB,_V<]C:9%1MF+
M4KK+*A]B--[(QM*IES'9>@H$/!$+.6#.W'D?XKII6G3=1"TW5ZI77`O9A7@V
M9-^M!WK!7&6U9=^+.#ZI:;5_U\Y:.<9D1A/>7?K+5PHE7<RL@ANBG;NHOM":
MN*&(38YR/SRCN+0F1LN77PJ^+\P<<O!7L"^<MSAF&'9M,48T?IZT+P=L7K)-
M#JG!/B(G!0WNIG7UNH@*](BML/V&E1HGID9JM,"Z3+C6#+LI8&:'31;95;25
M[9Z307WWUJ>9''`E0SE.Z]#'P'!L=ZFZ7J<*8/84_X5A%=MHEFF-FG+'`6MR
MH=ZB8:<<]_$1/.K)]WU+B9<5B.!C7A+S"8.'Z<#$$*'E1_-`[]]&;"R0A<72
MJ5=`$.)O[<`*D=E(B^/2-Y#X@_&;RS*8/ZD4==]K:=Q:IUO/\_M:\_>+O>&I
M4A;-11@7^F.N87(G<S*N6S)[GQ0L;S#(Q7_07W/_$Z7KK3C[\AI^]["J"\6O
M'@4#1(BG%"><M<[&_ZG?.BQV&WTC=-<K\SE44OKG42`PQ15W#)[1UI&[A;&R
MXM*+0#;Q&[&;L`H311AVH#X>$DV>X[.NT\=T$]S+)C6TI']7!`=1):]]3E5Z
M"(MLE65ID[&;>!=G304)SL^_CW4[A5!7=^^W[TF!KOPU?ZWRR<:C<X*E:E-7
M5''5,O7(IO[\^PDGEUHTFQX[6"F#0),#9K[W'6S=XZGW+"#M(_Q;%3ADAY7/
M/-W<&;\K*I;<5-4).`<J.'OGT?6\&).IO:K6KL<JZ>5)]04=*GD!ROG[8]NV
M:<:DK&Z2*.Y&OYDTA9LLSCS,6P3-,;**1F(0N9(ELO6]AD:J]JP1EM)_GVDS
MP&D9H<$,`#.ZIQ]]?G>)+P'V"W<Y):"26(LGO>(3IOY\<?AO'X`1?<WI_);#
M1B1%,HX7/5=%Y?9A,',UB=0OT2'&J)!D!:77_7>A(.-)[XX'>S`31KZ[FJ+'
MH%=VY:&5K?G_T"#GA6PJ>T\2P[RWI-8:@IES&62^>L3X$CB?1AANFV.>8J6%
MG6L7@F=:0?8%(,\N5Q'`)&VSWCV5N7\6-:PWY'\,@[>GGF&,='V+YPB\6(##
M5E-1'>M#Q33GRK=G<]]04H3A5M:`YK^-MQM^#@Y'HTVVA;^@>S1%OK?&OZFO
MM,(!@2JY$,3:I4`OJY"]ZIXV.#EJF)F5_W:5?LRH9Y>#B40#2[S_1G;#R1J(
M*N'GEI^R*_,B:_JS%]J(1:I\>Z:G?%?OJK.ZG?DTAZ/W$YCH)",39^E\X&P,
MCJX6'/JV,FSVR`;$!*6]3F'NF+`0``4CH;?3`KT$5CU6<M"!+B!_#,-%(0"T
M:KN:/-@D^5P?QGJ?>!6-DE2"Q!+%\:=!J'HG8%Y9RBI_HK13%UE/!<$L6U-*
MT!0-3@D0''VDQR(2-=ISKSR)Q$'[1(64%$#[KW>;Z,E6%I8!VC>%N;(2AV=#
MZFB=)'IDS;&&T"P'F'>R0%3`[_:,::O5BU,CSDK[`P-T0;-MC#-.HW).`WB\
MKK6QJJ-M::58V!ZE6%U^`)O.(/6SHVT.O(NGB*IW9>;:8<X,4Z`@MRCUI#(Z
M4D"(WPQ-ZJ(19$'":G.5'7"7:(M?62F@*#]X+&B81-PARP=0U4CILS"#ZXPC
MOUC%G"NXP-B%<OPUEBR]1Z4$[^[WR1J\OPW<'?H$P$#1)[YK>A^?6C(!W5@8
M9H&@_%QUB)WEBYD:.OZ#;F<KC(=BLD`,2(;M)<&K?*EA,CF8EQ$Z*Y.:]QGN
M&$`!O-0>5DH,.&]96JBT>-'#PX_"*T1T32**1HUUDXR?)A%A!2JL.=W^9YPR
M4>]6#=F>8U!:9M5:X.Q,JBE@:7@QSI^3"?IZL2N#50S@TTKAHRPX:`TJ2^Q<
M[/G/T)?4OOMPBNI*BM7U/>\A1F]-I5@4C7:3H@HT+W3Y0*7!"P$$&]EA9O8\
M/W!H<"!E8VAO)SP_)SL_/L2AT)ED=CHZUKOBB<)J<XQ#7Z;-E'64]\+2=OM$
M%G/O-BB>!2U;PIU65QMOSQOM/[A;TUCEWV#9]Z<?[\+%TUMZKW]&';SO43_S
MXR%V21RE%`JN>/9ON+:'"@NZ,8("M51ND8D/+[F25'P-X`P?.[)G&I]UJ"CJ
MCM5EZ-`@%](W'A@<U:?.FJ'.O<,N'E=QV38XFDIR<L5#KRBSWQ@[$E]=P+>R
M(_ASG@IVM6Q'OY3>UU[-8[N+'_=#RYL"Z!:>1F$)DP;!EBY<`[H&3B7)90+9
MW5%RG?7C(%P.;A<W='A5HCI^[C%[;0>S!F01.$DQK`$;7)#:1#%0(U]5W>+E
M]$C12;KBMDMOFU$V^WT^Y;M,(?8B[&'/\8"L5QFZD6$0G3<4^+_5$,GD2YH=
M4']V0&T;?X\A=9>ZUC-F1OU:KIM/G>0#(`5S<`4;-F"T>]>>B\DZJ2`)/.(Y
M]M7HG%_XZJQ^R3_7W";5\R[)VFLS=7RR'1Q"3>J9@OQT(7Q/3^#?=*QV[V`&
MLDUZ3HCTXA$U'0M0&ZFUM`OU!<WWA43Z:*LG@FEG]R"5!.[8:PVF(I''HH<"
M09VDJT0@1_)9!C?@7"J0ZY/2ZH4<C(MV[\%QW;EII^R]S>--7B:-_.1$33_S
M2*\]BTB7&KM/0>O3[G8S`L*%Z[N#H*JB1;4H!:=_718@?C+/P0&BUO6?HT19
MA7<W1H/X['K+L4@R*4Q0?I08?4&""X+"/ZG2G3=2:@]>!F)=YX<?MHQYRK*&
M&X,C@OM&E!\6O@^SZ''4'=V27NB\8A;]C!?[K%ED:W\<68RF%Z#(]APFYL.+
M/8O:C<YY2[ENB<=G$Y(@J3T\[2%C-6O/!;'/#]0YH54SJAGDB5P)(`0LKY9L
M5/ZX9<_]/&@26H>6&LN+K!-)#E8N+@2E>]]:.7)1DC<EN34:U<',F'=36*;G
M+.)R\8//YY72^*FO?^]?1AK<8A6OHM8ICHI+_GOV[(<SH@I7"RJ0^#KO^WLQ
MB#@\>AQ*VQW9O$6]YUE-"N^EK/V(9,YMF!LYMT")RR3IT^>UTWT%$UP!Q)&M
MI+HIQ6]GB\-43UC!ZTL$KP4/T!VH/-Z^0_T1$,;T6*9\L!L&H=*ENLJ)ZOLC
M"^3H78BN<TLT$IQLJ"`83+?XNF5HH7^P"+_2I2KG6%L(#RES57@/_N>*!/VV
M=HV/`_][T/@=`)#Z`L62))J&'60E.8-YM6U9^?A-K$A\9];,#VO<F$&^`AW;
MT<UL\ST6F7XYD@D0/XC8E`;T#`NV/(`-Y(8)(H5M`"D6$"*^@":U!7&\$OG]
M8DYY_MZM<ZE?^?AN$G=?.*OO,LD8CR!6XOGY-\=!SWU<\\#!PF$YI2>^H\BH
MP0I)XGXT0+(P7?6NNQ)/DV7FOX!Z/BD`T8T_CP"AQ_T4-LABZ?;PL+T]!E_R
M762H/S59C-<._8#O,=Y#A->X;UDSWNQD^>\"FJ+ORGLS@TLU=0.&2@\O.:BK
MH=&H^/.'^*/^X<,UBK$."8GL\_VO$]2E%G5C,X#X8E0?[+I62@N8=FW<RAZ_
M.`'S+2<.Y6&6CM>!]!CD=7N/.EZ%`"6&G5F[>S7AR23/%[$XC!D89/HG0`(]
M4([1#V'#CA(WT7%"?W-JF@BQJ:66\`E-HNA&'XD][HO4!+(/&W^\JB$!%AYX
MV#6]S$:-*`D4.:,4#FS9W(!4B7/S?9=*-YK4KB^YV_'_3PR`=8]+R^.=+^96
M#4!?Z,/Q:DM;D/Y#<..(3+8S&S2P:(LZH\(#66?RH`]OMA)&BKRFKY?48.!=
M08O8=T9-.AJ!Y3UNKH44/2G&M;?K77BFP!,U:BS'\(:]V]>7M<$*4LE1@K+$
ME?G>270:-X0'%&`F3)JK(2+53#D7IB2;$MJ(FF@]B3A7Y6X6/T6PL(QMEI44
MN77LY;0`?9UF&JQ=2BF]1X#\PIU=5XE(V0'D$1)O1(E0=&2N$6Y:G66C8TM&
M^)K/)G$TL]7TOTE:R."<C]D:.C0,`KX"BL8VFZG%5[X^(X>U":17S%M\KQO$
M'8>V/RV4I`?X8,3:X=W2H43RF"PFM@$9%8^+#A^N.\OM_I=[QZR__ZI@"H;A
M/3S9L(`691&,(':(LZO2:7+]>%NFE%(YF>WDTQ,65SF*BQQA.\K[-A$7O[[P
M2MGKW)MS=:2;8J2&M45BP'^J!2*;J&1,O"K?AV$%^X.\5[7=I]O.RWA+/9C?
MBM)U%/_8Y:R/)'MA0`2?0CE)&G$"KD.H29`5TD._-X6?KC/\S6BP?84*U\X6
M65]^NC]NBO>T$=?("^EI.-Q0U/"2!!2FCNKI?7*XC="KCR\1J)F9'<(_\N#V
M.7DMG&.S'!KIM6H)X:1F$XS)7L8+9L="D3I-JVZF"&>7(,&UI'V`X=WDY"C[
MBW9[TMC$DJJ\X?7#PZY0B/I0SV&=00,=A-:R1:^9MA](XUO3S*,>?4HPI$R<
M(D[8F/'APZ]\7KCF&E57#$0,8;MQ&@$9H+JRT9[)/*@^#&J#3N,B;72L+`M/
MA.J^'JAYG&X$1W%`I-81,J#BP:$R/D3X+^@H+R$<,O?5%C236I3;;*=9!?0S
MG[<QK:`06$;#<NL,,:[#R6%EL]\M%HVABV_C,;A<A5#C2N\K:0FV@-+XY`17
M4%78IUS71$NAV3?NU%-&X+$=+1!]C[PL\T(DD,&$@N2^UX4`_,7"0JH53\8O
MRQ,>`L53`VHA\']<'19?CM<?W&2<#%=F1KI-<5!=\K!C[P^BQ5,2D?<LI96G
M1`BD2DB3*HNW)/>5@"3JFH:,-,5Y=VNJ$V$DNSJ?RPGD3AI,)8S,1@711[N2
M6<*YR_K6Z,4Q"F0DHP!V^F4J`M`<D9C98-*^?U,VL1\ZILHQR#?I])K*65V%
MI*G0]>I@0H5&UXPT;M2?\F/;Q9!KJG[.X[VG10L=FI=@K_CRY1!`F/F795?1
M'*1,*B5^[&7;0,J:Y&.5VX[A$LDT]_@0:[9_,"!7&WWT^AO).(;-A,1&%%_+
MQ&DWA>37?@!N2B-GN%;,@Y56_L['?;+8Z!==!:)5+1]]<37/`:BUG`?IB&_Q
MV[0Z"'^<L`X[)#8QM]CNHL_M]Z)^@>56:\,WOCX4/&HKL"*8-Q]MD)&P5D%8
M*?,D8ACY_[((14_83A8RP2KZ\F9M.9KLN=R^*D=,9QC1E8LZ#]*R@BF%2?Z%
M^I8GUU4G==A*6H3<C-LG9NWVBV]JWL(!E-#5YR&_9@-$+Q_P95HHOW@0?>$!
MQ'8E\F0Q_B'@6%K&RB%?:O9(X9,+<QQ'2%`(-<N4Q4U/&_R2H(S>32%D!T14
M?A.;2W?G)]-0)??D8@KY2ON7@L"[Q+#_K%+"'75946K%Z0N%?DH`;5U*R<+S
M)DID>Y'FYUJD'*U!>#:P42`);ZD!43)2Z\2JMVD^;[="`*B5]UI=KULH<T[!
MI#O;I!?B"!\R*(6;YTIA:X]3(1+6[DT'AO[?>^!O36W>,YF/^$.^PG75SV%R
M",)/\SN@SL.KHH%"Y38`L^<%`8%D&.#$3F:AIU;]6GW@44\?QI[_7<<+94_@
ME$UR>,".<WD0[1UIKZQK=B.09UKQX^M?,[TR$],@E^W:LU?1X)L40E2=^_@B
M&Q\Q;]Z!(`3+G["LS[=V\7;/5$Y5,*/$G/"(#W+I.8">P5IRF[VWJ0_KD0!`
M.>2I,TMWC#R$61(^,$<I4NX.8_:7B3CO8AJA\_YR@'M^H4[7_L017#@S%"E`
M+.?[,UL2(8%F5=<,L#ZW+?5-MF"G])P5T<RWF,^LX]*/P<E5#%CF7KP@A9</
M?01#^&).>5++'F/HI6(#;?FB7%5*4RLLW$+Q3UI,?GV!<I3@V?H$3U0&$W18
M63I0R8<M?-[+7%=\))NS,I]C0)`14-<K<X[XZ-4N#()G6;(P4])_C(E.9>JG
M_?+VM4'9>!T]%YTE!//<TF]?.*NGG;S5<A,P\7H]2D]A^>VBM06S7=)</9=3
MGP:MN>D&H#VT>?([10+C8_-H('-7Z#.0^\L&\5WF)@,%/)+"Y>A;NPH6S]N$
MO^ICD1MC=Z).#*K4;"LYS=^^<^%+JGT2J#<9@>@IU'Y\UP'P&,$ZWS?-A?+X
M&Y?ATVO@:'JY#]I]5SI?'.26V'%*?U5DU#1`]S4ACQ!1L]@JZ]^07Q2?*R`U
MDC%E:?M-WCCC/\0L!$%'>EU=@PQO-/JN=?TMD/.L?4F)N-=+P*Q89S"><[I.
M'-FCATW;N>$DQH7BMNJTE^!S"8>V&#?X`OQ3NO"8JNK&=?>\11FS4B7FKJQ>
MNG];4&G8\/ZJUT2[780*F6@Y%Y>^O_O0HEPCJ_\479X0+SE<?6>I`U@M]\5G
MYV+WK/U,+9D:B$PI1[@EF!\,@+(0B9O<S\86=9^^WPAH?A*!=S[M!<5AZ>>>
M]G$)5H1R^>O))LAZS:D6YAM&Y2^V[`;(5OG_RHJ+%>WW7Z-Y+P=5,/!'SLF9
M+BD)4%7;>H.4$O6M]0=1S4@O_442\C-=%BWQ4&/19X2=H!)-M*&92!J">Z2D
ML,/=I@S=4,O\C!\LM`AC1[W<`!%DXV2@/D6\/`6P'F.],B+S7HR$;3=T[/NF
M%N]]I>M[)$D73QP2BU*UNE9:6:&=2UP@JT]MQ!]`XT'@\IP!$4#<QJT#I;R5
MCJ[)8;N[YM5"SL:$O\@6&71KO_5IIDS$]\^MI2P"8"C3H>"T&R*V"2Y2)0`\
M*BS_Z(P]$`YW.^:L#)\D&!"1`MT-J78&45>TM=Q/@3#8WI_S7#;+,QFP<$!>
M2RM857'CU23?DI,*;Z4],G4`UM9EA8\,HYS;*]^0LYU?%CWME6<0LS?*<ZS1
M\J[L.RGKRHQ`\HWF!;+.\<^JI&25D<DA[77W27DG[3^>H;A#F<.B+(N\4X=,
MFF=C(W'468SLJ(I_#4MN-/'&:^T_]L=(@@D#D_59)"(S"^M"FR2LU\<FZ>M_
M4/LD"&:YBU?I@)5D+`.!YC&@6'G.!K"-*K+`H7<I=O<L>RP<L+GT:G'180.7
M>;@G3S<.YR."UZE'%42DAQPA;VVRL-?,/X*Q*/1F<%K^K*Z+V[U)%K%"1PC)
M.KS"J)?&V3D=@^ID;%AJY1[1H64I@/1B+<#)V<D\L%,^;@0VS;+OF8UM@WT/
M@Y4.*JVM:,'#8`80H))>+:6@?<BA@-K81+J.E'0E]$S31Y6Z[V!B2B9KK75D
M]M.JJ,MM@,DR1>/UDI;0`I&QQ.-ZHA0V2BV9X6G%OP:SQI##?C7+,(Z+IP.8
MI+.#3(M#4P-VB@EGGYVE5(2_EH<]M3C&FFY)]#BI%^?+6"3<E-%3,/6.E0CZ
M97JH?A)[^N&M!;"A]@IMD&S<"T4%QH/IJ['+&#9PJ$6*(4]R**A$(^%5V#T?
ME!TK5H$'7&3B%M_\&'"YHK#A@9UY#@I"2!F1VI#J\*G^]6VH`^VJDON8Q[:Q
M>EZ/*(8N8I*R"6-("UL?MU1/F,SB.C+6'7]:W-G])`M_7;Y>7NQ\8,JPT,Q>
M.ECT>50<!>XT''\9=Y;^01DL>RIF;+J02X(02K(I2,NVK.?E^>8.P0#V>6Q]
M1:U4]\$$<F:+W,#=HP^&];YEU9K?%JFC/!.5WX-7C5IHH`_GUKT`C=Z-??'C
MUI9.[%D/AH)$SI5IOK;`V16TMJ8;6/V_L<4UZ39+]^UWI@]U]=KEIT0*TB-T
M!]_LU+*'T0`'M25'KL\U3.D@3['O6[E2ULYMOT.K#X(@).OH=(RF&E4I9LE2
MF32/="UH:+"`F.4&^W_[99>'5KLWPW)O)UPBUJ#_06C_=L2*U[3@-0:U*%+5
M[\S/NK;L[L@I.J+,8>0Y_^=(LN;<,,B+)]J2L:R+5$A1*?U`1RMOR,V`HFTC
M$2NJYT9M`+%D8O##W0"]Z^/-TP'$+='M6"2RF<!#L+SIE@Z7(3[+*;TM[8R@
MZ5A[-(7_;;Y20E@@1BID)?>88_D^_@H1^1,>.HJ;>[1.5Q\R&TBZJF02LGPR
M_"5(-8!ZR&"?KLQ-.(C>M.3ISZL$S$8?&\LR*2\&7YC-^^5.I:%\QGY.0;U,
MM<O5EIY/21F%L]/6"HLI9J:H[!>F=33F"WIN+NI0/>X<;#X,NYC'J[!O*)^S
M,>]$C(WUV)Y#-3;X]RF0ER.P">XVZ^#YO<#G(4QVHB]1`F;#7FEK5MB*141T
ML6PJXG!X0.MTZ[V<B!WARV=M4L\\S'DG186I**,I!K+"&_(C#G]8/XA09M=B
MPJ9-+_?Q0QDF,),64K;5)?VY;K)TUTH'`B+:ZUXO3KXBK%+*2NM6:OPZ.T'(
MLDB+TOQGS0K_B0_'$5QH91?3AR1T6WI4/(27$[)INZ@2110WXFX<[\(_/1!Z
MK@I3.#'[[Z^+208&JP7SHEJ[.)O=D8XC(I1L9%3G21%K?6?-,.)?0]*_DFQH
MQ9(@G:G(HP-]09K@T&Z&+CQJ!]?,S;SLA?,A:H++G!7:^M(71FGL-4!2C%I<
MQ-A.GUED24E0@,L'?\W^*R3\53GAXL/2@9DLPO+,9X<(ZO-!0<QO#P)WHL>T
MDXTY,A[W3EMV.&#H8:R3'-TP,M[L12E-'(;]G"[<D$+QF?DE:.P4RGPGB';L
MIG(X,^/M#PRFI.@+S):7"EMPMQ[91F]&DPX5!!Q"&16\]8(90QEU6HVJBX#M
M9<6.K!N*,?%I>\!]$Q8MND!,OI(%\W3W2DM1%\.KT<C@@_;*9>5&X+S/YHLB
M.:E16C+G?^1?.,_(.6F0Z\T9!?15[U[,O:4K#(I.SG\8'3;0L?*!H7!?1`<"
ME*J=C&<W6*BCE,.*IDX2QA>,92G1#A_,Z!F[L,F#]/3(D%*2;.AFM0=@-KI(
M[\':$&PQ&VJ=O&UZ_991R).,?EMWU^OGR/=`96!/53$&?@:5V@V!K8F(*[+9
M5:MC<X'`MWI@F6+12FW)]2R&93:Z/-</40KT_>W8>QO95?1+>'?TQ+65C=7$
M*TH98X`6N`=76E#.`'MD%/(`O&5A\.+9<YT>[4R!QY?/5PB/>69C^O>0M`7G
M*U;:"F'2,=!+E@0,O#RSQ:,'L6QJ8E/@[O?%Y-H4^%*QJ%]DA^")^59Q,+?$
M]BA.AWCGO-[]$RWU?U7?'8YWS!;IB']R<AR#<`,+Y"B]L%`;0\813K!5V\;_
M:!Y3,+D!.X!1@AF`LLGA3YR'9//]8K4G5R]OA`Y&=R!/O^R6;K'H]T0-%$E^
M,=*'VU<#E2.A+P\ZX)$:J;D&*&3!5O,J<2\\^J,#T;5\W'()TGOG7>6N#=M#
M/?H0]8O]H=:IQND9O`VN7`OE@+OVTT#[K.-;`Z"]M)&O\)U:F>L8$?F)QJ6Y
M#GT!&#K0L9B*O?.DW!F]-O@O3JWXS_9M=)$V4X0!2*W.&KS%;:U(5Y&T4**C
M0:Q88E%#^X8O^;3.1M01"S0NS<1(4_^(8TE^46[ZORDSGHLM;>;NTARL9^4[
M4D+84:*8<E,15>`QT>NS?%;%4V;WFVMPX#"GEH^_%%0"/F@5Y)&Z6JK[ZB<(
MJ!H%D46BUGS.@^*X\<@+,&C#1/D,D*6^:8:I0/W88.)5$Z*2__/UD23_V<KF
M%C4M@,)F56#8`^NO]_2<+@0,0LP+UVI,P0;IF<Y5WZ`X:H3]EA''$:/'_W_#
MK*10X"]-TNKT25@9H6\3"C:Y$=$1EW=9VNEX<<Y04J?3I4WG5L\%,A>+3(NC
MDF4?4]]=8U-6[V@1U]/L9F:'G$57)*!6WNZ^$N#H[;+;IL8^NRS"?PZK..%U
M_2!I'FFUL/"NHP\5HWIQ>WJ%E\$X>YGX_,J9C^SI9./IG$H`1%-60,Y!R"&6
M(PUY-+XAU[]KF]FA:#SLB*C.;.1,$/'J3:]MG?V[U5Z!Q+J<^;`["R\?"[+Q
MQ%::H#[6R>\*AY'N(9\^NAVNE#I*'1D\'0327XJ/>&V-N>%.E.O!+H]1%YM(
MK:VY1J7J,J2C84H'KXY?\#"O_=@X/T1FAL0U<KW25M`&9KL-#B1S'II_C3YQ
M:>BS9_A`MS/`AO/3X4JCYCI%9DLS=PBM\K9%IJY`ES%,(4C.:G<O(AYXNM14
MTL5:T8XH$Z&/!F&G3(IKJ9HU?C90^KFB?VB-:U[NJ*26G\.CB)V2X'+#<O0P
M6R<UIJ03.>LI<\*YRX<Z.?J%4+7;B5,'<A_L,:8#NFCXDZ2?37>E+,OUSP8+
M8G2'[RV`=Q;G-+[RN$XB(!Y1-=Q<U![7ANBKYY[>UM8!_Z>O=N#A>2RQ#R4J
M_,$F>Q)IJ@>*$NQ[WY`L5T(CJ7HBE9G-DEJY#6&](^`Y4S+RZ:FX<\8`UX8J
M/Z5<).&LF=VVHP-+(9MP"P7`>+.3%\*'">I1=#*W8`H0KR@LP(Y.2FF4GO(`
M_L]U*4?]C1NN=RB\:GYY`U%<WLXA)2HI[K`;:%+7J`2A2Y,\6B5FGO<NCS-8
M-9"N%!G5RL@.8614Q\BFA=2)VBHJ;?AAEN+!J6?`OX("9F^-#74'W0@.",/=
M+_HM4XW(:7ML'(@R=-?RJLUY;SPI"'M_,$EZBP_7DGBE1T>_*:QO$/+.V06G
M<">0\)I5?@GZI%7H(8\#9`*A-\>E'6U0<G4[[@VB^$5<P\31<RHUZZ7BZRA^
M8[`EH>K(S6UWTC0R_(OS_;`,<:K]]80'!K>N>(*N/1W2M\;[$TT3_V8#WTT5
M?)JGY[Z)@TSTO#'1JI.6D7<N[!@8;F$:Q`;1YR;MQ="=4*HM`#MT493R2!_O
M3X42<%S:_*[G(.YN+P@8KF0'^BA[C?@&<]"B,"$@EC4!#*YK9"TYQY84JACA
M@V+C!>CM>R=F_>'Z6%$5AH:9?NI\#LO-,)SUSH3QJ\?G2>3J.-G+6[]]1O<R
M+E05+=SNM?#G!@9VEY@=3%(,OE_20J0#87W&1=+SG__MP4IP57R=]TJ*`.&:
M;HD-`U(\P(Z?QS?^/<@B1*E.R\4(>L\7!9Y=A)P&?!CX+`-VT;RS3.1:#R<\
M7I9:&J7(10$HUJFJ[+'6FV6:Z(G0JBO0J0_S:"7;>X@D"O";6.OVOFYJEIP:
MCCX\<_1AY[7&T?ITXV'1A:J!<V1;KW@B?DH+L]4:Z2PRT#O:MI,,)6EMU%/)
MG&SR\8Z&\?D2+)44/LR10C@GL>6#I;VB0N!9=3P4ASJHC\(1NT89!"HT)&ZA
M'K/*L'DALEZ#*>1I3_6CKA3+:UTPRR7+*\!2:KT0IF#F;;^)8H/T0Y69XY#"
M9R(^%V=@>ZPC_"H(8CD8-^*7%KWW6E%@E?4[!:J@:+YVLQQ#/"X]][Z2DX^^
MJ3^YQ,:,\EKM`AL.:2`)1!V.=NN4V&68YS"V;/*&03J(=A6GPK[?>;PO`#\(
MN*GJ$O.#$W*]%_N_@EY590<`N@K5/VLO_K(0:F;)K?0!PE#7YH6-<=OI9^[U
MBRA*:[1ADM-V3U<.YP3^C.<&X>Q0O/19RMVC-=_MI\E2]C`TJ,_'<6RE$Q-1
MYP>Y:8$\T2A#M/".MQ90&NEC2ZRH+-4DFRL-;.%UG;Z^JE;J&8'IZ4K_7%Z:
MVJ>0HCD'TL/&M'@55_;Y2.Z<CQA3XH%#!(#N-`DTQD\ZA^$2$9ZH@Q/.WRDH
M90SGL0(D0F@35,N)CCGU!D;&^@M]=RN4-7F0-_N<BPH95]RWC.9VAM]3AV@Y
M-P7B[+,-#]BZ&;K&F)K"J'QJ10V&IE*)(@T;A4V)"X`D<BB][H8PH$#L=TI8
MKS%T_!23/;KUQL?;IU$$']L``>:+=NBUA6QPI'F&M^4@9:.Y#0K!S(RJ;YOR
M.)L&X>?S(%RP!F6J]AWDIX`XW<>T?>S:B<01-W9)@FO0(,VN!3K2KM\*QA>?
M@KQ3\FS@M,X3@8O?ZE[Q$LP9&MU9'K!-KUZ7I%DI$A-N\K`N$@I=`O01-)[F
M[=RQ+6O=.IEZ.W9FPCS.FZMV2Y*E.TMM7MVS.FA^DT_@??4T_E308R$\V3^#
MPFB,C1S'IP_*&)6:Z`[XG3Z=]%/==V4@9AJTLNA*YZ&3+_(3.5OE/YBQ,X@V
M:,,-]+XBKTK0U@S]>EGZ7,_I^>H!%OX"J6Q[Z*)W9CTBG;W>ZNH`"*ORA+JR
M566ZG.^FI_A.<)%TLY_7WG(.^<D=C(6@(*+W2]=:"%[UJ0DT<XY4YSTN"0`)
M7GRFG`F/_,W'Y@=1.9S![:LN>>!!+&)=[Y.NT(MK%ZUMVO0+=>(Z$]H1*ZT-
M"27MHHU4Z54XGKEJUPFENU>NBH".)C5+[U!HU7X8'_PW5Q]Z2;#?4,!-=/?Y
MX4V\-4'\)OZ^FH(G5WN_MQB;EL2(1[Z3C[]DO-,A,\L(_D-(N^GLR)?(!()L
M*>00J>V:HA4,0SBV8H@:5':BEVI,?NK_J5$-\>.N]5'!??TMSAB\Y!BI9KX5
M)[GP')0$H'TR#/$FXO6<@-7'>^5')B'O8$_AW_"EUF:?T8!`86@=:./+,Q+>
MYG;S6O)!2N-2**=C1I''WY0ITE13%>UJ4'LC62NH&8<K]"TJ:M9`&"W_+2<=
M<=)1O\%L7)B98H,)5N1)'SNZWM>Q'57$S^0A&E8T&19I>8U]"V(8RRC]]\01
MU%WZ+E02PZV])<7.^WES,/FG?Z$`4,"N:JGW*(+@A=D,+"/_S<Y?A>W;_=!3
MTW>)^N4]F=9B_O2N0]FTYJ46&CHXVRRQ_11+NZCFPZB,)&V+>>MKR)#/`5)L
M1P\WJ:#KEG)-*EE*"#$SK61"SA9NF7PV&<^9C_WG!N;CY/X6"T];AT7,]-W+
M`$H9UL:JV=9`O)F!AU3$I>A?Y/!B*L*,)\RB*^5L!XB]S'F1(^7WH16U"'R4
MB(+`;T17B6.7)=A:RB^9%7]IY>C&:&NI%Y.J+AQ%X5FLS=-.FJ4<SE*)(NX"
M4?6F_`5"9TNJPD8VE$Q<.PL88?L:G>K)0[JS5+%%FX'ZWQ-QT+/->J'X9LK@
M(48IOEV)`0BY(/YTN04BYYL3)*%-S?"1?QI"81V1_`B<-)6%=L2J&0L83D8W
M.N>NT^N%7PO^KCVY=T%H^?9K#6]OQBU1;G<JCHE`6KMM_1PXYJ[:S-4DL#,,
ML-';E,O_L':CJFZ+AX770"UR?VS)_'MW#YK+9&$W6R=TVW6+A^1\%X266L!<
M-L1"F)PGS]@:(JDNNE19M>-.;(%T"0O#-LP4D^0N7H=&N22BNP`2Q:9KC]9X
MXHF;<=%Z?M;-IXC/B'>3G`$F=`B/^+O!>^.+K12`V)`Y/'6T>[#-S<;0]A#J
MTA0Y)"Y)1IWCN5(M*]=0(A#>M[Q$A"/P#T;IN'1B:B5/3':-Q&WO%[1+,G?@
MT2XHCQ`@0#9<!XKO^\Q-+*>07?15Z4.V\\UY7*&`;CZ#!7<4FH'UL5VI36WZ
M:XK=MC&'*6^)50<M=HD*O8_%OO$U3Y]1X:@S/Q-7"7><*9Q+<H=F('6C=P%9
MV900=>,%?6_RB-Z%SE4U!A-&LA:R+VI\8'@HQH&&"ZF]#J/4U0&BC'I'TPMR
MD?&U$DUC,G(\Y'[G<%LQJIJ4<N56>WJL"&!ERJ,I3HO(,;%_JUJ1#%!8ZW9]
M;\Y703#-&T%(=;WY6Q\EZ:+*97W(C,K\7^=>_,!=Y=%=:YU;7^,/"$IF\7_J
M&KBK,IY9+D3Q`6/;90N;<+]O9=$!C5(3.UDU_3QFEWOOAM]Q,4^F.^>9LL*$
MXF<NS7Y=S]@/MX@-)K;$**$<(7Y)(ZN[`(CR.WD9F8(-9&?)4_4>`6OD)$>&
M@[_W'O3NERK>+T,/S6^B%.2[3.M%>Y)BXKHB:@36XS\KPG_ZU&N@7'5\"2T@
M'X@L&\3&2['_OCY&]-0_-.6%`*9C&&JU\4UOCR>$RYQ7B)`SP),U=2D]!39L
MB$>3G#>R:;N"C1`,(P&\WA9@`"]P3_0<]<X"'Y1GCMR3EBL>TYZ(K!J$\9O]
M_N4;J#)Q!>K,48!E&MP3KT=S@Q-:U2@Z7EAU.P";=3[@UFC#^U)CJ\PQ8'11
MTSHV<(TH'IS;0%\J-;"]TR[@Z-'TYC#*YIKQM@ZS/,?_-R7`,&'='DG#.9%P
MIB95Q166S,DE/A1+IT$%\W'Y/W<A,#TRO4BVG:./HFX,.,V($Y[UM@I@V$48
MES61]?'-?BD'7)<6#H5$UUE;Y"3!U/\1B(J"J<TTM%+P`XR2"9-+)S&64TG!
M#'O+H51WQ05XJ##IV?T(6\,^\ML$<;3)+Q6QO.$^7Q\R9U6MW&U+E0.$MFFW
MYAN'<O"HV5M6CM-.*$9A0FYY*49VH>X@#E"A:47NK[SC9Z<&Q'8_$9+0`&_`
M`Q>(RQV;&"5NQT.1+SRC/%#J?[CESBUR1"O&'E_:\2&;&_EXHN$&V.+FG5DY
M@^P>5LUR?C/*\BYPZSWPUKNE=I(]5(BA`)'P2?=(.MIVPQ("0B:W'64@!8?`
M?BG$(,#\(*O\\(+9CG:Q@Y1&/YO$9KJ,1.H5-%DXKE4X&5I?GM7EQ/(9B*:C
MPP^R#*1[4(K%>W0Y)8$1'P)Y$HTVTV7WB;N8R5(@\ZL:3QQVB<1#W5EUWKN0
MS5WD9O"^(_I_NU$,'@*9^+Z/7Z"+]G'=4!>\QSPQ*+4S@D^#!X5]5,,@9N'1
MXP4,SX.0QSWP>D);X=/4Z==(0.F+EBWU?03BG,E8J%[K+5*D1Z^!V<1],>CK
MA;PL$.D*X[,T*JBWK?1)6\!!Z(F54SA[.KOE)R<9345)V4!I1L>98^@5<S8#
M:@4^/#N2]W@H&UF5;T[J9@>]&5OTBH`7HX!I:<(&^$?_@((7"]_Q*.'$@4L.
M2:T4B-[KM>/NF6\0\==L]2"_IEO_@']W,"QI"I3\F&K`A^+MT'*HB$5]:?3!
M66BB)N!9PJ&^49R!IK'JQ,)D*54U?-;Z\XM#GDZIN,0NH<HZV[2"#,L;G5^"
M(,$*UKQ6XE9CADX7L`OO_AV;_3`_]*-1P>G<PEO,Y$GSDXX06T:5ZT>Y/$_-
M3IQ`Z4%BP310%IH%!1/\!(]K4L@0;(POOG%14O1:WG<@67#45M%/H-O50D34
M__$"BN@0HDG,^85:MDV\6YEK[-^\W@)(V;>I:7,]\XV[63P9L$N#33`_`5CO
M009V?.E^-[L2-+60B.H,H\1([8N54.#PHYF)M57F9IF]G<1)5J7<37H'.<%7
M:"GCX;0M%UJ>J*-U$=;IP\"P(:EZT!ELI+J<HGR@MA.$X&M<*V^2Q2@)R^H1
M%JX;6)OZDSHS6)VF+9;3><H!V3+_EVE<"J]RVI^%<&_4GN3V.JZ+-<R06?*!
MVBAVC*VQ0E'VNW7`J.(946I,IQ67B^2!9,^A"B?J@M4A4GUH_Q83A59_0/OH
M9`EPKZJ4S\"=Z::E7DRC,5U[0LS:TQ_JH77^_*O<EIS`LCW,7<^](\B0;_M*
M-/$D*?C*?^R7C]CDLO/WHG@4#W[F3/A@J_.E'K-.H^N,C_/*71`VKVU'65OH
M^85C0>B%MC*0DMA(D$+$B(F/`4UP4?KB?8Z_%=@-"=[Q00`#-?\"A:3TP%[?
M`$=S?3?8.5B4&\.F'?:`)`+NP9`*DTF64Q+I)K+R9XP]S+^=+SN&Y!AON#W/
MG;_1_B9:V0;\#6,&[F`MCG_2-#]J-R\S*Q&=BH@6N1=S)J16@_;L?RN<6_Y"
M<Z4H<FC!>U\XH/K(P.4LU"T%1#AB?MWWYL1I'*%NA3.3`Y/SER">_:S(:)51
M`$]7\1@;B`!,GHM#[(GOF%H[7Z;*HB+5XF"$P>M!,/[/6(OH51)];)2D^#.7
MO;"1K554LT(A#BYWTX#ILYN7/L2$'9$(]"$N_4+W`OWZUDJ`*`$U#,BN\8,1
M.)8+-L.R(L]T@'`<C;^;S^%)C7_!0EMV@=_RHEZ?DU"9]5K"K?1+]E/:YQ3T
ML%X8.E,S25B;KH$UC1,J!FK=+@0HEI>T=)$'$DRP>=YR1C$Y48^/LO(SGUDV
MR634U?%Y]NA-RP<0SIB_$O9-_?^```?W)5"02Q1F3Q"&U\*BU*=W=$:-3J4B
MDD]K&]$,.(N)WKY;(\R_UP&Y.03KFQ!M%4>9GBF_W!=@^5F;JVG/%^Y7WZQ&
M[ZE=Y9'==)>3<FQ6Q2&(&O,>0PCZ&XZ3YZNFP$(\EG3&^_')""B?6L<0HS9R
M4O>"B/PLJ)0WP(IYO_&O&CN'^(MERN,"/B#:HM)2F-RV7`>RY:C.ZM/$$I!U
M4J7^;13KXZC=28P_[.R?K>+W=&*HA"B=._F3;<8=45L<MO12.$@JQ0YR)\,$
MTBL@V<V8/N0Q4-TZ<3P>\(=C%[*@]"(?)-,-DE![0O0-DE`\_4`F6<G0L!]E
M=]:$?7`P'5A?L)L$*AGD"JEU$!SZ\%%,GL.&+)H[[^#"=3LWU<`A^G20B%V*
M_`Z&M[57-K2`M#N]S:]3<I@N&31EX??5P)E]0$C+[GE$#`3\WF.AV<J(QX^&
MZHCZ@)=>6"<&AUC1N^TQ/V(.*6RSU/]=C#*T!%'$*("QLBB:N);)AM="=X&,
MFWD\:`PG)!;WD%R0P9G[B1+X?>[W_V-#A:WBO)EEK@"QS9TWJ!!\B3$.I7"'
M%Q^/'.9N1--.PC3J9:,+3'O*HAH1E,,3`)'HJ8:42\S85Z3^ZR<9GR6R>>_.
M52$:XX_4_N[S$/\&U9D#!]"W=TL6/Y>:C#B3_$%H[IZNC$5.A]B_U^IABT?M
M8`C`B(.M2<TXT\*^TJBXQ%7@B=,%JIPT8J.Q&F5,(K]GS>"QQJKL;J:9Z@#^
MT.6R0;&^KG2>@T0.GX,/9E^1M2^@;4;C;V+DRD8PW'OO31DGHH&'ZJQQ92/;
M-TND=),J^EH1[*W5KV3/F9JH'5IB?S&4R5OH(@-D/N@6=8^Q"A[ESY$QBT#=
MY=NL,F8BL<2/'9;(I`11##P^2.^5BBUSX!Q'_XNEF:\;_V0"_R[A$EJ@(B1S
MU:L`Y&4V"RON+I$UG[B%;\O'E'?G04=3I.#'[.?A5<!!1#`>9GLS4`?V3<HV
M&V]H,XP&FVZUJM(>!RD"@FIS+K4Q]M3%?HVL;#,D2Q!/K\*+`"!3%09C;@I.
MQ+PK@D?XZ'O__?#W&8*/+6@(CH*D?PCGMSOR4KFD95!=2&,<$<J!9M?M6K=6
M$6`<9<$B;JNQ!+JE&"_!,7,?"-.K,5\.RM)`P%00*]MN2X0##K"A"?37.I\5
M$7T,TF?=:F(@#2O!JC!YQD*/:[D`]+XX'R/[-,`A04#4WT$!O#&&X?T:;1;H
MR6(^[;R"_:7H?>@:2ICN_>"D])$X6G@/&_UG36I7\;X'/M#CQ'&-EH<1VSPP
M+''5PJ_B:N`#HECNL$V)EYK4.5%E8*AW^QX\*GT((K4L"W,=.3#\,@-\$K_O
M-)MUH[P-6@L47]%43@>@+RS5%]SUC4[5[1:P0#$_44K9M-74W?Y)->F"YV>`
M_/%^@X9OF%<!Q:PE.^J-WWCK32J>^!JB58!THAGT2Z?G?>M53/>J8!CDE#+7
M[-;Z=[()HO<]^GD%$[-QZ;/XHDGP<9Y:R*XH"[?E7+AEJAB.8:M7#LO,6]U"
MB]\RM1/+41/;_O%1RP5@8`#-3<!51186WV@:ARDW&:W(6^ZH<!@!AO5>8L_-
M*_WB7M>$J5[W,I!%82RJ4*!,*Z$/TN3[\<N]#)>*42!$WFRP^WW2^^V5@@]>
MHQXH3C<#&?X+5[0O34C?0<H6T2O"T\`$`%<38>:!ZQ,GWW,4(&%':RX-^^B1
M^-H1[7=:Q:J6[=P!I\`)OOZIWC,A]-&H1H:?H.X\0C(TT8GD*E@KW0-O16C;
M!?\'"?K54[I^@,OW829"=I:W78]*I+0=9478E&!<"CMTGJ**!TB#;=B`>#(7
MQH*D+IL90LR2B&`"$UA!,YCJ>=V5KVPKUPE<6NFE><B7)XF^^^(#ZNN_-U,C
M(D9GR%O"%10;OX8LZ\]V2*1546!PT[G[\H&<GPIWLG>&,=WF%VDA-82E/S&>
M2J-!KKWR!#9F,^+KK;(&@])EWX!`(=>?MF*Z71$I)=A2+Y3AC>=ZPLK;I>LU
ME:'[&NOCP3QBX4WWM26O2@DS)`!WK(]N0\==D.HEBX9KQ8__E;FA[RD\=*!`
M3RYK[@NG3;OC</0/64VNRMJ!).EW"#CGEGPT!V[R6;ERGN6?HH0/!3G(4BC6
M17EQ25(:I7KH6<9Q2K?B?SF#AF:,AME"")T6<FW/'3=XA?;XORF%0S@L>5AB
M3/TX?Z1EW]&W+E>T2O`;+_Z<$7T$$\A%!,:FM_8$CAW+R\+;2+ZU&KN6;K2N
MC!D@.TKK(>'\+S!H2V*.-#BIM[/D$0SRR&EGXL;F";_5^C0PVT.X@%2VGPQ?
MM.D6#1JSJ;F5EB(V7_66V>12NU8@@\<DW!RR"K2#$PLB9:*[Q]+XI%V,VS2N
M@*Q1R5(?`0F;?2K'/GTG,VBYTZ>U+$0N40K*5M532P-;Y;^$*9&:OGT'OA%:
M5V1OHB`:9)**&BW>TS7%)MWX;!@+S#J6IXM*H1@+P!)I%^&FLINOUDYYXM9L
MV)&!8CFP?"PLDU6W)N2Q<CO2U#1:DHUOP-E\-D\?X@,*;9I*JD#P!"FV"8/^
M"PFD5WXK30RQ2!S.$Z#^23P>W.VA90HY7K+4G@^$J]K?MOH'`5\:-8QR/1\8
M-4&9_AYL$^][3U34P##1HY[V<^J!+*]'SI0]YM@RE03`C8G_-7N'>K6*=VVG
M5:MX9'FK-*%"4$3M]XK"(NV3#(^>&`(5G(/`N.P162I@@=PO<_V&LR>;>2<@
MV4>5?L&[61Q%&:$TV,T;AK8,ZQ3H^!J]==="5.0SA%IR3P][Y`77&)S=_";,
M^5Z=^)S0CA[22.&Z]"-:EF8&&]7WY42VZ;.B,B0>4ERED.CUJ_&S*4U],0@!
M"<Z<4(=6Q5]6H&^#*039W"`XU>VH9QYFXZ3E@!K<!A/7S!:WWI^:I8;'(\*4
M"]PI5^:!0T=-W1]-'J@_ZE-*FY8#*S_;77?^-=+'OPDY(2N0*J)W(#OME=J-
MJ*TU^4=$@6?LA?XXJ\QMK.GR>M3-C5#UK0B"%.9!`Z=CEX[%GG5EEE9TAU*(
M56T!78+CT]YB,6&/IXP&-)\\B%V>K]X-?"R9ZJ[#0PE4I*"4]).:4A9<(CBK
MVD:4PU=DSRWST]%_HL$>0HHGL7J#O!Z&TE`N6X)XWH"(\AOOWBD^!;<?3J'T
M5B\./<Y<E5Q]DJ.U\U[20\OT[JJ:6!(3R;&7^@HAL&9R>6H$%C-]RR>.TUM.
MLXA0B$8Z,AQP/O[Y"\]%@":)>$0N%&!7@!@)4.++_E1O`8,!=4SNADI]15D9
MU'^E)",5=]4E"O*-\9)F>#AU@;WS34IDI++@&NX3&(1\;3(9&?DM(X#O[*V\
M#RSB`7^S>+(BJSO;K\Q.^-O(E"KCF>396\NXZ>T$,=1R"6[*/@[VJZ@XX),'
MR0LESB"GZKZ2[7D:U','R)QB^-P&/54(JIC]9-QC+R;D]QI$(@IG$3>5_*=U
M;PCMD&PDXV8+K$2>`KKDA%<Y=;G%%ZH2AOXLZHQ60=8\OLSEC@!U3G!!V_%&
MA2/6'HO:^75OS),DONXJ<TLF=8UV90%^GQ/H0:7P%P*&)E2(1Q!IM8?QXFW;
MQTB-/3A<4HUE+.*5R]PQ.,LD<`3>J(H,TQD1Y&:3V(7N/3PU8$3_6Q=9CBSZ
M@!8O"'X/]Y:11?:V:31IH)_^K^JA1T[7>).1IC6Q^TP.FT8Z&&@NS=H+#0_/
M#*_$G<V-=Q\T`"#:C.F2`Q.]T5'7(KN3$FG1H\LS)\SU_0_MXQQ!PWAD58Y:
MO%S,FE_65:TL!RWN)EK#.A`NT*![B@RR%2/`_RUJ>;:0Z"F12_N?#6D9;24.
M-!.$#*4>I.N-F>\_0QKV/#;U*@.(.\LF4313R;996FW>E$/P`;'W(<+(W;]T
M-4HEXICT#&E"-0@P3ZKQ/\9N),K49>E4,0V-OBF2B0RCKLE=HZBT.'X*K[+Y
M:GB.V/S_4`JWM8,RNG*\VU!=[5,VFB,TKX3S,QK-61P84++B,Z:*,1Z:,QJ"
M(Y;6_F,Q;\G)U-%7B'YEX*E8S8WOGR8Z(A=\BZ0V97R=X7_CH1LUHVZ@@>\&
M?G:B^9SOF=YCU+)'T.NO.8S3AF52(7LBAS._-"B/"3S>X?N0^LZ3#S50#L2*
MDUDZ-FQ3ZMG=5A28+1QI_754./+<9D!\[4R:B7IO6:GABAW0*?22U\-HZ)@Y
M.!?B+NF`,WV30>8*+ID%UXOOR%MWZ=P\_%5--COP!XEPWJNF5D@U"$42+"VH
MW2(PO-K,BDP\QR-FYDJ@4`BWK#\[N8/A<.QK@1W0Q1F.,1:=4X9-B>4!22'\
MUJB%LA@O5)Y`26`3KI90;X1BK&8`B%#R5X&A[6HJ"?!0/Z=Z#[EK2O7Q`?WU
MJ[R[<A+&S-3I$"^S:*X0'^NKI)=AXS@FF/2FA)9AG!W7@=JI$ZI*Y%0^G6*2
M3&X(N'VS;N>-CAY+8971?8&%&"TH[K3R21KQEL9WA#,S&U?.JYJ9F"@H$VW9
M0'@RJT5<%0FB7;>SPF8SG>!]C0H3=W0^Q4:#2BH[6JUW//L=:[Z\=1Z='E'1
MBN$!))IA\E611_VCBAEH!]T->R*O$F',-22"HEU.ZMB+,8`:P?/,BW$*5%ZE
MZ-KJ0/J=<%PW`^?E8OB1LCF?Z0(DG),`1/CNON]U=0>9H1*:$*[JK\S&=#5#
M:?]/!*H@99@6(0F8MP%9LK/(#?J%"$<IH!<5$.M*0M?QLQ8RZ[H^D7;_HRG(
M1\,A03'F_[,'@5)U?*S(=+K#/SIMYNG).FJ84;!>#A]D.'VXB]#HL;.)ZZ&3
M\?OJ#!_`N@BN<D$//K(C6V-R3C3/)!-W7=G23VH1[LW848BZ#!8\R"?)2;D#
MU)O+R;00:#\"80A`@=<*KBTS]&@]DQSYC=D$\2HM1`,YPZS56<Q^C;IBC`-R
M*Z6M6_8>,.*9)?@LB.VW6=<T*#*_1_;<KVT<9Z'Y#X>@W.(_Q6R<KE6A90JA
M_/J"B75\U3_\YGH5IE\A@ZYQ$KU5,KG&%P"T2`898>'[9'[%R.'_P[C/7OYL
M8@9MRC95%;!!`C%`=A(L`K4>M\'B(V2;-ST7#Z*@B%.\+P0WQ)8L#:ZB]*G4
M/P27$"#="X;KHR$>+5"<<MIE>!XH,<L2V-0"":YC]A.@C2$*AC__'-/`I%';
M=2BU?+Q;?1LLUP%2TPBR$CX`1GR0NGO,D%*QLND140GG7[K%XA@RG#FMTQE6
M@3TD36"G\ZF%&`8">Z#I!@LU6/VB`2[[YR_!3]#SG_4#=%_.U:YY0X\X-8T'
M0CQ@`Q/HL9L>;]Q>>(JDIUY^E^G(K?ETUFC.)KXAE-Z%"=F(Y:.T\/CT;$IN
M(J;)Q4D0\!G0F39TWK8_+CO@JLE!94Z/J1I7J$`N1;K71R^$??EY3"`@?E2+
MT-S8W8?G%AYLS(6E_^EFU%?7X-16^D?$@S.;Z@4LB.I;3=_PD&Q86(@W19)=
MZ+.EY3#LKD-J@-HWZ!`I<=U0R[)@W4;LUN:`B`8M+W!0J^Q&")A"".^AK[7L
MHL/3H3MG6,8+Q:7-S*ZV4.P$MP^'JG]!P=M2HR\4#O*`#8UO64L#D?.9&3>*
MK=:=+G@ETT4J_)=JI7D3U$<1E_$)+G$?<Y&5\SH0Z(U1"'JASUXII=`8J<)S
M,XS_#BPH01$(9JNWB\_M"BL"1*""+#$"5KG,>4<&5\NP4KAOYPZHJ;9%Z'*<
M)PM1/F`[4PTL!:R,0Z*1J/153[*E*Z2XDE_P1*:$!*+9P<%4FBL2SC3C\3CI
MLDT_@0-V'@2'&WBD+%"QIT=^-K$++XZ,J,;TW2NG2<>N&:LQ16+>/8`D(?@I
M//2=MOZU$WNJ\]F/,G92LZE_G>=@N\@PD^)4'Z'`S#4?=RT`GO.#\M4I0BA9
MWUC.Q5LA\E:P49Z=R$2S'^#.E,/<T)#3WJFF8&&/:0.G1L!@\"R-1$9R$ZCM
MRHY!JNG2$`V+?@9\G-'JF5PI0+:6*Z%R?>044VU2?O2UR7N-SNMZWB5++?!K
M&4P\4O[X1V22[=(QZ;50JQ!>)XB*#=]#ZCA1MA-FS\J]YTZU7S@%50=K+JR5
M`G(`B)@B_-F\[*,-;>XI]\5_!(\\\:IR+X>K27/*M)>^:WQONGN.OXXNX&E8
MW:7T[JB\W!Z3TMQ3A*Y2)UJT;``K3<"(APWAO=^JV,CMCIIM4XBYI*T^I'?,
M(8#7++#VOSH59)7Z#/XS(JKPS?-U?/=[(4!%/<C7-%A$#P?,)59UB)@]&O5%
M@R?UTC_N?+D('#)\,9QQ-KA1ZK)T(JOI`OZIE`N=>,R-G>MA+`S^DI:0[>E6
M)L![R^/"3LO38-U#]#/"AQ=XKU"GJJ]N:XOM8W[?0VS>"LS&JE,94EE^)*1V
M]%(D6,6N`Z_4M\=AL$&;[&_!J_V3^E@3GM=WNG.:KS8KAS])H&1T&VDOE)$,
MN?0?3J7*@-]OC#0"RYV-4F4%;33S5GUC2-_(8F_=@*:D:"O3B?A9B("?#X"P
MCYSP=RZ<A[YF?6L6&A)0'2@=,I)8U1H_2%V)BR&=9KD,,KWV]S@RRX2$F8`]
M9`$$&RS.7%!7=Q(*8)6F2`J(;_*`FYT`->C3]FJJK)5DKS=`L<<T\D1>"EEY
M7;*&AQZKX+_>Y0[DUY2F2@$+D6F][UC]@SZ.F8O`&5#$DE+?C<EY?]4S@GWR
M5\[Z=3YH`2L1+(`["Z5+])^8X1_*+'/H3QA.H#+G'W-D.=-*<:")YORPM89X
M&.V^XQJL;]"RL_7N^^P>EQG?V0\7H(SX+&`H,I4&RC]*+&8<WVQ^YT&P`&7N
M:E0*3PQ%T+CLTC51YS+:K.X]O/(!L.?>B*FLOC?-BW-K4;C%D-O[+Y#.WF@"
MCLSTZ8QIXX7OMN"Z?;51`!PO>(B?E=,)5V`$"DL[3BD:)QI/QSZBA?BGP]Q2
M3"+":`I+;]!%]5)?(L3%-$'AJA[J-PG9L^-BAU>=I>/-T9Q)/:_6J<U.GV[7
M97Q3(<W-N0W;(G`?S:@P]P1\X-N28)",J^.O(@5E6+'+7\MEG.^>4<T[6-:L
MO>C$B@-)'1=$C:ZKV1&AX<X]/0`7W8U.C##G+=#N>YIWC%QN#)+M-"^J4LJ)
M[(/2:S=,]P+H/1E`V\MC;%SF[Q$:75_UKQ^^ER179QYT+%#N41E([R("M_EV
M:<FL78>[.]+^SRBWJ$3X)R'F)S8N<_H34KV#16L;0T?V4>1+@6](H#&GQT&A
M*7R4F63>8YTPV7*^G.BX;1E@9&A9P!O[?H^!1K!,=A0)VT+`B@#RCR=@H:.-
M[C$D8LU_$M$!N35N=>S>#A7.@@IYS63%!$;^[@[E8M'Y\,!F]J)1XVOR1$/B
MLOA,;]-"B)XY"/I;-K0J*S[BH7*27_K$[YO.3,!+:;.Z?!ZKO0#>!)U?,@N!
M`(-;^_-[JE6$'.:"_HK2&\L<P_#!HM5-3E9)N&ACWF+94MN8/Y<5*W34A!,_
M;4B01.!G<EOL)@G,0?6S*YX,`J4Q&TV_/&Z]IYX]])8H/$XBD3/AQ\5$`91Y
MLUY`?7AY6X_[*3^WIU4^2J;:^RNVY)J;]H8AW9D8JM6_3#[KLD?*!D_"FJ/+
M4%YI"4ZTAX%:,JTLW!.28M>[?A/W*@'XF>"U]Z?7='WG07;2Y>IS'NA5-5<I
MQC?(=Q6^A*E(GR&;\3>>DIH8FG=!_<GX19G1J6+M[/LP&I4V?ZYO)=32@4F*
M-^D-)P>/>V*G3SJP@J1^7XF7O%Q`0@0]>`+1SI)X&II.'I#H)9.8.&Z60X#*
M[K7WV\HPR>[@:7%)),1N^^03ZR=`T?RQ/C$W4<L4^/$+N_@0<\8(",(MO63Y
M%("4[:>O\C[Y8`76OA)!Z6C*?=``W61S'B@1QQT=LU@!`O^=XH4")S'Z-H.T
MHJA_<P=<D79X&JTBXZU-`O0"U*:0R],$[-NVP+\8DPHSBA<3\/25HAZ-JTA(
M_=\OK+#)4C6]3V1+Q-C\SA\L;CIM<EP4/23%C^D?[?(FS8?ZGASS8?"[I!DI
M1KH*]46$^3&?4$X,(3`5^%#+I9A:M\1R&'TZXKD]+7ETKRE%0D8C0GD%`E]6
MM\AYT*)E(?>HKJY1_TEH^43(WY)M$0X*(1P`EM\WYJ"GCV&F'$W3%SDQ%5&J
MX3;)677`ERX)39(I?=4Z[B@<9]RS+HX#^R(;U+"@7/TMFMK8V`!1X'7/Z/$:
MRPL4JV*LXB41T$'G8WW"LEP5*++8*@*:`<TF@K1N.AL;J5Y'-K*/=;JU1@6]
M(.0%'&>?.F=&X0;ZJ91;#M)8GDOOP?J45U#>A9]APQ,@Y56E:,AM@6T_"XT3
MCV^,]_L8_P9>;X[QJ94L`0[GQK?<N&\#1&C'BL7AO/59L:3XT?N*DI/0KLCE
MYBC=^76=3&/<TQ.M]Z['W!E>-VHB,_CY8Y#HJ7M'_-T9/$-_^YV1_9@D+%#W
M*KT#1@7!_JG\Q?*7/C+E32DAP2>-YOKF@UG++E-CA,U(FQWR+I_YSADT2,TF
MW2IL`&PQA1DW1"/HI,('D2`Z=K?:RQ$JWA3+OI>KC8^N9BC:V-%;NF(K2G,-
M`'S#Z+VF\@/LDHR!`8PQ4U2P'+ZL@7U("K9JZ-C<E*>NC.4QO,7L$(<=YFA2
M#8YJ_;>F!IO0O:[+;^B4`Z>GNXP2_P'3&J=\6\@*%<]^[VLX(+U^$:@YGXE3
M:P-B^8I?IQCP<WEY<#,%&TF956DBJ5@[:2FF=.VOM06<4%&0JXFF<6;4[!*P
MK0[FN"\\V#D/Q)1TVUV.'.%]&:ZH?YB1*KAB%"V,Z0)^_FE07707,5URO7)M
MS?C:]UFK/)9*P])F!3HK\_4PE9_1$;U#:J-7+IN$IM(RQ?A@Y-9\K`QKG5,[
M(U#>7LFRIV5O0CZL9/<$(@$0?RLJO9_9,IA%PN:-,F)(I#$PT=6!8(]9A,C]
MXLM$+5[LF9)F_8I,8YLZ$P6HQW+,^62<8*C'.W?[O)]MT1\JI$/.C]/E>BAR
MN1[@)G^O]D"(\N:0N;4W6DQ>CL[`N)%O\U`O;SDG=AK-.0;H%;J$,-BTTT^/
M,FU_12LHT`8[0#OS/5[T1'%6@:+#>G7EN#NS>V@CY?QUGR-88&PH20C6J53R
M_-M:YDG"."9\_KU@Y6LF@T!5!#\/(1PH=?"2=+SP_/J/;IOO#O3U7V,AVVN!
M5'B*S1[_U"F*/G\-P6[0X:$<NZM"_@98/8D_P-\E/&XTY5D<A2:I:8-W;7(X
M()YT=]W/J=Q&V<9D6D@U[R"&ZL*T8VC:G.%#K;@X]N%F?"-&5=[/D[\X'O)(
MM?IO&J4J"_:4BX=\J>>,8[_,TV>ZB8ELN#=2[<$.V\&>^:"^OAL2R@T2D9?7
M%16*MB7JE,1R;-#V\7F\#9OF6]Q-TE]@9S>=!UV-<D@S?*J*34AB[]C/X+YK
M*8H-_`KQKC%/^.[FS-NI=C2$"M*'SM0@;CR^UU_(4,2K2Z(=TA#$(CM(1X1%
M1;7:!H*XT.X</;U&G@NAP\,AK(*.5A^&%K+%5@E!Z^8BENBV?E81U@)@21W'
MY)A+RN55_`%D;W3L*P4%F!G:$G?'D.^6Q*BTIW>A9$$O8N=D1F@EC0B79^Z'
MPO;.A2QVK[*=/JYD5Z3<L.8L5G^WE@^%R+6&F`VK?V`X;#[K74:W+;%)=WP"
M*^`#PN?AERY[5'./LG,)3K+PYI/[^*D#2$.7@R-WIQI3VFM5@O2[A]J<SOR[
M3P<U>E_7U6_65B_*#A)+X2$@B!8RSGE`L:7$U[4T.`,Z&N+TG.1Q.1LX`YC=
MU8/73OXT!D#\"!/GRZ.5(W)!37T1W7B8./&V#4N*9!N,+LD_O%OVRUIKEOO?
MC8^<L(5V!IN@KZB_L#XX%_Y9^>E0]/Q1F9[F=6Q/L.1-"+7/3HN92/3@-[IE
M87ZQLEWXS*@`_^Z5XT3OU,]'DS8TVT[3$7NHVD_>IKC1728P_0OQ%RKA%82>
M`B$SL7TG`Y"26OH:U)/=A16ABV+F]9$%CE<)+?@!&=,4S'<$2QB?LZJ]R+"7
MY=QVM!(S0)96JG+^?SN)P'&/XS;<+OGG281P<U5/7)F0*?"C0&-U?.M?7(^J
M9-F^;6>;;<,T,U8QV-0XQR:!X(`!\MCG9-1HOXO\M22KS&P,U`5'M0!@F(Y]
MI#*8'Y0"U8`W-;WM;Z#`1UAQU0,*AAIF"BRLD/-A'D3B>QS5\$6AY5%7EJVO
M-@7PB+0&.A[\<A2C"VI5C9)R;QO;:'8H+"DC8TY-&!(/AL>D%"`7$Z=+&YC_
ME[0.9VU708T^V.="2O.>W4I6R^:.[B]&+H7`P#0`!1PO,\B,GW9CTC?+]CVU
MB1S;L(Y`2NENB9/^"AT>V4>;17!]0[/S,HNP&8H@^VGV2@DAW,^IYKN9E%+K
M?(/.U%:0UMFS6,FQ\V[`E,@,9[$USM"YCT']V120/H*,&5J.1H#F%_`&**W$
MKLBY<P<&PZ4>W?)+V<9/$N&'1/T7[Z"?]F)`D]UY'S@!@!4^UIR2$+.]1N2S
M[,13W`):PC<`5+\,)+FDJVY>J*>Y6SOIOK/!UCQFE)T:*,R7['^`\&S9D]0=
MT+DJ*?$?:JC]&4O$SGWNO*\$:0^Z"%F]SPO1'.)KN(&HH@ZL[E].%^T6#Z`]
MUW^&T:PP!!CUJ&3HFW8\>^.^_GUP&:2A^O28\-*5N\^I:AWV&U?8"9^2E%R^
M1]Q02;]:(4HUO&,%ZKU28/RX0`!7M>04'Z0<!?0DRQ?5!3)]UR/?;/#0K/Z9
MQ/T1KU3`+U5Q>I]"#8J'4#E0#QQ)LKJH3X.EGGL6Y>3KM%:?AH_]69+*,N,(
M5(\$ZJ?7;O-^M"/A[PR^Y^=B82_%(D^V,6!Q\G_M&+G<>KIPN'@,L)U;>`!0
MUSA]8]Y20AK*K-B[3L,@PSQ\BL\=Y#D#PGBS+<#-[O&5":%C@/QJP]HN(<%E
MGV4Z$<;/HL`0[EC-#@:[I-/X$[8W7)0S.W&3>4,[;<B&NT=5KB?FA!<1)H]/
M99GXD5)[KU/D#]7ME4E'<3IX0F1HL_J1ZFKD\X[,>KZ*ML&=9K(N#R'HH0-T
MI"$;*EB0(;/?J_YN#MP>K-`RC6-`5>A]$JIFHY1&HYKE>X=7,4(=9.]QP(RB
MN.\F<IH<(L:6*X0(3],67&4AL08;S&/>4@0@6"$*,O8#RBLO`NS;KW6`)8#=
M62''>T/FP\;R-B`KNE,8Z!I,&R&*H<MO'`+<=_2V'`2S_.V7OQ05Y0Y4+M#(
M_\>8Q9[SCYA%*1U-L';*"AS/B@9Z0(1P,E*F(V4%5=),Y2K'`!\_X/-`:[VS
M7+^YI"38MB,3$$\*-JP4467_9;K+#0MC+1@+H1#H+'DSQ[#+ZPN>((5-0[XX
M>>8#_MX_@HIR06IJ&FS,UAFY+6DKD\&E.`G8*\MN_+;J_J@E(AHX&]]$;01W
M[3J.GDVU=MUUAD4(7ZIB2Q%_NP`P]]HLAW#(;!CF`D$!2=07(;#FW4%=X"=)
M=[D+N6A"1UYP4+SPZUK,UERT6+R3`5YZ(VV0^QT8_6J,$5JZZ0$==]TTE2/"
MX@<SY3/]L+)Q.`!5A;:X+6C!_X0Z8()8:G'TFQ8LX(0:7AK\7`!;#;Y9QK'O
MD?OH[#8^2!]Y>T`V,\+1R,H91T^D42#^*8E+53<,]ISUX?FK$7,\-*=YT4&#
M^3I]W`J``UYS((5R()9&;Y^K%H4C$@]"EZY\^THEZ'>4(MWJ2W+L84TL6&H8
MQ%+#M>_B$IBC1(T9`DCGM\+OK_JIA'#'6W5'_BWPJD;G[.J\ONX!,6C\8QL0
MU-<[+3IUF7Y."DOE%&\,U5ID$`>8G`Z,YUUE>'SFVLW%FI2>E&(4E1MG*LGR
M0/T:'QY$C!N;60V[+!_94,?Z`:(!RFS*2#S,?EI]+4?EI,E>90'JN+O^WO84
M&OM%(#/*\24F\J+!O10*PT,+T9^6VU"!8&SP7]\)\_6`'B0W(BTN?BO(]R`F
M&8HQ2)I!`CI%HVCD^-3<,;^,YH9,[SI0Q[AG!:31;W@$1C7V=!F(0/KY8\_W
M"J7T48#,U6Y10.!/7/:&AW\,TG\R+\7%F'JLJGIA\DH+D>83^N6L[=AP=7>1
MV4=TEX($93FM+I\[#^6?#SBK3\\\QQ$Y3^3/;:79"8+SBG;G]_?-?M;[;AD%
M=>5-XP+^J)=SZ)S$;;*#$2)WX3FA"-Z3XS0NN`-;HMI>#3O-RK9FS!S1>GGB
M>U0C3%_MD897YW[Z='CB$`OW(C$D=W9))1H,M2XM!85`:`@-<IWH<9+X_'4]
M:56=1P[]06X;W0;,JT:251]A&W$Q%L0`U)Z4K/LRDB:-%R/97;6^',0$2L<3
M*&5T;$0W.@QP5.T3G*X?R?E;+J['=9^V,!?2]ZX4<+^+(R+L%6EA/I6R^FZ>
M@=]H82\SF<$(Y#KQ?/P,N.L)(:@S*CO#]WD/5;-EW08$P\V#S12>3\KOF)7]
MY.DE.!8IL=XMIWEY4TE64]ZY:-YYM`.,'"A8#8O\YOG'%.*>.-PW#Z.Y90/;
M>E[LC&\H:R'=NFWZCLKP&!S#!6&#MO]W>/7H:(D`%#F?*W1Z*5Q!,L6W9M_;
M$I;B.N[,M)II3M.UP<@"\<4P?2EL28KNT+?)N(YNR8*J;]3JIP[S7D.0)?H1
MF2J@2*APQ:<"N/7\E@BO;Z`D*Q!]YX5YR%>@EFHL$D_@3D'J&57VI4=8N*I.
M2@\74"_9R7:2%=EH>69,2>LC(:\+4*P3O./9B3,YT48L/4.[\#^=4:X,/TUL
M"TAYEPKOY8MXQ\R*[9;:EU9BK:7ZTDB'.U/X4XL1A*!Y<@K<1<GHL*3JQ#HZ
M.68IBZ"W-#$\O:<8@#2S+P0>Y&Y(H>8$1%8&JN219S>:R?=4$WP;%7O,1YR1
M7R(W+SW_BD)CA?^=^_@30"P"]-:B*;&*%=R_KM`.6*D7D;*2+*TC\5>/NFD&
M2]*M!QAW`:FR"/C@2)2?RQF+CV2,YP9J<Z3FUU':!<Z7>JZ3(A]#E8F&QA(Z
M:-BG*'K2A%/P!N>"L/DJ[=!KS>N$K'K""'93#O%SJS+\)Q4%IAP9)=N9PQHA
M[H?R]'6$R=$%L*>BD]/]%7'&CW7T`%'<IO#GJ9*#"X7+M4Z:IVW%H=>&=&BA
MU9V[";;U!,*&!I,-\,=A(MKV[G;&N#P%/!%660(N`JVOM!43%5-U?\]ABM2A
M:SYR&ICF;/]3M4]3B_Q6F)F?!P?;0X,#O^[N+9J;Z7>F$Y!9-(<,UOS;&.3^
M"#,1`5[54Q:`$C4(&3QME/%4']38^<(,4Z3#E_].(4;UOKJ&2>I`&R;1G";1
M82SR+[071F])L#H,Y+9(2-R%T,3L]D#+]AULJFMF=V0W(SD(6%C,!F3JEQWV
M,1Y=\3>OT%:63`DU\VGA0R!US^&H&AQW,,R6-=,;$/:/:A<\]?IQYN`[B/95
MN:NN+W6OW^2U(HWFM;,KA$8`A6W0P(5__<8XW:=9BN2C(4Y>43@<,8W!3TF+
M3(FH$(0,);F[8;%'W*JKES8K=7PLG.=;7&J(Y+_*B:[SDVNU#=S")]E^>X<8
M8,B!'9DS).-\='SY^QYWM5KFR0,DNPW=6\WT%O/`69,J_!W>$"VEQ6,:AT,?
MJ\52UY.N2IJO@!$K+8I:HA&>8"^<SQP@8!/2=L.8%E7F141"0MW75#BZ\!;R
M+RY4V\Y1WXT5UNPD52GJ36&JO**1LM0<(2G(:KD=J8T$W6NS\3TT9HH!K[Q?
MFAXO9YLZVSS)0FTRZ1OICQP%,TQ&T$&LFXV,P-"=B&J6DVB-UOD%/!0Q)N_%
MI7,;G>G>J?4T]PS<"W"NU/7TI0JL"@L%I7]KTG:!EB2'>7I?G?>9\(]W4`7_
M+4"`,;$_$0NMG^728+QZC-<_;83^L33D*@T.(M1'QYN?EX&5)8L(KCI[USBO
MBAS'F."G(X2/D3J1#A!DWLV6;;4MX;^+5TH-T>E#:17F8*Z*1&ZQA]SZ,%`Z
MAO'1L>J99LD6/.`Y>;[CT5$4"P<T8ZCHR>6HN<:7##>MN5/FUG@SJ*,(_;VT
MOFM2$LLH(DJ/^Y?BDIY"Z#[H.OA_`]%47L*]U>;T"UA216/$"XPTC`WX\AZ0
M$!$J#.RFK`?TA3>35%GN8#3"(XI/G4;SJ+-_^&#LYKLX0'(+8F6]7\B%]>/,
M+PS=6B]JOH7UMSI)/L6&\D6ANF^`0:#FM8R<'F0NQI)O2V7E9^2B_<ZLG:/K
MBAD`PE'V/(]$51^>D)?\:!S@+RC[\*VWIV7!X6LRL@"VH0CDNHM@\$GY?D@.
MN=A85HP7%^E$CF.K=WAC0EO60+`CYZ6"+KIQA"@^H'%BS/C4X=<V(I\R`IA)
ML6K4)<OVR5"FMVRA@NU`6EI,KDYO7#81\2BY%PZWHT+TQH:<$D.WE"J;F37\
MQE/9_YAF9.05+(=GTE[R-18%D'E)/$(8UN0=&%M+V-14*4UW;92?:4:RD?T@
MLA?GSI9M6Q_S=+BO0F5NN!5=#VO!.<LK"S9ZO*Z*&X.[$(8Z;18>UV_:@HEF
M)R":(<9V_NUBS$`JVTMB)E;2*WSNK2#,+:B8-JO'EVL4SY]WUN$R.R@02*P<
M'O<J$?&3+TKDU23CX^=3F"5CMW.N2W/-,/#15,?AG!3BKVG+I=R>M+5^/]*[
MQM+57/9B7=YR'44PH6'[P&U_[S8"4$G%$+7]WA\#*K$T]P#DH<&0P%FXOR'@
M_J;9L.-*R3K?<'LI56C1:"KT05UV7_NP/R@3*)-^F@%//AI,,<*.RR\&/CP`
M8#NJ*>5,V#A)V%+'>0?U;UO<4YLLZM\Z.4#Y21BXZE7`DQ5-P.""?HG*V6_H
MFA*S3:ZADH``_A_PLD:8=/;J.37>AN&BX,#,11%&ZQ(7\!-R]'#+3TZ7@*,$
M;(BFABEOSY9.RRP52.L/0#N%[2$$XD:13&\EF"5%1@V9!B$'-YV^\X[L01.,
MSP"E]ZDC-\K?G:WSAO"''5;)M%BBIHV54?_[!$O6-V7<;?8?$6U(R%D$=CDC
MVEZ_`@OWX%P.#Z6C\:F?#T5_S&)%KL11S('B\6A2,S\4/Y8BZ\$%QL$F,A#2
MS3CAI&UR)1C3RNN"=EOF=FLKF8Z#;9GV)OD?G23GGX$ZC1B%P6#4L4N&^<0Z
MDS5.0HX!2$XU-"*+?[:E9`WL,GQB0^0)<12,=GTI)U.H/J06K>&)5Y_%*)XG
M4('O?"O_%]RMQR47UKX@CRV,]2WFC9AXR+_?K>X`QEW3&'IN@67[\7[4*4A_
M_[9@S0%SQ.<H"?BTUL67UDK+33?34)E_1^1(QWFUX(F'+HTJ^D0.(G/=_F``
M)[HS^!'U6G9DNMLO<-W%P_//TG.1S'L`)`QDE1,DIO^DUOSH]O)?8[\:^DDM
MZ]!>6+:2=VC;1'^"XTOQ;'%K7],[!,Y7RK/$RI3P1T!;VXLQL7,)NP!RP$?<
MJ[HU,JD=[>5<*COUGEBX_]G^C^\9R4K@8<N]!#9LM[%X##-E],Y_BZJLR"N'
M1]3^*1OCHC1>*I(Z-\K2@:$ADGX.56)+9B<N37D2?R#,LPVT%REXR9VYF;DH
M"GS'1DXDR:FO3-VO<UE38FC5+!#])`/"SQQZ$\AY"3.1H8\6$O_G0FC:8;MX
M##J<97IO=\2/U7EZ.1\]9WO'&++S).L8IUN&OM/>>5C?^*Z`[`RVUG?J`X`R
MJ%"U*U=W$XR+/L7QW-ZU[ID<#/:#YD4W2M=.]CJG9"D9-R*2MMVSK>XS&/Z=
M][J0I)[.['5[FT9*_-,GH@9\D2:;:W"$`?'96R-KI<I/E5))E=_$=>+D:M7E
M,UW\_$IRKMBMG2+!12]8=;B<%O\]VB=.;C]L@T,];2(UY[3"APD9/R3=A-'&
MO-CZN[AWJ]UY?4A7I1]:'>@BS5;B$C,F&(=#>9U)=Z,L3B,_'I/^_F)4IO:.
MR2OHCU\B(-S>`^:-M(^Z.L")NX]%7>8X:IM^Z/6?W<.5C[$S_%W(A]!WVZ\?
M*?E_]U9EEZU1)/HM8]I`]3DQ=]A/G'IBC=1"]U.&QZU@Q=)E@PG.`P,\TGYS
M/K&S>HC_TWA3WV])/SH@_XP0FL\&F/1U5)C2<2KR18IF6\T5K91P/U.KT2Q7
M_C:!+$OI5"MRG..D`EM-/F]0(D>2\<+;1!*GHI%W^@J#=:]'/JA4<*ELH9>I
MJ#C<L2E/^&UX<)O:>'JK@^LW"_(GHR.#P$VUI+&AP`97?\.S--^-W6P5)Z/<
M-KR2260W8%4&ZPZ*AJJH9>UQXZ]HK;4PQ]V(A6.W/Z;/9>KV2./=F;P=$K?&
M+P5E3_>Q['R<Z/25>I('!X-TCCD3JTL=1X[?<-3U@7P_1AA\.L,Z<`+SJ\YY
M<P<%@YC#P$AZH#^>7/+=>_K8:K@-JO]PQPP:OT5\5Q->F:S'-N?#-9'1=4>B
M'9Q1S/4B>-0@*`Y9T0?(#VOK3$@R;KT>DRX9>18GQ<8,"F7ZRAX(I"8TBZXR
MF;/,<3+:8-"8#UW5[XGH[7.S(@9K$J.2^%"^>$]TT]TK(J`8LD.T(H"]?'45
M">7]HM*+<_3;ALF*9(W059DKRJX\/9K2]!P4\<*E4:S[=,2U+D03/;?_GGYF
M".":HAS#5*G3PV+DL?["E[9]W-.K3R:/N+IX?.%1[KU=GRTY,_[&]=\6*A^?
M>4<G/>;F8+1]>IJ7CI&5XOK<C3(_G7BWM[!?/8_H;#*VE,#TJ:/3^#<`4?--
MY&P6V=Z2>?AO`"`VYN@XM_^'%'#I#_QO(5JJ0HK,XRU!JH2I$`IJY6>%[M*_
MHQ?J['N**Z#E3%@M;TOERCY$#)?1\R_;A07_VY-6]P?0VRH,G0X5H9L`K6`,
M5-Z*3RZ^9)DN@_TB"(UCCV/9A>.F<,1L_>F"T)PDR%_H(?$]&?R.*4UP0A"6
MHN9+__%#B'G-8+;1[2`27O>NRPD+3?,4]T*`JX-0)X8_7WA>;-$?ZQ=D;@`&
M9XI^(VD$2:W4R_F1WJ,1+\#&S(?-L:?4T,/K&BAA&B#W>U^^S7\O/KER/QX^
M+GK2_\SMW4L9&J8_3]-5!!1B;GI`(?WZ3;7+X.<IZ,S/PED4'6HB>3Z*8;+H
MM>\2R=6$M#?-N1'.&/5)!#4WOX&"<@]C#?MY;]Z&W=86]"D_Y(TBW>_J3PU%
M,5*T"*5+I$R"-^]VI;#&Q7JV<(2F0!G-.-6[`Z'5/99;(^N5_QJ.,0;\#="&
M]\!#\N!A)-+?>NGA=:F5L?QL?V=SR:+)4,[G5J+HM$#O5WLO-_7#;4(TSPC'
M0E1#N_`*87(ZU1#W>66AA,?F8L_\]A1=.[P!!JL>ZIK5&^AXH@^FQ@64WHY(
M^K.FG$6]`*NO$N88Q5\>X&WHLN<LAEXGE*X$08EY@S@.LS!X=,.(2"KMRQ[%
MR8]0C4HPO^+P2O*+/MJ!\K#9W,?QESSG[34E/(Q*<H7_C'F6>45V>_*3>*V=
MIZK6ED>TM/`Y7W,I$2N]VB4YZW,+<<4>]*,XNQ6!1#0XNJB03GI9/].L1%&4
M"6,(XC0>J1V%?#J9_7,O>`J>^CZ6^.!OR@]4WYB5FC]`7:Z2=J^,DD;5^9V!
MLJL`C39"JO2]8#T+^(%>DC=M-Q%$OIV<`"G'7]6:!EH,@DTC(VXVT<ODQ(DA
MZD&N^AS4KO-.-*;XT;A>;B%S-OXT]Z&K+T+=NF(12',]69,+,+THQIU=);Z&
MK2$5)G5KOF/F3J>Z(L)VX^EQFB=#IU=%`>YSE`&LGN>3D!+I5\I9!OE:R@K;
M.!I=87V<H&L\X\5S;Q:&&/C>U@BD=/G'=E6I!T,7L13^DP"B?#L*,NQP1IV[
M'\N<`1A[*QJ/)S6H@0NHPWTU&&K[#>%*E6'/:(+<X:BCGY>)/+&03D42W3+7
MNE!J^,]WS,B:#-#+,#/KB;E+01+P:-^&,TD]6L(6)4N"Y4L3_T8T?J20/<Y?
M)I(YDL'#+_07BRS9C:Y=D`=0ZD``R3Z-8#PC>',2K[R@WDZ3$!V">#MX7D!4
M#1_;<?\C5'^3Q>QC1I+@[EGX+X7RAWV*B*I&%%23\JM->QI?4"=)9:&(77(#
M+"HR4*)/\C,'`KC+FW9XN%ZGB+:1#`X--?G2(,!V:=72[94?>KXVBTS#N"1%
MHZF<;Q$4WMX<NJW<?X=@#D0[Z$,"?^;O@YIU`]PK1;.RA)ZC2Y/VA%7O=T2F
M]F<CH14?60XUDCQ_+UB:59$&@3>WW&W4'@;Z.F*K'785(D,Y$/4$(.L-*&V^
MH;"ZL=L1D2)I,LN*ND$KS!/-,5?>LF9/Y+%_4JL_'11S.M5.B(]:[0GP_&9I
MPY+E-Y!)C=A04B/GHF-YD[K+X1+DBZPW%!=]*",Z#OGO2ULR^(23K6FI#"70
MF(\%!H9ZDOMDIK#S,"BQ[!7YN=,%VI7(.TE(R'1PYM?QV$"/_U&+W^I4-#ZI
M)975Q7X7!'@'%YSOX6DH8?FC@/[^13;R84B6O5X87$-GN4-(`9Q@-%Z.GW(V
M(`HJXT4[-;:MH3F[K3U10C`%D_GJ7#3KR;:UQ],/*?[+Q/*XAQPU<C&]0``K
MN\>^MVF"Z9IE/%0-=?R0Z%O!;D!S8/(-N`\!CR<2C$;IO<'&!C/.(=1BY.U&
MNJF";-?!W#<PM+S9&LCOO))[IM$=--CR+VM_\S5_*?A"%'`T@H5)N0)@4H*V
MG=RU[P`W#Q:T+ZF-#1U';X/J$E?7OI<KN"<GY"-ID+8_0!?&@0]TL4MK)<O-
M]6JSF+S_87*BB,19Y(0).CD#$>`G_UZG,61##&1THZQF0_CI/J/B)=GET!<T
MYG+I#94$[U(?IIT?YD>>;7@+^'JC(%5L_]Q+GYZ-%PA:0AO(ZNS#AG'%Y7:!
M1R2!NW.L9TL3PK&J*5I$K9-S/S)B0/8>30)BQ$8NUT%P57N9ZTHF4RUFOFP$
M-4RP<G'X5MWSOI`HI!%,IHJ_?.2%V>$W;])I(^3LVR9V9!?TA=)I%.`4&]7=
MJNN9/09+C674)HSM8']604P*(T2GDGO]8(5I:0'BFP6='FQR\US[9F(?D>0G
M3(R:IJ+;BN)CO'B1=4KIZ8J,"$VW!A+`4U%G^7C,LD1&['S[I8O@#T&+!"9>
M-196UC+&G%N'(RX@44?`'_=RDML[4I76(*(,13HM[)0IY\6W+"$WQSQYH/0F
M'!<4T\T+A8#%0*OEG4N-?.)55WT@W\)V'#[K,5^W6QWYAS>/J4M^%D"#2%H=
MO?OU:+DC:=+<5'T#U>=UFK`0R=A05@T&QFKCDN9$CD^;O-;ZV$!?QD0M&6K6
M%BU-^\>OQ0\'%:S2-H6^*)FA.%F6-KEA:12']'_>/-NI5#M8<$B9M,S>5G3O
M*'XG9/.7[^(,W<HAGV)6D[@RCEQ<61.NZTM[Q1U"Z.[:^"ILWFMIL0.]$T@5
M8K*AI=YG/*;5)FGM"P>E_;CS>:L">:X[]Z*3OG6/L@AXC'+G&MA^V*:&XYNW
M+)XW8+/+(MBLIIPGWC7_`&(4;?"06?F"(9#K))>VITJ^`*U</7AT607MD%<L
M1%'6HX($?XN;[9*IPR9#/>5%7+)83H:W@<]L&8+H"&G1M:$[)+.#4?W:E-))
M]0"S9G?\H*J*!^ZKH,5N;ZZ^;1K<9U$*[SOVN^,3`+:/[9I(^I9ANIBS$19Q
M&4M+134F;PD>'<,"0A^^L(+I^(NE>0\P)\-MQNY;5GX(4I!4Z%TQVT-IX5NN
M.)>6*V*M?6G"%`N-F>"WECM(?FD)9=6\8GYEOO==DFN%'5N"`XZC024D@]_0
M848ITO:*V!I9]CEP#^WT$(5,2=\+BZ`=:>SU/DP"R-33+?>_)<E#]B;F[>(;
M,R((=#Z5H?Y*X@R9>/^8V,F"I_4F%:FBH-CJ;BC%H!K[Q<4I7MPJP$:G3<=E
M&-#__F3=RIFZ9?XA)1.O`@;ZR:78FF6F%1Z%N&!@Z^P8G/#,`BYXT(C69S2U
MLO!;L0FHN+I6C>2#X;;]X+_3$2</'I^1%F&4<5A`EG==P]B(0^GQ$]QK_$U0
M,$%7ZA4OT`K,1,V[O/U$!4O2%0][#CKR-WX97+[0D/][^31-W\M,4/T`T2RB
MS5PW-SXZW-KCQ2DLZM6J1#F1]`R-;2H:,&-9]IR9JA,4[L;@O1Y7BP>T9$`N
M*/@<]CY;G+`][S.;G*+_)YKX\!%J=VYL;G4"?4>7A-\XU<0"->F'9QVZGD">
M]Y-%_@?9I\<RAT+6O[82!4S*S;T7)E3/AK*I$%L[4]UJ+Z@EG8]$7Q^IR@/N
ME?3<^_S#<;12T'ZX,^OCB?+N#S!&V4*XT5CV+;Z/2O.Q?QJ9!^'N:^!4'-,*
MY[Q'F8:+*M8!37+\>,ZL_G>O(%BOET(L8S,^L6FN,P]:N;Q9S4(+%=@$[%B!
MLA9ZQ8Q/`FG@TV"=#8Y]/(3B,<"E/"#=N0!Z!JBW!J^(=G+'?J`M&1]Y7GGQ
M/]JJ76K7P?NGUXAD%1+/<YV_1<.Y4X]>Q8H:_L44'#KB=X9+_J)Q9)RQ=)5M
M-=RMW;==<Y$<64:4]7_5T`N.M.+!-';KEJ.XKK1X?5O)VQ&R-@F&BDWYV'6V
MXH8^[MFE>&/\G"1@?(Y23-'/?$Z),6\568\H=U^35&[VU`7_2GOZ6`>CK:;D
M=6NI>(\Q9A69L.PU9\C`W1#"_/0ND8KO>(A)0(-V<)8'6X3]Z`P.%:K@GP:[
M``M@V^969P>:9>5I^W!16:`'O9GMIX4]$MC"(U.D)#*6<4G@FKD,WKA.Y<D<
M?JZ+B>T.=3Q,NUCS3F85)5_Z-J%.RUN3+04HL/V[5>9PTFJX%)P\(QQ;7W/'
M8B97@G:GZ?RF&EM,*Y(<.4,=R"\)L[8.R)B\5!@R)WY=@^CN&]8=KIWBEGFD
M%TGT4>F8TD1],+#?E_YP&G\8A/(DN%*FL/`,X%29^(IFL2JD8(S%)N_WJDAB
MW^=8-/B9^/[L4EX/;/T'D><_TA>(;*'<LE?;1ITL_1B:]EMG)UU?2HF6@V;J
M)&:`:3CP"PPB'AX$I6Y=.)E'_.7Y?\W:(A?VX1I)@XTX46]6D%H6N6-RH?1+
MT()X5H-"HU($*AHGE2@GMJ][7$,[2@3BZ1#VYOZ?&GTP3QJAP[9][D\R<X!3
M5.23'=F%QCEN?JM7*4%R"\7:W=C(U-+GI_LYQY4KC[;F$'R)-6&G%M10:3F'
MZ-8'6I6I4B]/)`Z2&+0VL<XST^>P0H(DXUZC:-L)?=2L'\!=:WL+<[2,DN/Z
M2?@7_`"8V5IS;M-=MA2Y`K=]8WB@7_T%LX_EKG%@'^KNR/;>%:A&_-P%*=E6
M1L]-L[1GR!!I>GLB)[DRC%#5]S0RE8_1VUG3D_LJ<40Q7#0QYX)`BN.F@+^T
MLJP=',648&8!C*]B3V]Z6SDILB+791%N4_A=5NU$*!.$[5K!(4`/1!$*2Z[6
M39ICB0"F.XI1=R!8<:,$O&9T%G`#Q)MTVN?2WCH%$I:%>)%H[1D7=:@OD8>,
M*L`.`54^R`G;YN['[I%@_OJ((*PE=&&;\".<#1?^U*XT`#8BX)[MB3/!,L)_
MD)F=%^K<::$@K`JUDZAT-8>=(TWMHY[667'7?I6`+W+5=ZR6(>857#]NOYCZ
MM]NP7>!E([,T`2>NUUA]@X>;,ZY0-A*@5DYWAYV^IU("MQJAF`XJQ&:'*@>[
MC>&HRU7']A4IT\C.YQLJ6/T4BN1K*'G-D$;0XS)IVPD8+T^JL=''SKJ0W<G+
MQ5V!4%GAA6'U19&9E\E!1DZ_?<L%AKL3\7M>+:W_\=.[X+%-''YV5`A*^;F)
M!5)@C8MG&C=47:\?V^$J1M*P<PD:6H"&EJX04%B$'%1K'U57[%QU7/%1EK(+
M,UTI!#;Z%&_H)N4;YJ&_KF,(.$&^.:%E!B=%/%.YRZ<R`T"[L:JNB";)`OT]
M$D\2`GJ4X=J5W"(/;1)_5>DZ2VU[GW=W8E%[[,X`\Z87SIHE<EKV4?>_</E:
M_*L9&(:Q#C;'H+T?<>G-<CTB_DZK!@4ZKSXK'A+YCS%13Z;BDT\R$.R@;T>#
M.]MPWS,'ALK]8AEI2=F2'`IE<AJV>H(_6>JZ,M6\,??C("!]XA`IP2L$*[>H
MV;B*=5U@AX@I>>G9N7O$Y\.R?E2NU4E?B&?6(6##BO#B>Y?=*0R30N8SKXAZ
M-?P;PGAU7@/\C)\RE/!YT/5?0>7I6*%TS]&HM,\YX3;[R)ZY)LY#2EW%<-UR
MGM)`?CS8D@RFQ=D)3SQ*U)Y<&Z)A&ZX?A!1V42U:>M7W2Y,PX4X5/Y[HE9^8
M25)B5'<O^R^U26.=2?G)W:P%\\8NCR19O0$^5QS)OD/88H="!LR>SV+Q)I^;
MB^WU'/V?O&H_'9Y#T-6>I#2AS8G17S2[=OTL5#DM.)_N07-NQ/@<?P:_.V8Q
MZ13:&"^C5H?.YY"`\@71Y517*Y"C%O,)AWNAQ(!_R?$A.%\ZFKP+T;?.`_;P
MEK)R5/3-M%PY@)EV*K*8S[LRUW*OZ8NR5RKSL'$GFY*?'P;'IUV#`X39U!IT
MP8,Z7=*[N`00FPN,O8FXN]F\8MVTV9RXO3_#=G^H'LH@3O?%G)0QJU_BS+)J
M4VY0%/*EC6I=!%)84$N_^5&6T`QDN[1XDWM8N"29U=M]__=MIZBS<#\:"R`>
MY/[*&APC:\;4*Q`O<3$Y1"3V2;;#Z%5NW0\<`+M;@Y?RJ?"#94J.TMQY7-E4
MY")@#)C%XV>3%@Z+N&H>>#\$K=>_@_C*:"<T%NIG3GH"I32L=;Y;(QF=/]D@
M07A@(!,[M90`III@+(YW8N3&,Q-?Q(,Z!7RS-_)$1B8B>2<3CFGN6S2JU@`9
MTPS03)H&P#70C3%4CCK"*/N<8RAFF0C90V"9:EOL*%N6T'JFCGP^M$NN5AOI
M=U^1'9,5X.(_;QF'J>`DH6+$$79^8%:_+N/%(Q7+!S#F&0W=EWJIGBLA/6?`
M/1$R0O#?V"WZ0XY:,1"G+/B8$GST\+1R6!>.[CAN?DG6M#3:J14FRQ--X$FJ
M,OI$8V^]N=0M?HQ&=$4>3DH'UG+I(SO>`=Z1B;9A:D0[JBVIVBO\=GN[8F[]
M'R?;E.TD8*`,XFS48R9E3HG22G9K78L-!T,Z14QPJCO5'.N99)[#.Y(ZO6<U
MJ^LZR!Y+5O];$5!W-TW$`M!/*]<_7YQG_$`*>@88O#&Y6>8BW=Z?^=I-K0@G
MY2M:C<I92R:4"7/W?5&=7)U8'?'`/B59SA7&H,BYGT'Z[Y-2LVZ3[XFIK:7_
M9PP=HFZ/WL^(,:7'>C?Z#U:M#<M(;.@R-+^3&&4OB_)F[R%)'JM_A<BJAYU0
M]?KL^`.2Y!HD*Y/TN^RG_-T[F3K]]DS,W[4NQ"YR)$HJ*N?:J[N@&`0\U"OX
MBC5J-QX-AI_2!43)F8*Z"+$G^,$/KB[@/A<F[-^_,:>Q%F^'#I;)Y_\[RQ_B
M-S6*<W?%4^IJYM\=$(XQ:<1F3MC];I/)O46'^M>W4FL;]MBRI<XO9"%>5F_+
M/PY_5Y-1K5HAF(;AZ14.J#:\I!K3H`]UR=))Y7^&7Z9Q`C9?4M@9J/+_3-9G
MX&!*P6YH*2(9?%,B`F``CU\&J=P#OQ/C2`CO\%9T>L&H6ZFL7FUUL^@U_;S1
M(;;K^".-&4=&L7B.2"=<1^4,M\9]!Z@4/A)JZBGK1'9>E%XQ;>1KB:MD_1!2
M51T;!G_V1,;"XNH[-NL.A33C>E^4M[$[^!`^-0X&]<L.U.?T=_FV[YTU6C\=
M@-&I4D]2#=.FK<=NT7HC.Y7\1M'-/?M/Q>T&;K[3+PV)`5NPB/L.2IOQ6;K`
M+MQM`49$."F$W)SN($,[-XZGAMRDC;5&9U(NJ@=O#$;-W).-F<%I+D-F:'3=
M,&[R\QG-$$Q;9'!&MR*]5C6U&%MVEP&[-[%%:!SUMHV6.BI_`XO=.@C!V$WM
M\K@^LK:[3;MN0_/-=1]-O4EB)FD.$ZCP1$(]XE)"&QAC=UYBE]NC#\)]&3"7
M^0,K>)>&N?-7&7ABUP*X=M^I?`"4]OIQK(II6Y2@%_BY%!CE<XSF]XYVMU/`
M]X'&5PWS+@8TMT8>^4>5_AK-!<#9KNJB\56IT#]*SGO/1<PDGPPCZ]Z%XQ^H
MD=BH?!'CU.&5F^GQ>X""B<ZC(A6O;R63MZMB,EI5.4F<FTO&)>%",1'8KW_3
MV"5I^J3$TV14:9XI;"]H3'B0MJ1.3EMYU#W_#KSR2)5@R8L741?-8B^'[&XL
MJW`(L3A(\/S"0B@HB:!6!%P<K$&4KH*_H2]>3_$UDBR>';34IL$X[/&FT([^
M;&5WJH1;R/.OR7'9`SU*\T3*V0C12;6G(VE#8T$>_7,SU>MRDNF!`<Z%LO8I
M`,Y(3D.E%-0;M8!S;$,7-*%)SLH%E@@7_Y0WL[D.MBT%6_+TUP95PN1`A3F"
M;SK_O,N;(F5+],9F+[6K4!6F=P83?P#]!1V+Q\U&FEY8:W\NW8#3UUDN2N8S
M<366'%.*:[:_>6S7A+$R@S-$![0J(_%=R(\ZR5TTQE/(J=<(RZ4/KF79RIZG
M8UO`4AL$R+!`8.EW=]YCM^-<?RHCNV/J$PCKA*N\*4\RG!M_Z7>)-`89-CM1
M8>/A\,KSZQ@0F[CCVF34?@V@XMX=N.X?S]1$8)#3?XPJHT6"4YY1O]E,OMIA
M_4B$Y,ZI%55A5XIH9JIFT0X.:<DOD4935)FJ<=L0A:R7UZLG##HMJ^5UFLH:
M3K[O-58MT#.>/^[K!W!%_('V*`-A."G=T@K.@3$[IC]H2)YA<@,I>.U"TO>&
MW:::#PL]0QIVFK@"(!PV2;UT']G*I>5'\*E5GZRY?5K"RP^P:.WAC+U(9KS?
ME;K^O*38"C@?V83/U/,;;,&U(AEH]O&.@FCJ%,W"N[YL_J]$D\\MSP7DDTHR
M_ONB+/78JGF8LM'H(H-ALBT07>*W_;6^C1?Q8R*,^<`[NDS$T=C)N/^;K0?.
MRK3RV+YST/.*G6>=]<%'WXQW#\I(C<MLF52]V`%A_7@B8FUP`EH:3XV^W(U\
M$=6S,Q_X-XT])52=S>C(R9CS5%8L0KC";)'*(((3GG<&]D"[8Y99=I)%/DDB
M1&QD#0%02ZR"E6''@9W#V>IBE+`+Q"*56#=`%%DG$/9G>E'ZYE/3KL*C7(F=
M[LQ*ZMX_C\.`E(.%IM]^O,OR,E4:>SFY/_>_QQ-?$ZK47IJM?;_'89*;UU8V
MCYR?.QBS%FHT[RKDT%@&IS^/-VV4Y3C(&]G,D_,S$Q2`-Y!PF;4*QVRFR9Z<
MU8Q&E!YRFE%NM(I1R!-Z,(&,``*0K6T:Z_0$;.9-*M7F0MZD&F76!R>43Y):
MY7S\3%2W,::;5FN.!>Y0"AX+R6/1MW>,M%F\V&>TBJ$3DHF9Q]".+E0T:4QW
M3!:]/YIZ\(<+J#6QO+ZPH*C\1]MQ$W(@=6:A081N7,+D,Y4^F8),NP1XFIN.
M.;4Q);524ZXD8VF7>+>2V;D,H`ARE++RP+C!UG4AIEAH#4N\Y!53VOH<F\0J
MS&#F2U]<L.(:PN'W+:N&AI4BA3K-.XFFVD26/M6>E33ZZ^8^Q^Y1N3%W4Z2)
M291`'D+I5(E=5&AL:00F"5^5;8#WIO.XWCI9/E4'GYV5W-C!4-O*A0W[4(1K
MPK<\P29/'H-Z*2M%>EE@4T@R)9HE*SF>F+POZZ*FU.8D]L+(Y$7!>,!3>Q:$
MX/,GMS-P<&/(/$"ZA#EQ;&$<'JN_=T%7792HM08:;6^$?2B6XJN/;0=%R*_'
M7$&BA>`R7?@X\9`MJ],SSL_&KV53+,*^.;_!XY\-ZLKR?IYCAI,/QFK]BPBF
M;/50N,D-"MWFZT$?*YHHXP.A43A;5!AL!1M9>UR<B]V;W:"(IYO+0;=_6X)#
MG@%Z,U78`7J5H=JX,@V4HJF%*^-`D6&*N,:;/65J6E1&1('\W6&JES@(C8-X
MCI31^I0B\.[R<6`JPK>\)-PHGM7V#?3S)3_^5UC4#=>\+%+8M0`JKNSLU8PJ
MX=D-0WC_.ZQWLEUDO0AV`H09?N3Z"M5)D^[#.*&5!$>B[]%*VS(;DF;A;!#J
M=CS?Q%M0W+Y/:UC3VL>,:&878&P(O[Z/RZ0[<07]`VZ1')"Q\E-^@:]IPSSN
MC]\*BOJFPLL"5]\J*7M]-L5)"\>X6XG5@C#$)(%'6)M.8(0'>-76Z'X]Z2A,
MZ]DXIIU@XFSPD7$<994@C.@SBO*RH14K#RFFY_9R6%+(G4S+WPZ_36JY:NT<
MKR?^Y5DP\7E&#+RIZM\L%Y]%01P/$WRLW;-OR?GN2:@S+5WU2(Z?ZRO'$R'.
M`*AF0BH.LZUN#^*3=]@W=\ICJD%0HBSB]]W&%_`:SK2NV(^7C=JBNBRK7C1V
M=7#EU%"6?579FT9W:U;3&6FHK)/=P2+0>3*+0!\(-%*959HJZ[GAN2E+,4?W
MR'KB,-@V1S*B.F05H1B=D7CO?)KG!JZI1V5SH+.LJ#]EA1H3-"#>=CN47RB"
M!=]>X\_7%K5723RKTM?JS5)[>^NCKD/BZF7^YI`A&DO>84I[@%@O5X3)ARPW
MT3JB-1P@3!6%XFCP%(1O+9-]DD[=YL;YWGJO`O\>P+"-DE@\=()4H$:I^*H'
M_A,3I"M7VZ;)SYX@K8CE;S<M&WQ!B[Q^'T&EPOP-4Y"$IA6]7($;:Q!VC./Z
M6N0-MWQ^UD7-PE^H2><BA?KE9`K1QG!A.B+S%^ZC%'RO,Y$!3<8.Q!(FOF"+
MS[,[3L`G5R+]@V61`B5?33ZDOD((CK]^MUXJ-!J)Y`IO4EQFP9@A>Q06DHE\
M"09-'8SO3^]&K:_%B+.V[$%&TV#$:CI'^;]'H7Z=\OG^[I@#9#XP\CX&8W09
M%3WHI\M'JG5P]C_V!]&U0(G339<O-.T>9;R^U>*Z73\>8@;5*(.N$$$V%DOL
M7IY/[=[%D75>1O6PWD_Q;)3XW(G]CM)M82#@V<0]?E;*<TL6[8\\>WB92%E2
MP:O%9GUAP>.&[J4#D,13Y>-ZQ)],*:W"/:&-*`+Q[#G.S+#KC%T,(;<FIR1L
M&YR\VPX4-Y)2)(QN>`JJ%RN%*VD3\O>AQ)U/U$\-!_AHWD?9S^E4%![:Z_BT
M_!5@,C$;?A2),DSE%A"4$_[IOHS\D;R@.D>W8(.F?";YY336;[WAT`F/^P=\
MN=JL[TA25,"[T*!G(VVU5MJ'E.CLVC.#'A\C&$=%JF>%D5<PB/,;]5,%?["D
M+ADEEW"X`\#(^`2%IF*>TAT5%^UYI^.'EENGV'A2)39L[$[<DQPG*D+\:D(M
M#XS-+3I:1\R?BE?0'G1.\R?&^=<^)BW(+[9(6,[D$;K[+SM<+&.TT$&Z?'@K
M]#2\/NB%DCH8_TNF07IKSB5(`1*Z!J6AD[<'-$QG+AAVPN%,W86/M0+^GRKT
M?XMMJ[4$5./%61A_F['-[8-`YE`+5`%-_:3N5H.4^Y&[K(M8TU87Z*$B*KTC
M^Q\/.%HJ=G-;$(4GT&U!&X+'^EAIS!R.EYPS7DU<M<4-_97"GC0>W23/-<<P
MB1ZV_I7,Q-89"WA\$4VFO5XC_0UOZ/H4M[2&:EB/&^_<N:3M+JX-KKV<L?SC
M_68E1#F.>`!XI0Q*7<6I95%.8?+0%)3IDR5DNZ--$(N?M1Z1EA%DT+2J&Y7N
MB/HAU":C.KFW>LQUMTFU:?_`=Z(^:!A-V*D0H--H=<ZSTDCA$+]*"^P%S/]^
M&?$C:U1%$O9_IZ232BM3[C6$!G%>@@A/4D58X6`VOHE^R:CJOVG59:E5&)1)
ML?"UJFU5)%(4;1'VLDB\9SB]%Z^27T!*(9/]4ME&5IO$4!>[!_//_N1;M];O
M;#<=I3QILG7F9];;93NAN<@;*"%8=XJP,?Q=ZP^E:\D%7.?W`UL[3,ZS/-V>
M&JFMAKG5176Y3<.4:OJ,:G.&7_<U<@$K.@RVLFODN$NPG!/Y3".6".\=24K^
M=9V"?.^53,#$MD5C53`&4`"*KL6#)KR#XMDG6Q![:Q4M48='\9AI$UG;O@ID
M3WFG>VZ`QF[P23*3`;#'W"QY^7GC<1.$LYQ<EZ-9`G'\<>+2ZO<_RTZOYA=H
M!1^?#,9?D!OO:+#/2_#,T7@.$;[QMA$4#;K04$7H"SF`14GDO^/@BY1_Z97<
M.9SK!GL%-/E-KI>C#$3!\+7K87U94]CZGI2[=7Y1^(.FG.&6DUA2.(4A**U!
M0(7([W:=`=W,+Z+_Q>KGQVW9-`>$MJR0@&*;4FW(\(Q@F-+(5;<KIS^N;@+.
MG;');S7Q'I49C-:<^/5XVIC]_(JM>)!^>I#)O9O">9PE`!>I\E1B4BEHL3,.
M%//[C%X-:WLB=P5O:"=S/;5,B)&SRE444"(BZ,F40LIB91_$M^%Y7Q7E>Q"0
M\N^Z66[+">MGCK5VM>"JS3Z9]E%NN)7>X%>^:9=>46-8%<>K>O<:U'3'X'NS
MU[6<BU]7\@@%5RBG/E<X!&$6TC#$UCBMU6:1#^$\]\WH$B4H?_!A:2Z.VC(B
M'^G81US&PF5[9EW1F+#];ZK:\.IWW'`Q^$_JHEB.@*L482)_EAW,"9]ILC6H
M);EEU2.A\L"/))S\R!RV67WS\9+/]#A:\1&W/7M,N1F*"XI..C8"&JE]'0@%
M#1L85:BQ0EM'7SC[#>UX4=*`A,DM&X%BGA.\-U+LB[E-C=L2I\OR$XR7^XN6
M0U-XK@X\B69BN92I67#:R5KH8E2_9CSD$\BRZW+'AUCRMP&EF$D[965`V%!L
M!\JF&+?LS^H3R!42=K3H<A$#H3-DG4QF4N*A6ND^R<*3Y.06/;^TGD'>70EO
M1DMIM#\ORW-GC)<22]3E2<3Z(`@,"4;3P<E2".;*[7I@R53^FL%RC`KK]YX_
MA9JDG*B?[,I<DB6-D&A4=:RIITFMV!<N@*13:5=W\*,,6&0,;%IW5;.GZ4:.
M?,^_,0'>`1[H"Z/>$HAK_TBB:^*40I3ZHXF"-"(F6>U/G$S"FG.QQ^OX.GE)
M(+^,F&<HVG"5J=UYL;48LJL?[CD['P=1/D6V/%2E!-?$2T=I)]D*WP5'IQT2
MV\'\5FC``;24/ETLB*=$+8G%"$@B[I^QR$@;R6M'W;FPP:MMXO`RV$KY3[$\
MD':80CAQ1TB-GO1S9F);;3N=7&CDQKL!&`N?5-=VTXO5P;=VK7WBF^%"E>@:
M?<'SC!?^07@YNM2.C^F0=P4B:T]E9C2GQ/0C=QIO6E4M,-!!//YSW`9PX'0*
MIMG-Z1CPO[N;P#"22:4PPD@_<=,X^[F>+`7;Z`52>WM>$9X<G%HUH`>Z(\4>
M+@;!M252XZKIA7'\D=P=^'K=:N&IX8)U1@YQFN\2XGK%W%7"*?)'+^E9S:TB
M4/W1R:%-K5]WPQ6![VV+^&AKP&9=](T^RUKPC6Z8A/[W3/[VO$9QL>:TJB((
M&\B@9WGYKCNI^_RD:3._1CN$MMTJ%TNDO(A@U8E":[:"10(!QJ/WD)HB__[(
M6UHXJC!VG0C0):&O%TF4;5@6&4,&K"-MU0D?,Y$DZ*\)Q$>FJ!!Y)Q6D\:2*
M:6``PBW!%MI:C69K71+O=GK0F\Z;YFE4X./-L`4O[QZDQ`\[V1'KR(6-Z]CT
MQS*5]S&%%,10T:@9UTE@Y9Z35+?B\6]6@Z[/WZ2+.FALUA>1I"Z4KN)L,W@F
M^R!0FT!<.!5*QS[2F/=`ABJ&GQ8M4C:+[4"K'"GTY(A^`3)7F>1Z<#>L.;0?
M/RC^X]$_%YBG<:+:6K>UX?H)D16I4:WDLA^;?W6LT+Q0?M>-+BNK*DN\Q5UE
M34/IZ6WF)G7UYS?8'9^[F)9X0Z^E$!IF]6&=9%/)/<W36Q5^";RRV'Q26=P?
M-Q.OZ+NYQ1HI&BN7@Y"M_6L_#-1P^2L[F;XY14!Y)/U`BY>N6\'CE]QACC//
M&'YW[FKW06$%4;3W1$CV$$NP.OW"(.5VU1(AV^3,OXXWQ_E5*<*.#XO.W62/
MS&/+`D@8T76'SKP&2Q@\^I*.-7Q%:P+L@]QN.6LPGH45&AB2]Y/-6G[WX>66
M-T8<8_B&2JLZK/1;W<8(W3T%$/ES$<9UG)@AQVI8)%6G`&*7)'\P_9AB6-5Q
M_0?+BV7,K$]RX?+X,[!:;<W00#A4]1%'><:[*]\!2JE=.J-X`<>7Z#!;_*NX
M#=Z*U%("^6);<8I,N>7A@4%1R>)VL\&(>6^>=5]UM%,>_P]:^;-TVPBB:NNI
M`W,3C>XH/+AYSYL,"T?E.^#:GI6G42A"64'R=TTI+`/P4HHSE3[!Q6VQS_>,
MGC2065&#!Q'A:OBK+Q))1M$!O'2$84KP(O),DO%TV=8,&=:+%BE9#RFQ6PZK
MHHV<-;WERTG1P(S9_'I;?4BW-"$/)+(DW2`G5VUG&M^`P+'C)K>%$YY,!Q$/
MIT?.=<2C-A\Z*WD$CBVAMF"O4LRJE^XRB*UZNJSLS78YX7A:`^L2692\:G;D
M#OM_N$R^[EVO*HH:$/7>F(839M4%R/</:;EFMNYS/6W,&C`QQ'<?,>W>-0W?
MI>+T8KOD`,)I/WFR23LV^,?0@9$6,!2CRH_3_#Y?:[.]M:U^7^50PZUDZICK
MK1+W#S*)3*J3&('(*PX,7JK5'9A1]H&AH"YXA'EOW2G)_@?N@O2CD.I?[7IK
M4,:NG0#L](RV%57I^I?+@)`J/(.<LF-^8:QU=<0LPQD[1!AB'Y+J7;Y;QTI#
M8E,JNTR8R1V0&+G,?NF'">XO]5DV+<4KCC\%H0C`Z&-,RA[.@*NF81A6$!`C
M;,KJ^(4=1K:*%=W#_()<::7KRHC(<(,BVX_K33/NA:T9AO>-391GY5P%>SS7
MH.Z7PU[/A;ATI+%/UBL1FD=1S.WVC_B?E0VR&Z<\U.YL,'0,OI`12JK[/&4&
M5+N70`<-?IMD'EG2-Q3$L;`F"5F1*,";8SA3#(V+IV;O[J:X]>#],!\UOAA7
MA]GJBOB;X!ZDS3<NKVC`T^EDH6',S3QD;R"8)234G'O"0XG^Y+'."$A8\UIB
M;#)SC=:[;DCH%H&?7$8Z.LAI/0LB,$13WG,!MM<FB;]3'-TLHK,.&DU>Z\5I
MY7:N)XU#Q;/G*KK_+ZYK)]7,#3*B.$]&I.->XB.6=V]%\G=7P)M?O=U8<)9G
MI][;(-R5:A"E\%W7%@$NF%&5E/@NI=]8:SU&RLAV&]&\`&C]R'#25U-6Y*6%
M*&)/6/P.R@4)K)3)ZY$5L&PGZIBBDY9W3!M%;2]V\].+O^AR!'89)5DQ[W6O
MHKN@?P_ZN#$8C``;HJ6*\%;;2=ED1%Z0"%<M9@4-+\TYF9P%;;SE2<;1K%,R
M?"^Q!(&05CO94!P/S="[AB#B7B?BE9.XHXL5Z:0ZE@/Y75:1^6UT1<=\KUWQ
M1.3_I9AQ-AKI*QU3W7G6?Z?4<UGEYA6RBP+[6'XOW443LW6A[%]9V<\R:/,I
MI0]QIID;0C3[*[G+@YH+]BWP_K]=XV"F\]J;]K^X(=!AF4N1`<COFS'<UR;7
M`7<+?BJ<D5SIO9NV\\U&V9W&"[JG,5!,KFGWO9(24<^50'4`<C:F=XO?'"-!
MY*GG")GFF3P):*A&EAY,7L.S4V9!V(@A#V/0%4/(-^R1BM:79UO+W%+2H:G!
M9_>,J<OO=^),B2;0'XL90&#%PJ(W0$`5+!%5@T7F2;8XK3G<5B03Y4IX2$C@
M8W[920.&,NMWI_`'(43)_.,OK*-OB.X%N4LWW^)79/J$=HZZ)&_QO3H)_I1.
MI2D.F0Z$Z$SI@$!(0JG<K)3(]8$`^\/FOQ>GCG]#1.'E#V`C>B#ON]G-%M]3
M7+$J&F>ES2BHE_LYFW9/!@@Y[RTS'125PWMB<J[.S'<G:[S*QVGW'99>OMU$
MB4.3E6S6(86$YF_'M7)^U*0JU%<3]G":Y*Q[,EBK&^FQPS=Q7X0'+L."[LNV
M&_J(Y1,;R"M.M<15%%_$T6I>CLP`>]IPKAHQO9J+6'9Z."%!1?!7A_&NA]6-
M216=QV4G%C>VL1%`Z\>(REE`)?;L'K)E^&RT!VY.*LXCVK"ZJR,GI/K]EW^1
M->Z_&G_QA0-.MQ)P\K0F$@:OZH+I/E`9F$F,J4YH1A$K/K,877?PJP4`EWJ`
M4#XI^O/+DT)HF;S`F"')'+IISY>Y.E"2[>?;G9*DWW556'G)-N,7DX^E.7FB
M-E$G+;7=LN<RD.9R?C:1-:&KP$'V`]M;TP%='\I^\C(,L'BTWM2H&JSYK!C9
M+#]!03P^OD0DT%?0E.H-Z9OG0^W-G9O9W619MYYP-[I65U)_A@UP5/?P$AD^
M(R10O"`^:#R[%BI@%Z"'IF,)IE$HJMK.@DN';43!*TE!TP>%?42+8"=5A'\6
M]P$A>ER2/ECA@F8A,)QE3Z:*P5(Q`45_D"3LSIS[$$K00-T=U>:=\'QA`FLD
M41/937,$'-Z:MZ]]9@J8OLH#[,?_32JPW1'AC"SM"U:B8L2">E0W`W95:=GZ
MWZT:H]^WLT]>Y7]6WIH,<WP'VY2S_]XI8RI-@]\7W/R0HQ`?YB[G/BXW^O?"
MFM7H!41<2;I+Y-^H.5?(+%O9,0X8.PGQC6A%YDM,HJ(?-P.WN&8<I&54L5M<
MID+?E<F8T/^/:^=PR)7QPL@2.C=4H$";B-*-?B#-OO+[H'P`W9]-][U[!DU>
MLG^%SOV])_BGW=!3?M@I&:ZN$UV/#C0'RCUY0.PE#(L>AI]/*M8H\W,LW@C!
M^)4&-"/1CCX>$$J_@H90N&\^B5/IR`)]9ATX`12F1?K\@HC-%6-)=8/>'*8^
MXX7(^8@:-W,*MJ)1\LZB,"SROV;";R[5TL$BJ')]8VZWKL\GBR"1IBQ3UR9:
MMM)1FNT1N<<,-KJ6^5(&H8I!U2E8`S#>=APS^*E:3NWAT2;X._V7;65K:0P0
M\DH#?;5=2<-8+M+$J,A"C-C<@,&;+<6Q/:^(DF+2@7W%@^>\DE#ZOO_->>47
M@[=DH0"4[%J(6;>KB<+/G(I;`+M.FZWDB#QF=%EG*[.HW7C"+0C3U"F[2+?5
MOE4L=TEX0)"H9+<T22Y<QU=/^>T[I*V?N4;I5)&5;U0L*6%A()W=,C\A=$L3
M7UU#H(LQXO0=68&-HK\.;O#VX5F^#6))Z>R7(UP7BPKY#247I6#F:.K&\L/A
M`%%T`QPF4%@=CBF&8AX]'PU2YU]"F>55M1'!"D+ARMYQ;A6ZN/'Y@?Y??B^1
MNO.L-2ATZ3A!MU5@#VAP$,;!/.JJ=G!H/S#D]*N6/U.MS+P=F&J+`@I5=#T]
MIXQGR&S2M!=4M_+43E5I*.GL]:Q]'LBV$_W$/!)+8+AJV][SJ6Z3<PU`<E+<
M$?B1SVT#\4)F+2%'ZYLM"VCKL5Q#V1!:2#7O_'R"*FZ6Z`?^_3]?\N!8Z5[4
M2XY*9\)XHE;=G:]JIQ<B_^ZC=0P5%238C=#IP/8!8,"AS)%U12#]DWL.'IN*
MD5VR=PU#D:@V8**/@I.*]_NU%U[)61?64ZA7UD%3`7>F8<%-VFHU&#3&5J?8
MCI6F@,-W:ENG8+A+5PE83BWJ1U'^RC/*T-(G^$634/_>!R>3W$\[5/44[?JX
M4DB;W.V_+""S96U1:NRGW&@U;=.R/?)Y[+5$U)-NK%KA.=2F00^"SH5%KO#I
M;`RQP5/IF9A\B&9(?YHF<HZD2LLH1A-\#Q3!\:B"98!VS0Q\#^83[6]@4R'>
M'=BP$.#G;\[NJ<YF9^+7FU00>UE-@Z<9O@-A@I>AGL%N53Q<XP<+&!Q_I-^`
MP[%OH$RLY[YAR@P$Q/0JUB(%K=6-34[&7T;[>T`=J>A+$+:*P)`8G"P+R5.E
MK?V(CU8-9!%LE)_\+3):A[O)%(Q^I-4-_.$*9J.)A)1.18CQ)E/-^Z,<=;W;
M*J8`K+@`I<?,'KH-]8$-.U?][-L@_L.PR%Z1HEI$\$1]&9<D*TDA*D._PGBW
M":3N'"TH>N6^DHA,G]X?D@9/-+E/,\I$5R.3-X@C!4Q1'G$:.ZNE"I>(BE&U
MT:A1TV8DIY8\?T\Y`XH@J,;+CI76R-K[,Z"H8@3TLQJZ^&8$*)R3S%^H`)#[
M+)G]V"U+AKI09ZU,:[?#F/]8*/81`][37_;Z)Z)^?_55@.W4D$HEY_1\'?!3
M5.F<90N]7^W.E\=R5F!J@T*Q"C:\>T$Y>RZC#9<Q&`65ST%=K4(`O\0K^G=H
MI&GEP1>*+Q#=RBLOA%NVS+;*O&P,W33[),:S7$N*CV(*O`.7NO/JK,VYG3<T
MK1"JN['I/+3[73OF;1S43CILIB`;@.+S)F8TV1/\'*;-F'O-<(U7_RW+Q7P]
MX"Z2^+M0]IA<6]LT6R>B?+U`UWFB6G[=#9]W;2!;N]4@'5^J5UO2VQ>>QK1^
MS_SN1J3"PQ]@+X]W\+:PL*J&P0ZD>@S/J;4#)@#FC%J0JWWFT@7:*'GPB4J-
M42WO!"ET.?T)$)8U<6I%ZXOY5KJ&9:4MM06M>G3$*&1K',0#]TQ1$*Q^Y0K3
MFO*61QWB"%=YQ)_TXL.8,F\V^/#P<Y)TJ$'\1>8-"F2NJ8K.5`&/XW45]N0?
MDTB`;[9PPREW1\-[KJ^CA'>!6Q=U;+O$Q4ES!2R&CPD+^^4@``5\7F):1E-H
MA"E?`-UG0E.'IC\4=VWN43.FL0C&I)VPV8_HF.XJB0[I&H2DG#>:Y8):0,OM
M*>893'$FTY1Q)$/N#3>-]-!C_[^ET4!S%<&])RQWJ]]S[GR5\8/KQ+H9^C";
MV.6<)5?L/J2N[#=)<'9B?6Z7$C_)IJ&`5V"&O>]=.TR,'4PIT5CJ9_"V$;47
MV1ZIC6S&Q19T:EN##EWQ=&O'_>;/P#Q1IXY2&3GR&.(S:KY;N\XV+W\X44EQ
MJUX32`DCNH4)8S@N7WAY2EV/#)=1/_S\3AI[99!_8D3L1QRA<>_IA5=A$#A4
MW.!\?@\!)!H"*=?Y5$9J7G)@[#_8)/TU`N1%!D@.#AMM#J?FH-?[W%FN'?/D
M)-:!G4O-L9@FO?;)-:'!2D@DSFJX=.$IB>'1D)F?Y!/(BED)+>/I)/NV*WA%
MI?JA;J^QDZ<!7'^VO;GV3$`8#D/<YMG@_MT2^^8%U9R].-.<QO]Z2+`"#T;+
MOI*,L`[J$B^2*LRU'.AT(K=M+[\_7SOUHS/CZ=*+H#BA/,GTPQYVX9Y!Z'\&
MVI/<9$B4'-3:5*W8MO/UC8HEO&-FNZ21](XSL*2<E:?`K+GY"^62[./ET$!7
MW0;.5RM!?/3YWE&'!MS_L]4:/]\`F%UM8F_G8P<._<+WV1C`[R6)`;T*QS3F
MLW)UG")/*>)O/$\3/"S-HT<SWD0EOV6(@U%TG'@X][AIS(2-C?)ZM]N?O3DL
MG;\;P(MD1WJ6/F*MW5N^$B1'5O`M2Q]R[4X2SLKFG40OHG1@`SJ*CN-SG*Y(
MI84`BFW/)%U\Z>U@LGS)MLJ&.WQRZO4C5H]-_VMUR4,U[TU]A/(6,IT:R$/!
M:_R/P:V/0OQ[Z&_BHVYKV85UP"@))DQBG,!+U)9616C[1,P#'BL_$X2JW6<*
M,!,DO)_<EFI@;KA),-A&H(2Q8O@[6>,W=U)2),T(.$S7"'\S*]8#!?4[DS2:
M@?'#=)T*UWNNY\0]GDQ5^`V".`.501*@S.H_",F3F*V@R6X3$AYX!/[_GKB!
MY8,X0$D`QX+`.4@SB)$X)=Y?1[B"FSF0?$5RPF.ESP]$$;`4Z"WUH1%SQ[]4
M]RUIXR^\3S.@,*6#^7T-3WFBTJ&\U9<[_?/C7O<OTE2*7(HN.ITS@1@<%1'[
M-6S+6;"`O"QN6@;?G7N42N4;P9QI[_G"2Q=BB'6'_?K]O@E@W(O4,G59PVXV
M>-"?+`TEZ2Y\@S.G8`)_IRU8&JD96)#`K\:;SR)!Z;7V(/,X01.6,Z;=&H2>
MV/"T;P:4,S!<XAP3G[!S2.N-'_V*:V]U;>%9]!-YKTHU%"9$.&0,IB;XP8DT
M+UM'V8NB.=IE]PL?%_MD18ZL'4V=GF-^&G>G*AP)\:CSV._6I*[]:PA>A]K$
MJ:&[EK*]QI[G7H?//0*(70V="7S5SA;2]-]BY$/_[^!AT]:H)06Y(D`=LM*O
MWB^R,YZ%+7R\H%K6)+^`-PBY3V[;X96#0+=.@R\EWA$S,7/MY@>2JK<MY5DV
M[%_EU1+,N")FL&_*H`P$4;WL_-XE@<<T3X\/3%!N^(G9YM5G=+K^VRMVR5#)
MJ+HK@H\?XEE#="RR"/V?#FI53[?GUU<!2`*7>3<<!\X"W^YMY\W85P4=D>SW
MO`F65Z(C5Z$06A=HH?RP&'\_[D.V$$(`FZJ;9;`SU*F)U6[QR/-/]R7/:')(
M$$'ZN#>+U[3(K-[_+/^^BK>)87"O@DY?8H!>YK@&\<=K,65JEG8R&H_-E5_]
M9C5(^'1YC7L>B^C+_L<RX@$M-SV!-K2@!'KA79>RC$.W30&<0"_['"*I$4XS
M7FAM!1BI%,G@']"JD<'L@NVI<UO%CV^A^7N?I_MJAE[EG4DDIED2;Y%DK`B:
M#V+T785&HQLRK9S28(=@*9&G";5GY*(DE(9[O0A&ANW0[ZA/RN.'3W=_FJ>O
M[NV`_":\EGS-O3YL4$B#V0RHOM4,H(_U*5Q,QU$L\3IE9E"*=53A*KT>QOQL
M:;^"U,U&[5K0-0Y'OI+5G`,I<'EL^!-K.6SXUN6,QE"R&PFH>TW("#PKS=),
M81S\Y@(@&HSAD!I#F,XNK;+KU&G,-2T<60<U__%"%\)9'R8=/NF*->;TYL<,
M1@>Y*)5O)RHFL4*=AXTL9G`I@GM?9928._+KW#5(>A=[?@+,II)22#`NAU2E
MO]QOFEWZ'W06KZJ%(F2N''^>#Z2V32;D],01FKQ9^6"TY77@DV2Z-KI6P!_$
M:^:,R%K,[)BSWUPY*O)GZ5#V5A^X1&-(/_>%$K]N14R\>&<+QT>61K$Z+.;@
M2RVQ''T0;UT9M(BM%T884>)K>0C"2`@X48*^KG?/=,/,"M<:[GJE7V%R!TG`
M,P;_$4,UZO#-J4LRQ%\*TL;H8XA$8V")^LE=&;95U6'$E<"0/&]-S";4(_`Z
M9CH_=-*M#JD1#E0PX3)/8467-DBJQW.#Z%YE2/4GH8UE:]/O2Z-;#NR0</A!
M%E#'2P6TFPZ%AR^:LJU\[GFJJ;FK>LT>)@RA)@5K&KB/K7M^BZBFBJ*T':<)
MS[UO%6LPHD3>123&O4&FF9!O"+PM-21H0!)!J0F87F:3#!7?7R20/UBTYH_K
M=]EY(9+,0P7SZ!:8]&4^7E^$T*><`&UPT")RVW_.=B6Q/LB<-U^S)IIF$1!-
MSN-@'>HW'(ET&0M/,-?=?;PA,%5@>1-0>;XI?LG`>REA3SW_F)UJPNF3;VO'
M*_\9B=[OETS'RUH),YA\>UT;DXO9=T2&M<$VN*E>7FJ')X"[(H2TMF3Y7D?=
M`)J%SQ#:[2T%B9O-A6_9],*?YUA;3%8S-F#N.,$J3R(2\AK'#!P?%!=Y&%E=
MN3C4H,>!V=>"/XB_`QYRMGU[*XS09YJ%]3ZD7LP[TN176X4%,0,5*G<#A^I5
MH&L^<[_)ARS-$6M9AF'#XP;GUMNI#?&D*29%_]LN[0B`Y!UN4M>E9/ZJ1106
MMF)T,>?(]2`RZ9LH\<AI.B8!W.<OPF8"04.+*6+.F-Y=`U?W%)GG<N9E62V@
MM+V7QR>+.#*./>/3N,WB7'^E5+@<Y!:1CR6U6(9YL<2=G$L<6_]C9=P,BV*@
M,6@QCAM`:)7.?2S#_U0HIA@,RD'`)KG)HVY/KC8E#FOLJ/0X&BC*B#9EZW:1
M%W;:.W>WW)ZT,]8L^%JBY"M._/UC"CSA=N77M-L0D_P'1[5QG-WC\N,DP!;3
M-R090R<NYRL+ZR4U0O^[K`&<J`(Y%4M[3O:J+L^9%IFQBM-'T^#:O8^72)1Z
M%U=2.LYRU4WQ_7;4"_^(!C-I/]0[^1-A'="]<7XESU[F.M]['RSG\9D<UQRB
M",F]MK%-"*5PU#-3\>FY?VZ0H#\T+!XM^;%GCSGI#@?5&/U&38``@BICKY4.
M<BW_^2M8_^VF:K+&J4E1;*S]!.0]H;V)%7<)0^&'<CU@Y7IJ5LPY9(M%A^Z/
MHEF:=Q*Q%?"L3]OQ>=:R_S4N#%RQ0<"NQ7#<W$8.I^ZH`)U"-RFJE8R2-`O>
M4(('>ABQ-RL`U2[51SN\9CJF\>H^9D8QH@'92AHMX,\2,]<B`CE8K;OD=9;S
M3S5.7&X9.6!%%='3B?U7-]D-U]A+V`-GRG9<W<:43&SOIJ%S,Q1.^(*"62H`
M7MHZ98VY@ESR@2>^OGDRC<`VI0!,PC<&&RQ;9&_,:DRD*!4E#[TI=JT8J?M]
MS$W9^R_BT0?(=4O1NH;'$OD^+<W-N0\7R*N)QZV6P3Z9A[H7QW?BW'?R&C/Y
MQ'PZJ!)/L23DW=E!':ZC0ZO/%P03$]-PHNJ7,_/?H%#(C,P+I;^"_]Y>\^;D
M3[=.WT2<@A;!FWC-54MHL0!:U#&@E^&P?L#G&*A8O-FF$Y:WDNH[(5`T1I+"
MN_GC4C,3B1B?&#Z)5+PS6/\@MR1KSP]4RX125MS]<7;TILHK\O&WCHA7/5XP
M9OOY%&-$6H8>.U%L=R]6N;&27V/OO].#9#\3D/[TLIR&H76Y.GU_26HRY,(V
M^U%,XG>J04#TO!5EED.)O)O>,#:QECF7N(,]+ODQ-:@4&PG5[F9WHG;$>$OJ
M+,`C\[L$Q`?CWPZ)C'>L"3OB#7Y>RG2JI>1XS7.FU<(F_3\>YD7TE7,57>EA
M1857AP1/4*BJA(_T:-H"I-.AP6AYSQ"7Q,HOW$[?XUH36EF_]HX1-KAF,;O5
MQ5+1_9N1JK;-"@Q3H*38?<<:<"2ALY4<8C+VDLFER>A/5=I!AJ/T$\2[-I-N
M%1DOBX^(3/P$MW/%S4\)G*/QRB7,MNA-F2U\)*/:/]8^V!GJ8%7V"N^7,HT;
MRAULIJ;[:>`&Y*6=XK4M5ILFG,4L5S-`)7;/G$G%\,4,*3LH-!H`.?H(NLZM
M%T[:G.*D?_*?-E'1HS\-M8?5QV);P`/)M8U0;B_7R\R=Q,ULC^7_9`K-^D+Q
M&`7`_Z)<E[4L1<N;:SE@Y.F30\B_8"Y4!S76G(*1)VAJI&*-S1'[]/7QRRGR
MT8Y$_J&J1'_/H"X/3Z$)/H(IHG'_3B,#%KU^R`FC=+T`]'I%Y%>'G=08BC70
MEM>":R\0E19/1A]Y":*E36VS*"\<^K^C=5*E%`4,4`,<(@XZ"BL7!YFIOK*B
MM$NELM'Z6OYPGAD-Z4N&O0J+)G4']34UG"<B$=@1-%M#@IWH$U@>.%B"@GB$
MR`R1WA-%U1<FB%P@%?8'51C`6&S*_>`%:`L0$B([XPE'UUKG](?_4KJ48R>W
MX;.D\;EX4P,25/8EPP)^O#[J(B,J=S>@)LOY2J9]*72Y*OLW`RYOG?&?UT("
MW@/Q!]0RUH@-7LD+BMQB94)1[$S'&J\)/$-OI4I?6"1K19)4R[$E9]]%CBY)
M2DBQ$]DSGT<[$RLNY;SB8$0-5H)T)C2H=$^?5C=8,NIE5[\'?K#LW(+.A!$U
M;P2UO.5TC^W<EIUDO.PO>5T2[0K&GENUQ!)Y3,`ZQ8-)X^.69+[^/8?X<>P#
MV_L,\%7+=P76M>A**`V31@P.3<,X*]A[B!*2M%!>X$TK0S`2\'D#QCK(_SFN
MS!IC?U"+$"3+&6I1!UL:JOD\+P^;F;*6012<6H7U5$#\P42[>CH_SQ:47HW0
M(M$[_FP*]K!*';QB3"X#^\6[RRJAO1A=C6NSV<U4K$B3/=6>WJ<GV5RJA,A"
M%HW+/IQ>@=@^!1KNSVPLI/[#M,`9SER0<V0M9#<X#9@_UN,8TQ[P(659"=T,
M1;T-V&T<P2]VI[2/GIE-9$[U\JE)3-;YK#5%8_JXF(*1H""3W&*=T526T2)7
MW#'OL#-"H!D>QRWH''!P)P-+<V;Y."H^IY*\0`SW?F5."B0S=_-MK)`75@VA
M6*B430I#H:Y?J:<3=EZ=+?VH&EF<JAA5O7V$V%9W*RLPZZS0WN=@'11["G,]
M+;NZ?PY:L!QJU\CP*(2,@85)^[)G=@&.#_1'LE)E%`;V68MP<`!SYG?[W%:6
M8U$95LOO6K11)*AN1))?P'#VG#'*#;#K`0>*1FFFB>PQM_$;5]=5PQ,/]9^P
M<:^"4U:9*IOJZ/7#B%\,-*"J7Y'L'H&/2`63Y/?;XE7Y,&K<2W7"DQD$?M$,
MLB+_7U26C621MI-FO^FBU^ZY*L&\[.;'#]E[!GLZ;LK:CG1Z<QAI!=(+_^+P
M6U5L<T0M,4R<L]]U10>S+D2\QB2#R>^32OXKUG.03G74,!SK!O/P\OKZD\D4
M:L".HAQ#CR*S!"K3;?L(J-UU&QE"98-<NZO096WWKIB9.&17H^=(LK5XH^J[
M52353S@Y^C:29+5,M(B:&LF)L*`KAKVN[S6EX)JGX/(@=9Q?'#ZMZC&H8"2(
MQAHM=]@7]+-K<TD]+CJ[_8S8P\=#^-U](',-3=MVXF;P>(-0J_M0/5[)W.2Q
MN]J#OPS#7VAQ/H)1J^*V\E__4/S_4FH>?H/N(?E+:_N[S_HU9J6F>LV%G=`+
M3N8,RQWOO0"%KE0$;ID?LF1$@2&*I*QFCSG]I6L2&I72VOJWM%EQ8Y;'!-A)
MC_)@]Q"DD\V`I:,39%@,5;$Q941:*>>?XB-WD;A)7*&L?J4KUX:LJ\-W'"%S
MGTST'.3:F@A6YB!<WPU'2:=)S=.-XE)!:MC9.(3T$:[ZUUIS&+#0S[/LVB[4
MD:35*`)]T<GAG?.'?M8F&^_@";E#_6=^B1RQ,+K2_T%:.,J"`ZL(D\6N'3^L
MFSV%^U4PU^6C7+/LJK^X[8MZ/CY[XGA@T79U'LV6MZ<VCT9ZJ#,K/E++UTO9
M%_'+AT3`<V-UPK0C+QM/_XZ;#)/*F/N9G2UVP4ZJT2;.=C%5_RX/E&6!`R)J
M-:[E',$/%0P?L?:'_]`%CO,$A;W<]<#A(>WG>ARFI:TYV(C:&HVCOX:+>`1M
M"(IJ6-1;*<NO<VSKAC[1)FEA%^!4!\DPL\6H20@U1Y$!#4,_G*X%V]P(!G.S
MKLSLPYT"ZR'>-+(.R(:'L7D6##YR!.FW])L+LW(;6HKQ'>L8O/_6E(UK_?"\
MZI)Z75"F($>L1VR1ZY+ENTN++G*`1N%(1(@-<C/!R$QR9$9-'$<B#2A:==DQ
M4EVVE*-(H-MZ"HQ/95@BZ]=)G,+?9K9RO6[#\Q0QS`#AE`L(UDR-)_21S-IF
M7YO#\"6EUZ\Q:\`D+A-AF3M%-B4X/V)_7?1A)':354BW]FHUTP_Q_QKO]R;E
M5$F*O/^,JV_OG5$]5Q(Y9A]!3W2>:M&FG0Y'DL2WMUBS#'97.$C@>3B<WKX!
MS%E@.8Q56LY9O#R&UZ'1L<W30_3TT@!4-``9;4AT-,P%[245'GNLMPLR5>."
M0P\0CEX78W[;&I_3S_2D#UYN`Q`\NRJU;77>KS6^LW[]8*]X*,1]4]V.>F5A
M9X1!6"39#T=L??,DIBLF^&C:"A]\>CB(VRR$7EE5&>:;QWMBNQE#B&\1?`E.
M,C.8^+'-IU)DL2&KSDX+L];G]C04RR)<27;KK`Z8U`C:G@DN.:[@`*R`:XL)
M>Z7,&LXO[L[6#.P_6N?C4B.3TCGMK-4\M"`%@F\5&Z&.>O&[[9>ZQ*:!5L1G
MS&4[T8;UT7NG=!S[XE?(;T\AR^:[9\;0%-@QJJ,\=D1]3*GT*<>PMF[*2``+
MY2]D1CW*8`NT.O?C+<"S3KT)&W?^-3*]D=&_;U"\Y><UZ<9I6WFX!HBI<%/6
MM!"D&1]NEX?Y_4-__HU1M#7$`K3SY8V(+E[DS1[S:=F$Q[5K>[!Z*VY@:I,9
M_4YAU.$[NI_8\FC\SZ+9&[O'Z]]OL-+-]>B7XWB@$$YO92WVGU'6ROZ;?6HB
MQ9,/,:=5SOTR8;A_L8M7S;^2`^6QIOI*<%B`8<="OZ*J@N)!LIE[%D3#_DL^
M%KXB!G*9CIBV'!1-?2=1518,V`<9,)@F@7-/C]_NL&!>&H;S5G\8ML$.(B$=
MT,M^YI=;K-TR4[?&E%RQ[^E9YY=,D5(UD-G;EU"RKUQ[W5PR:;(("<\2NCQ?
MJ+Z86L?'H.I-+Z";OL!HON<A6[P;K/^RJRQ5VYB+NU)@^IW1C6:X@.*XH!HT
M0'G4`8&WQ&.0+.,VC!'Q(\[U>)N\KB04?@YO$=X!$.I1E@$!FFRS?7UO"LRJ
MG.A9B+,-$O=8%4?MHBO#T,0HY?#HF#HHP=;<Q*)X_8$P!&XY<I7<+:.V+^5!
MIEC$F?4H2YCU:H((]/"K,D>"FH0UZE12]%/Z5Z<9V<P:MYOT@6$_LF3Y2"\)
M-YB@,)30Q?S0N8!Z?(_:09*664793AYHG@P53E>U=M,-SAGZZQ>#ZW>C;?!Y
MOT"Q?KYZ.:K*R6ENB533*L2B@[J=3;<RGN6!IKZCK)J=YKIHE4V&OVRCO4L9
M`"2!:98NZWDMIS*-SE()5*9G4[UN!D**]6/[(@9(7T&N`J3#:?JED5<\?[_"
M"]H)"G]3V.XC<;^["_,'C'K982LVV_%M"#V:G3EW4V(#R72@3:^;?QH8&(S(
M1WM9^#^:U'"TWYGOU&#.9A<TCP*5(PVO^[:P(,3D(S$EYT7;^FI?$6-;UJYL
MFSU+!W[V:VLJV@AIQ-"E[0%:5GAU<^RN0]:E^/F;[/Z'6)9WD,C]>@3KGIYF
M6<!Q:Q[3H;/0W)/:.9O5J$VQ7XSA</2ZZ^=\]BPU5V"<XX?<GL.[$K7;&F@F
M^(,`]9%;:P47C=GPDH;8MI"2N,?\;J+L5A]-PEM1,AUAQ:`U;_&&%2''+T'[
M'$!LX[.$]=>O`?]$7HOHD[W$%)\F,22Z9=?,36IY,)SH\\EV=%8U"AA"T9$A
M;B335#/-^?6_,LMP5B&06":>A[1GK,_":"5:9/YTWNH[\L$P-5:;_@_DR@?F
MK]\&KETV1Q*L.&69N.,P';9[,.C`/A2&X#-^88<5<)5;7[F'7Q=\O6>4`((X
M0YF$;XO#CSJN*$A(9^^C`K<-0+TB^,/'A1BSW]HQ]1E%0+7`F^Q#(_SR80K&
M`!Z1H+NU(5Z3>=1#IP;[<Z17E69KA2HR,_UHV!;V0]BOM.M&BP^:ZES%+B@8
M]HGL?!?T+-9KOR?[7DE[ZA=0RX5SQX)S8^:>9M*J;NH-=,E(^A#?FLD*N9T0
M*B5K-CA.MD-#RX0LE(!=>VNTX.,6JW&9O,K+N6$R1:R0?B]D\GOU!%2,]-\Z
M0Q$KHOTSIV&J@W)?0^SZ-@N',;*!@$.3\7)%?AF5<$VM&]D:<KG"X8-`%PXD
M25_BCL-C;X%^=K#`7IFG<&@`[EK_'2$E)M49,HG8=?1@*O`SN=8<H4NKUJ(3
M:]6ME\C'8%MJ@HZ"EX3+^KV*G4V5O-$:(N-T*R+]R6F>8[%BX044#=^Y570#
M%#5\_=;I<H,?\KB_8Q_=.;<\R+V@S],YPT4A^OS&YAY>QH8YI'>I0:VV.<!N
M"T2+5NRF"1R354CZ3H_L+=R^P"T5`M;OVM=]!H-T7.S($Q,GT`KBVP3=`PMO
M,/86:&AT&.F!O80\D)<Q,5U_O9E';Q7K%WJT2/-/P.#D[G.<N[`*80YK$CRK
MU=^.G=MU66%++T&H@3>U]H\=G#C)G^2*L^X.]"'NHB>)\BID`DI%/VV)00),
M8I@LHK&=$T3>!YG%_>:&R).%Z^&N\XMQ/U!<20.$Z41]=0%H)I_ZY$IF%%P[
MI(L1*A?I*`#,H^\%6<GA>ZCUREJ8[^(8ZPZJE$1G$_^WK3Y%H7O^?BHUPQ=#
M8K*$Z'^V#5022/.=<DQ?L4FVB3E@.%%V'P/0!T?-3HM^?">S%X/G7CI$&6%"
MIR<^[TW6`4Y]C1L:D&2HB+=E6,MAFE2#Y5-=OG)0D?GS<0.782<V0U85R<:%
M.8\2DIHO"?'J,>ZV&N`HM8`I*E3N$#RA?HH,&5_N)A4RVME<N&.RU]@'FKX3
M[X'R]J!`MSJP_>DT&FE>'0*'I##'G'18CMX>0^N9[`"J<,>RA&^>C)R26.U8
MHP/_\A2FI?]!1#TPQ<YH<(W""2#="_31CK\'G#WZ!:LEZ[KF0,(',FU]O;:[
M6&$0#06RKSL;@6=P3Z:8XP]D24-QMR'*PZ%Z.J;U:?1IR$3_"$_2`R62I/_V
M^G-8OQDDX\FM3%#`F7J?;H.QA+";;M4Q4@R=-R-JM"VGH0&2Q(H>NBOK''=L
MKL;@OW._$`BU=?+28P0=+%=#&.'CYZ]<,BS#&6I8;*,CGPEOG=8_,I20$9T!
M#T3[S2![&H.Q<.*2:X^$8LG-)<KQ&I)P:2%M2LGN=`]<]%)L5]8;,MX>S[P?
M)?`+I6)>3W-#+E!8)F/G<[]9<`L6S*_/N@H1I4%Y+AE8R\+X!4(`.Y0>'0IE
MU%5(`);W[?O.%@G)]`^GQ:\!\SCU$R'["GP8!DB8/Z&F`>@>>9^?!]O5@1Y"
M77NWXE3\(?/@DJ3>?`ZK&+AQ\N!]/J":.-:AD!Y-@F-4=#^'4K00^8_(MY60
M=FPF`J3C:M.7Z?A.C,=9!IGOIWJN]_D"UJ\F0DA8%309Y41F.I5/P.?Z;X^*
MS/F;.[-\6QR>'6SU]>S8KB9SDMN*KH_=&U#!7<*79:+'FR-D1A^4(W*$8LU>
MHVX"><6_9%\,CJH59&FB>+W:?`$RZ^!7*8SYSOE4=+HS/#]P:'`@96-H;R<\
M/PHG.S\^\!0MFI\#0YYC)OR;XRP&`S0WM;-4D<'85=7HO&7.@Y;K0&30L%]X
M.F27.,V>>I#SQR3['`-G`A;2\!(@P&L;@NCPO()#YQY0/T"P&O<]S.-)OHCG
MO<('8(N&U%9HI[UDF<5]TEW-.T98<&]2>6,/KO/+:YP9/"9BGD]T@</?J:"6
M$;98SU3]@D'H$%&<BS4DNW3KM)K;<2DW+$%&IUEXZX$3PM>14=,9MVR1]_9B
M!'A5AS:*+\A?[JO[9M:NH?QJC+$KATVG#`S#A2(M[T2('8`/0\1\?)R+7YZZ
M8#E#;>1D^S&!M:N[*$W7;;>8\>O*]CLU@GEY0X"&0H`9*M%'NL*F%VX^R$:-
MD8/N'0C5U%96?4)P-UMHK?HD[(>%'T4`%'R1:*85YZ9GX).H1,=)93EA3Z&W
M(H?N.QG(#;\\@S+QVDE$,YOPYN!T#Y0J4%2K@,B..%$MWM5*@/.TXZ4RUL8*
MZLYE.'@[Y],@!R-)$:F?><'*#YZZ?"345V)\FQ-#O83K_#M!U*]QW[&<C>[0
MOTW4,ZD,K;/5`YD)=L/8[N?^PD\I`0(*@O\T$>+PWY1RE`+:AX=KIJS#$9GL
M`.R@&`(T!?;G)`CH,$8-HDLS4PZ:ZG=-O%NT!N?5O1*H"@K\+OD+(*"3(<N;
M/%"1$5]2UWM8$Y.2K%6"1-*<J!-ST<'7]+R._Z]&[6"QN4`_]$.PI!1L6'QL
MF_9<KJ@$U@"!;IDD.6_G%U1H9'UW:9GL[O*5$M:0ZP1C2F:0]&0E-V1+S>IZ
MI@7%VZ'#\8P'[]ZD`*-2^'@M]055DZX,=*WAIK?>&N]T>IJ]CVVSE>;[DV(M
M+F6@;0+M`_.:#M#D$1,/=7ON_5T351UP$3^FBC"K&RPM_<);@1ZWE#6KG&BZ
M#A%1&#Z\"4IY,UHN6]Q%"E\_*ML$L8X](+F/@L%'D>MECRM@E^1XS@_*V\X,
ML$0HLIHK8.2P+:6FJA&>:,["2[_!SOS:F+/]\O@VI;J2Q9N<F[KVXB"'CIX`
MW+<H9E;W`UC:L4C#SB'+3E,!@"MTHQ8@B>E"3\<L4,E-A[ZVB?\;A9>W`01W
M6DC_%A9?J=V1D]=^P^DQF;F`)E_3N2(=D@_GN@!2BG8JU,P$,*"]Q(-^@M-?
M6K0XSUD'AN1FG;J)NX3V,#YQ&KR!_`S=,F>!,XNC;F#2ME=][,\N'>QX5$M^
MHD,#P7TWM^#""Z^$^"*<ERY''`6,.2[KS?.;4_YL>N(=BP-A`ZKAO9W+^;+D
M*T'V#X\S)-NYK+)V_5<.KB?^./33VMB`UHRTM#FL5<W'*M6;&[98:-6C;>6R
MZ(KL(%TOFEA;]4L6_%JTYT0#3@F^9)3U\*0W>F%*\_R($GL#GOG>=<*]/LQ;
MS&-SUXT96EL7UYQ,KIC!SQ#;$"@@(Q]::;(!'AF@W[:\K])-L439"J?\SBE8
MN0JW^LG.$(?;O7"8UE`]5412ZO'2:X^/8Q7GB'3XY'O>R2#%7\704O85HV\]
M!;64J:"X=,'L,X;;SJ%UY&I^2-JV$*A!4IAQVBE&^0#/SUJU:=:N.86-O.CD
M<&G?GFK;!$B%'TG:[0"5^1LLLE<`]0FO3*RYLG&`PY]'6+SOL&^4(%WZ0P$]
MQ$MI@/@QID+P8/#?QA"JR\LIRB>UG.D/*EL!YP@IX6#97?D.KKA+T!FPZ_5Q
MNK0%>YI/)Q^#^=7;$2-S&I[Y.9TJ.-'EW.T21R%I1$#G;B;_:>Q,EO%^+]LK
MGD/"VEN$A4*A[0\*&S]:&-]6"MFG@=79C?KET@)^,:*';G(H,<.R:LOT.MRW
M$A2J/]$0?P>0TA_5**F%H=T>JU(MN.R;L+B4_-O`Q5YS$4`&#5_DR[#["G1B
M8AH29@0"FHMA1VY8`?X?J+7Y#.J4SL1&X`U^$JA/J]S6@-XJ57[Y3[9,2QA=
MM4S;RT2ELM>Z$A4'BI%[7UPH<:RE$"VZ8WMJ2S'T#`N4`</^-846.7('KF[Y
M6OA]N?,FO=]615?T/,DO_88GY1Q_G^K*\@EDE(78Z59Z=U*GGRI3T?J:7?'H
M-O6R%93T'`=(`_*@H0SNSP_O6S+D%DQG^WK#-MC3!U)R2[V2`KM[9=CF2&U%
M$F<;XV=R1K3O$;MXF$)04?U_*=*HN-Q)FI)>H<#&>)+4XD(\"FYQ;^%2=)#4
M6UYT"XXRR1W$1(>YR[>DS%$9[\*CL7ZN^95B9/680",VT5.1Q:A/$,$\E@,K
M32!H%<5[2R^\<:RN\N\JZ!S<Z'6&E.E<NW:J6(*V3T$Z6,\P@RS[J,AH-EUK
M/>P5+-RKPV2%R;1&8,.6'90K@-3BU&5J1LSSL\*$O>9ZN<5FKV]%.AT3G^PS
M)N?(/8VJ@G4%\SA]`R`_WNUS!L\=<!4?>"M<VH4$4YDO+XV(.<,[L>C8F@CD
M%=Q*(@!FS49?07'P&^?`NLC4+E7'-1WK2B'H2/TL_SU<,?(M+Z7V$FID7+50
MJX;^P<8?(E_C5A;AOG!6RZ*Y9:+^R?*Q*U5T3TN^_!,C=E^PXSF/:.F?3=U4
M$UKS=J[:I9.NT&]PA(B?=DXIXF@,:Z@[M@=CYLA*W)<IG`>I_GN'+VEGEJ<N
MGOMWL>MLNWZVJ98;L[V35/`(_,:YR))C63=:!N<FSG)B42M19<YSNR$A)K9'
M\*VLC."4:<NV1).-FZ9SBK#M>ZK*]D)0O'^>FKL=FS^$_XATOZ,D[V+5_'4;
MB!NHD;W?VIH0YI,9T`25:ND@L=6;7L`]A'L,I4U4CAJ(0MH<^CRWW_2!S/"C
M;H#DQCRGJI(`--,HO*^<QQAUX^Z$]B&T^G&D5R*F?R]%E%Q<A5&XD7^Z[*4S
M9;-.T[@+]OD=%BMVKI+XYAZ\;!/0&0,_9.(N]5O1@HO`8MOOZ%'7E&RKN.CO
MWV)0^\:V$I7$6?-BN,'J*7F0!*_C0K2:[$I5"SOI0+;EVZ+@IRMVCI+Z67WC
M@V)R,97SFHGH?^C9+GNN/12AMOA.=[!/'TP3?@\@BW5><?RZMX?$Q7W3;`UA
M#"./6=DQKB0^_$G;"C\#L-&=WUM(CU"V%?KOETMW7Z#5UNQZ%*:]?*>4;,2Z
M)9LN,B<V[-7,M*"0V6.9W,)TLLR]`Y""SR'G]81QZ-%B/`T-N7YU]U"ZUUMO
MSQ-E3:7OT>22'WX@XD0CXVYWKYWMV?P:=R`MLSXE6:)#<[89$/5Z9Y>(#./[
MT@A?,@;P"TEZ)"K[U)I/H7T1+Y1GDZ.5^B5'\]V`F;0SP&8#0M2T)\-2%6KW
MEW]*6?ABV0Z#76I&]K<395(?RR7$*IO2ITL,>1E)NCD@!9=Y_O13E>$F8I-%
M?>'#4G[^[=[$TQ8%6T]K1S,2U$[M11ZUSLE^3LL*+8.PI9V2H?_!B7D0@%R#
MS@'@7;<#';T0:"";G:VZ0'>)_","]G.6U<I(M."9=2ZPMY7*$Z6&5DMY<BQ@
M"B(02X^777S9A8R!"-WGG!QC;80,:]&\NN4YK=)=8XA?^56L/B![U"H+F[QH
M^12QSG3AZN5VPALP(IOWGGQ2;F7H]:4@T]ZAP]-38XO_@DQ:A%7![>68H!&7
M:.4.8*`3O`9`DE.]^N.BBX.GAGS$72YR&&6MS9^,#F_TX!OS5LN.7^%HF:.S
M!>5*-.<8E'/TUY;!$V.C%S&RG*<@I6!GC?FQ^7SK3J;*]1X>@9'CJ.G/>@CE
M2:$>E]$D^^M4)4(G!ACPSG76$^'I*!/'P*]QV5'4W<)'`%IVI4J>;^(9XCFD
M(4@R/;\3.AMT]M`L',,F]&4XN<4&Z":RN+X(@9N179ZO=L)Q\*[5X=;)N?J(
M$L=9J?3.P.9GU3;>).GP'TH*KI3<VPJT:N1G#`825,>D']8_MTF7G.-H3.BS
MV"2)KCKL4#V%P_[*7LEKY2(??8AJR>-IBU*?%D5ZM@S<#Z"Q:Q[7J9XHC2\K
MWNIKP3"RH17[SZPQ7@!'5+AFW]0BP^/WE\7S=9I[SZX?<)EU4X_I=!8]`#.*
M\-^G%',`-_>>`B5SZM+>#?_.CN95JXMWTL+'T3M)>5<)P'T+8\0MD?]$-`)0
M]7GG-*UC6ZH*O0/C@#1KI1Y+2L8]+W]*.GVB0>ODEB`6+P[N$1K*9HQMQY4*
MG[%B%Y+NJ`333M'^@I^K'EU5*DEVQ,_"E]!PN)WU9NNPLB:5WJ7RJ+2]2V#9
M0CYLYL\S0CEH(L'NA<X`G/)X.F34=/)\N01@JHG0Y8QFP>,P&=JA?LIPK+*@
MQ`$UG^P@.O]<8:S_CFT_*_-[4I&=!X-WV^(Z#G^R4PT%E;?Q[T!&;#.;SNWW
MX@Z^O3=CE!31WYZ9QI0DCB#D$O=-QE;38],XARA:!^#)C,*P*6?1.*\.T>R%
M$X\NZ8&G&ZIXKG?F8!1[I%N<\71N>&M(MP*>"_LWOIUJ5$]9J];/KXM(E_MF
M*_V)3+9(@T8(HCR3#)56R2")>B`(L;N:9P#W]&L3K/:7V;N)MT()*<P5^@.*
MS53CV1:.ZK+!^YU3)*_/^OA.5>/N!::'\`+@#T@B3><9.EZ_.DFJAR8N_<U%
MY4\WW[IJ):GIC_R.N8$.H7D*J^@C()8#XY'@+"2B5T>E"')U?.,*CF7`WTJ$
M,".XR*F]/#"19/'`,$>YQ34+\FR_?P&5,B<T<*_?>)21%P0OK]OB6&?Q-_[X
MCH8TE2GAOVC4=DK)*?-5%^I2H%CO!#=)?LKYHM"X^^)PG'Q:V<X"*^'."NDJ
M'LWH&K;C`15CZZ;^^*5BM<L@/DR9+/"%JFFKX-EC>U@-)^@R#=&N`-__3A><
M$B)VN6I+YK]R/E^[J\E``<,*#4^D2I*G:$2;Q5;+NY7A5%C<8K586%'6`H9P
MVE8Q&I2*`%`^F*J"LC,W-YN"^QTE!4^/<QR,_*1MM9*=[!K@9%BJ0Y)W,2XD
MV]=Q9Q)['IND*"=X]EI6VB0LFAM5='6J^A;RIM9"UZ,Y%JHS+D#-T%OS%C+S
M&8LZ)-2U=8PI??L,,^D_.G7UN`F4>20.#82K)H&E=BEI)"B%$1?H4E^/#^?,
MXZL[F#?8%"I:9-DQS0R,(2E1\D0-9W[^<G4%GBEG"MI#S^J`Q6V^)!<A2@@3
MOW/(QPM%K&KH<D[T>DLC.L;L"SX0X]-4L.9+[Y`9S#+__H?G1*!KA@03LZV>
M#&#G,92$-$;VV/KT\L92'\J57LPZOWQ?7/IP+*4\A>Q#N`ASC#[F_$5<#*@L
M>LCOI5#2'X[><NP=J,GA"T^%931MP1\6^S(KSDY2F\1Q835C[4>J,"E->%U,
MZ?MA5QVD+J'SJ\71X5A9/HXAR\412-^0M!<1^38S?4>^[2OK63SJ]/,`1B'+
M1[X\?!Z1D9".%+5RL`'&7:SR./;E/6Z%)"QFJ>>"LJ?[0&-B'GK1:I[>]5"4
M6D3H8=&N[;N5XF+1,B\;Q&6TTD;JG'86.];S_*<U(D-!_%'/N3A76_TMZ:+;
MLZ@^TW=X:NN'MN'.\(<]UOUW\*+>HG\3]_K<`>/C7F7#6%85M.`:^B6!'+]%
M'V;O@-6GSLE&+&V-\&F8<&K/:S8U,M[&5R&T)D_F:YPOC\!6O,-LLHN4;,G/
M'KYH\^-?&3-+M6J;@^KK7?Q3:3^K'19>.A,.9;,OF%6A1EPKVLU#WHH?U?!P
MK)I":(L5C26H2/L3[2#1D]29"%CL$/<%\W-DA-KF>9]_1&P<S>5OQ5.8@W5D
M<"!3&"[&JNON/'-([:)<+NT!^$5WL,)R/=;23'2+>)"Y$9RDF`)/\02>]<<(
M)5!B$.ULH5Y?8BDW`DO'XVV'G?D$-V2!)U)WAYJT-E$($**.OC(=C!9TECLQ
M6RAH79+FU5@#1L&].6U;Z9\A@6L])3H`=Y>778(\25[J+SRI9L@$^S3'#L6'
M6>%6B0:%C4+X&T[/KD_8D+#!6%7"YCVP??,A_LNP-1E]VHE!`K#I[E<%&DHO
M^+5DO@=;B3>%^J<2)_?(-H@HB$D'N2-).2@G[Y&$UG<+S&SEYH.%J]A;8K3+
M6G&'9K&%Z1DU.J.KK_SG@TN7V&8@UM,'5I]HL1B*#5A#Q?PVU6R`]"`)K`':
M"5NM9YE<Y;_*8U><2@U,"(5\KMRJ_'D(,9'BM6@61,9$<)<J`0EH?A._A,9G
M2N]AO@ZH*:,!Y\CY!O)22]51Z\$F@:)=^0[E_6W.F6V=P4,A8ZLKT_%,'#I=
M&U&AOP!,1`6?8%NFJ^X-TVILP@[6F@W125O16MX^7P?&R''S;GKEHG0M*!X.
M`;2B<>Q(U;#@UEX(>X=FU(.703./A`7.J;=LS0.4OUM;7T#[P+QM_'%X\Y/8
M!Q;D95OPN04^(S&GX!%^%Y-(`-?)RX=<7+XA4=]O]XM;+"VN$65P=8CGWJC7
M*92V2ZK-O=.YIE9Y:;Y6?QJ;\.I%D]X%RYCS)X?0O;M?/]E26]6%$+05A2+1
M>&<UKQ,I#2-8L8K"588D3PKB'70C^3EYSPU,F._+ZQ1P"DHQE]$GNPA2F512
MLUQ[<=BV"+>QI+3""8^K=D24G^[ZP%Z30V"7V5D*RJ2))[.=)E(P7TO;?62G
MMCQH^6>506]QHKKFH123/?T$3W-'C)44G.(R@`LGL%O`<#H*6!DYCGUCDVF9
M6FMT1SJ.6Q)P&VP[A-%%>G)EBS%KY4#=<Y^MI#T?Z9\41':^"`#+W\E9!/UF
MTBP][TD8?5ON_K9[A:=[/5K-:!;QO$A?ZGVI>C]"$['>9(1B)>%'R,HE'3%$
MRLZ/LU(9:!$\!BLF-DP\X=WR6$RP8:D\]#["-)>$JN\5Z9T+*-$(*L8E1E_*
M;O=JJY?X;B^M8W+&(P]<]7>M3D<G#)$'LOQLO^ZA]D7@R8WO4X^^+D("(0.W
MK"SLYHP'E5/X.XMQ!,2=(U3J%4#OIDE>%P2\P8UPT0[&P\_[@QO8H8<G;;_*
MT:.$+GP(Z@7$&&P3=K+4;)*7A:^%9`RQ__>64ZS_Z50PH,?Q?[W,+,`"`%(_
MIF('@_X_LWLC;9T4\DZPPM`%F.P2AC*Z`M"5=^I=LJ7H"!IOZA`+*P:ZT655
M7KS_6%4XDW0H<3B&RXJ@P@O;OPN9<JS*)^/>!QX"2[7G?1?EQ6_"1=_49#*D
MX!Y(JTJV^*WJAD,7]$AUY<:81*,3,T]]RGLP'%E@\%L5QS==>\$FTD<3@/FI
MXTC&($;#L04V1-&NNGV54MI:+(0@,1)8Q0)()>`#6*XK9)XQ1BE@E,%'';G8
M7V/0H^DXYHGNUP\E"S5$HWLO3GQ'BGI^#2VNZ1=M6L,.F,8B4>JU0]$JI/Y%
MJW?_"SG&O0C@"Y&[!5MB[C%RSF5.>>/+$"P&TI+M%]*-NPTK>17$/-GV-?6I
M4<C8T55E+>D5XC7"^G4?,PL66K#54CAS!<Y!.TW<(<%AEHX?(&>-ZP<$D5Y!
M&G-@=7EU\T+YI"<G"[@K81#26J46]TS+>YZ/!R#TG/3%_=P8_I6<D2GKDC+&
M+YSI`=YI-!AFH\V9C?3K`N:-L#F]:4@F=D96TLZ(HT7%099#LA<+6FXU&[OU
MO](!R3#Z)Q70WEL0,O(.(!AA^^#BK-RTU:RY"3'<\3?\4?3P-[WB9;!<-/0Q
MD^Y7OB&Y=Q:&70CMC9Y=2$#&1!PIH>"?BM5OH=V57H\68<5KHB@'%8)74K).
M7;+-]9*M(APKQ3S>EDO739Z8.B/<A+I7,]6@/]2Y+OS7M[XG!4,;$7V,>6H=
MRB28N9?$PF;P7G7\6M`=8=):QWW"`SW2<WM<.9;Y'V&)4GUOE"3X*6M3Y?'N
MT6N[8_X)^\&JH1D&S$C88WX-I0RZ/-1,(L1+U&GP=5R?T*'B1#@::O8ZUTJU
M#LHE-4'DA^S?2D*%)7[B6J"@7+M'4B?M>5G#D,B[+>D+<S"ART975;.E+9*3
M;Z_")6H]CXNMMD]'UM?@K:>3<(\M$)GK)#%3RY-YRK!*8%5?*Y&A+@>DE/9;
M!)O"[Q+M]#MF26+[Q![&[/.8(<!RV?.[E.>3'W5HOJ'N7CR)'WJ#Y],XR$5'
MLRA3PE^'LX9T8679U9M,'?;6&%!EP$WF6@HE.F*U5**5``TLA82YGP380$4[
M$N/T<J>X$3G>81%N%LM);"WIK&H!&<.8KQ-$FL,V(HG\-_2Y16"20FP2&WT!
M@0MA^A'_009;D6CNNSCI3+STJF`H+X4XJ@)RL":1<1![;<Q@S_\S#E.A;64$
M1ML&6;4W,]61B+;OIN#^P<55N8@Q`XN<9CA/L9\7+>E!/*6'^,L5T(/"I4:!
M!NZ_\A]IQ53$7QC:5$!KJ^^:0HN0L*8,;CNRZ,W(IPY8Y/T2`5JK)[BVS]H3
M4O"O7Q+DA=ET?S_3R[5#>*W`MZ![?+0%9=P33]9G?8^0->%&&?Z34?8E"NY_
M#!K)\)Q<'#^*98&.RT-X6\;DCH/">8T==7-493)`>W4,!GO&M)AY31K<X6@%
ML"G'Y3=.KM3693&$@<1K'&;?Y&=$<<^"&:#IM`E\$*0U#>)\M8:J<0]`;@$<
M4ZG#WP_.!W?:'CR)=,4$J)ZA$FV96HZX-S%7@B//9O`YEYB`NKTH5ZG7602`
M]ZSJ"3>,#$T'4TD(SFOR(E`LPX]E>`3B!%U5.F0<"'74AN)5SKE',Z>_*;88
M9-6J?LL[G5N^>,#E2SK[WFI@Q>O`?N$Y<8/$X&O4PG80WT8X3)\+11:/K_V0
M3'T#\_R[%\"=]2Z5S[S5[G9F(0S1X>0+#!I+D9X=6G[P:934CEN;I74%IX!\
M%M@O`X-M(Y@N=S66:/?#4TE2,XH'DBA9(!"Q5;+DF@'[(43TN-X2/P`*"TC[
M+5`GSZ>@@\Y_)@WF+IL=$KG\GSZJH:S'$BRB11M=XUKJI,OB/>\.$57CD-,1
M!J>=CPDEB=-CK.&!5%(RA#1!*<QT\\"(1M19RN5!P;F/?R-+X'@:X9+*RY_X
MA.`XA$1Q^1ICG^Y,;AQ@91)_DUMS)#V%J=`WA1@6D'=R@TC+.R<^_-WO`A7M
MDU?C0O_^MXWF8H28Z[BNW(>F_7.FB'Y,B<FZ4Z->D@(47,2W"+<*0)""5DVX
MZ&_Z<+@6_._;R9@3?%^R^,I90/1\/OM^6:RKXW^6$H=Q6K.QYXSLX8TL$`U_
M+T)GYMU6Z]?@"0\4>:&I.T+\&PJBQ=6[W190<%;.(,Y+Q7K1[.N_SCM3E.IM
M$6^RYPF'Q'9`CTV@/YBN1$9]NTQNF(CQJQ!I5L%CZMB`G5XXP#-MFD8K&_1=
MZ;)Y8F[(.V"6US03H]:'&[>=N6_-3*YPM9VQU;-;R<7E-YX*3$3D%YNG0_D%
M\^DJ;OTZ3)V<*NT.]C)(5O8?@`]-T=8='7-$%6KOOE$NC[!Y=][@_2+P]\31
M4O_NT\Q,WB?RI#APPSL(%66RPBU'*WCA+5K=:VD)G#NT"A]W?J'M?FWO@)(^
M4\/"'K0KJ.:^PK%CHP03C`[(ZEE/6+(*M4%ZB2(R`3_^7GO3+4G9#>CC'U/*
M-F[8TSC-JH.3*S/"G-2Q.F)OIVG\F>R<B[4?1/TKK=::W0;*1Z1T/:O::2X.
M@96>5C=11LZJEVMXPL!)$W=;D4Q94DX1[-CSOO3K^2A;%UD%%T%?)',_#_C9
M\9)-6%P(9:8N6*<.W3GW4E]//8P$ZIW*:]$,\X`X:H'<B&5C']/^?0^4Z41@
MI4>SW4)=J,$5)WI&:0CUS_<*`3,?ZG`.X@A5K%_6>\:\&W;A?!*ABOBLT98<
M#[7^W),H[`I84_MP252XM$R<OZ/J><#X%M#/0L0DR6$!^=F*QALJR]FI!6HM
M?K@?#G72R:G8/H)7-QH>Z_DZ4>ZE2,<V-TLZ@@J-?CTQ0&'Q/'DQT7Y@4X!V
MB"303)N,V8;=?L=2@1W?$_H^*Y46'2V'JUE?D\U0":LFW$)P6R$9$.UA?"[0
M%]WN>WF$.U;KX.74DR!A?F;^!YP,I_AK\:PW&*Q#"ZYI$197]HFV/PXE2:46
M[(:!,?A%E$(Z4*$.CIK8V[=YT>YGB(FKZ>5QX-W+Y;`;(*`#M@=J-W@T<<1]
MC4^VO?0G((GQAMS9(2G['39E*D_\\Z8M+S*XG^#H1*D9GHU=T3&Q+TU.DO$.
M=^B:O543M'/&P_1ZDY\BIA*TF;%IM00%7X(`FN"HMNH[#P*<P('G>+!.-<D(
M#B_,=JR9KTD)[`8B]1N6.F:*6&@_ZD6(Y8?>51N$?7V7FG5$GKH:#G4&6]4=
M5[D1N@!<K&<D<<^Z(2=L9T?\C74R6("?`&5>Y`>^B\:%>,\,ACH^<AUDFD%8
M]6WW1+X,]K2*H8FP,TF55)4VW0MI=8C%L0,+O)V9F\*]ECHJ`&L^]'VAK2B>
MK/,Y2D,L,`1E%74'N`DQGBHTG0E]EXQGQ3.["NTAB08KN-04#6*'>9BH2-?3
MXU^**WTBUA^=A;Z8<$%1J=!6/)3J;8>WZ'7Y][4$Q<<<464QTF*C*/E@)N>8
M2<U5)*PE<U&XO9DR1..4?SHX($OX+V?7%C295O)S.7WC:(\[Q5GA,JV@)AQL
M'KE[O*4S:&9&H<'PZYV"F8,=D#]2XD9#85A.[N($-A@8F7,!^JCIB@/ZT[C;
M5/,9[J">B749*3F-9ZQ@R^4U9[BL3MFH5'L4(F9K=\6Q#?CC$C);35RB!&[2
MROK_"K%VCF8_Y\P9HX2G#L02U)7:/GD?JY%?"=&#[W)%;Q[$)S)#PZ-XC>@P
M1@G14)&T(J0\/:ZK]V[MN]J`-N4=LAYQYV%^6>O+.@O=%]:<M=U/E,_86)N1
ME`4KEX;)`_ZF5'#'&-D$(^`>LL@76,VS&D]NBIB2+-'$`;IQUTL79C?T4?K<
MA!(;U/>9:-R2OVWMV3S>F/JA+4_I]@LA)$C$:4Z*?=9AN(HOLE!1]AVROH<:
M^_X'P$:BO78T\X_&I^N=\?AK^%X%:I_\'Z`?XP&;(BL??Z54[^[D\NRF/+_B
MV%;!GE*OP8&HTUI+U./O,H#L`M4,S"9PYP[7?;\J)GDK#TK("$+B,;.`_\P_
M_;-P<R%MT[5;/>3>+.'(.V,;PZD6;H&*;<I>`"N05METHG_9K(2PMC_?U<B4
MYKX*:O,]*+G_$(';-A4U-XA!8TAUL]]_T]8J)%@^OG7*$5E='B],G=PO)<7X
M"99G/S5XO<431HY7KR"?ZU`7#7+4M%VUYB4A,U-Z]4N=!\98^UV8[@TH;1?"
M1P_\5:<<B1(M8Y2Q#+78'15UKT59H/(IF`A!P*OOT7=1SFENR5FH^*5/R_HG
MZWIL]$J*DK07D\Q_?+[$T*SV%<_B&UJ4$93XX3<2.J@RO)C>A!>,<RX?,]?`
M?%#6("4XV::I7'024Z/XOC1P3/);L<50#V@9ELPT\8Q7_<V.`.KW:M441.9(
MT]R2-'OW%'=KM,QVQ691[Q9:+IJ:C`FL0+`Y/WZ%Z*P)EZ&7>JF\(XG%Z&TT
M@2E$N=:9D0+*`8P+IB\>YU21$L%Y3S5TL%VSD/OZW(-]]9(&)]%[U$Z;/*KR
MZB4'55CU:HL+Y6\LT55?UA-PCEW%$RLWFE321>/?3Z<ON'"1>N]SOS.@6QR-
MLBQ./?)]>[/5(!`IJ/BBADKV("%'WR!QC9ZQX!QSUAL4Z[JWUKDQ/:4^F?D?
MK6RKIP4<"O,R_+4*DJ9.[$>(K_`<@OL5IM8A5OYT\:IBTE"S'6,'2F892'HN
MYQ!Q(0=1A_\K#7('',WASMY;LMO,(HB)+9%XDX/R]">V(K+U=A>)HO%6'C0#
MJWK/$:^3+`VM\+E$#^-SDP)WP$I3U+Y73E%P%%6.%WV+;LQW.K+I,]&!"J&B
M[KT$2&5Q:*<"KZ%WOZM&ZU(E>G]V%F&7F5F7IK?DU$H&1_^D*\"H$6^5B0?5
MR\+2PL$LE5]8@3?RGG'T2EB?Z8D<RJR^PQ=;DU&8:[W9_38F5M97(4)BAL!N
MWX6Z`U6Y$E%^S@PED8I5RS)LE8-!+OR1`SXP\6[!P-2Z_\L*YS)5:<-6K]I$
M&_9KK"!Z5W(X22Q!<W(@:?36$%YG"ULKE,=M7++3'NVNBKC1*-(]YAFXS7]C
MA/!LE_?Q@CH:&X\*@'$WBD()D1(L*='FPD<!#L@Z*D3(A)`6XT!!$.R`3+CP
M:>PY-E\ML#ZR'1[J%9HB]*!!$GE'5>=!(_O=+!2)2&/+=7L*,631W%<NIW8R
M+T7+7P#*,;-96J*9DO`T12NXLLP21\A1DAQ5$HMWG$XKJ,O$PD9^Q784"Z(H
M7VI*;S+JH56IA^K`G"3N%SZP&,_8B'+MZ;XQU;?!.8-O!J.0_=%/*,)-.@*N
MU^T=<AD;GLB7$GM3]5J?L=ICVS^[)XL>+$'8S;`<&KJ74)G<6T=&R3:!3A^S
M),/R?Z-%L6L4F]TD4^(`\ZS#_-F<*SMX%E^A9OEZQ<FH]5\BD]J)7YI?3+["
M&@6'`C"H=,!EB+[IKUEU&I8$D%%F0O+[SK3X=-1@$_(R+RQBZ^^;-":D'ZG,
M88:,]'GC+*[I(6,M8@*NYZTE&0>P&*`M,ZPOHF]2XN4C-BA8Q)E0E;FM[1(#
M@/G*GM\.&^@#`4`^NX;]_?4)FN0+7&;8U3V8.%&'4NF*I'/O"WFX8_25J^IT
M1AV5%]P+[,4\[$/U=O5,N`S,E[8`R3LDU^YD]XZGP#!W;G*B?`?H"0<SA#=$
M+X@RW+W8NSXL/(5DLW9(IMY;0)=(M<]]YFD:=!"B_RN%)[-#K<&Z$G@<Q!9^
M#[:DZ\-L*JZ"?M7'RK9OY'CVU.<_REML[7ZCF['\A<5=ZN+>2IT6A'`PVHL$
M&5EE]@/^)\<)3LO2FQ'^P*JTL\L-N-H2RO0Z!"2<:'&0KWX.^A<!YAL&\M7O
M&C^_^@8_0/;?2=U&HT[/;G6]''2"&/3N[O3IQPW]/K<<>5&G\OL@7$;('#M1
M="D4"HGMI`C<0-C_@:3S'M%&^A#U(]CY%T=*WK81#GBQUS>;<O:YF<U+D#8<
M`,FP>PUT'OXROU(;`BG_3.1Q1_5C5VXKYAOED7(<84IUC,8':,&7Q7+N$H+B
M5:DCBT-QCF>V;D;:O1V)B$*04'4?0\S\[GL!&0.?3?!'V/Z%`\K,H0RC=N^)
MGT0=&T/!3W?NRHMQ`6?2X0#N[A*7499H(R'NX,9\[Y"YH:F4H$^@VG>/UPP0
ME$'8=ZV$%12,!?D$Y*TB<IMWJ4E#B6^94L?`V5GR9_FK)_P)#$M:_4"=DRL<
M>H?$$$G_$AJFOTT>NQ0Z:1P8BJVR3'$`7B`(B;M9_-4VQ%J_KAP7.,"9;]01
M`DDFRMJ_3)"1!RTL]HU8[J`Z,")[7^`A\,X;M]V`9$8*U<Z$YN//YI[P<=&4
ML,J]4HE2E'%"/9GSC8@*]:87<U-:67]X"$,1=]X_#$B*(Y*><"=)&M)0^Y>:
M_,UC@U2.YC-X.*9SE=;_'78_"E&5U5E.^#=]X\VR@^(_P22QC.*#'=D1)<^]
M4`Q>?<6E\F.2QUYQ+#T&XO49DX:;0Y$P$"U!N>\[&V,2$TX>WZ=6D*>F"@];
M0[XD7N</[W/.G7<&*_9(G%<W3*9@(\PW1$-Y`7T%Z><E,0<FRPLD=PB+.#L%
MKM-6HY0C1#_%*Y%K)@NRW;H5'3;L8_17L@,74?L<5$!*\MU#TKIVN3+='//^
M:\\C"KT57`@^D0_M[+EIXK9`52<84BRMM5F5<HCS#T92D\/Y*50MLR_=L%KW
M;%^R(FQYCWCMZ!FVEI%1TUT[Z&!MX`&QB,9[W.U$(46I?$6T/<:(C7HY#[%J
M21S4KZ!Z[R!*>][OH":JM&P=8IS2=I[4'YG%%38RG(7R<"9B,@*26>B<+J,9
M*0/D",^:+*0(VDPFSO)URA_/.&&/K=^NG:(9+PVGX1HJ\C@I&@+TA/LX<PLA
M:H?YJ3$6F0"<55))`#/UMV/(&8Q"/$V&O83.H=&`0Z2^+"A.`LD\,/$DB7]U
M@";?#^A]*QJJXX7X"5+]JLM!D$>J&0TZ9,)C*BSM'H-*!DA/PX)T$^6D)C.G
MT*)Q;NKM3O?R1/GDL2RR!ANF._+*03`_3<M45WGM>O.GX:M*MB8GT"`IH1VC
M/Z.#9!5W.^L2=DMI)JD`2WWV_+,%LK,=[1+CI#HU+@K\D%U)TE]MW,NI)GF;
MR04>Z5S1@,I+1S/0@X?Y_,\4H>X%)HT`^PY]'C8XS_/$*JU3^50S2[\RXG0M
MX#$Z,79_O$`TSM!]$XKS<JCY#G&@JV1E4O^I[WHPJ)"\(.CPCPE>Q4*/I#2L
M"O(A&*M"?*J2H6FAO*6RUW2"[C>V^2_[^:$\&?70?XN8*O]EC%2QX)W@D4<"
M5-R87H,N:B_\HR/)_VZU@_=<-^SI"_3V7C7&9Z)QX;Z"P4[OL-\1*@"]P&H[
MTGNJ7IAN*I/]`<K/BD7(M@;0(0JC77>KJY_2CL)8/+A5[[K_EL1KM05F.G)X
MYY03+SSEX#\S^E%JU]:)2GE6L2,_">2VC(<NDRRSP%)UA,#>V;YW*VW7K9\E
M32T@7EM[7\\<!5_A>=Z+B/6X[06[ZU0:2,9%7YXIFKG:IY6M-%<R:F"2'@;!
M"2?]SJHND1VAD,[KNB$U2?Y927K;$6^`_+!P56V'BT9*F7#0M+>+-2=C\SI'
M$CI/JQM2WHC?M>MR9KLMW<"D#]IDKE*[Z\U$)T6Z7YL,8`^B!J6H*+T6VH`P
MGNN%I71$H?[6I6!Q\(8GNLKRM4'R<NB3K6UCP'MS"?!YX)X*WG>N&&7:&W>#
ML&I_\\?;-[R9LR+:&DL&[O0LNJ>V>X'-M1(F"1"X]KWI<B1K=*<E%D7I9MG"
M58NA/MY(+`Z\G\:Q]HMJ"+DD0Q6DI+%,F"[>E9A\+$W>L'4YQC6Y3<2RM)6<
M%5'_H1M\V?'5;I'W'`WS9=Z^]$4;,&*G?)`24*F*-7?AUZ(@@:^!)[22'?7;
M>;01H-HZ0;NO[6MXVX).TK8+9/A3='!J4&3KFM#]V5ZHUSWZ[2;[O]EI54/.
M_9S?'Q>A,D\2H*5-4WWHR2AW5K,?AZ>FFN"GPD\]"),UGT1\`+R+WUP)O1,;
M0ZB8G7:#QJ=[H"?'+7E$QU;L16Z/Y_JQE;%O2*&4N1^`,?F3@YV"9[?"!CDN
M,[%XR4L^B:@FUZ39H[/Q/R70#+(?9IJ[2Y022BT=V2QKU3X6ISF$8-%Q;_<V
M\GE=S(5;+O8&ODRNI<<#SWOH'F0QZ!B6U(=0^SRRD^-F)!Q0=,0JZ#X-WUGN
MJO/61(`0Z$^HZ-ORF'@8M2]=E/^0'15B@GG[>XOK0*%>+1SM85P^JL,7LC64
M,P+9[!9B)_H?_2B5K_-@"1#ZUXU5\K4E""!CA*N^5LN2U!8Z-#1#O]#V3ZZ,
M5304UQ%F+7Z\2;1E7TM@-EHS>:D2OJ2:2+VA;Z5X#R4>Q,1,2]_R$J-R5\%V
MS'],Q(]L2VYLK8-2`$/4!]&N2V3N(V]]&:UA:I>*!2/A(7\"+RVM[GMMY">3
ML-HE$[-F[*+)G!KP[9I=YT/87Q?"F,2ALPS(T\/Y_IO16E*@7UD%/#HN4R&M
MYA"!<ABE(E7."XJ(@SE!X$PK35'ZY?.&K%R2:S*G@\CXA?ZK!43,LQ.F@E_.
M8)S>\9M!RI*V3I2?W8DMS5VE[`5W%R'1H,%Q$A_0OYQW<%4UY>?QB!II/.X'
MMZWQI-:66XF%!F@D-Z3X=T@?&BUY79D-TE9^1VM9$:FEURU%]41C-KIOS<41
ME*))E\)`<'!E56[G\[39`(_+05?V4&%*L4&P?P5^OA^ZP=OVIQ#JPYJA%BCV
M&J&\''M)0BXK]#.(*=,RF\2L#-Y1:[ME0D2@[Q![TA<VZ`GF4N/&@W6Y_[JC
MM+@B<IN=D-:\@J!X5F=RDY@HE;/%BC^&K'GO@+Y>SL5H?L6BWZX4+2LH>:NK
MIRI^A*>`](E164;U9H#7B(0O/P8/Q0RU!!3R]]^-'895#Q?*D1RPX(70O^"]
MB[8U;:TC$\34P=YCJC"E.E=>7751<V/N?O<]_<`S:%BGT@5)81%^I/;Y.@<C
MZR8[!\%$"J>[U)?L;W9,L(J+@UHU'$$KC56TIAFKH?OO^`=YQ'E-"2=)I?6)
MC2M8_A_Z:4IN#)X27V7]7+I+7R'C5*PW5]S98)+;.J5GJ\^R#M&D3%PN0\0&
MU=*&MS-AU%<V5>$)Y'9TGC'`D<5&QV$A$EKDP9U97,+K`F+V.#RJLR-2!M_P
M.+CF$*(9]W?;#]*2"]\B%A7G$@FFV4<$Q-_<I>NZO)T%#CI2?1,7HD_\?V-G
M`G.+OOT[&)\,T]`8E/I-Y.8.WD7,XIB%)O'<G?Z7.EA%4_0U7MK4._N`K2;@
MKL_B01?SV>M\L:I_<^`!<U`#')9DULJ`R7..R#4'Y_Q;RM-8D0<E=4OK6_#!
M.BXOMNJFC:.D_`3-2TR%+UN[G#NXZ05\RTSSB5+X:I/'33K!I<!CU%F#E30^
M"C_'V=HV%X/+?^2IX["YX`V!XIFOGVE>Y0_VE["Q!W]"@<IM\DS=5^:)EP!H
MO9X`SO'55^^`(K^RP.A2J<;TM&O`*:RMBY8U9*60T2:(^KLJ<;O<=.5MUL`V
MR[')7$<173W9CQ).CP/%'K9[E--&&(D_%;8S6RVM0QW+8R$>6-,1:3\')=:M
M?-TTZT<.%BV.B&'5W\CN+.5X6@X7^"CGN?A#_M$ZH7N_3NCZ^30`Q7M.[(N)
M6/\A3K7^_Z;A0U%$ST1?L`9?$KN07WO2!VLZ8[5G<.#IJU:VSUL(!A/;GK[Q
M1"IY-Z`+8HR4(+-]I\"MHL`]W#M8)1?CTB&\7!0"PJ/;A39B48R*H9.JI2_`
MJ%_A\O3+5?C'<Y>B="A/G)Q]1=9.?IR&<:7.UFQRGWGR`NI8IH8:^J!OD?3W
MNRIH&&*/VI-4J[(.A4-MU7&9/X:=?^E>Y),E2%$:O;H/PJ<`43CN!)8OLE4R
MI>Y5K1RDM#XA%_!=4(H`D%WK5F3O9M,*TOLN4=YYVA+6(<%!V(3>0/H>.LE>
MDN:\R'U7#X[K5T4`C1.P!<MCX&;'EJ>C]];J0<$1N*/8\&_\%9$;H+<AO%HC
M[Z)6_WS_X!S6MI(>0^Y?:>\6D!^WJM#L!0LON=)W,ND?H9G^0=NRVB7E@F6R
M?+T(EQ]K?$!2*%L4<"0TV(V9?)6D4$A?'.UVP('Z7H6;>T`OL.A4[5=NU@[)
M7%HHBE)19?M6:^JU56B-7Y,'U<;M".R^9\#8=M00RR^TYE5];9M-`9BH.Z?I
M)\7>DXHF)!["B.D8`XZ=6TIG]<F1S]3NILW0>>#0#-!5#S5""#;^9[N'H876
M"FW?NR&GI(VWRSQ"&C_4Z0Z?U"T"4M/DPL'52V[L@6\_^=]LR>%+2X<(:S@Z
MJPK:-,'),RN;OV/4^\K>+06E:RLG,<[+6B<]26RM&V2[`;!BO5Q8H.Q?MF6J
MO<>/(GD+89L;3T?[,FPB%_B0IHTQMWU>/9L?&&S\,)(B8]08)H[FC+7><X6B
MX[M[:?JKDG^%F45LOL`^J@/-S^'UC6LS,6M(:G:1\G-]^W:A8&DE1A4TX0^J
M))T^U;S(HL-4W.DVJU-RM*BXK329G,^CIW5'56*5ITFUJ<R]*HECZ5IA+D)L
M0[.'EAMX+KYY$(SEP<8=Q(0=Q3F_]8W.PY8:&?>SK(&D>Q>K7^/@!I]ZJ1'[
M$U0"C#)V@$AW(F<.^>+RP^C&X]@WD13$)A@I7:AH$.5YZX?'N=>\;==X$-0F
M#EA72<L>YB*XSK$"VG*B+\R,V0-D.?C$(8C1:&#-ER>BK9XG&]TLCE<=?U'M
M:0Z\8`C*:A8>&QV&YH_BJ+FL`J)T5Z^2?/HEC1$.E0GYK@O<,(.4#<OEO845
M<&1$'$%;*9;_&3QIG[OM2F#UMLMRGDH5TB)*@+81NKY"[CU^A^%IKIWIXWO*
MKAGK=Z0&FU]B/MDD=9:')`<V!`W<7!J+DIOO)Z"6,+RBMAMSE9;TI<P<'DGJ
M:$4P!9^B%_JKH'U@#>\F'`B(9B%&7^OT,9N4WE)N_=03C?Z?YWOP_ZC=KO:P
M=:^)MD49!06HE-HU750].@3^"G\5UUY$(?^L+X%VQ\+7QE+61XZVKC$7#@1N
M/D[1?+?U`<VYGI[1&];0@8[@5+G<X1Y+N)40/(;[P-3O1!>_+%W?O*Z!WM9Q
MKF9B.##(0N(O^&T@A&-_%1HV8`:5;V'A,*]Z:\]G#%O15D.O*0,+:=R7-6'/
MT@601.4.;[>7:E5,S_EY%1]4@%BLG936.(\P[7\D"3+SCF!+$Z_P:"N'.V[-
M'M2`%IOR[BKTQOES9:'7BK8T5$@6/29)^9I$ZB(O(>O7R/")A0C,S!VE#WD*
M(EXLTD2-X:YK^/0T(`>KRZ*Q2(=@FQ4#@3MC!Y34G)@`M<._+C/W(=C5E;03
MXDI%C9#V7E"R7_=STBYYPL<WBTE("PX.EFJ:+N2Q3F-A\[B[ZO8\LD24,,T(
M_^X"-5LHR5M)DX#VK"NK#WL\A<KF8'^&J<D/(89F^6CT&R=RU_ZE+0Z;)!WF
M$.;P&'?(`!N],V"Y0+:8&OI[RS#SJ8V[@$;!)VZ3H&*TQ52+@G0CW"-WY`&G
M>59/>K&,Z65^UD'?R(GUQ,&K'2B8BY.=X?S0V_;4+H6S:M159!X`CO_V<L4K
MF./\07\*45*K"[(G!%Z2)/7G<GYW!]\VOY7+,^XXC!0*TZGZ)0@+:GZ6QK_;
M@E@'K-KEUKSH(/MV9#\<0CWF,SE2C/SA5:N_'#]*A^OCT!=->IX6NTT3+=9W
MU'<$[3`^BC#YXYG\A.A2M_JA@YW_^<#ZQWS4ET9!3)JE:;CU;JEHMU`+7IMT
M_FD+F=T;G\)@.M*_1UT$0"(2@ABF:=WY5=-\GV,QG2U@&EE'Q?")8'B%(`:>
M05'[V(OS.FU-49=V`)(78*DI/NXKD7[4.1:FIUK>DP&^6$U+R*`-#O9'Z8I3
M2\/V\@!<<6%:;\>B.-QYL+",)F1!E5W6:4PG0^X&.D'M5(:`@2YW=3-DR!VG
M+;(9>:ZDO(F?@RH^O4[1*+6)Z^&[1FQUDBOCR`(#TCJ-]&',:).(7?WB;4O%
MI3-CPA#DPB?YRZ,U]NZT=_9%Q;P_\"F(H'VOEH=)GS@AI9<$+L*[2@10>:'N
M@Y6KW:V3H:@W[Q@J:@O,LU9[KPP:RP_80!.2VTWC9]XSPJH\GT&A;H/KDCX.
MDL:I,ON/_LZ[PG":Y&3.UB/AKUFE1D8CA2U(I`X!,`./7]:EKB.^8QS>H%<(
M-O3($"^3\'.U)OWY."/2M?@]2Q829__X!9'3-G@<EV/TFQ%1*SYJNU/HCGBN
M\^]-62TA2DST5(!_)*F>)K`(;<G*?$@U%3Q+?IJ-2,#U:B^MN.[M#X+`"#OO
M#9X;0%\7WDWR)FEW3[0I#K_4F2O3!!">;B'0<R=4VE-$CI900D#O\I(3?%U8
MA>+#,$ZH>Y;5UH]7TVT2@@"/B7A%[:7_IPLXLH5<0S"4,)I*!@4H7CHVZV%&
MXG(N&3QL]_2CMWJ$^`35K=<#U-D?NX+ZD?B.VIV<,$DM%ZQZIPC`D,N\1J,T
MN0921>5"N?Y\Y]V!U(9C_[WIBF_$AR'TH[DTK[:`PH?.66=3H"Z9+/'PD[6I
M>W37,O!AQ6J+#"O8AHPM5>/>_QNYVKV7P+3==DXBT6FDD?A/7,C<QD":G2<+
M#./P#'NK,C'.L*![GQT%RKI=8&T>M&W*,`[,?QX"<L.U#/C6P\>2W=-+YX'N
M>.)=D]N'T,JN1J%TP&(]HR,LP<E+HBX,HNF6Z\\W3G0_I/L^Z/Y\*7AP+#BU
M(-2N6OW%][C/X^:.)SVB!5]UGX0@$C*!5.^'M:R4904RE!7=Q(*"AG[BPA>A
MYD6O=O%'T9KK%WAPC$*Z(L#H^Z="\VLJW9#)/'>#F"T*`K_OAA*YS*<FIM2R
MC'E\\X^3XM?P:$^7V?@L$WD6H@7N,`_\S.P>?Y6SQ*@DMM*N$5=[-S9W4!\7
M$[U>4'W4P^FO!P5!^]2I`^6'A#(JH*VH2;0>27S/EMA#%$J\X2U$AX:Y<1A?
MLMU#^O&+")<X5Y\SP3=W\*D`;+;Y0#+FZ;OQ9G7H.AUAI6YKW5.NYTZ?_G$F
M:RKCWM%'2]EK?`KGQ+7'SH##7'4N5+S$O*%*@GH'1EA''`T-Z63:W0CX*KH/
MY5<>:2W^-'@"OCF;\&;.@*=HSLW>=9(0.+V9;*+&(N+'.;'W?T(MJ3V4R+0G
ML"'N2G(Z-5R<JM`>3HF_ZLHAR2#L,31A[J0+AJ7409GG_\C9!W7D#M>&&RS8
M<,+,OEQ^S'97Y(&"VL=Z$LB3&6`_.4M2MR?-@7BA-1;(%&%FRZPY+AF];C.#
MI>I(VQ-S*#H-\Z"C4ET4V<8*YB.+1_@M#332HAJ(,?=Y3Y?TN`1#<]=:0Y_>
M#MWJ4=W_K6(.B6VJ<`O6$)^A8VKY^*!X6C;$[7D,<Z%D[.[WQ5E.0/40YW2/
MPI51,K@X<GV#@,O<'N9WG@_!J6$J/O.C'3\\&+NQK2:+SWJUDDH-D)@+]/M`
M&G\+>[JG$^0C.]JK"A7'I>K#N&5/-Y=EUHTZ(7(\2[BVC,THVFA7]N6<+".R
MD.3_IW$,F2:(#./RHCORD;Z"5`.@5T#L"YCX>OU:=:B=TD-U'&+Y^L6<C4^B
MMP-(EM$LN_P"3\Y]Y(.1D5VE8^G;?)1D%<"([)";5PQ2IM<CP>L,]ZZ9+[&.
M`[<VAB!D`66798,7VO`I5D!7_N]0/K%C@?*>+$35'-@;4R5FW.@-U=HV$V2E
M`I\$K9L,QS)2B#1PL6?6"=,BE)BPN;L8;)G)QK,A`\C=:MH(SY$)V':[AWD3
M'"6A!HY4(F@KQ#'E>ML57;?<@XJD-.1VAP4=V+CVQQ*[JSU:U[\KL-!+1BI>
MANC)A+N09T*@[4:-F9#@5\U[.M4J<0.X;V&^`$.CT72E-)*JE'>T+6SHN8B*
M_<GOR"D!!3;7\V!T$85/IJ.;<`Y(ABT!*S.T5PMD>5))S0`JVK3"O?E59J`]
MZ2QI89.Y\WY;J$0Q&+XAXF6G0,7^\YUS*;@'+7\%Z\HW)`Y[0HC\P#D[5*@E
M^;\T;YI7R3M7U\4X(,9XI70R0>,VL2$LHJ`"DU_&1F,4)O+M796X^*%B6#@#
M/#(I`\,KJ8HK2QHO#=\`W2B+9:#$IS07B$3S:<#)B7>DAJCQ092@Y$QKH/A3
MW^[CD7.B,5_9"DRB]']/B.AB`,3]-H+2]`9$1C,Z.C*AK[F^P?KAD\?PHRUP
MD&RZBC:XD>?+*JA:KL2<8_L162J">JV3J)NJS!1KFG.SKI>RT&6X.=*.,=K/
M72O%B54'UL"(NKQ3A1:W`E.-[#O4]U:SJ=E*B5L,QX776%]^UD#P=C;75/R,
M+6W0/2NSDI.<=T3EXP0E1BJ3\/I?GK5`J;RMBY?A3#GSUC76ZW/(1.MXLS5H
M9N]M;9"-FR++05,KDR"N)T'3!7_=AC(VDE?28Q%Y;KC)T!FB)Y[\3:/;?<!*
M--VP;:D-$">I!1MA1-&_Z$:>,:%P;B>/JL]T,[`=#*_D3K[9J*$T%"]V"TUC
M[O#_*P#OW?$5$,^@E#O*J.`IG)W_S,6=1<[MTFHP`91"+XRG_MT&HFL?K%GG
MI3IS,*CJPZZ,5*A2\:MW++(:1^)HN-OVCK!=<RD+Z)_6"RW!1`PSL0*JJG;,
M$29I5:3Y=/VC`KT+2=9PC852VC!I.*#!=HF90,B?R[/GC9X"#5RH&+6U']QR
MA'>_?.^`-W(?$%W)*)VQ;&#QO$O0=W=Y*;&4G0M4/HIT%\DYY1N7*PE!4U<Q
M_OT=7B^05BI?7MA9/Y$!Z2.%+SVY!T^G,E_=FU7@+]N'-SOQ6+^MF%7FB("Z
MO1EDQX,EX)73>0V:'F9@G?99N$_+V9?!L@KD+"T-$FY@&]EK[4QG29C]LH%H
M*0A?Z5'P:PUEI\E.IK>_"]^!I#O/-G[*E-.:2E#2X,7S_"S(F:(UCK/:YTJV
M^I&JL/,1A"(#IO)-1QS\ST;`A^^[DEUXY#SURJTBX/W"6BZQ#!_[Y(W1KLIR
M+Z%Q]QQ7[&#\*RR=@:E:%_\D).%<>R5#HPYRAS+:RH\&,;4PEROD&G*_\C>2
M#X,GMK1BRT"=!A$1W\[=$K[RID:1H@$/.I1RC$RWY/,8<>\36BE+7;C=Q)V9
MLX<X#W-+!Z*HAT&OX&%[$;P.*GQP&_.Y10^C(-*3E<!-7A]8N7O,T@[F8<.A
M&]1B*ZQ_,Y+'$X&8C$LXF[X*8_'\(Y-#Y=!6L.06I'P]0X\^!718$@Y@=G$]
MVC$2GD)P[XPRC"[Z6D]O]'D_9]'G?^/I'S0H6`U%=B[:.$Z.XGY<GUX\V3S+
M$T7$KF1C3*%M$]UA>Z&!'LO/&7`O<#%S_V['\I"Y,+!^_AJDWK<VXJ'B+41\
M#<X'UA4F1+=M8"3D`U3V:<8WR$1!U#38A*]W$J73:28J%GAC?G_QBT2$'*IZ
M.;C4DX:3*/#<X)VSMA-<7SN*TOO!/_9@G(^I)_#JTA.C`IE#ZX`E!`5$K45!
M@<(H<P1.E1/5=#K:D"[@4IZ@@PF@5`X'P@G&:'025.CZH%'MEV]Q_<C+6^`%
M+@]Z+#Q5\]MUCZDJ'A;"VZE4P$<6EM!*`5X4`PL(/BG*%XR]-OGF4=`6X%<F
M7B9Y)CF1?)_`^6@ZI!\N>(QVS*4,?^XPT90A-@<KM(0IS@CI2'<HT7!D0O(\
M]W-*(`X'-<(,?XG)U,30^;U9R_RK]S_]PJ\R+3A^+A)6MP+D%`)&!,J!U^%U
MI9&G;SH"&AW3WGE]QNJD_S%$2?R-V)\D8UW:1,,`+PMVK+S&W4N3HPUYFKN<
M<?`&8]+4ZX@-FF:P<AIY<\B]&I\J;M`G-C8IEXT]'%E;:*CE,ZTT`1K4)D.&
M2IL0&!+H;J_L-QVJT_7Q*</]8]<DP_<!C@6VTR$:6JE?LS[?(]"F8N_8S9)T
M:7,'JTMIO*QO%66ENGD#SY.%SZ7WG#IQ[?X&HMHR!C7&Q+(65GO8>Y3W4(GL
M#8'^3@Y=Z+/H#ZQ*$AYGE8>\X^:K4).QV\E>1AJFX#IB?5SI#)1I?*GJ?Q$.
MH&"'A&.U(&Y[UX,83#K&&7X`3E-G`YH?HQ*>D[^20>N`EAM6@EW=(/3:L4ET
MS5!$L\*Q:$8+\V[/0;A04V43;?'[P]5:HLDV_'72.O)'0(=)&#9*,2>$VF!.
M*SJZ!HF'A"HT%5IN1*!SU(/0-X)>EI7\P,\'#%(('UX_(A";S/4CUPPQ%@4/
MQQ1$&#`S"^[+N.PL"@9&GYZR9]7J1,40G;G#J=US]K7WFRNB-<57))IGLN<&
MO4GMA#\(<]\]K"[1?4A?3/&BQ(<#:$M)S:C94S>18.ORXW0=[#BS'#-AC^X-
MD6\4`253O+2[.VXMY:!>4Y=8UUY#$==IG8D[%2A"^Y;0!5#J'^$?4`A$%%$S
M888!^5ZP`Z@':@YU[GGG*P:PGL8B**O\2`9V*NSI'KTD\YN+U8\TDTL=R=9X
MC?1%T3TS]($,]I-O&CN"6G@=QQNPQ#A6"#,<4IH\B.*&K6C(K8CGUBK$KX7P
M$)F03AOL9V'0DL+QMO57PL<U\OYX1@L!Q9AX[G/R+K.T>AC.M&C]VDHA0?J%
M*:H`EFVH!OO>W*01Y,+V\<CM5E$G:SA=1*!$Y[=_`C+38BO;2QCBIFJP`D)2
MTL9?T/_3%K,'D0C!I'H8HXE!6I28(N::%28,Q*^Y+]LG5?&1#36U5$+>DS%%
M?U$-;7:8QYUKE\>4W1**O6YC/TV5`G[.3FET0DZ)BE491G(3_J5]NFJ'*+G@
M5-A=XIVR_?R+Y2NQ9TG0SNRSL(XIZ8$<TXH?)"H:JM9CU(O).6N"M]JOLR7_
MM*J%YJ<!<3_$A]G%F65P[222M7\A:$;C.CI&0Z8Z)2PLW+%*)D^BXK/W<<WB
M-@3VER"\L-H)-7.H1=:P[^L"[9"5X;G/@9D=Z\,L#%ZEC!`A?ZJ/TV:$>V7G
M&G;X`NI$ZMX,[951YH[NLM(+).@CQ42_3E'U$,MJ9CMV\>=J%`IL:I#9)/GW
MN5/H'E_5RSL?DH!=>>==->L58TD/N%-];\BHU[W04[;'Z$.1<(N#X$FU@@:[
MZ52R\ALCNN8LY+_Q5>&/K"M*!.%7OXJ@3NO'*';USL5]M;)Z&;W1$="\U1L[
M\):#SZ?+2!D@7'F6I\K8`>D-3+7$!W^X9_0X><L"M@9).R\($]':IQM6^.3\
MZ;RZGA-0NV=!+/<?\U%?E*9OE=PBR*<+K(YZ#'HBNWG9PEYI[32$MA.:P9<@
M(,ZM,TPR-,71<&Y*A1`-#!1XX?25J[5[HT,`=NML$L+!6%"/`=+;A,U&#E_3
MG;SY#D(@^>\-""%4;@KG3FW/2@?H:Z=X&VE!*6V]%P\(Z?58_IP7.KF<,?O^
MK",EWU+%I,1XMC5G(3*D_)^-_R:`BI=@W37%2]_R"50*\%#ZF]3H",C7CKD8
MM2UC>E'^-MWA/VJ@*[BSR=%\K8$Z4O!E;'/KCS7PAH%*J$9''_0,0B;D)BH+
MYY881Y\*>A"FU-6;^G_+>66V(,6[M8S<Z,11AP]#%//?L-@OBZ0$;^W^LM!.
MC!LS(27R;$E0H+V+0(XJ6@R2MMQ(4'HQ&TG@$9##IZNO0^ET!["DC5'0AS3`
MK6*BOR7BCHF$DPPYS-"MG^\14_B,Q/UE7Q@O0RZ+SVWK,_?D]S(QJDS('/\.
M9H>7WH!%8Q)0F1MM;VCQF;!>PD4`:D3X00/E?KRZOY5(O,[_N;I(7U_%_Y@:
M%_A*"-:?[1-3:-`_RJ!T@2?;<1TX/A$`DYOA;4>LGKR#01IIWF_"^*2#PDV^
M6/V?8DQC[-IIBJ-^`XS$CIY?]`?@S7Q1/7YHY6?/)7H)H*_!G@CX4_MG7S?$
ML3<N^\[H8&"6W")-ZD_<)_V'TZV.26QRJ]24=(BR575)@1;6>K!=*G\R1!%Y
MT).7,!^4I)7A013TQN;.=E1[.W->283ML4%9$L9R"E&\.@94S)LJG>%+/1F#
M2W<?:CDT0>BZOXQNNK';7)7%+?%X;BZ6LI)0?%L/Z+1J=S[R4-#58((@ZI3V
MA?KO$VU"S8%6#+025978B9X1AW@]@<&G\M$#@9=#]HD;T+-TD%F8B<`"2CW+
MMXS-CO'EYB0$P6*&:G,V[H!+"!_C:IS+#MV,5KD?YV'CO7>(81/?1!^40+VN
M-`!A-O&-%T,`P@$<50ZH:U^9%%X,(>*RL[RLHF@^;`LBG!5"$?,ZLE+@0Y;6
MUJ77E;?"T'">JE(G^[<^^YED!S[MT"HEM"4@L*[#(3Q!4!B>)!!"S=!]"(BP
M4D$[MV#9A4@7'_[Z4/N%`U2Z(U0P8E8=D*K\"!@N;(A,C=%YS/!N-6J=*T42
MJ>O$IHHX=DXNV@+Y=7^`_,A69V]I0(7O54C$/%1(,^32B/M$FA'I*0-GV:(<
MV#9HP%1ER_51Z&^L6Q*RN!$?W&=Y_TQ/WB\M,QN?L#5Y':KW=@0\1DT$R9F`
MITO1@3E349EATDU^BV6@%M-Z=0'^>B%.6A[.O'T"?O#\P>:,UA.3KS$'S]O-
MO#!^(=P1N84XW@C/\X>`76^X73W;.,]TSKC!5AF-E3566]5@IE:9-GA(+<1=
M42CD$0X=@S0^9T&(6!KI&GG$`LK&&QV>HO@&S_+.1+UR@]8E!W$E=^>8DI*Y
M_.IUISFU7R:H[&O8O!'`$IU$..TS6.O"@#*R#.`/ZAD`PG,F:\;O-K6Q'Y>W
MOK\&OT$50\][$'-9UG__;U,N.G79=HCL?%8ZT>T.EC&?O>#*T)H]RK7?Q9*9
MM1+D@VVOKWL0]6H-:=T=*GP]'H0MIYL30$MF$6WP42)==_<GUM:LG.CT'6%!
M.D".?E&$-5(_;!>DQ$?H<Q^\)%0VR`(4D"8),(CF/9:3N5\AD=(WY;Y54859
M"K/,JOR*,A2]IT2,LB4P-)V*HDANE63.S9E!EA"2DDB\!ZL?VQD<<0[_F>C"
MSE@?]8]*@Q&+(P'N;S2FS952W*YR<'\\M=Z&'!"H$:XZ:FLZ/AAA-V8B;=-9
M#@$QDI)YOQIR;K#^,,M9AG3"1?R-5829E?*`:!&'JJ:7^7VEUI"5%VV1XP-<
MG%'0_\HJE/.>>;X^FRF!2CE!!8SP+17%@#C,+EJ*$''-]H)14C1MY^DC;S2.
M28GCX4PKJ..OE?@+M!]J;Y0RQJ0S#2E+.P#L7M4NL&?TJ;70.?`#JZ&AF%NF
MA9-1XQ%$-56FC+,O5YW&H)DP7GP]MBK+GOXC!P./YM[T8--(BAER':H2<$!3
ME[2!27!N;SAX:$Q(?B00E81P+R4#_ZR/<<0R8,E.:A\TR4YS9G1)"%`,H!$E
MG`O*TP>)TI]V7F?4)4$69/P;8&6WM$7A?,8<;2]>?]$85P%[7!3[Z_LZU+OC
M3]-DM)W"2V_Q.3EV%DZJ8-QDT^!XV<-#ZO-I!:>KTF&@V:UKQ9>'I5QG`L[:
MZN2+ND;Z0B%:F#1-"(X\\G&$L\^PUK]/](?/WDCD!U`U>"&_<<D]769*4X=`
M&N!>.OFC0M0->Q(>NOWPZ;37+`M3J-T?+`JC1"]!DIEL_M;<>N:%LA6?%<`V
M[*(@M>VRFVA_DU@B<];-]_([.`R!%:Y[L<!8J%E27?G$Y1[D3WJF_%[$6G=%
MH[3F6ODD(B-)7Q-NWM8-PT-+NA=`)&]!20_:&80()@<[!)Y&_\FLV\_3W2E&
MX6O?K-Z:$>#V8/;2'^R*+8'J=0\O14RL+<(`Q%AP,^.(:%T>XG*I!EK_U>/<
M"K-C@>K+^1QK`<+J)C[I[)-ZI8HUZ]V5-8)FIOS"#515JW5U7+8P031;F]#*
M6]I6'.N8I6&WI+3F87ZWC/7/A2"Z@_H^H1?B-A6C[A)1C#@T]Z=W7QM1;5*/
MVJWLHU'#<P)8;Q[.T\A>"%P`R;**UG/J%'@^EQ^98I]+#\0SE4`ZW0(+226)
M58+(3&Q[T`;X\7.\KA1>O^$F((2J!J,8=+*U9<$QK9_:R$AV(GSDCE]RE)LV
MEQU3]B9KDFLLOZ5&70(TA#'>A.IW97/D[#7\D!DZ.(6*O[ON!HYV(:SLUS?N
M0Z6,5--!Z&%.5*P-PL;X+QN-91R;V]QJJ7FI2<@+VR2DF8-G9-LJ?9IR%S62
M'\@DTFU6HU6I.Q;1"E'<!KD5FW-+[3!"#[?PF&-[<Z]4C?Q[+N?"1MS^SB)9
MKEZ2M+,H*[R6%F6>2)#=8ZRH*,(Z1]65;JZ@J1M[/_S)8BS\ELD<*>=71*&#
MZ*U%L-[[9)R:<:;D\9*%5(S7JV.J_#S$2<8JL/.S<#>:8C(YQR"^262VV994
M^KD-*88X$%U-."*:XSJ3K>'@J[K_7`L51Y4!_.0Z.FDHC,+*25<ST4V$=>H,
M\C>,"+1V?0P8IVO6-N[HUI/?EO:DZ7R>(\+1UIWJETM-OP<8%_0L_M"`,)C?
M/9D$SAF%OD]K)?MXX8[Y;]+T-YI.W$*_'5P4*_A&'Z@MYF*]PJM6SK=2F)@H
M^KC-DW<`,`OL?W(GA>*\[7>:GD6H^,80:OO"/A+.0@3;]GCYNK&]RC@XSJ#;
M+(H2>BAR4&7NMP'OQXU<@SV7^4@;)6HDR!7X\[4X0K:U"%$N;MM<)OU?2.J.
M(DR;<<"C"1P3].(12!0+/8'?9.-R.'^K^0!3\PV!WZK#^^B5_1\.Q=+6;FB1
M_0%;=0,<37K96(7`Q1/'L+L1'7$YY$AZ27NT#U+&)[G,.16?M&[PWS(C2.?(
M07'HPVRZR;-<TH>9.@N!>?YL[T,'@"F#6K>;3IC,BN86GND`Z,TZ:38I$#FE
MDQGB(2EWRCBG?3?$+MQ$+;C,-J))>Q[[S+FUA2OA/!PE:9*^.DG>]&G4+97*
M@!HL"GEB]B]K[KI.=W)'CKTOF>RE"3=LT%<)VPKQ1*L66:)N]Z\)9YL$+&ML
M,VEZ6ZY9F\@`=A\V\@C6M;KJJ!I>-ET+?+K4!NB:XE"[']6GW;HY/<XV'OV<
M^V-D?=&?(6U8KN'T>53&IZNZ*D/J^5[>3YAOE.,^KEUPAD?MZ-.?5XRE_#ZN
MT`($AV[+9L&52/B,_^$^``8?_CIJGG#K*1/QQ'<R0>)X!JW\B';S%M3ZN4[3
M!P8BU1L2)*3<U_'A()\:>;:E?<K#:>FMIJTH<J9;BQH;CMU?KIU)Z8FU\@8_
M):WFD(#&\Y?H%@*0GH)9Q13(K5I%I&O.'7*TD73&"Y:]H<R[3T_#S;F>%%X7
MN%DH*G/_UVQB3/R/BPX4DXQ:0BG?8<&VW`[/\K;WJE:;.I];``?]PV)$[AQH
M`G747[QW5[N03R">3L<#WAG\UH8&[H9K<@?U_K,[MB"J=JFC@];NZKCRG2WJ
MR[QY++G)3`*%'4J#"99C[\6Z:4=43@JG4K`E!)+'Z,?U5]JV9E"3FN>K8PG9
MFM;N4P/W?4959S01U2O3D2(F[L&6$4`0S$KLG5W#!YED:TV>!\A-E[K(F7PO
M5!;`B$&G@L,%]*<0C,O"$ZY330TJ1D-:$TT-Y`[D3[\!3S#EVY&N9H7[9RXK
MC%*P&6*]AA7V!Y5$$(XDD8VMXCBRB^]4HX['RVX^"KP0@S*XSD2\2R<VI>9+
M8_6&7>_70T#H$9528*U\FQ!R@.2[KYV/)Z0P3ZF_YS@DBA_0/X1S@T'1*@XT
M-Z14;XP],4G@/9FOB=,G%?<3UNW++V0TJ9<"1MOG3^;_N&+<L0EOJY1-*$^5
M3W#B)'"7#'\4LV]'QYJ-Q-\JH6Q'Y36;5T+P]P60A_P#ZT`>9H\"&)IAHI_+
M2OIC6!($NJQY@Z`=:+J-_4.*$V8R*7TDXSE"$!_PDXW+Q;,0?0MIC+]LH!OF
M$9?5?EF[27@:TC<1*$9I0(=TVN>8(JLEY%G#WF[9QHFO(DV].T8KKQO&4BHA
M'(W+'UC,-PV$K`P%M\(2F7RNIX.7$RP]91SX2O7!:+!R6KV',*";IRN#)E7W
M-^DK0U'+8%HUSM%12CY-NSNC!AOM(9=C74`71A'_-<(!>F4S++O`G44EN;1'
M*PH<'^W\K5NM8"(X%(4TSZ%NCO<7#ABNG*6\7DI$%?]\8LKES\]V(7E[4C!0
M;I)B87I[S!NTN6K=R6`7-8B=,A-QP&1%X0ZH%YW_F'[%BL1&F.CTTC`F6DGM
MP71_Y9`\)Z$7.>HE]_MM:KN\UHLAMF#34S4U">D\TAO64KJ)R9@0T-L[/ZE^
MI&>4L)=<?PR]4R;PGDPD=`@+X7:!>2HU)P6#=M\0@$!R<L60%;GXS[GRB&2E
MW0W/7:E\FA!N'P;%206%"02,;.5[J^N.M)V`*:[EW'D@_5U]-<<]VES.TW_R
MO-J6ZA.B+NETW!2Z5DE9QB#55%`;YE;.%EX@#^[-1;RJ7/W8K5@;\BSQ5>QR
M5$!4WFZ&+9CE$![E6,X%LGORC73+NX9?8O;F2*_C+D,D.>&>34O*V;J:O09_
M_:3:1JV80P[5,:E-7&95GG/T:P67`.U*7*B*O&63\Q1`I&/ZW(Q=5#IIR<H"
M+S?]>%Y3SS9-NI;KH%A/DT[5?2/&]SSCUN95')^_^^K+\#TF2Q<C.;7K7ME[
MF+5(H<S**SPY.`XB\S99:))84CL]3#&YQ_E&L%%@EH<9>[@ITNB]Z,+R+-7>
M;L6W8%VFI%$"/B\>S#,7?V\3<V?,"XED#U!9PU:V>L(UIT*[<PL$$5%R/J(/
M4:`LK1EW;)\J^"%9P4S.#LE@BL6'C?`Y-5:<W0+:CZ4JI<+H"^Y(T);#L_(G
M)"W`^LJY)S@U'>]=?SB-`&-2LB;;>W5;=OP/,+?6\+P4)W^06QL!NHW"^7/]
M`16,J93]?@W:SUGQ0&7]'RH$$1#9V8;WM$</(GQYYCHJ7"!/4C$W8OGJ*=ML
M!,=@[?3UF:!L/YVX!8/M'D$I(:!I"@(A)/;CV7"FHQOGT$9L7_>*!K:DEM8Z
MDM["2'S/5W>XN1A_$OIL\-YY#C?%1_=D)L*=P!$3N^8(-?*<NAQ9VK]=Z]M%
MUOJT<2#G:^L!H+3WWN@9JGLV_]W;+0.1S]OVL;/XPSAPH`S"&DH^HR,9:T6Y
M:O"L+\F]>RF,`/[46037ZZF_M(ZR#K!A$#,6A#/0E3.'-9JR\5M:@Q6DJKE`
M[:EX%;>^)>OTEFV$N[SS!#*XF/E1L0#O0<;Z%^5UHM+D(\\VM4"KMU^L2QUK
MT/O?.IC/?\JUI]&V3)9\D<TS:='=:M^>KPQ4`.]?H&J:E?^ZA";_*`["0P78
MS>4":@]D.@7STY9QZM(Y#0A7-U=$*XM7<_#*_&"`(_=L8C56*Z[Z#S9DE.")
M/^A2RDFO9MO($F]\[#/L4SIA,:[IXP]4,SGT=]R\W-#!-4K22JVSJ,!KW@54
MB3^8N:#:'-KB@Y@4>,\=S*V0Z`[#]C+]\`9*O"6>K+RO@%9L&]ST==>UNPKT
M%_9B(ZQ]XHG@[$*I]S!R2+/QC2.B,;?9/P/P62U])+26YNJ=23LM?`]1)F-B
M]V3&\N_`B,_8#J6K2?/W&::F"XD5$&J[@N(R>Z8WBX;5S<8HOPR6%=Q<2K!<
M_YN"TB\ROX7=PGHV?+M-H&&!`:T>`PQH^8C'\.F587<GZ4BBM.DPO,M6`9C.
MJEY\FW^63.6>-(0$%+3+SBGATWCO'9^D/7I8-%\5#L*MCI<ABT6S>BP,C[CI
M.D\M3H7`^I"B,-`._B-81)]W%<'('9!"@"3GK'XS]TUN%<UF7?ED+`&L-1UX
M9`]`T1!VVP0(YXS'F?.D6F.4*#+Y:O_"2(![G6\\.^G(B$(I:2IXTA4"63)'
M;NTQ?1@?PNTY'%C+CV](>P]#`*,C4X*AS8H3M<FW]Z[?T7E8V;J!:;06.ND/
M(IZEKN=._R:C\>*?3I<4+>G;8!R0B!41U)D=4V]XAV9D_T5XYE<HZE*9&_5Y
M%D_P?\$YX=<H7`%Z7<7N87+V*3S9:K$Y*1IS`2#JQH9<;5`=WH-W+W]DA7N$
M1(<Q67J8`_J`<O<"BD1]7]7M+U;O'/-$9]IZ-J[[R#FKS@X%&YJH-K1^R$W#
MSM`C^[TJ;]J23U83+,,)?+)4`Y32;25D].E9AG3^NS*CU5WA<Y`!GI+ITG9R
M'ALI_:&9"QMF_?:E92QY5Y)4W?,'O@,`%S<Z.CGBXSVZ@<YMC"#@\ER]Y$M4
ME)F\L):$$/=PW=#4+:[\"HKQR!%Z(168Z0-6;ST-M1P>.OA9MMLY11>/=*.'
MNCYZ^/YI_^YHX2*,1QBE)68W`H["71=0KI/49HP1$COD$^D?!8FJ:-B54@ZA
M-^_I">.Z/;V+73MM;R[.FU>S3P$)^MG\S:*>2=1\]9:<Q14Y9Z5=AV0D7!S7
M^CCC6V6,=[LU_&_]0S2`W#8N.E8DQ;-FO^>O*!CU?7(:9]DI6*)ZX!K8XC[Z
M"FV"^Y?FSM@+YU&H@A=I4+\D!*E8+%C%U'E5&0<,,[0_#)A&XS#3E\VNVY4B
MX6]?`Q?P#R$$D26SC5'(_D@C$NG"]E,HDK#Y(*K[A.:4]KZ;>^VS@_//;F5D
M!=A]YRKX^!H=@O3F^,9B7A/;M+FXI>MR]',,HW?>9]#9A$:8@*._5F1LHE'8
MF5&*3Q1KXQL@HARW%),Q18`4"QP15"?4-RG.=-!&=.R(W5"".-0C^(O?&KAZ
M1#B([+B'=:U2KKL_?-<B8;K;8<(CQRF,D8$GZ#CW))<5M0)Y+?NG1X_NY,)&
ME&5<&+!1@BAG."[L"9,;JD8^SM^I&<N/D7L2BU(:V/P'V]T)F,A._&(MD#J;
M`/%8,:VW1)'3AMI*6^=+Y^9,@I'18@Q>L9<,K8S+UI5S[I'#J%@E?^@_T.(;
M#<UDTX_YJ,Y+SR@>_Q137JB#%&:1=#UF*:$S1E#OLT_@+1]`$+BKC7J-C^73
M0>]T<5L!6ER?T]A[FT23T4)!_!'%N@PMR*LK]#_OK$ES?B4=_&=[\7"U`2AS
M0<DKM`@V8)XFF6=Z=HEV0FXK+2S#"RNA_>Y]#V(?@949B[)I*KVG&M=PLJ2-
MG$_O^]9T$S7LK%*3DVW`OQ4XK?,R.?J^:.%ISYQD]&>NIBYVFV#F8?;'O3!T
MH:"*567+%L,H0-2^ZTL';;N-'W.O9L4OM(QA60<T@T_>^`!?BU&&M2'S'^#K
MUV/_%M`VFH2^<MN.W9K`UN?0/7F*H6!!EB#)R]KQ&C:(8P]8&=&`D9U6_UY:
M+`U!1.`IXQ)[JFE[;-W-+Y<%]Q5S<Q2)7/+,6!H>6&H29<'GS]!?__3/%`+J
M\NA!9'G%^5(:.;+<(Z"6T5NCYT,8B<$?%^%G]1FO)J.THC)2*(BXQ:-5NS7^
MR5_IAK_,/=,:0N-Z73P"*6H;)]3SO()^0K_I->XCW"K@[7AHELR[T=N;3V8*
MV4<'[JD!ZI4T.H6QL?QAR55Y<IR%)N;A@-8R4+SI626#7^#^96G4\D'U'.K?
M/,XRKG!4;A$Z[HC"]2_R#5&UIZC./P38K[G1./8;W8,2K:7QE#FOB2HWL9V:
M,5\`W,0M[]^2(RX_8)[O#:8#!\<I*%;\%-;@Q&J`TM-MO2"!1",Q9)USR.AR
MZ..:[G[L,5R==[Y\S./%B9PW5[4D^]>=YG@Q/)-\?8TZ/XWJM(,9*!6Q=]LT
MK$TK1?CS&K=%KWIQ<%E!2[L*OX7RT#T2.Y$Z$?1:)T',0?;,&>P;G0N.0AW,
M%;[\*"5F2[+V(FA01U<OW9S`WT($KZ*(W.KJ5K=%*0+@]UNDD![^\]>@?8MT
M?3@_'%T04G.(5$X(P:^,]['P?]'^J4);(6@8%`RJA+_8UY:[XD;7-33R_BGU
M45IP/94XS!'!4!9E.R;R<!@G]<WPO#\GWQ1''HP1^&1>`Y9@)RVJQ"Z%Z/BM
M!3"9@,[!?\R$Q\Y9^WA4B0]BJO035-F9\)/95Q2Q)`#O_+0!50^AS%RL9C5H
M]#D6,M.>S]YU7N=N4W$54#P<)V,#95D#9*N2H?@1H?N46^5DP'*]U)!#T+]!
M3$?M'0A=,CHC"FF%DW@B9<2EE,[*V)U;HD*Q,;\N`T3"1G;E9(#'+':@^VY_
MF#6]E+D=/!JR=<2>]<?%V&H"9/%^?1/ZT,^1EHO6F.JA5X0I3XQ/A^QY/)@`
ME8K!-QF/*QBE>K25J@TM4?[=P^T&4SX'(%EL"F-)'CLJ?3]#'JV3EGX)MKY*
MD<?_&\>M/QAPF1@B0^2?1%%^3WJ`[43M#/9(QO<L#9/3RY`E<_SBB__KX=]Y
M9D(1V2`<9PUS`!:?R4&2=S@2*Q+YUA'!'>S*"/J+`ER:]WC1<4$>Q]3MQTKH
M:'RR,#"J6@\[[WK;0E3?G7H^-\Q^FU?:9]4.AQW)TJ#1()/BW.O?WV:8'@QO
MQX'U!4JI\W#47NI(LH67E<KCS1X1?Y+5X?FKI;"/WP[&O0W"8BR?0R7N)21W
MD$X5H/N;<DW"&LTT<7YE*#=\/T_,=JL"H-<UN?4`NVG8S*6FRCY7C'`B\#Y/
M!KHJ%/.H)[:/-*)Y]?SOI2+=CKW,UZ\KOP!OB!R99-(.L:/_\QR?)R,P4]ET
ML5&[W::JW[E<EH%^L<M55YDQSB#+6FWAO4X)3EAJH>@@U3RV$\B<HLJ6Y\DL
MH-[Z1$;^<\=`="?*'+%S7<_\KX;D[4/SD#FPS,.1(`1Y3V/`T.=371H+_48X
M^R<L:51^\KO(4^OF>J7Z</"-_#/ZP'GF^,^O;-NX2T-H&4<B$E^,AM2%[++I
MGNE_3WP!WE/XSC>H52S40IPR6OPP119?>33<:TOTBL0PT`JDHFD5H>43^F.A
MJJ8H3O,YDT:K%=;OJ"5)C6N:W['JFN?.?YE=`%V/D%]*ZLAF(A%P3V,&;+6Q
M([:C$FT6/;R[^=BP('>1&H/='(#*E?I5DI1,?I#%ZBXQMLO6.D/>/'H35N`X
M!$C90:A")0S)DV\(1LCT0<+H7LN_4R\5SG&^G8:OG1%DYKD&M`(W"MO<Y?`-
M=XT-JUT)-D88=GKM*W1-$R`P$D8],3VRT\T?P(&^<__^XV/6[Q>.JO?+G3@*
MT4EKY4[B2[._M<6>W>]2(OEG(-*9K]<?-J)&R_8CHDA84R2O<6H,\Y6_<V::
M]TGBHMD'M+AS#JUE*S.-O*ZPX\1*CY#9%,K0S'K[O<W/>)#R9N.>G33K?,VW
M16GA!K)'4/#@CIJ6.5LUSS-PH;3V5//`"D"^6MP-/\@Q%=!8W*T@,L?BOETP
MN?P"W>.<F<BR@6;+N@ZSX>G5UO=H$WO"-ZP=7<=*8_>;1.;/L-%,BK5[J1D_
M0[3;H^UVKOEJ`KK7CL(+7\[$$")E9(HS97\Q=!T<F3Y?$6+G@J#[]_5+#>X9
M4P?JMX_Z#4_5YOB#Y\]R#Y9M.`LHQ'L;\ZW$.CZZ'WC'$*GJ(:*.M'WA(\5+
MDF9?>T:\YDH66*7,9HV=POYR&/VZCDN'X#XK_Y/#O.:>\[^,^8VDS]$[[(_L
M5>_^_HT)O?Z8KJ:[0;35WAVCCS#R</HMSG+N,U;YW_W2^QF(H9S9'9NB:@R=
M!7VW@K'!1)=,.BK!PI=!2-4/<RY*N'BP\U).+!XS1@9`K6S-["%RF+4[_9MZ
MD-;FQM9H\7!>)49RFW\Q.5<`*P':4.*HQ1D<?$"SMFBU$52&04*7L_IX3]JJ
MPNWQ=T4MZ+N7'DP]IAU'\IYF:@AA:P5TCK#`X"!X+""<)>380,=^ZR1I_&:]
M#:+R=A-B:MOFD#L90I];U7[%\Q\CVW`*3-\$M_T.2`R@JN^LT`J#3F$9PZE#
MR<'_DLF8K;$(7*':NV##`UMH2JKPAL%L-4VYZ>VU5C3#T7@-@Y3)!OZHHY!X
M3:/]A78YMD:F`=E)=6IWABX:D)*WY>5(]&[>)9T2D(N`S=T9*"'3,LN5T`HX
MYVA8LW)F"W&>17.:0U&@OIA#T_&7K!]A,0UCZ=T4(G2N@]YH'!EX%WGMVUQ?
MXE(7%V[JX07Z?P3&@6338:]AX#?,YQ""0#I#U*5B5B=67+3)?):)QGXB+!1B
MAKO]^E:]S@]9EWD1/",=%^^ZNQ"L?C%`AI8YI7_6"-^QBS`;?E;BLU!R<-17
M)T/;_[V:QHTAL;B!0")$'%MSA5$)RKJ\O*.;A\G3LB_*(AT"S?WK&7U*T65#
M+&/NU^S]J@K"MH)I-$KKHE(R,/U0=AS@:8,KG`FU,W-!HKM7&Z*KF3^@969O
M^"T9+AUTQ%8BDS$Y!X6_>IMFS2V)9>)*1PV>VKKCU=A]5VA:1'2L<U^JZ[D3
M),R+L"&<3HTLSCB!)OQ,:8GA"A301;9M*B0`18SDAWUU*L;[%;I2^ZLT)*9N
M(TAO&L)Z3WQ@Q/73MD6Z0::K+92M36E`79NQ[-&FC4KAI-PNK]YQKS]3M%\W
M?RK59-#:(_2Q.;A2U<*UQP^__/Y71LS6SN^AA5>@8AE0Q2_]7(@DAX&H`SX(
MF3#+S\R(W5R_;SV]5K%+R:UH<`]*@$P?>F0#H1IARH&O8^!I#^33/I.0+A=U
M+-U*0:0UX>#;?\<4M5H'BA<7&&$;&@4(ML3\1B_YZE8#;C;4;$`PFE`&LRY4
MHWWSQ%#,F*KX7S6!B2>H2C/GR--3B-^0N0L#S$YU2TE_\\3])"46WX6-(.$4
M>B<;URXRU=JJJN1FOHIL2&&-H@5DI%'D+!KQD8Y.M4N^O<.<)5BRPTR'U$JE
M*$E?U-^&S/W^B0,(*!OW,15?]V7P8Z1U^BW;%XLE>F"6=5B'Y1+7'*U/D%)]
MG/1#+TDR(]_"WAO<.9VR?(8-K#<E9W0]7IAGMG$H-^(P`+4L-_JL92A[;!Z/
M1?7U&4V4L*06712$UIG3@[DX<3"K>R`N#A-\MK4:&-ZD<51'X'[@\HC2Z42O
M=01;K`/J,U&VR+]F&N8B\J<N":QXUV@B,Z=2T,?%%R*56%(\#>Q.A+R@=':Q
MDN!NM=@=0B%1Y#:;;BXSN@'3TT90ZDZSNV6=)*-XRH0\DL#F^`N:,&JC:4TF
M:=/UXQY-=!<]SI1Y^Q!P\6'#CBI`H,@(?%A&R!YS]2@_/6EFT!',*H(BHM(_
MTJH#:R`GEV1`3."9('6FA;TRMWMFC@Y@)L^23(?T=*LU/'K!TNTEG++KF*1-
MM`5LKNR_7*6FX$6@0N=4>Z#FQUXSH!19U(*A3S'$(N+[6:#Y6WX<UD6CJR/&
M'>A\1P.]JW"N6%&&K%\FQ1]YR<J'.>)\]O'NCC,N5Z?[],C[*W.L(QZ$]-5>
M&$^?6<*J#4_GX?LZ77^<`$U&F6@S0G-&&KSOU0`)=V0%&2I]%2IXGJ.Q`]?(
MFC,7#`1M1H1?2J(B?Y-%C:/EYOK@FW@HS.R@AX*JAW1BQ)LBE;6=\/E-L$*>
M#N$M7QP73R/PYXY71;-JJ&<(SKGBZ;CI,$&O]N=IV,_*W6ZLH)3Y`"68DO87
M0=E'JXD"$<825&/C6*2P3C;G)/B1RQ6RO;G;M27H/,Z+JVL]%D8XP4O=T%YL
M\%M>B]N-DVQLL?D9DT3=D[XS0=+92)LSFN5'$"X3?.;VCXJ]/@@#58MH+"#'
MXR`)4V2H,J>6V)KU>HV5&/<_'ND]@HA:''*YZWZ<V!9);`LM>^JG*XJWOP@$
MQM>B;R/KPMWO@3-6MLJ12?C([.HRX9-V,@">,KA7MM&0[&W76-7)5%7'.3/P
MFWSZSFY`AE)DC9@-=)G$2A(2!&Q+V=NH21NNF*P0\5V.BB$I1E%P63[*[V&^
M?SE"?W?[&:\B/W^/N]'4M1&.K?PP>PP>Y*%F[LZN#NZ9TNW>&@SAVI@T0OUY
M7U'=B[V^7;R"V?AE/?-$M.5`^=![][/(308W//+]0OE>#BGHEQFA[R$*'R_,
M^Y$`[/2Z8CE6S@P!Y:HG3PUDJTD2SS0O+52W\%.3FNF)EBZHU63>9:4_!KCA
MVD_A(;[J7(U!D!OH%QTV4XPSET?4X#'<>AAY'V&F_=$1:ZP$Z#)L^KL[;2/+
M4@?"\K%!4BPS+G*+GB?SRSX:<^2+<Y-ZZA[#VN&K?KI<&&!T@GX&0]F99<G.
M87?^W_E.X($K]XYI0<Q_Z)MJLUB+P\8"[S$/M+/J!%-G<13\\;`')VN^VY7&
M.S8+,SKK"3/RUI7'NDQH@0KGYJI0BL>Z\"?VSJJ<I)G1*\RJC2KL(DP9AS'1
MNA[_Z,8A+G`)ZC=U_@JN]JNAU@?7UGZ<@+H7"$9@H:[EB:Z!U>]QD^@9LD/&
M<-V>O#0JAGL2'=T!;D?_P`A=:8W^@>(<Z^D;1X#8X\AO1+"&#V\QQ!-'3W2=
MJX7Q[D2+&(71U(^J;Z3%?T"TZ4#(+TRS>IK;$NPZ[2KP-"D/GB5LIDC@\"BP
ML2O,*@:PYO*%'BUE[IJS8?7CE,LCEQ=;P+X.%':C[";>TT=_O^[,SA.G5;4-
MD/B+K40[^<G/KS<X"+WR#%0>6T[XEOKQ@WGF$T-0.A/!L;2O6',$U%-FL6#W
M3Z-#UTT-K-^+5X9?OU:?A1AIB8Z![+GQ`>IWT.1MI)38J=0$=:U+_-'!V1K4
M=GFK&38^\F+E,*H@C^`[O%6/N5C7ETR!QJV&&`T*P[_9%]E2VQM8IRY!<Y`G
M181K-`G8EGXA<UF593!!+<U&?N7)"+(E@DW<,%P3GAUIP\S-.9V/RXQTN-]!
M6Q;CNZZE%I<6BT98U9BR3N@2!RUWW$F=,&EU9RZ`_KT)NUI=L>Z*`0]F^K7*
MF4L5WN<P/JE!4-T12O<?YK`8PK+L1DSY1=<8N[BP[KA$H6WCUC_`N*X*?L%T
M=XGA51[^-(9/.HIF2"B**_)0;.QZ.*]3K#)6*O9N8,6&;6!7&3.LV,WEBY-:
MAM:^9-HRD]F>@*XBO2]]Q3\5W/M??(T2]+DU[M&.$!@LB;RQGP0ZW^/L<6S8
M7##_1SCBY:*<DT1M2(E.<2@PS7WF":KOS./TW+)H7?:R<5VFX1RBX46_%85R
MW-06IT]=Z(\\5@4Z4KH81''8O!77,MY$(B>%K\DEVY/'[R2E\0EN^1M]L';P
M0J2HVZS*Y3%$I/H)7O<:6+,7UAP1^8E.*RJ(44<^+TM&:8[`(X!\?`+'8$=;
M-R;,?(=<IE[/J(7!YA9T0!H0K"`A0T7602]&S/!P=Z&;D)ZSSRM5`/LV,-63
M</S//`$[1IR#!!;<ZB)O<T%5:"W(:V\]^-KG]@:#M83T86I%)^QK36A3Y\>O
M`(X59ESW3!"9%V_T;9.^FH5D;"E[FJEF_B>^\$0/ODK?'#N13`<<!<*KH]+S
M:.E^^.78X=MQR%PT\>K[BMUO116.WFC%*<9X/L"&5AD,G]JVY@[9GK04OD[^
M+M'JJF!!<T)<+]8?YNNQ-=%"B54C,IB,(//%JK'SZ!>3X0P;L1YU7X3)[J&2
M6?YXPVMG!4,0/7%SUE@(7_4>'&,$<2)+8P!9WVG-20FEH(_-;IVD\FRNCA=<
MC_![6JW(6HKN9=3@L%4%T'!9*F$4:FY8FS^P6X1PV1C9EB`8^GZ9^4&O@I4G
M3PTL[2$?M_2$:A>BY^(*I,.6YE4*Y=]WTFQ4!,'`7BC"*^#(D,#63Q"3/1%U
M8I9H#!\P:N].$D`%)%[S;:8:6E4@U<RBF%?SD(4+I'(7QJCQN`_.K$(:CT'/
M>!729AFO</E31_96X-37KK5(>TN8:*VI#S.R'!R^C9G6Y[Z,>0_3<+]RX<A'
MZ",H&!ULO1?_GBZG!J&IZ?[OA^^(PCMQ5:5MXU$YL:4$Z)F5_0R[F#0;H8`6
MX!C3,]1[C>C>4I6M:/7#-CJ5ZOG9JI<"ZZWF&#I1'GWS.K3/Z*2+!WG0L,@6
MCE`1)Q&.XD$$_R%G,H)9;.SCRQ75MJ?@BS54:R=1R=KOH_I3V,^AY4577W,S
M^ONC>!G0?^/CO1S/:KPB'<H,*:`[I"DS'M]29]->T%3&?31#Q'U^FW?7=#IB
M*PP`"V=(:K^)_I,+]FIL^(K)TN7E,=SPN0HX>E7;^+1WG47E<M$NA;8VTC.L
M%"6<7H6_Y93>0&;/&+L"M!RY$(`[?)?F@8")^/D-#'H,K9[ASY@9EZY>;DW7
M5(>G2W-,>_O8^B!AQDYCY(?\SS?0F#V/Y:5B`U2R.2ECIFI5(;>+\HYE(L91
MXHG.LG0^G6K-_XUSP%'J%_T-8:PYG-54-N(1M1T8L<7^>Z*@WJ#.$$I+%Y^R
M+HI]`0J>5?.&/T0%'_3V)HD&9X'6-=]EG`5@&&+<W0[;8VXG`*G47L1ZJ/-@
M!53ZH7D1"*R1>%2C0MZ7<XIQSX;7<'W"(_;X7EL6GTC'G5,XWWXBJKNE<JY)
M(KY*T1:9+))NV?O0?5O@0HP_9IW0=_#O**O\[((\DT]U%8MOD-8M-2/I3,5"
MF,W&2\AN1SR!<=M+?S3RZ0?043U[XP6JNTZZ[;#Z,[GWHE#3)5REAT8:07,M
MJQ)%DFV>2W1NW,QAWV5NB)NW3F'Q=;J.?S;8Z6<&N.0=>;T^(NU;G.EYXZ+<
M8N-#RWTL"#WKO`=>=YLZQ&UD;\9XSW^(,V208BY5J=2>-:"^*`_!M457CE\3
M/1[<41V\QH9C)7QD_WQ+SV0ER8_E70_JW;4L44NS4)BU9E!*-:'V]#3Y@4)3
MWCNNNTR21Z>QG4`_0G.DB\(RN?.;M3N2OE(MT@,3_/[5H-UW"4/'7/SQG5)\
MCLC\8QHELO7@QD>VAGC>U3YK0K=),>G?5>MLN92L.I%",:R82*J#OJ1PU"4E
M%H%FX=:]2<)P0F^E[0K'M,(^0"@K<1"UG<6#$1<HVC:3>&&/:-#[91?E\LVP
MTEHS>8LJK_>-./$HCW5O#_G)8*/RN/T#70CY"G+2->:EZ2Z+!GYD:)8_\''!
MDD?[@)S<G1I),)#F7_7TS:=^KJ5WC?PM$\<)6;-^:\F?*/-G+(.Y)M3$$83S
M*E_Q&MR)E(U%1>48X@K8E%<\Q8>;(FLLT%L$7&L:X*!>RL.XI]^FL^W?6F>N
M(Y#VC%<MCQ`:,2828[\Q1$$/+GX=]8]/<&K4CJX67IO"HT1TM7RP1F&*I0K>
M;(@J^9[K"6'1VQNYA@*TRFUD1GS^3A>2G/^+A%:]$NC,.*-K@2W](1FQ//&V
M5R/X4/R7(S*I9_-WS,/N?#&PM*DA&`/F(LUK(#OE$#OO1=4(A`=BF>)]&B$\
M!9*MBGIET+@\`9W&6IIL,4#],9JT]#!`9IB=[(),5/1%MAPPT6@(PAD;("7-
M0F?,LZO.?P@LLXX-9@1DXK'MJ>QZ/,:/$\Z/46=,O#'/BT:4#T6VQLA3%>^9
M&-J^Y+T+`G!-/KNO%$05S,94?1D&&/@)I9VG]-G2)EP6?$)Q),@Y?HRH;J4`
MB%%#K%2=EN\,F`&!$"2+LU&+W+'LUJIP+3N7MTA$H<7NJE3Y>.(#6X=J+M7M
M(0OK'O4<@_':!`B1;77"EP^,'4ZQT7G^6Q":BYI8SI-Z=[\TB02NBVM&"0.R
MW^.P+06]:D"7F/D:RW1&;C[`'34KSJWK:RVCK%P+80^`@)JG6=.AY)J6Z)B4
MRC[/WI)_DZ";JID_T2&_S)7.7O*U;';IEB+IWNX"8')'_\N/E-Y[L":N[KE+
MEH1)-DHFV&ZZFGR$44]EF3Y2?\4"IUD`(KN#8KB0^,\+`USP?M,3)JV"D+0U
M,HVTQCH9E2]S#>6<CLZH[/>#*]P>CP*^'"@F:U()E!ZTA(PI`,`5'\N>`:`=
ML*J'A;WW_V6UJ;@GR&.W/L-B8D)>58-AF@HP0N8^J.Y__U'N:>EA57;&X(2'
M`41^4T)LM81%=ELKM&%\7KY$=YO,)MT5I20S'TUCM7*]<P39^VL,^4Z>1F&V
M;\B@M;/:^[-6UIS$`F;!+_!OWX_R2=9D$T!QY[\O[4VX`+9E4@/95#AD?'W%
M(%7E>)J-Z@SC1)2[R>E5ARA*Z*1#V5#;,7ZO9R?]:VOI3-5,`NE.^((G9JZ@
MZJV.86<IYM*NA0ZZQH-P#9V7'BY-M3.!]!?B=(Z8O:A;-S07IC@'^DA'?AK"
MB8M<:-<$F@G%G,>8U*EB6$P/_*WB/))-*4@FU-7?N8X*XX"Y-E83+1'\6!X9
M&#&]3-RKA77:1NE9TE5GTT$$7:0Z/MH'-MW$[2M#":9TT$ZG7B*FEBBI2UE;
MV<A9R/#H^;M(=/)KY1S%\42_.S!A-)P?<2,:OS3^60`LH-2'T].Q)\%5:^[E
MK^%#3RR8L%7MC>+&?+]K00OBN0@KAF^TSA>@@08(NI,^XO0#:A7\C97(E-]A
M+V^232HC\L$&O,#RTPU&*9=/F&Q0S,&IR:+FS)E/4=^"DY#R;P%[UZ<L)8&;
MO:GZ6(QC(.S_@IS<6!-:"4FHRF$*3/_%#"W5KY/@*T*=.V.M3J,<<YI#,J,W
MJ]$76\[`RP7G9W_C4]>((A!WR?";,J+$"9JK+.WTOA<'D\X5+6$^E_[AU)J"
MFP$+Y(^F4")G=#:+5"?!RW+!A.[-R)8!A(K[*EPJ9!:8-`S=P\^*0')-=?!]
MK?W,2,]_6F\/\B@K1K6ZD*]NUAQ"Q1#R&9X8G4/-*+91FNQE2EP#BKD;0\][
MI![X?Q`_N'YZ(,,"HR\4X&$)&,QVA>>-'FQ3(1@=I6O[GPI#.&@$T-D!1DJ^
MM9^E*RYW^:]F:H]F0:=A')L#DJ7>W_0STT\`G%Z+A.':H4RY&_"U2^I1S>NU
M.@^D#Z=<WG)[FLQ)&Y77856KVY87I-H#NPC#T%:XV4_E'>LYU6Q,VG\#8H(Q
MKJ&.5@(&ONMQ=I-8!T+;G?GJ`*7\*XQP9DI'O'.\DM",Z_OSTCKV_9[J"0DL
M(6U]^=4CY96LD$GCSY%5P%3_23-?XL6%*24*FS%E3\=^``P'3&FK3:],(J-0
M;*4Q,QP'H(O772WV(<I+)`@"]B(^\S90E4@=KXXUV48:5B%@"@YQ4!J$Z^IW
M1OIH?+5NL5@MB#LKO`/V5?F(=G-,Y`^H32JV,I:J52?(>OH['@:6DI!VE3__
MI9X2R!^1S?-VO5@IIV:N,^^=5)Z*&F_:K)_`1[\<833!22[UH7FI)]J2.4&"
M#ZFA?'[%1TX]RILP3`@NE;+;T#\>.=0T7\WN0PC3!>;NK;CBLTYT,(8[ZJZZ
MRMMYP!P^O/;+^-TA^3-4CG?]JS(1LGNG>5L#$6DMTPOSPS\FS+_VJ)A579;L
M'9M-+<)":4KDW'S>@5V4\\2_O^OL2<%YB>]YXIJ?(#[;.Y698+7+]B'1:!XN
MQ=[?]?AYKZI@JAC._X*ZQ.7#F4-S?_/'=UQ9^-X:!V0@8,K%7&<M_!&<U6S1
M!8S>/=>7(JM04=$>=!A1?'?@*0=-SAW@G-WLT`IUB02N2Y^-)F9&U.C9Z6VK
MV)P'9_>1VYS?"B+&@MMZ1KR[;Y-X(2%7MA@[VR`?L,27:!(`(.G$$E0)0TKW
MC>X,_NP7:RR#+SE&0:_N/E86&;K+_?#%/IQED&$??1%[&^4OH'?Q-VW2L!%*
M>D33QK`RG^38`_W-S(8"O(6]F'_3`'S&6B%?KA)>??T<K@"*7>=Y&"_XU8S2
M_E_][(=%-_B"4(AWC]926,]B_;=1J!%E642;!F*33/76G445Z7DUB&2#R'FI
MA)YD^>/E+ZWR>*V1;MN9IO`HE^I,XTEL_S->(OL)I`Q]6CP;YE_PU39H.O4U
MJU$N]U;5$HX$I?;R+8:S7([NIQVFV1+0?;@=#`!%UY=5;AF"$L1S287#CN3P
M:!CH4@_U&N]OP:;,^0I&[Y^PT_CS8J7$L2*&'8/!<R%/MG$C#B%SLVO,PGK^
M]'.DH6,YNY4-!G_%6FL<V4/.C*6\?5;0N?J+PU%M<T1;!I+#S`TW<5=F8*:?
MD(\X!$Y2/C"<3J,&FWV;^Q@@)"QU4JQ:0=R80$51$BX8?`T4EM%H+V%DE!I@
M%O</DWQZ)6(DN^WYM/<>51(\O;1^<#44-2'IFC8W`JZ,YVA[5\:8=C;Q,2XF
M8J'$)N]K6L1F+$+W4:3"8:7,N/31)GVRAX7N5_3T(3%GO`#A;3W\`4W5"%T+
M-PCS!)*256P*&2X_$B`<Y>,OR>]Q&)&\[Z\Q\DA<]=GDGCZ$++7M*8R-Q"*]
M/W^B\N2[ZPH2(>-;@<,33IH&5VL>HV1J7J?H0;56UH?`!:7DI%_H#=65Z5I*
M+HVXL=M3"%`[R\RIV::T$LM-Y?7,YZ4&V68VK@L`&1;M+X2]Y5@Z3Y!]4HM1
M<"M.?8`7@FU8\LY]RQVIZ-884_]M2<-'.*N3FPM$R#[`U?WD*X],U*>8AC)+
MV:/0DO"A<HT3^[\3]L6M]R$7=#9*\^UOCSWI'I^4]BH?[#@]E^:0\'=L7\0(
M831VH69&%/>;W2N']?<`9D#^FG#0D`M_\,^='/=^S-V!G'L9:`X&E2C9RM-.
MR3C\[.0D=X92'V)5/X'%E%MKSF(R_A@U32[6NT#8@`4AE%1OHBPQB7T%C%_2
ME>UJ_JF%[@=E]@S.?NM.4Q6OC_7$'0*7G0`G.4)PJ<W2T<YA:ULAA))!H&KB
M-/:T;O!@^HSVQ4ZKCF\)3AJ[D;RM$RP0L7.%!T!NL@=42A%7U5FY@USS;EBL
MIO%^2LO'J5[4=3X<O3ZTJ3&V\X=-8_OAYBMF_%/"THL1\V[/.X!1=B<7U<&O
M2BDBE;::,)BP3H',U-/AS]ML,C586#ML-@56O/IWR1VIG5GD!`AZ^S!B,-D*
M/>I_LT*TSOLA9`C9LE&11'</F3EG,D7<,>/:Z@`@,4M`5>&P37"WG,T<D+!.
M,9)8.YU5R#@U7^R8DXG7L^-/EH40+CB[W3;U`%7<\'*I\+M^8/1H]@]&<0D]
MTL8F>A:2V>.L((VEW3C^\$EBY#43Q!:<';"-%<$WP'WH[9R;O+_,](?IY*M\
MT.DSQ8^IKA#[H/G/!"<I\)BW&,GV(+C$<YUD4-2$$E._Z\@MZ]"E/^-UW:?6
M[@$G#PB?/L8&]X1CGBZ[_!XCF6%V:;3&D\V9WNST\@=0A(OG,W2F\\T(4SV5
MJM=78F8.,/%+MK`M[B)EY&B@)5;T9SA1'E?0+0$E7D"BH)0"!5,WI/7YJIE*
M4P:<RR:*PK3#)0%^5G9(T#1DB/?&J&@DS@>]I9SJ)(\U>P?^]<S*TTC,,]HJ
M;_L"?CCHIV^(:G*N*3TIP[B[FB]AH@`@7+R&[:?P.1+^[-R`S)NHK?KY#\9@
M=KX&/3F?%B<.PX]&4*'+?NR\P@9CQHMG(3+.H>W=?8=@ZA]Z\^:,817^\&@4
M>CA+.=H@"7^N$F_N8."G=@+-W+*LL"#)*VNDTD#W_JMN<9_=5@P).FM5FU:Z
MR0^9J(SH*(S2`TIBHI<Q[563Z+GWA+3YDI[&O']&.&=^[$G!.W^"A!>;)&G5
MT/PIC4Y5G0OQSM69F2$8?\-=4$7(&1?YR>G[ECRZ4F(^M+59`7*(2;<+O1[X
MD%_^\7OX/K_P?82R0W0SO^7_5EW\.!8/*#$8!H%7)X8STNXQ*AMZ*5,4Y=PA
M^]X0)K]I<**A4=BY$6%!BVQ1GVB;.0I$13JNNPTZTDN>6I!D[!VV*7!9P>JW
M[7=)DJ&QZT/+';XB4AC?XFQ4:SL,U*)9:(5VWG2]GWY9$7-O4=K82BK.V6]5
M>_HI[,C$V0H?E,Y2#?"VJN3/9.=9,TAR8?_9(%A,7.?AVXT(\B(8W>=/,*><
MJPB5Q^5EF1=S]I1G(;YU>'_Z&>RK%U`EN-C3"3CXQ5_MHMY1U8RKDJB]YH8K
M,EO%U"1<\9PZXYOCI&F49^X)_G?5[$0?@$:,<J&5T;.<+.KSA+?BQ'ABFI@@
MZAO'%`KQ)\J%NHRXY^>T78?:P_X>'YRCPP@$(6,$'/&^L>)=!1IT6/JG2?F%
M#/[`^T3?Y7QNB0@FYKUV;ZDNA8.^'"?-,T1:A;@N-&;MQ_6W;!5[C\^$@3#B
M./QPY_(_!]R>NI2W*JLRIS3W/6M:[*NRE,4W++(R)BIIG9R2+[9GDH?&LS7U
MG"PF#SZVFE5&R,.(;D)7WLH_&YRIYN('&]X.*MA>8NXC*=;X>++!\CTR1CL_
M*DP\EHU$!8&3+Y#>#(4S+,.:A)4%V;@'"MSF)!4K=P3DZ?XUX+9+*T?M#BW$
MHYN9')7=);I`H:1?(.HRHIS*LZQ=&3\(@I5Z.OYR\*5IHGI4=#=I$W4I7:'4
M6V7(_8*(7GHB@.KG"#^@;;3`T.@2Y$1$RF+@H#SALYZ%.@149>D*U%X)A8%(
M=88(OK&X5WCSC$9#^"?^T^4'1T8I\ZA-4HW_EE2.L7\Y?%AGP)'T.2MS^?+<
M7:&TU4H=)MK!+>WCT;<OF0>1@^X(,T[WS/E'F\4I&/KX[$M)=#'GL&CV_*,%
MH=[[&R'\/Q8Z;3\##1WX;>D87H\,H8,M=2(:1R_5.=>S1^:=V.>X(HF73BF)
M6LZH[",,_VW1[HOW10@AEH;TK/;9/ZI>92T&AN(H<2CHQ(UNIE=G,LD##CI,
MTG6>3,EMXA:/!0%ZF#%TQ@JEB1UBUM)>L3>BC!"Q_IL+^&TLO/I?X^QDQI*G
MAH7$H91_3!:Q'$/F%8;\54`:4.ZRIR]."T>YF<)%<Y.FKD&KSX%*I,QK2"V;
MSY/9>015MY'M!^FC3':]9K(SK_]%H;7,B'!>W]/N-6F:44#Y*MM23:F@M-K\
M<I)?OK%#)*F,PQH/#,DUIG_3,AW4JSD;3-[`"$@M,;+E"JDA/JW.)K/&;6..
M6IA\#*PYQOF$Q[+Y&]+W%.;"\%$I;,407!)T:6EC`K[%LFD"I^P*[],*&SD)
MT&T77,Y#XA#)X[#4\+:O&?YUL]LM<INT9$H>:](_+Z[0=SX*6,.H>]G@E:5B
MZ&/Q_9D79HJG(WM)2<=U]4]M)SV*7'G248[GWG%AWQ$FX"(^B9.J0X#27S(@
M_9(T$4_-KHX!SVD$5K0WP%:L$C>_Z-MW\PH+2>QJ*'HWG'#SI"6R3.I4;H]P
M_"#^%6.6\.X[?\S:T493`&P!^HLA=.?=[<>U:8M/-CC8X/AR;_L.B"&L'^J`
MO2-,+4R21VXES)$'$V:H>R5K0'QNQUTZ_.LIN2ZS!/4OQH\C]_-<(X5;76CP
MT==_43'&HVH]T!):,1S=[@7;DW)\2>1_JN+)/]5]/*G@^P70P8ZD65"SJ@?O
M!+TUHD@1JN]SBIQ-7(WVB'0_F##3!E/*0)AD"1440-T\H?^G.TC(!84Q2*IS
ME+_</11,;YAMCI>`LTYGFK067'9T2[PI40R;D[$`G/R^J<8`(7`?'W.'&-6&
M$I'F#A4V7QY-BB)RZ?/KN)_(A@NXNR[-$!S%R'W\@,:,2S$%E7W&1Z@;'[<.
MXY"_`4,/#IN>UK=.G^/\(H5V-#X6?B0M71T+9CE,RP+4UTM%'M$\/W!H<"!E
M8VAO)SP_)SL_/BYIS6II<10%>,O,QWOL$3/M*82FJJ)TZVAA^P@D5"T7I$UW
M`OLR.A$-[':NJ'XX:;-LH*WO&XX"^+B%AEI\E4"33WG,>FKI66EK&(S%B]\X
M>G%7;=O?TF.4H)EIZG/WSTC]G:]T!=)6BAV0FTP?AP%PF;&+U%5]+6?'V:%P
MK1Z@=`YR$^H9S2.TE^R%AO@/OM&(XI5S5KC(U9RJ_A,N5,7N%'52S--?>/.%
M[(<8O-F_LA:T2V,4##-74X6)HJVA\!8@TTDFS"17*K5WC1+^R2?$.55&_J@H
M#QB]\1T>>7@@3#F6*7I$*1XGZ+K6(]@TIP;:BIRY9K70TM03-P\A0`S<H6TJ
M.I@&II.FF$06:6IL`]2[<$JZ>E-QO<;Y^F>)XRP6GE`-*?CUA1@R5<9*?(;:
M#X:W-D!"TK_)1;PR<_3AN/EB3B9&LW>;$"6AA`=/X\='XRZLM;>4S@J;:97C
M%]\QNL8<#O9`YH=BSU3(VW#3)44%M5T_K?]"S*Y;JCLQG9MP[$20\8Z\^L91
M,^I,[$L!5]++!,\&FK&2P.>XOQK]>3SXU3R3;NO!@8/3O)@'U+HI@]5L@_"1
M[S*/(Z'VL0(F1?U_-&>-V6@HATQB$.DE9Y&2^+PZ"[F!H#R;G,K@CM,H8P"H
MI/9NHD\$[]'NXXU6\A\R_U:T]DXB"",.5:#<^54_@QZ<<JG(^I<E)`<ZCB`V
MNBGDQ4WM`M[9P'K?\W<Q:RT$_N>]4?#M<\,$00*`[L[PD!J4N#`'424S=X?1
M*V67&"C](*>3<X;J=;>0+9-X?OO09,0:I2HM2B"!(X]YPCDZFKH[V<SSV-C9
MFG2\3>=3"0<`@)*PE.QXO6Q))WAH.AVS\Q?NG;1KV#D]-@23,@F?-!)X/N`W
MI:,Z%Q7+*1N7/<!1-"QF>B=$Y>&=!)+34WP`M;8[KUJ5YJ9GX$;9?5D]]PG-
MLP*"_ZMC35HE^(,G+US[FO;U-U0`SU.25W5[GN#*\CLB`?$U_P;(":;;=#!1
M9S]AN(__#TAP`_!J+844<S#I46<5@*BZI6?Q$HIC*-'*8R]^SPT4(CD`7-.F
MK-KKYSH=M<$\W+WX0'V&8@=91F[<*4\W62WC1<)UURP(T(FZBY@D2D"]V(4O
M.;^Y-;^"793Z4%2N?P?*GY&4#O;E>2SB\Z'VY+XQ@NPILCRMAWWBVS6(.Z9V
M>N[>>%#OO/5Q2R&\"T:?9KHTJ%'O>D@*N&J0>M,8EI*=;-;>"MA0(D\ZX5YF
M-7M@<-(F#,EZRDC3I"+2YM-DTPS8B90(9F>8<PT=*#GIOM;75.`[-B#-O;$G
M^YPE;XZV"M=X-N3BUG8GW<]V9%WZEL1>(SV]^S][&0\:5S<2I"A2D>"&T)&#
M3R$CN@,;#-T/F+1.SN=A[E9^WK`/I@3-!%ECH1OA_7&)[;X.@G2D?@#-I%F5
MIYL.XP>=`O0K$OW6I=V)JP_9V\8O:?-(+B3:-!EVAUR+@Z[LRS_PH%%/1AA<
MDQZ@>^,N,<EXDTF2+2>PQWJ,3M_P<;0N/0=CO'D"?BQ-$ZYO\:&%(%SP*CJ'
M6P@"/P)@/EXJ5TMIIDF\/-$$WB$53&<.D#GGB=QHCN6G?WN#SDNW/R\\HH1F
M`$PD#J?!N+&/2QSH]G*',"9"$)DZBE&'KP]OD1/2:TXZ%FZJ`T9-EC$G>W6,
MNN#YL'6L1.4QWIP3J`MBM/_%8A!1.2"<'$L;?BE5^#V2^<^U`I/`GD.\OH30
MFQPO[\!.QTC[S>7*".NH%?>XS$&EVM7?7/B.S][WFLOG0SI_=/8'(T^)DX7G
M7U5#O*LY3VWPY$;"YDI:L[.-V>X']"]%DG\BD\?N#2HVREPD1":"[]U0A194
MVU>_498=S/MAQ44?97PK%%FCM:+B\W=0[T+EWVE_V#56A^X`.<R[>$)Q>WJQ
M>$*:#@PB#'?,XB`^=Q0B'%NTHZXBUGQIOX%NY91ES8NQ:,;:W5B'A11#H6.5
M1JFRKBE3P[F]O1MCG]DX-`>LGXRX`<&(>3_1\1P_%,+RQ<C_4"L1O0A8546`
M/X1+2LMGMQ3NQ1<19X4FAVC9!LTRCI(\T^HZ'7*N!H\2D(#);"M"L"F*]#^3
MY,^A!)-2;>9BGOEZ&KV"<:@M#`R#IA'7=](A,*!VB_"5Q;W:/VN^^9M.@?##
M7<S$)E8K!H9$6JD\!LH$K8&&4+1),18#;8]A,K:_D8X%@:_>S`C(X98)00QC
M2+%P3+`N_Q/Z8&-P"N/7%=;74=(XJD(R@`Z^)@HEUQ]\DJ?_;19&DK\?C3Z9
MQKIN;.95L'V70)IB=B3-.)>.1Y<T,BI=Z`@`U!M<7RQQM@1)D''G)5^/X2QJ
ME2\\TX4\&>P8AXLFI>6LU<%Q:1NRAWLD>XF+9*NMB0J#:OH@-M'&5K4^[A3@
M;\AP]^++W4?5(KBRA#92J/J&HQB#N/F0%".)R5KHM3L]\/@+I)*4NYRHMY*.
M#&W.V!!Y9>F='PFY@]1D>N"PY%+Q.R#$:-OXU&##=%`E^;E/8(QH;PQ6*1S$
MFMD((`(T2>R!#?_7_PGMMTA:PXQ<H;IIJ&8&8\^(+&EN9=5C-E?Q(K91!Y$*
MA+KRZHIS=+77I/-N,$'J4X<&GW3FBFZU(->]A#HF1OECK4M/`>H*0>O0@#N*
MRL]3]2@;L1CTY$#+)[2_LO]!D=)X,LH\_.EVI^BE8G?F^0?'75QAP%?$F<'8
M78XTHPXK!)K2-K\H*M+#.RI0D1BG64-3**@TE10^UXZC'W^Y%3"Z/MR;UMV=
MGTD3ZWO%1HPD[B-L6##@(0LL'!02_7LG^D+Q@?*H)$-Q^BN?OO:NL!1*!/N;
MJZX)^+8C]`WF@*(`8RBLD.O*V,N\[=,9?RO])]K"+#U4*]$=E[4@PUD)6\@&
MI-<U,(R@6.PIJ',`N0HO4WSFB?2!VY,YEWKAYM,_G]0I:+H_Q!AZ?A.G`[<Z
M!-2^0T6%)20.LQ?'(GLDPCK2\H.<1E+O>!5F'F3H]3>U7)P3VQEK%7U!`C0<
M1)9+Z87I3]O`B;J&674M7#ZGSL.`%C?E9TW>?B9_1+<+-RB1[SW0R(D#2#-J
M(!Z.SX4TTLIVW$#S>*9=[HUB\#`0T3)R#]M5+"B*&5C(8=SS@8=[)T+YP0QR
M`"IY"+!EUW#+:?G.D*1N.>=#>.=2,I!K*Z=84DCK/*%TKDP)[6).>EDUFC$G
M)(/?\BL)QQ#/!HOO=DI9\,QA$3K)IX!_#OV/F-7*]DC^D[L*>9_[B/79W;!!
M$:<Y,YY1D",QCK,`>-OSJ>JU0>\%!+]KJ.4%CLQ=!VE:]9J,4:B46@58A/\[
MGG+?62%]FW)OJ3VM2:??YC8Q36=&/9:"`<(\R31FM`5`JZ:OII1%JL9S@4DK
M%P^.LED8<?^F*@LS;YJBZS'B$HX5CBXPWMITEZ+F3K8V\$CMNZ\V-Y^6=6T1
M_S5H22J@)<M%E(HT5`2J&]K9$RNGV:0`G9QU[+1N#9)DF,\^5M^7F"A>^/];
M8,=JS&6])UQEC(A&3`W$&S/HTPM4+Y%U=.CH_X'&Q(R>#Q0M53-1_^A@F-&(
M9X$Q9H3)QKUJ,Z*M:&%<DD@CDH*S&:R1"S3"-6=FAQ0@J-A'+A9X[D'[BO[,
MPO+5QVG:R;LY8RCI(>^EK%<2=IDGWIC'-A#MVA@_)8V+/(-LRO2EXD]8G"%5
MXRUB=*DBXI7PE,'4TX'?$!L8/?@T%^%STIII+>%)$S2RWISF(#E37`X31CIH
MP9X4JH7O9;M.0M0U3+B!%D(X!I'H3S[^'A+NY,_=I&@XEQ^>,<,A%H7)*^UI
MNP&_#0#XN"?6`BM)R4!*++HPXMH.KKTRYQ/_L(%VYHEEK!/OZ?Q"R7/$I%&G
M]-JOP7$\P$196YN=O7AX]X:L[(>5I2)LM/B&!K?GZT3QURGPM2]XM0CR'3X#
M**<A?B&B('V/<2<9+)&\JI%O<*B*)CMT'1^7H2XG>8C(WCP:O"V5=C)LAL"`
M(EQ6&2I:;:^5;L<31@+:3R055<XX)[++[0#@C/=2RQ5Z:8H8.C\E\.4'YK8$
MZE\(@O2,OB0&J7-&NVQT$W4H^%`WY7Q]+S:3TT!`_-D1#`ZD]NA$[`*6:!*-
M\_F'1-E/#.)EPM)/*IC=&A2='!23<,0WY'HW^G@`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+V%D;6EN+W!L:6(O8VQA<W,N0VAE8VME
M<BYP:'``````````````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P-38R-C(@,3`U,34T,S,W,C<@,#(Q,#<R`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B`@("!D:64H(E1H92!F
M:6QE(&-L87-S+D-H96-K97(N<&AP(&ES('!A<G0@;V8@4&QE<VL@9&ES=')I
M8G5T:6]N+B!)="!C86YN;W0@8F4@<G5N(&]U='-I9&4@;V8@4&QE<VL@96YV
M:7)O;FUE;G0N7&XB*3L*("`@(%]?<&QE<VM?;&]A9&5R7W!R86=M85]?*"="
M)RD["C\^"HS-#D`7_PQ`*UR=MTBUK4Z"67\OPY?1,;1V6=`(G82Q8"T;YY!0
M+SSZJ/7@K0!T=+LR;\/ZYS*`<'U?%6(N4O@(P(AJ=`B+Z29^U/J!H=)][#*%
M2IA!8?;W@#/$'+R-Z0%L_!RA+RTY/Z6-=OFOA3O`5_8;6FHG;M9^'I;K<@SU
M>`*K=R4IF,@(5Y-LAQGU47,JE&0R%T:58TK,AOH\@^QLJEF_.>MOL7]%?)#%
M-FL9Y23N%*Z82HW=BC9:Q0K]AK*OH;X'J!\#R;-`[-'W&Y(9GMY)O0N#WWVZ
M.A?/P4?VK"R'[#`)U%:-.6Q^Q#]<&>AP@2L$\=64IVZD91!LRW(P74T"14-4
M:W\M#1N]#2&&6S/`:#SQOD<JI6WY)=9.-4JM9(]$4OF<M!%,-N43TD">U.A3
MU\LZW?K=3:Y-A.E'%@7&X3?[;<%FR)CF?F*`BTCW$GQ3+D`E2YAO<.7*5??X
M\@8E9(=^>VPH)YIXY(7+9A/_P8?&[^%LY0K,]NIL7@2C6VB3)IY")!U.@MQ)
MO/?(V#@D*&C<WX4GXZM^Z41'J6,2Z3LPK-RQYB`(&7"6D9Q:EHU"P)(V(3?A
M,WO82)OB7AS=N>Q:Y.0CBJ[1GUY8]@J0Q!V<2="(S.@F7!ZG/O*5%+8HB9YT
M8IGB\=!1UL'I[$/0C).6.='V)#:^WUP6V\C'E@9.'<C3O/R@<&-<<K`GU8)Y
M5,*'LL^*C5<I?0F_\8:B)K&L3@1835%*O;,IIW)@DC@\UC(FC.S(X:8BP^(Z
M#JP^_=F(9BT[G3/@:K?".AN@$S#D32.X!`8,\?AMB#!XT`!TO3G`A^:AHE2Y
M0/8^?Q.P'X<:.:&#KY/@AK)Q.>V2@#^CT%:'G->O#$]2^T,"D1!-%`]*O`Q_
MR9FL!-KV'$<*Q]V?3M[V_NA@H$N4&A,0%I\M1&0>>5HQ]_>:H;%+/PM;C[7O
ML+5B$WCT]&,?6MS25=E06=<9[K2W=E+EXVZ*3H^RXX!<->#J,-JF>.C^:S17
M&TH>.?QHP)'.5(L&#G':ZH<3JO9Z)R>E5AM8@KA8,]1^,,V3P26/ETX%SK:K
M*&3)OD*VQD^)VT&IHL[CHW[Y<#"=/"S@;*T_2FH43(.6<2+Z)8#!Y4N:^*$>
MK+]WEI9,W@IDYSH/!P,#%.H"(,\T&3PV0*FJ#4;\)4=S,%VU>`L2,&];IZ[Z
MV->-17V;^S2XBUA-*XH++17,M#:5`)+.'/K2MI;$MJ!SE?;)267G1F76O'KT
M#+SSB!P(G$;W^V`*L585"O;(0\?R/VUD%;L$UR[;]GB^MD^,95CD&]]5_1X3
ME&+6"Z*\HBJJ!W$%*(;J_<0>3H1;1O57OW9@E$4C^EGX"\OP`=O'P-[WW#B@
M`GSI4H4H"?-3>=ECR?5EDD=5A)1R,`C*+.YHMOQPU;)BK2S7\OL$S9_3U;<V
MDW8#;CW\$K8T!P-DOO0W627.`#V/(#";=B.O0%9B+4IM*5X4)0E_NR!TU/^%
M+0-Z."[0+'6(T('[P]5EE\M9%PNLS,%/%ZCBQ&L?X6`0D#:5MK@3^MP,XEJ8
M(<Q0S:YS`=HYI;OX>#,$T^\@[O%<_V3ZWOX)^]67O"&"^899HH#5@"V,2F!3
M\X$1W==W^ET)4,O#LXOX$RXA8SOYOAYYGFYL79*XRO=3SO[4!1BQA>7K)+E!
M1FG,NPZZC\BK^4>*Q7#_B4+7Z-_*(3@I\]4:;7C0H^4PW*P\?"MRD5]R6^J)
M!W'@OG'=#$SLV3X!9`\&YEQ*6W[R>^SNR/O=9B#)NXOF*15W@&/Y19&\<Z$S
M88!_QWQ:7Q][IYMMNQ\BZJ$(&E^E7M4X3=$QZ$F-#@EV%!D.@5#OW$3NDUCJ
MXJ0;S%E/%P$L.\WIWB8U%%SGJ0RFG!UQB#Z3D.H"=)HNL'^?HDA7*S$X_'%S
MXD-`EJ]3&]?!@!WX\%2!_9(!(=@I5`N3;D(63J3]I:9AI%[VLAV\<]HW+5:S
MSN=']N?D,."XX$@14K1_-_/,:<\#"I*O5M%^&XV7]B?0U(-)DN+)8+1@+GO5
M[$UX1R1<`0C80%9%(J-B1#%U?[?YF5C7Z7'ZAR_$4=1VUGC8*/!$D/4Q362\
M6,WU"-8^&"H*!MI=;8/I_^:!:-B!5;5)I`(/0,NQHF2EN4$!S2F3K#RYO!Q9
M@W(V2%`2Q-'-W1^2'!CY/N>,86^?9`MP.X>X?'R9AP7#ATNJS?4Q)GIA^=)X
M,X#`CTW^9***#\E=\:O%9KI>YS3J$WGEM)T?K6-@J(>3L'SPO^"+4D`Z,RB9
MN@E"VL,UFZ<<'N;50X4L[7T_1.<R;B?JMY96;-WG0.-U7\O[^FI1RMD66_M+
M@*!27S!AZBP>?D4=)W(-W:]XT`NTJJ8G4O?F@:^B_R8+\%HO6Z0J.P6U-M6'
MY7CPB6I/O#7D7T2<^1PX[L\['E>9,NI3M8[PA+_G*L`UO6^?-33V8C`3Z:P/
MI'B]&.U[QF65E2S:?*NE7BX%22(]62#>.^N'.W7Q8FJ-0H*9,,*@<%P!LF_L
M/I2RV:!^/R@NMMG?'30R'.@(10A(WEV?("O93HJS]$&8")>YYDR@C>-*T&-X
M,J$,'Q_3)7S\65[<.V_67/C!^E@Y%&S\?WAN9RCGI?1;*BT10XLFIM!/\5K7
M6MEK)^@A8-]W?*406,'7M^1D<DZSJ;ASZ-19G&]&:5G(/$N;GN2:_$XYO5)"
MKO$5DXM$S33Y^6^CF`*.4"8&#L9A*5)H?Z'BB(CE22)4-?K@DJ0+%5<STI$)
M4F6EB)NL`Y]UJJ&=M@8;%7@>/56+*NC\VR.>*$B8?8=#&GE55=O7([9$^4^%
M89M3-C>37/JG@OXMMB<HQ;PLCK_:\74T1*PT@`7L9=J+,+8AP+*P@99'E=5I
M)X!1?Y@$M6UVD(^=<5^747QPLA].74&I"HM>6M\,N`2(=_/^/M(5;HEK$[BV
MND!S\@YB(Z#I!83W^TT>@:E4GL=K@)\7'*W<AB4@G@@?^96K#PG@S!OZG(-K
M2')VK($M)!!NN"A:>@T7F5%-H+AC)0A?XS<_?(1X<D=<S@"*3[P&<QQKL@8\
MP#W3P9/Y"H+V0L$95:[89H%N5O0+A&\M=#$(X^RI?XS?:CW/<PYHB9,"2AX=
ME="(F[#P5SK5L;Y?]M"8J'[GO:6HE3P1NSYE3V!X.$@F#?(L6=OEN.)):69$
MMWBGKU=G5<.Q3V"J$!&O6R?OHWS(WMI<=YQA76$9'8C0ZF7#[GC#_O+0UJ!7
MSY[MPH4MP>Y"3#"(&S`8MN2:X73=A!>:H4)D%3:JT.559AN1ZM0(U7W7X8*)
MZNK$OGX)21Q7<3`W+'ET6)3_0RFJKQMWE#4A..BD8#?4NU9]W4']Y2H(Q$!4
MSY.9T`XV=%YLIX5\-+"L9PUGUV'"P:4X]CRW#!Q*O,Q0`#%]W]PH)`JR0#V'
M\!D"H,W.$Q,.Y'$J+6,SP6MD#%V0$U&%LZ+HY.SHDT5P:+1KK4!:D'>LH(ZL
MZ7D0=WF8WH+HSO0G_^9I6LTJ54RK7W16/G`65\#5)7/X_`B`BRH*'7+;?[-9
M1(S%6S_CI]4CDX@'1'S[PUY!O@)CHGE'BM-O9+EH@'JM3LC9`>&LSOXDZ=XG
MI*Y'O,`HTHA'4<H^W^I-V/S0"#/Y'[.G]]C#3C)(\;4T->0M.WZA70_-CPL)
MY@0MDTTQQ\.6!C1FFX\486L)7D5-K02/R1?M;_RX:UY.71UUKKN^CCRD8B;#
M%?;6%I&EL?>7Q[L-)J1D"-'/V[3HNWOY^P$%O&9%2\-S^Y[WOA*YI29I]@F8
MC@8EW!RY/[L5P^EA6;-?)5=!Y3?OS4^,"E1M]VD<I%.+CKA;$17ZOIH/@'X"
M3F55MJJLND5^X(KJ$(:/'6!$MKWCC0>AC=WVV0R2^K-8$X?PWC&:%-)HDL[7
MNN_HX:?$NOFT:K#+"`SWWP'P>V#BZ@HB(DL&#V6_X-ZN2>>V0^SG-/.9AD1_
M5DJ+?NK>!>'1B#]W13&P1$%2?^^`,J'\V'-^0'@-63HHOE1[W?/T?OWB]M5T
ME((GQ4S/[?3O7EWT'5QVH9\;W(J-H"LIQN]M#1K0986?IXQC,C)54<RPZS2L
MX$I"LRG8;;Q/$/%@P2EXFR+:-@JW_1?-9<O7G;P@)/EO`XQY`@G#,#9887QJ
MVX@-QB()_`-H<BHC;9R1+K?Q"EWMK?M<`?W47&[T93A6C-5V9L7$_$%&N.^<
ML-Y,LN(?G3PCY,W$8<.OD%4-,VQ7T]A.F9NG$)A_M:593B0;&-%FHY;=$^AL
MI$2;U8',-Z4)506I4\0ED!/=(]B\/?PWG^^**I>^'+AI1-8R,?O-1_>F0HF"
MU?3O]4.4=2(I+Q.F4$,&]<OK&JAQG28[<89S>X+)R\2/H(=KKJ=]+A`:`L[9
M[[[F[X:,RN2K9)K*WPY00QK[1#YU2XO='=BE;!U3`#S?%\:.@9!XRA("'@_(
M"$>'_EL`N_+3;AHHVI&`Q[1XBCGJ$'Y[>FMO-9<IS]K+DP`0V9ON=ZT*X-.@
M$C=AM)_SL-"<EC,!EV8.["8>T45>&:U,UZ..%7Q$O2!LNLD,-5QKI79^O2MV
M?NV%,3>V-K78^ZJTEI30<M*W6Z)]Q42:4H>MYBUMN7NEF'"0WV':XVEUUKOP
MIT0]90LI,A:A?$]#)B+=&@\//ST:2G0Y<HOQ>DG>K=>D"BJ6PI]DFS\DS*&,
MHO-/L`0)]5:$$4@D;VVUI&1?XR8E>G4V*#UMM,B)<(-1GK.I]7MW7(9>#VG!
MS7(@6E`&I@/M`7$&*(N#[T6)A_Y(TOV)M?,B!:07S1)RHG';UP`!.7D`QVZ%
M$)7>-ST+D(Z6(8@%-6*K#R[,.,ECJ.1Z0!:35!M<&@%>XRX6W!\^;R+)*X[/
MAE$`,+$[UJD%0Q!>+WAO%,(S9UKVK3Y0%Z?OG,:LU5H1%8-.Z]>%\X?7$=64
MLT9A2;,O,/8R/QUKA\:IBO&3A8"?9'/HTPT/+GSIB1ZHY'TUZHJF^_6[3<*Q
M@R-(-%^TQG-N7T**I[O`7[%YQRQ62(TR4+M=[([5:(8YZ"U37\LG-/%SJNN#
MU',@^3)OX4Y-KPKC<?31<_PK!#[Y2)UX[L"F!_>/^".($R0>3-:^3H#>@1ZP
M68EPK<BW^VQ>9,CH9>3^FDFE,QOHU_A`X"].)`L74)WB&;0<\)WQ.V4,-.9J
M'7FOV*BJ,H00="$M!_$YM@)B]Q+2Q9)P%!RMF#)K)U0N*:0VO*6H-NR5T-R2
M"U49@:0E]NPI]A[&\"HUEHHY!-T/QA.?C6M<C["V"!W*C/V45<0W`PR9A<O)
MSGY4K'PGVCK,ZA`LQI9G[JE-T1\7!^:)L=:,\9@$&"RQH'&8*M+V^*$9?9']
M<].,ANG\M-Z5`(6_6S;'9,B?4\5Y(XW$SNOW'U8H@79TJ7#*\1&[02+3@:%?
MWRHU__E">']^M?K$*E?H,2R'<+N=%&79T^4`V*]/)0OUV*UOX8H8QW,=>;(#
MX16L"<K_6,5[(3?/9R_##HBL[%WX-DX\8[CZ1'.(1@:<)Q`>BG,#VW_E<F*E
MNS<QD::+;`%&8*VV38)QN+]6C#2,.9LJ*54XCAC:/;8`'(XN_DKE:'8Z[:!@
MP.]:]A9?PFWP+U\XPY']8.G^8,3,KC;;L^JOP)DDO`QH2ZN"$&BP6>T%T@"A
MQNH$<;I0=^VRR$`B,,X^X2*03$"E.%WS50@9N>HQG8[X<G?%R>IM?]'NV1=F
M+``[S@^$34XHKRI'^#U]@J4A^W`>GKA4`/V&(U/4^HZ+OXVK]%98S"XY1[$0
M2K]XT7!&+PA\C>/148F!XC6:X$Z[T_^N:/22!R`83K,T(XYH;OM>,.RIA.*N
MN^Z_;U\5*0S!].8-=[.FR=S0`%GF_\8Z>0H9KE)FD@*?V0LLA6@F\3+S9,[V
M4@C`^'92PW".^.*#XN1:G(2@!K)Q*C5DIK$F6`U($)8-?(#_0?-3K6,"R$`I
M%I4BD3IHLVWEVZ.9KR0O"(6#]=?BL;[;`@=$/@WSF#S`!,VA^\-JH4(Q"IFE
M!+:KU$B*DSJ?:L$?K\5@R3/*=V<'Z,H$H0>"TGL/\M\;XD_NQ6^>Q+W300\Z
M0_I>D?9TRGL!!INTUYU`C<['VN'?/Y>8J6,S+:P/($6]1?WKP*#IPO,"7.;S
MJUN>M*AMZ0!"TO<QI6AN7._:[(BI#>+]@ZGE?YB5*3_=F'V?HM,"MY:Z`J#U
M=,7Q_M#,NVA2^/#ICPR(7R1L.U*&`/A+PP^8=$\T-J40_]?:'?(1Q?XK/%;P
MF`=DYJ=IEGH4GD"F8'254.Y84U8S,;DZ^S>6"'N'/5VDGG/R1/#@_1,OVT:\
M9*6>V6SU\9,M[E$^Y-FZV`&S#BAF-#O?TU=RUD=K/G+%J!*O$)-RV8Z'-TVP
M>!+R<\W.F20FR8PG*0>/@&EP70:#,F<-DQS6NJN]WL6*0P$1?$]<%\V*E-FW
M4[U"`!V(75?]*ZD-`E9161K7-YKY3],I(IHQ,05E&=7`SC5M^&C`'9=2EVK4
M*G4*^5$[+?2=UU(^D)JX#$KNJJKA`>)F5\K"'4HL[@!*"T]AO(6?<M?9CV.'
M7T![`6IZC=0U#7V,5W359G&[IBX>.'I^.^LQ<IE7_@G]:<ETGA5QM<`;9PJB
M$9V?45W3C.C:#WJ0,K7X<L&%Q\(W\KT-.[;=LW0X@$[0*H'&@CYW<LN#-;-+
M0M5(<9E=>RMOWP[D</B(8M_%Y2KVL`=<]XU*19@XD!M-2FG.\T4QN!L!Z$L4
MP9!?N9TUFO/]3]&"HB+2;^`']'X:@Y<*K*(73WYR8&^_+`#V'B>`'JN%#RU[
MA1`:-_ZJP66:7H`N^):3M2,UUK@Z/6'<&7@E"WN<LVM/C;(=AJ[W:Y'HG9Y(
MW/V,3>:Y..XOY4:P0)$HQ'8F\'M_HUOIDX.I9R(]EE9GD=P9]A1/_#Q],[&[
M+?UW/%+1R*["%U%#]SS(J$0B14_5&:BMB<$692Y.#N-VJH7;3X_50QN`!8(%
M+#>1D0+*&O(SK[R`60XN+^>(VA#*!@6"]5\F&,WP=PQY1W/^Z*6<&&B8YER_
M$?WO\6`-7DJ1QF!#)D=GAHTJJZ.NCN1S0ZWM6!],=D]]6A!='Y@_\#PDA7ZI
M8)YV61"S)19K$H<ES,J_C=2Z9]:"52ZIB*1:`N^/_QAY#__BA:"%<.=Q^=5W
M1-/A4]$N^.\7,URTSQAPQ>=DSMV+*`P_!/D#H[,@"J9C<.L6^_P8^QOE)`>/
MM!5`/_6KC7Z,9_I-#2/=09_HK?;`K"URA#JM=$3P8ZB!FJ8WM,S0J4Y>Q*=F
MK!3,LUS52:RW!LB2EM9/D(</<NX4J>B^]-XR5"N8^<`S`]SKH+;X&=G"CE;N
M:H89_#QF<!X-Q`&?9L0=ICK56K&<^"]0);/ZX_Y[$38H!XZE&;04DWZU8MR^
M_INGP1]QV>)'ZE?9*A'LX18*`.!-]I&WOA7\7NF]TE[?1;KP>[%^OOD-L[]%
M+TJ*<+[PLBRJ?0PJ-PVO:$,=@0H/PXPE2.Z3UC6%A+2*\@+^*[+=S=C[9[8V
M#?KK*-^ANP,S.6I_>2UP%?,T[%EVTER(9V$,'<SB-[OO-0;#-FB5FE(OWJU4
MTX7B&VG8X[6C$"$",I"$CY]-_-(>,#CA;%-!J!7;&(;>2A)YG&!2K\^#;/;`
MI[K\Y3*&/[^`!0W,E#"J.*MUM-Z[RG`>'9.@^H3I`OGW#']EISC3MQ5-@;D>
M\3`[2+F_B%ABHU5B:I,6:7<.'Q+,1RE<AJCAO&4#I]C5+-W"`HN8EOE)[YQ:
ME^WQK,QOEH),_)_*$=YNJEQKNY;G%L"<%UAB<?<;*DQX)?QVSK(IV,!OZIUF
M!#:Y;W*O6U3K'`*RYY7CKCORM2:RRW4+73"R!B'#49Y7.@]5@/J&OO_:>^*H
M"&<DG*7)R5LOW@)YI/U^DF."?>V'TDO?1,N*.S0*<\C>PSL9*-M4R`#-4:`!
MGFHM5@]\].N8:(Y0D/!FF.J(:L&T.;X(HAY;[_-)"1G[<GPOH[8YYC%4W+]T
MWAW$-S)=D;BG.MT8W4<FL].GY`X,C7FG6K?LNC:J..7YK\?@#Q56-L^)$G'/
M7;C];!<899TR2@*@B][O;0!&'[X*=$9"<@0&V!TE\S1"1:2MWPUI-0'?:#F]
MH%VB!>AY`K#W%B#M#4@'7@QQ>33/3V\3K%E&T'$CNQIU*OGKC+V#VL%LR;U_
MLB^T2'!OAN5M1'?(2BY9)"+//5NRCW6)E.#T6;JBUM7Q[.)N.5%MMV1\_YH-
M#3V=2@B*R9-W%_XL.6Y-%0"$B5*JK3$)WRD?5FWP"(IL83'CRK@B=>VC)*)L
M&WN?,HW"Z#HQX`<U`.NVAXL/;FH!<L0CEOED<3;P&)4&0+4!"[RI4KH3H0D.
ML,*N(D#,<26>RYZIKL]5P=]V^EB0P!<WXYYWF7SOEBQOZ$&J19"6'$F[;>)X
M2IQ+!K*?B\[5>Z9JSK!_HYK72^"4MW!,+5`7B7FL)+"+("(#U_O95\-U&CDY
MZ%!9`E3W#()&RX#U7RXQ4O-\%BD6YBO:J&L+S0B3%U"[=%.$1(["3FP,UO6I
M[_\&[9#2Q=4AW]GKB,?#4OS?"8<U*X^L=:27G1&/B&LLU.VFC+*<JLLH%^(N
MI,)^*+1^:NO<#XHT_+'"#77-;&@G4F?+P=9DX08J;$D8HJO1S)_I-MN/Q:NW
MFP-%8P&0BWLVS@7X7OAR>;`U(6*N$.%`7P*KT!Q,6A"B?0M-L^UAH`5',KX8
M#<U>"D2_XU'^^5+-Y<[EVX)8$P1)T=+1SQ3JM3K@)`[XN%JCWLFR5HCJD,;F
ME>X&EWKWX6?:I6+4FD;[8.]904Z2!2$K-(X341T^56^@MS.WD7S>Z(KB562+
MG^[%:EJACRHS]]"2.=\H/QJ=XA@&N]9-H`N5T0`!V@W&TK63\48\B:!>:'E!
M-P:_)';XZ=#=\&#:=B%Y["?6EW%^&F_'2PHAS%K)SD#&6+YWXWT-8]2)3-H0
M5'S^,^7:GD3WB?R;Z:]L%>4J(V2E7(_'_:77[#9.\8+XGB!)#5NH"Z&Z_.H<
M1A^I<YHXJCDKA8E$0(,>$[O3LL-I_GJSWI[]!C*$VS]R/"IZ^WH7`T_%TZW$
MV2LLG.N@54XM4K`Y<.(`RGRZ[K&/=NXM=XV,6LS!0*(,\!%<AZ>ZFM\++4U?
M5VXR>`O^3]5@A`\<;4)"A?!;4,A0XM)1:)&'6')P5"/DLDJ8Z-&\">RE5*.(
M<(Q/WB+O#JB`!3:_K>4X?.HAU4>5>@\2:U1C"R2(O6:"=J*LO9O/!-J4*AW$
M:KB^>8R"G]>5,AWX"W/^7!O1'%_D.YQ;!-(2M3"%T(:F<55)IEMY9M#LP+*6
MF7/JD6'<6;"E`K<,E,CU_.#.)"L/,V#UF>N>L(LQOE)8BPNPRH+Q];<RML`]
M>#X+`=O>"$^4"J<NBDL,[R8^\`4AI]0[X0<+,U$.FUVY%GQ'3:=^<ZT#,)WB
M9Y\]\HIF]A_+?)G+'S*#3U@732+Z@;#$:*J`>R+>KGX)**\B1MZ&W_EOGIA0
MA=Z`V$[9ML1[E3N#%QG!&>`5N)ZN+Q^Y"-'W(?8R-P.S$K,X?+KDAX/6F"=)
MQ=LK\:F-90*9]SI@7`.(QH:F1<`ST%\.7*A4+1DB+T`CL=F&*,R[+FD0#V!1
M(XUV_UO.XQ-RRX]R.3EZR_L8Q@Q]&;=(G"AKMJA#B0*A_L'N,VS6CM_847W/
M5Q_5]K76M=(ZC4C")9WHW`WR,@*C_*N7Z^20PZ-I%T5-Z!T$371`?-3V>/ZS
M&WA&8M\C3ZU*:Z]E.*-+_Z%(GO#O6"$X)*+D_EVBW-W#-F*V'<D4MNLL1*#9
M%QM\ZK\D#B->VK1IBGIRE,*!,^H6GZCK(!4NQ*_#FH(V.NF.I'P%##FMA4P-
M;\H,$97H!OGB4%8)+Q`VU=Y(1T'\NA=><5CR4*8`054+R[<M75N',%J\[G@<
M`20SDP&*(!>K5-PWKG]X99Z.ZC;%GK_45'Y.0S9_6M,H]C'L&E+O%C0YU!'0
M6JM3+*EYFO8KY!!#0.EEQNPB,F9)K"B<ZS]3OVB:;.([H1[4^\+T`,Z'\!'3
MZ39.`<`;7?D!3S(#L(J1'_!<2OF*/^8IO_<P@`C3IABWW*_,N\:4GV<;CPVO
MKCRU="2";&V!RO3G,4O(BFVI#;U9-=P4"3(]SXMY+7MB+@#VR=APD-SY:W)!
MM]/)=2-7E&-?TU+H4+,W[LD9:P%FZ<5NM$,[&/H$N"!+!&IM"[-RF2K"$[SV
M'_T1K!`FV4:D\#9_A[,=S;Y5&V<X'Z2$1S#"`3B8N5M!0$YDT`\$95YI%XXQ
MD()$G]FI/^[4(DPP#.-B6<!KLF2S"B<4Q,=V,\HR@@N5U,$2@_Y%VHN@MU'$
M(19ZBA\8Q>+M.?&&E>F*B3N<QS43)WW'FR)/9B)1[KX4-$O%-3`$V:<3#0!'
M!BN:@JZ*NS[%);-)!\8/EHNHBEAKDPDC/6/JP]Q!A1M+X>9'D!?.%/2D+FYC
M1*'HX%7!T3>/.^<PKJE&?;(U2)GXVB4N`=SX,7SP\[A8J%H(X>>SY9'M.WL3
MOH-A,[Y\7]"Z_&'WY"^5`E2=/^V&Z5+G`BB]MVJ7*'Y6S6SH-=":X?T@W5#U
M?LQ==?0L6E#$XTC!%44-K9H@I8S`6SC]C/D3]1&%Q]"9Y70?O!\HL1C\*&#6
MRAAM!JBOI54<<R`W4&!]@1V-+,1T%MP>ZK<8#IP<L.G8;LIFX'U+"M9*(A/X
MZ#NY_IQT<H@_CT3:R%?P935($-A9(6)!'X7KR*`<\X".<'I[-K-$,)6]%$EW
M6*+Q]B)3L%5BF?\=9[#X1/_S-/'"O)X%R0UCN!!'O+(O/5"9040@/N4O23K:
MQ1PI*,E<HG$*L=LC9JLTL?+K`?=+%51NRC)Z^LB0H%.\^[K:5%(?GD;7Q?S+
M;)@EMV_6DFVNH'VHQ+3XD[6%F@9T<UL98]B1:#[LU[5F/_IDI6\57B$70'GL
M^FOA_-'D#5ODN8PM4U8%@)>XGT(S,,TC;#O/:?"`:PW@D9_SN*@#64WXHWHF
M]AS6P>J!@#Q7*B"8$+>;NDT`=-70(9>?7.H7L]2C)\2ZB-!H@%5Q8@+?G]^B
MCBUU]=MV%!E8&27S\8CK!KO))FQ]Y"1SS3[K/IR1_2-EJUB;SO;C_Y%$8L6U
MFE&N0.*^M,1&YA-_J%5C>75P,<22`)_OHVE_9H.]NHUG<-1W`"T+COV+RL>J
MKC.3NSX44C0G&&!=Q:YP\_QS#?M3NT"+6A1B\]+O"N4SE%T4:=0PLRQW<)%<
M:>AJY2,4H9X4'L=M$41N3=2#JNM4?06TLE3%KQT,(R[J6/+GRBMWBRE#'W8>
M4CN;,`T0F@:S/*<(HNNL9ERZU]#%NW'11@Y!L2)WBG^?XN;[=X=`PUJXDV"Q
ML!DR1#+%]J?PP$EJK$@X+3&,4!O6Y!6MJY+NH"&C-">;T,3EDKN<TN?NCJ#(
MX;MC2E0*'6>8A%GRJN,NOC-4"Y+/=KE*]9NK4G%MQ'JH>S%W>AU=I#GVU\H.
M!\H">WD&`TB4;*+<6NX,#/V,ES'49BQ/5MD%H-FVDQN,&E5*)TL#@WSZS[V6
M1'KT;43?'SLX9ZXJ/W,N/3CX6C_MIHN)1'H\'^F6#&?R;=MZOHAD6!HZ//7=
MW;A&WC![*AG)J$>L^T!)FKDY3BW&I>%6)L9QH=!.X5-%YF`60GI>#Z9"#X>=
M8B?NE)#Q^0Q@CL+B(N.(CLJ_W-SU,UVES"%NRR`L$W+,R/#MF6?TF)8FSN*'
MSL#H7AU8PI@6`I?67@,D\"#GXN/FK6,&-)E'-HX=:CDGGQ$1)_#7Q.<9-:J,
MV[O+L=I%V'LM;AXUX!3CS1-BSIG/<9!$<2N.-C8!$^&9=)/<QG3=0;;%\VVQ
M20\<P@PC0<+^%<#J/T$"AFK/$\Z6C=R)S3Y4THEN/\+$./AR9!&6]UHN</,*
MTV7P@LA7:77\^BQJJ9^VS'.*X.>&!P?-VH?$&6E!TPT="6[4Y^=>#N%U0IUT
M41=0M[$7UXIH63&*-FV)KZF]F]AG9YIKZQ^`&DN[/="@%N,_8Z!<\"!:I\O7
M?'#MUR.OFCDLYOH+CD%)0Q!IG^#8/1)YJ@WU4B%&SF850-DU.3#KF<W#RDJR
M(7NQ'A%&&>)NO/@R])A^?E@"@Z$:7-%-4,4?V$QXR=&/-FAOZ/6J;\HH:S6M
ML,1E/`2=8S5QBR96LQ/L\,T=6MR@0>5P))4Z*R2*>FU$,+HUW'>S]U?$0@=P
M"B5%FE;1XUA/./ZA7%4/7(W]5IG+G!F^X3S9"]EU#[.Z\_`2T1RYY66"QV^,
MWGVMCM]<XUR[O<)4,@;2?$LRL/@Z]1,A`SXR2-Q3K<")U.@7NV+2]V(<]Q_'
MCV%N2^AI092#V,D3RZ=C/`FJZM(358F!Y^TK4A09N*SMYP//(V?"27]0?P'5
M\&TAO6\?-L!#-$6VQ`7,?HM&&?0>C''8J_3;8WI;B`(:->HJ,K+!20DZ(47_
MYLWD(8WIF2-A8TV!E";B(^HA<5.WF;,2@?TCMEE7W*P4CQNZ243Y^O-FB6S"
MFCG*=&X6$O(OFS)I!SF2J?@1A;*"+''P.)S<=L]A9\F/MPADV<;ZU$PDG4J[
M?O\"ARIZ@U2K`]T>LK]3>9=/"R*_KZJ]QKF:!@GKV-Q(=?]64(Z]F.V+"#2Z
MXU*.7;)%('JC3;62[K.6H5E#(YGT*EB\\>?0<`$_\=0XT=2M\`C(./9F`)""
M<NX67XI0R(^FFX<`_-S;?\(VQ"\Y5BMP<)%/UO9J$^PF":J-6NAOC:R@/I_<
MAJN%(C5-R=IS=G$92T;K.BO-2Z=Q8S;))MD4Y5EGI7^H,1;),X*4)!K(.=?5
M61+-.:%7%,%(3D?TK^6;F"%67V'N3W(WZ:<EG>[C;<'0D&D/6!J.#L^Q3E-S
M^/<\=)]VU9^`K[QW3:@QOS-1_3)PG/CE_`Q86LNI@6K:G/;BCI=Q.Y]=#N03
M&_Z+B=RJO&QR7&6OKE?A(-(1X"_1OYN'G3761U=B0B?3*O&>VT_D:E4<A[]E
M2M%IC*H(D&1^!V-L'&R*`=>4?H?,(DT%4:$-7O!VD%FCA9^'E<[@;J/MH@F*
MLT0&NN8U>";WDF'0Y$$8U6*=M<$LN00#;S;D1*,[C%WK5]\C/1/G@2!NB1ER
M8[:%23Q+''OE4><463:;0BP,K^IMJKEM%;N+]YZBE>\@B74=VHJYSA"Y":3(
M\`RF_*QRS9X`3FANT/>KQ4S10$#D#PN9R[^68M3`MV(=&ASWOHW30EN18PID
M#&XQ?3]T0#2/`C2;;+769N>-T"*$A$;,+^YRD1DJ#JTH\[I"A;:=W%_I;-H*
M.^<>I95/>2+T83)LEE^P15W"RR%2X!P\9,$]YG5[K*R1TN2$\XZFHMRJ\X]N
M8THR:GA!*+&(`:],>L>IPUC]3CS%";L,"<>8,';,?=]:R.)F"7_SQ-K$K0YB
M0>`Q&.EB58.44^Z(67W\A'/2/;&'W!G-(V@O>>%I#3&6BELBSC0UOVM=?0$J
MVK^)%_V=F^,?`9L4B1*B\T!GM&.S((/>79)L'[DJV]=)LYH#4<P+(7)G%&.Z
M!.,:'O+YTV;Z^`#EHO&;W7G0>3'O-(*U12VQ+;R]C>2N@].N6W1L:;-=),EG
M\$Z(VDSYGKZ@7(/C\N(.V&G-'56'4@PM;#!<=+%J/J"7%U=VFCE?L4$'<A,7
MCW[A>W./%,[>,Z$)"O@+2H6JVY2%D$_U)*M+6^,?)G3O!+X\E-=1^A46`NRP
M15PQ,`D%N(\/:VL4E1-!R@&[:1)Q2/W9S@[.L$WC$9AX>HJCHTC9\>HU61KH
MTOB>AYZ%E/Y,(3O05;@IET(N8M/0^,2>'X+!KM1U-SK#RC)VS1%;5H`["=-&
MEJ37]V[/_!95>QBO`G>E_C&T$X+(C%I,2GQ,F/")=,,).K@9V7:)OD,R2,@=
MZW\/M?NB*U#C,9$QG`/<[G09'6V74;^-B-3:4@Y\"(*@VY7%R[\AX@XUAYX+
M]TABJOUH]F.5)[=Q/RF[I^>U:946,I\;J]RK24?34>YW_X;?S.E*;>Z><!OF
M@'*Y`8IH-$GP@HVCW/F8%O+=+U+Y!7^X[,CU!!-?RO$,V^HY#3LD8YKXHQEW
M@0%JRX]FQ^X$^9J;VSX.'RA0-?(-\S2N1`OFUM,_^4PIT_R[OLS?S?#Q&\Z+
MAY9H!(O4@L96>.!A^]=B2/AC>C%2M%&JF5>BH'2PJU6_[6P=W!"&:**./Z?,
M[35W\3U6\4*M>?1(J;?5K9A1$/[OX3#7CY'W/P'**XMLF2;6&D(+EF@?&Z3:
M'8%/,:F4E#I.K5<'LL`0C8X2!?J3Q^-QMIX-:<F`XZ*CC30S$B\MIC?V0!9"
M033U6(]W%ON<M6G:BIF1O]!0:IMVO*?W!YJRO9G_F&D8?Z-NK:H0BX$?QZ34
M6=$H%A;.>)U4J+P'.Q76?8>"B9(_FX[S]>,6M.SR74#T$,]]D]XF^9K#9[D\
MTJOA"3QCR4E2F/)[-7%\S==,9M8J$[<=DS/<X44V!,.JZY#^?99I>L#]M6B9
MCTZ?Y=>]B1N8)56M=="W*DXMU.4;+(KT0'H`!4S0879W4%Q(R74,C=7K37F&
M6VC%T\ZUF:I:I6"0,V?^4573\FT!"30U(:YO2L#V$HY".#5``!C2JX<$A[7X
M@_>=X_9O=_]U6-"-`+M?^./I)Z:9PK*U"MJY<=N'I7R7\<KBE#>X-JT*%`_@
M':IR[]RUW5)A(B4ZB\$T5J!.ATO^XA9?_RBTMR.<%,1O2O97>AGO*=5'TT</
M[[,>`_A5XP?GV_-2-`@Z]6*^6SZN@X\9*+L)X3B[HA%A(5.L/D?ZUI_Z$;7$
M5[L*/A@92#FTC@MWO.>/*IRU.0D%J^_'H;09F7]G+T2:]>J,R",%YU,&+<X=
M#;8.FA@\E8OMLMM>K+9S5*9)_?BU)RV>AR`I_A5^^!7N"G]0`J80)C^,^ID#
M`;36V*;$L&>+GM0+R13ZR<R7"M2IWSV"]'\O$P$8NP?;H(.,;M:^MG'A,FM"
M'M$]U:(3`F@%BT=_JZT<BW"/I@*TB0ZSLKUFL=-_<SL4](>0[4UL=O6COR5[
M_';NXT1*,%!/6?#M"`%Y"A9M2PAO%@RMVKPG4^1[QL*R.DN`P#8V!5"P\=U&
M,/=U,F7[?BY#-`'N?X3>-C4;DXK3.@BB*#?B&1TF*$;O\+-^.?DKL`'F;[NX
MHF:?K1M+WY?!=J/*#]V'+\<AL!4>;2EC1_E/OWZ^!+69PVWK!2_&LVL'-9WP
M/G>X#F:Y.8CB_))B#3//0/>OKPYDQ!BBOKE1NNFI$5B8\J_AOL_^67$&/#$Y
M8?L^S9OTP]3DBNR$A>[MLQ7(2N1>.04S;FX*T;;Z9LZ5V1)6^)"%028!8%:+
ML#7=DE%`HE[SWH&;N1N^/.Y,I)MRP]>@K68<VK3\J4A15S,^PPQQS[]FEK*&
MH0YS-7[?H0P2TDUFW$"D_B3F*15?;;<A9"DR"NH?_=77C0"?][T'"L]T@CND
MF>8F[CH)&;9LN\)NB^[?L)!THK7`.#=#X*XUWQ()5B&4+$2+'^7EP6ED)JNV
MLROBYK96/CZJ1US91(OY7!FR`'"/$M28U#F)F6\'^G\UF`'P)]8:*,:>3C'H
M'X9;*U@2YB9FC`XWUPGJ3-]<RK.:1[6MD]L=6#06@[7[(]NY94\/FR?4T08C
M2WU+P,Q5(P/E#;Z7+SI%@5F]B>0P`Z@+#IN"+U56@#AZ&3QW*O6,.J"W/_/`
MFB`Q35VF11N_4+&J82:[T1_Z;_B]KL#--;X#T1B)5VR.CB`;Y.9"+&C-$\/W
M\=!3(,S[$74&/5Z_WZQR.2KDB04O$0XC]Y2`P;13'WU8PC>T>0!;4*#`.&[-
MMO/"6"'EP_I1&(P]?`'N5)(M\2"8"/8$Z$G2AM(R$5<I;#7-B]=^(K/6#&0"
MEK:!SYS:36)W`91?Y$BH46UVTOE]H<)Z8IFZ"D.1YN5M)R764OY(OHBUEL*T
MFPIJL5_Z9%BI4Z4O!FQ7#)5!@_QS@.WW=FA(^-H1^6XK++A<*5,%JB6`><BE
M^]_S4+Z7M!&NB,<*XJ;2\LA+58X)9TJW".KB\4EG1=X.3_O6EKT&D<JUL+TG
M5U+?E[4Z'WV0I)53%)V^#$&="4_T)HQ`Q<,#(G9Y).)I3Y.LXU42<X""-']1
M:=T/1P,4A?W?II2%_ETMJ<(+0L^E'#;=QY;J[63@8.!D$?2B-07TF*ECD4=K
M3SQ]Y'9?(_IAW*_?M7,2G:Z8,JFK^\.Y6-&%^WD^M'2ZUQ52F!@(0;<+G;%+
M3.7>A$KA!YQ-1*-:G&<<S*^DC9T?#AT?LB]A7/B[S4]*#N+905?,Z\8RDPON
MARK)37!K6CDP5;]*X-N,__19,](-MLU1S8VVCPGW70:N)-GH;W0<$)MU:8V_
M.>NK7,.4`PH6^3XV4>QHC';\W[F%8W?]S%1#0.5J=F`(9`52I8V6I:HO<;1$
M``BA4.=VXAH,"D!T;FO*^M`JFRI$D8I3(#3;^?V=S4FUC?;3_K*>-C)%0:S3
M)W(*VC4J?T3GOC8$?$-,^#+]1/QQ(;:[^VG=D4:28@0+_^$"YBV:C=4Q'H!B
M..-A!\N%?5O`B1-\,`$],&P.H*:LJ>;*-P\^@:[V]&CZC(ML%`_RZ&K$\0M0
M\F>!ER%`DOZ6G:]=0W#_ZQXTG2CE`*:P`%'P'4$>2G.:4=`;-:C8.R[NF65`
MXD!LHO#=E'$&H&DTC+;&=GMG!W1=WIR9^`M6_Q]%LF5LMGPE3?7#8TIMGF"(
MZ!"B=;'WE`K\,Z+4,[2<;`-_O<(.:6)W*>>GB.)IH5.SFEKFIL@Z2)'X^O6L
M!IZFG9`F[5$^9TQ?/>7#CS2%9A=<!E\R4XH.W'0K,NJIKF3DV>ZDMW#'I]G+
M+Z)J]F9=XUY#125P\KJ!3_+,5TW*A#?L7>1',GT_._"?3+Z^2(XBH5M6&(VN
M-%N%@3%M0GYR/04\<'?FO(=@2NFXDDQ2D?1A$GDX']IV4MCR;.V%!!O.2K0Z
MZP)-BN@IS\O"GFW2/?V':ZD)3*IV_I^"8.E3[462IGQ/K=W<Z,X<N[ZW1O_G
M:OUZR90,',V/!*0-9WZXW1=_1-UWQ&]FV,C38R'B4_\6Q\Y=;,%KZWG7L['C
M&$L0B"(#C,FQME?I)YILX?AW16AY08&Y8"_-Z8HSI>6EZTOT339VU@Z,7,Z/
M'VY7!`ODB&FJ4#0"EUE_A&Z;%`ND@\"E[TZW"->F).Z#D27\3E3^#$QJ`+U9
MK:Y87BKP1;8))26S:Y>X3!.!=&)"Y;<LERGKO(S=1P<B1E+8Z1N4"61$/M-K
MTOD7"KK=M0*%BA!0SHUH_*K'Z(M!+V,B,6T?5^2Z5&/;!R[CC%5'_)-=6:_"
MW(\4V@UOVS9'9#S5QSUA'64CN>):NP$VL5%N$8>SZ6K^=T0\I.JLIC.T<%WQ
M4CID61>]0L&RKLUT"O<7`'[EM)`*%DMRGJXT(TV&;T_S]OH!ZGL]V)=4UVP8
MO-8)=);F*_.4X;;AL`:(9`(1FQ=%<&[=*;<;)NVS=WI@L`N._P[2VR)\4EWD
MEJ:<'M_H7_+;L?F4$X'FD4H"1WFZPJ;50UZ&J[!S0"#V%(@YW_GMXTYH`K6T
MI&;#@-I,$M)@"+6_QE2A`8A_8($_]%[M4`TS+[VOVG^7><^('(A9=^M"HO%1
MN+Z5]7,Z3*X;GP4L!BG(HKD<P_E3*"GD"\>/9+%>P)NB^?9("A4J7X!_7J$H
M3K^]?)(*O8K:69PGE@_CO-G.1;7B7AT['QV,PP8>)GF^ZG+>4E9[;IHW>(+&
M-$__)GGHG%4<':0=42S\UHN>,TM<&1!?EV=0(KPYDQ78%V^ASFY$`0UZBS>5
M];+)6LI52:9DER8AE7'QT+W5,X79/&^^3.AK0@&:I0O70-["6YA2HUJ*]PA%
MAE(<1I7ZP\@'(\=@SB#Z;!(^GA/55\E5%,I1?LC")/V?8J^]N1ZO=8;Q<="D
M$4Z3JQ.J_NFI&:<WWDS\:4,25>C;EI'<6"W'I*3^2@`]S8ND(4W6"9A"S03E
MS_FNB%.5:)?].G=69@<KO990%1R)Z01`W!N1`8=HY1PEA,3R97J+6_AVR)I4
M@Z+<WFOY`J+N5K?_SV9K9@#4#(T;`$1?BN3*?GEN4A#J75U0[;/4-I<\%YZ=
M`%X+SN"S*:OP:\(1E<%6DLHFFPJ><*+Y]&.[QROWL'I('$R""`ELH?-XHI2%
MYV_)?<PA"1.ZY/DPWL'^S*?:Q"C4\GXS$E9Y*)'A1VF5@":IH2;<E2^(0%VO
MR_HN'("Q7RNW@Q=W<$M3OZ3988W$-3&Q/3D?'-@`E6%W,(,/@MTO+:@G:ID?
M0E%D,\*PY+L'V%[Z#E#!SZS33YIX:HRPFFJU(8%PP+/\65QEG@1A!_>Z;CC_
M+E:GABO-^GD-C>7HWE_V05D4\$04_&@II*$'U5*4C2XR4LMU+>C(AK,05*'B
MH(5,'@03M9H6Y8+_M$RAMLEHN,^^VB^FV>&"Z_LD4N&$3;/!^EH-49?B]7J:
MM=:#*B""&^@\Z22;!*VA:'Y.=]0"6'QD+U6TA@U*>&;U$E^["0.YELH)W!L5
M#QZ8S`+$(W+([?P.LM'=#I]M2Q_3Z/<&IMN5T/1*PLT<!O;?+0U_W]=V?+HH
M(D"Q)>[:@CQ>:!M>=PV8SF64:%C\B>="G#L:%!@=T,T`<S`O[A%:/`<U_TWO
M<J!X1F!JL:F%F+@?40`5SZU\CNO_TFHPG7\<PQ^3FFUO^PAAS"6_9ABJJUW7
M0_CETH%I&>'O)C(HRX#!Y;3O89,[<J@,I01%=]JC<V1OX_K$VJLG$-!LAMN8
M"5:D?2HP:4TO";+5%A_-:JQYOA.0>4]K]>:R9$BNM^<Q:LC3+^V97457M(MU
M,#EB=Y!<8:_'2MZD=I1;NLM4:>)]#G^!C=M]O0FSPB9,7`8DX]3-RJ[WTUPF
M8VQ$[H<)Q<N%`Y&Q&\)Q[KEX'&UI(&QS$THTA!OP&]]Y4\3AMX'?\D1BN9&+
MW?_S>!J*,QY1/87NDY7'U5R2L^9`/E"%U)P0;#0@)0K_RQ]HK)3S*Q&+<6T]
MAC/4\@:EO\*2^SPY","=?ZA@G5]5/1=V*GB'^DG#/2YE`6V*WC+S`,/O>,CA
MW+>YDC#/#)UBRV&9T&#<&V<HRUBKXC#5;DS1HF?@0F*C8TRU0M8H1A3)FP^.
MR/7JM"(,SN[=%F@.X%O0FXJIRH?X.YI['YH`C^]XK6)7PC]LS]NT]#'\1&?D
MA6>3Z,(4LEFD?=?Y6[/5:71R2AY6SAQ:X0#+!Z;G`DM[M>A$[<Q,"P&_9U(H
M)HK,_$:F)E`?\_EX!U02###7(R%A0[:>*_,0Q'@BGFB>#VQU6:,.[I!WEG1M
M'@=8@`M[@4WHNE8N?+<.%IVVAG75@Q>&X,G&K`[C+[2-9N</NGN34E[P*_X<
MQVF/P>7-.9H"Z4I.W)G_%R-N,`JW?O<_&/ZG;4(Z"%H`FJ&MZX5</C!1)7$J
M':(!%!%TD'W#\=X<057$`6DPH122I+F_XJQQ)=$/FRY)()#>>'([UYIC(=(J
MA^8?>-#SJ5??C3OF6+"35V5'<6M3GF-U([4ANVEK>CR^8</"KX?*>*JFVB>X
MTD&'K**/+S8,UM"AX"/M?B*7X%B)(R,OT,RAHU7T?_[!XZ89MTUCV<2*4E/N
M)1<0/PQ775JS@GA\>)_"^Z(B`N&`9`;(=A48\C^,9_BS"N-YRJ!5@MODOPKB
MOI@,+,QPE]7?\2ZT*-)$/#C]5K%7.8T$QGE:/>_)*WF\X-&+6?`#7>;NLRN]
M<346DP?4>56UB*//.6,II)8J;/Q1>#:EN&E;$@SVEU%#N/,)GRV2'["^%E>;
MA>9#.SVJ`NT-8'?082XK4`);#AP`44\U#?*2<WE!1U)V]UR<7W'#IDBB.L;>
MG[%,YC&LCGA=T/BB-;?L_%3_HO/]D>_T'(9P8@436W_'ZW)$4"#&=3^(LZ5?
M</9D#_[/^ROPSHQ0Q3W"@BAS.`PJH!0T[%-U^$#&-9%T4Z__P@J7RFX_MSA3
M4X8#.),L40A]].AP-<5@MX8UD^L!D-'80RB0?K?(51%<L%`5:SDT%4"52CM*
MUK)_H/6X1"EN\^V:&]"7)8T:LU^UUU=.AX4=VT&I?&4W&#_HJM^:N`@`%$O_
M9'>/(H/::92;'9FMO552["Q'J(U3[42=R-10W'ZA'%Z"S/$BI>Z7Q\^P+86A
MV=X]HDC>W7[5#OW?UE2P&7"2N^0K;$`7O"OI-$,/S=-DC^U9CZ)BQ94!H5";
MF++0JD?!E+J;4[4(X^IK:XCIA6Y-V<4$&RKLJGC#//K73)GT_"UW635,*)@J
M2-5X'%*^J_)4X]0U=++I5?&OZ7+Z;JE#0C5Z]HE;J0O@Y._Z+0@+=]^5B`(2
MR>;<,2FYZ+MZRB$4E,$/-!&;U#+X?C:WYF$]I0*8C%=HKG``\>)%Y2G#3CO=
ME^75"`+5*G_ZB2Z+!#3&R"NUP+FS)NMYEQ?YO%!-2?JX#KT[*+)Q">K;%EFH
M-7AI;'4`'CQ'<-<:)F$:3FNS*8W3<=[J:WF'L6'RN-A\0$@M<M%N&/*J6U+U
MSDD#N%Y2SKR(TC\=U+@,0TUM2.#9++R_./&W4/K#7%[`51^H2F]:&QMF3F)%
M(5HCX1*;(612H3WGLY_P3M%I#SJE19$>`6'T[>>`RLGK\7.47B!L.6DA'F7W
M-N$^PAUHA[&C]4Y-[/JCW+O&\TZIBY<S=/S#P%?E0S(8,8!@9&\GOOVONOA8
M3T^@0G7@J3\GW5+5&C\=??0O3S9\JWM@]4UA#Z.SOG`.DV$51"/LQ!&>\SXH
M]NBR'F!,"(!>PB!TCL^>ZG'^;^"BR-@.DK@:%IVXX)WZ1%GQH%3:^U_)0J9L
MV@I)7V:NUM[YGV%?OT]HR&\YGTEZ*63WCMBD:/.9K"77WH@VI]F&@0/I:J00
M(Y8RI,\\SDM<-"%Y)UZ<RQ7IR:-TH>!!/0LM^+401\I:92ZV#RYT.$8KIY4:
M:1:J\83D.3OA'35?8FE,"NQOX>:[CIF/9<"K![+=JP]\=Y_X82P(<T:,WY4_
M3DTY>,28K32SF22X0F2_LU:BP-?"2-H%^B+RA5\?FH,VAZ[&'2X$\,]/WM&C
M;ZE#Q82:)0-F7/;Q'G'N&U@*S'2-?>I6^:K^QTZE`*ZG*A.Q>T-,"&)WTF<:
M]ZXM'2%!=5OH&X&/X],51#L`WS;'>Q+M)\I+T.IK;^/U,7V$9@N#0T*#XN,3
MNSU@,4F];5TP*KC\./0`O7`P7T";E5M,1(I+<E419`D)=M'[0=L3.F&\2OYU
M-VY'4XE9M4/ZC/;GI$SK4^"E?2)7Q(EHAA;].ZT7)]\Q$K*@#"G>G*6_N"+P
M_^[ECHM"M<[P,F`L50QXJ4BB+^*U<Y;J;>QJ&<Z0T(0SSSBB=5DT[1#4U#$&
MSP[!]CLM/M9D'COX$VB/+R,LP3MRD+N%6<(B%J/PC?@6R-\B_>>)H_8]V</8
MLO4GO9V.OU5C%(8RIJ/+JR*(YIFDQB_DHK*OM/"W'8=+6=D>V4".W9PO%8WJ
MOMR.1+4$!2^9BM3FRD/;>#(I(]4>=.-;?.]V21TOV-IV[IRFDH$!-%8?>E4N
MLN<(A(2>,OW!6^LWU=@YHLT1/(YN&O2Z<4<2LBGN"9AP=)0@Z3GC9U`[Y99-
M/="S3<V^:WF,<U*2I@'AO`9]M^M#.CVWAAR'*^460P8(FJ,`J?[PY/II!8S8
M<4:Z[Z4-C17/!MPU/#7/*"C`=/3W<`O.HEY?1"HNO7$B,W"F5#I!:H8JKKB"
MF#1HX4XWC[RJ@![0J;'B&KO]"<^%E]_ZHQ8]U<!'0W8&6=](_IKQ%S5MK-E0
MB%)P$GOTDTQ"C;#)"9`)HZ?>.$+:QJ*-W%/]2M&%$6P<-5HXQEGM+[X"GXE>
MO8[-UNA8F?_,X_N5#125-P=6PZIW"16T%G__-X574YEKE''WV(FMTC^6#.,_
MPK$50:-\7TUO723:BBQ&K'DB/+9GHC!JKEOZ)0GZ,SV8>2*=#"5>+4S*:UGJ
M,8]_A"U1DOW%!'4--2:3<\<0AK8[:M*X-+311E$&/$S(_NCX-*>M9R%">$U#
M6#3Y`/Q;FQQ8*&S3.TVBOY2G6,>'N\W6"56I//TFGQ.4-]J.ZB/EH+N9D7NE
M1:Q(_?K#->FSG*[%6@U1X-8:,L**3]C)NJJM-#^J^CU66(Z?F<L3UIQBV5Q5
M'YQ7#7FTSX1V[LH@4;M3OBK%#I^1W5'FED,@9X?F>6-=7L[IG0BD9Q`$O&9J
M4;[NRQ\766&YTAO(_NBV+-RS)JV-!8)^%3Y),!G([1;W^T3W'8L%ML`_C7K5
M`LC,IGWV=96&I##MU![[Z[/CQWW2SNK\A&,PKMI<X'C834(W4;O@(]UE0^:*
MQ`&2)UH'&2(S6/^5/^T)&Z4W&WVZA*+^>"]5]Y;L952>\E97SANC&I*FEK5:
MO%@#G)K;14MQXY=!S>9F>P$8+08D/W,HRV#^.*:)+U)-$N_P)`4)LX890%!S
M*`^NJN1WKL44B(DLI\`_4/FZ;6TP4U]*:77]]WF#*"5^E$YZ&66QZ<:+(&$K
M4GMJ#!ZA&L=3I0!$0"UEPC"V:\RN'D>[WM(/6H+[NMG=[&^8HV5]3[+L34K\
M1[(A'3E,U'5%2@QA#:JE%;W6`&[[]=\OMG.&&F=",@U[`76;5K`4OWLE-5Z[
M)LY3P5M5E""5.*W\:MXGA71E][3F;HR#H!5J\L!4^TT^H="FHC,&N'TZO,)=
MIFD]06;U?8HM4B;R,M84?R..5(K6::@";3))[M(MN%0F28U4,G@33IO+A@M,
MW^P=7/QG%"F<-0H<P-W[\Y:[@MY!<4]AIV,)$AT%[JZB2\:^-`.#$N'!W,BD
MY:U?M).`CELL]9LKGW:L:4>B(V+RP@S^MLOT*QV$?[7ZY!T'@ZHJ>C^XY?<[
MBMS#,#B<48),F/_7@.$?$LPM3J$@//4/C,TX3/]F6Y,P#M9VO9X`(MG;']B7
M(DGAQGC8@!BM6-#%)."NK4*R6Y%;Y3T+B_'G/*QKS"EDU(@NB%>^\SJ"#RE$
MF,AR0\M)>I=J5,!F=WN;O-N0P5S$I5%\3E59[B[#Y]7L/H5S4NOS^TM+/\_=
MQ;6GV%SP94NSITG`*5M9P)[@Z4DC.75^E%82.YMW58JJ-`X,Y93O0FA4D!D\
MP1;#/'@PV!%GH36A9"I(%OD"H615&2(H2XU[Z)GO:W0E5Y;RNBI4IX\TFWVE
M(Z&AMPA"5.<9J"-%TY/^F)U.*@D806#HWMH)&4G1[/=ZEV7IL;97AJ8Q6H=Y
MM;8$-.I10[DCVST$'^HJ4D9.5SK@$D""L^AQ5F%I;#7T<G!IUY/R!70JVC6Y
M`A`F!!Z$(0Y0.H;'V]@$.ZS"YN<-;>'\NE+UHRWQE'VYG$,#5?AW*FBHVZLH
MJ!O*55'?MJWJ_J.,P?OVFR_@+]CA,V*7Q'BIQB`_O:/#UG.WIB@'HF/!6]&"
M+(QYF.(^0&<R#KIG6E&#`R-G;H<G?_N5O^AMMZDQ1OX=$*(1*?8-Q:NJ#1=9
MITV*4T0B&&&>?05VI\I.E4W,A7YHB1\/G^K?N-#<]%'46^$,E,AZ:?7]40[<
MB966QEF$_.QMT3BSAP`E8/DBH`;3^3&VQ_(-KKAL+GEX1]!$.A]1#>.,!8B!
M[?`N:46$DQ1U&#Q`L%5M`>A#@]+*%0DMZSQXNLFOK%->C8]=**63BD4+K@=D
MOQSN98[T*`?EIICTY9]XY5M?]Z9B#U]#LH1L6+^"V4A)]GSE1LDZ)J?B\$;R
M]>QVR;A6UH-?FR\')"CO.(1C+5V7YN")EFC=O'!@;Y$S"(,!O_^2G([C"L3Q
M-_5$VM(0_?2_EFGJ"P+9"1>\X*/KJD,U6/X!6NQ)Z[Y$(CHIPHS&,"JLQSU9
MMZ:,,^FM"ID=/*_7'R%G26%O00259`R2QDL_?/%,Q]I8F:*CUH\=0$NK$PL-
M-F?KGCE`#^CJ2M.PH9<$;MHBR$S9G-%`G@>^Y8A"H(AS\@'E$^M%S/"W'^:3
M.^Q(P`E.\+R*ZC_S\Y`4+;]SI>WC?]]V0E3\<9(>HB"9-#W*SF$)#4.B!RF3
MH]]`)5<HUEL_[#D5DKD+8EVJ9=T(>4WA'3PK,7UI<L[T'J`K$_$8B;B`C5=L
M)KC-XWQE`8LXG+"84+4/OM:"J*:\C<`5-;'<<FE5:^@;7FJY61`Z8GNYKV&,
M7_Q_75$364.9HV](@SR>8IQ+&&'79SN"_W9NV:VT;76OX!0L,R=K@U:8,_=Q
M$<^,,O""UH[-F:+TB=MPZ,0@%$=]TXF<4/$.PV:]J*2N>G>KA11Y#O78N"6L
M/KZT*AM>_F9R`1-),Z",VB[I8!88._'4ABTT29J,AHL;#$,_G'3/V.J=.T!-
M-[%:'<=?0JQV!R?Z9\\Y6V[<(SD2Y3+;&*5Z'D2R`ZQ.0M]K^8I`'L0#]*V)
MQBP*DC5E9);1C!HT6>HXEA`^;BW2,J2(;0KARL'*1"#&#4:K[K;CYJ.\8BH^
M3Z7%59SB'&8;F0VYD->7*:2R*4D7<BIZ>8Y32LL0'"8Y5<'*8"1BXRNE`T5:
M_C3&H[;TG<"QPQ2,)<-%V&SCQ2B+T.]O2.MDT!B(G#1F@J`R!+,DTS-DKZ`U
M\N+>_3D^9X+6^M%:#@1OB$O/#!GHY[CTH]C,(DWN6D+=>S;)"B;SS>\.WZG$
MNL+2]G3HZ9K:O;=DV=1V,IUH&4+=Q=FQ;*P)[:PIH,,X2%47)S64[?05OKLD
M/H=WH.\]7Z%&F6HQ?K'X*\-JU&<[-%'5LSY69*RPZC@NY9$6D"8JDHH6\;>I
M.X!M+IP2,PQ]8Y./<E%O9)$ONW0'QT$2*I4\DQVP+%YO=#F^#QT%A6R<<TEU
MN\=FXF'T=-Y5C$#O!1V35W#%U3J29O'KA"1TN_?G6D=1C3AK#"MC9!57)ZJ%
MA6,&_1<*E-</[85Z%J.1)ZZT`<,ET:$'-2LW2%N2)B[N-`8@^_B6DN77)OT_
M?UL@\=:\+<*I^;ETV0ZU_WVI753B5'^<CK.?X'S^LX]+,;[(;Z/<QI(M0.R7
M$@6VN!4'O]G5?TY2(%6T1LJALL*1FX$'M8\LY#!?[F)?S3RJ$VW5%GM[UX%2
MQ.[A;U[OTSOD8$E>OU)PE5B:/&=11:FR5M$4QY=*978)?:[?<R2#D^#U%3CW
M<M>'K'.?#P*7G>(VO`J=J/N+A#O@W?9KDU0GY`]/V](?D!824P"SAH.W$S65
M*S?'/@Y`CA4!SKCG->2]/_PM.3=JXH[3+LD;(LL7=+H#,0])O,M;4VGE&9IT
M+;'!V(84,?!:%*^4QJ@3B="PZT=,Q&XOR4M8-^ISO75X)S#_]-([V'JP!\5&
MRX^4H5D+U[X6=K+_?4B@;F;K7%NJK.);H"AS\'RT!":$@P@>K1EF"#:6])`X
MCT+,%)I983J+:HT^E['Y>=R#2'R+GIY@=X>)$%$E$WR3PVH@@MR,UPN#D$F#
MWX%V3FI'%.U:GSP\SMA=RIVWT_FT<8>&46Z!.0O<XW-D+)Y/:T[Y1D[FK-AC
MM3".SYU(6Z4GP[]+TNS$:K/O9(=48Q0M)?*$L*0URB*V(:OD*RT+YK5F#J9Q
M9RIK.@;UH>3=Z7OQ`O=G(I%2O3<'M>F*BR\\A4''*58P=8];1;1X.$'Z:<61
MN8A=K0A?PQAN)4=T?&$+&5#O:TF,5.&$PFDI"JZ5HJRP(9.CDRX(0.^]*RS$
MIYC41.U[.I?4&VWKQ09TXCH[TTQCAZ^"31;+ZU1IABRC8AV62S8DV@!?Z"&C
MRN7Y)()[Y!^<BP'?[P`O=-(C$D@9W]884]'MDGGQJ?N7I!QH_HNLA:#ST'A/
M!Y?PI0-F4_(_]L:)ASP`()CEKPXK)2&5"(ZW"3F^:[[RG[[SS;9-=+/R9>AD
MFVVOUGS;K.8)QL"2A42\H&ID^30)(*_((LV[R>]C>^U&_ZWBY)[O$S)4T^I[
M8N)*??^4F=^T95@/R=XF(?E:YU>-!S.&E,NTUK!=5I7PSNK)>=QAS]@N"3I?
M=;LI.Q2*G`<$=/+P8='@V(?0@NE*(#[D)57*@-#)XH(M;:&TT;+,@A,$T=9H
MF]_@V"\?4$!?ZC$-@,AVE/W6DXD.R]O82<N6O5W6\RY2DM.ZMV0?@6CO($8#
M(AGSW)+"+(-9WA&<8QH(^%09P`C$C(2LY?<G/)'?0!EZSL)T8RN`T6PS%&H$
M7-[LA3=7D\Z!(B!([BN4X>\/M[%H@I]FF#FZ*IMFK^+D)+HOF(]MDL9,(_JH
M8T>6H-]D9_BC8;E%/0;^R=LB<QK'.WP5VHV82?@JRF[VX9[B8HJS;TXVQ"HA
MK/Y6&I+=?]%-(Q/^+0%8++:_O.YHAM$3*9$1!A5PP[/>S(D@4GV1F6WIE$4_
M@*Q-8Y>8\PVEO<=1\!`6KY(`@)FK\"'N`)[('7V)`4Z"GUUE=C(IIOBCV8B#
M2!U3M;)K;`)<'X[HLU:@MYE<@\%80.^^,[YHX<M]S)/D).8A_=7H6<#$#RM8
MB6[D-,QTE$()?NY<K+D_`/%:K!@C&6BDPG8^WWEP`WQ1G]TJ&?5?F(F2L89\
M`)D!;T6!*(O6D*?#PR]<`]O:5$BJ6HK=+)AR6%]YM(!^0@2+$"0"%1&N]5KI
MC>Q=Z0T%.^.BRE8+$,\$30CL4T[0QP,7H[7^"<#502UA;\;TX).IO/F#5E\'
MP`>)`]^\_=8<I)&P_JDQ)YG0^\.4P;0<CJ.Y4I\L;8V[73RG;<SH-IP5!U?E
M%6/?%YZ`:[%IX:^N,CF8?Q(LIKA[$Z>Z$!2"VDXWJHT"FV*<\KU'0GIT$-%"
MA39.V#)5EV%V^BNK47K4C6WCN_#0?^(/+^9C%J1B&EFK^P":1>O+0"R],*)G
M0IPC1$XD^:B+RI]>'CTK#!4;>2)_CC!-^9M<4L9)(QN%"C@!]D6Q]?#8[LTV
MY;_TUNT5C_\[#:*9V5&XD/Z,.F[S3-C8@,;)?(O@C6$(!0>MFZRON=IR53]W
MOOX!#./*D`U_HT`O@BR;5$DSCC%=AOM1F'L?T9]&)_C.Z_!+;1#<_S?;AE.-
M#KKY`(>&$,<GQUYX-[MS\^7(#SD?C"GEU2+K;)*H.A]T<<H_XX;(0U,)AE#;
M)W>!;+9)&(F-7]S)&&9KRLPF07':&:#P(C0@I%+W?9I`89\]G\D1T]VX<,!/
MG(<20J!@P$ME6W-`H.%@Z,4F0+2:0=!PMJZ?7?%I]NS4P[F<9JD$CU4YA!_H
MM$DT#I9`O5:XQVD:P_<H7(7"_&]I$]9.*L&75OU4<8<J2NB,#5_=0HUZX#\6
M!XGCF%6C(_%C(]8`R<.Y2..K0.V(SVD1G"^G/=PE((8<"T:*[5Y&`4M/\B7P
M.[6R?_@!90$HLT@F_OIEY173.<B>JE@=R,W!+_&_3&G=DE!_IIDV09,<M26M
M):Q-._7V.%&--)[+#<+$;-^'BUTR_WVY?MPXH>8'[?!G$&-"KG:IYFV;+$HG
M9M47&AP,B*W\2]PN+G-N4^.;!.V1YDR3QH.+^[%$3#TT;VC:!'8@C%7]0#&/
M-U>,IA]BY\,?CF2[H34+>=)M&S."&KNV]#`KX#WRVF81Q\+)(T::N-%IMMM#
MO?U"\R[*,&Z*6$:$S$7@FD=&XMK=ZW4+JC;XK-3`[PQ>ZF^7OW[`A0K8[L:`
M59['F@G>S-FU\/2?*V$'I\=ZXK\[GC7[='T^_%!93'*-U@NMWI["40NHS"$;
M;DOAB_!TM_TEE^_?%E#("0U@\J1GB$-;Q_C'W5!F'99T7/%?3QI>1X#(.A^B
MJB2=2H;?-=/)?L0YTLK:C477;6AVDB4N-0ZO/!KM=YJ467>W3%.+2_6>!X++
M+@K@!]M_=6AMR5[XF)X!?/-J'8&`F?:TRN,#J9LP@>RIU)-EV>6WE@B.\8U)
M65KD"AEJEY,MDJH2%1$M^[ME[+M73]LTH1P21\[9/=28&\[4.LW5^[[BH'XH
MT(BTQ7X4^U;/X%VILD,0!/]_4H?\4T5G%2\/5E@&ICJ8!6M#:M,P`M/90Q.7
MC*I/5AFE3KU)E"#=0T!F'8+:C.(5&MMJKEF4]2U70JN(_]7]WNC3:&4Q+%SW
MZ(R.76$JFZ?.QY+*)(\B7@9R)-'2Y"QJW-G1=^%^_XQC19U=&^+0F.UI-@P:
M9+IR_5*)\$M;266_3+GHIWB8OE1H'SH%:X*N-$]!!A6Q\T(REC-6&W_HUVAS
MIS0&,AIO%L;/31WT.9:;9<58$=2BS?%IMZJGU:L0:1:O4R_1FT4E.*QQ'NT7
M?>1G0.R[=A4J-Q)=7K:M;8VZ["WRZG3%`S!70(3_B1FM;QNG(C$_''O32>`L
ML5''`I%1$SNR+T8E&8Y;L:B<);K7D9M@B^B3`@8B0OK!T?NJC?1<_M=&\DZ]
M^<FW!#6L]0J;NGHNGO3X.#8^F#Y0V3R95#=3<_Y?`%#9IUVP0:R*V(^#C"]-
MRRFN>@ZH%PH,#JO;F\'"-5*7],9.K/+IL(*-]>MW3/C:08(32O?R-AE"J`[!
M,?[5S4F\+Q0LNV<1X3=^`7S#V_-,-YMP)\;]3RR$B:%\W"P0V131:S]E4-3$
M)C)K"=LLFZ=ON\1#;I\;+QWKU"KQKE^A'Z$V_S/#?B+#,?\H6D&H&C&\`::E
M=B^L$O*&SM'R@&&*[T.+QZK"]/-$9O9!D-L/Y8=`/(`\$/(_Y,*.'=L+#F<1
MQ":*^-W5R:Q<Z]=S0"J)@T*8>X;BO+V52C':9&KZ8EF6M9=A5F.Q*R'PY:"\
MG)#MZIE"!%QK4))G@^H>'7>M9*]W^$GXJ)P,$L&'5G_-3ZD[`'2=<T.TGC8[
M71XRU]P;%Z;0L#6=2-('8-976A4G7RF=>A&ZNV&('4>ARDJ1IIPO;E'G=YA]
M9:W:3SN6I59?,DGT'J0S_8ZKI6>>@_2\7"QO&(Z20*L[WVHFV7;"#A^AQ[VS
MTC$4^WC^SIPDYES<O>.2E;U_WG=;O8I)4HIM"+*5-I2D1D"ACM4U4O52E30V
MCG3F'7H3!4FX)"`&C[.>S^]Q,A+9D@*I"JTW">JR+3%4_O9T5P2#_P(E5^_I
MG$6VF:/<TZPT88+G;-"(Y!6)4VTPT9ZP#.N.&>"[-MU*GUBTL#:,UNFS'YB7
M./D%F.O0H'P[["ZWZS#5EZB+?&C&4G:WGHAY;`\G[2OJ3KW1QBFSBM>')I7B
MH!@.DZ>;7EM;^6U[/7S"*VVP+\\,K:T00G,L5"PYURUF^,$L'6%I[-#P70)W
MOV9%:!,(@O/@VX8I2)$:AYD'!L%<BB%-0Q^QJ?Q#8RN\95LY)])]G7"/*&JS
M(9W$'#\G2FKRY`18&!,;)B9ZF(]#]I&7F(R[('38.FI,6CTRVX<N"E]U\.SO
M!8X3)2GXH*C-`U0A\43`D8T!^2:#,](*^<DQVFQ+T/_/X#GKT@Q$A/]W8=7Q
M;O0LS^SO_LZAVZSOI,!96O)>;232?A?=VY;E4&$\$EQ[U45_X+_V%O?W%O5)
MMA>#75(8!U'PKYF)1@#X2H#!!44:`]NWY6+,_1H$`6K>:W].QSE]/N`Z"3VR
M;S`OTFE_?IOLJZ'&WX;ROT8/H>7U#Z.#"6`*^L\2$PYJO;.2K+2WJSM81!04
MZ<;W2K';LZ(/I0IG0QK($4_[09D_^\ZL8+V5V`77MA_3F\IWX\J@;*WO32E]
MY8-O<!C!9VVC*O?;^S/%=X]V#^QA9`8['#17B?,*:2\OXM\^SPCQS2[<U\_M
MXLN:;[RT-&7O&!:Y)``XR=M1QDJZZZ*FL_!".I1K1E"`7B%6F5I[H%+A.ZMH
M)V?/+24VPSZE22SP]Y$/"O:#Z)",#USS2,R:;_@<S3F%$;"'%"ZY`T@B*F@C
MPDCGC#X<%EV[5D*[&EKWTZ3^^AL,.CX!4`F36:X9\#0*#A'G+F9>I7KRA/QV
M34'DSUS9RDU]#D*6W6I*'L;-6$@<S?4=GHXR^,OP<?,%[RJ]?1UC=)OW;[9<
M_;,6\S'RZWQ3\S';'[EY]4BX!LOD%P^M(C`HL]8OE87Q[Z04U"A.1NG6YGD@
MV7Z9->Q!LWUIWUK/>V1U9XL`#A8X?/@(Q/=BE;K<:)FHBO=AHH1IR9XX5ND7
MZQG=J---VTSTOLL#;\=FU:!\J/97J9X($J@1JBAQ\>E7@/P7K3'>Z2&18*JH
MRQBX.Z5K'5QQ_WBW2=2T].>Y$<&^@'1B!J4$;W\LG-*4R1*>BA,IYZ<-8A8E
M/!%,;*C;BQUC#[[?DKM"HNEDB$_L#'D64+'G,G<)Y]4D$FY,<*%=:\]>>2(+
M@;@+Z^CB=L.O]A0*PP)G2I[1>+-'WQNG&'WJOV4E+Q7A3$JKD1,;J'MRJ3GV
M*^"9SX^X=1@Z2A8"HAM7G%%09@D4.4L@+78X,CO%?)YSM.[\CN*='H0*-#LU
ML4HU]3?I7WK0;Q63%*@F-?;H=AQ"=.=RE:!B00N6T025.$JG,97;JBVDJSD>
MA7TEIA8V_2R$J<HTR:_<_C'[[1%L"_!=[`?%S/]@EII3,RI0!M'V#8^1=V#G
M9V3@&"(`4`&Y58D=U`0PU]#5ZIRAJK`+W,G("Z42A1BW5BN9.Z!&U1C(F?UE
MY._ZPM-`/Y8<AMZ8(V8QD@3;70;689?C3$K?NG1F_)3N5OG&W_/`*$TNL/;I
MM%9*>9>)8^AV6<PC$6966Q`3KC/W7-Q]?/ZPLOBD08`U7Q5GNX+A._IH+U.>
M>&9D_C76OG$2=?<=74+%;&4LVFS,T<\A2!DI"@2I78F*?U_9OKCOU/:.HUW^
M\5@1_K*?@TT%_,@ASJ+4UMI]>2'UQ6:B,X(SZ##EYLE/*([9$%MU<A5.:AY[
M(NH@897MBD2!?3W\-BU+.'S<KK5)U+:!T)+9*&[[4X\:7.&!&7MCXY,0C2Z+
M<%_@F8J,ZSY`*HEII;'85</10I"HV!E&3:Y?-"G5%*/`:<$(]X&,_NBX:::Y
M%K@28@S]0A?K<W"AJ&6>4UM\\3>_/)!=;%A+NJ7F&C&6VLK/#/R[?A!\)3C_
MO?F$4/#D`VXH3KB9?FPKWPM1#Z[";/^MVG1:KR0\RQ<ZV(_)VL1GBER<!MXZ
M,=JU<)FG,7WN/NBNZ@03?J/*L^@=`6Q^?Y++UMV?0(=UU761KI0RHM@!AO9!
M_ITQ?O\-QS50]\[DJS=D=VL.1XLQ\<B0?GV^#8VZRFR#G\F+HBU*K24@P\`.
M_EA0XFRJ:+Q:ZHJ@,6U&LH7+@)X"GY3P7]:,A,VI>//I,J[X7;YGVB\2HP#X
M/F8S/3#C%(8WPR_QE>T*FJ[^6@"L_='"`SAE'J"BDF[@M$-8A?JC_,)U(_6#
MAFPZ6[Q]\GI%'6NH2'=VH9E7D:@EU'#<8B42D!!:#`CS%G4'^S:!?%N+E]C(
M684B-?YL9>_/)*E*".N>,D&8?;4#2+O3U`F`^=>5J*F%FU2@9(EIGE?TVU)X
M\M9=."L5A=18<I0@!A591^/Y!=%6K"8I!)(_A.N'I$,G5TNA(2>J_,GNV"1Y
M`*T/1Y&2?%*NRC2,`L[\K&'!'^0"B'PB7VNJ5@JL/#CPF>RZ'8IG-F)<ZU-J
M'PF#NU:#VZ5$4!]<!)K'36=8N6U,1&TV<S;`UA,8A]MV-:O>Z9C#OKE!_*.<
MQFMO#,,\;T,3H<</#11^X'L2.TP@)MQUYI\^?R1$IF8O!7ZY.:/Z]0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+V%D;6EN+W!L:6(O8VQA<W,N
M1FEL94UA;F%G97(N<&AP````````````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`Q-C,R,30@,3`U,34T,S,W,C<@,#(Q-C<T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B`@("!D:64H
M(E1H92!F:6QE(&-L87-S+D9I;&5-86YA9V5R+G!H<"!I<R!P87)T(&]F(%!L
M97-K(&1I<W1R:6)U=&EO;BX@270@8V%N;F]T(&)E(')U;B!O=71S:61E(&]F
M(%!L97-K(&5N=FER;VYM96YT+EQN(BD["B`@("!?7W!L97-K7VQO861E<E]P
M<F%G;6%?7R@G0B<I.PH_/@I!READI4$=8O0?"PO)3-;[1<OW%RR1#=WOH<Q;
MH-*+,U>-)DF_69<6AGHHY8^--_U2%Z\^->12]X(PAI`8WJ@<R;FS3LCMR95O
M,YP>U9*KX92FB)V(14AD!B>CJ!SH=,L+-EA@?2^Z?P*E1B@FZ,?TNH;T'X3.
M&<_]G)0$:WWA*!G4!MD$5Q`1)S'G/:',77'+L#\_GLW>.E9L14+7:YZ&8&FJ
M#L"'Z`K`6U\(_*+;'R<2ODC^Q*[A"$B>C][WASG>2[<@1\F5G<(J;FX$/Y@Q
MJ2V18%,TN,O\PG^K_Q,4M2^[S[36$>^.A:8,KQA7B./<;(58*X8AG)O%F6MH
M'C'+F>NJL$(09Z_>):Z^>:4"UFM7)#5B?G=WM6NK`G(5671`+^T29;ET]U,?
M6U&!<"6#"((TAJ0WT^+)9140O(F\:1&.94H5LPZ#3?Y$P>MH*79RJ+!#A2Q"
MUSC.TI>$30#'D4?6L\-.-UN5BU*OZ!JX*.>G6W'>LI7=_+G[+-%L5Z8Q[,;1
MF^?#U`JMA=P=B;HW\&GZ%%.0M3AB63Y2#>S',>WL\6PX3-.&2N9X+1+N%C78
M`$#>^1ZMSU*ZB2^6Q'QE9D_"Z'90W97!@'5;6PTW7"=*+?F>1UGY=^4%(+/2
MP4].]FPA'593GU1JC)#8L+[E>"[SCY.H&P7V3DV$8IL17_H?EA!FLB%D^-1R
MJS^[:X*+N8QE[=#ZHHE7PZ.A'V<'L:4J!^JD`=`H)S&'E0+.,&57+;&;M)$W
MQ4`8\+=23S;AUDB8-1I`C4,B[2+)!SW1+`I!:AK%<OSYE%A=@,>J$?"O+1%.
M_71D1'/ZL1_4S";/+"<T=H*-WGCM6M*'PUP>H3M0/"N25P4`G:51G[1+<KQ>
MJ-Y6PPJG:!1DL">\=\14$3MIH!Y81KE$QNV3@VA@D.8L@;YDX)&Y_7YLUSD[
M+ND"T@'F48/B//=UE^M-=\,4T/9R,^1B`*9(N?.WGVL$E[5I)FB"4G;+&5AJ
M=(C0>M.J&)X*K]J[%##1F,ZPFVLF3$%0;T]YT5/*`(&$+N)KXWH5_7I`U]MS
MXN/>K6KR5+%RYSB^*#--7QW^$+$V84Z9.B".R1+G.E#O*1(9Z>BC92;B)&=&
M!J(;Q[C#Q17M&4RQ6LROK.EU@>%C`[UJ7-]XZ`X';OE52^L%GAJ@2W8;(D%U
M:`&8JX<:&O4!Z9':XUTUER,@]0RW*LJ[`#+?.!J[A>BJA53P#I]`R[-SVSR4
MV4UYIO;+[3M=H>(3"UT^EU%XLD/V-SV']:B%GLS.?^TUB4`H^GL$AM)X?Z)`
M-F^?6=1YOE>V98_C#=ER#(U*Z>FW#*(F+C4@-O0BE6R2?[KEO=9GO@SQ.S!Q
M:LBW%UX"AJ'/KD/`52$`@&XHZ^+<</ZBAZ`-WUOVQK!]J(F<2!3)B[NDM1]?
MDTA@+0=B`]9%Y>OVR1W)@SZ5T:8DM,*8D:2`@3"`Z-.)N5GUP$&D5!]OJ8LD
M;).O8&D&V9?5])I?N;!D^Q[+/MX!E9<,U*:^S=1SXP8/#R5H'>/,=6N+@/R#
M?XA&--1'I/+JPR-;TT(Q<*7IPW^?K;8M*[7ZZ=*L@/+"6_F2'<&#XC\;5OG7
M+?UHYO_740.V>'O2E?AF[M[@#)N>4ROT"!8E,Y#$;!T<C:S_%J)#L4%5OJ@<
MCME>`3:H0R]/4L4%(A^='MH$0JPY_9/TBYH17OFI?U@D\#[EU2%=4P1ES;;W
M\F8$D.PQ$3=MGXWR:EBG9O@J$61DHV1)\9PO^24'FYU2":;'PAQ$O>&"_*(/
M]N-RGL^J=5*B;X';8/#CHQ_<U6P7\O[((O:G>`WABB,%@929$:&<(+?,"<&E
MMZ.FEFY/&IA[,119]\#F,B*Q2/WD+9!ZB:S^WSR'"T/"V`TH2".W(),Z3GP+
MR$%>)LUPFHB%\W#@H@IUQBT8U8TX\MSIF;CL((^'VY:?C5"":"IQ28CZC&R#
M_?PJ*#7ZKPB5H7>S4"+`#,;C*2[]KC7A,+$6"^[Y6(2($7,S_9+(W9QT06@F
MGT"U2.+C&KG>5.=CS`:R[06VGK90NP#%RA[`@?/$`":T[,2-5[=*$&)GP.H@
M65'(UXBZ\HE,5UXD9)U`?9S9^*&\4C8/<'/ZC_1(]]@KT,?AQ&`U,9'3M.[O
ML":$2Z2OD>3AY/#'UK=8J]$X4T("Q^'O?"U=?=OP@>#H/G+3OPZYX410_5'P
M#.H"]S2UP1N'I/DB]\<5`UX+1CMNK[/+?"F1M$%CM.;1QCC#6(OY0%^'I&&#
M70L_?HO,:'!LSQ/-EK]I"N-RR*`+YLV%#H+L]5$7:>UK]2Y6ZA#YRJ2SD5;"
M;IZ1>5)QPH;RLZ7NN-$OP"R*L3;-'*4#BMK[U=/!.MML"K4<2`?*B*_[DU80
MF8#>^1I%S(FGCLHSFK*:1F%+D-FOH(X!!^&N9/N)P4=@A[G0H.X^;U%*<I>\
M]D4[KU6<%24$FJN4<?!G-YLA\?0W5?Y\KP*.>H!HQE#W/N8!IRI^G^8HR>,#
M.`"5ON(G[.S\[>/H`:^,^7:/Z=//[TW!8DA=NAF4U\/TZV+M`M2<\DSL=L^;
MWW;R]?3,1P?A4T267]4$XN(UL%*G)6XYCK7<!?L/.;DZK+E[TK7E>BHM[[%L
MZ+#A-,?&`$U`^>O-0ECO><AV'`#[YD&<9E(AD(<>EE+>/'2\DG34;H#+VHQY
MT=1+02?K#YLD"^RSG](9?-'+TJ.@<X7`BA,<=31T5*-K?*1STXR\7?"Z<A6,
M!L)T+0)H?R.*Z.7%-P*ULX=:4MT4OGQC`<)"@PW1,@R[?DU'0?\DBW8$Z)PW
M-NI*T2<5X)Z&Z)*635=T;\1"?,A:I9!0'\>JAG75%L!D`PN>M1V116&CBLF3
MN>D-.IJR[..H^*PTN^X5=0^BEISSAEA1EC]5RD^^.:CT!AR:7PLGTL$\CU\-
M:\[0?%G#2-,-RBGDXOX4#_)O%_#:01CIN@?X.E@MSLE+AH^['21-3SXFJ-K,
M['5+0>KU:F_811\-KO9^_JKF$L3H%5_+4H"+%#M%82S/VV-$%%1#U'.;S&%\
M\^JO1L@Y4;&D`H5WPFFUSG083)7=L7N?<E*IN:F_[--"?A[LN?2F<F)BY]2&
M.;8":-U3]$@-NF[>MG:_LQ2[9S0%K,LEE89XX4O&\X"K2%/Z?@$]1E419"1`
MS5`],(\WQK#[$K9.FKR.MK>"'Y"RJ!M^2,PZ$E"B=D`XT.W*UAO!29DSK-2`
MQ02W$"A)L2RQ(J_I>-]FA\>ZL-#_+Y@R^XW@L8VHPHX@68A6/&*\%.<&`F_F
M0<9AVGYA-73$<7Z%([W$_6:[*'=?U3)\4,Z!!`I_HP'-H!PAI77)LO>MEH)O
MB676];N#!W$0$>AGZ-^-&I0";#['7[Z1/FO6R5Q9-X>:6Z!T\63#A'(VP1)D
M#)]X`0<J?C;=DYRB-[_44KA\J4J.O]83NFW5QJ<>@5]DT@K"NC[<R:FK(@[)
MA,5F`7+>GM\H'N"`8(?UQA)'(EDS3E&$Z21]ZAD6]W@6:M^&<EI#UB.E_Z2/
M&7A,^<@<6DOXZFFB)LF'^SV,8RYN@E8?J#)\/<XGJ9];KU/1?Z6&X05DK]QJ
M/W]=G9%'<"5?JQYT?,.7OC'?3<O5U3U*C0@D5@9G,_S0!U]U4WFX%G).AL/$
M$#RV*V3*FBO@F2=LG<]"OC[1Q/M@EL2'7MC-\]MMHZQ1LB#CO<.58JX?@2,F
MLD#374X^8M/[J^7?_8OGQK3*)Y&A&N[P4$3P_6!AF.>.,<.E[!R@Z%@T2+O<
MTVR*DIAE%!:_E?08,I'@SAK>1EY#+*+PC<N^A<HZ-"R9C*IBD(9#BG[WV&ZH
MXL7RE`;[U+WC5@YOTHXHXQVW(RRL`7A[FW2R%]]O;R5Q1B.2VZ%.=S';(`^Q
MG&+C?^9T#J5?^"506/[-O1LVN6G@AU;?>]]+>TNH?O;"<6P5@PJ8%3I#YG%C
M0?0-'X+[%`Q2H_I-H99M]^H6@G![8>]3%;_;$)JHB=@26B@R?S-&&>O"67:Q
M]=2+!_/<(UV;.&\,#!77C(Z7SY[$-^R[Z`(_B737W+.H8[KFZ=*2\JW1%&D(
MG>!+>/[#@`WYK4D<Z,AN=(!CR`!UILSO^@G;[\;K,C%-04:SFD?C#5^?Y[,1
M-R3"J_@:>5Q$K'"=0%O8CU+.R6@`>&K\$(E3XP][XT-;GNI+R^Z*,T:HH':[
M5,$]O2U](9"ZO<;`!?X(</QA@78NKM?%B<&=G=E^]12?*RSF*9`^0IQF)!%.
MPE#&<(/_.NW??;0_#Q'+Y4B9W72'\FO^YJ9%WDLW#1;9&0O!>"(0V!W(YJ)I
MA1?$:X;P1E!HA/8L*+;0P1Q&FY/\3[?]E_P5<+PC=X)$2-`#OH'?2^!B$'T'
ME9268_EPEM%MAQY.Q6^;-X!PT`QW?'?V/]]S)[OO!(<EP:TF4(VMQL[T!)49
M./-`/S^;RH/3`%NR19E?@0(]R(98*I-XC!233.QNU`FRYIU-_W?H"#[)'YQE
M)L8NVT5<@?K2BYIF]^U7NK\G7Z6Z-A[*X$0)^_=!',&SM),K:LJ9]LV+?CCP
M7C'MM.;K]S1N4L279_..V.B'">RVV&$A&96.,#UU-\4?28Q`3<5#(DV-#0!@
MR+8Q3AYQ@68IU=+PZ;>>C&BT1=5<Q&XP[6T.#DAD?&,N8G;YF3*22L/K8A(?
MG-PRSS0/1IBAQQ2Z^O+]!=0\"*34;_Y0C"F:`/+@"UZ"#(D<U"KY4C@S%<!!
MQK[8'"XQC7WS_XSURDU&XT`X[6F4YA\('"^.HI8)LD`-RI:8V6!DO6>]/-0K
M]'9Y)$L)W[1AAT+$.DC$=M3&-+\M0NK%)1&+6SS)6GTP`(+^A>G$U.UR)]A*
M*QJP16-^]C@T[!$`H4[I>$I:UKHS8[S(DQON*B2V:QGUGD6H^DDVJ-AH(,(/
M@;$%,D[,9!O$=B]^@^^U#UPF/9V*Q`_+H;=5Y#X\`).,<0J1::ORVHFU%+I4
M[[%FQ;#Q&Q1V'_HC+<R&5U))]L$U,:QW:M,JN,V$BM([IWSFLOC#;2U/=]`V
MRE?J6O'K'"Q*6=GI(F89'?VZ8Z^<C/KWWL+/>\,6I`?_XH5,(!@F8QD4@E-_
M7_W<$C0[!Z1J?BK(O>2VII0]I%X\16?.&3X@Q/MZG.@6\MFM=H24#[@;Z^*M
M3&'$8:ON92_K+I;`0CVWR#G?2XHM^4@*2"_NN&P+G#D@%(:Z-9RFWO0SQ?H3
M7_K(*"A?QDYNJ,J;G;#6^%)+R$F4L!1$0-3@#7ABO$K>N2"M69&1UTH#R-K:
MC1M1]JH1NFB54*^PK!Y[XS>V`_%PY86[!/A722_SD`,-#PJ3U!S/S=E?<%!D
MON_WB=8!PZSH3;@2VV*]&-33AA;DO35WB7$W=C7<<\:8DZQ7L2Z&_LN6&>&*
MWK+?''J63:'&I)2SC109HH".U,YXTTNF'!>/4>WQ6Q.-Z9=M78;W9*);HO<I
MM9IG%*=##C<T_!I1>EGU$Z4X@?0:S'/EFH)"]P0?!GB0S?I(+<-O%O3Y2*,U
MM$&T*<-?/6<".\`0L.355K24*AIB(+JD::7OR;@C[%\/2;$5J]8(,ZE]9\5>
M=MRJJ34HUU^'EPK(T-@[LWI]`F.28#D\Z=DL&%9_3=C1+LH!B1`![<BCJ-18
MFX(J^%M8;@:S(@?UT`.UNH*A6#@OZQ5F1D&,.8`:!+XO?P`<I9#S=E*J\*(-
ME+W&`W2N$G'[K_XD3PX18XLP:H]FV+2*F2"HB8SV5%?1E#=G-H_GAC&-1RT8
M$Q)),N]$:&^UJK%S`U<KX'=9O7<Z-_+\7--Y%(E]/0=(88(M59:_=O#N&3^)
M%65C[(!P+B1Q'OEUWS+D0+P2K.+$MD5,?0^6L")*KW97H,4F\8N.4_YQX%@6
M:\#'>.\FOPRE!Z6]L486$MNH:P:O=]9?22`!?7\;V+:>9N2B&C@CI*W4G&M&
MXR3($FSB2/+$`6\_XE]8;OIR'?6%NU-9V_P/\>,@+W96=O9APN",6?\*!-$`
M_=EEMK)TEV[8;)$8RL2X?ZX<UL+#@],J*S<TRAN^>+[T\BQ8WIF2!-X,('A&
MJT5_[O;_.6%3KO&BHH^BN?VV>/UOCB@L6.V'EK,6YM0TS8-YAAQ7D']O9X;0
M(C>#9R06:D@OIV!@B6+3V`CTA@T`S#F,RLF6D;PHE$@H6IUW\?VU!??:`#5>
M6"6\FS'(<2HREWK<N_^<_D(`K?VUZ+']/VOI=K*88PQDMHGM+YGE-[3YT(4F
MJI84?.(CQ]<M&M.@SNF"`5K**!H!N#\V4=EN/,;O.#=)^]EYN0&\O<)+C<T'
ML^9\1[;+(F]@`WW9A\FK>E^96=T#%[,&;IMY$T]R-AF#ZC]$FP/UF3(PP2S-
MWWGL]-]#B\L%1RAP,(5Z%L,.V#/(8>''LYN[J\3_40YUOB)#?(ZOH13#73AL
M'"\C+1:%*UXG\%WW]Q=R&]-</#MD:*1I,%<:AB,;.7XW4QE/O&PK//=G7NJ<
M$%#O?X8+^<+!!9.%8Q3N?0=.H^!8VKI-H-WELG"ZG7,(##>.Y00)N=X5=[J=
M#U,27XD*\E.6(=01_S>M(>SZ@0GZK89LLX=X.8DB*5[%%)31'`Q-O=8P$D'&
M0@]5_^]DC7%:J/:N[\>_+@P_MOB%S(W'0DBP3J33=<C7_)!H0;*P("JNIK]S
MD[\;E&\"]DLI\NCUO^=0?X+!"Z2QALF0[["*E0A14H_'[[SO6(&=D^D6"OGC
MH?&]I]5HFEPW1XXQ,(A;.)-\139B^:,+K.^T.\`U<Q3?*K,&MW$9D8V,G1R.
M<N/*A/?%BL]%*$6!7TLJO/9,X`=]V+B;Y=!U[45O$P053!L.1*:38W\:UV"5
M280`MLR@\E1G^$'U70$PJD9<[]0E]2U/G_]XK!?N(O'E=']Z[Y\B+5@#553.
M`]*8N/P?'1=+\1>HSNP21&!%9_T;6@Y'4H.R_WYIUS_J*/E?D\N1J2-.BI0_
MLZPV%5:FK[#*V2^!EF,/2U;%(@;SKJZ;ILUOFM4Y?O*:MFT[^5^PS/&I/.,R
M>Y_V,:@J"4KAQ\\::54%WDHZ$2:C74>..@+?F;<?*-*&`I_4NE"!?'?&E&>I
M'&XSZ_E"S1IKH'59)#)\`3I+>W&+I#ZO_HRPB:DGOLCFU4VHR%[T8MG.57:B
MZH=#,!EQ8!?.<N,S`'^^[=`JLPJ]:5<Q?Z*1[\1+2@+%_^E+3EE9?@4CXPKJ
M=J_WR"M&AR"XFK%VPC:MG3JH.0.@,?WO=V-2N1<_%G:GMN><*[BNVH:$)R8L
MIAC2%30VV@1?+F,@>7(,"YDHBT-C&3"LD*>P%&[>B]SI4.*+=*)?YW\F9%@0
MM0&U>V3_/0M\97ZDP-HV3*'B+N\YX%5P,'&>D_=?SG>O9>^P;&2/CDF(SFLV
MYE=SU\)Q2,($<DZ$@,KO+"D$Z),,0PC#!5AE[[XT7S<*"OF?&#U*GQPS!F5J
M=.:9]-WLFK;%?V[K;;]QKCD]Y%UOD#&>YXO4];=?7L$$U&E1+CPC#=QB?J--
MJ.%#L5_#\7QF%M]-H,OEP3@6M+XKDK8Q\#%9/X(5'T*UK%6#WOXBA<'5RD#4
M:'&-6^1N;?>*91./."@3E1($1_:I^0?08^@;$7M[>@G1_STF\_O%O(<"$J,9
MASF9R/&_62+Q)#!!O`:X.]?T\"%&P]<HS\1H=^3/O9J,`G8*!@%%/P#@**U!
M+_6!3,BQUV%]?!N)7[A^EY5E%PFT"OA*:%A""W3%Z1@_U(UW^R=2%68W7CT9
M%)P-ZP%ERG()QG!:MPG9Y_1PJ8-V?;5CO#&M<JIE&!F^<_PC6.XW(Z]^8\J3
M?@:0!G\FY]D;$V9'WJ/IVL%D+:P=F(FN$(SNF-7*#)31Z3ZCFT@FV;&@R5:K
M)`?%X6R[;?5DOPK,CJ27^:SP?6[797_E1@OXF]L[J5`6F0@+`FXL3I-D`N%"
MV'7$[0`@LG'Z0S.QQ59,(L_4*9[KY8^?^K4/NX=T(T?QFB@@,N0X%04&[!4E
M^94[0S_+76S'#9%L'\SQS1S#SAF*'U1Z<OPP%,7P%)ELS`LG'G&@<89/8<X5
M/PUT[:2FBN&K`76;`]7Y+X25(ML]-=]Q0`CSG/]>-46PZO`O)B`:7M'K8<>)
M@NQ'.Q^>\3U4-_RY".`(PD%8/CDD'@HCU#2GJ1!LW"F)6``UI(:9?]0%HJK5
MPZU8N(H_6<VH4YIR$YPI97Y1-7[IA8AK):"`*J,J#[V]6*1/24:58%"3:#I<
M!AQ\8?@X$FI%L+'19Q6TFYJ#GYT\0JNA)\+2AEO[;G":@:&.)KJ*[C,(O%ZY
MS76T"GTE.>RJ[9H)$^QCX913:ABS:8$A1+9)Q=N";RU`EGXL+N=7TF.;<)#L
MACH;PA%'%9<R'3\X:S#K^<_)I[T@RE7=F+C,1U$`%!"9;.TD:,Y4[Q!5?C#S
M.G[Z%S[(4?CT7$2Q<WI@F-,EV%:/D\X59_EWA</F5LDSD5.DQ=G@6#T+6BAL
M/ZK6\;#5`YZI($+Q'SPG5WF3?)5M52"I"/F)7-D:X2'DI(X46W*?F%0W^NL6
MT8YE.E=D^WI/HFI?9I>_2N!<N"BS7Q'`6-),E\D#'7JW`8L*QD0^")[7TASP
M$>)T^[98+F?_K::YRKKOST9.M.F:J=)M4^Y,"1K_7ME[;<ZS"8$^/B%M=]W1
M+F4+?#Y-P+*2C;(XEDYRH?*#>N\+YN)]^<]WU(1J_"+6SK=5]YSJ_F.(_A^I
MC0VM7Z;$2:1T@*)*8R@_XY43351@W(,&!^[D3F-$D72J*XR8JW=V/E^;L:*-
M&'V-/%0BG-R/3R&C<B#5T>DG?+2`QC^'(7'"&%8LEJMG)<U`038,!;1Z2A<(
M<3D-``QH>^*FJ781XH&J=1I7U1)+KL>2`SQ(`'SW\!W/%N)PJLOH;NG)U$_"
MSL).6IY01:DF%KRAVDU!_)%)42W*4H.&6]HRQ-HS&FO,NQ*-1JZZA3R0V%EE
M[MU891'SUX5.AL/,!F:\=;'NQ]9B$DA>@6L(N.`="`TD]2-$PWWYL9"0>=^S
M<O!8+AP2*5KNJQ%;A$1](V/?Q'*R7BY#W51R:[+9I%3-%7I-H3,H&MHTB<3"
M-`8R"/*U6A[?72A.J?=.IM_G+RVMP6=\<6Y_HH*9,9Y)_?8R]"N=3?DAEEV_
MBBH0@@!NRMG,HUL/DD'2K,E<(>L3?(</E)--3(+!PJ;3E\CD!PST2#-)_T@?
MT_:L=:J)R=E/A8NG"-"@]7V-6^6F%@HLT<;KS^;5GG5@4)>6A_"%&%AH#*W:
MS6B4OM'I8=ETGYR1S>03J9ODPU6(<B7>M\3(@"IO2[4KWY75D53#KI[B((#=
MZX5I)1<S6XX;3IE"HHAS#0W,95:[H&JH.MW?2.CR$>BUWY07W%BYA/ITZ..R
M4E_S$7:Q7ZD_%GS'+B,=U3R)[@26\=V#K"Y6B5/,O&R5</3W4&8IUP.V`!5^
M#EJRJ4G_,%];@\A-@NZPV2-906C$7YTXY=V(D&E_8_=$J))&(`R0I:SM_,-H
MR0+Y_EB',`VBV/?IAW)RD#MWUK(IU$)D]?`K!-<_$8^-KKTO%D@$@\Q:%"--
M)/MNK]$,X$K1&GIM(3'%9__OTF'FIK5&@%<+G-,+^0!*,:4Z+%A$0+=LALJ%
MC_+-M_?:,:+D1=[+"\"ZDC'[0[5>X<J:=6CX5.JY\;K2?`Y\'\2^P&QU=;]9
MM'S%F'<^@N8F79`I%4JX14=%\@EWIF9NG]PCE70<OTGJN@[YDEE$BE5:+1:W
M%_#BFUQ9EO#8J/8L-"V6A0N-M)B:9QG:.2VKBU<@@+B`QFF@V"/HJ>^=/5NZ
MKO\BU2,7*8FZNT<:/@KR8A5"0?V']4`<-]G^&TQJF_W)[^M,R@,-ECOHO1)Y
MZ'M%7>ZYM6MR^D7]\2\N+>/N57/,`!V:M$#KYMJX)X]\#TE?"S6)!6]]Y=9H
M988O"RWO7B]Y`.+30BJ>N0095B"VG)ZP#,N4;TK$3P+-XWV=:;GJ*YE9TK2K
M!%-Z,N0Q*]3Q^U$WN,&<6R.5(#Y=-K%X6-V5C^ML]Z[26K@XT:TJ7(9=_=+S
M?%MCL3J(RNAYX'F@FPS?OJEI*&?"E\Q=F?74J,'7Z:]2I[-,092+A^X,QI30
MLO\=6TB?3'0[SD=>A*YJP%B@Q$SW1CHM2VV;`,XS6@8V/0VW7B&J.CCJO>%2
M.MWFTP_?JLE!GZ?VS)41R95+Y0#[0MJGMH)T&<Y&]B^?!]+'W8-<@6-K%K;!
MP^*U<Z:-WFZ`PWKGC<947:F=SVFKQFU4,Y(,Y]=+ZCO1C"_(S*ELA]88:N3:
M@R+L-O`XA2G>R265T$FR`.+!*DQQPM&72W4=09'TP1=V,OD=QQ<(>?S`S&`*
MJOUV=/A4%ZB0H7+AGWZUVM:1A@NLNPW<ND^C*JF>ILZ$V,FGK/IB4_Y`87<3
M"Q%14[(O*L8)R>BHP==A&]A!F=QK%O:Y8H/(P?-&NY);M#W\T]^5/_R:I\`X
M$8$O;8(P_UOR?;ZTP3FI[0E+K3)4E2;8Y9#Z;[':MR?PQ$V1[D&OX/,J-R+=
MV'+6^E5:^'S1R#_Q1'@;`*XRZ=V!Y->E?<#S5<]!\L%55Z\MR.:7GT13M3&C
M%(S4=##W!3;+Q:Q"TEPB46''3C=NFCP2@*X\,HV%H^UX4N?1JM/IH?;<SD58
M_=%,UZV!02=(C`[!Q4J'[X4:$TYG0>3H)GNQ5Z#0WO_+6:Q'IIZ_9=O]]VF5
ML5%U6/,#*[:X>C%.E"GSJZZQD%YX$S3=3$R7RK;)D`,`A[.9JBU,$>UI(+%*
MF5_6^1(8ZX2U=)"-=F=;=;"OOOZ''W"B_*S9YSMPZ0[5.3\WM\&3IV0HXY<!
M71M0Q7L@V=C.5;"1DONPL.#5(&$*QSA2#.863YIEUE`\A+A$3W\QE/@G+W$[
M5HBE:1$.:T!B.Q\!648,!=4;I<RPVZ<ZBH[_H%&>[T22;$+>N).\"\MY"9;C
M&RR>I2':M3D3:"6KK#A+&@/SGQ9TJ`_'&-E`XL3H.8/;_3=1A%#2*LZ54UI"
M(//?I^=\MP-![6@!KB_<YG9>18KOJ3A8MA`XTVN\NV&0!X_DXB8]]G-N_32W
M*YU-5_.LD@5:)8!]79UHN(-<(,M8\B_4I^-T_;<Z=NBJEVFM)`!JU%Y8INLT
M6^M?B"8<DQ[M&C3(!""61]^ZS/"+;3LI=GTS']_#4,U\Q<ZL<N2<S"R\Q09O
MFJ"D#Z._02V;JL+:=!GKFEKW??_+H>,]C*_`6Q!,CS0='QA$\-7F5C:IID`Q
M-KK0X'7PU^2`'(WFCG1V.*^A.S7A?,>X0Z%_9=P,KQ*D#H,`.6I\).3-$9U&
M`=`:[*II4#AVM)E@!:!P\X&R>)NB!0;(82-$$&,\,?1M,(QSKSYO7QKLE(*8
MDOM15;\5)5'8\KK?=O$FH-%,ZT@&04@]NPBQ/KV4P=8MG:8FX6AJK5EC!G$C
M]^&GM_\Z0C]H%RO>79Z&2'1AKS;?BISQ:7$69+HC%?6A6>P<6:#/\NU]]+N\
M[H/_)!NZ&Q4;^_'C^20$O_K%<[TRX\J'1PU>X%$!H_W\G\0I4;OY0=%YV^-^
M$-&Y42P,0PY4I.TW=YF7ZD_QA<'WC/_<91-_NGV]U\<SSJ+5-X4A:FH,EUA;
M[O$.:T]-<:_7,C9!&(X>`OGVO:3\ZT/;C`TJX$)E$B0K5J6;0;5(2[P*83AU
MVELDG#5^@V<%O.<;IA,;<#8F1LBN];E)8KRT2!'#]QJ4V:)1QX0JK)/DI_<X
M?NE'DP?[RJCXWI^7A-;D/)<&Y?`ZL3B&I1,&&RJN&$;N$*J6.JUEJ,CWU5&!
MC=)43?FVRV!<O_%"T9'MI\]D/<Z[S_C4Q1!:LZOX^"E"5_Z+I,$!*+3H#&0O
M;;Y3HN1^^/'4)8AA\$4"T_QG7),'))Y*1?W/]6THG>"%RG(3.Q2Q(=[SO>LG
M(FBYQ;SILA[USMT':#+-1/"M&\<"-H_V<R$8<DX:!5I84631D*%R/EX1HK'I
M.)S"VGRR%;>H$DJ:."\51]?;U?^)OMF,]E/0*609_'?&$+\.%CX4E_Q;-D&#
MR4QZ%X>9`+=&]2-*7LYE&>+<^?&],^3^&B+M\C`"?T+CUF!7E;=!VRUV6G+@
M$R4[]P@95>4GD$W7[9N&\K%L]WJ-FLJD&]+\:+D6[586N<O631'0M:6=T".$
M`8$;(/G)8AMULU.(@'543HE\%6_73]IZO9?-V`V$)IQU-)NK#THP=Q'[]3^*
M<L3_[>_/^52F/?]/8DR\:EUPXOR0$YD(L.VEN[Y'L%R'(7GWPLD@1(5W`EF.
M">],+Z;'-44;+\EPT[EL#_/]5,4;Q]H'ZOH+O_]9W+<WB;&>E-;%#OAETV%.
M\&!;U+7U]"45V"&,UE0"<DJ>>0I0/`A'ND3<(_SB&YT!I$J\4CB5LJL7'V89
M3/67XU+(#UQ[_HW+XEJ'S`)S-*SDCP?5A@%=;Z8GR4:<?@S'A8O0VG'+I`<C
MAS^,9LM3,8'TN0]'-C]W`FC[R!1SHVKAY1ISP\ZHZO4U>X^V0K/*V1?9\2_O
MTP\9,1!.C4%D709WU8Y$T7JJDGU^D6KA"[M\F9N<Q-X[CL).*OX519T]$Z4S
MR"0K#:,3)&5%.O#&+FB+RI"A]GK<^)(U.8CJ/S[+4Y%*G1N$BI6K%4@@NKVP
M8J_..@XW&EN3Y.E-#.]QT'K"@!V:$X22`%OB@@<ANH/-M,V@)@J$^ETU!USS
M3J"ZL'Z2$,W"R`CM30O::EY]GCWF.0-8;U*L[/]!;7*7]=OJL1?U@DOKME9S
M$;EH:I2Y=\.D8799/NNNL^B&%0'A`V^%#\%AWXM8QZ;>5=1-]6?SR?(/Y*XS
MMC)\A2WHED:F/,4"?T9@K+$(;%VD![8]['_*?D+:G:(43W5I%HR7;7TCG4$(
M3L&O*?02\*YO2Z"XEEP*T5@+*A+F9I!G2#QXEFO+9<P;1XOPIT/B8NWARQP@
MKA"Z_3)"VZBW7&*[?;#<#W"9<LA9J2P?+2LASG!B>M%MER"9U`93I;YTXFEV
M6.8)U`U(Q7*:L[%^/,KH^KVW;*ISP)RC/E6YQB4\H?6?(/EWBHJP3"0O^+^K
M@B2FPTTDP0L5.)8D@EZ4Z;FRH(/=F#-()UM':\K,34*0\=;W.RR'3^\+58*]
MP:/&O!G(+*Q-U8WJ?N1^ICJ]HT+9ZHDAE)';,D4<5T]X:V:(E\:`[(F*<0)(
MK,L>Y`@WK8W8'SM?NQ*D7&&<(/ZHT4%L0C*$T6Q-&E5PX52B:@0ZDVM/C%@<
M:0GE-,:3>M`SBSR7<.M:]@A^"^0AV#:?.XB2G"*$.H@1!LU<I`U)(Y"[$*3-
M4'O[)V>"#>@&G]]HCFZ.F(?!D':B5+>TC"U5'@V=2AWGD&G12U(..PL?LD#6
MG7Q-K=&&(FC+8Q>HLL$^B,DU)!GLRNN;TI326742&#YUL`Q$Q9MH@\A$Z84'
MMZ4`6.N$E%A?J]?3!2CE/G\FW/^SZ-+5_<0RO.E,2J+;2#O@@=KLR1J\^;3V
MRR2*(5-*^'F@7YD)Y$V]_=U`LY,:*:DL4DECTJV@TT$Y%JUXMO")S8[SIZRF
M%,$Z+)<PIO@^$6@5V6$$(/=UOZX;!&V]J$S98B9PJ?WV$ZU=$*@2DU68,;$Y
M\R+S@TMVH9QO%I'%@WARSJ=OK)E@B"KJFAZIKGFGFR4<A1+FD"S^</H#C?\)
M9``%X_Y.4?%5#(X&/O7\&9Q%8-)/9!()BU7(ENIQ)Q\W^2V=AT*#15S&U,`]
MZ2D!A]3B^\27Q.R=G,E[6]S22)TO$1$!1:4*_/B/*_P9FAQ^9PR?(^@<"BU<
MMLSTBS/@8ZT&F"L<<8)GF-K(E1O^5'\_*!C(^,"@<(Y]7C'0E#8Z-R*['R%-
MTH=9AZ\P%9QI:.P/&6("=PG>F)O#-]1=>G3]L75<+-S>*&8R&J2PW_&?]1LZ
M$'[T,BM?/(=498!QX^])*;BTHBSA%YMD7Q62*PHIL-7FCG\!%RE,6I*8&LJ:
M-.!/9,$?U8:6:(%XT>L3#:F;].U4=T^X%.(<$%?FO-9(=K'/#!3#[L5I@6TP
MY=..L<T9E1G\JD]D?6ET[93T]7N!6=0DG;J?6!_$DA7!G=LPB"82V>9T5907
M@/63K:5$O8$8=#$?(X\Y*ET2)&#883O=_)(H6^&H@/FVZFQG`77O^>CKYH->
MG/ASFLU'D1SO#G/\Q"E?XE>5"_C"+76YO9(,,'C$`$YXKR,HO:9GJ(X,Q^^5
MB+6/$T/TZWMB7!YN-D?GO])T&O[9#RGMP;%F;@1)5Z1(Z?[WE-D[M4W&X5B!
MSY\UU&A&5.@3"SO:I"B?+S[@X6%*5.^+WP*(`2[U+J)R9&%ZBM%/?CNSK(G)
M]#Z7.(J51TS1<X4=,K*^J=HNX[N-FC$$$27R6-3U!*&-L3L=@/^199KU#?&+
M1P<D1G:%,MP@M'0QKWDG#5L8N^N4XVTBWP\4(NC8;RGJB(4_*(F&31X#/=$6
M9J(>?JJJ<'E!#+HQ4_QWQ.`T1ET.(%'W2%8A6V-]H=P4;#*B>!I+\P7&FZ_K
M:^G5Z$`C^Y1MGQV("2`#7Z;-BCW(+G>6*L5=>356?87=J(31E_:O%-7$)T7C
MZ8]-Y%,*)0;NY%UKL:2&P3K&3-A#-(U=S.JO-.'0P'D0I[)SFE*;XKKZL]J*
M;#I:OGJ3R=>VPGV<S@^`HB/"Z8WJ:;1WZ_$6-T)UL&H+?</R6U<:@6&!R)<"
M7(2B%GA9N+3F*Z_&D6YJ@`(%&6<Y`4R;0FH-^]U)`K*3BQ&`.HAH7CCE@H#8
M(-F22(H2)`4[?YW&^.Y^0L87FO%M,V#'*`.<-'SM$<;C(`M_M[>7D)U@2+$7
M1H,"EU_Z\D>X8X>GQP9FFQ,Y/JZ2I'%\Q&AYNOYV/Q733]?[1M10!1W9)6:.
M2C1YJXSUPJ'M00;'.XOY<VT\NXG=IZM!54#C70MJJ/8MY=[JJ-LFY./EIJG:
M>K<>'(]_[V_9HD!CQV?.G&:H-;T.%+77M22^]M!46I^/61EQ80W"R%BQ(6_J
M"9&A0V-6S5>][1V;@*$(57'4JX-9XJ`5NJ.6]5#%?4V\73U\$*7^(UNQ(^!)
MKOC(?UI<;UYRGX(\Y*?>1Y78;Z!LMDMIMWZS'_?:(+H#;X8%F^AF8;<GN:K$
M]&B$2I;*09EE@O/,A*[+Y)"C\)V\54P=J:Q#68XS?*=2:-WKR1.=YJ8=8$Z*
M^*7Z*\JCC)D/O'M\EO4I?SDZA^13ZO(5UF]_5NA@GC30#,B:4[V)>C-&N?D$
M/!CHT._JWX+64SB3X=3<LU)GR'S&V85GPJKK8LC09?2TW/X79`(B9@+4J5O0
MR@+G1R,K'<X3O5L%#@(E'ZRLG.6^X<#QSLE/GAK6/(9FR_6_H<L^#`\BE/DI
M$<%'$S)>0\J7-F,*N!2.PPE_0<5QGS-;61[/6G+&<4R5QT*Q`GSK$Z,"!KDX
M+P/@:B]_&BPFSC440,GD*C_4Q1OH3W;?ONQ.CM&S($9*P3W1;P3XI6-)C3ES
M@C<B%6-H@A%#555_^"+SYQ\%&#4/8NI*$LB>9)EO!**A)2A&P_9Z?"`TW.LF
M"EXDX;(4:(N8>*5DXW3T\I@14#KE<G!:O;$A0@=VQ?-R12T`R3_3LGE'<9/Z
M3C..5\*-[Y80#PGPCLX3YE\Y`R;+G,Z:F4@UL.E>?&4`[SMX1?94J;U*AM<&
M`I^$KOKD:6/ST6I4P@;#]C['*=_>],'50#^-2KNQ^-&0*PXV[/!'9,_(5:MG
M\)RV3HXL4]F-MZQ]UW]2CX!G4;DWOO"\M8?DJAO4B$K`2`ZV`*2+)PCR.?+N
MMX<!W\F.XSQ$8QJ2X&R)ALFA.6V[..L;A;_>)6)\<9\"3%)\[%E77K$=NG58
M[=G3?"R&-2,`]SG:"?RFL<D%12VELJR+O`^LXB.#M"%583VGB8^9HB4<S,@1
M_!AK:;E`6H9O?Y0FG@@:7/'?\MF.O&&;ZH&F'E:,28#<F93H:>;9`&,\-&TG
MR%5=8%5P9S35B,79U=*$1[R9A/[7AZ?*_.),9>INH/QH<,QLZ(_^M`U]%5IK
MZWS6(R*Z`D@.FHU#2`ABG;<*L^#L0;M'6O72>S4,#J%-&_&/.XJ0XAV$\_K_
M0T\Y2!PB%4_!>+`=]"^6"J(+A^2VU),WB9?UA#(E=*L;G<I3CL)TC(:L)XO^
M:2,"55#M!R3N@[J^?7M7VW_9C)]F`BM$BI!HW>:XM/B"CL(#SX9W'U#W6J'"
MPC?`JRCA&PJKYH2VGRVR-.FHLL7VB'B52V3(:_XZ3'$^,&L62G9*)TUJ?Q$&
MN[$UUZAQ0C\QC69Z"1I$1V")G2;?*'SSV)Q&5F4F<S9M/;W",ZBZ"KPZP)Z!
MI]EXA4``D"55^'>J?/'R%N:I[+;HR7LEA8!#LYEU'TXI5YNP\8%"U3+4T.9$
MKU>7?:P\SLR@.CEL$THXO#W/ZNL6^LFY:=`N_UQ/)M",R;ST4M**J2%V0.5L
MS3VDIF0,YF->71VL[4PD^G;H1H2AC:U!O/^<K"!J1XW$CA=$@!LG8(SUZK)G
M'D.F,@JQ-+G[OAU>O(@)LY6&&'88A<N(#66^V.#(7L2CO675B%SLF4%8V1H#
M/()T$RV$2/'&%=@[JLA\#WK8HX5OD?-GT[0Y2$TJ!NQ!&U\H@4#/*YS+P'7L
M'DU9_T2.?`NK@4+$FT9N\%#=*Y=.SO7:FPY?.^-J;M:0]=GNWV'S\>[@X<T*
M+D.?@XBXC<)/&FB@$.E[Y,+.!B3R&6]?K''#_+-$_Q_+GJ!E9ECO!W=ND4JX
M8TGNFP\,,I(X,W1<6[.9_JX849LS1L]+G`9(>O:D(,4-TJ=R9Y8O<=-'Z;#7
MWO<]64[J/RU#,S!BC]^1=T:5$\.3*^UY?>ZQXKCWO1-YX"4@2T;J&\!RSG)J
M*'9<"K-'RI<IU`_L$\+XPUY]0^<1,V-#3T9B+@)1O15Z_,CB`?2BK0C=1375
M]?_/(#8P=W]9,=!O*XK7.1^1ID\KH"6B^\\7*AC%9S@%VI)A>1:SPK"<)Y=\
M8_F#`VI0.O#SJ+1<_>L*/MC(QWM]J.&"<'\I=?BW6KR`U6MSBG/'>!(M#,-S
M-EB&0G9PQ)XCSC21IMRJ&\Q*C?M_S?B+M&[=X5*:O9)<`O/8&(:,?DH=QXW]
M@XQG]$!&AYF;2)I<\N<,XH4%]6P!$BH[Q!AKUT0K<M#2P>W76*W7@"H5E=\%
MF->0EM=04KP"1O@G.Y4EH$M*S`)ONA@6*S^DEV"17J9O+SJXFF$(`!ENDW._
MS^8CZQ4T2Y6/6(UK@RS&S_SWV90Y-"WRD1!A$0V4U2#2+X_&/<$#6\SL$SM#
MRV%W"]Q``8A;O=V3+_LCY%VDCB)KL-<'#R('?\R]61?](("1W'EFVV`)@2BI
MP0(:]L'EFP:_4[GLRN:T@8E7K%-TX14(KE-(FK_J7GX/QT#='.%"\5O:2NRO
M)%GPVE;U]$K^FT34NLBT^@0NG,-%X]2X)>"V]<JU89##(I1C'6=UA00I*GZT
MMPB-):"=1MR7#Y!`,N%%Q7F)D4EM^UVIWEB=;FW('`(6A=(?N<`+#'J5T`3\
MK65/#NP*@+1NN=LRV)Q,\FJ//@6<,X$S`8+=U!#!*>M"#4O&VR>O]I2"[6OR
MS\^NMJW7;H-ET&PY+5IF1\;)-$9Y7!)QRD_35W8>58PO0</BK"`/+)1=.R@O
M52P<$2Z(3."&K**7F7\+"<H:&#\FP\73P]>5_:`QM%2X-4KEB6"GL.,9C[5H
M8A]YY[:6.*DZ[+O45A]OX6WD!H:S6HF"D]@TVSZ_"ZM$B0=2(6)3&'@BJV^J
M?LHX@W8&0`728@'H*4]G:">-%XX]D<!OCV>K*-\=X\B^+E,A1^P52K*A$$2E
M;O];I_[)+,7J=156$K/+P=6+S/%"8OHIS#*LMWDQ;:#I7K>F6*1PBT_$J#6X
M:6N=AD:3GU-@A2=B,O(\\,)-NZL9!$9R:^VI!V$,:>Q"-*TZLP=MM_3S*^2?
M);G\&?.;Y<,R`>C*A`'BIC3(ZKK7PHS'XA?J5%UFIWZ-,R&0-3H2%LY/>)AW
M&`_A<B)O"TFD?7[C>"&LB^#F?*AG6QIT&IRM">[Z$">@YC?*JFF@2_3A?(DN
M2_&=SN=I5B>AZ^XU3@$E))O3W(53W(^DR&H1_3.(=LG(5C7.E<E@R(BMA4CU
MO6A=WVG/&6D=B([Z`L/R,T7[WJ65^\X/J@80?;?I]Z"9QT[FL]76(UYPB3."
MFYR3["!,<JO3Z>%B='JOZ@S=!%34;"`Y8B1<VN]HW14_P"Z(2BW\8KEZL(+K
MJ*%$>EWL%GR#S0;Y)$;_1EXY5?.*H5;4E.;+HZ$`91ZB&'SR-#(KOWS$ZI),
M,Z]^;!I`P@8%8K\*;ZI$M/&E=:;>7&7`KRF!SYHF30B@3S1]+DWK`PZH\?0C
M=%Y[2'?T3N'\AC`ASN&THFD')+J1<N83)L4/)94H3:P\/#&)K>(RC4!6#![W
MN0@6Z_4YT\MV-I71.B#1V9#@(WDSA$2I#D9(J0F4G>%GJ*X"PCBO/J=RZ@M]
MXG5VF@*NWH#>8RA9KXF*H,+UN`J[@=)CR(!!K8W5`FC-+X#)UP6,>4S*?Q"Q
MM$1#ET8&&]*U\\7'?Y1,S07L-=)T[DE,(MKHC#8N`@]*51(67.$CAA#::3[B
ML?CQ1NN-8SP/E!\9_]MW6[FD*O1N%H<+6XN!$T(XD1FR+R0(.HN2(%B4M16V
M9_<1YE03_QSA)$Y64+T'NAD;H)`??09\SF8.`\MH$/@321PUVOUP>"C@6S`9
M#BFW"X5<]-$=[B('!ZWXY[EP[L-'/V]M"O=%7-644#BOD,V;UPY0^U0R-Q?G
MGS[B74`LA'/7:H(+A1C+R\.?VZVK4K28=[$/=.SKGT82#2-K"G@B0`82.U#V
MKR,3#@#YT8/'NA\RA3T(8;ZWOAAC3X27,D99-LK1F+%2Q4T\"'7^@P#SI7Y4
MY+S7GV1$>2YD>4V0LGQ>:H_CN0VZ_UFH1M=B=K16)7RLW)*-GJ24Y#QH!67W
M.#L+\K*&V:6U\ML;-4#P72;9_YT6'LG!S39PRW&>SW.<S_NP"DX?`^*;APC^
M5W%TA(M>CLQB'9<(IX@[*OMK`S'LM?ZNF;OYIJ>80AYQ(V92Z)V#O,B&A^1S
MT$[:?5#<U?P(*:%$KGL3P#,?M&MF=EIZ8ACD8=\J?.)8X4C6"?PXTX*YE$%]
MHC>U!GI@,-E*^18#>F:4;SB(1<3]BW!E,7OP;]+K>:$&R@[[":9>=)&T`%X\
M?&%SEBI*,$69WP03=(.$3:TDO)2,QUQAZCR7ST4%A$*N8+P:E9>Z47S*9N#%
M50'I_&?V8Z5L1BQ^#F)E%H_&\N&ZY&/.6TK#6:ZE!P7!@AZQ8'K&,'RJI79(
M946\)QH">W7R1W3Q_&PE(^+MA.&A7<-]R/[!<!9?XJX'I]G<+G@LI^G?G.PI
M><+!+R=:N&I8XRJ\XNNC/,`]%SLU+JQJS"43LX*?T7<#$9M-EWR8[8=#^7<$
M5E$K.T+1P=?3(1SDHYD!)I_LPW)#O2Y"FX1EK419:'T%BFO<[85%W$M4J'S7
M)C^K2\NI>3>KX,^4E02(C2@QE[>)R,#?\E>7W1[Q];YMU:AL-[:O)#:+8%R"
MN+8>[\HV@R>!HAW^0,NDS5O'7/UXY!=PZEX\\*$EU0T+WQ^)`O!;&]IDWT'Z
MV;F((]'!RJ?YI-4RB#8AMJGQU@>X2(H'U[_X"?>\QZSKTNJKHZB.2=\GT,XP
M]6=VQT9-'[9K>XM_"U&W_9YL\/L2N<#T4N)`K)C=+!'Y/FI/:](^84-3)209
M9",)^XGV_5\,!=G%1&$;2T2+><83,>I1">$[[S]RX8FLZ.1LIB&3N0=%/V%V
M/DKU*B1L4.3\:'6ZVBKD55!F=$Y(0/E%FZ.=@^W?_K5S`*FC2;<($')UH:_U
M`Q-8[*HBD"_7<$X7?K,&9+I2YXRH)Z%W.Z+4S@Z>*G<\>;M-KQ8DF-Q+^[!E
MX&2BL""@]*$`DUQ((#!Q`C?@PE\=6#-;'*5+.OD:$4U*0(J(.\OWG:N=FF4P
M%,#;),C>M4Y9.L9;-Q!)<,@S8?VV)DWHX](TICA.*3S>0R'Q0R.Y%?OI'SIA
ME5F"G(JL`-#^)E(UJ!E[]4Q5F""*9O$@Q<VD\Q]MW)Q6\QY=BOP2R@57P>;8
MY?JJCRZQ%SD67290/QIH$-\*1`ZQ:1FU##GJ3)VTX@'9AE._`(("=+V>3F7Y
M#0E)FMQ&7&0Z=R!C!Y$X+A=*X4DUV3V2!_HM.(!,@`?[%<Y)RP(UYW>#$X]6
M%/AM_I>EX#%:PG5Z`0Y9ZX-^Q.W5<=-1=IK!1;4`^1F*X+.*^3,@0+I1&N$#
MD&J$0[AAJ(@=H?.+<$6(.KG0"_%>(QW1F?&YDEML'ZF3P5Q^>TVO,D._$]6M
MC%"ETWQ(1ZAI7.R_UVPV3<K8,.#P0#$M">$<O1(L=Z#'4!A2D7<]Q%,^S8Y\
MQ7/JD,?;A5=+Z9'R?>D]CHP$$ZF;11SBN2$^Q/$*4]VWYW;+-DE?1:,MQ.U,
M/B^!0W)!RMO2%N$,P17&E+V5#D+)(B$C40]G0PPXYRD+L4)C8=D4BLG/@'\J
M.J,:O'KH!]">3G]D3O=@$3)ZXQ@?8.T/;Z(OK'C1@@Q/@[";'&J)J(7C7EB7
M"6`AB>I5)K>:G,*5_D^O5%I&=\=K>)1K3U`UW;T/&=6`8<SKML%%(FKOP];J
M)B#-Q,3';H+UO/[I'=I!"5*J+,+X(C:RE_E'9]?2\\I//&'?_]@^J81$//9V
M+)53PF`E0LG<D'F,N9Z#&C,KZ]WQ5+?'ER?T:'&LPPV@_)?X\A_Q_1[/U%`7
MK=6/N((W./^'3#KLK<XD%JH]>V9O$NR2:RRT7+M".!AD5?R#VU5/]UXG!G".
MM9R8I"@(=RR5A0]3H]&]Z2;^26&)$A9-N#-F\7NTN<^:M$@0H*(F_TX21^19
M'I-DW*:?#J6W(E)Y<`E>ECXBT5/$%#B*;:U?&G"QS=*:PUB2!H<HSX[N9W]6
MR2NJ/D(S'IP_%INB4,RD5%./1BU_4?]FTYZ6E!PU-)8(I#%4P!:AQQI3HB8!
M7R_H39]M/JE:J>_JA<%,2V_*\8"^.\1C5:2AN9,76.9`;6X0>Y[,2*@,+:W5
MO86XUKN0^M%32Q\G!^KK!Y&C#4J$[(A792^`_D6`BF@`_<E?9Q.)X/]#0?;'
M7`@4045Q`M#\;$&ZNS'+AZQF`#QA?*]-=VX,&NSKR[),.$GVW7I!D<W7_,+Z
MDE0+=V__&#1=3!!L=.=A)>PTSGL=)O9KTS>J#&O^S3@.LK'XUZ(2*MIV]8ME
MN=1#21\8?:P^R+WJ6M<4K&,*^/,K[F1!]]D5'\D`B$]\;=QIP(D4QIO`K_"W
M"KOCW8Z"O0LVI/HE_-(/$2/JJL`N1Z6O+3PBU!J@EC;,V`;*G#;V8R3S-TV[
MU5N.Z;-1%X<5L7RT*%O[C/P?:W1ITP3XWHM>4#RE%,?<8(7?JT8=VGW(2KIW
MP!6"1MCZ='.#8D(B/'I%CP.YO>!-DAF\(X*)\)X@E#6"GLZF.HVY+O5Y_\K,
M2,[#;RG2E`B*M2]V\[(63SIWE$23[2.B.7<X!3KBG9:EP08JYH5D7;DBG)U8
M+E`GEQ$41%'T#(DRP!.>%"2W:."'C0B>YPLHG>$04!!`AF?!GFC,`[%RF3==
MD[$P0PH)AN5)UGJ0B1ZO7`>"2K'\C&#-):[G9OEK[8.9IB"&"Q8S!11]_#D)
M$:*S`L-#`=;U_?(^0A01)2=<#XZ]^&_$VD**AU7LWABL%ZGG*@>]Y_QNY]&<
M>:K3UTWA(@-!(L'7EQ:/T+7KFZ^3SI+,0[[N>-N,!W-KS.5+AGJ%H)HOUFP&
M&'?KZ,K*D.3-+;;E;M-^I>@QH8/5,2B/^#5BI%UZC*K]?P"D&:=Q>[Q=\?3$
MVPJFY7M!DCL^$!--'H)ZQKQ8(>D>;@'TPP6JQIY,IG-7_0A*]:4J^CQB9L\9
M5$0<*!UAW;L#:N2RFJ+>TY/,.;01]AX`O(I5VFR%1(QH^V!X.0HP]-.T`Y[,
M=P-Q_:`W!R`77`=&Q+>D&T@1[WX7[&$!21Y4!P#HD*)?W*C;_K]+#+<4%\+L
M'KHO9+_?-5``IU,=&"_84J=5,>R#?).2MV@;,V;_Z.^Q8RVG&CRF?#Z89HT^
M.S"OF3IU#M#CGN5_^GE83LM[GM6K"W5,"87IYK)6_-J8LWKD(P_+H`OSX0)@
MS8&06^F_CTR1(TQ\G@N=Z%<5[;$U-499*.3>#N1QGH9#R1DCK[1@D8(D<UTH
MG]SEY8-D':[)V57D05LJ)_=&Q7YS:TG)(K&?OB"EWP!]DA55\<MX2*=]0.>S
M6K2Y=SV'ET]&S)X]<VSH]3^L'NNE4YDA2Q^H=>/XHL),A6'LU;_:Y^S@UW>2
M1!`^R^BPR[NWG$K4!K*3M<)H-+-`H8#+)R1"=V_CMV<#'CO!&=EC*F$.D*"\
M$=B(_,$]OD"!6D2RAJ4@SM/L5U+9Q!)%N0*2>KE)^+<[-DP0`B\V8-W]SC":
M\Y)/@05"3:OPZ5@VNF`M^2^)&F([L[K]^`0_DM:B>/Q9#V<.B4%8?SBCK5'`
MWIF-W`^S(E6QS:KIPH3`%7!@EV0*Y%R'G(8Y676`0(&D!IT%^,#//,<(_I:7
ME[/[AUG*(\3F^I>ZZG_B;0*['DNT#$O`E]H70NH\;I=7CX,>Q4M2!2I/"1LD
M9IZ^%=YYO2A::RA\_")G`)U1;+=6MM)?]8&BYKB8&-KP*L!^4NU;HJ'I2B-=
M)#[3TVH+S*PG#`U]V/$<J%G>E$AJ).KL,5<)2ABWQ722+6R\I\O*CVWO\`!#
M](7)?B+KD_Z(NPA)ODWB<35(G,/0&3IMA.M&8-8\/&%[X8J$D,/4`]6_+'.,
M[O`%QSADA-,0'95:'YWA;7]'\\QLGO$[^/$.$VS[Z8PR$T/"+$:MD#Z&G_'6
M+7/VU"IDO'Q.KI-]-ULX&53/7>@%6NO3BUF*.%#L^5@$]7'FM1X.B^<OV!-[
M>=/ZV39'SRVQAU%FVYFM#MP/S9\1=$CXR[3V)W)L$76)A3**E*9>V,=1L"E9
M44PJ`E.K`@";^"1]CB!+/O@V2+AG,C[I`4Q.C.Y.6'2F^Z?C[U?P3R^3=Q4X
M/B:Z'P,GQX^5=XZ_=\4+ND']1YBJI(++.BM"&A,6DEB,1YLK*[:<9(:F64*.
M1V2^?N"!_:LJ:])@'11D8Q;_SASR1SN)DG]`\D8`/<WU;>\`QP5P'^KE)J=E
M;8@U"78E(<C"V7SXX6>Z6:9B5T>-4C<DB4W'GO,-V"%\Z6;'?BP+GQ<?F_[\
M3#:&O`"M#X(W+X/$W,`18%MB`72JCN$9GE]+%_R#L[*+,-3T)QO*9_%,]V[6
M%O[+HOA\H.GM)H)2OS:H-YJ7)_"T*F1KK1L`F'P`^=EMLSCBTL#<D[D0ID'/
M45SF"&5[LD=U"36U=N5>UQ:O-EL;DM!\C7HJJN\+UHC=$0)=,PI03(IWB78,
M3A#%S+8V,1?6RHJ]:*FK'/6R734RW,G?B#IN*8PD$2GS]!SET?&T7*E'&\6H
MD0,)1I/_'X(*+:G@WF->M&C7R[KC;9A@$/Z_J]'5DKPR0>3],P\Q8Z[S*EUO
M3SIHQ[%+0]).,F'_=2(P&PP2`JY5:^,I*PEFD*QQZ^5%&#>MEP2@W2+);_I0
M:8,YIP6$NU7UK'5(\^1\2M>MZI<U<24C28&DV]F;8I.]?)966>:?MJ5=]:UD
M!E>.B$<95U*P+XYQ[S>]NF8T-'/QM@*LU<EBUZI,0L^W?#[G:3A/.D@J95M!
MFA/$-F!U^J-]3XE\UP_8C/(@FZV$4W0I+]Q?EP"1+?=H"<.(.!20DD!,0&BC
M#]31::8MI8AJ+T4N.L4YF`=+//7TPUX'-T+2KTKQVE)GU&O%-!H)@#F9A.2/
M('%0\:S&(.Y*N*4`.[RP]5XON:":V";\K.^VYE)P6&*I;T64RO,@SBDR%#&3
MW<VF>>IT3:\00$NSY5LQAZU&A:MSMSVQHW+T+G8GAF=L@:X?:WJ-5/KY?45M
MH@*N&@JVSVD2M`/Y1V(F$;[/86>:>8Q/8F,=3P^G<NP!08%G_VJWETA"0M$2
MMC[RO-\>,$Y2(76C<_OIN-7`ZD_K-&#S`<\\QP)JLFY[`;FDOVC!?U]^KH8Y
M%"7#).9HRLI8L76`YR7AX]DX0!G^(152_`$<X-CH$Z+>]-M1GGDPV@6E9T$2
MQW9KU/"OY>-1">(JHS0&6:W-?K.'\1$@*/-C#T[IV5Q@,CR7@Z%!<%2I]JW8
M)EA`LX2MJB0Y>T78G,;";HW\;)`Y&*&8\A+\E8]$@!/=0=!/E^KA?LW#L![T
M*OPU'!@(\?[>7\+0>7(20P^O>]ENST_SZMBWR6!B.DB^(*2W54WEC864^?(3
M;E"1\'A$5[O$D?FE%&L>"SX@5QK3ZA,<_N/=NYW-NC0Y'H(2IIF)%`7R6`'7
M!#_&B)R*YO(Q%-M3"Q.ZKXDV2UT[^=F:E.M1I`4'P8X%7R`<50H"`G!0P#2<
M)A87P:T:^B\NDO[@1S-=@EV>\3LHA`V\4`^!4P,=:.F7!<J$]2(@<H#">F3.
M(UJ=4617J,^18:`OW@H&,?EK8,*6;PS#89>M6ZMXX?NSNK((^!-"FY-XL:Z*
M<"FG/B&$#]WNCO-S,IKQ4YKQ":V,`2/&?3YK([H4C'C[,@HY7\KM3(C2`-!G
MZ]8`-N=6722&S3G^-10E'V+C=7T;THQS.AG*D]R2E@U:SJA*Z+5I1`D*A&RS
MIH5`'JKB4X4>B6)F<[I1&:<4GN0&Y42Y<#LOJ".F4R09Y`:S7,A"4X&GCF!@
MX#)1!]8)`]7/AC+:MP&1#?(4A^_WMTG8SWS:$M\Y56ELV(A#YC733_<;N=?8
M\*Z3'[Q6S@!.TNL*\VP6A;1UCK#W9&(Y8BNTM[->4]:BZ(I\S[3HC$;:[I'6
M;LU=<878,ZTHGY3I^?]>@;2N<ZP,7`K5,2):)V[+B>_=]LV"8A0-UO]W1DC1
M3ST1%[XH$!CMKI/3]LRG>R(=X@Y&20ZR!$!F23OMT3?Z\Z-OY0Q*@,-OX188
M^L45H2Y/T'!CFV[RDG?1:)WZ#L>N'QTQRX+79_\\C>3!)02;PJ(N@`TG?XJ*
M\-7`K5EH]"^[^\.R%21O@W+3,0)`[(?U]Z[=X-]X_24.5':CJYA$B-R":)$-
M/>!8/FJ+#;KPG>`Y.$;&-Q,.)\HM.LHY)J+;@NSR_VF^RC`RC)@$$LILAP4&
MKP=,.`X^]WV!W,EH?'K[&<&=WZ(&Q_9?:@ZXY41,T6\Z3+W=H'72&8,HPQSC
M*IQ*I1X4A"*%L=>WPJ*K!!37IPK;_LJF),9#M=C7_+61J-H8#%G;2"1(S:9M
M"5'<8Z\_"O*/K>A'G]D5\/[TJ.!Q",QNFI&9S,W?3C+-6GS_W1KY[1A*S"IP
MTP,%8WT92$<HM8>R4T"CBZN-6#:GIKN)/6IOU7CTUJIVBA_/<DGAEC2[Q2/Z
M.(X4`!T!I.",X<::U\$B&CZ`83L;I1OYQPCULN!Z-0QP94]3/Q`L8P0=[>^C
M3^+R8N>[!C%>H-!6*X'26`O35IY#+C]`Q57IN.DMD8[5_QR'V-IXDW+:_>[@
M<ZH*,*4>X?ON<#H=I;B:*/U[]G-^X6?D1TPD]UMNO'=1WWV:GM51,T?[D7PF
M:>:`*>GF)G2932\"POH$U=ZQ=`YZ(0?76K_!WZ--3WQG])X_*CO64B)TCS$(
MM*L9V%JO\80E&Q]H6G24>+&!HQI-75,U-[E'3+IW3BYUDNT/QV2?M695,Y%,
MO_JEY=T*`K."`Y\1],3(,?#^8;ZJF*L833=[[N@4S$83ZM:ENI#5N\G;206X
MBN/-DPN,<G!0E*('1E`,UOR=3"):IQM4CBMRSD.81][MX&.@U!LM:$MHB%Y/
MA\1.R-.6$M:0T#XWOCK02)WRKWG;\X*@+TU!W(CN5(BXT61:%[@Y`!X&_D.;
MK&*9IIMC7R?RH./`""#U9TWT.A%^(8%5"+>QE,U,UCM`NJ@[=0HW%\>%\5,'
M'!VNFSG`V4@0'7Z/:UB@=/(?(MRJ_9L;@?S0#+Q5O?8Z-)0$/7K?DMWQ&Y;-
M%5326F[C""`20H(DOY.]L+_[^Y;=5@=UQ<ZY>898K:,X1\$3PB@T*XDGY'1L
M99W&$G58];Y/JA")[Q)H>9VM)02V-+8KC&WFV)_`#FFC35S7UV7*M:G&S\,T
M+$R&=^"Z,@E+H)*^KF6-*.J;A%B5$P+.6?9:@FRS8+;5J6Q/W.G24R'N"%/=
MI;I!T(]Z6CZ=%<NY/F';)*V=OUOD8"8HZ]-#M4/"L/8=BR<;++@XDUB#"*L_
M@HOJ1Y;/^X051^!`XV<B7<3TG\OITUUDYM*(:@A<"3;W>`9\"@')-2#2X&%4
MBI?;RFHKH+L:_U<H:UNS$<*3WP2+9'V41W(CA#/GTS8R*,JX,LFE9,;NX_A]
M-CE=CG!),^[K9P/:FK_-&G\(K,S;2UT?U!PIJ3FTF(7;&3+]9Z_CA]7CI")=
M129XM`8KYCCC3ISAN9$#*<MW#4:O;TL_*4;?C)GH_!6?-9,U89*.^LI_>43/
M\;,QQLXK&CFS<C77O7#$SK_4M=H]IO.87UDLSSO99V;BB1]:]K1=N"7CU5'!
M;%A;HL$!1DG`8RAWA!8OX=Y(GRQ&:6]A#B_QK@8'AL&Y.FUA''F*+"NC6#ZY
M4>J^&_;!.D>4%3C4![Z#^;/`N0*[MXP.'4;2"`?CA!.G50PC,3^"1Q.!`,L#
M-#-1*IOWL842LE)UF"\RTZ?>]_0?/Z08F89+]<?'L_8L]U\IHL9>BP%X0Y#7
M"[.*EG/0E:I"?%CTHW>O;*O)"H9I5*::#F/$AO/^^$[C3[+V2,G5W,8VTX[*
M.K9:0],(CDC?4/G_4X;E/J`5EU<_SE>'_W+"Z\_MO_T!`MZHUFGWN<B'>4>;
M/V8.F=#3=6S4Y9RV<Y[U]5,J(T(DA7/6:NZ-I&)@RDPR%CVGMM'0K^8W6H=]
MO7FBX4PL1BIY+>M"2%R<,?]J2WW@)GFI@AINA@XEM4:DG^19B":N!ML.R827
MJI/,R"^(4113W*F#7N@W5>L`.UFZ,$FQ?3")"^,$GK#O)B.K%CAT.^E\9UU2
M-EVK0GDW-:0Q;R$#]65/',,8-P*G?TS9UBWD5KWBM*K*86XIN`<^$R;@UMF"
M*KW(R<X4&7^[`%X5N?PN'M!D9_TD".,($PG6#4;#.V2"#,DO?TAT(_R0V^_<
M9";JP^E0C,X\EN$PP5A0J];&.5V=A>%S4`*/;AU>MB!'5%S?HSP!$=54\8*?
M!?+`2<,&>L$BD-5WH'V;^E*I9A!=5G5RH%%Y@;W],^8=.?\I,?NS)^L9JJF:
MP%E>$B5XZSS,>LID$'KHQ!)TTT5#U#JSTL.+J%7>.['YI@WG"\[OQQGV1?RP
MM"7D$^8Q5MVB%P`UZC4'E%@RO=A[S>GTB)CN_T'&8,5!HG41A5<"F9L@7;?K
M+*5!Y2T0T5YCE4=N;U^<VK(RKYBFE2BZS*<BI:P["//FI9[09;!OZ<HUS=F%
MB="0J5X1)B9>@XM\$A-NB!4!O]\%QSQY9!:Y@`420<7ZRX59,["W>>*[QF>K
MEU4WBF2VNIC*/5GMQ1?&4#+<+H\^5_T%&LDN^UM/#S&8!XET*<*IL3P\5EKL
M>44A$N=F85RQNU#[8-5RG37>T<O@\1^6+J#J%3@2UHN]GC0[@FT2Q=D5L2]Y
M:S[SO>1)UC@%B2[T_]C9<9?`P(;*+&`-*$E#B(L\SG^N.1KQ<J'.9Z(8NZ._
M@"F.ZX]7W.7P1M(A]4B<OUZR6D;LQHB9C+!]"TB6$HM*1IX2]8^W>&!*0H0+
MBEP^A=R:_$2W([#+I6QC.UW$<D$")U()MX-XU6]P)H`KZN\4!?C)$I=BV_'^
M4C)[-J5C\N[Z2;!&H:P^:,!2S89GS'JBA/2Q(W<J)P'"P'FB5U670MO%BBP*
M5WJ5+A[/8WW(\YXWC9_Y(-WS^D:J*!<0>S]XMRV2O;PQ^F@J4?NT3MB.PHPS
M=7>$_<1^/S2YS:NUJ_U)CC/-T84&3+N]B?[)8(G'C1Q(_(QR6^%#"HR`>W,`
MEAT?S^6E.@:8=C$D=8AJ],WG=9[$+EU?N?4,SRAH4'KY5N\>^5(G9;4)F.GP
MO=*+)U7CEGH7"V1=1P_\KLWW8*2Z_)]T]3HHOC-P^U=(ABLZ%P/+]49HM6WH
MRQV$.D8;>3<%R^LM:I)/KO6FDHQG_#]-BP8N>T7[X*Q"(&']4H"&R=IY_#&I
MPUEVFF!YBBG]"95]>BN-GW8S?=4$:Q[1L:%^`G0!4%PYKJR]I-WLQZS8'Q0)
MO=Y+E="G3\A9L-BT',MIR0)A8!W4%BC>+=I#KO"G'8?Q]?*-UM$8;=5>8.2O
MM'_C)<CVH:K9FQPC/'Q>N/\+?O[MZ=J/QD?[*-&<3SPH"3L+)PW!LG_9_4\(
M@7.MRK"$1CK,=?XD&G%P&(/=`X#X*=7?1VY?>>-Z,)$X0FFTZB;-B]7GO(,]
MLHO,#Q6N37/DGJ3;Q6GE&KC:9AH:]E]Z;_XEBO]GT#V$4HG%<AN3L6W[Y;MJ
MC__[4!U;+=E^=:AM<:%QW5B$==6HZ72!_]MJ72JBO>6FX:'HQN"AM6K%OS@/
MLR,8V@KU'H0MG9E(EIFL7&X[>CP">(DOA2$AF+%F&16;06+]`'7;G`GS'XR!
MVK([@.N\UU;U&#8G">QSY]C3+UU6R&J*AEC<:I^&'O3@V:I[7QI]05OW:P!O
MHXX?3"7`3^(I+PHX4>:M"3E1,X\00DT_E:Y0Y8I*&IF2P#]F!3&;N!8Z.8FM
MTMX62#Q\ZI/^)7W7U)&`ZZ7/8[O8#WMA*N]UNO:]>03`@;?HNN%A.;J%QELH
M1)=1NWEPPHSWN=(A*3P@KGBLA?&>C0=P(F!Z*K:>U>;%P(PR:O8=7S2Q:B3Z
M2Y_1V"I9D'56$-_U4I"HGV/BH,R8KOH+TS"ZRF05J.YE,KT]X>'()#<*$R85
M[N_&J[S8`=X:QVG'IJAA-QV&BO#[.6:JN,FRR+SEHPGYK;P7!JI;;!:E05'1
MV@M2PA9$86WP(#APNO,8.2DX&-T+K84I5]G+$=4+X8AH/2#JW7PU>A'UE;\8
M0"-"P.#MTH#BW'E./P<@X8J1#363*LC)E/Z^VJ.3`]2.>:RG;$&I0(,/`YX$
MB/ZT$^[K)J7RJ^"5#E6PE$PESJU^HR87]_<\+VTI-*F/Y7CG9;LJZM5(PR/J
M#[--3!Q0)>KG6%]]-*4WYW&!0(@)NU:^=QPH,=/)TV!66S9^[RQGJ#[6:>$$
M0*0[-$82P[GGB7Q"0.3B230L8U$6GYWCF`W`V*K70DR&53RLUZ]V^&U8E*SY
M>"&U_B.#V"[\P`X>LUF=+^5537E_7?FTDU`D[+-&TH[\,LEVVQ[TO[N9J,G.
MHX215&P+)O7X7!,&Z35.\`:G_551>C/0R/NZOY2Q^J4M\IUM*RHN/N(\9.`Y
M>\THWE@'/^SM"A&/2V26OZSAE."?9;=U6"4A=CAD^NT'W;F"9";2N0AUWI'O
MC/17>J;\"C+6']?.V5O1O=VHNSY(%A;(4^K,#/L^\P8SC=C@X+**L5!100HQ
M.3WP)[%AXS_N`*A76FMQ8/?`\[AM%>I+GOIAV;/J](E2%&@TIY]+:JBWE/`P
M`&<ML+`8MC:^D:%0L7-ICT>-T9Y+,(9SY%2@H[G7!)5*D-3*2-%6+*\<:RD3
MO*U*AT^=XB5.DJV*'-U[;W.ROK3U-;QY,`1*T/:^G/)U`SYW!8&XZY^%S>Y_
M0.L.2@#U!Z.WTUFQ/UJ@-87M;"8-T0B>]*O3HQ*=""#W?*NC"/U5!U\1)%;N
M&`"HSE(.X@.79R5S_\V*P*$/_O5[H.AU\D7S`Z0I+2@E4[,7_9\C&[@D<L.J
M!<;%HHB,&SS^@"IDFJ&YIG^^N:Z?]4(!E$C8#)T&UVNI0%2VX7:Z,SBH+H1?
M-P)$[?WZ_^8N!ST1DHRM=@"7QQ_HF&-EN'QP.O5JX#[J"S?<!\BAP9&[1&9P
MTNI1,;^5A"(_`T(CYL5.&XO87,-0@#C9X568?R7N>+O&/AF:&);7L:#VA[-S
M%E5/*]@D]FXSDN3P+_(64VT0YD#\1A#92\?/(4@\S2SRBZ$U9&!@:B&F'VAU
MP`US-!MV<JUFGE,<M<`L5VIW-L<@T;>^KTW^$NKFD2%+7VQJ`/:AI//BK2GH
MW`T!5-VX&N7V(TXN)3#6JTI_APZG#X=TX0W#2JO"&\G*H+>Y*S1<H#N413AH
MB6W]W;OY<?E'%ZAVF6O8OK_Z=K^'N.Y%`UJU1I#'4[`1#.]HQFDU'2#^!T@J
MW[CQVV2`MS%%MVY7B2,49.>'E"HH,>,FRL&:3&ING4T==?,]0-02R<IU7M'P
M7,%-`XO_:,4)@NW;NT,A)*5]0OD@^(5__;FEC-*B`-(>H6'-5$K\SLF=B0*4
M8$WT:HMPQ_()DD"9#^8V?6755FO-EGFK1*19=V'/,9:F-V+-.MIV9VO<41YI
MP+[>WE/J8_E-1T8/P/6`5C1`63=XKQ'J/#'TK$;[UO:^$D&@!52G\H9!/995
M@O2^ACVI7ITI%@E)X=[E7]-Y/U8<\=&7#RW4;_P[[H%90QFJ"P](K@I*`_P#
MF]9%).VB88<XA<U,AJ)72+C*%P8C:UDTRU"OD.G%MGS5Q2H8_?&8%/R1#`9J
M'"RN`&K4LS2,`1W18\C9R(&IV[S+%K<VR=PKCIW];38J;,H*$K4D%$P"!PL0
M\46.:V]X[3`V`GE]JP^#GI4!TC<,-V;L3S1VC,POKG>'-WC#G1=$'\W>8K]U
M/QDV)N6/4*![9HH-:.1P5EI9+TE^"Y)J[LK.91#*-&I($LV3C-=%P3;SJ]T`
M\PCROTU7T8Z?$:NH'F7G*Z6]"A_$M\==8PS92?EZJ>?"EACG1)ZFAC%50=X1
M'D5G+O(.XQ0*JO4>*Q#BS#_S'.D(Z`J/PMV[4-X(>Q"1N;6(A+9&H:^)X>[7
MFWXGIJG&<YCSHL%M=EJ=6WBH%V4G*W:M<EZXKF$AFRB&O"OYAZB`!^EIDD*]
M',>U*R3",V-?]/.<B-Q4MYYO\B\HV)]W,QD<Z"]P]/?FQOQ;NV.PYK[.;Z7=
M>&^7JR!2'K\EKJA=<HQ6.,JYQ=O2VU$V2#<'C9ILSSYQN(Y\6S4&049!+`IB
MUZQ,/*<\^,TO<TU/MT,SC5T%N<N\#M*8Y_<?1^RA=*?RY<M/$8[9E-N&"2Q:
MUS0J"WZ,F%,$%T,5/R\U*K,L%I*G(+ZB)5W@."_[='HGS6M$7RO]-!^B(PB'
MO_*Z1>;OSFW50:#('E^%@-W%R#UH@(_=!F*N/-R0;LW^U\4R@>[^."_G1DY&
M,89)'*B>%'"[=PG9)*;YT/8.AN\S8O72;)-18<MN4=D$I].LQH[IDK(_OA<W
M##1#P4G#)!IF^XD`BBY\ACK$,=",I8*QDH.B9L:K*@WRKXL\3`I"\Y>`"IEB
MQN8@.?DW"ML("6JXHRLU7/1B\1,"*H7KO<FV.CP:(]<JY(+4(WGK1:=,Z)[+
MO@$'=70P:'H8*1ATG:9+2G*&>=I-7OR92>R?L\#T0['KQ4!_+I::?,Y==%1Q
MN?O0G/E(XI^E%1)IN4H:RT1W$N(D?EM=H2C.,IH-&]!U=F@<0&UH8?N1!KB>
M[-N#`EJNTET9E_D=5`J8RY4OX_`L=8D"`@39K+S"J(;\8@4,K"N4R-3G`O^@
MFDJ^^4R&/\39*85LCK`N-U1.T6;$8D68M7Y5UNI93)@40H)37X.?8BJ/)K2T
MY3>O1/3Q!%#:,*J0VH&8O0H0MG8%)85!2U$&#O/QHEQ;Q[[I;*_NO6Z7*Q7X
M%Q#;4:?BCA6AP5,E]Y%(T,JZ\E#Y.Y/)1U\AN`/_GV5J:'6QP0TYZ"98\59*
MD42DI/S&2^M-'1;PR@BHH@/P5<,\^7;_T<[U3PX&Z`06Y=-MA=X:%ES8%O`(
M`?%;7=VL@X_83&GSYN>AQO#4Q(1^R5LN5=1)1E2S]]J"$AM\EV=?--(X@]=9
M<V-!V3#T$SP$P[HW0V<V2G'UF<)&O#?W<R!?@4L_H:\*S??.F2!.8*LHX;&>
M_BOU$AO?=X`?)7P8*^J4RN'>X?(;XX.U"BE22BHG>=IET18L1<J/1M[#QK\N
M7!(RQIF$+,49D_0ZYEY&YIJ^S6P.=.W=CGF`%#)^(LT5)PP+)I>`'&.`$9Q6
M8&3;K`%:YK0BQC>/0C5S/(*Y:([OF0CR,)0J=9YS?/U=#F:AA#ZLS(=&GNZJ
M19!&/C@GQVD<@\!#6PP)DG.ED"J`ZO('E"5`]]\<('C7(ZHC2I//AR"_)^KY
ML26%46=S>4*NEKXN3NY#UKXF^SPYV@O%\V9V)IN:N`2%^)ILX9VT1+V-GT=8
M%/D!6?"NQ*>4$%YC&6\$P_RJT3N%FZRWJOC%J_PRIRE#J#7:)D(I'=<N8\*+
M\T,=,*$G2&^S#F?#N5SA).947L(N]3O9LZZ!M@[YR?GQ&3]^;*L4+T>+`PP;
MM8HD2^T^YT,.(`<D#N35C[4-GF)*I(CAZ=ME\EHZT$XBG_)+".=:"$`\N$0X
MO#=*8D/.EJR1BYZJ(M=U;E>T56GC?LR"#R:;*^/1'MI'.9PCYL!5S\OAP-=Q
M"W6@>*=V`WQ9D#HT.0"!7U%3?LE6/CW`L+5K.\Y@!4H:X!3REEFBF\_H6`&M
MTHF*=R9(V4E1J9A5]ITL*Z8;6,H72G+-Z>]3!^'2CMCS00<EA+P`-OT(!8&S
MEM4PJ8CA%AD--=.MFII(H!H)N[2>"47*>G\(URP`4EEOW9P''?I],>:QQV!Z
MB*]#.FA(ZR+@2.%?%W4?K7!3A"&L2FD=Q,=/FHCOU@``^KDEYH5F43BR'U6.
MZ^TVY',6T;1^Z[A#=OW\R:R31)KYC-11#<J*);FQ<R/2YINH-'$[_-;'+-%.
M&&T8+,@O#.+Z^-601Q&WR=4O2Y[7"[!P76!T=LX$'+H[YIO:7LZ<9+C`0"+?
MXKK.@LG05':H2T_([7E35*LWL=/WFPF3J1Z6K?M_\#F0-4\1)RG=)FE$NZGA
M;CPP5@6<%H#Z]OZ=#QK-+]O*$_R&3[E"-@`J=@B+\M5O;50!&"6,JB\L+P"I
M_/H_0@])59C(U2CNM8C#H;(Q8W;@.I$1-0ZD[%[3&Z'N\)-H(*Q@]ESSIQ"9
MKZ[#Y^=T;<AKY'.C-D?<'1S$OGOTA^XW(@R6>?PK6UE"JB=%FQ7(YA:R,Y@G
M5<&@Z1&8X82ENB'S+U%H59454RO]*%0857"4+**KQ0;4.!&9,D.QNI`_SI9E
M6Y*'`<19T563D#;1+;#A_3UA=M.J.(M2,=BZTG;T;;P;*+@^BAP6P41NV&93
M&>Y,=T@GX*)5.!AAV0:O7L?=UG?GJ1LEA-<)!GV_>^*56^#\B#*R$T8\J2BB
MY,O\!74Z[<">1OQE"09MO=OXBBS)^(9[)QQ'+B*%<:*3L$24_;,U('(@Y7Q"
MQ1K>-:RBLB&=NM=E*Z'0!97BL)J$]N;66,+?[PU=@U4'9'?+E-?"39#_!7@0
M`_IHGPY'^8D89>::D/ELHHRE<:V(+YZFP/7]<%>@X?1\GQ4Y\W<L-+.E^[[.
M`\>X?,<:7ZBB6@\5OA(@&\^7[>O:-\>W`&=Q&*0%8:7G+*1%`>)4=3VOL=>^
M]+;$JC;SQ?ZOJ)%XGA<^$Z4W_,E)Y.7JX/MHI=$'ZX^KY$R35Z)'K:Q=^50Q
MV08/GR^,K2FIZBR]/GUN[@)AH33]08A%K.4]G;E1C#ZCKE8;]Z20_A9MVYVO
MAJ\/G6P+!OL@EU\WZD5RP2?TPH/)9D'(*!<?Z_<N14^*Q$MNCSF5KY:("#IC
M-)IR*JGCOY//\T8K#\Q%"@F'<JZJ0(QB:IY6SZ=?EF5B.T*U;MH*TP?,K9>H
M)U`6P'U?0_FU=O\K[D<_H,II7:=\YW9L3QI94M3Q]H0A5^4?9\#\;#RN&P^?
M2(?9+>\'`<U1FJE#,EZCE2@4_@B[$CPE)N<+RIRMHVV?:]WD\D?$LPO4_7(G
MB"2?U[TH(I@9Y;B/(1F]BQE;+6XS[L/^J9297FS9`>1$_QQW.\0::;/S*Y`3
M6]=?)#O>]-HK?Z\M52CB]&@6//)90+"ACVH%.G).P"Y":^P4[TZO)?#N%8L,
MGY,ZV"D%0I"=CMKO13%K^>^]<.AM6N])=3OJ#C1JI&$BYZ@<VW).>-(';2_Z
M3&V)#9B;#,Q8W,\0KL9.5_S90BL<<=XU]7YA(GG6W3Z9GB-JZI^16F23MZL?
MN%_\T15%,J+9RQ-7MRNP;T$8%$N<9G,+"\/UJ#ZY`PT,RB0K.%"X)-'D[J6G
M0HT,;^:?7]S_C`%)M.VDE]ZF1*FU^JX<-DVS1R6[@^]JM?N[N,1>-2J]`49G
MO`AB6"N<.@&;FO@&C52G5O`Q58CJ)JBXC*N?E(VPOW#V,]VRL$VC9+\A,.G#
M+![I2TMP)\BO^'0AEUA!A;1D4ZS8/P*JF&.GL07^*-9BC"+(22J9`]M1W#M'
MED%*A^#Y&+)RO)MVU^<NSM\MKZU3B,'*]#N8XV7WKK$GBI`T#<?^VH?O]M<]
M-EN0$MR:&E(;9465]\D:="^+*]!,CL,CZE,*7Q]=2JJW!Q<<1,-N>L4W3R&G
M,)Y5_14,T`-`*](.V'7<O([8[,F+5YC-P?Z38(-0:>*(>D&=#8C&G&@1`JD7
MQV792G[3N"T!UQ\I=D^,N\%S=WQ]U8[N<JH)Z0`HN=-?7!+N,%<$_"*Q\<6]
M4-']2[X2=!@FO9=XIY"V:KWA@J_4BF+=Y+[5*E<I8,])VS]Y!?"]`!*6WRAC
M3[K$CQ'G+@ZB6+(H@48]"Y`M-3F\<VAQ$L8%$B\CF%Y'RXK9'`UV0#/M`A$H
M>-:G-$(<>T4@FVEY[^YB0W3H99S"+@:$3(8N'$75`'GB-/3CNL*9TAC&9&6M
M[UW>:SDKXE\A25_[I2>^_M?%E1:=TG4>X7$)K,*T5G;0&(#E:'DG?0M4ZY:%
M?=<W>G4LVM"2&.I:QI'Y0I6@<]X`)U$/<.=,)11=L\0AA&\OO@&P7-_=8!Q!
MZ$>H1,F@ZR/OK0/J/8`1$FPKNY&H,&A[TO"Q0Q7Q"N,]&=ZIH*8=<ILB@&OU
M)"71-T=67_WMXR+^%C0RV^#'PA."92UR+PM9V`LJT%-%K+:+.?B,'U`W`-3Z
M`EM-(4MWG6/L:9[@Q_F&U)V<=:8'8_A9\2WZ2^WT`J?+Y4:IA8Y?')2R`2%N
M?E*QIN#FT85A9"[($W`(ZDL1R;U^5"43D4.#I^P_#%E_$/<RXUF`Q)N1;V(E
MJ>1B\CHTCEX:DB',77PJ"_;OHKIPK:^Y:!!;\<VU_%]T<W#G<=.?MTE="A2T
M&HFQ64E(4XS?MZK*]/U$+@F)E-+%NWFB\FV#.NNG?7^)-M6+*P`1@Q*+EA>1
M("B$)>!(G\+\KK_$(+%@YP(CK<4DP;!QG0T5A>YL//I/5FER=O#(0O;/6@`F
M%D31)`0+H3)Z/CY56:CL9T\*_F\@GM*ZV0?=JZ5R3FA9B@%]].]L)01,>S_^
MQ1%K$()1'9<`_#'#02['#LAHY,+92/X$"Z]??N&_O7+VY]F40QP5"+:+L'9)
M`8M-,-I;*9I>LRY`.9=@FB)H3_O5`8`+?#3<K^P=#M3'\X@21`(1QZ5"0Y,X
M]O<T."-(N+8;ODG-1*]N@M2`/G.8KG!@B$E-3?Z=GJW;ITL+`Q?!O05T34T;
MV.HKX2G4!N//%#KX[$(`D]/QB4N_N!2]`SY0$0Z/Q^.THLVGKOT&S%/UV_+J
M)=ZPI<"NKI<A]JM(+)TG@6L7R.#K6PJA[VM&.DS[6/)=X3P>3U'$>7G-9A&B
MCG6=R$-^4Z;U[L\ZP<8<KYBT:<@7J#F=[91;[C\1"%-.\]T8D,QZF:ZON@:Y
M^(D)!<#;DS&-9-/"CB65S?I0NRVRX@2CW.3V=[T&S#+?E^"QY94\O+^"L$83
M/A@1"HP0LS?6^R'X:B5BIH0(-EA)ER)DWB4VCQ6N_7D2V%;\4E66B+@-9C+R
M@C-8U8+XKO!@L&<&<&K:2JIF+^Z^K1D8_%9/4?_72XM?XLR093W=`T);6@*6
MQW&O%/6)(<<2%3IGAP9&N1LI70F&C@*3*@&4I$@T,@\UN[44<4:^6C4\33I:
M7\C[H\M"NXF-&ZO<%HTZRL3"":V`JOMIQ.8-#^K,IBER@:,I'O/DO<Y(^T!N
MYAARQ\[J-8%OB#WCL"-6#/+)"9^AG<M7TWS`_#5\%]YFTMKL9N2^CHDU@T88
M#RS9M/,-[`RAQ=[5OUUWV&_SJ],]V:('5%#OML2!F?D3)6#;MZ)(_6M5>6+E
M@^5RUCV1^`P7]CI02_.BEV1W54_&;H[";O].8,-`[X9@.0:,.9!Z"Z)1/:X/
MKKD?"HMRFPL=UHS[_Z/5$";C/^3K/J/.`-_K=INL&.!R`:&*)&*VM)25'5;V
M3GF\"0#59ZIMB;:DOEH,,Y1[-\=Z.*1V@&O=<X<RTHTC5B!:W)070VQ^[T;/
M@9>0MA)X;$\`23E#+F^%SW6-VB!W;)RKH5,3]?``K/&`P_UF0O.X!,E8>4R9
M2^G]OXF(YU?=`B\TW6KGW!18W?-1#T.SD3D,799E1`&]2,4MYSFF;6/@#'[G
M+E".%A%)LZE.E=BH)NS?;9?%+)2MW<CO23FV2U+T3+#1<T74)`NFL,II;3)^
M9VX_:6HF)88S6N(J8KHW1;"2X^N8`QQ15\1ZB65H,H'9C%D?'Q/A+2*089C"
M+TVZD:3Q9IE(6>W>7[/BLVB@[AWD8R\EGV>%HIQS0_,$=\&M^+EGCMU)_8,Q
MH@B'<8LF/:S;8^Q],=_@3,B&JJ3>XRK^JOSQU:0..;"@BX*\,G2LT4-=8=Y;
M#L,2`8YLTY`-,`+%4P`VMRQ7.0JFZH8:RG3-+FUILU@/R.J<RL,3ICU<[FP+
M6[CEU"8YZ>$[Q2ZU0XEQF+7DF..$K"72M]XV'>=,<I5?.X-:<Y9:L@ML:#(S
M,:W5D'^>LVI^=N!*9%*L\\@_*6VX&"O1+"#>$!2;SONWB0>"2Z-UU*B]$:I[
M&R]S2MKES-*VND_Z,JG5+U]6CQ*A0DB]6?0#"4FA<5]"%.9$_9[UKK4N"H>^
M;9@WZ>GZ&W9C72$EOCH^7)*RP/#]YD\N_Y>(]:I;"8`?B3SD3Y8[\DG$'A#`
M0^14Y5^`"7Z)+4MLQ;"+#"K#7_4JJCO]O)`C%/2\`768*J8HZ'`6RJ]G_9PN
M-@;,U@QH;#0(3`.Y(T.$](Y-[UTQO/'SM_Z=`=JH];S$P26C7M9/H0I%E(V.
MJUSAL?867L@$ZDH1?\',XF>MR4;W6[.;H5EU;N(P75$#\,8(E,\+[ZKWBL$`
M]NL%11N&:00#>Y_L_5SUS`;M=*ASUX]9M,`8BB'(CV(M%W?E*_W&_IE5,)AG
M;WQ&8X=3J8)&&(U*F#-&19&,B2@8X-!#H*[O)@"A`T?QZ!]"!N0N<RM`9:21
MYP8JSU1Q<L[[AU*SC>!T"")&7.W24#`P`TDK0!ZQ[!WVD"OW1#MP!>9A!..+
MK%G>AZ"),,);AIG4X1<;;Z'Z#POJEO0\O[GE1+]Y^U<P.1I741B@T2YS\,U!
M.YJ-[XH_AMET#Q542<X>O[I9OL*`Y`5WG`OUB,L2,BZKL?<*8JLWG8[Q)ZH9
M6>-4Q=*P$5(KRC;IW1]^`453+BCS,RZ,B?0J;944;/H5M:Q$;G?2Q42$="67
M?5N'_7S)/+^!P<F<(:2VR]:#S^;^R`@*4>@4H5YL(;V8;K<65.,-WJ'7:M,Q
M6.E.8.Z&'J3-C8``_D\CU[7<%4MY,:P:+'["W\B/+S5-1@_*H4YB+B*3&[UA
M#!GBY3EC,5[5OA[[-?<QC,5!(=`2<LG#2^K]J@=*ZSP_<&AP(&5C:&\G/#\G
M.S\^"5LI'5J.^/R1XTN1+$4R;U)YU<%SG/F9D`;E[2U=(C!E8F*R&.$&&#;[
MZ+\_C6XI#>I'V?H*>H-*R(ST]J=8^5O4P!3(E!M$?]O"+S^).-P;;5C]MO+!
MZ#A3']E9M"614*&3N84?SZV=;:[#ZK(L0;;"SB/#@$K@TF;%B7H.D"=D!+Y:
M#+&<O;K;\HCECO@Q`]LP/'F'F-5*&/FFT1\WP-@<_#C4-.7'V6SW.^9LIE2X
M&GRBQ?"@LTWG[S4<E??H.<Y7G#[,A_?8!.=;6QE,(]BU&!9#LL2R_UA,?A4:
MEK">$TC$AO?Z`",`TS%I;+'N"83[N^Z`('+F-@2I*((T\(Q2J%T?I@6:QWRA
M\+R@!A+<=N^)TH[?P281H"^1)W6_;,5(AFP`W]\J;S1$68%W)V1TB.BT_*5H
M[>IB#E,;@5B33'=,A#9Z?&U1X_12[%`=4*V%:D1QH-;3L7!P_N0/PO]23W@2
MV@,<&&U-=2O&MG_W2X$OWJIUZ=^#0QE6S0&*`G;6%3C*M&R0;K_'Y()8%GKM
M8IDTW.]L[#;'_-\J&/6?9->AD#>91@FSENI%8"9FS?#I8;(VZ--^2:-P#$FB
M^]!,.[N1*H&$!+@,4&PAG=)!LV9=W(2M..X4TV95\`@8IR[3]"F\Y$C<W8U-
ME5,!#X!+ET@@C+J6HE/9=W]7(R@$ZA(*6?;BP!V^.=PE),LK)+7N6G&>W3YX
MF;Z=E/;^4^N-A+XM79WF-Y6$G1:W8N(^S\N2V(!A+,[[WNKTX*EL0C>%P_C*
MY-'R0`RO;-B!^;H?1R$]B=!-GV^$#'@!;%12;RW5B=L=0EGLE8$$;4:YH1M%
M21ZWPZ7HJ9[UM<EZ61<-)2BE.R^BKIZ"];MO7K:)^ME!HD>1JL"7$M'K_,"6
MO#=/2`4$2\DGO_#TO&EZJ>=*%Q1O]P=,X+/8%3<"D04(*E6-C$O)@5$K6,FP
M%:`O%2X-H,"_2NNV\F\6V/@=[N1P-/)'_%=JX^S#W#A!1#W]0E]<1EEC9<&5
MYQWYPL`9^TW6_\P&,-C1Q;9.30#(*;7G>T]J31M@-!0`UE,@&>239,;B>O<0
MVTMZ&DG43*3M^'W$+[/YO@[8B""\!#NF?\'!YVHNHNNQD%3%***_\AZ\;B$]
M_0S(Z;7VJ,EC(`YDO0G9.6NXM0%U&C=!U@M]GC.BWM*S<2LG#4_.N6.B8@=%
MOIJ;]&=\U52`R_)/+PDU_['[;"5\TOE("3XTA5P8-M@"$91,C(.M9]E-$3A<
M+#J0SN5.CE@%8FEUWG41T#T5:,Z<\=K4TP9Y-('9H\R"?EBFTMQ#&_QB1O/K
M2[!(F91-HBG?G'I"5Y@VD\XFW?BRG`L2MH-,.@\DBAW$'XAD[#WEF:1DJ.B0
M`.$73?\2)FHIN#'JR,MR114ETVJ(IA6A*B,6*X1_W^XD#E2P_-YN"(DZ+G*X
M7*O%=\V61H_YE-,Y4T%GF:$X^5L37:QOWDR_SES$\Z^&_Z7(Q,>=HK;@LA>.
MO+G?$G++].=0TD-R9XBNGDIE2(D5*:(&E!WUG[!.39-4'U'91(SC`MBFC]@C
M)K64F/)2N;AO^&/J@^@>NXD=S6<7'TG<L`$AT/X\E#BG?2HJS5G+;RRC?(42
M!*V*^]/+!A4__5*1*ZY[@8UNKM#_KZHIVAG.7$@ENSQ/U=?9RF9ECQ"!27>Z
MJB)./@P)RFAQ;3H"%:PSPD0+4/'-5&4A%Q0`'WSI:3V6R??UB4!<)3N\->OS
M>D<)TE(&0&@=)ASJTQ++.M"PHJ$6<ZDYR=FLB."R:7.);\XSJ5.,!UWV0@2B
MFK@Q6JI>\/"$?*G!7C%T.8U,[#O)?=]N#.=>%34^^2(QXYP>-/,CL[QEH5]0
M@?;^:/L.)]@Z6C_<+=QA-R)F`5`\KB9*16]2]HR<57D3+@C$?3&%UY/)=.(:
M>53]81S:B)PC)_D:X/\W)Y8O&3$7B%.@!;)ZT_N[4@(=$).8IG5?NZ6!4*<'
M1FSG":+5]7AGASO.^XJ6M6AV>J#3SME5W_G'SA;H^TP@T?`@35WV:_4?-LIK
M3534MS)]*U[J0_JVQJ<!(V\EM-VOI(6E/"%]03"/39F5QD#,!\>G(EJVSX]+
MO%>1V<\PNA722F!2E!?FFGKK\?)2]+.6VW\R\8D;$FTW&U>+0QM0;GT)9H#(
M"G</9WWHF7:$L:/Y(VR.."DC4>)BM,YCX*YIZ$Q*8;SB?,A3<:"TJ*PRBQU_
M&"G=QE<%U)5STDBI4K`Z:`>DD70$*)8CT\`AZOZ0\[9LB(<;QKIIP1DX+W6T
M4YFC2BXJ)O?%TDPFCG?4'T``+A"XY"5C<(.A->'GB]=ATN<W8E_*\W?L/&Y=
M?=!-#M$;!U`IO#-INWN'Y;3>NWN6:8)53QY:?4UJ">LA7N;8W>5#O)"5`I^=
M[`UQ6WF;.,'%#:/MZ@4CS!@N,PQRV7M;S24[::T_K9ELK9[K<5N`DNJ_O5[0
M":,OPC[34']4N.^H>50(^&X'V"*[<TE'\_&+H++!1P'F5ITIR1]N>,1&KK]K
M-"BY[#="&0='":'J@L/>YUQBHX<QQ6?L@H=6>=\=\3OE)IA*EDLCAI0T4VJH
M3)W+Z.`>]CQ4N:*FX?\>_S-]L3[(F<@\A&I#51"%>!0:4(KF!)/'/3&K/0;@
MV)G;S4B;#D\NE(]=AF]YNAH:5OQ:Q@TBX2)&?[X/^%:'4[!266:I8C72?^LY
MP!P;7`\)%HF]@&WF:-%G%61SZZO-G7D5U.G_#C4:D?1F2W`SSHSB[U9P07*T
M\_FYZ601-3R967G.$:P;H@"2R,'JR:*TJ,\JSIB!,&%V$3M+8*.&F<NL)8]T
MP_6KJKBQ9D6WUHBY9YL<L'!KM>M%MZ;1RI7&\+Y,#CA?AI_E*JRK,B5X?3'"
M2<<9HD'FZ&YR`6EM@[C<'0:%HG,UG>C!RT(,J0DH`=MP=H!7D70.XO1:#[K)
MM[[//$HT%2F$NFI(7*=2;T^V0A7EVY<^,U'A@)0Y)6GH0WDQZ.^</W-$8*0)
M\Y^ME:H.JYC?IKA$]CG-?9"YTQQH@TE3K!,[C5875,12/NB?%R;>UUAK;04B
M+D3-](+A%O&5DG)JF3:K7:C+LM*BR::#N(;OF)V9(,-SQYSQWH^4^*!*KG'G
M0QVC7=<N(`=Z;&Z8EU,*MR/N7^Y!F[E0'6^U9.YO#3:A^7_,8%`&C#I)3)#4
MJ0-E<L@L>CE,FW$V8S(^"VV"CMS/A45HX>&4D*-U'PJ;GJ)!.W%XAZG*UI'-
M#W$JORT79M5\F.K9!F-.TF1+0:1!UPL)IOW6=`R=)B;^R:BW+P0L*.L<3KW#
MM)#,4&>Z-3WX1#RMRYC57/\H$J(K#XT(8I5B6:T56A,)LJR>&Z6^%XN'S^*6
M#92^HK+EJD?&45XCV[MZ$%OHB9%V(`5--_@KBTW(<+YO`D-7%?2#<.KYDWAS
MTD[-(,<X_!'1>$`TXJ9CN/L>4/)0O(H=R86G8?,D75GU2QB&U1[P9K:-T:,5
MD\1C8@"9GR$E5\/'@)>"5CU@HE7*[W:RBQR/HM5\A+FP_X`.>GU15`^53)V8
M!6>#NLE-'C9:Z6OZ\2[NG&T5/!MY:*E+O<4J-ZW(7EUA!,.=>"%_:(P'NNOL
M'AQ&('\*GV6"R5>@WN]]?\L,*<`V<],M#:+3T7U9&X4!T'TWX/OJCZ0DO'N?
M&&RU=15)D5?]CH<PEAX=V#:CPR,W4C'N;NJY<M0P`L7WTFB53O9U<$3N];Z$
MU"*=E*K8A^4:P_EX]I,+SU/>V&J3AO1D9VZXSH63`(C1'V.R4[9D`NA;,86#
MV7[(RIJ4U6U9B\ZS<=?*@D++!&X^^^FF$/0*D$-!#KC*&/MG8J;6$@#IU4BD
MG>;E(E7P4U(2ITR_1.Q)-6H3DY46\":C>N^(GF"K$TG.5`Q5\``ZJ_4EP;#:
M"#QA.2053C'?K,<"JS@?[<OOQ`SJWR^>GL3MFFZ"^]9;Q<5T&F1.Q*Z?KH5W
M)>WAMV56(Z-+_$"=!]EH-M42L)_ZJGFM^^15\^#:P=;OT1'Z@!83N\J(*<2$
M&F)80_Y0D)^F?_OCJ7V:1,$SXTE=^@24=&=OUN+E0_;G9A]I@6^^=XV)TMUJ
M]R=\,,)07;8KTP>&!Z^@OC7Q+3TV>%#Z69PV<CMPB_5O-1R]6BPDAV3\A:\1
MF6?_$%\_J6$P&\T__!$WIA!]I1.8FW4]N:`\8FV-^4^UD[>.:<S:_SU)GJ,B
MDS_[Y]R=ZJ6J;O*YF4E1['&Q^G]0%&MB8:Q)#W6?6ML=>W&\W*%+N$KKXDB.
M!D]_-6.8*NS+U]M[]8@S@K/A`?`?O5>%67:>RN/T9]G'.%O"&'0.^K`BQC>>
M(^4_7I>RN(U-I.K\\,6G*3$X%:B2GCEYB1/-QC'QH,LJSB,JP\85=O!R?(/Y
M(=.>#]J&A37P"B8J=_JUTH`'/E:W?"P=U!9'@"JG:3T,N0J-P>91XHLJ!<@I
M,#!<S/R.0]OR)SL!1LW!KD:C4+--M]LU_=DL+<GHXVI>A8WUKZ>+QV50;XL>
MOP*O&.5FV!0MO/??[(W;%"AJ&_*?(6P0^X3^XC]X$,+:#L0J7)6K)V?)?:0F
MI]>73I3)OE)6P<_YOMF^UDV7OP)T_T#1^<UBPW/3-J4QJDC2;N$0M(RS6@",
M<%YOK3$:#-^=&:0^^5BS#Q5`!!&JQG"0Q^:7&ZM/^0D`=;#IK\^0`?)X:H5H
M%K1FP>*!0SM.]=(X#,\EV\;+HN.2ZA2%Y$<-I+9#\V%#VDBE#T%3&O6J3@9]
M`$(I$OUJ2[W.L)'>\F'[LKU#7CFPME7[F3PE0F8W5)"F29FX@M&8='MWBTU]
M2$#7!*;6#82^./39)OM!%MDTWF&D`[XSDC/_"JH,M-26Q](+ZN7YC+'*U"%T
MIL\7/N6'!*"Y!4B.#<B3O2B;BD29%3K;'.Q6GK-+2(RDJ(_PF2O)&`[_C`LW
MGTGQT3=]U`RKH7$-:.4G3Q(%>0ENP/G8Y&)9M59M`9.)<*SD:H`EAPS=O/\+
M-4'2M\9SF(%F09IYLDCZS2I2<J0#47P1/=^8#^@S%33=<G+54!BY&\L+[5@@
MK)K_88,H4&Y]+V,F0D$;`G]5)6.F:<'1([7>`HO2EQ=J8UBP[BR\1V`,>-I#
MW/SC`IF,.J5HY+$HPSHDXI>.>IG.)`(R+#9+YZV\P`&!37M.A_&/X`_VZK`V
M9)T(ZHD$C.0_J3:!57MF:?/Z80%GO>UQ3?C8>%D5$J=^I"0001Z#DT%*4M&G
M<B+81^"WP<-'L?!/GW(&1`#4A[U]8'TBU*JGD=#%GI:#X++WPT5'41;_CJ.?
M9"\PLOP(OI//_NFG-<X?GZ_H9"1C4W5DSFN>>,+SFYMWJSV*:PLM-<SO_)`F
ML,ZE'JOV$G"V5R0F7/;G4021/O3]G!F!93C;QKA9R3*S#\''G>RK:>#LQP@M
MHGR0*W,IX4':P?]##W5`Y%;ZH9&O1^&6/Y6K?D:HVN/76U&0.Z5V\"C9Y^,>
M&+FQ8711?!M<A9EAMX*KBOZ'\8<<_']L.Y)95/+0"Q#XBW?0M7M(**GK/V+N
MT4?\,5X>>)*?72XK$4G)O!'Q60YE]7Q=<@!H+C,0[,,.`5)9,A^9\G(BG&<1
M6@BZRBHYR;%8MQC8ZCD_2M@/U:YFD!]Q>83B+HPZC:56H):M=VABX*&/X'E_
M@#P\ED2W&?S<@NU/9!\K%O)8-QX(RRXL'B*00ZNLQUM&T2T^XY[72%;"7M'.
MC/(YBHPL&WB$>;LFKH=CZ:08(Y(=;L!%BW;VX:QFI])'645?,J,Z29-D$"UO
MFF#XU;\WQ+_(=V8]9#I#+HT.7)!S]/S\`K2$*5P0^X'M<E'*%SV6<R78GM^8
MD?P"!XW)WO6E.285Q+IDGD?BBOM^J"H]A)7]P4^M0&-_PRP!DV>6S-7[:(.O
M0%Z0(_I5`<B%E0P4B*R?`>!,[V+@)X1X.=R<?SFC=X2!'Q02,O3LS1<>U:(&
MB7L)M4[&)#*9Y8I8GZWQ![RR&>1$V)D;G5:"4F1D&JF-0/=04&KYA#(*\4KW
MZ#<_EPHE+3@8.%<QF6M&'J3LV07<;;Y0#^V;7G*^(9^;2=;M(6@O3%Q\"AO'
M'2-BW6,OB@AF;`Z8=;)LP%?6%::JPX@N`R)B/N2U4NL2!]U/8TY@WUP0T!3-
MLHA/?2,1C^[Z_#L^X+F'5#)56`SMTF;8+.N)4-'ZBBL7""=!AN#ATDNY6PM4
M49GA4%=[+*O@)0GO/&!Q)U@Z;`O]QML.G-"0-LEYZ\3O]I4;+$%<ES11)1?4
MAO79/6S6]%A)K1!1//Y3"F>(;^LQ",-4=9[438TL[3B`Q*;O;D>$!5!G_J<Y
MP1VBU[_(N#*WUL(<:B+@Q(E/?`;E&8YW(<&@!$@OU/R[=<63A0N\FWKAM2P;
MZ>QRUUO")$WNX!59N#I?Z\.+PU';F0@6&=VFN;E"]L;$9,;QS0#J"O_T/WR)
MJM<<*T!*H-FKQQ(SW!U+(G%PO8HRXI5HID:U!R+^9=.E!G+)3'?2"%6.=B.:
M4K=W_AX4;I%%R^1UE'R?OM9K?7,*,PU_,7(T"L8-;(_G:P%>H7?\3S^)4-@"
M`T=-G<;<V3&YE+MQ]/X%L)OQF1=]>%@[--TQ_J6(=W>/KL<882!)S6F4]A=`
M&P\8Z$A1&O6:JTHZ0(`U6Y13'6#"X??ABFSNGQ(/P6F^F1UY9FF69.B`@32_
M)4$)C/Z?*LM@YP5+QMYB;AVG\G,@BFCZ@;2/'=UP]ZH<VDBXG6ZCG\U"(5HP
M:T;)@Z'FVBP.79U)+E1>_$J8?/O)PNCL%PR_%UQ.(W(6<?R_N31%/A7`:*9W
MY9LTL$,R;>@S=,5+A\IMI?PIYE?0D,O7:P(;<.Q34I$6G^4B^!=@:TY;9BW8
M!@F#S6=O_%,P]Q'468M=FHJ;L4&]REQ$ED<D6]C.?0[%\7U8T()<W0KS5R9/
M>LYZ-[$H;&ZRIJ_\#;H;#5'0EIF4+OYB!,(IJ+!7EE)0AJ%[6IX#8//)0YA(
MT48[9*`$&JO#V"P7SW$P3&?`I+7E1RZ\-2Q3>1UT$,:#%H9K`#C3B&I(4<YZ
M@B1M3-_L]B(8IP#"K,BO3-@'U:&TUX:L'LY?B.M-T)VK=;[:7J3]Q$M2[GE,
M[%[P7N`7K*)+@"+W6['F'\O&</[)WD)T#5?"87`P!*H3Z[FC5^=\>06^NL"%
M8KT1%1BGL*DL0PEF]5+S(DT35`06#5/V79'1VW=L$6+<Q3FO^GFM##31%38B
M5Y9ED!Q'G3`J?4HFZ5[IF05?!A(:0BCX,*MEX+#OI4GA4-+*0:MZ+^;Q3SHE
M`6OB8TB5-HG;VQB/27&XU$9]7E="9K./`M`9]Y4>(E#P@G^MB&O##]2[5/TZ
M>R#)3K-8Y?;ZTY+\OOVD"AC,)C)?L+&%@SDR;^`@8G,=LY*\T']XF.QA0A4C
MB#P6K\\ZT[]/Z\#]I:`$?JL/NH]BC,;C))79ZLY!.).UQ9X)V0<:\?@>@Q#^
MBWGQ!,X4>M+,&I"O;TL"1@_WTFH\0W,KAJ/J0!/XVL2PYI7G!-17>EBXN(.2
M`)/4B14=:&@^$<`=?1!&9@,7E^K-(O@%ITC\N[_2!<7&2?EJ0[Z1)CJUCHRF
M'>CLK'0`=[-/X5-94ZB[%>:GA6(O$NJ/KZ-'=JX]D'H`'I/??K:_["N(^L(C
M3H;X#?]F"\!0GWX*D#+MSB5+4.B:^R'G'CPO#?RZ0W2`[+O/'&!ET.V`@"0?
MY[9S[X)501U-1YH;JG&R^E]YZ3"77@R4SNHHQ0^2,)K2U<./1"8-.WW55RD/
MX\J()?T&KT_1MY.TGQ0\DL<H[B.;Z7W0QY;=?3&U`=(3)->YAN,T)\^H]AH*
M$6@7+X@`B9B0`L:5^O+'X8U93^$S2G="^DF-OR'\7X/OJ2L.MO;,W&QC*\WJ
M<3"V3!2D4^P"D3>P6G4#&2-<V12_ZFX",-[\Y.CNR,K^@JSP,.-`+1JYC(80
MI!(5Q4$_.Z_K$@$VP.NT5*9^_>+@\OA9R:;]C^P`?R/#E0E4#'+[S-F.W%].
MT?!$7F4*;B!=?/<GG>[8'\Y0B6'$P@SAR`&,8,#,?#BI>2?\?3$@2_C3B08F
M'SS8M_IC0!2ICI4&<!QB23S`"ROQMG`X2$-I0.Y'`V7S635O@CC2R.W2LVZB
MK)][I8GL.T@A^BB2X@1+:+I$9D2#*YE>[=9X7^1#-$\EB@@+-EPUC/MG',S'
MP\UTP1Y$_,"#*&5_;N$%(1^A5:6M$5=WLDEO*5#82A"?XU:S"Z6B^UF5NLL"
M++M'!8T%,>.#BZ2SBD%6`F:A]IF2JW>JUPXCC'[_/BRJF9108[-F">I)D@J7
M;F.=P(B4FU'SD]*;DLK3)SAUNR)E+!AW6*+]+Z6@7)M`M[ZZ_X3'.F'3AO/?
MW^2VN*`M.AG[3X.L.>=`=^2RUMF+PM?V@3AJQNT\GLATOAH*=[,ABH^DG0;'
M-R:#%_MZAY=QV@HUUVV2](H8\'$DGR`ZB2P?8++V3,WJFK=)>X>X^(V<;@U0
M.B$SD,I6OPLPN.&8#L:@#^:`AZ8\[OE(RTT#`?8=(!;T4\##'U].U19/8C*>
MY8B)$>=TW53-JY8N4[/MWE$;DL:\`02B.![RAKIV-C(W93_Q&"D:$9<(8H"=
M='U\D(7FR0G#42*8V.AV<S>P1]%6]"R<1_1W?2T>PP&OP-"PA]L:0R;.H:[$
M1!Q_8U1QS()U7P;#%AO5J!$<A+M5P+\%OK>IP7EC8O)%6Q_V)[NG@/=3:HA2
MF!+158;CP[13%X[W)VFIP2_&F-="U6[_U$S]"A[BDTH)+."7IST=D[5DH]^K
MN%<*X,"[YPV"]S;/]7-+Q/]O#C!89&ZIPIU[P5BA7R)JF\I9DXQ1#\M=Q'2"
M?7X1`"6V1*EF'RV)5[TPJ_3#7YR@"WVC2`-!=N!DPSQ#&(S2!A_\;J`@U;L-
M[Z;LL@S`D=<2*L-REI4^O.GVF,/J[XFB"'/X1,6>156\I)"_BW[+X?<CW3N2
M^\\WI9]E2HR3;-::#:PU^R<,/;R1FA*08.34-4LV4D4)X!O?@/%2KA9=;42R
MT$2E+0+,@R,&BQ&)QF3R.^,PVF@_"%#KU5XFC/M!BMIF(]UH5MVRY1NC!?)3
MS5(7<JQ:=PUH1&@F+3H-KVXL$T8Z3PD19_SR)W$.T[1J'6U9()W)_F'J,7DD
M9H-U3ARWZ/V/*")A/G1HB<$S/V2*2FLQ<V.9/\**>%WR[+0I>6GOC`T$4NB`
MT@PG#\*P+_1+"0IO]\829HB/?5D%7.DH(IH50JQNN9;@O[ZG!,8TUC5K!&=L
M>\H*4MYB0M[P5&#DH1?>._^$A&%O">^Z(F-WK`+3#Y)MUMB1;,(H36<@6[Q+
MG<0I6>*@;1,5PKT=[M9^:3<K+W!C:0Z-]<UTAD1F6OIR8NPL`B8E@U`]SHTR
MU.`,Y#!U24':<]$J5P]RD119J`0!,Y(5/>5[Q;/=D!@QS[$#A'1'`WF'=87"
M9K9B&RM!C21%.08-'>I6PTV#A!R$BUY9MB2])/DD9TL`HA4>P![PE\M*=;/=
M_Y,A@L$<W#Q5"<ICA1[E.#)+T3\<K\MZ_\O)AUSSL(7I^+"M`AD:#VU7,[*^
M@ALY'K%7W*UA>U!]T-ZK`OV:SM0YC+@5Q99=9A%S(W#ID0MH<I'FSF"#<^=Q
M$_?[]1Q!2-K3LVGZ1?_K%\/($)JW0W9`9A:-+,Z]X/SIJ5=E&%ZD3$NL2<([
M5"SKAA=6?%@Y+.=#G0F7Q0$ALVUA7]C!6),;R5I'H`&H^<?%VK>:HU$+S4NZ
M0Q#Q^CJBLCK%:SMV\;*+P2XKT=]!<E.JAP!."EKGB\M]=-IEII0D:34`A0/T
MLGYGH>DVO)-IK&\4RIYF%:5A*\YQ;__ECVYH!7*<<B'"M&.QN]C4-NJ=DALJ
M+-CGG7K!67\LX5+=[H]?"9U[&45&HLK5Q+JC.V\B$.JQH2&S0I2NAR?Z>2U:
M^SJ.A;!)^0R[35JWN6ZEQ$YUW-J6--7IIQ-^_6;&+R\4ZPSL"&:<*J)1_=B'
MQ9&<YP[,8N-&`^G4'RD.'#118'*6PG\!K/D,Y+F$<&X(KM=BWN-$-^*W]+RO
M5M.JM*>\+=PRG\P5R?H[&2$*`ITEW^DL:$"_OVHX&1"$Q?RB+9"NK>TWXH/:
M5L]],-%F<B`=3#28?GI^.5I$XMVJW%>AG:YP63;9N[N/F9@N#@D_-GOQC](T
MF&-_$).8^VX^>TIJ&3H(6;(%P&M1EDQT=G%R563G?G))]6&,Y;_)`+&&#[)`
M?!OJ;R2N%*-O@S3)4'$J;\YL3=1FA\/>T?V9.^=-O@G@IFM<%'/>\8G>M5!T
M,2U6K\/E[;O'OF9U]4UV20*.5?(FU?5],3S->E`49?X]C&7S"O[K3-0,ASA9
MQ^AUN>J-I%AT.>>[*?,43+8<I5!K\R-VQN#!C_;*PE8CM3?_K1)1?6`PL8`K
M`!</X`K9R_2.`,)<VL;F]\;Z>Z'#%U!KY/876[5,YC?F4GG0QU_ELA5;<L98
MY#`\`<K/56L"ZYZ.,$@KF&M2V7AH%"BO&P%4)0^CF)]"M]$=??5.??N.V(-!
M1*1<XW&C+6SH7%TAZD;$T)SDTDQM&5.V_ML+F.@YGD^C([;:+O`O4&2)?;_&
M6_76IKAD6:&<N"AR@ENQ%Y#2/IGY'+QJL^:5STHR[$&B>5$J9$A?F[)$>RO4
MD[Z7(T@U@BNH*\ROS4YU@6L-M/;R*5:JW:VN%UUSQ"Q;_!?>[`</NQLF<IS7
M0IC]49*:Q]*O'"+^SM#4T:R'^=$5!G<\E)06F#TQ,;LPS"9]E"6^A_A10LZ?
M_<ZCL/>9$Q4]F_="-06*M$UE#Z<M_$KUE)BH]TSZHQ3*.SV**J;K]Q[GHD>6
M!EG^(&%*3*)L:YEC=]HIX$5L?\(;>)25%D,?B^T5<,5,H56Y\U\S+_8MXIZ(
M$>.[6?6$'1C8>'4GK$:#'=H'!(%0QC4LJ*.*6CL$O/]DW.G&6;`0&E^/@,=I
ML'1CJ>4T!;I;=F>+85`W2?\FQLX`YX--U2)6@E&SI$'KS`Y!:`F3J5#]_NR[
MF'S0D)E-3\V*F]!R=ZKC13=_7,#3C)E&84UH@PC3=C*O9J(35,Y/G<#2L;9>
MJ0/)Z@44^.J022U712VSU$[!Y!E#],&IXQ9S:)_$9=T87QB[G;&8[QRYTSEC
MT[C%X+V0H1JZ<%`1,&W%VU&(2.C42-/8:2>/_N.7ZJ#WBE7JP$NBOZ<$P:??
M!S#K-SL62*?_7XI(K@FX_I?S?LI2;LUG!T,<:#D5?.%P"]@X-S?Y22_%C12E
MU(ZKR#X)\/;Q]4O2_-IRV*P+QY.68R&Y[(UR>?O!-U<]6T4D_)/G6^(G>430
MBT_`5]:ZNW8:*<'):RA@`[Q6"QCOR8?HY:BGKYB%0*Y[:-4)\@>/\DK7'AH/
MT5WSQ$1LDNAP&-47&TFOLFKG+<S4,;]5O&IU[>N=YR97"FYXIV)E4#^]GZ!:
M11XP.Q?M1"!LSP@68:&N\QG\O4<]Z>"1+V'?[2UG"G?NV&[IZ'.JC+TD,>2\
M6;;KA4HI?&,3%%X[M"X%RYZLAY+SJ7\^7L/>I+=K8A[;:$1*.8BA86[0[7#3
M;ZJQ[T/I1+JX!M"'"*JMV\`P*.F79BR_:V3L`*`Y!&.%CX'M\VI!ZNGB'8!I
MPZ1/L&)MOA$/;V_35=EIU?J!D+@@LYL92G5K!M3['HQV`[$!J@T4$[2#U5QF
MQ'<($;QQA;.G[:Q8S[!=`F:&U,$42^X*S+1`#^''/B\(<.N#\"'_M56/0DP`
M-1(=6#8JI2UG>IPCDSM0R.<A'NHA^=.M#=N%MO^T9DAEI37K_).^8PXC%ZY>
M9G6X`Q7SLD/!QU[?T=Y`%"Y@CU'`_9BH#AJC$*,_?8DN0;5RWP!`_^(_6>*B
M#+%PE01D,G^P2%S7M@K[Y\:,37-*AZ7Q1[*J=\7)>:T&/^M4=N[#7"*=ET'.
M,O!>!NYK0RPG6PW6Q3>7R::=9,I9&\!B%'=W,;'+-:%'VAM&YS1SXRO>,U^@
M3`I>SB)P2:_4TH@$_@POZ:%!J3O6NR\S56UGDWE68077B);?(_B*B"CA7H,<
M(S&RV\4%)#7$]Z/-615*95T('MFE;>MH`(2HZ$8&#I'@(I>T@)XIOHOC2X;%
M"=)[S'"IH[#I?"O&"[]5XFTFE0X_H'TD:8PS<Y"1XL>ALJR]K*+7JYQD+Y1)
M;*K%LZ+<BK\1,>M]J-"),>Y.T!E^Q!:II#2:\,G0G&SI91\J^Z[>Q@QUWW/T
MF`RQ7$:WU=\X\;[3N-ZO*U>AA"V%CEOR+4F1*\"7[A'.M)=>$1_O@B44EOS7
MR1<\X$U:49"%:;7=[7R2OF0LNKU>!4#[*Q+^@Z2CVHO==`U]>TJ3=K1IQ?HS
MHC_8W2[,"[KC13QI4<,V2!L7WH141L_RZ`VD93=L'6-@7=:*5<@M25UG-J^C
M17+H5V!&7;QZQGA34<6C,0>/J!K<FTG#<Y[5$B4)RB=1)_D3JIC.'I;=BE#X
M#IFWW.I2>3.:9F=Y/,`NR-0A3QDVH6FF?*,4I=6+X10S0WN<(`+-HTU;3WG)
MQ9V>L_$P#1+HM)G=]!HJ-O6J7:[U>IXK_N?U&SX1<"Y=!4D2]-E@TO3!JS$$
MU8Y54&J/ZBWUM<"X79)(DI0")L&+N5M@6O")+KQ#(\6%O)@BZP><^G/C#'L7
M&H\`RH,M0QK1@/`I0@7!R7G@,?Z[I)AN7#98*+<Q:1H7%%8JI_;.'!UF>BTB
M<;6@"\F[`-8=].>[U5&O;>[DZP/UYS,D<B*'%O3I8`J`5Y\09'^?G0UO0"HG
MU/?S.\UD;4TVU^.#PUYPTH554R6X1#.5@,-W3\RNC[L&_T*KSA1S3=>8W[LZ
MV_%PGHS3>7%"G++.0)WJ%OM'5"Q4-08<AT27&GR"VXV(HO3ZWWVA*A0J'()G
M/5=`,">+KX`,&<*VJ&WF&^97R7[+[P/@#B3\8F',2Y!BA@*]2@"@WR@%.#\Q
M1;%<AN32D/7>]_AX=?3"A#`[X)CG>^Z5%]Q9?UK]A'8[&?/C\_2^8H3L`>BJ
M"1V+DQ*ENCS"6178V4/#<L5UU4US]<^;A8-Q#?ZQD7PMY[FM_5DNQUGD4P0@
M#\V'JY9`IL8[LY$82QK"*;+,VWN;@U,/MJI^2@8H28CM<^#2?=&AM$<,^1^G
MP/7YJXK2W+9J6+1O`9Q:4[/G=ETQ[6[VI+5BBS"^%XTD@+NZJ05BMIE;A`PM
ME2M[M2&4=$D1*]$3R\,?;IR6@G&12KY+48MIY#9]F$V&BFSIE7Z.LDMQ:0N]
MS1Q<R'MT!F@\?'JBN9-1V'5U7R*7B(,^V0Y_I:LKGY))UT9L2><44XL\G`?S
MSG$3\E&&P&<1C,UWDI[B])+5$-*E-MK:%]KK`@*,1-.VOH$>K_UH;^E'*!I-
MD$'+0E*73F,H)_^6?\UZ@A*XB4\](J(465.L3'E[F6?+8)A.S.98EX:.=;1T
M*L^JD"[\=Q*#-*C9IZ.-CJN0A0XSI44[0$`LLB/26CW$C$JN;&VT)'V@<_"%
M($CH2)/_!:V-Y_*%M.N9+'#7L)&'<[<G3Y]&>/S*F-I_66U^"V.;D1\H+7^4
MWT;P0`O>V0F+8MVP13T*6$^J"L5`*@L7><Y5M":(8M5L-E2QQQ`T/8U7KXW=
M6`MY$@B7>5EL<>)$4'O4::MAWGCJB37J!O.P7O_'+KB)XTKMV)D5AR%'BE\H
MLV?WLGJTMK_.#8J9[*[L7Y`LQ_&9%2+;!.O/.BQ]%G4:!PZVK[U@90N5H/!,
MCU+&4^R4%@_DU?=V6\#[PNDM6VI@GO3?CQ4+Q>.I_/J3=<C1UT[<H2P<C^T[
M$+^I7%+6UV1""NZQ5G^"_!`Q?T:QY0EV&3:C<O&/4VBGB*.L4[&O"%2.^*.>
M<+[&#3-C0_S.LGU.ALGE?GVDRGKN!/LE4$W1;Q0>/.X]D!J1+E"U#+)U2N)]
M07B0@6.L2D-!/YD%Y/+U./+)G'"*U=A8?F^;B!W:<<NG<W?Q*\!GN!46"?#4
MZL%`+1N%4&X&M+II5AO!I`03Z$*A;=Z6;O[2*),7"GWM^#FIT(:NU=%:^*]I
M&/?3-(+QR<?1H7]<=<UZ28.Q@E0J^PK6_^.#V4YO'5$]Y?8Z#_*'+5[]!S0V
M?5LOZPJ/7*R^K?^-UU:T'-'0XEUE8]&>;!6#N0082$*S`+IYUG@T3Z+%A`PQ
M&BL:+^A4R:S_Y<[@G=-NX1"<'),&%L]TWZ"-('7*E_`^5X2#&ZG)36UH-Z)>
MNX'--8UZU2?%O>MQU_W>D-N=A*'`Z!1KW6>J6G2WW0<_^^3RD+N$4T\72Y72
MRDL%'KVR3MHI36;41BM\B<1RDS2@0;UVE6:4:.OE@WT!K9!/9C0M&'P?8WKM
MU>*#0%`>5&6U'RG&:S<2=Z-R$3^)^;F=$[L+.C:JFC:A32WP\<@`2%[GSGP1
M>ARD?A\V(C@O'TTV]>=_U8C/X/*Q"1(094!HTHQ`OOR2W;C3#=$HN#Q5A_\G
MQ"7C.=E,QX!F*"SQSQ,CPH..LPW6+6V>E?$R2?`O7]T3"MM/$LK^OQM+.I&\
MN]7G*E+PVQ=M*C/>21V8A^A&(EZ3D@@&'Y=VZ*]DW_Y`))*T;WS3=X-2:;4!
M3BNQMM(YM"D^VFD1:8W]X;C]-MQR6YSSW:+Y\K-3OZDLW9GY@`WV\4W2=HM*
M#W-88W"R].K<#.`[NW*>?'W,YBW["MC>^5C2%;!M+61O1538$UOGER3%5X;"
MH*JI(/RS:H7Z&#H=B0K?AF/87I4EKRJ'EG&K)K3A658R6NN'R(\IM*;5ZC-4
MKD@'Q[=S+:,;/@('<4N:3"N9UM`Q6S+0BM%W",J\B7E82D^DT>HI"PK>?B6+
MKC+.+TKM8^9>!2.D8V,W\I]09EN4X-M3#3Y96Q..QSJNZ#>J?>::.2USEH34
MAI_@6_ZQGQETT5V#ZL)N<?%S*LG;7+D3<U>7OFSQ/E`+$Q1$M_`?CKX=W]F<
M%M\4=1R@'U1PY(!"\FK1T2]B43UCE864$RMUP!#*]CZ:3#E>9P%0E:==\;Q>
M#,WS+DP?105X(1^@HMEDC*A(3BA(4,?^()V$\,&T#OB-G+B:L:4A,HW@3Z9:
M52M>%R6G;KUV:](SP-]0XMMSY!9'U<^K&XQ),)WTTI?];]Y.LPG6D?)S#E?;
M.S@I%974K8B'GL#P'ET+A]YU5!,??.V4LTR*#T#55S?2]GXCJ4G!#"2(48`R
MUJ]/P#_^K=0!&5[CUH^G\4\J1(6KMDX<V/Q63\M^V<(9'"'R52%4`,77Q=-,
M.7FM0&MDLTIETU31S;2?GB8$.0C'`5P3!@VU3>`0K$>RH3DULZ"GHZG&SA$_
MKZ3L7"]'?FX(?K>FW-ZE:K!D<:3RS.>Q,;!H:E%ZN5ONQ=)BK)';]0@-2QIL
MQ-#V_SJ6L;)G$U,V>4$8G($W:P%D]_]JX/C^$G@:;9%?+V)-]O*-^3NYYAHL
MMOU9>4B>6D#.4I%3^.E%>J%-R@'NK(KZ(F!\/20W9E]]=7\-_L:"R"EK:D01
MCF4ZD52C1Q)8T\(@4F9Q%!TMQ].FN+&?FO=R?>O2>:Q!Q<]P-&I]PA`@OB&\
MEBA,,L(,S$!=]V#X7O9OC)8-(B67YD`5^JV1D^E=SX=8,:]U`(6"^?.1I`NA
MZ8>2+_.#B@9KK_DYTYHCGG=>""/KRRZA`2-Z$2_?UCEI;-W3F!S6T;M.<,'#
M=A;6QEQ[OO[=WU_JY'UVVKH!V][SC"HD65=+;W_B6JC2-\/38KF>)IG-L)5<
M$`0@13CN%LS[OA91_[C_EKIR5E4)]<\B#U!1VF''2YX'JCX<ZMI9(;@S^)_%
M>I#R/;]RPT3C.TZ`U9X]>KS?'<V*&*-[@-5@*M"&2V6>N<J3$KRGTP`X:(2@
M+=1I>G?C^)`([[$H\1JS<TJ;^^HE7.N[H("-7Z.+K=O(!/]YE_8>^CF.+^X;
MS$`0V)S9!%Q1CTW6K0[/V(I?-.7T>\&IM7N-9Y8!(:DV`@?5,%F8SOR"B*Z*
MM_O++]_Q\>65L%44%M`[CT,)QXW;FGPW+K/7OD8N3<`E(O%&-KT;)..QW8NK
MV@2JF/4=0Q[7PC?D)H%+.Z^H\2$E<U>"4VC6+7_$D2<MM1W3I-N5LN\QDD#Z
MM0IE9,/.(\8*0X,\_6ZUV*!7,CBZD25^_`4^1F@&-@0\L<G<-.,X%Q$??``>
M33_D83;+?X#C8/,#@V?+X]3P;CKU[MM<L,OH:D/PV7&*TN7M)4M.8)809#/9
M'2K`3V%^>/!.,V9LS,,?``[N.-EMM`$J[#R-*-AG_2Z@4?8AI2KS,VS`\RM:
M`V%=VEOHRN4JE+P9$JEF?96_"8,O5_1;P*+23D%2^C3_"/$E^,(`$4`]BF:U
MI0'`FBCH6XIFB&%\"6J3M,_SJ5Q9I%30<FB$;KV%C3V$RUNU^\49=QCH_W^$
MTG',X';VL"YB*GUP@[6E\Z+C&BA*5:BZW9KWE^R=0_#ZCU9BSA)P1O\<9CQL
M#QD0<2%_L57BD\J4Q9FGQ(QN>H8+(")5CD@S50M?&?-/V=TN09*;5NHD^D1[
MZME#@D8!BE&E"N^%@J!MXC=B%,`?!S&$P*HVP-7*:K\Y'<N$Q>8;%1S'X$!%
M!M%*7\=WGULO_+"8CQ_[R+1^^9I?A%Z]V$[E-K.L7J"*KI&CNA3&JQXLON[6
MS48(T;:<*6"OP4@6S#7?O``.9W^2/A0>92NTT59\<UL>04_R-P!$^13_EFEY
ME1,O0+0A=!P&75Z!I^-QA_"AYR:T,;UDDC?DRB9^GZ%^"F:M%HCT3<E1\RTK
M?P>9`E2;T-S`WU?#XT%-3'IR_C_S;S$N]AS$-7"!1%CSR3D'B/TOGLN>^M[D
MO%$BC@Q#?B.PLUCEW&0^!I$-V_&9&SU5A&$6R`"9>WC3&9!]K261@Y:8]3SD
MKWN-AT0+RRGWA$K[4A4V06)GR:ZN`2ME6+I4UWF1>9(*FU56)/M0'Y12%[)[
M'^CY486U:?G4X9>KZCG5">!]=Y9K`!2OT.3W$\NF(MI/I?JGYT-BMSCC,\N?
MF%P91N"FC#[6T%<;KZJN4V1/N4"\GU$96P1HQ<I(VC<O`L:>Z0#@R7S.]G]<
MXXNZM.BT1AKC\#JS8&'R]+F5"48Y+CX#Z>LV#!+5WB4K7=`C>Q3U9AR*[$(4
MH//D8;1.!"9US>7@2_48Z3HM>_*7&X?(2/'`F6/F>9B20%8//;=237I_R7BU
MNL<@1CY.*-UT3H%3HBP%F))L/G$[HU@I;W7"<Z_6\N@->;ELUB&I)Z4.V7V/
M>*K%*ZR!2,A[;G;[Y,,QM`\H-8HZ@\26Z@BC@6#0!'Z;#J)=;H<+QW&W<A7`
M/^X3ABMJ'TA<X+VF@&?LO==!0`"3%2!XXM^X(EF):U\ZY,Z3*PTF-1TH>OF0
M1[WIC0TT"3H@C?)C%20,F1^0^7[2_?9=0+$ZM:;(F@,FK'AW%*$3(3-*0640
M?YVJXFUXSH%=`VZH`C9K\,U7PC_;<Y*;D?KP.I&&%GU7O,-R:>G$+6N@(_(?
M\6U0B"QI:I],K@Q%@33"HIX9O3,8@O'/=C?>DU>OP4!2/\OO-K7&X_&ZT!L4
MX);1=P+WFN?)')@[?*+,=M$N;ZR$XQ4KSR0WB>QW6D`,.&<>M_R`=UJ:/M5:
MK5PTWQ);!<X`*U(P<_,&TX>D&)A>%)3^*0TDH+V7[J%<8DKQF2!XO*WR]6)8
MQ8S\.!VJ8=8^C1LKMU<-8LW:R4>*?TD4,Z2<>6'U_N$`!ZV\=OYEU&OGSD(8
MR+V>#P8`2ODP,Y0[XGWF8E0^)O5`G$G-\Q@Q8]>UWG94%6E3V`5`5V"2P[LQ
MKD>OXJ\2>DUM6L4>U'2.5W2&WFVO/JU#WF3=%U#N_G^#LA)Z:9<S%JJ<GR;L
M'<,1/<E;1`72_D:7>]<K!($>XHVUY-<2'JW]X$MP5!-\\QAN0\A5)\3!=/@Y
M$U<9FV+?7+'97)-3Y_I/Z5='PSK!DBB"G>IN&AV?<GF5%R#DA?C&+4=U;'EI
M1E_$'??7Q&02$+[KZ@I1Y)'6JC!^C&[6`///(!#EB!U%>I%;1)<Z2+KG-D9G
MHTRM$K?84"3Z2)T?]6%+8+@[M5D:)'<8.CK(X(2\DQ?:9G5FL%'(HPJ$:%]5
MQ4KACW_254D`]-)AUCA6OJ]^9Y.`4EY/O8P?0=AIQMQ0*X(H?C\M]$4H5DY;
M(!P\_`^FB(83'%'UK)4:WEEK?*]*'G`RH*J#L<Q;%0&HM274Z$&_A@CQ%#D^
M<,GC0Z'3Y/#$@NSGGU`M=T+9=:1`*UV)J#_FICX)_\&D1ZXS@E.-OLDBHK?\
MGS$HI@#(_&-&O4@6=+RT-;W+"@W):)[)%5815[H&@Z+Y4'[EPO.N@S/X98(;
M(.K=ZWWU@D$OA<+0_>8-]"U>OY_MPR*63E0+@*C3G^51VG.2YL>?@WMTI7_/
M]LSZ*/JP>M:JHAFP`W1]T:)#OLLN;F_7A)Z,1C5`&.CY?EL*W"J]C6IZ(\$P
M`#T9ECA&$\*&<=^;9[CARP?%S299R.R<L'33FX<NBQ"^N]]4TN%;1&W1/&(2
M&$JKQP+5+P-46L=;:EV=KY`@&M593::*;OS9O=>0J#0G\D:7&[9,3'Q*'&EE
MDOGJ\T?UQX8$HG\Q[^GK6>T3`=(G+*M`Z$UEA5;[?P,USIL4O40;]WDXKL:[
MW7<*)S!K_9CHLD2Y+_-.1FPD7P[4<!R1!U`?JMF4XS.:*Y1)EH1$W"-0<%O(
M""IZ5G8A`1_;H[@FZ@K<=#/2O7*R.4=M_%066)T9W<2MPBH[(%MNO:\=B>8E
MMN8E5E7(#VDEM)KHDG,V\/0?UH)E8N4/&5U&NQ;.#_CN0?QTU-!^N\UN'ZE;
MFO/FE@>J@9H"PZ4S@C_U6'U5A$_MK<;MATQ&5F=ZHD838S0Z`1"\5A<E!R?*
M#(D#Q\AI=K.+^%CP?.@J&#%'`>7234@#T3,2DP"+R-5Y?_?D+@U:NDVZWVNN
M6"Z,!.;^&?00R,Y87^)ZDZK%DQ4$.N??%?W1ENA;+<?OI"-AH7#,N"]_!RBY
M&&)(DY,CFR'0/5%B]X<A5YY-`XO@+^63HGOB<CSN\898][4W`Z+,O>D3=BNH
MS$Y@D#-%)8I#+#\V/(T4QS3JM(Z>U__8RSDC"*507/@*Q7VSHXSZ?3Y<VDB.
MQ;(OKE'^%CN=`P:FNWY\>JG`N^]SN[&Y]=)7Z63,3`E3=J3CCJHM?\LQGV`:
M)V%T@&!6A/8(4B4<E":`"X)([*J8Q!95EZT&(?UDN3U"1;0^ZG9&#$CI);7[
M$((WF'[0*2\QE]"T:]+W`CV7L`.K9^QP7(<;K3`4S&%$29`R0[\++(4KQIRZ
M%Z+?+!^(YGT!=B?%5-I":F!B5S?CSI(&)10Y(4#*0R>%"!8T!FN)O(0[/KX2
MUK7Q98\E:1:<VO#*TW:N])X)AY73DUA5?'S^+(<,=W1U\Z@M>`I4U\R;8+_2
MXPY7';@K(C]-=1_\<TC5M%*AJ.9;TQ`P0G1U3[2:/C^6V\,/]B[CA\2S([*G
MXKV95^_P3X^)%2:'(7N,?,:"SX_CW_8?(*?0I;'ZT-[BECKQD41!JXT:V*=2
MRP_=Q+R]2;\I`E<A-IEK3DC&]B17DD1`M:##Y+MC17LBR`X':*%3;A8J/>8W
MK?ZOV6NQ_^2U,@.;&HR4-&F=`.J?^&QN/VR^<%'2MYL&\XU*(UZ'GY?X^K_@
M8S,9@OP&>]P_^5WC[9#2;+&K>C-1_\'&O_*^R%SNJ>F(,C(L8@4.O@9.V,_-
M>&L(^.OH7P.:)]W9Y8;?8ULCLODY]6J(3CO+=VY&R(RQ-`/^1DL?K*2NDFJ+
M/"AT+B6AH8[R!BA;U'&*X*-<1<[4XD^@!9$WX`9IF-]-O0FZTB,#G!\*7R1R
M[^[9Z!/W<GX,AI_KHONGL"G(?'A5G8+=,S1]=?,1=&H_+0UYPT^>]8Y;:$32
MI+R4J?ESQ"O'MZ')(D77\@3^R>^*I#O[MGXF[N.(QZB@DRF@D!N7@6$RA-^#
MU7!4\^W,B1H[WG\V:N)#W7OV[+[((6XIT@^%^P-KAJ-B(F>H,GKUT(PNP@<T
M?]VWFRI;;EM?3_L?_,P7^#A!P2#.$79GBE:6(@PT($41(&!D]NGPKMM<DYJD
MS3ZQS3,>8[?K9YED_&9/,HNJ@ID=V@XC5/5/9Q%3X9>_:SB>\\Q^&8J[[E?\
M"-]R#8;!OUT2J_T>D?B;^AQ9?!&B#O3/V18TT?2PS;?5%T;7J34DDC[3V8#!
M1(]_3[XH'Z8OU%CH:`.KOW[OWS]_O/SN_*4,V\"4<,')T\<DAGX$)(]NM9[&
M!Q'U#;N_0!MJPA:E^O-9HD7+2CSQDT2&6+-"H)9RM/7826[7A,1_M\GY67#L
MW%+B6YU]',;$?Q)K#$MW-<%.!JN7%./3>1V5R%!\C3<>/C/M*67FA&O'F>9_
M$60A@0#<L6I\_!"-*U9%T=BMWD\,E:Z]\?IB1MQ7-L3Y9^OO"=%-L`^Y5W4,
M3^=>#>G0<+M`A16G?4`=`3O._UR,R2LTT7;6.D#G,#=.1>S.W%@1EBB!JB7=
MM'X#[J]+&W*CLJJKU:B*+SP=,VBH=>.D%*S\NY!@`GSTF4%O?>'J6A9ZCBV#
M2E7#+WOX*'J,V/8.JU?/)KU$TL.<"$D;5PMT=I5J`;TD<CG2C4CF51"'`A9C
M7]0R`<NY'&1Z6GY!_IW"$!IP>F^(NOCO;@KK:%[L:0JIJI`<C$:LRXJAAX"I
M\)47)\0":)%""\VG]@BV5=]7:D`7.`&+:SFL@KU^;OT1AB7JX;Y<"C'#06[%
MU@5W*UKXOPINJV(A`'X"=7(*R)#GJB^(]OWG/TT+J`D!D[$!Q5Z-DG;3`'1:
MW%2HF$7I.-OT!7)+-9PNW5%.BR\ZGDJ@?UH1^Y)*W.N_@<"!-TMP=Q\Y"4GV
M-.NLL-#`+6..:8E0\BGC%%[_GM9E%J1Z_R@+2O!K"'9IDBV@!\@7LL;L^1U@
MI3C@58P;%@N!!'8F:HG0L8,56XS9;RNJ4F5!HMZE?Q0_V$,POV;;@_B0]6X5
ML_7$+I(X7H^)]T7/3CG2#_*<6^>K0]<;FINKN3T\$6I,:9Q@.3S<3/SZ_.<.
MB-D:E"?=^]Q+*T8-77T"^<_GG;\N_I=]536Q-.ZAEHB8)\:=(S4Q)AV]<D^(
MYM'K[+F/U/78ORLY3S(I:"^&6Z\_,S(^M$!V4%5O3\6B:>`$BZ*D8LUQ;SWH
M7Y;N#$[MN[!S%D:CV_>;)1A*(GW45'B;=$W=(__K3_^.1M>1X52X@@NB8.<!
MVC*Z+UG^D7<17(X<'$<EUO!\6X;>.@JX<XSX7)XV_V^L\?P=6,5/OAC-=<`6
MWEQ&R8<:90Y!)=\.EY9F&75GCT^GI%@9H?PZ9(56B*F6ZJS%+[B&JRA"CJFX
M0_-WAT:V:[9EA&D0M*=1+<S?;^QF6GB`:Y52`V&PO\XP,U(_I"\."_YU?TJD
M&Y093,V]R@2-L`P*,[J]>V%8!GTX?F'?=CU&T^7\D$L535BZ9E?FO+&^)SC0
MB2_9:=8;Q7`^J44[H+P7O15<1J;L#51L/.!G\P2OD57W>_:>TP:=]JH-]^>>
MWX0,-+.<P^80ANI0F*@6X-&&KO@#3V214^_/\!^A'BADT,38MZ*3J2\X)`U'
M)-+L47,<&GAP4"IBZJO9Z$`3XEXUQ+SF(C+876C]Z1RS2P^5\4YQ:2O!3IP9
M]8-5\ZS,*@5F"[Q#.NO;Q@7K:![7E^:J=:BA_DE=B%,#<K`<[(,%E1(.YBV)
M"TUY="B?B%IEY!U,4B<>I,#HZ!%0BT;2`),.X;I=I]/"@7'KN8(LCNHT>`.5
MJ.79:/ZA:VBJ^FUED<_9R!D^4,2H$V1TFMLA#HPI1?WT'ZB!8%K;^OF8_Z=3
MJ/M_ZK%M*:*X!%SZ[>+*J"GU[%YC\712&OWC9<H(,MS9EB"IP[_PX&P.6TFO
ML5=DXRBG@=-G6&\[_%BZQK:]T*^@(X.H9O]'HXZJ`>#VT/.9.Y`0C@!<!3[H
MU$R4>@!@>Z5N)X?S>YTN/?;.`*287&T-G-E?"LT>-K%26`LM<%Y&0'/>I%%.
MUYI]![20C$SLMP"^[D7Y3_;#ZIP9O!T;W2.XX+-[$P(4,DI9G'IRL#`U02K[
M)UU.AVJ-+6J)<D7*'6+5_+1.%%`Y4=7EJABF-1K>/#6XG*W"K.UJ&O7</%GF
M0G3"[^Y?L7X,KXR;6AQ@S,.17L"V$9`>G(@.KD_Z&-2R`['7;!+,2WXR2.4U
M`$0:.N8$(!1-+TT9U!J5`#(2"<J@%]S4]QXJQYWDNV&5<(Y>S=#*A8=?7036
M2M]L%OK7SD'SA"C/TP5,GUVD4W\-1ZU#6]A4:+R14S,ME/K),(QKX`$KD-]<
M/2D^%(S3:="#^+RJM#KB!5%_IT%D/L8)D3B%+(9<</@)DLKQ)K%C3$]!1"]Z
MON/YVPIL=-JWB`<ET0MW'Y"\7S:R6.W.&I'H$\^5JMR][]!:#DRD`]M\6IB8
M1+*UYG=BQRHU!P,&':U5L`>9](`//9HC\H.HP3.:96652K$\=("L'4Y?W58K
M@G0.DM6'"-<C'3J!1ZA2RB(,"0L.O\$=NTJM1%XOY<2^&@5'=KW<OHY9$7*A
M6</IMIREH_5:%`!P)U&PI4<578;WK3&7B:3_HTORETIAPRYH@SZX=KV5O>(0
M23'[GRQD"=P<XJ`V.1SG/N/-LS^D]@3<V[UK,-$+[&_GB($ONXB>.P)5OL7'
MV\M=$L;+S];S017=(2LGT[\%"C;Z2CV`PYO$O(X5@JWJODE7J*^!4-LOAX!V
M8H%S]R:AB:;FNV4>"1"6I,#,4B1^Y'T0LS+QZSP4N8W/B'7K;*$D..2/7`C!
M;XW^/X1DZ$3QU5\%%01F#<B^V":KA$#IV]VFO7H'77Z=(5ZN]MDY;$2[]R.^
MKZ&Q,B\N>8'S/,M&'N@K9;`WP02S)U;K&D7I[L\>-^")^BASL2KZS%(WN8RO
M/SDF2JP$_@7JA+@#I0;*G9(CXC)M04K\2`LD,6'P5MZJZMAD2SE#9O5,T!<C
MA*JS<U;]$$TOO[*==!,\Y2+R,B,%H:QI;O3XO$:+M>3Z?%3#K"THC_D*(2BM
MCQFE3NIC:U+:/C1F%U_#9\"9H'K"P$HK*QGE^W8O!>;PD/"&\8UJ>];$KS*)
M`0CN4\X@BR"0FT-2:]LZ692PVW/G_*F9\8Q]"3=_.1<6ARVJBH7TJ,V-'QQ(
M!TY2@%`KQP3TO^N>)!_#-W86JLII@60%#[O6])8%)5E$#T>"9RRQ7O%HR7?C
MV3^L'_7V0A9`[L_ZAGB%6<OVM'M7XBT>(<CE0^NUL1XU47+)S^=2<[*G06VV
M!)N8ULS[*2*U*_=P(\.U.;\;[.'6,("];C4$V2P>D%X+&Q]#[+8F$%ST<$L!
M@J"\"*U.ESW^HP>*V6>:6)XIG"?>?H]>Y6/V<@V0G+I\4+!'!@&@34UAMLZ2
MJ2RU8O4H*[78+X)(T3`&L_'YOU="7N?M'"3'))1FP?)`UAOQ9(`NI\RUHZL^
M<$][N]PN#WK]6`/XNTYXC"0AC>>GWRM(IL.YW4HDNUP@T8=X<D3KIP)\G7\V
M2QD^SWUR;0T7:<C\RHUE]MMF"OOWA[&G"/QUW'6K,8"^0W(2%Z^RC31#ET<[
MTYD\Q*,_L<EY$V!^<>I/"M6<>L8(I/"?3)@4.+W%V,K@D_Y%M^,S2<]>QN'S
M+>E<R8A*`/*'\.#QH:<7YXO2;2`7Z%0-\XQ*/L-AZZ$`G:O:GV0^)JW"%H=F
MHW*&U,?"MS,GZM#5\_4>R[OA/I:,%>==B==HO?OA"YZMF2-:7KS1AR.U+D.`
M\CW)D!IQUO,E<K*@,BO=N+5IE\]--@/?V!8[36NA%R`(&[>DVR_VGX`]M'9B
M^GXV\4#4AD*`IZ53V8`V]*^?K\%:Z1*!04,.,!^K!/)(Z`A8.4[THN6!_CL<
M^`K=7%59K#'%J31$#?#Y"7U?W,#:P+;\Q>&B+SV*N,%-AV&CC/EQX"'[7`3M
M(K>0>/Z(5C`V2S/(&8I57?>XC`V2'QO/['T:@#I9MGKPK]+^+.VV1B)FS-``
MRC,(V*9R)05-7,IPO;A8'T:'BL9QOWD-@!R-EJ2,:]'HR;PC(F"#4W^7WP2*
M:\:[T#S&9`2U-G0H+0Y7!B1ZF+*0IV,PX3+J(-O.#J>](NMI)L!G%=MUSXB5
M'P@)/8Q5^P\N<TU9"@Q%*_6;WL8K#^$Z^QM1&WO84;J"<1GRIPS:#1,Q8G+@
MM4M/#)R.TGIKCXGFV326E8OFNC+9MT`+/][R%M+SZKW[H(BV:1@/G61_+V5@
MBITD70?JCT?N]W`3C0PCN@&Y#]O56Z7V`C?P12?RT6)9%GYU*_8.4)'&]"H\
MZ^T>_POH]G#I4B;O5X'+3#(C^!`=21^3W]Y,,$I$'D6^]%NV@.`#T;8"^*>4
M"+=Z<&R"DKV;<B6N@?<JPYX[S`B.F);9`E>#/[3KL#6'Y2\P\'R@W(W\9:V\
MFOI"V8YP0H<K@`:=<Y_^<,7/9'U<18"BW!*)`WBGEQC(SNW?O],HAIE:YL6T
M\N>>IVO=(8^>QP?LCTLE-XZDWDM2^4]KX=ND*X:-"?'BNJ1($L#)I`"U%TI(
M<:-`)(2R"Z.UN-"T=%^OE4)H%B*=A,9RK-`J'S-LEN_B-8#YFR#>AY'X*#3T
M_CS.G\M_DOHV7%#HM3EYM?#@?]9"SZ31%TS*@,9R;E\$F=4I.,\Y)*0E>OIG
M4I-S>5AC?Z5(PG/*_?`O&\)I4Y)%6X7/JN11??57$M\P_=OD:K>$^7BW;4TN
MIWTU1?#8W9AW9T&UY*OY4YI=_5%\MDKD;JE^Z(EHS#BXCP=`YVWU[]2+00P5
MOJ;S/^5#ABH8(H@^%8=WO<:[+-@4<!(@!)<#ST!NO62X0M9'`;ZDK##ASAU(
MNDFE/T#"+D"%@JP.XQ5:#/-HZLOM4::='D>+)P\J1)UT9#DL=I2)&_%.IP1X
M3]4V@-K@N]\,N_%D:Z56ZE(#WIE5+*@A:\S2!MB[BDQ!XP5R6_*:R9X//1V7
MV+IORM)6*>79\4O=E!'UU).YVHSFN=UNM2^Y>K&Q`UM5T(G'*2E@/GY^$,>#
MY$=MPSH/3@%@TF^;N$2%$A\*,K/4:*DL7IF.0GY>'?!`P[`-?2*(<]^_9"+%
M8.N^(B3\;T!?37?L*;O,WMIN.M5,,L:6_^>V`FGZ1X96X*4J%#1HV>O+]0_5
MRUYF/#]P:'`@96-H;R<\/R<[/SZ`RUPGW?!(!:9E_V(T.18NZ![J7O9C]DXK
M)E&(>U:EEB<_*T@:IC>H*<9L,81M5JAO(/;YO*^3E5>M$XI\L5@#`RG9O+)<
MKEU&%SSKA?ZRA(S9X0,9`.W#VE?@1JT`*Q(Z?"=MX4UE01*#<5ZM5`,)3T/F
M%(H4ZWI.>TKP//&*"UQ(XV;S><+:;*0[&NO%ZT_;;.MK/^^(\WG>>C?Q6`!.
M.UP>A*CO3#S<,G*<X2IV#EY$:$6?P?L%>T^E[ZWD+/3)KU_;V[S8+!Q&+.:1
M$>`VZ)09QX75CMA.+T]X;A"%DN4@")[HLZ7MWTX;J%*4\,$=L7<>S7YN@2I=
M<4Q[\]E:GEK;^!WA+5%<I>(_N3ZFL\\I!TQUL!3HF<ZX%W)2IU$\/(OFD4#5
M@1_!;H.6HDK'^5BVNI5S/P19P)WL'[CE_N]RO$<S+(U_%3O^:5749Q=21]UW
M1WLPN',!;3OQ?MX?.S%"T-Y,6]4?^*87B_[28_8S<XY''F@!IN6=4-TK"@#O
M(_584[GC<]#Z3U^X9,6OL/_Z)[E$%X_F(T,NR0A7K.O'\JKV6(;IJ9M^U@PR
M4)$:GGP!B,&44->/E&>/MCCUKLCLU6,:ET:6J0QK@4/YDFS^:6@'Q/BGS?T#
MT*9,-*9TH<DOJ)L9Y?=V"MW&EDS2!-YY)5=^RPP^-.).6N#8`%`_N&OW9![<
MN]$0H*[8N)Y<$'&0?01[4-XQ*1@WH@V>;?M>WF_[M4]<SM&6T@WK_J9N$(JN
M8YF&S2KGC2MD]I;*2'>^6_N_);<2,Y#9K=_Y0;_U5EEN/5>A)E36;$:WRA3W
M"R+*B#4[X`E6UY:@78<-$==_DK?M2#\NE8\5+"O5^GTH]:J^O"T@1#),J3+`
M=;)%87Z[RD=/Q^H@=L,#MNW5%YW?(ZAQ+JH2=_5;44A^#<]"WX"'M8F=&E'W
M3$3=P=%(-ZTSJ8\>CDO_*VM9V.D1>``0:2Q'.5R:+:K,`9)!0J*=S:D7)FI3
M3Z,0O@C]8NXUT7`'="JC>V*"''MWPR=;`FC=9Q27V[=?O1T'K-@64HO\5P%]
M:F-"K-.\P5Z9DQ/(3C`L&ZRVZ].-!Z:9[3"D;+!3`QVQ"S;=(=$JD"*#O7BX
M;NMUNGQV1FNT0G%0\:9(+OL&Q1`+%1\>*E5`N(;IH$H8_3P;3JT$(P`"FAF/
M:0(#D5Z$"I^TDSS_@W8Q6+2N-A$O$YC[ZU>/'W`VY=;K7:B"%&:<3J.`AF/!
M`3Y/0&N<\G3=73#_OCFK]OS3F7'4&HDY%3HK`2GH<.4';CG11VYI^,S#)B6#
M`JV4-AQ4([N=_3]"B<`<`#OY*7S0_W0_'FR<R3_]G'SOGJC*A\73>S<KD%9G
M\`@L#I<C"<3*^F+6FD(W]*>IK_NOL:!GUPM:_L^3T$T*CI>`9#@'0`A3EE>/
M\6RGN/JRYO^`T*M$0!=RYL'LA-TO7V9JF%RYH\FH.W;=.`=/JY^$M9*\'N8!
M6Y=B2OTR&3^_0T/NFWN>:?^M6`A!74-M3I&NN%.30]VNN8*9C!1_,I^WR*A2
MR+]]>TD*>A+1-P@L$Z;Y^H=LQK5M2[=J:'G4(Z@2CY@;F_GO=3!?!^!+"/)L
M7G5)S[B03%BL24*YMMQ:,Z_F<UX;]%^VOY;5J*GZ(L@:2T;Q2KC?Z74@EI,`
M20,)/W>4#IWF$;2:3V_66"Q1#%"SX&XI8\];/]>"\6X(5ZR>[3"$4%CM?*U]
MNS9SQ9I*+38`LBY>%]9!E@DT+>27@&X>J`CW>E;SI1%."G'1!,^L(<AFO^_8
MU$15@9&2'I7MR*_=%8&>U?JA&"J@Z6V$-W^L!8P(K23VM-8F]9O3)IE$[<RY
M#GFD)%=O'6*>."TD,#>G,!6A<V[#B<:4"5;&F2C<__'B:9T/QH>Z@U!/5`Q\
M4/M(E_`NJ%I%L/P@;YAJC*I0>N\P0&MOC;NM@[4:A0V:GSAF?MPL$.^A0;3I
M&924IUPD/2O!V2>8K^FR"J*H(RF3&@N;^)ZOFNR1QCF>[@=041_(>P.:F;S)
M$Z'>S:Q#30DL7EL_V''G+JD4]6"#I<(CB2R"UU5L&JH\G0`^K"<\T5+SD/I9
MQ+K;OCJ3TY$^B=^8V..!O^:?2F?*Z<]]D,20!ZO:N!T_&3)W7J\<@"4OCSY.
MTX<3D39PEJ,3N)]OVX:L0T39;M$G439(U5#:3>PORXJ:8Q<4L.I)0R0U>8-G
M==?*QSCG,FRTF^Y6PXDUL@Q1`5M2<M%A0JIV!+NE_=#LNIIN4^#B.9<ER*/!
M1(>[?(('K3:R\5,QH[S,"%4GFR92W!E(:-G6D'^QE0K&KB&_N,!8X>["1:^Q
M;U!8($#TUNPM?0+TM='(^G,A<DKO#94&_<U52W=_6`@_UW=\J>E7K+`U6$E@
M"0HIMMY#O.*F8CU8U/3??UXW!)NUBUQT_WV9=S8##1*#\L%HF])\KO\7C"]Y
MR8D_*T3-_F#!$FP#L"+@H"'FB=$UC;U8=OF42=,.]V*J?-TP",#0)Q3D8\9I
M50?U)2>]G<NMKXW$HF1>,>,B&!#(AJ7;<EK_H3.GEVEZOLAL#"2_O\+:3S"=
MJGVNR4=M6=Q1FZ/FP*86<^T!>KI')R1XGG7!)U9(=B&A<9/UF];S=RML962I
M>S"OZ18$Q,J*VQAI/DUQ%F=)AZ384D!8@K+"6$VFE5JHD4='`X;XG0&=HB/?
M,!+!A-.[ITGIR7^PG'5@IF2:"N5J<6W`SK"6KF2K$>]?#O-[2,7$?5$>C%Z=
MH+&W;(?JZS,CNDJG1.%[2PV6^^N4/X1ZXDNW0B^6`/T?.N!NU_'/,@&>0:#P
M:F;F2)*I7P&^CRDO0$US"^EF*V[LH#:?+V"JO3>5'D@[UQACIS/B@W#S,&(#
MXNP5;`/20#W)WT4T!SI%%Z]\9^S2IKN5>'VAV0]89-//!P>CR&W]Q;GUSQNX
M3;BG.^M)]P10!U"_]XZB8A_N;FFEQFBL*<Q?MJP,NOA-LQ+M+0OZ,N%1&!G1
MS30':.,^]2=@M.H+AB/T4)@"+,O!'AJ%Q_KGC$@9X=2NR.#D]YCU-^PS\6[,
MI"4R=KVMQK2<)D.""%]31B+9G_$/F_SXUAX%Q0O*[^!2O#I1W4#.=`'ZEEZ2
M<,!O=63_4.0T>GHNEL/#-U+*:HI=,L-H_D.QGU>KT02T:H$Z;+[[36=MU8AM
M?7GF5)_KI^%_'K)@=\;[L-HJEF:O:Y2!;L5P1&Y@N0TB,CC%+F3%C9([-S']
M[R%$>0;YQNH8#Q/N;574#1[Q608C8I,;%<)\P5-`'/X#9Y89M^^YQG-?F+QB
M7C*L[79F^W]30PZWFK[)!&WRX1+E:9Y.ODGF:L.H!4KQ"C=?JC[7%*XC&\)F
M(W62G1G;3F3/JDG/><S<*GO(,;5ZF\2:'86U/71'4XZT/TON#5F8E#+E9?AO
MSDH`*K(J6;34H3<SO$*=]>X:5W':NY,]:VMPIY8\8LJ"JV<[.;N76ZPSV:,L
M!>T9<.%8DM3!^?KIXIPP8`]G$-KPG&1'!O_B98W&QO[TT)!V6'Q"9+3M/.LN
M>4[H![#'`P4//>\1;=RA&\.8*KQ$_Z>-0F]S.-5X@'N?[SFZKG'ATZ;EP*AG
M;FJ\V+%R28BDGV8Z[!,BII,QG#4D0DZ]MWN.+D1P5%(1!WH(O0M%-:]VKF1$
MYHZ7?*Q?(H#>5B<TFPKH3(-?#>;M.0M;F-CT'F.4\+8C=1`P1()UG+]LL!6*
M@T1OL74U,1VSK^4PPA?*5UYLM<T4;<>F\SA&O$3F8=/!=S16BOB_RSISSLZ4
MMO[XKC\[:'@*_<A4LM`'7#X)KPMH4"8IVK[9U1(+ULEA:MIO,KH/\@^!1S#2
MYUE=]&,M/+'Y/5X_Q"45)Q6IH*:TR$UG"4E=:B#2[&Z5+8(':YAUE>D0\3&>
M7_J#L&&X_?42#6P::-:;)FQC,+6A\W&EF8Y<&B'+WH9M`^2QPJB]2MN-DJM8
M]Q(X@T=V<^K(L>];/4+F)5=%V1-T!4GO^+LME#4V&4";M%PS"`.>]#S^O7*"
M?PR2_.@IR6ID/K)AKZ\R,MUQ;:.'42(2)5G_G?$*@ZZ-AX2JC:6(0LQJ'S0[
MG_6HG'''\/5=<"R%R[#Y1ME:(]Y8OJ+V^;6D%(@2U=-IIS]I79'_]C],?I>E
MZ[Z\88F>*$/I>-B5BA197>]YCN%:!.;"*:-)K`X0';W8GT!:*0,YT6(D.91J
M^I,TXW*.F5QBM:(%YZ"HWGW?.WV)GDHBH[#,VWMV1@M=B7)4Z2:N2=7<@`':
M,G9@(T$>NU$<^\4A'$,H"E%EW5D(SP$_6]%Q4*XGBY:!?!`/#&H%XV%ZSU%$
M@@-:KUXRM[F(K9KYQU4L*^E)TB%56'Q5MQE+!<,\;Y]OUQ-Y\)9<VM[%XG7;
M>.5G6-$DX!?MWLRG34\HK8_E<91]#UUX\UEA^VO^&FE%T!`)<QE54PA_G*4\
MW8.9?O6*U'7>["3)O"ITNUL\PS3#TD9;8P70\EFL'(QJAYU,D["O2=^!=#NZ
MR2I-$2FV3</46_YY]TA*I,QFD['_C@:`E4(EP0:89B)$?RJ;_H%,ZI!S)8K4
M>.?H[GQ^H]E5CR8VCJ&^S&7!3FEML;YE%4I0\_EDS%]F*O9+K#3V757&5,M$
M622ZLN4@&S$OO0Q%!?>%.ZZ,HTDDW8\K1`D$I4&KFT?D;BT,XZ8^77P6Z@"/
MM*)FBY_IJK\4)ZWQJ>.GHDPF1PNZ>!%A#I4NW,U2@$KEV)#?F722CY%S.50F
MAY&DX1C09!4#_Z&:8$<>%:C5W^4Y#9E12H"I06'Y[F?H@+%/3TYW0F8/`59`
MW+N=90*2\K1HWXDA&V)^93:/ZJY4VZ^TK7F=Y`Z#"Q1]0;<<'H=V"-38`?M%
MCF6^49W#E]#3X)-*YQ_$4(\0C4U/0[\'2$@Y/"QH3-D[$9M:51=M)GMJ#EL,
MT9)P";O=3EX75S'X-_1FV:Z)V<$J4W8!HN>+<D5ZT+I3&8U;'"Q^4KPKZI!O
MEQ<PH&.NDS$(6I!UIM[?AI1<W,M]0_!''(ZBEV,&-UHA9GO^P>(38YT"`8CX
M#=LZG%;/*22A%$Q&F%[?S'='U>6+C`4RJ\73]^4G@2Q/)U2B@G,JDB<%'5MS
M8&;`O,S^AJ/[1Q(('D\4R%&=*PQ]H(V2#OO5\/.=TO:QIZ*3G^$C9<JED$/^
M_PLUV4U7G=[[VEC+WM$1K\M)A&^?\CZL(O55]5IW]9W;L>'YOX_<^3Q(^([R
M6Y$+_:*1>O_(Q').2:^090-`U_T7UV";-?B)9Q4U$2!I9\/RZ=$,7<5CK)8V
MK/5*)P0@%A6\Q"9DSS>US_V.&#`SDTL8JA]I:<-`]^:X]XK+YQGESAO1`.HU
MV53MO1R]*S>]QGKR2`3U@E'Y;S;S.$7-\L;$3>B.7;G,\H2941_->/H[LS+C
MQ:J#M8"U/%OP!=E@Z57*V0Z+4OC,FDY:O6!TE1EV%M-N`3Z#0:<9M\F7>O((
MQ"&F:L41:"#&79S;8)2;+SLQ7'\H@)ADJ?G0HQ4J#J/CBR]((_+[O+GB^K&Q
M7F]GB`R-G0G)?Z9UNK(3@280DV`=6!EDP^F/+X]"IZ<$-&YYSN.B>P9+S"C:
M`RU]5KIF<#['2R^QX=]WAI+U%8#T:"FR::,2(U>5UK$`C'+SG&A.^8-Q36$S
M&9.XJ+T4`$9N]$"$4NPG4[!W.2O-=0:\751]C?-;$P>D*+]-=30'#C?:($MS
MZUS(@S)",G>&Q'1#8NDBH'5TRJL3O=GNOE"4;G:\`BX>41H.K%'K*QH[6KF&
MDK$J>TIA4!7Y)9HDL&]V+N+4;)57/RZ^?4FLW1K`S3,<A\M73(;9.,9`[)`W
M(</[K:62<4(K8FF"XH1_;/XI9[&2D!J$R9/?;MSS<0N6=1+J6'KIR'*Y04NZ
M>`&JR?W`UK8XNG=`E,`/'GBRRFCVR.IOF"5##!Y0_:7=,=?0?H*_]CO'YHAO
MEQVZ-VH"@IFF7\02]R!&BCHDAA*E!5Y-KD!F!%_=:M"5O8=!3F@TOB7HZRF3
M1?KE/+H%RI3E<,FRA\6.W8Z?+E\98P?U!]H1KRPMR6OK='N/1?,!KHQHMS8N
M%4*-G[!;N%Z/+TL91(7GK$SSVNVJ\]!X]^2]`4*+Y*5=Z!QX)*$*5#C,QJRT
M#&&"STK0:2E+A+MG#1[Z*DF0*WF/!V\I<?+R`+3UH&:*=0(.6]P?@&,-)/A&
M&D#_$`&59Q)`F!'^TOJ=RUT!C&-[CH,'AI^&2O[VGQ3A`'ESA]H-S]<9+WB[
MH-LY7&S&W58LW9H/=:I?A4G7C%QUA99+H&9J6R`!>Z6:7V3W4$6$_`FO`P]*
M`MUA4^H8QL]6;VB<08/,_8Z*Y96Z_F2DTF8%LVT!6>5B@`(I^+@FH*O,@=/8
MX",7'\,:>Q=]M'EL`*NYIIUQ^C>4FI]%*&Z=[;ZO$`Z$1G_AQ6:M>@DY@5:4
M-)[5(SK),#G\.;7.K`V\0F>@@5)I*Z%`RYO=!0<$Q[':-])D"/^75\M5JQ)G
MJ2S?E]6/\K12E7$EQ+Y^N^#RCU7H#%S5W;#N*EU0S`=T&T2SG(%%X@@]9GJF
MIW:RD)(2STZ4C;R(Q^^@22HAA*@0\_=JWX_7*4N]^4L#4)/61(@[>4[R'7(]
M^+=?+Q25O$$F,7=%KG0VR?A/`QX[.\%6T9Z\;.VTKZUG(55/W::B^=0[G.27
M-L69JW>\F^76^PQ\0_QE[@%VS_BG6-SV1?\LZ_&OE==A/'^5^V$[%-.KW_BC
M2(SB?KX.P(!1("#/M<7#&]9A9>W*+;=YC"BK$J.*M(0Y*N2Q`%]D4?CFLA,X
MGZ#*QQ-=)=VO:07C073#)4$?+7#$G7?3,9,&P2/YT=8;C3>]O`?=Z"I8`_;3
M]D(F'U]P$2AJQ'Z^;:`PB<WC`3-%2YX(5KY2<#QHLJIX.A=UJ\_S2>2%/"5<
MJ=VM:&<;(>*""$WS_B(HUGM8U?BC#M*1&@UH'2DC0/YTAMIOK(S&HKC)J^2C
MO>*6+%6P2:9R-6<6Y/?JGV<ZM$_SZ2&L._XQ5I"F-AMWSO1I'U&%_+'BCN-.
M,0!$"[V\DB]''\G9LE`;A:\T0RE7WO[6!1Y"F2%W-E4N.$'R'^3*<!@R@0<'
M%0$A$>?+I=$K!^99'IF]X&OYOFIPX=WI)GI<\Z1G^.>LURSU$C;>!/;K_O3>
M'/YPB60[6ZQK>:0N*PR,7Y`H>W?PKHZ21/^;EHM\_'9]>_EP:0I#`K?Q%EMP
M[+83RV\0*>09Z4Z33J\3!NII!*HNT[/(;I5)K271*;X<M_4<+-P9_2[^<.BJ
MBF=A=L!SV_KU+@5!6F(S2`"%5M:WL^G=CJ?0[L=,_HT=O%F"KAOEA!A4QDL4
MZE3\`-[W#;RWZUC`Y`:DMN6]*M@['!2J^9W<U!W#6LH$=5257-\:S_<&=P+P
MM9F*D?GH9])Z?B"K)QF0C%8(>V]+MN:^\P<0XA2Q+;B@M%V]4`J<789D'NDO
M0"IBGM8K1'OHW@QPP>S?61PB^/J&@\8V>V.N7??;.M%D>K:3'=^5\VJB8@U7
MI#\C*_Q0AGGCA)#>7-G+)%8DQ_+^(+.CC]C+<L&EGS&;D"A7Z;I@A?#S*7T.
M&6-;!^>9*"GAT=Y@Z/CP'ZTYZIA'_$NOP/,76Y?/)-!?!LB,LH/W_I-E38YJ
M"X=ALVIR)L,D*Z<HXYC%_AL,7+L^6"GHMAM$.Z54/==Q]05I3EQVQ(.O09F2
M[@]38L^\C`/_RP!,(RM^W2PO.=`NHE)SSQ]S:Z(S.>"K'<V7T5V];N^UE^?G
MP>+$#)++\!:F=Z52A;MM!^!8KQ",T,/./D55OPQ,,0^VE8ID3.;3_`'`+^4F
M\F\DG[.HG_E;2%8N%Y\]2!MQ"\@!_:XWM$^:$H;GI4,`76Z&A&ACU_^>^P.F
MXP4*1E4M,B+".M_BKLI(LNY"PGMK'P@&Y:ARQJZ[!'LEX._?L,!LAY.H)M?0
M<Q34.T=2.,Y##ATG]:R;$EU-IBANQ(:M^=C!.8HIG6)P9D^%MMQQ8;15)0F;
M[VF02K5VS:VU3>;FO&$5)\XA=K:%<U79,%6Y;B`FIC9Q>DM^/<[A7/SA_2_$
M7,T19S[SF-)N%B7C?_J+V\1"<:>YVT8?@/(3^XGU`>9]VO-'*0E)'*>K0=`C
M$0>;3?@NWP+O7ID:B6YO<-J&#YVA<W)VNYZ`C`!GZ/Y>/:$0$YSZ0RPJ#X*H
MI;=X$?1,E)#I\L$T!YH\7UD\B[NJSAA%'("3MMF,Z;"DC-2$G-MKIOXZ=*@.
M`C^R%9&%3&`_T5#'&5]:Q);9VB>7'?FS%B@40=_J!#_I`<Y0_,('(;+V$TI1
MF=M1>O5`=`@W-V3"_OR'L`E41MP#9%V8-,MWZ)H^WJ"L#T$7!>*T52=G5^P9
M&92A)23TD3,O]AD<^HZ]]6`L<S^-_R'."Q^V'!ZLP63^OJA7=(SWXP!;(LMZ
MDHV$B8T3</J:2;P;N&C6&X"PY+GCCS.'#L#Q1I_*%#'8#5(H.4SZS;QJ$4#B
M.#)A];Q-W%_-O?DEA*X7#<`"O$%[VH:'7RU^?QL;6,3'V2W#;#B]\/X1F"2K
M6M97J>W3:24,DC,I_OD)MQI3F=#QODV'CKITI&`X4L+Q)OA_D/)[<:Y;[&MH
M(ELH:!M(G2.7_$)FS)XGK^7=DZZ<F3O&9-J]:/%2,WUO(@L@1@J_$/)#7`L)
MD9Q4)Y)2G1A@"#Q?./CU)1H&NBOW+I1OFI#,*0*V(I(DB'2G+=.D[D)*9P#(
M$'*74@C&HMU':*88[F-[@N:::?S1J-&^$VE`L_J[`0H>;U^V3KIC00LCZY7X
MV!P(#F[QUSN'<&5`YU6.;"_E_Y4/2[<WP21H9O(Q;5(F>GLF%H'I)28K7U)'
MOLB-W=+#Z91LE8VHS(.7#5;5N$Q`/!\C<V@(VUJ-@F1EDP_=M_!5&TV78<8T
MW4A\LZJ`H=-F^GN/90O-`5DJ:CEULAE6V]I3;MW.[T+`1-?('#K,]9Y/)F(8
M2(Z0>Q:VG#4&'G;R\+FLU`*W';0LU;B(H[MVN6'K<P)\42ZKP+VJZFT5?Z%I
M]ZH&81@]7MZ:IN(_:_H2C)D:?IG?ER5W5X-6@F!R:KM7(E+P^G\ZM6$]667R
M=E^9,R*._-)S9N"%%HN12>"*B#<;K]HB_"RR,3])"@QQ$MHN]:8H3A(?$0Y7
MWJKV"]2&V1P7#.P'Q?*MAE8AM4B47KPR^JO$QF6>,"NQF3NCURI`/X+(>.C?
M]G`T2=P#-/I+1AQM['B9KVH`&VSUVGTD(=KI#!G05[_AZ3V]9F6>AQ2)*[>"
M9N,%VZ./Q2B,A]2A82WPEQJUHW#HTI8(?21XLJ00@N<)R*OIG9D134,B,OWQ
M:+(U;I#UT\/\FN%'(3O!^"UP:]';MD+.J7/4M\0%+F3:%;X@^W>3ST:?>;/U
MWI'T)@/F;-RXT%6!YA-R^UX,H>XKNZPHZV>BUHB'[,<V'9RW)1`HB"0DY_:^
M,#(TO^L4VUB\269DDX<[).'7:;>^4H?;$(!$3+(\799N<-(7UMH!M%*.1#AY
M_],+T^J=]H[!S%E\[-Y(7^LP$JY19CROA_!4FL\I!BR\^8*CXT:)X;.%EWYI
M.ZI14V9))FM7@>CME0/0U!E6!2:8=U.J?Q(1^`K%)15>J>)UK#?LBX='OXE^
MP#A+<AX$.'M#?"1D4OHE!0:O9U!23XJ^C?T%GQNO\K><R<?P;*D'B?`!/K-%
M0VR.J\0I.=VQ`4;0JXB8('^"VFU.F:9_=EJIESFT;H`^ADV+]$2,CA*M```9
M,3T\;*E.EQ[+=ZN9Y8%.U:#5,Z4S@?-*-W1!TUL/\3T"JE;O%$-7E7?8>/AX
M[].^#X-`H(A69Z*J?+EEJ]%>Q4I)6KQS@>*V#)HF"_<ZDQ@=E842R6/PG8HC
M9':VZ1X7H.LO4P>ZP3`N/'#\"!-)4/P'HO#OMR:*'.$#C<EYL]72"T"45"%#
M1+XTA$$9??>=#GQM!>*`#>S]5'O@'5ME[Y^FHQ+MVM$:)R!BVP7P='I5=9X/
MLO4/DN"@]JHC9OEWY^VC!]X$8+@=PI?^V!L\FN,D?EXX%,T/4.!.\$=:.958
M8O,\]VO!"8FRJ2BVT5UTF<"PU(>->CO[+6&O=B-\5!U-"NNQ\6D1Q2C8B<IZ
MTV^D%*@SYO:TM\XY"Y]1=53[5>1?-MK+HU?49Z7>,+=;\2`JP0:>`_'KD51Q
M$V+WU2HH/*!(8#M']1=W+*7&M.TG*U10*8_".C."AV48C"6,E__-0/U^[#-\
M^F*'!$Q^I0K(>J'FX4<;RX>O=<?%.Q@FL4FL<2X+G9A)LE5PA^(>Z#DP^8/!
MW@R7KD@6H%BP&C#=Q<R>E:F*Z@QN1A.:L>GBD>YAYL"%@T8Y4+/Y-1DT+&<@
M<K-J4+*2[O+#ACX.!=%O@Q<*=5)6]ADK0=8-$!(+/O*SO'A"[)=G39[DZ-TG
M_;*^0[UYY[/K6O+Z,>0Q&9;/IYH9<BZ8(R"K%QF<Y,3Q-P0>@]'MD[)G$P9(
M/NUA#F6D`ZV7<Z!A]8$?&,1;L:@R#3=B]C'VE1:BY%4M!:HK&?C!<S#%V.T^
MN$\\17S:FO8.&NCSB=&+2.EW6=<8YH.*Q_"N]),#%FSB!4A2](:8G^EQ4^?4
MBAB<#?(ID@J7?:U:'ETZX]?30^9-(5MMR3)I$]GYX'V??PGI.'?ZD]1,0A!K
M>T_278+ZT@KE.BX(S.-Z;=69]^(8<822[K7918WA3T\4K?C9%I17G^0(4LJ/
MZ7GLYJP1%CA`ZAU:>>L*#_H2TUHH[TF.9RU50T64US/8>7>-GN<Y!X[22B@E
M&MQG(A0[L,`>H-JM('`:<NNV&D-!-%VS31MB<9@YU-$J?KJ(LT_@4?V-#>O/
M1^W<Y$?>CA^?P@JPAC%N\KPF.;6S&:QN&-![-_OFYGS*32?I(P+QV#Z9F%1X
M2[B&5+LN94#[&Q_AVZ!77M-1<N,=&T6FBJ)JV<IK_I7;&W5"`A^Y\^;]#9!$
MH5DV$1C9(+BQ*\>6GYK_*ZK:+KGM6G".XS*2B@)/)&L%1`7FM@9!E,7-LFE8
MV2;*PA.Y:\90::@Z%O3??K9PS12?[7+S%[Y0;?LP'Y(Q46;J';G28UECTV(]
MZ>''(GDY[9?P9,J*>,T#-8M9>RH7T.UZU'/'>7TE<7CZM]'QJ%<N9]Y@@MH8
M3OSN,2]0V998M/(U*[`0YP?2KFS21&DN4013N-KN_!'-F>X0PQ&BZKUW!3=6
MQQ+^ZXW8#=+66J<G+^>E&E7CM4]!::*2U=,3B%UHR<6EG6I1\7;P?WV,B,6#
M*7#5O_G8L3T1JE2Q#*RW@3D;VY(8*0)P($V^2#@LCN8=JQ(V[@KHA!XJJL'M
M9DG!J4-NWUDR?W"?\P^4%WS*LTN*IU#B`CP"Z!,KJOGMA(MBF!37Z;P/@)KJ
M!C/P>2AU+YA0@2\<EW1BZ?-?Q_/*=*P21]N)0!/%-?KIZ]PK_/I9/=R5+^$H
M/!>R/HZ2A0T6]*W"4NLDG[-+U!,Y0UWV.BI2FCVLBRM/PHV*N4`Q7T2L)0$`
MC!.A%$7==U`N<K:@)FUY',S-KFQ<EN.!/7W%-*-60>2,8-3U$*R/413>9U.O
M1'/&*]XDQS%Q/X=6KFNO^71QX5#0OES<FO+]2Z9_*S$S!D8@AV'N)-6D7A-J
M*]?`6[PEU*""'FXXQ@!P[]`>@:0=5JN+_?NM788UN'=-+,IHE4@,D,ESEI\C
M25@I[*G.Q&):.'4R$4(4D_ZS,=L4J@\RGK4$:MJ7AKP!?*(WV5C7]V?N>?N"
MW;*+]O%;N6F+`MX\#366)V%CJ9'EHRC,I*D]I34*"N"K"0N[HX`BX)W/V>>M
M:DD4_]&*PYNN3177(]]W_YU[THIF%Q.9ZI!UE90SVR"LD=?N@"T:P=*\3F-V
M7+X&];;'IW\NAUA*.[J`ZU?_.9I6U['EOMK2_4`'SUSV0?+-MZ#:K&:2M\=3
M9`X;[F5=G=E0:%D0F"#&E,EAD<!(-H`,9U'RT@J.!.J.3'+$9+2`AC.@GMH?
M?C0TWZ5I2P";<6;QO'L/\;<,*3,_T.#T'7B\Y\YL_1X?+-^?S'E?+H$'26CE
MA697$E9S/QUVROQA)>)1_5'W5T`[S*>`M\%9+IF34*WFREL"@![+UIP(Y)GL
M(US,,)*_UC2-)`E/V`"!3I/E[+88/:R^,5=V56,`B,PDT[K&_EU^K3I<T275
MOND\ZCP,@<7+178JV@`^0""!RFP.\D2T2N(MPI*O(LTP(ME?%E!2\IT?[4`P
MU6FB#>*=^)FK,^IT7?N6U(SQ8+4.E!R'8+L37;F;Z>+,/Y,+:6,<[;3,0%[F
MA?B0#3N^H9H^3#6SF1'%_!0\(X%,2%(()W?'*@W'4EWPU/\LZB/<`9!)2\4'
M##++&)WP*3+34X`='F3Y4S3*H;XO<W\8]/Z;.,-PS;=C10B>Z[;R-0P3>H2A
MG9T?A15`IQP@CB0_!B-P@G'0E,)*]+(MXN)Q"D4-_@G*N@!@\\H"68;L4/_G
MR%I.#LI!J_5!'\Q%S/%0RF8Z=CUJCGT(@0[7K!J!B`".D)W-_:A"@6O5^5+`
M4NS/O93]YR$C7S;)DR2(7-LMH'C9V-:T8(EL</_7T'C8&X=VE7`7/0B9^RGL
M$HHA5Q]2-L`#0!>#?K"_Y-6$P=K&M`K<<6'1J$);QC&QI3XI[T?OF0QO(._*
MYN#5N`Q%+*5DQ35X@_<':S,'D,</<Q$AL0H=RE+()T<,C'UF30@QR4$41$@X
M]TD\NT3.#UR?V(UMQ^J12,%?JYK0I"ZA<98P`%L[-J(PWE>.7/E<ZX0?$(.Z
MA(F5;U9(3]]-"&Y*W/@1OU:)4*OCJH,%K*3#H@`X%?*?LT;<C$<E,9&&-UJ#
MK9N[U#S8CUB1`3)"9!C+>>&#RW?[7VF;]50&,-97\W7"X&<ZDM%/"FO+D6F+
M6"Q5,<<SK9-Y[M9YSXA?@41RR4$9ALUJJB-NMD"FXZ=8>,MKM$T0?><+DXC1
M@C*GH8-HY.F3?.N7,?]X]F_X]LR^<_!)-)R*VC*WCO4K./32-J,(S_%U6YS[
M_@+$_>!O*U!VL$J^R)B8%E44Y9"VD.5]BLH0=-3_B[>N_C_`K1-9$4H8P'??
M]'@<$#.<>:-A\=H;1[7(]Z2-F'Z]K$QB*,D9A5$`Z3V]I`NV1T/M4LSWHG\$
M\C@YOK057\I7E=-PXQ7S$BI8>_ANH#SWYB=(4!!IU2Z!L*=5,&7R<G;#E8=V
MRLT79Y`RI);:B[JW%BL51T+2(8`1OLT0N&[16%N]Z!JF!AR2.7-)JD2I8<N_
M`B86)V/EFW#+E/-(PL*4IHS5FIIRKFYRE@TR=9O6\'G0ZNESJP%1,22/:?BD
M@-I[^*+O+'S%2XNGFU3S'U+S<]O2SS_*MG<D!AKOK0.\R)-.>.K4@[4#_SMP
MFI"F4==,53C?92QDV1?``&[7BW?Z3,$ZAGN6]G84(+W+6-!U4T%AO(I6+9ET
MKB52SX#7+",F^T++ZGZ]]YD8Y.,T?>FWE=#"?=)_)[@&@OTOU5C(@>SN`,_U
M-2SUU?XB861T(]2%R;']LC"BYJGR&A"A79.FG'U2:="G^5V>+,LXSB]XO=N%
M;1:0WG@H=!'Q<!]\R"2GVM1->^@3\N)+AAFP?()+NAPHFL9N2-]BS2>.<LGD
MAY#N#3T=B8@6.L!PHYN+RF_SU?DR\19&4B;AFH01N=VS@)VZW70YRJA3R*):
MT@)_=;?16&`7D>>\+;5A=13BY"&3,M(X/A7&N4D^EU2;7E6X9Y5Z(_*46]W3
MC*MT1&KNW)3N?Z"+;QD_^$]4)+R]`:IVB`P@<L:2/4VBYK&U"5#&Z+Z[)HA8
M0C5"Q*@,F.QVU'0QXI9]?X-F.,<M&8;9=@``O(XL[HMP<<N_B0]K&N63D$2O
MS!R^H?^SNGFV$E.&&\7-T!,)>162T>K"!IT&Q6K8O1"'(T?K!'(K!*"N1L[4
M,?PK6\P4OC6YQ>QEW/"C03W+1XD",Q%7)WU4N.^DH9'LY[^[B)-HI1`H@Q;'
MEOBLLYW)?5A`GF.+`3U#J^X%5\TPM;J&5._X&@]ERA8KV%%@CTPPD;Q%1;!9
MOEHM.V7KCZ,OAUO=1%!D0ZT2M[`]SL-#$=&Y#0U+D^O#B0^I:5-DP($H(ZKO
ML<XX7O+=VX!FL'$9X/?C(6,^AY+$&DCT0*:#RIY$X(T"/C[W$$\J1'\@5E(B
MXB*9HE8QA9]U&)2`S8H=MU;2'0(^]%;GU`Y(N1NSP+6RW+X`(A(^*$0V<6T`
M/QI-7REL1BM_'C0E4RI/4B9@J)<!@1ZX>K%K)D2P7_I$:P[O0,-(DX\7/.WW
M^/Q];6""3(/@W?0>Y@B_\',;9'`7=PD32%G?XKL=-8`WN-1RAQ\Z1Y`!\T9O
M.T&I8F/>%N%:9$'%[\D/P;BE2`RQ?514I-FI)_\/,4_WPF)2J,VV-JIG081:
MX::/QGA_-[AKE__1+Z#J^/M`TWATI*FZ.>_3/\7/-,:WP\#G.>!%<$A;N[[@
MJ_0"%T^]:P0/@FA<;HS;`T+A;Z4S6F0,9&T#?O5,"VZ\&_!IIVD<HG#'7\WT
MPSPE[S8/"ED?@WD(OW%5G@T,&SR*;R+GAZI,3)$WCPK\[9[_VJ^YKC7^$`$5
M.P4>\(2]J,3B&DB[F^\1'&21P5YAWP3A<A3XDK^H(TK\$^%?,IW&?Q!SI$^(
M>!W622Y1_:9;`75J\KJ<G-=)*KU4;YR)3$*+W]0=X)3IX#QTR:'OOBOQS?4Q
MY7JN(S!N;!(3>^16D5'`P+B4/4)R(,?2&MPV9+C*3&1`7)G<TO*53K9,"'H^
M$UMDFA8^^VN]L":"=H:5(NFJ,9]HNVE`_J)PQ+2_@F:E!@2,WGJ)]^B)3=(9
M(`"[RU<,[+/8G`!Q4U>4_5-MHS3*/A3=50:.6&D9HN#J,QCE55\*3)W(_[W5
M/=>K$N+!\+T`C2>CO(?]LY-6.6YEBO6?4N-;%';`QLQ,?]']D0&B?,`0FJ]@
M7#\;II>O,X(`TC+S(3Q@)IT>MISX7C[WIIAC+(&.AQ#M'PN`5'?:?1#O'IT2
M,#6B=EPO`[(:7WQ2:?X/7A@=4R@.+2L<:?RIC%48B"G<GR>!?G1[=\<PWP+%
M)Q43*SO_/-4+U!/(A'_K`7X&?N0-+.8X=!I-_/K(A`0M[LC;_A-:9(%HFPE3
M![H!!2LS(B0F35&'C^?%N$+A+7R^0M^#,X'7J;(!>!3INHT=5J<S*X31M,X(
M=L38RQ;3F+[`JD4&X6"X[,*ZEUE-J=L/IO`,E=U2*E5`%H=CQMA*+TS)L921
M(#<6_^,<^R:\B4,&J.<=+W=)S],SZP#H@Y5115CB2+405,&(7;CQ8#PUITGF
M<)?E+ZE8FJY3@$"`[`FK%<_Z]X2TS4EP7UU.C4<=.?NQ3"#W**Z]:)?*H[F]
MSG3*Y$@;U7FV7L`!=M%B%1YN"@\S>B^NURX<725.`,V)LQD\M3K<S/>N(IK;
MOM48L%KLWF,)P5NP]T;(*3.S+77SZ=*``8L2OX/=A[_/'-:?A1%L=-`KG.N]
M$*&&`=01'/`5,UN[+DTH?J&R>TB_GI](=E8I]XE=.!\__[W%3*$QSYY_(2*4
M2&[!TSNDG'5I>*4S`G3O/<X@1),?=UE&`<FLDPU*A446A!OJ4Q*(/1B*T^-@
MT9$AG$L:V5F/.XJY29?.L5S9(=J-:<5A_C,;@`D>=)'>N=07""H0QRHK-?!<
MAS&]$9^HCTDKYSXU_42E^HQ)M=E[T[5CB_L;)N>TH*R&DHPBA07W\.JUPLS=
M0]Q:+4X+-HK*+O@ZS2%52I-27D+MZ]4Z3!/[7AI?O`F*$\S%&(#0O(K+SQK_
MVY2E^M0/)GFZX)M&YM5Q`_"#/H')BS\5&C4!^O-'@6::BF=JSRIL=0[5M9>7
M31JP8=H3XIK.'+D@ONE,AOJ9,],HOY)#VG_26EG<M4QG;$-TFJMNQ#,<S7>G
M)W\+3$.+JHU(WPH`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+V%D;6EN+W!L
M:6(O;&]C86QE<P``````````````````````````````````````````````
M````````````````````````````````````````````,#`P-S4U(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,C<@,#$W,C0Q`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O861M:6XO<&QI8B]L;V-A;&5S+V5N+553````````````````
M````````````````````````````````````````````````````````````
M```````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q
M-30S,S<R-R`P,C`Q-S``(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]A9&UI;B]P;&EB+VQO8V%L97,O
M96XM55,O;65S<V%G97-?96XM55,N<&AP````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`Q-#0S,C<R(#$P-3$U-#,S-S(W(#`R,S8Q,P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`IG;&]B86P@)%!2
M3T1?3D%-12P@)&QM<V=?87)R.PIG;&]B86P@)&1E9E]D871E7V9O<FUA="P@
M)&1E9E]T:6UE7V9O<FUA="P@)&1E9E]D871E=&EM95]F;W)M870["@HO*BH*
M("H@1F]R(&UO<F4@:6YF;R!A8F]U="!T:6UE(&%N9"!D871E(&9O<FUA="!S
M964Z"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]M86YU86PO96XO9G5N8W1I;VXN
M9&%T92YP:'`*("HO"B1D969?9&%T95]F;W)M870)/2`G32!J+"!9)SL*)&1E
M9E]T:6UE7V9O<FUA=`D]("=H.FDZ<R!!)SL*)&1E9E]D871E=&EM95]F;W)M
M870]("=-(&HL(%D@:#II($$G.PH*)&QM<V=?87)R(#T@87)R87D@*`H*("`@
M("`@("`O+R`J*BH@5&AE('-T<FEN9W,@8F5L;W<@:&%V92!B965N(&=E;F5R
M871E9"!A=71O;6%T:6-A;&QY(&9R;VT@0$!#05!424].(&1I<F5C=&EV97,N
M"@H@("`@("`@("=U:5]?861M:6XM:6YF;U]?9&5S8W)I<'1I;VXG(#T^("=%
M9&ET($-0(&%D;6EN:7-T<F%T;W(@<&5R<V]N86P@:6YF;W)M871I;VXN)RP*
M("`@("`@("`G=6E?7V%D;6EN+6EN9F]?7V1O;F4G(#T^("=!9&UI;FES=')A
M=&]R('!E<G-O;F%L(&EN9F]R;6%T:6]N(&AA<R!B965N('5P9&%T960N)RP*
M("`@("`@("`G=6E?7V%D;6EN+6EN9F]?7W-H;W)T+71I=&QE)R`]/B`G061M
M:6X@:6YF;R<L"B`@("`@("`@)W5I7U]A9&UI;BUI;F9O7U]T:71L92<@/3X@
M)T-H86YG92!P97)S;VYA;"!I;F9O)RP*"B`@("`@("`@)W5I7U]A9&UI;BUP
M87-S=V]R9%]?9&5S8W)I<'1I;VXG(#T^("=#:&%N9V4@4&QE<VL@061M:6YI
M<W1R871O<B!P87-S=V]R9"XG+`H@("`@("`@("=U:5]?861M:6XM<&%S<W=O
M<F1?7V1O;F4G(#T^("=0;&5S:R!!9&UI;FES=')A=&]R('!A<W-W;W)D(&AA
M<R!B965N(&-H86YG960N)RP*("`@("`@("`G=6E?7V%D;6EN+7!A<W-W;W)D
M7U]S:&]R="UT:71L92<@/3X@)U!A<W-W;W)D)RP*("`@("`@("`G=6E?7V%D
M;6EN+7!A<W-W;W)D7U]T:71L92<@/3X@)T-H86YG92!P87-S=V]R9"<L"@H@
M("`@("`@("=U:5]?8VQI96YT7U]D97-C<FEP=&EO;B<@/3X@)T-L:65N="`E
M,5PG<R!A8V-O=6YT(&%N9"!D;VUA:6YS+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G1?7V1I<V%B;&5D+7=A<FYI;F<G(#T^("=#;&EE;G0@)3$@:7,@9&ES86)L
M960N)RP*("`@("`@("`G=6E?7V-L:65N=%]?;F]N92UA=F%I;&%B;&4G(#T^
M("=4:&5R92!A<F4@;F\@8VQI96YT(&%C8V]U;G1S(&-O;F9I9W5R960N)RP*
M("`@("`@("`G=6E?7V-L:65N=%]?<VAO<G0M=&ET;&4G(#T^("<E,2<L"B`@
M("`@("`@)W5I7U]C;&EE;G1?7W1I=&QE)R`]/B`G0VQI96YT("4Q)RP*("`@
M("`@("`G=6E?7V-L:65N=%]S96QF7U]D97-C<FEP=&EO;B<@/3X@)TQI<W0@
M;V8@;7D@9&]M86EN<RXG+`H@("`@("`@("=U:5]?8VQI96YT7W-E;&9?7W-H
M;W)T+71I=&QE)R`]/B`G37D@9&]M86EN<R<L"B`@("`@("`@)W5I7U]C;&EE
M;G1?<V5L9E]?=&ET;&4G(#T^("=->2!D;VUA:6YS)RP*("`@("`@("`G=6E?
M7V-L:65N=%]U;FMN;W=N7U]Q=6EC:RUS96%R8V@G(#T^("=#;&EE;G1S)RP*
M"B`@("`@("`@)W5I7U]C;&EE;G0O8F%C:W5P7U]D97-C<FEP=&EO;B<@/3X@
M)T)A8VL@=7`O4F5S=&]R92!C;&EE;G0@<&5R<V]N86P@:6YF;R!A;F0@86-C
M;W5N="!S971T:6YG<R!A;F0O;W(@8VQI96YT(&1O;6%I;G,L('-C:&5D=6QE
M(&)A8VMU<',@=FEA(%!L97-K($)A8VMU<"!-86YA9V5R+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O8F%C:W5P7U]D;VYE)R`]/B`G)RP*("`@("`@("`G=6E?
M7V-L:65N="]B86-K=7!?7W-H;W)T+71I=&QE)R`]/B`G0F%C:W5P)RP*("`@
M("`@("`G=6E?7V-L:65N="]B86-K=7!?7W1I=&QE)R`]/B`G0VQI96YT("4Q
M(&)A8VMU<"<L"B`@("`@("`@)W5I7U]C;&EE;G0O8F%C:W5P7W-E;&9?7V1E
M<V-R:7!T:6]N)R`]/B`G0F%C:R!U<"]297-T;W)E('EO=7(@9&]M86EN<R!A
M;F0O;W(@86-C;W5N="!S971T:6YG<RP@<V-H961U;&4@8F%C:W5P<R!V:6$@
M4&QE<VL@0F%C:W5P($UA;F%G97(N)RP*("`@("`@("`G=6E?7V-L:65N="]B
M86-K=7!?<V5L9E]?9&]N92<@/3X@)R<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M8F%C:W5P7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G0F%C:W5P)RP*("`@("`@
M("`G=6E?7V-L:65N="]B86-K=7!?<V5L9E]?=&ET;&4G(#T^("="86-K=7`@
M36%N86=E<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O8F%C:W5P7W5N:VYO=VY?
M7V1E<V-R:7!T:6]N)R`]/B`G0F%C:R!U<"]297-T;W)E(&-L:65N="!P97)S
M;VYA;"!I;F9O(&%N9"!A8V-O=6YT('-E='1I;F=S(&%N9"]O<B!C;&EE;G0@
M9&]M86EN<RP@<V-H961U;&4@8F%C:W5P<R!V:6$@4&QE<VL@0F%C:W5P($UA
M;F%G97(N)RP*("`@("`@("`G=6E?7V-L:65N="]B86-K=7!?=6YK;F]W;E]?
M<VAO<G0M=&ET;&4G(#T^("="86-K=7`G+`H@("`@("`@("=U:5]?8VQI96YT
M+V)A8VMU<%]U;FMN;W=N7U]T:71L92<@/3X@)T-L:65N="!"86-K=7`G+`H@
M("`@("`@("=U:5]?8VQI96YT+V)A8VMU<%]U;FMN;W=N7U]W:7IA<F0M=&ET
M;&4G(#T^("=#;&EE;G0@0F%C:W5P)RP*("`@("`@("`G=6E?7V-L:65N="]B
M86-K=7!?=6YK;F]W;E]?=VEZ87)D7U\Q7W5N:VYO=VXG(#T^("=396QE8W0@
M82!C;&EE;G0@=VAO<V4@86-C;W5N="!A;F0@9&]M86EN('EO=2!W86YT('1O
M(&)A8VL@=7`N)RP*("`@("`@("`G=6E?7V-L:65N="]B86-K=7!?=6YK;F]W
M;E]?=VEZ87)D7U\R)R`]/B`G5&\@8F%C:R!U<"!T:&4@86-C;W5N="!S971T
M:6YG<R!A;F0O;W(@9&]M86EN<RP@8VQI8VL@0F%C:W5P($YO=RX@5&\@<F5S
M=&]R92!T:&4@97AI<W1I;F<@8F%C:W5P(&9I;&4L(&-L:6-K(&ET<R!N86UE
M+B!4;R!S8VAE9'5L92!B86-K=7!S+"!C;&EC:R!38VAE9'5L960@0F%C:W5P
M+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS7U]D97-C
M<FEP=&EO;B<@/3X@)TQI<W0@;V8@8W5S=&]M(&)U='1O;G,@9F]R(&-L:65N
M="`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS7U]S
M:&]R="UT:71L92<@/3X@)T-U<W1O;2!B=71T;VYS)RP*("`@("`@("`G=6E?
M7V-L:65N="]C=7-T;VTM8G5T=&]N<U]?=&ET;&4G(#T^("=#=7-T;VT@8G5T
M=&]N<R!O9B!C;&EE;G0@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O
M;2UB=71T;VYS7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G3&ES="!O9B!M>2!C
M=7-T;VT@8G5T=&]N<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB
M=71T;VYS7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G37D@8W5S=&]M(&)U='1O
M;G,G+`H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS7W-E;&9?
M7W1I=&QE)R`]/B`G37D@8W5S=&]M(&)U='1O;G,G+`H@("`@("`@("=U:5]?
M8VQI96YT+V-U<W1O;2UB=71T;VYS7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]
M/B`G3&ES="!O9B!A(&-L:65N="!C=7-T;VT@8G5T=&]N<RXG+`H@("`@("`@
M("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS7W5N:VYO=VY?7W-H;W)T+71I
M=&QE)R`]/B`G0W5S=&]M(&)U='1O;G,G+`H@("`@("`@("=U:5]?8VQI96YT
M+V-U<W1O;2UB=71T;VYS7W5N:VYO=VY?7W1I=&QE)R`]/B`G0VQI96YT(&-U
M<W1O;2!B=71T;VYS)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O8W5S=&]M+6)U
M='1O;G,O8W5S=&]M+6)U='1O;E]?;F]N92UA=F%I;&%B;&4G(#T^("=9;W4@
M9&]N7"=T(&AA=F4@86YY(&-L:65N="UL979E;"!C=7-T;VT@8G5T=&]N<RXG
M+`H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB
M=71T;VY?7VYO;F4M879A:6QA8FQE7U\Q)R`]/B`G0VQI96YT("4Q(&1O97-N
M7"=T(&AA=F4@86YY(&-U<W1O;2!B=71T;VYS+B<L"@H@("`@("`@("=U:5]?
M8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L971E7U]D
M97-C<FEP=&EO;B<@/3X@)U)E;6]V92!C;&EE;G0M;&5V96P@8W5S=&]M(&)U
M='1O;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS
M+V-U<W1O;2UB=71T;VXO9&5L971E7U]D;VYE)R`]/B`G0VQI96YT+6QE=F5L
M(&-U<W1O;2!B=71T;VX@)3$@:&%S(&)E96X@<F5M;W9E9"XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L
M971E7U]S:&]R="UT:71L92<@/3X@)U)E;6]V92<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D96QE=&5?7W1I
M=&QE)R`]/B`G4F5M;W9E(&-U<W1O;2!B=71T;VX@)3$G+`H@("`@("`@("=U
M:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L971E
M7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G4F5M;W9E(&$@8VQI96YT+6QE
M=F5L(&-U<W1O;2!B=71T;VXN)RP*("`@("`@("`G=6E?7V-L:65N="]C=7-T
M;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+V1E;&5T95]U;FMN;W=N7U]S:&]R
M="UT:71L92<@/3X@)U)E;6]V92<L"B`@("`@("`@)W5I7U]C;&EE;G0O8W5S
M=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D96QE=&5?=6YK;F]W;E]?=&ET
M;&4G(#T^("=296UO=F4@8W5S=&]M(&)U='1O;B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D96QE=&5?=6YK
M;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G0W5S=&]M($)U='1O;B!296UO=F%L
M)RP*("`@("`@("`G=6E?7V-L:65N="]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM
M8G5T=&]N+V1E;&5T95]U;FMN;W=N7U]W:7IA<F1?7S%?=6YK;F]W;B<@/3X@
M)U-E;&5C="!A(&-L:65N="!W:&]S92!C=7-T;VT@8G5T=&]N('EO=2!W86YT
M('1O(')E;6]V92!A;F0@8VQI8VL@3F5X="`^/BXG+`H@("`@("`@("=U:5]?
M8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L971E7W5N
M:VYO=VY?7W=I>F%R9%]?,U]U;FMN;W=N)R`]/B`G4V5L96-T(&$@8W5S=&]M
M(&)U='1O;B!Y;W4@=V%N="!T;R!R96UO=F4@86YD(&-L:6-K($YE>'0@/CXN
M)RP*("`@("`@("`G=6E?7V-L:65N="]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM
M8G5T=&]N+V1E;&5T95]U;FMN;W=N7U]W:7IA<F1?7S0G(#T^("=#;VYF:7)M
M(')E;6]V:6YG('1H92!C=7-T;VT@8G5T=&]N(&)Y('-E;&5C=&EN9R!T:&4@
M8VAE8VL@8F]X(&]N('1H:7,@<V-R965N(&%N9"!C;&EC:R!&:6YI<V@N)RP*
M"B`@("`@("`@)W5I7U]C;&EE;G0O8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U
M='1O;B]P<F]P97)T:65S7U]D97-C<FEP=&EO;B<@/3X@)T5D:70@<')O<&5R
M=&EE<R!O9B!C;&EE;G0M;&5V96P@8W5S=&]M(&)U='1O;B`E,2XG+`H@("`@
M("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO
M<')O<&5R=&EE<U]?9&]N92<@/3X@)T-U<W1O;2!B=71T;VX@)3$@<')O<&5R
M=&EE<R!H879E(&)E96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT
M+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]?<VAO
M<G0M=&ET;&4G(#T^("=0<F5F97)E;F-E<R<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T:65S7U]T
M:71L92<@/3X@)TUO9&EF>2!C;&EE;G0@8W5S=&]M(&)U='1O;B`E,2<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O
M;B]P<F]P97)T:65S7VYE=U]?9&5S8W)I<'1I;VXG(#T^("=#<F5A=&4@;F5W
M(&-L:65N="UL979E;"!C=7-T;VT@8G5T=&]N+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T:65S
M7VYE=U]?9&]N92<@/3X@)T-U<W1O;2!B=71T;VX@)3$@:&%S(&)E96X@8W)E
M871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U
M<W1O;2UB=71T;VXO<')O<&5R=&EE<U]N97=?7W-H;W)T+71I=&QE)R`]/B`G
M0W)E871E)RP*("`@("`@("`G=6E?7V-L:65N="]C=7-T;VTM8G5T=&]N<R]C
M=7-T;VTM8G5T=&]N+W!R;W!E<G1I97-?;F5W7U]T:71L92<@/3X@)T-R96%T
M92!C;&EE;G0@8W5S=&]M(&)U='1O;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T:65S7VYE=U]?
M=VEZ87)D+71I=&QE)R`]/B`G0W5S=&]M($)U='1O;B!#<F5A=&EO;B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O
M;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\Q7W5N:VYO=VXG(#T^("=396QE
M8W0@82!C;&EE;G0@9F]R('=H;VT@>6]U('=A;GD@=&\@8W)E871E(&$@8W5S
M=&]M(&)U='1O;B!A;F0@8VQI8VL@3F5X="`^/BXG+`H@("`@("`@("=U:5]?
M8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE
M<U]N97=?7W=I>F%R9%]?,U]N97<G(#T^("=#;&EC:R!&:6YI<V@@=&\@8W)E
M871E(&-U<W1O;2!B=71T;VX@=VET:"!T:&4@9&5F:6YE9"!P<F]P97)T:65S
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O8W5S=&]M+6)U='1O;G,O8W5S=&]M
M+6)U='1O;B]P<F]P97)T:65S7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G
M161I="!P<F]P97)T:65S(&]F(&$@8VQI96YT+6QE=F5L(&-U<W1O;2!B=71T
M;VXN)RP*("`@("`@("`G=6E?7V-L:65N="]C=7-T;VTM8G5T=&]N<R]C=7-T
M;VTM8G5T=&]N+W!R;W!E<G1I97-?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^
M("=0<F]P97)T:65S)RP*("`@("`@("`G=6E?7V-L:65N="]C=7-T;VTM8G5T
M=&]N<R]C=7-T;VTM8G5T=&]N+W!R;W!E<G1I97-?=6YK;F]W;E]?=&ET;&4G
M(#T^("=-;V1I9GD@8VQI96YT(&-U<W1O;2!B=71T;VXG+`H@("`@("`@("=U
M:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R
M=&EE<U]U;FMN;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=-;V1I9GEI;F<@0VQI
M96YT+6QE=F5L($-U<W1O;2!"=71T;VXG+`H@("`@("`@("=U:5]?8VQI96YT
M+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]U;FMN
M;W=N7U]W:7IA<F1?7S-?=6YK;F]W;B<@/3X@)U-E;&5C="!W:&EC:"!C=7-T
M;VT@8G5T=&]N('EO=2!W86YT('1O(&UO9&EF>2!A;F0@8VQI8VL@3F5X="`^
M/BXG+`H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O
M;2UB=71T;VXO<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S0G(#T^("=7
M:&5N(&1O;F4@=VET:"!E9&ET:6YG('!R;W!E<G1I97,@;V8@=&AE(&-U<W1O
M;2!B=71T;VXL(&-L:6-K($9I;FES:"!T;R!A<'!L>2!C:&%N9V5S(&%N9"!E
M>&ET('1H92!W:7IA<F0N)RP*("`@("`@("`G=6E?7V-L:65N="]C=7-T;VTM
M8G5T=&]N<R]C=7-T;VTM8G5T=&]N+W!R;W!E<G1I97-?=6YK;VYO=VY?7W=I
M>F%R9%]?,5]U;FMN;W=N)R`]/B`G4V5L96-T(&$@8VQI96YT('=H;W-E(&-U
M<W1O;2!B=71T;VX@>6]U('=A;G0@=&\@;6]D:69Y(&%N9"!C;&EC:R!.97AT
M(#X^+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1A<VAB;V%R9"-C=7-T;VTM
M8G5T=&]N<U]?=&ET;&4G(#T^("=#=7-T;VT@8G5T=&]N<R<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&%S:&)O87)D(V1O;6%I;G-?7V1E<V-R:7!T:6]N)R`]
M/B`G3F\@9F%V;W)I=&4@9&]M86EN<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&%S:&)O87)D(V1O;6%I;G-?7W1I=&QE)R`]/B`G1&]M86EN<R<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D(V9A=F]R:71E<R]T86)S7U]D97-C
M<FEP=&EO;B<@/3X@)U-H;W<@=&AE(&9O;&QO=VEN9R!T86)S(&EN($9A=F]R
M:71E<SHG+`H@("`@("`@("=U:5]?8VQI96YT+V1A<VAB;V%R9"-F879O<FET
M97-?7W1I=&QE)R`]/B`G1F%V;W)I=&5S)RP*("`@("`@("`G=6E?7V-L:65N
M="]D87-H8F]A<F0C:6YF;R]F;V]T97)?7V1E<V-R:7!T:6]N)R`]/B`G4VAO
M=R!T:&4@9F]L;&]W:6YG(&)U='1O;G,@:6X@=&AE(&9O;W1E<CHG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1A<VAB;V%R9"-I;F9O7U]D97-C<FEP=&EO;B<@
M/3X@)U-H;W<@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO;CHG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1A<VAB;V%R9"-I;F9O7U]T:71L92<@/3X@)TEN9F]R
M;6%T:6]N)RP*("`@("`@("`G=6E?7V-L:65N="]D87-H8F]A<F0C;6%I;&YA
M;65S7U]D97-C<FEP=&EO;B<@/3X@)TYO(&9A=F]R:71E(&UA:6QN86UE<R<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D(VUA:6QN86UE<U]?=&ET
M;&4G(#T^("=-86EL;F%M97,G+`H@("`@("`@("=U:5]?8VQI96YT+V1A<VAB
M;V%R9"-Q=6EC:RUS96%R8VA?7W1I=&QE)R`]/B`G475I8VL@<V5A<F-H)RP*
M("`@("`@("`G=6E?7V-L:65N="]D87-H8F]A<F0C<F5C96YT7U]D97-C<FEP
M=&EO;B<@/3X@)TYO(')E8V5N="!P86=E<R<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&%S:&)O87)D(W)E8V5N=%]?=&ET;&4G(#T^("=296-E;G0G+`H@("`@
M("`@("=U:5]?8VQI96YT+V1A<VAB;V%R9"-S:&]R=&-U='-?7V1E<V-R:7!T
M:6]N)R`]/B`G3F\@<VAO<G1C=71S)RP*("`@("`@("`G=6E?7V-L:65N="]D
M87-H8F]A<F0C<VAO<G1C=71S7U]T:71L92<@/3X@)U-H;W)T8W5T<R<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D(W-T871I<W1I8W-?7V1E<V-R
M:7!T:6]N)R`]/B`G4VAO=R!T:&4@9F]L;&]W:6YG(&EN9F]R;6%T:6]N.B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D(W-T871I<W1I8W-?7W1I
M=&QE)R`]/B`G4W1A=&ES=&EC<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S
M:&)O87)D(W1O;VQS+V9O;W1E<E]?9&5S8W)I<'1I;VXG(#T^("=3:&]W('1H
M92!F;VQL;W=I;F<@8G5T=&]N<R!I;B!T:&4@9F]O=&5R.B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&%S:&)O87)D(W1O;VQS7U]D97-C<FEP=&EO;B<@/3X@
M)U-H;W<@=&AE(&9O;&QO=VEN9R!B=71T;VYS.B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&%S:&)O87)D(W1O;VQS7U]T:71L92<@/3X@)U1O;VQS)RP*("`@
M("`@("`G=6E?7V-L:65N="]D87-H8F]A<F1?7V1E<V-R:7!T:6]N)R`]/B`G
M1&5S:W1O<"!O9B!C;&EE;G0@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M87-H8F]A<F1?7W-H;W)T+71I=&QE)R`]/B`G)3%<)W,@1&5S:W1O<"<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D7U]T:71L92<@/3X@)T1E<VMT
M;W`@;V8@8VQI96YT("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D87-H8F]A
M<F1?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=->2!$97-K=&]P+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D7W-E;&9?7W-H;W)T+71I=&QE)R`]
M/B`G1&5S:W1O<"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D7W-E
M;&9?7W1I=&QE)R`]/B`G37D@1&5S:W1O<"<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&%S:&)O87)D7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G0VQI96YT
M($1E<VMT;W`N)RP*("`@("`@("`G=6E?7V-L:65N="]D87-H8F]A<F1?=6YK
M;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=$97-K=&]P)RP*("`@("`@("`G=6E?
M7V-L:65N="]D87-H8F]A<F1?=6YK;F]W;E]?=&ET;&4G(#T^("=#;&EE;G0@
M1&5S:W1O<"<L"@H@("`@("`@("=U:5]?8VQI96YT+V1A<VAB;V%R9"]C=7-T
M;VUI>F5?7V1E<V-R:7!T:6]N)R`]/B`G0W5S=&]M:7IE($1E<VMT;W`@;V8@
M8VQI96YT("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D+V-U
M<W1O;6EZ95]?9&]N92<@/3X@)U-E='1I;F<@;V8@1&5S:W1O<"!F;W(@8VQI
M96YT("4Q(&AA=F4@8F5E;B!U<&1A=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&%S:&)O87)D+V-U<W1O;6EZ95]?<VAO<G0M=&ET;&4G(#T^("=#=7-T
M;VUI>F4@1&5S:W1O<"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D
M+V-U<W1O;6EZ95]?=&ET;&4G(#T^("=#=7-T;VUI>F4@1&5S:W1O<"!F;W(@
M8VQI96YT("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D87-H8F]A<F0O8W5S
M=&]M:7IE7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G0W5S=&]M:7IE('EO=7(@
M1&5S:W1O<"!C;VYT96YT+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O
M87)D+V-U<W1O;6EZ95]S96QF7U]D;VYE)R`]/B`G66]U<B!$97-K=&]P('-E
M='1I;F=S(&AA=F4@8F5E;B!U<&1A=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&%S:&)O87)D+V-U<W1O;6EZ95]S96QF7U]S:&]R="UT:71L92<@/3X@
M)T-U<W1O;6EZ92!$97-K=&]P)RP*("`@("`@("`G=6E?7V-L:65N="]D87-H
M8F]A<F0O8W5S=&]M:7IE7W-E;&9?7W1I=&QE)R`]/B`G0W5S=&]M:7IE(&UY
M($1E<VMT;W`G+`H@("`@("`@("=U:5]?8VQI96YT+V1A<VAB;V%R9"]C=7-T
M;VUI>F5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=#=7-T;VUI>F4@1&5S
M:W1O<"!F;W(@82!C;&EE;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]D87-H
M8F]A<F0O8W5S=&]M:7IE7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G0W5S
M=&]M:7IE($1E<VMT;W`G+`H@("`@("`@("=U:5]?8VQI96YT+V1A<VAB;V%R
M9"]C=7-T;VUI>F5?=6YK;F]W;E]?=&ET;&4G(#T^("=#=7-T;VUI>F4@8VQI
M96YT($1E<VMT;W`G+`H@("`@("`@("=U:5]?8VQI96YT+V1A<VAB;V%R9"]C
M=7-T;VUI>F5?=6YK;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G0W5S=&]M:7II
M;F<@0VQI96YT($1E<VMT;W`G+`H@("`@("`@("=U:5]?8VQI96YT+V1A<VAB
M;V%R9"]C=7-T;VUI>F5?=6YK;F]W;E]?=VEZ87)D7U\Q7W5N:VYO=VXG(#T^
M("=396QE8W0@82!C;&EE;G0@=VAO<V4@1&5S:W1O<"!Y;W4@=V%N="!T;R!C
M=7-T;VUI>F4@86YD(&-L:6-K($YE>'0@/CXN)RP*"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&%S:&)O87)D+W-H;W)T8W5T+W!R;W!E<G1I97-?7V1E<V-R:7!T
M:6]N)R`]/B`G161I="!P<F]P97)T:65S(&]F('-H;W)T8W5T("4Q+B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D+W-H;W)T8W5T+W!R;W!E<G1I
M97-?7V1O;F4G(#T^("=0<F]P97)T:65S(&]F('-H;W)T8W5T("4Q(&AA=F4@
M8F5E;B!U<&1A=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D
M+W-H;W)T8W5T+W!R;W!E<G1I97-?7W-H;W)T+71I=&QE)R`]/B`G161I="<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D+W-H;W)T8W5T+W!R;W!E
M<G1I97-?7W1I=&QE)R`]/B`G161I="!S:&]R=&-U="`E,2<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&%S:&)O87)D+W-H;W)T8W5T+W!R;W!E<G1I97-?;F5W
M7U]D97-C<FEP=&EO;B<@/3X@)T-R96%T92!N97<@<VAO<G1C=70N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D87-H8F]A<F0O<VAO<G1C=70O<')O<&5R=&EE
M<U]N97=?7V1O;F4G(#T^("=3:&]R=&-U="`E,2!H87,@8F5E;B!C<F5A=&5D
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D+W-H;W)T8W5T+W!R
M;W!E<G1I97-?;F5W7U]S:&]R="UT:71L92<@/3X@)T-R96%T92!S:&]R=&-U
M="<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D+W-H;W)T8W5T+W!R
M;W!E<G1I97-?;F5W7U]T:71L92<@/3X@)T-R96%T92!S:&]R=&-U="<L"@H@
M("`@("`@("=U:5]?8VQI96YT+V1E;&5T95]?9&5S8W)I<'1I;VXG(#T^("=2
M96UO=F4@86-C;W5N="!O9B!C;&EE;G0@)3$N)RP*("`@("`@("`G=6E?7V-L
M:65N="]D96QE=&5?7V1O;F4G(#T^("=#;&EE;G0@)3$@:&%S(&)E96X@<F5M
M;W9E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1E;&5T95]?<VAO<G0M=&ET
M;&4G(#T^("=296UO=F4G+`H@("`@("`@("=U:5]?8VQI96YT+V1E;&5T95]?
M=&ET;&4G(#T^("=296UO=F4@8VQI96YT("4Q)RP*("`@("`@("`G=6E?7V-L
M:65N="]D96QE=&5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=296UO=F4@
M82!C;&EE;G0@86-C;W5N="XG+`H@("`@("`@("=U:5]?8VQI96YT+V1E;&5T
M95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)U)E;6]V92<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&5L971E7W5N:VYO=VY?7W1I=&QE)R`]/B`G4F5M;W9E
M(&-L:65N="<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&5L971E7W5N:VYO=VY?
M7W=I>F%R9"UT:71L92<@/3X@)T-L:65N="!296UO=F%L)RP*("`@("`@("`G
M=6E?7V-L:65N="]D96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\Q7W5N:VYO=VXG
M(#T^("=396QE8W0@=VAI8V@@8VQI96YT('EO=2!W86YT('1O(')E;6]V92!A
M;F0@8VQI8VL@3F5X="`^/BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1E;&5T
M95]U;FMN;W=N7U]W:7IA<F1?7S(G(#T^("=#;VYF:7)M(&-L:65N="!R96UO
M=F%L(&)Y('-E;&5C=&EN9R!T:&4@8VAE8VL@8F]X(&%N9"!C;&EC:R!&:6YI
M<V@@=&\@8V]M<&QE=&4@=&AE(')E;6]C86P@86YD(&5X:70@=&AE('=I>F%R
M9"XG+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6Y?7V1E<V-R:7!T:6]N
M)R`]/B`G36%N86=E(&1O;6%I;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;E]?9&ES86)L960M=V%R;FEN9R<@/3X@)T1O;6%I;B`E,2!I<R!D
M:7-A8FQE9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;E]?;F]N92UA
M=F%I;&%B;&4G(#T^("=9;W4@9&]N7"=T(&AA=F4@86YY(&1O;6%I;G,N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6Y?7VYO;F4M879A:6QA8FQE7U\Q
M)R`]/B`G0VQI96YT("4Q(&1O97-N7"=T(&AA=F4@86YY(&1O;6%I;G,N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6Y?7W-H;W)T+71I=&QE)R`]/B`G
M)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;E]?=&ET;&4G(#T^("=$
M;VUA:6X@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;E]S96QF7U]D
M97-C<FEP=&EO;B<@/3X@)TUA;F%G92!Y;W5R(&1O;6%I;BXG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;E]S96QF7U]D:7-A8FQE9"UW87)N:6YG)R`]
M/B`G66]U<B!D;VUA:6X@:7,@9&ES86)L960N)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6Y?<V5L9E]?<75I8VLM<V5A<F-H)R`]/B`G37D@9&]M86EN
M<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN7W-E;&9?7W-H;W)T+71I
M=&QE)R`]/B`G37D@9&]M86EN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6Y?<V5L9E]?=&ET;&4G(#T^("=->2!D;VUA:6XG+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;E]U;FMN;W=N7U]Q=6EC:RUS96%R8V@G(#T^("=$;VUA
M:6YS)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V)A8VMU<%]?9&5S
M8W)I<'1I;VXG(#T^("="86-K('5P+U)E<W1O<F4@=&AE(&1O;6%I;BP@<V-H
M961U;&4@=&AE(&1O;6%I;B!B86-K=7!S('9I82!0;&5S:R!"86-K=7`@36%N
M86=E<BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]B86-K=7!?7V1O
M;F4G(#T^("<G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]B86-K=7!?
M7W-H;W)T+71I=&QE)R`]/B`G0F%C:W5P)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO8F%C:W5P7U]T:71L92<@/3X@)T1O;6%I;B`E,2!B86-K=7`G
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]B86-K=7!?<V5L9E]?9&5S
M8W)I<'1I;VXG(#T^("="86-K('5P+U)E<W1O<F4@>6]U<B!D;VUA:6XL('-C
M:&5D=6QE('1H92!D;VUA:6X@8F%C:W5P<R!V:6$@4&QE<VL@0F%C:W5P($UA
M;F%G97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8F%C:W5P7W-E
M;&9?7V1O;F4G(#T^("<G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]B
M86-K=7!?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("="86-K=7`G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]B86-K=7!?<V5L9E]?=&ET;&4G(#T^("=$
M;VUA:6X@8F%C:W5P)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8F%C
M:W5P7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G0F%C:R!U<"]297-T;W)E
M(&$@9&]M86EN+"!S8VAE9'5L92!A(&1O;6%I;B!B86-K=7!S('9I82!0;&5S
M:R!"86-K=7`@36%N86=E<BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]B86-K=7!?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("="86-K=7`G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]B86-K=7!?=6YK;F]W;E]?=&ET
M;&4G(#T^("=$;VUA:6X@0F%C:W5P)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO8F%C:W5P7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@/3X@)T1O;6%I
M;B!"86-K=7`G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]B86-K=7!?
M=6YK;F]W;E]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D;VUA
M:6X@>6]U('=A;G0@=&\@8F%C:R!U<"!A;F0@8VQI8VL@3F5X="`^/BXG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]B86-K=7!?=6YK;F]W;E]?=VEZ
M87)D7U\S)R`]/B`G5&\@8F%C:R!U<"!T:&4@9&]M86EN+"!C;&EC:R!"86-K
M=7`@3F]W+B!4;R!R97-T;W)E('1H92!E>&ES=&EN9R!B86-K=7`@9FEL92P@
M8VQI8VL@:71S(&YA;64N(%1O('-C:&5D=6QE(&)A8VMU<',L(&-L:6-K(%-C
M:&5D=6QE9"!"86-K=7`N)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+V-U<W1O;2UB=71T;VYS7U]D97-C<FEP=&EO;B<@/3X@)TQI<W0@;V8@9&]M
M86EN("4Q(&-U<W1O;2!B=71T;VYS+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+V-U<W1O;2UB=71T;VYS7U]S:&]R="UT:71L92<@/3X@)T-U<W1O
M;2!B=71T;VYS)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M
M+6)U='1O;G-?7W1I=&QE)R`]/B`G0W5S=&]M(&)U='1O;G,@9F]R(&1O;6%I
M;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O;2UB=71T
M;VYS7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G3&ES="!O9B!Y;W5R(&-U<W1O
M;2!B=71T;VYS+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O
M;2UB=71T;VYS7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G37D@8W5S=&]M(&)U
M='1O;G,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T
M=&]N<U]S96QF7U]T:71L92<@/3X@)TUY(&-U<W1O;2!B=71T;VYS)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G-?=6YK;F]W
M;E]?9&5S8W)I<'1I;VXG(#T^("=,:7-T(&]F(&1O;6%I;B!C=7-T;VT@8G5T
M=&]N<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T
M=&]N<U]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)T-U<W1O;2!B=71T;VYS
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G-?
M=6YK;F]W;E]?=&ET;&4G(#T^("=$;VUA:6X@8W5S=&]M(&)U='1O;G,G+`H*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S
M=&]M+6)U='1O;E]?;F]N92UA=F%I;&%B;&4G(#T^("=9;W4@9&]N7"=T(&AA
M=F4@86YY(&1O;6%I;BUL979E;"!C=7-T;VT@8G5T=&]N<RXG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T
M=&]N7U]N;VYE+6%V86EL86)L95]?,2<@/3X@)T-L:65N="`E,2!D;V5S;EPG
M="!H879E(&%N>2!D;VUA:6XM;&5V96P@8W5S=&]M(&)U='1O;G,N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M
M+6)U='1O;E]?;F]N92UA=F%I;&%B;&5?7S(G(#T^("=4:&5R92!A<F4@;F\@
M8W5S=&]M(&)U='1O;G,@9F]R(&1O;6%I;B`E,2XG+`H*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D
M96QE=&5?7V1E<V-R:7!T:6]N)R`]/B`G4F5M;W9E(&1O;6%I;B!C=7-T;VT@
M8G5T=&]N("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O
M;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L971E7U]D;VYE)R`]/B`G1&]M
M86EN(&-U<W1O;2!B=71T;VX@)3$@:&%S(&)E96X@<F5M;W9E9"XG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM
M8G5T=&]N+V1E;&5T95]?<VAO<G0M=&ET;&4G(#T^("=296UO=F4G+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM
M8G5T=&]N+V1E;&5T95]?=&ET;&4G(#T^("=296UO=F4@8W5S=&]M(&)U='1O
M;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O;2UB=71T
M;VYS+V-U<W1O;2UB=71T;VXO9&5L971E7W5N:VYO=VY?7V1E<V-R:7!T:6]N
M)R`]/B`G4F5M;W9E(&$@9&]M86EN+6QE=F5L(&-U<W1O;2!B=71T;VXN)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S
M=&]M+6)U='1O;B]D96QE=&5?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=2
M96UO=F4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T
M=&]N<R]C=7-T;VTM8G5T=&]N+V1E;&5T95]U;FMN;W=N7U]T:71L92<@/3X@
M)U)E;6]V92!D;VUA:6X@8W5S=&]M(&)U='1O;B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L
M971E7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@/3X@)T-U<W1O;2!"=71T;VX@
M4F5M;W9A;"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O;2UB
M=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L971E7W5N:VYO=VY?7W=I>F%R9%]?
M,5]U;FMN;W=N)R`]/B`G4V5L96-T(&$@8VQI96YT(&9R;VT@=VAO<V4@9&]M
M86EN('EO=2!W86YT('1O(')E;6]V92!A(&-U<W1O;2!B=71T;VX@86YD(&-L
M:6-K($YE>'0@/CXN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S
M=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D96QE=&5?=6YK;F]W;E]?=VEZ
M87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@9G)O;2!W:&EC
M:"!Y;W4@=V%N="!T;R!R96UO=F4@82!C=7-T;VT@8G5T=&]N(&%N9"!C;&EC
M:R!.97AT(#X^+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O
M;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L971E7W5N:VYO=VY?7W=I>F%R
M9%]?-%]U;FMN;W=N)R`]/B`G4V5L96-T(&$@8W5S=&]M(&)U='1O;B!Y;W4@
M=V%N="!T;R!R96UO=F4@86YD(&-L:6-K($YE>'0@/CXN)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O
M;B]D96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\U)R`]/B`G0V]N9FER;2!R96UO
M=FEN9R!T:&4@8W5S=&]M(&)U='1O;B!B>2!S96QE8W1I;F<@=&AE(&-H96-K
M(&)O>"!A;F0@8VQI8VL@1FEN:7-H('1O(&-O;7!L971E;'D@<F5M;W9E('1H
M92!B=71T;VX@86YD(&5X:70@=&AE('=I>F%R9"XG+`H*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P
M<F]P97)T:65S7U]D97-C<FEP=&EO;B<@/3X@)T5D:70@<')O<&5R=&EE<R!O
M9B!D;VUA:6XM;&5V96P@8W5S=&]M(&)U='1O;B`E,2XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N
M+W!R;W!E<G1I97-?7V1O;F4G(#T^("=#=7-T;VT@8G5T=&]N("4Q('!R;W!E
M<G1I97,@:&%V92!B965N('5P9&%T960N)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T
M:65S7U]S:&]R="UT:71L92<@/3X@)U!R;W!E<G1I97,G+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N
M+W!R;W!E<G1I97-?7W1I=&QE)R`]/B`G36]D:69Y(&1O;6%I;B!C=7-T;VT@
M8G5T=&]N("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M
M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T:65S7VYE=U]?9&5S8W)I
M<'1I;VXG(#T^("=#<F5A=&4@;F5W(&1O;6%I;BUL979E;"!C=7-T;VT@8G5T
M=&]N+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O;2UB=71T
M;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]N97=?7V1O;F4G(#T^("=#
M=7-T;VT@8G5T=&]N("4Q(&AA<R!B965N(&-R96%T960N)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O
M;B]P<F]P97)T:65S7VYE=U]?<VAO<G0M=&ET;&4G(#T^("=#<F5A=&4G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T
M;VTM8G5T=&]N+W!R;W!E<G1I97-?;F5W7U]T:71L92<@/3X@)T-R96%T92!D
M;VUA:6X@8W5S=&]M(&)U='1O;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]N
M97=?7W=I>F%R9"UT:71L92<@/3X@)T-U<W1O;2!"=71T;VX@0W)E871I;VXG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C
M=7-T;VTM8G5T=&]N+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S%?=6YK;F]W
M;B<@/3X@)U-E;&5C="!A(&-L:65N="!F;W(@=VAO<V4@9&]M86EN('EO=2!W
M86YT('1O(&-R96%T92!A(&-U<W1O;2!B=71T;VX@86YD(&-L:6-K($YE>'0@
M/CXN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O
M;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\R7W5N
M:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@9F]R('=H:6-H('EO=2!W86YT
M('1O(&-R96%T92!A(&-U<W1O;2!B=71T;VX@86YD(&-L:6-K($YE>'0@/CXN
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O
M8W5S=&]M+6)U='1O;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\R7W5N:VYO
M=VXG(#T^("=396QE8W0@82!D;VUA:6X@;VX@=VAI8V@@>6]U('=A;G0@=&\@
M;6]D:69Y(&$@8W5S=&]M(&)U='1O;B!A;F0@8VQI8VL@3F5X="`^/BXG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T
M;VTM8G5T=&]N+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S1?;F5W)R`]/B`G
M0VQI8VL@1FEN:7-H('1O(&-R96%T92!T:&4@8W5S=&]M(&)U='1O;B!A;F0@
M97AI="!T:&4@=VEZ87)D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]U;FMN
M;W=N7U]D97-C<FEP=&EO;B<@/3X@)T5D:70@9&]M86EN+6QE=F5L(&-U<W1O
M;2!B=71T;VX@<')O<&5R=&EE<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+W!R;W!E<G1I97-?
M=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=0<F]P97)T:65S)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U
M='1O;B]P<F]P97)T:65S7W5N:VYO=VY?7W1I=&QE)R`]/B`G36]D:69Y(&1O
M;6%I;B!C=7-T;VT@8G5T=&]N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T:65S7W5N
M:VYO=VY?7W=I>F%R9"UT:71L92<@/3X@)TUO9&EF>6EN9R!$;VUA:6X@0W5S
M=&]M($)U='1O;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O
M;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]U;FMN;W=N7U]W
M:7IA<F1?7S1?=6YK;F]W;B<@/3X@)U-E;&5C="!A(&-U<W1O;2!B=71T;VX@
M=VAI8V@@<V5T=&EN9W,@>6]U('=A;G0@=&\@;6]D:69Y(&%N9"!C;&EC:R!.
M97AT(#X^+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O;2UB
M=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA
M<F1?7S4G(#T^("=7:&5N(&1O;F4@=VET:"!C:&%N9VEN9R!P<F]P97)T:65S
M(&]F('1H92!C=7-T;VT@8G5T=&]N+"!C;&EC:R!&:6YI<V@@=&\@87!P;'D@
M8VAA;F=E<R!A;F0@97AI="!T:&4@=VEZ87)D+B<L"@H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]D87-H8F]A<F0C8W5S=&]M+6)U='1O;G-?7W1I=&QE
M)R`]/B`G0W5S=&]M(&)U='1O;G,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]D87-H8F]A<F0C9F%V;W)I=&5S+W1A8G-?7V1E<V-R:7!T:6]N)R`]
M/B`G4VAO=R!T:&4@9F]L;&]W:6YG('1A8G,@:6X@1F%V;W)I=&5S.B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R9"-F879O<FET97-?
M7W1I=&QE)R`]/B`G1F%V;W)I=&5S)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO9&%S:&)O87)D(VEN9F\O9F]O=&5R7U]D97-C<FEP=&EO;B<@/3X@
M)U-H;W<@=&AE(&9O;&QO=VEN9R!B=71T;VYS(&EN('1H92!F;V]T97(Z)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D(VEN9F]?7V1E
M<V-R:7!T:6]N)R`]/B`G4VAO=R!T:&4@9F]L;&]W:6YG(&EN9F]R;6%T:6]N
M.B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R9"-I;F9O
M7U]T:71L92<@/3X@)TEN9F]R;6%T:6]N)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO9&%S:&)O87)D(VUA:6QN86UE<U]?9&5S8W)I<'1I;VXG(#T^
M("=.;R!F879O<FET92!M86EL;F%M97,G+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]D87-H8F]A<F0C;6%I;&YA;65S7U]T:71L92<@/3X@)TUA:6QN
M86UE<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R9"-Q
M=6EC:RUS96%R8VA?7W1I=&QE)R`]/B`G475I8VL@<V5A<F-H)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D(W)E8V5N=%]?9&5S8W)I
M<'1I;VXG(#T^("=.;R!R96-E;G0@<&%G97,G+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]D87-H8F]A<F0C<F5C96YT7U]T:71L92<@/3X@)U)E8V5N
M="<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R9"-S:&]R
M=&-U='-?7V1E<V-R:7!T:6]N)R`]/B`G3F\@<VAO<G1C=71S)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D(W-H;W)T8W5T<U]?=&ET
M;&4G(#T^("=3:&]R=&-U=',G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]D87-H8F]A<F0C<W1A=&ES=&EC<U]?9&5S8W)I<'1I;VXG(#T^("=3:&]W
M('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VXZ)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO9&%S:&)O87)D(W-T871I<W1I8W-?7W1I=&QE)R`]/B`G
M4W1A=&ES=&EC<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB
M;V%R9"-T;V]L<R]F;V]T97)?7V1E<V-R:7!T:6]N)R`]/B`G4VAO=R!T:&4@
M9F]L;&]W:6YG(&)U='1O;G,@:6X@=&AE(&9O;W1E<CHG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A<F0C=&]O;'-?7V1E<V-R:7!T:6]N
M)R`]/B`G4VAO=R!T:&4@9F]L;&]W:6YG(&)U='1O;G,Z)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D(W1O;VQS7U]T:71L92<@/3X@
M)U1O;VQS)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D
M7U]D97-C<FEP=&EO;B<@/3X@)T1E<VMT;W`@;V8@9&]M86EN(&%D;6EN:7-T
M<F%T;W(@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O
M87)D7U]S:&]R="UT:71L92<@/3X@)R4Q7"=S($1E<VMT;W`G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A<F1?7W1I=&QE)R`]/B`G1&5S
M:W1O<"!O9B!D;VUA:6X@861M:6X@)3$G+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]D87-H8F]A<F1?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=->2!$
M97-K=&]P+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R
M9%]S96QF7U]S:&]R="UT:71L92<@/3X@)T1E<VMT;W`G+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A<F1?<V5L9E]?=&ET;&4G(#T^("=-
M>2!$97-K=&]P)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O
M87)D7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G1&]M86EN(&%D;6EN:7-T
M<F%T;W(@9&5S:W1O<"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D
M87-H8F]A<F1?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=$97-K=&]P)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D7W5N:VYO=VY?
M7W1I=&QE)R`]/B`G1&]M86EN(&%D;6EN(&1E<VMT;W`G+`H*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D+V-U<W1O;6EZ95]?9&5S8W)I
M<'1I;VXG(#T^("=#=7-T;VUI>F4@1&5S:W1O<"!F;W(@1&]M86EN($%D;6EN
M:7-T<F%T;W(@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%S
M:&)O87)D+V-U<W1O;6EZ95]?9&5S8W)I<'1I;VXG(#T^("=#=7-T;VUI>F4@
M1&]M86EN($%D;6EN:7-T<F%T;W(@1&5S:W1O<"XG+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]D87-H8F]A<F0O8W5S=&]M:7IE7U]D;VYE)R`]/B`G
M1&5S:W1O<"!O9B!$;VUA:6X@061M:6YI<W1R871O<B`E,2!H87,@8F5E;B!U
M<&1A=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R
M9"]C=7-T;VUI>F5?7W-H;W)T+71I=&QE)R`]/B`G0W5S=&]M:7IE($1E<VMT
M;W`G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A<F0O8W5S
M=&]M:7IE7U]S:&]R="UT:71L92<@/3X@)T-U<W1O;6EZ92!$97-K=&]P)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D+V-U<W1O;6EZ
M95]?=&ET;&4G(#T^("=#=7-T;VUI>F4@1&5S:W1O<"!O9B!$;VUA:6X@061M
M:6X@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A<F0O
M8W5S=&]M:7IE7U]T:71L92<@/3X@)T-U<W1O;6EZ92!$;VUA:6X@061M:6X@
M1&5S:W1O<"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R
M9"]C=7-T;VUI>F5?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=#=7-T;VUI>F4@
M;7D@1&5S:W1O<"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D87-H
M8F]A<F0O8W5S=&]M:7IE7W-E;&9?7V1O;F4G(#T^("=9;W5R($1E<VMT;W`@
M<V5T=&EN9W,@:&%V92!B965N('5P9&%T960N)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO9&%S:&)O87)D+V-U<W1O;6EZ95]S96QF7U]S:&]R="UT
M:71L92<@/3X@)T-U<W1O;6EZ92!$97-K=&]P)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO9&%S:&)O87)D+V-U<W1O;6EZ95]S96QF7U]T:71L92<@
M/3X@)T-U<W1O;6EZ92!M>2!$97-K=&]P)RP*"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+V1A<VAB;V%R9"]S:&]R=&-U="]P<F]P97)T:65S7U]D97-C
M<FEP=&EO;B<@/3X@)T5D:70@<')O<&5R=&EE<R!O9B!S:&]R=&-U="`E,2XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A<F0O<VAO<G1C
M=70O<')O<&5R=&EE<U]?9&]N92<@/3X@)U-H;W)T8W5T("4Q(&AA<R!B965N
M('5P9&%T960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O
M87)D+W-H;W)T8W5T+W!R;W!E<G1I97-?7W-H;W)T+71I=&QE)R`]/B`G161I
M="<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R9"]S:&]R
M=&-U="]P<F]P97)T:65S7U]T:71L92<@/3X@)T5D:70@<VAO<G1C=70@)3$G
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A<F0O<VAO<G1C
M=70O<')O<&5R=&EE<U]N97=?7V1E<V-R:7!T:6]N)R`]/B`G0W)E871E(&YE
M=R!S:&]R=&-U="XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D87-H
M8F]A<F0O<VAO<G1C=70O<')O<&5R=&EE<U]N97=?7V1O;F4G(#T^("=3:&]R
M=&-U="`E,2!H87,@8F5E;B!C<F5A=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+V1A<VAB;V%R9"]S:&]R=&-U="]P<F]P97)T:65S7VYE=U]?
M<VAO<G0M=&ET;&4G(#T^("=#<F5A=&4@<VAO<G1C=70G+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A<F0O<VAO<G1C=70O<')O<&5R=&EE
M<U]N97=?7W1I=&QE)R`]/B`G0W)E871E('-H;W)T8W5T)RP*"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B87-E<U]?9&5S8W)I<'1I;VXG(#T^
M("=,:7-T(&]F(&1O;6%I;B`E,2!D871A8F%S97,N)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO9&%T86)A<V5S7U]S:&]R="UT:71L92<@/3X@)T1A
M=&%B87-E<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B87-E
M<U]?=&ET;&4G(#T^("=$871A8F%S97,@;V8@9&]M86EN("4Q)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO9&%T86)A<V5S7W-E;&9?7V1E<V-R:7!T
M:6]N)R`]/B`G3&ES="!O9B!Y;W5R(&1A=&%B87-E<RXG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]D871A8F%S97-?<V5L9E]?<VAO<G0M=&ET;&4G
M(#T^("=$871A8F%S97,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D
M871A8F%S97-?<V5L9E]?=&ET;&4G(#T^("=->2!D871A8F%S97,G+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]D871A8F%S97-?=6YK;F]W;E]?9&5S
M8W)I<'1I;VXG(#T^("=,:7-T(&]F(&1O;6%I;B!D871A8F%S97,N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%T86)A<V5S7W5N:VYO=VY?7W-H
M;W)T+71I=&QE)R`]/B`G1&%T86)A<V5S)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO9&%T86)A<V5S7W5N:VYO=VY?7W1I=&QE)R`]/B`G1&]M86EN
M(&1A=&%B87-E<R<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D871A
M8F%S97,O9&%T86)A<V5?7V1E<V-R:7!T:6]N)R`]/B`G1&%T86)A<V4@)3$@
M=7-E<G,@86YD(%=E8D%D;6EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+V1A=&%B87-E<R]D871A8F%S95]?;F]N92UA=F%I;&%B;&4G(#T^("=9
M;W4@9&]N7"=T(&AA=F4@86YY(&1A=&%B87-E<RXG+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]D871A8F%S97,O9&%T86)A<V5?7VYO;F4M879A:6QA
M8FQE7U\Q)R`]/B`G0VQI96YT("4Q(&1O97-N7"=T(&AA=F4@86YY(&1A=&%B
M87-E<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D871A8F%S97,O
M9&%T86)A<V5?7VYO;F4M879A:6QA8FQE7U\R)R`]/B`G5&AE<F4@87)E(&YO
M(&1A=&%B87-E<R!O;B!D;VUA:6X@)3$N)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO9&%T86)A<V5S+V1A=&%B87-E7U]S:&]R="UT:71L92<@/3X@
M)R4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%T86)A<V5S+V1A
M=&%B87-E7U]T:71L92<@/3X@)T1A=&%B87-E("4Q('5S97)S)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO9&%T86)A<V5S+V1A=&%B87-E7W5N:VYO
M=VY?7V1E<V-R:7!T:6]N)R`]/B`G36%N86=E(&1A=&%B87-E('5S97)S(&%N
M9"!A8V-E<W,@5V5B061M:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO9&%T86)A<V5S+V1A=&%B87-E7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]
M/B`G1&%T86)A<V4@=7-E<G,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]D871A8F%S97,O9&%T86)A<V5?=6YK;F]W;E]?=&ET;&4G(#T^("=-86YA
M9V4@9&%T86)A<V4@=7-E<G,G+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO9&%T86)A<V5S+V1A=&%B87-E+V1E;&5T95]?9&5S8W)I<'1I;VXG(#T^
M("=296UO=F4@9&%T86)A<V4@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO9&%T86)A<V5S+V1A=&%B87-E+V1E;&5T95]?9&]N92<@/3X@)T1A
M=&%B87-E("4Q(&AA<R!B965N(')E;6]V960N)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO9&%T86)A<V5S+V1A=&%B87-E+V1E;&5T95]?<VAO<G0M
M=&ET;&4G(#T^("=296UO=F4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]D871A8F%S97,O9&%T86)A<V4O9&5L971E7U]T:71L92<@/3X@)U)E;6]V
M92!D871A8F%S92`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A
M=&%B87-E<R]D871A8F%S92]D96QE=&5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG
M(#T^("=296UO=F4@82!D871A8F%S92XG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]D871A8F%S97,O9&%T86)A<V4O9&5L971E7W5N:VYO=VY?7W-H
M;W)T+71I=&QE)R`]/B`G4F5M;W9E)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO9&%T86)A<V5S+V1A=&%B87-E+V1E;&5T95]U;FMN;W=N7U]T:71L
M92<@/3X@)U)E;6]V92!D871A8F%S92<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+V1A=&%B87-E<R]D871A8F%S92]D96QE=&5?=6YK;F]W;E]?=VEZ
M87)D+71I=&QE)R`]/B`G1&%T86)A<V4@4F5M;W9A;"<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+V1A=&%B87-E<R]D871A8F%S92]D96QE=&5?=6YK
M;F]W;E]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@
M9G)O;2!W:&EC:"!W86YT('1O(')E;6]V92!A(&1A=&%B87-E(&%N9"!C;&EC
M:R!.97AT(#X^+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B
M87-E<R]D871A8F%S92]D96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\T7W5N:VYO
M=VXG(#T^("=396QE8W0@82!D871A8F%S92!Y;W4@=V%N="!T;R!R96UO=F4@
M86YD(&-L:6-K($YE>'0@/CXN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO9&%T86)A<V5S+V1A=&%B87-E+V1E;&5T95]U;FMN;W=N7U]W:7IA<F1?
M7S4G(#T^("=#;VYF:7)M(')E;6]V:6YG('1H92!D871A8F%S92!B>2!S96QE
M8W1I;F<@=&AE(&-H96-K(&)O>"!A;F0@8VQI8VL@1FEN:7-H('1O(&-O;7!L
M971E;'D@<F5M;W9E('1H92!D871A8F%S92!A;F0@97AI="!T:&4@=VEZ87)D
M+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D871A8F%S97,O9&%T
M86)A<V4O<')O<&5R=&EE<U]N97<M861H;V-?7W=I>F%R9%]?-%]N97<G(#T^
M("=4:&4@9&%T86)A<V4@=VEL;"!B92!C<F5A=&5D(&EM;65D:6%T96QY(&%F
M=&5R('EO=2!C;&EC:R!.97AT(#X^+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+V1A=&%B87-E<R]D871A8F%S92]P<F]P97)T:65S7VYE=U]?9&5S
M8W)I<'1I;VXG(#T^("=#<F5A=&4@82!N97<@9&%T86)A<V4N)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO9&%T86)A<V5S+V1A=&%B87-E+W!R;W!E
M<G1I97-?;F5W7U]D;VYE)R`]/B`G1&%T86)A<V4@)3$@:&%S(&)E96X@8W)E
M871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D871A8F%S97,O
M9&%T86)A<V4O<')O<&5R=&EE<U]N97=?7W-H;W)T+71I=&QE)R`]/B`G0W)E
M871E(&1A=&%B87-E)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%T
M86)A<V5S+V1A=&%B87-E+W!R;W!E<G1I97-?;F5W7U]T:71L92<@/3X@)T-R
M96%T92!D871A8F%S92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A
M=&%B87-E<R]D871A8F%S92]P<F]P97)T:65S7VYE=U]?=VEZ87)D+71I=&QE
M)R`]/B`G1&%T86)A<V4@0W)E871I;VXG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]D871A8F%S97,O9&%T86)A<V4O<')O<&5R=&EE<U]N97=?7W=I
M>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T(&$@9&]M86EN(&]N('=H:6-H
M('EO=2!W86YT('1O(&-R96%T92!A(&1A=&%B87-E(&%N9"!C;&EC:R!.97AT
M(#X^+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B87-E<R]D
M871A8F%S92]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\T7VYE=R<@/3X@)T-L
M:6-K($9I;FES:"!T;R!C<F5A=&4@=&AE(&1A=&%B87-E(&%N9"!E>&ET('1H
M92!W:7IA<F0N)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B
M87-E<R]D871A8F%S92]W96)A9&UI;E]?9&5S8W)I<'1I;VXG(#T^("=!8V-E
M<W,@5V5B061M:6X@9F]R(&UA;F%G:6YG(&1A=&%B87-E("4Q+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B87-E<R]D871A8F%S92]W96)A
M9&UI;E]?9&]N92<@/3X@)R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+V1A=&%B87-E<R]D871A8F%S92]W96)A9&UI;E]?<VAO<G0M=&ET;&4G(#T^
M("=796)!9&UI;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B
M87-E<R]D871A8F%S92]W96)A9&UI;E]?=&ET;&4G(#T^("=/<&5N(%=E8D%D
M;6EN(&9O<B!D871A8F%S92`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+V1A=&%B87-E<R]D871A8F%S92]W96)A9&UI;E]U;FMN;W=N7U]D97-C
M<FEP=&EO;B<@/3X@)T%C8V5S<R!796)!9&UI;B!F;W(@;6%N86=I;F<@82!D
M871A8F%S92XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D871A8F%S
M97,O9&%T86)A<V4O=V5B861M:6Y?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^
M("=796)!9&UI;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B
M87-E<R]D871A8F%S92]W96)A9&UI;E]U;FMN;W=N7U]T:71L92<@/3X@)T]P
M96X@5V5B061M:6X@9F]R(&1A=&%B87-E)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO9&%T86)A<V5S+V1A=&%B87-E+W=E8F%D;6EN7W5N:VYO=VY?
M7W=I>F%R9"UT:71L92<@/3X@)U=E8D%D;6EN(%-T87)T=7`G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]D871A8F%S97,O9&%T86)A<V4O=V5B861M
M:6Y?=6YK;F]W;E]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D
M;VUA:6X@9F]R('=H;W-E(&1A=&%B87-E('EO=2!W86YT('1O(&]P96X@5V5B
M061M:6X@86YD(&-L:6-K($YE>'0@/CXN)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO9&%T86)A<V5S+V1A=&%B87-E+W=E8F%D;6EN7W5N:VYO=VY?
M7W=I>F%R9%]?-%]U;FMN;W=N)R`]/B`G4V5L96-T(&$@9&%T86)A<V4@=VAI
M8V@@>6]U('=A;G0@=&\@;6%N86=E('9I82!796)!9&UI;BXG+`H*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO9&5L971E7U]D97-C<FEP=&EO;B<@/3X@
M)U)E;6]V92!D;VUA:6X@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO9&5L971E7U]D;VYE)R`]/B`G1&]M86EN("4Q(&AA<R!B965N(')E;6]V
M960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&5L971E7U]S:&]R
M="UT:71L92<@/3X@)U)E;6]V92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+V1E;&5T95]?=&ET;&4G(#T^("=296UO=F4@9&]M86EN("4Q)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&5L971E7W5N:VYO=VY?7V1E<V-R
M:7!T:6]N)R`]/B`G4F5M;W9E(&$@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+V1E;&5T95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@
M)U)E;6]V92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1E;&5T95]U
M;FMN;W=N7U]T:71L92<@/3X@)U)E;6]V92!D;VUA:6XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]D96QE=&5?=6YK;F]W;E]?=VEZ87)D+71I=&QE
M)R`]/B`G1&]M86EN(%)E;6]V86PG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]D96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=3
M96QE8W0@82!D;VUA:6X@>6]U('=A;G0@=&\@<F5M;W9E(&%N9"!C;&EC:R!.
M97AT(#X^+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1E;&5T95]U
M;FMN;W=N7U]W:7IA<F1?7S,G(#T^("=#;VYF:7)M(')E;6]V:6YG('1H92!D
M;VUA:6X@8GD@<V5L96-T:6YG('1H92!C:&5C:R!B;W@@86YD(&-L:6-K($9I
M;FES:"!T;R!C;VUP;&5T96QY(')E;6]V92!I="!A;F0@97AI="!T:&4@=VEZ
M87)D+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG7U]N
M;VYE+6%V86EL86)L92<@/3X@)TAO<W1I;F<@:7,@;F]T(&-O;F9I9W5R960@
M;VX@>6]U<B!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:&]S=&EN9U]?;F]N92UA=F%I;&%B;&5?7S(G(#T^("=(;W-T:6YG(&ES(&YO
M="!C;VYF:6=U<F5D(&]N(&1O;6%I;B`E,2XG+`H*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO:&]S=&EN9R]F:6QE+6UA;F%G97)?7V1E<V-R:7!T:6]N
M)R`]/B`G06-C97-S(&1O;6%I;B`E,2!&:6QE($UA;F%G97(N)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]F:6QE+6UA;F%G97)?7V1O
M;F4G(#T^("<G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG
M+V9I;&4M;6%N86=E<E]?<VAO<G0M=&ET;&4G(#T^("=&:6QE(&UA;F%G97(G
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+V9I;&4M;6%N
M86=E<E]?=&ET;&4G(#T^("=-86YA9V4@9FEL97,@;VX@9&]M86EN("4Q)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]F:6QE+6UA;F%G
M97)?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=/<F=A;FEZ92!Y;W5R('=E8G-I
M=&4@9FEL97,@86YD(&1I<F5C=&]R:65S('9I82!0;&5S:R!&:6QE($UA;F%G
M97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]F:6QE
M+6UA;F%G97)?<V5L9E]?9&]N92<@/3X@)R<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VAO<W1I;F<O9FEL92UM86YA9V5R7W-E;&9?7W-H;W)T+71I
M=&QE)R`]/B`G1FEL92!M86YA9V5R)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO:&]S=&EN9R]F:6QE+6UA;F%G97)?<V5L9E]?=&ET;&4G(#T^("=-
M86YA9V4@9FEL97,@;VX@;7D@9&]M86EN)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]F:6QE+6UA;F%G97)?=6YK;F]W;E]?9&5S8W)I
M<'1I;VXG(#T^("=/<F=A;FEZ92!A('=E8G-I=&4@9FEL97,@86YD(&1I<F5C
M=&]R:65S('9I82!0;&5S:R!&:6QE($UA;F%G97(N)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO:&]S=&EN9R]F:6QE+6UA;F%G97)?=6YK;F]W;E]?
M<VAO<G0M=&ET;&4G(#T^("=&:6QE(&UA;F%G97(G+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]H;W-T:6YG+V9I;&4M;6%N86=E<E]U;FMN;W=N7U]T
M:71L92<@/3X@)TUA;F%G92!F:6QE<R!O;B!D;VUA:6XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+V9I;&4M;6%N86=E<E]U;FMN;W=N
M7U]W:7IA<F0M=&ET;&4G(#T^("=-86YA9VEN9R!&:6QE<R<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O9FEL92UM86YA9V5R7W5N:VYO
M=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T(&$@9&]M86EN('=H
M:6-H(&9I;&5S(&%N9"!D:7)E8W1O<FEE<R!Y;W4@=V%N="!T;R!M86YA9V4@
M=VET:"!&:6QE($UA;F%G97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO:&]S=&EN9R]F:6QE+6UA;F%G97)?=6YK;F]W;E]?=VEZ87)D7U\S+W!R
M;W!E<G1I97-?<&AO<W1I;F<G(#T^("=(;W-T:6YG(&ES(&YO="!Y970@8V]N
M9FEG=7)E9"!O;B!T:&4@9&]M86EN+B!0;&5A<V4@<V5T('5P('!H>7-I8V%L
M(&AO<W1I;F<@86YD(&-L:6-K($YE>'0@/CX@=&\@<')O8V5E9"!T;R!&:6QE
M($UA;F%G97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN
M9R]F:6QE+6UA;F%G97)?=6YK;F]W;E]?=VEZ87)D7U\S+W!R;W!E<G1I97-?
M<V5L9BUP:&]S=&EN9R<@/3X@)TAO<W1I;F<@:7,@;F]T('EE="!C;VYF:6=U
M<F5D(&]N('EO=7(@9&]M86EN+B!0;&5A<V4@<V5T('5P('!H>7-I8V%L(&AO
M<W1I;F<@86YD(&-L:6-K($YE>'0@/CX@=&\@<')O8V5E9"!T;R!&:6QE($UA
M;F%G97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]F
M:6QE+6UA;F%G97)?=6YK;F]W;E]?=VEZ87)D7U\T)R`]/B`G5VAE;B!D;VYE
M('=I=&@@;6%N86=I;F<@9FEL97,@;VX@=&AE(&1O;6%I;BP@8VQI8VL@1FEN
M:7-H('1O(&5X:70@=&AE('=I>F%R9"XG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]H;W-T:6YG+V9I;&4M;6%N86=E<E]U;FMN;W=N7U]W:7IA<F1?
M7S1?<V5L9B<@/3X@)U=H96X@9&]N92!W:71H(&UA;F%G:6YG(&9I;&5S(&]N
M('EO=7(@9&]M86EN+"!C;&EC:R!&:6YI<V@@=&\@97AI="!T:&4@=VEZ87)D
M+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W!R;W!E
M<G1I97-?7V1E<V-R:7!T:6]N)R`]/B`G4V5T('5P(&AO<W1I;F<@<V5R=FEC
M97,@9F]R(&1O;6%I;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]H;W-T:6YG+W!R;W!E<G1I97-?7W-H;W)T+71I=&QE)R`]/B`G4V5T('5P
M(&AO<W1I;F<G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG
M+W!R;W!E<G1I97-?7W1I=&QE)R`]/B`G4V5T('5P(&AO<W1I;F<@;VX@9&]M
M86EN("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]P
M<F]P97)T:65S7V9O<G=A<F1I;F=?7V1E<V-R:7!T:6]N)R`]/B`G0V]N9FEG
M=7)E(&9O<G=A<F1I;F<@;VX@9&]M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VAO<W1I;F<O<')O<&5R=&EE<U]F;W)W87)D:6YG7U]D
M;VYE)R`]/B`G1F]R=V%R9&EN9R!P<F]P97)T:65S(&]N(&1O;6%I;B`E,2!H
M879E(&)E96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]H;W-T:6YG+W!R;W!E<G1I97-?9F]R=V%R9&EN9U]?<VAO<G0M=&ET;&4G
M(#T^("=#;VYF:6=U<F4@9F]R=V%R9&EN9R<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VAO<W1I;F<O<')O<&5R=&EE<U]F;W)W87)D:6YG7U]T:71L
M92<@/3X@)T-O;F9I9W5R92!F;W)W87)D:6YG(&]N(&1O;6%I;B`E,2<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<')O<&5R=&EE<U]P
M:&]S=&EN9U]?9&5S8W)I<'1I;VXG(#T^("=#;VYF:6=U<F4@=FER='5A;"!H
M;W-T(&9O<B!D;VUA:6X@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO:&]S=&EN9R]P<F]P97)T:65S7W!H;W-T:6YG7U]D;VYE)R`]/B`G4&AY
M<VEC86P@:&]S=&EN9R!S971T:6YG<R!O;B!D;VUA:6X@)3$@:&%V92!B965N
M('5P9&%T960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN
M9R]P<F]P97)T:65S7W!H;W-T:6YG7U]S:&]R="UT:71L92<@/3X@)T-O;F9I
M9W5R92!P:'ES:6-A;"!H;W-T:6YG)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S7W!H;W-T:6YG7U]T:71L92<@/3X@
M)T-O;F9I9W5R92!P:'ES:6-A;"!H;W-T:6YG(&]N(&1O;6%I;B`E,2<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<')O<&5R=&EE<U]S
M96QF+69O<G=A<F1I;F=?7V1E<V-R:7!T:6]N)R`]/B`G0V]N9FEG=7)E(&9O
M<G=A<F1I;F<@;VX@>6]U<B!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S7W-E;&8M9F]R=V%R9&EN9U]?
M9&]N92<@/3X@)T9O<G=A<F1I;F<@;VX@>6]U<B!D;VUA:6X@:&%S(&)E96X@
M8V]N9FEG=7)E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T
M:6YG+W!R;W!E<G1I97-?<V5L9BUF;W)W87)D:6YG7U]S:&]R="UT:71L92<@
M/3X@)T-O;F9I9W5R92!F;W)W87)D:6YG)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S7W-E;&8M9F]R=V%R9&EN9U]?
M=&ET;&4G(#T^("=#;VYF:6=U<F4@9F]R=V%R9&EN9R<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<')O<&5R=&EE<U]S96QF+7!H;W-T
M:6YG7U]D97-C<FEP=&EO;B<@/3X@)T-O;F9I9W5R92!V:7)T=6%L(&AO<W0@
M9F]R('EO=7(@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VAO<W1I;F<O<')O<&5R=&EE<U]S96QF+7!H;W-T:6YG7U]D;VYE)R`]/B`G
M4&AY<VEC86P@:&]S=&EN9R!S971T:6YG<R!O;B!Y;W5R(&1O;6%I;B!H879E
M(&)E96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H
M;W-T:6YG+W!R;W!E<G1I97-?<V5L9BUP:&]S=&EN9U]?<VAO<G0M=&ET;&4G
M(#T^("=#;VYF:6=U<F4@<&AY<VEC86P@:&]S=&EN9R<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<')O<&5R=&EE<U]S96QF+7!H;W-T
M:6YG7U]T:71L92<@/3X@)T-O;F9I9W5R92!P:'ES:6-A;"!H;W-T:6YG)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S
M7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G0VQI8VL@=&\@<V5T('5P(&AO<W1I
M;F<@<V5R=FEC97,@9F]R('EO=7(@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VAO<W1I;F<O<')O<&5R=&EE<U]S96QF7U]S:&]R="UT
M:71L92<@/3X@)U-E="!U<"!H;W-T:6YG)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S7W-E;&9?7W1I=&QE)R`]/B`G
M4V5T('5P(&AO<W1I;F<G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H
M;W-T:6YG+W!R;W!E<G1I97-?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=#
M;VYF:6=U<F4@:&]S=&EN9R!S97)V:6-E<R!F;W(@82!D;VUA:6XN)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S7W5N
M:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G0V]N9FEG=7)E(&AO<W1I;F<G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W!R;W!E<G1I97-?
M=6YK;F]W;E]?=&ET;&4G(#T^("=#;VYF:6=U<F4@:&]S=&EN9R!O;B!A(&1O
M;6%I;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<')O
M<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=#;VYF:6=U<FEN
M9R!(;W-T:6YG)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN
M9R]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G
M4V5L96-T(&$@9&]M86EN(&9O<B!W:&EC:"!Y;W4@=V%N="!T;R!C;VYF:6=U
M<F4@:&]S=&EN9R!S97)V:6-E<R!A;F0@8VQI8VL@3F5X="`^/BXG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W!R;W!E<G1I97-?=6YK
M;F]W;E]?=VEZ87)D7U\T)R`]/B`G4V5L96-T('1H92!T>7!E(&]F(&AO<W1I
M;F<@<V5R=FEC97,@>6]U('=A;G0@=&\@8V]N9FEG=7)E(&]N('1H92!D;VUA
M:6X@86YD(&-L:6-K($YE>'0@/CXN)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?-%]F
M;W)W87)D:6YG)R`]/B`G5VAE;B!D;VYE('=I=&@@8V]N9FEG=7)I;F<@9F]R
M=V%R9&EN9R!O;B!T:&4@9&]M86EN+"!C;&EC:R!&:6YI<V@N)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S7W5N:VYO
M=VY?7W=I>F%R9%]?-%]P:&]S=&EN9R<@/3X@)U=H96X@9&]N92!W:71H(&-O
M;F9I9W5R:6YG('!H>7-I8V%L(&AO<W1I;F<@;VX@=&AE(&1O;6%I;BP@8VQI
M8VL@1FEN:7-H('1O(&%P<&QY('1H92!C;VYF:6=U<F%T:6]N(&%N9"!E>&ET
M('1H92!W:7IA<F0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S
M=&EN9R]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?-%]S96QF)R`]/B`G
M4V5L96-T('1H92!T>7!E(&]F(&AO<W1I;F<@<V5R=FEC97,@>6]U('=A;G0@
M=&\@8V]N9FEG=7)E(&]N('1H92!D;VUA:6X@86YD(&-L:6-K($YE>'0@/CXN
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]P<F]P97)T
M:65S7W5N:VYO=VY?7W=I>F%R9%]?-%]S96QF+69O<G=A<F1I;F<G(#T^("=7
M:&5N(&1O;F4@=VET:"!C;VYF:6=U<FEN9R!F;W)W87)D:6YG(&]N('EO=7(@
M9&]M86EN+"!C;&EC:R!&:6YI<V@N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?-%]S
M96QF+7!H;W-T:6YG)R`]/B`G5VAE;B!D;VYE('=I=&@@8V]N9FEG=7)I;F<@
M<&AY<VEC86P@:&]S=&EN9R!O;B!Y;W5R(&1O;6%I;BP@8VQI8VL@1FEN:7-H
M+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-I=&4M
M87!P;&EC871I;VYS7U]D97-C<FEP=&EO;B<@/3X@)TUA;F%G92!S:71E(&%P
M<&QI8V%T:6]N<R!O;B!D;VUA:6X@)3$N)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<U]?<VAO<G0M=&ET
M;&4G(#T^("=3:71E(&%P<&QI8V%T:6]N<R<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO;G-?7W1I=&QE)R`]
M/B`G36%N86=E('-I=&4@87!P;&EC871I;VYS(&]N(&1O;6%I;B`E,2<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A
M=&EO;G-?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=-86YA9V4@<VET92!A<'!L
M:6-A=&EO;G,@;VX@>6]U<B!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<U]S96QF7U]S:&]R
M="UT:71L92<@/3X@)U-I=&4@87!P;&EC871I;VYS)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<U]S96QF
M7U]T:71L92<@/3X@)TUA;F%G92!M>2!S:71E(&%P<&QI8V%T:6]N<R<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A
M=&EO;G-?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=-86YA9V4@<VET92!A
M<'!L:6-A=&EO;G,@;VX@82!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<U]U;FMN;W=N7U]S
M:&]R="UT:71L92<@/3X@)U-I=&4@87!P;&EC871I;VYS)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<U]U
M;FMN;W=N7U]T:71L92<@/3X@)TUA;F%G92!D;VUA:6X@<VET92!A<'!L:6-A
M=&EO;G,G+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S
M:71E+6%P<&QI8V%T:6]N<R]S:71E+6%P<&QI8V%T:6]N7U]D97-C<FEP=&EO
M;B<@/3X@)U)E8V]N9FEG=7)E('-I=&4@87!P;&EC871I;VX@)3$N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T
M:6]N<R]S:71E+6%P<&QI8V%T:6]N7U]N;VYE+6%V86EL86)L92<@/3X@)UEO
M=2!D;VY<)W0@:&%V92!A;GD@:6YS=&%L;&5D('-I=&4@87!P;&EC871I;VYS
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA
M<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;E]?;F]N92UA=F%I;&%B;&5?
M7S$G(#T^("=#;&EE;G0@)3$@9&]E<VY<)W0@:&%V92!A;GD@(&EN<W1A;&QE
M9"!S:71E(&%P<&QI8V%T:6]N<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC871I
M;VY?7VYO;F4M879A:6QA8FQE7U\R)R`]/B`G3F\@<VET92!A<'!L:6-A=&EO
M;G,@87)E(&-U<G)E;G1L>2!I;G-T86QL960@;VX@9&]M86EN("4Q+B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A
M=&EO;G,O<VET92UA<'!L:6-A=&EO;E]?<VAO<G0M=&ET;&4G(#T^("<E,2<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L
M:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;E]?=&ET;&4G(#T^("=3:71E(&%P
M<&QI8V%T:6]N("4Q)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO
M<W1I;F<O<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]D96QE
M=&5?7V1E<V-R:7!T:6]N)R`]/B`G56YI;G-T86QL('-I=&4@87!P;&EC871I
M;VX@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S
M:71E+6%P<&QI8V%T:6]N<R]S:71E+6%P<&QI8V%T:6]N+V1E;&5T95]?9&]N
M92<@/3X@)U-I=&4@87!P;&EC871I;VX@)3$@:&%S(&)E96X@=6YI;G-T86QL
M960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E
M+6%P<&QI8V%T:6]N<R]S:71E+6%P<&QI8V%T:6]N+V1E;&5T95]?<VAO<G0M
M=&ET;&4G(#T^("=296UO=F4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC871I;VXO
M9&5L971E7U]T:71L92<@/3X@)U)E;6]V92!S:71E(&%P<&QI8V%T:6]N("4Q
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P
M<&QI8V%T:6]N<R]S:71E+6%P<&QI8V%T:6]N+V1E;&5T95]U;FMN;W=N7U]D
M97-C<FEP=&EO;B<@/3X@)U5N:6YS=&%L;"!A('-I=&4@87!P;&EC871I;VXN
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P
M<&QI8V%T:6]N<R]S:71E+6%P<&QI8V%T:6]N+V1E;&5T95]U;FMN;W=N7U]S
M:&]R="UT:71L92<@/3X@)U)E;6]V92<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A
M=&EO;B]D96QE=&5?=6YK;F]W;E]?=&ET;&4G(#T^("=296UO=F4@<VET92!A
M<'!L:6-A=&EO;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I
M;F<O<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]D96QE=&5?
M=6YK;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G4VET92!!<'!L:6-A=&EO;B!5
M;FEN<W1A;&PG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG
M+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC871I;VXO9&5L971E7W5N
M:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T(&$@9&]M86EN
M(&]N('=H:6-H('EO=2!W86YT('1O('5N:6YS=&%L;"!A('-I=&4@87!P;&EC
M871I;VX@86YD(&-L:6-K($YE>'0@/CXN)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<R]S:71E+6%P<&QI
M8V%T:6]N+V1E;&5T95]U;FMN;W=N7U]W:7IA<F1?7S5?=6YK;F]W;B<@/3X@
M)U-E;&5C="!A('-I=&4@87!P;&EC871I;VX@>6]U('=A;G0@=&\@=6YI;G-T
M86QL("!A;F0@8VQI8VL@3F5X="`^/BXG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC
M871I;VXO9&5L971E7W5N:VYO=VY?7W=I>F%R9%]?-B<@/3X@)T-O;F9I<FT@
M=6YI;G-T86QL:6YG('1H92!S:71E(&%P<&QI8V%T:6]N(&)Y('-E;&5C=&EN
M9R!T:&4@8VAE8VL@8F]X(&%N9"!C;&EC:R!&:6YI<V@@=&\@8V]M<&QE=&5L
M>2!U;FEN<W1A;&P@:70@86YD(&5X:70@=&AE('=I>F%R9"XG+`H*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N
M<R]S:71E+6%P<&QI8V%T:6]N+W!R;W!E<G1I97-?7V1E<V-R:7!T:6]N)R`]
M/B`G4F5C;VYF:6=U<F4@<VET92!A<'!L:6-A=&EO;B`E,2XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS
M+W-I=&4M87!P;&EC871I;VXO<')O<&5R=&EE<U]?9&]N92<@/3X@)U-I=&4@
M87!P;&EC871I;VX@)3$@8V]N9FEG=7)A=&EO;B!H87,@8F5E;B!U<&1A=&5D
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA
M<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]P<F]P97)T:65S7U]S:&]R
M="UT:71L92<@/3X@)U)E8V]N9FEG=7)E)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<R]S:71E+6%P<&QI
M8V%T:6]N+W!R;W!E<G1I97-?7W1I=&QE)R`]/B`G4F5C;VYF:6=U<F4@<VET
M92!A<'!L:6-A=&EO;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]P
M<F]P97)T:65S7VYE=U]?9&5S8W)I<'1I;VXG(#T^("=);G-T86QL(&$@<VET
M92!A<'!L:6-A=&EO;B!O;B!A(&1O;6%I;BXG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P
M;&EC871I;VXO<')O<&5R=&EE<U]N97=?7V1O;F4G(#T^("=3:71E(&%P<&QI
M8V%T:6]N("4Q(&AA<R!B965N(&EN<W1A;&QE9"XG+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M
M87!P;&EC871I;VXO<')O<&5R=&EE<U]N97=?7W-H;W)T+71I=&QE)R`]/B`G
M26YS=&%L;"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O
M<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]P<F]P97)T:65S
M7VYE=U]?=&ET;&4G(#T^("=);G-T86QL('-I=&4@87!P;&EC871I;VXG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-I=&4M87!P;&EC
M871I;VYS+W-I=&4M87!P;&EC871I;VXO<')O<&5R=&EE<U]N97=?7W=I>F%R
M9"UT:71L92<@/3X@)U-I=&4@07!P;&EC871I;VX@26YS=&%L;&%T:6]N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI
M8V%T:6]N<R]S:71E+6%P<&QI8V%T:6]N+W!R;W!E<G1I97-?;F5W7U]W:7IA
M<F1?7S$O8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T:65S
M)R`]/B`G4V5T('5P('!R;W!E<G1I97,@;V8@=&AE(&-U<W1O;2!B=71T;VX@
M86YD(&-L:6-K($9I;FES:"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC871I;VXO
M<')O<&5R=&EE<U]N97=?7W=I>F%R9%]?,B]C=7-T;VTM8G5T=&]N<R]C=7-T
M;VTM8G5T=&]N+W!R;W!E<G1I97,G(#T^("=3970@=7`@<')O<&5R=&EE<R!O
M9B!T:&4@8W5S=&]M(&)U='1O;B!A;F0@8VQI8VL@1FEN:7-H+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO
M;G,O<VET92UA<'!L:6-A=&EO;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\R
M7W5N:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@;VX@=VAI8V@@>6]U('=A
M;G0@=&\@:6YS=&%L;"!S:71E(&%P<&QI8V%T:6]N(&%N9"!C;&EC:R!.97AT
M(#X^+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET
M92UA<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]P<F]P97)T:65S7VYE
M=U]?=VEZ87)D7U\S+W!R;W!E<G1I97-?<&AO<W1I;F<G(#T^("=(;W-T:6YG
M(&ES(&YO="!Y970@8V]N9FEG=7)E9"!O;B!T:&4@9&]M86EN+B!3970@=7`@
M<&AY<VEC86P@:&]S=&EN9R!A;F0@8VQI8VL@3F5X="`^/B!T;R!P<F]C965D
M('1O(&EN<W1A;&QI;F<@=&AE('-I=&4@87!P;&EC871I;VXN)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N
M<R]S:71E+6%P<&QI8V%T:6]N+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S,O
M<')O<&5R=&EE<U]S96QF+7!H;W-T:6YG)R`]/B`G2&]S=&EN9R!I<R!N;W0@
M>65T(&-O;F9I9W5R960@;VX@>6]U<B!D;VUA:6XN(%-E="!U<"!P:'ES:6-A
M;"!H;W-T:6YG(&%N9"!C;&EC:R!.97AT(#X^('1O('!R;V-E960@=&\@:6YS
M=&%L;&EN9R!T:&4@<VET92!A<'!L:6-A=&EO;BXG+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M
M87!P;&EC871I;VXO<')O<&5R=&EE<U]N97=?7W=I>F%R9%]?-5]N97<G(#T^
M("=396QE8W0@82!S:71E(&%P<&QI8V%T:6]N('EO=2!W86YT('1O(&EN<W1A
M;&P@86YD(&-L:6-K($YE>'0@/CXN)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<R]S:71E+6%P<&QI8V%T
M:6]N+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S5?;F5W+65X=')A)R`]/B`G
M1&5F:6YE('=H870@<VAO=6QD(&)E(&1O;F4@=&\@=&AE(&5X=')A(&9I;&5S
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA
M<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]P<F]P97)T:65S7VYE=U]?
M=VEZ87)D7U\U7VYE=RUI;F9O)R`]/B`G0VQI8VL@3F5X="`^/B!T;R!I;G-T
M86QL('1H92!S:71E(&%P<&QI8V%T:6]N+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L
M:6-A=&EO;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\U7VYE=RUI;G-T86QL
M)R`]/B`G4W!E8VEF>2!T:&4@<VET92!A<'!L:6-A=&EO;B!P87)A;65T97)S
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA
M<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]P<F]P97)T:65S7VYE=U]?
M=VEZ87)D7U]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+W!R;W!E<G1I
M97,G(#T^("=3970@=7`@<')O<&5R=&EE<R!O9B!T:&4@8W5S=&]M(&)U='1O
M;B!A;F0@8VQI8VL@1FEN:7-H+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO
M;B]P<F]P97)T:65S7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G4F5C;VYF
M:6=U<F4@82!S:71E(&%P<&QI8V%T:6]N+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L
M:6-A=&EO;B]P<F]P97)T:65S7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G
M4F5C;VYF:6=U<F4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T
M:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC871I;VXO<')O<&5R
M=&EE<U]U;FMN;W=N7U]T:71L92<@/3X@)U)E8V]N9FEG=7)E('-I=&4@87!P
M;&EC871I;VXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG
M+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC871I;VXO<')O<&5R=&EE
M<U]U;FMN;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=3:71E($%P<&QI8V%T:6]N
M(%)E8V]N9FEG=7)A=&EO;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]P
M<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L
M96-T(&$@9&]M86EN(&]N('=H:6-H('EO=2!W86YT('1O(')E8V]N9FEG=7)E
M(&$@<VET92!A<'!L:6-A=&EO;BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC871I
M;VXO<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S5?=6YK;F]W;B<@/3X@
M)U-E;&5C="!A('-I=&4@87!P;&EC871I;VX@>6]U('=A;G0@=&\@<F5C;VYF
M:6=U<F4N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S
M:71E+6%P<&QI8V%T:6]N<R]S:71E+6%P<&QI8V%T:6]N+W!R;W!E<G1I97-?
M=6YK;F]W;E]?=VEZ87)D7U\V)R`]/B`G4W!E8VEF>2!T:&4@<VET92!A<'!L
M:6-A=&EO;B!P87)A;65T97)S+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G-?7V1E<V-R:7!T:6]N)R`]/B`G3&ES
M="!O9B!D;VUA:6X@)3$@<W5B9&]M86EN<RXG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G-?7W-H;W)T+71I=&QE)R`]
M/B`G4W5B9&]M86EN<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO
M<W1I;F<O<W5B9&]M86EN<U]?=&ET;&4G(#T^("=3=6)D;VUA:6YS(&]F(&1O
M;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O
M<W5B9&]M86EN<U]S96QF7U]D97-C<FEP=&EO;B<@/3X@)TQI<W0@;V8@>6]U
M<B!S=6)D;VUA:6YS+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO
M<W1I;F<O<W5B9&]M86EN<U]S96QF7U]S:&]R="UT:71L92<@/3X@)U-U8F1O
M;6%I;G,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U
M8F1O;6%I;G-?<V5L9E]?=&ET;&4G(#T^("=->2!S=6)D;VUA:6YS)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS7W5N
M:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G4W5B9&]M86EN<R!O9B!A(&1O;6%I
M;BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O
M;6%I;G-?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=3=6)D;VUA:6YS)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS
M7W5N:VYO=VY?7W1I=&QE)R`]/B`G4W5B9&]M86EN<R!O9B!A(&1O;6%I;B<L
M"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I
M;G,O<W5B9&]M86EN7U]D97-C<FEP=&EO;B<@/3X@)U!R;W!E<G1I97,@;V8@
M<W5B9&]M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO
M<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA:6Y?7VYO;F4M879A:6QA8FQE)R`]
M/B`G66]U(&1O;EPG="!H879E(&%N>2!S=6)D;VUA:6YS+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA
M:6Y?7VYO;F4M879A:6QA8FQE7U\Q)R`]/B`G0VQI96YT("4Q(&1O97-N7"=T
M(&AA=F4@86YY('-U8F1O;6%I;G,N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS+W-U8F1O;6%I;E]?;F]N92UA=F%I
M;&%B;&5?7S(G(#T^("=4:&5R92!A<F4@;F\@<W5B9&]M86EN<R!O;B!D;VUA
M:6X@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S
M=6)D;VUA:6YS+W-U8F1O;6%I;E]?<VAO<G0M=&ET;&4G(#T^("<E,2<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S
M=6)D;VUA:6Y?7W1I=&QE)R`]/B`G4W5B9&]M86EN("4Q)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS+W-U8F1O;6%I
M;E]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)T-O;F9I9W5R92!S=6)D;VUA
M:6X@:&]S=&EN9R!S971T:6YG<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN7W5N:VYO=VY?7W-H
M;W)T+71I=&QE)R`]/B`G4W5B9&]M86EN)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS+W-U8F1O;6%I;E]U;FMN;W=N
M7U]T:71L92<@/3X@)T-O;F9I9W5R92!S=6)D;VUA:6XG+`H*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS+W-U8F1O;6%I
M;B]D96QE=&5?7V1E<V-R:7!T:6]N)R`]/B`G4F5M;W9E('-U8F1O;6%I;B`E
M,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O
M;6%I;G,O<W5B9&]M86EN+V1E;&5T95]?9&]N92<@/3X@)U-U8F1O;6%I;B`E
M,2!H87,@8F5E;B!R96UO=F5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA:6XO9&5L971E7U]S:&]R
M="UT:71L92<@/3X@)U)E;6]V92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA:6XO9&5L971E7U]T:71L
M92<@/3X@)U)E;6]V92!S=6)D;VUA:6X@)3$G+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+V1E;&5T
M95]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)T1E;&5T92!S=6)D;VUA:6X@
M8V]N9FEG=7)A=&EO;B!A;F0@8V]N=&5N="XG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+V1E;&5T
M95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)U)E;6]V92<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA
M:6XO9&5L971E7W5N:VYO=VY?7W1I=&QE)R`]/B`G4F5M;W9E('-U8F1O;6%I
M;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M
M86EN<R]S=6)D;VUA:6XO9&5L971E7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@
M/3X@)U-U8F1O;6%I;B!296UO=F%L)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS+W-U8F1O;6%I;B]D96QE=&5?=6YK
M;F]W;E]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@
M9G)O;2!W:&EC:"!Y;W4@=V%N="!T;R!R96UO=F4@82!S=6)D;VUA:6XN)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS
M+W-U8F1O;6%I;B]D96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\U7W5N:VYO=VXG
M(#T^("=396QE8W0@82!S=6)D;VUA:6X@>6]U('=A;G0@=&\@<F5M;W9E+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M86EN
M<R]S=6)D;VUA:6XO9&5L971E7W5N:VYO=VY?7W=I>F%R9%]?-B<@/3X@)T-O
M;F9I<FT@<F5M;W9I;F<@=&AE('-U8F1O;6%I;B!B>2!S96QE8W1I;F<@=&AE
M(&-H96-K(&)O>"!A;F0@8VQI8VL@9FEN:7-H('1O(&-O;7!L971E;'D@<F5M
M;W9E(&ET(&%N9"!E>&ET('1H92!W:7IA<F0N)RP*"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA:6XO<')O
M<&5R=&EE<U]?9&5S8W)I<'1I;VXG(#T^("=#;VYF:6=U<F4@<W5B9&]M86EN
M("4Q(&AO<W1I;F<@<V5T=&EN9W,N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS+W-U8F1O;6%I;B]P<F]P97)T:65S
M7U]D;VYE)R`]/B`G4W5B9&]M86EN("4Q(&-O;F9I9W5R871I;VX@:&%S(&)E
M96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T
M:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+W!R;W!E<G1I97-?7W-H;W)T+71I
M=&QE)R`]/B`G)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T
M:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+W!R;W!E<G1I97-?7W1I=&QE)R`]
M/B`G0V]N9FEG=7)E('-U8F1O;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA:6XO<')O<&5R
M=&EE<U]N97<M861H;V-?7W=I>F%R9%]?-5]N97<G(#T^("=.97<@<W5B9&]M
M86EN('=I;&P@8F4@8W)E871E9"!I;6UE9&EA=&5L>2!A9G1E<B!Y;W4@8VQI
M8VL@3F5X="`^/BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T
M:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+W!R;W!E<G1I97-?;F5W7U]D97-C
M<FEP=&EO;B<@/3X@)T-R96%T92!N97<@<W5B9&]M86EN+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA
M:6XO<')O<&5R=&EE<U]N97=?7V1O;F4G(#T^("=3=6)D;VUA:6X@)3$@:&%S
M(&)E96X@8W)E871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H
M;W-T:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+W!R;W!E<G1I97-?;F5W7U]S
M:&]R="UT:71L92<@/3X@)T-R96%T92!S=6)D;VUA:6XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN
M+W!R;W!E<G1I97-?;F5W7U]T:71L92<@/3X@)T-R96%T92!S=6)D;VUA:6XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I
M;G,O<W5B9&]M86EN+W!R;W!E<G1I97-?;F5W7U]W:7IA<F0M=&ET;&4G(#T^
M("=3=6)D;VUA:6X@0W)E871I;VXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+W!R;W!E<G1I97-?
M;F5W7U]W:7IA<F1?7S)?=6YK;F]W;B<@/3X@)U-E;&5C="!A(&1O;6%I;B!O
M;B!W:&EC:"!Y;W4@=V%N="!T;R!C<F5A=&4@82!S=6)D;VUA:6XN)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS+W-U
M8F1O;6%I;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\S+W!R;W!E<G1I97-?
M<&AO<W1I;F<G(#T^("=(;W-T:6YG(&ES(&YO="!Y970@8V]N9FEG=7)E9"!O
M;B!T:&4@9&]M86EN+B!3970@=7`@<&AY<VEC86P@:&]S=&EN9R!A;F0@8VQI
M8VL@3F5X="`^/B!T;R!P<F]C965D('1O('-U8F1O;6%I;B!C<F5A=&EO;BXG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I
M;G,O<W5B9&]M86EN+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S,O<')O<&5R
M=&EE<U]S96QF+7!H;W-T:6YG)R`]/B`G2&]S=&EN9R!I<R!N;W0@>65T(&-O
M;F9I9W5R960@;VX@>6]U<B!D;VUA:6XN(%-E="!U<"!P:'ES:6-A;"!H;W-T
M:6YG(&%N9"!C;&EC:R!.97AT(#X^('1O('!R;V-E960@=&\@<W5B9&]M86EN
M(&-R96%T:6]N+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I
M;F<O<W5B9&]M86EN<R]S=6)D;VUA:6XO<')O<&5R=&EE<U]N97=?7W=I>F%R
M9%]?-5]N97<G(#T^("=3<&5C:69Y('1H92!S=6)D;VUA:6X@:&]S=&EN9R!P
M87)A;65T97)S(&%N9"!C;&EC:R!&:6YI<V@@=&\@8W)E871E('1H92!S=6)D
M;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S
M=6)D;VUA:6YS+W-U8F1O;6%I;B]P<F]P97)T:65S7W5N:VYO=VY?7V1E<V-R
M:7!T:6]N)R`]/B`G0V]N9FEG=7)E('-U8F1O;6%I;B!H;W-T:6YG('-E='1I
M;F=S+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B
M9&]M86EN<R]S=6)D;VUA:6XO<')O<&5R=&EE<U]U;FMN;W=N7U]S:&]R="UT
M:71L92<@/3X@)U-U8F1O;6%I;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA:6XO<')O<&5R=&EE<U]U
M;FMN;W=N7U]T:71L92<@/3X@)T-O;F9I9W5R92!S=6)D;VUA:6XG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G,O<W5B
M9&]M86EN+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G
M4W5B9&]M86EN($-O;F9I9W5R871I;VXG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+W!R;W!E<G1I
M97-?=6YK;F]W;E]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D
M;VUA:6X@=VAO<V4@<W5B9&]M86EN('EO=2!W86YT('1O(')E8V]N9FEG=7)E
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M
M86EN<R]S=6)D;VUA:6XO<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S5?
M=6YK;F]W;B<@/3X@)U-E;&5C="!A('-U8F1O;6%I;B!Y;W4@=V%N="!T;R!R
M96-O;F9I9W5R92XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T
M:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+W!R;W!E<G1I97-?=6YK;F]W;E]?
M=VEZ87)D7U\V)R`]/B`G5VAE;B!D;VYE('=I=&@@8V]N9FEG=7)I;F<@=&AE
M('-U8F1O;6%I;B!H;W-T:6YG('-E='1I;F=S+"!C;&EC:R!&:6YI<V@@=&\@
M87!P;'D@8VAA;F=E<R!A;F0@97AI="!T:&4@=VEZ87)D+B<L"@H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<U]?9&5S8W)I
M<'1I;VXG(#T^("=,:7-T(&]F(&1O;6%I;B`E,2!W96(@=7-E<G,N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E<G-?7W-H
M;W)T+71I=&QE)R`]/B`G5V5B('5S97)S)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E<G-?7W1I=&QE)R`]/B`G5V5B('5S
M97)S(&]F(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VAO<W1I;F<O=V5B+75S97)S7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G3&ES
M="!O9B!Y;W5R('=E8B!U<V5R<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]H;W-T:6YG+W=E8BUU<V5R<U]S96QF7U]S:&]R="UT:71L92<@/3X@
M)U=E8B!U<V5R<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I
M;F<O=V5B+75S97)S7W-E;&9?7W1I=&QE)R`]/B`G37D@=V5B('5S97)S)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E<G-?
M=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=,:7-T(&]F(&1O;6%I;B!W96(@
M=7-E<G,N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W
M96(M=7-E<G-?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=796(@=7-E<G,G
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R
M<U]U;FMN;W=N7U]T:71L92<@/3X@)T1O;6%I;B!W96(@=7-E<G,G+`H*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E<G,O<')O
M<&5R=&EE<U]?9&5S8W)I<'1I;VXG(#T^("=796(@=7-E<G,@<')E9F5R96YC
M97,@;VX@9&]M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VAO<W1I;F<O=V5B+75S97)S+W!R;W!E<G1I97-?7V1O;F4G(#T^("=796(@
M=7-E<G,@<')E9F5R96YC97,@:&%V92!B965N('5P9&%T960@;VX@9&]M86EN
M("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B
M+75S97)S+W!R;W!E<G1I97-?7W-H;W)T+71I=&QE)R`]/B`G4')E9F5R96YC
M97,@9F]R('=E8B!U<V5R<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VAO<W1I;F<O=V5B+75S97)S+W!R;W!E<G1I97-?7W1I=&QE)R`]/B`G5V5B
M('5S97)S('!R969E<F5N8V5S(&]N(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W!R;W!E<G1I97-?
M<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=9;W5R('=E8B!U<V5R<R!P<F5F97)E
M;F-E<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B
M+75S97)S+W!R;W!E<G1I97-?<V5L9E]?9&]N92<@/3X@)UEO=7(@=V5B('5S
M97)S('!R969E<F5N8V5S(&AA=F4@8F5E;B!U<&1A=&5D+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W!R;W!E<G1I
M97-?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=796(@=7-E<G,@<')E9F5R96YC
M97,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU
M<V5R<R]P<F]P97)T:65S7W-E;&9?7W1I=&QE)R`]/B`G37D@=V5B('5S97)S
M('!R969E<F5N8V5S)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S
M=&EN9R]W96(M=7-E<G,O<')O<&5R=&EE<U]U;FMN;W=N7U]D97-C<FEP=&EO
M;B<@/3X@)U=E8B!U<V5R<R!P<F5F97)E;F-E<R!O9B!A(&1O;6%I;BXG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<R]P
M<F]P97)T:65S7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G4')E9F5R96YC
M97,@9F]R('=E8B!U<V5R<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VAO<W1I;F<O=V5B+75S97)S+W!R;W!E<G1I97-?=6YK;F]W;E]?=&ET;&4G
M(#T^("=796(@=7-E<G,@<')E9F5R96YC97,@;V8@82!D;VUA:6XG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<R]P<F]P
M97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T
M(&$@9&]M86EN(&9O<B!W:&EC:"!Y;W4@=V%N="!T;R!C;VYF:6=U<F4@=V5B
M('5S97)S('!R969E<F5N8V5S+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VAO<W1I;F<O=V5B+75S97)S+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ
M87)D7U\U)R`]/B`G5VAE;B!D;VYE('=I=&@@961I=&EN9R!T:&4@=V5B('5S
M97)S('!R969E<F5N8V5S+"!C;&EC:R!&:6YI<V@@=&\@87!P;'D@8VAA;F=E
M<R!A;F0@97AI="!T:&4@=VEZ87)D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W!R;W!E<G1I97-?=6YK;F]W;E]?
M=VEZ87)D7U\U7W-E;&8G(#T^("=7:&5N(&1O;F4@=VET:"!E9&ET:6YG('EO
M=7(@=V5B('5S97)S('!R969E<F5N8V5S+"!C;&EC:R!&:6YI<V@@=&\@87!P
M;'D@8VAA;F=E<R!A;F0@97AI="!T:&4@=VEZ87)D+B<L"@H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<R]W96(M=7-E<E]?
M9&5S8W)I<'1I;VXG(#T^("=796(@=7-E<B`E,2!P<F]P97)T:65S+B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E
M8BUU<V5R7U]N;VYE+6%V86EL86)L92<@/3X@)UEO=2!D;VY<)W0@:&%V92!A
M;GD@=V5B('5S97)S+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO
M<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R7U]N;VYE+6%V86EL86)L95]?,2<@
M/3X@)T-L:65N="`E,2!D;V5S;EPG="!H879E(&%N>2!W96(@=7-E<G,N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E<G,O
M=V5B+75S97)?7VYO;F4M879A:6QA8FQE7U\R)R`]/B`G5&AE<F4@87)E(&YO
M('=E8B!U<V5R(&%C8V]U;G1S(&]N(&1O;6%I;B`E,2XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<R]W96(M=7-E<E]?
M<VAO<G0M=&ET;&4G(#T^("<E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R7U]T:71L92<@/3X@)U=E
M8B!U<V5R("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN
M9R]W96(M=7-E<G,O=V5B+75S97)?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^
M("=#:&%N9V4@<&%S<W=O<F0@9F]R('=E8B!U<V5R(&%C8V]U;G0L(&QI;6ET
M(&1I<VL@<W!A8V4@=7-A9V4@86YD('-E="!U<"!S8W)I<'1S('-U<'!O<G0N
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E
M<G,O=V5B+75S97)?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=796(@=7-E
M<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S
M97)S+W=E8BUU<V5R7W5N:VYO=VY?7W1I=&QE)R`]/B`G0V]N9FEG=7)E('=E
M8B!U<V5R(&%C8V]U;G0G+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:&]S=&EN9R]W96(M=7-E<G,O=V5B+75S97(O9&5L971E7U]D97-C<FEP=&EO
M;B<@/3X@)T1E;&5T92!W96(@=7-E<B!A8V-O=6YT(&%N9"!C;VYT96YT+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S
M+W=E8BUU<V5R+V1E;&5T95]?9&]N92<@/3X@)U=E8B!U<V5R("4Q(&AA<R!B
M965N(')E;6]V960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S
M=&EN9R]W96(M=7-E<G,O=V5B+75S97(O9&5L971E7U]S:&]R="UT:71L92<@
M/3X@)U)E;6]V92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I
M;F<O=V5B+75S97)S+W=E8BUU<V5R+V1E;&5T95]?=&ET;&4G(#T^("=296UO
M=F4@=V5B('5S97(@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H
M;W-T:6YG+W=E8BUU<V5R<R]W96(M=7-E<B]D96QE=&5?=6YK;F]W;E]?9&5S
M8W)I<'1I;VXG(#T^("=$96QE=&4@82!W96(@=7-E<B!A8V-O=6YT(&%N9"!C
M;VYT96YT+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O
M=V5B+75S97)S+W=E8BUU<V5R+V1E;&5T95]U;FMN;W=N7U]S:&]R="UT:71L
M92<@/3X@)U)E;6]V92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO
M<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R+V1E;&5T95]U;FMN;W=N7U]T:71L
M92<@/3X@)U)E;6]V92!W96(@=7-E<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R+V1E;&5T95]U;FMN
M;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=796(@57-E<B!296UO=F%L)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E<G,O=V5B
M+75S97(O9&5L971E7W5N:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G
M4V5L96-T(&$@9&]M86EN(&9R;VT@=VAI8V@@>6]U('=A;G0@=&\@<F5M;W9E
M(&$@=V5B('5S97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S
M=&EN9R]W96(M=7-E<G,O=V5B+75S97(O9&5L971E7W5N:VYO=VY?7W=I>F%R
M9%]?-5]U;FMN;W=N)R`]/B`G4V5L96-T(&$@=V5B('5S97(@86-C;W5N="!Y
M;W4@=V%N="!T;R!R96UO=F4N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO:&]S=&EN9R]W96(M=7-E<G,O=V5B+75S97(O9&5L971E7W5N:VYO=VY?
M7W=I>F%R9%]?-B<@/3X@)T-O;F9I<FT@<F5M;W9I;F<@=&AE('=E8B!U<V5R
M(&%C8V]U;G0@8GD@<V5L96-T:6YG('1H92!C:&5C:R!B;W@@86YD(&-L:6-K
M(&9I;FES:"!T;R!C;VUP;&5T96QY(')E;6]V92!I="!A;F0@97AI="!T:&4@
M=VEZ87)D+BXG+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN
M9R]W96(M=7-E<G,O=V5B+75S97(O<')O<&5R=&EE<U]?9&5S8W)I<'1I;VXG
M(#T^("=%9&ET('!R;W!E<G1I97,@;V8@=V5B('5S97(@)3$N)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E<G,O=V5B+75S
M97(O<')O<&5R=&EE<U]?9&]N92<@/3X@)U=E8B!U<V5R("4Q(&%C8V]U;G0@
M:&%V92!B965N('5P9&%T960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO:&]S=&EN9R]W96(M=7-E<G,O=V5B+75S97(O<')O<&5R=&EE<U]?<VAO
M<G0M=&ET;&4G(#T^("<E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R+W!R;W!E<G1I97-?7W1I=&QE
M)R`]/B`G0V]N9FEG=7)E('=E8B!U<V5R(&%C8V]U;G0@)3$G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<R]W96(M=7-E
M<B]P<F]P97)T:65S7VYE=RUA9&AO8U]?=VEZ87)D7U\U7VYE=R<@/3X@)TYE
M=R!W96(@=7-E<B!A8V-O=6YT('=I;&P@8F4@8W)E871E9"!I;6UE9&EA=&5L
M>2!A9G1E<B!Y;W4@8VQI8VL@3F5X="`^/BXG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<R]W96(M=7-E<B]P<F]P97)T
M:65S7VYE=U]?9&5S8W)I<'1I;VXG(#T^("=#<F5A=&4@;F5W('=E8B!U<V5R
M(&%C8V]U;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN
M9R]W96(M=7-E<G,O=V5B+75S97(O<')O<&5R=&EE<U]N97=?7V1O;F4G(#T^
M("=796(@=7-E<B`E,2!H87,@8F5E;B!C<F5A=&5D+B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R+W!R
M;W!E<G1I97-?;F5W7U]S:&]R="UT:71L92<@/3X@)T-R96%T92!W96(@=7-E
M<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S
M97)S+W=E8BUU<V5R+W!R;W!E<G1I97-?;F5W7U]T:71L92<@/3X@)T-R96%T
M92!W96(@=7-E<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I
M;F<O=V5B+75S97)S+W=E8BUU<V5R+W!R;W!E<G1I97-?;F5W7U]W:7IA<F0M
M=&ET;&4G(#T^("=796(@=7-E<B!C<F5A=&EO;B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R+W!R;W!E
M<G1I97-?;F5W7U]W:7IA<F1?7S)?=6YK;F]W;B<@/3X@)U-E;&5C="!A(&1O
M;6%I;B!O;B!W:&EC:"!Y;W4@=V%N="!T;R!C<F5A=&4@=V5B('5S97(@86-C
M;W5N="XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E
M8BUU<V5R<R]W96(M=7-E<B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\S+W!R
M;W!E<G1I97-?<&AO<W1I;F<G(#T^("=(;W-T:6YG(&ES(&YO="!Y970@8V]N
M9FEG=7)E9"!O;B!T:&4@9&]M86EN+B!3970@=7`@<&AY<VEC86P@:&]S=&EN
M9R!A;F0@8VQI8VL@3F5X="`^/B!T;R!P<F]C965D('1O(&-R96%T:6YG('=E
M8B!U<V5R(&%C8V]U;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:&]S=&EN9R]W96(M=7-E<G,O=V5B+75S97(O<')O<&5R=&EE<U]N97=?7W=I
M>F%R9%]?,R]P<F]P97)T:65S7W-E;&8M<&AO<W1I;F<G(#T^("=(;W-T:6YG
M(&ES(&YO="!Y970@8V]N9FEG=7)E9"!O;B!Y;W5R(&1O;6%I;BX@4V5T('5P
M('!H>7-I8V%L(&AO<W1I;F<@86YD(&-L:6-K($YE>'0@/CX@=&\@<')O8V5E
M9"!T;R!C<F5A=&EN9R!W96(@=7-E<B!A8V-O=6YT+B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R+W!R
M;W!E<G1I97-?;F5W7U]W:7IA<F1?7S5?;F5W)R`]/B`G0VQI8VL@1FEN:7-H
M('1O(&-R96%T92!T:&4@=V5B('5S97(@86-C;W5N="XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<R]W96(M=7-E<B]P
M<F]P97)T:65S7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G0VAA;F=E('!A
M<W-W;W)D(&9O<B!W96(@=7-E<B!A8V-O=6YT+"!L:6UI="!D:7-K('-P86-E
M('5S86=E(&%N9"!S970@=7`@<V-R:7!T<R!S=7!P;W)T+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R
M+W!R;W!E<G1I97-?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=796(@=7-E
M<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S
M97)S+W=E8BUU<V5R+W!R;W!E<G1I97-?=6YK;F]W;E]?=&ET;&4G(#T^("=#
M;VYF:6=U<F4@=V5B('5S97(@86-C;W5N="<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R+W!R;W!E<G1I
M97-?=6YK;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G0V]N9FEG=7)I;F<@5V5B
M(%5S97(@06-C;W5N="<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO
M<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R+W!R;W!E<G1I97-?=6YK;F]W;E]?
M=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@;VX@=VAI
M8V@@>6]U('=A;G0@=&\@<F5C;VYF:6=U<F4@=V5B('5S97(@86-C;W5N="XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R
M<R]W96(M=7-E<B]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?-5]U;FMN
M;W=N)R`]/B`G4V5L96-T('=E8B!U<V5R(&%C8V]U;G0@>6]U('=A;G0@=&\@
M<F5C;VYF:6=U<F4N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S
M=&EN9R]W96(M=7-E<G,O=V5B+75S97(O<')O<&5R=&EE<U]U;FMN;W=N7U]W
M:7IA<F1?7S8G(#T^("=7:&5N(&1O;F4@=VET:"!C;VYF:6=U<FEN9R!T:&4@
M=V5B('5S97(@86-C;W5N="P@8VQI8VL@1FEN:7-H('1O(&%P<&QY(&-H86YG
M97,@86YD(&5X:70@=&AE('=I>F%R9"XG+`H*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:6YD:6-A=&]R+61I<VLM<W!A8V4M;&EM:70M=7-A9V5?7V1E
M<V-R:7!T:6]N)R`]/B`G1&ES:R!S<&%C92!U<V%G92!L:6UI="!F;W(@9&]M
M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O
M<BUD:7-K+7-P86-E+6QI;6ET+75S86=E7U]S:&]R="UT:71L92<@/3X@)T1I
M<VL@<W!A8V4@=7-A9V4@;&EM:70G+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]I;F1I8V%T;W(M9&ES:RUS<&%C92UL:6UI="UU<V%G95]?=&ET;&4G
M(#T^("=$:7-K('-P86-E('5S86=E(&QI;6ET(&9O<B!D;VUA:6X@)3$G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M9&ES:RUS<&%C
M92UL:6UI="UU<V%G95]S96QF7U]D97-C<FEP=&EO;B<@/3X@)T1I<VL@<W!A
M8V4@=7-A9V4@;&EM:70@9F]R('EO=7(@9&]M86EN+B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUD:7-K+7-P86-E+6QI;6ET+75S
M86=E7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G1&ES:R!S<&%C92!U<V%G92!L
M:6UI="<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUD
M:7-K+7-P86-E+6QI;6ET+75S86=E7W-E;&9?7W1I=&QE)R`]/B`G1&ES:R!S
M<&%C92!U<V%G92!L:6UI="!F;W(@>6]U<B!D;VUA:6XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M9&ES:RUS<&%C92UL:6UI="UU
M<V%G95]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)T1I<VL@<W!A8V4@=7-A
M9V4@;&EM:70@9F]R(&$@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VEN9&EC871O<BUD:7-K+7-P86-E+6QI;6ET+75S86=E7W5N:VYO
M=VY?7W-H;W)T+71I=&QE)R`]/B`G1&ES:R!S<&%C92!U<V%G92!L:6UI="<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUD:7-K+7-P
M86-E+6QI;6ET+75S86=E7W5N:VYO=VY?7W1I=&QE)R`]/B`G1&ES:R!S<&%C
M92!U<V%G92!L:6UI="!F;W(@82!D;VUA:6XG+`H*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO:6YD:6-A=&]R+65X<&ER871I;VY?7V1E<V-R:7!T:6]N
M)R`]/B`G1&]M86EN("4Q(&5X<&ER871I;VX@9&%T92`N)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+65X<&ER871I;VY?7W-H;W)T
M+71I=&QE)R`]/B`G17AP:7)A=&EO;B!D871E)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO:6YD:6-A=&]R+65X<&ER871I;VY?7W1I=&QE)R`]/B`G
M1&]M86EN("4Q(&5X<&ER871I;VX@9&%T92<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VEN9&EC871O<BUE>'!I<F%T:6]N7W-E;&9?7V1E<V-R:7!T
M:6]N)R`]/B`G66]U<B!D;VUA:6X@97AP:7)A=&EO;B!D871E+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUE>'!I<F%T:6]N7W-E
M;&9?7W-H;W)T+71I=&QE)R`]/B`G17AP:7)A=&EO;B!D871E)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+65X<&ER871I;VY?<V5L
M9E]?=&ET;&4G(#T^("=9;W5R(&1O;6%I;B!E>'!I<F%T:6]N(&1A=&4N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+65X<&ER871I
M;VY?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=$;VUA:6X@97AP:7)A=&EO
M;B!D871E+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O
M<BUE>'!I<F%T:6]N7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G17AP:7)A
M=&EO;B!D871E)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A
M=&]R+65X<&ER871I;VY?=6YK;F]W;E]?=&ET;&4G(#T^("=$;VUA:6X@97AP
M:7)A=&EO;B!D871E)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN
M9&EC871O<BUF=6QL+7-T871U<U]?9&5S8W)I<'1I;VXG(#T^("=#;VUP;&5T
M92!S=&%T=7,@;V8@9&]M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VEN9&EC871O<BUF=6QL+7-T871U<U]?<VAO<G0M=&ET;&4G(#T^
M("=#;VUP;&5T92!S=&%T=7,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]I;F1I8V%T;W(M9G5L;"US=&%T=7-?7W1I=&QE)R`]/B`G0V]M<&QE=&4@
M<W1A='5S(&]F(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VEN9&EC871O<BUF=6QL+7-T871U<U]S96QF7U]D97-C<FEP=&EO;B<@
M/3X@)T-O;7!L971E('-T871U<R!O9B!Y;W5R(&1O;6%I;BXG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M9G5L;"US=&%T=7-?<V5L
M9E]?<VAO<G0M=&ET;&4G(#T^("=#;VUP;&5T92!S=&%T=7,G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M9G5L;"US=&%T=7-?<V5L
M9E]?=&ET;&4G(#T^("=#;VUP;&5T92!S=&%T=7,@;V8@>6]U<B!D;VUA:6XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M9G5L;"US
M=&%T=7-?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=#;VUP;&5T92!S=&%T
M=7,@;V8@82!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:6YD:6-A=&]R+69U;&PM<W1A='5S7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]
M/B`G0V]M<&QE=&4@<W1A='5S)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO:6YD:6-A=&]R+69U;&PM<W1A='5S7W5N:VYO=VY?7W1I=&QE)R`]/B`G
M0V]M<&QE=&4@<W1A='5S(&]F(&$@9&]M86EN)RP*"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VEN9&EC871O<BUI<%]?9&5S8W)I<'1I;VXG(#T^("=)
M4"!A9&1R97-S(&]F(&1O;6%I;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]I;F1I8V%T;W(M:7!?7W-H;W)T+71I=&QE)R`]/B`G25`@861D
M<F5S<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUI
M<%]?=&ET;&4G(#T^("=)4"!A9&1R97-S(&]F(&1O;6%I;B`E,2<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUI<%]S96QF7U]D97-C
M<FEP=&EO;B<@/3X@)TE0(&%D9')E<W,@;V8@>6]U<B!D;VUA:6XN)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+6EP7W-E;&9?7W-H
M;W)T+71I=&QE)R`]/B`G25`@861D<F5S<R<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VEN9&EC871O<BUI<%]S96QF7U]T:71L92<@/3X@)TE0(&%D
M9')E<W,@;V8@>6]U<B!D;VUA:6XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]I;F1I8V%T;W(M:7!?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=)
M4"!A9&1R97-S(&]F(&$@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VEN9&EC871O<BUI<%]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@
M)TE0(&%D9')E<W,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I
M8V%T;W(M:7!?=6YK;F]W;E]?=&ET;&4G(#T^("=)4"!A9&1R97-S(&]F(&$@
M9&]M86EN)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O
M<BUM87@M;6%I;&)O>&5S+6QI;6ET+75S86=E7U]D97-C<FEP=&EO;B<@/3X@
M)TUA:6QB;WAE<R!L:6UI="!U<V%G92!F;W(@9&]M86EN("4Q+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUM87@M;6%I;&)O>&5S
M+6QI;6ET+75S86=E7U]S:&]R="UT:71L92<@/3X@)TUA:6QB;WAE<R!L:6UI
M="!U<V%G92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O
M<BUM87@M;6%I;&)O>&5S+6QI;6ET+75S86=E7U]T:71L92<@/3X@)TUA:6QB
M;WAE<R!L:6UI="!U<V%G92!F;W(@9&]M86EN("4Q)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+6UA>"UM86EL8F]X97,M;&EM:70M
M=7-A9V5?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=-86EL8F]X97,@;&EM:70@
M=7-A9V4@9F]R('EO=7(@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VEN9&EC871O<BUM87@M;6%I;&)O>&5S+6QI;6ET+75S86=E7W-E
M;&9?7W-H;W)T+71I=&QE)R`]/B`G36%I;&)O>&5S(&QI;6ET('5S86=E)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+6UA>"UM86EL
M8F]X97,M;&EM:70M=7-A9V5?<V5L9E]?=&ET;&4G(#T^("=-86EL8F]X97,@
M;&EM:70@=7-A9V4@9F]R('EO=7(@9&]M86EN)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO:6YD:6-A=&]R+6UA>"UM86EL8F]X97,M;&EM:70M=7-A
M9V5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=-86EL8F]X97,@;&EM:70@
M=7-A9V4@9F]R(&$@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VEN9&EC871O<BUM87@M;6%I;&)O>&5S+6QI;6ET+75S86=E7W5N:VYO
M=VY?7W-H;W)T+71I=&QE)R`]/B`G36%I;&)O>&5S(&QI;6ET('5S86=E)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+6UA>"UM86EL
M8F]X97,M;&EM:70M=7-A9V5?=6YK;F]W;E]?=&ET;&4G(#T^("=-86EL8F]X
M97,@;&EM:70@=7-A9V4@9F]R(&$@9&]M86EN)RP*"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VEN9&EC871O<BUM87@M<W5B9&]M86EN<RUL:6UI="UU
M<V%G95]?9&5S8W)I<'1I;VXG(#T^("=3=6)D;VUA:6YS(&QI;6ET('5S86=E
M(&9O<B!D;VUA:6X@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:6YD:6-A=&]R+6UA>"US=6)D;VUA:6YS+6QI;6ET+75S86=E7U]S:&]R="UT
M:71L92<@/3X@)U-U8F1O;6%I;G,@;&EM:70@=7-A9V4G+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M;6%X+7-U8F1O;6%I;G,M;&EM
M:70M=7-A9V5?7W1I=&QE)R`]/B`G4W5B9&]M86EN<R!L:6UI="!U<V%G92!F
M;W(@9&]M86EN("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD
M:6-A=&]R+6UA>"US=6)D;VUA:6YS+6QI;6ET+75S86=E7W-E;&9?7V1E<V-R
M:7!T:6]N)R`]/B`G4W5B9&]M86EN<R!L:6UI="!U<V%G92!F;W(@>6]U<B!D
M;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R
M+6UA>"US=6)D;VUA:6YS+6QI;6ET+75S86=E7W-E;&9?7W-H;W)T+71I=&QE
M)R`]/B`G4W5B9&]M86EN<R!L:6UI="!U<V%G92<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VEN9&EC871O<BUM87@M<W5B9&]M86EN<RUL:6UI="UU
M<V%G95]S96QF7U]T:71L92<@/3X@)U-U8F1O;6%I;G,@;&EM:70@=7-A9V4@
M9F]R('EO=7(@9&]M86EN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:6YD:6-A=&]R+6UA>"US=6)D;VUA:6YS+6QI;6ET+75S86=E7W5N:VYO=VY?
M7V1E<V-R:7!T:6]N)R`]/B`G4W5B9&]M86EN<R!L:6UI="!U<V%G92!F;W(@
M82!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A
M=&]R+6UA>"US=6)D;VUA:6YS+6QI;6ET+75S86=E7W5N:VYO=VY?7W-H;W)T
M+71I=&QE)R`]/B`G4W5B9&]M86EN<R!L:6UI="!U<V%G92<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUM87@M<W5B9&]M86EN<RUL
M:6UI="UU<V%G95]U;FMN;W=N7U]T:71L92<@/3X@)U-U8F1O;6%I;G,@;&EM
M:70@=7-A9V4@9F]R(&$@9&]M86EN)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VEN9&EC871O<BUN86UE7U]D97-C<FEP=&EO;B<@/3X@)TYA;64@
M;V8@9&]M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN
M9&EC871O<BUN86UE7U]S:&]R="UT:71L92<@/3X@)T1O;6%I;B!N86UE)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+6YA;65?7W1I
M=&QE)R`]/B`G3F%M92!O9B!D;VUA:6X@)3$G+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]I;F1I8V%T;W(M;F%M95]S96QF7U]D97-C<FEP=&EO;B<@
M/3X@)TYA;64@;V8@>6]U<B!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:6YD:6-A=&]R+6YA;65?<V5L9E]?<VAO<G0M=&ET;&4G(#T^
M("=$;VUA:6X@;F%M92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN
M9&EC871O<BUN86UE7W-E;&9?7W1I=&QE)R`]/B`G3F%M92!O9B!Y;W5R(&1O
M;6%I;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUN
M86UE7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G3F%M92!O9B!A(&1O;6%I
M;BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M;F%M
M95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)T1O;6%I;B!N86UE)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+6YA;65?=6YK;F]W
M;E]?=&ET;&4G(#T^("=.86UE(&]F(&$@9&]M86EN)RP*"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUS=&%T95]?9&5S8W)I<'1I;VXG
M(#T^("=(96%L=&@@<W1A=&4@;V8@9&]M86EN("4Q+B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUS=&%T95]?<VAO<G0M=&ET;&4G
M(#T^("=(96%L=&@@<W1A=&4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]I;F1I8V%T;W(M<W1A=&5?7W1I=&QE)R`]/B`G2&5A;'1H('-T871E(&]F
M(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC
M871O<BUS=&%T95]S96QF7U]D97-C<FEP=&EO;B<@/3X@)TAE86QT:"!S=&%T
M92!O9B!Y;W5R(&1O;6%I;BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]I;F1I8V%T;W(M<W1A=&5?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=(96%L
M=&@@<W1A=&4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T
M;W(M<W1A=&5?<V5L9E]?=&ET;&4G(#T^("=(96%L=&@@<W1A=&4@;V8@>6]U
M<B!D;VUA:6XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T
M;W(M<W1A=&5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=(96%L=&@@<W1A
M=&4@;V8@82!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:6YD:6-A=&]R+7-T871E7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G2&5A
M;'1H('-T871E)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A
M=&]R+7-T871E7W5N:VYO=VY?7W1I=&QE)R`]/B`G2&5A;'1H('-T871E(&]F
M(&$@9&]M86EN)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC
M871O<BUS=&%T=7,M9&5T86EL<U]?9&5S8W)I<'1I;VXG(#T^("=$971A:6QE
M9"!S=&%T=7,@;V8@9&]M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VEN9&EC871O<BUS=&%T=7,M9&5T86EL<U]?<VAO<G0M=&ET;&4G
M(#T^("=$971A:6QE9"!S=&%T=7,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]I;F1I8V%T;W(M<W1A='5S+61E=&%I;'-?7W1I=&QE)R`]/B`G1&5T
M86EL960@<W1A='5S(&]F(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VEN9&EC871O<BUS=&%T=7,M9&5T86EL<U]S96QF7U]D97-C
M<FEP=&EO;B<@/3X@)T1E=&%I;&5D('-T871U<R!O9B!Y;W5R(&1O;6%I;BXG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M<W1A='5S
M+61E=&%I;'-?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=$971A:6QE9"!S=&%T
M=7,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M<W1A
M='5S+61E=&%I;'-?<V5L9E]?=&ET;&4G(#T^("=$971A:6QE9"!S=&%T=7,@
M;V8@>6]U<B!D;VUA:6XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I
M;F1I8V%T;W(M<W1A='5S+61E=&%I;'-?=6YK;F]W;E]?9&5S8W)I<'1I;VXG
M(#T^("=$971A:6QE9"!S=&%T=7,@;V8@82!D;VUA:6XN)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+7-T871U<RUD971A:6QS7W5N
M:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G1&5T86EL960@<W1A='5S)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+7-T871U<RUD971A
M:6QS7W5N:VYO=VY?7W1I=&QE)R`]/B`G1&5T86EL960@<W1A='5S(&]F(&$@
M9&]M86EN)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O
M<BUS=&%T=7-?7V1E<V-R:7!T:6]N)R`]/B`G4W1A='5S(&]F(&1O;6%I;B`E
M,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M<W1A
M='5S7U]S:&]R="UT:71L92<@/3X@)U-T871U<R<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VEN9&EC871O<BUS=&%T=7-?7W1I=&QE)R`]/B`G4W1A
M='5S(&]F(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VEN9&EC871O<BUS=&%T=7-?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=3=&%T
M=7,@;V8@>6]U<B!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO:6YD:6-A=&]R+7-T871U<U]S96QF7U]S:&]R="UT:71L92<@/3X@)U-T
M871U<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUS
M=&%T=7-?<V5L9E]?=&ET;&4G(#T^("=3=&%T=7,@;V8@>6]U<B!D;VUA:6XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M<W1A='5S
M7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G4W1A='5S(&]F(&$@9&]M86EN
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUS=&%T
M=7-?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=3=&%T=7,G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M<W1A='5S7W5N:VYO=VY?
M7W1I=&QE)R`]/B`G4W1A='5S(&]F(&$@9&]M86EN)RP*"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUT<F%F9FEC+6QI;6ET+75S86=E
M7U]D97-C<FEP=&EO;B<@/3X@)U1R869F:6,@;&EM:70@=7-A9V4@9F]R(&1O
M;6%I;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T
M;W(M=')A9F9I8RUL:6UI="UU<V%G95]?<VAO<G0M=&ET;&4G(#T^("=4<F%F
M9FEC(&QI;6ET('5S86=E)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:6YD:6-A=&]R+71R869F:6,M;&EM:70M=7-A9V5?7W1I=&QE)R`]/B`G5')A
M9F9I8R!L:6UI="!U<V%G92!F;W(@9&]M86EN("4Q)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+71R869F:6,M;&EM:70M=7-A9V5?
M<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=4<F%F9FEC(&QI;6ET('5S86=E(&9O
M<B!Y;W5R(&1O;6%I;BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I
M;F1I8V%T;W(M=')A9F9I8RUL:6UI="UU<V%G95]S96QF7U]S:&]R="UT:71L
M92<@/3X@)U1R869F:6,@;&EM:70@=7-A9V4G+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]I;F1I8V%T;W(M=')A9F9I8RUL:6UI="UU<V%G95]S96QF
M7U]T:71L92<@/3X@)U1R869F:6,@;&EM:70@=7-A9V4@9F]R('EO=7(@9&]M
M86EN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+71R
M869F:6,M;&EM:70M=7-A9V5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=4
M<F%F9FEC(&QI;6ET('5S86=E(&9O<B!A(&1O;6%I;BXG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M=')A9F9I8RUL:6UI="UU<V%G
M95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)U1R869F:6,@;&EM:70@=7-A
M9V4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M=')A
M9F9I8RUL:6UI="UU<V%G95]U;FMN;W=N7U]T:71L92<@/3X@)U1R869F:6,@
M;&EM:70@=7-A9V4@9F]R(&$@9&]M86EN)RP*"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VQI;6ET<U]?9&5S8W)I<'1I;VXG(#T^("=6:65W(&]R(&5D
M:70@<F5S;W5R8V4@=7-A9V4@;&EM:71S(&9O<B!D;VUA:6X@)3$N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;&EM:71S7U]D;VYE)R`]/B`G3&EM
M:71S(&]F(&1O;6%I;B`E,2!H879E(&)E96X@=7!D871E9"XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]L:6UI='-?7W-H;W)T+71I=&QE)R`]/B`G
M3&EM:71S)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;&EM:71S7U]T
M:71L92<@/3X@)U9I97<O161I="!D;VUA:6X@)3$@;&EM:71S)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO;&EM:71S7W-E;&9?7V1E<V-R:7!T:6]N
M)R`]/B`G5FEE=R!M>2!L:6UI=',N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;&EM:71S7W-E;&9?7V1O;F4G(#T^("<G+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]L:6UI='-?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=,
M:6UI=',G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]L:6UI='-?<V5L
M9E]?=&ET;&4G(#T^("=6:65W(&UY(&QI;6ET<R<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VQI;6ET<U]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@
M)U9I97<@;W(@961I="!R97-O=7)C92!U<V%G92!L:6UI=',@9F]R(&$@9&]M
M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VQI;6ET<U]U;FMN
M;W=N7U]S:&]R="UT:71L92<@/3X@)TQI;6ET<R<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VQI;6ET<U]U;FMN;W=N7U]T:71L92<@/3X@)U9I97<O
M161I="!D;VUA:6X@;&EM:71S)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO;&EM:71S7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@/3X@)U9I97=I;F<O
M161I=&EN9R!$;VUA:6X@3&EM:71S)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;&EM:71S7W5N:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G
M4V5L96-T(&$@9&]M86EN('=H;W-E(&QI;6ET<R!Y;W4@=V%N="!T;R!V:65W
M(&]R(&5D:70N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;&EM:71S
M7W5N:VYO=VY?7W=I>F%R9%]?,R<@/3X@)U=H96X@9&]N92!W:71H(&5D:71I
M;F<@=&AE(&1O;6%I;B!L:6UI=',L(&-L:6-K($9I;FES:"!T;R!A<'!L>2!C
M:&%N9V5S(&%N9"!E>&ET('1H92!W:7IA<F0N)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO;&EM:71S7W5N:VYO=VY?7W=I>F%R9%]?,U]S96QF)R`]
M/B`G5VAE;B!D;VYE('=I=&@@=FEE=VEN9R!Y;W5R(&QI;6ET<RP@8VQI8VL@
M1FEN:7-H+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL7U]D
M97-C<FEP=&EO;B<@/3X@)TUA;F%G92!M86EL('-Y<W1E;2!O9B!D;VUA:6X@
M)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;%]?9&ES86)L
M960M=V%R;FEN9R<@/3X@)TUA:6P@<V5R=FEC92!O;B!D;VUA:6X@)3$@:7,@
M9&ES86)L960@+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6Q?
M7W-H;W)T+71I=&QE)R`]/B`G36%I;"<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VUA:6Q?7W1I=&QE)R`]/B`G36%N86=E(&UA:6P@;VX@9&]M86EN
M("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;%]S96QF7U]D
M97-C<FEP=&EO;B<@/3X@)T-O;F9I9W5R92!M86EL('-Y<W1E;2!O;B!Y;W5R
M(&1O;6%I;BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL7W-E
M;&9?7V1I<V%B;&5D+7=A<FYI;F<G(#T^("=-86EL('-E<G9I8V4@;VX@>6]U
M<B!D;VUA:6X@:7,@9&ES86)L960N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;6%I;%]S96QF7U]S:&]R="UT:71L92<@/3X@)TUA:6PG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL7W-E;&9?7W1I=&QE)R`]/B`G
M36%N86=E(&UA:6PG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G0V]N9FEG=7)E(&UA:6P@<WES
M=&5M(&]N(&$@9&]M86EN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;%]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)TUA:6PG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL7W5N:VYO=VY?7W1I=&QE)R`]/B`G
M36%N86=E(&UA:6P@;VX@9&]M86EN)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VUA:6PO;6%I;&YA;65?7V1E<V-R:7!T:6]N)R`]/B`G36%N86=E
M(&UA:6P@86-C;W5N="`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]M86EL+VUA:6QN86UE7U]N;VYE+6%V86EL86)L92<@/3X@)UEO=2!D;VY<
M)W0@:&%V92!A;GD@;6%I;&YA;65S+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VUA:6PO;6%I;&YA;65?7VYO;F4M879A:6QA8FQE7U\Q)R`]/B`G
M0VQI96YT("4Q(&1O97-N7"=T(&-H879E(&%N>2!M86EL;F%M97,N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M95]?;F]N92UA
M=F%I;&%B;&5?7S(G(#T^("=4:&5R92!A<F4@;F\@;6%I;&YA;65S(&]N(&1O
M;6%I;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA
M:6QN86UE7U]S:&]R="UT:71L92<@/3X@)R4Q)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO;6%I;"]M86EL;F%M95]?=&ET;&4G(#T^("=-86EL;F%M
M92`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA
M;65?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=-86YA9V4@>6]U<B!M86EL(&%C
M8V]U;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL
M;F%M95]S96QF7U]Q=6EC:RUS96%R8V@G(#T^("=->2!M86EL;F%M97,G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE7W-E;&9?
M7W-H;W)T+71I=&QE)R`]/B`G37D@;6%I;&YA;64G+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE7W-E;&9?7W1I=&QE)R`]/B`G
M37D@;6%I;&YA;64G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE7W5N:VYO=VY?7W%U:6-K+7-E87)C:"<@/3X@)TUA:6QN86UE
M<R<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+V%N=&EV:7)U<R]P<F]P97)T:65S7U]D97-C<FEP=&EO;B<@/3X@)T-O;F9I
M9W5R92!A;G1I=FER=7,@<V5R=FEC92!F;W(@;6%I;"!A8V-O=6YT("4Q+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O86YT
M:79I<G5S+W!R;W!E<G1I97-?7V1O;F4G(#T^("=!;G1I=FER=7,@<V5T=&EN
M9W,@9F]R(&UA:6QN86UE("4Q(&AA=F4@8F5E;B!U<&1A=&5D+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O86YT:79I<G5S
M+W!R;W!E<G1I97-?7W-H;W)T+71I=&QE)R`]/B`G06YT:79I<G5S)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A;G1I=FER
M=7,O<')O<&5R=&EE<U]?=&ET;&4G(#T^("=3970@=7`@86YT:79I<G5S(&9O
M<B!M86EL;F%M92`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA
M:6PO;6%I;&YA;64O86YT:79I<G5S+W!R;W!E<G1I97-?<V5L9E]?9&5S8W)I
M<'1I;VXG(#T^("=#;VYF:6=U<F4@86YT:79I<G5S('-E<G9I8V4@9F]R('EO
M=7(@;6%I;"!A8V-O=6YT+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VUA:6PO;6%I;&YA;64O86YT:79I<G5S+W!R;W!E<G1I97-?<V5L9E]?9&]N
M92<@/3X@)T%N=&EV:7)U<R!S971T:6YG<R!F;W(@>6]U<B!M86EL;F%M92!H
M879E(&)E96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]M86EL+VUA:6QN86UE+V%N=&EV:7)U<R]P<F]P97)T:65S7W-E;&9?7W-H
M;W)T+71I=&QE)R`]/B`G06YT:79I<G5S)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO;6%I;"]M86EL;F%M92]A;G1I=FER=7,O<')O<&5R=&EE<U]S
M96QF7U]T:71L92<@/3X@)U-E="!U<"!A;G1I=FER=7,G+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%N=&EV:7)U<R]P<F]P
M97)T:65S7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G0V]N9FEG=7)E(&%N
M=&EV:7)U<R!S97)V:6-E(&9O<B!A(&UA:6P@86-C;W5N="XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%N=&EV:7)U<R]P
M<F]P97)T:65S7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G06YT:79I<G5S
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A
M;G1I=FER=7,O<')O<&5R=&EE<U]U;FMN;W=N7U]T:71L92<@/3X@)U-E="!U
M<"!A;G1I=FER=7,@9F]R(&UA:6QN86UE)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO;6%I;"]M86EL;F%M92]A;G1I=FER=7,O<')O<&5R=&EE<U]U
M;FMN;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=!;G1I=FER=7,@0V]N9FEG=7)A
M=&EO;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA
M;64O86YT:79I<G5S+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\R7W5N
M:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@;VX@9F]R('=H:6-H(&UA:6P@
M86-C;W5N="!Y;W4@=V%N="!T;R!S970@=7`@86YT:79I<G5S+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O86YT:79I<G5S
M+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\T7W5N:VYO=VXG(#T^("=3
M96QE8W0@82!M86EL;F%M92!F;W(@=VAI8V@@>6]U('=A;G0@=&\@<V5T('5P
M(&%N=&EV:7)U<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+V%N=&EV:7)U<R]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R
M9%]?-B<@/3X@)U-E;&5C="!W:&5T:&5R(&EN8V]M:6YG(&]R(&]U=&-O;6EN
M9R!M86EL+"!O<B!B;W1H('-H;W5L9"!B92!C:&5C:V5D(&9O<B!V:7)U<V5S
M+B!7:&5N(&1O;F4@=VET:"!C;VYF:6=U<FEN9R!A;G1I=FER=7,@9F]R('1H
M92!M86EL;F%M92P@8VQI8VL@1FEN:7-H('1O(&%P<&QY(&-H86YG97,@86YD
M(&5X:70@=&AE('=I>F%R9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]M86EL+VUA:6QN86UE+V%N=&EV:7)U<R]P<F]P97)T:65S7W5N:VYO=VY?
M7W=I>F%R9%]?-E]S96QF)R`]/B`G5VAE;B!D;VYE('=I=&@@8V]N9FEG=7)I
M;F<@86YT:79I<G5S(&9O<B!Y;W5R(&UA:6P@86-C;W5N="P@8VQI8VL@=&\@
M87!P;'D@8VAA;F=E<R!A;F0@97AI="!T:&4@=VEZ87)D+B<L"@H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD
M97)S7U]D97-C<FEP=&EO;B<@/3X@)TQI<W0@;V8@875T;W)E<W!O;F1E<G,@
M;VX@;6%I;&YA;64@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<U]?9&ES86)L960M=V%R;FEN
M9R<@/3X@)U1H92!A=71O<F5S<&]N9&5R<R!S97)V:6-E(&]N(&UA:6QN86UE
M("4Q(&ES(&1I<V%B;&5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G-?7W-H;W)T+71I=&QE)R`]
M/B`G)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN
M86UE+V%U=&]R97-P;VYD97)S7U]T:71L92<@/3X@)T%U=&]R97-P;VYD97)S
M(&]N(&UA:6QN86UE("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<U]S96QF7U]D97-C<FEP=&EO
M;B<@/3X@)TUA;F%G92!Y;W5R(&%U=&]R97-P;VYD97)S+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E
M<G-?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=->2!A=71O<F5S<&]N9&5R<R<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T
M;W)E<W!O;F1E<G-?<V5L9E]?=&ET;&4G(#T^("=->2!A=71O<F5S<&]N9&5R
M<R<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97)?7VYO;F4M879A:6QA8FQE
M)R`]/B`G66]U(&1O;EPG="!H879E(&%N>2!A=71O<F5S<&]N9&5R<RXG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R
M97-P;VYD97)S+V%U=&]R97-P;VYD97)?7VYO;F4M879A:6QA8FQE7U\Q)R`]
M/B`G0VQI96YT("4Q(&1O97-N7"=T(&AA=F4@86YY(&%U=&]R97-P;VYD97)S
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O
M875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<E]?;F]N92UA=F%I;&%B;&5?
M7S(G(#T^("=4:&5R92!A<F4@;F\@875T;W)E<W!O;F1E<G,@;VX@9&]M86EN
M("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA
M;64O875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<E]?;F]N92UA=F%I;&%B
M;&5?7S0G(#T^("=4:&5R92!A<F4@;F\@875T;W)E<W!O;F1E<G,@8V]N9FEG
M=7)E9"!O;B!M86EL;F%M92`E,2XG+`H*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N
M9&5R+V%T=&%C:"UD96QE=&5?7V1E<V-R:7!T:6]N)R`]/B`G4F5M;W9E(&%T
M=&%C:&UE;G1S(&9R;VT@875T;W)E<W!O;F1E<B`E,2XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S
M+V%U=&]R97-P;VYD97(O871T86-H+61E;&5T95]?9&]N92<@/3X@)T%T=&%C
M:&UE;G1S(&AA=F4@8F5E;B!R96UO=F5D(&9R;VT@)3$@875T;W)E<W!O;F1E
M<BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O871T86-H+61E;&5T95]?
M<VAO<G0M=&ET;&4G(#T^("=296UO=F4@871T86-H;65N=',G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD
M97)S+V%U=&]R97-P;VYD97(O871T86-H+61E;&5T95]?=&ET;&4G(#T^("=2
M96UO=F4@871T86-H;65N=',@9G)O;2!A=71O<F5S<&]N9&5R("4Q)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S
M<&]N9&5R<R]A=71O<F5S<&]N9&5R+V%T=&%C:"UD96QE=&5?;F5W7U]D97-C
M<FEP=&EO;B<@/3X@)T-L:6-K('1O(')E;6]V92!A='1A8VAM96YT<R!F<F]M
M(&YE=R!A=71O<F5S<&]N9&5R+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E
M<B]A='1A8V@M9&5L971E7VYE=U]?9&]N92<@/3X@)T%T=&%C:&UE;G1S(&AA
M=F4@8F5E;B!R96UO=F5D(&9R;VT@)3$@875T;W)E<W!O;F1E<BXG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P
M;VYD97)S+V%U=&]R97-P;VYD97(O871T86-H+61E;&5T95]N97=?7W-H;W)T
M+71I=&QE)R`]/B`G4F5M;W9E(&%T=&%C:&UE;G1S)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A
M=71O<F5S<&]N9&5R+V%T=&%C:"UD96QE=&5?;F5W7U]T:71L92<@/3X@)U)E
M;6]V92!A='1A8VAM96YT<R!F<F]M(&$@;F5W(&%U=&]R97-P;VYD97(G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R
M97-P;VYD97)S+V%U=&]R97-P;VYD97(O871T86-H+61E;&5T95]U;FMN;W=N
M7U]D97-C<FEP=&EO;B<@/3X@)T1E;&5T92!A;B!A=71O<F5S<&]N9&5R(&%T
M=&%C:&UE;G1S("XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O871T86-H
M+61E;&5T95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)U)E;6]V92!A='1A
M8VAM96YT<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I
M;&YA;64O875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<B]A='1A8V@M9&5L
M971E7W5N:VYO=VY?7W1I=&QE)R`]/B`G4F5M;W9E(&%N(&%U=&]R97-P;VYD
M97(@871T86-H;65N=',G+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V%T
M=&%C:%]?9&5S8W)I<'1I;VXG(#T^("=!='1A8V@@9FEL97,@=&\@875T;W)E
M<W!O;F1E<B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O871T86-H
M7U]D;VYE)R`]/B`G071T86-H;65N=',@:&%V92!B965N(&%D9&5D('1O(&%U
M=&]R97-P;VYD97(@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V%T
M=&%C:%]?<VAO<G0M=&ET;&4G(#T^("=!='1A8V@@9FEL97,G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD
M97)S+V%U=&]R97-P;VYD97(O871T86-H7U]T:71L92<@/3X@)T%T=&%C:"!F
M:6QE<R!T;R!A=71O<F5S<&]N9&5R("4Q)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S
M<&]N9&5R+V%T=&%C:%]N97=?7V1E<V-R:7!T:6]N)R`]/B`G061D(&%T=&%C
M:&UE;G0@9FEL97,@9F]R(&YE=R!A=71O<F5S<&]N9&5R+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E
M<G,O875T;W)E<W!O;F1E<B]A='1A8VA?;F5W7U]D;VYE)R`]/B`G071T86-H
M;65N=',@:&%V92!B965N(&%D9&5D('1O(&%U=&]R97-P;VYD97(@)3$N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O
M<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V%T=&%C:%]N97=?7W-H;W)T+71I
M=&QE)R`]/B`G071T86-H(&9I;&5S)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N
M9&5R+V%T=&%C:%]N97=?7W1I=&QE)R`]/B`G071T86-H(&9I;&5S('1O(&YE
M=R!A=71O<F5S<&]N9&5R)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V%T
M=&%C:%]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)T%D9"!A='1A8VAM96YT
M(&9I;&5S(&9O<B!A;B!A=71O<F5S<&]N9&5R+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T
M;W)E<W!O;F1E<B]A='1A8VA?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=!
M='1A8V@@9FEL97,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O871T86-H
M7W5N:VYO=VY?7W1I=&QE)R`]/B`G071T86-H(&9I;&5S('1O(&%U=&]R97-P
M;VYD97(G+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL
M;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V1E;&5T95]?9&5S
M8W)I<'1I;VXG(#T^("=296UO=F4@875T;W)E<W!O;F1E<B`E,2XG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P
M;VYD97)S+V%U=&]R97-P;VYD97(O9&5L971E7U]D;VYE)R`]/B`G075T;W)E
M<W!O;F1E<B`E,2!H87,@8F5E;B!R96UO=F5D+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T
M;W)E<W!O;F1E<B]D96QE=&5?7W-H;W)T+71I=&QE)R`]/B`G4F5M;W9E)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O
M<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V1E;&5T95]?=&ET;&4G(#T^("=2
M96UO=F4@875T;W)E<W!O;F1E<B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T;W)E<W!O
M;F1E<B]D96QE=&5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=$96QE=&4@
M875T;W)E<W!O;F1E<B!C;VYF:6=U<F%T:6]N(&9O<B!A(&UA:6P@86-C;W5N
M="XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O9&5L971E7W5N:VYO=VY?
M7W-H;W)T+71I=&QE)R`]/B`G4F5M;W9E)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S
M<&]N9&5R+V1E;&5T95]U;FMN;W=N7U]T:71L92<@/3X@)U)E;6]V92!A=71O
M<F5S<&]N9&5R)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M
M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V1E;&5T95]U
M;FMN;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=!=71O<F5S<&]N9&5R(%)E;6]V
M86PG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O9&5L971E7W5N:VYO=VY?
M7W=I>F%R9%]?,5]U;FMN;W=N)R`]/B`G4V5L96-T(&$@8VQI96YT(&]W;FEN
M9R!T:&4@9&]M86EN(&9R;VT@=VAI8V@@>6]U('=A;G0@=&\@<F5M;W9E(&%U
M=&]R97-P;VYD97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I
M;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V1E;&5T
M95]U;FMN;W=N7U]W:7IA<F1?7S)?=6YK;F]W;B<@/3X@)U-E;&5C="!A(&1O
M;6%I;B!F<F]M('=H:6-H('EO=2!W86YT('1O(')E;6]V92!A=71O<F5S<&]N
M9&5R+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA
M;64O875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<B]D96QE=&5?=6YK;F]W
M;E]?=VEZ87)D7U\T7W5N:VYO=VXG(#T^("=396QE8W0@82!M86EL;F%M92!F
M<F]M('=H:6-H('EO=2!W86YT('1O(')E;6]V92!A=71O<F5S<&]N9&5R+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T
M;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<B]D96QE=&5?=6YK;F]W;E]?=VEZ
M87)D7U\V7W5N:VYO=VXG(#T^("=0;&5A<V4@<V5L96-T('=H:6-H(&%U=&]R
M97-P;VYD97(@>6]U('=A;G0@=&\@<F5M;W9E+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T
M;W)E<W!O;F1E<B]D96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\W)R`]/B`G0V]N
M9FER;2!R96UO=FEN9R!T:&4@875T;W)E<W!O;F1E<B!B>2!S96QE8W1I;F<@
M=&AE(&-H96-K(&)O>"!A;F0@8VQI8VL@9FEN:7-H('1O(&-O;7!L971E;'D@
M<F5M;W9E(&ET(&%N9"!E>&ET('1H92!W:7IA<F0N)RP*"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O
M875T;W)E<W!O;F1E<B]P<F]P97)T:65S7U]D97-C<FEP=&EO;B<@/3X@)T-O
M;F9I9W5R92!A=71O<F5S<&]N9&5R("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T;W)E
M<W!O;F1E<B]P<F]P97)T:65S7U]D;VYE)R`]/B`G075T;W)E<W!O;F1E<B`E
M,2!C;VYF:6=U<F%T:6]N(&AA<R!B965N('5P9&%T960N)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R
M<R]A=71O<F5S<&]N9&5R+W!R;W!E<G1I97-?7W-H;W)T+71I=&QE)R`]/B`G
M4')E9F5R96YC97,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O<')O<&5R
M=&EE<U]?=&ET;&4G(#T^("=!=71O<F5S<&]N9&5R("4Q('!R969E<F5N8V5S
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A
M=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+W!R;W!E<G1I97-?;F5W7U]D
M97-C<FEP=&EO;B<@/3X@)T-R96%T92!N97<@875T;W)E<W!O;F1E<B!F;W(@
M82!M86EL(&%C8V]U;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+W!R
M;W!E<G1I97-?;F5W7U]D;VYE)R`]/B`G075T;W)E<W!O;F1E<B`E,2!H87,@
M8F5E;B!C<F5A=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA
M:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<B]P<F]P
M97)T:65S7VYE=U]?<VAO<G0M=&ET;&4G(#T^("=#<F5A=&4G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD
M97)S+V%U=&]R97-P;VYD97(O<')O<&5R=&EE<U]N97=?7W1I=&QE)R`]/B`G
M0W)E871E(&%U=&]R97-P;VYD97(G+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD
M97(O<')O<&5R=&EE<U]N97=?7W=I>F%R9"UT:71L92<@/3X@)T%U=&]R97-P
M;VYD97(@0W)E871I;VXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M
M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O<')O
M<&5R=&EE<U]N97=?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T(&$@
M9&]M86EN(&9O<B!W:&EC:"!M86EL(&%C8V]U;G0@>6]U('=A;G0@=&\@8W)E
M871E(&%U=&]R97-P;VYD97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R
M+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S1?=6YK;F]W;B<@/3X@)U!L96%S
M92!S96QE8W0@82!M86EL;F%M92!F;W(@=VAI8V@@>6]U('=A;G0@=&\@8W)E
M871E(&%U=&]R97-P;VYD97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R
M+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S8O871T86-H)R`]/B`G4V5L96-T
M(&%T=&%C:&UE;G1S(&%N9"!C;&EC:R!/2R!T;R!R971U<FX@=&\@961I=&EN
M9R!T:&4@875T;W)E<W!O;F1E<B!P<F]P97)T:65S+B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O
M875T;W)E<W!O;F1E<B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\V+V%T=&%C
M:"<@/3X@)U-E;&5C="!A='1A8VAM96YT<R!A;F0@8VQI8VL@3TL@=&\@<F5T
M=7)N('1O(&5D:71I;F<@=&AE(&%U=&]R97-P;VYD97(@<')O<&5R=&EE<RXG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U
M=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O<')O<&5R=&EE<U]N97=?7W=I
M>F%R9%]?-B]A='1A8V@M9&5L971E)R`]/B`G0V]N9FER;2!A='1A8VAM96YT
M(')E;6]V86P@86YD(&-L:6-K($]+('1O(')E='5R;B!T;R!E9&ET:6YG('1H
M92!A=71O<F5S<&]N9&5R('!R;W!E<G1I97,N)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O
M<F5S<&]N9&5R+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S8O9FEL97,O9&5L
M971E)R`]/B`G0V]N9FER;2!F:6QE<R!R96UO=F%L(&%N9"!C;&EC:R!/2R!T
M;R!R971U<FX@=&\@;6%N86=I;F<@=&AE(&%U=&]R97-P;VYD97(@871T86-H
M;65N=',N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL
M;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+W!R;W!E<G1I97-?
M;F5W7U]W:7IA<F1?7S9?;F5W)R`]/B`G0VQI8VL@1FEN:7-H('1O(&-R96%T
M92!T:&4@875T;W)E<W!O;F1E<BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD
M97(O<')O<&5R=&EE<U]N97=?7W=I>F%R9%]?-R<@/3X@)U=H96X@9&]N92!W
M:71H(&-H86YG:6YG('1H92!A=71O<F5S<&]N9&5R('!R;W!E<G1I97,L(&-L
M:6-K($9I;FES:"!T;R!A<'!L>2!C:&%N9V5S(&%N9"!E>&ET('1H92!W:7IA
M<F0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M
M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+W!R;W!E<G1I97-?=6YK
M;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=#:&%N9V4@875T;W)E<W!O;F1E<B!S
M971T:6YG<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA
M:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O<')O<&5R=&EE
M<U]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)U!R;W!E<G1I97,G+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P
M;VYD97)S+V%U=&]R97-P;VYD97(O<')O<&5R=&EE<U]U;FMN;W=N7U]T:71L
M92<@/3X@)U)E8V]N9FEG=7)E(&%U=&]R97-P;VYD97(G+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S
M+V%U=&]R97-P;VYD97(O<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F0M=&ET
M;&4G(#T^("=!=71O<F5S<&]N9&5R(%)E8V]N9FEG=7)I;F<G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD
M97)S+V%U=&]R97-P;VYD97(O<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?
M7S)?=6YK;F]W;B<@/3X@)U-E;&5C="!A(&1O;6%I;B!F;W(@=VAI8V@@;6%I
M;"!A8V-O=6YT('EO=2!W86YT('1O(&-O;F9I9W5R92!A=71O<F5S<&]N9&5R
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O
M875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<B]P<F]P97)T:65S7W5N:VYO
M=VY?7W=I>F%R9%]?-%]U;FMN;W=N)R`]/B`G4V5L96-T(&$@;6%I;&YA;64@
M9F]R('=H:6-H('EO=2!W86YT('1O(&-O;F9I9W5R92!A=71O<F5S<&]N9&5R
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O
M875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<B]P<F]P97)T:65S7W5N:VYO
M=VY?7W=I>F%R9%]?-B]A='1A8V@G(#T^("=396QE8W0@871T86-H;65N=',@
M86YD(&-L:6-K($]+('1O(')E='5R;B!T;R!E9&ET:6YG('1H92!A=71O<F5S
M<&]N9&5R('!R;W!E<G1I97,N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R
M+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\V+V%T=&%C:"UD96QE=&4G
M(#T^("=#;VYF:7)M(&%T=&%C:&UE;G0@<F5M;W9A;"!A;F0@8VQI8VL@3TL@
M=&\@<F5T=7)N('1O(&5D:71I;F<@=&AE(&%U=&]R97-P;VYD97(@<')O<&5R
M=&EE<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN
M86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O<')O<&5R=&EE<U]U
M;FMN;W=N7U]W:7IA<F1?7S8O9FEL97,O9&5L971E)R`]/B`G0V]N9FER;2!F
M:6QE<R!R96UO=F%L(&%N9"!C;&EC:R!/2R!T;R!R971U<FX@=&\@;6%N86=I
M;F<@=&AE(&%U=&]R97-P;VYD97(@871T86-H;65N=',N)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R
M<R]A=71O<F5S<&]N9&5R+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\V
M7W5N:VYO=VXG(#T^("=396QE8W0@=VAI8V@@875T;W)E<W!O;F1E<B!Y;W4@
M=V%N('1O(&UA;F%G92XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M
M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O<')O
M<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S<G(#T^("=7:&5N(&1O;F4@=VET
M:"!C:&%N9VEN9R!T:&4@875T;W)E<W!O;F1E<B!P<F]P97)T:65S+"!C;&EC
M:R!&:6YI<V@@=&\@87!P;'D@8VAA;F=E<R!A;F0@97AI="!T:&4@=VEZ87)D
M+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O=&]G9VQE7V1I<V%B;&5?
M7V1E<V-R:7!T:6]N)R`]/B`G1&ES86)L92!A=71O<F5S<&]N9&5R("4Q+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T
M;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<B]T;V=G;&5?9&ES86)L95]?9&]N
M92<@/3X@)T%U=&]R97-P;VYD97(@)3$@:&%S(&)E96X@9&ES86)L960N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O
M<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+W1O9V=L95]D:7-A8FQE7U]S:&]R
M="UT:71L92<@/3X@)T1I<V%B;&4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD
M97(O=&]G9VQE7V1I<V%B;&5?7W1I=&QE)R`]/B`G1&ES86)L92!A=71O<F5S
M<&]N9&5R("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M
M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+W1O9V=L95]E
M;F%B;&5?7V1E<V-R:7!T:6]N)R`]/B`G16YA8FQE(&%U=&]R97-P;VYD97(@
M)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M
M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+W1O9V=L95]E;F%B;&5?
M7V1O;F4G(#T^("=!=71O<F5S<&]N9&5R("4Q(&AA<R!B965N(&5N86)L960N
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A
M=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+W1O9V=L95]E;F%B;&5?7W-H
M;W)T+71I=&QE)R`]/B`G16YA8FQE)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N
M9&5R+W1O9V=L95]E;F%B;&5?7W1I=&QE)R`]/B`G16YA8FQE(&%U=&]R97-P
M;VYD97(@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA
M:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O=&]G9VQE7W5N
M:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G16YA8FQE(&]R(&1I<V%B;&4@875T
M;W)E<W!O;F1E<B!O;B!A(&UA:6P@86-C;W5N="XG+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U
M=&]R97-P;VYD97(O=&]G9VQE7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G
M16YA8FQE+V1I<V%B;&4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M
M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O=&]G
M9VQE7W5N:VYO=VY?7W1I=&QE)R`]/B`G16YA8FQE+T1I<V%B;&4@875T;W)E
M<W!O;F1E<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I
M;&YA;64O875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<B]T;V=G;&5?=6YK
M;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G16YA8FQI;F<O1&ES86)L:6YG($%U
M=&]R97-P;VYD97(G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O=&]G9VQE
M7W5N:VYO=VY?7W=I>F%R9%]?,5]U;FMN;W=N)R`]/B`G4V5L96-T(&$@8VQI
M96YT(&]W;FEN9R!T:&4@9&]M86EN(&]N('=H:6-H('EO=2!W86YT('1O(&5N
M86)L92!O<B!D:7-A8FQE(&%U=&]R97-P;VYD97(N)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A
M=71O<F5S<&]N9&5R+W1O9V=L95]U;FMN;W=N7U]W:7IA<F1?7S)?=6YK;F]W
M;B<@/3X@)U-E;&5C="!A(&1O;6%I;B!O;B!W:&EC:"!Y;W4@=V%N="!T;R!E
M;F%B;&4@;W(@9&ES86)L92!A=71O<F5S<&]N9&5R+B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O
M875T;W)E<W!O;F1E<B]T;V=G;&5?=6YK;F]W;E]?=VEZ87)D7U\T7W5N:VYO
M=VXG(#T^("=396QE8W0@82!M86EL;F%M92!O;B!W:&EC:"!Y;W4@=V%N="!T
M;R!E;F%B;&4@;W(@9&ES86)L92!A=71O<F5S<&]N9&5R+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E
M<G,O875T;W)E<W!O;F1E<B]T;V=G;&5?=6YK;F]W;E]?=VEZ87)D7U\V7W5N
M:VYO=VXG(#T^("=396QE8W0@=VAI8V@@875T;W)E<W!O;F1E<B!Y;W4@=V%N
M="!T;R!E;F%B;&4@;W(@9&ES86)L92XG+`H*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]T;V=G;&5?
M9&ES86)L95]?9&5S8W)I<'1I;VXG(#T^("=$:7-A8FQE(&%U=&]R97-P;VYD
M:6YG('-E<G9I8V4@;VX@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]T;V=G;&5?9&ES86)L
M95]?9&]N92<@/3X@)T%U=&]R97-P;VYD:6YG('-E<G9I8V4@:&%S(&)E96X@
M9&ES86)L960@;VX@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]T;V=G;&5?9&ES86)L95]?
M<VAO<G0M=&ET;&4G(#T^("=$:7-A8FQE)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]T;V=G;&5?
M9&ES86)L95]?=&ET;&4G(#T^("=$:7-A8FQE(&%U=&]R97-P;VYD:6YG('-E
M<G9I8V4@;VX@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+W1O9V=L95]E;F%B;&5?7V1E<V-R
M:7!T:6]N)R`]/B`G16YA8FQE(&%U=&]R97-P;VYD:6YG('-E<G9I8V4@;VX@
M)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M
M92]A=71O<F5S<&]N9&5R<R]T;V=G;&5?96YA8FQE7U]D;VYE)R`]/B`G075T
M;W)E<W!O;F1I;F<@<V5R=FEC92!H87,@8F5E;B!E;F%B;&5D(&]N("4Q+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T
M;W)E<W!O;F1E<G,O=&]G9VQE7V5N86)L95]?<VAO<G0M=&ET;&4G(#T^("=%
M;F%B;&4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN
M86UE+V%U=&]R97-P;VYD97)S+W1O9V=L95]E;F%B;&5?7W1I=&QE)R`]/B`G
M16YA8FQE(&%U=&]R97-P;VYD97)S('-E<G9I8V4@;VX@)3$G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD
M97)S+W1O9V=L95]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)T5N86)L92!O
M<B!D:7-A8FQE(&%U=&]R97-P;VYD:6YG('-E<G9I8V4@9F]R(&$@;6%I;"!A
M8V-O=6YT+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I
M;&YA;64O875T;W)E<W!O;F1E<G,O=&]G9VQE7W5N:VYO=VY?7W-H;W)T+71I
M=&QE)R`]/B`G16YA8FQE+V1I<V%B;&4G+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+W1O9V=L95]U
M;FMN;W=N7U]T:71L92<@/3X@)T5N86)L92]$:7-A8FQE(&%U=&]R97-P;VYD
M97)S)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M
M92]A=71O<F5S<&]N9&5R<R]T;V=G;&5?=6YK;F]W;E]?=VEZ87)D+71I=&QE
M)R`]/B`G16YA8FQI;F<O1&ES86)L:6YG($%U=&]R97-P;VYD:6YG(%-E<G9I
M8V4@;VX@36%I;&YA;64G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M
M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+W1O9V=L95]U;FMN;W=N7U]W
M:7IA<F1?7S%?=6YK;F]W;B<@/3X@)U-E;&5C="!A(&-L:65N="!O=VYI;F<@
M=&AE(&1O;6%I;B!O;B!W:&EC:"!Y;W4@=V%N="!T;R!E;F%B;&4@;W(@9&ES
M86)L92!A=71O<F5S<&]N9&EN9R!S97)V:6-E(&9O<B!M86EL;F%M92XG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R
M97-P;VYD97)S+W1O9V=L95]U;FMN;W=N7U]W:7IA<F1?7S)?=6YK;F]W;B<@
M/3X@)U-E;&5C="!A(&1O;6%I;B!T:&4@9&]M86EN(&]N('=H:6-H('EO=2!W
M86YT('1O(&5N86)L92!O<B!D:7-A8FQE(&%U=&]R97-P;VYD:6YG('-E<G9I
M8V4@9F]R(&UA:6QN86UE+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O=&]G9VQE7W5N:VYO=VY?
M7W=I>F%R9%]?-%]U;FMN;W=N)R`]/B`G4V5L96-T(&$@;6%I;&YA;64@;VX@
M=VAI8V@@>6]U('=A;G0@=&\@96YA8FQE(&]R(&1I<V%B;&4@875T;W)E<W!O
M;F1I;F<@<V5R=FEC92XG+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]D96QE=&5?7V1E<V-R:7!T:6]N)R`]/B`G4F5M;W9E
M(&UA:6QN86UE("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA
M:6PO;6%I;&YA;64O9&5L971E7U]D;VYE)R`]/B`G36%I;&YA;64@)3$@:&%S
M(&)E96X@<F5M;W9E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M
M86EL+VUA:6QN86UE+V1E;&5T95]?<VAO<G0M=&ET;&4G(#T^("=296UO=F4G
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V1E
M;&5T95]?=&ET;&4G(#T^("=296UO=F4@;6%I;&YA;64@)3$G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V1E;&5T95]U;FMN
M;W=N7U]D97-C<FEP=&EO;B<@/3X@)T1E;&5T92!A(&UA:6P@86-C;W5N="XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V1E
M;&5T95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)U)E;6]V92<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O9&5L971E7W5N
M:VYO=VY?7W1I=&QE)R`]/B`G4F5M;W9E(&UA:6QN86UE)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]D96QE=&5?=6YK;F]W
M;E]?=VEZ87)D+71I=&QE)R`]/B`G36%I;&YA;64@4F5M;W9A;"<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O9&5L971E7W5N
M:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T(&$@9&]M86EN
M('1O(')E;6]V92!A(&UA:6QN86UE(&9R;VTN)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]D96QE=&5?=6YK;F]W;E]?=VEZ
M87)D7U\T7W5N:VYO=VXG(#T^("=396QE8W0@82!M86EL;F%M92!T;R!R96UO
M=F4N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M
M92]D96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\U)R`]/B`G0V]N9FER;2!R96UO
M=FEN9R!T:&4@;6%I;&YA;64@8GD@<V5L96-T:6YG('1H92!C:&5C:R!B;W@@
M86YD(&-L:6-K(&9I;FES:"!T;R!C;VUP;&5T96QY(')E;6]V92!I="!A;F0@
M97AI="!T:&4@=VEZ87)D+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]M86EL+VUA:6QN86UE+V9O<G=A<F1I;F=?7V1E<V-R:7!T:6]N)R`]/B`G
M0V]N9FEG=7)E(&UA:6P@9F]R=V%R9&EN9R!O;B`E,2XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V9O<G=A<F1I;F=?7V1O
M;F4G(#T^("=-86EL(&9O<G=A<F1I;F<@<V5T=&EN9W,@9F]R(&UA:6QN86UE
M("4Q(&AA=F4@8F5E;B!U<&1A=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VUA:6PO;6%I;&YA;64O9F]R=V%R9&EN9U]?<VAO<G0M=&ET;&4G
M(#T^("=&;W)W87)D:6YG)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]F;W)W87)D:6YG7U]T:71L92<@/3X@)U-E="!U<"!F
M;W)W87)D:6YG(&9O<B!M86EL;F%M92`E,2<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O9F]R=V%R9&EN9U]S96QF7U]D97-C
M<FEP=&EO;B<@/3X@)T-O;F9I9W5R92`@;6%I;"!F;W)W87)D:6YG(&9O<B!Y
M;W5R(&UA:6P@86-C;W5N="XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]M86EL+VUA:6QN86UE+V9O<G=A<F1I;F=?<V5L9E]?9&]N92<@/3X@)TUA
M:6P@9F]R=V%R9&EN9R!S971T:6YG<R!F;W(@>6]U<B!M86EL;F%M92!H879E
M(&)E96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M
M86EL+VUA:6QN86UE+V9O<G=A<F1I;F=?<V5L9E]?<VAO<G0M=&ET;&4G(#T^
M("=&;W)W87)D:6YG)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I
M;"]M86EL;F%M92]F;W)W87)D:6YG7W-E;&9?7W1I=&QE)R`]/B`G4V5T('5P
M(&9O<G=A<F1I;F<G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+V9O<G=A<F1I;F=?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^
M("=#;VYF:6=U<F4@9F]R=V%R9&EN9R!S97)V:6-E(&]N(&$@;6%I;"!A8V-O
M=6YT+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA
M;64O9F]R=V%R9&EN9U]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)T9O<G=A
M<F1I;F<G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN
M86UE+V9O<G=A<F1I;F=?=6YK;F]W;E]?=&ET;&4G(#T^("=3970@=7`@;6%I
M;"!F;W)W87)D:6YG)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I
M;"]M86EL;F%M92]F;W)W87)D:6YG7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@
M/3X@)TUA:6P@1F]R=V%R9&EN9R!3971U<"<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O9F]R=V%R9&EN9U]U;FMN;W=N7U]W
M:7IA<F1?7S)?=6YK;F]W;B<@/3X@)U-E;&5C="!A(&1O;6%I;B!F;W(@=VAI
M8V@@;6%I;&YA;64@>6]U('=A;G0@=&\@<V5T('5P(&UA:6P@9F]R=V%R9&EN
M9RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+V9O<G=A<F1I;F=?=6YK;F]W;E]?=VEZ87)D7U\T7W5N:VYO=VXG(#T^("=3
M96QE8W0@82!M86EL;F%M92!F;W(@=VAI8V@@>6]U('=A;G0@=&\@<V5T('5P
M(&UA:6P@9F]R=V%R9&EN9RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]M86EL+VUA:6QN86UE+V9O<G=A<F1I;F=?=6YK;F]W;E]?=VEZ87)D7U\U
M)R`]/B`G5VAE;B!D;VYE('=I=&@@8V]N9FEG=7)I;F<@9F]R=V%R9&EN9R!F
M;W(@=&AE(&UA:6QN86UE+"!C;&EC:R!&:6YI<V@@=&\@87!P;'D@8V]N9FEG
M=7)A=&EO;B!A;F0@97AI="!T:&4@=VEZ87)D+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O9F]R=V%R9&EN9U]U;FMN;W=N
M7U]W:7IA<F1?7S5?<V5L9B<@/3X@)U=H96X@9&]N92!W:71H(&-O;F9I9W5R
M:6YG(&UA:6P@9F]R=V%R9&EN9R!F;W(@>6]U<B!M86EL;F%M92P@8VQI8VL@
M1FEN:7-H('1O(&%P<&QY(&-O;F9I9W5R871I;VX@86YD(&5X:70@=&AE('=I
M>F%R9"XG+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL
M;F%M92]M86EL8F]X+W!R;W!E<G1I97-?7V1E<V-R:7!T:6]N)R`]/B`G0V]N
M9FEG=7)E(&UA:6QB;W@@;VX@;6%I;&YA;64@)3$N)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]M86EL8F]X+W!R;W!E<G1I
M97-?7V1O;F4G(#T^("=-86EL8F]X("4Q(&-O;F9I9W5R871I;VX@:&%S(&)E
M96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+VUA:6QB;W@O<')O<&5R=&EE<U]?<VAO<G0M=&ET;&4G(#T^
M("=#;VYF:6=U<F4@;6%I;&)O>"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VUA:6PO;6%I;&YA;64O;6%I;&)O>"]P<F]P97)T:65S7U]T:71L92<@
M/3X@)TUA:6QB;W@@)3$@<')O<&5R=&EE<R<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O;6%I;&)O>"]P<F]P97)T:65S7W-E
M;&9?7V1E<V-R:7!T:6]N)R`]/B`G0V]N9FEG=7)E('EO=7(@;6%I;&)O>"XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+VUA
M:6QB;W@O<')O<&5R=&EE<U]S96QF7U]D;VYE)R`]/B`G66]U<B!M86EL8F]X
M(&-O;F9I9W5R871I;VX@:&%S(&)E96X@=7!D871E9"XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+VUA:6QB;W@O<')O<&5R
M=&EE<U]S96QF7U]S:&]R="UT:71L92<@/3X@)T-O;F9I9W5R92!M86EL8F]X
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]M
M86EL8F]X+W!R;W!E<G1I97-?<V5L9E]?=&ET;&4G(#T^("=->2!M86EL8F]X
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]M
M86EL8F]X+W!R;W!E<G1I97-?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=#
M;VYF:6=U<F4@;6%I;&)O>"!O;B!A(&UA:6P@86-C;W5N="XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+VUA:6QB;W@O<')O
M<&5R=&EE<U]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)T-O;F9I9W5R92!M
M86EL8F]X)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL
M;F%M92]M86EL8F]X+W!R;W!E<G1I97-?=6YK;F]W;E]?=&ET;&4G(#T^("=#
M;VYF:6=U<F4@;6%I;&)O>"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VUA:6PO;6%I;&YA;64O;6%I;&)O>"]P<F]P97)T:65S7W5N:VYO=VY?7W=I
M>F%R9"UT:71L92<@/3X@)TUA:6QB;W@@0V]N9FEG=7)A=&EO;B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O;6%I;&)O>"]P
M<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L
M96-T(&$@9&]M86EN('1O(&-O;F9I9W5R92!M86EL8F]X(&]N+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O;6%I;&)O>"]P
M<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?-%]U;FMN;W=N)R`]/B`G4V5L
M96-T(&$@;6%I;&YA;64@=&\@8V]N9FEG=7)E(&UA:6QB;W@@;VXN)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]M86EL8F]X
M+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\V)R`]/B`G5VAE;B!D;VYE
M('=I=&@@8V]N9FEG=7)I;F<@;6%I;&)O>"!O;B!T:&4@;6%I;&YA;64L(&-L
M:6-K($9I;FES:"!T;R!A<'!L>2!C:&%N9V5S(&%N9"!E>&ET('1H92!W:7IA
M<F0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M
M92]M86EL8F]X+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\V7W-E;&8G
M(#T^("=7:&5N(&1O;F4@=VET:"!C;VYF:6=U<FEN9R!Y;W5R(&UA:6QB;W@L
M(&-L:6-K($9I;FES:"!T;R!A<'!L>2!C:&%N9V5S(&%N9"!E>&ET('1H92!W
M:7IA<F0N)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I
M;&YA;64O<')O<&5R=&EE<U]?9&5S8W)I<'1I;VXG(#T^("=%9&ET('!R;W!E
M<G1I97,@;V8@;6%I;&YA;64@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P97)T:65S7U]D;VYE)R`]/B`G4')O
M<&5R=&EE<R!O9B!M86EL;F%M92`E,2!H879E(&)E96X@=7!D871E9"XG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W!R;W!E
M<G1I97-?7W-H;W)T+71I=&QE)R`]/B`G36%I;&YA;64@<')O<&5R=&EE<R<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<')O
M<&5R=&EE<U]?=&ET;&4G(#T^("=-86EL;F%M92`E,2!P<F]P97)T:65S)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P
M97)T:65S7VYE=RUA9&AO8U]?=VEZ87)D7U\T7VYE=R<@/3X@)TYN97<@;6%I
M;&YA;64@=VEL;"!B92!C<F5A=&5D(&EM;65D:6%T96QY(&%F=&5R('EO=2!C
M;&EC:R!.97AT(#X^+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA
M:6PO;6%I;&YA;64O<')O<&5R=&EE<U]N97<M8F5F;W)E+6%N=&EV:7)U<U]?
M=VEZ87)D7U\T7VYE=R<@/3X@)T-L:6-K($YE>'0@/CX@=&\@8W)E871E('1H
M92!M86EL;F%M92!A;F0@<')O8V5E9"!T;R!C;VYF:6=U<FEN9R!A;G1I+79I
M<G5S('-E='1I;F=S+B!#;&EC:R!&:6YI<V@@=&\@:G5S="!C<F5A=&4@=&AE
M(&UA:6QN86UE(&%N9"!E>&ET('1H92!W:7IA<F0N)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P97)T:65S7VYE=RUB
M969O<F4M<W!A;2UF:6QT97)?7W=I>F%R9%]?-"]A;G1I=FER=7,O<')O<&5R
M=&EE<R<@/3X@)U-P96-I9GD@<&%R86UE=&5R<R!O9B!$<BY796(@86YT:79I
M<G5S(&-O;F9I9W5R871I;VXN($-L:6-K($YE>'0@/CX@=&\@<')O8V5E9"!T
M;R!A;G1I+7-P86T@9FEL=&5R(&-O;F9I9W5R871I;VXN($-L:6-K($9I;FES
M:"!T;R!S879E($1R+E=E8B!C;VYF:6=U<F%T:6]N(&%N9"!E>&ET('1H92!W
M:7IA<F0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL
M;F%M92]P<F]P97)T:65S7VYE=RUB969O<F4M<W!A;2UF:6QT97)?7W=I>F%R
M9%]?-%]N97<G(#T^("=#;&EC:R!.97AT(#X^('1O(&-R96%T92!T:&4@;6%I
M;&YA;64@86YD('!R;V-E960@=&\@8V]N9FEG=7)I;F<@86YT:2US<&%M(&9I
M;'1E<B!F;W(@=&AE(&UA:6QN86UE+B!#;&EC:R!&:6YI<V@@=&\@:G5S="!C
M<F5A=&4@=&AE(&UA:6QN86UE+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VUA:6PO;6%I;&YA;64O<')O<&5R=&EE<U]N97=?7V1E<V-R:7!T:6]N
M)R`]/B`G0W)E871E(&YE=R!M86EL(&%C8V]U;G0N)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P97)T:65S7VYE=U]?
M9&]N92<@/3X@)TUA:6QN86UE("4Q(&AA<R!B965N(&-R96%T960N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P97)T
M:65S7VYE=U]?<VAO<G0M=&ET;&4G(#T^("=#<F5A=&4@;6%I;&YA;64G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W!R;W!E
M<G1I97-?;F5W7U]T:71L92<@/3X@)T-R96%T92!M86EL;F%M92<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<')O<&5R=&EE
M<U]N97=?7W=I>F%R9"UT:71L92<@/3X@)T-R96%T:6YG($UA:6QN86UE)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P
M97)T:65S7VYE=U]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D
M;VUA:6X@;VX@=VAI8V@@>6]U('=A;G0@=&\@8W)E871E(&UA:6QN86UE+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<')O
M<&5R=&EE<U]N97=?7W=I>F%R9%]?-"]A;G1I=FER=7,O<')O<&5R=&EE<R<@
M/3X@)T-L:6-K($9I;FES:"!T;R!S879E($1R+E=E8B!C;VYF:6=U<F%T:6]N
M(&%N9"!F:6YI<V@@=&AE('=I>F%R9"XG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]M86EL+VUA:6QN86UE+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?
M7S0O<W!A;2UF:6QT97(O<')O<&5R=&EE<R<@/3X@)T-O;F9I9W5R92!T:&4@
M86YT:2US<&%M(&9I;'1E<B!A;F0@8VQI8VL@1FEN:7-H('1O(&%P<&QY(&-H
M86YG97,@86YD(&5X:70@=&AE('=I>F%R9"XG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W!R;W!E<G1I97-?;F5W7U]W:7IA
M<F1?7S1?;F5W)R`]/B`G0VQI8VL@1FEN:7-H('1O(&-R96%T92!T:&4@;6%I
M;&YA;64@86YD(&5X:70@=&AE('=I>F%R9"XG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W!R;W!E<G1I97-?<V5L9E]?9&5S
M8W)I<'1I;VXG(#T^("=%9&ET('!R;W!E<G1I97,@;V8@>6]U<B!M86EL(&%C
M8V]U;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL
M;F%M92]P<F]P97)T:65S7W-E;&9?7V1O;F4G(#T^("=0<F]P97)T:65S(&]F
M('EO=7(@;6%I;&YA;64@:&%V92!B965N('5P9&%T960N)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P97)T:65S7W-E
M;&9?7W-H;W)T+71I=&QE)R`]/B`G36%I;&YA;64@<')O<&5R=&EE<R<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<')O<&5R
M=&EE<U]S96QF7U]T:71L92<@/3X@)T5D:70@;7D@86-C;W5N="<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<')O<&5R=&EE
M<U]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)T-H86YG92!P87-S=V]R9"!A
M;F0@:6YT97)F86-E(&%N9"!S97-S:6]N('!R969E<F5N8V5S(&9O<B!A(&UA
M:6P@86-C;W5N="XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+W!R;W!E<G1I97-?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^
M("=-86EL;F%M92!P<F]P97)T:65S)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P97)T:65S7W5N:VYO=VY?7W1I=&QE
M)R`]/B`G161I="!M86EL;F%M92!P<F]P97)T:65S)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P97)T:65S7W5N:VYO
M=VY?7W=I>F%R9"UT:71L92<@/3X@)T5D:71I;F<@36%I;&YA;64@4')O<&5R
M=&EE<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA
M;64O<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S)?=6YK;F]W;B<@/3X@
M)U-E;&5C="!A(&1O;6%I;B!O;B!W:&EC:"!Y;W4@=V%N="!T;R!C;VYF:6=U
M<F4@;6%I;&YA;64N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I
M;"]M86EL;F%M92]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?-%]U;FMN
M;W=N)R`]/B`G4V5L96-T('=H:6-H(&UA:6QN86UE('EO=2!W86YT('1O(&-O
M;F9I9W5R92XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA
M:6QN86UE+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\U)R`]/B`G5VAE
M;B!D;VYE('=I=&@@8VAA;F=I;F<@;6%I;&YA;64@<')O<&5R=&EE<RP@8VQI
M8VL@1FEN:7-H('1O(&%P<&QY(&-H86YG97,@86YD(&5X:70@=&AE('=I>F%R
M9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\U7W-E;&8G(#T^("=7:&5N
M(&1O;F4@=VET:"!C:&%N9VEN9R!M86EL;F%M92!P<F]P97)T:65S+"!C;&EC
M:R!&:6YI<V@@=&\@87!P;'D@8VAA;F=E<R!A;F0@97AI="!T:&4@=VEZ87)D
M+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+W-P86TM9FEL=&5R+W!R;W!E<G1I97-?7V1E<V-R:7!T:6]N)R`]/B`G0V]N
M9FEG=7)E('-P86T@9FEL=&5R(&9O<B!M86EL;F%M92`E,2XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W-P86TM9FEL=&5R
M+W!R;W!E<G1I97-?7V1O;F4G(#T^("=3<&%M(&9I;'1E<B!S971T:6YG<R!F
M;W(@;6%I;&YA;64@)3$@:&%V92!B965N('5P9&%T960N)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]S<&%M+69I;'1E<B]P
M<F]P97)T:65S7U]S:&]R="UT:71L92<@/3X@)U-P86T@9FEL=&5R)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]S<&%M+69I
M;'1E<B]P<F]P97)T:65S7U]T:71L92<@/3X@)T-O;F9I9W5R92!S<&%M(&9I
M;'1E<B!F;W(@;6%I;&YA;64@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]M86EL+VUA:6QN86UE+W-P86TM9FEL=&5R+W!R;W!E<G1I97-?96YA
M8FQE7U]D97-C<FEP=&EO;B<@/3X@)T5N86)L92!A;F0@8V]N9FEG=7)E('-P
M86T@9FEL=&5R(&9O<B!M86EL;F%M92`E,2XG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W-P86TM9FEL=&5R+W!R;W!E<G1I
M97-?96YA8FQE7U]D;VYE)R`]/B`G4W!A;2!F:6QT97(@9F]R(&UA:6QN86UE
M("4Q(&AA<R!B965N(&5N86)L960N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;6%I;"]M86EL;F%M92]S<&%M+69I;'1E<B]P<F]P97)T:65S7V5N
M86)L95]?<VAO<G0M=&ET;&4G(#T^("=3<&%M(&9I;'1E<B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<W!A;2UF:6QT97(O
M<')O<&5R=&EE<U]E;F%B;&5?7W1I=&QE)R`]/B`G16YA8FQE+T-O;F9I9W5R
M92!S<&%M(&9I;'1E<B!F;W(@;6%I;&YA;64@)3$G+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W-P86TM9FEL=&5R+W!R;W!E
M<G1I97-?<V5L9BUE;F%B;&5?7V1E<V-R:7!T:6]N)R`]/B`G16YA8FQE(&%N
M9"!C;VYF:6=U<F4@9FEL=&5R(&9O<B!Y;W5R(&UA:6P@86-C;W5N="XG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W-P86TM
M9FEL=&5R+W!R;W!E<G1I97-?<V5L9BUE;F%B;&5?7V1O;F4G(#T^("=3<&%M
M(&9I;'1E<B!F;W(@>6]U<B!M86EL;F%M92!H87,@8F5E;B!E;F%B;&5D+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<W!A
M;2UF:6QT97(O<')O<&5R=&EE<U]S96QF+65N86)L95]?<VAO<G0M=&ET;&4G
M(#T^("=3<&%M(&9I;'1E<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VUA:6PO;6%I;&YA;64O<W!A;2UF:6QT97(O<')O<&5R=&EE<U]S96QF+65N
M86)L95]?=&ET;&4G(#T^("=%;F%B;&4@86YD(&-O;F9I9W5R92!S<&%M(&9I
M;'1E<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA
M;64O<W!A;2UF:6QT97(O<')O<&5R=&EE<U]S96QF7U]D97-C<FEP=&EO;B<@
M/3X@)T-O;F9I9W5R92!S<&%M(&9I;'1E<B!F;W(@>6]U<B!M86EL(&%C8V]U
M;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M
M92]S<&%M+69I;'1E<B]P<F]P97)T:65S7W-E;&9?7V1O;F4G(#T^("=3<&%M
M(&9I;'1E<B!S971T:6YG<R!H879E(&)E96X@=7!D871E9"XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W-P86TM9FEL=&5R
M+W!R;W!E<G1I97-?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=3<&%M(&9I;'1E
M<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O
M<W!A;2UF:6QT97(O<')O<&5R=&EE<U]S96QF7U]T:71L92<@/3X@)T-O;F9I
M9W5R92!S<&%M(&9I;'1E<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VUA:6PO;6%I;&YA;64O<W!A;2UF:6QT97(O<')O<&5R=&EE<U]U;FMN;W=N
M7U]D97-C<FEP=&EO;B<@/3X@)T-O;F9I9W5R92!S<&%M(&9I;'1E<FEN9R!S
M971T:6YG<R!F;W(@82!M86EL(&%C8V]U;G0N)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]S<&%M+69I;'1E<B]P<F]P97)T
M:65S7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G4W!A;2!F:6QT97(G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W-P86TM
M9FEL=&5R+W!R;W!E<G1I97-?=6YK;F]W;E]?=&ET;&4G(#T^("=#;VYF:6=U
M<F4@<W!A;2!F:6QT97(@9F]R(&UA:6QN86UE)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]S<&%M+69I;'1E<B]P<F]P97)T
M:65S7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@/3X@)U-P86T@9FEL=&5R(&-O
M;F9I9W5R871I;VXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+W-P86TM9FEL=&5R+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ
M87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@;VX@=VAI8V@@
M;6%I;&YA;64@>6]U('=A;G0@=&\@8V]N9FEG=7)E('-P86T@9FEL=&5R:6YG
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O
M<W!A;2UF:6QT97(O<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S1?=6YK
M;F]W;B<@/3X@)U-E;&5C="!O;B!W:&EC:"!M86EL;F%M92!Y;W4@=V%N="!T
M;R!C;VYF:6=U<F4@<W!A;2!F:6QT97)I;F<N)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]S<&%M+69I;'1E<B]P<F]P97)T
M:65S7W5N:VYO=VY?7W=I>F%R9%]?-B<@/3X@)U=H96X@9&]N92!W:71H(&-O
M;F9I9W5R:6YG('-P86T@9FEL=&5R(&9O<B!T:&4@;6%I;&YA;64L(&-L:6-K
M($9I;FES:"!T;R!A<'!L>2!C:&%N9V5S(&%N9"!E>&ET('1H92!W:7IA<F0N
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]S
M<&%M+69I;'1E<B]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?-E]E;F%B
M;&4G(#T^("=7:&5N('EO=2!C;&EC:R!&:6YI<V@L('-P86T@9FEL=&5R(&9O
M<B!T:&4@;6%I;&YA;64@=VEL;"!B92!E;F%B;&5D+B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<W!A;2UF:6QT97(O<')O
M<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S9?<V5L9B<@/3X@)U=H96X@9&]N
M92!W:71H(&-O;F9I9W5R:6YG('-P86T@9FEL=&5R(&9O<B!Y;W5R(&UA:6QN
M86UE+"!C;&EC:R!&:6YI<V@N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO;6%I;"]M86EL;F%M92]S<&%M+69I;'1E<B]P<F]P97)T:65S7W5N:VYO
M=VY?7W=I>F%R9%]?-E]S96QF+65N86)L92<@/3X@)U=H96X@>6]U(&-L:6-K
M($9I;FES:"P@<W!A;2!F:6QT97(@9F]R('EO=7(@;6%I;&YA;64@=VEL;"!B
M92!E;F%B;&5D+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+W!R;W!E<G1I97-?7V1E<V-R:7!T:6]N)R`]/B`G0V]N9FEG=7)E(&UA:6P@
M<WES=&5M(&]N(&1O;6%I;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]M86EL+W!R;W!E<G1I97-?7V1O;F4G(#T^("=-86EL('-Y<W1E;2!O
M;B!D;VUA:6X@)3$@:&%S(&)E96X@8V]N9FEG=7)E9"XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]M86EL+W!R;W!E<G1I97-?7W-H;W)T+71I=&QE
M)R`]/B`G0V]N9FEG=7)E(&UA:6P@<WES=&5M)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO;6%I;"]P<F]P97)T:65S7U]T:71L92<@/3X@)TUA;F%G
M92!M86EL(&]N(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VUA:6PO<')O<&5R=&EE<U]S96QF7U]D97-C<FEP=&EO;B<@/3X@)T-O
M;F9I9W5R92!M86EL('-Y<W1E;2!O;B!Y;W5R(&1O;6%I;BXG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+W!R;W!E<G1I97-?<V5L9E]?9&]N
M92<@/3X@)TUA:6P@<WES=&5M(&]N('EO=7(@9&]M86EN(&AA<R!B965N(&-O
M;F9I9W5R960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]P
M<F]P97)T:65S7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G0V]N9FEG=7)E(&UA
M:6P@<WES=&5M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]P
M<F]P97)T:65S7W-E;&9?7W1I=&QE)R`]/B`G36%N86=E(&UA:6PG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+W!R;W!E<G1I97-?=6YK;F]W
M;E]?9&5S8W)I<'1I;VXG(#T^("=#;VYF:6=U<F4@;6%I;"!S>7-T96T@;VX@
M82!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]P
M<F]P97)T:65S7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G0V]N9FEG=7)E
M(&UA:6P@<WES=&5M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I
M;"]P<F]P97)T:65S7W5N:VYO=VY?7W1I=&QE)R`]/B`G36%N86=E(&UA:6P@
M;VX@9&]M86EN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]P
M<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@/3X@)TUA:6P@<WES
M=&5M(&-O;F9I9W5R871I;VXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]M86EL+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\R7W5N:VYO=VXG
M(#T^("=396QE8W0@82!D;VUA:6X@;VX@=VAI8V@@>6]U('=A;G0@=&\@8V]N
M9FEG=7)E(&UA:6P@<WES=&5M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VUA:6PO<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S0G(#T^("=7
M:&5N(&1O;F4@=VET:"!C;VYF:6=U<FEN9R!T:&4@;6%I;"!S>7-T96TL(&-L
M:6-K($9I;FES:"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\T7W-E;&8G(#T^("=7:&5N
M(&1O;F4@=VET:"!C;VYF:6=U<FEN9R!T:&4@;6%I;"!S>7-T96TL(&-L:6-K
M($9I;FES:"XG+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]T
M;V=G;&5?9&ES86)L95]?9&5S8W)I<'1I;VXG(#T^("=$:7-A8FQE(&UA:6P@
M<V5R=FEC97,@;VX@9&]M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VUA:6PO=&]G9VQE7V1I<V%B;&5?7V1O;F4G(#T^("=-86EL('-E
M<G9I8V5S(&]N(&1O;6%I;B`E,2!H879E(&)E96X@9&ES86)L960N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]T;V=G;&5?9&ES86)L95]?
M<VAO<G0M=&ET;&4G(#T^("=$:7-A8FQE)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO;6%I;"]T;V=G;&5?9&ES86)L95]?=&ET;&4G(#T^("=$:7-A
M8FQE(&UA:6P@;VX@9&]M86EN("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;6%I;"]T;V=G;&5?96YA8FQE7U]D97-C<FEP=&EO;B<@/3X@)T5N
M86)L92!M86EL('-E<G9I8V5S(&9O<B!D;VUA:6X@)3$N)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO;6%I;"]T;V=G;&5?96YA8FQE7U]D;VYE)R`]
M/B`G36%I;"!S97)V:6-E<R!O;B!D;VUA:6X@)3$@:&%V92!B965N(&5N86)L
M960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]T;V=G;&5?
M96YA8FQE7U]S:&]R="UT:71L92<@/3X@)T5N86)L92<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VUA:6PO=&]G9VQE7V5N86)L95]?=&ET;&4G(#T^
M("=%;F%B;&4@;6%I;"!O;B!D;VUA:6X@)3$G+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]M86EL+W1O9V=L95]S96QF+61I<V%B;&5?7V1E<V-R:7!T
M:6]N)R`]/B`G0VQI8VL@=&\@9&ES86)L92!M86EL('-E<G9I8V5S(&]N('EO
M=7(@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO
M=&]G9VQE7W-E;&8M9&ES86)L95]?9&]N92<@/3X@)TUA:6P@<V5R=FEC97,@
M;VX@>6]U<B!D;VUA:6X@:&%V92!B965N(&1I<V%B;&5D+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO=&]G9VQE7W-E;&8M9&ES86)L95]?
M<VAO<G0M=&ET;&4G(#T^("=$:7-A8FQE)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO;6%I;"]T;V=G;&5?<V5L9BUD:7-A8FQE7U]T:71L92<@/3X@
M)T1I<V%B;&4@;6%I;"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA
M:6PO=&]G9VQE7W-E;&8M96YA8FQE7U]D97-C<FEP=&EO;B<@/3X@)T-L:6-K
M('1O(&5N86)L92!M86EL('-E<G9I8V5S(&]N('EO=7(@9&]M86EN+B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO=&]G9VQE7W-E;&8M96YA
M8FQE7U]D;VYE)R`]/B`G36%I;"!S97)V:6-E<R!O;B!Y;W5R(&1O;6%I;B!H
M879E(&)E96X@96YA8FQE9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]M86EL+W1O9V=L95]S96QF+65N86)L95]?<VAO<G0M=&ET;&4G(#T^("=%
M;F%B;&4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+W1O9V=L
M95]S96QF+65N86)L95]?=&ET;&4G(#T^("=%;F%B;&4@;6%I;"<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO=&]G9VQE7W-E;&9?7V1E<V-R
M:7!T:6]N)R`]/B`G0VQI8VL@=&\@96YA8FQE(&]R(&1I<V%B;&4@;6%I;"!S
M97)V:6-E<R!O;B!Y;W5R(&1O;6%I;BXG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]M86EL+W1O9V=L95]S96QF7U]S:&]R="UT:71L92<@/3X@)T5N
M86)L92]D:7-A8FQE)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I
M;"]T;V=G;&5?<V5L9E]?=&ET;&4G(#T^("=%;F%B;&4O1&ES86)L92!M86EL
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]T;V=G;&5?=6YK
M;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=%;F%B;&4@;W(@9&ES86)L92!M86EL
M('-E<G9I8V5S(&]N(&$@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VUA:6PO=&]G9VQE7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G
M16YA8FQE+V1I<V%B;&4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M
M86EL+W1O9V=L95]U;FMN;W=N7U]T:71L92<@/3X@)T5N86)L92]$:7-A8FQE
M(&UA:6P@;VX@9&]M86EN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]T;V=G;&5?=6YK;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G16YA8FQI
M;F<O1&ES86)L:6YG($UA:6P@4V5R=FEC97,@;VX@1&]M86EN)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]T;V=G;&5?=6YK;F]W;E]?=VEZ
M87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@;VX@=VAI8V@@9&]M86EN('EO
M=2!W86YT('1O(&5N86)L92!O<B!D:7-A8FQE(&UA:6P@<V5R=FEC97,N)RP*
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+W!R;W!E<G1I97-?7V1E<V-R
M:7!T:6]N)R`]/B`G4V5T('5P(&1O;6%I;B!A9&UI;FES=')A=&]R(&%C8V]U
M;G0@9F]R(&1O;6%I;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]P<F]P97)T:65S7U]D;VYE)R`]/B`G1&]M86EN(&%D;6EN(&%C8V]U;G0@
M)3$@:&%S(&)E96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]P<F]P97)T:65S7U]S:&]R="UT:71L92<@/3X@)T1O;6%I;B!P<F]P
M97)T:65S)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO<')O<&5R=&EE
M<U]?=&ET;&4G(#T^("=3970@=7`@9&]M86EN(&%D;6EN(&9O<B!D;VUA:6X@
M)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S7VYE
M=RUA9&AO8U]?=VEZ87)D7U\R7VYE=R<@/3X@)TYE=R!D;VUA:6X@=VEL;"!B
M92!C<F5A=&5D(&EM;65D:6%T96QY(&%F=&5R('EO=2!C;&EC:R!.97AT(#X^
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+W!R;W!E<G1I97-?;F5W
M7U]D97-C<FEP=&EO;B<@/3X@)T-R96%T92!A;F0@8V]N9FEG=7)E(&YE=R!D
M;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO<')O<&5R=&EE
M<U]N97=?7V1O;F4G(#T^("=$;VUA:6X@)3$@:&%S(&)E96X@8W)E871E9"XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S7VYE=U]?
M<VAO<G0M=&ET;&4G(#T^("=#<F5A=&4@9&]M86EN)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO<')O<&5R=&EE<U]N97=?7W1I=&QE)R`]/B`G0W)E
M871E(&1O;6%I;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+W!R;W!E
M<G1I97-?;F5W7U]W:7IA<F0M=&ET;&4G(#T^("=$;VUA:6X@0W)E871I;VXG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S7VYE=U]?
M=VEZ87)D7U\Q7W5N:VYO=VXG(#T^("=396QE8W0@82!C;&EE;G0@9F]R('=H
M;VT@>6]U('=A;G0@=&\@8W)E871E(&$@9&]M86EN+B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S(O:&]S
M=&EN9R]P<F]P97)T:65S)R`]/B`G4V5L96-T('1H92!D97-I<F5D(&AO<W1I
M;F<@='EP92!F;W(@=&AE(&1O;6%I;B!A;F0@8VQI8VL@3F5X="`^/BXG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S7VYE=U]?=VEZ
M87)D7U\R+VAO<W1I;F<O<')O<&5R=&EE<U]F;W)W87)D:6YG)R`]/B`G5VAE
M;B!D;VYE('=I=&@@8V]N9FEG=7)I;F<@9F]R=V%R9&EN9R!O;B!T:&4@9&]M
M86EN+"!C;&EC:R!&:6YI<V@@=&\@87!P;'D@=&AE(&-O;F9I9W5R871I;VX@
M86YD(&5X:70@=&AE('=I>F%R9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\R+VAO<W1I;F<O<')O<&5R
M=&EE<U]P:&]S=&EN9R<@/3X@)U=H96X@9&]N92!W:71H(&-O;F9I9W5R:6YG
M('!H>7-I8V%L(&AO<W1I;F<@;VX@=&AE(&1O;6%I;BP@8VQI8VL@1FEN:7-H
M('1O(&%P<&QY(&%L;"!C:&%N9V5S(&%N9"!E>&ET('1H92!W:7IA<F0N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO<')O<&5R=&EE<U]N97=?7W=I
M>F%R9%]?,B]L:6UI=',G(#T^("=#;&EC:R!.97AT(#X^('1O('!R;V-E960@
M=&\@8V]N9FEG=7)I;F<@:&]S=&EN9R!F;W(@=&AE(&1O;6%I;BX@0VQI8VL@
M1FEN:7-H('1O(&%P<&QY(&1O;6%I;B!L:6UI=',@86YD(&5X:70@=&AE('=I
M>F%R9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S
M7VYE=U]?=VEZ87)D7U\R7VYE=R<@/3X@)T-L:6-K($YE>'0@/CX@=&\@8W)E
M871E('1H92!D;VUA:6X@86YD('!R;V-E960@=&\@8V]N9FEG=7)I;F<@9&]M
M86EN(&QI;6ET<RX@0VQI8VL@1FEN:7-H('1O(&-R96%T92!T:&4@9&]M86EN
M('=I=&AO=70@:71S(&9U<G1H97(@8V]N9FEG=7)I;F<@86YD(&5X:70@=&AE
M('=I>F%R9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T
M:65S7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G0VAA;F=E('EO=7(@<&%S<W=O
M<F0@86YD('!E<G-O;F%L(&EN9F\L('-E="!U<"!#4"!A<'!E87)A;F-E(&%N
M9"!V:65W('EO=7(@<&5R;6ES<VEO;G,N)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO<')O<&5R=&EE<U]S96QF7U]D;VYE)R`]/B`G4')O<&5R=&EE
M<R!O9B!Y;W5R(&1O;6%I;B!H879E(&)E96X@=7!D871E9"XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S7W-E;&9?7W-H;W)T+71I
M=&QE)R`]/B`G1&]M86EN('!R;W!E<G1I97,G+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]P<F]P97)T:65S7W-E;&9?7W1I=&QE)R`]/B`G161I="!M
M>2!A8V-O=6YT)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO<')O<&5R
M=&EE<U]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)U-E="!U<"!D;VUA:6X@
M861M:6YI<W1R871O<B!A8V-O=6YT(&9O<B!A(&1O;6%I;BXG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S7W5N:VYO=VY?7W-H;W)T
M+71I=&QE)R`]/B`G1&]M86EN('!R;W!E<G1I97,G+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]P<F]P97)T:65S7W5N:VYO=VY?7W1I=&QE)R`]/B`G
M4V5T('5P(&1O;6%I;B!A9&UI;B!F;W(@9&]M86EN)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F0M=&ET
M;&4G(#T^("=3971T:6YG(%5P($1O;6%I;B!!9&UI;FES=')A=&]R($%C8V]U
M;G0G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S7W5N
M:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T(&$@9&]M86EN
M(&9O<B!W:&EC:"!Y;W4@=V%N="!T;R!S970@=7`@9&]M86EN(&%D;6EN:7-T
M<F%T;W(@86-C;W5N="XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]P
M<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?,R<@/3X@)U=H96X@9&]N92!W
M:71H('-P96-I9GEI;F<@<')O<&5R=&EE<R!O9B!D;VUA:6X@861M:6YI<W1R
M871O<B!A8V-O=6YT+"!C;&EC:R!&:6YI<V@@=&\@87!P;'D@8VAA;F=E<R!A
M;F0@97AI="!T:&4@=VEZ87)D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\S7W-E;&8G(#T^("=7
M:&5N(&1O;F4@=VET:"!S<&5C:69Y:6YG('!R;W!E<G1I97,@;V8@9&]M86EN
M(&%D;6EN:7-T<F%T;W(@86-C;W5N="P@8VQI8VL@1FEN:7-H('1O(&%P<&QY
M(&-H86YG97,@86YD(&5X:70@=&AE('=I>F%R9"XG+`H*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO=&]G9VQE7V1I<V%B;&5?7V1E<V-R:7!T:6]N)R`]
M/B`G1&ES86)L92!D;VUA:6X@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO=&]G9VQE7V1I<V%B;&5?7V1O;F4G(#T^("=$;VUA:6X@)3$@:&%S
M(&)E96X@9&ES86)L960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M=&]G9VQE7V1I<V%B;&5?7W-H;W)T+71I=&QE)R`]/B`G1&ES86)L92<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+W1O9V=L95]D:7-A8FQE7U]T:71L
M92<@/3X@)T1I<V%B;&4@9&]M86EN("4Q)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO=&]G9VQE7V5N86)L95]?9&5S8W)I<'1I;VXG(#T^("=%;F%B
M;&4@9&]M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+W1O
M9V=L95]E;F%B;&5?7V1O;F4G(#T^("=$;VUA:6X@)3$@:&%S(&)E96X@96YA
M8FQE9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]T;V=G;&5?96YA
M8FQE7U]S:&]R="UT:71L92<@/3X@)T5N86)L92<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+W1O9V=L95]E;F%B;&5?7W1I=&QE)R`]/B`G16YA8FQE
M(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+W1O9V=L
M95]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)T5N86)L92!O<B!D:7-A8FQE
M(&$@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+W1O9V=L
M95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)T5N86)L92]D:7-A8FQE)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO=&]G9VQE7W5N:VYO=VY?7W1I
M=&QE)R`]/B`G16YA8FQE+T1I<V%B;&4@9&]M86EN)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO=&]G9VQE7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@
M/3X@)T5N86)L:6YG+T1I<V%B;&EN9R!$;VUA:6XG+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]T;V=G;&5?=6YK;F]W;E]?=VEZ87)D7U\R7W5N:VYO
M=VXG(#T^("=396QE8W0@=VAI8V@@9&]M86EN('EO=2!W86YT('1O(&5N86)L
M92!O<B!D:7-A8FQE+B<L"@H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O
M<BUC;VUP86YY+6YA;65?7V1E<V-R:7!T:6]N)R`]/B`G0V]M<&%N>2!N86UE
M(&]F(&-L:65N="`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O
M<BUC;VUP86YY+6YA;65?7W-H;W)T+71I=&QE)R`]/B`G0V]M<&%N>2!N86UE
M)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M8V]M<&%N>2UN86UE
M7U]T:71L92<@/3X@)T-O;7!A;GD@;F%M92!O9B!C;&EE;G0@)3$G+`H@("`@
M("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUC;VUP86YY+6YA;65?<V5L9E]?
M9&5S8W)I<'1I;VXG(#T^("=9;W5R(&-O;7!A;GD@;F%M92<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O:6YD:6-A=&]R+6-O;7!A;GDM;F%M95]S96QF7U]S:&]R
M="UT:71L92<@/3X@)T-O;7!A;GD@;F%M92<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O:6YD:6-A=&]R+6-O;7!A;GDM;F%M95]S96QF7U]T:71L92<@/3X@)UEO
M=7(@8V]M<&%N>2!N86UE)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T
M;W(M8V]M<&%N>2UN86UE7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G0V]M
M<&%N>2!N86UE(&]F(&$@8VQI96YT+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M:6YD:6-A=&]R+6-O;7!A;GDM;F%M95]U;FMN;W=N7U]S:&]R="UT:71L92<@
M/3X@)T-O;7!A;GD@;F%M92<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A
M=&]R+6-O;7!A;GDM;F%M95]U;FMN;W=N7U]T:71L92<@/3X@)T-O;7!A;GD@
M;F%M92!O9B!A(&-L:65N="<L"@H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC
M871O<BUC;VYT86-T+6YA;65?7V1E<V-R:7!T:6]N)R`]/B`G0V]N=&%C="!N
M86UE(&]F(&-L:65N="`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC
M871O<BUC;VYT86-T+6YA;65?7W-H;W)T+71I=&QE)R`]/B`G0V]N=&%C="!N
M86UE)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M8V]N=&%C="UN
M86UE7U]T:71L92<@/3X@)T-O;G1A8W0@;F%M92!O9B!C;&EE;G0@)3$G+`H@
M("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUC;VYT86-T+6YA;65?<V5L
M9E]?9&5S8W)I<'1I;VXG(#T^("=9;W5R(&-O;G1A8W0@;F%M92<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+6-O;G1A8W0M;F%M95]S96QF7U]S
M:&]R="UT:71L92<@/3X@)T-O;G1A8W0@;F%M92<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O:6YD:6-A=&]R+6-O;G1A8W0M;F%M95]S96QF7U]T:71L92<@/3X@
M)UEO=7(@8V]N=&%C="!N86UE)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I
M8V%T;W(M8V]N=&%C="UN86UE7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G
M0V]N=&%C="!N86UE(&]F(&$@8VQI96YT+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O:6YD:6-A=&]R+6-O;G1A8W0M;F%M95]U;FMN;W=N7U]S:&]R="UT:71L
M92<@/3X@)T-O;G1A8W0@;F%M92<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD
M:6-A=&]R+6-O;G1A8W0M;F%M95]U;FMN;W=N7U]T:71L92<@/3X@)T-O;G1A
M8W0@;F%M92!O9B!A(&-L:65N="<L"@H@("`@("`@("=U:5]?8VQI96YT+VEN
M9&EC871O<BUD:7-K+7-P86-E+6QI;6ET+75S86=E7U]D97-C<FEP=&EO;B<@
M/3X@)T1I<VL@<W!A8V4@;&EM:70@=7-A9V4@9F]R(&-L:65N="`E,2XG+`H@
M("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUD:7-K+7-P86-E+6QI;6ET
M+75S86=E7U]S:&]R="UT:71L92<@/3X@)T1I<VL@<W!A8V4@;&EM:70@=7-A
M9V4G+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUD:7-K+7-P86-E
M+6QI;6ET+75S86=E7U]T:71L92<@/3X@)T1I<VL@<W!A8V4@;&EM:70@=7-A
M9V4@9F]R(&-L:65N="`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A
M=&]R+61I<VLM<W!A8V4M;&EM:70M=7-A9V5?<V5L9E]?9&5S8W)I<'1I;VXG
M(#T^("=9;W5R(&1I<VL@<W!A8V4@;&EM:70@=7-A9V4G+`H@("`@("`@("=U
M:5]?8VQI96YT+VEN9&EC871O<BUD:7-K+7-P86-E+6QI;6ET+75S86=E7W-E
M;&9?7W-H;W)T+71I=&QE)R`]/B`G1&ES:R!S<&%C92!L:6UI="!U<V%G92<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+61I<VLM<W!A8V4M;&EM
M:70M=7-A9V5?<V5L9E]?=&ET;&4G(#T^("=9;W5R(&1I<VL@<W!A8V4@;&EM
M:70@=7-A9V4G+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUD:7-K
M+7-P86-E+6QI;6ET+75S86=E7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G
M1&ES:R!S<&%C92!L:6UI="!U<V%G92!F;W(@82!C;&EE;G0N)RP*("`@("`@
M("`G=6E?7V-L:65N="]I;F1I8V%T;W(M9&ES:RUS<&%C92UL:6UI="UU<V%G
M95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)T1I<VL@<W!A8V4@;&EM:70@
M=7-A9V4G+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUD:7-K+7-P
M86-E+6QI;6ET+75S86=E7W5N:VYO=VY?7W1I=&QE)R`]/B`G1&ES:R!S<&%C
M92!L:6UI="!U<V%G92!F;W(@82!C;&EE;G0G+`H*("`@("`@("`G=6E?7V-L
M:65N="]I;F1I8V%T;W(M96UA:6Q?7V1E<V-R:7!T:6]N)R`]/B`G16UA:6P@
M861D<F5S<R!O9B!C;&EE;G0@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]I
M;F1I8V%T;W(M96UA:6Q?7W-H;W)T+71I=&QE)R`]/B`G16UA:6P@861D<F5S
M<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+65M86EL7U]T:71L
M92<@/3X@)T5M86EL(&%D9')E<W,@;V8@8VQI96YT("4Q)RP*("`@("`@("`G
M=6E?7V-L:65N="]I;F1I8V%T;W(M96UA:6Q?<V5L9E]?9&5S8W)I<'1I;VXG
M(#T^("=9;W5R(&5M86EL(&%D9')E<W,G+`H@("`@("`@("=U:5]?8VQI96YT
M+VEN9&EC871O<BUE;6%I;%]S96QF7U]S:&]R="UT:71L92<@/3X@)T5M86EL
M(&%D9')E<W,G+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUE;6%I
M;%]S96QF7U]T:71L92<@/3X@)UEO=7(@96UA:6P@861D<F5S<R<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+65M86EL7W5N:VYO=VY?7V1E<V-R
M:7!T:6]N)R`]/B`G16UA:6P@861D<F5S<R!O9B!A(&-L:65N="XG+`H@("`@
M("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUE;6%I;%]U;FMN;W=N7U]S:&]R
M="UT:71L92<@/3X@)T5M86EL(&%D9')E<W,G+`H@("`@("`@("=U:5]?8VQI
M96YT+VEN9&EC871O<BUE;6%I;%]U;FMN;W=N7U]T:71L92<@/3X@)T5M86EL
M(&%D9')E<W,@;V8@82!C;&EE;G0G+`H*("`@("`@("`G=6E?7V-L:65N="]I
M;F1I8V%T;W(M9G5L;"US=&%T=7-?7V1E<V-R:7!T:6]N)R`]/B`G0V]M<&QE
M=&4@<W1A='5S(&9O<B!C;&EE;G0@)3$N)RP*("`@("`@("`G=6E?7V-L:65N
M="]I;F1I8V%T;W(M9G5L;"US=&%T=7-?7W-H;W)T+71I=&QE)R`]/B`G0V]M
M<&QE=&4@<W1A='5S)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M
M9G5L;"US=&%T=7-?7W1I=&QE)R`]/B`G0V]M<&QE=&4@<W1A='5S(&9O<B!C
M;&EE;G0@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUF=6QL
M+7-T871U<U]S96QF7U]D97-C<FEP=&EO;B<@/3X@)UEO=7(@8V]M<&QE=&4@
M<W1A='5S)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M9G5L;"US
M=&%T=7-?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=#;VUP;&5T92!S=&%T=7,G
M+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUF=6QL+7-T871U<U]S
M96QF7U]T:71L92<@/3X@)UEO=7(@8V]M<&QE=&4@<W1A='5S)RP*("`@("`@
M("`G=6E?7V-L:65N="]I;F1I8V%T;W(M9G5L;"US=&%T=7-?=6YK;F]W;E]?
M9&5S8W)I<'1I;VXG(#T^("=#;VUP;&5T92!S=&%T=7,@9F]R(&$@8VQI96YT
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+69U;&PM<W1A='5S
M7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G0V]M<&QE=&4@<W1A='5S)RP*
M("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M9G5L;"US=&%T=7-?=6YK
M;F]W;E]?=&ET;&4G(#T^("=#;VUP;&5T92!S=&%T=7,@9F]R(&$@8VQI96YT
M)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+6UA>"UD;VUA:6YS
M+6QI;6ET+75S86=E7U]D97-C<FEP=&EO;B<@/3X@)TUA>&EM=6T@9&]M86EN
M<R!L:6UI="!U<V%G92!F;W(@8VQI96YT("4Q+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O:6YD:6-A=&]R+6UA>"UD;VUA:6YS+6QI;6ET+75S86=E7U]S:&]R
M="UT:71L92<@/3X@)TUA>&EM=6T@9&]M86EN<R!L:6UI="!U<V%G92<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+6UA>"UD;VUA:6YS+6QI;6ET
M+75S86=E7U]T:71L92<@/3X@)TUA>&EM=6T@9&]M86EN<R!L:6UI="!U<V%G
M92!F;W(@8VQI96YT("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T
M;W(M;6%X+61O;6%I;G,M;&EM:70M=7-A9V5?<V5L9E]?9&5S8W)I<'1I;VXG
M(#T^("=9;W5R(&UA>&EM=6T@9&]M86EN<R!L:6UI="!U<V%G92<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+6UA>"UD;VUA:6YS+6QI;6ET+75S
M86=E7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G36%X:6UU;2!D;VUA:6YS(&QI
M;6ET('5S86=E)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M;6%X
M+61O;6%I;G,M;&EM:70M=7-A9V5?<V5L9E]?=&ET;&4G(#T^("=9;W5R(&UA
M>&EM=6T@9&]M86EN<R!L:6UI="!U<V%G92<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O:6YD:6-A=&]R+6UA>"UD;VUA:6YS+6QI;6ET+75S86=E7W5N:VYO=VY?
M7V1E<V-R:7!T:6]N)R`]/B`G36%X:6UU;2!D;VUA:6YS(&QI;6ET('5S86=E
M(&9O<B!A(&-L:65N="<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R
M+6UA>"UD;VUA:6YS+6QI;6ET+75S86=E7W5N:VYO=VY?7W-H;W)T+71I=&QE
M)R`]/B`G36%X:6UU;2!D;VUA:6YS(&QI;6ET('5S86=E)RP*("`@("`@("`G
M=6E?7V-L:65N="]I;F1I8V%T;W(M;6%X+61O;6%I;G,M;&EM:70M=7-A9V5?
M=6YK;F]W;E]?=&ET;&4G(#T^("=-87AI;75M(&1O;6%I;G,@;&EM:70@=7-A
M9V4@9F]R(&$@8VQI96YT)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A
M=&]R+6UA>"UM86EL8F]X97,M;&EM:70M=7-A9V5?7V1E<V-R:7!T:6]N)R`]
M/B`G36%X:6UU;2!M86EL8F]X97,@;&EM:70@=7-A9V4@9F]R(&-L:65N="`E
M,2XG+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUM87@M;6%I;&)O
M>&5S+6QI;6ET+75S86=E7U]S:&]R="UT:71L92<@/3X@)TUA>&EM=6T@;6%I
M;&)O>&5S(&QI;6ET('5S86=E)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I
M8V%T;W(M;6%X+6UA:6QB;WAE<RUL:6UI="UU<V%G95]?=&ET;&4G(#T^("=-
M87AI;75M(&UA:6QB;WAE<R!L:6UI="!U<V%G92!F;W(@8VQI96YT("4Q)RP*
M("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M;6%X+6UA:6QB;WAE<RUL
M:6UI="UU<V%G95]S96QF7U]D97-C<FEP=&EO;B<@/3X@)UEO=7(@;6%X:6UU
M;2!M86EL8F]X97,@;&EM:70@=7-A9V4G+`H@("`@("`@("=U:5]?8VQI96YT
M+VEN9&EC871O<BUM87@M;6%I;&)O>&5S+6QI;6ET+75S86=E7W-E;&9?7W-H
M;W)T+71I=&QE)R`]/B`G36%X:6UU;2!M86EL8F]X97,@;&EM:70@=7-A9V4G
M+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUM87@M;6%I;&)O>&5S
M+6QI;6ET+75S86=E7W-E;&9?7W1I=&QE)R`]/B`G66]U<B!M87AI;75M(&UA
M:6QB;WAE<R!L:6UI="!U<V%G92<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD
M:6-A=&]R+6UA>"UM86EL8F]X97,M;&EM:70M=7-A9V5?=6YK;F]W;E]?9&5S
M8W)I<'1I;VXG(#T^("=-87AI;75M(&UA:6QB;WAE<R!L:6UI="!U<V%G92!F
M;W(@82!C;&EE;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M
M;6%X+6UA:6QB;WAE<RUL:6UI="UU<V%G95]U;FMN;W=N7U]S:&]R="UT:71L
M92<@/3X@)TUA>&EM=6T@;6%I;&)O>&5S(&QI;6ET('5S86=E)RP*("`@("`@
M("`G=6E?7V-L:65N="]I;F1I8V%T;W(M;6%X+6UA:6QB;WAE<RUL:6UI="UU
M<V%G95]U;FMN;W=N7U]T:71L92<@/3X@)TUA>&EM=6T@;6%I;&)O>&5S(&QI
M;6ET('5S86=E(&9O<B!A(&-L:65N="<L"@H@("`@("`@("=U:5]?8VQI96YT
M+VEN9&EC871O<BUS=&%T95]?9&5S8W)I<'1I;VXG(#T^("=3=&%T92!O9B!C
M;&EE;G0@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M<W1A
M=&5?7W-H;W)T+71I=&QE)R`]/B`G4W1A=&4G+`H@("`@("`@("=U:5]?8VQI
M96YT+VEN9&EC871O<BUS=&%T95]?=&ET;&4G(#T^("=3=&%T92!O9B!C;&EE
M;G0@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUS=&%T95]S
M96QF7U]D97-C<FEP=&EO;B<@/3X@)UEO=7(@<W1A=&4G+`H@("`@("`@("=U
M:5]?8VQI96YT+VEN9&EC871O<BUS=&%T95]S96QF7U]S:&]R="UT:71L92<@
M/3X@)U-T871E)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M<W1A
M=&5?<V5L9E]?=&ET;&4G(#T^("=9;W5R('-T871E)RP*("`@("`@("`G=6E?
M7V-L:65N="]I;F1I8V%T;W(M<W1A=&5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG
M(#T^("=3=&%T92!O9B!A(&-L:65N="XG+`H@("`@("`@("=U:5]?8VQI96YT
M+VEN9&EC871O<BUS=&%T95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)U-T
M871E)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M<W1A=&5?=6YK
M;F]W;E]?=&ET;&4G(#T^("=3=&%T92!O9B!A(&-L:65N="<L"@H@("`@("`@
M("=U:5]?8VQI96YT+VEN9&EC871O<BUS=&%T=7,M9&5T86EL<U]?9&5S8W)I
M<'1I;VXG(#T^("=$971A:6QE9"!S=&%T=7,@9F]R(&-L:65N="`E,2XG+`H@
M("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUS=&%T=7,M9&5T86EL<U]?
M<VAO<G0M=&ET;&4G(#T^("=$971A:6QE9"!S=&%T=7,G+`H@("`@("`@("=U
M:5]?8VQI96YT+VEN9&EC871O<BUS=&%T=7,M9&5T86EL<U]?=&ET;&4G(#T^
M("=$971A:6QE9"!S=&%T=7,@9F]R(&-L:65N="`E,2<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O:6YD:6-A=&]R+7-T871U<RUD971A:6QS7W-E;&9?7V1E<V-R
M:7!T:6]N)R`]/B`G66]U<B!D971A:6QE9"!S=&%T=7,G+`H@("`@("`@("=U
M:5]?8VQI96YT+VEN9&EC871O<BUS=&%T=7,M9&5T86EL<U]S96QF7U]S:&]R
M="UT:71L92<@/3X@)T1E=&%I;&5D('-T871U<R<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O:6YD:6-A=&]R+7-T871U<RUD971A:6QS7W-E;&9?7W1I=&QE)R`]
M/B`G66]U<B!D971A:6QE9"!S=&%T=7,G+`H@("`@("`@("=U:5]?8VQI96YT
M+VEN9&EC871O<BUS=&%T=7,M9&5T86EL<U]U;FMN;W=N7U]D97-C<FEP=&EO
M;B<@/3X@)T1E=&%I;&5D('-T871U<R!F;W(@82!C;&EE;G0N)RP*("`@("`@
M("`G=6E?7V-L:65N="]I;F1I8V%T;W(M<W1A='5S+61E=&%I;'-?=6YK;F]W
M;E]?<VAO<G0M=&ET;&4G(#T^("=$971A:6QE9"!S=&%T=7,G+`H@("`@("`@
M("=U:5]?8VQI96YT+VEN9&EC871O<BUS=&%T=7,M9&5T86EL<U]U;FMN;W=N
M7U]T:71L92<@/3X@)T1E=&%I;&5D('-T871U<R!F;W(@82!C;&EE;G0G+`H*
M("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M<W1A='5S7U]D97-C<FEP
M=&EO;B<@/3X@)U-T871U<R!F;W(@8VQI96YT("4Q+B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O:6YD:6-A=&]R+7-T871U<U]?<VAO<G0M=&ET;&4G(#T^("=3
M=&%T=7,G+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUS=&%T=7-?
M7W1I=&QE)R`]/B`G4W1A='5S(&9O<B!C;&EE;G0@)3$G+`H@("`@("`@("=U
M:5]?8VQI96YT+VEN9&EC871O<BUS=&%T=7-?<V5L9E]?9&5S8W)I<'1I;VXG
M(#T^("=9;W5R('-T871U<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A
M=&]R+7-T871U<U]S96QF7U]S:&]R="UT:71L92<@/3X@)U-T871U<R<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+7-T871U<U]S96QF7U]T:71L
M92<@/3X@)UEO=7(@<W1A='5S)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I
M8V%T;W(M<W1A='5S7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G4W1A='5S
M(&9O<B!A(&-L:65N="XG+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O
M<BUS=&%T=7-?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=3=&%T=7,G+`H@
M("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUS=&%T=7-?=6YK;F]W;E]?
M=&ET;&4G(#T^("=3=&%T=7,@9F]R(&$@8VQI96YT)RP*"B`@("`@("`@)W5I
M7U]C;&EE;G0O:6YD:6-A=&]R+71R869F:6,M;&EM:70M=7-A9V5?7V1E<V-R
M:7!T:6]N)R`]/B`G5')A9F9I8R!L:6UI="!U<V%G92!F;W(@8VQI96YT("4Q
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+71R869F:6,M;&EM
M:70M=7-A9V5?7W-H;W)T+71I=&QE)R`]/B`G5')A9F9I8R!L:6UI="!U<V%G
M92<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+71R869F:6,M;&EM
M:70M=7-A9V5?7W1I=&QE)R`]/B`G5')A9F9I8R!L:6UI="!U<V%G92!F;W(@
M8VQI96YT("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M=')A
M9F9I8RUL:6UI="UU<V%G95]S96QF7U]D97-C<FEP=&EO;B<@/3X@)UEO=7(@
M=')A9F9I8R!L:6UI="!U<V%G92<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD
M:6-A=&]R+71R869F:6,M;&EM:70M=7-A9V5?<V5L9E]?<VAO<G0M=&ET;&4G
M(#T^("=4<F%F9FEC(&QI;6ET('5S86=E)RP*("`@("`@("`G=6E?7V-L:65N
M="]I;F1I8V%T;W(M=')A9F9I8RUL:6UI="UU<V%G95]S96QF7U]T:71L92<@
M/3X@)UEO=7(@=')A9F9I8R!L:6UI="!U<V%G92<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O:6YD:6-A=&]R+71R869F:6,M;&EM:70M=7-A9V5?=6YK;F]W;E]?
M9&5S8W)I<'1I;VXG(#T^("=4<F%F9FEC(&QI;6ET('5S86=E(&9O<B!A(&-L
M:65N="XG+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUT<F%F9FEC
M+6QI;6ET+75S86=E7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G5')A9F9I
M8R!L:6UI="!U<V%G92<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R
M+71R869F:6,M;&EM:70M=7-A9V5?=6YK;F]W;E]?=&ET;&4G(#T^("=4<F%F
M9FEC(&QI;6ET('5S86=E(&9O<B!A(&-L:65N="<L"@H@("`@("`@("=U:5]?
M8VQI96YT+VEP+7!O;VQ?7V1E<V-R:7!T:6]N)R`]/B`G061D+U)E;6]V92!)
M4"!A9&1R97-S97,@86YD(&%S<VEG;B!34TP@8V5R=&EF:6-A=&5S(&9O<B!C
M;&EE;G0@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]I<"UP;V]L7U]S:&]R
M="UT:71L92<@/3X@)TE0('!O;VPG+`H@("`@("`@("=U:5]?8VQI96YT+VEP
M+7!O;VQ?7W1I=&QE)R`]/B`G0VQI96YT("4Q($E0('!O;VPG+`H@("`@("`@
M("=U:5]?8VQI96YT+VEP+7!O;VQ?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=6
M:65W('EO=7(@25`@<&]O;"XG+`H@("`@("`@("=U:5]?8VQI96YT+VEP+7!O
M;VQ?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=)4"!P;V]L)RP*("`@("`@("`G
M=6E?7V-L:65N="]I<"UP;V]L7W-E;&9?7W1I=&QE)R`]/B`G37D@25`@<&]O
M;"<L"@H@("`@("`@("=U:5]?8VQI96YT+VEP+7!O;VPO<')O<&5R=&EE<U]?
M9&5S8W)I<'1I;VXG(#T^("=3970@=7`@25`@<&]O;"!F;W(@8VQI96YT("4Q
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O:7`M<&]O;"]P<F]P97)T:65S7U]D
M;VYE)R`]/B`G0VQI96YT("4Q($E0('!O;VP@:&%S(&)E96X@=7!D871E9"XG
M+`H@("`@("`@("=U:5]?8VQI96YT+VEP+7!O;VPO<')O<&5R=&EE<U]?<VAO
M<G0M=&ET;&4G(#T^("=)4"!P;V]L)RP*("`@("`@("`G=6E?7V-L:65N="]I
M<"UP;V]L+W!R;W!E<G1I97-?7W1I=&QE)R`]/B`G4V5T('5P($E0('!O;VP@
M9F]R(&-L:65N="`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O:7`M<&]O;"]P
M<F]P97)T:65S7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G5FEE=R!Y;W5R($E0
M('!O;VPN)RP*("`@("`@("`G=6E?7V-L:65N="]I<"UP;V]L+W!R;W!E<G1I
M97-?<V5L9E]?9&]N92<@/3X@)R<L"B`@("`@("`@)W5I7U]C;&EE;G0O:7`M
M<&]O;"]P<F]P97)T:65S7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G37D@25`@
M<&]O;"<L"B`@("`@("`@)W5I7U]C;&EE;G0O:7`M<&]O;"]P<F]P97)T:65S
M7W-E;&9?7W1I=&QE)R`]/B`G37D@25`@<&]O;"<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O:7`M<&]O;"]P<F]P97)T:65S7W5N:VYO=VY?7V1E<V-R:7!T:6]N
M)R`]/B`G061D+U)E;6]V92!)4"!A9&1R97-S97,@=&\O9G)O;2!C;&EE;G0@
M25`@<&]O;"P@86YD(&UA;F%G92!34TP@8V5R=&EF:6-A=&5S+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O:7`M<&]O;"]P<F]P97)T:65S7W5N:VYO=VY?7W-H
M;W)T+71I=&QE)R`]/B`G25`@<&]O;"<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M:7`M<&]O;"]P<F]P97)T:65S7W5N:VYO=VY?7W1I=&QE)R`]/B`G4V5T('5P
M(&-L:65N="!)4"!P;V]L)RP*("`@("`@("`G=6E?7V-L:65N="]I<"UP;V]L
M+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G0VQI96YT
M($E0(%!O;VP@0V]N9FEG=7)A=&EO;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M:7`M<&]O;"]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?,5]U;FMN;W=N
M)R`]/B`G4V5L96-T(&$@8VQI96YT('=H;W-E($E0('!O;VP@>6]U('=A;G0@
M=&\@8V]N9FEG=7)E+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O:7`M<&]O;"]P
M<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?,R<@/3X@)U=H96X@9&]N92!W
M:71H(&5D:71I;F<@=&AE(&-L:65N="!)4"!P;V]L+"!C;&EC:R!&:6YI<V@@
M=&\@87!P;'D@8VAA;F=E<R!A;F0@97AI="!T:&4@=VEZ87)D+B<L"@H@("`@
M("`@("=U:5]?8VQI96YT+VQI;6ET<U]?9&5S8W)I<'1I;VXG(#T^("=6:65W
M(&]R(&5D:70@;&EM:71S(&]F(&-L:65N="`E,2XG+`H@("`@("`@("=U:5]?
M8VQI96YT+VQI;6ET<U]?9&]N92<@/3X@)TQI;6ET<R!O9B!C;&EE;G0@)3$@
M:&%V92!B965N('5P9&%T960N)RP*("`@("`@("`G=6E?7V-L:65N="]L:6UI
M='-?7W-H;W)T+71I=&QE)R`]/B`G3&EM:71S)RP*("`@("`@("`G=6E?7V-L
M:65N="]L:6UI='-?7W1I=&QE)R`]/B`G5FEE=R!O<B!E9&ET(&QI;6ET<R!O
M9B!C;&EE;G0@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+VQI;6ET<U]S96QF
M7U]D97-C<FEP=&EO;B<@/3X@)U9I97<@;7D@;&EM:71S+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O;&EM:71S7W-E;&9?7V1O;F4G(#T^("<G+`H@("`@("`@
M("=U:5]?8VQI96YT+VQI;6ET<U]S96QF7U]S:&]R="UT:71L92<@/3X@)TQI
M;6ET<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O;&EM:71S7W-E;&9?7W1I=&QE
M)R`]/B`G5FEE=R!M>2!L:6UI=',G+`H@("`@("`@("=U:5]?8VQI96YT+VQI
M;6ET<U]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)U9I97<@;W(@961I="!L
M:6UI=',@;V8@82!C;&EE;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]L:6UI
M='-?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=,:6UI=',G+`H@("`@("`@
M("=U:5]?8VQI96YT+VQI;6ET<U]U;FMN;W=N7U]T:71L92<@/3X@)U9I97<@
M;W(@961I="!L:6UI=',@;V8@82!C;&EE;G0G+`H@("`@("`@("=U:5]?8VQI
M96YT+VQI;6ET<U]U;FMN;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=6:65W:6YG
M(&]R(&5D:71I;F<@82!C;&EE;G0@;&EM:71S)RP*("`@("`@("`G=6E?7V-L
M:65N="]L:6UI='-?=6YK;F]W;E]?=VEZ87)D7U\Q7W5N:VYO=VXG(#T^("=0
M;&5A<V4@<V5L96-T(&$@8VQI96YT('=H;W-E(&QI;6ET<R!T;R!V:65W(&]R
M(&5D:70N)RP*("`@("`@("`G=6E?7V-L:65N="]L:6UI='-?=6YK;F]W;E]?
M=VEZ87)D7U\R)R`]/B`G069T97(@961I=&EN9R!T:&4@8VQI96YT(&QI;6ET
M<RP@8VQI8VL@1FEN:7-H+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O;&EM:71S
M7W5N:VYO=VY?7W=I>F%R9%]?,E]S96QF)R`]/B`G069T97(@=FEE=VEN9R!Y
M;W5R(&QI;6ET<RP@8VQI8VL@1FEN:7-H+B<L"@H@("`@("`@("=U:5]?8VQI
M96YT+W!E<FUI<W-I;VYS7U]D97-C<FEP=&EO;B<@/3X@)U9I97<@;W(@961I
M="!P97)M:7-S:6]N<R!F;W(@8VQI96YT(&%C8V]U;G0@)3$N)RP*("`@("`@
M("`G=6E?7V-L:65N="]P97)M:7-S:6]N<U]?9&]N92<@/3X@)U!E<FUI<W-I
M;VYS(&]F(&-L:65N="`E,2!H879E(&)E96X@=7!D871E9"XG+`H@("`@("`@
M("=U:5]?8VQI96YT+W!E<FUI<W-I;VYS7U]S:&]R="UT:71L92<@/3X@)U!E
M<FUI<W-I;VYS)RP*("`@("`@("`G=6E?7V-L:65N="]P97)M:7-S:6]N<U]?
M=&ET;&4G(#T^("=#;&EE;G0@)3$@<&5R;6ES<VEO;G,G+`H@("`@("`@("=U
M:5]?8VQI96YT+W!E<FUI<W-I;VYS7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G
M5FEE=R!Y;W5R('!E<FUI<W-I;VYS+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M<&5R;6ES<VEO;G-?<V5L9E]?9&]N92<@/3X@)R<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O<&5R;6ES<VEO;G-?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=097)M
M:7-S:6]N<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O<&5R;6ES<VEO;G-?<V5L
M9E]?=&ET;&4G(#T^("=->2!P97)M:7-S:6]N<R<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O<&5R;6ES<VEO;G-?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=6
M:65W(&]R(&5D:70@<&5R;6ES<VEO;G,@9F]R(&$@8VQI96YT(&%C8V]U;G0N
M)RP*("`@("`@("`G=6E?7V-L:65N="]P97)M:7-S:6]N<U]U;FMN;W=N7U]S
M:&]R="UT:71L92<@/3X@)U!E<FUI<W-I;VYS)RP*("`@("`@("`G=6E?7V-L
M:65N="]P97)M:7-S:6]N<U]U;FMN;W=N7U]T:71L92<@/3X@)U9I97<O161I
M="!C;&EE;G0@<&5R;6ES<VEO;G,G+`H@("`@("`@("=U:5]?8VQI96YT+W!E
M<FUI<W-I;VYS7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@/3X@)U9I97=I;F<O
M161I=&EN9R!#;&EE;G0@4&5R;6ES<VEO;G,G+`H@("`@("`@("=U:5]?8VQI
M96YT+W!E<FUI<W-I;VYS7W5N:VYO=VY?7W=I>F%R9%]?,2]P<F]P97)T:65S
M7W-E;&8G(#T^("=7:&5N(&1O;F4@=VET:"!V:65W:6YG('EO=7(@<&5R;6ES
M<VEO;G,L(&-L:6-K($9I;FES:"!T;R!T;R!A<'!L>2!C:&%N9V5S(&%N9"!E
M>&ET('1H92!W:7IA<F0N)RP*("`@("`@("`G=6E?7V-L:65N="]P97)M:7-S
M:6]N<U]U;FMN;W=N7U]W:7IA<F1?7S%?=6YK;F]W;B<@/3X@)U-E;&5C="!A
M(&-L:65N="!W:&]S92!P97)M:7-S:6]N<R!Y;W4@=V%N="!T;R!V:65W+V5D
M:70N)RP*("`@("`@("`G=6E?7V-L:65N="]P97)M:7-S:6]N<U]U;FMN;W=N
M7U]W:7IA<F1?7S(G(#T^("=7:&5N(&1O;F4@=VET:"!E9&ET:6YG('1H92!C
M;&EE;G0@<&5R;6ES<VEO;G,L(&-L:6-K($9I;FES:"!T;R!A<'!L>2!C:&%N
M9V5S(&%N9"!E>&ET('1H92!W:7IA<F0N)RP*"B`@("`@("`@)W5I7U]C;&EE
M;G0O<')E9F5R96YC97-?7V1E<V-R:7!T:6]N)R`]/B`G161I="!S97-S:6]N
M(&%N9"!I;G1E<F9A8V4@<')E9F5R96YC97,@9F]R(&-L:65N="`E,2XG+`H@
M("`@("`@("=U:5]?8VQI96YT+W!R969E<F5N8V5S7U]D;VYE)R`]/B`G4')E
M9F5R96YC97,@9F]R(&-L:65N="`E,2!H879E(&)E96X@=7!D871E9"XG+`H@
M("`@("`@("=U:5]?8VQI96YT+W!R969E<F5N8V5S7U]S:&]R="UT:71L92<@
M/3X@)U!R969E<F5N8V5S)RP*("`@("`@("`G=6E?7V-L:65N="]P<F5F97)E
M;F-E<U]?=&ET;&4G(#T^("=#;&EE;G0@)3$@<')E9F5R96YC97,G+`H@("`@
M("`@("=U:5]?8VQI96YT+W!R969E<F5N8V5S7W-E;&9?7V1E<V-R:7!T:6]N
M)R`]/B`G161I="!Y;W5R('-E<W-I;VX@86YD(&EN=&5R9F%C92!P<F5F97)E
M;F-E<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O<')E9F5R96YC97-?<V5L9E]?
M9&]N92<@/3X@)UEO=7(@<')E9F5R96YC97,@:&%V92!B965N('5P9&%T960N
M)RP*("`@("`@("`G=6E?7V-L:65N="]P<F5F97)E;F-E<U]S96QF7U]S:&]R
M="UT:71L92<@/3X@)TUY('!R969E<F5N8V5S)RP*("`@("`@("`G=6E?7V-L
M:65N="]P<F5F97)E;F-E<U]S96QF7U]T:71L92<@/3X@)TUY('!R969E<F5N
M8V5S)RP*("`@("`@("`G=6E?7V-L:65N="]P<F5F97)E;F-E<U]U;FMN;W=N
M7U]D97-C<FEP=&EO;B<@/3X@)T5D:70@0U`@<V5S<VEO;B!A;F0@:6YT97)F
M86-E('!R969E<F5N8V5S(&9O<B!A(&-L:65N="XG+`H@("`@("`@("=U:5]?
M8VQI96YT+W!R969E<F5N8V5S7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G
M4')E9F5R96YC97,G+`H@("`@("`@("=U:5]?8VQI96YT+W!R969E<F5N8V5S
M7W5N:VYO=VY?7W1I=&QE)R`]/B`G161I="!C;&EE;G0@<')E9F5R96YC97,G
M+`H@("`@("`@("=U:5]?8VQI96YT+W!R969E<F5N8V5S7W5N:VYO=VY?7W=I
M>F%R9"UT:71L92<@/3X@)T5D:71I;F<@0VQI96YT(%!R969E<F5N8V5S)RP*
M("`@("`@("`G=6E?7V-L:65N="]P<F5F97)E;F-E<U]U;FMN;W=N7U]W:7IA
M<F1?7S%?=6YK;F]W;B<@/3X@)U-E;&5C="!C;&EE;G0@=VAO<V4@<V5S<VEO
M;B!A;F0@:6YT97)F86-E('!R969E<F5N8V5S('EO=2!W86YT('1O(&UA;F%G
M92XG+`H@("`@("`@("=U:5]?8VQI96YT+W!R969E<F5N8V5S7W5N:VYO=VY?
M7W=I>F%R9%]?,B<@/3X@)T%F=&5R(&5D:71I;F<@=&AE(&-L:65N="!P<F5F
M97)E;F-E<RP@8VQI8VL@1FEN:7-H+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M<')E9F5R96YC97-?=6YK;F]W;E]?=VEZ87)D7U\R7W-E;&8G(#T^("=!9G1E
M<B!E9&ET:6YG('EO=7(@<')E9F5R96YC97,L(&-L:6-K($9I;FES:"XG+`H*
M("`@("`@("`G=6E?7V-L:65N="]P<F]P97)T:65S7U]D97-C<FEP=&EO;B<@
M/3X@)T5D:70@<&5R<V]N86P@:6YF;W)M871I;VX@;V8@8VQI96YT("4Q+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O<')O<&5R=&EE<U]?9&]N92<@/3X@)U!E
M<G-O;F%L(&EN9F]R;6%T:6]N(&]F(&-L:65N="`E,2!H87,@8F5E;B!U<&1A
M=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O<')O<&5R=&EE<U]?<VAO<G0M
M=&ET;&4G(#T^("=097)S;VYA;"!I;F9O<FUA=&EO;B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O<')O<&5R=&EE<U]?=&ET;&4G(#T^("=#;&EE;G0@)3$@<&5R
M<V]N86P@:6YF;R<L"B`@("`@("`@)W5I7U]C;&EE;G0O<')O<&5R=&EE<U]N
M97<M861H;V-?7W=I>F%R9%]?,5]N97<G(#T^("=4:&4@8VQI96YT(&%C8V]U
M;G0@=VEL;"!B92!C<F5A=&5D(&EM;65D:6%T96QY(&%F=&5R('EO=2!C;&EC
M:R!.97AT(#X^+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O<')O<&5R=&EE<U]N
M97=?7V1E<V-R:7!T:6]N)R`]/B`G0W)E871E(&YE=R!C;&EE;G0@86-C;W5N
M="XG+`H@("`@("`@("=U:5]?8VQI96YT+W!R;W!E<G1I97-?;F5W7U]D;VYE
M)R`]/B`G0VQI96YT("4Q(&AA<R!B965N(&-R96%T960N)RP*("`@("`@("`G
M=6E?7V-L:65N="]P<F]P97)T:65S7VYE=U]?<VAO<G0M=&ET;&4G(#T^("=#
M<F5A=&4@8VQI96YT)RP*("`@("`@("`G=6E?7V-L:65N="]P<F]P97)T:65S
M7VYE=U]?=&ET;&4G(#T^("=#<F5A=&4@8VQI96YT)RP*("`@("`@("`G=6E?
M7V-L:65N="]P<F]P97)T:65S7VYE=U]?=VEZ87)D+71I=&QE)R`]/B`G0VQI
M96YT($-R96%T:6]N)RP*("`@("`@("`G=6E?7V-L:65N="]P<F]P97)T:65S
M7VYE=U]?=VEZ87)D7U\Q+VEP+7!O;VPO<')O<&5R=&EE<R<@/3X@)U=H96X@
M9&]N92!W:71H(&-O;F9I9W5R:6YG('1H92!C;&EE;G0@25`@<&]O;"P@8VQI
M8VL@1FEN:7-H('1O(&-O;7!L971E+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M<')O<&5R=&EE<U]N97=?7W=I>F%R9%]?,2]L:6UI=',G(#T^("=#;&EC:R!.
M97AT(#X^('1O('!R;V-E960@=&\@8V]N9FEG=7)I;F<@8VQI96YT('!E<FUI
M<W-I;VYS+B!#;&EC:R!&:6YI<V@@=&\@87!P;'D@=&AE(&QI;6ET<R!A;F0@
M97AI="!T:&ES('=I>F%R9"XG+`H@("`@("`@("=U:5]?8VQI96YT+W!R;W!E
M<G1I97-?;F5W7U]W:7IA<F1?7S$O<&5R;6ES<VEO;G,G(#T^("=#;&EC:R!.
M97AT(#X^('1O('!R;V-E960@=&\@8V]N9FEG=7)I;F<@8VQI96YT($E0('!O
M;VPN($-L:6-K($9I;FES:"!T;R!A<'!L>2!T:&4@<&5R;6ES<VEO;G,@86YD
M(&5X:70@=&AI<R!W:7IA<F0N)RP*("`@("`@("`G=6E?7V-L:65N="]P<F]P
M97)T:65S7VYE=U]?=VEZ87)D7U\Q7VYE=R<@/3X@)T-L:6-K($YE>'0@/CX@
M=&\@8W)E871E('1H92!C;&EE;G0@86-C;W5N="!A;F0@<')O8V5E9"!T;R!C
M;VYF:6=U<FEN9R!R97-O=7)C92!U<V%G92!L:6UI=',N($-L:6-K($9I;FES
M:"!T;R!C<F5A=&4@=&AE(&%C8V]U;G0@=VET:&]U="!I=',@9G5R=&AE<B!C
M;VYF:6=U<FEN9RXG+`H@("`@("`@("=U:5]?8VQI96YT+W!R;W!E<G1I97-?
M<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=%9&ET('EO=7(@<&5R<V]N86P@:6YF
M;W)M871I;VXN)RP*("`@("`@("`G=6E?7V-L:65N="]P<F]P97)T:65S7W-E
M;&9?7V1O;F4G(#T^("=9;W5R('!E<G-O;F%L(&EN9F]R;6%T:6]N(&AA<R!B
M965N('5P9&%T960N)RP*("`@("`@("`G=6E?7V-L:65N="]P<F]P97)T:65S
M7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G37D@<&5R<V]N86P@:6YF;W)M871I
M;VXG+`H@("`@("`@("=U:5]?8VQI96YT+W!R;W!E<G1I97-?<V5L9E]?=&ET
M;&4G(#T^("=->2!P97)S;VYA;"!I;F9O)RP*("`@("`@("`G=6E?7V-L:65N
M="]P<F]P97)T:65S7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G161I="!A
M(&-L:65N="!P97)S;VYA;"!I;F9O<FUA=&EO;BXG+`H@("`@("`@("=U:5]?
M8VQI96YT+W!R;W!E<G1I97-?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=0
M97)S;VYA;"!I;F9O<FUA=&EO;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O<')O
M<&5R=&EE<U]U;FMN;W=N7U]T:71L92<@/3X@)T5D:70@8VQI96YT('!E<G-O
M;F%L(&EN9F\G+`H@("`@("`@("=U:5]?8VQI96YT+W!R;W!E<G1I97-?=6YK
M;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G161I=&EN9R!#;&EE;G0@4&5R<V]N
M86P@26YF;W)M871I;VXG+`H@("`@("`@("=U:5]?8VQI96YT+W!R;W!E<G1I
M97-?=6YK;F]W;E]?=VEZ87)D7U\Q7W5N:VYO=VXG(#T^("=396QE8W0@8VQI
M96YT('=H;W-E('!E<G-O;F%L(&EN9F\@>6]U('=A;G0@=&\@8VAA;F=E+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA
M<F1?7S(G(#T^("=7:&5N(&1O;F4@=VET:"!E9&ET:6YG('1H92!C;&EE;G0@
M:6YF;RP@8VQI8VL@1FEN:7-H('1O(&%P<&QY(&-H86YG97,N)RP*("`@("`@
M("`G=6E?7V-L:65N="]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?,E]S
M96QF)R`]/B`G5VAE;B!D;VYE('=I=&@@961I=&EN9R!Y;W5R(&EN9F\L(&-L
M:6-K($9I;FES:"!T;R!A<'!L>2!C:&%N9V5S+B<L"@H@("`@("`@("=U:5]?
M8VQI96YT+W1O9V=L95]D:7-A8FQE7U]D97-C<FEP=&EO;B<@/3X@)T1I<V%B
M;&4@8VQI96YT(&%C8V]U;G0@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]T
M;V=G;&5?9&ES86)L95]?9&]N92<@/3X@)T-L:65N="`E,2!H87,@8F5E;B!D
M:7-A8FQE9"XG+`H@("`@("`@("=U:5]?8VQI96YT+W1O9V=L95]D:7-A8FQE
M7U]S:&]R="UT:71L92<@/3X@)T1I<V%B;&4G+`H@("`@("`@("=U:5]?8VQI
M96YT+W1O9V=L95]D:7-A8FQE7U]T:71L92<@/3X@)T1I<V%B;&4@8VQI96YT
M("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]T;V=G;&5?96YA8FQE7U]D97-C
M<FEP=&EO;B<@/3X@)T5N86)L92!C;&EE;G0@86-C;W5N="`E,2XG+`H@("`@
M("`@("=U:5]?8VQI96YT+W1O9V=L95]E;F%B;&5?7V1O;F4G(#T^("=#;&EE
M;G0@)3$@:&%S(&)E96X@96YA8FQE9"XG+`H@("`@("`@("=U:5]?8VQI96YT
M+W1O9V=L95]E;F%B;&5?7W-H;W)T+71I=&QE)R`]/B`G16YA8FQE)RP*("`@
M("`@("`G=6E?7V-L:65N="]T;V=G;&5?96YA8FQE7U]T:71L92<@/3X@)T5N
M86)L92!C;&EE;G0@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+W1O9V=L95]U
M;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)T5N86)L92!O<B!D:7-A8FQE(&$@
M8VQI96YT(&%C8V]U;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]T;V=G;&5?
M=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=%;F%B;&4O9&ES86)L92<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O=&]G9VQE7W5N:VYO=VY?7W1I=&QE)R`]/B`G
M16YA8FQE+T1I<V%B;&4@82!C;&EE;G0G+`H@("`@("`@("=U:5]?8VQI96YT
M+W1O9V=L95]U;FMN;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=%;F%B;&EN9R]$
M:7-A8FQI;F<@0VQI96YT($%C8V]U;G0G+`H@("`@("`@("=U:5]?8VQI96YT
M+W1O9V=L95]U;FMN;W=N7U]W:7IA<F1?7S%?=6YK;F]W;B<@/3X@)U-E;&5C
M="!A(&-L:65N="!A8V-O=6YT('EO=2!W86YT('1O(&5N86)L92]D:7-A8FQE
M+B<L"@H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G-?7V1E<V-R:7!T:6]N
M)R`]/B`G4V5R=F5R+7=I9&4@8W5S=&]M(&)U='1O;G,N)RP*("`@("`@("`G
M=6E?7V-U<W1O;2UB=71T;VYS7U]S:&]R="UT:71L92<@/3X@)T-U<W1O;2!B
M=71T;VYS)RP*("`@("`@("`G=6E?7V-U<W1O;2UB=71T;VYS7U]T:71L92<@
M/3X@)U-E<G9E<BUW:61E(&-U<W1O;2!B=71T;VYS)RP*"B`@("`@("`@)W5I
M7U]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N7U]N;VYE+6%V86EL86)L
M92<@/3X@)UEO=2!D;VY<)W0@8W5R<F5N=&QY(&AA=F4@86YY(&-U<W1O;2!B
M=71T;VYS+B<L"@H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M
M+6)U='1O;B]D96QE=&5?7V1E<V-R:7!T:6]N)R`]/B`G4F5M;W9E('-E<G9E
M<BUW:61E(&-U<W1O;2!B=71T;VX@)3$N)RP*("`@("`@("`G=6E?7V-U<W1O
M;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L971E7U]D;VYE)R`]/B`G4V5R
M=F5R+7=I9&4@8W5S=&]M(&)U='1O;B`E,2!H87,@8F5E;B!R96UO=F5D+B<L
M"B`@("`@("`@)W5I7U]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+V1E
M;&5T95]?<VAO<G0M=&ET;&4G(#T^("=296UO=F4G+`H@("`@("`@("=U:5]?
M8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D96QE=&5?7W1I=&QE)R`]
M/B`G4F5M;W9E(&-U<W1O;2!B=71T;VX@)3$G+`H@("`@("`@("=U:5]?8W5S
M=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D96QE=&5?=6YK;F]W;E]?9&5S
M8W)I<'1I;VXG(#T^("=296UO=F4@<V5R=F5R+7=I9&4@8W5S=&]M(&)U='1O
M;BXG+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O
M;B]D96QE=&5?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=296UO=F4G+`H@
M("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D96QE
M=&5?=6YK;F]W;E]?=&ET;&4G(#T^("=296UO=F4@8W5S=&]M(&)U='1O;B<L
M"B`@("`@("`@)W5I7U]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+V1E
M;&5T95]U;FMN;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=#=7-T;VT@8G5T=&]N
M(')E;6]V86PG+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M
M+6)U='1O;B]D96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^
M("=396QE8W0@=VAI8V@@<V5R=F5R+7=I9&4@8W5S=&]M(&)U='1O;B!Y;W4@
M=V%N="!T;R!R96UO=F4N)RP*("`@("`@("`G=6E?7V-U<W1O;2UB=71T;VYS
M+V-U<W1O;2UB=71T;VXO9&5L971E7W5N:VYO=VY?7W=I>F%R9%]?,R<@/3X@
M)T-O;F9I<FT@<F5M;W9I;F<@=&AE('-E<G9E<BUW:61E(&-U<W1O;2!B=71T
M;VX@8GD@<V5L96-T:6YG('1H92!C:&5C:R!B;W@@86YD(&-L:6-K(&9I;FES
M:"!T;R!C;VUP;&5T96QY(')E;6]V92!I="!A;F0@97AI="!T:&4@=VEZ87)D
M+B<L"@H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O
M;B]P<F]P97)T:65S7U]D97-C<FEP=&EO;B<@/3X@)T5D:70@<')O<&5R=&EE
M<R!O9B!S97)V97(M=VED92!C=7-T;VT@8G5T=&]N("4Q+B<L"B`@("`@("`@
M)W5I7U]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+W!R;W!E<G1I97-?
M7V1O;F4G(#T^("=0<F]P97)T:65S(&]F(&-U<W1O;2!B=71T;VX@)3$@:&%V
M92!B965N('5P9&%T960N)RP*("`@("`@("`G=6E?7V-U<W1O;2UB=71T;VYS
M+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]?<VAO<G0M=&ET;&4G(#T^("=0
M<F]P97)T:65S)RP*("`@("`@("`G=6E?7V-U<W1O;2UB=71T;VYS+V-U<W1O
M;2UB=71T;VXO<')O<&5R=&EE<U]?=&ET;&4G(#T^("=-;V1I9GD@<V5R=F5R
M(&-U<W1O;2!B=71T;VX@)3$G+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O
M;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T:65S7VYE=U]?9&5S8W)I<'1I;VXG
M(#T^("=#<F5A=&4@;F5W('-E<G9E<BUW:61E(&-U<W1O;2!B=71T;VXN)RP*
M("`@("`@("`G=6E?7V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO<')O
M<&5R=&EE<U]N97=?7V1O;F4G(#T^("=#=7-T;VT@8G5T=&]N("4Q(&AA<R!B
M965N(&-R96%T960G+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S
M=&]M+6)U='1O;B]P<F]P97)T:65S7VYE=U]?<VAO<G0M=&ET;&4G(#T^("=#
M<F5A=&4G+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U
M='1O;B]P<F]P97)T:65S7VYE=U]?=&ET;&4G(#T^("=#<F5A=&4@<V5R=F5R
M(&-U<W1O;2!B=71T;VXG+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O
M8W5S=&]M+6)U='1O;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D+71I=&QE)R`]
M/B`G0W5S=&]M(&)U='1O;B!C<F5A=&EO;B<L"B`@("`@("`@)W5I7U]C=7-T
M;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+W!R;W!E<G1I97-?;F5W7U]W:7IA
M<F1?7S)?;F5W)R`]/B`G0VQI8VL@1FEN:7-H('1O(&-R96%T92!T:&4@8W5S
M=&]M(&)U='1O;BXG+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S
M=&]M+6)U='1O;B]P<F]P97)T:65S7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]
M/B`G161I="!P<F]P97)T:65S(&]F(&$@<V5R=F5R+7=I9&4@8W5S=&]M(&)U
M='1O;BXG+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U
M='1O;B]P<F]P97)T:65S7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G4')O
M<&5R=&EE<R<L"B`@("`@("`@)W5I7U]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM
M8G5T=&]N+W!R;W!E<G1I97-?=6YK;F]W;E]?=&ET;&4G(#T^("=-;V1I9GD@
M<V5R=F5R+7=I9&4@8W5S=&]M(&)U='1O;B<L"B`@("`@("`@)W5I7U]C=7-T
M;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+W!R;W!E<G1I97-?=6YK;F]W;E]?
M=VEZ87)D+71I=&QE)R`]/B`G36]D:69Y:6YG(%-E<G9E<BUW:61E($-U<W1O
M;2!"=71T;VXG+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M
M+6)U='1O;B]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N
M)R`]/B`G4V5L96-T('=H:6-H(&-U<W1O;2!B=71T;VX@>6]U('=A;G0@=&\@
M;6]D:69Y+B<L"B`@("`@("`@)W5I7U]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM
M8G5T=&]N+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\S)R`]/B`G5VAE
M;B!D;VYE('=I=&@@;6]D:69Y:6YG('1H92!S97)V97(M=VED92!C=7-T;VT@
M8G5T=&]N+"!C;&EC:R!&:6YI<V@@=&\@87!P;'D@8VAA;F=E<R!A;F0@97AI
M="!T:&4@=VEZ87)D+B<L"@H@("`@("`@("=U:5]?9&%S:&)O87)D(V-L:65N
M='-?7V1E<V-R:7!T:6]N)R`]/B`G3F\@9F%V;W)I=&4@8VQI96YT<R<L"B`@
M("`@("`@)W5I7U]D87-H8F]A<F0C8VQI96YT<U]?=&ET;&4G(#T^("=#;&EE
M;G1S)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9"-C=7-T;VTM8G5T=&]N<U]?
M=&ET;&4G(#T^("=#=7-T;VT@8G5T=&]N<R<L"B`@("`@("`@)W5I7U]D87-H
M8F]A<F0C9&]M86EN<U]?9&5S8W)I<'1I;VXG(#T^("=.;R!F879O<FET92!D
M;VUA:6YS)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9"-D;VUA:6YS7U]T:71L
M92<@/3X@)T1O;6%I;G,G+`H@("`@("`@("=U:5]?9&%S:&)O87)D(V9A=F]R
M:71E<R]T86)S7U]D97-C<FEP=&EO;B<@/3X@)U-H;W<@=&AE(&9O;&QO=VEN
M9R!T86)S(&EN($9A=F]R:71E<SHG+`H@("`@("`@("=U:5]?9&%S:&)O87)D
M(V9A=F]R:71E<U]?=&ET;&4G(#T^("=&879O<FET97,G+`H@("`@("`@("=U
M:5]?9&%S:&)O87)D(VEN9F\O9F]O=&5R7U]D97-C<FEP=&EO;B<@/3X@)U-H
M;W<@=&AE(&9O;&QO=VEN9R!B=71T;VYS(&EN('1H92!F;V]T97(Z)RP*("`@
M("`@("`G=6E?7V1A<VAB;V%R9"-I;F9O7U]D97-C<FEP=&EO;B<@/3X@)U-H
M;W<@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO;CHG+`H@("`@("`@("=U:5]?
M9&%S:&)O87)D(VEN9F]?7W1I=&QE)R`]/B`G4V5R=F5R($EN9F]R;6%T:6]N
M)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9"-M86EL;F%M97-?7V1E<V-R:7!T
M:6]N)R`]/B`G3F\@9F%V;W)I=&4@;6%I;&YA;65S)RP*("`@("`@("`G=6E?
M7V1A<VAB;V%R9"-M86EL;F%M97-?7W1I=&QE)R`]/B`G36%I;&YA;65S)RP*
M("`@("`@("`G=6E?7V1A<VAB;V%R9"-Q=6EC:RUS96%R8VA?7W1I=&QE)R`]
M/B`G475I8VL@<V5A<F-H)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9"-R96-E
M;G1?7V1E<V-R:7!T:6]N)R`]/B`G3F\@<F5C96YT('!A9V5S)RP*("`@("`@
M("`G=6E?7V1A<VAB;V%R9"-R96-E;G1?7W1I=&QE)R`]/B`G4F5C96YT)RP*
M("`@("`@("`G=6E?7V1A<VAB;V%R9"-S:&]R=&-U='-?7V1E<V-R:7!T:6]N
M)R`]/B`G3F\@<VAO<G1C=71S)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9"-S
M:&]R=&-U='-?7W1I=&QE)R`]/B`G4VAO<G1C=71S)RP*("`@("`@("`G=6E?
M7V1A<VAB;V%R9"-S=&%T:7-T:6-S+V9O;W1E<E]?9&5S8W)I<'1I;VXG(#T^
M("=3:&]W('1H92!F;VQL;W=I;F<@8G5T=&]N<R!I;B!T:&4@9F]O=&5R.B<L
M"B`@("`@("`@)W5I7U]D87-H8F]A<F0C<W1A=&ES=&EC<U]?9&5S8W)I<'1I
M;VXG(#T^("=3:&]W('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VXZ)RP*("`@
M("`@("`G=6E?7V1A<VAB;V%R9"-S=&%T:7-T:6-S7U]T:71L92<@/3X@)U-T
M871I<W1I8W,G+`H@("`@("`@("=U:5]?9&%S:&)O87)D(W1O;VQS+V9O;W1E
M<E]?9&5S8W)I<'1I;VXG(#T^("=3:&]W('1H92!F;VQL;W=I;F<@8G5T=&]N
M<R!I;B!T:&4@9F]O=&5R.B<L"B`@("`@("`@)W5I7U]D87-H8F]A<F0C=&]O
M;'-?7V1E<V-R:7!T:6]N)R`]/B`G4VAO=R!T:&4@9F]L;&]W:6YG(&)U='1O
M;G,Z)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9"-T;V]L<U]?=&ET;&4G(#T^
M("=4;V]L<R<L"B`@("`@("`@)W5I7U]D87-H8F]A<F1?7V1E<V-R:7!T:6]N
M)R`]/B`G061M:6YI<W1R871O<B!$97-K=&]P+B<L"B`@("`@("`@)W5I7U]D
M87-H8F]A<F1?7W-H;W)T+71I=&QE)R`]/B`G1&5S:W1O<"<L"B`@("`@("`@
M)W5I7U]D87-H8F]A<F1?7W1I=&QE)R`]/B`G061M:6YI<W1R871O<B!$97-K
M=&]P)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9%]S96QF7U]D97-C<FEP=&EO
M;B<@/3X@)TUY($1E<VMT;W`N)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9%]S
M96QF7U]S:&]R="UT:71L92<@/3X@)T1E<VMT;W`G+`H@("`@("`@("=U:5]?
M9&%S:&)O87)D7W-E;&9?7W1I=&QE)R`]/B`G37D@1&5S:W1O<"<L"@H@("`@
M("`@("=U:5]?9&%S:&)O87)D+V-U<W1O;6EZ95]?9&5S8W)I<'1I;VXG(#T^
M("=#=7-T;VUI>F4@061M:6YI<W1R871O<B!$97-K=&]P+B<L"B`@("`@("`@
M)W5I7U]D87-H8F]A<F0O8W5S=&]M:7IE7U]D;VYE)R`]/B`G061M:6X@1&5S
M:W1O<"!H87,@8F5E;B!U<&1A=&5D+B<L"B`@("`@("`@)W5I7U]D87-H8F]A
M<F0O8W5S=&]M:7IE7U]S:&]R="UT:71L92<@/3X@)T-U<W1O;6EZ92!$97-K
M=&]P)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9"]C=7-T;VUI>F5?7W1I=&QE
M)R`]/B`G0W5S=&]M:7IE($%D;6EN($1E<VMT;W`G+`H@("`@("`@("=U:5]?
M9&%S:&)O87)D+V-U<W1O;6EZ95]S96QF7U]D97-C<FEP=&EO;B<@/3X@)T-U
M<W1O;6EZ92!Y;W5R($1E<VMT;W`N)RP*("`@("`@("`G=6E?7V1A<VAB;V%R
M9"]C=7-T;VUI>F5?<V5L9E]?9&]N92<@/3X@)UEO=7(@1&5S:W1O<"!H87,@
M8F5E;B!U<&1A=&5D+B<L"B`@("`@("`@)W5I7U]D87-H8F]A<F0O8W5S=&]M
M:7IE7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G0W5S=&]M:7IE($1E<VMT;W`G
M+`H@("`@("`@("=U:5]?9&%S:&)O87)D+V-U<W1O;6EZ95]S96QF7U]T:71L
M92<@/3X@)T-U<W1O;6EZ92!M>2!$97-K=&]P)RP*"B`@("`@("`@)W5I7U]D
M87-H8F]A<F0O<VAO<G1C=70O<')O<&5R=&EE<U]?9&5S8W)I<'1I;VXG(#T^
M("=%9&ET('-H;W)T8W5T("4Q+B<L"B`@("`@("`@)W5I7U]D87-H8F]A<F0O
M<VAO<G1C=70O<')O<&5R=&EE<U]?9&]N92<@/3X@)U-H;W)T8W5T("4Q(&AA
M<R!B965N('5P9&%T960N)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9"]S:&]R
M=&-U="]P<F]P97)T:65S7U]S:&]R="UT:71L92<@/3X@)T5D:70G+`H@("`@
M("`@("=U:5]?9&%S:&)O87)D+W-H;W)T8W5T+W!R;W!E<G1I97-?7W1I=&QE
M)R`]/B`G161I="!S:&]R=&-U="`E,2<L"B`@("`@("`@)W5I7U]D87-H8F]A
M<F0O<VAO<G1C=70O<')O<&5R=&EE<U]N97=?7V1E<V-R:7!T:6]N)R`]/B`G
M0W)E871E(&YE=R!S:&]R=&-U="XG+`H@("`@("`@("=U:5]?9&%S:&)O87)D
M+W-H;W)T8W5T+W!R;W!E<G1I97-?;F5W7U]D;VYE)R`]/B`G4VAO<G1C=70@
M)3$@:&%S(&)E96X@8W)E871E9"XG+`H@("`@("`@("=U:5]?9&%S:&)O87)D
M+W-H;W)T8W5T+W!R;W!E<G1I97-?;F5W7U]S:&]R="UT:71L92<@/3X@)T-R
M96%T92!S:&]R=&-U="<L"B`@("`@("`@)W5I7U]D87-H8F]A<F0O<VAO<G1C
M=70O<')O<&5R=&EE<U]N97=?7W1I=&QE)R`]/B`G0W)E871E(&YE=R!S:&]R
M=&-U="<L"@H@("`@("`@("=U:5]?:6YD:6-A=&]R+6-L:65N=',M;G5M8F5R
M7U]D97-C<FEP=&EO;B<@/3X@)TYU;6)E<B!O9B!C;&EE;G1S+B<L"B`@("`@
M("`@)W5I7U]I;F1I8V%T;W(M8VQI96YT<RUN=6UB97)?7W-H;W)T+71I=&QE
M)R`]/B`G3G5M8F5R(&]F(&-L:65N=',G+`H@("`@("`@("=U:5]?:6YD:6-A
M=&]R+6-L:65N=',M;G5M8F5R7U]T:71L92<@/3X@)TYU;6)E<B!O9B!C;&EE
M;G1S)RP*"B`@("`@("`@)W5I7U]I;F1I8V%T;W(M8W!U7U]D97-C<FEP=&EO
M;B<@/3X@)T-052XG+`H@("`@("`@("=U:5]?:6YD:6-A=&]R+6-P=5]?<VAO
M<G0M=&ET;&4G(#T^("=#4%4G+`H@("`@("`@("=U:5]?:6YD:6-A=&]R+6-P
M=5]?=&ET;&4G(#T^("=#4%4G+`H*("`@("`@("`G=6E?7VEN9&EC871O<BUD
M:7-K+75S86=E7U]D97-C<FEP=&EO;B<@/3X@)T1I<VL@<W!A8V4@=7-A9V4N
M)RP*("`@("`@("`G=6E?7VEN9&EC871O<BUD:7-K+75S86=E7U]S:&]R="UT
M:71L92<@/3X@)T1I<VL@<W!A8V4@=7-A9V4G+`H@("`@("`@("=U:5]?:6YD
M:6-A=&]R+61I<VLM=7-A9V5?7W1I=&QE)R`]/B`G1&ES:R!S<&%C92!U<V%G
M92<L"@H@("`@("`@("=U:5]?:6YD:6-A=&]R+61O;6%I;G,M;G5M8F5R7U]D
M97-C<FEP=&EO;B<@/3X@)TYU;6)E<B!O9B!D;VUA:6YS+B<L"B`@("`@("`@
M)W5I7U]I;F1I8V%T;W(M9&]M86EN<RUN=6UB97)?7W-H;W)T+71I=&QE)R`]
M/B`G3G5M8F5R(&]F(&1O;6%I;G,G+`H@("`@("`@("=U:5]?:6YD:6-A=&]R
M+61O;6%I;G,M;G5M8F5R7U]T:71L92<@/3X@)TYU;6)E<B!O9B!D;VUA:6YS
M)RP*"B`@("`@("`@)W5I7U]I;F1I8V%T;W(M:&]S=&YA;65?7V1E<V-R:7!T
M:6]N)R`]/B`G2&]S=&YA;64N)RP*("`@("`@("`G=6E?7VEN9&EC871O<BUH
M;W-T;F%M95]?<VAO<G0M=&ET;&4G(#T^("=(;W-T;F%M92<L"B`@("`@("`@
M)W5I7U]I;F1I8V%T;W(M:&]S=&YA;65?7W1I=&QE)R`]/B`G2&]S=&YA;64G
M+`H*("`@("`@("`G=6E?7VEN9&EC871O<BUL:6-E;G-E+65X<&ER871I;VY?
M7V1E<V-R:7!T:6]N)R`]/B`G3&EC96YS92!K97D@97AP:7)A=&EO;B!D871E
M+B<L"B`@("`@("`@)W5I7U]I;F1I8V%T;W(M;&EC96YS92UE>'!I<F%T:6]N
M7U]S:&]R="UT:71L92<@/3X@)TQI8V5N<V4@:V5Y(&5X<&ER871I;VX@9&%T
M92<L"B`@("`@("`@)W5I7U]I;F1I8V%T;W(M;&EC96YS92UE>'!I<F%T:6]N
M7U]T:71L92<@/3X@)TQI8V5N<V4@:V5Y(&5X<&ER871I;VX@9&%T92<L"@H@
M("`@("`@("=U:5]?:6YD:6-A=&]R+6QI8V5N<V4M:V5Y+6ED7U]D97-C<FEP
M=&EO;B<@/3X@)TQI8V5N<V4@:V5Y(&YU;6)E<BXG+`H@("`@("`@("=U:5]?
M:6YD:6-A=&]R+6QI8V5N<V4M:V5Y+6ED7U]S:&]R="UT:71L92<@/3X@)TQI
M8V5N<V4@:V5Y(&YU;6)E<B<L"B`@("`@("`@)W5I7U]I;F1I8V%T;W(M;&EC
M96YS92UK97DM:61?7W1I=&QE)R`]/B`G3&EC96YS92!K97D@;G5M8F5R)RP*
M"B`@("`@("`@)W5I7U]I;F1I8V%T;W(M;&]A9"UA=F%R86=E7U]D97-C<FEP
M=&EO;B<@/3X@)T%V97)A9V4@;&]A9"XG+`H@("`@("`@("=U:5]?:6YD:6-A
M=&]R+6QO860M879A<F%G95]?<VAO<G0M=&ET;&4G(#T^("=!=F5R86=E(&QO
M860G+`H@("`@("`@("=U:5]?:6YD:6-A=&]R+6QO860M879A<F%G95]?=&ET
M;&4G(#T^("=!=F5R86=E(&QO860G+`H*("`@("`@("`G=6E?7VEN9&EC871O
M<BUM96TM=7-A9V5?7V1E<V-R:7!T:6]N)R`]/B`G365M;W)Y('5S86=E+B<L
M"B`@("`@("`@)W5I7U]I;F1I8V%T;W(M;65M+75S86=E7U]S:&]R="UT:71L
M92<@/3X@)TUE;6]R>2!U<V%G92<L"B`@("`@("`@)W5I7U]I;F1I8V%T;W(M
M;65M+75S86=E7U]T:71L92<@/3X@)TUE;6]R>2!U<V%G92<L"@H@("`@("`@
M("=U:5]?:6YD:6-A=&]R+6]S7U]D97-C<FEP=&EO;B<@/3X@)T]P97)A=&EN
M9R!S>7-T96TN)RP*("`@("`@("`G=6E?7VEN9&EC871O<BUO<U]?<VAO<G0M
M=&ET;&4G(#T^("=/<&5R871I;F<@<WES=&5M)RP*("`@("`@("`G=6E?7VEN
M9&EC871O<BUO<U]?=&ET;&4G(#T^("=/<&5R871I;F<@<WES=&5M)RP*"B`@
M("`@("`@)W5I7U]I;F1I8V%T;W(M=7!T:6UE7U]D97-C<FEP=&EO;B<@/3X@
M)U5P=&EM92XG+`H@("`@("`@("=U:5]?:6YD:6-A=&]R+75P=&EM95]?<VAO
M<G0M=&ET;&4G(#T^("=5<'1I;64G+`H@("`@("`@("=U:5]?:6YD:6-A=&]R
M+75P=&EM95]?=&ET;&4G(#T^("=5<'1I;64G+`H*("`@("`@("`G=6E?7VEN
M9&EC871O<BUV97)S:6]N7U]D97-C<FEP=&EO;B<@/3X@)U!L97-K('9E<G-I
M;VXN)RP*("`@("`@("`G=6E?7VEN9&EC871O<BUV97)S:6]N7U]S:&]R="UT
M:71L92<@/3X@)U!L97-K('9E<G-I;VXG+`H@("`@("`@("=U:5]?:6YD:6-A
M=&]R+79E<G-I;VY?7W1I=&QE)R`]/B`G4&QE<VL@=F5R<VEO;B<L"@H@("`@
M("`@("=U:5]?;&EC96YS95]?9&5S8W)I<'1I;VXG(#T^("=6:65W('EO=7(@
M;&EC96YS92!I;F9O+"!O<F1E<B!N97<@;&EC96YS92!K97DL(')E=')I979E
M(&%N9"!U<&QO860@8V]M;6]N(&%N9"!A9&1I=&EO;F%L(&QI8V5N<V4@:V5Y
M<RXG+`H@("`@("`@("=U:5]?;&EC96YS95]?<VAO<G0M=&ET;&4G(#T^("=,
M:6-E;G-E)RP*("`@("`@("`G=6E?7VQI8V5N<V5?7W1I=&QE)R`]/B`G36%N
M86=E(%!L97-K(&QI8V5N<V4G+`H*("`@("`@("`G=6E?7VYE=W,O9&ES;6ES
M<U]?9&5S8W)I<'1I;VXG(#T^("=#;&EC:R!T;R!C;VUP;&5T96QY(&-L;W-E
M('1H92!.97=S(&9R86UE+B!0;&5S:R!W:6QL(&YO="!S:&]W('1H:7,@9G)A
M;64@=6YT:6P@3F5W<R!A<G1I8VQE<R!A<F4@=7!D871E9"XG+`H@("`@("`@
M("=U:5]?;F5W<R]D:7-M:7-S7U]D;VYE)R`]/B`G4&QE<VL@3F5W<R!H879E
M(&)E96X@8VQO<V5D+B<L"B`@("`@("`@)W5I7U]N97=S+V1I<VUI<W-?7W1I
M=&QE)R`]/B`G0VQO<V4@;F5W<R<L"@H@("`@("`@("=U:5]?<V5R=F5R7U]D
M97-C<FEP=&EO;B<@/3X@)U-E<G9E<B!M86YA9V5M96YT+B<L"B`@("`@("`@
M)W5I7U]S97)V97)?7W-H;W)T+71I=&QE)R`]/B`G4V5R=F5R)RP*("`@("`@
M("`G=6E?7W-E<G9E<E]?=&ET;&4G(#T^("=397)V97(@;6%N86=E;65N="<L
M"@H@("`@("`@("=U:5]?<V5R=F5R+V%U=&]I;G-T86QL97)?7V1E<V-R:7!T
M:6]N)R`]/B`G57!D871E('EO=7(@8V]N=')O;"!P86YE;"!O<B!I=',@8V]M
M<&]N96YT<RXG+`H@("`@("`@("=U:5]?<V5R=F5R+V%U=&]I;G-T86QL97)?
M7W-H;W)T+71I=&QE)R`]/B`G57!D871E<B<L"B`@("`@("`@)W5I7U]S97)V
M97(O875T;VEN<W1A;&QE<E]?=&ET;&4G(#T^("=5<&1A=&5R)RP*"B`@("`@
M("`@)W5I7U]S97)V97(O:6YT97)F86-E7U]D97-C<FEP=&EO;B<@/3X@)U-E
M="!U<"!$97-K=&]P('!R97-E=',L(&EN=&5R9F%C92!T96UP;&%T97,L('-K
M:6YS(&%N9"!L;V-A;&5S+B<L"B`@("`@("`@)W5I7U]S97)V97(O:6YT97)F
M86-E7U]S:&]R="UT:71L92<@/3X@)TEN=&5R9F%C92!P<F5F97)E;F-E<R<L
M"B`@("`@("`@)W5I7U]S97)V97(O:6YT97)F86-E7U]T:71L92<@/3X@)U-E
M="!U<"!S97)V97(@:6YT97)F86-E('!R969E<F5N8V5S)RP*"B`@("`@("`@
M)W5I7U]S97)V97(O:6YT97)F86-E+V1A<VAB;V%R9"UP<F5S971S7U]D97-C
M<FEP=&EO;B<@/3X@)TUA;F%G92!$97-K=&]P('!R97-E=',N)RP*("`@("`@
M("`G=6E?7W-E<G9E<B]I;G1E<F9A8V4O9&%S:&)O87)D+7!R97-E='-?7W-H
M;W)T+71I=&QE)R`]/B`G1&5S:W1O<"!P<F5S971S)RP*("`@("`@("`G=6E?
M7W-E<G9E<B]I;G1E<F9A8V4O9&%S:&)O87)D+7!R97-E='-?7W1I=&QE)R`]
M/B`G36%N86=E($1E<VMT;W`@<')E<V5T<R<L"@H@("`@("`@("=U:5]?<V5R
M=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]D96QE=&5?7V1E<V-R
M:7!T:6]N)R`]/B`G4F5M;W9E($1E<VMT;W`@<')E<V5T<RXG+`H@("`@("`@
M("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]D96QE
M=&5?7V1O;F4G(#T^("=396QE8W1E9"!D97-K=&]P('!R97-E=',@:&%V92!B
M965N(')E;6]V960N)RP*("`@("`@("`G=6E?7W-E<G9E<B]I;G1E<F9A8V4O
M9&%S:&)O87)D+7!R97-E=',O9&5L971E7U]S:&]R="UT:71L92<@/3X@)U)E
M;6]V92<L"B`@("`@("`@)W5I7U]S97)V97(O:6YT97)F86-E+V1A<VAB;V%R
M9"UP<F5S971S+V1E;&5T95]?=&ET;&4G(#T^("=296UO=F4@1&5S:W1O<"!P
M<F5S971S)RP*("`@("`@("`G=6E?7W-E<G9E<B]I;G1E<F9A8V4O9&%S:&)O
M87)D+7!R97-E=',O9&5L971E7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G
M4F5M;W9E(&$@1&5S:W1O<"!P<F5S970G+`H@("`@("`@("=U:5]?<V5R=F5R
M+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]D96QE=&5?=6YK;F]W;E]?
M<VAO<G0M=&ET;&4G(#T^("=296UO=F4G+`H@("`@("`@("=U:5]?<V5R=F5R
M+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]D96QE=&5?=6YK;F]W;E]?
M=&ET;&4G(#T^("=296UO=F4@82!$97-K=&]P('!R97-E="<L"@H@("`@("`@
M("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]P<F5S
M970O<')O<&5R=&EE<U]?9&5S8W)I<'1I;VXG(#T^("=%9&ET($1E<VMT;W`@
M<')E<V5T("4Q+B<L"B`@("`@("`@)W5I7U]S97)V97(O:6YT97)F86-E+V1A
M<VAB;V%R9"UP<F5S971S+W!R97-E="]P<F]P97)T:65S7U]D;VYE)R`]/B`G
M1&5S:W1O<"!P<F5S970@)3$@:&%S(&)E96X@=7!D871E9"XG+`H@("`@("`@
M("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]P<F5S
M970O<')O<&5R=&EE<U]?<VAO<G0M=&ET;&4G(#T^("<E,2<L"B`@("`@("`@
M)W5I7U]S97)V97(O:6YT97)F86-E+V1A<VAB;V%R9"UP<F5S971S+W!R97-E
M="]P<F]P97)T:65S7U]T:71L92<@/3X@)T5D:70@1&5S:W1O<"!P<F5S970@
M)3$G+`H@("`@("`@("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M
M<')E<V5T<R]P<F5S970O<')O<&5R=&EE<U]N97=?7V1E<V-R:7!T:6]N)R`]
M/B`G0W)E871E(&YE=R!$97-K=&]P('!R97-E="!B87-E9"!O;B!T:&4@<')E
M<V5T("4Q+B<L"B`@("`@("`@)W5I7U]S97)V97(O:6YT97)F86-E+V1A<VAB
M;V%R9"UP<F5S971S+W!R97-E="]P<F]P97)T:65S7VYE=U]?9&]N92<@/3X@
M)T1E<VMT;W`@<')E<V5T("4Q(&AA<R!B965N(&-R96%T960N)RP*("`@("`@
M("`G=6E?7W-E<G9E<B]I;G1E<F9A8V4O9&%S:&)O87)D+7!R97-E=',O<')E
M<V5T+W!R;W!E<G1I97-?;F5W7U]S:&]R="UT:71L92<@/3X@)T-O<'D@)3$G
M+`H@("`@("`@("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E
M<V5T<R]P<F5S970O<')O<&5R=&EE<U]N97=?7W1I=&QE)R`]/B`G0V]P>2!$
M97-K=&]P('!R97-E="`E,2<L"B`@("`@("`@)W5I7U]S97)V97(O:6YT97)F
M86-E+V1A<VAB;V%R9"UP<F5S971S+W!R97-E="]P<F]P97)T:65S7VYE=U]?
M=VEZ87)D+71I=&QE)R`]/B`G1&5S:W1O<"!0<F5S970@0W)E871I;VXG+`H@
M("`@("`@("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T
M<R]P<F5S970O<')O<&5R=&EE<U]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@
M)T5D:70@82!$97-K=&]P('!R97-E="XG+`H@("`@("`@("=U:5]?<V5R=F5R
M+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]P<F5S970O<')O<&5R=&EE
M<U]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)T5D:70G+`H@("`@("`@("=U
M:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]P<F5S970O
M<')O<&5R=&EE<U]U;FMN;W=N7U]T:71L92<@/3X@)T5D:70@1&5S:W1O<"!P
M<F5S970G+`H@("`@("`@("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A
M<F0M<')E<V5T<R]P<F5S970O<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F0M
M=&ET;&4G(#T^("=%9&ET:6YG(&$@1&5S:W1O<"!P<F5S970G+`H@("`@("`@
M("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]P<F5S
M970O<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S1?=6YK;F]W;B<@/3X@
M)U-E;&5C="!W:&EC:"!$97-K=&]P('!R97-E="!Y;W4@=V%N="!T;R!E9&ET
M+B<L"@H@("`@("`@("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M
M<')E<V5T<R]U<&QO861?7V1E<V-R:7!T:6]N)R`]/B`G57!L;V%D($1E<VMT
M;W`@<')E<V5T<R!T;R!S97)V97(N)RP*("`@("`@("`G=6E?7W-E<G9E<B]I
M;G1E<F9A8V4O9&%S:&)O87)D+7!R97-E=',O=7!L;V%D7U]D;VYE)R`]/B`G
M1&5S:W1O<"!P<F5S971S(&AA=F4@8F5E;B!U<&QO861E9"XG+`H@("`@("`@
M("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]U<&QO
M861?7W-H;W)T+71I=&QE)R`]/B`G57!L;V%D)RP*("`@("`@("`G=6E?7W-E
M<G9E<B]I;G1E<F9A8V4O9&%S:&)O87)D+7!R97-E=',O=7!L;V%D7U]T:71L
M92<@/3X@)U5P;&]A9"!$97-K=&]P('!R97-E=',G+`H*("`@("`@("`G=6E?
M7W-E<G9E<B]I<"UA9&1R97-S97-?7V1E<V-R:7!T:6]N)R`]/B`G061D($E0
M(&%D9')E<W-E<R!T;R!A;F0@<F5M;W9E(&9R;VT@=&AE(&YE='=O<FL@:6YT
M97)F86-E<RXG+`H@("`@("`@("=U:5]?<V5R=F5R+VEP+6%D9')E<W-E<U]?
M<VAO<G0M=&ET;&4G(#T^("=)4"!A9&1R97-S97,G+`H@("`@("`@("=U:5]?
M<V5R=F5R+VEP+6%D9')E<W-E<U]?=&ET;&4G(#T^("=-86YA9V4@25`@861D
M<F5S<V5S)RP*"B`@("`@("`@)W5I7U]S97)V97(O;6%I;%]?9&5S8W)I<'1I
M;VXG(#T^("=#;VYF:6=U<F4@<V5R=F5R+7=I9&4@;6%I;"!S>7-T96TN)RP*
M("`@("`@("`G=6E?7W-E<G9E<B]M86EL7U]S:&]R="UT:71L92<@/3X@)TUA
M:6PG+`H@("`@("`@("=U:5]?<V5R=F5R+VUA:6Q?7W1I=&QE)R`]/B`G4V5R
M=F5R+7=I9&4@;6%I;"!P<F5F97)E;F-E<R<L"@H@("`@("`@("=U:5]?<V5R
M=F5R+W!R969E<F5N8V5S7U]D97-C<FEP=&EO;B<@/3X@)U-E="!U<"!S97)V
M97(@<')E9F5R96YC97,N)RP*("`@("`@("`G=6E?7W-E<G9E<B]P<F5F97)E
M;F-E<U]?9&]N92<@/3X@)U-E<G9E<B!P<F5F97)E;F-E<R!H879E(&)E96X@
M=7!D871E9"XG+`H@("`@("`@("=U:5]?<V5R=F5R+W!R969E<F5N8V5S7U]S
M:&]R="UT:71L92<@/3X@)U!R969E<F5N8V5S)RP*("`@("`@("`G=6E?7W-E
M<G9E<B]P<F5F97)E;F-E<U]?=&ET;&4G(#T^("=397)V97(@<')E9F5R96YC
M97,G+`H*("`@("`@("`G=6E?7W-E<G9E<B]S97)V:6-E<U]?9&5S8W)I<'1I
M;VXG(#T^("=3=&%R="P@<W1O<"!O<B!R97-T87)T(&-O;G1R;VP@<&%N96P@
M<V5R=FEC97,N)RP*("`@("`@("`G=6E?7W-E<G9E<B]S97)V:6-E<U]?<VAO
M<G0M=&ET;&4G(#T^("=397)V:6-E<R<L"B`@("`@("`@)W5I7U]S97)V97(O
M<V5R=FEC97-?7W1I=&QE)R`]/B`G36%N86=E('-E<G9I8V5S)RP*"B`@("`@
M("`@)W5I7U]S97)V97(O<W1A=&ES=&EC<U]?9&5S8W)I<'1I;VXG(#T^("=6
M:65W('-Y<W1E;2!S=&%T:7-T:6-S+B<L"B`@("`@("`@)W5I7U]S97)V97(O
M<W1A=&ES=&EC<U]?<VAO<G0M=&ET;&4G(#T^("=S=&%T:7-T:6-S)RP*("`@
M("`@("`G=6E?7W-E<G9E<B]S=&%T:7-T:6-S7U]T:71L92<@/3X@)U-Y<W1E
M;2!S=&%T:7-T:6-S)RP*"B`@("`@("`@)W5I7U]S=7!P;W)T7U]D97-C<FEP
M=&EO;B<@/3X@)U-U8FUI="!A(')E<75E<W0@9F]R(%!L97-K('1E8VAN:6-A
M;"!S=7!P;W)T+B<L"B`@("`@("`@)W5I7U]S=7!P;W)T7U]D;VYE)R`]/B`G
M5&5C:&YI8V%L('-U<'!O<G0@<&%G92!H87,@8F5E;B!O<&5N960N)RP*("`@
M("`@("`G=6E?7W-U<'!O<G1?7W-H;W)T+71I=&QE)R`]/B`G4W5P<&]R="<L
M"B`@("`@("`@)W5I7U]S=7!P;W)T7U]T:71L92<@/3X@)U1E8VAN:6-A;"!S
M=7!P;W)T)RP*"B`@("`@("`@+R\@*BHJ(%1H92!S=')I;F=S(&%B;W9E(&AA
M=F4@8F5E;B!G96YE<F%T960@875T;VUA=&EC86QL>2!F<F]M($!`0T%05$E/
M3B!D:7)E8W1I=F5S+@H*"2\O(&%K<W,@<&%R=`H*"2=?7U]?9&5T86EL<R<@
M/3X@)R@E,2DG+`H))U]?7U]L:7-T7V5M<'1Y)R`]/B`G)RP*"2=?7U]?;&ES
M=%]F:7)S=%]I=&5M)R`]/B`G)3$G+`H))U]?7U]L:7-T7VET96TG(#T^("<L
M("4Q)RP*"2=?7U]?;&ES=%]L87-T7VET96TG(#T^("<L("4Q)RP*"@DG7U]S
M:&]W7VAI9&5?=&ET;&4G(#T^("=-:6YI;6EZ92]297-T;W)E)RP*"2=?7U50
M3$]!1%]%4E)?1D]235]325I%)R`]/B`B57!L;V%D960@9FEL92!E>&-E961S
M('1H92!A;&QO=V5D('-I>F4@;V8@)3$B+`H))U]?55!,3T%$7T524E])3DE?
M4TE:12<@/3X@(E5P;&]A9&5D(&9I;&4@97AC965D<R!T:&4@86QL;W=E9"!S
M:7IE(BP*"2=?7U503$]!1%]%4E)?3D]?1DE,12<@/3X@(DYO(&9I;&4@<F5C
M96EV960B+`H))U]?55!,3T%$7T524E]/2R<@/3X@(D9I;&4@<W5C8V5S<V9U
M;&QY('5P;&]A9&5D(BP*"2=?7U503$]!1%]%4E)?4$%25$E!3"<@/3X@(D9I
M;&4@=V%S('!A<G1I86QL>2!U<&QO861E9"P@<&QE87-E('1R>2!A9V%I;B(L
M"@DG7U]A9&UI;E]S97)V97)?;F]T7W)E<W!O;F0G(#T^("))9B`E,2!D;V5S
M(&YO="!R97-P;VYD+"!P;&5A<V4@86-C97-S('1H92!S97)V97(@86YD(')E
M<W1A<G0@=&AE(&%D;6EN:7-T<F%T:79E('=E8B!S97)V97(@96YG:6YE(&UA
M;G5A;&QY+B(L"@DG7U]A8V-O=6YT<R<@/3X@(D%C8V]U;G1S(BP*"2=?7V%D
M9')E<W,G(#T^(")!9&1R97-S(BP*"2=?7V%D9')E<W-E<R<@/3X@(D%D9')E
M<W-E<R(L"@DG7U]A8VQ?<F5C;W)D<R<)/3X@)T%#3"!296-O<F1S)RP*"2=?
M7V%D;6EN7W)E<&]S:71O<GDG(#T^(")!9&UI;FES=')A=&]R)W,@<F5P;W-I
M=&]R>2(L"@DG7U]A;&PG(#T^(")!3$PB+`H))U]?86QL;W=?;75L=&EP;'E?
M;&]G:6XG(#T^(")!;&QO=R!M=6QT:7!L92!S97-S:6]N<R(L"@DG7U]A;&QO
M=V5D)R`]/B`B06QL;W=E9"(L"@DG7U]A;F]N9G1P7W-T871U<R<@/3X@(D%N
M;VYY;6]U<R!&5%`B+`H))U]?87!A8VAE7V5R<F1O8W,G(#T^(")#=7-T;VT@
M17)R;W(@1&]C=6UE;G1S(BP*"2=?7V%P86-H95]R97-T87)T)R`]/B`B+BXN
M)3$@=V5B+7-E<G9E<B!I<R!B96EN9R!R97-T87)T960L('!L96%S92!W86ET
M+BXN(BP*"2=?7V%S<"<@/3X@(DUI8W)O<V]F="!!4U`B+`H))U]?87-P7V1O
M=%]N970G(#T^(")-:6-R;W-O9G0@05-0+DY%5"(L"@DG7U]A<W!?9&]T7VYE
M=%]S=7!P;W)T)R`]/B`B36EC<F]S;V9T($%34"Y.150@<W5P<&]R="(L"@DG
M7U]A<W!?=6YI>%]S=7!P;W)T)R`]/B`B07!A8VAE($%34"!S=7!P;W)T(BP*
M"2=?7V%S<%]W:6Y?<W5P<&]R="<@/3X@(DUI8W)O<V]F="!!4U`@<W5P<&]R
M="(L"@DG7U]A='1A8VAM96YT<R<@/3X@(D%T=&%C:&UE;G1S(BP*"2=?7V%T
M=&%C:&UE;G1S7VQI<W0G(#T^(")!='1A8VAM96YT<R(L"@DG7U]A=71H;W(G
M(#T^("=!=71H;W(G+`H))U]?875T;W)E<W!?;F%M95]A;')E861Y7V5X:7-T
M<R<@/3X@(D%U=&]R97-P;VYD97(@=VET:"!N86UE("4Q(&%L<F5A9'D@97AI
M<W1S+B(L"@DG7U]A=71O<F5S<&]N9&5R)R`]/B`B075T;W)E<W!O;F1E<B`@
M(BP*"2=?7V%U=&]R97-P;VYD97)S)R`]/B`B075T;W)E<W!O;F1E<G,B+`H)
M)U]?875T;W)E<W!O;F1E<G-?;&ES="<@/3X@(D%U=&]R97-P;VYD97)S(BP*
M"2=?7V%U=&]R97-P;VYD97)?871T86-H;65N=%]F:6QE<R<@/3X@(D%U=&]R
M97-P;VYD97(@071T86-H;65N="!&:6QE<R(L"@DG7U]A=71O7W5P9&%T97-?
M;&ES="<@/3X@)T%V86EL86)L92!5<&1A=&5S)RP*"2=?7V%V86EL)R`]/B`B
M079A:6QA8FQE(BP*"2=?7V)I;F1?<W1A='5S)R`]/B`B1$Y3(%-E<G9E<B!S
M=&%T=7,B+`H))U]?8G5?:7-?;F]T7VEN<W1A;&QE9"<@/3X@(E1H:7,@<V5R
M=FEC92!I<R!N;W0@8W5R<F5N=&QY(&%V86EL86)L92P@8F5C875S92!T:&4@
M8F%C:W5P('5T:6QI=&EE<R!W97)E(&YO="!I;G-T86QL960N(BP*"2=?7V)U
M7VYO=%]S=7!P;W)T7VEN7VME>2<@/3X@(D)A8VMU<"!C87!A8FEL:71Y(&ES
M(&YO="!S=7!P;W)T960@8GD@=&AE(&QI8V5N<V4@:V5Y+B(L"@DG7U]B>71E
M<R<@/3X@(F)Y=&5S(BP*"2=?7V-A;E]N;W1?=7-E7W)E<V5R=F5D7W=O<F1S
M)R`]/B`B66]U(&-A;FYO="!U<V4@=&AE(')E<V5R=F5D('=O<F1S+B(L"@DG
M7U]C97)T:69I8V%T92<@/3X@(D-E<G1I9FEC871E(BP*"2=?7V-E<G1I9FEC
M871E<R<@/3X@(D-E<G1I9FEC871E<R(L"@DG7U]C97)T:69I8V%T97-?;&ES
M="<@/3X@(D-E<G1I9FEC871E<R(L"@DG7U]C9VE?<W5P<&]R="<@/3X@(D-'
M22!S=7!P;W)T(BP*"2=?7V-H86YG95]D871E)R`]/B`B36]D:69I8V%T:6]N
M(&1A=&4B+`H))U]?8VAO;W-E7VQO9V\G(#T^(")#:&]O<V4@;F5W(&QO9V\@
M9FEL92(L"@DG7U]C:71Y)R`]/B`B0VET>2(L"@DG7U]C;%]N;W1?97AI<W0G
M(#T^(")#;&EE;G0@86-C;W5N="!D;V5S(&YO="!E>&ES="XB+`H))U]?8VQI
M96YT)R`]/B`B0VQI96YT(BP*"2=?7V-L:65N=%]C87)D)R`]/B`B0VQI96YT
M(&-A<F0B+`H))U]?8VQI96YT7V-O;G1A8W1?;F%M92<@/3X@(D-L:65N="!C
M;VYT86-T(&YA;64B+`H))U]?8VQI96YT7V9O<FTG(#T^(")#;&EE;G0@9F]R
M;2(L"@DG7U]C;&EE;G1?:7!?<&]O;"<@/3X@(D-L:65N="=S($E0('!O;VPB
M+`H))U]?8VQI96YT7VQI;6ET<R<@/3X@(D-L:65N="!A8V-O=6YT(&QI;6ET
M<R(L"@DG7U]C;&EE;G1?<&5R;6ES<VEO;G,G(#T^(")#;&EE;G0@<&5R;6ES
M<VEO;G,B+`H))U]?8VQI96YT7W!R969E<F5N8V5S)R`]/B`B0VQI96YT('!R
M969E<F5N8V5S(BP*"2=?7V-L:65N=%]S=&%T=7,G(#T^(")#;&EE;G0@<W1A
M='5S(BP*"2=?7V-L:65N=%]N86UE)R`]/B`B0VQI96YT)W,@;F%M92(L"@DG
M7U]C;&EE;G1?=&]T86PG(#T^(")#;&EE;G0@5&]T86PB+`H))U]?8VQI96YT
M7W=I=&A?;&]G:6Y?;F%M95]A;')E861Y7V5X:7-T<R<@/3X@(D-L:65N="!W
M:71H(&QO9VEN(&YA;64@7"(E,5PB(&%L<F5A9'D@97AI<W1S+B(L"@DG7U]C
M;&EE;G1?9&]M=7-E<E]W:71H7VQO9VEN7V%L<F5A9'E?97AI<W1S)R`]/B`B
M3&]G:6X@;F%M92`G)3$G(&ES(&%L<F5A9'D@:6X@=7-E(&)Y('1H92!A9&UI
M;FES=')A=&]R(&]F(&1O;6%I;B`G)3$G+B(L"@DG7U]C;&EE;G1S)R`]/B`B
M0VQI96YT<R(L"@DG7U]C;&EE;G1S7V=L;V)A;%]C:&%N9V5S)R`]/B`B1W)O
M=7`@3W!E<F%T:6]N<R!O;B!#;&EE;G0@06-C;W5N=',B+`H))U]?8VQI96YT
M<U]L:7-T)R`]/B`B0VQI96YT<R(L"@DG7U]C;61?;F]T7V9O=6YD)R`]/B`B
M56YK;F]W;B!C;VUM86YD.B`E,2(L"@DG7U]C;VQD9G5S:6]N7VYO=%]S=7!P
M;W)T7VEN7VME>2<@/3X@(D-O;&1&=7-I;VX@:7,@;F]T('-U<'!O<G1E9"!B
M>2!T:&4@;&EC96YS92!K97DB+`H))U]?8V]L9&9U<VEO;E]S=&%T=7,G(#T^
M("=#;VQD1G5S:6]N('-T871U<R<L"@DG7U]C;VQD9G5S:6]N7W-U<'!O<G0G
M(#T^(")#;VQD1G5S:6]N('-U<'!O<G0B+`H))U]?8V]M;6%N9"<@/3X@)T-O
M;6UA;F0G+`H))U]?8V]M;65N=',G(#T^(")#;VUM96YT<R(L"@DG7U]C;VUP
M86YY7VYA;64G(#T^(")#;VUP86YY(&YA;64B+`H))U]?8V]M<&]N96YT7W9E
M<G-I;VXG(#T^(")#;VUP;VYE;G0@=F5R<VEO;B(L"@DG7U]A;&QO=U]Z;VYE
M7W1R86YS9F5R7VQI<W0G(#T^("=#;VUM;VX@06QL;W<@6F]N92!4<F%N<V9E
M<B!!0TPG+`H))U]?8V]M<&]N96YT7VYO=%]I;G-T86QL960G(#T^(")#;VUP
M;VYE;G0@)3$@=V%S(&YO="!I;G-T86QL960B+`H))U]?8V]N9FER;5]D96PG
M(#T^(")9;W4@;75S="!C;VYF:7)M(&1E;&5T:6]N+B(L"@DG7U]C;VYF:7)M
M7W-T;W`G(#T^(")9;W4@;75S="!C;VYF:7)M('!R;V-E<W,@<W1O<'!I;F<N
M(BP*"2=?7V-O;F9I<FU?<&%S<W=D)R`]/B`B0V]N9FER;2`E,2!087-S=V]R
M9"(L"@DG7U]C;VYF:7)M7W!A<W-W9%]S:6YG;&4G(#T^(")#;VYF:7)M(%!A
M<W-W;W)D(BP*"2=?7V-O;F9I<FU?<F5M;W9A;"<@/3X@(D-O;F9I<FT@<F5M
M;W9A;"(L"@DG7U]C;VYH96QP)R`]/B`B0V]N=&5X="!H96QP('1I<"(L"@DG
M7U]C;VYT86-T7VYA;64G(#T^(")#;VYT86-T(&YA;64B+`H))U]?8V]U;G1R
M>2<@/3X@(D-O=6YT<GDB+`H))U]?8V]U;G1R:65S)R`]/B`G0V]U;G1R>2<L
M"@DG7U]C;W5N=')Y7W5N:VYO=VXG(#T^("=5;F%B;&4@=&\@<F5C;V=N:7IE
M('1H92!C;W5N=')Y('-U8F-O9&4N)RP*"2=?7V-R96%T95]D;VUA:6XG(#T^
M("=#<F5A=&4@;F5W(&1O;6%I;B<L"@DG7U]C<GEP=&5D)R`]/B`G96YC<GEP
M=&5D)RP*"2=?7V-P7V%C8V5S<R<@/3X@(D-O;G1R;VP@<&%N96P@86-C97-S
M(BP*"2=?7V-P7W5S97(G(#T^(")#;VYT<F]L(%!A;F5L(%5S97(B+`H))U]?
M8W)E871E)R`]/B`B0W)E871E(BP*"2=?7V-R96%T95]C;&EE;G1?=&5M<&QA
M=&5?=VET:&]U=%]T96UP;&%T92<@/3X@(D-R96%T92!C;&EE;G0@=VET:&]U
M="!T96UP;&%T92(L"@DG7U]C<F5A=&5?9&]M86EN7V9O<B<@/3X@(D-R96%T
M92!N97<@9&]M86EN(&9O<B`\8CXE,3PO8CXB+`H))U]?8W)E871E7V1O;6%I
M;E]T96UP;&%T95]W:71H;W5T7W1E;7!L871E)R`]/B`B0W)E871E(&1O;6%I
M;B!W:71H;W5T('1E;7!L871E(BP*"2=?7V-R96%T:6]N7V1A=&4G(#T^(")#
M<F5A=&EO;B!D871E(BP*"2=?7V-R;VYT86)?=6YI>"<@/3X@(D-R;VYT86(B
M+`H))U]?8W)O;G1A8E]W:6XG(#T^(")38VAE9'5L97(B+`H))U]?8W1?8VUD
M)R`]/B`B0V]M;6%N9"(L"@DG7U]C=%]D;VTG(#T^(")$87D@;V8@=&AE($UO
M;G1H(BP*"2=?7V-T7V1O;5\G(#T^(")$32(L"@DG7U]C=%]D;W<G(#T^(")$
M87D@;V8@=&AE(%=E96LB+`H))U]?8W1?9&]W7R<@/3X@(D17(BP*"2=?7V-T
M7V5N86)L960G(#T^(")3=&%T=7,B+`H))U]?8W1?96YA8FQE9%\G(#T^(")3
M(BP*"2=?7V-T7VAO=7(G(#T^(")(;W5R(BP*"2=?7V-T7VAO=7)?)R`]/B`B
M2"(L"@DG7U]C=%]M:6YU=&4G(#T^(")-:6YU=&4B+`H))U]?8W1?;6EN=71E
M7R<@/3X@(DUI;B(L"@DG7U]C=%]M;VYT:"<@/3X@(DUO;G1H(BP*"2=?7V-T
M7VUO;G1H7R<@/3X@(DTB+`H))U]?8W1?;6]N=&A?96YT97)?861V)R`]/B`B
M16YT97(@=&AE('9A;'5E(BP*"2=?7V-T7VAI;G1?=6YI>%]F;W)M870G(#T^
M(")I;B!53DE8(&-R;VYT86(@9F]R;6%T(&4N9RXB+`H))U]?8W1?;6]N=&A?
M96YT97(G(#T^(")396QE8W0@=&AE(&UO;G1H(BP*"2=?7V-T7V1O=U]E;G1E
M<E]A9'8G(#T^(")%;G1E<B!T:&4@=F%L=64B+`H))U]?8W1?9&]W7V5N=&5R
M)R`]/B`B4V5L96-T('1H92!D87D@;V8@=V5E:R(L"@DG7U]C=%]M;VYT:%]J
M86XG(#T^("=*86YU87)Y)RP*"2=?7V-T7VUO;G1H7V9E8B<@/3X@)T9E8G)U
M87)Y)RP*"2=?7V-T7VUO;G1H7VUA<B<@/3X@)TUA<F-H)RP*"2=?7V-T7VUO
M;G1H7V%P<B<@/3X@)T%P<FEL)RP*"2=?7V-T7VUO;G1H7VUA>2<@/3X@)TUA
M>2<L"@DG7U]C=%]M;VYT:%]J=6XG(#T^("=*=6YE)RP*"2=?7V-T7VUO;G1H
M7VIU;"<@/3X@)TIU;'DG+`H))U]?8W1?;6]N=&A?875G)R`]/B`G075G=7-T
M)RP*"2=?7V-T7VUO;G1H7W-E<"<@/3X@)U-E<'1E;6)E<B<L"@DG7U]C=%]M
M;VYT:%]O8W0G(#T^("=/8W1O8F5R)RP*"2=?7V-T7VUO;G1H7VYO=B<@/3X@
M)TYO=F5M8F5R)RP*"2=?7V-T7VUO;G1H7V1E8R<@/3X@)T1E8V5M8F5R)RP*
M"2=?7V-T7V1O=U]S=6XG(#T^("=3=6YD87DG+`H))U]?8W1?9&]W7VUO;B<@
M/3X@)TUO;F1A>2<L"@DG7U]C=%]D;W=?='5E)R`]/B`G5'5E<V1A>2<L"@DG
M7U]C=%]D;W=?=V5D)R`]/B`G5V5D;F5S9&%Y)RP*"2=?7V-T7V1O=U]T:'4G
M(#T^("=4:'5R<V1A>2<L"@DG7U]C=%]D;W=?9G)I)R`]/B`G1G)I9&%Y)RP*
M"2=?7V-T7V1O=U]S870G(#T^("=3871U<F1A>2<L"@DG7U]C=7-T;VU?8G5T
M=&]N)R`]/B`B0W5S=&]M(&)U='1O;B(L"@DG7U]C=7-T;VU?8G5T=&]N<R<@
M/3X@(D-U<W1O;2!B=71T;VYS(BP*"2=?7V-U<W1O;5]B=71T;VYS7VQI<W0G
M(#T^(")#=7-T;VT@8G5T=&]N<R(L"@DG7U]D86EL>2<@/3X@(D1A:6QY(BP*
M"2=?7V1A;&EA<U]N;W1?97AI<W0G(#T^("=$;VUA:6X@86QI87,@9&]E<R!N
M;W0@97AI<W0N)RP*"2=?7V1A=&%B87-E7VYO=%]A8W1I=F%T960G(#T^("(E
M,2!W87,@;F]T(&%C=&EV871E9"!I;B!T:&4@<V5R=F5R(&%D;6EN:7-T<F%T
M:6]N('-E8W1I;VXN(BP*"2=?7V1A=&%B87-E7VYO=%]I;G-T86QL960G(#T^
M(")$871A8F%S92`E,2!I<R!N;W0@:6YS=&%L;&5D+B(L"@DG7U]D871A8F%S
M95]N;W1?<G5N)R`]/B`B1&%T86)A<V4@)3$@:7,@;F]T(')U;FYI;F<N(BP*
M"2=?7V1A=&%B87-E<R<@/3X@(D1A=&%B87-E<R(L"@DG7U]D871A8F%S97-?
M;&ES="<@/3X@(D1A=&%B87-E<R(L"@DG7U]D871A8F%S95]T>7!E7VYO=%]S
M=7!P;W)T961?8GE?:V5Y)R`]/B`G5&AI<R!T>7!E(&]F(&1A=&%B87-E(&ES
M(&YO="!S=7!P;W)T960@8GD@>6]U<B!L:6-E;G-E(&ME>2<L"@DG7U]D871E
M7VEM;65D:6%T96QY)R`]/B`B=&]D87DB+`H))U]?9&%T95]N979E<B<@/3X@
M(FYE=F5R(BP*"2=?7V1A>2AS*2<@/3X@(D1A>2AS*2(L"@DG7U]D87DP)R`]
M/B`B4W5N(BP*"2=?7V1A>3$G(#T^(")-;VXB+`H))U]?9&%Y,B<@/3X@(E1U
M97,B+`H))U]?9&%Y,R<@/3X@(E=E9"(L"@DG7U]D87DT)R`]/B`B5&AU<G,B
M+`H))U]?9&%Y-2<@/3X@(D9R:2(L"@DG7U]D87DV)R`]/B`B4V%T(BP*"2=?
M7V1A>7,G(#T^("(E,2!D87DH<RDB+`H))U]?1&%Y<R<@/3X@(D1A>7,B+`H)
M)U]?9&)?861M:6Y?;&]G:6Y?96UP='DG(#T^(")9;W4@:&%V92!E;G1E<F5D
M(&%N(&5M<'1Y(&QO9VEN+"!D:7-A8FQI;F<@8V]N=')O;"!O=F5R("4Q(&EN
M('1H92!I;G1E<F9A8V4N($1O('EO=2!W86YT('1O('!R;V-E960_(BP*"2=?
M7V1B7V%L<F5A9'E?97AI<W0G(#T^(")$871A8F%S92`E,2!A;')E861Y(&5X
M:7-T<RXB+`H))U]?9&)?96YG:6YE)R`]/B`B1&%T86)A<V4@16YG:6YE(BP)
M+R\@:6YD:7)E8W0*"2=?7V1B7W1Y<&4G(#T^(")$871A8F%S92!T>7!E(BP*
M"2=?7V1B7W5S97(G(#T^(")$871A8F%S92!U<V5R(BP*"2=?7V1B7W5S97)S
M)R`]/B`B1&%T86)A<V4@=7-E<G,B+`H))U]?9&)?<V5R=F5R)R`]/B`G1&%T
M86)A<V4@<V5R=F5R)RP*"2=?7V1E8W)E;65N="<@/3X@(D1E8W)E87-E("@M
M*2(L"2\O(&EN9&ER96-T"@DG7U]D969?9&]M86EN)R`]/B`B1&5F875L="!D
M;VUA:6XB+`H))U]?9&5F875L=%]F;W)?;7ES<6PG(#T^("=D969A=6QT(&9O
M<B!->5-13"<L"@DG7U]D969A=6QT7V9O<E]P;W-T9W)E<W%L)R`]/B`G9&5F
M875L="!F;W(@4&]S=&=R95-13"<L"@DG7U]D96QE=&4G(#T^(")$96QE=&4B
M+`H))U]?9&5M;R<@/3X@(E1H:7,@9G5N8W1I;VX@:7,@9&ES86)L960@:6X@
M9&5M;R!V97)S:6]N+B(L"@DG7U]D:7)E8W1O<GDG(#T^(")$:7)E8W1O<GDB
M+`H))U]?9&ES86)L95]L;V-K7W-C<F5E;B<@/3X@)U!R979E;G0@=7-E<G,@
M9G)O;2!W;W)K:6YG('=I=&@@=&AE(&-O;G1R;VP@<&%N96P@=6YT:6P@:6YT
M97)F86-E('-C<F5E;G,@87)E(&-O;7!L971E;'D@;&]A9&5D+B<L"@DG7U]D
M:7-M:7-S7VYE=W,_)R`]/B`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(&-O
M;7!L971E;'D@:&ED92!T:&4@;F5W<R!B;&]C:S]<;EQN5&AE(&YE=W,@=VEL
M;"!N;W0@8F4@<VAO=VX@86YY;6]R92!U;G1I;"!T:&5R92!I<R!S;VUE(&UO
M<F4@;F5W<R!S;VUE9&%Y+B!)9B!Y;W4@=V]U;&0@<F%T:&5R(&QI:V4@=&\@
M<V5E('1H97-E(&YE=W,@86=A:6X@<V]M971I;64L('EO=2!C86X@;6EN:6UI
M>F4@=&AE(&)L;V-K(&EN<W1E860@8GD@8VQI8VMI;F<@;VX@:71S('1I=&QE
M(&)A<BXB+`H))U]?9&5F875L=%]B86-K=7!?8V]M;65N="<@/3X@(B4Q(&)A
M8VMU<"Y<;D-R96%T:6]N(&1A=&4Z("4R(BP*"2=?7V1E<V-R:7!T:6]N)R`]
M/B`B1&5S8W)I<'1I;VXB+`H))U]?9&ES86)L960G(#T^(")D:7-A8FQE9"(L
M"@DG7U]D:7-K7W-P86-E7VQI;6ET)R`]/B`B1&ES:R!S<&%C92!L:6UI="(L
M"@DG7U]D:7-K7W5S86=E7V)Y)R`]/B`B1&ES:R!S<&%C92!U<V5D(&)Y("4Q
M(BP*"2=?7V1N<R<@/3X@(D1.4R(L"@DG7U]D;G-?<F5C;W)D7V%L<F5A9'E?
M97AI<W0G(#T^(")$3E,@<F5C;W)D(&%L<F5A9'D@97AI<W1S+B(L"@DG7U]D
M;G-?;6%S=&5R7W-H;W5L9%]B95]R96UO=&4G(#T^(")9;W4@<VAO=6QD(&AA
M=F4@='=O(&1I9F9E<F5N="!A=71H;W)I=&%T:79E(&YA;64@<V5R=F5R<R!O
M;B!S97!A<F%T92!H;W-T<RXB+`H))U]?9&YS7W)E8V]R9%]N;W1?97AI<W0G
M(#T^(")$3E,@<F5C;W)D(&1O97,@;F]T(&5X:7-T+B(L"@DG7U]D;G-?<V5R
M=F5R)R`]/B`B1$Y3('-E<G9E<B(L"2\O(&EN9&ER96-T"@DG7U]D;VU?:61?
M:7-?=6YD969I;F5D)R`]/B`B1&]M86EN(&ED(&ES('5N9&5F:6YE9"XB+`H)
M)U]?9&]M7VYA;64G(#T^(")$;VUA:6X@;F%M92(L"@DG7U]D;VU?;F%M95]I
M<U]I;G9A;&ED)R`]/B`B1&]M86EN(&YA;64@:7,@:6YV86QI9"X@4&QE87-E
M(&UA:V4@<W5R92!Y;W5R(&1O;6%I;B!N86UE(&-O;7!R:7-E<R!O;FQY(&%L
M<&AA;G5M97)I8RP@9&]T(&%N9"!H>7!H96X@<WEM8F]L<RP@86YD(&ES(&YO
M="!G<F5A=&5R('1H86X@,C4U('-Y;6)O;',@:6X@;&5N9W1H+B!%86-H('!A
M<G0@;V8@=&AE(&1O;6%I;B!N86UE(&)E='=E96X@9&]T<R!S:&]U;&0@;F]T
M(&5X8V5E9"`V,R!S>6UB;VQS+B(L"@DG7U]D;VU?;F]T7V5X:7-T)R`]/B`B
M1&]M86EN(&1O97,@;F]T(&5X:7-T+B(L"@DG7U]D;VUA:6XG(#T^(")$;VUA
M:6X@)3$B+`H))U]?9&]M86EN7V9O<FTG(#T^(")$;VUA:6X@9F]R;2(L"@DG
M7U]D;VUA:6Y?:7-?='5R;F5D7V]F9E]F;W)?8F%C:W5P)R`]/B`B1&]M86EN
M("4Q(&ES('1E;7!O<F%R:6QY('1U<FYE9"!O9F8@9F]R(&)A8VMU<"]R97-T
M;W)I;F<@86YD(&ES(&YO="!C=7)R96YT;'D@879A:6QA8FQE+B(L"@DG7U]D
M;VUA:6Y?;&EM:71S)R`]/B`B1&]M86EN(&QI;6ET<R(L"@DG7U]D;VUA:6Y?
M;F%M92<@/3X@(D1O;6%I;B!N86UE(BP*"2=?7VUA:6Q?;F%M95]I;E]!4T-)
M25]F;W)M)R`]/B`B36%I;"!N86UE(&EN($%30TE)(&9O<FUA="(L"@DG7U]M
M97-S86=E7V5R<F]R)R`]/B`G17)R;W(G+`H))U]?;65S<V%G95]W87)N:6YG
M)R`]/B`G5V%R;FEN9R<L"@DG7U]M97-S86=E7VEN9F\G(#T^("=);F9O<FUA
M=&EO;B<L"@DG7U]D;VUA:6Y?;F%M95]I;E]!4T-)25]F;W)M)R`]/B`B1&]M
M86EN(&YA;64@:6X@05-#24D@9F]R;6%T(BP*"2=?7V1O;6%I;E]R97!O<VET
M;W)Y)R`]/B`B4F5P;W-I=&]R>2!O9B!D;VUA:6X@)3$B+`H))U]?9&]M86EN
M7W-T871U<R<@/3X@(D1O;6%I;B!S=&%T=7,B+`H))U]?9&]M86EN7V1N<R<@
M/3X@)T1O;6%I;B!$3E,@>F]N92<L"@DG7U]D;VUA:6Y?=&]T86PG(#T^(")$
M;VUA:6X@5&]T86PB+`H))U]?9&]M86EN7W5S97(G(#T^(")$;VUA:6X@861M
M:6YI<W1R871O<B(L"@DG7U]D;VUA:6YS)R`]/B`B1&]M86EN<R(L"@DG7U]D
M;VUA:6YS7V=L;V)A;%]C:&%N9V5S)R`]/B`B1W)O=7`@3W!E<F%T:6]N<R!O
M;B!$;VUA:6YS(BP*"2=?7VUA:6QN86UE<U]G;&]B86Q?8VAA;F=E<R<@/3X@
M(D=R;W5P($]P97)A=&EO;G,@;VX@36%I;"!.86UE<R(L"@DG7U]M:6=R871I
M;VY?;6%N86=E<B<@/3X@)TUI9W)A=&EO;B!-86YA9V5R)RP*"2=?7V)A8VMU
M<%]M86YA9V5R)R`]/B`G0F%C:W5P($UA;F%G97(G+`H))U]?9&]M86EN<U]L
M:7-T)R`]/B`B1&]M86EN<R(L"@DG7U]D;VUA:6Y?<F5S;VQV97-?=&]?86YO
M=&AE<E]I<"<@/3X@(E1H92!D;VUA:6X@<F5S;VQV97,@=&\@86YO=&AE<B!)
M4"!A9&1R97-S("@E,2DN(%!L96%S92!C;W)R96-T($1.4R!S971T:6YG<RXB
M+`H))U]?9&]U8FQE7W=W=U]W87)N:6YG)R`]/B`B5&AE(&1O;6%I;B!N86UE
M(&)E9VEN<R!W:71H('=W=RP@86QT:&]U9V@@=&AE(%=75R!P<F5F:7@@:7,@
M96YA8FQE9"Y<;E!R;V-E960@86YY=V%Y/R(L"@DG7U]D<VUA:6PG(#T^(")-
M86EL('-E<G9I8V4B+`H))U]?9'-M86EL;&ES="<@/3X@(DUA:6QI;F<@;&ES
M="!S97)V:6-E(BP*"2=?7V1S<E]D8B<@/3X@(D1"(BP*"2=?7V1S<E]D;F%M
M92<@/3X@(D1O;6%I;B!N86UE(BP*"2=?7V1S<E]D=2<@/3X@(D15(BP*"2=?
M7V1S<E]M82<@/3X@(DU!(BP*"2=?7V1S<E]M9R<@/3X@(DU'(BP*"2=?7V1S
M<E]M;"<@/3X@(DU,(BP*"2=?7V1S<E]M;B<@/3X@(DU";W@B+`H))U]?9'-R
M7VUR)R`]/B`B35(B+`H))U]?9'-R7W!N86UE)R`]/B`B0VQI96YT)W,@;F%M
M92(L"@DG7U]D<W)?<V0G(#T^(")31"(L"@DG7U]D<W)?='(G(#T^(")44B(L
M"@DG7U]D<W)?=W4G(#T^(")752(L"@DG7U]D<W1O;6-A="<@/3X@(E1O;6-A
M="!S97)V:6-E(BP*"2=?7V1U;7!?;F%M92<@/3X@(D)A8VMU<"!F:6QE(&YA
M;64B+`H))U]?9'5M<'-?=&]T7W-I>F4G(#T^(")4;W1A;"!S:7IE(&]F(&)A
M8VMU<"!F:6QE<R(L"@DG7U]E;6%I;"<@/3X@(D4M;6%I;"(L"@DG7U]E;6%I
M;%]A9&1R7VES7VEN=F%L:60G(#T^(")%+6UA:6P@861D<F5S<R!I<R!I;G9A
M;&ED+B(L"@DG7U]E;F%B;&5D)R`]/B`B96YA8FQE9"(L"@DG7U]E;G1E<E]C
M97)T7W1E>'0G(#T^(")%;G1E<B!C97)T:69I8V%T92!T97AT(BP*"2=?7V5N
M=&5R7VQO9V]?=7)L)R`]/B`B16YT97(@;F5W(%523"!F;W(@;&]G;R(L"@DG
M7U]E;G1E<E]S:7IE)R`]/B`B16YT97(@<VEZ92(L"@DG7U]E=F5N="<@/3X@
M)T5V96YT)RP*"2=?7V5V96YT7VAA;F1L97(G(#T^("=%=F5N="!H86YD;&5R
M)RP*"2=?7V5V96YT7VAA;F1L97)S)R`]/B`G179E;G0@:&%N9&QE<G,G+`H)
M)U]?97AC;'5S:79E)R`]/B`B17AC;'5S:79E(BP*"2=?7V5X<&ER871I;VY?
M9&%T92<@/3X@(D5X<&ER871I;VX@9&%T92(L"@DG7U]F87@G(#T^(")&87@B
M+`H))U]?9FEL92<@/3X@(D9I;&4B+`H))U]?9FEL95]I<U]E;7!T>2<@/3X@
M(D9I;&4@:7,@96UP='DN(BP*"2=?7V9I;&5?;F%M92<@/3X@(D9I;&4@;F%M
M92(L"@DG7U]F:6QE7W1Y<&4G(#T^("=&:6QE('1Y<&4G+`H))U]?9FEL96UA
M;F%G97(G(#T^(")&:6QE($UA;F%G97(B+`H))U]?9FEL97!A=&A?:7-?96UP
M='DG(#T^(")0871H('1O(&9I;&4@:7,@96UP='DB+`H))U]?9FEL97-?;&ES
M="<@/3X@(D9I;&5S(BP*"2=?7V9P7W-S;%]U;FEX7W-U<'!O<G0G(#T^(")&
M<F]N=%!A9V4@;W9E<B!34TP@<W5P<&]R="(L"@DG7U]F<%]S<VQ?=VEN7W-U
M<'!O<G0G(#T^(")-:6-R;W-O9G0@1G)O;G1086=E(&]V97(@4U-,('-U<'!O
M<G0B+`H))U]?9G!?=6YI>%]A=71H)R`]/B`B1G)O;G1086=E(&%U=&AO<FEN
M9R(L"@DG7U]F<%]U;FEX7W-U<'!O<G0G(#T^(")&<F]N=%!A9V4@<W5P<&]R
M="(L"@DG7U]F<%]W:6Y?875T:"<@/3X@(DUI8W)O<V]F="!&<F]N=%!A9V4@
M875T:&]R:6YG(BP*"2=?7V9P7W=I;E]S=7!P;W)T)R`]/B`B36EC<F]S;V9T
M($9R;VYT4&%G92!S=7!P;W)T(BP*"2=?7V9R;VYT<&%G92<@/3X@(DUI8W)O
M<V]F="!&<F]N=%!A9V4B+`H))U]?9G1P)R`]/B`B1E10(BP)+R\@*VEN9&ER
M96-T"@DG7U]F='!?<V5T=&EN9W,G(#T^(")&5%`@<V5T=&EN9W,B+`H))U]?
M9G1P7W-E<G8G(#T^(")&5%`@<V5R=F5R(BP)+R\@:6YD:7)E8W0*"2=?7V9T
M<%]S97)V97)?<&%R86UE=&5R<U]A<F5?96UP='DG(#T^(")9;W4@<VAO=6QD
M('-E="!T:&4@1E10(&%C8V]U;G0@<')O<&5R=&EE<R!F:7)S="$B+`H))U]?
M9G1P7W-T871U<R<@/3X@(D944"!S97)V97(@<W1A='5S(BP*"2=?7V9U;&Q?
M9&%Y,"<@/3X@(E-U;F1A>2(L"@DG7U]F=6QL7V1A>3$G(#T^(")-;VYD87DB
M+`H))U]?9G5L;%]D87DR)R`]/B`B5'5E<V1A>2(L"@DG7U]F=6QL7V1A>3,G
M(#T^(")7961N97-D87DB+`H))U]?9G5L;%]D87DT)R`]/B`B5&AU<G-D87DB
M+`H))U]?9G5L;%]D87DU)R`]/B`B1G)I9&%Y(BP*"2=?7V9U;&Q?9&%Y-B<@
M/3X@(E-A='5R9&%Y(BP*"2=?7V9U;&Q?;6]N=&@Q)R`]/B`B2F%N=6%R>2(L
M"@DG7U]F=6QL7VUO;G1H,3`G(#T^(")/8W1O8F5R(BP*"2=?7V9U;&Q?;6]N
M=&@Q,2<@/3X@(DYO=F5M8F5R(BP*"2=?7V9U;&Q?;6]N=&@Q,B<@/3X@(D1E
M8V5M8F5R(BP*"2=?7V9U;&Q?;6]N=&@R)R`]/B`B1F5B<G5A<GDB+`H))U]?
M9G5L;%]M;VYT:#,G(#T^(")-87)C:"(L"@DG7U]F=6QL7VUO;G1H-"<@/3X@
M(D%P<FEL(BP*"2=?7V9U;&Q?;6]N=&@U)R`]/B`B36%Y(BP*"2=?7V9U;&Q?
M;6]N=&@V)R`]/B`B2G5N92(L"@DG7U]F=6QL7VUO;G1H-R<@/3X@(DIU;'DB
M+`H))U]?9G5L;%]M;VYT:#@G(#T^(")!=6=U<W0B+`H))U]?9G5L;%]M;VYT
M:#DG(#T^(")397!T96UB97(B+`H))U]?9V5N97)A;"<@/3X@(D=E;F5R86PB
M+`H))U]?9VEG82<@/3X@(D<B+`H))U]?9W)O=7`G(#T^(")'<F]U<"(L"@DG
M7U]H)R`]/B`B2"(L"@DG7U]H87)D7V1I<VM?<75O=&$G(#T^(")(87)D(&1I
M<VL@<75O=&$B+`H))U]?:&%R9%]D:7-K7W%U;W1A7VYO=%]S=7!P;W)T960G
M(#T^(")H87)D(&1I<VL@<75O=&$@:7,@;F]T('-U<'!O<G1E9"(L"@DG7U]H
M96%D97)?=&5X=%]I<U]I;G9A;&ED)R`]/B`B2&5A9&5R('1E>'0@:7,@:6YV
M86QI9"XB+`H))U]?:&5L<"<@/3X@(DAE;'`B+`H))U]?:&5L<%]T;W!I8U]N
M;W1?9F]U;F0G(#T^("=4:&4@:&5L<"!T;W!I8R!Y;W4@<F5Q=65S=&5D("@E
M,2D@9&]E<R!N;W0@97AI<W0N)RP*"2=?7VAO;64G(#T^(")(;VUE(BP*"2=?
M7VAO<W1I;F<G(#T^(")(;W-T:6YG(BP*"2=?7VAO<W1I;F=?:7!?9&YS7VEP
M7VYO=%]E<75I=B<@/3X@(DYO;F4@;V8@25`@861D<F5S<V5S('-P96-I9FEE
M9"!I;B!!($1.4R!R96-O<F1S(&UA=&-H('1H92!)4"!A9&1R97-S('5S960@
M9F]R(&AO<W1I;F<B+`H))U]?:&]S=&EN9U]S8W)I<'1I;F<G(#T^(")(;W-T
M:6YG('-C<FEP=&EN9R!S=7!P;W)T(BP*"2=?7VAO<W1I;F=?<V5T=7!?<&%G
M95]T:71L92<@/3X@(E!H>7-I8V%L(&AO<W1I;F<@<V5T=7`@<&%G92!F;W(@
M9&]M86EN("4Q(BP*"2=?7VAO<W1I;F=?=&ET;&4G(#T^(")(;W-T:6YG("@E
M,2DB+`H))U]?:&]S=&EN9U]T>7!E)R`]/B`B2&]S=&EN9R!T>7!E(BP*"2=?
M7VAO<W1N86UE)R`]/B`B2&]S=&YA;64B+`H))U]?:&]S=&YA;65?:7-?96UP
M='DG(#T^(")(;W-T;F%M92!I<R!E;7!T>2XB+`H))U]?2&]U<G,G(#T^("=(
M;W5R<R<L"@DG7U]H<W1?='EP95]I;F-O<G)E8W0G(#T^(")(;W-T:6YG('1Y
M<&4@:7,@:6YC;W)R96-T+B(L"@DG7U]H='1P)R`]/B`B2%144"(L"2\O:6YD
M:7)E8W0*"2=?7VAT>7!E)R`]/B`B2"(L"@DG7U]I9&QE7W1I;64G(#T^("))
M9&QE('1I;64B+`H))U]?:69A8V4G(#T^("));G1E<F9A8V4B+`H))U]?:6UA
M9V4G(#T^("));6%G92(L"@DG7U]I;6%P7W-T871U<R<@/3X@(DE-05`@4V5R
M=F5R('-T871U<R(L"@DG7U]I;B<@/3X@(DEN(BP*"2=?7VEN7R4G(#T^(")I
M;B`E(BP*"2=?7VEN8V]R<F5C=%]D871A8F%S97-?;&]G:6Y?<&%S<R<@/3X@
M(EEO=2!S<&5C:69I960@:6YC;W)R96-T(&-R961E;G1I86QS(&9O<B!A8V-E
M<W,@=&\@4&]S=&=R95-13"XB+`H))U]?:6YC;W)R96-T7VEP7V]R7VYE='=O
M<FM?861D<F5S<R<@/3X@)TEN8V]R<F5C="!)4"!A9&1R97-S(&]R(&YE='=O
M<FLN)RP*"2=?7VEN8W)E;65N="<@/3X@(DEN8W)E87-E("@K*2(L"2\O(&EN
M9&ER96-T"@DG7U]I;F9O)R`]/B`G26YF;R<L"@DG7U]I;G-T86QL)R`]/B`B
M26YS=&%L;"(L"@DG7U]I;G-T86QL7W!R969I>"<@/3X@(DEN<W1A;&P@<')E
M9FEX(BP*"2=?7VEN=&5R9F%C95]S:VEN)R`]/B`B26YT97)F86-E('-K:6XB
M+`H))U]?:6YV86QI9%]C97)T7VED)R`]/B`B26YV86QI9"!C97)T:69I8V%T
M92!I9"(L"@DG7U]I;G9A;&ED7V-O;G1E>'0G(#T^("));G9A;&ED(&-O;G1E
M>'0Z("4Q(BP*"2=?7VEN=F%L:61?9&)?=7-R7VYA;64G(#T^(")$871A8F%S
M92!U<V5R(&YA;64@:7,@:6YV86QI9"XB+`H))U]?:6YV86QI9%]D:7)?;F%M
M92<@/3X@(D1I<F5C=&]R>2!N86UE(&ES(&EN=F%L:60B+`H))U]?:6YV86QI
M9%]D;VU?;F%M92<@/3X@(D1O;6%I;B!N86UE(&ES(&EN=F%L:60N(BP*"2=?
M7VEN=F%L:61?9FEL96YA;64G(#T^("));G9A;&ED(&9I;&5N86UE+B!$;R!N
M;W0@=7-E('-I;F=L92!Q=6]T97,@86YD+V]R(%PB+BXO7"(@8V]M8FEN871I
M;VXN(BP*"2=?7VEN=F%L:61?:60G(#T^("));G9A;&ED(&ED96YT:69I97(N
M(BP*"2=?7VEN=F%L:61?;6%X7V)U='1O;E]L96XG(#T^("));F%P<')O<')I
M871E('9A;'5E(&9O<B!N=6UB97(@;V8@8VAA<F%C=&5R<RX@66]U('-H;W5L
M9"!U<V4@;VYL>2!D:6=I=',N(BP*"2=?7VEN=F%L:61?;6%X7VQE='1E<E]S
M:7IE)R`]/B`B36%X:6UU;2!L971T97(@<VEZ92!I<R!I;G9A;&ED+B(L"@DG
M7U]I;G9A;&ED7W!D:7)?;F%M92<@/3X@(E!R;W1E8W1E9"!D:7)E8W1O<GD@
M;F%M92!I<R!I;G9A;&ED+B(L"@DG7U]I;G9A;&ED7W)E<W1A<G1?87!A8VAE
M7VEN=&5R=F%L)R`]/B`B07!A8VAE(')E<W1A<G0@:6YT97)V86P@:7,@:6YV
M86QI9"(L"@DG7U]I;G9A;&ED7W1M<&Q?;F%M92<@/3X@(E1E;7!L871E(&YA
M;64@:7,@:6YV86QI9"XB+`H))U]?:6YV86QI9%]V86QU92<@/3X@(DEM<')O
M<&5R('9A;'5E+B(L"@DG7U]I<%]A9&1R)R`]/B`B25`@061D<F5S<R(L"@DG
M7U]I<%]A9&1R97-S7V%N9%]M87-K)R`]/B`B25`@061D<F5S<R!A;F0@4W5B
M;F5T($UA<VLB+`H))U]?:7!?;6%S:R<@/3X@(E-U8FYE="!-87-K(BP*"2=?
M7VEP7V%L:6%S7U]M87-K)R`]/B`B25`@061D<F5S<R!A;F0@4W5B;F5T($UA
M<VLB+`H))VEP7V%L:6%S7U]M87-K)R`]/B`B25`@061D<F5S<R!A;F0@4W5B
M;F5T($UA<VLB+`H))U]?:7!?861D<E]F;W)M)R`]/B`B25`@061D<F5S<R!F
M;W)M(BP*"2=?7VEP7V%D9')?:7-?:6YV86QI9"<@/3X@(DE0(&%D9')E<W,@
M:7,@:6YV86QI9"XB+`H))U]?:7!?861D<E]L:7-T)R`]/B`B25`@061D<F5S
M<V5S(BP*"2=?7VEP7V%D9')E<W-?9&]E<U]N;W1?97AI<W0G(#T^("))4"!A
M9&1R97-S(&1O97,@;F]T(&5X:7-T+B(L"@DG7U]I<%]A9&1R97-S97,G(#T^
M("))4"!!9&1R97-S97,B+`H))U]?:7!?861D<F5S<U]A;F1?;6%S:U]H:6YT
M)R`]/B`G12YG+B`E,2<L"@DG7U]I<U]O=VYE<B<@/3X@(D\B+`H))U]?:F%V
M85]E;F=I;F4G(#T^(")*879A(BP)+R\@:6YD:7)E8W0*"2=?7VID:R<@/3X@
M(DI$2R(L"@DG7U]K8B<@/3X@(DM"(BP*"2=?7VMB<',G(#T^(")+0B]S(BP*
M"2=?7VMB>71E<R<@/3X@(FMI;&]B>71E<R(L"@DG7U]K97E?;&EM:71S7V5X
M8V5E9&EN9R<@/3X@(E1H:7,@86-T:6]N(&5X8V5E9',@=&AE(&QI;6ET<R!D
M969I;F5D(&)Y('EO=7(@<V]F='=A<F4@;&EC96YS92X@268@>6]U(')E8V5I
M=F5D('1H:7,@;65S<V%G92!Y;W4@;6%Y(&-O;G1A8W0@>6]U<B!P<F]V:61E
M<B!O<B!T:&4@;6%N=69A8W1U<F5R('1O(&-L87)I9GD@;W(@97AT96YD('1H
M92!L:6UI=',@;V8@=&AI<R!L:6-E;G-E+B(L"@DG7U]K:6QO)R`]/B`B2R(L
M"@DG7U]K97EW;W)D<R<@/3X@)TME>7=O<F1S)RP*"2=?7VQA;F=?=6YK;F]W
M;B<@/3X@)U5N86)L92!T;R!R96-O9VYI>F4@=&AE(&QA;F=U86=E+B<L"@DG
M7U]L86YG=6%G97,G(#T^("=,86YG=6%G92<L"@DG7U]L96%R;E]M;W)E)R`]
M/B`G3&5A<FX@;6]R92<L"@DG7U]L;V-A;&5S)R`]/B`B3&%N9W5A9V4@<&%C
M:W,B+`H))U]?;&EM:70G(#T^("),:6UI="(L"@DG7U]L:6UI=',G(#T^("),
M:6UI=',B+`H))U]?;&EN:U]U<FQ?:7-?:6YV86QI9"<@/3X@(DQO9V\@55),
M(&ES(&EN=F%L:60N(BP*"2=?7VQI<W1S)R`]/B`B36%I;&EN9R!L:7-T<R(L
M"@DG7U]L:71E<F%L7V)Y=&5S)R`]/B`B0B(L"@DG7U]P<F]C97-S:6YG)R`]
M/B`B4&QE87-E('=A:70N/&)R/DQO861I;F<@+BXN(BP*"2=?7VQO8V%L92<@
M/3X@(DEN=&5R9F%C92!L86YG=6%G92(L"@DG7U]L;V-A;&5?:7-?;F]T7V1E
M9FEN960G(#T^("));G1E<F9A8V4@;&%N9W5A9V4@:7,@;F]T(&1E9FEN960N
M(BP*"2=?7VQO8V%L7W-E<G9E<E]M>7-Q;"<@/3X@)TQO8V%L($UY4U%,('-E
M<G9E<B<L"@DG7U]L;V-A;%]S97)V97)?<&]S=&=R97-Q;"<@/3X@)TQO8V%L
M(%!O<W1G<F5344P@<V5R=F5R)RP*"2=?7VQO9U]F:6QE<R<@/3X@(DQO9R!F
M:6QE<R(L"@DG7U]C;VYF:6=?9FEL97,G(#T^("=#;VYF:6<@9FEL97,G+`H)
M)U]?8VAR;V]T7V9I;&5S)R`]/B`G0VAR;V]T960@96YV:7)O;FUE;G0G+`H)
M)U]?;&]G:6XG(#T^("(E,2!,;V=I;B(L"@DG7U]L;V=I;C$G(#T^("),;V=I
M;B(L"@DG7U]L;V=I;E]D:7-A8FQE9"<@/3X@(DQO9VEN(&1I<V%B;&5D(BP*
M"2=?7VQO9VEN7V5N86)L960G(#T^("),;V=I;B!E;F%B;&5D(BP*"2=?7VQO
M9VEN7VEN8V]R<F5C="<@/3X@(DQO9VEN(&ES(&EN8V]R<F5C="XB+`H))U]?
M;&]G:6Y?;F%M92<@/3X@(B4Q(&QO9VEN(&YA;64B+`H))U]?;&]G:6Y?;F%M
M95]I<U]I;G9A;&ED)R`]/B`B)3$@;&]G:6X@;F%M92!I<R!I;G9A;&ED+B(L
M"@DG7U]L;V=O;E]T:6UE)R`]/B`B3&]G;VX@=&EM92(L"@DG7U]L;V=O=70G
M(#T^("),;V<@;W5T(BP*"2=?7VUA)R`]/B`B36%I;"!A;&EA<V5S(BP*"2=?
M7VUA:6PG(#T^(")-86EL(BP*"2=?7VUA:6Q?86QI87-?;F%M92<@/3X@(DUA
M:6P@86QI87,@;F%M92(L"@DG7U]M86EL7V5X8VAA;F=E<E]N86UE7VES7VEN
M=F%L:60G(#T^(")-86EL(&5X8VAA;F=E<B!N86UE(&ES(&EN=F%L:60N(BP*
M"2=?7VUA:6Q?9W)O=7!S)R`]/B`B36%I;"!G<F]U<',B+`H))U]?;6%I;%]L
M:7-T7V5N9VEN92<@/3X@(DUA:6QI;F<@;&ES="!S;V9T=V%R92(L"@DG7U]M
M86EL7VYA;64G(#T^(")-86EL(&YA;64B+`H))U]?;6%I;%]N86UE7V9O<FTG
M(#T^(")-86EL(&YA;64@9F]R;2(L"@DG7U]M86EL7VYA;65S)R`]/B`B36%I
M;"!N86UE<R(L"@DG7U]M86EL7VYA;65S7VQI<W0G(#T^(")-86EL(&YA;65S
M(BP*"2=?7VUA:6Q?<V5R=B<@/3X@(DUA:6P@<V5R=F5R(BP*"2=?7VUA:6Q?
M=7-E<B<@/3X@)TUA:6P@=7-E<B<L"@DG7U]M86EL9W)O=7`G(#T^(")-86EL
M(&=R;W5P(BP*"2=?7VUA:6QL:7-T)R`]/B`B36%I;&EN9R!L:7-T(BP*"2=?
M7VUA:6QL:7-T<R<@/3X@(DUA:6QI;F<@;&ES=',B+`H))U]?;6%I;&QI<W1?
M;65M8F5R<R<@/3X@)TUA:6QI;F<@;&ES="!M96UB97)S)RP*"2=?7VUA:6QL
M:7-T7VUE;6)E<B<@/3X@)TUA:6QI;F<@;&ES="!M96UB97(G+`H))U]?;6%I
M;&YA;64G(#T^(")-86EL(&YA;64B+`H))U]?;6%I;&YA;65?<F5D:7)?<V5L
M9B<@/3X@(DUA:6P@;F%M92!C86YN;W0@8F4@<F5D:7)E8W1E9"!T;R!I='-E
M;&8N(BP*"2=?7VUA<W1E<B<@/3X@(DUA<W1E<B(L"@DG7U]M87A?9&]M7VYU
M;5]R96%C:&5D7V9O<E]C;"<@/3X@(E1H92!L:6UI="!O;B!N=6UB97(@;V8@
M9&]M86EN<R!H87,@8F5E;B!R96%C:&5D(&9O<B!T:&ES(&-L:65N="!A8V-O
M=6YT+B(L"@DG7U]M87A?9FEL95]S:7IE7V%V86EL86)L92<@/3X@(DUA>&EM
M=6T@9FEL97-I>F4@86QL;W=E9"`E,2(L"@DG7U]M87A?<W5B9&]M7VYU;5]R
M96%C:&5D7V9O<E]C;"<@/3X@(E1H92!L:6UI="!O;B!N=6UB97(@;V8@<W5B
M9&]M86EN<R!H87,@8F5E;B!R96%C:&5D(&9O<B!T:&ES(&-L:65N="!A8V-O
M=6YT+B(L"@DG7U]M87A?<W5B9&]M7VYU;5]R96%C:&5D7V9O<E]D;VTG(#T^
M(")4:&4@;&EM:70@;VX@;G5M8F5R(&]F('-U8F1O;6%I;G,@:&%S(&)E96X@
M<F5A8VAE9"!F;W(@=&AE(&1O;6%I;BXB+`H))U]?;6%X7W-U8F1O;5]N=6U?
M<F5A8VAE9%]F;W)?:V5Y)R`]/B`B5&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!S
M=6)D;VUA:6YS(&%L;&]W960@8GD@=&AE(&QI8V5N<V4@:V5Y(&AA<R!B965N
M(')E86-H960N(BP*"2=?7VUA>%]T<F%F9FEC7VQI;6ET)R`]/B`B5')A9F9I
M8R!L:6UI="(L"@DG7U]M87AI;75M7V5X8VQ?:7!?;G5M)R`]/B`B36%I;"!N
M86UE<R(L"@DG7U]M8B<@/3X@(DU"(BP*"2=?7VUB>71E<R<@/3X@(FUE9V%B
M>71E<R(L"@DG7U]M8E]M;VYT:"<@/3X@(DU"+VUO;G1H(BP*"2=?7VUE9V$G
M(#T^(")-(BP*"2=?7TUI;G5T97,G(#T^("=-:6YU=&5S)RP*"2=?7VUL<U]N
M;W1?:6Y?:V5Y)R`]/B`B66]U<B!P<F]D=6-T(&ME>2!D;V5S(&YO="!S=7!P
M;W)T(&UU;'1I;&EN9W5A;"!I;G1E<F9A8V4N(BP*"2=?7VUO9&EF:6-A=&EO
M;E]D871E)R`]/B`B36]D:69I8V%T:6]N(&1A=&4B+`H))U]?;6]D=6QE)R`]
M/B`B36]D=6QE(BP*"2=?7VUO9'5L97,G(#T^(")-;V1U;&5S(BP*"2=?7VUO
M;G1H)R`]/B`B36]N=&@B+`H))U]?;6]N=&@H<RDG(#T^(")-;VYT:"AS*2(L
M"@DG7U]M;VYT:#$G(#T^(")*86XB+`H))U]?;6]N=&@Q,"<@/3X@(D]C="(L
M"@DG7U]M;VYT:#$Q)R`]/B`B3F]V(BP*"2=?7VUO;G1H,3(G(#T^(")$96,B
M+`H))U]?;6]N=&@R)R`]/B`B1F5B(BP*"2=?7VUO;G1H,R<@/3X@(DUA<B(L
M"@DG7U]M;VYT:#0G(#T^(")!<')I;"(L"@DG7U]M;VYT:#4G(#T^(")-87DB
M+`H))U]?;6]N=&@V)R`]/B`B2G5N92(L"@DG7U]M;VYT:#<G(#T^(")*=6QY
M(BP*"2=?7VUO;G1H."<@/3X@(D%U9R(L"@DG7U]M;VYT:#DG(#T^(")397!T
M(BP*"2=?7VUO;G1H;'DG(#T^(")-;VYT:&QY(BP*"2=?7VUO;G1H<R<@/3X@
M(DUO;G1H<R(L"@DG7U]M;W9E9%]P97)M86YE;G1L>2<@/3X@)TUO=F5D(%!E
M<FUA;F5N=&QY)RP*"2=?7VUS<W%L)R`]/B`B36EC<F]S;V9T(%-13"!S97)V
M97(B+`H))U]?;7-S<6Q?<W1A='5S)R`]/B`B36EC<F]S;V9T(%-13"!S97)V
M97(@<W1A='5S(BP*"2=?7VUU;'1I<&QY7VQO9VEN7V1E;GDG(#T^(")5;F%B
M;&4@=&\@;&]G('EO=2!O;BX@06YO=&AE<B!U<V5R('=I=&@@=&AE('-A;64@
M;&]G:6X@;F%M92`H)3$I(&ES(&%L<F5A9'D@;&]G9V5D(&EN('1O('1H92!C
M;VYT<F]L('!A;F5L+B(L"@DG7U]M>7-Q;"<@/3X@(DUY4U%,(BP*"2=?7VUY
M<W%L7W-T871U<R<@/3X@(E-13"!S97)V97(@<W1A='5S(BP*"2=?7VUY<W%L
M7W9E<G-I;VXG(#T^(")->7-Q;"!V97)S:6]N(BP*"2=?7VYA;64G(#T^(").
M86UE(BP*"2=?7VYA;65?:6YV86QI9"<@/3X@(DYA;64@:7,@:6YV86QI9"XB
M+`H))U]?;F%M97-E<G9E<B<@/3X@(FYA;65S97)V97(B+`H))U]?;F5T=V]R
M:R<@/3X@(DYE='=O<FLB+`H))U]?;F5T=V]R:W,G(#T^(").971W;W)K<R(L
M"@DG7U]N971W;W)K<U]L:7-T)R`]/B`B3F5T=V]R:W,B+`H))U]?;F5W7W!A
M<W-W9"<@/3X@(DYE=R`E,2!P87-S=V]R9"(L"@DG7U]N97=?<&%S<W=D7W-I
M;F=L92<@/3X@(DYE=R!P87-S=V]R9"(L"@DG7U]N;R<@/3X@(DYO(BP*"2=?
M7VYO7VEP7V%D9')E<W-?=VET:%]P<F]P97)L>5]T>7!E7V%V86EL86)L92<@
M/3X@(E5N86)L92!T;R!R97-T;W)E('1H92!B86-K960@=7`@9&%T82!B96-A
M=7-E('1H97)E(&%R92!N;R!S=6ET86)L92!)4"!A9&1R97-S97,@<F5Q=6ER
M960@9F]R(')E<W1O<FEN9RXB+`H))U]?;F]?8VQI96YT<U]S<&5C:69I960G
M(#T^(").;R!C;&EE;G0@86-C;W5N=',@<W!E8VEF:65D+B(L"@DG7U]N;U]C
M;VUM96YT<R<@/3X@(DYO(&-O;6UE;G1S+B(L"@DG7U]N;U]I<%]S<&5C:69I
M960G(#T^(").;R!I<"!S<&5C:69I960N(BP*"2=?7VYO7W-I=&5?87!P<U]S
M<&5C:69I960G(#T^(").;R!S:71E(&%P<&QI8V%T:6]N<R!S96QE8W1E9"XB
M+`H))U]?;F]C:&%N9V4G(#T^(")$;R!N;W0@8VAA;F=E(BP*"2=?7VYO;&]G
M:6XG(#T^(")&;W)B:61D96XB+`H))U]?;F]N92<@/3X@(DYO;F4B+`H))U]?
M;F]T7V-O;F9I9W5R960G(#T^(").;W0@8V]N9FEG=7)E9"(L"@DG7U]N;W1?
M<W5P<&]R=&5D7V)Y7V9T<"<@/3X@(BAN;W0@<W5P<&]R=&5D(&)Y($944"!S
M97)V97(I(BP*"2=?7VYO=%]S=7!P;W)T961?8GE?;6%I;&UN9R<@/3X@(FYO
M="!S=7!P;W)T960@8GD@=&AE(&UA:6P@<V5R=F5R(BP*"2=?7VYO=&EF:6-A
M=&EO;B<@/3X@(DYO=&EF:6-A=&EO;B(L"@DG7U]N;W1I9FEC871I;VYS)R`]
M/B`B3F]T:69I8V%T:6]N<R(L"@DG7U]N=6U?9&ES<&QA>65D)R`]/B`B)3$@
M;V8@)3(@9&ES<&QA>65D(BP*"2=?7VYU;5]I<U]I;G9A;&ED)R`]/B`B3G5M
M8F5R(&ES(&EN=F%L:60N(BP*"2=?7V]B:F5C=%]N;W1?9F]U;F0G(#T^("=/
M8FIE8W0@;F]T(&9O=6YD.B`E,2<L"@DG7U]O9E]A;&PG(#T^("(E(&]F($%L
M;"(L"@DG7U]O9F8G(#T^(")/9F8B+`H))U]?;VLG(#T^(")/2R(L"@DG7U]O
M;&1?<&%S<W=D)R`]/B`B3VQD("4Q('!A<W-W;W)D(BP*"2=?7V]L9%]P87-S
M=V1?<VEN9VQE)R`]/B`B3VQD('!A<W-W;W)D(BP*"2=?7V]N)R`]/B`B3VXB
M+`H))U]?;W1H97)S)R`]/B`B3W1H97)S(BP*"2=?7V]T:&5R7VEP7U]W:6QL
M7V)E7V%D9&5D)R`]/B`G3W1H97(@879A:6QA8FQE($E0(&%D9')E<W-E<R`H
M=VEL;"!B92!A9&1E9"!T;R!T:&4@8VQI96YT7"=S($E0('!O;VPI)RP*"2=?
M7V]U="<@/3X@(D]U="(L"@DG7U]O=VYE<B<@/3X@(D]W;F5R(BP*"2=?7W`G
M(#T^(")0(BP*"2=?7W!A<W-W9"<@/3X@(B4Q(%!A<W-W;W)D(BP*"2=?7W!A
M<W-W9%]S:6YG;&4G(#T^(")087-S=V]R9"(L"@DG7U]P87-S=V1?:&EN="<@
M/3X@(D%T(&QE87-T(#4@8VAA<F%C=&5R<RP@;F\@;F%T:6]N86P@8VAA<F%C
M=&5R<R(L"@DG7U]P87-S=V1?:7-?:6YV86QI9"<@/3X@(B4Q(%!A<W-W;W)D
M(&ES(&EN=F%L:60N(BP*"2=?7W!A<W-W9%]N;W1?;6%T8V@G(#T^(")087-S
M=V]R9',@9&\@;F]T(&UA=&-H(2(L"@DG7U]P871H)R`]/B`B4&%T:"(L"@DG
M7U]P97)L7W5N:7A?<W5P<&]R="<@/3X@(FUO9%]P97)L('-U<'!O<G0B+`H)
M)U]?<&5R;%]W:6Y?<W5P<&]R="<@/3X@(E!E<FP@<W5P<&]R="(L"@DG7U]P
M97)M7V1E;FEE9"<@/3X@(E!E<FUI<W-I;VX@9&5N:65D+B(L"@DG7U]P97)M
M:7-S:6]N<R<@/3X@(E!E<FUI<W-I;VYS(BP*"2=?7W!E<G-O;F%L7VYA;64G
M(#T^(")097)S;VYA;"!N86UE(BP*"2=?7W!G7V%D;6EN7VYO=%]A8W1I=F%T
M960G(#T^(")0;W-T9W)E4U%,('=A<R!N;W0@86-T:79A=&5D(&EN('1H92!S
M97)V97(@861M:6YI<W1R871I;VX@<V5C=&EO;BXB+`H))U]?<&=?;F]T7VEN
M<W0G(#T^(")0;W-T9W)E4U%,('=A<R!N;W0@:6YS=&%L;&5D+B(L"@DG7U]P
M9U]N;W1?<G5N7V]R7VEN<W0G(#T^(")0;W-T9W)E4U%,('=A<R!N;W0@:6YS
M=&%L;&5D(&]R(&ES(&YO="!R=6YN:6YG+B(L"@DG7U]P:&]N92<@/3X@(E!H
M;VYE(BP*"2=?7W!H;W-T:6YG)R`]/B`B4&AY<VEC86P@:&]S=&EN9R(L"@DG
M7U]P:'!?<W5P<&]R="<@/3X@(E!(4"!S=7!P;W)T(BP*"2=?7W!H<%]S869E
M7VUO9&4G(#T^(")02%`@)W-A9F5?;6]D92<@;VXB+`H))U]?<&AP7W9E<G-I
M;VXG(#T^(")02%`@=F5R<VEO;B(L"@DG7U]P:'ES:6-A;"<@/3X@(E!H>7-I
M8V%L(&AO<W1I;F<B+`H))U]?<&QE<VM?<W1A=%]P9&ER)R`]/B`B4')O=&5C
M="!D:7)E8W1O<GD@)R]P;&5S:RUS=&%T+R<B+`H))U]?<&QE<VM?<W1A=%]D
M:7)?;F%M92<@/3X@(D1O;6%I;B!S=&%T:7-T:6-S(BP*"2=?7W!L97-K7W-T
M871?<')O=&5C="<@/3X@(F%C8V5S<VEB;&4@=FEA('!A<W-W;W)D('!R;W1E
M8W1E9"!D:7)E8W1O<GD@)R]P;&5S:RUS=&%T+R<B+`H))U]?<&QE<VM?<W1A
M=%]P<F]T96-T7VEN<W1A;&PG(#T^(")A8V-E<W-I8FQE('9I82!P87-S=V]R
M9"!P<F]T96-T960@9&ER96-T;W)Y("<O<&QE<VLM<W1A="\G(BP*"2=?7W!L
M97-K7W-T871?=V5B<W1A=%]N;W1?86-T:79A=&4G(#T^(")796(@<W1A=&ES
M=&EC<R!A<F4@;F]T(&5N86)L960N(BP*"2=?7W!O<#-?:6UA<"<@/3X@(E!/
M4#,O24U!4"(L"2\O(&EN9&ER96-T"@DG7U]P;W`S7W-T871U<R<@/3X@(E!/
M4#,@<V5R=F5R('-T871U<R(L"@DG7U]P;W!E;E]E<G)O<B<@/3X@(D%N(&5R
M<F]R(&]C8W5R<F5D('=H:6QE(&-A;&QI;F<@=&AE('!O<&5N(&9U;F-T:6]N
M+B(L"@DG7U]P;W)T)R`]/B`G4&]R="<L"@DG7U]P;W-T9W)E<R<@/3X@(E!O
M<W1G<F5344PB+`H))U]?<&]S=&=R97-Q;"<@/3X@(E!O<W1G<F5344PB+`H)
M)U]?<&]S=&=R97-Q;%]S=&%T=7,G(#T^(")0;W-T9W)E4U%,('-T871U<R(L
M"@DG7U]P<F5F97)E;F-E<R<@/3X@(E!R969E<F5N8V5S(BP*"2=?7V%D;6EN
M:7-T<F%T;W)?<')E9F5R96YC97,G(#T^(")!9&UI;FES=')A=&]R)W,@4')E
M9F5R96YC97,B+`H))U]?86-C;W5N=%]P<F5F97)E;F-E<R<@/3X@(D%C8V]U
M;G0@4')E9F5R96YC97,B+`H))U]?:6YT97)F86-E7W!R969E<F5N8V5S7V=E
M;F5R86PG(#T^("='96YE<F%L)RP*"2=?7VEN=&5R9F%C95]P<F5F97)E;F-E
M<U]D969A=6QT)R`]/B`G1&5F875L="!);G1E<F9A8V4@4')E9F5R96YC97,G
M+`H))U]?:6YT97)F86-E7W!R969E<F5N8V5S7V%D;6EN)R`]/B`B061M:6YI
M<W1R871O<B=S($EN=&5R9F%C92!0<F5F97)E;F-E<R(L"@DG<V5R=F5R7W!R
M969E<F5N8V5S7U]D969A=6QT7VET;7!L)R`]/B`G1&5F875L="!I;G1E<F9A
M8V4@8W5S=&]M:7IA=&EO;B!T96UP;&%T92<L"@DG<V5R=F5R7W!R969E<F5N
M8V5S7U]A9&UI;E]I=&UP;"<@/3X@(D%D;6EN:7-T<F%T;W(G<R!I;G1E<F9A
M8V4@8W5S=&]M:7IA=&EO;B!T96UP;&%T92(L"@DG7U]I;G1E<F9A8V5?=&5M
M<&QA=&4G(#T^("=);G1E<F9A8V4@8W5S=&]M:7IA=&EO;B!T96UP;&%T92<L
M"@DG7U]S>7-T96U?<')E9F5R96YC97,G(#T^(")3>7-T96T@<')E9F5R96YC
M97,B+`H))U]?:6YT97)F86-E7W!R969E<F5N8V5S)R`]/B`B26YT97)F86-E
M('!R969E<F5N8V5S(BP*"2=?7W!R:6]R:71Y)R`]/B`G4')I;W)I='DG+`H)
M)U]?<')I;W)I='E?:&EG:&5S="<@/3X@)VAI9VAE<W0G+`H))U]?<')I;W)I
M='E?:&EG:"<@/3X@)VAI9V@G+`H))U]?<')I;W)I='E?;F]R;6%L)R`]/B`G
M;F]R;6%L)RP*"2=?7W!R:6]R:71Y7VQO=R<@/3X@)VQO=R<L"@DG7U]P<FEO
M<FET>5]L;W=E<W0G(#T^("=L;W=E<W0G+`H))U]?<')I;W)I='E?;W1H97(G
M(#T^("=C=7-T;VTG+`H))U]?<')O8V5E9#\G(#T^(")$;R!Y;W4@=V%N="!T
M;R!P<F]C965D/R(L"@DG7U]P<F]C96YT)R`]/B`B)2(L"@DG7U]P<F]T96-T
M7V1I<E]U<V5R)R`]/B`B4')O=&5C=&5D(&1I<F5C=&]R>2!U<V5R(BP*"2=?
M7W!R;W1E8W1?9&ER7W5S97)S)R`]/B`B4')O=&5C=&5D(&1I<F5C=&]R>2!U
M<V5R<R(L"@DG7U]P<F]T96-T7V1I<G,G(#T^(")0<F]T96-T960@9&ER96-T
M;W)I97,B+`H))U]?<')O=FED97)?8V]N=&%C=%]N86UE)R`]/B`B4')O=FED
M97(G<R!C;VYT86-T(&YA;64B+`H))U]?<'0G(#T^(")U;FET<R(L"@DG7U]P
M>71H;VY?=6YI>%]S=7!P;W)T)R`]/B`B;6]D7W!Y=&AO;B!S=7!P;W)T(BP*
M"2=?7W!Y=&AO;E]W:6Y?<W5P<&]R="<@/3X@(E!Y=&AO;B!S=7!P;W)T(BP*
M"2=?7W%U;W1A)R`]/B`B475O=&$B+`H))U]?<B<@/3X@(E(B+`H))U]?<F5C
M;VYF:6=U<F4G(#T^(")296-O;F9I9W5R92(L"@DG7U]R96-O<F1?='EP92<@
M/3X@(E)E8V]R9"!T>7!E(BP*"2=?7W)E;&5A<V4G(#T^(")296QE87-E(BP*
M"2=?7W)E;6]T95]D8E]N;W1?<W5P<&]R=&5D7V)Y7VME>2<@/3X@)U)E;6]T
M92!D871A8F%S92!H;W-T:6YG(&ES(&YO="!S=7!P;W)T960@8GD@>6]U<B!L
M:6-E;G-E(&ME>2XG+`H))U]?<F5M;W9E)R`]/B`B4F5M;W9E(BP*"2=?7W)E
M;6]V95]C;VYF:7)M871I;VXG(#T^(")296UO=F%L(&-O;F9I<FUA=&EO;B(L
M"@DG7U]R97!O<G0G(#T^(")297!O<G0B+`H))U]?<F5P;W)T7V%U=&\G(#T^
M("=$96QI=F5R>2!S8VAE9'5L92<L"@DG7U]R97!O<G1?9F]R;2<@/3X@(E)E
M<&]R="!F;W)M(BP*"2=?7W)E<&]R=%]S:7IE7VYA)R`]/B`B4V5R=FEC92!I
M<R!U;F%V86EL86)L92(L"@DG7U]R97!O<G1S7VQI<W0G(#T^(")297!O<G1S
M(BP*"2=?7W)E<75E<W1E9"<@/3X@(E)E<75E<W1E9"(L"@DG7U]R97%U:7)E
M9%]F:65L9',G(#T^(")297%U:7)E9"!F:65L9',B+`H))U]?<F5S<%]N86UE
M7VEN=F%L:60G(#T^(")!=71O<F5S<&]N9&5R(&YA;64@:7,@:6YV86QI9"X@
M57-E(&]N;'D@86QP:&%N=6UE<FEC+"!D;W1S+"!U;F1E<G-C;W)E(&%N9"!W
M:&ET92!S<&%C97,@<WEM8F]L<RXB+`H))U]?8R<@/3X@(D$B+"`O+R!!8V-E
M<W,@=&\@8V]N=')O;"!P86YE;`H))U]?<R<@/3X@(E,B+`H))U]?<V5R=F5R
M7VYA;65?:7-?:6YV86QI9"<@/3X@(E-E<G9E<B!N86UE(&ES(&EN=F%L:60N
M(BP*"2=?7W-C<F5E;G-H;W1S)R`]/B`G4V-R965N<VAO=',G+`H))U]?<V-R
M:7!T7W=A<FYI;F<G(#T^(")">2!R96UO=FEN9R!T:&4@<V-R:7!T:6YG(&-A
M<&%B:6QI='D@9G)O;2!T:&ES(&1O;6%I;B!A;&P@:6YF;'5E;F-E9"!S8W)I
M<'1S('=I;&P@8F4@9&ES<&QA>65D(&EN('!L86EN('1E>'0@=VAE;B!C86QL
M960@8GD@82!B<F]W<V5R+B`@270@:7,@861V:7-A8FQE(&9O<B!T:&4@861M
M:6YI<W1R871O<B!T;R!R96UO=F4@86QL(&1E<&5N9&5N="!S8W)I<'1S(&9R
M;VT@=&AE(&=I=F5N(&1O;6%I;BXB+`H))U]?<V5C)R`]/B`B4V5C;VYD<R(L
M"@DG7U]S965?;&ES=%]O9E]L;V=G961?:6XG(#T^(")3964@=&AE(&QI<W0@
M;V8@8W5R<F5N=&QY(&QO9V=E9"!O;B!U<V5R<RXB+`H))U]?<V5L96-T7V-E
M<G1S7W1O7W)E;6]V92<@/3X@(E-E;&5C="!C97)T:69I8V%T97,@=&\@8F4@
M<F5M;W9E9"XB+`H))U]?<V5L96-T7V-L:65N='-?=&]?<F5M;W9E)R`]/B`B
M4V5L96-T(&-L:65N="!A8V-O=6YT<R!T;R!B92!R96UO=F5D+B(L"@DG7U]S
M96QE8W1?9&]M86EN<U]T;U]D969A=6QT7VAO<W0G(#T^(")396QE8W0@82!D
M;VUA:6X@=&\@<V5T(&%S(&1E9F%U;'0N(BP*"2=?7W-E;&5C=%]D;VUA:6YS
M7W1O7W)E;6]V92<@/3X@(E-E;&5C="!D;VUA:6YS('1O(&)E(')E;6]V960N
M(BP*"2=?7W-E;&5C=%]F:6QE<U]T;U]R96UO=F4G(#T^(")396QE8W0@9FEL
M97,@=&\@8F4@<F5M;W9E9"XB+`H))U]?<V5L96-T7VEP)R`]/B`B4V5L96-T
M(&%N($E0(&%D9')E<W,B+`H))U]?<V5L96-T7VEP7W1O7W)E;6]V92<@/3X@
M(E-E;&5C="!A;B!)4"!A9&1R97-S('1O(&)E(')E;6]V960N(BP*"2=?7W-E
M;&5C=%]T96UP;&%T92<@/3X@(E-E;&5C="!T96UP;&%T92(L"@DG7U]S96QE
M8W1?=&5M<&QA=&5S7W1O7W)E;6]V92<@/3X@(E-E;&5C="!T96UP;&%T97,@
M=&\@8F4@<F5M;W9E9"XB+`H))U]?<V5R=F5R)R`]/B`B4V5R=F5R(BP*"2=?
M7W-E<G9E<G-?;&ES="<@/3X@(E-L879E(%-E<G9E<G,B+`H))U]?<V5R=F5R
M7W1O=&%L)R`]/B`B4V5R=F5R(%1O=&%L(BP*"2=?7W-E<G9I8V4G(#T^(")3
M97)V:6-E(BP*"2=?7W-E<G9I8V5S)R`]/B`B4V5R=FEC97,B+`H))U]?<V5S
M<VEO;G,G(#T^(")397-S:6]N<R(L"@DG7U]S97-S:6]N<U]L:7-T)R`]/B`B
M4V5S<VEO;G,B+`H))U]?<V5T)R`]/B`B16YA8FQE(BP*"2=?7W-E='5P7VQO
M9V]?<')E9B<@/3X@(E-E="!U<"!L;V=O('!R;W!E<G1I97,B+`H))U]?<VAA
M<F5D)R`]/B`B4VAA<F5D(BP*"2=?7W-H961U;&5D7V)A8VMU<"<@/3X@(E-H
M961U;&5D($)A8VMU<"(L"@DG7U]S:&5L;%]A8V-E<W-?=V%R;FEN9R<@/3X@
M(D%L;&]W:6YG('-H96QL(&%C8V5S<R!T;R!T:&4@<WES=&5M(&ES(&AI9VAL
M>2!D86YG97)O=7,@9F]R('1H92!S>7-T96T@<V5C=7)I='DN($%L;&]W(&%C
M8V5S<R!T;R!T:&4@<WES=&5M(&]N;'D@:68@>6]U(&-L96%R;'D@=6YD97)S
M=&%N9"!W:&%T('EO=2!A<F4@9&]I;F<L(&%N9"!O;FQY('1O('1R=7-T960@
M=7-E<G,N($1O('EO=2!R96%L;'D@=V%N="!T;R!A;&QO=R!A8V-E<W,_(BP*
M"2=?7W-I=&5A<'!?;F]T7W-U<'!O<G1?:6Y?:V5Y)R`]/B`B4VET92!A<'!L
M:6-A=&EO;G,@87)E(&YO="!S=7!P;W)T960@8GD@=&AE(&QI8V5N<V4@:V5Y
M(BP*"2=?7W-I=&5A<'!?8V%N;F]T7W)E8V]N9FEG=7)E7W=I=&A?<F5M;W1E
M7V1A=&%B87-E)R`]/B`G5&AE(&-O;F9I9W5R871I;VX@;V8@=&AI<R!S:71E
M(&%P<&QI8V%T:6]N(&AA<R!B965N(&-H86YG960@;6%N=6%L;'DN($EN(&]R
M9&5R('1O('!R;W1E8W0@=&AE(&UA;G5A;"!M;V1I9FEC871I;VYS+"!R96-O
M;F9I9W5R871I;VX@=&AR;W5G:"!0;&5S:R!I<R!D:7-A;&QO=V5D+B<L"@DG
M7U]S:71E87!P7VQO8V%L7V1B7V1I<V%L;&]W960G(#T^("=!(')E;6]T92!D
M871A8F%S92!S97)V97(@:&%S(&)E96X@<V5L96-T960@87,@=&AE(&1E9F%U
M;'0@9&%T86)A<V4@;&]C871I;VXL(&)U="!T:&ES('-I=&4@87!P;&EC871I
M;VX@:7,@=6YA8FQE('1O('5S92!A(')E;6]T92!D871A8F%S92X@5&AE('-I
M=&4@87!P;&EC871I;VX@8V%N;F]T(&)E(&EN<W1A;&QE9"X@06X@=7!G<F%D
M92!O9B!T:&4@<VET92!A<'!L:6-A=&EO;B!P86-K86=E(&ES(')E8V]M;65N
M9&5D+B<L"@DG7U]S:71E87!P7W)E;6]T95]D871A8F%S92<@/3X@)U1H92!D
M871A8F%S92!C86X@8F4@:&]S=&5D(&]N(&$@<F5M;W1E('-E<G9E<BXG+`H)
M)U]?<VET95]A<'!L:6-A=&EO;B<@/3X@(E-I=&4@07!P;&EC871I;VXB+`H)
M)U]?<VET95]A<'!L:6-A=&EO;E]P86-K86=E)R`]/B`B4VET92!!<'!L:6-A
M=&EO;B!086-K86=E(BP*"2=?7W-I=&5?87!P;&EC871I;VY?<&%C:V%G97,G
M(#T^(")3:71E($%P<&QI8V%T:6]N(%!A8VMA9V5S(BP*"2=?7W-I=&5?87!P
M;&EC871I;VYS)R`]/B`B4VET92!!<'!L:6-A=&EO;G,B+`H))U]?<VET95]M
M86YA9V5M96YT)R`]/B`B5V5B(%!U8FQI<VAI;F<B+`DO+R!I;F1I<F5C=`H)
M)U]?<VEZ92<@/3X@(E-I>F4B+`H))U]?<VME;&5T;VXG(#T^(")3:V5L971O
M;B(L"@DG7U]S:VEN<R<@/3X@)U-K:6YS)RP*"2=?7W-M='`G(#T^(")33510
M(BP)+R\@:6YD:7)E8W0*"2=?7W-M='!?<W1A='5S)R`]/B`B4TU44"!S97)V
M97(@<W1A='5S(BP*"2=?7W-O;65?9FEE;&1S7V%R95]E;7!T>5]O<E]I;G9A
M;&ED)R`]/B`B4V]M92!F:65L9',@87)E(&5M<'1Y(&]R(&-O;G1A:6X@86X@
M:6UP<F]P97(@=F%L=64N(BP*"2=?7W-O;65?9FEE;&1S7V%R95]E;7!T>5]O
M<E]I;G9A;&ED7V]R7VQO;F<G(#T^(")3;VUE(&9I96QD<R!A<F4@96UP='D@
M;W(@8V]N=&%I;B!A;B!I;7!R;W!E<B!V86QU92X@5&AE('9A;'5E<R!S:&]U
M;&0@8F4@;&EM:71E9"!T;R`V-"!C:&%R86-T97)S+B!)9B!Y;W4@87)E('5S
M:6YG(&%N(&EN=&5R;F%T:6]N86QI>F5D(&1O;6%I;B!N86UE+"!M86ME('-U
M<F4@96%C:"!P87)T(&]F('1H92!D;VUA:6X@;F%M92!B971W965N(&1O=',@
M9&]E<R!N;W0@97AC965D(#8S('-Y;6)O;',@=VAE;B!T<F%N<V9O<FUE9"!T
M;R!!4T-)22!F;W)M870N(BP*"2=?7W-P86UA<W-A<W-I;B<@/3X@(E-P86U!
M<W-A<W-I;B(L"@DG7U]S<&%M87-S87-S:6Y?<W1A='5S)R`]/B`B4W!A;4%S
M<V%S<VEN('-T871U<R(L"@DG7U]S<&QI=&5D7V)A8VMU<"<@/3X@(BAM=6QT
M:79O;'5M92!B86-K=7`I(BP*"2=?7W-P;&ET7V)A8VMU<%]F:6QE)R`]/B`B
M0W)E871E(&$@;75L=&EV;VQU;64@8F%C:W5P(BP*"2=?7W-P;&ET7V)A8VMU
M<%]S:7IE)R`]/B`B5F]L=6UE('-I>F4B+`H))U]?<W!L:71?8F%C:W5P7VQE
M<W-?=&AA;E\U,#`G(#T^(")6;VQU;64@<VEZ97,@;&5S<R!T:&%N(#4P,"!M
M96=A8GET97,@87)E(&YO="!S=7!P;W)T960B+`H))U]?<W-I)R`]/B`B4U-)
M(BP*"2=?7W-S:5]S=7!P;W)T)R`]/B`B4U-)('-U<'!O<G0B+`H))U]?<W-L
M)R`]/B`G4U-,)RP*"2=?7W-S;%]S=7!P;W)T)R`]/B`B4U-,('-U<'!O<G0B
M+`H))U]?<V%M95]S<VPG(#T^(")5<V4@82!S:6YG;&4@9&ER96-T;W)Y(&9O
M<B!H;W5S:6YG(%-33"!A;F0@;F]N+5-33"!C;VYT96YT(BP*"2=?7W-A;65?
M<W-L7V-U)R`]/B`B0V]M;6]N(%-33"].;VXM4U-,(&-O;G1E;G0B+`H))U]?
M<W1A=&4G(#T^(")3=&%T92]0<F]V:6YC92(L"@H))U]?<W1A='5S7U]!8W1I
M=F4G(#T^("=!8W1I=F4G+`H))U]?<W1A='5S7U]A8W1I=F4G(#T^("=A8W1I
M=F4G+`H))U]?<W1A='5S7U]087-S:79E)R`]/B`G1&ES86)L960G+`H))U]?
M<W1A='5S7U]P87-S:79E)R`]/B`G9&ES86)L960G+`H))U]?<W1A='5S7U]O
M9F8G(#T^("=D:7-A8FQE9"<L"@DG7U]S=&%T=7-?7W=I=&A?<&%R96YT)R`]
M/B`G9&ES86)L960G+`H))U]?<W1A='5S7U]B86-K=7!?<F5S=&]R92<@/3X@
M)W1E;7!O<F%R:6QY('-U<W!E;F1E9"!F;W(@8F%C:VEN9R!U<"!O<B!R97-T
M;W)I;F<G+`H))U]?<W1A='5S7U]A9&UI;B<@/3X@)V1I<V%B;&5D(&)Y(&%D
M;6EN)RP*"2=?7W-T871U<U]?<F5S<V5L97(G(#T^("=D:7-A8FQE9"!B>2!R
M97-E;&QE<B<L"@DG7U]S=&%T=7-?7V-L:65N="<@/3X@)V1I<V%B;&5D(&)Y
M(&-L:65N="<L"@DG7U]S=&%T=7-?7W5N:VYO=VXG(#T^("=S=&%T=7,@:7,@
M=6YK;F]W;B<L"@H))U]?<W1A='5S7V]F)R`]/B`B)3$@<W1A='5S(BP*"@DO
M+R!E;F0@;V8@86MS<R!P87)T"@H)+R\@<VAR86UK;R!P87)T"@H))U]?<W1U
M;FYE;"<@/3X@(E-T=6YN96PB+`H))U]?<W1U;FYE;%]S97)V97(G(#T^(")3
M='5N;F5L('-E<G9E<B(L"2\O(&EN9&ER96-T"@DG7U]S=6)D;VUA:6XG(#T^
M(")3=6)D;VUA:6XB+`H))U]?<W5B9&]M86EN7VYA;64G(#T^(")3=6)D;VUA
M:6X@;F%M92(L"@DG7U]S=6)D;VUA:6Y?;F%M95]I;E]!4T-)25]F;W)M)R`]
M/B`B26X@05-#24D@9F]R;6%T(BP*"2=?7W-U8F1O;6%I;G,G(#T^(")3=6)D
M;VUA:6YS(BP*"2=?7W-U8F1O;6%I;G-?;&ES="<@/3X@(E-U8F1O;6%I;G,B
M+`H))U]?<W5B9&]M86EN<U]N;W1?<W5P<&]R=%]I;E]K97DG(#T^(")3=6)D
M;VUA:6X@;W!E<F%T:6]N<R!A<F4@;F]T('-U<'!O<G1E9"!B>2!T:&4@;&EC
M96YS92!K97DB+`H))U]?<WES7W5S97)?='EP92<@/3X@(D944"!U<V5R(BP*
M"2=?7W-Y<U]U<V5R7W1Y<&5?;6%I;B<@/3X@(E5S92!T:&4@1E10('5S97(@
M86-C;W5N="!O9B!T:&4@;6%I;B!D;VUA:6XB+`H))U]?<WES7W5S97)?='EP
M95]N871I=F4G(#T^(")#<F5A=&4@82!S97!A<F%T92!&5%`@=7-E<B!A8V-O
M=6YT(&9O<B!T:&ES('-U8F1O;6%I;B(L"@DG7U]T)R`]/B`B5"(L"@DG7U]T
M87)G971?9&]M86EN)R`]/B`B5&%R9V5T(&1O;6%I;B(L"@DG7U]T87-K)R`]
M/B`G5&%S:R<L"@DG7U]T87-K<U]L:7-T)R`]/B`G5&%S:W,G+`H))U]?=&5M
M<&QA=&4G(#T^(")496UP;&%T92(L"@DG7U]T96UP;&%T95]N;W1?86-C97!T
M960G(#T^(")5;F%B;&4@=&\@86-C97!T('1H92!T96UP;&%T93H@=&AE(&9O
M;&QO=VEN9R!L:6UI=&%T:6]N<R!A<F4@97AC965D960N(BP*"2=?7W1E;7!L
M871E<R<@/3X@(E1E;7!L871E<R(L"@DG7U]T96UP;&%T97-?;&ES="<@/3X@
M(E1E;7!L871E<R(L"@DG7U]T97)A)R`]/B`B5"(L"@DG7U]T97AT)R`]/B`B
M5&5X="(L"@DG7U]T:71L92<@/3X@(E1I=&QE(BP*"2=?7W1O;6-A="<@/3X@
M(E1O;6-A="(L"@DG7U]T;VUC871?;F]T7W-U<'!O<G1?:6Y?:V5Y)R`]/B`B
M5&]M8V%T(&ES(&YO="!S=7!P;W)T960@8GD@=&AE(&QI8V5N<V4@:V5Y(BP*
M"2=?7W-P86UA<W-A<W-I;E]N;W1?<W5P<&]R=%]I;E]K97DG(#T^(")3<&%M
M07-S87-S:6X@:7,@;F]T('-U<'!O<G1E9"!B>2!T:&4@;&EC96YS92!K97DB
M+`H))U]?=&]M8V%T7W-T871U<R<@/3X@(E1O;6-A="!S=&%T=7,B+`H))U]?
M=&]O;',G(#T^(")4;V]L<R(L"@DG7U]T;W1A;"<@/3X@(E1O=&%L("4Q(BP*
M"2=?7W1O=&%L7W-I>F4G(#T^(")4;W1A;"!S:7IE(BP*"2=?7W1O=&%L7W5S
M960G(#T^(")4;W1A;"!5<V5D(BP*"2=?7W1T<R<@/3X@(DAE;'`@1&5S:R(L
M"@DG7U]T<F%F9FEC)R`]/B`B5')A9F9I8R(L"@DG7U]T<F%F9FEC7V)Y7V-L
M:65N="<@/3X@(E1R869F:6,@8GD@8VQI96YT(BP*"2=?7W1R869F:6-?8GE?
M9&]M86EN)R`]/B`B5')A9F9I8R!B>2!D;VUA:6XB+`H))U]?=')A9F9I8U]B
M>5]S97)V:6-E)R`]/B`B5')A9F9I8R!B>2!S97)V:6-E(BP*"2=?7W1R869F
M:6-?:&ES=&]R>2<@/3X@(E1R869F:6,@:&ES=&]R>2(L"@DG7U]U;F%B;&5?
M8VAA;F=E7VQO8V%L92<@/3X@(E5N86)L92!T;R!C:&%N9V4@=&AE(&EN=&5R
M9F%C92!L86YG=6%G93H@)3$B+`H))U]?=6YA8FQE7V-R96%T95]N97=?9&]M
M)R`]/B`B56YA8FQE('1O(&-R96%T92!N97<@9&]M86EN.B`E,2(L"@DG7U]U
M;F%B;&5?9&5F:6YE7V1O;5]N86UE)R`]/B`B56YA8FQE('1O(&1E9FEN92!D
M;VUA:6X@;F%M93H@)3$B+`H))U]?=6YA8FQE7V1E9FEN95]N96-E<W-A<GE?
M<')O<&5R=&EE<R<@/3X@(E5N86)L92!T;R!D969I;F4@86QL(')E<75I<F5D
M('!R;W!E<G1I97,N(BP*"2=?7W5N86)L95]D969I;F5?<')O<&5R=&EE<R<@
M/3X@(E5N86)L92!T;R!D969I;F4@<')O<&5R=&EE<SH@)3$B+`H))U]?=6YA
M8FQE7V5X96-?=71I;"<@/3X@(E5N86)L92!T;R!E>&5C=71E('5T:6QI='DZ
M("4Q(BP*"2=?7W5N86)L95]G96YE<F%T95]C97)T)R`]/B`B56YA8FQE('1O
M(&=E;F5R871E(&-E<G1I9FEC871E.B`E,2(L"@DG7U]U;F%B;&5?9V5N97)A
M=&5?8W-R)R`]/B`B56YA8FQE('1O(&=E;F5R871E($-34CH@)3$B+`H))U]?
M=6YA8FQE7V=E=%]D;G-?85]R96-S)R`]/B`B56YA8FQE('1O(')E=')I979E
M(&EP(&%D9')E<W-E<R!F;W(@02!$3E,@<F5C;W)D<R!F;W(@=&AI<R!H;W-T
M:6YG(&%C8V]U;G0Z("4Q(BP*"2=?7W5N86)L95]G971?;6)O>%]Q=6]T82<@
M/3X@(E5N86)L92!T;R!R971R:65V92!T:&4@:6YF;W)M871I;VX@;VX@=&AE
M(&UA:6QB;W@@<VEZ92!L:6UI="XB+`H))U]?=6YA8FQE7W)E9&ER96-T7W1O
M7VUY<V5L9B<@/3X@(E5N86)L92!T;R!R961I<F5C="!T;R!O;F5S96QF+B(L
M"@DG7U]U;F%B;&5?<F5M;W9E7V-L:65N="<@/3X@(E5N86)L92!T;R!R96UO
M=F4@8VQI96YT.B`E,2(L"@DG7U]U;F%B;&5?<V5T7W5P7VUB;WA?<75O=&$G
M(#T^(")5;F%B;&4@=&\@<V5T('1H92!M86EL8F]X('-I>F4@;&EM:70@9F]R
M('1H92!D;VUA:6XZ("4Q(BP*"2=?7W5N86)L95]S971U<%]P87-S)R`]/B`B
M56YA8FQE('1O('-E="!P87-S=V]R9#H@)3$B+`H))U]?=6YA8FQE7W1O7V-R
M96%T95]N97=?86-C;W5N="<@/3X@(E5N86)L92!T;R!C<F5A=&4@;F5W(&%C
M8V]U;G0Z("4Q(BP*"2=?7W5N86)L95]T;U]D969I;F5?9&)?<VEZ92<@/3X@
M(E5N86)L92!T;R!D969I;F4@=&AE(&1A=&%B87-E('-I>F4B+`H))U]?=6YA
M8FQE7W1O7V5N86)L95]S:&]R=%]N86UE<R<@/3X@(E5N86)L92!T;R!A;&QO
M=R!T:&4@=7-E(&]F('-H;W)T(&UA:6P@;F%M97,@9F]R(%!/4#,O24U!4"!A
M8V-O=6YT<RXB+`H))U]?=6YA8FQE7W1O7V9E=&-H7V1A=&%?9G)O;5]S=6)M
M:70G(#T^(")5;F%B;&4@=&\@9F5T8V@@=&AE('-U8FUI='1E9"!D871A.B`E
M,2(L"@DG7U]U;F%B;&5?=&]?;W!E;E]F:6QE)R`]/B`B56YA8FQE('1O(&]P
M96X@=&AE(&9I;&4@)3$Z("4R+B(L"@DG7U]U;F%B;&5?=&]?=7!D871E7W-U
M8F1O;6%I;B<@/3X@(E5N86)L92!T;R!M86ME(&-H86YG97,@=&\@=&AE('-U
M8F1O;6%I;CH@)3$B+`H))U]?=6YA8FQE7W5P9&%T95]C;%]D871A)R`]/B`B
M56YA8FQE('1O('5P9&%T92!C;&EE;G0@9&%T83H@)3$B+`H))U]?=6YA8FQE
M7W5P9&%T95]D8E]P87)A;7,G(#T^(")5;F%B;&4@=&\@=7!D871E(&1A=&%B
M87-E('!A<F%M971E<G,Z("4Q(BP*"2=?7W5N86)L95]U<&1A=&5?9&]M7V1A
M=&$G(#T^(")5;F%B;&4@=&\@=7!D871E(&1O;6%I;B!D871A.B`E,2(L"@DG
M7U]U;F1E9FEN960G(#T^(")U;F1E9FEN960B+`H))U]?=6YI;G-T86QL)R`]
M/B`B56YI;G-T86QL(BP*"2=?7W5N:VYO=VY?97)R;W(G(#T^(")5;FMN;W=N
M(&5R<F]R(BP*"2=?7W5N;&EM:71E9"<@/3X@(E5N;&EM:71E9"(L"@DG7U]U
M;FQI;6ET961?;&]W97(G(#T^(")5;FQI;6ET960B+`H))U]?=6YS970G(#T^
M(")$:7-A8FQE(BP*"2=?7W5P9&%T92<@/3X@(E5P9&%T92(L"@DG7U]U<&QO
M861?8V5R=%]F:6QE)R`]/B`B57!L;V%D(&-E<G1I9FEC871E(&9I;&4@(BP*
M"2=?7W5P;&]A9&5D7V9I;&5?:7-?:6YV86QI9"<@/3X@(E5P;&]A9&5D(&9I
M;&4@:7,@:6YV86QI9#H@)3$B+`H))U]?=7)L)R`]/B`B55),(BP*"2=?7W5S
M86=E)R`]/B`B1&ES:R!U<V%G92(L"@DG7U]U<V5D)R`]/B`B57-E9"(L"@DG
M7U]U<V5R)R`]/B`B57-E<B(L"@DG7U]U<V5R7V%L<F5A9'E?97AI<W0G(#T^
M(")5<V5R("4Q(&%L<F5A9'D@97AI<W1S+B(L"@DG7U]U<V5R7V%L<F5A9'E?
M97AI<W1S)R`]/B`B57-E<B`E,2!A;')E861Y(&5X:7-T<RXB+`H))U]?=7-E
M<E]A;')E861Y7VQO9V=E9"<@/3X@(D%N;W1H97(@=7-E<B!W:71H('1H92!S
M86UE(&QO9VEN("@E,2D@:7,@86QR96%D>2!L;V=G960@;VX@=&\@=&AE("!C
M;VYT<F]L('!A;F5L+B(L"@DG7U]V86QU92<@/3X@(E9A;'5E(BP*"2=?7W9E
M<G-I;VXG(#T^(")697)S:6]N(BP*"2=?7W9H7W1Y<&4G(#T^(")6:7)T=6%L
M(&AO<W0@='EP92(L"@DG7U]V:&]S='-?87!A8VAE7W-T871U<R<@/3X@(E=E
M8B!S97)V97(@<W1A='5S(BP*"2=?7W=R;VYG7V-H87)S971?8V]N=F5R<VEO
M;B<@/3X@)U=R;VYG(&-H87)S970L(&-O;G9E<G-I;VX@9G)O;2`B)3$B('1O
M("(E,B(@:7,@;F]T(&%L;&]W960G+`H))U]?=V%R;FEN9U\G(#T^(")787)N
M:6YG(2(L"@DG7U]W87)N:6YG7V5X8VQ?:7!?;G5M)R`]/B`B17AC;'5S:79E
M($E0(&%D9')E<W,B+`H))U]?=V%R;FEN9U]E>'!I<F%T:6]N)R`]/B`B17AP
M:7)A=&EO;B!D871E(BP*"2=?7W=E8E]A<'!S)R`]/B`B2F%V82!A<'!L:6-A
M=&EO;G,B+`H))U]?=V5B7W-C<FEP=&EN9R<@/3X@(E=E8B!S8W)I<'1I;F<B
M+`DO+R!I;F1I<F5C=`H))U]?=V5B7W-E<G8G(#T^(")796(@<V5R=F5R(BP)
M+R\@:6YD:7)E8W0*"2=?7W=E8E]S=&%T:7-T:6,G(#T^(")796(@<W1A=&ES
M=&EC<R(L"2\O(&EN9&ER96-T"@DG7U]W96)M86EL)R`]/B`B5V5B36%I;"(L
M"2\O("MI;F1I<F5C=`H))U]?=V5B<W1A=%]N;W1?:6YS=&%L;&5D)R`]/B`B
M5V5B86QI>F5R(&ES(&YO="!C=7)R96YT;'D@:6YS=&%L;&5D(&]N('1H92!S
M97)V97(N($-O;G1A8W0@=&AE('-E<G9E<B!A9&UI;FES=')A=&]R('1O(&AA
M=F4@=&AE(%=E8F%L:7IE<B!I;G-T86QL960N(BP*"2=?7W=E8G-T871?<W5P
M<&]R="<@/3X@(E=E8B!S=&%T:7-T:6-S(BP*"2=?7W=E8G5S97(G(#T^(")7
M96(@=7-E<B(L"@DG7U]W96)U<V5R<U]L:7-T)R`]/B`B5V5B('5S97)S(BP*
M"2=?7W=E96ML>2<@/3X@(E=E96ML>2(L"@DG7U]W:&%T<U]N97=?:6Y?=F5R
M<VEO;B<@/3X@(E=H870G<R!N97<@:6X@4&QE<VL@)3$_(BP*"2=?7W=R;VYG
M7VAO<W1I;F=?='EP95]?;F]N92<@/3X@)U1H97)E(&ES(&YO('!H>7-I8V%L
M(&AO<W1I;F<@8V]N9FEG=7)E9"!O;B!T:&ES(&1O;6%I;BXG+`H))U]?=W)O
M;F=?:&]S=&EN9U]T>7!E7U]S=&1?9G=D)R`]/B`G5&AI<R!D;VUA:6X@:&%S
M('-T86YD87)D(&9O<G=A<F1I;F<@8V]N9FEG=7)E9"X@5&AI<R!O<&5R871I
M;VX@:7,@879A:6QA8FQE(&]N;'D@9F]R(&1O;6%I;G,@=VET:"!P:'ES:6-A
M;"!H;W-T:6YG+B<L"@DG7U]W<F]N9U]H;W-T:6YG7W1Y<&5?7V9R;5]F=V0G
M(#T^("=4:&ES(&1O;6%I;B!H87,@9G)A;64@9F]R=V%R9&EN9R!C;VYF:6=U
M<F5D+B!4:&ES(&]P97)A=&EO;B!I<R!A=F%I;&%B;&4@;VYL>2!F;W(@9&]M
M86EN<R!W:71H('!H>7-I8V%L(&AO<W1I;F<N)RP*"2=?7W=U)R`]/B`B5V5B
M('5S97)S(BP*"2=?7W=W=R<@/3X@(E=75R(L"@DG7U]W=W=?<')E9FEX)R`]
M/B`B5U=7('!R969I>"(L"@DG7U]W=W=?<')E9FEX7W=A<U]C:&%N9V5D)R`]
M/B`B5U=7('!R969I>"!W87,@8VAA;F=E9"X@0F4@<W5R92!T;R!M;V1I9GD@
M=&AE(%-33"!C97)T:69I8V%T92!A8V-O<F1I;F=L>2XB+`H))U]?>65A<B<@
M/3X@(EEE87(B+`H))U]?>65A<BAS*2<@/3X@(EEE87(H<RDB+`H))U]?>65S
M)R`]/B`B665S(BP*"2=?7WEO=2<@/3X@(EEO=2(L"@DG7U]Z:7!?8V]D92<@
M/3X@(E!O<W1A;"]:25`@8V]D92(L"@DG7U]F;W)M7VYO<FUA;"<@/3X@(DYO
M<FUA;"(L"@DG7U]F;W)M7V%D=F%N8V5D)R`]/B`B061V86YC960B+`H*"2=?
M7VUA>%]D;VUA:6YS7VQI;6ET7W5S86=E)R`]/B`G)3$@;V8@)3(@9&]M86EN
M*',I('5S960[("4S(&%V86EL86)L92<L"@DG7U]M87A?9&]M86EN<U]N;U]L
M:6UI=%]U<V%G92<@/3X@)R4Q(&]F('5N;&EM:71E9"!D;VUA:6YS('5S960G
M+`H))U]?;6%X7VUA:6QB;WAE<U]L:6UI=%]U<V%G92<@/3X@)R4Q(&]F("4R
M(&UA:6QB;W@H97,I('5S960[("4S(&%V86EL86)L92<L"@DG7U]M87A?;6%I
M;&)O>&5S7VYO7VQI;6ET7W5S86=E)R`]/B`G)3$@;V8@=6YL:6UI=&5D(&UA
M:6QB;WAE<R!U<V5D)RP*"2=?7V1I<VM?<W!A8V5?;&EM:71?=7-A9V4G(#T^
M("<E,2!O9B`E,B!U<V5D.R`E,R!A=F%I;&%B;&4G+`H))U]?9&ES:U]S<&%C
M95]N;U]L:6UI=%]U<V%G92<@/3X@)R4Q(&]F('5N;&EM:71E9"!D:7-K('-P
M86-E('5S960G+`H))U]?=')A9F9I8U]L:6UI=%]U<V%G92<@/3X@)R4Q(&]F
M("4R('5S960[("4S(&%V86EL86)L92<L"@DG7U]T<F%F9FEC7VYO7VQI;6ET
M7W5S86=E)R`]/B`G)3$@;V8@=6YL:6UI=&5D('1R869F:6,@=7-E9"<L"@DG
M7U]M87A?<W5B9&]M86EN<U]L:6UI=%]U<V%G92<@/3X@)R4Q(&]F("4R('-U
M8F1O;6%I;BAS*2!U<V5D.R`E,R!A=F%I;&%B;&4G+`H))U]?;6%X7W-U8F1O
M;6%I;G-?;F]?;&EM:71?=7-A9V4G(#T^("<E,2!O9B!U;FQI;6ET960@<W5B
M9&]M86EN<R!U<V5D)RP*"@DG7U]M96U?=7-A9V5?:6YF;R<@/3X@)R4Q(&]F
M("4R('5S960[("4S(&%V86EL86)L92<L"@DG7U]D:7-K7W5S86=E7VEN9F\G
M(#T^("<E,2!O9B`E,B!U<V5D.R`E,R!A=F%I;&%B;&4G+`H*"2=A8W1I;VYL
M;V=?7V-O;F9I<FU?8VQE86Y?;&]G)R`]/B`B07)E('EO=2!S=7)E('EO=2!W
M:7-H('1O(&1E;&5T92!T:&4@<V5L96-T960@86-T:6]N(&QO9R!R96-O<F1S
M/R(L"@DG86-T:6]N;&]G7U]D:6=I=%]E>'!E8W1E9"<@/3X@(D$@;G5M8F5R
M(&5X<&5C=&5D.B`E,2(L"@DG86-T:6]N;&]G7U]D;VYT7W)E;6]V95]R96-S
M)R`]/B`B9&\@;F]T(')E;6]V92!R96-O<F1S(BP*"2=A8W1I;VYL;V=?7V9R
M;VU?9&%T92<@/3X@(F9R;VTZ(BP*"2=A8W1I;VYL;V=?7VEN8V]R<F5C=%]R
M;W1A=&EO;B<@/3X@(DEN=F%L:60@;&]G(')O=&%T:6]N('!A<F%M971E<G,@
M<W!E8VEF:65D.B`E,2(L"@DG86-T:6]N;&]G7U]J<U]I;F-O<G)E8W1?9&%T
M92<@/3X@(DEN=F%L:60@9&%T92!S<&5C:69I960B+`H))V%C=&EO;FQO9U]?
M:G-?:6YC;W)R96-T7VYU;5]P97)I;V1S)R`]/B`B26YV86QI9"!R;W1A=&EO
M;B!P97)I;V0@<W!E8VEF:65D(BP*"2=A8W1I;VYL;V=?7VIS7VEN8V]R<F5C
M=%]N=6U?<F5C;W)D<R<@/3X@(DEN=F%L:60@;G5M8F5R(&]F(')E8V]R9',@
M<W!E8VEF:65D(BP*"2=A8W1I;VYL;V=?7VQO9V=E9%]A8W1I;VYS)R`]/B`B
M3&]G9V5D(&%C=&EO;G,B+`H))V%C=&EO;FQO9U]?<&5R:6]D7V1A>2<@/3X@
M(F1A>7,B+`H))V%C=&EO;FQO9U]?<&5R:6]D7VUO;G1H)R`]/B`B;6]N=&AS
M(BP*"2=A8W1I;VYL;V=?7W!E<FEO9%]W965K)R`]/B`B=V5E:W,B+`H))V%C
M=&EO;FQO9U]?<V5T=&EN9W,G(#T^(")!8W1I;VX@;&]G('-E='1I;F=S(BP*
M"2=A8W1I;VYL;V=?7W-T;W)E7VQO9W-?:6Y?9&(G(#T^(")3=&]R92!R96-O
M<F1S(&EN('1H92!D871A8F%S92(L"@DG86-T:6]N;&]G7U]S=&]R95]N=6UB
M97(G(#T^(")E;G1R:65S(BP*"2=A8W1I;VYL;V=?7W1O7V1A=&4G(#T^(")T
M;SHB+`H))V%C=&EO;FQO9U]?=6YK;F]W;E]R;W1?<&5R:6]D)R`]/B`B56YK
M;F]W;B!R;W1A=&EO;B!P97)I;V0Z("4Q(BP*"2=A8W1I;VYL;V=?7W5N:VYO
M=VY?<F]T7W1Y<&4G(#T^(")5;FMN;W=N(')O=&%T:6]N('1Y<&4Z("4Q(BP*
M"2=A8W1I;VYL;V=?7W=R;VYG7V1A=&5?<&5R:6]D)R`]/B`B26YV86QI9"!D
M871E(BP*"2=A8W1I;VYL;V=?7W-E<W-I;VY?<')E9F5R96YC97,G(#T^("=,
M;V=I;B!S971T:6YG<R<L"@H))V%C=&EO;FQO9U]?861M:6Y?:6YF;R<@/3X@
M)T%D;6EN:7-T<F%T;W(@:6YF;W)M871I;VXG+`H))V%C=&EO;FQO9U]?<V5R
M=FEC92<@/3X@)U-E<G9I8V4G+`H))V%C=&EO;FQO9U]?:7!?861D<B<@/3X@
M)TE0(&%D9')E<W,G+`H))V%C=&EO;FQO9U]?8VQI96YT)R`]/B`G0VQI96YT
M(&%C8V]U;G0G+`H))V%C=&EO;FQO9U]?8VQI96YT7W-T871U<R<@/3X@)T-L
M:65N="!A8V-O=6YT('-T871U<R<L"@DG86-T:6]N;&]G7U]C;&EE;G1?<')E
M9F5R96YC97,G(#T^(")#;&EE;G0G<R!I;G1E<F9A8V4@<')E9F5R96YC97,B
M+`H))V%C=&EO;FQO9U]?8VQI96YT7VQI;6ET<R<@/3X@)T-L:65N="!A8V-O
M=6YT(&QI;6ET<R<L"@DG86-T:6]N;&]G7U]C;&EE;G1?;&EM:71?<VEZ92<@
M/3X@(D1I<VL@<W!A8V4@;&EM:70@9F]R(&-L:65N="!A8V-O=6YT(BP*"2=A
M8W1I;VYL;V=?7V-L:65N=%]L:6UI=%]T<F%F9FEC)R`]/B`B5')A9F9I8R!L
M:6UI="!F;W(@8VQI96YT(&%C8V]U;G0B+`H))V%C=&EO;FQO9U]?8VQI96YT
M7W!E<FUI<W-I;VYS)R`]/B`B0VQI96YT)W,@<&5R;6ES<VEO;G,B+`H))V%C
M=&EO;FQO9U]?8VQI96YT7VEP7W!O;VPG(#T^(")#;&EE;G0G<R!)4"!P;V]L
M(BP*"2=A8W1I;VYL;V=?7V-L:65N=%]S:71E87!P)R`]/B`B0VQI96YT)W,@
M<VET92!A<'!L:6-A=&EO;B!P;V]L(BP*"2=A8W1I;VYL;V=?7V1O;6%I;E]U
M<V5R)R`]/B`G1&]M86EN(&%D;6EN:7-T<F%T;W(@86-C;W5N="<L"@DG86-T
M:6]N;&]G7U]D;VUA:6XG(#T^("=$;VUA:6XG+`H))V%C=&EO;FQO9U]?9&]M
M86EN7V]W;F5R)R`]/B`G1&]M86EN(&]W;F5R)RP*"2=A8W1I;VYL;V=?7V1O
M;6%I;E]S=&%T=7,G(#T^("=$;VUA:6X@<W1A='5S)RP*"2=A8W1I;VYL;V=?
M7V1O;6%I;E]D;G,G(#T^("=$;VUA:6X@1$Y3('IO;F4G+`H))V%C=&EO;FQO
M9U]?<W5B9&]M86EN)R`]/B`G4W5B9&]M86EN)RP*"2=A8W1I;VYL;V=?7V1A
M<VAB;V%R9%]P<F5S970G(#T^("=$97-K=&]P('!R97-E="<L"@DG86-T:6]N
M;&]G7U]D;VUA:6Y?86QI87,G(#T^("=$;VUA:6X@86QI87,G+`H))V%C=&EO
M;FQO9U]?9&]M86EN7V%L:6%S7V1N<R<@/3X@)T1O;6%I;B!A;&EA<R!$3E,@
M>F]N92<L"@DG86-T:6]N;&]G7U]D;VUA:6Y?;&EM:71S)R`]/B`G1&]M86EN
M(&QI;6ET<R<L"@DG86-T:6]N;&]G7U]D;VUA:6Y?;&EM:71?<VEZ92<@/3X@
M)T1I<VL@<W!A8V4@;&EM:70@9F]R(&1O;6%I;B<L"@DG86-T:6]N;&]G7U]D
M;VUA:6Y?;&EM:71?=')A9F9I8R<@/3X@)U1R869F:6,@;&EM:70@9F]R(&1O
M;6%I;B<L"@DG86-T:6]N;&]G7U]C<%]U<V5R)R`]/B`G0V]N=')O;"!P86YE
M;"!U<V5R)RP*"2=A8W1I;VYL;V=?7VUA:6QN86UE)R`]/B`G36%I;"!N86UE
M)RP*"2=A8W1I;VYL;V=?7VUA:6QL:7-T)R`]/B`G36%I;&EN9R!L:7-T)RP*
M"2=A8W1I;VYL;V=?7W!H;W-T:6YG)R`]/B`G4&AY<VEC86P@:&]S=&EN9R<L
M"@DG86-T:6]N;&]G7U]F;W)W87)D:6YG)R`]/B`G4W1A;F1A<F0@;W(@9G)A
M;64@9F]R=V%R9&EN9R!H;W-T:6YG)RP*"2=A8W1I;VYL;V=?7W=E8G5S97(G
M(#T^("=796(@=7-E<B!A8V-O=6YT)RP*"2=A8W1I;VYL;V=?7W-I=&5?87!P
M;&EC871I;VXG(#T^("=3:71E(&%P<&QI8V%T:6]N)RP*"2=A8W1I;VYL;V=?
M7W-I=&5?87!P;&EC871I;VY?<&%C:V%G92<@/3X@)U-I=&4@87!P;&EC871I
M;VX@<&%C:V%G92<L"@DG86-T:6]N;&]G7U]L:6-E;G-E)R`]/B`G3&EC96YS
M92!K97DG+`H*"2=A8W1I;VYL;V=?7VQI;6ET7W)E86-H960G(#T^("=R96%C
M:&5D)RP*"2=A8W1I;VYL;V=?7V%D9&5D)R`]/B`G861D960G+`H))V%C=&EO
M;FQO9U]?<F5M;W9E9"<@/3X@)W)E;6]V960G+`H))V%C=&EO;FQO9U]?8VAA
M;F=E)R`]/B`G8VAA;F=E9"<L"@DG86-T:6]N;&]G7U]U<&1A=&4G(#T^("=U
M<&1A=&5D)RP*"2=A8W1I;VYL;V=?7V5X<&ER960G(#T^("=E>'!I<F5D)RP*
M"2=A8W1I;VYL;V=?7V-R96%T92<@/3X@)V-R96%T960G+`H))V%C=&EO;FQO
M9U]?9&5L971E)R`]/B`G9&5L971E9"<L"@DG86-T:6]N;&]G7U]S97)V:6-E
M7W-T;W`G(#T^("=S=&]P<&5D)RP*"2=A8W1I;VYL;V=?7W-E<G9I8V5?<F5S
M=&%R="<@/3X@)W)E<W1A<G1E9"<L"@DG86-T:6]N;&]G7U]S97)V:6-E7W-T
M87)T)R`]/B`G<W1A<G1E9"<L"@DG86-T:6]N;&]G7U]L;V=I;B<@/3X@)VQO
M9V=E9"!I;B<L"@DG86-T:6]N;&]G7U]L;V=O=70G(#T^("=L;V=G960@;W5T
M)RP*"2=A8W1I;VYL;V=?7VEN<W1A;&PG(#T^("=I;G-T86QL960G+`H))V%C
M=&EO;FQO9U]?=6YI;G-T86QL)R`]/B`G=6YI;G-T86QL960G+`H))V%C=&EO
M;FQO9U]?<F5C;VYF:6=U<F4G(#T^("=R96-O;F9I9W5R960G+`H*"2=A9&UI
M;E]E9%]?961I=%]A9&UI;FES=')A=&]R7VEN9F\G(#T^(")%9&ET(&%D;6EN
M:7-T<F%T;W(@:6YF;W)M871I;VXB+`H))V%D;6EN7V5D7U]I7W=O=6QD7VQI
M:V5?<F5C:65V95]A;FYO=6YC92<@/3X@(DD@=V]U;&0@;&EK92!T;R!R96-E
M:79E('!E<FEO9&EC(&4M;6%I;',@9G)O;2!35W-O9G0L($EN8RX@86YN;W5N
M8VEN9R!N97<@<')O9'5C=',L(&1I<V-O=6YT<R!A;F0@;6]R92XB+`H))V%D
M;6EN7V5D7U]C<F5A=&5?9&5F875L=%]C;&EE;G0G(#T^("))('=O=6QD(&QI
M:V4@=&\@8W)E871E(&$@9&5F875L="!C;&EE;G0@86-C;W5N="XB+`H))V%D
M;6EN7V5D7U]U;F%B;&5?=7!D871E)R`]/B`B56YA8FQE('1O('5P9&%T92!A
M9&UI;FES=')A=&]R(&EN9F]R;6%T:6]N.B`E,2(L"@DG86YO;F9T<%]?86QL
M;W=?=7!L;V%D7VEN8V]M:6YG)R`]/B`B06QL;W<@=7!L;V%D:6YG('1O(&EN
M8V]M:6YG(&1I<F5C=&]R>2(L"@DG86YO;F9T<%]?86QL;W=?8W)E871E7V1I
M<G,G(#T^("=!;&QO=R!C<F5A=&EO;B!O9B!D:7)E8W1O<FEE<R!I;B!T:&4@
M:6YC;VUI;F<@9&ER96-T;W)Y)RP*"2=A;F]N9G1P7U]A;&QO=U]D;W=N;&]A
M9%]I;F-O;6EN9R<@/3X@)T%L;&]W(&1O=VYL;V%D:6YG(&9R;VT@=&AE(&EN
M8V]M:6YG(&1I<F5C=&]R>2<L"@DG86YO;F9T<%]?86YO;F9T<%]F;W)?9&]M
M86EN)R`]/B`B06YO;GEM;W5S($944"!A8V-O=6YT(&9O<B!T:&4@9&]M86EN
M(BP*"2=A;F]N9G1P7U]D:7-P;&%Y7VQO9VEN)R`]/B`G1&ES<&QA>2!L;V=I
M;B!M97-S86=E)RP*"2=A;F]N9G1P7U]L;V=I;E]T97AT)R`]/B`G365S<V%G
M92!T97AT)RP*"2=A;F]N9G1P7U]L;V=I;E]T97AT7VQI;6ET)R`]/B`B26YV
M86QI9"!M97-S86=E('1E>'0@;&5N9W1H+B!3:&]U;&0@8F4@9G)O;2`Q('1O
M(#8U-3,S(&-H87)A8W1E<G,N(BP*"2=A;F]N9G1P7U]L;V=I;E]T97AT7V%S
M8VEI)R`]/B`B02!M97-S86=E('1E>'0@8V%N(&-O;G1A:6X@;VYL>2!!4T-)
M22!C:&%R86-T97)S+B(L"@DG86YO;F9T<%]?96YA8FQE9%]O;E]O=&AE<E]I
M<"<@/3X@(FES('5S960@;VX@86YO=&AE<B!)4"!A9&1R97-S(BP*"2=A;F]N
M9G1P7U]I;G9A;&ED7V)A;F1W:61T:"<@/3X@(DEN=F%L:60@9&]W;FQO860@
M8F%N9'=I9'1H('9A;'5E+"!O;FQY(&1I9VET<R!A<F4@86QL;W=E9"XB+`H)
M)V%N;VYF='!?7VEN=F%L:61?;6%X7V-O;FXG(#T^("));G9A;&ED(&YU;6)E
M<B!O9B!M87AI;75M('-I;75L=&%N96]U<R!C;VYN96-T:6]N<RP@;VYL>2!D
M:6=I=',@87)E(&%L;&]W960B+`H))V%N;VYF='!?7VEN=F%L:61?<75O=&$G
M(#T^("));G9A;&ED(&1I<VL@<W!A8V4@=F%L=64L(&]N;'D@9&EG:71S(&%R
M92!A;&QO=V5D+B(L"@DG86YO;F9T<%]?:7!?861D<F5S7W1Y<&5?<VAA<F5D
M)R`]/B`B2&]S=&EN9R!I<R!B87-E9"!O;B!T:&4@<VAA<F5D(&EP(&%D9')E
M<W,N(BP*"2=A;F]N9G1P7U]L:6UI=%]I;F-O;6EN9U]D:7-K7W-P86-E)R`]
M/B`B3&EM:70@9&ES:R!S<&%C92!I;B!T:&4@:6YC;VUI;F<@9&ER96-T;W)Y
M(BP*"2=A;F]N9G1P7U]L:6UI=%]M87AI;75M7V)A;F1W:61T:"<@/3X@(DQI
M;6ET(&1O=VYL;V%D(&)A;F1W:61T:"!F;W(@=&AI<R!V:7)T=6%L($944"!D
M;VUA:6XB+`H))V%N;VYF='!?7VQI;6ET7VUA>&EM=6U?8V]N;F5C=&EO;G,G
M(#T^("),:6UI="!N=6UB97(@;V8@<VEM=6QT86YE;W5S(&-O;FYE8W1I;VYS
M(BP*"2=A;F]N9G1P7U]U;F%B;&5?8W)E871E)R`]/B`B56YA8FQE('1O(&-R
M96%T92!A;F]N>6UO=7,@1E10(&%C8V]U;G0Z("4Q(BP*"2=A;F]N9G1P7U]U
M;F%B;&5?96YA8FQE)R`]/B`B1F%I;&5D('1O(&5N86)L92!A;F]N>6UO=7,@
M1E10(&%C8V]U;G0Z("4Q(BP*"2=A;F]N9G1P7U]U;F%B;&5?:6YI="<@/3X@
M(E5N86)L92!T;R!I;FET:6%L:7IE(&%N;VYY;6]U<R!&5%`@86-C;W5N=#H@
M)3$B+`H))V%N;VYF='!?7W5N86)L95]P=71?8V]N9B<@/3X@(E5N86)L92!T
M;R!P=70@8V]N9FEG=7)A=&EO;B!F:6QE.B`E,2(L"@DG86YO;F9T<%]?=6YA
M8FQE7W-E=%]Q=6]T82<@/3X@(E5N86)L92!T;R!S970@=&AE(&EN8V]M:6YG
M(&1I<F5C=&]R>2!D:7-K('-P86-E(&QI;6ET.B`E,2(L"@DG86YO;F9T<%]?
M=6YA8FQE7W5P9&%T92<@/3X@(E5N86)L92!T;R!U<&1A=&4@86YO;GEM;W5S
M($944"!A8V-O=6YT('!R;W!E<G1I97,Z("4Q(BP*"2=A=71H7U]U<&1A=&5?
M861M:6Y?:6YF;R<@/3X@(E!L96%S92!E;G1E<B!A9&UI;FES=')A=&]R)W,@
M:6YF;W)M871I;VXN(%1H:7,@:6YF;W)M871I;VX@:7,@<F5Q=6ER960@=&\@
M;W!E<F%T92`E,2XB+`H))V%U=&A?7W5P9&%T95]C;%]E;6%I;%]A;F1?<&AO
M;F4G(#T^(")0;&5A<V4@96YT97(@>6]U<B!E+6UA:6P@86YD('!H;VYE(&YU
M;6)E<BX@5&AE>2!W:6QL(&)E('5S960@=&\@;F]T:69Y('EO=2!O9B!P;W-S
M:6)L92!P<F]B;&5M<RXB+`H))V%U=&A?7WEO=5]N;W1?:&%V95]P97)M)R`]
M/B`B66]U(&1O(&YO="!H879E('!E<FUI<W-I;VYS('1O(&UA;F%G92!T:&ES
M(&1O;6%I;BXB+`H))V%U=&A?7VME>5]E>'!I<F5D7V%D;6EN)R`]/B`G66]U
M<B!L:6-E;G-E(&ME>2!H87,@97AP:7)E9"X@5&\@8V]N=&EN=64@=7-I;F<@
M>6]U<B!#;VYT<F]L(%!A;F5L('EO=2!M=7-T('!U<F-H87-E(&$@;F]N+65X
M<&ER:6YG(&-O;6UE<F-I86P@;&EC96YS92XG+`H))V%U=&A?7VME>5]E>'!I
M<F5D7V-L:65N="<@/3X@)U1H92!L:6-E;G-E(&ME>2!H87,@97AP:7)E9"X@
M4&QE87-E(&-O;G1A8W0@>6]U<B!S97)V:6-E('!R;W9I9&5R+B<L"@DG875T
M;VEN<W1A;&QE<E]?;F]T7VEN<W1A;&QE9"<@/3X@)T%U=&]I;G-T86QL97(@
M8V]M<&]N96YT(&ES(&YO="!I;G-T86QL960N)RP*"2=A=71O:6YS=&%L;&5R
M7U]R96QE87-E7V%C=&EO;B<@/3X@)T%V86EL86)L92!O<&5R871I;VYS)RP*
M"2=A=71O:6YS=&%L;&5R7U]R96QE87-E7V%C=&EO;E]I8V]N)R`]/B`G4R<L
M"@DG875T;VEN<W1A;&QE<E]?<F5L96%S95]A8W1I;VY?=7!G<F%D92<@/3X@
M)U5P9W)A9&EN9R!T;R!T:&4@;F5W(&-O;G1R;VP@<&%N96P@=F5R<VEO;B<L
M"@DG875T;VEN<W1A;&QE<E]?<F5L96%S95]A8W1I;VY?=7!D871E)R`]/B`G
M57!D871I;F<@;W(@861D:6YG(&YE=R!C;VUP;VYE;G1S)RP*"2=A=71O:6YS
M=&%L;&5R7U]R96QE87-E7V%C=&EO;E]U<#)D871E)R`]/B`G66]U(&AA=F4@
M86X@=7`@=&\@9&%T92!V97)S:6]N)RP*"2=A=71O:6YS=&%L;&5R7U]C;VUP
M;VYE;G1?86-T:6]N)R`]/B`G4W1A='5S)RP*"2=A=71O:6YS=&%L;&5R7U]C
M;VUP;VYE;G1?86-T:6]N7VEC;VXG(#T^("=3)RP*"2=A=71O:6YS=&%L;&5R
M7U]C;VUP;VYE;G1?86-T:6]N7VEN<W1A;&PG(#T^("=.;W0@:6YS=&%L;&5D
M)RP*"2=A=71O:6YS=&%L;&5R7U]C;VUP;VYE;G1?86-T:6]N7W5P9&%T92<@
M/3X@)T%N('5P9&%T92!I<R!A=F%I;&%B;&4G+`H))V%U=&]I;G-T86QL97)?
M7V-O;7!O;F5N=%]A8W1I;VY?=7!G<F%D92<@/3X@)T%N('5P9&%T92!I<R!A
M=F%I;&%B;&4G+`H))V%U=&]I;G-T86QL97)?7V-O;7!O;F5N=%]A8W1I;VY?
M=7`R9&%T92<@/3X@)UEO=2!H879E(&%N('5P('1O(&1A=&4@=F5R<VEO;B<L
M"@DG875T;VEN<W1A;&QE<E]?8V]M<&]N96YT7V%C=&EO;E]E<G)O<B<@/3X@
M)U5P9&%T97,@87)E(&YO="!A=F%I;&%B;&4G+`H))V%U=&]I;G-T86QL97)?
M7V-O;7!O;F5N=%]S97)V97)B=6EL9'1I;64G(#T^("=,871E<W0@<F5L96%S
M92<L"@DG875T;VEN<W1A;&QE<E]?8V]M<&]N96YT7VQO8V%L8G5I;&1T:6UE
M)R`]/B`G66]U<B!R96QE87-E)RP*"2=A=71O:6YS=&%L;&5R7U]C;VUP;VYE
M;G0G(#T^("=#;VUP;VYE;G0G+`H))V%U=&]I;G-T86QL97)?7V-O;7!O;F5N
M=',G(#T^("=#;VUP;VYE;G1S)RP*"2=A=71O:6YS=&%L;&5R7U]C;VUP;VYE
M;G1S7W1I=&QE)R`]/B`G)3$@0V]M<&]N96YT<R<L"@DG875T;VEN<W1A;&QE
M<E]?8V]M<&]N96YT7V1E<&5N9&5N8WE?;F]T92<@/3X@)W)E<75I<F5D(&9O
M<B!I;G-T86QL871I;VX@;V8@=&AE(&-O;7!O;F5N=',@>6]U('-E;&5C=&5D
M)RP*"2=A=71O:6YS=&%L;&5R7U]I;G-T86QL7V-O;F9I<FTG(#T^("=997,L
M($D@=VES:"!T;R!I;G-T86QL('1H97-E(&-O;7!O;F5N=',G+`H))V%U=&]I
M;G-T86QL97)?7VEN<W1A;&Q?8V]N9FER;5]R97%U97-T)R`]/B`G4&QE87-E
M('-E;&5C="!T:&4@8VAE8VMB;W@@=&\@8V]N9FER;2XG+`H))V%U=&]I;G-T
M86QL97)?7VEN<W1A;&Q?=&ET;&4G(#T^("=#;VYF:7)M($EN<W1A;&QA=&EO
M;B!O9B!T:&4@4V5L96-T960@0V]M<&]N96YT<R<L"@DG875T;VEN<W1A;&QE
M<E]?:V5R;F5L7W5P9&%T95]C;VYF:7)M)R`]/B`G0V]N9FER;2!T:&4@:V5R
M;F5L('5P9&%T92<L"@DG875T;VEN<W1A;&QE<E]?:V5Y7W5P9&%T95]C;VYF
M:7)M)R`]/B`G0V]N9FER;2!S:VEP<&EN9R!K97D@=7!D871E(&%N9"!I;G-T
M86QL:6YG('1H92!D969A=6QT(&ME>2<L"@DG875T;VEN<W1A;&QE<E]?:V5Y
M7W5P9&%T95]C;VYF:7)M7W)E<75E<W0G(#T^("=0;&5A<V4@8VAE8VL@=&AE
M(&-H96-K8F]X('1O(&-O;F9I<FTN)RP*"2=A=71O:6YS=&%L;&5R7U]K97E?
M=7!D871E7V9A:6QE9"<@/3XG/'`^4&QE<VL@:7,@=6YA8FQE('1O('5P9&%T
M92!Y;W5R('!R;V1U8W0@;&EC96YS92X\+W`^)PH)"2X@)SQP/B4Q/"]P/B<*
M"0DN("<\<#Y#;VYT:6YU:6YG('=I=&@@=&AE('5P9W)A9&4@=VET:&]U="!H
M879I;F<@86X@87!P<F]P<FEA=&4@<')O9'5C="!L:6-E;G-E('=I;&P@<F5S
M=6QT(&EN('1H92!I;G-T86QL871I;VX@;V8@82!D969A=6QT(&QI8V5N<V4@
M=VET:"!L:6UI=&5D(&9U;F-T:6]N86QI='DN($%D;6EN:7-T<F%T;W)S(&%R
M92!A9'9I<V5D('1O(&9I<G-T(&%C<75I<F4@=&AE(&%P<')O<')I871E(&QI
M8V5N<V4@8F5F;W)E(&-O;G1I;G5I;F<@=VET:"!T:&4@<')O9'5C="!U<&=R
M861E+CPO<#XG+`H))V%U=&]I;G-T86QL97)?7V5M86EL)R`]/B`G4V5N9"!N
M;W1I8V4@=&\G+`H))V%U=&]I;G-T86QL97)?7V5M86EL7V%D;6EN)R`]/B`B
M061M:6YI<W1R871O<B=S(&4M;6%I;"(L"@DG875T;VEN<W1A;&QE<E]?96UA
M:6Q?96UA:6PG(#T^("=#=7-T;VT@92UM86EL(&%D9')E<W,N+BXG+`H))V%U
M=&]I;G-T86QL97)?7W)E;&5A<V4G(#T^("=296QE87-E(&YA;64G+`H))V%U
M=&]I;G-T86QL97)?7W)E;&5A<V5S)R`]/B`G079A:6QA8FQE(')E;&5A<V5S
M)RP*"2=A=71O:6YS=&%L;&5R7U]R96QE87-E<U]T:71L92<@/3X@)U!L97-K
M(%5P9&%T97(G+`H))V%U=&]I;G-T86QL97)?7W-E;&5C=%]C;VUP;VYE;G1S
M7W1O7VEN<W1A;&PG(#T^("=396QE8W0@=&AE(&-O;7!O;F5N=',@=&\@8F4@
M:6YS=&%L;&5D)RP*"2=A=71O:6YS=&%L;&5R7U]S=&%T=7-?97)R;W(G(#T^
M("=%<G)O<CH@)3$N)RP*"2=A=71O:6YS=&%L;&5R7U]S=&%T=7-?:6YS=&%L
M;%]E<G)O<B<@/3X@)TEN<W1A;&QA=&EO;B!C;W5L9"!N;W0@8F4@<W1A<G1E
M9#H@)3$N)RP*"2=A=71O:6YS=&%L;&5R7U]S=&%T=7-?:6YS=&%L;%]B=7-Y
M)R`]/B`G26YS=&%L;&%T:6]N(&-O=6QD(&YO="!B92!S=&%R=&5D.B!A;F]T
M:&5R(&EN<W1A;&QA=&EO;B!P<F]C961U<F4@:7,@8W5R<F5N=&QY(')U;FYI
M;F<N)RP*"2=A=71O:6YS=&%L;&5R7U]S=&%T=7-?:6YS=&%L;%]O:R<@/3X@
M)TEN<W1A;&QA=&EO;B!S=&%R=&5D+B!9;W4@=VEL;"!B92!N;W1I9FEE9"!O
M9B!I;G-T86QL871I;VX@<')O9W)E<W,@8GD@92UM86EL("@E,2DN)RP*"2=A
M=71O:6YS=&%L;&5R7U]S=&%T=7-?<75E<GE?8G5S>2<@/3X@)TEN<W1A;&QA
M=&EO;B!I<R!I;B!P<F]G<F5S<RXG+`H))V%U=&]I;G-T86QL97)?7W-T871U
M<U]Q=65R>5]E<G)O<B<@/3X@)U5N86)L92!T;R!R971R:65V92!I;G-T86QL
M871I;VX@<W1A='5S.B`E,2<L"@DG875T;VEN<W1A;&QE<E]?8V]N9FEG=7)E
M7W1I=&QE)R`]/B`G57!D871E<B!3971T:6YG<R<L"@DG875T;VEN<W1A;&QE
M<E]?<')E9F5R96YC97-?;&5G96YD)R`]/B`G4V5T=&EN9W,G+`H))V%U=&]I
M;G-T86QL97)?7W-O=7)C95]T>7!E)R`]/B`G4V]U<F-E('1Y<&4G+`H))V%U
M=&]I;G-T86QL97)?7W-O=7)C95]T>7!E7VEN=F%L:60G(#T^("=);G9A;&ED
M('-O=7)C92!T>7!E)RP*"2=A=71O:6YS=&%L;&5R7U]S;W5R8V5?='EP95]P
M;&5S:R<@/3X@)U!L97-K('5P9&%T92!S97)V97(G+`H))V%U=&]I;G-T86QL
M97)?7W-O=7)C95]T>7!E7VYE='=O<FLG(#T^("=.971W;W)K('-T;W)A9V4G
M+`H))V%U=&]I;G-T86QL97)?7W-O=7)C95]I;G9A;&ED)R`]/B`G26YV86QI
M9"!S;W5R8V4G+`H))V%U=&]I;G-T86QL97)?7W-O=7)C95]I;G9A;&ED7VYE
M='=O<FLG(#T^("=);G9A;&ED('-O=7)C92!54DP@*'-A;7!L93H@:'1T<#HO
M+W-O=7)C92P@9G1P.B\O<V]U<F-E*2<L"@DG875T;VEN<W1A;&QE<E]?<V]U
M<F-E)R`]/B`G4V]U<F-E(%523"<L"@DG875T;VEN<W1A;&QE<E]?=&%R9V5T
M)R`]/B`G5&5M<&]R87)Y(&1O=VYL;V%D(&1I<F5C=&]R>2<L"@DG875T;VEN
M<W1A;&QE<E]?=&%R9V5T7VEN=F%L:60G(#T^(")3<&5C:69Y(&%B<V]L=71E
M('!A=&@B+`H))V%U=&]I;G-T86QL97)?7V-H96-K7W5P9&%T97,G(#T^("=#
M:&5C:R!F;W(@=7!D871E<R!U<&]N(&%D;6EN:7-T<F%T;W)<)W,@;&]G:6X@
M=&\@8V]N=')O;"!P86YE;"XG+`H))V%U=&]I;G-T86QL97)?7V-H96-K7W5P
M9&%T97-?=V%R;FEN9R<@/3X@)TYE=R`\82!H<F5F/2(E,2(^=7!D871E<SPO
M83X@87)E(&%V86EL86)L92!F;W(@)3(@)RP*"2=B86-K=7!?7W!E<FEO9"<)
M/3X@)T)A8VMU<"!P97)I;V0G+`H))V)A8VMU<%]?<F5P;W-I=&]R>2<]/B`G
M0F%C:W5P(&9I;&5S(')E<&]S:71O<GD@;&]C871I;VXG+`H))V)A8VMU<%]?
M;6%X7V1U;7!?9FEL97,G"3T^("=.=6UB97(@;V8@8F%C:W5P(&9I;&5S('-T
M;W)E9"!I;B!R97!O<VET;W)Y)RP*"2=B86-K=7!?7V9I;&5N86UE7W!R969I
M>"<]/B`G061D('!R969I>"!T;R!B86-K=7`@9FEL92!N86UE<R<L"@DG8F%C
M:W5P7U]E<G)O<E]N;W1I9GE?96UA:6PG(#T^("=396YD(&YO=&EF:6-A=&EO
M;B!O;B!E<G)O<G,@:68@86YY(&]C8W5R(&1U<FEN9R!B86-K=7`@=&\@96UA
M:6PG+`H))V)A8VMU<%]?9'5M<%]I;F9O)R`]/B`B0F%C:W5P(&EN9F]R;6%T
M:6]N(BP*"2=B86-K=7!?7V1U;7!?9FEL95]N86UE7VYO=%]D969I;F5D)R`]
M/B`B0F%C:W5P(&9I;&4@;F%M92!I<R!N;W0@<W!E8VEF:65D(BP*"2=B86-K
M=7!?7V9T<%]A8V-O=6YT)R`]/B`B1E10(&%C8V]U;G0@9F]R(')E;6]T92!R
M97!O<VET;W)Y(BP*"2=B86-K=7!?7V-R;VY?8F%C:W5P7W1A<VM?<')E9G,G
M(#T^(")38VAE9'5L960@0F%C:W5P(BP*"2=B86-K=7!?7V9T<%]A8V-O=6YT
M7V9O<E]B86-K=7`G(#T^(")&5%`@86-C;W5N="!P<F5F97)E;F-E<R(L"@DG
M8F%C:W5P7U]L;V-A;%]F:6QE)R`]/B`G3&]C86P@8F%C:W5P(&9I;&4G+`H)
M)V)A8VMU<%]?9&]M86EN7V1U;7!S)R`]/B`G;&]C86P@<F5P;W-I=&]R>2<L
M"@DG8F%C:W5P7U]D;VUA:6Y?9G1P)R`]/B`G<F5M;W1E($944"!S97)V97(G
M+`H))V)A8VMU<%]?=W)O;F=?<&%T:"<@/3X@(DEN8V]R<F5C="!P871H('1O
M('1H92!B86-K=7`@9FEL97,@<F5P;W-I=&]R>3H@1&\@;F]T('5S92!T:&4@
M<V5Q=65N8V4@;V8@8VAA<F%C=&5R<R`N+B\N+B\B+`H))V)A8VMU<%]?=6YA
M8FQE7W1O7V-O;FYE8W1?=&]?9G1P7W-E<G9E<B<]/B`B56YA8FQE('1O(&-O
M;FYE8W0@=&\@1E10('-E<G9E<CH@)3$B+`H))V)A8VMU<%]?8F%C:W5P7W1A
M<VM?9&]E<U]N;W1?97AI<W0G(#T^(")"86-K=7`@=&%S:R!D;V5S(&YO="!E
M>&ES="P@>6]U('-H;W5L9"!C<F5A=&4@:70@8F5F;W)E('1U<FYI;F<@;VXN
M(BP*"2=B86-K=7!?7W)E<W1O<F5?<&%R86US)R`]/B`B4F5S=&]R92!P87)A
M;65T97)S(BP*"2=B86-K=7!?7V-O;F9I<FUA=&EO;B<@/3X@(E=A<FYI;F<Z
M('1H92!D;VUA:6X@=VEL;"!N;W0@8F4@879A:6QA8FQE(&1U<FEN9R!B86-K
M=7`O<F5S=&]R:6YG+B(L"@DG8F%C:W5P7U]D=6UP9FEL95]I<U]N;W1?97AI
M<W0G(#T^(")"86-K=7`@9FEL92!D;V5S(&YO="!E>&ES="XB+`H))V)A8VMU
M<%]?8F%C:W5P7VUE=&AO9"<)/3X@)T)A8VMU<"!M971H;V0G+`H))V)A8VMU
M<%]?9'5M<&9I;&5?;F%M92<@/3X@(D)A8VMU<"!F:6QE(&YA;64B+`H))V)A
M8VMU<%]?9'5M<&9I;&5?;F%M95]I<U]I;G9A;&ED)R`]/B`B0F%C:W5P(&9I
M;&4@;F%M92!I<R!I;G9A;&ED.B!5<V4@;VYL>2!A;'!H86YU;65R:6,L(&1A
M<V@L(&1O="!A;F0@=6YD97)S8V]R92!S>6UB;VQS+"!D;R!N;W0@=7-E(&YA
M;64@;&EK92!D97-C<FEP=&EO;BXJ(&%S(&)A8VMU<"!F:6QE(&YA;64N(BP*
M"2=B86-K=7!?7V1U;7!F:6QE7VYA;65?:7-?;F]T7V1E9FEN960G(#T^(")"
M86-K=7`@9FEL92!N86UE(&ES('5N9&5F:6YE9"XB+`H))V)A8VMU<%]?96UA
M:6Q?<F5Q=6ER960G(#T^(")9;W5R(&4M;6%I;"!A9&1R97-S(&ES(')E<75I
M<F5D('1O(&ME97`@>6]U(&EN9F]R;65D(&]F('1H92!B86-K=7`O<F5S=&]R
M:6YG('!R;V-E9'5R92!P<F]G<F5S<RX@4&QE87-E('-P96-I9GD@>6]U<B!E
M+6UA:6P@:6X@=&AE(&%C8V]U;G0@9&5T86EL<RXB+`H))V)A8VMU<%]?97)R
M;W)?9'5R:6YG7V)A8VMU<"<@/3X@(E5N86)L92!T;R!C<F5A=&4@=&AE(&)A
M8VMU<"!F:6QE.B`E,2(L"@DG8F%C:W5P7U]I;G!U=%]E;6%I;%]W87)N:6YG
M)R`]/B`B66]U('-H;W5L9"!E:71H97(@<W!E8VEF>2!E+6UA:6P@9F]R(&YO
M=&EF:6-A=&EO;B!O<B!D97-E;&5C="!T:&4@8VAE8VMB;W@N(BP*"2=B86-K
M=7!?7VUA:V5?9&]W;FQO860G(#T^(")D;R!N;W0@<W1O<F4@=&AE(&)A8VMU
M<"!F:6QE(&EN(')E<&]S:71O<GDL(&]N;'D@9&]W;FQO860@:70B+`H))V)A
M8VMU<%]?;6%K95]D=6UP)R`]/B`G8W)E871E(&)A8VMU<"!F:6QE(&%N9"!S
M=&]R92!I;B!L;V-A;"!R97!O<VET;W)Y)RP*"2=B86-K=7!?7VUA:V5D=6UP
M7W1O7V9T<"<@/3X@)V-R96%T92!B86-K=7`@9FEL92!A;F0@<W1O<F4@;VX@
M<F5M;W1E($944"!S97)V97(G+`H))V)A8VMU<%]?9G1P7W-E<G9E<B<@/3X@
M(D944"!S97)V97(B+`H))V)A8VMU<%]?9G1P7V)A<V5D:7(G(#T^(")0871H
M('1O(&)A8VMU<"!F:6QE<R!R97!O<VET;W)Y(&]N($944"!S97)V97(B+`H)
M)V)A8VMU<%]?;F]T:69I8V%T:6]N7V5M86EL)R`]/B`B3F]T:69Y(&)Y(&4M
M;6%I;"(L"@DG8F%C:W5P7U]N;W1I9GE?96UA:6Q?:7-?:6YV86QI9"<@/3X@
M(DEN8V]R<F5C="!E+6UA:6P@861D<F5S<R!F;W(@8F%C:W5P+W)E<W1O<FEN
M9R!P<F]G<F5S<R!N;W1I9FEC871I;VX@:7,@<W!E8VEF:65D+B(L"@DG8F%C
M:W5P7U]R97-T;W)E7VEP)R`]/B`B25`@861D<F5S<R!F;W(@<F5S=&]R871I
M;VXB+`H))V)A8VMU<%]?<V5L96-T7V1U;7!F:6QE)R`]/B`B4V5L96-T(&$@
M8F%C:W5P(&9I;&4N(BP*"2=B86-K=7!?7W1I;64G(#T^(")"86-K=7`@=&EM
M92(L"@DG8F%C:W5P7U]V:65W7V1U;7!?:6YF;R<@/3X@(E9I97<@=&AE(&)A
M8VMU<"!I;F9O<FUA=&EO;B!F;W(@9&]M86EN("4Q(BP*"2=B86-K=7!?7W=R
M;VYG7V1O;6%I;E]N86UE)R`]/B`B5&AE(&)A8VMU<"!F:6QE(&-O;G1A:6YS
M('1H92!D871A(&]F(&1O;6%I;B`E,2!A;F0@=&AE<F5F;W)E(&-A;FYO="!B
M92!R97-T;W)E9"!O;B!D;VUA:6X@)3(B+`H))V)A8VMU<%]?:6YC;W)R96-T
M7V9T<%]U<V5R7V]R7W!A<W-W9"<@/3X@(DEN8V]R<F5C="!&5%`@=7-E<B!O
M<B!P87-S=V]R9"X@4&QE87-E(&-O<G)E8W0@1E10($%C8V]U;G0@4')O<&5R
M=&EE<R(L"@DG8F%C:W5P7U]A8V-E<W-?9&5N:65D)R`]/B`B06-C97-S(&1E
M;FEE9"X@4&QE87-E(&-O<G)E8W0@1E10($%C8V]U;G0@4')O<&5R=&EE<R(L
M"@DG8F%C:W5P7U]C;W5L9&YO=%]R97-O;'9E7VAO<W0G(#T^(")#;W5L9&XG
M="!R97-O;'9E(&AO<W0@)3$B+`H))V)A8VMU<%]?<F5S=&]R95]F<F]M)R`]
M/B`B4F5S=&]R92`E,2(L"@DG8F%C:W5P7U]D;VUA:6Y?<V5S<VEO;E]F86EL
M960G(#T^("=$;VUA:6X@)3$@=V%S(&YO="!B86-K960@=7`G+`H))V)A8VMU
M<%]?8VQI96YT7W-E<W-I;VY?9F%I;&5D)R`]/B`G0VQI96YT("4Q('=A<R!N
M;W0@8F%C:V5D('5P)RP*"2=B86-K=7!?7V1O;6%I;E]S97-S:6]N7W)E<W1O
M<F5?9F%I;&5D)R`]/B`G1&]M86EN("4Q('=A<R!N;W0@<F5S=&]R960G+`H)
M)V)A8VMU<%]?8VQI96YT7W-E<W-I;VY?<F5S=&]R95]F86EL960G(#T^("=#
M;&EE;G0@)3$@=V%S(&YO="!R97-T;W)E9"<L"@DG8F%C:W5P7U]D;VUA:6Y?
M<V5S<VEO;E]C;VUP;&5T92<@/3X@)T1O;6%I;B`E,2!W87,@8F%C:V5D('5P
M)RP*"2=B86-K=7!?7V1O;6%I;E]S97-S:6]N7V)A8VMU<"<@/3X@)T)A8VMU
M<"!O9B!D;VUA:6X@)3$G+`H))V)A8VMU<%]?8VQI96YT7W-E<W-I;VY?8F%C
M:W5P)R`]/B`G0F%C:W5P(&]F(&-L:65N="`E,2<L"@DG8F%C:W5P7U]D;VUA
M:6Y?<W1O<%]T:71L92<@/3X@)T-A;F-E;&QI;F<@8F%C:W5P(&]F(&1O;6%I
M;B`E,2<L"@DG8F%C:W5P7U]C;&EE;G1?<W1O<%]T:71L92<@/3X@)T-A;F-E
M;&QI;F<@8F%C:W5P(&]F(&-L:65N="`E,2<L"@DG8F%C:W5P7U]D;VUA:6Y?
M<F5S=&]R95]S=&]P7W1I=&QE)R`]/B`G0V%N8V5L;&QI;F<@<F5S=&]R92!O
M9B!D;VUA:6X@)3$G+`H))V)A8VMU<%]?8VQI96YT7W)E<W1O<F5?<W1O<%]T
M:71L92<@/3X@)T-A;F-E;&QI;F<@<F5S=&]R92!O9B!C;&EE;G0@)3$G+`H)
M)V)A8VMU<%]?9&]M86EN7W-E<W-I;VY?8F%C:W5P7W-T;W`G(#T^("=9;W4@
M87)E(&%B;W5T('1O(&-A;F-E;"!T:&4@86-T:79E(&)A8VMU<"!P<F]C97-S
M(2!"86-K=7`@9FEL92!W:6QL(&YO="!B92!C<F5A=&5D+B<L"@DG8F%C:W5P
M7U]B86-K=7!?<W1O<%]C;VYF:7)M)R`]/B`G665S+"!)('=A;G0@=&\@<W1O
M<"!T:&4@8F%C:W5P('!R;V-E<W,G+`H))V)A8VMU<%]?<F5S=&]R95]S=&]P
M7V-O;F9I<FTG(#T^("=997,L($D@=V%N="!T;R!S=&]P('1H92!R97-T;W)E
M('!R;V-E<W,G+`H))V)A8VMU<%]?9&]M86EN7W-E<W-I;VY?<F5S=&]R92<@
M/3X@)U)E<W1O<F4@;V8@9&]M86EN("4Q)RP*"2=B86-K=7!?7V1O;6%I;E]S
M97-S:6]N7W)E<W1O<F5?<W1O<"<@/3X@)UEO=2!A<F4@86)O=70@=&\@8V%N
M8V5L('1H92!A8W1I=F4@<F5S=&]R92!P<F]C97-S(2<L"@DG8F%C:W5P7U]D
M;VUA:6Y?8F%C:W5P7V9I;&5?:6YF;R<@/3X@)T1O;6%I;B!"86-K=7`@1FEL
M92!);F9O<FUA=&EO;B<L"@DG8F%C:W5P7U]D;VUA:6Y?8F%C:W5P7V9I;&5?
M;&ES="<@/3X@)V5X:7-T:6YG(&)A8VMU<"!F:6QE<R<L"@DG8F%C:W5P7U]D
M;VUA:6Y?8F%C:W5P7W!R;V=R97-S)R`]/B`G4')O9W)E<W,@;V8@9&]M86EN
M("4Q(&)A8VMU<"<L"@DG8F%C:W5P7U]D;VUA:6Y?<F5S=&]R95]P<F]G<F5S
M<R<@/3X@)U!R;V=R97-S(&]F(&1O;6%I;B`E,2!R97-T;W)E)RP*"2=B86-K
M=7!?7V1O;6%I;E]B86-K=7!?<')O9W)E<W-?96QA<'-E9%]T:6UE)R`]/B`G
M16QA<'-E9"!T:6UE.B`E,2<L"@DG8F%C:W5P7U]D;VUA:6Y?<F5S=&]R95]P
M<F]G<F5S<U]E;&%P<V5D7W1I;64G(#T^("=%;&%P<V5D('1I;64Z("4Q)RP*
M"2=B86-K=7!?7VEP7VUA<%]L96=E;F0G(#T^("=)4"!-87!P:6YG)RP*"2=B
M86-K=7!?7VEP7VUA<%]L:7-T7V-O=6YT)R`]/B`G25`@061D<F5S<V5S)RP*
M"2=B86-K=7!?7V1O;6%I;E]R97-T;W)E7W-E<W-I;VY?8V]M<&QE=&4G(#T^
M("=$;VUA:6X@)3$@:7,@<F5S=&]R960G+`H))V)A8VMU<%]?9&]M86EN7W)E
M<W1O<F5?<V5S<VEO;E]C;VUP;&5T95]M97-S86=E)R`]/B`G1&]M86EN("4Q
M(&AA<R!B965N(')E<W1O<F5D)RP*"2=B86-K=7!?7V1O;6%I;E]B86-K=7!?
M9FEL95]D96QE=&4G(#T^("=4:&4@9F]L;&]W:6YG(&)A8VMU<"!F:6QE<R!W
M:6QL(&)E(')E;6]V960Z)RP*"2=B86-K=7!?7V1O;6%I;E]B86-K=7!?9FEL
M95]F;W)?<F5M;W9E)R`]/B`G4V5L96-T(&)A8VMU<"!F:6QE<R!Y;W4@=VES
M:"!T;R!R96UO=F4G+`H))V)A8VMU<%]?8F%C:W5P7V]V97)W<FET95]F:6QE
M7V-O;F9I<FTG(#T^("=297!L86-E;65N="!C;VYF:7)M871I;VXG+`H))V)A
M8VMU<%]?8F%C:W5P7V]V97)W<FET95]F:6QE7V-O;F9I<FU?=&5X="<@/3X@
M)T)A8VMU<"!F:6QE('=I=&@@=&AE(&YA;64@(B4Q(B!A;')E861Y(&5X:7-T
M<RX@1&\@>6]U('=A;G0@=&\@<F5P;&%C92!I=#\G+`H))V)A8VMU<%]?8F%C
M:W5P7V-O;F9I<FU?;W9E<G=R:71E)R`]/B`G0V]N9FER;2!F:6QE(')E<&QA
M8V5M96YT)RP*"2=B86-K=7!?7V)A8VMU<%]O=F5R=W)I=&5?;&5G96YG)R`]
M/B`G4F5P;&%C92<L"@DG8F%C:W5P7U]B86-K=7!?;F]T7V-O;G1A:6Y?9&]M
M86EN)R`]/B`G0F%C:W5P(&9I;&4@9&]E<R!N;W0@8V]N=&%I;B!I;F9O<FUA
M=&EO;B!A8F]U="!D;VUA:6X@)3$G+`H))V)A8VMU<%]?8F%C:W5P7VYO=%]C
M;VYT86EN7V-L:65N="<@/3X@)T)A8VMU<"!F:6QE(&1O97,@;F]T(&-O;G1A
M:6X@:6YF;W)M871I;VX@86)O=70@8VQI96YT("4Q)RP*"2=B86-K=7!?7V)A
M8VMU<%]C;&EE;G1?:6YF;R<@/3X@(D)A8VMU<"!C;&EE;G0G<R!P<F5F97)E
M;F-E<R!A;F0@86-C;W5N="!D971A:6QS(BP*"2=B86-K=7!?7V-L:65N=%]B
M86-K=7!?<')O9W)E<W,G(#T^("=0<F]G<F5S<R!O9B!#;&EE;G0@)3$@0F%C
M:W5P)RP*"2=B86-K=7!?7V-L:65N=%]S97-S:6]N7V-O;7!L971E)R`]/B`G
M0VQI96YT("4Q(&ES(&)A8VME9"!U<"<L"@DG8F%C:W5P7U]C;&EE;G1?8F%C
M:W5P7V9I;&5?:6YF;R<@/3X@)T-L:65N="!"86-K=7`@1FEL92!);F9O<FUA
M=&EO;B<L"@DG8F%C:W5P7U]R97-T;W)E7V-L:65N=%]I;F9O)R`]/B`B4F5S
M=&]R92!C;&EE;G0G<R!P<F5F97)E;F-E<R!A;F0@86-C;W5N="!D971A:6QS
M(BP*"2=B86-K=7!?7V-L:65N=%]S97-S:6]N7W)E<W1O<F4G(#T^("=297-T
M;W)I;F<@0VQI96YT("4Q)RP*"2=B86-K=7!?7V-L:65N=%]D8E]S97)V97)?
M;6%P)R`]/B`G1&%T86)A<V4@4V5R=F5R<R!-87!P:6YG)RP*"2=B86-K=7!?
M7V1O;6%I;E]D8E]S97)V97)?;6%P)R`]/B`G1&%T86)A<V4@4V5R=F5R<R!-
M87!P:6YG)RP*"2=B86-K=7!?7V-L:65N=%]R97-T;W)E7W-E<W-I;VY?8V]M
M<&QE=&5?;65S<V%G92<@/3X@)T-L:65N="`E,2!H87,@8F5E;B!R97-T;W)E
M9"XG+`H))V)A8VMU<%]?8VQI96YT7W)E<W1O<F5?<V5S<VEO;E]C;VUP;&5T
M92<@/3X@)T-L:65N="`E,2!R97-T;W)E9"<L"@DG8F%C:W5P7U]R97-T;W)E
M7W-E;&5C=%]S;VUE)R`]/B`G4&QE87-E('-E;&5C="!O8FIE8W1S('EO=2!W
M:7-H('1O(')E<W1O<F4N)RP*"2=B86-K=7!?7V-L:65N=%]R97-T;W)E7W!R
M;V=R97-S)R`]/B`G4')O9W)E<W,@;V8@0VQI96YT("4Q(%)E<W1O<F4G+`H)
M)V)A8VMU<%]?;F5W7V)A8VMU<"<@/3X@)T-R96%T:6YG($YE=R!"86-K=7`G
M+`H))V)A8VMU<%]?9&]N92<@/3X@)T1O;F4Z)RP*"2=B86-K=7!?7V1O;F5?
M9&]M86EN<R<@/3X@)R4Q(&1O;6%I;BAS*2!O=70@;V8@)3(G+`H))V)A8VMU
M<%]?9&]N95]C;&EE;G1S)R`]/B`G)3$@8VQI96YT*',I(&]U="!O9B`E,B<L
M"@DG8F%C:W5P7U]R96UA:6YI;F<G(#T^("=296UA:6YI;F<Z)RP*"2=B86-K
M=7!?7W)E;6%I;FEN9U]D;VUA:6YS)R`]/B`G)3$@9&]M86EN*',I)RP*"2=B
M86-K=7!?7W)E;6%I;FEN9U]C;&EE;G1S)R`]/B`G)3$@8VQI96YT*',I)RP*
M"2=B86-K=7!?7V]V97)A;&Q?8F%C:W5P7W!R;V=R97-S)R`]/B`G3W9E<F%L
M;"!B86-K=7`@<')O9W)E<W,G+`H))V)A8VMU<%]?8V]M;65N=%]N7V$G(#T^
M("=N+V$G+`H))V)A8VMU<%]?8V]M;6%N9%]I9VYO<F4G(#T^("=#;VUM86YD
M("(E,2(@:7,@:6=N;W)E9"<L"@DG8F%C:W5P7U]N;W1?8F%C:W5P7V9I;&4G
M(#T^("=.;W0@82!B86-K=7`@9FEL92<L"@DG8F%C:W5P7U]D8E]S97)V97)?
M;6%P<&EN9R<@/3X@)U-E;&5C="!T:&4@9&%T86)A<V4@<V5R=F5R(&-O;F9I
M9W5R960@:6X@4&QE<VL@=&\@=VAI8V@@>6]U('=I<V@@=&\@;6%P('1H92!D
M871A8F%S92!S97)V97(@9G)O;2!B86-K=7`N)RP*"2=B86-K=7!?7W5N86)L
M95]U<&1A=&4G(#T^("=5;F%B;&4@=&\@=7!D871E('-C:&5D=6QE9"!B86-K
M=7`@:6YF;W)M871I;VXZ("4Q)RP*"2=B86-K=7!?7VYO7V]B:F5C=',G(#T^
M("=T:&5R92!A<F4@;F\@;V)J96-T<R!F;W(@8F%C:W5P)RP*"2=B86-K=7!?
M7V-L:5]W87)N:6YG7VYO=%]E;F]U9VA?:7`G(#T^("=705).24Y'.B!N;W0@
M96YO=6=H($E0(&%D9')E<W-E<R!T;R!P97)F;W)M(&1E9F%U;'0@25`@;6%P
M<&EN9SH@)RP*"2=B=%]B86-K=7!?;F]W)R`]/B`B0F%C:W5P($YO=R(L"@DG
M8G1?;F5W7W)E<W1O<F4G(#T^(")297-T;W)E(BP*"2=B=%]B86-K=7!?<V-H
M961U;&4G(#T^(")38VAE9'5L960@0F%C:W5P(BP*"2=B86-K=7!?97AI<W1?
M8F%C:W5P<R<@/3X@(D5X:7-T:6YG(&)A8VMU<"!F:6QE<R(L"@DG8F%C:W5P
M7V1I86QO9U]?<&%G95]T:71L92<@/3X@(D)A8VMU<"!&:6QE($-R96%T:6]N
M(BP*"2=B86-K=7!?9&EA;&]G7U]P;&5A<V5?=V%I="<@/3X@(E1H92!B86-K
M=7`@<')O8V5S<R!I<R!A8F]U="!T;R!B96=I;BX@)3$@5&AI<R!O<&5R871I
M;VX@;6EG:'0@=&%K92!S;VUE('1I;64N("4R(%!L96%S92!W86ET+BXN("4S
M(BP*"2=D=6UP7V9I;&5?7VEN8V]R<F5C=%]F:6QE;F%M92<@/3X@(E1H92!F
M:6QE<R!Y;W4@<W!E8VEF:65D(&%R92!N;W0@<&%R=',@;V8@=&AE('-A;64@
M;75L=&DM=F]L=6UE(&)A8VMU<"XB+`H))V1U;7!?9FEL95]?:6YC;W)R96-T
M7W-E<75E;F-E)R`]/B`B5W)O;F<@<V5Q=65N8V4@;V8@=F]L=6UE<R!S<&5C
M:69I960A(BP*"2=B=%]A8V-E<'0G(#T^(")!8V-E<'0B+`H))V)T7V%C8V5S
M<R<@/3X@(D%C8V5S<R(L"@DG8G1?86-T:6]N7VQO9R<@/3X@(D%C=&EO;B!,
M;V<B+`H))V)T7V%D9"<@/3X@(D%D9"(L"@DG8G1?861D7V-L:65N="<@/3X@
M(D%D9"!.97<@0VQI96YT(BP*"2=B=%]D871A8F%S95]S97)V97)?861D)R`]
M/B`G061D($1A=&%B87-E(%-E<G9E<B<L"@DG8G1?861D7VYE=U]C871E9V]R
M>2<@/3X@(D%D9"!.97<@0V%T96=O<GDB+`H))V)T7V%D9%]N97=?<')I;W)I
M='DG(#T^(")!9&0@3F5W(%!R:6]R:71Y(BP*"2=B=%]A9&1?;F5W7W%U975E
M)R`]/B`B061D($YE=R!1=65U92(L"@DG8G1?861D7VYE=U]T:6-K970G(#T^
M(")!9&0@3F5W(%1I8VME="(L"@DG8G1?861D7W-E<G9I8V5S)R`]/B`B061D
M(%-E<G9I8V5S(BP*"2=B=%]A9&1?861D<F5S<U]T;U]A8VPG(#T^("=!9&0@
M3F5W($%D9')E<W,G+`H))V)T7V%D9%]T;R<@/3X@(CP\($%D9"(L"@DG8G1?
M=&]?861D)R`]/B`B061D(#X^(BP*"2=B=%]T;U]E>&-L=7-I=F4G(#T^("(\
M/"!%>&-L=7-I=F4B+`H))V)T7W1O7W-H87)E9"<@/3X@(E-H87)E9"`^/B(L
M"@DG8G1?86YO;F9T<%]S=&%T<R<@/3X@(D%N;VXN1E10(%-T871S(BP*"2=B
M=%]A;F]N>6UO=7-?9G1P)R`]/B`B06YO;GEM;W5S($944"(L"@DG8G1?871T
M86-H)R`]/B`B071T86-H(BP*"2=B=%]A=71O:6YS=&%L;&5R)R`]/B`G57!D
M871E<B<L"@DG8G1?8F%C:R<@/3X@(CP\($)A8VLB+`H))V)T7V)A8VMU<"<@
M/3X@(D)A8VL@=7`B+`H))V)T7V)U>5]C97)T<R<@/3X@(D)U>2!#97)T<R(L
M"@DG8G1?8FQO8VME9%]D;VUA:6YS)R`]/B`G0FQA8VL@3&ES="<L"@DG8G1?
M8FQO8VME9%]D;VUA:6Y?861D)R`]/B`G061D($1O;6%I;B<L"@DG8G1?8V%N
M8V5L)R`]/B`B0V%N8V5L(BP*"2=B=%]C87)D)R`]/B`B0V%R9"(L"@DG8G1?
M8V5R="<@/3X@(D-E<G1I9FEC871E(BP*"2=B=%]C97)T7V%D9"<@/3X@(D%D
M9"!.97<@0V5R=&EF:6-A=&4B+`H))V)T7V-E<G1?8G5Y)R`]/B`B0G5Y($-E
M<G0B+`H))V)T7V-E<G1?<F5Q=65S="<@/3X@(E)E<75E<W0B+`H))V)T7V-E
M<G1?<V5L9E]S:6=N)R`]/B`B4V5L9BU3:6=N960B+`H))V)T7V-E<G1?=FEE
M=R<@/3X@(E9I97<@0V5R=',B+`H))V)T7V-E<G1I9FEC871E<R<@/3X@(D-E
M<G1I9FEC871E<R(L"@DG8G1?8V9?8V]N9FEG=7)E)R`]/B`B0V]L9$9U<VEO
M;B!3971T:6YG<R(L"@DG8G1?8VAA;F=E7W!A<W-W9"<@/3X@(D-H86YG92!0
M87-S=V]R9"(L"@DG8G1?8VQE86Y?;&]G)R`]/B`B0VQE87(@3&]G(BP*"2=B
M=%]C;&5A<B<@/3X@(D-L96%R(BP*"2=B=%]C;&EE;G1?=&5M<&QA=&5S)R`]
M/B`B0VQI96YT(%1E;7!L871E<R(L"@DG8G1?8VQI96YT<R<@/3X@(D-L:65N
M=',B+`H))V)T7V-O9&5P86=E7V-H86YG92<@/3X@)T-H86YG92!%;F-O9&EN
M9R<L"@DG8G1?8V]M<%]I;F9O)R`]/B`B0V]M<&]N96YT($EN9F\B+`H))V)T
M7V-O;6UO;E]A8VPG(#T^("=#;VUM;VX@04-,)RP*"2=B=%]C;VYF:6=U<F5?
M;6%I;&QI<W1S)R`]/B`B4V5T(%5P($UA:6QM86XB+`H))V)T7V-O;F9I9W5R
M95]O9&)C)R`]/B`B3T1"0R!3971T:6YG<R(L"@DG8G1?8V]P>2<@/3X@(D-O
M<'DB+`H))V)T7V-O<'E?;6]V92<@/3X@(D-O<'DO36]V92(L"@DG8G1?8W)E
M871E)R`]/B`B0W)E871E(BP*"2=B=%]C<F5A=&5?86-C;W5N="<@/3X@(D-R
M96%T92!.97<@06-C;W5N="(L"@DG8G1?8W)E871E7V1I<B<@/3X@(D%D9"!.
M97<@1&ER96-T;W)Y(BP*"2=B=%]C<F5A=&5?9FEL92<@/3X@(D%D9"!.97<@
M1FEL92(L"@DG8G1?8V]U;G1?<VEZ92<@/3X@(D-A;&-U;&%T92!3:7IE(BP*
M"2=B=%]C<F]N=&%B7W5N:7@G(#T^(")#<F]N=&%B(BP*"2=B=%]C<F]N=&%B
M7W=I;B<@/3X@(E-C:&5D=6QE<B(L"@DG8G1?8W5S=&]M7V)U='1O;E]N97<G
M(#T^(")!9&0@3F5W($)U='1O;B(L"@DG8G1?8W5S=&]M7V)U='1O;G,G(#T^
M(")#=7-T;VT@0G5T=&]N<R(L"@DG8G1?8W5S=&]M:7IE)R`]/B`B0W5S=&]M
M:7IE(BP*"2=B=%]D871A8F%S97,G(#T^(")$871A8F%S97,B+`H))V)T7V1A
M=&%B87-E7W-E<G9E<G,G(#T^("=$871A8F%S92!397)V97)S)RP*"2=B=%]D
M8E]U<W)?;F5W)R`]/B`B061D($YE=R!$871A8F%S92!5<V5R(BP*"2=B=%]D
M8E]N97<G(#T^(")!9&0@3F5W($1A=&%B87-E(BP*"2=B=%]D8E]P:'!M>6%D
M;6EN)R`]/B`B37E344P@061M:6XB+`H))V)T7V1B7W!H<'!G861M:6XG(#T^
M(")0;W-T9W)E4U%,($%D;6EN(BP*"2=B=%]D8G5S97)?9&5F875L="<@/3X@
M(D1E9F%U;'0@9F]R($1"(%=E8D%D;6EN(BP*"2=B=%]D96-L:6YE)R`]/B`B
M1&5C;&EN92(L"@DG8G1?9&5F875L="<@/3X@(D1E9F%U;'0B+`H))V)T7V1E
M9F%U;'1S)R`]/B`B1&5F875L=',B+`H))V)T7V1E;&5T92<@/3X@(D1E;&5T
M92(L"@DG8G1?9&ER96-T;W)I97,G(#T^(")$:7)E8W1O<FEE<R(L"@DG8G1?
M9&ES86)L92<@/3X@(D1I<V%B;&4B+`H))V)T7V1N<R<@/3X@(D1.4R(L"@DG
M8G1?9&YS7V%D9"<@/3X@(D%D9"!.97<@4F5C;W)D(BP*"2=B=%]D;G-R96-O
M<F1?861D)R`]/B`B061D($YE=R!296-O<F0B+`H))V)T7V1N<U]S;V$G(#T^
M(")33T$@4')E9F5R96YC97,B+`H))V)T7V1N<U]P<F5F97)E;F-E<R<@/3X@
M(D1.4R!0<F5F97)E;F-E<R(L"@DG8G1?9&]?8F%C:W5P)R`]/B`B0F%C:R!5
M<"(L"@DG8G1?9&]?<F5S=&]R92<@/3X@(E)E<W1O<F4B+`H))V)T7V1O7W5P
M;&]A9"<@/3X@(E5P;&]A9"(L"@DG8G1?9&]M86EN7W1E;7!L871E<R<@/3X@
M(D1O;6%I;B!496UP;&%T97,B+`H))V)T7V1O;6%I;E]U<V5R)R`]/B`B1&]M
M86EN($%D;6EN:7-T<F%T;W(B+`H))V)T7V1O;6%I;E]U<V5R7W!A<W-W9"<@
M/3X@(D1O;6%I;B!!9&UI;FES=')A=&]R(%!A<W-W;W)D(BP*"2=B=%]D;VUA
M:6YS)R`]/B`B1&]M86EN<R(L"@DG8G1?9&]W;FQO860G(#T^(")$;W=N;&]A
M9"(L"@DG8G1?9&]W;FQO861?;&]G)R`]/B`B1&]W;FQO860B+`H))V)T7V5D
M:70G(#T^(")%9&ET(BP*"2=B=%]E;F%B;&4G(#T^(")%;F%B;&4B+`H))V)T
M7V5V96YT;6=R)R`]/B`G179E;G0@36%N86=E<B<L"@DG8G1?979E;G1?:&%N
M9&QE<E]A9&0G(#T^("=!9&0@3F5W($5V96YT($AA;F1L97(G+`H))V)T7V5X
M<&]R="<@/3X@)T5X<&]R="<L"@DG8G1?97AT<F%S)R`]/B`B17AT<F%S(BP*
M"2=B=%]F:6QE7VUA;F%G97(G(#T^(")&:6QE($UA;F%G97(B+`H))V)T7V9I
M;FES:"<@/3X@(D9I;FES:"(L"@DG8G1?9G1P7V%C8V]U;G0G(#T^(")&5%`@
M06-C;W5N="!0<F]P97)T:65S(BP*"2=B=%]F;W)G971?<&%S<W=O<F0G(#T^
M(")&;W)G;W0@4&%S<W=O<F0_(BP*"2=B=%]F<%]S<VQ?=V5B861M:6XG(#T^
M(")&4"U34TP@5V5B861M:6XB+`H))V)T7V9P7W=E8F%D;6EN)R`]/B`B1E`@
M5V5B861M:6XB+`H))V)T7V9T<%]S=&%T<R<@/3X@(D944"!3=&%T<R(L"@DG
M8G1?9V5T7W!A<W-W;W)D)R`]/B`B1V5T(%!A<W-W;W)D(BP*"2=B=%]G;&]B
M86Q?8VAA;F=E<R<@/3X@(D=R;W5P($]P97)A=&EO;G,B+`H))V)T7VAE;'`G
M(#T^(")(96QP(BP*"2=B=%]H:61E7V%L:6%S97,G(#T^(")(:61E($%L:6%S
M97,B+`H))V)T7VAI9&5?=&]O;&)A<B<@/3X@)TAI9&4@=&]O;&)A<B<L"@DG
M8G1?:&ED95]S=6)D;VUA:6YS)R`]/B`B2&ED92!3=6)D;VUA:6YS(BP*"2=B
M=%]H;VUE)R`]/B`B2&]M92(L"@DG8G1?:&]S=&EN9R<@/3X@(DAO<W1I;F<B
M+`H))V)T7VEN<W1A;&PG(#T^("));G-T86QL(BP*"2=B=%]I;G1E<F9A8V5?
M;6%N86=E;65N="<@/3X@(DEN=&5R9F%C92!-86YA9V5M96YT(BP*"2=B=%]I
M<%]A;&EA<VEN9R<@/3X@(DE0($%D9')E<W-E<R(L"@DG8G1?:7!?861D)R`]
M/B`B061D($YE=R!)4"!!9&1R97-S(BP*"2=B=%]I<%]P;V]L)R`]/B`B25`@
M4&]O;"(L"@DG8G1?:V5Y7VEN9F\G(#T^("),:6-E;G-E($UA;F%G96UE;G0B
M+`H))V)T7VME>5]B=7EO;FQI;F5?861D;VYS)R`]/B`G3W)D97(@0V]N=')O
M;"!086YE;"!!9&0M3VYS)RP*"2=B=%]K97E?8G5Y;VYL:6YE7W5P9W)A9&5S
M)R`]/B`G3W)D97(@0V]N=')O;"!086YE;"!5<&=R861E<R<L"@DG8G1?:V5Y
M7V)U>6]N;&EN95]N97<G(#T^("=/<F1E<B!.97<@2V5Y)RP*"2=B=%]K97E?
M=7!D871E)R`]/B`G4F5T<FEE=F4@2V5Y<R<L"@DG8G1?:V5Y7W5P;&]A9"<@
M/3X@)U5P;&]A9"!+97DG+`H))V)T7VME>5]D;W=N;&]A9"<@/3X@)T1O=VYL
M;V%D($ME>2<L"@DG8G1?:V5Y7W)E=F5R="<@/3X@)U)O;&P@0F%C:R!+97DG
M+`H))V)T7VQI;6ET<R<@/3X@(DQI;6ET<R(L"@DG8G1?;&]C86QE7V%D9"<@
M/3X@)T%D9"!,;V-A;&4G+`H))V)T7VQO8V%L97,G(#T^("=,;V-A;&5S)RP*
M"2=B=%]L;V=?;6%N86=E<B<@/3X@(DQO9R!-86YA9V5R(BP*"2=B=%]L;V=I
M;B<@/3X@(DQO9VEN(BP*"2=B=%]L;V=O)R`]/B`B3&]G;R!3971U<"(L"@DG
M8G1?;&]G;U]D969A=6QT)R`]/B`B1&5F875L="!,;V=O(BP*"2=B=%]L;V=O
M7W-E;F1?;&EN:R<@/3X@(D%T=&%C:"!,:6YK(BP*"2=B=%]L;V=O7W-E;F1?
M;&]G;R<@/3X@(D%T=&%C:"!,;V=O(BP*"2=B=%]L;V=O=70G(#T^("),;V<@
M3W5T(BP*"2=B=%]L;V=R;W1A=&EO;B<@/3X@(DQO9R!2;W1A=&EO;B(L"@DG
M8G1?;6%I;"<@/3X@(DUA:6PB+`H))V)T7VUA:6Q?86QI87-?861D)R`]/B`B
M061D($YE=R!-86EL($%L:6%S(BP*"2=B=%]M86EL7V%L:6%S97,G(#T^(")-
M86EL($%L:6%S97,B+`H))V)T7VUA:6Q?9W)O=7!?861D)R`]/B`B061D($YE
M=R!-96UB97(B+`H))V)T7VUA:6Q?9W)O=7!S)R`]/B`B1W)O=7!S(BP*"2=B
M=%]M86EL7V1R=V5B)R`]/B`G1'(N5V5B)RP*"2=B=%]M86EL7VYA;65?861D
M)R`]/B`B061D($YE=R!-86EL($YA;64B+`H))V)T7VUA:6Q?<')E9F5R96YC
M97,G(#T^(")0<F5F97)E;F-E<R(L"@DG8G1?;6%I;%]G<F]U<"<@/3X@(DUA
M:6P@1W)O=7`B+`H))V)T7VUA:6Q?;6%I;&)O>"<@/3X@(DUA:6QB;W@B+`H)
M)V)T7VUA:6Q?<F5D:7)E8W0G(#T^(")2961I<F5C="(L"@DG8G1?;6%I;%]R
M97-P7V%D9"<@/3X@(D%D9"!.97<@075T;W)E<W!O;F1E<B(L"@DG8G1?;6%I
M;%]R97-P7V%T=&%C:%]A9&0G(#T^(")!9&0@3F5W($%T=&%C:&UE;G0B+`H)
M)V)T7VUA:6Q?<F5S<%]F:6QE<R<@/3X@(D%T=&%C:&UE;G0@1FEL97,B+`H)
M)V)T7VUA:6Q?<F5S<&]N9&5R<R<@/3X@(D%U=&]R97-P;VYD97)S(BP*"2=B
M=%]M86EL7W-P86UF:6QT97(G(#T^(")3<&%M($9I;'1E<B(L"@DG8G1?;6%I
M;%]W96)M86EL)R`]/B`B5V5B36%I;"(L"@DG8G1?;6%I;&QI<W1?;F5W)R`]
M/B`B061D($YE=R!-86EL:6YG($QI<W0B+`H))V)T7VUA:6QL:7-T7VUE;6)E
M<E]N97<G(#T^(")!9&0@3F5W($UE;6)E<B(L"@DG8G1?;6%I;&QI<W1S)R`]
M/B`B36%I;&EN9R!,:7-T<R(L"@DG8G1?;6%I;&UA;B<@/3X@(DUA:6QM86XB
M+`H))V)T7VUA:V5?9'5M<"<@/3X@(D-R96%T92!"86-K=7`B+`H))V)T7VUA
M;F%G92<@/3X@(DUA;F%G92(L"@DG8G1?;6%S=&5R)R`]/B`B36%S=&5R(BP*
M"2=B=%]M:6=R871I;VY?;6%N86=E<B<@/3X@)TUI9W)A=&EO;B!-86YA9V5R
M)RP*"2=B=%]M:6=R871E)R`]/B`G36EG<F%T92<L"@DG8G1?;6]D=6QE<U]A
M9&0G(#T^("=!9&0@36]D=6QE)RP*"2=B=%]M;V1U;&5S7VUA;F%G92<@/3X@
M)TUA;F%G92!-;V1U;&5S)RP*"2=B=%]M;W9E)R`]/B`B36]V92(L"@DG8G1?
M;7!C)R`]/B`B37E0;&5S:RYC;VTB+`H))V)T7VYE=U]C;&EE;G0G(#T^(")!
M9&0@3F5W($-L:65N="!!8V-O=6YT(BP*"2=B=%]N97=?9&]M86EN)R`]/B`B
M061D($YE=R!$;VUA:6XB+`H))V)T7VYE>'0G(#T^(").97AT(#X^(BP*"2=B
M=%]N97AT7W!A9V4G(#T^(").97AT(BP*"2=B=%]N971W;W)K7V%D9"<@/3X@
M(D%D9"!.97<@3F5T=V]R:R(L"@DG8G1?;F]T:69I8V%T:6]N<R<@/3X@(DYO
M=&EF:6-A=&EO;G,B+`H))V)T7V]D8F-?9'-N7V%D9"<@/3X@(D%D9"!.97<@
M3T1"0R!$4TXB+`H))V)T7V]F9B<@/3X@(D]F9B(L"@DG8G1?;VLG(#T^(")/
M2R(L"@DG8G1?;VXG(#T^(")/;B(L"@DG8G1?;VY?;V9F)R`]/B`B3VXO3V9F
M(BP*"2=B=%]P9%]N97<G(#T^(")!9&0@3F5W($1I<F5C=&]R>2(L"@DG8G1?
M<&1?=7-E<E]N97<G(#T^(")!9&0@3F5W(%5S97(B+`H))V)T7W!E<FUI<W-I
M;VYS)R`]/B`B4&5R;6ES<VEO;G,B+`H))V)T7W!H<&UY861M:6XG(#T^(")0
M:'!->4%D;6EN(BP*"2=B=%]P:'!P9V%D;6EN)R`]/B`B4&AP4&=!9&UI;B(L
M"@DG8G1?<&]S=&=R95]S<6PG(#T^(")0;W-T9W)E4U%,(BP*"2=B=%]P<F5F
M97)E;F-E<R<@/3X@(E!R969E<F5N8V5S(BP*"2=B=%]P<F5V7W!A9V4G(#T^
M(")0<F5V(BP*"2=B=%]P<F5V:65W)R`]/B`G4VET92!0<F5V:65W)RP*"2=B
M=%]P<FEN="<@/3X@(E!R:6YT(BP*"2=B=%]R96)O;W0G(#T^(")296)O;W0B
M+`H))V)T7W)E9G)E<V@G(#T^(")2969R97-H(BP*"2=B=%]R96=I<W1E<B<@
M/3X@(E)E9VES=&5R(BP*"2=B=%]R96UO=F4G(#T^(")296UO=F4B+`H))V)T
M7W)E;6]V95]F<F]M)R`]/B`B4F5M;W9E(#X^(BP*"2=B=%]F<F]M7W)E;6]V
M92<@/3X@(CP\(%)E;6]V92(L"@DG8G1?<F5M;W9E7W-E;&5C=&5D)R`]/B`B
M4F5M;W9E(%-E;&5C=&5D(BP*"2=B=%]R97!A:7)?:7`G(#T^(")297!A:7(@
M25`B+`H))V)T7W)E<&]R="<@/3X@(E)E<&]R="(L"@DG8G1?<F5P;W)T7V%U
M=&\G(#T^("=297!O<G0@1&5L:79E<GDG+`H))V)T7W)E<&]R=%]A=71O7VYE
M=R<@/3X@)T%D9"!$96QI=F5R>2!38VAE9'5L92<L"@DG8G1?<F5P;W)T7VYE
M=R<@/3X@(D%D9"!.97<@3&%Y;W5T(BP*"2=B=%]R97)E861?:7`G(#T^(")2
M97)E860@25`B+`H))V)T7W)E<V5T)R`]/B`B4F5S970B+`H))V)T7W)E<W1A
M<G1?<V5R=FEC97,G(#T^(")397)V:6-E($UA;F%G96UE;G0B+`H))V)T7W-A
M=F4G(#T^(")3879E(BP*"2=B=%]S96%R8V@G(#T^(")396%R8V@B+`H))V)T
M7W-E;F1?8GE?96UA:6PG(#T^(")396YD($)Y($4M36%I;"(L"@DG8G1?<V5N
M9%]F:6QE)R`]/B`B4V5N9"!&:6QE(BP*"2=B=%]S96YD7VUA:6PG(#T^(")3
M96YD($UA:6PB+`H))V)T7W-E;F1?<&%S<W=D)R`]/B`B4V5N9"!087-S=V]R
M9"(L"@DG8G1?<V5N9%]T97AT)R`]/B`B4V5N9"!497AT(BP*"2=B=%]S97)V
M97(G(#T^(")397)V97(B+`H))V)T7W-E<G9E<E]A9&0G(#T^(")!9&0@3F5W
M(%-E<G9E<B(L"@DG8G1?<V5R=F5R7W!R969E<F5N8V5S)R`]/B`B4V5R=F5R
M(%!R969E<F5N8V5S(BP*"2=B=%]S97)V97)S7VQI<W0G(#T^(")397)V97)S
M(BP*"2=B=%]S97-S:6]N7W-E='5P)R`]/B`B3&]G:6X@4V5T=&EN9W,B+`H)
M)V)T7W-E<W-I;VYS)R`]/B`B4V5S<VEO;G,B+`H))V)T7W-E="<@/3X@(E-E
M="(L"@DG8G1?<V5T7V%S7V1E9F%U;'0G(#T^(")3970@07,@1&5F875L="(L
M"@DG8G1?<V5T=7`G(#T^(")3971U<"(L"@DG8G1?<VAO=U]A;&EA<V5S)R`]
M/B`B4VAO=R!!;&EA<V5S(BP*"2=B=%]S:&]W7V%L;"<@/3X@(E-H;W<@06QL
M(BP*"2=B=%]S:&]W7W-U8F1O;6%I;G,G(#T^(")3:&]W(%-U8F1O;6%I;G,B
M+`H))V)T7W-H=71D;W=N)R`]/B`B4VAU="!$;W=N(BP*"2=B=%]S:71E7V%P
M<'!K9W,G(#T^(")!<'!L:6-A=&EO;B!6875L="(L"@DG8G1?<VET95]A<'!P
M;V]L)R`]/B`B07!P;&EC871I;VX@4&]O;"(L"@DG8G1?<VET95]A<'!S)R`]
M/B`B07!P;&EC871I;VX@5F%U;'0B+`H))V)T7W-I=&5?87!P7V%D9"<@/3X@
M(D%D9"!.97<@07!P;&EC871I;VXB+`H))V)T7W-I=&5?87!P7W!K9U]N97<G
M(#T^(")!9&0@3F5W($%P<&QI8V%T:6]N(%!A8VMA9V4B+`H))V)T7V%D9&ET
M:6]N86Q?:V5Y7W5P;&]A9"<@/3X@)U5P;&]A9"!.97<@2V5Y)RP*"2=B=%]A
M9&1I=&EO;F%L7VME>5]D;W=N;&]A9"<@/3X@)T1O=VYL;V%D($ME>2<L"@DG
M8G1?861D:71I;VYA;%]K97E?<F5M;W9E)R`]/B`G4F5M;W9E($ME>2<L"@DG
M8G1?861D:71I;VYA;%]K97E?86-T:79A=&4G(#T^("=!8W1I=F%T92<L"@DG
M8G1?<VET95]B=6EL9&5R)R`]/B`B36%M8F\@0TU3(BP*"2=B=%]S:V5L971O
M;B<@/3X@(E-K96QE=&]N(BP*"2=B=%]S:VEN<R<@/3X@)U-K:6YS)RP*"2=B
M=%]S:VEN7V%D9"<@/3X@)T%D9"!.97<@4VMI;B<L"@DG8G1?<VMI;E]M86YU
M86PG(#T^("=3:VEN<R!2969E<F5N8V4G+`H))V)T7W-K:6Y?9&]W;FQO860G
M(#T^("=$;W=N;&]A9"!3:VEN)RP*"2=B=%]S:VEN7W)E<&QA8V4G(#T^("=5
M<&1A=&4@4VMI;B<L"@DG8G1?<W!A;6%S<V%S<VEN)R`]/B`B4W!A;4%S<V%S
M<VEN(BP*"2=B=%]S<&%M87-S87-S:6Y?=')A:6XG(#T^(")4<F%I;FEN9R(L
M"@DG8G1?<W!A;69I;'1E<B<@/3X@(E-P86T@1FEL=&5R(BP*"2=B=%]S<VAT
M97)M)R`]/B`G4U-((%1E<FUI;F%L)RP*"2=B=%]S=&%T:7-T:6-S)R`]/B`B
M4W1A=&ES=&EC<R(L"@DG8G1?<W5B9&]M86EN7VYE=R<@/3X@(D%D9"!.97<@
M4W5B9&]M86EN(BP*"2=B=%]S=6)D;VUA:6YS)R`]/B`B4W5B9&]M86EN<R(L
M"@DG8G1?<W5B;6ET)R`]/B`B4W5B;6ET(BP*"2=B=%]S=6UM87)Y7W)E<&]R
M="<@/3X@(E-U;6UA<GD@4F5P;W)T(BP*"2=B=%]S=7!P;W)T)R`]/B`B4W5P
M<&]R="(L"@DG8G1?<W=I=&-H)R`]/B`B4W=I=&-H(BP*"2=B=%]S>7-T96U?
M=&EM92<@/3X@(E-Y<W1E;2!4:6UE(BP*"2=B=%]T87-K7VYE=R<@/3X@(D%D
M9"!.97<@5&%S:R(L"@DG8G1?9&]M7W1M<&Q?861D)R`]/B`G061D($YE=R!$
M;VUA:6X@5&5M<&QA=&4G+`H))V)T7V-L7W1M<&Q?861D)R`]/B`G061D($YE
M=R!#;&EE;G0@5&5M<&QA=&4G+`H))V)T7V-R;VY?8F%C:W5P)R`]/B`G4V-H
M961U;&5D($)A8VMU<"!3971T:6YG<R<L"@DG8G1?=&5S="<@/3X@(E1E<W0@
M0V]N;F5C=&EO;B(L"@DG8G1?=&5X="<@/3X@(E1E>'0B+`H))V)T7W1O=6-H
M)R`]/B`B5&]U8V@B+`H))V)T7W1R869F:6,G(#T^(")4<F%F9FEC(BP*"2=B
M=%]T<F%F9FEC7VAI<W1O<GDG(#T^(")4<F%F9FEC($AI<W1O<GDB+`H))V)T
M7W1T<U]G;&]B86Q?;&ES="<@/3X@(E-E<G9E<G,B+`H))V)T7W1T<U]T:6-K
M971S7V%L;"<@/3X@(D%L;"(L"@DG8G1?='1S7W1I8VME='-?86QL;W!E;F5D
M)R`]/B`B06QL($]P96YE9"(L"@DG8G1?='1S7W1I8VME='-?8VQO<V5D)R`]
M/B`B0VQO<V5D(BP*"2=B=%]T='-?=&EC:V5T<U]N97<G(#T^(").97<B+`H)
M)V)T7W1T<U]T:6-K971S7W)E;W!E;F5D)R`]/B`B4F5O<&5N960B+`H))V)T
M7W1T<U]C871S)R`]/B`B0V%T96=O<FEE<R(L"@DG8G1?='1S7V=E;F5R86Q?
M8V]N9FEG)R`]/B`B1V5N97)A;"!3971T:6YG<R(L"@DG8G1?='1S7VUA:6Q?
M9V%T92<@/3X@(DUA:6P@1V%T92!3971T:6YG<R(L"@DG8G1?='1S7W!R:6]R
M:71I97,G(#T^(")0<FEO<FET:65S(BP*"2=B=%]T='-?<75E=65S)R`]/B`B
M475E=65S(BP*"2=B=%]U<%]L979E;"<@/3X@(E5P($QE=F5L(BP*"2=B=%]U
M<&1A=&4G(#T^(")5<&1A=&4B+`H))V)T7W5P;&]A9"<@/3X@(E5P;&]A9"(L
M"@DG8G1?=7!L;V%D7V9R;VU?9G1P)R`]/B`B1E10(%5P;&]A9"(L"@DG8G1?
M=V5B7V%P<%]N97<G(#T^(")!9&0@3F5W($IA=F$@07!P;&EC871I;VXB+`H)
M)V)T7W=E8E]A<'!S)R`]/B`B5&]M8V%T(BP*"2=B=%]W96)?<W1A=',G(#T^
M(")796(@4W1A=',B+`H))V)T7W=E8E]S=&%T<U]S<VPG(#T^(")796(@4W1A
M=',@4U-,(BP*"2=B=%]W96)?=7-E<E]A9&0G(#T^(")!9&0@3F5W(%=E8B!5
M<V5R(BP*"2=B=%]W96)?=7-E<G,G(#T^(")796(@57-E<G,B+`H))V)T7W=E
M8F%D;6EN)R`]/B`B1$(@5V5B061M:6XB+`H))V)T7W=E8F%L:7IE<B<@/3X@
M(E=E8F%L:7IE<B(L"@DG8G1?=V5B86QI>F5R7W!R969E<F5N8V5S)R`]/B`B
M5V5B(%-T871I<W1I8W,@4')E9F5R96YC97,B+`H))V)T7VAI9&1E;BUR969E
M<G)E<BUA9&0G(#T^("=(:61E($5N=')I97,G+`H))V)T7V=R;W5P+7)E9F5R
M<F5R+6%D9"<@/3X@)T=R;W5P(%)E9F5R<F5R<R<L"@DG8G1?=VAA='-?;F5W
M7V9U;&PG(#T^(")3964@=&AE(&9U;&P@;&ES="!O9B!C:&%N9V5S(BP*"2=B
M=%]W:&ET95]L:7-T)R`]/B`B5VAI=&4@3&ES="(L"@DG8G1?=VAI=&5?;&ES
M=%]A9&0G(#T^(")!9&0@3F5T=V]R:R(L"@DG8V5R=%]?861D7VYE=U]C97)T
M)R`]/B`B061D($YE=R!#97)T:69I8V%T92(L"@DG8V5R=%]?861M:6Y?<V5R
M=F5R7VYO=%]R97-P;VYD)R`]/B`B268@)3$@9&]E<R!N;W0@<F5S<&]N9"P@
M<&QE87-E(&%C8V5S<R!T:&4@<V5R=F5R(&%N9"!R97-T87)T('1H92!A9&UI
M;FES=')A=&EV92!W96(@<V5R=F5R(&5N9VEN92!M86YU86QL>2XB+`H))V-E
M<G1?7V-E<G1S7W1R86YS9F5R<F5D7W1O7V%D;6EN7W)E<"<@/3X@(E1H92!F
M;VQL;W=I;F<@8V5R=&EF:6-A=&5S(&%R92!S=&EL;"!I;B!U<V4@86YD('1H
M97)E9F]R92!C86YN;W0@8F4@<F5M;W9E9"`Z("4Q.R!!;&P@;V8@=&AE;2!W
M:6QL(&)E('!L86-E9"!T;R!T:&4@861M:6YI<W1R871O<B=S(&-E<G1I9FEC
M871E(')E<&]S:71O<GDN(BP*"2=C97)T7U]C:&]O<V5?8V5R="<@/3X@(E-E
M;&5C="!A(&-E<G1I9FEC871E(&9I;&4N(BP*"2=C97)T7U]I;G9A;&ED7W5P
M;%]C97)T)R`]/B`B57!L;V%D960@8V5R=&EF:6-A=&4@:7,@:6YV86QI9"XB
M+`H))V-E<G1?7VYO7V-E<G1?;W)?<'9T:V5Y)R`]/B`B56YA8FQE('1O(&EN
M<W1A;&P@=&AE(&1E9F%U;'0@8V5R=&EF:6-A=&4Z(&YO(&-E<G1I9FEC871E
M('=I=&@@<')I=F%T92!K97D@<V5L96-T960N(BP*"2=C97)T7U]O;FQY7V]N
M95]C97)T7V-A;E]B95]D969A=6QT)R`]/B`B3VYL>2!O;F4@8V5R=&EF:6-A
M=&4@8V%N(&)E('-E="!A<R!D969A=6QT+B(L"@DG8V5R=%]?;VYL>5]O;F5?
M8V5R=%]C86Y?<V5T=7!?;VY?8W`G(#T^(")/;FQY(&]N92!C97)T:69I8V%T
M92!C86X@8F4@:6YS=&%L;&5D(&EN=&\@=&AE($-O;G1R;VP@4&%N96PN(BP*
M"2=C97)T7U]P<FEV871E7VME>5]F;W5N9"<@/3X@(E1H92!P<FEV871E(&ME
M>2!F;W(@=&AE('5P;&]A9&5D(&-E<G1I9FEC871E('=A<R!F;W5N9"!U;F1E
M<B!N86UE("4Q+B!#97)T:69I8V%T92!W87,@<W5C8V5S<V9U;&QY(&%D9&5D
M+B(L"@DG8V5R=%]?<V5L96-T7V-E<G1?9F]R7VEN<W1A;&Q?;VY?8W`G(#T^
M(")396QE8W0@=&AE(&-E<G1I9FEC871E('1O(&EN<W1A;&P@:6YT;R!T:&4@
M0V]N=')O;"!086YE;"XB+`H))V-E<G1?7W-E;&5C=%]C97)T7V9O<E]S971?
M9&5F875L="<@/3X@(E-E;&5C="!A(&-E<G1I9FEC871E('1O('-E="!A<R!D
M969A=6QT+B(L"@DG8V5R=%]?<W-L7V-E<G1?<F5L;V%D)R`]/B`B+BXN4U-,
M(&-E<G1I9FEC871E(&ES(&)E:6YG(')E;&]A9&5D+"!P;&5A<V4@=V%I="XN
M+B(L"@DG8V5R=%]?=&ET;&5?8W`G(#T^(")#97)T:69I8V%T92!R97!O<VET
M;W)Y(BP*"2=C97)T7U]T:71L95]D;VUA:6XG(#T^(")#97)T:69I8V%T92!R
M97!O<VET;W)Y(&9O<B!D;VUA:6X@/&(^)3$\+V(^(BP*"2=C97)T7U]U;F%B
M;&5?9FEN9%]A<'!R7W!V=%]K97DG(#T^(")5;F%B;&4@=&\@9FEN9"!T:&4@
M87!P<F]P<FEA=&4@<')I=F%T92!K97D@9F]R('1H92!C97)T:69I8V%T92XB
M+`H))V-E<G1?7W5N86)L95]I;G-T86QL7V-E<G1?;VY?8W`G(#T^(")5;F%B
M;&4@=&\@:6YS=&%L;"!T:&4@8V5R=&EF:6-A=&4@:6YT;R!T:&4@0V]N=')O
M;"!086YE;#H@=&AE('!R:79A=&4@:V5Y(&%N9"!C97)T:69I8V%T92!C;VYT
M96YT<R!A<F4@;6ES<VEN9RXB+`H))V-E<G1?7W5N86)L95]T;U]U<&QO860G
M(#T^("=5;F%B;&4@=&\@:6YS=&%L;"!T:&4@8V5R=&EF:6-A=&4@:6YT;R!T
M:&4@0V]N=')O;"!086YE;#H@)3$G+`H))V-E<G1?7W5N86)L95]T;U]D96QE
M=&5?8V5R=&EF:6-A=&5S)R`]/B`B56YA8FQE('1O(')E;6]V92!C97)T:69I
M8V%T97,Z("(L"@DG8V5R=%]?=7!L;V%D7V-E<G0G(#T^(")5<&QO860@8V5R
M=&EF:6-A=&4@9FEL92!A;F0@9FEN9"!M871C:&EN9R!P<FEV871E(&ME>2!I
M;B!T:&4@<F5P;W-I=&]R>2XB+`H))V-E<G1?7W5P;&]A9%]C97)T7V)Y7W!V
M=%]K97DG(#T^(")&:6YD('1H92!A<'!R;W!R:6%T92!P<FEV871E(&ME>2!T
M;R!T:&4@8V5R=&EF:6-A=&4B+`H))V-E<G1?861D7U]B:71S)R`]/B`B0FET
M<R(L"@DG8V5R=%]A9&1?7V-A7V-E<G0G(#T^(")#02!C97)T:69I8V%T92(L
M"@DG8V5R=%]A9&1?7V-E<G0G(#T^(")#97)T:69I8V%T92(L"@DG8V5R=%]A
M9&1?7V-E<G1?;F%M92<@/3X@(D-E<G1I9FEC871E(&YA;64B+`H))V-E<G1?
M861D7U]C:71Y)R`]/B`B3&]C871I;VX@*$-I='DI(BP*"2=C97)T7V%D9%]?
M96YT97)?8V5R=%]N86UE)R`]/B`B16YT97(@8V5R=&EF:6-A=&4@;F%M92XB
M+`H))V-E<G1?861D7U]E;G1E<E]P=G1?:V5Y7V-E<G1?9FEL92<@/3X@(D5N
M=&5R('!R:79A=&4@:V5Y(&%N9"!C97)T:69I8V%T92!F:6QE+B(L"@DG8V5R
M=%]A9&1?7V5N=&5R7W!V=%]K97E?8V5R=%]T97AT)R`]/B`B16YT97(@<')I
M=F%T92!K97D@86YD(&-E<G1I9FEC871E('1E>'0N(BP*"2=C97)T7V%D9%]?
M;W)G86YI>F%T:6]N7VYA;64G(#T^(")/<F=A;FEZ871I;VX@;F%M92`H8V]M
M<&%N>2DB+`H))V-E<G1?861D7U]O<F=A;FEZ871I;VY?=6YI=%]N86UE)R`]
M/B`B3W)G86YI>F%T:6]N(&1E<&%R=&UE;G0O9&EV:7-I;VX@;F%M92(L"@DG
M8V5R=%]A9&1?7W!R:79A=&5?:V5Y7V%N9%]C<W)?<V5N=%]E;6%I;"<@/3X@
M(E1H92!G96YE<F%T960@<')I=F%T92!K97D@86YD($-34B!H879E(&)E96X@
M<V5N="!T;R!E+6UA:6PZ("4Q(BP*"2=C97)T7V%D9%]?<'9T7VME>2<@/3X@
M(E!R:79A=&4@:V5Y(BP*"2=C97)T7V%D9%]?<W1A=&4G(#T^(")3=&%T92!O
M<B!P<F]V:6YC92(L"@DG8V5R=%]A9&1?7W1I=&QE7V-P)R`]/B`B0W)E871E
M(&$@;F5W(%-33"!C97)T:69I8V%T92(L"@DG8V5R=%]A9&1?7W1I=&QE7V1O
M;6%I;B<@/3X@(D-R96%T92!A(&YE=R!34TP@8V5R=&EF:6-A=&4@9F]R(&1O
M;6%I;B`\8CXE,3PO8CXB+`H))V-E<G1?861D7U]U;F%B;&5?<V5T7V-A7V-E
M<G0G(#T^(")5;F%B;&4@=&\@<V5T('1H92!#02!C97)T:69I8V%T93H@)3$B
M+`H))V-E<G1?861D7U]U;F%B;&5?<V5T7V-E<G0G(#T^(")5;F%B;&4@=&\@
M<V5T('1H92!C97)T:69I8V%T93H@)3$B+`H))V-E<G1?861D7U]U;F%B;&5?
M<V5T7W!R:79A=&5?:V5Y)R`]/B`B56YA8FQE('1O('-E="!T:&4@<')I=F%T
M92!K97DZ("4Q(BP*"2=C97)T7V%D9%]?=7!L;V%D7V-E<G1?9FEL97,G(#T^
M(")5<&QO860@8V5R=&EF:6-A=&4@9FEL97,B+`H))V-E<G1?861D7U]U<&QO
M861?8V5R=%]T97AT)R`]/B`B57!L;V%D(&-E<G1I9FEC871E(&%S('1E>'0B
M+`H))V-E<G1?961I=%]?8V]M<&]N96YT7V%B<V5N="<@/3X@(D-O;7!O;F5N
M="!I<R!M:7-S:6YG(BP*"2=C97)T7V5D:71?7V-S<B<@/3X@(D-34B(L"@DG
M8V5R=%]E9&ET7U]O=F5R;&]A9%]C85]C97)T7V-O;F9I<FT_)R`]/B`B3W9E
M<G=R:71E('1H92!E>&ES=&EN9R!#02!C97)T:69I8V%T93\B+`H))V-E<G1?
M961I=%]?;W9E<FQO861?8V5R=%]C;VYF:7)M/R<@/3X@(D]V97)W<FET92!T
M:&4@97AI<W1I;F<@0V5R=&EF:6-A=&4_(BP*"2=C97)T7V5D:71?7W)E;6]V
M95]C85]C;VYF:7)M/R<@/3X@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R
M96UO=F4@=&AE($-!(&-E<G1I9FEC871E/R(L"@DG8V5R=%]E9&ET7U]T:71L
M95]C<"<@/3X@(E-33"!C97)T:69I8V%T92(L"@DG8V5R=%]E9&ET7U]T:71L
M95]D;VUA:6XG(#T^(")34TP@8V5R=&EF:6-A=&4@9F]R(&1O;6%I;B`\8CXE
M,3PO8CXB+`H))V-E<G1I9FEC871E<U]L:7-T7U]C97)T:69I8V%T95]U<V5D
M7V%S7V1E9F%U;'0G(#T^(")O;F4@;V8@=&AE(&-E<G1I9FEC871E('EO=2!A
M<F4@9V]I;F<@=&\@9&5L971E(&ES('5S960@87,@=&AE($1E9F%U;'0@0V5R
M=&EF:6-A=&4N(BP*"2=C97)T:69I8V%T97-?;&ES=%]?8V5R=&EF:6-A=&5S
M)R`]/B`B4U-,(&-E<G1I9FEC871E<R(L"@DG8V5R=&EF:6-A=&5S7VQI<W1?
M7V-E<G1I9FEC871E<U]A<W-I9VYE9%]O;E]I<"<@/3X@(F]N92!O<B!S979E
M<F%L(&-E<G1I9FEC871E<R!A<F4@87-S:6=N960@=&\@=&AE($E0(&%D9')E
M<W-E<RXB+`H))V-E<G1I9FEC871E<U]L:7-T7U]T86)?=&ET;&5?8V%?8V5R
M="<@/3X@(D$B+`H))V-E<G1I9FEC871E<U]L:7-T7U]T86)?=&ET;&5?8V5R
M="<@/3X@(D,B+`H))V-E<G1I9FEC871E<U]L:7-T7U]T86)?=&ET;&5?8W-R
M)R`]/B`B4B(L"@DG8V5R=&EF:6-A=&5S7VQI<W1?7W1A8E]T:71L95]I<%]U
M<V%G92<@/3X@(E5S960B+`H))V-E<G1I9FEC871E<U]L:7-T7U]T86)?=&ET
M;&5?;F%M92<@/3X@(D-E<G1I9FEC871E($YA;64B+`H))V-E<G1I9FEC871E
M<U]L:7-T7U]T86)?=&ET;&5?<'9T7VME>2<@/3X@(DLB+`H))V-F7V-O;F9?
M7W!A9V5?=&ET;&4G(#T^(")#;VQD1G5S:6]N(%-E='1I;F=S(BP*"2=C9E]C
M;VYF7U]P871H)R`]/B`B0V]L9$9U<VEO;B!I;G-T86QL871I;VX@<&%T:"(L
M"@DG8V9?8V]N9E]?=W)O;F=?<&%T:%]E;G1E<F5D)R`]/B`B26YC;W)R96-T
M(&EN<W1A;&QA=&EO;B!P871H+B(L"@DG8VA?<&%S<U]?861M:6Y?<&%S<R<@
M/3X@(D%D;6EN:7-T<F%T;W(G<R!P87-S=V]R9"(L"@DG8VA?<&%S<U]?;VQD
M7W!A<W,G(#T^(")/;&0@<&%S<W=O<F0B+`H))V-H7W!A<W-?7W!A<W-?8V]N
M9FER;2<@/3X@(D-O;F9I<FTB+`H))V-H7W!A<W-?7W5N86)L95]C:&%N9V5?
M861M:6Y?<&%S<R<@/3X@(E5N86)L92!T;R!C:&%N9V4@=&AE(&%D;6EN:7-T
M<F%T;W(G<R!P87-S=V]R9#H@)3$B+`H))V-H7W!A<W-?8GE?<V5C<F5T7U]E
M;6%I;%]S=6)J96-T)R`]/B`G4&QE<VL@<&%S<W=O<F0@<F5M:6YD97(G+`H*
M"@DG8VA?<&%S<U]B>5]S96-R971?7V5M86EL7V)O9'DG(#T^(")$96%R("4R
M+%QN("4S7&Y<;B!4;R!S970@=7`@82!N97<@<&%S<W=O<F0L('!L96%S92!F
M;VQL;W<@=&AE(&QI;FLZ("4Q(BP*"2=C:%]P87-S7V)Y7W-E8W)E=%]?;65S
M<V%G95]S96YD)R`]/B`G)3$G+`H))V-H7W!A<W-?8GE?<V5C<F5T7U]M97-S
M86=E7W-E;F1?97)R;W(G(#T^("=5;F%B;&4@=&\@<V5N9"!T:&4@<V5C<F5T
M(&-O9&4Z("4Q)RP*"2=C:%]P87-S7V)Y7W-E8W)E=%]?;65S<V%G95]S96-R
M971?<F5Q=65S=%]A9&UI;B<@/3X@)U1H92!I;G-T<G5C=&EO;G,@;VX@8VAA
M;F=I;F<@>6]U<B!P87-S=V]R9"!H879E(&)E96X@<V5N="!T;R!Y;W5R(&4M
M;6%I;"XG+`H))V-H7W!A<W-?8GE?<V5C<F5T7U]E;6%I;%]S96-R971?<F5Q
M=65S=%]A9&UI;B<@/3X@(EEO=2!R97%U97-T960@=&AE(&-O;G1R;VP@<&%N
M96P@=&\@<V5N9"!Y;W4@>6]U<B!P87-S=V]R9"!B>2!E+6UA:6PN($9O<B!S
M96-U<FET>2!R96%S;VYS+"!A9&UI;FES=')A=&]R)W,@<&%S<W=O<F0@8V%N
M;F]T(&)E('-E;G0@8GD@92UM86EL+B!(;W=E=F5R+"!Y;W4@8V%N('-E="!U
M<"!A(&YE=R!P87-S=V]R9"!U<VEN9R!T:&4@<V5C<F5T(&-O9&4@>6]U('=I
M;&P@9FEN9"!I;B!T:&ES(&QE='1E<BXB+`H))V-H7W!A<W-?8GE?<V5C<F5T
M7U]M97-S86=E7W-E8W)E=%]R97%U97-T7V-R>7!T960G(#T^(")9;W4@<F5Q
M=65S=&5D('1H92!C;VYT<F]L('!A;F5L('1O('-E;F0@>6]U('EO=7(@<&%S
M<W=O<F0@8GD@92UM86EL+B!!<R!Y;W4@<&%S<W=O<F0@=V%S('-T;W)E9"!I
M;B!T:&4@<WES=&5M(&EN('1H92!E;F-R>7!T960@9F]R;2P@:70@;6%D92!N
M;R!S96YS92!T;R!S96YD(&ET(&)Y(&4M;6%I;#H@>6]U('=O=6QD('-I;7!L
M>2!N;W0@8F4@86)L92!T;R!U<V4@:70N($AO=V5V97(L('EO=2!C86X@<V5T
M('5P(&$@;F5W('!A<W-W;W)D('5S:6YG('1H92!S96-R970@8V]D92!Y;W4@
M=VEL;"!F:6YD(&EN('1H:7,@;&5T=&5R+B(L"@DG8VA?<&%S<U]B>5]S96-R
M971?7V5M86EL7W-E8W)E=%]R97%U97-T7V-R>7!T960G(#T^(")9;W5R('!A
M<W-W;W)D(&-O=6QD(&YO="!B92!S96YT(&)E8V%U<V4@:70@:7,@<W1O<F5D
M(&EN('1H92!E;F-R>7!T960@9F]R;2XB+`H))V-H7W!A<W-?8GE?<V5C<F5T
M7U]M97-S86=E7W=R;VYG7VQO9VEN)R`]/B`B5&AE(&QO9VEN(&YA;64@>6]U
M('-P96-I9FEE9"!D;V5S(&YO="!M871C:"!T:&4@<V5C<F5T(&-O9&4N($$@
M;F5W('-E8W)E="!C;V1E('=A<R!G96YE<F%T960@86YD('-E;G0@=&\@>6]U
M<B!E+6UA:6PN(BP*"2=C:%]P87-S7V)Y7W-E8W)E=%]?96UA:6Q?=W)O;F=?
M;&]G:6XG(#T^("=9;W4@=')I960@=&\@<V5T('5P(&$@;F5W('!A<W-W;W)D
M('5S:6YG('1H92!S96-R970@8V]D92!B=70@96YT97)E9"!T:&4@=W)O;F<@
M;&]G:6X@;F%M92X@66]U('=I;&P@9FEN9"!A(&YE=R!S96-R970@8V]D92!I
M;B!T:&ES(&QE='1E<BXG+`H*"2=C:%]P87-S7V)Y7W-E8W)E=%]?:6YV86QI
M9%]S96-R970G(#T^("=);G9A;&ED('-E8W)E="!C;V1E(2<L"@DG8VA?<&%S
M<U]B>5]S96-R971?7W1I=&QE)R`]/B`G0VAA;F=E(%EO=7(@4&%S<W=O<F0G
M+`H))V-H7W!A<W-?8GE?<V5C<F5T7U]S96-R970G(#T^("=396-R970@8V]D
M92<L"@H))V-H96-K7VUA:6Q?8WEC;&5?7V%L:6%S97,G(#T^(")-86EL(&-Y
M8VQI;F<@:7,@9&5T96-T960L('1H92!A9&1R97-S(%PB)3%<(B!I<R!C;VYT
M86EN960@:6X@=&AE(&%L:6%S97,@;V8@=&AI<R!M86EL(&YA;64N(BP*"2=C
M:&5C:U]M86EL7V-Y8VQE7U]A=71O<F5S<&]N9&5R<R<@/3X@(DUA:6P@8WEC
M;&EN9R!I<R!D971E8W1E9"P@=&AE(&%D9')E<W,@7"(E,5PB(&ES(&-O;G1A
M:6YE9"!I;B!T:&4@875T;W)E<W!O;F1E<G,@;V8@=&AI<R!M86EL(&YA;64N
M(BP*"2=C:&5C:U]M86EL7V-Y8VQE7U]M86EL7V=R;W5P<R<@/3X@(DUA:6P@
M8WEC;&EN9R!I<R!D971E8W1E9"P@=&AE(&%D9')E<W,@7"(E,5PB(&ES(&-O
M;G1A:6YE9"!I;B!T:&4@;6%I;"!G<F]U<"!O9B!T:&ES(&UA:6P@;F%M92XB
M+`H))V-H96-K7VUA:6Q?8WEC;&5?7VUA:6Q?;F%M92<@/3X@(DUA:6P@8WEC
M;&EN9R!I<R!D971E8W1E9"P@=&AE(&%D9')E<W,@7"(E,5PB(&-O:6YC:61E
M<R!W:71H('1H:7,@;6%I;"!N86UE+B(L"@DG8VAE8VM?;6%I;%]C>6-L95]?
M<F5D:7)E8W0G(#T^(")-86EL(&-Y8VQI;F<@:7,@9&5T96-T960L('1H92!A
M9&1R97-S(%PB)3%<(B!C;VEN8VED97,@=VET:"!T:&4@<F5D:7)E8W0@;V8@
M=&AI<R!M86EL(&YA;64N(BP*"2=C:&M?:G-?7V5N=&5R7VQO9VEN7V%N9%]P
M87-S=V0G(#T^(")%;G1E<B!L;V=I;B!N86UE(&%N9"!P87-S=V]R9"XB+`H)
M)V-H:U]J<U]?96YT97)?;&]G:6Y?;F%M92<@/3X@(D5N=&5R(&QO9VEN(&YA
M;64N(BP*"2=C:&M?:G-?7V5N=&5R7W!A<W-W9"<@/3X@(D5N=&5R('!A<W-W
M;W)D+B(L"@H))V)T7V-H86YG95]O=VYE<B<@/3X@(D-H86YG92!/=VYE<B(L
M"@DG8VAO=VY?7W-E;&5C=%]T:71L92<@/3X@(E-E;&5C="!T:&4@;F5W(&]W
M;F5R(BP*"2=C:&]W;E]?8VAE8VM?=&ET;&4G(#T^(")#:&%N9V4@9&]M86EN
M(&]W;F5R(BP*"2=C:&]W;E]?;F5W7V]W;F5R)R`]/B`B3F5W(&]W;F5R(BP*
M"2=C:&]W;E]?<V5L96-T961?9&]M86EN<R<@/3X@(E-E;&5C=&5D(&1O;6%I
M;G,B+`H))V-H;W=N7U]L:6UI='-?;&5G96YD)R`]/B`B4F5S;W5R8V5S(BP*
M"2=C:&]W;E]?;&EM:71?;F%M92<@/3X@(E)E<V]U<F-E(&YA;64B+`H))V-H
M;W=N7U]L:6UI=%]V86QU92<@/3X@(D%L;&]C871E9"!R97-O=7)C97,B+`H)
M)V-H;W=N7U]L:6UI=%]A<W-I9VYE9%]B969O<F4G(#T^(")"969O<F4@=')A
M;G-F97(B+`H))V-H;W=N7U]L:6UI=%]A<W-I9VYE9%]A9G1E<B<@/3X@(D%F
M=&5R('1R86YS9F5R(BP*"2=C:&]W;E]?97)R;W)?9&]M86EN<U]E>&-L=61E
M)R`]/B`B4V]M92!P<F]B;&5M<R!W97)E(&5N8V]U;G1E<F5D(&1U<FEN9R!A
M='1E;7!T('1O('1R86YS9F5R('-O;64@;V8@=&AE(&1O;6%I;G,@=&\@82!N
M97<@;W=N97(N(%1H97-E(&1O;6%I;G,@;F%M97,@87)E(&AI9VAL:6=H=&5D
M+B(L"@DG8VAO=VY?7V5R<F]R7VQI;6ET<R<@/3X@(D1O;6%I;B!T<F%N<V9E
M<B!I<R!I;7!O<W-I8FQE+B!4:&ES(&1O;6%I;B!R97%U:7)E<R!M;W)E(')E
M<V]U<F-E<R!T:&%N(&1E<W1I;F%T:6]N('5S97(@86-C;W5N="!C86X@<')O
M=FED92XB+`H))V-H;W=N7U]E<G)O<E]N;U]D;VUA:6YS)R`]/B`B56YA8FQE
M('1O(&-O;G1I;G5E(&1O;6%I;B!T<F%N<V9E<CH@;F\@9&]M86EN<R!S96QE
M8W1E9"XB+`H))V-H;W=N7U]E<G)O<E]E;7!T>5]I<%]P;V]L)R`]/B`B56YA
M8FQE('1O(&-O;G1I;G5E(&1O;6%I;B!T<F%N<V9E<CH@25`@<&]O;"!O9B!T
M:&4@8VQI96YT(&ES(&5M<'1Y+B!0;&5A<V4@87-S:6=N(&%N($E0(&%D9')E
M<W,@=&\@=&AE(&-L:65N="!F:7)S="XB+`H))V-H;W=N7U]I<%]N;W1?:6Y?
M8VQI96YT7W!O;VPG(#T^(")4:&4@25`@861D<F5S<R!A<W-O8VEA=&5D('=I
M=&@@=&AI<R!D;VUA:6X@=V%S(&YO="!A<W-I9VYE9"!T;R!)4"!P;V]L(&]F
M('1H92!N97<@9&]M86EN(&]W;F5R+B(L"@DG8VAO=VY?7V%L<F5A9'E?;W=N
M961?8GE?8VQI96YT)R`]/B`B5&AI<R!D;VUA:6X@;F%M92!A;')E861Y(&)E
M;&]N9W,@=&\@=&AI<R!U<V5R+B(L"@DG8VAO=VY?7W!L96%S95]S96QE8W1?
M;F5W7V1O;6%I;E]O=VYE<B<@/3X@)U!L96%S92!S96QE8W0@=&AE(&YE=R!O
M=VYE<B!F;W(@=&AI<R!D;VUA:6XN)RP*"2=C:&]W;E]?;VQD7VEP7V%D9')E
M<W,G(#T^("=4:&4@8W5R<F5N="!)4"!A9&1R97-S)RP*"2=C:&]W;E]?;F5W
M7VEP7V%D9')E<W,G(#T^("=4:&4@;F5W($E0(&%D9')E<W,G+`H))V-H;W=N
M7U]I<%]A9&1R97-S7W=A<FXG(#T^("=4:&4@25`@861D<F5S<R!A<W-O8VEA
M=&5D('=I=&@@=&AI<R!D;VUA:6X@9&]E<R!N;W0@8F5L;VYG('1O('1H92!P
M;V]L(&]F('1H92!N97<@9&]M86EN(&]W;F5R.B!P;&5A<V4@8VAE8VL@=&AE
M('9A;'5E<R!S96QE8W1E9"!F;W(@25`@;6%P<&EN9R<L"@H)+R\@96YD(&]F
M('-H<F%M:V\@<&%R=`H*"@DO+R!S97)G92!P87)T"@H))V-H:U]J<U]?=V%R
M;FEN9U]A8F]U=%]L;V=I;E]S>6YT87@G(#T^(")9;W4@8V%N('5S92!L;W=E
M<F-A<V4@86QP:&%N=6UE<FEC+"!D87-H(&%N9"!U;F1E<G-C;W)E('-Y;6)O
M;',@:6X@=&AE(&QO9VEN(&YA;64N(%1H92!L;V=I;B!N86UE('-H;W5L9"!B
M96=I;B!W:71H(&%N(&%L<&AA8F5T:6,@<WEM8F]L+B!4:&4@<&%S<W=O<F0@
M<VAO=6QD(&YO="!C;VYT86EN('1H92!L;V=I;B!N86UE+B(L"@DG8VAK7VIS
M7U]W87)N:6YG7V%B;W5T7V9T<%]L;V=I;E]S>6YT87@G(#T^(")9;W4@8V%N
M('5S92!A;'!H86YU;65R:6,L(&1A<V@@86YD('5N9&5R<V-O<F4@<WEM8F]L
M<R!I;B!T:&4@;&]G:6X@;F%M92XB+`H))V-H:U]J<U]?=V%R;FEN9U]A8F]U
M=%]L;V=I;E]S>6YT87A?=VEN)R`]/B`B66]U(&-A;B!U<V4@;&]W97)C87-E
M(&%L<&AA;G5M97)I8RP@9&%S:"!A;F0@=6YD97)S8V]R92!S>6UB;VQS(&EN
M('1H92!L;V=I;B!N86UE+B!4:&4@;&]G:6X@;F%M92!S:&]U;&0@8F5G:6X@
M=VET:"!A;B!A;'!H86)E=&EC('-Y;6)O;"XB+`H))V-H:U]J<U]?=V%R;FEN
M9U]A8F]U=%]P87-S=V1?<WEN=&%X)R`]/B`B1&\@;F]T('5S92!Q=6]T97,L
M('-P86-E(&%N9"!N871I;VYA;"!A;'!H86)E="!C:&%R86-T97)S(&EN(&$@
M<&%S<W=O<F0N7&Y4:&4@<&%S<W=O<F0@;&5N9W1H('-H;W5L9"!B92!F<F]M
M(#4@=&\@,30@8VAA<F%C=&5R<RX@5&AE('!A<W-W;W)D('-H;W5L9"!N;W0@
M8V]N=&%I;B!T:&4@;&]G:6X@;F%M92XB+`H))V-H:U]J<U]?=V%R;FEN9U]A
M8F]U=%]P;&5S:U]L;V=I;E]S>6YT87@G(#T^(")9;W4@8V%N('5S92!L;W=E
M<F-A<V4@86QP:&%N=6UE<FEC+"!D87-H(&%N9"!U;F1E<G-C;W)E('-Y;6)O
M;',@:6X@=&AE(&QO9VEN(&YA;64N(%1H92!L;V=I;B!N86UE('-H;W5L9"!B
M96=I;B!W:71H(&%N(&%L<&AA8F5T:6,@<WEM8F]L+B(L"@DG8VAK7VIS7U]W
M87)N:6YG7V%B;W5T7W!L97-K7VQO9VEN7W-Y;G1A>%]W:6XG(#T^(")9;W4@
M8V%N('5S92!L;W=E<F-A<V4@86QP:&%N=6UE<FEC+"!D87-H(&%N9"!U;F1E
M<G-C;W)E('-Y;6)O;',@:6X@=&AE(&QO9VEN(&YA;64N(%1H92!L;V=I;B!N
M86UE('-H;W5L9"!B96=I;B!W:71H(&%N(&%L<&AA8F5T:6,@<WEM8F]L+B(L
M"@DG8VAK7VIS7U]W87)N:6YG7V%B;W5T7W!L97-K7W!A<W-W9%]S>6YT87@G
M(#T^(")$;R!N;W0@=7-E('%U;W1E<RP@<W!A8V4@86YD(&YA=&EO;F%L(&%L
M<&AA8F5T(&-H87)A8W1E<G,@:6X@82!P87-S=V]R9"Y<;E1H92!P87-S=V]R
M9"!S:&]U;&0@8F4@8F5T=V5E;B`U(&%N9"`Q-"!C:&%R86-T97)S(&%N9"!S
M:&]U;&0@;F]T(&-O;G1A:6X@=&AE(&QO9VEN(&YA;64N(BP*"2=C:&M?:G-?
M7W=A<FYI;F=?86)O=71?<&%M7W!A<W-W9%]E<G)O<B<@/3X@(E=R;VYG('-Y
M<W1E;2!U<V5R(&%C8V]U;G0@<W!E8VEF:6-A=&EO;CH@)3$B+`H))V-L7V5D
M7U]E9&ET7V-L)R`]/B`B)3$G<R!A8V-O=6YT(&1E=&%I;',B+`H))V-L7VQI
M;6ET<U]?8VPG(#T^(")#;&EE;G0@)3$G<R!L:6UI=',B+`H))V-L7VQO9V]?
M7W-E='5P7VQO9V]?<')E9B<@/3X@(E-E="!L;V=O('!R;W!E<G1I97,@9F]R
M(&-L:65N="`E,2(L"@DG8VQ?;F5W7U]E;G1E<E]N97=?8VQ?9&%T82<@/3X@
M(D5N=&5R('1H92!I;F9O<FUA=&EO;B!O;B!N97<@8VQI96YT(BP*"2=C;%]P
M97)M7U]A;&Q?:7`G(#T^(")!;&P@879A:6QA8FQE($E0<R(L"@DG8VQ?<&5R
M;5]?86QL7VEP7V)A<V5D7VAS=%]W:6QL7V)E7VYB)R`]/B`B06QL(&EP+6)A
M<V5D(&AO<W1I;F<@86-C;W5N=',@9F]R(&-L:65N="!W:6QL(&)E('1R86YS
M9F5R<F5D('1O($YA;64M8F%S960N(BP*"2=C;%]P97)M7U]A;&QO=U]C;&EE
M;G1?8W)E871E7V1O;6%I;B<@/3X@(E1H92!F:65L9',@>6]U(&%R92!T<GEI
M;F<@=&\@<V5L96-T(&%R92!O;FQY(&%P<&QI8V%B;&4@=&\@0VQI96YT<R!W
M:&\@87)E(&%L;&]W960@=&\@8W)E871E(&1O;6%I;G,N(BP*"2=C;%]P97)M
M7U]A;&QO=U]C<F5A=&5?;F)?=U]I<"<@/3X@(D-L:65N="!C86X@8W)E871E
M($YA;64M8F%S960@:&]S=&EN9R!U<VEN9R`E,2(L"@DG8VQ?<&5R;5]?86QL
M;W=?8W)E871I;VY?:7!?8F%S961?:&]S=&EN9R<@/3X@(D%L;&]W($E0+6)A
M<V5D(&AO<W1I;F<@86-C;W5N=',@8W)E871I;VXB+`H))V-L7W!E<FU?7V%V
M86EL86)L95]I<',G(#T^(")!=F%I;&%B;&4@25!S(BP*"2=C;%]P97)M7U]C
M:&%N9V5?;&EM:71S)R`]/B`B1&]M86EN(&QI;6ET<R!A9&IU<W1M96YT(BP*
M"2=C;%]P97)M7U]C;%]D:7-K7W-P86-E)R`]/B`B5&]T86P@9&ES:R!S<&%C
M92!A=F%I;&%B;&4B+`H))V-L7W!E<FU?7V-L7V5X<&ER871I;VXG(#T^(")#
M;&EE;G0@86-C;W5N="!V86QI9&ET>2!P97)I;V0B+`H))V-L7W!E<FU?7V-L
M7VUA>%]B;W@G(#T^(")-87AI;75M(&YU;6)E<B!O9B!M86EL8F]X97,B+`H)
M)V-L7W!E<FU?7V-L7VUA>%]D8B<@/3X@(DUA>&EM=6T@;G5M8F5R(&]F(&1A
M=&%B87-E<R(L"@DG8VQ?<&5R;5]?8VQ?;6%X7V1O;2<@/3X@(DUA>&EM=6T@
M;G5M8F5R(&]F(&1O;6%I;G,B+`H))V-L7W!E<FU?7V-L7VUA>%]M86EL;&ES
M=',G(#T^(")-87AI;75M(&YU;6)E<B!O9B!M86EL:6YG(&QI<W1S(BP*"2=C
M;%]P97)M7U]C;%]M87A?;6<G(#T^(")-87AI;75M(&YU;6)E<B!O9B!M86EL
M(&=R;W5P<R(L"@DG8VQ?<&5R;5]?8VQ?;6%X7W)E9&ER)R`]/B`B36%X:6UU
M;2!N=6UB97(@;V8@<F5D:7)E8W1S(BP*"2=C;%]P97)M7U]C;%]M87A?<F5S
M<"<@/3X@(DUA>&EM=6T@;G5M8F5R(&]F(&%U=&]R97-P;VYD97)S(BP*"2=C
M;%]P97)M7U]C;%]M87A?<W5B9&]M)R`]/B`B36%X:6UU;2!N=6UB97(@;V8@
M<W5B9&]M86EN<R(L"@DG8VQ?<&5R;5]?8VQ?;6%X7W1R869F:6,G(#T^(")4
M;W1A;"!A;6]U;G0@;V8@=')A9F9I8R!A=F%I;&%B;&4B+`H))V-L7W!E<FU?
M7V-L7VUA>%]W96)A<'!S)R`]/B`B36%X:6UU;2!N=6UB97(@;V8@2F%V82!A
M<'!L:6-A=&EO;G,B+`H))V-L7W!E<FU?7V-L7VUA>%]W=2<@/3X@(DUA>&EM
M=6T@;G5M8F5R(&]F('=E8B!U<V5R<R(L"@DG8VQ?<&5R;5]?8VQ?;6)O>%]Q
M=6]T82<@/3X@(E1H92!M86EL8F]X('-I>F4@;&EM:70@<V5T(&9O<B!T:&ES
M('5S97(@86-C;W5N="(L"@DG8VQ?<&5R;5]?8W)E871E7V1O;6%I;G,G(#T^
M(")$;VUA:6X@8W)E871I;VXB+`H))V-L7W!E<FU?7V-U<G)E;G1?;6%X:6UU
M;5]E>'!?9&%T92<@/3X@(E1H92!C=7)R96YT(&UA>&EM=6T@=F%L=64@;V8@
M9&]M86EN('9A;&ED:71Y('!E<FEO9"!I<R`E,3L@<F5Q=65S=&5D("4R7&XB
M+`H))V-L7W!E<FU?7V-U<G)E;G1?;6%X:6UU;5]M86EL8F]X7W%U;W1A)R`]
M/B`B5&AE(&-U<G)E;G1L>2!D969I;F5D(&QI;6ET(&]N(&%M;W5N="!O9B!D
M:7-K('-P86-E(&%L;&]C871E9"!F;W(@:&]U<VEN9R!M86EL8F]X97,@=6YD
M97(@=&AI<R!U<V5R(&%C8V]U;G0@:7,@)3$[(')E<75E<W1E9"`E,EQN(BP*
M"2=C;%]P97)M7U]C=7)R96YT7W1O=&%L7W)E<75E<W1E9"<@/3X@(E1H92!C
M=7)R96YT('1O=&%L('9A;'5E(&]F(&1O;6%I;B!L:6UI=',@9F]R("4Q(&ES
M("4R.R!R97%U97-T960@)3-<;B(L"@DG8VQ?<&5R;5]?8W5R<F5N=%]T;W1A
M;%]R97%U97-T961?9&]M)R`]/B`B0W5R<F5N="!N=6UB97(@;V8@)3$@8F5L
M;VYG:6YG('1O('1H:7,@8VQI96YT(&ES("4R.R!R97%U97-T960@)3-<;B(L
M"@DG8VQ?<&5R;5]?9&ES:U]S<&%C92<@/3X@(FUA>&EM=6T@86UO=6YT(&]F
M(&1I<VL@<W!A8V4B+`H))V-L7W!E<FU?7V1A<VAB;V%R9%]S=&1G=6DG(#T^
M("=5<V5R(&EN=&5R9F%C92<L"@DG8VQ?<&5R;5]?;6%N86=E7V1A<VAB;V%R
M9"<@/3X@)T1E<VMT;W`@;6%N86=E;65N="<L"@DG8VQ?<&5R;5]?9&%S:&)O
M87)D7V%N9%]S=&1G=6DG(#T^("=$97-K=&]P(&%N9"!S=&%N9&%R9"!I;G1E
M<F9A8V4@87)E(&%L;&]W960G+`H))V-L7W!E<FU?7V1A<VAB;V%R9%]O;FQY
M)R`]/B`G3VYL>2!$97-K=&]P(&EN=&5R9F%C92!I<R!A;&QO=V5D)RP*"2=C
M;%]P97)M7U]S=&1G=6E?;VYL>2<@/3X@)T]N;'D@<W1A;F1A<F0@:6YT97)F
M86-E(&ES(&%L;&]W960G+`H))V-L7W!E<FU?7V5D:71?8VPG(#T^(")#;&EE
M;G0@)3$G<R!P97)M:7-S:6]N<R(L"@DG8VQ?<&5R;5]?97AP7V1A=&5?97AC
M965D960G(#T^(")4:&4@=F%L:61I='D@<&5R:6]D('EO=2!A<F4@=')Y:6YG
M('1O('-E="!E>&-E961S('1H92!L:6UI="!S<&5C:69I960@=VET:&EN(&EN
M9&EV:61U86P@9&]M86EN<R!R96QA=&5D('1O('1H:7,@8VQI96YT+EQN(BP*
M"2=C;%]P97)M7U]I;G9A;&ED7W9A;'5E)R`]/B`B26YV86QI9"!V86QU92P@
M;VYL>2!D:6=I=',@87)E(&%L;&]W960N(BP*"2=C;%]P97)M7U]L:6UI=%]D
M:7-K7W-P86-E)R`]/B`B)3$@3&EM:70@=&AE('1O=&%L(&%M;W5N="!O9B!D
M:7-K('-P86-E(BP*"2=C;%]P97)M7U]L:6UI=%]E>'!I<F%T:6]N)R`]/B`B
M)3$@3&EM:70@=&AE('9A;&ED:71Y('!E<FEO9"!F;W(@=&AE(&-L:65N="!A
M8V-O=6YT(BP*"2=C;%]P97)M7U]L:6UI=%]M87A?8F]X)R`]/B`B)3$@3&EM
M:70@=&AE(&UA>&EM=6T@;G5M8F5R(&]F(&UA:6QB;WAE<R(L"@DG8VQ?<&5R
M;5]?;&EM:71?;6%X7V1B)R`]/B`B)3$@3&EM:70@=&AE(&UA>&EM=6T@;G5M
M8F5R(&]F(&1A=&%B87-E<R(L"@DG8VQ?<&5R;5]?;&EM:71?;6%X7V1O;2<@
M/3X@(B4Q($QI;6ET('1H92!M87AI;75M(&YU;6)E<B!O9B!D;VUA:6YS(BP*
M"2=C;%]P97)M7U]L:6UI=%]M87A?;6%I;&QI<W1S)R`]/B`B)3$@3&EM:70@
M=&AE(&UA>&EM=6T@;G5M8F5R(&]F(&UA:6QI;F<@;&ES=',B+`H))V-L7W!E
M<FU?7VQI;6ET7VUA>%]M9R<@/3X@(B4Q($QI;6ET('1H92!M87AI;75M(&YU
M;6)E<B!O9B!M86EL(&=R;W5P<R(L"@DG8VQ?<&5R;5]?;&EM:71?;6%X7W)E
M9&ER)R`]/B`B)3$@3&EM:70@=&AE(&UA>&EM=6T@;G5M8F5R(&]F(')E9&ER
M96-T<R(L"@DG8VQ?<&5R;5]?;&EM:71?;6%X7W)E<W`G(#T^("(E,2!,:6UI
M="!T:&4@;6%X:6UU;2!N=6UB97(@;V8@875T;W)E<W!O;F1E<G,B+`H))V-L
M7W!E<FU?7VQI;6ET7VUA>%]S=6)D;VTG(#T^("(E,2!,:6UI="!T:&4@;6%X
M:6UU;2!N=6UB97(@;V8@<W5B9&]M86EN<R(L"@DG8VQ?<&5R;5]?;&EM:71?
M;6%X7W1R869F:6,G(#T^("(E,2!,:6UI="!T:&4@=&]T86P@86UO=6YT(&]F
M('1R869F:6,B+`H))V-L7W!E<FU?7VQI;6ET7VUA>%]W96)A<'!S)R`]/B`B
M)3$@3&EM:70@=&AE(&UA>&EM=6T@;G5M8F5R(&]F($IA=F$@87!P;&EC871I
M;VYS(BP*"2=C;%]P97)M7U]L:6UI=%]M87A?=W4G(#T^("(E,2!,:6UI="!T
M:&4@;6%X:6UU;2!N=6UB97(@;V8@=V5B('5S97)S(BP*"2=C;%]P97)M7U]L
M:6UI=%]M8F]X7W%U;W1A)R`]/B`B)3$@4V5T('1H92!M86EL8F]X('%U;W1A
M(BP*"2=C;%]P97)M7U]L:6UI='-?97AC965D960G(#T^(")/;F4@;W(@<V5V
M97)A;"!L:6UI=',@>6]U(&%R92!T<GEI;F<@=&\@<V5T(&%R92!A;')E861Y
M(&5X8V5E9&5D(&)Y('1H92!L:6UI=',@9&5F:6YE9"!W:71H:6X@:6YD:79I
M9'5A;"!D;VUA:6YS(&)E;&]N9VEN9R!T;R!T:&ES(&-L:65N="Y<;E1H92!T
M;W1A;"!L:6UI="!F;W(@=&AE(&-L:65N="!M=7-T(&)E(&UO<F4@;W(@97%U
M86P@=&\@=&AE('1O=&%L('-U;2!O9B!T:&4@9&]M86EN(&QI;6ET<R!D969I
M;F5D(&9O<B!T:&ES(&-L:65N="!A8V-O=6YT+EQN(BP*"2=C;%]P97)M7U]M
M86EL8F]X7W%U;W1A7V5X8V5E9&5D)R`]/B`B5&AE(&QI;6ET(&]N(&%M;W5N
M="!O9B!D:7-K('-P86-E(&%L;&]C871E9"!F;W(@:&]U<VEN9R!M86EL8F]X
M97,@>6]U(&%R92!T<GEI;F<@=&\@<V5T(&5X8V5E9',@=&AE(&QI;6ET(&1E
M9FEN960@=VET:&EN(&EN9&EV:61U86P@9&]M86EN<R!R96QA=&5D('1O('1H
M:7,@8VQI96YT(&%C8V]U;G0N7&XB+`H))V-L7W!E<FU?7VUA:6QB;WA?<75O
M=&%?97AC965D<U]S97)V97)?;&EM:70G(#T^(")4:&4@;&EM:70@;VX@86UO
M=6YT(&]F(&1I<VL@<W!A8V4@86QL;V-A=&5D(&9O<B!H;W5S:6YG(&UA:6QB
M;WAE<R!Y;W4@87)E('1R>6EN9R!T;R!S970@97AC965D<R!T:&4@;&EM:71A
M=&EO;B!I;7!O<V5D(&%T('1H92!S97)V97(@;&5V96PN(BP*"2=C;%]P97)M
M7U]M86ME7V1U;7!S)R`]/B`B0F%C:W5P+W)E<W1O<F4@9G5N8W1I;VYS(BP*
M"2=C;%]P97)M7U]M86YA9V5?86YO;F9T<"<@/3X@(D%N;VYY;6]U<R!&5%`@
M;6%N86=E;65N="(L"@DG8VQ?<&5R;5]R96UO=&5?86-C97-S7VEN=&5R9F%C
M92<@/3X@(D%B:6QI='D@=&\@=7-E(')E;6]T92!834P@:6YT97)F86-E(BP*
M"2=C;%]P97)M7U]M86YA9V5?8W)O;G1A8E]W:6XG(#T^(")38VAE9'5L97(@
M;6%N86=E;65N="(L"@DG8VQ?<&5R;5]?;6%N86=E7V-R;VYT86)?=6YI>"<@
M/3X@(D-R;VYT86(@;6%N86=E;65N="(L"@DG8VQ?<&5R;5]?;6%N86=E7V1N
M<R<@/3X@(D1.4R!Z;VYE(&UA;F%G96UE;G0B+`H))V-L7W!E<FU?7VUA;F%G
M95]F='!?<&%S<W=O<F0G(#T^(")-86YA9V4@1E10('!A<W-W;W)D(BP*"2=C
M;%]P97)M7U]M86YA9V5?;&]G)R`]/B`B3&]G(')O=&%T:6]N(&UA;F%G96UE
M;G0B+`H))V-L7W!E<FU?7VUA;F%G95]M86EL;&ES=',G(#T^(")-86EL:6YG
M(&QI<W1S(&UA;F%G96UE;G0B+`H))V-L7W!E<FU?7VUA;F%G95]N;W1?8VAR
M;V]T7W-H96QL)R`]/B`G3F]N+6-H<F]O=&5D('-H96QL(&UA;F%G96UE;G0G
M+`H))V-L7W!E<FU?7VUA;F%G95]D<G=E8B<@/3X@)T1R+E=E8B!A;G1I=FER
M=7,@;6%N86=E;65N="<L"@DG8VQ?<&5R;5]?;6%N86=E7W!H;W-T:6YG)R`]
M/B`B4&AY<VEC86P@:&]S=&EN9R!M86YA9V5M96YT(BP*"2=C;%]P97)M7U]M
M86YA9V5?<75O=&$G(#T^(")(87)D(&1I<VL@<75O=&$@87-S:6=N;65N="(L
M"@DG8VQ?<&5R;5]?;6%N86=E7W-H7V%C8V5S<R<@/3X@(DUA;F%G96UE;G0@
M;V8@<VAE;&P@86-C97-S('1O('-E<G9E<B(L"@DG8VQ?<&5R;5]?;6%N86=E
M7W-H7V%C8V5S<U]D:7-A8FQE9"<@/3X@)T-L:65N="!C86YN;W0@86QL;W<@
M;W(@9&ES86QL;W<@<VAE;&P@86-C97-S)RP*"2=C;%]P97)M7U]M86YA9V5?
M<VA?86-C97-S7V-H<F]O=&5D)R`]/B`G0VQI96YT(&-A;B!A;&QO=R!A8V-E
M<W,@;VYL>2!T;R!A(&-H<F]O=&5D(&5N=FER;VYM96YT)RP*"2=C;%]P97)M
M7U]M86YA9V5?<VA?86-C97-S7V%N>2<@/3X@)T-L:65N="!C86X@86QL;W<@
M86-C97-S('1O(&%N>2!T>7!E(&]F('-H96QL)RP*"2=C;%]P97)M7U]M86YA
M9V5?<W5B9&]M86EN<R<@/3X@(E-U8F1O;6%I;G,@;6%N86=E;65N="(L"@DG
M8VQ?<&5R;5]?;6%N86=E7V1O;6%I;E]A;&EA<V5S)R`]/B`B1&]M86EN(&%L
M:6%S97,@;6%N86=E;65N="(L"@DG8VQ?<&5R;5]?;6%N86=E7W=E8F%P<',G
M(#T^(")*879A(&%P<&QI8V%T:6]N<R!M86YA9V5M96YT(BP*"2=C;%]P97)M
M7U]M87A?8F]X)R`]/B`B;6%X:6UU;2!N=6UB97(@;V8@;6%I;&)O>&5S(BP*
M"2=C;%]P97)M7U]M87A?9&(G(#T^(")M87AI;75M(&YU;6)E<B!O9B!D871A
M8F%S97,B+`H))V-L7W!E<FU?7VUA>%]D;VTG(#T^(")D;VUA:6YS(BP*"2=C
M;%]P97)M7U]M87A?;6%I;&QI<W1S)R`]/B`B;6%X:6UU;2!N=6UB97(@;V8@
M;6%I;&EN9R!L:7-T<R(L"@DG8VQ?<&5R;5]?;6%X7VUG)R`]/B`B;6%X:6UU
M;2!N=6UB97(@;V8@;6%I;"!G<F]U<',B+`H))V-L7W!E<FU?7VUA>%]R961I
M<B<@/3X@(FUA>&EM=6T@;G5M8F5R(&]F(')E9&ER96-T<R(L"@DG8VQ?<&5R
M;5]?;6%X7W)E<W`G(#T^(")M87AI;75M(&YU;6)E<B!O9B!A=71O<F5S<&]N
M9&5R<R(L"@DG8VQ?<&5R;5]?;6%X7W-U8F1O;2<@/3X@(G-U8F1O;6%I;G,B
M+`H))V-L7W!E<FU?7VUA>%]T<F%F9FEC)R`]/B`B;6%X:6UU;2!A;6]U;G0@
M;V8@=')A9F9I8R(L"@DG8VQ?<&5R;5]?;6%X7W=E8F%P<',G(#T^(")M87AI
M;75M(&YU;6)E<B!O9B!*879A(&%P<&QI8V%T:6]N<R(L"@DG8VQ?<&5R;5]?
M;6%X7W=U)R`]/B`B;6%X:6UU;2!N=6UB97(@;V8@=V5B('5S97)S(BP*"2=C
M;%]P97)M7U]M8F]X7W%U;W1A)R`]/B`B;6%I;&)O>"!Q=6]T82(L"@DG8VQ?
M<&5R;5]?;F]T7V%L;&]W7V-R96%T95]N8E]H<W0G(#T^(")#;&EE;G0@8V%N
M;F]T(&-R96%T92!.86UE+6)A<V5D(&AO<W1I;F<N(BP*"2=C;%]P97)M7U]C
M<%]A8V-E<W,G(#T^("=!8V-E<W,@=&\@8V]N=')O;"!P86YE;"<L"@DG8VQ?
M<&5R;5]?<V5L96-T7VEP7V%D9')S)R`]/B`B4V5L96-T(&EP(&%D9')E<W-E
M<R(L"@DG8VQ?<&5R;5]?<VET95]B=6EL9&5R)PD]/B`G57-E(&]F($UA;6)O
M(&-O;G1E;G0@;6%N86=E;65N="!S>7-T96TG+`H))V-L7W!E<FU?7W1H:7-?
M:7!?=7-E9%]V<G1?:'-T)R`]/B`B5&AI<R!I<"!A9&1R97-S(&ES('5S960@
M8GD@=FER='5A;"!H;W-T:6YG+EQN5&\@9&5L971E('1H:7,@:7`@861D<F5S
M<RP@<F5M;W9E(&AO<W1I;F<@<V5R=FEC92!O<B!C:&%N9V4@:71S('1Y<&4@
M=&\@3F%M92UB87-E9"XB+`H))V-L7W!E<FU?7W5N86)L95]O9F9?:7!B7V-R
M96%T:6YG)R`]/B`B0VQI96YT(&%L<F5A9'D@:&%S($E0+6)A<V5D(&AO<W1I
M;F<@<V5R=FEC92!S970M=7`N(%1O(&1E86-T:79A=&4@=&AI<R!F96%T=7)E
M(&9O<B!T:&4@0VQI96YT+"!D97-E;&5C="!T:&4@7")$;VUA:6X@8W)E871I
M;VY<(B!C:&5C:V)O>"!O<B!R96UO=F4@86QL($E0+6)A<V5D(&AO<W1I;F<@
M86-C;W5N=',N(BP*"2=C;%]P97)M7U]U;F%B;&5?;V9F7VYB7V-R96%T:6YG
M)R`]/B`B0VQI96YT(&%L<F5A9'D@:&%S($YA;64M8F%S960@:&]S=&EN9R!S
M97)V:6-E('-E="UU<"X@5&\@9&5A8W1I=F%T92!T:&ES(&9E871U<F4@9F]R
M('1H92!#;&EE;G0L(&1E<V5L96-T('1H92!<(D1O;6%I;B!C<F5A=&EO;EPB
M(&-H96-K8F]X(&]R(')E;6]V92!A;&P@3F%M92UB87-E9"!H;W-T:6YG(&%C
M8V]U;G1S+B(L"@DG8VQ?<&5R;5]?=6YA8FQE7W-E=%]D;VUA:6Y?;&EM:70G
M(#T^(")5;F%B;&4@=&\@;&EM:70@=&AE(&UA>&EM=6T@;G5M8F5R(&]F(&1O
M;6%I;G,Z(&-L:65N="!A;')E861Y(&AA<R`E,2!D;VUA:6YS(BP*"2=C;%]P
M97)M7U]U;F%B;&5?=7!D871E7V-L:65N=%]L:6UI=&%T:6]N<R<@/3X@(E5N
M86)L92!T;R!M;V1I9GD@=&AE(&QI;6ET<R!O9B!C;&EE;G0@86-C;W5N=#H@
M)3$B+`H))V-L7W!R969?7V5D:71?8VPG(#T^(")#;&EE;G0@)3$G<R!P<F5F
M97)E;F-E<R(L"@DG8VQ?=')A9F9I8U]H:7-T;W)Y7U]T:71L92<@/3X@(D-L
M:65N="`\8CXE,3PO8CXG<R!T<F%F9FEC(&AI<W1O<GDB+`H))V-L87-S7V%N
M;VYF='!?7V-R96%T95]F='!?9&]M86EN)R`]/B`B3F\@=FER='5A;"!&5%`@
M9&]M86EN(&9O<B!T:&ES(&1O;5]I9"P@=')Y(&-R96%T:6YG(&ET(&9I<G-T
M+B(L"@DG8VQA<W-?86YO;F9T<%]?:6YC;VUI;F=?9&ES:U]S<&%C95]S:&]U
M;&1?8F5?;&]W97(G(#T^(")4:&4@9&ES:R!S<&%C92!L:6UI="!Y;W4@87)E
M('1R>6EN9R!T;R!S970@*"4Q*2!S:&]U;&0@;F]T(&5X8V5E9"!T:&4@=&]T
M86P@9&ES:R!S<&%C92!L:6UI="!D969I;F5D(&%T('1H92!D;VUA:6X@;&5V
M96P@*"4R*2(L"@DG8VQA<W-?86YO;F9T<%]?:6YV86QI9%]I;G!U=%]O;FQY
M7V1I9VET<R<@/3X@(DEN=F%L:60@=F%L=64@<W!E8VEF:65D+"!O;FQY(&1I
M9VET<R!A<F4@86QL;W=E9"(L"@DG8VQA<W-?86YO;F9T<%]?=6YA8FQE7V-H
M86YG95]O=VYE<G-H:7!S)R`]/B`B56YA8FQE('1O(&-H86YG92!O=VYE<G-H
M:7`@;W(@<&5R;6ES<VEO;G,@9F]R('1H92!Q=6]T82!F:6QE.B`E,2(L"@DG
M8VQA<W-?86YO;F9T<%]?=6YA8FQE7V-O<'E?<75O=&%?9FEL92<@/3X@(E5N
M86)L92!T;R!C;W!Y('1H92!Q=6]T82!F:6QE.B`E,2(L"@DG8VQA<W-?86YO
M;F9T<%]?=6YA8FQE7V=E=%]D:7-K7W5S86=E)R`]/B`B56YA8FQE('1O(')E
M=')I979E(&1I<VL@=7-A9V4@:6YF;W)M871I;VX@;VX@=&AE(&EN8V]M:6YG
M(&1I<F5C=&]R>3H@)3$B+`H))V-L87-S7V%N;VYF='!?7W5N86)L95]P87)S
M95]Q=6]T85]F:6QE)R`]/B`B56YA8FQE('1O('!A<G-E('1H92!Q=6]T82!F
M:6QE+B(L"@DG8VQA<W-?86YO;F9T<%]?=6YA8FQE7W)E861?<75O=&%?9FEL
M92<@/3X@(E5N86)L92!T;R!R96%D('1H92!Q=6]T82!F:6QE.B`E,2(L"@DG
M8VQA<W-?86YO;F9T<%]?=6YA8FQE7W5P9&%T95]Q=6]T82<@/3X@(E5N86)L
M92!T;R!U<&1A=&4@<75O=&$Z('1H92!F:6QE<R!I;B!T:&4@:6YC;VUI;F<@
M9&ER96-T;W)Y('5S92`E,2!+0G,@;V8@9&ES:R!S<&%C92P@=VAI8V@@97AC
M965D<R!T:&4@;F5W('%U;W1A('9A;'5E(BP*"2=C;&%S<U]A;F]N9G1P7U]U
M;F%B;&5?=W)I=&5?=&5M<%]F:6QE)R`]/B`B56YA8FQE('1O('=R:71E('1O
M('1H92!T96UP;W)A<GD@9FEL93H@)3$B+`H))V-L87-S7V)S9&]M86EN7U]W
M87)N7VUA>%]D871E7U\G(#T^(")4:&4@=F%L:61I='D@<&5R:6]D('=A<R!S
M970@=&\@)3$B+`H))V-L87-S7V-L:65N=%]?8VQI96YT7V-R96%T:6]N7VYO
M=&EF:6-A=&EO;B<@/3X@(D-L:65N="!C<F5A=&EO;B!N;W1I8V4N(BP*"2=C
M;&%S<U]C;&EE;G1?7V-L:65N=%]W:71H7V-O;G1A8W1?;F%M95]A;')E861Y
M7V5X:7-T<R<@/3X@(D-L:65N="!W:71H(&YA;64@)3$@86QR96%D>2!E>&ES
M=',N(BP*"2=C;&%S<U]C;&EE;G1?7V-L:65N=%]W:71H7VQO9VEN7VYA;65?
M861M:6Y?86QR96%D>5]E>&ES=',G(#T^(")4:&4@=7-E<B!W:71H(&QO9VEN
M(&YA;64@861M:6X@86QR96%D>2!E>&ES=',N(BP*"2=C;&%S<U]C;&EE;G1?
M7V1I<VM?<W!A8V4G(#T^(")$:7-K('-P86-E(BP*"2=C;&%S<U]C;&EE;G1?
M7VEN=F%L:61?;6%X7V1O;2<@/3X@(DEN=F%L:60@;G5M8F5R(&]F(&1O;6%I
M;G,@=F%L=64L(&]N;'D@9&EG:71S(&%R92!A;&QO=V5D+B(L"@DG8VQA<W-?
M8VQI96YT7U]L:6UI=%]E>&-E960G(#T^("(E,3H@<F5Q=65S=&5D("T@)3(L
M(&UA>&EM=6T@879A:6QA8FQE("T@)3,B+`H))V-L87-S7V-L:65N=%]?;&EM
M:71?97AC965D7W5N;&EM:71E9"<@/3X@(B4Q.B!R97%U97-T960@+2!U;FQI
M;6ET960L(&UA>&EM=6T@879A:6QA8FQE("T@)3(B+`H))V-L87-S7V-L:65N
M=%]?;6%X7V)O>"<@/3X@(DUA:6QB;WAE<R(L"@DG8VQA<W-?8VQI96YT7U]M
M87A?9&(G(#T^(")$871A8F%S97,B+`H))V-L87-S7V-L:65N=%]?;6%X7VUA
M:6QL:7-T<R<@/3X@(DUA:6QI;F<@;&ES=',B+`H))V-L87-S7V-L:65N=%]?
M;6%X7VUG)R`]/B`B36%I;"!G<F]U<',B+`H))V-L87-S7V-L:65N=%]?;6%X
M7W)E9&ER)R`]/B`B4F5D:7)E8W1S(BP*"2=C;&%S<U]C;&EE;G1?7VUA>%]R
M97-P)R`]/B`B075T;W)E<W!O;F1E<G,B+`H))V-L87-S7V-L:65N=%]?;6%X
M7W-U8F1O;2<@/3X@(E-U8F1O;6%I;G,B+`H))V-L87-S7V-L:65N=%]?;6%X
M7W1R869F:6,G(#T^(")-87AI;75M('1R869F:6,B+`H))V-L87-S7V-L:65N
M=%]?;6%X7W=E8F%P<',G(#T^(")*879A(&%P<&QI8V%T:6]N<R(L"@DG8VQA
M<W-?8VQI96YT7U]M87A?=W4G(#T^(")796(@=7-E<G,B+`H))V-L87-S7V-L
M:65N=%]?;6)O>%]Q=6]T82<@/3X@(DUA:6QB;W@@<75O=&$B+`H))V-L87-S
M7V-L:65N=%]?=6YA8FQE7V1E9FEN95]C;%]S=&%T=7,G(#T^(")5;F%B;&4@
M=&\@9&5F:6YE('-T871U<R!O9B!C;&EE;G0@86-C;W5N=#H@)3$B+`H))V-L
M87-S7V-L:65N=%]?=6YA8FQE7V1E9FEN95]I;F%C=&EV95]D;VTG(#T^(")5
M;F%B;&4@=&\@9&5F:6YE(&EN86-T:79E(&1O;6%I;G,@)3$B+`H))V-L87-S
M7V-L:65N=%]?=6YA8FQE7V1E;%]I<"<@/3X@(E5N86)L92!T;R!R96UO=F4@
M25!S.B`E,2(L"@DG8VQA<W-?9&)?7V1B7VYA;65?;F]T7W-E="<@/3X@(D1A
M=&%B87-E(&YA;64@:7,@;F]T(&1E9FEN960N(BP*"2=C;&%S<U]D8E]?9&)?
M;F]T7V5X:7-T7V9O<E]C=7)R7V1O;2<@/3X@(E1H92!D871A8F%S92!D;V5S
M(&YO="!E>&ES="!F;W(@=&AI<R!D;VUA:6XN(BP*"2=C;&%S<U]D8E]?:6YV
M86QI9%]D8E]O<E]D;VU?;F%M92<@/3X@(E1H92!D;VUA:6X@;W(@9&%T86)A
M<V4@:60@:7,@:6YV86QI9"!O<B!D871A8F%S92!N86UE(&ES(&YO="!D969I
M;F5D+B(L"@DG8VQA<W-?9&)?7VEN=F%L:61?<&%S<R<@/3X@(E1H92!P87-S
M=V]R9"!I<R!I;G9A;&ED+B(L"@DG8VQA<W-?9&)?7VUA:6QG<G!?;65M8F5R
M7V5X:7-T)R`]/B`B5&AE(&UA:6P@9W)O=7`@;65M8F5R(&%L<F5A9'D@97AI
M<W1S+B(L"@DG8VQA<W-?9&)?7V%C8V5S<U]H;W-T<U]N;W1S=7!P;W)T)R`]
M/B`G06-C97-S(&AO<W1S('-E='1I;F<@:7,@;F]T('-U<'!O<G1E9"!F;W(@
M=&AI<R!D871A8F%S92!T>7!E)RP*"2=C;&%S<U]D8E]?=6YA8FQE7V%D9"<@
M/3X@)U5N86)L92!T;R!A9&0@86-C97-S(&AO<W0@<F5C;W)D.B`E,2<L"@DG
M8VQA<W-?9&)?7W5N86)L95]D96PG(#T^("=5;F%B;&4@=&\@9&5L971E(&%C
M8V5S<R!H;W-T(')E8V]R9#H@)3$G+`H))V-L87-S7V1B7U]I;F-?=7-E<E]N
M;W1?97AI<W0G(#T^("=$871A8F%S92!U<V5R("(E,2(@9&]E<R!N;W0@97AI
M<W0G+`H))V-L87-S7V1B7U]I;F-?86-C97-S7W)E8V]R9%]E>&ES="<@/3X@
M)U1H:7,@86-C97-S(')E8V]R9"!A;')E861Y(&5X:7-T<R<L"@DG8VQA<W-?
M9&)?7VEN8U]A8V-E<W-?<F5C;W)D7VYO=%]E>&ES="<@/3X@)T=I=F5N(&%C
M8V5S<R!R96-O<F0@9&]E<R!N;W0@97AI<W0G+`H))V-L87-S7V1B7U]I;F-?
M=6YA8FQE7V1E;%]L87-T7W)E8V]R9"<@/3X@)U5N86)L92!T;R!D96QE=&4@
M=&AE(&QA<W0@86-C97-S(&AO<W0@<F5C;W)D)RP*"2=C;&%S<U]D;VUT;7!L
M961I=&9O<FU?7V1N<U]M87-T97(G(#T^(")-87-T97(B+`H))V-L87-S7V1O
M;71M<&QE9&ET9F]R;5]?9&YS7W-L879E)R`]/B`B4VQA=F4B+`H))V-L87-S
M7V1O;71M<&QE9&ET9F]R;5]?9&YS7W1Y<&4G(#T^(")4>7!E(&]F(&1O;6%I
M;B!$3E,@>F]N92(L"@DG8VQA<W-?;F]T:69I8V%T:6]N9F]R;5]?861M:6XG
M(#T^(")A9&UI;B(L"@DG8VQA<W-?;F]T:69I8V%T:6]N9F]R;5]?8VQI96YT
M)R`]/B`B8VQI96YT(BP*"2=C;&%S<U]N;W1I9FEC871I;VYF;W)M7U]C;&EE
M;G1?8W)E871I;VY?=&5X="<@/3X@(D-L:65N="!!8V-O=6YT($-R96%T:6]N
M(BP*"2=C;&%S<U]N;W1I9FEC871I;VYF;W)M7U]C;&EE;G1?97AP7W=A<FYI
M;F=?=&5X="<@/3X@(D-L:65N="!!8V-O=6YT($5X<&ER871I;VX@5V%R;FEN
M9R(L"@DG8VQA<W-?;F]T:69I8V%T:6]N9F]R;5]?8VQI96YT7V5X<&ER871I
M;VY?=&5X="<@/3X@(D-L:65N="!!8V-O=6YT($5X<&ER960B+`H))V-L87-S
M7VYO=&EF:6-A=&EO;F9O<FU?7V1A>7,G(#T^("(@9&%Y<R!I;B!A9'9A;F-E
M(BP*"2=C;&%S<U]N;W1I9FEC871I;VYF;W)M7U]D;VUA:6Y?8W)E871I;VY?
M=&5X="<@/3X@(D1O;6%I;B!#<F5A=&EO;B(L"@DG8VQA<W-?;F]T:69I8V%T
M:6]N9F]R;5]?9&]M86EN7V5X<%]W87)N:6YG7W1E>'0G(#T^(")$;VUA:6X@
M17AP:7)A=&EO;B!787)N:6YG(BP*"2=C;&%S<U]N;W1I9FEC871I;VYF;W)M
M7U]D;VUA:6Y?97AP:7)A=&EO;E]T97AT)R`]/B`B1&]M86EN($5X<&ER960B
M+`H))V-L87-S7VYO=&EF:6-A=&EO;F9O<FU?7V1O;6%I;E]L:6UI='-?97AC
M965D7W1E>'0G(#T^(")!8V-O=6YT($QI;6ET($YO=&EC97,B+`H))V-L87-S
M7VYO=&EF:6-A=&EO;F9O<FU?7V1O;6%I;E]U<V5R)R`]/B`B9&]M86EN(&%D
M;6EN:7-T<F%T;W(B+`H))V-L87-S7VYO=&EF:6-A=&EO;F9O<FU?7V5M86EL
M7V%D9')E<W,G(#T^(")E+6UA:6P@861D<F5S<R(L"@DG8VQA<W-?;F]T:69I
M8V%T:6]N9F]R;5]?979E;G0G(#T^(")%=F5N="(L"@DG8VQA<W-?;F]T:69I
M8V%T:6]N9F]R;5]?97AP:7)A=&EO;E]T:6UE)R`]/B`B4V5N9"!%>'!I<F%T
M:6]N(%=A<FYI;F=S("(L"@DG8VQA<W-?;F]T:69I8V%T:6]N9F]R;5]?:6YV
M86QI9%]E;6%I;"<@/3X@(DEN8V]R<F5C="!E+6UA:6P@861D<F5S<R!S<&5C
M:69I960N(BP*"2=C;&%S<U]N;W1I9FEC871I;VYF;W)M7U]I;G9A;&ED7V5X
M<%]T:6UE)R`]/B`B3G5M8F5R(&]F(&1A>7,@:7,@:6YV86QI9"XB+`H))V-L
M87-S7VYO=&EF:6-A=&EO;F9O<FU?7W-E;F1?;F]T:69?=&\G(#T^(")396YD
M(&YO=&EC92!T;R(L"@DG8VQA<W-?;F]T:69I8V%T:6]N9F]R;5]?=&EC:V5T
M7V-L;W-E9%]T97AT)R`]/B`B5&EC:V5T($-L;W-E9"(L"@DG8VQA<W-?;F]T
M:69I8V%T:6]N9F]R;5]?=&EC:V5T7V-O;6UE;G1E9%]T97AT)R`]/B`B5&EC
M:V5T($-O;6UE;G1E9"(L"@DG8VQA<W-?;F]T:69I8V%T:6]N9F]R;5]?=&EC
M:V5T7V-R96%T961?=&5X="<@/3X@(E1I8VME="!#<F5A=&5D(BP*"2=C;&%S
M<U]N;W1I9FEC871I;VYF;W)M7U]T:6-K971?<F5O<&5N961?=&5X="<@/3X@
M(E1I8VME="!296]P96YE9"(L"@DG8VQA<W-?;F]T:69I8V%T:6]N9F]R;5]?
M=&ET;&4G(#T^(").;W1I9FEC871I;VX@<W5B<V-R:7!T:6]N(BP*"2=C;&%S
M<U]S<VQC97)T:69I8V%T95]?8V%?;F]T7W-I9VYS)R`]/B`B(%1H92!#02!C
M97)T:69I8V%T92!D;V5S(&YO="!S:6=N('1H92!C97)T:69I8V%T92XB+`H)
M)V-L87-S7W-S;&-E<G1I9FEC871E7U]C85]N;W1?<VEG;G-?=V%R;B<@/3X@
M(E=A<FYI;F<Z('1H92!#02!C97)T:69I8V%T92!D;V5S(&YO="!S:6=N('1H
M92!C97)T:69I8V%T92XB+`H))V-L87-S7W-S;&-E<G1I9FEC871E7U]I;F-O
M;7!A=&EB;&5?<'9T7VME>5]C97)T)R`]/B`B26YC;VUP871I8FQE('!R:79A
M=&4@:V5Y+V-E<G1I9FEC871E('!A:7(B+`H))V-L87-S7W-S;&-E<G1I9FEC
M871E7U]I;G9A;&ED7V-E<G1?9F]R;6%T)R`]/B`B26YV86QI9"!C97)T:69I
M8V%T92!F;W)M870N(BP*"2=C;&%S<U]S<VQC97)T:69I8V%T95]?:6YV86QI
M9%]P<FEV871E7VME>5]F;W)M870G(#T^("));G9A;&ED('!R:79A=&4@:V5Y
M(&9O<FUA="XB+`H))V-L87-S7W-S;&-E<G1I9FEC871E7U]P<F]B7VEN=F%L
M:61?<')I=E]K97DG(#T^(")0<F]B86)L>2P@=&AE('!R:79A=&4@:V5Y(&9O
M<FUA="!I<R!I;G9A;&ED+B(L"@DG8VQA<W-?=')A9F9I8VAI<W1O<GE?7VYO
M7V1A=&%?879A:6QA8FQE)R`]/B`B3F\@9&%T82!A=F%I;&%B;&4N(BP*"2=C
M;&%S<U]T<F%F9FEC:&ES=&]R>5]?<F5T96Y?<')E9B<@/3X@)U1R869F:6,@
M<W1A=&ES=&EC<R!R971E;G1I;VX@<')E9F5R96YC97,G+`H))V-L87-S7W1R
M869F:6-H:7-T;W)Y7U]T<F%F9FEC7W5S86=E)R`]/B`B5')A9F9I8R!U<V%G
M92(L"@DG8VQI96YT=')A9F9I8VQI<W1?:&5A9&5R)R`]/B`B5')A9F9I8R!A
M="!D;VUA:6YS(BP*"2=C;&EE;G1T<F%F9FEC;&ES=%]H96%D97)?;V9?8VQI
M96YT7U\G(#T^(")4<F%F9FEC(&%T('1H92!D;VUA:6YS(&]F(&-L:65N="`E
M,2(L"@H))V-L:7-T7U]F:7)S="<@/3X@)T9I<G-T)RP*"2=C;&ES=%]?;&%S
M="<@/3X@)TQA<W0G+`H))V-L:7-T7U]P<F5V)R`]/B`G)FQT.R9L=#LG+`H)
M)V-L:7-T7U]N97AT)R`]/B`G)F=T.R9G=#LG+`H))V-L:7-T7U]P86=E)R`]
M/B`G4&%G97,G+`H))V-L:7-T7U]P86=E7W-I>F4G(#T^("=.=6UB97(@;V8@
M96YT<FEE<R!P97(@<&%G92<L"@DG8VQI<W1?7VEN9F\G(#T^("<E-"`E,2!T
M;W1A;"<L"@DG8VQI<W1?7VEN9F]?96UP='DG(#T^("=.;R`E,2<L"@DG8VQI
M<W1?7VEN9F]?9FEL=&5R)R`]/B`G)34@)3$@9F]U;F0G+`H))V-L:7-T7U]I
M;F9O7W!A9VEN9R<@/3X@)R4R+24S("4Q(&]F("4T('1O=&%L)RP*"2=C;&ES
M=%]?:6YF;U]P86=I;F=?9FEL=&5R)R`]/B`G)3(M)3,@)3$@;V8@)34@9F]U
M;F0G+`H))V-L:7-T7U]S96%R8VA?<VAO=R<@/3X@)U-H;W<@4V5A<F-H)RP*
M"2=C;&ES=%]?<V5A<F-H7VAI9&4G(#T^("=(:61E(%-E87)C:"<L"@H))V-M
M9%]D;G-?7V%?9&YS7W)E8V]R9%]A;')E861Y7V5X:7-T)R`]/B`B4W5C:"!!
M(')E8V]R9"!A;')E861Y(&5X:7-T<RXB+`H))V-M9%]D;G-?7V-A;F]N:6-A
M;%]D;VU?;F%M95]I<U]I;G9A;&ED)R`]/B`B0V%N;VYI8V%L(&1O;6%I;B!N
M86UE(&ES(&EN=F%L:60N(BP*"2=C;61?9&YS7U]C;F%M95]D;G-?<F5C;W)D
M7V%L<F5A9'E?97AI<W0G(#T^(")3=6-H($-.04U%(')E8V]R9"!A;')E861Y
M(&5X:7-T<RXB+`H))V-M9%]D;G-?7V-N86UE7VEN7W)R7V-O;6)I;F%T:6]N
M)R`]/B`G5&AE<F4@:7,@:6YC;W)R96-T(&-O;6)I;F%T:6]N(&]F(')E<V]U
M<F-E(')E8V]R9',@:6X@=&AE('IO;F4G+`H))V-M9%]D;G-?7V-N86UE7V-O
M97AI<W1?=VET:%]D871A)R`]/B`G02!#3D%-12!R96-O<F0@8V%N;F]T(&-O
M97AI<W0@=VET:"!O=&AE<B!R97-O=7)C92!R96-O<F1S(&EN('1H92!S86UE
M('IO;F4N)RP*"2=C;61?9&YS7U]D;G-?<F5C;W)D7W1Y<&5?:7-?:6YV86QI
M9"<@/3X@(E)E<V]U<F-E(')E8V]R9"!T>7!E(&ES(&EN=F%L:60N(BP*"2=C
M;61?9&YS7U]E>'1?:&]S=%]I<U]N;W1?<F5S;VQV960G(#T^(")5;F%B;&4@
M=&\@<F5S;VQV92!T:&4@8V%N;VYI8V%L(&YA;64@)3$N(BP*"2=C;61?9&YS
M7U]D;VUA:6Y?<F5S=&]R95]D;G-?>F]N95]F86EL961?861D7W)E8V]R9"<@
M/3X@)U5N86)L92!T;R!R97-T;W)E('1H92!$3E,@>F]N93H@86X@97)R;W(@
M;V-C=7)E9"!W:&EL92!A9&1I;F<@=&AE("4Q(')E8V]R9"<L"@DG8VUD7V1N
M<U]?;6%I;%]D;VU?;F%M95]I<U]I;G9A;&ED)R`]/B`B36%I;"!E>&-H86YG
M97(@;F%M92!I<R!I;G9A;&ED+B(L"@DG8VUD7V1N<U]?;7A?<')I;W)I='E?
M:7-?:6YV86QI9"<@/3X@(DU8('!R:6]R:71Y(&ES(&EN=F%L:60N(BP*"2=C
M;61?9&YS7U]N86UE7W-E<G9E<E]I<U]I;G9A;&ED)R`]/B`B3F%M92!S97)V
M97(@:7,@:6YV86QI9"XB+`H))V-M9%]D;G-?7VYE='=O<FM?;6%S:U]S:&]U
M;&1?8F5?,C1?,39?;W)?."<@/3X@(DYE='=O<FL@;6%S:R!V86QU92!S:&]U
M;&0@8F4@,C0L(#$V(&]R(#@N(BP*"2=C;61?9&YS7U]T:&ES7V1N<U]R96-O
M<F1?86QR96%D>5]E>&ES=',G(#T^(")3=6-H(')E<V]U<F-E(')E8V]R9"!A
M;')E861Y(&5X:7-T<RXB+`H))V-M9%]D;G-?7W5N86)L95]A9&1?<F5C;W)D
M)R`]/B`B56YA8FQE('1O(&%D9"`G)3$G(')E8V]R9#H@)3(B+`H))V-M9%]D
M;G-?7W5N86)L95]A9&1?85]R96-O<F0G(#T^(")5;F%B;&4@=&\@861D($$@
M<F5C;W)D.B`E,2(L"@DG8VUD7V1N<U]?=6YA8FQE7V%D9%]C;F%M95]R96-O
M<F0G(#T^(")5;F%B;&4@=&\@861D($-.04U%(')E8V]R9#H@)3$B+`H))V-M
M9%]D;G-?7W5N86)L95]A9&1?9&YS7W)E8V]R9"<@/3X@(E5N86)L92!T;R!A
M9&0@<F5S;W5R8V4@<F5C;W)D.B`E,2(L"@DG8VUD7V1N<U]?=6YA8FQE7V%D
M9%]E>'1?;G-?<F5C;W)D)R`]/B`B56YA8FQE('1O(&%D9"!%6%1?3E,@<F5C
M;W)D.B`E,2(L"@DG8VUD7V1N<U]?=6YA8FQE7V%D9%]N<U]R96-O<F0G(#T^
M(")5;F%B;&4@=&\@861D($Y3(')E8V]R9#H@)3$B+`H))V-M9%]D;G-?7W5N
M86)L95]A9&1?<'1R7W)E8V]R9"<@/3X@(E5N86)L92!T;R!A9&0@4%12(')E
M8V]R9#H@)3$B+`H))V-M9%]D;G-?7W5N86)L95]A9&1?='AT7W)E8V]R9"<@
M/3X@(E5N86)L92!T;R!A9&0@5%A4(')E8V]R9#H@)3$B+`H))V-M9%]D;G-?
M7W5N86)L95]C<F5A=&5?9&YS7WIO;F4G(#T^(")5;F%B;&4@=&\@8W)E871E
M('1H92!$3E,@>F]N92`E,2(L"@DG8VUD7V1N<U]?=6YA8FQE7V1E9FEN95]D
M;G-?<F5C;W)D)R`]/B`B56YA8FQE('1O(&1E9FEN92!T:&4@<F5S;W5R8V4@
M<F5C;W)D("4Q(BP*"2=C;61?9&YS7U]U;F%B;&5?9V5T7V1E9F%U;'1?9&YS
M7WIO;F5?<W1A='5S7W-E=%]T<G5E)R`]/B`B56YA8FQE('1O(')E=')I979E
M('1H92!D969A=6QT($1.4R!Z;VYE('-T871U<SH@)3$B+`H))V-M9%]D;G-?
M7W5N86)L95]I;G-E<G1?85]R96-O<F0G(#T^(")5;F%B;&4@=&\@:6YS97)T
M($$@<F5C;W)D.B`E,2(L"@DG8VUD7V1N<U]?=6YA8FQE7VEN<V5R=%]M>%]R
M96-O<F0G(#T^(")5;F%B;&4@=&\@:6YS97)T($U8(')E8V]R9#H@)3$B+`H)
M)V-M9%]D;G-?7W5N86)L95]I;G-E<G1?;G-?<F5C;W)D)R`]/B`B56YA8FQE
M('1O(&EN<V5R="!.4R!R96-O<F0Z("4Q(BP*"2=C;61?9&YS7U]U;F%B;&5?
M<V5T7V1N<U]Z;VYE7W-T871U<R<@/3X@(E5N86)L92!T;R!S970@=&AE($1.
M4R!Z;VYE('-T871U<SH@)3$B+`H))V-M9%]D;VUA:6YS7U]D;VU?86QR96%D
M>5]E>&ES=',G(#T^(")$;VUA:6X@)3$@86QR96%D>2!E>&ES=',N(BP*"2=C
M;61?9&]M86EN<U]?9&YS7W)E8V]R9%]A;')E861Y7V5X:7-T<R<@/3X@(E-U
M8V@@1$Y3(')E8V]R9"!F;W(@9&]M86EN("4Q(&%L<F5A9'D@97AI<W1S+B(L
M"@DG8VUD7V1O;6%I;G-?7V1O;5]A;')E861Y7V5X:7-T<S$G(#T^(")4:&5R
M92!A<F4@)3(@<W5B9&]M86EN<R!I;B!T:&ES(&1O;6%I;BX@1&]M86EN("4Q
M(&%L<F5A9'D@97AI<W1S+B(L"@DG8VUD7V1O;6%I;G-?7V1O;5]A;')E861Y
M7V5X:7-T<S(G(#T^(")T:&4@<W5B9&]M86EN("4Q(&%L<F5A9'D@97AI<W1S
M+B(L"@DG8VUD7V1O;6%I;G-?7W-U8F1O;5]A;')E861Y7V5X:7-T<R<@/3X@
M(E1H92!S=6)D;VUA:6X@=VET:"!S=6-H(&YA;64@86QR96%D>2!E>&ES=',N
M(BP*"2=C;61?9&]M86EN<U]?9&%L:6%S7V%L<F5A9'E?97AI<W1S)R`]/B`B
M5&AI<R!A;&EA<R!A;')E861Y(&5X:7-T<RXB+`H))V-M9%]D;VUA:6YS7U]U
M;F%B;&5?9&5L7VUA:6Q?9F]R7V1O;2<@/3X@(E5N86)L92!T;R!D96QE=&4@
M=&AE(&UA:6P@<V5R=FEC97,@9F]R(&1O;6%I;CH@)3$B+`H))V-M9%]D;VUA
M:6YS7U]U;F%B;&5?9&5L971E7V%N;VYY;6]U<U]F='`G(#T^(")5;F%B;&4@
M=&\@9&5L971E(&%N;VYY;6]U<R!&5%`@86-C;W5N="!F;W(@9&]M86EN.B`E
M,2(L"@DG8VUD7V1O;6%I;G-?7W5N86)L95]U<&1A=&5?9&]M7W!A<F%M)R`]
M/B`B56YA8FQE('1O('5P9&%T92!T:&4@9&]M86EN('!A<F%M971E<G,Z("4Q
M+B(L"@DG8VUD7V1O;6%I;G-?7W5N86)L95]R96YA;65?8VQI96YT7V5X:7-T
M)R`]/B`B9&]M86EN(&%D;6EN:7-T<F%T;W(G<R!L;V=I;B!N86UE(&ES(&%L
M<F5A9'D@:6X@=7-E+B(L"@DG8VUD7VAO<W1I;F=?7VAS=%]T>7!E7VES7VYO
M=%]P:'ES:6-A;%]H<W0G(#T^(")(;W-T:6YG('1Y<&4@:7,@;F]T('!H>7-I
M8V%L+B(L"@DG8VUD7VAO<W1I;F=?7W5N86)L95]C<F5A=&5?=7-E<B<@/3X@
M(E5N86)L92!T;R!C<F5A=&4@=7-E<B`E,CH@)3$B+`H))V-M9%]H;W-T:6YG
M7U]U;F%B;&5?9&5F:6YE7VEP7V%D9')?9F]R7VYA;65?8F%S961?=FER='5A
M;%]H;W-T<R<@/3X@(E5N86)L92!T;R!D969I;F4@25`@861D<F5S<R!F;W(@
M=&AE(&YA;64M8F%S960@=FER='5A;"!H;W-T<SH@)3$B+`H))V-M9%]H;W-T
M:6YG7U]U;F%B;&5?9&5L7V]L9%]H<W0G(#T^(")5;F%B;&4@=&\@9&5L971E
M('1H92!P<F5V:6]U<VQY('-E="!U<"!H;W-T:6YG.B`E,2(L"@DG8VUD7VAO
M<W1I;F=?7W5N86)L95]D96Q?<')O=&5C=&5D7V1I<F5C=&]R>2<@/3X@(E5N
M86)L92!T;R!D96QE=&4@<')O=&5C=&5D(&1I<F5C=&]R>3H@)3$B+`H))V-M
M9%]H;W-T:6YG7U]U;F%B;&5?9&5L7W=E8E]U<V5R)R`]/B`B56YA8FQE('1O
M(&1E;&5T92!W96(@=7-E<CH@)3$B+`H))V-M9%]H;W-T:6YG7U]U;F%B;&5?
M;6%K92]U<&1A=&5?=FER='5A;%]H;W-T)R`]/B`B56YA8FQE('1O(&-R96%T
M92!O<B!U<&1A=&4@=&AE(%9I<G1U86P@2&]S=#H@)3$B+`H))V-M9%]H;W-T
M:6YG7U]U;F%B;&5?;6%K95]F<F%M95]F;W)W87)D7VAS="<@/3X@(E5N86)L
M92!T;R!S970@=7`@=&AE(&9R86UE(&9O<G=A<F1I;F<@:&]S=&EN9RXB+`H)
M)V-M9%]H;W-T:6YG7U]U;F%B;&5?<F5B=6EL9%]F='!?8V]N9FEG)R`]/B`B
M56YA8FQE('1O(')E8G5I;&0@=&AE('!R;V9T<&0@8V]N9FEG=7)A=&EO;B!F
M:6QE.B`E,2(L"@DG8VUD7VAO<W1I;F=?7W5N86)L95]S971?=7!?<W-L)R`]
M/B`B56YA8FQE('1O('-E="!U<"!34TP@)3$B+`H))V-M9%]H;W-T:6YG7U]U
M;F%B;&5?=6YP<F]T96-T7W-S;%]D:7)E8W1O<GDG(#T^(")5;F%B;&4@=&\@
M<F5M;W9E('!R;W1E8W1I;VX@9G)O;2!T:&4@4U-,(&1I<F5C=&]R>3H@)3$B
M+`H))V-M9%]H;W-T:6YG7U]U;F%B;&5?=7!D871E7V1E<W1?=7)L)R`]/B`B
M56YA8FQE('1O('5P9&%T92!T:&4@9&5S=&EN871I;VX@55),("4Q(BP*"2=C
M;61?:&]S=&EN9U]?=6YA8FQE7W5P9&%T95]D;G-?>F]N95]F;W)?9&]M7W5N
M86)L95]E>&5C7W5T:6PG(#T^(")5;F%B;&4@=&\@=7!D871E('1H92!$3E,@
M>F]N92!F;W(@=&AE(&1O;6%I;CH@=71I;&ET>2!E>&5C=71I;VX@9F%I;&5D
M+B(L"@DG8VUD7VAO<W1I;F=?7W5N86)L95]U<&1A=&5?9G1P7W!A<W-W9"<@
M/3X@(E5N86)L92!T;R!U<&1A=&4@1E10('!A<W-W;W)D("4Q(BP*"2=C;61?
M:&]S=&EN9U]?=6YA8FQE7W5P9&%T95]U<V5R)R`]/B`B56YA8FQE('1O('5P
M9&%T92!U<V5R("4R.B`E,2(L"@DG8VUD7VAO<W1I;F=?7W5N:VYO=VY?:'-T
M7W1Y<&4G(#T^(")5;FMN;W=N(&AO<W1I;F<@='EP92XB+`H))V-M9%]H;W-T
M:6YG7U]Y;W5?;F]T7VAA=F5?<&5R;6ES<VEO;E]D96Q?:'-T)R`]/B`B66]U
M(&1O(&YO="!H879E('1H92!P97)M:7-S:6]N('1O('1E<FUI;F%T92!H;W-T
M:6YG('-E<G9I8V4N(BP*"2=C;61?;6%I;%]?861D<E]A;')E861Y7W5S961?
M:6Y?;6%I;%]R961I<F5C="<@/3X@(D%D9')E<W,@)3$@:7,@86QR96%D>2!B
M96EN9R!U<V5D(&EN(&$@;6%I;"!R961I<F5C="XB+`H))V-M9%]M86EL7U]A
M;&EA<U]A;')E861Y7V5X:7-T<R<@/3X@(F%L:6%S(&%L<F5A9'D@97AI<W1S
M+B(L"@DG8VUD7VUA:6Q?7V%U=&]R97-P7VED7V%N9%]M86EL;F%M95]I9%]N
M;W1?;6%T8V@G(#T^(")!=71O<F5S<&]N9&5R(&ED(&%N9"!M86EL(&YA;64@
M:60@9&\@;F]T(&UA=&-H(2(L"@DG8VUD7VUA:6Q?7V%U=&]R97-P7VED7VES
M7W5N9&5F:6YE9"<@/3X@(D%U=&]R97-P;VYD97(@:60@:7,@=6YD969I;F5D
M+B(L"@DG8VUD7VUA:6Q?7VUA:6Q?86QI87-?86QR96%D>5]E>&ES='-?:6Y?
M;6%I;%]N86UE)R`]/B`B5&AE(&UA:6P@86QI87,@=VET:"!S=6-H(&YA;64@
M86QR96%D>2!E>&ES=',@9F]R('1H92!M86EL(&YA;64@)3$B+`H))V-M9%]M
M86EL7U]M86EL7VYA;65?86QR96%D>5]E>&ES='-?:6Y?;6%I;&QI<W1S)R`]
M/B`B36%I;"!N86UE("4Q(&ES(&%L<F5A9'D@:6X@82!M86EL:6YG(&QI<W0B
M+`H))V-M9%]M86EL7U]M86EL7VYA;65?86QR961Y7V5X:7-T7VEN7V1O;2<@
M/3X@(E1H92!M86EL(&YA;64@)3$@:7,@86QR96%D>2!I;B!T:&4@9&]M86EN
M(BP*"2=C;61?;6%I;%]?;6%I;%]N86UE7VYO=%]E>&ES="<@/3X@(E1H92!M
M86EL(&YA;64@9&]E<R!N;W0@97AI<W0N(BP*"2=C;61?;6%I;%]?;6%I;%]N
M86UE7W!A<W-W9%]P87)T)R`]/B`B5&AE('!A<W-W;W)D('-H;W5L9"!N;W0@
M8V]N=&%I;B!M86EL(&YA;64@87,@:71S('!A<G0N(BP*"2=C;61?;6%I;%]?
M;6%I;%]P87-S=V1?:6YC;W)R96-T)R`]/B`B7&Y4:&4@<&%S<W=O<F0@:7,@
M:6YC;W)R96-T+"!U<V4@870@;&5A<W0@-2!C:&%R86-T97)S+B!4:&4@<&%S
M<W=O<F0@<VAO=6QD(&YO="!C;VYT86EN(&UA:6P@;F%M92!A<R!I=',@<&%R
M="Y<;D]N;'D@3&%T:6X@8VAA<F%C=&5R<RP@;F\@9&EC=&EO;F%R>2!W;W)D
M<R`H;W!T:6]N86PI+B(L"@DG8VUD7VUA:6Q?7VUA:6Q?<F5D:7)E8W1?861D
M<E]I<U]I;G9A;&ED)R`]/B`B36%I;"!R961I<F5C="!A9&1R97-S(&ES(&EN
M=F%L:60N(BP*"2=C;61?;6%I;%]?;6%I;&QI<W1?86QR96%D>5]E>&ES=%]I
M;E]T:&ES7V1O;2<@/3X@(DUA:6QI;F<@;&ES="`E,2!A;')E861Y(&5X:7-T
M<R!O;B!T:&ES(&1O;6%I;BXB+`H))V-M9%]M86EL7U]M86EL;&ES=%]A;')E
M861Y7V5X:7-T<R<@/3X@(FUA:6QI;F<@;&ES="!A;')E861Y(&5X:7-T<RXB
M+`H))V-M9%]M86EL7U]M86EL;F%M95]A;')E861Y7V5X:7-T7VEN7VUG)R`]
M/B`B36%I;"!N86UE("4Q(&ES(&%L<F5A9'D@:6X@82!M86EL(&=R;W5P+B(L
M"@DG8VUD7VUA:6Q?7VUA:6QN86UE7V%L<F5A9'E?97AI<W1?:6Y?<F5D:7(G
M(#T^(")-86EL(&YA;64@)3$@:7,@86QR96%D>2!I;B!A(')E9&ER96-T+B(L
M"@DG8VUD7VUA:6Q?7VUA:6QN86UE7V%L<F5A9'E?97AI<W1?:6Y?=&AI<U]D
M;VTG(#T^(")-86EL(&YA;64@)3$@86QR96%D>2!E>&ES=',@:6X@=&AI<R!D
M;VUA:6XN(BP*"2=C;61?;6%I;%]?;6%I;&YA;65?86QR96%D>5]E>&ES=',G
M(#T^(")M86EL(&YA;64@86QR96%D>2!E>&ES=',N(BP*"2=C;61?;6%I;%]?
M;6%I;&YA;65?:7-?:6YV86QI9"<@/3X@(DUA:6P@;F%M92`E,2!I<R!I;G9A
M;&ED+B(L"@DG8VUD7VUA:6Q?7VUA:6QN86UE7W5N86)L95]U<&1A=&4G(#T^
M(")5;F%B;&4@=&\@=7!D871E('1H92!M86EL(&YA;64@<')O<&5R=&EE<SHB
M+`H))V-M9%]M86EL7U]M87A?875T;W)E<W!?<F5A8VAE9%]F;W)?=&AI<U]D
M;VTG(#T^(")-87AI;75M(&YU;6)E<B!O9B!A=71O<F5S<&]N9&5R<R!I<R!R
M96%C:&5D(&9O<B!T:&ES(&1O;6%I;BXB+`H))V-M9%]M86EL7U]M87A?;6%I
M;%]G<F]U<'-?;G5M7VAA<U]B965N7W)E86-H961?9F]R7W1H:7-?9&]M)R`]
M/B`B;6%X:6UU;2!N=6UB97(@;V8@;6%I;"!G<F]U<',@:&%S(&)E96X@<F5A
M8VAE9"!F;W(@=&AI<R!D;VUA:6XN(BP*"2=C;61?;6%I;%]?;6%X7VYU;5]O
M9E]R961I<F5C='-?:&%S7V)E96Y?<F5A8VAE9%]F;W)?=&AI<U]D;VTG(#T^
M(")M87AI;75M(&YU;6)E<B!O9B!R961I<F5C=',@:&%S(&)E96X@<F5A8VAE
M9"!F;W(@=&AI<R!D;VUA:6XN(BP*"2=C;61?;6%I;%]?;6%X7W!O<W1B;WAE
M<U]N=6U?:&%S7V)E96Y?<F5A8VAE9"<@/3X@(FUA>&EM=6T@;G5M8F5R(&]F
M(&UA:6QB;WAE<R!H87,@8F5E;B!R96%C:&5D+B(L"@DG8VUD7VUA:6Q?7VYO
M7VUE;6)E<G-?<W!E8VEF:65D)R`]/B`B;F\@;65M8F5R<R!S<&5C:69I960N
M(BP*"2=C;61?;6%I;%]?=&AE7W!A<W-W9%]I<U]T;V]?<VEM<&QE7V-H;V]S
M95]A;F]T:&5R)R`]/B`B5&AE('!A<W-W;W)D(&ES('1O;R!S:6UP;&4L('!L
M96%S92!C:&]O<V4@86YO=&AE<BXB+`H))V-M9%]M86EL7U]T:&ES7V%D9')?
M86QR96%D>5]E>&ES=%]I;E]M9U]O<E]M;B<@/3X@(E1H:7,@861D<F5S<R!I
M<R!A;')E861Y(&EN(&$@;6%I;"!G<F]U<"!O<B!M86EL(&YA;64N(BP*"2=C
M;61?;6%I;%]?=6YA8FQE7V1E9FEN95]A=71O<F5S<%]I9"<@/3X@(E5N86)L
M92!T;R!D969I;F4@875T;W)E<W!O;F1E<B!I9"`E,2(L"@DG8VUD7VUA:6Q?
M7W5N86)L95]D96Q?;6%I;%]F;W)?9&]M)R`]/B`B56YA8FQE('1O(')E;6]V
M92!T:&4@;6%I;"!S97)V:6-E(&9R;VT@9&]M86EN("4Q(BP*"2=C;61?;6%I
M;%]?=6YA8FQE7V1E;%]M86EL7W)E9&ER96-T:6]N)R`]/B`B56YA8FQE('1O
M(')E;6]V92!M86EL(')E9&ER96-T:6]N("4Q(BP*"2=C;61?;6%I;%]?=6YA
M8FQE7W)E;6]V95]A=71O<F5S<"<@/3X@(E5N86)L92!T;R!R96UO=F4@875T
M;W)E<W!O;F1E<G,Z("4Q(BP*"2=C;61?;6%I;%]?=6YA8FQE7W)E;6]V95]M
M86EL7V=R;W5P7VUE;6)E<G,G(#T^(")5;F%B;&4@=&\@<F5M;W9E('1H92!M
M86EL(&=R;W5P(&UE;6)E<G,Z("4Q(BP*"2=C;61?;6%I;%]?=6YA8FQE7W)E
M;6]V95]R961I<F5C="<@/3X@(E5N86)L92!T;R!R96UO=F4@<F5D:7)E8W0Z
M("4Q(BP*"2=C;61?;6%I;%]?=6YA8FQE7W1U<FY?;V9F7VUA:6Q?9W)O=7`G
M(#T^(")&86EL960@=&\@9&ES86)L92!T:&4@;6%I;"!G<F]U<#H@)3$B+`H)
M)V-M9%]M86EL7U]U;F%B;&5?=7!D871E7VUA:6Q?<F5D:7)E8W0G(#T^(")5
M;F%B;&4@=&\@=7!D871E('1H92!M86EL(')E9&ER96-T("4Q(BP*"2=C;61?
M;6%I;%]?=6YA8FQE7W5P9&%T95]M8F]X7W%U;W1A)R`]/B`B56YA8FQE('1O
M('5P9&%T92!T:&4@;6%I;&)O>"!Q=6]T82XB+`H))V-M9%]M86EL7U]U<&QO
M861E9%]F:6QE7VES7W1O;U]B:6<G(#T^(")5<&QO861E9"!F:6QE('-I>F4@
M:7,@=&]O(&QA<F=E+B(L"@DG8VUD7VUA:6Q?7V%D9&ET:6]N86QL>2<@/3X@
M(D%D9&ET:6]N86QL>3H@(BP*"2=C;61?<&1?7VEN=F%L:61?;&]G:6XG(#T^
M("));F-O<G)E8W0@;&]G:6XN(BP*"2=C;61?<&1?7W1H:7-?=7-E<E]A;')E
M861Y7V5X:7-T)R`]/B`B4W5C:"!U<V5R(&%L<F5A9'D@97AI<W1S+B(L"@DG
M8VUD7W!D7U]U;F%B;&5?9&5F:6YE7VAS=%]T>7!E)R`]/B`B56YA8FQE('1O
M(&1E9FEN92!H;W-T:6YG('1Y<&4N(BP*"2=C;61?<&1?7W5N86)L95]U<&1?
M<&1?=7-R)R`]/B`B56YA8FQE('1O('5P9&%T92!P<F]T96-T960@9&ER96-T
M;W)Y('5S97(@<')O<&5R=&EE<SH@)3$B+`H))V-M9%]P9%]?=7-E<E]I<U]U
M;F1E9FEN960G(#T^(")5<V5R(&ES('5N9&5F:6YE9"XB+`H))V-M9%]S97)V
M97)?7VYO7V5N;W5G:%]F<F5E7V1I<VM?<W!A8V4G(#T^(").;W0@96YO=6=H
M(&1I<VL@<W!A8V4N(BP*"2=C;61?<V5R=F5R7U]O;&1?<&%S<W=D7VES7VEN
M8V]R<F5C=%]P;&5A<V5?=')Y7V%G86EN)R`]/B`B;VQD('!A<W-W;W)D(&ES
M(&EN8V]R<F5C="X@4&QE87-E+"!T<GD@86=A:6XN(BP*"2=C;61?=V5B7W5S
M<E]?;6%X7W=E8E]U<V5R<U]R96%C:&5D7V9O<E]T:&ES7V1O;2<@/3X@(FUA
M>&EM=6T@=V5B('5S97)S(&QI;6ET(&ES(')E86-H960@9F]R('1H:7,@9&]M
M86EN+B(L"@DG8VUD7W=E8E]U<W)?7W5N86)L95]C<F5A=&5?=7-E<B<@/3X@
M(G5N86)L92!T;R!C<F5A=&4@<WES=&5M('5S97(Z("4Q(BP*"2=C;61?=V5B
M7W5S<E]?=6YA8FQE7V1E9FEN95]M87A?=V5B7W5S97)S7VQI;6ET)R`]/B`B
M=6YA8FQE('1O(&1E9FEN92!M87AI;75M('=E8B!U<V5R<R!L:6UI=#H@)3$B
M+`H))V-M9%]W96)?=7-R7U]U<V5R7V%L<F5A9'E?97AI<W1S)R`]/B`B=7-E
M<B!A;')E861Y(&5X:7-T<RXB+`H))V-M9%]W96)?=7-R7U]W96)?=7-E<E]N
M86UE7VES7VEN=F%L:60G(#T^(")W96(@=7-E<B!N86UE("4Q(&ES(&EN=F%L
M:60N(BP*"2=C;61?=V5B7W5S<E]?=V5B7W5S97)?;F]T7V5X:7-T)R`]/B`B
M=V5B('5S97(@9&]E<R!N;W0@97AI<W0N(BP*"2=C;VUM;VY?9G5N8U]?97AE
M8U]B861?87)G=6UE;G0G(#T^(")E>&5C(&%R9W5M96YT('-H;W5L9"!N;W0@
M8V]N=&%I;B!S:6YG;&4@<75O=&4@<WEM8F]L+B(L"@DG8V]M;6]N7V%C;%]?
M861D7V%D9')E<W,G(#T^("=!9&0@=&\@0V]M;6]N($%L;&]W(%IO;F4@5')A
M;G-F97(@04-,)RP*"2=C;VUM;VY?86-L7V%D9%]R96-O<F0G(#T^("=!9&0@
M82!!0TP@<F5C;W)D)RP*"2=E;G1E<E]I<%]O<E]N971W;W)K7V%D9')E<W,G
M(#T^("=%;G1E<B!)4"!O<B!N971W;W)K(&%D9')E<W,G+`H))U]?96]L)R`]
M/B`G3&EN92!B<F5A:W,G+`H))V5O;%]?;F]N92<@/3X@)V1O(&YO="!M;V1I
M9GDG+`H))V5O;%]?;&8G(#T^("=I;B!5;FEX('-T>6QE)RP*"2=E;VQ?7V-R
M)R`]/B`G:6X@36%C3U,@<W1Y;&4G+`H))V5O;%]?8W)L9B<@/3X@)VEN(%=I
M;F1O=W,@<W1Y;&4G+`H))V5O;%]?8FEN87)Y7V9I;&4G(#T^("=5;F%B;&4@
M=&\@8VAA;F=E(&QI;F4@8G)E86L@<W1Y;&4@:6X@8FEN87)Y(&9I;&4N)RP*
M"2=C;VUP7VEN9F]?7VAE861E<B<@/3X@)T-O;7!O;F5N=',G+`H))V-O;7!?
M:6YF;U]?8V]M<%]N86UE)R`]/B`B0V]M<&]N96YT(&YA;64B+`H))V-O;7!?
M:6YF;U]?8V]M<%]V97)S:6]N)R`]/B`B0V]M<&]N96YT('9E<G-I;VXB+`H)
M)V-O;7!?:6YF;U]?=&ET;&4G(#T^("));F9O<FUA=&EO;B!O;B`E,2!C;VUP
M;VYE;G1S(BP*"2=C;VYF:6=U<F5?7V9U;&Q?:&]S=&YA;65?:&EN="<@/3X@
M)U-P96-I9GD@=&AE(&9U;&QY('%U86QI9FEE9"!D;VUA:6X@;F%M92!F;W(@
M=&AI<R!S97)V97(N($5X86UP;&4Z(&AO<W1N86UE+F1O;6%I;BYC;VTG+`H)
M)V-O;F9I9W5R95]?9&5F875L=%]I<%]A9&1R97-S7VAI;G0G(#T^("=3<&5C
M:69Y('1H92!)4"!A9&1R97-S('1H870@=VEL;"!B92!U<V5D(&%S('1H92!M
M86EN('-E<G9E<B!)4"!A9&1R97-S+B!396QE8W0@86X@97AI<W1I;F<@25`@
M861D<F5S<R!O<B!C;&EC:R!!9&0@25`@061D<F5S<R!T;R!A9&0@82!N97<@
M25`@861D<F5S<R!T;R!T:&4@<WES=&5M+B!)9B!Y;W4@=V%N="!T:&4@;F5W
M($E0(&%D9')E<W,@=&\@8F4@<VAA<F5D(&)E='=E96X@<V5V97)A;"!C;&EE
M;G0@86-C;W5N=',L('-E;&5C="!T:&4@4VAA<F5D(&-H96-K(&)O>"XG+`H)
M)V-O;F9I9W5R95]?9&5F875L=%]I<%]A9&1R97-S7VAI;G1?<V5L96-T7V]N
M;'DG(#T^("=3<&5C:69Y('1H92!)4"!A9&1R97-S('1H870@=VEL;"!B92!U
M<V5D(&%S('1H92!M86EN($E0(&%D9')E<W,@9F]R('1H:7,@<V5R=F5R+B<L
M"@DG8V]N9FEG=7)E7U]S:&%R961?:7!?861D<F5S<U]H:6YT)R`]/B`G66]U
M(&-A;B!C:&%N9V4@=&AE('1Y<&4@;V8@97AI<W1I;F<@25`@861D<F5S<V5S
M(&9R;VT@97AC;'5S:79E('1O('-H87)E9"X@4VAA<F5D($E0(&%D9')E<W-E
M<R!C86X@8F4@87-S:6=N960@=&\@;75L=&EP;&4@8VQI96YT(&%C8V]U;G1S
M+B!4;R!C:&%N9V4@=&AE($E0(&%D9')E<W,@='EP92!F<F]M(&5X8VQU<VEV
M92!T;R!S:&%R960L('-E;&5C="!)4"!A9&1R97-S97,@:6X@=&AE(&QI<W0@
M;V8@97AC;'5S:79E($E0(&%D9')E<W-E<RP@86YD(&-L:6-K(%-H87)E9"XG
M+`H))U]?9&5F875L=%]I<%]A9&1R97-S)R`]/B`G1&5F875L="!)4"!!9&1R
M97-S)RP*"2=C;VYF:6=U<F5?7V1E9F%U;'1?:7!?<V5L96-T)R`]/B`G4V5L
M96-T(&%N(&%D9')E<W,G+`H))V-O;F9I9W5R95]?9&5F875L=%]I<%]N97<G
M(#T^("=!9&0@25`@061D<F5S<R<L"@DG8V]N9FEG=7)E7U]I<%]I;G1E<F9A
M8V4G(#T^("=);G1E<F9A8V4G+`H))V-O;F9I9W5R95]?:7!?861D<F5S<R<@
M/3X@)TE0($%D9')E<W,G+`H))V-O;F9I9W5R95]?:7!?<VAA<F5D)R`]/B`G
M4VAA<F5D)RP*"2=C;VYF:6=U<F5?7W-E;&5C=%]E>&QU<VEV95]I<',G(#T^
M("=%>&-L=7-I=F4@25`@861D<F5S<V5S)RP*"2=C;VYF:6=U<F5?7W-E;&5C
M=%]S:&%R961?:7!S)R`]/B`G4VAA<F5D($E0(&%D9')E<W-E<R<L"@DG8V]N
M9FEG=7)E7U]A9&UI;E]P87-S=V]R9%]C:&%N9V4G(#T^(")0;&5A<V4@8VAA
M;F=E('1H92!D969A=6QT(&%D;6EN:7-T<F%T;W(@<&%S<W=O<F0N(BP*"2=C
M;VYF:6=U<F5?7V5R<F]R7VYA;65D7W)E<W1A<G0G(#T^(").86UE9"!R97-T
M87)T(&5R<F]R+B!&;W(@<')O<&5R(&YA;65D('=O<FL@>6]U('-H;W5L9"!R
M97-T87)T(&ET+B(L"@DG8V]N9FEG=7)E7U]F:6QL7V9O;&QO=VEN9U]F:65L
M9',G(#T^(")&:6QL('1H92!R97%U97-T960@:6YF;W)M871I;VX@:6YT;R!T
M:&4@87!P<F]P<FEA=&4@9FEE;&1S+B!4:&ES(&EN9F]R;6%T:6]N(&ES(')E
M<75I<F5D(&9O<B`E,2!T;R!W;W)K+B(L"@DG8V]N9FEG=7)E7U]F=6QL7VAO
M<W1N86UE)R`]/B`B1G5L;"!H;W-T;F%M92(L"@DG8V]N9FEG=7)E7U]U;F%B
M;&5?8V]N9FEG=7)E)R`]/B`B56YA8FQE('1O(&-O;F9I9W5R93H@)3$B+`H)
M)V-P7V%C8V5S<U]A9&UI;E]D96YY)R`]/B`B06-C97-S(&9O<B!A9&UI;FES
M=')A=&]R(&9R;VT@861D<F5S<R`G)3$G(&ES(')E<W1R:6-T960@:6X@86-C
M;W)D86YC92!W:71H($E0($%C8V5S<R!R97-T<FEC=&EO;B!P;VQI8WD@8W5R
M<F5N=&QY(&%P<&QI960N(BP*"2=C<%]A8V-E<W-?8W5R<E]I<%]A8V-E<W-?
M9&5N>2<@/3X@(E=A<FYI;F<A(2$@5&AE(&%C8V5S<R!R97-T<FEC=&EO;B!P
M;VQI8WD@86YD('1H92!L:7-T(&]F(&YE='=O<FMS(&%R92!C=7)R96YT;'D@
M8V]N9FEG=7)E9"!T:&4@=V%Y('EO=2!W:6QL(&YO="!B92!A8FQE('1O(&QO
M9VEN('=I=&@@861M:6YI<W1R871O<B=S(')I9VAT<R!F<F]M('EO=7(@25`@
M861D<F5S<R`G)3$G+B(L"@DG8W!?86-C97-S7V5D:71?:&5A9&5R)R`]/B`B
M3F5T=V]R:R!E9&ET:6YG(BP*"2=C<%]A8V-E<W-?97AI<W1S)R`]/B`B5&AE
M(&YE='=O<FL@:7,@86QR96%D>2!I;B!T:&4@25`@86-C97-S(')E<W1R:6-T
M:6]N(&QI<W0N(BP*"2=C<%]A8V-E<W-?:&5A9&5R)R`]/B`B25`@86-C97-S
M(')E<W1R:6-T:6]N(&UA;F%G96UE;G0B+`H))V-P7V%C8V5S<U]P;VQI8WDG
M(#T^(")#;VYT<F]L('!A;F5L(&%C8V5S<R!W:71H(&%D;6EN:7-T<F%T;W(G
M<R!P<FEV:6QE9V5S(BP*"2=C<%]A8V-E<W-?<&]L:6-Y7V%L;&]W)R`]/B`B
M06QL;W=E9"P@97AC;'5D:6YG('1H92!N971W;W)K<R!I;B!T:&4@;&ES="XB
M+`H))V-P7V%C8V5S<U]P;VQI8WE?9&5N>2<@/3X@(D1E;FEE9"!F<F]M('1H
M92!N971W;W)K<R!T:&%T(&%R92!N;W0@;&ES=&5D+B(L"@DG8W!?86-C97-S
M7W)E;6]V95]H96%D97(G(#T^(").971W;W)K(')E;6]V86PB+`H))V-P7V%C
M8V5S<U]S96QE8W1?:7`G(#T^(")396QE8W0@;VYE(&]R('-E=F5R86P@;F5T
M=V]R:W,@9G)O;2!T:&4@25`@86-C97-S(')E<W1R:6-T:6]N(&QI<W0N(BP*
M"2=C<%]A8V-E<W-?<W=I=&-H7V-O;F9I<FUA=&EO;B<@/3X@(D-H86YG92!T
M:&4@86-C97-S('!O;&EC>3\B+`H))V-P7V%C8V5S<U]S=VET8VA?9&5N>5]E
M<G)O<B<@/3X@(E5N86)L92!T;R!C:&%N9V4@=&AE(&%C8V5S<R!P;VQI8WDZ
M(&YO(&YE='=O<FMS('-P96-I9FEE9"(L"@DG8W!?86-C97-S7W-W:71C:%]D
M96YY7VYO=R<@/3X@(E1H92!A8V-E<W,@<&]L:6-Y('=A<R!C:&%N9V5D(&)E
M8V%U<V4@=&AE<F4@87)E(&YO(&YE='=O<FMS('-P96-I9FEE9"XB+`H))V-P
M7V%C8V5S<U]?;F5T=V]R:U]A9&1R97-S)R`]/B`G4W5B;F5T(&]R($E0(&%D
M9')E<W,G+`H))V-P7V%C8V5S<U]?;F5T=V]R:U]M87-K)R`]/B`G4W5B;F5T
M(&UA<VLG+`H))V-R96%T95]D;VUA:6Y?=V%R;E]?)R`]/B`B5&AE(&9O;&QO
M=VEN9R!E>&-E<'1I;VYS('=E<F4@;6%D92!D=7)I;F<@9&]M86EN(&-R96%T
M:6]N.B(L"@DG8W)E871E7V1O;6%I;E]?8VQI96YT7W-E;&5C="<@/3X@)U-E
M;&5C="!T:&4@8VQI96YT('1O(&-R96%T92!T:&4@9&]M86EN(&9O<B<L"@DG
M8W)O;G1A8E]?8W)O;G1A8E]E;G1R>5]E>&ES=',G(#T^(")4:&4@)3$@=&%S
M:R!A;')E861Y(&5X:7-T<R(L"@DG8W)O;G1A8E]?8W)O;G1A8E]E;G1R>5]N
M;W1?97AI<W1S)R`]/B`B5&AE("4Q('1A<VL@9&]E<R!N;W0@97AI<W0B+`H)
M)V-R;VYT86)?7VEN=F%L:61?=F%L=65S7V9O=6YD)R`]/B`B5&AE<F4@87)E
M(&EN8V]R<F5C="!P87)A;65T97(@=F%L=65S(BP*"2=C<F]N=&%B7V5D:71?
M7V-R;VYT86)?;V9?7R<@/3X@(D5D:71I;F<@=&AE("4Q('1A<VL@;V8@)3(B
M+`H))V-R;VYT86)?961I=%]?8VUD7VUA>%]L96XG(#T^(")4:&4@8V]M;6%N
M9"!Y;W4@<W!E8VEF:65D(&5X8V5E9',@=&AE(&%L;&]W960@;&5N9W1H("@E
M,2!S>6UB;VQS*2XB+`H))V-R;VYT86)?;&ES=%]?;6%I;%]T;U]?)R`]/B`B
M4V5N9"`E,2!M97-S86=E<R!T;R!A9&1R97-S("4R(BP*"2=C<F]N=&%B7VQI
M<W1?7VUA:6Q?=&]?:7-?:6YV86QI9"<@/3X@(E1H92!A9&1R97-S(&9O<B`E
M,2!M97-S86=E<R!D96QI=F5R>2!I<R!I;F-O<G)E8W0B+`H))V-R;VYT86)?
M;&ES=%]?<F5M;W9E7V]N7W5S97)?7R<@/3X@(E)E;6]V92!T:&4@<V-H961U
M;&5D('1A<VMS(&]F("4R(BP*"2=C<F]N=&%B7VQI<W1?7W-E;&5C=%]T;U]R
M96UO=F4G(#T^(")396QE8W0@=&AE("4Q('1A<VMS('1O(&)E(')E;6]V960N
M(BP*"2=C<F]N=&%B7VQI<W1?7W-H;W=?8W)O;G1A8E]O9E]?)R`]/B`B4VAO
M=R`E,2!O9B`E,B(L"@DG8W)O;G1A8E]L:7-T7U]S>7-U<V5R7VQI<W1?96UP
M='DG(#T^(")4:&5R92!A<F4@;F\@)3$@=&%S:W,@879A:6QA8FQE(BP*"2=C
M<F]N=&%B7VQI<W1?7W1A<VMS)R`]/B`B)3$@=&%S:W,B+`H*"2=C=7-T;VU?
M8G5T=&]N7U]S;W)T7VME>2<)"3T^("=0<FEO<FET>2<L"@DG8W5S=&]M7V)U
M='1O;E]?<&QA8V4G"0D)/3X@)TQO8V%T:6]N)RP*"2=C=7-T;VU?8G5T=&]N
M7U]P;&%C95]N879I9V%T:6]N)PD]/B`G3F%V:6=A=&EO;B!P86YE;"<L"@DG
M8W5S=&]M7V)U='1O;E]?<&QA8V5?861M:6XG"0D]/B`G061M:6YI<W1R871O
M<EPG<R!$97-K=&]P)RP*"2=C=7-T;VU?8G5T=&]N7U]P;&%C95]C;&EE;G0G
M"0D]/B`G0VQI96YT7"=S($1E<VMT;W`@+R!(;VUE('!A9V4G+`H))V-U<W1O
M;5]B=71T;VY?7W!L86-E7V1O;6%I;B<)"3T^("=$;VUA:6X@3W=N97)<)W,@
M1&5S:W1O<"`O($AO;64@<&%G92<L"@DG8W5S=&]M7V)U='1O;E]?<'5B;&EC
M)PD)"3T^("=6:7-I8FQE('1O(&%L;"!S=6(M;&]G:6YS)RP*"2=C=7-T;VU?
M8G5T=&]N7U]I;6%G92<)"0D]/B`G0F%C:V=R;W5N9"!I;6%G92<L"@DG8W5S
M=&]M7V)U='1O;E]?8V]N:&5L<"<)"3T^(")#;VYT97AT(&AE;'`@=&EP(&-O
M;G1E;G1S(BP*"2=C=7-T;VU?8G5T=&]N7U]E9&ET)PD)"3T^(")#=7-T;VT@
M0G5T=&]N(%!R;W!E<G1I97,B+`H))V-U<W1O;5]B=71T;VY?7VEN8VQU9&5?
M8VQI96YT7V-N86UE)PD]/B`B26YC;'5D92!C;&EE;G0G<R!C;VUP86YY(&YA
M;64B+`H))V-U<W1O;5]B=71T;VY?7VEN8VQU9&5?8VQI96YT7V5M86EL)R`]
M/B`B26YC;'5D92!C;&EE;G0G<R!E+6UA:6PB+`H))V-U<W1O;5]B=71T;VY?
M7VEN8VQU9&5?8VQI96YT7VED)R`]/B`B26YC;'5D92!C;&EE;G0@:60B+`H)
M)V-U<W1O;5]B=71T;VY?7VEN8VQU9&5?8VQI96YT7W!N86UE)R`]/B`B26YC
M;'5D92!C;&EE;G0G<R!C;VYT86-T(&YA;64B+`H))V-U<W1O;5]B=71T;VY?
M7VEN8VQU9&5?9&]M86EN7VED)R`]/B`B26YC;'5D92!D;VUA:6X@:60B+`H)
M)V-U<W1O;5]B=71T;VY?7VEN8VQU9&5?9&]M86EN7VYA;64G(#T^("));F-L
M=61E(&1O;6%I;B!N86UE(BP*"2=C=7-T;VU?8G5T=&]N7U]I;F-L=61E7V9T
M<%]U<V5R)R`]/B`B26YC;'5D92!&5%`@3&]G:6XB+`H))V-U<W1O;5]B=71T
M;VY?7VEN8VQU9&5?9G1P7W!A<W,G(#T^("));F-L=61E($944"!P87-S=V]R
M9"(L"@DG8W5S=&]M7V)U='1O;E]?:6YT97)N86Q?;W!E;B<@/3X@(D]P96X@
M55),(&EN('1H92!#;VYT<F]L(%!A;F5L(BP*"2=C=7-T;VU?8G5T=&]N7U]T
M97AT)R`]/B`B0G5T=&]N(&QA8F5L(BP*"2=C=7-T;VU?8G5T=&]N7U]U<FPG
M(#T^(")54DPB+`H*"2=C=7-T;VU?8G5T=&]N<U]?96UP='E?<V5L96-T:6]N
M)R`]/B`B4V5L96-T('1H92!B=71T;VYS('1O(&)E(')E;6]V960N(BP*"2=C
M=7-T;VU?8G5T=&]N<U]?;F%M92<@/3X@(DQA8F5L(BP*"2=C=7-T;VU?8G5T
M=&]N<U]?<'5B;&EC)R`]/B`G02<L+R]"=71T;VX@86-C97-S:6)I;&ET>2!P
M<F]P97)T>0H))V-U<W1O;5]B=71T;VYS7U]S;W)T7VME>2<@/3X@)U!R:6]R
M:71Y)RP@+R]4:&ES(&ES('1H92!L:7-T('1I=&QE('=H:6-H(&EN9&EC871E
M<R!T:&4@;W)D97(@;V8@=&AE(&-U<G)E;G0@8G5T=&]N"@DG8W5S=&]M7V)U
M='1O;G-?7W!L86-E)R`]/B`G3"<L+R],;V-A=&EO;@H))V-U<W1O;5]B=71T
M;VYS7U]R96UO=F4G(#T^(")4:&4@9F]L;&]W:6YG(&)U='1O;G,@=VEL;"!B
M92!R96UO=F5D.B(L"@DG8G1?9&]M86EN7V%L:6%S97,G(#T^("=$;VUA:6X@
M06QI87-E<R<L"@DG8G1?9&]M86EN7V%L:6%S7V%D9"<@/3X@)T%D9"!$;VUA
M:6X@06QI87,G+`H))W!B7U]D;VUA:6Y?86QI87-E<R<@/3X@)T1O;6%I;B!A
M;&EA<V5S)RP*"2=D87-H8F]A<F1?7VYA=E]B=71T;VY?;F%M92<@/3X@(D1E
M<VMT;W`B+`H))V1A;&EA<U]?;&ES=%]T:71L92<@/3X@)T1O;6%I;B!A;&EA
M<V5S(&]F('1H92!D;VUA:6X@)3$G+`H))V1A;&EA<U]?;&ES=%]L96=E;F0G
M(#T^("=$;VUA:6X@86QI87-E<R<L"@DG9&%L:6%S7U]L:7-T7VAE861E<B<@
M/3X@)T1O;6%I;B!A;&EA<V5S)RP*"2=D86QI87-?7VQI<W1?<W1A='5S)R`]
M/B`G4R<L"@DG9&%L:6%S7U]L:7-T7VYA;64G(#T^("=$;VUA:6X@86QI87,@
M;F%M92<L"@DG9&%L:6%S7U]L:7-T7V%S8VEI7VYA;64G(#T^("=);B!!4T-)
M22!F;W)M870G+`H))V1A;&EA<U]?<F5M;W9E7W1I=&QE)R`]/B`G5&AE(&9O
M;&QO=VEN9R!D;VUA:6X@86QI87-E<R!O9B!T:&4@9&]M86EN("4Q('=I;&P@
M8F4@<F5M;W9E9#HG+`H))V1A;&EA<U]?<V5L96-T7V1O;6%I;E]A;&EA<V5S
M7W1O7W)E;6]V92<@/3X@)U-E;&5C="!T:&4@9&]M86EN(&%L:6%S97,@=&\@
M8F4@<F5M;W9E9"XG+`H))V1A;&EA<U]?8V]N=')O;%]T:71L92<@/3X@)T1O
M;6%I;B!A;&EA<R`E,2<L"@DG9&%L:6%S7U]C;VYT<F]L7VEN9F]?;&5G96YD
M)R`]/B`G26YF;R<L"@DG9&%L:6%S7U]C;VYT<F]L7W-T871U<U]T:71L92<@
M/3X@)U,G+`H))V1A;&EA<U]?8V]N=')O;%]N86UE7W1I=&QE)R`]/B`G4V5R
M=FEC92!N86UE)RP*"2=D86QI87-?7V-O;G1R;VQ?9&5T86EL<U]T:71L92<@
M/3X@)T1E=&%I;',G+`H))V1A;&EA<U]?<V5R=FEC95]M86EL)R`]/B`G36%I
M;"<L"@DG9&%L:6%S7U]S97)V:6-E7W=E8B<@/3X@)U=E8B<L"@DG9&%L:6%S
M7U]D;VUA:6Y?<V5R=FEC95]M86EL7V5N86)L960G(#T^("=-86EL('-E<G9I
M8V4@:7,@96YA8FQE9"!O;B!T:&4@9&]M86EN+B<L"@DG9&%L:6%S7U]D;VUA
M:6Y?<V5R=FEC95]M86EL7V1I<V%B;&5D)R`]/B`G36%I;"!S97)V:6-E(&ES
M(&1I<V%B;&5D(&]N('1H92!D;VUA:6XN)RP*"2=D86QI87-?7V1O;6%I;E]S
M97)V:6-E7VUA:6Q?;7@G(#T^("<E,2!U<V5D(&%S(&UA:6P@97AC:&%N9V5R
M+B<L"@DG9&%L:6%S7U]E9&ET7W1I=&QE)R`]/B`G1&]M86EN(&%L:6%S('!R
M969E<F5N8V5S)RP*"2=D86QI87-?7V%D9%]T:71L92<@/3X@)T%D9"!D;VUA
M:6X@86QI87,G+`H))V1A;&EA<U]?961I=%]L96=E;F0G(#T^("=0<F5F97)E
M;F-E<R<L"@DG9&%L:6%S7U]E9&ET7VYA;64G(#T^("=$;VUA:6X@86QI87,@
M;F%M92<L"@DG9&%L:6%S7U]I;G9A;&ED7W9A;'5E<R<@/3X@)U1H92!D;VUA
M:6X@;F%M92!Y;W4@<W!E8VEF:65D(&ES(&EN=F%L:60N($1O;6%I;B!N86UE
M<R!C86X@8V]M<')I<V4@;&5T=&5R<RP*9&EG:71S(&%N9"!H>7!H96YS+B!%
M86-H('!A<G0@;V8@=&AE(&1O;6%I;B!N86UE(&)E='=E96X@9&]T<R!S:&]U
M;&0@;F]T(&)E"FQO;F=E<B!T:&%N(#8S('-Y;6)O;',N)RP*"2=D86QI87-?
M7V1O;6%I;E]A;')E861Y7V5X:7-T<R<@/3X@)TEN8V]R<F5C="!N86UE(&]F
M(&1O;6%I;B!A;&EA<R`E,2P@9&]M86EN("4Q(&%L<F5A9'D@97AI<W1S+B<L
M"@DG9&%L:6%S7U]W=W=?<')E9FEX7V1O;6%I;E]A;')E861Y7V5X:7-T<R<@
M/3X@)TEN8V]R<F5C="!N86UE(&]F(&1O;6%I;B!A;&EA<R!W=W<N)3$L('1H
M:7,@86QI87,@:7,@86QR96%D>2!C<F5A=&5D(&9O<B!T:&4@9&]M86EN("4Q
M+B<L"@DG9&%L:6%S7U]W96)M86EL7V5N86)L961?9&]M86EN7V%L<F5A9'E?
M97AI<W1S)R`]/B`G26YC;W)R96-T(&1O;6%I;B!A;&EA<R!N86UE.B!4:&5R
M92!I<R!A;')E861Y("!T:&4@9&]M86EN(&YA;64@=V5B;6%I;"XE,2XG+`H)
M)V1A;&EA<U]?;&ES='-?96YA8FQE9%]D;VUA:6Y?86QR96%D>5]E>&ES=',G
M(#T^("=);F-O<G)E8W0@9&]M86EN(&%L:6%S(&YA;64Z($$@9&]M86EN('=I
M=&@@;F%M92`@;&ES=',N)3$@86QR96%D>2!E>&ES=',N)RP*"2=D86QI87-?
M7W-U8F1O;5]A;')E861Y7V5X:7-T<R<@/3X@)TEN8V]R<F5C="!D;VUA:6X@
M86QI87,@;F%M93H@02!D;VUA:6X@=VET:"!N86UE("4Q(&%L<F5A9'D@97AI
M<W1S+B<L"@DG9&%L:6%S7U]D;G-?<F5C;W)D7V%L<F5A9'E?97AI<W1S)R`]
M/B`G4W5C:"!R97-O=7)C92!R96-O<F0@:7,@86QR96%D>2!I;B!T:&4@>F]N
M92!O9B!T:&4@9&]M86EN("`E,2XG+`H))V1A;&EA<U]?9&%L:6%S7V%L<F5A
M9'E?97AI<W1S)R`]/B`G1&]M86EN(&%L:6%S("4Q(&%L<F5A9'D@97AI<W1S
M+B<L"@DG9&%L:6%S7U]M86EL7W1U<FY?;VY?9F%I;&5D)R`]/B`G56YA8FQE
M('1O('1U<FX@;VX@;6%I;"!S97)V:6-E.B`E,2<L"@DG9&%L:6%S7U]W96)?
M='5R;E]O;E]F86EL960G(#T^("=5;F%B;&4@=&\@='5R;B!O;B!796(@<V5R
M=FEC93H@)3$G+`H))V1A=&%B87-E<U]?9&)?861M:6Y?;&]G:6XG(#T^("(E
M,2!A9&UI;FES=')A=&]R)W,@;&]G:6XB+`H))V1A=&%B87-E<U]?;F]T7VEN
M<W1A;&QE9"<@/3X@(BAN;W0@:6YS=&%L;&5D*2(L"@DG9&%T86)A<V5S7U]N
M;W1?<W5P<&]R=&5D7VQI8V5N<V4G(#T^("(H;F]T('-U<'!O<G1E9"!B>2!Y
M;W5R(&QI8V5N<V4@:V5Y*2(L"@DG9&%T86)A<V5S7U]T:71L92<@/3X@(D1A
M=&%B87-E($UA;F%G96UE;G0@86YD($%D;6EN:7-T<F%T;W(G<R!#<F5D96YT
M:6%L<R(L"@DG9&%T86)A<V5S7U]U;F%B;&5?8V]N;F5C="<@/3X@(E5N86)L
M92!T;R!A8V-E<W,@9&%T86)A<V4N($EN8V]R<F5C="!P87)A;65T97)S+B(L
M"@DG9&%T86)A<V5S7U]I;F-O<G)E8W1?9&)?861M:6Y?;&]G:6XG(#T^("=4
M:&4@;&]G:6X@;F%M92!C86X@8V]N=&%I;B!O;FQY(&%L<&AA;G5M97)I8RP@
M9&%S:"!A;F0@=6YD97)S8V]R92!S>6UB;VQS+"!A;F0@<VAO=6QD(&)E9VEN
M('=I=&@@86X@86QP:&%B971I8R!S>6UB;VPN)RP*"2=D871A8F%S97-?7VEN
M8V]R<F5C=%]D8E]A9&UI;E]P87-S=V0G(#T^("=4:&4@<&%S<W=O<F0@<VAO
M=6QD(&YO="!C;VYT86EN('1H92!L;V=I;B!N86UE+B<L"@DG9&%T86)A<V5?
M:&]S=&EN9U]P<F5F97)E;F-E<U]F;W)M7U]A;&QO=U]S:71E87!P7VQO8V%L
M7V1B7W1E>'0G(#T^("=);G-T86QL871I;VX@;V8@<VET92!A<'!L:6-A=&EO
M;G,@=&AA="!D;R!N;W0@<W5P<&]R="!R96UO=&4@9&%T86)A<V5S)RP*"2=D
M871A8F%S95]H;W-T:6YG7W!R969E<F5N8V5S7V9O<FU?7V%L;&]W7W-I=&5A
M<'!?;&]C86Q?9&)?=')U95]T97AT)R`]/B`G06QL;W<@;&]C86P@:&]S=&EN
M9R!O9B!D871A8F%S97,@9F]R('1H97-E('-I=&4@87!P;&EC871I;VYS)RP*
M"2=D871A8F%S95]H;W-T:6YG7W!R969E<F5N8V5S7V9O<FU?7V%L;&]W7W-I
M=&5A<'!?;&]C86Q?9&)?9F%L<V5?=&5X="<@/3X@)T1I<V%L;&]W(&EN<W1A
M;&QA=&EO;B!O9B!T:&5S92!S:71E(&%P<&QI8V%T:6]N<R<L"@DG9&%T86)A
M<V5?:&]S=&EN9U]P<F5F97)E;F-E<U]F;W)M7U]A;&QO=U]S:71E87!P7VQO
M8V%L7V1B7VAI;G0G(#T^("=4:&ES('!R969E<F5N8V4@:7,@;VYL>2!I;B!E
M9F9E8W0@=VAE;B!A(')E;6]T92!D871A8F%S92!S97)V97(@:7,@<V5L96-T
M960@87,@9&5F875L="XG+`H))V1A=&%B87-E7VAO<W1I;F=?<')E9F5R96YC
M97-?9F]R;5]?=&ET;&4G(#T^("=$871A8F%S92!H;W-T:6YG('!R969E<F5N
M8V5S)RP*"2=D871A8F%S95]S97)V97)S7V9O<FU?7W1I=&QE)R`]/B`G1&%T
M86)A<V4@<V5R=F5R<R<L"@DG9&%T86)A<V5?<V5R=F5R<U]F;W)M7U]S97)V
M97)?;&ES=%]L96=E;F0G(#T^("=$871A8F%S92!S97)V97)S)RP))V1A=&%B
M87-E7W-E<G9E<G-?9F]R;5]?<F5M;W9E7V5M<'1Y7W-E;&5C=&EO;B<@/3X@
M)TYO(&1A=&%B87-E('-E<G9E<G,@<V5L96-T960N)RP*"2=D871A8F%S95]S
M97)V97)S7V9O<FU?7W)E;6]V95]T:71L92<@/3X@)U1H92!F;VQL;W=I;F<@
M9&%T86)A<V4@<V5R=F5R<R!W:6QL(&)E(')E;6]V960Z)RP*"2=D871A8F%S
M95]S97)V97)?9&%T86)A<V5?;&ES=%]?8VQI96YT)R`]/B`G0VQI96YT)RP*
M"2=D871A8F%S95]S97)V97)?9&%T86)A<V5?;&ES=%]?9&]M86EN)R`]/B`G
M1&]M86EN)RP*"2=D871A8F%S95]S97)V97)?9&%T86)A<V5?;&ES=%]?:&5A
M9&5R)R`]/B`G1&%T86)A<V5S)RP*"2=D871A8F%S95]S97)V97)?9&%T86)A
M<V5?;&ES=%]?;F%M92<@/3X@)TYA;64G+`H))V1A=&%B87-E7W-E<G9E<E]D
M871A8F%S97-?9F]R;5]?9&%T86)A<V5S7VQI<W1?;&5G96YD)R`]/B`G1&%T
M86)A<V5S)RP*"2=D871A8F%S95]S97)V97)?9&%T86)A<V5S7V9O<FU?7W)E
M;6]V95]E;7!T>5]S96QE8W1I;VXG(#T^("=.;R!D871A8F%S97,@<V5L96-T
M960N)RP*"2=D871A8F%S95]S97)V97)?9&%T86)A<V5S7V9O<FU?7W)E;6]V
M95]T:71L92<@/3X@)U1H92!F;VQL;W=I;F<@9&%T86)A<V5S('=I;&P@8F4@
M<F5M;W9E9#HG+`H))V1A=&%B87-E7W-E<G9E<E]D871A8F%S97-?9F]R;5]?
M=&%B)R`]/B`G1&%T86)A<V5S("@E,2DG+`H))V1A=&%B87-E7W-E<G9E<E]E
M9&ET7V9O<FU?7V%D;6EN7VQO9VEN)R`]/B`B061M:6YI<W1R871O<B=S(&QO
M9VEN(&YA;64B+`H))V1A=&%B87-E7W-E<G9E<E]E9&ET7V9O<FU?7V%D;6EN
M7W!A<W-W;W)D7V]L9"<@/3X@(D-U<G)E;G0@861M:6YI<W1R871O<B=S('!A
M<W-W;W)D(BP*"2=D871A8F%S95]S97)V97)?961I=%]F;W)M7U]A9&UI;E]P
M87-S=V]R9"<@/3X@(DYE=R!A9&UI;FES=')A=&]R)W,@<&%S<W=O<F0B+`H)
M)V1A=&%B87-E7W-E<G9E<E]E9&ET7V9O<FU?7V%D;6EN7W!A<W-W;W)D,B<@
M/3X@(D-O;F9I<FT@;F5W(&%D;6EN:7-T<F%T;W(G<R!P87-S=V]R9"(L"@DG
M9&%T86)A<V5?<V5R=F5R7V5D:71?9F]R;5]?9&5F875L="<@/3X@)U5S92!T
M:&ES('-E<G9E<B!A<R!D969A=6QT(&9O<B`E,2<L"@DG9&%T86)A<V5?<V5R
M=F5R7V5D:71?9F]R;5]?9'5P;&EC871E)R`]/B`G02!D871A8F%S92!S97)V
M97(@=VET:"!T:&ES(&-O;6)I;F%T:6]N(&]F(&AO<W0@861D<F5S<R!A;F0@
M<&]R="!N=6UB97(@:7,@86QR96%D>2!R96=I<W1E<F5D+B<L"@DG9&%T86)A
M<V5?<V5R=F5R7V5D:71?9F]R;5]?:&]S="<@/3X@)TAO<W0@;F%M92!O<B!)
M4"!A9&1R97-S)RP*"2=D871A8F%S95]S97)V97)?961I=%]F;W)M7U]L96=E
M;F1?875T:&5N=&EC871I;VXG(#T^("=!=71H96YT:6-A=&EO;B<L"@DG9&%T
M86)A<V5?<V5R=F5R7V5D:71?9F]R;5]?;&5G96YD7V=E;F5R86PG(#T^("='
M96YE<F%L)RP*"2=D871A8F%S95]S97)V97)?961I=%]F;W)M7U]P87-S=V]R
M9%]W87)N:6YG7W!O<W1G<F5S<6PG(#T^("=)9B!Y;W4@8VAA;F=E('1H92!L
M;V=I;B!O<B!P87-S=V]R9"!B96QO=RP@=&AE(%!O<W1G<F5344P@=7-E<B!A
M8V-O=6YT('=I=&@@861M:6YI<W1R871I=F4@<FEG:'1S('=I;&P@8F4@=7!D
M871E9"XG+`H))V1A=&%B87-E7W-E<G9E<E]E9&ET7V9O<FU?7W!O<G0G(#T^
M("=0;W)T(&YU;6)E<B<L"@DG9&%T86)A<V5?<V5R=F5R7V5D:71?9F]R;5]?
M<&]R=%]H:6YT)R`]/B`G3&5A=F4@8FQA;FL@9F]R('1H92!D969A=6QT('!O
M<G0@;G5M8F5R)RPG9&%T86)A<V5?<V5R=F5R7V5D:71?9F]R;5]?=&%B)R`]
M/B`G1&%T86)A<V4@<V5R=F5R)RP*"2=D871A8F%S95]S97)V97)?961I=%]F
M;W)M7U]T:71L95]N97<G(#T^("=.97<@9&%T86)A<V4@<V5R=F5R)RP*"2=D
M871A8F%S95]S97)V97)?961I=%]F;W)M7U]T:71L95]E9&ET)R`]/B`G1&%T
M86)A<V4@<V5R=F5R("4Q)RP*"2=D871A8F%S95]S97)V97)?961I=%]F;W)M
M7U]T>7!E)R`]/B`G1&%T86)A<V4@<V5R=F5R('1Y<&4G+`H))V1A=&%B87-E
M7W-E<G9E<E]E9&ET7V9O<FU?7W5N:7A?<V]C:V5T)R`]/B`G*&QO8V%L(&-O
M;FYE8W1I;VXI)RP*"2=D871A8F%S95]S97)V97)?97)R;W)?7V-O;G-U;'1?
M861M:6XG(#T^("=0;&5A<V4@8V]N=&%C="!T:&4@<V5R=F5R(&%D;6EN:7-T
M<F%T;W(N)RP*"2=D871A8F%S95]S97)V97)?97)R;W)?7VQA<W1?7V-O;FYE
M8W1I;VY?9F%I;&5D)R`]/B`G5&AE(&QA<W0@871T96UP="!T;R!C;VYT<F]L
M('1H:7,@9&%T86)A<V4@<V5R=F5R(&9A:6QE9"!B96-A=7-E(&]F(&YE='=O
M<FL@<')O8FQE;7,N)RP*"2=D871A8F%S95]S97)V97)?97)R;W)?7VQA<W1?
M7W!E<FUI<W-I;VY?9&5N:65D)R`]/B`G5&AE(&QA<W0@871T96UP="!T;R!C
M;VYT<F]L('1H:7,@9&%T86)A<V4@<V5R=F5R(&9A:6QE9"!B96-A=7-E('1H
M92!S=7!P;&EE9"!A8V-O=6YT(&1O97,@;F]T('!O<W-E<W,@861M:6YI<W1R
M871I=F4@<')I=FEL96=E<RXG+`H))V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?
M;&%S=%]?8W)E9&5N=&EA;'-?;F]T7W-E="<@/3X@(EEO=2!N965D('1O('-U
M<'!L>2!V86QI9"!A9&UI;FES=')A=&]R)W,@;&]G:6X@86YD('!A<W-W;W)D
M(&)E9F]R92!0;&5S:R!C86X@8V]N;F5C="!T;R!T:&ES('-E<G9E<BXB+`H)
M)V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?;&%S=%]?;W1H97)?97)R;W(G(#T^
M("=4:&4@;&%S="!A='1E;7!T('1O(&-O;G1R;VP@=&AI<R!D871A8F%S92!S
M97)V97(@9F%I;&5D+B<L"@DG9&%T86)A<V5?<V5R=F5R7V5R<F]R7U]R96%L
M7U]C;VYN96-T:6]N7V9A:6QE9"<@/3X@)T-O;FYE8W1I;VX@=&\@=&AE(&1A
M=&%B87-E('-E<G9E<B!H87,@9F%I;&5D(&)E8V%U<V4@;V8@;F5T=V]R:R!P
M<F]B;&5M<SHG+`H))V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?<F5A;%]?<&5R
M;6ES<VEO;E]D96YI960G(#T^("=#;VYN96-T:6]N('1O('1H92!D871A8F%S
M92!S97)V97(@:&%S(&9A:6QE9"!B96-A=7-E('1H92!S=7!P;&EE9"!A8V-O
M=6YT(&1O97,@;F]T('!O<W-E<W,@861M:6YI<W1R871I=F4@<')I=FEL96=E
M<SHG+`H))V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?<F5A;%]?9'5P;&EC871E
M7V]B:F5C="<@/3X@)T-O;FYE8W1I;VX@=&\@=&AE(&1A=&%B87-E('-E<G9E
M<B!H87,@9F%I;&5D(&)E8V%U<V4@;V8@82!N86UE(&-L87-H.B<L"@DG9&%T
M86)A<V5?<V5R=F5R7V5R<F]R7U]R96%L7U]U;F%C8V5P=&%B;&5?;F%M92<@
M/3X@)T-O;FYE8W1I;VX@=&\@=&AE(&1A=&%B87-E('-E<G9E<B!H87,@9F%I
M;&5D(&)E8V%U<V4@;V8@86X@:6YV86QI9"!O8FIE8W0@;F%M93HG+`H))V1A
M=&%B87-E7W-E<G9E<E]E<G)O<E]?<F5A;%]?=6YA8V-E<'1A8FQE7W!A<W-W
M;W)D)R`]/B`G0V]N;F5C=&EO;B!T;R!T:&4@9&%T86)A<V4@<V5R=F5R(&AA
M<R!F86EL960@8F5C875S92!O9B!A;B!U;F%C8V5P=&%B;&4@<&%S<W=O<F0Z
M)RP*"2=D871A8F%S95]S97)V97)?97)R;W)?7W)E86Q?7V-R961E;G1I86QS
M7VYO=%]S970G(#T^(")0;&5S:R!C86YN;W0@8V]N;F5C="!T;R!T:&4@9&%T
M86)A<V4@<V5R=F5R(&)E8V%U<V4@=F%L:60@861M:6YI<W1R871O<B=S(&QO
M9VEN(&%N9"!P87-S=V]R9"!H879E(&YO="!B965N('-P96-I9FEE9"XB+`H)
M)V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?<F5A;%]?;W1H97)?97)R;W(G(#T^
M("=#;VYN96-T:6]N('1O('1H92!D871A8F%S92!S97)V97(@:&%S(&9A:6QE
M9#HG+`H))V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?=&5S=%]?8V]N;F5C=&EO
M;E]F86EL960G(#T^("=497-T(&-O;FYE8W1I;VX@=&\@=&AE(&1A=&%B87-E
M('-E<G9E<B!H87,@9F%I;&5D(&)E8V%U<V4@;V8@;F5T=V]R:R!P<F]B;&5M
M<SHG+`H))V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?=&5S=%]?<&5R;6ES<VEO
M;E]D96YI960G(#T^("=497-T(&-O;FYE8W1I;VX@=&\@=&AE(&1A=&%B87-E
M('-E<G9E<B!H87,@9F%I;&5D(&)E8V%U<V4@=&AE('-U<'!L:65D(&%C8V]U
M;G0@9&]E<R!N;W0@<&]S<V5S<R!A9&UI;FES=')A=&EV92!P<FEV:6QE9V5S
M.B<L"@DG9&%T86)A<V5?<V5R=F5R7V5R<F]R7U]T97-T7U]D=7!L:6-A=&5?
M;V)J96-T)R`]/B`G5&5S="!C;VYN96-T:6]N('1O('1H92!D871A8F%S92!S
M97)V97(@:&%S(&9A:6QE9"!B96-A=7-E(&]F(&$@;F%M92!C;&%S:#HG+`H)
M)V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?=&5S=%]?=6YA8V-E<'1A8FQE7VYA
M;64G(#T^("=497-T(&-O;FYE8W1I;VX@=&\@=&AE(&1A=&%B87-E('-E<G9E
M<B!H87,@9F%I;&5D(&)E8V%U<V4@;V8@86X@:6YV86QI9"!O8FIE8W0@;F%M
M93HG+`H))V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?=&5S=%]?=6YA8V-E<'1A
M8FQE7W!A<W-W;W)D)R`]/B`G5&5S="!C;VYN96-T:6]N('1O('1H92!D871A
M8F%S92!S97)V97(@:&%S(&9A:6QE9"!B96-A=7-E(&]F(&%N('5N86-C97!T
M86)L92!P87-S=V]R9#HG+`H))V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?=&5S
M=%]?8W)E9&5N=&EA;'-?;F]T7W-E="<@/3X@(EEO=2!N965D('1O('-U<'!L
M>2!V86QI9"!A9&UI;FES=')A=&]R)W,@;&]G:6X@86YD('!A<W-W;W)D(&)E
M9F]R92!0;&5S:R!C86X@8V]N;F5C="!T;R!T:&ES('-E<G9E<BXB+`H))V1A
M=&%B87-E7W-E<G9E<E]E<G)O<E]?=&5S=%]?;W1H97)?97)R;W(G(#T^("=4
M97-T(&-O;FYE8W1I;VX@=&\@=&AE(&1A=&%B87-E('-E<G9E<B!H87,@9F%I
M;&5D.B<L"@DG9&%T86)A<V5?<V5R=F5R7VQI<W1?7VAE861E<B<@/3X@)T1A
M=&%B87-E('-E<G9E<G,G+`H))V1A=&%B87-E7W-E<G9E<E]L:7-T7U]L87-T
M7V5R<F]R)R`]/B`G4R<L"@DG9&%T86)A<V5?<V5R=F5R7VQI<W1?7W1Y<&4G
M(#T^("=397)V97(@='EP92<L"@DG9&%T86)A<V5?<V5R=F5R7VQI<W1?7VAO
M<W0G(#T^("=(;W-T(&YA;64G+`H))V1A=&%B87-E7W-E<G9E<E]L:7-T7U]P
M;W)T)R`]/B`G4&]R="<L"@DG9&%T86)A<V5?<V5R=F5R7VQI<W1?7V1B8V]U
M;G0G(#T^("=$871A8F%S97,G+`H))V1B7U]C<F5A=&5?;F5W7V1B)R`]/B`B
M061D(&YE=R!D871A8F%S92(L"@DG9&)?7V1B7V%D9"<@/3X@(D%D9"!.97<@
M1&%T86)A<V4B+`H))V1B7U]D8E]F;W)?9&]M)R`]/B`B1&%T86)A<V5S(&9O
M<B!D;VUA:6X@)3$B+`H))V1B7U]D8E]I9%]U;F1E9FEN960G(#T^(")$871A
M8F%S92!I9"!I<R!U;F1E9FEN960N(BP*"2=D8E]?9&)?;F%M92<@/3X@(D1A
M=&%B87-E(&YA;64B+`H))V1B7U]D8E]N;W1?97AI<W0G(#T^(")$871A8F%S
M92!D;V5S(&YO="!E>&ES="XB+`H))V1B7U]D8E]T>7!E)R`]/B`B5'EP92(L
M"@DG9&)?7V1B7W-E<G9E<B<@/3X@(D1A=&%B87-E('-E<G9E<B(L"@DG9&)?
M<V5R=F5R7VYO=%]E>&ES="<@/3X@(D1A=&%B87-E('-E<G9E<B!D;V5S(&YO
M="!E>&ES="XB+`H))V1B7U]D8E]U<V5R7VYO=%]E>&ES="<@/3X@(D1A=&%B
M87-E('5S97(@9&]E<R!N;W0@97AI<W0N(BP*"2=D8E]?9&]M86EN7VYO=%]E
M>&ES="<@/3X@(D1O;6%I;B!D;V5S(&YO="!E>&ES="XB+`H))V1B7U]E;G1E
M<E]D8E]N86UE)R`]/B`B16YT97(@;F5W(&1A=&%B87-E(&YA;64N(BP*"2=D
M8E]?:6YV86QI9%]D8E]I9"<@/3X@(D1A=&%B87-E(&ED96YT:69I97(@:7,@
M:6YV86QI9"XB+`H))V1B7U]I;G9A;&ED7V1B7VYA;64G(#T^(")$871A8F%S
M92!N86UE(&ES(&EN=F%L:60N(%1H92!D871A8F%S92!N86UE('-H;W5L9"!C
M;VYT86EN(&]N;'D@3&%T:6X@86QP:&%B970@<WEM8F]L<RP@9&EG:71S(&]R
M(&1A<V@N($ET(&-A;FYO="!B92!L;VYG97(@=&AA;B`V,R!S>6UB;VQS+B(L
M"@DG9&)?7VUA>%]D8E]R96%C:&5D7V9O<E]D;VTG(#T^(")4:&4@;&EM:70@
M;VX@;G5M8F5R(&]F(&1A=&%B87-E<R!I<R!R96%C:&5D(&9O<B!T:&ES(&1O
M;6%I;BXB+`H))V1B7U]N;VYD969A=6QT7W-E<G9E<E]N;W1?86QL;W=E9"<@
M/3X@)T]N;'D@=&AE(&%D;6EN:7-T<F%T;W(@8V%N(&-H;V]S92!S97)V97)S
M(&9O<B!D871A8F%S92!H;W-T:6YG+B<L"@DG9&)?7W!O<W1G<F5S7VYO=%]C
M;VYN96-T7V9O<E]A9&UI;B<@/3X@(E5N86)L92!T;R!C;VYN96-T('1O(%!O
M<W1G<F5344PN($5N86)L92!0;W-T9W)E4U%,('-U<'!O<G0@;VX@=&AE('-E
M<G9E<B!A9&UI;FES=')A=&EO;B!P86=E+B(L"@DG9&)?7W!O<W1G<F5S7VYO
M=%]C;VYN96-T7V9O<E]C;&EE;G0G(#T^(")5;F%B;&4@=&\@8V]N;F5C="!T
M;R!0;W-T9W)E4U%,+B!2969E<B!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A
M=&]R(&9O<B!H96QP+B(L"@DG9&)?7W)E;6]V95]D8E]O;E]D;VUA:6XG(#T^
M(")4:&4@9F]L;&]W:6YG(&1A=&%B87-E<R!W:6QL(&)E(')E;6]V960@9G)O
M;2!T:&4@9&]M86EN("4Q.B(L"@DG9&)?7W)E;6]V95]D8E]O;E]D;VUA:6Y?
M;V9?8VPG(#T^(")4:&4@9F]L;&]W:6YG(&1A=&%B87-E<R!F;W(@9&]M86EN
M("4R(&]W;F5D(&)Y(&-L:65N="`E,2!W:6QL(&)E(')E;6]V960Z(BP*"2=D
M8E]?<F5M;W9E7V1B7VQI;FME9%]R97-O=7)C92<@/3X@)U1H:7,@9&%T86)A
M<V4@:7,@:6X@=7-E(&)Y(&$@<VET92!A<'!L:6-A=&EO;BX@270@8V%N(&)E
M(')E;6]V960@;VYL>2!A9G1E<B!U;FEN<W1A;&QI;F<@=&AI<R!S:71E(&%P
M<&QI8V%T:6]N+B<L"@DG9&)?7W)E;6]V95]D8E]U<V5R<R<@/3X@(E1H92!F
M;VQL;W=I;F<@=7-E<G,@;V8@9&%T86)A<V4@)3(@:6X@9&]M86EN("4Q('=I
M;&P@8F4@<F5M;W9E9#HB+`H))V1B7U]R96UO=F5?9&)?=7-E<G-?;V9?8VPG
M(#T^(")4:&4@9F]L;&]W:6YG('5S97)S(&]F(&1A=&%B87-E("4S(&EN(&1O
M;6%I;B`E,B!O=VYE9"!B>2!T:&4@8VQI96YT("4Q('=I;&P@8F4@<F5M;W9E
M9#HB+`H))V1B7U]S96QE8W1?9&)?9F]R7W)E;6]V92<@/3X@(E-E;&5C="!T
M:&4@9&%T86)A<V5S('1O(&)E(')E;6]V960N(BP*"2=D8E]?<V5L96-T7V1B
M7W5S97)S7V9O<E]R96UO=F4G(#T^(")396QE8W0@=&AE(&1A=&%B87-E('5S
M97)S('1O(&)E(')E;6]V960N(BP*"2=D8E]?=6YA8FQE7V-R96%T95]D8E]U
M<V5R)R`]/B`B56YA8FQE('1O(&-R96%T92!T:&4@9&%T86)A<V4@=7-E<CH@
M)3$B+`H))V1B7U]U;F%B;&5?9&5F:6YE7V1B7VYA;64G(#T^(")5;F%B;&4@
M=&\@9&5F:6YE('1H92!D871A8F%S92!N86UE.B`E,2(L"@DG9&)?7W5N86)L
M95]D969I;F5?9&)?=7-E<B<@/3X@(E5N86)L92!T;R!D969I;F4@=&AE(&1A
M=&%B87-E('5S97(Z("4Q(BP*"2=D8E]?=6YA8FQE7V1E9FEN95]D8E]U<V5R
M<R<@/3X@(E5N86)L92!T;R!D969I;F4@9&%T86)A<V4@=7-E<G,Z("4Q(BP*
M"2=D8E]?=6YA8FQE7W-E;&5C=%]D;VU?;F%M92<@/3X@(E5N86)L92!T;R!S
M96QE8W0@9&]M86EN(&YA;64Z("4Q(BP*"2=D8E]E9&ET7U]D8E]F;W)?9&]M
M)R`]/B`B57-E<G,@9F]R(&1A=&%B87-E("4Q(&]N(&1O;6%I;B`E,B(L"@DG
M9&)?961I=%]?:6YV86QI9%]D8E]N86UE)R`]/B`B5&AE(&1A=&%B87-E(&YA
M;64@:7,@:6YV86QI9"XB+`H))V1B7V5D:71?7VYO7W5S97)S)R`]/B`B5&AE
M<F4@87)E(&YO('5S97)S('=I=&@@8W)E9&5N=&EA;',@9F]R('1H:7,@9&%T
M86)A<V4N(BP*"2=D8E]E9&ET7U]U;F%B;&5?9&5F:6YE7V1B7W5S<G,G(#T^
M(")5;F%B;&4@=&\@9&5F:6YE('1H92!D871A8F%S92!U<V5R<SH@)3$B+`H)
M)V1B7V5D:71?7W5N86)L95]S96QE8W1?9&)?=7-R)R`]/B`B56YA8FQE('1O
M('-E;&5C="!T:&4@9&%T86)A<V4@=7-E<BXB+`H))V1B7V5D:71?7V1B7W5S
M97)?<&%S<W=O<F1?9F]R7R<@/3X@(E!L96%S92!T>7!E(&EN('1H92!P87-S
M=V]R9"!T;R!L;V<@:6X@87,@=&AE(&1A=&%B87-E('5S97(@)3$@(BP*"2=D
M8E]L:7-T7U]T86)?=&ET;&5?9&)?='EP92<@/3X@(E0B+`H))V1B7W5S<E]E
M9&ET7U]A9&1?9&)?=7-R)R`]/B`B5&AE(&1A=&%B87-E('5S97(@861D:71I
M;VXB+`H))V1B7W5S<E]E9&ET7U]D8E]U<W)?;F%M92<@/3X@(D1A=&%B87-E
M('5S97(@;F%M92(L"@DG9&)?=7-R7V5D:71?7V5D:71?9&)?=7-R)R`]/B`B
M4V5T('5P(&-R961E;G1I86QS(&9O<B!D871A8F%S92!U<V5R(&%C8V]U;G0B
M+`H))V1B7W5S<E]E9&ET7U]F;W)?9&(G(#T^("(@:6X@)3$@9&%T86)A<V4B
M+`H))V1B7W5S<E]E9&ET7U]N;W1?8W)E871E7W!A<W,G(#T^(")4:&ES(&]P
M97)A=&EO;B!W:6QL(')E<W5L="!I;B!C<F5A=&EN9R!A(&1A=&%B87-E('5S
M97(@86-C;W5N="!W:71H;W5T('!A<W-W;W)D+EQN1&\@>6]U('=I<V@@=&\@
M8W)E871E(&$@=7-E<B!W:71H;W5T(&%S<VEG;FEN9R!A('!A<W-W;W)D/R(L
M"@DG9&)U<V5R7U]O;FQY7V]N95]U<V5R7V-A;E]B95]D969A=6QT)R`]/B`B
M3VYL>2!O;F4@=7-E<B!C86X@8F4@<V5T(&%S(&1E9F%U;'0N(BP*"2=D8E]S
M97)V97)?7V-A;FYO=%]D96QE=&5?9&5F875L="<@/3X@(E1H92!D969A=6QT
M(&1A=&%B87-E('-E<G9E<B!C86YN;W0@8F4@9&5L971E9"XB+`H))V1B7W-E
M<G9E<E]?8V%N;F]T7V1E;&5T95]L;V-A;"<@/3X@(E1H92!L;V-A;"!D871A
M8F%S92!S97)V97(@8V%N;F]T(&)E(&1E;&5T960N(BP*"2=D8E]S97)V97)?
M7V-A;FYO=%]D96QE=&5?=7-E9"<@/3X@)T$@9&%T86)A<V4@<V5R=F5R(&-A
M;FYO="!B92!D96QE=&5D('=H:6QE('1H97)E(&%R92!D871A8F%S97,@:&]S
M=&5D(&]N(&ET+B<L"@DG9&5M;U]?9&ES86)L961?:6Y?9&5M;R<@/3X@(E1H
M:7,@;W!E<F%T:6]N(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&1E;6\@=F5R
M<VEO;BXB+`H))V1N<U]?861D7V1N<U]M87-T97)?<V5R=F5R)R`]/B`B061D
M($1.4R!M87-T97(@<V5R=F5R(BP*"2=D;G-?7V%D9%]D;G-?<F5C;W)D)R`]
M/B`B061D(')E<V]U<F-E(')E8V]R9"(L"@DG9&YS7U]A9&1?;F%M97-E<G9E
M<B<@/3X@(D%D9"!N86UE<V5R=F5R(BP*"2=D;G-?7V1N<U]R96-O<F1?;F]T
M7V5X:7-T)R`]/B`B5&AE<F4@:7,@;F\@<W5C:"!R97-O=7)C92!R96-O<F0@
M:6X@=&AE('IO;F4N(BP*"2=D;G-?7V1N<U]Z;VYE7V9O<E]D;VUA:6XG(#T^
M(")$3E,@>F]N92!F;W(@=&AE(&1O;6%I;B(L"@DG9&YS7U]D;G-?>F]N95]L
M96=E;F0G(#T^("=297-O=7)C92!R96-O<F1S)RP*"2=D;G-?7V1N<U]Z;VYE
M7VUA<W1E<E]T:71L92<@/3X@)U1H:7,@<V5R=F5R(&%C=',@87,@82!P<FEM
M87)Y(&YA;65S97)V97(@9F]R('1H92!$3E,@>F]N92`E,2<L"@DG9&YS7U]D
M;G-?>F]N95]S;&%V95]T:71L92<@/3X@)U1H:7,@<V5R=F5R(&%C=',@87,@
M82!S96-O;F1A<GD@;F%M97-E<G9E<B!F;W(@=&AE($1.4R!Z;VYE("4Q)RP*
M"2=D;G-?7V1N<U]Z;VYE7V]F9E]T:71L92<@/3X@)TYA;65S97)V97)S(&9O
M<B!T:&4@1$Y3('IO;F4@)3$G+`H))V1N<U]?861D7V1N<U]R96-O<F1?;6%S
M=&5R7W1I=&QE)R`]/B`G061D(')E<V]U<F-E(')E8V]R9"!T;R!T:&4@>F]N
M92<L"@DG9&YS7U]A9&1?9&YS7W)E8V]R9%]S;&%V95]T:71L92<@/3X@)T%D
M9"!P<FEM87)Y($1.4R!S97)V97(G+`H))V1N<U]?861D7V1N<U]R96-O<F1?
M;V9F7W1I=&QE)R`]/B`G061D(&YA;65S97)V97(G+`H))V1N<U]?961I=%]D
M;G-?<F5C;W)D7VUA<W1E<E]T:71L92<@/3X@)T5D:70@<F5S;W5R8V4@<F5C
M;W)D)RP*"2=D;G-?7V5D:71?9&YS7W)E8V]R9%]S;&%V95]T:71L92<@/3X@
M)T5D:70@<V5R=F5R(')E8V]R9"<L"@DG9&YS7U]E9&ET7V1N<U]R96-O<F1?
M;V9F7W1I=&QE)R`]/B`G161I="!N86UE<V5R=F5R)RP*"2=D;G-?7V1N<U]R
M96-O<F1?:6YV86QI9%]V86QU97,G(#T^("=4:&5R92!A<F4@:6YC;W)R96-T
M('!A<F%M971E<B!V86QU97,N)RP*"2=D;G-?7V1N<U]Z;VYE7VEN=F%L:61?
M=F%L=65S)R`]/B`G5&AE<F4@87)E(&EN8V]R<F5C="!P87)A;65T97(@=F%L
M=65S+B<L"@DG9&YS7U]D;G-?<V]A7W1I=&QE)R`]/B`G4T]!(%!R969E<F5N
M8V5S)RP*"2=D;G-?7V1N<U]S;V%?;&5G96YD)R`]/B`G4T]!(%!R969E<F5N
M8V5S)RP*"2=D;G-?7V1N<U]S;V%?='1L)R`]/B`G5%1,)RP*"2=D;G-?7V1N
M<U]S;V%?<F5F<F5S:"<@/3X@)U)E9G)E<V@G+`H))V1N<U]?9&YS7W-O85]R
M971R>2<@/3X@)U)E=')Y)RP*"2=D;G-?7V1N<U]S;V%?97AP:7)E)R`]/B`G
M17AP:7)E)RP*"2=D;G-?7V1N<U]S;V%?;6EN:6UU;2<@/3X@)TUI;FEM=6TG
M+`H))V1N<U]?9&YS7W-O85]T=&Q?97)R;W(G(#T^("=45$P@=F%L=64@:7,@
M:6YV86QI9"X@270@8V%N(&)E(&9R;VT@,2!S96-O;F0@=&\@-C@@>65A<G,N
M)RP*"2=D;G-?7V1N<U]S;V%?<F5F<F5S:%]E<G)O<B<@/3X@)U)E9G)E<V@@
M=F%L=64@:7,@:6YV86QI9"X@270@8V%N(&)E(&9R;VT@,2!S96-O;F0@=&\@
M-C@@>65A<G,N)RP*"2=D;G-?7V1N<U]S;V%?<F5T<GE?97)R;W(G(#T^("=2
M971R>2!V86QU92!I<R!I;G9A;&ED+B!)="!C86X@8F4@9G)O;2`Q('-E8V]N
M9"!T;R`V."!Y96%R<RXG+`H))V1N<U]?9&YS7W-O85]E>'!I<F5?97)R;W(G
M(#T^("=%>'!I<F4@=F%L=64@:7,@:6YV86QI9"X@270@8V%N(&)E(&9R;VT@
M,2!S96-O;F0@=&\@-C@@>65A<G,N)RP*"2=D;G-?7V1N<U]S;V%?;6EN:6UU
M;5]E<G)O<B<@/3X@)TUI;FEM=6T@=F%L=64@:7,@:6YV86QI9"X@270@8V%N
M(&)E(&9R;VT@,2!S96-O;F0@=&\@-C@@>65A<G,N)RP*"2=D;G-?7V1N<U]D
M969A=6QT7W1I=&QE)R`]/B`G4F5S=&]R92!T:&4@1$Y3('IO;F4N)RP*"2=D
M;G-?7V1N<U]D969A=6QT7VQE9V5N9"<@/3X@)UIO;F4@<F5S=&]R:6YG(&]P
M=&EO;G,N)RP*"2=D;G-?7V1N<U]D969A=6QT7W1E>'0G(#T^("=#:&]O<V4@
M=&AE('-E='1I;F=S(&9O<B!R97-T;W)I;F<@=&AE($1.4R!Z;VYE+"!C;VYF
M:7)M('1H96T@86YD(&-L:6-K($]++B<L"@DG9&YS7U]D;G-?9&5F875L=%]C
M;VYF:7)M)R`]/B`G0V]N9FER;2!R97-T;W)I;F<@;V8@1$Y3('IO;F4N)RP*
M"2=D;G-?7V1N<U]D969A=6QT7V-O;F9I<FU?<F5Q=6ER960G(#T^("=0;&5A
M<V4@8V]N9FER;2!R97-T;W)I;F<@;V8@1$Y3('IO;F4N)RP*"@DG9&YS7W1?
M7V1N<U]D969A=6QT7W1I=&QE)R`]/B`G4F5S=&]R92!T:&4@;W)I9VEN86P@
M1$Y3('IO;F4@=&5M<&QA=&4N)RP*"2=D;G-?=%]?9&YS7V1E9F%U;'1?;&5G
M96YD)R`]/B`G4F5S=&]R:6YG(&]P=&EO;G,N)RP*"2=D;G-?=%]?9&YS7V1E
M9F%U;'1?=&5X="<@/3X@)T-H;V]S92!T:&4@<V5T=&EN9W,@9F]R(')E<W1O
M<FEN9R!T:&4@1$Y3('IO;F4@=&5M<&QA=&4L(&-O;F9I<FT@=&AE;2!A;F0@
M8VQI8VL@3TLN)RP*"2=D;G-?=%]?9&YS7V1E9F%U;'1?8V]N9FER;2<@/3X@
M)T-O;F9I<FT@<F5S=&]R:6YG(&]F($1.4R!Z;VYE('1E;7!L871E+B<L"@DG
M9&YS7W1?7V1N<U]D969A=6QT7V-O;F9I<FU?<F5Q=6ER960G(#T^("=0;&5A
M<V4@8V]N9FER;2!R97-T;W)I;F<@;V8@1$Y3('IO;F4@=&5M<&QA=&4N)RP*
M"2=D;G-?=%]?9&YS7WIO;F5?;V9F7W)E;6]V95]T:71L92<@/3X@(E1H92!F
M;VQL;W=I;F<@<F5S;W5R8V4@<F5C;W)D<R!F;W(@1$Y3('IO;F4@=&5M<&QA
M=&4@=VEL;"!B92!R96UO=F5D.B(L"@DG9&YS7W1?7V1N<U]Z;VYE7VUA<W1E
M<E]R96UO=F5?=&ET;&4G(#T^(")4:&4@9F]L;&]W:6YG(')E<V]U<F-E(')E
M8V]R9',@=VEL;"!B92!R96UO=F5D(&9R;VT@1$Y3('IO;F4@=&5M<&QA=&4Z
M(BP*"2=D;G-?=%]?861D7V1N<U]R96-O<F1?;6%S=&5R7W1I=&QE)R`]/B`G
M061D(')E<V]U<F-E(')E8V]R9"!T;R!T:&4@>F]N92!T96UP;&%T92<L"@DG
M9&YS7W1?7V%D9%]D;G-?<F5C;W)D7V]F9E]T:71L92<@/3X@)T%D9"!N86UE
M<V5R=F5R)RP*"2=D;G-?=%]?961I=%]D;G-?<F5C;W)D7VUA<W1E<E]T:71L
M92<@/3X@)T5D:70@<F5S;W5R8V4@<F5C;W)D)RP*"2=D;G-?=%]?961I=%]D
M;G-?<F5C;W)D7V]F9E]T:71L92<@/3X@)T5D:70@;F%M97-E<G9E<B<L"@DG
M9&YS7W1?7W-E;&5C=%]R96-O<F1?=&]?<F5M;W9E)R`]/B`G4V5L96-T(')E
M8V]R9',@=&\@8F4@<F5M;W9E9"!F<F]M('1H92!$3E,@=&5M<&QA=&4N)RP*
M"@DG9&YS7U]U;FET7W-E8V]N9',G(#T^("=S96-O;F1S)RP*"2=D;G-?7W5N
M:71?;6EN=71E<R<@/3X@)VUI;G5T97,G+`H))V1N<U]?=6YI=%]H;W5R<R<@
M/3X@)VAO=7)S)RP*"2=D;G-?7W5N:71?9&%Y<R<@/3X@)V1A>7,G+`H))V1N
M<U]?=6YI=%]W965K<R<@/3X@)W=E96MS)RP*"2=D;G-?7V1N<U]Z;VYE7V]F
M9E]R96UO=F5?=&ET;&4G(#T^(")4:&4@9F]L;&]W:6YG(')E<V]U<F-E(')E
M8V]R9',@=VEL;"!B92!R96UO=F5D(&9R;VT@=&AE('IO;F4@)3$Z(BP*"2=D
M;G-?7V1N<U]Z;VYE7VUA<W1E<E]R96UO=F5?=&ET;&4G(#T^(")4:&4@9F]L
M;&]W:6YG(')E<V]U<F-E(')E8V]R9',@9F]R($1.4R!Z;VYE("4Q('=I;&P@
M8F4@<F5M;W9E9#HB+`H))V1N<U]?9&YS7WIO;F5?<VQA=F5?<F5M;W9E7W1I
M=&QE)R`]/B`B5&AE(&9O;&QO=VEN9R!P<FEM87)Y(&YA;65S97)V97(@<F5C
M;W)D<R!F;W(@)3$@=VEL;"!B92!R96UO=F5D.B(L"@DG9&YS7U]D;G-?>F]N
M95]S=&%T=7,G(#T^(")$3E,@>F]N92!S=&%T=7,N(BP*"2=D;G-?7V1N<U]Z
M;VYE7W1E;7!L871E)R`]/B`B1$Y3('IO;F4@=&5M<&QA=&4B+`H))V1N<U]?
M9&YS7WIO;F5?=&5M<&QA=&5?<F5S=&]R95]D969A=6QT)R`]/B`B4F5S=&]R
M92!T:&4@9&5F875L="!$3E,@>F]N92!T96UP;&%T92(L"@DG9&YS7U]D;G-?
M>F]N95]T96UP;&%T95]R97-T;W)E7V1E9F%U;'1?8V]N9FER;2<@/3X@(E)E
M<W1O<FEN9R!T:&4@<W1A;F1A<F0@1$Y3('IO;F4@=&5M<&QA=&4@=VEL;"!D
M:7-C87)D('1H92!C=7)R96YT;'D@=7-E9"!T96UP;&%T92P@<')O8V5E9"!A
M;GEW87D_(BP*"2=D;G-?7V1N<U]Z;VYE7W1E;7!L871E7W)E<W1O<F5?9&5F
M875L=%]E<G)O<B<@/3X@(D5R<F]R(')E<W1O<FEN9R!T:&4@1$Y3('IO;F4@
M=&5M<&QA=&4Z(BP*"2=D;G-?7VAO<W0G(#T^(")(;W-T(BP*"2=D;G-?7VEN
M=F%L:61?:7!?861D<F5S<R<@/3X@(DE0(&%D9')E<W,@;V8@;F5W(&UA<W1E
M<B!$3E,@<V5R=F5R(&ES(&EN=F%L:60@;W(@96UP='DN(BP*"2=D;G-?7VEP
M7V%D9')E<W,G(#T^("))4"!!9&1R97-S(BP*"2=D;G-?7VUA<W1E<E]D;G-?
M='EP92<@/3X@(FES(&$@;6%S=&5R($1.4R!S97)V97(B+`H))V1N<U]?;6%S
M=&5R<R<@/3X@(D1.4R!M87-T97(@<V5R=F5R<R(L"@DG9&YS7U]S;V%?;6EN
M:6UU;5]T;V]?;&%R9V4G(#T^("=#86-H:6YG(&YE9V%T:79E(')E<W!O;G-E
M<R!F;W(@;6]R92!T:&%N('1H<F5E(&AO=7)S(&ES(&YO="!R96-O;6UE;F1E
M9"XG+`H))V1N<U]?<V5L96-T7VUA<W1E<G-?=&]?<F5M;W9E)R`]/B`B4V5L
M96-T(')E8V]R9',@=&\@8F4@<F5M;W9E9"XB+`H))V1N<U]?<V5L96-T7W1E
M;7!L871E7W)E8V]R9%]T;U]R96UO=F4G(#T^("=396QE8W0@<F5C;W)D<R!T
M;R!B92!R96UO=F5D+B<L"@DG9&YS7U]S96QE8W1?8V]M;6]N7V%C;%]R96-O
M<F1?=&]?<F5M;W9E)R`]/B`G4V5L96-T($%#3"!R96-O<F1S(&9O<B!R96UO
M=FEN9RXG+`H))V1N<U]?<V5L96-T7W)E8V]R9%]T;U]R96UO=F4G(#T^("=3
M96QE8W0@<F5S;W5R8V4@<F5C;W)D<R!T;R!B92!R96UO=F5D+B<L"@DG9&YS
M7U]N86UE<V5R=F5R<U]F;W)?9&]M86EN)R`]/B`B3F%M97-E<G9E<G,@9F]R
M('1H92!D;VUA:6XB+`H))V1N<U]?;G,G(#T^(").86UE('-E<G9E<B(L"@DG
M9&YS7U]N<U]R96-O<F0G(#T^(").86UE('-E<G9E<G,B+`H))V1N<U]?<F5M
M;W9E7V1N<U]M87-T97)S7V]N7V1O;6%I;B<@/3X@(E1H92!F;VQL;W=I;F<@
M1$Y3(&UA<W1E<B!S97)V97)S(&9O<B!D;VUA:6X@)3(@;W=N960@8GD@8VQI
M96YT("4Q('=I;&P@8F4@<F5M;W9E9#HB+`H))V1N<U]?<F5M;W9E7V1N<U]Z
M;VYE7V]F7V1O;6%I;E]?)R`]/B`B1$Y3(')E8V]R9',@<F5M;W9A;"!F<F]M
M(&1O;6%I;B`E,2(L"@DG9&YS7U]R96UO=F5?9&YS7WIO;F5?=&5M<&QA=&5?
M7R<@/3X@(E1H92!F;VQL;W=I;F<@<F5S;W5R8V4@<F5C;W)D<R!W:6QL(&)E
M(')E;6]V960@9G)O;2!T:&4@=&5M<&QA=&4Z(BP*"2=D;G-?7W)E;6]V95]C
M;VUM;VY?86-L7W)E8V]R9"<@/3X@(E1H92!F;VQL;W=I;F<@04-,(')E8V]R
M9',@=VEL;"!B92!R96UO=F5D(BP*"2=D;G-?7W)E;6]V95]T:&ES7V1N<U]R
M96-O<F0_)R`]/B`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(')E;6]V92!T
M:&ES($1.4R!R96-O<F0_(BP*"2=D;G-?7W)E<W1O<F5?9&5F875L="<@/3X@
M(E)E<W1O<FEN9R!T:&4@1$Y3('IO;F4@8GD@=&AE('1E;7!L871E(BP*"2=D
M;G-?7W)E<W1O<F5?9&5F875L=%]C;VYF:7)M)R`]/B`B4F5S=&]R:6YG('1H
M92!$3E,@>F]N92!W:6QL(&1I<V-A<F0@=&AE(&-U<G)E;G0@1$Y3('IO;F4@
M8V]N9FEG=7)A=&EO;BP@<')O8V5E9"!A;GEW87D_(BP*"2=D;G-?7W)E<W1O
M<F5?9&5F875L=%]E<G)O<B<@/3X@(D5R<F]R(')E<W1O<FEN9R!$3E,@>F]N
M93HB+`H))V1N<U]?<VQA=F5?9&YS7W1Y<&4G(#T^(")I<R!A('-E8V]N9&%R
M>2!N86UE('-E<G9E<B(L"@DG9&YS7U]S=6)D;VUA:6Y?9&YS7W)E8U]R96UO
M=F5D)R`]/B`B5&AE($$@<F5C;W)D(&AA<R!B965N(')E;6]V960@9G)O;2!T
M:&4@<W5B9&]M86EN('IO;F4@)3$B+`H))V1N<U]?='EP92<@/3X@(E)E8V]R
M9"!T>7!E(BP*"2=D;G-?7W5N86)L95]A8W1I=F%T92]D96%C=&EV871E7V1N
M<R<@/3X@(E5N86)L92!T;R!A8W1I=F%T92]D96%C=&EV871E($1.4SH@)3$B
M+`H))V1N<U]?=6YA8FQE7V%D9%]D;G-?;6%S=&5R7V1U<&QI8V%T95]E;G1R
M>2<@/3X@(E5N86)L92!T;R!A9&0@1$Y3(&UA<W1E<B!S97)V97(Z(&1U<&QI
M8V%T92!E;G1R>2XB+`H))V1N<U]?=6YA8FQE7V1E9FEN95]D;G-?<F5C;W)D
M)R`]/B`B56YA8FQE('1O(&1E9FEN92!T:&4@1$Y3(')E8V]R9#H@)3$B+`H)
M)V1N<U]?=6YA8FQE7V=E=%]D;G-?=&5M<&QA=&5?<W1A='5S)R`]/B`B56YA
M8FQE('1O(')E=')I979E('1H92!$3E,@=&5M<&QA=&4@<W1A='5S+B(L"@DG
M9&YS7U]U;F%B;&5?<F5M;W9E7V1N<U]R96,G(#T^(")5;F%B;&4@=&\@<F5M
M;W9E('1H92!$3E,@<F5C;W)D.B`E,2(L"@DG9&YS7U]V86PG(#T^(")686QU
M92(L"@DG9&YS7U]W87)N:6YG<U]?)R`]/B`B5&AE(')E<W5L="!O9B!$3E,@
M>F]N92!M;V1I9FEC871I;VXZ(BP*"2=D;G-?7WEO=5]N;W1?:&%V95]P97)M
M7VUA;F%G95]D;G,G(#T^(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T
M;R!M86YA9V4@=&AE($1.4R!Z;VYE(&9O<B!T:&ES(&1O;6%I;BXB+`H))V1N
M<U]?>F]N95]R96-O<F0G(#T^(")$3E,@<F5C;W)D<R(L"@DG9&YS7U]D;G-?
M<')E9F5R96YC97-?9F]R;2<@/3X@)T1.4R!P<F5F97)E;F-E<R<L"@DG9&YS
M7U]D;G-?<F5C=7)S:6]N7W-E='1I;F=S)R`]/B`G1$Y3(')E8W5R<VEO;B!S
M971T:6YG<R<L"@DG9&YS7U]A;&QO=U]R96-U<G-I;VXG(#T^("=!;&QO=R!R
M96-U<G-I;VXG+`H))V1N<U]A9&1?7V%D9%]R96-?9F]R7WIO;F4G(#T^(")!
M9&0@)3$@9F]R('IO;F4@)3(B+`H))V1N<U]A9&1?7V-A;F]N:6-A;%]D;VU?
M;F%M95]I<U]I;G9A;&ED)R`]/B`B0V%N;VYI8V%L(&1O;6%I;B!N86UE(&ES
M(&EN=F%L:60N(BP*"2=D;G-?861D7U]E;G1E<E]C86YO;FEC86Q?;F%M92<@
M/3X@(D5N=&5R(&$@8V%N;VYI8V%L(&YA;64B+`H))V1N<U]A9&1?7V5N=&5R
M7V1O;5]N86UE)R`]/B`B16YT97(@9&]M86EN(&YA;64B+`H))V1N<U]A9&1?
M7V5N=&5R7VEP7V%D9')E<W,G(#T^(")%;G1E<B!)4"!A9&1R97-S(BP*"2=D
M;G-?861D7U]E;G1E<E]I<%]M87-K)R`]/B`B16YT97(@25`O;6%S:R(L"@DG
M9&YS7V%D9%]?96YT97)?;6%I;%]D;VUA:6XG(#T^(")%;G1E<B!M86EL(&1O
M;6%I;B(L"@DG9&YS7V%D9%]?96YT97)?;6%I;%]E>&-H86YG97(G(#T^(")%
M;G1E<B!M86EL(&5X8VAA;F=E<B(L"@DG9&YS7V%D9%]?96YT97)?;F%M97-E
M<G9E<B<@/3X@(D5N=&5R(&YA;65S97)V97(B+`H))V1N<U]A9&1?7V5N=&5R
M7W1X=%]R96-O<F0G(#T^(")%;G1E<B!46%0@<F5C;W)D(BP*"2=D;G-?861D
M7U]I;G9A;&ED7VEP)R`]/B`B25`@861D<F5S<R!I<R!I;G9A;&ED+B(L"@DG
M9&YS7V%D9%]?;&]W)R`]/B`B;&]W(BP*"2=D;G-?861D7U]M86EL7V1O;5]N
M86UE7VES7VEN=F%L:60G(#T^(")-86EL(&1O;6%I;B!N86UE(&ES(&EN=F%L
M:60N(BP*"2=D;G-?861D7U]N86UE<V5R=F5R7VES7VEN=F%L:60G(#T^(").
M86UE<V5R=F5R(&ES(&EN=F%L:60N(BP*"2=D;G-?861D7U]R96-O<F0G(#T^
M("(E,2!R96-O<F0B+`H))V1N<U]A9&1?7W-E;&5C=%]P<F5F97)?9F]R7VUA
M:6Q?97AC:&%N9V5?<V5R=F5R)R`]/B`B4W!E8VEF>2!P<FEO<FET>2!O9B!M
M86EL(&5X8VAA;F=E('-E<G9E<B(L"@DG9&YS7V%D9%]?=6YA8FQE7VEN<V5R
M=%]N97=?9&YS7W)E8R<@/3X@(E5N86)L92!T;R!I;G-E<G0@;F5W($1.4R!R
M96-O<F0Z("4Q(BP*"2=D;G-?861D7U]V97)Y7VAI9V@G(#T^(")V97)Y(&AI
M9V@B+`H))V1N<U]C:&5C:U]?=&5S=%]D;G-?>F]N92<@/3X@(E1E<W0@1$Y3
M('IO;F4@)3$@;VX@)3(B+`H))V1N<U]C:&5C:U]?=6YA8FQE7V=E=%]D;VU?
M<')O<&5R=&EE<R<@/3X@(E5N86)L92!T;R!R971R:65V92!D;VUA:6X@<')O
M<&5R=&EE<SH@)3$B+`H))V1O;5]C=')L7U]A;&QO=V5D)R`]/B`B06QL;W=E
M9"(L"@DG9&]M7V-T<FQ?7V1B)R`]/B`B1&%T86)A<V5S(BP*"2=D;VU?8W1R
M;%]?9&5L7VAS=%]O;E]D;VTG(#T^(")!<F4@>6]U('-U<F4@>6]U('=A;G0@
M=&\@<F5M;W9E(&AO<W1I;F<@8V]N9FEG=7)A=&EO;B!F<F]M(&1O;6%I;B`E
M,3\B+`H))V1O;5]C=')L7U]D:7-K7W-P86-E)R`]/B`B1&ES:R!S<&%C92(L
M"@DG9&]M7V-T<FQ?7V1O;5]A9&TG(#T^(")$;VUA:6X@)3$@;V8@)3(B+`H)
M)V1O;5]C=')L7U]D;VU?8VPG(#T^(")$;VUA:6X@)3$B+`H))V1O;5]C=')L
M7U]D;VUA:6Y?:&%S7V9O<G=A<F1I;F=?=VET:%]U;F1E9FEN961?9G=D7W5R
M;"<@/3X@(D1O;6%I;B!H87,@9F]R=V%R9&EN9R!S970@=7`@=VET:"!U;F1E
M9FEN960@9F]R=V%R9&EN9R!54DPB+`H))V1O;5]C=')L7U]D;VUA:6Y?:&%S
M7V9R86UE7V9O<G=A<F1I;F<G(#T^(")$;VUA:6X@:&%S(&9R86UE(&9O<G=A
M<F1I;F<@=&\@=&AE(%523"`E,2(L"@DG9&]M7V-T<FQ?7V1O;6%I;E]H87-?
M;F]?:&]S=&EN9R<@/3X@(D1O;6%I;B!H87,@;F\@:&]S=&EN9R!C;VYF:6=U
M<F5D(BP*"2=D;VU?8W1R;%]?9&]M86EN7VAA<U]P:'ES:6-A;%]H;W-T:6YG
M)R`]/B`B1&]M86EN(&AA<R!P:'ES:6-A;"!H;W-T:6YG(&]N($E0("4Q(BP*
M"2=D;VU?8W1R;%]?9&]M86EN7VAA<U]S=&%N9&%R9%]F;W)W87)D:6YG)R`]
M/B`B1&]M86EN(&AA<R!S=&%N9&%R9"!F;W)W87)D:6YG('1O('1H92!54DP@
M)3$B+`H))V1O;5]C=')L7U]M86EL;&ES=',G(#T^(")-86EL:6YG(&QI<W1S
M(BP*"2=D;VU?8W1R;%]?;6)O>&5S)R`]/B`B36%I;&)O>&5S(BP*"2=D;VU?
M8W1R;%]?;6<G(#T^(")-86EL(&=R;W5P<R(L"@DG9&]M7V-T<FQ?7W)E9&ER
M)R`]/B`B4F5D:7)E8W1S(BP*"2=D;VU?8W1R;%]?<F5S;W5R8V5?;F%M92<@
M/3X@(E)E<V]U<F-E(BP*"2=D;VU?8W1R;%]?<F5S<"<@/3X@(D%U=&]R97-P
M;VYD97)S(BP*"2=D;VU?8W1R;%]?<W5B9&]M)R`]/B`B4W5B9&]M86EN<R(L
M"@DG9&]M7V-T<FQ?7W1R869F:6,G(#T^(")4<F%F9FEC(BP*"2=D;VU?8W1R
M;%]?=6YA8FQE7V%C=&EV871E+V1E86-T:79A=&5?9&]M)R`]/B`B56YA8FQE
M('1O(&%C=&EV871E+V1E86-T:79A=&4@9&]M86EN.B`E,2(L"@DG9&]M7V-T
M<FQ?7W5S960G(#T^(")5<V5D(BP*"2=D;VU?8W1R;%]?=V5B87!P<R<@/3X@
M(DIA=F$@87!P;&EC871I;VYS(BP*"2=D;VU?8W1R;%]?>6]U7W=A;G1?8VAA
M;F=E7W1H95]S=&%T=7-?;V9?=&AE7V1O;6%I;C\_)R`]/B`B07)E('EO=2!S
M=7)E('EO=2!W86YT('1O(&-H86YG92!T:&4@<W1A=&4@;V8@9&]M86EN/R(L
M"@DO+R!E;F0@;V8@<V5R9V4@<&%R=`H*"2\O(&UA=F5R:6-K('!A<G0*"@DG
M9&]M7V-T<FQ?7W=U)R`]/B`B5V5B('5S97)S(BP*"2=D;VU?<')E9E]?8F]U
M;F-E7W=I=&A?<&AR87-E)R`]/B`B0F]U;F-E('=I=&@@;65S<V%G92(L"@DG
M9&]M7W!R969?7V-A=&-H7V%D9'(G(#T^(")&;W)W87)D('1O(&%D9')E<W,B
M+`H))V1O;5]P<F5F7U]R96IE8W0G(#T^("=296IE8W0G+`H))V1O;5]P<F5F
M7U]C;VYF:7)M7V1O;6%I;E]R96UO=FEN9R<@/3X@(E!L96%S92P@9&\@;F]T
M(&9O<F=E="!T;R!I;F9O<FT@=&AE(&1O;6%I;B!V:7-I=&]R<R!O9B!T:&4@
M9&]M86EN(&YA;64@8VAA;F=E+B!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@
M<F5N86UE('1H92!D;VUA:6X_(BP*"2=D;VU?<')E9E]?9&)?:6YC;VYS>7-T
M96YC>2<@/3X@(F1A=&%B87-E(&EN8V]N<VES=&5N8WDN(BP*"2=D;VU?<')E
M9E]?9&)S)R`]/B`B9&%T86)A<V5S(BP*"2=D;VU?<')E9E]?9&5L971E7W1R
M869F:6-?<W1A="<@/3X@(E)E=&%I;B!T<F%F9FEC('-T871I<W1I8W,B+`H)
M)V1O;5]P<F5F7U]D96QE=&5?=')A9F9I8U]S=&%T7V]L9&5R)R`]/B`B4F5T
M86EN('1R869F:6,@<W1A=&ES=&EC<R(L"@DG9&]M7W!R969?7V1O7VYO=%]U
M<V5?<WEM8F]L7V%P;W-T<F]F)R`]/B`B1&\@;F]T('5S92!A<&]S=')O<&AE
M+"!R979E<G-E(&%P;W-T<F]P:&4L('-E;6EC;VQO;B!O<B!E;7!T>2!V86QU
M92!I;B!T:&4@8F]U;F-E(&UE<W-A9V4@9FEE;&0N(BP*"2=D;VU?<')E9E]?
M9&]M7VQE=F5L7VYA;65?8V]N9FQI8W0G(#T^(")4:&4@9&]M86EN(&%D;6EN
M:7-T<F%T;W(G<R!L;V=I;B!N86UE(&-O;F9L:6-T<R!W:71H(&QO9VEN(&YA
M;64@;V8@;VYE(&]F('1H92!C;&EE;G1S+B(L"@DG9&]M7W!R969?7VEN=F%L
M:61?9&ES:U]S<&%C95]L:6UI="<@/3X@(DEN=F%L:60@9&ES:R!S<&%C92!L
M:6UI="XB+`H))V1O;5]P<F5F7U]I;G9A;&ED7V5X<&ER871I;VY?9&%T95]L
M:6UI="<@/3X@(DEN=F%L:60@=F%L:61I='D@<&5R:6]D+B(L"@DG9&]M7W!R
M969?7VEN=F%L:61?;6%X7W1R869F:6-?;&EM:70G(#T^("));G9A;&ED('1R
M869F:6,@;&EM:70N(BP*"2=D;VU?<')E9E]?;&EM:71S7V]F7V1O;2<@/3X@
M(DQI;6ET<R!F;W(@9&]M86EN("4Q(BP*"2=D;VU?<')E9E]?;6%I;%]G<G!S
M)R`]/B`B;6%I;"!G<F]U<',B+`H))V1O;5]P<F5F7U]M86EL7VYO;F5X:7-T
M96YT7W5S97(G(#T^(")-86EL('1O(&YO;F5X:7-T96YT('5S97(B+`H))V1O
M;5]P<F5F7U]M86EL7W)E9&ER<R<@/3X@(FUA:6P@<F5D:7)E8W1S(BP*"2=D
M;VU?<')E9E]?;6%I;%]R97-P<R<@/3X@(FUA:6P@875T;W)E<W!O;F1E<G,B
M+`H))V1O;5]P<F5F7U]M87A?;&EM:71?:7-?:6YV86QI9"<@/3X@(B4Q(&ES
M(&EN=F%L:60N(BP*"2=D;VU?<')E9E]?;6%X7VYU;5]O9E\E;V)J96-T<U]I
M<U]I;G9A;&ED)R`]/B`B36%X:6UU;2!N=6UB97(@;V8@)3$@:7,@:6YV86QI
M9"XB+`H))V1O;5]P<F5F7U]N97=?;&EM:71?;&5S<U]C=7)R96YT;'E?=7-E
M9"<@/3X@(B4Q.B!R97%U97-T960@+2`E,BP@8W5R<F5N=&QY('5S960@+2`E
M,R(L"@DG9&]M7W!R969?7V]L9&5R7W1H870G(#T^("(@9F]R("(L"@DG9&]M
M7W!R969?7W!O<W1B;WAE<R<@/3X@(FUA:6QB;WAE<R(L"@DG9&]M7W!R969?
M7W!R969E<F5N8V5S7V]F7V1O;2<@/3X@(E!R969E<F5N8V5S(&9O<B!D;VUA
M:6X@)3$B+`H))V1O;5]P<F5F7U]R961I<F5C=%]T;U]I='-E;&8G(#T^(")4
M:&4@9&]M86EN('=I;&P@:&%V92!T:&4@9F]R=V%R9&EN9R!S970@=&\@:71S
M96QF(BP*"2=D;VU?<')E9E]?=')A9E]S=&%T7W=I;&Q?;F]T7V1E;&5T92<@
M/3X@(E1R869F:6,@<W1A=&ES=&EC<R!W:6QL(&YO="!B92!D96QE=&5D+B(L
M"@DG9&]M7W!R969?7W1R869F:6-?;&]G9VEN9U]P97)I;V1?8V]U;&1N=%]B
M95]L;W=E<B<@/3X@(EEO=2!S<&5C:69I960@=&AE(&1O;6%I;B!T<F%F9FEC
M('-T871I<W1I8W,@<F5T96YT:6]N('1I;64@=&\@8F4@;&5S<R!T:&%N('1H
M92!T;W1A;"!V86QU92!D969I;F5D(&9O<B!T:&4@<V5R=F5R("@E,2!M;VYT
M:"AS*2DN(%1H92!S=&%T:7-T:6-S(')E=&5N=&EO;B!P97)I;V0@:7,@<V5T
M(&5Q=6%L('1O('1H92!D969A=6QT('9A;'5E(&9O<B!T:&4@<V5R=F5R("@E
M,2!M;VYT:"AS*2DN(BP*"2=D;VU?<')E9E]?=6YA8FQE7V%D9%]W=W=?<')E
M9FEX7VEN7V1O;2<@/3X@(E5N86)L92!T;R!A9&0@82!W=W<@<')E9FEX('1O
M(&1O;6%I;CH@)3$B+`H))V1O;5]P<F5F7U]U;F%B;&5?9&5F:6YE7W!H>7-I
M8V%L7VAS=%]P87)A;2<@/3X@(E5N86)L92!T;R!D969I;F4@<&AY<VEC86P@
M:&]S=&EN9R!P87)A;65T97)S.B`E,2(L"@DG9&]M7W!R969?7W5N86)L95]R
M96YA;65?9&]M86EN)R`]/B`B56YA8FQE('1O(')E;F%M92!T:&4@9&]M86EN
M(BP*"2=D;VU?<')E9E]?=6YA8FQE7W-E=%]U<%]M8F]X7W%U;W1A)R`]/B`B
M56YA8FQE('1O('-E="!T:&4@;6%I;&)O>"!Q=6]T82!F;W(@=&AI<R!D;VUA
M:6XZ("4Q(BP*"2=D;VU?<')E9E]?=6YA8FQE7W-E=%]U<%]W96)?=7-E<E]S
M8W)I<'0G(#T^(")5;F%B;&4@=&\@<V5T('5P('-C<FEP=&EN9R!F;W(@=V5B
M('5S97)S.B`E,2(L"@DG9&]M7W!R969?7W5N;&EM:71E9"<@/3X@(E5N;&EM
M:71E9"(L"@DG9&]M7W!R969?7W=E8E]U<W)S)R`]/B`B=V5B('5S97)S(BP*
M"2=D;VU?<')E9E]?=V5B=7-E<G-?<V-R:7!T)R`]/B`B06QL;W<@=&AE('=E
M8B!U<V5R<R!S8W)I<'1I;F<B+`H))V1O;5]P<F5F7U]Y;W5?86QR96%D>5]H
M879E7R5O8FIE8W0G(#T^(")9;W4@86QR96%D>2!H879E("4Q(BP*"2=D;VU?
M8VQI7U]W87)N:6YG7VEG;F]R95]Q=6]T82<@/3X@)U=!4DY)3D<Z($]P=&EO
M;B`B+6AA<F1?<75O=&$B(&ES(&EG;F]R960Z(&AA<F0@9&ES:R!Q=6]T82!I
M<R!N;W0@<W5P<&]R=&5D)RP*"2=D;VU?=7-E<E]C;&EE;G1?;&]G:6Y?97AI
M<W0G(#T^(")5;F%B;&4@=&\@86QL;W<@9&]M86EN(&%D;6EN:7-T<F%T;W(G
M<R!A8V-E<W,@=&\@8V]N=')O;"!P86YE;"!O;B!T:&4@9&]M86EN("4Q.B!L
M;V=I;B!N86UE(&ES(&%L<F5A9'D@:6X@=7-E+B(L"@DG9&]M7W1R869F:6-?
M:&ES=&]R>5]?=&ET;&4G(#T^(")$;VUA:6X@/'-P86X@8VQA<W,]7")N86UE
M7"(^)3$\+W-P86X^('1R869F:6,@:&ES=&]R>2XB+`H))V1O;6%I;E]?<W5B
M9&]M86EN7V5X:7-T<R<@/3X@(E1H97)E(&ES(&$@<W5B9&]M86EN('=I=&@@
M;F%M92`E,2XE,BXB+`H))V1O;6%I;E]?9&%L:6%S7V5X:7-T<R<@/3X@(E1H
M97)E(&ES(&$@9&]M86EN(&%L:6%S('=I=&@@;F%M92`E,2XE,BXB+`H))V1O
M;6%I;E]?=6YA8FQE7W1O7W1U<FY?;VY?<V5R=FEC92<@/3X@(D9A:6QE9"!T
M;R!E;F%B;&4@=&AE("4Q('-E<G9I8V4B+`H))V1O;6%I;G-?7V-H86YG95]T
M:&5?<W1A='5S7V]F7V1O;6%I;C\G(#T^(")!<F4@>6]U('-U<F4@>6]U('=A
M;G0@=&\@8VAA;F=E('1H92!S=&%T=7,@;V8@9&]M86EN("4Q/R(L"@DG9&]M
M86EN<U]?8VQI96YT7VEN9F\G(#T^("(E,2!D;VUA:6YS+"`E,B!A8W1I=F4@
M9&]M86EN<RP@)3,@9&ES:R!S<&%C92!U<V5D+"`E-"!T<F%F9FEC('5S960B
M+`H))V1O;6%I;G-?7V-L:65N=%]I;F9O7VAI9&EN9U]T<F%F9FEC)R`]/B`B
M)3$@9&]M86EN<RP@)3(@86-T:79E(&1O;6%I;G,L("4S(&1I<VL@<W!A8V4@
M=7-E9"(L"@DG9&]M86EN<U]?<F5M;W9E7V1O;2<@/3X@(E1H92!F;VQL;W=I
M;F<@9&]M86EN<R!W:6QL(&)E(')E;6]V960Z(BP*"2=D;VUA:6YS7U]R96UO
M=F5?9&]M7V9O<E]C;"<@/3X@(E1H92!F;VQL;W=I;F<@9&]M86EN<R!O=VYE
M9"!B>2!C;&EE;G0@)3$@=VEL;"!B92!R96UO=F5D.B(L"@DG9&]M86EN<U]?
M<V5L96-T7V1O;5]F;W)?<F5M;W9E)R`]/B`B4V5L96-T(&1O;6%I;G,@=&\@
M8F4@<F5M;W9E9"XB+`H))V1O;6%I;G-?7W5N86)L95]T;U]C:&%N9V5?8VQI
M96YT7W-T871U<R<@/3X@(E5N86)L92!T;R!C:&%N9V4@=&AE(&-L:65N="!A
M8V-O=6YT('-T871U<SH@)3$B+`H))V1O;6%I;G-?7W5N86)L95]U<&1A=&5?
M87!A8VAE7W-E='1I;F=S)R`]/B`B56YA8FQE('1O('5P9&%T92!!<&%C:&4@
M<V5T=&EN9W,B+`H))V1O;6%I;G-?7WEO=5]D;U]N;W1?:&%V95]P97)M:7-S
M:6]N<U]T;U]D96QE=&5?9&]M86EN<R<@/3X@(EEO=2!D;R!N;W0@:&%V92!P
M97)M:7-S:6]N<R!T;R!D96QE=&4@9&]M86EN<RXB+`H))V1O;6%I;G-?7WEO
M=5]W86YT7V-H86YG95]T:&5?<W1A='5S7V]F7W1H95]C;#\_)R`]/B`B07)E
M('EO=2!S=7)E('EO=2!W86YT('1O(&-H86YG92!T:&4@<W1A=&4@;V8@8VQI
M96YT(&%C8V]U;G0_(BP*"2=D;VUA:6YS7U]Y;W5?=V%N=%]C:&%N9V5?=&AE
M7V-P7V%C8V5S<U]O9E]T:&5?8VP_/R<@/3X@(D%R92!Y;W4@<W5R92!Y;W4@
M=V%N="!T;R!P97)F;W)M('1H:7,@;W!E<F%T:6]N/R(L"@DG9&]M86EN<U]L
M:7-T7U]U;F%B;&5?<F5M;W9E7V1O;7,G(#T^(")5;F%B;&4@=&\@<F5M;W9E
M(&1O;6%I;G,Z("4Q(BP*"2=D;VUA:6YT<F%F9FEC;&ES=%]H96%D97)?;V9?
M9&]M86EN7U\G(#T^(")4<F%F9FEC(&%T(&1O;6%I;B`E,2(L"@DG9'-?7V%N
M;VYY;6]U<U]F='`G(#T^(")!;F]N>6UO=7,@1E10(BP*"2=D<G=E8E]?<&%G
M971I=&QE)R`]/B`G1'(N5V5B($%N=&EV:7)U<R!0<F5F97)E;F-E<R<L"@DG
M9')W96)?7V1R=V5B)R`]/B`G06YT:79I<G5S(&UA:6P@8VAE8VMI;F<G+`H)
M)V1R=V5B7U]D<G=E8E]D:7)E8W1I;VXG(#T^("=#:&5C:VEN9R!M86EL(&9O
M<B!V:7)U<V5S)RP*"2=D<G=E8E]?9')W96)?9&ER96-T:6]N7V]F9B<@/3X@
M)T1I<V%B;&5D)RP*"2=D<G=E8E]?9')W96)?9&ER96-T:6]N7V%N>2<@/3X@
M)TEN8V]M:6YG(&%N9"!O=71G;VEN9R!M86EL)RP*"2=D<G=E8E]?9')W96)?
M9&ER96-T:6]N7V9R;VTG(#T^("=/=71G;VEN9R!M86EL(&]N;'DG+`H))V1R
M=V5B7U]D<G=E8E]D:7)E8W1I;VY?=&\G(#T^("=);F-O;6EN9R!M86EL(&]N
M;'DG+`H))V1R=V5B7U]D:7-A8FQE7W)E87-O;E]K97DG(#T^("=$<BY796(@
M:7,@;F]T('-U<'!O<G1E9"!B>2!T:&4@;&EC96YS92!K97DN)RP*"2=D<G=E
M8E]?9&ES86)L95]R96%S;VY?<&5R;2<@/3X@)UEO=2!H879E(&YO('!E<FUI
M<W-I;VX@=&\@;6%N86=E($1R+E=E8B!A;G1I=FER=7,N)RP*"2=D<G=E8E]?
M9&ES86)L95]R96%S;VY?:6YS=&%L;"<@/3X@)T1R+E=E8B!A;G1I=FER=7,@
M:7,@;F]T(&EN<W1A;&QE9"XG+`H))V1S7U]D;G,G(#T^(")$3E,@6F]N92(L
M"@DG9'-?7VUA:6PG(#T^(")-86EL(BP*"2=D<U]?=&]M8V%T)R`]/B`B5&]M
M8V%T(BP*"2=D<W)?7V]F7V-L:65N=%]T:71L92<@/3X@(D1O;6%I;B!3=6UM
M87)Y(%)E<&]R="!O9B`E,2(L"@DG9'-R7U]R97!O<G1?:&%S7V)E96Y?<V5N
M=%]E;6%I;"<@/3X@(D1O;6%I;B!3=6UM87)Y(%)E<&]R="!H87,@8F5E;B!S
M96YT('1O(&4M;6%I;#H@)3$B+`H))V1S<E]?=&ET;&4G(#T^(")$;VUA:6X@
M4W5M;6%R>2!297!O<G0B+`H))V1U;7!?9FEL95]?<F5M;W9E)PD]/B`B4F5M
M;W9E(BP*"2=D=6UP7V9I;&5?7V%D9"<)/3X@(E-P96-I9GD@=&AE(&YE>'0@
M=F]L=6UE(BP*"2=D=6UP<U]L:7-T7U]D96QE=&EO;E]P86=E7W1I=&QE)R`]
M/B`B5&AE(&9O;&QO=VEN9R!B86-K=7`@9FEL97,@;V8@9&]M86EN("4Q('=I
M;&P@8F4@<F5M;W9E9#HB+`H))V1U;7!S7VQI<W1?7W5P;&%D7V1U;7!?9FEL
M97,G(#T^(")5<&QO860@8F%C:W5P(&9I;&4B+`H))V1U;7!S7VQI<W1?7V1U
M;7!?9FEL97,G(#T^(")"86-K=7`@9FEL97,B+`H))V1U;7!S7VQI<W1?7V1U
M;7!F:6QE7V%L<F5A9'E?97AI<W1S)R`]/B`B5&AE(&9I;&4@)3$@86QR96%D
M>2!E>&ES=',N(BP*"2=D=6UP<U]L:7-T7U]D=6UP9FEL95]I<U]I;G9A;&ED
M)R`]/B`B5&AE(&9I;&4@)3$@:7,@;F]T(&$@=F%L:60@9&]M86EN(&)A8VMU
M<"!F:6QE+B(L"@DG9'5M<'-?;&ES=%]?<&%G95]T:71L92<@/3X@(D)A8VMU
M<"!F:6QE<R!R97!O<VET;W)Y(BP*"2=D=6UP<U]U<&QO861?7W!A9V5?=&ET
M;&4G(#T^(")5<&QO861I;F<@0F%C:W5P($9I;&5S('1O(%)E<&]S:71O<GDB
M+`H))V1U;7!S7VQI<W1?7W)E<&]S:71O<GE?:7-?;F]T7V5X:7-T)R`]/B`B
M0F%C:W5P(&9I;&5S(')E<&]S:71O<GD@9&]E<R!N;W0@97AI<W0B+`H))V1U
M;7!S7VQI<W1?7W1O=&%L7W-I>F4G(#T^(")4;W1A;"!S:7IE.B`E,2(L"@DG
M9'5M<'-?;&ES=%]?=6YA8FQE7W1O7W)E;6]V92<@/3X@(E5N86)L92!T;R!R
M96UO=F4@=&AE(&)A8VMU<"!F:6QE.B`E,2(L"@DG9'5M<'-?;&ES=%]?9'5M
M<&9I;&5?8V%N7V-O;F9L:6-T)R`]/B`B5&AE(&9I;&4@;F%M92!Y;W4@<W!E
M8VEF:65D(&-O;F9L:6-T<R!W:71H(&9I;&4@)3'"H%!L96%S92P@<W!E8VEF
M>2!A;F]T:&5R(&9I;&4@;F%M92XB+`H))V1U<W)?961?7V%L;&]W7V1L7W5S
M<E]A8V-E<W,G(#T^(")!;&QO=R!D;VUA:6X@861M:6YI<W1R871O<B=S(&%C
M8V5S<R(L"@DG9'5S<E]E9%]?:6YF;W)M871I;VXG(#T^(")%9&ET('1H92!P
M<F]P97)T:65S(&]F(&1O;6%I;B!A9&UI;FES=')A=&]R)W,@86-C;W5N="(L
M"@DG9'5S<E]E9%]?;&]C86QE)R`]/B`B1&]M86EN(&%D;6EN:7-T<F%T;W(G
M<R!L86YG=6%G92(L"@DG9'5S<E]E9%]?<VMI;B<@/3X@(D1O;6%I;B!A9&UI
M;FES=')A=&]R)W,@:6YT97)F86-E('-K:6XB+`H))V5S<U]?97)R;W(G(#T^
M(")%<G)O<B(L"@DG979E;G1?:&%N9&QE<E]E9&ET7U]T:71L92<@/3X@)T5V
M96YT($AA;F1L97(@4')O<&5R=&EE<R<L"@DG979E;G1?:&%N9&QE<G-?<F5M
M;W9E7U]T:71L92<@/3X@)U)E;6]V92!T:&4@<V5L96-T960@979E;G0@:&%N
M9&QE<G,G+`H))V5V96YT7VAA;F1L97)S7W)E;6]V95]?<V5L96-T7V5V96YT
M7VAA;F1L97)S7V9O<E]R96UO=F4G(#T^("=396QE8W0@=&AE(&5V96YT(&AA
M;F1L97)S('1O(&)E(')E;6]V960N)RP*"2=E=F5N=%]H86YD;&5R<U]L:7-T
M7U]T:71L92<@/3X@)T5V96YT($UA;F%G97(G+`H))V5X86UP;&5?7R<@/3X@
M(D5X86UP;&4Z("4Q(BP*"2=E>'1R87-?7V)U>5]N97=?:V5Y)R`]/B`B66]U
M<B!C=7)R96YT(&QI8V5N<V4@:V5Y(&1O97,@;F]T(&%L;&]W('EO=2!T;R!M
M;V1I9GD@=&AE<V4@;V)J96-T<RX@268@>6]U('=I<V@@=&\@8F4@86)L92!T
M;R!D;R!T:&%T+"!Y;W4@<VAO=6QD('!U<F-H87-E(&$@;F5W(&QI8V5N<V4@
M:V5Y(BP*"@DG9F5A='5R95]?9&5S:W1O<%]?:&5A9&5R)R`]/B`G1&5S:W1O
M<"<L"@DG9F5A='5R95]?9&5S:W1O<%]?861M:6XG(#T^("=4:&4@<&%G92!Y
M;W4@87)E(&-U<G)E;G1L>2!O;B!I<R!T:&4@;F5W('1A<VLM;W)I96YT960@
M1&5S:W1O<"P@=VAI8V@@9VEV97,@>6]U('%U:6-K(&%C8V5S<R!T;R!Y;W5R
M(&1A:6QY('1A<VMS+"!R97-O=7)C97,@=7-A9V4@<W1A=&ES=&EC<RP@86YD
M(&]F9F5R<R!A(&AA;F1Y('-T;W)A9V4@9F]R('EO=7(@9F%V;W)I=&4@<&QA
M8V5S(&EN(%!L97-K+B!$97-K=&]P(&ES(&%C8V5S<VEB;&4@9G)O;2!T:&4@
M;&5F="!M96YU(&%T(&%N>2!T:6UE+B<L"@DG9F5A='5R95]?9&5S:W1O<%]?
M8VQI96YT)R`]/B`G5&AE('!A9V4@>6]U(&%R92!C=7)R96YT;'D@;VX@:7,@
M=&AE(&YE=R!T87-K+6]R:65N=&5D($1E<VMT;W`L('=H:6-H(&=I=F5S('EO
M=2!Q=6EC:R!A8V-E<W,@=&\@>6]U<B!D86EL>2!T87-K<RP@<F5S;W5R8V5S
M('5S86=E('-T871I<W1I8W,L(&%N9"!O9F9E<G,@82!H86YD>2!S=&]R86=E
M(&9O<B!Y;W5R(&9A=F]R:71E('!L86-E<R!I;B!0;&5S:RX@1&5S:W1O<"!I
M<R!A8V-E<W-I8FQE(&9R;VT@=&AE(&QE9G0@;65N=2!A="!A;GD@=&EM92XG
M+`H))V9E871U<F5?7V1E<VMT;W!?7V1O;6%I;B<@/3X@)U1H92!P86=E('EO
M=2!A<F4@8W5R<F5N=&QY(&]N(&ES('1H92!N97<@=&%S:RUO<FEE;G1E9"!$
M97-K=&]P+"!W:&EC:"!G:79E<R!Y;W4@<75I8VL@86-C97-S('1O('EO=7(@
M9&%I;'D@=&%S:W,L(')E<V]U<F-E<R!U<V%G92!S=&%T:7-T:6-S+"!A;F0@
M;V9F97)S(&$@:&%N9'D@<W1O<F%G92!F;W(@>6]U<B!F879O<FET92!P;&%C
M97,@:6X@4&QE<VLN($1E<VMT;W`@:7,@86-C97-S:6)L92!F<F]M('1H92!L
M969T(&UE;G4@870@86YY('1I;64N)RP*"2=F96%T=7)E7U]D;VUA:6Y?86QI
M87-E<U]?:&5A9&5R)R`]/B`G1&]M86EN($%L:6%S97,G+`H))V9E871U<F5?
M7V1O;6%I;E]A;&EA<V5S7U]C;&EE;G0G(#T^("=4:&ES(&YE=R!F96%T=7)E
M(&%L;&]W<R!Y;W4@=&\@<V5T('5P(&%L=&5R;F%T:79E(&YA;65S(&9O<B!Y
M;W5R(&1O;6%I;G,@=VET:"!N;R!A9&1I=&EO;F%L(&-O<W0N($1O;6%I;B!A
M;&EA<V5S(&%C="!A<R!N:6-K;F%M97,@9F]R('EO=7(@=V5B<VET97,@86YD
M(&4M;6%I;"!A9&1R97-S97,N(%1H:7,@9F5A='5R92!I<R!A8V-E<W-I8FQE
M(&)Y('-E;&5C=&EN9R!A(&1O;6%I;B!O;B!Y;W5R($AO;64@4&%G92!A;F0@
M8VQI8VMI;F<@7"=$;VUA:6X@06QI87-E<UPG+B<L"@DG9F5A='5R95]?9&]M
M86EN7V%L:6%S97-?7V1O;6%I;B<@/3X@)U1H:7,@;F5W(&9E871U<F4@86QL
M;W=S('EO=2!T;R!S970@=7`@86QT97)N871I=F4@;F%M97,@9F]R('EO=7(@
M9&]M86EN('=I=&@@;F\@861D:71I;VYA;"!C;W-T+B!$;VUA:6X@86QI87-E
M<R!A8W0@87,@;FEC:VYA;65S(&9O<B!Y;W5R('=E8G-I=&4@86YD(&4M;6%I
M;"!A9&1R97-S97,N(%1H:7,@9F5A='5R92!I<R!A8V-E<W-I8FQE(&)Y(&-L
M:6-K:6YG(%PG1&]M86EN($%L:6%S97-<)R!O;B!Y;W5R($AO;64@<&%G92XG
M+`H))V9E871U<F5?7V1O;6%I;E]A;&EA<V5S7U]Q=6EC:U]L:6YK)R`]/B`G
M1V\@=&\@1&]M86EN($%L:6%S97,@;6%N86=E;65N="<L"@DG9F5A='5R95]?
M=V%T8VAD;V<R7U]H96%D97(G(#T^("=7871C:&1O9R`R+C`G+`H))V9E871U
M<F5?7W=A=&-H9&]G,E]?861M:6XG(#T^("=4:&4@<V5C;VYD(&5D:71O;B!O
M9B!7871C:&1O9R!M;V1U;&4@(&UO;FET;W)S('9I=&%L(%!L97-K('-E<G9I
M8V5S(&QI:V4@07!A8VAE(%=E8B!397)V97(L(&YO=&EF>6EN9R!Y;W4@=FEA
M(&4M;6%I;"!I;B!C87-E(&]F('-E<G9I8V4@:7-S=65S+B!7871C:&1O9R`R
M+C`@;F]W(&%L<V\@;6]N:71O<G,@>6]U<B!H87)D(&1I<VMS('1O(&5N<W5R
M92!Y;W4@=V]N7"=T(')U;B!O=70@;V8@<W1O<F%G92!U;F5X<&5C=&5D;'DL
M('-C86YS('EO=7(@<V5R=F5R(&9O<B!S96-U<FET>2!V=6QN97)A8FEL:71I
M97,@<W5C:"!A<R!R;V]T:VET<RP@8F%C:V1O;W)S(&%N9"!L;V-A;"!E>'!L
M;VET<RP@86YD(&1I<W!L87ES($-052!A;F0@4D%-('5S86=E('-T871I<W1I
M8W,N(%1O(&%C8V5S<R!7871C:&1O9R`R+C`L(&-L:6-K($UO9'5L97,@:6X@
M=&AE(&QE9G0@;65N=2P@=&AE;B!C;&EC:R!7871C:&1O9R!O;B!T:&4@($UO
M9'5L97,@<&%G92XG+`H))V9E871U<F5?7W=A=&-H9&]G,E]?<75I8VM?;&EN
M:R<@/3X@)T=O('1O(%=A=&-H9&]G(#(N,"<L"@DG9F5A='5R95]?<F5M;W1E
M7V1B7U]H96%D97(G(#T^("=296UO=&4@1&%T86)A<V4@2&]S=&EN9R<L"@DG
M9F5A='5R95]?<F5M;W1E7V1B7U]A9&UI;B<@/3X@)TEN(&%D9&ET:6]N('1O
M(&AO<W1I;F<@;&]C86P@9&%T86)A<V5S+"!0;&5S:R`X(&-A;B!H;W-T('5S
M97)S7"<@9&%T82!O;B!R96UO=&4@9&%T86)A<V4@<V5R=F5R<RX@66]U(&-A
M;B!E=F5N(&AA=F4@<V5V97)A;"!0;&5S:R!S97)V97)S(&AO<W1I;F<@=&AE
M:7(@=7-E<G-<)R!D871A8F%S97,@;VX@82!S:6YG;&4@9&5D:6-A=&5D(&UA
M8VAI;F4N($)O=&@@37E344P@*&EN8VQU9&EN9R!->5-13"`T+C$I(&%N9"!0
M;W-T9W)E4U%,(&%R92!S=7!P;W)T960N(%1O(&%C8V5S<R!$871A8F%S92!3
M97)V97)S(&UA;F%G96UE;G0@<&%G92P@8VQI8VL@1&%T86)A<V4@4V5R=F5R
M<R!O;B!397)V97(@061M:6YI<W1R871I;VX@<&%G92XG+`H))V9E871U<F5?
M7W)E;6]T95]D8E]?<75I8VM?;&EN:R<@/3X@)T=O('1O($1A=&%B87-E(%-E
M<G9E<G,@;6%N86=E;65N="<L"@DG9F5A='5R95]?;6%I;%]Q=65U95]?:&5A
M9&5R)R`]/B`G36%I;"!1=65U92!-86YA9V5M96YT)RP*"2=F96%T=7)E7U]M
M86EL7W%U975E7U]A9&UI;B<@/3X@)U1H:7,@;F5W(&9E871U<F4@86QL;W=S
M(&%D;6EN:7-T<F%T;W)S('1O(&UA;F%G92!T:&4@46UA:6P@;65S<V%G92!Q
M=65U92!D:7)E8W1L>2!F<F]M(%!L97-K+B!7:71H('1H:7,@9F5A='5R92P@
M>6]U(&-A;B!M86YU86QL>2!D96QE=&4@<W!A;2!A;F0@;W1H97(@=6YW86YT
M960@;6%I;"!F<F]M('1H92!Q=65U92P@=7-I;F<@<75I8VL@86YD(&EN='5I
M=&EV92!S;W)T:6YG(&]P=&EO;G,N(%1O(&%C8V5S<R!-86EL('%U975E(&UA
M;F%G96UE;G0@<&%G92P@8VQI8VL@36%I;"!O;B!T:&4@4V5R=F5R($%D;6EN
M:7-T<F%T:6]N('!A9V4@86YD('-E;&5C="!T:&4@36%I;"!1=65U92!T86(N
M)RP*"2=F96%T=7)E7U]M86EL7W%U975E7U]Q=6EC:U]L:6YK)R`]/B`G1V\@
M=&\@36%I;"!1=65U92!M86YA9V5M96YT)RP*"2=F96%T=7)E7U]S;V%?7VAE
M861E<B<@/3X@)T1.4R!33T$@4F5C;W)D<R!-86YA9V5M96YT)RP*"2=F96%T
M=7)E7U]S;V%?7V-L:65N="<@/3X@)U-T87)T($]F($%U=&AO<FET>2`H4T]!
M*2!R96-O<F1S(&%R92!S<&5C:6%L('1Y<&4@;V8@1$Y3(')E8V]R9',@=&AA
M="!D969I;F4@=&AE('!A<F%M971E<G,@;V8@1$Y3(')E8V]R9',@8V%C:&EN
M9RX@4W1A<G1I;F<@=VET:"!0;&5S:R`X+"!Y;W4@:&%V92!F=6QL(&-O;G1R
M;VP@;W9E<B!$3E,@4T]!(')E8V]R9',L('=H:6-H(&QE=',@>6]U('-P96-I
M9GD@=F%R:6]U<R!T:6UE;W5T<R!T;R!F:6YE+71U;F4@=&AE(&1O;6%I;B!N
M86UE('-E<G9I8V4N(%1O(&%C8V5S<R!33T$@<F5C;W)D<R!M86YA9V5M96YT
M+"!S96QE8W0@82!D;VUA:6X@;VX@>6]U<B!(;VUE('!A9V4L(&-L:6-K($1.
M4R!A;F0@8VQI8VL@4T]!(%!R969E<F5N8V5S+B<L"@DG9F5A='5R95]?<V]A
M7U]D;VUA:6XG(#T^("=3=&%R="!/9B!!=71H;W)I='D@*%-/02D@<F5C;W)D
M<R!A<F4@<W!E8VEA;"!T>7!E(&]F($1.4R!R96-O<F1S('1H870@9&5F:6YE
M('1H92!P87)A;65T97)S(&]F($1.4R!R96-O<F1S(&-A8VAI;F<N(%-T87)T
M:6YG('=I=&@@4&QE<VL@."P@>6]U(&AA=F4@9G5L;"!C;VYT<F]L(&]V97(@
M1$Y3(%-/02!R96-O<F1S+"!W:&EC:"!L971S('EO=2!S<&5C:69Y('9A<FEO
M=7,@=&EM96]U=',@=&\@9FEN92UT=6YE('1H92!D;VUA:6X@;F%M92!S97)V
M:6-E+B!4;R!A8V-E<W,@4T]!(')E8V]R9',@;6%N86=E;65N="P@8VQI8VL@
M1$Y3(&]N('EO=7(@2&]M92!P86=E(&%N9"!C;&EC:R!33T$@4')E9F5R96YC
M97,N)RP*"2=F96%T=7)E7U]S;V%?7W%U:6-K7VQI;FLG(#T^("=';R!T;R!3
M3T$@4F5C;W)D<R!M86YA9V5M96YT('!A9V4G+`H*"2=F:6QE;6%N86=E<E]?
M:71E;7,G(#T^("=F:6QE<R!A;F0@9&ER96-T;W)I97,@:6X@)3$G+`H))V9I
M;&5M86YA9V5R7U]C:&1I<E]E<G)O<E]?)R`]/B`B56YA8FQE('1O(&-H86YG
M92!D:7)E8W1O<GD@=&\@)3$Z("4R(BP*"2=F:6QE;6%N86=E<E]?8VAM;V1?
M9&ER)R`]/B`B0VAA;F=E('!E<FUI<W-I;VYS(&9O<B!D:7)E8W1O<GD@)3$B
M+`H))V9I;&5M86YA9V5R7U]C:&UO9%]E<G)O<E]?)R`]/B`B56YA8FQE('1O
M(&-H86YG92!P97)M:7-S:6]N<R!F;W(@9FEL92`E,3H@)3(B+`H))V9I;&5M
M86YA9V5R7U]C:&UO9%]F:6QE)R`]/B`B0VAA;F=E('!E<FUI<W-I;VYS(&9O
M<B!F:6QE("4Q(BP*"2=F:6QE;6%N86=E<E]?8V]P>5]E<G)O<E]?)R`]/B`B
M56YA8FQE('1O(&-O<'D@)3$@=&\@)3(Z("4S(BP*"2=F:6QE;6%N86=E<E]?
M8V]P>5]M;W9E)R`]/B`B0V]P>2`H;6]V92D@9FEL97,@9G)O;2`E,2(L"@DG
M9FEL96UA;F%G97)?7V-O=6YT7W-I>F5?7R<@/3X@)U-E;&5C=&EO;B!S:7IE
M.B`E,2<L"@DG9FEL96UA;F%G97)?7V-O=6YT7W-I>F5?97)R;W)?7R<@/3X@
M)U5N86)L92!T;R!C86QC=6QA=&4@<VEZ92!F;W(@)3$Z("4R)RP*"2=F:6QE
M;6%N86=E<E]?8V]U;G1?<VEZ95]N;W1E)R`]/B`G5&AE('1O=&%L('-I>F4@
M;V8@9FEL97,@86YD('-U8F1I<F5C=&]R:65S+B<L"@DG9FEL96UA;F%G97)?
M7V-R96%T95]D:7(G(#T^(")$:7)E8W1O<GD@8W)E871I;VXB+`H))V9I;&5M
M86YA9V5R7U]C<F5A=&5?9&ER7V5R<F]R7U\G(#T^(")5;F%B;&4@=&\@8W)E
M871E(&1I<F5C=&]R>2`E,3H@)3(B+`H))V9I;&5M86YA9V5R7U]C<F5A=&5?
M9FEL92<@/3X@(D9I;&4@8W)E871I;VXB+`H))V9I;&5M86YA9V5R7U]C<F5A
M=&5?9FEL95]?)R`]/B`B0W)E871E(&9I;&4@)3$B+`H))V9I;&5M86YA9V5R
M7U]C<F5A=&5?9FEL95]E<G)O<E]?)R`]/B`B56YA8FQE('1O(&-R96%T92!F
M:6QE("4Q.B`E,B(L"@DG9FEL96UA;F%G97)?7V-R96%T95]F:6QE7VAT;6PG
M(#T^(")5<V4@:'1M;"!T96UP;&%T92(L"@DG9FEL96UA;F%G97)?7V1E;6\G
M(#T^(")4:&ES(&]P97)A=&EO;B!I<R!N;W0@879A:6QA8FQE(&EN('1H92!D
M96UO('9E<G-I;VXN(BP*"2=F:6QE;6%N86=E<E]?9&5S=&EN871I;VXG(#T^
M(")$97-T:6YA=&EO;B(L"@DG9FEL96UA;F%G97)?7V1I<E]N;W1?97AI<W1S
M)R`]/B`B1&ER96-T;W)Y("4Q(&1O97,@;F]T(&5X:7-T+B(L"@DG9FEL96UA
M;F%G97)?7V1I<FYA;64G(#T^(")$:7)E8W1O<GD@;F%M92(L"@DG9FEL96UA
M;F%G97)?7V9I;&5N86UE)R`]/B`B1FEL92!N86UE(BP*"2=F:6QE;6%N86=E
M<E]?:7-?;F]?<W5C:"<@/3X@(E1H97)E(&ES(&YO(&9I;&4@;W(@9&ER96-T
M;W)Y('=I=&@@;F%M92`E,2(L"@DG9FEL96UA;F%G97)?7V)I;F%R>5]D871A
M7V%C8V5S<R<@/3X@)U1H:7,@9FEL92!M87D@8F4@82!B:6YA<GD@9FEL92X@
M1&\@>6]U('=A;G0@=&\@;W!E;B!I=#\G+`H))V9I;&5M86YA9V5R7U]E9&ET
M)R`]/B`B161I="!F:6QE("4Q(BP*"2=F:6QE;6%N86=E<E]?961I=%]E<G)O
M<E]?)R`]/B`B56YA8FQE('1O(&5D:70@9FEL92`E,3H@)3(B+`H))V9I;&5M
M86YA9V5R7U]E;7!T>5]S96QE8W1I;VXG(#T^(").;R!F:6QE*',I('-E;&5C
M=&5D+B(L"@DG9FEL96UA;F%G97)?7V9I;&5?97AI<W1S)R`]/B`B1FEL92`E
M,2!A;')E861Y(&5X:7-T<RXB+`H))V9I;&5M86YA9V5R7U]M;W9E7V5R<F]R
M7U\G(#T^(")5;F%B;&4@=&\@;6]V92`E,2!T;R`E,CH@)3,B+`H))V9I;&5M
M86YA9V5R7U]N97=?9&ER)R`]/B`B1&ER96-T;W)Y(&YA;64B+`H))V9I;&5M
M86YA9V5R7U]N97=?9&ER7W1I=&QE)R`]/B`B0W)E871E(&YE=R!D:7)E8W1O
M<GD@:6X@)3$B+`H))V9I;&5M86YA9V5R7U]N97=?9FEL95]T:71L92<@/3X@
M(D-R96%T92!N97<@9FEL92!I;B`E,2(L"@DG9FEL96UA;F%G97)?7VYO=%]A
M;&QO=V5D)R`]/B`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C:&%N9V4@<&5R
M;6ES<VEO;G,@9F]R('1H92!F:6QE+B(L"@DG9FEL96UA;F%G97)?7W)?;6]D
M92<@/3X@(E)E860@;6]D92(L"@DG9FEL96UA;F%G97)?7W)?<&5R;5]D:7(G
M(#T^("),:7-T(&1I<F5C=&]R>2(L"@DG9FEL96UA;F%G97)?7W)?<&5R;5]F
M:6QE)R`]/B`B4F5A9"!D871A(BP*"2=F:6QE;6%N86=E<E]?<F5M;W9E)R`]
M/B`B4F5M;W9E(&9I;&5S(&9R;VT@)3$B+`H))V9I;&5M86YA9V5R7U]R96UO
M=F5?97)R;W)?7R<@/3X@(E5N86)L92!T;R!R96UO=F4@9FEL92`E,3H@)3(B
M+`H))V9I;&5M86YA9V5R7U]R96YA;65?9&ER)R`]/B`B4F5N86UE(&1I<F5C
M=&]R>2`E,2(L"@DG9FEL96UA;F%G97)?7W)E;F%M95]E<G)O<E]?)R`]/B`B
M56YA8FQE('1O(')E;F%M92`E,2!T;R`E,CH@)3,B+`H))V9I;&5M86YA9V5R
M7U]R96YA;65?9FEL92<@/3X@(E)E;F%M92!F:6QE("4Q(BP*"2=F:6QE;6%N
M86=E<E]?<V5T7W=I;E]P97)M:7-S:6]N<U]D:7(G(#T^(")3970@<&5R;6ES
M<VEO;G,@9F]R("4Q(&9O;&1E<B(L"@DG9FEL96UA;F%G97)?7W-E=%]W:6Y?
M<&5R;6ES<VEO;G-?9FEL92<@/3X@(E-E="!P97)M:7-S:6]N<R!F;W(@)3$@
M9FEL92(L"@DG9FEL96UA;F%G97)?7W-H;W<G(#T^(")3:&]W(&9I;&4@)3$B
M+`H))V9I;&5M86YA9V5R7U]S:&]W7V5R<F]R7U\G(#T^(")5;F%B;&4@=&\@
M<VAO=R!F:6QE("4Q.B`E,B(L"@DG9FEL96UA;F%G97)?7W-O=7)C92<@/3X@
M(E-O=7)C92(L"@DG9FEL96UA;F%G97)?7W1O=6-H7V-O;F9I<FTG(#T^(")!
M<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@8VAA;F=E('1H92!T:6UE<W1A;7`@
M;V8@=&AE('-E;&5C=&5D(&9I;&5S/R(L"@DG9FEL96UA;F%G97)?7W1O=6-H
M7V5R<F]R7U\G(#T^(")5;F%B;&4@=&\@8VAA;F=E('1H92!T:6UE<W1A;7`@
M9F]R(&9I;&4@)3$Z("4R(BP*"2=F:6QE;6%N86=E<E]?;F]?<&5R;7-?;W)?
M=6YS=7!P;W)T961?9FEL95]T>7!E)R`]/B`G56YA8FQE('1O(')E860@=&AE
M(&9I;&4@;W(@=&AE(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P;W)T960N)RP*
M"2=F:6QE;6%N86=E<E]?=7!L;V%D7V5R<F]R7U\G(#T^(")5;F%B;&4@=&\@
M=7!L;V%D("4Q('1O("4R.B`E,R(L"@DG9FEL96UA;F%G97)?7W5P;&]A9%]F
M:6QE)R`]/B`B57!L;V%D(&9I;&4B+`H))V9I;&5M86YA9V5R7U]U<&QO861?
M9FEL95]S<F,G(#T^(")&:6QE('-O=7)C92(L"@DG9FEL96UA;F%G97)?7W5S
M97)N86UE)R`]/B`B57-E<B(L"@DG9FEL96UA;F%G97)?7W=?;6]D92<@/3X@
M(E=R:71E(&UO9&4B+`H))V9I;&5M86YA9V5R7U]W7W!E<FU?9&ER)R`]/B`B
M0W)E871E(&9I;&5S(BP*"2=F:6QE;6%N86=E<E]?=U]P97)M7V9I;&4G(#T^
M(")7<FET92!D871A(BP*"2=F:6QE;6%N86=E<E]?>%]M;V1E)R`]/B`B17AE
M8W5T92]S96%R8V@@;6]D92(L"@DG9FEL96UA;F%G97)?7WA?<&5R;5]D:7(G
M(#T^(")4<F%V97)S92!D:7)E8W1O<GDB+`H))V9I;&5M86YA9V5R7U]X7W!E
M<FU?9FEL92<@/3X@(D5X96-U=&4@9FEL92(L"@DG9FEL96UA;F%G97)?7W5N
M86)L95]T;U]R97-O;'9E7W)E86QP871H)R`]/B`B56YA8FQE('1O(')E<V]L
M=F4@<&%T:"!T;R!F:6QE("4Q(BP@+R]T;R!C:&5C:PH))V9I;&5M86YA9V5R
M7U]A8V-E<W-?=&]?<F5A;'!A=&A?9&5N:65D)R`]/B`B4&5R;6ES<VEO;B!D
M96YI960@=&\@)3$@+3X@)3(B+"`O+W1O(&-H96-K"@DG9V-H7U]A8W1I;VXG
M(#T^(")!8W1I;VXB+`H))V=C:%]?869T97)?9&5C<F5A<VEN9U]F;W)?=&AE
M7W9A;'5E7VYU;6)E<E]W:6QL7V)E8V%M95]N96=A=&EV92<@/3X@(D%F=&5R
M(&1E8W)E87-I;F<@=&AE('-P96-I9FEE9"!V86QU92P@:70@=VEL;"!B96-O
M;64@;F5G871I=F4N(BP*"2=G8VA?7V-A=&AE9V]R>2<@/3X@(D-A=&5G;W)Y
M(BP*"2=G8VA?7V-L:65N=%]P86=E7W1I=&QE)R`]/B`B1W)O=7`@;W!E<F%T
M:6]N<R!O;B!C;&EE;G0@86-C;W5N=',B+`H))V=C:%]?8VQI96YT<U]S96QE
M8W1I;VXG(#T^(")-;V1I9FEE9"!A8V-O=6YT<R`H)3$I(BP*"2=G8VA?7V1O
M;6%I;E]P86=E7W1I=&QE)R`]/B`B1W)O=7`@;W!E<F%T:6]N<R!O;B!D;VUA
M:6YS(BP*"2=G8VA?7V1O;6%I;G-?<V5L96-T:6]N)R`]/B`B36]D:69I960@
M9&]M86EN<R`H)3$I(BP*"2=G8VA?7VUA:6QN86UE<U]S96QE8W1I;VXG(#T^
M(")-;V1I9FEE9"!M86EL(&YA;65S("@E,2DB+`H))V=C:%]?:&]S=&EN9R<@
M/3X@(DAO<W1I;F<B+`H))V=C:%]?:&]S=&EN9U]A<&%C:&5?97)R;W)?9&]C
M<R<@/3X@(D-U<W1O;2!E<G)O<B!D;V-U;65N=',B+`H))V=C:%]?:&]S=&EN
M9U]C9VDG(#T^(")#1TD@<W5P<&]R="(L"@DG9V-H7U]H;W-T:6YG7VQO9U]R
M;W1A=&EO;B<@/3X@(DQO9R!R;W1A=&EO;B!S=&%T=7,B+`H))V=C:%]?:&]S
M=&EN9U]L;V=?<F]T871I;VY?8V]M<')E<W,G(#T^("),;V<@9FEL97,@8V]M
M<')E<W-I;VXB+`H))V=C:%]?:&]S=&EN9U]L;V=?<F]T871I;VY?;6%I;'1O
M)R`]/B`B1&5L:79E<B!P<F]C97-S960@;&]G(&9I;&5S('1O(BP*"2=G8VA?
M7VAO<W1I;F=?;&]G7W)O=&%T:6]N7VUA>%]F:6QE<R<@/3X@(DYU;6)E<B!O
M9B!L;V<@9FEL92!I;G-T86YC97,B+`H))V=C:%]?:&]S=&EN9U]L;V=?<F]T
M871I;VY?<&5R:6]D)R`]/B`B3&]G(')O=&%T:6]N(&-O;F1I=&EO;B(L"@DG
M9V-H7U]H;W-T:6YG7VQO9U]R;W1A=&EO;E]T:71L92<@/3X@(DQO9R!R;W1A
M=&EO;B(L"@DG9V-H7U]H;W-T:6YG7W!D:7)?<&QE<VM?<W1A="<@/3X@(E!R
M;W1E8W0@9&ER96-T;W)Y("<O<&QE<VLM<W1A="\G(BP*"2=G8VA?7VAO<W1I
M;F=?<&AP)R`]/B`B4$A0('-U<'!O<G0B+`H))V=C:%]?:&]S=&EN9U]S:&5L
M;"<@/3X@(E-H96QL(&%C8V5S<R(L"@DG9V-H7U]H;W-T:6YG7W-S:2<@/3X@
M(E-322!S=7!P;W)T(BP*"2=G8VA?7VAO<W1I;F=?<W-L)R`]/B`B4U-,('-U
M<'!O<G0B+`H))V=C:%]?:&]S=&EN9U]T>7!E)R`]/B`B2&]S=&EN9R(L"@DG
M9V-H7U]H;W-T:6YG7W=E8G-T870G(#T^(")796(@<W1A=&ES=&EC<R(L"@DG
M9V-H7U]I;G9A;&ED7V1A=&5?=F%L=64G(#T^("));F-O<G)E8W0@9&%T92!V
M86QU92XB+`H))V=C:%]?:6YV86QI9%]L;V=R;W1A=&5?<&%R86US)R`]/B`B
M3&]G(')O=&%T:6]N(&-O;F9I9R!I<R!N;W0@>65T(&-R96%T960@9F]R('1H
M:7,@9&]M86EN+"!T;R!C<F5A=&4@:70@>6]U(&YE960@=&\@9FEL;"!O=70@
M86QL('1H92!F:65L9',@97AC97!T(&9O<B`E,2XB+`H))V=C:%]?:71?:7-?
M:6UP;W-S:6)L95]T;U]D96-R96%S95]N=6UB97)?;6]R95]T:&%N7S$P,%]P
M97)C96YT<R<@/3X@(E5N86)L92!T;R!D96-R96%S92!T:&4@;G5M8F5R(&)Y
M(&UO<F4@=&AA;B`Q,#`E+B(L"@DG9V-H7U]I=%]I<U]I;7!O<W-I8FQE7W1O
M7VEN8W)E87-E7V]R7V1E8W)E87-E7W5N;&EM:71E9%]V86QU92<@/3X@(E5N
M86)L92!T;R!I;F-R96%S92!O<B!D96-R96%S92!T:&4@=F%L=64@+2!I="!I
M<R!U;FQI;6ET960N(BP*"2=G8VA?7VQI;5]D:7-K7W-P86-E)R`]/B`B3&EM
M:70@=&]T86P@9&ES:R!S<&%C92(L"@DG9V-H7U]L:6U?97AP:7)A=&EO;B<@
M/3X@(DQI;6ET('1H92!V86QI9&ET>2!P97)I;V0B+`H))V=C:%]?;&EM7VUA
M>%]B;W@G(#T^("),:6UI="!T:&4@;G5M8F5R(&]F(&UA:6QB;WAE<R(L"@DG
M9V-H7U]L:6U?;6%X7V1B)R`]/B`B3&EM:70@=&AE(&YU;6)E<B!O9B!D871A
M8F%S97,B+`H))V=C:%]?;&EM7VUA>%]D;VTG(#T^("),:6UI="!T:&4@;G5M
M8F5R(&]F(&1O;6%I;G,B+`H))V=C:%]?;&EM7VUA>%]M86EL;&ES=',G(#T^
M("),:6UI="!T:&4@;G5M8F5R(&]F(&UA:6QI;F<@;&ES=',B+`H))V=C:%]?
M;&EM7VUA>%]M9R<@/3X@(DQI;6ET('1H92!N=6UB97(@;V8@;6%I;"!G<F]U
M<',B+`H))V=C:%]?;&EM7VUA>%]R961I<B<@/3X@(DQI;6ET('1H92!N=6UB
M97(@;V8@;6%I;"!R961I<F5C=',B+`H))V=C:%]?;&EM7VUA>%]R97-P)R`]
M/B`B3&EM:70@=&AE(&YU;6)E<B!O9B!M86EL(&%U=&]R97-P;VYD97)S(BP*
M"2=G8VA?7VQI;5]M87A?<W5B9&]M)R`]/B`B3&EM:70@=&AE(&YU;6)E<B!O
M9B!S=6)D;VUA:6YS(BP*"2=G8VA?7VQI;5]M87A?=')A9F9I8R<@/3X@(DQI
M;6ET('1O=&%L(&%M;W5N="!O9B!T<F%F9FEC(BP*"2=G8VA?7VQI;5]M87A?
M=V5B87!P<R<@/3X@(DQI;6ET('1H92!N=6UB97(@;V8@2F%V82!A<'!L:6-A
M=&EO;G,B+`H))V=C:%]?;&EM7VUA>%]W=2<@/3X@(DQI;6ET('1H92!N=6UB
M97(@;V8@=V5B('5S97)S(BP*"2=G8VA?7VQI;5]M8F]X7W%U;W1A)R`]/B`B
M4V5T('1H92!M86EL8F]X('%U;W1A(BP*"2=G8VA?7VQI;5]T>7!E)R`]/B`B
M3&EM:70B+`H))V=C:%]?;&EM:71?;75S=%]B95]I;G1E9V5R7W!O<VET:79E
M7VYU;6)E<B<@/3X@(E1H92!L:6UI="!V86QU92!M=7-T(&)E(&$@<&]S:71I
M=F4@:6YT96=E<BXB+`H))V=C:%]?;F5W7VQI;6ET7W9A;'5E7V)E='=E96Y?
M>F5R;U]A;F1?:V)Y=&4G(#T^(")4:&4@;F5W(&QI;6ET('9A;'5E(&-A;B!B
M92!E:71H97(@,"P@,2!+:6QO8GET92!O<B!G<F5A=&5R+B(L"@DG9V-H7U]N
M97=?;&EM:71?=F%L=65?8F5T=V5E;E]Z97)O7V%N9%]M8GET92<@/3X@(E1H
M92!N97<@;&EM:70@=F%L=64@8V%N(&)E(&5I=&AE<B`P+"`Q($UE9V%B>71E
M(&]R(&=R96%T97(N(BP*"2=G8VA?7VQI;6ET7W9A;'5E7VES7V]U=%]O9E]R
M86YG92<@/3X@(E1H92!L:6UI="!V86QU92!S<&5C:69I960@97AC965D<R!T
M:&4@<F%N9V4@;V8@86QL;W=A8FQE('9A;'5E<RXB+`H))V=C:%]?;&EM:71S
M)R`]/B`B3&EM:71S(BP*"2=G8VA?7VUA:6QN86UE7W!A9V5?=&ET;&4G(#T^
M("='<F]U<"!O<&5R871I;VYS(&]N(&UA:6P@;F%M97,G+`H))V=C:%]?;6Y?
M;F]?875T;W)E<W!O;F1E<B<@/3X@)U1H97)E(&%R92!N;R!A=71O<F5S<&]N
M9&5R<R!S970M=7`@9F]R('1H92!M86EL(&YA;64N)RP*"2=G8VA?7VYE=U]C
M;&EE;G1?;&EM:71?:7-?;&5S<U]T:&%N7V1O;6%I;E]L:6UI=',G(#T^(")4
M:&4@<W!E8VEF:65D(&QI;6ET('9A;'5E(&ES(&QE<W,@=&AA;B!T:&4@=&]T
M86P@;V8@86QL(&QI;6ET<R!D969I;F5D(&9O<B!T:&ES(&-L:65N="=S(&1O
M;6%I;G,B+`H))V=C:%]?;F5W7VQI;6ET7W9A;'5E7W=I;&Q?8F5C86UE7V]U
M=%]O9E]R86YG92<@/3X@(D-H86YG:6YG('1H92!V86QU92!T;R!T:&4@;&5V
M96P@<W!E8VEF:65D('=I;&P@<F5S=6QT(&EN(&5X8V5E9&EN9R!T:&4@;6%X
M:6UU;2!A;&QO=V%B;&4@9&EG:70@=F%L=64N(BP*"2=G8VA?7VYO7V-L:65N
M='-?<V5L96-T960G(#T^(").;R!C;&EE;G0@86-C;W5N=',@<V5L96-T960B
M+`H))V=C:%]?;F]?9&]M86EN<U]S96QE8W1E9"<@/3X@(DYO(&1O;6%I;G,@
M<V5L96-T960B+`H))V=C:%]?;F]?;6%I;&YA;65S7W-E;&5C=&5D)R`]/B`G
M3F\@;6%I;"!N86UE<R!S96QE8W1E9"<L"@DG9V-H7U]P87)A;65T<B<@/3X@
M(E!A<F%M971E<B(L"@DG9V-H7U]P97)M7V-H86YG95]L:6UI=',G(#T^(")!
M8FEL:71Y('1O(&UO9&EF>2!D;VUA:6X@;&EM:71S(BP*"2=G8VA?7W!E<FU?
M8W)E871E7V1O;6%I;G,G(#T^(")!8FEL:71Y('1O(&-R96%T92!D;VUA:6YS
M(BP*"2=G8VA?7W!E<FU?='EP92<@/3X@(E!E<FUI<W-I;VXB+`H))V=C:%]?
M<&5R;6ES<VEO;G,G(#T^(")097)M:7-S:6]N<R(L"@DG9V-H7U]P<F5F7V%L
M;&]W7W-C<FEP=&EN9R<@/3X@(D%L;&]W('1H92!W96(@=7-E<G,@<V-R:7!T
M:6YG(BP*"2=G8VA?7W!R969?9&5L971E7W-T871I<W1I8R<@/3X@(E)E=&%I
M;B!T<F%F9FEC('-T871I<W1I8W,@9F]R(BP*"2=G8VA?7W!R969?;6%I;&UA
M;E]N;W1?:6YS=&%L;&5D7V]R7V-O;F8G(#T^(")-86EL;6%N(%-E<G9E<B!%
M>'1E;G-I;VYS(&%R92!N;W0@8W5R<F5N=&QY(&EN<W1A;&QE9"!O<B!P<F]P
M97)L>2!C;VYF:6=U<F5D(&]N('1H92!S97)V97(N(BP*"2=G8VA?7W!R969?
M;F]N97AI<W0G(#T^(")-86EL('1O(&YO;F5X:7-T96YT('5S97(B+`H))V=C
M:%]?<')E9E]T>7!E)R`]/B`B4')E9F5R96YC92(L"@DG9V-H7U]P<F5F7W=E
M8E]M86EL)R`]/B`B5V5B36%I;"(L"@DG9V-H7U]P<F5F7W=W=U]P<F5F:7@G
M(#T^(")75U<@<')E9FEX(BP*"2=G8VA?7W!R969E<F5N8V5S)R`]/B`B4')E
M9F5R96YC97,B+`H))V=C:%]?<F5J96-T:6]N)R`]/B`B4F5J96-T:6]N(')E
M87-O;B(L"@DG9V-H7U]S97)V7V%N;VYY;6]U<U]F='`G(#T^(")!;F]N>6UO
M=7,@1E10(BP*"2=G8VA?7W-E<G9?9&YS)R`]/B`B1$Y3('IO;F4B+`H))V=C
M:%]?<V5R=E]M86EL)R`]/B`B36%I;"(L"@DG9V-H7U]S97)V7VUA:6QL:7-T
M<R<@/3X@(DUA:6QI;F<@;&ES=',B+`H))V=C:%]?<V5R=E]T;VUC870G(#T^
M(")4;VUC870B+`H))V=C:%]?<V5R=E]T>7!E)R`]/B`B4V5R=FEC92(L"@DG
M9V-H7U]S97)V:6-E<R<@/3X@(E-E<G9I8V5S(BP*"2=G8VA?7W)E:F5C=%]L
M96=E;F0G(#T^(")4:&4@9W)O=7`@;W!E<F%T:6]N<R!H879E(&)E96X@<W5C
M8V5S<V9U;&QY('!E<F9O<FUE9"P@97AC97!T(&9O<B!T:&4@9F]L;&]W:6YG
M(&]B:F5C=',Z(BP*"2=G8VA?7W9A;'5E)R`]/B`B5F%L=64B+`H))V=C:%]?
M=F%L=65?;75S=%]B95]I;G1E9V5R7W!O<VET:79E7VYU;6)E<B<@/3X@(E1H
M92!V86QU92!M=7-T(&)E(&$@<&]S:71I=F4@:6YT96=E<BXB+`H))V=E=%]P
M87-S=V]R9%]?861M:6Y?<&%S<W=O<F0G(#T^(")4:&4@861M:6YI<W1R871O
M<B=S('!A<W-W;W)D(&-A;FYO="!B92!S96YT(&)Y(&4M;6%I;"!F;W(@<V5C
M=7)I='D@<F5A<V]N<RX@66]U(&-A;B!L;V]K(&ET('5P(&EN('1H92`O971C
M+W!S82\N<'-A+G-H861O=R!F:6QE(&QO8V%T960@;VX@>6]U<B!0;&5S:R!H
M;W-T+"!O;F-E('EO=2!A<F4@;&]G9V5D(&]N(&%S('5S97(@<F]O="XB+`H)
M)V=E=%]P87-S=V]R9%]?96YC<GEP=&5D7W!A<W-W;W)D)R`]/B`B56YA8FQE
M('1O('-E;F0@=&AE('!A<W-W;W)D(&EN9F]R;6%T:6]N.B!T:&4@<&%S<W=O
M<F0@:7,@<W1O<F5D(&5N8W)Y<'1E9"XB+`H))V=E=%]P87-S=V]R9%]?:6YV
M86QI9%]L;V=I;E]O<E]E;6%I;"<@/3X@(DED96YT:69I8V%T:6]N(&9A:6QE
M9#H@:6YV86QI9"!L;V=I;B!O<B!E+6UA:6P@861D<F5S<R!S<&5C:69I960N
M(%!L96%S92P@=')Y(&%G86EN+B(L"@DG9V5T7W!A<W-W;W)D7U]L86)E;"<@
M/3X@(D=E="!P87-S=V]R9"(L"@DG9V5T7W!A<W-W;W)D7U]M86EL7V5R<F]R
M)R`]/B`B06X@97)R;W(@;V-C=7)E9"!W:&EL92!A='1E;7!T:6YG('1O('-E
M;F0@=&AE('!A<W-W;W)D('1O(&4M;6%I;"`E,3H@)3(B+`H))V=E=%]P87-S
M=V]R9%]?;6%I;%]O:R<@/3X@(E1H92!P87-S=V]R9"!H87,@8F5E;B!S=6-C
M97-S9G5L;'D@<V5N="!T;R!E+6UA:6PZ("4Q+B(L"@DG9V5T7W!A<W-W;W)D
M7U]M97-S86=E)R`]/B`B66]U<B!L;V=I;B!N86UE(&9O<B!A8V-E<W-I;F<@
M=&AE('-Y<W1E;3H@)3%<;EEO=7(@<&%S<W=O<F0@:7,@)3(B+`H))V=E=%]P
M87-S=V]R9%]?<W5B:F5C="<@/3X@(E!A<W-W;W)D(&9O<B!A8V-E<W,@=&\@
M<WES=&5M(BP*"2=G971?<&%S<W=O<F1?7W=A<FYI;F<G(#T^("(\8CY!='1E
M;G1I;VXA(2$\+V(^/&)R/EQN4V5N9&EN9R!P87-S=V]R9"!B>2!E+6UA:6P@
M:7,@:6YS96-U<F4A/&)R/EQN16YT97(@>6]U<B!L;V=I;B!N86UE(&%N9"!E
M+6UA:6P@<F5G:7-T97)E9"!I;B!T:&4@<WES=&5M(&9O<B!P87-S=V]R9"!D
M96QI=F5R>2XB+`H))V=R;W5P<U]?879A:6QA8FQE)R`]/B`B079A:6QA8FQE
M(&UA:6P@9W)O=7!S(BP*"2=G<F]U<'-?7V=R;W5P<U]F;W)?;6%I;&YA;64G
M(#T^(")-86EL(&=R;W5P<R!F;W(@=&AE(&UA:6P@;F%M92`E,2(L"@DG9W)O
M=7!S7U]M96UB97)?;V8G(#T^(")-96UB97(@;V8@=&AE(&9O;&QO=VEN9R!M
M86EL(&=R;W5P<R(L"@DG:&5L<%]?:&5L<%]A<F5A)R`]/B`B2&5L<"!A<F5A
M+B(L"@DG:'-T7V1E9E]?875T:%]D:7-A8FQE9"<@/3X@(F1I<V%B;&5D(BP*
M"2=H<W1?9&5F7U]A=71H7V5N86)L960G(#T^(")E;F%B;&5D(BP*"2=H<W1?
M9&5F7U]C:&%N9V5?8W5R<E]D;G-?:7`G(#T^(")4:&4@8W5R<F5N="!)4"!A
M9&1R97-S(&]F('1H92!!($1.4R!R96-O<F0@=VEL;"!B92!C:&%N9V5D(BP*
M"2=H<W1?9&5F7U]C<E]H;W-T:6YG7VEP7V1N<U]I<%]N;W1?97%U:78G(#T^
M(").;VYE(&]F('1H92!)4"!A9&1R97-S97,@;V8@=&AE($$@1$Y3(')E8V]R
M9"!M871C:"!W:71H($E0(&%D9')E<W,@87-S:6=N960@=&\@=&AE(&AO<W1I
M;F<@86-C;W5N="!B96EN9R!C<F5A=&5D(BP*"2=H<W1?9&5F7U]D97-T7W5R
M;"<@/3X@(D1E<W1I;F%T:6]N(%523"(L"@DG:'-T7V1E9E]?9&ES:U]Q=6]T
M82<@/3X@(D1I<VL@<75O=&$B+`H))VAS=%]D969?7V1I<VM?<W!A8V5?;&EM
M:71?97AC965D7VEN8V]M:6YG7W%U;W1A)R`]/B`B5&AE(&1I<VL@<W!A8V4@
M;&EM:70@>6]U(&%R92!T<GEI;F<@=&\@<V5T(&ES(&5X8V5E9&5D(&)Y('1H
M92!D:7-K('-P86-E(&QI;6ET(&EN('1H92!A;F]N>6UO=7,@1E10(&EN8V]M
M:6YG(&1I<F5C=&]R>2X@5&AE(&1I<VL@<W!A8V4@;&EM:70@:6X@=&AE(&%N
M;VYY;6]U<R!&5%`@:6YC;VUI;F<@9&ER96-T;W)Y(&UU<W0@;F]T(&5X8V5E
M9"!T:&4@9&]M86EN(&1I<VL@<W!A8V4@;&EM:70N(BP*"2=H<W1?9&5F7U]F
M<%]A9&UI;E]L;V=I;B<@/3X@(D9R;VYT4&%G92!!9&UI;FES=')A=&]R)W,@
M3&]G:6XB+`H))VAS=%]D969?7V9P7V%D;6EN7VQO9VEN7VES7VEN=F%L:60G
M(#T^(")&<F]N=%!A9V4@061M:6YI<W1R871O<B=S($QO9VEN(&ES(&EN=F%L
M:60N(BP*"2=H<W1?9&5F7U]F<%]A9&UI;E]P87-S=V0G(#T^(")&<F]N=%!A
M9V4@061M:6XG<R!087-S=V]R9"(L"@DG:'-T7V1E9E]?9G!?97AT96YT:6]N
M7W-U<'!O<G0G(#T^(")&<F]N=%!A9V4@97AT96YS:6]N<R!S=7!P;W)T+B(L
M"@DG:'-T7V1E9E]?9G)A;65?9F]R=V%R9&EN9U]D969I;FET:6]N)R`]/B`B
M1G)A;64@9F]R=V%R9&EN9R!A<W-I9VYM96YT(&9O<B!D;VUA:6X@)3$B+`H)
M)VAS=%]D969?7V9T<'5S97)?9F]R7VAS=%]N;W1?97AI<W1?:6Y?<WES=&5M
M)R`]/B`B5T%23DE.1RX@1E10('5S97(@)3$@:7,@=7-E9"!I;B!A(&AO<W1I
M;F<@86-C;W5N="!B=70@9&]E<R!N;W0@97AI<W0@:6X@=&AE('-Y<W1E;2XB
M+`H))VAS=%]D969?7VAS=%]T>7!E7VES7VYO=%]D969I;F5D)R`]/B`B2&]S
M=&EN9R!T>7!E(&ES(&YO="!D969I;F5D(BP*"2=H<W1?9&5F7U]I<%]B87-E
M9"<@/3X@(DE0+6)A<V5D(BP*"2=H<W1?9&5F7U]N86UE7V)A<V5D7W!O=V5R
M7V%N;VYY;6]U<U]F='!?9&]W;B<@/3X@(E1R86YS9F5R<FEN9R!Y;W5R(&AO
M<W1I;F<@86-C;W5N="!T;R!S:&%R960@:7`@861D<F5S<R!W:6QL(&1I<V%B
M;&4@>6]U<B!A;F]N>6UO=7,@1E10(&1O;6%I;BX@4')O8V5E9"!A;GEW87D_
M(BP*"2=H<W1?9&5F7U]P87-S=V]R9%]I<U]I;G9A;&ED7W!A<W-W;W)D7W-Y
M;G1A>"<@/3X@(E!A<W-W;W)D(&ES(&EN=F%L:60N7&Y$;R!N;W0@=7-E('-I
M;F=L92!Q=6]T92!A;F0@;F%T:6]N86P@86QP:&%B970@8VAA<F%C=&5R<R!I
M;B!A('!A<W-W;W)D+EQN5&AE('!A<W-W;W)D(&QE;F=T:"!S:&]U;&0@8F4@
M9G)O;2`U('1O(#$T(&-H87)A8W1E<G,N(%1H92!P87-S=V]R9"!S:&]U;&0@
M;F]T(&-O;G1A:6X@=&AE('5S97(@;F%M92XB+`H))VAS=%]D969?7W-H96QL
M)R`]/B`B4VAE;&P@86-C97-S('1O('-E<G9E<B!W:71H($944"!U<V5R)W,@
M8W)E9&5N=&EA;',B+`H))VAS=%]D969?7W-T86YD87)D7V9O<G=A<F1I;F=?
M9&5F:6YI=&EO;B<@/3X@(E-T86YD87)D(&9O<G=A<F1I;F<@87-S:6=N;65N
M="!F;W(@9&]M86EN("4Q(BP*"2=H<W1?9&5F7U]T:71L95]N86UE7V)A<V5D
M)R`]/B`B3F%M92UB87-E9"(L"@DG:'-T7V1E9E]?=6YA8FQE7V-R96%T92]U
M<&1A=&5?<&AY<VEC7VAS="<@/3X@(E5N86)L92!T;R!C<F5A=&4O=7!D871E
M('!H>7-I8V%L(&AO<W1I;F<Z("4Q(BP*"2=H<W1?9&5F7U]U;F%B;&5?8W)E
M871E+W5P9&%T95]S=&1?9G=D)R`]/B`B56YA8FQE('1O(&-R96%T92]U<&1A
M=&4@<W1A;F1A<F0@9F]R=V%R9&EN9SH@)3$B+`H))VAS=%]D969?7W5N86)L
M95]C<F5A=&5?9F]R=V%R9&EN9U]M>7-E;&8G(#T^(")5;F%B;&4@=&\@8W)E
M871E(&9O<G=A<F1I;F<@=&\@=&AE(&1O;6%I;B!I='-E;&8N(BP*"2=H<W1?
M9&5F7U]U;F%B;&5?='5R;E]S<VQ?;V9F7W=H:6QE7V9P7W-S;%]O;B<@/3X@
M(E5N86)L92!T;R!T=7)N(&]F9B!34TP@<W5P<&]R=#H@1G)O;G1086=E(&]V
M97(@4U-,('-U<'!O<G0@:7,@96YA8FQE9"XB+`H))VAS=%]D969?7W5N86)L
M95]T=7)N7V9P7W-S;"<@/3X@(E5N86)L92!T;R!T=7)N(&]N($9R;VYT4&%G
M92!O=F5R(%-33"!S=7!P;W)T.B!34TP@<W5P<&]R="!I<R!D:7-A8FQE9"XB
M+`H))VAS=%]D969?7W5N86)L95]T=7)N7V]N7W-S;%]C97)T7VYO=%]D969I
M;F5D)R`]/B`B56YA8FQE('1O('1U<FX@;VX@4U-,('-U<'!O<G0Z(&YO(%-3
M3"!C97)T:69I8V%T92!I;G-T86QL960B+`H))VAS=%]D969?7W5R;%]I<U]I
M;G9A;&ED)R`]/B`B55),(&ES(&EN=F%L:60N(BP*"2=H<W1?9&5F7U]V:7)T
M=6%L7VAO<W1?86-C97-S)R`]/B`B5FER='5A;"!H;W-T(&%C8V5S<R!F;W(@
M9&]M86EN("4Q(BP*"2=H<W1?9&5F7U]V:7)T=6%L7VAO<W1?=7-E<U]N;VY?
M97AI<W1E9%]I<%]A9&1R97-S)R`]/B`B5T%23DE.1RX@5&AI<R!V:7)T=6%L
M(&AO<W0@:7,@=7-I;F<@82!N;VYE>&ES=&5N="!)4"!A9&1R97-S(&9O<B!H
M;W-T:6YG+B(L"@DG:'-T7V1E9E]?>6]U7VAA=F5?;F]?:7!S)R`]/B`B66]U
M(&AA=F4@;F\@:7`@861D<F5S<V5S(&%V86EL86)L92!A;F0@>6]U(&%R92!N
M;W0@86QL;W=E9"!T;R!C<F5A=&4@3F%M92UB87-E9"!H;W-T:6YG+B(L"@DG
M:'-T7V1E9E]?>6]U7W1U<FYE9%]O9F9?9G!?<W-L7W-U<'!O<G1?86QL7V9P
M7W-E='1I;F=S7W=I;&Q?8F5?9&5S=')O>65D7V]K/R<@/3X@(EEO=2!H879E
M('1U<FYE9"!O9F8@=&AE($9R;VYT4&%G92!O=F5R(%-33"!S=7!P;W)T+B!!
M;&P@1G)O;G1086=E('-E='1I;F=S('=I;&P@8F4@9&ES8V%R9&5D+B!$;R!Y
M;W4@=V%N="!T;R!P<F]C965D/R(L"@DG:'-T7V1E9E]?>6]U7W1U<FYE9%]O
M9F9?9G!?<W5P<&]R=%]A;&Q?9G!?<V5T=&EN9W-?=VEL;%]B95]D97-T<F]Y
M961?;VL_)R`]/B`B66]U(&AA=F4@='5R;F5D(&]F9B!T:&4@1G)O;G1086=E
M('-U<'!O<G0N($%L;"!&<F]N=%!A9V4@<V5T=&EN9W,@=VEL;"!B92!D:7-C
M87)D960N($1O('EO=2!W86YT('1O('!R;V-E960_(BP*"2=H<W1?<V5L7U]H
M96%D97(G(#T^("`@(E1O(&AO<W0@82!W96(@<VET92!O;B!T:&ES(&UA8VAI
M;F4L('-E;&5C="!T:&4@4&AY<VEC86P@:&]S=&EN9R!O<'1I;VXN(%5P;VX@
M8V]M<&QE=&EO;B!O9B!T:&ES('!R;V-E9'5R92P@>6]U<B!C;VYT<F]L('!A
M;F5L('=I;&P@<V5T('5P('1H92!D;VUA:6X@;F%M92!S97)V97(@;VX@=&AI
M<R!M86-H:6YE('1O('-E<G9E('1H92!N97<@9&]M86EN(&YA;64@86YD('!R
M97!A<F4@=&AE('=E8B!S97)V97(@=&\@<V5R=F4@=&AE(&YE=R!W96(@<VET
M93H@82!N97<@>F]N92!F:6QE('=I=&@@87!P<F]P<FEA=&4@<F5S;W5R8V4@
M<F5C;W)D<R!W:6QL(&)E(&%D9&5D('1O('1H92!D;VUA:6X@;F%M92!S97)V
M97(G<R!C;VYF:6=U<F%T:6]N(&9I;&5S+"!A('=E8B!S<&%C92!W:6QL(&)E
M(&-R96%T960@:6YS:61E('1H92!W96(@<V5R=F5R)W,@9&ER96-T;W)Y+"!A
M;F0@;F5C97-S87)Y('5S97(@86-C;W5N=',@=VEL;"!B92!C<F5A=&5D(&]N
M('1H92!S97)V97(N7&Y.;W1E.B!)9B!T:&4@<VET92!I<R!H;W-T960@;VX@
M86YO=&AE<B!M86-H:6YE+"!A;F0@>6]U('=I<V@@=&\@<V5T('5P('EO=7(@
M8V]N=')O;"!P86YE;"=S($1.4R!S97)V97(@;VYL>2!T;R!S97)V92!T:&4@
M1$Y3('IO;F4@9F]R('1H870@<VET92P@<V5L96-T(&5I=&AE<B!&<F%M92!F
M;W)W87)D:6YG(&]R(%-T86YD87)D(&9O<G=A<F1I;F<@;W!T:6]N+B!7:71H
M('-T86YD87)D(&9O<G=A<F1I;F<L(&$@=7-E<B!I<R!R961I<F5C=&5D('1O
M('1H92!S:71E(&%N9"!T:&4@86-T=6%L('-I=&4G<R!54DP@:7,@<VAO=VX@
M:6X@=&AE('5S97(G<R!B<F]W<V5R+"!S;R!T:&4@=7-E<B!A;'=A>7,@:VYO
M=W,@=&AA="!H92!O<B!S:&4@:7,@<F5D:7)E8W1E9"!T;R!A;F]T:&5R(%52
M3"X@5VET:"!F<F%M92!F;W)W87)D:6YG+"!A('5S97(@:7,@<F5D:7)E8W1E
M9"!T;R!T:&4@<VET92!W:71H;W5T(&MN;W=I;F<@=&AA="!T:&4@<VET92!A
M8W1U86QL>2!R97-I9&5S(&%T(&%N;W1H97(@;&]C871I;VXN(BP*"2=H<W1?
M<V5L7U]P:'ES:6-A;%]H<W0G"3T^(")0:'ES:6-A;"!H;W-T:6YG(BP*"2=H
M<W1?<V5L7U]S96QE8W1?:'-T7W1Y<&4G(#T^(")396QE8W0@=&AE('1Y<&4@
M;V8@:&]S=&EN9R!F;W(@=&AE(&1O;6%I;B(L"@DG:'-T7W-E;%]?<V5L96-T
M7VAS=%]T>7!E7W=A<FYI;F<G(#T^(")396QE8W0@=&AE('1Y<&4@;V8@:&]S
M=&EN9R!F;W(@=&AE(&1O;6%I;B$B+`H))VAS=%]S96Q?7W-T86YD87)D7V9R
M=R<)/3X@(E-T86YD87)D(&9O<G=A<F1I;F<B+`H))VAS=%]S96Q?7V9R86UE
M7V9R=R<)/3X@(D9R86UE(&9O<G=A<F1I;F<B+`H))U]?8VAO;W-E7VAS=%]T
M>7!E)R`]/B`B4V5L96-T('1H92!R97%U:7)E9"!H;W-T:6YG('1Y<&4N(BP*
M"2=?7V9R86UE7V9R=R<@/3X@(D9R86UE(&9O<G=A<F1I;F<B+`H))U]?:&]S
M=&EN9U]E>&ES=',G(#T^(")5;F%B;&4@=&\@8W)E871E(&AO<W1I;F<L(&%S
M(&ET(&ES(&%L<F5A9'D@8V]N9FEG=7)E9"!F;W(@=&AI<R!D;VUA:6XN(%EO
M=2!W:6QL(&)E(')E9&ER96-T960@=&\@=&AE(&AO<W1I;F<@;6%N86=E;65N
M="!P86=E+B(L"@DG7U]N;U]H<W1?8V]N9B<@/3X@(E1H97)E(&ES(&YO(&AO
M<W1I;F<@8V]N9FEG=7)E9"!F;W(@>6]U<B!D;VUA:6XN(BP*"2=?7W!H>7-I
M8V%L7VAS="<@/3X@(E!H>7-I8V%L(&AO<W1I;F<B+`H))U]?<V5L96-T7VAS
M=%]T>7!E)R`]/B`B4V5L96-T('1H92!T>7!E(&]F(&AO<W1I;F<@9F]R('1H
M92!D;VUA:6XB+`H))U]?<W1A;F1A<F1?9G)W)R`]/B`B4W1A;F1A<F0@9F]R
M=V%R9&EN9R(L"@DG7U]W87)N:6YG)R`]/B`B5V%R;FEN9R$@06QL(&]F('1H
M92!P<F5V:6]U<VQY('-E="!P87)A;65T97)S('=I;&P@8F4@9&ES8V%R9&5D
M+B!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@8VAA;F=E('1H92!H;W-T:6YG
M('1Y<&4_(BP*"2=I7V-L7R$G(#T^(")297-O=7)C92!U<V%G92!O9B!T:&4@
M8VQI96YT(&ES(&5X8V5E9&EN9R!L:6UI=',N(BP*"2=I7V-L7V]F9B<@/3X@
M(D-L:65N="!I<R!I;F%C=&EV92XB+`H))VE?8VQ?;V9F7V)Y7V%D;6EN)R`]
M/B`B0VQI96YT(&%C8V]U;G0@:7,@9&ES86)L960@8GD@861M:6YI<W1R871O
M<BXB+`H))VE?8VQ?;V9F7V5X<&ER960G(#T^(")#;&EE;G0@86-C;W5N="!I
M<R!E>'!I<F5D+B(L"@DG:5]C;%]O:R<@/3X@(E)E<V]U<F-E('5S86=E(&]F
M('1H92!C;&EE;G0@:7,@=VET:&EN(&QI;6ET<RXB+`H))VE?8VQ?;VXG(#T^
M(")#;&EE;G0@:7,@86-T:79E+B(L"@DG:5]D;VU?(2<@/3X@(D1I<VL@<W!A
M8V4@86YD+V]R('1R869F:6,@;&EM:71S(&%R92!E>&-E961E9"!I;B!T:&4@
M9&]M86EN+B(L"@DG:5]D;VU?;V9F)R`]/B`B1&]M86EN(&ES(&EN86-T:79E
M+B(L"@DG:5]D;VU?;V9F7V)A8VMU<%]R97-T;W)E)R`]/B`B1&]M86EN(&ES
M('1E;7!O<F%R:6QY(&1I<V%B;&5D(&9O<B!B86-K=7`O<F5S=&]R:6YG+B(L
M"@DG:5]D;VU?;V9F7V)Y7V%D;6EN)R`]/B`B1&]M86EN(&ES(&1I<V%B;&5D
M(&)Y(&%D;6EN:7-T<F%T;W(B+`H))VE?9&]M7V]F9E]B>5]C;&EE;G0G(#T^
M(")$;VUA:6X@:7,@9&ES86)L960@8GD@8VQI96YT(BP*"2=I7V1O;5]O9F9?
M8GE?<F5S96QL97(G(#T^(")$;VUA:6X@:7,@9&ES86)L960@8GD@<F5S96QL
M97(B+`H))VE?9&]M7V]F9E]E>'!I<F5D)R`]/B`B1&]M86EN(&ES(&5X<&ER
M960B+`H))VE?9&]M7V]F9E]W:71H7W!A<F5N="<@/3X@(D-L:65N="!I<R!D
M:7-A8FQE9"!A;&]N9R!W:71H(&AI<R]H97(@9&]M86EN(BP*"2=I7V1O;5]O
M:R<@/3X@(D1O;6%I;B!I<R!A;&P@<FEG:'0N(BP*"2=I7V1O;5]O;B<@/3X@
M(D1O;6%I;B!I<R!A8W1I=F4N(BP*"2=I<%]A9&1R7U]A;')E861Y7V5X:7-T
M<R<@/3X@(DE0(&%D9')E<W,@)3$@86QR96%D>2!E>&ES=',N(BP*"2=I<%]A
M9&1R7U]C86YT7V%D9"<@/3X@(DE0("4Q(&1O97,@;F]T(&5X:7-T(&]R(&)E
M;&]N9W,@=&\@25`@<&]O;"!O9B!A;F]T:&5R(&-L:65N="(L"@DG:7!?861D
M<E]?8VQ?9&]M86EN<U]L:7-T7V9O<E]I<"<@/3X@(E1H92!D;VUA:6YS(&]F
M(&-L:65N="`E,2!T:&%T('5S92`E,B!I<"!A9&1R97-S("4S(BP*"2=I<%]A
M9&1R7U]C;%]L:7-T7V9O<E]I<"<@/3X@(D-L:65N=',@=7-I;F<@)3$@25`@
M861D<F5S<R`E,B(L"@DG:7!?861D<E]?8VQ?;&ES=%]F;W)?:7!?861D)R`]
M/B`B061D($E0(&%D9')E<W,@=&\@8VQI96YT<R!P;V]L(BP*"2=I<%]A9&1R
M7U]D;VUA:6YS7VQI<W1?9F]R7VEP)R`]/B`B1&]M86EN<R!U<VEN9R`E,2!)
M4"!A9&1R97-S("4R(BP*"2=I<%]A9&1R7U]I<%]U<V5D7V)Y7VAS=%]O<E]F
M<G<G(#T^("))4"!A9&1R97-S("4Q(&ES('5S960@9F]R(&AO<W1I;F<@;W(@
M9F]R=V%R9&EN9RXB+`H))VEP7V%D9')?7W)E;6]V95]I<%]A9&1R)R`]/B`B
M5&AE<V4@:7`@861D<F5S<V5S('=I;&P@8F4@<F5M;W9E9"!F<F]M('1H92!S
M>7-T96TZ(BP*"2=I<%]A9&1R7U]S96QE8W1?8VQI96YT<R<@/3X@(E-E;&5C
M="!C;&EE;G1S(BP*"2=I<%]A9&1R7U]S96QE8W1?:7!?861D<E]T;U]R96UO
M=F4G(#T^(")396QE8W0@=&AE($E0(&%D9')E<W,@=&\@8F4@<F5M;W9E9"XB
M+`H))VEP7V%D9')?7W5N86QL;W=E9%]B>5]L:6-E;G-E)R`]/B`B4&QE<VL@
M:7,@;F]T(&QI8V5N<V5D('1O('=O<FL@;VX@25`@861D<F5S<R`E,2Y<;D%L
M;&]W960@25`@<F%N9V5S(&%R93H@)3(N(BP*"2=I<%]A;&EA<U]?861D7VEP
M)R`]/B`B061D($E0(&%D9')E<W,B+`H))VEP7V%L:6%S7U]A9&1R7V%L<F5A
M9'E?97AI<W0G(#T^(")A9&1R97-S(&%L<F5A9'D@97AI<W1S+B(L"@DG:7!?
M86QI87-?7V%L:6%S7VUA;F%G92<@/3X@(DE0(&%D9')E<W-E<R!M86YA9V5M
M96YT(BP*"2=I<%]A;&EA<U]?86QI87-E<R<@/3X@(DE0($%D9')E<W-E<R`B
M+`H))VEP7V%L:6%S7U]I;G1E<F9A8V4G(#T^("));G1E<F9A8V4@(BP*"2=I
M<%]A;&EA<U]?:6YV86QI9%]I<%]N;5]B<V1?=G)T7VAS=',G(#T^("(E,2!)
M4"!A9&1R97-S(&9O<B!N86UE+6)A<V5D('9I<G1U86P@:&]S=&EN9R!I<R!I
M;G9A;&ED+B(L"@DG:7!?86QI87-?7VEN=F%L:61?:7!?;W)?;F5T;6%S:R<@
M/3X@(DEN=F%L:60@25`@861D<F5S<R]N971M87-K('!A:7(N(BP*"2=I<%]A
M;&EA<U]?:7!?8V%N7VYO=%]B95]D96QE=&5D)R`]/B`B5&AI<R!I<R!T:&4@
M;6%I;B!S97)V97(@25`L('=H:6-H(&-A;FYO="!B92!R96UO=F5D+B(L"@DG
M:7!?86QI87-?7VEP7VYO=%]E>&ES="<@/3X@(FEP(&%D9')E<W,@)3$@9&]E
M<R!N;W0@97AI<W0N(BP*"2=I<%]A;&EA<U]?:7!?861D<F5S<U]A;F1?;6%S
M:R<@/3X@)TE0(&%D9')E<W,@86YD('-U8FYE="!M87-K)RP*"2=I<%]A;&EA
M<U]?<F5M;W9E7W-E;&5C=&5D7VEP7V%L:6%S97,_)R`]/B`B07)E('EO=2!S
M=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<V5L96-T960@25`@861D<F5S
M<V5S/R(L"@DG:7!?86QI87-?7W-E;&5C=%]I<"<@/3X@(E-E;&5C="!A="!L
M96%S="!O;F4@25`@861D<F5S<R!F<F]M('1H92!L:7-T('1O(')E;6]V92!I
M="XB+`H))VEP7V%L:6%S7U]T:&ES7VEP7W5S961?9F]R7V1O;6%I;B<@/3X@
M(B@E,2D@=&AI<R!)4"!A9&1R97-S(&ES('5S960@9F]R(&1O;6%I;B`E,BXB
M+`H))VEP7V%L:6%S7U]T:&ES7VEP7W5S961?9F]R7VYM7V)S9%]V<G1?:'-T
M<R<@/3X@(B@E,2D@=&AI<R!)4"!A9&1R97-S(&ES('5S960@9F]R(&YA;64M
M8F%S960@=FER='5A;"!H;W-T<RXB+`H))VEP7V%L:6%S7U]T>7!E)R`]/B`B
M25`@='EP92(L"@DG:7!?86QI87-?7W5N86)L95]A9&1?:7`G(#T^(")5;F%B
M;&4@=&\@861D($E0.B`E,2(L"@DG:7!?86QI87-?7W5N86)L95]R96UO=F5?
M:7`G(#T^(")5;F%B;&4@=&\@<F5M;W9E($E0.B`E,2(L"@DG:7!?8W1R;%]?
M86YO;GEM;W5S7V9T<%]E>&ES='-?:6Y?9&]M86EN)R`]/B`B66]U(&-A;FYO
M="!C:&%N9V4@=&AE($E0(&%D9')E<W,@='EP92!T;R!S:&%R960L(&%S(&ET
M('=I;&P@;6%K92!!;F]N>6UO=7,@1E10(&9O<B!D;VUA:6X@)R4Q)R!U;F%V
M86EL86)L92XB+`H))VEP7V-T<FQ?7VEP7V%D9'(G(#T^("))4"!A9&1R97-S
M("4R(&]N('1H92!I;G1E<F9A8V4@)3$B+`H))VEP7V-T<FQ?7VEP7V5X:7-T
M<U]M86YY7W!O;VQS)R`]/B`B66]U(&-A;FYO="!C:&%N9V4@25`@='EP92X@
M25`@861D<F5S<R!B96QO;F=S('1O('1H92!P;V]L<R!O9B!S979E<F%L(&-L
M:65N=',@870@=&AE('-A;64@=&EM92XB+`H))VEP7V-T<FQ?7W-S;%]C97)T
M)R`]/B`B4U-,($-E<G1I9FEC871E(BP*"2=I<%]P;V]L7U]I<%]A9&1R97-S
M7VES7V%B<V5N9%]I;E]P;V]L)R`]/B`B25`@861D<F5S<R!I<R!M:7-S:6YG
M+B(L"@DG:7!?<&]O;%]?:7!?<&]O;%]F;W)?8VQI96YT)R`]/B`B25`@<&]O
M;"!O9B!C;&EE;G0@)3$B+`H))VEP7W!O;VQ?7VYO7V-L:65N<U]A=F%I;"<@
M/3X@(E1H97)E(&%R92!N;R!C;&EE;G1S(&%V86EL86)L92(L"@DG:7!?<&]O
M;%]?;F]?=F%C86YT7VEP<R<@/3X@(E1H97)E(&%R92!N;R!V86-A;G0@25!S
M(BP*"2=I<%]P;V]L7U]P;V]L7VES7V5M<'1Y)R`]/B`B0VQI96YT)W,@25`@
M<&]O;"!I<R!E;7!T>2X@5&\@861D(&%N($E0(&%D9')E<W,L('EO=2!S:&]U
M;&0@=7-E('1H92!#;&EE;G0G<R!)4"!P;V]L(&UA;F%G96UE;G0@9G5N8W1I
M;VYS(&%V86EL86)L92!F<F]M('1H92!#;&EE;G0G<R!(;VUE(%!A9V4N(BP*
M"2=I<%]P;V]L7U]R96UO=F5?:7!?861D<B<@/3X@(E1H97-E(&EP(&%D9')E
M<W-E<R!W:6QL(&)E(')E;6]V960@9G)O;2!T:&4@<&]O;"`E,3HB+`H))VEP
M7W!O;VQ?7W-E;&5C=%]F<F5E7VEP<R<@/3X@(E9A8V%N="!)4',B+`H))VEP
M7W!O;VQ?7W5S961?:7!S)R`]/B`B0VQI96YT)W,@25`@<&]O;"(L"@DG;&EC
M96YS95]?:5]A9W)E92<@/3X@(DD@86=R964@=&\@=&AE('1E<FUS(&]F('1H
M:7,@;&EC96YS92!A9W)E96UE;G0N(BP*"2=L:6-E;G-E7U]N;W1?<VAO=R<@
M/3X@(D1O(&YO="!S:&]W(&ET(&%G86EN+B(L"@DG;&EC96YS95]?=6YA8FQE
M7V]P96Y?;&EC96YS95]F:6QE)R`]/B`B56YA8FQE('1O(&]P96X@=&AE(&QI
M8V5N<V4@9FEL93H@)3$B+`H))VQI8V5N<V5?7WEO=5]S:&]U;&1?86-C97!T
M)R`]/B`B26X@;W)D97(@=&\@=7-E("104D]$7TY!344@>6]U('-H;W5L9"!A
M9W)E92!T;R!T:&4@=&5R;7,@;V8@=&AI<R!L:6-E;G-E+B(L"@DG;&EM:71?
M7V1A=&5?:6Y?<&%S="<@/3X@(E9A;&ED:71Y('!E<FEO9"!I<R!I;G9A;&ED
M+B`E,2!I<R!I;B!T:&4@<&%S="XB+`H))VQI;6ET7U]D:7-K7W-P86-E)R`]
M/B`B1&ES:R!S<&%C92(L"@DG;&EM:71?7V5N=&5R7V1A=&4G(#T^(")%;G1E
M<B!D871E(BP*"2=L:6UI=%]?97AP:7)A=&EO;B<@/3X@(E9A;&ED:71Y('!E
M<FEO9"(L"@DG;&EM:71?7VUA>%]B;W@G(#T^(")-87AI;75M(&YU;6)E<B!O
M9B!M86EL8F]X97,B+`H))VQI;6ET7U]M87A?9&(G(#T^(")-87AI;75M(&YU
M;6)E<B!O9B!D871A8F%S97,B+`H))VQI;6ET7U]M87A?9&]M)R`]/B`B36%X
M:6UU;2!N=6UB97(@;V8@9&]M86EN<R(L"@DG;&EM:71?7VUA>%]M86EL;&ES
M=',G(#T^(")-87AI;75M(&YU;6)E<B!O9B!M86EL:6YG(&QI<W1S(BP*"2=L
M:6UI=%]?;6%X7VUG)R`]/B`B36%X:6UU;2!N=6UB97(@;V8@;6%I;"!G<F]U
M<',B+`H))VQI;6ET7U]M87A?<F5D:7(G(#T^(")-87AI;75M(&YU;6)E<B!O
M9B!M86EL(')E9&ER96-T<R(L"@DG;&EM:71?7VUA>%]R97-P)R`]/B`B36%X
M:6UU;2!N=6UB97(@;V8@;6%I;"!A=71O<F5S<&]N9&5R<R(L"@DG;&EM:71?
M7VUA>%]S=6)D;VTG(#T^(")-87AI;75M(&YU;6)E<B!O9B!S=6)D;VUA:6YS
M(BP*"2=L:6UI=%]?;6%X7W1R869F:6,G(#T^(")-87AI;75M(&%M;W5N="!O
M9B!T<F%F9FEC(BP*"2=L:6UI=%]?;6%X7W=E8F%P<',G(#T^(")-87AI;75M
M(&YU;6)E<B!O9B!*879A(&%P<&QI8V%T:6]N<R(L"@DG;&EM:71?7VUA>%]W
M=2<@/3X@(DUA>&EM=6T@;G5M8F5R(&]F('=E8B!U<V5R<R(L"@DG;&EM:71?
M7VUB;WA?<75O=&$G(#T^(")3970@=&AE(&UA:6QB;W@@<75O=&$B+`H))VQI
M;6ET7U]U;FET<U]D:7-K7W-P86-E)R`]/B`B34(B+`H))VQI;6ET7U]U;FET
M<U]M87A?8F]X)R`]/B`B;6%I;&)O>&5S(BP*"2=L:6UI=%]?=6YI='-?;6%X
M7VUN)R`]/B`B;F%M97,B+`H))VQI;6ET7U]U;FET<U]M87A?9&(G(#T^(")D
M871A8F%S97,B+`H))VQI;6ET7U]U;FET<U]M87A?8VPG(#T^(")C;&EE;G1S
M(BP*"2=L:6UI=%]?=6YI='-?;6%X7V1O;2<@/3X@(F1O;6%I;G,B+`H))VQI
M;6ET7U]U;FET<U]M87A?;6%I;&QI<W1S)R`]/B`B;6%I;&EN9R!L:7-T<R(L
M"@DG;&EM:71?7W5N:71S7VUA>%]M9R<@/3X@(FUA:6P@9W)O=7!S(BP*"2=L
M:6UI=%]?=6YI='-?;6%X7W)E9&ER)R`]/B`B<F5D:7)E8W1S(BP*"2=L:6UI
M=%]?=6YI='-?;6%X7W)E<W`G(#T^(")A=71O<F5S<&]N9&5R<R(L"@DG;&EM
M:71?7W5N:71S7VUA>%]S=6)D;VTG(#T^(")S=6)D;VUA:6YS(BP*"2=L:6UI
M=%]?=6YI='-?;6%X7W1R869F:6,G(#T^(")-0B]M;VYT:"(L"@DG;&EM:71?
M7W5N:71S7VUA>%]W96)A<'!S)R`]/B`B2F%V82!A<'!L:6-A=&EO;G,B+`H)
M)VQI;6ET7U]U;FET<U]M87A?=W4G(#T^(")W96(@=7-E<G,B+`H))VQI;6ET
M7U]U;FET<U]M8F]X7W%U;W1A)R`]/B`B2T(B+`H*"2=L;V-A;&5?=7!L;V%D
M7U]T:71L92<@/3X@)T%D9"!,;V-A;&4G+`H))VQO8V%L95]U<&QO861?7V9I
M;&5?;F%M92<@(#T^("=0871H('1O('1H92!L86YG=6%G92!P86-K(&9I;&4@
M;&]C871I;VXG+`H))VQO8V%L95]U<&QO861?7W5N86)L95]T;U]I;G-T86QL
M)R`@/3X@)U5N86)L92!T;R!I;G-T86QL('1H92!L86YG=6%G92!P86-K(&9I
M;&4G+`H))VQO8V%L97-?;&ES=%]?=&ET;&4G("`@("`@(#T^("=,86YG=6%G
M92!P86-K<R!R97!O<VET;W)Y)RP*"2=L;V-A;&5S7VQI<W1?7VQE9V5N9"<@
M("`@("`@/3X@)T%V86EL86)L92!L86YG=6%G97,G+`H))VQO8V%L97-?;&ES
M=%]?86-T:79E7W1I=&QE)PD]/B`G4R<L"@DG;&]C86QE<U]L:7-T7U]L;V-A
M;&5?=&ET;&4G"3T^("=,86YG=6%G92!P86-K)RP*"2=L;V-A;&5S7VQI<W1?
M7VQA;F=?=&ET;&4G"0D]/B`G3&%N9W5A9V4G+`H))VQO8V%L97-?;&ES=%]?
M8V]U;G1R>5]T:71L92<)/3X@)T-O=6YT<GDG+`H))VQO8V%L97-?;&ES=%]?
M=7-E9%]T:71L92<)"3T^("=5<V5D)RP*"@DG;&]C86QE<U]R96UO=F5?7W1I
M=&QE)R`@("`@/3X@)TQO8V%L97,@4F5M;W9A;"<L"@DG;&]C86QE<U]R96UO
M=F5?7W-E;&5C=%]L;V-A;&5S7V9O<E]R96UO=F4G(#T^("=396QE8W0@=&AE
M(&QO8V%L97,@=&\@8F4@<F5M;W9E9"XG+`H))VQO8V%L97-?7V-A;E]N;W1?
M<F5M;W9E)R`@(#T^("=5;F%B;&4@=&\@<F5M;W9E('1H92!L86YG=6%G92!P
M86-K(&9O<B!L;V-A;&4@)3$Z("4R)RP*"@DG;&]G7V9I;&5?=FEE=V5R7U]F
M:6QE7VYA;65?:7-?=6YD969I;F5D)R`]/B`B4W!E8VEF>2!T:&4@;&]G(&9I
M;&5N86UE(&9O<B!V:65W:6YG+B(L"@DG;&]G7V9I;&5S7U]D96QE=&EO;E]P
M86=E7W1I=&QE)R`]/B`B5&AE(&9O;&QO=VEN9R!L;V<@9FEL97,@9F]R(&1O
M;6%I;B`E,2!W:6QL(&)E(')E;6]V960Z(BP*"2=L;V=?9FEL97-?7VEN=F%L
M:61?=F%L=65?;&EN97-?9F]R7W9I97<G(#T^("));G9A;&ED(&YU;6)E<B!O
M9B!L:6YE<R!S<&5C:69I960N(BP*"2=L;V=?9FEL97-?7VQI;F5S7V]F7VQO
M9V9I;&5?9F]R7W9I97<G(#T^("),:6YE<R!O9B!L;V<@9FEL92!T;R!B92!D
M:7-P;&%Y960@*&9R;VT@=&AE(&5N9"!O9B!T:&4@9FEL92DB+`H))VQO9U]F
M:6QE<U]?;&]G7V9I;&5?8V%N7VYO=%]B95]D96QE=&5D)R`]/B`B5&AI<R!L
M;V<@9FEL92!I<R!A8W1I=F4@86YD('1H97)E9F]R92!C86YN;W0@8F4@9&5L
M971E9"XB+`H))VQO9U]F:6QE<U]?;&]G7V9I;&5S)R`]/B`B3&]G(&9I;&5S
M(BP*"2=L;V=?9FEL97-?7W!A9V5?=&ET;&4G(#T^("),;V<@9FEL97,@;6%N
M86=E;65N="!F;W(@9&]M86EN("4Q(BP*"2=L;V=?9FEL97-?7W-E;&5C=%]F
M:6QE<U]F;W)?<F5M;W9E)R`]/B`B3F\@;&]G(&9I;&5S('-E;&5C=&5D(&9O
M<B!R96UO=F%L+B(L"@DG;&]G7V9I;&5S7U]T;W1A;%]L;V=F:6QE<U]S:7IE
M)R`]/B`B3&]G(&9I;&5S('1O=&%L('-I>F4Z("4Q(BP*"2=L;V=?<F]T7U]C
M;VUP<F5S<R<@/3X@(D-O;7!R97-S(&QO9R!F:6QE<R(L"@DG;&]G7W)O=%]?
M;&]G7W)O=%]P97)I;V0G(#T^("),;V<@<F]T871I;VX@8V]N9&ET:6]N(BP*
M"2=L;V=?<F]T7U]L;V=?<F]T7W-I>F4G(#T^(")B>2!S:7IE(BP*"2=L;V=?
M<F]T7U]L;V=?<F]T7W1I;64G(#T^(")B>2!T:6UE(BP*"2=L;V=?<F]T7U]L
M;V=R;W1A=&EO;E]E;F%B;&4G(#T^(")%;F%B;&4@;&]G(')O=&%T:6]N(BP*
M"2=L;V=?<F]T7U]M86EL)R`]/B`B4V5N9"!P<F]C97-S960@;&]G(&9I;&5S
M('1O(&4M;6%I;"(L"@DG;&]G7W)O=%]?;6%X7VYU;6)E<E]O9E]L;V=F:6QE
M<R<@/3X@(DUA>&EM=6T@;G5M8F5R(&]F(&QO9R!F:6QE<R(L"@DG;&]G7W)O
M=%]?<&%G95]T:71L92<@/3X@(DQO9R!R;W1A=&EO;B!P<F5F97)E;F-E<R!F
M;W(@9&]M86EN("4Q(BP*"2=L;V=?<F]T7U]T:6UE7W!E<FEO9"<@/3X@(G!E
M<FEO9"(L"@DG;&]G:6Y?=7!?7V%C8V5S<U]D96YI961?86-C;W5N=%]D:7-A
M8FQE9"<@/3X@(D%C8V5S<R!D96YI960N(%EO=7(@86-C;W5N="!H87,@8F5E
M;B!D:7-A8FQE9"XB+`H))VQO9VEN7W5P7U]D969A=6QT7VQO8V%L92<@/3X@
M)U5S97(@9&5F875L="<L"@DG;&]G:6Y?=7!?7V5N=&5R7VQO9VEN7V%N9%]P
M87-S=V0G(#T^(")%;G1E<B!Y;W5R(&QO9VEN(&YA;64@86YD('!A<W-W;W)D
M+B(L"@DG;&]G:6Y?=7!?7V9O<F=O=%]P87-S=V]R9%]L86)E;"<@/3X@(D9O
M<F=O="!Y;W5R('!A<W-W;W)D/R(L"@DG;&]G:6Y?=7!?7V9O<F=O=%]P87-S
M=V]R9%]T97AT)R`]/B`B268@>6]U(&9O<F=O="!Y;W5R('!A<W-W;W)D('=E
M('=I;&P@=')Y('1O(&AE;'`@>6]U(&)Y('-E;F1I;F<@:70@;W5T('1O('EO
M=7(@92UM86EL+B(L"@DG;&]G:6Y?=7!?7VQO9VEN7VAA<U]B965N7VQO8VME
M9"<@/3X@(D%C8V5S<R!D96YI960N(BP*"2=L;V=I;E]U<%]?;&]G:6Y?;&%B
M96Q?<&QE<VLG(#T^("),;V=I;B!4;R`E,2(L"@DG;&]G:6Y?=7!?7VQO9VEN
M7W1E>'0G(#T^(")%;G1E<B!T:&4@;&]G:6X@;F%M92!I;G1O(%PB3&]G:6Y<
M(B!A;F0@<&%S<W=O<F0@:6YT;R!T:&4@7")087-S=V]R9%PB(&9I96QD<R!R
M97-P96-T:79E;'DN(%1H96X@8VQI8VL@7"),;V=I;EPB+B(L"@DG;&]G:6Y?
M=7!?7W5N86)L95]T;U]C:&5C:U]P87-S)R`]/B`B56YA8FQE('1O(&-H96-K
M('!A<W-W;W)D.B`E,2(L"@DG;&]C86QE<U]L:7-T7U]M;'-?;&EM:70G(#T^
M(")4:&4@;&EM:70@;VX@=&AE(&UA>&EM=6T@;G5M8F5R(&]F(&QA;F=U86=E
M('!A8VMS(&ES(&5X8V5E9&5D+B!!8W1I=F4@;&%N9W5A9V5S("4Q+B!!;&QO
M=V5D(&QA;F=U86=E<R`E,BXB+`H))VQO9VEN7W5P7U]S:&]R=%]W87)N:6YG
M7VQI;6ET<U]L:6-E;F-E7VME>2<@/3X@(D%C8V5S<R!T;R!T:&4@8V]N=')O
M;"!P86YE;"!I<R!T96UP;W)A<FEL>2!U;F%V86EL86)L92X@4&QE87-E(&-O
M;G1A8W0@>6]U<B!P<F]V:61E<B!F;W(@9&5T86EL<RXB+`H))VQO9VEN7W5P
M7U]G<F%C95]P97)I;V0G(#T^("=9;W4@87)E(&-U<G)E;G1L>2!O<&5R871I
M;F<@=VET:&EN('1H92!G<F%C92!P97)I;V0@;V8@>6]U<B!P<F]D=6-T(&QI
M8V5N<V4@*"4S*2X@5&\@=7!D871E('EO=7(@<')O9'5C="!L:6-E;G-E('5S
M92!T:&4@4F5T<FEE=F4@2V5Y<R!F=6YC=&EO;B!O9B`E,4QI8V5N<V4@36%N
M86=E<B4R+B<L"@DG;&]G:6Y?=7!?7W!A<G1N97)?;&EC96YS95]M97-S86=E
M)R`]/B`G66]U(&%R92!C=7)R96YT;'D@;W!E<F%T:6YG('=I=&@@82!L:6UI
M=&5D('!R;V1U8W0@;&EC96YS92!T:&%T(')E<75I<F5S(')E9VES=')A=&EO
M;B!P<FEO<B!T;R!A8W1I=F%T:6YG('1H92!F=6QL(&9E871U<F4@<V5T+B`@
M5&\@=7!D871E('EO=7(@<')O9'5C="!L:6-E;G-E('-E;&5C="!T:&4@4F5T
M<FEE=F4@2V5Y<R!O<'1I;VX@9G)O;2!W:71H:6X@)3%,:6-E;G-E($UA;F%G
M97(E,BXG+`H))VUA7U]C<F5A=&5?=&ET;&4G(#T^("=#<F5A=&EN9R!M86EL
M(&%L:6%S(&9O<B`E,2<L"@DG;6%?7V5D:71?=&ET;&4G(#T^(")%9&ET(&UA
M:6P@86QI87,@)3$B+`H))VUA7U]E;G1E<E]N97=?86QI87,G(#T^(")%;G1E
M<B!N97<@86QI87,N(BP*"2=M85]?:6YV86QI9%]A;&EA<R<@/3X@(DEN=F%L
M:60@;6%I;"!A;&EA<RXB+`H))VUA7U]M86EL7V%L:6%S97-?;6%I;&YA;64G
M(#T^(")-86EL(&%L:6%S97,@9F]R(&UA:6P@;F%M92`E,2(L"@DG;6%?7VUA
M:6QN86UE7V1O97-?;F]T7V5X:7-T)R`]/B`B36%I;"!N86UE(&1O97,@;F]T
M(&5X:7-T+B(L"@DG;6%?7W-E;&5C=%]M85]F;W)?<F5M;W9E)R`]/B`B4V5L
M96-T(&UA:6P@86QI87-E<R!T;R!B92!R96UO=F5D+B(L"@DG;6%?7W5N86)L
M95]T;U]A9&1?;F5W7VUA)R`]/B`B56YA8FQE('1O(&%D9"!N97<@;6%I;"!A
M;&EA<SH@)3$B+`H))VUA:6Q?7V%L;&]W7W-H;W)T7W!O<#-?;F%M97,G(#T^
M(").86UE<R!F;W(@4$]0,R])34%0(&UA:6P@86-C;W5N=',B+`H))VUA:6Q?
M7V%L;&]W7W-H;W)T7W!O<#-?;F%M97-?9&ES86)L960G(#T^(")/;FQY('5S
M92!O9B!F=6QL(%!/4#,O24U!4"!M86EL(&%C8V]U;G1S(&YA;65S(&ES(&%L
M;&]W960B+`H))VUA:6Q?7V%L;&]W7W-H;W)T7W!O<#-?;F%M97-?96YA8FQE
M9"<@/3X@(E5S92!O9B!S:&]R="`H=V5B;6%S=&5R*2!A;F0@9G5L;"`H=V5B
M;6%S=&5R0&1O;6%I;BYC;VTI(%!/4#,O24U!4"!M86EL(&%C8V]U;G0@;F%M
M97,@:7,@86QL;W=E9"(L"@DG;6%I;%]?8F%D9&]M86EN7V5X:7-T<R<@/3X@
M(E5N86)L92!T;R!A9&0@9&]M86EN('1O('1H92!B;&%C:R!L:7-T.B!S=6-H
M(&1O;6%I;B!A;')E861Y(&5X:7-T<R(L"@DG;6%I;%]?8FQO8VM?;6%I;%]F
M<F]M7V1O;7,G(#T^(")";&%C:R!,:7-T(BP*"2=M86EL7U]B;&]C:V5R<R<@
M/3X@(D)L;V-K960@9&]M86EN<R(L"@DG;6%I;%]?8FQO8VME<G-?<F5M;W9E
M)R`]/B`B4F5M;W9E(&)L;V-K960@9&]M86EN<R(L"@DG;6%I;%]?8FQO8VME
M<E]A9&0G(#T^(")!9&0@9&]M86EN<R!T;R!B;&%C:R!L:7-T(BP*"2=M86EL
M7U]C;&]S960G(#T^(")C;&]S960B+`H))VUA:6Q?7V-R>7!T961?<&%S<W=D
M7VUA=&-H)R`]/B`B5&AE<F4@87)E(&UA:6P@;F%M97,@;6%T8VAI;F<@=&AE
M(&5N8W)Y<'1E9"!P87-S=V]R9',N(BP*"2=M86EL7U]D;VU?:6Y?;&ES="<@
M/3X@(D1O;6%I;B!I<R!A;')E861Y(&EN('1H92!B;&%C:R!L:7-T+B(L"@DG
M;6%I;%]?96YA8FQE7W)B;"<@/3X@(D5N86)L92!-05!3('-P86T@<')O=&5C
M=&EO;B(L"@DG;6%I;%]?96YT97)?<F)L7W-E<G9E<B<@/3X@(E1Y<&4@:6X@
M=&AE($U!4%,@>F]N92XB+`H))VUA:6Q?7V5N=&5R7W)I9VAT7VEP7VUA<VLG
M(#T^(")%;G1E<B!T:&4@:7`@;6%S:R!B971W965N(#$@86YD(#,R(BP*"2=M
M86EL7U]E;G1E<E]R:6=H=%]I<%]M87-K7S(T)R`]/B`B16YT97(@=&AE(&EP
M(&UA<VL@8F5T=V5E;B`R-"!A;F0@,S(B+`H))VUA:6Q?7VEN<W1A;&Q?<F)L
M<VUT<&1?<')O9W)A;2<@/3X@(DEN<W1A;&P@=&AE(')B;'-M='`@<V]F='=A
M<F4N(BP*"2=M86EL7U]I;G9A;&ED7V1O;5]N86UE)R`]/B`B1&]M86EN(&YA
M;64@)3$@:7,@:6YV86QI9"XB+`H))VUA:6Q?7VEN=F%L:61?<&]P7VQO8VM?
M=&EM92<@/3X@(E!/4#,@;&]C:R!T:6UE(&ES(&EN=F%L:60N(BP*"2=M86EL
M7U]I;G9A;&ED7W)B;%]S97)V97(G(#T^(")-05!3('IO;F4@;F%M92!I<R!I
M;G9A;&ED+B(L"@DG;6%I;%]?:7!?86YD7VUA<VLG(#T^("))4"!A9&1R97-S
M+VUA<VLB+`H))VUA:6Q?7VEP7V%N9%]M87-K7V5X:7-T<R<@/3X@(E-U8V@@
M:7`@861D<F5S<R]N971M87-K('!A:7(@86QR96%D>2!E>&ES=',N(BP*"2=M
M86EL7U]I<%]O<E]M87-K7VES7VEN=F%L:60G(#T^("))4"!A9&1R97-S+VYE
M="!M87-K('!A:7(@:7,@:6YV86QI9"XB+`H))VUA:6Q?7VQO8VM?=&EM92<@
M/3X@(FQO8VL@=&EM92(L"@DG;6%I;%]?;6%I;%]O<'1I;VYS)R`]/B`B36%X
M:6UU;2!L971T97(@<VEZ92!A;F0@<F5L87D@;6]D92!P87)A;65T97)S(BP*
M"2=M86EL7U]M86EL;F%M97-?<&%S<W=D7VUA=&-H)R`]/B`B5&AE<F4@87)E
M(&UA:6P@;F%M92!A;F0@<&%S<W=O<F0@<&%I<G,@;6%T8VAI;F<N(BP*"2=M
M86EL7U]S96QE8W1?9&]M86EN<U]F;W)?<F5M;W9E)R`]/B`B4V5L96-T('1H
M92!D;VUA:6YS('1O(&)E(')E;6]V960N(BP*"@DO+R!E;F0@;V8@;6%V97)I
M8VL@<&%R=`H*"@DO+R!K;V]P97(@<&%R=`H*"2=M86EL7U]M87A?<VEZ92<@
M/3X@(DUA>&EM=6T@;&5T=&5R('-I>F4B+`H))VUA:6Q?7VUB;WA?<75O=&$G
M(#T^(")-86EL8F]X('%U;W1A(BP*"2=M86EL7U]M:6XG(#T^(")-:6XB+`H)
M)VUA:6Q?7W1O=&%L7V9I;&5S7W-I>F4G(#T^(")4;W1A;"!R97!O<VET;W)Y
M('-I>F4Z("4Q(BP*"2=M86EL7U]F:6QE;F%M95]A;')E861Y7VEN7W)E<&]S
M:71O<GDG(#T^(")&:6QE('=I=&@@<W5C:"!N86UE(&ES(&%L<F5A9'D@:6X@
M<F5P;W-I=&]R>2(L"@DG;6%I;%]?;F]?=VAI=&5?;&ES=%]M87-K7V9E871U
M<F5?,C0G(#T^(")0;&5A<V4L('5S92`R-"!O<B!H:6=H97(@87,@;6%S:R!V
M86QU92Y<;EEO=7(@;6%I;"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S971T
M:6YG(&UA<VMS+B!792!C86X@;VYL>2!E;75L871E('-E='1I;F<@;6%S:R!F
M;W(@=F%L=65S(&YO="!L97-S('1H86X@,C0N(BP*"2=M86EL7U]O<&5N)R`]
M/B`B;W!E;B(L"@DG;6%I;%]?;W!E;E]R96QA>5]W87)N:6YG)R`]/B`B4V5T
M=&EN9R!Y;W5R(&UA:6P@<F5L87D@=&\@;W!E;B!E>'!O<V5S('EO=7(@;6%I
M;"!S97)V97(@=&\@<W!A;6UI;F<@86)U<V4N7&Y<;DET('-H;W5L9"!O;FQY
M(&)E('5S960@9F]R('1E;7!O<F%R>2!T97-T:6YG(&]F('EO=7(@;6%I;"!S
M97)V97(@;W(@:6X@:6YS=&%N8V5S('=H97)E('EO=2!A<F4@;W!E<F%T:6YG
M(%!L97-K(&9R;VT@:6YT97)N86P@;F5T=V]R:R!N;W0@86-C97-S:6)L92!V
M:6$@=&AE($EN=&5R;F5T+EQN7&Y!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@
M:V5E<"!T:&ES('-E='1I;F<_(BP*"2=M86EL7U]P;W`S)R`]/B`B4$]0,R(L
M"@DG;6%I;%]?<')E9F5R96YC97,G(#T^(")-86EL('!R969E<F5N8V5S(BP*
M"2=M86EL7U]R8FQ?>F]N97,G(#T^(")-05!3('IO;F5S(BP*"2=M86EL7U]R
M96QA>5]F<F]M7VEP)R`]/B`B5VAI=&4@3&ES="(L"@DG;6%I;%]?<F5L87EI
M;F<G(#T^(")296QA>6EN9R(L"@DG;6%I;%]?<F5Q<E]A=71H)R`]/B`B875T
M:&]R:7IA=&EO;B!I<R!R97%U:7)E9#H@(BP*"2=M86EL7U]S;71P)R`]/B`B
M4TU44"(L"@DG;6%I;%]?=6YA8FQE7V%D9%]N97=?;6%I;%]N86UE)R`]/B`B
M56YA8FQE('1O(&%D9"!N97<@;6%I;"!N86UE.B`E,2(L"@DG;6%I;%]?=VAI
M=&5?;&ES="<@/3X@(E=H:71E($QI<W0B+`H))VUA:6Q?7W=H:71E7VQI<W1?
M861D)R`]/B`G061D($YE=R!.971W;W)K)RP*"2=M86EL7U]W:&ET95]L:7-T
M7W)E;6]V92<@/3X@)U1H92!F;VQL;W=I;F<@;F5T=V]R:W,@=VEL;"!B92!R
M96UO=F5D.B<L"@DG;6%I;%]?=VAI=&5?;&ES=%]M96UB97(G(#T^("=!;&QO
M=V5D(&YE='=O<FMS)RP*"2=M86EL7U]W:&ET95]L:7-T7V5M<'1Y7W-E;&5C
M=&EO;E]F;W)?<F5M;W9E)R`]/B`G4V5L96-T('1H92!E;G1R:65S('1O(&)E
M(')E;6]V960N)RP*"2=M86EL7W%U975E7U]T;V]L<U]L96=E;F0G(#T^("=4
M;V]L<R<L"@DG;6%I;%]Q=65U95]?:6YF;U]L96=E;F0G(#T^("=);F9O)RP*
M"2=M86EL7W%U975E7U]M97-S86=E<U]L:7-T7VQE9V5N9"<@/3X@)TUE<W-A
M9V5S(&EN(&UA:6P@<75E=64G+`H))VUA:6Q?<75E=65?7W$G(#T^("=1)RP*
M"2=M86EL7W%U975E7U]S=6)J96-T)R`]/B`G4W5B:F5C="<L"@DG;6%I;%]Q
M=65U95]?96YV96QO<&5?<V5N9&5R)R`]/B`G4V5N9&5R)RP*"2=M86EL7W%U
M975E7U]E;G9E;&]P95]R96-I<&EE;G1S)R`]/B`G4F5C:7!I96YT<R<L"@DG
M;6%I;%]Q=65U95]?9&%T92<@/3X@)T1A=&4G+`H))VUA:6Q?<75E=65?7V%G
M92<@/3X@)T%G92<L"@DG;6%I;%]Q=65U95]?<VEZ92<@/3X@)U-I>F4G+`H)
M)VUA:6Q?<75E=65?7VUE<W-A9V5S)R`]/B`G;65S<V%G97,G+`H))VUA:6Q?
M<75E=65?7VEN9F]?=&5X="<@/3X@)TUE<W-A9V5S(&EN('%U975E.B`E,2!N
M;W0@<')E<')O8V5S<V5D+"`E,B!L;V-A;"P@)3,@<F5M;W1E+"`E-"!T;W1A
M;"XG+`H))VUA:6Q?<75E=65?7W-E;&5C=%]?86QL)R`]/B`G06QL)RP*"2=M
M86EL7W%U975E7U]S96QE8W1?7W1O9&\G(#T^("=.;W0@4')E<')O8V5S<V5D
M)RP*"2=M86EL7W%U975E7U]S96QE8W1?7W)E;6]T92<@/3X@)U)E;6]T92<L
M"@DG;6%I;%]Q=65U95]?<V5L96-T7U]L;V-A;"<@/3X@)TQO8V%L)RP*"2=M
M86EL7W%U975E7U]S96QE8W1?7VQO8V%L7V%N9%]R96UO=&4G(#T^("=,;V-A
M;"!A;F0@4F5M;W1E)RP*"2=M86EL7W%U975E7U]Q=65U92<@/3X@)U%U975E
M<R<L"@DG;6%I;%]Q=65U95]?96YV96QO<&4G(#T^("=%;G9E;&]P92<L"@DG
M;6%I;%]Q=65U95]?<V5N9&5R)R`]/B`G4V5N9&5R)RP*"2=M86EL7W%U975E
M7U]R96-I<&EE;G0G(#T^("=296-I<&EE;G0G+`H))VUA:6Q?<75E=65?7W-T
M87)T7V1A=&4G(#T^("=3=&%R="<L"@DG;6%I;%]Q=65U95]?96YD7V1A=&4G
M(#T^("=%;F0G+`H))VUA:6Q?<75E=65?7VUI;E]A9V4G(#T^("=-:6YI;75M
M)RP*"2=M86EL7W%U975E7U]M87A?86=E)R`]/B`G36%X:6UU;2<L"@DG;6%I
M;%]Q=65U95]?;6EN7W-I>F4G(#T^("=-:6YI;75M)RP*"2=M86EL7W%U975E
M7U]M87A?<VEZ92<@/3X@)TUA>&EM=6TG+`H))VUA:6Q?<75E=65?7V5M<'1Y
M7W-E;&5C=&EO;B<@/3X@)TYO(&UE<W-A9V5S('-E;&5C=&5D+B<L"@DG;6%I
M;%]Q=65U95]?<F5M;W9E7VUE<W-A9V5S7V-O;F9I<FTG(#T^("=$;R!Y;W4@
M<F5A;&QY('=A;G0@=&\@<F5M;W9E('1H92!S96QE8W1E9"!M97-S86=E<R!F
M<F]M('1H92!Q=65U93\G+`H))VUA:6Q?<75E=65?7VYO=%]A;&QO=V5D7V)Y
M7VQI8V5N<V5?:V5Y)R`]/B`G36%I;"!Q=65U92!M86YA9V5M96YT(&ES(&YO
M="!A;&QO=V5D(&)Y('1H92!L:6-E;G-E(&ME>2XG+`H))V)T7W-H;W=?861V
M86YC961?<V5A<F-H)R`]/B`G4VAO=R!!9'9A;F-E9"!396%R8V@G+`H))V)T
M7VAI9&5?861V86YC961?<V5A<F-H)R`]/B`G2&ED92!!9'9A;F-E9"!396%R
M8V@G+`H))VUA:6QL:7-T7U\G(#T^(")-86EL:6YG(&QI<W0@)3$B+`H))VUA
M:6QL:7-T7U]A;')E861Y7V5X:7-T<R<@/3X@(DUA:6QI;F<@;&ES="!A;')E
M861Y(&5X:7-T<RXB+`H))VUA:6QL:7-T7U]C<F5A=&5?;6%I;&QI<W1?9F]R
M)R`]/B`B0W)E871E(&$@;6%I;&EN9R!L:7-T(&9O<B!D;VUA:6X@)3$B+`H)
M)VUA:6QL:7-T7U]E;6%I;%]?)R`]/B`B36%I;&EN9R!L:7-T(&%D;6EN:7-T
M<F%T;W(G<R!E;6%I;"`E,2(L"@DG;6%I;&QI<W1?7VEN=F%L:61?96UA:6PG
M(#T^(")!9&UI;FES=')A=&]R)W,@96UA:6P@:7,@:6YV86QI9"(L"@DG;6%I
M;&QI<W1?7VEN=F%L:61?;F%M92<@/3X@(E1H92!M86EL:6YG(&QI<W0@;F%M
M92!I<R!I;G9A;&ED(BP*"2=M86EL;&ES=%]?:6YV97)T7V]N7V]F9C\G(#T^
M(")#:&%N9V4@=&AE('-T871E(&]F('-E;&5C=&5D(&UA:6QI;F<@;&ES=',_
M(BP*"2=M86EL;&ES=%]?:6YV97)T7V]N7V]F9E]O;F4_)R`]/B`B0VAA;F=E
M('1H92!S=&%T92!O9B!T:&4@;6%I;&EN9R!L:7-T/R(L"@DG;6%I;&QI<W1?
M7VUA:6Q?86QI87-?86QR96%D>5]E>&ES='-?:6Y?=&AI<U]D;VUA:6XG(#T^
M(")4:&4@;6%I;"!A;&EA<R`E,2!A;')E861Y(&5X:7-T<R!I;B!T:&ES(&1O
M;6%I;B(L"@DG;6%I;&QI<W1?7VYA;65?7R<@/3X@(DUA:6QI;F<@;&ES="!N
M86UE("4Q(BP*"2=M86EL;&ES=%]?;F5W7U\G(#T^(")#<F5A=&4@;F5W(&UA
M:6QI;F<@;&ES="`E,2(L"@DG;6%I;&QI<W1?7VYO=&EF>5]?)R`]/B`B3F]T
M:69Y(&%D;6EN:7-T<F%T;W(@;V8@=&AE(&UA:6QI;F<@;&ES="!C<F5A=&EO
M;B(L"@DG;6%I;&QI<W1S7U\G(#T^(")-86EL:6YG(&QI<W1S("4Q(BP*"2=M
M86EL;&ES='-?7VQI;6ET7V-L7VUA>%]M86EL;&ES=',G(#T^(")4:&4@;&EM
M:70@;VX@;G5M8F5R(&]F(&UA:6QI;F<@;&ES=',@:&%S(&)E96X@<F5A8VAE
M9"!F;W(@=&AE(&-L:65N="`H;&EM:70Z("4Q+"!U<V5D.B`E,BDB+`H))VUA
M:6QL:7-T<U]?;&EM:71?9&]M7VUA>%]M86EL;&ES=',G(#T^(")4:&4@;&EM
M:70@;VX@;G5M8F5R(&]F(&UA:6QI;F<@;&ES=',@:&%S(&)E96X@<F5A8VAE
M9"!F;W(@=&AE(&1O;6%I;BXB+`H))VUA:6QL:7-T<U]?;&ES="<@/3X@(DUA
M:6QI;F<@;&ES=',B+`H))VUA:6QL:7-T<U]?;&ES='-?;V9?9&]M86EN7U\G
M(#T^(")-86EL:6YG(&QI<W1S(&EN(&1O;6%I;B`E,2(L"@DG;6%I;&QI<W1S
M7U]M86EL;6%N7VYO=%]I;G-T86QL961?;W)?8V]N9B<@/3X@(EQN36%I;&UA
M;B!397)V97(@17AT96YS:6]N<R!A<F4@;F]T(&-U<G)E;G1L>2!I;G-T86QL
M960@;W(@8V]N9FEG=7)E9%QN;VX@=&AE('-E<G9E<BX@0V]N=&%C="!T:&4@
M<V5R=F5R(&%D;6EN:7-T<F%T;W(@=&\@:&%V92!T:&4@36%I;&UA;B!397)V
M97(@17AT96YS:6]N<R!I;G-T86QL960@;W(@<')O<&5R;'D@8V]N9FEG=7)E
M9"XB+`H))VUA:6QL:7-T<U]?<F5M;W9E7VUA:6QL:7-T<U]O;E]D;VUA:6XG
M(#T^(")296UO=FEN9R!M86EL:6YG(&QI<W1S(&9R;VT@9&]M86EN("4Q+B(L
M"@DG;6%I;&QI<W1S7U]S96QE8W1?;6%I;&QI<W1?9F]R7VEN=F5R=%]O;E]O
M9F8G(#T^(")9;W4@<VAO=6QD('-E;&5C="!A="!L96%S="!O;F4@;6%I;&EN
M9R!L:7-T+B(L"@DG;6%I;&QI<W1S7U]S96QE8W1?;6%I;&QI<W1?9F]R7W)E
M;6]V92<@/3X@(E-E;&5C="!T:&4@;6%I;&EN9R!L:7-T<R!T;R!B92!R96UO
M=F5D+B(L"@DG;6%I;&QI<W1S7U]S96QE8W1?;6%I;&QI<W1S7W1O7W)E;6]V
M92<@/3X@(E-E;&5C="!O;F4@;W(@<V5V97)A;"!M86EL:6YG(&QI<W1S('1O
M(&)E(')E;6]V960N(BP*"2=M86EL;&ES='-?7W-T871U<R<@/3X@(DUA:6QI
M;F<@;&ES="!S97)V:6-E(&ES(&5N86)L960B+`H))VUA:6QL:7-T<U]?=6YA
M8FQE7W1O7V1E;&5T95]?)R`]/B`B56YA8FQE('1O(&1E;&5T92!T:&4@;6%I
M;&EN9R!L:7-T.B`E,2(L"@DG;6%I;&QI<W1S7U]D:7-A8FQE9%]T97AT)R`]
M/B`G66]U(&-A;FYO="!M86YA9V4@=&AE(&UA:6QI;F<@;&ES=',@8F5C875S
M92!T:&4@36%I;&UA;B!C;VUP;VYE;G0@:7,@;F]T(&EN<W1A;&QE9"!O<B!C
M;VYF:6=U<F5D+B<L"@DG;6%I;&QI<W1S7U]D:7-A8FQE9%]T97AT7V%D;6EN
M)R`]/B`G66]U(&-A;FYO="!M86YA9V4@=&AE(&UA:6QI;F<@;&ES=',@8F5C
M875S92!T:&4@36%I;&UA;B!C;VUP;VYE;G0@:7,@;F]T(&EN<W1A;&QE9"!O
M<B!C;VYF:6=U<F5D+B!0;&5A<V4@=7-E('1H92!-86EL;6%N(&-O;F9I9W5R
M871I;VX@9G5N8W1I;VX@870@=&AE(%-E<G9E<B!!9&UI;FES=')A=&EO;B!0
M86=E+B<L"@DG;6%I;&QI<W1S7U]D:7-A8FQE9%]T97AT7W5S97(G(#T^("=9
M;W4@8V%N;F]T(&UA;F%G92!T:&4@;6%I;&EN9R!L:7-T<R!B96-A=7-E('1H
M92!-86EL;6%N(&-O;7!O;F5N="!I<R!N;W0@:6YS=&%L;&5D(&]R(&-O;F9I
M9W5R960N(%!L96%S92!C;VYT86-T('EO=7(@<V5R=F5R(&%D;6EN:7-T<F%T
M;W(@=&\@:&%V92!T:&4@36%I;&UA;B!I;G-T86QL960N)RP*"2=M86EL;&ES
M='-?8V]N9E]?<&%G95]T:71L92<@/3X@(D-O;F9I9W5R:6YG($UA:6QI;F<@
M3&ES=',@36%N86=E<B(L"@DG;6%I;&QI<W1S7V-O;F9?7W-U8V-E<W-F=6PG
M(#T^("=4:&4@36%I;&UA;B!S;V9T=V%R92!H87,@8F5E;B!S=6-C97-S9G5L
M;'D@8V]N9FEG=7)E9"P@<V\@=&AE(%-E="!5<"!-86EL;6%N(&)U='1O;B!W
M:6QL(&YO(&QO;F=E<B!B92!A8V-E<W-I8FQE(&9R;VT@=&AE(%-E<G9E<B!!
M9&UI;FES=')A=&EO;B!S8W)E96XN)RP*"2=M86EL;&ES=%]M96UB97)?961I
M=%]?=&ET;&4G(#T^(")!9&0@3F5W(%-U8G-C<FEB97(B+`H))VUA:6QL:7-T
M7VUE;6)E<G-?7W1I=&QE)R`]/B`G)3$@4W5B<V-R:6)E<G,G+`H))VUA:6QL
M:7-T7VUE;6)E<G-?7W-E;&5C=%]F;W)?<F5M;W9E)R`]/B`B4V5L96-T('1H
M92!S=6)S8W)I8F5R<R!T;R!B92!R96UO=F5D+B(L"@DG;6%I;&QI<W1?;65M
M8F5R<U]R96UO=F5?7W1I=&QE)R`]/B`G4F5M;W9E(&UA:6QI;F<@;&ES="!S
M=6)S8W)I8F5R<R<L"@DG;6%I;&QI<W1?;65M8F5R7U]A;')E861Y7V5X:7-T
M<R<@/3X@)TUA:6QI;F<@;&ES="!S=6)S8W)I8F5R(&%L<F5A9'D@97AI<W1S
M+B<L"@DG;6%I;&QI<W1?;65M8F5R7U]N;W1?97AI<W1S)R`]/B`G5&AE<F4@
M:7,@;F\@<W5C:"!U<V5R(&]N('1H92!M86EL:6YG(&QI<W0N)RP*"2=M86YA
M9V5R7U]A8V-E<W-?9&5N:65D)R`]/B`B06-C97-S(&1E;FEE9#H@)3$B+`H)
M)VUA;F%G97)?7V%D;6EN)R`]/B`B061M:6YI<W1R871O<B(L"@DG;6%N86=E
M<E]?8VQI96YT)R`]/B`B0VQI96YT(BP*"2=M86YA9V5R7U]D;VUA:6XG(#T^
M(")$;VUA:6XB+`H))VUA;F%G97)?7V1O;6%I;E]C;%]L:6UI=%]E>&-E961I
M;F<G(#T^(")4:&4@;&EM:70@;VX@;G5M8F5R(&]F(&1O;6%I;G,@:7,@<F5A
M8VAE9"!F;W(@=&AI<R!C;&EE;G0@86-C;W5N="(L"@DG;6%N86=E<E]?9&]M
M86EN7VES7VYO=%]Y;W5R<R<@/3X@(D1O;6%I;B`E,2!D;V5S(&YO="!B96QO
M;F<@=&\@>6]U(BP*"2=M86YA9V5R7U]D;VUA:6Y?:V5Y7VQI;6ET7V5X8V5E
M9&EN9R<@/3X@(E1H92!L:6UI="!O;B!D;VUA:6X@8W)E871I;VX@9&5F:6YE
M9"!B>2!Y;W5R(&QI8V5N<V4@:V5Y(&ES(')E86-H960B+`H))VUA;F%G97)?
M7VYO7W!E<FU?=&]?8V%L;"<@/3X@(EEO=2!D;R!N;W0@:&%V92!T:&4@<&5R
M;6ES<VEO;B!T;R!C86QL("4Q(BP*"2=M86YA9V5R7U]N;U]P97)M7W1O7V-R
M96%T95]D;VUA:6YS)R`]/B`B66]U(&1O(&YO="!H879E('1H92!P97)M:7-S
M:6]N('1O(&-R96%T92!D;VUA:6YS(BP*"2=M86YA9V5R7U]N;U]P97)M7W1O
M7VUO9&EF>5]D;VUA:6XG(#T^(")9;W4@9&\@;F]T(&AA=F4@=&AE('!E<FUI
M<W-I;VX@=&\@;6]D:69Y(&1O;6%I;B`E,2(L"@DG;6%N86=E<E]?;F]?<&5R
M;5]T;U]M;V1I9GE?9&]M86EN<R<@/3X@(EEO=2!D;R!N;W0@:&%V92!T:&4@
M<&5R;6ES<VEO;B!T;R!M;V1I9GD@9&]M86EN<R(L"@DG;6%N86=E<E]?;F]?
M<&5R;5]T;U]R96UO=F5?9&]M86EN)R`]/B`B66]U(&1O(&YO="!H879E('1H
M92!P97)M:7-S:6]N('1O(')E;6]V92!D;VUA:6X@)3$B+`H))VUA;F%G97)?
M7VYO7W!E<FU?=&]?<F5M;W9E7V1O;6%I;G,G(#T^(")9;W4@9&\@;F]T(&AA
M=F4@=&AE('!E<FUI<W-I;VX@=&\@<F5M;W9E(&1O;6%I;G,B+`H))VUA;F%G
M97)?7VYO9&5?9&]E<VYT7V5X:7-T)R`]/B`B)3$@9&]E<R!N;W0@97AI<W0B
M+`H))VUA;F%G97)?7W5S97)?9&ES86)L960G(#T^(")9;W5R(&%C8V]U;G0@
M:7,@9&ES86)L960N(%EO=2!C86YN;W0@;W!E<F%T92!T:&4@<WES=&5M+B(L
M"@DG;6)O>%]Q=6]T85]U;G-U<'!O<G1E9"<@/3X@(FYO="!S=7!P;W)T960@
M8GD@=&AE(&UA:6P@<V5R=F5R(BP*"2=M;E]?871T86-H7W)E;6]V92<@/3X@
M(E)E;6]V92!A='1A8VAM96YT<R(L"@DG;6Y?7V%T=&%C:%]S96QE8W1?9F]R
M7W)E;6]V92<@/3X@(E-E;&5C="!A='1A8VAM96YT<R!T;R!B92!R96UO=F5D
M+B(L"@DG;6Y?7V-R96%T95]T:71L92<@/3X@(D-R96%T92!M86EL(&YA;64B
M+`H))VUN7U]E9&ET7W1I=&QE)R`]/B`B4')E9F5R96YC97,B+`H))VUN7U]F
M:6QE<U]L:7-T7W1I=&QE)R`]/B`B071T86-H;65N="!&:6QE<R(L"@DG;6Y?
M7V9I;&5S7W)E;6]V92<@/3X@(E)E;6]V92!F:6QE<R!F<F]M(&%T=&%C:&UE
M;G1S(')E<&]S:71O<GDN(%1H:7,@9FEL97,@87)E('!O<W-I8FQY('5S960@
M8GD@875T;W)E<W!O;F1E<G,N(%1H97D@=VEL;"!B92!R96UO=F5D(&9R;VT@
M8F]T:#H@=&AE(')E<&]S:71O<GD@86YD(&%U=&]R97-P;VYD97)S('5S:6YG
M('1H96TN(BP*"2=M;E]?9FEL97-?<V5L96-T7V9O<E]R96UO=F4G(#T^(")3
M96QE8W0@9FEL97,@=&\@8F4@<F5M;W9E9"XB+`H))VUN7U]M86EL7V%L:6%S
M7V9O<FTG(#T^(")-86EL(&%L:6%S(&9O<FTB+`H))VUN7U]M86EL7V%L:6%S
M97-?;&ES="<@/3X@(DUA:6P@86QI87-E<R(L"@DG;6Y?7VUA:6QB;W@G(#T^
M(")-86EL8F]X(&UA;F%G96UE;G0B+`H))VUN7U]R961I<E]R96UO=F4G(#T^
M(")296UO=F4@;65M8F5R<R(L"@DG;6Y?7W)E9&ER7W-E;&5C=%]F;W)?<F5M
M;W9E)R`]/B`B4V5L96-T('1H92!M96UB97)S('1O(&)E(')E;6]V960N(BP*
M"2=M;E]?<F5S<%]R96UO=F4G(#T^(")296UO=F4@;6%I;"!A=71O<F5S<&]N
M9&5R<R(L"@DG;6Y?7W)E<W!?<V5L96-T7V9O<E]R96UO=F4G(#T^(")396QE
M8W0@=&AE(&%U=&]R97-P;VYD97)S('1O(&)E(')E;6]V960N(BP*"2=M;E]?
M<V5L96-T7V9I;&5S7V9O<E]A='1A8V@G(#T^(")396QE8W0@=&AE(&9I;&5S
M('1O(&)E(&%T=&%C:&5D+B(L"@DG;6Y?7W-E;&5C=%]M;E]F;W)?<F5M;W9E
M)R`]/B`B4V5L96-T('1H92!M86EL(&YA;65S('1O(&)E(')E;6]V960N(BP*
M"2=M;E]?=6YA8FQE7V1E9FEN95]M;B<@/3X@(E5N86)L92!T;R!D969I;F4@
M;6%I;"!N86UE<SH@)3$B+`H))VUN7U]U;F%B;&5?<F5M;W9E7VUB;WA?<75O
M=&$G(#T^(")5;F%B;&4@=&\@<F5S970@=&AE(&QI;6ET(&]N(&UA:6QB;W@@
M<VEZ93H@)3$B+`H))VUN7U]U<&QO861?9FEL92<@/3X@(E5P;&]A9"!F:6QE
M(BP*"2=M;E]E9&ET7U]A9&1?;6%I;%]G<F]U<%]M96UB97)S7V]R7W1U<FY?
M;V9F7V)O>"<@/3X@(EEO=2!S:&]U;&0@861D(&$@;6%I;"!G<F]U<"!M96UB
M97(@8F5F;W)E(&5N86)L:6YG('1H92!M86EL(&=R;W5P+B(L"@DG;6Y?961I
M=%]?861D7W)E<W!?;W)?='5R;E]O9F9?8F]X)R`]/B`B66]U('-H;W5L9"!A
M9&0@875T;W)E<W!O;F1E<B!O<B!D97-E;&5C="!T:&4@875T;W)E<W!O;F1E
M<B!C:&5C:V)O>"XB+`H))VUN7V5D:71?7V%T=&%C:&UE;G1S)R`]/B`B071T
M86-H;65N=',B+`H))VUN7V5D:71?7V1O;5]Q=6]T85]L97-S7W1H96Y?<75O
M=&$G(#T^(")4:&4@<VEZ92!O9B!T:&ES(&UA:6QB;W@@;75S="!N;W0@97AC
M965D('1H92!L:6UI="!O;B!A;6]U;G0@;V8@9&ES:R!S<&%C92!A;&QO8V%T
M960@9F]R(&AO=7-I;F<@;6%I;&)O>&5S(&EN('1H:7,@9&]M86EN+B(L"@DG
M;6Y?961I=%]?96YT97)?97AT97)N86Q?<F-P;G1?96UA:6PG(#T^(")%;G1E
M<B!E>'1E<FYA;"!M86EL(&=R;W5P(&UE;6)E<B=S(&4M;6%I;"(L"@DG;6Y?
M961I=%]?96YT97)?;6%I;%]R961I<E]O<E]T=7)N7V]F9E]B;W@G(#T^(")9
M;W4@<VAO=6QD(&5N=&5R(&$@;6%I;"!R961I<F5C="!O<B!D97-E;&5C="!T
M:&4@<F5D:7)E8W0@8VAE8VMB;W@N(BP*"2=M;E]E9&ET7U]E>'1?<F-P;G1?
M96UA:6Q?:6YV86QI9"<@/3X@(D5X=&5R;F%L(')E8VEP:65N="!E+6UA:6P@
M861D<F5S<R!I<R!I;G9A;&ED+B(L"@DG;6Y?961I=%]?9FEL95]E>&ES=',G
M(#T^(")&:6QE(&5X:7-T<RX@3W9E<G=R:71E/R(L"@DG;6Y?961I=%]?9FEL
M97-?9&5L9%]F<F]M7W)E<&]S:71O<GDG(#T^(")4:&5S92!F:6QE<R!W:6QL
M(&)E(&1E;&5T960@9G)O;2!R97!O<VET;W)Y(&%N9"!A=71O<F5S<&]N9&5R
M<R!C;VYT86EN:6YG('1H96TN($1O('EO=2!W86YT('1O('!R;V-E960_(BP*
M"2=M;E]E9&ET7U]M86EL7VYA;64G(#T^(")-86EL(&YA;64B+`H))VUN7V5D
M:71?7VUA:6Q?;F%M95]I;G9A;&ED)R`]/B`B36%I;"!N86UE(&ES(&EN=F%L
M:60N(BP*"2=M;E]E9&ET7U]M86EL7W)E9&ER)R`]/B`B36%I;"!R961I<F5C
M=',B+`H))VUN7V5D:71?7VUA:6Q?<F5D:7)?861D)R`]/B`B061D($UA:6P@
M1W)O=7`@365M8F5R(BP*"2=M;E]E9&ET7U]M86EL7W)E<W!S)R`]/B`B36%I
M;"!A=71O<F5S<&]N9&5R<R(L"@DG;6Y?961I=%]?;6%I;&)O>"<@/3X@(DUA
M:6QB;W@B+`H))VUN7V5D:71?7VUA:6QG<F]U<"<@/3X@(DUA:6P@9W)O=7`B
M+`H))VUN7V5D:71?7VUA:6QG<F]U<%]A9&1R97-S97,G(#T^(")-86EL(&=R
M;W5P(&UE;6)E<G,B+`H))VUN7V5D:71?7VUA:6QG<F]U<%]D:7-A8FQE9"<@
M/3X@(D%V86EL86)L92!O;FQY('=H96X@;6%I;"!N86UE(&ES(&%L<F5A9'D@
M861D960B+`H))VUN7V5D:71?7VUA>%]D;VU?<75O=&$G(#T^(")$969A=6QT
M(&9O<B!T:&4@9&]M86EN("@E,2DB+`H))VUN7V5D:71?7VUB;WA?<75O=&%?
M:6YV86QI9"<@/3X@(DEC;W)R96-T(&UA:6QB;W@@<VEZ92!S<&5C:69I960N
M(BP*"2=M;E]E9&ET7U]N97=?<F5S<%]N86UE)R`]/B`B3F5W(&%U=&]R97-P
M;VYD97(@;F%M92(L"@DG;6Y?961I=%]?;F]?875T;W)E<W!O;F1E<G,G(#T^
M(")9;W4@<VAO=6QD(&%D9"!A="!L96%S="!O;F4@875T;W)E<W!O;F1E<B!B
M969O<F4@='5R;FEN9R!T:&4@875T;W)E<W!O;F1E<B!S97)V:6-E(&]N+V]F
M9BXB+`H))VUN7V5D:71?7VYO7V9I;&5?<V5L)R`]/B`B3F\@9FEL97,@<V5L
M96-T960N(BP*"2=M;E]E9&ET7U]N;U]M86EL7V%D9')E<W-E<R<@/3X@(DYO
M(&4M;6%I;"!A9&1R97-S97,@:&%V92!B965N(&5N=&5R960@;W(@<V5L96-T
M960N(BP*"2=M;E]E9&ET7U]N;VYE)R`]/B`B3F]N92(L"@DG;6Y?961I=%]?
M;F]T7V-R96%T95]P87-S)R`]/B`B5&AI<R!W:6QL(&YO="!C<F5A=&4@82!P
M87-S=V]R9"!F;W(@=&AI<R!A8V-O=6YT+EQN5VET:&]U="!P87-S=V]R9"P@
M=7-E<B!W:6QL(&YO="!B92!A8FQE('1O('9I97<@86YD+V]R('-E;F0@;6%I
M;"XB+`H))VUN7V5D:71?7W)E9&ER7V5M86EL7VEN=F%L:60G(#T^(")2961I
M<F5C="!E+6UA:6P@861D<F5S<R!I<R!I;G9A;&ED+B(L"@DG;6Y?961I=%]?
M<F5D:7)E8W0G(#T^(")2961I<F5C="(L"@DG;6Y?961I=%]?<F5D:7)E8W1?
M861D<B<@/3X@(E)E9&ER96-T(&%D9')E<W,B+`H))VUN7V5D:71?7W)E;6]V
M95]A=71O<F5S<#\G(#T^(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M
M;W9E('1H92!A=71O<F5S<&]N9&5R/R(L"@DG;6Y?961I=%]?<F5M;W9E7W)C
M<&YT<S\G(#T^(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H
M97-E(')E8VEP:65N=',_(BP*"2=M;E]E9&ET7U]R97!O<VET;W)Y)R`]/B`B
M4F5P;W-I=&]R>2(L"@DG;6Y?961I=%]?<F5S<'-?871T86-H)R`]/B`B075T
M;W)E<W!O;F1E<B!A='1A8VAM96YT(&9I;&5S(BP*"2=M;E]E9&ET7U]S96QE
M8W1?<F-P;G1?9G)O;5]L:7-T)R`]/B`B4V5L96-T(&%T(&QE87-T(&]N92!R
M96-I<&EE;G0@9G)O;2!T:&4@;&ES="!T;R!R96UO=F4@:70N(BP*"2=M;E]E
M9&ET7U]S96QE8W1?<F5G:7-T97)E9%]U<V5R<R<@/3X@(E-E;&5C="!R96=I
M<W1E<F5D('5S97)S(BP*"2=M;E]E9&ET7U]S96QE8W1E9%]P;W-T8F]X7VAA
M=F5?;F]T7W-E='5P7W!A<W-W9"<@/3X@(EEO=2!H879E(&-H;W-E;B!T;R!H
M879E(&$@;6%I;&)O>"!B=70@:&%V92!N;W0@<V5T('5P('1H92!P87-S=V]R
M9"!F;W(@:70N(BP*"2=M;E]E9&ET7U]U;F%B;&5?86-T7V1E86-T7VUA:6Q?
M9W)O=7`G(#T^(")5;F%B;&4@=&\@86-T:79A=&4O9&5A8W1I=F%T92!M86EL
M(&=R;W5P.B`E,2(L"@DG;6Y?961I=%]?=6YA8FQE7V%C=%]D96%C=%]M86EL
M7W)E9&ER)R`]/B`B56YA8FQE('1O(&%C=&EV871E+V1E86-T:79A=&4@;6%I
M;"!R961I<F5C=#H@)3$B+`H))VUN7V5D:71?7W5N86)L95]A8W1?9&5A8W1?
M<&]S=&)O>"<@/3X@(E5N86)L92!T;R!A8W1I=F%T92]D96%C=&EV871E(&UA
M:6QB;W@Z("4Q(BP*"2=M;E]E9&ET7U]U;F%B;&5?86-T7V1E86-T7W)E<W`G
M(#T^(")5;F%B;&4@=&\@86-T:79A=&4O9&5A8W1I=F%T92!A=71O<F5S<&]N
M9&5R<SH@)3$B+`H))VUN7V5D:71?7W5N86)L95]A9&1?871T86-H)R`]/B`B
M56YA8FQE('1O(&%D9"!A='1A8VAM96YT(&9I;&4Z("4Q(BP*"2=M;E]E9&ET
M7U]U;F%B;&5?861D7VUA:6Q?9W)O=7!?;65M8F5R)R`]/B`B56YA8FQE('1O
M(&%D9"!M86EL(&=R;W5P(&UE;6)E<CH@)3$B+`H))VUN7V5D:71?7W5N86)L
M95]A9&1?<F5S<"<@/3X@(E5N86)L92!T;R!A9&0@875T;W)E<W!O;F1E<CH@
M)3$B+`H))VUN7V5D:71?7W5N86)L95]C:&%N9V5?;6%I;%]N86UE)R`]/B`B
M56YA8FQE('1O(&-H86YG92!M86EL(&YA;64Z("4Q(BP*"2=M;E]E9&ET7U]U
M;F%B;&5?9&5A8W1I=F%T95]M86EL7V=R;W5P)R`]/B`B56YA8FQE('1O(&1E
M86-T:79A=&4@;6%I;"!G<F]U<#H@)3$B+`H))VUN7V5D:71?7W5N86)L95]D
M96%C=&EV871E7W)E<W`G(#T^(")5;F%B;&4@=&\@9&5A8W1I=F%T92!M86EL
M(&%U=&]R97-P;VYD97)S.B`E,2(L"@DG;6Y?961I=%]?=6YA8FQE7V1E9FEN
M95]R97-P7VED)R`]/B`B56YA8FQE('1O(&1E9FEN92!A=71O<F5S<&]N9&5R
M(&ED.B`E,2(L"@DG;6Y?961I=%]?=6YA8FQE7W)E;6]V95]A='1A8V@G(#T^
M(")5;F%B;&4@=&\@<F5M;W9E(&%T=&%C:&UE;G0@9FEL92AS*3H@)3$B+`H)
M)VUN7V5D:71?7W5N86)L95]R96UO=F5?875T;W)E<W`G(#T^(")5;F%B;&4@
M=&\@<F5M;W9E(&%U=&]R97-P;VYD97(Z("4Q(BP*"2=M;E]E9&ET7U]U;F%B
M;&5?<F5M;W9E7VUA:6Q?9W)O=7!?;65M8F5R)R`]/B`B56YA8FQE('1O(')E
M;6]V92!M86EL(&=R;W5P(&UE;6)E<G,Z("4Q(BP*"2=M;E]E9&ET7U]U;F%B
M;&5?<V5T=7!?;6%I;%]R961I<B<@/3X@(E5N86)L92!T;R!S970@=7`@;6%I
M;"!R961I<F5C="!A9&1R97-S.B`E,2(L"@DG;6Y?961I=%]?=W)O;F=?=V%Y
M)PD)"3T^("=4:&4@;65S<V%G97,@861D<F5S<V5D('1O("4Q('=I;&P@;F]T
M(&)E(&1E;&EV97)E9"P@87,@=&AE(&UA:6P@;F%M92!I<R!N96ET:&5R(&$@
M;6%I;&)O>"P@;F]R(')E9&ER96-T+"!M86EL(&=R;W5P+"!O<B!A=71O<F5S
M<&]N9&5R+B<L"@DG;6Y?;&ES=%]?;6%I;%]N86UE<U]F;W)?9&]M86EN)R`]
M/B`B36%I;"!N86UE<R!F;W(@9&]M86EN("4Q(BP*"2=M;E]L:7-T7U]S85]C
M86YN;W1?=6YA8FQE)R`]/B`B0V%N;F]T(&5N86)L92!S<&%M(&9I;'1E<FEN
M9R(L"@DG;6Y?;&ES=%]?=&%B7V-P7V%C8V5S<R<@/3X@(DPB+`H))VUN7VQI
M<W1?7W1A8E]T:71L95]C;&EE;G0G(#T^("=#;&EE;G0G+`H))VUN7VQI<W1?
M7W1A8E]T:71L95]D;VUA:6XG(#T^("=$;VUA:6XG+`H))VUN7VQI<W1?7W1A
M8E]T:71L95]A=71O<F5S<"<@/3X@(D$B+`H))VUN7VQI<W1?7W1A8E]T:71L
M95]B;W@G(#T^(")"(BP*"2=M;E]L:7-T7U]T86)?=&ET;&5?9W)O=7`G(#T^
M(")'(BP*"2=M;E]L:7-T7U]T86)?=&ET;&5?;F%M92<@/3X@(DYA;64B+`H)
M)VUN7VQI<W1?7W1A8E]T:71L95]R961I<F5C="<@/3X@(E(B+`H))VUN7VQI
M<W1?7W1A8E]T:71L95]S<&%M9FEL=&5R)R`]/B`B4R(L"@DG;6Y?;&ES=%]?
M=&%B7W1I=&QE7V1R=V5B)R`]/B`G058G+`H))VUN7VQI<W1?7W5N86)L95]R
M96UO=F5?;6YS)R`]/B`B56YA8FQE('1O(')E;6]V92!T:&4@;6%I;"!N86UE
M<SH@)3$B+`H*"2=M;V1S7VUA;F%G7U]T:71L92<)"0D)/3X@)TUO9'5L97,@
M;6%N86=E;65N="<L"@DG;6]D<U]M86YA9U]?96UP='E?<V5L96-T:6]N7V9O
M<E]R96UO=F4G(#T^("=396QE8W0@=&AE(&UO9'5L97,@=&\@8F4@<F5M;W9E
M9"XG+`H))VUO9'-?;6%N86=?7V-A;E]N;W1?<F5M;W9E)PD]/B`G56YA8FQE
M('1O(')E;6]V92!M;V1U;&4@)3$Z("4R)RP*"2=M;V1S7W)E;6]V95]?=&ET
M;&4G"0D)/3X@)TUO9'5L92!R96UO=F%L)RP*"2=M;V1U;&5?=7!L;V%D7U]T
M:71L92<@/3X@)U5P;&]A9"!.97<@36]D=6QE)RP*"2=M;V1U;&5?=7!L;V%D
M7U]F:6QE7VYA;64G"3T^("=0871H('1O('1H92!M;V1U;&4@<&%C:V%G92!F
M:6QE)RP*"2=M;V1U;&5?=7!L;V%D7U]M;V1U;&5?=V%S7VEN<W1A;&QE9"<@
M/3X@)U1H:7,@;6]D=6QE(&ES(&%L<F5A9'D@:6YS=&%L;&5D+B!)9B!Y;W4@
M=VES:"!T;R!I;G-T86QL(&$@;F5W97(@=F5R<VEO;B!O9B!T:&ES(&UO9'5L
M92P@<&QE87-E(&1E:6YS=&%L;"!T:&4@;6]D=6QE('1H<F]U9V@@=&AE(&-O
M;G1R;VP@<&%N96PL(&%N9"!T:&5N('1R>2!I;G-T86QL:6YG+B<L"@DG;6]D
M=6QE7W5P;&]A9%]?=6YA8FQE7W1O7VEN<W1A;&PG"3T^("=5;F%B;&4@=&\@
M:6YS=&%L;"!T:&4@;6]D=6QE('!A8VMA9V4@9FEL92<L"@H))VUP8U]?=6YA
M8FQE7V)U>5]C97)T7W5N86)L95]G96YE<F%T95]C<W(G(#T^(")5;F%B;&4@
M=&\@<'5R8VAA<V4@82!C97)T:69I8V%T93H@=6YA8FQE('1O(&=E;F5R871E
M('1H92!#4U(Z("4Q(BP*"2=M<&-?7W5N86)L95]B=7E?8V5R=%]U;F%B;&5?
M<W1O<F5?<')I=F%T95]K97DG(#T^(")5;F%B;&4@=&\@<'5R8VAA<V4@82!C
M97)T:69I8V%T93H@=6YA8FQE('1O('-T;W)E('1H92!P<FEV871E(&ME>3H@
M)3$B+`H))VYE=W-?87)T:6-L97-?=&ET;&4G(#T^("=0;&5S:R!.97=S)RP*
M"2=N879?7V-U<W1O;5]B=71T;VYS)R`]/B`G0W5S=&]M)RP*"2=N879?7V=E
M;F5R86PG(#T^("='96YE<F%L)RP*"2=N879?7W-Y<W1E;2<@/3X@)U-Y<W1E
M;2<L"@DG;F%V7U]H96QP7V%N9%]S=7!P;W)T)R`]/B`G2&5L<"`F(%-U<'!O
M<G0G+`H))VYO7W!S85]M86EL<U]M871C:&5D)R`]/B`B3F\@;6%I;"!A8V-O
M=6YT<R!M871C:&EN9R!Y;W5R(&-R:71E<FEA(BP*"2=N;W1I9FEC871I;VY?
M=&5X=%]?:6YV86QI9%]T97AT7VQE;F=T:"<@/3X@(DEN=F%L:60@;F]T:6-E
M('1E>'0@;&5N9W1H+B!3:&]U;&0@8F4@9G)O;2`Q('1O(#8U-3,S(&-H87)A
M8W1E<G,N(BP*"2=N;W1I9FEC871I;VY?=&5X=%]?=&5X="<@/3X@(DYO=&EC
M92!T97AT(BP*"2=N;W1I9FEC871I;VY?=&5X=%]?=&ET;&4G(#T^(")%9&ET
M(&YO=&EC92(L"@DG;F]T:69I8V%T:6]N7W1E>'1?7W5N86)L95]S971?=&5X
M="<@/3X@(E5N86)L92!T;R!M;V1I9GD@;F]T:6-E('1E>'0Z("(L"@DG;F]T
M:69I8V%T:6]N<U]?=6YA8FQE7W1O7W5P9&%T92<@/3X@(E5N86)L92!T;R!U
M<&1A=&4@;F]T:69I8V%T:6]N.B`E,2(L"@DG;V1B8U]?8V%N=%]A9&1?9'-N
M)R`]/B`B56YA8FQE('1O(&%D9"!$4TX@)3$Z("4R(BP*"2=O9&)C7U]C86YT
M7V)U:6QD7V-O;FYE8W1I;VY?<W1R:6YG)R`]/B`B56YA8FQE('1O(&-O;FYE
M8W0@=7-I;F<@=&AE('!A<F%M971E<G,@<W!E8VEF:65D+"!P;&5A<V4@=')Y
M(&%G86EN('5S:6YG(&1I9F9E<F5N="!P87)A;65T97)S+B!5=&EL:71Y(&AA
M<R!R971U<FYE9#H@)3$B+`H))V]D8F-?7V-A;G1?8V]N;F5C="<@/3X@(E5N
M86)L92!T;R!C;VYN96-T('1O('1H92!D871A('-O=7)C92!U<VEN9R!T:&4@
M9&5F:6YE9"!S971T:6YG<RX@4V5R=F5R(&AA<R!R971U<FYE9#H@)3$B+`H)
M)V]D8F-?7V-A;G1?9&5L971E7V1S;B<@/3X@(E5N86)L92!T;R!D96QE=&4@
M1%-.("4Q.B`E,B(L"@DG;V1B8U]?8V%N=%]G971?9')I=F5R<R<@/3X@(E5N
M86)L92!T;R!R971R:65V92!A(&QI<W0@;V8@3T1"0R!D<FEV97)S.B`E,2(L
M"@DG;V1B8U]?8V%N=%]G971?;&ES="<@/3X@(E5N86)L92!T;R!R971R:65V
M92!A(&QI<W0@;V8@97AI<W1I;F<@1%-.<SH@)3$B+`H))V]D8F-?7V-A;G1?
M<&%R<V5?<W1R:6YG)R`]/B`B56YA8FQE('1O('!A<G-E('1H92!C;VYN96-T
M:6]N('-T<FEN9R(L"@DG;V1B8U]?8V]N;F5C=%]S=6-C97-S)R`]/B`B0V]N
M;F5C=&EO;B!S=6-C97-S9G5L(BP*"2=O9&)C7U]D<FEV97)?;F]T7W-E="<@
M/3X@(D1R:79E<B!I<R!N;W0@<V5T(BP*"2=O9&)C7U]D<FEV97)?;W)?;F%M
M95]N;W1?<V5T)R`]/B`B1')I=F5R(&]R(&YA;64@;V8@=&AE($]$0D,@8V]N
M;F5C=&EO;B!W97)E(&YO="!S970B+`H))V]D8F-?7V1S;E]A;')E861Y7V5X
M:7-T<R<@/3X@(D133B!W:71H('1H:7,@;F%M92`H)3$I(&%L<F5A9'D@97AI
M<W1S(&EN('1H92!S>7-T96TB+`H))V]D8F-?7V1S;E]N;W1?97AI<W1S)R`]
M/B`B5&AI<R!$4TX@9&]E<R!N;W0@97AI<W0B+`H))V]D8F-?7V5N=&5R7V-O
M;FYE8W1I;VY?<&%R86US)R`]/B`B66]U('-H;W5L9"!S<&5C:69Y('1H92!O
M<'1I;VYS('1O(&)E('5S960@8GD@=&AE(&1R:79E<BX@069T97(@>6]U(&AA
M=F4@<W5P<&QI960@86QL('1H92!R97%U:7)E9"!D871A+"!Y;W4@=VEL;"!N
M965D('1O(&-L:6-K($9I;FES:"!I;B!O<F1E<B!T;R!C;VUP;&5T92!T:&4@
M3T1"0R!$4TX@8V]N9FEG=7)A=&EO;BXB+`H))V]D8F-?7V5N=&5R7V1S;E]N
M86UE)R`]/B`B16YT97(@1%-.(&YA;64B+`H))V]D8F-?7VEN=F%L:61?9'-N
M7VYA;64G(#T^(")7<F]N9R!S>6YT87@@9F]R($]$0D,@8V]N;F5C=&EO;B!N
M86UE("@E,2DZ('!L96%S92!U<V4@;VYL>2!A;'!H86YU;65R:6,@<WEM8F]L
M<RXB+`H))V]D8F-?7VYO7W-U8VA?9')I=F5R)R`]/B`B3T1"0R!D<FEV97(@
M=VET:"!S=6-H(&YA;64@*"4Q*2!I<R!N;W0@<W5P<&]R=&5D(BP*"2=O9&)C
M7U]R96UO=F5?<&%G95]T:71L92<@/3X@(E1H92!F;VQL;W=I;F<@3T1"0R!$
M4TX@8V]N;F5C=&EO;G,@=VEL;"!B92!R96UO=F5D.B(L"@DG;V1B8U]?<V5L
M96-T7V1S;E]T;U]R96UO=F4G(#T^(")396QE8W0@1%-.<R!T;R!B92!R96UO
M=F5D+B(L"@DG;V1B8U]A9&1?;F5W)R`]/B`B061D(&YE=R!$4TX@8V]N;F5C
M=&EO;B(L"@DG;V1B8U]D<FEV97(G(#T^(")$<FEV97(B+`H))V]D8F-?9'-N
M7V1E<V-R:7!T:6]N)R`]/B`B0V]N;F5C=&EO;B!D97-C<FEP=&EO;B(L"@DG
M;V1B8U]D<VY?;&ES="<@/3X@(D]$0D,@1%-.(&-O;FYE8W1I;VYS(BP*"2=O
M9&)C7V1S;E]N86UE)R`]/B`B0V]N;F5C=&EO;B!N86UE(BP*"2=O9&)C7V1S
M;E]S>7-T96TG(#T^(")3>7-T96T@1%-.(BP*"2=O9&)C7V1S;E]T97AT)R`]
M/B`B3T1"0R!$4TXB+`H))V]D8F-?<F5Q7V9I96QD7VYO=%]S970G(#T^(")2
M97%U:7)E9"!P87)A;65T97)S(&%R92!N;W0@<W5P<&QI960N(BP*"2=P8E]?
M86QI87-E<R<@/3X@(D%L:6%S97,B+`H))W!B7U]A;F]N9G1P)R`]/B`B06YO
M;GEM;W5S($944"(L"@DG<&)?7V%U=&]I;G-T86QL97)?<F5L96%S97,G(#T^
M("=5<&1A=&5R)RP*"2=P8E]?8V5R="<@/3X@(D-E<G1I9FEC871E<R(L"@DG
M<&)?7V-L7W!O;VPG(#T^("))4"!A9&1R97-S97,B+`H))W!B7U]C;%]P;V]L
M7V-T<FPG(#T^("(E,2(L"@DG<&)?7V-L7W!R968G(#T^(")0<F5F97)E;F-E
M<R(L"@DG<&)?7V-L7W)P="<@/3X@(E)E<&]R="(L"@DG<&)?7V-L7W)P=%]L
M:7-T)R`]/B`B0W5S=&]M:7IE(BP*"2=P8E]?8VQ?=&5M<&QA=&5S)R`]/B`B
M0VQI96YT('1E;7!L871E<R(L"@DG<&)?7V-L7W1R869F:6,G(#T^(")4<F%F
M9FEC(BP*"2=P8E]?8VQ?=')A9F9I8U]H:7-T;W)Y)R`]/B`B5')A9F9I8R!H
M:7-T;W)Y(BP*"2=P8E]?8VQ?=')A9F9I8U]O9B<@/3X@(E1R869F:6,@;V8@
M)3$B+`H))W!B7U]C;&EE;G0G(#T^("(E,2(L"@DG<&)?7V-L:65N=',G(#T^
M(")#;&EE;G1S(BP*"2=P8E]?8V]M<%]I;F9O)R`]/B`B0V]M<&]N96YT(&EN
M9F\B+`H))W!B7U]C;VUM;VY?86-L)R`]/B`G06QL;W<@5')A;G-F97(@04-,
M)RP*"2=P8E]?8W!?86-C97-S)R`]/B`B06-C97-S(BP*"2=P8E]?8W)O;G1A
M8B<@/3X@(E-C:&5D=6QE<B(L"@DG<&)?7V-U<W1O;5]B=71T;VYS)R`]/B`B
M0W5S=&]M($)U='1O;G,B+`H))W!B7U]D8B<@/3X@(D1A=&%B87-E<R(L"@DG
M<&)?7V1B7V5D:70G(#T^("(E,2(L"@DG<&)?7V1B7W-E<G9E<E]E9&ET)R`]
M/B`G)3$G+`H))W!B7U]D8E]S97)V97)S)R`]/B`G1&%T86)A<V4@<V5R=F5R
M<R<L"@DG<&)?7V1L7W5S<E]E9"<@/3X@(D1O;6%I;B!A9&UI;FES=')A=&]R
M(BP*"2=P8E]?9&YS)R`]/B`B1$Y3(BP*"2=P8E]?9&YS7W1E;7!L871E)R`]
M/B`B1$Y3(BP*"2=P8E]?9&YS7W0G(#T^(")$3E,B+`H))W!B7U]D;VU?8W1R
M;"<@/3X@(B4Q(BP*"2=P8E]?9&]M7VQI;2<@/3X@(D1O;6%I;B!L:6UI=',B
M+`H))W!B7U]D;VU?<')E9B<@/3X@(E!R969E<F5N8V5S(BP*"2=P8E]?9&]M
M7W-U;5]R97!O<G0G(#T^(")$;VUA:6X@4W5M;6%R>2!297!O<G0B+`H))W!B
M7U]D;VU?=&5M<&QA=&5S)R`]/B`B1&]M86EN(%1E;7!L871E<R(L"@DG<&)?
M7V1O;5]T<F%F9FEC)R`]/B`B5')A9F9I8R!O9B`E,2(L"@DG<&)?7V1O;5]T
M<F%F9FEC7VAI<W1O<GDG(#T^(")4<F%F9FEC($AI<W1O<GDB+`H))W!B7U]D
M;VUA:6YS)R`]/B`B1&]M86EN<R(L"@DG<&)?7V1U;7!S7VQI<W0G(#T^(")"
M86-K=7`@1FEL97,@4F5P;W-I=&]R>2(L"@DG<&)?7V5V96YT7VAA;F1L97)S
M)R`]/B`G179E;G0@;6%N86=E<B<L"@DG<&)?7V9O<G=A<F1I;F=?<V5T=7`G
M(#T^(")&;W)W87)D:6YG(%-E='5P(BP*"2=P8E]?9FEL96UA;F%G97(G(#T^
M(")&:6QE($UA;F%G97(B+`H))W!B7U]G;&]B86QC:&%N9V5S)R`]/B`B1W)O
M=7`@3W!E<F%T:6]N<R(L"@DG<&)?7VEP7V%L:6%S:6YG)R`]/B`B25`@061D
M<F5S<V5S(BP*"2=P8E]?:7!?9&]M86EN<R<@/3X@(D1O;6%I;G,B+`H))W!B
M7U]I<%]C;&EE;G1S)R`]/B`B25`@061D<F5S<V5S(')E;6]V86PB+`H))W!B
M7U]L:6-E;G-E7VUA;F%G96UE;G0G(#T^("=,:6-E;G-E($UA;F%G96UE;G0G
M+`H))W!B7U]L;V-A;&5S)R`]/B`G3&]C86QE<R<L"@DG<&)?7VQO9U]F:6QE
M<R<@/3X@(DQO9R!F:6QE<R(L"@DG<&)?7VUA:6PG(#T^("=-86EL)RP*"2=P
M8E]?;6%I;%]B;&]C:V5D7V1O;6%I;G,G(#T^("=";&%C:R!L:7-T)RP*"2=P
M8E]?;6%I;%]N86UE7V9I;&5S)R`]/B`B071T86-H;65N="!F:6QE<R(L"@DG
M<&)?7VUA:6Q?;F%M95]E9&ET)R`]/B`B)3$B+`H))W!B7U]M86EL7VYA;65?
M;6%I;%]G<F]U<"<@/3X@(DUA:6P@9W)O=7`B+`H))W!B7U]M86EL7VYA;65?
M<F5D:7)E8W1S)R`]/B`B4F5D:7)E8W1S(BP*"2=P8E]?;6%I;%]N86UE7W)E
M<W!?871T86-H7V%D9"<@/3X@(DYE=R!A='1A8VAM96YT(BP*"2=P8E]?;6%I
M;%]N86UE7W)E<W!?961I="<@/3X@(B4Q(BP*"2=P8E]?;6%I;%]N86UE7W)E
M<W!O;F1E<G,G(#T^(")!=71O<F5S<&]N9&5R<R(L"@DG<&)?7VUA:6Q?;F%M
M97,G(#T^(")-86EL(BP*"2=P8E]?;6%I;%]W:&ET95]L:7-T)R`]/B`G5VAI
M=&4@;&ES="<L"@DG<&)?7VUA:6QL:7-T<R<@/3X@(DUA:6QI;F<@;&ES=',B
M+`H))W!B7U]M;V1U;&5S)R`]/B`G36]D=6QE<R<L"@DG<&)?7VUO9'5L97-?
M;6%N86=E;65N="<@/3X@)TUA;F%G92!-;V1U;&5S)RP*"2=P8E]?;F]T:69I
M8V%T:6]N<R<@/3X@(DYO=&EF:6-A=&EO;G,B+`H))W!B7U]O9&)C)R`]/B`B
M3T1"0R(L"@DG<&)?7W!H;W-T:6YG7W-E='5P)R`]/B`B4&AY<VEC86P@:&]S
M=&EN9R!S971U<"(L"@DG<&)?7W!R=&1?9&ER<R<@/3X@(E!R;W1E8W1E9"!D
M:7)E8W1O<FEE<R(L"@DG<&)?7W!R=&1I<E]E9&ET)R`]/B`B)3$B+`H))W!B
M7U]R97!O<G0G(#T^(")297!O<G0B+`H))W!B7U]R97!O<G1?875T;R<@/3X@
M(D1E;&EV97)Y('-C:&5D=6QE(&9O<B`E,2(L"@DG<&)?7W)E<&]R=%]L:7-T
M)R`]/B`B0W5S=&]M:7IE(BP*"2=P8E]?<V5R=F5R)R`]/B`B4V5R=F5R(BP*
M"2=P8E]?<V5R=F5R7VEN9F\G(#T^(")3;&%V92!S97)V97(@:6YF;W)M871I
M;VXB+`H))W!B7U]S97)V97)?=')A9F9I8R<@/3X@(E-E<G9E<B!T<F%F9FEC
M(BP*"2=P8E]?<V5R=F5R<U]L:7-T)R`]/B`B4VQA=F4@<V5R=F5R(&%C8V]U
M;G1S(BP*"2=P8E]?<V5S<VEO;G,G(#T^(")397-S:6]N<R(L"@DG<&)?7W-A
M<'!?<&]O;"<@/3X@(D%P<&QI8V%T:6]N(%!O;VPB+`H))W!B7U]S:71E87!P
M7VEN<W1A;&PG(#T^(")3:71E($%P<&QI8V%T:6]N($EN<W1A;&QA=&EO;B(L
M"@DG<&)?7W-I=&5?87!P7W!K9W,G(#T^(")3:71E($%P<&QI8V%T:6]N(%!A
M8VMA9V5S(BP*"2=P8E]?<VET95]A<'!S)R`]/B`B4VET92!!<'!L:6-A=&EO
M;G,B+`H))W!B7U]A9&1I=&EO;F%L7VME>5]I;F9O)R`]/B`G2V5Y(%!R;W!E
M<G1I97,G+`H))W!B7U]A9&1I=&EO;F%L7VME>5]P<F]P97)T:65S)R`]/B`G
M2V5Y(%!R;W!E<G1I97,G+`H))W!B7U]S:V5L971O;B<@/3X@(E-K96QE=&]N
M($UA;F%G96UE;G0B+`H))W!B7U]S:VEN<R<@/3X@)U-K:6YS)RP*"2=P8E]?
M<VMI;E]I;F9O)R`]/B`G)3$G+`H))W!B7U]S<&%M87-S87-S:6XG(#T^(")3
M<&%M07-S87-S:6XB+`H))W!B7U]S=&%T:7-T:6-S)R`]/B`B4W1A=&ES=&EC
M<R(L"@DG<&)?7W-U8F1O;6%I;G,G(#T^(")3=6)D;VUA:6YS(BP*"2=P8E]?
M=&5M<&QA=&5S)R`]/B`B5&5M<&QA=&5S(BP*"2=P8E]?=&EC:V5T<R<@/3X@
M(E1I8VME=',B+`H))W!B7U]T=',G(#T^(")4:6-K971S(BP*"2=P8E]?=V5B
M7V%P<',G(#T^(")4;VUC870B+`H))W!B7U]W96)?=7-E<G,G(#T^(")796(@
M=7-E<G,B+`H))W!B7U]W96)A;&EZ97)?<')E9F5R96YC97,G(#T^("=796(@
M4W1A=&ES=&EC<R!0<F5F97)E;F-E<R<L"@DG<&1I<E]?96YT97)?9&ER7VYA
M;64G(#T^(")%;G1E<B!D:7)E8W1O<GD@;F%M92XB+`H))W!D:7)?7VEN=F%L
M:61?:'-T)R`]/B`B2&]S=&EN9R!T>7!E(&ES(&EN=F%L:60N($UU<W0@8F4@
M<&AY<VEC86PN(BP*"2=P9&ER7U]P9%]I9%]I<U]U;F1E9FEN960G(#T^(")0
M<F]T96-T960@9&ER96-T;W)Y(&ED(&ES('5N9&5F:6YE9"XB+`H))W!D:7)?
M7W!D:7)?97AI<W0G(#T^(")$:7)E8W1O<GD@=VET:"!T:&ES(&YA;64@:7,@
M86QR96%D>2!P<F]T96-T960N(BP*"2=P9&ER7U]P9&ER7VYO=%]E>&ES="<@
M/3X@(E!R;W1E8W1E9"!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(BP*"2=P
M9&ER7U]P9&ER7W5S<E]N;W1?97AI<W0G(#T^(")0<F]T96-T960@9&ER96-T
M;W)Y('5S97(@9&]E<R!N;W0@97AI<W0N(BP*"2=P9&ER7U]P<F1I<G-?9F]R
M7V1O;6%I;B<@/3X@(E!R;W1E8W1E9"!D:7)E8W1O<FEE<R!F;W(@9&]M86EN
M("4Q(BP*"2=P9&ER7U]R96UO=F5?<&1I<E]U<W)S)R`]/B`B5&AE(&9O;&QO
M=VEN9R!U<V5R<R!O9B!P<F]T96-T960@9&ER96-T;W)Y("4R(&EN(&1O;6%I
M;B`E,2!W:6QL(&)E(')E;6]V960Z(BP*"2=P9&ER7U]R96UO=F5?<&1I<G-?
M;VY?9&]M)R`]/B`B5&AI<R!O<&5R871I;VX@=VEL;"!R97-U;'0@:6X@<F5M
M;W9I;F<@<')O=&5C=&EO;B!F<F]M('1H92!D:7)E8W1O<FEE<R!O9B!D;VUA
M:6X@)3(@;W=N960@8GD@8VQI96YT("4Q+"!T:&4@9&ER96-T;W)I97,@=&AE
M;7-E;'9E<R!W:6QL(&YO="!B92!E<F%S960N(BP*"2=P9&ER7U]S96QE8W1?
M<&1I<E]U<W)S7V9O<E]R96UO=F4G(#T^(")396QE8W0@=&AE('!R;W1E8W1E
M9"!D:7)E8W1O<GD@=7-E<G,@=&\@8F4@<F5M;W9E9"XB+`H))W!D:7)?7W-E
M;&5C=%]P9&ER<U]T;U]R96UO=F4G(#T^(")396QE8W0@=&AE(&1I<F5C=&]R
M:65S('1O(')E;6]V92!P<F]T96-T:6]N(&9R;VTN(BP*"2=P9&ER7U]U;F%B
M;&5?9&5F:6YE7W!D:7)?=7-E<G,G(#T^(")5;F%B;&4@=&\@9&5F:6YE('1H
M92!P<F]T96-T960@9&ER96-T;W)Y('5S97)S+B(L"@DG<&1I<E]?=6YA8FQE
M7V1E9FEN95]P9&ER<U]P<F]P97)T:65S)R`]/B`B56YA8FQE('1O('-E="!T
M:&4@<')O=&5C=&5D(&1I<F5C=&]R:65S)R!P<F]P97)T:65S.B`E,2(L"@DG
M<&1I<E]?=6YA8FQE7W-E;&5C=%]D;VU?<&%R86TG(#T^(")5;F%B;&4@=&\@
M<V5L96-T(&1O;6%I;B!P87)A;65T97)S.B`E,2(L"@DG<&1I<E]E9%]?8W)E
M871E7W!D:7)?9F]R7V1O;6%I;B<@/3X@(D-R96%T92!N97<@<')O=&5C=&5D
M(&1I<F5C=&]R>2!O;B!D;VUA:6X@)3$B+`H))W!D:7)?961?7V1I<E]A;')E
M861Y7W!R;W1E8W0G(#T^(")4:&ES(&1I<F5C=&]R>2!I<R!A;')E861Y('!R
M;W1E8W1E9"XB+`H))W!D:7)?961?7VAE861?='AT)R`]/B`B2&5A9&5R(%1E
M>'0B+`H))W!D:7)?961?7VEN=F%L:61?;&]G:6XG(#T^(")5<V5R(&YA;64@
M:7,@:6YV86QI9"XB+`H))W!D:7)?961?7VQO9VEN7V5X:7-T<R<@/3X@(E-U
M8V@@=7-E<B!A;')E861Y(&5X:7-T<RX@5')Y(&%N;W1H97(@;&]G:6X@;F%M
M92XB+`H))W!D:7)?961?7VYE=U]U<W(G(#T^(").97<@=7-E<B(L"@DG<&1I
M<E]E9%]?;F]N7W-S;"<@/3X@(DYO;BU34TPB+`H))W!D:7)?961?7V-G:5]B
M:6XG(#T^(")C9VDM8FEN(BP*"2=P9&ER7V5D7U]P871H)R`]/B`B1&ER96-T
M;W)Y(&YA;64B+`H))W!D:7)?961?7W!D:7)?9F]R7V1O;6%I;B<@/3X@(E!R
M;W1E8W1E9"!D:7)E8W1O<GD@)3$@;VX@9&]M86EN("4R(BP*"2=P9&ER7V5D
M7U]P9&ER7VQO8V%T:6]N)R`]/B`B1&ER96-T;W)Y(&QO8V%T:6]N(BP*"2=P
M9&ER7V5D7U]P9&ER7W5S97)S)R`]/B`B4')O=&5C=&5D(&1I<F5C=&]R>2!U
M<V5R<R(L"@DG<&1I<E]E9%]?<W-L)R`]/B`B4U-,(BP*"2=P9&ER7V5D7U]S
M<VQ?;F]T7W-U<'!O<G1E9%]D;VUA:6XG(#T^(")34TP@:7,@;F]T('-U<'!O
M<G1E9"!I;B!T:&ES(&1O;6%I;BXB+`H))W!D:7)?961?7W-S;%]O<E]N;VYS
M<VQ?<VAO=6QD7V)E7V-H96-K960G(#T^(")!="!L96%S="!O;F4@8VAE8VMB
M;W@@<VAO=6QD(&)E('-E;&5C=&5D(&9R;VT@4U-,(&%N9"!.;VXM4U-,(&-H
M96-K8F]X97,N(BP*"2=P9&ER7V5D7U]U;F%B;&5?8W)?<&1I<E]U<W(G(#T^
M(")5;F%B;&4@=&\@8W)E871E('1H92!P<F]T96-T960@9&ER96-T;W)Y('5S
M97(Z("4Q(BP*"2=P9&ER7V5D7U]U;F%B;&5?8W)E871E7W!D:7(G(#T^(")5
M;F%B;&4@=&\@8W)E871E('1H92!P<F]T96-T960@9&ER96-T;W)Y.B`E,2(L
M"@DG<&1I<E]E9%]?=6YA8FQE7V1E9FEN95]H<W1?='EP92<@/3X@(E5N86)L
M92!T;R!D969I;F4@=&AE(&AO<W1I;F<@='EP92XB+`H))W!D:7)?961?7W5N
M86)L95]U<&1A=&5?<&1I<B<@/3X@(E5N86)L92!T;R!U<&1A=&4@=&AE('!R
M;W1E8W1E9"!D:7)E8W1O<GDZ("4Q(BP*"2=P9&ER7V5D7U]W<F]N9U]S>6UB
M;VQ?:6Y?:&5A9&5R)R`]/B`B4&QE87-E+"!D;R!N;W0@=7-E('-Y;6)O;"`E
M,2!I;B!T:&4@9&ER96-T;W)Y(&AE861E<B(L"@DG<&1I<E]U<W)?961?7V-R
M96%T95]P9&ER7W5S<E]F;W)?<&0G(#T^(")#<F5A=&4@=7-E<B!F;W(@=&AE
M('!R;W1E8W1E9"!D:7)E8W1O<GD@)3$B+`H))W!D:7)?=7-R7V5D7U]N;W1?
M8W)E871E7W!A<W,G(#T^(")4:&ES('=I;&P@;F]T(&-R96%T92!A('!A<W-W
M;W)D(&9O<B!T:&4@;F5W('!R;W1E8W1E9"!D:7)E8W1O<GD@=7-E<BY<;E=I
M=&AO=70@<&%S<W=O<F0@=&AE('5S97(@=VEL;"!N;W0@8F4@86)L92!T;R!L
M;V<@:6XN(BP*"2=P9&ER7W5S<E]E9%]?<&%S<U]F;W)?<&1I<E]U<W(G(#T^
M(")087-S=V]R9"!F;W(@=&AE('!R;W1E8W1E9"!D:7)E8W1O<GD@=7-E<B`E
M,2(L"@DG<&1I<E]U<W)?961?7W5N86)L95]S96QE8W1?<&1I<E]U<W(G(#T^
M(")5;F%B;&4@=&\@<V5L96-T('1H92!P<F]T96-T960@9&ER96-T;W)Y('5S
M97(Z("4Q(BP*"2=P9&ER7W5S<G-?;&ES=%]?=6YA8FQE7V1E9FEN95]P9&ER
M7W5S<G,G(#T^(")5;F%B;&4@=&\@9&5F:6YE('1H92!P<F]T96-T960@9&ER
M96-T;W)Y('5S97)S.B`E,2(L"@DG<&1I<E]U<W)S7VQI<W1?7W5N86)L95]R
M96UO=F5?<&1?=7-R<R<@/3X@(E5N86)L92!T;R!R96UO=F4@=&AE('!R;W1E
M8W1E9"!D:7)E8W1O<GD@=7-E<G,Z("4Q(BP*"2=P9&ER<U]L:7-T7U]N86UE
M)R`]/B`B3F%M92(L"@DG<&1I<G-?;&ES=%]?=&%B7W1I=&QE7VYO;E]S96-U
M<F5?9&ER)R`]/B`B3B(L"@DG<&1I<G-?;&ES=%]?=&%B7W1I=&QE7W-E8W5R
M95]D:7(G(#T^(")3(BP*"2=P9&ER<U]L:7-T7U]T86)?=&ET;&5?8V=I7V)I
M;E]D:7(G(#T^(")#(BP*"2=P9&ER<U]L:7-T7U]U;F%B;&5?<F5M;W9E7W!D
M:7)S)R`]/B`B56YA8FQE('1O(')E;6]V92!T:&4@<')O=&5C=&5D(&1I<F5C
M=&]R:65S.B`E,2(L"@DG<&AO<W1I;F=?7V%N;VYF='!?9&ES86)L960G(#T^
M(")!;F]N>6UO=7,@1E10('-E<G9I8V4@:7,@9&ES86)L960@;VX@=&AI<R!D
M;VUA:6X@87,@=&AI<R!)4"!A9&1R97-S(&ES(&%L<F5A9'D@8F5I;F<@=7-E
M9"!F;W(@86YO;GEM;W5S($944"!S97)V:6-E(&]N(&%N;W1H97(@9&]M86EN
M+B(L"@DG<&AO<W1I;F=?7V%N;VYF='!?96YC<GEP="<)/3X@)U1H92!P87-S
M=V]R9"!O9B!&5%`@=7-E<B!I<R!E;F-R>7!T960L(&%N9"!T:&5R969O<F4@
M8V%N;F]T(&)E('5S960@9F]R('!R;W1E8W1I;F<@9&ER96-T;W)Y("]P;&5S
M:RUS=&%T+RX@4&QE87-E(')E96YT97(@>6]U<B!&5%`@<&%S<W=O<F0L(&]R
M(&1E<V5L96-T('1H92!O<'1I;VX@(F%C8V5S<VEB;&4@=FEA('!A<W-W;W)D
M('!R;W1E8W1E9"!D:7)E8W1O<GD@7"<O<&QE<VLM<W1A="]<)R(G+`H))W!H
M;W-T:6YG7U]I<%]C:&%N9V5?=V%R;FEN9R<@/3X@(DE0(&%D9')E<W,@8VAA
M;F=E9"X@5&AE(&-O<G)E<W!O;F1I;F<@8VAA;F=E<R!W97)E(&%L<V\@;6%D
M92!I;B!T:&4@9&]M86EN)W,@1$Y3('IO;F4N(BP*"2=P:&]S=&EN9U]?;W1H
M97)?:&]S=&EN9U]E>&ES='-?;VY?:7`G(#T^(")5;F%B;&4@=&\@8VAA;F=E
M('1H92!C97)T:69I8V%T92!B96-A=7-E('1H:7,@:7`@861D<F5S<R!I<R!B
M96EN9R!U<V5D(&EN(&]N92!O<B!S979E<F%L(&AO<W1I;F<@86-C;W5N=',N
M(BP*"2=P:&]S=&EN9U]?=6YA8FQE7W1O7V-H86YG95]C97)T:69I8V%T92<@
M/3X@(E5N86)L92!T;R!I;G-T86QL('1H92!C97)T:69I8V%T93H@)3$B+`H)
M)W!H;W-T:6YG7U]U;F%B;&5?=&]?8VAA;F=E7VEP7V%D9')E<W,G(#T^(")5
M;F%B;&4@=&\@8VAA;F=E('1H92!I<"!A9&1R97-S.B`E,2(L"@DG<&AO<W1I
M;F=?7W5N86)L95]T;U]S971?8V5R="<@/3X@(E5N86)L92!T;R!S970@=&AE
M('-S;"!C97)T:69I8V%T93H@)3$B+`H))W!H;W-T:6YG7U]U;F%B;&5?=7!D
M871E)R`]/B`B56YA8FQE('1O('5P9&%T92!H;W-T:6YG('!R969E<F5N8V5S
M.B`E,2(L"@DG<&AO<W1I;F=?7W5N86)L95]M86YA9V4G(#T^(")5;F%B;&4@
M=&\@;6%N86=E(&AO<W1I;F<Z("4Q(BP*"@DG<&EC:V5R7V%U=&]R97-P;VYD
M97)?7W1I=&QE)R`]/B`G075T;W)E<W!O;F1E<B!S96QE8W1I;VXG+`H))W!I
M8VME<E]C;&EE;G1?7W1I=&QE)R`]/B`G0VQI96YT('-E;&5C=&EO;B<L"@DG
M<&EC:V5R7V1A=&%B87-E7U]T:71L92<@/3X@)T1A=&%B87-E('-E;&5C=&EO
M;B<L"@DG<&EC:V5R7V1O;6%I;E]?=&ET;&4G(#T^("=$;VUA:6X@<V5L96-T
M:6]N)RP*"2=P:6-K97)?;6%I;&YA;65?7W1I=&QE)R`]/B`G36%I;&YA;64@
M<V5L96-T:6]N)RP*"2=P:6-K97)?<VET95]A<'!L:6-A=&EO;E]?=&ET;&4G
M(#T^("=3:71E(&%P<&QI8V%T:6]N('-E;&5C=&EO;B<L"@DG<&EC:V5R7W-U
M8F1O;6%I;E]?=&ET;&4G(#T^("=3=6)D;VUA:6X@<V5L96-T:6]N)RP*"2=P
M:6-K97)?=V5B7W5S97)?7W1I=&QE)R`]/B`G5V5B('5S97(@<V5L96-T:6]N
M)RP*"2=P:6-K97)?8W5S=&]M7V)U='1O;E]?=&ET;&4G(#T^("=#=7-T;VT@
M8G5T=&]N('-E;&5C=&EO;B<L"@H))W!L97-K7V=U:61E)R`]/B`B4&QE<VL@
M57-E<B=S($=U:61E(BP*"2=P;&5S:U]K97E?7V%C=&EO;E]L;V=S)R`]/B`B
M06)I;&ET>2!T;R!U<V4@86-T:6]N(&QO9V=I;F<B+`H))W!L97-K7VME>5]?
M87!P7W9A=6QT)R`]/B`B06)I;&ET>2!T;R!U<V4@87!P;&EC871I;VX@=F%U
M;'0B+`H))W!L97-K7VME>5]?8F%C:W5P)R`]/B`B06)I;&ET>2!T;R!U<V4@
M=&AE(&)A8VMU<"!F=6YC=&EO;G,B+`H))W!L97-K7VME>5]?8VQI96YT7W1E
M;7!L<R<@/3X@(D%B:6QI='D@=&\@;6%N86=E(&-L:65N="!T96UP;&%T97,B
M+`H))W!L97-K7VME>5]?8VQI96YT<R<@/3X@(DUA>&EM=6T@;G5M8F5R(&]F
M(&-L:65N="!A8V-O=6YT<R(L"@DG<&QE<VM?:V5Y7U]C;VQD9G5S:6]N)R`]
M/B`B06)I;&ET>2!T;R!U<V4@0V]L9$9U<VEO;B(L"@DG<&QE<VM?:V5Y7U]D
M;VUA:6YS)R`]/B`B36%X:6UU;2!N=6UB97(@;V8@9&]M86EN<R(L"@DG<&QE
M<VM?:V5Y7U]D87-H8F]A<F0G(#T^("=!8FEL:71Y('1O('5S92!$97-K=&]P
M(&EN=&5R9F%C92<L"@DG<&QE<VM?:V5Y7U]S=&1G=6DG(#T^("=!8FEL:71Y
M('1O('5S92!S=&%N9&%R9"!I;G1E<F9A8V4G+`H))W!L97-K7VME>5]?;6%N
M86=E7V1A<VAB;V%R9"<@/3X@)T%B:6QI='D@=&\@;6%N86=E($1E<VMT;W`G
M+`H))W!L97-K7VME>5]?:V5Y7VEP7W)A;F=E<R<@/3X@)UEO=2!C86X@=7-E
M(%!L97-K(&]N;'D@=VET:"!T:&4@9F]L;&]W:6YG($E0(&%D9')E<W-E<SHG
M+`H))W!L97-K7VME>5]?9')W96(G(#T^(")!8FEL:71Y('1O('5S92!$<BY7
M96(@86YT:79I<G5S(BP*"2=P;&5S:U]K97E?7V5V96YT7VUA;F%G97(G(#T^
M(")!8FEL:71Y('1O('5S92!E=F5N="!M86YA9V5R(BP*"2=P;&5S:U]K97E?
M7V5X<&ER871I;VYS)R`]/B`B06)I;&ET>2!T;R!M86YA9V4@9&]M86EN(&%N
M9"!C;&EE;G0@86-C;W5N="!E>'!I<F%T:6]N(&1A=&5S(BP*"2=P;&5S:U]K
M97E?7V=R;W5P7V]P<R<@/3X@(D%B:6QI='D@=&\@<&5R9F]R;2!G;&]B86P@
M;W!E<F%T:6]N<R!O;B!O8FIE8W1S("AG<F]U<"!O<&5R871I;VYS*2(L"@DG
M<&QE<VM?:V5Y7U]E>'!I<F%T:6]N)R`]/B`B2V5Y(&5X<&ER871I;VX@9&%T
M92(L"@DG<&QE<VM?:V5Y7U]K97E?;G5M8F5R)R`]/B`B2V5Y(&YU;6)E<B(L
M"@DG<&QE<VM?:V5Y7U]L86YG=6%G97,G(#T^(")-87AI;75M(&YU;6)E<B!O
M9B!L86YG=6%G92!P86-K<R(L"@DG<&QE<VM?:V5Y7U]M86EL;F%M97,G(#T^
M(")-87AI;75M(&YU;6)E<B!O9B!M86EL(&%C8V]U;G1S(BP*"2=P;&5S:U]K
M97E?7VUI9W)A=&EO;E]M86YA9V5R)R`]/B`B06)I;&ET>2!T;R!U<V4@36EG
M<F%T:6]N($UA;F%G97(B+`H))W!L97-K7VME>5]?;7-S<6PG(#T^(")!8FEL
M:71Y('1O('5S92!-:6-R;W-O9G0@4U%,(%-E<G9E<B(L"@DG<&QE<VM?:V5Y
M7U]M>7!L97-K7V9U;F,G(#T^(")-4$,@9G5N8W1I;VYA;&ET>2(L"@DG<&QE
M<VM?:V5Y7U]M>7!L97-K7VUA;F%G92<@/3X@(D%D;6EN:7-T<F%T;W(@8V%N
M(&UA;F%G92!-4$,@<V5R=FEC92!A8V-E<W-I8FEL:71Y(BP*"2=P;&5S:U]K
M97E?7VUY<&QE<VM?<V5R=F5R7VED)R`]/B`B35!#('-L879E('-E<G9E<B!I
M9&5N=&EF:65R(BP*"2=P;&5S:U]K97E?7VYO=&EF:6-A=&EO;G,G(#T^(")!
M8FEL:71Y('1O(&UA;F%G92!N;W1I9FEC871I;VYS(BP*"2=P;&5S:U]K97E?
M7W!O<W1G<F5S<6PG(#T^(")!8FEL:71Y('1O('5S92!0;W-T9W)E4U%,(BP*
M"2=P;&5S:U]K97E?7W%M86EL7W%U975E)R`]/B`G06)I;&ET>2!T;R!M86YA
M9V4@;6%I;"!Q=65U92<L"@DG<&QE<VM?:V5Y7U]R96UO=&5?9&(G(#T^("=!
M8FEL:71Y('1O('5S92!R96UO=&4@9&%T86)A<V4@:&]S=&EN9R<L"@DG<&QE
M<VM?:V5Y7U]S:71E8G5I;&1E<B<@/3X@(D%B:6QI='D@=&\@=7-E($UA;6)O
M($--4R(L"@DG<&QE<VM?:V5Y7U]S;&%V95]S97)V97)S)R`]/B`B4VQA=F4@
M<V5R=F5R<R!L:6UI="(L"@DG<&QE<VM?:V5Y7U]S<&%M87-S87-S:6XG(#T^
M(")!8FEL:71Y('1O('5S92!3<&%M07-S87-S:6XB+`H))W!L97-K7VME>5]?
M<W5B9&]M86EN<R<@/3X@(D%B:6QI='D@=&\@;6%N86=E('-U8F1O;6%I;G,B
M+`H))W!L97-K7VME>5]?<WES7V%C8V5S<R<@/3X@(D%B:6QI='D@=&\@;6%N
M86=E('-H96QL(&%C8V5S<R(L"@DG<&QE<VM?:V5Y7U]T;VUC870G(#T^(")!
M8FEL:71Y('1O('5S92!4;VUC870B+`H))W!L97-K7VME>5]?=')A9F9I8U]R
M97!O<G1S)R`]/B`B06)I;&ET>2!T;R!U<V4@=')A9F9I8R!R97!O<G1I;F<B
M+`H))W!L97-K7VME>5]?='1S)R`]/B`B06)I;&ET>2!T;R!U<V4@2&5L<"!$
M97-K(BP*"2=P;&5S:U]K97E?7W9I<G1U;WIZ;R<@/3X@(E9A;&ED(&9O<B!6
M:7)T=6]Z>F\@;VYL>2(L"@DG<&QE<VM?:V5Y7U]W96)U<V5R<R<@/3X@(DUA
M>&EM=6T@;G5M8F5R(&]F('=E8B!U<V5R<R(L"@DG<&QE<VM?:V5Y7U]L:6-E
M;G-E7W5P9&%T95]D871E)R`]/B`G3F5X="!L:6-E;G-E(&ME>2!U<&1A=&4G
M+`H))W!L97-K7VME>5]?875T;VEN<W1A;&QE<E]C;VYF:6<G(#T^("=!8FEL
M:71Y('1O(&UA;F%G92!U<&1A=&5R('!R969E<F5N8V5S)RP*"2=P;&5S:U]K
M97E?=7!D871E7U]T:71L92<@/3X@)TME>2!5<&1A=&4@4W1A='5S)RP*"2=P
M;&5S:U]K97E?=7!D871E7U]L96=E;F0G(#T^("=+97D@57!D871E(%-T871U
M<R<L"@DG<&QE<VM?:V5Y7W5P9&%T95]?;F5W7V%D9&ET:6]N86Q?:V5Y)R`]
M/B`G3F5W(&%D9&ET:6]N86P@:V5Y(')E8V5I=F5D)RP*"@DG<&QE<VM?:V5Y
M7U]C:&5C:U]W<F]N9R<@"0D)"3T^("=4:&4@;&EC96YS92!K97D@:7,@;F]T
M('9A;&ED+B!4;R!U<V4@=&AE(&-O;G1R;VP@<&%N96PL(&]B=&%I;B!A;F0@
M:6YS=&%L;"!A(&YE=R!F=6QL>2!F96%T=7)E9"!L:6-E;G-E(&ME>2XG+`H)
M)W!L97-K7VME>5]?=7!L;V%D7V-H96-K7W=R;VYG)PD)"3T^("=4:&4@=7!L
M;V%D960@;&EC96YS92!K97D@:7,@;F]T('9A;&ED+B<L"@DG<&QE<VM?:V5Y
M7U]R979E<G1?8VAE8VM?=W)O;F<G"0D)/3X@)U1H92!P<F5V:6]U<VQY(&EN
M<W1A;&QE9"!L:6-E;G-E(&ME>2!I<R!N;W0@=F%L:60N)RP*"2=P;&5S:U]K
M97E?7W5P9&%T95]C:&5C:U]W<F]N9R<)"0D]/B`G5&AE('5P9&%T960@;&EC
M96YS92!K97D@:7,@;F]T('9A;&ED+B<L"@H))W!L97-K7VME>5]?:V5Y7V5X
M<&ER960G"0D)"3T^("=9;W5R(&QI8V5N<V4@:V5Y(&AA<R!E>'!I<F5D+B!4
M;R!C;VYT:6YU92!U<VEN9R!Y;W5R(&-O;G1R;VP@<&%N96PL('EO=2!M=7-T
M('!U<F-H87-E(&$@;F]N+65X<&ER:6YG(&-O;6UE<F-I86P@;&EC96YS92XG
M+`H))W!L97-K7VME>5]?=FER=6]Z>F]?;VYL>5]K97DG"0D)/3X@)U1H92!L
M:6-E;G-E(&ME>2!I<R!I;G1E;F1E9"!O;FQY(&9O<B!U<V4@=VET:"!0;&5S
M:R!I;G-I9&4@5FER='5O>GIO('9I<G1U86P@<')I=F%T92!S97)V97)S+B<L
M"@DG<&QE<VM?:V5Y7U]E87-Y7VUI<W5S960G"0D)"3T^("=4:&4@;&EC96YS
M92!K97D@9F]R(%!L97-K($5A<WD@86QL;W=S('-E<G9I;F<@;VYL>2!O;F4@
M8VQI96YT(&%C8V]U;G0N(%EO=2!H879E("4Q(&-L:65N=',N)RP*"2=P;&5S
M:U]K97E?7VEP7W)A;F=E<U]E>&-E961E9"<)"0D]/B`G66]U(&-A;B!U<V4@
M=&AI<R!L:6-E;G-E9"!0;&5S:R!C;W!Y(&]N;'D@=VET:"!T:&4@9F]L;&]W
M:6YG($E0(&%D9')E<W-E<SH@)3(N(%1H92!F;VQL;W=I;F<@25`@861D<F5S
M<V5S(&%R92!N;W0@8V]V97)E9"!B>2!Y;W5R(&QI8V5N<V4Z("4Q+B<L("\O
M)3$@=6YA;&QO=V5D(&%D9')E<W-E<R!L:7-T('-E<&%R871E9"!B>2!C;VUM
M82P@)3(@86QL;W=E9"!I<"!A9&1R97-S97,@;&ES="!S97!A<F%T960@8GD@
M8V]M;6$*"2=P;&5S:U]K97E?7VQI;6ET<U]E>&-E961E9"<)"0D]/B`G5&AE
M(&%M;W5N="!O9B!C=7)R96YT;'D@=7-E9"!R97-O=7)C97,@;W9E<G)I9&5S
M('1H92!L:6UI=',@9&5F:6YE9"!B>2!Y;W5R(&QI8V5N<V4N)RP*"2=P;&5S
M:U]K97E?7VQI;6ET<U]E>&-E961E9%]L:6U?9&]M)PD]/B`G5&AE(&YU;6)E
M<B!O9B!W96(@<VET97,@:&]S=&5D(&]N('1H92!S97)V97(@97AC965D<R!T
M:&4@;&EM:71S(&1E9FEN960@8GD@>6]U<B!L:6-E;G-E+B!9;W4@:&%V92`E
M,B!S:71E<R!H;W-T960[('EO=7(@;&EC96YS92!A;&QO=W,@:&]S=&EN9R!O
M;FQY("4Q('-I=&5S+B<L("\O("4Q(&QI;6ET('9A;'5E+"`E,B!U<V5D('9A
M;'5E+"`E,R!D96QT82!V86QU90H))W!L97-K7VME>5]?;&EM:71S7V5X8V5E
M9&5D7VQI;5]C;"<)"3T^("=4:&4@;G5M8F5R(&]F('-E<G9E9"!C;&EE;G0@
M86-C;W5N=',@97AC965D<R!T:&4@;&EM:71S(&1E9FEN960@8GD@>6]U<B!L
M:6-E;G-E+B!9;W4@:&%V92`E,B!C;&EE;G0@86-C;W5N=',@8W5R<F5N=&QY
M('-E<G9E9#L@>6]U<B!L:6-E;G-E(&%L;&]W<R!S97)V:6YG(&]N;'D@)3$@
M8VQI96YT(&%C8V]U;G1S+B<L("\O)3$@;&EM:70@=F%L=64L("4R('5S960@
M=F%L=64L("4S(&1E;'1A('9A;'5E"@DG<&QE<VM?:V5Y7U]L:6UI='-?97AC
M965D961?;&EM7VUN)PD)/3X@)U1H92!N=6UB97(@;V8@<V5R=F5D(&4M;6%I
M;"!A8V-O=6YT<R!E>&-E961S('1H92!L:6UI=',@9&5F:6YE9"!B>2!Y;W5R
M(&QI8V5N<V4N(%EO=2!H879E("4R(&4M;6%I;"!A8V-O=6YT<R!C=7)R96YT
M;'D@<V5R=F5D.R!Y;W5R(&QI8V5N<V4@86QL;W=S('-E<G9I;F<@;VYL>2`E
M,2!E+6UA:6P@86-C;W5N=',N)RP@+R\@)3$@;&EM:70@=F%L=64L("4R('5S
M960@=F%L=64L("4S(&1E;'1A('9A;'5E"@DG<&QE<VM?:V5Y7U]L:6UI='-?
M97AC965D961?;&EM7W=U)PD)/3X@)U1H92!N=6UB97(@;V8@<V5R=F5D('=E
M8B!U<V5R(&%C8V]U;G1S(&5X8V5E9',@=&AE(&QI;6ET<R!D969I;F5D(&)Y
M('EO=7(@;&EC96YS92X@66]U(&AA=F4@)3(@=V5B('5S97(@86-C;W5N=',@
M8W5R<F5N=&QY('-E<G9E9#L@>6]U<B!L:6-E;G-E(&%L;&]W<R!S97)V:6YG
M(&]N;'D@)3$@=V5B('5S97(@86-C;W5N=',N)RP@+R\@)3$@;&EM:70@=F%L
M=64L("4R('5S960@=F%L=64L("4S(&1E;'1A('9A;'5E"@DG<&QE<VM?:V5Y
M7U]L:6UI='-?97AC965D961?34Q3)PD)/3X@)U1H92!N=6UB97(@;V8@8W5R
M<F5N=&QY('5S960@;&%N9W5A9V4@<&%C:W,@97AC965D<R!T:&4@;&EM:71S
M(&1E9FEN960@8GD@>6]U<B!L:6-E;G-E+B!4:&5R92!A<F4@)3(@;&%N9W5A
M9V4@<&%C:W,@:6YS=&%L;&5D.R!Y;W5R(&QI8V5N<V4@86QL;W=S(&EN<W1A
M;&QI;F<@;VYL>2`E,2!L86YG=6%G92!P86-K<RXG+"`O+R`E,2!L:6UI="!V
M86QU92P@)3(@=7-E9"!V86QU92P@)3,@9&5L=&$@=F%L=64*"@DG<&QE<VM?
M:V5Y7U]K97E?9FEL95]I;G9A;&ED)R`]/B`G5&AE('5P;&]A9&5D(&ME>2!F
M:6QE(&ES(&YO="!V86QI9"!O<B!D;V5S(&YO="!C;VYT86EN(&$@;&EC96YS
M92!K97DN)RP*"2=K97E?7W1I=&QE)R`]/B`G3&EC96YS92!-86YA9V5M96YT
M)RP*"2=K97E?7W5P;&]A9%]T:71L92<@/3X@)TQI8V5N<V4@2V5Y(%5P;&]A
M9"<L"@DG:V5Y7U]U<&QO861?;&5G96YD)R`]/B`G3&EC96YS92!K97D@=7!L
M;V%D)RP*"2=K97E?7V9I;&4G(#T^("=0871H('1O('1H92!L:6-E;G-E(&ME
M>2!F:6QE(&QO8V%T:6]N)RP*"2=K97E?7VYO7VME>5]F:6QE7VEN7WII<"<@
M/3X@)U1H92!U<&QO861E9"`N>FEP(&9I;&4@9&]E<R!N;W0@8V]N=&%I;B!K
M97D@9FEL92<L"@DG:V5Y7U]K97E?=7!L;V%D)R`]/B`G3&EC96YS92!+97D@
M26YS=&%L;&%T:6]N)RP*"2=K97E?7V]V97)W<FET95]C;VYF:7)M871I;VXG
M(#T^("=297!L86-E('1H92!C=7)R96YT;'D@:6YS=&%L;&5D(&QI8V5N<V4@
M:V5Y('=I=&@@=&AE('-E;&5C=&5D(&]N92<L"@DG:V5Y7U]O=F5R=W)I=&5?
M8V]N9FER;6%T:6]N7W)E<75I<F5D)R`]/B`G4&QE87-E(&-O;F9I<FT@=&AE
M(&QI8V5N<V4@:V5Y(')E<&QA8V5M96YT+B<L"@DG:V5Y7U]L:6UI='-?97AC
M965D961?8V]N9FER;6%T:6]N)R`]/B`G1&\@;F]T(&-H96-K('1H92!L:6UI
M=',@;VX@<F5S;W5R8V4@=7-A9V4@9&5F:6YE9"!B>2!T:&4@:V5Y)RP*"2=K
M97E?7W1A8G-?<&QE<VLG(#T^("=0;&5S:R!,:6-E;G-E($ME>2<L"@DG:V5Y
M7U]T86)S7V%D9&ET:6]N86PG(#T^("=!9&1I=&EO;F%L($QI8V5N<V4@2V5Y
M<R<L"@DG:V5Y7W)E=F5R=%]?=&ET;&4G(#T^("=,:6-E;G-E($ME>2!2;VQL
M8F%C:R<L"@DG:V5Y7W)E=F5R=%]?;&5G96YD)R`]/B`G2V5Y(')O;&QB86-K
M(&-O;F9I<FUA=&EO;B<L"@DG:V5Y7W)E=F5R=%]?=&5X="<@/3X@)U1H92!L
M:6-E;G-E(&ME>2!W:71H('1H92!F;VQL;W=I;F<@<')O<&5R=&EE<R!W:6QL
M(&)E(')E<W1O<F5D.B<L"@DG861D:71I;VYA;%]K97E?7VEN9F\G(#T^("=!
M9&1I=&EO;F%L($ME>2!0<F]P97)T:65S)RP*"2=A9&1I=&EO;F%L7VME>5]?
M<')O<%]N86UE)R`]/B`G4')O<&5R='DG+`H))V%D9&ET:6]N86Q?:V5Y7U]P
M<F]P7W9A;'5E)R`]/B`G5F%L=64G+`H))V%D9&ET:6]N86Q?:V5Y7U]D97-C
M<E]N86UE)R`]/B`G2V5Y(&YA;64G+`H))V%D9&ET:6]N86Q?:V5Y7U]D97-C
M<E]K97E?;G5M8F5R)R`]/B`G2V5Y(&YU;6)E<B<L"@DG861D:71I;VYA;%]K
M97E?7V1E<V-R7VQI;5]D871E)R`]/B`G17AP:7)A=&EO;B!D871E)RP*"2=A
M9&1I=&EO;F%L7VME>5]?9&5S8W)?;&EC96YS95]U<&1A=&5?9&%T92<@/3X@
M)TYE>'0@;&EC96YS92!K97D@=7!D871E)RP*"2=A9&1I=&EO;F%L7VME>5]?
M<F5M;W9E7W1I=&QE)R`]/B`B5&AE('-I=&4@87!P;&EC871I;VX@:V5Y('=I
M=&@@=&AE(&9O;&QO=VEN9R!P<F]P97)T:65S('=I;&P@8F4@<F5M;W9E9#HB
M+`H))V%D9&ET:6]N86Q?:V5Y<U]?<F5M;W9E7W1I=&QE)R`]/B`B5&AE(&9O
M;&QO=VEN9R!A9&1I=&EO;F%L(&ME>7,@=VEL;"!B92!R96UO=F5D.B(L"@DG
M861D:71I;VYA;%]K97ES7U]S96QE8W1?=&]?<F5M;W9E)R`]/B`G4V5L96-T
M('1H92!A9&1I=&EO;F%L(&ME>7,@=&\@8F4@<F5M;W9E9"XG+`H))V%D9&ET
M:6]N86Q?:V5Y7U]F:6QE7VEN=F%L:60G(#T^("=4:&4@=7!L;V%D960@:V5Y
M(&9I;&4@:7,@;F]T('9A;&ED(&]R(&1O97,@;F]T(&-O;G1A:6X@82!L:6-E
M;G-E(&ME>2XG+`H))V%D9&ET:6]N86Q?:V5Y7U]F:6QE7VEN8V]M<&%T:6)L
M92<@/3X@)U1H92!U<&QO861E9"!K97D@9FEL92!I<R!N;W0@=F%L:60@9F]R
M('1H:7,@87!P;&EC871I;VXN)RP*"2=A9&1I=&EO;F%L7VME>5]?;F]T7V5X
M:7-T<R<@/3X@)TYO(&QI8V5N<V4@:V5Y(&EN<W1A;&QE9"XG+`H))V%D9&ET
M:6]N86Q?:V5Y<U]?;&5G96YD)R`]/B`G061D:71I;VYA;"!K97ES)RP*"2=A
M9&1I=&EO;F%L7VME>7-?7VQI<W1?:&5A9&5R)R`]/B`G061D:71I;VYA;"!K
M97ES)RP*"2=A9&1I=&EO;F%L7VME>5]U<&1A=&5?7W1I=&QE)R`]/B`G57!D
M871I;F<@061D:71I;VYA;"!+97DN)RP*"2=A9&1I=&EO;F%L7VME>5]U<&1A
M=&5?7VQE9V5N9"<@/3X@)U-T871U<R!O9B!A9&1I=&EO;F%L(&ME>2!U<&1A
M=&4N)RP*"2=A9&1I=&EO;F%L7VME>5]U<&1A=&5?7VYE=U]K97DG(#T^("=!
M9&1I=&EO;F%L($ME>2!0<F]P97)T:65S)RP*"2=A9&1I=&EO;F%L7VME>5]U
M<&1A=&5?7W)E<W5L=%]R97-P;VYS92<@/3X@)TQI8V5N<VEN9R!S97)V97(@
M<F5S<&]N<V4Z("4Q)RP*"2=A9&1I=&EO;F%L7VME>5]U<&1A=&5?7W)E<W5L
M=%]N971W;W)K)R`]/B`G56YA8FQE('1O(&-O;FYE8W0@=&\@=&AE(&QI8V5N
M<VEN9R!S97)V97(N(%!L96%S92!M86ME('-U<F4@=&AA="!Y;W5R(&YE='=O
M<FL@86QL;W=S(&-O;6UU;FEC871I;VX@=&\@)3$Z("4R+B<L"@DG861D:71I
M;VYA;%]K97E?=7!D871E7U]R97-U;'1?;&]C:R<@/3X@)TME>2!U<&1A=&4@
M:7,@86QR96%D>2!I;B!P<F]G<F5S<R<L"@DG861D:71I;VYA;%]K97E?=7!D
M871E7U]R97-U;'1?:6YT97)N86Q?97)R;W(G(#T^("=%<G)O<B!O8V-U<G)E
M9"!W:&EL92!U<&1A=&EN9R!T:&4@;&EC96YS92!K97DZ("4Q)RP*"@DG8G1?
M861D:71I;VYA;%]K97E?<F5V97)T)R`]/B`G4F]L;"!"86-K($ME>2<L"@DG
M8G1?861D:71I;VYA;%]K97E?=7!D871E)R`]/B`G4F5T<FEE=F4@061D:71I
M;VYA;"!+97DG+`H))V%D9&ET:6]N86Q?:V5Y7W)E=F5R=%]?=&ET;&4G(#T^
M("=0;&5A<V4@8V]N9FER;2!T:&4@;W!E<F%T:6]N)RP*"2=A9&1I=&EO;F%L
M7VME>5]R979E<G1?7VQE9V5N9"<@/3X@)U!R;W!E<G1I97,@;V8@=&AE('!R
M979I;W5S;'D@=7-E9"!A9&1I=&EO;F%L(&ME>2<L"@DG861D:71I;VYA;%]K
M97E?<F5V97)T7U]C;VYF:7)M7W1E>'0G(#T^("=2;VQL(&)A8VL@:V5Y)RP*
M"2=A9&1I=&EO;F%L7VME>5]R979E<G1?7V-O;F9I<FU?<F5Q=6ER960G(#T^
M("=0;&5A<V4@8V]N9FER;2!T:&4@;W!E<F%T:6]N+B<L"@H))W!R;V-E961?
M=&]?8VQ?<&]O;"<@/3X@(E!R;V-E960@=&\@8V]N9FEG=7)I;F<@8VQI96YT
M)W,@25`@<&]O;"(L"@DG<')O8V5E9%]T;U]H;W-T:6YG7W-E='5P)R`]/B`B
M4')O8V5E9"!T;R!H;W-T:6YG('-E='5P(BP*"2=R96UO=F5#97)T<U]?<F5M
M;W9E7V-E<G1I9FEC871E<U]C<"<@/3X@(E1H92!F;VQL;W=I;F<@8V5R=&EF
M:6-A=&5S('=I;&P@8F4@<F5M;W9E9#H@(BP*"2=R96UO=F5#97)T<U]?<F5M
M;W9E7V-E<G1I9FEC871E<U]D;VUA:6XG(#T^(")4:&4@9F]L;&]W:6YG(&-E
M<G1I9FEC871E<R!O=VYE9"!B>2`E,2!W:6QL(&)E(')E;6]V960Z("(L"@DG
M<F5M;W9E0VQI96YT<TE07W)E;6]V95]C;&EE;G1S7VEP)R`]/B`B5&AI<R!)
M4"!A9&1R97-S('=I;&P@8F4@<F5M;W9E9"!F<F]M('1H92!P;V]L<R!O9B!T
M:&4@9F]L;&]W:6YG(&-L:65N=',Z(BP*"2=R96UO=F5#;&EE;G1S4VET94%P
M<%]R96UO=F5?8VQI96YT<R<@/3X@(E1H:7,@<VET92!A<'!L:6-A=&EO;B!W
M:6QL(&)E(')E;6]V960@9G)O;2!T:&4@<&]O;',@;V8@=&AE(&9O;&QO=VEN
M9R!C;&EE;G1S.B(L"@DG<F5M;W9E0VQI96YT<U]?<F5M;W9E7V-L:65N='-?
M9&]M86EN<R<@/3X@(E1H92!F;VQL;W=I;F<@8VQI96YT(&%C8V]U;G1S(&%N
M9"!T:&5I<B!D;VUA:6YS('=I;&P@8F4@<F5M;W9E9#HB+`H))W)E;6]V94UA
M:6Q!;&EA<V5S7U]R96UO=F5?;6%I;%]A;&EA<V5S)R`]/B`B5&AE(&9O;&QO
M=VEN9R!M86EL(&%L:6%S97,@9F]R('1H92!M86EL(&YA;64@)3$@=VEL;"!B
M92!R96UO=F5D.B(L"@DG<F5M;W9E36%I;$YA;65S7U]R96UO=F5?;6%I;&YA
M;65S)R`]/B`B5&AE(&9O;&QO=VEN9R!M86EL(&YA;65S(&%N9"!A;&EA<V5S
M('=I;&P@8F4@<F5M;W9E9"!F<F]M('1H92!D;VUA:6X@)3$Z(BP*"2=R96UO
M=F5-86EL3F%M97-?7W)E;6]V95]M86EL;F%M97-?;V9?8VPG(#T^(")4:&4@
M9F]L;&]W:6YG(&UA:6P@;F%M97,@86YD(&%L:6%S97,@=VEL;"!B92!R96UO
M=F5D(&9R;VT@9&]M86EN("4R(&]W;F5D(&)Y(&-L:65N="`E,3HB+`H))W)E
M;6]V94UA:6Q.86UE<U]?=&AE<V5?;6%I;&YA;65S7W=I;&Q?;F]T7V1E;&5T
M92<@/3X@(E1H97-E(&UA:6P@;F%M97,@=VEL;"!N;W0@8F4@9&5L971E9"XB
M+`H))W)E;6]V95-E<W-I;VYS7U]R96UO=F5?=&ET;&4G(#T^(")4:&4@9F]L
M;&]W:6YG('-E<W-I;VYS('=I;&P@8F4@96YD960Z(BP*"2=R96UO=F5&='!3
M97-S:6]N<U]?<F5M;W9E7W1I=&QE)R`]/B`B5&AE(&9O;&QO=VEN9R!&5%`@
M<V5S<VEO;G,@=VEL;"!B92!E;F1E9#HB+`H))W)E;6]V951E;7!L871E<U]?
M<F5M;W9E7W1E;7!L871E<R<@/3X@(E1H92!F;VQL;W=I;F<@=&5M<&QA=&5S
M('=I;&P@8F4@<F5M;W9E9#HB+`H))W)E<&]R=%]A=71O7U]L:7-T7W1I=&QE
M)R`]/B`G1"<L"@DG<F5P;W)T7V%U=&]?7VQI<W1?875T;R<@/3X@)T9R97%U
M96YC>2<L"@DG<F5P;W)T7V%U=&]?7VQI<W1?;&%S="<@/3X@)TQA<W0@9&5L
M:79E<GD@9&%T92<L"@DG<F5P;W)T7V%U=&]?7VQI<W1?<F5C:7!I96YT)R`]
M/B`G1&5L:79E<B!T;R<L"@DG<F5P;W)T7V%U=&]?7VQI<W1?<V5L96-T)R`]
M/B`G4F5P;W)T(&]N)RP*"2=R97!O<G1?875T;U]?=&ET;&4G(#T^("=$96QI
M=F5R>2!38VAE9'5L97,@9F]R("4Q)RP*"2=R97!O<G1?875T;U]?<F5C:7!I
M96YT7V5M86EL)R`]/B`G=&AE(&4M;6%I;"!A9&1R97-S($D@<W!E8VEF>2<L
M"@DG<F5P;W)T7V%U=&]?7W)E8VEP:65N=%]A9&UI;B<@/3X@)W1H92!S97)V
M97(@861M:6YI<W1R871O<B<L"@DG<F5P;W)T7V%U=&]?7W)E8VEP:65N=%]C
M;&EE;G0G(#T^("=T:&4@8VQI96YT)RP*"2=R97!O<G1?875T;U]?<F5C:7!I
M96YT7V1O;6%I;B<@/3X@)W1H92!D;VUA:6X@861M:6YI<W1R871O<B<L"@DG
M<F5P;W)T7V%U=&]?961I=%]?<V5L96-T)R`]/B`G4F5P;W)T(&]N)RP*"2=R
M97!O<G1?875T;U]?<V5L96-T7V-L:65N=%]R97!O<G1?86QL)R`]/B`G86QL
M(&-L:65N=',G+`H))W)E<&]R=%]A=71O7U]S96QE8W1?8VQI96YT7W)E<&]R
M=%]C=7)R96YT)R`]/B`G=&AI<R!C;&EE;G0G+`H))W)E<&]R=%]A=71O7U]S
M96QE8W1?8VQI96YT7W)E<&]R=%]O=&AE<E]C;&EE;G0G(#T^("<E,2<L"@DG
M<F5P;W)T7V%U=&]?7W-E;&5C=%]D;VUA:6Y?<F5P;W)T7V%L;"<@/3X@)V%L
M;"!D;VUA:6YS)RP*"2=R97!O<G1?875T;U]?<V5L96-T7V1O;6%I;E]R97!O
M<G1?;W1H97)?8VQI96YT)R`]/B`G86QL(&1O;6%I;G,@;V8@)3$G+`H))W)E
M<&]R=%]A=71O7U]S96QE8W1?9&]M86EN7W)E<&]R=%]C;&EE;G0G(#T^("=A
M;&P@9&]M86EN<R!O9B!T:&ES(&-L:65N="<L"@DG<F5P;W)T7V%U=&]?7W-E
M;&5C=%]D;VUA:6Y?<F5P;W)T7V-U<G)E;G0G(#T^("=T:&ES(&1O;6%I;B<L
M"@DG<F5P;W)T7V%U=&]?7W-E;&5C=%]D;VUA:6Y?<F5P;W)T7V]T:&5R7V1O
M;6%I;B<@/3X@)R4Q)RP*"2=R97!O<G1?875T;U]?;&5G96YD)R`]/B`G1&5L
M:79E<GD@<V-H961U;&5S)RP*"2=R97!O<G1?875T;U]?<V5L96-T7V9O<E]R
M96UO=F4G(#T^(")396QE8W0@=&AE(&1E;&EV97)Y('-C:&5D=6QE<R!T;R!B
M92!R96UO=F5D+B(L"@DG<F5P;W)T7V%U=&]?<F5M;W9E7U]T:71L92<@/3X@
M(E1H92!F;VQL;W=I;F<@<F5P;W)T(&1E;&EV97)Y('-C:&5D=6QE<R!W:6QL
M(&)E(')E;6]V960Z(BP*"2=R97!O<G1?875T;U]E9&ET7U]T:71L92<@/3X@
M)T1E;&EV97)Y(%-C:&5D=6QE(%!R;W!E<G1I97,G+`H))W)E<&]R=%]A=71O
M7V5D:71?7W)E8VEP:65N="<@/3X@)T1E;&EV97(@=&\G+`H))W)E<&]R=%]A
M=71O7V5D:71?7W1A<F=E="<@/3X@)U)E<&]R="!O;B<L"@DG<F5P;W)T7V%U
M=&]?961I=%]?875T;R<@/3X@)T1E;&EV97)Y(&9R97%U96YC>2<L"@DG<F5S
M<%]E9&ET7U]A;'=A>7-?<F5S<&]N9"<@/3X@(F%L=V%Y<R!R97-P;VYD(BP*
M"2=R97-P7V5D:71?7W)E<&QY7W-U8FIE8W0G(#T^(")297!L>2!S=6)J96-T
M(BP*"2=R97-P7V5D:71?7V%N<W=E<E]T>'0G(#T^(")297!L>2!W:71H('1E
M>'0B+`H))W)E<W!?961I=%]?871T86-H)R`]/B`B071T86-H(&9I;&5S(BP*
M"2=R97-P7V5D:71?7V1E9F%U;'1?<W5B:F5C="<@/3X@(E)E.B`E,2(L"@DG
M<F5S<%]E9&ET7U]F;W(G(#T^(")F;W(@(BP*"2=R97-P7V5D:71?7V9R=U]R
M<7-T7V5M86EL)R`]/B`B57!O;B!A=71O;6%T:6,@<F5S<&]N<V4L(&9O<G=A
M<F0@=&AE(&]R:6=I;F%L(&UE<W-A9V4@=&\@=&AE('-P96-I9FEE9"!E+6UA
M:6PB+`H))W)E<W!?961I=%]?9G=D7V5M86EL7VEN=F%L:60G(#T^(")$97-T
M:6YA=&EO;B!E+6UA:6P@861D<F5S<R!I<R!I;G9A;&ED+B(L"@DG<F5S<%]E
M9&ET7U]I;E]B;V1Y)R`]/B`B=VAE;B!S<&5C:69I960@=V]R9',@87)E(&9O
M=6YD(&EN('1H92!M97-S86=E(&)O9'DB+`H))W)E<W!?961I=%]?:6Y?<W5B
M:F5C="<@/3X@(G=H96X@<W!E8VEF:65D('=O<F1S(&%R92!F;W5N9"!I;B!M
M97-S86=E('-U8FIE8W0B+`H))W)E<W!?961I=%]?:6YV86QI9%]R97-P7V9R
M97$G(#T^(")297-P;VYS92!F<F5Q=65N8WD@:7,@:6YV86QI9"XB+`H))W)E
M<W!?961I=%]?:6YV86QI9%]R<7-T7W1X="<@/3X@(DEN=F%L:60@<F5Q=65S
M="!T97AT+B(L"@DG<F5S<%]E9&ET7U]I;G9A;&ED7W-T;W)E7VQI;5]N=6TG
M(#T^("),:6UI="!V86QU92!I<R!I;G9A;&ED+B(L"@DG<F5S<%]E9&ET7U]L
M:6UI='-?=&ET;&4G(#T^("),:6UI=',B+`H))W)E<W!?961I=%]?;6%X:6UU
M;5]A;&QO=V5D7W)E<W!?9G)E<5]R96%C:&5D)R`]/B`B3G5M8F5R(&]F(&UA
M>&EM=6T@<F5S<&]N<V5S('!E<B!D87D@97AC965D<R!T:&4@9&5F:6YE9"!R
M871E+B!!;&QO=V5D.B`E,2P@<F5Q=65S=&5D.B`E,B(L"@DG<F5S<%]E9&ET
M7U]N;U]F:6QE<U]S96PG(#T^(").;R!F:6QE<R!S96QE8W1E9"XB+`H))W)E
M<W!?961I=%]?;F]?='AT7W-U<'!L:65D)R`]/B`B3F\@=&5X="!S=7!P;&EE
M9"XB+`H))W)E<W!?961I=%]?<F5P;'E?=&ET;&4G(#T^(")297!L>2(L"@DG
M<F5S<%]E9&ET7U]R97!L>5]T;U]A9&1R97-S)R`]/B`B4F5T=7)N(&%D9')E
M<W,B+`H))W)E<W!?961I=%]?<F5P;'E?=&]?:6YV86QI9"<@/3X@(E)E='5R
M;B!A9&1R97-S(&ES(&EN=F%L:60N(BP*"2=R97-P7V5D:71?7W)E<&QY7W5N
M:7%?96UA:6PG(#T^(")297!L>2!T;R!T:&4@=6YI<75E(&4M;6%I;"!A9&1R
M97-S(&YO="!M;W)E('1H86XB+`H))W)E<W!?961I=%]?8V]N9&ET:6]N<U]T
M:71L92<@/3X@(D-O;F1I=&EO;G,B+`H))W)E<W!?961I=%]?<F5S<"<@/3X@
M(D%U=&]R97-P;VYD97(@("(L"@DG<F5S<%]E9&ET7U]R97-P7VYA;64G(#T^
M(")!=71O<F5S<&]N9&5R(&YA;64B+`H))W)E<W!?961I=%]?<F5S<%]N;W1?
M97AI<W0G(#T^(")!=71O<F5S<&]N9&5R(&1O97,@;F]T(&5X:7-T+B(L"@DG
M<F5S<%]E9&ET7U]R97-P7W-T871U<R<@/3X@(D%U=&]R97-P;VYD97(@<W1A
M='5S(BP*"2=R97-P7V5D:71?7W)Q<W1?='AT)R`]/B`G4W!E8VEF>2!T:&4@
M8V]N9&ET:6]N(&9O<B!T:&ES(&%U=&]M871I8R!R97!L>2<L"@DG<F5S<%]E
M9&ET7U]S96QE8W1?9FEL97-?;VY?<V5R=F5R7V9O<E]A='1A8V@G(#T^(")3
M96QE8W0@=&AE(&9I;&5S('EO=2!W86YT('1O(&%T=&%C:"(L"@DG<F5S<%]E
M9&ET7U]S=&]R95]U<%]T;R<@/3X@(E-T;W)E('5P('1O(BP*"2=R97-P7V5D
M:71?7W-U8FI?;&EN95]I;G9A;&ED)R`]/B`B4W5B:F5C="!L:6YE(&ES(&EN
M8V]R<F5C="XB+`H))W)E<W!?961I=%]?=&5X=%]T;V]?8FEG)R`]/B`B5&AE
M(')E<&QY(&UE<W-A9V4@=&5X="!I<R!T;V\@;&%R9V4N(BP*"2=R97-P7V5D
M:71?7W1I;65S7VEN7V%?9&%Y)R`]/B`B=&EM97,@82!D87DN(BP*"2=R97-P
M7V5D:71?7W5N86)L95]D969I;F5?<F5S<%]C;VYD)R`]/B`B56YA8FQE('1O
M(&1E9FEN92!T:&4@875T;W)E<W!O;F1E<B!C;VYD:71I;VXZ("4Q(BP*"2=R
M97-P7V5D:71?7W5N86)L95]D969I;F5?<F5S<%]S=&%T=7,G(#T^(")5;F%B
M;&4@=&\@9&5F:6YE(&%U=&]R97-P;VYD97(@<W1A='5S.B`E,2(L"@DG<F5S
M<%]E9&ET7U]U;F%B;&5?='5R;E]O;E]R97-P)R`]/B`B56YA8FQE('1O('1U
M<FX@;VX@=&AE(&%U=&]R97-P;VYD97(Z("4Q(BP*"2=R97-P7V5D:71?7W5N
M:7%?96UA:6PG(#T^(")U;FEQ=64@92UM86EL(&%D9')E<W-E<R(L"@DG<F5S
M<%]E9&ET7U]C;VYT96YT7W1Y<&4G(#T^("=-86EL('-E;F1I;F<@9F]R;6%T
M)RP*"2=R97-P7V5D:71?7V-O;G1E;G1?='EP95]T97AT)R`]/B`G4&QA:6X@
M=&5X="<L"@DG<F5S<%]E9&ET7U]C;VYT96YT7W1Y<&5?:'1M;"<@/3X@)TA4
M34PG+`H))W)E<W!?961I=%]?8VAA<G-E="<@/3X@)T5N8V]D:6YG)RP*"2=R
M97-T87)T7U]C;VQD9G5S:6]N)R`]/B`B0V]L9$9U<VEO;B`H)3$I(BP*"2=R
M97-T87)T7U]C;VQD9G5S:6]N7VEN<W1A;&QA=&EO;E]T>7!E)R`]/B`B26YS
M=&%L;&%T:6]N('1Y<&4Z("4Q(BP*"2=R97-T87)T7U]D;G,G(#T^("=$3E,@
M4V5R=F5R("@E,2DG+`H))W)E<W1A<G1?7V1R=V5B)R`]/B`G1'(N5V5B(&%N
M=&EV:7)U<R<L"@DG<F5S=&%R=%]?;6%I;"<@/3X@(DE-05`O4$]0,R!397)V
M97(@*"4Q*2(L"@DG<F5S=&%R=%]?;7-S<6PG(#T^(")-:6-R;W-O9G0@4U%,
M('-E<G9E<B(L"@DG<F5S=&%R=%]?<&]S=&=R97-Q;"<@/3X@(E!O<W1G<F53
M44PB+`H))W)E<W1A<G1?7W!S82<@/3X@(E-E<G9I8V5S(&UA;F%G96UE;G0B
M+`H))W)E<W1A<G1?7W-M='`G(#T^(")33510(%-E<G9E<B`H)3$I(BP*"2=R
M97-T87)T7U]S<&%M87-S87-S:6XG(#T^(")3<&%M07-S87-S:6XB+`H))W)E
M<W1A<G1?7W-T=6YN96PG(#T^(")3='5N;F5L(BP*"2=R97-T87)T7U]T;VUC
M870G(#T^(")4;VUC870B+`H))W)E<W1A<G1?7W=E8B<@/3X@(E=E8B!397)V
M97(@*"4Q*2(L"@DG<FU?9&]M86EN<U]?<V]M95]D;VUA:6YS7V%R95]N;W1?
M97AI<W0G(#T^(")3;VUE(&]F('1H92!S<&5C:69I960@9&]M86EN<R!D;R!N
M;W0@97AI<W0N(%1H97D@:&%V92!B965N('!O<W-I8FQY(')E;6]V960@8GD@
M86YO=&AE<B!U<V5R+B(L"@DG<G!T7V-L7V1O;5]D871A7V)A<V5S)R`]/B`B
M1$)A<V5S(BP*"2=R<'1?8VQ?9&]M7VUA:6Q?9W)O=7!S)R`]/B`B34=R;W5P
M<R(L"@DG<G!T7V-L7V1O;5]M86EL7VQI<W1S)R`]/B`B34QI<W1S(BP*"2=R
M<'1?8VQ?9&]M7VUA:6Q?<F5S<',G(#T^(")!4F5S<"XB+`H))W)P=%]C;%]D
M;VU?<&]S=&)O>&5S)R`]/B`B34)O>&5S(BP*"2=R<'1?8VQ?9&]M7W)E9&ER
M96-T<R<@/3X@(E)E9&ER+B(L"@DG<G!T7V-L7V1O;5]S=6)D;VUA:6YS)R`]
M/B`B4W5B9&]M(BP*"2=R<'1?8VQ?9&]M7W=E8E]U<V5R<R<@/3X@(E=5<V5R
M<R(L"@DG<G!T7V-L7V1O;5]W96)A<'!S)R`]/B`B5T%P<',B+`H))W)P=%]C
M;%]R97!O<G1?9F]R7V-L7U\G(#T^(")297!O<G0@;VX@8VQI96YT("4Q(BP*
M"2=R<'1?8VQ?<V5C=&EO;E]D;VUA:6YS)R`]/B`B1&]M86EN<R(L"@DG<G!T
M7V-L7W-E8W1I;VY?9G5L;%]D;VUA:6YS)R`]/B`B1&]M86EN<R(L"@DG<G!T
M7V-L7W-E8W1I;VY?9V5N97)A;"<@/3X@(D=E;F5R86PB+`H))W)P=%]C<F5A
M=&4G(#T^(")#<F5A=&4@<F5P;W)T(BP*"2=R<'1?96UP='DG(#T^(")4:&4@
M<F5P;W)T('-H;W5L9"!C;VYT86EN(&%T(&QE87-T(&]N92!S96-T:6]N(BP*
M"2=R<'1?9&5F875L=%]R97!O<G0G(#T^(")5<V4@87,@9&5F875L="!R97!O
M<G0B+`H))W)P=%]D;VU?<F5P;W)T7V9O<E]D;VU?7R<@/3X@(D1O;6%I;B!R
M97!O<G0@9F]R("4Q(BP*"2=R<'1?9&]M7W-E8W1I;VY?9&%T86)A<V5S)R`]
M/B`B1&%T86)A<V5S(BP*"2=R<'1?9&]M7W-E8W1I;VY?9G5L;%]D871A8F%S
M97,G(#T^(")$871A8F%S97,B+`H))W)P=%]D;VU?<V5C=&EO;E]F=6QL7VUA
M:6QL:7-T<R<@/3X@(DUA:6QI;F<@;&ES=',B+`H))W)P=%]D;VU?<V5C=&EO
M;E]F=6QL7VUA:6QN86UE<R<@/3X@(DUA:6P@;F%M97,B+`H))W)P=%]D;VU?
M<V5C=&EO;E]F=6QL7W=E8G5S97)S)R`]/B`B5V5B('5S97)S(BP*"2=R<'1?
M9&]M7W-E8W1I;VY?9G5L;%]S:71E87!P<R<@/3X@)U-I=&4@87!P;&EC871I
M;VYS)RP*"2=R<'1?9&]M7W-E8W1I;VY?9G5L;%]T;VUC870G(#T^(")*879A
M(&%P<&QI8V%T:6]N<R(L"@DG<G!T7V1O;5]S96-T:6]N7V=E;F5R86PG(#T^
M(")'96YE<F%L(BP*"2=R<'1?9&]M7W-E8W1I;VY?:&]S=&EN9R<@/3X@(DAO
M<W1I;F<B+`H))W)P=%]D;VU?<V5C=&EO;E]L:7-T7W1O;6-A="<@/3X@(DIA
M=F$@87!P;&EC871I;VYS(BP*"2=R<'1?9&]M7W-E8W1I;VY?;6%I;&QI<W1S
M)R`]/B`B36%I;&EN9R!L:7-T<R(L"@DG<G!T7V1O;5]S96-T:6]N7VUA:6QN
M86UE<R<@/3X@(DUA:6P@;F%M97,B+`H))W)P=%]D;VU?<V5C=&EO;E]S:71E
M87!P<R<@/3X@)U-I=&4@87!P;&EC871I;VYS)RP*"2=R<'1?9&]M7W-E8W1I
M;VY?=&]M8V%T)R`]/B`B2F%V82!A<'!L:6-A=&EO;G,B+`H))W)P=%]D;VU?
M<V5C=&EO;E]W96)U<V5R<R<@/3X@(E=E8B!U<V5R<R(L"@DG<G!T7V1O;5]T
M:71L95]W85]S=&%T=7,G(#T^(")3(BP*"2=R<'1?961I=%]?)R`]/B`B161I
M="!R97!O<G0@)3$B+`H))W)P=%]E;G1E<E]E;6%I;%]A9&1R97-S)R`]/B`B
M16YT97(@=&AE(&4M;6%I;"!A9&1R97-S('1H92!R97!O<G0@=VEL;"!B92!D
M96QI=F5R960@=&\N(BP*"2=R<'1?;&ES="<@/3X@(D-U<W1O;2!R97!O<G0@
M;&%Y;W5T<R(L"@DG<G!T7VYA;64G(#T^(")297!O<G0@;F%M92(L"@DG<G!T
M7W)E;6]V95]R97!O<G1S)R`]/B`B5&AE(&9O;&QO=VEN9R!R97!O<G0@;&%Y
M;W5T<R!W:6QL(&)E(')E;6]V960Z(BP*"2=R<'1?<F5P;W)T<R<@/3X@(E)E
M<&]R=',B+`H))W)P=%]S96-T:6]N7V9U;&PG(#T^(")&=6QL(BP*"2=R<'1?
M<V5C=&EO;E]N;VYE)R`]/B`B3F]N92(L"@DG<G!T7W-E8W1I;VY?<W5M;6%R
M>2<@/3X@(E-U;6UA<GDB+`H))W)P=%]S96QE8W1?<F5P;W)T<U]F;W)?<F5M
M;W9E)R`]/B`B4V5L96-T('1H92!R97!O<G0@;&%Y;W5T<R!T;R!B92!R96UO
M=F5D+B(L"@DG<G!T7V1E9F%U;'1?9G5L;"<@/3X@)T9U;&P@4F5P;W)T)RP*
M"2=R<'1?9&5F875L=%]S=6UM87)Y)R`]/B`G4W5M;6%R>2!297!O<G0G+`H*
M"2\O(&5N9"!O9B!K;V]P97(@<&%R=`H*"2\O(&=R97D@<&%R="`H<G-E<W-I
M;VX@<W5P<&]R="D*"2=R<V5S<VEO;E]N;U]A<&E?<G!C7V5R<FUS9R<@/3X@
M(E!L97-K($%022!24$,@:7,@;F]T(&EN<W1A;&QE9"!O;B!T:&4@<F5M;W1E
M(&AO<W0N($-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O<B!F;W(@
M<W5P<&]R="XB+`H))W)S97-S:6]N7VYO7V%C8V]U;G1?97)R;7-G)R`]/B`B
M56YA8FQE('1O(&%C8V5S<R!T:&4@<F5M;W1E('-E<G9I8V4@=6YD97(@>6]U
M<B!A8V-O=6YT+B!4:&4@;6]S="!C;VUM;VX@<F5A<V]N(&ES('1H870@=&AE
M('-E<G9I8V4@9F]R('EO=7(@86-C;W5N="!I<R!N;W0@86-T:79A=&5D('EE
M="X@4&QE87-E+"!W86ET(&9O<B!S979E<F%L(&UI;G5T97,L(&%N9"!T:&5N
M('1R>2!A9V%I;BX@268@>6]U(&5N8V]U;G1E<B!T:&ES(&5R<F]R(&%G86EN
M+"!C;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(BP*"2=R<V5S
M<VEO;E]N;U]D;VUA:6Y?97)R;7-G)R`]/B`B56YA8FQE('1O(&%C8V5S<R!T
M:&4@<F5M;W1E('-E<G9I8V4@9F]R('1H:7,@9&]M86EN+B!4:&4@;6]S="!C
M;VUM;VX@<F5A<V]N(&ES('1H870@=&AE('-E<G9I8V4@9F]R('1H:7,@9&]M
M86EN(&ES(&YO="!A8W1I=F%T960@>65T+B!0;&5A<V4L('=A:70@9F]R('-E
M=F5R86P@;6EN=71E<RP@86YD('1H96X@=')Y(&%G86EN+B!)9B!Y;W4@96YC
M;W5N=&5R('1H:7,@97)R;W(@86=A:6XL(&-O;G1A8W0@>6]U<B!S>7-T96T@
M861M:6YI<W1R871O<BXB+`H))W)S97-S:6]N7W5N:VYO=VY?97)R;7-G)R`]
M/B`B5&AE(')E;6]T92!S97)V97(@:&%S(')E:F5C=&5D('1H92!A='1E;7!T
M('1O(&5S=&%B;&ES:"!A('-E<W-I;VXN($-O;G1A8W0@>6]U<B!S>7-T96T@
M861M:6YI<W1R871O<B!F;W(@<W5P<&]R="X@5&AE(&5R<F]R('=A<SH@)3$B
M+`H))W)S97-S:6]N7W5N:VYO=VXR7V5R<FUS9R<@/3X@(E5N:VYO=VX@97)R
M;W(@=VAI;&4@97-T86)L:7-H:6YG(&$@<F5M;W1E('-E<W-I;VXN($UO<W0@
M<')O8F%B;'D@=&AE(')E;6]T92!S97)V97(@9&]E<R!N;W0@<F5S<&]N9"!P
M<F]P97)L>2!O<B!D;V5S(&YO="!A;G-W97(@870@86QL+B!!<VL@>6]U<B!S
M>7-T96T@861M:6YI<W1R871O<B!T;R!C:&5C:R!F;W(@97)R;W(@9&5T86EL
M<R!I;B!T:&4@07!A8VAE(&5R<F]R(&QO9RXB+`H))W)S97-S:6]N7VYO7V-O
M;FYE8W1?97)R;7-G)R`]/B`B56YA8FQE('1O(&%C8V5S<R!T:&4@<F5M;W1E
M('-E<G9I8V4Z(&-O;FYE8W1I;F<@=&\@<F5M;W1E('-E<W-I;VX@9F%I;&5D
M+B!#;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(@9F]R('-U<'!O
M<G0N(BP*"2\O(&5N9"!O9B!G<F5Y('!A<G0*"@DO+R!P:70@<&%R=`H*"2=R
M<'1?<V5N9%]R97!O<G1?8GE?96UA:6Q?97)R;W)?7R<@/3X@(D5R<F]R('-E
M;F1I;F<@=&AE(')E<&]R=#H@)3$B+`H))W)P=%]S96YD7W)E<&]R=%]B>5]E
M;6%I;%]O:U]?)R`]/B`B5&AE(')E<&]R="!H87,@8F5E;B!S96YT('1O("4Q
M+B(L"@DG<V%?86-T:6]N7V1E;"<@/3X@(D1E;&5T92(L"@DG<V%?86-T:6]N
M7V1E<V,G(#T^(")7:&%T('1O(&1O('=I=&@@<W!A;2!M86EL(BP*"2=S85]A
M8W1I;VY?<V%V92<@/3X@(DUA<FL@87,@<W!A;2!A;F0@<W1O<F4@:6X@;6%I
M;&)O>"(L"@DG<V%?861M:6Y?8FQA8VML:7-T)R`]/B`B061M:6YI<W1R871O
M<B=S(&)L86-K(&QI<W0B+`H))W-A7V%D;6EN7W=H:71E;&ES="<@/3X@(D%D
M;6EN:7-T<F%T;W(G<R!W:&ET92!L:7-T(BP*"2=S85]B;&%C:VQI<W0G(#T^
M(")";&%C:R!L:7-T(BP*"2=S85]B;&%C:VQI<W1?9&5S8R<@/3X@(D%L=V%Y
M<R!M87)K(&%S('-P86T@;6%I;"!F<F]M(&%D9')E<W,B+`H))W-A7V)Y7W1A
M9R<@/3X@(F)Y('1A9R(L"@DG<V%?8V9G7W5S95]P;VQI8WDG(#T^(")5<V%G
M92!P;VQI8WD@<V5T=&EN9W,B+`H))W-A7V-O;F9?;&ES=%]B;&%C:R<@/3X@
M(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-E;&5C=&5D
M('!A='1E<FYS(&9R;VT@=&AE(&)L86-K(&QI<W0_(BP*"2=S85]C;VYF7VQI
M<W1?:6=N;W)E)R`]/B`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V
M92!T:&4@<V5L96-T960@<&%T=&5R;G,@9G)O;2!T:&4@:6=N;W)E(&QI<W0_
M(BP*"2=S85]C;VYF7VQI<W1?=VAI=&4G(#T^(")!<F4@>6]U('-U<F4@>6]U
M('=A;G0@=&\@<F5M;W9E('1H92!S96QE8W1E9"!P871T97)N<R!F<F]M('1H
M92!W:&ET92!L:7-T/R(L"@DG<V%?9&)?9&5L7V-O;F9I<FTG(#T^(")!<F4@
M>6]U('-U<F4@>6]U('=A;G0@=&\@8VQE87(@=&AE(%-P86U!<W-A<W-I;B=S
M(&1A=&%B87-E/R(L"@DG<V%?96UL7VEN7VEG;F]R96QI<W0G(#T^(")%+6UA
M:6P@:7,@:6X@=&AE(&EG;F]R92!L:7-T(BP*"2=S85]E;6Q?<&%T=&5R;B<@
M/3X@(D4M;6%I;"!P871T97)N(BP*"2=S85]E;7!T>5]E;6%I;"<@/3X@(D-A
M;FYO="!A9&0@96UP='D@92UM86EL('!A='1E<FXN(BP*"2=S85]E>&ES='-?
M96UA:6PG(#T^(")3=6-H(&4M;6%I;"!P871T97)N(&%L<F5A9'D@97AI<W1S
M+B(L"@DG<V%?9&ES86)L961?7VUA:6QN86UE7VYO=%]F:6QT97)I;F<G(#T^
M(")4:&4@8W5R<F5N="!S97)V97(@<V5T=&EN9W,@9&\@;F]T(&%L;&]W('1O
M('5S92!M86EL(&9I;'1E<FEN9R!F;W(@=&AI<R!M86EL(&YA;64B+`H))W-A
M7V1I<V%B;&5D7U]F:6QT97)I;F=?:7-?9&ES86)L960G(#T^("=3<&%M(&9I
M;'1E<FEN9R!W87,@9&ES86)L960@8GD@=&AE('-E<G9E<B!A9&UI;FES=')A
M=&]R)RP*"2=S85]E;F%B;&5?9FEL=&5R)R`]/B`B16YA8FQE('-P86T@9FEL
M=&5R:6YG(BP*"2=S85]H:71S7W)E<2<@/3X@(DAI=',@<F5Q=6ER960@9F]R
M('-P86TB+`H))W-A7VAI='-?;F]T7VYU;6)E<B<@/3X@)U1H92!N=6UB97(@
M>6]U('-P96-I9FEE9"!I<R!I;G9A;&ED+B!9;W4@<VAO=6QD('5S92!A('!O
M<VET:79E(&EN=&5G97(N)RP*"2=S85]I9VYO<F5L:7-T)R`]/B`B4V5R=F5R
M+7=I9&4@:6=N;W)E(&QI<W0B+`H))W-A7VEG;F]R96QI<W1?9&5S8R<@/3X@
M(D1O(&YO="!F:6QT97(@;6%I;"!F;W(@=&AE<V4@86-C;W5N=',B+`H))W-A
M7VUO9&EF>5]S=6)J)R`]/B`B36]D:69Y('-P86T@;6%I;"!S=6)J96-T(BP*
M"2=S85]P871T97)N7VEN7V)L86-K;&ES="<@/3X@(E!A='1E<FX@86QR96%D
M>2!E>&ES=',@:6X@8FQA8VL@;&ES="(L"@DG<V%?<&%T=&5R;E]I;E]I9VYO
M<F5L:7-T)R`]/B`B4&%T=&5R;B!A;')E861Y(&5X:7-T<R!I;B!I9VYO<F4@
M;&ES="(L"@DG<V%?<&%T=&5R;E]I;E]W:&ET96QI<W0G(#T^(")0871T97)N
M(&%L<F5A9'D@97AI<W1S(&EN('=H:71E(&QI<W0B+`H))W-A7W!A='1E<FY?
M:7-?:6YV86QI9"<@/3X@(E!A='1E<FX@:7,@:6YV86QI9"XB+`H))V)T7W-A
M7V-L96%R7V1B)R`]/B`G0VQE87(@4W!A;2!&:6QT97(@1&%T86)A<V4G+`H)
M)V)T7W-A7V9O<F=E="<@/3X@)T9O<F=E="!)="<L"@DG8G1?<V%?;&5A<FY?
M87-?<W!A;2<@/3X@(DET)W,@4W!A;2$B+`H))V)T7W-A7VQE87)N7V%S7VYO
M;G-P86TG(#T^("))="=S($YO="!3<&%M(BP*"2=S85]T<F%I;F5R7U]P86=E
M7W1I=&QE)R`]/B`G4W!A;2!F:6QT97(@=')A:6YI;F<G+`H))W-A7W1R86EN
M97)?7W1O;VQS7VQE9V5N9"<@/3X@)U1O;VQS)RP*"2=S85]T<F%I;F5R7U]I
M;F9O7VQE9V5N9"<@/3X@)TEN9F\G+`H))W-A7W1R86EN97)?7VUE<W-A9V5S
M7VQI<W1?;&5G96YD)R`]/B`G365S<V%G97,@:6X@>6]U<B!M86EL8F]X)RP*
M"2=S85]T<F%I;F5R7U]C)R`]/B`G5"<L"@DG<V%?=')A:6YE<E]?;"<@/3X@
M)TPG+`H))W-A7W1R86EN97)?7W-U8FIE8W0G(#T^("=3=6)J96-T)RP*"2=S
M85]T<F%I;F5R7U]F<F]M)R`]/B`G1G)O;2<L"@DG<V%?=')A:6YE<E]?9&%T
M92<@/3X@)T1A=&4G+`H))W-A7W1R86EN97)?7VEN9F]?=&5X="<@/3X@)TUE
M<W-A9V5S(&QE87)N960Z("4Q(&%S('-P86TL("4R(&%S(&YO;BUS<&%M+"`E
M,R!T;W1A;"XG+`H))W-A7W1R86EN97)?7VUE<W-A9V5S)R`]/B`G;65S<V%G
M92AS*2<L"@DG<V%?=')A:6YE<E]?<V5L96-T7U]A;&PG(#T^("=!;&PG+`H)
M)W-A7W1R86EN97)?7W-E;&5C=%]?<W!A;5]O;FQY)R`]/B`G4W!A;2<L"@DG
M<V%?=')A:6YE<E]?<V5L96-T7U]H86U?;VYL>2<@/3X@)TYO;BU3<&%M)RP*
M"2=S85]T<F%I;F5R7U]S96QE8W1?7W5N:VYO=VY?;VYL>2<@/3X@)U5N:VYO
M=VXG+`H))W-A7W1R86EN97)?7V-A;FYO=%]R96UO=F5?;65S<V%G97,G(#T^
M("=#86YN;W0@<F5M;W9E('1H92!S96QE8W1E9"!M97-S86=E<R!F<F]M('1H
M92!M86EL8F]X+B<L"@DG<V%?=')A:6YE<E]?<F5M;W9E7VUE<W-A9V5S7V-O
M;F9I<FTG(#T^("=!<F4@>6]U('-U<F4@=&AA="!Y;W4@=VES:"!T;R!R96UO
M=F4@=&AE('-E;&5C=&5D(&UE<W-A9V5S(&9R;VT@=&AE(&UA:6QB;W@_)RP*
M"2=S85]S96QE8W1?96UA:6PG(#T^(")396QE8W0@870@;&5A<W0@;VYE(&4M
M;6%I;"!P871T97)N(&9R;VT@=&AE(&QI<W0@=&\@<F5M;W9E(&ET+B(L"@DG
M<V%?<W)V7V)L86-K;&ES="<@/3X@(E-E<G9E<BUW:61E(&)L86-K(&QI<W0B
M+`H))W-A7W-R=E]C9F<G(#T^(")397)V97(@=VED92!S971T:6YG<R(L"@DG
M<V%?<W)V7W-E='1I;F=S)R`]/B`B4V5R=F5R('-E='1I;F=S(BP*"2=S85]S
M<G9?=VAI=&5L:7-T)R`]/B`B4V5R=F5R+7=I9&4@=VAI=&4@;&ES="(L"@DG
M<V%?=7-E7W-R=E]S971T:6YG<R<@/3X@(E5S92!S97)V97(@=VED92!S971T
M:6YG<R(L"@DG<V%?=7-E<E]B;&%C:VQI<W0G(#T^(")5<V5R)W,@8FQA8VL@
M;&ES="(L"@DG<V%?=7-E<E]W:&ET96QI<W0G(#T^(")5<V5R)W,@=VAI=&4@
M;&ES="(L"@DG<V%?=7-R7V1I<V%B;&5D7V)Y7W-R=B<@/3X@(D%D;6EN:7-T
M<F%T;W(@:&%S(&1I<V%B;&5D('5S97(M8V]N9FEG=7)E9"!S<&%M(&9I;'1E
M<FEN9R(L"@DG<V%?=7-R7VYO7W!O<W1B;W@G(#T^(")5<V5R(&AA<R!N;R!M
M86EL8F]X(&5N86)L960B+`H))W-A7W5S<E]S971T:6YG<R<@/3X@(E!E<G-O
M;F%L('-E='1I;F=S(BP*"2=S85]W:&ET96QI<W0G(#T^(")7:&ET92!L:7-T
M(BP*"2=S85]W:&ET96QI<W1?9&5S8R<@/3X@(DYE=F5R(&UA<FL@87,@<W!A
M;2!M86EL(&9R;VT@861D<F5S<R(L"@DG<V5R=F5R7U]A9&UI;E]I;F9O)R`]
M/B`B061M:6YI<W1R871O<B!I;F9O<FUA=&EO;B(L"@DG<V5R=F5R7U]C=')L
M7W!A;F5L)R`]/B`B0V]N=')O;"!086YE;"(L"@DG<V5R=F5R7U]E;G1E<E]B
M=6=?97-S96YC95]B96QO=R<@/3X@(D5N=&5R('1H92!B=6<@9&5S8W)I<'1I
M;VX@8F5L;W<B+`H))W-E<G9E<E]?<&]W97)?;6%N86=E;65N="<@/3X@(E!O
M=V5R(&UA;F%G96UE;G0B+`H))W-E<G9E<E]?<V5R=FEC97,G(#T^(")397)V
M:6-E<R(L"@DG<V5R=F5R7U]S>7-T96TG(#T^(")3>7-T96TB+`H))W-E<G9E
M<E]?=&ET;&4G(#T^(")397)V97(@061M:6YI<W1R871I;VXB+`H))W-E<G9E
M<E]?=V%R;FEN9U]R96)O;W0G(#T^(")787)N:6YG(2!4:&4@<WES=&5M('=I
M;&P@;F]W(&)E(')E8F]O=&5D+B!0<F]C965D/R(L"@DG<V5R=F5R7U]W87)N
M:6YG7W-H=71D;W=N)R`]/B`B5T%23DE.1SH@5&AI<R!O<&5R871I;VX@=VEL
M;"!S:'5T('1H92!S97)V97(@9&]W;BX@(%1H92!S97)V97(@8V%N;F]T7&YB
M92!R97-T87)T960@<F5M;W1E;'D@8GD@;65A;G,@;V8@=&AI<R!S;V9T=V%R
M92X@07)E('EO=2!S=7)E('EO=2!W86YT('1O('!R;V-E960_(BP*"2=S97)V
M97)?7W=I;&Q?<F5B;V]T)R`]/B`B5&AE('-Y<W1E;2!W:6QL(&YO=R!B92!R
M96)O;W1E9"XB+`H))W-E<G9E<E]?=VEL;%]S:'5T9&]W;B<@/3X@(E1H92!S
M>7-T96T@:7,@<VAU='1I;F<@9&]W;BXB+`H))W-E<G9E<E]P<F5F97)E;F-E
M<U]?861M:6Y?;&%N9W5A9V4G(#T^(")!9&UI;FES=')A=&]R)W,@:6YT97)F
M86-E(&QA;F=U86=E(BP*"2=S97)V97)?<')E9F5R96YC97-?7V%D;6EN7W-K
M:6XG(#T^(")!9&UI;FES=')A=&]R)W,@:6YT97)F86-E('-K:6XB+`H))W-E
M<G9E<E]P<F5F97)E;F-E<U]?86QL;W=?861M:6Y?;75L=&EP;'E?;&]G:6XG
M(#T^(")!;&QO=R!M=6QT:7!L92!S97-S:6]N<R!U;F1E<B!A9&UI;FES=')A
M=&]R)W,@;&]G:6XB+`H))W-E<G9E<E]P<F5F97)E;F-E<U]?8V]U;G1?9&ES
M:U]S<&%C92<@/3X@(DEN8VQU9&4@:6X@=&AE(&1I<VL@<W!A8V4@=7-A9V4@
M8V%L8W5L871I;VXB+`H))W-E<G9E<E]P<F5F97)E;F-E<U]?8V]U;G1?=')A
M9F9I8R<@/3X@(DEN8VQU9&4@:6X@=&AE('1R869F:6,@8V%L8W5L871I;VXB
M+`H))W-E<G9E<E]P<F5F97)E;F-E<U]?8V]U;G1?='EP92<@/3X@)U=H96X@
M8V%L8W5L871I;F<@9&ES:R!S<&%C92!U<V%G92P@8V]U;G0G+`H))W-E<G9E
M<E]P<F5F97)E;F-E<U]?8V]U;G1?='EP95]?8GET92<@/3X@)V9I;&4@<VEZ
M92<L"@DG<V5R=F5R7W!R969E<F5N8V5S7U]C;W5N=%]T>7!E7U]B;&]C:R<@
M/3X@)V%M;W5N="!O9B!D:7-K('-P86-E('5S960G+`H))W-E<G9E<E]P<F5F
M97)E;F-E<U]?9&5F875L=%]L86YG=6%G92<@/3X@(D1E9F%U;'0@;&]C86QE
M(BP*"2=S97)V97)?<')E9F5R96YC97-?7V1E9F%U;'1?<VMI;B<@/3X@(D1E
M9F%U;'0@<VMI;B(L"@DG<V5R=F5R7W!R969E<F5N8V5S7U]D:7-P;&%Y)R`]
M/B`B1&ES<&QA>2(L"@DG<V5R=F5R7W!R969E<F5N8V5S7U]I;F-L=61E7V1A
M=&%B87-E<R<@/3X@(F1A=&%B87-E<R(L"@DG<V5R=F5R7W!R969E<F5N8V5S
M7U]I;F-L=61E7V1O;6%I;F1U;7!S)R`]/B`B9&]M86EN(&)A8VMU<"!F:6QE
M<R(L"@DG<V5R=F5R7W!R969E<F5N8V5S7U]I;F-L=61E7VEN8V]M:6YG)R`]
M/B`B;VYL>2!I;F)O=6YD('1R869F:6,B+`H))W-E<G9E<E]P<F5F97)E;F-E
M<U]?:6YC;'5D95]I;F-O;6EN9U]A;F1?;W5T9V]I;F<G(#T^(")I;F)O=6YD
M(&%N9"!O=71B;W5N9"!T<F%F9FEC(BP*"2=S97)V97)?<')E9F5R96YC97-?
M7VEN8VQU9&5?;&]G<R<@/3X@(FQO9R!F:6QE<R(L"@DG<V5R=F5R7W!R969E
M<F5N8V5S7U]I;F-L=61E7VUA:6QB;WAE<R<@/3X@(FUA:6QB;WAE<R(L"@DG
M<V5R=F5R7W!R969E<F5N8V5S7U]I;F-L=61E7VUA:6QL:7-T<R<@/3X@(FUA
M:6QI;F<@;&ES=',B+`H))W-E<G9E<E]P<F5F97)E;F-E<U]?:6YC;'5D95]O
M=71G;VEN9R<@/3X@(F]N;'D@;W5T8F]U;F0@=')A9F9I8R(L"@DG<V5R=F5R
M7W!R969E<F5N8V5S7U]I;F-L=61E7W=E8F%P<',G(#T^(")*879A(&%P<&QI
M8V%T:6]N<R(L"@DG<V5R=F5R7W!R969E<F5N8V5S7U]K965P7W-T871S)R`]
M/B`B4F5T86EN('1R869F:6,@<W1A=&ES=&EC<R!F;W(B+`H))W-E<G9E<E]P
M<F5F97)E;F-E<U]?;6%X7V)U='1O;E]L96YG=&@G(#T^(")"=71T;VX@;&%B
M96P@;&5N9W1H(BP*"2=S97)V97)?<')E9F5R96YC97-?7W)E<W1A<G1?87!A
M8VAE7VEN=&5R=F%L)R`]/B`B07!A8VAE(')E<W1A<G0@:6YT97)V86PB+`H)
M)W-E<G9E<E]P<F5F97)E;F-E<U]?<W1A=%]W87)N:6YG)R`]/B`B5&AE(&-H
M86YG97,@;6%D92!T;R!T:&4@9&ES:R!S<&%C92!U<V%G92!C86QC=6QA=&EO
M;B!S8VAE;64@=VEL;"!T86ME(&5F9F5C="!O;FQY(&1U<FEN9R!N97AT('-T
M871I<W1I8W,@8V%L8W5L871I;VXN(BP*"2=S97)V97)?<')E9F5R96YC97-?
M7W1I=&QE)R`]/B`B4V5R=F5R('!R969E<F5N8V5S(BP*"2=S97)V97)?;6%I
M;%]?=&ET;&4G(#T^(")397)V97(M=VED92!M86EL('!R969E<F5N8V5S(BP*
M"2=M86EL7U]T86)S7W!R969E<F5N8V5S)R`]/B`B4')E9F5R96YC97,B+`H)
M)VUA:6Q?7W1A8G-?=VAI=&5?;&ES="<@/3X@(E=H:71E($QI<W0B+`H))VUA
M:6Q?7W1A8G-?8FQO8VME9%]D;VUA:6YS)R`]/B`B0FQA8VL@3&ES="(L"@DG
M;6%I;%]?=&%B<U]M86EL7W%U975E)R`]/B`B36%I;"!1=65U92(L"@DG<V5R
M=F5R7W!R969E<F5N8V5S7U]U<V5?=F]C86)U;&%R>2<@/3X@(D-H96-K('1H
M92!P87-S=V]R9',@9F]R(&UA:6QB;WAE<R!I;B!T:&4@9&EC=&EO;F%R>2(L
M"@DG<V5R=F5R<U]L:7-T7U]A8V-O=6YT7V1I<V%B;&5D)R`]/B`B26YF;W)M
M871I;VX@<75E<GD@:7,@9&ES86)L960@9F]R('1H:7,@<V5R=F5R+B(L"@DG
M<V5R=F5R<U]L:7-T7U]P;&5A<V5?=V%I="<@/3X@(E%U97)Y:6YG('-L879E
M('-E<G9E<G,N("4Q(%1H:7,@;W!E<F%T:6]N(&UI9VAT('1A:V4@<V]M92!T
M:6UE+B`E,B!0;&5A<V4@=V%I="XN+B(L"@DG<V5R=F5R<U]L:7-T7U]R96UO
M=F5?<&%G95]T:71L92<@/3X@(E1H92!F;VQL;W=I;F<@<VQA=F4@<V5R=F5R
M(&%C8V]U;G1S('=I;&P@8F4@<F5M;W9E9#HB+`H))W-E<G9E<G-?;&ES=%]?
M<V5L96-T7W-L879E7W-E<G9E<G-?=&]?<F5M;W9E)R`]/B`B4V5L96-T('1H
M92!S;&%V92!S97)V97)S('1O(&)E(')E;6]V960N(BP*"2=S97)V97)S7VQI
M<W1?7W1O=&%L7V9I;&5S)R`]/B`B4VQA=F4@<V5R=F5R<R(L"@DG<V5R=F5R
M<U]L:7-T7U]U;F%B;&5?=&]?9V5T7W-L879E<U]N=6UB97(G(#T^(")5;F%B
M;&4@=&\@9&5T97)M:6YE('1H92!N=6UB97(@;V8@<VQA=F4@<V5R=F5R<R(L
M"@DG<V5R=F5R<U]L:7-T7U]U;F%B;&5?=&]?<F5M;W9E)R`]/B`B56YA8FQE
M('1O(')E;6]V92!T:&4@<VQA=F4@<V5R=F5R(&%C8V]U;G0Z("4Q(BP*"2=S
M97)V97)S7VQI<W1?7WEO=5]H879E7W1O;U]M86YY7W-L879E<R<@/3X@(EEO
M=2!H879E(&UO<F4@<VQA=F4@<V5R=F5R<R!A8V-O=6YT<R!S970@=7`@=&AA
M;B!I="!I<R!A;&QO=V5D(&)Y('EO=7(@;&EC96YS92!K97DN(BP*"2=S97)V
M97)T<F%F9FEC;&ES=%]H96%D97(G(#T^(")397)V97(@=')A9F9I8R(L"@DG
M<V5S<VEO;E]?:6YV86QI9%]I9&QE7W1I;64G(#T^(")397-S:6]N(&ED;&4@
M=&EM92!I<R!I;G9A;&ED+B(L"@DG<V5S<VEO;E]?:6YV86QI9%]L;V=I;E]A
M='1E;7!T<R<@/3X@(DEN=F%L:60@;&]G:6X@871T96UP=',@=F%L=64@<VAO
M=6QD(&)E(&$@<&]S:71I=F4@:6YT96=E<BXB+`H))W-E<W-I;VY?7VEN=F%L
M:61?;&]G:6Y?:6YT97)V86PG(#T^("));G9A;&ED(&QO9VEN(&EN=&5R=F%L
M('9A;'5E('-H;W5L9"!B92!A('!O<VET:79E(&EN=&5G97(N(BP*"2=S97-S
M:6]N7U]I;G9A;&ED7VQO9VEN7VQO8VM?=&EM92<@/3X@(DEN=F%L:60@;&]G
M:6X@;&]C:R!T:6UE('9A;'5E('-H;W5L9"!B92!A('!O<VET:79E(&EN=&5G
M97(N(BP*"2=S97-S:6]N<U]?86=R965M96YT)R`]/B`B665S+"!)('=I<V@@
M=&\@96YD('1H97-E('-E<W-I;VYS+B(L"@DG<V5S<VEO;G-?7VEN=E]L;V=I
M;E]A='1E;7!T<R<@/3X@(DEN=F%L:60@;&]G:6X@871T96UP=',B+`H))W-E
M<W-I;VYS7U]I;G9?;&]G:6Y?:6YT97)V86PG(#T^("));G9A;&ED(&QO9VEN
M(&EN=&5R=F%L(BP*"2=S97-S:6]N<U]?:6YV7VQO9VEN7VQO8VM?=&EM92<@
M/3X@(DEN=F%L:60@;&]G:6X@;&]C:R!T:6UE(BP*"2=S97-S:6]N<U]?;6EN
M)R`]/B`B36EN=71E<R(L"@DG<V5S<VEO;G-?7W)E<75I<F5D7V9I96QD<R<@
M/3X@(E)E<75I<F5D(&9I96QD<RXB+`H))W-E<W-I;VYS7U]S96QE8W1?<V5S
M<VEO;G-?9F]R7W)E;6]V92<@/3X@(E-E;&5C="!T:&4@<V5S<VEO;G,@=&\@
M8F4@96YD960N(BP*"2=S97-S:6]N<U]?<V5S<VEO;E]I9&QE7W1I;64G(#T^
M(")397-S:6]N(&ED;&4@=&EM92(L"@DG<V5S<VEO;G-?7W-E<W-I;VY?<V5T
M=7`G(#T^("),;V=I;B!3971T:6YG<R(L"@DG<V5S<VEO;G-?7W-E<W-I;VYS
M7VUA;F%G96UE;G0G(#T^(")397-S:6]N<R!-86YA9V5M96YT(BP*"2=S97-S
M:6]N<U]?=6YA8FQE7W-E='5P7VEN=F%L:61?;&]G:6Y?871T96UP=',G(#T^
M(")5;F%B;&4@=&\@<V5T('5P('1H92!N=6UB97(@;V8@:6YV86QI9"!L;V=I
M;B!A='1E;7!T<SH@)3$B+`H))W-E<W-I;VYS7U]U;F%B;&5?<V5T=7!?:6YV
M86QI9%]L;V=I;E]I;G1E<G9A;"<@/3X@(E5N86)L92!T;R!S970@=7`@:6YV
M86QI9"!L;V=I;B!I;G1E<G9A;#H@)3$B+`H))W-E<W-I;VYS7U]U;F%B;&5?
M<V5T=7!?:6YV86QI9%]L;V=I;E]L;V-K7W1I;64G(#T^(")5;F%B;&4@=&\@
M<V5T('5P(&EN=F%L:60@;&]G:6X@;&]C:R!T:6UE.B`E,2(L"@DG<V5S<VEO
M;G-?7W5N86)L95]S971U<%]S97-S:6]N7VED;&4G(#T^(")5;F%B;&4@=&\@
M<V5T('5P('-E<W-I;VX@:61L92!T:6UE.B`E,2(L"@DG<V5S<VEO;G-?7W1A
M8G-?8W!?<V5S<VEO;G,G(#T^("=#4"!397-S:6]N<R<L"@DG<V5S<VEO;G-?
M7W1A8G-?9G1P7W-E<W-I;VYS)R`]/B`G1E10(%-E<W-I;VYS)RP*"2=S97-S
M:6]N<U]?9G1P7W-E<W-I;VYS7VQO9VEN)R`]/B`G1E10('5S97(@;&]G:6XG
M+`H))W-E<W-I;VYS7U]F='!?<V5S<VEO;G-?9&]M86EN)R`]/B`G1&]M86EN
M(&YA;64G+`H))W-E<W-I;VYS7U]F='!?<V5S<VEO;G-?<&%T:"<@/3X@)T-U
M<G)E;G0@;&]C871I;VXG+`H))W-E<W-I;VYS7U]F='!?<V5S<VEO;G-?9FEL
M92<@/3X@)T9I;&4@;F%M92<L"@DG<V5S<VEO;G-?7V9T<%]S97-S:6]N<U]A
M8W1I;VXG(#T^("=3=&%T=7,G+`H))W-E<W-I;VYS7U]F='!?<V5S<VEO;G-?
M<W!E960G(#T^("=3<&5E9"P@2T(O4R<L"@DG<V5S<VEO;G-?7V9T<%]S97-S
M:6]N<U]C;VUP)R`]/B`G4')O9W)E<W,L("4G+`H*"@DG<VET95]A<'!S7U]A
M8V-E<W-?;&5V96PG(#T^("=!8V-E<W,@;&5V96PG+`H))W-I=&5?87!P<U]?
M86-C97-S7VQE=F5L7V-O;6UE<F-I86PG(#T^("=#;VUM97)C:6%L)RP*"2=S
M:71E7V%P<'-?7V%C8V5S<U]L979E;%]F<F5E)R`]/B`G1G)E92<L"@DG<VET
M95]A<'!S7U]A8W1I;VY?:6YS=&%L;&5R)R`]/B`B4VET92!A<'!L:6-A=&EO
M;B!I;G-T86QL871I;VXB+`H))W-I=&5?87!P<U]?86-T:6]N7W)E8V]N9FEG
M=7)E)R`]/B`B4VET92!A<'!L:6-A=&EO;B!R96-O;F9I9W5R:6YG(BP*"2=S
M:71E7V%P<'-?7V5X=')A7V9I;&5S7W1I=&QE)R`]/B`G5VAA="!T;R!D;R!W
M:71H('1H92!F:6QE<S\G+`H))W-I=&5?87!P<U]?97AT<F%?9FEL97-?=V%R
M;FEN9R<@/3X@)U1H92!C;VYT96YT<R!O9B!T:&4@9&ER96-T;W)Y("4Q('=I
M;&P@8F4@<F5W<FET=&5N('1O(&5N<W5R92!T:&4@8VQE86X@:6YS=&%L;&%T
M:6]N(&%N9"!P<F]P97(@=V]R:R!O9B!T:&4@87!P;&EC871I;VXN(%-O+"!I
M9B!Y;W4@:&%V92!A;GD@=F%L=6%B;&4@9&%T82!S=&]R960@=VET:&EN('1H
M92!D;VUA:6XL('EO=2!S:&]U;&0@8F%C:R!T:&5M('5P(&]R(&UO=F4@=&\@
M86YO=&AE<B!L;V-A=&EO;B!B969O<F4@>6]U('!R;V-E960@=VET:"!T:&4@
M:6YS=&%L;&%T:6]N+B!9;W4@8V%N(&)R;W=S92!T:&4@9&]M86EN(&-O;G1E
M;G0@=VET:"`E,BXG+`H))W-I=&5?87!P<U]?97AT<F%?9FEL97-?=V%R;FEN
M9U]B<F]W<V4G(#T^("=B<F]W<V4@=&AE(&1O;6%I;B!C;VYT96YT('=I=&@@
M1FEL92!-86YA9V5R)RP*"2=S:71E7V%P<'-?7V5X=')A7V9I;&5S7VQE9V5N
M9"<@/3X@)U=H870@=&\@9&\@=VET:"!T:&4@9FEL97,_)RP*"2=S:71E7V%P
M<'-?7V5X=')A7V9I;&5S7V1E;&5T92<@/3X@)U)E;6]V92!A;&P@9FEL97,@
M:6X@=&AE(&1O8W5M96YT(')O;W0@9&ER96-T;W)Y+B<L"@DG<VET95]A<'!S
M7U]E>'1R85]F:6QE<U]K965P)R`]/B`G2V5E<"!E>&ES=&EN9R!F:6QE<RP@
M=VAE;B!P;W-S:6)L92X@3F]T92!T:&%T(&%P<&QI8V%T:6]N(&9I;&5S('=I
M;&P@;W9E<G=R:71E('1H92!E>&ES=&EN9R!F:6QE<R!A;GEW87DL(&%N9"!T
M:&4@97AT<F$@9FEL97,@;6%Y(&-A=7-E(&%P<&QI8V%T:6]N('1O(&)E:&%V
M92!I;F-O<G)E8W1L>2XG+`H))W-I=&5?87!P<U]?;F]?=F%C86YT7W-I=&5?
M87!P<R<@/3X@(EEO=2!H879E(&YO(&-O;6UE<F-I86P@<VET92!A<'!L:6-A
M=&EO;G,@=&\@861D+B(L"@DG<VET95]A<'!S7U]C;%]L:7-T7V9O<E]A<'`G
M(#T^(")#;&EE;G1S('5S:6YG(&-O;6UE<F-I86P@<VET92!A<'!L:6-A=&EO
M;B`E,2(L"@DG<VET95]A<'!S7U]C;%]L:7-T7V9O<E]A<'!?861D)R`]/B`B
M4V5L96-T('1H92!C;&EE;G1S('=H;R!S:&]U;&0@=7-E('1H:7,@87!P;&EC
M871I;VXB+`H))W-I=&5?87!P<U]?8W5S=&]M7V)U='1O;E]L979E;"<@/3X@
M)U=O=6QD('EO=2!L:6ME('1O(&-R96%T92!A(&YE=R!C=7-T;VT@8G5T=&]N
M(&9O<B!A8V-E<W-I;F<@=&AI<R!A<'!L:6-A=&EO;C\G+`H))W-I=&5?87!P
M<U]?8W5S=&]M7V)U='1O;E]L979E;%]F86QS95]D;VUA:6Y?=7-E<E]O;FQY
M)R`]/B`G3F\G+`H))W-I=&5?87!P<U]?8W5S=&]M7V)U='1O;E]L979E;%]D
M;VUA:6Y?=7-E<E]O;FQY)R`]/B`G665S)RP*"2=S:71E7V%P<'-?7V-U<W1O
M;5]B=71T;VY?;&5V96Q?9F%L<V4G(#T^("=.;R<L"@DG<VET95]A<'!S7U]C
M=7-T;VU?8G5T=&]N7VQE=F5L7V1O;6%I;B<@/3X@)UEE<RP@86YD(&UA:V4@
M:70@879A:6QA8FQE(&9O<B!T:&4@8W5R<F5N="!D;VUA:6X@;VYL>2XG+`H)
M)W-I=&5?87!P<U]?8W5S=&]M7V)U='1O;E]L979E;%]C;&EE;G0G(#T^("=9
M97,L(&%N9"!M86ME(&ET(&%V86EL86)L92!F;W(@86QL(&1O;6%I;G,@;V8@
M=&AE(&-L:65N="XG+`H))W-I=&5?87!P<U]?8W5S=&]M7V)U='1O;E]L979E
M;%]A9&UI;B<@/3X@)UEE<RP@86YD(&UA:V4@:70@879A:6QA8FQE(&9O<B!A
M;&P@9&]M86EN<RXG+`H))W-I=&5?87!P<U]?9&5S8W)I<'1I;VXG(#T^(")$
M97-C<FEP=&EO;B(L"@DG<VET95]A<'!S7U]D:7)?=7-E9%]B>5]S87!P7U\G
M(#T^(")4:&4@9&ER96-T;W)Y(%PB)3%<(B!I<R!U<V5D(&)Y(&%N;W1H97(@
M<VET92!A<'!L:6-A=&EO;B(L"@DG<VET95]A<'!S7U]D:7)?=7-E9%]B>5]F
M<%]?)R`]/B`B5&AE(&1I<F5C=&]R>2!<(B4Q7"(@:7,@=7-E9"!B>2!T:&4@
M1G)O;G1086=E(&%P<&QI8V%T:6]N(BP*"2=S:71E7V%P<'-?7V1I<E]U<V5D
M7V)Y7W5N:VYO=VY?7R<@/3X@(E1H92!D:7)E8W1O<GD@7"(E,5PB(&%L<F5A
M9'D@97AI<W1S(BP*"2=S:71E7V%P<'-?7V9I;&5?;F%M92<@/3X@(E-I=&4@
M87!P;&EC871I;VX@<&%C:V%G92!F:6QE;F%M92(L"@DG<VET95]A<'!S7U]I
M;G-T86QL871I;VY?;G5M8F5R)R`]/B`B26YS=&%N8V5S(BP*"2=S:71E7V%P
M<'-?7VEN<W1A;&QE9%]I;E]?)R`]/B`B:6YS=&%L;&5D(&EN("4Q(BP*"2=S
M:71E7V%P<'-?7VEN=F%L:61?:6YS=&%L;%]P<F5F:7@G(#T^("));G9A;&ED
M(&EN<W1A;&QA=&EO;B!P<F5F:7@B+`H))W-I=&5?87!P<U]?:6YV86QI9%]P
M86-K86=E)R`]/B`B4VET92!A<'!L:6-A=&EO;B!P86-K86=E(&ES(&EN=F%L
M:60N(BP*"2=S:71E7V%P<'-?7V5R<F]R7W1E<W1?<&%C:V%G92<@/3X@(E1H
M:7,@<&%C:V%G92!F:6QE(&ES(&EN=F%L:60N7&XE,2(L"@DG<VET95]A<'!S
M7U]E<G)O<E]T97-T7W!A8VMA9V5?=F%U;'0G(#T^(")4:&ES(&9I;&4@:7,@
M;F]T(&$@=F%L:60@<VET92!A<'!L:6-A=&EO;B!P86-K86=E+EQN)3$B+`H)
M)W-I=&5?87!P<U]?97)R;W)?861D7W!A8VMA9V5?7R<@/3X@(E5N86)L92!T
M;R!I;G-T86QL('1H92!S:71E(&%P<&QI8V%T:6]N('!A8VMA9V4N7&XE,2(L
M"@DG<VET95]A<'!S7U]K97E?<W1A='5S)R`]/B`G3&EC96YS:6YG)RP*"2=S
M:71E7V%P<'-?7VME>5]S=&%T=7-?9G)E92<@/3X@)T1I<W1R:6)U=&5D(&9R
M965L>2X@3F\@;&EC96YS92!K97D@<F5Q=6ER960G+`H))W-I=&5?87!P<U]?
M:V5Y7W-T871U<U]O:R<@/3X@)U1H92!R97%U:7)E9"!L:6-E;G-E(&ME>2!I
M<R!I;G-T86QL960G+`H))W-I=&5?87!P<U]?:V5Y7W-T871U<U]P<F]B;&5M
M)R`]/B`G5&AE(')E<75I<F5D(&QI8V5N<V4@:V5Y(&ES(&YO="!I;G-T86QL
M960G+`H))W-I=&5?87!P<U]?;F%M92<@/3X@(DYA;64B+`H))W-I=&5?87!P
M<U]?;F]?9&]M86EN<R<@/3X@)U1H92!S:71E(&%P<&QI8V%T:6]N(&-A;FYO
M="!B92!I;G-T86QL960N(%1H97)E(&ES(&%L<F5A9'D@86YO=&AE<B!S:71E
M(&%P<&QI8V%T:6]N(&EN<W1A;&QE9"!I;B!T:&4@<F]O="!D:7)E8W1O<GD@
M;V8@=&AI<R!D;VUA:6XN($-O;G-I9&5R(&-R96%T:6YG(&$@<W5B9&]M86EN
M(&9O<B!T:&4@<VET92!A<'!L:6-A=&EO;BXG+`H))W-I=&5?87!P<U]?<&%C
M:V%G95]I;F9O7R<@/3X@(E-I=&4@07!P;&EC871I;VX@4&%C:V%G92!);F9O
M<FUA=&EO;B(L"@DG<VET95]A<'!S7U]P86-K86=E7VEN=&5G<F%T960G(#T^
M(")B=6EL="UI;B!P86-K86=E+"!C86YN;W0@8F4@<F5M;W9E9"(L"@DG<VET
M95]A<'!S7U]P;V]L7W1I=&QE)R`]/B`G07!P;&EC871I;VX@<&]O;"!O9B`E
M,2<L"@DG<VET95]A<'!S7U]P;V]L7W)E;6]V95]T:71L92<@/3X@(E1H92!F
M;VQL;W=I;F<@<VET92!A<'!L:6-A=&EO;B!P86-K86=E<R!W:6QL(&)E(')E
M;6]V960@9G)O;2!T:&4@<&]O;#HB+`H))W-I=&5?87!P<U]?<&]O;%]S96QE
M8W1?<&%C:V%G97-?=&]?<F5M;W9E)R`]/B`G4V5L96-T('1H92!S:71E(&%P
M<&QI8V%T:6]N('!A8VMA9V5S('1O(&)E(')E;6]V960N)RP*"2=S:71E7V%P
M<'-?7W!O;VQ?<V5L96-T7W!A8VMA9V5S7W1O7V%D9"<@/3X@)U-E;&5C="!T
M:&4@<VET92!A<'!L:6-A=&EO;B!P86-K86=E<R!T;R!A9&0@=&\@=&AE('!O
M;VPN)RP*"2=S:71E7V%P<'-?7W!O;VQ?861D7W1I=&QE)R`]/B`G061D('-I
M=&4@87!P;&EC871I;VX@<&%C:V%G97,@=&\@=&AE('!O;VPG+`H))W-I=&5?
M87!P<U]?<F5L96%S92<@/3X@(E)E;&5A<V4B+`H))W-I=&5?87!P<U]?<F5Q
M=6ER97-?879A:6)L95]T:71L92<@/3X@(D%V86EL86)L92(L"@DG<VET95]A
M<'!S7U]R97%U:7)E<U]E<G)O<B<@/3X@(E1H92!S:71E(&%P<&QI8V%T:6]N
M(')E<75I<F5S('1H92!R97-O=7)C97,L('=H:6-H(&%R92!N;W0@8W5R<F5N
M=&QY(&%V86EL86)L92(L"@DG<VET95]A<'!S7U]R97%U:7)E<U]E<G)O<E]?
M)R`]/B`B5&AE('-I=&4@87!P;&EC871I;VX@<F5Q=6ER97,@=&AE(')E<V]U
M<F-E<RP@=VAI8V@@87)E(&YO="!C=7)R96YT;'D@879A:6QA8FQE.EQN)3$B
M+`H))W-I=&5?87!P<U]?<F5Q=6ER97-?97)R;W)?9&5S8W)I<'1I;VY?7R<@
M/3X@(B4Q+"`E,BX@<F5Q=6ER960Z("4S+B!A=F%I;&%B;&4Z("4T+B(L"@DG
M<VET95]A<'!S7U]R97%U:7)E<U]E<G)O<E]H;W-T:6YG7U\G(#T^(")4:&4@
M<F5Q=6ER960@<F5S;W5R8V4@:7,@;F]T(&5N86)L960@:6X@9&]M86EN(&AO
M<W1I;F<@9F5A='5R97,N(BP*"2=S:71E7V%P<'-?7W)E<75I<F5S7V5R<F]R
M7VQI;6ET<U]?)R`]/B`B5&AE(')E<75I<F5D(')E<V]U<F-E(&ES(&YO="!A
M=F%I;&%B;&4@9'5E('1O(&1O;6%I;B!L:6UI=',@9&5F:6YE9"XB+`H))W-I
M=&5?87!P<U]?<F5Q=6ER97-?97)R;W)?<WES=&5M7V1I<VM?<W!A8V5?7R<@
M/3X@(DYO="!E;F]U9V@@9G)E92!D:7-K('-P86-E(&]N("4Q+B!0;&5A<V4@
M9G)E92!U<"!S;VUE(&1I<VL@<W!A8V4@86YD('1R>2!I;G-T86QL:6YG('1H
M:7,@87!P;&EC871I;VX@86=A:6XN(BP*"2=S:71E7V%P<'-?7W)E<75I<F5S
M7V5R<F]R7W9E<G-I;VY?7R<@/3X@(E1H92!C;VUP;VYE;G0@=F5R<VEO;B!O
M;B!T:&4@<V5R=F5R(&1O97,@;F]T('-A=&ES9GD@=&AE('-I=&4@87!P;&EC
M871I;VXG<R!R97%U:7)E;65N=',N(BP*"2=S:71E7V%P<'-?7W)E<75I<F5S
M7V5R<F]R7W-U8F1O;6%I;E]?)R`]/B`B5&AE(')E<75I<F5D(')E<V]U<F-E
M(&ES(&YO="!E;F%B;&5D(&EN('-U8F1O;6%I;B!F96%T=7)E<RXB+`H))W-I
M=&5?87!P<U]?<F5Q=6ER97-?97)R;W)?=&ET;&4G(#T^(")$97-C<FEP=&EO
M;B(L"@DG<VET95]A<'!S7U]R97%U:7)E<U]N86UE7W1I=&QE)R`]/B`B4F5Q
M=6ER960B+`H))W-I=&5?87!P<U]?<F5Q=6ER97-?='EP95]T:71L92<@/3X@
M(E1Y<&4B+`H))W-I=&5?87!P<U]?<F5Q=6ER97-?=F%L=65?=&ET;&4G(#T^
M(")686QU92(L"@DG<VET95]A<'!S7U]R97-O=7)C95]U<V5D7V)Y7W-A<'`G
M(#T^(")4:&ES(')E<V]U<F-E(&ES('5S960@8GD@86X@:6YS=&%L;&5D('-I
M=&4@87!P;&EC871I;VXB+`H))W-I=&5?87!P<U]?<F]O=%]U<V5D7V)Y7W-A
M<'`G(#T^(")4:&ES(')E<V]U<F-E(&ES('5S960@8GD@86X@:6YS=&%L;&5D
M('-I=&4@87!P;&EC871I;VXB+`H))W-I=&5?87!P<U]?<V5L96-T7V%P<%]P
M:V=?=&]?:6YS=&%L;"<@/3X@(E-E;&5C="!T:&4@<VET92!A<'!L:6-A=&EO
M;B!P86-K86=E('1O(&EN<W1A;&PB+`H))W-I=&5?87!P<U]?<V5L96-T7V%P
M<%]P:V=S7W1O7W5N:6YS=&%L;"<@/3X@(E-E;&5C="!T:&4@<VET92!A<'!L
M:6-A=&EO;B!P86-K86=E<R!T;R!U;FEN<W1A;&PB+`H))W-I=&5?87!P<U]?
M<V5L96-T7V%P<%]T;U]A<'!L:6-A=&EO;B<@/3X@(E-E;&5C="!T:&4@<VET
M92!A<'!L:6-A=&EO;B!T;R!O<&5N(BP*"2=S:71E7V%P<'-?7W-E;&5C=%]A
M<'!?=&]?<F5C;VYF:6=U<F4G(#T^(")396QE8W0@=&AE('-I=&4@87!P;&EC
M871I;VX@=&\@<F5C;VYF:6=U<F4B+`H))W-I=&5?87!P<U]?<V5L96-T7V%P
M<'-?=&]?=6YI;G-T86QL)R`]/B`B4V5L96-T('1H92!S:71E(&%P<&QI8V%T
M:6]N<R!T;R!U;FEN<W1A;&PB+`H))W-I=&5?87!P<U]?<V5L96-T7V-L:65N
M=',G(#T^(")396QE8W0@8VQI96YT<R(L"@DG<VET95]A<'!S7U]S:71E7V%P
M<%]P:V=S)R`]/B`B4VET92!A<'!L:6-A=&EO;B!P86-K86=E<R(L"@DG<VET
M95]A<'!S7U]S:71E7V%P<%]P:V=S7V%D9"<@/3X@(D%D9"!N97<@<VET92!A
M<'!L:6-A=&EO;B!P86-K86=E(BP*"2=S:71E7V%P<'-?7W-I=&5?87!P7W!K
M9W-?;6%N86=E;65N="<@/3X@(D%P<&QI8V%T:6]N(%9A=6QT(BP*"2=S:71E
M7V%P<'-?7W-I=&5?87!P<R<@/3X@(E-I=&4@07!P;&EC871I;VYS(BP*"2=S
M:71E7V%P<'-?7W-I=&5?87!P<U]M86YA9V5M96YT)R`]/B`B26YS=&%L;&5D
M($%P<&QI8V%T:6]N<R(L"@DG<VET95]A<'!S7U]S:71E7V%P<%]P:V=S7VEN
M<W1A;&QA=&EO;B<@/3X@)TEN<W1A;&QA=&EO;CH@<V5L96-T('1H92!A<'!L
M:6-A=&EO;B!T;R!B92!I;G-T86QL960G+`H))W-I=&5?87!P<U]?<VET95]A
M<'!?<&MG<U]I;G-T86YC97,G(#T^("=);G-T86QL871I;VYS(&]F('1H92`E
M,2!!<'!L:6-A=&EO;B<L"@DG<VET95]A<'!S7U]U;FEN<W1A;&Q?<V%P<"<@
M/3X@(E5N:6YS=&%L;"!A<'!L:6-A=&EO;G,@9G)O;2!D;VUA:6X@)3$B+`H)
M)W-I=&5?87!P<U]?=6YI;G-T86QL7W-A<'!P:V<G(#T^(")5;FEN<W1A;&P@
M87!P;&EC871I;VX@<&%C:V%G97,B+`H))W-I=&5?87!P<U]?=7!L;V%D7W-I
M=&5?87!P7W!K9U]T:71L92<@/3X@(E5P;&]A9"!N97<@<VET92!A<'!L:6-A
M=&EO;B!P86-K86=E(BP*"2=S:71E7V%P<'-?7W9E<G-I;VXG(#T^(")697)S
M:6]N(BP*"2=S:71E7V)U:6QD97)?<F5Q=6ER97,G(#T^("<E,2`M("4S)RP*
M"2=S:V5L971O;E]?861M:6Y?;&%B96PG(#T^(")!9&UI;FES=')A=&]R(&1E
M9FEN960@<VME;&5T;VXB+`H))W-K96QE=&]N7U]C;&EE;G1?;&%B96PG(#T^
M("(E,2!D969I;F5D('-K96QE=&]N(BP*"2=S:V5L971O;E]?861M:6Y?<&%G
M92<@/3X@(E-K96QE=&]N(&UA;F%G96UE;G0B+`H))W-K96QE=&]N7U]F:6QE
M<U]L:7-T)R`]/B`B4VME;&5T;VX@8V]N=&5N=',B+`H))W-K96QE=&]N7U]A
M<F-H:79E<E]N;W1?:6YS=&%L;&5D)R`]/B`B56YA8FQE('1O('5N<&%C:R!T
M:&4@<VME;&5T;VXN($%R8VAI=F5R(&ES('!O<W-I8FQY(&YO="!I;G-T86QL
M960@;VX@=&AE('-E<G9E<BX@0V]N=&%C="!T:&4@)%!23T1?3D%-12!A9&UI
M;FES=')A=&]R('1O(&AA=F4@=&AE(&%R8VAI=F5R('-O9G1W87)E(&EN<W1A
M;&QE9"XB+`H))W-K96QE=&]N7U]C;&EE;G1?<&%G92<@/3X@(E9I<G1U86P@
M:&]S="!S:V5L971O;B!M86YA9V5M96YT(BP*"2=S:V5L971O;E]?87)C:&EV
M95]C;W)R=7!T960G(#T^(")!<F-H:79E(&-H96-K(&1I<V-O=F5R960@=&AA
M="!T:&4@87)C:&EV92!F:6QE(&ES(&5I=&AE<B!C;W)R=7!T(&]R('1H:7,@
M87)C:&EV92!T>7!E(&ES(&YO="!S=7!P;W)T960N(BP*"2=S:V5L971O;E]?
M87)C:&EV95]T;V]?;&%R9V4G(#T^(")!<F-H:79E(&-H96-K(&1I<V-O=F5R
M960@=&AA="!T:&4@87)C:&EV92!F:6QE(&ES('1O;R!L87)G92XB+`H))W-K
M96QE=&]N7U]N;W1?<W5P<&]R=&5D7V%R8VAI=F5?='EP92<@/3X@(E1H:7,@
M='EP92!O9B!A<F-H:79E("AF:6QE("4Q*2!I<R!N;W0@<W5P<&]R=&5D(BP*
M"2=S:V5L971O;E]?=7!L;V%D7V%R8VAI=F5?9FEL92<@/3X@(E5P;&]A9"!S
M:V5L971O;B!A<F-H:79E(&9I;&4B+`H))W-K:6Y?9&]W;FQO861?7W1I=&QE
M)R`]/B`G1&]W;FQO860@4VMI;B<L"@DG<VMI;E]D;W=N;&]A9%]N;W=?7W1I
M=&QE)R`]/B`G4VMI;B!D;W=N;&]A9"!I;B!P<F]G<F5S<R<L"@DG<VMI;E]D
M;W=N;&]A9%]N;W=?7W1E>'0G(#T^("=4:&4@<VMI;B!P86-K86=E(&-R96%T
M:6]N(&ES(&EN('!R;V=R97-S+CQB<CY4:&ES('!R;V-E9'5R92!M87D@=&%K
M92!S;VUE('1I;64N/&)R/B!/;F-E('1H92!D:6%L;V<*=VEN9&]W(&%P<&5A
M<G,L('EO=2!C86X@8V]N=&EN=64@;W!E<F%T:6YG('1H92!C;VYT<F]L('!A
M;F5L+B<L"@DG<VMI;E]F:6QE7U]H96QP7V9O<E]U<VEN9U]T>7!E<R<@/3X@
M(E!L96%S92P@=7-E('1H92!S:VEN(&%R8VAI=F5S(&EN(&]N92!O9B!T:&4@
M9F]L;&]W:6YG(&9O<FUA=',B+`H))W-K:6Y?:6YF;U]?=&ET;&4G(#T^("=3
M:VEN(%!R;W!E<G1I97,G+`H))W-K:6Y?;6YG7V5R<E]?<G!M7VYO=%]S:VEN
M)PD]/B`G5&AI<R!24$T@:7,@;F]T(&$@8V]N=')O;"!P86YE;"!S:VEN('!A
M8VMA9V4G+`H))W-K:6Y?;6YG7V5R<E]?<'-A7VEN<W1A;&Q?;F]R96QO8R<@
M/3X@)T9A:6QE9"!T;R!I;G-T86QL(')P;2UB87-E9"!S:VEN(&EN('1H92!S
M<&5C:69I960@;&]C871I;VXN)RP*"2=S:VEN7VUN9U]E<G)?7V%L<F5A9'E?
M97AI<W1S)R`]/B`G5&AE('-K:6X@:6YS=&%L;&%T:6]N(&1I<F5C=&]R>2!A
M;')E861Y(&5X:7-T<RP@86YD('1H97)E(&ES(&$@<VMI;B!P86-K86=E(&1E
M<&QO>65D+B<L"@DG<VMI;E]M;F=?97)R7U]R<&U?=7!G<F%D95]N;VYR<&TG
M(#T^("=4:&4@=7!L;V%D960@9FEL92!I<R!N;W0@82!V86QI9"!24$T@<VMI
M;B!P86-K86=E+B<L"@DG<VMI;E]M;F=?97)R7U]R<&U?=7!G<F%D95]N;W-K
M:6XG(#T^("=4:&4@=7!L;V%D960@9FEL92!I<R!N;W0@82!V86QI9"!S:VEN
M('!A8VMA9V4N)RP*"2=S:VEN7VUN9U]E<G)?7W)P;5]U<&=R861E7V)A<V4G
M(#T^(")4:&4@=7!L;V%D960@9FEL92!I<R!N;W0@82!V86QI9"`D4%)/1%].
M04U%('-K:6X@<&%C:V%G92XB+`H))W-K:6Y?;6YG7V5R<E]?<G!M7W5P9W)A
M9&5?;W1H97(G(#T^("=5;F%B;&4@=&\@:6YS=&%L;"!T:&4@<VMI;CH@:6YV
M86QI9"!S:VEN(&9O<FUA="XG+`H))W-K:6Y?;6YG7V5R<E]?;F]?85]S:VEN
M)R`]/B`B5&AE('5P;&]A9&5D(&9I;&4@:7,@;F]T(&$@=F%L:60@)%!23T1?
M3D%-12!S:VEN('!A8VMA9V4N(BP*"2=S:VEN7W5P;&]A9%]?=&ET;&4G(#T^
M("=5<&QO860@3F5W(%-K:6XG+`H))W-K:6Y?=7!L;V%D7U]A;')E861Y7V5X
M:7-T<R<@/3X@(E1H92!S:VEN("<E,2<@86QR96%D>2!E>&ES=',B+`H))W-K
M:6Y?=7!L;V%D7U]U;F%B;&5?=&]?87!P;'DG(#T^(")4:&4@=7!L;V%D960@
M9FEL92!D;V5S(&YO="!C;VYT86EN(&$@4&QE<VL@<VMI;BP@;W(@=&AE(&%R
M8VAI=F4@9F]R;6%T(&ES(&YO="!S=7!P;W)T960N(BP*"2=S:VEN7W5P;&]A
M9%]?9FEL95]N86UE)R`]/B`G4&%T:"!T;R!T:&4@<VMI;B!P86-K86=E(&9I
M;&4G+`H))W-K:6YS7VQI<W1?7W1I=&QE)R`]/B`G4VMI;G,@4F5P;W-I=&]R
M>2<L"@DG<VMI;G-?<F5M;W9E7U]T:71L92<@/3X@)U-K:6X@4F5M;W9A;"<L
M"@DG<VMI;G-?<F5M;W9E7U]S96QE8W1?<VMI;G-?9F]R7W)E;6]V92<@/3X@
M)U-E;&5C="!T:&4@<VMI;G,@=&\@8F4@<F5M;W9E9"XG+`H))W-L879E7V-E
M<G1?7W!A9V5?=&ET;&4G(#T^(")3;&%V92!S97)V97(@)3$@8V5R=&EF:6-A
M=&4@<V5T=7`N(BP*"2=S;&%V95]S97)V97)?7V%D;6EN7V%P86-H95]I<U]N
M;W1?=V]R:R<@/3X@(D%D;6EN(&%P86-H92!S97)V97(@9&]E<R!N;W0@9G5N
M8W1I;VXZ('1H92!P;W)T(')E:F5C=',@8V]N;F5C=&EO;G,N(BP*"2=S;&%V
M95]S97)V97)?7V%L;%]O:R<@/3X@(D%L;"!S97)V:6-E<R!F=6YC=&EO;B!P
M<F]P97)L>2!A;F0@=&AE<F4@87)E(&YO('!R;V)L96T@9&]M86EN<R!O<B!C
M;&EE;G1S(&]N('1H92!S;&%V92!S97)V97(N(BP*"2=S;&%V95]S97)V97)?
M7V)A9%]C;&EE;G1S)R`]/B`B5&AE<F4@87)E('!R;V)L96T@8VQI96YT<R!O
M;B!T:&4@<VQA=F4@<V5R=F5R+B(L"@DG<VQA=F5?<V5R=F5R7U]B861?9&]M
M86EN<R<@/3X@(E1H97)E(&%R92!P<F]B;&5M(&1O;6%I;G,@;VX@=&AE('-L
M879E('-E<G9E<BXB+`H))W-L879E7W-E<G9E<E]?8F%D7V1O;6%I;G-?86YD
M7V-L:65N=',G(#T^(")4:&5R92!A<F4@<')O8FQE;2!C;&EE;G1S(&%N9"!D
M;VUA:6YS(&]N('1H92!S;&%V92!S97)V97(N(BP*"2=S;&%V95]S97)V97)?
M7V-E<G1?9FEL96YA;65?:7-?96UP='DG(#T^(")5<&QO861E9"!S;&%V92!S
M97)V97(@8V5R=&EF:6-A=&4@9FEL96YA;64@:7,@96UP='DN(BP*"2=S;&%V
M95]S97)V97)?7V-E<G1?:7-?:6YV86QI9"<@/3X@(E1H92!C97)T:69I8V%T
M92!U<V5D(&9O<B!T:&ES('-E<W-I;VX@9&ED(&YO="!P87-S('1H92!V97)I
M9FEC871I;VXN(BP*"2=S;&%V95]S97)V97)?7V-E<G1?:7-?;F]T7W-E="<@
M/3X@(E-33"!C97)T:69I8V%T92!F;W(@=&AI<R!S;&%V92!S97)V97(@=V%S
M(&YO="!I;G-T86QL960N(BP*"2=S;&%V95]S97)V97)?7V-E<G1?=&5X=&9I
M96QD7VES7V5M<'1Y)R`]/B`B57!L;V%D960@<VQA=F4@<V5R=F5R(&-E<G1I
M9FEC871E(&ES(&5M<'1Y+B(L"@DG<VQA=F5?<V5R=F5R7U]C;W5L9&YT7V-O
M;FYE8W0G(#T^(")&86EL960@=&\@8V]N;F5C="!T;R!H;W-T+B(L"@DG<VQA
M=F5?<V5R=F5R7U]D97-C<FEP=&EO;B<@/3X@(D1E<V-R:7!T:6]N(BP*"2=S
M;&%V95]S97)V97)?7V1O7VYO=%]R97%U97-T)R`]/B`B1&\@;F]T(')E<75E
M<W0@:6YF;W)M871I;VX@9G)O;2!T:&4@<V5R=F5R(BP*"2=S;&%V95]S97)V
M97)?7V5N=&5R<')I<V5?:7-?;F]T7W-U<'!O<G1E9"<@/3X@(E1H92`D4%)/
M1%].04U%('9E<G-I;VX@<G5N;FEN9R!O;B!T:&ES('-E<G9E<B!D;V5S(&YO
M="!S=7!P;W)T('1H92!-87-T97(@9F5A='5R92XB+`H))W-L879E7W-E<G9E
M<E]?9F]L;&]W:6YG7W-E<G9I8V5S7VES7VYO=%]W;W)K)R`]/B`B5&AE(&9O
M;&QO=VEN9R!S97)V:6-E<R!D;R!N;W0@9G5N8W1I;VX@;VX@=&AE('-L879E
M('-E<G9E<CH@)3$N(BP*"2=S;&%V95]S97)V97)?7VEN=F%L:61?;&]G:6Y?
M;W)?<&%S<W=O<F0G(#T^("));F-O<G)E8W0@;&]G:6X@86YD('!A<W-W;W)D
M+B(L"@DG<VQA=F5?<V5R=F5R7U]K97E?;&EM:71S)R`]/B`B66]U<B!K97D@
M86QL;W=S(&-R96%T:6YG("4Q('-L879E('-E<G9E<G,@86-C;W5N=',@;VYL
M>2XB+`H))W-L879E7W-E<G9E<E]?<&%G95]T:71L92<@/3X@(E-L879E('-E
M<G9E<B!A8V-O=6YT(BP*"2=S;&%V95]S97)V97)?7W)E<75E<W1?=&EM96]U
M="<@/3X@(E-E<G9E<B!D871A(')E=')I979A;"!T:6UE;W5T+B(L"@DG<VQA
M=F5?<V5R=F5R7U]S96QE8W1?<VQA=F5?<V5R=F5R<U]F;W)?<F5M;W9E)R`]
M/B`B4V5L96-T('-L879E('-E<G9E<B!A8V-O=6YT<R!T;R!B92!R96UO=F5D
M+B(L"@DG<VQA=F5?<V5R=F5R7U]S97)V97)?86-C;W5N=%]A;')E861Y7V5X
M:7-T)R`]/B`B<V5R=F5R(&%C8V]U;G0@=VET:"!S=6-H(&AO<W1N86UE(&%L
M<F5A9'D@97AI<W1S+B(L"@DG<VQA=F5?<V5R=F5R7U]S97)V97)?:6YF;U]I
M<U]N;W1?879A:6QA8FQE)R`]/B`B4VQA=F4@<V5R=F5R(&EN9F]R;6%T:6]N
M(&ES(&YO="!C=7)R96YT;'D@879A:6QA8FQE+B(L"@DG<VQA=F5?<V5R=F5R
M7U]S;VUE7W-E<G9I8V5S7VES7VYO=%]W;W)K)R`]/B`B4V]M92!S97)V:6-E
M<R!D;R!N;W0@9G5N8W1I;VX@;VX@=&AE('-L879E('-E<G9E<BXB+`H))W-L
M879E7W-E<G9E<E]?=6YA8FQE7V1E9FEN95]H;W-T;F%M92<@/3X@(E5N86)L
M92!T;R!D969I;F4@=&AE('-L879E('-E<G9E<B!H;W-T;F%M93H@)3$B+`H)
M)W-L879E7W-E<G9E<E]?=6YA8FQE7W1O7W)E<V]L=F5?:&]S=&YA;64G(#T^
M(")5;F%B;&4@=&\@<F5S;VQV92!T:&4@:&]S=&YA;64N(BP*"2=S;&%V95]S
M97)V97)?7W5N86)L95]T;U]S971?8V5R=&EF:6-A=&4G(#T^(")5;F%B;&4@
M=&\@:6YS=&%L;"!T:&4@8V5R=&EF:6-A=&4@=&\@=&AE('-L879E('-E<G9E
M<CH@)3$B+`H))W-L879E7W-E<G9E<E]?=6YA8FQE7W1O7W5P9&%T92<@/3X@
M(E5N86)L92!T;R!U<&1A=&4@=&AE('-L879E('-E<G9E<B!P<F5F97)E;F-E
M<SH@)3$B+`H))W-L879E7W-E<G9E<E]?=6YK;F]W;E]E<G)O<B<@/3X@(E-E
M<G9E<B!R971U<FYE9"!U;FMN;W=N(&5R<F]R+B(L"@DG<W!A;6%S<V%S<VEN
M7U]T:71L92<@/3X@(E-P86T@9FEL=&5R(&-O;F9I9W5R871I;VXB+`H))W-P
M87=?7V5D:71?9FEL95]?)R`]/B`G5UE325=91R!E9&ET;W(Z("4Q)RP*"2=S
M<&%W;E]?=6YA8FQE7W1O7V5D:71?;F]?8F]D>2<@/3X@)U5N86)L92!T;R!E
M9&ET('1H:7,@9FEL92!B96-A=7-E(&ET(&1O97,@;F]T(&-O;G1A:6X@=&AE
M(#QB;V1Y/B!T86<N)RP*"2=S<&9?<&%R86UE=&5R<R<@/3X@)T5N86)L92!3
M4$8@<W!A;2!P<F]T96-T:6]N)RP*"2=S<&9?8F5H879I;W(G(#T^("=34$8@
M8VAE8VMI;F<@;6]D92<L"@DG<W!F7W)U;&5S)R`]/B`G4U!&(&QO8V%L(')U
M;&5S)RP*"2=S<&9?9W5E<W,G(#T^("=34$8@9W5E<W,G+`H))W-P9E]E>'`G
M(#T^("=34$8@97AP;&%N871I;VX@=&5X="<L"@DG<W!F7U]U;F%B;&5?=7!D
M871E)R`]/B`G56YA8FQE('1O('5P9&%T92!34$8@<&%R86UE=&5R<R<L"@DG
M<W!F7V)H=E]?8W)E871E7VAE861E<G-?;F]?8FQO8VLG(#T^("=/;FQY(&-R
M96%T92!296-E:79E9"U34$8@:&5A9&5R<RP@;F5V97(@8FQO8VLG+`H))W-P
M9E]B:'9?7W5S95]T;7!?97)R;W)S)R`]/B`G57-E('1E;7!O<F%R>2!E<G)O
M<B!N;W1I8V5S('=H96X@>6]U(&AA=F4@1$Y3(&QO;VMU<"!P<F]B;&5M<R<L
M"@DG<W!F7V)H=E]?<F5J96-T7VEF7V9A:6PG(#T^("=296IE8W0@;6%I;',@
M=VAE;B!34$8@<F5S;VQV97,@=&\@(F9A:6PB("AD96YY*2<L"@DG<W!F7V)H
M=E]?<F5J96-T7VEF7W-O9G1F86EL)R`]/B`G4F5J96-T(&UA:6QS('=H96X@
M4U!&(')E<V]L=F5S('1O(")S;V9T9F%I;"(G+`H))W-P9E]B:'9?7W)E:F5C
M=%]I9E]N975T<F%L)R`]/B`G4F5J96-T(&UA:6QS('=H96X@4U!&(')E<V]L
M=F5S('1O(")N975T<F%L(B<L"@DG<W!F7V)H=E]?<F5J96-T7VEF7VYO7W!A
M<W,G(#T^("=296IE8W0@;6%I;',@=VAE;B!34$8@9&]E<R!N;W0@<F5S;VQV
M92!T;R`B<&%S<R(G+`H))W-S:'1E<FU?7W1I=&QE)R`]/B`G4V5C=7)E(%-H
M96QL(%1E<FUI;F%L)RP*"2=S<VAT97)M7U]P87-S=V]R9%]A=71H96YT:6-A
M=&EO;E]W87)N:6YG)R`]/B`G3F]T93H@4&%S<W=O<F0@875T:&5N=&EC871I
M;VX@:7,@9&ES86)L960@:6X@=&AE(&QO8V%L(%-32"!S97)V97(@8V]N9FEG
M=7)A=&EO;BX@268@>6]U(&%R92!U;F%B;&4@=&\@8V]N;F5C="!U<VEN9R!T
M:&4@4U-((%1E<FUI;F%L+"!A<VL@=&AE(&%D;6EN:7-T<F%T;W(@=&\@<V5T
M(")087-S=V]R9$%U=&AE;G1I8V%T:6]N('EE<R(@:6X@=&AE("]E=&,O<W-H
M+W-S:&1?8V]N9FEG(&9I;&4N)RP*"2=S<VAT97)M7U]P87-S=V]R9%]A=71H
M96YT:6-A=&EO;E]W87)N:6YG7V%D;6EN)R`]/B`G3F]T93H@4&%S<W=O<F0@
M875T:&5N=&EC871I;VX@:7,@9&ES86)L960@:6X@=&AE(&QO8V%L(%-32"!S
M97)V97(@8V]N9FEG=7)A=&EO;BX@268@>6]U(&%R92!U;F%B;&4@=&\@8V]N
M;F5C="!U<VEN9R!T:&4@4U-((%1E<FUI;F%L+"!P;&5A<V4@<V5T(")087-S
M=V]R9$%U=&AE;G1I8V%T:6]N('EE<R(@:6X@=&AE("]E=&,O<W-H+W-S:&1?
M8V]N9FEG(&9I;&4N)RP*"2=S=&%T:7-T:6-S7U]A8W1I=F5?9&]M86EN<R<@
M/3X@(D%C=&EV92!D;VUA:6YS(BP*"2=S=&%T:7-T:6-S7U]C;&EE;G1S)R`]
M/B`B0VQI96YT<R(L"@DG<W1A=&ES=&EC<U]?<W5B9&]M86EN<R<@/3X@(E-U
M8F1O;6%I;G,B+`H))W-T871I<W1I8W-?7V-P=2<@/3X@(D-052(L"@DG<W1A
M=&ES=&EC<U]?9&%T86)A<V5S)R`]/B`B1&%T86)A<V5S(BP*"2=S=&%T:7-T
M:6-S7U]D8E]U<V5R<R<@/3X@(D1A=&%B87-E('5S97)S(BP*"2=S=&%T:7-T
M:6-S7U]D:7)S)R`]/B`B1&ER96-T;W)I97,B+`H))W-T871I<W1I8W-?7V1O
M;5]A8W1I=F4G(#T^(")!8W1I=F4B+`H))W-T871I<W1I8W-?7V1O;5]P87-S
M:79E)R`]/B`B4&%S<VEV92(L"@DG<W1A=&ES=&EC<U]?9&]M7W!R;V)L96TG
M(#T^(")0<F]B;&5M(BP*"2=S=&%T:7-T:6-S7U]D;VUA:6YS)R`]/B`B1&]M
M86EN<R(L"@DG<W1A=&ES=&EC<U]?9&]M86EN<U]W:71H7VAO<W0G(#T^(")$
M;VUA:6YS('=I=&@@:&]S=&EN9R(L"@DG<W1A=&ES=&EC<U]?9&]M<R<@/3X@
M(D1O;6%I;G,@(BP*"2=S=&%T:7-T:6-S7U]F:6QE<WES=&5M)R`]/B`B1FEL
M97-Y<W1E;2(L"@DG<W1A=&ES=&EC<U]?9V5N97)A;"<@/3X@(D=E;F5R86PB
M+`H))W-T871I<W1I8W-?7VAD9%]A=F%I;&%B;&4G(#T^(")!=F%I;&%B;&4B
M+`H))W-T871I<W1I8W-?7VAD9%]C87!A8VET>2<@/3X@(D-A<&%C:71Y(BP*
M"2=S=&%T:7-T:6-S7U]H9&1?=&]T86PG(#T^(")4;W1A;"(L"@DG<W1A=&ES
M=&EC<U]?:&1D7W5S86=E)R`]/B`B2&%R9"!$:7-K(%5S86=E(BP*"2=S=&%T
M:7-T:6-S7U]H9&1?=7-E9"<@/3X@(E5S960B+`H))W-T871I<W1I8W-?7VEP
M)R`]/B`B25`@861D<F5S<R(L"@DG<W1A=&ES=&EC<U]?:V5Y7VYU;6)E<B<@
M/3X@(DME>2!N=6UB97(B+`H))W-T871I<W1I8W-?7VPQ)R`]/B`B3&%S="`Q
M(&UI;G5T92(L"@DG<W1A=&ES=&EC<U]?;#$U)R`]/B`B3&%S="`Q-2!M:6YU
M=&5S(BP*"2=S=&%T:7-T:6-S7U]L-2<@/3X@(DQA<W0@-2!M:6YU=&5S(BP*
M"2=S=&%T:7-T:6-S7U]L82<@/3X@(D-052!U<V%G92(L"@DG<W1A=&ES=&EC
M<U]?;6%I;%]A=71O<F5S<&]N9&5R<R<@/3X@(D%U=&]R97-P;VYD97)S(BP*
M"2=S=&%T:7-T:6-S7U]M86EL7V)O>&5S)R`]/B`B36%I;&)O>&5S(BP*"2=S
M=&%T:7-T:6-S7U]M86EL7V=R;W5P<R<@/3X@(DUA:6P@9W)O=7!S(BP*"2=S
M=&%T:7-T:6-S7U]M86EL7VQI<W1S)R`]/B`B36%I;&EN9R!L:7-T<R(L"@DG
M<W1A=&ES=&EC<U]?;6%I;%]R961I<F5C=',G(#T^(")-86EL(')E9&ER96-T
M<R(L"@DG<W1A=&ES=&EC<U]?;65M)R`]/B`B365M;W)Y(%5S86=E(BP*"2=S
M=&%T:7-T:6-S7U]M96U?=7-A9V4G(#T^(")5<V%G92(L"@DG<W1A=&ES=&EC
M<U]?;65M;W)Y7V)U9F9E<B<@/3X@(D)U9F9E<B(L"@DG<W1A=&ES=&EC<U]?
M;65M;W)Y7V-A8VAE9"<@/3X@(D-A8VAE9"(L"@DG<W1A=&ES=&EC<U]?;65M
M;W)Y7V9R964G(#T^(")&<F5E(BP*"2=S=&%T:7-T:6-S7U]M96UO<GE?<VAA
M<F5D)R`]/B`B4VAA<F5D(BP*"2=S=&%T:7-T:6-S7U]M96UO<GE?=&]T86PG
M(#T^(")4;W1A;"(L"@DG<W1A=&ES=&EC<U]?;65M;W)Y7W5S960G(#T^(")5
M<V5D(BP*"2=S=&%T:7-T:6-S7U]O<R<@/3X@(D]3(BP*"2=S=&%T:7-T:6-S
M7U]P<F]B;&5M7V-L:65N=',G(#T^(")0<F]B;&5M(&-L:65N=',B+`H))W-T
M871I<W1I8W-?7W!R;V)L96U?9&]M86EN<R<@/3X@(E!R;V)L96T@9&]M86EN
M<R(L"@DG<W1A=&ES=&EC<U]?<W=A<"<@/3X@(E-W87`@=7-A9V4B+`H))W-T
M871I<W1I8W-?7W-W87!?9G)E92<@/3X@(D9R964B+`H))W-T871I<W1I8W-?
M7W-W87!?=&]T86PG(#T^(")4;W1A;"(L"@DG<W1A=&ES=&EC<U]?<W=A<%]U
M<V%G92<@/3X@(E5S86=E(BP*"2=S=&%T:7-T:6-S7U]S=V%P7W5S960G(#T^
M(")5<V5D(BP*"2=S=&%T:7-T:6-S7U]S>7-T96U?<W1A="<@/3X@(E-Y<W1E
M;2!S=&%T:7-T:6-S(BP*"2=S=&%T:7-T:6-S7U]U;F%B;&5?9&5F:6YE7V%C
M=&EV95]D;VUS)R`]/B`B56YA8FQE('1O(&1E=&5R;6EN92!T:&4@;G5M8F5R
M(&]F(&%C=&EV92!D;VUA:6YS.B`E,2(L"@DG<W1A=&ES=&EC<U]?=6YA8FQE
M7V1E9FEN95]I;F%C=&EV95]D;VUS)R`]/B`B56YA8FQE('1O(&1E=&5R;6EN
M92!T:&4@;G5M8F5R(&]F(&EN86-T:79E(&1O;6%I;G,Z("4Q(BP*"2=S=&%T
M:7-T:6-S7U]U<%]T:6UE)R`]/B`B4WES=&5M(%5P=&EM93H@(BP*"2=S=&%T
M:7-T:6-S7U]V97(G(#T^(")697)S:6]N(BP*"2=S=&%T:7-T:6-S7U]W96)?
M87!P<R<@/3X@(DIA=F$@87!P;&EC871I;VYS(BP*"2=S=&%T:7-T:6-S7U]W
M96)?=7-E<G,G(#T^(")796(@=7-E<G,B+`H))W-T871U<U]?8VQI96YT7VAA
M<U]R96%S;VYS7W1O7V)E7V]F9B<@/3X@(E1H92!C;&EE;G0@86-C;W5N="!I
M<R!S=&EL;"!D:7-A8FQE9"X@5&AE(')E87-O;CH@)3$B+`H))W-T871U<U]?
M9&]M86EN7VAA<U]R96%S;VYS7W1O7V)E7V]F9B<@/3X@(E1H92!D;VUA:6X@
M:7,@<W1I;&P@9&ES86)L960N(%1H92!R96%S;VXZ("4Q(BP*"2=S=6)D;VUA
M:6Y?7V-R96%T95]?)R`]/B`B0W)E871E(&$@<W5B9&]M86EN(&EN('1H92!D
M;VUA:6X@)3$B+`H))W-U8F1O;6%I;E]?961I=%]?)R`]/B`B36%N86=E('-U
M8F1O;6%I;B`E,2(L"@DG<W5B9&]M86EN7U]I;G9A;&ED7VYA;64G(#T^("))
M;G9A;&ED('-U8F1O;6%I;B!N86UE.B!U<V4@;VYL>2!A;'!H86YU;65R:6,@
M86YD(&1A<V@@<WEM8F]L<RXB+`H))W-U8F1O;6%I;G-?7V9U;&Q?;F%M95]L
M;VYG)R`]/B`B5&AE(&9U;&P@;F%M92!O9B!S=6)D;VUA:6X@:7,@=&]O(&QO
M;F<N(BP*"2=S=6)D;VUA:6YS7U]L:7-T7V]F7V1O;6%I;B<@/3X@(E-U8F1O
M;6%I;G,@:6X@=&AE(&1O;6%I;B`E,2(L"@DG<W5B9&]M86EN<U]?;6%I;&QI
M<W1S7V5N86)L961?:6Y?9&]M86EN)R`]/B`B26YC;W)R96-T('-U8F1O;6%I
M;B!N86UE(&QI<W1S+B4Q+"!O;B!D;VUA:6X@)3$@=&AE($UA:6QI;F<@;&ES
M=',@87)E(&5N86)L960N(BP*"2=S=6)D;VUA:6YS7U]D86QI87-?97AI<W1S
M)R`]/B`G5&AE(&1O;6%I;B!A;&EA<R!W:71H('-U8V@@;F%M92!A;')E9'D@
M97AI<W1S+B<L"@DG<W5B9&]M86EN<U]?;F%M95]E>&ES=',G(#T^(")4:&4@
M<W5B9&]M86EN('=I=&@@<W5C:"!N86UE(&%L<F5A9'D@97AI<W1S+B(L"@DG
M<W5B9&]M86EN<U]?<F5G=6QA<E]D;VUA:6Y?97AI<W1S)R`]/B`B5&AE(&1O
M;6%I;B!W:71H('-U8V@@;F%M92!A;')E9'D@97AI<W1S+B(L"@DG<W5B9&]M
M86EN<U]?<F5M;W9E7W-U8F1O;6%I;G-?;VY?9&]M86EN)R`]/B`B5&AE(&9O
M;&QO=VEN9R!S=6)D;VUA:6YS(&9O<B!D;VUA:6X@)3$@=VEL;"!B92!R96UO
M=F5D.B(L"@DG<W5B9&]M86EN<U]?<V5L96-T7W-U8F1O;6%I;G-?9F]R7W)E
M;6]V92<@/3X@(E-E;&5C="!T:&4@<W5B9&]M86EN<R!T;R!B92!R96UO=F5D
M+B(L"@DG<W5B9&]M86EN<U]?=&%R9V5T7V9O;&1E<E]E>&ES=',G(#T^(")4
M:&4@9&ER96-T;W)Y("4Q(&9O<B!S=6)D;VUA:6X@86QR96%D>2!E>&ES=',N
M(BP*"2=S=6)D;VUA:6YS7U]W96)M86EL7V5N86)L961?:6Y?9&]M86EN)R`]
M/B`B26YC;W)R96-T('-U8F1O;6%I;B!N86UE('=E8FUA:6PN)3$L(&]N(&1O
M;6%I;B`E,2!T:&4@5V5B;6%I;"!I<R!E;F%B;&5D+B(L"@DG<W5B9&]M86EN
M<U]?9&YS7W)E8V]R9%]A;')E861Y7V5X:7-T<R<@/3X@)U-U8V@@<F5S;W5R
M8V4@<F5C;W)D(&ES(&%L<F5A9'D@:6X@=&AE('IO;F4@)3$N)RP*"2=S=6)D
M;VUA:6YS7U]W=W=?<')E9FEX7VEN7V1O;6%I;B<@/3X@(DEN8V]R<F5C="!S
M=6)D;VUA:6X@;F%M93H@=&AE(&1O;6%I;B`E,2!A;')E861Y(&AA<R!T:&4@
M5U=7(&%L:6%S+B(L"@DG<W5B9&]M86EN<U]?8W)E871I;VY?:6Y?9&YS7W-L
M879E)R`]/B`B4&QE<VLG<R!N86UE('-E<G9E<B!I<R!A8W1I;F<@87,@82!S
M96-O;F1A<GD@*'-L879E*2!N86UE('-E<G9E<B!F;W(@=&AI<R!D;VUA:6XN
M($9O<B!Y;W5R('-U8F1O;6%I;B!T;R!R97-O;'9E('!R;W!E<FQY+"!M86ME
M('-U<F4@=&AA="!T:&4@>F]N92!F:6QE(&]N('1H92!P<FEM87)Y("AM87-T
M97(I('-E<G9E<B!C;VYT86EN<R!T:&4@<F5C;W)D("4Q(BP*"2=S>7-?=7-E
M<E]?871T<FEB=71E<U]N;W1?8VAA;F=E9"<@/3X@(EQN5&AE(&9O;&QO=VEN
M9R!S>7-T96T@=7-E<B!A='1R:6)U=&5S('=E<F4@;F]T(&-H86YG960Z("4Q
M(BP*"2=S>7-?=7-E<E]?;F]?86-C97-S7W=I=&AO=71?<&%S<W=O<F0G(#T^
M(")9;W4@9&ED(&YO="!S970@82!P87-S=V]R9"X@5&AE('-Y<W1E;2!U<V5R
M('=I;&P@8F4@8W)E871E9"P@8G5T('=I;&P@;F]T(&)E(&%B;&4@=&\@;&]G
M(&EN('1O('1H92!S>7-T96TL('5N=&EL(&AE+W-H92!I<R!G:79E;B!A('!A
M<W-W;W)D+B!7;W5L9"!Y;W4@;&EK92!T;R!P<F]C965D/R(L"@DG<WES7W5S
M97)?7VYO7VAA<F1?<75O=&$G(#T^(")N;W0@<W5P<&]R=&5D(BP*"2=S>7-U
M<V5R7U]Z97)O7W%U;W1A7VES7W5N;&EM:71E9"<@/3X@(C`@9F]R('5N;&EM
M:71E9"(L"@DG=&5M<&QA=&5?7VYU;5]E>&-L7VEP<R<@/3X@(D%L;&]C871E
M(&5X8VQU<VEV92!I<"!A9&1R97-S97,@=&\@=&AE(&-L:65N="(L"@DG=&5M
M<&QA=&5?7W-E;%]S:%]I<',G(#T^(")396QE8W0@<VAA<F5D(&EP(&%D9')E
M<W-E<R(L"@DG=&5M<&QA=&5?7V%V7W-H7VEP<R<@/3X@(D%V86EL86)L92!S
M:&%R960@:7`@861D<F5S<V5S(BP*"2=T96UP;&%T95]?=7!?=&]?97AC;%]I
M<"<@/3X@(E5P('1O("4Q(&EP(&%D9')E<W-E<R(L"@DG=&5M<&QA=&5S7U]A
M;&Q?8VQI96YT<R<@/3X@(F%L;"!C;&EE;G1S(BP*"2=T96UP;&%T97-?7V-L
M7V1O;6%I;E]T96UP;&%T97,G(#T^(")496UP;&%T97,@9F]R("4Q(BP*"2=T
M96UP;&%T97-?7V-L7W1E;7!L871E<R<@/3X@(D-L:65N="!T96UP;&%T97,B
M+`H))W1I;65?7V1A>2<@/3X@(D1A>2(L"@DG=&EM95]?9&]M7VYA;65?:7`G
M(#T^(")$;VUA:6X@;F%M92!O<B!)4"(L"@DG=&EM95]?:&]U<G,G(#T^(")(
M;W5R<R(L"@DG=&EM95]?:6YV86QI9%]I<"<@/3X@(DEN=F%L:60@25`@861D
M<F5S<R!O<B!D;VUA:6X@;F%M92XB+`H))W1I;65?7VEN=F%L:61?>65A<B<@
M/3X@(EEE87(@:7,@:6YV86QI9"X@4VAO=6QD(&)E(&)E='=E96X@,3DW,2!A
M;F0@,C`S-BXB+`H))W1I;65?7VEN=F%L:61?;6]N=&@G(#T^(")-;VYT:"!I
M<R!I;G9A;&ED+B!3:&]U;&0@8F4@8F5T=V5E;B`Q(&%N9"`Q,BXB+`H))W1I
M;65?7VEN=F%L:61?9&%Y)R`]/B`B1&%Y(&ES(&EN=F%L:60N(%-H;W5L9"!B
M92!B971W965N(#$@86YD(#,Q+B(L"@DG=&EM95]?:6YV86QI9%]H;W5R<R<@
M/3X@(DAO=7)S(&ES(&EN=F%L:60N(%-H;W5L9"!B92!B971W965N(#`@86YD
M(#(T+B(L"@DG=&EM95]?:6YV86QI9%]M:6YU=&5S)R`]/B`B36EN=71E<R!I
M<R!I;G9A;&ED+B!3:&]U;&0@8F4@8F5T=V5E;B`P(&%N9"`U.2XB+`H))W1I
M;65?7VEN=F%L:61?<V5C;VYD<R<@/3X@(E-E8V]N9',@:7,@:6YV86QI9"X@
M4VAO=6QD(&)E(&)E='=E96X@,"!A;F0@-3DN(BP*"2=T:6UE7U]M:6YU=&5S
M)R`]/B`B36EN=71E<R(L"@DG=&EM95]?;6]N=&@G(#T^(")-;VYT:"(L"@DG
M=&EM95]?<V5C)R`]/B`B4V5C;VYD<R(L"@DG=&EM95]?<WEN7W-Y<U]T:6UE
M)R`]/B`B4WEN8VAR;VYI>F4@<WES=&5M('1I;64B+`H))W1I;65?7W-Y<W1E
M;5]D871E)R`]/B`B4WES=&5M($1A=&4@86YD(%1I;64B+`H))W1I;65?7W-Y
M<W1E;5]D871E7W1I=&QE)R`]/B`B4WES=&5M($1A=&4@86YD(%1I;64B+`H)
M)W1I;65?7W1I;65Z;VYE7W1I=&QE)R`]/B`G5&EM92!Z;VYE)RP*"2=T:6UE
M7U]T:6UE>F]N92<@/3X@)UEO=7(@=&EM92!Z;VYE)RP*"2=T:6UE7U]P;&5A
M<V5?<V5L96-T7W1I;65Z;VYE)R`]/B`G4&QE87-E+"!S96QE8W0@82!T:6UE
M('IO;F4G+`H))U]?<&QE87-E7W-E;&5C=%]C;W5N=')Y)R`]/B`G4&QE87-E
M+"!S96QE8W0@>6]U<B!C;W5N=')Y)RP*"2=T:6UE7U]U;F%B;&5?<V5T7W1I
M;64G(#T^(")5;F%B;&4@=&\@<V5T('1H92!S>7-T96T@=&EM93H@)3$B+`H)
M)W1I;65?7WEE87(G(#T^(")996%R(BP*"2=T;7!L7U]C<F5A=&4G(#T^(")#
M<F5A=&4@=&5M<&QA=&4B+`H))W1M<&Q?7V5D:71?7R<@/3X@(D5D:70@=&5M
M<&QA=&4@)3$B+`H))W1M<&Q?7VQO9W)O=&%T:6]N7W=A<FXG(#T^("),;V<@
M<F]T871I;VX@;VX@=&AE(&1O;6%I;B!C<F5A=&5D(&)Y('1H:7,@=&5M<&QA
M=&4@=VEL;"!B92!P97)F;W)M960@;VYL>2!I;B!C87-E(&]F('-U8G-E<75E
M;G0@<&AY<VEC86P@:&]S=&EN9R!A8V-O=6YT(&-R96%T:6]N(&9O<B!I="XB
M+`H))W1M<&Q?7VYA;64G(#T^(")496UP;&%T92!N86UE(BP*"2=T;7!L7U]N
M86UE7VEN=F%L:60G(#T^(")496UP;&%T92!N86UE(&ES(&EN=F%L:60@;W(@
M96UP='DN(BP*"2=T;7!L7U]D;VU?97AI<W0G(#T^(")$;VUA:6X@=&5M<&QA
M=&4@=VET:"!S=6-H(&YA;64@86QR96%D>2!E>&ES=',@:6X@861M:6YI<W1R
M871O<B=S(&]R(&-L:65N="=S('1E;7!L871E<R!P;V]L+B(L"@DG=&UP;%]?
M=7-E7VYE>'1?:7!?861D<B<@/3X@(DYE>'0@=F%C86YT(&EP(&%D9')E<W,@
M=VEL;"!B92!U<V5D(BP*"2=T;V]L<V)A<E]?;&]G;W5T/R<@/3X@(D%R92!Y
M;W4@<W5R92!Y;W4@=VES:"!T;R!L;V<@;W5T/R(L"@DG=')A9F9I8U]?;F]?
M<&5R:6]D<U]F;W5N9"<@/3X@(E5N86)L92!T;R!D:7-P;&%Y('1H92!T<F%F
M9FEC('-T871I<W1I8W,N(%1H:7,@9G5N8W1I;VX@=VEL;"!B92!A=F%I;&%B
M;&4@;VYL>2!A9G1E<B!T:&4@;F5X="!S=&%T:7-T:6-S(&-A;&-U;&%T:6]N
M+B(L"@DG='1S)R`]/B`B2&5L<"!$97-K(BP*"2=T='-?7V-A;G1?8VQO<V5?
M8VQO<V5D)R`]/B`B66]U(&-A;FYO="!C;&]S92!A;B!A;')E861Y(&-L;W-E
M9"!T:6-K970B+`H))W1T<U]?8V%N=%]D96Q?8V%T7W1I8VME=',G(#T^(")5
M;F%B;&4@=&\@9&5L971E('1H92!C871E9V]R>3H@:70@:7,@=7-E9"!B>2!C
M97)T86EN('1I8VME=',@;W(@87-S:6=N960@87,@9&5F875L="!C871E9V]R
M>2XB+`H))W1T<U]?8V%N=%]D96Q?<')I;W)I='E?=&EC:V5T<R<@/3X@(E5N
M86)L92!T;R!D96QE=&4@=&AE('!R:6]R:71Y.B!I="!I<R!U<V5D(&)Y(&-E
M<G1A:6X@=&EC:V5T<R!O<B!A<W-I9VYE9"!A<R!D969A=6QT('!R:6]R:71Y
M+B(L"@DG='1S7U]C86YT7V1E;%]Q=65U95]T:6-K971S)R`]/B`B56YA8FQE
M('1O(&1E;&5T92!T:&4@<75E=64Z(&ET(&ES('5S960@8GD@8V5R=&%I;B!T
M:6-K971S(&]R(&%S<VEG;F5D(&%S(&1E9F%U;'0@<75E=64N(BP*"2=T='-?
M7V-A;G1?;W!E;E]N;W1?8VQO<V5D)R`]/B`B66]U(&-A;FYO="!R96]P96X@
M82!N;VXM8VQO<V5D('1I8VME="(L"@DG='1S7U]C871E9V]R>2<@/3X@(D-A
M=&5G;W)Y(BP*"2=T='-?7V-A=&5G;W)Y7V%L<F5A9'E?97AI<W1S7U\G(#T^
M("=#871E9V]R>2`E,2!A;')E861Y(&5X:7-T<RXG+`H))W1T<U]?8V%T<R<@
M/3X@(D-A=&5G;W)I97,B+`H))W1T<U]?8V]N9E]C86Y?<&]S="<@/3X@(D%L
M;&]W(&-U<W1O;65R<R!T;R!S=6)M:70@=&EC:V5T<R(L"@DG='1S7U]C;VYF
M7V1E9E]C871E9V]R>2<@/3X@(D1E9F%U;'0@0V%T96=O<GDB+`H))W1T<U]?
M96YA8FQE9"<@/3X@(D5N86)L960B+`H))W1T<U]?9V5N97)A;%]C;VYF:6<G
M(#T^(")(96QP($1E<VL@4V5T=&EN9W,B+`H))W1T<U]?<')I;W)I=&EE<U]L
M:7-T)R`]/B`B4')I;W)I=&EE<R(L"@DG='1S7U]P=6)L:6-?;F%M92<@/3X@
M(DYO=&EF:6-A=&EO;B!396YD97(G<R!.86UE(BP*"2=T='-?7W!U8FQI8U]E
M;6%I;"<@/3X@(DYO=&EF:6-A=&EO;B!396YD97(G<R!2971U<FX@061D<F5S
M<R(L"@DG='1S7U]C;VYF7V1E9E]P<FEO<FET>2<@/3X@(D1E9F%U;'0@4')I
M;W)I='DB+`H))W1T<U]?8V]N9E]D969?<75E=64G(#T^(")$969A=6QT(%%U
M975E(BP*"2=T='-?7V-O;F9?96YA8FQE9"<@/3X@(D5N86)L960B+`H))W1T
M<U]?8V]N9FEG=7)A=&EO;B<@/3X@(DAE;'`@1&5S:R!3971T:6YG<R(L"@DG
M='1S7U]E9&ET7V-A="<@/3X@(D5D:70@8V%T96=O<GDB+`H))W1T<U]?961I
M=%]P<FEO<FET>2<@/3X@(D5D:70@<')I;W)I='DB+`H))W1T<U]?961I=%]Q
M=65U92<@/3X@(D5D:70@<75E=64B+`H))W1T<U]?97)R7W-E;%]Q<&,G(#T^
M(")9;W4@<VAO=6QD('-E;&5C="!T:&4@9&5F875L="!Q=65U92P@<')I;W)I
M='D@86YD(&-A=&5G;W)Y('1O(&%L;&]W('1I8VME="!S=6)M:7-S:6]N+B(L
M"@DG='1S7U]G;%]C;G1?8VQO<V5D)R`]/B`B0VQO<V5D(BP*"2=T='-?7V=L
M7V-N=%]N97<G(#T^(").97<B+`H))W1T<U]?9VQ?8VYT7V]P96YE9"<@/3X@
M(D]P96XB+`H))W1T<U]?9VQ?8VYT7W)E;W!E;F5D)R`]/B`B4F5O<&5N960B
M+`H))W1T<U]?9VQ?<V5R=F5R7VYA;64G(#T^(")397)V97(@2&]S=&YA;64B
M+`H))W1T<U]?9VQ?<V5R=F5R<R<@/3X@(E-E<G9E<G,B+`H))W1T<U]?9VQ?
M='1S7V-A;E]P;W-T)R`]/B`B5&EC:V5T(%-U8FUI<W-I;VXB+`H))W1T<U]?
M9VQ?='1S7V5N86)L960G(#T^(")(96QP($1E<VL@:7,@86-T:79A=&5D(BP*
M"2=T='-?7V=L7W5N:VYO=VXG(#T^(")5;FMN;W=N(BP*"2=T='-?7V=L7W5P
M9&%T960G(#T^(")5<&1A=&5D(BP*"2=T='-?7V=L;V)A;%]T=',G(#T^(")'
M;&]B86P@2&5L<"!$97-K(BP*"2=T='-?7VQO8U]C;VYF7W1I=&QE)R`]/B`B
M3&]C86P@2&5L<"!$97-K(%-E='1I;F=S(BP*"2=T='-?7VQO8U]I;F9O)R`]
M/B`B5&]T86P@)3$L('1O=&%L(&]P96X@)3(@*"!N97<@)3,L(')E;W!E;F5D
M("4T*2P@=&]T86P@8VQO<V5D("4U('1I8VME=',N(BP*"2=T='-?7VQO8U]T
M:6-K971S7W1I=&QE)R`]/B`B3&]C86P@5&EC:V5T<R(L"@DG='1S7U]M86EL
M9V%T95]C;VYF:6<G(#T^(")(96QP($1E<VL@36%I;"!'871E(%-E='1I;F=S
M(BP*"2=T='-?7VYE=R<@/3X@(DYE=R!4:6-K970B+`H))W1T<U]?<&]P7W-E
M<G9E<B<@/3X@(E!/4#,@4V5R=F5R(BP*"2=T='-?7W!O<%]U<V5R;F%M92<@
M/3X@(E!/4#,@3&]G:6XB+`H))W1T<U]?<')I;W)I=&EE<R<@/3X@(E!R:6]R
M:71I97,B+`H))W1T<U]?<')I;W)I='DG(#T^(")0<FEO<FET>2(L"@DG='1S
M7U]P<FEO<FET>5]A;')E861Y7V5X:7-T<U]?)R`]/B`B4')I;W)I='D@)3$@
M86QR96%D>2!E>&ES=',N(BP*"2=T='-?7W%U97)Y7W!E<FEO9"<@/3X@(E%U
M97)Y(&UA:6P@;VYC92!I;B(L"@DG='1S7U]Q=65R>5]P97)I;V1?;6EN=71E
M<R<@/3X@(FUI;B(L"@DG='1S7U]Q=65U97,G(#T^(")1=65U97,B+`H))W1T
M<U]?<75E=65S7VQI<W0G(#T^(")1=65U97,@;&ES="(L"@DG='1S7U]Q=65U
M92<@/3X@(E%U975E(BP*"2=T='-?7W%U975E7V%L<F5A9'E?97AI<W1S7U\G
M(#T^("=1=65U92`E,2!A;')E861Y(&5X:7-T<RXG+`H))W1T<U]?<F5M;W9E
M7V-A=',G(#T^(")296UO=F4@8V%T96=O<FEE<R(L"@DG='1S7U]R96UO=F5?
M<')I;W)I=&5S)R`]/B`B4F5M;W9E('!R:6]R:71I97,B+`H))W1T<U]?<F5M
M;W9E7W%U975E<R<@/3X@(E)E;6]V92!Q=65U97,B+`H))W1T<U]?<F5P;W)T
M97)?='EP95]A9&UI;B<@/3X@(D%D;6EN:7-T<F%T;W(B+`H))W1T<U]?<F5P
M;W)T97)?='EP95]C;&EE;G0G(#T^(")#;&EE;G0B+`H))W1T<U]?<F5P;W)T
M97)?='EP95]D;VUA:6XG(#T^(")$;VUA:6XB+`H))W1T<U]?<F5P;W)T97)?
M='EP95]E;6%I;"<@/3X@(D4M;6%I;"(L"@DG='1S7U]R97!O<G1E<E]T>7!E
M7VUA:6QN86UE)R`]/B`B36%I;"!N86UE(BP*"2=T='-?7W-E;&5C=%]C871S
M7W1O7W)E;6]V92<@/3X@(E-E;&5C="!C871E9V]R:65S('1O(&)E(')E;6]V
M960N(BP*"2=T='-?7W-E;&5C=%]E=F5N=%]T>7!E)R`]/B`B4V5L96-T(&5V
M96YT('1Y<&4@9F]R(&-O;6UE;G0@<W5B;6ES<VEO;B(L"@DG='1S7U]S96QE
M8W1?<')I;W)I=&5S7W1O7W)E;6]V92<@/3X@(E-E;&5C="!P<FEO<FET:65S
M('1O(&)E(')E;6]V960N(BP*"2=T='-?7W-E;&5C=%]Q=65U97-?=&]?<F5M
M;W9E)R`]/B`B4V5L96-T('%U975E<R!T;R!B92!R96UO=F5D+B(L"@DG='1S
M7U]S=&%R=%]T:6-K971?<W5B:B<@/3X@(E1I8VME="!S=6)J96-T(&UU<W0@
M<W1A<G0@=VET:"(L"@DG='1S7U]T979?8VQO<V5D)R`]/B`B0VQO<V5D(BP*
M"2=T='-?7W1E=E]C;VUM96YT960G(#T^(")#;VUM96YT960B+`H))W1T<U]?
M=&5V7V-R96%T960G(#T^(")#<F5A=&5D(BP*"2=T='-?7W1E=E]R96]P96YE
M9"<@/3X@(E)E;W!E;F5D(BP*"2=T='-?7W1I8VME="<@/3X@(E1I8VME="(L
M"@DG='1S7U]T:6-K971?8F]D>2<@/3X@(E1I8VME="!";V1Y(BP*"2=T='-?
M7W1I8VME=%]C871E9V]R>2<@/3X@(D-A=&5G;W)Y(BP*"2=T='-?7W1I8VME
M=%]I9"<@/3X@(DED(BP*"2=T='-?7W1I8VME=%]M86EL8VQ?;F%M92<@/3X@
M(E)E<&]R=&5R($YA;64B+`H))W1T<U]?=&EC:V5T7VUO9&EF:65D)R`]/B`B
M36]D:69I960B+`H))W1T<U]?=&EC:V5T7W%U975E)R`]/B`B475E=64B+`H)
M)W1T<U]?=&EC:V5T7W)E<&]R=&5R7W1Y<&4G(#T^(")297!O<G1E<B!4>7!E
M(BP*"2=T='-?7W1I8VME=%]S=&%T=7,G(#T^(")4:6-K970@4W1A='5S(BP*
M"2=T='-?7W1I8VME=%]S=6)J96-T)R`]/B`B5&EC:V5T(%-U8FIE8W0B+`H)
M)W1T<U]?=&EC:V5T7W1I=&QE:60G(#T^(")4:6-K970@)3$B+`H))W1T<U]?
M=&EC:V5T<R<@/3X@(E1I8VME=',B+`H))W1T<U]?=&EC:V5T<U]L:7-T)R`]
M/B`B5&EC:V5T<R(L"@DG='1S7U]T:6-K971S7W-U;6UA<GDG(#T^(")4:6-K
M971S(%-U;6UA<GDB+`H))W1T<U]?=&YE=E]C;&]S92<@/3X@(D-L;W-E('1I
M8VME="(L"@DG='1S7U]T;F5V7V-O;6UE;G0G(#T^(")#;VUM96YT('1I8VME
M="(L"@DG='1S7U]T;F5V7W)E;W!E;B<@/3X@(E)E;W!E;B(L"@DG='1S7U]T
M<U]A;&PG(#T^(")!;&PB+`H))W1T<U]?='-?86QL;W!E;F5D)R`]/B`B06QL
M(&]P96XB+`H))W1T<U]?='-?8VQO<V5D)R`]/B`B0VQO<V5D(BP*"2=T='-?
M7W1S7VYE=R<@/3X@(DYE=R(L"@DG='1S7U]T<U]R96]P96YE9"<@/3X@(E)E
M;W!E;F5D(BP*"2=T='-?7W1T<R<@/3X@(DAE;'`@1&5S:R(L"@DG='1S7V-A
M;G1?<&]S="<@/3X@(E1I8VME="!S=6)M:7-S:6]N(&ES(&1I<V%B;&5D(BP*
M"2=T='-?979?7VAI<W1O<GDG(#T^(")4:6-K970@2&ES=&]R>2(L"@DG='1S
M7VYO=%]A8W1I=F%T960G(#T^(")(96QP($1E<VL@:7,@;F]T(&%C=&EV871E
M9"XB+`H))W1T<U]T:6-K971?7V1O)R`]/B`B5&EC:V5T($5V96YT(BP*"2=T
M='-?=&EC:V5T7U]N97=?8V]M;65N="<@/3X@(DYE=R!#;VUM96YT(BP*"2=T
M='-?=&EC:V5T7U]P=6)L:6,G(#T^(")6:7-I8FQE('1O(&-L:65N="(L"@DG
M='1S7W1I8VME=%]?<')I=F%T92<@/3X@(DEN=FES:6)L92!T;R!C;&EE;G0B
M+`H))W1T<U]T:6-K971?9&]?<V5C=&EO;B<@/3X@(DYE=R!%=F5N="(L"@DG
M=FA?8F%S961?7VYO7V9R965?:7!?9F]R7W9H)R`]/B`B5&AE<F4@87)E(&YO
M('9A8V%N="!)4"!A9&1R97-S97,@9F]R('1H92!)4"UB87-E9"!V:7)T=6%L
M(&AO<W1I;F<N(%!L96%S92P@861D(&%N($E0(&%D9')E<W,N(BP*"@DG=FES
M:6)I;&ET>5]?861M:6YO;FQY)R`]/B`G061M:6X@3VYL>2<L"@DG=FES:6)I
M;&ET>5]?8G5T=&]N7W-E=',G(#T^("="=71T;VX@<V5T<R<L"@DG=FES:6)I
M;&ET>5]?8V]N=')O;"<@/3X@)T-L:6-K('1O(&-U<W1O;6EZ92!T:&ES(&-O
M;G1R;VPN)RP*"2=V:7-I8FEL:71Y7U]C=7)R96YT7V-U<W1O;6EZ871I;VYS
M)R`]/B`G0W5R<F5N="!C=7-T;VUI>F%T:6]N<R<L"@DG=FES:6)I;&ET>5]?
M8W5R<F5N=%]C=7-T;VUI>F%T:6]N<U]B96QO=R<@/3X@)U1H92!F;VQL;W=I
M;F<@8G5T=&]N<R!H879E(&-U<W1O;2!S971T:6YG<RX@0VQI8VL@=&AE;2!T
M;R!C:&%N9V4@=&AE<V4@<V5T=&EN9W,N)RP*"2=V:7-I8FEL:71Y7U]C=7)R
M96YT7V-U<W1O;6EZ871I;VYS7V9O<FUS)R`]/B`G4V]M92!C;VYT<F]L<R!O
M;B!F;W)M<R!H879E(&-U<W1O;2!S971T:6YG<RXG+`H))W9I<VEB:6QI='E?
M7V-U<W1O;6EZ871I;VY?9F]O=&YO=&4G(#T^("=#;&EC:R!/2R!T;R!F:6YI
M<V@@8W5S=&]M:7IA=&EO;B!O9B!T:&ES('-C<F5E;BXG+`H))W9I<VEB:6QI
M='E?7V1E9F%U;'0G(#T^("=$969A=6QT)RP*"2=V:7-I8FEL:71Y7U]E>'!O
M<G1?;F]T92<@/3X@(E1H92!C=7-T;VUI>F%T:6]N('-E='1I;F=S('EO=2!M
M861E(&%R92!A8F]U="!T;R!B92!E>'!O<G1E9"X@02!S:&5L;"!S8W)I<'0@
M=VEL;"!N;W<@8F4@9&]W;FQO861E9"!T;R!Y;W5R(&-O;7!U=&5R+B!4;R!A
M<'!L>2!T:&5S92!S971T:6YG<R!T;R!A;F]T:&5R(%!L97-K('-E<G9E<BP@
M;W9E<G=R:71I;F<@86YY(&5X:7-T:6YG(&EN=&5R9F%C92!M86YA9V5M96YT
M('-E='1I;F=S+"!P;&5A<V4@=7!L;V%D(&%N9"!E>&5C=71E('1H92!S8W)I
M<'0@=&AE<F4N7&Y<;E!L96%S92!N;W1E('1H870L(&EF('EO=2!H879E(&UA
M9&4@86YY(&-H86YG97,@;VX@=&AI<R!S8W)E96X@8G5T(&AA=F5N)W0@>65T
M(&-L:6-K960@3TLL('1H92!D871A(&5X<&]R=&5D('=I;&P@;F]T(&EN8VQU
M9&4@>6]U<B!L871E<W0@8VAA;F=E<RXB+`H))W9I<VEB:6QI='E?7V9O<FU?
M8V]N=')O;'-?<F5S970G(#T^("=!;&P@8V]N=')O;',@;VX@9F]R;7,@=VEL
M;"!B92!R97-E="!T;R!D969A=6QT('-E='1I;F=S)RP*"2=V:7-I8FEL:71Y
M7U]H:61E)R`]/B`G2&ED92<L"@DG=FES:6)I;&ET>5]?:&ED95]D:7-A8FQE
M9"<@/3X@)TAI9&4@86QL(&=R87EE9"!O=70@8G5T=&]N<R!B>2!D969A=6QT
M)RP*"2=V:7-I8FEL:71Y7U]H:61E7W5N879A:6QA8FQE7VQI;6ET<R<@/3X@
M)TAI9&4@9G)O;2!U<V5R<R!T:&4@;&EM:70@;6%N86=E;65N=`IC;VYT<F]L
M<R!T:&5Y(&%R92!N;W0@86QL;W=E9"!T;R!O<&5R871E)RP*"2=V:7-I8FEL
M:71Y7U]H:61E7W5N879A:6QA8FQE7W!E<FUI<W-I;VYS)R`]/B`G2&ED92!F
M<F]M('5S97)S('1H92!P97)M:7-S:6]N"FUA;F%G96UE;G0@8V]N=')O;',@
M=&AE>2!A<F4@;F]T(&%L;&]W960@=&\@;W!E<F%T92<L"@DG=FES:6)I;&ET
M>5]?;F]?8W5R<F5N=%]C=7-T;VUI>F%T:6]N<R<@/3X@)T%L;"!B=71T;VYS
M(&]N(%!L97-K('-C<F5E;G,@:&%V92!D969A=6QT('-E='1I;F=S+B<L"@DG
M=FES:6)I;&ET>5]?<F5S971?86QL)R`]/B`G4F5S970@86QL('1O(&1E9F%U
M;'0G+`H))W9I<VEB:6QI='E?7W)E<V5T7W-C<F5E;B<@/3X@)U)E<W1O<F4@
M;W)I9VEN86P@;&%Y;W5T(&]F('1H:7,@<V-R965N)RP*"2=V:7-I8FEL:71Y
M7U]R;V]T7V]V97)R:61E7W!A<G-E7V5R<F]R)R`]/B`G5&AE<F4@:7,@82!S
M>6YT87@@97)R;W(@:6X@9FEL92`E,2!I;B!L:6YE("4R(2<L"@DG=FES:6)I
M;&ET>5]?<V-R965N7W1I=&QE)R`]/B`G26YT97)F86-E(&UA;F%G96UE;G0G
M+`H))W9I<VEB:6QI='E?7W-E=%]C97)T7W!U8VAA<VEN9R<@/3X@)TAI9&4@
M8G5T=&]N<R!F;W(@8V5R=&EF:6-A=&4@<'5R8VAA<VEN9R<L"@DG=FES:6)I
M;&ET>5]?<V5T7V1O;6%I;E]R96=I<W1R871I;VXG(#T^("=(:61E(&)U='1O
M;G,@9F]R(&1O;6%I;B!R96=I<W1R871I;VXG+`H))W9I<VEB:6QI='E?7W-E
M=%]E>'1R87,G(#T^("=(:61E(&)U='1O;G,@9F]R(&5X=')A('-E<G9I8V5S
M)RP*"2=V:7-I8FEL:71Y7U]S971?;6%I;%]B;W5N8V4G(#T^("=(:61E(&-O
M;G1R;VQS(&9O<B!B;W5N8V4@;65S<V%G97,@9F]R(&YO;BUE>&ES=&5N="!M
M86EL(&%D9')E<W-E<R<L"@DG=FES:6)I;&ET>5]?<VAO=R<@/3X@)U-H;W<G
M+`H))W9I<VEB:6QI='E?7W-H;W=?=&]O;&)A<B<@/3X@)U-H;W<@26YT97)F
M86-E(&UA;F%G96UE;G0@=&]O;&)A<B<L"@DG=FES:6)I;&ET>5]?<W1A;F1B
M>5]F;V]T;F]T92<@/3X@)T-L:6-K('1O(&-U<W1O;6EZ92!C;VYT<F]L<R!O
M;B!T:&ES('-C<F5E;BXG+`H))W9I<VEB:6QI='E?7W-T86YD8GE?9F]O=&YO
M=&5?;F]C;VYT<F]L<R<@/3X@)U1H97)E(&%R92!N;R!C=7-T;VUI>F%B;&4@
M8V]N=')O;',@;VX@=&AI<R!S8W)E96XN)RP*"2=I;G1E<F9A8V5?<')E9F5R
M96YC97,G(#T^("=);G1E<F9A8V4@<')E9F5R96YC97,G+`H))VET;7!L7U]L
M:7-T7W1I=&QE)R`]/B`G26YT97)F86-E('1E;7!L871E<R!M86YA9V5M96YT
M)RP*"2=P8E]?:6YT97)F86-E7W1E;7!L871E<R<@/3X@)TEN=&5R9F%C92!M
M86YA9V5M96YT)RP*"2=B=%]I;G1E<F9A8V5?=&5M<&QA=&5?861D)R`]/B`G
M061D($EN=&5R9F%C92!496UP;&%T92<L"@DG:71M<&Q?7VQI<W1?;&5G96YD
M)R`]/B`G26YT97)F86-E('1E;7!L871E<R<L"@DG:71M<&Q?7VQI<W1?;F%M
M92<@/3X@)TEN=&5R9F%C92!T96UP;&%T92!N86UE)RP*"2=I=&UP;%]?;&ES
M=%]U<V%G92<@/3X@)U5S86=E)RP*"2=I=&UP;%]?;&ES=%]H96%D97(G(#T^
M("=);G1E<F9A8V4@=&5M<&QA=&5S)RP*"2=I=&UP;%]?<V5L96-T7W1E;7!L
M871E<U]T;U]R96UO=F4G(#T^("=396QE8W0@=&AE(&EN=&5R9F%C92!T96UP
M;&%T97,@=&\@8F4@<F5M;W9E9"XG+`H))VET;7!L7U]S96QE8W1?=&5M<&QA
M=&5?=&]?;6%K95]D969A=6QT)R`]/B`G4V5L96-T(&%N(&EN=&5R9F%C92!T
M96UP;&%T92!T;R!M86ME(&ET(&1E9F%U;'0N)RP*"2=I=&UP;%]?;F%M92<@
M/3X@)TEN=&5R9F%C92!T96UP;&%T92!N86UE)RP*"2=B=%]S:&]W7VET;7!L
M7W1O;VQB87(G(#T^("=3:&]W(%1O;VQB87(G+`H))VET;7!L7U]U<&QO861?
M=&ET;&4G(#T^("=5<&QO860@:6YT97)F86-E('1E;7!L871E)RP*"2=I=&UP
M;%]?=7!L;V%D7VQE9V5N9"<@/3X@)U5P;&]A9"!I;G1E<F9A8V4@=&5M<&QA
M=&4G+`H))VET;7!L7U]F:6QE7VYA;64G(#T^("=0871H('1O(&EN=&5R9F%C
M92!T96UP;&%T92!F:6QE)RP*"2=I=&UP;%]?:6YV86QI9%]V86QU97,G(#T^
M("=);G9A;&ED('9A;'5E<R<L"@DG:71M<&Q?7V%L<F5A9'E?97AI<W0G(#T^
M("=);G1E<F9A8V4@=&5M<&QA=&4@=VET:"!N86UE("(E,2(@86QR96%D>2!E
M>&ES=',N)RP*"2=I=&UP;%]?=7!L;V%D7VEN=F%L:61?='EP92<@/3X@)TYO
M="!S=7!P;W)T960@9FEL92!T>7!E+B<L"@DG:71M<&Q?7WAM;%]L;V%D7V9A
M:6QE9"<@/3X@)UA-3"!F:6QE(&ES(&EN('1H92!W<F]N9R!F;W)M870N)RP*
M"2=I=&UP;%]?961I=%]T:71L92<@/3X@)T5D:70@:6YT97)F86-E('1E;7!L
M871E("4Q)RP*"2=I=&UP;%]?861D7W1I=&QE)R`]/B`G061D(&YE=R!I;G1E
M<F9A8V4@=&5M<&QA=&4G+`H))VET;7!L7U]C;%]L:7-T7V9O<E\G(#T^("=#
M;&EE;G1S('5S:6YG("4Q(&EN=&5R9F%C92!T96UP;&%T92<L"@DG:71M<&Q?
M7V-L7VQI<W1?861D)R`]/B`G4V5L96-T('1H92!C;&EE;G1S('=H;R!S:&]U
M;&0@=7-E('1H:7,@:6YT97)F86-E('1E;7!L871E)RP*"2=I=&UP;%]?<F5M
M;W9E7W1I=&QE)R`]/B`G5&AE(&9O;&QO=VEN9R!I;G1E<F9A8V4@=&5M<&QA
M=&5S('=I;&P@8F4@<F5M;W9E9#HG+`H))VET;7!L7U]R96UO=F5?8VQI96YT
M<R<@/3X@)U1H92!F;VQL;W=I;F<@8VQI96YT<R!W:6QL(&YO(&QO;F=E<B!U
M<V4@=&AI<R!I;G1E<F9A8V4@8W5S=&]M:7IA=&EO;B!T96UP;&%T93HG+`H)
M)W!B7U]I;G1E<F9A8V5?8VQI96YT<R<@/3X@)T-L:65N=',@=7-I;F<@)3$G
M+`H*"2=W96)A;&EZ97)?<')E9F5R96YC97-?7W1I=&QE)R`]/B`G5V5B(%-T
M871I<W1I8W,@4')E9F5R96YC97,G+`H))W=E8F%L:7IE<E]P<F5F97)E;F-E
M<U]?=&%B7VAI9&1E;E]R969E<G)E<G,G(#T^("=(:61D96X@4F5F97)R97)S
M)RP*"2=W96)A;&EZ97)?<')E9F5R96YC97-?7W1A8E]G<F]U<%]R969E<G)E
M<G,G(#T^("='<F]U<&5D(%)E9F5R<F5R<R<L"@H))W=E8F%L:7IE<E]H:61D
M96Y?<F5F97)R97)?7V5D:71?=&ET;&4G(#T^("=(:61D96X@16YT<GD@4')O
M<&5R=&EE<R<L"@DG=V5B86QI>F5R7VAI9&1E;E]R969E<G)E<E]?961I=%]L
M96=E;F0G(#T^("=(:61D96X@16YT<FEE<R<L"@DG=V5B86QI>F5R7VAI9&1E
M;E]R969E<G)E<E]?<F5F97)R97)?='EP92<@/3X@)T5N=')Y('1Y<&4G+`H)
M)W=E8F%L:7IE<E]H:61D96Y?<F5F97)R97)?7W)E9F5R<F5R)R`]/B`G4F5F
M97)R97(G+`H))W=E8F%L:7IE<E]H:61D96Y?<F5F97)R97)?7VQI<W1?:&5A
M9&5R)R`]/B`G2&ED9&5N(%)E9F5R<F5R<R<L"@DG=V5B86QI>F5R7VAI9&1E
M;E]R969E<G)E<E]?;&ES=%]L96=E;F0G(#T^("=(:61D96X@4F5F97)R97)S
M)RP*"2=W96)A;&EZ97)?:&ED9&5N7W)E9F5R<F5R7U]R969E<G)E<E]D:7)E
M8W1?<F5Q=65S="<@/3X@)T1I<F5C="!R97%U97-T)RP*"2=W96)A;&EZ97)?
M:&ED9&5N7W)E9F5R<F5R7U]R969E<G)E<E]C=7-T;VU?<F5F97)R97(G(#T^
M("=2969E<G)E<B<L"@DG=V5B86QI>F5R7VAI9&1E;E]R969E<G)E<E]?<F5M
M;W9E7V5M<'1Y7W-E;&5C=&EO;B<@/3X@)TYO(&5N=')I97,@<V5L96-T960G
M+`H))W=E8F%L:7IE<E]H:61D96Y?<F5F97)R97)?7W)E;6]V95]T:71L92<@
M/3X@)U1H92!F;VQL;W=I;F<@<F5F97)R97)S('=I;&P@;F\@;&]N9V5R(&)E
M(&AI9&1E;CHG+`H))W=E8F%L:7IE<E]H:61D96Y?<F5F97)R97)?7V%L<F5A
M9'E?97AI<W0G(#T^("=3=6-H(&5N=')Y(&%L<F5A9'D@97AI<W1S+B<L"@H)
M)W=E8F%L:7IE<E]G<F]U<%]R969E<G)E<E]?;&ES=%]H96%D97(G(#T^("='
M<F]U<"!2969E<G)E<G,G+`H))W=E8F%L:7IE<E]G<F]U<%]R969E<G)E<E]?
M;&ES=%]L96=E;F0G(#T^("='<F]U<"!2969E<G)E<G,G+`H))W=E8F%L:7IE
M<E]G<F]U<%]R969E<G)E<E]?961I=%]T:71L92<@/3X@)U)E9F5R<F5R($=R
M;W5P(%!R;W!E<G1I97,G+`H))W=E8F%L:7IE<E]G<F]U<%]R969E<G)E<E]?
M961I=%]L96=E;F0G(#T^("=2969E<G)E<B!'<F]U<"!0<F]P97)T:65S)RP*
M"2=W96)A;&EZ97)?9W)O=7!?<F5F97)R97)?7V=R;W5P)R`]/B`G1W)O=7`G
M+`H))W=E8F%L:7IE<E]G<F]U<%]R969E<G)E<E]?<F5F97)R97(G(#T^("=2
M969E<G)E<B<L"@DG=V5B86QI>F5R7V=R;W5P7W)E9F5R<F5R7U]A;')E861Y
M7V5X:7-T)R`]/B`G02!G<F]U<"!R969E<G)E<B!W:71H('-U8V@@;F%M92!A
M;')E861Y(&5X:7-T<RXG+`H))W=E8F%L:7IE<E]G<F]U<%]R969E<G)E<E]?
M<F5M;W9E7V5M<'1Y7W-E;&5C=&EO;B<@/3X@)TYO(')E9F5R<F5R<R!S96QE
M8W1E9"<L"@DG=V5B86QI>F5R7V=R;W5P7W)E9F5R<F5R7U]R96UO=F5?=&ET
M;&4G(#T^("=4:&4@9F]L;&]W:6YG(')E9F5R<F5R('-I=&5S('=I;&P@8F4@
M=6YG<F]U<&5D.B<L"@H))W=E8E]A<'!S7U]D;VUA:6Y?;&EM:71?97AC965D
M960G(#T^(")5;F%B;&4@=&\@861D(&YE=R!*879A(&%P<&QI8V%T:6]N.B!D
M;VUA:6X@;&EM:70@:7,@97AC965D960B+`H))W=E8E]A<'!S7U]H879E7VYO
M7W!E<FUI<W-I;VYS)R`]/B`B56YA8FQE('1O(&UA;F%G92!*879A(&%P<&QI
M8V%T:6]N<SH@8VQI96YT(&]R(&1O;6%I;B!L979E;"!U<V5R(&1O97,@;F]T
M(&AA=F4@=&AE(&%P<')O<')I871E('!E<FUI<W-I;VX@;W(@9&]M86EN(&ES
M(&YO="!A8W1I=F4N(BP*"2=W96)?87!P<U]?;VYL>5]W87)?9FEL92<@/3X@
M(D]N;'D@+G=A<B!F:6QE<R!C86X@8F4@:6YS=&%L;&5D(&%S(&$@2F%V82!A
M<'!L:6-A=&EO;BXB+`H))W=E8E]A<'!S7U]R96UO=F5?=V5B87!P<U]O;E]D
M;VTG(#T^(")4:&4@9F]L;&]W:6YG($IA=F$@87!P;&EC871I;VYS(&9O<B!D
M;VUA:6X@)3(@;W=N960@8GD@8VQI96YT("4Q('=I;&P@8F4@<F5M;W9E9#HB
M+`H))W=E8E]A<'!S7U]S96QE8W1?=V%R7V9I;&4G(#T^(")396QE8W0@2F%V
M82!A<'!L:6-A=&EO;B!F:6QE+B(L"@DG=V5B7V%P<'-?7W-E;&5C=%]W96)A
M<'!S7W1O7W)E;6]V92<@/3X@(E-E;&5C="!T:&4@2F%V82!A<'!L:6-A=&EO
M;G,@=&\@8F4@<F5M;W9E9"XB+`H))W=E8E]A<'!S7U]T:71L92<@/3X@(DIA
M=F$@87!P;&EC871I;VYS(&9O<B!D;VUA:6X@)3$B+`H))W=E8E]A<'!S7U]A
M9&1?=&ET;&4G(#T^(")!9&1I;F<@3F5W($IA=F$@07!P;&EC871I;VXB+`H)
M)W=E8E]A<'!S7U]T;VUC871?;6%Y7V)E7VYO=%]W;W)K)R`]/B`B4&]S<VEB
M;&4@<F5A<V]N("T@5&]M8V%T('-E<G9I8V4@:7,@;F]T(&-U<G)E;G1L>2!R
M=6YN:6YG(&]N('1H92!S97)V97(N(BP*"2=W96)?87!P<U]?=&]M8V%T7W-T
M871U<R<@/3X@(E1O;6-A="!S=&%T=7,B+`H))W=E8E]A<'!S7U]U;F%B;&5?
M=&]?<W1A<G1?=V5B87!P)R`]/B`B56YA8FQE('1O('-T87)T('5P($IA=F$@
M87!P;&EC871I;VXZ("4Q(BP*"2=W96)?87!P<U]?=6YA8FQE7W1O7V1O=VY?
M=V5B87!P)R`]/B`B56YA8FQE('1O('-H=70@9&]W;B!*879A(&%P<&QI8V%T
M:6]N.B`E,2(L"@DG=V5B7V%P<'-?7W5P;&]A9%]W87)?9FEL92<@/3X@(E5P
M;&]A9"!705(@9FEL92(L"@DG=V5B7V%P<'-?7W=A<E]F:6QE)R`]/B`B5T%2
M(&9I;&4B+`H))W=E8E]A<'!S7U]W96)?87!P7V-O=6QD;G1?;F%M961?;6%N
M86=E<B<@/3X@(D%N(&%P<&QI8V%T:6]N(&-A;FYO="!B92!N86UE9"!A<R!M
M86YA9V5R(BP*"2=W96)?87!P<U]?=V5B7V%P<%]F:6QE;F%M95]I;G9A;&ED
M)R`]/B`B07!P;&EC871I;VX@9FEL96YA;64@:7,@:6YV86QI9"X@57-E(&]N
M;'D@86QP:&%N=6UE<FEC(&-H87)A8W1E<G,L(&1O="!A;F0@:'EP:&5N('-Y
M;6)O;',N(BP*"2=W96)?87!P<U]?=V5B87!P7V5X:7-T<R<@/3X@(D$@2F%V
M82!A<'!L:6-A=&EO;B!W:71H('-U8V@@;F%M92!A;')E861Y(&5X:7-T<RXB
M+`H*"2=W=5]?861D:71I;VYA;%]F96%T=7)E<R<@/3X@(D%D9&ET:6]N86P@
M9F5A='5R97,B+`H))W=U7U]A=%]D;VUA:6YS7W1E>'0G(#T^(")%;F%B;&4@
M=V5B=7-E<D`E,2!A8V-E<W,@9F]R;6%T(BP*"2=W=5]?96YT97)?=V5B7W5S
M97)?;F%M92<@/3X@(D5N=&5R(&YE=R!W96(@=7-E<B!N86UE+B(L"@DG=W5?
M7VYE=U]W=2<@/3X@(D%D9"!N97<@=V5B('5S97(@;V8@9&]M86EN(#QB/B4Q
M/"]B/B(L"@DG=W5?7W)E;6]V95]W=5]O;E]D;VTG(#T^(")4:&4@9F]L;&]W
M:6YG('=E8B!U<V5R<R!O9B!D;VUA:6X@)3$@=VEL;"!B92!R96UO=F5D.B(L
M"@DG=W5?7W)E;6]V95]W=5]O;E]D;VU?;V9?8VPG(#T^(")4:&4@9F]L;&]W
M:6YG('=E8B!U<V5R<R!O9B!D;VUA:6X@)3(@;W=N960@8GD@8VQI96YT("4Q
M('=I;&P@8F4@<F5M;W9E9#HB+`H))W=U7U]S96QE8W1?=W5?9F]R7W)E;6]V
M92<@/3X@(E-E;&5C="!T:&4@=V5B('5S97)S('1O(&)E(')E;6]V960N(BP*
M"2=W=5]?=6YA8FQE7V-R96%T92<@/3X@(E5N86)L92!T;R!C<F5A=&4@=V5B
M('5S97(Z("4Q(BP*"2=W=5]?=6YA8FQE7W)E;6]V95]W=2<@/3X@(E5N86)L
M92!T;R!R96UO=F4@=V5B('5S97)S.B`E,2(L"@DG=W5?7W=E8E]U<V5R<U]D
M;VUA:6XG(#T^(")796(@=7-E<G,@;V8@9&]M86EN("4Q(BP*"2=W=5]?=W5?
M:61?=6YD969I;F5D)R`]/B`B5V5B('5S97(@:60@:7,@=6YD969I;F5D+B(L
M"@DG=W5?7W=U7VYA;64G(#T^(")796(@=7-E<B!N86UE(BP*"2=W=5]E9&ET
M7U]D:7-K7W%U;W1A)R`]/B`B1&ES:R!Q=6]T82(L"@DG=W5?961I=%]?:6YV
M86QI9%]P87-S)R`]/B`B4&%S<W=O<F0@:7,@:6YV86QI9"XB+`H))W=U7V5D
M:71?7VEN=F%L:61?<75O=&$G(#T^(")4:&4@<W!E8VEF:65D(&1I<VL@<W!A
M8V4@<75O=&$@=F%L=64@:7,@:6YV86QI9"X@4&QE87-E+"!E;G1E<B!A('!O
M<VET:79E(&EN=&5G97(N(BP*"2=W=5]E9&ET7U]N;W1?8W)E871E7W!A<W,G
M(#T^(")4:&ES(&%C=&EO;B!W:6QL(&YO="!C<F5A=&4@82!P87-S=V]R9"!F
M;W(@=&AE(&YE=R!W96(@=7-E<BY<;E=I=&AO=70@<&%S<W=O<F0@=&AE('5S
M97(@=VEL;"!N;W0@8F4@86)L92!T;R!L;V<@:6XN(BP*"2=W=5]E9&ET7U]P
M87-S=V1?9F]R7W=U)R`]/B`B4')O<&5R=&EE<R!O9B!W96(@=7-E<B`@)3$B
M+`H))W=U7V5D:71?7W5N86)L95]U<&1A=&4G(#T^(")5;F%B;&4@=&\@=7!D
M871E('1H92!W96(@=7-E<B!P<F]P97)T>3H@)3$B+`H*"2=D87-H8F]A<F1?
M7V)O;VMM87)K7V)U='1O;E]T:71L95]F879O<FET95]E9&ET)PD)/3X@)T5D
M:70@1F%V;W)I=&4G+`H))V1A<VAB;V%R9%]?8F]O:VUA<FM?8G5T=&]N7W1I
M=&QE7V9A=F]R:71E7V%D9"<)"0D]/B`G061D('1O(&9A=F]R:71E<R<L"@DG
M9&%S:&)O87)D7U]B;V]K;6%R:U]B=71T;VY?=&ET;&5?<VAO<G1C=71?961I
M="<)"3T^("=%9&ET(%-H;W)T8W5T)RP*"2=D87-H8F]A<F1?7V)O;VMM87)K
M7V)U='1O;E]T:71L95]S:&]R=&-U=%]A9&0G"0D)/3X@)T-R96%T92!S:&]R
M=&-U="<L"@H))V1A<VAB;V%R9%]?8F]O:VUA<FM?8G5T=&]N7V1E<V-R:7!T
M:6]N7V9A=F]R:71E7V5D:70G"3T^("=%9&ET('!R;W!E<G1I97,@;V8@<VAO
M<G1C=70@=&\@(B4Q(BXG+`H))V1A<VAB;V%R9%]?8F]O:VUA<FM?8G5T=&]N
M7V1E<V-R:7!T:6]N7V9A=F]R:71E7V%D9"<)/3X@)T%D9"`B)3$B('1O(&9A
M=F]R:71E<RXG+`H))V1A<VAB;V%R9%]?8F]O:VUA<FM?8G5T=&]N7V1E<V-R
M:7!T:6]N7W-H;W)T8W5T7V5D:70G"3T^("=%9&ET('!R;W!E<G1I97,@;V8@
M<VAO<G1C=70@=&\@(B4Q(BXG+`H))V1A<VAB;V%R9%]?8F]O:VUA<FM?8G5T
M=&]N7V1E<V-R:7!T:6]N7W-H;W)T8W5T7V%D9"<)/3X@)T-R96%T92!S:&]R
M=&-U="!T;R`B)3$B+B<L"@H))V1A<VAB;V%R9%]?8F]O:VUA<FM?=&ET;&5?
M9F%V;W)I=&5?961I="<)/3X@)T5D:71I;F<@4')O<&5R=&EE<R!O9B!3:&]R
M=&-U="!T;R`B)3$B)RP*"2=D87-H8F]A<F1?7V)O;VMM87)K7W1I=&QE7V9A
M=F]R:71E7V%D9"<)/3X@)T%D9&EN9R`B)3$B('1O($9A=F]R:71E<R<L"@DG
M9&%S:&)O87)D7U]B;V]K;6%R:U]T:71L95]S:&]R=&-U=%]E9&ET)PD]/B`G
M161I=&EN9R!0<F]P97)T:65S(&]F(%-H;W)T8W5T('1O("(E,2(G+`H))V1A
M<VAB;V%R9%]?8F]O:VUA<FM?=&ET;&5?<VAO<G1C=71?861D)PD]/B`G0W)E
M871I;F<@<VAO<G1C=70@=&\@(B4Q(B<L"@H))V1A<VAB;V%R9%]?<V5C=&EO
M;E]S:&]W7W1I=&QE)PD)"0D]/B`G4F5S=&]R92<L"@DG9&%S:&)O87)D7U]S
M96-T:6]N7VAI9&5?=&ET;&4G"0D)"3T^("=-:6YI;6EZ92<L"@DG9&%S:&)O
M87)D7U]S:&]R=&-U=%]P<F]P97)T:65S7W1I=&QE)PD)/3X@)U-H;W)T8W5T
M(%!R;W!E<G1I97,G+`H))V1A<VAB;V%R9%]?<VAO<G1C=71?=&ET;&4G"0D)
M"0D]/B`G5&ET;&4G+`H))V1A<VAB;V%R9%]?<VAO<G1C=71?=&ET;&5?9&5F
M875L="<)"0D]/B`G57-E(&1E9F%U;'0G+`H))V1A<VAB;V%R9%]?<VAO<G1C
M=71?9&5S8W)I<'1I;VXG"0D)/3X@)T1E<V-R:7!T:6]N)RP*"2=D87-H8F]A
M<F1?7W-H;W)T8W5T7V1E<V-R:7!T:6]N7V1E9F%U;'0G"3T^("=5<V4@9&5F
M875L="<L"@DG9&%S:&)O87)D7U]S:&]R=&-U=%]T:71L95]I;G9A;&ED7W9A
M;'5E)PD]/B`G5&AE('1I=&QE('-H;W5L9"!C;VYT86EN(&9R;VT@,2!T;R`R
M-34@8VAA<F%C=&5R<RXG+`H))V1A<VAB;V%R9%]?<VAO<G1C=71?9&5S8W)I
M<'1I;VY?:6YV86QI9%]V86QU92<)/3X@)U1H92!D97-C<FEP=&EO;B!S:&]U
M;&0@8V]N=&%I;B!F<F]M(#$@=&\@,C4U(&-H87)A8W1E<G,N)RP*"@DG9&%S
M:&)O87)D7U]P<F5S971S7V5X<&]R=%]F86EL960G"3T^("=%<G)O<B!O8V-U
M<G)E9"!D=7)I;F<@97AP;W)T:6YG('-E;&5C=&5D($1E<VMT;W`@<')E<V5T
M<SH@)3$G+`H))V1A<VAB;V%R9%]?<')E<V5T7V5R<F]R)PD)/3X@)T5R<F]R
M(&]C8W5R<F5D(&EN($1E<VMT;W`@<')E<V5T("(E,2(G+`H))V1A<VAB;V%R
M9%]?<')E<V5T7V5R<F]R7U\G"0D]/B`G17)R;W(@;V-C=7)R960@:6X@1&5S
M:W1O<"!P<F5S970@(B4Q(CH@)3(G+`H*"2=D87-H8F]A<F1?7W!R97-E=%]U
M<&QO861?9F%I;&5D)PD]/B`G17)R;W(@;V-C=7)R960@9'5R:6YG(&EM<&]R
M=&EN9R!$97-K=&]P('!R97-E=',@9G)O;2!F:6QE.B`E,2<L"@DG9&%S:&)O
M87)D7U]P<F5S971?<F5P;&%C95]N86UE7V-O;F9L:6-T)PD]/B`G4')E<V5T
M<R!W:71H('1H92!N86UE<R!C;VYT86EN960@:6X@=&AE(&9I;&4@86QR96%D
M>2!E>&ES="!I;B!0;&5S:RX@5&\@<F5P;&%C92!E>&ES=&EN9R!P<F5S971S
M('=I=&@@=&AE('5P;&]A9&5D(&]N97,L('-E;&5C="!T:&4@;W9E<G=R:71I
M;F<@8V]N9FER;6%T:6]N(&-H96-K8F]X+B<L"@DG9&%S:&)O87)D7U]P<F5S
M971?=7!L;V%D7W)E<&QA8V5?8V]N9FER;6%T:6]N)R`]/B`G3W9E<G=R:71E
M('!R97-E=',@=VET:"!T:&4@<V%M92!N86UE(&%N9"!T>7!E+B<L"@H))V1A
M<VAB;V%R9%]?<')E<V5T7W5P;&]A9%]T:71L92<)/3X@)U5P;&]A9&EN9R!$
M97-K=&]P(%!R97-E=',G+`H))V1A<VAB;V%R9%]?<')E<V5T7W5P;&]A9%]L
M96=E;F0G"3T^("=5<&QO860@1&5S:W1O<"!P<F5S971S)RP*"2=D87-H8F]A
M<F1?7W!R97-E=%]U<&QO861?9FEL96YA;64G"3T^("=$97-K=&]P('!R97-E
M=',@9FEL92!L;V-A=&EO;B<L"@H))V1A<VAB;V%R9%]?<')E<V5T7VYA;65?
M97AI<W1S)PD)/3X@)T1E<VMT;W`@4')E<V5T("!W:71H(&YA;64@)3$@86QR
M96%D>2!E>&ES=',N)RP*"2=?7V1A<VAB;V%R9%]P<F5S970G"0D)"3T^("=$
M97-K=&]P('!R97-E="<L"@DG9&%S:&)O87)D7U]P<F5S971S7W!R:79A=&4G
M"0D]/B`G0W5S=&]M:7IE9"!$97-K=&]P)RP*"@DG9&%S:&)O87)D7U]P<F5S
M971S7VQI<W1?;&5G96YD)PD]/B`G1&5S:W1O<"!P<F5S971S)RP*"2=D87-H
M8F]A<F1?7W!R97-E='-?;&ES=%]I=&5M)PD)/3X@)T1E<VMT;W`@<')E<V5T
M<R<L"@DG9&%S:&)O87)D7U]P<F5S971S7VQI<W1?8V]P>2<)"3T^("=#;W!Y
M($1E<VMT;W`@<')E<V5T)RP*"2=D87-H8F]A<F1?7W!R97-E='-?='EP92<)
M"3T^("=4)RP*"2=D87-H8F]A<F1?7W!R97-E=%]T>7!E)PD)/3X@)U1Y<&4G
M+`H))V1A<VAB;V%R9%]?<')E<V5T7W1Y<&5?861M:6XG"0D]/B`G061M:6YI
M<W1R871O<EPG<R!D97-K=&]P('!R97-E="<L"@DG9&%S:&)O87)D7U]P<F5S
M971?='EP95]C;&EE;G0G"0D]/B`G0VQI96YT7"=S(&1E<VMT;W`@<')E<V5T
M)RP*"2=D87-H8F]A<F1?7W!R97-E=%]T>7!E7V1O;6%I;B<)"3T^("=$;VUA
M:6X@;W=N97)<)W,@9&5S:W1O<"!P<F5S970G+`H))V1A<VAB;V%R9%]?<')E
M<V5T<U]N86UE)PD)/3X@)T1E<VMT;W`@<')E<V5T(&YA;64G+`H))V1A<VAB
M;V%R9%]?<')E<V5T7VYA;64G("`)"3T^("=.86UE)RP*"2=D87-H8F]A<F1?
M7W!R97-E=%]D969A=6QT)PD)/3X@)T1E9F%U;'0G+`H))V1A<VAB;V%R9%]?
M<')E<V5T7V1I<V%B;&5D7W1A<VMS)PD]/B`G079A:6QA8FQE('1A<VMS)RP*
M"2=D87-H8F]A<F1?7W!R97-E=%]E;F%B;&5D7W1A<VMS)PD]/B`G4V5L96-T
M960@=&%S:W,G+`H*"2=D87-H8F]A<F1?7V1E;&5T95]P<F5S971?8W5S=&]M
M7W!R97-E="<@/3X@)T-U<W1O;2!$97-K=&]P('!R97-E="!C86YN;W0@8F4@
M<F5M;W9E9"XG+`H))V1A<VAB;V%R9%]?9&5L971E7W!R97-E=%]P<FEV871E
M7W!R97-E="<@/3X@)U!R:79A=&4@1&5S:W1O<"!P<F5S970@8V%N;F]T(&)E
M(')E;6]V960N)RP*"2=D87-H8F]A<F1?7V1E;&5T95]P<F5S971?9&5F875L
M=%]P<F5S970G(#T^("=$969A=6QT($1E<VMT;W`@<')E<V5T(&-A;FYO="!B
M92!R96UO=F5D+B<L"@H))V1A<VAB;V%R9%]?=W)O;F=?<')E<V5T7W1Y<&4G
M"0D]/B`G26YC;VUP871I8FQE($1E<VMT;W`@<')E<V5T('1Y<&4N)RP*"@DG
M<&)?7V1A<VAB;V%R9"<)"0D)/3X@)T1E<VMT;W`G+`H*"2=D87-H8F]A<F1?
M7W!R97-E='-?>&UL7VQO861?97)R;W(G"3T^("=5;F%B;&4@=&\@:6UP;W)T
M(&1E<VMT;W`@<')E<V5T<SH@5&AE('5P;&]A9&5D(%A-3"!F:6QE(&-O;G1A
M:6YS(&$@<WEN=&%X(&5R<F]R+B<L"@DG9&%S:&)O87)D7U]P<F5S971S7WAM
M;%]V86QI9&%T:6]N7V5R<F]R)PD]/B`G56YA8FQE('1O(&EM<&]R="!D97-K
M=&]P('!R97-E=',Z(%1H92!U<&QO861E9"!834P@9FEL92!C;VYT86EN<R!A
M('-Y;G1A>"!E<G)O<BXG+`H))V1A<VAB;V%R9%]?<')E<V5T<U]X;6Q?=F5R
M<VEO;E]E<G)O<B<)"3T^("=5;F%B;&4@=&\@:6UP;W)T(&1E<VMT;W`@<')E
M<V5T<SH@5&AE('5P;&]A9&5D(%A-3"!F:6QE('=A<R!C<F5A=&5D(&)Y(%!L
M97-K('9E<G-I;VX@)3(@=VAI8V@@:7,@96%R;&EE<B!T:&%N('1H92!C=7)R
M96YT('9E<G-I;VX@*"4Q*2XG+`H*"2=D87-H8F]A<F1?7W!R97-E=%]R96UO
M=F5?96UP='E?<V5L96-T:6]N)PD]/B`G3F\@<')E<V5T<R!S96QE8W1E9"X@
M4V5L96-T(&1E<VMT;W`@<')E<V5T<R!Y;W4@=V%N="!T;R!R96UO=F4N)RP*
M"2=D87-H8F]A<F1?7W!R97-E=%]R96UO=F5?=&ET;&4G"0D)/3X@)U1H92!F
M;VQL;W=I;F<@1&5S:W1O<"!P<F5S971S('=I;&P@8F4@<F5M;W9E9#HG+`H*
M"2=D87-H8F]A<F1?7W!R97-E=%]E9&ET7W1I=&QE)PD)"0D]/B`G161I=&EN
M9R!$97-K=&]P(%!R97-E="<L"@DG9&%S:&)O87)D7U]D87-H8F]A<F1?8W5S
M=&]M:7IE7W1I=&QE)PD)/3X@)T-U<W1O;6EZ:6YG($1E<VMT;W`G+`H*"2=S
M97)V97)?:6YT97)F86-E7U]P86=E7W1I=&QE)PD]/B`G4V5R=F5R($EN=&5R
M9F%C92!0<F5F97)E;F-E<R<L"@DG<V5R=F5R7VEN=&5R9F%C95]?=&%B<U]L
M;V-A;&5S)R`]/B`G3&]C86QE<R<L"@DG<V5R=F5R7VEN=&5R9F%C95]?=&%B
M<U]S:VEN<R<)(#T^("=3:VEN<R<L"@DG<V5R=F5R7VEN=&5R9F%C95]?=&%B
M<U]D87-H8F]A<F1?<')E<V5T<R<@/3X@)T1E<VMT;W`@4')E<V5T<R<L"@DG
M<V5R=F5R7VEN=&5R9F%C95]?=&%B<U]I;G1E<F9A8V5?=&5M<&QA=&5S)R`]
M/B`G26YT97)F86-E(%1E;7!L871E<R<L"@DG8G1?<V5R=F5R7VEN=&5R9F%C
M92<)/3X@)TEN=&5R9F%C92!0<F5F97)E;F-E<R<L"@DG<&)?7W-E<G9E<E]I
M;G1E<F9A8V4G"3T^("=);G1E<F9A8V4@4')E9F5R96YC97,G+`H*"2=B=%]W
M:7IA<F1?;F5X="<@/3X@)TYE>'0@/CXG+`H))V)T7W=I>F%R9%]P<F5V)R`]
M/B`G/#P@0F%C:R<L"@H))U]?;&EM:71?97AC965D961?;6%X7V1O;5]S97)V
M97(G"0D)"3T^("=397)V97(@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R
M(&]F(&1O;6%I;G,N(%!L96%S92!C;VYT86-T('1O('1H92!S97)V97(@861M
M:6YI<W1R871O<BXG+`H))U]?;&EM:71?97AC965D961?;6%X7W-U8F1O;5]S
M97)V97(G"0D)/3X@)U-E<G9E<B!R96%C:&5D('1H92!L:6UI="!O;B!N=6UB
M97(@;V8@<W5B9&]M86EN<RX@4&QE87-E(&-O;G1A8W0@=&\@=&AE('-E<G9E
M<B!A9&UI;FES=')A=&]R+B<L"@DG7U]L:6UI=%]E>&-E961E9%]M87A?9&]M
M86EN7V%L:6%S97-?<V5R=F5R)PD]/B`G4V5R=F5R(')E86-H960@=&AE(&QI
M;6ET(&]N(&YU;6)E<B!O9B!D;VUA:6X@86QI87-E<RX@4&QE87-E(&-O;G1A
M8W0@=&\@=&AE('-E<G9E<B!A9&UI;FES=')A=&]R+B<L"@DG7U]L:6UI=%]E
M>&-E961E9%]M87A?=W5?<V5R=F5R)PD)"0D]/B`G4V5R=F5R(')E86-H960@
M=&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!W96(@=7-E<B`@86-C;W5N=',N(%!L
M96%S92!C;VYT86-T('1O('1H92!S97)V97(@861M:6YI<W1R871O<BXG+`H)
M)U]?;&EM:71?97AC965D961?;6%X7VUN7W-E<G9E<B<)"0D)/3X@)U-E<G9E
M<B!R96%C:&5D('1H92!L:6UI="!O;B!N=6UB97(@;V8@92UM86EL(&YA;65S
M+B!0;&5A<V4@8V]N=&%C="!T;R!T:&4@<V5R=F5R(&%D;6EN:7-T<F%T;W(N
M)RP*"@DG7U]L:6UI=%]E>&-E961E9%]M87A?8VQ?=7-E<F%D;6EN)PD)/3X@
M)UEO=2!H879E(')E86-H960@=&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!C;&EE
M;G0@86-C;W5N=',@9&5F:6YE9"!B>2!Y;W5R(&QI8V5N<V4@:V5Y+B!!;&QO
M=V5D.B`E,BX@57-E9#H@)3,N(%)E<75I<F5D.B`E-2<L"@DG7U]L:6UI=%]E
M>&-E961E9%]M87A?9&]M7W5S97)A9&UI;B<)"3T^("=9;W4@:&%V92!R96%C
M:&5D('1H92!L:6UI="!O;B!N=6UB97(@;V8@9&]M86EN<R!D969I;F5D(&)Y
M('EO=7(@;&EC96YS92!K97DN($%L;&]W960Z("4R+B!5<V5D.B`E,RX@4F5Q
M=6ER960Z("4U+B<L"@DG7U]L:6UI=%]E>&-E961E9%]M87A?<W5B9&]M7W5S
M97)A9&UI;B<)"3T^("=9;W4@:&%V92!R96%C:&5D('1H92!L:6UI="!O;B!N
M=6UB97(@;V8@<W5B9&]M86EN<R!D969I;F5D(&)Y('EO=7(@;&EC96YS92!K
M97DN($%L;&]W960Z("4R+B!5<V5D.B`E,RX@4F5Q=6ER960Z("4U+B<L"@DG
M7U]L:6UI=%]E>&-E961E9%]D:7-K7W-P86-E7W5S97)A9&UI;B<)"3T^("=9
M;W4@:&%V92!N;R!F<F5E(&1I<VL@<W!A8V4@;&5F="X@5&]T86P@86UO=6YT
M(&]F(&%V86EL86)L92!D:7-K('-P86-E.B`E,BX@57-E9#H@)3,N(%)E<75I
M<F5D.B`E-2XG+`H))U]?;&EM:71?97AC965D961?;6%X7W=U7W5S97)A9&UI
M;B<)"0D]/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R
M(&]F('=E8B!U<V5R("!A8V-O=6YT<R!D969I;F5D(&)Y('EO=7(@;&EC96YS
M92!K97DN($%L;&]W960Z("4R+B!5<V5D.B`E,RX@4F5Q=6ER960Z("4U+B<L
M"@DG7U]L:6UI=%]E>&-E961E9%]M87A?9&)?=7-E<F%D;6EN)PD)"3T^("=9
M;W4@:&%V92!R96%C:&5D('1H92!L:6UI="!O;B!N=6UB97(@;V8@9&%T86)A
M<V5S(&1E9FEN960@8GD@>6]U<B!L:6-E;G-E(&ME>2X@06QL;W=E9#H@)3(N
M(%5S960Z("4S+B!297%U:7)E9#H@)34N)RP*"2=?7VQI;6ET7V5X8V5E9&5D
M7VUA>%]B;WA?=7-E<F%D;6EN)PD)"3T^("=9;W4@:&%V92!R96%C:&5D('1H
M92!L:6UI="!O;B!N=6UB97(@;V8@;6%I;&)O>&5S(&1E9FEN960@8GD@>6]U
M<B!L:6-E;G-E(&ME>2X@06QL;W=E9#H@)3(N(%5S960Z("4S+B!297%U:7)E
M9#H@)34N)RP*"2=?7VQI;6ET7V5X8V5E9&5D7VUA>%]M;E]U<V5R861M:6XG
M"0D]/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R(&]F
M(&4M;6%I;"!N86UE<R!D969I;F5D(&)Y('EO=7(@;&EC96YS92!K97DN($%L
M;&]W960Z("4R+B!5<V5D.B`E,RX@4F5Q=6ER960Z("4U+B<L"@DG7U]L:6UI
M=%]E>&-E961E9%]M87A?<F5D:7)?=7-E<F%D;6EN)PD)/3X@)UEO=2!H879E
M(')E86-H960@=&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!M86EL(&9O=V%R9&5R
M<R`H<F5D:7)E8W1S*2!D969I;F5D(&)Y('EO=7(@;&EC96YS92!K97DN($%L
M;&]W960Z("4R+B!5<V5D.B`E,RX@4F5Q=6ER960Z("4U+B<L"@DG7U]L:6UI
M=%]E>&-E961E9%]M87A?;6=?=7-E<F%D;6EN)PD)"3T^("=9;W4@:&%V92!R
M96%C:&5D('1H92!L:6UI="!O;B!N=6UB97(@;V8@;6%I;"!G<F]U<',@*&4M
M;6%I;"!F;W)W87)D97)S('=I=&@@;75L=&EP;&4@<F5C:7!I96YT<RD@9&5F
M:6YE9"!B>2!Y;W5R(&QI8V5N<V4@:V5Y+B!!;&QO=V5D.B`E,BX@57-E9#H@
M)3,N(%)E<75I<F5D.B`E-2XG+`H))U]?;&EM:71?97AC965D961?;6%X7W)E
M<W!?=7-E<F%D;6EN)PD)/3X@)UEO=2!H879E(')E86-H960@=&AE(&QI;6ET
M(&]N(&YU;6)E<B!O9B`@875T;W)E<W!O;F1E<G,@9&5F:6YE9"!B>2!Y;W5R
M(&QI8V5N<V4@:V5Y+B!!;&QO=V5D.B`E,BX@57-E9#H@)3,N(%)E<75I<F5D
M.B`E-2XG+`H))U]?;&EM:71?97AC965D961?;6%X7VUA:6QL:7-T<U]U<V5R
M861M:6XG"3T^("=9;W4@:&%V92!R96%C:&5D('1H92!L:6UI="!O;B!N=6UB
M97(@;V8@;6%I;&EN9R!L:7-T<R!D969I;F5D(&)Y('EO=7(@;&EC96YS92!K
M97DN($%L;&]W960Z("4R+B!5<V5D.B`E,RX@4F5Q=6ER960Z("4U+B<L"@DG
M7U]L:6UI=%]E>&-E961E9%]M87A?=V5B87!P<U]U<V5R861M:6XG"3T^("=9
M;W4@:&%V92!R96%C:&5D('1H92!L:6UI="!O;B!N=6UB97(@;V8@2F%V82!A
M<'!L:6-A=&EO;G,@9&5F:6YE9"!B>2!Y;W5R(&QI8V5N<V4@:V5Y+B!!;&QO
M=V5D.B`E,BX@26YS=&%L;&5D.B`E,RX@4F5Q=6ER960Z("4U+B<L"@H))U]?
M;&EM:71?97AC965D961?;6%X7V1O;5]U<V5R8VQI96YT)PD)/3X@)UEO=2!H
M879E(')E86-H960@=&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!D;VUA:6YS+B`@
M06QL;W=E9#H@)3(N(%5S960Z("4S+B!297%U:7)E9#H@)34N)RP*"2=?7VQI
M;6ET7V5X8V5E9&5D7VUA>%]S=6)D;VU?=7-E<F-L:65N="<)/3X@)UEO=2!H
M879E(')E86-H960@=&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!S=6)D;VUA:6YS
M("X@06QL;W=E9#H@)3(N(%5S960Z("4S+B!297%U:7)E9#H@)34N)RP*"2=?
M7VQI;6ET7V5X8V5E9&5D7V1I<VM?<W!A8V5?=7-E<F-L:65N="<)/3X@)UEO
M=2!H879E(')E86-H960@=&AE(&1I<VL@<W!A8V4@=7-A9V4@;&EM:70N("!!
M;&QO=V5D.B`E,BX@57-E9#H@)3,N(%)E<75I<F5D.B`E-2XG+`H))U]?;&EM
M:71?97AC965D961?;6%X7W1R869F:6-?=7-E<F-L:65N="<)/3X@)UEO=2!H
M879E(')E86-H960@=&AE(&QI;6ET(&]N(&%M;W5N="!O9B!B86YD=VED=&@N
M($%L;&]W960Z("4R+B!5<V5D.B`E,RXG+`H))U]?;&EM:71?97AC965D961?
M;6%X7W=U7W5S97)C;&EE;G0G"0D]/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@
M;&EM:70@;VX@;G5M8F5R(&]F('=E8B!U<V5R(&%C8V]U;G1S+B!!;&QO=V5D
M.B`E,BX@57-E9#H@)3,N(%)E<75I<F5D.B`E-2XG+`H))U]?;&EM:71?97AC
M965D961?;6%X7V1B7W5S97)C;&EE;G0G"0D]/B`G66]U(&AA=F4@<F5A8VAE
M9"!T:&4@;&EM:70@;VX@;G5M8F5R(&]F(&1A=&%B87-E<R`N($%L;&]W960Z
M("4R+B!5<V5D.B`E,RX@4F5Q=6ER960Z("4U+B<L"@DG7U]L:6UI=%]E>&-E
M961E9%]M87A?8F]X7W5S97)C;&EE;G0G"0D]/B`G66]U(&AA=F4@<F5A8VAE
M9"!T:&4@;&EM:70@;VX@;G5M8F5R(&]F(&UA:6QB;WAE<R`N($%L;&]W960Z
M("4R+B!5<V5D.B`E,RX@4F5Q=6ER960Z("4U+B<L"@DG7U]L:6UI=%]E>&-E
M961E9%]M87A?<F5D:7)?=7-E<F-L:65N="<)"3T^("=9;W4@:&%V92!R96%C
M:&5D('1H92!L:6UI="!O;B!N=6UB97(@;V8@;6%I;"!F;W)W87)D97)S("AR
M961I<F5C=',I+B!!;&QO=V5D.B`E,BX@57-E9#H@)3,N(%)E<75I<F5D.B`E
M-2XG+`H))U]?;&EM:71?97AC965D961?;6%X7VUG7W5S97)C;&EE;G0G"0D]
M/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R(&]F(&UA
M:6P@9F]R=V%R9&5R<R!W:71H(&UU;'1I<&QE(')E8VEP:65N=',@*&UA:6P@
M9W)O=7!S*2X@06QL;W=E9#H@)3(N(%5S960Z("4S+B!297%U:7)E9#H@)34N
M)RP*"2=?7VQI;6ET7V5X8V5E9&5D7VUA>%]R97-P7W5S97)C;&EE;G0G"0D]
M/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R(&]F("!A
M=71O<F5S<&]N9&5R<RX@06QL;W=E9#H@)3(N(%5S960Z("4S+B!297%U:7)E
M9#H@)34N)RP*"2=?7VQI;6ET7V5X8V5E9&5D7VUA>%]M86EL;&ES='-?=7-E
M<F-L:65N="<)/3X@)UEO=2!H879E(')E86-H960@=&AE(&QI;6ET(&]N(&YU
M;6)E<B!O9B!M86EL:6YG(&QI<W1S+B!!;&QO=V5D.B`E,BX@57-E9#H@)3,N
M(%)E<75I<F5D.B`E-2XG+`H))U]?;&EM:71?97AC965D961?;6%X7W=E8F%P
M<'-?=7-E<F-L:65N="<)/3X@)UEO=2!H879E(')E86-H960@=&AE(&QI;6ET
M(&]N(&YU;6)E<B!O9B!*879A(&%P<&QI8V%T:6]N<RX@06QL;W=E9#H@)3(N
M($EN<W1A;&QE9#H@)3,N(%)E<75I<F5D.B`E-2<L"@DG7U]L:6UI=%]E>&-E
M961E9%]E>'!I<F%T:6]N7W5S97)C;&EE;G0G"3T^("=9;W5R(&%C8V]U;G0@
M97AP:7)E9"!O;B`E,BXG+`H*"2=?7VQI;6ET7V5X8V5E9&5D7VUA>%]S=6)D
M;VU?=7-E<F1O;6%I;B<)/3X@)UEO=2!H879E(')E86-H960@=&AE(&QI;6ET
M(&]N(&YU;6)E<B!O9B!S=6)D;VUA:6YS("X@06QL;W=E9#H@)3(N(%5S960Z
M("4S+B!297%U:7)E9#H@)34N)RP*"2=?7VQI;6ET7V5X8V5E9&5D7V1I<VM?
M<W!A8V5?=7-E<F1O;6%I;B<)/3X@)UEO=2!H879E(')E86-H960@=&AE(&1I
M<VL@<W!A8V4@=7-A9V4@;&EM:70N("!!;&QO=V5D.B`E,BX@57-E9#H@)3,N
M(%)E<75I<F5D.B`E-2XG+`H))U]?;&EM:71?97AC965D961?;6%X7W1R869F
M:6-?=7-E<F1O;6%I;B<)/3X@)UEO=2!H879E(')E86-H960@=&AE(&QI;6ET
M(&]N(&%M;W5N="!O9B!B86YD=VED=&@N($%L;&]W960Z("4R+B!5<V5D.B`E
M,RXG+`H))U]?;&EM:71?97AC965D961?;6%X7W=U7W5S97)D;VUA:6XG"0D]
M/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R(&]F('=E
M8B!U<V5R(&%C8V]U;G1S+B!!;&QO=V5D.B`E,BX@57-E9#H@)3,N(%)E<75I
M<F5D.B`E-2XG+`H))U]?;&EM:71?97AC965D961?;6%X7V1B7W5S97)D;VUA
M:6XG"0D]/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R
M(&]F(&1A=&%B87-E<R`N($%L;&]W960Z("4R+B!5<V5D.B`E,RX@4F5Q=6ER
M960Z("4U+B<L"@DG7U]L:6UI=%]E>&-E961E9%]M87A?8F]X7W5S97)D;VUA
M:6XG"0D]/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R
M(&]F(&UA:6QB;WAE<R`N($%L;&]W960Z("4R+B!5<V5D.B`E,RX@4F5Q=6ER
M960Z("4U+B<L"@DG7U]L:6UI=%]E>&-E961E9%]M87A?<F5D:7)?=7-E<F1O
M;6%I;B<)"3T^("=9;W4@:&%V92!R96%C:&5D('1H92!L:6UI="!O;B!N=6UB
M97(@;V8@;6%I;"!F;W)W87)D97)S("AR961I<F5C=',I+B!!;&QO=V5D.B`E
M,BX@57-E9#H@)3,N(%)E<75I<F5D.B`E-2XG+`H))U]?;&EM:71?97AC965D
M961?;6%X7VUG7W5S97)D;VUA:6XG"0D]/B`G66]U(&AA=F4@<F5A8VAE9"!T
M:&4@;&EM:70@;VX@;G5M8F5R(&]F(&UA:6P@9F]R=V%R9&5R<R!W:71H(&UU
M;'1I<&QE(')E8VEP:65N=',@*&UA:6P@9W)O=7!S*2X@06QL;W=E9#H@)3(N
M(%5S960Z("4S+B!297%U:7)E9#H@)34N)RP*"2=?7VQI;6ET7V5X8V5E9&5D
M7VUA>%]R97-P7W5S97)D;VUA:6XG"0D]/B`G66]U(&AA=F4@<F5A8VAE9"!T
M:&4@;&EM:70@;VX@;G5M8F5R(&]F("!A=71O<F5S<&]N9&5R<RX@06QL;W=E
M9#H@)3(N(%5S960Z("4S+B!297%U:7)E9#H@)34N)RP*"2=?7VQI;6ET7V5X
M8V5E9&5D7VUA>%]M86EL;&ES='-?=7-E<F1O;6%I;B<)/3X@)UEO=2!H879E
M(')E86-H960@=&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!M86EL:6YG(&QI<W1S
M+B!!;&QO=V5D.B`E,BX@57-E9#H@)3,N(%)E<75I<F5D.B`E-2XG+`H))U]?
M;&EM:71?97AC965D961?;6%X7W=E8F%P<'-?=7-E<F1O;6%I;B<)/3X@)UEO
M=2!H879E(')E86-H960@=&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!*879A(&%P
M<&QI8V%T:6]N<RX@06QL;W=E9#H@)3(N($EN<W1A;&QE9#H@)3,N(%)E<75I
M<F5D.B`E-2<L"@DG7U]L:6UI=%]E>&-E961E9%]E>'!I<F%T:6]N7W5S97)D
M;VUA:6XG"3T^("=9;W5R(&%C8V]U;G0@97AP:7)E9"!O;B`E,BXG+`H*"@DG
M86-T:6]N;&]G7U]D8E]S97)V97(G(#T^("=$871A8F%S92!S97)V97(G+`H)
M)V1A<VAB;V%R9%]?<')E<V5T<U]S96QE8W1?=&]?9&]W;FQO860G(#T^("=.
M;R!D97-K=&]P('!R97-E=',@<V5L96-T960N(%!L96%S92!S96QE8W0@=&AE
M('!R97-E=',@>6]U('=A;G0@=&\@9&]W;FQO860N)RP*"2=M:6=R871I;VY?
M=7!L;V%D7V9O<FU?;65S)R`]/B`G57!L;V%D:6YG(&UI9W)A=&EO;B!A9V5N
M="!T;R!H;W-T("4Q+B<L"@DG;6EG<F%T:6]N7W5P;&]A9%]A9V5N=%]F86QS
M92<@/3X@)T9A:6QE9"!T;R!U<&QO860@=&AE(&UI9W)A=&EO;B!A9V5N="<L
M"@DG;6EG<F%T:6]N7W5P;&]A9%]A9V5N="<@/3X@)TUI9W)A=&EO;B!!9V5N
M="!5<&QO860G+`H))VUI9W)A=&EO;E]U<&QO861?86=E;G1?;VXG(#T^("=5
M<&QO861I;F<@36EG<F%T:6]N($%G96YT('1O("4Q)RP*"2=M:6=R871I;VY?
M:&]S=%]I;F9O)R`]/B`G26YF;W)M871I;VX@;VX@4V]U<F-E($AO<W0@)3$G
M+`H))VUI9W)A=&EO;E]G971?86-C;W5N=%]A;F1?9&]M86EN<R<@/3X@)U-E
M;&5C="!O8FIE8W1S('1H870@>6]U('=I<V@@=&\@;6EG<F%T92!F<F]M(&AO
M<W0@)3$G+`H))VUI9W)A=&EO;E]M97-S86=E7VQE9V5N9"<@/3X@)TEN9F]R
M;6%T:6]N)RP*"2=M:6=R871I;VY?:&]S=%]D971A:6QS)R`]/B`G2&]S="!D
M971A:6QS)RP*"2=M:6=R871I;VY?:&]S=%]I;F9O7V]S)R`]/B`G3W!E<F%T
M:6YG('-Y<W1E;2<L"@DG;6EG<F%T:6]N7VAO<W1?:6YF;U]L;V%D879G)R`]
M/B`G3&]A9"!A=F5R86=E(&]N('1H92!H;W-T)RP*"2=M:6=R871I;VY?:&]S
M=%]I;F9O7VAO<W1I;F=P;&%T9F]R;2<@/3X@)TAO<W1I;F<@<&QA=&9O<FTO
M=F5R<VEO;B<L"@DG;6EG<F%T:6]N7VAO<W1?:6YF;U]C;&EE;G1S)R`]/B`G
M3G5M8F5R(&]F(&-L:65N=',G+`H))VUI9W)A=&EO;E]H;W-T7VEN9F]?9&]M
M86EN<R<@/3X@)TYU;6)E<B!O9B!D;VUA:6YS)RP*"2=M:6=R871I;VY?:&]S
M=%]I;F9O7VAO<W0G(#T^("=397)V97(G+`H))VUI9W)A=&EO;E]G971?86-C
M;W5N=%]D;VUA:6Y?;65S)R`]/B`G1&]W;FQO861I;F<@82!L:7-T(&]F(&%C
M8V]U;G1S(&%N9"!D;VUA:6YS(&9R;VT@=&AE('-O=7)C92!H;W-T("4Q+B<L
M"@DG;6EG<F%T:6]N7VUA:6Y?9&]W;FQO860Q)R`]/B`B5')A;G-F97)R:6YG
M(&9I;&4Z("4Q7&Y3:7IE.B`E,EQN3&5F="!T;R!T<F%N<V9E<CH@)3,B+`H)
M)VUI9W)A=&EO;E]M86EN7V1O=VYL;V%D,B<@/3X@(DAO<W0Z("4Q7&Y4<F%N
M<V9E<G)E9#H@)3(@9FEL97,L("4S7&Y,969T.B`E-"!F:6QE<RP@)35<;E1R
M86YS9F5R('-P965D.B`E-B(L"@DG;6EG<F%T:6]N7W-E;&5C=%]A8V-O=6YT
M)R`]/B`G4V5L96-T('1H92!C;&EE;G0@86-C;W5N="<L"@DG;6EG<F%T:6]N
M7VEP7VUA<%]P86=E)R`]/B`G25`@;6%P<&EN9R!F;W(@;6EG<F%T:6YG(&1A
M=&$@9G)O;2`E,2<L"@DG;6EG<F%T:6]N7V1B7W-E<G9R95]M87!?<&%G92<@
M/3X@)T1A=&%B87-E('-E<G9E<G,@;6%P<&EN9R!F;W(@;6EG<F%T:6YG(&1A
M=&$@9G)O;2`E,2<L"@DG;6EG<F%T:6]N7V1B7W-E<G9R95]M87!?;&5G96YD
M)R`]/B`G1$(@<V5R=F5R<R!M87!P:6YG)RP*"2=M:6=R871I;VY?:7!?;6%P
M)R`]/B`G25`@36%P<&EN9R<L"@DG;6EG<F%T:6]N7VEP7VUA<%]A;&5R="<@
M/3X@)U!L96%S92!S<&5C:69Y(&UA<'!I;F<@9F]R(&%L;"!)4"!A9&1R97-S
M97,G+`H))VUI9W)A=&EO;E]S=&]P7W!A9V4G(#T^("=3=&]P(&UI9W)A=&EN
M9R!D871A(&9R;VT@:&]S="`E,2<L"@DG;6EG<F%T:6]N7W-T;W!?;65S<V%G
M92<@/3X@)U-T;W`@=&AE(&UI9W)A=&EO;B!P<F]C97-S)RP*"2=M:6=R871I
M;VY?9&5P;&]Y7VEN9F\Q)R`]/B`G1&5P;&]Y:6YG("4Q("4R)RP*"2=M:6=R
M871I;VY?9&5P;&]Y7VEN9F\R)R`]/B`B5&]T86P@86-C;W5N=',O;&5F="`E
M,2\E,EQN5&]T86P@9&]M86EN<R]L969T("4S+R4T7&XB+`H))VUI9W)A=&EO
M;E]N;W1I9GDG(#T^("=.;W1I9GD@=7-E<G,@=7!O;B!C<F5A=&EO;B!O9B!E
M86-H('-Y<W1E;2!O8FIE8W0G+`H))VUI9W)A=&EO;E]K965P7V%R8VAI=F5S
M)R`]/B`G2V5E<"!T:&4@=&5M<&]R87)Y(&9I;&5S)RP*"2=M:6=R871I;VY?
M<V5T=&EN9R<@/3X@)T1E<&QO>6UE;G0@4V5T=&EN9W,G+`H))VUI9W)A=&EO
M;E]S971T:6YG7VQE9R<@/3X@)T1E<&QO>6UE;G0@<V5T=&EN9W,G+`H))VUI
M9W)A=&EO;E]D97!L;WE?<')O9W)E<W,G(#T^("=$97!L;WEM96YT('!R;V=R
M97-S)RP*"2=M:6=R871I;VY?9&5P;&]Y7VEN9F\G(#T^("=$97!L;WEM96YT
M('!R;V=R97-S(&9O<B!H;W-T("4Q)RP*"2=M:6=R871I;VY?:&]S="<@/3X@
M)U-O=7)C92!H;W-T)RP*"2=M:6=R871I;VY?<&%S<W=O<F0G(#T^("=,;V=I
M;B!P87-S=V]R9"<L"@DG;6EG<F%T:6]N7W!L871F;W)M)R`]/B`G4V]U<F-E
M('!L871F;W)M)RP*"2=M:6=R871I;VY?=')A;G-L971E)R`]/B`G0V]N=F5R
M=&EN9R!D=6UP('1O(%!L97-K(&9O<FUA="<L"@DG;6EG<F%T:6]N7V%G96YT
M7W=A:70G(#T^("=786ET:6YG('1H92!R97-P;VYS92!F<F]M(&%G96YT)RP*
M"2=M:6=R871I;VY?96YD7V1E<&QO>5]I;F9O)R`]/B`G1&%T82!M:6=R871I
M;VX@9G)O;2!H;W-T("4Q(&AA<R!B965N(&-O;7!L971E9"XG+`H))VUI9W)A
M=&EO;E]D97!L;WE?9&5T86EL<R<@/3X@)T1E=&%I;',G+`H))VUI9W)A=&EO
M;E]W<F]N9U]A9V5N="<@/3X@)T%G96YT(&ES(&YO="!S=6ET86)L92!F;W(@
M=&AE(&=I=F5N(&AO<W0N)RP*"2=M:6=R871I;VY?<V5L96-T7W-O;64G(#T^
M("=396QE8W0@=&AE(&]B:F5C=',@=&\@;6EG<F%T92XG+`H))VUI9W)A=&EO
M;E]D;W=L;V%D)R`]/B`G1&]W;FQO861I;F<@8V]N=&5N="!F<F]M(&AO<W0@
M)3$G+`H))VUI9W)A=&EO;E]D;W=L;V%D7W!R;V=R97-S)R`]/B`G1&]W;FQO
M860@<')O9W)E<W,G+`H))VUI9W)A=&EO;E]D;W=L;V%D7V-U<G)E;G0G(#T^
M("=$;W=N;&]A9&EN9R!C=7)R96YT(&9I;&4G+`H))VUI9W)A=&EO;E]X;6Q?
M9&5S8R<@/3X@)T1O=VYL;V%D:6YG('1H92!D=6UP(&1E<V-R:7!T:6]N+B<L
M"@DG;6EG<F%T:6]N7VYO7V5R<F]R<R<@/3X@)U1H92!M:6=R871I;VX@:&%S
M(&)E96X@8V]M<&QE=&5D+B<L"@DG;6EG<F%T:6]N7W5N86)L95]G971?86-C
M;W5N=%]A;F1?9&]M86EN<R<@/3X@)U5N86)L92!T;R!R971R:65V92!A(&QI
M<W0@;V8@86-C;W5N=',@86YD(&1O;6%I;G,Z("<L"@DG;6EG<F%T:6]N7W5N
M86)L95]T<F%N<VQA=&4G(#T^("=5;F%B;&4@=&\@8V]N=F5R="!T:&4@9&%T
M82!T;R!0;&5S:R!F;W)M870Z("<L"@DG;6EG<F%T:6]N7W5N86)L95]D=6UP
M7W)E=')I979E)R`]/B`G1F%I;&5D('1O(')E=')I979E('1H92!D871A.B`G
M+`H))VUI9W)A=&EO;E]U;F%B;&5?87)C:&EV95]H;W-T)R`]/B`G56YA8FQE
M('1O(&-R96%T92!A(&1E<V-R:7!T:6]N(&9O<B!T:&4@;6EG<F%T960@;V)J
M96-T<SH@)RP*"2=M:6=R871I;VY?<V5L96-T7V%C8V]U;G1?<&%G92<@/3X@
M)U-E;&5C="!T:&4@8VQI96YT(&%C8V]U;G0@=&\@=VAI8V@@>6]U('=I<V@@
M=&\@;6EG<F%T92!T:&4@9&]M86EN<R<L"@DG;6EG<F%T:6]N7W5N86)L95]D
M97!L;WDG(#T^("=5;F%B;&4@=&\@9&5P;&]Y('1H92!M:6=R871E9"!O8FIE
M8W1S.B`G+`H))V)T7VUI9W)A=&EO;E]M;W)E)R`]/B`G36EG<F%T92!M;W)E
M)RP*"2=B=%]M:6=R871I;VY?8F5G:6XG(#T^("=&:6YI<V@G+`H))VUI9W)A
M=&EO;E]S96QE8W1?97AI<W1?:7`G(#T^("=396QE8W0@9&5S=&EN871I;VX@
M25`G+`H))VUI9W)A=&EO;E]S96QE8W1?97AI<W1?9&)?<V5R=F5R)R`]/B`G
M4V5L96-T(&1E<W1I;F%T:6]N($1"('-E<G9E<B<L"@DG;6EG<F%T:6]N7V1O
M;6%I;E]C;W5N="<@/3X@)TYU;6)E<B!O9B!D;VUA:6YS)RP*"2=M:6=R871I
M;VY?86-C;W5N="<@/3X@)T%C8V]U;G0G+`H))VUI9W)A=&EO;E]D96UO7W=A
M<B<@/3X@(E=A<FYI;F<A(%1H:7,@:7,@=&AE($UI9W)A=&EO;B!-86YA9V5R
M(&1E;6\N($YO(&%C8V]U;G1S(&%N9"!D;VUA:6YS('=I;&P@8F4@86-T=6%L
M;'D@;6EG<F%T960N(%QN4&QE87-E('-P96-I9GD@=&AE(&1E<VER960@=F%L
M=65S+B(L"@DG;6EG<F%T:6]N7V1O=VYL;V%D7VYO=%]S<&%C92<@/3X@)TYO
M="!E;F]U9V@@9&ES:R!S<&%C92$G+`H))V)T7VUI9W)A=&EO;E]I9VYO<F4G
M(#T^("=)9VYO<F4G+`H))V)T7VUI9W)A=&EO;E]R971R>2<@/3X@)U)E=')Y
M)RP*"2=M:6=R871I;VY?9'5M<%]A;&PG(#T^("=-:6=R871E(&%L;"!C;&EE
M;G1S(&%N9"!D;VUA:6YS)RP*"2=M:6=R871I;VY?9&5T86EL<R<@/3X@)TUI
M9W)A=&EO;B!D971A:6QS)RP*"2=M:6=R871I;VY?;&EM:71?97)R;W(G(#T^
M(")4:&4@;G5M8F5R(&]F('MT>7!E?2!Y;W4@87)E('1R>6EN9R!T;R!C<F5A
M=&4@=V]U;&0@;W9E<G)I9&4@=&AE(&QI;6ET<R!D969I;F5D(&)Y('1H92!L
M:6-E;G-E(&ME>2`M("4Q+EQN66]U(&-A;B!C<F5A=&4@;VYL>2`E,B![='EP
M97T@;6]R92XB+`H))VUI9W)A=&EO;E]I9&QE)R`]/B`G4')E<&%R:6YG(&9O
M<B!E>&5C=71I;VXG+`H))VUI9W)A=&EO;E]R96UO=F5?86=E;G0G(#T^("=2
M96UO=F4@86=E;G0G+`H))VUI9W)A=&EO;E]S=&]P7VQA8FQE)R`]/B`G4W1O
M<'!I;F<G+`H))VUI9W)A=&EO;E]R96UO=F5?87)C:&EV92<@/3X@)U)E;6]V
M92!T96UP;W)A<GD@9FEL97,G+`H))VUI9W)A=&EO;E]N;U]O8FIE8W0G(#T^
M("=4:&5R92!A<F4@;F\@;V)J96-T<R!F;W(@;6EG<F%T:6]N(&]N('1H92!R
M96UO=&4@:&]S="XG+`H))VUI9W)A=&EO;E]N;U]D;VUA:6XG(#T^("=.;R!D
M;VUA:6YS('=E<F4@9F]U;F0G+`H))V)T7VUI9W)A=&5?<VEN9VQE)R`]/B`G
M4VEN9VQE+4AO<W0@36EG<F%T:6]N)RP*"2=M:6=R871I;VY?8V]M<')E<W,G
M(#T^("=$871A(&-O;7!R97-S:6]N)RP*"2=M:6=R871I;VY?;6]D92<@/3X@
M)TUI9W)A=&EO;B!M;V1E)RP*"2=M:6=R871I;VY?9'5M<%]M97-S86=E,2<@
M/3X@(D-U<G)E;G1L>2!D=6UP:6YG('1H92!A8V-O=6YT.B`E,5QN0W5R<F5N
M="!D;VUA:6XZ("4R7&Y!8V-O=6YT<R!L969T('1O(&1U;7`Z("4S7&Y$;VUA
M:6YS(&QE9G0@=&\@9'5M<#H@)30B+`H))VUI9W)A=&EO;E]D=6UP7W!R;V=R
M97-S)R`]/B`G1'5M<&EN9R!P<F]G<F5S<R<L"@DG;6EG<F%T:6]N7V1U;7!?
M8W5R<F5N="<@/3X@)T1U;7!I;F<@9&%T82<L"@DG;6EG<F%T:6]N7V%G96YT
M7W!A=&@G(#T^("=$:7)E8W1O<GD@;VX@=&AE('-O=7)C92!H;W-T('=H97)E
M($UI9W)A=&EO;B!-86YA9V5R('=I;&P@<&QA8V4@86QL(&1A=&$@8F5F;W)E
M('1R86YS9F5R<FEN9R!T:&5M)RP*"2=M:6=R871I;VY?9'5M<%]N;V5X:7-T
M)R`]/B`G1F]R('1H92!S:6YG;&4M:&]S="!M:6=R871I;VXL('EO=2!S:&]U
M;&0@<&QA8V4@=&AE(&1U;7`@=&\@(B4Q(BXG+`H))VUI9W)A=&EO;E]S=61O
M7W!A<W-W;W)D)R`]/B`G4W5D;R!P87-S=V]R9"<L"@DG;6EG<F%T:6]N7W-U
M9&]?<F]O="<@/3X@)W)O;W0G+`H))VUI9W)A=&EO;E]S=61O7V]T:&5R<R<@
M/3X@)V]T:&5R)RP*"2=M:6=R871I;VY?8F%C:V5N9%]C<F%S:%]O9F9?;65S
M<R<@/3X@)TUI9W)A=&EO;B!-86YA9V5R(&)A8VL@96YD('1E<FUI;F%T960@
M8F5C875S92!O9B!U;F5X<&5C=&5D(&5R<F]R+B!0;&5A<V4@8V]N=&%C="!S
M=7!P;W)T+B<L"@DG;6EG<F%T:6]N7W-I;F=L95]N;W1E7VUE<W,G(#T^("=5
M<V4@=&AI<R!F96%T=7)E('1O(&EM<&]R="!T:&4@9&%T82!C<F5A=&5D(&)Y
M('1H92!M:6=R871I;VX@86=E;G0N)RP*"2=M:6=R871I;VY?<VEN9VQE7VUO
M9&4G(#T^("=$871A(&EM<&]R="<L"@DG;6EG<F%T:6]N7VYO<FUA;%]M;V1E
M)R`]/B`G36EG<F%T:6]N)RP*"2=M:6=R871I;VY?<V5L96-T7V-L:65N="<@
M/3X@)U-E;&5C="!C;&EE;G0G+`H))VUI9W)A=&EO;E]F<F]M)R`]/B`G("AM
M:6=R871I;VX@9G)O;2!H;W-T("4Q*2<L"@DG;6EG<F%T:6]N7W-E;&5C=%]M
M;V1E)R`]/B`G4V5L96-T(&UI9W)A=&EO;B!M;V1E)RP*"2=M:6=R871I;VY?
M<V5L96-T7V-L:65N=%]I;E]L:7-T)R`]/B`G5&\@<V5L96-T(&$@8VQI96YT
M+"!C;&EC:R!O;B!T:&4@8VQI96YT(&YA;64G+`H))VUI9W)A=&EO;E]S:6YG
M;&5?:6YF;R<@/3X@)TEM<&]R=&EN9R!D871A(&9R;VT@)3$G+`H))VUI9W)A
M=&EO;E]D=6UP7VEN9F\G(#T^("=$=6UP(&1E=&%I;',G+`H))VUI9W)A=&EO
M;E]S96QE8W1?<VEN9VQE7VUO9&4G(#T^("=396QE8W0@:6UP;W)T(&UO9&4G
M+`H))VUI9W)A=&EO;E]S96QE8W1?<VEN9VQE7VET96TG(#T^("=396QE8W0@
M;V)J96-T<R!F;W(@:6UP;W)T)RP*"2=M:6=R871I;VY?<VEN9VQE7V%L;"<@
M/3X@)TEM<&]R="!A;&PG+`H))VUI9W)A=&EO;E]A9&1?9G)E95]I<"<@/3X@
M)SQB/DYO=&4Z/"]B/B!">2!S96QE8W1I;F<@82!V86-A;G0@25`@861D<F5S
M<R!Y;W4@=VEL;"!A9&0@:70@=&\@8VQI96YT7"=S($E0('!O;VPN)RP*"2=M
M:6=R871I;VY?:7!?=F%C86YT)R`]/B`G5F%C86YT)RP*"2=M:6=R871I;VY?
M<VEN9VQE7W1R86YS)R`]/B`G0V]N=F5R=&EN9R!D871A('1O(&YA=&EV92!0
M;&5S:R!F;W)M870G+`H))VUI9W)A=&EO;E]S96QE8W1?:7`G(#T^("=396QE
M8W0@25`G+`H))VUI9W)A=&EO;E]N;U]C:&5C:U]S<&%C92<@/3X@)T1O(&YO
M="!C:&5C:R!F;W(@86UO=6YT(&]F(&9R964@9&ES:R!S<&%C92!D=7)I;F<@
M;6EG<F%T:6]N)RP*"2=M:6=R871I;VY?9G-?:6YF;U]M;W5N='!O:6YT)R`]
M/B`G36]U;G0@<&]I;G0G+`H))VUI9W)A=&EO;E]F<U]I;F9O7W1Y<&4G(#T^
M("=4>7!E)RP*"2=M:6=R871I;VY?9G-?:6YF;U]T;W1A;"<@/3X@)U1O=&%L
M)RP*"2=M:6=R871I;VY?9G-?:6YF;U]F<F5E)R`]/B`G1G)E92<L"@DG;6EG
M<F%T:6]N7V9S7VQE9V5N="<@/3X@)U-O=7)C92!H;W-T('!A<G1I=&EO;B<L
M"@DG;6EG<F%T:6]N7V9S7W5S86=E)R`]/B`G57-A9V4G+`H))VUI9W)A=&EO
M;E]L;V-A;%]F<U]L96=E;G0G(#T^("=7;W)K:6YG(&1I<F5C=&]R>2<L"@DG
M;6EG<F%T:6]N7W-T;W)A9V5?9&ER)R`]/B`G1&ER96-T;W)Y(&]N('1H:7,@
M<V5R=F5R('1O('=H:6-H(&%L;"!D871A('=I;&P@8F4@=')A;G-F97)R960G
M+`H))VUI9W)A=&EO;E]U<&QO861?<V-O=6YT)R`]/B`G4F5T<FEE=FEN9R!I
M;F9O<FUA=&EO;B!O;B!T:&4@:&]S="`E,2!I<R!I;B!P<F]C97-S)RP*"2=M
M:6=R871I;VY?=7!L;V%D7W-C;W5N=%]O;B<@/3X@)U)E=')I979I;F<@:6YF
M;W)M871I;VX@;VX@=&AE(&AO<W0@)3$G+`H))VUI9W)A=&EO;E]S;W5R8V5?
M<&QA=&9O<FTG(#T^("=-:6=R871I;VX@<&QA=&9O<FTG+`H))VUI9W)A=&EO
M;E]P;&%T9F]R;5]D971E8U]F86EL)R`]/B`G075T;VUA=&EC(&1E=&5C=&EO
M;B!O9B!H;W-T:6YG('!L871F;W)M(&9A:6QE9"X@4&QE87-E('-E;&5C="!P
M;&%T9F]R;2!M86YU86QL>2!F<F]M('1H92!C;VUB;R!B;W@@8F5L;W<N)RP*
M"2=M:6=R871I;VY?<V5L96-T7W!L871F;W)M)R`]/B`G+2T@4V5L96-T('!L
M871F;W)M("TM)RP*"2=M:6=R871I;VY?;F]?8VQI96YT)R`]/B`G66]U(&AA
M=F4@;F\@8VQI96YT(&%C8V]U;G1S(&]N('1H92!D97-T:6YA=&EO;B!H;W-T
M('1O(&UI9W)A=&4@9&]M86EN<R!T;R<L"@DG;6EG<F%T:6]N7W1E;7!L871E
M7VQE9V5N9"<@/3X@)T-R96%T:6]N(&]F(&1O;6%I;G,@8GD@=&5M<&QA=&4G
M+`H))VUI9W)A=&EO;E]C;&EE;G1?=&5M<&QA=&4G(#T^("=5<V4@82!T96UP
M;&%T92!F;W(@8W)E871I;F<@8VQI96YT(&%C8V]U;G1S)RP*"2=M:6=R871I
M;VY?9&]M86EN7W1E;7!L871E)R`]/B`G57-E(&$@=&5M<&QA=&4@9F]R(&-R
M96%T:6YG(&1O;6%I;G,G+`H))VUI9W)A=&EO;E]R96%C:&5D7VQI;6ET)R`]
M/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R(&]F("4Q
M+B<L"@DG;6EG<F%T:6]N7W)E86-H961?;&EM:71?8VQI96YT)R`]/B`G8VQI
M96YT(&%C8V]U;G1S)RP*"2=M:6=R871I;VY?<F5A8VAE9%]L:6UI=%]D;VUA
M:6XG(#T^("=D;VUA:6YS)RP*"2=M:6=R871I;VY?<V5S<VEO;E]L:7-T)R`]
M/B`G4&QE<VL@36EG<F%T:6]N($UA;F%G97(G+`H))VUI9W)A=&EO;E]C=7)R
M96YT7VUI9W)A=&EO;G-?;&ES="<@/3X@)T-U<G)E;G0@;6EG<F%T:6]N<R<L
M"@DG;6EG<F%T:6]N7V-U<G)E;G1?;6EG<F%T:6]N)R`]/B`G0W5R<F5N="!M
M:6=R871I;VYS)RP*"2=B=%]M:6=R871I;VY?<V5S<VEO;E]A9&0G(#T^("=3
M=&%R="!A(&YE=R!M:6=R871I;VXG+`H))VUI9W)A=&EO;E]S97-S:6]N7VQI
M<W1?7V]B:F5C=',G(#T^("=-:6=R871I;F<@;V)J96-T<R<L"@DG;6EG<F%T
M:6]N7W-E<W-I;VY?;&ES=%]?<W1A<G1?9&%T92<@/3X@)U-T87)T(&1A=&4G
M+`H))VUI9W)A=&EO;E]S97-S:6]N7VQI<W1?7V5L87!S960G(#T^("=%;&%P
M<V5D('1I;64G+`H))VUI9W)A=&EO;E]S97-S:6]N7VQI<W1?7W!R;V=R97-S
M)R`]/B`G4')O9W)E<W,G+`H))VUI9W)A=&EO;E]S97-S:6]N7VQI<W1?7VYO
M=%]S96QE8W1E9"<@/3X@)TYO="!Y970@<V5L96-T960G+`H))VUI9W)A=&EO
M;E]S=&%T95]D97-C7V9A:6QE9"<@/3X@)T9A:6QE9"!M:6=R871I;VXG+`H)
M)VUI9W)A=&EO;E]S=&%T95]D97-C7V%W86ET:6YG7W-T87)T)R`]/B`G5V%I
M=&EN9R!F;W(@82!S=&%R="<L"@DG;6EG<F%T:6]N7W-T871E7V1E<V-?87=A
M:71I;F=?86=E;G1?<&%R86TG(#T^("=0;&5A<V4@<W!E8VEF>2!M:6=R871I
M;VX@<&%R86UE=&5R<R<L"@DG;6EG<F%T:6]N7W-T871E7V1E<V-?<V5L96-T
M7V]B:F5C="<@/3X@)U-E;&5C="!T:&4@8G5S:6YE<W,@;V)J96-T<R!T;R!M
M:6=R871E)RP*"2=M:6=R871I;VY?<W1A=&5?9&5S8U]S96QE8W1?8VQI96YT
M)R`]/B`G4V5L96-T('1H92!C;&EE;G0@9F]R(&UI9W)A=&EO;B<L"@DG;6EG
M<F%T:6]N7W-T871E7V1E<V-?:7!?;6%P)R`]/B`G25`@;6%P<&EN9R<L"@DG
M;6EG<F%T:6]N7W-T871E7V1E<V-?9&)?<V5R=F5R7VUA<"<@/3X@)T1"('-E
M<G9E<B!M87!P:6YG)RP*"2=M:6=R871I;VY?<W1A=&5?9&5S8U]A<&E?;6EG
M<F%T:6]N)R`]/B`G36EG<F%T:6]N(&UA9&4@8GD@;65A;G,@;V8@4E!#)RP*
M"2=M:6=R871I;VY?<W1A=&5?9&5S8U]D=6UP:6YG)R`]/B`G4F5T<FEE=FEN
M9R!D871A(&9R;VT@<F5M;W1E(&AO<W0G+`H))VUI9W)A=&EO;E]S97-S:6]N
M7V9A:6QE9"<@/3X@)TUI9W)A=&EO;B!F<F]M(&AO<W0@)3$@9F%I;&5D)RP*
M"2=M:6=R871I;VY?8V]M<&QE=&5D)R`]/B`G5&AE(&UI9W)A=&EO;B!H87,@
M8F5E;B!C;VUP;&5T960N)RP*"2=M:6=R871I;VY?;F]?861M:6Y?9&]M7W1E
M;7!L871E)R`]/B`G5&AE<F4@87)E(&YO(&%D;6EN:7-T<F%T;W)<)W,@9&]M
M86EN('1E;7!L871E<R<L"@DG;6EG<F%T:6]N7V5R<F]R7V9I;&4G(#T^("=&
M:6QE)RP*"2=M:6=R871I;VY?97)R;W)?;&EN92<@/3X@)TQI;F4G+`H))VUI
M9W)A=&EO;E]E<G)O<E]C;VYT97AT)R`]/B`G0V]N=&5X="<L"@DG;6EG<F%T
M:6]N7V5R<F]R7W1E>'0G(#T^("=497AT)RP*"2=M:6=R871I;VY?97)R;W)?
M='EP92<@/3X@)U1Y<&4G+`H))VUI9W)A=&EO;E]E<G)O<E]N86UE)R`]/B`G
M3F%M92<L"@DG;6EG<F%T:6]N7VYO7VEP7V%V86EL86)L92<@/3X@)TYO($E0
M(&%D9')E<W-E<R!A=F%I;&%B;&4G+`H))VUI9W)A=&EO;E]A;FYO;E]F='!?
M;&]S="<@/3X@)T%F=&5R($E0(&UA<'!I;F<L('EO=2!W:6QL(&YO="!B92!A
M8FQE('1O('5S92!A;F]N>6UO=7,@1E10('-E<G9I8V4@(&]N("(E,2(N)RP*
M"2=P8E]M:6=R871I;VY?9G)O;2<@/3X@)TUI9W)A=&EO;B!F<F]M("4Q)RP*
M"2=M:6=R871I;VY?8VUD7VEG;F]R960G(#T^("=4:&4@8V]M;6%N9"`B)3$B
M('=A<R!I9VYO<F5D+B<L"@DG;6EG<F%T:6]N7V1B7W-E<G9E<E]N;W1?9FEN
M9"<@/3X@)U1H92!D871A8F%S92!W:6QL(&YO="!B92!R97-T;W)E9#H@=&AE
M(&%P<')O<')I871E(&1A=&%B87-E('-E<G9E<B!F;W(@=&AI<R!D871A8F%S
M92!I<R!N;W0@:6YS=&%L;&5D+B<L"@DG;6EG<F%T:6]N7VYO=%]U;F%B;&5?
M;6EG<F%T95]S;VUE)R`]/B`G36EG<F%T:6]N(&-A;FYO="!C;VYT:6YU93H@
M96ET:&5R('1H92!S96QE8W1E9"!O8FIE8W1S(&%R92!A;')E861Y(&UI9W)A
M=&5D(&]R('1H97D@8V%N;F]T(&)E(&UI9W)A=&5D(&)E8V%U<V4@9&]M86EN
M(&YA;64@;W(@=7-E<B!A8V-O=6YT(&YA;64@:7,@:6YV86QI9"XG+`HI.PHO
M+W)E<75I<F5?;VYC92@G;&]C86QE<R]E;BU54R]U:5]C87!T:6]N<RYI;F,G
M*3L*/SX*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+V%D;6EN+W-B:6X`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,C<@,#$U-C(T`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O861M:6XO<V)I;B]F:6QE;6YG````````````````````````````````
M```````````````````````````````````````````````````````````P
M,#`U-3`@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#$V,3,S,"`Q,#4Q-30S,S<R
M-R`P,3<R-#<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````?T5,1@$!`0D```````````(``P`!````G)@$"#0```!`WP``````
M`#0`(``&`"@`%P`6``8````T````-(`$"#2`!`C`````P`````4````$````
M`P```/0```#T@`0(](`$"!4````5````!`````$````!``````````"`!`@`
M@`0(A=@``(78```%`````!````$```"(V```B&@%"(AH!0B0`@``#$````8`
M````$````@```*S8``"L:`4(K&@%",@```#(````!@````0````$````#`$`
M``R!!`@,@00(&````!@````$````!````"]L:6)E>&5C+VQD+65L9BYS;RXQ
M``````@````$`````0```$9R965"4T0`P+`'`&$```!T``````````````!3
M````0P`````````$`````````&\```!)```````````````0````8P```%<`
M```M````;@```!$````*`````````%@```!@````60```'``````````````
M`#@```!%````8@```%\`````````-0````````!5````40```&P`````````
M`````"D```!:````9````$L```!>````<0```$$````<`````````&L```!=
M````80```#H````/````:````"P```!M````9P```#,`````````3````!\`
M````````/@```$0````,````:0```#<`````````90````````!S````<@``
M```````]`````````#(`````````)0````````!J````7````%8````B````
M2@```#`````H````9@````````````````````````!0````!@``````````
M````*P```%0````[````2```````````````````````````````````````
M````````````````````````"```````````````````````````````````
M```````2```````````````-``````````````````````````L`````````
M`P```!H`````````````````````````#@``````````````(```````````
M````%@```"$````````````````````7````!P`````````O`````````!@`
M```)```````````````````````````````;````,0``````````````````
M```````Y`````0```!,````J````)@````````````````````4`````````
M``````````!&`````````````````````@```#P````N````/P`````````=
M```````````````T````'@```#8```!2``````````````!"`````````",`
M````````1P```$`````4````3@```!4````G`````````!D```!-````)```
M`````````````````%L```````````````````!/````````````````````
M`````-(!````````D@```!(````+```````````````2````V@$``"!K!0@$
M````$0`4`.0!````````*````!(```#L`0```````!P#```2````.@``````
M```L````$@```$(!````````7@```!(```#R`0`````````````2````1@$`
M``````!;````$@`````"`````````````!(```!/`0``)&L%"`0````1`!0`
M"`(````````(`0``$@```",`````````Q0```!(````2````K&@%"``````1
M`/'_#P(````````G````$@```%@!````````Q````!(````8`@``````````
M```2````'P(````````]````$@```"<"````````5@```!(````N`@``````
M```````2````-0(`````````````$@```%\!````````<P$``!(````\`@``
M`````'8````2````00(`````````````$@```$@"````````1`$``!(```!E
M`0``*&L%"`0````1`!0`O0$```````#2````$@```$\"`````````````!(`
M``!O`0`````````````2````5`(```````"2`0``$@```!L`````````*0``
M`!(````B`````````-D````2````6P(````````@````$@```&("````````
M`````!(```!V`0`````````````2````:`(```````!@````$@```"P`````
M````E@```!(```!P`@```````/0$```2````-@(`````````````$@```!D"
M`````````````!(````S````<)($"``````2``@`>0(`````````````$@``
M`'T!```P:P4(5`P``!$`%`!^`@`````````````2````D`$`````````````
M$@```(4"````````&`$``!(```"8`0```````'(````2````C@(`````````
M````$@```)P``````````````!(```"5`@``B*@%"`0````1`!0`G0(`````
M````````$@```#D`````````)P```!(```"C`@`````````````2````00``
M````````````$@```$@``````````````"````!"`@`````````````2````
MJ`(```````!!````$@```+,"````````)@```!(```"X`@``B&@%"`0````1
M``T`PP(`````````````$@```,D"````````<@```!(```!@`````````!<`
M```2````T`(`````````````$@```-8"`````````````!(```!I````````
M```````2````]0````````!\````$@````$!`````````````!(````)`0``
M`````#D````2````W0(`````````````$@```)\!````````*@```!(````1
M`0``A'<%"`0````1`!0`Y`(`````````````$@```*<!````````X0```!(`
M``#I`@```````#`````2````)`$````````Z````$@```&@`````````&P$`
M`!(```"/`@`````````````2````;@```(AW!0@$````$0`4`'L`````````
MM@```!(```!F`P``&&L%"``````0`/'_@0``````````````$@```.\"````
M````!0```!(```"(`````````!8!```2````^0(````````B````$@```"P!
M`````````````!(````!`P```````"<````2````"@,```````!D!0``$@``
M`!$#````````)P```!(```"/````7!@%"``````2``L`2@,```````"E````
M$@```!H#````````+````!(````A`P```````"D````2````E0````````".
M````$@```)X"`````````````!(```";`````````*X````2````7P,``!AK
M!0@`````$`#Q_Z(```"(:04(`````!$`\?]R`P``E*@%"``````0`/'_,P,`
M``````!#````$@```"D#````````)P```!(```"N`0```````%8````2````
M,@,`````````````$@```'P``````````````!(```"U`0`````````````2
M````O`$```````">````$@```#@#`````````````!(````_`P```````*@`
M```2````N```````````````(````$@#````````#`$``!(```#"`0``````
M```````2````4@,`````````````$@```%D#`````````````!(```#,````
M```````````@````B0``````````````$@```.(`````````*0```!(`````
M;&EB>BYS;RXR`'-T<F-P>0!?1%E.04U)0P!M86QL;V,`=G-N<')I;G1F`&9F
M;'5S:`!?:6YI=`!F<')I;G1F`'-T<F-A=`!?7V1E<F5G:7-T97)?9G)A;65?
M:6YF;P!?7V5R<F]R`&9R96%D`%]?:7-T:')E861E9`!F;W!E;@!M96US970`
M9F-L;W-E`%]F:6YI`&9P=71C`&9W<FET90!?1TQ/0D%,7T]&1E-%5%]404),
M15\`7TIV7U)E9VES=&5R0VQA<W-E<P!?7W)E9VES=&5R7V9R86UE7VEN9F\`
M9G)E90!L:6)C<GEP="YS;RXR`%]?7W)U;F5T>7!E`'-T<FYC;7``<W1R;F-P
M>0!?0W5R<F5N=%)U;F5,;V-A;&4`<W1R;F-A=`!S=')C;7``;&EB8W)Y<'1O
M+G-O+C,`340U`'-T<F5R<F]R`%]?<W1D:6YP`&=E=&5N=@!F9V5T<P!?7W-T
M9&5R<G``9V5T=6ED`'-E;&5C=`!?1&5F875L=%)U;F5,;V-A;&4`<W1R<F-H
M<@!C86QL;V,`<F5A;&QO8P!S<V-A;F8`9FEL96YO`'-T<F-H<@!F<'5T<P!F
M8VYT;`!L:6)C+G-O+C4`<'5T8VAA<@!?7W-T9&]U='``=V%I='!I9`!P;W!E
M;@!G971D=&%B;&5S:7IE`&=E=&5U:60`<&-L;W-E`&=E=&=R9VED`&9C:&UO
M9`!?7W-R9V5T`'5S;&5E<`!E>&5C=F4`9F-H;W=N`&=E=&,`9F-H9&ER`'!E
M<G)O<@!D=7`R`'-Y<W1E;0!M:W1E;7``<FUD:7(`<F5A9&1I<@!R96%L<&%T
M:`!P:7!E`')E;F%M90!B87-E;F%M90!R:6YD97@`96YV:7)O;@!F<W1A=`!K
M:6QL`&EN:71G<F]U<',`=V%I=`!?7W!R;V=N86UE`&QS=&%T`'-T<G-T<@!F
M;&]C:P!S971G:60`=6YL:6YK`&9O<FL`97AE8W8`7VEN:71?=&QS`&]P96YD
M:7(`9V5T<'=U:60`9V5T8W=D`&=E='!W;F%M`&%T97AI=`!M:W-T96UP`&=E
M=&=R;F%M`%]E>&ET`'-E='-I9`!C;&]S961I<@!V87-P<FEN=&8`<V5T=6ED
M`&UK9&ER`%]E9&%T80!?7V)S<U]S=&%R=`!?96YD```@:P4(!0,``"1K!0@%
M"P``*&L%"`4:```P:P4(!2L``(1W!0@%1P``B'<%"`5.``"4:04(!P$``)AI
M!0@'`@``G&D%"`<$``"@:04(!P4``*1I!0@'!@``J&D%"`<'``"L:04(!P@`
M`+!I!0@'"0``M&D%"`<*``"X:04(!PP``+QI!0@'#0``P&D%"`</``#$:04(
M!Q```,AI!0@'$0``S&D%"`<2``#0:04(!Q,``-1I!0@'%```V&D%"`<5``#<
M:04(!Q8``.!I!0@'%P``Y&D%"`<8``#H:04(!QD``.QI!0@'&P``\&D%"`<<
M``#T:04(!QT``/AI!0@''@``_&D%"`<?````:@4(!R````1J!0@'(0``"&H%
M"`<B```,:@4(!R,``!!J!0@')```%&H%"`<E```8:@4(!R8``!QJ!0@')P``
M(&H%"`<H```D:@4(!RH``"AJ!0@'+```+&H%"`<M```P:@4(!RX``#1J!0@'
M+P``.&H%"`<P```\:@4(!S$``$!J!0@',P``1&H%"`<T``!(:@4(!S4``$QJ
M!0@'-@``4&H%"`<X``!4:@4(!SD``%AJ!0@'.@``7&H%"`<\``!@:@4(!ST`
M`&1J!0@'/@``:&H%"`<_``!L:@4(!T```'!J!0@'00``=&H%"`="``!X:@4(
M!T,``'QJ!0@'1```@&H%"`=%``"$:@4(!T8``(AJ!0@'2```C&H%"`=)``"0
M:@4(!TH``)1J!0@'2P``F&H%"`=,``"<:@4(!TT``*!J!0@'3P``I&H%"`=1
M``"H:@4(!U(``*QJ!0@'4P``L&H%"`=4``"T:@4(!U4``+AJ!0@'5@``O&H%
M"`=7``#`:@4(!U@``,1J!0@'6@``R&H%"`=;``#,:@4(!UP``-!J!0@'70``
MU&H%"`=>``#8:@4(!U\``-QJ!0@'8P``X&H%"`=D``#D:@4(!V4``.AJ!0@'
M9@``[&H%"`=G``#P:@4(!V@``/1J!0@':0``^&H%"`=J``#\:@4(!VL```!K
M!0@';0``!&L%"`=N```(:P4(!V\```QK!0@'<```$&L%"`=R```4:P4(!W,`
M`.@+!P``Z+J%``##`/\UC&D%"/\ED&D%"`````#_)91I!0AH`````.G@____
M_R68:04(:`@```#IT/____\EG&D%"&@0````Z<#_____):!I!0AH&````.FP
M_____R6D:04(:"````#IH/____\EJ&D%"&@H````Z9#_____):QI!0AH,```
M`.F`_____R6P:04(:#@```#I</____\EM&D%"&A`````Z6#_____);AI!0AH
M2````.E0_____R6\:04(:%````#I0/____\EP&D%"&A8````Z3#_____)<1I
M!0AH8````.D@_____R7(:04(:&@```#I$/____\ES&D%"&AP````Z0#_____
M)=!I!0AH>````.GP_O___R74:04(:(````#IX/[___\EV&D%"&B(````Z=#^
M____)=QI!0AHD````.G`_O___R7@:04(:)@```#IL/[___\EY&D%"&B@````
MZ:#^____)>AI!0AHJ````.F0_O___R7L:04(:+````#I@/[___\E\&D%"&BX
M````Z7#^____)?1I!0AHP````.E@_O___R7X:04(:,@```#I4/[___\E_&D%
M"&C0````Z4#^____)0!J!0AHV````.DP_O___R4$:@4(:.````#I(/[___\E
M"&H%"&CH````Z1#^____)0QJ!0AH\````.D`_O___R40:@4(:/@```#I\/W_
M__\E%&H%"&@``0``Z>#]____)1AJ!0AH"`$``.G0_?___R4<:@4(:!`!``#I
MP/W___\E(&H%"&@8`0``Z;#]____)21J!0AH(`$``.F@_?___R4H:@4(:"@!
M``#ID/W___\E+&H%"&@P`0``Z8#]____)3!J!0AH.`$``.EP_?___R4T:@4(
M:$`!``#I8/W___\E.&H%"&A(`0``Z5#]____)3QJ!0AH4`$``.E`_?___R5`
M:@4(:%@!``#I,/W___\E1&H%"&A@`0``Z2#]____)4AJ!0AH:`$``.D0_?__
M_R5,:@4(:'`!``#I`/W___\E4&H%"&AX`0``Z?#\____)51J!0AH@`$``.G@
M_/___R58:@4(:(@!``#IT/S___\E7&H%"&B0`0``Z<#\____)6!J!0AHF`$`
M`.FP_/___R5D:@4(:*`!``#IH/S___\E:&H%"&BH`0``Z9#\____)6QJ!0AH
ML`$``.F`_/___R5P:@4(:+@!``#I</S___\E=&H%"&C``0``Z6#\____)7AJ
M!0AHR`$``.E0_/___R5\:@4(:-`!``#I0/S___\E@&H%"&C8`0``Z3#\____
M)81J!0AHX`$``.D@_/___R6(:@4(:.@!``#I$/S___\EC&H%"&CP`0``Z0#\
M____)9!J!0AH^`$``.GP^____R64:@4(:``"``#IX/O___\EF&H%"&@(`@``
MZ=#[____)9QJ!0AH$`(``.G`^____R6@:@4(:!@"``#IL/O___\EI&H%"&@@
M`@``Z:#[____):AJ!0AH*`(``.F0^____R6L:@4(:#`"``#I@/O___\EL&H%
M"&@X`@``Z7#[____);1J!0AH0`(``.E@^____R6X:@4(:$@"``#I4/O___\E
MO&H%"&A0`@``Z4#[____)<!J!0AH6`(``.DP^____R7$:@4(:&`"``#I(/O_
M__\ER&H%"&AH`@``Z1#[____)<QJ!0AH<`(``.D`^____R70:@4(:'@"``#I
M\/K___\EU&H%"&B``@``Z>#Z____)=AJ!0AHB`(``.G0^O___R7<:@4(:)`"
M``#IP/K___\EX&H%"&B8`@``Z;#Z____)>1J!0AHH`(``.F@^O___R7H:@4(
M:*@"``#ID/K___\E[&H%"&BP`@``Z8#Z____)?!J!0AHN`(``.EP^O___R7T
M:@4(:,`"``#I8/K___\E^&H%"&C(`@``Z5#Z____)?QJ!0AHT`(``.E`^O__
M_R4`:P4(:-@"``#I,/K___\E!&L%"&C@`@``Z2#Z____)0AK!0AHZ`(``.D0
M^O___R4,:P4(:/`"``#I`/K___\E$&L%"&CX`@``Z?#Y____)11K!0AH``,`
M`.G@^?__58GE5U93@^P,B=&-=0B+7OR-?)X$B3V(J`4(A=M^+8-]"`!T)XM%
M"*.(:`4(B<*`.`!T&(`Z+W4+C4(!HXAH!0B-=@!"@#H`=>J)]KBL:`4(A<!T
M#H/L#%'H8O[__X/$$.L%Z-C]__^#[`QH7!@%".A+_O__Z%KY__^#[`175E/H
M(P8``(/$%%#H@O[__Y"058GE@^P(@#V,=P4(`'5!H9!H!0B+`(7`=!:)]H,%
MD&@%"`3_T*&0:`4(BP"%P'7LN`````"%P'00@^P,:*AH!0CHCF;[]X/$$,8%
MC'<%"`')PXGV58GE@^P(N`````"%P'05@^P(:)!W!0AHJ&@%".A?9OOW@\00
M@SV$:04(`'0;N`````"%P'02@^P,:(1I!0CH/6;[]X/$$(GVR<.0D%6)Y8U5
MF(/L<%+_=0CHKOW__X/$$$`/E,`/ML#)PXGV58GE5U93@>R`$```BU4,9HF5
MAN____PQP+^Q&`4(N?_____RKO?1N`$0```IR%#_=0B-M>CO__]6Z`+\__];
M7XV]B.___U=6Z%/]__^#Q!"#^/^)PP^$H0```(L=C*@%"(7;='2#[`QF@[V&
M[___`'5RBX6X[___BY6\[___4E#_M:CO__]6:,,8!0CH3_C__X/$%/^UF.__
M_^@A0```@\0,4%;_M93O___HK3\``%E;4&C0&`4(Z"3X__]8#[>UD.___UJ!
MYO\!``!6:-<8!0CH"OC__X/$$(UE]%M>,<!?R<.0BX7`[___BY7$[___#Z3"
M"<'@">N%C78`@^P(5U;HNOK__X/$$(7`=14/MXV0[___@>$`\```@?D`H```
M="J#[!#HMOK__UK_,.C>]___@\004&C=&`4(:@%J`>B`>P``@\00Z0_____\
M43'`B=F_L1@%"/*N]]%)46BQ&`4(5N@X^___@\00Z>O^__]5B>575E.#['B+
M70A3BWT,Z(O[__^#Q!"%P(G&#X1"`0``@^P,4^CU^?__D(/$$(/L#%;HZ/C_
M_X/$$(7`#X0.`0``@^P(C56(4HU8"%/HW?O__X/$$$`/A)\```"+59")T"4`
M\```/0!```!U<HL5D*@%"(72=+>#[`QFA?]T=(M%P(M5Q`^DP@G!X`E24/]U
MJ%-HPQ@%".C3]O__@\04_W68Z*@^``"#Q`Q04/]UE.@W/@``65M0:-`8!0CH
MKO;__P^W79!86H'C_P$``%-HUQ@%".B7]O__Z4[___^)]H/L"`^_SU%3Z*/]
M___I.O___XGVBT6XBU6\ZY&#[`B-18A04^A'^?__@\00A<!U%XM5D(G1@>$`
M\```@?D`H```#X0Y____@^P0Z$'Y__]:_S#H:?;__X/$$%!HW1@%"&H!:@'H
M"WH``(/$$.D,____@^P,5NAV^___C67T6UXQP%_)PX/L$.@$^?__6?\PZ"SV
M__^#Q!!0:.X8!0AJ`6H!Z,YY``"#Q!#IE/[__XGV58GE5U93@>R,````BT40
M9HE%AL<%C*@%"`````#'!9"H!0@`````_(MU"+\"&04(N08```#SIG5;QP6,
MJ`4(`0```(/L"(U5B%+_=0SH3OK__X/$$$!T<P^W79"!XP#P``"!^P!````/
MA)H```"#[`@/OWV&5_]U#.B"_/__@\00A<`/A9L```"-9?1;7C'`7\G#D+L%
M````_(MU"+\(&04(B=GSI@^%D````,<%D*@%"`$```"#[`B-58A2_W4,Z-OY
M__^#Q!!`=8V#[!#H#?C__UO_,.@U]?__@\004&C=&`4(:@%J`>C7>```#[==
MD('C`/```(/$$('[`$````^%:/___XGV@^P(#[]%AE#_=0SH6/W__X/$$(7`
M#X1F____D(/L#&H!Z&YW``"#Q!"-9?1;7C'`7\G#D/R+=0B_#1D%"(G9\Z9U
M&<<%C*@%"`$```#'!9"H!0@!````Z5+___]6:!@:!0AJ`6H!Z%%X``"#Q!#I
MR/[__Y!5B>575E.-G>CO__^![!`0``#\OOH;!0BY!P```(G?\Z5FI6CB#P``
M:@"-A0;P__]0Z"[X__]8BT40A<!T8E#_=0QH$AD%"&@`$```4^AR]/__@\04
M4^BI^/__@\00@_C_=&"#[`Q0Z*CY__]?6%/_=0CH&24``(/$$(7`=2F#[`AH
MI`$``%/HR/7__XD<).CP]/__,<"-9?1;7E_)PXGVN!\9!0CKEX/L#%/_=0AH
M/!H%"&H!:@#HC'<``+C_____Z]-0:&`:!0AJ`6H`Z'9W``"X_____^N]C78`
M58GE5U93@>SL!```BU4,@^3P@^P0BP+'A7S[__\`````QX5X^___`````&;'
MA7;[__\``*.$J`4(Z&X(``#HA?3__X/L"&H`:"T9!0B)P^@X.```@\00.<-T
M#>AH]/__A<`/A8<"``#H6_/__X7`#X2P`0``@WT(`@^.C0$``(M5#(M:!(M"
M"(F%@/O___RY!0```+XT&04(B=_SI@^%3@$``(-]"`1^%+D*````OCD9!0B+
MO8#[___SIG024&A$&04(:@%J`>B@=@``@\00NP,```#\B[6`^___OV(9!0B)
MV?.F#X6A````QX5\^___71D%"+H"````ZPR0BW4,BPR6B4R6^$([50A\\(M%
M"(M=#,=$@_@`````Z/GU__^%P(G&#X0:`0``4&H"C96$^___4E;H+_+__X/$
M$$`/A&`!``"+E83[__^)T(/@?W1C@_A_=`B%P`^%O`$``(G7@^=_@_]_#X34
M`0``@^P,:@KHT_'__\<$)`````#HPW0``(UE]%M>,<!?R</\N00```"+M8#[
M__^_:AD%"/.F#X41`0``QX5\^___91D%".E!____P?H(A=)TL?^U?/O__VB$
M&@4(:@!J`>B>=0``@\00@^P,:@KH;?'__\<$)`````#H770``(UE]%M>,<!?
MR</HTO'__X7`#X71_O__@^P,4^BA%0``Z<#^____=0AHJ!H%"&H!:@'H3W4`
M`(/$$.E:_O__@^P,:@#HZ?;__\<$)`````#H;?3__X/$$.DR_O__@^P(:@)J
M`>AI\O__Z%3Q__^#Q!"#^`.-6/]^%9"#[`Q3Z,_V__^)V(/$$$N#^`-_[%#_
M=1#_=0S_M7S[___HPO'__X/$$%!J`HV5A/O__U)6Z,_P__^#Q!!`#X6@_O__
M@^P,:@'HEW,``(/$$.F._O___(NU@/O__[]^&04(B=GSIG1#_(NU@/O__[]S
M&04(N08```#SI@^%@@```,>%?/O__VX9!0CI!?[__V@M&04(:.@:!0AJ`6H!
MZ&IT``"#Q!#I7OW__\>%?/O__WD9!0CIV_W__X/L#%#_M7S[__]H,!L%"&H`
M:@'H.W0``(/$((N5A/O__^D>_O__@^P,P?H(4O^U?/O__VAL&P4(:@!J`>@2
M=```@\0@Z0G^___\B[6`^___OY49!0B)V?.F="3\B[6`^___OXH9!0BY!@``
M`/.F=1['A7S[__^!&04(Z5S]___'A7S[__^0&04(Z4W]___\B[6`^___OYT9
M!0B)V?.F=0_'A7S[__^8&04(Z2S]___\B[6`^___OZ49!0BY!@```/.F=0_'
MA7S[__^@&04(Z0C]___\B[6`^___O[`9!0BY!@```/.F=0_'A7S[__^K&04(
MZ>3\__^[!0```/R+M8#[__^_*!D%"(G9\Z9U#\>%?/O__[89!0CIOOS___R+
MM8#[__^_Q!D%"(G9\Z9U4(-]"`1^2HM=#(MS%+D,````O\D9!0CSIG4)9L>%
M=OO__P$`5P^_E7;[__]2BT4,_W`0_W`,Z";Y___'!"0`````Z+9Q``"#Q!#I
M7OS__XGV_+D,````B[6`^___O]49!0CSIG4*@WT(!`^$GP```/RY"P```(NU
M@/O__[\Y&04(\Z9U-(-]"`1^+HM=#(-]"`:+0PR+4Q!U"8M[%(F]>/O__U'_
MM7C[__]24.@L^O__B00DZXR-=@#\N0D```"+M8#[__^_X1D%"/.F=0:#?0@$
M='/\N04```"+M8#[__^_ZAD%"/.F=0J#?0@%#X2#````_[6`^___:*@;!0AJ
M`6H!Z!YR``"#Q!#IGOO__X/L"(V]B/O__\<%C*@%"`````!7BU4,_W(,Z-/R
M__]`6P^4P%X/MMA3:.\9!0CH_^W__^GT_O__@^P(BU4,C87H^___BW(,4%;H
MM.___XD$)(G#Z!9,``"#Q!"%P'135FC4&P4(ZXB+70R+<PRY#````+_)&04(
M\Z9U"6;'A7;[__\!`(/L"(M]#`^_E7;[__^+7Q!24^A/`0``B=&)PB'(@\00
M0'494VCS&04(Z3W___^#[`Q3Z)?N___I;/[__U!14F@0&@4(Z6'___^058GE
M5U93@>R(````BT4(:/LK!0AFB46&Z'?Q__^)18"+38`Q]C'_@\00,<`QTH7)
M#X2A````B?:#[`S_=8#HT>[__X/$$(7`#X2Z````@'@(+HU8"'41BD,!A,!T
MVCPN#X2"````B?:#[`B-58A24^C/[___@\00A<!XO&:#?88`=%T#=<`3?<0/
MMTV0@>$`\```@?D`0```=9V#[`Q3Z'#O__^#Q!"%P'B-@^P,#[]=AE/H2/__
M_P'&$=?'!"3Z*P4(Z$SO__^#Q!"%P`^)9?___XGPB?J-9?1;7E_)PY`#=;@3
M?;SKH8![`@`/A7;___^#[`S_=8#H%^[__X/$$(7`#X5&____@^P,_W6`Z+'Q
M__^)\(GZZ[Z-=@!5B>575E.![)0```"-18A0BU4,_W4(9HE5AL=%@``0``#H
M`N___X/$$(7`NO____^Y_____W@U9H-]A@!U.@^W39"!X0#P``"!^0!```"+
M=;B+?;QT.HGPB?IF@WV&`'0'#Z3""<'@"8G1B<*-9?1;7HG07XG*R<,/MTV0
M@>$`\```@?D`0```BW7`BWW$=<:#[`QH`!```.@+[?__@\00A<")P[K_____
MN?____]TO(/L"/]U@%/H[.___X/$$(7`=3^#[`B!18``$```_W6`4XF=?/__
M_^CL[O__@\00A<")PW7+@^P,_[5\____Z!7Q__^Z_____[G_____Z6K___^#
M[`S_=0CHZ^W__X/$$(7`>%&#[`P/OT6&4.C#_?__B85P____`;5P____B95T
M____$;UT____B1PDZ+?M__^#Q!"%P'@=@^P,4^BW\/__@\00BX5P____BY5T
M____Z?7^__^#[`Q3ZX.058GE5U93@^QLH3QX!0B%P'0*C67T6UY?R<.)]H/L
M#&C]*P4(Z"<B``"#Q!"%P(G##X2B"```@#@`#X29"```@^P,B1T\>`4(:`PL
M!0CH_B$``(/$$(7`B<-T!8`X`'425VC`+@4(:@%J`>A1;@``@\00@^P,B1TT
M>`4(:!LL!0CHRR$``(/$$(7`B<-T!8`X`'425FCD+@4(:@%J`>@>;@``@\00
M@^P,B1TP>`4(:"@L!0CHF"$``(/$$(7`B<-T!8`X`'4246@(+P4(:@%J`>CK
M;0``@\00@^P,B1TL>`4(:#@L!0CH92$``(/$$(7`B<-T!8`X`'424F@L+P4(
M:@%J`>BX;0``@\00@^P,B1TH>`4(:$0L!0CH,B$``(/$$(7`B<-T!8`X`'42
M4&A,+P4(:@%J`>B%;0``@\00@^P,B1TD>`4(:%$L!0CH_R```(/$$(7`B<-T
M!8`X`'424&AP+P4(:@%J`>A2;0``@\00@^P,B1T@>`4(:&,L!0CHS"```(/$
M$(7`B<-T!8`X`'424&AM+`4(:@%J`>@?;0``@\00@^P,B1T<>`4(:(LL!0CH
MF2```(/$$(7`B<-T!8`X`'424&B8+P4(:@%J`>CL;```@\00@^P,B1T8>`4(
M:)DL!0CH9B```(/$$(7`B<-T!8`X`'46:)DL!0AHO"\%"&H!:@'HM6P``(/$
M$(/L#(D=%'@%"&BD+`4(Z"\@``"#Q!"%P(G#=`6`.`!U$E!H["\%"&H!:@'H
M@FP``(/$$(/L#(D=$'@%"&BU+`4(Z/P?``"#Q!"%P(G#=`6`.`!U$E!HOBP%
M"&H!:@'H3VP``(/$$(/L#(D="'@%"&C;+`4(Z,D?``"#Q!"%P(G#=`6`.`!U
M$E=HY2P%"&H!:@'H'&P``(/$$(/L#(D=!'@%"&@#+04(Z)8?``"#Q!"%P(G#
M=`6`.`!U$E9H%#`%"&H!:@'HZ6L``(/$$(/L#(D=`'@%"&@/+04(Z&,?``"#
MQ!"%P(G#=`6`.`!U$E%H-#`%"&H!:@'HMFL``(/$$(/L#(D=_'<%"&@;+04(
MZ#`?``"#Q!"%P(G#=`6`.`!U$E)H5#`%"&H!:@'H@VL``(/$$(/L#(D=^'<%
M"&@G+04(Z/T>``"#Q!"%P(G#=`6`.`!U$E!H=#`%"&H!:@'H4&L``(/$$(/L
M#(D=]'<%"&@T+04(Z,H>``"#Q!"%P(G#=`6`.`!U$E!HF#`%"&H!:@'H'6L`
M`(/$$(/L#(D=\'<%"&A#+04(Z)<>``"#Q!"%P(G#=`6`.`!U$E!HO#`%"&H!
M:@'HZFH``(/$$(/L#(D=['<%"&A1+04(Z&0>``"#Q!"%P(G#=`6`.`!U$E!H
MX#`%"&H!:@'HMVH``(/$$(/L#(D=Z'<%"&A>+04(Z#$>``"#Q!"%P(G#=`6`
M.`!U$E!H92T%"&H!:@'HA&H``(/$$(/L#(D=#'@%"&B`+04(Z/X=``"#Q!"%
MP(G#=`6`.`!U$E!H!#$%"&H!:@'H46H``(/$$(/L#(D=Y'<%"&B.+04(Z,L=
M``"#Q!"%P(G#=`6`.`!U$E=H*#$%"&H!:@'H'FH``(/$$(/L#(D=X'<%"&B;
M+04(Z)@=``"#Q!"%P(G#=`6`.`!U$E9H3#$%"&H!:@'HZVD``(/$$(/L#(D=
MW'<%"&BG+04(Z/4?``"CV'<%"%E;:``0``!J`>@>Z/__,=N^_____XL5/'@%
M"(E%C(E5\*/4=P4(_(G7B-B)\?*N]]&#Q`Q)4?]U\/]UC.@+Z?__6%IHNRT%
M"/\UU'<%".@YZ/__65]H`!```&H!Z,OG__^+%3QX!0B)18R)5>BCT'<%"/R)
MUXC8B?'RKO?1@\0,25%2_W6,Z,'H__]86FC0+04(_S70=P4(Z._G__]97V@`
M$```:@'H@>?__XL5/'@%"(E%C(E5X*/,=P4(_(G7B-B)\?*N]]&#Q`Q)4?]U
MX/]UC.AUZ/__6%IHXBT%"/\US'<%".BCY___65]H`!```&H!Z#7G__^+%3QX
M!0B)18R)5=BCR'<%"/R)UXC8B?'RKO?1@\0,25'_==C_=8SH*>C__UA::/4M
M!0C_-<AW!0CH5^?__UE?:``0``!J`>CIYO__BQ4\>`4(B46,B570H\1W!0C\
MB=>(V(GQ\J[WT8/$#$E1_W70_W6,Z-WG__]86F@(+@4(_S7$=P4(Z`OG__]9
M7V@`$```:@'HG>;__XL5/'@%"(E%C(E5R*/`=P4(_(G7B-B)\?*N]]&#Q`Q)
M4?]UR/]UC.B1Y___6%IH'BX%"/\UP'<%".B_YO__65]H`!```&H!Z%'F__^+
M%3QX!0B)18R)5<"CO'<%"/R)UXC8B?'RKO?1@\0,25'_=<#_=8SH1>?__UA:
M:#,N!0C_-;QW!0CH<^;__UE?:``0``!J`>@%YO__BQ4\>`4(B46,B56XH[AW
M!0C\B=>(V(GQ\J[WT8/$#$E1_W6X_W6,Z/GF__]86FA'+@4(_S6X=P4(Z"?F
M__]97V@`$```:@'HN>7__XL5/'@%"(E%C(E5L*.T=P4(_(G7B-B)\?*N]]&#
MQ`Q)4?]UL/]UC.BMYO__6%IH7"X%"/\UM'<%".C;Y?__65]H`!```&H!Z&WE
M__^+%3QX!0B)18R)5:BCL'<%"/R)UXC8B?'RKO?1@\0,25'_=:C_=8SH8>;_
M_UA::&XN!0C_-;!W!0CHC^7__UE?:``0``!J`>@AY?__BQ4\>`4(B46,B56@
MHZQW!0C\B=>(V(GQ\J[WT8/$#$E1_W6@_W6,Z!7F__]86FB#+@4(_S6L=P4(
MZ$/E__]?6&@`$```:@'HU>3__X/$#*.H=P4(:``0``#_-3QX!0A0Z-SE__^+
M%:AW!0B)59B)U_R(V(GQ\J[WT;\`$```@\0,*<]7:)@N!0C_=9CH$.;__XL5
M/'@%"(E5D(G7_(C8B?'RKO?1@\$1B0PDZ)'C__]97O\U/'@%"%")P^CQX?__
M6%IHK2X%"%/HM.3__XD=.'@%"(UE]%M>7\G#B?90:&PQ!0AJ`6H!Z-EE``"#
MQ!#I4/?__Y!5B>575E.![`P0``"+70B%V[X0)P``=!T/OA.!^O\```!W6J&$
M=P4(BT20-"4`!0``A<!U$U!HCS$%"&H!:@'HC&4``(/$$)"#[`Q&5NCJY?__
M@\00A<!U[X'^_/\``'8J4&BA,04(:@!J`.A@90``C67T6UZX`0```%_)PX/L
M#%+HIN3__X/$$.NA:+$Q!0AHP#$%"/]U#%93:'PT!0AH`!```(V=Z.___U/H
MG.'__X/$%%/H@^+__X/$$(7`B<=T"HGXC67T6UY?R<.#[`QHQS$%".AG)P``
M68G#6&CH`0``_W4,Z*+F__^#Q`Q35O]U#.C5XO__6%IHZ`$``/]U#.C6XO__
M@\00B?CKMXUV`%6)Y5=64X'L("```/R^*C@%"+D&````C;WH[___QX7DW___
M`0```/.EI&CG#P``:@"-A0'P__]0Z)_D__^#[`C_=0S_=0CHT>3__X/$(#'2
MA<`/A.`!``"+50B%TG10BUT(#[X3@?K_````#X<&`@``H81W!0B+1)`T)0`%
M``"%P'0LBWT,A?]T)8MU#`^^%H'Z_P````^'[`$``(L-A'<%"(M$D30E``4`
M`(7`=1)0:,\Q!0AJ`6H!Z`)D``"#Q!#_=0AH[#$%"&@`$```C;7HW___5NAB
MX/__6U]H'"X%"%;HY=___X/$$(7`B<,/A*4!``"#[`R-E>CO__]2Z'GD__^#
MQ!"%P(F%X-___W4RZ3P!``"-=@#'A>3?__\`````_#'`N?____]2B??RKO?1
M25%6_[7@W___Z/WA__^#Q!!04V@`$```5NAMX/__@\00A<!T.8N]Y-___X7_
M=,*`O>C?__\C=:^`O>G?__\@=-"`O>K?__\*=9U04V@`$```5N@TX/__@\00
MA<!UQ_]U"&C_,04(:``0``!6Z)K?__^)-"3H@N#__UC_=0S_=0AHM#0%"&@`
M$```5NA[W___@\045NABX/__@\0,:-@T!0AH`!```%:)Q^A=W___B30DZ$7@
M__^#Q!"%_W54@^P,C97H[___4O]U#&@=,@4(:``0``!6Z#'?__^#Q!16Z!C@
M__^)'"3H$-___UC_M>#?__^-G>CO___H7N3__XD<).@6XO__B?J-9?1;7HG0
M7\G#@^P,C8WH[___4?]U".NJ@^P,4^C2WO__C87H[___4&@`-04(:@%J`>A1
M8@``@\0@Z<O^__^#[`Q2Z)SA__^#Q!#I\OW__X/L#%+HB^'__X/$$.D-_O__
M_W4(:$0U!0AJ`6H!Z!9B``"#Q!#I0O[__XGV58GE5U93@>Q\$```BUT(A=MT
M)0^^$X'Z_P````^'(@$``*&$=P4(BT20-"4`!0``A<`/A:````!6:#(R!0AJ
M`6H!Z,5A``"#Q!"#[`B-18A0_W4,Z(_B__^#Q!"%P`^4P@^V\H7V=!R+592+
M39B+?9")E83O__^)C8#O__]FB;U^[___@^P,_W4,4VAP-04(C9V([___:``0
M``!3Z.?=__^#Q!13Z,[>__^#Q`QHV#0%"&@`$```4XG'Z,G=__^)'"3HL=[_
M_X/$$(7V=4*-9?1;7HGX7\G#BWT,A?\/A%7___^+30P/OA&!^O\```!W9XLU
MA'<%"(M$EC0E``@``(7`#X5"____Z2O___^-=@!1_[6`[____[6$[____W4,
MZ./>__]8#[>U?N___UI6_W4,Z.'>__^#Q!"-9?1;7HGX7\G#@^P,4N@;X/__
M@\00Z=;^__^-=@"#[`Q2Z`?@__^#Q!#KE8GV58GE5E.![``0``"+70B%VXMU
M#'1'#[X3@?K_````#X>4````H81W!0B+1)`T)0`%``"%P'0FA?9T(@^^%H'Z
M_P````^'@P```(L-A'<%"(M$D30E``@``(7`=1)0:$\R!0AJ`6H!Z#E@``"#
MQ!"#[`Q64VB8-04(C9WX[___:``0``!3Z)?<__^#Q!13Z'[=__^#Q`QHV#0%
M"&@`$```4XG&Z'G<__^)'"3H8=W__XUE^%N)\%[)PX/L#%+H/]___X/$$.ED
M____C78`@^P,4N@KW___@\00Z7;___^-=@!5B>53@^P4C4WXBUT(QT7P____
M_\=%]/____^-5?114HU%\%!3Z%8@``"#Q!!`#X0$`0``@^P,_W7XZ%'>__^#
MQ!!`#X07`0``BT7P/?,!``!V08/L"/]U]%/H0=[__X/$$$!T4X/L#/]U].B0
MWO__@\00A<!U>8/L#/]U\.CNX/__@\00A<`/A8\````QP(M=_,G#4&B\-04(
M:@%J`>@A7P``@\00@^P(_W7T4^CNW?__@\000'6M@^P0Z"#>__]:_S#H2-O_
M_XD$)%-HX#4%"&H!:@'HZEX``(/$((/L#/]U].@8WO__@\00A<!TB)#_=?1H
M:C(%"&H!:@'HPUX``(/$$(/L#/]U\.AAX/__@\00A<`/A'/___^)]O]U\&B`
M,@4(:@%J`>B77@``@\00,<"+7?S)PY!3:)8R!0AJ`6H!Z'U>``"#Q!"#[`S_
M=?CH.]W__X/$$$`/A>K^__^0@^P,_W7X4VBH,@4(:@%J`>A/7@``@\0@Z<S^
M__^-=@!5B>564X/L$(MU".C@W?__A<")PG4BZ)7?__]`=7^#[`QHQC(%".A%
MV___QP0D`P```.@YW___D%-J`HU%]%!2Z/O9__^#Q!!`#X3?````BU7TB="#
MX']T)X/X?W0(A<`/A0,!``")T8/A?X/Y?P^$Y@```#'`C67X6U[)PXUV`,'Z
M"(72=.U6:`PV!0AJ`&H`Z*Y=``"X_____^O9@^P(:@)HUC(%".C4WO__B</'
M!"0`````Z%;?___'!"0!````Z$K?___'!"0"````Z#[?__]96&H`4^BTVO__
M6%IJ`5/HJMK__UE8:@)3Z*#:__^)'"3H&-___XDT).B`_?__6%IJ#VK_Z.7;
M___'!"00)P``Z/G9__]>6&H):O_HSMO__\<$)`````#H0M[__X/L$.@JW/__
M6?\PZ%+9__^)!"16:"PV!0AJ`&H`Z/1<``"X_____^D<____@^P,P?H(4E9H
M8#8%".O>@^P,4%9HH#8%".O2C78`58GE5U93@>P,$```BW4(A?:+?0QT/@^^
M%H'Z_P````^'UP```*&$=P4(BT20-"4`!0``A<!T'8/L#%;H&-W__X/$$#'2
MA<!U+XUE]%M>B=!?R<.04&C@,@4(:@%J`>AI7```@\00@^P,5NCIW/__@\00
M,=*%P'31:@%J`59H\C(%".C9'```@\00A<!U?X/L#%;H\?W__U9H`#,%"(V=
MZ.___V@`$```4^B:V/__@\044^B!V?__B30D:!XS!0AH,S,%"&@`$```4^AY
MV/__@\044^A@V?__@\00A<")P@^%9/___X7_=`6`/P!U-C'2C67T6UZ)T%_)
MPXGV@^P,4N@CV___@\00Z2'___]0:#LS!0AJ`&H`Z+!;``"#Q!#I:O___X/L
M"/\U-'@%"%?HZ30``(/$$(7`=+3H[1\``(7`=!"#[`Q7Z,@M``"#Q!`QTNN=
M@^P(:@%7Z#8G``"#Q!#K[)!5B>575E.#['R+?0B-7=B-M7C____'1=A8,P4(
MQT7<8C,%",=%X`````#K%(/#!.A0VO__BQ.%TL<``````'0\4/\S5VAJ,P4(
MZ)Y9``!:6590Z.W;__^#Q!"%P'7.#[=5@(G0)0#P```]`(```'6\@^)`=+>+
M`^L%C78`,<"-9?1;7E_)PXGV58GE5U93@>P(`0``_W4(BWT,Z%7;__^#Q!"%
MP(G##X3<`0``@^P,_W,<Z'W9__^#Q!!`=#.#[`B-18A0:&\S!0CH=MO__X/$
M$$!T$@^W59"!X@#P``"!^@!```!T(HUE]%M>7\G#B?;_<QQHX#8%"&H!:@'H
M9UH``(/$$.NWB?:#[`B-M7C___^+0PR-C03___]648F%`/___\>%>/___XLS
M!0C'A7S___]S,P4(QT6`@3,%",=%A`````#H"S,``(/$$(7`#X55`0``_S4H
M:P4(:C)J`6@`-P4(Z.S:__^#Q!"%_P^$)0(``(/L#&B5,P4(Z'39__^#Q!!`
M#X3K`@``@^P,:*<S!0CH7=G__X/$$$`/A"8#``"#[`QHLC,%".A&V?__@\00
M0`^$Y@(``(/L#&B^,P4(Z"_9__^#Q!!`#X1]`@``@^P(:&@T!0AHE3,%".B3
MV?__@\00A<")Q@^$:@$``(/L"&C),P4(4.@(V/__@\00A<`/B%$!``"#[`A7
M_W,,_W,(_W4(:.<S!0A6Z.77__^#Q""%P`^(+@$``(/L#%;H<=G__X/$$$`/
MA!L!``"-=@!0:@!HE3,%"&AO,P4(:/TS!0AH`#0%"&@#-`4(:`,T!0CH%E$`
M`(/$((7`#X1U_O__4&@T-P4(:@%J`>CH6```@\00Z5[^__^#[`S_=0AH*D@%
M"&@6-`4(:@%J`>C'6```@\0@Z0/^__^#[`QH+S0%".@^V/__@\000`^$KP``
M`%!HI`$``&@!!@``:"\T!0CHS]G__X/$$(/X_XG&#X0D`@``4/]U"/^U`/__
M_VA@-P4(Z/56``#'!"0`````:"XT!0A0:#DT!0C_M03_____M03___]J`E9J
M_XF%_/[__^CW5```@\0P0`^$P0$``(/L#/^U_/[__^@'VO__B30DZ._9__^#
MQ!#H-]?__\<``````.D3_O__4&B0-P4(:@%J`>@!6```@\00Z='^___H$-?_
M_X,X`@^$0____V@O-`4(:#PT!0AJ`6H!Z-A7``"#Q!#I*/___XM['(VU:/__
M_\>%:/___U@S!0C'A6S___]B,P4(QX5P____`````.L7C78`Z+O6__^#Q@3'
M``````"+!H7`='!0_S97:&HS!0CH!E8``%I9C94(____4E#H3]C__X/$$(7`
M=<@/MY40____B=&!X0#P``"!^0"```!UL8/B0'2LBP:%P(G'#X5/_?__@^P,
M_W4(:"I(!0AHP#<%"&H!:@'H*U<``(/$(.DN_?__C78`,<#KSN@SUO__@S@"
M#X1U_?__:+XS!0AH/#0%"&H!:@'H^U8``(/$$.E:_?__Z`K6__^#.`(/A`?]
M__]HE3,%"&@\-`4(:@%J`>C25@``@\00Z>S\___HX=7__X,X`@^$#/W__VBR
M,P4(:#PT!0AJ`6H!Z*E6``"#Q!#I\?S__^BXU?__@S@"#X3,_/__:*<S!0AH
M/#0%"&H!:@'H@%8``(/$$.FQ_/__4&CH-P4(:@%J`>AI5@``@\00Z2C^__]0
M:`@X!0AJ`6H!Z%)6``"#Q!#IQ?W__XGV58GE4X/L)(M%",=%Z#=(!0C'1>Q.
M-`4(B47PQT7T`````.C-U?__@_C_C5WHB<)T0X7`=%A0:@"-3>114N@"TO__
MBU7D@\00,<"%TG09B=#!^`B#XG]U"H/X0W0/@_A!=`JX_____XM=_,G#,<"+
M7?S)PY!2:%4T!0AJ`6H!Z,55``"#Q!"Z_____^O!@^P(4V@W2`4(Z'G5___'
M!"3_____Z)W6__^058GE4X/L)(M%",=%Z$1(!0C'1>Q0-`4(B47PQT7T````
M`.@EU?__@_C_C5WH=$6%P'1:46H`C4WD45#H7-'__XM5Y(/$$#'`A=)T&8G0
MP?@(@^)_=0J#^$-T$8/X070,N/____^+7?S)PXGV,<"+7?S)PY!3:%4T!0AJ
M`6H!Z!U5``"#Q!"Z_____^N_@^P(4VA$2`4(Z-'4___'!"3_____Z/75__^0
M58GE5E.![#P0``"+70B+=0Q3Z#DO``"#Q!"%P+K_____#X6O````A?:X9#0%
M"`^$K````&H`4U!H:C0%".AV2P``B1PDZ&KV__^#Q!"%]@^$L0```(F=\.__
M_\>%Z.___S=(!0C'A>SO__].-`4(QX7T[___`````.@FU/__@_C_C9WH[___
MB<(/A-D```"%P`^$!P$``%!J`(V%U.___U!2Z$W0__^#Q!"+A=3O__\QTH7`
M="")PL'Z"*A_=1*#^D,/A)0```"#^D$/A(L```"Z_____XUE^%N)T%[)PY!J
M`%.X=30%"%!H:C0%".C%2@``B1PDZ+GU__^#Q!"%]@^%3____XF=X.___\>%
MV.___T1(!0C'A=SO__]0-`4(QX7D[___`````.AUT___@_C_C9W8[___="Z%
MP'1&5FH`C8W0[___45#HIL___X/$$(N%T.___^E4____C67X6S'2B=!>R<.0
M4&A5-`4(:@%J`>B!4P``@\00N/_____I,O___X/L"%-H1$@%".@RT___QP0D
M_____^A6U/__@^P(4V@W2`4(Z^2-=@!5B>53@^PTBT4(QT7844@%",=%W``T
M!0C'1>!Z-`4(B47DQT7H`````.C*TO__@_C_C5W8="J%P'0_46H`C4W445#H
M`<___XM5U(/$$#'`A=)T!;C_____BUW\R<.-=@!3:%4T!0AJ`6H!Z-U2``"#
MQ!"X_____^O?@^P(4VA12`4(Z)'2___'!"3_____Z+73__^058GE5U93@>PD
M$```_W4,_W4(Z/W2__^#Q!`QTH7`=0J-9?1;7HG07\G#@^P(:@'_=0SH13$`
M`(/$$(7`B87@[___=#>#[`Q0Z,<N``"#Q!"%P'0GBT4(@#@M=4N`>`$`=46+
M/8AW!0B%_P^%4P(``*$D:P4(#[]`#NL\_W4,:&1(!0AJ`&H`Z"Q2``!8_[7@
M[___Z#`O``"Z`0```(UE]%M>B=!?R<.#[`AJ`/]U".A`T___@\00B87D[___
MB[7D[___A?8/B(4!``"+10R`."UU((!X`0!U&HL-B'<%"(7)#X7O`0``BQ4@
M:P4(#[]R#NL5@^P(:`$&``#_=0SH\=+__X/$$(G&A?:-O>CO__\/B'8!``")
M]E!H`!```%?_M>3O___HVM#__X/$$(7`B<-_$.MUC78`Z)?0___'``0```!0
M4U=6Z.C/__^#Q!"%P'3E.=ATP8/L$.AUT/__6_\PZ)W-__]:65#_=0S_=0AH
MD$@%"&H`:@#H.E$``(/$%/^UX.___^B\+0``B30DZ/#2__]8_[7D[___Z.32
M__^Z`0```.GS_O__0P^$J0$``(L=B'<%"(7;#X4J`0``H2!K!0@/OW@..?=T
M(H/L#%;HK]+__X/$$(7`#X4G`0``BS6(=P4(A?8/A38!``"+#21K!0@/OT$.
M.X7D[___=!F#[`S_M>3O___H=M+__X/$$(7`#X4A`0``@^P,_[7@[___Z"$M
M``"#Q!"%P'4',=+IZ_W___]U#&BT2`4(:@!J`.AR4```@\00,=+IT/W__X/L
M$.A\S___6_\PZ*3,__^)!"3_=0AH-TH%"&H`:@#H1%```(/$%/^UX.___^C&
M+```N@$```#I$?[__X/L$.A`S___6O\PZ&C,__^)!"3_=0QH-TH%"&H`:@#H
M"%```(/$%/^UX.___^B*+```Z='^__^#[`S_-21K!0CH`]'__^G>_?__@^P,
M_S4@:P4(Z/#0___I&O[__X/L#/\U(&L%".C=T/__@\00.?`/A<K^___IV?[_
M_X/L$.C%SO__7_\PZ.W+__^)!"3_=0QH4DH%".N#@^P,_S4D:P4(Z*+0__^#
MQ!#IOO[__X/L$.B2SO__7O\PZ+K+__^)!"3_=0AH4DH%".D1____@^P0Z'+.
M__];_S#HFLO__UI94/]U#/]U"&C@2`4(Z?C]__^-=@!5B>575E.!["00``"+
M11AFB87F[___:@#_=0CH5-#__XF%V.___X/$$$`/A$("```QP(M]#/RY____
M__*N]]&#[`R-6?^#P0=1Z&;,__^#Q!"%P(F%X.___P^$40(``%!3_W4,_[7@
M[___Z$7.__^+E>#O___'!!HN6%A8QT0:!%A86`")%"3H:,___XF%W.___X/$
M$$`/A/4!``!3:``0``"-M>CO__]6_[78[___Z-#-__^#Q!"%P(G'=$DQ]I`Y
M_G/84%>-G>CO__]3_[7<[___Z-S,__^#Q!"#^/^)PW0&*=_KVHGV@^P,_W4,
M_W4(:`A)!0AJ`6H!Z#E.```IWX/$(.NZ4?]U%/]U$/^UW.___^@,R___@\00
M0'1V@^P(#[>-YN___U'_M=SO___HL,K__X/$$$`/A)````"#[`S_M=SO___H
MN,___X/$$$`/A*H```"#[`S_M=CO___HH,___UA:_W4,_[7@[___Z/#+__^#
MQ!!`#X3$````@^P,_[7@[___Z(C/__^-9?1;7E_)PX/L#/]U#/]U"&@T204(
M:@%J`>B-30``@\0@@^P(#[>-YN___U'_M=SO___H(,K__X/$$$`/A7#___^#
M[`S_=0S_=0AH8$D%"&H!:@'H4TT``(/$((/L#/^UW.___^@.S___@\000`^%
M5O___X/L#/]U#/]U"&B,204(:@%J`>@A30``@\0@@^P,_[78[___Z-S.__]8
M6O]U#/^UX.___^@LR___@\000`^%//___X/L#/]U#/]U"&BX204(:@%J`>C?
M3```@\0@@^P,_[7@[___Z*K.__^-9?1;7E_)PX/L#/]U#/]U"&CD204(:@%J
M`>BO3```@\0@Z9_]__^#[`S_=0S_=0AH#$H%"&H!:@'HD$P``(/$(.GL_?__
M4&AO2@4(:@%J`>AY3```@\00Z9C]__^058GE5U93@^Q\,<#\N?____^+?0CR
MKO?1BQU`>`4(287;B4V$#X3!````,?_'18``````.SU$>`4(#X.B````BUV`
M`QU`>`4(ZQ:)]HLUA'<%"(M$EC0E`$```(7`="%##[83@?K_````=N&#[`Q2
MZ%C+__\E`$```(/$$(7`==^+583\.=*)WHM]"(G1\Z9U*HM%A`^V%`.!^O\`
M```/AV$!``"+/81W!0B+1)<T)0!```"%P`^%@@$``(L51'@%"#E5@',;BPU`
M>`4(BUV`_T6`@#P+``^$(0$``#E5@'+K,<"-9?1;7E_)PX/L"&@<+@4(:(%*
M!0CH?\O__XG'@\00,<"%_W3;BQ6(=P4(@^P(C76(A=)6#X7Y````#[]'#E#H
MU<G__X/$$(7`#X6]````BUVX@^P,@\,"4^BKR/__@\00A<"C0'@%"`^$G@``
M`%=J`?]UN%#H_\K__X/$$$@/A;L```"+1;B+#4!X!0BC1'@%",8$"``Q]HL5
M1'@%"#G6<Q>-=@"+#4!X!0B`/#$*C1PQ="]&.=9R[(/L#%?H!\O__X/$$.E]
M_O__C78`H81W!0B+1)`T)0!```"%P'0DQ@,`2P^^$X'Z_P```';?@^P,4NCR
MR?__)0!```"#Q!"%P'7<BQ5$>`4(1NNI@^P,5^BTRO__Z>3^__\Y58#I-/[_
M_X/L#%+HOLG__X/$$.F8_O__5^APR___6NG__O__@^P,_S5`>`4(Z!S,__]8
MQP5`>`4(`````.NU`UV$ZQ2+-81W!0B+1)8T)0!```"%P'0D0XH#A,!T'3P*
M=!D/MM"!^O\```!VUX/L#%+H6,G__X/$$.O3BTV`.PU$>`4(B=@/@EG^___I
M4O[__Y!5B>564X/L#(MU"%;H7_W__X/$$(7`B<-T!8`X`'425FB32@4(:@%J
M`>BR20``@\00C67XB=A;7LG#D)!5B>575E.![*00``!J`?]U"(M=$,>%?.__
M_P````#H12@``(/$$(7`B85X[___=!"#[`Q0Z,<E``"#Q!"%P'5$@^P0Z'C(
M__]9_S#HH,7__XD$)/]U"&BL2@4(:@!J`.A`20``@\04_[5X[___Z$(F``"Z
M`0```(UE]%M>B=!?R<.-=@"#[`B-A8CO__]0_W4(Z.K)__^#Q!"%P`^%F```
M`(/[`0^$Q@````^..@(``(/[`@^$6P,``(N%?.___X7`=3Y7_[68[____[64
M[____W4(Z,C&__^#Q!"%P`^(W00``(/L"`^WC9#O__]1_W4(Z+K&__^#Q!"%
MP`^(IP$``(/L#/^U>.___^@E)0``@\00,=*%P`^$6____X/L$.B<Q___6?\P
MZ,3$__^)!"3_=0AHW$H%".LIZ(+'__^#.`(/A%(!``"#[!#H<<?__UK_,.B9
MQ/__B00D_W4(:`Q+!0AJ`&H`Z#E(``#I`O___XN%?.___X7`#X51`0``@^P(
M:!PN!0C_=0CH(LC__X/$$(7`B85H[___#X3_!```_W4(:.M+!0AH`!```(VU
MZ.___U;H:,3__UM?:&@T!0A6Z.O'__^#Q!"%P(F%9.___P^$J`8``(GV5_^U
M:.___VC_#P``5NBVQ/__@\00A<`/A,,!```QP(GW_+G_____\J[WT8UY_\>%
M=.___P````"`O#WG[___"@^$Q````(M=#(L3A=)T0)!05U;_,^C>QO__@\00
MA<!U%XL+B@0Y/`IT!(3`=0K'A73O__\!````@\,$BP.%P'7/BYUT[___A=L/
MA7'___^#[`C_M63O__]6Z(K(__^#Q!!`#X58_____W4(:-1+!0AJ`6H!Z!-'
M``"#Q!#I/____\>%?.___P$```#I^?W__X/L$.@0QO__6_\PZ#C#__^)!"3_
M=0AH-$L%"&H`:@#HV$8``(/$((/L#/^U>.___^A7(P``Z9#]__^->?[I-/__
M_X7;#X7'_?__BU44A=(/A$P$``"#?10!#X6R_?__@^P(:/)+!0C_=0CHF<;_
M_X/$$(7`B86$[___#X1V`P``BW4,BSZ%_W1.B?HQP/R)U[G_____\JZ)R_?3
M_[6$[___2U-J`5+H/<?__XL.@\00@'P9_PIT%_^UA.___VH!:@%H#AH%".@=
MQ___@\00@\8$BQ:%TG6T@^P,_[6$[___Z%/&__^#Q!"%P`^$(?W__X/L$.@@
MQ?__7_\PZ$C"__^)!"3_=0AH4DH%".D+____@^P,_[5H[___Z!K&__^#Q!"%
MP`^$:P(``(/L$.CGQ/__6_\PZ`_"__^)!"3_=0AH4DH%"&H`:@#HKT4``(/$
M%/^U>.___^@Q(@``6?^U9.___^C1Q?__Z5[\__^#[`AH'"X%"/]U".B,Q?__
M@\00A<")A6#O__\/A&D"``#_=0AHZTL%"&@`$```C;WH[___5^C2P?__65MH
M:#0%"(VUZ.___U;H3\7__X/$$(7`B85<[___#X1:!```B?90_[5@[___:/\/
M``"-M>CO__]6Z!3"__^#Q!"%P`^$20$``#'`_+G_____C;WH[___\J[WT8U!
M_XF%<.___\>%;.___P````"`O`7G[___"@^$Z````(MU#(L^A?]TH8G[ZRB0
M#XZL````@WT4`@^$A@```(N%;.___X7`=&*#Q@2+'H7;#X1U____,<#\N?__
M__^)W_*N]]&-4?^`?!/_`'4#C5'^@WT4`76X.Y5P[___=\"-O>CO__]14BG7
M`[UP[___4U?HT</__X/$$(7`=:+'A6SO__\!````ZZ")]H/L"/^U7.___XV-
MZ.___U'HE\7__X/$$.N$@^P(4XV=Z.___U/H,L/__X/$$(7`=<'I7O___XM-
M%(7)#X53____.Y5P[___#X='____5U)3C97H[___4NA@P___ZXV#Z0*)C7#O
M___I"O___X/L$.CXPO__7O\PZ"#`__^)!"3_=0AH9$L%".GC_/__@^P,_[5@
M[___Z/+#__^#Q!"%P`^$Q0```(/L$.B_PO__7_\PZ.>___^)!"3_=0AH4DH%
M"&H`:@#HAT,``(/$%/^U>.___^@)(```7O^U7.___^BIP___Z3;Z__^#[`S_
MM63O___HEL/__X/$$(7`#X5#_?___W4(:.M+!0AH`!```%;HN+___UA:_W4(
M5NA=P?__@\00A<`/A$7Z__^#[!#H.L+__U__,.ABO___B00D_W4(:)1+!0CI
M)?S__X/L$.@:PO__7O\PZ$*___^)!"3_=0AH]$L%".D%_/__@^P,_[5<[___
MZ!3#__^#Q!"%P`^%P?S___]U"&CK2P4(:``0``"-E>CO__]2Z#"___]96_]U
M"(V=Z.___U/HS\#__X/$$(7`#X2M^?__@^P0Z*S!__]:_S#HU+[__X/$$%"-
MO>CO__]7:)1+!0C_-2AK!0CH"<'__UC_-2AK!0CH/<#__UCIB?O___]U"&CK
M2P4(:``0``"-E>CO__]2Z+Z^__];7FAH-`4(C;7H[___5N@[PO__@\00A<")
MA8#O__\/A(P"``"+=0R+/H7_=$Z)^HG7,<#\N?_____RKHG/]]?_M8#O__]/
M5VH!4NC?PO__BPZ#Q!"`?#G_"G07_[6`[___:@%J`6@.&@4(Z+_"__^#Q!"#
MQ@2+%H72=;2#[`AH'"X%"/]U".C#P?__@\00A<")PP^$;0$``%=3:``0``"-
ME>CO__]2Z).^__^#Q!"%P`^$"`$``(/L"/^U@.___XVUZ.___U;HT\+__X/$
M$$!UQX/L$.B%P/__6O\PZ*V]__^)!"3_=0AHM$L%"&H`:@#H34$``(/$%/^U
M>.___^C/'0``B1PDZ'/!__]8_[6`[___Z&?!___I]/?__X/L$.@ZP/__6?\P
MZ&*]__^#Q!!05FCT2P4(_S4H:P4(Z)V___]:_S4H:P4(Z-&^__]8_[5X[___
MZ'D=``!8_[5H[___Z!G!___IIO?__X/L$.CLO___6O\PZ!2]__^#Q!!0C97H
M[___4FCT2P4(_S4H:P4(Z$F___]8_S4H:P4(Z'V^__]8_[5X[___Z"4=``!8
M_[5@[___Z,7`___I4O?__X/L#%/HM\#__X/$$(7`=&^#[!#HB+___U[_,.BP
MO/__B00D_W4(:%)*!0AJ`&H`Z%!```"#Q!3_M7CO___HTAP``.D&____@^P0
MZ%&___]:_S#H>;S__XD$)/]U"&CT2P4(:@!J`.@90```@\04_[6`[___Z$?`
M__]8Z3/Y__^#[`S_M8#O___H,\#__X/$$(7`#X7@^?___W4(:.M+!0AH`!``
M`(V-Z.___U'H3[S__UE;_W4(C9WH[___4^CNO?__@\00A<`/A,SV__^#[!#H
MR[[__UK_,.CSN___@\004(V]Z.___U=H$$P%".D:_?__@^P0Z*:^__]9_S#H
MSKO__X/$$%"-G>CO__]3:/1+!0CI]?S__Y!5B>6#[`C_=13_=1"-1?A0BU4,
M_W4(B57XQT7\`````.BC]?__R<.058GE5U93@^P8BW4(5HM=#(M]$.BXO___
M@\00A<")PG0KA=MT!8M`"(D#A?]T!8M*#(D/BUT4A=MT"(MR'(M5%(DR,<"-
M9?1;7E_)PU9H,$P%"&H`:@#HZ3X``+C_____Z^*)]E6)Y5-1BU4,A=*+70AT
M)8/L#%/H5+___X/$$(7`=#R+0`R)1?@QP$!T(HM%^(M=_,G#B?:#[`Q3Z"^_
M__^#Q!"%P'07BT`(Z]F-=@#'1?@`````BT7XBUW\R<-3:#!,!0AJ`&H`Z'8^
M``"#Q!"X_____^NS58GEBU4(B@*$P'0;#[[`/?\```!W&/8$A65K!0@$=`Y"
MB@*$P'7EN`$```#)PS'`R<.)]E6)Y5-1BUT(Z$>]__^#[`S'``````!3Z"B_
M__^#Q!"%P'0(BT`(BUW\R<.#[!#H(;W__UK_,.A)NO__B00D4VAS3`4(:@!J
M`.CK/0``,<"+7?S)PU6)Y5-1BUT(Z/.\__^#[`S'``````!3Z%2Z__^#Q!"%
MP(G:=`>)T(M=_,G#@^P0Z,R\__]:_S#H]+G__XD$)%-HA$P%"&H`:@#HECT`
M`#'2Z].)]E6)Y5-0BUT(B=J*`^L9B?8/OL`]_P```'=+]@2%96L%"`1T04**
M`H3`=>50C47X4&B53`4(4^@1O?__@\00BUWXZ&:\__^#[`S'``````!3Z,>Y
M__^#Q!"%P(G:="J)T(M=_,G#Z$*\__^#[`S'``````!3Z".^__^#Q!"%P'0S
MBT`(BUW\R<.#[!#H'+S__UG_,.A$N?__B00D4VB$3`4(:@!J`.CF/```,=*#
MQ"")T.NM@^P0Z/&[__]:_S#H&;G__XD$)%-H<TP%"&H`:@#HNSP``(/$(#'`
MBUW\R<.058GE4X/L$(M="%/H++W__X/$$(7`=`B+0`B+7?S)PX/L$.BEN___
M6O\PZ,VX__^)!"13:%!,!0AJ`&H`Z&\\```QP(M=_,G#58GE4X/L$(M="%/H
MQ+S__X/$$(7`="E1:/\/``#_,&A@>`4(Z+N[___&!5^(!0@`@\00N&!X!0B+
M7?S)PXUV`%-HF$P%"&@`$```:&!X!0CHC[C__X/$$+A@>`4(BUW\R<.)]E6)
MY5.#[!"+70A3Z("X__^#Q!"%P'0I4VC_#P``_S!H8(@%".A7N___Q@5?F`4(
M`(/$$+A@B`4(BUW\R<.-=@!3:)A,!0AH`!```&A@B`4(Z"NX__^#Q!"X8(@%
M"(M=_,G#D)!5B>6#[&BAE&@%"(/X_W0$R<.)]H/L"(U%F%!HFTP%".A7O/__
M@\00A<!U$@^W5:"!X@#P``"!^@"```!T$<<%E&@%"`````"AE&@%",G#BU7,
MBT7(B=$)P77CQP64:`4(`0```.OAD%6)Y5=64X'LA````(U%B%#_=0CH'+K_
M_X/$$$`/A'`"```/MT60)0#P```]`*````^$1@$``#T`@```#X2"`0``@^P(
M:@1H^RL%".@DO/__B46`@\000`^$IP$``(/L#/]U".@<N___@\00A<")180/
MA,("``"#[`S_=0CH@[G__X/$$$`/A&T"``"0@^P,_W6$Z&VX__^#Q!"%P'1_
M@^P(C56(4HU8"%/HAKG__X/$$$`/A'@!```/MT60)0#P```]`$````^$N```
M`#T`@```=;E1_W40_W4,4^A4N/__@\000'6F@^P0Z&:Y__]:_S#HCK;__XD$
M)%-HI$T%"&H!:@'H,#H``(/$((/L#/]UA.CNM___@\00A<!U@8/L#/]U@.@L
MM___@\000`^$-@$``(/L#/]U@.C'N___@\000`^$(0$``(/L#/]UA.ABN___
M@\000`^$<`$``(M=%(7;=!E1_W40_W4,_W4(Z,*W__^#Q!!`#X2<`0``C67T
M6UY?R</\B=Z_^RL%"+D"````\Z8/A//^__^)WK_Z*P4(N0,```#SI@^$W_[_
M_VH!_W40_W4,4^A%_O__@\00Z<G^__]6_W40_W4,_W4(Z&*W__^#Q!!`=:2#
M[!#H=+C__UO_,.B<M?__B00D_W4(:*1-!0AJ`6H!Z#PY``"#Q"#I>/___X/L
M$.A(N/__6?\PZ'"U__^#Q!!0:,Q-!0AJ`6H!Z!(Y``"#Q!#I+_[__XGVZ!^X
M__^#.`(/A$[^__^#[!#H#KC__U[_,.@VM?__B00D4V@`3@4(:@%J`>C8.```
M@\0@Z5#^__^#[!#HY+?__U__,.@,M?__@\004&@H3@4(:@%J`>BN.```@\00
MZ;7^___HO;?__X,X`@^%@OW__X/L$.BLM___7_\PZ-2T__^)!"3_=0AHKTP%
M"&H!:@'H=#@``(/$(.E6_?__@^P0Z("W__]>_S#HJ+3__XD$)/]U"&C+3`4(
M:@%J`>A(.```@\0@Z63^__^#[!#H5+?__U__,.A\M/__B00D_W4(:.=,!0CI
MY_W__X/L$.@TM___6O\PZ%RT__^)!"3_=0AH!$T%".F[_O__@^P0Z!2W__]:
M_S#H/+3__XD$)/]U"&@@304(:@%J`>C<-P``@\0@Z1+]__]5B>575E.![(0`
M``"-18A0_W4(Z+BV__^#Q!!`#X1X`@``#[=%D"4`\```/0"@```/A$X!```]
M`(````^$B@$``(/L"&H$:/LK!0CHP+C__XE%@(/$$$`/A+`!``"#[`S_=0CH
MN+?__X/$$(7`B46$#X3*`@``@^P,_W4(Z!^V__^#Q!!`#X1U`@``D(/L#/]U
MA.@)M?__@\00A<`/A(````"#[`B-38A1C5@(4^@>MO__@\000`^$?`$```^W
M19`E`/```#T`0```#X2\````/0"```!UM8/L"`^W10Q04^C[M/__@\000'6A
M@^P0Z/VU__]?_S#H);/__XD$)%-H5$X%"&H!:@'HQS8``(/$((/L#/]UA.B%
MM/__@\00A<!U@(/L#/]U@.C#L___@\000`^$.0$``(/L#/]U@.A>N/__@\00
M0`^$)`$``(/L#/]UA.CYM___@\000`^$<P$``(M=%(7;=!R#[`@/MU404O]U
M".AHM/__@\000`^$G@$``(GVC67T6UY?R</\B=Z_^RL%"+D"````\Z8/A.O^
M__^)WK_Z*P4(N0,```#SI@^$U_[__VH!_W40_W4,4^@]_O__@\00Z<'^__^#
M[`@/MU4,4O]U".@%M/__@\000'6C@^P0Z`>U__]?_S#H+[+__XD$)/]U"&@[
M304(:@%J`>C/-0``@\0@Z7?___^#[!#HV[3__U[_,.@#LO__@\004&C,304(
M:@%J`>BE-0``@\00Z2;^__^0Z+.T__^#.`(/A$;^__^#[!#HHK3__UK_,.C*
ML?__B00D4V@`3@4(:@%J`>AL-0``@\0@Z4S^__^#[!#H>+3__U[_,.B@L?__
M@\004&@H3@4(:@%J`>A"-0``@\00Z;+^___H4;3__X,X`@^%>OW__X/L$.A`
MM/__6O\PZ&BQ__^)!"3_=0AHKTP%"&H!:@'H"#4``(/$(.E._?__@^P0Z!2T
M__];_S#H/+'__XD$)/]U"&C+3`4(:@%J`>C<-```@\0@Z6'^__^#[!#HZ+/_
M_UG_,.@0L?__B00D_W4(:.=,!0CIY/W__X/L$.C(L___6O\PZ/"P__^)!"3_
M=0AH64T%".F\_O__@^P0Z*BS__];_S#HT+#__XD$)/]U"&@@304(:@%J`>AP
M-```@\0@Z0K]__]5B>564XM='%/_=1#_=0R+=0A6Z!CY__]3_W48_W445NAO
M_/__C67X6S'`7LG#B?95B>575E.![(0```"-18A0_W4(Z!RS__^#Q!!`#X1`
M`@``#[=%D"4`\```/0"@```/A%X!```]`(````^$4P$``(/L"&H$:/LK!0CH
M)+7__XE%@(/$$$`/A%("``"#[`S_=0CH'+3__X/$$(7`B46$#X2O`@``@^P,
M_W4(Z(.R__^#Q!!`#X1Z`@``D(/L#/]UA.AML?__@\00A<!T<H/L"(U5B%*-
M6`A3Z(:R__^#Q!!`#X1(`0``#[=-D('A`/```('Y`$````^%Y@```/R)WK_[
M*P4(N0(```#SIG2MB=Z_^BL%"+D#````\Z9TG8/L"&H!4^@&____@\00@^P,
M_W6$Z/RP__^#Q!"%P'6/D(/L#/]U@.@YL/__@\000`^$$P$``(/L#/]U@.C4
MM/__@\000`^$_@```(/L#/]UA.AOM/__@\000`^$B@$``(M=#(7;=%.#[`S_
M=0CH@[#__X/$$$!U0NCHL?__@S@"=#B#[!#HV['__UG_,.@#K___B00D_W4(
M:'5-!0CI#0$``(UV`(/L#/]U".@ELO__@\000`^$S````(UE]%M>7\G#C78`
M@^P,4^@'LO__@\000`^%Q?[__^B(L?__@S@"#X2W_O__@^P0Z'>Q__]:_S#H
MGZ[__XD$)%-H?$X%"&H!:@'H03(``(/$(.F-_O__D.A/L?__@S@"#X1^_O__
M@^P0Z#ZQ__]9_S#H9J[__XD$)%-H`$X%"&H!:@'H"#(``(/$(.F`_O__@^P0
MZ!2Q__]?_S#H/*[__X/$$%!H*$X%"&H!:@'HWC$``(/$$.G8_O__Z.VP__^#
M.`(/A;+]___I-/___^C:L/__@S@"#X0F____@^P0Z,FP__]:_S#H\:W__XD$
M)/]U"&BH3@4(:@%J`>B1,0``@\0@Z?K^__^#[!#HG;#__U__,.C%K?__@\00
M4&C,304(:@%J`>AG,0``@\00Z83]__^#[!#H<[#__U[_,.B;K?__B00D_W4(
M:,M,!0AJ`6H!Z#LQ``"#Q"#I2O[__X/L$.A'L/__6_\PZ&^M__^)!"3_=0AH
MYTP%".G)_O__@^P0Z">P__]>_S#H3ZW__XD$)/]U"&@@304(:@%J`>CO,```
M@\0@Z27]__^-=@!5B>575E.![)0```"-18A0_W4(Z,BO__^#Q!!`#X1X`@``
M#[=%D"4`\```/0"@```/A+8!```]`(````^$LP$``(/L"&H$:/LK!0CHT+'_
M_XE%@(/$$$`/A+`!``"#[`S_=0CHR+#__X/$$(7`B46$#X2*`@``@^P,_W4(
MZ"^O__^#Q!!`#X1)`@``D(/L#/]UA.@9KO__@\00A<`/A.8```"#[`B-58A2
MC5@(4^@NK___@\000`^$?`$```^W19`E`/```#T`0```=&P]`(```'6YBT44
MA<!TLHM]##'`_+G_____\J[WT591_W4,4^A<K___@\00A<!UD8/L"/]U$/]U
M#.@'KO__@\000`^%>?___X/L$.CEKO__6O\PZ`VL__]>7U#_=1#_=0QHR$X%
M".FY`0``B?;\B=Z_^RL%"+D"````\Z8/A#____^)WK_Z*P4(N0,```#SI@^$
M*____VH!_W40_W4,4^B1_O__@\00@^P,_W6$Z#.M__^#Q!"%P`^%&O___X/L
M#/]U@.AMK/__@\000`^$TP```(/L#/]U@.@(L?__@\000`^$O@```(/L#/]U
MA.BCL/__@\000'4I@^P0Z#6N__]9_S#H7:O__XD$)/]U"&C+3`4(:@%J`>C]
M+@``@\0@B?:-9?1;7E_)P_]U"&CX3@4(:@%J`.C?+@``C67T6UY?R<.#[!#H
MZZW__U[_,.@3J___@\004&C,304(:@%J`>BU+@``@\00Z2;^__^0Z,.M__^#
M.`(/A$;^__^#[!#HLJW__UK_,.C:JO__B00D4V@`3@4(:@%J`>A\+@``@\0@
MZ4S^__^#[!#HB*W__UO_,.BPJO__@\004&@H3@4(:@%J`>A2+@``@\00Z1C_
M___H8:W__X,X`@^%>OW__X/L$.A0K?__7_\PZ'BJ__^)!"3_=0AHKTP%"&H!
M:@'H&"X``(/$(.E._?__@^P0Z"2M__]9_S#H3*K__XD$)/]U"&CG3`4(:@%J
M`>CL+0``@\0@Z8S]__^#[!#H^*S__UO_,.@@JO__B00D_W4(:"!-!0AJ`6H!
MZ,`M``"#Q"#I2OW__U6)Y593@>Q@$```H9QH!0B%P(MU"+N<:`4(#X30````
M@^P(_S!6Z-T&``"#Q!"%P`^%S````(/#!(L#A<!UX59H)$\%"&H!:@'H:BT`
M`(/$$(/L"(V%F.___U!6Z#.N__^#Q!"%P'084&AH3P4(:@%J`>A!+0``C67X
M6U[)PXGV@^P,_S68:`4(BQ/_,FB2304(:``0``"-G?CO__]3Z)&I__^#Q!13
MZ*BJ__^#Q!"%P'13@^P,4U9HG$\%"&H!:@#H\BP``(/$&%-6Z%0$``"#Q!"%
MP'2@4&C$3P4(:@%J`>C2+```@\00C67X6U[)PZ&<:`4(A<`/A53____I/?__
M_XL#Z^]0:/1/!0AJ`6H!Z*,L``"#Q!#KF8GV58GE5U93@^Q\H9QH!0B%P,=%
MA)QH!0@/A.P```"#[`S_,.C!K/__@\00A<")Q@^$W0```(M=A(/L#(L+_S'H
M):O__X/$$(GV@^P,5N@7JO__@\00A<")P@^$B@```(/L"(U]B%>-6@A3Z`JM
M__^#Q!!`=&P/MT60)0#P```]`$```'7$BQ68:`4(B56`,<"+?8#\N?_____R
MKO?125!1_W6`4^A@J___@\00A<!UF6H`4VB>304(:)@9!0CH6Q0``(/$$(7`
M=(!3:#10!0B)]FH!:@#HPRL``.EE____B?93:&A0!0CKZ(/L#&BB304(Z'.J
M__^#180$BW6$@\00BP:%P`^%%/___XUE]%M>7\G#@^P0Z)^J__]:_S#HQZ?_
M_XD$)(M5A(L"_S!H($T%"&H!:@#H8RL``(UE]%M>7\G#D)"058GE4X/L#(M=
M"&@!!@``4^A_K/__@\00A<!X$(/L#%#H_ZS__S'`BUW\R<.#[!#H0*K__UK_
M,.AHI___B00D4VB,4`4(:@!J`.@**P``N/____^+7?S)PU6)Y5.#[`R+70AH
M`0(``%/H)ZS__X/$$(7`>!"#[`Q0Z*>L__\QP(M=_,G#@^P0Z.BI__]9_S#H
M$*?__XD$)%-HMU$%"&H`:@#HLBH``+C_____BUW\R<-5B>575E.#[!2+?0R)
M1?")5>QJ+U#H^JC__X/$$(7`B<,/M_=T)SM%\'0BQ@``B?"#[`@E_P$``%#_
M=0B+5>R+1?#HN?___\8#+X/$$(/L"%;_=?#H"ZS__X/$$$!T'5;_=0C_=>S_
M=?#H-JC__X/$$$!T4(UE]%M>7\G#Z$.I__^#.!%T[H/L$.@VJ?__7_\PZ%ZF
M__^)!"3_=?!HN%`%"&H!:@'H_BD``(/$(%;_=0C_=>S_=?#HZ*?__X/$$$!U
MLHGV@^P0Z/BH__];_S#H(*;__XD$)/]U\&C4404(:@%J`.C`*0``@\0@C67T
M6UY?R<.058GE5U93@^P4BT4,BWT0#[==%(E%\/]U"&@=4P4(Z!4H``")QEA:
M4U>+5?")\.C9_O__B74(@\00C67T6UY?R>E+J___C78`58GE5E.+=0@/MUT4
MZ'>H__^#[`C'``````!35N@'J___@\00A<!T"NA;J/__@S@1=5]0_W40_W4,
M5N@II___@\00A<!T"N@]J/__@S@"=6J#[`A35N@>I___@\00A<!U"S'`C67X
M6U[)PXGVZ!>H__^#.`)TZX/L$.@*J/__6?\PZ#*E__^)!"16:-A0!0CK&8/L
M$.COI___6O\PZ!>E__^)!"16:/A0!0AJ`&H`Z+DH``"X_____^NI@^P0Z,:G
M__];_S#H[J3__XD$)%9H&%$%".O5C78`58GE5U93@^QTC5V(4XMU"%:+?0SH
M5ZG__X/$$(7`=`PQP(UE]%M>7\G#B?:#[`A35^@ZJ?__@\00A<!T.X/L"%=6
MZ'FF__^#Q!"%P'32@^P0Z%JG__]:_S#H@J3__UE;4%=6:.A1!0AJ`&H`Z",H
M``"X_____^NJ5V@X404(:@!J`.@-*```N/_____KE(GV58GE5E.#[&"+=0B+
M713H#:?__\<``````(/L"(U%F%!6Z+JH__^#Q!"%P'0+,<"-9?A;7LG#B?90
M_W40_W4,5NB[I?__@\00A<!U/8/L"`^WTU)6Z+>E__^#Q!"%P'3-@^P0Z+BF
M__]9_S#HX*/__XD$)%9H>%$%"&H`:@#H@B<``+C_____ZZ:#[!#HCZ;__UO_
M,.BWH___B00D5FB8404(Z]55B>53@^P0_W4(Z(VG__^#Q!"%P(G#=0B)V(M=
M_,G#D(/L$.A4IO__6O\PZ'RC__^#Q!!0:`92!0AJ`&H`Z!XG``")V(/$$(M=
M_,G#58GE5U93@^QLBWT(QP<`````BUT,BS.%]G0KC76(B?:#[`A6_S/HQ:?_
M_X/$$(7`=!Z#PP3H]J7__XL+A<G'``````!UVHUE]%M>,<!?R<.+`XD'C67T
M6UZX`0```%_)PY"0D%6)Y5=64X'LA#```(U=B%.+=0A6BWT,Z)"E__^#Q!"%
MP'40#[=%D"4`\```/0!```!T"C'`C67T6UY?R<.#[`A35^AEI?__@\00A<!U
MY0^W59"!X@#P``"!^@!```!UTX/L"&@`$```C9V(S___4^BXIO__B30DZ`"E
M__]>6&@`$```C;6([___5NB=IO__B3PDZ.6D__]:66@`$```C96(W___4NB"
MIO__C;V(W___B1PDZ,2D__\QP/RY______*N]]&-6?]04U:-C8C?__]1QX6`
MS___`````.@\I?__@\0@A<!U"H"\'8CO__\O=`N+A8#/___I.?___\>%@,__
M_P$```#KZ56)Y8M5"#'`A=)T!8`Z`'4%N`$```#)PU6)Y5=64X'L@#```(M=
M"&@`$```:@"-A8C?__]0Z(JE__^#Q`QH`!```&H`:&"8!0CH=J7__UY?:``0
M``"-M8C/__]6Z,.E__^#Q!"%P`^$50$``(/L"(U5B%)3Z`NF__^#Q!"%P`^%
M2`$``%%H`!```%.-G8CO__]3Z(VD__\/MTV0@>$`\```@\00@?D`0```="R#
M[`AJ+U/H+:/__X/$$(7`='[&``!2:``0``!`4(V]B-___U?H3Z3__X/$$(/L
M#%/HDZ/__X/$$(7`=1F#[`AH`!```&A@F`4(Z"JE__^#Q!"%P'4;4&@D4@4(
M:@!J`.B8)```C67T6UXQP%_)PXGV@+V(W___`'4_@^P,5NA&H___C67T6UZX
M8)@%"%_)PY!0:``0``!3C86(W___4.C5H___@\0,:``0``!H^RL%"%/I;O__
M_XGV_+]@F`4(4+G_____,<#RKKL`$```]]%)B=HIRE)H:U(%"&A@F`4(Z/2C
M__^_8)@%"/PQP+G_____\J[WT4F#Q`PIRU.-G8C?__]3:&"8!0CHRZ/__X/$
M$.ED____4VAM4@4(Z3O___]3:$Q2!0CI,/___Y!5B>6#[!#_=0AHUA@%".C=
M`@``@\0,4/\U/'@%"&B*4@4(Z"TB``#)PXUV`%6)Y8M5"#'`A=)T"#'`@SH`
M#Y_`R<.)]E6)Y8M5"(72N`$```!T"#'`@SH`#Y3`R<.-=@!5B>564XM="#'V
MA=NX_____W0HBP.%P'X0@^P,4.@:I?__@\00A<!X*8M#!(7`=12#[`Q3Z!.E
M__^)\(UE^%M>R<.)]H/L#%#H_Z3__X/$$.O>@^P0Z#*B__]:_S#H6I___XD$
M)/]S!&C`4@4(:@%J`.CZ(@``OO____^#Q"#KJ56)Y593BUT(,?:%V[C_____
M="N+`X7`?A"#[`Q0Z)JD__^#Q!"%P'@MBT,$A<!U&(/L#%/HDZ3__X/$$(GP
MC67X6U[)PXUV`(/L#%#H>Z3__X/$$.O:@^P0Z*ZA__]9_S#HUI[__XD$)/]S
M!&C`4@4(:@%J`.AV(@``OO____^#Q"#KI56)Y5=64X/L&(M]"(MU%&H(Z-*?
M__^#Q!`QTH7`B<-T4F:%]L<``````,=`!`````!U38/L"%=H'5,%".BO(```
M@\0,B4,$:*0!``#_=0Q0Z%.C__^#Q!"%P(D#>&&#[`C_=1!0Z"ZA__^#Q!"%
MP(G:=7V-9?1;7HG07\G#C78`@^P(5VC6&`4(Z/X```"#Q`Q0_S4\>`4(:(I2
M!0CH3B```(/$#(E#!&BD`0``_W4,4.CRHO__@\00A<")`WF?@^P0Z,&@__]>
M_S#HZ9W__XD$)/]S!&B?4@4(:@!J`.B)(0``B=J-9?1;7HG07\G#D(/L#/\S
MZ#ZC__^#Q!#HAJ#__X,X(P^4P@^VPDB)VHD#Z].)]E6)Y8/L"`^_10Q0:@9H
M`@8``/]U".C2_O__R<-5B>6#[`@/OT4,4&H":`(&``#_=0CHMO[__\G#58GE
M5U93@^P,BWT(OF"H!0@QVY!0#[8$'U!H[U(%"%9#Z):A__^#Q@*#Q!"#^P]^
MXXUE]%M>N&"H!0A?R<.)]E6)Y5=64X'L*!```/]U#/]U"&AJ,P4(C9WH[___
M:``0``!3Z#2=__^#Q!QJ`(G?_#'`N?_____RKO?125%3Z,F<__^)QH/$$+M@
MJ`4(,?^04@^V%#Y2:.]2!0A31^@:H?__@\,"@\00@_\/?N.-9?1;7KA@J`4(
M7\G#D)!5B>575E.![!P0``"AB'<%"(7`BUT(BWT,#X4A`0``BPTD:P4(#[]1
M#CG:#X3S````H2!K!0@/OT`..?@/A.(```"#[`R-E>#O__]2Z"^>___HNI__
M_X/$$(7`B<8/C`X"```/A!`!``"#[`S_M>3O___HN:'__XV=Z.___X/$$.LH
MB?;&A`7G[___`%-H'5,%"&H`:@#HR1\``%__-2AK!0CHF9W__X/$$%%H_P\`
M`%/_M>#O___H])[__X/$$(7`?\&#[`S_M>#O___H7Z'__X/$#&H"C9W<[___
M4U;H?9O__X/$$$`/A*X!``"+E=SO__^)T(/@?W0;@_A_=`B%P`^%KP$``(G7
M@^=_@_]_#X1!`0``C67T6UZ)T,'X"%_)PXGV4&CH4P4(:@!J`.@Q'P``C67T
M6UZX_____U_)PX/L#/\U)&L%".@RH/__@\00.=ATSXLUB'<%"(7V#X3._O__
M@^P,_S4@:P4(Z`^@__^#Q!#IP?[__X/L#&H`Z*V@___'!"0!````Z*&@___'
M!"0"````Z)6@__]8_[7@[___Z(F@__]>6&H`4^C_F___65MJ`5?H]9O__UA:
M:@+_M>3O___HYIO__U]8_W44_W40Z%F>__^)A=SO___HGIW__U[_,.C&FO__
M@\0,4&@@5`4(_S4H:P4(Z`*=___H?9W__X/$$(,X#G0Z_S4H:P4(:@)J`6CT
M4@4(Z#&?__];_S4H:P4(Z!6<__]9_[7D[___Z/F?__^+A=SO__^-9?1;7E_)
MP_\U*&L%"&I8:@%H1%0%".O$@^P,P?H(4E9HH%0%"&H`:@#H^!T``.G"_O__
M@^P0Z`>=__]:_S#H+YK__X/$$%!HU%0%"&H!:@'HT1T``(/$$.F8_O__@^P0
MZ-V<__]:_S#H!9K__XD$)%9H]%0%".NM@^P,4%9H.%4%".NAB?95B>575E.#
M[`R+=0B)1?"+?0R-1OPY^(G3=BE1BQ>)T/?0`P90`Q-2BTWP_S'HNIS__X/$
M$(7`?C\!!XUE]%M>7\G#D(L6@^P(@<(`$```B192_S/HXYS__X/$$(7`B0-U
MN5!H]U(%"&H!:@'H+QT``(/$$.NEB?:#[`R+=?#_-NCGGO__BUWPQP/_____
MZ"F<__]:_S#H49G__X/$#%!H;%4%"/\U*&L%".B-F___Z`B<___'``````"#
MQ!"-9?1;7E_)PXUV`%6)Y5=64X'L/`$``(M%$#')C5T0C544A<#K"HG6BSY!
M@\($A?]U](/L#(T4C0@```!2Z!V:__^#Q!"%P(F%T/[__P^$;`,``(M%#(N-
MT/[__XD!C5,$N0$```"+`^L1B=.+O=#^__^)!(^#P@1!BP.%P'7KBY70_O__
M@^P,C;7@_O__QP2*`````,>%R/[__P````!6Z%J:__^#Q!#HXIO__X7`B87,
M_O__#XS%`@``#X[.`P``@^P,QX7$_O__`!```/^UY/[__^C6G?__QX7`_O__
M`````,<$)``0``#H<)G__UI9BTT(B0%J`_^UX/[__^A\G?__@\@$@\0,4&H$
M_[7@_O__Z&B=__^-M6C___^#Q!"X(````$B%P,<$A@````!U](V=Z/[__[`@
M2(7`QP2#`````'7TBXW@_O__B<^P`8/A']/@P>\%"82]:/___^B<FO__C;W8
M_O__@^P,QP``````QX78_O__`0```,>%W/[__P````!74U-6BY7@_O__0E+H
M")G__X/$(.A@FO__BP"%P`^%[0```(N5X/[__XG0P>@%B=&#X1^+A(5H____
MT^BH`0^$]P```%"+A<3^__\KA<#^__](4(N%P/[__XM-"`,!4%+H1)K__X/$
M$(/X_P^$10(``(7`#X[P````BY7$_O__`87`_O__2CN5P/[__P^.TP$``+@@
M````B?9(A<#'!(8`````=?2P((GV2(7`QP2#`````'7TBXW@_O__B<JP`8/A
M']/@P>H%"825:/___^BFF?__@^P,QP``````QX78_O__`0```,='!`````!7
M4U-6BY7@_O__0E+H&YC__X/$(.ASF?__BP"%P`^$$____^ADF?__@S@$=4^+
ME>#^__^)T,'H!8G1@^$?BX2%:/___]/HJ`$/A0G___]0:@&-E=3^__]2_[7,
M_O__Z`F6__^#Q!`[A<S^__\/A3/____'A<C^__\!````BTT(BSF+M<#^___&
M!#<`BYW(_O__A=L/A`D!``"+A=3^__^H?[O_____=1>)P\'["`^$@0```('[
M_P````^$0@$``(/L"(MU"/\V4_]U#&B0504(:@%J`.B7&0``@\0@BTT(@^P,
M_S'H8YO__X/$$(M]"(/L#,<'`````/^UT/[__^A)F___C67TB=A;7E_)PX/L
M$.AWF/__6O\PZ)^5__^#Q!!0:`Y3!0AJ`6H!Z$$9```QVX/$$(/L#/^UT/[_
M_^@*F___C67TB=A;7E_)PX/L$.@XF/__7O\PZ&"5__^#Q!!0:"!3!0AJ`6H!
MZ`(9``"#Q!#I:OS__XGV@^P(@87$_O__`!```/^UQ/[__XM%"/\PZ'>8__^+
M30B#Q!")`>D#_O__QX74_O__`````%-J`(V%U/[__U#_M<S^___HJY3__X/$
M$.G0_O__Z+Z7__^#.`0/A*7^__^#[!#HK9?__UG_,.C5E/__@\004&@[4P4(
M:@%J`.AW&```@\00Z7O^__^+50C_,FA84P4(:@%J`.A<&```@\00Z<#^__^#
M[`S_M>#^___H$IK__\<$)`$```#H!IK__\<$)`(```#H^IG__UA::@'_M>3^
M___H:Y7__U]8:@+_M>3^___H7)7__UM>_[70_O___W4,Z,R7___H%Y?__UG_
M,.@_E/__@\0,4/]U#&AB4P4(Z/Z3___'!"3_____Z-*8__^)]E6)Y593BW4(
MBUT,.=Z)\'0;@_[_=!Z#[`A35N@`E?__B<.)-"3H=IG__XG8C67X6U[)PY"#
M[`AJ`FC6,@4(Z,V8__^)QH/$$(/^_[C_____=<3KV%6)Y593@>RP`0``BW4(
MC4T,B;58_O__N@$```"#^F-_$XG+BP.#P02)A)58_O__0H7`=>C'1>@`````
MZ.R6__^%P'0E@^P,C8U4_O__4>@9EO__@\00,<#VA53^__]_#Y7`C67X6U[)
MPX/L#&H`Z-F8___'!"0!````Z,V8___'!"0"````Z,&8__]86FH":-8R!0CH
M(YC__UF)PUAJ`%/H)Y3__UA::@%3Z!V4__]96&H"4^@3E/__6%J-E5C^__]2
M5NB$EO__B00DZ*R7__]5B>575E.#[!1H'"X%"/]U#,=%\`````#HGY+__X/$
M$(7`B<8/A"0!``"#[`QH`1```,=%[``0``#'1>@`````Z.>3__^#Q!"%P(G'
M#X0:`0``Q@``ZR^0BU8$2H72B58$#XC4````BPX/MAE!@_O_B0YT+XM%[#E%
MZ'18BT7HB!PX0(E%Z(L=B'<%"(7;=,B#[`Q6Z".3__^)PX/$$(/[_W71@^P,
MBT7HQ@0'`%;H:9+__X/$$(/X_W1WP?@(=`.)1?"+=0B)/HM%\(UE]%M>7\G#
MD(M5Z(/L"('"`1```%*+3>B!P0`0``!7B4WLZ%F5__^#Q!"%P(G'=8#_-2AK
M!0AJ26H!:+15!0CHC);__\=%Z`````"#Q!"#[`R+1>C&!`<`5NCRD?__@\00
M@_C_=8G'1?#_____ZXB#[`Q6Z"B2__^)PX/$$.E0_____S4H:P4(:EQJ`6@`
M5@4(Z#J6__^X_____^E?_____S4H:P4(:B9J`6A@5@4(Z^"-=@!5B>53@^P,
MC47XQT7X`````/]U"%#H9O[__X/$$(/X_XG#=#R%P'0CBT7X@^P,@#@`=06X
M=5,%"%!3:(A6!0AJ`6H`Z.@4``"#Q""#[`S_=?CHMI;__XG8BUW\R<.-=@"#
M[!#HY)/__UK_,.@,D?__@\004&BT5@4(:@%J`.BN%```@\00@^P,_W7XZ'R6
M__^)V(M=_,G#D%6)Y593Z,J0__^)QKL#````.?-]%(UV`(/L#%/H0Y;__T.#
MQ!`Y\WSOZ(:3___'``````"-9?A;7LG#D%6)Y5=64X/L#(M]%.CWD___@_C_
MB<,/A,````"%P`^%S````(MU"(7V="2#_O\/A,8```"#[`AJ`%;H:9'__XG#
MB30DZ-^5__^#Q!!#=&"+=0R#_@%T)(/^_P^$N0```(/L"&H!5N@]D?__B<.)
M-"3HLY7__X/$$$-T-(MU$(/^`@^$M````(/^_P^$_P```(/L"&H"5N@-D?__
MB<.)-"3H@Y7__X/$$$,/A8P```"#[!#HP9+__U[_,.CIC___@\0,4&B!4P4(
M_S4H:P4(Z"62__];:O_H?93__Y!7:.!6!0AJ`6H!Z'$3``"#Q!")]HUE](G8
M6UY?R<.#[`AJ`FC6,@4(Z(^4__^#Q!"#^/^)Q@^%'?___^N6@^P(:@)HUC(%
M".APE/__@\00@_C_B<8/A2K____I=/___^A8C___NP,````YPXG&?&GH*)+_
M_X/L",<``````/]U&%?HQI+__X/L$.@.DO__6?\PZ#:/__^#Q!!05V@`5P4(
M_S4H:P4(Z'&1__^#Q!3I1?___X/L"&H":-8R!0CH^I/__X/$$(/X_XG&#X7D
M_O__Z?[^__^-=@"#[`Q30^AJE/__@\00.?-]AH/L#%-#Z%F4__^#Q!`Y\WS>
MZ7#___^058GE5U93@>S8````BT4(BTT,C;5@____QP``````QP$`````5L>%
M2/___P````#'A4S___\`````QX5`____`````,>%1/___P````#'A33___\`
M````QX4P____`````.@VD/__@\000`^%[P$``(V=6/___U!H)%<%"&H!:@'H
M^Q$``(/$$(N%6/___XN58/___SG0?0*)T(UX`5!J!&H$4NATD___@\000`^$
M(@(``%%J!&H$_[58____Z%J3__^#Q!!`#X0(`@``@^P,_W44_W40_W,$_W8$
M:@#H0OW__XN-8/___X/$((/Y_XF%./___P^$\0$``(N=6/___XVU:/___[@@
M````D$B%P,<$A@````!U](/Y_W03B<JP`8/A'\'J!=/@"825:/___X/[_W08
MB=J#XQ^X`0```(C9P>H%T^`)A)5H____QX50____`0```,>%5/___P````"-
MG5#____H,)#__X/L#,<``````%-J`&H`5E?HNX[__X/$((7`#XYT`0``BXU@
M____A<E^&8G*P>H%@^$?BX25:/___]/HJ`$/A=$```"+G5C___^%VWX;B=K!
MZ@6)V8/A'XN$E6C____3Z*@!#X73````BXU@____@_G_#X4C____@_O_#X4:
M____B[4P____A?9U->BAC___QP``````4&H!C;T\____5_^U./___^AFC/__
M@\00A<#'A33_________#X5C`0``BT4(BQ"%TG0*BXU,____Q@0*`(MU#(L6
MA=)T"HN]1/___\8$.@"+A33___^-9?1;7E_)PX/L#(V=6/___U/H+H[__X/$
M$$`/A1#^___I^?W__XUV`(/L"(V=3/___U.-C4C___]1BU4(C85@____Z$'R
M__^#Q!#I"/___X/L"(V%1/___U"-G4#___]3BU4,C858____Z!KR__^#Q!"+
MG5C____I`/___U)H2%<%"&H!:@'HG0\``(/$$.GA_?__BYU8____@_O_#X4&
M_O__Z??^__^0Z)>.___'``````!0:@&-C3S___]1_[4X____Z%R+__^#Q!"%
MP'2BZ'".__^+$(72=5"+A3S___^H?W5&P?@(B84T____@^P,_[58____Z/F0
M__]8_[5@____QX58_________^CCD/__QX5@_________\>%,/___P$```#I
M1/___\>%-/_________KM^@)CO__BQB%VW4;BX4\____J']U$<'X"(F%-/__
M_^EZ_O__C78`QX4T_________^EH_O__D%6)Y8M%%%93,<F-712-51B%P.L*
MB="+,$&#P@2%]G7T@^P,C12-!````%+H"(S__X/$$(7`B<9T1XL#,<F%P(U3
M!(D&=07K#XD$CHG3BP-!@\($A<!U\<<$C@````!6_W40_W4,_W4(Z,_[__^)
MPXDT).@AD/__C67XB=A;7LG#@^P0Z%"-__]:_S#H>(K__X/$$%!HGU,%"&H!
M:@'H&@X``(/$$.N2D%6)Y593@^P0BW4(_W4,5HU5]%*-1?!0Z'C[__^#Q!"%
MP(G#="N+31"%R74DBT7PA<!U.HM%](7`=$J#[`Q05FBS4P4(:@%J`.C'#0``
M@\0@@^P,_W7PZ)6/__]8_W7TZ(R/__^-9?B)V%M>R<.#[`A0_S4H:P4(Z#2,
M__^#Q!#KLHUV`%9H>%<%"&H!:@#H@0T``(/$$(/L#/]U\.A/C___6/]U].A&
MC___C67XB=A;7LG#D%6)Y5=64X/L#(M%##')BWT(C74,C540A<#K"Y")T(L8
M08/"!(7;=?2#[`R-%(T$````4NBDBO__@\00A<")PP^$U@```(L&,<F%P(U6
M!(D#=07K#XD$BXG6BP9!@\($A<!U\<<$BP````!35XU5\%*-3>Q1Z&?Z__^#
MQ!"%P(G&="2+1>R%P'5[BT7PA<!T/(/L#%!7:+-3!0AJ`6H`Z+T,``"#Q""#
M[`S_=>SHBX[__UC_=?#H@H[__XD<).AZCO__C67T6XGP7E_)PU=H>%<%"&H!
M:@#HA0P``(/$$(/L#/]U[.A3CO__6/]U\.A*CO__B1PDZ$*.__^-9?1;B?!>
M7\G#@^P(4/\U*&L%".CIBO__@\00Z6[___^#[!#H68O__UK_,.B!B/__@\00
M4&B?4P4(:@%J`>@C#```@\00Z0#___^-=@!5B>564X/L$(M="/]U#%.-5?12
MC47P4.A\^?__@\00A<")QG0DBT7PA<!U=(M%](7`=#F#[`Q04VBS4P4(:@%J
M`.C2"P``@\0@@^P,_W7PZ*"-__]8_W7TZ)>-__^#Q!"-9?A;B?!>R<.-=@!3
M:'A7!0AJ`6H`Z)T+``"#Q!"#[`S_=?#H:XW__UC_=?3H8HW__X/$$(UE^%N)
M\%[)PXGV@^P(4/\U*&L%".@%BO__@\00Z77___^058GE5E.![!@0``"+70AJ
M+U/HEHS__X/$$(7`#X6K````@^P,4_\U/'@%"&C+4P4(:``0``"-G?CO__]3
MZ)N'__^#Q"#_=0Q3C97T[___4HV%\.___U#HA?C__X/$$(7`B<9T+(N%\.__
M_X7`=7J+A?3O__^%P'1`@^P,4%-HLU,%"&H!:@#HU0H``(/$((GV@^P,_[7P
M[___Z)Z,__]8_[7T[___Z)*,__^#Q!"-9?A;B?!>R<.)]E-H>%<%"&H!:@#H
MF0H``(/$$.O$4VB85P4(:@!J`.B%"@``C67X6[C_____7LG#D(/L"%#_-2AK
M!0CH!8G__X/$$.EO____D%6)Y593@>RP`0``BW4(C4T,B;58_O__N@$```"#
M^F,/CY\```")RXL#@\$$B8256/[__T*%P'7D@_IC#X^#````QX256/[__P``
M``"-A5C^__]05HV-5/[__U&-E5#^__]2Z'GW__^#Q!"%P(G#="Z+A5#^__^%
MP`^%B@```(N%5/[__X7`=$B#[`Q05FBS4P4(:@%J`.C%"0``@\0@@^P,_[50
M_O__Z)"+__]8_[54_O__Z(2+__^#Q!"-9?B)V%M>R</'1>@`````Z7S___]6
M:'A7!0AJ`6H`Z($)``"#Q!"#[`S_M5#^___H3(O__UC_M53^___H0(O__X/$
M$(UE^(G86U[)PX/L"%#_-2AK!0CHY8?__X/$$.E?____D%6)Y593@>RX$0``
MBW4(:B]6Z':*__^#Q!"%P`^%``$``(/L#%;_-3QX!0AHRU,%"&@`$```C;7X
M[___5NA[A?__C5T,B;58[O__N@$```"#Q"")]H/Z8P^/H0```(G9BP&#PP2)
MA)58[O__0H7`=>2#^F,/CX4```#'A)58[O__`````(V%6.[__U!6C9U4[O__
M4XV54.[__U+H(?;__X/$$(7`B<-T,(N%4.[__X7`#X6&````BX54[O__A<!T
M38/L#%!6:+-3!0AJ`6H`Z&T(``"#Q"")]H/L#/^U4.[__^@VBO__6/^U5.[_
M_^@JBO__@\00C67XB=A;7LG#QX7H[___`````.EW____5FAX5P4(:@%J`.@D
M"```@\00Z[=6:)A7!0AJ`&H`Z!`(``"-9?A;N/____]>R<.#[`A0_S4H:P4(
MZ)&&__^#Q!#I8____Y!5B>575E.#[`R+10PQR8M]"(UU#(U5$(7`ZPN0B="+
M&$&#P@2%VW7T@^P,C12-!````%+H,(7__X/$$(7`B<,/A-8```"+!C')A<"-
M5@2)`W4%ZP^)!(N)UHL&08/"!(7`=?''!(L`````4U>-5?!2C4WL4>CS]/__
M@\00A<")QG0DBT7LA<!U>XM%\(7`=#R#[`Q05VBS4P4(:@%J`.A)!P``@\0@
M@^P,_W7LZ!>)__]8_W7PZ`Z)__^)'"3H!HG__XUE]%N)\%Y?R<-7:'A7!0AJ
M`6H`Z!$'``"#Q!"#[`S_=>SHWXC__UC_=?#HUHC__XD<).C.B/__C67T6XGP
M7E_)PX/L"%#_-2AK!0CH=87__X/$$.EN____@^P0Z.6%__]:_S#H#8/__X/$
M$%!HGU,%"&H!:@'HKP8``(/$$.D`____C78`58GE5U93@>S(````BU4(C85@
M____QP(`````4,>%4/___P````#'A53___\`````QX5$____`````.B!A/__
M@\000`^$#`(``%)J!(N-8/___VH$C5D!48F=0/___^C=A___@\000`^$'@(`
M`(/L#/]U$/]U#&H"_[5D____:@#HP_'__XN=8/___X/$((/[_XF%2/___P^$
MI````(VU:/___XV]6/___[@@````B?9(A<#'!(8`````=?2#^_]T%8G:@^,?
ML`&(V<'J!=/@"825:/___\='!`````#'A5C___\!````Z-2$__^#[`S'````
M``!7:@!J`%;_M4#____H6H/__X/$((7`#X[;````BYU@____A=M^%XG:P>H%
MB=F#X1^+A)5H____T^BH`75A@_O_#X5N____,?^%_W4QZ'J$___'``````!0
M:@&-E4S___]2_[5(____Z#^!__^#Q!"%P,>%1/________]U3HM%"(L0A=)T
M"HN-5/___\8$"@"+A43___^-9?1;7E_)PX/L"(V%5/___U"-G5#___]3BU4(
MC85@____Z%+G__^#Q!"+G6#____I<O___^C[@___BQB%VW45BX5,____J']U
M"\'X"(F%1/___^N2QX5$_________^N&Z,^#___'``````!0:@&-C4S___]1
M_[5(____Z)2`__^#Q!"%P'2BZ*B#__^+,(7V#X6`````BX5,____J']U=L'X
M"(F%1/___X/L#/^U8/___^@MAO__@\00QX5@_________^D=____46@D5P4(
M:@%J`>A`!```@\004FH$BXU@____:@2-60%1B9U`____Z+^%__^#Q!!`#X7B
M_?__4&A(5P4(:@%J`>@*!```@\00Z<O]___'A43_________ZX>)]E6)Y8M%
M$%93,<F-71"-512%P.L*B="+,$&#P@2%]G7T@^P,C12-!````%+H0('__X/$
M$(7`B<9T18L#,<F%P(U3!(D&=07K#XD$CHG3BP-!@\($A<!U\<<$C@````!3
M5O]U#/]U".CE_/__B<.)-"3H6X7__XUE^(G86U[)PX/L$.B*@O__6O\PZ+)_
M__^#Q!!0:)]3!0AJ`6H!Z%0#``"#Q!#KE(UV`%6)Y8M%&%93,<F-71B-51R%
MP.L*B="+,$&#P@2%]G7T@^P,C12-!````%+HF(#__X/$$(7`B<9T3HL#,<F%
MP(U3!(D&=07K#XD$CHG3BP-!@\($A<!U\8/L#,<$C@````!6_W44_W40_W4,
M_W4(Z'WN__^#Q!16B</HJH3__XUE^(G86U[)PX/L$.C9@?__6O\PZ`%___^#
MQ!!0:)]3!0AJ`6H!Z*,"``"#Q!#KBXGV58GE5U93@^QLBWT,A?\/A)D```"%
M_XG^=&N`/P!T9I"#[`AJ.E;H;8+__X/$$(7`B<-T7"GP0_]U"%90:-M3!0CH
MV@```(G&6%J-58A25N@D@___@\00A<!U$XM-$(7)=$$/MWV0@^=)@_])=#6#
M[`Q6Z`&$__^#Q!"%VXG>=`6`.P!UFS'`C67T6UY?R<.0,<#\N?____^)]_*N
M]]&-0?_KE(UE]%N)\%Y?R<.#[`QHXU,%".A^?O__B<>#Q!`QP(7_#X5+____
MZ[R058GE@^P,QT7\`````/]U#/]U"(U%_%#H0(/__X/$$$!T!HM%_,G#D(/L
M$.B\@/__6O\PZ.1]__^#Q!!0:-I7!0AJ`6H!Z(8!``"+1?R#Q!#)PXGV58GE
MC54,@^P,QT7\`````%+_=0B-1?Q0Z.N"__^#Q!!`=`6+1?S)PX/L$.AH@/__
M6?\PZ)!]__^#Q!!0:-I7!0AJ`6H!Z#(!``"+1?R#Q!#)PY"058GE@^P4_W4(
MZ!:"__^)]E6)Y5=64X/L#*&$J`4(,?:%P(M="`^%P0```(/L"/\U*&L%"%/H
M2H+__XG?,<#\N?_____RKO?1@\00@'P9_@IT$X/L"/\U*&L%"&H*Z)*!__^#
MQ!"#[`S_-2AK!0CHD7[__X/$$(7V=!525FCU5P4(_S4@:P4(Z#A___^#Q!"#
M[`C_-2!K!0A3Z.:!__^)WS'`_+G_____\J[WT8/$$(!\&?X*=!.#[`C_-2!K
M!0AJ"N@N@?__@\00@^P,_S4@:P4(Z"U^__^+50R#Q!"%TG4[C67T6UXQP%_)
MPY"#[`Q0Z']^__^#Q!"%P(G&#X0I____45!H]5<%"/\U*&L%".BP?O__@\00
MZ0____^#[`S_=0SH_8#__Y!5B>575E.#[!R+30B+50R)3?")5>SH`G___XL`
M@^P,B47DQT7H`!```&@`$```Z$E]__^#Q!"%P(G##X0H`0``C7445O]U$&@`
M$```4.@Z??__@\00/0`0``")Q@^-T@```.BU?O__BU7DB1#HJW[__XLXA?]U
M*5;_=>S_=?!3Z&3^__^#Q!"%VW0,@^P,4^A(@?__@\00C67T6UY?R<.0BTWH
M,?\I\8E-X'0[@^P0Z&A^__]9_S#HD'O__XD$).A8?O___S!H^E<%"/]UX(T\
M,U?HI7O__X/$(#M%X`^=P`^V^(7_=)"#[`B-5#<!4E/HIW[__X/$$(7`#X1W
M____@^P0B</H$G[__UK_,.@Z>___B00DZ`)^____,&CZ5P4(5XT,,U'H47O_
M_X/$(.E$____D(/L"(UX`5=3Z%M^__^#Q!"%P`^$%O___XG#C444B7WH4/]U
M$%=3Z"U\__^#Q!#I^_[__Y!0_W7L_W7P:!!8!0CH;_W__XUE]%M>7\G#D)"0
M58GE4X/L!+MT:04(@SUT:04(_W0-C78`_Q.#ZP2#._]U]H/$!%O)P^C+@/__
MPP``)$9R965"4T0Z('-R8R]L:6(O8W-U+VDS.#8M96QF+V-R=&DN4RQV(#$N
M-B`R,#`R+S`U+S$U(#`T.C$Y.C0Y(&]B<FEE;B!%>'`@)``@*&)R;VME;B!S
M>6UL:6YK*0`E<PDE;'4))6QL=0D`)7,))7,)`"4P,V\*`'-T870@9F%I;&5D
M.B`E<PH`;W!E;F1I<B!F86EL960Z("5S"@!F:6QE<P!D:7)S`&)O=&@`)7,O
M)7,M6%A86%A8`'!S82UT96UP+69I;&4`<'-A861M`')O;W0`8W`R=&5M<&YA
M;0!.;W0@86QL;W=E9"!U<V5R("=R;V]T)PH`+V)I;B]L<P`O8FEN+V-A=``O
M8FEN+V-H;6]D`"]B:6XO8W``+W5S<B]B:6XO=&]U8V@`+V)I;B]M=@`O8FEN
M+W)M`"]B:6XO;6MD:7(`+V)I;B]R;61I<@`O=7-R+V)I;B]F:6QE`&QI<W0`
M+2UI;BUB;&]C:W,`9FEL95]E>&ES=',`<F5A;'!A=&@`<VEZ90`E:0H`56YA
M8FQE('1O(&=E="!S:7IE(&9O<B`G)7,G"@`E;&QD"@```%=R;VYG(&-O;6UA
M;F0@;W!T:6]N('1O(&QI<W0@9FEL97,*`%5N86)L92!T;R!C;W!Y('1H92!F
M:6QE("5S('1O("5S"@```$5R<F]R(&1U<FEN9R!T96UP;W)A<GD@;F%M92!C
M<F5A=&4*`$5R<F]R(&]C8W5R960@9'5R:6YG("5S(&-O;6UA;F0N"@```%-Y
M<W1E;2!%<G)O<CH@:6YV86QI9"!A<F=U;65N="!N=6UB97(@)60L(&UU<W0@
M8F4@,R!O<B!M;W)E"@````!!=71H96YT:6-A=&EO;B!F86EL960L('EO=2!A
M<F4@;F]T("5S(&]R(')O;W0@+2!C86YN;W0@<W1A<G0@<')O9W)A;6TN"@!5
M;F%B;&4@=&\@97AE8W5T92`E<R!C;VUM86YD.B!D865M;VX@:VEL;&5D(&)Y
M('-I9VYA;"`E:0H```!5;F%B;&4@=&\@97AE8W5T92`E<R!C;VUM86YD.B!D
M865M;VX@<W1O<'!E9"!B>2!S:6=N86P@)6D*``!7<F]N9R!C;VUM86YD(&YA
M;64@;W(@<&%R86UE=&5R(&YU;6)E<CH@)7,*`%5N86)L92!T;R!R96-I979E
M(')E86P@<&%T:"!F;W(@)R5S)PH`+W1M<"]P<V$M875T;W)E<W!O;F1E<BU8
M6%A86%@`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XN`%!23T150U1?4D]/5%]$`$A45%!$
M7U9(3U-44U]$`$A45%!$7T-/3D9?1`!(5%101%])3D-,541%7T0`2%144$1?
M0DE.7T0`44U!24Q?4D]/5%]$`%%-04E,7TU!24Q.04U%4U]$`$944$1?0T].
M1@!%<G)O<CH@1E101%]#3TY&(&YO="!D969I;F5D"@!&5%!$7T-/3D9?24Y#
M`$944$1?0DE.7T0`3D%-141?4E5.7U)/3U1?1`!714)?4U1!5`!%<G)O<CH@
M5T5"7U-4050@;F]T(&1E9FEN960*`$Q/1U)/5$%410!%<G)O<CH@3$]'4D]4
M051%(&YO="!D969I;F5D"@!-65-13%]605)?1`!-65-13%]"24Y?1`!01U-1
M3%]"24Y?1`!01U-13%]$051!7T0`34%)3$U!3E]23T]47T0`34%)3$U!3E]6
M05)?1`!04D]$54-47U)#7T0`1%5-4%]$`$5R<F]R.B!$54U07T0@;F]T(&1E
M9FEN960*`$-!5$%,24Y!7TA/344`1%)714)?4D]/5%]$`$125T5"7T540U]$
M`$-54DQ?0T%?0E5.1$Q%7T9)3$4`+V%D;6EN+V-O;F8O<V5T=&EN9W,`+V%D
M;6EN+V)I;B]D;G-M;F<`+V%D;6EN+V)I;B]M86EL;6YG`"]A9&UI;B]B:6XO
M=7-E<FUN9P`O861M:6XO8FEN+V9P7W=R87!P97(`+V%D;6EN+V)I;B]R;5]P
M9%]U<W(`+V%D;6EN+V)I;B]M86ME7W9R=``O861M:6XO8FEN+W=E8G-R=FUN
M9P`O861M:6XO8FEN+W)M7V9R;0`O861M:6XO8FEN+VEN=&5R9F%C90`O861M
M:6XO8FEN+V1O;6%I;FUN9P`O861M:6XO8FEN+V-H:V-O;F9I9P`O=F%R+V-E
M<G1I9FEC871E<P``17)R;W(Z($A45%!$7U9(3U-44U]$(&YO="!D969I;F5D
M"@``17)R;W(Z($A45%!$7T-/3D9?1"!N;W0@9&5F:6YE9`H`````17)R;W(Z
M($A45%!$7TE.0TQ51$5?1"!N;W0@9&5F:6YE9`H`17)R;W(Z($A45%!$7T))
M3E]$(&YO="!D969I;F5D"@!%<G)O<CH@44U!24Q?4D]/5%]$(&YO="!D969I
M;F5D"@````!%<G)O<CH@44U!24Q?34%)3$Y!34537T0@;F]T(&1E9FEN960*
M````17)R;W(Z($944$1?0T].1E])3D,@;F]T(&1E9FEN960*````17)R;W(Z
M("5S(&YO="!D969I;F5D(&EN('!R;V1U8W0@8V]N9FEG(&9I;&4`````17)R
M;W(Z($Y!345$7U)53E]23T]47T0@;F]T(&1E9FEN960*`````$5R<F]R.B!-
M65-13%]605)?1"!N;W0@9&5F:6YE9`H`17)R;W(Z($U94U%,7T))3E]$(&YO
M="!D969I;F5D"@!%<G)O<CH@4$=344Q?0DE.7T0@;F]T(&1E9FEN960*`$5R
M<F]R.B!01U-13%]$051!7T0@;F]T(&1E9FEN960*`````$5R<F]R.B!-04E,
M34%.7U)/3U1?1"!N;W0@9&5F:6YE9`H``$5R<F]R.B!-04E,34%.7U9!4E]$
M(&YO="!D969I;F5D"@```$5R<F]R.B!04D]$54-47U)#7T0@;F]T(&1E9FEN
M960*`````$5R<F]R.B!#051!3$E.05](3TU%(&YO="!D969I;F5D"@```$5R
M<F]R.B!$4E=%0E]23T]47T0@;F]T(&1E9FEN960*`````$5R<F]R.B!$4E=%
M0E]%5$-?1"!N;W0@9&5F:6YE9`H`17)R;W(Z(%!23T150U1?4D]/5%]$(&YO
M="!D969I;F5D"@!%<G)O<CH@96UP='D@57-E<@!-05A5240@<F5A8VAE9`H`
M+W5S<B]B:6XO9F%L<V4`<'-A8VQN`'!S87-E<G8`17)R;W(Z(&5M<'1Y(%5S
M97(@;W(@3F5W57-E<@!C<F]N=&%B("UL("UU("<E<R<`96-H;R`G>2<@?"!C
M<F]N=&%B("UR("UU("<E<R<`8W)O;G1A8B`M=2`G)7,G("<E<R<`17)R;W(Z
M(&5M<'1Y(%5S97(@;W(@2&]M941I<@!%<G)O<CH@96UP='D@57-E<B!O<B!3
M:&5L;`!&86EL960@=&\@<V5T9VED.B`E9`H`1F%I;&5D('1O('-E='5I9#H@
M)60*`%5S97(@)7,@;F]T(&9O=6YD`$-A;FYO="!C:&1I<B!T;R`E<R!H;VUE
M9&ER("5S`'-E='-I9"@I(&9A:6QE9``O9&5V+VYU;&P`17)R;W(Z(&5M<'1Y
M('5S97(`+V5T8R]F='!U<V5R<P!E8VAO("=Y97,G?&-R;VYT86(@+7(@+74@
M)R5S)P`O=7-R+W-B:6XO<'<@=7-E<F1E;``E<R`G)7,G`%5N86)L92!T;R!E
M;F%B;&4@9G1P(&%C8V5S<PH`+V)I;B]B87-H`"]B:6XO<V@`)7,E<P!E=&,`
M+W5S<B]B:6XO9W)E<``O=7-R+VQO8V%L+V)I;B]G<F5P`&5T8R]M87-T97(N
M<&%S<W=D`&5T8R]P=V0N9&(`971C+W-P=V0N9&(`971C+W!A<W-W9`!R;V]T
M.BHZ,#HP.CHZ.B8Z+SHO8FEN+V9A;'-E"@`E<SHJ.B5D.B5D.CHZ.B8Z+SHE
M<PH`+60`+7``+W5S<B]S8FEN+W!W9%]M:V1B`"5S*"DZ('5S97(@)7,@;F]T
M(&9O=6YD`"]E=&,O9W)O=7``+44`=6YL:6YK*"5S*2!F86EL960`=6YL;V-K
M`%5N86)L92!T;R!F;W)K`&%L;&]W`&-R;VYT86)M;F<`9&5N>0`A`"]U<W(O
M<V)I;B]P=R!U<V5R861D("<E<R<@+74@)74@+60@)R5S)R`M9R`G)7,G("US
M("<E<R<`+W5S<B]S8FEN+W!W('5S97)M;V0@)R5S)R`M;"`G)7,G````+W5S
M<B]S8FEN+W!W9%]M:V1B("]E=&,O;6%S=&5R+G!A<W-W9````$524D]2.B!5
M;F%B;&4@=&\@8W)E871E('1E;7`@9FEL92`G)7,G(&YA;64@=&\@<W1O<F4@
M=7-E<B!C<F]N=&%B"@``15)23U(Z(%5N86)L92!T;R!O<&5N(&-R;VYT86(@
M;V8@=7-E<B`G)7,G"@`O=7-R+W-B:6XO<'<@=7-E<FUO9"`G)7,G("UM("UD
M("<E<R<`````+W5S<B]S8FEN+W!W('5S97)M;V0@)R5S)R`M<R`G)7,G````
M0V%N;F]T(')U;B!A<R!F;W)B:61D96X@=6ED.B`E9`H`````56YA8FQE('1O
M(&EN:70@;F5W(&=R;W5P<R!F;W(@=7-E<B`E<SH@)7,```!#;&]S92!U<V5R
M("<E<R<@<V5S<VEO;B!F86EL960*`$5R<F]R(&]C8W5R960@9'5R:6YG(&-L
M;W-E('5S97(@)R5S)R!S97-S:6]N.B`E<PH```!5;F%B;&4@=&\@8VQO<V4@
M=7-E<B`G)7,G('-E<W-I;VXZ(&1A96UO;B!S=&]P<&5D(&)Y('-I9VYA;"`E
M:0H`56YA8FQE('1O(&-L;W-E('5S97(@)R5S)R!S97-S:6]N.B!D865M;VX@
M:VEL;&5D(&)Y('-I9VYA;"`E:0H``'-E='5P7V-H<F]O=#H@8VAD:7(H)7,I
M(&9A:6QE9```;6M?9W)O=7`Z(&=R97`@;F]T(&9O=6YD+"!N;W0@=W)I=&EN
M9R!G<F]U<',@9FEL90H``'-E='5P7V-H<F]O=#H@<&%S<W=D(&1A=&%B87-E
M('5P9&%T92!F86EL960`7G!S87-E<G8Z?%Y;7CI=*CI;7CI=*CHH,'PE9"DZ
M?%LL.ETE<R@L6UXZ72I\*20`<V5T=7!?8VAR;V]T.B!W<FET92!T;R![<F]O
M='TO971C+W!A<W-W9"!F86EL960`)7,H*3H@3F\@8VAR;V]T960@<VAE;&P@
M9F]R("5S(&9O=6YD`````&UK7V=R;W5P.B!G<F5P(&5X96-U=&EO;B!F86EL
M960`;6M?9W)O=7`Z(&]P96XH+V5T8R]G<F]U<"D@9F%I;&5D`"]T;7`O8W)O
M;G1A8BUT;7`M6%A86%A86```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!S971U<%]C
M:')O;W0`+W5S<B]S8FEN+W!W`"]U<W(O<V)I;B]P=P`O=7-R+V)I;B]C:'!A
M<W,`````17)R;W(@;V-C=7)R960@=VAI;&4@;&]C:VEN9R!T:&4@9FEL92`E
M<PH```!5;F%B;&4@=&\@8V]P>2!F:6QE("5S('1O("5S.B`E<PH```!%<G)O
M<B!O8V-U<G)E9"!W:&EL92!U;FQO8VMI;F<@=&AE(&9I;&4@)7,*`$5R<F]R
M('=H:6QE(&-O<'EI;F<@9FEL92`E<R!T;R`E<SH@)7,```!C;W!Y7V9I;&5?
M871O;6EC*"5S("T^("5S*3H@=W)I=&4@9F%I;&5D`````&-O<'E?9FEL95]A
M=&]M:6,H)7,@+3X@)7,I.B!C:&]W;B!F86EL960`````8V]P>5]F:6QE7V%T
M;VUI8R@E<R`M/B`E<RDZ(&-H;6]D(&9A:6QE9`````!C;W!Y7V9I;&5?871O
M;6EC*"5S("T^("5S*3H@9FQU<V@@9F%I;&5D`````&-O<'E?9FEL95]A=&]M
M:6,H)7,@+3X@)7,I.B!R96YA;64@9F%I;&5D````8V]P>5]F:6QE7V%T;VUI
M8R@E<R`M/B`E<RDZ(&]P96X@9F%I;&5D`&-O<'E?9FEL95]A=&]M:6,H)7,@
M+3X@)7,I.B!M:W-T96UP(&9A:6QE9`!5;F%B;&4@=&\@;W!E;B!F:6QE("5S
M.B`E<P!5;F%B;&4@=&\@8VQO<V4@9FEL92`E<SH@)7,*`$%L;&]C871I;VX@
M9F%I;&5D`"]E=&,O<'-A+W!S82YC;VYF`$5R<F]R.B`E<R!N;W0@9&5F:6YE
M9`````!%<G)O<B!O8V-U<G)E9"!W:&EL92!L;V-K:6YG('1H92!F:6QE("5S
M.B`E<PH```!%<G)O<B!O8V-U<G)E9"!W:&EL92!U;FQO8VMI;F<@=&AE(&9I
M;&4@)7,Z("5S"@!F:6QE7W-T<CH@56YA8FQE('1O('-T870@9FEL92`E<SH@
M)7,*````9FEL95]S='(Z($524D]2.B!5;F%B;&4@=&\@8VAM;V0@9FEL92`E
M<SH@)7,`````9FEL95]S='(Z($524D]2.B!5;F%B;&4@=&\@8VAO=VX@9FEL
M92`E<SH@)7,`````17)R;W(@=VAI;&4@<F5N86UE(&9I;&4@)7,Z("5S"@!5
M;F%B;&4@=&\@9G!U=',@=&\@9FEL92`E<SH@)7,*`&-A;FYO="!W<FET92!A
M(&QI;F4@=&\@)7,N=&UP`&$`56YA8FQE('1O(&]P96X@9FEL92`E<SH@)7,*
M`%5N86)L92!T;R!R96YA;64@9FEL92`E<SH@)7,*````56YA8FQE('1O(&=E
M='!W;F%M(&9O<B!U<V5R("5S``!5;F%B;&4@=&\@9FEN9"!U:60@9F]R('5S
M97(@)7,Z("5S`&=E=&=R;F%M*"5S*3H@)7,`9V5T9W)G:60H)60I.B`E<P`E
M9``E=0`O9&5V+VAD=C$`7U]D96QE=&5D`%5N86)L92!T;R!G970@96YT<GD@
M)7,Z("5S"@!5;F%B;&4@=&\@8VQO<V4@9&ER("5S.B`E<PH`56YA8FQE('1O
M(&-H86YG92!D:7(@)7,Z("5S"@!5;F%B;&4@=&\@8VAO=VX@9&ER("5S.B`E
M<PH`56YA8FQE('1O(&]P96X@9&ER("5S.B`E<PH`56YA8FQE('1O(&-H;6]D
M(&5N=')Y("5S.B`E<PH`56YA8FQE('1O(&-H;6]D(&1I<B`E<SH@)7,*`%5N
M86)L92!T;R!R96UO=F4@9&ER("5S.B`E<PH`)7,O)7-86%A86%@`+7)F`"T`
M56YA8FQE('1O(&-H;W=N(&1I<F5C=&]R>2!E;G1R>2`E<SH@)7,*`%5N86)L
M92!T;R!G970@9FEL92!D97-C<FEP=&]R(&]F(&-U<G)E;G0@9&ER.B`E<PH`
M``!5;F%B;&4@=&\@8VAE8VL@9&ER96-T;W)Y(&5N=')Y("5S.B`E<PH`56YA
M8FQE('1O(')E<W1O<F4@)B!C;&]S92!C=7)R96YT(&1I<CH@)7,*``!5;F%B
M;&4@=&\@8VAM;V0@9&ER96-T;W)Y(&5N=')Y("5S.B`E<PH`56YA8FQE('1O
M('5N;&EN:R!D:7)E8W1O<GD@96YT<GD@)7,Z("5S"@````!5;F%B;&4@=&\@
M=6YL:6YK(&5N=')Y("5S.B`E<PH``%5N86)L92!T;R!R96YA;64@9&ER96-T
M;W)Y(&5N=')Y("5S('1O("5S.B`E<PH``$ET)W,@82!R96=U;&%T(&5N=')Y
M*&YO="!D:7)E8W1O<GDI.B`E<PH`````9&5F97)R961?<F5M;W9E*"DZ(&YO
M="!S=7!P;W)T960@9&ER96-T;W)Y(&9O<B!D969E<G)E9"!R96UO=F4Z("5S
M"@!D969E<G)E9%]R96UO=F4H*3H@8V%N)W0@<W1A="!D:7)E8W1O<GDL('-K
M:7`@:70N"@``9&5F97)R961?<F5M;W9E*"DZ(')E;F%M92!D:7(@)7,@=&\@
M)7,*`&1E9F5R<F5D7W)E;6]V92@I.B!5;F%B;&4@=&\@<F5N86UE(&1I<F5C
M=&]R>0H``&1E9F5R<F5D7W)E;6]V92@I.B!5;F%B;&4@8W)E871E(&9I;&5N
M86UE(&9O<B!D96QE=&4@9&ER96-T;W)Y"@!#86XG="!R96UO=F4@9&ER96-T
M;W)Y("5S("AW:6QL('1R>2!I;B!N97AT('1I;64I"@``56YA8FQE('1O('-T
M870@9FEL92`E<RP@<VMI<'!E9`H`````56YA8FQE('1O('1R=6YC871E(&]R
M(&-R96%T92!F:6QE("5S.B`E<P````!#86YN;W0@8W)E871E(&1I<F5C=&]R
M>2`E<SH@)7,``$524D]2.B!5;F%B;&4@=&\@8VAM;V0@)7,Z("5S"@``15)2
M3U(Z(%5N86)L92!T;R!M:V1I<B`E<SH@)7,*``!%4E)/4CH@56YA8FQE('1O
M(&-H;W=N("5S.B`E<PH``$1I<F5C=&]R>2!R96YA;64@97)R;W(Z('1A<F=E
M="!D:7)E8W1O<GD@)7,@86QR96%D>2!E>&ES=',N"@````!%4E)/4CH@=6YA
M8FQE('1O(&-H;6]D("5S.B`E<PH``$524D]2.B!U;F%B;&4@=&\@8VAO=VX@
M)7,Z("5S"@!5;F%B;&4@=&\@8W)E871E(&9I;&4@)7,Z("5S`$-A;FYO="!C
M:&]W;B`E<SH@)7,`4F5M86UI;F<@)7,@=&\@)7,@9F%I;&5D.B`E<PH`56YA
M8FQE('1O(&-L;W-E('1H92!F:6QE.B`E<PH`56YA8FQE('1O(&=E="!R96%L
M('!A=&@@:6YF;W)M871I;VX*`````%-U8V@@<&%T:"`G)7,G(&1O97,@;F]T
M(&5X:7-T"@`O`%5N86)L92!T;R!S879E(&-U<G)E;G0@<&%T:`H`)7,O=F%R
M+VQO8VLO9FEL97,O)7,`56YA8FQE('1O(&]P96X@9FEL92`B)7,B.B`E<RX`
M````06X@97)R;W(@;V-C=7)E9"!D=7)I;F<@8VQO<VEN9R`G)7,G(&9I;&4Z
M("5S"@`E,#)X`"X*`$-A;FYO="!A;&QO8V%T92!M96UO<GD`0V%N;F]T(&9O
M<FLH*3H*)7,`0V%N;F]T(&%L;&]C871E(&)U9F9E<CH*)7,`0V%N;F]T(')E
M860@8VAI;&0@;W5T<'5T.@HE<P!E<G)O<CH*)7,`0V%N;F]T(&5X96,@)7,Z
M"B5S`&5R<F]R.B!N;VYE`&9O<FM?97AE8W8Z(&1U<"@I(&9A:6QE9#H@)7,*
M`&UA;&QO8R@I(&9A:6QE9#H@)7,`)7,@97AE8W5T:6]N(&9A:6QE9#H*)7,`
M)7,O861M:6XO8FEN+R5S`"4N*G,O)7,`4$%42`!V86QU97,@,"PQ+#(@;F]T
M(&%L;&]W960@9F]R('9A<FEA8FQE<R!F9%]I;B`F(&9D7V]U=`H``$5R<F]R
M(&]C8W5R960@9'5R:6YG(&5X96-V*"DZ"B5S`````"P@<&]S<VEB;&4@<F5A
M<V]N("T@3E5,3"!P87)A;65T97(@:7,@86)S96YT(&EN('5T:6Q?97AE8RAP
M871H+"!A<F<Q+"!A<F<R+"!.54Q,*2!C86QL+@H`````5&AE(&-H:6QD('!R
M;V-E<W,@=VET:"!P:60@)60@<W1O<'!E9"!B>2!S:6=N86P@)6D*`$5R<F]R
M(&]C8W5R960@9'5R:6YG(&9O<FLH*3H*)7,`17)R;W(@;V-C=7)E9"!D=7)I
M;F<@=V%I=&EN9R!T:&4@8VAI;&0@<')O8V5S<R!W:71H('!I9#H@)60Z("5S
M"@````!4:&4@8VAI;&0@<')O8V5S<R!W:71H('!I9"`E9"!K:6QL960@8GD@
M<VEG;F%L("5I"@``9F]R:U]E>&5C*CH@<F5A9"AP:7!E*2!F86EL960Z("5S
M"@``=71I;&ET>2`E<R!F86EL960@*')E<W5L=#TE9"DZ"B5S````<&]P96Y?
M97AE8SH@=V%R;FEN9SH@9F%I;&5D('1O(&%L;&]C871E(&UE;6]R>2!F;W(@
M8V]M;6%N9"!O=71P=70@8G5F9F5R"@```'!O<&5N7V5X96,Z(&9A:6QE9"!T
M;R!E>&5C=71E(&-O;6UA;F0Z(&9O<FL@;W(@<&EP92!C86QL<R!F86EL960L
M(&]R(&-A;FYO;B!A;&QO8V%T92!M96UO<GD*`````'!O<&5N7V5X96,Z(&9A
M:6QE9"!T;R!A;&QO8V%T92!M96UO<GD*``!P;W!E;E]E>&5C.B!C;VUM86YD
M(&9A:6QE9"!C;V1E.B`E9"`L("5S"@```'!O<&5N7V5X96,Z(&9A:6QE9"!T
M;R!E>&5C=71E(&-O;6UA;F0Z("5S"@``9F]R:U]E>&5C=E]P:7!E<SH@9F]R
M:R@I(&9A:6QE9`!F;W)K7V5X96-V.B!E>&5C=B@B)7,B*2!F86EL960Z("5S
M"@!F;W)K7V5X96-V7V=E=&]U=&5R<CH@<&EP92@I(&9A:6QE9`!F;W)K7V5X
M96-V7V=E=&]U=&5R<CH@9F-N=&PH3U].3TY"3$]#2RD@9F%I;&5D```E<R!E
M>&5C=71I;VX@9F%I;&5D("AN;R!O=71P=70I`%5T:6QI='D@;F%M92`G)7,G
M(&ES(&EN=F%L:60N(%5S92!O;FQY('5T:6QI='D@;F%M92!W:71H;W5T('!A
M=&@N`$-A;FYO="!A;&QO8V%T92!M96UO<GDZ("5S`"5S.B``"E-Y<W1E;2!E
M<G)O<B`E9#H@)7,``$-A;B=T(&%L;&]C871E(&UE;6]R>2!F;W(@97)R;W(@
M;65S<V%G90`D1G)E94)31#H@<W)C+VQI8B]C<W4O:3,X-BUE;&8O8W)T;BY3
M+'8@,2XU(#(P,#(O,#4O,34@,#0Z,3DZ-#D@;V)R:65N($5X<"`D`````-88
M!0@`````@&D%"/____^E3`4(-'@%""!X!0@```````````$````!`````0``
M`.<````!````,P$```$```#(`0``#````'"2!`@-````7!@%"`0````D@00(
M!0```,"+!`@&````@(0$"`H```!W`P``"P```!`````5``````````,```"(
M:04(`@````@#```4````$0```!<```!HCP0($0```#B/!`@2````,````!,`
M```(````````````````````````````````````````````````````````
M````````````_____P````#_____``````````"L:`4(``````````"2D@0(
MHI($"+*2!`C"D@0(TI($".*2!`CRD@0(`I,$"!*3!`@BDP0(,I,$"$*3!`A2
MDP0(8I,$"'*3!`B"DP0(DI,$"**3!`BRDP0(PI,$"-*3!`CBDP0(\I,$"`*4
M!`@2E`0((I0$"#*4!`A"E`0(4I0$"&*4!`ARE`0(@I0$")*4!`BBE`0(LI0$
M",*4!`C2E`0(XI0$"/*4!`@"E00($I4$""*5!`@RE00(0I4$"%*5!`ABE00(
M<I4$"(*5!`B2E00(HI4$"+*5!`C"E00(TI4$".*5!`CRE00(`I8$"!*6!`@B
ME@0(,I8$"$*6!`A2E@0(8I8$"'*6!`B"E@0(DI8$"**6!`BRE@0(PI8$"-*6
M!`CBE@0(\I8$"`*7!`@2EP0((I<$"#*7!`A"EP0(4I<$"&*7!`AREP0(@I<$
M")*7!`BBEP0(LI<$",*7!`C2EP0(XI<$"/*7!`@"F`0($I@$""*8!`@RF`0(
M0I@$"%*8!`ABF`0(<I@$"(*8!`B2F`0(````````````)$9R965"4T0Z('-R
M8R]L:6(O8W-U+V-O;6UO;B]C<G1B<F%N9"YC+'8@,2XT(#(P,#,O,3`O,3<@
M,34Z-#,Z,3,@<&5T97(@17AP("0`)$9R965"4T0Z('-R8R]L:6(O8W-U+VDS
M.#8M96QF+V-R=#$N8RQV(#$N,3,@,C`P-"\P."\Q-2`Q-CHQ.#HU,2!D9G(@
M17AP("0`1T-#.B`H1TY5*2`S+C0N,B!;1G)E94)31%T@,C`P-#`W,C@``$=#
M0SH@*$=.52D@,RXT+C(@6T9R965"4T1=(#(P,#0P-S(X``!'0T,Z("A'3E4I
M(#,N-"XR(%M&<F5E0E-$72`R,#`T,#<R.```1T-#.B`H1TY5*2`S+C0N,B!;
M1G)E94)31%T@,C`P-#`W,C@``$=#0SH@*$=.52D@,RXT+C(@6T9R965"4T1=
M(#(P,#0P-S(X``!'0T,Z("A'3E4I(#,N-"XR(%M&<F5E0E-$72`R,#`T,#<R
M.```1T-#.B`H1TY5*2`S+C0N,B!;1G)E94)31%T@,C`P-#`W,C@``$=#0SH@
M*$=.52D@,RXT+C(@6T9R965"4T1=(#(P,#0P-S(X``!'0T,Z("A'3E4I(#,N
M-"XR(%M&<F5E0E-$72`R,#`T,#<R.```1T-#.B`H1TY5*2`S+C0N,B!;1G)E
M94)31%T@,C`P-#`W,C@``$=#0SH@*$=.52D@,RXT+C(@6T9R965"4T1=(#(P
M,#0P-S(X``!'0T,Z("A'3E4I(#,N-"XR(%M&<F5E0E-$72`R,#`T,#<R.```
M1T-#.B`H1TY5*2`S+C0N,B!;1G)E94)31%T@,C`P-#`W,C@``$=#0SH@*$=.
M52D@,RXT+C(@6T9R965"4T1=(#(P,#0P-S(X``!'0T,Z("A'3E4I(#,N-"XR
M(%M&<F5E0E-$72`R,#`T,#<R.```1T-#.B`H1TY5*2`S+C0N,B!;1G)E94)3
M1%T@,C`P-#`W,C@``$=#0SH@*$=.52D@,RXT+C(@6T9R965"4T1=(#(P,#0P
M-S(X``!'0T,Z("A'3E4I(#,N-"XR(%M&<F5E0E-$72`R,#`T,#<R.```1T-#
M.B`H1TY5*2`S+C0N,B!;1G)E94)31%T@,C`P-#`W,C@``$=#0SH@*$=.52D@
M,RXT+C(@6T9R965"4T1=(#(P,#0P-S(X```N<VAS=')T86(`+FEN=&5R<``N
M;F]T92Y!0DDM=&%G`"YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N<F5L+F1Y;@`N
M<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YD871A`"YE:%]F
M<F%M90`N9'EN86UI8P`N8W1O<G,`+F1T;W)S`"YJ8W(`+F=O=``N8G-S`"YC
M;VUM96YT````````````````````````````````````````````````````
M````"P````$````"````](`$"/0````5```````````````!`````````!,`
M```'`````@````R!!`@,`0``&```````````````!``````````A````!0``
M``(````D@00()`$``%P#```$``````````0````$````)P````L````"````
M@(0$"(`$``!`!P``!0````$````$````$````"\````#`````@```,"+!`C`
M"P``=P,``````````````0`````````W````"0````(````XCP0(.`\``#``
M```$``````````0````(````0`````D````"````:(\$"&@/```(`P``!```
M``D````$````"````$D````!````!@```'"2!`AP$@``"P``````````````
M!`````````!$`````0````8```!\D@0(?!(``"`&``````````````0````$
M````3P````$````&````G)@$")P8``#`?P`````````````$`````````%4`
M```!````!@```%P8!0A<F```!@``````````````!`````````!;`````0``
M``(```!D&`4(9)@``"%```````````````0`````````8P````$````#````
MB&@%"(C8```@```````````````$`````````&D````!`````@```*AH!0BH
MV```!```````````````!`````````!S````!@````,```"L:`4(K-@``,@`
M```%``````````0````(````?`````$````#````=&D%"'39```(````````
M```````$`````````(,````!`````P```'QI!0A\V0``"```````````````
M!`````````"*`````0````,```"$:04(A-D```0```````````````0`````
M````CP````$````#````B&D%"(C9``"0`0`````````````$````!````)0`
M```(`````P```"!K!0@@VP``=#T`````````````(`````````"9`````0``
M````````````(-L``'T#``````````````$``````````0````,`````````
M`````)W>``"B```````````````!````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4`````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,#`P(#$P-3$U-#,S-S4T(#`Q-30V,P`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R````````````````````````````````````````````````
M````````````````````````````````````````````````,#`P-S4U(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S,@,#$V-#`W
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4V5R=FEC97,`````````````
M````````````````````````````````````````````````````````````
M```````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q
M,#4Q-30S,S<R-R`P,C`Q-S4`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]3
M97)V:6-E<R]796%T:&5R````````````````````````````````````````
M`````````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S(W(#`R,34W-``@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+U-E<G9I8V5S+U=E871H97(O16IS92YP:'``````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-#(U,3(@,3`U,34T,S,W,C<@
M,#(S,C4V`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI
M9G1W:61T:#TT('-O9G1T86)S=&]P/30@9F]L9&UE=&AO9#UM87)K97(Z("HO
M"@HO*BH*("H@4$5!4CHZ4V5R=FEC97-?5V5A=&AE<E]%:G-E"B`J"B`J(%!(
M4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J(#Q,24-%3E-%/@H@*B!#;W!Y<FEG
M:'0@*&,I(#(P,#4L($%L97AA;F1E<B!7:7)T>@H@*B!!;&P@<FEG:'1S(')E
M<V5R=F5D+@H@*@H@*B!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C
M92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70*("H@;6]D:69I
M8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO
M=VEN9R!C;VYD:71I;VYS"B`J(&%R92!M970Z"B`J(&\@4F5D:7-T<FEB=71I
M;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y
M<FEG:'0@;F]T:6-E+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N
M9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N"B`J(&\@4F5D:7-T<FEB=71I
M;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C
M;W!Y<FEG:'0@;F]T:6-E+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS
M(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@:6X@=&AE(&1O8W5M96YT
M871I;VX*("H@("!A;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I
M=&@@=&AE(&1I<W1R:6)U=&EO;BX*("H@;R!.96ET:&5R('1H92!N86UE(&]F
M('1H92!S;V9T=V%R92!N;W(@=&AE(&YA;65S(&]F(&ET<R!C;VYT<FEB=71O
M<G,*("H@("!M87D@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O
M9'5C=',@9&5R:79E9"!F<F]M('1H:7,@<V]F='=A<F4*("H@("!W:71H;W5T
M('-P96-I9FEC('!R:6]R('=R:71T96X@<&5R;6ES<VEO;BX*("H*("H@5$A)
M4R!33T945T%212!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%
M4E,@04Y$($-/3E1224)55$]24R`B05,@25,B"B`J($%.1"!!3ED@15A04D53
M4R!/4B!)35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5"!,
M24U)5$5$(%1/+"!42$4*("H@24U03$E%1"!705)204Y42453($]&($U%4D-(
M04Y404))3$E462!!3D0@1DE43D534R!&3U(@02!005)424-53$%2(%!54E!/
M4T4*("H@05)%($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(12!#
M3U!94DE'2%0@3U=.15(@3U(@0T].5%))0E543U)3($)%"B`J($Q)04),12!&
M3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL(%-014-)04PL
M($5814U03$%262P@3U(*("H@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,
M541)3D<L($)55"!.3U0@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8*("H@
M4U5"4U1)5%5412!'3T]$4R!/4B!315)624-%4SL@3$]34R!/1B!54T4L($1!
M5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3"B`J($E.5$524E505$E/3BD@
M2$]7159%4B!#0553140@04Y$($].($%.62!42$5/4ED@3T8@3$E!0DE,2519
M+"!72$542$52($E."B`J($-/3E1204-4+"!35%))0U0@3$E!0DE,2519+"!/
M4B!43U)4("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I"B`J
M($%225-)3D<@24X@04Y9(%=!62!/550@3T8@5$A%(%5312!/1B!42$E3(%-/
M1E1705)%+"!%5D5.($E&($%$5DE3140@3T8@5$A%"B`J(%!/4U-)0DE,2519
M($]&(%-50T@@1$%-04=%+@H@*B`\+TQ)0T5.4T4^"B`J"B`J($!C871E9V]R
M>2`@("!796(@4V5R=FEC97,*("H@0'!A8VMA9V4@("`@(%-E<G9I8V5S7U=E
M871H97(*("H@0&%U=&AO<B`@("`@($%L97AA;F1E<B!7:7)T>B`\86QE>$!P
M8S1P+FYE=#X*("H@0&-O<'ER:6=H="`@(#(P,#4@06QE>&%N9&5R(%=I<G1Z
M"B`J($!L:6-E;G-E("`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI
M8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I
M;VX@("`@($-64SH@)$ED.B!%:G-E+G!H<"QV(#$N,C,@,C`P-2\Q,2\Q,R`R
M,3HU-CHQ-B!E<G4@17AP("0*("H@0&QI;FL@("`@("`@(&AT='`Z+R]P96%R
M+G!H<"YN970O<&%C:V%G92]397)V:6-E<U]796%T:&5R"B`J($!L:6YK("`@
M("`@("!H='1P.B\O=W=W+F5J<V4N8V]M+W-E<G9I8V5S+W=E871H97)?>&UL
M7W=E8E]S97)V:6-E<RYH=&T*("H@0&5X86UP;&4@("`@(&5X86UP;&5S+V5J
M<V4M8F%S:6,N<&AP("`@("`@("`@("`@(&5J<V4M8F%S:6,N<&AP"B`J($!F
M:6QE<V]U<F-E"B`J+PH*<F5Q=6ER95]O;F-E(")397)V:6-E<R]796%T:&5R
M+T-O;6UO;BYP:'`B.PH*+R\@>WM[(&-L87-S(%-E<G9I8V5S7U=E871H97)?
M16IS90HO*BH*("H@5&AI<R!C;&%S<R!A8W1S(&%S(&%N(&EN=&5R9F%C92!T
M;R!T:&4@<V]A<"!S97)V:6-E(&]F($5*4T4N($ET(')E=')I979E<PH@*B!C
M=7)R96YT('=E871H97(@9&%T82!A;F0@9F]R96-A<W1S(&)A<V5D(&]N('!O
M<W1A;"!C;V1E<R`H6DE0*2X*("H*("H@0W5R<F5N=&QY('1H:7,@<V5R=FEC
M92!I<R!O;FQY(&%V86EL86)L92!F;W(@55,@=&5R<FET;W)Y+@H@*@H@*B!&
M;W(@82!W;W)K:6YG(&5X86UP;&4L('!L96%S92!T86ME(&$@;&]O:R!A=`H@
M*B`@("`@9&]C<R]397)V:6-E<U]796%T:&5R+V5X86UP;&5S+V5J<V4M8F%S
M:6,N<&AP"B`J"B`J($!C871E9V]R>2`@("!796(@4V5R=FEC97,*("H@0'!A
M8VMA9V4@("`@(%-E<G9I8V5S7U=E871H97(*("H@0&%U=&AO<B`@("`@($%L
M97AA;F1E<B!7:7)T>B`\86QE>$!P8S1P+FYE=#X*("H@0&-O<'ER:6=H="`@
M(#(P,#4@06QE>&%N9&5R(%=I<G1Z"B`J($!L:6-E;G-E("`@("!H='1P.B\O
M=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@
M0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@(%)E;&5A<V4Z(#$N-"XP"B`J
M($!L:6YK("`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4V5R
M=FEC97-?5V5A=&AE<@H@*B!`;&EN:R`@("`@("`@:'1T<#HO+W=W=RYE:G-E
M+F-O;2]S97)V:6-E<R]W96%T:&5R7WAM;%]W96)?<V5R=FEC97,N:'1M"B`J
M($!E>&%M<&QE("`@("!E>&%M<&QE<R]E:G-E+6)A<VEC+G!H<"`@("`@("`@
M("`@("!E:G-E+6)A<VEC+G!H<`H@*B\*8VQA<W,@4V5R=FEC97-?5V5A=&AE
M<E]%:G-E(&5X=&5N9',@4V5R=FEC97-?5V5A=&AE<E]#;VUM;VX@>PH*("`@
M("\O('M[>R!P<F]P97)T:65S"B`@("`O*BH*("`@("`J(%=31$P@;V)J96-T
M+"!P<F]V:61E9"!B>2!%2E-%"B`@("`@*@H@("`@("H@0'9A<B`@("`@;V)J
M96-T("`@("`@("`@("`@("`@("`@("`@("1?=W-D;`H@("`@("H@0&%C8V5S
M<R`@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]W<V1L.PH*("`@("\J*@H@
M("`@("H@4T]!4"!O8FIE8W0@=&\@86-C97-S('=E871H97(@9&%T82P@<')O
M=FED960@8GD@14I310H@("`@("H*("`@("`J($!V87(@("`@(&]B:F5C="`@
M("`@("`@("`@("`@("`@("`@("`D7W=E871E<E-O87`*("`@("`J($!A8V-E
M<W,@('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?=V5A=&AE<E-O87`["B`@
M("`O+R!]?7T*"B`@("`O+R![>WL@8V]N<W1R=6-T;W(*("`@("\J*@H@("`@
M("H@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!297%U:7)E<R!33T%0('1O
M(&)E(&EN<W1A;&QE9`H@("`@("H*("`@("`J($!P87)A;2`@(&%R<F%Y("`@
M("`@("`@("`@("`@("`@("`@("`D;W!T:6]N<PH@("`@("H@0'!A<F%M("`@
M;6EX960@("`@("`@("`@("`@("`@("`@("`@("1E<G)O<@H@("`@("H@0'1H
M<F]W<R`@4$5!4E]%<G)O<@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@
M("HO"B`@("!F=6YC=&EO;B!397)V:6-E<U]796%T:&5R7T5J<V4H)&]P=&EO
M;G,L("8D97)R;W(I"B`@("!["B`@("`@("`@)'!E<G)O<B`](&YU;&P["B`@
M("`@("`@)'1H:7,M/E-E<G9I8V5S7U=E871H97)?0V]M;6]N*"1O<'1I;VYS
M+"`D<&5R<F]R*3L*("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%
M<G)O<B@D<&5R<F]R*2D@>PH@("`@("`@("`@("`D97)R;W(@/2`D<&5R<F]R
M.PH@("`@("`@('T*("`@('T*("`@("\O('U]?0H*("`@("\O('M[>R!?8V]N
M;F5C=%-E<G9E<B@I"B`@("`O*BH*("`@("`J($-O;FYE8W1S('1O('1H92!3
M3T%0('-E<G9E<B!A;F0@<F5T<FEE=F5S('1H92!74T1,(&1A=&$*("`@("`J
M"B`@("`@*B!`<F5T=7)N("!014%27T5R<F]R?&)O;VP*("`@("`J($!T:')O
M=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?5U)/3D=?
M4T525D527T1!5$$*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V-O;FYE8W1397)V97(H*0H@("`@>PH@("`@("`@(&EN
M8VQU9&5?;VYC92`B4T]!4"]#;&EE;G0N<&AP(CL*("`@("`@("`D=&AI<RT^
M7W=S9&P@/2!N97<@4T]!4%]74T1,*")H='1P.B\O=W=W+F5J<V4N8V]M+U=E
M871H97)397)V:6-E+U-E<G9I8V4N87-M>#]74T1,(BP@)'1H:7,M/E]H='1P
M3W!T:6]N<RD["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?=W-D;"T^9F%U
M;'0I("8F(%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'1H:7,M/E]W<V1L
M+3YF875L="DI('L*("`@("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H
M97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%4E)/4E]74D].1U]3
M15)615)?1$%402P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@
M("`@("`@(&5V86PH)'1H:7,M/E]W<V1L+3YG96YE<F%T94%L;%!R;WAI97,H
M*2D["B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H(E=E8E-E<G9I8V5?4V5R
M=FEC95]397)V:6-E4V]A<"(I*2!["B`@("`@("`@("`@(')E='5R;B!397)V
M:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?15)2
M3U)?5U)/3D=?4T525D527T1!5$$L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@
M("`@("`@?0H@("`@("`@("1T:&ES+3Y?=V5A=&AE<E-O87`@/2`F;F5W(%=E
M8E-E<G9I8V5?4V5R=FEC95]397)V:6-E4V]A<#L*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@7V-H96-K3&]C
M871I;VY)1"@I"B`@("`O*BH*("`@("`J($-H96-K<R!T:&4@:60@9F]R('9A
M;&ED('9A;'5E<R!A;F0@=&AU<R!P<F5V96YT<R!S:6QL>2!R97%U97-T<R!T
M;R!%2E-%('-E<G9E<@H@("`@("H*("`@("`J($!P87)A;2`@('-T<FEN9R`@
M("`@("`@("`@("`@("`@("`@("`D:60*("`@("`J($!R971U<FX@(%!%05)?
M17)R;W)\8F]O;`H@("`@("H@0'1H<F]W<R`@4$5!4E]%<G)O<CHZ4T525DE#
M15-?5T5!5$A%4E]%4E)/4E].3U],3T-!5$E/3@H@("`@("H@0'1H<F]W<R`@
M4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/4E])3E9!3$E$7TQ/
M0T%424]."B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]C:&5C:TQO8V%T:6]N240H)&ED*0H@("`@>PH@("`@("`@(&EF
M("AI<U]A<G)A>2@D:60I('Q\(&ES7V]B:F5C="@D:60I('Q\("%S=')L96XH
M)&ED*2D@>PH@("`@("`@("`@("!R971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ
M<F%I<V5%<G)O<BA315)624-%4U]714%42$527T524D]27TY/7TQ/0T%424].
M+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T@96QS96EF("@A8W1Y
M<&5?9&EG:70H)&ED*2!\?"`H<W1R;&5N*"1I9"D@(3T@-2DI('L*("`@("`@
M("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T52
M5DE#15-?5T5!5$A%4E]%4E)/4E])3E9!3$E$7TQ/0T%424].+"!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@<V5A<F-H3&]C871I;VXH
M*0H@("`@+RHJ"B`@("`@*B!%2E-%(&]F9F5R<R!N;R!S96%R8V@@9G5N8W1I
M;VX@=&\@9&%T92P@<V\@=&AI<R!F=6YC=&EO;B!I<R!D:7-A8FQE9"X*("`@
M("`J($UA>6)E('1H:7,@:7,@=&AE('!L86-E('1O(&EN=&5R9F%C92!T;R!S
M;VUE(&]N;&EN92!P;W-T8V]D92!S97)V:6-E+BXN"B`@("`@*@H@("`@("H@
M0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1L;V-A=&EO
M;@H@("`@("H@0'!A<F%M("`@8F]O;"`@("`@("`@("`@("`@("`@("`@("`@
M("1U<V5&:7)S=`H@("`@("H@0')E='5R;B`@8F]O;`H@("`@("H@0&%C8V5S
M<R`@<'5B;&EC"B`@("`@*B!`9&5P<F5C871E9`H@("`@("HO"B`@("!F=6YC
M=&EO;B!S96%R8VA,;V-A=&EO;B@D;&]C871I;VX@/2!N=6QL+"`D=7-E1FER
M<W0@/2!N=6QL*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*
M("`@("\O('U]?0H*("`@("\O('M[>R!S96%R8VA,;V-A=&EO;D)Y0V]U;G1R
M>2@I"B`@("`O*BH*("`@("`J($5*4T4@;V9F97)S(&YO('-E87)C:"!F=6YC
M=&EO;B!T;R!D871E+"!S;R!T:&ES(&9U;F-T:6]N(&ES(&1I<V%B;&5D+@H@
M("`@("H@36%Y8F4@=&AI<R!I<R!T:&4@<&QA8V4@=&\@:6YT97)F86-E('1O
M('-O;64@;VYL:6YE('!O<W1C;V1E('-E<G9I8V4N+BX*("`@("`J"B`@("`@
M*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)&-O=6YT
M<GD*("`@("`J($!R971U<FX@(&)O;VP*("`@("`J($!A8V-E<W,@('!U8FQI
M8PH@("`@("H@0&1E<')E8V%T960*("`@("`J+PH@("`@9G5N8W1I;VX@<V5A
M<F-H3&]C871I;VY">4-O=6YT<GDH)&-O=6YT<GD@/2!N=6QL*0H@("`@>PH@
M("`@("`@(')E='5R;B!F86QS93L*("`@('T*("`@("\O('U]?0H*("`@("\O
M('M[>R!G971,;V-A=&EO;B@I"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE
M(&1A=&$@9F]R('1H92!L;V-A=&EO;B!B96QO;F=I;F<@=&\@=&AE($E$"B`@
M("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@
M("`@("1I9`H@("`@("H@0')E='5R;B`@4$5!4E]%<G)O<GQA<G)A>0H@("`@
M("H@0'1H<F]W<R`@4$5!4E]%<G)O<@H@("`@("H@0&%C8V5S<R`@<'5B;&EC
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$QO8V%T:6]N*"1I9"`]("(B*0H@
M("`@>PH@("`@("`@("1S=&%T=7,@/2`D=&AI<RT^7V-H96-K3&]C871I;VY)
M1"@D:60I.PH*("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O
M<B@D<W1A='5S*2D@>PH@("`@("`@("`@("!R971U<FX@)'-T871U<SL*("`@
M("`@("!]"@H@("`@("`@("1L;V-A=&EO;E)E='5R;B`](&%R<F%Y*"D["@H@
M("`@("`@(&EF("@D=&AI<RT^7V-A8VAE16YA8FQE9"`F)B`H)'=E871H97(@
M/2`D=&AI<RT^7V-A8VAE+3YG970H)&ED+"`B=V5A=&AE<B(I*2D@>PH@("`@
M("`@("`@("`O+R!'970@9&%T82!F<F]M(&-A8VAE"B`@("`@("`@("`@("1T
M:&ES+3Y?=V5A=&AE<B`]("1W96%T:&5R.PH@("`@("`@("`@("`D;&]C871I
M;VY2971U<FY;(F-A8VAE(ET@/2`B2$E4(CL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`O+R!#:&5C:RP@:68@=&AE('=E871H97)3;V%P+4]B:F5C
M="!I<R!P<F5S96YT+B!)9B!N;W0L(&-O;FYE8W0@=&\@=&AE(%-E<G9E<B!A
M;F0@<F5T<FEE=F4@=&AE(%=$4TP@9&%T80H@("`@("`@("`@("!I9B`H(21T
M:&ES+3Y?=V5A=&AE<E-O87`I('L*("`@("`@("`@("`@("`@("1S=&%T=7,@
M/2`D=&AI<RT^7V-O;FYE8W1397)V97(H*3L*("`@("`@("`@("`@("`@(&EF
M("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N("1S=&%T=7,["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1W96%T:&5R(#T@)'1H
M:7,M/E]W96%T:&5R4V]A<"T^9V5T5V5A=&AE<DEN9F\H)&ED*3L*"B`@("`@
M("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1W96%T:&5R
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1W96%T:&5R.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^7W=E871H97(@/2`D=V5A=&AE
M<CL*"B`@("`@("`@("`@(&EF("@D=&AI<RT^7V-A8VAE16YA8FQE9"D@>PH@
M("`@("`@("`@("`@("`@+R\@+BXN86YD(&-A8VAE(&ET"B`@("`@("`@("`@
M("`@("`D97AP:7)E(#T@8V]N<W1A;G0H(E-%4E9)0T537U=%051(15)?15A0
M25)%4U]714%42$52(BD["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-A8VAE
M+3YE>'13879E*"1I9"P@)'1H:7,M/E]W96%T:&5R+"`B(BP@)&5X<&ER92P@
M(G=E871H97(B*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D;&]C871I
M;VY2971U<FY;(F-A8VAE(ET@/2`B34E34R(["B`@("`@("`@?0H@("`@("`@
M("1L;V-A=&EO;E)E='5R;ELB;F%M92)=(#T@)'1H:7,M/E]W96%T:&5R+3Y,
M;V-A=&EO;CL*"B`@("`@("`@<F5T=7)N("1L;V-A=&EO;E)E='5R;CL*("`@
M('T*("`@("\O('U]?0H*("`@("\O('M[>R!G971796%T:&5R*"D*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!T:&4@=V5A=&AE<BUD871A(&9O<B!T:&4@<W5P
M<&QI960@;&]C871I;VX*("`@("`J"B`@("`@*B!`<&%R86T@("!S=')I;F<@
M("`@("`@("`@("`@("`@("`@("`@)&ED"B`@("`@*B!`<&%R86T@("!S=')I
M;F<@("`@("`@("`@("`@("`@("`@("`@)'5N:71S1F]R;6%T"B`@("`@*B!`
M<F5T=7)N("!014%27T5R<F]R?&%R<F%Y"B`@("`@*B!`=&AR;W=S("!014%2
M7T5R<F]R"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T5V5A=&AE<B@D:60@/2`B(BP@)'5N:71S1F]R;6%T(#T@(B(I
M"B`@("!["B`@("`@("`@)'-T871U<R`]("1T:&ES+3Y?8VAE8VM,;V-A=&EO
M;DE$*"1I9"D["@H@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R
M<F]R*"1S=&%T=7,I*2!["B`@("`@("`@("`@(')E='5R;B`D<W1A='5S.PH@
M("`@("`@('T*"B`@("`@("`@+R\@1V5T(&]T:&5R(&1A=&$*("`@("`@("`D
M=6YI=',@("`@/2`D=&AI<RT^9V5T56YI='-&;W)M870H)'5N:71S1F]R;6%T
M*3L*"B`@("`@("`@)'=E871H97)2971U<FX@/2!A<G)A>2@I.PH@("`@("`@
M(&EF("@D=&AI<RT^7V-A8VAE16YA8FQE9"`F)B`H)'=E871H97(@/2`D=&AI
M<RT^7V-A8VAE+3YG970H)&ED+"`B=V5A=&AE<B(I*2D@>PH@("`@("`@("`@
M("`O+R!386UE('!R;V-E9'5R92XN+@H@("`@("`@("`@("`D=&AI<RT^7W=E
M871H97(@/2`D=V5A=&AE<CL*("`@("`@("`@("`@)'=E871H97)2971U<FY;
M(F-A8VAE(ET@/2`B2$E4(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`O+R!#:&5C:RP@:68@=&AE('=E871H97)3;V%P+4]B:F5C="!I<R!P<F5S
M96YT+B!)9B!N;W0L(&-O;FYE8W0@=&\@=&AE(%-E<G9E<B!A;F0@<F5T<FEE
M=F4@=&AE(%=$4TP@9&%T80H@("`@("`@("`@("!I9B`H(21T:&ES+3Y?=V5A
M=&AE<E-O87`I('L*("`@("`@("`@("`@("`@("1S=&%T=7,@/2`D=&AI<RT^
M7V-O;FYE8W1397)V97(H*3L*("`@("`@("`@("`@("`@(&EF("A397)V:6-E
M<U]796%T:&5R.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1S=&%T=7,["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("\O("XN+F%S(&QA<W0@9G5N8W1I;VX*
M("`@("`@("`@("`@)'=E871H97(@/2`D=&AI<RT^7W=E871H97)3;V%P+3YG
M971796%T:&5R26YF;R@D:60I.PH*("`@("`@("`@("`@:68@*%-E<G9I8V5S
M7U=E871H97(Z.FES17)R;W(H)'=E871H97(I*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@)'=E871H97(["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1T:&ES+3Y?=V5A=&AE<B`]("1W96%T:&5R.PH*("`@("`@("`@("`@:68@
M*"1T:&ES+3Y?8V%C:&5%;F%B;&5D*2!["B`@("`@("`@("`@("`@("`O+R`N
M+BYA;F0@8V%C:&4@:70*("`@("`@("`@("`@("`@("1E>'!I<F4@/2!C;VYS
M=&%N="@B4T525DE#15-?5T5!5$A%4E]%6%!)4D537U=%051(15(B*3L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?8V%C:&4M/F5X=%-A=F4H)&ED+"`D=&AI
M<RT^7W=E871H97(L("(B+"`D97AP:7)E+"`B=V5A=&AE<B(I.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1W96%T:&5R4F5T=7)N6R)C86-H92)=(#T@
M(DU)4U,B.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I<W-E="@D8V]M<&%S
M<RDI('L*("`@("`@("`@("`@+R\@665S+"!.3D4@86YD('1H92!L:6ME<R!A
M<F4@;75L=&EP;&5S(&]F(#(R+C4L(&)U="!A<R!T:&4@;W1H97(*("`@("`@
M("`@("`@+R\@<V5R=FEC97,@<F5T=7)N(&EN=&5G97)S(&9O<B!T:&ES('9A
M;'5E+"!T:&5S92!D:7)E8W1I;VYS(&%R90H@("`@("`@("`@("`O+R!R;W5N
M9&5D('5P"B`@("`@("`@("`@("1C;VUP87-S(#T@87)R87DH"B`@("`@("`@
M("`@("`@("`B;F]R=&@B("`@("`@("`@("`@(#T^(&%R<F%Y*").(BP@("`@
M(#`I+`H@("`@("`@("`@("`@("`@(FYO<G1H(&YO<G1H96%S="(@("`]/B!A
M<G)A>2@B3DY%(BP@(#(S*2P*("`@("`@("`@("`@("`@(")N;W)T:&5A<W0B
M("`@("`@("`@/3X@87)R87DH(DY%(BP@("`T-2DL"B`@("`@("`@("`@("`@
M("`B96%S="!N;W)T:&5A<W0B("`@(#T^(&%R<F%Y*")%3D4B+"`@-C@I+`H@
M("`@("`@("`@("`@("`@(F5A<W0B("`@("`@("`@("`@("`]/B!A<G)A>2@B
M12(L("`@(#DP*2P*("`@("`@("`@("`@("`@(")E87-T('-O=71H96%S="(@
M("`@/3X@87)R87DH(D5312(L(#$Q,RDL"B`@("`@("`@("`@("`@("`B<V]U
M=&AE87-T(B`@("`@("`@(#T^(&%R<F%Y*")312(L("`Q,S4I+`H@("`@("`@
M("`@("`@("`@(G-O=71H('-O=71H96%S="(@("`]/B!A<G)A>2@B4U-%(BP@
M,34X*2P*("`@("`@("`@("`@("`@(")S;W5T:"(@("`@("`@("`@("`@/3X@
M87)R87DH(E,B+"`@(#$X,"DL"B`@("`@("`@("`@("`@("`B<V]U=&@@<V]U
M=&AW97-T(B`@(#T^(&%R<F%Y*")34U<B+"`R,#,I+`H@("`@("`@("`@("`@
M("`@(G-O=71H=V5S="(@("`@("`@("`]/B!A<G)A>2@B4U<B+"`@,C(U*2P*
M("`@("`@("`@("`@("`@(")W97-T('-O=71H=V5S="(@("`@/3X@87)R87DH
M(E=35R(L(#(T."DL"B`@("`@("`@("`@("`@("`B=V5S="(@("`@("`@("`@
M("`@(#T^(&%R<F%Y*")7(BP@("`R-S`I+`H@("`@("`@("`@("`@("`@(G=E
M<W0@;F]R=&AW97-T(B`@("`]/B!A<G)A>2@B5TY7(BP@,CDS*2P*("`@("`@
M("`@("`@("`@(")N;W)T:'=E<W0B("`@("`@("`@/3X@87)R87DH(DY7(BP@
M(#,Q-2DL"B`@("`@("`@("`@("`@("`B;F]R=&@@;F]R=&AW97-T(B`@(#T^
M(&%R<F%Y*").3E<B+"`S,S@I"B`@("`@("`@("`@("D["B`@("`@("`@?0H*
M("`@("`@("`O+R!);FET:6%L:7IE('-O;64@87)R87ES"B`@("`@("`@)'5P
M9&%T92`@("`@("`@("`@("`](&%R<F%Y*"D["B`@("`@("`@)'1E;7!E<F%T
M=7)E("`@("`@("`](&%R<F%Y*"D["B`@("`@("`@)&9E;'1496UP97)A='5R
M92`@("`](&%R<F%Y*"D["B`@("`@("`@)'9I<VEB:6QI='D@("`@("`@("`]
M(&%R<F%Y*"D["B`@("`@("`@)'!R97-S=7)E("`@("`@("`@("`](&%R<F%Y
M*"D["B`@("`@("`@)&1E=U!O:6YT("`@("`@("`@("`](&%R<F%Y*"D["B`@
M("`@("`@)'5V26YD97@@("`@("`@("`@("`](&%R<F%Y*"D["B`@("`@("`@
M)'=I;F0@("`@("`@("`@("`@("`](&%R<F%Y*"D["@H@("`@("`@(&EF("AP
M<F5G7VUA=&-H*"(O*%QW*RD@*%QD*RDL("A<9"LI+"!A="`H7&0K.EQD*R!<
M=TTI(%M>7"A=*RA<*"A;7EPI72LI7"DI/R\B+"`D=&AI<RT^7W=E871H97(M
M/DQA<W15<&1A=&5D+"`D=7!D871E*2D@>PH@("`@("`@("`@("!I9B`H:7-S
M970H)'5P9&%T95LU72DI('L*("`@("`@("`@("`@("`@("1T:6UE<W1R:6YG
M(#T@)'5P9&%T95LV73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1T:6UE<W1R:6YG(#T@)'5P9&%T95LR72XB("(N)'5P9&%T95LQ
M72XB("(N)'5P9&%T95LS72XB("(N)'5P9&%T95LT72XB($535"(["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)'=E871H97)2971U<FY;(G5P9&%T92)=
M("`@("`@("`@("`@/2!G;61A=&4H=')I;2@D=&AI<RT^7V1A=&5&;W)M870N
M(B`B+B1T:&ES+3Y?=&EM949O<FUA="DL('-T<G1O=&EM92@D=&EM97-T<FEN
M9RDI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1W96%T:&5R4F5T
M=7)N6R)U<&1A=&4B72`@("`@("`@("`@(#T@(B(["B`@("`@("`@?0H@("`@
M("`@("1W96%T:&5R4F5T=7)N6R)U<&1A=&5287<B72`@("`@("`@(#T@)'1H
M:7,M/E]W96%T:&5R+3Y,87-T57!D871E9#L*("`@("`@("`D=V5A=&AE<E)E
M='5R;ELB<W1A=&EO;B)=("`@("`@("`@("`]("1T:&ES+3Y?=V5A=&AE<BT^
M4F5P;W)T961!=#L*("`@("`@("`D=V5A=&AE<E)E='5R;ELB8V]N9&ET:6]N
M26-O;B)=("`@("`]("1T:&ES+3Y?=V5A=&AE<BT^26-O;DEN9&5X.PH@("`@
M("`@('!R96=?;6%T8V@H(B\H+3]<9"LI7$0K+R(L("1T:&ES+3Y?=V5A=&AE
M<BT^5&5M<')A='5R92P@)'1E;7!E<F%T=7)E*3L*("`@("`@("`D=V5A=&AE
M<E)E='5R;ELB=&5M<&5R871U<F4B72`@("`@("`]("1T:&ES+3YC;VYV97)T
M5&5M<&5R871U<F4H)'1E;7!E<F%T=7)E6S%=+"`B9B(L("1U;FET<ULB=&5M
M<")=*3L*("`@("`@("!P<F5G7VUA=&-H*"(O*"T_7&0K*5Q$*R\B+"`D=&AI
M<RT^7W=E871H97(M/D9E96QS3&EK92P@)&9E;'1496UP97)A='5R92D["B`@
M("`@("`@)'=E871H97)2971U<FY;(F9E;'1496UP97)A='5R92)=("`@/2`D
M=&AI<RT^8V]N=F5R=%1E;7!E<F%T=7)E*"1F96QT5&5M<&5R871U<F5;,5TL
M(")F(BP@)'5N:71S6R)T96UP(ETI.PH@("`@("`@("1W96%T:&5R4F5T=7)N
M6R)C;VYD:71I;VXB72`@("`@("`@(#T@)'1H:7,M/E]W96%T:&5R+3Y&;W)E
M8V%S=#L*("`@("`@("!I9B`H<')E9U]M871C:"@B+RA;7&1<+ETK*5Q$*R\B
M+"`D=&AI<RT^7W=E871H97(M/E9I<VEB:6QI='DL("1V:7-I8FEL:71Y*2D@
M>PH@("`@("`@("`@("`D=V5A=&AE<E)E='5R;ELB=FES:6)I;&ET>2)=("`@
M(#T@)'1H:7,M/F-O;G9E<G1$:7-T86YC92@D=FES:6)I;&ET>5LQ72P@(G-M
M(BP@)'5N:71S6R)V:7,B72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'=E871H97)2971U<FY;(G9I<VEB:6QI='DB72`@("`]('1R:6TH)'1H
M:7,M/E]W96%T:&5R+3Y6:7-I8FEL:71Y*3L*("`@("`@("!]"B`@("`@("`@
M<')E9U]M871C:"@B+RA;7&1<+ETK*2!I;F-H97,@86YD("A<=RLI+R(L("1T
M:&ES+3Y?=V5A=&AE<BT^4')E<W-U<F4L("1P<F5S<W5R92D["B`@("`@("`@
M)'=E871H97)2971U<FY;(G!R97-S=7)E(ET@("`@("`@("`@/2`D=&AI<RT^
M8V]N=F5R=%!R97-S=7)E*"1P<F5S<W5R95LQ72P@(FEN(BP@)'5N:71S6R)P
M<F5S(ETI.PH@("`@("`@("1W96%T:&5R4F5T=7)N6R)P<F5S<W5R951R96YD
M(ET@("`@(#T@)'!R97-S=7)E6S)=.PH@("`@("`@('!R96=?;6%T8V@H(B\H
M+3]<9"LI7$0K+R(L("1T:&ES+3Y?=V5A=&AE<BT^1&5W4&]I;G0L("1D97=0
M;VEN="D["B`@("`@("`@)'=E871H97)2971U<FY;(F1E=U!O:6YT(ET@("`@
M("`@("`@/2`D=&AI<RT^8V]N=F5R=%1E;7!E<F%T=7)E*"1D97=0;VEN=%LQ
M72P@(F8B+"`D=6YI='-;(G1E;7`B72D["B`@("`@("`@<')E9U]M871C:"@B
M+RA<9"LI("A<=RLI+R(L("1T:&ES+3Y?=V5A=&AE<BT^559);F1E>"P@)'5V
M26YD97@I.PH@("`@("`@("1W96%T:&5R4F5T=7)N6R)U=DEN9&5X(ET@("`@
M("`@("`@(#T@)'5V26YD97A;,5T["B`@("`@("`@)'=E871H97)2971U<FY;
M(G5V5&5X=")=("`@("`@("`@("`@/2`D=79);F1E>%LR73L*("`@("`@("`D
M=V5A=&AE<E)E='5R;ELB:'5M:61I='DB72`@("`@("`@("`]('-T<E]R97!L
M86-E*"(E(BP@(B(L("1T:&ES+3Y?=V5A=&AE<BT^2'5M:61I='DI.PH@("`@
M("`@(&EF("AP<F5G7VUA=&-H*"(O1G)O;2!T:&4@*%M<=UP@72LI(&%T("A;
M7&1<+ETK*2`H9W5S=&EN9R!T;R`H6UQD7"Y=*RD@*3]M<&@O(BP@)'1H:7,M
M/E]W96%T:&5R+3Y7:6YD+"`D=VEN9"DI('L*("`@("`@("`@("`@)'=E871H
M97)2971U<FY;(G=I;F0B72`@("`@("`@("`@("`@/2`D=&AI<RT^8V]N=F5R
M=%-P965D*"1W:6YD6S)=+"`B;7!H(BP@)'5N:71S6R)W:6YD(ETI.PH@("`@
M("`@("`@("!I9B`H:7-S970H)'=I;F1;-%TI*2!["B`@("`@("`@("`@("`@
M("`D=V5A=&AE<E)E='5R;ELB=VEN9$=U<W0B72`@("`@(#T@)'1H:7,M/F-O
M;G9E<G13<&5E9"@D=VEN9%LT72P@(FUP:"(L("1U;FET<ULB=VEN9")=*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D=V5A=&AE<E)E='5R;ELB=VEN
M9$1E9W)E97,B72`@("`@("`]("1C;VUP87-S6W-T<G1O;&]W97(H)'=I;F1;
M,5TI75LQ73L*("`@("`@("`@("`@)'=E871H97)2971U<FY;(G=I;F1$:7)E
M8W1I;VXB72`@("`@/2`D8V]M<&%S<UMS=')T;VQO=V5R*"1W:6YD6S%=*5U;
M,%T["B`@("`@("`@?2!E;'-E:68@*'-T<G1O;&]W97(H)'1H:7,M/E]W96%T
M:&5R+3Y7:6YD*2`]/2`B8V%L;2(I('L*("`@("`@("`@("`@)'=E871H97)2
M971U<FY;(G=I;F0B72`@("`@("`@("`](#`["B`@("`@("`@("`@("1W96%T
M:&5R4F5T=7)N6R)W:6YD1&5G<F5E<R)=("`@/2`P.PH@("`@("`@("`@("`D
M=V5A=&AE<E)E='5R;ELB=VEN9$1I<F5C=&EO;B)=(#T@(D-!3$TB.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1W96%T:&5R4F5T=7)N.PH@("`@?0H@
M("`@+R\@?7U]"@H@("`@+R\@>WM[(&=E=$9O<F5C87-T*"D*("`@("\J*@H@
M("`@("H@1V5T('1H92!F;W)E8V%S="!F;W(@=&AE(&YE>'0@9&%Y<PH@("`@
M("H*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@
M("`D:6YT"B`@("`@*B!`<&%R86T@("!I;G0@("`@("`@("`@("`@("`@("`@
M("`@("`@)&1A>7,@("`@("`@("`@(%9A;'5E<R!B971W965N(#$@86YD(#D*
M("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D
M=6YI='-&;W)M870*("`@("`J($!R971U<FX@(%!%05)?17)R;W)\87)R87D*
M("`@("`J($!T:')O=W,@(%!%05)?17)R;W(*("`@("`J($!A8V-E<W,@('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!G971&;W)E8V%S="@D:60@/2`B
M(BP@)&1A>7,@/2`R+"`D=6YI='-&;W)M870@/2`B(BD*("`@('L*("`@("`@
M("`D<W1A='5S(#T@)'1H:7,M/E]C:&5C:TQO8V%T:6]N240H)&ED*3L*"B`@
M("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'-T871U<RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1S=&%T=7,["B`@("`@("`@?0H@("`@
M("`@(&EF("@A:6Y?87)R87DH)&1A>7,L(')A;F=E*#$L(#DI*2D@>PH@("`@
M("`@("`@("`D9&%Y<R`](#(["B`@("`@("`@?0H*("`@("`@("`O+R!'970@
M;W1H97(@9&%T80H@("`@("`@("1U;FET<R`@("`]("1T:&ES+3YG9715;FET
M<T9O<FUA="@D=6YI='-&;W)M870I.PH*("`@("`@("`D9F]R96-A<W12971U
M<FX@/2!A<G)A>2@I.PH@("`@("`@(&EF("@D=&AI<RT^7V-A8VAE16YA8FQE
M9"`F)B`H)&9O<F5C87-T(#T@)'1H:7,M/E]C86-H92T^9V5T*"1I9"P@(F9O
M<F5C87-T(BDI*2!["B`@("`@("`@("`@("\O(%-A;64@<')O8V5D=7)E+BXN
M"B`@("`@("`@("`@("1T:&ES+3Y?9F]R96-A<W0@/2`D9F]R96-A<W0["B`@
M("`@("`@("`@("1F;W)E8V%S=%)E='5R;ELB8V%C:&4B72`](")(250B.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O($-H96-K+"!I9B!T:&4@
M=V5A=&AE<E-O87`M3V)J96-T(&ES('!R97-E;G0N($EF(&YO="P@8V]N;F5C
M="!T;R!T:&4@4V5R=F5R(&%N9"!R971R:65V92!T:&4@5T133"!D871A"B`@
M("`@("`@("`@(&EF("@A)'1H:7,M/E]W96%T:&5R4V]A<"D@>PH@("`@("`@
M("`@("`@("`@)'-T871U<R`]("1T:&ES+3Y?8V]N;F5C=%-E<G9E<B@I.PH@
M("`@("`@("`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H
M)'-T871U<RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'-T871U
M<SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@+R\@+BXN87,@;&%S="!F=6YC=&EO;@H@("`@("`@("`@("`D9F]R96-A
M<W0@/2`D=&AI<RT^7W=E871H97)3;V%P+3Y'971.:6YE1&%Y1F]R96-A<W1)
M;F9O*"1I9"D["@H@("`@("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ
M:7-%<G)O<B@D9F]R96-A<W0I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)&9O<F5C87-T.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^
M7V9O<F5C87-T(#T@)&9O<F5C87-T.PH*("`@("`@("`@("`@:68@*"1T:&ES
M+3Y?8V%C:&5%;F%B;&5D*2!["B`@("`@("`@("`@("`@("`O+R`N+BYA;F0@
M8V%C:&4@:70*("`@("`@("`@("`@("`@("1E>'!I<F4@/2!C;VYS=&%N="@B
M4T525DE#15-?5T5!5$A%4E]%6%!)4D537T9/4D5#05-4(BD["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V-A8VAE+3YE>'13879E*"1I9"P@)'1H:7,M/E]F
M;W)E8V%S="P@(B(L("1E>'!I<F4L(")F;W)E8V%S="(I.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1F;W)E8V%S=%)E='5R;ELB8V%C:&4B72`](")-
M25-3(CL*("`@("`@("!]"@H@("`@("`@("1F;W)E8V%S=%)E='5R;ELB9&%Y
M<R)=("`@/2!A<G)A>2@I.PH*("`@("`@("`O+R!);FET:6%L:7IE('-O;64@
M87)R87ES"B`@("`@("`@)'1E;7!E<F%T=7)E2&EG:"`@("`](&%R<F%Y*"D[
M"B`@("`@("`@)'1E;7!E<F%T=7)E3&]W("`@("`](&%R<F%Y*"D["@H@("`@
M("`@(&9O<B`H)&D@/2`Q.R`D:2`\/2`D9&%Y<SL@)&DK*RD@>PH@("`@("`@
M("`@("!P<F5G7VUA=&-H*"(O*"T_7&0K*5Q$*R\B+"`D=&AI<RT^7V9O<F5C
M87-T+3Y[(D1A>2(N)&E]+3Y(:6=H+"`D=&5M<&5R871U<F5(:6=H*3L*("`@
M("`@("`@("`@<')E9U]M871C:"@B+R@M/UQD*RE<1"LO(BP@)'1H:7,M/E]F
M;W)E8V%S="T^>R)$87DB+B1I?2T^3&]W+"`D=&5M<&5R871U<F5,;W<I.PH@
M("`@("`@("`@("`D9&%Y(#T@87)R87DH"B`@("`@("`@("`@("`@("`B=&5M
M<&5R='5R94AI9V@B(#T^("1T:&ES+3YC;VYV97)T5&5M<&5R871U<F4H)'1E
M;7!E<F%T=7)E2&EG:%LQ72P@(F8B+"`D=6YI='-;(G1E;7`B72DL"B`@("`@
M("`@("`@("`@("`B=&5M<&5R871U<F5,;W<B(#T^("1T:&ES+3YC;VYV97)T
M5&5M<&5R871U<F4H)'1E;7!E<F%T=7)E3&]W6S%=+"`B9B(L("1U;FET<ULB
M=&5M<")=*2P*("`@("`@("`@("`@("`@(")D87DB(#T^(&%R<F%Y*`H@("`@
M("`@("`@("`@("`@("`@(")C;VYD:71I;VXB("`@("`]/B`D=&AI<RT^7V9O
M<F5C87-T+3Y[(D1A>2(N)&E]+3Y&;W)E8V%S="P*("`@("`@("`@("`@("`@
M("`@("`B8V]N9&ET:6]N26-O;B(@/3X@)'1H:7,M/E]F;W)E8V%S="T^>R)$
M87DB+B1I?2T^26-O;DEN9&5X+`H@("`@("`@("`@("`@("`@("`@(")P<F5C
M:7!I=&%T:6]N(B`]/B!T<FEM*'-T<E]R97!L86-E*"(E(BP@(B(L("1T:&ES
M+3Y?9F]R96-A<W0M/GLB1&%Y(BXD:7TM/E!R96-I<$-H86YC92DI"B`@("`@
M("`@("`@("`@("`I"B`@("`@("`@("`@("D["@H@("`@("`@("`@("`D9F]R
M96-A<W12971U<FY;(F1A>7,B75M=(#T@)&1A>3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D9F]R96-A<W12971U<FX["B`@("!]"B`@("`O+R!]?7T*
M?0HO+R!]?7T*/SX*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U-E
M<G9I8V5S+U=E871H97(O1VQO8F%L=V5A=&AE<BYP:'``````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P-#8T-#`@,3`U,34T,S,W,C<@,#(U,34T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J('9I;3H@
M<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S
M=&]P/30@9F]L9&UE=&AO9#UM87)K97(Z("HO"@HO*BH*("H@4$5!4CHZ4V5R
M=FEC97-?5V5A=&AE<E]';&]B86QW96%T:&5R"B`J"B`J(%!(4"!V97)S:6]N
M<R`T(&%N9"`U"B`J"B`J(#Q,24-%3E-%/@H@*B!#;W!Y<FEG:'0@*&,I(#(P
M,#4L($%L97AA;F1E<B!7:7)T>@H@*B!!;&P@<FEG:'1S(')E<V5R=F5D+@H@
M*@H@*B!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN
M87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70*("H@;6]D:69I8V%T:6]N+"!A
M<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO=VEN9R!C;VYD
M:71I;VYS"B`J(&%R92!M970Z"B`J(&\@4F5D:7-T<FEB=71I;VYS(&]F('-O
M=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0@;F]T
M:6-E+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L
M;&]W:6YG(&1I<V-L86EM97(N"B`J(&\@4F5D:7-T<FEB=71I;VYS(&EN(&)I
M;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0@
M;F]T:6-E+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@
M9F]L;&]W:6YG(&1I<V-L86EM97(@:6X@=&AE(&1O8W5M96YT871I;VX*("H@
M("!A;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE(&1I
M<W1R:6)U=&EO;BX*("H@;R!.96ET:&5R('1H92!N86UE(&]F('1H92!S;V9T
M=V%R92!N;W(@=&AE(&YA;65S(&]F(&ET<R!C;VYT<FEB=71O<G,*("H@("!M
M87D@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O9'5C=',@9&5R
M:79E9"!F<F]M('1H:7,@<V]F='=A<F4*("H@("!W:71H;W5T('-P96-I9FEC
M('!R:6]R('=R:71T96X@<&5R;6ES<VEO;BX*("H*("H@5$A)4R!33T945T%2
M12!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@04Y$($-/
M3E1224)55$]24R`B05,@25,B"B`J($%.1"!!3ED@15A04D534R!/4B!)35!,
M245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5"!,24U)5$5$(%1/
M+"!42$4*("H@24U03$E%1"!705)204Y42453($]&($U%4D-(04Y404))3$E4
M62!!3D0@1DE43D534R!&3U(@02!005)424-53$%2(%!54E!/4T4*("H@05)%
M($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(12!#3U!94DE'2%0@
M3U=.15(@3U(@0T].5%))0E543U)3($)%"B`J($Q)04),12!&3U(@04Y9($1)
M4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL(%-014-)04PL($5814U03$%2
M62P@3U(*("H@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,541)3D<L($)5
M5"!.3U0@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8*("H@4U5"4U1)5%54
M12!'3T]$4R!/4B!315)624-%4SL@3$]34R!/1B!54T4L($1!5$$L($]2(%!2
M3T9)5%,[($]2($)54TE.15-3"B`J($E.5$524E505$E/3BD@2$]7159%4B!#
M0553140@04Y$($].($%.62!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52
M($E."B`J($-/3E1204-4+"!35%))0U0@3$E!0DE,2519+"!/4B!43U)4("A)
M3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I"B`J($%225-)3D<@
M24X@04Y9(%=!62!/550@3T8@5$A%(%5312!/1B!42$E3(%-/1E1705)%+"!%
M5D5.($E&($%$5DE3140@3T8@5$A%"B`J(%!/4U-)0DE,2519($]&(%-50T@@
M1$%-04=%+@H@*B`\+TQ)0T5.4T4^"B`J"B`J($!C871E9V]R>2`@("!796(@
M4V5R=FEC97,*("H@0'!A8VMA9V4@("`@(%-E<G9I8V5S7U=E871H97(*("H@
M0&%U=&AO<B`@("`@($%L97AA;F1E<B!7:7)T>B`\86QE>$!P8S1P+FYE=#X*
M("H@0&-O<'ER:6=H="`@(#(P,#4@06QE>&%N9&5R(%=I<G1Z"B`J($!L:6-E
M;G-E("`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S
M9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@($-6
M4SH@)$ED.B!';&]B86QW96%T:&5R+G!H<"QV(#$N,S0@,C`P-2\Q,2\Q,R`R
M,3HU-CHQ-B!E<G4@17AP("0*("H@0&QI;FL@("`@("`@(&AT='`Z+R]P96%R
M+G!H<"YN970O<&%C:V%G92]397)V:6-E<U]796%T:&5R"B`J($!L:6YK("`@
M("`@("!H='1P.B\O=W=W+F-A<&5S8VEE;F-E+F-O;2]W96)S97)V:6-E<R]G
M;&]B86QW96%T:&5R+VEN9&5X+G-H=&UL"B`J($!E>&%M<&QE("`@("!E>&%M
M<&QE<R]G;&]B86QW96%T:&5R+6)A<VEC+G!H<"`@("!G;&]B86QW96%T:&5R
M+6)A<VEC+G!H<`H@*B!`9FEL97-O=7)C90H@*B\*"G)E<75I<F5?;VYC92`B
M4V5R=FEC97,O5V5A=&AE<B]#;VUM;VXN<&AP(CL*"B\O('M[>R!C;&%S<R!3
M97)V:6-E<U]796%T:&5R7T=L;V)A;'=E871H97(*+RHJ"B`J(%1H:7,@8VQA
M<W,@86-T<R!A<R!A;B!I;G1E<F9A8V4@=&\@=&AE('-O87`@<V5R=FEC92!O
M9B!C87!E<V-I96YC92YC;VTN"B`J($ET('-E87)C:&5S(&9O<B!G:79E;B!L
M;V-A=&EO;G,@86YD(')E=')I979E<R!C=7)R96YT('=E871H97(@9&%T82X*
M("H*("H@1VQO8F%L5V5A=&AE<B!I<R!A(%-/05`@9G)O;G1E;F0@9F]R($U%
M5$%2(&1A=&$L('!R;W9I9&5D(&)Y($-A<&538VEE;F-E+@H@*B!)9B!Y;W4@
M=V%N="!T;R!U<V4@345405(L('EO=2!S:&]U;&0@=')Y('1H:7,@8VQA<W,@
M9FER<W0L(&%S(&ET(&ES(&UU8V@*("H@;6]R92!C;VUF;W)T86)L92`H86YD
M(&%L<V\@82!B:70@9F%S=&5R*2!T:&%N('1H92!N871I=F4@345405(M8VQA
M<W,*("H@<')O=FED960@8GD@=&AI<R!P86-K86=E+B!/;B!T:&4@;W1H97(@
M:&%N9"P@=&AI<R!S97)V:6-E('=O;B=T('-U<'!L>0H@*B!4049S+"!T:&4@
M9F]R96-A<W0@<WES=&5M(&%C8V]M<&%N>6EN9R!-151!4BP@<V\@>6]U(&AA
M=F4@=&\@;6%K90H@*B!T:&4@8V%L;"!H97)E+BXN"B`J"B`J($9O<B!A('=O
M<FMI;F<@97AA;7!L92P@<&QE87-E('1A:V4@82!L;V]K(&%T"B`J("`@("!D
M;V-S+U-E<G9I8V5S7U=E871H97(O97AA;7!L97,O9VQO8F%L=V5A=&AE<BUB
M87-I8RYP:'`*("H*("H*("H@0&-A=&5G;W)Y("`@(%=E8B!397)V:6-E<PH@
M*B!`<&%C:V%G92`@("`@4V5R=FEC97-?5V5A=&AE<@H@*B!`875T:&]R("`@
M("`@06QE>&%N9&5R(%=I<G1Z(#QA;&5X0'!C-'`N;F5T/@H@*B!`8V]P>7)I
M9VAT("`@,C`P-2!!;&5X86YD97(@5VER='H*("H@0&QI8V5N<V4@("`@(&AT
M='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N
M<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@("`@4F5L96%S93H@,2XT
M+C`*("H@0&QI;FL@("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G
M92]397)V:6-E<U]796%T:&5R"B`J($!L:6YK("`@("`@("!H='1P.B\O=W=W
M+F-A<&5S8VEE;F-E+F-O;2]W96)S97)V:6-E<R]G;&]B86QW96%T:&5R+VEN
M9&5X+G-H=&UL"B`J($!E>&%M<&QE("`@("!E>&%M<&QE<R]G;&]B86QW96%T
M:&5R+6)A<VEC+G!H<"`@("!G;&]B86QW96%T:&5R+6)A<VEC+G!H<`H@*B\*
M8VQA<W,@4V5R=FEC97-?5V5A=&AE<E]';&]B86QW96%T:&5R(&5X=&5N9',@
M4V5R=FEC97-?5V5A=&AE<E]#;VUM;VX@>PH*("`@("\O('M[>R!P<F]P97)T
M:65S"B`@("`O*BH*("`@("`J(%=31$P@;V)J96-T+"!P<F]V:61E9"!B>2!#
M87!E4V-I96YC90H@("`@("H*("`@("`J($!V87(@("`@(&]B:F5C="`@("`@
M("`@("`@("`@("`@("`@("`D7W=S9&P*("`@("`J($!A8V-E<W,@('!R:79A
M=&4*("`@("`J+PH@("`@=F%R("1?=W-D;#L*"B`@("`O*BH*("`@("`J(%-/
M05`@;V)J96-T('1O(&%C8V5S<R!S=&%T:6]N(&1A=&$L('!R;W9I9&5D(&)Y
M($-A<&538VEE;F-E"B`@("`@*@H@("`@("H@0'9A<B`@("`@;V)J96-T("`@
M("`@("`@("`@("`@("`@("`@("1?<W1A=&EO;E-O87`*("`@("`J($!A8V-E
M<W,@('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?<W1A=&EO;E-O87`["@H@
M("`@+RHJ"B`@("`@*B!33T%0(&]B:F5C="!T;R!A8V-E<W,@=V5A=&AE<B!D
M871A+"!P<F]V:61E9"!B>2!#87!E4V-I96YC90H@("`@("H*("`@("`J($!V
M87(@("`@("!O8FIE8W0@("`@("`@("`@("`@("`@("`@("`@)%]W96%T:&5R
M4V]A<`H@("`@("H@0&%C8V5S<R`@('!R:79A=&4*("`@("`J+PH@("`@=F%R
M("1?=V5A=&AE<E-O87`["B`@("`O+R!]?7T*"B`@("`O+R![>WL@8V]N<W1R
M=6-T;W(*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@
M*B!297%U:7)E<R!33T%0('1O(&)E(&EN<W1A;&QE9`H@("`@("H*("`@("`J
M($!P87)A;2`@(&%R<F%Y("`@("`@("`@("`@("`@("`@("`@("`D;W!T:6]N
M<PH@("`@("H@0'!A<F%M("`@;6EX960@("`@("`@("`@("`@("`@("`@("`@
M("1E<G)O<@H@("`@("H@0'1H<F]W<R`@4$5!4E]%<G)O<@H@("`@("H@0'1H
M<F]W<R`@4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/4E]74D].
M1U]315)615)?1$%400H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("HO
M"B`@("!F=6YC=&EO;B!397)V:6-E<U]796%T:&5R7T=L;V)A;'=E871H97(H
M)&]P=&EO;G,L("8D97)R;W(I"B`@("!["B`@("`@("`@)'!E<G)O<B`](&YU
M;&P["B`@("`@("`@)'1H:7,M/E-E<G9I8V5S7U=E871H97)?0V]M;6]N*"1O
M<'1I;VYS+"`D<&5R<F]R*3L*("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE
M<CHZ:7-%<G)O<B@D<&5R<F]R*2D@>PH@("`@("`@("`@("`D97)R;W(@/2`D
M<&5R<F]R.PH@("`@("`@('T*("`@('T*("`@("\O('U]?0H*("`@("\O('M[
M>R!?8V]N;F5C=%-E<G9E<B@I"B`@("`O*BH*("`@("`J($-O;FYE8W1S('1O
M('1H92!33T%0('-E<G9E<B!A;F0@<F5T<FEE=F5S('1H92!74T1,(&1A=&$*
M("`@("`J"B`@("`@*B!`<F5T=7)N("!014%27T5R<F]R?&)O;VP*("`@("`J
M($!T:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?
M5U)/3D=?4T525D527T1!5$$*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V-O;FYE8W1397)V97(H*0H@("`@>PH@("`@
M("`@(&EN8VQU9&5?;VYC92`B4T]!4"]#;&EE;G0N<&AP(CL*("`@("`@("`D
M=&AI<RT^7W=S9&P@/2!N97<@4T]!4%]74T1,*")H='1P.B\O;&EV92YC87!E
M<V-I96YC92YC;VTO=W-D;"]';&]B86Q796%T:&5R+G=S9&PB+"`D=&AI<RT^
M7VAT='!/<'1I;VYS*3L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]W<V1L
M+3YF875L="D@)B8@4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D=&AI<RT^
M7W=S9&PM/F9A=6QT*2D@>PH@("`@("`@("`@("`D97)R;W(@/2!397)V:6-E
M<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?15)23U)?
M5U)/3D=?4T525D527T1!5$$L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@
M("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@(&5V86PH)'1H:7,M
M/E]W<V1L+3YG96YE<F%T94%L;%!R;WAI97,H*2D["B`@("`@("`@:68@*"%C
M;&%S<U]E>&ES=',H(E=E8E-E<G9I8V5?1VQO8F%L5V5A=&AE<E]3=&%T:6]N
M26YF;R(I('Q\("%C;&%S<U]E>&ES=',H(E=E8E-E<G9I8V5?1VQO8F%L5V5A
M=&AE<E]';&]B86Q796%T:&5R(BDI('L*("`@("`@("`@("`@)&5R<F]R(#T@
M4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$52
M7T524D]27U=23TY'7U-%4E9%4E]$051!+"!?7T9)3$5?7RP@7U],24Y%7U\I
M.PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`D=&AI
M<RT^7W-T871I;VY3;V%P(#T@)FYE=R!796)397)V:6-E7T=L;V)A;%=E871H
M97)?4W1A=&EO;DEN9F\["B`@("`@("`@)'1H:7,M/E]W96%T:&5R4V]A<"`]
M("9N97<@5V5B4V5R=FEC95]';&]B86Q796%T:&5R7T=L;V)A;%=E871H97([
M"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H@("`@+R\@?7U]"@H@("`@
M+R\@>WM[(%]C:&5C:TQO8V%T:6]N240H*0H@("`@+RHJ"B`@("`@*B!#:&5C
M:W,@=&AE(&ED(&9O<B!V86QI9"!V86QU97,@86YD('1H=7,@<')E=F5N=',@
M<VEL;'D@<F5Q=65S=',@=&\*("`@("`J($=L;V)A;%=E871H97(@<V5R=F5R
M"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@
M("`@("`@("1I9`H@("`@("H@0')E='5R;B`@4$5!4E]%<G)O<GQB;V]L"B`@
M("`@*B!`=&AR;W=S("!014%27T5R<F]R.CI315)624-%4U]714%42$527T52
M4D]27TY/7TQ/0T%424]."B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R.CI3
M15)624-%4U]714%42$527T524D]27TE.5D%,241?3$]#051)3TX*("`@("`J
M($!A8V-E<W,@('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V-H96-K
M3&]C871I;VY)1"@D:60I"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1I
M9"D@?'P@:7-?;V)J96-T*"1I9"D@?'P@(7-T<FQE;B@D:60I*2!["B`@("`@
M("`@("`@(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%
M4E9)0T537U=%051(15)?15)23U)?3D]?3$]#051)3TXL(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["B`@("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?<W1A=&EO;E-O
M87`M/FES5F%L:61#;V1E*"1I9"D@/3T](&9A;'-E*2!["B`@("`@("`@("`@
M(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T53
M7U=%051(15)?15)23U)?24Y604Q)1%],3T-!5$E/3BP@7U]&24Q%7U\L(%]?
M3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[('-E87)C:$QO8V%T:6]N*"D*("`@
M("\J*@H@("`@("H@4V5A<F-H97,@241S(&9O<B!G:79E;B!L;V-A=&EO;BP@
M<F5T=7)N<R!A<G)A>2!O9B!P;W-S:6)L92!L;V-A=&EO;G,*("`@("`J(&]R
M('-I;F=L92!)1`H@("`@("H*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@
M("`@("`@("`@("`@("`@("`D;&]C871I;VX*("`@("`J($!P87)A;2`@(&)O
M;VP@("`@("`@("`@("`@("`@("`@("`@("`D=7-E1FER<W0@("`@("`@268@
M<V5T+"!F:7)S="!)1"!O9B!R97-U;'0M87)R87D@:7,@<F5T=7)N960*("`@
M("`J($!R971U<FX@(%!%05)?17)R;W)\87)R87E\<W1R:6YG"B`@("`@*B!`
M=&AR;W=S("!014%27T5R<F]R.CI315)624-%4U]714%42$527T524D]27U=2
M3TY'7U-%4E9%4E]$051!"B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R.CI3
M15)624-%4U]714%42$527T524D]27U5.2TY/5TY?3$]#051)3TX*("`@("`J
M($!A8V-E<W,@('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!S96%R8VA,
M;V-A=&EO;B@D;&]C871I;VXL("1U<V5&:7)S="`](&9A;'-E*0H@("`@>PH@
M("`@("`@("\O($-H96-K+"!I9B!T:&4@<W1A=&EO;E-O87`M3V)J96-T(&ES
M('!R97-E;G0N($EF(&YO="P@8V]N;F5C="!T;R!T:&4@4V5R=F5R(&%N9"!R
M971R:65V92!T:&4@5T133"!D871A"B`@("`@("`@:68@*"$D=&AI<RT^7W-T
M871I;VY3;V%P*2!["B`@("`@("`@("`@("1S=&%T=7,@/2`D=&AI<RT^7V-O
M;FYE8W1397)V97(H*3L*("`@("`@("`@("`@:68@*%-E<G9I8V5S7U=E871H
M97(Z.FES17)R;W(H)'-T871U<RDI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D<W1A='5S.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O
M+R!'970@<V5A<F-H(&1A=&$@9G)O;2!S97)V97(@86YD('5N<V5R:6%L:7IE
M"B`@("`@("`@)'-E87)C:"`]("1T:&ES+3Y?<W1A=&EO;E-O87`M/G-E87)C
M:$)Y3F%M92@D;&]C871I;VXI.PH*("`@("`@("!I9B`H4V5R=FEC97-?5V5A
M=&AE<CHZ:7-%<G)O<B@D<V5A<F-H*2D@>PH@("`@("`@("`@("!R971U<FX@
M4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$52
M7T524D]27U=23TY'7U-%4E9%4E]$051!+"!?7T9)3$5?7RP@7U],24Y%7U\I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@A:7-?87)R87DH
M)'-E87)C:"D@?'P@(7-I>F5O9B@D<V5A<F-H*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#
M15-?5T5!5$A%4E]%4E)/4E]53DM.3U=.7TQ/0T%424].+"!?7T9)3$5?7RP@
M7U],24Y%7U\I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@:68@*"$D=7-E1FER<W0@)B8@*'-I>F5O9B@D<V5A<F-H*2`^(#$I*2![
M"B`@("`@("`@("`@("`@("`@("`@)'-E87)C:%)E='5R;B`](&%R<F%Y*"D[
M"B`@("`@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F
M*"1S96%R8V@I.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1S
M96%R8VA2971U<FY;)'-E87)C:%LD:5TM/FEC86]=(#T@)'-E87)C:%LD:5TM
M/FYA;64N(BP@(BXD<V5A<F-H6R1I72T^8V]U;G1R>3L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)'5S949I<G-T
M('Q\("AS:7IE;V8H)'-E87)C:"D@/3T@,2DI('L*("`@("`@("`@("`@("`@
M("`@("`D<V5A<F-H4F5T=7)N(#T@)'-E87)C:%LP72T^:6-A;SL*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1S96%R8VA2971U<FX["B`@("!]"B`@("`O+R!]?7T*"B`@("`O
M+R![>WL@<V5A<F-H3&]C871I;VY">4-O=6YT<GDH*0H@("`@+RHJ"B`@("`@
M*B!2971U<FYS($E$<R!W:71H(&QO8V%T:6]N+6YA;64@9F]R(&$@9VEV96X@
M8V]U;G1R>2!O<B!A;&P@879A:6QA8FQE"B`@("`@*B!C;W5N=')I97,L(&EF
M(&YO('9A;'5E('=A<R!G:79E;@H@("`@("H*("`@("`J($!P87)A;2`@('-T
M<FEN9R`@("`@("`@("`@("`@("`@("`@("`D8V]U;G1R>0H@("`@("H@0')E
M='5R;B`@4$5!4E]%<G)O<GQA<G)A>0H@("`@("H@0'1H<F]W<R`@4$5!4E]%
M<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/4E]74D].1U]315)615)?1$%4
M00H@("`@("H@0'1H<F]W<R`@4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%
M4E]%4E)/4E]53DM.3U=.7TQ/0T%424]."B`@("`@*B!`86-C97-S("!P=6)L
M:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<V5A<F-H3&]C871I;VY">4-O=6YT
M<GDH)&-O=6YT<GD@/2`B(BD*("`@('L*("`@("`@("`O+R!2971U<FX@=&AE
M(&%V86EL86)L92!C;W5N=')I97,@87,@;F\@8V]U;G1R>2!W87,@9VEV96X*
M("`@("`@("!I9B`H(7-T<FQE;B@D8V]U;G1R>2DI('L*("`@("`@("`@("`@
M)&-O=6YT<FEE<R`]("1T:&ES+3Y?<W1A=&EO;E-O87`M/FQI<W1#;W5N=')I
M97,H*3L*("`@("`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R
M;W(H)&-O=6YT<FEE<RDI('L*("`@("`@("`@("`@("`@(')E='5R;B!397)V
M:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?15)2
M3U)?5U)/3D=?4T525D527T1!5$$L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1C;W5N=')I97,["B`@
M("`@("`@?0H*("`@("`@("`O+R!#:&5C:RP@:68@=&AE('-T871I;VY3;V%P
M+4]B:F5C="!I<R!P<F5S96YT+B!)9B!N;W0L(&-O;FYE8W0@=&\@=&AE(%-E
M<G9E<B!A;F0@<F5T<FEE=F4@=&AE(%=$4TP@9&%T80H@("`@("`@(&EF("@A
M)'1H:7,M/E]S=&%T:6]N4V]A<"D@>PH@("`@("`@("`@("`D<W1A='5S(#T@
M)'1H:7,M/E]C;VYN96-T4V5R=F5R*"D["B`@("`@("`@("`@(&EF("A397)V
M:6-E<U]796%T:&5R.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)'-T871U<SL*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@+R\@3F]W(&9O<B!T:&4@<F5A;"!S96%R8V@*("`@("`@("`D
M8V]U;G1R>4QO8W,@/2`D=&AI<RT^7W-T871I;VY3;V%P+3YS96%R8VA">4-O
M=6YT<GDH)&-O=6YT<GDI.PH@("`@("`@("\O($-H96-K(')E<W5L="!F;W(@
M=F%L:61I='D*("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O
M<B@D8V]U;G1R>4QO8W,I*2!["B`@("`@("`@("`@(')E='5R;B!397)V:6-E
M<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?15)23U)?
M5U)/3D=?4T525D527T1!5$$L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@
M("`@?2!E;'-E:68@*"%I<U]A<G)A>2@D8V]U;G1R>4QO8W,I*2!["B`@("`@
M("`@("`@(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%
M4E9)0T537U=%051(15)?15)23U)?54Y+3D]73E],3T-!5$E/3BP@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("\O($-O;G-T<G5C
M="!T:&4@<F5S=6QT"B`@("`@("`@)&QO8V%T:6]N<R`](&%R<F%Y*"D["B`@
M("`@("`@9F]R96%C:"`H)&-O=6YT<GE,;V-S(&%S("1L;V-A=&EO;BD@>PH@
M("`@("`@("`@("`D;&]C871I;VYS6R1L;V-A=&EO;BT^:6-A;UT@/2`D;&]C
M871I;VXM/FYA;64N(BP@(BXD;&]C871I;VXM/F-O=6YT<GD["B`@("`@("`@
M?0H@("`@("`@(&%S;W)T*"1L;V-A=&EO;G,I.PH*("`@("`@("!R971U<FX@
M)&QO8V%T:6]N<SL*("`@('T*("`@("\O('U]?0H*("`@("\O('M[>R!G971,
M;V-A=&EO;B@I"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&1A=&$@9F]R
M('1H92!L;V-A=&EO;B!B96QO;F=I;F<@=&\@=&AE($E$"B`@("`@*@H@("`@
M("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1I9`H@
M("`@("H@0')E='5R;B`@4$5!4E]%<G)O<GQA<G)A>0H@("`@("H@0'1H<F]W
M<R`@4$5!4E]%<G)O<@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=$QO8V%T:6]N*"1I9"`]("(B*0H@("`@>PH@("`@
M("`@("1S=&%T=7,@/2`D=&AI<RT^7V-H96-K3&]C871I;VY)1"@D:60I.PH*
M("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'-T871U<SL*("`@("`@("!]"@H@
M("`@("`@("1L;V-A=&EO;E)E='5R;B`](&%R<F%Y*"D["@H@("`@("`@(&EF
M("@D=&AI<RT^7V-A8VAE16YA8FQE9"`F)B`H)&QO8V%T:6]N(#T@)'1H:7,M
M/E]C86-H92T^9V5T*")'5RTB+B1I9"P@(FQO8V%T:6]N(BDI*2!["B`@("`@
M("`@("`@("\O($=E="!D871A(&9R;VT@8V%C:&4*("`@("`@("`@("`@)'1H
M:7,M/E]L;V-A=&EO;B`]("1L;V-A=&EO;CL*("`@("`@("`@("`@)&QO8V%T
M:6]N4F5T=7)N6R)C86-H92)=(#T@(DA)5"(["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@+R\@0VAE8VLL(&EF('1H92!S=&%T:6]N4V]A<"U/8FIE
M8W0@:7,@<')E<V5N="X@268@;F]T+"!C;VYN96-T('1O('1H92!397)V97(@
M86YD(')E=')I979E('1H92!71%-,(&1A=&$*("`@("`@("`@("`@:68@*"$D
M=&AI<RT^7W-T871I;VY3;V%P*2!["B`@("`@("`@("`@("`@("`D<W1A='5S
M(#T@)'1H:7,M/E]C;VYN96-T4V5R=F5R*"D["B`@("`@("`@("`@("`@("!I
M9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D<W1A='5S.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`D;&]C871I;VX@/2`D
M=&AI<RT^7W-T871I;VY3;V%P+3YG9713=&%T:6]N*"1I9"D["@H@("`@("`@
M("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D;&]C871I;VXI
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&QO8V%T:6]N.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^7VQO8V%T:6]N(#T@)&QO8V%T
M:6]N.PH*("`@("`@("`@("`@:68@*"1T:&ES+3Y?8V%C:&5%;F%B;&5D*2![
M"B`@("`@("`@("`@("`@("`O+R`N+BYA;F0@8V%C:&4@:70*("`@("`@("`@
M("`@("`@("1E>'!I<F4@/2!C;VYS=&%N="@B4T525DE#15-?5T5!5$A%4E]%
M6%!)4D537TQ/0T%424].(BD["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-A
M8VAE+3YE>'13879E*")'5RTB+B1I9"P@)'1H:7,M/E]L;V-A=&EO;BP@(B(L
M("1E>'!I<F4L(")L;V-A=&EO;B(I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1L;V-A=&EO;E)E='5R;ELB8V%C:&4B72`](")-25-3(CL*("`@("`@
M("!]"B`@("`@("`@:68@*'-T<FQE;B@D=&AI<RT^7VQO8V%T:6]N+3YR96=I
M;VXI("8F('-T<FQE;B@D=&AI<RT^7VQO8V%T:6]N+3YC;W5N=')Y*2D@>PH@
M("`@("`@("`@("`D;&]C;F%M92`]("1T:&ES+3Y?;&]C871I;VXM/FYA;64N
M(BP@(BXD=&AI<RT^7VQO8V%T:6]N+3YR96=I;VXN(BP@(BXD=&AI<RT^7VQO
M8V%T:6]N+3YC;W5N=')Y.PH@("`@("`@('T@96QS96EF("AS=')L96XH)'1H
M:7,M/E]L;V-A=&EO;BT^8V]U;G1R>2DI('L*("`@("`@("`@("`@)&QO8VYA
M;64@/2`D=&AI<RT^7VQO8V%T:6]N+3YN86UE+B(L("(N)'1H:7,M/E]L;V-A
M=&EO;BT^8V]U;G1R>3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M;&]C;F%M92`]("1T:&ES+3Y?;&]C871I;VXM/FYA;64["B`@("`@("`@?0H@
M("`@("`@("1L;V-A=&EO;E)E='5R;ELB;F%M92)=("`@("`@/2`D;&]C;F%M
M93L*("`@("`@("`D;&]C871I;VY2971U<FY;(FQA=&ET=61E(ET@(#T@)'1H
M:7,M/E]L;V-A=&EO;BT^;&%T:71U9&4["B`@("`@("`@)&QO8V%T:6]N4F5T
M=7)N6R)L;VYG:71U9&4B72`]("1T:&ES+3Y?;&]C871I;VXM/FQO;F=I='5D
M93L*("`@("`@("`D;&]C871I;VY2971U<FY;(G-U;G)I<V4B72`@(#T@9&%T
M92@D=&AI<RT^7W1I;65&;W)M870L("1T:&ES+3YC86QC=6QA=&53=6Y2:7-E
M4V5T*&=M;6MT:6UE*"DL(%-53D953D-37U)%5%]424U%4U1!35`L("1T:&ES
M+3Y?;&]C871I;VXM/FQA=&ET=61E+"`D=&AI<RT^7VQO8V%T:6]N+3YL;VYG
M:71U9&4L(%-%4E9)0T537U=%051(15)?4U5.1E5.0U-?4U5.4DE315]:14Y)
M5$@L(#`L('1R=64I*3L*("`@("`@("`D;&]C871I;VY2971U<FY;(G-U;G-E
M=")=("`@(#T@9&%T92@D=&AI<RT^7W1I;65&;W)M870L("1T:&ES+3YC86QC
M=6QA=&53=6Y2:7-E4V5T*&=M;6MT:6UE*"DL(%-53D953D-37U)%5%]424U%
M4U1!35`L("1T:&ES+3Y?;&]C871I;VXM/FQA=&ET=61E+"`D=&AI<RT^7VQO
M8V%T:6]N+3YL;VYG:71U9&4L(%-%4E9)0T537U=%051(15)?4U5.1E5.0U-?
M4U5.4T547UI%3DE42"P@(#`L(&9A;'-E*2D["B`@("`@("`@)&QO8V%T:6]N
M4F5T=7)N6R)E;&5V871I;VXB72`]("1T:&ES+3Y?;&]C871I;VXM/F5L979A
M=&EO;CL*"B`@("`@("`@<F5T=7)N("1L;V-A=&EO;E)E='5R;CL*("`@('T*
M("`@("\O('U]?0H*("`@("\O('M[>R!G971796%T:&5R*"D*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@=V5A=&AE<BUD871A(&9O<B!T:&4@<W5P<&QI
M960@;&]C871I;VX*("`@("`J"B`@("`@*B!`<&%R86T@("!S=')I;F<@("`@
M("`@("`@("`@("`@("`@("`@)&ED"B`@("`@*B!`<&%R86T@("!S=')I;F<@
M("`@("`@("`@("`@("`@("`@("`@)'5N:71S1F]R;6%T"B`@("`@*B!`<F5T
M=7)N("!014%27T5R<F]R?&%R<F%Y"B`@("`@*B!`=&AR;W=S("!014%27T5R
M<F]R"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T5V5A=&AE<B@D:60@/2`B(BP@)'5N:71S1F]R;6%T(#T@(B(I"B`@
M("!["B`@("`@("`@<W1A=&EC("1C;&]U9',["B`@("`@("`@:68@*"%I<W-E
M="@D8VQO=61S*2D@>PH@("`@("`@("`@("`D8VQO=61S("`@(#T@87)R87DH
M"B`@("`@("`@("`@("`@("`B<VMY(&-L96%R(BP*("`@("`@("`@("`@("`@
M(")F97<B+`H@("`@("`@("`@("`@("`@(G-C871T97)E9"(L"B`@("`@("`@
M("`@("`@("`B8G)O:V5N(BP*("`@("`@("`@("`@("`@(")O=F5R8V%S="(L
M"B`@("`@("`@("`@("D["B`@("`@("`@?0H*("`@("`@("`D<W1A='5S(#T@
M)'1H:7,M/E]C:&5C:TQO8V%T:6]N240H)&ED*3L*"B`@("`@("`@:68@*%-E
M<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'-T871U<RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1S=&%T=7,["B`@("`@("`@?0H*("`@("`@("`O+R!'970@
M;W1H97(@9&%T80H@("`@("`@("1U;FET<R`@("`]("1T:&ES+3YG9715;FET
M<T9O<FUA="@D=6YI='-&;W)M870I.PH*("`@("`@("`D=V5A=&AE<E)E='5R
M;B`](&%R<F%Y*"D["B`@("`@("`@:68@*"1T:&ES+3Y?8V%C:&5%;F%B;&5D
M("8F("@D=V5A=&AE<B`]("1T:&ES+3Y?8V%C:&4M/F=E="@B1U<M(BXD:60L
M(")W96%T:&5R(BDI*2!["B`@("`@("`@("`@("\O(%-A;64@<')O8V5D=7)E
M+BXN"B`@("`@("`@("`@("1T:&ES+3Y?=V5A=&AE<B`]("1W96%T:&5R.PH@
M("`@("`@("`@("`D=V5A=&AE<E)E='5R;ELB8V%C:&4B72`](")(250B.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O($-H96-K+"!I9B!T:&4@
M=V5A=&AE<E-O87`M3V)J96-T(&ES('!R97-E;G0N($EF(&YO="P@8V]N;F5C
M="!T;R!T:&4@4V5R=F5R(&%N9"!R971R:65V92!T:&4@5T133"!D871A"B`@
M("`@("`@("`@(&EF("@A)'1H:7,M/E]W96%T:&5R4V]A<"D@>PH@("`@("`@
M("`@("`@("`@)'-T871U<R`]("1T:&ES+3Y?8V]N;F5C=%-E<G9E<B@I.PH@
M("`@("`@("`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H
M)'-T871U<RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'-T871U
M<SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@+R\@+BXN87,@;&%S="!F=6YC=&EO;@H@("`@("`@("`@("`D=V5A=&AE
M<B`]("1T:&ES+3Y?=V5A=&AE<E-O87`M/F=E=%=E871H97)297!O<G0H)&ED
M*3L*"B`@("`@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R
M*"1W96%T:&5R*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1W96%T:&5R
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^7W=E871H97(@
M/2`D=V5A=&AE<CL*"B`@("`@("`@("`@(&EF("@D=&AI<RT^7V-A8VAE16YA
M8FQE9"D@>PH@("`@("`@("`@("`@("`@+R\@+BXN86YD(&-A8VAE(&ET"B`@
M("`@("`@("`@("`@("`D97AP:7)E(#T@8V]N<W1A;G0H(E-%4E9)0T537U=%
M051(15)?15A025)%4U]714%42$52(BD["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7V-A8VAE+3YE>'13879E*")'5RTB+B1I9"P@)'1H:7,M/E]W96%T:&5R
M+"`B(BP@)&5X<&ER92P@(G=E871H97(B*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D=V5A=&AE<E)E='5R;ELB8V%C:&4B72`](")-25-3(CL*("`@
M("`@("!]"@H@("`@("`@("1U<&1A=&4@/2!T<FEM*'-T<E]R97!L86-E*&%R
M<F%Y*")4(BP@(EHB*2P@(B`B+"`D=&AI<RT^7W=E871H97(M/G1I;65S=&%M
M<"DI+B(@1TU4(CL*"B`@("`@("`@)'=E871H97)2971U<FY;(G5P9&%T92)=
M("`@("`@("`@("`@/2!G;61A=&4H=')I;2@D=&AI<RT^7V1A=&5&;W)M870N
M(B`B+B1T:&ES+3Y?=&EM949O<FUA="DL('-T<G1O=&EM92@D=7!D871E*2D[
M"B`@("`@("`@)'=E871H97)2971U<FY;(G5P9&%T95)A=R)=("`@("`@("`@
M/2`D=&AI<RT^7W=E871H97(M/G1I;65S=&%M<#L*("`@("`@("!I9B`H<W1R
M;&5N*"1T:&ES+3Y?=V5A=&AE<BT^<W1A=&EO;BT^<F5G:6]N*2`F)B!S=')L
M96XH)'1H:7,M/E]W96%T:&5R+3YS=&%T:6]N+3YC;W5N=')Y*2D@>PH@("`@
M("`@("`@("`D;&]C;F%M92`]("1T:&ES+3Y?=V5A=&AE<BT^<W1A=&EO;BT^
M;F%M92XB+"`B+B1T:&ES+3Y?=V5A=&AE<BT^<W1A=&EO;BT^<F5G:6]N+B(L
M("(N)'1H:7,M/E]W96%T:&5R+3YS=&%T:6]N+3YC;W5N=')Y.PH@("`@("`@
M('T@96QS96EF("AS=')L96XH)'1H:7,M/E]W96%T:&5R+3YS=&%T:6]N+3YC
M;W5N=')Y*2D@>PH@("`@("`@("`@("`D;&]C;F%M92`]("1T:&ES+3Y?=V5A
M=&AE<BT^<W1A=&EO;BT^;F%M92XB+"`B+B1T:&ES+3Y?=V5A=&AE<BT^<W1A
M=&EO;BT^8V]U;G1R>3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M;&]C;F%M92`]("1T:&ES+3Y?=V5A=&AE<BT^<W1A=&EO;BT^;F%M93L*("`@
M("`@("!]"B`@("`@("`@)'=E871H97)2971U<FY;(G-T871I;VXB72`@("`@
M("`@("`@/2`D;&]C;F%M93L*("`@("`@("`D=V5A=&AE<E)E='5R;ELB=VEN
M9")=("`@("`@("`@("`@("`]("1T:&ES+3YC;VYV97)T4W!E960H)'1H:7,M
M/E]W96%T:&5R+3YW:6YD+3YP<F5V86EL:6YG7W-P965D+"`B;7!S(BP@)'5N
M:71S6R)W:6YD(ETI.PH@("`@("`@("1W96%T:&5R4F5T=7)N6R)W:6YD1&5G
M<F5E<R)=("`@("`@(#T@)'1H:7,M/E]W96%T:&5R+3YW:6YD+3YP<F5V86EL
M:6YG7V1I<F5C=&EO;BT^9&5G<F5E<SL*("`@("`@("`D=V5A=&AE<E)E='5R
M;ELB=VEN9$1I<F5C=&EO;B)=("`@("`]("1T:&ES+3Y?=V5A=&AE<BT^=VEN
M9"T^<')E=F%I;&EN9U]D:7)E8W1I;VXM/F-O;7!A<W,["B`@("`@("`@:68@
M*"1T:&ES+3Y?=V5A=&AE<BT^=VEN9"T^<')E=F%I;&EN9U]S<&5E9"`A/2`D
M=&AI<RT^7W=E871H97(M/G=I;F0M/F=U<W1?<W!E960I('L*("`@("`@("`@
M("`@)'=E871H97)2971U<FY;(G=I;F1'=7-T(ET@("`@("`]("1T:&ES+3YC
M;VYV97)T4W!E960H)'1H:7,M/E]W96%T:&5R+3YW:6YD+3YG=7-T7W-P965D
M+"`B;7!S(BP@)'5N:71S6R)W:6YD(ETI.PH@("`@("`@('T*("`@("`@("!I
M9B`H)'1H:7,M/E]W96%T:&5R+3YW:6YD+3YV87)Y:6YG7V9R;VU?9&ER96-T
M:6]N("$]("(B("8F("1T:&ES+3Y?=V5A=&AE<BT^=VEN9"T^=F%R>6EN9U]T
M;U]D:7)E8W1I;VX@(3T@(B(I('L*("`@("`@("`@("`@)'=E871H97)2971U
M<FY;(G=I;F1687(B72`@("`@("`](&%R<F%Y("@*("`@("`@("`@("`@("`@
M(")F<F]M(B`]/B`D=&AI<RT^7W=E871H97(M/G=I;F0M/G9A<GEI;F=?9G)O
M;5]D:7)E8W1I;VXL"B`@("`@("`@("`@("`@("`B=&\B("`@/3X@)'1H:7,M
M/E]W96%T:&5R+3YW:6YD+3YV87)Y:6YG7W1O7V1I<F5C=&EO;@H@("`@("`@
M("`@("`I.PH@("`@("`@('T*"B`@("`@("`@)'=E871H97)2971U<FY;(G9I
M<VEB:6QI='DB72`@("`@("`@/2`D=&AI<RT^8V]N=F5R=$1I<W1A;F-E*"1T
M:&ES+3Y?=V5A=&AE<BT^=FES:6)I;&ET>2T^9&ES=&%N8V4@+R`Q,#`P+"`B
M:VTB+"`D=6YI='-;(G9I<R)=*3L*("`@("`@("`D=V5A=&AE<E)E='5R;ELB
M=FES475A;&EF:65R(ET@("`@("`]("1T:&ES+3Y?=V5A=&AE<BT^=FES:6)I
M;&ET>2T^<75A;&EF:65R.PH*("`@("`@("`D8V]N9&ET:6]N(#T@87)R87DH
M*3L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'1H:7,M/E]W
M96%T:&5R+3YP:&5N;VUE;F$I.R`D:2LK*2!["B`@("`@("`@("`@("1C;VYD
M:71I;VY;72`]("1T:&ES+3Y?=V5A=&AE<BT^<&AE;F]M96YA6R1I72T^<W1R
M:6YG.PH@("`@("`@('T*("`@("`@("`D=V5A=&AE<E)E='5R;ELB8V]N9&ET
M:6]N(ET@("`@("`@("`](&EM<&QO9&4H(BP@(BP@)&-O;F1I=&EO;BD["@H@
M("`@("`@(&EF("AI<U]A<G)A>2@D=&AI<RT^7W=E871H97(M/G-K>2T^;&%Y
M97)S*2D@>PH@("`@("`@("`@("`D;&%Y97)S(#T@87)R87DH*3L*("`@("`@
M("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F*"1T:&ES+3Y?=V5A=&AE
M<BT^<VMY+3YL87EE<G,I.R`D:2LK*2!["B`@("`@("`@("`@("`@("!I9B`H
M<W1R=&]U<'!E<B@D=&AI<RT^7W=E871H97(M/G-K>2T^;&%Y97)S6R1I72T^
M='EP92D@(3T@(D-,14%2(BD@>PH@("`@("`@("`@("`@("`@("`@("1L87EE
M<G-;)&E=("`@("`@("`@("`@(#T@87)R87DH*3L*("`@("`@("`@("`@("`@
M("`@("`D;&%Y97)S6R1I75LB86UO=6YT(ET@("`]("1C;&]U9'-;)'1H:7,M
M/E]W96%T:&5R+3YS:WDM/FQA>65R<ULD:5TM/F5X=&5N=%T["B`@("`@("`@
M("`@("`@("`@("`@)&QA>65R<ULD:5U;(FAE:6=H=")=("`@/2`D=&AI<RT^
M8V]N=F5R=$1I<W1A;F-E*"1T:&ES+3Y?=V5A=&AE<BT^<VMY+3YL87EE<G-;
M)&E=+3YA;'1I='5D92P@(FTB+"`D=6YI='-;(FAE:6=H=")=*3L*("`@("`@
M("`@("`@("`@("`@("!I9B`H<W1R=&]U<'!E<B@D=&AI<RT^7W=E871H97(M
M/G-K>2T^;&%Y97)S6R1I72T^='EP92D@(3T@(D-,3U5$(BD@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D;&%Y97)S6R1I75LB='EP92)=(#T@=6-W;W)D
M<RAS=')?<F5P;&%C92@B7R(L("(B+"`D=&AI<RT^7W=E871H97(M/G-K>2T^
M;&%Y97)S6R1I72T^='EP92DI.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M<VEZ96]F*"1L87EE<G,I*2!["B`@("`@("`@("`@("`@("`D=V5A=&AE<E)E
M='5R;ELB8VQO=61S(ET@("`@("`@(#T@)&QA>65R<SL*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@)'=E871H97)2971U<FY;(G1E;7!E<F%T
M=7)E(ET@("`@("`@/2`D=&AI<RT^8V]N=F5R=%1E;7!E<F%T=7)E*"1T:&ES
M+3Y?=V5A=&AE<BT^=&5M<&5R871U<F4M/F%M8FEE;G0L(")C(BP@)'5N:71S
M6R)T96UP(ETI.PH@("`@("`@("1F96QT5&5M<&5R871U<F4@/2`D=&AI<RT^
M8V%L8W5L871E5VEN9$-H:6QL*"1T:&ES+3YC;VYV97)T5&5M<&5R871U<F4H
M)'=E871H97)2971U<FY;(G1E;7!E<F%T=7)E(ETL("1U;FET<ULB=&5M<")=
M+"`B9B(I+"`D=&AI<RT^8V]N=F5R=%-P965D*"1W96%T:&5R4F5T=7)N6R)W
M:6YD(ETL("1U;FET<ULB=VEN9")=+"`B;7!H(BDI.PH@("`@("`@("1W96%T
M:&5R4F5T=7)N6R)F96QT5&5M<&5R871U<F4B72`@(#T@)'1H:7,M/F-O;G9E
M<G1496UP97)A='5R92@D9F5L=%1E;7!E<F%T=7)E+"`B9B(L("1U;FET<ULB
M=&5M<")=*3L*("`@("`@("`D=V5A=&AE<E)E='5R;ELB9&5W4&]I;G0B72`@
M("`@("`@("`]("1T:&ES+3YC;VYV97)T5&5M<&5R871U<F4H)'1H:7,M/E]W
M96%T:&5R+3YT96UP97)A='5R92T^9&5W<&]I;G0L(")C(BP@)'5N:71S6R)T
M96UP(ETI.PH@("`@("`@("1W96%T:&5R4F5T=7)N6R)H=6UI9&ET>2)=("`@
M("`@("`@(#T@)'1H:7,M/E]W96%T:&5R+3YT96UP97)A='5R92T^<F5L871I
M=F5?:'5M:61I='D["B`@("`@("`@)'=E871H97)2971U<FY;(G!R97-S=7)E
M(ET@("`@("`@("`@/2`D=&AI<RT^8V]N=F5R=%!R97-S=7)E*"1T:&ES+3Y?
M=V5A=&AE<BT^<')E<W-U<F4M/F%L=&EM971E<BP@(FAP82(L("1U;FET<ULB
M<')E<R)=*3L*"B`@("`@("`@<F5T=7)N("1W96%T:&5R4F5T=7)N.PH@("`@
M?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[(&=E=$9O<F5C87-T*"D*("`@("\J
M*@H@("`@("H@1VQO8F%L5V5A=&AE<B!H87,@;F\@9F]R96-A<W0@<&5R('-E
M+"!S;R!T:&ES(&9U;F-T:6]N(&ES(&IU<W0@9F]R"B`@("`@*B!C;VUP871I
M8FEL:71Y('!U<G!O<V5S+@H@("`@("H*("`@("`J($!P87)A;2`@('-T<FEN
M9R`@("`@("`@("`@("`@("`@("`@("`D:6YT"B`@("`@*B!`<&%R86T@("!I
M;G0@("`@("`@("`@("`@("`@("`@("`@("`@)&1A>7,*("`@("`J($!P87)A
M;2`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D=6YI='-&;W)M870*
M("`@("`J($!R971U<FX@(&)O;VP*("`@("`J($!A8V-E<W,@('!U8FQI8PH@
M("`@("H@0&1E<')E8V%T960*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1F]R
M96-A<W0H)&ED(#T@;G5L;"P@)&1A>7,@/2!N=6QL+"`D=6YI='-&;W)M870@
M/2!N=6QL*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*("`@
M("\O('U]?0I]"B\O('U]?0H_/@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O4V5R=FEC97,O5V5A=&AE<B]-971A<BYP:'``````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#(U,C`R-"`Q,#4Q-30S,S<R-R`P,C,T-#$`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RH@
M=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F
M='1A8G-T;W`]-"!F;VQD;65T:&]D/6UA<FME<CH@*B\*"B\J*@H@*B!014%2
M.CI397)V:6-E<U]796%T:&5R7TUE=&%R"B`J"B`J(%!(4"!V97)S:6]N<R`T
M(&%N9"`U"B`J"B`J(#Q,24-%3E-%/@H@*B!#;W!Y<FEG:'0@*&,I(#(P,#4L
M($%L97AA;F1E<B!7:7)T>@H@*B!!;&P@<FEG:'1S(')E<V5R=F5D+@H@*@H@
M*B!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y
M(&9O<FUS+"!W:71H(&]R('=I=&AO=70*("H@;6]D:69I8V%T:6]N+"!A<F4@
M<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO=VEN9R!C;VYD:71I
M;VYS"B`J(&%R92!M970Z"B`J(&\@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C
M92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0@;F]T:6-E
M+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W
M:6YG(&1I<V-L86EM97(N"B`J(&\@4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R
M>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0@;F]T
M:6-E+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L
M;&]W:6YG(&1I<V-L86EM97(@:6X@=&AE(&1O8W5M96YT871I;VX*("H@("!A
M;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE(&1I<W1R
M:6)U=&EO;BX*("H@;R!.96ET:&5R('1H92!N86UE(&]F('1H92!S;V9T=V%R
M92!N;W(@=&AE(&YA;65S(&]F(&ET<R!C;VYT<FEB=71O<G,*("H@("!M87D@
M8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O9'5C=',@9&5R:79E
M9"!F<F]M('1H:7,@<V]F='=A<F4*("H@("!W:71H;W5T('-P96-I9FEC('!R
M:6]R('=R:71T96X@<&5R;6ES<VEO;BX*("H*("H@5$A)4R!33T945T%212!)
M4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@04Y$($-/3E12
M24)55$]24R`B05,@25,B"B`J($%.1"!!3ED@15A04D534R!/4B!)35!,245$
M(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5"!,24U)5$5$(%1/+"!4
M2$4*("H@24U03$E%1"!705)204Y42453($]&($U%4D-(04Y404))3$E462!!
M3D0@1DE43D534R!&3U(@02!005)424-53$%2(%!54E!/4T4*("H@05)%($1)
M4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(12!#3U!94DE'2%0@3U=.
M15(@3U(@0T].5%))0E543U)3($)%"B`J($Q)04),12!&3U(@04Y9($1)4D5#
M5"P@24Y$25)%0U0L($E.0TE$14Y404PL(%-014-)04PL($5814U03$%262P@
M3U(*("H@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,541)3D<L($)55"!.
M3U0@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8*("H@4U5"4U1)5%5412!'
M3T]$4R!/4B!315)624-%4SL@3$]34R!/1B!54T4L($1!5$$L($]2(%!23T9)
M5%,[($]2($)54TE.15-3"B`J($E.5$524E505$E/3BD@2$]7159%4B!#0553
M140@04Y$($].($%.62!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52($E.
M"B`J($-/3E1204-4+"!35%))0U0@3$E!0DE,2519+"!/4B!43U)4("A)3D-,
M541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I"B`J($%225-)3D<@24X@
M04Y9(%=!62!/550@3T8@5$A%(%5312!/1B!42$E3(%-/1E1705)%+"!%5D5.
M($E&($%$5DE3140@3T8@5$A%"B`J(%!/4U-)0DE,2519($]&(%-50T@@1$%-
M04=%+@H@*B`\+TQ)0T5.4T4^"B`J"B`J($!C871E9V]R>2`@("!796(@4V5R
M=FEC97,*("H@0'!A8VMA9V4@("`@(%-E<G9I8V5S7U=E871H97(*("H@0&%U
M=&AO<B`@("`@($%L97AA;F1E<B!7:7)T>B`\86QE>$!P8S1P+FYE=#X*("H@
M0&-O<'ER:6=H="`@(#(P,#4@06QE>&%N9&5R(%=I<G1Z"B`J($!L:6-E;G-E
M("`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL
M:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@($-64SH@
M)$ED.B!-971A<BYP:'`L=B`Q+C@W(#(P,#8O,#,O,#@@,3(Z,SDZ,3@@97)U
M($5X<"`D"B`J($!L:6YK("`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A
M8VMA9V4O4V5R=FEC97-?5V5A=&AE<@H@*B!`;&EN:R`@("`@("`@:'1T<#HO
M+W=E871H97(N;F]A82YG;W8O=V5A=&AE<B]M971A<BYS:'1M;`H@*B!`;&EN
M:R`@("`@("`@:'1T<#HO+W=E871H97(N;F]A82YG;W8O=V5A=&AE<B]T868N
M<VAT;6P*("H@0&5X86UP;&4@("`@(&5X86UP;&5S+VUE=&%R+6)A<VEC+G!H
M<"`@("`@("`@("`@(&UE=&%R+6)A<VEC+G!H<`H@*B!`97AA;7!L92`@("`@
M97AA;7!L97,O;65T87(M97AT96YS:79E+G!H<"`@("`@("`@;65T87(M97AT
M96YS:79E+G!H<`H@*B!`9FEL97-O=7)C90H@*B\*"G)E<75I<F5?;VYC92`B
M4V5R=FEC97,O5V5A=&AE<B]#;VUM;VXN<&AP(CL*"G)E<75I<F5?;VYC92`B
M1$(N<&AP(CL*"B\O('M[>R!C;&%S<R!397)V:6-E<U]796%T:&5R7TUE=&%R
M"B\J*@H@*B!4:&ES(&-L87-S(&%C=',@87,@86X@:6YT97)F86-E('1O('1H
M92!-151!4B]4048@<V5R=FEC92!O9@H@*B!W96%T:&5R+FYO86$N9V]V+B!)
M="!S96%R8VAE<R!F;W(@;&]C871I;VYS(&=I=F5N(&EN($E#04\@;F]T871I
M;VX@86YD"B`J(')E=')I979E<R!T:&4@8W5R<F5N="!W96%T:&5R(&1A=&$N
M"B`J"B`J($]F(&-O=7)S92!T:&4@<&%R<VEN9R!O9B!T:&4@345405(M9&%T
M82!H87,@:71S(&QI;6ET871I;VYS+"!A<R!I=`H@*B!F;VQL;W=S('1H92!&
M961E<F%L($UE=&5O<F]L;V=I8V%L($AA;F1B;V]K($YO+C$@=VET:"!M;V1I
M9FEC871I;VYS('1O"B`J(&%C8V]M;V1A=&4@9F]R(&YO;BU54R!R97!O<G1S
M+"!S;R!I9B!T:&4@<F5P;W)T(&1E=FEA=&5S(&9R;VT@=&AE<V4*("H@<W1A
M;F1A<F1S+"!Y;W4@=V]N)W0@9V5T(&ET('!A<G-E9"!C;W)R96-T;'DN"B`J
M($%N>71H:6YG('1H870@:7,@;F]T('!A<G-E9"P@:7,@<V%V960@:6X@=&AE
M(")N;W!A<G-E(B!A<G)A>2UE;G1R>2P*("H@<F5T=7)N960@8GD@9V5T5V5A
M=&AE<B@I+"!S;R!Y;W4@8V%N(&1O('EO=7(@;W=N('!A<G-I;F<@869T97)W
M87)D<RX@5&AI<PH@*B!L:6UI=&%T:6]N(&ES('-P96-I9FEC86QL>2!G:79E
M;B!F;W(@<F5M87)K<RP@87,@=&AE(&-L87-S(&ES(&YO=`H@*B!P<F]C97-S
M:6YG(&5V97)Y=&AI;F<@;65N=&EO;F5D('1H97)E+"!B=70@>6]U('=I;&P@
M9V5T('1H92!M;W-T(&-O;6UO;@H@*B!F:65L9',@;&EK92!P<F5C:7!I=&%T
M:6]N(&%N9"!T96UP97)A='5R92UC:&%N9V5S+B!!9V%I;BP@979E<GET:&EN
M9R!N;W0*("H@<&%R<V5D+"!G;V5S(&EN=&\@(FYO<&%R<V4B+@H@*@H@*B!)
M9B!Y;W4@=&AI;FLL('-O;64@:6UP;W)T86YT(&9I96QD(&ES(&UI<W-I;F<@
M;W(@;F]T(&-O<G)E8W1L>2!P87)S960L"B`J('!L96%S92!F:6QE(&$@9F5A
M='5R92UR97%U97-T+V)U9W)E<&]R="!A="!H='1P.B\O<&5A<BYP:'`N;F5T
M+R!A;F0@8F4*("H@<W5R92!T;R!P<F]V:61E('1H92!-151!4B`H;W(@5$%&
M*2!R97!O<G0@=VET:"!A(%]D971A:6QE9%\@97AP;&%N871I;VXA"B`J"B`J
M($9O<B!W;W)K:6YG(&5X86UP;&5S+"!P;&5A<V4@=&%K92!A(&QO;VL@870*
M("H@("`@(&1O8W,O4V5R=FEC97-?5V5A=&AE<B]E>&%M<&QE<R]M971A<BUB
M87-I8RYP:'`*("H@("`@(&1O8W,O4V5R=FEC97-?5V5A=&AE<B]E>&%M<&QE
M<R]M971A<BUE>'1E;G-I=F4N<&AP"B`J"B`J"B`J($!C871E9V]R>2`@("!7
M96(@4V5R=FEC97,*("H@0'!A8VMA9V4@("`@(%-E<G9I8V5S7U=E871H97(*
M("H@0&%U=&AO<B`@("`@($%L97AA;F1E<B!7:7)T>B`\86QE>$!P8S1P+FYE
M=#X*("H@0&-O<'ER:6=H="`@(#(P,#4@06QE>&%N9&5R(%=I<G1Z"B`J($!L
M:6-E;G-E("`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S
M+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@
M(%)E;&5A<V4Z(#$N-"XP"B`J($!L:6YK("`@("`@("!H='1P.B\O<&5A<BYP
M:'`N;F5T+W!A8VMA9V4O4V5R=FEC97-?5V5A=&AE<@H@*B!`;&EN:R`@("`@
M("`@:'1T<#HO+W=E871H97(N;F]A82YG;W8O=V5A=&AE<B]M971A<BYS:'1M
M;`H@*B!`;&EN:R`@("`@("`@:'1T<#HO+W=E871H97(N;F]A82YG;W8O=V5A
M=&AE<B]T868N<VAT;6P*("H@0&5X86UP;&4@("`@(&5X86UP;&5S+VUE=&%R
M+6)A<VEC+G!H<"`@("`@("`@("`@(&UE=&%R+6)A<VEC+G!H<`H@*B!`97AA
M;7!L92`@("`@97AA;7!L97,O;65T87(M97AT96YS:79E+G!H<"`@("`@("`@
M;65T87(M97AT96YS:79E+G!H<`H@*B\*8VQA<W,@4V5R=FEC97-?5V5A=&AE
M<E]-971A<B!E>'1E;F1S(%-E<G9I8V5S7U=E871H97)?0V]M;6]N"GL*("`@
M("\O('M[>R!P<F]P97)T:65S"B`@("`O*BH*("`@("`J($EN9F]R;6%T:6]N
M('1O(&%C8V5S<R!T:&4@;&]C871I;VX@1$(*("`@("`J"B`@("`@*B!`=F%R
M("`@("!O8FIE8W0@($1"("`@("`@("`@("`@("`@("`@)%]D8@H@("`@("H@
M0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]D8CL*"B`@("`O
M*BH*("`@("`J(%1H92!S;W5R8V4@345405(@=7-E<PH@("`@("H*("`@("`J
M($!V87(@("`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D7W-O=7)C
M94UE=&%R"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B\*("`@('9A
M<B`D7W-O=7)C94UE=&%R.PH*("`@("\J*@H@("`@("H@5&AE('-O=7)C92!4
M048@=7-E<PH@("`@("H*("`@("`J($!V87(@("`@('-T<FEN9R`@("`@("`@
M("`@("`@("`@("`@("`D7W-O=7)C951A9@H@("`@("H@0&%C8V5S<R`@<')I
M=F%T90H@("`@("HO"B`@("!V87(@)%]S;W5R8V54868["@H@("`@+RHJ"B`@
M("`@*B!4:&ES('!A=&@@:7,@=7-E9"!T;R!F:6YD('1H92!-151!4B!D871A
M"B`@("`@*@H@("`@("H@0'9A<B`@("`@<W1R:6YG("`@("`@("`@("`@("`@
M("`@("`@("1?<V]U<F-E4&%T:$UE=&%R"B`@("`@*B!`86-C97-S("!P<FEV
M871E"B`@("`@*B\*("`@('9A<B`D7W-O=7)C95!A=&A-971A<CL*"B`@("`O
M*BH*("`@("`J(%1H:7,@<&%T:"!I<R!U<V5D('1O(&9I;F0@=&AE(%1!1B!D
M871A"B`@("`@*@H@("`@("H@0'9A<B`@("`@<W1R:6YG("`@("`@("`@("`@
M("`@("`@("`@("1?<V]U<F-E4&%T:%1A9@H@("`@("H@0&%C8V5S<R`@<')I
M=F%T90H@("`@("HO"B`@("!V87(@)%]S;W5R8V50871H5&%F.PH@("`@+R\@
M?7U]"@H@("`@+R\@>WM[(&-O;G-T<G5C=&]R"B`@("`O*BH*("`@("`J($-O
M;G-T<G5C=&]R"B`@("`@*@H@("`@("H@0'!A<F%M("`@87)R87D@("`@("`@
M("`@("`@("`@("`@("`@("1O<'1I;VYS"B`@("`@*B!`<&%R86T@("!M:7AE
M9"`@("`@("`@("`@("`@("`@("`@("`@)&5R<F]R"B`@("`@*B!`=&AR;W=S
M("!014%27T5R<F]R"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%-E<G9I8V5S7U=E871H97)?365T87(H)&]P=&EO;G,L
M("8D97)R;W(I"B`@("!["B`@("`@("`@)'!E<G)O<B`](&YU;&P["B`@("`@
M("`@)'1H:7,M/E-E<G9I8V5S7U=E871H97)?0V]M;6]N*"1O<'1I;VYS+"`D
M<&5R<F]R*3L*("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O
M<B@D<&5R<F]R*2D@>PH@("`@("`@("`@("`D97)R;W(@/2`D<&5R<F]R.PH@
M("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`O+R!3970@
M;W!T:6]N<R!A8V-O<F1I;F=L>0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N
M<ULB9'-N(ETI*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULB
M9&)/<'1I;VYS(ETI*2!["B`@("`@("`@("`@("`@("`D<W1A='5S(#T@)'1H
M:7,M/G-E=$UE=&%R1$(H)&]P=&EO;G-;(F1S;B)=+"`D;W!T:6]N<ULB9&)/
M<'1I;VYS(ETI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)'-T871U<R`]("1T:&ES+3YS971-971A<D1"*"1O<'1I;VYS6R)D<VXB
M72D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*%-E<G9I
M8V5S7U=E871H97(Z.FES17)R;W(H)'-T871U<RDI('L*("`@("`@("`@("`@
M)&5R<F]R(#T@)'-T871U<SL*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@
M('T*"B`@("`@("`@+R\@4V5T=&EN9R!T:&4@9&%T82!S;W5R8V5S(&9O<B!-
M151!4B!A;F0@5$%&("T@:&%V92!T;R!W871C:"!O=70@9F]R(&]L9&5R($%0
M22!U<V%G90H@("`@("`@(&EF("@H)'-O=7)C92`](&ES<V5T*"1O<'1I;VYS
M6R)S;W5R8V4B72DI('Q\(&ES<V5T*"1O<'1I;VYS6R)S;W5R8V5-971A<B)=
M*2D@>PH@("`@("`@("`@("`D<V]U<F-E365T87(@/2`D<V]U<F-E(#\@)&]P
M=&EO;G-;(G-O=7)C92)=(#H@)&]P=&EO;G-;(G-O=7)C94UE=&%R(ET["B`@
M("`@("`@("`@(&EF("@H)'-O=7)C95!A=&@@/2!I<W-E="@D;W!T:6]N<ULB
M<V]U<F-E4&%T:")=*2D@?'P@:7-S970H)&]P=&EO;G-;(G-O=7)C95!A=&A-
M971A<B)=*2D@>PH@("`@("`@("`@("`@("`@)'-O=7)C95!A=&A-971A<B`]
M("1S;W5R8V50871H(#\@)&]P=&EO;G-;(G-O=7)C95!A=&@B72`Z("1O<'1I
M;VYS6R)S;W5R8V50871H365T87(B73L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1S;W5R8V50871H365T87(@/2`B(CL*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1S;W5R8V5-
M971A<B`](")H='1P(CL*("`@("`@("`@("`@)'-O=7)C95!A=&A-971A<B`]
M("(B.PH@("`@("`@('T*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;(G-O
M=7)C951A9B)=*2D@>PH@("`@("`@("`@("`D<V]U<F-E5&%F(#T@)&]P=&EO
M;G-;(G-O=7)C951A9B)=.PH@("`@("`@("`@("!I9B`H:7-S970H)&]P=&EO
M;ELB<V]U<F-E4&%T:%1A9B)=*2D@>PH@("`@("`@("`@("`@("`@)'-O=7)C
M95!A=&A4868@/2`D;W!T:6]N<ULB<V]U<F-E4&%T:%1A9B)=.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'-O=6-E4&%T:%1A9B`]
M("(B.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'-O=7)C951A9B`](")H='1P(CL*("`@("`@("`@("`@)'-O=7)C95!A
M=&A4868@/2`B(CL*("`@("`@("!]"B`@("`@("`@)'-T871U<R`]("1T:&ES
M+3YS971-971A<E-O=7)C92@D<V]U<F-E365T87(L("1S;W5R8V50871H365T
M87(L("1S;W5R8V54868L("1S;W5R8V50871H5&%F*3L*("`@("`@("!I9B`H
M4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@("`@
M("`@("`D97)R;W(@/2`D<W1A='5S.PH@("`@("`@("`@("!R971U<FX["B`@
M("`@("`@?0H@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[('-E=$UE=&%R
M1$(H*0H@("`@+RHJ"B`@("`@*B!3971S('1H92!P87)A;65T97)S(&YE961E
M9"!F;W(@8V]N;F5C=&EN9R!T;R!T:&4@1$(L('=H97)E('1H90H@("`@("H@
M;&]C871I;VXM<V5A<F-H(&ES(&9E=&-H:6YG(&ET<R!D871A(&9R;VTN(%EO
M=2!N965D('1O(&)U:6QD(&$@1$(*("`@("`J('=I=&@@=&AE(&5X=&5R;F%L
M('1O;VP@8G5I;&1-971A<D1"(&9I<G-T+"!I="!F971C:&5S('1H92!L;V-A
M=&EO;G,*("`@("`J(&%N9"!A:7)P;W)T<R!F<F]M(&$@3D]!02UW96)S:71E
M+@H@("`@("H*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@("`@
M("`@("`@("`D9'-N"B`@("`@*B!`<&%R86T@("!A<G)A>2`@("`@("`@("`@
M("`@("`@("`@("`@)&1B3W!T:6]N<PH@("`@("H@0')E='5R;B`@1$)?17)R
M;W)\8F]O;`H@("`@("H@0'1H<F]W<R`@1$)?17)R;W(*("`@("`J($!S964@
M("`@($1".CIP87)S94133@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E=$UE=&%R1$(H)&1S;BP@)&1B3W!T:6]N<R`]
M(&%R<F%Y*"DI"B`@("!["B`@("`@("`@)&1S;FEN9F\@/2!$0CHZ<&%R<V5$
M4TXH)&1S;BD["B`@("`@("`@:68@*&ES7V%R<F%Y*"1D<VYI;F9O*2`F)B`A
M:7-S970H)&1S;FEN9F];(FUO9&4B72DI('L*("`@("`@("`@("`@)&1S;FEN
M9F];(FUO9&4B73T@,#8T-#L*("`@("`@("!]"@H@("`@("`@("\O($EN:71I
M86QI>F4@8V]N;F5C=&EO;B!T;R!$0B!A;F0@<W1O<F4@:6X@;V)J96-T(&EF
M('-U8V-E<W-F=6P*("`@("`@("`D9&(@/2`@1$(Z.F-O;FYE8W0H)&1S;FEN
M9F\L("1D8D]P=&EO;G,I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D9&(I
M*2!["B`@("`@("`@("`@(')E='5R;B`D9&(["B`@("`@("`@?0H@("`@("`@
M("1T:&ES+3Y?9&(@/2`D9&(["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[('-E=$UE=&%R4V]U<F-E*"D*("`@
M("\J*@H@("`@("H@4V5T<R!T:&4@<V]U<F-E+"!W:&5R92!T:&4@8VQA<W,@
M=')I97,@=&\@;&]C871E('1H92!-151!4B]4048@9&%T80H@("`@("H*("`@
M("`J(%-O=7)C92!C86X@8F4@:'1T<"P@9G1P(&]R(&9I;&4N"B`@("`@*B!!
M;'1E<FYA=&4@<V]U<F-E<&%T:',@8V%N(&)E('!R;W9I9&5D+@H@("`@("H*
M("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D
M<V]U<F-E365T87(*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@
M("`@("`@("`@("`D<V]U<F-E4&%T:$UE=&%R"B`@("`@*B!`<&%R86T@("!S
M=')I;F<@("`@("`@("`@("`@("`@("`@("`@)'-O=7)C951A9@H@("`@("H@
M0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1S;W5R8V50
M871H5&%F"B`@("`@*B!`<F5T=7)N("!014%27T524D]2?&)O;VP*("`@("`J
M($!T:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?
M345405)?4T]54D-%7TE.5D%,240*("`@("`J($!A8V-E<W,@('!U8FQI8PH@
M("`@("HO"B`@("!F=6YC=&EO;B!S971-971A<E-O=7)C92@D<V]U<F-E365T
M87(L("1S;W5R8V50871H365T87(@/2`B(BP@)'-O=7)C951A9B`]("(B+"`D
M<V]U<F-E4&%T:%1A9B`]("(B*0H@("`@>PH@("`@("`@(&EF("AI;E]A<G)A
M>2@D<V]U<F-E365T87(L(&%R<F%Y*")H='1P(BP@(F9T<"(L(")F:6QE(BDI
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V]U<F-E365T87(@/2`D<V]U<F-E
M365T87(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(%-E
M<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%
M4E)/4E]-151!4E]33U520T5?24Y604Q)1"P@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("!]"@H@("`@("`@("\O($-H96-K(&9O<B!A('!R;W!E<B!-
M151!4B!S;W5R8V4@:68@<&%R86UE=&5R(&ES('-E="P@:68@;F]T('-E="!U
M<V4@9&5F875L=',*("`@("`@("!C;&5A<G-T871C86-H92@I.PH@("`@("`@
M(&EF("AS=')L96XH)'-O=7)C95!A=&A-971A<BDI('L*("`@("`@("`@("`@
M:68@*"@D=&AI<RT^7W-O=7)C94UE=&%R(#T](")F:6QE(B`F)B!I<U]D:7(H
M)'-O=7)C95!A=&A-971A<BDI('Q\("@D=&AI<RT^7W-O=7)C94UE=&%R("$]
M(")F:6QE(B`F)B!P87)S95]U<FPH)'-O=7)C95!A=&A-971A<BDI*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7W-O=7)C95!A=&A-971A<B`]("1S;W5R
M8V50871H365T87(["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("!R971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)6
M24-%4U]714%42$527T524D]27TU%5$%27U-/55)#15])3E9!3$E$+"!?7T9)
M3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@<W=I=&-H("@D<V]U<F-E365T87(I('L*("`@("`@
M("`@("`@("`@(&-A<V4@(FAT='`B.@H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<V]U<F-E4&%T:$UE=&%R(#T@(FAT='`Z+R]W96%T:&5R+FYO86$N
M9V]V+W!U8B]D871A+V]B<V5R=F%T:6]N<R]M971A<B]S=&%T:6]N<R(["B`@
M("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E
M(")F='`B.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<V]U<F-E4&%T
M:$UE=&%R(#T@(F9T<#HO+W=E871H97(N;F]A82YG;W8O9&%T82]O8G-E<G9A
M=&EO;G,O;65T87(O<W1A=&EO;G,B.PH@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@8V%S92`B9FEL92(Z"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]S;W5R8V50871H365T87(@/2`B+B(["B`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(&EF("AI;E]A<G)A>2@D<V]U<F-E5&%F+"!A<G)A>2@B:'1T
M<"(L(")F='`B+"`B9FEL92(I*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W-O
M=7)C951A9B`]("1S;W5R8V54868["B`@("`@("`@?2!E;'-E:68@*"1S;W5R
M8V54868@(3T@(B(I('L*("`@("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E
M871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%4E)/4E]-151!
M4E]33U520T5?24Y604Q)1"P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@
M("!]"@H@("`@("`@("\O($-H96-K(&9O<B!A('!R;W!E<B!4048@<V]U<F-E
M(&EF('!A<F%M971E<B!I<R!S970L(&EF(&YO="!S970@=7-E(&1E9F%U;'1S
M"B`@("`@("`@8VQE87)S=&%T8V%C:&4H*3L*("`@("`@("!I9B`H<W1R;&5N
M*"1S;W5R8V50871H5&%F*2D@>PH@("`@("`@("`@("!I9B`H*"1T:&ES+3Y?
M<V]U<F-E5&%F(#T](")F:6QE(B`F)B!I<U]D:7(H)'-O=7)C95!A=&A4868I
M*2!\?"`H)'1H:7,M/E]S;W5R8V54868@(3T@(F9I;&4B("8F('!A<G-E7W5R
M;"@D<V]U<F-E4&%T:%1A9BDI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7W-O=7)C95!A=&A4868@/2`D<V]U<F-E4&%T:%1A9CL*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B!397)V:6-E<U]796%T
M:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?15)23U)?345405)?
M4T]54D-%7TE.5D%,240L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@
M("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!S=VET8V@@*"1S
M;W5R8V54868I('L*("`@("`@("`@("`@("`@(&-A<V4@(FAT='`B.@H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<V]U<F-E4&%T:%1A9B`](")H='1P
M.B\O=V5A=&AE<BYN;V%A+F=O=B]P=6(O9&%T82]F;W)E8V%S=',O=&%F+W-T
M871I;VYS(CL*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@(&-A<V4@(F9T<"(Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]S;W5R8V50871H5&%F(#T@(F9T<#HO+W=E871H97(N;F]A82YG;W8O9&%T
M82]F;W)E8V%S=',O=&%F+W-T871I;VYS(CL*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@(F9I;&4B.@H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<V]U<F-E4&%T:%1A9B`]("(N(CL*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"B`@("`O+R!]?7T*"B`@
M("`O+R![>WL@7V-H96-K3&]C871I;VY)1"@I"B`@("`O*BH*("`@("`J($-H
M96-K<R!T:&4@:60@9F]R('9A;&ED('9A;'5E<R!A;F0@=&AU<R!P<F5V96YT
M<R!S:6QL>2!R97%U97-T<R!T;PH@("`@("H@345405(@<V5R=F5R"B`@("`@
M*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@
M("1I9`H@("`@("H@0')E='5R;B`@4$5!4E]%<G)O<GQB;V]L"B`@("`@*B!`
M=&AR;W=S("!014%27T5R<F]R.CI315)624-%4U]714%42$527T524D]27TY/
M7TQ/0T%424]."B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R.CI315)624-%
M4U]714%42$527T524D]27TE.5D%,241?3$]#051)3TX*("`@("`J($!A8V-E
M<W,@('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V-H96-K3&]C871I
M;VY)1"@D:60I"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1I9"D@?'P@
M:7-?;V)J96-T*"1I9"D@?'P@(7-T<FQE;B@D:60I*2!["B`@("`@("`@("`@
M(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T53
M7U=%051(15)?15)23U)?3D]?3$]#051)3TXL(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["B`@("`@("`@?2!E;'-E:68@*"%C='EP95]A;&YU;2@D:60I('Q\("AS
M=')L96XH)&ED*2`^(#0I*2!["B`@("`@("`@("`@(')E='5R;B!397)V:6-E
M<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?15)23U)?
M24Y604Q)1%],3T-!5$E/3BP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H@("`@+R\@?7U]"@H@
M("`@+RHJ"B`@("`@*B!$;W=N;&]A9',@=&AE('=E871H97(M(&]R(&9O<F5C
M87-T+61A=&$@9F]R(&%N(&ED(&9R;VT@=&AE('-E<G9E<B!D97!E;F1A;G0@
M;VX@=&AE(&1A=&%T>7!E(&%N9"!R971U<FYS(&ET"B`@("`@*@H@("`@("H@
M0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1I9`H@("`@
M("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1D871A
M5'EP90H@("`@("H@0')E='5R;B`@4$5!4E]%<G)O<GQA<G)A>0H@("`@("H@
M0'1H<F]W<R`@4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/4E]7
M4D].1U]315)615)?1$%400H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@
M("HO"B`@("`O+R![>WL@7W)E=')I979E4V5R=F5R1&%T82@I"B`@("!F=6YC
M=&EO;B!?<F5T<FEE=F5397)V97)$871A*"1I9"P@)&1A=&%4>7!E*2!["B`@
M("`@("`@<W=I=&-H*"1T:&ES+3Y[(E]S;W5R8V4B+G5C9FER<W0H)&1A=&%4
M>7!E*7TI('L*("`@("`@("`@("`@8V%S92`B9FEL92(Z"B`@("`@("`@("`@
M("`@("`O+R!&:6QE('-O=7)C92!I<R!U<V5D+"!G970@9FEL92!A;F0@<F5A
M9"!A<RUI<R!I;G1O(&$@<W1R:6YG"B`@("`@("`@("`@("`@("`D<V]U<F-E
M(#T@<F5A;'!A=&@H)'1H:7,M/GLB7W-O=7)C95!A=&@B+G5C9FER<W0H)&1A
M=&%4>7!E*7TN(B\B+B1I9"XB+E185"(I.PH@("`@("`@("`@("`@("`@)&1A
M=&$@/2!`9FEL95]G971?8V]N=&5N=',H)'-O=7)C92D["B`@("`@("`@("`@
M("`@("!I9B`H)&1A=&$@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#
M15-?5T5!5$A%4E]%4E)/4E]74D].1U]315)615)?1$%402P@7U]&24Q%7U\L
M(%]?3$E.15]?*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("!C87-E(")H='1P(CH*("`@("`@("`@("`@
M("`@("\O($A45%`@=7-E9"P@86-Q=6ER92!R97%U97-T(&]B:F5C="!A;F0@
M9F5T8V@@9&%T82!F<F]M('=E8G-E<G9E<BX@4F5T=7)N(&)O9'D@;V8@<F5P
M;'D*("`@("`@("`@("`@("`@(&EN8VQU9&5?;VYC92`B2%144"]297%U97-T
M+G!H<"(["@H@("`@("`@("`@("`@("`@)')E<75E<W0@/2`F;F5W($A45%!?
M4F5Q=65S="@D=&AI<RT^>R)?<V]U<F-E4&%T:"(N=6-F:7)S="@D9&%T851Y
M<&4I?2XB+R(N)&ED+B(N5%A4(BP@)'1H:7,M/E]H='1P3W!T:6]N<RD["B`@
M("`@("`@("`@("`@("`D<W1A='5S(#T@)')E<75E<W0M/G-E;F1297%U97-T
M*"D["B`@("`@("`@("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%
M<G)O<B@D<W1A='5S*2!\?"`H:6YT*2`D<F5Q=65S="T^9V5T4F5S<&]N<V5#
M;V1E*"D@/#X@,C`P*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%-E
M<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%
M4E)/4E]74D].1U]315)615)?1$%402P@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D9&%T82`]("1R
M97%U97-T+3YG971297-P;VYS94)O9'DH*3L*("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("!C87-E(")F='`B.@H@("`@("`@("`@("`@("`@
M+R\@1E10(&%S('-O=7)C92P@86-Q=6ER92!N96-C97-S87)Y(&]B:F5C="!F
M:7)S=`H@("`@("`@("`@("`@("`@:6YC;'5D95]O;F-E(").970O1E10+G!H
M<"(["@H@("`@("`@("`@("`@("`@+R\@4&%R<V4@<V]U<F-E('1O(&=E="!T
M:&4@<V5R=F5R(&1A=&$*("`@("`@("`@("`@("`@("1S97)V97(@/2!P87)S
M95]U<FPH)'1H:7,M/GLB7W-O=7)C95!A=&@B+G5C9FER<W0H)&1A=&%4>7!E
M*7TN(B\B+B1I9"XB+E185"(I.PH*("`@("`@("`@("`@("`@("\O($EF(&YE
M8V-E<W-A<GD@;W!T:6]N<R!A<F4@;F]T('-E="P@=7-E(&1E9F%U;'1S"B`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1S97)V97);(G!O<G0B72D@?'P@
M)'-E<G9E<ELB<&]R=")=(#T]("(B('Q\("1S97)V97);(G!O<G0B72`]/2`P
M*2!["B`@("`@("`@("`@("`@("`@("`@)'-E<G9E<ELB<&]R=")=(#T@,C$[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1S97)V97);(G5S97(B72D@?'P@)'-E<G9E<ELB=7-E<B)=(#T]("(B*2![
M"B`@("`@("`@("`@("`@("`@("`@)'-E<G9E<ELB=7-E<B)=(#T@(F9T<"([
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1S97)V97);(G!A<W,B72D@?'P@)'-E<G9E<ELB<&%S<R)=(#T]("(B*2![
M"B`@("`@("`@("`@("`@("`@("`@)'-E<G9E<ELB<&%S<R)=(#T@(F9T<$`B
M.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\O($EN<W1A
M;G1I871E(&]B:F5C="!A;F0@8V]N;F5C="!T;R!S97)V97(*("`@("`@("`@
M("`@("`@("1F='`@/2`F;F5W($YE=%]&5%`H)'-E<G9E<ELB:&]S=")=+"`D
M<V5R=F5R6R)P;W)T(ETL("1T:&ES+3Y?:'1T<$]P=&EO;G-;(G1I;65O=70B
M72D["B`@("`@("`@("`@("`@("`D<W1A='5S(#T@)&9T<"T^8V]N;F5C="@I
M.PH@("`@("`@("`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R
M;W(H)'-T871U<RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@4V5R
M=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$527T52
M4D]27U=23TY'7U-%4E9%4E]$051!+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\O($QO9VEN('1O
M('-E<G9E<BXN+@H@("`@("`@("`@("`@("`@)'-T871U<R`]("1F='`M/FQO
M9VEN*"1S97)V97);(G5S97(B72P@)'-E<G9E<ELB<&%S<R)=*3L*("`@("`@
M("`@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1S=&%T
M=7,I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E
M871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%4E)/4E]74D].
M1U]315)615)?1$%402P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("`@("`O+R`N+BYA;F0@<F5T<FEE=F4@
M=&AE(&1A=&$@:6YT;R!A('1E;7!O<F%R>2!F:6QE"B`@("`@("`@("`@("`@
M("`D=&5M<&9I;&4@/2!T96UP;F%M*"(N+R(L(")397)V:6-E<U]796%T:&5R
M7TUE=&%R(BD["B`@("`@("`@("`@("`@("`D<W1A='5S(#T@)&9T<"T^9V5T
M*"1S97)V97);(G!A=&@B72P@)'1E;7!F:6QE+"!T<G5E+"!&5%!?05-#24DI
M.PH@("`@("`@("`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R
M;W(H)'-T871U<RDI('L*("`@("`@("`@("`@("`@("`@("!U;FQI;FLH)'1E
M;7!F:6QE*3L*("`@("`@("`@("`@("`@("`@("!R971U<FX@4V5R=FEC97-?
M5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$527T524D]27U=2
M3TY'7U-%4E9%4E]$051!+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\O($1I<V-O;FYE8W0@1E10
M('-E<G9E<BP@86YD(')E860@9&%T82!F<F]M('1E;7!O<F%R>2!F:6QE"B`@
M("`@("`@("`@("`@("`D9G1P+3YD:7-C;VYN96-T*"D["B`@("`@("`@("`@
M("`@("`D9&%T82`]($!F:6QE7V=E=%]C;VYT96YT<R@D=&5M<&9I;&4I.PH@
M("`@("`@("`@("`@("`@=6YL:6YK*"1T96UP9FEL92D["B`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@("\O(%-P;&ET(&1A=&$@
M:6YT;R!A;B!A<G)A>2!A;F0@<F5T=7)N"B`@("`@("`@<F5T=7)N('!R96=?
M<W!L:70H(B]<;GQ<<EQN?%QN7'(O(BP@)&1A=&$I.PH@("`@?0H@("`@+R\@
M?7U]"@H@("`@+R\@>WM[(%]P87)S95=E871H97)$871A*"D*("`@("\J*@H@
M("`@("H@4&%R<V5S('1H92!D871A(&%N9"!C86-H97,@:70*("`@("`J"B`@
M("`@*B!-151!4B!+4$E4(#`Y,3DU-5H@0T]2(#(R,#$U1S(U2U0@,R\T4TT@
M4C(X3"\R-C`P1E0@5%-202!/5D,P,3!#0@H@("`@("H@,3@O,38@03(Y.3(@
M4DU+(%-,4#`T-2!4,#$X,C`Q-3D*("`@("`J"B`@("`@*B!`<&%R86T@("!A
M<G)A>2`@("`@("`@("`@("`@("`@("`@("`@)&1A=&$*("`@("`J($!R971U
M<FX@(%!%05)?17)R;W)\87)R87D*("`@("`J($!T:')O=W,@(%!%05)?17)R
M;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?5U)/3D=?4T525D527T1!5$$*
M("`@("`J($!T:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?
M15)23U)?54Y+3D]73E],3T-!5$E/3@H@("`@("H@0&%C8V5S<R`@<')I=F%T
M90H@("`@("HO"B`@("!F=6YC=&EO;B!?<&%R<V5796%T:&5R1&%T82@D9&%T
M82D*("`@('L*("`@("`@("!S=&%T:6,@)&-O;7!A<W,["B`@("`@("`@<W1A
M=&EC("1C;&]U9',["B`@("`@("`@<W1A=&EC("1C;VYD:71I;VYS.PH@("`@
M("`@('-T871I8R`D<V5N<V]R<SL*("`@("`@("!I9B`H(6ES<V5T*"1C;VUP
M87-S*2D@>PH@("`@("`@("`@("`D8V]M<&%S<R`](&%R<F%Y*`H@("`@("`@
M("`@("`@("`@(DXB+"`B3DY%(BP@(DY%(BP@(D5.12(L"B`@("`@("`@("`@
M("`@("`B12(L(")%4T4B+"`B4T4B+"`B4U-%(BP*("`@("`@("`@("`@("`@
M(")3(BP@(E-35R(L(")35R(L(")74U<B+`H@("`@("`@("`@("`@("`@(E<B
M+"`B5TY7(BP@(DY7(BP@(DY.5R(*("`@("`@("`@("`@*3L*("`@("`@("`@
M("`@)&-L;W5D<R`@("`](&%R<F%Y*`H@("`@("`@("`@("`@("`@(G-K8R(@
M("`@("`@("`]/B`B<VMY(&-L96%R(BP*("`@("`@("`@("`@("`@(")N<V,B
M("`@("`@("`@/3X@(FYO('-I9VYI9FEC86YT(&-L;W5D(BP*("`@("`@("`@
M("`@("`@(")F97<B("`@("`@("`@/3X@(F9E=R(L"B`@("`@("`@("`@("`@
M("`B<V-T(B`@("`@("`@(#T^(")S8V%T=&5R960B+`H@("`@("`@("`@("`@
M("`@(F)K;B(@("`@("`@("`]/B`B8G)O:V5N(BP*("`@("`@("`@("`@("`@
M(")O=F,B("`@("`@("`@/3X@(F]V97)C87-T(BP*("`@("`@("`@("`@("`@
M(")V=B(@("`@("`@("`@/3X@(G9E<G1I8V%L('9I<VEB:6QI='DB+`H@("`@
M("`@("`@("`@("`@(G1C=2(@("`@("`@("`]/B`B5&]W97)I;F<@0W5M=6QU
M<R(L"B`@("`@("`@("`@("`@("`B8V(B("`@("`@("`@(#T^(")#=6UU;&]N
M:6UB=7,B+`H@("`@("`@("`@("`@("`@(F-L<B(@("`@("`@("`]/B`B8VQE
M87(@8F5L;W<@,3(L,#`P(&9T(@H@("`@("`@("`@("`I.PH@("`@("`@("`@
M("`D8V]N9&ET:6]N<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@(BLB("`@
M("`@("`@("`]/B`B:&5A=GDB+"`@("`@("`@(BTB("`@("`@("`@("`]/B`B
M;&EG:'0B+`H*("`@("`@("`@("`@("`@(")V8R(@("`@("`@("`@/3X@(G9I
M8VEN:71Y(BP@("`@(")R92(@("`@("`@("`@/3X@(G)E8V5N="(L"B`@("`@
M("`@("`@("`@("`B;G-W(B`@("`@("`@(#T^(")N;R!S:6=N:69I8V%N="!W
M96%T:&5R(BP*"B`@("`@("`@("`@("`@("`B;6DB("`@("`@("`@(#T^(")S
M:&%L;&]W(BP@("`@("`B8F,B("`@("`@("`@(#T^(")P871C:&5S(BP*("`@
M("`@("`@("`@("`@(")P<B(@("`@("`@("`@/3X@(G!A<G1I86PB+"`@("`@
M(")T<R(@("`@("`@("`@/3X@(G1H=6YD97)S=&]R;2(L"B`@("`@("`@("`@
M("`@("`B8FPB("`@("`@("`@(#T^(")B;&]W:6YG(BP@("`@("`B<V@B("`@
M("`@("`@(#T^(")S:&]W97)S(BP*("`@("`@("`@("`@("`@(")D<B(@("`@
M("`@("`@/3X@(FQO=R!D<FEF=&EN9R(L(")F>B(@("`@("`@("`@/3X@(F9R
M965Z:6YG(BP*"B`@("`@("`@("`@("`@("`B9'HB("`@("`@("`@(#T^(")D
M<FEZ>FQE(BP@("`@("`B<F$B("`@("`@("`@(#T^(")R86EN(BP*("`@("`@
M("`@("`@("`@(")S;B(@("`@("`@("`@/3X@(G-N;W<B+"`@("`@("`@(")S
M9R(@("`@("`@("`@/3X@(G-N;W<@9W)A:6YS(BP*("`@("`@("`@("`@("`@
M(")I8R(@("`@("`@("`@/3X@(FEC92!C<GES=&%L<R(L(")P92(@("`@("`@
M("`@/3X@(FEC92!P96QL971S(BP*("`@("`@("`@("`@("`@(")G<B(@("`@
M("`@("`@/3X@(FAA:6PB+"`@("`@("`@(")G<R(@("`@("`@("`@/3X@(G-M
M86QL(&AA:6PO<VYO=R!P96QL971S(BP*("`@("`@("`@("`@("`@(")U<"(@
M("`@("`@("`@/3X@(G5N:VYO=VX@<')E8VEP:71A=&EO;B(L"@H@("`@("`@
M("`@("`@("`@(F)R(B`@("`@("`@("`]/B`B;6ES="(L("`@("`@("`@(F9G
M(B`@("`@("`@("`]/B`B9F]G(BP*("`@("`@("`@("`@("`@(")F=2(@("`@
M("`@("`@/3X@(G-M;VME(BP@("`@("`@(")V82(@("`@("`@("`@/3X@(G9O
M;&-A;FEC(&%S:"(L"B`@("`@("`@("`@("`@("`B<V$B("`@("`@("`@(#T^
M(")S86YD(BP@("`@("`@("`B:'HB("`@("`@("`@(#T^(")H87IE(BP*("`@
M("`@("`@("`@("`@(")P>2(@("`@("`@("`@/3X@(G-P<F%Y(BP@("`@("`@
M(")D=2(@("`@("`@("`@/3X@(G=I9&5S<')E860@9'5S="(L"@H@("`@("`@
M("`@("`@("`@(G-Q(B`@("`@("`@("`]/B`B<W%U86QL(BP@("`@("`@(G-S
M(B`@("`@("`@("`]/B`B<V%N9'-T;W)M(BP*("`@("`@("`@("`@("`@(")D
M<R(@("`@("`@("`@/3X@(F1U<W1S=&]R;2(L("`@(")P;R(@("`@("`@("`@
M/3X@(G=E;&P@9&5V96QO<&5D(&1U<W0O<V%N9"!W:&ER;',B+`H@("`@("`@
M("`@("`@("`@(F9C(B`@("`@("`@("`]/B`B9G5N;F5L(&-L;W5D(BP*"B`@
M("`@("`@("`@("`@("`B*V9C(B`@("`@("`@(#T^(")T;W)N861O+W=A=&5R
M<W!O=70B"B`@("`@("`@("`@("D["B`@("`@("`@("`@("1S96YS;W)S(#T@
M87)R87DH"B`@("`@("`@("`@("`@("`B<G9R;F\B("`]/B`B4G5N=V%Y(%9I
M<W5A;"!286YG92!$971E8W1O<B!O9F9L:6YE(BP*("`@("`@("`@("`@("`@
M(")P=VEN;R(@(#T^(")0<F5S96YT(%=E871H97(@261E;G1I9FEE<B!O9F9L
M:6YE(BP*("`@("`@("`@("`@("`@(")P;F\B("`@(#T^(")4:7!P:6YG($)U
M8VME="!286EN($=A=6=E(&]F9FQI;F4B+`H@("`@("`@("`@("`@("`@(F9Z
M<F%N;R(@/3X@(D9R965Z:6YG(%)A:6X@4V5N<V]R(&]F9FQI;F4B+`H@("`@
M("`@("`@("`@("`@(G1S;F\B("`@/3X@(DQI9VAT;FEN9R!$971E8W1I;VX@
M4WES=&5M(&]F9FQI;F4B+`H@("`@("`@("`@("`@("`@(G9I<VYO(B`@/3X@
M(C)N9"!6:7-I8FEL:71Y(%-E;G-O<B!O9F9L:6YE(BP*("`@("`@("`@("`@
M("`@(")C:&EN;R(@(#T^("(R;F0@0V5I;&EN9R!(96EG:'0@26YD:6-A=&]R
M(&]F9FQI;F4B"B`@("`@("`@("`@("D["B`@("`@("`@?0H*("`@("`@("`D
M;65T87)#;V1E(#T@87)R87DH"B`@("`@("`@("`@(")R97!O<G0B("`@("`@
M/3X@(DU%5$%2?%-014-)(BP*("`@("`@("`@("`@(G-T871I;VXB("`@("`]
M/B`B7'=[-'TB+`H@("`@("`@("`@("`B=7!D871E(B`@("`@(#T^("(H7&1[
M,GTI/RA<9'LT?2E:(BP*("`@("`@("`@("`@(G1Y<&4B("`@("`@("`]/B`B
M05543WQ#3U(B+`H@("`@("`@("`@("`B=VEN9"(@("`@("`@(#T^("(H7&1[
M,WU\5D%2?%920BDH7&1[,BPS?2DH1RA<9'LR?2DI/RA<=WLR+#-]*2(L"B`@
M("`@("`@("`@(")W:6YD5F%R(B`@("`@/3X@(BA<9'LS?2E6*%QD>S-]*2(L
M"B`@("`@("`@("`@(")V:7-&<F%C(B`@("`@/3X@(BA<9'LQ?2DB+`H@("`@
M("`@("`@("`B=FES:6)I;&ET>2(@(#T^("(H7&1[-'TI?"@H37Q0*3\H*%QD
M>S$L,GU\*"A<9"D@*3\H7&0I7"\H7&0I*2A337Q+32DI*7PH0T%63TLI(BP*
M("`@("`@("`@("`@(G)U;G=A>2(@("`@("`]/B`B4BA<9'LR?2DH7'<I/UPO
M*%!\32D_*%QD>S1]*2A&5"D_*%8H4'Q-*3\H7&1[-'TI*$94*3\I/RA<=RD_
M(BP*("`@("`@("`@("`@(F-O;F1I=&EO;B(@("`]/B`B*"U\7"M\5D-\4D5\
M3E-7*3\H34E\0D-\4%)\5%-\0DQ\4TA\1%)\1EHI/R@H1%HI?"A202E\*%-.
M*7PH4T<I?"A)0RE\*%!,*7PH1U(I?"A'4RE\*%50*2DJ*$)2?$9'?$95?%9!
M?$15?%-!?$A:?%!9*3\H4$]\4U%\1D-\4U-\1%,I/R(L"B`@("`@("`@("`@
M(")C;&]U9',B("`@("`@/3X@(BA32T-\0TQ2?$Y30WPH*$9%5WQ30U1\0DM.
M?$]60WQ65BDH7&1[,WTI*%1#57Q#0BD_*2DB+`H@("`@("`@("`@("`B=&5M
M<&5R871U<F4B(#T^("(H32D_*%QD>S)]*5PO*"A-*3\H7&1[,GTI?%A8?%PO
M7"\I/R(L"B`@("`@("`@("`@(")P<F5S<W5R92(@("`@/3X@(BA!*2A<9'LT
M?2E\*%$I*%QD>S1]*2(L"B`@("`@("`@("`@(")T<F5N9"(@("`@("`@/3X@
M(DY/4TE'?%1%35!/?$)%0TU'(BP*("`@("`@("`@("`@(G)E;6%R:R(@("`@
M("`]/B`B4DU+(@H@("`@("`@("D["@H@("`@("`@("1R96UA<FMS(#T@87)R
M87DH"B`@("`@("`@("`@(")N;W-P96-I(B`@("`@/3X@(DY/4U!%0TDB+`H@
M("`@("`@("`@("`B875T;W-T871I;VXB(#T^(")!3R@Q?#(I(BP*("`@("`@
M("`@("`@(G!R97-S8VAG(B`@("`]/B`B4%)%4RA2?$8I4B(L"B`@("`@("`@
M("`@(")S96%P<F5S<W5R92(@/3X@(E-,4"A<9'LS?7Q.3RDB+`H@("`@("`@
M("`@("`B<')E8VEP(B`@("`@(#T^("(H4'PV?#<I*%QD>S1]?%PO>S1]*2(L
M"B`@("`@("`@("`@(")S;F]W9&5P=&@B("`@/3X@(C1<+RA<9'LS?2DB+`H@
M("`@("`@("`@("`B<VYO=V5Q=6EV(B`@(#T^("(Y,S,H7&1[,WTI(BP*("`@
M("`@("`@("`@(F-L;W5D='EP97,B("`]/B`B.%PO*%QD?%PO*2A<9'Q<+RDH
M7&1\7"\I(BP*("`@("`@("`@("`@(G-U;F1U<F%T:6]N(B`]/B`B.3@H7&1[
M,WTI(BP*("`@("`@("`@("`@(C%H=&5M<&1E=R(@("`]/B`B5"@P?#$I*%QD
M>S-]*2@H,'PQ*2A<9'LS?2DI/R(L"B`@("`@("`@("`@("(V:&UA>'1E;7`B
M("`@/3X@(C$H,'PQ*2A<9'LS?2DB+`H@("`@("`@("`@("`B-FAM:6YT96UP
M(B`@(#T^("(R*#!\,2DH7&1[,WTI(BP*("`@("`@("`@("`@(C(T:'1E;7`B
M("`@("`]/B`B-"@P?#$I*%QD>S-]*2@P?#$I*%QD>S-]*2(L"B`@("`@("`@
M("`@("(S:'!R97-S=&5N9"(@/3X@(C4H6S`M.%TI*%QD>S-]*2(L"B`@("`@
M("`@("`@(")S96YS;W)S(B`@("`@/3X@(E)64DY/?%!724Y/?%!.3WQ&6E)!
M3D]\5%-.3WQ625-.3WQ#2$E.3R(L"B`@("`@("`@("`@(")M86EN=&%I;B(@
M("`@/3X@(EM<)%TB"B`@("`@("`@*3L*"B`@("`@("`@:68@*%-%4E9)0T53
M7U=%051(15)?1$5"54<I('L*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I
M(#P@<VEZ96]F*"1D871A*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@96-H
M;R`D9&%T85LD:5T["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@
M+R\@4W1A<G0@=VET:"!P87)S:6YG('1H92!F:7)S="!L:6YE(&9O<B!T:&4@
M;&%S="!U<&1A=&4*("`@("`@("`D=V5A=&AE<D1A=&$@/2!A<G)A>2@I.PH@
M("`@("`@("1W96%T:&5R1&%T85LB<W1A=&EO;B)=("`@/2`B(CL*("`@("`@
M("`D=V5A=&AE<D1A=&%;(F1A=&%287<B72`@(#T@:6UP;&]D92@B("(L("1D
M871A*3L*("`@("`@("`D=V5A=&AE<D1A=&%;(G5P9&%T92)=("`@(#T@<W1R
M=&]T:6UE*'1R:6TH)&1A=&%;,%TI+B(@1TU4(BD["B`@("`@("`@)'=E871H
M97)$871A6R)U<&1A=&5287<B72`]('1R:6TH)&1A=&%;,%TI.PH@("`@("`@
M("\O(&%N9"!P<F5P87)E('1H92!R97-T(&9O<B!S=&5P<&EN9R!T:')O=6=H
M"B`@("`@("`@87)R87E?<VAI9G0H)&1A=&$I.PH@("`@("`@("1M971A<B`]
M(&5X<&QO9&4H(B`B+"!P<F5G7W)E<&QA8V4H(B]<<WLR+'TO(BP@(B`B+"!I
M;7!L;V1E*"(@(BP@)&1A=&$I*2D["@H@("`@("`@("\O($%D9"!A(&9E=R!L
M;V-A;"!V87)I86)L97,@9F]R(&1A=&$@<')O8V5S<VEN9PH@("`@("`@("1T
M<F5N9$-O=6YT(#T@,#L@("`@("`@("`@("`@+R\@268@=V4@:&%V92!T<F5N
M9',L('=E(&YE960@=&AI<PH@("`@("`@("1P;VEN=&5R("`@(#TF("1W96%T
M:&5R1&%T83L@+R\@4&]I;G1E<B!T;R!T:&4@87)R87D@=V4@861D('1H92!D
M871A('1O"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F*"1M971A
M<BD[("1I*RLI('L*("`@("`@("`@("`@+R\@0VAE8VL@9F]R('=H:71E<W!A
M8V4@86YD('-T97`@;&]O<"P@:68@;F]T:&EN9R=S('1H97)E"B`@("`@("`@
M("`@("1M971A<ELD:5T@/2!T<FEM*"1M971A<ELD:5TI.PH@("`@("`@("`@
M("!I9B`H(7-T<FQE;B@D;65T87);)&E=*2D@>PH@("`@("`@("`@("`@("`@
M8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("A315)6
M24-%4U]714%42$527T1%0E5'*2!["B`@("`@("`@("`@("`@("`D=&%B(#T@
M<W1R7W)E<&5A="@B7'0B+"`R("T@9FQO;W(H*'-T<FQE;B@D;65T87);)&E=
M*2`K(#(I("\@."DI.PH@("`@("`@("`@("`@("`@96-H;R`B7"(B+B1M971A
M<ELD:5TN(EPB(BXD=&%B+B(M/B`B.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`O+R!);FET:6%L:7IE('-O;64@87)R87ES"B`@("`@("`@("`@("1R
M97-U;'0@("`](&%R<F%Y*"D["B`@("`@("`@("`@("1R97-U;'161B`](&%R
M<F%Y*"D["B`@("`@("`@("`@("1L<F5S=6QT("`](&%R<F%Y*"D["@H@("`@
M("`@("`@("`D9F]U;F0@/2!F86QS93L*("`@("`@("`@("`@9F]R96%C:"`H
M)&UE=&%R0V]D92!A<R`D:V5Y(#T^("1R96=E>'`I('L*("`@("`@("`@("`@
M("`@("\O($-H96-K(&EF(&-U<G)E;G0@8V]D92!M871C:&5S(&-U<G)E;G0@
M;65T87(@<VYI<'!E=`H@("`@("`@("`@("`@("`@:68@*"@D9F]U;F0@/2!P
M<F5G7VUA=&-H*"(O7B(N)')E9V5X<"XB)"]I(BP@)&UE=&%R6R1I72P@)')E
M<W5L="DI(#T]('1R=64I('L*("`@("`@("`@("`@("`@("`@("!S=VET8V@@
M*"1K97DI('L*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B<W1A=&EO
M;B(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB<W1A
M=&EO;B)=(#T@)')E<W5L=%LP73L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('5N<V5T*"1M971A<D-O9&5;(G-T871I;VXB72D["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@
M("`@8V%S92`B=VEN9"(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!087)S92!W:6YD(&1A=&$L(&9I<G-T('1H92!S<&5E9"P@8V]N=F5R="!F
M<F]M(&MT('1O(&-H;W-E;B!U;FET"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<&]I;G1E<ELB=VEN9")=(#T@)'1H:7,M/F-O;G9E<G13<&5E9"@D
M<F5S=6QT6S)=+"!S=')T;VQO=V5R*"1R97-U;'1;-5TI+"`B;7!H(BD["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)')E<W5L=%LQ72`]/2`B
M5D%2(B!\?"`D<F5S=6QT6S%=(#T](")64D(B*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@5F%R:6%B;&4@=VEN9',*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB=VEN9$1E9W)E97,B
M72`@(#T@(E9A<FEA8FQE(CL*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<&]I;G1E<ELB=VEN9$1I<F5C=&EO;B)=(#T@(E9A<FEA8FQE(CL*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@+R\@4V%V92!W:6YD(&1E9W)E92!A
M;F0@8V%L8R!D:7)E8W1I;VX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<&]I;G1E<ELB=VEN9$1E9W)E97,B72`@(#T@:6YT=F%L*"1R97-U
M;'1;,5TI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN
M=&5R6R)W:6YD1&ER96-T:6]N(ET@/2`D8V]M<&%S<UMR;W5N9"@D<F5S=6QT
M6S%=("\@,C(N-2D@)2`Q-ET["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-?;G5M97)I
M8R@D<F5S=6QT6S1=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("\O(%=I;F0@=VET:"!G=7-T<RXN+@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1P;VEN=&5R6R)W:6YD1W5S=")=(#T@)'1H:7,M/F-O
M;G9E<G13<&5E9"@D<F5S=6QT6S1=+"!S=')T;VQO=V5R*"1R97-U;'1;-5TI
M+"`B;7!H(BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M("`@("`@("`@8V%S92`B=VEN9%9A<B(Z"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`O+R!/;F-E(&UO<F4@=VEN9"P@;F]W('9A<FEA8FEL:71Y(&%R
M;W5N9"!T:&4@8W5R<F5N="!W:6YD+61I<F5C=&EO;@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'!O:6YT97);(G=I;F1687)I86)I;&ET>2)=(#T@
M87)R87DH(F9R;VTB(#T^(&EN='9A;"@D<F5S=6QT6S%=*2P@(G1O(B`]/B!I
M;G1V86PH)')E<W5L=%LR72DI.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(G9I<T9R
M86,B.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@4&]S<VEB;&4@
M9G)A8W1I;VYA;"!V:7-I8FEL:71Y(&AE<F4N($-H96-K(&EF(&ET(&UA=&-H
M97,@=VET:"!T:&4@;F5X="!-151!4B!P:65C92!F;W(@=FES:6)I;&ET>0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;65T87);
M)&D@*R`Q72D@?'P@(7!R96=?;6%T8V@H(B]>(BXD;65T87)#;V1E6R)V:7-I
M8FEL:71Y(ETN(B0O:2(L("1R97-U;'1;,5TN(B`B+B1M971A<ELD:2`K(#%=
M+"`D<F5S=6QT5D8I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+R\@3F\@;F5X="!-151!4B!P:65C92!A=F%I;&%B;&4@;W(@;F]T(&UA
M=&-H:6YG+B!-871C:"!A9V%I;G-T(&YE>'0@345405(@8V]D90H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1F;W5N9"`](&9A;'-E.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!-871C:"X@2&%N9"!O=F5R(')E<W5L="!A;F0@
M861V86YC92!-151!4@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("A315)624-%4U]714%42$527T1%0E5'*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&5C:&\@)&ME>2XB7&XB.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!E8VAO(")<(B(N)')E<W5L
M=%LQ72XB("(N)&UE=&%R6R1I("L@,5TN(EPB(BYS=')?<F5P96%T*")<="(L
M(#(@+2!F;&]O<B@H<W1R;&5N*"1R97-U;'1;,5TN(B`B+B1M971A<ELD:2`K
M(#%=*2`K(#(I("\@."DI+B(M/B`B.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M:V5Y(#T@(G9I<VEB:6QI='DB.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1R97-U;'0@/2`D<F5S=6QT5D8["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&DK*SL*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B=FES:6)I;&ET
M>2(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB=FES
M475A;&EF:65R(ET@/2`B050B.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*&ES7VYU;65R:6,H)')E<W5L=%LQ72D@)B8@*"1R97-U;'1;,5T@
M/3T@.3DY.2DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!5<'!E<B!L:6UI="!O9B!V:7-I8FEL:71Y(')A;F=E"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'9I<VEB:6QI='D@/2`D=&AI<RT^8V]N
M=F5R=$1I<W1A;F-E*#$P+"`B:VTB+"`B<VTB*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB=FES475A;&EF:65R(ET@/2`B
M0D593TY$(CL*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF
M("AI<U]N=6UE<FEC*"1R97-U;'1;,5TI*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@-"UD:6=I="!V:7-I8FEL:71Y(&EN(&T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=FES:6)I;&ET>2`]("1T
M:&ES+3YC;VYV97)T1&ES=&%N8V4H*"1R97-U;'1;,5TO,3`P,"DL(")K;2(L
M(")S;2(I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@
M*"%I<W-E="@D<F5S=6QT6S$Q72D@?'P@)')E<W5L=%LQ,5T@(3T@(D-!5D]+
M(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D<F5S
M=6QT6S-=(#T](")-(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<&]I;G1E<ELB=FES475A;&EF:65R(ET@/2`B0D5,3U<B.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF("@D<F5S
M=6QT6S-=(#T](")0(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<&]I;G1E<ELB=FES475A;&EF:65R(ET@/2`B0D593TY$(CL*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*&ES7VYU;65R:6,H)')E<W5L=%LU
M72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M=FES:6)I;&ET>2!A<R!O;F4O='=O+61I9VET(&YU;6)E<@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=FES:6)I;&ET>2`]("1T:&ES
M+3YC;VYV97)T1&ES=&%N8V4H)')E<W5L=%LU72P@)')E<W5L=%LQ,%TL(")S
M;2(I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O('1H92!Y
M+WH@<&%R="P@861D(&EF('=E(&AA9"!A('@@<&%R="`H<V5E('9I<VEB:6QI
M='DQ*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M:7-?;G5M97)I8R@D<F5S=6QT6S==*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'9I<VEB:6QI='D@/2`D=&AI<RT^8V]N
M=F5R=$1I<W1A;F-E*"1R97-U;'1;-UT@*R`D<F5S=6QT6SA=("\@)')E<W5L
M=%LY72P@)')E<W5L=%LQ,%TL(")S;2(I.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'9I<VEB:6QI='D@/2`D=&AI<RT^8V]N
M=F5R=$1I<W1A;F-E*"1R97-U;'1;.%T@+R`D<F5S=6QT6SE=+"`D<F5S=6QT
M6S$P72P@(G-M(BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)V:7-1=6%L:69I97(B72`]
M(")"15E/3D0B.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V
M:7-I8FEL:71Y(#T@)'1H:7,M/F-O;G9E<G1$:7-T86YC92@Q,"P@(FMM(BP@
M(G-M(BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT
M97);(F-L;W5D<R)=(#T@87)R87DH87)R87DH(F%M;W5N="(@/3X@(D-L96%R
M(&)E;&]W(BP@(FAE:6=H="(@/3X@-3`P,"DI.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P;VEN=&5R6R)C;VYD:71I;VXB72`](")N;R!S
M:6=N:69I8V%N="!W96%T:&5R(CL*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)V
M:7-I8FEL:71Y(ET@/2`D=FES:6)I;&ET>3L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E
M(")C;VYD:71I;VXB.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M1FER<W0@<V]M92!B87-I8R!S971U<',*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)'!O:6YT97);(F-O;F1I=&EO;B)=*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)C;VYD
M:71I;VXB72`]("(B.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E:68@*'-T<FQE;B@D<&]I;G1E<ELB8V]N9&ET:6]N(ETI(#X@,"D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)C;VYD
M:71I;VXB72`N/2`B+"(["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&EN7V%R<F%Y*'-T
M<G1O;&]W97(H)')E<W5L=%LP72DL("1C;VYD:71I;VYS*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("\O($9I<G-T('1R>2!M871C:&EN
M9R!T:&4@8V]M<&QE=&4@<W1R:6YG"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!O:6YT97);(F-O;F1I=&EO;B)=("X]("(@(BXD8V]N9&ET
M:6]N<UMS=')T;VQO=V5R*"1R97-U;'1;,%TI73L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+R\@3F\@;'5C:RP@;6%T8V@@<&%R="!B>2!P87)T"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87E?<VAI9G0H)')E<W5L
M="D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E<W5L="`]
M(&%R<F%Y7W5N:7%U92@D<F5S=6QT*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!F;W)E86-H("@D<F5S=6QT(&%S("1C;VYD:71I;VXI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*'-T<FQE
M;B@D8V]N9&ET:6]N*2`^(#`I('L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P;VEN=&5R6R)C;VYD:71I;VXB72`N/2`B("(N
M)&-O;F1I=&EO;G-;<W1R=&]L;W=E<B@D8V]N9&ET:6]N*5T["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB8V]N
M9&ET:6]N(ET@/2!T<FEM*"1P;VEN=&5R6R)C;VYD:71I;VXB72D["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M("`@("`@("`@8V%S92`B8VQO=61S(CH*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)'!O:6YT97);(F-L;W5D<R)=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)C;&]U9',B
M72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*'-I>F5O9B@D<F5S=6QT
M*2`]/2`U*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M3VYL>2!A;6]U;G0@86YD(&AE:6=H=`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1C;&]U9"`](&%R<F%Y*")A;6]U;G0B(#T^("1C;&]U9'-;
M<W1R=&]L;W=E<B@D<F5S=6QT6S-=*5TL(")H96EG:'0B(#T^("@D<F5S=6QT
M6S1=*C$P,"DI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@96QS96EF("AS:7IE;V8H)')E<W5L
M="D@/3T@-BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O
M($%M;W5N="P@:&5I9VAT(&%N9"!T>7!E"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&-L;W5D(#T@87)R87DH(F%M;W5N="(@/3X@)&-L;W5D
M<UMS=')T;VQO=V5R*"1R97-U;'1;,UTI72P@(FAE:6=H="(@/3X@*"1R97-U
M;'1;-%TJ,3`P*2P@(G1Y<&4B(#T^("1C;&]U9'-;<W1R=&]L;W=E<B@D<F5S
M=6QT6S5=*5TI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@4TM#(&]R($-,4B!O<B!.4T,*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D8VQO=60@/2!A<G)A>2@B86UO
M=6YT(B`]/B`D8VQO=61S6W-T<G1O;&]W97(H)')E<W5L=%LP72E=*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1P;VEN=&5R6R)C;&]U9',B75M=(#T@)&-L;W5D.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("`@("`@("`@(&-A<V4@(G1E;7!E<F%T=7)E(CH*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("\O(&YO<FUA;"!T96UP97)A='5R92!I;B!F:7)S="!P
M87)T"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!N96=A=&EV92!V
M86QU90H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1R97-U;'1;
M,5T@/3T@(DTB*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)')E<W5L=%LR72`J/2`M,3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)T96UP
M97)A='5R92)=(#T@)'1H:7,M/F-O;G9E<G1496UP97)A='5R92@D<F5S=6QT
M6S)=+"`B8R(L(")F(BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H<VEZ96]F*"1R97-U;'0I(#X@-"D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("\O('-A;64@9F]R(&1E=W!O:6YT"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"1R97-U;'1;-%T@/3T@(DTB*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R97-U;'1;
M-5T@*CT@+3$["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)D97=0
M;VEN=")=(#T@)'1H:7,M/F-O;G9E<G1496UP97)A='5R92@D<F5S=6QT6S5=
M+"`B8R(L(")F(BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!O:6YT97);(FAU;6ED:71Y(ET@/2`D=&AI<RT^8V%L8W5L871E2'5M:61I
M='DH)')E<W5L=%LR72P@)')E<W5L=%LU72D["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)'!O:6YT97);(G=I;F0B72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!.;W<@8V%L8W5L871E('=I;F1C:&EL;"!F<F]M
M('1E;7!E<F%T=7)E(&%N9"!W:6YD<W!E960*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<&]I;G1E<ELB9F5L=%1E;7!E<F%T=7)E(ET@/2`D
M=&AI<RT^8V%L8W5L871E5VEN9$-H:6QL*"1P;VEN=&5R6R)T96UP97)A='5R
M92)=+"`D<&]I;G1E<ELB=VEN9")=*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@("`@("`@("!C87-E(")P<F5S<W5R92(Z"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H)')E<W5L=%LQ72`]/2`B02(I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!0<F5S<W5R
M92!P<F]V:61E9"!I;B!I;F-H97,*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<&]I;G1E<ELB<')E<W-U<F4B72`]("1R97-U;'1;,ET@+R`Q
M,#`["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)')E
M<W5L=%LS72`]/2`B42(I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`O+R`N+BX@:6X@:&5C=&]P87-C86P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<&]I;G1E<ELB<')E<W-U<F4B72`]("1T:&ES+3YC
M;VYV97)T4')E<W-U<F4H)')E<W5L=%LT72P@(FAP82(L(")I;B(I.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@
M(G1R96YD(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(%=E(&UA
M>2!H879E(&$@=')E;F0@:&5R92XN+B!E>'1R86-T('1Y<&4@86YD('-E="!P
M;VEN=&5R(&]N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!C<F5A
M=&5D(&YE=R!A<G)A>0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D=V5A=&AE<D1A=&%;(G1R96YD(ETI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'=E871H97)$871A6R)T<F5N9")=(#T@
M87)R87DH*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=V5A
M=&AE<D1A=&%;(G1R96YD(EU;)'1R96YD0V]U;G1=(#T@87)R87DH*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1P;VEN=&5R(#TF("1W96%T:&5R1&%T85LB=')E;F0B75LD
M=')E;F1#;W5N=%T["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=')E
M;F1#;W5N="LK.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT
M97);(G1Y<&4B72`]("1R97-U;'1;,%T["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!W:&EL92`H:7-S970H)&UE=&%R6R1I("L@,5TI("8F('!R96=?
M;6%T8V@H(B]>*$9-?%1,?$%4*2A<9'LR?2DH7&1[,GTI)"]I(BP@)&UE=&%R
M6R1I("L@,5TL("1L<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@D;')E<W5L=%LQ72`]/2`B1DTB*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)F<F]M(ET@
M/2`D;')E<W5L=%LR72XB.B(N)&QR97-U;'1;,UT["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1L<F5S=6QT6S%=(#T](")4
M3"(I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O
M:6YT97);(G1O(ET@/2`D;')E<W5L=%LR72XB.B(N)&QR97-U;'1;,UT["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(F%T(ET@
M/2`D;')E<W5L=%LR72XB.B(N)&QR97-U;'1;,UT["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("\O($%S('=E(&AA=F4@:G5S="!E>'1R86-T960@=&AE('1I;64@
M9F]R('1H:7,@=')E;F0*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`O+R!F<F]M(&]U<B!-151!4BP@:6YC<F5A<V4@9FEE;&0M8V]U;G1E<@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I*RL["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B<F5M
M87)K(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(%)E;6%R:R!P
M87)T(&)E9VEN<PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&UE=&%R
M0V]D92`]("1R96UA<FMS.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'=E871H97)$871A6R)R96UA<FLB72`](&%R<F%Y*"D["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@
M("`@8V%S92`B875T;W-T871I;VXB.@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+R\@5VAI8V@@875T;W-T871I;VX@9&\@=V4@:&%V92!H97)E/PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1R97-U;'1;,5T@/3T@
M,"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W96%T:&5R
M1&%T85LB<F5M87)K(EU;(F%U=&]S=&%T:6]N(ET@/2`B075T;VUA=&EC('=E
M871H97)S=&%T:6]N('<O;R!P<F5C:7!I=&%T:6]N(&1I<V-R:6UI;F%T;W(B
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;(G)E;6%R
M:R)=6R)A=71O<W1A=&EO;B)=(#T@(D%U=&]M871I8R!W96%T:&5R<W1A=&EO
M;B!W+R!P<F5C:7!I=&%T:6]N(&1I<V-R:6UI;F%T;W(B.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@=6YS970H)&UE=&%R0V]D95LB875T;W-T871I;VXB72D["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@
M("`@("`@8V%S92`B<')E<W-C:&<B.@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+R\@1&5C;V1I;F<@9F]R(')A<&ED('!R97-S=7)E(&-H86YG97,*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AS=')T;VQO=V5R*"1R
M97-U;'1;,5TI(#T](")R(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1W96%T:&5R1&%T85LB<F5M87)K(EU;(G!R97-S8VAG(ET@/2`B
M4')E<W-U<F4@<FES:6YG(')A<&ED;'DB.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=V5A=&AE<D1A=&%;(G)E;6%R:R)=6R)P<F5S<V-H9R)=(#T@(E!R
M97-S=7)E(&9A;&QI;F<@<F%P:61L>2(["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D
M;65T87)#;V1E6R)P<F5S<V-H9R)=*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")S
M96%P<F5S<W5R92(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!0
M<F5S<W5R92!A="!S96$@;&5V96P@*&1E;&EV97)E9"!I;B!H<&$I"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`O+R!$96-O9&EN9R!I<R!A(&)I="!O
M8G-C=7)E(&%S(#DX,B!G971S(#DY."XR"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`O+R!W:&5R96%S(#$Q,R!B96-O;65S(#$Q,3,@+3X@;F\@<F5A
M;"!R=6QE(&AE<F4*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AS
M=')T;VQO=V5R*"1R97-U;'1;,5TI("$](")N;R(I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H)')E<W5L=%LQ72`^(#4P,"D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<')E<W,@/2`Y
M,#`@*R!R;W5N9"@D<F5S=6QT6S%=("\@,3`P+"`Q*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<')E<W,@/2`Q,#`P("L@)')E<W5L=%LQ
M73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'=E871H97)$871A6R)R96UA<FLB
M75LB<V5A<')E<W-U<F4B72`]("1T:&ES+3YC;VYV97)T4')E<W-U<F4H)'!R
M97-S+"`B:'!A(BP@(FEN(BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D;65T87)#
M;V1E6R)S96%P<F5S<W5R92)=*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")P<F5C
M:7`B.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@4')E8VEP:71A
M=&EO;B!I;B!I;F-H97,*("`@("`@("`@("`@("`@("`@("`@("`@("`@('-T
M871I8R`D:&]U<G,["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1W96%T:&5R1&%T85LB<')E8VEP:71A=&EO;B)=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W96%T:&5R1&%T85LB<')E
M8VEP:71A=&EO;B)=(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D:&]U<G,@/2!A<G)A>2@B4"(@/3X@(C$B+"`B-B(@/3X@
M(C,O-B(L("(W(B`]/B`B,C0B*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?;G5M
M97)I8R@D<F5S=6QT6S)=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1P<F5C:7`@/2`B:6YD971E<FUI;F%B;&4B.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1R97-U;'1;,ET@/3T@(C`P
M,#`B*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!R96-I
M<"`](")T<F%C96%B;&4B.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?65L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<F5C
M:7`@/2`D<F5S=6QT6S)=("\@,3`P.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=E871H97)$
M871A6R)P<F5C:7!I=&%T:6]N(EU;72`](&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(")A;6]U;G0B(#T^("1P<F5C:7`L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(FAO=7)S(B`@/3X@)&AO=7)S
M6R1R97-U;'1;,5U="B`@("`@("`@("`@("`@("`@("`@("`@("`@("`I.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("`@("`@("`@(&-A<V4@(G-N;W=D97!T:"(Z"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!3;F]W(&1E<'1H(&EN(&EN8VAE<PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'=E871H97)$871A6R)R96UA<FLB75LB
M<VYO=V1E<'1H(ET@/2`D<F5S=6QT6S%=.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@=6YS970H)&UE=&%R0V]D95LB<VYO=V1E<'1H(ETI.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("`@("`@("`@(&-A<V4@(G-N;W=E<75I=B(Z"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!386UE(&9O<B!E<75I=F%L96YT(&EN(%=A=&5R+BXN
M("AI;F-H97,I"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=V5A=&AE
M<D1A=&%;(G)E;6%R:R)=6R)S;F]W97%U:78B72`]("1R97-U;'1;,5T@+R`Q
M,#L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1M971A<D-O
M9&5;(G-N;W=E<75I=B)=*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")C;&]U9'1Y
M<&5S(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O($-L;W5D('1Y
M<&5S+"!H879E;B=T(&9O=6YD(&$@=V%Y(&9O<B!D96-E;G0@9&5C;V1I;F<@
M*'EE="D*("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1M971A
M<D-O9&5;(F-L;W5D='EP97,B72D["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B<W5N
M9'5R871I;VXB.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@1'5R
M871I;VX@;V8@<W5N<VAI;F4@*&EN(&UI;G5T97,I"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;(G)E;6%R:R)=6R)S=6YD=7)A
M=&EO;B)=(#T@(E1O=&%L(&UI;G5T97,@;V8@<W5N<VAI;F4Z("(N)')E<W5L
M=%LQ73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1M971A
M<D-O9&5;(G-U;F1U<F%T:6]N(ETI.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(C%H
M=&5M<&1E=R(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!496UP
M97)A='5R97,@:6X@=&AE(&QA<W0@:&]U<B!I;B!#"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H)')E<W5L=%LQ72`]/2`B,2(I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5S=6QT6S)=("H]("TQ.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'=E871H97)$871A6R)R96UA<FLB75LB,6AT96UP(ET@
M/2`D=&AI<RT^8V]N=F5R=%1E;7!E<F%T=7)E*"1R97-U;'1;,ET@+R`Q,"P@
M(F,B+"`B9B(I.PH*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AS
M:7IE;V8H)')E<W5L="D@/B`S*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+R\@<V%M92!F;W(@9&5W<&]I;G0*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H)')E<W5L=%LT72`]/2`B,2(I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E<W5L=%LU72`J
M/2`M,3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=E871H97)$871A6R)R96UA
M<FLB75LB,6AD97<B72`]("1T:&ES+3YC;VYV97)T5&5M<&5R871U<F4H)')E
M<W5L=%LU72`O(#$P+"`B8R(L(")F(BD["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D
M;65T87)#;V1E6R(Q:'1E;7!D97<B72D["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B
M-FAM87AT96UP(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O($UA
M>"!T96UP97)A='5R92!I;B!T:&4@;&%S="`V(&AO=7)S(&EN($,*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@D<F5S=6QT6S%=(#T]("(Q(BD@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R97-U;'1;,ET@
M*CT@+3$["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;(G)E;6%R:R)=6R(V
M:&UA>'1E;7`B72`]("1T:&ES+3YC;VYV97)T5&5M<&5R871U<F4H)')E<W5L
M=%LR72`O(#$P+"`B8R(L(")F(BD["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!U;G-E="@D;65T87)#;V1E6R(V:&UA>'1E;7`B72D["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@
M("`@("`@8V%S92`B-FAM:6YT96UP(CH*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("\O($UI;B!T96UP97)A='5R92!I;B!T:&4@;&%S="`V(&AO=7)S
M(&EN($,*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D<F5S=6QT
M6S%=(#T]("(Q(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1R97-U;'1;,ET@*CT@+3$["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;
M(G)E;6%R:R)=6R(V:&UI;G1E;7`B72`]("1T:&ES+3YC;VYV97)T5&5M<&5R
M871U<F4H)')E<W5L=%LR72`O(#$P+"`B8R(L(")F(BD["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!U;G-E="@D;65T87)#;V1E6R(V:&UI;G1E;7`B
M72D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@("`@("`@("`@("`@8V%S92`B,C1H=&5M<"(Z"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`O+R!-87@O36EN('1E;7!E<F%T=7)E<R!I;B!T
M:&4@;&%S="`R-"!H;W5R<R!I;B!#"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H)')E<W5L=%LQ72`]/2`B,2(I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<F5S=6QT6S)=("H]("TQ.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'=E871H97)$871A6R)R96UA<FLB75LB,C1H;6%X=&5M<")=(#T@)'1H
M:7,M/F-O;G9E<G1496UP97)A='5R92@D<F5S=6QT6S)=("\@,3`L(")C(BP@
M(F8B*3L*"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)')E<W5L
M=%LS72`]/2`B,2(I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<F5S=6QT6S1=("H]("TQ.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=E871H97)$871A
M6R)R96UA<FLB75LB,C1H;6EN=&5M<")=(#T@)'1H:7,M/F-O;G9E<G1496UP
M97)A='5R92@D<F5S=6QT6S1=("\@,3`L(")C(BP@(F8B*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('5N<V5T*"1M971A<D-O9&5;(C(T:'1E;7`B
M72D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@("`@("`@("`@("`@8V%S92`B,VAP<F5S<W1E;F0B.@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@+R\@5V4@9&]N)W0@<V%V92!T:&4@<')E
M<W-U<F4@9'5R:6YG('1H92!D87DL('-O(&YO(&1E8V]D:6YG"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`O+R!P;W-S:6)L92P@<V]R<GD*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1M971A<D-O9&5;(C-H<')E
M<W-T96YD(ETI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(FYO<W!E8VDB.@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@+R\@3F\@8VAA;F=E(&1U<FEN9R!T
M:&4@;&%S="!H;W5R"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=V5A
M=&AE<D1A=&%;(G)E;6%R:R)=6R)N;W-P96-I(ET@/2`B3F\@8VAA;F=E<R!I
M;B!W96%T:&5R(&-O;F1I=&EO;G,B.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@=6YS970H)&UE=&%R0V]D95LB;F]S<&5C:2)=*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@
M("`@("!C87-E(")S96YS;W)S(CH*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("\O(%=E(&UA>2!H879E(&UU;'1I<&QE(&)R;VME;B!S96YS;W)S+"!S
M;R!D;R!N;W0@=6YS970*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)'=E871H97)$871A6R)R96UA<FLB75LB<V5N<V]R<R)=*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W96%T:&5R1&%T
M85LB<F5M87)K(EU;(G-E;G-O<G,B72`](&%R<F%Y*"D["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=V5A=&AE<D1A=&%;(G)E;6%R:R)=6R)S96YS;W)S(EU;<W1R=&]L;W=E
M<B@D<F5S=6QT6S!=*5T@/2`D<V5N<V]R<UMS=')T;VQO=V5R*"1R97-U;'1;
M,%TI73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@("`@("`@("!C87-E(")M86EN=&%I;B(Z"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;(G)E;6%R:R)=6R)M
M86EN=&%I;B)=(#T@(DUA:6YT86EN86YC92!N965D960B.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@=6YS970H)&UE=&%R0V]D95LB;6%I;G1A:6XB
M72D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("\O($1O(&YO=&AI;F<L(&IU<W0@<')E=F5N="!F=7)T:&5R
M(&UA=&-H:6YG"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D
M;65T87)#;V1E6R1K97E=*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!I9B`H)&9O=6YD("8F("%315)624-%4U]714%42$527T1%0E5'*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@("`@('T@96QS96EF("@D9F]U;F0@)B8@4T525DE#15-?5T5!5$A%4E]$
M14)51RD@>PH@("`@("`@("`@("`@("`@("`@("`@("!E8VAO("1K97DN(EQN
M(CL*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&EF("@A)&9O=6YD*2!["B`@("`@("`@("`@("`@("!I9B`H
M4T525DE#15-?5T5!5$A%4E]$14)51RD@>PH@("`@("`@("`@("`@("`@("`@
M(&5C:&\@(FXO85QN(CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(&EF("@A:7-S970H)'=E871H97)$871A6R)N;W!A<G-E(ETI*2!["B`@
M("`@("`@("`@("`@("`@("`@)'=E871H97)$871A6R)N;W!A<G-E(ET@/2!A
M<G)A>2@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'=E
M871H97)$871A6R)N;W!A<G-E(EU;72`]("1M971A<ELD:5T["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D=V5A=&AE<D1A
M=&%;(FYO<&%R<V4B72DI('L*("`@("`@("`@("`@)'=E871H97)$871A6R)N
M;W!A<G-E(ET@/2!I;7!L;V1E*"(@(BP@("1W96%T:&5R1&%T85LB;F]P87)S
M92)=*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=V5A=&AE<D1A=&$[
M"B`@("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@7W!A<G-E1F]R96-A<W1$
M871A*"D*("`@("\J*@H@("`@("H@4&%R<V5S('1H92!D871A(&%N9"!C86-H
M97,@:70*("`@("`J"B`@("`@*B!4048@2TQ'02`R-S$W,S1:(#(W,3@Q."`Q
M,3`P-TM4(%`V4TT@+5)!(%-#5#`R,"!"2TXR,#`*("`@("`J("`@("!&33(S
M,#`@,30P,#=+5"!0-E--(%-#5#`S,"!"2TXQ-3`*("`@("`J("`@("!&33`T
M,#`@5E)",#-+5"!0-E--(%-#5#`S-2!/5D,P.#`@4%)/0C,P(#`U,#D@4#93
M32`M4D$@0DM.,#,U"B`@("`@*B`@("`@1DTP.3`P(%920C`S2U0@-E--("U2
M02!"4B!30U0P,34@3U9#,#,U"B`@("`@*B`@("`@("`@(%1%35!/(#$R,34@
M-5--("U202!"4B!30U0P,#D@0DM.,#$U"B`@("`@*B`@("`@("`@($)%0TU'
M(#$U,3<@,38P,#=+5"!0-E--($Y35R!30U0P,34@0DM.,#<P"B`@("`@*@H@
M("`@("H@0'!A<F%M("`@87)R87D@("`@("`@("`@("`@("`@("`@("`@("1D
M871A"B`@("`@*B!`<F5T=7)N("!014%27T5R<F]R?&%R<F%Y"B`@("`@*B!`
M=&AR;W=S("!014%27T5R<F]R.CI315)624-%4U]714%42$527T524D]27U=2
M3TY'7U-%4E9%4E]$051!"B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R.CI3
M15)624-%4U]714%42$527T524D]27U5.2TY/5TY?3$]#051)3TX*("`@("`J
M($!A8V-E<W,@('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7W!A<G-E
M1F]R96-A<W1$871A*"1D871A*0H@("`@>PH@("`@("`@('-T871I8R`D8V]M
M<&%S<SL*("`@("`@("!S=&%T:6,@)&-L;W5D<SL*("`@("`@("!S=&%T:6,@
M)&-O;F1I=&EO;G,["B`@("`@("`@<W1A=&EC("1S96YS;W)S.PH@("`@("`@
M(&EF("@A:7-S970H)&-O;7!A<W,I*2!["B`@("`@("`@("`@("1C;VUP87-S
M(#T@87)R87DH"B`@("`@("`@("`@("`@("`B3B(L(").3D4B+"`B3D4B+"`B
M14Y%(BP*("`@("`@("`@("`@("`@(")%(BP@(D5312(L(")312(L(")34T4B
M+`H@("`@("`@("`@("`@("`@(E,B+"`B4U-7(BP@(E-7(BP@(E=35R(L"B`@
M("`@("`@("`@("`@("`B5R(L(")73E<B+"`B3E<B+"`B3DY7(@H@("`@("`@
M("`@("`I.PH@("`@("`@("`@("`D8VQO=61S("`@(#T@87)R87DH"B`@("`@
M("`@("`@("`@("`B<VMC(B`@("`@("`@(#T^(")S:WD@8VQE87(B+`H@("`@
M("`@("`@("`@("`@(FYS8R(@("`@("`@("`]/B`B;F\@<VEG;FEF:6-A;G0@
M8VQO=60B+`H@("`@("`@("`@("`@("`@(F9E=R(@("`@("`@("`]/B`B9F5W
M(BP*("`@("`@("`@("`@("`@(")S8W0B("`@("`@("`@/3X@(G-C871T97)E
M9"(L"B`@("`@("`@("`@("`@("`B8FMN(B`@("`@("`@(#T^(")B<F]K96XB
M+`H@("`@("`@("`@("`@("`@(F]V8R(@("`@("`@("`]/B`B;W9E<F-A<W0B
M+`H@("`@("`@("`@("`@("`@(G9V(B`@("`@("`@("`]/B`B=F5R=&EC86P@
M=FES:6)I;&ET>2(L"B`@("`@("`@("`@("`@("`B=&-U(B`@("`@("`@(#T^
M(")4;W=E<FEN9R!#=6UU;'5S(BP*("`@("`@("`@("`@("`@(")C8B(@("`@
M("`@("`@/3X@(D-U;75L;VYI;6)U<R(L"B`@("`@("`@("`@("`@("`B8VQR
M(B`@("`@("`@(#T^(")C;&5A<B!B96QO=R`Q,BPP,#`@9G0B"B`@("`@("`@
M("`@("D["B`@("`@("`@("`@("1C;VYD:71I;VYS(#T@87)R87DH"B`@("`@
M("`@("`@("`@("`B*R(@("`@("`@("`@(#T^(")H96%V>2(L("`@("`@("`B
M+2(@("`@("`@("`@(#T^(")L:6=H="(L"@H@("`@("`@("`@("`@("`@(G9C
M(B`@("`@("`@("`]/B`B=FEC:6YI='DB+"`@("`@(G)E(B`@("`@("`@("`]
M/B`B<F5C96YT(BP*("`@("`@("`@("`@("`@(")N<W<B("`@("`@("`@/3X@
M(FYO('-I9VYI9FEC86YT('=E871H97(B+`H*("`@("`@("`@("`@("`@(")M
M:2(@("`@("`@("`@/3X@(G-H86QL;W<B+"`@("`@(")B8R(@("`@("`@("`@
M/3X@(G!A=&-H97,B+`H@("`@("`@("`@("`@("`@(G!R(B`@("`@("`@("`]
M/B`B<&%R=&EA;"(L("`@("`@(G1S(B`@("`@("`@("`]/B`B=&AU;F1E<G-T
M;W)M(BP*("`@("`@("`@("`@("`@(")B;"(@("`@("`@("`@/3X@(F)L;W=I
M;F<B+"`@("`@(")S:"(@("`@("`@("`@/3X@(G-H;W=E<G,B+`H@("`@("`@
M("`@("`@("`@(F1R(B`@("`@("`@("`]/B`B;&]W(&1R:69T:6YG(BP@(F9Z
M(B`@("`@("`@("`]/B`B9G)E97II;F<B+`H*("`@("`@("`@("`@("`@(")D
M>B(@("`@("`@("`@/3X@(F1R:7IZ;&4B+"`@("`@(")R82(@("`@("`@("`@
M/3X@(G)A:6XB+`H@("`@("`@("`@("`@("`@(G-N(B`@("`@("`@("`]/B`B
M<VYO=R(L("`@("`@("`@(G-G(B`@("`@("`@("`]/B`B<VYO=R!G<F%I;G,B
M+`H@("`@("`@("`@("`@("`@(FEC(B`@("`@("`@("`]/B`B:6-E(&-R>7-T
M86QS(BP@(G!E(B`@("`@("`@("`]/B`B:6-E('!E;&QE=',B+`H@("`@("`@
M("`@("`@("`@(F=R(B`@("`@("`@("`]/B`B:&%I;"(L("`@("`@("`@(F=S
M(B`@("`@("`@("`]/B`B<VUA;&P@:&%I;"]S;F]W('!E;&QE=',B+`H@("`@
M("`@("`@("`@("`@(G5P(B`@("`@("`@("`]/B`B=6YK;F]W;B!P<F5C:7!I
M=&%T:6]N(BP*"B`@("`@("`@("`@("`@("`B8G(B("`@("`@("`@(#T^(")M
M:7-T(BP@("`@("`@("`B9F<B("`@("`@("`@(#T^(")F;V<B+`H@("`@("`@
M("`@("`@("`@(F9U(B`@("`@("`@("`]/B`B<VUO:V4B+"`@("`@("`@(G9A
M(B`@("`@("`@("`]/B`B=F]L8V%N:6,@87-H(BP*("`@("`@("`@("`@("`@
M(")S82(@("`@("`@("`@/3X@(G-A;F0B+"`@("`@("`@(")H>B(@("`@("`@
M("`@/3X@(FAA>F4B+`H@("`@("`@("`@("`@("`@(G!Y(B`@("`@("`@("`]
M/B`B<W!R87DB+"`@("`@("`@(F1U(B`@("`@("`@("`]/B`B=VED97-P<F5A
M9"!D=7-T(BP*"B`@("`@("`@("`@("`@("`B<W$B("`@("`@("`@(#T^(")S
M<75A;&PB+"`@("`@("`B<W,B("`@("`@("`@(#T^(")S86YD<W1O<FTB+`H@
M("`@("`@("`@("`@("`@(F1S(B`@("`@("`@("`]/B`B9'5S='-T;W)M(BP@
M("`@(G!O(B`@("`@("`@("`]/B`B=V5L;"!D979E;&]P960@9'5S="]S86YD
M('=H:7)L<R(L"B`@("`@("`@("`@("`@("`B9F,B("`@("`@("`@(#T^(")F
M=6YN96P@8VQO=60B+`H*("`@("`@("`@("`@("`@("(K9F,B("`@("`@("`@
M/3X@(G1O<FYA9&\O=V%T97)S<&]U="(*("`@("`@("`@("`@*3L*("`@("`@
M("!]"@H@("`@("`@("1T869#;V1E(#T@87)R87DH"B`@("`@("`@("`@(")R
M97!O<G0B("`@("`@/3X@(E1!1GQ!340B+`H@("`@("`@("`@("`B<W1A=&EO
M;B(@("`@(#T^(")<=WLT?2(L"B`@("`@("`@("`@(")U<&1A=&4B("`@("`@
M/3X@(BA<9'LR?2D_*%QD>S1]*5HB+`H@("`@("`@("`@("`B=F%L:60B("`@
M("`@(#T^("(H7&1[,GTI*%QD>S)]*2A<9'LR?2DB+`H@("`@("`@("`@("`B
M=VEN9"(@("`@("`@(#T^("(H7&1[,WU\5D%2?%920BDH7&1[,BPS?2DH1RA<
M9'LR?2DI/RA<=WLR+#-]*2(L"B`@("`@("`@("`@(")V:7-&<F%C(B`@("`@
M/3X@(BA<9'LQ?2DB+`H@("`@("`@("`@("`B=FES:6)I;&ET>2(@(#T^("(H
M7&1[-'TI?"@H37Q0*3\H*%QD>S$L,GU\*"A<9"D@*3\H7&0I7"\H7&0I*2A3
M37Q+32DI*7PH0T%63TLI(BP*("`@("`@("`@("`@(F-O;F1I=&EO;B(@("`]
M/B`B*"U\7"M\5D-\4D5\3E-7*3\H34E\0D-\4%)\5%-\0DQ\4TA\1%)\1EHI
M/R@H1%HI?"A202E\*%-.*7PH4T<I?"A)0RE\*%!,*7PH1U(I?"A'4RE\*%50
M*2DJ*$)2?$9'?$95?%9!?$15?%-!?$A:?%!9*3\H4$]\4U%\1D-\4U-\1%,I
M/R(L"B`@("`@("`@("`@(")C;&]U9',B("`@("`@/3X@(BA32T-\0TQ2?$Y3
M0WPH*$9%5WQ30U1\0DM.?$]60WQ65BDH7&1[,WTI*%1#57Q#0BD_*2DB+`H@
M("`@("`@("`@("`B=VEN9'-H96%R(B`@(#T^(")74RA<9'LS?2E<+RA<9'LS
M?2DH7&1[,BPS?2DH7'=[,BPS?2DB+`H@("`@("`@("`@("`B=&5M<&UA>"(@
M("`@(#T^(")46"A<9'LR?2E<+RA<9'LR?2DH7'<I(BP*("`@("`@("`@("`@
M(G1E;7!M:6XB("`@("`]/B`B5$XH7&1[,GTI7"\H7&1[,GTI*%QW*2(L"B`@
M("`@("`@("`@(")T96UP;6%X;6EN(B`@/3X@(E18*%QD>S)]*5PO*%QD>S)]
M*2A<=RE43BA<9'LR?2E<+RA<9'LR?2DH7'<I(BP*("`@("`@("`@("`@(F9R
M;VTB("`@("`@("`]/B`B1DTH7&1[,GTI*%QD>S)]*3\B+`H@("`@("`@("`@
M("`B9FUC(B`@("`@("`@(#T^("(H4%)/0GQ"14--1WQ414U03RDH7&1[,GTI
M/R(*("`@("`@("`I.PH*("`@("`@("!I9B`H4T525DE#15-?5T5!5$A%4E]$
M14)51RD@>PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H
M)&1A=&$I.R`D:2LK*2!["B`@("`@("`@("`@("`@("!E8VAO("1D871A6R1I
M73L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`O+R!/:RP@=V4@
M:&%V92!C;W)R96-T(&1A=&$L('-T87)T('=I=&@@<&%R<VEN9R!T:&4@9FER
M<W0@;&EN92!F;W(@=&AE(&QA<W0@=7!D871E"B`@("`@("`@)&9O<F5C87-T
M1&%T82`](&%R<F%Y*"D["B`@("`@("`@)&9O<F5C87-T1&%T85LB<W1A=&EO
M;B)=("`@/2`B(CL*("`@("`@("`D9F]R96-A<W1$871A6R)D871A4F%W(ET@
M("`](&EM<&QO9&4H(B`B+"`D9&%T82D["B`@("`@("`@)&9O<F5C87-T1&%T
M85LB=7!D871E(ET@("`@/2!S=')T;W1I;64H=')I;2@D9&%T85LP72DN(B!'
M350B*3L*("`@("`@("`D9F]R96-A<W1$871A6R)U<&1A=&5287<B72`]('1R
M:6TH)&1A=&%;,%TI.PH@("`@("`@("\O(&%N9"!P<F5P87)E('1H92!R97-T
M(&9O<B!S=&5P<&EN9R!T:')O=6=H"B`@("`@("`@87)R87E?<VAI9G0H)&1A
M=&$I.PH@("`@("`@("1T868@/2!E>'!L;V1E*"(@(BP@<')E9U]R97!L86-E
M*"(O7'-[,BQ]+R(L("(@(BP@:6UP;&]D92@B("(L("1D871A*2DI.PH*("`@
M("`@("`O+R!!9&0@82!F97<@;&]C86P@=F%R:6%B;&5S(&9O<B!D871A('!R
M;V-E<W-I;F<*("`@("`@("`D9G)O;51I;64@/2`@(B([("`@("`@("`@("`@
M+R\@5&AE('1I;65P97)I;V0@=&AE(&1A=&$@9V5T<R!A9&1E9"!T;PH@("`@
M("`@("1F;6-#;W5N="`]("`P.R`@("`@("`@("`@("`O+R!)9B!W92!H879E
M($9-0W,@*$9O<F5C87-T($UE=&5O<F]L;V=I8V%L($-O;F1I=&EO;G,I+"!W
M92!N965D('1H:7,*("`@("`@("`D<&]I;G1E<B`@/28@)&9O<F5C87-T1&%T
M83L@+R\@4&]I;G1E<B!T;R!T:&4@87)R87D@=V4@861D('1H92!D871A('1O
M"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F*"1T868I.R`D:2LK
M*2!["B`@("`@("`@("`@("\O($-H96-K(&9O<B!W:&ET97-P86-E(&%N9"!S
M=&5P(&QO;W`L(&EF(&YO=&AI;F<G<R!T:&5R90H@("`@("`@("`@("`D=&%F
M6R1I72`]('1R:6TH)'1A9ELD:5TI.PH@("`@("`@("`@("!I9B`H(7-T<FQE
M;B@D=&%F6R1I72DI('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!I9B`H4T525DE#15-?5T5!5$A%4E]$
M14)51RD@>PH@("`@("`@("`@("`@("`@)'1A8B`]('-T<E]R97!E870H(EQT
M(BP@,B`M(&9L;V]R*"AS=')L96XH)'1A9ELD:5TI("L@,BD@+R`X*2D["B`@
M("`@("`@("`@("`@("!E8VAO(")<(B(N)'1A9ELD:5TN(EPB(BXD=&%B+B(M
M/B`B.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!);FET:6%L:7IE
M('-O;64@87)R87ES"B`@("`@("`@("`@("1R97-U;'0@("`](&%R<F%Y*"D[
M"B`@("`@("`@("`@("1R97-U;'161B`](&%R<F%Y*"D["B`@("`@("`@("`@
M("1L<F5S=6QT("`](&%R<F%Y*"D["@H@("`@("`@("`@("`D9F]U;F0@/2!F
M86QS93L*("`@("`@("`@("`@9F]R96%C:"`H)'1A9D-O9&4@87,@)&ME>2`]
M/B`D<F5G97AP*2!["B`@("`@("`@("`@("`@("`O+R!#:&5C:R!I9B!C=7)R
M96YT(&-O9&4@;6%T8VAE<R!C=7)R96YT('1A9B!S;FEP<&5T"B`@("`@("`@
M("`@("`@("!I9B`H*"1F;W5N9"`]('!R96=?;6%T8V@H(B]>(BXD<F5G97AP
M+B(D+VDB+"`D=&%F6R1I72P@)')E<W5L="DI(#T]('1R=64I('L*("`@("`@
M("`@("`@("`@("`@("`D:6YS97)T(#T@87)R87DH*3L*("`@("`@("`@("`@
M("`@("`@("!S=VET8V@@*"1K97DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@8V%S92`B<W1A=&EO;B(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<&]I;G1E<ELB<W1A=&EO;B)=(#T@)')E<W5L=%LP73L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('5N<V5T*"1T869#;V1E6R)S=&%T:6]N(ETI
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@("`@("`@("`@("`@(&-A<V4@(G9A;&ED(CH*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1P;VEN=&5R6R)V86QI9%)A=R)=(#T@)')E<W5L=%LP
M73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O($=E;F5R871E<R!T
M:&4@=&EM97!E<FEO9"!T:&4@<F5P;W)T(&ES('9A;&ED(&9O<@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@;&ES="@D>65A<BP@)&UO;G1H+"`D9&%Y
M*2`](&5X<&QO9&4H(BTB+"!D871E*")9+6TM9"(L("1F;W)E8V%S=$1A=&%;
M(G5P9&%T92)=*2D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!$
M871E(&ES(&EN(&YE>'0@;6]N=&@*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@D<F5S=6QT6S%=(#P@)&1A>2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1M;VYT:"LK.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT
M97);(G9A;&ED1G)O;2)=(#T@9VUM:W1I;64H)')E<W5L=%LR72P@,"P@,"P@
M)&UO;G1H+"`D<F5S=6QT6S%=+"`D>65A<BD["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!686QI9"!T:6UE(&5N9',@;F5X="!D87D*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@D<F5S=6QT6S)=(#X]("1R97-U
M;'1;,UTI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5S
M=6QT6S%=*RL["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB=F%L:614;R)=("`@
M/2!G;6UK=&EM92@D<F5S=6QT6S-=+"`P+"`P+"`D;6]N=&@L("1R97-U;'1;
M,5TL("1Y96%R*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T
M*"1T869#;V1E6R)V86QI9")=*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("\O($YO=R!T:&4@9W)O=7!S('=I;&P@<W1A<G0L('-O(&EN:71I86QI
M>F4@=&AE('1I;64@9W)O=7!S"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<&]I;G1E<ELB=&EM92)=(#T@87)R87DH*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1F<F]M5&EM92`]("1R97-U;'1;,ETN(CHP,"(["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB=&EM92)=6R1F
M<F]M5&EM95T@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+R\@4V5T('!O:6YT97(@=&\@=&AE(&9I<G-T('1I;65P97)I;V0*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R(#TF("1P;VEN=&5R
M6R)T:6UE(EU;)&9R;VU4:6UE73L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")W:6YD
M(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(%!A<G-E('=I;F0@
M9&%T82P@9FER<W0@=&AE('-P965D+"!C;VYV97)T(&9R;VT@:W0@=&\@8VAO
M<V5N('5N:70*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R
M6R)W:6YD(ET@/2`D=&AI<RT^8V]N=F5R=%-P965D*"1R97-U;'1;,ETL('-T
M<G1O;&]W97(H)')E<W5L=%LU72DL(")M<&@B*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("@D<F5S=6QT6S%=(#T](")605(B('Q\("1R97-U
M;'1;,5T@/3T@(E920B(I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`O+R!687)I86)L92!W:6YD<PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1P;VEN=&5R6R)W:6YD1&5G<F5E<R)=("`@/2`B5F%R:6%B
M;&4B.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R
M6R)W:6YD1&ER96-T:6]N(ET@/2`B5F%R:6%B;&4B.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!3879E('=I;F0@9&5G<F5E(&%N9"!C86QC(&1I<F5C
M=&EO;@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R
M6R)W:6YD1&5G<F5E<R)=("`@/2`D<F5S=6QT6S%=.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)W:6YD1&ER96-T:6]N(ET@
M/2`D8V]M<&%S<UMR;W5N9"@D<F5S=6QT6S%=("\@,C(N-2D@)2`Q-ET["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-?;G5M97)I8R@D<F5S=6QT6S1=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(%=I;F0@=VET:"!G=7-T
M<RXN+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R
M6R)W:6YD1W5S=")=(#T@)'1H:7,M/F-O;G9E<G13<&5E9"@D<F5S=6QT6S1=
M+"!S=')T;VQO=V5R*"1R97-U;'1;-5TI+"`B;7!H(BD["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)'!R;V)A8FEL:71Y*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P;VEN=&5R6R)W:6YD4')O8B)=(#T@)'!R;V)A
M8FEL:71Y.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T
M*"1P<F]B86)I;&ET>2D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@("`@("`@("`@8V%S92`B=FES1G)A8R(Z"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!0;W-S:6)L92!F<F%C=&EO;F%L('9I<VEB:6QI
M='D@:&5R92X@0VAE8VL@:68@:70@;6%T8VAE<R!W:71H('1H92!N97AT(%1!
M1B!P:65C92!F;W(@=FES:6)I;&ET>0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D=&%F6R1I("L@,5TI('Q\("%P<F5G7VUA=&-H
M*"(O7B(N)'1A9D-O9&5;(G9I<VEB:6QI='DB72XB)"]I(BP@)')E<W5L=%LQ
M72XB("(N)'1A9ELD:2`K(#%=+"`D<F5S=6QT5D8I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@+R\@3F\@;F5X="!4048@<&EE8V4@879A
M:6QA8FQE(&]R(&YO="!M871C:&EN9RX@36%T8V@@86=A:6YS="!N97AT(%1!
M1B!C;V1E"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O=6YD
M(#T@9F%L<V4["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O($UA=&-H+B!(86YD(&]V
M97(@<F5S=6QT(&%N9"!A9'9A;F-E(%1!1@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("A315)624-%4U]714%42$527T1%0E5'*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&5C:&\@)&ME>2XB
M7&XB.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!E8VAO
M(")<(B(N)')E<W5L=%LQ72XB("(N)'1A9ELD:2`K(#%=+B)<(B(N<W1R7W)E
M<&5A="@B7'0B+"`R("T@9FQO;W(H*'-T<FQE;B@D<F5S=6QT6S%=+B(@(BXD
M=&%F6R1I("L@,5TI("L@,BD@+R`X*2DN(BT^("(["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1K97D@/2`B=FES:6)I;&ET>2(["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)')E<W5L="`]("1R97-U;'161CL*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D:2LK.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")V
M:7-I8FEL:71Y(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN
M=&5R6R)V:7-1=6%L:69I97(B72`](")!5"(["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-?;G5M97)I8R@D<F5S=6QT6S%=*2`F)B`H)')E
M<W5L=%LQ72`]/2`Y.3DY*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("\O(%5P<&5R(&QI;6ET(&]F('9I<VEB:6QI='D@<F%N9V4*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=FES:6)I;&ET>2`]("1T
M:&ES+3YC;VYV97)T1&ES=&%N8V4H,3`L(")K;2(L(")S;2(I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)V:7-1=6%L:69I
M97(B72`](")"15E/3D0B.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E:68@*&ES7VYU;65R:6,H)')E<W5L=%LQ72DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`O+R`T+61I9VET('9I<VEB:6QI='D@
M:6X@;0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V:7-I8FEL
M:71Y(#T@)'1H:7,M/F-O;G9E<G1$:7-T86YC92@H)')E<W5L=%LQ72\Q,#`P
M*2P@(FMM(BP@(G-M(BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M(&5L<V5I9B`H(6ES<V5T*"1R97-U;'1;,3%=*2!\?"`D<F5S=6QT6S$Q72`A
M/2`B0T%63TLB*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"1R97-U;'1;,UT@/3T@(DTB*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P;VEN=&5R6R)V:7-1=6%L:69I97(B72`](")"
M14Q/5R(["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M:68@*"1R97-U;'1;,UT@/3T@(E`B*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P;VEN=&5R6R)V:7-1=6%L:69I97(B72`](")"
M15E/3D0B.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-?;G5M97)I8R@D
M<F5S=6QT6S5=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`O+R!V:7-I8FEL:71Y(&%S(&]N92]T=V\M9&EG:70@;G5M8F5R"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V:7-I8FEL:71Y
M(#T@)'1H:7,M/F-O;G9E<G1$:7-T86YC92@D<F5S=6QT6S5=+"`D<F5S=6QT
M6S$P72P@(G-M(BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+R\@=&AE('DO>B!P87)T+"!A9&0@:68@=V4@:&%D(&$@>"!P87)T("AS964@
M=FES:6)I;&ET>3$I"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("AI<U]N=6UE<FEC*"1R97-U;'1;-UTI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=FES:6)I;&ET>2`]("1T
M:&ES+3YC;VYV97)T1&ES=&%N8V4H)')E<W5L=%LW72`K("1R97-U;'1;.%T@
M+R`D<F5S=6QT6SE=+"`D<F5S=6QT6S$P72P@(G-M(BD["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=FES:6)I;&ET>2`]("1T
M:&ES+3YC;VYV97)T1&ES=&%N8V4H)')E<W5L=%LX72`O("1R97-U;'1;.5TL
M("1R97-U;'1;,3!=+"`B<VTB*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(G9I<U%U86QI
M9FEE<B)=(#T@(D)%64].1"(["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'9I<VEB:6QI='D@/2`D=&AI<RT^8V]N=F5R=$1I<W1A;F-E*#$P
M+"`B:VTB+"`B<VTB*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<&]I;G1E<ELB8VQO=61S(ET@/2!A<G)A>2AA<G)A>2@B86UO=6YT(B`]
M/B`B0VQE87(@8F5L;W<B+"`B:&5I9VAT(B`]/B`U,#`P*2D["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(F-O;F1I=&EO;B)=
M(#T@(FYO('-I9VYI9FEC86YT('=E871H97(B.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1P<F]B86)I;&ET>2DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<&]I;G1E<ELB=FES4')O8B)=(#T@)'!R;V)A8FEL:71Y
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1P<F]B
M86)I;&ET>2D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB=FES:6)I;&ET>2)=
M(#T@)'9I<VEB:6QI='D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B8V]N9&ET:6]N
M(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O($9I<G-T('-O;64@
M8F%S:6,@<V5T=7!S"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1P;VEN=&5R6R)C;VYD:71I;VXB72DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB8V]N9&ET:6]N(ET@/2`B
M(CL*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF("AS=')L
M96XH)'!O:6YT97);(F-O;F1I=&EO;B)=*2`^(#`I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB8V]N9&ET:6]N(ET@+CT@
M(BPB.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AI;E]A<G)A>2AS=')T;VQO=V5R*"1R
M97-U;'1;,%TI+"`D8V]N9&ET:6]N<RDI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!&:7)S="!T<GD@;6%T8VAI;F<@=&AE(&-O;7!L
M971E('-T<FEN9PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P
M;VEN=&5R6R)C;VYD:71I;VXB72`N/2`B("(N)&-O;F1I=&EO;G-;<W1R=&]L
M;W=E<B@D<F5S=6QT6S!=*5T["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O
M($YO(&QU8VLL(&UA=&-H('!A<G0@8GD@<&%R=`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y7W-H:69T*"1R97-U;'0I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1R97-U;'0@/2!A<G)A>5]U;FEQ
M=64H)')E<W5L="D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)')E<W5L="!A<R`D8V]N9&ET:6]N*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AS=')L96XH)&-O;F1I=&EO
M;BD@/B`P*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<&]I;G1E<ELB8V]N9&ET:6]N(ET@+CT@(B`B+B1C;VYD:71I;VYS
M6W-T<G1O;&]W97(H)&-O;F1I=&EO;BE=.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(F-O;F1I=&EO;B)=(#T@
M=')I;2@D<&]I;G1E<ELB8V]N9&ET:6]N(ETI.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1P<F]B86)I;&ET>2DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB8V]N9&ET:6]N
M(ET@+CT@(B`H(BXD<')O8F%B:6QI='DN(B4@<')O8BXI(CL*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D<')O8F%B:6QI='DI.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A
M<V4@(F-L;W5D<R(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1P;VEN=&5R6R)C;&]U9',B72DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB8VQO=61S(ET@/2!A<G)A>2@I
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("AS:7IE;V8H)')E<W5L="D@/3T@-2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O($]N;'D@86UO=6YT
M(&%N9"!H96EG:'0*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M8VQO=60@/2!A<G)A>2@B86UO=6YT(B`]/B`D8VQO=61S6W-T<G1O;&]W97(H
M)')E<W5L=%LS72E=+"`B:&5I9VAT(B`]/B`H)')E<W5L=%LT72`J(#$P,"DI
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@96QS96EF("AS:7IE;V8H)')E<W5L="D@/3T@-BD@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O($%M;W5N="P@
M:&5I9VAT(&%N9"!T>7!E"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&-L;W5D(#T@87)R87DH(F%M;W5N="(@/3X@)&-L;W5D<UMS=')T;VQO
M=V5R*"1R97-U;'1;,UTI72P@(FAE:6=H="(@/3X@*"1R97-U;'1;-%T@*B`Q
M,#`I+"`B='EP92(@/3X@)&-L;W5D<UMS=')T;VQO=V5R*"1R97-U;'1;-5TI
M72D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!32T,@;W(@0TQ2(&]R($Y30PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1C;&]U9"`](&%R<F%Y*")A;6]U;G0B(#T^
M("1C;&]U9'-;<W1R=&]L;W=E<B@D<F5S=6QT6S!=*5TI.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:68H:7-S970H)'!R;V)A8FEL:71Y*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1C;&]U9%LB<')O8B)=(#T@)'!R;V)A8FEL:71Y
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1P<F]B
M86)I;&ET>2D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB8VQO=61S(EU;72`]
M("1C;&]U9#L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@("`@("`@("!C87-E(")W:6YD<VAE87(B.@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@+R\@4&%R<V4@=VEN9'-H96%R+"!I
M9B!A=F%I;&%B;&4*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN
M=&5R6R)W:6YD<VAE87(B72`@("`@("`@("`]("1T:&ES+3YC;VYV97)T4W!E
M960H)')E<W5L=%LS72P@<W1R=&]L;W=E<B@D<F5S=6QT6S1=*2P@(FUP:"(I
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(G=I;F1S
M:&5A<DAE:6=H=")=("`@(#T@)')E<W5L=%LQ72`J(#$P,#L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)W:6YD<VAE87)$96=R965S
M(ET@("`]("1R97-U;'1;,ET["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<&]I;G1E<ELB=VEN9'-H96%R1&ER96-T:6]N(ET@/2`D8V]M<&%S<UMR
M;W5N9"@D<F5S=6QT6S)=("\@,C(N-2D@)2`Q-ET["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@
M8V%S92`B=&5M<&UA>"(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M9F]R96-A<W1$871A6R)T96UP97)A='5R94AI9V@B72`]("1T:&ES+3YC;VYV
M97)T5&5M<&5R871U<F4H)')E<W5L=%LQ72P@(F,B+"`B9B(I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@
M("`@("`@(&-A<V4@(G1E;7!M:6XB.@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+R\@4&%R<V4@;6%X+VUI;B!T96UP97)A='5R90H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&9O<F5C87-T1&%T85LB=&5M<&5R871U<F5,
M;W<B72`@/2`D=&AI<RT^8V]N=F5R=%1E;7!E<F%T=7)E*"1R97-U;'1;,5TL
M(")C(BP@(F8B*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")T96UP;6%X;6EN(CH*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F;W)E8V%S=$1A=&%;(G1E
M;7!E<F%T=7)E2&EG:")=(#T@)'1H:7,M/F-O;G9E<G1496UP97)A='5R92@D
M<F5S=6QT6S%=+"`B8R(L(")F(BD["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D9F]R96-A<W1$871A6R)T96UP97)A='5R94QO=R)=("`]("1T:&ES
M+3YC;VYV97)T5&5M<&5R871U<F4H)')E<W5L=%LT72P@(F,B+"`B9B(I.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("`@("`@("`@(&-A<V4@(F9R;VTB.@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+R\@3F5X="!T:6UE<&5R:6]D(&ES(&-O;6EN9R!U<"P@<')E
M<&%R92!A<G)A>2!A;F0*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O
M('-E="!P;VEN=&5R(&%C8V]R9&EN9VQY"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H<VEZ96]F*"1R97-U;'0I(#X@,BD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("\O(%1H92!)0T%/('=A>0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1F<F]M5&EM92`]("1R97-U;'1;
M,5TN(CHB+B1R97-U;'1;,ET["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O
M(%1H92!!=7-T<F%L:6%N('=A>2`H2&5Y(&UA=&5S(2D*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9G)O;51I;64@/2`D<F5S=6QT6S%=+B(Z
M,#`B.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&9O<F5C87-T1&%T85LB=&EM92)=6R1F<F]M
M5&EM95T@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&9M8T-O=6YT(#T@,#L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P
M;VEN=&5R(#TF("1F;W)E8V%S=$1A=&%;(G1I;64B75LD9G)O;51I;65=.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("`@("`@("`@(&-A<V4@(F9M8R(["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`O+R!497-T+"!I9B!T:&ES(&ES(&$@<')O8F%B:6QI='D@9F]R
M('1H92!N97AT($9-0PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*'!R96=?;6%T8V@H(B]>0D5#34=\5$5-4$\D+VDB+"`D=&%F6R1I("L@,5TL
M("1L<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("\O(%-E="!T>7!E('1O($)%0TU'(&]R(%1%35!/"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1Y<&4@/2`D;')E<W5L=%LP73L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!3970@<')O8F%B:6QI='D*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<')O8F%B:6QI='D@
M/2`D<F5S=6QT6S)=.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("\O($YO=R!E>'1R86-T('1I;64@9F]R('1H:7,@9W)O=7`*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!P<F5G7VUA=&-H*"(O7BA<9'LR?2DH
M7&1[,GTI)"]I(BP@)'1A9ELD:2`K(#)=+"`D;')E<W5L="D["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&9R;VT@/2`D;')E<W5L=%LQ72XB
M.C`P(CL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&\@("`]
M("1L<F5S=6QT6S)=+B(Z,#`B.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T;R`@(#T@*"1T;R`]/2`B,C0Z,#`B*2`_("(P,#HP,"(@.B`D
M=&\["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@07,@=V4@
M;F]W(&AA=F4@='EP92P@<')O8F%B:6QI='D@86YD('1I;64@9F]R('1H:7,@
M1DU#"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@9G)O;2!O
M=7(@5$%&+"!I;F-R96%S92!F:65L9"UC;W5N=&5R"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&D@*ST@,CL*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H*"(O7BA<9'LR?2DH7&1[
M,GTI)"]I(BP@)'1A9ELD:2`K(#%=+"`D;')E<W5L="DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`O+R!.;W)M86P@9W)O=7`L('-E="!T
M>7!E(&%N9"!U<V4@97AT<F%C=&5D('1I;64*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D='EP92`]("1R97-U;'1;,5T["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@+R\@0VAE8VL@9F]R(%!23T)D9`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<F5S=6QT
M6S)=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<')O8F%B:6QI='D@/2`D<F5S=6QT6S)=.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9G)O;2`]("1L<F5S=6QT6S%=+B(Z,#`B.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T;R`@(#T@)&QR97-U;'1;,ETN(CHP,"(["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1O("`@/2`H)'1O(#T]
M("(R-#HP,"(I(#\@(C`P.C`P(B`Z("1T;SL*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!386UE(&%S(&%B;W9E+"!W92!H879E(&$@=&EM
M92!F;W(@=&AI<R!&34,@9G)O;2!O=7(@5$%&+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("\O(&EN8W)E87-E(&9I96QD+6-O=6YT97(*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:2`K/2`Q.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`O+R!4:&ES(&ES(&5I=&AE<B!A(%!23T)D9"!O
M<B!A(&UA;&9O<FUE9"!4048*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)')E<W5L=%LR72DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'!R;V)A8FEL:71Y(#T@)')E<W5L=%LR
M73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+R\@2&%N9&QE('1H92!&34,L(&=E;F5R871E(&YE8V-E<W-A<GD@
M87)R87D@:68@:70G<R!T:&4@9FER<W0N+BX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D='EP92DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1F;W)E8V%S=$1A=&%;(G1I
M;64B75LD9G)O;51I;65=6R)F;6,B72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&9O<F5C87-T1&%T85LB=&EM92)=6R1F<F]M
M5&EM95U;(F9M8R)=(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&9O<F5C87-T1&%T85LB=&EM92)=6R1F<F]M5&EM95U;(F9M8R)=6R1F;6-#
M;W5N=%T@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("\O("XN+F%N9"!S970@<&]I;G1E<BX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<&]I;G1E<B`])B`D9F]R96-A<W1$871A6R)T:6UE
M(EU;)&9R;VU4:6UE75LB9FUC(EU;)&9M8T-O=6YT73L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9FUC0V]U;G0K*SL*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`O+R!);G-E<G0@9&%T80H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)T>7!E(ET@/2`D='EP
M93L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB
M9G)O;2)=(#T@)&9R;VT["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'!O:6YT97);(G1O(ET@("`]("1T;SL*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!U;G-E="@D='EP92P@)&9R;VTL("1T;RD["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P<F]B86)I
M;&ET>2DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!O:6YT97);(G!R;V)A8FEL:71Y(ET@/2`D<')O8F%B:6QI='D["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1P<F]B86)I
M;&ET>2D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&1E9F%U
M;'0Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!$;R!N;W1H:6YG
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@:68@*"1F;W5N9"`F
M)B`A4T525DE#15-?5T5!5$A%4E]$14)51RD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H
M)&9O=6YD("8F(%-%4E9)0T537U=%051(15)?1$5"54<I('L*("`@("`@("`@
M("`@("`@("`@("`@("`@96-H;R`D:V5Y+B)<;B(["B`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(21F
M;W5N9"D@>PH@("`@("`@("`@("`@("`@:68@*%-%4E9)0T537U=%051(15)?
M1$5"54<I('L*("`@("`@("`@("`@("`@("`@("!E8VAO(")N+V%<;B(["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1F
M;W)E8V%S=$1A=&%;(FYO<&%R<V4B72DI('L*("`@("`@("`@("`@("`@("`@
M("`D9F]R96-A<W1$871A6R)N;W!A<G-E(ET@/2!A<G)A>2@I.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&9O<F5C87-T1&%T85LB;F]P
M87)S92)=6UT@/2`D=&%F6R1I73L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@:68@*&ES<V5T*"1F;W)E8V%S=$1A=&%;(FYO<&%R<V4B72DI
M('L*("`@("`@("`@("`@)&9O<F5C87-T1&%T85LB;F]P87)S92)=(#T@:6UP
M;&]D92@B("(L("`D9F]R96-A<W1$871A6R)N;W!A<G-E(ETI.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1F;W)E8V%S=$1A=&$["B`@("!]"B`@("`O
M+R!]?7T*"B`@("`O+R![>WL@7V-O;G9E<G12971U<FXH*0H@("`@+RHJ"B`@
M("`@*B!#;VYV97)T<R!T:&4@9&%T82!I;B!T:&4@<F5T=7)N(&%R<F%Y('1O
M('1H92!D97-I<F5D('5N:71S(&%N9"]O<@H@("`@("H@;W5T<'5T(&9O<FUA
M="X*("`@("`J"B`@("`@*B!`<&%R86T@("!A<G)A>2`@("`@("`@("`@("`@
M("`@("`@("`@)'1A<F=E=`H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@
M("`@("`@("`@("`@("`@("1U;FET<PH@("`@("H@0'!A<F%M("`@<W1R:6YG
M("`@("`@("`@("`@("`@("`@("`@("1L;V-A=&EO;@H@("`@("H@0&%C8V5S
M<R`@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N=F5R=%)E='5R
M;B@F)'1A<F=E="P@)'5N:71S+"`D;&]C871I;VXI"B`@("!["B`@("`@("`@
M:68@*&ES7V%R<F%Y*"1T87)G970I*2!["B`@("`@("`@("`@(&9O<F5A8V@@
M*"1T87)G970@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@("`@("!I
M9B`H:7-?87)R87DH)'9A;"DI('L*("`@("`@("`@("`@("`@("`@("`O+R!!
M;F]T:&5R(&%R<F%Y(&1E=&5C=&5D+"!S;R!R96-U<G-E(&EN=&\@:70@=&\@
M8V]N=F5R="!T:&4@=6YI=',*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V-O;G9E<G12971U<FXH)'1A<F=E=%LD:V5Y72P@)'5N:71S+"`D;&]C871I
M;VXI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("!S=VET8V@@*"1K97DI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M8V%S92`B<W1A=&EO;B(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M;F5W5F%L(#T@)&QO8V%T:6]N6R)N86UE(ET["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S
M92`B=7!D871E(CH*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B=F%L
M:61&<F]M(CH*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B=F%L:614
M;R(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F5W5F%L(#T@9VUD
M871E*'1R:6TH)'1H:7,M/E]D871E1F]R;6%T+B(@(BXD=&AI<RT^7W1I;65&
M;W)M870I+"`D=F%L*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")W:6YD(CH*("`@
M("`@("`@("`@("`@("`@("`@("`@8V%S92`B=VEN9$=U<W0B.@H@("`@("`@
M("`@("`@("`@("`@("`@("!C87-E(")W:6YD<VAE87(B.@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&YE=U9A;"`]("1T:&ES+3YC;VYV97)T4W!E
M960H)'9A;"P@(FUP:"(L("1U;FET<ULB=VEN9")=*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@
M("!C87-E(")V:7-I8FEL:71Y(CH*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1N97=686P@/2`D=&AI<RT^8V]N=F5R=$1I<W1A;F-E*"1V86PL(")S
M;2(L("1U;FET<ULB=FES(ETI.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(FAE:6=H
M="(Z"B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(G=I;F1S:&5A<DAE
M:6=H="(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F5W5F%L(#T@
M)'1H:7,M/F-O;G9E<G1$:7-T86YC92@D=F%L+"`B9G0B+"`D=6YI='-;(FAE
M:6=H=")=*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@("`@("`@("!C87-E(")T96UP97)A='5R92(Z"B`@
M("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(G1E;7!E<F%T=7)E2&EG:"(Z
M"B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(G1E;7!E<F%T=7)E3&]W
M(CH*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B9&5W4&]I;G0B.@H@
M("`@("`@("`@("`@("`@("`@("`@("!C87-E(")F96QT5&5M<&5R871U<F4B
M.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YE=U9A;"`]("1T:&ES
M+3YC;VYV97)T5&5M<&5R871U<F4H)'9A;"P@(F8B+"`D=6YI='-;(G1E;7`B
M72D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@("`@("`@("`@("`@8V%S92`B<')E<W-U<F4B.@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&YE=U9A;"`]("1T:&ES+3YC;VYV97)T4')E
M<W-U<F4H)'9A;"P@(FEN(BP@)'5N:71S6R)P<F5S(ETI.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@
M("`@(&-A<V4@(F%M;W5N="(Z"B`@("`@("`@("`@("`@("`@("`@("`@(&-A
M<V4@(G-N;W=D97!T:"(Z"B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@
M(G-N;W=E<75I=B(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M:7-?;G5M97)I8R@D=F%L*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1N97=686P@/2`D=&AI<RT^8V]N=F5R=%!R97-S=7)E*"1V86PL
M(")I;B(L("1U;FET<ULB<F%I;B)=*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&YE=U9A;"`]("1V86P["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@("`@("`@("`@("`@8V%S92`B<V5A<')E<W-U<F4B.@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&YE=U9A;"`]("1T:&ES+3YC;VYV97)T
M4')E<W-U<F4H)'9A;"P@(FEN(BP@)'5N:71S6R)P<F5S(ETI.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@
M("`@("`@(&-A<V4@(C%H=&5M<"(Z"B`@("`@("`@("`@("`@("`@("`@("`@
M(&-A<V4@(C%H9&5W(CH*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B
M-FAM87AT96UP(CH*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B-FAM
M:6YT96UP(CH*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B,C1H;6%X
M=&5M<"(Z"B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(C(T:&UI;G1E
M;7`B.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YE=U9A;"`]("1T
M:&ES+3YC;VYV97)T5&5M<&5R871U<F4H)'9A;"P@(F8B+"`D=6YI='-;(G1E
M;7`B72D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&-O;G1I;G5E(#(["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@("1T87)G971;)&ME>5T@/2`D;F5W5F%L
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[('-E87)C:$QO8V%T:6]N*"D*
M("`@("\J*@H@("`@("H@4V5A<F-H97,@241S(&9O<B!G:79E;B!L;V-A=&EO
M;BP@<F5T=7)N<R!A<G)A>2!O9B!P;W-S:6)L92!L;V-A=&EO;G,*("`@("`J
M(&]R('-I;F=L92!)1`H@("`@("H*("`@("`J($!P87)A;2`@('-T<FEN9WQA
M<G)A>2`@("`@("`@("`@("`@("`D;&]C871I;VX*("`@("`J($!P87)A;2`@
M(&)O;VP@("`@("`@("`@("`@("`@("`@("`@("`D=7-E1FER<W0@("`@("`@
M268@<V5T+"!F:7)S="!)1"!O9B!R97-U;'0M87)R87D@:7,@<F5T=7)N960*
M("`@("`J($!R971U<FX@(%!%05)?17)R;W)\87)R87E\<W1R:6YG"B`@("`@
M*B!`=&AR;W=S("!014%27T5R<F]R.CI315)624-%4U]714%42$527T524D]2
M7U5.2TY/5TY?3$]#051)3TX*("`@("`J($!T:')O=W,@(%!%05)?17)R;W(Z
M.E-%4E9)0T537U=%051(15)?15)23U)?1$)?3D]47T-/3DY%0U1%1`H@("`@
M("H@0'1H<F]W<R`@4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/
M4E])3E9!3$E$7TQ/0T%424]."B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V5A<F-H3&]C871I;VXH)&QO8V%T:6]N+"`D
M=7-E1FER<W0@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?9&(I('Q\("%$0CHZ:7-#;VYN96-T:6]N*"1T:&ES+3Y?9&(I*2![
M"B`@("`@("`@("`@(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES945R
M<F]R*%-%4E9)0T537U=%051(15)?15)23U)?1$)?3D]47T-/3DY%0U1%1"P@
M7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI
M<U]S=')I;F<H)&QO8V%T:6]N*2D@>PH@("`@("`@("`@("`O+R!4<GD@=&\@
M<&%R="!S96%R8V@@<W1R:6YG(&EN(&YA;64L('-T871E(&%N9"!C;W5N=')Y
M('!A<G0*("`@("`@("`@("`@+R\@86YD(&)U:6QD('=H97)E(&-L875S92!F
M<F]M(&ET(&9O<B!T:&4@<V5L96-T"B`@("`@("`@("`@("1L;V-A=&EO;B`]
M(&5X<&QO9&4H(BPB+"`D;&]C871I;VXI.PH*("`@("`@("`@("`@+R\@5')I
M;2P@8V%P<RUL;W<@86YD('%U;W1E('1H92!S=')I;F=S"B`@("`@("`@("`@
M(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D;&]C871I;VXI.R`D:2LK*2![
M"B`@("`@("`@("`@("`@("`D;&]C871I;VY;)&E=(#T@)'1H:7,M/E]D8BT^
M<75O=&4H(B4B+G-T<G1O;&]W97(H=')I;2@D;&]C871I;VY;)&E=*2DN(B4B
M*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*'-I>F5O9B@D;&]C
M871I;VXI(#T](#$I('L*("`@("`@("`@("`@("`@("1W:&5R92`@/2`B3$]7
M15(H;F%M92D@3$E+12`B+B1L;V-A=&EO;ELP73L*("`@("`@("`@("`@?2!E
M;'-E:68@*'-I>F5O9B@D;&]C871I;VXI(#T](#(I('L*("`@("`@("`@("`@
M("`@("1W:&5R92`@/2`B3$]715(H;F%M92D@3$E+12`B+B1L;V-A=&EO;ELP
M73L*("`@("`@("`@("`@("`@("1W:&5R92`N/2`B($%.1"!,3U=%4BAC;W5N
M=')Y*2!,24M%("(N)&QO8V%T:6]N6S%=.PH@("`@("`@("`@("!](&5L<V5I
M9B`H<VEZ96]F*"1L;V-A=&EO;BD@/3T@,RD@>PH@("`@("`@("`@("`@("`@
M)'=H97)E("`]("),3U=%4BAN86UE*2!,24M%("(N)&QO8V%T:6]N6S!=.PH@
M("`@("`@("`@("`@("`@)'=H97)E("X]("(@04Y$($Q/5T52*'-T871E*2!,
M24M%("(N)&QO8V%T:6]N6S%=.PH@("`@("`@("`@("`@("`@)'=H97)E("X]
M("(@04Y$($Q/5T52*&-O=6YT<GDI($Q)2T4@(BXD;&]C871I;VY;,ET["B`@
M("`@("`@("`@('T@96QS96EF("AS:7IE;V8H)&QO8V%T:6]N*2`]/2`T*2![
M"B`@("`@("`@("`@("`@("`D=VAE<F4@(#T@(DQ/5T52*&YA;64I($Q)2T4@
M(BYS=6)S='(H)&QO8V%T:6]N6S!=+"`P+"`M,BDN(BP@(BYS=6)S='(H)&QO
M8V%T:6]N6S%=+"`R*3L*("`@("`@("`@("`@("`@("1W:&5R92`N/2`B($%.
M1"!,3U=%4BAS=&%T92D@3$E+12`B+B1L;V-A=&EO;ELR73L*("`@("`@("`@
M("`@("`@("1W:&5R92`N/2`B($%.1"!,3U=%4BAC;W5N=')Y*2!,24M%("(N
M)&QO8V%T:6]N6S-=.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!#
M<F5A=&4@<V5L96-T+"!L;V-A=&EO;G,@=VET:"!)0T%/(&9I<G-T"B`@("`@
M("`@("`@("1S96QE8W0@/2`B4T5,14-4(&EC86\L(&YA;64L('-T871E+"!C
M;W5N=')Y+"!L871I='5D92P@;&]N9VET=61E("(N"B`@("`@("`@("`@("`@
M("`@("`@("`B1E)/32!M971A<DQO8V%T:6]N<R`B+@H@("`@("`@("`@("`@
M("`@("`@("`@(E=(15)%("(N)'=H97)E+B(@(BX*("`@("`@("`@("`@("`@
M("`@("`@(")/4D1%4B!"62!I8V%O($1%4T,B.PH@("`@("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'-E;&5C="D["B`@("`@("`@("`@
M("\O($-H96-K(')E<W5L="!F;W(@=F%L:61I='D*("`@("`@("`@("`@:68@
M*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("`@("`@?2!E;'-E:68@*'-T<G1O;&]W97(H
M9V5T7V-L87-S*"1R97-U;'0I*2`A/2`B9&)?<F5S=6QT(B!\?"`D<F5S=6QT
M+3YN=6U2;W=S*"D@/3T@,"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%-E
M<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%
M4E)/4E]53DM.3U=.7TQ/0T%424].+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!297-U;'0@:7,@=F%L:60L
M('-T87)T('!R97!A<FEN9R!T:&4@<F5T=7)N"B`@("`@("`@("`@("1I8V%O
M(#T@87)R87DH*3L*("`@("`@("`@("`@=VAI;&4@*"@D<F]W(#T@)')E<W5L
M="T^9F5T8VA2;W<H1$)?1D540TA-3T1%7T%34T]#*2D@(3T@;G5L;"D@>PH@
M("`@("`@("`@("`@("`@)&QO8VEC86\@/2`D<F]W6R)I8V%O(ET["B`@("`@
M("`@("`@("`@("`O+R!&:7)S="!T:&4@;F%M92!O9B!T:&4@;&]C871I;VX*
M("`@("`@("`@("`@("`@(&EF("@A<W1R;&5N*"1R;W=;(G-T871E(ETI*2![
M"B`@("`@("`@("`@("`@("`@("`@)&QO8VYA;64@/2`D<F]W6R)N86UE(ETN
M(BP@(BXD<F]W6R)C;W5N=')Y(ET["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("1L;V-N86UE(#T@)')O=ULB;F%M92)=
M+B(L("(N)')O=ULB<W1A=&4B72XB+"`B+B1R;W=;(F-O=6YT<GDB73L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@D;&]C:6-A;R`A
M/2`B+2TM+2(I('L*("`@("`@("`@("`@("`@("`@("`O+R!792!H879E(&$@
M;&]C871I;VX@=VET:"!)0T%/"B`@("`@("`@("`@("`@("`@("`@)&EC86];
M)&QO8VEC86]=(#T@)&QO8VYA;64["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("\O($YO($E#04\L('1R>2!F:6YD:6YG
M('1H92!N96%R97-T(&%I<G!O<G0*("`@("`@("`@("`@("`@("`@("`D;&]C
M:6-A;R`]("1T:&ES+3YS96%R8VA!:7)P;W)T*"1R;W=;(FQA=&ET=61E(ETL
M("1R;W=;(FQO;F=I='5D92)=*3L*("`@("`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1I8V%O6R1L;V-I8V%O72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&EC86];)&QO8VEC86]=(#T@)&QO8VYA;64["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@("`@("\O($]N;'D@;VYE(')E<W5L=#\@4F5T=7)N(&%S('-T<FEN
M9PH@("`@("`@("`@("!I9B`H<VEZ96]F*"1I8V%O*2`]/2`Q('Q\("1U<V5&
M:7)S="D@>PH@("`@("`@("`@("`@("`@)&EC86\@/2!K97DH)&EC86\I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y*"1L;V-A
M=&EO;BDI('L*("`@("`@("`@("`@+R\@3&]C871I;VX@=V%S('!R;W9I9&5D
M(&%S(&-O;W)D:6YA=&5S+"!S96%R8V@@;F5A<F5S="!A:7)P;W)T"B`@("`@
M("`@("`@("1I8V%O(#T@)'1H:7,M/G-E87)C:$%I<G!O<G0H)&QO8V%T:6]N
M6S!=+"`D;&]C871I;VY;,5TI.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)
M0T537U=%051(15)?15)23U)?24Y604Q)1%],3T-!5$E/3BP@7U]&24Q%7U\L
M(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6-A;SL*
M("`@('T*("`@("\O('U]?0H*("`@("\O('M[>R!S96%R8VA,;V-A=&EO;D)Y
M0V]U;G1R>2@I"B`@("`O*BH*("`@("`J(%)E='5R;G,@241S('=I=&@@;&]C
M871I;VXM;F%M92!F;W(@82!G:79E;B!C;W5N=')Y(&]R(&%L;"!A=F%I;&%B
M;&4*("`@("`J(&-O=6YT<FEE<RP@:68@;F\@=F%L=64@=V%S(&=I=F5N"B`@
M("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@
M("`@("1C;W5N=')Y"B`@("`@*B!`<F5T=7)N("!014%27T5R<F]R?&%R<F%Y
M"B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R.CI315)624-%4U]714%42$52
M7T524D]27U5.2TY/5TY?3$]#051)3TX*("`@("`J($!T:')O=W,@(%!%05)?
M17)R;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?1$)?3D]47T-/3DY%0U1%
M1`H@("`@("H@0'1H<F]W<R`@4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%
M4E]%4E)/4E]74D].1U]315)615)?1$%400H@("`@("H@0&%C8V5S<R`@<'5B
M;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('-E87)C:$QO8V%T:6]N0GE#;W5N
M=')Y*"1C;W5N=')Y(#T@(B(I"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D
M=&AI<RT^7V1B*2!\?"`A1$(Z.FES0V]N;F5C=&EO;B@D=&AI<RT^7V1B*2D@
M>PH@("`@("`@("`@("!R971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%
M<G)O<BA315)624-%4U]714%42$527T524D]27T1"7TY/5%]#3TY.14-4140L
M(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("`O+R!2
M971U<FX@=&AE(&%V86EL86)L92!C;W5N=')I97,@87,@;F\@8V]U;G1R>2!W
M87,@9VEV96X*("`@("`@("!I9B`H(7-T<FQE;B@D8V]U;G1R>2DI('L*("`@
M("`@("`@("`@)'-E;&5C="`](")314Q%0U0@1$E35$E.0U0H8V]U;G1R>2D@
M(BX*("`@("`@("`@("`@("`@("`@("`@(")&4D]-(&UE=&%R06ER<&]R=',@
M(BX*("`@("`@("`@("`@("`@("`@("`@(")/4D1%4B!"62!C;W5N=')Y($%3
M0R(["B`@("`@("`@("`@("1C;W5N=')I97,@/2`D=&AI<RT^7V1B+3YG971#
M;VPH)'-E;&5C="D["@H@("`@("`@("`@("`O+R!!<R`D8V]U;G1R:65S(&ES
M(&5I=&AE<B!A;B!E<G)O<B!O<B!T:&4@=')U92!R97-U;'0L"B`@("`@("`@
M("`@("\O('=E(&-A;B!J=7-T(')E='5R;B!I=`H@("`@("`@("`@("!R971U
M<FX@)&-O=6YT<FEE<SL*("`@("`@("!]"@H@("`@("`@("\O($YO=R!F;W(@
M=&AE(')E86P@<V5A<F-H"B`@("`@("`@)'-E;&5C="`](")314Q%0U0@:6-A
M;RP@;F%M92P@<W1A=&4L(&-O=6YT<GD@(BX*("`@("`@("`@("`@("`@("`@
M(D923TT@;65T87)!:7)P;W)T<R`B+@H@("`@("`@("`@("`@("`@("`B5TA%
M4D4@3$]715(H8V]U;G1R>2D@3$E+12`G)2(N<W1R=&]L;W=E<BAT<FEM*"1C
M;W5N=')Y*2DN(B4G("(N"B`@("`@("`@("`@("`@("`@(")/4D1%4B!"62!N
M86UE($%30R(["B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y
M*"1S96QE8W0I.PH@("`@("`@("\O($-H96-K(')E<W5L="!F;W(@=F%L:61I
M='D*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?2!E;'-E:68@*'-T<G1O
M;&]W97(H9V5T7V-L87-S*"1R97-U;'0I*2`A/2`B9&)?<F5S=6QT(B!\?"`D
M<F5S=6QT+3YN=6U2;W=S*"D@/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@
M4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$52
M7T524D]27U5.2TY/5TY?3$]#051)3TXL(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@?0H*("`@("`@("`O+R!#;VYS=')U8W0@=&AE(')E<W5L=`H@
M("`@("`@("1L;V-A=&EO;G,@/2!A<G)A>2@I.PH@("`@("`@('=H:6QE("@H
M)')O=R`]("1R97-U;'0M/F9E=&-H4F]W*$1"7T9%5$-(34]$15]!4U-/0RDI
M("$](&YU;&PI('L*("`@("`@("`@("`@)&QO8VEC86\@/2`D<F]W6R)I8V%O
M(ET["B`@("`@("`@("`@(&EF("@D;&]C:6-A;R`A/2`B+2TM+2(I('L*("`@
M("`@("`@("`@("`@("\O($9I<G-T('1H92!N86UE(&]F('1H92!L;V-A=&EO
M;@H@("`@("`@("`@("`@("`@:68@*"%S=')L96XH)')O=ULB<W1A=&4B72DI
M('L*("`@("`@("`@("`@("`@("`@("`D;&]C;F%M92`]("1R;W=;(FYA;64B
M72XB+"`B+B1R;W=;(F-O=6YT<GDB73L*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@)&QO8VYA;64@/2`D<F]W6R)N86UE
M(ETN(BP@(BXD<F]W6R)S=&%T92)=+B(L("(N)')O=ULB8V]U;G1R>2)=.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&QO8V%T:6]N<ULD
M;&]C:6-A;UT@/2`D;&]C;F%M93L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1L;V-A=&EO;G,["B`@("!]"B`@("`O+R!]?7T*
M"B`@("`O+R![>WL@<V5A<F-H06ER<&]R="@I"B`@("`O*BH*("`@("`J(%-E
M87)C:&5S('1H92!N96%R97-T(&%I<G!O<G0H<RD@9F]R(&=I=F5N(&-O;W)D
M:6YA=&5S+"!R971U<FYS(&%R<F%Y"B`@("`@*B!O9B!)1',@;W(@<VEN9VQE
M($E$"B`@("`@*@H@("`@("H@0'!A<F%M("`@9FQO870@("`@("`@("`@("`@
M("`@("`@("`@("1L871I='5D90H@("`@("H@0'!A<F%M("`@9FQO870@("`@
M("`@("`@("`@("`@("`@("`@("1L;VYG:71U9&4*("`@("`J($!P87)A;2`@
M(&EN="`@("`@("`@("`@("`@("`@("`@("`@("`D;G5M4F5S=6QT<PH@("`@
M("H@0')E='5R;B`@4$5!4E]%<G)O<GQA<G)A>7QS=')I;F<*("`@("`J($!T
M:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?54Y+
M3D]73E],3T-!5$E/3@H@("`@("H@0'1H<F]W<R`@4$5!4E]%<G)O<CHZ4T52
M5DE#15-?5T5!5$A%4E]%4E)/4E]$0E].3U1?0T].3D5#5$5$"B`@("`@*B!`
M=&AR;W=S("!014%27T5R<F]R.CI315)624-%4U]714%42$527T524D]27TE.
M5D%,241?3$]#051)3TX*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!S96%R8VA!:7)P;W)T*"1L871I='5D92P@)&QO;F=I
M='5D92P@)&YU;5)E<W5L=',@/2`Q*0H@("`@>PH@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]D8BD@?'P@(41".CII<T-O;FYE8W1I;VXH)'1H:7,M/E]D
M8BDI('L*("`@("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A
M:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%4E)/4E]$0E].3U1?0T].3D5#
M5$5$+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@("`@("!I
M9B`H(6ES7VYU;65R:6,H)&QA=&ET=61E*2!\?"`A:7-?;G5M97)I8R@D;&]N
M9VET=61E*2D@>PH@("`@("`@("`@("!R971U<FX@4V5R=FEC97-?5V5A=&AE
M<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$527T524D]27TE.5D%,241?
M3$]#051)3TXL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@
M("`@("`O+R!'970@86QL(&%I<G!O<G1S"B`@("`@("`@)'-E;&5C="`](")3
M14Q%0U0@:6-A;RP@>"P@>2P@>B!&4D]-(&UE=&%R06ER<&]R=',B.PH@("`@
M("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<V5L96-T*3L*("`@
M("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("`@("`@?2!E;'-E:68@*'-T<G1O;&]W97(H
M9V5T7V-L87-S*"1R97-U;'0I*2`A/2`B9&)?<F5S=6QT(B!\?"`D<F5S=6QT
M+3YN=6U2;W=S*"D@/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@4V5R=FEC
M97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$527T524D]2
M7U5.2TY/5TY?3$]#051)3TXL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@
M("`@?0H*("`@("`@("`O+R!297-U;'0@:7,@=F%L:60L('-T87)T('-E87)C
M:`H@("`@("`@("\O($EN:71I86QI>F4@=F%L=65S"B`@("`@("`@)&UI;E]D
M:7-T(#T@;G5L;#L*("`@("`@("`D<75E<GD@("`@/2`D=&AI<RT^<&]L87(R
M8V%R=&5S:6%N*"1L871I='5D92P@)&QO;F=I='5D92D["B`@("`@("`@)'-E
M87)C:"`@(#T@87)R87DH(F1I<W0B(#T^(&%R<F%Y*"DL(")I8V%O(B`]/B!A
M<G)A>2@I*3L*("`@("`@("!W:&EL92`H*"1R;W<@/2`D<F5S=6QT+3YF971C
M:%)O=RA$0E]&151#2$U/1$5?05-33T,I*2`A/2!N=6QL*2!["B`@("`@("`@
M("`@("1I8V%O(#T@)')O=ULB:6-A;R)=.PH@("`@("`@("`@("`D86ER("`]
M(&%R<F%Y*"1R;W=;(G@B72P@)')O=ULB>2)=+"`D<F]W6R)Z(ETI.PH*("`@
M("`@("`@("`@)&1I<W0@/2`P.PH@("`@("`@("`@("`D9"`](#`["B`@("`@
M("`@("`@("\O($-A;&-U;&%T92!D:7-T86YC92!O9B!Q=65R>2!A;F0@8W5R
M<F5N="!A:7)P;W)T"B`@("`@("`@("`@("\O(&)R96%K(&]F9BP@:68@9&ES
M=&%N8V4@:7,@;&%R9V5R('1H86X@8W5R<F5N="`D;6EN7V1I<W0*("`@("`@
M("`@("`@9F]R*"1D.R`D9"`\('-I>F5O9B@D86ER*3L@)&0K*RD@>PH@("`@
M("`@("`@("`@("`@)'0@/2`D86ER6R1D72`M("1Q=65R>5LD9%T["B`@("`@
M("`@("`@("`@("`D9&ES="`K/2!P;W<H)'0L(#(I.PH@("`@("`@("`@("`@
M("`@:68@*"1M:6Y?9&ES="`A/2!N=6QL("8F("1D:7-T(#X@)&UI;E]D:7-T
M*2!["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D9"`^/2!S:7IE
M;V8H)&%I<BDI('L*("`@("`@("`@("`@("`@("\O($]K+"!C=7)R96YT(&%I
M<G!O<G0@:7,@;VYE(&]F('1H92!N96%R97(@;&]C871I;VYS"B`@("`@("`@
M("`@("`@("`O+R!A9&0@=&\@<F5S=6QT+6%R<F%Y"B`@("`@("`@("`@("`@
M("`D<V5A<F-H6R)D:7-T(EU;72`]("1D:7-T.PH@("`@("`@("`@("`@("`@
M)'-E87)C:%LB:6-A;R)=6UT@/2`D:6-A;SL*("`@("`@("`@("`@("`@("\O
M(%-O<G0@87)R87D@9F]R(&1I<W1A;F-E"B`@("`@("`@("`@("`@("!A<G)A
M>5]M=6QT:7-O<G0H)'-E87)C:%LB9&ES=")=+"!33U)47TY5345224,L(%-/
M4E1?05-#+"`D<V5A<F-H6R)I8V%O(ETL(%-/4E1?4U1224Y'+"!33U)47T%3
M0RD["B`@("`@("`@("`@("`@("`O+R!)9B!A<G)A>2!I<R!L87)G97(@=&AE
M;B!D97-I<F5D(')E<W5L=',L(&-H;W`@;V9F(&QA<W0@;VYE"B`@("`@("`@
M("`@("`@("!I9B`H<VEZ96]F*"1S96%R8VA;(F1I<W0B72D@/B`D;G5M4F5S
M=6QT<RD@>PH@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W!O<"@D<V5A<F-H
M6R)D:7-T(ETI.PH@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W!O<"@D<V5A
M<F-H6R)I8V%O(ETI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@)&UI;E]D:7-T(#T@;6%X*"1S96%R8VA;(F1I<W0B72D["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@:68@*"1N=6U297-U;'1S(#T](#$I
M('L*("`@("`@("`@("`@+R\@3VYL>2!O;F4@<F5S=6QT('=A;G1E9"P@<F5T
M=7)N(&%S('-T<FEN9PH@("`@("`@("`@("!R971U<FX@)'-E87)C:%LB:6-A
M;R)=6S!=.PH@("`@("`@('T@96QS96EF("@D;G5M4F5S=6QT<R`^(#$I('L*
M("`@("`@("`@("`@+R\@4F5T=7)N(&9O=6YD(&QO8V%T:6]N<PH@("`@("`@
M("`@("!R971U<FX@)'-E87)C:%LB:6-A;R)=.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES945R
M<F]R*%-%4E9)0T537U=%051(15)?15)23U)?54Y+3D]73E],3T-!5$E/3BP@
M7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@("!]"B`@("`O+R!]
M?7T*"B`@("`O+R![>WL@9V5T3&]C871I;VXH*0H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!D871A(&9O<B!T:&4@;&]C871I;VX@8F5L;VYG:6YG('1O
M('1H92!)1`H@("`@("H*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@
M("`@("`@("`@("`@("`D:60*("`@("`J($!R971U<FX@(%!%05)?17)R;W)\
M87)R87D*("`@("`J($!T:')O=W,@(%!%05)?17)R;W(*("`@("`J($!A8V-E
M<W,@('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!G971,;V-A=&EO;B@D
M:60@/2`B(BD*("`@('L*("`@("`@("`D<W1A='5S(#T@)'1H:7,M/E]C:&5C
M:TQO8V%T:6]N240H)&ED*3L*"B`@("`@("`@:68@*%-E<G9I8V5S7U=E871H
M97(Z.FES17)R;W(H)'-T871U<RDI('L*("`@("`@("`@("`@<F5T=7)N("1S
M=&%T=7,["B`@("`@("`@?0H*("`@("`@("`D;&]C871I;VY2971U<FX@/2!A
M<G)A>2@I.PH*("`@("`@("!I9B`H)'1H:7,M/E]C86-H945N86)L960@)B8@
M*"1L;V-A=&EO;B`]("1T:&ES+3Y?8V%C:&4M/F=E="@B345405(M(BXD:60L
M(")L;V-A=&EO;B(I*2D@>PH@("`@("`@("`@("`O+R!'<F%B('-T=69F(&9R
M;VT@8V%C:&4*("`@("`@("`@("`@)'1H:7,M/E]L;V-A=&EO;B`]("1L;V-A
M=&EO;CL*("`@("`@("`@("`@)&QO8V%T:6]N4F5T=7)N6R)C86-H92)=(#T@
M(DA)5"(["B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES+3Y?9&(I("8F
M($1".CII<T-O;FYE8W1I;VXH)'1H:7,M/E]D8BDI('L*("`@("`@("`@("`@
M+R\@1V5T(&1A=&$@9G)O;2!$0@H@("`@("`@("`@("`D<V5L96-T(#T@(E-%
M3$5#5"!I8V%O+"!N86UE+"!S=&%T92P@8V]U;G1R>2P@;&%T:71U9&4L(&QO
M;F=I='5D92P@96QE=F%T:6]N("(N"B`@("`@("`@("`@("`@("`@("`@("`B
M1E)/32!M971A<D%I<G!O<G1S(%=(15)%(&EC86\])R(N)&ED+B(G(CL*("`@
M("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1S96QE8W0I
M.PH*("`@("`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?2!E
M;'-E:68@*'-T<G1O;&]W97(H9V5T7V-L87-S*"1R97-U;'0I*2`A/2`B9&)?
M<F5S=6QT(B!\?"`D<F5S=6QT+3YN=6U2;W=S*"D@/3T@,"D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H
M4T525DE#15-?5T5!5$A%4E]%4E)/4E]53DM.3U=.7TQ/0T%424].+"!?7T9)
M3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("\O
M(%)E<W5L="!I<R!O:RP@<'5T('1H:6YG<R!I;G1O(&]B:F5C=`H@("`@("`@
M("`@("`D=&AI<RT^7VQO8V%T:6]N(#T@)')E<W5L="T^9F5T8VA2;W<H1$)?
M1D540TA-3T1%7T%34T]#*3L*"B`@("`@("`@("`@(&EF("@D=&AI<RT^7V-A
M8VAE16YA8FQE9"D@>PH@("`@("`@("`@("`@("`@+R\@+BXN86YD(&-A8VAE
M(&ET"B`@("`@("`@("`@("`@("`D97AP:7)E(#T@8V]N<W1A;G0H(E-%4E9)
M0T537U=%051(15)?15A025)%4U],3T-!5$E/3B(I.PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]C86-H92T^97AT4V%V92@B345405(M(BXD:60L("1T:&ES
M+3Y?;&]C871I;VXL("(B+"`D97AP:7)E+"`B;&]C871I;VXB*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)&QO8V%T:6]N4F5T=7)N6R)C86-H92)=
M(#T@(DU)4U,B.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES
M+3Y?;&]C871I;VX@/2!A<G)A>2@*("`@("`@("`@("`@("`@(")N86UE(B`@
M("`@(#T^("1I9"P*("`@("`@("`@("`@("`@(")S=&%T92(@("`@(#T^("(B
M+`H@("`@("`@("`@("`@("`@(F-O=6YT<GDB("`@/3X@(B(L"B`@("`@("`@
M("`@("`@("`B;&%T:71U9&4B("`]/B`B(BP*("`@("`@("`@("`@("`@(")L
M;VYG:71U9&4B(#T^("(B+`H@("`@("`@("`@("`@("`@(F5L979A=&EO;B(@
M/3X@(B(*("`@("`@("`@("`@*3L*("`@("`@("!]"B`@("`@("`@+R\@4W1U
M9F8@;F%M92US=')I;F<@=&]G971H97(*("`@("`@("!I9B`H<W1R;&5N*"1T
M:&ES+3Y?;&]C871I;VY;(G-T871E(ETI("8F('-T<FQE;B@D=&AI<RT^7VQO
M8V%T:6]N6R)C;W5N=')Y(ETI*2!["B`@("`@("`@("`@("1L;V-N86UE(#T@
M)'1H:7,M/E]L;V-A=&EO;ELB;F%M92)=+B(L("(N)'1H:7,M/E]L;V-A=&EO
M;ELB<W1A=&4B72XB+"`B+B1T:&ES+3Y?;&]C871I;VY;(F-O=6YT<GDB73L*
M("`@("`@("!](&5L<V5I9B`H<W1R;&5N*"1T:&ES+3Y?;&]C871I;VY;(F-O
M=6YT<GDB72DI('L*("`@("`@("`@("`@)&QO8VYA;64@/2`D=&AI<RT^7VQO
M8V%T:6]N6R)N86UE(ETN(BP@(BXD=&AI<RT^7VQO8V%T:6]N6R)C;W5N=')Y
M(ET["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&QO8VYA;64@/2`D
M=&AI<RT^7VQO8V%T:6]N6R)N86UE(ET["B`@("`@("`@?0H@("`@("`@("1L
M;V-A=&EO;E)E='5R;ELB;F%M92)=("`@("`@/2`D;&]C;F%M93L*("`@("`@
M("`D;&]C871I;VY2971U<FY;(FQA=&ET=61E(ET@(#T@)'1H:7,M/E]L;V-A
M=&EO;ELB;&%T:71U9&4B73L*("`@("`@("`D;&]C871I;VY2971U<FY;(FQO
M;F=I='5D92)=(#T@)'1H:7,M/E]L;V-A=&EO;ELB;&]N9VET=61E(ET["B`@
M("`@("`@)&QO8V%T:6]N4F5T=7)N6R)S=6YR:7-E(ET@("`](&1A=&4H)'1H
M:7,M/E]T:6UE1F]R;6%T+"`D=&AI<RT^8V%L8W5L871E4W5N4FES95-E="AG
M;6UK=&EM92@I+"!354Y&54Y#4U]2151?5$E-15-404U0+"`D=&AI<RT^7VQO
M8V%T:6]N6R)L871I='5D92)=+"`D=&AI<RT^7VQO8V%T:6]N6R)L;VYG:71U
M9&4B72P@4T525DE#15-?5T5!5$A%4E]354Y&54Y#4U]354Y225-%7UI%3DE4
M2"P@,"P@=')U92DI.PH@("`@("`@("1L;V-A=&EO;E)E='5R;ELB<W5N<V5T
M(ET@("`@/2!D871E*"1T:&ES+3Y?=&EM949O<FUA="P@)'1H:7,M/F-A;&-U
M;&%T95-U;E)I<V53970H9VUM:W1I;64H*2P@4U5.1E5.0U-?4D547U1)3453
M5$%-4"P@)'1H:7,M/E]L;V-A=&EO;ELB;&%T:71U9&4B72P@)'1H:7,M/E]L
M;V-A=&EO;ELB;&]N9VET=61E(ETL(%-%4E9)0T537U=%051(15)?4U5.1E5.
M0U-?4U5.4T547UI%3DE42"P@(#`L(&9A;'-E*2D["B`@("`@("`@)&QO8V%T
M:6]N4F5T=7)N6R)E;&5V871I;VXB72`]("1T:&ES+3Y?;&]C871I;VY;(F5L
M979A=&EO;B)=.PH*("`@("`@("!R971U<FX@)&QO8V%T:6]N4F5T=7)N.PH@
M("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[(&=E=%=E871H97(H*0H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('1H92!W96%T:&5R+61A=&$@9F]R('1H92!S
M=7!P;&EE9"!L;V-A=&EO;@H@("`@("H*("`@("`J($!P87)A;2`@('-T<FEN
M9R`@("`@("`@("`@("`@("`@("`@("`D:60*("`@("`J($!P87)A;2`@('-T
M<FEN9R`@("`@("`@("`@("`@("`@("`@("`D=6YI='-&;W)M870*("`@("`J
M($!R971U<FX@(%!(4%]%<G)O<GQA<G)A>0H@("`@("H@0'1H<F]W<R`@4$A0
M7T5R<F]R"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T5V5A=&AE<B@D:60@/2`B(BP@)'5N:71S1F]R;6%T(#T@(B(I
M"B`@("!["B`@("`@("`@)&ED("`@("`]('-T<G1O=7!P97(H)&ED*3L*("`@
M("`@("`D<W1A='5S(#T@)'1H:7,M/E]C:&5C:TQO8V%T:6]N240H)&ED*3L*
M"B`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'-T871U
M<RDI('L*("`@("`@("`@("`@<F5T=7)N("1S=&%T=7,["B`@("`@("`@?0H*
M("`@("`@("`O+R!'970@;W1H97(@9&%T80H@("`@("`@("1U;FET<R`@("`]
M("1T:&ES+3YG9715;FET<T9O<FUA="@D=6YI='-&;W)M870I.PH@("`@("`@
M("1L;V-A=&EO;B`]("1T:&ES+3YG971,;V-A=&EO;B@D:60I.PH*("`@("`@
M("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D;&]C871I;VXI*2![
M"B`@("`@("`@("`@(')E='5R;B`D;&]C871I;VX["B`@("`@("`@?0H*("`@
M("`@("!I9B`H)'1H:7,M/E]C86-H945N86)L960@)B8@*"1W96%T:&5R(#T@
M)'1H:7,M/E]C86-H92T^9V5T*")-151!4BTB+B1I9"P@(G=E871H97(B*2DI
M('L*("`@("`@("`@("`@+R\@5V5E+BXN(&ET('=A<R!C86-H960L(&QE="=S
M(&AA=F4@:70N+BX*("`@("`@("`@("`@)'=E871H97)2971U<FX@(#T@)'=E
M871H97(["B`@("`@("`@("`@("1T:&ES+3Y?=V5A=&AE<B`]("1W96%T:&5R
M4F5T=7)N.PH@("`@("`@("`@("`D=V5A=&AE<E)E='5R;ELB8V%C:&4B72`]
M(")(250B.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O($1O=VYL
M;V%D('=E871H97(*("`@("`@("`@("`@)'=E871H97)$871A(#T@)'1H:7,M
M/E]R971R:65V95-E<G9E<D1A=&$H)&ED+"`B;65T87(B*3L*("`@("`@("`@
M("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'=E871H97)$871A
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1W96%T:&5R1&%T83L*("`@
M("`@("`@("`@?2!E;'-E:68@*"%I<U]A<G)A>2@D=V5A=&AE<D1A=&$I('Q\
M('-I>F5O9B@D=V5A=&AE<D1A=&$I(#P@,BD@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?
M5T5!5$A%4E]%4E)/4E]74D].1U]315)615)?1$%402P@7U]&24Q%7U\L(%]?
M3$E.15]?*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@4&%R<V4@
M=V5A=&AE<@H@("`@("`@("`@("`D=V5A=&AE<E)E='5R;B`@/2`D=&AI<RT^
M7W!A<G-E5V5A=&AE<D1A=&$H)'=E871H97)$871A*3L*"B`@("`@("`@("`@
M(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1W96%T:&5R4F5T=7)N
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1W96%T:&5R4F5T=7)N.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!!9&0@86X@:6-O;B!F;W(@
M=&AE(&-U<G)E;G0@8V]N9&ET:6]N<PH@("`@("`@("`@("`O+R!$971E<FUI
M;F4@:68@8V5R=&%I;B!V86QU97,@87)E('-E="P@:68@;F]T('5S92!D969A
M=6QT<PH@("`@("`@("`@("`D8V]N9&ET:6]N("`@/2!I<W-E="@D=V5A=&AE
M<E)E='5R;ELB8V]N9&ET:6]N(ETI("`@/R`D=V5A=&AE<E)E='5R;ELB8V]N
M9&ET:6]N(ET@("`Z(").;R!3:6=N:69I8V%N="!796%T:&5R(CL*("`@("`@
M("`@("`@)&-L;W5D<R`@("`@(#T@:7-S970H)'=E871H97)2971U<FY;(F-L
M;W5D<R)=*2`@("`@(#\@)'=E871H97)2971U<FY;(F-L;W5D<R)=("`@("`@
M.B`@("`@("`@("`@("`@("`@(&%R<F%Y*"D["B`@("`@("`@("`@("1W:6YD
M("`@("`@("`](&ES<V5T*"1W96%T:&5R4F5T=7)N6R)W:6YD(ETI("`@("`@
M("`_("1W96%T:&5R4F5T=7)N6R)W:6YD(ET@("`@("`@(#H@("`@("`@("`@
M("`@("`@("`@("`@("`U.R`*("`@("`@("`@("`@)'1E;7!E<F%T=7)E(#T@
M:7-S970H)'=E871H97)2971U<FY;(G1E;7!E<F%T=7)E(ETI(#\@)'=E871H
M97)2971U<FY;(G1E;7!E<F%T=7)E(ET@.B`@("`@("`@("`@("`@("`@("`@
M("`@-S`[(`H@("`@("`@("`@("`D;&%T:71U9&4@("`@/2!I<W-E="@D;&]C
M871I;VY;(FQA=&ET=61E(ETI("`@("`@("`@/R`D;&]C871I;VY;(FQA=&ET
M=61E(ET@("`@("`@("`Z("`@("`@("`@("`@("`@("`@("`@+3,V,#L*("`@
M("`@("`@("`@)&QO;F=I='5D92`@(#T@:7-S970H)&QO8V%T:6]N6R)L;VYG
M:71U9&4B72D@("`@("`@(#\@)&QO8V%T:6]N6R)L;VYG:71U9&4B72`@("`@
M("`@.B`@("`@("`@("`@("`@("`@("`@("TS-C`["B`@("`@("`@("`@(`H@
M("`@("`@("`@("`O+R!'970@=&AE(&EC;VX*("`@("`@("`@("`@)'=E871H
M97)2971U<FY;(F-O;F1I=&EO;DEC;VXB72`]("1T:&ES+3YG971796%T:&5R
M26-O;B@D8V]N9&ET:6]N+"`D8VQO=61S+"`D=VEN9"P@)'1E;7!E<F%T=7)E
M+"`D;&%T:71U9&4L("1L;VYG:71U9&4I.PH*("`@("`@("`@("`@:68@*"1T
M:&ES+3Y?8V%C:&5%;F%B;&5D*2!["B`@("`@("`@("`@("`@("`O+R!#86-H
M92!W96%T:&5R"B`@("`@("`@("`@("`@("`D97AP:7)E(#T@8V]N<W1A;G0H
M(E-%4E9)0T537U=%051(15)?15A025)%4U]714%42$52(BD["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V-A8VAE+3YE>'13879E*")-151!4BTB+B1I9"P@
M)'=E871H97)2971U<FXL("1U;FET<T9O<FUA="P@)&5X<&ER92P@(G=E871H
M97(B*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7W=E871H
M97(@/2`D=V5A=&AE<E)E='5R;CL*("`@("`@("`@("`@)'=E871H97)2971U
M<FY;(F-A8VAE(ET@/2`B34E34R(["B`@("`@("`@?0H*("`@("`@("`D=&AI
M<RT^7V-O;G9E<G12971U<FXH)'=E871H97)2971U<FXL("1U;FET<RP@)&QO
M8V%T:6]N*3L*"B`@("`@("`@<F5T=7)N("1W96%T:&5R4F5T=7)N.PH@("`@
M?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[(&=E=$9O<F5C87-T*"D*("`@("\J
M*@H@("`@("H@345405(@<')O=FED97,@;F\@9F]R96-A<W0@<&5R('-E+"!W
M92!U<V4@=&AE(%1!1B!R97!O<G1S('1O(&=E;F5R871E"B`@("`@*B!A(&9O
M<F5C87-T(&9O<B!T:&4@86YN;W5N8V5D('1I;65P97)I;V0*("`@("`J"B`@
M("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)&ED
M"B`@("`@*B!`<&%R86T@("!I;G0@("`@("`@("`@("`@("`@("`@("`@("`@
M)&1A>7,@("`@("`@("`@($EG;F]R960L(&YO="!A<'!L:6-A8FQE"B`@("`@
M*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)'5N:71S
M1F]R;6%T"B`@("`@*B!`<F5T=7)N("!014%27T5R<F]R?&%R<F%Y"B`@("`@
M*B!`=&AR;W=S("!014%27T5R<F]R"B`@("`@*B!`86-C97-S("!P=6)L:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1F]R96-A<W0H)&ED(#T@(B(L("1D
M87ES(#T@;G5L;"P@)'5N:71S1F]R;6%T(#T@(B(I"B`@("!["B`@("`@("`@
M)&ED("`@("`]('-T<G1O=7!P97(H)&ED*3L*("`@("`@("`D<W1A='5S(#T@
M)'1H:7,M/E]C:&5C:TQO8V%T:6]N240H)&ED*3L*"B`@("`@("`@:68@*%-E
M<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'-T871U<RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1S=&%T=7,["B`@("`@("`@?0H*("`@("`@("`O+R!'970@
M;W1H97(@9&%T80H@("`@("`@("1U;FET<R`@("`]("1T:&ES+3YG9715;FET
M<T9O<FUA="@D=6YI='-&;W)M870I.PH@("`@("`@("1L;V-A=&EO;B`]("1T
M:&ES+3YG971,;V-A=&EO;B@D:60I.PH*("`@("`@("!I9B`H4V5R=FEC97-?
M5V5A=&AE<CHZ:7-%<G)O<B@D;&]C871I;VXI*2!["B`@("`@("`@("`@(')E
M='5R;B`D;&]C871I;VX["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M
M/E]C86-H945N86)L960@)B8@*"1F;W)E8V%S="`]("1T:&ES+3Y?8V%C:&4M
M/F=E="@B345405(M(BXD:60L(")F;W)E8V%S="(I*2D@>PH@("`@("`@("`@
M("`O+R!7964N+BX@:70@=V%S(&-A8VAE9"P@;&5T)W,@:&%V92!I="XN+@H@
M("`@("`@("`@("`D9F]R96-A<W12971U<FX@(#T@)&9O<F5C87-T.PH@("`@
M("`@("`@("`D=&AI<RT^7V9O<F5C87-T(#T@)&9O<F5C87-T4F5T=7)N.PH@
M("`@("`@("`@("`D9F]R96-A<W12971U<FY;(F-A8VAE(ET@/2`B2$E4(CL*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!$;W=N;&]A9"!F;W)E
M8V%S=`H@("`@("`@("`@("`D9F]R96-A<W1$871A(#T@)'1H:7,M/E]R971R
M:65V95-E<G9E<D1A=&$H)&ED+"`B=&%F(BD["B`@("`@("`@("`@(&EF("A3
M97)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1F;W)E8V%S=$1A=&$I*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)&9O<F5C87-T1&%T83L*("`@("`@("`@
M("`@?2!E;'-E:68@*"%I<U]A<G)A>2@D9F]R96-A<W1$871A*2!\?"!S:7IE
M;V8H)&9O<F5C87-T1&%T82D@/"`R*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%4
M2$527T524D]27U=23TY'7U-%4E9%4E]$051!+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!087)S92!F;W)E
M8V%S=`H@("`@("`@("`@("`D9F]R96-A<W12971U<FX@(#T@)'1H:7,M/E]P
M87)S949O<F5C87-T1&%T82@D9F]R96-A<W1$871A*3L*"B`@("`@("`@("`@
M(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1F;W)E8V%S=%)E='5R
M;BDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D9F]R96-A<W12971U<FX[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1T:&ES+3Y?8V%C:&5%
M;F%B;&5D*2!["B`@("`@("`@("`@("`@("`O+R!#86-H92!W96%T:&5R"B`@
M("`@("`@("`@("`@("`D97AP:7)E(#T@8V]N<W1A;G0H(E-%4E9)0T537U=%
M051(15)?15A025)%4U]&3U)%0T%35"(I.PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]C86-H92T^97AT4V%V92@B345405(M(BXD:60L("1F;W)E8V%S=%)E
M='5R;BP@)'5N:71S1F]R;6%T+"`D97AP:7)E+"`B9F]R96-A<W0B*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7V9O<F5C87-T(#T@)&9O
M<F5C87-T4F5T=7)N.PH@("`@("`@("`@("`D9F]R96-A<W12971U<FY;(F-A
M8VAE(ET@/2`B34E34R(["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V-O
M;G9E<G12971U<FXH)&9O<F5C87-T4F5T=7)N+"`D=6YI=',L("1L;V-A=&EO
M;BD["@H@("`@("`@(')E='5R;B`D9F]R96-A<W12971U<FX["B`@("!]"B`@
M("`O+R!]?7T*?0HO+R!]?7T*/SX*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]397)V:6-E<R]796%T:&5R+U=E871H97)D;W1C;VTN<&AP````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#8S,#$P(#$P-3$U-#,S-S(W(#`R-3$W,0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*B!V
M:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T
M=&%B<W1O<#TT(&9O;&1M971H;V0];6%R:V5R.B`J+PH*+RHJ"B`J(%!%05(Z
M.E-E<G9I8V5S7U=E871H97)?5V5A=&AE<F1O=&-O;0H@*@H@*B!02%`@=F5R
M<VEO;G,@-"!A;F0@-0H@*@H@*B`\3$E#14Y313X*("H@0V]P>7)I9VAT("AC
M*2`R,#`U+"!!;&5X86YD97(@5VER='H*("H@06QL(')I9VAT<R!R97-E<G9E
M9"X*("H*("H@4F5D:7-T<FEB=71I;VX@86YD('5S92!I;B!S;W5R8V4@86YD
M(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T"B`J(&UO9&EF:6-A=&EO
M;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F;VQL;W=I;F<@
M8V]N9&ET:6]N<PH@*B!A<F4@;65T.@H@*B!O(%)E9&ES=')I8G5T:6]N<R!O
M9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I9VAT
M(&YO=&EC92P*("H@("!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE
M(&9O;&QO=VEN9R!D:7-C;&%I;65R+@H@*B!O(%)E9&ES=')I8G5T:6]N<R!I
M;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C92!T:&4@86)O=F4@8V]P>7)I
M9VAT(&YO=&EC92P*("H@("!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@
M=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN('1H92!D;V-U;65N=&%T:6]N
M"B`J("`@86YD+V]R(&]T:&5R(&UA=&5R:6%L<R!P<F]V:61E9"!W:71H('1H
M92!D:7-T<FEB=71I;VXN"B`J(&\@3F5I=&AE<B!T:&4@;F%M92!O9B!T:&4@
M<V]F='=A<F4@;F]R('1H92!N86UE<R!O9B!I=',@8V]N=')I8G5T;W)S"B`J
M("`@;6%Y(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E('!R;V1U8W1S
M(&1E<FEV960@9G)O;2!T:&ES('-O9G1W87)E"B`J("`@=VET:&]U="!S<&5C
M:69I8R!P<FEO<B!W<FET=&5N('!E<FUI<W-I;VXN"B`J"B`J(%1(25,@4T]&
M5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($-/4%E224=(5"!(3TQ$15)3($%.
M1"!#3TY44DE"551/4E,@(D%3($E3(@H@*B!!3D0@04Y9($584%)%4U,@3U(@
M24U03$E%1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.3U0@3$E-251%
M1"!43RP@5$A%"B`J($E-4$Q)140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"
M24Q)5%D@04Y$($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!4B!055)03U-%"B`J
M($%212!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4@0T]065))
M1TA4($]73D52($]2($-/3E1224)55$]24R!"10H@*B!,24%"3$4@1D]2($%.
M62!$25)%0U0L($E.1$E214-4+"!)3D-)1$5.5$%,+"!34$5#24%,+"!%6$5-
M4$Q!4EDL($]2"B`J($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'
M+"!"550@3D]4($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&"B`J(%-50E-4
M25155$4@1T]/1%,@3U(@4T525DE#15,[($Q/4U,@3T8@55-%+"!$051!+"!/
M4B!04D]&2513.R!/4B!"55-)3D534PH@*B!)3E1%4E)54%1)3TXI($A/5T56
M15(@0T%54T5$($%.1"!/3B!!3ED@5$A%3U)9($]&($Q)04))3$E462P@5TA%
M5$A%4B!)3@H@*B!#3TY44D%#5"P@4U1224-4($Q)04))3$E462P@3U(@5$]2
M5"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*0H@*B!!4DE3
M24Y'($E.($%.62!705D@3U54($]&(%1(12!54T4@3T8@5$A)4R!33T945T%2
M12P@159%3B!)1B!!1%9)4T5$($]&(%1(10H@*B!03U-324))3$E462!/1B!3
M54-(($1!34%'12X*("H@/"],24-%3E-%/@H@*@H@*B!`8V%T96=O<GD@("`@
M5V5B(%-E<G9I8V5S"B`J($!P86-K86=E("`@("!397)V:6-E<U]796%T:&5R
M"B`J($!A=71H;W(@("`@("!!;&5X86YD97(@5VER='H@/&%L97A`<&,T<"YN
M970^"B`J($!C;W!Y<FEG:'0@("`R,#`U($%L97AA;F1E<B!7:7)T>@H@*B!`
M;&EC96YS92`@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E
M<R]B<V0M;&EC96YS92YP:'`@($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@
M("!#5E,Z("1)9#H@5V5A=&AE<F1O=&-O;2YP:'`L=B`Q+C4X(#(P,#4O,3$O
M,3<@,#@Z,3DZ-#(@97)U($5X<"`D"B`J($!L:6YK("`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O4V5R=FEC97-?5V5A=&AE<@H@*B!`;&EN
M:R`@("`@("`@:'1T<#HO+W=W=RYW96%T:&5R+F-O;2]S97)V:6-E<R]X;6QO
M87`N:'1M;`H@*B!`97AA;7!L92`@("`@97AA;7!L97,O=V5A=&AE<BYC;VTM
M8F%S:6,N<&AP("`@("`@=V5A=&AE<BYC;VTM8F%S:6,N<&AP"B`J($!E>&%M
M<&QE("`@("!E>&%M<&QE<R]W96%T:&5R+F-O;2UE>'1E;G-I=F4N<&AP("!W
M96%T:&5R+F-O;2UE>'1E;G-I=F4N<&AP"B`J($!F:6QE<V]U<F-E"B`J+PH*
M<F5Q=6ER95]O;F-E(")397)V:6-E<R]796%T:&5R+T-O;6UO;BYP:'`B.PH*
M+R\@>WM[(&-L87-S(%-E<G9I8V5S7U=E871H97)?5V5A=&AE<F1O=&-O;0HO
M*BH*("H@5&AI<R!C;&%S<R!A8W1S(&%S(&%N(&EN=&5R9F%C92!T;R!T:&4@
M>&UL('-E<G9I8V4@;V8@=V5A=&AE<BYC;VTN($ET"B`J('-E87)C:&5S(&9O
M<B!G:79E;B!L;V-A=&EO;G,@86YD(')E=')I979E<R!C=7)R96YT('=E871H
M97(@9&%T82!A<R!W96QL"B`J(&%S(&9O<F5C87-T(&9O<B!U<"!T;R`Q,"!D
M87ES+@H@*@H@*B!&;W(@=7-I;F<@=&AE('=E871H97(N8V]M('AM;"US97)V
M:6-E('!L96%S92!V:7-I=`H@*B`@("`@:'1T<#HO+W=W=RYW96%T:&5R+F-O
M;2]S97)V:6-E<R]X;6QO87`N:'1M;`H@*B!A;F0@9F]L;&]W('1H92!L:6YK
M('1O('-I9VX@=7`L(&ET)W,@9G)E92$@66]U('=I;&P@<F5C96EV92!A;B!E
M;6%I;`H@*B!W:&5R92!T;R!D;W=N;&]A9"!T:&4@4T1+('=I=&@@=&AE(&YE
M961E9"!I;6%G97,@86YD(&=U:61E;&EN97,@:&]W('1O"B`J('!U8FQI<V@@
M;&EV92!D871A(&9R;VT@=V5A=&AE<BYC;VTN(%5N9F]R='5N871E;'D@=&AE
M(&=U:61E;&EN97,@87)E(&$*("H@8FET(&AA<G-H+"!T:&%T)W,@=VAY('1H
M97)E)W,@;F\@86-T=6%L(&1A=&$M<F5P<F5S96YT871I;VX@:6X@=&AI<PH@
M*B!C;&%S<RP@:G5S="!T:&4@<F%W(&1A=&$N($%L<V\@=V5A=&AE<BYC;VT@
M9&5M86YD<R!A8W1I=F4@8V%C:&EN9RP@<V\@22=D"B`J('-T<F]N9VQY(')E
M8V]M;65N9"!E;F%B;&EN9R!T:&4@8V%C:&EN9R!I;7!L96UE;G1E9"!I;B!T
M:&ES(&-L87-S+B!)=`H@*B!O8F5Y<R!T;R!T:&4@=&EM97,@87,@=W)I='1E
M;B!D;W=N(&EN('1H92!G=6ED96QI;F5S+@H@*@H@*B!&;W(@=V]R:VEN9R!E
M>&%M<&QE<RP@<&QE87-E('1A:V4@82!L;V]K(&%T"B`J("`@("!D;V-S+U-E
M<G9I8V5S7U=E871H97(O97AA;7!L97,O=V5A=&AE<BYC;VTM8F%S:6,N<&AP
M"B`J("`@("!D;V-S+U-E<G9I8V5S7U=E871H97(O97AA;7!L97,O=V5A=&AE
M<BYC;VTM97AT96YS:79E+G!H<`H@*@H@*B!`8V%T96=O<GD@("`@5V5B(%-E
M<G9I8V5S"B`J($!P86-K86=E("`@("!397)V:6-E<U]796%T:&5R"B`J($!A
M=71H;W(@("`@("!!;&5X86YD97(@5VER='H@/&%L97A`<&,T<"YN970^"B`J
M($!C;W!Y<FEG:'0@("`R,#`U($%L97AA;F1E<B!7:7)T>@H@*B!`;&EC96YS
M92`@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M
M;&EC96YS92YP:'`@($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@("!296QE
M87-E.B`Q+C0N,`H@*B!`;&EN:R`@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE
M="]P86-K86=E+U-E<G9I8V5S7U=E871H97(*("H@0&QI;FL@("`@("`@(&AT
M='`Z+R]W=W<N=V5A=&AE<BYC;VTO<V5R=FEC97,O>&UL;V%P+FAT;6P*("H@
M0&5X86UP;&4@("`@(&5X86UP;&5S+W=E871H97(N8V]M+6)A<VEC+G!H<"`@
M("`@('=E871H97(N8V]M+6)A<VEC+G!H<`H@*B!`97AA;7!L92`@("`@97AA
M;7!L97,O=V5A=&AE<BYC;VTM97AT96YS:79E+G!H<"`@=V5A=&AE<BYC;VTM
M97AT96YS:79E+G!H<`H@*B\*8VQA<W,@4V5R=FEC97-?5V5A=&AE<E]796%T
M:&5R9&]T8V]M(&5X=&5N9',@4V5R=FEC97-?5V5A=&AE<E]#;VUM;VX@>PH*
M("`@("\O('M[>R!P<F]P97)T:65S"B`@("`O*BH*("`@("`J(%!A<G1N97(M
M240@870@=V5A=&AE<BYC;VT*("`@("`J"B`@("`@*B!`=F%R("`@("!S=')I
M;F<@("`@("`@("`@("`@("`@("`@("`@)%]P87)T;F5R240*("`@("`J($!A
M8V-E<W,@('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?<&%R=&YE<DE$(#T@
M(B(["@H@("`@+RHJ"B`@("`@*B!,:6-E;G-E(&ME>2!A="!W96%T:&5R+F-O
M;0H@("`@("H*("`@("`J($!V87(@("`@('-T<FEN9R`@("`@("`@("`@("`@
M("`@("`@("`D7VQI8V5N<V5+97D*("`@("`J($!A8V-E<W,@('!R:79A=&4*
M("`@("`J+PH@("`@=F%R("1?;&EC96YS94ME>2`]("(B.PH*("`@("\J*@H@
M("`@("H@4W=I=&-H('1O('1O9V=L92!P<F4M9F5T8VAI;F<@;V8@9&%T82!I
M;B!O;F4@<VEN9VQE(')E<75E<W0*("`@("`J"B`@("`@*B!`=F%R("`@("!B
M;V]L("`@("`@("`@("`@("`@("`@("`@("`@)%]P<F5&971C:`H@("`@("H@
M0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("`@=F%R("1?<')E1F5T8V@@
M/2!F86QS93L*"B`@("`O*BH*("`@("`J($]B:F5C="!C;VYT86EN:6YG('1H
M92!P<F]M;W1I;VYA;"!L:6YK<RUD871A"B`@("`@*@H@("`@("H@0'9A<B`@
M("`@;V)J96-T('-T9$-L87-S("`@("`@("`@("`@("1?;&EN:W,*("`@("`J
M($!A8V-E<W,@('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?;&EN:W,["@H@
M("`@+RHJ"B`@("`@*B!834Q?56YS97)I86QI>F5R+"!U<V5D(&9O<B!P<F]C
M97-S:6YG('1H92!X;6P*("`@("`J"B`@("`@*B!`=F%R("`@("!O8FIE8W0@
M6$U,7U5N<V5R:6%L:7IE<B`@("`@)%]U;G-E<FEA;&EZ97(*("`@("`J($!A
M8V-E<W,@('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?=6YS97)I86QI>F5R
M.PH@("`@+R\@?7U]"@H@("`@+R\@>WM[(&-O;G-T<G5C=&]R"B`@("`O*BH*
M("`@("`J($-O;G-T<G5C=&]R"B`@("`@*@H@("`@("H@4F5Q=6ER97,@6$U,
M7U-E<FEA;&EZ97(@=&\@8F4@:6YS=&%L;&5D"B`@("`@*@H@("`@("H@0'!A
M<F%M("`@87)R87D@("`@("`@("`@("`@("`@("`@("`@("1O<'1I;VYS"B`@
M("`@*B!`<&%R86T@("!M:7AE9"`@("`@("`@("`@("`@("`@("`@("`@)&5R
M<F]R"B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R"B`@("`@*B!`86-C97-S
M("!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%-E<G9I8V5S7U=E871H
M97)?5V5A=&AE<F1O=&-O;2@D;W!T:6]N<RP@)B1E<G)O<BD*("`@('L*("`@
M("`@("`D<&5R<F]R(#T@;G5L;#L*("`@("`@("`D=&AI<RT^4V5R=FEC97-?
M5V5A=&AE<E]#;VUM;VXH)&]P=&EO;G,L("1P97)R;W(I.PH@("`@("`@(&EF
M("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1P97)R;W(I*2!["B`@("`@
M("`@("`@("1E<G)O<B`]("1P97)R;W(["B`@("`@("`@("`@(')E='5R;CL*
M("`@("`@("!]"@H@("`@("`@("\O(%-E="!O<'1I;VYS(&%C8V]R9&EN9VQY
M"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R)P87)T;F5R240B72DI('L*
M("`@("`@("`@("`@)'1H:7,M/G-E=$%C8V]U;G1$871A*"1O<'1I;VYS6R)P
M87)T;F5R240B72D["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D;W!T
M:6]N<ULB;&EC96YS94ME>2)=*2D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T
M06-C;W5N=$1A=&$H(B(L("1O<'1I;VYS6R)L:6-E;G-E2V5Y(ETI.PH@("`@
M("`@('T*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;(G!R949E=&-H(ETI
M*2!["B`@("`@("`@("`@("1T:&ES+3YE;F%B;&50<F5&971C:"@D;W!T:6]N
M<ULB<')E1F5T8V@B72D["B`@("`@("`@?0H*("`@("`@("!I;F-L=61E7V]N
M8V4@(EA-3"]5;G-E<FEA;&EZ97(N<&AP(CL*("`@("`@("`D=6YS97)I86QI
M>F5R(#T@)FYE=R!834Q?56YS97)I86QI>F5R*&%R<F%Y*")C;VUP;&5X5'EP
M92(@/3X@(F]B:F5C="(L(")K97E!='1R:6)U=&4B(#T^(")T>7!E(BDI.PH@
M("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1U;G-E<FEA
M;&EZ97(I*2!["B`@("`@("`@("`@("1E<G)O<B`]("1U;G-E<FEA;&EZ97([
M"B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D=&AI<RT^7W5N<V5R:6%L:7IE<B`]("1U;G-E<FEA;&EZ97(["B`@
M("`@("`@?0H*("`@("`@("`O+R!#86XG="!A8W%U:7)E(&%N(&]B:F5C="!H
M97)E+"!H87,@=&\@8F4@8VQE86X@;VX@979E<GD@<F5Q=65S=`H@("`@("`@
M(&EN8VQU9&5?;VYC92`B2%144"]297%U97-T+G!H<"(["B`@("!]"B`@("`O
M+R!]?7T*"B`@("`O+R![>WL@<V5T06-C;W5N=$1A=&$H*0H@("`@+RHJ"B`@
M("`@*B!3971S('1H92!N96-C97-S87)Y(&%C8V]U;G0M:6YF;W)M871I;VX@
M9F]R('=E871H97(N8V]M+"!Y;W4G;&P*("`@("`J(')E8V5I=F4@=&AE;2!A
M9G1E<B!R96=I<W1E<FEN9R!F;W(@=&AE(%A-3"US=')E86T*("`@("`J"B`@
M("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)'!A
M<G1N97))1`H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@
M("`@("`@("1L:6-E;G-E2V5Y"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V5T06-C;W5N=$1A=&$H)'!A<G1N97))1"P@
M)&QI8V5N<V5+97DI"B`@("!["B`@("`@("`@:68@*'-T<FQE;B@D<&%R=&YE
M<DE$*2`F)B!C='EP95]D:6=I="@D<&%R=&YE<DE$*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7W!A<G1N97))1"`@/2`D<&%R=&YE<DE$.PH@("`@("`@('T*
M("`@("`@("!I9B`H<W1R;&5N*"1L:6-E;G-E2V5Y*2`F)B!C='EP95]A;&YU
M;2@D;&EC96YS94ME>2DI('L*("`@("`@("`@("`@)'1H:7,M/E]L:6-E;G-E
M2V5Y(#T@)&QI8V5N<V5+97D["B`@("`@("`@?0H@("`@?0H@("`@+R\@?7U]
M"@H@("`@+R\@>WM[(&5N86)L95!R949E=&-H*"D*("`@("\J*@H@("`@("H@
M16YA8FQE<R!P<F4M9F5T8VAI;F<@;V8@9&%T82!I;B!O;F4@<VEN9VQE(')E
M<75E<W0*("`@("`J"B`@("`@*B!`<&%R86T@("!B;V]L("`@("`@("`@("`@
M("`@("`@("`@("`@)'!R949E=&-H"B`@("`@*B!`86-C97-S("!P=6)L:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@96YA8FQE4')E1F5T8V@H)'!R949E=&-H
M*0H@("`@>PH@("`@("`@(&EF("@D<')E1F5T8V@@/3T@=')U92D@>PH@("`@
M("`@("`@("`D=&AI<RT^7W!R949E=&-H(#T@=')U93L*("`@("`@("!]"B`@
M("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@7V-H96-K3&]C871I;VY)1"@I
M"B`@("`O*BH*("`@("`J($-H96-K<R!T:&4@:60@9F]R('9A;&ED('9A;'5E
M<R!A;F0@=&AU<R!P<F5V96YT<R!S:6QL>2!R97%U97-T<R!T;PH@("`@("H@
M=V5A=&AE<BYC;VT@<V5R=F5R"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R
M:6YG("`@("`@("`@("`@("`@("`@("`@("1I9`H@("`@("H@0')E='5R;B`@
M4$5!4E]%<G)O<GQB;V]L"B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R.CI3
M15)624-%4U]714%42$527T524D]27TY/7TQ/0T%424]."B`@("`@*B!`=&AR
M;W=S("!014%27T5R<F]R.CI315)624-%4U]714%42$527T524D]27TE.5D%,
M241?3$]#051)3TX*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V-H96-K3&]C871I;VY)1"@D:60I"B`@("!["B`@("`@
M("`@:68@*&ES7V%R<F%Y*"1I9"D@?'P@:7-?;V)J96-T*"1I9"D@?'P@(7-T
M<FQE;B@D:60I*2!["B`@("`@("`@("`@(')E='5R;B!397)V:6-E<U]796%T
M:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?15)23U)?3D]?3$]#
M051)3TXL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?2!E;'-E:68@
M*"%C='EP95]A;&YU;2@D:60I('Q\("AS=')L96XH)&ED*2`^(#@I*2!["B`@
M("`@("`@("`@(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R
M*%-%4E9)0T537U=%051(15)?15)23U)?24Y604Q)1%],3T-!5$E/3BP@7U]&
M24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[(%]P87)S95=E871H
M97)$871A*"D*("`@("\J*@H@("`@("H@1F5T8VAE<R!T:&4@9&%T82!B87-E
M9"!O;B!T:&4@<F5Q=65S=&5D('1Y<&4@86YD(&-A8VAE<R!I=`H@("`@("H*
M("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D
M:60*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@
M("`D<F5Q5'EP90H@("`@("H@0')E='5R;B`@4$5!4E]%<G)O<GQB;V]L"B`@
M("`@*B!`=&AR;W=S("!014%27T5R<F]R.CI315)624-%4U]714%42$527T52
M4D]27U=23TY'7U-%4E9%4E]$051!"B`@("`@*B!`=&AR;W=S("!014%27T5R
M<F]R"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]P87)S95=E871H97)$871A*"1I9"P@)')E<51Y<&4I"B`@("!["B`@
M("`@("`@:68@*"1T:&ES+3Y?<')E1F5T8V@I('L*("`@("`@("`@("`@)')E
M<51Y<&4@/2`B86QL(CL*("`@("`@("!]"@H@("`@("`@("1U<FP@/2`B:'1T
M<#HO+WAO87`N=V5A=&AE<BYC;VTO=V5A=&AE<B]L;V-A;"\B+B1I9"XB/W!R
M;V0]>&]A<"9P87(](BXD=&AI<RT^7W!A<G1N97))1"XB)FME>3TB+B1T:&ES
M+3Y?;&EC96YS94ME>3L*"B`@("`@("`@<W=I=&-H("@D<F5Q5'EP92D@>PH@
M("`@("`@("`@("!C87-E(")L:6YK<R(Z"B`@("`@("`@("`@("`@("`D=7)L
M("X]("(F;&EN:SUX;V%P(CL*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("!C87-E(")W96%T:&5R(CH*("`@("`@("`@("`@("`@("1U<FP@
M+CT@(B9C8STJ)G5N:70]<R(["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@8V%S92`B9F]R96-A<W0B.@H@("`@("`@("`@("`@("`@)'5R
M;"`N/2`B)F1A>68],3`F=6YI=#US(CL*("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("!C87-E(")A;&PB.@H@("`@("`@("`@("`@("`@)'5R
M;"`N/2`B)FQI;FL]>&]A<"9C8STJ)F1A>68],3`F=6YI=#US(CL*("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@+R\@1V5T(&1A
M=&$@9G)O;2!54DPN+BX*("`@("`@("`D<F5Q=65S="`]("9N97<@2%144%]2
M97%U97-T*"1U<FPL("1T:&ES+3Y?:'1T<$]P=&EO;G,I.PH@("`@("`@("1S
M=&%T=7,@/2`D<F5Q=65S="T^<V5N9%)E<75E<W0H*3L*("`@("`@("!I9B`H
M4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2!\?"`H:6YT*2`D
M<F5Q=65S="T^9V5T4F5S<&]N<V5#;V1E*"D@/#X@,C`P*2!["B`@("`@("`@
M("`@(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)
M0T537U=%051(15)?15)23U)?5U)/3D=?4T525D527T1!5$$L(%]?1DE,15]?
M+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@("`@("1D871A(#T@)')E<75E
M<W0M/F=E=%)E<W!O;G-E0F]D>2@I.PH*("`@("`@("`O+R`N+BYA;F0@=6YS
M97)I86QI>F4*("`@("`@("`D<W1A='5S(#T@)'1H:7,M/E]U;G-E<FEA;&EZ
M97(M/G5N<V5R:6%L:7IE*"1D871A*3L*"B`@("`@("`@:68@*%-E<G9I8V5S
M7U=E871H97(Z.FES17)R;W(H)'-T871U<RDI('L*("`@("`@("`@("`@<F5T
M=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!
M5$A%4E]%4E)/4E]74D].1U]315)615)?1$%402P@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F]O="`]("1T
M:&ES+3Y?=6YS97)I86QI>F5R+3YG9712;V]T3F%M92@I.PH@("`@("`@("`@
M("`D9&%T82`]("1T:&ES+3Y?=6YS97)I86QI>F5R+3YG9715;G-E<FEA;&EZ
M961$871A*"D["@H@("`@("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ
M:7-%<G)O<B@D<F]O="D@?'P@)')O;W0@/3T@(DA434PB*2!["B`@("`@("`@
M("`@("`@("`O+R!3;VUE=&AI;F<@=W)O;F<@:&5R92P@;6%Y8F4@;F]T(%A-
M3"!R971R:65V960N+BX*("`@("`@("`@("`@("`@(')E='5R;B!397)V:6-E
M<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?15)23U)?
M5U)/3D=?4T525D527T1!5$$L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@
M("`@("`@('T@96QS96EF("@D<F]O="`]/2`B97)R;W(B*2!["B`@("`@("`@
M("`@("`@("`O+R!792!G;W0@86X@97)R;W(@8F%C:R!F<F]M('=E871H97(N
M8V]M"B`@("`@("`@("`@("`@("`D97)R;F\@(#T@:V5Y*&=E=%]O8FIE8W1?
M=F%R<R@D9&%T82DI.PH@("`@("`@("`@("`@("`@<F5T=7)N(%-E<G9I8V5S
M7U=E871H97(Z.G)A:7-E17)R;W(H)&5R<FYO+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+R\@
M5F%L:60@9&%T82P@;&5T<R!G970@<W1A<G1E9`H@("`@("`@("`@("`@("`@
M+R\@3&]O<"!T:')O=6=H('1H92!D:69F97)E;G0@<W5B+7!A<G1S(&]F('1H
M92!D871A(&9R;R!P<F]C97-S:6YG"B`@("`@("`@("`@("`@("!F;W)E86-H
M("AG971?;V)J96-T7W9A<G,H)&1A=&$I(&%S("1K97D@/3X@)'9A;"D@>PH@
M("`@("`@("`@("`@("`@("`@('-W:71C:"`H)&ME>2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("!C87-E(")H96%D(CH*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&-O;G1I;G5E(#(["B`@("`@("`@("`@("`@("`@("`@("`@
M(&-A<V4@(G!R;6\B.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A
M<FYA;64@(#T@(FQI;FMS(CL*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")L;V,B.@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64@(#T@(FQO8V%T
M:6]N(CL*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@("`@("`@("!C87-E(")C8R(Z"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=F%R;F%M92`@/2`B=V5A=&AE<B(["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@
M("`@("`@8V%S92`B9&%Y9B(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=F%R;F%M92`@/2`B9F]R96-A<W0B.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@("\O(%-A=F4@9&%T82!I;B!O8FIE8W0*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^>R)?(BXD=F%R;F%M97T@/2`D=F%L.PH@("`@
M("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7V-A8VAE16YA8FQE9"D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`O+R`N+BYA;F0@8V%C:&4@:68@<&]S
M<VEB;&4*("`@("`@("`@("`@("`@("`@("`@("`@)&5X<&ER92`](&-O;G-T
M86YT*")315)624-%4U]714%42$527T584$E215-?(BYS=')T;W5P<&5R*"1V
M87)N86UE*2D["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8V%C
M:&4M/F5X=%-A=F4H)&ED+"`D=F%L+"`B(BP@)&5X<&ER92P@)'9A<FYA;64I
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@<V5A<F-H3&]C871I;VXH*0H@
M("`@+RHJ"B`@("`@*B!396%R8VAE<R!)1',@9F]R(&=I=F5N(&QO8V%T:6]N
M+"!R971U<FYS(&%R<F%Y(&]F('!O<W-I8FQE(&QO8V%T:6]N<PH@("`@("H@
M;W(@<VEN9VQE($E$"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@
M("`@("`@("`@("`@("`@("`@("1L;V-A=&EO;@H@("`@("H@0'!A<F%M("`@
M8F]O;"`@("`@("`@("`@("`@("`@("`@("`@("1U<V5&:7)S="`@("`@("!)
M9B!S970L(&9I<G-T($E$(&]F(')E<W5L="UA<G)A>2!I<R!R971U<FYE9`H@
M("`@("H@0')E='5R;B`@4$5!4E]%<G)O<GQA<G)A>7QS=')I;F<*("`@("`J
M($!T:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?
M5U)/3D=?4T525D527T1!5$$*("`@("`J($!T:')O=W,@(%!%05)?17)R;W(Z
M.E-%4E9)0T537U=%051(15)?15)23U)?54Y+3D]73E],3T-!5$E/3@H@("`@
M("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('-E87)C
M:$QO8V%T:6]N*"1L;V-A=&EO;BP@)'5S949I<G-T(#T@9F%L<V4I"B`@("![
M"B`@("`@("`@)&QO8V%T:6]N(#T@=')I;2@D;&]C871I;VXI.PH@("`@("`@
M("1L;V-,;W<@("`]('-T<G1O;&]W97(H)&QO8V%T:6]N*3L*("`@("`@("`*
M("`@("`@("`O+R!#:&5C:R!O;B!C86-H960@9&%T83H@340U+6AA<V@@;V8@
M;&]C871I;VX@:&%S('1O(&)E(&-O<G)E8W0@86YD('1H92!U<V5R9&%T82!H
M87,@=&\@8F4@=&AE('-A;64@87,@=&AE(&=I=F5N(&QO8V%T:6]N(`H@("`@
M("`@(&EF("@D=&AI<RT^7V-A8VAE16YA8FQE9"`F)B`D;&]C3&]W(#T]("1T
M:&ES+3Y?8V%C:&4M/F=E=%5S97)$871A*&UD-2@D;&]C3&]W*2P@(G-E87)C
M:"(I*2!["B`@("`@("`@("`@("1S96%R8V@@/2`D=&AI<RT^7V-A8VAE+3YG
M970H;60U*"1L;V-,;W<I+"`B<V5A<F-H(BD["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@+R\@1V5T('-E87)C:"!D871A(&9R;VT@<V5R=F5R(&%N
M9"!U;G-E<FEA;&EZ90H@("`@("`@("`@("`D<F5Q=65S="`]("9N97<@2%14
M4%]297%U97-T*")H='1P.B\O>&]A<"YW96%T:&5R+F-O;2]S96%R8V@O<V5A
M<F-H/W=H97)E/2(N=7)L96YC;V1E*"1L;V-A=&EO;BDL("1T:&ES+3Y?:'1T
M<$]P=&EO;G,I.PH@("`@("`@("`@("`D<W1A='5S(#T@)')E<75E<W0M/G-E
M;F1297%U97-T*"D["B`@("`@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R
M.CII<T5R<F]R*"1S=&%T=7,I('Q\("AI;G0I("1R97%U97-T+3YG971297-P
M;VYS94-O9&4H*2`\/B`R,#`I('L*("`@("`@("`@("`@("`@(')E='5R;B!3
M97)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?
M15)23U)?5U)/3D=?4T525D527T1!5$$L(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&1A=&$@/2`D<F5Q=65S="T^
M9V5T4F5S<&]N<V5";V1Y*"D["B`@("`*("`@("`@("`@("`@+R\@+BXN86YD
M('5N<V5R:6%L:7IE"B`@("`@("`@("`@("1S=&%T=7,@/2`D=&AI<RT^7W5N
M<V5R:6%L:7IE<BT^=6YS97)I86QI>F4H)&1A=&$L(&9A;'-E+"!A<G)A>2@B
M;W9E<G)I9&5/<'1I;VYS(B`]/B!T<G5E+"`B8V]M<&QE>%1Y<&4B(#T^(")A
M<G)A>2(L(")K97E!='1R:6)U=&4B(#T^(")I9"(I*3L*("`@(`H@("`@("`@
M("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A
M:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%4E)/4E]74D].1U]315)615)?
M1$%402P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@?0H@("`@
M"B`@("`@("`@("`@("1R;V]T(#T@)'1H:7,M/E]U;G-E<FEA;&EZ97(M/F=E
M=%)O;W1.86UE*"D["B`@("`@("`@("`@("1S96%R8V@@/2`D=&AI<RT^7W5N
M<V5R:6%L:7IE<BT^9V5T56YS97)I86QI>F5D1&%T82@I.PH@("`@"B`@("`@
M("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1S96%R8V@I
M('Q\("1R;V]T(#T](")(5$U,(BD@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%
M4E]%4E)/4E]74D].1U]315)615)?1$%402P@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("`@("`@?2!E;'-E:68@*"%I<U]A<G)A>2@D<V5A<F-H*2!\
M?"`A<VEZ96]F*"1S96%R8V@I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$52
M7T524D]27U5.2TY/5TY?3$]#051)3TXL(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D=&AI<RT^7V-A8VAE
M16YA8FQE9"D@>PH@("`@("`@("`@("`@("`@+R\@+BXN86YD(&-A8VAE(&EF
M('!O<W-I8FQE"B`@("`@("`@("`@("`@("`D97AP:7)E(#T@8V]N<W1A;G0H
M(E-%4E9)0T537U=%051(15)?15A025)%4U]314%20T@B*3L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?8V%C:&4M/F5X=%-A=F4H;60U*"1L;V-,;W<I+"`D
M<V5A<F-H+"`D;&]C3&]W+"`D97AP:7)E+"`B<V5A<F-H(BD["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@A)'5S949I<G-T("8F("AS
M:7IE;V8H)'-E87)C:"D@/B`Q*2D@>PH@("`@("`@("`@("`D<V5A<F-H4F5T
M=7)N(#T@)'-E87)C:#L*("`@("`@("!](&5L<V5I9B`H)'5S949I<G-T('Q\
M("AS:7IE;V8H)'-E87)C:"D@/3T@,2DI('L*("`@("`@("`@("`@)'-E87)C
M:%)E='5R;B`](&ME>2@D<V5A<F-H*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D<V5A<F-H4F5T=7)N.PH@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@
M>WM[('-E87)C:$QO8V%T:6]N0GE#;W5N=')Y*"D*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!O;FQY(&9A;'-E+"!A<R!W96%T:&5R+F-O;2!O9F9E<G,@;F\@
M8V]U;G1R>2!L:7-T:6YG('9I80H@("`@("H@:71S(%A-3"!S97)V:6-E<PH@
M("`@("H*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@("`@("`@
M("`@("`D8V]U;G1R>0H@("`@("H@0')E='5R;B`@8F]O;`H@("`@("H@0&%C
M8V5S<R`@<'5B;&EC"B`@("`@*B!`9&5P<F5C871E9`H@("`@("HO"B`@("!F
M=6YC=&EO;B!S96%R8VA,;V-A=&EO;D)Y0V]U;G1R>2@D8V]U;G1R>2`]("(B
M*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*("`@("\O('U]
M?0H*("`@("\O('M[>R!G971,:6YK<R@I"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE(&1A=&$@9F]R('1H92!P<F]M;W1I;VYA;"!L:6YK<R!B96QO;F=I
M;F<@=&\@=&AE($E$"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@
M("`@("`@("`@("`@("`@("`@("1I9`H@("`@("H@0')E='5R;B`@4$5!4E]%
M<G)O<GQA<G)A>0H@("`@("H@0'1H<F]W<R`@4$5!4E]%<G)O<@H@("`@("H@
M0&%C8V5S<R`@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$QI;FMS
M*"1I9"`]("(B*0H@("`@>PH@("`@("`@("1S=&%T=7,@/2`D=&AI<RT^7V-H
M96-K3&]C871I;VY)1"@D:60I.PH*("`@("`@("!I9B`H4V5R=FEC97-?5V5A
M=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'-T871U<SL*("`@("`@("!]"@H@("`@("`@("1L:6YK<U)E='5R;B`](&%R
M<F%Y*"D["@H@("`@("`@(&EF("@D=&AI<RT^7V-A8VAE16YA8FQE9"`F)B`H
M)&QI;FMS(#T@)'1H:7,M/E]C86-H92T^9V5T*"1I9"P@(FQI;FMS(BDI*2![
M"B`@("`@("`@("`@("\O($=E="!D871A(&9R;VT@8V%C:&4*("`@("`@("`@
M("`@)'1H:7,M/E]L:6YK<R`]("1L:6YK<SL*("`@("`@("`@("`@)&QI;FMS
M4F5T=7)N6R)C86-H92)=(#T@(DA)5"(["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@+R\@4V%M92!A<R!I;B!T:&4@9G5N8W1I;VX@86)O=F4N+BX*
M("`@("`@("`@("`@)'-T871U<R`]("1T:&ES+3Y?<&%R<V5796%T:&5R1&%T
M82@D:60L(")L:6YK<R(I.PH*("`@("`@("`@("`@:68@*%-E<G9I8V5S7U=E
M871H97(Z.FES17)R;W(H)'-T871U<RDI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D<W1A='5S.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1L:6YK
M<U)E='5R;ELB8V%C:&4B72`](")-25-3(CL*("`@("`@("!]"@H@("`@("`@
M("1L:6YK<U)E='5R;ELB<')O;6\B72`](&%R<F%Y*"D["B`@("`@("`@9F]R
M("@D:2`](#`[("1I(#P@<VEZ96]F*"1T:&ES+3Y?;&EN:W,M/FQI;FLI.R`D
M:2LK*2!["B`@("`@("`@("`@("1L:6YK<U)E='5R;ELB<')O;6\B75LD:5T@
M/2!A<G)A>2@I.PH@("`@("`@("`@("`D;&EN:W-2971U<FY;(G!R;VUO(EU;
M)&E=6R)T:71L92)=(#T@)'1H:7,M/E]L:6YK<RT^;&EN:ULD:5TM/G0["B`@
M("`@("`@("`@("\O($(P<FME9"!R97-P;VYS92`H<F5T=7)N960@:7,@)G!A
M<CUX;V%P+"!S:&]U;&0@8F4@)G!R;V0]>&]A<"DL(&9I>"!I=`H@("`@("`@
M("`@("`D;&EN:W-2971U<FY;(G!R;VUO(EU;)&E=6R)L:6YK(ET@(#T@<W1R
M7W)E<&QA8V4H(G!A<CTB+"`B<')O9#TB+"`D=&AI<RT^7VQI;FMS+3YL:6YK
M6R1I72T^;"D["B`@("`@("`@("`@("1L:6YK<U)E='5R;ELB<')O;6\B75LD
M:5U;(FQI;FLB72`N/2`B)G!A<CTB+B1T:&ES+3Y?<&%R=&YE<DE$.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1L:6YK<U)E='5R;CL*("`@('T*("`@
M("\O('U]?0H*("`@("\O('M[>R!G971,;V-A=&EO;B@I"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE(&1A=&$@9F]R('1H92!L;V-A=&EO;B!B96QO;F=I
M;F<@=&\@=&AE($E$"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@
M("`@("`@("`@("`@("`@("`@("1I9`H@("`@("H@0')E='5R;B`@4$5!4E]%
M<G)O<GQA<G)A>0H@("`@("H@0'1H<F]W<R`@4$5!4E]%<G)O<@H@("`@("H@
M0&%C8V5S<R`@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$QO8V%T
M:6]N*"1I9"`]("(B*0H@("`@>PH@("`@("`@("1S=&%T=7,@/2`D=&AI<RT^
M7V-H96-K3&]C871I;VY)1"@D:60I.PH*("`@("`@("!I9B`H4V5R=FEC97-?
M5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'-T871U<SL*("`@("`@("!]"@H@("`@("`@("1L;V-A=&EO;E)E='5R
M;B`](&%R<F%Y*"D["@H@("`@("`@(&EF("@D=&AI<RT^7V-A8VAE16YA8FQE
M9"`F)B`H)&QO8V%T:6]N(#T@)'1H:7,M/E]C86-H92T^9V5T*"1I9"P@(FQO
M8V%T:6]N(BDI*2!["B`@("`@("`@("`@("\O($=E="!D871A(&9R;VT@8V%C
M:&4*("`@("`@("`@("`@)'1H:7,M/E]L;V-A=&EO;B`]("1L;V-A=&EO;CL*
M("`@("`@("`@("`@)&QO8V%T:6]N4F5T=7)N6R)C86-H92)=(#T@(DA)5"([
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@4V%M92!A<R!I;B!T
M:&4@9G5N8W1I;VX@86)O=F4N+BX*("`@("`@("`@("`@)'-T871U<R`]("1T
M:&ES+3Y?<&%R<V5796%T:&5R1&%T82@D:60L(")L;V-A=&EO;B(I.PH*("`@
M("`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'-T871U
M<RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<W1A='5S.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1L;V-A=&EO;E)E='5R;ELB8V%C:&4B72`]
M(")-25-3(CL*("`@("`@("!]"@H@("`@("`@("1L;V-A=&EO;E)E='5R;ELB
M;F%M92)=("`@("`@/2`D=&AI<RT^7VQO8V%T:6]N+3YD;F%M.PH@("`@("`@
M("1L;V-A=&EO;E)E='5R;ELB=&EM92)=("`@("`@/2!D871E*"1T:&ES+3Y?
M=&EM949O<FUA="P@<W1R=&]T:6UE*"1T:&ES+3Y?;&]C871I;VXM/G1M*2D[
M"B`@("`@("`@)&QO8V%T:6]N4F5T=7)N6R)L871I='5D92)=("`]("1T:&ES
M+3Y?;&]C871I;VXM/FQA=#L*("`@("`@("`D;&]C871I;VY2971U<FY;(FQO
M;F=I='5D92)=(#T@)'1H:7,M/E]L;V-A=&EO;BT^;&]N.PH@("`@("`@("1L
M;V-A=&EO;E)E='5R;ELB<W5N<FES92)=("`@/2!D871E*"1T:&ES+3Y?=&EM
M949O<FUA="P@<W1R=&]T:6UE*"1T:&ES+3Y?;&]C871I;VXM/G-U;G(I*3L*
M("`@("`@("`D;&]C871I;VY2971U<FY;(G-U;G-E=")=("`@(#T@9&%T92@D
M=&AI<RT^7W1I;65&;W)M870L('-T<G1O=&EM92@D=&AI<RT^7VQO8V%T:6]N
M+3YS=6YS*2D["B`@("`@("`@)&QO8V%T:6]N4F5T=7)N6R)T:6UE>F]N92)=
M("`]("1T:&ES+3Y?;&]C871I;VXM/GIO;F4["@H@("`@("`@(')E='5R;B`D
M;&]C871I;VY2971U<FX["B`@("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@
M9V5T5V5A=&AE<B@I"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('=E871H
M97(M9&%T82!F;W(@=&AE('-U<'!L:65D(&QO8V%T:6]N"B`@("`@*@H@("`@
M("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1I9`H@
M("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1U
M;FET<T9O<FUA=`H@("`@("H@0')E='5R;B`@4$5!4E]%<G)O<GQA<G)A>0H@
M("`@("H@0'1H<F]W<R`@4$5!4E]%<G)O<@H@("`@("H@0&%C8V5S<R`@<'5B
M;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%=E871H97(H)&ED(#T@(B(L
M("1U;FET<T9O<FUA="`]("(B*0H@("`@>PH@("`@("`@("1S=&%T=7,@/2`D
M=&AI<RT^7V-H96-K3&]C871I;VY)1"@D:60I.PH*("`@("`@("!I9B`H4V5R
M=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'-T871U<SL*("`@("`@("!]"@H@("`@("`@("\O($=E="!O
M=&AE<B!D871A"B`@("`@("`@)'5N:71S("`@(#T@)'1H:7,M/F=E=%5N:71S
M1F]R;6%T*"1U;FET<T9O<FUA="D["@H@("`@("`@("1W96%T:&5R4F5T=7)N
M(#T@87)R87DH*3L*"B`@("`@("`@:68@*"1T:&ES+3Y?8V%C:&5%;F%B;&5D
M("8F("@D=V5A=&AE<B`]("1T:&ES+3Y?8V%C:&4M/F=E="@D:60L(")W96%T
M:&5R(BDI*2!["B`@("`@("`@("`@("\O(%-A;64@<')O8V5D=7)E+BXN"B`@
M("`@("`@("`@("1T:&ES+3Y?=V5A=&AE<B`]("1W96%T:&5R.PH@("`@("`@
M("`@("`D=V5A=&AE<E)E='5R;ELB8V%C:&4B72`](")(250B.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("\O("XN+F%S(&QA<W0@9G5N8W1I;VX*
M("`@("`@("`@("`@)'-T871U<R`]("1T:&ES+3Y?<&%R<V5796%T:&5R1&%T
M82@D:60L(")W96%T:&5R(BD["@H@("`@("`@("`@("!I9B`H4V5R=FEC97-?
M5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1S=&%T=7,["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'=E
M871H97)2971U<FY;(F-A8VAE(ET@/2`B34E34R(["B`@("`@("`@?0H*("`@
M("`@("`O+R!3;VUE(&5X<&QA;F%T:6]N(&9O<B!T:&4@;F5X="!T=V\@;&EN
M97,Z"B`@("`@("`@+R\@=V5A=&AE<BYC;VT@:7-N)W0@86QW87ES('-U<'!L
M>6EN9R!T:&4@=&EM97IO;F4@:6X@=&AE('5P9&%T92!S=')I;F<L(&)U=`H@
M("`@("`@("\O('5S97,@(DQO8V%L(%1I;64B(&%S(')E9F5R96YC92P@=VAI
M8V@@:7,@:6UH;R!U='1E<FQY('-T=7!I9"P@8F5C875S92!I="=S"B`@("`@
M("`@+R\@:6YC;VYS:7-T96YT+B!796QL+"!W:&%T($D@9&\@:&5R92!I<R!C
M:&5C:R!F;W(@=&AI<R!S=')I;F<@86YD(&EF($D@8V%N"B`@("`@("`@+R\@
M9FEN9"!I="P@22!C86QC=6QA=&4@=&AE(&1I9F9E<F5N8V4@8F5T=V5E;B!T
M:&4@=&EM97IO;F4@870@=&AE(&QO8V%T:6]N"B`@("`@("`@+R\@86YD('1H
M:7,@8V]M<'5T97)S('1I;65Z;VYE+B!4:&ES(&%M;W5N="!O9B!S96-O;F1S
M(&ES('1H96X@<W5B=')A8W1E9"!F<F]M"B`@("`@("`@+R\@=&AE('1I;64@
M=&AE('5P9&%T92US=')I;F<@:&%S(&1E;&EV97)E9"X*("`@("`@("`D=7!D
M871E("`@/2!S=')?<F5P;&%C92@B3&]C86P@5&EM92(L("(B+"`D=&AI<RT^
M7W=E871H97(M/FQS=7`I.PH@("`@("`@("1A9&IU<W146B`]("@D=7!D871E
M(#T]("1T:&ES+3Y?=V5A=&AE<BT^;'-U<"D@/R`P(#H@)'1H:7,M/E]L;V-A
M=&EO;BT^>F]N92`J(#,V,#`@+2!D871E*"):(BD["B`@("`@("`@)'=E871H
M97)2971U<FY;(G5P9&%T92)=("`@("`@("`@("`@/2!G;61A=&4H=')I;2@D
M=&AI<RT^7V1A=&5&;W)M870N(B`B+B1T:&ES+3Y?=&EM949O<FUA="DL('-T
M<G1O=&EM92@D=7!D871E*2`M("1A9&IU<W146BD["B`@("`@("`@)'=E871H
M97)2971U<FY;(G5P9&%T95)A=R)=("`@("`@("`@/2`D=&AI<RT^7W=E871H
M97(M/FQS=7`["B`@("`@("`@)'=E871H97)2971U<FY;(G-T871I;VXB72`@
M("`@("`@("`@/2`D=&AI<RT^7W=E871H97(M/F]B<W0["B`@("`@("`@)'=E
M871H97)2971U<FY;(G1E;7!E<F%T=7)E(ET@("`@("`@/2`D=&AI<RT^8V]N
M=F5R=%1E;7!E<F%T=7)E*"1T:&ES+3Y?=V5A=&AE<BT^=&UP+"`B9B(L("1U
M;FET<ULB=&5M<")=*3L*("`@("`@("`D=V5A=&AE<E)E='5R;ELB9F5L=%1E
M;7!E<F%T=7)E(ET@("`]("1T:&ES+3YC;VYV97)T5&5M<&5R871U<F4H)'1H
M:7,M/E]W96%T:&5R+3YF;&EK+"`B9B(L("1U;FET<ULB=&5M<")=*3L*("`@
M("`@("`D=V5A=&AE<E)E='5R;ELB8V]N9&ET:6]N(ET@("`@("`@("`]("1T
M:&ES+3Y?=V5A=&AE<BT^=#L*("`@("`@("`D=V5A=&AE<E)E='5R;ELB8V]N
M9&ET:6]N26-O;B)=("`@("`]("1T:&ES+3Y?=V5A=&AE<BT^:6-O;CL*("`@
M("`@("`D=V5A=&AE<E)E='5R;ELB<')E<W-U<F4B72`@("`@("`@("`]("1T
M:&ES+3YC;VYV97)T4')E<W-U<F4H)'1H:7,M/E]W96%T:&5R+3YB87(M/G(L
M(")I;B(L("1U;FET<ULB<')E<R)=*3L*("`@("`@("`D=V5A=&AE<E)E='5R
M;ELB<')E<W-U<F54<F5N9")=("`@("`]("1T:&ES+3Y?=V5A=&AE<BT^8F%R
M+3YD.PH@("`@("`@("1W96%T:&5R4F5T=7)N6R)W:6YD(ET@("`@("`@("`@
M("`@(#T@)'1H:7,M/F-O;G9E<G13<&5E9"@D=&AI<RT^7W=E871H97(M/G=I
M;F0M/G,L(")M<&@B+"`D=6YI='-;(G=I;F0B72D["B`@("`@("`@)'=E871H
M97)2971U<FY;(G=I;F1'=7-T(ET@("`@("`@("`@/2`D=&AI<RT^8V]N=F5R
M=%-P965D*"1T:&ES+3Y?=V5A=&AE<BT^=VEN9"T^9W5S="P@(FUP:"(L("1U
M;FET<ULB=VEN9")=*3L*("`@("`@("`D=V5A=&AE<E)E='5R;ELB=VEN9$1E
M9W)E97,B72`@("`@("`]("1T:&ES+3Y?=V5A=&AE<BT^=VEN9"T^9#L*("`@
M("`@("`D=V5A=&AE<E)E='5R;ELB=VEN9$1I<F5C=&EO;B)=("`@("`]("1T
M:&ES+3Y?=V5A=&AE<BT^=VEN9"T^=#L*("`@("`@("`D=V5A=&AE<E)E='5R
M;ELB:'5M:61I='DB72`@("`@("`@("`]("1T:&ES+3Y?=V5A=&AE<BT^:&UI
M9#L*("`@("`@("!I9B`H:7-?;G5M97)I8R@D=&AI<RT^7W=E871H97(M/G9I
M<RDI('L*("`@("`@("`@("`@)'=E871H97)2971U<FY;(G9I<VEB:6QI='DB
M72`@("`]("1T:&ES+3YC;VYV97)T1&ES=&%N8V4H)'1H:7,M/E]W96%T:&5R
M+3YV:7,L(")S;2(L("1U;FET<ULB=FES(ETI.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1W96%T:&5R4F5T=7)N6R)V:7-I8FEL:71Y(ET@("`@
M/2`D=&AI<RT^7W=E871H97(M/G9I<SL*("`@("`@("!]"B`@("`@("`@)'=E
M871H97)2971U<FY;(G5V26YD97@B72`@("`@("`@("`@/2`D=&AI<RT^7W=E
M871H97(M/G5V+3YI.PH@("`@("`@("1W96%T:&5R4F5T=7)N6R)U=E1E>'0B
M72`@("`@("`@("`@(#T@)'1H:7,M/E]W96%T:&5R+3YU=BT^=#L*("`@("`@
M("`D=V5A=&AE<E)E='5R;ELB9&5W4&]I;G0B72`@("`@("`@("`]("1T:&ES
M+3YC;VYV97)T5&5M<&5R871U<F4H)'1H:7,M/E]W96%T:&5R+3YD97=P+"`B
M9B(L("1U;FET<ULB=&5M<")=*3L*"B`@("`@("`@<F5T=7)N("1W96%T:&5R
M4F5T=7)N.PH@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[(&=E=$9O<F5C
M87-T*"D*("`@("\J*@H@("`@("H@1V5T('1H92!F;W)E8V%S="!F;W(@=&AE
M(&YE>'0@9&%Y<PH@("`@("H*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@
M("`@("`@("`@("`@("`@("`D:60*("`@("`J($!P87)A;2`@(&EN="`@("`@
M("`@("`@("`@("`@("`@("`@("`D9&%Y<R`@("`@("`@("`@5F%L=65S(&)E
M='=E96X@,2!A;F0@,3`*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@
M("`@("`@("`@("`@("`D=6YI='-&;W)M870*("`@("`J($!R971U<FX@(%!%
M05)?17)R;W)\87)R87D*("`@("`J($!T:')O=W,@(%!%05)?17)R;W(*("`@
M("`J($!A8V-E<W,@('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!G971&
M;W)E8V%S="@D:60@/2`B(BP@)&1A>7,@/2`R+"`D=6YI='-&;W)M870@/2`B
M(BD*("`@('L*("`@("`@("`D<W1A='5S(#T@)'1H:7,M/E]C:&5C:TQO8V%T
M:6]N240H)&ED*3L*"B`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES
M17)R;W(H)'-T871U<RDI('L*("`@("`@("`@("`@<F5T=7)N("1S=&%T=7,[
M"B`@("`@("`@?0H@("`@("`@(&EF("@A:6Y?87)R87DH)&1A>7,L(')A;F=E
M*#$L(#$P*2DI('L*("`@("`@("`@("`@)&1A>7,@/2`R.PH@("`@("`@('T*
M"B`@("`@("`@+R\@1V5T(&]T:&5R(&1A=&$*("`@("`@("`D=6YI=',@("`@
M/2`D=&AI<RT^9V5T56YI='-&;W)M870H)'5N:71S1F]R;6%T*3L*"B`@("`@
M("`@)&9O<F5C87-T4F5T=7)N(#T@87)R87DH*3L*"B`@("`@("`@:68@*"1T
M:&ES+3Y?8V%C:&5%;F%B;&5D("8F("@D9F]R96-A<W0@/2`D=&AI<RT^7V-A
M8VAE+3YG970H)&ED+"`B9F]R96-A<W0B*2DI('L*("`@("`@("`@("`@+R\@
M16YC;W)E+BXN"B`@("`@("`@("`@("1T:&ES+3Y?9F]R96-A<W0@/2`D9F]R
M96-A<W0["B`@("`@("`@("`@("1F;W)E8V%S=%)E='5R;ELB8V%C:&4B72`]
M(")(250B.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O("XN+@H@
M("`@("`@("`@("`D<W1A='5S(#T@)'1H:7,M/E]P87)S95=E871H97)$871A
M*"1I9"P@(F9O<F5C87-T(BD["@H@("`@("`@("`@("!I9B`H4V5R=FEC97-?
M5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1S=&%T=7,["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&9O
M<F5C87-T4F5T=7)N6R)C86-H92)=(#T@(DU)4U,B.PH@("`@("`@('T*"B`@
M("`@("`@+R\@4V]M92!E>'!L86YA=&EO;B!F;W(@=&AE(&YE>'0@='=O(&QI
M;F5S.B`H<V%M92!A<R!A8F]V92D*("`@("`@("`O+R!W96%T:&5R+F-O;2!I
M<VXG="!A;'=A>7,@<W5P<&QY:6YG('1H92!T:6UE>F]N92!I;B!T:&4@=7!D
M871E('-T<FEN9RP@8G5T"B`@("`@("`@+R\@=7-E<R`B3&]C86P@5&EM92(@
M87,@<F5F97)E;F-E+"!W:&EC:"!I<R!I;6AO('5T=&5R;'D@<W1U<&ED+"!B
M96-A=7-E(&ET)W,*("`@("`@("`O+R!I;F-O;G-I<W1E;G0N(%=E;&PL('=H
M870@22!D;R!H97)E(&ES(&-H96-K(&9O<B!T:&ES('-T<FEN9R!A;F0@:68@
M22!C86X*("`@("`@("`O+R!F:6YD(&ET+"!)(&-A;&-U;&%T92!T:&4@9&EF
M9F5R96YC92!B971W965N('1H92!T:6UE>F]N92!A="!T:&4@;&]C871I;VX*
M("`@("`@("`O+R!A;F0@=&AI<R!C;VUP=71E<G,@=&EM97IO;F4N(%1H:7,@
M86UO=6YT(&]F('-E8V]N9',@:7,@=&AE;B!S=6)T<F%C=&5D(&9R;VT*("`@
M("`@("`O+R!T:&4@=&EM92!T:&4@=7!D871E+7-T<FEN9R!H87,@9&5L:79E
M<F5D+@H@("`@("`@("1U<&1A=&4@("`]('-T<E]R97!L86-E*"),;V-A;"!4
M:6UE(BP@(B(L("1T:&ES+3Y?9F]R96-A<W0M/FQS=7`I.PH@("`@("`@("1A
M9&IU<W146B`]("@D=7!D871E(#T]("1T:&ES+3Y?9F]R96-A<W0M/FQS=7`I
M(#\@,"`Z("1T:&ES+3Y?;&]C871I;VXM/GIO;F4@*B`S-C`P("T@9&%T92@B
M6B(I.PH@("`@("`@("1F;W)E8V%S=%)E='5R;ELB=7!D871E(ET@("`@/2!G
M;61A=&4H)'1H:7,M/E]D871E1F]R;6%T+B(@(BXD=&AI<RT^7W1I;65&;W)M
M870L('-T<G1O=&EM92@D=7!D871E*2`M("1A9&IU<W146BD["B`@("`@("`@
M)&9O<F5C87-T4F5T=7)N6R)U<&1A=&5287<B72`]("1T:&ES+3Y?9F]R96-A
M<W0M/FQS=7`["B`@("`@("`@)&9O<F5C87-T4F5T=7)N6R)D87ES(ET@("`@
M("`](&%R<F%Y*"D["@H@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1D87ES
M.R`D:2LK*2!["B`@("`@("`@("`@("1D87D@/2!A<G)A>2@*("`@("`@("`@
M("`@("`@(")T96UP97)A='5R94AI9V@B(#T^("1T:&ES+3YC;VYV97)T5&5M
M<&5R871U<F4H)'1H:7,M/E]F;W)E8V%S="T^9&%Y6R1I72T^:&DL(")F(BP@
M)'5N:71S6R)T96UP(ETI+`H@("`@("`@("`@("`@("`@(G1E;7!E<F%T=7)E
M3&]W(B`@/3X@)'1H:7,M/F-O;G9E<G1496UP97)A='5R92@D=&AI<RT^7V9O
M<F5C87-T+3YD87E;)&E=+3YL;W<L(")F(BP@)'5N:71S6R)T96UP(ETI+`H@
M("`@("`@("`@("`@("`@(G-U;G)I<V4B("`@("`@("`@/3X@9&%T92@D=&AI
M<RT^7W1I;65&;W)M870L('-T<G1O=&EM92@D=&AI<RT^7V9O<F5C87-T+3YD
M87E;)&E=+3YS=6YR*2DL"B`@("`@("`@("`@("`@("`B<W5N<V5T(B`@("`@
M("`@("`]/B!D871E*"1T:&ES+3Y?=&EM949O<FUA="P@<W1R=&]T:6UE*"1T
M:&ES+3Y?9F]R96-A<W0M/F1A>5LD:5TM/G-U;G,I*2P*("`@("`@("`@("`@
M("`@(")D87DB(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@(")C;VYD
M:71I;VXB("`@("`]/B`D=&AI<RT^7V9O<F5C87-T+3YD87E;)&E=+3YP87)T
M6S!=+3YT+`H@("`@("`@("`@("`@("`@("`@(")C;VYD:71I;VY)8V]N(B`]
M/B`D=&AI<RT^7V9O<F5C87-T+3YD87E;)&E=+3YP87)T6S!=+3YI8V]N+`H@
M("`@("`@("`@("`@("`@("`@(")W:6YD(B`@("`@("`@("`]/B`D=&AI<RT^
M8V]N=F5R=%-P965D*"1T:&ES+3Y?9F]R96-A<W0M/F1A>5LD:5TM/G!A<G1;
M,%TM/G=I;F0M/G,L(")M<&@B+"`D=6YI='-;(G=I;F0B72DL"B`@("`@("`@
M("`@("`@("`@("`@(G=I;F1'=7-T(B`@("`@(#T^("1T:&ES+3YC;VYV97)T
M4W!E960H)'1H:7,M/E]F;W)E8V%S="T^9&%Y6R1I72T^<&%R=%LP72T^=VEN
M9"T^9W5S="P@(FUP:"(L("1U;FET<ULB=VEN9")=*2P*("`@("`@("`@("`@
M("`@("`@("`B=VEN9$1E9W)E97,B("`@/3X@)'1H:7,M/E]F;W)E8V%S="T^
M9&%Y6R1I72T^<&%R=%LP72T^=VEN9"T^9"P*("`@("`@("`@("`@("`@("`@
M("`B=VEN9$1I<F5C=&EO;B(@/3X@)'1H:7,M/E]F;W)E8V%S="T^9&%Y6R1I
M72T^<&%R=%LP72T^=VEN9"T^="P*("`@("`@("`@("`@("`@("`@("`B<')E
M8VEP:71A=&EO;B(@/3X@)'1H:7,M/E]F;W)E8V%S="T^9&%Y6R1I72T^<&%R
M=%LP72T^<'!C<"P*("`@("`@("`@("`@("`@("`@("`B:'5M:61I='DB("`@
M("`@/3X@)'1H:7,M/E]F;W)E8V%S="T^9&%Y6R1I72T^<&%R=%LP72T^:&UI
M9`H@("`@("`@("`@("`@("`@*2P*("`@("`@("`@("`@("`@(")N:6=H="(@
M/3X@87)R87D@*`H@("`@("`@("`@("`@("`@("`@(")C;VYD:71I;VXB("`@
M("`]/B`D=&AI<RT^7V9O<F5C87-T+3YD87E;)&E=+3YP87)T6S%=+3YT+`H@
M("`@("`@("`@("`@("`@("`@(")C;VYD:71I;VY)8V]N(B`]/B`D=&AI<RT^
M7V9O<F5C87-T+3YD87E;)&E=+3YP87)T6S%=+3YI8V]N+`H@("`@("`@("`@
M("`@("`@("`@(")W:6YD(B`@("`@("`@("`]/B`D=&AI<RT^8V]N=F5R=%-P
M965D*"1T:&ES+3Y?9F]R96-A<W0M/F1A>5LD:5TM/G!A<G1;,5TM/G=I;F0M
M/G,L(")M<&@B+"`D=6YI='-;(G=I;F0B72DL"B`@("`@("`@("`@("`@("`@
M("`@(G=I;F1'=7-T(B`@("`@(#T^("1T:&ES+3YC;VYV97)T4W!E960H)'1H
M:7,M/E]F;W)E8V%S="T^9&%Y6R1I72T^<&%R=%LQ72T^=VEN9"T^9W5S="P@
M(FUP:"(L("1U;FET<ULB=VEN9")=*2P*("`@("`@("`@("`@("`@("`@("`B
M=VEN9$1E9W)E97,B("`@/3X@)'1H:7,M/E]F;W)E8V%S="T^9&%Y6R1I72T^
M<&%R=%LQ72T^=VEN9"T^9"P*("`@("`@("`@("`@("`@("`@("`B=VEN9$1I
M<F5C=&EO;B(@/3X@)'1H:7,M/E]F;W)E8V%S="T^9&%Y6R1I72T^<&%R=%LQ
M72T^=VEN9"T^="P*("`@("`@("`@("`@("`@("`@("`B<')E8VEP:71A=&EO
M;B(@/3X@)'1H:7,M/E]F;W)E8V%S="T^9&%Y6R1I72T^<&%R=%LQ72T^<'!C
M<"P*("`@("`@("`@("`@("`@("`@("`B:'5M:61I='DB("`@("`@/3X@)'1H
M:7,M/E]F;W)E8V%S="T^9&%Y6R1I72T^<&%R=%LQ72T^:&UI9`H@("`@("`@
M("`@("`@("`@*0H@("`@("`@("`@("`I.PH*("`@("`@("`@("`@)&9O<F5C
M87-T4F5T=7)N6R)D87ES(EU;72`]("1D87D["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)&9O<F5C87-T4F5T=7)N.PH@("`@?0H@("`@+R\@?7U]"GT*
M+R\@?7U]"C\^"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O4V5R=FEC97,O5V5A=&AE<B]#;VUM;VXN<&AP````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#$Q,S`P,"`Q,#4Q-30S,S<R-R`P,C,V,#<`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RH@
M=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F
M='1A8G-T;W`]-"!F;VQD;65T:&]D/6UA<FME<CH@*B\*"B\J*@H@*B!014%2
M.CI397)V:6-E<U]796%T:&5R7T-O;6UO;@H@*@H@*B!02%`@=F5R<VEO;G,@
M-"!A;F0@-0H@*@H@*B`\3$E#14Y313X*("H@0V]P>7)I9VAT("AC*2`R,#`U
M+"!!;&5X86YD97(@5VER='H*("H@06QL(')I9VAT<R!R97-E<G9E9"X*("H*
M("H@4F5D:7-T<FEB=71I;VX@86YD('5S92!I;B!S;W5R8V4@86YD(&)I;F%R
M>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T"B`J(&UO9&EF:6-A=&EO;BP@87)E
M('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F;VQL;W=I;F<@8V]N9&ET
M:6]N<PH@*B!A<F4@;65T.@H@*B!O(%)E9&ES=')I8G5T:6]N<R!O9B!S;W5R
M8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I9VAT(&YO=&EC
M92P*("H@("!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO
M=VEN9R!D:7-C;&%I;65R+@H@*B!O(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA
M<GD@9F]R;2!M=7-T(')E<')O9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT(&YO
M=&EC92P*("H@("!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O
M;&QO=VEN9R!D:7-C;&%I;65R(&EN('1H92!D;V-U;65N=&%T:6]N"B`J("`@
M86YD+V]R(&]T:&5R(&UA=&5R:6%L<R!P<F]V:61E9"!W:71H('1H92!D:7-T
M<FEB=71I;VXN"B`J(&\@3F5I=&AE<B!T:&4@;F%M92!O9B!T:&4@<V]F='=A
M<F4@;F]R('1H92!N86UE<R!O9B!I=',@8V]N=')I8G5T;W)S"B`J("`@;6%Y
M(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E('!R;V1U8W1S(&1E<FEV
M960@9G)O;2!T:&ES('-O9G1W87)E"B`J("`@=VET:&]U="!S<&5C:69I8R!P
M<FEO<B!W<FET=&5N('!E<FUI<W-I;VXN"B`J"B`J(%1(25,@4T]&5%=!4D4@
M25,@4%)/5DE$140@0ED@5$A%($-/4%E224=(5"!(3TQ$15)3($%.1"!#3TY4
M4DE"551/4E,@(D%3($E3(@H@*B!!3D0@04Y9($584%)%4U,@3U(@24U03$E%
M1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.3U0@3$E-251%1"!43RP@
M5$A%"B`J($E-4$Q)140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)5%D@
M04Y$($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!4B!055)03U-%"B`J($%212!$
M25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4@0T]065))1TA4($]7
M3D52($]2($-/3E1224)55$]24R!"10H@*B!,24%"3$4@1D]2($%.62!$25)%
M0U0L($E.1$E214-4+"!)3D-)1$5.5$%,+"!34$5#24%,+"!%6$5-4$Q!4EDL
M($]2"B`J($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'+"!"550@
M3D]4($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&"B`J(%-50E-425155$4@
M1T]/1%,@3U(@4T525DE#15,[($Q/4U,@3T8@55-%+"!$051!+"!/4B!04D]&
M2513.R!/4B!"55-)3D534PH@*B!)3E1%4E)54%1)3TXI($A/5T5615(@0T%5
M4T5$($%.1"!/3B!!3ED@5$A%3U)9($]&($Q)04))3$E462P@5TA%5$A%4B!)
M3@H@*B!#3TY44D%#5"P@4U1224-4($Q)04))3$E462P@3U(@5$]25"`H24Y#
M3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*0H@*B!!4DE324Y'($E.
M($%.62!705D@3U54($]&(%1(12!54T4@3T8@5$A)4R!33T945T%212P@159%
M3B!)1B!!1%9)4T5$($]&(%1(10H@*B!03U-324))3$E462!/1B!354-(($1!
M34%'12X*("H@/"],24-%3E-%/@H@*@H@*B!`8V%T96=O<GD@("`@5V5B(%-E
M<G9I8V5S"B`J($!P86-K86=E("`@("!397)V:6-E<U]796%T:&5R"B`J($!A
M=71H;W(@("`@("!!;&5X86YD97(@5VER='H@/&%L97A`<&,T<"YN970^"B`J
M($!C;W!Y<FEG:'0@("`R,#`U($%L97AA;F1E<B!7:7)T>@H@*B!`;&EC96YS
M92`@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M
M;&EC96YS92YP:'`@($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@("!#5E,Z
M("1)9#H@0V]M;6]N+G!H<"QV(#$N-3$@,C`P-2\Q,2\Q,R`R,CHR-SHS,B!E
M<G4@17AP("0*("H@0&QI;FL@("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O
M<&%C:V%G92]397)V:6-E<U]796%T:&5R"B`J($!F:6QE<V]U<F-E"B`J+PH*
M<F5Q=6ER95]O;F-E(")397)V:6-E<R]796%T:&5R+G!H<"(["@HO+R![>WL@
M8V]N<W1A;G1S"B\O('M[>R!N871U<F%L(&-O;G-T86YT<R!A;F0@;65A<W5R
M97,*9&5F:6YE*")315)624-%4U]714%42$527U)!1$E54U]%05)42"(L(#8S
M-S@N,34I.PHO+R!]?7T*"B\O('M[>R!D969A=6QT('9A;'5E<R!F;W(@=&AE
M('-U;BUF=6YC=&EO;G,*9&5F:6YE*")315)624-%4U]714%42$527U-53D95
M3D-37T1%1D%53%1?3$%425151$4B+"`@,S$N-S8V-RD["F1E9FEN92@B4T52
M5DE#15-?5T5!5$A%4E]354Y&54Y#4U]$149!54Q47TQ/3D=)5%5$12(L(#,U
M+C(S,S,I.PID969I;F4H(E-%4E9)0T537U=%051(15)?4U5.1E5.0U-?4U5.
M4DE315]:14Y)5$@B+"`@("`Y,"XX,RD["F1E9FEN92@B4T525DE#15-?5T5!
M5$A%4E]354Y&54Y#4U]354Y3151?6D5.251((BP@("`@(#DP+C@S*3L*+R\@
M?7U]"B\O('U]?0H*+R\@>WM[(&-L87-S(%-E<G9I8V5S7U=E871H97)?0V]M
M;6]N"B\J*@H@*B!087)E;G0@8VQA<W,@9F]R('=E871H97(M<V5R=FEC97,N
M($1E9FEN97,@8V]M;6]N(&9U;F-T:6]N<R!F;W(@=6YI=`H@*B!C;VYV97)S
M:6]N<RP@8VAE8VMS(&9O<B!C86-H92!E;F%B;&EN9R!A;F0@9&]E<R!O=&AE
M<B!M:7-C96QL86YE;W5S"B`J('1H:6YG<RX*("H*("H@0&-A=&5G;W)Y("`@
M(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G92`@("`@4V5R=FEC97-?5V5A=&AE
M<@H@*B!`875T:&]R("`@("`@06QE>&%N9&5R(%=I<G1Z(#QA;&5X0'!C-'`N
M;F5T/@H@*B!`8V]P>7)I9VAT("`@,C`P-2!!;&5X86YD97(@5VER='H*("H@
M0&QI8V5N<V4@("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS
M97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@
M("`@4F5L96%S93H@,2XT+C`*("H@0&QI;FL@("`@("`@(&AT='`Z+R]P96%R
M+G!H<"YN970O<&%C:V%G92]397)V:6-E<U]796%T:&5R"B`J+PIC;&%S<R!3
M97)V:6-E<U]796%T:&5R7T-O;6UO;B!["@H@("`@+R\@>WM[('!R;W!E<G1I
M97,*("`@("\J*@H@("`@("H@1F]R;6%T(&]F('1H92!U;FET<R!P<F]V:61E
M9"`H<W1A;F1A<F0O;65T<FEC+V-U<W1O;2D*("`@("`J"B`@("`@*B!`=F%R
M("`@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)%]U;FET<T9O<FUA
M=`H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]U
M;FET<T9O<FUA="`](")S(CL*"B`@("`O*BH*("`@("`J($-U<W1O;2!F;W)M
M870@;V8@=&AE('5N:71S"B`@("`@*@H@("`@("H@0'9A<B`@("`@87)R87D@
M("`@("`@("`@("`@("`@("`@("`@("1?8W5S=&]M56YI='-&;W)M870*("`@
M("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?8W5S=&]M
M56YI='-&;W)M870@/2!A<G)A>2@*("`@("`@("`B=&5M<"(@("`]/B`B9B(L
M"B`@("`@("`@(G9I<R(@("`@/3X@(G-M(BP*("`@("`@("`B:&5I9VAT(B`]
M/B`B9G0B+`H@("`@("`@(")W:6YD(B`@(#T^(")M<&@B+`H@("`@("`@(")P
M<F5S(B`@(#T^(")I;B(L"B`@("`@("`@(G)A:6XB("`@/3X@(FEN(@H@("`@
M*3L*"B`@("`O*BH*("`@("`J($]P=&EO;G,@9F]R($A45%`@<F5Q=65S=',*
M("`@("`J"B`@("`@*B!`=F%R("`@("!A<G)A>2`@("`@("`@("`@("`@("`@
M("`@("`@)%]H='1P3W!T:6]N<PH@("`@("H@0&%C8V5S<R`@<')I=F%T90H@
M("`@("HO"B`@("!V87(@)%]H='1P3W!T:6]N<R`](&%R<F%Y*"D["@H@("`@
M+RHJ"B`@("`@*B!&;W)M870@;V8@=&AE('5S960@9&%T97,*("`@("`J"B`@
M("`@*B!`=F%R("`@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)%]D
M871E1F]R;6%T"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B\*("`@
M('9A<B`D7V1A=&5&;W)M870@/2`B;2]D+WDB.PH*("`@("\J*@H@("`@("H@
M1F]R;6%T(&]F('1H92!U<V5D('1I;65S"B`@("`@*@H@("`@("H@0'9A<B`@
M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1?=&EM949O<FUA=`H@
M("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]T:6UE
M1F]R;6%T(#T@(D<Z:2!!(CL*"B`@("`O*BH*("`@("`J($]B:F5C="!C;VYT
M86EN:6YG('1H92!L;V-A=&EO;BUD871A"B`@("`@*@H@("`@("H@0'9A<B`@
M("`@;V)J96-T('-T9$-L87-S("`@("`@("`@("`@("1?;&]C871I;VX*("`@
M("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?;&]C871I
M;VX["@H@("`@+RHJ"B`@("`@*B!/8FIE8W0@8V]N=&%I;FEN9R!T:&4@=V5A
M=&AE<BUD871A"B`@("`@*@H@("`@("H@0'9A<B`@("`@;V)J96-T('-T9$-L
M87-S("`@("`@("`@("`@("1?=V5A=&AE<@H@("`@("H@0&%C8V5S<R`@<')I
M=F%T90H@("`@("HO"B`@("!V87(@)%]W96%T:&5R.PH*("`@("\J*@H@("`@
M("H@3V)J96-T(&-O;G1A:6YI;F<@=&AE(&9O<F5C87-T+61A=&$*("`@("`J
M"B`@("`@*B!`=F%R("`@("!O8FIE8W0@<W1D0VQA<W,@("`@("`@("`@("`@
M)%]F;W)E8V%S=`H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@
M("!V87(@)%]F;W)E8V%S=#L*"B`@("`O*BH*("`@("`J($-A8VAE+"!C;VYT
M86EN:6YG('1H92!D871A+6]B:F5C=',*("`@("`J"B`@("`@*B!`=F%R("`@
M("!O8FIE8W0@0V%C:&4@("`@("`@("`@("`@("`@)%]C86-H90H@("`@("H@
M0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]C86-H93L*"B`@
M("`O*BH*("`@("`J(%!R;W9I9&5S(&-H96-K(&9O<B!#86-H90H@("`@("H*
M("`@("`J($!V87(@("`@(&)O;VP@("`@("`@("`@("`@("`@("`@("`@("`D
M7V-A8VAE16YA8FQE9`H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("HO
M"B`@("!V87(@)%]C86-H945N86)L960@/2!F86QS93L*("`@("\O('U]?0H*
M("`@("\O('M[>R!C;VYS=')U8W1O<@H@("`@+RHJ"B`@("`@*B!#;VYS=')U
M8W1O<@H@("`@("H*("`@("`J($!P87)A;2`@(&%R<F%Y("`@("`@("`@("`@
M("`@("`@("`@("`D;W!T:6]N<PH@("`@("H@0'!A<F%M("`@;6EX960@("`@
M("`@("`@("`@("`@("`@("`@("1E<G)O<@H@("`@("H@0'1H<F]W<R`@4$5!
M4E]%<G)O<@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!F
M=6YC=&EO;B!397)V:6-E<U]796%T:&5R7T-O;6UO;B@D;W!T:6]N<RP@)B1E
M<G)O<BD*("`@('L*("`@("`@("`O+R!3970@<V]M92!C;VYS=&%N=',@9F]R
M('1H92!C87-E('=H96X@4$A0-"!I<R!U<V5D+"!A<R!T:&4*("`@("`@("`O
M+R!D871E7W-U;G-E="]S=6YR:7-E(&9U;F-T:6]N<R!A<F4@;F]T(&EM<&QE
M;65N=&5D('1H97)E"B`@("`@("`@:68@*"%D969I;F5D*")354Y&54Y#4U]2
M151?5$E-15-404U0(BDI('L*("`@("`@("`@("`@9&5F:6YE*")354Y&54Y#
M4U]2151?5$E-15-404U0(BP@,"D["B`@("`@("`@("`@(&1E9FEN92@B4U5.
M1E5.0U-?4D547U-44DE.1R(L("`@(#$I.PH@("`@("`@("`@("!D969I;F4H
M(E-53D953D-37U)%5%]$3U5"3$4B+"`@("`R*3L*("`@("`@("!]"@H@("`@
M("`@("\O(%-E="!O<'1I;VYS(&%C8V]R9&EN9VQY"B`@("`@("`@:68@*&ES
M<V5T*"1O<'1I;VYS6R)C86-H951Y<&4B72DI('L*("`@("`@("`@("`@:68@
M*&ES<V5T*"1O<'1I;VYS6R)C86-H94]P=&EO;G,B72DI('L*("`@("`@("`@
M("`@("`@("1S=&%T=7,@/2`D=&AI<RT^<V5T0V%C:&4H)&]P=&EO;G-;(F-A
M8VAE5'EP92)=+"`D;W!T:6]N<ULB8V%C:&5/<'1I;VYS(ETI.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'-T871U<R`]("1T:&ES
M+3YS971#86-H92@D;W!T:6]N<ULB8V%C:&54>7!E(ETI.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R
M*"1S=&%T=7,I*2!["B`@("`@("`@("`@("`@("`D97)R;W(@/2`D<W1A='5S
M.PH@("`@("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;(G5N:71S1F]R;6%T
M(ETI*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULB8W5S=&]M
M56YI='-&;W)M870B72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3YS9715
M;FET<T9O<FUA="@D;W!T:6]N<ULB=6YI='-&;W)M870B72P@)&]P=&EO;G-;
M(F-U<W1O;55N:71S1F]R;6%T(ETI.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/G-E=%5N:71S1F]R;6%T*"1O<'1I;VYS
M6R)U;FET<T9O<FUA=")=*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R)H='1P5&EM96]U=")=*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^<V5T2'1T<%1I;65O=70H)&]P=&EO;G-;(FAT
M='!4:6UE;W5T(ETI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T
M:&ES+3YS971(='1P5&EM96]U="@V,"D["B`@("`@("`@?0H@("`@("`@(&EF
M("AI<W-E="@D;W!T:6]N<ULB:'1T<%!R;WAY(ETI*2!["B`@("`@("`@("`@
M("1S=&%T=7,@/2`D=&AI<RT^<V5T2'1T<%!R;WAY*"1O<'1I;VYS6R)H='1P
M4')O>'DB72D["B`@("`@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII
M<T5R<F]R*"1S=&%T=7,I*2!["B`@("`@("`@("`@("`@("`D97)R;W(@/2`D
M<W1A='5S.PH@("`@("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;(F1A=&5&
M;W)M870B72DI('L*("`@("`@("`@("`@)'1H:7,M/G-E=$1A=&54:6UE1F]R
M;6%T*"1O<'1I;VYS6R)D871E1F]R;6%T(ETL("(B*3L*("`@("`@("!]"B`@
M("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R)T:6UE1F]R;6%T(ETI*2!["B`@
M("`@("`@("`@("1T:&ES+3YS971$871E5&EM949O<FUA="@B(BP@)&]P=&EO
M;G-;(G1I;65&;W)M870B72D["B`@("`@("`@?0H@("`@?0H@("`@+R\@?7U]
M"@H@("`@+R\@>WM[('-E=$-A8VAE*"D*("`@("\J*@H@("`@("H@16YA8FQE
M<R!C86-H:6YG('1H92!D871A+"!U<V%G92!S=')O;F=L>2!R96-O;6UE;F1E
M9`H@("`@("H*("`@("`J(%)E<75I<F5S($-A8VAE('1O(&)E(&EN<W1A;&QE
M9`H@("`@("H*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@("`@
M("`@("`@("`D8V%C:&54>7!E"B`@("`@*B!`<&%R86T@("!A<G)A>2`@("`@
M("`@("`@("`@("`@("`@("`@)&-A8VAE3W!T:6]N<PH@("`@("H@0')E='5R
M;B`@4$5!4E]%<G)O<GQB;V]L"B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R
M.CI315)624-%4U]714%42$527T524D]27T-!0TA%7TE.251?1D%)3$5$"B`@
M("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T
M0V%C:&4H)&-A8VAE5'EP92`](")F:6QE(BP@)&-A8VAE3W!T:6]N<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@+R\@5&AE(&5R<F]R(&AA;F1L:6YG(&EN
M($-A8VAE(&ES(&$@8FET(&-R=6UM>2`H<F5A9#H@;F]T(&5X:7-T96YT*0H@
M("`@("`@("\O('-O('=E(&AA=F4@=&\@9&\@=&AA="!O;B!O=7(@;W=N+BXN
M"B`@("`@("`@0&EN8VQU9&5?;VYC92`B0V%C:&4N<&AP(CL*("`@("`@("!`
M)&-A8VAE(#T@;F5W($-A8VAE*"1C86-H951Y<&4L("1C86-H94]P=&EO;G,I
M.PH@("`@("`@(&EF("AI<U]O8FIE8W0H)&-A8VAE*2`F)B`H<W1R=&]L;W=E
M<BAG971?8VQA<W,H)&-A8VAE*2D@/3T@(F-A8VAE(B!\?"!I<U]S=6)C;&%S
M<U]O9B@D8V%C:&4L(")C86-H92(I*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7V-A8VAE("`@("`@("`]("1C86-H93L*("`@("`@("`@("`@)'1H:7,M/E]C
M86-H945N86)L960@/2!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1T:&ES+3Y?8V%C:&4@("`@("`@(#T@;G5L;#L*("`@("`@("`@("`@
M)'1H:7,M/E]C86-H945N86)L960@/2!F86QS93L*("`@("`@("`@("`@<F5T
M=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!
M5$A%4E]%4E)/4E]#04-(15])3DE47T9!24Q%1"P@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H@
M("`@+R\@?7U]"@H@("`@+R\@>WM[('-E=%5N:71S1F]R;6%T*"D*("`@("\J
M*@H@("`@("H@0VAA;F=E<R!T:&4@<F5P<F5S96YT871I;VX@;V8@=&AE('5N
M:71S("AS=&%N9&%R9"]M971R:6,I"B`@("`@*@H@("`@("H@0'!A<F%M("`@
M<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1U;FET<T9O<FUA=`H@("`@
M("H@0'!A<F%M("`@87)R87D@("`@("`@("`@("`@("`@("`@("`@("1C=7-T
M;VU5;FET<T9O<FUA=`H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-E=%5N:71S1F]R;6%T*"1U;FET<T9O<FUA="P@)&-U
M<W1O;55N:71S1F]R;6%T(#T@87)R87DH*2D*("`@('L*("`@("`@("!S=&%T
M:6,@)&%C8V5P=&5D1F]R;6%T<SL*("`@("`@("!I9B`H(6ES<V5T*"1A8V-E
M<'1E9$9O<FUA=',I*2!["B`@("`@("`@("`@("1A8V-E<'1E9$9O<FUA=',@
M/2!A<G)A>2@*("`@("`@("`@("`@("`@(")T96UP(B`@(#T^(&%R<F%Y*")C
M(BP@(F8B*2P*("`@("`@("`@("`@("`@(")V:7,B("`@(#T^(&%R<F%Y*")M
M(BP@(FMM(BP@(F9T(BP@(G-M(BDL"B`@("`@("`@("`@("`@("`B:&5I9VAT
M(B`]/B!A<G)A>2@B;2(L(")F="(I+`H@("`@("`@("`@("`@("`@(G=I;F0B
M("`@/3X@87)R87DH(FUP:"(L(")K;6@B+"`B:W0B+"`B;7!S(BP@(F9P<R(L
M(")B9G0B*2P*("`@("`@("`@("`@("`@(")P<F5S(B`@(#T^(&%R<F%Y*")I
M;B(L(")H<&$B+"`B;6(B+"`B;6TB+"`B871M(BDL"B`@("`@("`@("`@("`@
M("`B<F%I;B(@("`]/B!A<G)A>2@B:6XB+"`B;6TB*0H@("`@("`@("`@("`I
M.PH@("`@("`@('T*"B`@("`@("`@:68@*'-T<FQE;B@D=6YI='-&;W)M870I
M("8F(&EN7V%R<F%Y*'-T<G1O;&]W97(H)'5N:71S1F]R;6%T>S!]*2P@87)R
M87DH(F,B+"`B;2(L(")S(BDI*2!["B`@("`@("`@("`@("1T:&ES+3Y?=6YI
M='-&;W)M870@/2!S=')T;VQO=V5R*"1U;FET<T9O<FUA='LP?2D["B`@("`@
M("`@("`@(&EF("@D=&AI<RT^7W5N:71S1F]R;6%T(#T](")C(B`F)B!I<U]A
M<G)A>2@D8W5S=&]M56YI='-&;W)M870I*2!["B`@("`@("`@("`@("`@("!F
M;W)E86-H("@D8W5S=&]M56YI='-&;W)M870@87,@)&ME>2`]/B`D=F%L=64I
M('L*("`@("`@("`@("`@("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@D
M:V5Y+"`D86-C97!T961&;W)M871S*2`F)B!I;E]A<G)A>2@D=F%L=64L("1A
M8V-E<'1E9$9O<FUA='-;)&ME>5TI*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?8W5S=&]M56YI='-&;W)M871;)&ME>5T@/2`D=F%L=64[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!](&5L<V5I9B`H)'1H:7,M/E]U;FET<T9O<FUA="`]/2`B8R(I
M('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?=6YI='-&;W)M870@/2`B<R([
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"B`@("`O+R!]?7T*"B`@
M("`O+R![>WL@<V5T2'1T<$]P=&EO;B@I"B`@("`O*BH*("`@("`J(%-E=',@
M86X@;W!T:6]N(&9O<B!U<V%G92!I;B!(5%107U)E<75E<W0@;V)J96-T<PH@
M("`@("H*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@("`@("`@
M("`@("`D=F%R3F%M90H@("`@("H@0'!A<F%M("`@;6EX960@("`@("`@("`@
M("`@("`@("`@("`@("1V87)686QU90H@("`@("H@0&%C8V5S<R`@<'5B;&EC
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$AT='!/<'1I;VXH)'9A<DYA;64L
M("1V87)686QU92D*("`@('L*("`@("`@("!I9B`H:7-?<W1R:6YG*"1V87).
M86UE*2`F)B`D=F%R3F%M92`A/2`B(B`F)B`A96UP='DH)'9A<E9A;'5E*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^7VAT='!/<'1I;VYS6R1V87).86UE72`]
M("1V87)686QU93L*("`@("`@("!]"B`@("!]"B`@("`O+R!]?7T*"B`@("`O
M+R![>WL@<V5T2'1T<%1I;65O=70H*0H@("`@+RHJ"B`@("`@*B!3971S('1H
M92!T:6UE;W5T(&EN('-E8V]N9',@9F]R($A45%`@<F5Q=65S=',*("`@("`J
M"B`@("`@*B!`<&%R86T@("!I;G0@("`@("`@("`@("`@("`@("`@("`@("`@
M)&AT='!4:6UE;W5T"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@<V5T2'1T<%1I;65O=70H)&AT='!4:6UE;W5T*0H@("`@
M>PH@("`@("`@(&EF("AI<U]I;G0H)&AT='!4:6UE;W5T*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7VAT='!/<'1I;VYS6R)T:6UE;W5T(ET@/2`D:'1T<%1I
M;65O=70["B`@("`@("`@?0H@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[
M('-E=$AT='!0<F]X>2@I"B`@("`O*BH*("`@("`J(%-E=',@=&AE('!R;WAY
M(&9O<B!(5%10(')E<75E<W1S"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R
M:6YG("`@("`@("`@("`@("`@("`@("`@("1H='1P4')O>'D*("`@("`J($!A
M8V-E<W,@('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!S971(='1P4')O
M>'DH)&AT='!0<F]X>2D*("`@('L*("`@("`@("!I9B`H*"1P<F]X>2`]('!A
M<G-E7W5R;"@D:'1T<%!R;WAY*2D@(3T](&9A;'-E("8F("1P<F]X>5LB<V-H
M96UE(ET@/3T@(FAT='`B*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D<')O
M>'E;(G5S97(B72D@)B8@)'!R;WAY6R)U<V5R(ET@(3T@(B(I('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?:'1T<$]P=&EO;G-;(G!R;WAY7W5S97(B72`]
M("1P<F]X>5LB=7-E<B)=.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("AI<W-E="@D<')O>'E;(G!A<W,B72D@)B8@)'!R;WAY6R)P87-S(ET@(3T@
M(B(I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?:'1T<$]P=&EO;G-;(G!R
M;WAY7W!A<W,B72`]("1P<F]X>5LB<&%S<R)=.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&EF("AI<W-E="@D<')O>'E;(FAO<W0B72D@)B8@)'!R;WAY
M6R)H;W-T(ET@(3T@(B(I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?:'1T
M<$]P=&EO;G-;(G!R;WAY7VAO<W0B72`]("1P<F]X>5LB:&]S=")=.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&EF("AI<W-E="@D<')O>'E;(G!O<G0B
M72D@)B8@)'!R;WAY6R)P;W)T(ET@(3T@(B(I('L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?:'1T<$]P=&EO;G-;(G!R;WAY7W!O<G0B72`]("1P<F]X>5LB
M<&]R=")=.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!R971U<FX@=')U
M93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4V5R=FEC
M97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$527T524D]2
M7TA45%!?4%)/6%E?24Y604Q)1"P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@
M("`@("!]"B`@("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@9V5T56YI='-&
M;W)M870H*0H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!S96QE8W1E9"!U
M;FET<R!F;W)M870*("`@("`J"B`@("`@*B!`<&%R86T@("!S=')I;F<@("`@
M("`@("`@("`@("`@("`@("`@)'5N:71S1F]R;6%T"B`@("`@*B!`<F5T=7)N
M("!A<G)A>0H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%5N:71S1F]R;6%T*"1U;FET<T9O<FUA="`]("(B*0H@("`@
M>PH@("`@("`@("\O(%1H:7,@:7,@8VAE87`G;R!S='5F9@H@("`@("`@(&EF
M("AS=')L96XH)'5N:71S1F]R;6%T*2`F)B!I;E]A<G)A>2AS=')T;VQO=V5R
M*"1U;FET<T9O<FUA='LP?2DL(&%R<F%Y*")C(BP@(FTB+"`B<R(I*2D@>PH@
M("`@("`@("`@("`D=6YI='-&;W)M870@/2!S=')T;VQO=V5R*"1U;FET<T9O
M<FUA='LP?2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'5N:71S
M1F]R;6%T(#T@)'1H:7,M/E]U;FET<T9O<FUA=#L*("`@("`@("!]"@H@("`@
M("`@("1C(#T@)'1H:7,M/E]C=7-T;VU5;FET<T9O<FUA=#L*("`@("`@("`D
M;2`](&%R<F%Y*`H@("`@("`@("`@("`B=&5M<"(@("`]/B`B8R(L"B`@("`@
M("`@("`@(")V:7,B("`@(#T^(")K;2(L"B`@("`@("`@("`@(")H96EG:'0B
M(#T^(")M(BP*("`@("`@("`@("`@(G=I;F0B("`@/3X@(FMM:"(L"B`@("`@
M("`@("`@(")P<F5S(B`@(#T^(")M8B(L"B`@("`@("`@("`@(")R86EN(B`@
M(#T^(")M;2(*("`@("`@("`I.PH@("`@("`@("1S(#T@87)R87DH"B`@("`@
M("`@("`@(")T96UP(B`@(#T^(")F(BP*("`@("`@("`@("`@(G9I<R(@("`@
M/3X@(G-M(BP*("`@("`@("`@("`@(FAE:6=H="(@/3X@(F9T(BP*("`@("`@
M("`@("`@(G=I;F0B("`@/3X@(FUP:"(L"B`@("`@("`@("`@(")P<F5S(B`@
M(#T^(")I;B(L"B`@("`@("`@("`@(")R86EN(B`@(#T^(")I;B(*("`@("`@
M("`I.PH*("`@("`@("!R971U<FX@)'LD=6YI='-&;W)M871].PH@("`@?0H@
M("`@+R\@?7U]"@H@("`@+R\@>WM[('-E=$1A=&54:6UE1F]R;6%T*"D*("`@
M("\J*@H@("`@("H@0VAA;F=E<R!T:&4@<F5P<F5S96YT871I;VX@;V8@=&EM
M92!A;F0@9&%T97,@*'-E92!H='1P.B\O=W=W+G!H<"YN970O9&%T92D*("`@
M("`J"B`@("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@
M("`@)&1A=&5&;W)M870*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@
M("`@("`@("`@("`@("`D=&EM949O<FUA=`H@("`@("H@0&%C8V5S<R`@<'5B
M;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$1A=&54:6UE1F]R;6%T*"1D
M871E1F]R;6%T(#T@(B(L("1T:6UE1F]R;6%T(#T@(B(I"B`@("!["B`@("`@
M("`@:68@*'-T<FQE;B@D9&%T949O<FUA="DI('L*("`@("`@("`@("`@)'1H
M:7,M/E]D871E1F]R;6%T(#T@)&1A=&5&;W)M870["B`@("`@("`@?0H@("`@
M("`@(&EF("AS=')L96XH)'1I;65&;W)M870I*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?=&EM949O<FUA="`]("1T:6UE1F]R;6%T.PH@("`@("`@('T*("`@
M('T*("`@("\O('U]?0H*("`@("\O('M[>R!C;VYV97)T5&5M<&5R871U<F4H
M*0H@("`@+RHJ"B`@("`@*B!#;VYV97)T('1E;7!E<F%T=7)E(&)E='=E96X@
M9B!A;F0@8PH@("`@("H*("`@("`J($!P87)A;2`@(&9L;V%T("`@("`@("`@
M("`@("`@("`@("`@("`D=&5M<&5R871U<F4*("`@("`J($!P87)A;2`@('-T
M<FEN9R`@("`@("`@("`@("`@("`@("`@("`D9G)O;0H@("`@("H@0'!A<F%M
M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1T;PH@("`@("H@0')E
M='5R;B`@9FQO870*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!C;VYV97)T5&5M<&5R871U<F4H)'1E;7!E<F%T=7)E+"`D
M9G)O;2P@)'1O*0H@("`@>PH@("`@("`@("1F<F]M(#T@<W1R=&]L;W=E<B@D
M9G)O;7LP?2D["B`@("`@("`@)'1O("`@/2!S=')T;VQO=V5R*"1T;WLP?2D[
M"@H@("`@("`@("1R97-U;'0@/2!A<G)A>2@*("`@("`@("`@("`@(F8B(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`@("`@(F8B(#T^("1T96UP97)A='5R92P@
M("`@("`@("`@("`B8R(@/3X@*"1T96UP97)A='5R92`M(#,R*2`O(#$N.`H@
M("`@("`@("`@("`I+`H@("`@("`@("`@("`B8R(@/3X@87)R87DH"B`@("`@
M("`@("`@("`@("`B9B(@/3X@,2XX("H@)'1E;7!E<F%T=7)E("L@,S(L(")C
M(B`]/B`D=&5M<&5R871U<F4*("`@("`@("`@("`@*0H@("`@("`@("D["@H@
M("`@("`@(')E='5R;B!R;W5N9"@D<F5S=6QT6R1F<F]M75LD=&]=+"`R*3L*
M("`@('T*("`@("\O('U]?0H*("`@("\O('M[>R!C;VYV97)T4W!E960H*0H@
M("`@+RHJ"B`@("`@*B!#;VYV97)T('-P965D(&)E='=E96X@;7!H+"!K;6@L
M(&MT+"!M<',L(&9P<R!A;F0@8F9T"B`@("`@*@H@("`@("H@1G5N8W1I;VX@
M=VEL;"!R971U<FX@(F9A;'-E(B!W:&5N('1R>6EN9R!T;R!C;VYV97)T(&9R
M;VT*("`@("`J($)E875F;W)T+"!A<R!I="!I<R!A('-C86QE(&%N9"!N;W0@
M82!T<G5E(&UE87-U<F5M96YT"B`@("`@*@H@("`@("H@0'!A<F%M("`@9FQO
M870@("`@("`@("`@("`@("`@("`@("`@("1S<&5E9`H@("`@("H@0'!A<F%M
M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1F<F]M"B`@("`@*B!`
M<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)'1O"B`@("`@
M*B!`<F5T=7)N("!F;&]A='QI;G1\8F]O;`H@("`@("H@0&%C8V5S<R`@<'5B
M;&EC"B`@("`@*B!`;&EN:R`@("!H='1P.B\O=W=W+G-P8RYN;V%A+F=O=B]F
M87$O=&]R;F%D;R]B96%U9F]R="YH=&UL"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&-O;G9E<G13<&5E9"@D<W!E960L("1F<F]M+"`D=&\I"B`@("!["B`@("`@
M("`@)&9R;VT@/2!S=')T;VQO=V5R*"1F<F]M*3L*("`@("`@("`D=&\@("`]
M('-T<G1O;&]W97(H)'1O*3L*"B`@("`@("`@<W1A=&EC("1F86-T;W(["B`@
M("`@("`@<W1A=&EC("1B96%U9F]R=#L*("`@("`@("!I9B`H(6ES<V5T*"1F
M86-T;W(I*2!["B`@("`@("`@("`@("1F86-T;W(@/2!A<G)A>2@*("`@("`@
M("`@("`@("`@(")M<&@B(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@
M(")M<&@B(#T^(#$L("`@("`@("`@(FMM:"(@/3X@,2XV,#DS-#0L(")K="(@
M/3X@,"XX-C@Y-S8R+"`B;7!S(B`]/B`P+C0T-S`T+"`@(")F<',B(#T^(#$N
M-#8V-C8V-PH@("`@("`@("`@("`@("`@*2P*("`@("`@("`@("`@("`@(")K
M;6@B(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@(")M<&@B(#T^(#`N
M-C(Q,S<Q,BP@(FMM:"(@/3X@,2P@("`@("`@(")K="(@/3X@,"XU,SDY-38X
M+"`B;7!S(B`]/B`P+C(W-S<W-S@L(")F<',B(#T^(#`N.3$Q,S0T-`H@("`@
M("`@("`@("`@("`@*2P*("`@("`@("`@("`@("`@(")K="(@(#T^(&%R<F%Y
M*`H@("`@("`@("`@("`@("`@("`@(")M<&@B(#T^(#$N,34P-S<Y-"P@(FMM
M:"(@/3X@,2XX-3(L("`@(")K="(@/3X@,2P@("`@("`@("`B;7!S(B`]/B`P
M+C4Q-#0T-#0L(")F<',B(#T^(#$N-C@W.#`Y.0H@("`@("`@("`@("`@("`@
M*2P*("`@("`@("`@("`@("`@(")M<',B(#T^(&%R<F%Y*`H@("`@("`@("`@
M("`@("`@("`@(")M<&@B(#T^(#(N,C,V.3,V,RP@(FMM:"(@/3X@,RXV+"`@
M("`@(")K="(@/3X@,2XY-#,X-#0U+"`B;7!S(B`]/B`Q+"`@("`@("`@(")F
M<',B(#T^(#,N,C@P.#,Y.0H@("`@("`@("`@("`@("`@*2P*("`@("`@("`@
M("`@("`@(")F<',B(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@(")M
M<&@B(#T^(#`N-C@Q.#$X,BP@(FMM:"(@/3X@,2XP.3<R."P@(")K="(@/3X@
M,"XU.3(T.#,X+"`B;7!S(B`]/B`P+C,P-#@L("`@(")F<',B(#T^(#$*("`@
M("`@("`@("`@("`@("D*("`@("`@("`@("`@*3L*"B`@("`@("`@("`@("\O
M($)E875F;W)T('-C86QE+"!M96%S=7)E;65N=',@87)E(&EN(&MN;W1S"B`@
M("`@("`@("`@("1B96%U9F]R="`](&%R<F%Y*`H@("`@("`@("`@("`@("`@
M("`Q+"`@(#,L("`@-BP@(#$P+`H@("`@("`@("`@("`@("`@(#$V+"`@,C$L
M("`R-RP@(#,S+`H@("`@("`@("`@("`@("`@(#0P+"`@-#<L("`U-2P@(#8S
M"B`@("`@("`@("`@("D["B`@("`@("`@?0H*("`@("`@("!I9B`H)&9R;VT@
M/3T@(F)F="(I('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T@96QS96EF("@D=&\@/3T@(F)F="(I('L*("`@("`@("`@("`@)'-P965D
M(#T@<F]U;F0H)'-P965D("H@)&9A8W1O<ELD9G)O;5U;(FMT(ETL(#`I.PH@
M("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)&)E875F;W)T
M*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@:68@*"1S<&5E9"`\/2`D8F5A
M=69O<G1;)&E=*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1I.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(')E
M='5R;B!S:7IE;V8H)&)E875F;W)T*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!R971U<FX@<F]U;F0H)'-P965D("H@)&9A8W1O<ELD9G)O;5U;
M)'1O72P@,BD["B`@("`@("`@?0H@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@
M>WM[(&-O;G9E<G10<F5S<W5R92@I"B`@("`O*BH*("`@("`J($-O;G9E<G0@
M<')E<W-U<F4@8F5T=V5E;B!I;BP@:'!A+"!M8BP@;6T@86YD(&%T;0H@("`@
M("H*("`@("`J($!P87)A;2`@(&9L;V%T("`@("`@("`@("`@("`@("`@("`@
M("`D<')E<W-U<F4*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@
M("`@("`@("`@("`D9G)O;0H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@
M("`@("`@("`@("`@("`@("1T;PH@("`@("H@0')E='5R;B`@9FQO870*("`@
M("`J($!A8V-E<W,@('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!C;VYV
M97)T4')E<W-U<F4H)'!R97-S=7)E+"`D9G)O;2P@)'1O*0H@("`@>PH@("`@
M("`@("1F<F]M(#T@<W1R=&]L;W=E<B@D9G)O;2D["B`@("`@("`@)'1O("`@
M/2!S=')T;VQO=V5R*"1T;RD["@H@("`@("`@('-T871I8R`D9F%C=&]R.PH@
M("`@("`@(&EF("@A:7-S970H)&9A8W1O<BDI('L*("`@("`@("`@("`@)&9A
M8W1O<B`](&%R<F%Y*`H@("`@("`@("`@("`@("`@(FEN(B`@(#T^(&%R<F%Y
M*`H@("`@("`@("`@("`@("`@("`@(")I;B(@/3X@,2P@("`@("`@("`B:'!A
M(B`]/B`S,RXX-C,X.#<L(")M8B(@/3X@,S,N.#8S.#@W+"`B;6TB(#T^(#(U
M+C0L("`@("`@(F%T;2(@/3X@,"XP,S,T,C$S"B`@("`@("`@("`@("`@("`I
M+`H@("`@("`@("`@("`@("`@(FAP82(@(#T^(&%R<F%Y*`H@("`@("`@("`@
M("`@("`@("`@(")I;B(@/3X@,"XP,CDU,RP@("`B:'!A(B`]/B`Q+"`@("`@
M("`@(")M8B(@/3X@,2P@("`@("`@("`B;6TB(#T^(#`N-S4P,#8Q-BP@(F%T
M;2(@/3X@,"XP,#`Y.#8Y"B`@("`@("`@("`@("`@("`I+`H@("`@("`@("`@
M("`@("`@(FUB(B`@(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@(")I
M;B(@/3X@,"XP,CDU,RP@("`B:'!A(B`]/B`Q+"`@("`@("`@(")M8B(@/3X@
M,2P@("`@("`@("`B;6TB(#T^(#`N-S4P,#8Q-BP@(F%T;2(@/3X@,"XP,#`Y
M.#8Y"B`@("`@("`@("`@("`@("`I+`H@("`@("`@("`@("`@("`@(FUM(B`@
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@(")I;B(@/3X@,"XP,SDS
M-S`Q+"`B:'!A(B`]/B`Q+C,S,S(R,SDL(")M8B(@/3X@,2XS,S,R,C,Y+"`B
M;6TB(#T^(#$L("`@("`@("`@(F%T;2(@/3X@,"XP,#$S,34X"B`@("`@("`@
M("`@("`@("`I+`H@("`@("`@("`@("`@("`@(F%T;2(@(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@(")I;B(@/3X@,CDL.3(Q,C4X+"`B:'!A(B`]
M/B`Q,#$S+C(U,#$L(")M8B(@/3X@,3`Q,RXR-3`Q+"`B;6TB(#T^(#<U.2XY
M.3DY-3(L(")A=&TB(#T^(#$*("`@("`@("`@("`@("`@("D*("`@("`@("`@
M("`@*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!R;W5N9"@D<')E<W-U
M<F4@*B`D9F%C=&]R6R1F<F]M75LD=&]=+"`R*3L*("`@('T*("`@("\O('U]
M?0H*("`@("\O('M[>R!C;VYV97)T1&ES=&%N8V4H*0H@("`@+RHJ"B`@("`@
M*B!#;VYV97)T(&1I<W1A;F-E(&)E='=E96X@:VTL(&9T(&%N9"!S;0H@("`@
M("H*("`@("`J($!P87)A;2`@(&9L;V%T("`@("`@("`@("`@("`@("`@("`@
M("`D9&ES=&%N8V4*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@
M("`@("`@("`@("`D9G)O;0H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@
M("`@("`@("`@("`@("`@("1T;PH@("`@("H@0')E='5R;B`@9FQO870*("`@
M("`J($!A8V-E<W,@('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!C;VYV
M97)T1&ES=&%N8V4H)&1I<W1A;F-E+"`D9G)O;2P@)'1O*0H@("`@>PH@("`@
M("`@("1T;R`@(#T@<W1R=&]L;W=E<B@D=&\I.PH@("`@("`@("1F<F]M(#T@
M<W1R=&]L;W=E<B@D9G)O;2D["@H@("`@("`@('-T871I8R`D9F%C=&]R.PH@
M("`@("`@(&EF("@A:7-S970H)&9A8W1O<BDI('L*("`@("`@("`@("`@)&9A
M8W1O<B`](&%R<F%Y*`H@("`@("`@("`@("`@("`@(FTB(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@(")M(B`]/B`Q+"`@("`@("`@("`@(")K;2(@
M/3X@,3`P,"P@("`@("`B9G0B(#T^(#,N,C@P.#,Y.#DU+"`B<VTB(#T^(#`N
M,#`P-C(Q,S8Y.0H@("`@("`@("`@("`@("`@*2P*("`@("`@("`@("`@("`@
M(")K;2(@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@(FTB(#T^(#`N
M,#`Q+"`@("`@("`@(FMM(B`]/B`Q+"`@("`@("`@(")F="(@/3X@,S(X,"XX
M,SDX.34L(")S;2(@/3X@,"XV,C$S-CDY"B`@("`@("`@("`@("`@("`I+`H@
M("`@("`@("`@("`@("`@(F9T(B`]/B!A<G)A>2@*("`@("`@("`@("`@("`@
M("`@("`B;2(@/3X@,"XS,#0X+"`@("`@("`B:VTB(#T^(#`N,#`P,S`T."P@
M(F9T(B`]/B`Q+"`@("`@("`@("`@(G-M(B`]/B`P+C`P,#$X.30*("`@("`@
M("`@("`@("`@("DL"B`@("`@("`@("`@("`@("`B<VTB(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@(")M(B`]/B`P+C`P,38P.3,T-S(L(")K;2(@
M/3X@,2XV,#DS-#<R+"`B9G0B(#T^(#4R.#`N,#$P-BP@("`B<VTB(#T^(#$*
M("`@("`@("`@("`@("`@("D*("`@("`@("`@("`@*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B!R;W5N9"@D9&ES=&%N8V4@*B`D9F%C=&]R6R1F<F]M
M75LD=&]=+"`R*3L*("`@('T*("`@("\O('U]?0H*("`@("\O('M[>R!C86QC
M=6QA=&57:6YD0VAI;&PH*0H@("`@+RHJ"B`@("`@*B!#86QC=6QA=&4@=VEN
M9&-H:6QL(&9R;VT@=&5M<&5R871U<F4@86YD('=I;F1S<&5E9"`H96YH86YC
M960@9F]R;75L82D*("`@("`J"B`@("`@*B!496UP97)A='5R92!H87,@=&\@
M8F4@96YT97)E9"!I;B!D96<@1BP@<W!E960@:6X@;7!H(0H@("`@("H*("`@
M("`J($!P87)A;2`@(&9L;V%T("`@("`@("`@("`@("`@("`@("`@("`D=&5M
M<&5R871U<F4*("`@("`J($!P87)A;2`@(&9L;V%T("`@("`@("`@("`@("`@
M("`@("`@("`D<W!E960*("`@("`J($!R971U<FX@(&9L;V%T"B`@("`@*B!`
M86-C97-S("!P=6)L:6,*("`@("`J($!L:6YK("`@(&AT='`Z+R]W=W<N;G=S
M+FYO86$N9V]V+V]M+W=I;F1C:&EL;"\*("`@("`J+PH@("`@9G5N8W1I;VX@
M8V%L8W5L871E5VEN9$-H:6QL*"1T96UP97)A='5R92P@)'-P965D*0H@("`@
M>PH@("`@("`@(')E='5R;B!R;W5N9"@S-2XW-"`K(#`N-C(Q-2`J("1T96UP
M97)A='5R92`M(#,U+C<U("H@<&]W*"1S<&5E9"P@,"XQ-BD@*R`P+C0R-S4@
M*B`D=&5M<&5R871U<F4@*B!P;W<H)'-P965D+"`P+C$V*2D["B`@("!]"B`@
M("`O+R!]?7T*"B`@("`O+R![>WL@8V%L8W5L871E2'5M:61I='DH*0H@("`@
M+RHJ"B`@("`@*B!#86QC=6QA=&4@:'5M:61I='D@9G)O;2!T96UP97)A='5R
M92!A;F0@9&5W<&]I;G0*("`@("`J(%1H:7,@:7,@;VYL>2!A;B!A<'!R;WAI
M;6%T:6]N+"!T:&5R92!I<R!N;R!E>&%C="!F;W)M=6QA+"!T:&ES"B`@("`@
M*B!O;F4@:&5R92!I<R!C86QL960@36%G;G5S+49O<FUU;&$*("`@("`J"B`@
M("`@*B!496UP97)A='5R92!A;F0@9&5W<&]I;G0@:&%V92!T;R!B92!E;G1E
M<F5D(&EN(&1E9R!#(0H@("`@("H*("`@("`J($!P87)A;2`@(&9L;V%T("`@
M("`@("`@("`@("`@("`@("`@("`D=&5M<&5R871U<F4*("`@("`J($!P87)A
M;2`@(&9L;V%T("`@("`@("`@("`@("`@("`@("`@("`D9&5W4&]I;G0*("`@
M("`J($!R971U<FX@(&9L;V%T"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@
M("`J($!L:6YK("`@(&AT='`Z+R]W=W<N9F%Q<RYO<F<O9F%Q<R]M971E;W)O
M;&]G>2]T96UP+61E=W!O:6YT+PH@("`@("HO"B`@("!F=6YC=&EO;B!C86QC
M=6QA=&5(=6UI9&ET>2@D=&5M<&5R871U<F4L("1D97=0;VEN="D*("`@('L*
M("`@("`@("`O+R!&:7)S="!C86QC=6QA=&4@<V%T=7)A=&EO;B!S=&5A;2!P
M<F5S<W5R92!F;W(@8F]T:"!T96UP97)A='5R97,*("`@("`@("!I9B`H)'1E
M;7!E<F%T=7)E(#X](#`I('L*("`@("`@("`@("`@)&$@/2`W+C4["B`@("`@
M("`@("`@("1B(#T@,C,W+C,["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&$@/2`W+C8["B`@("`@("`@("`@("1B(#T@,C0P+C<["B`@("`@("`@
M?0H@("`@("`@("1T96UP4U-0(#T@-BXQ,#<X("H@<&]W*#$P+"`H)&$@*B`D
M=&5M<&5R871U<F4I("\@*"1B("L@)'1E;7!E<F%T=7)E*2D["@H@("`@("`@
M(&EF("@D9&5W4&]I;G0@/CT@,"D@>PH@("`@("`@("`@("`D82`](#<N-3L*
M("`@("`@("`@("`@)&(@/2`R,S<N,SL*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D82`](#<N-CL*("`@("`@("`@("`@)&(@/2`R-#`N-SL*("`@
M("`@("!]"B`@("`@("`@)&1E=U-34"`@/2`V+C$P-S@@*B!P;W<H,3`L("@D
M82`J("1D97=0;VEN="D@+R`H)&(@*R`D9&5W4&]I;G0I*3L*"B`@("`@("`@
M<F5T=7)N(')O=6YD*#$P,"`J("1D97=34U`@+R`D=&5M<%-34"P@,2D["B`@
M("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@8V%L8W5L871E1&5W4&]I;G0H
M*0H@("`@+RHJ"B`@("`@*B!#86QC=6QA=&4@9&5W<&]I;G0@9G)O;2!T96UP
M97)A='5R92!A;F0@:'5M:61I='D*("`@("`J(%1H:7,@:7,@;VYL>2!A;B!A
M<'!R;WAI;6%T:6]N+"!T:&5R92!I<R!N;R!E>&%C="!F;W)M=6QA+"!T:&ES
M"B`@("`@*B!O;F4@:&5R92!I<R!C86QL960@36%G;G5S+49O<FUU;&$*("`@
M("`J"B`@("`@*B!496UP97)A='5R92!H87,@=&\@8F4@96YT97)E9"!I;B!D
M96<@0R$*("`@("`J"B`@("`@*B!`<&%R86T@("!F;&]A="`@("`@("`@("`@
M("`@("`@("`@("`@)'1E;7!E<F%T=7)E"B`@("`@*B!`<&%R86T@("!F;&]A
M="`@("`@("`@("`@("`@("`@("`@("`@)&AU;6ED:71Y"B`@("`@*B!`<F5T
M=7)N("!F;&]A=`H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`;&EN
M:R`@("!H='1P.B\O=W=W+F9A<7,N;W)G+V9A<7,O;65T96]R;VQO9WDO=&5M
M<"UD97=P;VEN="\*("`@("`J+PH@("`@9G5N8W1I;VX@8V%L8W5L871E1&5W
M4&]I;G0H)'1E;7!E<F%T=7)E+"`D:'5M:61I='DI"B`@("!["B`@("`@("`@
M:68@*"1T96UP97)A='5R92`^/2`P*2!["B`@("`@("`@("`@("1A(#T@-RXU
M.PH@("`@("`@("`@("`D8B`](#(S-RXS.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1A(#T@-RXV.PH@("`@("`@("`@("`D8B`](#(T,"XW.PH@
M("`@("`@('T*"B`@("`@("`@+R\@1FER<W0@8V%L8W5L871E('-A='5R871I
M;VX@<W1E86T@<')E<W-U<F4@9F]R('1E;7!E<F%T=7)E"B`@("`@("`@)%-3
M4"`](#8N,3`W."`J('!O=R@Q,"P@*"1A("H@)'1E;7!E<F%T=7)E*2`O("@D
M8B`K("1T96UP97)A='5R92DI.PH*("`@("`@("`O+R!3=&5A;2!P<F5S<W5R
M90H@("`@("`@("134"`@/2`D:'5M:61I='D@+R`Q,#`@*B`D4U-0.PH*("`@
M("`@("`D=B`@(#T@;&]G*"134"`O(#8N,3`W."P@,3`I.PH*("`@("`@("!R
M971U<FX@<F]U;F0H)&(@*B`D=B`O("@D82`M("1V*2P@,2D["B`@("!]"B`@
M("`O+R!]?7T*"B`@("`O+R![>WL@<&]L87(R8V%R=&5S:6%N*"D*("`@("\J
M*@H@("`@("H@0V]N=F5R="!P;VQA<B!C;V]R9&EN871E<R!T;R!C87)T97-I
M86X@8V]O<F1I;F%T97,*("`@("`J"B`@("`@*B!`<&%R86T@("!F;&]A="`@
M("`@("`@("`@("`@("`@("`@("`@)&QA=&ET=61E"B`@("`@*B!`<&%R86T@
M("!F;&]A="`@("`@("`@("`@("`@("`@("`@("`@)&QO;F=I='5D90H@("`@
M("H@0')E='5R;B`@87)R87D*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@
M("HO"B`@("!F=6YC=&EO;B!P;VQA<C)C87)T97-I86XH)&QA=&ET=61E+"`D
M;&]N9VET=61E*0H@("`@>PH@("`@("`@("1T:&5T82`](&1E9S)R860H)&QA
M=&ET=61E*3L*("`@("`@("`D<&AI("`@/2!D96<R<F%D*"1L;VYG:71U9&4I
M.PH*("`@("`@("`D>"`](%-%4E9)0T537U=%051(15)?4D%$25537T5!4E1(
M("H@8V]S*"1P:&DI("H@8V]S*"1T:&5T82D["B`@("`@("`@)'D@/2!315)6
M24-%4U]714%42$527U)!1$E54U]%05)42"`J('-I;B@D<&AI*2`J(&-O<R@D
M=&AE=&$I.PH@("`@("`@("1Z(#T@4T525DE#15-?5T5!5$A%4E]2041)55-?
M14%25$@@("`@("`@("`@("`@*B!S:6XH)'1H971A*3L*"B`@("`@("`@<F5T
M=7)N(&%R<F%Y*"1X+"`D>2P@)'HI.PH@("`@?0H@("`@+R\@?7U]"@H*("`@
M("\O('M[>R!C86QC=6QA=&53=6Y2:7-E4V5T*"D*("`@("\J*@H@("`@("H@
M0V%L8W5L871E<R!S=6YR:7-E(&%N9"!S=6YS970@9F]R(&$@;&]C871I;VX*
M("`@("`J"B`@("`@*B!4:&4@<W5N('!O<VET:6]N(&%L9V]R:71H;2!T86ME
M;B!F<F]M('1H92`G55,@3F%V86P@3V)S97)V871O<GDG<PH@("`@("H@06QM
M86YA8R!F;W(@0V]M<'5T97)S)RP@:6UP;&5M96YT960@8GD@2V5N($)L;V]M
M(#QK96MA8FQO;VU;871==6-D879I<UMD;W1=961U/@H@("`@("H@9F]R('1H
M92!Z;6%N:6T@<')O:F5C="P@8V]N=F5R=&5D('1O($,@8GD@36]S:&4@1&]R
M;VX@/&UO<V1O<F]N6V%T76YE='9I<VEO;EMD;W1=;F5T6V1O=%UI;#X*("`@
M("`J(&%N9"!F:6YA;&QY('1A:V5N(&9R;VT@=&AE(%!(4#4@<V]U<F-E<R!A
M;F0@8V]N=F5R=&5D('1O(&YA=&EV92!02%`@87,@82!W<F%P<&5R+@H@("`@
M("H*("`@("`J(%1H92!D871E(&AA<R!T;R!B92!E;G1E<F5D(&%S(&$@=&EM
M97-T86UP(0H@("`@("H*("`@("`J($!P87)A;2`@(&EN="`@("`@("`@("`@
M("`@("`@("`@("`@("`D9&%T90H@("`@("H@0'!A<F%M("`@:6YT("`@("`@
M("`@("`@("`@("`@("`@("`@("1R971F;W)M870*("`@("`J($!P87)A;2`@
M(&9L;V%T("`@("`@("`@("`@("`@("`@("`@("`D;&%T:71U9&4*("`@("`J
M($!P87)A;2`@(&9L;V%T("`@("`@("`@("`@("`@("`@("`@("`D;&]N9VET
M=61E"B`@("`@*B!`<&%R86T@("!F;&]A="`@("`@("`@("`@("`@("`@("`@
M("`@)'IE;FET:`H@("`@("H@0'!A<F%M("`@9FQO870@("`@("`@("`@("`@
M("`@("`@("`@("1G;71?;V9F<V5T"B`@("`@*B!`<&%R86T@("!B;V]L("`@
M("`@("`@("`@("`@("`@("`@("`@)'-U;G)I<V4*("`@("`J($!R971U<FX@
M(%!%05)?17)R;W)\;6EX960*("`@("`J($!T:')O=W,@(%!%05)?17)R;W(Z
M.E-%4E9)0T537U=%051(15)?15)23U)?4U5.1E5.0U-?1$%415])3E9!3$E$
M"B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R.CI315)624-%4U]714%42$52
M7T524D]27U-53D953D-37U)%5$9/4DU?24Y604Q)1`H@("`@("H@0'1H<F]W
M<R`@4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/4E]53DM.3U=.
M7T524D]2"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J+PH@("`@9G5N
M8W1I;VX@8V%L8W5L871E4W5N4FES95-E="@D9&%T92P@)')E=&9O<FUA="`]
M(&YU;&PL("1L871I='5D92`](&YU;&PL("1L;VYG:71U9&4@/2!N=6QL+"`D
M>F5N:71H(#T@;G5L;"P@)&=M=%]O9F9S970@/2!N=6QL+"`D<W5N<FES92`]
M('1R=64I"B`@("!["B`@("`@("`@+R\@1&%T92!M=7-T(&)E('1I;65S=&%M
M<"!F;W(@;F]W"B`@("`@("`@:68@*"%I<U]I;G0H)&1A=&4I*2!["B`@("`@
M("`@("`@(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%
M4E9)0T537U=%051(15)?15)23U)?4U5.1E5.0U-?1$%415])3E9!3$E$+"!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@+R\@0VAE
M8VL@9F]R('!R;W!E<B!R971U<FX@9F]R;6%T"B`@("`@("`@:68@*"1R971F
M;W)M870@/3T](&YU;&PI('L*("`@("`@("`@("`@)')E=&9O<FUA="`@/2!3
M54Y&54Y#4U]2151?4U1224Y'.PH@("`@("`@('T@96QS96EF("@A:6Y?87)R
M87DH)')E=&9O<FUA="P@87)R87DH4U5.1E5.0U-?4D547U1)34535$%-4"P@
M4U5.1E5.0U-?4D547U-44DE.1RP@4U5.1E5.0U-?4D547T1/54),12DI("D@
M>PH@("`@("`@("`@("!R971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%
M<G)O<BA315)624-%4U]714%42$527T524D]27U-53D953D-37U)%5$9/4DU?
M24Y604Q)1"P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@
M("`@("\O(%-E="!D969A=6QT('9A;'5E<R!F;W(@8V]O<F1I;F%T97,*("`@
M("`@("!I9B`H)&QA=&ET=61E(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1L
M871I='5D92`@(#T@4U5.1E5.0U-?1$5&055,5%],051)5%5$13L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D;&%T:71U9&4@("`]("AF;&]A="D@
M)&QA=&ET=61E.PH@("`@("`@('T*("`@("`@("!I9B`H)&QO;F=I='5D92`]
M/3T@;G5L;"D@>PH@("`@("`@("`@("`D;&]N9VET=61E("`](%-53D953D-3
M7T1%1D%53%1?3$].1TE4541%.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1L;VYG:71U9&4@(#T@*&9L;V%T*2`D;&]N9VET=61E.PH@("`@("`@
M('T*("`@("`@("!I9B`H)'IE;FET:"`]/3T@;G5L;"D@>PH@("`@("`@("`@
M("!I9B@D<W5N<FES92D@>PH@("`@("`@("`@("`@("`@)'IE;FET:"`](%-5
M3D953D-37U-53E))4T5?6D5.251(.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)'IE;FET:"`](%-53D953D-37U-53E-%5%]:14Y)
M5$@["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D>F5N:71H("`@("`]("AF;&]A="D@)'IE;FET:#L*("`@("`@("!]"@H@
M("`@("`@("\O($1E9F%U;'0@=F%L=64@9F]R($=-5"!O9F9S970*("`@("`@
M("!I9B`H)&=M=%]O9F9S970@/3T](&YU;&PI('L*("`@("`@("`@("`@)&=M
M=%]O9F9S970@/2!D871E*"):(BP@)&1A=&4I("\@,S8P,#L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D9VUT7V]F9G-E="`]("AF;&]A="D@)&=M
M=%]O9F9S970["B`@("`@("`@?0H*("`@("`@("`O+R!)9B!W92!H879E(%!(
M4#4L('1H96X@86-T(&%S('=R87!P97(@9F]R('1H92!A<'!R;W!R:6%T92!F
M=6YC=&EO;G,*("`@("`@("!I9B`H)'-U;G)I<V4@)B8@9G5N8W1I;VY?97AI
M<W1S*")D871E7W-U;G)I<V4B*2D@>PH@("`@("`@("`@("!R971U<FX@9&%T
M95]S=6YR:7-E*"1D871E+"`D<F5T9F]R;6%T+"`D;&%T:71U9&4L("1L;VYG
M:71U9&4L("1Z96YI=&@L("1G;71?;V9F<V5T*3L*("`@("`@("!]"B`@("`@
M("`@:68@*"$D<W5N<FES92`F)B!F=6YC=&EO;E]E>&ES=',H(F1A=&5?<W5N
M<V5T(BDI('L*("`@("`@("`@("`@<F5T=7)N(&1A=&5?<W5N<V5T*"1D871E
M+"`D<F5T9F]R;6%T+"`D;&%T:71U9&4L("1L;VYG:71U9&4L("1Z96YI=&@L
M("1G;71?;V9F<V5T*3L*("`@("`@("!]"@H@("`@("`@("\O($%P<&%R96YT
M;'D@=V4@:&%V92!02%`T+"!S;R!C86QC=6QA=&4@=&AE(&YE8V-E<W-A<GD@
M<W1E<',@:6X@;F%T:79E(%!(4`H@("`@("`@("\O(%-T97`@,3H@1FER<W0@
M8V%L8W5L871E('1H92!D87D@;V8@=&AE('EE87(*("`@("`@("`D3B`](&1A
M=&4H(GHB+"`D9&%T92D@*R`Q.PH*("`@("`@("`O+R!3=&5P(#(Z($-O;G9E
M<G0@=&AE(&QO;F=I='5D92!T;R!H;W5R('9A;'5E(&%N9"!C86QC=6QA=&4@
M86X@87!P<F]X:6UA=&4@=&EM90H@("`@("`@("1L;F=(;W5R(#T@)&QO;F=I
M='5D92`O(#$U.PH*("`@("`@("`O+R!5<V4@,3@@9F]R('-U;G-E="!I;G-T
M96%D(&]F(#8*("`@("`@("!I9B`H)'-U;G)I<V4I('L*("`@("`@("`@("`@
M+R\@4W5N<FES90H@("`@("`@("`@("`D="`]("1.("L@*"@V("T@)&QN9TAO
M=7(I("\@,C0I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O(%-U
M;G-E=`H@("`@("`@("`@("`D="`]("1.("L@*"@Q."`M("1L;F=(;W5R*2`O
M(#(T*3L*("`@("`@("!]"@H@("`@("`@("\O(%-T97`@,SH@0V%L8W5L871E
M('1H92!S=6XG<R!M96%N(&%N;VUA;'D*("`@("`@("`D32`]("@P+CDX-38@
M*B`D="D@+2`S+C(X.3L*"B`@("`@("`@+R\@4W1E<"`T.B!#86QC=6QA=&4@
M=&AE('-U;B=S('1R=64@;&]N9VET=61E"B`@("`@("`@)$P@/2`D32`K("@Q
M+CDQ-B`J('-I;BAD96<R<F%D*"1-*2DI("L@*#`N,#(P("H@<VEN*&1E9S)R
M860H,B`J("1-*2DI("L@,C@R+C8S-#L*"B`@("`@("`@=VAI;&4@*"1,(#P@
M,"D@>PH@("`@("`@("`@("`D3'@@/2`D3"`K(#,V,#L*("`@("`@("`@("`@
M87-S97)T*"1,>"`A/2`D3"D[("\O(&%S:VEN9W1H96=U<G4Z(')E86QL>2!N
M965D960_"B`@("`@("`@("`@("1,(#T@)$QX.PH@("`@("`@('T*"B`@("`@
M("`@=VAI;&4@*"1,(#X](#,V,"D@>PH@("`@("`@("`@("`D3'@@/2`D3"`M
M(#,V,#L*("`@("`@("`@("`@87-S97)T*"1,>"`A/2`D3"D[("\O(&%S:VEN
M9W1H96=U<G4Z(')E86QL>2!N965D960_"B`@("`@("`@("`@("1,(#T@)$QX
M.PH@("`@("`@('T*"B`@("`@("`@+R\@4W1E<"`U83H@0V%L8W5L871E('1H
M92!S=6XG<R!R:6=H="!A<V-E;G-I;VX*("`@("`@("`D4D$@/2!R860R9&5G
M*&%T86XH,"XY,3<V-"`J('1A;BAD96<R<F%D*"1,*2DI*3L*"B`@("`@("`@
M=VAI;&4@*"1202`\(#`I('L*("`@("`@("`@("`@)%)!>"`]("1202`K(#,V
M,#L*("`@("`@("`@("`@87-S97)T*"1207@@(3T@)%)!*3L@+R\@87-K:6YG
M=&AE9W5R=3H@<F5A;&QY(&YE961E9#\*("`@("`@("`@("`@)%)!(#T@)%)!
M>#L*("`@("`@("!]"@H@("`@("`@('=H:6QE("@D4D$@/CT@,S8P*2!["B`@
M("`@("`@("`@("1207@@/2`D4D$@+2`S-C`["B`@("`@("`@("`@(&%S<V5R
M="@D4D%X("$]("1202D[("\O(&%S:VEN9W1H96=U<G4Z(')E86QL>2!N965D
M960_"B`@("`@("`@("`@("1202`]("1207@["B`@("`@("`@?0H*("`@("`@
M("`O+R!3=&5P(#5B.B!2:6=H="!A<V-E;G-I;VX@=F%L=64@;F5E9',@=&\@
M8F4@:6X@=&AE('-A;64@<75A9')A;G0@87,@3`H@("`@("`@("1,<75A9')A
M;G0@(#T@9FQO;W(H)$P@+R`Y,"D@*B`Y,#L*("`@("`@("`D4D%Q=6%D<F%N
M="`](&9L;V]R*"1202`O(#DP*2`J(#DP.PH*("`@("`@("`D4D$@/2`D4D$@
M*R`H)$QQ=6%D<F%N="`M("1207%U861R86YT*3L*"B`@("`@("`@+R\@4W1E
M<"`U8SH@4FEG:'0@87-C96YS:6]N('9A;'5E(&YE961S('1O(&)E(&-O;G9E
M<G1E9"!I;G1O(&AO=7)S"B`@("`@("`@)%)!("\](#$U.PH*("`@("`@("`O
M+R!3=&5P(#8Z($-A;&-U;&%T92!T:&4@<W5N)W,@9&5C;&EN871I;VX*("`@
M("`@("`D<VEN1&5C(#T@,"XS.3<X,B`J('-I;BAD96<R<F%D*"1,*2D["B`@
M("`@("`@)&-O<T1E8R`](&-O<RAA<VEN*"1S:6Y$96,I*3L*"B`@("`@("`@
M+R\@4W1E<"`W83H@0V%L8W5L871E('1H92!S=6XG<R!L;V-A;"!H;W5R(&%N
M9VQE"B`@("`@("`@)&-O<T@@/2`H8V]S*&1E9S)R860H)'IE;FET:"DI("T@
M*"1S:6Y$96,@*B!S:6XH9&5G,G)A9"@D;&%T:71U9&4I*2DI("\@*"1C;W-$
M96,@*B!C;W,H9&5G,G)A9"@D;&%T:71U9&4I*2D["@H@("`@("`@("\O(%A8
M6#H@5VAA="=S('1H92!U<V4@;V8@=&AI<R!B;&]C:RXN(#\*("`@("`@("`O
M+R!I9B`H<W5N<FES92`F)B!C;W-((#X@,2!\?"`A<W5N<FES92`F)B!C;W-(
M(#P@+3$I('L*("`@("`@("`O+R`@("`@=&AR;W<@9&]E<VYT:&%P<&5N*"D[
M"B`@("`@("`@+R\@?0H*("`@("`@("`O+R!3=&5P(#=B.B!&:6YI<V@@8V%L
M8W5L871I;F<@2"!A;F0@8V]N=F5R="!I;G1O(&AO=7)S"B`@("`@("`@:68@
M*"1S=6YR:7-E*2!["B`@("`@("`@("`@("\O(%-U;G)I<V4*("`@("`@("`@
M("`@)$@@/2`S-C`@+2!R860R9&5G*&%C;W,H)&-O<T@I*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`O+R!3=6YS970*("`@("`@("`@("`@)$@@
M/2!R860R9&5G*&%C;W,H)&-O<T@I*3L*("`@("`@("!]"B`@("`@("`@)$@@
M/2`D2"`O(#$U.PH*("`@("`@("`O+R!3=&5P(#@Z($-A;&-U;&%T92!L;V-A
M;"!M96%N('1I;64*("`@("`@("`D5"`]("1(("L@)%)!("T@*#`N,#8U-S$@
M*B`D="D@+2`V+C8R,CL*"B`@("`@("`@+R\@4W1E<"`Y.B!#;VYV97)T('1O
M(%540PH@("`@("`@("155"`]("14("T@)&QN9TAO=7(["@H@("`@("`@('=H
M:6QE("@D550@/"`P*2!["B`@("`@("`@("`@("155'@@/2`D550@*R`R-#L*
M("`@("`@("`@("`@87-S97)T*"155'@@(3T@)%54*3L@+R\@87-K:6YG=&AE
M9W5R=3H@<F5A;&QY(&YE961E9#\*("`@("`@("`@("`@)%54(#T@)%54>#L*
M("`@("`@("!]"@H@("`@("`@('=H:6QE("@D550@/CT@,C0I('L*("`@("`@
M("`@("`@)%54>"`]("155"`M(#(T.PH@("`@("`@("`@("!A<W-E<G0H)%54
M>"`A/2`D550I.R`O+R!A<VMI;F=T:&5G=7)U.B!R96%L;'D@;F5E9&5D/PH@
M("`@("`@("`@("`D550@/2`D551X.PH@("`@("`@('T*"B`@("`@("`@)%54
M(#T@)%54("L@)&=M=%]O9F9S970["@H@("`@("`@("\O($YO=R!B<FEN9R!T
M:&4@<F5S=6QT(&EN=&\@=&AE(&-H;W-E;B!F;W)M870@86YD(')E='5R;@H@
M("`@("`@('-W:71C:"`H)')E=&9O<FUA="D@>PH@("`@("`@("`@("!C87-E
M(%-53D953D-37U)%5%]424U%4U1!35`Z"B`@("`@("`@("`@("`@("!R971U
M<FX@9FQO;W(H)&1A=&4@+2`H)&1A=&4@)2`H,C0@*B`S-C`P*2DI("L@9FQO
M;W(H-C`@*B`D550I.PH@("`@("`@("`@("!C87-E(%-53D953D-37U)%5%]3
M5%))3D<Z"B`@("`@("`@("`@("`@("`D3B`](&9L;V]R*"155"D["B`@("`@
M("`@("`@("`@("!R971U<FX@<W!R:6YT9B@B)3`R9#HE,#)D(BP@)$XL(&9L
M;V]R*#8P("H@*"155"`M("1.*2DI.PH@("`@("`@("`@("!C87-E(%-53D95
M3D-37U)%5%]$3U5"3$4Z"B`@("`@("`@("`@("`@("!R971U<FX@)%54.PH@
M("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@<F5T=7)N(%-E
M<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%
M4E)/4E]53DM.3U=.7T524D]2+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@
M("`@('T*("`@('T*("`@("\O('U]?0H*("`@("\O('M[>R!G971796%T:&5R
M26-O;B@I"B`@("`O*BH*("`@("`J($=E=',@82!N=6UB97(@8V]R<F5S<&]N
M9&EN9R!T;R!A('=E871H97(@:6-O;BX*("`@("`J"B`@("`@*B!4:&5S92!N
M=6UB97)S(&IU<W0@:&%P<&5N('1O(&-O<G)E<W!O;F0@=VET:"!T:&4@:6-O
M;G,@=&AA="!Y;W4@9V5T('=I=&@*("`@("`J('1H92!W96%T:&5R+F-O;2!3
M1$LL(&)U="!O<&5N('9E<G-I;VYS(&]F('1H96T@:&%V92!B965N(&-R96%T
M960N($EN<'5T"B`@("`@*B!M=7-T(&)E(&EN('-T86YD87)D('5N:71S+B!&
M;W(@=&AE(&EC;VYS('1H870@:6YC;'5D92!D87DO;FEG:'0L('=E('5S90H@
M("`@("H@=&AE('!R97-E;G0@=&EM92!A;F0@=&AE('!R;W9I9&5D(&QA="]L
M;VX@=&\@9&5T97)M:6YE(&EF('1H92!S=6X@:7,@=7`N"B`@("`@*B!!(&-O
M;7!L971E('-E="!O9B!I8V]N(&1E<V-R:7!T:6]N<R!C86X@8F4@9F]U;F0@
M:&5R93H*("`@("`J(&AT='`Z+R]S<F%N<VAA9G0N=VEN8W5S=&]M:7IE+F-O
M;2]!<G1I8VQE<RYA<W!X/T%)1#TV,#$V-29U/3`*("`@("`J"B`@("`@*B!4
M:&5R92!A<F4@82!N=6UB97(@;V8@:6-O;B!S971S(&AE<F4Z"B`@("`@*B!H
M='1P.B\O=W=W+F1E<VMT;W!S:61E8F%R+F-O;2]F;W)U;7,O:6YD97@N<&AP
M/W-H;W=T;W!I8STR-#0Q)G-T/3`*("`@("`J(&AT='`Z+R]W=W<N9&5S:W1O
M<'-I9&5B87(N8V]M+V9O<G5M<R]I;F1E>"YP:'`_<VAO=W1O<&EC/3@Q.0H@
M("`@("H*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@("`@("`@
M("`@("`D8V]N9&ET:6]N("`@("`@5&AE(&-O;F1I=&EO;BX*("`@("`J($!P
M87)A;2`@(&%R<F%Y("`@("`@("`@("`@("`@("`@("`@("`D8VQO=61S("`@
M("`@("`@5&AE(&-L;W5D<R!A="!V87)I;W5S(&QE=F5L<RX*("`@("`J($!P
M87)A;2`@(&9L;V%T("`@("`@("`@("`@("`@("`@("`@("`D=VEN9"`@("`@
M("`@("`@5VEN9"!S<&5E9"!I;B!M<&@N"B`@("`@*B!`<&%R86T@("!F;&]A
M="`@("`@("`@("`@("`@("`@("`@("`@)'1E;7!E<F%T=7)E("`@(%1E;7!E
M<F%T=7)E(&EN(&1E9R!&+@H@("`@("H@0'!A<F%M("`@9FQO870@("`@("`@
M("`@("`@("`@("`@("`@("1L871I='5D92`@("`@("!0;VEN="!L871I='5D
M92X*("`@("`J($!P87)A;2`@(&9L;V%T("`@("`@("`@("`@("`@("`@("`@
M("`D;&]N9VET=61E("`@("`@4&]I;G0@;&]N9VET=61E+@H@("`@("H@0&%U
M=&AO<B`@4V5T:"!0<FEC92`@/'-E=&A`<')I8V5P86=E<RYO<F<^"B`@("`@
M*B!`86-C97-S("!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5V5A
M=&AE<DEC;VXH)&-O;F1I=&EO;BP@)&-L;W5D<R`](&%R<F%Y*"DL("1W:6YD
M(#T@-2P@)'1E;7!E<F%T=7)E(#T@-S`L("1L871I='5D92`]("TS-C`L("1L
M;VYG:71U9&4@/2`M,S8P*0H@("`@>PH@("`@("`@("\O(%-E87)C:"!F;W(@
M;6%T8VAE<R!T:&%T(&1O;B=T('5S92!T:&4@=&EM92!O9B!D87D*("`@("`@
M("`D:&%I;"`@("`@/2`H8F]O;"D@<W1R:7-T<B@D8V]N9&ET:6]N+"`B:&%I
M;"(I.PH@("`@("`@("1D=7-T("`@("`]("AB;V]L*2!S=')I<W1R*"1C;VYD
M:71I;VXL(")D=7-T(BD@("`@('Q\("AB;V]L*2!S=')I<W1R*"1C;VYD:71I
M;VXL(")S86YD(BD["B`@("`@("`@)'-M;VME("`@(#T@*&)O;VPI('-T<FES
M='(H)&-O;F1I=&EO;BP@(G-M;VME(BD@("`@?'P@*&)O;VPI('-T<FES='(H
M)&-O;F1I=&EO;BP@(G9O;&-A;FEC(&%S:"(I.PH*("`@("`@("`O+R!3;&EG
M:'1L>2!M;W)E(&-O;7!L97@@;6%T8VAE<R!T:&%T(&UI9VAT(&]R(&UI9VAT
M(&YO="!U<V4@=&AE('1I;64@;V8@9&%Y"B`@("`@("`@)&YE87(@("`@(#T@
M*&)O;VPI('-T<FES='(H)&-O;F1I=&EO;BP@(G9I8VEN:71Y(BD@?'P@*&)O
M;VPI('-T<FES='(H)&-O;F1I=&EO;BP@(G)E8V5N="(I.PH@("`@("`@("1L
M:6=H="`@("`]("AB;V]L*2!S=')I<W1R*"1C;VYD:71I;VXL(")L:6=H="(I
M.PH@("`@("`@("1H96%V>2`@("`]("AB;V]L*2!S=')I<W1R*"1C;VYD:71I
M;VXL(")H96%V>2(I.PH@("`@("`@("1I8V4@("`@("`]("AB;V]L*2!S=')I
M<W1R*"1C;VYD:71I;VXL(")I8V4B*2`@("`@('Q\("AB;V]L*2!S=')I<W1R
M*"1C;VYD:71I;VXL(")P96QL971S(BD["B`@("`@("`@)')A:6X@("`@(#T@
M*&)O;VPI('-T<FES='(H)&-O;F1I=&EO;BP@(G)A:6XB*3L*("`@("`@("`D
M<VYO=R`@("`@/2`H8F]O;"D@<W1R:7-T<B@D8V]N9&ET:6]N+"`B<VYO=R(I
M.PH@("`@("`@("1F;V<@("`@("`]("AB;V]L*2!S=')I<W1R*"1C;VYD:71I
M;VXL(")F;V<B*2`@("`@('Q\("AB;V]L*2!S=')I<W1R*"1C;VYD:71I;VXL
M(")S<')A>2(I("`@("`@("!\?"`H8F]O;"D@<W1R:7-T<B@D8V]N9&ET:6]N
M+"`B;6ES="(I.PH@("`@("`@("1H87IE("`@("`]("AB;V]L*2!S=')I<W1R
M*"1C;VYD:71I;VXL(")H87IE(BD["B`@("`@("`@)'1S("`@("`@(#T@*&)O
M;VPI('-T<FES='(H)&-O;F1I=&EO;BP@(G1H=6YD97)S=&]R;2(I.PH@("`@
M("`@("1F<F5E>FEN9R`]("AB;V]L*2!S=')I<W1R*"1C;VYD:71I;VXL(")F
M<F5E>FEN9R(I.PH@("`@("`@("1W:6YD("`@("`]("AB;V]L*2!S=')I<W1R
M*"1C;VYD:71I;VXL(")S<75A;&PB*2`@('Q\("1W:6YD(#X@,C4["B`@("`@
M("`@)&YS=R`@("`@(#T@*&)O;VPI('-T<FES='(H)&-O;F1I=&EO;BP@(FYO
M('-I9VYI9FEC86YT('=E871H97(B*3L*("`@("`@("`D:&]T("`@("`@/2`D
M=&5M<&5R871U<F4@/B`Y-3L*("`@("`@("`D9G)I9VED("`@/2`D=&5M<&5R
M871U<F4@/"`U.PH*"B`@("`@("`@:68@*"1H86EL*2!["B`@("`@("`@("`@
M(')E='5R;B`V.R`@+R\@2&%I;`H@("`@("`@('T*("`@("`@("!I9B`H)&1U
M<W0I('L*("`@("`@("`@("`@<F5T=7)N(#$Y.R`O+R!$=7-T"B`@("`@("`@
M?0H@("`@("`@(&EF("@D<VUO:V4I('L*("`@("`@("`@("`@<F5T=7)N(#(R
M.R`O+R!3;6]K90H@("`@("`@('T*"B`@("`@("`@+R\@1V5T('-O;64@;V8@
M=&AE(&1A;F=E<F]U<R!C;VYD:71I;VYS(&9I<W0*("`@("`@("!I9B`H)')A
M:6X@)B8@)'-N;W<@)B8@*"1I8V4@?'P@)&9R965Z:6YG*2D@>PH@("`@("`@
M("`@("!R971U<FX@-SL@("\O($EC>2]#;&]U9',@4F%I;BU3;F]W"B`@("`@
M("`@?0H@("`@("`@(&EF("@H)'1S('Q\("1R86EN*2`F)B`H)&EC92!\?"`D
M9G)E97II;F<I*2!["B`@("`@("`@("`@(')E='5R;B`Q,#L@+R\@26-Y+U)A
M:6X*("`@("`@("!]"B`@("`@("`@:68@*"@D9F]G('Q\("1H87IE*2`F)B`H
M)&EC92!\?"`D9G)E97II;F<I*2!["B`@("`@("`@("`@(')E='5R;B`X.R`@
M+R\@26-Y+TAA>F4@4F%I;@H@("`@("`@('T*("`@("`@("!I9B`H)')A:6X@
M)B8@)'-N;W<I('L*("`@("`@("`@("`@<F5T=7)N(#4[("`O+R!#;&]U9'DO
M4VYO=RU286EN($UI>`H@("`@("`@('T*("`@("`@("!I9B`H)&9O9R`F)B`D
M<F%I;BD@>PH@("`@("`@("`@("!R971U<FX@.3L@("\O($AA>F4O4F%I;@H@
M("`@("`@('T*("`@("`@("!I9B`H)'=I;F0@)B8@)')A:6XI('L*("`@("`@
M("`@("`@<F5T=7)N(#$[("`O+R!7:6YD+U)A:6X*("`@("`@("!]"B`@("`@
M("`@:68@*"1W:6YD("8F("1S;F]W*2!["B`@("`@("`@("`@(')E='5R;B`T
M,SL@+R\@5VEN9'DO4VYO=PH@("`@("`@('T*("`@("`@("!I9B`H)'-N;W<@
M)B8@)&QI9VAT*2!["B`@("`@("`@("`@(')E='5R;B`Q,SL@+R\@1FQU<G)I
M97,*("`@("`@("!]"B`@("`@("`@:68@*"1L:6=H="`F)B`D<F%I;BD@>PH@
M("`@("`@("`@("!R971U<FX@,3$[("\O($QI9VAT(%)A:6X*("`@("`@("!]
M"@H@("`@("`@("\O($=E="!T:&4@;6%X:6UU;2!C;W9E<F%G92!O9B!T:&4@
M8VQO=61S(&%T(&%N>2!H96EG:'0N($9O<B!M;W-T"B`@("`@("`@+R\@<&5O
M<&QE+"!O=F5R8V%S="!A="`Q,#`P9G0@:7,@=&AE('-A;64@87,@;W9E<F-A
M<W0@870@,3`P,#!F="X*("`@("`@("`O+PH@("`@("`@("\O(#`@/3T@8VQE
M87(L(#$@/3T@:&%Z97DL(#(@/3T@<&%R=&QY(&-L;W5D>2P@,R`]/2!M;W-T
M;'D@8VQO=61Y+"`T(#T](&]V97)C87-T"B`@("`@("`@)&-O=F5R86=E(#T@
M,#L*("`@("`@("!F;W)E86-H("@D8VQO=61S(&%S("1L87EE<BD@>PH@("`@
M("`@("`@("!I9B`H)&-O=F5R86=E(#P@,2`F)B!S=')I<W1R*"1L87EE<ELB
M86UO=6YT(ETL(")F97<B*2D@>PH@("`@("`@("`@("`@("`@)&-O=F5R86=E
M(#T@,3L*("`@("`@("`@("`@?2!E;'-E:68@*"1C;W9E<F%G92`\(#(@)B8@
M<W1R:7-T<B@D;&%Y97);(F%M;W5N=")=+"`B<V-A='1E<F5D(BDI('L*("`@
M("`@("`@("`@("`@("1C;W9E<F%G92`](#(["B`@("`@("`@("`@('T@96QS
M96EF("@D8V]V97)A9V4@/"`S("8F("AS=')I<W1R*"1L87EE<ELB86UO=6YT
M(ETL(")B<F]K96XB*2!\?"!S=')I<W1R*"1L87EE<ELB86UO=6YT(ETL(")C
M=6UU;'5S(BDI*2!["B`@("`@("`@("`@("`@("`D8V]V97)A9V4@/2`S.PH@
M("`@("`@("`@("!](&5L<V5I9B`H)&-O=F5R86=E(#P@-"`F)B!S=')I<W1R
M*"1L87EE<ELB86UO=6YT(ETL(")O=F5R8V%S="(I*2!["B`@("`@("`@("`@
M("`@("`D8V]V97)A9V4@/2`T.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("`O+R!#:&5C:R!I9B!I="!I<R!D87D@;W(@;F]T+B`P(&ES(&YI
M9VAT+"`R(&ES(&1A>2P@86YD(#$@:7,@=6YK;F]W;@H@("`@("`@("\O(&]R
M('1W:6QI9VAT("A^*"M\+2DQ(&AO=7(@;V8@<W5N<FES92]S=6YS970I+B!.
M;W1E('1H870@='=I;&EG:'0@:7-N)W0*("`@("`@("`O+R!A;'=A>7,@86-C
M=7)A=&4@8F5C875S92!O9B!I<W-U97,@=W)A<'!I;F<@87)O=6YD('1H92`R
M-&AR(&-L;V-K+B!/:"!W96QL+BXN"B`@("`@("`@:68@*"1L871I='5D92`\
M(#DP("8F("1L871I='5D92`^("TY,"`F)B`D;&]N9VET=61E(#P@,3@P("8F
M("1L;VYG:71U9&4@/B`M,3@P*2!["B`@("`@("`@("`@("\O($-A;&-U;&%T
M92!S=6YR:7-E+W-U;G-E="!A;F0@8W5R<F5N="!T:6UE(&EN($=-5`H@("`@
M("`@("`@("`D<W5N<FES92`@(#T@)'1H:7,M/F-A;&-U;&%T95-U;E)I<V53
M970H9VUM:W1I;64H*2P@4U5.1E5.0U-?4D547U1)34535$%-4"P@)&QA=&ET
M=61E+"`D;&]N9VET=61E+"!315)624-%4U]714%42$527U-53D953D-37U-5
M3E))4T5?6D5.251(+"`P+"!T<G5E*3L*("`@("`@("`@("`@)'-U;G-E="`@
M("`]("1T:&ES+3YC86QC=6QA=&53=6Y2:7-E4V5T*&=M;6MT:6UE*"DL(%-5
M3D953D-37U)%5%]424U%4U1!35`L("1L871I='5D92P@)&QO;F=I='5D92P@
M4T525DE#15-?5T5!5$A%4E]354Y&54Y#4U]354Y225-%7UI%3DE42"P@,"P@
M9F%L<V4I.PH@("`@("`@("`@("`D=&EM94]F1&%Y(#T@9VUM:W1I;64H*3L*
M"B`@("`@("`@("`@("\O($YO=R!T:&%T('=E(&AA=F4@=&AE('-U;G)I<V4O
M<W5N<V5T('1I;65S(&%N9"!T:&4@8W5R<F5N="!T:6UE+`H@("`@("`@("`@
M("`O+R!W92!N965D('1O(&9I9W5R92!O=70@:68@:70@:7,@9&%Y+"!N:6=H
M="P@;W(@='=I;&EG:'0N(%=R87!P:6YG"B`@("`@("`@("`@("\O('1H97-E
M('1I;65S(&%R;W5N9"!T:&4@,C1H<B!C;&]C:R!I<R!A('!A:6XN"B`@("`@
M("`@("`@(&EF("@D<W5N<FES92`\("1S=6YS970I('L*("`@("`@("`@("`@
M("`@(&EF("@D=&EM94]F1&%Y(#X@*"1S=6YR:7-E("L@,S8P,"D@)B8@)'1I
M;65/9D1A>2`\("@D<W5N<V5T("T@,S8P,"DI('L*("`@("`@("`@("`@("`@
M("`@("`D:7-$87D@/2`R.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1T
M:6UE3V9$87D@/B`H)'-U;G)I<V4@+2`S-C`P*2`F)B`D=&EM94]F1&%Y(#P@
M*"1S=6YS970@*R`S-C`P*2D@>PH@("`@("`@("`@("`@("`@("`@("1I<T1A
M>2`](#$["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("1I<T1A>2`](#`["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("!I9B`H)'1I;65/9D1A>2`\
M("@D<W5N<FES92`M(#,V,#`I("8F("1T:6UE3V9$87D@/B`H)'-U;G-E="`K
M(#,V,#`I*2!["B`@("`@("`@("`@("`@("`@("`@)&ES1&%Y(#T@,#L*("`@
M("`@("`@("`@("`@('T@96QS96EF("@D=&EM94]F1&%Y(#P@*"1S=6YR:7-E
M("L@,S8P,"D@)B8@)'1I;65/9D1A>2`^("@D<W5N<V5T("T@,S8P,"DI('L*
M("`@("`@("`@("`@("`@("`@("`D:7-$87D@/2`Q.PH@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D:7-$87D@/2`R.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@+R\@1&5F875L="!T;R!T=VEL:6=H="!B96-A=7-E
M(&ET('1E;F1S('1O(&AA=F4@;F5U=')A;"!I8V]N<RX*("`@("`@("`@("`@
M)&ES1&%Y(#T@,3L*("`@("`@("!]"@H@("`@("`@("\O($=E;F5R86P@<')E
M8VEP:71A=&EO;@H@("`@("`@(&EF("@D=',@)B8@)&YE87(I('L*("`@("`@
M("`@("`@<W=I=&-H("@D:7-$87DI('L*("`@("`@("`@("`@("`@(&-A<V4@
M,#H*("`@("`@("`@("`@("`@(&-A<V4@,3H*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@,S@[("\O($QI9VAT;FEN9PH@("`@("`@("`@("`@("`@8V%S
M92`R.@H@("`@("`@("`@("`@("`@("`@(')E='5R;B`S-SL@+R\@3&EG:'1N
M:6YG+T1A>0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@D
M=',I('L*("`@("`@("`@("`@<W=I=&-H("@D:7-$87DI('L*("`@("`@("`@
M("`@("`@(&-A<V4@,#H*("`@("`@("`@("`@("`@("`@("!R971U<FX@-#<[
M("\O(%1H=6YD97)S=&]R;2].:6=H=`H@("`@("`@("`@("`@("`@8V%S92`Q
M.@H@("`@("`@("`@("`@("`@8V%S92`R.@H@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`P.R`@+R\@4F%I;B],:6=H=&YI;F<*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!I9B`H)'-N;W<I('L*("`@("`@("`@("`@<W=I
M=&-H("@D:7-$87DI('L*("`@("`@("`@("`@("`@(&-A<V4@,#H*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@-#8[("\O(%-N;W<O3FEG:'0*("`@("`@
M("`@("`@("`@(&-A<V4@,3H*("`@("`@("`@("`@("`@(&-A<V4@,CH*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@-#$[("\O(%-N;W<*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@("`@("!I9B`H)')A:6XI('L*("`@("`@("`@
M("`@<W=I=&-H("@D:7-$87DI('L*("`@("`@("`@("`@("`@(&-A<V4@,#H*
M("`@("`@("`@("`@("`@("`@("!R971U<FX@-#4[("\O(%)A:6XO3FEG:'0*
M("`@("`@("`@("`@("`@(&-A<V4@,3H*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@-#`[("\O(%)A:6X*("`@("`@("`@("`@("`@(&-A<V4@,CH*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@,SD[("\O(%)A:6XO1&%Y"B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O($-L;W5D(&-O;F1I=&EO
M;G,@;F5A<B!T:&4@9W)O=6YD"B`@("`@("`@:68@*"1F;V<I('L*("`@("`@
M("`@("`@<F5T=7)N(#(P.R`O+R!&;V<*("`@("`@("!]"B`@("`@("`@:68@
M*"1H87IE*2!["B`@("`@("`@("`@(')E='5R;B`R,3L@+R\@2&%Z90H@("`@
M("`@('T*"B`@("`@("`@+R\@0VQO=60@8V]N9&ET:6]N<PH@("`@("`@(&EF
M("@D8V]V97)A9V4@/3T@-"D@>PH@("`@("`@("`@("!R971U<FX@,C8[("\O
M($UO<W1L>2!#;&]U9'D*("`@("`@("!]"B`@("`@("`@:68@*"1C;W9E<F%G
M92`]/2`S*2!["B`@("`@("`@("`@('-W:71C:"`H)&ES1&%Y*2!["B`@("`@
M("`@("`@("`@("!C87-E(#`Z"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M(#(W.R`O+R!-;W-T;'D@0VQO=61Y+TYI9VAT"B`@("`@("`@("`@("`@("!C
M87-E(#$Z"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(#(V.R`O+R!-;W-T
M;'D@0VQO=61Y"B`@("`@("`@("`@("`@("!C87-E(#(Z"B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N(#(X.R`O+R!-;W-T;'D@0VQO=61Y+T1A>0H@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@D8V]V97)A9V4@/3T@
M,BD@>PH@("`@("`@("`@("!S=VET8V@@*"1I<T1A>2D@>PH@("`@("`@("`@
M("`@("`@8V%S92`P.@H@("`@("`@("`@("`@("`@("`@(')E='5R;B`R.3L@
M+R\@4&%R=&QY($-L;W5D>2].:6=H=`H@("`@("`@("`@("`@("`@8V%S92`Q
M.@H@("`@("`@("`@("`@("`@("`@(')E='5R;B`R-CL@+R\@36]S=&QY($-L
M;W5D>0H@("`@("`@("`@("`@("`@8V%S92`R.@H@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`S,#L@+R\@4&%R=&QY($-L;W5D>2]$87D*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@("`@("!I9B`H)&-O=F5R86=E(#T](#$I('L*
M("`@("`@("`@("`@<W=I=&-H("@D:7-$87DI('L*("`@("`@("`@("`@("`@
M(&-A<V4@,#H*("`@("`@("`@("`@("`@(&-A<V4@,3H*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@,S,[("\O($AA>GDO3FEG:'0*("`@("`@("`@("`@
M("`@(&-A<V4@,CH*("`@("`@("`@("`@("`@("`@("!R971U<FX@,S0[("\O
M($AA>GDO1&%Y"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O
M($-A=&-H+6%L;',*("`@("`@("!I9B`H)'=I;F0I('L*("`@("`@("`@("`@
M<F5T=7)N(#(S.R`O+R!7:6YD"B`@("`@("`@?0H@("`@("`@(&EF("@D:&]T
M*2!["B`@("`@("`@("`@(')E='5R;B`S-CL@+R\@2&]T(0H@("`@("`@('T*
M("`@("`@("!I9B`H)&9R:6=I9"D@>PH@("`@("`@("`@("!R971U<FX@,C4[
M("\O($9R:6=I9`H@("`@("`@('T*"B`@("`@("`@:68@*"1N<W<I('L*("`@
M("`@("`@("`@<W=I=&-H("@D:7-$87DI('L*("`@("`@("`@("`@("`@(&-A
M<V4@,#H*("`@("`@("`@("`@("`@(&-A<V4@,3H*("`@("`@("`@("`@("`@
M("`@("`O+R!5<V4@;FEG:'0@9F]R('1W:6QI9VAT(&)E8V%U<V4@=&AE(&UO
M;VX@:7,@9V5N97)A;&QY"B`@("`@("`@("`@("`@("`@("`@+R\@;W5T('1H
M96XL('-O(&ET('=I;&P@;6%T8V@@=VET:"!M;W-T(&EC;VX@<V5T<RX*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@,S$[("\O($-L96%R($YI9VAT"B`@
M("`@("`@("`@("`@("!C87-E(#(Z"B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N(#,R.R`O+R!#;&5A<B!$87D*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N(")N82(["B`@("!]"B`@("`O+R!]?7T*?0HO+R!]
M?7T*/SX*=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]397)V:6-E<R]7
M96%T:&5R+G!H<```````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#(V,#8R(#$P-3$U-#,S-S(W(#`R,C,W,@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*B!V:6TZ('-E="!E>'!A
M;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT(&9O
M;&1M971H;V0];6%R:V5R.B`J+PH*+RHJ"B`J(%!%05(Z.E-E<G9I8V5S7U=E
M871H97(*("H*("H@4V5R=FEC97-?5V5A=&AE<B!S96%R8VAE<R!F;W(@9VEV
M96X@;&]C871I;VYS(&%N9"!R971R:65V97,@8W5R<F5N=`H@*B!W96%T:&5R
M(&1A=&$@86YD+"!D97!E;F1A;G0@;VX@=&AE('5S960@<V5R=FEC92P@86QS
M;R!F;W)E8V%S=',N(%5P('1O"B`J(&YO=RP@4T]!4"!S97)V:6-E<R!F<F]M
M($-A<&538VEE;F-E(&%N9"!%2E-%+"!834P@9G)O;2!W96%T:&5R+F-O;2!A
M;F0*("H@345405(O5$%&(&9R;VT@;F]A82YG;W8@87)E('-U<'!O<G1E9"P@
M9G5R=&AE<B!S97)V:6-E<R!W:6QL(&=E=`H@*B!I;F-L=61E9"P@:68@=&AE
M>2!B96-O;64@879A:6QA8FQE(&%N9"!A<F4@<')O<&5R;'D@9&]C=6UE;G1E
M9"X*("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@/$Q)0T5.4T4^
M"B`J($-O<'ER:6=H="`H8RD@,C`P-2P@06QE>&%N9&5R(%=I<G1Z"B`J($%L
M;"!R:6=H=',@<F5S97)V960N"B`J"B`J(%)E9&ES=')I8G5T:6]N(&%N9"!U
M<V4@:6X@<V]U<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U
M=`H@*B!M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@<')O=FED960@=&AA
M="!T:&4@9F]L;&]W:6YG(&-O;F1I=&EO;G,*("H@87)E(&UE=#H*("H@;R!2
M961I<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE
M(&%B;W9E(&-O<'ER:6=H="!N;W1I8V4L"B`J("`@=&AI<R!L:7-T(&]F(&-O
M;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX*("H@;R!2
M961I<W1R:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@
M=&AE(&%B;W9E(&-O<'ER:6=H="!N;W1I8V4L"B`J("`@=&AI<R!L:7-T(&]F
M(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T
M:&4@9&]C=6UE;G1A=&EO;@H@*B`@(&%N9"]O<B!O=&AE<B!M871E<FEA;',@
M<')O=FED960@=VET:"!T:&4@9&ES=')I8G5T:6]N+@H@*B!O($YE:71H97(@
M=&AE(&YA;64@;V8@=&AE('-O9G1W87)E(&YO<B!T:&4@;F%M97,@;V8@:71S
M(&-O;G1R:6)U=&]R<PH@*B`@(&UA>2!B92!U<V5D('1O(&5N9&]R<V4@;W(@
M<')O;6]T92!P<F]D=6-T<R!D97)I=F5D(&9R;VT@=&AI<R!S;V9T=V%R90H@
M*B`@('=I=&AO=70@<W!E8VEF:6,@<')I;W(@=W)I='1E;B!P97)M:7-S:6]N
M+@H@*@H@*B!42$E3(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#3U!9
M4DE'2%0@2$],1$524R!!3D0@0T].5%))0E543U)3(")!4R!)4R(*("H@04Y$
M($%.62!%6%!215-3($]2($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$24Y'
M+"!"550@3D]4($Q)34E4140@5$\L(%1(10H@*B!)35!,245$(%=!4E)!3E1)
M15,@3T8@34520TA!3E1!0DE,2519($%.1"!&251.15-3($9/4B!!(%!!4E1)
M0U5,05(@4%524$]310H@*B!!4D4@1$E30TQ!24U%1"X@24X@3D\@159%3E0@
M4TA!3$P@5$A%($-/4%E224=(5"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4*
M("H@3$E!0DQ%($9/4B!!3ED@1$E214-4+"!)3D1)4D5#5"P@24Y#241%3E1!
M3"P@4U!%0TE!3"P@15A%35!,05)9+"!/4@H@*B!#3TY315%514Y424%,($1!
M34%'15,@*$E.0TQ51$E.1RP@0E54($Y/5"!,24U)5$5$(%1/+"!04D]#55)%
M345.5"!/1@H@*B!354)35$E4551%($=/3T13($]2(%-%4E9)0T53.R!,3U-3
M($]&(%5312P@1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,*("H@24Y4
M15)255!424].*2!(3U=%5D52($-!55-%1"!!3D0@3TX@04Y9(%1(14]262!/
M1B!,24%"24Q)5%DL(%=(151(15(@24X*("H@0T].5%)!0U0L(%-44DE#5"!,
M24%"24Q)5%DL($]2(%1/4E0@*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]4
M2$525TE312D*("H@05))4TE.1R!)3B!!3ED@5T%9($]55"!/1B!42$4@55-%
M($]&(%1(25,@4T]&5%=!4D4L($5614X@248@041625-%1"!/1B!42$4*("H@
M4$]34TE"24Q)5%D@3T8@4U5#2"!$04U!1T4N"B`J(#PO3$E#14Y313X*("H*
M("H@0&-A=&5G;W)Y("`@(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G92`@("`@
M4V5R=FEC97-?5V5A=&AE<@H@*B!`875T:&]R("`@("`@06QE>&%N9&5R(%=I
M<G1Z(#QA;&5X0'!C-'`N;F5T/@H@*B!`8V]P>7)I9VAT("`@,C`P-2!!;&5X
M86YD97(@5VER='H*("H@0&QI8V5N<V4@("`@(&AT='`Z+R]W=W<N;W!E;G-O
M=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS
M90H@*B!`=F5R<VEO;B`@("`@0U93.B`D260Z(%=E871H97(N<&AP+'8@,2XT
M,R`R,#`U+S$Q+S$V(#$R.C0X.C,T(&5R=2!%>'`@)`H@*B!`;&EN:R`@("`@
M("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U-E<G9I8V5S7U=E871H
M97(*("H@0&9I;&5S;W5R8V4*("HO"@HO+R![>WL@8V]N<W1A;G1S"B\O('M[
M>R!C86-H92!T:6UE<PID969I;F4H(E-%4E9)0T537U=%051(15)?15A025)%
M4U]53DE44R(L("`@("`@("`Y,#`I.R`O+R`Q-4T*9&5F:6YE*")315)624-%
M4U]714%42$527T584$E215-?3$]#051)3TXB+"`@(#0S,C`P*3L@+R\@,3)(
M"F1E9FEN92@B4T525DE#15-?5T5!5$A%4E]%6%!)4D537U=%051(15(B+"`@
M("`@,3@P,"D[("\O(#,P30ID969I;F4H(E-%4E9)0T537U=%051(15)?15A0
M25)%4U]&3U)%0T%35"(L("`@(#<R,#`I.R`O+R`@,D@*9&5F:6YE*")315)6
M24-%4U]714%42$527T584$E215-?3$E.2U,B+"`@("`@(#0S,C`P*3L@+R\@
M,3)("F1E9FEN92@B4T525DE#15-?5T5!5$A%4E]%6%!)4D537U-%05)#2"(L
M("`@,C0Q.3(P,"D[("\O(#(X1`HO+R!]?7T*"B\O('M[>R!E<G)O<B!C;V1E
M<PID969I;F4H(E-%4E9)0T537U=%051(15)?15)23U)?4T525DE#15].3U1?
M1D]53D0B+"`@("`@("`@,3`I.PID969I;F4H(E-%4E9)0T537U=%051(15)?
M15)23U)?54Y+3D]73E],3T-!5$E/3B(L("`@("`@("`@,3$I.PID969I;F4H
M(E-%4E9)0T537U=%051(15)?15)23U)?5U)/3D=?4T525D527T1!5$$B+"`@
M("`@("`@,3(I.PID969I;F4H(E-%4E9)0T537U=%051(15)?15)23U)?0T%#
M2$5?24Y)5%]&04E,140B+"`@("`@("`@,3,I.PID969I;F4H(E-%4E9)0T53
M7U=%051(15)?15)23U)?1$)?3D]47T-/3DY%0U1%1"(L("`@("`@("`@,30I
M.PID969I;F4H(E-%4E9)0T537U=%051(15)?15)23U)?2%144%]04D]865])
M3E9!3$E$(BP@("`@("`@,34I.PID969I;F4H(E-%4E9)0T537U=%051(15)?
M15)23U)?4U5.1E5.0U-?1$%415])3E9!3$E$(BP@("`@,38I.PID969I;F4H
M(E-%4E9)0T537U=%051(15)?15)23U)?4U5.1E5.0U-?4D541D]235])3E9!
M3$E$(BP@,3<I.PID969I;F4H(E-%4E9)0T537U=%051(15)?15)23U)?3454
M05)?4T]54D-%7TE.5D%,240B+"`@("`@,3@I.PHO+R!]?7T*"B\O('M[>R!E
M<G)O<B!C;V1E<R!D969I;F5D(&)Y('=E871H97(N8V]M"F1E9FEN92@B4T52
M5DE#15-?5T5!5$A%4E]%4E)/4E]53DM.3U=.7T524D]2(BP@("`@("`@("`@
M("`P*3L*9&5F:6YE*")315)624-%4U]714%42$527T524D]27TY/7TQ/0T%4
M24].(BP@("`@("`@("`@("`@(#$I.PID969I;F4H(E-%4E9)0T537U=%051(
M15)?15)23U)?24Y604Q)1%],3T-!5$E/3B(L("`@("`@("`@,BD["F1E9FEN
M92@B4T525DE#15-?5T5!5$A%4E]%4E)/4E])3E9!3$E$7U!!4E1.15)?240B
M+"`@("`@,3`P*3L*9&5F:6YE*")315)624-%4U]714%42$527T524D]27TE.
M5D%,241?4%)/1%5#5%]#3T1%(BP@("`Q,#$I.PID969I;F4H(E-%4E9)0T53
M7U=%051(15)?15)23U)?24Y604Q)1%],24-%3E-%7TM%62(L("`@(#$P,BD[
M"B\O('U]?0HO+R!]?7T*"B\O('M[>R!C;&%S<R!397)V:6-E<U]796%T:&5R
M"B\J*@H@*B!4:&ES(&-L87-S(&%C=',@87,@86X@:6YT97)F86-E('1O('9A
M<FEO=7,@;VYL:6YE('=E871H97(M<V5R=FEC97,N"B`J"B`J($!C871E9V]R
M>2`@("!796(@4V5R=FEC97,*("H@0'!A8VMA9V4@("`@(%-E<G9I8V5S7U=E
M871H97(*("H@0&%U=&AO<B`@("`@($%L97AA;F1E<B!7:7)T>B`\86QE>$!P
M8S1P+FYE=#X*("H@0&-O<'ER:6=H="`@(#(P,#4@06QE>&%N9&5R(%=I<G1Z
M"B`J($!L:6-E;G-E("`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI
M8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I
M;VX@("`@(%)E;&5A<V4Z(#$N-"XP"B`J($!L:6YK("`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O4V5R=FEC97-?5V5A=&AE<@H@*B\*8VQA
M<W,@4V5R=FEC97-?5V5A=&AE<B!["@H@("`@+R\@>WM[("9S97)V:6-E*"D*
M("`@("\J*@H@("`@("H@1F%C=&]R>2!F;W(@8W)E871I;F<@=&AE('-E<G9I
M8V5S+6]B:F5C=',*("`@("`J"B`@("`@*B!5<V%B;&4@:V5Y<R!F;W(@=&AE
M(&]P=&EO;G,@87)R87D@87)E.@H@("`@("H@;R!D96)U9R`@("`@("`@("`@
M("`@96YA8FQE<R!D96)U9V=I;F<@;W5T<'5T"B`@("`@*B`M+2T@0V]M;6]N
M($]P=&EO;G,*("`@("`J(&\@8V%C:&54>7!E("`@("`@("`@(&1E9FEN97,@
M=VAA="!T>7!E(&]F(&-A8VAE('1O('5S90H@("`@("H@;R!C86-H94]P=&EO
M;G,@("`@("`@<&%S<V5S(&-A8VAE(&]P=&EO;G,*("`@("`J(&\@=6YI='-&
M;W)M870@("`@("`@('5S92`H55,I+7-T86YD87)D+"!M971R:6,@;W(@8W5S
M=&]M('5N:71S"B`@("`@*B!O(&-U<W1O;55N:71S1F]R;6%T("!D969I;F5S
M('1H92!C=7-T;VUI>F5D('5N:71S(&9O<FUA=`H@("`@("H@;R!H='1P5&EM
M96]U="`@("`@("`@<V5T<R!T:6UE;W5T(&9O<B!(5%10(')E<75E<W1S"B`@
M("`@*B!O(&AT='!0<F]X>2`@("`@("`@("!S971S('!R;WAY(&9O<B!(5%10
M(')E<75E<W1S+"!P;&5A<V4@=7-E('1H90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@;F]T871I;VX@:'1T<#HO+UMU<V5R6SIP87-S74!=:&]S=%LZ
M<&]R=%T*("`@("`J(&\@9&%T949O<FUA="`@("`@("`@('-T<FEN9R!T;R!U
M<V4@9F]R(&1A=&4@;W5T<'5T"B`@("`@*B!O('1I;65&;W)M870@("`@("`@
M("!S=')I;F<@=&\@=7-E(&9O<B!T:6UE(&]U='!U=`H@("`@("H@+2TM($5*
M4T4@3W!T:6]N<PH@("`@("H@;R!N;VYE"B`@("`@*B`M+2T@1VQO8F%L5V5A
M=&AE<B!/<'1I;VYS"B`@("`@*B!O(&YO;F4*("`@("`J("TM+2!-151!4B]4
M048@3W!T:6]N<PH@("`@("H@;R!D<VX@("`@("`@("`@("`@("`@4W1R:6YG
M(&9O<B!D969I;FEN9R!T:&4@1$(@8V]N;F5C=&EO;@H@("`@("H@;R!D8D]P
M=&EO;G,@("`@("`@("`@<&%S<V5S($1"(&]P=&EO;G,*("`@("`J(&\@<V]U
M<F-E365T87(@("`@("`@(&AT='`L(&9T<"!O<B!F:6QE("T@='EP92!O9B!D
M871A+7-O=7)C92!F;W(@345405(*("`@("`J(&\@<V]U<F-E4&%T:$UE=&%R
M("`@('=H97)E('1O(&QO;VL@9F]R('1H92!S;W5R8V4L(%5222!O<B!F:6QE
M<&%T:"P*("`@("`J("`@("`@("`@("`@("`@("`@("`@(&]F($U%5$%2(&EN
M9F]R;6%T:6]N"B`@("`@*B!O('-O=7)C951A9B`@("`@("`@("!H='1P+"!F
M='`@;W(@9FEL92`M('1Y<&4@;V8@9&%T82US;W5R8V4@9F]R(%1!1@H@("`@
M("H@;R!S;W5R8V50871H5&%F("`@("`@=VAE<F4@=&\@;&]O:R!F;W(@=&AE
M('-O=7)C92P@55))(&]R(&9I;&5P871H+`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@;V8@5$%&(&EN9F]R;6%T:6]N"B`@("`@*B`M+2T@=V5A=&AE
M<BYC;VT@3W!T:6]N<PH@("`@("H@;R!P87)T;F5R240@("`@("`@("`@66]U
M)VQL(')E8V5I=F4@=&AE<V4@:V5Y<R!A9G1E<B!R96=I<W1E<FEN9PH@("`@
M("H@;R!L:6-E;G-E2V5Y("`@("`@("`@=VET:"!T:&4@=V5A=&AE<BYC;VT@
M6$U,+7-E<G9I8V4*("`@("`J(&\@<')E1F5T8V@@("`@("`@("`@($5N86)L
M97,@<')E+69E=&-H:6YG(&]F(&1A=&$@:6X@;VYE('-I;F=L92!R97%U97-T
M"B`@("`@*@H@("`@("H@0'!A<F%M("`@('-T<FEN9R`@("`@("`@("`@("`@
M("`@("`@("1S97)V:6-E"B`@("`@*B!`<&%R86T@("`@87)R87D@("`@("`@
M("`@("`@("`@("`@("`@)&]P=&EO;G,*("`@("`J($!R971U<FX@("!014%2
M7T5R<F]R?&]B:F5C=`H@("`@("H@0'1H<F]W<R`@(%!%05)?17)R;W(*("`@
M("`J($!T:')O=W,@("!014%27T5R<F]R.CI315)624-%4U]714%42$527T52
M4D]27U-%4E9)0T5?3D]47T9/54Y$"B`@("`@*B!`86-C97-S("`@<'5B;&EC
M"B`@("`@*B\*("`@(&9U;F-T:6]N("9S97)V:6-E*"1S97)V:6-E+"`D;W!T
M:6]N<R`](&YU;&PI"B`@("!["B`@("`@("`@)'-E<G9I8V4@/2!U8V9I<G-T
M*'-T<G1O;&]W97(H)'-E<G9I8V4I*3L*("`@("`@("`D8VQA<W-N86UE(#T@
M(E-E<G9I8V5S7U=E871H97)?(BXD<V5R=FEC93L*"B`@("`@("`@+R\@0VAE
M8VL@9F]R(&1E8G5G9VEN9RUM;V1E(&%N9"!S970@<W1U9F8@86-C;W)D:6YG
M;'D*("`@("`@("!I9B`H:7-?87)R87DH)&]P=&EO;G,I("8F(&ES<V5T*"1O
M<'1I;VYS6R)D96)U9R)=*2`F)B`D;W!T:6]N<ULB9&5B=6<B72`^/2`R*2![
M"B`@("`@("`@("`@(&EF("@A9&5F:6YE9"@B4T525DE#15-?5T5!5$A%4E]$
M14)51R(I*2!["B`@("`@("`@("`@("`@("!D969I;F4H(E-%4E9)0T537U=%
M051(15)?1$5"54<B+"!T<G5E*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I;F-L=61E7V]N8V4H(E-E<G9I8V5S+U=E871H97(O(BXD<V5R=FEC92XB
M+G!H<"(I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@A9&5F
M:6YE9"@B4T525DE#15-?5T5!5$A%4E]$14)51R(I*2!["B`@("`@("`@("`@
M("`@("!D969I;F4H(E-%4E9)0T537U=%051(15)?1$5"54<B+"!F86QS92D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@0&EN8VQU9&5?;VYC92@B4V5R
M=FEC97,O5V5A=&AE<B\B+B1S97)V:6-E+B(N<&AP(BD["B`@("`@("`@?0H*
M("`@("`@("`O+R!.;R!S=6-H('-E<G9I8V4N+BX@8F%I;"!O=70*("`@("`@
M("!I9B`H(6-L87-S7V5X:7-T<R@D8VQA<W-N86UE*2D@>PH@("`@("`@("`@
M("!R971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%
M4U]714%42$527T524D]27U-%4E9)0T5?3D]47T9/54Y$+"!?7T9)3$5?7RP@
M7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@+R\@0W)E871E('-E<G9I
M8V4@86YD(')E='5R;@H@("`@("`@("1E<G)O<B`](&YU;&P["B`@("`@("`@
M0"1O8FH@/2`F;F5W("1C;&%S<VYA;64H)&]P=&EO;G,L("1E<G)O<BD["@H@
M("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1E<G)O<BDI
M('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@)&]B:CL*("`@("`@("!]"B`@("!]"B`@
M("`O+R!]?7T*"B`@("`O+R![>WL@87!I5F5R<VEO;B@I"B`@("`O*BH*("`@
M("`J($9O<B!Y;W5R(&-O;G9E;FEE;F-E+"!W:&5N($D@8V]M92!U<"!W:71H
M(&-H86YG97,@:6X@=&AE($%022XN+@H@("`@("H*("`@("`J($!R971U<FX@
M('-T<FEN9PH@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&%P:59E<G-I;VXH*0H@("`@>PH@("`@("`@(')E='5R;B`B,2XT
M(CL*("`@('T*("`@("\O('U]?0H*("`@("\O('M[>R!?97)R;W)-97-S86=E
M*"D*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;65S<V%G92!F;W(@82!C
M97)T86EN(&5R<F]R(&-O9&4*("`@("`J"B`@("`@*B!`<&%R86T@("!014%2
M7T5R<F]R?&EN="`@("`@("`@("`@("`@)'9A;'5E"B`@("`@*B!`<F5T=7)N
M("!S=')I;F<*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V5R<F]R365S<V%G92@D=F%L=64I"B`@("!["B`@("`@("`@
M<W1A=&EC("1E<G)O<DUE<W-A9V5S.PH@("`@("`@(&EF("@A:7-S970H)&5R
M<F]R365S<V%G97,I*2!["B`@("`@("`@("`@("1E<G)O<DUE<W-A9V5S(#T@
M87)R87DH"B`@("`@("`@("`@("`@("!315)624-%4U]714%42$527T524D]2
M7U-%4E9)0T5?3D]47T9/54Y$("`@("`@("`@/3X@(E)E<75E<W1E9"!S97)V
M:6-E(&-O=6QD(&YO="!B92!F;W5N9"XB+`H@("`@("`@("`@("`@("`@4T52
M5DE#15-?5T5!5$A%4E]%4E)/4E]53DM.3U=.7TQ/0T%424].("`@("`@("`@
M(#T^(")5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(L"B`@("`@("`@("`@
M("`@("!315)624-%4U]714%42$527T524D]27U=23TY'7U-%4E9%4E]$051!
M("`@("`@("`@/3X@(E-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B
M;&4N(BP*("`@("`@("`@("`@("`@(%-%4E9)0T537U=%051(15)?15)23U)?
M0T%#2$5?24Y)5%]&04E,140@("`@("`@("`]/B`B0V%C:&4@:6YI="!W87,@
M;F]T(&-O;7!L971E9"XB+`H@("`@("`@("`@("`@("`@4T525DE#15-?5T5!
M5$A%4E]%4E)/4E]$0E].3U1?0T].3D5#5$5$("`@("`@("`@(#T^(")-971A
M<D1"(&ES(&YO="!C;VYN96-T960N(BP*("`@("`@("`@("`@("`@(%-%4E9)
M0T537U=%051(15)?15)23U)?2%144%]04D]865])3E9!3$E$("`@("`@("`]
M/B`B5&AE(&=I=F5N('!R;WAY(&ES(&YO="!V86QI9"P@<&QE87-E('5S92!T
M:&4@;F]T871I;VX@:'1T<#HO+UMU<V5R6SIP87-S74!=:&]S=%LZ<&]R=%TN
M(BP*("`@("`@("`@("`@("`@(%-%4E9)0T537U=%051(15)?15)23U)?4U5.
M1E5.0U-?1$%415])3E9!3$E$("`@("`]/B`B5&AE(&1A=&4@>6]U)W9E('!R
M;W9I9&5D(&9O<B!C86QC=6QA=&EO;B!O9B!S=6YR:7-E+W-U;G-E="!I<R!N
M;W0@82!T:6UE<W1A;7`N(BP*("`@("`@("`@("`@("`@(%-%4E9)0T537U=%
M051(15)?15)23U)?4U5.1E5.0U-?4D541D]235])3E9!3$E$("`]/B`B5&AE
M(')E='5R;B!F;W)M870@>6]U)W9E('!R;W9I9&5D(&9O<B!C86QC=6QA=&EO
M;B!O9B!S=6YR:7-E+W-U;G-E="!I<R!N;W0@=F%L:60N(BP*("`@("`@("`@
M("`@("`@(%-%4E9)0T537U=%051(15)?15)23U)?345405)?4T]54D-%7TE.
M5D%,240@("`@("`]/B`B5&AE($U%5$%2+U1!1B!S;W5R8V4@>6]U)W9E('!R
M;W9I9&5D(&AA<R!A;B!I;G9A;&ED('1Y<&4@;W(@<&%T:"XB+`H@("`@("`@
M("`@("`@("`@4T525DE#15-?5T5!5$A%4E]%4E)/4E]53DM.3U=.7T524D]2
M("`@("`@("`@("`@(#T^(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D
M+B(L"B`@("`@("`@("`@("`@("!315)624-%4U]714%42$527T524D]27TY/
M7TQ/0T%424].("`@("`@("`@("`@("`@/3X@(DYO(&QO8V%T:6]N('!R;W9I
M9&5D+B(L"B`@("`@("`@("`@("`@("!315)624-%4U]714%42$527T524D]2
M7TE.5D%,241?3$]#051)3TX@("`@("`@("`@/3X@(DEN=F%L:60@;&]C871I
M;VX@<')O=FED960N(BP*("`@("`@("`@("`@("`@(%-%4E9)0T537U=%051(
M15)?15)23U)?24Y604Q)1%]005)43D527TE$("`@("`@("`]/B`B26YV86QI
M9"!P87)T;F5R(&ED+B(L"B`@("`@("`@("`@("`@("!315)624-%4U]714%4
M2$527T524D]27TE.5D%,241?4%)/1%5#5%]#3T1%("`@("`@/3X@(DEN=F%L
M:60@<')O9'5C="!C;V1E+B(L"B`@("`@("`@("`@("`@("!315)624-%4U]7
M14%42$527T524D]27TE.5D%,241?3$E#14Y315]+15D@("`@("`@/3X@(DEN
M=F%L:60@;&EC96YS92!K97DN(@H@("`@("`@("`@("`I.PH@("`@("`@('T*
M"B`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'9A;'5E
M*2D@>PH@("`@("`@("`@("`D=F%L=64@/2`D=F%L=64M/F=E=$-O9&4H*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!I<W-E="@D97)R;W)-97-S86=E
M<ULD=F%L=65=*2`_("1E<G)O<DUE<W-A9V5S6R1V86QU95T@.B`D97)R;W)-
M97-S86=E<UM315)624-%4U]714%42$527T524D]27U5.2TY/5TY?15)23U)=
M.PH@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[(&ES17)R;W(H*0H@("`@
M+RHJ"B`@("`@*B!#:&5C:W,@9F]R(&%N(&5R<F]R(&]B:F5C="P@<V%M92!A
M<R!I;B!014%2"B`@("`@*@H@("`@("H@0'!A<F%M("`@4$5!4E]%<G)O<GQM
M:7AE9"`@("`@("`@("`@("1V86QU90H@("`@("H@0')E='5R;B`@8F]O;`H@
M("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES
M17)R;W(H)'9A;'5E*0H@("`@>PH@("`@("`@(')E='5R;B`H:7-?;V)J96-T
M*"1V86QU92D@)B8@*'-T<G1O;&]W97(H9V5T7V-L87-S*"1V86QU92DI(#T]
M(")P96%R7V5R<F]R(B!\?"!I<U]S=6)C;&%S<U]O9B@D=F%L=64L(")P96%R
M7V5R<F]R(BDI*3L*("`@('T*("`@("\O('U]?0H*("`@("\O('M[>R`F<F%I
M<V5%<G)O<B@I"B`@("`O*BH*("`@("`J($-R96%T97,@97)R;W(L('-A;64@
M87,@:6X@4$5!4B!W:71H(&$@8W5S=&]M:7IE9"!F;&%V;W(*("`@("`J"B`@
M("`@*B!`<&%R86T@("!I;G0@("`@("`@("`@("`@("`@("`@("`@("`@)&-O
M9&4*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@
M("`D9FEL90H@("`@("H@0'!A<F%M("`@:6YT("`@("`@("`@("`@("`@("`@
M("`@("`@("1L:6YE"B`@("`@*B!`<F5T=7)N("!014%27T5R<F]R"B`@("`@
M*B!`86-C97-S("!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N("9R86ES
M945R<F]R*"1C;V1E(#T@4T525DE#15-?5T5!5$A%4E]%4E)/4E]53DM.3U=.
M7T524D]2+"`D9FEL92`]("(B+"`D;&EN92`](#`I"B`@("!["B`@("`@("`@
M+R\@5&AI<R!S:&]U;&0@:6UP<F]V92!T:&4@<&5R9F]R;6%N8V4@;V8@=&AE
M('-C<FEP="P@87,@4$5!4B!I<R!O;FQY(&EN8VQU9&5D+"!W:&5N"B`@("`@
M("`@+R\@<F5A;&QY(&YE961E9"X*("`@("`@("!I;F-L=61E7V]N8V4@(E!%
M05(N<&AP(CL*"B`@("`@("`@)&UE<W-A9V4@/2`B4V5R=FEC97-?5V5A=&AE
M<B(["B`@("`@("`@:68@*"1F:6QE("$]("(B("8F("1L:6YE(#X@,"D@>PH@
M("`@("`@("`@("`D;65S<V%G92`N/2`B("@B+F)A<V5N86UE*"1F:6QE*2XB
M.B(N)&QI;F4N(BDB.PH@("`@("`@('T*("`@("`@("`D;65S<V%G92`N/2`B
M.B`B+E-E<G9I8V5S7U=E871H97(Z.E]E<G)O<DUE<W-A9V4H)&-O9&4I.PH*
M("`@("`@("`D97)R;W(@/2!014%2.CIR86ES945R<F]R*"1M97-S86=E+"`D
M8V]D92P@4$5!4E]%4E)/4E]215154DXL($5?55-%4E].3U1)0T4L(")397)V
M:6-E<U]796%T:&5R7T5R<F]R(BP@;G5L;"P@9F%L<V4I.PH@("`@("`@(')E
M='5R;B`D97)R;W(["B`@("!]"B`@("`O+R!]?7T*?0HO+R!]?7T*/SX*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]!<F-H:79E
M````````````````````````````````````````````````````````````
M`````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,#`P(#$P-3$U-#,S-S(W(#`Q-S<W,P`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+T%R8VAI=F4O5&%R+G!H<```````````````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`Q-C8W-S<@,3`U,34T,S,W,C<@,#(Q,S0Q
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP#0HO*B!V:6TZ('-E="!T<STT('-W/30Z("HO#0HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\($-O
M<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PT*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@
M=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\#0HO
M+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@
M9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P-"B\O('P@879A:6QA8FQE
M('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@
M=7)L.B`@("`@("`@("`@?`T*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\S7S`N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\#0HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H
M92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P-"B\O('P@;V)T
M86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N
M9"!A(&YO=&4@=&\@("`@("`@("`@?`T*+R\@?"!L:6-E;G-E0'!H<"YN970@
M<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@
M("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O
M('P@075T:&]R.B!6:6YC96YT($)L879E="`\=FEN8V5N=$!P:'!C;VYC97!T
M+FYE=#X@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK#0HO+PT*+R\@)$ED.B!487(N<&AP+'8@,2XR.2`R
M,#`U+S`S+S$W(#(Q.C`R.C,Q('9B;&%V970@17AP("0-"@T*<F5Q=6ER95]O
M;F-E("=014%2+G!H<"<[#0H-"@T*9&5F:6YE("@G05)#2$E615]405)?0514
M7U-%4$%2051/4B<L(#DP,#`Q*3L-"@T*+RHJ#0HJ($-R96%T97,@82`H8V]M
M<')E<W-E9"D@5&%R(&%R8VAI=F4-"BH-"BH@0&%U=&AO<B`@(%9I;F-E;G0@
M0FQA=F5T(#QV:6YC96YT0'!H<&-O;F-E<'0N;F5T/@T**B!`=F5R<VEO;B`@
M)%)E=FES:6]N.B`Q+C(Y("0-"BH@0'!A8VMA9V4@($%R8VAI=F4-"BHO#0IC
M;&%S<R!!<F-H:79E7U1A<B!E>'1E;F1S(%!%05(-"GL-"B`@("`O*BH-"B`@
M("`J($!V87(@<W1R:6YG($YA;64@;V8@=&AE(%1A<@T*("`@("HO#0H@("`@
M=F%R("1?=&%R;F%M93TG)SL-"@T*("`@("\J*@T*("`@("H@0'9A<B!B;V]L
M96%N(&EF('1R=64L('1H92!487(@9FEL92!W:6QL(&)E(&=Z:7!P960-"B`@
M("`J+PT*("`@('9A<B`D7V-O;7!R97-S/69A;'-E.PT*#0H@("`@+RHJ#0H@
M("`@*B!`=F%R('-T<FEN9R!4>7!E(&]F(&-O;7!R97-S:6]N(#H@)VYO;F4G
M+"`G9WHG(&]R("=B>C(G#0H@("`@*B\-"B`@("!V87(@)%]C;VUP<F5S<U]T
M>7!E/2=N;VYE)SL-"@T*("`@("\J*@T*("`@("H@0'9A<B!S=')I;F<@17AP
M;&]D92!S97!A<F%T;W(-"B`@("`J+PT*("`@('9A<B`D7W-E<&%R871O<CTG
M("<[#0H-"B`@("`O*BH-"B`@("`J($!V87(@9FEL92!D97-C<FEP=&]R#0H@
M("`@*B\-"B`@("!V87(@)%]F:6QE/3`[#0H-"B`@("`O*BH-"B`@("`J($!V
M87(@<W1R:6YG($QO8V%L(%1A<B!N86UE(&]F(&$@<F5M;W1E(%1A<B`H:'1T
M<#HO+R!O<B!F='`Z+R\I#0H@("`@*B\-"B`@("!V87(@)%]T96UP7W1A<FYA
M;64])R<[#0H-"B`@("`O+R![>WL@8V]N<W1R=6-T;W(-"B`@("`O*BH-"B`@
M("`J($%R8VAI=F5?5&%R($-L87-S(&-O;G-T<G5C=&]R+B!4:&ES(&9L879O
M=7(@;V8@=&AE(&-O;G-T<G5C=&]R(&]N;'D-"B`@("`J(&1E8VQA<F4@82!N
M97<@07)C:&EV95]487(@;V)J96-T+"!I9&5N=&EF>6EN9R!I="!B>2!T:&4@
M;F%M92!O9B!T:&4-"B`@("`J('1A<B!F:6QE+@T*("`@("H@268@=&AE(&-O
M;7!R97-S(&%R9W5M96YT(&ES('-E="!T:&4@=&%R('=I;&P@8F4@<F5A9"!O
M<B!C<F5A=&5D(&%S(&$-"B`@("`J(&=Z:7`@;W(@8GHR(&-O;7!R97-S960@
M5$%2(&9I;&4N#0H@("`@*@T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)'!?
M=&%R;F%M92`@5&AE(&YA;64@;V8@=&AE('1A<B!A<F-H:79E('1O(&-R96%T
M90T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)'!?8V]M<')E<W,@8V%N(&)E
M(&YU;&PL("=G>B<@;W(@)V)Z,B<N(%1H:7,-"B`@("`J("`@("`@("`@("`@
M("`@("`@('!A<F%M971E<B!I;F1I8V%T97,@:68@9WII<"!O<B!B>C(@8V]M
M<')E<W-I;VX-"B`@("`J("`@("`@("`@("`@("`@("`@(&ES(')E<75I<F5D
M+B`@1F]R(&-O;7!A=&EB:6QI='D@<F5A<V]N('1H90T*("`@("H@("`@("`@
M("`@("`@("`@("`@8F]O;&5A;B!V86QU92`G=')U92<@;65A;G,@)V=Z)RX-
M"B`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@*B\-"B`@("!F=6YC=&EO;B!!
M<F-H:79E7U1A<B@D<%]T87)N86UE+"`D<%]C;VUP<F5S<R`](&YU;&PI#0H@
M("`@>PT*("`@("`@("`D=&AI<RT^4$5!4B@I.PT*("`@("`@("`D=&AI<RT^
M7V-O;7!R97-S(#T@9F%L<V4[#0H@("`@("`@("1T:&ES+3Y?8V]M<')E<W-?
M='EP92`]("=N;VYE)SL-"B`@("`@("`@:68@*"@D<%]C;VUP<F5S<R`]/3T@
M;G5L;"D@?'P@*"1P7V-O;7!R97-S(#T]("<G*2D@>PT*("`@("`@("`@("`@
M:68@*$!F:6QE7V5X:7-T<R@D<%]T87)N86UE*2D@>PT*("`@("`@("`@("`@
M("`@(&EF("@D9G`@/2!`9F]P96XH)'!?=&%R;F%M92P@(G)B(BDI('L-"B`@
M("`@("`@("`@("`@("`@("`@+R\@;&]O:R!F;W(@9WII<"!M86=I8R!C;V]K
M:64-"B`@("`@("`@("`@("`@("`@("`@)&1A=&$@/2!F<F5A9"@D9G`L(#(I
M.PT*("`@("`@("`@("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"1D871A(#T](")<,S=<,C$S(BD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C;VUP<F5S<R`]('1R=64[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-O;7!R97-S7W1Y<&4@
M/2`G9WHG.PT*("`@("`@("`@("`@("`@("`@("`O+R!.;R!S=7)E(&ET)W,@
M96YO=6=H="!F;W(@82!M86=I8R!C;V1E("XN+BX-"B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E:68@*"1D871A(#T](")"6B(I('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?8V]M<')E<W,@/2!T<G5E.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C;VUP<F5S<U]T>7!E(#T@)V)Z
M,B<[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("\O('!R
M;V)A8FQY(&$@<F5M;W1E(&9I;&4@;W(@<V]M92!F:6QE(&%C8V5S<VEB;&4-
M"B`@("`@("`@("`@("`@("`O+R!T:')O=6=H(&$@<W1R96%M(&EN=&5R9F%C
M90T*("`@("`@("`@("`@("`@(&EF("AS=6)S='(H)'!?=&%R;F%M92P@+3(I
M(#T]("=G>B<I('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C;VUP
M<F5S<R`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]M
M<')E<W-?='EP92`]("=G>B<[#0H@("`@("`@("`@("`@("`@?2!E;'-E:68@
M*"AS=6)S='(H)'!?=&%R;F%M92P@+3,I(#T]("=B>C(G*2!\?`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`H<W5B<W1R*"1P7W1A<FYA;64L("TR*2`]
M/2`G8GHG*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-O;7!R
M97-S(#T@=')U93L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C;VUP
M<F5S<U]T>7!E(#T@)V)Z,B<[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@:68@*"@D
M<%]C;VUP<F5S<R`]/3T@=')U92D@?'P@*"1P7V-O;7!R97-S(#T]("=G>B<I
M*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]C;VUP<F5S<R`]('1R=64[
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]C;VUP<F5S<U]T>7!E(#T@)V=Z
M)SL-"B`@("`@("`@("`@('T@96QS92!I9B`H)'!?8V]M<')E<W,@/3T@)V)Z
M,B<I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V-O;7!R97-S(#T@=')U
M93L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V-O;7!R97-S7W1Y<&4@/2`G
M8GHR)SL-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M9&EE*")5;G-U<'!O<G1E9"!C;VUP<F5S<VEO;B!T>7!E("<D<%]C;VUP<F5S
M<R=<;B(N#0H@("`@("`@("`@("`@("`@("`@(")3=7!P;W)T960@='EP97,@
M87)E("=G>B<@86YD("=B>C(G+EQN(BD[#0H@("`@("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M("1T:&ES+3Y?=&%R;F%M92`]("1P7W1A<FYA;64[#0H@("`@("`@(&EF("@D
M=&AI<RT^7V-O;7!R97-S*2![("\O(&%S<V5R="!Z;&EB(&]R(&)Z,B!E>'1E
M;G-I;VX@<W5P<&]R=`T*("`@("`@("`@("`@:68@*"1T:&ES+3Y?8V]M<')E
M<W-?='EP92`]/2`G9WHG*0T*("`@("`@("`@("`@("`@("1E>'1N86UE(#T@
M)WIL:6(G.PT*("`@("`@("`@("`@96QS92!I9B`H)'1H:7,M/E]C;VUP<F5S
M<U]T>7!E(#T]("=B>C(G*0T*("`@("`@("`@("`@("`@("1E>'1N86UE(#T@
M)V)Z,B<[#0H-"B`@("`@("`@("`@(&EF("@A97AT96YS:6]N7VQO861E9"@D
M97AT;F%M92DI('L-"B`@("`@("`@("`@("`@("!014%2.CIL;V%D17AT96YS
M:6]N*"1E>'1N86UE*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF
M("@A97AT96YS:6]N7VQO861E9"@D97AT;F%M92DI('L-"B`@("`@("`@("`@
M("`@("!D:64H(E1H92!E>'1E;G-I;VX@)R1E>'1N86UE)R!C;W5L9&XG="!B
M92!F;W5N9"Y<;B(N#0H@("`@("`@("`@("`@("`@("`@(")0;&5A<V4@;6%K
M92!S=7)E('EO=7(@=F5R<VEO;B!O9B!02%`@=V%S(&)U:6QT("(N#0H@("`@
M("`@("`@("`@("`@("`@(")W:71H("<D97AT;F%M92<@<W5P<&]R="Y<;B(I
M.PT*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[
M>R!D97-T<G5C=&]R#0H@("`@9G5N8W1I;VX@7T%R8VAI=F5?5&%R*"D-"B`@
M("![#0H@("`@("`@("1T:&ES+3Y?8VQO<V4H*3L-"B`@("`@("`@+R\@+2TM
M+2T@3&]O:R!F;W(@82!L;V-A;"!C;W!Y('1O(&1E;&5T90T*("`@("`@("!I
M9B`H)'1H:7,M/E]T96UP7W1A<FYA;64@(3T@)R<I#0H@("`@("`@("`@("!`
M=6YL:6YK*"1T:&ES+3Y?=&5M<%]T87)N86UE*3L-"B`@("`@("`@)'1H:7,M
M/E]014%2*"D[#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(&-R
M96%T92@I#0H@("`@+RHJ#0H@("`@*B!4:&ES(&UE=&AO9"!C<F5A=&5S('1H
M92!A<F-H:79E(&9I;&4@86YD(&%D9"!T:&4@9FEL97,@+R!D:7)E8W1O<FEE
M<PT*("`@("H@=&AA="!A<F4@;&ES=&5D(&EN("1P7V9I;&5L:7-T+@T*("`@
M("H@268@82!F:6QE('=I=&@@=&AE('-A;64@;F%M92!E>&ES="!A;F0@:7,@
M=W)I=&%B;&4L(&ET(&ES(')E<&QA8V5D#0H@("`@*B!B>2!T:&4@;F5W('1A
M<BX-"B`@("`J(%1H92!M971H;V0@<F5T=7)N(&9A;'-E(&%N9"!A(%!%05(@
M97)R;W(@=&5X="X-"B`@("`J(%1H92`D<%]F:6QE;&ES="!P87)A;65T97(@
M8V%N(&)E(&%N(&%R<F%Y(&]F('-T<FEN9RP@96%C:"!S=')I;F<-"B`@("`J
M(')E<')E<V5N=&EN9R!A(&9I;&5N86UE(&]R(&$@9&ER96-T;W)Y(&YA;64@
M=VET:"!T:&5I<B!P871H(&EF#0H@("`@*B!N965D960N($ET(&-A;B!A;'-O
M(&)E(&$@<VEN9VQE('-T<FEN9R!W:71H(&YA;65S('-E<&%R871E9"!B>2!A
M#0H@("`@*B!S:6YG;&4@8FQA;FLN#0H@("`@*B!&;W(@96%C:"!D:7)E8W1O
M<GD@861D960@:6X@=&AE(&%R8VAI=F4L('1H92!F:6QE<R!A;F0-"B`@("`J
M('-U8BUD:7)E8W1O<FEE<R!A<F4@86QS;R!A9&1E9"X-"B`@("`J(%-E92!A
M;'-O(&-R96%T94UO9&EF>2@I(&UE=&AO9"!F;W(@;6]R92!D971A:6QS+@T*
M("`@("H-"B`@("`J($!P87)A;2!A<G)A>2`@)'!?9FEL96QI<W0@06X@87)R
M87D@;V8@9FEL96YA;65S(&%N9"!D:7)E8W1O<GD@;F%M97,L(&]R(&$-"@DJ
M("`@("`@("`@("`@("`@("`@("`@("`@("`@<VEN9VQE('-T<FEN9R!W:71H
M(&YA;65S('-E<&%R871E9"!B>2!A('-I;F=L90T*"2H@("`@("`@("`@("`@
M("`@("`@("`@("`@("!B;&%N:R!S<&%C92X-"B`@("`J($!R971U<FX@("`@
M("`@("`@("`@("`@("`@=')U92!O;B!S=6-C97-S+"!F86QS92!O;B!E<G)O
M<BX-"B`@("`J($!S964@8W)E871E36]D:69Y*"D-"B`@("`J($!A8V-E<W,@
M<'5B;&EC#0H@("`@*B\-"B`@("!F=6YC=&EO;B!C<F5A=&4H)'!?9FEL96QI
M<W0I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/F-R96%T94UO9&EF
M>2@D<%]F:6QE;&ES="P@)R<L("<G*3L-"B`@("!]#0H@("`@+R\@?7U]#0H-
M"B`@("`O+R![>WL@861D*"D-"B`@("`O*BH-"B`@("`J(%1H:7,@;65T:&]D
M(&%D9"!T:&4@9FEL97,@+R!D:7)E8W1O<FEE<R!T:&%T(&%R92!L:7-T960@
M:6X@)'!?9FEL96QI<W0@:6X-"B`@("`J('1H92!A<F-H:79E+B!)9B!T:&4@
M87)C:&EV92!D;V5S(&YO="!E>&ES="!I="!I<R!C<F5A=&5D+@T*("`@("H@
M5&AE(&UE=&AO9"!R971U<FX@9F%L<V4@86YD(&$@4$5!4B!E<G)O<B!T97AT
M+@T*("`@("H@5&AE(&9I;&5S(&%N9"!D:7)E8W1O<FEE<R!L:7-T960@87)E
M(&]N;'D@861D960@870@=&AE(&5N9"!O9B!T:&4@87)C:&EV92P-"B`@("`J
M(&5V96X@:68@82!F:6QE('=I=&@@=&AE('-A;64@;F%M92!I<R!A;')E861Y
M(&%R8VAI=F5D+@T*("`@("H@4V5E(&%L<V\@8W)E871E36]D:69Y*"D@;65T
M:&]D(&9O<B!M;W)E(&1E=&%I;',N#0H@("`@*@T*("`@("H@0'!A<F%M(&%R
M<F%Y("`D<%]F:6QE;&ES="!!;B!A<G)A>2!O9B!F:6QE;F%M97,@86YD(&1I
M<F5C=&]R>2!N86UE<RP@;W(@80T*"2H@("`@("`@("`@("`@("`@("`@("`@
M("`@("!S:6YG;&4@<W1R:6YG('=I=&@@;F%M97,@<V5P87)A=&5D(&)Y(&$@
M<VEN9VQE#0H)*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&)L86YK('-P
M86-E+@T*("`@("H@0')E='5R;B`@("`@("`@("`@("`@("`@("!T<G5E(&]N
M('-U8V-E<W,L(&9A;'-E(&]N(&5R<F]R+@T*("`@("H@0'-E92!C<F5A=&5-
M;V1I9GDH*0T*("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`J+PT*("`@(&9U
M;F-T:6]N(&%D9"@D<%]F:6QE;&ES="D-"B`@("![#0H@("`@("`@(')E='5R
M;B`D=&AI<RT^861D36]D:69Y*"1P7V9I;&5L:7-T+"`G)RP@)R<I.PT*("`@
M('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!E>'1R86-T*"D-"B`@("!F
M=6YC=&EO;B!E>'1R86-T*"1P7W!A=&@])R<I#0H@("`@>PT*("`@("`@("!R
M971U<FX@)'1H:7,M/F5X=')A8W1-;V1I9GDH)'!?<&%T:"P@)R<I.PT*("`@
M('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!L:7-T0V]N=&5N="@I#0H@
M("`@9G5N8W1I;VX@;&ES=$-O;G1E;G0H*0T*("`@('L-"B`@("`@("`@)'9?
M;&ES=%]D971A:6P@/2!A<G)A>2@I.PT*#0H@("`@("`@(&EF("@D=&AI<RT^
M7V]P96Y296%D*"DI('L-"B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]E>'1R
M86-T3&ES="@G)RP@)'9?;&ES=%]D971A:6PL(")L:7-T(BP@)R<L("<G*2D@
M>PT*("`@("`@("`@("`@("`@('5N<V5T*"1V7VQI<W1?9&5T86EL*3L-"B`@
M("`@("`@("`@("`@("`D=E]L:7-T7V1E=&%I;"`](#`[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`D=&AI<RT^7V-L;W-E*"D[#0H@("`@("`@('T-
M"@T*("`@("`@("!R971U<FX@)'9?;&ES=%]D971A:6P[#0H@("`@?0T*("`@
M("\O('U]?0T*#0H@("`@+R\@>WM[(&-R96%T94UO9&EF>2@I#0H@("`@+RHJ
M#0H@("`@*B!4:&ES(&UE=&AO9"!C<F5A=&5S('1H92!A<F-H:79E(&9I;&4@
M86YD(&%D9"!T:&4@9FEL97,@+R!D:7)E8W1O<FEE<PT*("`@("H@=&AA="!A
M<F4@;&ES=&5D(&EN("1P7V9I;&5L:7-T+@T*("`@("H@268@=&AE(&9I;&4@
M86QR96%D>2!E>&ES=',@86YD(&ES('=R:71A8FQE+"!I="!I<R!R97!L86-E
M9"!B>2!T:&4-"B`@("`J(&YE=R!T87(N($ET(&ES(&$@8W)E871E(&%N9"!N
M;W0@86X@861D+B!)9B!T:&4@9FEL92!E>&ES=',@86YD(&ES#0H@("`@*B!R
M96%D+6]N;'D@;W(@:7,@82!D:7)E8W1O<GD@:70@:7,@;F]T(')E<&QA8V5D
M+B!4:&4@;65T:&]D(')E='5R;@T*("`@("H@9F%L<V4@86YD(&$@4$5!4B!E
M<G)O<B!T97AT+@T*("`@("H@5&AE("1P7V9I;&5L:7-T('!A<F%M971E<B!C
M86X@8F4@86X@87)R87D@;V8@<W1R:6YG+"!E86-H('-T<FEN9PT*("`@("H@
M<F5P<F5S96YT:6YG(&$@9FEL96YA;64@;W(@82!D:7)E8W1O<GD@;F%M92!W
M:71H('1H96ER('!A=&@@:68-"B`@("`J(&YE961E9"X@270@8V%N(&%L<V\@
M8F4@82!S:6YG;&4@<W1R:6YG('=I=&@@;F%M97,@<V5P87)A=&5D(&)Y(&$-
M"B`@("`J('-I;F=L92!B;&%N:RX-"B`@("`J(%1H92!P871H(&EN9&EC871E
M9"!I;B`D<%]R96UO=F5?9&ER('=I;&P@8F4@<F5M;W9E9"!F<F]M('1H90T*
M("`@("H@;65M;W)I>F5D('!A=&@@;V8@96%C:"!F:6QE("\@9&ER96-T;W)Y
M(&QI<W1E9"!W:&5N('1H:7,@<&%T:`T*("`@("H@97AI<W1S+B!">2!D969A
M=6QT(&YO=&AI;F<@:7,@<F5M;W9E9"`H96UP='D@<&%T:"`G)RD-"B`@("`J
M(%1H92!P871H(&EN9&EC871E9"!I;B`D<%]A9&1?9&ER('=I;&P@8F4@861D
M960@870@=&AE(&)E9VEN;FEN9R!O9@T*("`@("H@=&AE(&UE;6]R:7IE9"!P
M871H(&]F(&5A8V@@9FEL92`O(&1I<F5C=&]R>2!L:7-T960N($AO=V5V97(@
M:70@8V%N#0H@("`@*B!B92!S970@=&\@96UP='D@)R<N(%1H92!A9&1I;F<@
M;V8@82!P871H(&ES(&1O;F4@869T97(@=&AE(')E;6]V:6YG#0H@("`@*B!O
M9B!P871H+@T*("`@("H@5&AE('!A=&@@861D+W)E;6]V92!A8FEL:71Y(&5N
M86)L97,@=&AE('5S97(@=&\@<')E<&%R92!A;B!A<F-H:79E#0H@("`@*B!F
M;W(@97AT<F%C=&EO;B!I;B!A(&1I9F9E<F5N="!P871H('1H86X@=&AE(&]R
M:6=I;B!F:6QE<R!A<F4N#0H@("`@*B!3964@86QS;R!A9&1-;V1I9GDH*2!M
M971H;V0@9F]R(&9I;&4@861D:6YG('!R;W!E<G1I97,N#0H@("`@*@T*("`@
M("H@0'!A<F%M(&%R<F%Y("`D<%]F:6QE;&ES="`@("`@06X@87)R87D@;V8@
M9FEL96YA;65S(&%N9"!D:7)E8W1O<GD@;F%M97,L#0H)*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!O<B!A('-I;F=L92!S=')I;F<@=VET:"!N
M86UE<R!S97!A<F%T960@8GD-"@DJ("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&$@<VEN9VQE(&)L86YK('-P86-E+@T*("`@("H@0'!A<F%M('-T
M<FEN9R`D<%]A9&1?9&ER("`@("`@02!S=')I;F<@=VAI8V@@8V]N=&%I;G,@
M82!P871H('1O(&)E(&%D9&5D#0H)*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!T;R!T:&4@;65M;W)I>F5D('!A=&@@;V8@96%C:"!E;&5M96YT
M(&EN#0H)*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@;&ES
M="X-"B`@("`J($!P87)A;2!S=')I;F<@)'!?<F5M;W9E7V1I<B`@($$@<W1R
M:6YG('=H:6-H(&-O;G1A:6YS(&$@<&%T:"!T;R!B90T*"2H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@<F5M;W9E9"!F<F]M('1H92!M96UO<FEZ
M960@<&%T:"!O9B!E86-H#0H)*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!E;&5M96YT(&EN('1H92!L:7-T+"!W:&5N(')E;&5V86YT+@T*("`@
M("H@0')E='5R;B!B;V]L96%N("`@("`@("`@("`@("`@=')U92!O;B!S=6-C
M97-S+"!F86QS92!O;B!E<G)O<BX-"B`@("`J($!A8V-E<W,@<'5B;&EC#0H@
M("`@*B!`<V5E(&%D9$UO9&EF>2@I#0H@("`@*B\-"B`@("!F=6YC=&EO;B!C
M<F5A=&5-;V1I9GDH)'!?9FEL96QI<W0L("1P7V%D9%]D:7(L("1P7W)E;6]V
M95]D:7(])R<I#0H@("`@>PT*("`@("`@("`D=E]R97-U;'0@/2!T<G5E.PT*
M#0H@("`@("`@(&EF("@A)'1H:7,M/E]O<&5N5W)I=&4H*2D-"B`@("`@("`@
M("`@(')E='5R;B!F86QS93L-"@T*("`@("`@("!I9B`H)'!?9FEL96QI<W0@
M(3T@)R<I('L-"B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D<%]F:6QE;&ES
M="DI#0H@("`@("`@("`@("`@("`@)'9?;&ES="`]("1P7V9I;&5L:7-T.PT*
M("`@("`@("`@("`@96QS96EF("AI<U]S=')I;F<H)'!?9FEL96QI<W0I*0T*
M("`@("`@("`@("`@("`@("1V7VQI<W0@/2!E>'!L;V1E*"1T:&ES+3Y?<V5P
M87)A=&]R+"`D<%]F:6QE;&ES="D[#0H@("`@("`@("`@("!E;'-E('L-"B`@
M("`@("`@("`@("`@("`D=&AI<RT^7V-L96%N1FEL92@I.PT*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?97)R;W(H)TEN=F%L:60@9FEL92!L:7-T)RD[#0H@
M("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*
M#0H@("`@("`@("`@("`D=E]R97-U;'0@/2`D=&AI<RT^7V%D9$QI<W0H)'9?
M;&ES="P@)'!?861D7V1I<BP@)'!?<F5M;W9E7V1I<BD[#0H@("`@("`@('T-
M"@T*("`@("`@("!I9B`H)'9?<F5S=6QT*2![#0H@("`@("`@("`@("`D=&AI
M<RT^7W=R:71E1F]O=&5R*"D[#0H@("`@("`@("`@("`D=&AI<RT^7V-L;W-E
M*"D[#0H@("`@("`@('T@96QS90T*("`@("`@("`@("`@)'1H:7,M/E]C;&5A
M;D9I;&4H*3L-"@T*("`@("`@("!R971U<FX@)'9?<F5S=6QT.PT*("`@('T-
M"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!A9&1-;V1I9GDH*0T*("`@("\J
M*@T*("`@("H@5&AI<R!M971H;V0@861D('1H92!F:6QE<R`O(&1I<F5C=&]R
M:65S(&QI<W1E9"!I;B`D<%]F:6QE;&ES="!A="!T:&4-"B`@("`J(&5N9"!O
M9B!T:&4@97AI<W1I;F<@87)C:&EV92X@268@=&AE(&%R8VAI=F4@9&]E<R!N
M;W0@>65T(&5X:7-T<R!I=`T*("`@("H@:7,@8W)E871E9"X-"B`@("`J(%1H
M92`D<%]F:6QE;&ES="!P87)A;65T97(@8V%N(&)E(&%N(&%R<F%Y(&]F('-T
M<FEN9RP@96%C:"!S=')I;F<-"B`@("`J(')E<')E<V5N=&EN9R!A(&9I;&5N
M86UE(&]R(&$@9&ER96-T;W)Y(&YA;64@=VET:"!T:&5I<B!P871H(&EF#0H@
M("`@*B!N965D960N($ET(&-A;B!A;'-O(&)E(&$@<VEN9VQE('-T<FEN9R!W
M:71H(&YA;65S('-E<&%R871E9"!B>2!A#0H@("`@*B!S:6YG;&4@8FQA;FLN
M#0H@("`@*B!4:&4@<&%T:"!I;F1I8V%T960@:6X@)'!?<F5M;W9E7V1I<B!W
M:6QL(&)E(')E;6]V960@9G)O;2!T:&4-"B`@("`J(&UE;6]R:7IE9"!P871H
M(&]F(&5A8V@@9FEL92`O(&1I<F5C=&]R>2!L:7-T960@=VAE;B!T:&ES('!A
M=&@-"B`@("`J(&5X:7-T<RX@0GD@9&5F875L="!N;W1H:6YG(&ES(')E;6]V
M960@*&5M<'1Y('!A=&@@)R<I#0H@("`@*B!4:&4@<&%T:"!I;F1I8V%T960@
M:6X@)'!?861D7V1I<B!W:6QL(&)E(&%D9&5D(&%T('1H92!B96=I;FYI;F<@
M;V8-"B`@("`J('1H92!M96UO<FEZ960@<&%T:"!O9B!E86-H(&9I;&4@+R!D
M:7)E8W1O<GD@;&ES=&5D+B!(;W=E=F5R(&ET(&-A;@T*("`@("H@8F4@<V5T
M('1O(&5M<'1Y("<G+B!4:&4@861D:6YG(&]F(&$@<&%T:"!I<R!D;VYE(&%F
M=&5R('1H92!R96UO=FEN9PT*("`@("H@;V8@<&%T:"X-"B`@("`J(%1H92!P
M871H(&%D9"]R96UO=F4@86)I;&ET>2!E;F%B;&5S('1H92!U<V5R('1O('!R
M97!A<F4@86X@87)C:&EV90T*("`@("H@9F]R(&5X=')A8W1I;VX@:6X@82!D
M:69F97)E;G0@<&%T:"!T:&%N('1H92!O<FEG:6X@9FEL97,@87)E+@T*("`@
M("H@268@82!F:6QE+V1I<B!I<R!A;')E861Y(&EN('1H92!A<F-H:79E(&ET
M('=I;&P@;VYL>2!B92!A9&1E9"!A="!T:&4-"B`@("`J(&5N9"!O9B!T:&4@
M87)C:&EV92X@5&AE<F4@:7,@;F\@=7!D871E(&]F('1H92!E>&ES=&EN9R!A
M<F-H:79E9`T*("`@("H@9FEL92]D:7(N($AO=V5V97(@=VAI;&4@97AT<F%C
M=&EN9R!T:&4@87)C:&EV92P@=&AE(&QA<W0@9FEL92!W:6QL#0H@("`@*B!R
M97!L86-E('1H92!F:7)S="!O;F4N(%1H:7,@<F5S=6QT<R!I;B!A(&YO;F4@
M;W!T:6UI>F%T:6]N(&]F('1H90T*("`@("H@87)C:&EV92!S:7IE+@T*("`@
M("H@268@82!F:6QE+V1I<B!D;V5S(&YO="!E>&ES="!T:&4@9FEL92]D:7(@
M:7,@:6=N;W)E9"X@2&]W979E<B!A;@T*("`@("H@97)R;W(@=&5X="!I<R!S
M96YD('1O(%!%05(@97)R;W(N#0H@("`@*B!)9B!A(&9I;&4O9&ER(&ES(&YO
M="!R96%D86)L92!T:&4@9FEL92]D:7(@:7,@:6=N;W)E9"X@2&]W979E<B!A
M;@T*("`@("H@97)R;W(@=&5X="!I<R!S96YD('1O(%!%05(@97)R;W(N#0H@
M("`@*@T*("`@("H@0'!A<F%M(&%R<F%Y("`@("`@)'!?9FEL96QI<W0@("`@
M($%N(&%R<F%Y(&]F(&9I;&5N86UE<R!A;F0@9&ER96-T;W)Y#0H)*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;F%M97,L(&]R(&$@<VEN
M9VQE('-T<FEN9R!W:71H(&YA;65S#0H)*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@<V5P87)A=&5D(&)Y(&$@<VEN9VQE(&)L86YK('-P
M86-E+@T*("`@("H@0'!A<F%M('-T<FEN9R`@("`@)'!?861D7V1I<B`@("`@
M($$@<W1R:6YG('=H:6-H(&-O;G1A:6YS(&$@<&%T:"!T;R!B90T*"2H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%D9&5D('1O('1H92!M
M96UO<FEZ960@<&%T:"!O9B!E86-H#0H)*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@96QE;65N="!I;B!T:&4@;&ES="X-"B`@("`J($!P
M87)A;2!S=')I;F<@("`@("1P7W)E;6]V95]D:7(@("!!('-T<FEN9R!W:&EC
M:"!C;VYT86EN<R!A('!A=&@@=&\@8F4-"@DJ("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!R96UO=F5D(&9R;VT@=&AE(&UE;6]R:7IE9"!P
M871H(&]F#0H)*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M96%C:"!E;&5M96YT(&EN('1H92!L:7-T+"!W:&5N#0H@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5L979A;G0N#0H@("`@*B!`
M<F5T=7)N("`@("`@("`@("`@("`@("`@("`@("`@("`@=')U92!O;B!S=6-C
M97-S+"!F86QS92!O;B!E<G)O<BX-"B`@("`J($!A8V-E<W,@<'5B;&EC#0H@
M("`@*B\-"B`@("!F=6YC=&EO;B!A9&1-;V1I9GDH)'!?9FEL96QI<W0L("1P
M7V%D9%]D:7(L("1P7W)E;6]V95]D:7(])R<I#0H@("`@>PT*("`@("`@("`D
M=E]R97-U;'0@/2!T<G5E.PT*#0H@("`@("`@(&EF("@A)'1H:7,M/E]I<T%R
M8VAI=F4H*2D-"B`@("`@("`@("`@("1V7W)E<W5L="`]("1T:&ES+3YC<F5A
M=&5-;V1I9GDH)'!?9FEL96QI<W0L("1P7V%D9%]D:7(L#0H)"0D@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1P7W)E;6]V95]D:7(I.PT*("`@
M("`@("!E;'-E('L-"B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D<%]F:6QE
M;&ES="DI#0H@("`@("`@("`@("`@("`@)'9?;&ES="`]("1P7V9I;&5L:7-T
M.PT*("`@("`@("`@("`@96QS96EF("AI<U]S=')I;F<H)'!?9FEL96QI<W0I
M*0T*("`@("`@("`@("`@("`@("1V7VQI<W0@/2!E>'!L;V1E*"1T:&ES+3Y?
M<V5P87)A=&]R+"`D<%]F:6QE;&ES="D[#0H@("`@("`@("`@("!E;'-E('L-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7V5R<F]R*"=);G9A;&ED(&9I;&4@
M;&ES="<I.PT*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@("`@('T-"@T*("`@("`@("`@("`@)'9?<F5S=6QT(#T@)'1H:7,M/E]A
M<'!E;F0H)'9?;&ES="P@)'!?861D7V1I<BP@)'!?<F5M;W9E7V1I<BD[#0H@
M("`@("`@('T-"@T*("`@("`@("!R971U<FX@)'9?<F5S=6QT.PT*("`@('T-
M"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!A9&13=')I;F<H*0T*("`@("\J
M*@T*("`@("H@5&AI<R!M971H;V0@861D(&$@<VEN9VQE('-T<FEN9R!A<R!A
M(&9I;&4@870@=&AE#0H@("`@*B!E;F0@;V8@=&AE(&5X:7-T:6YG(&%R8VAI
M=F4N($EF('1H92!A<F-H:79E(&1O97,@;F]T('EE="!E>&ES=',@:70-"B`@
M("`J(&ES(&-R96%T960N#0H@("`@*@T*("`@("H@0'!A<F%M('-T<FEN9R`@
M("`@)'!?9FEL96YA;64@("`@($$@<W1R:6YG('=H:6-H(&-O;G1A:6YS('1H
M92!F=6QL#0H)*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M9FEL96YA;64@<&%T:"!T:&%T('=I;&P@8F4@87-S;V-I871E9`T*"2H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('=I=&@@=&AE('-T<FEN
M9RX-"B`@("`J($!P87)A;2!S=')I;F<@("`@("1P7W-T<FEN9R`@("`@("!4
M:&4@8V]N=&5N="!O9B!T:&4@9FEL92!A9&1E9"!I;@T*"2H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('1H92!A<F-H:79E+@T*("`@("H@
M0')E='5R;B`@("`@("`@("`@("`@("`@("`@("`@("`@('1R=64@;VX@<W5C
M8V5S<RP@9F%L<V4@;VX@97)R;W(N#0H@("`@*B!`86-C97-S('!U8FQI8PT*
M("`@("HO#0H@("`@9G5N8W1I;VX@861D4W1R:6YG*"1P7V9I;&5N86UE+"`D
M<%]S=')I;F<I#0H@("`@>PT*("`@("`@("`D=E]R97-U;'0@/2!T<G5E.PT*
M("`@("`@("`-"B`@("`@("`@:68@*"$D=&AI<RT^7VES07)C:&EV92@I*2![
M#0H@("`@("`@("`@("!I9B`H(21T:&ES+3Y?;W!E;E=R:71E*"DI('L-"B`@
M("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`D=&AI<RT^7V-L;W-E*"D[#0H@("`@("`@('T-"B`@("`@
M("`@#0H@("`@("`@(&EF("@A)'1H:7,M/E]O<&5N07!P96YD*"DI#0H@("`@
M("`@("`@("!R971U<FX@9F%L<V4[#0H-"B`@("`@("`@+R\@3F5E9"!T;R!C
M:&5C:R!T:&4@9V5T(&)A8VL@=&\@=&AE('1E;7!O<F%R>2!F:6QE(#\@+BXN
M+@T*("`@("`@("`D=E]R97-U;'0@/2`D=&AI<RT^7V%D9%-T<FEN9R@D<%]F
M:6QE;F%M92P@)'!?<W1R:6YG*3L-"@T*("`@("`@("`D=&AI<RT^7W=R:71E
M1F]O=&5R*"D[#0H-"B`@("`@("`@)'1H:7,M/E]C;&]S92@I.PT*#0H@("`@
M("`@(')E='5R;B`D=E]R97-U;'0[#0H@("`@?0T*("`@("\O('U]?0T*#0H@
M("`@+R\@>WM[(&5X=')A8W1-;V1I9GDH*0T*("`@("\J*@T*("`@("H@5&AI
M<R!M971H;V0@97AT<F%C="!A;&P@=&AE(&-O;G1E;G0@;V8@=&AE(&%R8VAI
M=F4@:6X@=&AE(&1I<F5C=&]R>0T*("`@("H@:6YD:6-A=&5D(&)Y("1P7W!A
M=&@N(%=H96X@<F5L979A;G0@=&AE(&UE;6]R:7IE9"!P871H(&]F('1H90T*
M("`@("H@9FEL97,O9&ER(&-A;B!B92!M;V1I9FEE9"!B>2!R96UO=FEN9R!T
M:&4@)'!?<F5M;W9E7W!A=&@@<&%T:"!A="!T:&4-"B`@("`J(&)E9VEN;FEN
M9R!O9B!T:&4@9FEL92]D:7(@<&%T:"X-"B`@("`J(%=H:6QE(&5X=')A8W1I
M;F<@82!F:6QE+"!I9B!T:&4@9&ER96-T;W)Y('!A=&@@9&]E<R!N;W0@97AI
M<W1S(&ET(&ES#0H@("`@*B!C<F5A=&5D+@T*("`@("H@5VAI;&4@97AT<F%C
M=&EN9R!A(&9I;&4L(&EF('1H92!F:6QE(&%L<F5A9'D@97AI<W1S(&ET(&ES
M(')E<&QA8V5D#0H@("`@*B!W:71H;W5T(&QO;VMI;F<@9F]R(&QA<W0@;6]D
M:69I8V%T:6]N(&1A=&4N#0H@("`@*B!7:&EL92!E>'1R86-T:6YG(&$@9FEL
M92P@:68@=&AE(&9I;&4@86QR96%D>2!E>&ES=',@86YD(&ES('=R:71E#0H@
M("`@*B!P<F]T96-T960L('1H92!E>'1R86-T:6]N(&ES(&%B;W)T960N#0H@
M("`@*B!7:&EL92!E>'1R86-T:6YG(&$@9FEL92P@:68@82!D:7)E8W1O<GD@
M=VET:"!T:&4@<V%M92!N86UE(&%L<F5A9'D-"B`@("`J(&5X:7-T<RP@=&AE
M(&5X=')A8W1I;VX@:7,@86)O<G1E9"X-"B`@("`J(%=H:6QE(&5X=')A8W1I
M;F<@82!D:7)E8W1O<GDL(&EF(&$@9FEL92!W:71H('1H92!S86UE(&YA;64@
M86QR96%D>0T*("`@("H@97AI<W1S+"!T:&4@97AT<F%C=&EO;B!I<R!A8F]R
M=&5D+@T*("`@("H@5VAI;&4@97AT<F%C=&EN9R!A(&9I;&4O9&ER96-T;W)Y
M(&EF('1H92!D97-T:6YA=&EO;B!D:7)E8W1O<GD@97AI<W0-"B`@("`J(&%N
M9"!I<R!W<FET92!P<F]T96-T960L(&]R(&1O97,@;F]T(&5X:7-T(&)U="!C
M86X@;F]T(&)E(&-R96%T960L#0H@("`@*B!T:&4@97AT<F%C=&EO;B!I<R!A
M8F]R=&5D+@T*("`@("H@268@869T97(@97AT<F%C=&EO;B!A;B!E>'1R86-T
M960@9FEL92!D;V5S(&YO="!S:&]W('1H92!C;W)R96-T#0H@("`@*B!S=&]R
M960@9FEL92!S:7IE+"!T:&4@97AT<F%C=&EO;B!I<R!A8F]R=&5D+@T*("`@
M("H@5VAE;B!T:&4@97AT<F%C=&EO;B!I<R!A8F]R=&5D+"!A(%!%05(@97)R
M;W(@=&5X="!I<R!S970@86YD(&9A;'-E#0H@("`@*B!I<R!R971U<FYE9"X@
M2&]W979E<B!T:&4@<F5S=6QT(&-A;B!B92!A('!A<G1I86P@97AT<F%C=&EO
M;B!T:&%T(&UA>0T*("`@("H@;F5E9"!T;R!B92!M86YU86QL>2!C;&5A;F5D
M+@T*("`@("H-"B`@("`J($!P87)A;2!S=')I;F<@)'!?<&%T:"`@("`@("`@
M(%1H92!P871H(&]F('1H92!D:7)E8W1O<GD@=VAE<F4@=&AE#0H)*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!F:6QE<R]D:7(@;F5E9"!T;R!B
M>2!E>'1R86-T960N#0H@("`@*B!`<&%R86T@<W1R:6YG("1P7W)E;6]V95]P
M871H("!087)T(&]F('1H92!M96UO<FEZ960@<&%T:"!T:&%T(&-A;B!B90T*
M"2H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5M;W9E9"!I9B!P
M<F5S96YT(&%T('1H92!B96=I;FYI;F<@;V8-"@DJ("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('1H92!F:6QE+V1I<B!P871H+@T*("`@("H@0')E
M='5R;B!B;V]L96%N("`@("`@("`@("`@("`@=')U92!O;B!S=6-C97-S+"!F
M86QS92!O;B!E<G)O<BX-"B`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@*B!`
M<V5E(&5X=')A8W1,:7-T*"D-"B`@("`J+PT*("`@(&9U;F-T:6]N(&5X=')A
M8W1-;V1I9GDH)'!?<&%T:"P@)'!?<F5M;W9E7W!A=&@I#0H@("`@>PT*("`@
M("`@("`D=E]R97-U;'0@/2!T<G5E.PT*("`@("`@("`D=E]L:7-T7V1E=&%I
M;"`](&%R<F%Y*"D[#0H-"B`@("`@("`@:68@*"1V7W)E<W5L="`]("1T:&ES
M+3Y?;W!E;E)E860H*2D@>PT*("`@("`@("`@("`@)'9?<F5S=6QT(#T@)'1H
M:7,M/E]E>'1R86-T3&ES="@D<%]P871H+"`D=E]L:7-T7V1E=&%I;"P-"@D)
M"2`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(F-O;7!L971E(BP@
M,"P@)'!?<F5M;W9E7W!A=&@I.PT*("`@("`@("`@("`@)'1H:7,M/E]C;&]S
M92@I.PT*("`@("`@("!]#0H-"B`@("`@("`@<F5T=7)N("1V7W)E<W5L=#L-
M"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@97AT<F%C=$EN4W1R
M:6YG*"D-"B`@("`O*BH-"B`@("`J(%1H:7,@;65T:&]D(&5X=')A8W0@9G)O
M;2!T:&4@87)C:&EV92!O;F4@9FEL92!I9&5N=&EF:65D(&)Y("1P7V9I;&5N
M86UE+@T*("`@("H@5&AE(')E='5R;B!V86QU92!I<R!A('-T<FEN9R!W:71H
M('1H92!F:6QE(&-O;G1E;G0L(&]R($Y53$P@;VX@97)R;W(N#0H@("`@*B!`
M<&%R86T@<W1R:6YG("1P7V9I;&5N86UE("`@("!4:&4@<&%T:"!O9B!T:&4@
M9FEL92!T;R!E>'1R86-T(&EN(&$@<W1R:6YG+@T*("`@("H@0')E='5R;B`@
M("`@("`@("`@("`@("`@("`@("`@82!S=')I;F<@=VET:"!T:&4@9FEL92!C
M;VYT96YT(&]R($Y53$PN#0H@("`@*B!`86-C97-S('!U8FQI8PT*("`@("HO
M#0H@("`@9G5N8W1I;VX@97AT<F%C=$EN4W1R:6YG*"1P7V9I;&5N86UE*0T*
M("`@('L-"B`@("`@("`@:68@*"1T:&ES+3Y?;W!E;E)E860H*2D@>PT*("`@
M("`@("`@("`@)'9?<F5S=6QT(#T@)'1H:7,M/E]E>'1R86-T26Y3=')I;F<H
M)'!?9FEL96YA;64I.PT*("`@("`@("`@("`@)'1H:7,M/E]C;&]S92@I.PT*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'9?<F5S=6QT(#T@3E5,
M3#L-"B`@("`@("`@?0T*#0H@("`@("`@(')E='5R;B`D=E]R97-U;'0[#0H@
M("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(&5X=')A8W1,:7-T*"D-
M"B`@("`O*BH-"B`@("`J(%1H:7,@;65T:&]D(&5X=')A8W0@9G)O;2!T:&4@
M87)C:&EV92!O;FQY('1H92!F:6QE<R!I;F1I8V%T960@:6X@=&AE#0H@("`@
M*B`D<%]F:6QE;&ES="X@5&AE<V4@9FEL97,@87)E(&5X=')A8W1E9"!I;B!T
M:&4@8W5R<F5N="!D:7)E8W1O<GD@;W(-"B`@("`J(&EN('1H92!D:7)E8W1O
M<GD@:6YD:6-A=&5D(&)Y('1H92!O<'1I;VYA;"`D<%]P871H('!A<F%M971E
M<BX-"B`@("`J($EF(&EN9&EC871E9"!T:&4@)'!?<F5M;W9E7W!A=&@@8V%N
M(&)E('5S960@:6X@=&AE('-A;64@=V%Y(&%S(&ET(&ES#0H@("`@*B!U<V5D
M(&EN(&5X=')A8W1-;V1I9GDH*2!M971H;V0N#0H@("`@*B!`<&%R86T@87)R
M87D@("1P7V9I;&5L:7-T("`@("!!;B!A<G)A>2!O9B!F:6QE;F%M97,@86YD
M(&1I<F5C=&]R>2!N86UE<RP-"@DJ("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&]R(&$@<VEN9VQE('-T<FEN9R!W:71H(&YA;65S('-E<&%R871E
M9`T*"2H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8GD@82!S:6YG
M;&4@8FQA;FL@<W!A8V4N#0H@("`@*B!`<&%R86T@<W1R:6YG("1P7W!A=&@@
M("`@("`@("!4:&4@<&%T:"!O9B!T:&4@9&ER96-T;W)Y('=H97)E('1H90T*
M"2H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9FEL97,O9&ER(&YE
M960@=&\@8GD@97AT<F%C=&5D+@T*("`@("H@0'!A<F%M('-T<FEN9R`D<%]R
M96UO=F5?<&%T:"`@4&%R="!O9B!T:&4@;65M;W)I>F5D('!A=&@@=&AA="!C
M86X@8F4-"@DJ("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E;6]V
M960@:68@<')E<V5N="!A="!T:&4@8F5G:6YN:6YG(&]F#0H)*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!T:&4@9FEL92]D:7(@<&%T:"X-"B`@
M("`J($!R971U<FX@("`@("`@("`@("`@("`@("`@("`@('1R=64@;VX@<W5C
M8V5S<RP@9F%L<V4@;VX@97)R;W(N#0H@("`@*B!`86-C97-S('!U8FQI8PT*
M("`@("H@0'-E92!E>'1R86-T36]D:69Y*"D-"B`@("`J+PT*("`@(&9U;F-T
M:6]N(&5X=')A8W1,:7-T*"1P7V9I;&5L:7-T+"`D<%]P871H/2<G+"`D<%]R
M96UO=F5?<&%T:#TG)RD-"B`@("![#0H@("`@("`@("1V7W)E<W5L="`]('1R
M=64[#0H@("`@("`@("1V7VQI<W1?9&5T86EL(#T@87)R87DH*3L-"@T*("`@
M("`@("!I9B`H:7-?87)R87DH)'!?9FEL96QI<W0I*0T*("`@("`@("`@("`@
M)'9?;&ES="`]("1P7V9I;&5L:7-T.PT*("`@("`@("!E;'-E:68@*&ES7W-T
M<FEN9R@D<%]F:6QE;&ES="DI#0H@("`@("`@("`@("`D=E]L:7-T(#T@97AP
M;&]D92@D=&AI<RT^7W-E<&%R871O<BP@)'!?9FEL96QI<W0I.PT*("`@("`@
M("!E;'-E('L-"B`@("`@("`@("`@("1T:&ES+3Y?97)R;W(H)TEN=F%L:60@
M<W1R:6YG(&QI<W0G*3L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("`@("`@?0T*#0H@("`@("`@(&EF("@D=E]R97-U;'0@/2`D=&AI<RT^7V]P
M96Y296%D*"DI('L-"B`@("`@("`@("`@("1V7W)E<W5L="`]("1T:&ES+3Y?
M97AT<F%C=$QI<W0H)'!?<&%T:"P@)'9?;&ES=%]D971A:6PL(")P87)T:6%L
M(BP-"@D)"2`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9?;&ES
M="P@)'!?<F5M;W9E7W!A=&@I.PT*("`@("`@("`@("`@)'1H:7,M/E]C;&]S
M92@I.PT*("`@("`@("!]#0H-"B`@("`@("`@<F5T=7)N("1V7W)E<W5L=#L-
M"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@<V5T071T<FEB=71E
M*"D-"B`@("`O*BH-"B`@("`J(%1H:7,@;65T:&]D('-E="!S<&5C:69I8R!A
M='1R:6)U=&5S(&]F('1H92!A<F-H:79E+B!)="!U<V5S(&$@=F%R:6%B;&4-
M"B`@("`J(&QI<W0@;V8@<&%R86UE=&5R<RP@:6X@=&AE(&9O<FUA="!A='1R
M:6)U=&4@8V]D92`K(&%T=')I8G5T92!V86QU97,@.@T*("`@("H@)&%R8V@M
M/G-E=$%T=')I8G5T92A!4D-(259%7U1!4E]!5%1?4T5005)!5$]2+"`G+"<I
M.PT*("`@("H@0'!A<F%M(&UI>&5D("1A<F=V("`@("`@("`@("`@=F%R:6%B
M;&4@;&ES="!O9B!A='1R:6)U=&5S(&%N9"!V86QU97,-"B`@("`J($!R971U
M<FX@("`@("`@("`@("`@("`@("`@("`@('1R=64@;VX@<W5C8V5S<RP@9F%L
M<V4@;VX@97)R;W(N#0H@("`@*B!`86-C97-S('!U8FQI8PT*("`@("HO#0H@
M("`@9G5N8W1I;VX@<V5T071T<FEB=71E*"D-"B`@("![#0H@("`@("`@("1V
M7W)E<W5L="`]('1R=64[#0H@("`@("`@(`T*("`@("`@("`O+R`M+2TM+2!'
M970@=&AE(&YU;6)E<B!O9B!V87)I86)L92!L:7-T(&]F(&%R9W5M96YT<PT*
M("`@("`@("!I9B`H*"1V7W-I>F4@/2!F=6YC7VYU;5]A<F=S*"DI(#T](#`I
M('L-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@("`@
M("`@(`T*("`@("`@("`O+R`M+2TM+2!'970@=&AE(&%R9W5M96YT<PT*("`@
M("`@("`D=E]A='1?;&ES="`]("9F=6YC7V=E=%]A<F=S*"D[#0H-"B`@("`@
M("`@+R\@+2TM+2T@4F5A9"!T:&4@871T<FEB=71E<PT*("`@("`@("`D:3TP
M.PT*("`@("`@("!W:&EL92`H)&D\)'9?<VEZ92D@>PT*#0H@("`@("`@("`@
M("`O+R`M+2TM+2!,;V]K(&9O<B!N97AT(&]P=&EO;@T*("`@("`@("`@("`@
M<W=I=&-H("@D=E]A='1?;&ES=%LD:5TI('L-"B`@("`@("`@("`@("`@("`O
M+R`M+2TM+2!,;V]K(&9O<B!O<'1I;VYS('1H870@<F5Q=65S="!A('-T<FEN
M9R!V86QU90T*("`@("`@("`@("`@("`@(&-A<V4@05)#2$E615]405)?0514
M7U-%4$%2051/4B`Z#0H@("`@("`@("`@("`@("`@("`@("\O("TM+2TM($-H
M96-K('1H92!N=6UB97(@;V8@<&%R86UE=&5R<PT*("`@("`@("`@("`@("`@
M("`@("!I9B`H*"1I*S$I(#X]("1V7W-I>F4I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?97)R;W(H)TEN=F%L:60@;G5M8F5R(&]F('!A
M<F%M971E<G,@9F]R("<-"@D)"0D)"2`@("`@("`@("`@("`@+B=A='1R:6)U
M=&4@05)#2$E615]405)?05147U-%4$%2051/4B<I.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H-"B`@("`@("`@("`@("`@("`@("`@+R\@+2TM+2T@1V5T('1H92!V
M86QU90T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-E<&%R871O<B`]
M("1V7V%T=%]L:7-T6R1I*S%=.PT*("`@("`@("`@("`@("`@("`@("`D:2LK
M.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*#0H@("`@("`@("`@("`@("`@
M9&5F875L="`Z#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?97)R;W(H
M)U5N:VYO=R!A='1R:6)U=&4@8V]D92`G+B1V7V%T=%]L:7-T6R1I72XG)RD[
M#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@
M("`@('T-"@T*("`@("`@("`@("`@+R\@+2TM+2T@3F5X="!A='1R:6)U=&4-
M"B`@("`@("`@("`@("1I*RL[#0H@("`@("`@('T-"@T*("`@("`@("!R971U
M<FX@)'9?<F5S=6QT.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[
M>R!?97)R;W(H*0T*("`@(&9U;F-T:6]N(%]E<G)O<B@D<%]M97-S86=E*0T*
M("`@('L-"B`@("`@("`@+R\@+2TM+2T@5&\@8F4@8V]M<&QE=&5D#0H@("`@
M("`@("1T:&ES+3YR86ES945R<F]R*"1P7VUE<W-A9V4I.PT*("`@('T-"B`@
M("`O+R!]?7T-"@T*("`@("\O('M[>R!?=V%R;FEN9R@I#0H@("`@9G5N8W1I
M;VX@7W=A<FYI;F<H)'!?;65S<V%G92D-"B`@("![#0H@("`@("`@("\O("TM
M+2TM(%1O(&)E(&-O;7!L971E9`T*("`@("`@("`D=&AI<RT^<F%I<V5%<G)O
M<B@D<%]M97-S86=E*3L-"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![
M>WL@7VES07)C:&EV92@I#0H@("`@9G5N8W1I;VX@7VES07)C:&EV92@D<%]F
M:6QE;F%M93U.54Q,*0T*("`@('L-"B`@("`@("`@:68@*"1P7V9I;&5N86UE
M(#T]($Y53$PI('L-"B`@("`@("`@("`@("1P7V9I;&5N86UE(#T@)'1H:7,M
M/E]T87)N86UE.PT*("`@("`@("!]#0H@("`@("`@(&-L96%R<W1A=&-A8VAE
M*"D[#0H@("`@("`@(')E='5R;B!`:7-?9FEL92@D<%]F:6QE;F%M92D[#0H@
M("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(%]O<&5N5W)I=&4H*0T*
M("`@(&9U;F-T:6]N(%]O<&5N5W)I=&4H*0T*("`@('L-"B`@("`@("`@:68@
M*"1T:&ES+3Y?8V]M<')E<W-?='EP92`]/2`G9WHG*0T*("`@("`@("`@("`@
M)'1H:7,M/E]F:6QE(#T@0&=Z;W!E;B@D=&AI<RT^7W1A<FYA;64L(")W8CDB
M*3L-"B`@("`@("`@96QS92!I9B`H)'1H:7,M/E]C;VUP<F5S<U]T>7!E(#T]
M("=B>C(G*0T*("`@("`@("`@("`@)'1H:7,M/E]F:6QE(#T@0&)Z;W!E;B@D
M=&AI<RT^7W1A<FYA;64L(")W8B(I.PT*("`@("`@("!E;'-E(&EF("@D=&AI
M<RT^7V-O;7!R97-S7W1Y<&4@/3T@)VYO;F4G*0T*("`@("`@("`@("`@)'1H
M:7,M/E]F:6QE(#T@0&9O<&5N*"1T:&ES+3Y?=&%R;F%M92P@(G=B(BD[#0H@
M("`@("`@(&5L<V4-"B`@("`@("`@("`@("1T:&ES+3Y?97)R;W(H)U5N:VYO
M=VX@;W(@;6ES<VEN9R!C;VUP<F5S<VEO;B!T>7!E("@G#0H)"0D@("`@("`@
M("`@("`@("XD=&AI<RT^7V-O;7!R97-S7W1Y<&4N)RDG*3L-"@T*("`@("`@
M("!I9B`H)'1H:7,M/E]F:6QE(#T](#`I('L-"B`@("`@("`@("`@("1T:&ES
M+3Y?97)R;W(H)U5N86)L92!T;R!O<&5N(&EN('=R:71E(&UO9&4@7"<G#0H)
M"0D@("`@("`@("`@("`@("XD=&AI<RT^7W1A<FYA;64N)UPG)RD[#0H@("`@
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"@T*("`@("`@("!R
M971U<FX@=')U93L-"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@
M7V]P96Y296%D*"D-"B`@("!F=6YC=&EO;B!?;W!E;E)E860H*0T*("`@('L-
M"B`@("`@("`@:68@*'-T<G1O;&]W97(H<W5B<W1R*"1T:&ES+3Y?=&%R;F%M
M92P@,"P@-RDI(#T]("=H='1P.B\O)RD@>PT*#0H@("`@("`@("`@+R\@+2TM
M+2T@3&]O:R!I9B!A(&QO8V%L(&-O<'D@;F5E9"!T;R!B92!D;VYE#0H@("`@
M("`@("`@:68@*"1T:&ES+3Y?=&5M<%]T87)N86UE(#T]("<G*2![#0H@("`@
M("`@("`@("`@("1T:&ES+3Y?=&5M<%]T87)N86UE(#T@=6YI<6ED*"=T87(G
M*2XG+G1M<"<[#0H@("`@("`@("`@("`@(&EF("@A)'9?9FEL95]F<F]M(#T@
M0&9O<&5N*"1T:&ES+3Y?=&%R;F%M92P@)W)B)RDI('L-"B`@("`@("`@("`@
M("`@("`D=&AI<RT^7V5R<F]R*"=5;F%B;&4@=&\@;W!E;B!I;B!R96%D(&UO
M9&4@7"<G#0H)"0D)("`@("`@("`@("`@("`N)'1H:7,M/E]T87)N86UE+B=<
M)R<I.PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?=&5M<%]T87)N86UE(#T@
M)R<[#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@(&EF("@A)'9?9FEL95]T;R`]($!F;W!E
M;B@D=&AI<RT^7W1E;7!?=&%R;F%M92P@)W=B)RDI('L-"B`@("`@("`@("`@
M("`@("`D=&AI<RT^7V5R<F]R*"=5;F%B;&4@=&\@;W!E;B!I;B!W<FET92!M
M;V1E(%PG)PT*"0D)"2`@("`@("`@("`@("`@+B1T:&ES+3Y?=&5M<%]T87)N
M86UE+B=<)R<I.PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?=&5M<%]T87)N
M86UE(#T@)R<[#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@('=H:6QE("@D=E]D871A(#T@
M0&9R96%D*"1V7V9I;&5?9G)O;2P@,3`R-"DI#0H@("`@("`@("`@("`@("`@
M("!`9G=R:71E*"1V7V9I;&5?=&\L("1V7V1A=&$I.PT*("`@("`@("`@("`@
M("!`9F-L;W-E*"1V7V9I;&5?9G)O;2D[#0H@("`@("`@("`@("`@($!F8VQO
M<V4H)'9?9FEL95]T;RD[#0H@("`@("`@("`@?0T*#0H@("`@("`@("`@+R\@
M+2TM+2T@1FEL92!T;R!O<&5N(&EF('1H92!L;V-A;"!C;W!Y#0H@("`@("`@
M("`@)'9?9FEL96YA;64@/2`D=&AI<RT^7W1E;7!?=&%R;F%M93L-"@T*("`@
M("`@("!](&5L<V4-"B`@("`@("`@("`O+R`M+2TM+2!&:6QE('1O(&]P96X@
M:68@=&AE(&YO<FUA;"!487(@9FEL90T*("`@("`@("`@("1V7V9I;&5N86UE
M(#T@)'1H:7,M/E]T87)N86UE.PT*#0H@("`@("`@(&EF("@D=&AI<RT^7V-O
M;7!R97-S7W1Y<&4@/3T@)V=Z)RD-"B`@("`@("`@("`@("1T:&ES+3Y?9FEL
M92`]($!G>F]P96XH)'9?9FEL96YA;64L(")R8B(I.PT*("`@("`@("!E;'-E
M(&EF("@D=&AI<RT^7V-O;7!R97-S7W1Y<&4@/3T@)V)Z,B<I#0H@("`@("`@
M("`@("`D=&AI<RT^7V9I;&4@/2!`8GIO<&5N*"1V7V9I;&5N86UE+"`B<F(B
M*3L-"B`@("`@("`@96QS92!I9B`H)'1H:7,M/E]C;VUP<F5S<U]T>7!E(#T]
M("=N;VYE)RD-"B`@("`@("`@("`@("1T:&ES+3Y?9FEL92`]($!F;W!E;B@D
M=E]F:6QE;F%M92P@(G)B(BD[#0H@("`@("`@(&5L<V4-"B`@("`@("`@("`@
M("1T:&ES+3Y?97)R;W(H)U5N:VYO=VX@;W(@;6ES<VEN9R!C;VUP<F5S<VEO
M;B!T>7!E("@G#0H)"0D@("`@("`@("`@("`@("XD=&AI<RT^7V-O;7!R97-S
M7W1Y<&4N)RDG*3L-"@T*("`@("`@("!I9B`H)'1H:7,M/E]F:6QE(#T](#`I
M('L-"B`@("`@("`@("`@("1T:&ES+3Y?97)R;W(H)U5N86)L92!T;R!O<&5N
M(&EN(')E860@;6]D92!<)R<N)'9?9FEL96YA;64N)UPG)RD[#0H@("`@("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"@T*("`@("`@("!R971U
M<FX@=')U93L-"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@7V]P
M96Y296%D5W)I=&4H*0T*("`@(&9U;F-T:6]N(%]O<&5N4F5A9%=R:71E*"D-
M"B`@("![#0H@("`@("`@(&EF("@D=&AI<RT^7V-O;7!R97-S7W1Y<&4@/3T@
M)V=Z)RD-"B`@("`@("`@("`@("1T:&ES+3Y?9FEL92`]($!G>F]P96XH)'1H
M:7,M/E]T87)N86UE+"`B<BMB(BD[#0H@("`@("`@(&5L<V4@:68@*"1T:&ES
M+3Y?8V]M<')E<W-?='EP92`]/2`G8GHR)RD-"B`@("`@("`@("`@("1T:&ES
M+3Y?9FEL92`]($!B>F]P96XH)'1H:7,M/E]T87)N86UE+"`B<BMB(BD[#0H@
M("`@("`@(&5L<V4@:68@*"1T:&ES+3Y?8V]M<')E<W-?='EP92`]/2`G;F]N
M92<I#0H@("`@("`@("`@("`D=&AI<RT^7V9I;&4@/2!`9F]P96XH)'1H:7,M
M/E]T87)N86UE+"`B<BMB(BD[#0H@("`@("`@(&5L<V4-"B`@("`@("`@("`@
M("1T:&ES+3Y?97)R;W(H)U5N:VYO=VX@;W(@;6ES<VEN9R!C;VUP<F5S<VEO
M;B!T>7!E("@G#0H)"0D@("`@("`@("`@("`@("XD=&AI<RT^7V-O;7!R97-S
M7W1Y<&4N)RDG*3L-"@T*("`@("`@("!I9B`H)'1H:7,M/E]F:6QE(#T](#`I
M('L-"B`@("`@("`@("`@("1T:&ES+3Y?97)R;W(H)U5N86)L92!T;R!O<&5N
M(&EN(')E860O=W)I=&4@;6]D92!<)R<-"@D)"2`@("`@("`@("`@("`@+B1T
M:&ES+3Y?=&%R;F%M92XG7"<G*3L-"B`@("`@("`@("`@(')E='5R;B!F86QS
M93L-"B`@("`@("`@?0T*#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-
M"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!?8VQO<V4H*0T*("`@(&9U;F-T
M:6]N(%]C;&]S92@I#0H@("`@>PT*("`@("`@("`O+VEF("AI<W-E="@D=&AI
M<RT^7V9I;&4I*2![#0H@("`@("`@(&EF("AI<U]R97-O=7)C92@D=&AI<RT^
M7V9I;&4I*2![#0H@("`@("`@("`@("!I9B`H)'1H:7,M/E]C;VUP<F5S<U]T
M>7!E(#T]("=G>B<I#0H@("`@("`@("`@("`@("`@0&=Z8VQO<V4H)'1H:7,M
M/E]F:6QE*3L-"B`@("`@("`@("`@(&5L<V4@:68@*"1T:&ES+3Y?8V]M<')E
M<W-?='EP92`]/2`G8GHR)RD-"B`@("`@("`@("`@("`@("!`8GIC;&]S92@D
M=&AI<RT^7V9I;&4I.PT*("`@("`@("`@("`@96QS92!I9B`H)'1H:7,M/E]C
M;VUP<F5S<U]T>7!E(#T]("=N;VYE)RD-"B`@("`@("`@("`@("`@("!`9F-L
M;W-E*"1T:&ES+3Y?9FEL92D[#0H@("`@("`@("`@("!E;'-E#0H@("`@("`@
M("`@("`@("`@)'1H:7,M/E]E<G)O<B@G56YK;F]W;B!O<B!M:7-S:6YG(&-O
M;7!R97-S:6]N('1Y<&4@*"<-"@D)"0D@("`@("`@("`@("`@("XD=&AI<RT^
M7V-O;7!R97-S7W1Y<&4N)RDG*3L-"@T*("`@("`@("`@("`@)'1H:7,M/E]F
M:6QE(#T@,#L-"B`@("`@("`@?0T*#0H@("`@("`@("\O("TM+2TM($QO;VL@
M:68@82!L;V-A;"!C;W!Y(&YE960@=&\@8F4@97)A<V4-"B`@("`@("`@+R\@
M3F]T92!T:&%T(&ET(&UI9VAT(&)E(&EN=&5R97-T:6YG('1O(&ME97`@=&AE
M('5R;"!F;W(@82!T:6UE(#H@5&]$;PT*("`@("`@("!I9B`H)'1H:7,M/E]T
M96UP7W1A<FYA;64@(3T@)R<I('L-"B`@("`@("`@("`@($!U;FQI;FLH)'1H
M:7,M/E]T96UP7W1A<FYA;64I.PT*("`@("`@("`@("`@)'1H:7,M/E]T96UP
M7W1A<FYA;64@/2`G)SL-"B`@("`@("`@?0T*#0H@("`@("`@(')E='5R;B!T
M<G5E.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!?8VQE86Y&
M:6QE*"D-"B`@("!F=6YC=&EO;B!?8VQE86Y&:6QE*"D-"B`@("![#0H@("`@
M("`@("1T:&ES+3Y?8VQO<V4H*3L-"@T*("`@("`@("`O+R`M+2TM+2!,;V]K
M(&9O<B!A(&QO8V%L(&-O<'D-"B`@("`@("`@:68@*"1T:&ES+3Y?=&5M<%]T
M87)N86UE("$]("<G*2![#0H@("`@("`@("`@("`O+R`M+2TM+2!296UO=F4@
M=&AE(&QO8V%L(&-O<'D@8G5T(&YO="!T:&4@<F5M;W1E('1A<FYA;64-"B`@
M("`@("`@("`@($!U;FQI;FLH)'1H:7,M/E]T96UP7W1A<FYA;64I.PT*("`@
M("`@("`@("`@)'1H:7,M/E]T96UP7W1A<FYA;64@/2`G)SL-"B`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("\O("TM+2TM(%)E;6]V92!T:&4@;&]C
M86P@=&%R;F%M92!F:6QE#0H@("`@("`@("`@("!`=6YL:6YK*"1T:&ES+3Y?
M=&%R;F%M92D[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]T87)N86UE
M(#T@)R<[#0H-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*("`@("\O
M('U]?0T*#0H@("`@+R\@>WM[(%]W<FET94)L;V-K*"D-"B`@("!F=6YC=&EO
M;B!?=W)I=&5";&]C:R@D<%]B:6YA<GE?9&%T82P@)'!?;&5N/6YU;&PI#0H@
M("`@>PT*("`@("`@:68@*&ES7W)E<V]U<F-E*"1T:&ES+3Y?9FEL92DI('L-
M"B`@("`@("`@("!I9B`H)'!?;&5N(#T]/2!N=6QL*2![#0H@("`@("`@("`@
M("`@(&EF("@D=&AI<RT^7V-O;7!R97-S7W1Y<&4@/3T@)V=Z)RD-"B`@("`@
M("`@("`@("`@("`@($!G>G!U=',H)'1H:7,M/E]F:6QE+"`D<%]B:6YA<GE?
M9&%T82D[#0H@("`@("`@("`@("`@(&5L<V4@:68@*"1T:&ES+3Y?8V]M<')E
M<W-?='EP92`]/2`G8GHR)RD-"B`@("`@("`@("`@("`@("`@($!B>G=R:71E
M*"1T:&ES+3Y?9FEL92P@)'!?8FEN87)Y7V1A=&$I.PT*("`@("`@("`@("`@
M("!E;'-E(&EF("@D=&AI<RT^7V-O;7!R97-S7W1Y<&4@/3T@)VYO;F4G*0T*
M("`@("`@("`@("`@("`@("`@0&9P=71S*"1T:&ES+3Y?9FEL92P@)'!?8FEN
M87)Y7V1A=&$I.PT*("`@("`@("`@("`@("!E;'-E#0H@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7V5R<F]R*"=5;FMN;W=N(&]R(&UI<W-I;F<@8V]M<')E
M<W-I;VX@='EP92`H)PT*"0D)"2`@("`@("`@("`@("`@("`N)'1H:7,M/E]C
M;VUP<F5S<U]T>7!E+B<I)RD[#0H@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@:68@*"1T:&ES+3Y?8V]M<')E<W-?='EP92`]/2`G9WHG*0T*
M("`@("`@("`@("`@("`@("`@0&=Z<'5T<R@D=&AI<RT^7V9I;&4L("1P7V)I
M;F%R>5]D871A+"`D<%]L96XI.PT*("`@("`@("`@("`@("!E;'-E(&EF("@D
M=&AI<RT^7V-O;7!R97-S7W1Y<&4@/3T@)V)Z,B<I#0H@("`@("`@("`@("`@
M("`@("!`8GIW<FET92@D=&AI<RT^7V9I;&4L("1P7V)I;F%R>5]D871A+"`D
M<%]L96XI.PT*("`@("`@("`@("`@("!E;'-E(&EF("@D=&AI<RT^7V-O;7!R
M97-S7W1Y<&4@/3T@)VYO;F4G*0T*("`@("`@("`@("`@("`@("`@0&9P=71S
M*"1T:&ES+3Y?9FEL92P@)'!?8FEN87)Y7V1A=&$L("1P7VQE;BD[#0H@("`@
M("`@("`@("`@(&5L<V4-"B`@("`@("`@("`@("`@("`@("1T:&ES+3Y?97)R
M;W(H)U5N:VYO=VX@;W(@;6ES<VEN9R!C;VUP<F5S<VEO;B!T>7!E("@G#0H)
M"0D)("`@("`@("`@("`@("`@("XD=&AI<RT^7V-O;7!R97-S7W1Y<&4N)RDG
M*3L-"@T*("`@("`@("`@('T-"B`@("`@('T-"B`@("`@(')E='5R;B!T<G5E
M.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!?<F5A9$)L;V-K
M*"D-"B`@("!F=6YC=&EO;B!?<F5A9$)L;V-K*"D-"B`@("![#0H@("`@("`D
M=E]B;&]C:R`](&YU;&P[#0H@("`@("!I9B`H:7-?<F5S;W5R8V4H)'1H:7,M
M/E]F:6QE*2D@>PT*("`@("`@("`@(&EF("@D=&AI<RT^7V-O;7!R97-S7W1Y
M<&4@/3T@)V=Z)RD-"B`@("`@("`@("`@("`@)'9?8FQO8VL@/2!`9WIR96%D
M*"1T:&ES+3Y?9FEL92P@-3$R*3L-"B`@("`@("`@("!E;'-E(&EF("@D=&AI
M<RT^7V-O;7!R97-S7W1Y<&4@/3T@)V)Z,B<I#0H@("`@("`@("`@("`@("1V
M7V)L;V-K(#T@0&)Z<F5A9"@D=&AI<RT^7V9I;&4L(#4Q,BD[#0H@("`@("`@
M("`@96QS92!I9B`H)'1H:7,M/E]C;VUP<F5S<U]T>7!E(#T]("=N;VYE)RD-
M"B`@("`@("`@("`@("`@)'9?8FQO8VL@/2!`9G)E860H)'1H:7,M/E]F:6QE
M+"`U,3(I.PT*("`@("`@("`@(&5L<V4-"B`@("`@("`@("`@("`@)'1H:7,M
M/E]E<G)O<B@G56YK;F]W;B!O<B!M:7-S:6YG(&-O;7!R97-S:6]N('1Y<&4@
M*"<-"@D)"2`@("`@("`@("`@("`@("`N)'1H:7,M/E]C;VUP<F5S<U]T>7!E
M+B<I)RD[#0H@("`@("!]#0H@("`@("!R971U<FX@)'9?8FQO8VL[#0H@("`@
M?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(%]J=6UP0FQO8VLH*0T*("`@
M(&9U;F-T:6]N(%]J=6UP0FQO8VLH)'!?;&5N/6YU;&PI#0H@("`@>PT*("`@
M("`@:68@*&ES7W)E<V]U<F-E*"1T:&ES+3Y?9FEL92DI('L-"B`@("`@("`@
M("!I9B`H)'!?;&5N(#T]/2!N=6QL*0T*("`@("`@("`@("`@("`D<%]L96X@
M/2`Q.PT*#0H@("`@("`@("`@:68@*"1T:&ES+3Y?8V]M<')E<W-?='EP92`]
M/2`G9WHG*2![#0H@("`@("`@("`@("`@($!G>G-E96LH)'1H:7,M/E]F:6QE
M+"!`9WIT96QL*"1T:&ES+3Y?9FEL92DK*"1P7VQE;BHU,3(I*3L-"B`@("`@
M("`@("!]#0H@("`@("`@("`@96QS92!I9B`H)'1H:7,M/E]C;VUP<F5S<U]T
M>7!E(#T]("=B>C(G*2![#0H@("`@("`@("`@("`@("\O("TM+2TM(%)E<&QA
M8V4@;6ES<VEN9R!B>G1E;&PH*2!A;F0@8GIS965K*"D-"B`@("`@("`@("`@
M("`@9F]R("@D:3TP.R`D:3PD<%]L96X[("1I*RLI#0H@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W)E861";&]C:R@I.PT*("`@("`@("`@('T@96QS92!I
M9B`H)'1H:7,M/E]C;VUP<F5S<U]T>7!E(#T]("=N;VYE)RD-"B`@("`@("`@
M("`@("`@0&9S965K*"1T:&ES+3Y?9FEL92P@0&9T96QL*"1T:&ES+3Y?9FEL
M92DK*"1P7VQE;BHU,3(I*3L-"B`@("`@("`@("!E;'-E#0H@("`@("`@("`@
M("`@("1T:&ES+3Y?97)R;W(H)U5N:VYO=VX@;W(@;6ES<VEN9R!C;VUP<F5S
M<VEO;B!T>7!E("@G#0H)"0D@("`@("`@("`@("`@("`@+B1T:&ES+3Y?8V]M
M<')E<W-?='EP92XG*2<I.PT*#0H@("`@("!]#0H@("`@("!R971U<FX@=')U
M93L-"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@7W=R:71E1F]O
M=&5R*"D-"B`@("!F=6YC=&EO;B!?=W)I=&5&;V]T97(H*0T*("`@('L-"B`@
M("`@(&EF("AI<U]R97-O=7)C92@D=&AI<RT^7V9I;&4I*2![#0H@("`@("`@
M("`@+R\@+2TM+2T@5W)I=&4@=&AE(&QA<W0@,"!F:6QL960@8FQO8VL@9F]R
M(&5N9"!O9B!A<F-H:79E#0H@("`@("`@("`@)'9?8FEN87)Y7V1A=&$@/2!P
M86-K*")A-3$R(BP@)R<I.PT*("`@("`@("`@("1T:&ES+3Y?=W)I=&5";&]C
M:R@D=E]B:6YA<GE?9&%T82D[#0H@("`@("!]#0H@("`@("!R971U<FX@=')U
M93L-"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@7V%D9$QI<W0H
M*0T*("`@(&9U;F-T:6]N(%]A9&1,:7-T*"1P7VQI<W0L("1P7V%D9%]D:7(L
M("1P7W)E;6]V95]D:7(I#0H@("`@>PT*("`@("`@)'9?<F5S=6QT/71R=64[
M#0H@("`@("`D=E]H96%D97(@/2!A<G)A>2@I.PT*#0H@("`@("`O+R`M+2TM
M+2!296UO=F4@<&]T96YT:6%L('=I;F1O=W,@9&ER96-T;W)Y('-E<&%R871O
M<@T*("`@("`@)'!?861D7V1I<B`]("1T:&ES+3Y?=')A;G-L871E5VEN4&%T
M:"@D<%]A9&1?9&ER*3L-"B`@("`@("1P7W)E;6]V95]D:7(@/2`D=&AI<RT^
M7W1R86YS;&%T95=I;E!A=&@H)'!?<F5M;W9E7V1I<BP@9F%L<V4I.PT*#0H@
M("`@("!I9B`H(21T:&ES+3Y?9FEL92D@>PT*("`@("`@("`@("1T:&ES+3Y?
M97)R;W(H)TEN=F%L:60@9FEL92!D97-C<FEP=&]R)RD[#0H@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@("`@?0T*#0H@("`@("!I9B`H<VEZ96]F*"1P
M7VQI<W0I(#T](#`I#0H@("`@("`@("`@<F5T=7)N('1R=64[#0H-"B`@("`@
M(&9O<F5A8V@@*"1P7VQI<W0@87,@)'9?9FEL96YA;64I('L-"B`@("`@("`@
M("!I9B`H(21V7W)E<W5L="D@>PT*("`@("`@("`@("`@("!B<F5A:SL-"B`@
M("`@("`@("!]#0H-"B`@("`@("`@+R\@+2TM+2T@4VMI<"!T:&4@8W5R<F5N
M="!T87(@;F%M90T*("`@("`@("!I9B`H)'9?9FEL96YA;64@/3T@)'1H:7,M
M/E]T87)N86UE*0T*("`@("`@("`@("`@8V]N=&EN=64[#0H-"B`@("`@("`@
M:68@*"1V7V9I;&5N86UE(#T]("<G*0T*("`@("`@("`@("`@8V]N=&EN=64[
M#0H-"B`@("`@("`@:68@*"%F:6QE7V5X:7-T<R@D=E]F:6QE;F%M92DI('L-
M"B`@("`@("`@("`@("1T:&ES+3Y?=V%R;FEN9R@B1FEL92`G)'9?9FEL96YA
M;64G(&1O97,@;F]T(&5X:7-T(BD[#0H@("`@("`@("`@("!C;VYT:6YU93L-
M"B`@("`@("`@?0T*#0H@("`@("`@("\O("TM+2TM($%D9"!T:&4@9FEL92!O
M<B!D:7)E8W1O<GD@:&5A9&5R#0H@("`@("`@(&EF("@A)'1H:7,M/E]A9&1&
M:6QE*"1V7V9I;&5N86UE+"`D=E]H96%D97(L("1P7V%D9%]D:7(L("1P7W)E
M;6]V95]D:7(I*0T*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*#0H@("`@
M("`@(&EF("A`:7-?9&ER*"1V7V9I;&5N86UE*2D@>PT*("`@("`@("`@("`@
M:68@*"$H)'!?:&1I<B`](&]P96YD:7(H)'9?9FEL96YA;64I*2D@>PT*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?=V%R;FEN9R@B1&ER96-T;W)Y("<D=E]F
M:6QE;F%M92<@8V%N(&YO="!B92!R96%D(BD[#0H@("`@("`@("`@("`@("`@
M8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!W:&EL92`H
M9F%L<V4@(3T]("@D<%]H:71E;2`](')E861D:7(H)'!?:&1I<BDI*2![#0H@
M("`@("`@("`@("`@("`@:68@*"@D<%]H:71E;2`A/2`G+B<I("8F("@D<%]H
M:71E;2`A/2`G+BXG*2D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H)'9?
M9FEL96YA;64@(3T@(BXB*0T*("`@("`@("`@("`@("`@("`@("`@("`@)'!?
M=&5M<%]L:7-T6S!=(#T@)'9?9FEL96YA;64N)R\G+B1P7VAI=&5M.PT*("`@
M("`@("`@("`@("`@("`@("!E;'-E#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D<%]T96UP7VQI<W1;,%T@/2`D<%]H:71E;3L-"@T*("`@("`@("`@("`@
M("`@("`@("`D=E]R97-U;'0@/2`D=&AI<RT^7V%D9$QI<W0H)'!?=&5M<%]L
M:7-T+`T*"0D)"0D@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!?861D
M7V1I<BP-"@D)"0D)"0D)"0D)"21P7W)E;6]V95]D:7(I.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@('T-"@T*("`@("`@("`@("`@=6YS970H
M)'!?=&5M<%]L:7-T*3L-"B`@("`@("`@("`@('5N<V5T*"1P7VAD:7(I.PT*
M("`@("`@("`@("`@=6YS970H)'!?:&ET96TI.PT*("`@("`@("!]#0H@("`@
M("!]#0H-"B`@("`@(')E='5R;B`D=E]R97-U;'0[#0H@("`@?0T*("`@("\O
M('U]?0T*#0H@("`@+R\@>WM[(%]A9&1&:6QE*"D-"B`@("!F=6YC=&EO;B!?
M861D1FEL92@D<%]F:6QE;F%M92P@)B1P7VAE861E<BP@)'!?861D7V1I<BP@
M)'!?<F5M;W9E7V1I<BD-"B`@("![#0H@("`@("!I9B`H(21T:&ES+3Y?9FEL
M92D@>PT*("`@("`@("`@("1T:&ES+3Y?97)R;W(H)TEN=F%L:60@9FEL92!D
M97-C<FEP=&]R)RD[#0H@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@
M?0T*#0H@("`@("!I9B`H)'!?9FEL96YA;64@/3T@)R<I('L-"B`@("`@("`@
M("`D=&AI<RT^7V5R<F]R*"=);G9A;&ED(&9I;&4@;F%M92<I.PT*("`@("`@
M("`@(')E='5R;B!F86QS93L-"B`@("`@('T-"@T*("`@("`@+R\@+2TM+2T@
M0V%L8W5L871E('1H92!S=&]R960@9FEL96YA;64-"B`@("`@("1P7V9I;&5N
M86UE(#T@)'1H:7,M/E]T<F%N<VQA=&57:6Y0871H*"1P7V9I;&5N86UE+"!F
M86QS92D[.PT*("`@("`@)'9?<W1O<F5D7V9I;&5N86UE(#T@)'!?9FEL96YA
M;64[#0H@("`@("!I9B`H<W1R8VUP*"1P7V9I;&5N86UE+"`D<%]R96UO=F5?
M9&ER*2`]/2`P*2![#0H@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("!]
M#0H@("`@("!I9B`H)'!?<F5M;W9E7V1I<B`A/2`G)RD@>PT*("`@("`@("`@
M(&EF("AS=6)S='(H)'!?<F5M;W9E7V1I<BP@+3$I("$]("<O)RD-"B`@("`@
M("`@("`@("`@)'!?<F5M;W9E7V1I<B`N/2`G+R<[#0H-"B`@("`@("`@("!I
M9B`H<W5B<W1R*"1P7V9I;&5N86UE+"`P+"!S=')L96XH)'!?<F5M;W9E7V1I
M<BDI(#T]("1P7W)E;6]V95]D:7(I#0H@("`@("`@("`@("`@("1V7W-T;W)E
M9%]F:6QE;F%M92`]('-U8G-T<B@D<%]F:6QE;F%M92P@<W1R;&5N*"1P7W)E
M;6]V95]D:7(I*3L-"B`@("`@('T-"B`@("`@("1V7W-T;W)E9%]F:6QE;F%M
M92`]("1T:&ES+3Y?=')A;G-L871E5VEN4&%T:"@D=E]S=&]R961?9FEL96YA
M;64I.PT*("`@("`@:68@*"1P7V%D9%]D:7(@(3T@)R<I('L-"B`@("`@("`@
M("!I9B`H<W5B<W1R*"1P7V%D9%]D:7(L("TQ*2`]/2`G+R<I#0H@("`@("`@
M("`@("`@("1V7W-T;W)E9%]F:6QE;F%M92`]("1P7V%D9%]D:7(N)'9?<W1O
M<F5D7V9I;&5N86UE.PT*("`@("`@("`@(&5L<V4-"B`@("`@("`@("`@("`@
M)'9?<W1O<F5D7V9I;&5N86UE(#T@)'!?861D7V1I<BXG+R<N)'9?<W1O<F5D
M7V9I;&5N86UE.PT*("`@("`@?0T*#0H@("`@("`D=E]S=&]R961?9FEL96YA
M;64@/2`D=&AI<RT^7W!A=&A2961U8W1I;VXH)'9?<W1O<F5D7V9I;&5N86UE
M*3L-"@T*("`@("`@:68@*"1T:&ES+3Y?:7-!<F-H:79E*"1P7V9I;&5N86UE
M*2D@>PT*("`@("`@("`@(&EF("@H)'9?9FEL92`]($!F;W!E;B@D<%]F:6QE
M;F%M92P@(G)B(BDI(#T](#`I('L-"B`@("`@("`@("`@("`@)'1H:7,M/E]W
M87)N:6YG*")5;F%B;&4@=&\@;W!E;B!F:6QE("<B+B1P7V9I;&5N86UE#0H)
M"0D@("`@("`@("`@("`@("`@("`N(B<@:6X@8FEN87)Y(')E860@;6]D92(I
M.PT*("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("!]#0H-
M"B`@("`@("`@("!I9B`H(21T:&ES+3Y?=W)I=&5(96%D97(H)'!?9FEL96YA
M;64L("1V7W-T;W)E9%]F:6QE;F%M92DI#0H@("`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"@T*("`@("`@("`@('=H:6QE("@H)'9?8G5F9F5R(#T@9G)E
M860H)'9?9FEL92P@-3$R*2D@(3T@)R<I('L-"B`@("`@("`@("`@("`@)'9?
M8FEN87)Y7V1A=&$@/2!P86-K*")A-3$R(BP@(B1V7V)U9F9E<B(I.PT*("`@
M("`@("`@("`@("`D=&AI<RT^7W=R:71E0FQO8VLH)'9?8FEN87)Y7V1A=&$I
M.PT*("`@("`@("`@('T-"@T*("`@("`@("`@(&9C;&]S92@D=E]F:6QE*3L-
M"@T*("`@("`@?2!E;'-E('L-"B`@("`@("`@("`O+R`M+2TM+2!/;FQY(&AE
M861E<B!F;W(@9&ER#0H@("`@("`@("`@:68@*"$D=&AI<RT^7W=R:71E2&5A
M9&5R*"1P7V9I;&5N86UE+"`D=E]S=&]R961?9FEL96YA;64I*0T*("`@("`@
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("!]#0H-"B`@("`@(')E='5R
M;B!T<G5E.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!?861D
M4W1R:6YG*"D-"B`@("!F=6YC=&EO;B!?861D4W1R:6YG*"1P7V9I;&5N86UE
M+"`D<%]S=')I;F<I#0H@("`@>PT*("`@("`@:68@*"$D=&AI<RT^7V9I;&4I
M('L-"B`@("`@("`@("`D=&AI<RT^7V5R<F]R*"=);G9A;&ED(&9I;&4@9&5S
M8W)I<'1O<B<I.PT*("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@('T-
M"@T*("`@("`@:68@*"1P7V9I;&5N86UE(#T]("<G*2![#0H@("`@("`@("`@
M)'1H:7,M/E]E<G)O<B@G26YV86QI9"!F:6QE(&YA;64G*3L-"B`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("!]#0H-"B`@("`@("\O("TM+2TM($-A
M;&-U;&%T92!T:&4@<W1O<F5D(&9I;&5N86UE#0H@("`@("`D<%]F:6QE;F%M
M92`]("1T:&ES+3Y?=')A;G-L871E5VEN4&%T:"@D<%]F:6QE;F%M92P@9F%L
M<V4I.SL-"@T*("`@("`@:68@*"$D=&AI<RT^7W=R:71E2&5A9&5R0FQO8VLH
M)'!?9FEL96YA;64L('-T<FQE;B@D<%]S=')I;F<I+`T*"2`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@,"P@,"P@(B(L(#`L(#`I*0T*("`@("`@
M("`@(')E='5R;B!F86QS93L-"@T*("`@("`@)&D],#L-"B`@("`@('=H:6QE
M("@H)'9?8G5F9F5R(#T@<W5B<W1R*"1P7W-T<FEN9RP@*"@D:2LK*2HU,3(I
M+"`U,3(I*2`A/2`G)RD@>PT*("`@("`@("`@("1V7V)I;F%R>5]D871A(#T@
M<&%C:R@B834Q,B(L("1V7V)U9F9E<BD[#0H@("`@("`@("`@)'1H:7,M/E]W
M<FET94)L;V-K*"1V7V)I;F%R>5]D871A*3L-"B`@("`@('T-"@T*("`@("`@
M<F5T=7)N('1R=64[#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[
M(%]W<FET94AE861E<B@I#0H@("`@9G5N8W1I;VX@7W=R:71E2&5A9&5R*"1P
M7V9I;&5N86UE+"`D<%]S=&]R961?9FEL96YA;64I#0H@("`@>PT*("`@("`@
M("!I9B`H)'!?<W1O<F5D7V9I;&5N86UE(#T]("<G*0T*("`@("`@("`@("`@
M)'!?<W1O<F5D7V9I;&5N86UE(#T@)'!?9FEL96YA;64[#0H@("`@("`@("1V
M7W)E9'5C95]F:6QE;F%M92`]("1T:&ES+3Y?<&%T:%)E9'5C=&EO;B@D<%]S
M=&]R961?9FEL96YA;64I.PT*#0H@("`@("`@(&EF("AS=')L96XH)'9?<F5D
M=6-E7V9I;&5N86UE*2`^(#DY*2![#0H@("`@("`@("`@:68@*"$D=&AI<RT^
M7W=R:71E3&]N9TAE861E<B@D=E]R961U8V5?9FEL96YA;64I*0T*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H-"B`@("`@("`@)'9?
M:6YF;R`]('-T870H)'!?9FEL96YA;64I.PT*("`@("`@("`D=E]U:60@/2!S
M<')I;G1F*"(E-G,@(BP@1&5C3V-T*"1V7VEN9F];-%TI*3L-"B`@("`@("`@
M)'9?9VED(#T@<W!R:6YT9B@B)39S("(L($1E8T]C="@D=E]I;F9O6S5=*2D[
M#0H@("`@("`@("1V7W!E<FUS(#T@<W!R:6YT9B@B)39S("(L($1E8T]C="AF
M:6QE<&5R;7,H)'!?9FEL96YA;64I*2D[#0H-"B`@("`@("`@)'9?;71I;64@
M/2!S<')I;G1F*"(E,3%S(BP@1&5C3V-T*&9I;&5M=&EM92@D<%]F:6QE;F%M
M92DI*3L-"@T*("`@("`@("!I9B`H0&ES7V1I<B@D<%]F:6QE;F%M92DI('L-
M"B`@("`@("`@("`D=E]T>7!E9FQA9R`]("(U(CL-"B`@("`@("`@("`D=E]S
M:7IE(#T@<W!R:6YT9B@B)3$Q<R`B+"!$96-/8W0H,"DI.PT*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("1V7W1Y<&5F;&%G(#T@)R<[#0H@("`@("`@
M("`@8VQE87)S=&%T8V%C:&4H*3L-"B`@("`@("`@("`D=E]S:7IE(#T@<W!R
M:6YT9B@B)3$Q<R`B+"!$96-/8W0H9FEL97-I>F4H)'!?9FEL96YA;64I*2D[
M#0H@("`@("`@('T-"@T*("`@("`@("`D=E]L:6YK;F%M92`]("<G.PT*#0H@
M("`@("`@("1V7VUA9VEC(#T@)R<[#0H-"B`@("`@("`@)'9?=F5R<VEO;B`]
M("<G.PT*#0H@("`@("`@("1V7W5N86UE(#T@)R<[#0H-"B`@("`@("`@)'9?
M9VYA;64@/2`G)SL-"@T*("`@("`@("`D=E]D979M86IO<B`]("<G.PT*#0H@
M("`@("`@("1V7V1E=FUI;F]R(#T@)R<[#0H-"B`@("`@("`@)'9?<')E9FEX
M(#T@)R<[#0H-"B`@("`@("`@)'9?8FEN87)Y7V1A=&%?9FER<W0@/2!P86-K
M*")A,3`P83AA.&$X83$R03$R(BP-"@D)("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1V7W)E9'5C95]F:6QE;F%M92P@)'9?<&5R;7,L("1V7W5I9"P-
M"@D)"0D)"0D)"21V7V=I9"P@)'9?<VEZ92P@)'9?;71I;64I.PT*("`@("`@
M("`D=E]B:6YA<GE?9&%T85]L87-T(#T@<&%C:R@B83%A,3`P839A,F$S,F$S
M,F$X83AA,34U83$R(BP-"@D)("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'9?='EP969L86<L("1V7VQI;FMN86UE+"`D=E]M86=I8RP-"@D)"0D)"0D)
M("`@)'9?=F5R<VEO;BP@)'9?=6YA;64L("1V7V=N86UE+`T*"0D)"0D)"0D@
M("`D=E]D979M86IO<BP@)'9?9&5V;6EN;W(L("1V7W!R969I>"P@)R<I.PT*
M#0H@("`@("`@("\O("TM+2TM($-A;&-U;&%T92!T:&4@8VAE8VMS=6T-"B`@
M("`@("`@)'9?8VAE8VMS=6T@/2`P.PT*("`@("`@("`O+R`N+BXN+B!&:7)S
M="!P87)T(&]F('1H92!H96%D97(-"B`@("`@("`@9F]R("@D:3TP.R`D:3PQ
M-#@[("1I*RLI#0H@("`@("`@("`@("`D=E]C:&5C:W-U;2`K/2!O<F0H<W5B
M<W1R*"1V7V)I;F%R>5]D871A7V9I<G-T+"1I+#$I*3L-"B`@("`@("`@+R\@
M+BXN+BX@26=N;W)E('1H92!C:&5C:W-U;2!V86QU92!A;F0@<F5P;&%C92!I
M="!B>2`G("<@*'-P86-E*0T*("`@("`@("!F;W(@*"1I/3$T.#L@)&D\,34V
M.R`D:2LK*0T*("`@("`@("`@("`@)'9?8VAE8VMS=6T@*ST@;W)D*"<@)RD[
M#0H@("`@("`@("\O("XN+BXN($QA<W0@<&%R="!O9B!T:&4@:&5A9&5R#0H@
M("`@("`@(&9O<B`H)&D],34V+"`D:CTP.R`D:3PU,3([("1I*RLL("1J*RLI
M#0H@("`@("`@("`@("`D=E]C:&5C:W-U;2`K/2!O<F0H<W5B<W1R*"1V7V)I
M;F%R>5]D871A7VQA<W0L)&HL,2DI.PT*#0H@("`@("`@("\O("TM+2TM(%=R
M:71E('1H92!F:7)S="`Q-#@@8GET97,@;V8@=&AE(&AE861E<B!I;B!T:&4@
M87)C:&EV90T*("`@("`@("`D=&AI<RT^7W=R:71E0FQO8VLH)'9?8FEN87)Y
M7V1A=&%?9FER<W0L(#$T."D[#0H-"B`@("`@("`@+R\@+2TM+2T@5W)I=&4@
M=&AE(&-A;&-U;&%T960@8VAE8VMS=6T-"B`@("`@("`@)'9?8VAE8VMS=6T@
M/2!S<')I;G1F*"(E-G,@(BP@1&5C3V-T*"1V7V-H96-K<W5M*2D[#0H@("`@
M("`@("1V7V)I;F%R>5]D871A(#T@<&%C:R@B83@B+"`D=E]C:&5C:W-U;2D[
M#0H@("`@("`@("1T:&ES+3Y?=W)I=&5";&]C:R@D=E]B:6YA<GE?9&%T82P@
M."D[#0H-"B`@("`@("`@+R\@+2TM+2T@5W)I=&4@=&AE(&QA<W0@,S4V(&)Y
M=&5S(&]F('1H92!H96%D97(@:6X@=&AE(&%R8VAI=F4-"B`@("`@("`@)'1H
M:7,M/E]W<FET94)L;V-K*"1V7V)I;F%R>5]D871A7VQA<W0L(#,U-BD[#0H-
M"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*("`@("\O('U]?0T*#0H@
M("`@+R\@>WM[(%]W<FET94AE861E<D)L;V-K*"D-"B`@("!F=6YC=&EO;B!?
M=W)I=&5(96%D97)";&]C:R@D<%]F:6QE;F%M92P@)'!?<VEZ92P@)'!?;71I
M;64],"P@)'!?<&5R;7,],"P-"@D@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<%]T>7!E/2<G+"`D<%]U:60],"P@)'!?9VED/3`I#0H@("`@>PT*("`@
M("`@("`D<%]F:6QE;F%M92`]("1T:&ES+3Y?<&%T:%)E9'5C=&EO;B@D<%]F
M:6QE;F%M92D[#0H-"B`@("`@("`@:68@*'-T<FQE;B@D<%]F:6QE;F%M92D@
M/B`Y.2D@>PT*("`@("`@("`@(&EF("@A)'1H:7,M/E]W<FET94QO;F=(96%D
M97(H)'!?9FEL96YA;64I*0T*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@("`@("!]#0H-"B`@("`@("`@:68@*"1P7W1Y<&4@/3T@(C4B*2![#0H@
M("`@("`@("`@)'9?<VEZ92`]('-P<FEN=&8H(B4Q,7,@(BP@1&5C3V-T*#`I
M*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`D=E]S:7IE(#T@<W!R
M:6YT9B@B)3$Q<R`B+"!$96-/8W0H)'!?<VEZ92DI.PT*("`@("`@("!]#0H-
M"B`@("`@("`@)'9?=6ED(#T@<W!R:6YT9B@B)39S("(L($1E8T]C="@D<%]U
M:60I*3L-"B`@("`@("`@)'9?9VED(#T@<W!R:6YT9B@B)39S("(L($1E8T]C
M="@D<%]G:60I*3L-"B`@("`@("`@)'9?<&5R;7,@/2!S<')I;G1F*"(E-G,@
M(BP@1&5C3V-T*"1P7W!E<FUS*2D[#0H-"B`@("`@("`@)'9?;71I;64@/2!S
M<')I;G1F*"(E,3%S(BP@1&5C3V-T*"1P7VUT:6UE*2D[#0H-"B`@("`@("`@
M)'9?;&EN:VYA;64@/2`G)SL-"@T*("`@("`@("`D=E]M86=I8R`]("<G.PT*
M#0H@("`@("`@("1V7W9E<G-I;VX@/2`G)SL-"@T*("`@("`@("`D=E]U;F%M
M92`]("<G.PT*#0H@("`@("`@("1V7V=N86UE(#T@)R<[#0H-"B`@("`@("`@
M)'9?9&5V;6%J;W(@/2`G)SL-"@T*("`@("`@("`D=E]D979M:6YO<B`]("<G
M.PT*#0H@("`@("`@("1V7W!R969I>"`]("<G.PT*#0H@("`@("`@("1V7V)I
M;F%R>5]D871A7V9I<G-T(#T@<&%C:R@B83$P,&$X83AA.&$Q,D$Q,B(L#0H)
M"2`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<%]F:6QE;F%M92P@)'9?
M<&5R;7,L("1V7W5I9"P@)'9?9VED+`T*"0D)"0D)"0D))'9?<VEZ92P@)'9?
M;71I;64I.PT*("`@("`@("`D=E]B:6YA<GE?9&%T85]L87-T(#T@<&%C:R@B
M83%A,3`P839A,F$S,F$S,F$X83AA,34U83$R(BP-"@D)("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'!?='EP92P@)'9?;&EN:VYA;64L("1V7VUA9VEC
M+`T*"0D)"0D)"0D@("`D=E]V97)S:6]N+"`D=E]U;F%M92P@)'9?9VYA;64L
M#0H)"0D)"0D)"2`@("1V7V1E=FUA:F]R+"`D=E]D979M:6YO<BP@)'9?<')E
M9FEX+"`G)RD[#0H-"B`@("`@("`@+R\@+2TM+2T@0V%L8W5L871E('1H92!C
M:&5C:W-U;0T*("`@("`@("`D=E]C:&5C:W-U;2`](#`[#0H@("`@("`@("\O
M("XN+BXN($9I<G-T('!A<G0@;V8@=&AE(&AE861E<@T*("`@("`@("!F;W(@
M*"1I/3`[("1I/#$T.#L@)&DK*RD-"B`@("`@("`@("`@("1V7V-H96-K<W5M
M("L](&]R9"AS=6)S='(H)'9?8FEN87)Y7V1A=&%?9FER<W0L)&DL,2DI.PT*
M("`@("`@("`O+R`N+BXN+B!)9VYO<F4@=&AE(&-H96-K<W5M('9A;'5E(&%N
M9"!R97!L86-E(&ET(&)Y("<@)R`H<W!A8V4I#0H@("`@("`@(&9O<B`H)&D]
M,30X.R`D:3PQ-38[("1I*RLI#0H@("`@("`@("`@("`D=E]C:&5C:W-U;2`K
M/2!O<F0H)R`G*3L-"B`@("`@("`@+R\@+BXN+BX@3&%S="!P87)T(&]F('1H
M92!H96%D97(-"B`@("`@("`@9F]R("@D:3TQ-38L("1J/3`[("1I/#4Q,CL@
M)&DK*RP@)&HK*RD-"B`@("`@("`@("`@("1V7V-H96-K<W5M("L](&]R9"AS
M=6)S='(H)'9?8FEN87)Y7V1A=&%?;&%S="PD:BPQ*2D[#0H-"B`@("`@("`@
M+R\@+2TM+2T@5W)I=&4@=&AE(&9I<G-T(#$T."!B>71E<R!O9B!T:&4@:&5A
M9&5R(&EN('1H92!A<F-H:79E#0H@("`@("`@("1T:&ES+3Y?=W)I=&5";&]C
M:R@D=E]B:6YA<GE?9&%T85]F:7)S="P@,30X*3L-"@T*("`@("`@("`O+R`M
M+2TM+2!7<FET92!T:&4@8V%L8W5L871E9"!C:&5C:W-U;0T*("`@("`@("`D
M=E]C:&5C:W-U;2`]('-P<FEN=&8H(B4V<R`B+"!$96-/8W0H)'9?8VAE8VMS
M=6TI*3L-"B`@("`@("`@)'9?8FEN87)Y7V1A=&$@/2!P86-K*")A."(L("1V
M7V-H96-K<W5M*3L-"B`@("`@("`@)'1H:7,M/E]W<FET94)L;V-K*"1V7V)I
M;F%R>5]D871A+"`X*3L-"@T*("`@("`@("`O+R`M+2TM+2!7<FET92!T:&4@
M;&%S="`S-38@8GET97,@;V8@=&AE(&AE861E<B!I;B!T:&4@87)C:&EV90T*
M("`@("`@("`D=&AI<RT^7W=R:71E0FQO8VLH)'9?8FEN87)Y7V1A=&%?;&%S
M="P@,S4V*3L-"@T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H@("`@
M+R\@?7U]#0H-"B`@("`O+R![>WL@7W=R:71E3&]N9TAE861E<B@I#0H@("`@
M9G5N8W1I;VX@7W=R:71E3&]N9TAE861E<B@D<%]F:6QE;F%M92D-"B`@("![
M#0H@("`@("`@("1V7W-I>F4@/2!S<')I;G1F*"(E,3%S("(L($1E8T]C="AS
M=')L96XH)'!?9FEL96YA;64I*2D[#0H-"B`@("`@("`@)'9?='EP969L86<@
M/2`G3"<[#0H-"B`@("`@("`@)'9?;&EN:VYA;64@/2`G)SL-"@T*("`@("`@
M("`D=E]M86=I8R`]("<G.PT*#0H@("`@("`@("1V7W9E<G-I;VX@/2`G)SL-
M"@T*("`@("`@("`D=E]U;F%M92`]("<G.PT*#0H@("`@("`@("1V7V=N86UE
M(#T@)R<[#0H-"B`@("`@("`@)'9?9&5V;6%J;W(@/2`G)SL-"@T*("`@("`@
M("`D=E]D979M:6YO<B`]("<G.PT*#0H@("`@("`@("1V7W!R969I>"`]("<G
M.PT*#0H@("`@("`@("1V7V)I;F%R>5]D871A7V9I<G-T(#T@<&%C:R@B83$P
M,&$X83AA.&$Q,D$Q,B(L#0H)"2`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G+B\N+T!,;VYG3&EN:R<L(#`L(#`L(#`L("1V7W-I>F4L(#`I.PT*("`@
M("`@("`D=E]B:6YA<GE?9&%T85]L87-T(#T@<&%C:R@B83%A,3`P839A,F$S
M,F$S,F$X83AA,34U83$R(BP-"@D)("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'9?='EP969L86<L("1V7VQI;FMN86UE+"`D=E]M86=I8RP-"@D)"0D)
M"0D)("`@)'9?=F5R<VEO;BP@)'9?=6YA;64L("1V7V=N86UE+`T*"0D)"0D)
M"0D@("`D=E]D979M86IO<BP@)'9?9&5V;6EN;W(L("1V7W!R969I>"P@)R<I
M.PT*#0H@("`@("`@("\O("TM+2TM($-A;&-U;&%T92!T:&4@8VAE8VMS=6T-
M"B`@("`@("`@)'9?8VAE8VMS=6T@/2`P.PT*("`@("`@("`O+R`N+BXN+B!&
M:7)S="!P87)T(&]F('1H92!H96%D97(-"B`@("`@("`@9F]R("@D:3TP.R`D
M:3PQ-#@[("1I*RLI#0H@("`@("`@("`@("`D=E]C:&5C:W-U;2`K/2!O<F0H
M<W5B<W1R*"1V7V)I;F%R>5]D871A7V9I<G-T+"1I+#$I*3L-"B`@("`@("`@
M+R\@+BXN+BX@26=N;W)E('1H92!C:&5C:W-U;2!V86QU92!A;F0@<F5P;&%C
M92!I="!B>2`G("<@*'-P86-E*0T*("`@("`@("!F;W(@*"1I/3$T.#L@)&D\
M,34V.R`D:2LK*0T*("`@("`@("`@("`@)'9?8VAE8VMS=6T@*ST@;W)D*"<@
M)RD[#0H@("`@("`@("\O("XN+BXN($QA<W0@<&%R="!O9B!T:&4@:&5A9&5R
M#0H@("`@("`@(&9O<B`H)&D],34V+"`D:CTP.R`D:3PU,3([("1I*RLL("1J
M*RLI#0H@("`@("`@("`@("`D=E]C:&5C:W-U;2`K/2!O<F0H<W5B<W1R*"1V
M7V)I;F%R>5]D871A7VQA<W0L)&HL,2DI.PT*#0H@("`@("`@("\O("TM+2TM
M(%=R:71E('1H92!F:7)S="`Q-#@@8GET97,@;V8@=&AE(&AE861E<B!I;B!T
M:&4@87)C:&EV90T*("`@("`@("`D=&AI<RT^7W=R:71E0FQO8VLH)'9?8FEN
M87)Y7V1A=&%?9FER<W0L(#$T."D[#0H-"B`@("`@("`@+R\@+2TM+2T@5W)I
M=&4@=&AE(&-A;&-U;&%T960@8VAE8VMS=6T-"B`@("`@("`@)'9?8VAE8VMS
M=6T@/2!S<')I;G1F*"(E-G,@(BP@1&5C3V-T*"1V7V-H96-K<W5M*2D[#0H@
M("`@("`@("1V7V)I;F%R>5]D871A(#T@<&%C:R@B83@B+"`D=E]C:&5C:W-U
M;2D[#0H@("`@("`@("1T:&ES+3Y?=W)I=&5";&]C:R@D=E]B:6YA<GE?9&%T
M82P@."D[#0H-"B`@("`@("`@+R\@+2TM+2T@5W)I=&4@=&AE(&QA<W0@,S4V
M(&)Y=&5S(&]F('1H92!H96%D97(@:6X@=&AE(&%R8VAI=F4-"B`@("`@("`@
M)'1H:7,M/E]W<FET94)L;V-K*"1V7V)I;F%R>5]D871A7VQA<W0L(#,U-BD[
M#0H-"B`@("`@("`@+R\@+2TM+2T@5W)I=&4@=&AE(&9I;&5N86UE(&%S(&-O
M;G1E;G0@;V8@=&AE(&)L;V-K#0H@("`@("`@("1I/3`[#0H@("`@("`@('=H
M:6QE("@H)'9?8G5F9F5R(#T@<W5B<W1R*"1P7V9I;&5N86UE+"`H*"1I*RLI
M*C4Q,BDL(#4Q,BDI("$]("<G*2![#0H@("`@("`@("`@("`D=E]B:6YA<GE?
M9&%T82`]('!A8VLH(F$U,3(B+"`B)'9?8G5F9F5R(BD[#0H@("`@("`@("`@
M("`D=&AI<RT^7W=R:71E0FQO8VLH)'9?8FEN87)Y7V1A=&$I.PT*("`@("`@
M("!]#0H-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*("`@("\O('U]
M?0T*#0H@("`@+R\@>WM[(%]R96%D2&5A9&5R*"D-"B`@("!F=6YC=&EO;B!?
M<F5A9$AE861E<B@D=E]B:6YA<GE?9&%T82P@)B1V7VAE861E<BD-"B`@("![
M#0H@("`@("`@(&EF("AS=')L96XH)'9?8FEN87)Y7V1A=&$I/3TP*2![#0H@
M("`@("`@("`@("`D=E]H96%D97);)V9I;&5N86UE)UT@/2`G)SL-"B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H-"B`@("`@("`@:68@
M*'-T<FQE;B@D=E]B:6YA<GE?9&%T82D@(3T@-3$R*2![#0H@("`@("`@("`@
M("`D=E]H96%D97);)V9I;&5N86UE)UT@/2`G)SL-"B`@("`@("`@("`@("1T
M:&ES+3Y?97)R;W(H)TEN=F%L:60@8FQO8VL@<VEZ92`Z("<N<W1R;&5N*"1V
M7V)I;F%R>5]D871A*2D[#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@("`@('T-"@T*("`@("`@("`O+R`M+2TM+2!#86QC=6QA=&4@=&AE(&-H
M96-K<W5M#0H@("`@("`@("1V7V-H96-K<W5M(#T@,#L-"B`@("`@("`@+R\@
M+BXN+BX@1FER<W0@<&%R="!O9B!T:&4@:&5A9&5R#0H@("`@("`@(&9O<B`H
M)&D],#L@)&D\,30X.R`D:2LK*0T*("`@("`@("`@("`@)'9?8VAE8VMS=6TK
M/6]R9"AS=6)S='(H)'9?8FEN87)Y7V1A=&$L)&DL,2DI.PT*("`@("`@("`O
M+R`N+BXN+B!)9VYO<F4@=&AE(&-H96-K<W5M('9A;'5E(&%N9"!R97!L86-E
M(&ET(&)Y("<@)R`H<W!A8V4I#0H@("`@("`@(&9O<B`H)&D],30X.R`D:3PQ
M-38[("1I*RLI#0H@("`@("`@("`@("`D=E]C:&5C:W-U;2`K/2!O<F0H)R`G
M*3L-"B`@("`@("`@+R\@+BXN+BX@3&%S="!P87)T(&]F('1H92!H96%D97(-
M"B`@("`@("`@9F]R("@D:3TQ-38[("1I/#4Q,CL@)&DK*RD-"B`@("`@("`@
M("`@)'9?8VAE8VMS=6TK/6]R9"AS=6)S='(H)'9?8FEN87)Y7V1A=&$L)&DL
M,2DI.PT*#0H@("`@("`@("1V7V1A=&$@/2!U;G!A8VLH(F$Q,#!F:6QE;F%M
M92]A.&UO9&4O83AU:60O83AG:60O83$R<VEZ92]A,3)M=&EM92\B#0H)"2`@
M("`@("`@("`@("`@("`@+B)A.&-H96-K<W5M+V$Q='EP969L86<O83$P,&QI
M;FLO839M86=I8R]A,G9E<G-I;VXO(@T*"0D)"0D)("XB83,R=6YA;64O83,R
M9VYA;64O83AD979M86IO<B]A.&1E=FUI;F]R(BP-"@D)"0D)"2`D=E]B:6YA
M<GE?9&%T82D[#0H-"B`@("`@("`@+R\@+2TM+2T@17AT<F%C="!T:&4@8VAE
M8VMS=6T-"B`@("`@("`@)'9?:&5A9&5R6R=C:&5C:W-U;2==(#T@3V-T1&5C
M*'1R:6TH)'9?9&%T85LG8VAE8VMS=6TG72DI.PT*("`@("`@("!I9B`H)'9?
M:&5A9&5R6R=C:&5C:W-U;2==("$]("1V7V-H96-K<W5M*2![#0H@("`@("`@
M("`@("`D=E]H96%D97);)V9I;&5N86UE)UT@/2`G)SL-"@T*("`@("`@("`@
M("`@+R\@+2TM+2T@3&]O:R!F;W(@;&%S="!B;&]C:R`H96UP='D@8FQO8VLI
M#0H@("`@("`@("`@("!I9B`H*"1V7V-H96-K<W5M(#T](#(U-BD@)B8@*"1V
M7VAE861E<ELG8VAE8VMS=6TG72`]/2`P*2D-"B`@("`@("`@("`@("`@("!R
M971U<FX@=')U93L-"@T*("`@("`@("`@("`@)'1H:7,M/E]E<G)O<B@G26YV
M86QI9"!C:&5C:W-U;2!F;W(@9FEL92`B)RXD=E]D871A6R=F:6QE;F%M92==
M#0H)"0D@("`@("`@("`@("`@("XG(B`Z("<N)'9?8VAE8VMS=6TN)R!C86QC
M=6QA=&5D+"`G#0H)"0D)"0D@("XD=E]H96%D97);)V-H96-K<W5M)UTN)R!E
M>'!E8W1E9"<I.PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@
M("!]#0H-"B`@("`@("`@+R\@+2TM+2T@17AT<F%C="!T:&4@<')O<&5R=&EE
M<PT*("`@("`@("`D=E]H96%D97);)V9I;&5N86UE)UT@/2!T<FEM*"1V7V1A
M=&%;)V9I;&5N86UE)UTI.PT*("`@("`@("`D=E]H96%D97);)VUO9&4G72`]
M($]C=$1E8RAT<FEM*"1V7V1A=&%;)VUO9&4G72DI.PT*("`@("`@("`D=E]H
M96%D97);)W5I9"==(#T@3V-T1&5C*'1R:6TH)'9?9&%T85LG=6ED)UTI*3L-
M"B`@("`@("`@)'9?:&5A9&5R6R=G:60G72`]($]C=$1E8RAT<FEM*"1V7V1A
M=&%;)V=I9"==*2D[#0H@("`@("`@("1V7VAE861E<ELG<VEZ92==(#T@3V-T
M1&5C*'1R:6TH)'9?9&%T85LG<VEZ92==*2D[#0H@("`@("`@("1V7VAE861E
M<ELG;71I;64G72`]($]C=$1E8RAT<FEM*"1V7V1A=&%;)VUT:6UE)UTI*3L-
M"B`@("`@("`@:68@*"@D=E]H96%D97);)W1Y<&5F;&%G)UT@/2`D=E]D871A
M6R=T>7!E9FQA9R==*2`]/2`B-2(I('L-"B`@("`@("`@("`D=E]H96%D97);
M)W-I>F4G72`](#`[#0H@("`@("`@('T-"B`@("`@("`@+RH@+2TM+2T@06QL
M('1H97-E(&9I96QD<R!A<F4@<F5M;W9E9"!F;W)M('1H92!H96%D97(@8F5C
M875S90T*"0ET:&5Y(&1O(&YO="!C87)R>2!I;G1E<F5S=&EN9R!I;F9O#0H@
M("`@("`@("1V7VAE861E<EML:6YK72`]('1R:6TH)'9?9&%T85ML:6YK72D[
M#0H@("`@("`@("1V7VAE861E<EMM86=I8UT@/2!T<FEM*"1V7V1A=&%;;6%G
M:6-=*3L-"B`@("`@("`@)'9?:&5A9&5R6W9E<G-I;VY=(#T@=')I;2@D=E]D
M871A6W9E<G-I;VY=*3L-"B`@("`@("`@)'9?:&5A9&5R6W5N86UE72`]('1R
M:6TH)'9?9&%T85MU;F%M95TI.PT*("`@("`@("`D=E]H96%D97);9VYA;65=
M(#T@=')I;2@D=E]D871A6V=N86UE72D[#0H@("`@("`@("1V7VAE861E<EMD
M979M86IO<ET@/2!T<FEM*"1V7V1A=&%;9&5V;6%J;W)=*3L-"B`@("`@("`@
M)'9?:&5A9&5R6V1E=FUI;F]R72`]('1R:6TH)'9?9&%T85MD979M:6YO<ETI
M.PT*("`@("`@("`J+PT*#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-
M"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!?<F5A9$QO;F=(96%D97(H*0T*
M("`@(&9U;F-T:6]N(%]R96%D3&]N9TAE861E<B@F)'9?:&5A9&5R*0T*("`@
M('L-"B`@("`@("1V7V9I;&5N86UE(#T@)R<[#0H@("`@("`D;B`](&9L;V]R
M*"1V7VAE861E<ELG<VEZ92==+S4Q,BD[#0H@("`@("!F;W(@*"1I/3`[("1I
M/"1N.R`D:2LK*2![#0H@("`@("`@("1V7V-O;G1E;G0@/2`D=&AI<RT^7W)E
M861";&]C:R@I.PT*("`@("`@("`D=E]F:6QE;F%M92`N/2`D=E]C;VYT96YT
M.PT*("`@("`@?0T*("`@("`@:68@*"@D=E]H96%D97);)W-I>F4G72`E(#4Q
M,BD@(3T@,"D@>PT*("`@("`@("`D=E]C;VYT96YT(#T@)'1H:7,M/E]R96%D
M0FQO8VLH*3L-"B`@("`@("`@)'9?9FEL96YA;64@+CT@)'9?8V]N=&5N=#L-
M"B`@("`@('T-"@T*("`@("`@+R\@+2TM+2T@4F5A9"!T:&4@;F5X="!H96%D
M97(-"B`@("`@("1V7V)I;F%R>5]D871A(#T@)'1H:7,M/E]R96%D0FQO8VLH
M*3L-"@T*("`@("`@:68@*"$D=&AI<RT^7W)E861(96%D97(H)'9?8FEN87)Y
M7V1A=&$L("1V7VAE861E<BDI#0H@("`@("`@(')E='5R;B!F86QS93L-"@T*
M("`@("`@)'9?:&5A9&5R6R=F:6QE;F%M92==(#T@)'9?9FEL96YA;64[#0H-
M"B`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@
M("\O('M[>R!?97AT<F%C=$EN4W1R:6YG*"D-"B`@("`O*BH-"B`@("`J(%1H
M:7,@;65T:&]D(&5X=')A8W0@9G)O;2!T:&4@87)C:&EV92!O;F4@9FEL92!I
M9&5N=&EF:65D(&)Y("1P7V9I;&5N86UE+@T*("`@("H@5&AE(')E='5R;B!V
M86QU92!I<R!A('-T<FEN9R!W:71H('1H92!F:6QE(&-O;G1E;G0L(&]R($Y5
M3$P@;VX@97)R;W(N#0H@("`@*B!`<&%R86T@<W1R:6YG("1P7V9I;&5N86UE
M("`@("!4:&4@<&%T:"!O9B!T:&4@9FEL92!T;R!E>'1R86-T(&EN(&$@<W1R
M:6YG+@T*("`@("H@0')E='5R;B`@("`@("`@("`@("`@("`@("`@("`@82!S
M=')I;F<@=VET:"!T:&4@9FEL92!C;VYT96YT(&]R($Y53$PN#0H@("`@*B!`
M86-C97-S('!R:79A=&4-"B`@("`J+PT*("`@(&9U;F-T:6]N(%]E>'1R86-T
M26Y3=')I;F<H)'!?9FEL96YA;64I#0H@("`@>PT*("`@("`@("`D=E]R97-U
M;'1?<W1R(#T@(B([#0H-"B`@("`@("`@5VAI;&4@*'-T<FQE;B@D=E]B:6YA
M<GE?9&%T82`]("1T:&ES+3Y?<F5A9$)L;V-K*"DI("$](#`I#0H@("`@("`@
M('L-"B`@("`@("`@("!I9B`H(21T:&ES+3Y?<F5A9$AE861E<B@D=E]B:6YA
M<GE?9&%T82P@)'9?:&5A9&5R*2D-"B`@("`@("`@("`@(')E='5R;B!.54Q,
M.PT*#0H@("`@("`@("`@:68@*"1V7VAE861E<ELG9FEL96YA;64G72`]/2`G
M)RD-"B`@("`@("`@("`@(&-O;G1I;G5E.PT*#0H@("`@("`@("`@+R\@+2TM
M+2T@3&]O:R!F;W(@;&]N9R!F:6QE;F%M90T*("`@("`@("`@(&EF("@D=E]H
M96%D97);)W1Y<&5F;&%G)UT@/3T@)TPG*2![#0H@("`@("`@("`@("!I9B`H
M(21T:&ES+3Y?<F5A9$QO;F=(96%D97(H)'9?:&5A9&5R*2D-"B`@("`@("`@
M("`@("`@<F5T=7)N($Y53$P[#0H@("`@("`@("`@?0T*#0H@("`@("`@("`@
M:68@*"1V7VAE861E<ELG9FEL96YA;64G72`]/2`D<%]F:6QE;F%M92D@>PT*
M("`@("`@("`@("`@("!I9B`H)'9?:&5A9&5R6R=T>7!E9FQA9R==(#T]("(U
M(BD@>PT*("`@("`@("`@("`@("`@("`@)'1H:7,M/E]E<G)O<B@G56YA8FQE
M('1O(&5X=')A8W0@:6X@<W1R:6YG(&$@9&ER96-T;W)Y("<-"@D)"0D@("`@
M("`@("`@("`@("`@+B=E;G1R>2![)RXD=E]H96%D97);)V9I;&5N86UE)UTN
M)WTG*3L-"B`@("`@("`@("`@("`@("`@(')E='5R;B!.54Q,.PT*("`@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@)&X@/2!F;&]O
M<B@D=E]H96%D97);)W-I>F4G72\U,3(I.PT*("`@("`@("`@("`@("`@("`@
M9F]R("@D:3TP.R`D:3PD;CL@)&DK*RD@>PT*("`@("`@("`@("`@("`@("`@
M("`@("1V7W)E<W5L=%]S='(@+CT@)'1H:7,M/E]R96%D0FQO8VLH*3L-"B`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@(&EF("@H)'9?
M:&5A9&5R6R=S:7IE)UT@)2`U,3(I("$](#`I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`D=E]C;VYT96YT(#T@)'1H:7,M/E]R96%D0FQO8VLH*3L-"B`@
M("`@("`@("`@("`@("`@("`@("`D=E]R97-U;'1?<W1R("X]('-U8G-T<B@D
M=E]C;VYT96YT+"`P+`T*"0D)"0D@("`@("`@("`@("`@("`@("`@("`@("`@
M("@D=E]H96%D97);)W-I>F4G72`E(#4Q,BDI.PT*("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@<F5T=7)N("1V7W)E<W5L=%]S='([
M#0H@("`@("`@("`@("`@('T-"B`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`D=&AI<RT^7VIU;7!";&]C:RAC96EL*"@D=E]H96%D97);)W-I
M>F4G72\U,3(I*2D[#0H@("`@("`@("`@?0T*("`@("`@("!]#0H-"B`@("`@
M("`@<F5T=7)N($Y53$P[#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@
M>WM[(%]E>'1R86-T3&ES="@I#0H@("`@9G5N8W1I;VX@7V5X=')A8W1,:7-T
M*"1P7W!A=&@L("8D<%]L:7-T7V1E=&%I;"P@)'!?;6]D92P-"@D@("`@("`@
M("`@("`@("`@("`@("`@)'!?9FEL95]L:7-T+"`D<%]R96UO=F5?<&%T:"D-
M"B`@("![#0H@("`@)'9?<F5S=6QT/71R=64[#0H@("`@)'9?;F(@/2`P.PT*
M("`@("1V7V5X=')A8W1?86QL(#T@=')U93L-"B`@("`D=E]L:7-T:6YG(#T@
M9F%L<V4[#0H-"B`@("`D<%]P871H(#T@)'1H:7,M/E]T<F%N<VQA=&57:6Y0
M871H*"1P7W!A=&@L(&9A;'-E*3L-"B`@("!I9B`H)'!?<&%T:"`]/2`G)R!\
M?"`H<W5B<W1R*"1P7W!A=&@L(#`L(#$I("$]("<O)PT*"2`@("`F)B!S=6)S
M='(H)'!?<&%T:"P@,"P@,RD@(3T@(BXN+R(@)B8@(7-T<G!O<R@D<%]P871H
M+"`G.B<I*2D@>PT*("`@("`@)'!?<&%T:"`]("(N+R(N)'!?<&%T:#L-"B`@
M("!]#0H@("`@)'!?<F5M;W9E7W!A=&@@/2`D=&AI<RT^7W1R86YS;&%T95=I
M;E!A=&@H)'!?<F5M;W9E7W!A=&@I.PT*#0H@("`@+R\@+2TM+2T@3&]O:R!F
M;W(@<&%T:"!T;R!R96UO=F4@9F]R;6%T("AS:&]U;&0@96YD(&)Y("\I#0H@
M("`@:68@*"@D<%]R96UO=F5?<&%T:"`A/2`G)RD@)B8@*'-U8G-T<B@D<%]R
M96UO=F5?<&%T:"P@+3$I("$]("<O)RDI#0H@("`@("`D<%]R96UO=F5?<&%T
M:"`N/2`G+R<[#0H@("`@)'!?<F5M;W9E7W!A=&A?<VEZ92`]('-T<FQE;B@D
M<%]R96UO=F5?<&%T:"D[#0H-"B`@("!S=VET8V@@*"1P7VUO9&4I('L-"B`@
M("`@(&-A<V4@(F-O;7!L971E(B`Z#0H@("`@("`@("1V7V5X=')A8W1?86QL
M(#T@5%)513L-"B`@("`@("`@)'9?;&ES=&EN9R`]($9!3%-%.PT*("`@("`@
M8G)E86L[#0H@("`@("!C87-E(")P87)T:6%L(B`Z#0H@("`@("`@("`@)'9?
M97AT<F%C=%]A;&P@/2!&04Q313L-"B`@("`@("`@("`D=E]L:7-T:6YG(#T@
M1D%,4T4[#0H@("`@("!B<F5A:SL-"B`@("`@(&-A<V4@(FQI<W0B(#H-"B`@
M("`@("`@("`D=E]E>'1R86-T7V%L;"`]($9!3%-%.PT*("`@("`@("`@("1V
M7VQI<W1I;F<@/2!44E5%.PT*("`@("`@8G)E86L[#0H@("`@("!D969A=6QT
M(#H-"B`@("`@("`@)'1H:7,M/E]E<G)O<B@G26YV86QI9"!E>'1R86-T(&UO
M9&4@*"<N)'!?;6]D92XG*2<I.PT*("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@?0T*#0H@("`@8VQE87)S=&%T8V%C:&4H*3L-"@T*("`@('=H:6QE("AS
M=')L96XH)'9?8FEN87)Y7V1A=&$@/2`D=&AI<RT^7W)E861";&]C:R@I*2`A
M/2`P*0T*("`@('L-"B`@("`@("1V7V5X=')A8W1?9FEL92`]($9!3%-%.PT*
M("`@("`@)'9?97AT<F%C=&EO;E]S=&]P<&5D(#T@,#L-"@T*("`@("`@:68@
M*"$D=&AI<RT^7W)E861(96%D97(H)'9?8FEN87)Y7V1A=&$L("1V7VAE861E
M<BDI#0H@("`@("`@(')E='5R;B!F86QS93L-"@T*("`@("`@:68@*"1V7VAE
M861E<ELG9FEL96YA;64G72`]/2`G)RD@>PT*("`@("`@("!C;VYT:6YU93L-
M"B`@("`@('T-"@T*("`@("`@+R\@+2TM+2T@3&]O:R!F;W(@;&]N9R!F:6QE
M;F%M90T*("`@("`@:68@*"1V7VAE861E<ELG='EP969L86<G72`]/2`G3"<I
M('L-"B`@("`@("`@:68@*"$D=&AI<RT^7W)E861,;VYG2&5A9&5R*"1V7VAE
M861E<BDI#0H@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@?0T*#0H@
M("`@("!I9B`H*"$D=E]E>'1R86-T7V%L;"D@)B8@*&ES7V%R<F%Y*"1P7V9I
M;&5?;&ES="DI*2![#0H@("`@("`@("\O("TM+2TM($)Y(&1E9F%U;'0@;F\@
M=6YZ:7`@:68@=&AE(&9I;&4@:7,@;F]T(&9O=6YD#0H@("`@("`@("1V7V5X
M=')A8W1?9FEL92`](&9A;'-E.PT*#0H@("`@("`@(&9O<B`H)&D],#L@)&D\
M<VEZ96]F*"1P7V9I;&5?;&ES="D[("1I*RLI('L-"B`@("`@("`@("`O+R`M
M+2TM+2!,;V]K(&EF(&ET(&ES(&$@9&ER96-T;W)Y#0H@("`@("`@("`@:68@
M*'-U8G-T<B@D<%]F:6QE7VQI<W1;)&E=+"`M,2D@/3T@)R\G*2![#0H@("`@
M("`@("`@("`O+R`M+2TM+2!,;V]K(&EF('1H92!D:7)E8W1O<GD@:7,@:6X@
M=&AE(&9I;&5N86UE('!A=&@-"B`@("`@("`@("`@(&EF("@H<W1R;&5N*"1V
M7VAE861E<ELG9FEL96YA;64G72D@/B!S=')L96XH)'!?9FEL95]L:7-T6R1I
M72DI#0H)"0D@("`@)B8@*'-U8G-T<B@D=E]H96%D97);)V9I;&5N86UE)UTL
M(#`L('-T<FQE;B@D<%]F:6QE7VQI<W1;)&E=*2D-"@D)"0D@("`@/3T@)'!?
M9FEL95]L:7-T6R1I72DI('L-"B`@("`@("`@("`@("`@)'9?97AT<F%C=%]F
M:6QE(#T@5%)513L-"B`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@?0T*#0H@("`@("`@("`@+R\@+2TM+2T@270@:7,@
M82!F:6QE+"!S;R!C;VUP87)E('1H92!F:6QE(&YA;65S#0H@("`@("`@("`@
M96QS96EF("@D<%]F:6QE7VQI<W1;)&E=(#T]("1V7VAE861E<ELG9FEL96YA
M;64G72D@>PT*("`@("`@("`@("`@)'9?97AT<F%C=%]F:6QE(#T@5%)513L-
M"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@?2!E;'-E('L-"B`@("`@("`@)'9?97AT<F%C=%]F:6QE(#T@5%)5
M13L-"B`@("`@('T-"@T*("`@("`@+R\@+2TM+2T@3&]O:R!I9B!T:&ES(&9I
M;&4@;F5E9"!T;R!B92!E>'1R86-T960-"B`@("`@(&EF("@H)'9?97AT<F%C
M=%]F:6QE*2`F)B`H(21V7VQI<W1I;F<I*0T*("`@("`@>PT*("`@("`@("!I
M9B`H*"1P7W)E;6]V95]P871H("$]("<G*0T*("`@("`@("`@("`@)B8@*'-U
M8G-T<B@D=E]H96%D97);)V9I;&5N86UE)UTL(#`L("1P7W)E;6]V95]P871H
M7W-I>F4I#0H)"0D@("`@/3T@)'!?<F5M;W9E7W!A=&@I*0T*("`@("`@("`@
M("1V7VAE861E<ELG9FEL96YA;64G72`]('-U8G-T<B@D=E]H96%D97);)V9I
M;&5N86UE)UTL#0H)"2`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1P7W)E;6]V95]P871H7W-I>F4I.PT*("`@("`@("!I9B`H*"1P7W!A=&@@
M(3T@)RXO)RD@)B8@*"1P7W!A=&@@(3T@)R\G*2D@>PT*("`@("`@("`@('=H
M:6QE("AS=6)S='(H)'!?<&%T:"P@+3$I(#T]("<O)RD-"B`@("`@("`@("`@
M("1P7W!A=&@@/2!S=6)S='(H)'!?<&%T:"P@,"P@<W1R;&5N*"1P7W!A=&@I
M+3$I.PT*#0H@("`@("`@("`@:68@*'-U8G-T<B@D=E]H96%D97);)V9I;&5N
M86UE)UTL(#`L(#$I(#T]("<O)RD-"B`@("`@("`@("`@("`@)'9?:&5A9&5R
M6R=F:6QE;F%M92==(#T@)'!?<&%T:"XD=E]H96%D97);)V9I;&5N86UE)UT[
M#0H@("`@("`@("`@96QS90T*("`@("`@("`@("`@)'9?:&5A9&5R6R=F:6QE
M;F%M92==(#T@)'!?<&%T:"XG+R<N)'9?:&5A9&5R6R=F:6QE;F%M92==.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D=E]H96%D97);
M)V9I;&5N86UE)UTI*2![#0H@("`@("`@("`@:68@*"`@("A`:7-?9&ER*"1V
M7VAE861E<ELG9FEL96YA;64G72DI#0H)"2`@("`@("8F("@D=E]H96%D97);
M)W1Y<&5F;&%G)UT@/3T@)R<I*2![#0H@("`@("`@("`@("`D=&AI<RT^7V5R
M<F]R*"=&:6QE("<N)'9?:&5A9&5R6R=F:6QE;F%M92==#0H)"0D@("`@("`@
M("`@("`@("XG(&%L<F5A9'D@97AI<W1S(&%S(&$@9&ER96-T;W)Y)RD[#0H@
M("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@?0T*("`@("`@
M("`@(&EF("@@("`H)'1H:7,M/E]I<T%R8VAI=F4H)'9?:&5A9&5R6R=F:6QE
M;F%M92==*2D-"@D)("`@("`@)B8@*"1V7VAE861E<ELG='EP969L86<G72`]
M/2`B-2(I*2![#0H@("`@("`@("`@("`D=&AI<RT^7V5R<F]R*"=$:7)E8W1O
M<GD@)RXD=E]H96%D97);)V9I;&5N86UE)UT-"@D)"2`@("`@("`@("`@("`@
M+B<@86QR96%D>2!E>&ES=',@87,@82!F:6QE)RD[#0H@("`@("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@("`@("`@?0T*("`@("`@("`@(&EF("@A:7-?
M=W)I=&5A8FQE*"1V7VAE861E<ELG9FEL96YA;64G72DI('L-"B`@("`@("`@
M("`@("1T:&ES+3Y?97)R;W(H)T9I;&4@)RXD=E]H96%D97);)V9I;&5N86UE
M)UT-"@D)"2`@("`@("`@("`@("`@+B<@86QR96%D>2!E>&ES=',@86YD(&ES
M('=R:71E('!R;W1E8W1E9"<I.PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@("`@("`@('T-"B`@("`@("`@("!I9B`H9FEL96UT:6UE*"1V7VAE
M861E<ELG9FEL96YA;64G72D@/B`D=E]H96%D97);)VUT:6UE)UTI('L-"B`@
M("`@("`@("`@("\O(%1O(&)E(&-O;7!L971E9"`Z($%N(&5R<F]R(&]R('-I
M;&5N="!N;R!R97!L86-E(#\-"B`@("`@("`@("!]#0H@("`@("`@('T-"@T*
M("`@("`@("`O+R`M+2TM+2!#:&5C:R!T:&4@9&ER96-T;W)Y(&%V86EL86)I
M;&ET>2!A;F0@8W)E871E(&ET(&EF(&YE8V5S<V%R>0T*("`@("`@("!E;'-E
M:68@*"@D=E]R97-U;'0-"@D)("`@("`@("`@/2`D=&AI<RT^7V1I<D-H96-K
M*"@D=E]H96%D97);)W1Y<&5F;&%G)UT@/3T@(C4B#0H)"0D)("`@("`@("`@
M("`@("`@("`@("`_)'9?:&5A9&5R6R=F:6QE;F%M92==#0H)"0D)"0D)"0DZ
M9&ER;F%M92@D=E]H96%D97);)V9I;&5N86UE)UTI*2DI("$](#$I('L-"B`@
M("`@("`@("`@("1T:&ES+3Y?97)R;W(H)U5N86)L92!T;R!C<F5A=&4@<&%T
M:"!F;W(@)RXD=E]H96%D97);)V9I;&5N86UE)UTI.PT*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H-"B`@("`@("`@:68@*"1V7V5X
M=')A8W1?9FEL92D@>PT*("`@("`@("`@(&EF("@D=E]H96%D97);)W1Y<&5F
M;&%G)UT@/3T@(C4B*2![#0H@("`@("`@("`@("!I9B`H(4!F:6QE7V5X:7-T
M<R@D=E]H96%D97);)V9I;&5N86UE)UTI*2![#0H@("`@("`@("`@("`@("`@
M:68@*"%`;6MD:7(H)'9?:&5A9&5R6R=F:6QE;F%M92==+"`P-S<W*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V5R<F]R*"=5;F%B;&4@=&\@
M8W)E871E(&1I<F5C=&]R>2![)PT*"0D)"0D@("`@("`@("`@("`@("XD=E]H
M96%D97);)V9I;&5N86UE)UTN)WTG*3L-"B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("!I9B`H*"1V
M7V1E<W1?9FEL92`]($!F;W!E;B@D=E]H96%D97);)V9I;&5N86UE)UTL(")W
M8B(I*2`]/2`P*2![#0H@("`@("`@("`@("`@("`@("`D=&AI<RT^7V5R<F]R
M*"=%<G)O<B!W:&EL92!O<&5N:6YG('LG+B1V7VAE861E<ELG9FEL96YA;64G
M70T*"0D)"2`@("`@("`@("`@("`@("`N)WT@:6X@=W)I=&4@8FEN87)Y(&UO
M9&4G*3L-"B`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("1N(#T@9FQO
M;W(H)'9?:&5A9&5R6R=S:7IE)UTO-3$R*3L-"B`@("`@("`@("`@("`@("`@
M(&9O<B`H)&D],#L@)&D\)&X[("1I*RLI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`D=E]C;VYT96YT(#T@)'1H:7,M/E]R96%D0FQO8VLH*3L-"B`@("`@
M("`@("`@("`@("`@("`@("!F=W)I=&4H)'9?9&5S=%]F:6QE+"`D=E]C;VYT
M96YT+"`U,3(I.PT*("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M:68@*"@D=E]H96%D97);)W-I>F4G72`E(#4Q,BD@(3T@,"D@>PT*("`@("`@
M("`@("`@("`D=E]C;VYT96YT(#T@)'1H:7,M/E]R96%D0FQO8VLH*3L-"B`@
M("`@("`@("`@("`@9G=R:71E*"1V7V1E<W1?9FEL92P@)'9?8V]N=&5N="P@
M*"1V7VAE861E<ELG<VEZ92==("4@-3$R*2D[#0H@("`@("`@("`@("!]#0H-
M"B`@("`@("`@("`@($!F8VQO<V4H)'9?9&5S=%]F:6QE*3L-"@T*("`@("`@
M("`@("`@+R\@+2TM+2T@0VAA;F=E('1H92!F:6QE(&UO9&4L(&UT:6UE#0H@
M("`@("`@("`@("!`=&]U8V@H)'9?:&5A9&5R6R=F:6QE;F%M92==+"`D=E]H
M96%D97);)VUT:6UE)UTI.PT*("`@("`@("`@("`@+R\@5&\@8F4@8V]M<&QE
M=&5D#0H@("`@("`@("`@("`O+V-H;6]D*"1V7VAE861E<EMF:6QE;F%M95TL
M($1E8T]C="@D=E]H96%D97);;6]D95TI*3L-"B`@("`@("`@("!]#0H-"B`@
M("`@("`@("`O+R`M+2TM+2!#:&5C:R!T:&4@9FEL92!S:7IE#0H@("`@("`@
M("`@8VQE87)S=&%T8V%C:&4H*3L-"B`@("`@("`@("!I9B`H9FEL97-I>F4H
M)'9?:&5A9&5R6R=F:6QE;F%M92==*2`A/2`D=E]H96%D97);)W-I>F4G72D@
M>PT*("`@("`@("`@("`@("`D=&AI<RT^7V5R<F]R*"=%>'1R86-T960@9FEL
M92`G+B1V7VAE861E<ELG9FEL96YA;64G70T*"0D)("`@("`@("`@("`@("`@
M("XG(&1O97,@;F]T(&AA=F4@=&AE(&-O<G)E8W0@9FEL92!S:7IE(%PG)PT*
M"0D)"0D)"2YF:6QE<VEZ92@D=E]H96%D97);)V9I;&5N86UE)UTI#0H)"0D)
M"0D)+B=<)R`H)RXD=E]H96%D97);)W-I>F4G70T*"0D)"0D)"2XG(&5X<&5C
M=&5D*2X@07)C:&EV92!M87D@8F4@8V]R<G5P=&5D+B<I.PT*("`@("`@("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@?0T*("`@("`@("`@('T-
M"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`D=&AI<RT^7VIU;7!";&]C
M:RAC96EL*"@D=E]H96%D97);)W-I>F4G72\U,3(I*2D[#0H@("`@("`@('T-
M"B`@("`@('T@96QS92![#0H@("`@("`@("`@)'1H:7,M/E]J=6UP0FQO8VLH
M8V5I;"@H)'9?:&5A9&5R6R=S:7IE)UTO-3$R*2DI.PT*("`@("`@?0T*#0H@
M("`@("`O*B!40D,@.B!3965M<R!T;R!B92!U;G5S960@+BXN#0H@("`@("!I
M9B`H)'1H:7,M/E]C;VUP<F5S<RD-"B`@("`@("`@)'9?96YD7V]F7V9I;&4@
M/2!`9WIE;V8H)'1H:7,M/E]F:6QE*3L-"B`@("`@(&5L<V4-"B`@("`@("`@
M)'9?96YD7V]F7V9I;&4@/2!`9F5O9B@D=&AI<RT^7V9I;&4I.PT*("`@("`@
M("`J+PT*#0H@("`@("!I9B`H)'9?;&ES=&EN9R!\?"`D=E]E>'1R86-T7V9I
M;&4@?'P@)'9?97AT<F%C=&EO;E]S=&]P<&5D*2![#0H@("`@("`@("\O("TM
M+2TM($QO9R!E>'1R86-T960@9FEL97,-"B`@("`@("`@:68@*"@D=E]F:6QE
M7V1I<B`](&1I<FYA;64H)'9?:&5A9&5R6R=F:6QE;F%M92==*2D-"@D)("`@
M(#T]("1V7VAE861E<ELG9FEL96YA;64G72D-"B`@("`@("`@("`D=E]F:6QE
M7V1I<B`]("<G.PT*("`@("`@("!I9B`H*'-U8G-T<B@D=E]H96%D97);)V9I
M;&5N86UE)UTL(#`L(#$I(#T]("<O)RD@)B8@*"1V7V9I;&5?9&ER(#T]("<G
M*2D-"B`@("`@("`@("`D=E]F:6QE7V1I<B`]("<O)SL-"@T*("`@("`@("`D
M<%]L:7-T7V1E=&%I;%LD=E]N8BLK72`]("1V7VAE861E<CL-"B`@("`@('T-
M"B`@("!]#0H-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*("`@("\O
M('U]?0T*#0H@("`@+R\@>WM[(%]O<&5N07!P96YD*"D-"B`@("!F=6YC=&EO
M;B!?;W!E;D%P<&5N9"@I#0H@("`@>PT*("`@("`@("!I9B`H9FEL97-I>F4H
M)'1H:7,M/E]T87)N86UE*2`]/2`P*0T*("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7V]P96Y7<FET92@I.PT*("`@("`@("`@(`T*("`@("`@("!I9B`H)'1H
M:7,M/E]C;VUP<F5S<RD@>PT*("`@("`@("`@("`@)'1H:7,M/E]C;&]S92@I
M.PT*#0H@("`@("`@("`@("!I9B`H(4!R96YA;64H)'1H:7,M/E]T87)N86UE
M+"`D=&AI<RT^7W1A<FYA;64N(BYT;7`B*2D@>PT*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?97)R;W(H)T5R<F]R('=H:6QE(')E;F%M:6YG(%PG)RXD=&AI
M<RT^7W1A<FYA;64-"@D)"0D@("`@("`@("`@("`@("XG7"<@=&\@=&5M<&]R
M87)Y(&9I;&4@7"<G+B1T:&ES+3Y?=&%R;F%M90T*"0D)"0D)"2`@+B<N=&UP
M7"<G*3L-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@
M("`@("!]#0H-"B`@("`@("`@("`@(&EF("@D=&AI<RT^7V-O;7!R97-S7W1Y
M<&4@/3T@)V=Z)RD-"B`@("`@("`@("`@("`@("`D=E]T96UP7W1A<B`]($!G
M>F]P96XH)'1H:7,M/E]T87)N86UE+B(N=&UP(BP@(G)B(BD[#0H@("`@("`@
M("`@("!E;'-E:68@*"1T:&ES+3Y?8V]M<')E<W-?='EP92`]/2`G8GHR)RD-
M"B`@("`@("`@("`@("`@("`D=E]T96UP7W1A<B`]($!B>F]P96XH)'1H:7,M
M/E]T87)N86UE+B(N=&UP(BP@(G)B(BD[#0H@("`@("`@("`@("`@("`@#0H@
M("`@("`@("`@("!I9B`H)'9?=&5M<%]T87(@/3T@,"D@>PT*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?97)R;W(H)U5N86)L92!T;R!O<&5N(&9I;&4@7"<G
M+B1T:&ES+3Y?=&%R;F%M90T*"0D)"2`@("`@("`@("`@("`@+B<N=&UP7"<@
M:6X@8FEN87)Y(')E860@;6]D92<I.PT*("`@("`@("`@("`@("`@($!R96YA
M;64H)'1H:7,M/E]T87)N86UE+B(N=&UP(BP@)'1H:7,M/E]T87)N86UE*3L-
M"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]
M#0H-"B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]O<&5N5W)I=&4H*2D@>PT*
M("`@("`@("`@("`@("`@($!R96YA;64H)'1H:7,M/E]T87)N86UE+B(N=&UP
M(BP@)'1H:7,M/E]T87)N86UE*3L-"B`@("`@("`@("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@("`@("`@("!]#0H-"B`@("`@("`@("`@(&EF("@D=&AI
M<RT^7V-O;7!R97-S7W1Y<&4@/3T@)V=Z)RD@>PT*("`@("`@("`@("`@("`@
M("1V7V)U9F9E<B`]($!G>G)E860H)'9?=&5M<%]T87(L(#4Q,BD[#0H-"B`@
M("`@("`@("`@("`@("`O+R`M+2TM+2!296%D('1H92!F;VQL;W=I;F<@8FQO
M8VMS(&)U="!N;W0@=&AE(&QA<W0@;VYE#0H@("`@("`@("`@("`@("`@:68@
M*"%`9WIE;V8H)'9?=&5M<%]T87(I*2![#0H@("`@("`@("`@("`@("`@("`@
M(&1O>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'9?8FEN87)Y7V1A=&$@
M/2!P86-K*")A-3$R(BP@)'9?8G5F9F5R*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?=W)I=&5";&]C:R@D=E]B:6YA<GE?9&%T82D[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D=E]B=69F97(@/2!`9WIR96%D*"1V
M7W1E;7!?=&%R+"`U,3(I.PT*#0H@("`@("`@("`@("`@("`@("`@('T@=VAI
M;&4@*"%`9WIE;V8H)'9?=&5M<%]T87(I*3L-"B`@("`@("`@("`@("`@("!]
M#0H-"B`@("`@("`@("`@("`@("!`9WIC;&]S92@D=E]T96UP7W1A<BD[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!E;'-E:68@*"1T:&ES+3Y?8V]M
M<')E<W-?='EP92`]/2`G8GHR)RD@>PT*("`@("`@("`@("`@("`@("1V7V)U
M9F9E<F5D7VQI;F5S("`@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@("1V
M7V)U9F9E<F5D7VQI;F5S6UT@/2!`8GIR96%D*"1V7W1E;7!?=&%R+"`U,3(I
M.PT*#0H@("`@("`@("`@("`@("`@+R\@+2TM+2T@4F5A9"!T:&4@9F]L;&]W
M:6YG(&)L;V-K<R!B=70@;F]T('1H92!L87-T(&]N90T*("`@("`@("`@("`@
M("`@('=H:6QE("AS=')L96XH)'9?8G5F9F5R961?;&EN97-;70T*"0D)"2`@
M("`@("`@("`@("`@/2!`8GIR96%D*"1V7W1E;7!?=&%R+"`U,3(I*2`^(#`I
M('L-"B`@("`@("`@("`@("`@("`@("`@)'9?8FEN87)Y7V1A=&$@/2!P86-K
M*")A-3$R(BP-"@D)"0D)("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W-H
M:69T*"1V7V)U9F9E<F5D7VQI;F5S*2D[#0H@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?=W)I=&5";&]C:R@D=E]B:6YA<GE?9&%T82D[#0H@("`@("`@
M("`@("`@("`@?0T*#0H@("`@("`@("`@("`@("`@0&)Z8VQO<V4H)'9?=&5M
M<%]T87(I.PT*("`@("`@("`@("`@?0T*#0H@("`@("`@("`@("!I9B`H(4!U
M;FQI;FLH)'1H:7,M/E]T87)N86UE+B(N=&UP(BDI('L-"B`@("`@("`@("`@
M("`@("`D=&AI<RT^7V5R<F]R*"=%<G)O<B!W:&EL92!D96QE=&EN9R!T96UP
M;W)A<GD@9FEL92!<)R<-"@D)"0D@("`@("`@("`@("`@("XD=&AI<RT^7W1A
M<FYA;64N)RYT;7!<)R<I.PT*("`@("`@("`@("`@?0T*#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`O+R`M+2TM+2!&;W(@;F]T(&-O;7!R97-S
M960@=&%R+"!J=7-T(&%D9"!F:6QE<R!B969O<F4@=&AE(&QA<W0-"@D)"2\O
M("`@("`@(#4Q,B!B>71E<R!B;&]C:PT*("`@("`@("`@("`@:68@*"$D=&AI
M<RT^7V]P96Y296%D5W)I=&4H*2D-"B`@("`@("`@("`@("`@(')E='5R;B!F
M86QS93L-"@T*("`@("`@("`@("`@8VQE87)S=&%T8V%C:&4H*3L-"B`@("`@
M("`@("`@("1V7W-I>F4@/2!F:6QE<VEZ92@D=&AI<RT^7W1A<FYA;64I.PT*
M("`@("`@("`@("`@9G-E96LH)'1H:7,M/E]F:6QE+"`D=E]S:7IE+34Q,BD[
M#0H@("`@("`@('T-"@T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H@
M("`@+R\@?7U]#0H-"B`@("`O+R![>WL@7V%P<&5N9"@I#0H@("`@9G5N8W1I
M;VX@7V%P<&5N9"@D<%]F:6QE;&ES="P@)'!?861D7V1I<CTG)RP@)'!?<F5M
M;W9E7V1I<CTG)RD-"B`@("![#0H@("`@("`@(&EF("@A)'1H:7,M/E]O<&5N
M07!P96YD*"DI#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@
M("`@("`-"B`@("`@("`@:68@*"1T:&ES+3Y?861D3&ES="@D<%]F:6QE;&ES
M="P@)'!?861D7V1I<BP@)'!?<F5M;W9E7V1I<BDI#0H@("`@("`@("`@("1T
M:&ES+3Y?=W)I=&5&;V]T97(H*3L-"@T*("`@("`@("`D=&AI<RT^7V-L;W-E
M*"D[#0H-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*("`@("\O('U]
M?0T*#0H@("`@+R\@>WM[(%]D:7)#:&5C:R@I#0H-"B`@("`O*BH-"B`@("`@
M*B!#:&5C:R!I9B!A(&1I<F5C=&]R>2!E>&ES=',@86YD(&-R96%T92!I="`H
M:6YC;'5D:6YG('!A<F5N=`T*("`@("`J(&1I<G,I(&EF(&YO="X-"B`@("`@
M*@T*("`@("`J($!P87)A;2!S=')I;F<@)'!?9&ER(&1I<F5C=&]R>2!T;R!C
M:&5C:PT*("`@("`J#0H@("`@("H@0')E='5R;B!B;V]L(%12544@:68@=&AE
M(&1I<F5C=&]R>2!E>&ES=',@;W(@=V%S(&-R96%T960-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!?9&ER0VAE8VLH)'!?9&ER*0T*("`@('L-"B`@("`@("`@
M:68@*"A`:7-?9&ER*"1P7V1I<BDI('Q\("@D<%]D:7(@/3T@)R<I*0T*("`@
M("`@("`@("`@<F5T=7)N('1R=64[#0H-"B`@("`@("`@)'!?<&%R96YT7V1I
M<B`](&1I<FYA;64H)'!?9&ER*3L-"@T*("`@("`@("!I9B`H*"1P7W!A<F5N
M=%]D:7(@(3T@)'!?9&ER*2`F)@T*("`@("`@("`@("`@*"1P7W!A<F5N=%]D
M:7(@(3T@)R<I("8F#0H@("`@("`@("`@("`H(21T:&ES+3Y?9&ER0VAE8VLH
M)'!?<&%R96YT7V1I<BDI*0T*("`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"@T*("`@("`@("!I9B`H(4!M:V1I<B@D<%]D:7(L(#`W-S<I*2![#0H@("`@
M("`@("`@("`D=&AI<RT^7V5R<F]R*")5;F%B;&4@=&\@8W)E871E(&1I<F5C
M=&]R>2`G)'!?9&ER)R(I.PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@("`@("!]#0H-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@
M("`@+R\@?7U]#0H-"B`@("`O+R![>WL@7W!A=&A2961U8W1I;VXH*0T*#0H@
M("`@+RHJ#0H@("`@("H@0V]M<')E<W,@<&%T:"!B>2!C:&%N9VEN9R!F;W(@
M97AA;7!L92`B+V1I<B]F;V\O+BXO8F%R(B!T;R`B+V1I<B]B87(B+"`-"B`@
M("`@*B!R86YD(&5M;W9E(&1O=6)L92!S;&%S:&5S+@T*("`@("`J#0H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<%]D:7(@<&%T:"!T;R!R961U8V4-"B`@("`@
M*@T*("`@("`J($!R971U<FX@<W1R:6YG(')E9'5C960@<&%T:`T*("`@("`J
M#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("H-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!?<&%T:%)E9'5C=&EO;B@D<%]D:7(I#0H@("`@>PT*("`@
M("`@("`D=E]R97-U;'0@/2`G)SL-"@T*("`@("`@("`O+R`M+2TM+2!,;V]K
M(&9O<B!N;W0@96UP='D@<&%T:`T*("`@("`@("!I9B`H)'!?9&ER("$]("<G
M*2![#0H@("`@("`@("`@("`O+R`M+2TM+2!%>'!L;V1E('!A=&@@8GD@9&ER
M96-T;W)Y(&YA;65S#0H@("`@("`@("`@("`D=E]L:7-T(#T@97AP;&]D92@G
M+R<L("1P7V1I<BD[#0H-"B`@("`@("`@("`@("\O("TM+2TM(%-T=61Y(&1I
M<F5C=&]R:65S(&9R;VT@;&%S="!T;R!F:7)S=`T*("`@("`@("`@("`@9F]R
M("@D:3US:7IE;V8H)'9?;&ES="DM,3L@)&D^/3`[("1I+2TI('L-"B`@("`@
M("`@("`@("`@("`O+R`M+2TM+2!,;V]K(&9O<B!C=7)R96YT('!A=&@-"B`@
M("`@("`@("`@("`@("!I9B`H)'9?;&ES=%LD:5T@/3T@(BXB*2![#0H@("`@
M("`@("`@("`@("`@("`@("\O("TM+2TM($EG;F]R92!T:&ES(&1I<F5C=&]R
M>0T*("`@("`@("`@("`@("`@("`@("`O+R!3:&]U;&0@8F4@=&AE(&9I<G-T
M("1I/3`L(&)U="!N;R!C:&5C:R!I<R!D;VYE#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@(&5L<V4@:68@*"1V7VQI<W1;)&E=(#T]("(N
M+B(I('L-"B`@("`@("`@("`@("`@("`@("`@+R\@+2TM+2T@26=N;W)E(&ET
M(&%N9"!I9VYO<F4@=&AE("1I+3$-"B`@("`@("`@("`@("`@("`@("`@)&DM
M+3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@96QS92!I
M9B`H("`@*"1V7VQI<W1;)&E=(#T]("<G*0T*"0D)"2`@("`@("`@("8F("@D
M:2$]*'-I>F5O9B@D=E]L:7-T*2TQ*2D-"@D)"0D)"2`F)B`H)&DA/3`I*2![
M#0H@("`@("`@("`@("`@("`@("`@("\O("TM+2TM($EG;F]R92!O;FQY('1H
M92!D;W5B;&4@)R\O)R!I;B!P871H+`T*("`@("`@("`@("`@("`@("`@("`O
M+R!B=70@;F]T('1H92!F:7)S="!A;F0@;&%S="`O#0H@("`@("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)'9?<F5S=6QT(#T@
M)'9?;&ES=%LD:5TN*"1I(3TH<VEZ96]F*"1V7VQI<W0I+3$I/R<O)PT*"0D)
M"0D@("`@("`@("`@("`N)'9?<F5S=6QT.B<G*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)'9?<F5S
M=6QT(#T@<W1R='(H)'9?<F5S=6QT+"`G7%PG+"`G+R<I.PT*("`@("`@("!R
M971U<FX@)'9?<F5S=6QT.PT*("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@
M+R\@>WM[(%]T<F%N<VQA=&57:6Y0871H*"D-"B`@("!F=6YC=&EO;B!?=')A
M;G-L871E5VEN4&%T:"@D<%]P871H+"`D<%]R96UO=F5?9&ES:U]L971T97(]
M=')U92D-"B`@("![#0H@("`@("!I9B`H3U-?5TE.1$]74RD@>PT*("`@("`@
M("`@("\O("TM+2TM($QO;VL@9F]R('!O=&5N=&EA;"!D:7-K(&QE='1E<@T*
M("`@("`@("`@(&EF("@@("`H)'!?<F5M;W9E7V1I<VM?;&5T=&5R*0T*"0D@
M("`@("`F)B`H*"1V7W!O<VET:6]N(#T@<W1R<&]S*"1P7W!A=&@L("<Z)RDI
M("$](&9A;'-E*2D@>PT*("`@("`@("`@("`@("`D<%]P871H(#T@<W5B<W1R
M*"1P7W!A=&@L("1V7W!O<VET:6]N*S$I.PT*("`@("`@("`@('T-"B`@("`@
M("`@("`O+R`M+2TM+2!#:&%N9V4@<&]T96YT:6%L('=I;F1O=W,@9&ER96-T
M;W)Y('-E<&%R871O<@T*("`@("`@("`@(&EF("@H<W1R<&]S*"1P7W!A=&@L
M("=<7"<I(#X@,"D@?'P@*'-U8G-T<B@D<%]P871H+"`P+#$I(#T]("=<7"<I
M*2![#0H@("`@("`@("`@("`@("1P7W!A=&@@/2!S=')T<B@D<%]P871H+"`G
M7%PG+"`G+R<I.PT*("`@("`@("`@('T-"B`@("`@('T-"B`@("`@(')E='5R
M;B`D<%]P871H.PT*("`@('T-"B`@("`O+R!]?7T-"@T*?0T*/SX-"@!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T%U=&@`````````````````````
M````````````````````````````````````````````````````````````
M````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U
M,34T,S,W,C<@,#$W,S$S`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O075T
M:"]305-,````````````````````````````````````````````````````
M```````````````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<R-R`P,C`P-34`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]!=71H+U-!4TPO0V]M;6]N+G!H<```````````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`V-30P(#$P-3$U-#,S-S(W(#`R
M,C$P,@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK(`HO+R!\
M($-O<'ER:6=H="`H8RD@,C`P,BTR,#`S(%)I8VAA<F0@2&5Y97,@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\(`HO+R!\($%L;"!R:6=H=',@
M<F5S97)V960N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\(`HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\(`HO+R!\(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N
M9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U="`@("!\(`HO+R!\(&UO
M9&EF:6-A=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F
M;VQL;W=I;F<@8V]N9&ET:6]N<R`@("!\(`HO+R!\(&%R92!M970Z("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\(`HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M(`HO+R!\(&\@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@
M<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0@("`@("!\(`HO+R!\("`@;F]T
M:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN
M9R!D:7-C;&%I;65R+B`@("`@("!\(`HO+R!\(&\@4F5D:7-T<FEB=71I;VYS
M(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y
M<FEG:'0@("!\(`HO+R!\("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET
M:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN('1H92!\(`HO
M+R!\("`@9&]C=6UE;G1A=&EO;B!A;F0O;W(@;W1H97(@;6%T97)I86QS('!R
M;W9I9&5D('=I=&@@=&AE(&1I<W1R:6)U=&EO;BY\(`HO+R!\(&\@5&AE(&YA
M;65S(&]F('1H92!A=71H;W)S(&UA>2!N;W0@8F4@=7-E9"!T;R!E;F1O<G-E
M(&]R('!R;VUO=&4@("`@("!\(`HO+R!\("`@<')O9'5C=',@9&5R:79E9"!F
M<F]M('1H:7,@<V]F='=A<F4@=VET:&]U="!S<&5C:69I8R!P<FEO<B!W<FET
M=&5N("!\(`HO+R!\("`@<&5R;6ES<VEO;BX@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`HO+R!\
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\(`HO+R!\(%1(25,@4T]&5%=!
M4D4@25,@4%)/5DE$140@0ED@5$A%($-/4%E224=(5"!(3TQ$15)3($%.1"!#
M3TY44DE"551/4E,@("!\(`HO+R!\(")!4R!)4R(@04Y$($%.62!%6%!215-3
M($]2($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4("`@
M("!\(`HO+R!\($Q)34E4140@5$\L(%1(12!)35!,245$(%=!4E)!3E1)15,@
M3T8@34520TA!3E1!0DE,2519($%.1"!&251.15-3($9/4B!\(`HO+R!\($$@
M4$%25$E#54Q!4B!055)03U-%($%212!$25-#3$%)345$+B!)3B!.3R!%5D5.
M5"!32$%,3"!42$4@0T]065))1TA4("!\(`HO+R!\($]73D52($]2($-/3E12
M24)55$]24R!"12!,24%"3$4@1D]2($%.62!$25)%0U0L($E.1$E214-4+"!)
M3D-)1$5.5$%,+"!\(`HO+R!\(%-014-)04PL($5814U03$%262P@3U(@0T].
M4T51545.5$E!3"!$04U!1T53("A)3D-,541)3D<L($)55"!.3U0@("`@("!\
M(`HO+R!\($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&(%-50E-425155$4@
M1T]/1%,@3U(@4T525DE#15,[($Q/4U,@3T8@55-%+"!\(`HO+R!\($1!5$$L
M($]2(%!23T9)5%,[($]2($)54TE.15-3($E.5$524E505$E/3BD@2$]7159%
M4B!#0553140@04Y$($].($%.62!\(`HO+R!\(%1(14]262!/1B!,24%"24Q)
M5%DL(%=(151(15(@24X@0T].5%)!0U0L(%-44DE#5"!,24%"24Q)5%DL($]2
M(%1/4E0@("!\(`HO+R!\("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%
M4E=)4T4I($%225-)3D<@24X@04Y9(%=!62!/550@3T8@5$A%(%5312!\(`HO
M+R!\($]&(%1(25,@4T]&5%=!4D4L($5614X@248@041625-%1"!/1B!42$4@
M4$]34TE"24Q)5%D@3T8@4U5#2"!$04U!1T4N("!\(`HO+R!\("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\(`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK(`HO+R!\($%U=&AO<CH@4FEC:&%R9"!(97EE<R`\<FEC:&%R9$!P
M:'`N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK(`HO+R`*+R\@)$ED.B!#;VUM
M;VXN<&AP+'8@,2XV(#(P,#,O,#(O,C$@,38Z,#<Z,3<@;6H@17AP("0*"B\J
M*@HJ($-O;6UO;B!F=6YC=&EO;F%L:71Y('1O(%-!4TP@;65C:&%N:7-M<PHJ
M"BH@0&%U=&AO<B`@4FEC:&%R9"!(97EE<R`\<FEC:&%R9$!P:'`N;F5T/@HJ
M($!A8V-E<W,@('!U8FQI8PHJ($!V97)S:6]N(#$N,`HJ($!P86-K86=E($%U
M=&A?4T%33`HJ+PH*8VQA<W,@075T:%]305-,7T-O;6UO;@I["B`@("`O*BH*
M("`@("H@1G5N8W1I;VX@=VAI8V@@:6UP;&5M96YT<R!(34%#($U$-2!D:6=E
M<W0*("`@("H*("`@("H@0'!A<F%M("!S=')I;F<@)&ME>2`@5&AE('-E8W)E
M="!K97D*("`@("H@0'!A<F%M("!S=')I;F<@)&1A=&$@5&AE(&1A=&$@=&\@
M<')O=&5C=`H@("`@*B!`<F5T=7)N('-T<FEN9R`@("`@("!4:&4@2$U!0R!-
M1#4@9&EG97-T"B`@("`J+PH@("`@9G5N8W1I;VX@7TA-04-?340U*"1K97DL
M("1D871A*0H@("`@>PH@("`@("`@(&EF("AS=')L96XH)&ME>2D@/B`V-"D@
M>PH@("`@("`@("`@("`D:V5Y(#T@<&%C:R@G2#,R)RP@;60U*"1K97DI*3L*
M("`@("`@("!]"@H@("`@("`@(&EF("AS=')L96XH)&ME>2D@/"`V-"D@>PH@
M("`@("`@("`@("`D:V5Y(#T@<W1R7W!A9"@D:V5Y+"`V-"P@8VAR*#`I*3L*
M("`@("`@("!]"@H@("`@("`@("1K7VEP860@/2!S=6)S='(H)&ME>2P@,"P@
M-C0I(%X@<W1R7W)E<&5A="AC:'(H,'@S-BDL(#8T*3L*("`@("`@("`D:U]O
M<&%D(#T@<W5B<W1R*"1K97DL(#`L(#8T*2!>('-T<E]R97!E870H8VAR*#!X
M-4,I+"`V-"D["@H@("`@("`@("1I;FYE<B`@/2!P86-K*"=(,S(G+"!M9#4H
M)&M?:7!A9"`N("1D871A*2D["B`@("`@("`@)&1I9V5S="`](&UD-2@D:U]O
M<&%D("X@)&EN;F5R*3L*"B`@("`@("`@<F5T=7)N("1D:6=E<W0["B`@("!]
M"GT*/SX*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O075T:"]305-,+T-R86U-1#4N<&AP````````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-C<P-B`Q,#4Q-30S,S<R-R`P
M,C(P-#8`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L@#0HO
M+R!\($-O<'ER:6=H="`H8RD@,C`P,BTR,#`S(%)I8VAA<F0@2&5Y97,@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`T*+R\@?"!!;&P@<FEG
M:'1S(')E<V5R=F5D+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?"`-"B\O('P@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P@#0HO+R!\(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U
M<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U="`@("!\(`T*
M+R\@?"!M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@<')O=FED960@=&AA
M="!T:&4@9F]L;&]W:6YG(&-O;F1I=&EO;G,@("`@?"`-"B\O('P@87)E(&UE
M=#H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P@#0HO+R!\("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\(`T*+R\@?"!O(%)E9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@
M8V]D92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I9VAT("`@("`@?"`-
M"B\O('P@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T
M:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N("`@("`@('P@#0HO+R!\(&\@4F5D
M:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H
M92!A8F]V92!C;W!Y<FEG:'0@("!\(`T*+R\@?"`@(&YO=&EC92P@=&AI<R!L
M:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE
M<B!I;B!T:&4@?"`-"B\O('P@("!D;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE
M<B!M871E<FEA;',@<')O=FED960@=VET:"!T:&4@9&ES=')I8G5T:6]N+GP@
M#0HO+R!\(&\@5&AE(&YA;65S(&]F('1H92!A=71H;W)S(&UA>2!N;W0@8F4@
M=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@("`@("!\(`T*+R\@?"`@('!R
M;V1U8W1S(&1E<FEV960@9G)O;2!T:&ES('-O9G1W87)E('=I=&AO=70@<W!E
M8VEF:6,@<')I;W(@=W)I='1E;B`@?"`-"B\O('P@("!P97)M:7-S:6]N+B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P@#0HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M(`T*+R\@?"!42$E3(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#3U!9
M4DE'2%0@2$],1$524R!!3D0@0T].5%))0E543U)3("`@?"`-"B\O('P@(D%3
M($E3(B!!3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!705)204Y42453+"!)
M3D-,541)3D<L($)55"!.3U0@("`@('P@#0HO+R!\($Q)34E4140@5$\L(%1(
M12!)35!,245$(%=!4E)!3E1)15,@3T8@34520TA!3E1!0DE,2519($%.1"!&
M251.15-3($9/4B!\(`T*+R\@?"!!(%!!4E1)0U5,05(@4%524$]312!!4D4@
M1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%($-/4%E224=(5"`@
M?"`-"B\O('P@3U=.15(@3U(@0T].5%))0E543U)3($)%($Q)04),12!&3U(@
M04Y9($1)4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL('P@#0HO+R!\(%-0
M14-)04PL($5814U03$%262P@3U(@0T].4T51545.5$E!3"!$04U!1T53("A)
M3D-,541)3D<L($)55"!.3U0@("`@("!\(`T*+R\@?"!,24U)5$5$(%1/+"!0
M4D]#55)%345.5"!/1B!354)35$E4551%($=/3T13($]2(%-%4E9)0T53.R!,
M3U-3($]&(%5312P@?"`-"B\O('P@1$%402P@3U(@4%)/1DE44SL@3U(@0E53
M24Y%4U,@24Y415)255!424].*2!(3U=%5D52($-!55-%1"!!3D0@3TX@04Y9
M('P@#0HO+R!\(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(15(@24X@0T].
M5%)!0U0L(%-44DE#5"!,24%"24Q)5%DL($]2(%1/4E0@("!\(`T*+R\@?"`H
M24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!4DE324Y'($E.
M($%.62!705D@3U54($]&(%1(12!54T4@?"`-"B\O('P@3T8@5$A)4R!33T94
M5T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(12!03U-324))3$E462!/1B!3
M54-(($1!34%'12X@('P@#0HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\(`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*R`-"B\O('P@
M075T:&]R.B!2:6-H87)D($AE>65S(#QR:6-H87)D0'!H<"YN970^("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P@#0HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK(`T*+R\@#0HO+R`D260Z($-R86U-1#4N<&AP+'8@
M,2XT(#(P,#,O,#(O,C$@,38Z,#<Z,3<@;6H@17AP("0-"@T*+RHJ#0HJ($EM
M<&QM96YT871I;VX@;V8@0U)!32U-1#4@4T%33"!M96-H86YI<VT-"BH-"BH@
M0&%U=&AO<B`@4FEC:&%R9"!(97EE<R`\<FEC:&%R9$!P:'`N;F5T/@T**B!`
M86-C97-S("!P=6)L:6,-"BH@0'9E<G-I;VX@,2XP#0HJ($!P86-K86=E($%U
M=&A?4T%33`T**B\-"@T*<F5Q=6ER95]O;F-E*"=!=71H+U-!4TPO0V]M;6]N
M+G!H<"<I.PT*#0IC;&%S<R!!=71H7U-!4TQ?0W)A;4U$-2!E>'1E;F1S($%U
M=&A?4T%33%]#;VUM;VX-"GL-"B`@("`O*BH-"B`@("`J($EM<&QE;65N=',@
M=&AE($-204TM340U(%-!4TP@;65C:&%N:7-M#0H@("`@*B!4:&ES($1/15,@
M3D]4(&)A<V4V-"!E;F-O9&4@=&AE(')E='5R;B!V86QU92P-"B`@("`J('EO
M=2!W:6QL(&YE960@=&\@9&\@=&AA="!Y;W5R<V5L9BX-"B`@("`J#0H@("`@
M*B!`<&%R86T@<W1R:6YG("1U<V5R("`@("`@57-E<FYA;64-"B`@("`J($!P
M87)A;2!S=')I;F<@)'!A<W,@("`@("!087-S=V]R9`T*("`@("H@0'!A<F%M
M('-T<FEN9R`D8VAA;&QE;F=E(%1H92!C:&%L;&5N9V4@<W5P<&QI960@8GD@
M=&AE('-E<G9E<BX-"B`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!T
M:&ES('-H;W5L9"!B92!A;')E861Y(&)A<V4V-%]D96-O9&5D+@T*("`@("H-
M"B`@("`J($!R971U<FX@<W1R:6YG(%1H92!S=')I;F<@=&\@<&%S<R!B86-K
M('1O('1H92!S97)V97(L(&]F('1H92!F;W)M#0H@("`@*B`@("`@("`@("`@
M("`@("`B/'5S97(^(#QD:6=E<W0^(BX@5&AI<R!I<R!.3U0@8F%S938T7V5N
M8V]D960N#0H@("`@*B\-"B`@("!F=6YC=&EO;B!G971297-P;VYS92@D=7-E
M<BP@)'!A<W,L("1C:&%L;&5N9V4I#0H@("`@>PT*("`@("`@("!R971U<FX@
M)'5S97(@+B`G("<@+B`D=&AI<RT^7TA-04-?340U*"1P87-S+"`D8VAA;&QE
M;F=E*3L-"B`@("!]#0I]#0H_/@``````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+T%U=&@O4T%33"]$:6=E<W1-1#4N<&AP````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,C`R-C`@,3`U,34T,S,W,C<@
M,#(R,S<R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L@"B\O
M('P@0V]P>7)I9VAT("AC*2`R,#`R+3(P,#,@4FEC:&%R9"!(97EE<R`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@"B\O('P@06QL(')I9VAT
M<R!R97-E<G9E9"X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P@"B\O('P@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P@"B\O('P@4F5D:7-T<FEB=71I;VX@86YD('5S92!I;B!S;W5R8V4@
M86YD(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T("`@('P@"B\O('P@
M;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE
M(&9O;&QO=VEN9R!C;VYD:71I;VYS("`@('P@"B\O('P@87)E(&UE=#H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P@"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P@"B\O('P@;R!2961I<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S
M="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H="`@("`@('P@"B\O('P@("!N
M;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W
M:6YG(&1I<V-L86EM97(N("`@("`@('P@"B\O('P@;R!2961I<W1R:6)U=&EO
M;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B;W9E(&-O
M<'ER:6=H="`@('P@"B\O('P@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD
M:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@:6X@=&AE('P@
M"B\O('P@("!D;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE<B!M871E<FEA;',@
M<')O=FED960@=VET:"!T:&4@9&ES=')I8G5T:6]N+GP@"B\O('P@;R!4:&4@
M;F%M97,@;V8@=&AE(&%U=&AO<G,@;6%Y(&YO="!B92!U<V5D('1O(&5N9&]R
M<V4@;W(@<')O;6]T92`@("`@('P@"B\O('P@("!P<F]D=6-T<R!D97)I=F5D
M(&9R;VT@=&AI<R!S;V9T=V%R92!W:71H;W5T('-P96-I9FEC('!R:6]R('=R
M:71T96X@('P@"B\O('P@("!P97)M:7-S:6]N+B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@"B\O
M('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@"B\O('P@5$A)4R!33T94
M5T%212!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@04Y$
M($-/3E1224)55$]24R`@('P@"B\O('P@(D%3($E3(B!!3D0@04Y9($584%)%
M4U,@3U(@24U03$E%1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.3U0@
M("`@('P@"B\O('P@3$E-251%1"!43RP@5$A%($E-4$Q)140@5T%24D%.5$E%
M4R!/1B!-15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,@1D]2('P@"B\O('P@
M02!005)424-53$%2(%!54E!/4T4@05)%($1)4T-,04E-140N($E.($Y/($56
M14Y4(%-(04Q,(%1(12!#3U!94DE'2%0@('P@"B\O('P@3U=.15(@3U(@0T].
M5%))0E543U)3($)%($Q)04),12!&3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L
M($E.0TE$14Y404PL('P@"B\O('P@4U!%0TE!3"P@15A%35!,05)9+"!/4B!#
M3TY315%514Y424%,($1!34%'15,@*$E.0TQ51$E.1RP@0E54($Y/5"`@("`@
M('P@"B\O('P@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8@4U5"4U1)5%54
M12!'3T]$4R!/4B!315)624-%4SL@3$]34R!/1B!54T4L('P@"B\O('P@1$%4
M02P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,@24Y415)255!424].*2!(3U=%
M5D52($-!55-%1"!!3D0@3TX@04Y9('P@"B\O('P@5$A%3U)9($]&($Q)04))
M3$E462P@5TA%5$A%4B!)3B!#3TY44D%#5"P@4U1224-4($Q)04))3$E462P@
M3U(@5$]25"`@('P@"B\O('P@*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]4
M2$525TE312D@05))4TE.1R!)3B!!3ED@5T%9($]55"!/1B!42$4@55-%('P@
M"B\O('P@3T8@5$A)4R!33T945T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(
M12!03U-324))3$E462!/1B!354-(($1!34%'12X@('P@"B\O('P@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P@"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L@"B\O('P@075T:&]R.B!2:6-H87)D($AE>65S(#QR:6-H87)D
M0'!H<"YN970^("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L@"B\O(`HO+R`D260Z($1I
M9V5S=$U$-2YP:'`L=B`Q+C8@,C`P,R\P,B\R,2`Q-CHP-SHQ-R!M:B!%>'`@
M)`H*+RHJ"BH@26UP;&UE;G1A=&EO;B!O9B!$24=%4U0M340U(%-!4TP@;65C
M:&%N:7-M"BH**B!`875T:&]R("!2:6-H87)D($AE>65S(#QR:6-H87)D0'!H
M<"YN970^"BH@0&%C8V5S<R`@<'5B;&EC"BH@0'9E<G-I;VX@,2XP"BH@0'!A
M8VMA9V4@075T:%]305-,"BHO"@IR97%U:7)E7V]N8V4H)T%U=&@O4T%33"]#
M;VUM;VXN<&AP)RD["@IC;&%S<R!!=71H7U-!4TQ?1&EG97-T340U(&5X=&5N
M9',@075T:%]305-,7T-O;6UO;@I["B`@("`O*BH*("`@("H@4')O=FED97,@
M=&AE("AM86EN*2!C;&EE;G0@<F5S<&]N<V4@9F]R($1)1T535"U-1#4*("`@
M("H@<F5Q=6ER97,@82!F97<@97AT<F$@<&%R86UE=&5R<R!T:&%N('1H92!O
M=&AE<@H@("`@*B!M96-H86YI<VUS+"!W:&EC:"!A<F4@=6YA=F]I9&%B;&4N
M"B`@("`J(`H@("`@*B!`<&%R86T@('-T<FEN9R`D875T:&-I9"`@($%U=&AE
M;G1I8V%T:6]N(&ED("AU<V5R;F%M92D*("`@("H@0'!A<F%M("!S=')I;F<@
M)'!A<W,@("`@("!087-S=V]R9`H@("`@*B!`<&%R86T@('-T<FEN9R`D8VAA
M;&QE;F=E(%1H92!D:6=E<W0@8VAA;&QE;F=E('-E;G0@8GD@=&AE('-E<G9E
M<@H@("`@*B!`<&%R86T@('-T<FEN9R`D:&]S=&YA;64@(%1H92!H;W-T;F%M
M92!O9B!T:&4@;6%C:&EN92!Y;W4G<F4@8V]N;F5C=&EN9R!T;PH@("`@*B!`
M<&%R86T@('-T<FEN9R`D<V5R=FEC92`@(%1H92!S97)V:6-E;F%M92`H96<N
M(&EM87`L('!O<"P@86-A<"!E=&,I"B`@("`J($!P87)A;2`@<W1R:6YG("1A
M=71H>FED("`@075T:&]R:7IA=&EO;B!I9"`H=7-E<FYA;64@=&\@<')O>'D@
M87,I"B`@("`J($!R971U<FX@<W1R:6YG("`@("`@("`@("`@5&AE(&1I9V5S
M="!R97-P;VYS92`H3D]4(&)A<V4V-"!E;F-O9&5D*0H@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N(&=E=%)E<W!O;G-E*"1A=71H
M8VED+"`D<&%S<RP@)&-H86QL96YG92P@)&AO<W1N86UE+"`D<V5R=FEC92P@
M)&%U=&AZ:60@/2`G)RD*("`@('L*("`@("`@("`D8VAA;&QE;F=E(#T@)'1H
M:7,M/E]P87)S94-H86QL96YG92@D8VAA;&QE;F=E*3L*("`@("`@("`D875T
M:'II9%]S=')I;F<@/2`G)SL*("`@("`@("!I9B`H)&%U=&AZ:60@(3T@)R<I
M('L*("`@("`@("`@("`@)&%U=&AZ:61?<W1R:6YG(#T@)RQA=71H>FED/2(G
M("X@)&%U=&AZ:60@+B`G(B<[(`H@("`@("`@('T*"B`@("`@("`@:68@*"%E
M;7!T>2@D8VAA;&QE;F=E*2D@>PH@("`@("`@("`@("`D8VYO;F-E("`@("`@
M("`@/2`D=&AI<RT^7V=E=$-N;VYC92@I.PH@("`@("`@("`@("`D9&EG97-T
M7W5R:2`@("`@/2!S<')I;G1F*"<E<R\E<R<L("1S97)V:6-E+"`D:&]S=&YA
M;64I.PH@("`@("`@("`@("`D<F5S<&]N<V5?=F%L=64@/2`D=&AI<RT^7V=E
M=%)E<W!O;G-E5F%L=64H)&%U=&AC:60L("1P87-S+"`D8VAA;&QE;F=E6R=R
M96%L;2==+"`D8VAA;&QE;F=E6R=N;VYC92==+"`D8VYO;F-E+"`D9&EG97-T
M7W5R:2P@)&%U=&AZ:60I.PH*("`@("`@("`@("`@<F5T=7)N('-P<FEN=&8H
M)W5S97)N86UE/2(E<R(L<F5A;&T](B5S(B<@+B`D875T:'II9%]S=')I;F<@
M("X@)RQN;VYC93TB)7,B+&-N;VYC93TB)7,B+&YC/2(P,#`P,#`P,2(L<6]P
M/6%U=&@L9&EG97-T+75R:3TB)7,B+')E<W!O;G-E/25S+"5D)RP@)&%U=&AC
M:60L("1C:&%L;&5N9V5;)W)E86QM)UTL("1C:&%L;&5N9V5;)VYO;F-E)UTL
M("1C;F]N8V4L("1D:6=E<W1?=7)I+"`D<F5S<&]N<V5?=F%L=64L("1C:&%L
M;&5N9V5;)VUA>&)U9B==*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G26YV86QI9"!D:6=E<W0@8VAA
M;&QE;F=E)RD["B`@("`@("`@?0H@("`@?0H@("`@"B`@("`O*BH*("`@("H@
M4&%R<V5S(&%N9"!V97)I9FEE<R!T:&4@9&EG97-T(&-H86QL96YG92H*("`@
M("H*("`@("H@0'!A<F%M("!S=')I;F<@)&-H86QL96YG92!4:&4@9&EG97-T
M(&-H86QL96YG90H@("`@*B!`<F5T=7)N(&%R<F%Y("`@("`@("`@("`@(%1H
M92!P87)S960@8VAA;&QE;F=E(&%S(&%N(&%S<V]C"B`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@87)R87D@:6X@=&AE(&9O<FT@(F1I<F5C=&EV
M92`]/B!V86QU92(N"B`@("`J($!A8V-E<W,@<')I=F%T90H@("`@*B\*("`@
M(&9U;F-T:6]N(%]P87)S94-H86QL96YG92@D8VAA;&QE;F=E*0H@("`@>PH@
M("`@("`@("1T;VME;G,@/2!A<G)A>2@I.PH@("`@("`@('=H:6QE("AP<F5G
M7VUA=&-H*"<O7BA;82UZ+5TK*3TH(EM>(ETK*#\\(5Q<7"DB?%M>+%TK*2]I
M)RP@)&-H86QL96YG92P@)&UA=&-H97,I*2!["@H@("`@("`@("`@("`O+R!)
M9VYO<F4@=&AE<V4@87,@<&5R(')F8S(X,S$*("`@("`@("`@("`@:68@*"1M
M871C:&5S6S%=(#T]("=O<&%Q=64G($]2("1M871C:&5S6S%=(#T]("=D;VUA
M:6XG*2!["B`@("`@("`@("`@("`@("`D8VAA;&QE;F=E(#T@<W5B<W1R*"1C
M:&%L;&5N9V4L('-T<FQE;B@D;6%T8VAE<ULP72D@*R`Q*3L*("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O
M+R!!;&QO=V5D(&UU;'1I<&QE(")R96%L;2(@86YD(")A=71H+7!A<F%M(@H@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1T;VME;G-;)&UA=&-H97-;,5U=*2!!
M3D0@*"1M871C:&5S6S%=(#T]("=R96%L;2<@3U(@)&UA=&-H97-;,5T@/3T@
M)V%U=&@M<&%R86TG*2D@>PH@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y
M*"1T;VME;G-;)&UA=&-H97-;,5U=*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1T;VME;G-;)&UA=&-H97-;,5U=6UT@/2!P<F5G7W)E<&QA8V4H)R]>(B@N
M*BDB)"\G+"`G7%PQ)RP@)&UA=&-H97-;,ETI.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&]K96YS6R1M871C:&5S
M6S%=72`](&%R<F%Y*"1T;VME;G-;)&UA=&-H97-;,5U=+"!P<F5G7W)E<&QA
M8V4H)R]>(B@N*BDB)"\G+"`G7%PQ)RP@)&UA=&-H97-;,ETI*3L*("`@("`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("\O($%N>2!O=&AE<B!M=6QT:7!L
M92!I;G-T86YC92`](&9A:6QU<F4*("`@("`@("`@("`@?2!E;'-E:68@*"%E
M;7!T>2@D=&]K96YS6R1M871C:&5S6S%=72DI('L*("`@("`@("`@("`@("`@
M("1T;VME;G,@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1O:V5N<ULD
M;6%T8VAE<ULQ75T@/2!P<F5G7W)E<&QA8V4H)R]>(B@N*BDB)"\G+"`G7%PQ
M)RP@)&UA=&-H97-;,ETI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O
M+R!296UO=F4@=&AE(&IU<W0@<&%R<V5D(&1I<F5C=&EV92!F<F]M('1H92!C
M:&%L;&5N9V4*("`@("`@("`@("`@)&-H86QL96YG92`]('-U8G-T<B@D8VAA
M;&QE;F=E+"!S=')L96XH)&UA=&-H97-;,%TI("L@,2D["B`@("`@("`@?0H*
M("`@("`@("`O*BH*("`@("`@("`J($1E9F%U;'1S(&%N9"!R97%U:7)E9"!D
M:7)E8W1I=F5S"B`@("`@("`@*B\*("`@("`@("`O+R!296%L;0H@("`@("`@
M(&EF("AE;7!T>2@D=&]K96YS6R=R96%L;2==*2D@>PH@("`@("`@("`@("`D
M=6YA;64@/2!P;W-I>%]U;F%M92@I.PH@("`@("`@("`@("`D=&]K96YS6R=R
M96%L;2==(#T@)'5N86UE6R=N;V1E;F%M92==.PH@("`@("`@('T*("`@("`@
M("`*("`@("`@("`O+R!-87AB=68*("`@("`@("!I9B`H96UP='DH)'1O:V5N
M<ULG;6%X8G5F)UTI*2!["B`@("`@("`@("`@("1T;VME;G-;)VUA>&)U9B==
M(#T@-C4U,S8["B`@("`@("`@?0H@("`@("`@(`H@("`@("`@("\O(%)E<75I
M<F5D.B!N;VYC92P@86QG;W)I=&AM"B`@("`@("`@:68@*&5M<'1Y*"1T;VME
M;G-;)VYO;F-E)UTI($]2(&5M<'1Y*"1T;VME;G-;)V%L9V]R:71H;2==*2D@
M>PH@("`@("`@("`@("!R971U<FX@87)R87DH*3L*("`@("`@("!]"B`@("`@
M("`@"B`@("`@("`@<F5T=7)N("1T;VME;G,["B`@("!]"@H@("`@+RHJ"B`@
M("`J($-R96%T97,@=&AE(')E<W!O;G-E/2!P87)T(&]F('1H92!D:6=E<W0@
M<F5S<&]N<V4*("`@("H*("`@("H@0'!A<F%M("!S=')I;F<@)&%U=&AC:60@
M("`@075T:&5N=&EC871I;VX@:60@*'5S97)N86UE*0H@("`@*B!`<&%R86T@
M('-T<FEN9R`D<&%S<R`@("`@("!087-S=V]R9`H@("`@*B!`<&%R86T@('-T
M<FEN9R`D<F5A;&T@("`@("!296%L;2!A<R!P<F]V:61E9"!B>2!T:&4@<V5R
M=F5R"B`@("`J($!P87)A;2`@<W1R:6YG("1N;VYC92`@("`@($YO;F-E(&%S
M('!R;W9I9&5D(&)Y('1H92!S97)V97(*("`@("H@0'!A<F%M("!S=')I;F<@
M)&-N;VYC92`@("`@0VQI96YT(&YO;F-E"B`@("`J($!P87)A;2`@<W1R:6YG
M("1D:6=E<W1?=7)I(%1H92!D:6=E<W0M=7)I/2!V86QU92!P87)T(&]F('1H
M92!R97-P;VYS90H@("`@*B!`<&%R86T@('-T<FEN9R`D875T:'II9"`@("!!
M=71H;W)I>F%T:6]N(&ED"B`@("`J($!R971U<FX@<W1R:6YG("`@("`@("`@
M("`@(%1H92!R97-P;VYS93T@<&%R="!O9B!T:&4@9&EG97-T(')E<W!O;G-E
M"B`@("`J($!A8V-E<W,@<')I=F%T90H@("`@*B\@("`@"B`@("!F=6YC=&EO
M;B!?9V5T4F5S<&]N<V5686QU92@D875T:&-I9"P@)'!A<W,L("1R96%L;2P@
M)&YO;F-E+"`D8VYO;F-E+"`D9&EG97-T7W5R:2P@)&%U=&AZ:60@/2`G)RD*
M("`@('L*("`@("`@("!I9B`H)&%U=&AZ:60@/3T@)R<I('L*("`@("`@("`@
M("`@)$$Q(#T@<W!R:6YT9B@G)7,Z)7,Z)7,G+"!P86-K*"=(,S(G+"!M9#4H
M<W!R:6YT9B@G)7,Z)7,Z)7,G+"`D875T:&-I9"P@)')E86QM+"`D<&%S<RDI
M*2P@)&YO;F-E+"`D8VYO;F-E*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D03$@/2!S<')I;G1F*"<E<SHE<SHE<SHE<R<L('!A8VLH)T@S,B<L
M(&UD-2AS<')I;G1F*"<E<SHE<SHE<R<L("1A=71H8VED+"`D<F5A;&TL("1P
M87-S*2DI+"`D;F]N8V4L("1C;F]N8V4L("1A=71H>FED*3L*("`@("`@("!]
M"B`@("`@("`@)$$R(#T@)T%55$A%3E1)0T%413HG("X@)&1I9V5S=%]U<FD[
M"B`@("`@("`@<F5T=7)N(&UD-2AS<')I;G1F*"<E<SHE<SHP,#`P,#`P,3HE
M<SIA=71H.B5S)RP@;60U*"1!,2DL("1N;VYC92P@)&-N;VYC92P@;60U*"1!
M,BDI*3L*("`@('T*"B`@("`O*BH*("`@("H@0W)E871E<R!T:&4@8VQI96YT
M(&YO;F-E(&9O<B!T:&4@<F5S<&]N<V4*("`@("H*("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!C;F]N8V4@=F%L=64*("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$-N;VYC92@I"B`@("!["B`@("`@
M("`@:68@*&9I;&5?97AI<W1S*"<O9&5V+W5R86YD;VTG*2D@>PH@("`@("`@
M("`@("!R971U<FX@8F%S938T7V5N8V]D92AF<F5A9"AF;W!E;B@G+V1E=B]U
M<F%N9&]M)RP@)W(G*2P@,S(I*3L*"B`@("`@("`@?2!E;'-E:68@*&9I;&5?
M97AI<W1S*"<O9&5V+W)A;F1O;2<I*2!["B`@("`@("`@("`@(')E='5R;B!B
M87-E-C1?96YC;V1E*&9R96%D*&9O<&5N*"<O9&5V+W)A;F1O;2<L("=R)RDL
M(#,R*2D["@H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1S='(@/2`G
M)SL*("`@("`@("`@("`@;71?<W)A;F0H*&1O=6)L92EM:6-R;W1I;64H*2HQ
M,#`P,#`P,"D["B`@("`@("`@("`@(&9O<B`H)&D],#L@)&D\,S([("1I*RLI
M('L*("`@("`@("`@("`@("`@("1S='(@+CT@8VAR*&UT7W)A;F0H,"P@,C4U
M*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@"B`@("`@("`@("`@(')E
M='5R;B!B87-E-C1?96YC;V1E*"1S='(I.PH@("`@("`@('T*("`@('T*?0H_
M/@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+T%U=&@O4T%33"],;V=I;BYP:'``````````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#8R-S0@,3`U,34T,S,W,C<@,#(Q-S(V`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK(`T*+R\@?"!#;W!Y
M<FEG:'0@*&,I(#(P,#(M,C`P,R!2:6-H87)D($AE>65S("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?"`-"B\O('P@06QL(')I9VAT<R!R97-E
M<G9E9"X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P@#0HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M(`T*+R\@?"!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@
M8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70@("`@?"`-"B\O('P@;6]D
M:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O
M;&QO=VEN9R!C;VYD:71I;VYS("`@('P@#0HO+R!\(&%R92!M970Z("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\(`T*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?"`-"B\O('P@;R!2961I<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S
M="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H="`@("`@('P@#0HO+R!\("`@
M;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO
M=VEN9R!D:7-C;&%I;65R+B`@("`@("!\(`T*+R\@?"!O(%)E9&ES=')I8G5T
M:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C92!T:&4@86)O=F4@
M8V]P>7)I9VAT("`@?"`-"B\O('P@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C
M;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@:6X@=&AE
M('P@#0HO+R!\("`@9&]C=6UE;G1A=&EO;B!A;F0O;W(@;W1H97(@;6%T97)I
M86QS('!R;W9I9&5D('=I=&@@=&AE(&1I<W1R:6)U=&EO;BY\(`T*+R\@?"!O
M(%1H92!N86UE<R!O9B!T:&4@875T:&]R<R!M87D@;F]T(&)E('5S960@=&\@
M96YD;W)S92!O<B!P<F]M;W1E("`@("`@?"`-"B\O('P@("!P<F]D=6-T<R!D
M97)I=F5D(&9R;VT@=&AI<R!S;V9T=V%R92!W:71H;W5T('-P96-I9FEC('!R
M:6]R('=R:71T96X@('P@#0HO+R!\("`@<&5R;6ES<VEO;BX@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\(`T*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?"`-"B\O('P@
M5$A)4R!33T945T%212!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/
M3$1%4E,@04Y$($-/3E1224)55$]24R`@('P@#0HO+R!\(")!4R!)4R(@04Y$
M($%.62!%6%!215-3($]2($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$24Y'
M+"!"550@3D]4("`@("!\(`T*+R\@?"!,24U)5$5$(%1/+"!42$4@24U03$E%
M1"!705)204Y42453($]&($U%4D-(04Y404))3$E462!!3D0@1DE43D534R!&
M3U(@?"`-"B\O('P@02!005)424-53$%2(%!54E!/4T4@05)%($1)4T-,04E-
M140N($E.($Y/($5614Y4(%-(04Q,(%1(12!#3U!94DE'2%0@('P@#0HO+R!\
M($]73D52($]2($-/3E1224)55$]24R!"12!,24%"3$4@1D]2($%.62!$25)%
M0U0L($E.1$E214-4+"!)3D-)1$5.5$%,+"!\(`T*+R\@?"!34$5#24%,+"!%
M6$5-4$Q!4EDL($]2($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'
M+"!"550@3D]4("`@("`@?"`-"B\O('P@3$E-251%1"!43RP@4%)/0U5214U%
M3E0@3T8@4U5"4U1)5%5412!'3T]$4R!/4B!315)624-%4SL@3$]34R!/1B!5
M4T4L('P@#0HO+R!\($1!5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3($E.
M5$524E505$E/3BD@2$]7159%4B!#0553140@04Y$($].($%.62!\(`T*+R\@
M?"!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52($E.($-/3E1204-4+"!3
M5%))0U0@3$E!0DE,2519+"!/4B!43U)4("`@?"`-"B\O('P@*$E.0TQ51$E.
M1R!.14=,24=%3D-%($]2($]42$525TE312D@05))4TE.1R!)3B!!3ED@5T%9
M($]55"!/1B!42$4@55-%('P@#0HO+R!\($]&(%1(25,@4T]&5%=!4D4L($56
M14X@248@041625-%1"!/1B!42$4@4$]34TE"24Q)5%D@3T8@4U5#2"!$04U!
M1T4N("!\(`T*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?"`-"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L@#0HO+R!\($%U=&AO<CH@
M4FEC:&%R9"!(97EE<R`\<FEC:&%R9$!P:'`N;F5T/B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\(`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*R`-"B\O(`T*+R\@)$ED.B!,;V=I;BYP:'`L=B`Q+C0@,C`P,R\P
M,B\R,2`Q-CHP-SHQ-R!M:B!%>'`@)`T*#0HO*BH-"BH@5&AI<R!I<R!T96-H
M;FEC86QL>2!N;W0@82!305-,(&UE8VAA;FES;2P@:&]W979E<@T**B!I="=S
M('5S960@8GD@3F5T7U-I979E+"!.971?0WER=7,@86YD('!O=&5N=&EA;&QY
M#0HJ(&]T:&5R('!R;W1O8V]L<R`L('-O(&AE<F4@:7,@82!G;V]D('!L86-E
M('1O(&%B<W1R86-T#0HJ(&ET+@T**@T**B!`875T:&]R("!2:6-H87)D($AE
M>65S(#QR:6-H87)D0'!H<"YN970^#0HJ($!A8V-E<W,@('!U8FQI8PT**B!`
M=F5R<VEO;B`Q+C`-"BH@0'!A8VMA9V4@075T:%]305-,#0HJ+PT*#0IR97%U
M:7)E7V]N8V4H)T%U=&@O4T%33"]#;VUM;VXN<&AP)RD[#0H-"F-L87-S($%U
M=&A?4T%33%],;V=I;B!E>'1E;F1S($%U=&A?4T%33%]#;VUM;VX-"GL-"B`@
M("`O*BH-"B`@("`J(%!S975D;R!305-,($Q/1TE.(&UE8VAA;FES;0T*("`@
M("H-"B`@("`J($!P87)A;2`@<W1R:6YG("1U<V5R(%5S97)N86UE#0H@("`@
M*B!`<&%R86T@('-T<FEN9R`D<&%S<R!087-S=V]R9`T*("`@("H@0')E='5R
M;B!S=')I;F<@("`@("`@3$]'24X@<W1R:6YG#0H@("`@*B\-"B`@("!F=6YC
M=&EO;B!G971297-P;VYS92@D=7-E<BP@)'!A<W,I#0H@("`@>PT*("`@("`@
M("!R971U<FX@<W!R:6YT9B@G3$]'24X@)7,@)7,G+"`D=7-E<BP@)'!A<W,I
M.PT*("`@('T-"GT-"C\^````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]!=71H+U-!4TPO4&QA:6XN<&AP````````````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`V,C4Q(#$P-3$U-#,S-S(W(#`R,3<Q-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*R`-"B\O('P@0V]P
M>7)I9VAT("AC*2`R,#`R+3(P,#,@4FEC:&%R9"!(97EE<R`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P@#0HO+R!\($%L;"!R:6=H=',@<F5S
M97)V960N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\(`T*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?"`-"B\O('P@4F5D:7-T<FEB=71I;VX@86YD('5S92!I;B!S;W5R8V4@86YD
M(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T("`@('P@#0HO+R!\(&UO
M9&EF:6-A=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F
M;VQL;W=I;F<@8V]N9&ET:6]N<R`@("!\(`T*+R\@?"!A<F4@;65T.B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?"`-"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P@#0HO+R!\(&\@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C;V1E(&UU
M<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0@("`@("!\(`T*+R\@?"`@
M(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL
M;W=I;F<@9&ES8VQA:6UE<BX@("`@("`@?"`-"B\O('P@;R!2961I<W1R:6)U
M=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B;W9E
M(&-O<'ER:6=H="`@('P@#0HO+R!\("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@
M8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN('1H
M92!\(`T*+R\@?"`@(&1O8W5M96YT871I;VX@86YD+V]R(&]T:&5R(&UA=&5R
M:6%L<R!P<F]V:61E9"!W:71H('1H92!D:7-T<FEB=71I;VXN?"`-"B\O('P@
M;R!4:&4@;F%M97,@;V8@=&AE(&%U=&AO<G,@;6%Y(&YO="!B92!U<V5D('1O
M(&5N9&]R<V4@;W(@<')O;6]T92`@("`@('P@#0HO+R!\("`@<')O9'5C=',@
M9&5R:79E9"!F<F]M('1H:7,@<V]F='=A<F4@=VET:&]U="!S<&5C:69I8R!P
M<FEO<B!W<FET=&5N("!\(`T*+R\@?"`@('!E<FUI<W-I;VXN("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?"`-"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@#0HO+R!\
M(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($-/4%E224=(5"!(
M3TQ$15)3($%.1"!#3TY44DE"551/4E,@("!\(`T*+R\@?"`B05,@25,B($%.
M1"!!3ED@15A04D534R!/4B!)35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.
M1RP@0E54($Y/5"`@("`@?"`-"B\O('P@3$E-251%1"!43RP@5$A%($E-4$Q)
M140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,@
M1D]2('P@#0HO+R!\($$@4$%25$E#54Q!4B!055)03U-%($%212!$25-#3$%)
M345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4@0T]065))1TA4("!\(`T*+R\@
M?"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4@3$E!0DQ%($9/4B!!3ED@1$E2
M14-4+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@?"`-"B\O('P@4U!%0TE!3"P@
M15A%35!,05)9+"!/4B!#3TY315%514Y424%,($1!34%'15,@*$E.0TQ51$E.
M1RP@0E54($Y/5"`@("`@('P@#0HO+R!\($Q)34E4140@5$\L(%!23T-54D5-
M14Y4($]&(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,[($Q/4U,@3T8@
M55-%+"!\(`T*+R\@?"!$051!+"!/4B!04D]&2513.R!/4B!"55-)3D534R!)
M3E1%4E)54%1)3TXI($A/5T5615(@0T%54T5$($%.1"!/3B!!3ED@?"`-"B\O
M('P@5$A%3U)9($]&($Q)04))3$E462P@5TA%5$A%4B!)3B!#3TY44D%#5"P@
M4U1224-4($Q)04))3$E462P@3U(@5$]25"`@('P@#0HO+R!\("A)3D-,541)
M3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I($%225-)3D<@24X@04Y9(%=!
M62!/550@3T8@5$A%(%5312!\(`T*+R\@?"!/1B!42$E3(%-/1E1705)%+"!%
M5D5.($E&($%$5DE3140@3T8@5$A%(%!/4U-)0DE,2519($]&(%-50T@@1$%-
M04=%+B`@?"`-"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@#0HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK(`T*+R\@?"!!=71H;W(Z
M(%)I8VAA<F0@2&5Y97,@/')I8VAA<F1`<&AP+FYE=#X@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?"`-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L@#0HO+R`-"B\O("1)9#H@4&QA:6XN<&AP+'8@,2XU(#(P,#,O
M,#(O,C$@,38Z,#<Z,3<@;6H@17AP("0-"@T*+RHJ#0HJ($EM<&QM96YT871I
M;VX@;V8@4$Q!24X@4T%33"!M96-H86YI<VT-"BH-"BH@0&%U=&AO<B`@4FEC
M:&%R9"!(97EE<R`\<FEC:&%R9$!P:'`N;F5T/@T**B!`86-C97-S("!P=6)L
M:6,-"BH@0'9E<G-I;VX@,2XP#0HJ($!P86-K86=E($%U=&A?4T%33`T**B\-
M"@T*<F5Q=6ER95]O;F-E*"=!=71H+U-!4TPO0V]M;6]N+G!H<"<I.PT*#0IC
M;&%S<R!!=71H7U-!4TQ?4&QA:6X@97AT96YD<R!!=71H7U-!4TQ?0V]M;6]N
M#0I[#0H@("`@+RHJ#0H@("`@*B!2971U<FYS(%!,04E.(')E<W!O;G-E#0H@
M("`@*@T*("`@("H@0'!A<F%M("!S=')I;F<@)&%U=&AC:60@("!!=71H96YT
M:6-A=&EO;B!I9"`H=7-E<FYA;64I#0H@("`@*B!`<&%R86T@('-T<FEN9R`D
M<&%S<R`@("`@(%!A<W-W;W)D#0H@("`@*B!`<&%R86T@('-T<FEN9R`D875T
M:'II9"`@($%U=&]R:7IA=&EO;B!I9`T*("`@("H@0')E='5R;B!S=')I;F<@
M("`@("`@("`@("!03$%)3B!297-P;VYS90T*("`@("HO#0H@("`@9G5N8W1I
M;VX@9V5T4F5S<&]N<V4H)&%U=&AC:60L("1P87-S+"`D875T:'II9"`]("<G
M*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1A=71H>FED("X@8VAR*#`I("X@
M)&%U=&AC:60@+B!C:'(H,"D@+B`D<&%S<SL-"B`@("!]#0I]#0H_/@T*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O075T:"]305-,+T%N;VYY;6]U<RYP:'``````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P-C<V-"`Q,#4Q-30S,S<R-R`P,C(V-3(`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L@#0HO+R!\($-O
M<'ER:6=H="`H8RD@,C`P,BTR,#`S(%)I8VAA<F0@2&5Y97,@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\(`T*+R\@?"!!;&P@<FEG:'1S(')E
M<V5R=F5D+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?"`-"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P@#0HO+R!\(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N
M9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U="`@("!\(`T*+R\@?"!M
M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@<')O=FED960@=&AA="!T:&4@
M9F]L;&]W:6YG(&-O;F1I=&EO;G,@("`@?"`-"B\O('P@87)E(&UE=#H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P@#0HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\(`T*+R\@?"!O(%)E9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D92!M
M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I9VAT("`@("`@?"`-"B\O('P@
M("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L
M;&]W:6YG(&1I<V-L86EM97(N("`@("`@('P@#0HO+R!\(&\@4F5D:7-T<FEB
M=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V
M92!C;W!Y<FEG:'0@("!\(`T*+R\@?"`@(&YO=&EC92P@=&AI<R!L:7-T(&]F
M(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T
M:&4@?"`-"B\O('P@("!D;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE<B!M871E
M<FEA;',@<')O=FED960@=VET:"!T:&4@9&ES=')I8G5T:6]N+GP@#0HO+R!\
M(&\@5&AE(&YA;65S(&]F('1H92!A=71H;W)S(&UA>2!N;W0@8F4@=7-E9"!T
M;R!E;F1O<G-E(&]R('!R;VUO=&4@("`@("!\(`T*+R\@?"`@('!R;V1U8W1S
M(&1E<FEV960@9G)O;2!T:&ES('-O9G1W87)E('=I=&AO=70@<W!E8VEF:6,@
M<')I;W(@=W)I='1E;B`@?"`-"B\O('P@("!P97)M:7-S:6]N+B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P@#0HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`T*+R\@
M?"!42$E3(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@
M2$],1$524R!!3D0@0T].5%))0E543U)3("`@?"`-"B\O('P@(D%3($E3(B!!
M3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!705)204Y42453+"!)3D-,541)
M3D<L($)55"!.3U0@("`@('P@#0HO+R!\($Q)34E4140@5$\L(%1(12!)35!,
M245$(%=!4E)!3E1)15,@3T8@34520TA!3E1!0DE,2519($%.1"!&251.15-3
M($9/4B!\(`T*+R\@?"!!(%!!4E1)0U5,05(@4%524$]312!!4D4@1$E30TQ!
M24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%($-/4%E224=(5"`@?"`-"B\O
M('P@3U=.15(@3U(@0T].5%))0E543U)3($)%($Q)04),12!&3U(@04Y9($1)
M4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL('P@#0HO+R!\(%-014-)04PL
M($5814U03$%262P@3U(@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,541)
M3D<L($)55"!.3U0@("`@("!\(`T*+R\@?"!,24U)5$5$(%1/+"!04D]#55)%
M345.5"!/1B!354)35$E4551%($=/3T13($]2(%-%4E9)0T53.R!,3U-3($]&
M(%5312P@?"`-"B\O('P@1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,@
M24Y415)255!424].*2!(3U=%5D52($-!55-%1"!!3D0@3TX@04Y9('P@#0HO
M+R!\(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(15(@24X@0T].5%)!0U0L
M(%-44DE#5"!,24%"24Q)5%DL($]2(%1/4E0@("!\(`T*+R\@?"`H24Y#3%5$
M24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!4DE324Y'($E.($%.62!7
M05D@3U54($]&(%1(12!54T4@?"`-"B\O('P@3T8@5$A)4R!33T945T%212P@
M159%3B!)1B!!1%9)4T5$($]&(%1(12!03U-324))3$E462!/1B!354-(($1!
M34%'12X@('P@#0HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`T*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*R`-"B\O('P@075T:&]R
M.B!2:6-H87)D($AE>65S(#QR:6-H87)D0'!H<"YN970^("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P@#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK(`T*+R\@#0HO+R`D260Z($%N;VYY;6]U<RYP:'`L=B`Q+C0@
M,C`P,R\P,B\R,2`Q-CHP-SHQ-R!M:B!%>'`@)`T*#0HO*BH-"BH@26UP;&UE
M;G1A=&EO;B!O9B!!3D].64U/55,@4T%33"!M96-H86YI<VT-"BH-"BH@0&%U
M=&AO<B`@4FEC:&%R9"!(97EE<R`\<FEC:&%R9$!P:'`N;F5T/@T**B!`86-C
M97-S("!P=6)L:6,-"BH@0'9E<G-I;VX@,2XP#0HJ($!P86-K86=E($%U=&A?
M4T%33`T**B\-"@T*<F5Q=6ER95]O;F-E*"=!=71H+U-!4TPO0V]M;6]N+G!H
M<"<I.PT*#0IC;&%S<R!!=71H7U-!4TQ?06YO;GEM;W5S(&5X=&5N9',@075T
M:%]305-,7T-O;6UO;@T*>PT*("`@("\J*@T*("`@("H@3F]T(&UU8V@@=&\@
M9&\@:&5R92!E>&-E<'0@<F5T=7)N('1H92!T;VME;B!S=7!P;&EE9"X-"B`@
M("`J($YO(&5N8V]D:6YG+"!H87-H:6YG(&]R(&5N8W)Y<'1I;VX@=&%K97,@
M<&QA8V4@9F]R('1H:7,-"B`@("`J(&UE8VAA;FES;2P@<VEM<&QY(&]N92!O
M9CH-"B`@("`J("!O($%N(&5M86EL(&%D9')E<W,-"B`@("`J("!O($%N(&]P
M87%U92!S=')I;F<@;F]T(&-O;G1A:6YI;F<@(D`B('1H870@8V%N(&)E(&EN
M=&5R<')E=&5D#0H@("`@*B`@("!B>2!T:&4@<WES861M:6X-"B`@("`J("!O
M($YO=&AI;F<-"B`@("`J#0H@("`@*B!792!C;W5L9"!H879E('-O;64@;&]G
M:6,@:&5R92!F;W(@=&AE('-E8V]N9"!O<'1I;VXL(&)U="!T:&ES#0H@("`@
M*B!W;W5L9"!B>2!N;R!M96%N<R!C<F5A=&4@<V]M971H:6YG(&EN=&5R<')E
M=&%B;&4N#0H@("`@*@T*("`@("H@0'!A<F%M("!S=')I;F<@)'1O:V5N($]P
M=&EO;F%L(&5M86EL(&%D9')E<W,@;W(@<W1R:6YG('1O('!R;W9I9&4-"B`@
M("`J("`@("`@("`@("`@("`@("`@("`@("!A<R!T<F%C92!I;F9O<FUA=&EO
M;BX-"B`@("`J($!R971U<FX@<W1R:6YG("`@("`@("!4:&4@=6YA;'1E<F5D
M(&EN<'5T('1O:V5N#0H@("`@*B\-"B`@("!F=6YC=&EO;B!G971297-P;VYS
M92@D=&]K96X@/2`G)RD-"B`@("![#0H@("`@("`@(')E='5R;B`D=&]K96X[
M#0H@("`@?0T*?0T*/SX```````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+T%U=&@O4T%33"YP:'``````````````````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,3`R,#0@,3`U,34T,S,W,C<@,#(P-C0R
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK(`T*+R\@?"!#
M;W!Y<FEG:'0@*&,I(#(P,#(M,C`P,R!2:6-H87)D($AE>65S("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?"`-"B\O('P@06QL(')I9VAT<R!R
M97-E<G9E9"X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P@#0HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\(`T*+R\@?"!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A
M;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70@("`@?"`-"B\O('P@
M;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE
M(&9O;&QO=VEN9R!C;VYD:71I;VYS("`@('P@#0HO+R!\(&%R92!M970Z("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\(`T*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?"`-"B\O('P@;R!2961I<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@
M;75S="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H="`@("`@('P@#0HO+R!\
M("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O
M;&QO=VEN9R!D:7-C;&%I;65R+B`@("`@("!\(`T*+R\@?"!O(%)E9&ES=')I
M8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C92!T:&4@86)O
M=F4@8V]P>7)I9VAT("`@?"`-"B\O('P@("!N;W1I8V4L('1H:7,@;&ES="!O
M9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@:6X@
M=&AE('P@#0HO+R!\("`@9&]C=6UE;G1A=&EO;B!A;F0O;W(@;W1H97(@;6%T
M97)I86QS('!R;W9I9&5D('=I=&@@=&AE(&1I<W1R:6)U=&EO;BY\(`T*+R\@
M?"!O(%1H92!N86UE<R!O9B!T:&4@875T:&]R<R!M87D@;F]T(&)E('5S960@
M=&\@96YD;W)S92!O<B!P<F]M;W1E("`@("`@?"`-"B\O('P@("!P<F]D=6-T
M<R!D97)I=F5D(&9R;VT@=&AI<R!S;V9T=V%R92!W:71H;W5T('-P96-I9FEC
M('!R:6]R('=R:71T96X@('P@#0HO+R!\("`@<&5R;6ES<VEO;BX@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\(`T*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?"`-"B\O
M('P@5$A)4R!33T945T%212!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4
M($A/3$1%4E,@04Y$($-/3E1224)55$]24R`@('P@#0HO+R!\(")!4R!)4R(@
M04Y$($%.62!%6%!215-3($]2($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$
M24Y'+"!"550@3D]4("`@("!\(`T*+R\@?"!,24U)5$5$(%1/+"!42$4@24U0
M3$E%1"!705)204Y42453($]&($U%4D-(04Y404))3$E462!!3D0@1DE43D53
M4R!&3U(@?"`-"B\O('P@02!005)424-53$%2(%!54E!/4T4@05)%($1)4T-,
M04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(12!#3U!94DE'2%0@('P@#0HO
M+R!\($]73D52($]2($-/3E1224)55$]24R!"12!,24%"3$4@1D]2($%.62!$
M25)%0U0L($E.1$E214-4+"!)3D-)1$5.5$%,+"!\(`T*+R\@?"!34$5#24%,
M+"!%6$5-4$Q!4EDL($]2($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$
M24Y'+"!"550@3D]4("`@("`@?"`-"B\O('P@3$E-251%1"!43RP@4%)/0U52
M14U%3E0@3T8@4U5"4U1)5%5412!'3T]$4R!/4B!315)624-%4SL@3$]34R!/
M1B!54T4L('P@#0HO+R!\($1!5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3
M($E.5$524E505$E/3BD@2$]7159%4B!#0553140@04Y$($].($%.62!\(`T*
M+R\@?"!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52($E.($-/3E1204-4
M+"!35%))0U0@3$E!0DE,2519+"!/4B!43U)4("`@?"`-"B\O('P@*$E.0TQ5
M1$E.1R!.14=,24=%3D-%($]2($]42$525TE312D@05))4TE.1R!)3B!!3ED@
M5T%9($]55"!/1B!42$4@55-%('P@#0HO+R!\($]&(%1(25,@4T]&5%=!4D4L
M($5614X@248@041625-%1"!/1B!42$4@4$]34TE"24Q)5%D@3T8@4U5#2"!$
M04U!1T4N("!\(`T*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?"`-
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L@#0HO+R!\($%U=&AO
M<CH@4FEC:&%R9"!(97EE<R`\<FEC:&%R9$!P:'`N;F5T/B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\(`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*R`-"B\O(`T*+R\@)$ED.B!305-,+G!H<"QV(#$N-"`R,#`S
M+S`R+S(Q(#$V.C`W.C$W(&UJ($5X<"`D#0H-"B\J*@T**B!#;&EE;G0@:6UP
M;&5M96YT871I;VX@;V8@=F%R:6]U<R!305-,(&UE8VAA;FES;7,@#0HJ#0HJ
M($!A=71H;W(@(%)I8VAA<F0@2&5Y97,@/')I8VAA<F1`<&AP+FYE=#X-"BH@
M0&%C8V5S<R`@<'5B;&EC#0HJ($!V97)S:6]N(#$N,`T**B!`<&%C:V%G92!!
M=71H7U-!4TP-"BHO#0H-"G)E<75I<F5?;VYC92@G4$5!4BYP:'`G*3L-"@T*
M8VQA<W,@075T:%]305-,#0I[#0H@("`@+RHJ#0H@("`@*B!&86-T;W)Y(&-L
M87-S+B!2971U<FYS(&%N(&]B:F5C="!O9B!T:&4@<F5Q=65S=`T*("`@("H@
M='EP92X-"B`@("`J#0H@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E($]N92!O
M9CH@06YO;GEM;W5S#0H@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@4&QA:6X-"B`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!#
M<F%M340U#0H@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1&EG
M97-T340U#0H@("`@*B`@("`@("`@("`@("`@("`@("`@(%1Y<&5S(&%R92!N
M;W0@8V%S92!S96YS:71I=F4-"B`@("`J+PT*("`@(&9U;F-T:6]N("9F86-T
M;W)Y*"1T>7!E*0T*("`@('L-"B`@("`@("`@<W=I=&-H("AS=')T;VQO=V5R
M*"1T>7!E*2D@>PT*("`@("`@("`@("`@8V%S92`G86YO;GEM;W5S)SH-"B`@
M("`@("`@("`@("`@("`D9FEL96YA;64@(#T@)T%U=&@O4T%33"]!;F]N>6UO
M=7,N<&AP)SL-"B`@("`@("`@("`@("`@("`D8VQA<W-N86UE(#T@)T%U=&A?
M4T%33%]!;F]N>6UO=7,G.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*#0H@
M("`@("`@("`@("!C87-E("=L;V=I;B<Z#0H@("`@("`@("`@("`@("`@)&9I
M;&5N86UE("`]("=!=71H+U-!4TPO3&]G:6XN<&AP)SL-"B`@("`@("`@("`@
M("`@("`D8VQA<W-N86UE(#T@)T%U=&A?4T%33%],;V=I;B<[#0H@("`@("`@
M("`@("`@("`@8G)E86L[#0H-"B`@("`@("`@("`@(&-A<V4@)W!L86EN)SH-
M"B`@("`@("`@("`@("`@("`D9FEL96YA;64@(#T@)T%U=&@O4T%33"]0;&%I
M;BYP:'`G.PT*("`@("`@("`@("`@("`@("1C;&%S<VYA;64@/2`G075T:%]3
M05-,7U!L86EN)SL-"B`@("`@("`@("`@("`@("!B<F5A:SL-"@T*("`@("`@
M("`@("`@8V%S92`G8W)A;6UD-2<Z#0H@("`@("`@("`@("`@("`@)&9I;&5N
M86UE("`]("=!=71H+U-!4TPO0W)A;4U$-2YP:'`G.PT*("`@("`@("`@("`@
M("`@("1C;&%S<VYA;64@/2`G075T:%]305-,7T-R86U-1#4G.PT*("`@("`@
M("`@("`@("`@(&)R96%K.PT*#0H@("`@("`@("`@("!C87-E("=D:6=E<W1M
M9#4G.@T*("`@("`@("`@("`@("`@("1F:6QE;F%M92`@/2`G075T:"]305-,
M+T1I9V5S=$U$-2YP:'`G.PT*("`@("`@("`@("`@("`@("1C;&%S<VYA;64@
M/2`G075T:%]305-,7T1I9V5S=$U$-2<[#0H@("`@("`@("`@("`@("`@8G)E
M86L[#0H-"B`@("`@("`@("`@(&1E9F%U;'0Z#0H@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TEN=F%L:60@4T%33"!M96-H86YI
M<VT@='EP92<I.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("!]
M#0H-"B`@("`@("`@<F5Q=6ER95]O;F-E*"1F:6QE;F%M92D[#0H@("`@("`@
M(')E='5R;B!N97<@)&-L87-S;F%M92@I.PT*("`@('T-"GT-"@T*/SX`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M0V%C:&4`````````````````````````````````````````````````````
M```````````````````````````````````P,#`W-34@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<S,"`P,3<T,#<`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]#86-H92]#;VYT86EN97(`````````````````
M`````````````````````````````````````````````````````````#`P
M,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S,P
M(#`R,3,S,0`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T-A8VAE+T-O;G1A
M:6YE<B]D8BYP:'``````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,C(S,S`@,3`U,34T,S,W,C<@,#(R-3$T`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\(%!%05(@.CH@0V%C:&4@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT
M("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO
M;B`R+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\"B\O('P@=&AA="!I
M<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.
M4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X
M="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@
M>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E
M(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@
M("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@
M>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%5L9B!7
M96YD96P@/'5L9BYW96YD96Q`<&AP9&]C+F1E/B`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@?"`@("`@("`@("!396)A<W1I86X@0F5R9VUA;FX@
M/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X@("`@("`@("`@("`@("!\"B\O
M('P@("`@("`@("`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!D8BYP:'`L=B`Q+C4@,C`P,R\P
M,2\P-"`Q,3HU-#HT-B!M:B!%>'`@)`H*<F5Q=6ER95]O;F-E("=$0BYP:'`G
M.PIR97%U:7)E7V]N8V4@)T-A8VAE+T-O;G1A:6YE<BYP:'`G.PH*+RHJ"BH@
M4$5!4B]$0B!#86-H92!#;VYT86EN97(N"BH**B!705).24Y'.B!/=&AE<B!S
M>7-T96US(&UI9VAT(&]R(&UI9VAT(&YO="!S=7!P;W)T(&-E<G1A:6X@9&%T
M871Y<&5S(&]F"BH@=&AE('1A8FQE<R!S:&]W;BX@07,@9F%R(&%S($D@:VYO
M=R!T:&5R92=S(&YO(&QA<F=E(&)I;F%R>0HJ('1Y<&4@:6X@4U%,+3DR(&]R
M(%-13"TY.2X@4&]S=&=R97,@<V5E;7,@=&\@;&%C:R!A;GD**B!"3$]"(&]R
M(%1%6%0@='EP92P@9F]R($U3+5-13"!Y;W4@8V]U;&0@=7-E($E-04=%+"!D
M;VXG="!K;F]W"BH@86)O=70@;W1H97(@9&%T86)A<V5S+B!0;&5A<V4@861D
M('-U9V5S=&EO;G,@9F]R(&]T:&5R(&1A=&%B87-E<R!T;PHJ('1H92!I;FQI
M;F4@9&]C<RX**@HJ(%1H92!F:65L9"`G8VAA;F=E9"<@:&%S(&YO(&UE86YI
M;F<@9F]R('1H92!#86-H92!I='-E;&8N($ET)W,@:G5S="!T:&5R90HJ(&)E
M8V%U<V4@:70G<R!A(&=O;V0@:61E82!T;R!H879E(&%N(&%U=&]M871I8V%L
M;'D@=7!D871E9"!T:6UE<W1A;7`**B!F:65L9"!F;W(@9&5B=6=G:6YG(&EN
M(&%L;"!O9B!Y;W5R('1A8FQE<RX**@HJ($9O<B!?37E344Q?('EO=2!N965D
M('1H:7,@1$(@=&%B;&4Z"BH**B!#4D5!5$4@5$%"3$4@8V%C:&4@*`HJ("`@
M:60@("`@("`@("`@0TA!4B@S,BD@3D]4($Y53$P@1$5&055,5"`G)RP**B`@
M(&-A8VAE9W)O=7`@(%9!4D-(05(H,3(W*2!.3U0@3E5,3"!$149!54Q4("<G
M+`HJ("`@8V%C:&5D871A("`@0DQ/0B!.3U0@3E5,3"!$149!54Q4("<G+`HJ
M("`@=7-E<F1A=&$@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,($1%1D%53"`G
M)RP**B`@(&5X<&ER97,@("`@($E.5"@Y*2!.3U0@3E5,3"!$149!54Q4(#`L
M"BH**B`@(&-H86YG960@("`@(%1)34535$%-4"@Q-"D@3D]4($Y53$PL"BH*
M*B`@($E.1$58("AE>'!I<F5S*2P**B`@(%!224U!4ED@2T59("AI9"P@8V%C
M:&5G<F]U<"D**B`I"BH**B!`875T:&]R("`@4V5B87-T:6%N($)E<F=M86YN
M(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^"BH@0'9E<G-I;VX@("1)9#H@
M9&(N<&AP+'8@,2XU(#(P,#,O,#$O,#0@,3$Z-30Z-#8@;6H@17AP("0**B!`
M<&%C:V%G92`@0V%C:&4**B\*8VQA<W,@0V%C:&5?0V]N=&%I;F5R7V1B(&5X
M=&5N9',@0V%C:&5?0V]N=&%I;F5R('L*"B`@("`O*BH*("`@("H@3F%M92!O
M9B!T:&4@1$(@=&%B;&4@=&\@<W1O<F4@8V%C:&EN9R!D871A"B`@("`J"B`@
M("`J($!S964@($-A8VAE7T-O;G1A:6YE<E]F:6QE.CHD9FEL96YA;65?<')E
M9FEX"B`@("`J+PH@("`@=F%R("1C86-H95]T86)L92`]("<G.PH*("`@("\J
M*@H@("`@*B!014%2($1"(&1S;B!T;R!U<V4N"B`@("`J"B`@("`J($!V87(@
M('-T<FEN9PH@("`@*B\*("`@('9A<B`D9'-N(#T@)R<["@H@("`@+RHJ"B`@
M("`J(%!%05(@1$(@;V)J96-T"B`@("`J"B`@("`J($!V87(@(&]B:F5C="!0
M14%27T1""B`@("`J+PH@("`@=F%R("1D8CL*"B`@("!F=6YC=&EO;B!#86-H
M95]#;VYT86EN97)?9&(H)&]P=&EO;G,I"B`@("!["B`@("`@("`@:68@*"%I
M<U]A<G)A>2@D;W!T:6]N<RD@?'P@(6ES<V5T*"1O<'1I;VYS6R=D<VXG72DI
M('L*("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G3F\@9'-N
M('-P96-I9FEE9"$G+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*
M"B`@("`@("`@)'1H:7,M/G-E=$]P=&EO;G,H)&]P=&EO;G,L("!A<G)A>5]M
M97)G92@D=&AI<RT^86QL;W=E9%]O<'1I;VYS+"!A<G)A>2@G9'-N)RP@)V-A
M8VAE7W1A8FQE)RDI*3L*"B`@("`@("`@:68@*"$D=&AI<RT^9'-N*0H@("`@
M("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*"=.;R!D<VX@<W!E8VEF
M:65D(2<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["@H@("`@("`@("1T:&ES+3YD
M8B`]($1".CIC;VYN96-T*"1T:&ES+3YD<VXL('1R=64I.PH@("`@("`@(&EF
M("A$0CHZ:7-%<G)O<B@D=&AI<RT^9&(I*2!["B`@("`@("`@("`@(')E='5R
M;B!N97<@0V%C:&5?17)R;W(H)T1".CIC;VYN96-T(&9A:6QE9#H@)R`N($1"
M.CIE<G)O<DUE<W-A9V4H)'1H:7,M/F1B*2P@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^9&(M/G-E
M=$9E=&-H36]D92A$0E]&151#2$U/1$5?05-33T,I.PH@("`@("`@('T*("`@
M('T*"B`@("!F=6YC=&EO;B!F971C:"@D:60L("1G<F]U<"D*("`@('L*("`@
M("`@("`D<75E<GD@/2!S<')I;G1F*")314Q%0U0@8V%C:&5D871A+"!U<V5R
M9&%T82P@97AP:7)E<R!&4D]-("5S(%=(15)%(&ED(#T@)R5S)R!!3D0@8V%C
M:&5G<F]U<"`]("<E<R<B+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/F-A8VAE7W1A8FQE+`H@("`@("`@("`@("`@("`@("`@("`@("`@861D
M<VQA<VAE<R@D:60I+`H@("`@("`@("`@("`@("`@("`@("`@("`@861D<VQA
M<VAE<R@D9W)O=7`I"B`@("`@("`@("`@("`@("`@("`@("`@("`I.PH*("`@
M("`@("`D<F5S(#T@)'1H:7,M/F1B+3YQ=65R>2@D<75E<GDI.PH*("`@("`@
M("!I9B`H1$(Z.FES17)R;W(H)')E<RDI"B`@("`@("`@("`@(')E='5R;B!N
M97<@0V%C:&5?17)R;W(H)T1".CIQ=65R>2!F86EL960Z("<@+B!$0CHZ97)R
M;W)-97-S86=E*"1R97,I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@("`@
M("`D<F]W(#T@)')E<RT^9F5T8VA2;W<H*3L*("`@("`@("!I9B`H:7-?87)R
M87DH)')O=RDI"B`@("`@("`@("`@("1D871A(#T@87)R87DH)')O=ULG97AP
M:7)E<R==+"`D=&AI<RT^9&5C;V1E*"1R;W=;)V-A8VAE9&%T82==*2P@)')O
M=ULG=7-E<F1A=&$G72D["B`@("`@("`@96QS90H@("`@("`@("`@("`D9&%T
M82`](&%R<F%Y*$Y53$PL($Y53$PL($Y53$PI.PH*("`@("`@("`O+R!L87-T
M('5S960@<F5Q=6ER960@8GD@=&AE(&=A<F)A9V4@8V]L;&5C=&EO;@H@("`@
M("`@("\O(%=!4DY)3D<Z(&UI9VAT(&)E($UY4U%,('-P96-I9FEC"B`@("`@
M("`@)'%U97)Y(#T@<W!R:6YT9B@B55!$051%("5S(%-%5"!C:&%N9V5D(#T@
M*$Y/5R@I("L@,"D@5TA%4D4@:60@/2`G)7,G($%.1"!C86-H96=R;W5P(#T@
M)R5S)R(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8V%C
M:&5?=&%B;&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A9&1S;&%S
M:&5S*"1I9"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A9&1S;&%S
M:&5S*"1G<F]U<"D*("`@("`@("`@("`@("`@("`@("`@("`@("`I.PH*("`@
M("`@("`D<F5S(#T@)'1H:7,M/F1B+3YQ=65R>2@D<75E<GDI.PH*("`@("`@
M("!I9B`H1$(Z.FES17)R;W(H)')E<RDI"B`@("`@("`@("`@(')E='5R;B!N
M97<@0V%C:&5?17)R;W(H)T1".CIQ=65R>2!F86EL960Z("<@+B!$0CHZ97)R
M;W)-97-S86=E*"1R97,I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@("`@
M("!R971U<FX@)&1A=&$["B`@("!]"@H@("`@+RHJ"B`@("`J(%-T;W)E<R!A
M(&1A=&%S970N"B`@("`J"B`@("`J(%=!4DY)3D<Z('=E('5S92!T:&4@4U%,
M(&-O;6UA;F0@4D503$%#12!)3E1/('1H:7,@;6EG:'0@8F4*("`@("H@37E3
M44P@<W!E8VEF:6,N($%S($UY4U%,(&ES('9E<GD@<&]P=6QA<B!T:&4@;65T
M:&]D('-H;W5L9`H@("`@*B!W;W)K(&9I;F4@9F]R(#DU)2!O9B!Y;W4N"B`@
M("`J+PH@("`@9G5N8W1I;VX@<V%V92@D:60L("1D871A+"`D97AP:7)E<RP@
M)&=R;W5P+"`D=7-E<F1A=&$I"B`@("!["B`@("`@("`@)'1H:7,M/F9L=7-H
M4')E;&]A9"@D:60L("1G<F]U<"D["@H@("`@("`@("1Q=65R>2`]('-P<FEN
M=&8H(E)%4$Q!0T4@24Y43R`E<R`H=7-E<F1A=&$L(&-A8VAE9&%T82P@97AP
M:7)E<RP@:60L(&-A8VAE9W)O=7`I(%9!3%5%4R`H)R5S)RP@)R5S)RP@)60L
M("<E<R<L("<E<R<I(BP*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YC86-H95]T86)L92P*("`@("`@("`@("`@("`@("`@("`@("`@(&%D9'-L
M87-H97,H)'5S97)D871A*2P*("`@("`@("`@("`@("`@("`@("`@("`@(&%D
M9'-L87-H97,H)'1H:7,M/F5N8V]D92@D9&%T82DI+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YG971%>'!I<F5S06)S;VQU=&4H)&5X<&ER
M97,I("P*("`@("`@("`@("`@("`@("`@("`@("`@(&%D9'-L87-H97,H)&ED
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@(&%D9'-L87-H97,H)&=R;W5P
M*0H@("`@("`@("`@("`@("`@("`@("`@("`I.PH*("`@("`@("`D<F5S(#T@
M)'1H:7,M/F1B+3YQ=65R>2@D<75E<GDI.PH*("`@("`@("!I9B`H1$(Z.FES
M17)R;W(H)')E<RDI('L*("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%
M<G)O<B@G1$(Z.G%U97)Y(&9A:6QE9#H@)R`N($1".CIE<G)O<DUE<W-A9V4H
M)')E<RD@+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@('T*
M"B`@("!F=6YC=&EO;B!R96UO=F4H)&ED+"`D9W)O=7`I"B`@("!["B`@("`@
M("`@)'1H:7,M/F9L=7-H4')E;&]A9"@D:60L("1G<F]U<"D["@H@("`@("`@
M("1Q=65R>2`]('-P<FEN=&8H(D1%3$5412!&4D]-("5S(%=(15)%(&ED(#T@
M)R5S)R!A;F0@8V%C:&5G<F]U<"`]("<E<R<B+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/F-A8VAE7W1A8FQE+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@861D<VQA<VAE<R@D:60I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@861D<VQA<VAE<R@D9W)O=7`I"B`@("`@("`@("`@("`@("`@("`@
M("`@("D["@H@("`@("`@("1R97,@/2`D=&AI<RT^9&(M/G%U97)Y*"1Q=65R
M>2D["@H@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S*2D*("`@("`@("`@
M("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G1$(Z.G%U97)Y(&9A:6QE9#H@
M)R`N($1".CIE<G)O<DUE<W-A9V4H)')E<RDL(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["B`@("!]"@H@("`@9G5N8W1I;VX@9FQU<V@H)&=R;W5P(#T@)R<I"B`@
M("!["B`@("`@("`@)'1H:7,M/F9L=7-H4')E;&]A9"@I.PH*("`@("`@("`@
M:68@*"1G<F]U<"D@>PH@("`@("`@("`@("`D<75E<GD@/2!S<')I;G1F*")$
M14Q%5$4@1E)/32`E<R!72$5212!C86-H96=R;W5P(#T@)R5S)R(L("1T:&ES
M+3YC86-H95]T86)L92P@861D<VQA<VAE<R@D9W)O=7`I*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D<75E<GD@/2!S<')I;G1F*")$14Q%5$4@
M1E)/32`E<R(L("1T:&ES+3YC86-H95]T86)L92D["B`@("`@("`@?0H*("`@
M("`@("`D<F5S(#T@)'1H:7,M/F1B+3YQ=65R>2@D<75E<GDI.PH*("`@("`@
M("!I9B`H1$(Z.FES17)R;W(H)')E<RDI"B`@("`@("`@("`@(')E='5R;B!N
M97<@0V%C:&5?17)R;W(H)T1".CIQ=65R>2!F86EL960Z("<@+B!$0CHZ97)R
M;W)-97-S86=E*"1R97,I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&ED17AI<W1S*"1I9"P@)&=R;W5P*0H@("`@>PH@("`@
M("`@("1Q=65R>2`]('-P<FEN=&8H(E-%3$5#5"!I9"!&4D]-("5S(%=(15)%
M($E$(#T@)R5S)R!!3D0@8V%C:&5G<F]U<"`]("<E<R<B+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/F-A8VAE7W1A8FQE+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@861D<VQA<VAE<R@D:60I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@861D<VQA<VAE<R@D9W)O=7`I"B`@("`@("`@("`@("`@
M("`@("`@("`@("D["@H@("`@("`@("1R97,@/2`D=&AI<RT^9&(M/G%U97)Y
M*"1Q=65R>2D["@H@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S*2D*("`@
M("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G1$(Z.G%U97)Y(&9A
M:6QE9#H@)R`N($1".CIE<G)O<DUE<W-A9V4H)')E<RDL(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["@H@("`@("`@("1R;W<@/2`D<F5S+3YF971C:%)O=R@I.PH*
M("`@("`@("!I9B`H:7-?87)R87DH)')O=RDI('L*("`@("`@("`@("`@<F5T
M=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!G87)B86=E
M0V]L;&5C=&EO;B@D;6%X;&EF971I;64I"B`@("!["B`@("`@("`@)'1H:7,M
M/F9L=7-H4')E;&]A9"@I.PH*("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=$
M14Q%5$4@1E)/32`E<R!72$5212`H97AP:7)E<R`\/2`E9"!!3D0@97AP:7)E
M<R`^(#`I($]2(&-H86YG960@/#T@)60G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/F-A8VAE7W1A8FQE+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@=&EM92@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@=&EM92@I
M("T@)&UA>&QI9F5T:6UE"B`@("`@("`@("`@("`@("`@("`@("`@*3L*"B`@
M("`@("`@)')E<R`]("1T:&ES+3YD8BT^<75E<GDH)'%U97)Y*3L*"B`@("`@
M("`@)'%U97)Y(#T@<W!R:6YT9B@G<V5L96-T('-U;2AL96YG=&@H8V%C:&5D
M871A*2D@87,@0V%C:&53:7IE(&9R;VT@)7,G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/F-A8VAE7W1A8FQE"B`@("`@("`@("`@("`@("`@
M("`@("`@*3L*("`@("`@("`D8V%C:&5S:7IE(#T@)'1H:7,M/F1B+3Y'971/
M;F4H)'%U97)Y*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)&-A8VAE<VEZ
M92DI('L*("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G1$(Z
M.G%U97)Y(&9A:6QE9#H@)R`N($1".CIE<G)O<DUE<W-A9V4H)&-A8VAE<VEZ
M92DL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("`O
M+VEF(&-A8VAE(&ES('1O(&)I9RX*("`@("`@("!I9B`H)&-A8VAE<VEZ92`^
M("1T:&ES+3YH:6=H=V%T97(I"B`@("`@("`@>PH@("`@("`@("`@("`O+V9I
M;F0@=&AE(&QO=W=A=&5R(&UA<FLN"B`@("`@("`@("`@("1Q=65R>2`]('-P
M<FEN=&8H)W-E;&5C="!L96YG=&@H8V%C:&5D871A*2!A<R!S:7IE+"!C:&%N
M9V5D(&9R;VT@)7,@;W)D97(@8GD@8VAA;F=E9"!$15-#)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC86-H95]T86)L
M90H@("`@("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@("`@("1R97,@
M/2`D=&AI<RT^9&(M/G%U97)Y*"1Q=65R>2D["B`@("`@("`@("`@(&EF("A$
M0CHZ:7-%<G)O<B@D<F5S*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&YE
M=R!#86-H95]%<G)O<B@G1$(Z.G%U97)Y(&9A:6QE9#H@)R`N($1".CIE<G)O
M<DUE<W-A9V4H)')E<RDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("1N=6UR;W=S(#T@)'1H:7,M/F1B+3YN=6U2
M;W=S*"1R97,I.PH@("`@("`@("`@("`D:V5E<%]S:7IE(#T@,#L*("`@("`@
M("`@("`@=VAI;&4@*"1K965P7W-I>F4@/"`D=&AI<RT^;&]W=V%T97(@)B8@
M)&YU;7)O=W,M+2D@>PH@("`@("`@("`@("`@("`@)&5N=')Y(#T@)')E<RT^
M9F5T8VA2;W<H1$)?1D540TA-3T1%7T%34T]#*3L*("`@("`@("`@("`@("`@
M("1K965P7W-I>F4@*ST@)&5N=')Y6R=S:7IE)UT["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("\O9&5L971E(&%L;"!E;G1R:65S+"!W:&EC:"!W97)E
M(&-H86YG960@8F5F;W)E('1H92`B;&]W=W=A=&5R(&UA<FLB"B`@("`@("`@
M("`@("1Q=65R>2`]('-P<FEN=&8H)V1E;&5T92!F<F]M("5S('=H97)E(&-H
M86YG960@/#T@)RXH)&5N=')Y6R=C:&%N9V5D)UT@/R`D96YT<GE;)V-H86YG
M960G72`Z(#`I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/F-A8VAE7W1A8FQE"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@*3L*("`@("`@("`@("`@)')E<R`]("1T:&ES+3YD8BT^
M<75E<GDH)'%U97)Y*3L*("`@("`@("!]"@H@("`@("`@(&EF("A$0CHZ:7-%
M<G)O<B@D<F5S*2D@>PH@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R
M<F]R*"=$0CHZ<75E<GD@9F%I;&5D.B`G("X@1$(Z.F5R<F]R365S<V%G92@D
M<F5S*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@("!]"@I]
M"C\^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]#86-H92]#;VYT86EN97(O;61B+G!H<```````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#,S,C$T(#$P-3$U-#,S-S(W(#`R
M,C8W-``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!0
M14%2(#HZ($-A8VAE(#HZ($U$0B!#;VYT86EN97(@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!0
M2%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@
M9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP(&]F('1H92!02%`@;&EC
M96YS92P@("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@
M<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*
M+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@
M870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@
M82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@
M('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L
M('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS
M94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E
M;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!.;W1E.B!4:&ES(&ES(&$@341"+6]R:65N=&5D(')E=W)I
M=&4@;V8@0V%C:&4O0V]N=&%I;F5R+V1B+G!H<"X@("`@("!\"B\O('P@5&AA
M;FMS('1O($QU:V%S(%-M:71H(&9O<B!H:7,@<&%T:65N8V4@:6X@86YS=V5R
M:6YG(&UY('%U97-T:6]N<R`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!!=71H;W(Z($QO<F5N>F\@06QB97)T;VX@/&PN86QB
M97)T;VX@870@<75I<&\N:70^("`@("`@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z(&UD8BYP:'`L
M=B`Q+C,@,C`P,R\P,2\P-"`Q,3HU-#HT-B!M:B!%>'`@)`H*<F5Q=6ER95]O
M;F-E("=-1$(N<&AP)SL*<F5Q=6ER95]O;F-E("=#86-H92]#;VYT86EN97(N
M<&AP)SL*"B\J*@HJ(%!%05(O341"($-A8VAE($-O;G1A:6YE<BX**@HJ($Y"
M.B!4:&4@9FEE;&0@)V-H86YG960G(&AA<R!N;R!M96%N:6YG(&9O<B!T:&4@
M0V%C:&4@:71S96QF+B!)="=S(&IU<W0@=&AE<F4**B!B96-A=7-E(&ET)W,@
M82!G;V]D(&ED96$@=&\@:&%V92!A;B!A=71O;6%T:6-A;&QY('5P9&%T960@
M=&EM97-T86UP"BH@9FEE;&0@9F]R(&1E8G5G9VEN9R!I;B!A;&P@;V8@>6]U
M<B!T86)L97,N"BH**B!!(%A-3"!-1$(M8V]M<&QI86YT('-C:&5M82!E>&%M
M<&QE(&9O<B!T:&4@=&%B;&4@;F5E9&5D(&ES('!R;W9I9&5D+@HJ($QO;VL@
M870@=&AE(&9I;&4@(FUD8E]C86-H95]S8VAE;6$N>&UL(B!F;W(@=&AA="X*
M*@HJ("TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+0HJ($$@8F%S:6,@=7-A9V4@97AA;7!L93H**B`M+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T**@HJ("1D8FEN9F\@/2!A<G)A
M>2@**B`@("=D871A8F%S92<@("`@/3X@)V1B;F%M92<L"BH@("`G<&AP='EP
M92<@("`@(#T^("=M>7-Q;"<L"BH@("`G=7-E<FYA;64G("`@(#T^("=R;V]T
M)RP**B`@("=P87-S=V]R9"<@("`@/3X@)R<L"BH@("`G8V%C:&5?=&%B;&4G
M(#T^("=C86-H92<**B`I.PHJ"BH**B`D8V%C:&4@/2!N97<@0V%C:&4H)VUD
M8B<L("1D8FEN9F\I.PHJ("1I9"`]("1C86-H92T^9V5N97)A=&5)1"@G=&5S
M=&5N=')Y)RD["BH**B!I9B`H)&1A=&$@/2`D8V%C:&4M/F=E="@D:60I*2![
M"BH@("`@96-H;R`G0V%C:&4@:&ET+CQB<B`O/D1A=&$Z("<N)&1A=&$["BH*
M*B!](&5L<V4@>PHJ("`@)&1A=&$@/2`G9&%T82!O9B!A;GD@:VEN9"<["BH@
M("`D8V%C:&4M/G-A=F4H)&ED+"`D9&%T82D["BH@("!E8VAO("=#86-H92!M
M:7-S+CQB<B`O/B<["BH@?0HJ"BH@+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM"BH**B!`875T:&]R("`@3&]R96YZ;R!!;&)E
M<G1O;B`\;"YA;&)E<G1O;B!A="!Q=6EP;RYI=#X**B!`=F5R<VEO;B`@)$ED
M.B!M9&(N<&AP+'8@,2XS(#(P,#,O,#$O,#0@,3$Z-30Z-#8@;6H@17AP("0*
M*B!`<&%C:V%G92`@0V%C:&4**B\*8VQA<W,@0V%C:&5?0V]N=&%I;F5R7VUD
M8B!E>'1E;F1S($-A8VAE7T-O;G1A:6YE<B!["@H@("`@+RHJ"B`@("`@*B!.
M86UE(&]F('1H92!-1$(@=&%B;&4@=&\@<W1O<F4@8V%C:&EN9R!D871A"B`@
M("`@*@H@("`@("H@0'-E92`@0V%C:&5?0V]N=&%I;F5R7V9I;&4Z.B1F:6QE
M;F%M95]P<F5F:7@*("`@("`J+PH@("`@=F%R("1C86-H95]T86)L92`]("<G
M.PH*("`@("\J*@H@("`@("H@4$5!4B!-1$(@;V)J96-T"B`@("`@*@H@("`@
M("H@0'9A<B`@;V)J96-T(%!%05)?341""B`@("`@*B\*("`@('9A<B`D9&([
M"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("H*("`@("`J($!P
M87)A;2!M:7AE9"!!<G)A>2!W:71H(&-O;FYE8W1I;VX@:6YF;R!O<B!D<VX@
M<W1R:6YG"B`@("`@*B\*("`@(&9U;F-T:6]N($-A8VAE7T-O;G1A:6YE<E]M
M9&(H)&]P=&EO;G,I"B`@("!["B`@("`@("`@)'1H:7,M/F1B(#T@)DU$0CHZ
M0V]N;F5C="@D;W!T:6]N<RD["B`@("`@("`@:68H341".CII<T5R<F]R*"1T
M:&ES+3YD8BDI('L*("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R
M*"=-1$(Z.F-O;FYE8W0@9F%I;&5D.B`G"B`@("`@("`@("`@("`@("`@("`@
M+B`D=&AI<RT^9&(M/F=E=$UE<W-A9V4H*2P@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^9&(M/G-E
M=$9E=&-H36]D92A-1$)?1D540TA-3T1%7T%34T]#*3L*("`@("`@("!]"B`@
M("`@("`@)'1H:7,M/G-E=$]P=&EO;G,H)&]P=&EO;G,L(&%R<F%Y7VUE<F=E
M*"1T:&ES+3YA;&QO=V5D7V]P=&EO;G,L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)V1S;B<L("=C86-H95]T86)L
M92<I*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&971C:"!I;B!T:&4@9&(@
M=&AE(&1A=&$@=&AA="!M871C:&5S(&EN<'5T('!A<F%M971E<G,*("`@("`J
M"B`@("`@*B!`<&%R86T@("`@<W1R:6YG("!D871A<V5T($E$"B`@("`@*B!`
M<&%R86T@("`@<W1R:6YG("!C86-H92!G<F]U<`H@("`@("H@0')E='5R;B`@
M(&UI>&5D("`@9&%T87-E="!V86QU92!O<B!.54Q,+T-A8VAE7T5R<F]R(&]N
M(&9A:6QU<F4*("`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@9F5T8V@H)&ED+"`D9W)O=7`I"B`@("!["B`@("`@("`@)'%U
M97)Y(#T@)U-%3$5#5"!C86-H961A=&$@1E)/32`G("X@)'1H:7,M/F-A8VAE
M7W1A8FQE"B`@("`@("`@("`@("`@("`N)R!72$5212!I9#TG("`@("`@("X@
M)'1H:7,M/F1B+3YG971497AT5F%L=64H)&ED*0H@("`@("`@("`@("`@("`@
M+B<@04Y$(&-A8VAE9W)O=7`])R`N("1T:&ES+3YD8BT^9V5T5&5X=%9A;'5E
M*"1G<F]U<"D["B`@("`@("`@:68H)')E<R`]("1T:&ES+3YD8BT^<75E<GDH
M)'%U97)Y*2D@>PH@("`@("`@("`@("!I9B@D=&AI<RT^9&(M/F5N9$]F4F5S
M=6QT*"1R97,I*2!["B`@("`@("`@("`@("`@("`O+VYO(')O=W,@<F5T=7)N
M960*("`@("`@("`@("`@("`@("1D871A(#T@87)R87DH3E5,3"P@3E5,3"P@
M3E5,3"D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M8VQO8B`]("1T:&ES+3YD8BT^9F5T8VA#;&]B*"1R97,L,"PG8V%C:&5D871A
M)RD["B`@("`@("`@("`@("`@("!I9B@A341".CII<T5R<F]R*"1C;&]B*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1C86-H961?9&%T82`]("<G.PH@("`@
M("`@("`@("`@("`@("`@('=H:6QE*"$D=&AI<RT^9&(M/F5N9$]F3$]"*"1C
M;&]B*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!I9BA-1$(Z.FES17)R
M;W(H)&5R<F]R(#T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/F1B+3YR96%D3&]B*"1C;&]B+"1D871A+#@P,#`I/#`I*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE
M7T5R<F]R*"=-1$(Z.G%U97)Y(&9A:6QE9#H@)PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`N("1E<G)O<BT^9V5T365S<V%G92@I+"!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@("`@("1C86-H961?9&%T82`N/2`D9&%T
M83L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M=6YS970H)&1A=&$I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YD8BT^
M9&5S=')O>4QO8B@D8VQO8BD["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/F1B+3YF<F5E4F5S=6QT*"1R97,I.PH*("`@("`@("`@("`@("`@("`@("`O
M+V9I;FES:&5D(&9E=&-H:6YG($Q/0BP@;F]W(&9E=&-H(&]T:&5R(&9I96QD
M<RXN+@H@("`@("`@("`@("`@("`@("`@("1Q=65R>2`]("=314Q%0U0@=7-E
M<F1A=&$L(&5X<&ER97,@1E)/32`G("X@)'1H:7,M/F-A8VAE7W1A8FQE"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`N)R!72$5212!I9#TG("`@("`@
M("X@)'1H:7,M/F1B+3YG971497AT5F%L=64H)&ED*0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+B<@04Y$(&-A8VAE9W)O=7`])R`N("1T:&ES+3YD
M8BT^9V5T5&5X=%9A;'5E*"1G<F]U<"D["B`@("`@("`@("`@("`@("`@("`@
M:68H)')E<R`]("1T:&ES+3YD8BT^<75E<GDH)'%U97)Y*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D<F]W(#T@)'1H:7,M/F1B+3YF971C:$EN=&\H
M)')E<RD["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D
M<F]W*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&$@/2!A
M<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1R;W=;)V5X<&ER97,G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YD96-O9&4H)&-A8VAE9%]D871A*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R;W=;)W5S
M97)D871A)UT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1D871A(#T@87)R87DH3E5,3"P@3E5,3"P@
M3E5,3"D["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D9&%T
M82`](&%R<F%Y*$Y53$PL($Y53$PL($Y53$PI.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G341".CIQ=65R>2!F86EL
M960Z("<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("1C;&]B+3YG
M971-97-S86=E*"DL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/F1B+3YF
M<F5E4F5S=6QT*"1R97,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("\O<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G341".CIQ=65R>2!F86EL960Z
M("<*("`@("`@("`@("`@+R\@("`@("`@("`@+B`D<F5S=6QT+3YG971-97-S
M86=E*"DL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@("1D871A
M(#T@87)R87DH3E5,3"P@3E5,3"P@3E5,3"D["B`@("`@("`@?0H*("`@("`@
M("`O+R!L87-T('5S960@<F5Q=6ER960@8GD@=&AE(&=A<F)A9V4@8V]L;&5C
M=&EO;@H@("`@("`@("1Q=65R>2`]("=54$1!5$4@)R`@("`@("`@("`N("1T
M:&ES+3YC86-H95]T86)L90H@("`@("`@("`@("`@("`@+B<@4T54(&-H86YG
M960])R`@("`N('1I;64H*0H@("`@("`@("`@("`@("`@+B<@5TA%4D4@:60]
M)R`@("`@("`N("1T:&ES+3YD8BT^9V5T5&5X=%9A;'5E*"1I9"D*("`@("`@
M("`@("`@("`@("XG($%.1"!C86-H96=R;W5P/2<@+B`D=&AI<RT^9&(M/F=E
M=%1E>'1686QU92@D9W)O=7`I.PH*("`@("`@("`D<F5S(#T@)'1H:7,M/F1B
M+3YQ=65R>2@D<75E<GDI.PH@("`@("`@(&EF("A-1$(Z.FES17)R;W(H)')E
M<RDI('L*("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G341"
M.CIQ=65R>2!F86EL960Z("<*("`@("`@("`@("`@("`@("X@)'1H:7,M/F1B
M+3YE<G)O<DUE<W-A9V4H)')E<RDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D9&%T83L*("`@('T*"B`@("\J*@H@
M("`@("H@4W1O<F5S(&$@9&%T87-E="!I;B!T:&4@9&%T86)A<V4*("`@("`J
M"B`@("`@*B!)9B!D871A<V5T7TE$(&%L<F5A9'D@97AI<W1S+"!O=F5R=W)I
M=&4@:70@=VET:"!N97<@9&%T82P*("`@("`J(&5L<V4@:6YS97)T(&1A=&$@
M:6X@82!N97<@<F5C;W)D+@H@("`@("H*("`@("`J($!P87)A;2`@("!S=')I
M;F<@(&1A=&%S970@240*("`@("`J($!P87)A;2`@("!M:7AE9"`@(&1A=&$@
M=&\@8F4@8V%C:&5D"B`@("`@*B!`<&%R86T@("`@:6YT96=E<B!E>'!I<F%T
M:6]N('1I;64*("`@("`J($!P87)A;2`@("!S=')I;F<@(&-A8VAE(&=R;W5P
M"B`@("`@*B!`<&%R86T@("`@<W1R:6YG("!U<V5R9&%T80H@("`@("H@0&%C
M8V5S<R`@('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!S879E*"1I9"P@
M)&1A=&$L("1E>'!I<F5S+"`D9W)O=7`L("1U<V5R9&%T82D*("`@('L*("`@
M("`@("!G;&]B86P@)&1B.PH@("`@("`@("1T:&ES+3YF;'5S:%!R96QO860H
M)&ED+"`D9W)O=7`I.PH*("`@("`@("`D9FEE;&1S(#T@87)R87DH"B`@("`@
M("`@("`@("=I9"<@("`@("`@(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)U1Y<&4G("`@/3X@)W1E>'0G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)U9A;'5E)R`@/3X@)&ED+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)TME>2<@("`@/3X@=')U90H@("`@("`@("`@("`@
M("`@("`@("`@("`I+`H@("`@("`@("`@("`G=7-E<F1A=&$G("`]/B!A<G)A
M>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=4>7!E)R`@(#T^("=I
M;G1E9V5R)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=686QU92<@
M(#T^("1U<V5R9&%T82P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=.
M=6QL)R`@(#T^("@D=7-E<F1A=&$@/R!F86QS92`Z('1R=64I"B`@("`@("`@
M("`@("`@("`@("`@("`@("DL"B`@("`@("`@("`@("=E>'!I<F5S)R`@(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U1Y<&4G("`@
M/3X@)VEN=&5G97(G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U9A
M;'5E)R`@/3X@)'1H:7,M/F=E=$5X<&ER97-!8G-O;'5T92@D97AP:7)E<RD*
M("`@("`@("`@("`@("`@("`@("`@("`@*2P*("`@("`@("`@("`@)V-A8VAE
M9W)O=7`G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)U1Y<&4G("`@/3X@)W1E>'0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)U9A;'5E)R`@/3X@)&=R;W5P"B`@("`@("`@("`@("`@("`@("`@("`@
M("D*("`@("`@("`@("`@*3L*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3YD
M8BT^<F5P;&%C92@D=&AI<RT^8V%C:&5?=&%B;&4L("1F:65L9',I.PH*("`@
M("`@("!I9BA-1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@
M+R]687)?1'5M<#HZ9&ES<&QA>2@D<F5S=6QT*3L*("`@("`@("`@("`@<F5T
M=7)N(&YE=R!#86-H95]%<G)O<B@G341".CIQ=65R>2!F86EL960Z("<*("`@
M("`@("`@("`@("`@("`@("`N("1T:&ES+3YD8BT^97)R;W)-97-S86=E*"1R
M97-U;'0I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@("`@
M("!U;G-E="@D9FEE;&1S*3L@+R]E;F0@9FER<W0@<&%R="!O9B!Q=65R>0H@
M("`@("`@("1Q=65R>3(@/2`G55!$051%("<@("`N("1T:&ES+3YC86-H95]T
M86)L90H@("`@("`@("`@("`@("`@("XG(%-%5"!C86-H961A=&$]/R<*("`@
M("`@("`@("`@("`@("`N)R!72$5212!I9#TG+B`D=&AI<RT^9&(M/F=E=%1E
M>'1686QU92@D:60I.PH*("`@("`@("!I9B@H)'!R97!A<F5D7W%U97)Y(#T@
M)'1H:7,M/F1B+3YP<F5P87)E475E<GDH)'%U97)Y,BDI*2!["B`@("`@("`@
M("`@("1C:&%R7VQO8B`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)T5R<F]R)R`]/B`G)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=4>7!E)R`]/B`G9&%T82<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G1&%T82<@/3X@)'1H:7,M/F5N8V]D92@D9&%T82D*("`@("`@("`@
M("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@:68H(4U$0CHZ:7-%<G)O
M<B@D8VQO8B`]("1T:&ES+3YD8BT^8W)E871E3&]B*"1C:&%R7VQO8BDI*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^9&(M/G-E=%!A<F%M0VQO8B@D<')E
M<&%R961?<75E<GDL,2PD8VQO8BPG8V%C:&5D871A)RD["B`@("`@("`@("`@
M("`@("!I9BA-1$(Z.FES17)R;W(H)&5R<F]R/21T:&ES+3YD8BT^97AE8W5T
M95%U97)Y*"1P<F5P87)E9%]Q=65R>2DI*2!["B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G341".CIQ=65R>2!F86EL960Z
M("<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)&5R<F]R+3YG971-
M97-S86=E*"D@+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)'1H:7,M/F1B+3YD97-T<F]Y3&]B*"1C
M;&]B*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("\O
M(&-R96%T:6]N(&]F('1H92!H86YD;&5R(&]B:F5C="!F86EL960*("`@("`@
M("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H)TU$0CHZ<75E<GD@
M9F%I;&5D.B`G"B`@("`@("`@("`@("`@("`@("`@("`@("X@)&-L;V(M/F=E
M=$UE<W-A9V4H*2`L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)'1H:7,M/F1B+3YF<F5E4')E<&%R9611=65R>2@D
M<')E<&%R961?<75E<GDI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("\O<')E<&%R960@<75E<GD@9F%I;&5D"B`@("`@("`@("`@(')E='5R;B!N
M97<@0V%C:&5?17)R;W(H)TU$0CHZ<75E<GD@9F%I;&5D.B`G"B`@("`@("`@
M("`@("`@("`@("`@+B`D<')E<&%R961?<75E<GDM/F=E=$UE<W-A9V4H*2`L
M(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@4F5M;W9E<R!A(&1A=&%S970@9G)O;2!T:&4@9&%T86)A<V4*
M("`@("`J"B`@("`@*B!`<&%R86T@("`@<W1R:6YG("!D871A<V5T($E$"B`@
M("`@*B!`<&%R86T@("`@<W1R:6YG("!C86-H92!G<F]U<`H@("`@("HO"B`@
M("!F=6YC=&EO;B!R96UO=F4H)&ED+"`D9W)O=7`I"B`@("!["B`@("`@("`@
M)'1H:7,M/F9L=7-H4')E;&]A9"@D:60L("1G<F]U<"D["@H@("`@("`@("1Q
M=65R>2`]("=$14Q%5$4@1E)/32`G("`@("`N("1T:&ES+3YC86-H95]T86)L
M90H@("`@("`@("`@("`@("`@+B<@5TA%4D4@:60])R`@("`@("`N("1T:&ES
M+3YD8BT^9V5T5&5X=%9A;'5E*"1I9"D*("`@("`@("`@("`@("`@("XG($%.
M1"!C86-H96=R;W5P/2<@+B`D=&AI<RT^9&(M/F=E=%1E>'1686QU92@D9W)O
M=7`I.PH*("`@("`@("`D<F5S(#T@)'1H:7,M/F1B+3YQ=65R>2@D<75E<GDI
M.PH@("`@("`@(&EF("A-1$(Z.FES17)R;W(H)')E<RDI('L*("`@("`@("`@
M("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G341".CIQ=65R>2!F86EL960Z
M("<*("`@("`@("`@("`@("`@("`@("`N("1T:&ES+3YD8BT^97)R;W)-97-S
M86=E*"1R97,I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E;6]V92!A;&P@8V%C:&5D(&1A=&$@9F]R
M(&$@8V5R=&%I;B!G<F]U<"P@;W(@96UP='D*("`@("`J('1H92!C86-H92!T
M86)L92!I9B!N;R!G<F]U<"!I<R!S<&5C:69I960N"B`@("`@*@H@("`@("H@
M0'!A<F%M("`@('-T<FEN9R`@8V%C:&4@9W)O=7`*("`@("`J+PH@("`@9G5N
M8W1I;VX@9FQU<V@H)&=R;W5P(#T@)R<I"B`@("!["B`@("`@("`@)'1H:7,M
M/F9L=7-H4')E;&]A9"@I.PH*("`@("`@("!I9B`H)&=R;W5P*2!["B`@("`@
M("`@("`@("1Q=65R>2`]("=$14Q%5$4@1E)/32`G("`@("`@("X@)'1H:7,M
M/F-A8VAE7W1A8FQE"B`@("`@("`@("`@("`@("`@("`@+B<@5TA%4D4@8V%C
M:&5G<F]U<#TG("X@)'1H:7,M/F1B+3YG971497AT5F%L=64H)&=R;W5P*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<75E<GD@/2`G1$5,151%
M($923TT@)R`N("1T:&ES+3YC86-H95]T86)L93L*("`@("`@("!]"@H@("`@
M("`@("1R97,@/2`D=&AI<RT^9&(M/G%U97)Y*"1Q=65R>2D["B`@("`@("`@
M:68@*$U$0CHZ:7-%<G)O<B@D<F5S*2D@>PH@("`@("`@("`@("!R971U<FX@
M;F5W($-A8VAE7T5R<F]R*"=-1$(Z.G%U97)Y(&9A:6QE9#H@)PH@("`@("`@
M("`@("`@("`@+B`D=&AI<RT^9&(M/F5R<F]R365S<V%G92@D<F5S*2P@7U]&
M24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#:&5C:R!I9B!A(&1A=&%S970@240O9W)O=7`@97AI<W1S+@H@("`@
M("H*("`@("`J($!P87)A;2`@("!S=')I;F<@(&1A=&%S970@240*("`@("`J
M($!P87)A;2`@("!S=')I;F<@(&-A8VAE(&=R;W5P"B`@("`@*B!`<F5T=7)N
M("`@8F]O;&5A;@H@("`@("HO"B`@("!F=6YC=&EO;B!I9$5X:7-T<R@D:60L
M("1G<F]U<"D*("`@('L*("`@("`@("`D<75E<GD@/2`G4T5,14-4(&ED($92
M3TT@)R`@+B`D=&AI<RT^8V%C:&5?=&%B;&4*("`@("`@("`@("`@("`@("XG
M(%=(15)%(&ED/2<@("`@("`@+B`D=&AI<RT^9&(M/F=E=%1E>'1686QU92@D
M:60I"B`@("`@("`@("`@("`@("`N)R!!3D0@8V%C:&5G<F]U<#TG("X@)'1H
M:7,M/F1B+3YG971497AT5F%L=64H)&=R;W5P*3L*("`@("`@("!E8VAO("1Q
M=65R>3L*("`@("`@("`D<F5S(#T@)'1H:7,M/F1B+3YQ=65R>2@D<75E<GDI
M.PH@("`@("`@(&EF("A-1$(Z.FES17)R;W(H)')E<RDI('L*("`@("`@("`@
M("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G341".CIQ=65R>2!F86EL960Z
M("<*("`@("`@("`@("`@("`@("`@("`N("1T:&ES+3YD8BT^97)R;W)-97-S
M86=E*"1R97,I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@
M("`@("`D<F]W(#T@)'1H:7,M/F1B+3YF971C:$EN=&\H)')E<RD["@H@("`@
M("`@(&EF("AI<U]A<G)A>2@D<F]W*2D@>PH@("`@("`@("`@("!R971U<FX@
M=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1V%R8F%G92!C
M;VQL96-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M("`@(&EN="!M87AL:69E
M=&EM90H@("`@("HO"B`@("!F=6YC=&EO;B!G87)B86=E0V]L;&5C=&EO;B@D
M;6%X;&EF971I;64I"B`@("!["B`@("`@("`@)'1H:7,M/F9L=7-H4')E;&]A
M9"@I.PH@("`@("`@("1Q=65R>2`]("=$14Q%5$4@1E)/32`G("`@("`@("`N
M("1T:&ES+3YC86-H95]T86)L90H@("`@("`@("`@("`@("`@+B<@5TA%4D4@
M*&5X<&ER97,@/#T@)R`N('1I;64H*0H@("`@("`@("`@("`@("`@+B<@04Y$
M(&5X<&ER97,@/B`P*2!/4B!C:&%N9V5D(#P]("<N('1I;64H*2`M("1M87AL
M:69E=&EM93L*"B`@("`@("`@)')E<R`]("1T:&ES+3YD8BT^<75E<GDH)'%U
M97)Y*3L*"B`@("`@("`@)'%U97)Y(#T@)U-%3$5#5"!S=6TH;&5N9W1H*&-A
M8VAE9&%T82DI(&%S($-A8VAE4VEZ92!&4D]-("<*("`@("`@("`@("`@("`@
M("X@)'1H:7,M/F-A8VAE7W1A8FQE.PH*("`@("`@("`D8V%C:&5S:7IE(#T@
M)'1H:7,M/F1B+3YG971/;F4H)'%U97)Y*3L*("`@("`@("!I9B`H341".CII
M<T5R<F]R*"1C86-H97-I>F4I*2!["B`@("`@("`@("`@(')E='5R;B!N97<@
M0V%C:&5?17)R;W(H)TU$0CHZ<75E<GD@9F%I;&5D.B`G"B`@("`@("`@("`@
M("`@("`@("`N("1T:&ES+3YD8BT^97)R;W)-97-S86=E*"1C86-H97-I>F4I
M+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@("`@("`O+VEF
M(&-A8VAE(&ES('1O(&)I9RX*("`@("`@("!I9B`H)&-A8VAE<VEZ92`^("1T
M:&ES+3YH:6=H=V%T97(I"B`@("`@("`@>PH@("`@("`@("`@("`O+V9I;F0@
M=&AE(&QO=W=A=&5R(&UA<FLN"B`@("`@("`@("`@("1Q=65R>2`]("=314Q%
M0U0@;&5N9W1H*&-A8VAE9&%T82D@87,@<VEZ92P@8VAA;F=E9"!&4D]-("<*
M("`@("`@("`@("`@("`@("`@("`N("1T:&ES+3YC86-H95]T86)L92`N)R!/
M4D1%4B!"62!C:&%N9V5D($1%4T,G.PH*("`@("`@("`@("`@)')E<R`]("1T
M:&ES+3YD8BT^<75E<GDH)'%U97)Y*3L*("`@("`@("`@("`@:68@*$U$0CHZ
M:7-%<G)O<B@D<F5S*2D@>PH@("`@("`@("`@("`@("!R971U<FX@;F5W($-A
M8VAE7T5R<F]R*"=-1$(Z.G%U97)Y(&9A:6QE9#H@)PH@("`@("`@("`@("`@
M("`@("`@("X@)'1H:7,M/F1B+3YE<G)O<DUE<W-A9V4H)')E<RDL(%]?1DE,
M15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&YU
M;7)O=W,@/2`D=&AI<RT^9&(M/FYU;5)O=W,H)')E<RD["B`@("`@("`@("`@
M("1K965P7W-I>F4@/2`P.PH@("`@("`@("`@("!W:&EL92`H)&ME97!?<VEZ
M92`\("1T:&ES+3YL;W=W871E<B`F)B`D;G5M<F]W<RTM*2!["B`@("`@("`@
M("`@("`@("`D96YT<GD@/2`D=&AI<RT^9&(M/F9E=&-H26YT;R@D<F5S+$U$
M0E]&151#2$U/1$5?05-33T,I.PH@("`@("`@("`@("`@("`@)&ME97!?<VEZ
M92`K/2`D96YT<GE;)W-I>F4G73L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@+R]D96QE=&4@86QL(&5N=')I97,L('=H:6-H('=E<F4@8VAA;F=E9"!B
M969O<F4@=&AE(")L;W=W871E<B!M87)K(@H@("`@("`@("`@("`D<75E<GD@
M/2`G1$5,151%($923TT@)R`N("1T:&ES+3YC86-H95]T86)L90H@("`@("`@
M("`@("`@("`@("`@("XG(%=(15)%(&-H86YG960\/2<N*"1E;G1R>5LG8VAA
M;F=E9"==(#\@)&5N=')Y6R=C:&%N9V5D)UT@.B`P*3L*"B`@("`@("`@("`@
M("1R97,@/2`D=&AI<RT^9&(M/G%U97)Y*"1Q=65R>2D["B`@("`@("`@("`@
M(&EF("A-1$(Z.FES17)R;W(H)')E<RDI('L*("`@("`@("`@("`@("`@<F5T
M=7)N(&YE=R!#86-H95]%<G)O<B@G341".CIQ=65R>2!F86EL960Z("<*("`@
M("`@("`@("`@("`@("`@("`N("1T:&ES+3YD8BT^97)R;W)-97-S86=E*"1R
M97,I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@?0H*?0H_/@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O0V%C:&4O0V]N=&%I;F5R+V9I;&4N<&AP````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`S,30P-2`Q,#4Q-30S,S<R-R`P,C,P
M-3$`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$5!
M4B`Z.B!#86-H92`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0
M($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I
M;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,"!O9B!T:&4@4$A0(&QI8V5N
M<V4L("`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A
M8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O
M('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@
M8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\
M"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P
M;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`
M<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY
M+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@075T:&]R<SH@56QF(%=E;F1E;"`\=6QF+G=E;F1E;$!P:'!D
M;V,N9&4^("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\("`@("`@
M("`@(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN
M+F1E/B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O"B\O("1)9#H@9FEL92YP:'`L=B`Q+C$S(#(P,#,O,#,O,C<@
M,3`Z-#@Z-#(@8VAR96=U($5X<"`D"@IR97%U:7)E7V]N8V4@)T-A8VAE+T-O
M;G1A:6YE<BYP:'`G.PH*+RHJ"BH@4W1O<F5S(&-A8VAE(&-O;G1E;G1S(&EN
M(&$@9FEL92X**@HJ($!A=71H;W(@("!5;&8@5V5N9&5L("`\=6QF+G=E;F1E
M;$!P:'!D;V,N9&4^"BH@0'9E<G-I;VX@("1)9#H@9FEL92YP:'`L=B`Q+C$S
M(#(P,#,O,#,O,C<@,3`Z-#@Z-#(@8VAR96=U($5X<"`D"BHO"F-L87-S($-A
M8VAE7T-O;G1A:6YE<E]F:6QE(&5X=&5N9',@0V%C:&5?0V]N=&%I;F5R('L*
M"B`@("`O*BH*("`@("H@1FEL92!L;V-K:6YG"B`@("`J"B`@("`J(%=I=&@@
M9FEL92!C;VYT86EN97(L(&ET)W,@<&]S<VEB;&4L('1H870@>6]U(&=E="!C
M;W)R=7!T960*("`@("H@9&%T82UE;G1R:65S('5N9&5R(&)A9"!C:7)C=6US
M=&%N8V5S+B!4:&4@9FEL92!L;V-K:6YG(&UU<W0*("`@("H@:6UP<F]V92!T
M:&ES('!R;V)L96T@8G5T(&ET)W,@97AP97)I;65N=&%L('-T=69F+B!3;R!T
M:&4*("`@("H@9&5F875L="!V86QU92!I<R!F86QS92X@0G5T(&ET('-E96US
M('1O(&=I=F4@9V]O9"!R97-U;'1S"B`@("`J"B`@("`J($!V87(@8F]O;&5A
M;@H@("`@*B\*("`@('9A<B`D9FEL94QO8VMI;F<@/2!F86QS93L*"B`@("`O
M*BH*("`@("H@1&ER96-T;W)Y('=H97)E('1O('!U="!T:&4@8V%C:&4@9FEL
M97,N"B`@("`J"B`@("`J($!V87(@('-T<FEN9R`@36%K92!S=7)E('1O(&%D
M9"!A('1R86EL:6YG('-L87-H"B`@("`J+PH@("`@=F%R("1C86-H95]D:7(@
M/2`G)SL*"B`@("`O*BH*("`@("H@1FEL96YA;64@<')E9FEX(&9O<B!C86-H
M92!F:6QE<RX*("`@("H*("`@("H@66]U(&-A;B!U<V4@=&AE(&9I;&5N86UE
M('!R969I>"!T;R!I;7!L96UE;G0@82`B9&]M86EN(B!B87-E9"!C86-H92!O
M<B!J=7-T"B`@("`J('1O(&=I=F4@=&AE(&9I;&5S(&$@;6]R92!D97-C<FEP
M=&EV92!N86UE+B!4:&4@=V]R9"`B9&]M86EN(B!I<R!B;W)R;V5D(&9R;VT*
M("`@("H@82!U<V5R(&%U=&AE;G1I9FEC871I;VX@<WES=&5M+B!/;F4@=7-E
M<B!I9"`H8V%C:&5D(&1A=&%S970@=VET:"!T:&4@240@>"D*("`@("H@;6%Y
M(&5X:7-T<R!I;B!D:69F97)E;G0@9&]M86EN<R`H9&EF9F5R96YT(&9I;&5N
M86UE('!R969I>"DN(%EO=2!M:6=H="!W86YT"B`@("`J('1O('5S92!T:&ES
M('1O(&AA=F4@9&EF9F5R96YT(&-A8VAE('9A;'5E<R!F;W(@82!P<F]D=6-T
M:6]N+"!D979E;&]P;65N="!A;F0*("`@("H@<75A;&ET>2!A<W-U<F%N8V4@
M<WES=&5M+B!)9B!Y;W4@=V%N="!T:&4@<')O9'5C=&EO;B!C86-H92!N;W0@
M=&\@8F4@:6YF;'5E;F-E9`H@("`@*B!B>2!T:&4@<75A;&ET>2!A<W-U<F%N
M8V4@86-T:79I=&EE<RP@=7-E(&1I9F9E<F5N="!F:6QE;F%M92!P<F5F:7AE
M<R!F;W(@=&AE;2X*("`@("H*("`@("H@22!P97)S;VYA;&QY(&1O;B=T('1H
M:6YK('1H870@>6]U)VQL(&YE=F5R(&YE960@=&AI<RP@8G5T(#8T,&MB(&AA
M<'!E;F0@=&\@8F4*("`@("H@;F]T(&5N;W5G:"P@<V\N+BX@>6]U(&MN;W<@
M=VAA="!)(&UE86XN($EF('EO=2!F:6YD(&$@=7-E9G5L(&%P<&QI8V%T:6]N
M(&]F('1H90H@("`@*B!F96%T=7)E('!L96%S92!U<&1A=&4@=&AI<R!I;FQI
M;F4@9&]C+@H@("`@*@H@("`@*B!`=F%R("!S=')I;F<*("`@("HO"B`@("!V
M87(@)&9I;&5N86UE7W!R969I>"`]("<G.PH@("`@"B`@("`*("`@("\J*@H@
M("`@*B!,:7-T(&]F(&-A8VAE(&5N=')I97,L('5S960@=VET:&EN(&$@9V,@
M<G5N"B`@("`J(`H@("`@*B!`=F%R(&%R<F%Y"B`@("`J+PH@("`@=F%R("1E
M;G1R:65S.PH@("`@"B`@("`O*BH*("`@("H@5&]T86P@;G5M8F5R(&]F(&)Y
M=&5S(')E<75I<F5D(&)Y(&%L;"!C86-H92!E;G1R:65S+"!U<V5D('=I=&AI
M;B!A(&=C(')U;BX*("`@("H@"B`@("`J($!V87(@(&EN=`H@("`@*B\*("`@
M('9A<B`D=&]T86Q?<VEZ92`](#`["@H*("`@("\J*@H@("`@*B!-87@@3&EN
M92!,96YG=&@@;V8@=7-E<F1A=&$*("`@("H*("`@("H@268@<V5T('1O(#`L
M(&ET('=I;&P@=&%K92!T:&4@9&5F875L="`*("`@("H@*"`Q,#(T(&EN('!H
M<"`T+C(L('5N;&EM:71E9"!I;B!P:'`@-"XS*0H@("`@*B!S964@:'1T<#HO
M+V-H+G!H<"YN970O;6%N=6%L+V5N+V9U;F-T:6]N+F9G971S+G!H<`H@("`@
M*B!F;W(@9&5T86EL<PH@("`@*@H@("`@*B!`=F%R(&EN=`H@("`@*B\*("`@
M('9A<B`D;6%X7W5S97)D871A7VQI;F5L96YG=&@@/2`R-3<["@H@("`@+RHJ
M"B`@("`J($-R96%T97,@=&AE(&-A8VAE(&1I<F5C=&]R>2!I9B!N96-C97-S
M87)Y"B`@("`J"B`@("`J($!P87)A;2`@("!A<G)A>2`@($-O;F9I9R!O<'1I
M;VYS.B!;(F-A8VAE7V1I<B(@/3X@+BXN+"`B9FEL96YA;65?<')E9FEX(B`]
M/B`N+BY="B`@("`J+PH@("`@(&9U;F-T:6]N($-A8VAE7T-O;G1A:6YE<E]F
M:6QE*"1O<'1I;VYS(#T@)R<I('L*("`@("`@("!I9B`H:7-?87)R87DH)&]P
M=&EO;G,I*0H@("`@("`@("`@("`D=&AI<RT^<V5T3W!T:6]N<R@D;W!T:6]N
M<RP@87)R87E?;65R9V4H)'1H:7,M/F%L;&]W961?;W!T:6]N<RP@87)R87DH
M)V-A8VAE7V1I<B<L("=F:6QE;F%M95]P<F5F:7@G+"`G;6%X7W5S97)D871A
M7VQI;F5L96YG=&@G*2DI.PH@("`@("`@(`H@("`@("`@(&-L96%R<W1A=&-A
M8VAE*"D["B`@("`@("`@:68@*"1T:&ES+3YC86-H95]D:7(I"B`@("`@("`@
M>PH@("`@("`@("`@("`O+R!M86ME(')E;&%T:79E('!A=&AS(&%B<V]L=71E
M(&9O<B!U<V4@:6X@9&5C;VYS=')U8W1O<BX*("`@("`@("`@("`@+R\@:70@
M;&]O:W,@;&EK92!T:&4@9&5C;VYS=')U8W1O<B!H87,@<')O8FQE;7,@=VET
M:"!R96QA=&EV92!P871H<PH@("`@("`@("`@("!I9B`H3U-?54Y)6"`F)B`G
M+R<@(3T@)'1H:7,M/F-A8VAE7V1I<GLP?2`@*0H@("`@("`@("`@("`@("`@
M)'1H:7,M/F-A8VAE7V1I<B`](')E86QP871H*"!G971C=V0H*2`N("<O)R`N
M("1T:&ES+3YC86-H95]D:7(I("X@)R\G.PH*("`@("`@("`@("`@+R\@8VAE
M8VL@:68@82!T<F%I;&EN9R!S;&%S:"!I<R!I;B!C86-H95]D:7(*("`@("`@
M("`@("`@:68@*"1T:&ES+3YC86-H95]D:7)[<W1R;&5N*"1T:&ES+3YC86-H
M95]D:7(I+3%]("$]($1)4D5#5$]265]315!!4D%43U(I"B`@("`@("`@("`@
M("`@("`@)'1H:7,M/F-A8VAE7V1I<B`N/2`G+R<["@H@("`@("`@("`@("!I
M9B`@*"%F:6QE7V5X:7-T<R@D=&AI<RT^8V%C:&5?9&ER*2!\?"`A:7-?9&ER
M*"1T:&ES+3YC86-H95]D:7(I*0H@("`@("`@("`@("`@("`@;6MD:7(H)'1H
M:7,M/F-A8VAE7V1I<BP@,#<U-2D["B`@("`@("`@?0H@("`@("`@("1T:&ES
M+3YE;G1R:65S(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^9W)O=7!?9&ER
M<R`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@"B`@("!]("\O(&5N
M9"!F=6YC(&-O;G1R=6-T;W(*"B`@("!F=6YC=&EO;B!F971C:"@D:60L("1G
M<F]U<"D@>PH@("`@("`@("1F:6QE(#T@)'1H:7,M/F=E=$9I;&5N86UE*"1I
M9"P@)&=R;W5P*3L*("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1F:6QE*2D*
M("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*$Y53$PL($Y53$PL($Y53$PI.PH*
M("`@("`@("`O+R!R971R:79E('1H92!C;VYT96YT"B`@("`@("`@:68@*"$H
M)&9H(#T@0&9O<&5N*"1F:6QE+"`G<F(G*2DI"B`@("`@("`@("`@(')E='5R
M;B!N97<@0V%C:&5?17)R;W(H(D-A;B=T(&%C8V5S<R!C86-H92!F:6QE("<D
M9FEL92<N($-H96-K(&%C8V5S<R!R:6=H=',@86YD('!A=&@N(BP@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*"B`@("`@("`@+R\@1FEL92!L;V-K:6YG("AS:&%R
M960@;&]C:RD*("`@("`@("!I9B`H)'1H:7,M/F9I;&5,;V-K:6YG*0H@("`@
M("`@("`@("!F;&]C:R@D9F@L($Q/0TM?4T@I.PH*("`@("`@("`O+R!F:6QE
M(&9O<FUA=#H*("`@("`@("`O+R`Q<W0@;&EN93H@97AP:7)A=&EO;B!D871E
M"B`@("`@("`@+R\@,FYD(&QI;F4Z('5S97(@9&%T80H@("`@("`@("\O(#-R
M9"L@;&EN97,Z(&-A8VAE(&1A=&$*("`@("`@("`D97AP:7)E(#T@=')I;2AF
M9V5T<R@D9F@L(#$R*2D["B`@("`@("`@:68@*"1T:&ES+3YM87A?=7-E<F1A
M=&%?;&EN96QE;F=T:"`]/2`P("D@>PH@("`@("`@("`@("`D=7-E<F1A=&$@
M/2!T<FEM*&9G971S*"1F:"DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1U<V5R9&%T82`]('1R:6TH9F=E=',H)&9H+"`D=&AI<RT^;6%X7W5S
M97)D871A7VQI;F5L96YG=&@I*3L*("`@("`@("!]"B`@("`@("`@)&-A8VAE
M9&%T82`]("1T:&ES+3YD96-O9&4H9G)E860H)&9H+"!F:6QE<VEZ92@D9FEL
M92DI*3L*"B`@("`@("`@+R\@56YL;V-K:6YG"B`@("`@("`@:68@*"1T:&ES
M+3YF:6QE3&]C:VEN9RD*("`@("`@("`@("`@9FQO8VLH)&9H+"!,3T-+7U5.
M*3L*"B`@("`@("`@9F-L;W-E*"1F:"D["@H@("`@("`@("\O(&QA<W0@=7-A
M9V4@9&%T92!U<V5D(&)Y('1H92!G8R`M(&UA>&QI9F5T:6UE"B`@("`@("`@
M+R\@=&]U8V@@=VET:&]U="!S96-O;F0@<&%R86T@<')O9'5C960@<W1U<&ED
M(&5N=')I97,N+BX*("`@("`@("!T;W5C:"@D9FEL92QT:6UE*"DI.PH@("`@
M("`@(&-L96%R<W1A=&-A8VAE*"D["@H@("`@("`@(')E='5R;B!A<G)A>2@D
M97AP:7)E+"`D8V%C:&5D871A+"`D=7-E<F1A=&$I.PH@("`@?2`O+R!E;F0@
M9G5N8R!F971C:`H*("`@("\J*@H@("`@*B!3=&]R97,@82!D871A<V5T+@H@
M("`@*@H@("`@*B!705).24Y'.B!)9B!Y;W4@<W5P<&QY('5S97)D871A(&ET
M(&UU<W0@;F]T(&-O;G1A:6X@86YY(&QI;F5B<F5A:W,L"B`@("`J(&]T:&5R
M=VES92!I="!W:6QL(&)R96%K('1H92!F:6QE<W1R=6-T=7)E+@H@("`@*B\*
M("`@(&9U;F-T:6]N('-A=F4H)&ED+"`D8V%C:&5D871A+"`D97AP:7)E<RP@
M)&=R;W5P+"`D=7-E<F1A=&$I('L*("`@("`@("`D=&AI<RT^9FQU<VA0<F5L
M;V%D*"1I9"P@)&=R;W5P*3L*"B`@("`@("`@)&9I;&4@/2`D=&AI<RT^9V5T
M1FEL96YA;64H)&ED+"`D9W)O=7`I.PH@("`@("`@(&EF("@A*"1F:"`]($!F
M;W!E;B@D9FEL92P@)W=B)RDI*0H@("`@("`@("`@("!R971U<FX@;F5W($-A
M8VAE7T5R<F]R*")#86XG="!A8V-E<W,@)R1F:6QE)R!T;R!S=&]R92!C86-H
M92!D871A+B!#:&5C:R!A8V-E<W,@<FEG:'1S(&%N9"!P871H+B(L(%]?1DE,
M15]?+"!?7TQ)3D5?7RD["@H@("`@("`@("\O($9I;&4@;&]C:VEN9R`H97AC
M;'5S:79E(&QO8VLI"B`@("`@("`@:68@*"1T:&ES+3YF:6QE3&]C:VEN9RD*
M("`@("`@("`@("`@9FQO8VLH)&9H+"!,3T-+7T58*3L*"B`@("`@("`@+R\@
M9FEL92!F;W)M870Z"B`@("`@("`@+R\@,7-T(&QI;F4Z(&5X<&ER871I;VX@
M9&%T90H@("`@("`@("\O(#)N9"!L:6YE.B!U<V5R(&1A=&$*("`@("`@("`O
M+R`S<F0K(&QI;F5S.B!C86-H92!D871A"B`@("`@("`@)&5X<&ER97,@/2`D
M=&AI<RT^9V5T17AP:7)E<T%B<V]L=71E*"1E>'!I<F5S*3L*("`@("`@("!F
M=W)I=&4H)&9H+"`D97AP:7)E<R`N(")<;B(I.PH@("`@("`@(&9W<FET92@D
M9F@L("1U<V5R9&%T82`N(")<;B(I.PH@("`@("`@(&9W<FET92@D9F@L("1T
M:&ES+3YE;F-O9&4H)&-A8VAE9&%T82DI.PH*("`@("`@("`O+R!&:6QE('5N
M;&]C:VEN9PH@("`@("`@(&EF("@D=&AI<RT^9FEL94QO8VMI;F<I"B`@("`@
M("`@("`@(&9L;V-K*"1F:"P@3$]#2U]53BD["@H@("`@("`@(&9C;&]S92@D
M9F@I.PH*("`@("`@("`O+R!))VT@;F]T('-U<F4@:68@=V4@;F5E9"!T:&ES
M"@DO+R!I(&1O;B=T('1H:6YK('=E(&YE960@=&AI<R`H8VAR96=U*0H@("`@
M("`@("\O('1O=6-H*"1F:6QE*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]("\O(&5N9"!F=6YC('-A=F4*"B`@("!F=6YC=&EO;B!R96UO=F4H)&ED
M+"`D9W)O=7`I('L*("`@("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D*"1I9"P@
M)&=R;W5P*3L*"B`@("`@("`@)&9I;&4@/2`D=&AI<RT^9V5T1FEL96YA;64H
M)&ED+"`D9W)O=7`I.PH@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D9FEL92DI
M('L*"B`@("`@("`@("`@("1O:R`]('5N;&EN:R@D9FEL92D["B`@("`@("`@
M("`@(&-L96%R<W1A=&-A8VAE*"D["@H@("`@("`@("`@("!R971U<FX@)&]K
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?2`O+R!E
M;F0@9G5N8R!R96UO=F4*"B`@("!F=6YC=&EO;B!F;'5S:"@D9W)O=7`I('L*
M("`@("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D*"D["B`@("`@("`@)&1I<B`]
M("@D9W)O=7`I(#\@)'1H:7,M/F-A8VAE7V1I<B`N("1G<F]U<"`N("<O)R`Z
M("1T:&ES+3YC86-H95]D:7(["@H@("`@("`@("1N=6U?<F5M;W9E9"`]("1T
M:&ES+3YD96QE=&5$:7(H)&1I<BD["B`@("`@("`@=6YS970H)'1H:7,M/F=R
M;W5P7V1I<G-;)&=R;W5P72D["B`@("`@("`@8VQE87)S=&%T8V%C:&4H*3L*
M"B`@("`@("`@<F5T=7)N("1N=6U?<F5M;W9E9#L*("`@('T@+R\@96YD(&9U
M;F,@9FQU<V@*"B`@("!F=6YC=&EO;B!I9$5X:7-T<R@D:60L("1G<F]U<"D@
M>PH*("`@("`@("!R971U<FX@9FEL95]E>&ES=',H)'1H:7,M/F=E=$9I;&5N
M86UE*"1I9"P@)&=R;W5P*2D["B`@("!]("\O(&5N9"!F=6YC(&ED17AI<W1S
M"@H@("`@+RHJ"B`@("`J($1E;&5T97,@86QL(&5X<&ER960@9FEL97,N"B`@
M("`J"B`@("`J($=A<F)A9V4@8V]L;&5C=&EO;B!F;W(@9FEL97,@:7,@82!R
M871H97(@(F5X<&5N<VEV92(L(")L;VYG('1I;64B"B`@("`J(&]P97)A=&EO
M;BX@06QL(&9I;&5S(&EN('1H92!C86-H92!D:7)E8W1O<GD@:&%V92!T;R!B
M92!E>&%M:6YE9"!W:&EC:`H@("`@*B!M96%N<R!T:&%T('1H97D@;75S="!B
M92!O<&5N960@9F]R(')E861I;F<L('1H92!E>'!I<F%T:6]N(&1A=&4@:&%S
M('1O(&)E"B`@("`J(')E860@9G)O;2!T:&5M(&%N9"!I9B!N96-C97-S87)Y
M('1H97D@:&%V92!T;R!B92!U;FQI;FME9"`H<F5M;W9E9"DN"B`@("`J($EF
M('EO=2!H879E(&$@=7-E<B!C;VUM96YT(&9O<B!A(&=O;V0@9&5F875L="!G
M8R!P<F]B86)I;&ET>2!P;&5A<V4@861D(&ET('1O"B`@("`J('1O('1H92!I
M;FQI;F4@9&]C<RX*("`@("H*("`@("H@0'!A<F%M("`@(&EN=&5G97(@36%X
M:6UU;2!L:69E=&EM92!I;B!S96-O;F1S(&]F(&%N(&YO(&QO;F=E<B!U<V5D
M+W1O=6-H960@96YT<GD*("`@("H@0'1H<F]W<R`@($-A8VAE7T5R<F]R"B`@
M("`J+PH@("`@9G5N8W1I;VX@9V%R8F%G94-O;&QE8W1I;VXH)&UA>&QI9F5T
M:6UE*2!["@H@("`@("`@("1T:&ES+3YF;'5S:%!R96QO860H*3L*("`@("`@
M("!C;&5A<G-T871C86-H92@I.PH*("`@("`@("`D;VL@/2`D=&AI<RT^9&]'
M87)B86=E0V]L;&5C=&EO;B@D;6%X;&EF971I;64L("1T:&ES+3YC86-H95]D
M:7(I.PH*("`@("`@("`O+R!C:&5C:R!T:&4@<W!A8V4@=7-E9"!B>2!T:&4@
M8V%C:&4@96YT<FEE<R`@("`@("`@"B`@("`@("`@:68@*"1T:&ES+3YT;W1A
M;%]S:7IE(#X@)'1H:7,M/FAI9VAW871E<BD@>PH@("`@("`@(`H@("`@("`@
M("`@("!K<G-O<G0H)'1H:7,M/F5N=')I97,I.PH@("`@("`@("`@("!R97-E
M="@D=&AI<RT^96YT<FEE<RD["B`@("`@("`@("`@(`H@("`@("`@("`@("!W
M:&EL92`H)'1H:7,M/G1O=&%L7W-I>F4@/B`D=&AI<RT^;&]W=V%T97(@)B8@
M;&ES="@D;&%S=&UO9"P@)&5N=')Y*2`](&5A8V@H)'1H:7,M/F5N=')I97,I
M*2!["B`@("`@("`@("`@("`@("!I9B`H0'5N;&EN:R@D96YT<GE;)V9I;&4G
M72DI"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G1O=&%L7W-I>F4@+3T@
M)&5N=')Y6R=S:7IE)UT["B`@("`@("`@("`@("`@("!E;'-E"B`@("`@("`@
M("`@("`@("`@("`@;F5W($-A8VAE17)R;W(H(D-A;B=T(&1E;&5T92![)&5N
M=')Y6R)F:6QE(EU]+B!#:&5C:R!T:&4@<&5R;6ES<VEO;G,N(BD["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@"B`@("`@("`@?0H@("`@("`@(`H@("`@
M("`@("1T:&ES+3YE;G1R:65S(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^
M=&]T86Q?<VEZ92`](#`["B`@("`@("`@"B`@("`@("`@<F5T=7)N("1O:SL*
M("`@('T@+R\@96YD(&9U;F,@9V%R8F%G94-O;&QE8W1I;VX*("`@(`H@("`@
M+RHJ"B`@("`J($1O97,@=&AE(')E8W5R<VEV92!G8R!P<F]C961U<F4L('!R
M;W1E8W1E9"X*("`@("H*("`@("H@0'!A<F%M("`@(&EN=&5G97(@36%X:6UU
M;2!L:69E=&EM92!I;B!S96-O;F1S(&]F(&%N(&YO(&QO;F=E<B!U<V5D+W1O
M=6-H960@96YT<GD*("`@("H@0'!A<F%M("`@('-T<FEN9R`@9&ER96-T;W)Y
M('1O(&5X86UI;F4@+2!D;VXG="!S971S('1H:7,@<&%R86UE=&5R+"!I="=S
M('5S960@9F]R(&$*("`@("H@("`@("`@("`@("`@("`@("`@<F5C=7)S:79E
M(&9U;F-T:6]N(&-A;&PA"B`@("`J($!T:')O=W,@("!#86-H95]%<G)O<@H@
M("`@*B\*("`@(&9U;F-T:6]N(&1O1V%R8F%G94-O;&QE8W1I;VXH)&UA>&QI
M9F5T:6UE+"`D9&ER*2!["B`@("`@("`@("`@"B`@("`@("`@:68@*"$H)&1H
M(#T@;W!E;F1I<B@D9&ER*2DI"B`@("`@("`@("`@(')E='5R;B!N97<@0V%C
M:&5?17)R;W(H(D-A;B=T(&%C8V5S<R!C86-H92!D:7)E8W1O<GD@)R1D:7(G
M+B!#:&5C:R!P97)M:7-S:6]N<R!A;F0@<&%T:"XB+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH*("`@("`@("!W:&EL92`H)&9I;&4@/2!R96%D9&ER*"1D:"DI
M('L*("`@("`@("`@("`@:68@*"<N)R`]/2`D9FEL92!\?"`G+BXG(#T]("1F
M:6QE*0H@("`@("`@("`@("`@("`@8V]N=&EN=64["@H@("`@("`@("`@("`D
M9FEL92`]("1D:7(@+B`D9FEL93L*("`@("`@("`@("`@:68@*&ES7V1I<B@D
M9FEL92DI('L*("`@("`@("`@("`@("`@("1T:&ES+3YD;T=A<F)A9V5#;VQL
M96-T:6]N*"1M87AL:69E=&EM92PD9FEL92`N("<O)RD["B`@("`@("`@("`@
M("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@
M<VMI<"!T<F]U8FQE(&UA:V5R<R!B=70@:6YF;W)M('1H92!U<V5R"B`@("`@
M("`@("`@(&EF("@A*"1F:"`]($!F;W!E;B@D9FEL92P@)W)B)RDI*2!["B`@
M("`@("`@("`@("`@("!N97<@0V%C:&5?17)R;W(H(D-A;B=T(&%C8V5S<R!C
M86-H92!F:6QE("<D9FEL92<L('-K:7!P:6YG(&ET+B!#:&5C:R!P97)M:7-S
M:6]N<R!A;F0@<&%T:"XB+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@
M("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1E>'!I<F4@/2!F9V5T<R@D9F@L(#$Q*3L*("`@("`@("`@("`@9F-L;W-E
M*"1F:"D["B`@("`@("`@("`@("1L87-T=7-E9"`](&9I;&5M=&EM92@D9FEL
M92D["B`@("`@("`@("`@(`H@("`@("`@("`@("`D=&AI<RT^96YT<FEE<ULD
M;&%S='5S961=(#T@87)R87DH)V9I;&4G(#T^("1F:6QE+"`G<VEZ92<@/3X@
M9FEL97-I>F4H)&9I;&4I*3L*("`@("`@("`@("`@)'1H:7,M/G1O=&%L7W-I
M>F4@*ST@9FEL97-I>F4H)&9I;&4I.PH@("`@("`@("`@("`*("`@("`@("`@
M("`@+R\@<F5M;W9E(&EF(&5X<&ER960*("`@("`@("`@("`@:68@*"@@*"1E
M>'!I<F4@)B8@)&5X<&ER92`\/2!T:6UE*"DI('Q\("@D;&%S='5S960@/#T@
M*'1I;64H*2`M("1M87AL:69E=&EM92DI("D@)B8@(75N;&EN:R@D9FEL92DI
M"B`@("`@("`@("`@("`@("!N97<@0V%C:&5?17)R;W(H(D-A;B=T('5N;&EN
M:R!C86-H92!F:6QE("<D9FEL92<L('-K:7!P:6YG+B!#:&5C:R!P97)M:7-S
M:6]N<R!A;F0@<&%T:"XB+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@
M('T*"B`@("`@("`@8VQO<V5D:7(H)&1H*3L*"B`@("`@("`@+R\@9FQU<V@@
M=&AE(&1I<VL@<W1A=&4@8V%C:&4*("`@("`@("!C;&5A<G-T871C86-H92@I
M.PH*("`@('T@+R\@96YD(&9U;F,@9&]'87)B86=E0V]L;&5C=&EO;@H*("`@
M("\J*@H@("`@*B!2971U<FYS('1H92!F:6QE;F%M92!F;W(@=&AE('-P96-I
M9FEE9"!I9"X*("`@("H*("`@("H@0'!A<F%M("`@('-T<FEN9R`@9&%T87-E
M="!)1`H@("`@*B!`<&%R86T@("`@<W1R:6YG("!C86-H92!G<F]U<`H@("`@
M*B!`<F5T=7)N("`@<W1R:6YG("!F=6QL(&9I;&5N86UE('=I=&@@=&AE('!A
M=&@*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$9I;&5N86UE*"1I9"P@)&=R;W5P*2!["@H@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^9W)O=7!?9&ER<ULD9W)O=7!=*2D*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YG<F]U<%]D:7)S6R1G<F]U<%T@+B`D=&AI<RT^9FEL96YA
M;65?<')E9FEX("X@)&ED.PH*("`@("`@("`D9&ER(#T@)'1H:7,M/F-A8VAE
M7V1I<B`N("1G<F]U<"`N("<O)SL*("`@("`@("!I9B`H(69I;&5?97AI<W1S
M*"1D:7(I*2!["B`@("`@("`@("`@(&UK9&ER*"1D:7(L(#`W-34I.PH@("`@
M("`@("`@("!C;&5A<G-T871C86-H92@I.PH@("`@("`@('T*"B`@("`@("`@
M)'1H:7,M/F=R;W5P7V1I<G-;)&=R;W5P72`]("1D:7(["@H@("`@("`@(')E
M='5R;B`D9&ER("X@)'1H:7,M/F9I;&5N86UE7W!R969I>"`N("1I9#L*("`@
M('T@+R\@96YD(&9U;F,@9V5T1FEL96YA;64*"B`@("`O*BH*("`@("H@1&5L
M971E<R!A(&1I<F5C=&]R>2!A;F0@86QL(&9I;&5S(&EN(&ET+@H@("`@*@H@
M("`@*B!`<&%R86T@("`@<W1R:6YG("!D:7)E8W1O<GD*("`@("H@0')E='5R
M;B`@(&EN=&5G97(@;G5M8F5R(&]F(')E;6]V960@9FEL97,*("`@("H@0'1H
M<F]W<R`@($-A8VAE7T5R<F]R"B`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E
M1&ER*"1D:7(I('L*("`@("`@("!I9B`H(2@D9&@@/2!O<&5N9&ER*"1D:7(I
M*2D*("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@B0V%N)W0@
M<F5M;W9E(&1I<F5C=&]R>2`G)&1I<B<N($-H96-K('!E<FUI<W-I;VYS(&%N
M9"!P871H+B(L(%]?1DE,15]?+"!?7TQ)3D5?7RD["@H@("`@("`@("1N=6U?
M<F5M;W9E9"`](#`["@H@("`@("`@('=H:6QE("AF86QS92`A/3T@)&9I;&4@
M/2!R96%D9&ER*"1D:"DI('L*("`@("`@("`@("`@:68@*"<N)R`]/2`D9FEL
M92!\?"`G+BXG(#T]("1F:6QE*0H@("`@("`@("`@("`@("`@8V]N=&EN=64[
M"@H@("`@("`@("`@("`D9FEL92`]("1D:7(@+B`D9FEL93L*("`@("`@("`@
M("`@:68@*&ES7V1I<B@D9FEL92DI('L*("`@("`@("`@("`@("`@("1F:6QE
M("X]("<O)SL*("`@("`@("`@("`@("`@("1N=6T@/2`D=&AI<RT^9&5L971E
M1&ER*"1F:6QE("X@)R\G*3L*("`@("`@("`@("`@("`@(&EF("AI<U]I;G0H
M)&YU;2DI"B`@("`@("`@("`@("`@("`@("`@)&YU;5]R96UO=F5D("L]("1N
M=6T["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!I9B`H
M=6YL:6YK*"1F:6QE*2D*("`@("`@("`@("`@("`@("`@("`D;G5M7W)E;6]V
M960K*SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`O+R!A8V-O
M<F1I;F<@=&\@<&AP+6UA;G5A;"!T:&4@9F]L;&]W:6YG(&ES(&YE961E9"!F
M;W(@=VEN9&]W<R!I;G-T86QL871I;VYS+@H@("`@("`@(&-L;W-E9&ER*"1D
M:"D["B`@("`@("`@=6YS970H("1D:"D["B`@("`@("`@:68@*"1D:7(@(3T@
M)'1H:7,M/F-A8VAE7V1I<BD@>R`@+R]D96QE=&4@=&AE('-U8BUD:7(@96YT
M<FEE<R`@:71S96QF(&%L<V\L(&)U="!N;W0@=&AE(&-A8VAE+61I<BX*("`@
M("`@("`@("`@<FU$:7(H)&1I<BD["B`@("`@("`@("`@("1N=6U?<F5M;W9E
M9"LK.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1N=6U?<F5M;W9E9#L*
M("`@('T@+R\@96YD(&9U;F,@9&5L971E1&ER"B`@("`*?2`O+R!E;F0@8VQA
M<W,@9FEL90H_/@H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O0V%C:&4O0V]N=&%I;F5R+VUS97-S:6]N
M+G!H<```````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q-C8S,2`Q,#4Q-30S
M,S<S,"`P,C,W-S``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@4$5!4B`Z.B!#86-H92`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P
M,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@
M<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,"!O9B!T:&4@
M4$A0(&QI8V5N<V4L("`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET
M:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@
M("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I
M9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT
M='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R
M96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B
M;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I
M9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\
M(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM
M;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@56QF(%=E;F1E;"`\=6QF+G=E
M;F1E;$!P:'!D;V,N9&4^("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!M<V5S
M<VEO;BYP:'`L=B`Q+C0@,C`P,R\P,2\P-"`Q,3HU-#HT-B!M:B!%>'`@)`H*
M<F5Q=6ER95]O;F-E("=#86-H92]#;VYT86EN97(N<&AP)SL*"B\J*@HJ(%-T
M;W)E<R!C86-H92!C;VYT96YT<R!I;B!M<V5S<VEO;G,N"BH**B!705).24Y'
M.B!E>'!E<FEM96YT86PL('5N=&5S=&5D"BH**B!`875T:&]R("`@56QF(%=E
M;F1E;"`@/'5L9BYW96YD96Q`<&AP9&]C+F1E/@HJ($!V97)S:6]N("`D260Z
M(&US97-S:6]N+G!H<"QV(#$N-"`R,#`S+S`Q+S`T(#$Q.C4T.C0V(&UJ($5X
M<"`D"BHO"F-L87-S($-A8VAE7T-O;G1A:6YE<E]M<V5S<VEO;B!E>'1E;F1S
M($-A8VAE7T-O;G1A:6YE<B!["@H*("`@("\J*@H@("`@*B!,96YG=&@@;V8@
M=&AE($-A8VAE+4ED96YT:69I97(*("`@("H*("`@("H@3F]T92!T:&%T('1H
M92!014%2+4-A8VAE('!R969I>&5S('1H92!)1"!W:71H(&%N(&UD-2@I('9A
M;'5E"B`@("`J(&]F('1H92!C86-H92UG<F]U<"X@02!G;V]D('9A;'5E(&9O
M<B!T:&4@:61?;&5N9W1H"B`@("`J(&1E<&5N9',@;VX@=&AE(&UA>&EM=6T@
M;G5M8F5R(&]F(&5N=')I97,@<&5R(&-A8VAE(&=R;W5P+@H@("`@*@H@("`@
M*B!`=F%R("!I;G0*("`@("HO"B`@("!V87(@)&ED7VQE;F=T:"`](#,R.PH@
M("`@"B`@("`*("`@("\J*@H@("`@*B!5<V4@;7-E<W-I;VY?=6YI<2!T;R!C
M<F5A=&4@82!U;FEQ=64@4TE$+@H@("`@*B`*("`@("H@0'9A<B`@8F]O;&5A
M;@H@("`@*B\*("`@('9A<B`D=6YI<2`]('1R=64["B`@("`*("`@(`H@("`@
M+RHJ"B`@("`J($5S=&%B;&ES:"!A(&-O;FYE8W1I;VX@=&\@82!M<V5S<VEO
M;B!S97)V97(_"B`@("`J"B`@("`J($!V87(@(&)O;VQE86X*("`@("HO"B`@
M("!V87(@)&-O;FYE8W0@/2!T<G5E.PH@("`*("`@"B`@("`O*BH*("`@("H@
M;7-E<W-I;VX@:&]S=`H@("`@*@H@("`@*B!`=F%R("!S=')I;F<*("`@("HO
M("`*("`@('9A<B`D:&]S="`]($Y53$P["B`@("`*("`@"B`@("`O*BH*("`@
M("H@;7-E<W-I;VX@<&]R=`H@("`@*@H@("`@*B!`=F%R("!S=')I;F<*("`@
M("HO"B`@("!V87(@)'!O<G0@/2!.54Q,.PH@("`@"B`@("`*("`@("\J*@H@
M("`@*B!M97-E<W-I;VX@<V5R=F5R(&-O;FYE8W1I;VX*("`@("H*("`@("H@
M0'9A<B`@<F5S;W5R8V4@;7-E<W-I;VX*("`@("HO"B`@("!V87(@)&US(#T@
M3E5,3#L*"B`@("`*("`@(&9U;F-T:6]N($-A8VAE7T-O;G1A:6YE<E]M<V5S
M<VEO;B@D;W!T:6]N<R`]("<G*2!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1O
M<'1I;VYS*2D*("`@("`@("`@("`@)'1H:7,M/G-E=$]P=&EO;G,H)&]P=&EO
M;G,L(&%R<F%Y7VUE<F=E*"1T:&ES+3YA;&QO=V5D7V]P=&EO;G,L(&%R<F%Y
M*"=I9%]L96YG:'0G+"`G=6YI<2<L("=H;W-T)RP@)W!O<G0G+"`G8V]N;F5C
M="<I*2D["@H@("`@("`@(&EF("@D8V]N;F5C="D@>R`@("`@("`@("`@(`H@
M("`@("`@("`@("!I9B`H3E5,3"`]/2`D=&AI<RT^:&]S="D*("`@("`@("`@
M("`@("`@(&YE=R!#86-H95]%<G)O<B@G3F\@:&]S="!S<&5C:69I960N)RP@
M7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@:68@*$Y53$P@/3T@
M)'1H:7,M/G!O<G0I"B`@("`@("`@("`@("`@("!N97<@0V%C:&5?17)R;W(H
M)TYO('!O<G0@<W!E8VEF:65D+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@
M("`@("`@"B`@("`@("`@("`@(&EF("@A*"1T:&ES+3YM<R`](&US97-S:6]N
M7V-O;FYE8W0H)'1H:7,M/FAO<W0L("1T:&ES+3YP;W)T*2DI"B`@("`@("`@
M("`@("`@("!N97<@0V%C:&5?17)R;W(H)T-A;B!N;W0@8V]N;F5C="!T;R!T
M:&4@<V5V97(@=7-I;F<@:&]S="`B)R`N("1T:&ES+3YH;W-T("X@)R(@;VX@
M<&]R="`B)R`N("1T:&ES+3YP;W)T("X@)R(G+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@('T*("`@("`@("`*("`@('T@+R\@96YD(&9U;F,@8V]N
M=')U8W1O<@H*("`@(&9U;F-T:6]N(&9E=&-H*"1I9"P@)&=R;W5P*2!["B`@
M("`*("`@("`@("`D:60@/2!S=')T;W5P<&5R*&UD-2@D9W)O=7`I*2`N("1I
M9#L*("`@("`@("`D9W)O=7`@/2!M<V5S<VEO;E]G970H)&ED+"`G7W!E87)?
M8V%C:&5?9&%T82<L($Y53$PI.PH@("`@("`@(`H@("`@("`@(&EF("A.54Q,
M(#T]("1D871A*0H@("`@("`@("`@("!R971U<FX@87)R87DH3E5,3"P@3E5,
M3"P@3E5,3"D["B`@("`@("`@"B`@("`@("`@<F5T=7)N(&%R<F%Y*"1D871A
M6R=E>'!I<F5S)UTL("1D871A6R=C86-H961A=&$G72P@)&1A=&%;)W5S97)D
M871A)UTI.PH@("`@?2`O+R!E;F0@9G5N8R!F971C:`H*("`@("\J*@H@("`@
M*B!3=&]R97,@82!D871A<V5T+@H@("`@*@H@("`@*B!705).24Y'.B!)9B!Y
M;W4@<W5P<&QY('5S97)D871A(&ET(&UU<W0@;F]T(&-O;G1A:6X@86YY(&QI
M;F5B<F5A:W,L"B`@("`J(&]T:&5R=VES92!I="!W:6QL(&)R96%K('1H92!F
M:6QE<W1R=6-T=7)E+@H@("`@*B\*("`@(&9U;F-T:6]N('-A=F4H)&ED+"`D
M8V%C:&5D871A+"`D97AP:7)E<RP@)&=R;W5P+"`D=7-E<F1A=&$I('L*("`@
M("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D*"1I9"P@)&=R;W5P*3L*("`@("`@
M("`*("`@("`@("`D8V%C:&5D871A("`@("`@/2`D=&AI<RT^96YC;V1E*"1C
M86-H961A=&$I.PH@("`@("`@("1E>'!I<F5S7V%B<R`@("`]("1T:&ES+3YG
M971%>'!I<F5S06)S;VQU=&4H)&5X<&ER97,I.PH*("`@("`@("`D<VEZ92`]
M(#$@*R!S=')L96XH)&-A8VAE9&%T82D@*R!S=')L96XH)&5X<&ER97-?86)S
M*2`K('-T<FQE;B@D=7-E<F1A=&$I("L@<W1R;&5N*"1G<F]U<"D["B`@("`@
M("`@)'-I>F4@*ST@<W1R;&5N*"1S:7IE*3L*("`@("`@("`*("`@("`@("`D
M9&%T82`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=C86-H961A=&$G
M(#T^("1C86-H961A=&$L(`H@("`@("`@("`@("`@("`@("`@("=E>'!I<F5S
M)R`@(#T^("1E>'!I<F5S7V%B<RP*("`@("`@("`@("`@("`@("`@("`G=7-E
M<F1A=&$G("`]/B`D=7-E<F1A=&$*("`@("`@("`@("`@("`@("`@*3L*("`@
M("`@("`D:60@/2!S=')T;W5P<&5R*&UD-2@D9W)O=7`I*2`N("1I9#L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(`H@("`@("`@(&US97-S:6]N7VQO
M8VLH)&ED*3L*("`@("`@("`*("`@("`@("!I9B`H(6US97-S:6]N7W-E="@D
M:60L("=?<&5A<E]C86-H92<L('1R=64I*2!["B`@("`@("`@("`@(&US97-S
M:6]N7W5N;&]C:R@D:60I.PH@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE
M7T5R<F]R*")#86XG="!W<FET92!C86-H92!D871A+B(L(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["B`@("`@("`@?0H@("`@("`@(`H@("`@("`@(&EF("@A;7-E
M<W-I;VY?<V5T*"1I9"P@)U]P96%R7V-A8VAE7V1A=&$G+"`D9&%T82DI('L*
M("`@("`@("`@("`@;7-E<W-I;VY?=6YL;V-K*"1I9"D["B`@("`@("`@("`@
M(')E='5R;B!N97<@0V%C:&5?17)R;W(H(D-A;B=T('=R:71E(&-A8VAE(&1A
M=&$N(BP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@("`@("`@
M"B`@("`@("`@:68@*"%M<V5S<VEO;E]S970H)&ED+"`G7W!E87)?8V%C:&5?
M9W)O=7`G+"`D9W)O=7`I*2!["B`@("`@("`@("`@(&US97-S:6]N7W5N;&]C
M:R@D:60I.PH@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*")#
M86XG="!W<FET92!C86-H92!D871A+B(L(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@?0H@("`@("`@(`H@("`@("`@(&EF("@A;7-E<W-I;VY?<V5T
M*"1I9"P@)U]P96%R7V-A8VAE7W-I>F4G+"`D<VEZ92DI('L*("`@("`@("`@
M("`@;7-E<W-I;VY?=6YL;V-K*"1I9"D["B`@("`@("`@("`@(')E='5R;B!N
M97<@0V%C:&5?17)R;W(H(D-A;B=T('=R:71E(&-A8VAE(&1A=&$N(BP@7U]&
M24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@
M+R\@;&5T(&US97-S:6]N(&1O('-O;64@1T,@87,@=V5L;`H@("`@("`@("\O
M(&YO=&4@=&AA="!M<V5S<VEO;B!W;W)K<R!D:69F97)E;G0@9G)O;2!T:&4@
M4$5!4B!#86-H92X*("`@("`@("`O+R!M<V5S<VEO;B!D96QE=&5S(&%N(&5N
M=')Y(&EF(&ET(&AA<R!N;W0@8F5E;B!U<V5D(&9O<B!N+7-E8V]N9',N"B`@
M("`@("`@+R\@4$5!4B!#86-H92!D96QE=&5S(&%F=&5R(&XM<V5C;VYD<RX*
M("`@("`@("!I9B`H,"`A/2`D97AP:7)E<RD*("`@("`@("`@("`@;7-E<W-I
M;VY?=&EM96]U="@D:60L("1E>'!I<F5S*3L*("`@("`@("`@("`@"B`@("`@
M("`@;7-E<W-I;VY?=6YL;V-K*"1I9"D["@H@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?2`O+R!E;F0@9G5N8R!S879E"@H@("`@9G5N8W1I;VX@<F5M;W9E
M*"1I9"P@)&=R;W5P*2!["B`@("`@("`@)'1H:7,M/F9L=7-H4')E;&]A9"@D
M:60L("1G<F]U<"D["B`@("`*("`@("`@("!R971U<FX@;7-E<W-I;VY?9&5S
M=')O>2AS=')T;W5P<&5R*&UD-2@D9W)O=7`I*2`N("1I9"D["B`@("!]("\O
M(&5N9"!F=6YC(')E;6]V90H*("`@(&9U;F-T:6]N(&9L=7-H*"1G<F]U<"D@
M>PH@("`@("`@("1T:&ES+3YF;'5S:%!R96QO860H*3L*("`@("`@"B`@("`@
M("`@)'-E<W-I;VYS(#T@;7-E<W-I;VY?9FEN9"@G7W!E87)?8V%C:&5?9W)O
M=7`G+"`D9W)O=7`I.PH@("`@("`@(&EF("AE;7!T>2@D<V5S<VEO;G,I*0H@
M("`@("`@("`@("!R971U<FX@,#L*("`@("`@("`*("`@("`@("!F;W)E86-H
M("@D<V5S<VEO;G,@87,@)&L@/3X@)&ED*0H@("`@("`@("`@("!M97-S<VEO
M;E]D97-T<F]Y*"1I9"D["@H@("`@("`@(')E='5R;B!C;W5N="@D<V5S<VEO
M;G,I.PH@("`@?2`O+R!E;F0@9G5N8R!F;'5S:`H*("`@(&9U;F-T:6]N(&ED
M17AI<W1S*"1I9"P@)&=R;W5P*2!["B`@("`@("`@"B`@("`@("`@<F5T=7)N
M("A.54Q,(#T](&US97-S:6]N7V=E="AS=')T;W5P<&5R*&UD-2@D9W)O=7`I
M*2`N("1I9"P@)U]P96%R7V-A8VAE7V=R;W5P)RP@3E5,3"DI(#\@9F%L<V4@
M.B!T<G5E.PH@("`@?2`O+R!E;F0@9G5N8R!I9$5X:7-T<PH*("`@("\J*@H@
M("`@*B!$96QE=&5S(&%L;"!E>'!I<F5D(&9I;&5S+@H@("`@*@H@("`@*B!.
M;W1E.B!G87)B86=E(&-O;&QE8W1I;VX@<VAO=6QD(&-A=7-E(&QO="=S(&]F
M(&YE='=O<FL@=')A9F9I8RX*("`@("H*("`@("H@0'!A<F%M("`@(&EN=&5G
M97(@36%X:6UU;2!L:69E=&EM92!I;B!S96-O;F1S(&]F(&%N(&YO(&QO;F=E
M<B!U<V5D+W1O=6-H960@96YT<GD*("`@("H@0'1H<F]W<R`@($-A8VAE7T5R
M<F]R"B`@("`J+PH@("`@9G5N8W1I;VX@9V%R8F%G94-O;&QE8W1I;VXH)&UA
M>&QI9F5T:6UE*2!["B`@("`@("`@)'1H:7,M/F9L=7-H4')E;&]A9"@I.PH@
M("`@("`@(`H@("`@("`@("1S97-S:6]N<R`](&US97-S:6]N7V9I;F0H)U]P
M96%R7V-A8VAE)RP@=')U92D["B`@("`@("`@:68@*&5M<'1Y*"1S97-S:6]N
M<RDI"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@(`H@("`@("`@
M("1T;W1A;"`](#`["B`@("`@("`@)&5N=')I97,@/2!A<G)A>2@I.PH@("`@
M("`@(`H@("`@("`@(&9O<F5A8V@@*"1S97-S:6]N<R!A<R`D:R`]/B`D:60I
M('L*("`@("`@("`@("`@)&1A=&$@/2!M<V5S<VEO;E]G970H)&ED+"`G7W!E
M87)?8V%C:&5?9&%T82<L($Y53$PI.PH@("`@("`@("`@("!I9B`H3E5,3"`]
M/2`D9&%T82D*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@
M("`@("`@"B`@("`@("`@("`@(&EF("@D9&%T85LG97AP:7)E<R==(#P]('1I
M;64H*2D@>PH@("`@("`@("`@("`@("`@;7-E<W-I;VY?9&5S=')O>2@D:60I
M.PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@"B`@("`@("`@("`@("1S:7IE(#T@;7-E<W-I;VY?9V5T*"1I
M9"P@)U]P96%R7V-A8VAE7W-I>F4G+"!.54Q,*3L*("`@("`@("`@("`@)'1O
M=&%L("L]("1S:7IE.PH@("`@("`@("`@("`D96YT<FEE<ULD9&%T85LG97AP
M:7)E<R==72`](&%R<F%Y*"1I9"P@)'-I>F4I.PH@("`@("`@('T*("`@("`@
M("`*("`@("`@("!I9B`H)'1O=&%L(#X@)'1H:7,M/FAI9VAW871E<BD@>PH@
M("`@("`@("`@("`*("`@("`@("`@("`@:W)S;W)T*"1E;G1R:65S*3L*("`@
M("`@("`@("`@<F5S970H)&5N=')I97,I.PH@("`@("`@("`@("`*("`@("`@
M("`@("`@=VAI;&4@*"1T;W1A;"`^("1T:&ES+3YL;W=W871E<B`F)B!L:7-T
M*"1E>'!I<F5S+"`D96YT<GDI(#T@96%C:"@D96YT<FEE<RDI('L*("`@("`@
M("`@("`@("`@(&US97-S:6]N7V1E<W1R;WDH)&5N=')Y6S!=*3L*("`@("`@
M("`@("`@("`@("1T;W1A;"`M/2`D96YT<GE;,5T["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@"B`@("`@("`@?0H@("`@("`@(`H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?2`O+R!E;F0@9G5N8R!G87)B86=E0V]L;&5C=&EO;@H@
M("`@"GT@+R\@96YD(&-L87-S(&9I;&4*/SX`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]#86-H92]#;VYT86EN97(O<&AP;&EB
M+G!H<```````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#(R-#8R(#$P-3$U
M-#,S-S,P(#`R,S0P-0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\@?"!014%2(#HZ($-A8VAE("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR
M,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP(&]F('1H
M92!02%`@;&EC96YS92P@("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W
M:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@
M("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N
M86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O
M('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@
M:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!5;&8@5V5N9&5L(#QU;&8N
M=V5N9&5L0'!H<&1O8RYD93X@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O('P@("`@("`@("`@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I
M86XM8F5R9VUA;FXN9&4^("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!P:'!L:6(N<&AP+'8@,2XS
M(#(P,#,O,#$O,#0@,3$Z-30Z-#8@;6H@17AP("0*"G)E<75I<F5?;VYC92`G
M0V%C:&4O0V]N=&%I;F5R+G!H<"<["@HO*BH**B!3=&]R97,@8V%C:&4@9&%T
M82!I;G1O(&$@9&%T86)A<V4@=&%B;&4@=7-I;F<@4$A03&EB<R!$0B!A8G-T
M<F%C=&EO;BX**@HJ(%=!4DY)3D<Z($]T:&5R('-Y<W1E;7,@;6EG:'0@;W(@
M;6EG:'0@;F]T('-U<'!O<G0@8V5R=&%I;B!D871A='EP97,@;V8@"BH@=&AE
M('1A8FQE<R!S:&]W;BX@07,@9F%R(&%S($D@:VYO=R!T:&5R92=S(&YO(&QA
M<F=E(&)I;F%R>2`**B!T>7!E(&EN(%-13"TY,B!O<B!344PM.3DN(%!O<W1G
M<F5S('-E96US('1O(&QA8VL@86YY(`HJ($),3T(@;W(@5$585"!T>7!E+"!F
M;W(@35,M4U%,('EO=2!C;W5L9"!U<V4@24U!1T4L(&1O;B=T(&MN;W<@"BH@
M86)O=70@;W1H97(@9&%T86)A<V5S+B!0;&5A<V4@861D('-U9V5S=&EO;G,@
M9F]R(&]T:&5R(&1A=&%B87-E<R!T;R`**B!T:&4@:6YL:6YE(&1O8W,N"BH*
M*B!4:&4@9FEE;&0@)V-H86YG960G(&ES('5S960@8GD@=&AE(&=A<F)A9V4@
M8V]L;&5C=&EO;BX@1&5P96YD:6YG(&]N(`HJ('EO=7(@9&%T86)A<V5S>7-T
M96T@>6]U(&UI9VAT(&AA=F4@=&\@<W5B8VQA<W,@9F5T8V@H*2!A;F0@9V%R
M8F%G94-O;&QE8W1I;VXH*2X**@HJ($9O<B!?37E344Q?('EO=2!N965D('1H
M:7,@1$(@=&%B;&4Z"BH**B!#4D5!5$4@5$%"3$4@8V%C:&4@*`HJ("`@:60@
M("`@("`@("`@0TA!4B@S,BD@3D]4($Y53$P@1$5&055,5"`G)RP**B`@(&-A
M8VAE9W)O=7`@(%9!4D-(05(H,3(W*2!.3U0@3E5,3"!$149!54Q4("<G+`HJ
M("`@8V%C:&5D871A("`@0DQ/0B!.3U0@3E5,3"!$149!54Q4("<G+`HJ("`@
M=7-E<F1A=&$@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,($1%1D%53"`G)RP*
M*B`@(&5X<&ER97,@("`@($E.5"@Y*2!.3U0@3E5,3"!$149!54Q4(#`L"BH@
M(`HJ("`@8VAA;F=E9"`@("`@5$E-15-404U0*#$T*2!.3U0@3E5,3"P**B`@
M"BH@("!)3D1%6"`H97AP:7)E<RDL"BH@("!04DE-05)9($M%62`H:60L(&-A
M8VAE9W)O=7`I"BH@*0HJ"BH@"BH@0&%U=&AO<B`@(%5L9B!796YD96P@(#QU
M;&8N=V5N9&5L0'!H<&1O8RYD93XL(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`
M<V5B87-T:6%N+6)E<F=M86YN+F1E/@HJ($!V97)S:6]N("`D260Z('!H<&QI
M8BYP:'`L=B`Q+C,@,C`P,R\P,2\P-"`Q,3HU-#HT-B!M:B!%>'`@)`HJ($!P
M86-K86=E("!#86-H90HJ($!S964@("`@("!S879E*"D**B\*8VQA<W,@0V%C
M:&5?0V]N=&%I;F5R7W!H<&QI8B!E>'1E;F1S($-A8VAE7T-O;G1A:6YE<B![
M"B`@"B`@("`O*BH*("`@("H@3F%M92!O9B!T:&4@1$(@=&%B;&4@=&\@<W1O
M<F4@8V%C:&EN9R!D871A"B`@("`J(`H@("`@*B!`<V5E("!#86-H95]#;VYT
M86EN97)?9FEL93HZ)&9I;&5N86UE7W!R969I>`H@("`@*B\@(`H@("`@=F%R
M("1C86-H95]T86)L92`]("=C86-H92<["@H@("`@+RHJ"B`@("`J(%!(4$QI
M8B!O8FIE8W0*("`@("H@"B`@("`J($!V87(@(&]B:F5C="!014%27T1""B`@
M("`J+PH@("`@=F%R("1D8CL*"B`@("`O*BH*("`@("H@3F%M92!O9B!T:&4@
M4$A03&EB($1"(&-L87-S('1O('5S90H@("`@*B`*("`@("H@0'9A<B`@<W1R
M:6YG("`*("`@("H@0'-E92`@)&1B7W!A=&@L("1L;V-A;%]P871H"B`@("`J
M+PH@("`@=F%R("1D8E]C;&%S<R`]("<G.PH*("`@("\J*@H@("`@*B!&:6QE
M;F%M92!O9B!Y;W5R(&QO8V%L+FEN8PH@("`@*B`*("`@("H@268@96UP='DL
M("=L;V-A;"YI;F,G(&ES(&%S<W5M960N"B`@("`J"B`@("`J($!V87(@("`@
M("`@<W1R:6YG"B`@("`J+PH@("`@=F%R("1L;V-A;%]F:6QE(#T@)R<["@H@
M("`@+RHJ"B`@("`J($EN8VQU9&4@<&%T:"!F;W(@>6]U(&QO8V%L+FEN8PH@
M("`@*@H@("`@*B!(24Y4.B!)9B!Y;W5R)W)E(&YO="!U<VEN9R!02%!,:6(G
M<R!P<F5P96YD+G!H<"!Y;W4@;75S="`*("`@("H@=&%K92!C87)E('1H870@
M86QL(&-L87-S97,@*&9I;&5S*2!R969E<F5N8V5S(&)Y('EO=2`*("`@("H@
M;&]C86PN:6YC(&%R92!I;F-L=61E9"!A=71O;6%T:6-A;&QY+B!3;R!Y;W4@
M;6EG:'0@"B`@("`J('=A;G0@=&\@=W)I=&4@82!N97<@;&]C86PR+FEN8R!T
M:&%T(&]N;'D@<F5F97)R<R!T;R`*("`@("H@=&AE(&1A=&%B87-E(&-L87-S
M("AF:6QE*2!Y;W4G<F4@=7-I;F<@86YD(&EN8VQU9&5S(&%L;"!R97%U:7)E
M9"!F:6QE<RX*("`@("H*("`@("H@0'9A<B`@<W1R:6YG("!P871H('1O('EO
M=7(@;&]C86PN:6YC("T@;6%K92!S=7)E('1O(&%D9"!A('1R86EL:6YG('-L
M87-H"B`@("`J($!S964@("1L;V-A;%]F:6QE"B`@("`J+PH@("`@=F%R("1L
M;V-A;%]P871H(#T@)R<["@H@("`@+RHJ"B`@("`J($-R96%T97,@86X@:6YS
M=&%N8V4@;V8@82!P:'!L:6(@9&(@8VQA<W,@=&\@=7-E(&ET(&9O<B!S=&]R
M86=E+@H@("`@*@H@("`@*B!`<&%R86T@("`@;6EX960@("!)9B!E;7!T>2!T
M:&4@;V)J96-T('1R:65S('1O('5S960@=&AE(`H@("`@*B`@("`@("`@("`@
M("`@("`@("!P<F5C;VYF:6=U<F5D(&-L87-S('9A<FEA8FQE<RX@268@9VEV
M96X@:70@"B`@("`J("`@("`@("`@("`@("`@("`@(&UU<W0@8F4@86X@87)R
M87D@=VET:#H*("`@("H@("`@("`@("`@("`@("`@("`@("!D8E]C;&%S<R`]
M/B!N86UE(&]F('1H92!$0B!C;&%S<R!T;R!U<V4*("`@("H@("`@("`@("`@
M("`@("`@("`@;W!T:6]N86PZ"B`@("`J("`@("`@("`@("`@("`@("`@("`@
M9&)?9FEL92`]/B!F:6QE;F%M92!O9B!T:&4@1$(@8VQA<W,*("`@("H@("`@
M("`@("`@("`@("`@("`@("!D8E]P871H(#T^('!A=&@@=&\@=&AE($1"(&-L
M87-S"B`@("`J("`@("`@("`@("`@("`@("`@("`@;&]C86Q?9FEL92`]/B!K
M:6YD(&]F(&QO8V%L+FEN8PH@("`@*B`@("`@("`@("`@("`@("`@("`@(&QO
M8V%L7W!A=&L@/3X@<&%T:"!T;R!T:&4@;&]C86PN:6YC"B`@("`J("`@("`@
M("`@("`@("`@("`@('-E92`D;&]C86Q?<&%T:"!F;W(@<V]M92!H:6YT<RYS
M"B`@("`J($!S964@("1L;V-A;%]P871H"B`@("`J+PH@("`@9G5N8W1I;VX@
M0V%C:&5?0V]N=&%I;F5R7W!H<&QI8B@D;W!T:6]N<R`]("<G*2!["B`@("`@
M("`@:68@*&ES7V%R<F%Y*"1O<'1I;VYS*2D*("`@("`@("`@("`@)'1H:7,M
M/G-E=$]P=&EO;G,H)&]P=&EO;G,L("!A<G)A>5]M97)G92@D=&AI<RT^86QL
M;W=E9%]O<'1I;VYS+"!A<G)A>2@G9&)?8VQA<W,G+"`G9&)?9FEL92<L("=D
M8E]P871H)RP@)VQO8V%L7V9I;&4G+"`G;&]C86Q?<&%T:"<I*2D["@H@("`@
M("`@(&EF("@A)'1H:7,M/F1B7V-L87-S*0H@("`@("`@("`@("!R971U<FX@
M;F5W($-A8VAE7T5R<F]R*"=.;R!D871A8F%S92!C;&%S<R!S<&5C:69I960N
M)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@("`@+R\@:6YC;'5D92!T
M:&4@<F5Q=6ER960@9FEL97,*("`@("`@("!I9B`H)'1H:7,M/F1B7V9I;&4I
M"B`@("`@("`@("`@(&EN8VQU9&5?;VYC92@D=&AI<RT^9&)?<&%T:"`N("1T
M:&ES+3YD8E]F:6QE*3L*"B`@("`@("`@:68@*"1T:&ES+3YL;V-A;%]F:6QE
M*0H@("`@("`@("`@("!I;F-L=61E7V]N8V4H)'1H:7,M/FQO8V%L7W!A=&@@
M+B`D=&AI<RT^;&]C86Q?9FEL92D["@H@("`@("`@("\O(&-R96%T92!A(&1B
M(&]B:F5C="`*("`@("`@("`D=&AI<RT^9&(@/2!N97<@)'1H:7,M/F1B7V-L
M87-S.PH@("`@?2`O+R!E;F0@8V]N<W1R=6-T;W(*"B`@("!F=6YC=&EO;B!F
M971C:"@D:60L("1G<F]U<"D@>PH@("`@("`@("1Q=65R>2`]('-P<FEN=&8H
M(E-%3$5#5"!E>'!I<F5S+"!C86-H961A=&$L('5S97)D871A($923TT@)7,@
M5TA%4D4@:60@/2`G)7,G($%.1"!C86-H96=R;W5P(#T@)R5S)R(L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8V%C:&5?=&%B;&4L(`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&ED+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&=R;W5P"B`@("`@("`@("`@("`@("`@("`@("`@
M("`I.PH@("`@("`@("1T:&ES+3YD8BT^<75E<GDH)'%U97)Y*3L*("`@("`@
M("!I9B`H(21T:&ES+3YD8BT^3F5X=%]296-O<F0H*2D*("`@("`@("`@("`@
M<F5T=7)N(&%R<F%Y*$Y53$PL($Y53$PL($Y53$PI.PH*("`@("`@("`O+R!L
M87-T('5S960@<F5Q=6ER960@8GD@=&AE(&=A<F)A9V4@8V]L;&5C=&EO;B`@
M(`H@("`@("`@("\O(%=!4DY)3D<Z(&UI9VAT(&)E($UY4U%,('-P96-I9FEC
M("`@("`@("`@"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@B55!$051%("5S
M(%-%5"!C:&%N9V5D(#T@*$Y/5R@I("L@,"D@5TA%4D4@:60@/2`G)7,G($%.
M1"!C86-H96=R;W5P(#T@)R5S)R(L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^8V%C:&5?=&%B;&4L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D:60L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9W)O
M=7`*("`@("`@("`@("`@("`@("`@("`@("`@("`I.PH@("`@("`@("1T:&ES
M+3YD8BT^<75E<GDH)'%U97)Y*3L*("`@("`@("!R971U<FX@87)R87DH)'1H
M:7,M/F1B+3YF*"=E>'!I<F5S)RDL("1T:&ES+3YD96-O9&4H)'1H:7,M/F1B
M+3YF*"=C86-H961A=&$G*2DL("1T:&ES+3YD8BT^9B@G=7-E<F1A=&$G*2D[
M"B`@("!]("\O(&5N9"!F=6YC(&9E=&-H"@H@("`@+RHJ"B`@("`J(%-T;W)E
M<R!A(&1A=&%S970N"B`@("`J(`H@("`@*B!705).24Y'.B!W92!U<V4@=&AE
M(%-13"!C;VUM86YD(%)%4$Q!0T4@24Y43R!T:&ES(&UI9VAT(&)E(`H@("`@
M*B!->5-13"!S<&5C:69I8RX@07,@37E344P@:7,@=F5R>2!P;W!U;&%R('1H
M92!M971H;V0@<VAO=6QD"B`@("`J('=O<FL@9FEN92!F;W(@.34E(&]F('EO
M=2X*("`@("HO"B`@("!F=6YC=&EO;B!S879E*"1I9"P@)&1A=&$L("1E>'!I
M<F5S+"`D9W)O=7`I('L*("`@("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D*"1I
M9"P@)&=R;W5P*3L*"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@B4D503$%#
M12!)3E1/("5S("AC86-H961A=&$L(&5X<&ER97,L(&ED+"!C86-H96=R;W5P
M*2!604Q515,@*"<E<R<L("5D+"`G)7,G+"`G)7,G*2(L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^8V%C:&5?=&%B;&4L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A9&1S;&%S:&5S*"1T:&ES+3YE;F-O9&4H
M)&1A=&$I*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YG
M971%>'!I<F5S06)S;VQU=&4H)&5X<&ER97,I("P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1I9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1G<F]U<`H@("`@("`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`D
M=&AI<RT^9&(M/G%U97)Y*"1Q=65R>2D["@H@("`@("`@(')E='5R;B`H8F]O
M;&5A;BDD=&AI<RT^9&(M/F%F9F5C=&5D7W)O=W,H*3L@"B`@("!]("\O(&5N
M9"!F=6YC('-A=F4*"B`@("!F=6YC=&EO;B!R96UO=F4H)&ED+"`D9W)O=7`I
M('L*("`@("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D*"1I9"P@)&=R;W5P*3L*
M("`@("`@("`D=&AI<RT^9&(M/G%U97)Y*`H@("`@("`@("`@("`@("`@("`@
M("`@("!S<')I;G1F*")$14Q%5$4@1E)/32`E<R!72$5212!I9"`]("<E<R<@
M04Y$(&-A8VAE9W)O=7`@/2`G)7,G(BP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YC86-H95]T86)L92P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1I9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1G
M<F]U<`H@("`@("`@("`@("`@("`@("`@("`@("`@("D*("`@("`@("`@("`@
M("`@("`@("`I.PH*("`@("`@("!R971U<FX@*&)O;VQE86XI)'1H:7,M/F1B
M+3YA9F9E8W1E9%]R;W=S*"D["B`@("!]("\O(&5N9"!F=6YC(')E;6]V90H*
M("`@(&9U;F-T:6]N(&9L=7-H*"1G<F]U<"D@>PH@("`@("`@("1T:&ES+3YF
M;'5S:%!R96QO860H*3L*"B`@("`@("`@:68@*"1G<F]U<"D@>PH@("`@("`@
M("`@("`D=&AI<RT^9&(M/G%U97)Y*'-P<FEN=&8H(D1%3$5412!&4D]-("5S
M(%=(15)%(&-A8VAE9W)O=7`@/2`G)7,G(BP@)'1H:7,M/F-A8VAE7W1A8FQE
M+"`D9W)O=7`I*3L@("`@"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'1H:7,M/F1B+3YQ=65R>2AS<')I;G1F*")$14Q%5$4@1E)/32`E<R(L("1T
M:&ES+3YC86-H95]T86)L92DI.R`@("`*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D=&AI<RT^9&(M/F%F9F5C=&5D7W)O=W,H*3L*("`@('T@+R\@96YD
M(&9U;F,@9FQU<V@*"B`@("!F=6YC=&EO;B!I9$5X:7-T<R@D:60L("1G<F]U
M<"D@>PH@("`@("`@("1T:&ES+3YD8BT^<75E<GDH"B`@("`@("`@("`@("`@
M("`@("`@("`@('-P<FEN=&8H(E-%3$5#5"!I9"!&4D]-("5S(%=(15)%($E$
M(#T@)R5S)R!!3D0@8V%C:&5G<F]U<"`]("<E<R<B+"`*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YC86-H95]T86)L92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1I9"P@"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9W)O=7`*("`@("`@("`@("`@("`@("`@("`@("`@*2`@(`H@
M("`@("`@("`@("`@("`@("`@("D["@H@("`@("`@(')E='5R;B`H8F]O;&5A
M;BDD=&AI<RT^9&(M/FYF*"D[("`@("`@("`@("`@("`@("`@("`@("`@(`H@
M("`@?2`O+R!E;F0@9G5N8R!I<T5X:7-T<PH*("`@(&9U;F-T:6]N(&=A<F)A
M9V5#;VQL96-T:6]N*"1M87AL:69E=&EM92D@>PH@("`@("`@("1T:&ES+3YF
M;'5S:%!R96QO860H*3L*"B`@("`@("`@)'1H:7,M/F1B+3YQ=65R>2@@"B`@
M("`@("`@("`@("`@("`@("`@("`@('-P<FEN=&8H(D1%3$5412!&4D]-("5S
M(%=(15)%("AE>'!I<F5S(#P]("5D($%.1"!E>'!I<F5S(#X@,"D@3U(@8VAA
M;F=E9"`\/2`H3D]7*"D@+2`E9"DB+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/F-A8VAE7W1A8FQE+"`*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('1I;64H*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1M87AL:69E=&EM90H@("`@("`@("`@("`@("`@("`@("`@("`I"B`@("`@
M("`@("`@("`@("`@("`@*3L*"B`@("`@("`@+R]C:&5C:R!F;W(@=&]T86P@
M<VEZ92!O9B!C86-H90H@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)W-E;&5C
M="!S=6TH;&5N9W1H*&-A8VAE9&%T82DI(&%S($-A8VAE4VEZ92!F<F]M("5S
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC86-H95]T86)L
M90H@("`@("`@("`@("`@("`@("`@("`@("D["@H@("`@("`@("1T:&ES+3YD
M8BT^<75E<GDH)'%U97)Y*3L*("`@("`@("`D=&AI<RT^9&(M/DYE>'1?4F5C
M;W)D*"D["B`@("`@("`@)&-A8VAE<VEZ92`]("1T:&ES+3YD8BT^9B@G0V%C
M:&53:7IE)RD["B`@("`@("`@+R]I9B!C86-H92!I<R!T;R!B:6<N"B`@("`@
M("`@:68@*"1C86-H97-I>F4@/B`D=&AI<RT^:&EG:'=A=&5R*0H@("`@("`@
M('L*("`@("`@("`@("`@+R]F:6YD('1H92!L;W=W871E<B!M87)K+@H@("`@
M("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=S96QE8W0@;&5N9W1H*&-A8VAE
M9&%T82D@87,@<VEZ92P@8VAA;F=E9"!F<F]M("5S(&]R9&5R(&)Y(&-H86YG
M960@1$530R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^8V%C:&5?=&%B;&4*("`@("`@("`@("`@("`@("`@("`@("`I
M.PH@("`@("`@("`@("`D=&AI<RT^9&(M/G%U97)Y*"1Q=65R>2D["@H@("`@
M("`@("`@("`D:V5E<%]S:7IE/3`["B`@("`@("`@("`@('=H:6QE("@D:V5E
M<%]S:7IE(#P@)'1H:7,M/FQO=W=A=&5R("8F("1T:&ES+3YD8BT^3F5X=%]2
M96-O<F0H*2`I"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@("1K965P
M7W-I>F4@*ST@)'1H:7,M/F1B+3YF*"=S:7IE)RD["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@+R]D96QE=&4@86QL(&5N=')I97,L('=H:6-H('=E<F4@
M8VAA;F=E9"!B969O<F4@=&AE(")L;W=W=V%T97(@;6%R:R(*("`@("`@("`@
M("`@)'%U97)Y(#T@<W!R:6YT9B@G9&5L971E(&9R;VT@)7,@=VAE<F4@8VAA
M;F=E9"`\/2`G+B1T:&ES+3YD8BT^9B@G8VAA;F=E9"<I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-A8VAE7W1A8FQE
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L*"B`@("`@
M("`@("`@("1T:&ES+3YD8BT^<75E<GDH)'%U97)Y*3L*("`@("`@("!]"B`@
M("!]("\O(&5N9"!F=6YC(&=A<F)A9V5#;VQL96-T:6]N"GT*/SX`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O0V%C:&4O0V]N=&%I;F5R+W-H;2YP:'``````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`R,3$S-2`Q,#4Q-30S,S<S,"`P,C(W,3(`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$5!4B`Z.B!#86-H
M92`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B
M:F5C="!T;R!V97)S:6]N(#(N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@
M('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@
M=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA
M8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L
M:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T
M:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T
M86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N
M9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S
M;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M075T:&]R<SH@56QF(%=E;F1E;"`\=6QF+G=E;F1E;$!P:'!D;V,N9&4^("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\("`@("`@("`@(%-E8F%S
M=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/B`@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O
M"B\O("1)9#H@<VAM+G!H<"QV(#$N,R`R,#`S+S`Q+S`T(#$Q.C4T.C0V(&UJ
M($5X<"`D"@IR97%U:7)E7V]N8V4@)T-A8VAE+T-O;G1A:6YE<BYP:'`G.PH*
M+RHJ"BH@4W1O<F5S(&-A8VAE(&1A=&$@:6YT;R!S:&%R960@;65M;W)Y+@HJ
M"BH@5V5L;"P@=&AI<R!I<R!N;W0@82!V97)Y(&5F9FEC:65N="!I;7!L96UE
M;G1A=&EO;BX@26YD965D(&ET)W,@;75C:"`**B!S;&]W97(@=&AA;B!T:&4@
M9FEL92!C;VYT86EN97(@87,@9F%R(&%S(&UY('1E<W1S('-H;W=E9"X@1FEL
M97,@87)E(`HJ(&-A8VAE9"!B>2!M;W-T(&]P97)A=&EN9R!S>7-T96US(&%N
M9"!I="!W:6QL(&)E(&AA<F0@=&\@=W)I=&4@82!F87-T97(@"BH@8V%C:&EN
M9R!A;&=O<FET:&T@=7-I;F<@4$A0+@HJ"BH@0&%U=&AO<B`@(%5L9B!796YD
M96P@/'5L9BYW96YD96Q`<&AP9&]C+F1E/@HJ($!V97)S:6]N("`D260Z('-H
M;2YP:'`L=B`Q+C,@,C`P,R\P,2\P-"`Q,3HU-#HT-B!M:B!%>'`@)`HJ($!P
M86-K86=E("!#86-H90HJ+PIC;&%S<R!#86-H95]#;VYT86EN97)?<VAM(&5X
M=&5N9',@0V%C:&5?0V]N=&%I;F5R('L*("`@("\J*@H@("`@*B!+97D@;V8@
M=&AE('-E;6%P:&]R92!U<V5D('1O('-Y;F,@=&AE(%-(32!A8V-E<W,*("`@
M("H@"B`@("`J($!V87(@(&EN=`H@("`@*B\*("`@('9A<B`D<V5M7VME>2`]
M($Y53$P["@H@("`@+RHJ"B`@("`J(%!E<FUI<W-I;VYS(&]F('1H92!S96UA
M<&AO<F4@=7-E9"!T;R!S>6YC('1H92!32$T@86-C97-S"B`@("`J(`H@("`@
M*B!`=F%R("!I;G0*("`@("HO"B`@("!V87(@)'-E;5]P97)M(#T@,#8T-#L*
M"B`@("`O*BH*("`@("H@4V5M87!H;W)E(&AA;F1L97(*("`@("H@"B`@("`J
M($!V87(@(')E<V]U<F-E"B`@("`J+PH@("`@=F%R("1S96U?:60@/2!.54Q,
M.PH*("`@("\J*@H@("`@*B!+97D@;V8@=&AE('-H87)E9"!M96UO<GD@8FQO
M8VL@=7-E9"!T;R!S=&]R92!C86-H92!D871A"B`@("`J"B`@("`J($!V87(@
M(&EN=`H@("`@*B\*("`@('9A<B`D<VAM7VME>2`]($Y53$P["@H@("`@+RHJ
M"B`@("`J(%-I>F4@;V8@=&AE('-H87)E9"!M96UO<GD@8FQO8VL@=7-E9`H@
M("`@*B`*("`@("H@3F]T93H@=&AE(&-O;G1A:6YE<B!D;V5S(&]N;'D@=7-E
M(%]O;F5?('-H;2!B;&]C:R!N;R!M;W)E(0H@("`@*B`*("`@("H@0'9A<B`@
M:6YT"B`@("`J+R`@("`@("`@"B`@("!V87(@)'-H;5]S:7IE(#T@,3,Q,#<R
M.PH*("`@("\J*@H@("`@*B!097)M:7-S:6]N<R!O9B!T:&4@<VAA<F5D(&UE
M;6]R>2!B;&]C:PH@("`@*B`*("`@("H@0'9A<B`@:6YT"B`@("`J+PH@("`@
M=F%R("1S:&U?<&5R;2`](#`V-#0["@H@("`@+RHJ"B`@("`J(%-H87)E9"!M
M96UO<GD@:&%N9&QE<@H@("`@*B`*("`@("H@0'9A<B!R97-O=7)C90H@("`@
M*B\*("`@('9A<B`D<VAM7VED(#T@3E5,3#L*"B`@("`O*BH*("`@("H@2&%S
M:"!O9B!C86-H92!E;G1R:65S"B`@("`J(`H@("`@*B!5<V5D(&)Y('1H92!G
M87)B86=E(&-O;&QE8W1I;VX@=&\@9FEN9"!O;&0@96YT<FEE<RX*("`@("H*
M("`@("H@0'9A<B`@87)R87D*("`@("HO"B`@("!V87(@)&5N=')I97,@/2!A
M<G)A>2@I.PH*("`@("\J*@H@("`@*B!.=6UB97(@;V8@8GET97,@8V]N<W5M
M960@8GD@=&AE(&-A8VAE"B`@("`J(`H@("`@*B!`=F%R("!I;G0*("`@("HO
M"B`@("!V87(@)'1O=&%L7W-I>F4@/2`P.PH*("`@("\J*@H@("`@*B!#<F5A
M=&5S(&$@<VAA<F5D(&UE;6]R>2!C;VYT86EN97(*("`@("H*("`@("H@0'!A
M<F%M(&%R<F%Y("`@('-H;5]K97DL('-E;5]K97DL('-H;5]S:7IE+"!S96U?
M<&5R;2P@<VAM7W!E<FT*("`@("HO("`@(`H@("`@9G5N8W1I;VX@0V%C:&5?
M0V]N=&%I;F5R7W-H;2@D;W!T:6]N<R`]("<G*2!["B`@("`@("`@:68@*&ES
M7V%R<F%Y*"1O<'1I;VYS*2D*("`@("`@("`@("`@)'1H:7,M/G-E=$]P=&EO
M;G,H)&]P=&EO;G,L(&%R<F%Y7VUE<F=E*"1T:&ES+3YA;&QO=V5D7V]P=&EO
M;G,L(`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)W-H;5]K97DG+"`@)W-E;5]K97DG+"`*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=S:&U?<VEZ92<L("=S96U?<&5R;2<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G<VAM7W!E<FTG"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("D*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("D*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("D["@H@("`@("`@("\O($-A8VAE.CI#;VYT86EN97(@:&EG
M:"T@86YD(&QO=W=A=&5R(&1E9F%U;'1S('-H;W5L9"!B92!O=F5R<FED9&5N
M(&EF"B`@("`@("`@+R\@;F]T(&%L<F5A9'D@9&]N92!B>2!T:&4@=7-E<@H@
M("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;)VAI9VAW871E<B==*2D@"B`@
M("`@("`@("`@("1T:&ES+3YH:6=H=V%T97(@/2!R;W5N9"@P+C<U("H@,3,Q
M,#<R*3L*("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=L;W=W871E<B==
M*2D*("`@("`@("`@("`@)'1H:7,M/FQO=W=A=&5R(#T@<F]U;F0H,"XU("H@
M,3,Q,#<R*3L*"B`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG<VAM7W-I
M>F4G72DI"B`@("`@("`@("`@("1T:&ES+3YS:&U?<VEZ92`](#$S,3`W,CL*
M"B`@("`@("`@+R]G970@4TA-(&%N9"!396UA<&AO<F4@:&%N9&QE<PH@("`@
M("`@(&EF("@A*"1T:&ES+3YS:&U?:60@/2!S:&UO<%]O<&5N*"1T:&ES+3YS
M:&U?:V5Y+"`G8R<L("1T:&ES+3YS:&U?<&5R;2P@)'1H:7,M/G-H;5]S:7IE
M*2DI"B`@("`@("`@("`@(&YE=R!#86-H95]%<G)O<B@B0V%N)W0@;W!E;B!3
M2$T@<V5G;65N="`G>R1T:&ES+3YS:&U?:V5Y?2<L('-I>F4@)WLD=&AI<RT^
M<VAM7W-I>F5])RXB+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&
M24Q%7U\L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7TQ)3D5?7PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`I.PH*("`@("`@("!I9B`H(2@D
M=&AI<RT^<V5M7VED(#T@<V5M7V=E="@D=&AI<RT^<V5M7VME>2P@,2P@)'1H
M:7,M/G-E;5]P97)M*2DI"B`@("`@("`@("`@(&YE=R!#86-H95]%<G)O<B@B
M0V%N)W0@9V5T('-E;6%P:&]R92`G>R1T:&ES+3YS96U?:V5Y?2<@=7-I;F<@
M<&5R;7,@)WLD=&AI<RT^<V5M7W!E<FU])RXB+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@7U]&24Q%7U\L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!?7TQ)3D5?7PH@("`@("`@("`@("`@("`@("`@("`@("`@("`I.PH*
M("`@('T@+R\@96YD(&-O;G-T<G5C=&]R"@H@("`@9G5N8W1I;VX@9F5T8V@H
M)&ED+"`D9W)O=7`I('L*("`@("`@("!S96U?86-Q=6ER92@D=&AI<RT^<V5M
M7VED*3L*"B`@("`@("`@)&-A8VAE9&%T82`]('-H;6]P7W)E860H)'1H:7,M
M/G-H;5]I9"P@,"P@)'1H:7,M/G-H;5]S:7IE*3L*"B`@("`@("`@<V5M7W)E
M;&5A<V4H)'1H:7,M/G-E;5]I9"D["@H@("`@("`@("1C86-H961A=&$@/2`D
M=&AI<RT^9&5C;V1E*"1C86-H961A=&$I.PH*("`@("`@("!I9B`H(6ES<V5T
M*"1C86-H961A=&%;)&=R;W5P75LD:61=*2D*("`@("`@("`@("`@<F5T=7)N
M(&%R<F%Y*$Y53$PL($Y53$PL($Y53$PI.PH@("`@("`@(&5L<V4@"B`@("`@
M("`@("`@("1C86-H961A=&$@/2`D8V%C:&5D871A6R1G<F]U<%U;)&ED73L*
M"B`@("`@("`@<F5T=7)N(&%R<F%Y*"1C86-H961A=&%;)V5X<&ER92==+`H@
M("`@("`@("`@("`@("`@("`@("`D8V%C:&5D871A6R=C86-H961A=&$G72P*
M("`@("`@("`@("`@("`@("`@("`@)&-A8VAE9&%T85LG=7-E<F1A=&$G70H@
M("`@("`@("`@("`@("`@("`@("D["B`@("!]("\O(&5N9"!F=6YC(&9E=&-H
M"@H@("`@9G5N8W1I;VX@<V%V92@D:60L("1D871A+"`D97AP:7)E+"`D9W)O
M=7`L("1U<V5R9&%T82D@>PH@("`@("`@("1T:&ES+3YF;'5S:%!R96QO860H
M)&ED+"`D9W)O=7`I.PH*("`@("`@("!S96U?86-Q=6ER92@D=&AI<RT^<V5M
M7VED*3L*"B`@("`@("`@)&-A8VAE9&%T82`]("1T:&ES+3YD96-O9&4H<VAM
M;W!?<F5A9"@D=&AI<RT^<VAM7VED+"`P+"`D=&AI<RT^<VAM7W-I>F4I*3L*
M("`@("`@("`D8V%C:&5D871A6R1G<F]U<%U;)&ED72`](&%R<F%Y*"=E>'!I
M<F4G("`@(#T^("1T:&ES+3YG971%>'!I<F5S06)S;VQU=&4H)&5X<&ER92DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8V%C
M:&5D871A)R`]/B`D9&%T82P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=U<V5R9&%T82<@(#T^("1U<V5R9&%T82P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=C:&%N9V5D)R`@
M(#T^('1I;64H*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`I.PH*("`@("`@("!I9B`H<W1R;&5N*"1N97=D871A(#T@)'1H:7,M
M/F5N8V]D92@D8V%C:&5D871A*2D@/B`D=&AI<RT^<VAM7W-I>F4I"B`@("`@
M("`@("`@("1C86-H961A=&$@/2`D=&AI<RT^9V%R8F%G94-O;&QE8W1I;VXH
M=&EM92@I+"`D8V%C:&5D871A*3L*"B`@("`@("`@<VAM;W!?=W)I=&4H)'1H
M:7,M/G-H;5]I9"P@)&YE=V1A=&$L(#`I.PH*("`@("`@("!S96U?<F5L96%S
M92@D=&AI<RT^<V5M7VED*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M("\O(&5N9"!F=6YC('-A=F4*"B`@("!F=6YC=&EO;B!R96UO=F4H)&ED+"`D
M9W)O=7`I('L*("`@("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D*"1I9"P@)&=R
M;W5P*3L*"B`@("`@("`@<V5M7V%C<75I<F4H)'1H:7,M/G-E;5]I9"D["@H@
M("`@("`@("1C86-H961A=&$@/2`D=&AI<RT^9&5C;V1E*'-H;6]P7W)E860H
M)'1H:7,M/G-H;5]I9"P@,"P@)'1H:7,M/G-H;5]S:7IE*2D["B`@("`@("`@
M=6YS970H)&-A8VAE9&%T85LD9W)O=7!=6R1I9%TI.PH@("`@("`@('-H;6]P
M7W=R:71E*"1T:&ES+3YS:&U?:60L("1T:&ES+3YE;F-O9&4H)&-A8VAE9&%T
M82DL(#`I.PH*("`@("`@("!S96U?<F5L96%S92@D=&AI<RT^<V5M7VED*3L*
M("`@('T@+R\@96YD(&9U;F,@<F5M;W9E"@H@("`@9G5N8W1I;VX@9FQU<V@H
M)&=R;W5P(#T@)R<I('L*("`@("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D*"D[
M"@H@("`@("`@('-E;5]A8W%U:7)E*"1T:&ES+3YS96U?:60I.PH*("`@("`@
M("!S:&UO<%]W<FET92@D=&AI<RT^<VAM7VED+"`D=&AI<RT^96YC;V1E*&%R
M<F%Y*"DI+"`P*3L*"B`@("`@("`@<V5M7W)E;&5A<V4H)'1H:7,M/G-E;5]I
M9"D["B`@("!]("\O(&5N9"!F=6YC(&9L=7-H"@H@("`@9G5N8W1I;VX@:61%
M>&ES=',H)&ED+"`D9W)O=7`I('L*("`@("`@("!S96U?86-Q=6ER92@D=&AI
M<RT^<V5M7VED*3L*"B`@("`@("`@)&-A8VAE9&%T82`]('-H;5]R96%D*"1T
M:&ES+3YS:&U?:60L(#`L("1T:&ES+3YS:&U?<VEZ92D["@H@("`@("`@('-E
M;5]R96QE87-E*"1T:&ES+3YS96U?:60I.PH*("`@("`@("`D8V%C:&5D871A
M(#T@)'1H:7,M/F1E8V]D92@D8V%C:&5D871A*3L*"B`@("`@("`@<F5T=7)N
M(&ES<V5T*"1C86-H961A=&%;)&=R;W5P75LD:61=*3L*("`@('T@+R\@96YD
M(&9U;F,@:7-%>&ES=',*"B`@("!F=6YC=&EO;B!G87)B86=E0V]L;&5C=&EO
M;B@D;6%X;&EF971I;64L("1C86-H961A=&$@/2!A<G)A>2@I*2!["B`@("`@
M("`@:68@*"1L;V-K(#T@96UP='DH)&-A8VAE9&%T82DI('L*("`@("`@("`@
M("`@<V5M7V%C<75I<F4H)'1H:7,M/G-E;5]I9"D["B`@("`@("`@("`@("1C
M86-H961A=&$@/2`D=&AI<RT^9&5C;V1E*'-H;6]P7W)E860H)'1H:7,M/G-H
M;5]I9"P@,"P@)'1H:7,M/G-H;5]S:7IE*2D["B`@("`@("`@?0H*("`@("`@
M("`D=&AI<RT^9&]'87)B86=E0V]L;&5C=&EO;B@D;6%X;&EF971I;64L("8D
M8V%C:&5D871A*3L*("`@("`@("!I9B`H)'1H:7,M/G1O=&%L7W-I>F4@/B`D
M=&AI<RT^:&EG:'=A=&5R*2!["B`@("`@("`@("`@(&MR<V]R="@D=&AI<RT^
M96YT<FEE<RD["B`@("`@("`@("`@(')E<V5T*"1T:&ES+3YE;G1R:65S*3L*
M"B`@("`@("`@("`@('=H:6QE("@D=&AI<RT^=&]T86Q?<VEZ92`^("1T:&ES
M+3YL;W=W871E<B`F)B!L:7-T*"1S:7IE+"`D96YT<FEE<RD@/2!E86-H*"1T
M:&ES+3YE;G1R:65S*2D@>PH@("`@("`@("`@("`@("`@<F5S970H)&5N=')I
M97,I.PH*("`@("`@("`@("`@("`@('=H:6QE("AL:7-T*"1K+"`D96YT<GDI
M(#T@96%C:"@D96YT<FEE<RDI('L*("`@("`@("`@("`@("`@("`@("!U;G-E
M="@D8V%C:&5D871A6R1E;G1R>5LG9W)O=7`G75U;)&5N=')Y6R=I9"==72D[
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G1O=&%L7W-I>F4@+3T@)'-I
M>F4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(&EF("@D;&]C:RD*("`@("`@("`@("`@<V5M7W)E;&5A<V4H
M)'1H:7,M/G-E;5]I9"D["@H@("`@("`@("1T:&ES+3YE;G1R:65S(#T@87)R
M87DH*3L*("`@("`@("`D=&AI<RT^=&]T86Q?<VEZ92`](#`["@H@("`@("`@
M(')E='5R;B`D8V%C:&5D871A.R`@("`@("`@("`@"B`@("!]("\O(&5N9"!F
M=6YC(&=A<F)A9V5#;VQL96-T:6]N"@H@("`@9G5N8W1I;VX@9&]'87)B86=E
M0V]L;&5C=&EO;B@D;6%X;&EF971I;64L("8D8V%C:&5D871A*2!["B`@("`@
M("`@)&-H86YG960@/2!T:6UE*"D@+2`D;6%X;&EF971I;64["B`@("`@("`@
M)')E;6]V960@/2`P.PH*("`@("`@("!R97-E="@D8V%C:&5D871A*3L*"B`@
M("`@("`@=VAI;&4@*&QI<W0H)&=R;W5P+"`D9W)O=7!D871A*2`](&5A8V@H
M)&-A8VAE9&%T82DI('L*("`@("`@("`@("`@<F5S970H)&=R;W5P9&%T82D[
M"@H@("`@("`@("`@("!W:&EL92`H;&ES="@D:60L("1D871A*2`](&5A8V@H
M)&=R;W5P9&%T82DI('L*("`@("`@("`@("`@("`@(&EF("@D9&%T85LG97AP
M:7)E)UT@/"!T:6UE*"D@?'P@)&1A=&%;)V-H86YG960G72`\("1C:&%N9V5D
M*2!["B`@("`@("`@("`@("`@("`@("`@=6YS970H)&-A8VAE9&%T85LD9W)O
M=7!=6R1I9%TI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`O+R!U9VQY(&)U="!S:6UP;&4@=&\@:6UP;&5M96YT(#HO
M"B`@("`@("`@("`@("1S:7IE(#T@<W1R;&5N*"1T:&ES+3YE;F-O9&4H)&1A
M=&$I*3L*("`@("`@("`@("`@)'1H:7,M/F5N=')I97-;)'-I>F5=6UT@/2!A
M<G)A>2@G9W)O=7`G(#T^("1G<F]U<"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G:60G("`@(#T^("1I9`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L*"B`@("`@
M("`@("`@("1T:&ES+3YT;W1A;%]S:7IE("L]("1S:7IE.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1R96UO=F5D.PH@("`@?2`@+R\@96YD(&9U;F,@
M9&]'87)B86=E0V]L;&5C=&EO;@I]("\O(&5N9"!C;&%S<R!#86-H95]#;VYT
M86EN97)?<VAM"C\^"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]#86-H92]#;VYT86EN97(O=')I9FEL92YP:'``````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$Q,C,T(#$P-3$U-#,S-S,P(#`R,S4V
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!014%2
M(#HZ($-A8VAE("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`T(%1H92!02%`@
M1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL
M92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP(&]F('1H92!02%`@;&EC96YS
M92P@("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C
M:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@
M?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C
M;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*
M+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L
M96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P
M:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN
M("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\@?"!!=71H;W)S.B!5;&8@5V5N9&5L(#QU;&8N=V5N9&5L0'!H<&1O
M8RYD93X@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@
M("`@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN
M9&4^("`@("`@("`@("`@("`@?`HO+R!\("`@("`@("`@($EA;B!%=7)E(#QI
M975R94!P:'`N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)
M9#H@=')I9FEL92YP:'`L=B`Q+C$@,C`P-"\P-"\P,2`P-SHU,#HP-R!C:')E
M9W4@17AP("0*"G)E<75I<F5?;VYC92`G0V%C:&4O0V]N=&%I;F5R+V9I;&4N
M<&AP)SL*"B\J*@H@*B!4<FDM9FEL92!C86-H92X*("H*("H@5&AI<R!C86-H
M92!C;VYT86EN97(@<W1O<F5S(&9I;&5S('=I=&@@;F\@<W!E8VEA;"!E;F-O
M9&EN9R!T;R!R961U8V4@;W9E<FAE860N"B`J($5X<&ER871I;VX@)B!U<V5R
M(&1A=&$@87)E('-T;W)E9"!I;B!S97!E<F%T92!F:6QE<RP@<')E9FEX960@
M=VET:"!A("<N)R!A;F0*("H@<W5F9FEX960@=VET:"`G+F5X<"<@)B`G+F1A
M="<@<F5S<&5C=&EV96QY+@H@*@H@*B!3964@:'1T<#HO+V%T;VUI>F5D+F]R
M9R]014%2+T-A8VAE7W1R:69I;&4N:'1M;"!F;W(@;6]R92!I;F9O<FUA=&EO
M;BX*("H*("H@0&%U=&AO<B!)86X@175R92`\:65U<F5`<&AP+FYE=#X*("H@
M0'9E<G-I;VX@,2XP"B`J+PIC;&%S<R!#86-H95]#;VYT86EN97)?=')I9FEL
M92!E>'1E;F1S($-A8VAE7T-O;G1A:6YE<E]F:6QE('L*("`@("\J*@H@("`@
M("H@1F5T8V@@8V%C:&5D(&9I;&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D:60@0V%C:&4@240@=&\@9F5T8V@*("`@("`J($!P87)A;2!S=')I
M;F<@)&=R;W5P($=R;W5P('1O(&9E=&-H(&9R;VT*("`@("`J($!R971U<FX@
M87)R87D@,2UD:6UE;G-I;VYA;"!A<G)A>2!I;B!T:&4@9F]R;6%T.B!E>'!I
M<F%T:6]N+&1A=&$L=7-E<F1A=&$*("`@("`J+PH@("`@9G5N8W1I;VX@9F5T
M8V@H)&ED+"`D9W)O=7`I"B`@("!["B`@("`@("`@)&9I;&4@/2`D=&AI<RT^
M9V5T1FEL96YA;64H)&ED+"`D9W)O=7`I.PH@("`@("`@(&EF("@A9FEL95]E
M>&ES=',H)&9I;&4I*0H@("`@("`@("`@("!R971U<FX@87)R87DH3E5,3"P@
M3E5,3"P@3E5,3"D["B`@("`@("`@"B`@("`@("`@<F5T=7)N(&%R<F%Y*`H@
M("`@("`@("`@("`@("`@9FEL95]G971?8V]N=&5N=',H)'1H:7,M/E]G971%
M>'!&:6QE*"1F:6QE*2DL"B`@("`@("`@("`@("`@("!F:6QE7V=E=%]C;VYT
M96YT<R@D9FEL92DL"B`@("`@("`@("`@("`@("!F:6QE7V=E=%]C;VYT96YT
M<R@D=&AI<RT^7V=E=%5$1FEL92@D9FEL92DI"B`@("`@("`@*3L*("`@('T*
M("`@(`H@("`@+RHJ"B`@("`@*B!'970@=&AE(&9I;&4@=&\@<W1O<F4@8V%C
M:&4@9&%T82!I;BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R!#86-H
M92!D871A(&9I;&4@;F%M90H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]G971&:6QE*"1F:6QE*0H@("`@>PH@("`@("`@
M("1D:7(@/2!D:7)N86UE*"1F:6QE*3L*("`@("`@("`D9FEL92`](&)A<V5N
M86UE*"1F:6QE*3L*("`@("`@("!R971U<FX@)&1I<BXG+RXG+B1F:6QE.PH@
M("`@?0H@("`@"B`@("`O*BH*("`@("`J($=E="!T:&4@9FEL92!T;R!S=&]R
M92!E>'!I<F%T:6]N(&1A=&$@:6XN"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@17AP:7)A=&EO;B!D871A(&9I;&4@;F%M90H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971%>'!&:6QE*"1F
M:6QE*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V=E=$9I;&4H)&9I
M;&4I+B<N97AP)SL*("`@('T*("`@(`H@("`@+RHJ"B`@("`@*B!'970@=&AE
M(&9I;&4@=&\@<W1O<F4@=7-E<B!D871A(&EN+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG(%5S97(@9&%T82!F:6QE(&YA;64*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T541&:6QE*"1F
M:6QE*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V=E=$9I;&4H)&9I
M;&4I+B<N9&%T)SL*("`@('T*("`@(`H@("`@+RHJ"B`@("`@*B!#86-H92!F
M:6QE"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@0V%C:&4@240*
M("`@("`J($!P87)A;2!M:7AE9"`D8V%C:&5D871A($1A=&$@=&\@8V%C:&4*
M("`@("`J($!P87)A;2!M:7AE9"`D97AP:7)E<R!7:&5N('1H92!D871A(&5X
M<&ER97,*("`@("`J($!P87)A;2!S=')I;F<@)&=R;W5P($-A8VAE(&=R;W5P
M('1O('-T;W)E(&1A=&$@:6X*("`@("`J($!P87)A;2!M:7AE9"`D=7-E<F1A
M=&$@061D:71I;VYA;"!D871A('1O('-T;W)E"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@=')U92!O;B!S=6-C97-S+"!F86QS92!O=&AE<G=I<V4*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V%V92@D:60L("1C86-H961A=&$L("1E>'!I<F5S
M+"`D9W)O=7`L("1U<V5R9&%T82D*("`@('L*("`@("`@("`D=&AI<RT^9FQU
M<VA0<F5L;V%D*"1I9"P@)&=R;W5P*3L*"B`@("`@("`@)&9I;&4@/2`D=&AI
M<RT^9V5T1FEL96YA;64H)&ED+"`D9W)O=7`I.PH@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1R97,@/2`D=&AI<RT^7W-A=F5$871A*"1F:6QE+"`D8V%C
M:&5D871A*2DI('L*("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@
M?0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1R97,@/2`D=&AI<RT^7W-A
M=F5$871A*"1T:&ES+3Y?9V5T17AP1FEL92@D9FEL92DL("1E>'!I<F5S*2DI
M('L*("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@?0H@("`@("`@
M(&EF*%!%05(Z.FES17)R;W(H)')E<R`]("1T:&ES+3Y?<V%V941A=&$H)'1H
M:7,M/E]G97151$9I;&4H)&9I;&4I+"`D=7-E<D1A=&$I*2D@>PH@("`@("`@
M("`@("!R971U<FX@)')E<SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4V%V92!D871A(&EN(&$@9FEL
M90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&4@1FEL92!T;R!S
M879E(&1A=&$@:6X*("`@("`J($!P87)A;2!S=')I;F<@)&1A=&$@1&%T82!T
M;R!S879E"B`@("`@*B!`<F5T=7)N(&UI>&5D('1R=64@;VX@<W5C8V5S<RP@
M0V%C:&5?17)R;W(@;W1H97)W:7-E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S
M879E1&%T82@D9FEL92P@)&1A=&$I('L*("`@("`@("`O+R!3879E(&1A=&$*
M("`@("`@("!I9B`H(2@D9F@@/2!`9F]P96XH)&9I;&4L("=W8B<I*2D*("`@
M("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@B0V%N)W0@86-C97-S
M("<D9FEL92<@=&\@<W1O<F4@8V%C:&4@9&%T82X@0VAE8VL@86-C97-S(')I
M9VAT<R!A;F0@<&%T:"XB+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@
M(`H@("`@("`@(&EF("@D=&AI<RT^9FEL94QO8VMI;F<I('L*("`@("`@("`@
M("`@9FQO8VLH)&9H+"!,3T-+7T58*3L*("`@("`@("!]"B`@("`@("`@"B`@
M("`@("`@9G=R:71E*"1F:"P@)&1A=&$I.PH@("`@("`@(`H@("`@("`@(&EF
M*"1T:&ES+3YF:6QE3&]C:VEN9RD@>PH@("`@("`@("`@("!F;&]C:R@D9F@L
M($Q/0TM?54XI.PH@("`@("`@('T*("`@("`@("`*("`@("`@("!F8VQO<V4H
M)&9H*3L*("`@("`@("!R971U<FX@=')U93L*("`@('T*?0H*/SX`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O0V%C:&4O0V]N=&%I;F5R+V1B>"YP:'``````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R,C<U,2`Q,#4Q-30S,S<S
M,"`P,C(W,#4`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O
M('P@4$5!4B`Z.B!#86-H92`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4
M:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U
M<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,"!O9B!T:&4@4$A0
M(&QI8V5N<V4L("`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T
M:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@
M("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M
M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E
M:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@
M=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M
M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI
M8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D
M:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@075T:&]R<SH@0VAR:7-T:6%N(%-T;V-K97(@/&-H
M<F5G=4!P:&%N="YC:#X@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!D8G@N<&AP
M+'8@,2XT(#(P,#,O,#$O,#0@,3$Z-30Z-#8@;6H@17AP("0*"@IR97%U:7)E
M7V]N8V4@)T-A8VAE+T-O;G1A:6YE<BYP:'`G.PH*+RHJ"BH@97AT+V1B>"!#
M86-H92!#;VYT86EN97(N"BH**B!705).24Y'.B!/=&AE<B!S>7-T96US(&UI
M9VAT(&]R(&UI9VAT(&YO="!S=7!P;W)T(&-E<G1A:6X@9&%T871Y<&5S(&]F
M(`HJ('1H92!T86)L97,@<VAO=VXN($%S(&9A<B!A<R!)(&MN;W<@=&AE<F4G
M<R!N;R!L87)G92!B:6YA<GD@"BH@='EP92!I;B!344PM.3(@;W(@4U%,+3DY
M+B!0;W-T9W)E<R!S965M<R!T;R!L86-K(&%N>2`**B!"3$]"(&]R(%1%6%0@
M='EP92P@9F]R($U3+5-13"!Y;W4@8V]U;&0@=7-E($E-04=%+"!D;VXG="!K
M;F]W(`HJ(&%B;W5T(&]T:&5R(&1A=&%B87-E<RX@4&QE87-E(&%D9"!S=6=E
M<W1I;VYS(&9O<B!O=&AE<B!D871A8F%S97,@=&\@"BH@=&AE(&EN;&EN92!D
M;V-S+@HJ"BH@5&AE(&9I96QD("=C:&%N9V5D)R!H87,@;F\@;65A;FEN9R!F
M;W(@=&AE($-A8VAE(&ET<V5L9BX@270G<R!J=7-T('1H97)E(`HJ(&)E8V%U
M<V4@:70G<R!A(&=O;V0@:61E82!T;R!H879E(&%N(&%U=&]M871I8V%L;'D@
M=7!D871E9"!T:6UE<W1A;7`**B!F:65L9"!F;W(@9&5B=6=G:6YG(&EN(&%L
M;"!O9B!Y;W5R('1A8FQE<RX**@HJ($9O<B!?37E344Q?('EO=2!N965D('1H
M:7,@1$(@=&%B;&4Z"BH**B!#4D5!5$4@5$%"3$4@8V%C:&4@*`HJ("`@:60@
M("`@("`@("`@0TA!4B@S,BD@3D]4($Y53$P@1$5&055,5"`G)RP**B`@(&-A
M8VAE9W)O=7`@(%9!4D-(05(H,3(W*2!.3U0@3E5,3"!$149!54Q4("<G+`HJ
M("`@8V%C:&5D871A("`@0DQ/0B!.3U0@3E5,3"!$149!54Q4("<G+`HJ("`@
M=7-E<F1A=&$@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,($1%1D%53%0@)R<L
M"BH@("!E>'!I<F5S("`@("!)3E0H.2D@3D]4($Y53$P@1$5&055,5"`P+`HJ
M("`**B`@(&-H86YG960@("`@(%1)34535$%-4"@Q-"D@3D]4($Y53$PL"BH@
M(`HJ("`@24Y$15@@*&5X<&ER97,I+`HJ("`@4%))34%262!+15D@*&ED+"!C
M86-H96=R;W5P*0HJ("D**@HJ($!A=71H;W(@("!#:')I<W1I86X@4W1O8VME
M<B`\8VAR96=U0'!H86YT+F-H/@HJ($!V97)S:6]N("`D260Z(&1B>"YP:'`L
M=B`Q+C0@,C`P,R\P,2\P-"`Q,3HU-#HT-B!M:B!%>'`@)`HJ($!P86-K86=E
M("!#86-H90HJ+PIC;&%S<R!#86-H95]#;VYT86EN97)?9&)X(&5X=&5N9',@
M0V%C:&5?0V]N=&%I;F5R('L*"B`@("`O*BH*("`@("H@3F%M92!O9B!T:&4@
M1$(@=&%B;&4@=&\@<W1O<F4@8V%C:&EN9R!D871A"B`@("`J(`H@("`@*B!`
M<V5E("!#86-H95]#;VYT86EN97)?9FEL93HZ)&9I;&5N86UE7W!R969I>`H@
M("`@*B\@(`H@("`@=F%R("1C86-H95]T86)L92`]("<G.PH*("`@("\J*@H@
M("`@*B!$0G@@;6]D=6QE('1O('5S90H@("`@*@H@("`@*B`@870@=&AE(&UO
M;65N="!O;FQY(&UY<W%L(&]R(&]D8F,*("`@("H@"B`@("`J($!V87(@('-T
M<FEN9PH@("`@*B\*("`@('9A<B`D;6]D=6QE(#T@)R<["@H@("`@+RHJ"B`@
M("`J($1"(&AO<W0@=&\@=7-E"B`@("`J(`H@("`@*B!`=F%R("!S=')I;F<*
M("`@("HO"B`@("!V87(@)&AO<W0@/2`G)SL*"B`@("`O*BH*("`@("H@1$(@
M9&%T86)A<V4@=&\@=7-E"B`@("`J(`H@("`@*B!`=F%R("!S=')I;F<*("`@
M("HO"B`@("!V87(@)&1B(#T@)R<["@H@("`@+RHJ"B`@("`J($1"('5S97)N
M86UE('1O('5S90H@("`@*B`*("`@("H@0'9A<B`@<W1R:6YG"B`@("`J+PH@
M("`@=F%R("1U<V5R;F%M92`]("<G.PH*("`@("\J*@H@("`@*B!$0B!P87-S
M=V]R9"!T;R!U<V4*("`@("H@"B`@("`J($!V87(@('-T<FEN9PH@("`@*B\*
M("`@('9A<B`D<&%S<W=O<F0@/2`G)SL*"B`@("`O*BH*("`@("H@1$)X(&AA
M;F1L92!O8FIE8W0*("`@("H@"B`@("`J($!V87(@(&]B:F5C="!$0G@@:&%N
M9&QE"B`@("`J+PH@("`@=F%R("1D8CL*("`@(`H@("`@"B`@("`O*BH*("`@
M("H@17-T86)L:7-H(&$@<&5R<VES=&5N="!C;VYN96-T:6]N/PH@("`@*B`*
M("`@("H@0'9A<B`@8F]O;&5A;B`*("`@("HO"B`@("!V87(@)'!E<G-I<W1E
M;G0@/2!T<G5E.PH@("`@"@H@("`@9G5N8W1I;VX@0V%C:&5?0V]N=&%I;F5R
M7V1B>"@D;W!T:6]N<RD*("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1O
M<'1I;VYS*2`I('L*("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O
M<B@G3F\@;W!T:6]N<R!S<&5C:69I960A)RP@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YS971/<'1I;VYS*"1O<'1I
M;VYS+"`@87)R87E?;65R9V4H)'1H:7,M/F%L;&]W961?;W!T:6]N<RP@87)R
M87DH)VUO9'5L92<L)VAO<W0G+"=D8B<L)W5S97)N86UE)RPG<&%S<W=O<F0G
M+"`G8V%C:&5?=&%B;&4G+"`G<&5R<VES=&5N="<I*2D["@H@("`@("`@(&EF
M("@A)'1H:7,M/FUO9'5L92D*("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H
M95]%<G)O<B@G3F\@;6]D=6QE('-P96-I9FEE9"$G+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH*("`@("`@("`D=&AI<RT^9&(@/2!D8GA?8V]N;F5C="@D=&AI
M<RT^;6]D=6QE+"`D=&AI<RT^:&]S="P@)'1H:7,M/F1B+"`D=&AI<RT^=7-E
M<FYA;64L("1T:&ES+3YP87-S=V]R9"P@)'1H:7,M/G!E<G-I<W1E;G0I.PH*
M("`@("`@("!I9B`H9&)X7V5R<F]R*"1T:&ES+3YD8BDI('L*("`@("`@("`@
M("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G1$)X(&-O;FYE8W0@9F%I;&5D
M.B`G("X@9&)X7V5R<F]R*"1T:&ES+3YD8BDL(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R]N;W0@:6UP;&5M
M96YT960@>65T(&EN(&1B>`H@("`@("`@("`@("`O+R1T:&ES+3YD8BT^<V5T
M1F5T8VA-;V1E*$1"7T9%5$-(34]$15]!4U-/0RD["B`@("`@("`@?0H@("`@
M?0H*("`@(&9U;F-T:6]N(&9E=&-H*"1I9"P@)&=R;W5P*0H@("`@>PH@("`@
M("`@("1Q=65R>2`]('-P<FEN=&8H(E-%3$5#5"!C86-H961A=&$L('5S97)D
M871A+"!E>'!I<F5S($923TT@)7,@5TA%4D4@:60@/2`G)7,G($%.1"!C86-H
M96=R;W5P(#T@)R5S)R(L"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^8V%C:&5?=&%B;&4L"B`@("`@("`@("`@("`@("`@("`@("`@("!A9&1S
M;&%S:&5S*"1I9"DL"B`@("`@("`@("`@("`@("`@("`@("`@("!A9&1S;&%S
M:&5S*"1G<F]U<"D*("`@("`@("`@("`@("`@("`@("`@("`@*3L*"B`@("`@
M("`@)')E<R`](&1B>%]Q=65R>2@D=&AI<RT^9&(L("1Q=65R>2D["B`@("`@
M("`@:68@*&1B>%]E<G)O<B@D=&AI<RT^9&(I*0H@("`@("`@("`@("!R971U
M<FX@;F5W($-A8VAE7T5R<F]R*"=$0G@@<75E<GD@9F%I;&5D.B`G("X@9&)X
M7V5R<F]R*"1T:&ES+3YD8BDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["@H@("`@
M("`@("1R;W<@/2`D<F5S+3YD871A6S!=.PH*("`@("`@("!I9B`H:7-?87)R
M87DH)')O=RDI"B`@("`@("`@("`@("1D871A(#T@87)R87DH)')O=ULG97AP
M:7)E<R==+"`D=&AI<RT^9&5C;V1E*"1R;W=;)V-A8VAE9&%T82==*2P@)')O
M=ULG=7-E<F1A=&$G72D["B`@("`@("`@96QS92`*("`@("`@("`@("`@)&1A
M=&$@/2!A<G)A>2A.54Q,+"!.54Q,+"!.54Q,*3L*"B`@("`@("`@+R\@;&%S
M="!U<V5D(')E<75I<F5D(&)Y('1H92!G87)B86=E(&-O;&QE8W1I;VX@("`*
M("`@("`@("`O+R!705).24Y'.B!M:6=H="!B92!->5-13"!S<&5C:69I8R`@
M("`@("`@(`H@("`@("`@("1Q=65R>2`]('-P<FEN=&8H(E501$%412`E<R!3
M150@8VAA;F=E9"`]("A.3U<H*2`K(#`I(%=(15)%(&ED(#T@)R5S)R!!3D0@
M8V%C:&5G<F]U<"`]("<E<R<B+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/F-A8VAE7W1A8FQE+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@861D<VQA<VAE<R@D:60I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@861D<VQA<VAE<R@D9W)O=7`I"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@*3L*("`@("`@("`*("`@("`@("`D<F5S(#T@9&)X7W%U97)Y*"1T
M:&ES+3YD8BP@)'%U97)Y*3L*("`@("`@("!I9B`H9&)X7V5R<F]R*"1T:&ES
M+3YD8BDI"B`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H)T1"
M>"!Q=65R>2!F86EL960Z("<@+B!D8GA?97)R;W(H)'1H:7,M/F1B*2P@7U]&
M24Q%7U\L(%]?3$E.15]?*3L@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(`H@("`@("`@("`@("`*("`@("`@("!R971U<FX@)&1A=&$[("`@("`@("`@
M("`@"B`@("!]"@H@("`@+RHJ"B`@("`J(%-T;W)E<R!A(&1A=&%S970N"B`@
M("`J(`H@("`@*B!705).24Y'.B!W92!U<V4@=&AE(%-13"!C;VUM86YD(%)%
M4$Q!0T4@24Y43R!T:&ES(&UI9VAT(&)E(`H@("`@*B!->5-13"!S<&5C:69I
M8RX@07,@37E344P@:7,@=F5R>2!P;W!U;&%R('1H92!M971H;V0@<VAO=6QD
M"B`@("`J('=O<FL@9FEN92!F;W(@.34E(&]F('EO=2X*("`@("HO"B`@("!F
M=6YC=&EO;B!S879E*"1I9"P@)&1A=&$L("1E>'!I<F5S+"`D9W)O=7`L("1U
M<V5R9&%T82D*("`@('L*("`@("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D*"1I
M9"P@)&=R;W5P*3L*"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@B4D503$%#
M12!)3E1/("5S("AU<V5R9&%T82P@8V%C:&5D871A+"!E>'!I<F5S+"!I9"P@
M8V%C:&5G<F]U<"D@5D%,5453("@G)7,G+"`G)7,G+"`E9"P@)R5S)RP@)R5S
M)RDB+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-A8VAE7W1A
M8FQE+`H@("`@("`@("`@("`@("`@("`@("`@("`@861D<VQA<VAE<R@D=7-E
M<F1A=&$I+`H@("`@("`@("`@("`@("`@("`@("`@("`@861D<VQA<VAE<R@D
M=&AI<RT^96YC;V1E*"1D871A*2DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^9V5T17AP:7)E<T%B<V]L=71E*"1E>'!I<F5S*2`L"B`@("`@
M("`@("`@("`@("`@("`@("`@("!A9&1S;&%S:&5S*"1I9"DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("!A9&1S;&%S:&5S*"1G<F]U<"D*("`@("`@("`@
M("`@("`@("`@("`@("`@*3L*"B`@("`@("`@)')E<R`](&1B>%]Q=65R>2@D
M=&AI<RT^9&(L("1Q=65R>2D["@H@("`@("`@(&EF("AD8GA?97)R;W(H)'1H
M:7,M/F1B*2D@>PH@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R
M*"=$0G@@<75E<GD@9F%I;&5D.B`G("X@9&)X7V5R<F]R*"1T:&ES+3YD8BD@
M+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@('T*"B`@("!F
M=6YC=&EO;B!R96UO=F4H)&ED+"`D9W)O=7`I"B`@("!["B`@("`@("`@)'1H
M:7,M/F9L=7-H4')E;&]A9"@D:60L("1G<F]U<"D["@H@("`@("`@("1Q=65R
M>2`]('-P<FEN=&8H(D1%3$5412!&4D]-("5S(%=(15)%(&ED(#T@)R5S)R!A
M;F0@8V%C:&5G<F]U<"`]("<E<R<B+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/F-A8VAE7W1A8FQE+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@861D<VQA<VAE<R@D:60I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M861D<VQA<VAE<R@D9W)O=7`I"B`@("`@("`@("`@("`@("`@("`@("`@("D[
M"@H@("`@("`@("1R97,@/2!D8GA?<75E<GDH)'1H:7,M/F1B+"`D<75E<GDI
M.PH*("`@("`@("!I9B`H9&)X7V5R<F]R*"1T:&ES+3YD8BDI"B`@("`@("`@
M("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H)T1">"!Q=65R>2!F86EL960Z
M("<@+B!D8GA?97)R;W(H)'1H:7,M/F1B*2P@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!F;'5S:"@D9W)O=7`@/2`G)RD*("`@
M('L*("`@("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D*"D["@H@("`@("`@(&EF
M("@D9W)O=7`I('L*("`@("`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@B1$5,
M151%($923TT@)7,@5TA%4D4@8V%C:&5G<F]U<"`]("<E<R<B+"`D=&AI<RT^
M8V%C:&5?=&%B;&4L(&%D9'-L87-H97,H)&=R;W5P*2D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@B1$5,151%($92
M3TT@)7,B+"`D=&AI<RT^8V%C:&5?=&%B;&4I.PH@("`@("`@('T*"B`@("`@
M("`@)')E<R`](&1B>%]Q=65R>2@D=&AI<RT^9&(L)'%U97)Y*3L*"B`@("`@
M("`@:68@*&1B>%]E<G)O<B@D=&AI<RT^9&(I*0H@("`@("`@("`@("!R971U
M<FX@;F5W($-A8VAE7T5R<F]R*"=$0G@@<75E<GD@9F%I;&5D.B`G("X@9&)X
M7V5R<F]R*"1T:&ES+3YD8BDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("!]
M"@H@("`@9G5N8W1I;VX@:61%>&ES=',H)&ED+"`D9W)O=7`I"B`@("!["B`@
M("`@("`@)'%U97)Y(#T@<W!R:6YT9B@B4T5,14-4(&ED($923TT@)7,@5TA%
M4D4@240@/2`G)7,G($%.1"!C86-H96=R;W5P(#T@)R5S)R(L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^8V%C:&5?=&%B;&4L"B`@("`@("`@
M("`@("`@("`@("`@("`@("!A9&1S;&%S:&5S*"1I9"DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("!A9&1S;&%S:&5S*"1G<F]U<"D*("`@("`@("`@("`@
M("`@("`@("`@("`@*3L*"B`@("`@("`@)')E<R`](&1B>%]Q=65R>2@D=&AI
M<RT^9&(L("1Q=65R>2D["@H@("`@("`@(&EF("AD8GA?97)R;W(H)'1H:7,M
M/F1B*2D*("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G1$)X
M('%U97)Y(&9A:6QE9#H@)R`N(&1B>%]E<G)O<B@D=&AI<RT^9&(I+"!?7T9)
M3$5?7RP@7U],24Y%7U\I.PH*"B`@("`@("`@)')O=R`]("1R97-;,%T["@H@
M("`@("`@(&EF("AI<U]A<G)A>2@D<F]W*2D@>PH@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&=A<F)A9V5#
M;VQL96-T:6]N*"1M87AL:69E=&EM92D*("`@('L*("`@("`@("`D=&AI<RT^
M9FQU<VA0<F5L;V%D*"D["B`@("`@("`@"B`@("`@("`@)'%U97)Y(#T@<W!R
M:6YT9B@G1$5,151%($923TT@)7,@5TA%4D4@*&5X<&ER97,@/#T@)60@04Y$
M(&5X<&ER97,@/B`P*2!/4B!C:&%N9V5D(#P]("A.3U<H*2`M("5D*2<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8V%C:&5?=&%B;&4L"B`@
M("`@("`@("`@("`@("`@("`@("`@("!T:6UE*"DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`D;6%X;&EF971I;64*("`@("`@("`@("`@("`@("`@("`@
M("`I.PH*"B`@("`@("`@)')E<R`](&1B>%]Q=65R>2@D=&AI<RT^9&(L("1Q
M=65R>2D["@H@("`@("`@(&EF("AD8GA?97)R;W(H)'1H:7,M/F1B*2D*("`@
M("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G1$)X('%U97)Y(&9A
M:6QE9#H@)R`N(&1B>%]E<G)O<B@D=&AI<RT^9&(I+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH*("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=S96QE8W0@<W5M
M*&QE;F=T:"AC86-H961A=&$I*2!A<R!#86-H95-I>F4@9G)O;2`E<R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8V%C:&5?=&%B;&4*("`@
M("`@("`@("`@("`@("`@("`@("`I.PH*("`@("`@("`D<F5S(#T@9&)X7W%U
M97)Y*"1T:&ES+3YD8BP@)'%U97)Y*3L*("`@("`@("`O+VEF(&-A8VAE(&ES
M('1O(&)I9RX*("`@("`@("!I9B`H)')E<RT^9&%T85LP75M#86-H95-I>F5=
M(#X@)'1H:7,M/FAI9VAW871E<BD*("`@("`@("!["B`@("`@("`@("`@("\O
M9FEN9"!T:&4@;&]W=V%T97(@;6%R:RX*("`@("`@("`@("`@)'%U97)Y(#T@
M<W!R:6YT9B@G<V5L96-T(&QE;F=T:"AC86-H961A=&$I(&%S('-I>F4L(&-H
M86YG960@9G)O;2`E<R!O<F1E<B!B>2!C:&%N9V5D($1%4T,G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-A8VAE7W1A
M8FQE"B`@("`@("`@("`@("`@("`@("`@("`@*3L*"B`@("`@("`@("`@("1R
M97,@/2!D8GA?<75E<GDH)'1H:7,M/F1B+"`D<75E<GDI.PH@("`@("`@("`@
M("`D:V5E<%]S:7IE/3`["B`@("`@("`@("`@("1I/3`["B`@("`@("`@("`@
M('=H:6QE("@D:V5E<%]S:7IE(#P@)'1H:7,M/FQO=W=A=&5R("8F("1I(#P@
M)')E<RT^<F]W<R`I"B`@("`@("`@("`@('L*"B`@("`@("`@("`@("`@("`D
M:V5E<%]S:7IE("L]("1R97,M/F1A=&%;)&E=6W-I>F5=.PH@("`@("`@("`@
M("`@("`@)&DK*SL*("`@('T*("`@(`H@("`@("`@("`@("`O+V1E;&5T92!A
M;&P@96YT<FEE<RP@=VAI8V@@=V5R92!C:&%N9V5D(&)E9F]R92!T:&4@(FQO
M=W=W871E<B!M87)K(@H@("`@("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=D
M96QE=&4@9G)O;2`E<R!W:&5R92!C:&%N9V5D(#P]("5S)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC86-H95]T86)L
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R97,M
M/F1A=&%;)&E=6V-H86YG961="B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@*3L*("`@("`@("`@("`@)')E<R`](&1B>%]Q=65R>2@D=&AI
M<RT^9&(L("1Q=65R>2D["B`@("`@("`@?0H@("`@?0I]"C\^````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T-A
M8VAE+T5R<F]R+G!H<```````````````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#,T-3,@,3`U,34T,S,W,S`@,#(Q,C<U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!%05(@.CH@0V%C:&4@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@
M=&\@=F5R<VEO;B`R+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\"B\O
M('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F
M:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A
M="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(
M4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I
M="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N
M;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@
M8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO
M<G,Z(%5L9B!796YD96P@/'5L9BYW96YD96Q`<&AP9&]C+F1E/B`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O"B\O("1)9#H@17)R;W(N<&AP+'8@,2XS(#(P,#,O,#$O,#0@
M,3$Z-30Z-#4@;6H@17AP("0*"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PH*
M+RHJ"BH@0V%C:&4@17)R;W(@8VQA<W,**B`**B!`<&%C:V%G92!#86-H90HJ
M+PIC;&%S<R!#86-H95]%<G)O<B!E>'1E;F1S(%!%05)?17)R;W(@>PH*"B`@
M+RHJ"B`@*B!0<F5F:7@@;V8@86QL(&5R<F]R(&UE<W-A9V5S+@H@("H@"B`@
M*B!`=F%R("!S=')I;F<*("`J+PH@('9A<B`D97)R;W)?;65S<V%G95]P<F5F
M:7@@/2`G0V%C:&4M17)R;W(Z("<["B`@"B`@+RHJ"B`@*B!#<F5A=&5S(&%N
M(&-A8VAE(&5R<F]R(&]B:F5C="X*("`J(`H@("H@0'!A<F%M("!S=')I;F<@
M(&5R<F]R(&UE<W-A9V4*("`J($!P87)A;2`@<W1R:6YG("!F:6QE('=H97)E
M('1H92!E<G)O<B!O8V-U<F5D"B`@*B!`<&%R86T@('-T<FEN9R`@;&EN96YU
M;6)E<B!W:&5R92!T:&4@97)R;W(@;V-C=7)E9`H@("HO"B`@9G5N8W1I;VX@
M0V%C:&5?17)R;W(H)&US9RP@)&9I;&4@/2!?7T9)3$5?7RP@)&QI;F4@/2!?
M7TQ)3D5?7RD@>PH@("`@"B`@("`D=&AI<RT^4$5!4E]%<G)O<BAS<')I;G1F
M*"(E<R!;)7,@;VX@;&EN92`E9%TN(BP@)&US9RP@)&9I;&4L("1L:6YE*2D[
M"B`@("`*("!]("\O(&5N9"!F=6YC($-A8VAE7T5R<F]R"B`@"GT@+R\@96YD
M(&-L87-S($-A8VAE7T5R<F]R"C\^````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]#86-H92]&
M=6YC=&EO;BYP:'``````````````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#$Q,#<U(#$P-3$U-#,S-S,P(#`R,3<W,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!014%2(#HZ($-A8VAE("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER
M:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E
M<G-I;VX@,BXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`HO+R!\('1H
M870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,
M24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P
M,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\
M($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC
M96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T
M;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M
M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!3
M96)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X@
M("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+PHO+R`D260Z($9U;F-T:6]N+G!H<"QV(#$N-B`R,#`S+S`Q+S`T(#$Q
M.C4T.C0U(&UJ($5X<"`D"@IR97%U:7)E7V]N8V4@)T-A8VAE+G!H<"<["@HO
M*BH**B!&=6YC=&EO;E]#86-H90HJ"BH@4'5R<&]S93H**@HJ("`@0V%C:&EN
M9R!T:&4@<F5S=6QT(&%N9"!O=71P=70@;V8@9G5N8W1I;VYS+@HJ"BH@17AA
M;7!L93H**@HJ("`@<F5Q=6ER95]O;F-E("=#86-H92]&=6YC=&EO;BYP:'`G
M.PHJ"BH@("!C;&%S<R!F;V\@>PHJ("`@("!F=6YC=&EO;B!B87(H)'1E<W0I
M('L**B`@("`@("!E8VAO(")F;V\Z.F)A<B@D=&5S="D\8G(^(CL**B`@("`@
M?0HJ("`@?0HJ"BH@("!C;&%S<R!B87(@>PHJ("`@("!F=6YC=&EO;B!F;V]B
M87(H)&]B:F5C="D@>PHJ("`@("`@(&5C:&\@)R0G+B1O8FIE8W0N)RT^9F]O
M8F%R*"<N)&]B:F5C="XG*3QB<CXG.PHJ("`@("!]"BH@("!]"BH**B`@("1B
M87(@/2!N97<@8F%R.PHJ"BH@("!F=6YC=&EO;B!F;V]B87(H*2!["BH@("`@
M(&5C:&\@)V9O;V)A<B@I)SL**B`@('T**@HJ("`@)&-A8VAE(#T@;F5W($-A
M8VAE7T9U;F-T:6]N*"D["BH**B`@("1C86-H92T^8V%L;"@G9F]O.CIB87(G
M+"`G=&5S="<I.PHJ("`@)&-A8VAE+3YC86QL*"=B87(M/F9O;V)A<B<L("=B
M87(G*3L**B`@("1C86-H92T^8V%L;"@G9F]O8F%R)RD["BH**B!.;W1E.@HJ
M(`HJ("`@66]U(&-A;FYO="!C86-H92!E=F5R>2!F=6YC=&EO;BX@66]U('-H
M;W5L9"!O;FQY(&-A8VAE(`HJ("`@9G5N8W1I;VYS('1H870@;VYL>2!D97!E
M;F0@;VX@=&AE:7(@87)G=6UE;G1S(&%N9"!D;VXG="!U<V4**B`@(&=L;V)A
M;"!O<B!S=&%T:6,@=F%R:6%B;&5S+"!D;VXG="!R96QY(&]N(&1A=&%B87-E
M('%U97)I97,@;W(@"BH@("!F:6QE<RP@86YD('-O(&]N+@HJ(`HJ($!A=71H
M;W(@("`@("`@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R
M9VUA;FXN9&4^"BH@0&UO9'5L92`@("`@("!&=6YC=&EO;E]#86-H90HJ($!M
M;V1U;&5G<F]U<"`@1G5N8W1I;VY?0V%C:&4**B!`<&%C:V%G92`@("`@($-A
M8VAE"BH@0'9E<G-I;VX@("`@("`D4F5V:7-I;VXZ(#$N-B`D"BH@0&%C8V5S
M<R`@("`@("!P=6)L:6,**B\*8VQA<W,@0V%C:&5?1G5N8W1I;VX@97AT96YD
M<R!#86-H92!["B`@("!V87(@)&5X<&ER97,["@H@("`@+RHJ"B`@("`J($-O
M;G-T<G5C=&]R"B`@("`J"B`@("`J($!P87)A;2`@("!S=')I;F<@($YA;64@
M;V8@8V]N=&%I;F5R(&-L87-S"B`@("`J($!P87)A;2`@("!A<G)A>2`@($%R
M<F%Y('=I=&@@8V]N=&%I;F5R(&-L87-S(&]P=&EO;G,*("`@("H@0'!A<F%M
M("`@(&EN=&5G97(@3G5M8F5R(&]F('-E8V]N9',@9F]R('=H:6-H('1O(&-A
M8VAE"B`@("`J+PH@("`@9G5N8W1I;VX@0V%C:&5?1G5N8W1I;VXH)&-O;G1A
M:6YE<B`@/2`G9FEL92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M8V]N=&%I;F5R7V]P=&EO;G,@/2!A<G)A>2@G8V%C:&5?9&ER)R`@("`@("`]
M/B`G+B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G9FEL96YA;65?<')E9FEX)R`]/B`G8V%C:&5?
M)PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5X
M<&ER97,@/2`S-C`P"B`@("`@("`@("`@("`@("`@("`@("`@("`@("D*("`@
M('L*("`@("`@)'1H:7,M/D-A8VAE*"1C;VYT86EN97(L("1C;VYT86EN97)?
M;W!T:6]N<RD["B`@("`@("1T:&ES+3YE>'!I<F5S(#T@)&5X<&ER97,[("`@
M("`@"B`@("!]"@H@("`@+RHJ"B`@("`J(%!%05(M1&5C;VYS=')U8W1O<@H@
M("`@*B!#86QL(&1E8V]N<W1R=6-T;W(@;V8@<&%R96YT"B`@("`J+PH@("`@
M9G5N8W1I;VX@7T-A8VAE7T9U;F-T:6]N*"D@>PH@("`@("`@("1T:&ES+3Y?
M0V%C:&4H*3L*("`@('T*"B`@("`O*BH*("`@("H@0V%L;',@82!C86-H96%B
M;&4@9G5N8W1I;VX@;W(@;65T:&]D+@H@("`@*@H@("`@*B!`<F5T=7)N(&UI
M>&5D("1R97-U;'0*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("HO"B`@("!F
M=6YC=&EO;B!C86QL*"D@>PH@("`@("`@("\O(&=E="!A<F=U;65N=',*("`@
M("`@("`D87)G=6UE;G1S(#T@9G5N8U]G971?87)G<R@I.PH*("`@("`@("`O
M+R!G96YE<F%T92!C86-H92!I9`H@("`@("`@("1I9"`](&UD-2AS97)I86QI
M>F4H)&%R9W5M96YT<RDI.PH*("`@("`@("`O+R!Q=65R>2!C86-H90H@("`@
M("`@("1C86-H961?;V)J96-T(#T@)'1H:7,M/F=E="@D:60L("=F=6YC=&EO
M;E]C86-H92<I.PH*("`@("`@("!I9B`H)&-A8VAE9%]O8FIE8W0@(3T@3E5,
M3"D@>PH@("`@("`@("`@("`O+R!C86-H92!H:70Z(')E='5R;B!C86-H960@
M;W5T<'5T(&%N9"!R97-U;'0*"B`@("`@("`@("`@("1O=71P=70@/2`D8V%C
M:&5D7V]B:F5C=%LP73L*("`@("`@("`@("`@)')E<W5L="`]("1C86-H961?
M;V)J96-T6S%=.PH*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!C
M86-H92!M:7-S.B!C86QL(&9U;F-T:6]N+"!S=&]R92!O=71P=70@86YD(')E
M<W5L="!I;B!C86-H90H*("`@("`@("`@("`@;V)?<W1A<G0H*3L*("`@("`@
M("`@("`@)'1A<F=E="`](&%R<F%Y7W-H:69T*"1A<F=U;65N=',I.PH*("`@
M("`@("`@("`@+R\@8VQA<W-N86UE.CIS=&%T:6--971H;V0*("`@("`@("`@
M("`@:68@*'-T<G-T<B@D=&%R9V5T+"`G.CHG*2D@>PH@("`@("`@("`@("`@
M("`@;&ES="@D8VQA<W,L("1M971H;V0I(#T@97AP;&]D92@G.CHG+"`D=&%R
M9V5T*3L*"B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@8V%L;%]U<V5R7V9U
M;F-?87)R87DH87)R87DH)&-L87-S+"`D;65T:&]D*2P@)&%R9W5M96YT<RD[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O(&]B:F5C="T^;65T:&]D
M"B`@("`@("`@("`@(&5L<V5I9B`H<W1R<W1R*"1T87)G970L("<M/B<I*2![
M"B`@("`@("`@("`@("`@("!L:7-T*"1O8FIE8W0L("1M971H;V0I(#T@97AP
M;&]D92@G+3XG+"`D=&%R9V5T*3L*("`@("`@("`@("`@("`@(&=L;V)A;"`D
M)&]B:F5C=#L*"B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@8V%L;%]U<V5R
M7V9U;F-?87)R87DH87)R87DH)"1O8FIE8W0L("1M971H;V0I+"`D87)G=6UE
M;G1S*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@9G5N8W1I;VX*
M("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@
M8V%L;%]U<V5R7V9U;F-?87)R87DH)'1A<F=E="P@)&%R9W5M96YT<RD["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1O=71P=70@/2!O8E]G971?8V]N
M=&5N=',H*3L*("`@("`@("`@("`@;V)?96YD7V-L96%N*"D["@H@("`@("`@
M("`@("`D=&AI<RT^<V%V92@D:60L(&%R<F%Y*"1O=71P=70L("1R97-U;'0I
M+"`D=&AI<RT^97AP:7)E<RP@)V9U;F-T:6]N7V-A8VAE)RD["B`@("`@("`@
M?0H*("`@("`@("!E8VAO("1O=71P=70["B`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("!]"GT*/SX*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M0V%C:&4O1W)A<&AI8W,N<&AP````````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`S,#4W,"`Q,#4Q-30S,S<S,"`P,C$W-#0`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$5!4B`Z.B!#86-H92`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C
M="!T;R!V97)S:6]N(#(N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P*
M+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE
M(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE
M(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@
M4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN
M(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A
M(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W
M92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T
M:&]R<SH@56QF(%=E;F1E;"`\=6QF+G=E;F1E;$!P:'!D;V,N9&4^("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\*+R\@)$ED.B!'<F%P:&EC<RYP:'`L=B`Q+C4@,C`P,R\P
M,2\P-"`Q,3HU-#HT-2!M:B!%>'`@)`H*<F5Q=6ER95]O;F-E("=#86-H92YP
M:'`G.PH*+RHJ"BH@1W)A<&AI8W,@9&ES:R!C86-H92X**B`**B!4:&4@=7-U
M86P@=V%Y('1O(&-R96%T92!I;6%G97,@:7,@=&\@<&%S<R!S;VUE(&%R9W5M
M96YT<R!T:&%T(&1E<V-R:6)E('1H92!I;6%G92`**B!T;R!A('-C<FEP="!T
M:&%T(&1Y;F%M:6-A;&QY(&-R96%T97,@86X@:6UA9V4N($9O<B!E=F5R>2!I
M;6%G92!O9B!A('!A9V4@"BH@82!N97<@4$A0(&EN=&5R<')E=&5R(&=E=',@
M<W1A<G1E9"X@5&AI<R!I<R!A(&=O;V0@=V%Y('1O(&MI;&P@>6]U<B!W96)S
M97)V97(N"BH@"BH@5VAE;B!D96%L:6YG('=I=&@@9'EN86UI8V%L;'D@9V5N
M97)A=&5D(&EM86=E<R!Y;W4@<VAO=6QD(&YO="!C86QL(&%N;W1H97(@<V-R
M:7!T(`HJ('1O(&=E;F5R871E('1H92!I;6%G97,@8G5T(&=E;F5R871E('1H
M92!I;6%G97,@8GD@=&AE('-C<FEP="!T:&%T('!R;V1U8V5S('1H92!P86=E
M"BH@=&AA="!C;VYT86EN<R!T:&4@:6UA9V5S+B!4:&ES(&ES(&$@;6%J;W(@
M:6UP<F]V96UE;G0@8G5T(&ET)W,@;VYL>2!H86QF('1H92!W87DN"BH@"BH@
M5&AE<F4G<R!N;R!N965D('1O(')E<F5N9&5R(&%N(&EM86=E(&]N(&5V97)Y
M(')E<75E<W0N($$@<VEM<&QE(&1I<VL@8V%C:&4@8V%N(')E9'5C90HJ('1H
M92!C;VUP=71A=&EO;B!T:6UE(&1R86UA=&EC86QL>2X@5&AI<R!I<R!W:&%T
M('1H92!C;&%S<R!G<F%P:&EC<U]C86-H92!I<R!F;W(N(`HJ(`HJ(%5S86=E
M.@HJ(`HJ("\O(&-R96%T92!A;B!I;G-T86YC92!O9B!T:&4@9W)A<&AI8W,@
M8V%C:&4**B`D8V%C:&4@/2!N97<@9W)A<&AI8W-?8V%C:&4["BH**B`D:6UG
M(#T@26UA9V5#<F5A=&4H+BXN*3L**@HJ("\O(&-O;7!U=&4@86X@240@9F]R
M('EO=7(@:6UA9V4@8F%S960@;VX@='EP:6-A;"!P87)A;65T97)S"BH@)&ED
M(#T@;35D*"`D<VEZ92P@)&-O;&]R<RP@)&QA8F5L*3L**B`**B`O+R!C:&5C
M:R!I9B!I="=S(&-A8VAE9`HJ(&EF("@A*"1L:6YK(#T@)&-A8VAE+3YG971)
M;6%G94QI;FLH)&ED+"`G9VEF)RDI*2!["BH@(`HJ("`@+R\@:&UM;2P@:70G
M<R!N;W0@8V%C:&5D+"!C<F5A=&4@:70**B`@("XN+@HJ("`@+R\@8V%C:&5)
M;6%G94QI;FLH*2!A;F0@8V%C:&5);6%G92@I(&UA:V4@=&AE($EM86=E1TE&
M*"D@8V%L;"$**B`@("\O(&-A8VAE26UA9V4H*2!R971U<FYS('1H92!V86QU
M92!O9B!);6%G94=)1B@I(%ME=&,N72P@8V%C:&5);6%G94QI;FLH*2!R971U
M<FYS(&$@55),"BH@("`D;&EN:R`]("1C86-H92T^8V%C:&5);6%G94QI;FLH
M)&ED+"`D:6UG+"`G9VEF)RD["BH@"BH@?0HJ"BH@+R\@3VLL(&QE="=S(&)U
M:6QD('1H92!);6%G94QI;FL**B`D<VEZ92`](&=E=$EM86=E4VEZ92@D;&EN
M:ULP72D["BH@<')I;G1F*"<\:6UG('-R8STB)7,B("5S/B<L("1L:6YK6S%=
M+"`D<VEZ95LS72D["BH**B`O+R!F;W(@8V%C:&5);6%G92@I.@HJ("\O(&AE
M861E<B@G0V]N=&5N="UT>7!E.B!I;6%G92]G:68G*3L@<')I;G0@)&-A8VAE
M+3YC86-H94EM86=E*"1I9"P@)&EM9RP@)V=I9B<I.PHJ(`HJ"BH@5&AE(&-L
M87-S(')E<75I<F5S(%!(4"`T+C`N,BL@6TEM86=E5'EP92@I72X@3F]T92!T
M:&%T(&-A8VAE26UA9V4H*2!W;W)K<R!W:71H"BH@=&AE(&]U='!U="!B=69F
M97(N($UO9&EF>2!I="!I9B!R97%U:7)E9"$**@HJ($!A=71H;W(@("!5;&8@
M5V5N9&5L(#QU;&8N=V5N9&5L0'!H<&1O8RYD93X**B!`=F5R<VEO;B`@)$ED
M.B!'<F%P:&EC<RYP:'`L=B`Q+C4@,C`P,R\P,2\P-"`Q,3HU-#HT-2!M:B!%
M>'`@)`HJ($!P86-K86=E("!#86-H90HJ+PIC;&%S<R!#86-H95]'<F%P:&EC
M<R!E>'1E;F1S($-A8VAE('L*"@H@("`@+RHJ"B`@("`J($-A8VAE(%523"!P
M<F5F:7@N"B`@("`J(`H@("`@*B!-86ME('-U<F4@=&AA="!T:&4@8V%C:&4@
M55),('!R969I>"!P;VEN=',@=&\@=&AE("1C86-H95]D:7(L(&]T:&5R=VES
M90H@("`@*B!Y;W5R(&QI;FMS('=I;&P@8F4@8G)O:V5N+B!5<V4@<V5T0V%C
M:&554DP@=&\@<W!E8VEF>2!T:&4@8V%C:&5?=7)L(&%N9"`*("`@("H@<V5T
M0V%C:&5$:7(H*2!F;W(@=&AE(&-A8VAE7V1I<BX*("`@("H@"B`@("`J($!V
M87(@('-T<FEN9PH@("`@*B!`<V5E("!S971#86-H95523"@I+"!S971#86-H
M941I<B@I"B`@("`J+PH@("`@=F%R("1C86-H95]U<FP@/2`G)SL*"B`@("`O
M*BH*("`@("H@1&ER96-T;W)Y('=H97)E(&-A8VAE9"!F:6QE<R!G970@<W1O
M<F5D+@H@("`@*B!S"B`@("`J($UA:V4@<W5R92!T:&%T('1H92!C86-H95]D
M:7(@:7,@=W)I=&%B;&4@86YD(&]F9F5R<R!E;F]U9V@@<W!A8V4N($-H96-K
M(`H@("`@*B!A;'-O(&EF('EO=7(@8V%C:&5?=7)L('!O:6YT<R!T;R!T:&4@
M9&ER96-T;W)Y+B!5<V4@<V5T0V%C:&5$:7(H*2!T;R!S970*("`@("H@=&AE
M('9A<FEA8FQE+@H@("`@*B`*("`@("H@0'9A<B`@<W1R:6YG"B`@("`J($!S
M964@('-E=$-A8VAE1&ER*"DL('-E=$-A8VAE55),*"D*("`@("HO"B`@("!V
M87(@)&-A8VAE7V1I<B`]("<G.PH*("`@("\J*@H@("`@*B!.86UE<')E9FEX
M(&]F(&-A8VAE9"!F:6QE<RX*("`@("H@"B`@("`J(%!E<B!D969A=6QT('1H
M92!P<F5F:7@@(F=R87!H:6-S7R(@9V5T<R!U<V5D+B!9;W4@;6EG:'0@=7-E
M('1H:7,@"B`@("`J(&9O<B!V97)S:6]N:6YG(&]R('1O(&5A<V4@*&UA;G5A
M;"D@8VQE86X@=7!S+@H@("`@*@H@("`@*B!`=F%R("`@("`@<W1R:6YG"B`@
M("`J+PH@("`@=F%R("1C86-H95]F:6QE7W!R969I>"`]("=G<F%P:&EC<U\G
M.PH@("`@"B`@("`*("`@("\J*@H@("`@*B!#86-H92!C;VYT86EN97(@9W)O
M=7`N"B`@("`J"B`@("`J($!V87(@("`@("!S=')I;F<*("`@("HO"B`@("!V
M87(@)&-A8VAE7V=R;W5P(#T@)V=R87!H:6-S)SL*"B`@("`*("`@("\J*@H@
M("`@*B!-87!P:6YG(&9R;VT@<W5P<&]R=&5D(&EM86=E('1Y<&4@=&\@82!)
M;6%G951Y<&4H*2!C;VYS=&%N="X*("`@("H@"B`@("`J(%)E9F5R<B!T;R!T
M:&4@4$A0(&UA;G5A;"!F;W(@;6]R92!I;F9O<FUA=&EO;G,@;VX@26UA9V54
M>7!E*"D*("`@("H@"B`@("`J($!V87(@(&%R<F%Y"B`@("`J($!L:6YK(&AT
M='`Z+R]W=W<N<&AP+FYE="]);6%G951Y<&4*("`@("HO"B`@("!V87(@)&EM
M86=E='EP97,@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G9VEF)R`@(#T^($E-1U]'248L(`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=J<&<G("`@/3X@24U'7TI01RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G<&YG)R`@(#T^($E-1U]03D<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W=B;7`G("`]/B!)34=?5T)-
M4`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L*"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`*("`@("\J*@H@("`@*B!);G-T86YT:6%T97,@
M82!C86-H92!F:6QE(&-O;G1A:6YE<BX*("`@("H*("`@("HO"B`@("!F=6YC
M=&EO;B!#86-H95]'<F%P:&EC<R@I('L*("`@(`H@("`@("`@("1T:&ES+3Y#
M86-H92@G9FEL92<L(&%R<F%Y*"=C86-H95]D:7(G(#T^("1T:&ES+3YC86-H
M95]D:7(L("=F:6QE;F%M95]P<F5F:7@G(#T^("1T:&ES+3YC86-H95]F:6QE
M7W!R969I>"DI.PH@("`@("`@(`H@("`@?2`O+R!E;F0@8V]N<W1R=6-T;W(*
M"B`@("`*("`@("\J*@H@("`@*B!2971U<FYS('1H92!C;VYT96YT(&]F(&$@
M8V%C:&5D(&EM86=E(&9I;&4N"B`@("`J(`H@("`@*B!4:&ES(&9U;F-T:6]N
M(&-A;B!B92!U<V5D('1O('-E;F0@=&AE(&EM86=E(&1I<F5C=&QY('1O('1H
M92!B<F]W<V5R+@H@("`@*B!-86ME('-U<F4@=&AA="!Y;W4@<V5N9"!A(&-O
M<G)E<W!O;F1E;F1I;F<@:&5A9&5R(&)E9F]R92!S96YD:6YG('1H92!I;6%G
M92!I='-E;&8N"B`@("`J"B`@("`J($%L=V%Y<R!T<GD@=&\@9V5T('1H92!I
M;6%G92!F<F]M('1H92!C86-H92!B969O<F4@>6]U(&-O;7!U=&4@:70N(%-E
M92`*("`@("H@=&AE(&-L87-S(&1O8W,@9F]R(&%N(&5X86UP;&4N"B`@("`J
M"B`@("`J($!P87)A;2`@("!S=')I;F<@($EM86=E+4E$"B`@("`J($!P87)A
M;2`@("!S=')I;F<@($EM86=E('1Y<&4Z(&=I9BP@:G!G+"!P;F<L('=B;7`*
M("`@("H@0')E='5R;B`@('-T<FEN9R`@26UA9V4@9FEL92!C;VYT96YT<R!I
M9B!A(&-A8VAE9"!F:6QE(&5X:7-T<R!O=&AE<G=I<V4@86X@96UP='D@<W1R
M:6YG"B`@("`J($!S964@("`@("!C86-H94EM86=E*"D*("`@("HO("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@"B`@("!F=6YC=&EO;B!G
M971);6%G92@D:60L("1F;W)M870@/2`G<&YG)RD@>PH@("`@("`@("1I9"`]
M("1T:&ES+3YG96YE<F%T94E$*"1I9"P@)&9O<FUA="D["B`@("`@("`@"B`@
M("`@("`@<F5T=7)N("1T:&ES+3YG970H)&ED+"`D=&AI<RT^8V%C:&5?9W)O
M=7`I.PH@("`@?2`O+R!E;F0@9G5N8R!G971);6%G90H*("`@(`H@("`@+RHJ
M"B`@("`J(%)E='5R;G,@86X@87)R87D@=VET:"!A(&QI;FL@=&\@=&AE(&-A
M8VAE9"!I;6%G92!A;F0@=&AE(&EM86=E(&9I;&4@<&%T:"X*("`@("H@"B`@
M("`J($%L=V%Y<R!T<GD@=&\@9V5T('1H92!I;6%G92!F<F]M('1H92!C86-H
M92!B969O<F4@>6]U(&-O;7!U=&4@:70N(%-E92`*("`@("H@=&AE(&-L87-S
M(&1O8W,@9F]R(&%N(&5X86UP;&4N"B`@("`J"B`@("`J($!P87)A;2`@("!S
M=')I;F<@($EM86=E+4E$"B`@("`J($!P87)A;2`@("!S=')I;F<@($EM86=E
M('1Y<&4Z(&=I9BP@:G!G+"!P;F<L('=B;7`*("`@("H@0')E='5R;B`@(&%R
M<F%Y("`@6R!F=6QL('!A=&@@=&\@=&AE(&EM86=E(&9I;&4L(&EM86=E('5R
M;"!="B`@("`J($!T:')O=R`@("!#86-H95]%<G)O<@H@("`@*B!`<V5E("`@
M("`@8V%C:&5);6%G94QI;FLH*0H@("`@*B\*("`@(&9U;F-T:6]N(&=E=$EM
M86=E3&EN:R@D:60L("1F;W)M870@/2`G<&YG)RD@>PH@("`@("`@("1I9"`]
M("1T:&ES+3YG96YE<F%T94E$*"1I9"P@)&9O<FUA="D["B`@("`@("`@:68@
M*"$D=&AI<RT^8V]N=&%I;F5R+3YI9$5X:7-T<R@D:60L("1T:&ES+3YC86-H
M95]G<F]U<"DI(`H@("`@("`@("`@("!R971U<FX@87)R87DH*3L*"B`@("`@
M("`@)&9I;&4@/2`D=&AI<RT^8V%C:&5?=7)L("X@)'1H:7,M/F-A8VAE7V9I
M;&5?<')E9FEX("X@)&ED.PH*("`@("`@("!R971U<FX@87)R87DH)'1H:7,M
M/F-O;G1A:6YE<BT^9V5T1FEL96YA;64H)&ED+"`D=&AI<RT^8V%C:&5?9W)O
M=7`I+"`D9FEL92D["B`@("!]("\O(&5N9"!F=6YC(&=E=$EM86=E3&EN:PH@
M("`@"@H@("`@+RHJ"B`@("`J($-R96%T92!A;B!I;6%G92!F<F]M('1H92!G
M:79E;B!I;6%G92!H86YD;&5R+"!C86-H92!I="!A;F0@<F5T=7)N('1H92!F
M:6QE(&-O;G1E;G0N"B`@("`J"B`@("`J($%L=V%Y<R!T<GD@=&\@<F5T<FEV
M92!T:&4@:6UA9V4@9G)O;2!T:&4@8V%C:&4@8F5F;W)E('EO=2!C;VUP=71E
M(&ET+@H@("`@*B`*("`@("H@5V%R;FEN9SH@=&AI<R!F=6YC=&EO;B!U<V5S
M('1H92!O=71P=70@8G5F9F5R+B!)9B!Y;W4@97AP96-T(&-O;&QI<VEO;G,@
M"B`@("`J(&UO9&EF>2!T:&4@8V]D92X*("`@("H*("`@("H@0'!A<F%M("`@
M('-T<FEN9R`@26UA9V4M240N(%5S960@87,@82!P87)T(&]F('1H92!C86-H
M92!F:6QE;F%M92X*("`@("H@("`@("`@("`@("`@("`@("`@57-E(&UD-2@I
M('1O(&=E;F5R871E(&$@(G5N:7%U92(@240@9F]R('EO=7(@:6UA9V4*("`@
M("H@("`@("`@("`@("`@("`@("`@8F%S960@;VX@8VAA<F%C=&5R:7-T:6,@
M=F%L=65S('-U8V@@87,@=&AE(&-O;&]R+"!S:7IE(&5T8RX*("`@("H@0'!A
M<F%M("`@('-T<FEN9R`@26UA9V4@:&%N9&QE<B!T;R!C<F5A=&4@=&AE(&EM
M86=E(&9R;VTN"B`@("`J($!P87)A;2`@("!S=')I;F<@($EM86=E('1Y<&4Z
M(&=I9BP@:G!G+"!P;F<L('=B;7`N($%L<V\@=7-E9"!A<R!F:6QE;F%M92!S
M=69F:7@N"B`@("`J("`@("`@("`@("`@("`@("`@($EF(&%N('5N<W5P<&]R
M=&5D('1Y<&4@:7,@<F5Q=65S=&5D('1H92!F=6YC=&EO;G,@=')I97,@=&\@
M"B`@("`J("`@("`@("`@("`@("`@("`@(&9A;&QB86-K('1O(&$@<W5P<&]R
M=&5D('1Y<&4@8F5F;W)E('1H<F]W:6YG(&%N(&5X97!T:6]N+@H@("`@*B!`
M<F5T=7)N("`@<W1R:6YG("!);6%G92!C;VYT96YT(')E='5R;F5D(&)Y($EM
M86=E1TE&+RXN+B`*("`@("H@0'1H<F]W<R`@($-A8VAE7T5R<F]R"B`@("`J
M($!A8V-E<W,@("!P=6)L:6,*("`@("H@0'-E92`@("`@(&=E=$EM86=E*"D*
M("`@("HO"B`@("!F=6YC=&EO;B!C86-H94EM86=E*"1I9"P@)&EM9RP@)&9O
M<FUA="`]("=P;F<G*2!["B`@("`@("`@:68@*"$D:60I"B`@("`@("`@("`@
M(')E='5R;B!N97<@0V%C:&5?17)R;W(H)UEO=2!M=7-T('!R;W9I9&4@86X@
M240@9F]R(&%N9"!I;6%G92!T;R!B92!C86-H960A)RP@7U]&24Q%7U\L(%]?
M3$E.15]?*3L*"B`@("`@("`@)&ED(#T@)'1H:7,M/F=E;F5R871E240H)&ED
M+"`D9F]R;6%T*3L*("`@("`@("`D='EP97,@/2!);6%G951Y<&5S*"D["@H@
M("`@("`@("\O($-H96-K(&EF('1H92!R97%U97-T960@:6UA9V4@='EP92!I
M<R!S=7!P;W)T960@8GD@=&AE($=$(&QI8BX*("`@("`@("`O+R!)9B!N;W0L
M('1R>2!A(&-A;&QB86-K('1O('1H92!F:7)S="!A=F%I;&%B;&4@:6UA9V4@
M='EP92X*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YI;6%G971Y<&5S6R1F
M;W)M871=*2!\?"`A*"1T>7!E<R`F("1T:&ES+3YI;6%G971Y<&5S6R1F;W)M
M871=*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^:6UA9V5T>7!E
M<R!A<R`D<W5P<&]R=&5D(#T^("1B:71M87-K*2!["B`@("`@("`@("`@("`@
M("!I9B`H)'1Y<&5S("8@)&)I=&UA<VLI('L*("`@("`@("`@("`@("`@("`@
M("!N97<@0V%C:&5?17)R;W(H(E1H92!B=6EL9"!I;B!'1"!L:6(@9&]E<R!N
M;W0@<W5P<&]R="!T:&4@:6UA9V4@='EP92`D9F]R;6%T+B!&86QL8F%C:R!T
M;R`D<W5P<&]R=&5D+B(L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!N
M97<@0V%C:&5?17)R;W(H(DAM;2P@:7,@>6]U<B!02%`@8G5I;&0@=VET:"!'
M1"!S=7!P;W)T/R!#86XG="!F:6YD(&%N>2!S=7!P;W)T960@='EP97,N(BP@
M7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1I;6%G92`]("1T:&ES
M+3YG970H)&ED+"`D=&AI<RT^8V%C:&5?9W)O=7`I*0H@("`@("`@("`@("!R
M971U<FX@)&EM86=E.PH*("`@("`@("`O+R!S879E('1H92!I;6%G92!T;R!T
M:&4@;W5T<'5T(&)U9F9E<BP@=W)I=&4@:70@=&\@9&ES:R!A;F0@"B`@("`@
M("`@+R\@<F5T=7)N('1H92!I;6%G92X*("`@("`@("!O8E]E;F1?8VQE86XH
M*3L*("`@("`@("!O8E]S=&%R="@I.R`*"B`@("`@("`@:68@*'-T<G1O=7!P
M97(H)&9O<FUA="D@/3T@(DI01R(I('L*("`@("`@("`@("`@)&=E;D9O<FUA
M="`](")*4$5'(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9V5N
M1F]R;6%T(#T@<W1R=&]U<'!E<B@D9F]R;6%T*3L*("`@("`@("!]"@H@("`@
M("`@("\O(&=E;F5R871E('1H92!I;6%G90H@("`@("`@("1F=6YC(#T@)TEM
M86=E)R`N("1G96Y&;W)M870["B`@("`@("`@)&9U;F,H)&EM9RD["B`@("`@
M("`@26UA9V5$97-T<F]Y*"1I;6<I.PH*("`@("`@("!O8E]E;F0H*3L*("`@
M("`@("`D:6UA9V4@/2!O8E]G971?8V]N=&5N=',H*3L*("`@("`@("!O8E]E
M;F1?8VQE86XH*3L*"B`@("`@("`@+R\@<V%V92!T:&4@9V5N97)A=&5D(&EM
M86=E('1O(&1I<VL*("`@("`@("`D=&AI<RT^<V%V92@D:60L("1I;6%G92P@
M,"P@)'1H:7,M/F-A8VAE7V=R;W5P*3L*"B`@("`@("`@<F5T=7)N("1I;6%G
M93L*("`@('T@+R\@96YD(&9U;F,@8V%C:&5);6%G90H@("`@"@H@("`@+RHJ
M"B`@("`J($-R96%T92!A;B!I;6%G92!F<F]M('1H92!G:79E;B!I;6%G92!H
M86YD;&5R+"!C86-H92!I="!A;F0@<F5T=7)N(&$@=7)L(&%N9"!T:&4@9FEL
M92!P871H(&]F('1H92!I;6%G92X*("`@("H*("`@("H@06QW87ES('1R>2!T
M;R!R971R:79E('1H92!I;6%G92!F<F]M('1H92!C86-H92!B969O<F4@>6]U
M(&-O;7!U=&4@:70N"B`@("`J"B`@("`J($!P87)A;2`@("!S=')I;F<@($EM
M86=E+4E$+B!5<V5D(&%S(&$@<&%R="!O9B!T:&4@8V%C:&4@9FEL96YA;64N
M"B`@("`J("`@("`@("`@("`@("`@("`@(%5S92!M9#4H*2!T;R!G96YE<F%T
M92!A(")U;FEQ=64B($E$(&9O<B!Y;W5R(&EM86=E"B`@("`J("`@("`@("`@
M("`@("`@("`@(&)A<V5D(&]N(&-H87)A8W1E<FES=&EC('9A;'5E<R!S=6-H
M(&%S('1H92!C;VQO<BP@<VEZ92!E=&,N"B`@("`J($!P87)A;2`@("!S=')I
M;F<@($EM86=E(&AA;F1L97(@=&\@8W)E871E('1H92!I;6%G92!F<F]M+@H@
M("`@*B!`<&%R86T@("`@<W1R:6YG("!);6%G92!T>7!E.B!G:68L(&IP9RP@
M<&YG+"!W8FUP+B!!;'-O('5S960@87,@9FEL96YA;64@<W5F9FEX+@H@("`@
M*B`@("`@("`@("`@("`@("`@("!)9B!A;B!U;G-U<'!O<G1E9"!T>7!E(&ES
M(')E<75E<W1E9"!T:&4@9G5N8W1I;VYS('1R:65S('1O(`H@("`@*B`@("`@
M("`@("`@("`@("`@("!F86QL8F%C:R!T;R!A('-U<'!O<G1E9"!T>7!E(&)E
M9F]R92!T:')O=VEN9R!A;B!E>&5P=&EO;BX*("`@("H@0')E='5R;B`@(&%R
M<F%Y("!;(&9U;&P@<&%T:"!T;R!T:&4@:6UA9V4@9FEL92P@:6UA9V4@=7)L
M(%T*("`@("H@0'1H<F]W<R`@($-A8VAE7T5R<F]R"B`@("`J($!A8V-E<W,@
M("!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!C86-H94EM86=E3&EN:R@D
M:60L("8D:6UG+"`D9F]R;6%T(#T@)W!N9R<I('L*("`@("`@("!I9B`H(21I
M9"D*("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B`H)UEO=2!M
M=7-T('!R;W9I9&4@86X@240@9F]R(&%N9"!I;6%G92!T;R!B92!C86-H960A
M)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@("`@)&ED(#T@)'1H:7,M
M/F=E;F5R871E240H)&ED+"`D9F]R;6%T*3L*("`@("`@("`D='EP97,@/2!)
M;6%G951Y<&5S*"D["@H@("`@("`@("\O($-H96-K(&EF('1H92!R97%U97-T
M960@:6UA9V4@='EP92!I<R!S=7!P;W)T960@8GD@=&AE($=$(&QI8BX*("`@
M("`@("`O+R!)9B!N;W0L('1R>2!A(&-A;&QB86-K('1O('1H92!F:7)S="!A
M=F%I;&%B;&4@:6UA9V4@='EP92X*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3YI;6%G971Y<&5S6R1F;W)M871=*2!\?"`A*"1T>7!E<R`F("1T:&ES+3YI
M;6%G971Y<&5S6R1F;W)M871=*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D
M=&AI<RT^:6UA9V5T>7!E<R!A<R`D<W5P<&]R=&5D(#T^("1B:71M87-K*2`*
M("`@("`@("`@("`@("`@(&EF("@D='EP97,@)B`D8FET;6%S:RD*("`@("`@
M("`@("`@("`@("`@("!N97<@0V%C:&5?17)R;W(H(E1H92!B=6EL9"!I;B!'
M1"!L:6(@9&]E<R!N;W0@<W5P<&]R="!T:&4@:6UA9V4@='EP92`D9F]R;6%T
M+B!&86QL8F%C:R!T;R`D<W5P<&]R=&5D+B(L(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["B`@("`@("`@("`@("`@("!E;'-E"B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N(&YE=R!#86-H95]%<G)O<B@B2&UM+"!I<R!Y;W5R(%!(4"!B=6EL
M9"!W:71H($=$('-U<'!O<G0_($-A;B=T(&9I;F0@86YY('-U<'!O<G1E9"!T
M>7!E<RXB+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@
M("`@)'5R;"`]("1T:&ES+3YC86-H95]U<FP@+B`D=&AI<RT^8V%C:&5?9FEL
M95]P<F5F:7@@+B`D:60["B`@("`@("`@)&9F:6QE(#T@)'1H:7,M/F-O;G1A
M:6YE<BT^9V5T1FEL96YA;64H)&ED+"`D=&AI<RT^8V%C:&5?9W)O=7`I.PH*
M("`@("`@("!I9B`H)'1H:7,M/FES0V%C:&5D*"1I9"P@)'1H:7,M/F-A8VAE
M7V=R;W5P*2`F)B`A:7-%>'!I<F5D*"1I9"P@)'1H:7,M/F-A8VAE7V=R;W5P
M*2D*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"1F9FEL92P@)'5R;"D["@H@
M("`@("`@(&EF("AS=')T;W5P<&5R*"1F;W)M870I(#T](")*4$<B*2!["B`@
M("`@("`@("`@("1G96Y&;W)M870@/2`B2E!%1R(["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)&=E;D9O<FUA="`]('-T<G1O=7!P97(H)&9O<FUA
M="D["B`@("`@("`@?0H*("`@("`@("`D9G5N8R`]("=);6%G92<@+B`D9V5N
M1F]R;6%T.PH@("`@("`@("1F=6YC*"1I;6<L("1F9FEL92D["@H@("`@("`@
M($EM86=E1&5S=')O>2@D:6UG*3L*"B`@("`@("`@<F5T=7)N(&%R<F%Y*"1F
M9FEL92P@)'5R;"D["B`@("!]("\O(&5N9"!F=6YC(&-A8VAE26UA9V5,:6YK
M"@H@("`@"B`@("`O*BH*("`@("H@4V5T<R!T:&4@55),('!R969I>"!U<V5D
M('=H96X@<F5N9&5R:6YG($A434P@5&%G<RX@"B`@("`J(`H@("`@*B!-86ME
M('-U<F4@=&AA="!T:&4@55),(&UA=&-H97,@=&AE(&-A8VAE(&1I<F5C=&]R
M>2P@"B`@("`J(&]T:&5R=VES92!Y;W4G;&P@9V5T(&)R;VME;B!L:6YK<RX*
M("`@("H@"B`@("`J($!P87)A;2`@("!S=')I;F<*("`@("H@0&%C8V5S<R`@
M('!U8FQI8PH@("`@*B!`<V5E("`@("`@<V5T0V%C:&5$:7(H*0H@("`@*B\*
M("`@(&9U;F-T:6]N('-E=$-A8VAE55),*"1C86-H95]U<FPI('L*("`@("`@
M("!I9B`H)&-A8VAE7W5R;"`F)B`G+R<@(3T@<W5B<W1R*"1C86-H95]U<FPL
M(#$I*2`*("`@("`@("`@("`@)&-A8VAE7W5R;"`N/2`G+R<["B`@("`@("`@
M("`@(`H@("`@("`@("1T:&ES+3YC86-H95]U<FP@/2`D8V%C:&5?=7)L.PH@
M("`@("`@(`H@("`@?2`O+R!E;F0@9G5N8R!S971#86-H95523`H*("`@(`H@
M("`@+RHJ"B`@("`J(%-E=',@=&AE(&1I<F5C=&]R>2!W:&5R92!T;R!C86-H
M92!G96YE<F%T960@26UA9V5S"B`@("`J(`H@("`@*B!`<&%R86T@("`@<W1R
M:6YG"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("H@0'-E92`@("`@('-E
M=$-A8VAE55),*"D*("`@("HO"B`@("!F=6YC=&EO;B!S971#86-H941I<B@D
M8V%C:&5?9&ER*2!["B`@("`@("`@:68@*"1C86-H95]D:7(@)B8@)R\G("$]
M('-U8G-T<B@D8V%C:&5?9&ER+"`Q*2D*("`@("`@("`@("`@)&-A8VAE7V1I
M<B`N/2`G+R<["@H@("`@("`@("1T:&ES+3YC86-H95]D:7(@/2`D8V%C:&5?
M9&ER.PH@("`@("`@("1T:&ES+3YC;VYT86EN97(M/F-A8VAE7V1I<B`]("1C
M86-H95]D:7(["B`@("!]("\O(&5N9"!F=6YC('-E=$-A8VAE1&ER"B`@("`*
M("`@(`H@("`@9G5N8W1I;VX@9V5N97)A=&5)1"@D=F%R:6%B;&4L("1F;W)M
M870@/2`G<&YG)RD@>PH@("`@("!R971U<FX@;60U*'-E<FEA;&EZ92@D=F%R
M:6%B;&4I*2`N("<N)R`N("1F;W)M870["B`@("!]("\O(&5N9"!F=6YC(&=E
M;F5R871E240*("`@(`H@("`@"GT@+R\@96YD(&-L87-S($-A8VAE7T=R87!H
M:6-S"C\^"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T-A8VAE+TA4
M5%!?4F5Q=65S="YP:'``````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,C,R-30@,3`U,34T,S,W,S`@,#(R-#<T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!%05(@.CH@0V%C:&4@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I
M9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R
M<VEO;B`R+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\"B\O('P@=&AA
M="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)
M0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O
M=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R
M+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@
M268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E
M;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O
M=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O
M("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA
M:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z($9A
M8FEE;B!-05)462`\9F%B:65N+FUA<G1Y0&9R964N9G(^('P*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@2%144%]297%U97-T
M+G!H<"QV(#$N.2`R,#`S+S`W+S$S(#`X.C(W.C$X(&9A8B!%>'`@)`H*<F5Q
M=6ER95]O;F-E("=#86-H92YP:'`G.PIR97%U:7)E7V]N8V4@)TA45%`O4F5Q
M=65S="YP:'`G.PH*9&5F:6YE*"=#04-(15](5%107U)%455%4U1?1U)/55!?
M3D%-12<L("=C86-H95]H='1P7W)E<75E<W0G*3L*9&5F:6YE*"=#04-(15](
M5%107U)%455%4U1?4U5#0T534U]215-03TY315]#3T1%)RP@,C`P*3L*9&5F
M:6YE*"=#04-(15](5%107U)%455%4U1?2T5%4%],3T-!3%]#3U!9)RP@,2D[
M"F1E9FEN92@G0T%#2$5?2%144%]215%515-47U)%5%523E]&04Q312<L(#(I
M.PID969I;F4H)T-!0TA%7TA45%!?4D5154535%]215154DY?4$5!4E]%4E)/
M4B<L(#,I.PH*+RHJ"BH@2%144%]297%U97-T($-A8VAE"BH**B!4:&4@8VQA
M<W-I8V%L(&5X86UP;&4@:7,@.@HJ"BH@66]U('=A;G0@=&\@9V5T(&YE=W,@
M9G)O;2!A;F]T:&5R('-I=&4@=&AR;W5G:"!24U,@<F5M;W1E(&9I;&5S+B!"
M=70@>6]U"BH@9&]N)W0@=V%N="!T;R!A8V-E<W,@=&\@=&\@=&AE(')E;6]T
M92!S:71E(&%T(&5V97)Y('1I;64@>6]U(&1I<W!L87D**B!I=',@;F5W<R!O
M;B!Y;W5R('-I=&4N($)E8V%U<V4L(&EF('1H92!R96UO=&4@<VET92!I<R!D
M;W=N(&]R('-L;W<N+BX**B!3;R!Y;W4@>6]U(&YE960@82!C;&%S<R!W:&EC
M:"!M86ME<R!A(&QO8V%L(&-A8VAE(&-O<'D@;V8@=&AE(')E;6]T92!F:6QE
M+@HJ($5V97)Y('@@:&]U<G,L('1H92!C86-H92!I<R!U<&1A=&5D+B!"=70@
M:68@=&AE(')E;6]T92!S:71E(&ES(&1O=VXL('1H90HJ(&QO8V%L(&-A8VAE
M(&-O<'D@:7,@:V5E<&5D("AY;W4@8V%N(&%L<V\@9V5T(&5R<F]R(&UE<W-A
M9V5S(&EF('EO=2!W86YT*2X**@HJ(%-O('EO=2!N965D('1H:7,@8VQA<W,A
M"BH**B!#86-H95](5%107U)E<75E<W0@:6YH97)I=',@9G)O;2!#86-H92!A
M;F0@=7-E($A45%!?4F5Q=65S="!T;R!A8V-E<W,@=&\**B!T:&4@<F5M;W1E
M(&9I;&4N"BH**B!5<V%G92!E>&%M<&QE(#H**@HJ(#P_<&AP"BH@<F5Q=6ER
M95]O;F-E*"=#86-H92](5%107U)E<75E<W0N<&AP)RD["BH**B`D8V%C:&4@
M/2`F;F5W($-A8VAE7TA45%!?4F5Q=65S="@G:'1T<#HO+W=W=RYP:'`N;F5T
M)RP@3E5,3"P@)V9I;&4G+"!.54Q,+"`S-C`P*3L**B`D8V%C:&4M/G-E;F12
M97%U97-T*"D["BH@)')E;6]T949I;&5";V1Y(#T@)&-A8VAE+3YG971297-P
M;VYS94)O9'DH*3L**@HJ("@N+BXI"BH@/SX**@HJ($!A=71H;W(@("!&86)I
M96X@34%25%D@/&9A8FEE;BYM87)T>4!F<F5E+F9R/@HJ($!V97)S:6]N("`D
M260Z($A45%!?4F5Q=65S="YP:'`L=B`Q+CD@,C`P,R\P-R\Q,R`P.#HR-SHQ
M."!F86(@17AP("0**B!`<&%C:V%G92`@0V%C:&4**B\*"F-L87-S($-A8VAE
M7TA45%!?4F5Q=65S="!E>'1E;F1S($-A8VAE"GL*"B`@("`O+R`M+2T@4')I
M=F%T92!P<F]P97)T:65S("TM+0H*("`@("\J*@H@("`@*B!,:69E=&EM92!I
M;B!S96-O;F1S("@P(&5N9&QE<W,I"B`@("`J"B`@("`J($!V87(@:6YT("1?
M97AP:7)E<PH@("`@*B\*("`@('9A<B`D7V5X<&ER97,["@H@("`@+RHJ"B`@
M("`J($A45%`@4F5Q=65S=`H@("`@*@H@("`@*B!`=F%R(&]B:F5C="`D7W)E
M<75E<W0*("`@("HO"B`@("!V87(@)%]R97%U97-T.PH*("`@("\J*@H@("`@
M*B!#86-H92!I9"!F;W(@=&AE(&-L87-S:6,@8V%C:&4@9FEL90H@("`@*@H@
M("`@*B!`<V5E('-E;F1297%U97-T*"D*("`@("H@0'9A<B!S=')I;F<@)%]I
M9`H@("`@*B\*("`@('9A<B`D7VED.PH*("`@("\J*@H@("`@*B!#86-H92!I
M9"!F;W(@=&AE(&5N9&QE<W,@8V%C:&4@9FEL90H@("`@*@H@("`@*B!`<V5E
M('-E;F1297%U97-T*"D*("`@("H@0'9A<B!S=')I;F<@)%]I9`H@("`@*B\*
M("`@('9A<B`D7VED,CL*"B`@("`O*BH*("`@("H@1&%T82!T;R!U<V4*("`@
M("H*("`@("H@0'-E92!G971297!O;G-E0F]D>2@I+"!G971297!O;G-E2&5A
M9&5R*"DL(&=E=%)E<&]N<V5#;V1E*"D*("`@("H@0'9A<B!A<G)A>2`D7V1A
M=&$*("`@("HO"B`@("!V87(@)%]D871A(#L*"B`@("`O+R`M+2T@4'5B;&EC
M(&UE=&AO9',@+2TM"@H@("`@+RHJ"B`@("`J($-O;G-T<G5C=&]R"B`@("`J
M"B`@("`J($!P87)A;2`D=7)L(%1H92!U<FP@=&\@86-C97-S"B`@("`J($!P
M87)A;2`D<&%R86US($%S<V]C:6%T:79E(&%R<F%Y(&]F('!A<F%M971E<G,@
M=VAI8V@@8V%N(&)E.@H@("`@*B`@("`@("`@("`@("`@("`@(&UE=&AO9"`@
M("`@+2!-971H;V0@=&\@=7-E+"!'150L(%!/4U0@971C"B`@("`J("`@("`@
M("`@("`@("`@("`@:'1T<"`@("`@("`M($A45%`@5F5R<VEO;B!T;R!U<V4L
M(#$N,"!O<B`Q+C$*("`@("H@("`@("`@("`@("`@("`@("!U<V5R("`@("`@
M("T@0F%S:6,@075T:"!U<V5R;F%M90H@("`@*B`@("`@("`@("`@("`@("`@
M('!A<W,@("`@("`@+2!"87-I8R!!=71H('!A<W-W;W)D"B`@("`J("`@("`@
M("`@("`@("`@("`@<')O>'E?:&]S="`M(%!R;WAY('-E<G9E<B!H;W-T"B`@
M("`J("`@("`@("`@("`@("`@("`@<')O>'E?<&]R="`M(%!R;WAY('-E<G9E
M<B!P;W)T"B`@("`J("`@("`@("`@("`@("`@("`@<')O>'E?=7-E<B`M(%!R
M;WAY(&%U=&@@=7-E<FYA;64*("`@("H@("`@("`@("`@("`@("`@("!P<F]X
M>5]P87-S("T@4')O>'D@875T:"!P87-S=V]R9`H@("`@*B!`<&%R86T@<W1R
M:6YG("1C;VYT86EN97(@3F%M92!O9B!C;VYT86EN97(@8VQA<W,*("`@("H@
M0'!A<F%M(&%R<F%Y("1C;VYT86EN97)/<'1I;VYS($%R<F%Y('=I=&@@8V]N
M=&%I;F5R(&-L87-S(&]P=&EO;G,*("`@("H@0'!A<F%M(&EN="`D;6]D92!7
M:&%T('1O(&1O('=H96X@=&AE(')E;6]T92!S97)V97(@:7,@9&]W;B`Z"B`@
M("`J("`@("`@("`@("`@("`@("`@($-!0TA%7TA45%!?4D5154535%]+1450
M7TQ/0T%,7T-/4%D@;W(*("`@("H@("`@("`@("`@("`@("`@("`@0T%#2$5?
M2%144%]215%515-47U)%5%523E]&04Q312!O<@H@("`@*B`@("`@("`@("`@
M("`@("`@("!#04-(15](5%107U)%455%4U1?4D5455).7U!%05)?15)23U(*
M("`@("H@0'!A<F%M(&EN="`D97AP:7)E<R!L:69E=&EM92!O9B!T:&4@8V%C
M:&5D(&1A=&$@:6X@<V5C;VYD<R`M(#`@9F]R(&5N9&QE<W,*("`@("H@0'-E
M92!#86-H92P@2%144%]297%U97-T"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`J+PH@("`@9G5N8W1I;VX@0V%C:&5?2%144%]297%U97-T*"1U<FPL("1P
M87)A;7,@/2!.54Q,+"`D8V]N=&%I;F5R("`]("=F:6QE)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D8V]N=&%I;F5R3W!T:6]N<R`]($Y5
M3$PL("1E>'!I<F5S(#T@,S8P,"P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D;6]D92`]($-!0TA%7TA45%!?4D5154535%]+14507TQ/0T%,
M7T-/4%DI"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D<&%R86US*2D@)'!A
M<F%M<R`](&%R<F%Y*"D["B`@("`@("`@:68@*"%I<W-E="@D8V]N=&%I;F5R
M3W!T:6]N<RDI('L*("`@("`@("`@("`@)&-O;G1A:6YE<D]P=&EO;G,@/2!A
M<G)A>2`H"B`@("`@("`@("`@("`@("`G8V%C:&5?9&ER)R`]/B`G+W1M<"\G
M+`H@("`@("`@("`@("`@("`@)V9I;&5N86UE7W!R969I>"<@/3X@)V-A8VAE
M7R<*("`@("`@("`@("`@*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/D-A
M8VAE*"1C;VYT86EN97(L("1C;VYT86EN97)/<'1I;VYS*3L*("`@("`@("`D
M=&AI<RT^7W)E<75E<W0@/2`F;F5W($A45%!?4F5Q=65S="@D=7)L+"`D<&%R
M86US*3L*("`@("`@("`D=&AI<RT^7VED(#T@;60U*"1U<FPN<V5R:6%L:7IE
M*"1P87)A;7,I*3L*("`@("`@("`D=&AI<RT^7VED,B`](&UD-2@D=&AI<RT^
M7VED*3L@+R\@=V4@;F5E9"!T=V\@:V5Y<PH@("`@("`@("1T:&ES+3Y?;6]D
M92`]("1M;V1E.PH@("`@("`@("1T:&ES+3Y?97AP:7)E<R`]("1E>'!I<F5S
M.PH@("`@?0H*("`@("\J*@H@("`@*B!$96-O;G-T<G5C=&]R"B`@("`J"B`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`J+PH@("`@9G5N8W1I;VX@7T-A8VAE
M7TA45%!?4F5Q=65S="@I"B`@("!["B`@("`@("`@)'1H:7,M/E]#86-H92@I
M.PH@("`@?0H*("`@("\J*@H@("`@*B!'970@86YD(')E='5R;B!T:&4@<F5S
M<&]N<V4@8F]D>2`H3E5,3"!I9B!N;R!D871A(&%V86EL86)L92D*("`@("H*
M("`@("H@0'-E92!S96YD4F5Q=65S="@I"B`@("`J($!R971U<FX@;6EX960@
M<F5S<&]N<V4@8F]D>0H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%)E<W!O;G-E0F]D>2@I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?9&%T85LG8F]D>2==.PH@("`@?0H*("`@("\J*@H@("`@
M*B!'970@86YD(')E='5R;B!T:&4@<F5S<&]N<V4@8V]D92`H3E5,3"!I9B!N
M;R!D871A(&%V86EL86)L92D*("`@("H*("`@("H@0'-E92!S96YD4F5Q=65S
M="@I"B`@("`J($!R971U<FX@;6EX960@<F5S<&]N<V4@8V]D90H@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N(&=E=%)E<W!O;G-E
M0V]D92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&%T85LG8V]D
M92==.PH@("`@?0H*("`@("\J*@H@("`@*B!'970@86YD(')E='5R;B!T:&4@
M<F5S<&]N<V4@:&5A9&5R("A.54Q,(&EF(&YO(&1A=&$@879A:6QA8FQE*0H@
M("`@*@H@("`@*B!`<V5E('-E;F1297%U97-T*"D*("`@("H@0')E='5R;B!M
M:7AE9"!R97-P;VYS92!H96%D97(*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("HO"B`@("!F=6YC=&EO;B!G971297-P;VYS94AE861E<B@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?9&%T85LG:&5A9&5R)UT["B`@("!]"@H*
M("`@("\J*@H@("`@*B!3970@82!N97<@;6]D92!W:&5N('1H92!S97)V97(@
M:7,@9&]W;@H@("`@*@H@("`@*B!`<&%R86T@:6YT("1N97=-;V1E(%=H870@
M=&\@9&\@=VAE;B!T:&4@<F5M;W1E('-E<G9E<B!I<R!D;W=N(#H*("`@("H@
M("`@("`@("`@("`@("`@("`@("`@0T%#2$5?2%144%]215%515-47TM%15!?
M3$]#04Q?0T]062!O<@H@("`@*B`@("`@("`@("`@("`@("`@("`@("!#04-(
M15](5%107U)%455%4U1?4D5455).7T9!3%-%(&]R"B`@("`J("`@("`@("`@
M("`@("`@("`@("`@($-!0TA%7TA45%!?4D5154535%]215154DY?4$5!4E]%
M4E)/4@H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N
M('-E=$UO9&4H)&YE=TUO9&4I"B`@("!["B`@("`@("`@)'1H:7,M/E]M;V1E
M(#T@)&YE=TUO9&4["B`@("!]"@H@("`@+RHJ"B`@("`J(%-E;F0@=&AE($A4
M5%`@<F5Q=65S="!O<B!U<V4@=&AE(&-A8VAE('-Y<W1E;0H@("`@*@H@("`@
M*B!)9B!T:&5R92!I<R!A(&-A8VAE(&9I;&4@9F]R('1H:7,@2%144"!R97%U
M97-T+"!T:&4@<F5Q=65S="!I<R!N;W0@<F4M<V5N="X*("`@("H@0V%C:&5D
M(')E<W!O;G-E(&ES('5S960N(%EE="P@:68@=&AE(&-A8VAE(&ES(&5X<&ER
M960L('1H92!(5%10(')E<75E<W0*("`@("H@:7,@<F4M<V5N="X@5&AE;BP@
M:68@=&AE(')E;6]T92!S97)V97(@:7,@9&]W;BP@=&AI<R!M971H;V0@=VEL
M;"!R971U<FX@.@H@("`@*B`H9&5P96YD:6YG(&]N('1H92!S96QE8W1E9"!M
M;V1E*0H@("`@*B`M(&9A;'-E(&]R"B`@("`J("T@82!014%27T5R<F]R(&]R
M("AB971T97(I"B`@("`J("T@=')U92!A;F0@=&AE(&QO8V%L(&-O<'D@;V8@
M=&AE(&QA=&5S="!V86QI9"!R97-P;VYS92!W:6QL(&)E('5S960N"B`@("`J
M"B`@("`J("AT96-H;FEC86PI"B`@("`J($9O<B!T:&4@;&%S="!C:&]I8V4L
M('1H97)E(&ES(&$@=&5C:&YI8V%L('1I<',N"B`@("`J($EN9&5E9"P@=&AE
M<F4@87)E('1W;R!C86-H92!F:6QE<RX@5&AE(&9I<G-T(&]N92`H:60@:V5Y
M*2!I<R!A(&-L87-S:6-A;"!O;F4*("`@("H@=VET:"!T:&4@9VEV96X@;&EF
M971I;64N($)U="!I="!C86X@8F4@<F5M;W9E9"!B>2!A=71O;6%T:6,@9V%R
M8F%G92!C;VQL96-T:6]N"B`@("`J(&9O<B!E>&%M<&QE+B!3;R!T;R!B92!A
M8FQE('1O('5S92!T:&4@;&%T97-T('9A;&ED(')E<W!O;G-E("AW:&5N('1H
M92!R96UO=&4*("`@("H@<V5R=F5R(&ES(&1E860I+"!W92!M86ME(&$@<V5C
M;VYD(&-A8VAE(&9I;&4@=VET:"!N;R!L:69E=&EM92`H:60R(&ME>2DN"B`@
M("`J"B`@("`J($!R971U<FX@;6EX960@=')U92!O<B!F86QS92!O<B!A(%!%
M05)?15)23U(*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("HO"B`@("!F=6YC
M=&EO;B!S96YD4F5Q=65S="@I"B`@("!["B`@("`@("`@:68@*"1D871A(#T@
M)'1H:7,M/F=E="@D=&AI<RT^7VED+"!#04-(15](5%107U)%455%4U1?1U)/
M55!?3D%-12DI('L*("`@("`@("`@("`@+R\@+2TM($-A8VAE(&AI="`M+2T*
M("`@("`@("`@("`@)'1H:7,M/E]D871A(#T@)&1A=&$["B`@("`@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O
M("TM+2!#86-H92!M:7-S("TM+0H@("`@("`@("`@("!I9B`H)'1H:7,M/E]S
M96YD4F5Q=65S=$%N9$=E=%)E<W!O;G-E*"DI('L*("`@("`@("`@("`@("`@
M("\O(%-O('1H92!R96UO=&4@<V5R=F5R(&ES(&]K+BXN"B`@("`@("`@("`@
M("`@("`D=&AI<RT^<V%V92@D=&AI<RT^7VED+"`D=&AI<RT^7V1A=&$L("1T
M:&ES+3Y?97AP:7)E<RP@0T%#2$5?2%144%]215%515-47T=23U507TY!344I
M.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-A=F4H)'1H:7,M/E]I9#(L("1T
M:&ES+3Y?9&%T82P@,"P@0T%#2$5?2%144%]215%515-47T=23U507TY!344I
M.PH@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("!I9B`H)&1A=&%?<V%V(#T@)'1H:7,M
M/F=E="@D=&AI<RT^7VED,BP@0T%#2$5?2%144%]215%515-47T=23U507TY!
M344I*2!["B`@("`@("`@("`@("`@("`@("`@+R\@3VLL('1H92`B<F5C;W9E
M<B!C86-H92(@:7,@879A:6QA8FQE+BXN"B`@("`@("`@("`@("`@("`@("`@
M<W=I=&-H("@D=&AI<RT^7VUO9&4I('L*("`@("`@("`@("`@("`@("`@("!C
M87-E($-!0TA%7TA45%!?4D5154535%]+14507TQ/0T%,7T-/4%DZ"B`@("`@
M("`@("`@("`@("`@("`@("`@("\O(%=E(&UA:V4@82!N97<@;&]C86P@8V]P
M>2!A;F0@:V5E<"!I="!U;G1I;"!I="!E>'!I<F5S+BXN"B`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YS879E*"1T:&ES+3Y?:60L("1D871A7W-A
M=BP@)'1H:7,M/E]E>'!I<F5S+"!#04-(15](5%107U)%455%4U1?1U)/55!?
M3D%-12D["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&%T82`]
M("1D871A7W-A=CL*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R
M=64["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("`@("`@("`@(&-A<V4@0T%#2$5?2%144%]215%515-47U)%5%523E]&04Q3
M13H*("`@("`@("`@("`@("`@("`@("`@("`@+R\@5V4@<F5T=7)N(&9A;'-E
M"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@
M8V%S92!#04-(15](5%107U)%455%4U1?4D5455).7U!%05)?15)23U(Z"B`@
M("`@("`@("`@("`@("`@("`@("`@("\O(%=E(')E='5R;B!A(%!%05)?17)R
M;W(A"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?
M17)R;W(H)U)E;6]T92!F:6QE(&ES(&YO="!A=F%I;&%B;&4A)RD["B`@("`@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@+R\@270G<R!T97)R:6)L92$@5&AE(')E;6]T92!S97)V97(@:7,@9&]W
M;B!A;F0@9&5F:6YI=&EV96QY(&YO(&-A8VAE(&%V86EL86)L92$*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*"=296UO=&4@
M<V5R=F5R(&1O=VX@86YD(&YO(&-A8VAE(&%V86EL86)L92$G*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@
M("`O+R`M+2T@4')I=F%T92!-971H;V1S("TM+0H*("`@("\J*@H@("`@*B!3
M96YD($A45%`@<F5Q=65S="!A;F0@9V5T('1H92!R97-P;VYS90H@("`@*@H@
M("`@*B!`<F5T=7)N(&)O;VQE86X@<W5C8V5S<R!O<B!N;W0@/PH@("`@*B!`
M<V5E($A45%!?4F5Q=65S=`H@("`@*B!`86-C97-S('!R:79A=&4*("`@("HO
M"B`@("!F=6YC=&EO;B!?<V5N9%)E<75E<W1!;F1'971297-P;VYS92@I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]R97%U97-T+3YS96YD4F5Q=65S="@I.PH@
M("`@("`@("1B;V1Y(#T@)'1H:7,M/E]R97%U97-T+3YG971297-P;VYS94)O
M9'DH*3L*("`@("`@("`D8V]D92`]("1T:&ES+3Y?<F5Q=65S="T^9V5T4F5S
M<&]N<V5#;V1E*"D["B`@("`@("`@)&AE861E<B`]("1T:&ES+3Y?<F5Q=65S
M="T^9V5T4F5S<&]N<V5(96%D97(H*3L*("`@("`@("`D=&AI<RT^7V1A=&$@
M/2!A<G)A>2@*("`@("`@("`@("`@)V)O9'DG(#T^("1B;V1Y+`H@("`@("`@
M("`@("`G8V]D92<@/3X@)&-O9&4L"B`@("`@("`@("`@("=H96%D97(G(#T^
M("1H96%D97(*("`@("`@("`I.PH@("`@("`@(')E='5R;B`H*"1C;V1E/3U#
M04-(15](5%107U)%455%4U1?4U5#0T534U]215-03TY315]#3T1%*2`_('1R
M=64@.B!F86QS92D["B`@("!]"@I]"C\^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T-A8VAE+T]U='!U
M="YP:'``````````````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,38Q-3,@,3`U,34T,S,W,S`@,#(Q-3`U`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\(%!%05(@.CH@0V%C:&4@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT
M("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO
M;B`R+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\"B\O('P@=&AA="!I
M<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.
M4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X
M="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@
M>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E
M(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@
M("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@
M>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%5L9B!7
M96YD96P@/'5L9BYW96YD96Q`<&AP9&]C+F1E/B`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@?"`@("`@("`@("!#:')I<W1I86X@4W1O8VME<B`\
M8VAR96=U0'!H86YT+F-H/B`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M('P@("`@("`@("`@5FEN86D@2V]P<"`\:V]P<$!N971Z87)B96ET97(N9&4^
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!/=71P=70N<&AP+'8@,2XV(#(P
M,#,O,#$O,#0@,3$Z-30Z-#4@;6H@17AP("0*"G)E<75I<F5?;VYC92`G0V%C
M:&4N<&AP)SL*"B\J*@HJ($-L87-S('1O(&-A8VAE('1H92!O=71P=70@;V8@
M82!S8W)I<'0@=7-I;F<@=&AE(&]U='!U="!B=69F97)I;F<@9G5N8W1I;VYS
M"BH**B!3:6UP;&4@;W5T<'5T(&-A8VAE+B!3;VUE('!A9V5S(')E<75I<F4@
M;&]T<R!O9B!T:6UE('1O(&-O;7!U=&4N($-A8VAI;F<@=&AE"BH@;W5T<'5T
M(&-A;B!I;F-R96%S92!T:&4@;W9E<F%L;"!S<&5E9"!D<F%M871I8V%L;'DL
M(&5S<&5C:6%L;'D@:68@>6]U('5S90HJ(&$@4VAA<F5D($UE;6]R>2!S=&]R
M86=E(&-O;G1A:6YE<BX**@HJ($%S('EO=2!C86X@<V5E(&EN('1H92!E>&%M
M<&QE('1H92!U<V%G92!I<R!E>'1E;65L>2!S:6UP;&4N(%1O(&-A8VAE(&$@
M<V-R:7!T"BH@<VEM<&QE('!U="!S;VUE(&9E=R!L:6YE<R!O9B!C;V1E(&EN
M(&9R;VYT(&]F('EO=7(@<V-R:7!T(&%N9"!S;VUE(&%T('1H92!E;F0N"BH@
M02!P<F5F97)R86)L92!P;&%C92!F;W(@=&AI<R!A<F4@=&AE(&%U=&]?<')E
M<&5N9"!A;F0@875T;U]A<'!E;F0@9FEL97,@*#T^('!H<"YI;FDI+@HJ"BH@
M57-A9V4@97AA;7!L93H**@HJ("`O+R!P;&%C92!T:&ES('-O;65W:&5R92!I
M;B!A(&-E;G1R86P@8V]N9FEG(&9I;&4**B`@9&5F:6YE*$-!0TA%7U-43U)!
M1T5?0TQ!4U,L("=F:6QE)RD["BH@("\O(&9I;&4@<W1O<F%G92!N965D<R!A
M(&1I<B!T;R!P=70@=&AE(&-A8VAE(&9I;&5S"BH@(&1E9FEN92A#04-(15]$
M25(L("<O=F%R+W1M<"\G*3L**@HJ("`O+R!G970@82!C86-H92!O8FIE8W0*
M*B`@)&-A8VAE(#T@;F5W($-A8VAE7T]U='!U="A#04-(15]35$]204=%7T-,
M05-3+"!A<G)A>2@G8V%C:&5?9&ER)R`]/B!#04-(15]$25(I*3L**@HJ("`O
M+R!C;VUP=71E('1H92!U;FEQ=64@:&%N9&QE+@HJ("`O+R!I9B!Y;W5R('-C
M<FEP="!D97!E;F1S(&]N($-O;VMI92!A;F0@2%144"!0;W-T(&1A=&$@87,@
M=V5L;`HJ("`O+R!Y;W4@<VAO=6QD('5S93H**B`@+R\@)&-A8VAE7VAA;F1L
M92`](&%R<F%Y*`HJ("`O+R`@("`@("`@("`@("`@("`@("`@("`@)V9I;&4G
M(#T^("1215%515-47U5222P**B`@+R\@("`@("`@("`@("`@("`@("`@("`@
M("=P;W-T)R`]/B`D2%144%]03U-47U9!4E,L"BH@("\O("`@("`@("`@("`@
M("`@("`@("`@("`G8V]O:VEE)R`@/3X@)$A45%!?0T]/2TE%7U9!4E,**B`@
M+R\@("`@("`@("`@("`@("`@("`@("D["BH@("\O($)U="!B92!W87)N960L
M('5S:6YG(&%L;"!'150@;W(@4$]35"!687)I86)L97,@87,@82!S965D"BH@
M("\O(&-A;B!B92!U<V5D(&9O<B!A($1/4R!A='1A8VLN($-A;&QI;F<@:'1T
M<#HO+W=W=RYE>&%M<&QE+F-O;2]E>&%M<&QE+G!H<#]W:&%T979E<@HJ("`O
M+R!W:&5R92!W:&%T979E<B!I<R!A(')A;F1O;2!T97AT(&UI9VAT(&)E('5S
M960@=&\@9FQO;V0@>6]U<B!C86-H92X**B`@)&-A8VAE7VAA;F1L92`]("1C
M86-H92T^9V5N97)A=&5)1"@D4D5154535%]54DDI.PHJ"BH@("\O(&YO=R!T
M:&4@;6%G:6,@:&%P<&5N<SH@:68@8V%C:&5D(&-A;&P@9&EE*"D**B`@+R\@
M=&\@96YD('1H92!T:6UE(&-O;G-U;7!T:6]N9R!S8W)I<'0@<V-R:7!T(&5X
M96-U=&EO;B!A;F0@=7-E('1H92!C86-H960@=F%L=64A"BH@(&EF("@D8V]N
M=&5N="`]("1C86-H92T^<W1A<G0H)&-A8VAE7VAA;F1L92DI('L**B`@("`@
M<')I;G0@)&-O;G1E;G0["BH@("`@('!R:6YT("<\<#Y#86-H92!H:70\+W`^
M)SL**B`@("`@9&EE*"D["BH@('T**@HJ("`O+R!T:6UE(&-O;G-U;7!T:6]N
M('-C<FEP="!G;V5S(&AE<F4N"BH**B`@+R\@<W1O<F4@=&AE(&]U='!U="!O
M9B!T:&4@8V%C:&4@:6YT;R!T:&4@8V%C:&4@86YD('!R:6YT('1H92!O=71P
M=70N"BH@('!R:6YT("1C86-H92T^96YD*"D["BH@('!R:6YT("(\<#Y#86-H
M92!M:7-S+"!S=&]R960@=7-I;F<@=&AE($E$("<D:60G+CPO<#XB.PHJ"BH@
M($EF('EO=2!D;R!N;W0@=V%N="!T;R!C86-H92!A('=H;VQE('!A9V4@+2!N
M;R!P<F]B;&5M.@HJ"BH@(&EF("@A*"1C;VYT96YT(#T@)&-A8VAE+3YS=&%R
M="@D8V%C:&5?:&%N9&QE*2DI('L**B`@("`@+R\@9&\@=&AE(&-O;7!U=&%T
M:6]N(&AE<F4**B`@("`@<')I;G0@)&-A8VAE+3YE;F0H*0HJ("!](&5L<V4@
M>PHJ("`@("!P<FEN="`D8V]N=&5N=#L**B`@?0HJ"BH@($EF('EO=2!N965D
M(&%N(&5X86UP;&4@<V-R:7!T(&-H96-K('1H92`H875T;U\I<')E<&5N9"!A
M;F0@*&%U=&]?*6%P<&5N9`HJ("!F:6QE<R!O9B!M>2!H;VUE<&%G93H**@HJ
M("`@(&AT='`Z+R]W=W<N=6QF+7=E;F1E;"YD92]P:'`O<VAO=U]S;W5R8V4N
M<&AP/V9I;&4]<')E<&5N9`HJ("`@(&AT='`Z+R]W=W<N=6QF+7=E;F1E;"YD
M92]P:'`O<VAO=U]S;W5R8V4N<&AP/V9I;&4]87!P96YD"BH**B`@1&]N)W0@
M:VYO=R!H;W<@=&\@=7-E(&ET(&]R('EO=2!N965D('!R;V9I;&EN9R!I;F9O
M<FUA=&EO;G,_8`HJ("!!<VL@0VAR:7-T:6%N(&AE('=A<R!P871I96YT('=I
M=&@@;64@86YD(&AE)VQL(&)E('-O('=I=&@@>6]U<B!Q=65S=&EO;G,@.RDN
M"BH**B`@2&%V92!F=6XA"BH**B!`875T:&]R<R`@56QF(%=E;F1E;"`\=6QF
M+G=E;F1E;$!P:'!D;V,N9&4^"BH@0'9E<G-I;VX@("1)1#H@)`HJ($!P86-K
M86=E("!#86-H90HJ($!A8V-E<W,@("!P=6)L:6,**B\*8VQA<W,@0V%C:&5?
M3W5T<'5T(&5X=&5N9',@0V%C:&4@>PH*("`@("\J*@H@("`@*B!)1"!P87-S
M960@=&\@<W1A<G0H*0H@("`@*@H@("`@*B!`=F%R("!S=')I;F<*("`@("H@
M0'-E92`@<W1A<G0H*2P@96YD*"D*("`@("HO"B`@("!V87(@)&]U='!U=%]I
M9"`]("<G.PH*("`@("\J*@H@("`@*B!'<F]U<"!P87-S960@=&\@<W1A<G0H
M*0H@("`@*@H@("`@*B!`=F%R("!S=')I;F<*("`@("H@0'-E92`@<W1A<G0H
M*2P@96YD*"D*("`@("HO"B`@("!V87(@)&]U='!U=%]G<F]U<"`]("<G.PH*
M("`@("\J*@H@("`@*B!014%2+41E8V]N<W1R=6-T;W(*("`@("H@0V%L;"!D
M96-O;G-T<G5C=&]R(&]F('!A<F5N=`H@("`@*B\*("`@(&9U;F-T:6]N(%]#
M86-H95]/=71P=70H*0H@("`@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]#
M86-H92@I.PH@("`@?0H*("`@("\J*@H@("`@*B!S=&%R=',@=&AE(&]U='!U
M="!B=69F97)I;F<@86YD(')E='5R;G,@86X@96UP='D@<W1R:6YG(&]R(')E
M='5R;G,@=&AE(&-A8VAE9"!O=71P=70@9G)O;2!T:&4@8V%C:&4N"B`@("`J
M"B`@("`J($!P87)A;2`@("!S=')I;F<@(&1A=&%S970@240*("`@("H@0'!A
M<F%M("`@('-T<FEN9R`@8V%C:&4@9W)O=7`*("`@("H@0')E='5R;B`@('-T
M<FEN9PH@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J+PH@("`@9G5N8W1I
M;VX@<W1A<G0H)&ED+"`D9W)O=7`@/2`G9&5F875L="<I('L*("`@("`@("!I
M9B`H(21T:&ES+3YC86-H:6YG*0H@("`@("`@("`@("!R971U<FX@)R<["@H@
M("`@("`@("\O('1H:7,@:7,@86QR96%D>2!C86-H960@<F5T=7)N(&ET(&9R
M;VT@=&AE(&-A8VAE('-O('1H870@=&AE('5S97(*("`@("`@("`O+R!C86X@
M=7-E('1H92!C86-H92!C;VYT96YT(&%N9"!S=&]P('-C<FEP="!E>&5C=71I
M;VX*("`@("`@("!I9B`H)&-O;G1E;G0@/2`D=&AI<RT^9V5T*"1I9"P@)&=R
M;W5P*2D*("`@("`@("`@("`@<F5T=7)N("1C;VYT96YT.PH*("`@("`@("`O
M+R!R96UE;6)E<B!S;VUE(&1A=&$@=&\@8F4@86)L92!T;R!F:6QL('1H92!C
M86-H92!O;B!C86QL:6YG(&5N9"@I"B`@("`@("`@)'1H:7,M/F]U='!U=%]I
M9"`]("1I9#L*("`@("`@("`D=&AI<RT^;W5T<'5T7V=R;W5P(#T@)&=R;W5P
M.PH*("`@("`@("`O+R!705).24Y'.B!W92!N965D('1H92!O=71P=70@8G5F
M9F5R("T@<&]S<VEB;&4@8VQA<VAE<PH@("`@("`@(&]B7W-T87)T*"D["B`@
M("`@("`@;V)?:6UP;&EC:71?9FQU<V@H9F%L<V4I.PH*("`@("`@("!R971U
M<FX@)R<["B`@("!]("\O(&5N9"!F=6YC('-T87)T"@H@("`@+RH*("`@("H@
M4W1O<F5S('1H92!C;VYT96YT(&]F('1H92!O=71P=70@8G5F9F5R(&EN=&\@
M=&AE(&-A8VAE(&%N9"!R971U<FYS('1H92!C;VYT96YT+@H@("`@*@H@("`@
M*B!`<&%R86T@("`@;6EX960@("!L:69E=&EM92!O9B!T:&4@8V%C:&5D(&1A
M=&$@:6X@<V5C;VYD<R`M(#`@9F]R(&5N9&QE<W,N($UO<F4@9F]R;6%T<R!A
M=F%I;&%B;&4N('-E92!#;VYT86EN97(Z.F=E=$5X<&ER97-!8G-O;'5T92@I
M"B`@("`J($!P87)A;2`@("!S=')I;F<@(&%D9&ET:6]N86P@=7-E<F1E9FEN
M960@9&%T80H@("`@*B!`<F5T=7)N("`@<W1R:6YG("!C86-H960@;W5T<'5T
M"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("H@0'-E92`@("`@(&5N9%!R
M:6YT*"DL(&5N9$=E="@I+"!#;VYT86EN97(Z.F=E=$5X<&ER97-!8G-O;'5T
M92@I"B`@("`J+PH@("`@9G5N8W1I;VX@96YD*"1E>'!I<F4@/2`P+"`D=7-E
M<F1A=&$@/2`G)RD@>PH@("`@("`@("1C;VYT96YT(#T@;V)?9V5T7V-O;G1E
M;G1S*"D["B`@("`@("`@;V)?96YD7V-L96%N*"D["@H@("`@("`@("\O('-T
M;W)E(&EN('1H92!C86-H90H@("`@("`@(&EF("@D=&AI<RT^8V%C:&EN9RD*
M("`@("`@("`@("`@)'1H:7,M/F-O;G1A:6YE<BT^<V%V92@D=&AI<RT^;W5T
M<'5T7VED+"`D8V]N=&5N="P@)&5X<&ER92P@)'1H:7,M/F]U='!U=%]G<F]U
M<"P@)'5S97)D871A*3L*"B`@("`@("`@<F5T=7)N("1C;VYT96YT.PH@("`@
M?2`O+R!E;F0@9G5N8R!E;F0H*0H*("`@("\J*@H@("`@*B!3=&]R97,@=&AE
M(&-O;G1E;G0@;V8@=&AE(&]U='!U="!B=69F97(@:6YT;R!T:&4@8V%C:&4@
M86YD('!R:6YT<R!T:&4@8V]N=&5N="X*("`@("H*("`@("H@0&)R;W1H97(@
M(&5N9"@I"B`@("`J+PH@("`@9G5N8W1I;VX@96YD4')I;G0H)&5X<&ER92`]
M(#`L("1U<V5R9&%T82`]("<G*2!["B`@("`@("`@)'1H:7,M/G!R:6YT0V]N
M=&5N="@D=&AI<RT^96YD*"1E>'!I<F4L("1U<V5R9&%T82DI.PH@("`@?2`O
M+R!E;F0@9G5N8R!E;F10<FEN=`H*("`@("\J*@H@("`@*B!396YD<R!T:&4@
M9&%T82!T;R!T:&4@=7-E<BX*("`@("H@5&AI<R!I<R!F;W(@8V]M<&%T:6)I
M;&ET>2!W:71H($]U='!U=$-O;7!R97-S:6]N"B`@("`J(`H@("`@*B!`<&%R
M86T@("`@<W1R:6YG"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("HO("`@
M(`H@("`@9G5N8W1I;VX@<')I;G1#;VYT96YT*"1C;VYT96YT(#T@)R<I('L*
M("`@("`@("!I9B`H)R<@/3T@)&-O;G1E;G0I"B`@("`@("`@("`@("1C;VYT
M96YT(#T@)B1T:&ES+3YC;VYT86EN97(M/F-A8VAE9&%T83L*("`@("`@("`@
M("`@"B`@("`@("`@<')I;G0@)&-O;G1E;G0["B`@("!]"B`@("`O*BH*("`@
M("H@4F5T=7)N<R!T:&4@8V]N=&5N="!O9B!T:&4@;W5T<'5T(&)U9F9E<B!B
M=70@9&]E<R!N;W0@<W1O<F4@:70@:6YT;R!T:&4@8V%C:&4N"B`@("`J"B`@
M("`J(%5S92!T:&ES(&UE=&AO9"!I9B!T:&4@8V]N=&5N="!O9B!Y;W5R('-C
M<FEP="!I<R!M87)K=7`@*%A-3"D*("`@("H@=&AA="!H87,@=&\@8F4@<&%R
M<V5D+V-O;G9E<G1E9"`H6%-,5"D@8F5F;W)E('EO=2!C86X@;W5T<'5T"B`@
M("`J(&%N9"!S=&]R92!I="!I;G1O('1H92!C86-H92!U<VEN9R!S879E*"DN
M"B`@("`J"B`@("`J($!R971U<FX@("!S=')I;F<*("`@("H@0&%C8V5S<R`@
M('!U8FQI8PH@("`@*B!`<V5E("`@("`@96YD4')I;G0H*2P@96YD*"D*("`@
M("HO"B`@("!F=6YC=&EO;B!E;F1'970H*2!["B`@("`@("`@)&-O;G1E;G0@
M/2!O8E]G971?8V]N=&5N=',H*3L*("`@("`@("!O8E]E;F1?8VQE86XH*3L*
M"B`@("`@("`@)'1H:7,M/F]U='!U=%]I9"`]("<G.PH@("`@("`@("1T:&ES
M+3YO=71P=71?9W)O=7`@/2`G)SL*"B`@("`@("`@<F5T=7)N("1C;VYT96YT
M.PH@("`@?2`O+R!E;F0@9G5N8R!E;F1'970*?2`O+R!E;F0@8VQA<W,@;W5T
M<'5T"C\^"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O0V%C:&4O3W5T
M<'5T0V]M<')E<W-I;VXN<&AP````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`R,34S-"`Q,#4Q-30S,S<S,"`P,C,W,C8`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@4$5!4B`Z.B!#86-H92`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG
M:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S
M:6]N(#(N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P*+R\@?"!T:&%T
M(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#
M14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U
M9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N
M='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)
M9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N
M<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U
M9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@
M("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I
M;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@56QF
M(%=E;F1E;"`\=6QF+G=E;F1E;$!P:'!D;V,N9&4^("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R!\("`@("`@("`@($-H<FES=&EA;B!3=&]C:V5R
M(#QC:')E9W5`<&AA;G0N8V@^("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"@IR97%U:7)E7V]N8V4@
M)T-A8VAE+T]U='!U="YP:'`G.PH*+RHJ"BH@0V%C:&4@=7-I;F<@3W5T<'5T
M($)U9F9E<FEN9R!A;F0@8V]N=&YE="`H9WHI(&-O;7!R97-S:6]N+@HJ*B!5
M<V%G92!E>&%M<&QE.@HJ"BH@("\O('!L86-E('1H:7,@<V]M97=H97)E(&EN
M(&$@8V5N=')A;"!C;VYF:6<@9FEL90HJ("!D969I;F4H0T%#2$5?4U1/4D%'
M15]#3$%34RP@)V9I;&4G*3L**B`@+R\@9FEL92!S=&]R86=E(&YE961S(&$@
M9&ER('1O('!U="!T:&4@8V%C:&4@9FEL97,**B`@9&5F:6YE*$-!0TA%7T1)
M4BP@)R]V87(O=&UP+R<I.PHJ"BH@("\O(&=E="!A(&-A8VAE(&]B:F5C=`HJ
M("`D8V%C:&4@/2!N97<@0V%C:&5?3W5T<'5T*$-!0TA%7U-43U)!1T5?0TQ!
M4U,L(&%R<F%Y*"=C86-H95]D:7(G(#T^($-!0TA%7T1)4BDI.PHJ"BH@(&EF
M("@A*"1C;VYT96YT(#T@)&-A8VAE+3YS=&%R="@D8V%C:&4M/F=E;F5R871E
M240H)%)%455%4U1?55))*2DI*2!["BH@("`@<')I;G0@(FAE;&QO('=O<FQD
M(CL**B`@("`D8V%C:&4M/F5N9%!R:6YT*"LQ,#`P*3L**B`@?0HJ("!E;'-E
M('L**B`@("`D8V%C:&4M/G!R:6YT0V]N=&5N="@I.PHJ("!]"BH**B`@($]2
M"BH**B`@:68@*"@D8V]N=&5N="`]("1C86-H92T^<W1A<G0H)&-A8VAE+3YG
M96YE<F%T94E$*"1215%515-47U5222DI*2D@>PHJ("`@("1C86-H92T^<')I
M;G1#;VYT96YT*"D["BH@("`@9&EE*"D["BH@('T**B`@("!P<FEN="`B:&5L
M;&\@=V]R;&0B.PHJ("`@("1C86-H92T^96YD4')I;G0H*S$P,#`I.PHJ"BH*
M*B!"87-E9"!U<&]N(&$@8V%S92!S='5D>2!F<F]M($-H<FES=&EA;B!3=&]C
M:V5R(&%N9"!I;G-P:7)E9"!B>2!J<&-A8VAE+@HJ"BH@0'9E<G-I;VX@("1)
M9#H@3W5T<'5T0V]M<')E<W-I;VXN<&AP+'8@,2XW(#(P,#,O,#$O,#0@,3$Z
M-30Z-#4@;6H@17AP("0**B!`875T:&]R("`@56QF(%=E;F1E;"`\=6QF+G=E
M;F1E;$!P:'!D;V,N9&4^+"!#:')I<W1I86X@4W1O8VME<B`\8VAR96=U0'!H
M86YT+F-H/@HJ($!A8V-E<W,@("!P=6)L:6,**B!`<&%C:V%G92`@0V%C:&4*
M*B\*8VQA<W,@0V%C:&5?3W5T<'5T0V]M<')E<W-I;VX@97AT96YD<R!#86-H
M95]/=71P=70@>PH@("`@"B`@("`O*BH*("`@("H@16YC;V1I;F<L('=H870@
M=&AE('5S97(@*&ET<R!B<F]W<V5R*2!O9B!Y;W5R('=E8G-I=&4@86-C97!T
M<PH@("`@*B`*("`@("H@(F%U=&\B('-T86YD<R!F;W(@=&5S="!U<VEN9R`D
M7U-%4E9%4ELG2%144%]!0T-%4%1?14Y#3T1)3D<G72@D2%144%]!0T-%4%1?
M14Y#3T1)3D<I+@H@("`@*@H@("`@*B!`=F%R("!S=')I;F<*("`@("H@0'-E
M92`@0V%C:&5?3W5T<'5T0V]M<')E<W-I;VXH*2P@<V5T16YC;V1I;F<H*0H@
M("`@*B\*("`@('9A<B`D96YC;V1I;F<@/2`G875T;R<["B`*("`@(`H@("`@
M+RHJ"B`@("`J($UE=&AO9"!U<V5D(&9O<B!C;VUP<F5S<VEO;@H@("`@*@H@
M("`@*B!`=F%R("!S=')I;F<*("`@("H@0'-E92`@:7-#;VUP<F5S<V5D*"D*
M("`@("HO(`H@("`@=F%R("1C;VUP<F5S<VEO;B`]("<G.PH*("`@(`H@("`@
M+RHJ"B`@("`J(%-E=',@=&AE('-T;W)A9V4@9&5T86EL<R!A;F0@=&AE(&-O
M;G1E;G0@96YC;V1I;F<@=7-E9"`H:68@;F]T(&%U=&]D971E8W1I;VXI"B`@
M("`J(`H@("`@*B!`<&%R86T@("`@<W1R:6YG("!.86UE(&]F(&-O;G1A:6YE
M<B!C;&%S<PH@("`@*B!`<&%R86T@("`@87)R87D@("!!<G)A>2!W:71H(&-O
M;G1A:6YE<B!C;&%S<R!O<'1I;VYS"B`@("`J($!P87)A;2`@("!S=')I;F<@
M(&-O;G1E;G0@96YC;V1I;F<@;6]D92`M(&%U=&\@/3X@=&5S="!W:&EC:"!E
M;F-O9&EN9R!T:&4@=7-E<B!A8V-E<'1S"B`@("`J+R`@("`*("`@(&9U;F-T
M:6]N($-A8VAE7T]U='!U=$-O;7!R97-S:6]N*"1C;VYT86EN97(L("1C;VYT
M86EN97)?;W!T:6]N<R`]("<G+"`D96YC;V1I;F<@/2`G875T;R<I('L*("`@
M(`H@("`@("`@("1T:&ES+3YS971%;F-O9&EN9R@D96YC;V1I;F<I.PH@("`@
M("`@("1T:&ES+3Y#86-H92@D8V]N=&%I;F5R+"`D8V]N=&%I;F5R7V]P=&EO
M;G,I.PH@("`@("`@(`H@("`@?2`O+R!E;F0@8V]N<W1R=6-T;W(*"B`@("`*
M("`@("\J*@H@("`@*B!#86QL('!A<F5N="!D96-O;G-T<G5C=&]R+@H@("`@
M*B\*("`@(&9U;F-T:6]N(%]#86-H95]/=71P=71#;VUP<F5S<VEO;B@I('L*
M("`@("`@("`D=&AI<RT^7T-A8VAE*"D["B`@("!]("\O(&5N9"!D96-O;G-T
M<G5C=&]R"B`@("`*"B`@("!F=6YC=&EO;B!G96YE<F%T94E$*"1V87)I86)L
M92D@>PH@("`@("`@(`H@("`@("`@("1T:&ES+3YC;VUP<F5S<VEO;B`]("1T
M:&ES+3YG971%;F-O9&EN9R@I.PH@("`@("`@(`H@("`@("`@(')E='5R;B!M
M9#4H<V5R:6%L:7IE*"1V87)I86)L92D@+B!S97)I86QI>F4H)'1H:7,M/F-O
M;7!R97-S:6]N*2D["B`@("!]("\O(&5N9"!G96YE<F%T94E$"@H@("`@"B`@
M("!F=6YC=&EO;B!G970H)&ED+"`D9W)O=7`I('L*("`@("`@("`D=&AI<RT^
M8V]N=&5N="`]("<G.PH@("`@("`@(`H@("`@("`@(&EF("@A)'1H:7,M/F-A
M8VAI;F<I"B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("`*("`@("`@
M("!I9B`H)'1H:7,M/FES0V%C:&5D*"1I9"P@)&=R;W5P*2`F)B`A)'1H:7,M
M/FES17AP:7)E9"@D:60L("1G<F]U<"DI"B`@("`@("`@("`@("1T:&ES+3YC
M;VYT96YT(#T@)'1H:7,M/FQO860H)&ED+"`D9W)O=7`I.PH@("`@("`@("`@
M("`*("`@("`@("!R971U<FX@)'1H:7,M/F-O;G1E;G0["B`@("!]("\O(&5N
M9"!F=6YC(&=E=`H@("`@"B`@("`*("`@("\J*@H@("`@*B!3=&]P<R!T:&4@
M;W5T<'5T(&)U9F9E<FEN9RP@<V%V97,@:70@=&\@=&AE(&-A8VAE(&%N9"!R
M971U<FYS('1H92!?8V]M<')E<W-E9%\@8V]N=&5N="X@"B`@("`J"B`@("`J
M($EF('EO=2!N965D('1H92!U;F-O;7!R97-S960@8V]N=&5N="!F;W(@9G5R
M=&AE<B!P<F]C97-S:6]N(&)E9F]R90H@("`@*B!I="=S('-A=F5D(&EN('1H
M92!C86-H92!U<V4@96YD1V5T*"DN(&5N9$=E="@I(&1O97,@7VYO="!C;VUP
M<F5S<U\N"B`@("`J+R`@("`*("`@(&9U;F-T:6]N(&5N9"@D97AP:7)E(#T@
M,"P@)'5S97)D871A(#T@)R<I('L*("`@("`@("`D8V]N=&5N="`](&]B7V=E
M=%]C;VYT96YT<R@I.PH@("`@("`@(&]B7V5N9%]C;&5A;B@I.PH*("`@("`@
M("`O+R!S=&]R92!I;B!T:&4@8V%C:&4*("`@("`@("!I9B`H)'1H:7,M/F-A
M8VAI;F<I('L*("`@("`@("`@("`@)'1H:7,M/F5X=%-A=F4H)'1H:7,M/F]U
M='!U=%]I9"P@)&-O;G1E;G0L("1U<V5R9&%T82P@)&5X<&ER92P@)'1H:7,M
M/F]U='!U=%]G<F]U<"D["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^8V]N
M=&5N=#L@("`@("`@("`@("`@("`@"B`@("`@("`@?0H@("`@("`@("`@("`*
M("`@("`@("!R971U<FX@)&-O;G1E;G0[("`@("`@("`*("`@('T@+R\@96YD
M(&9U;F,@96YD*"D*("`@(`H@("`@"B`@("!F=6YC=&EO;B!E;F10<FEN="@D
M97AP:7)E(#T@,"P@)'5S97)D871A(#T@)R<I('L*("`@("`@("`D=&AI<RT^
M<')I;G1#;VYT96YT*"1T:&ES+3YE;F0H)&5X<&ER92P@)'5S97)D871A*2D[
M"B`@("!]("\O(&5N9"!F=6YC(&5N9%!R:6YT"@H@("`@"B`@("`O*BH*("`@
M("H@4V%V97,@=&AE(&=I=F5N(&1A=&$@=&\@=&AE(&-A8VAE+@H@("`@*B`*
M("`@("HO("`@"B`@("!F=6YC=&EO;B!E>'13879E*"1I9"P@)&-A8VAE9&%T
M82P@)'5S97)D871A+"`D97AP:7)E<R`](#`L("1G<F]U<"`]("=D969A=6QT
M)RD@>PH@("`@("`@(&EF("@A)'1H:7,M/F-A8VAI;F<I"B`@("`@("`@("`@
M(')E='5R;B!T<G5E.PH*("`@("`@("!I9B`H)'1H:7,M/F-O;7!R97-S:6]N
M*2![("`@("`@("`@("`@"B`@("`@("`@("`@(`H@("`@("`@("`@("`D;&5N
M(#T@<W1R;&5N*"1C86-H961A=&$I.R`@("`@("`@("`@(`H@("`@("`@("`@
M("`D8W)C(#T@8W)C,S(H)&-A8VAE9&%T82D["B`@("`@("`@("`@("1C86-H
M961A=&$@/2!G>F-O;7!R97-S*"1C86-H961A=&$L(#DI.PH@("`@("`@("`@
M("`D=&AI<RT^8V]N=&5N="`]('-U8G-T<B@D8V%C:&5D871A+"`P+"!S=')L
M96XH)&-A8VAE9&%T82D@+2`T*2`N('!A8VLH)U8G+"`D8W)C*2`N('!A8VLH
M)U8G+"`D;&5N*3L*("`@("`@("`@("`@"B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@"B`@("`@("`@("`@("1T:&ES+3YC;VYT96YT(#T@)&-A8VAE
M9&%T83L*("`@("`@("`@("`@"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D
M=&AI<RT^8V]N=&%I;F5R+3YS879E*"1I9"P@)'1H:7,M/F-O;G1E;G0L("1E
M>'!I<F5S+"`D9W)O=7`L("1U<V5R9&%T82D["B`@("!]("\O(&5N9"!F=6YC
M(&5X=%-A=F4*("`@(`H@("`@+RHJ"B`@("`J(%-E;F1S('1H92!C;VUP<F5S
M<V5D(&1A=&$@=&\@=&AE('5S97(N"B`@("`J(`H@("`@*B!`<&%R86T@("`@
M<W1R:6YG"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("HO("`@(`H@("`@
M9G5N8W1I;VX@<')I;G1#;VYT96YT*"1C;VYT96YT(#T@)R<I('L*("`@("`@
M("`D<V5R=F5R(#T@)B1T:&ES+3Y?:6UP;W)T1VQO8F%L5F%R:6%B;&4H(G-E
M<G9E<B(I.PH*("`@("`@("!I9B`H)R<@/3T@)&-O;G1E;G0I"B`@("`@("`@
M("`@("1C;VYT96YT(#T@)B1T:&ES+3YC;VYT86EN97(M/F-A8VAE9&%T83L*
M("`@("`@("`@("`@("`@("`*("`@("`@("!I9B`H)'1H:7,M/F-O;7!R97-S
M:6]N("8F("1T:&ES+3YC86-H:6YG*2!["B`@(`H@("`@("`@("`@("`D971A
M9R`]("=014%2+4-A8VAE+2<@+B!M9#4H<W5B<W1R*"1C;VYT96YT+"`M-#`I
M*3L*("`@("`@("`@("`@:&5A9&5R*")%5&%G.B`D971A9R(I.PH@("`@("`@
M("`@("!I9B`H:7-S970H)'-E<G9E<ELG2%144%])1E].3TY%7TU!5$-()UTI
M("8F('-T<G-T<BAS=')I<'-L87-H97,H)'-E<G9E<ELG2%144%])1E].3TY%
M7TU!5$-()UTI+"`D971A9RDI('L*("`@("`@("`@("`@("`@("\O(&YO="!M
M;V1I9FEE9`H@("`@("`@("`@("`@("`@:&5A9&5R*"=(5%10+S$N,"`S,#0G
M*3L*("`@("`@("`@("`@("`@(')E='5R;CL*("`@("`@("`@("`@?2!E;'-E
M('L*("`@"B`@("`@("`@("`@("`@("`O+R!C;&EE;G0@86-C97!P=',@<V]M
M92!E;F-O9&EN9R`M('-E;F0@:&5A9&5R<R`F(&1A=&$*("`@("`@("`@("`@
M("`@(&AE861E<B@B0V]N=&5N="U%;F-O9&EN9SH@>R1T:&ES+3YC;VUP<F5S
M<VEO;GTB*3L*("`@("`@("`@("`@("`@(&AE861E<B@G5F%R>3H@06-C97!T
M+45N8V]D:6YG)RD["B`@("`@("`@("`@("`@("!P<FEN="`B7'@Q9EQX.&)<
M>#`X7'@P,%QX,#!<>#`P7'@P,%QX,#`B.PH@("`@("`@("`@("!]"B`@("`@
M("`@"B`@("`@("`@?0H@("`@("`@(`H@("`@("`@(&1I92@D8V]N=&5N="D[
M"B`@("!]("\O(&5N9"!F=6YC('!R:6YT0V]N=&5N=`H@("`@"B`@("`*("`@
M("\J*@H@("`@*B!2971U<FYS('1H92!E;F-O9&EN9R!M971H;V0@;V8@=&AE
M(&-U<G)E;G0@9&%T87-E="X@"B`@("`J"B`@("`J($!A8V-E<W,@("!P=6)L
M:6,*("`@("H@0')E='5R;B`@('-T<FEN9R`@16UP='D@<W1R:6YG("AW:&EC
M:"!E=F%L=6%T97,@=&\@9F%L<V4I(&UE86YS(&YO(&-O;7!R97-S:6]N"B`@
M("`J+PH@("`@9G5N8W1I;VX@:7-#;VUP<F5S<V5D*"D@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^8V]M<')E<W-I;VX["B`@("!]("\O(&5N9"!F=6YC(&ES
M0V]M<')E<W-E9`H*("`@("\J*@H@("`@*B!3971S('1H92!E;F-O9&EN9R!T
M;R!B92!U<V5D+@H@("`@*B`*("`@("H@0'!A<F%M("`@('-T<FEN9R`@(F%U
M=&\B(&UE86YS(&%U=&]D971E8W0@9F]R(&5V97)Y(&-L:65N=`H@("`@*B!`
M86-C97-S("`@<'5B;&EC"B`@("`J($!S964@("`@("`D96YC;V1I;F<*("`@
M("HO"B`@("!F=6YC=&EO;B!S971%;F-O9&EN9R@D96YC;V1I;F<@/2`G875T
M;R<I('L*("`@("`@("`D=&AI<RT^96YC;V1I;F<@/2`D96YC;V1I;F<["B`@
M("!]("\O(&5N9"!F=6YC('-E=$5N8V]D:6YG"B`@("`*("`@(`H@("`@+RHJ
M"B`@("`J(%)E='5R;G,@=&AE(&5N8V]D:6YG('1O(&)E('5S960@9F]R('1H
M92!D871A('1R86YS;6ES<VEO;B!T;R!T:&4@8VQI96YT+@H@("`@*@H@("`@
M*B!`<V5E("`@("`@<V5T16YC;V1I;F<H*0H@("`@*B\@("`@"B`@("!F=6YC
M=&EO;B!G971%;F-O9&EN9R@I('L*("`@("`@("`D<V5R=F5R(#T@)B1T:&ES
M+3Y?:6UP;W)T1VQO8F%L5F%R:6%B;&4H(G-E<G9E<B(I.PH*("`@("`@("`O
M+R!E;F-O9&EN9R!S970@8GD@=7-E<B`@("`*("`@("`@("!I9B`H)V%U=&\G
M("$]("1T:&ES+3YE;F-O9&EN9RD*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YE;F-O9&EN9SL*("`@("`@("`*("`@("`@("`O+R!C:&5C:R!W:&%T('1H
M92!C;&EE;G0@86-C97!T<PH@("`@("`@(&EF("AF86QS92`A/3T@<W1R<&]S
M*"1S97)V97);)TA45%!?04-#15!47T5.0T]$24Y')UTL("=X+6=Z:7`G*2D*
M("`@("`@("`@("`@<F5T=7)N("=X+6=Z:7`G.PH@("`@("`@(&EF("AF86QS
M92`A/3T@<W1R<&]S*"1S97)V97);)TA45%!?04-#15!47T5.0T]$24Y')UTL
M("=G>FEP)RDI"B`@("`@("`@("`@(')E='5R;B`G9WII<"<["B`@("`@("`@
M("`@(`H@("`@("`@("\O(&YO(&-O;7!R97-S:6]N"B`@("`@("`@<F5T=7)N
M("<G.PH@("`@("`@(`H@("`@?2`O+R!E;F0@9G5N8R!G971%;F-O9&EN9PH*
M("`@("\O('M[>R!?:6UP;W)T1VQO8F%L5F%R:6%B;&4H*0H*("`@("\J*@H@
M("`@("H@26UP;W)T('9A<FEA8FQE<R!F<F]M('-P96-I86P@;F%M97-P86-E
M<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!P87)A
M;2!S=')I;F<@5'EP92!O9B!V87)I86)L92`H<V5R=F5R+"!S97-S:6]N+"!P
M;W-T*0H@("`@("H@0')E='5R;B!A<G)A>0H@("`@("HO"B`@("!F=6YC=&EO
M;B`F7VEM<&]R=$=L;V)A;%9A<FEA8FQE*"1V87)I86)L92D@"B`@("!["B`@
M("`@(`H@("`@("`@("1V87(@/2!N=6QL.PH*("`@("`@("!S=VET8V@@*'-T
M<G1O;&]W97(H)'9A<FEA8FQE*2D@>PH*("`@("`@("`@("`@8V%S92`B<V5R
M=F5R(B`Z"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)%]315)615(I*2![
M"B`@("`@("`@("`@("`@("`@("`@)'9A<B`]("8D7U-%4E9%4CL*("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'9A<B`]
M("8D1TQ/0D%,4ULG2%144%]315)615)?5D%24R==.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E
M(")S97-S:6]N(B`Z"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)%]315-3
M24].*2D@>PH@("`@("`@("`@("`@("`@("`@("1V87(@/2`F)%]315-324].
M.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`D=F%R(#T@)B1'3$]"04Q36R=(5%107U-%4U-)3TY?5D%24R==.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("!C87-E(")P;W-T(B`Z"B`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)%]03U-4*2D@>PH@("`@("`@("`@("`@("`@("`@("1V87(@/2`F)%]03U-4
M.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`D=F%R(#T@)B1'3$]"04Q36R=(5%107U!/4U1?5D%24R==.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("!D969A=6QT.@H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1V87(["B`@("!](`H*("`@("\O('U]"GT@+R\@
M96YD(&-L87-S($]U='!U=$-O;7!R97-S:6]N"C\^"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]#
M86-H92]#;VYT86EN97(N<&AP````````````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#,R,S<T(#$P-3$U-#,S-S,P(#`R,C$S,@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!014%2(#HZ($-A8VAE("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T
M('1O('9E<G-I;VX@,BXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`HO
M+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@
M9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@
M870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!0
M2%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@
M:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@
M;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E
M(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H
M;W)S.B!5;&8@5V5N9&5L(#QU;&8N=V5N9&5L0'!H<&1O8RYD93X@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@4V5B87-T:6%N
M($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^("`@("`@("`@
M("`@("`@?`HO+R!\("`@("`@("`@($-H<FES=&EA;B!3=&]C:V5R(#QC:')E
M9W5`<&AA;G0N8V@^("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@0V]N=&%I;F5R
M+G!H<"QV(#$N-"`R,#`S+S`Q+S`T(#$Q.C4T.C0U(&UJ($5X<"`D"@IR97%U
M:7)E7V]N8V4@)T-A8VAE+T5R<F]R+G!H<"<["@HO*BH**B!#;VUM;VX@8F%S
M92!C;&%S<R!O9B!A;&P@8V%C:&4@<W1O<F%G92!C;VYT86EN97(N"BH@"BH@
M5&\@<W!E960@=7`@=&AI;F=S('=E(&1O(&$@<')E;&]A9"!Y;W4@<VAO=6QD
M(&MN;W<@86)O=70L(&]T:&5R=VES92!I="!M:6=H="`**B!P;&%Y('EO=2!A
M('1R:6-K+B!4:&4@0V%C:&4@8V]N=')O;&QE<B!C;&%S<V5S("A#86-H92]#
M86-H92P@0V%C:&4O3W5T<'5T+"`N+BXI"BH@=7-U86QL>2!D;R!S;VUE=&AI
M;F<@;&EK92!I<R`H:7-#86-H960H)&ED*2`F)B`A:7-%>'!I<F5D*"1I9"DI
M(')E='5R;B`D8V]N=&%I;F5R+3YL;V%D*"1I9"DN"BH@:68@>6]U(&EM<&QE
M;65N="!I<T-A8VAE9"@I+"!I<T5X<&ER960H*2!A;F0@;&]A9"@I('-T<F%I
M9VAT(&%H96%D+"!E86-H(&]F('1H:7,@"BH@9G5N8W1I;VYS('=I;&P@<F5S
M=6QT(&EN(&$@<W1O<F%G92!M961I=6T@*&1B+"!F:6QE+"XN+BD@86-C97-S
M+B!4:&ES(&=E;F5R871E<R!T;V\@;75C:"!L;V%D+B`**B!.;W<L(&$@<VEM
M<&QE('-P96-U;&%T:79E('!R96QO860@<VAO=6QD('-A=F5S('1I;64@:6X@
M;6]S="!C87-E<RX@5VAE;F5V97(@"BH@;VYE(&]F('1H92!M96YT:6]N960@
M;65T:&]D<R!I<R!I;G9O:V5D('=E('!R96QO860@=&AE(&-A8VAE9"!D871A
M<V5T(&EN=&\@8VQA<W,@=F%R:6%B;&5S+@HJ(%1H870@;65A;G,@=&AA="!W
M92!H879E(&]N;'D@;VYE('-T;W)A9V4@;65D:75M(&%C8V5S<R!F;W(@=&AE
M('-E<75E;F-E"BH@("AI<T-A8VAE9"@D:60I("8F("%I<T5X<&ER960H)&ED
M*2D@<F5T=7)N("1C;VYT86EN97(M/FQO860H)&ED*2X**B!4:&4@8F%D('1H
M:6YG(&ES('1H870@=&AE('!R96QO861E9"!D871A(&UI9VAT(&)E(&]U=&1A
M=&5D(&UE86YW:&EL92P@=VAI8V@@:7,@"BH@=6YL:6ME;'D@8G5T(&9O<B!Y
M;W4@<&]W97(@=7-E<G,L(&)E('=A<FYE9"X@268@>6]U(&1O(&YO="!W86YT
M('1H92!P<F5L;V%D(`HJ('EO=2!S:&]U;&0@<W=I=&-H(&ET(&]F9B!B>2!S
M971T:6YG('1H92!C;&%S<R!V87)I86)L92`D<')E;&]A9"!T;R!F86QS92X@
M06YY=V%Y+"!T:&ES(&ES(`HJ(&YO="!R96-O;6UE;F1E9"$**B`**B!`875T
M:&]R("`@56QF(%=E;F1E;"`\=6QF+G=E;F1E;$!P:'!D;V,N9&4^"BH@0'9E
M<G-I;VX@("1)9#H@0V]N=&%I;F5R+G!H<"QV(#$N-"`R,#`S+S`Q+S`T(#$Q
M.C4T.C0U(&UJ($5X<"`D"BH@0'!A8VMA9V4@($-A8VAE"BH@0&%C8V5S<R`@
M('!U8FQI8PHJ($!A8G-T<F%C=`HJ+PIC;&%S<R!#86-H95]#;VYT86EN97(@
M>PH*("`@("\J*@H@("`@*B!&;&%G(&EN9&EC871I;F<@=VAE=&5R('1O('!R
M96QO860@9&%T87-E=',N"B`@("`J"B`@("`J(%-E92!T:&4@8VQA<W,@9&5S
M8W)I<'1I;VX@9F]R(&UO<F4@9&5T86EL<RX*("`@("H*("`@("H@0'9A<B`@
M8F]O;&5A;@H@("`@*B\*("`@('9A<B`D<')E;&]A9"`]('1R=64["@H@("`@
M+RHJ"B`@("`J($E$(&]F(&$@<')E;&]A9&5D(&1A=&%S970*("`@("H*("`@
M("H@0'9A<B`@<W1R:6YG"B`@("`J+PH@("`@=F%R("1I9"`]("<G.PH*("`@
M("\J*@H@("`@*B!#86-H92!G<F]U<"!O9B!A('!R96QO861E9"!D871A<V5T
M"B`@("`J"B`@("`J($!V87(@('-T<FEN9PH@("`@*B\*("`@('9A<B`D9W)O
M=7`@/2`G)SL*"B`@("`O*BH*("`@("H@17AP:7)A=&EO;B!T:6UE<W1A;7`@
M;V8@82!P<F5L;V%D960@9&%T87-E="X*("`@("H@"B`@("`J($!V87(@(&EN
M=&5G97(@,"!M96%N<R!N979E<BP@96YD;&5S<PH@("`@*B\*("`@('9A<B`D
M97AP:7)E<R`](#`["@H@("`@+RHJ"B`@("`J(%9A;'5E(&]F(&$@<')E;&]A
M9&5D(&1A=&%S970N"B`@("`J(`H@("`@*B!`=F%R("!S=')I;F<*("`@("HO
M"B`@("!V87(@)&-A8VAE9&%T82`]("<G.PH*("`@("\J*@H@("`@*B!0<F5L
M;V%D960@=7-E<F1A=&$@9FEE;&0N"B`@("`J(`H@("`@*B!`=F%R("!S=')I
M;F<*("`@("HO"B`@("!V87(@)'5S97)D871A(#T@)R<["@H@("`@+RHJ"B`@
M("`J($9L86<@:6YD:6-A=&EN9R!T:&%T('1H92!D871A<V5T(')E<75E<W1E
M9"!F;W(@<')E;&]A9&EN9R!I<R!U;FMN;W=N+@H@("`@*B`@"B`@("`J($!V
M87(@(&)O;VQE86X*("`@("HO"B`@("!V87(@)'5N:VYO=VX@/2!T<G5E.PH*
M("`@("\J*@H@("`@*B!%;F-O9&EN9R!M;V1E(&9O<B!C86-H92!D871A.B!B
M87-E-C0@;W(@861D<VQA<VAE<R@I("AS;&%S:"DN"B`@("`J"B`@("`J($!V
M87(@('-T<FEN9R`@8F%S938T(&]R('-L87-H"B`@("`J+PH@("`@=F%R("1E
M;F-O9&EN9U]M;V1E(#T@)V)A<V4V-"<["B`@("`*("`@("\J*@H@("`@*B!(
M:6=H=V%T97(@;6%R:R`M(&UA>&EM=6T@<W!A8V4@<F5Q=6ER960@8GD@86QL
M(&-A8VAE(&5N=')I97,N"B`@("`J(`H@("`@*B!7:&5N979E<B!T:&4@9V%R
M8F%G92!C;VQL96-T:6]N(')U;G,@:70@8VAE8VMS('1H92!A;6]U;G0@;V8@
M<W!A8V4*("`@("H@<F5Q=6ER960@8GD@86QL(&-A8VAE(&5N=')I97,N($EF
M(&ET)W,@;6]R92!T:&%N(&X@*&AI9VAW871E<BD@8GET97,*("`@("H@=&AE
M(&=A<F)A9V4@8V]L;&5C=&EO;B!D96QE=&5S(&%S(&UA;GD@96YT<FEE<R!A
M<R!N96-E<W-A<GD@=&\@<F5A8V@@=&AE"B`@("`J(&QO=W=A=&5R(&UA<FLN
M(`H@("`@*B`*("`@("H@0'9A<B`@:6YT"B`@("`J($!S964@(&QO=W=A=&5R
M"B`@("`J+PH@("`@=F%R("1H:6=H=V%T97(@/2`R,#0X,#`P.R`*("`@(`H@
M("`@"B`@("`O*BH*("`@("H@3&]W=V%T97(@;6%R:PH@("`@*@H@("`@*B!`
M=F%R("!I;G0*("`@("H@0'-E92`@:&EG:'=A=&5R"B`@("`J+PH@("`@=F%R
M("1L;W=W871E<B`](#$U,S8P,#`["B`@("`*("`@(`H@("`@+RHJ"B`@("`J
M($]P=&EO;G,@=&AA="!C86X@8F4@<V5T(&EN(&5V97)Y(&1E<FEV960@8VQA
M<W,@=7-I;F<@:70G<R!C;VYS=')U8W1O<BX*("`@("H@"B`@("`J($!V87(@
M(&%R<F%Y"B`@("`J+PH@("`@=F%R("1A;&QO=V5D7V]P=&EO;G,@/2!A<G)A
M>2@G96YC;V1I;F=?;6]D92<L("=H:6=H=V%T97(G+"`G;&]W=V%T97(G*3L*
M("`@(`H@("`@"B`@("`O*BH*("`@("H@3&]A9',@82!D871A<V5T(&9R;VT@
M=&AE(&-A8VAE+@H@("`@*B`*("`@("H@0'!A<F%M("`@('-T<FEN9R`@9&%T
M87-E="!)1`H@("`@*B!`<&%R86T@("`@<W1R:6YG("!C86-H92!G<F]U<`H@
M("`@*B!`<F5T=7)N("`@;6EX960@("!D871A<V5T('9A;'5E(&]R($Y53$P@
M;VX@9F%I;'5R90H@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J+PH@("`@
M9G5N8W1I;VX@;&]A9"@D:60L("1G<F]U<"D@>PH@("`@("`@(&EF("@D=&AI
M<RT^<')E;&]A9"D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/FED("$]("1I
M9"!\?"`D=&AI<RT^9W)O=7`@(3T@)&=R;W5P*0H@("`@("`@("`@("`@("`@
M)'1H:7,M/G!R96QO860H)&ED+"`D9W)O=7`I.PH*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YC86-H961A=&$["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@;&ES="@@+"`D9&%T82P@*2`]("1T:&ES+3YF971C:"@D:60L("1G
M<F]U<"D["B`@("`@("`@("`@(')E='5R;B`D9&%T83L*("`@("`@("!]"B`@
M("!]("\O(&5N9"!F=6YC(&QO860*"B`@("`O*BH*("`@("H@4F5T=7)N<R!T
M:&4@=7-E<F1A=&$@9FEE;&0@;V8@82!C86-H960@9&%T82!S970N"B`@("`J
M"B`@("`J($!P87)A;2`@("!S=')I;F<@(&1A=&%S970@240*("`@("H@0'!A
M<F%M("`@('-T<FEN9R`@8V%C:&4@9W)O=7`*("`@("H@0')E='5R;B`@('-T
M<FEN9R`@=7-E<F1A=&$*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=%5S97)D871A*"1I9"P@)&=R;W5P*2!["B`@("`@
M("`@:68@*"1T:&ES+3YP<F5L;V%D*2!["B`@("`@("`@("`@(&EF("@D=&AI
M<RT^:60@(3T@)&ED('Q\("1T:&ES+3YG<F]U<"`A/2`D9W)O=7`I"B`@("`@
M("`@("`@("`@("`D=&AI<RT^<')E;&]A9"@D:60L("1G<F]U<"D["B`@("`@
M("`@("`@("`@("`*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YU<V5R9&%T
M83L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!L:7-T*"`L("P@)'5S
M97)D871A*2`]("1T:&ES+3YF971C:"@D:60L("1G<F]U<"D["B`@("`@("`@
M("`@(')E='5R;B`D=7-E<F1A=&$["B`@("`@("`@?0H@("`@?2`O+R!E;F0@
M9G5N8R!G9715<V5R9&%T80H*("`@("\J*@H@("`@*B!#:&5C:W,@:68@82!D
M871A<V5T(&ES(&5X<&ER960N"B`@("`J(`H@("`@*B!`<&%R86T@("`@<W1R
M:6YG("!D871A<V5T($E$"B`@("`J($!P87)A;2`@("!S=')I;F<@(&-A8VAE
M(&=R;W5P"B`@("`J($!P87)A;2`@("!I;G1E9V5R(&UA>&EM=6T@86=E('1I
M;65S=&%M<`H@("`@*B!`<F5T=7)N("`@8F]O;&5A;B`*("`@("H@0&%C8V5S
M<R`@('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N(&ES17AP:7)E9"@D:60L
M("1G<F]U<"P@)&UA>%]A9V4I('L*("`@("`@("!I9B`H)'1H:7,M/G!R96QO
M860I('L*("`@("`@("`@(&EF("@D=&AI<RT^:60@(3T@)&ED('Q\("1T:&ES
M+3YG<F]U<"`A/2`D9W)O=7`I"B`@("`@("`@("`@("1T:&ES+3YP<F5L;V%D
M*"1I9"P@)&=R;W5P*3L*("`@("`@("`@(`H@("`@("`@("`@:68@*"1T:&ES
M+3YU;FMN;W=N*0H@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@+R\@8VAE8VL@:68@870@86QL(&ET(&ES
M(&-A8VAE9`H@("`@("`@("`@("!I9B`H(21T:&ES+3YI<T-A8VAE9"@D:60L
M("1G<F]U<"DI"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@("`@("`@("`*("`@("`@("`@("`@+R\@22=M(&QA>GDN+BX*("`@("`@
M("`@("`@;&ES="@D=&AI<RT^97AP:7)E<RP@+"`I(#T@)'1H:7,M/F9E=&-H
M*"1I9"P@)&=R;W5P*3L*("`@("`@("!]"@H@("`@("`@("\O(&5N9&QE<W,*
M("`@("`@("!I9B`H,"`]/2`D=&AI<RT^97AP:7)E<RD*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH*("`@("`@("`O+R!Y;W4@9F5E;"!F:6YE+"!5;&8_
M"B`@("`@("`@:68@*"1E>'!I<F5D("`]("@D=&AI<RT^97AP:7)E<R`\/2!T
M:6UE*"D@?'P@*"1M87A?86=E("8F("@D=&AI<RT^97AP:7)E<R`\/2`D;6%X
M7V%G92DI*2`I('L*"B`@("`@("`@("`@)'1H:7,M/G)E;6]V92@D:60L("1G
M<F]U<"D["B`@("`@("`@("`@)'1H:7,M/F9L=7-H4')E;&]A9"@I.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@)&5X<&ER960["B`@("!]("\O(&5N9"!F
M=6YC(&ES17AP:7)E9`H*("`@("\J*@H@("`@*B!#:&5C:W,@:68@82!D871A
M<V5T(&ES(&-A8VAE9"X*("`@("H*("`@("H@0'!A<F%M("`@('-T<FEN9R`@
M9&%T87-E="!)1`H@("`@*B!`<&%R86T@("`@<W1R:6YG("!C86-H92!G<F]U
M<`H@("`@*B!`<F5T=7)N("`@8F]O;&5A;@H@("`@*B\*("`@(&9U;F-T:6]N
M(&ES0V%C:&5D*"1I9"P@)&=R;W5P*2!["B`@("`@("`@:68@*"1T:&ES+3YP
M<F5L;V%D*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^:60@(3T@)&ED('Q\
M("1T:&ES+3YG<F]U<"`A/2`D9W)O=7`I"B`@("`@("`@("`@("`@("`D=&AI
M<RT^<')E;&]A9"@D:60L("1G<F]U<"D["@H@("`@("`@("`@("!R971U<FX@
M(2@D=&AI<RT^=6YK;F]W;BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YI9$5X:7-T<R@D:60L("1G<F]U<"D["B`@("`@
M("`@?0H@("`@?2`O+R!E;F0@9G5N8R!I<T-A8VAE9`H*("`@("\O"B`@("`O
M+R!A8G-T<F%C="!M971H;V1S"B`@("`O+PH*("`@("\J*@H@("`@*B!&971C
M:&5S(&$@9&%T87-E="!F<F]M('1H92!S=&]R86=E(&UE9&EU;2X*("`@("H*
M("`@("H@0'!A<F%M("`@('-T<FEN9R`@9&%T87-E="!)1`H@("`@*B!`<&%R
M86T@("`@<W1R:6YG("!C86-H92!G<F]U<`H@("`@*B!`<F5T=7)N("`@87)R
M87D@("!F;W)M870Z(%ME>'!I<F4@9&%T92P@8V%C:&5D(&1A=&$L('5S97(@
M9&%T85T*("`@("H@0'1H<F]W<R`@($-A8VAE7T5R<F]R"B`@("`J($!A8G-T
M<F%C=`H@("`@*B\*("`@(&9U;F-T:6]N(&9E=&-H*"1I9"P@)&=R;W5P*2![
M"B`@("`@("`@<F5T=7)N(&%R<F%Y*$Y53$PL($Y53$PL($Y53$PI.PH@("`@
M?2`O+R!E;F0@9G5N8R!F971C:`H*("`@("\J*@H@("`@*B!3=&]R97,@82!D
M871A<V5T+@H@("`@*B`*("`@("H@0'!A<F%M("`@('-T<FEN9R`@9&%T87-E
M="!)1`H@("`@*B!`<&%R86T@("`@;6EX960@("!D871A('1O('-T;W)E"B`@
M("`J($!P87)A;2`@("!M:7AE9"`@('5S97)D969I;F5D(&5X<&ER92!D871E
M"B`@("`J($!P87)A;2`@("!S=')I;F<@(&-A8VAE(&=R;W5P"B`@("`J($!P
M87)A;2`@("!S=')I;F<@(&%D9&ET:6]N86P@=7-E<F1E9FEN960@9&%T80H@
M("`@*B!`<F5T=7)N("`@8F]O;&5A;@H@("`@*B!`=&AR;W=S("`@0V%C:&5?
M17)R;W(*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B!`86)S=')A8W0*
M("`@("HO"B`@("!F=6YC=&EO;B!S879E*"1I9"P@)&1A=&$L("1E>'!I<F4L
M("1G<F]U<"P@)'5S97)D871A*2!["B`@("`@("`@+R\@455%4U1)3TXZ(%-H
M;W5L9"!W92!U<&1A=&4@=&AE('!R96QO860@8G5F9F5R(&EN<W1E860_"B`@
M("`@("`@+R\@1&]N)W0@=&AI;FL@<V\@87,@=&AE('-E<75E;F-E('-A=F4H
M*2]L;V%D*"D@:7,@=6YL:6ME;'DN"B`@("`@("`@)'1H:7,M/F9L=7-H4')E
M;&]A9"@D:60L("1G<F]U<"D["@H@("`@("`@(')E='5R;B!.54Q,.PH@("`@
M?2`O+R!E;F0@9G5N8R!S879E"@H@("`@+RHJ"B`@("`J(%)E;6]V97,@82!D
M871A<V5T+@H@("`@*B`*("`@("H@0'!A<F%M("`@('-T<FEN9R`@9&%T87-E
M="!)1`H@("`@*B!`<&%R86T@("`@<W1R:6YG("!C86-H92!G<F]U<`H@("`@
M*B!`<F5T=7)N("`@8F]O;&5A;B`@"B`@("`J($!A8V-E<W,@("!P=6)L:6,*
M("`@("H@0&%B<W1R86-T"B`@("`J+R`@("`@"B`@("!F=6YC=&EO;B!R96UO
M=F4H)&ED+"`D9W)O=7`I('L*("`@("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D
M*"1I9"P@)&=R;W5P*3L*("`@("`@("!R971U<FX@3E5,3#L*("`@('T@+R\@
M96YD(&9U;F,@<F5M;W9E"@H@("`@+RHJ"B`@("`J($9L=7-H97,@=&AE(&-A
M8VAE("T@<F5M;W9E<R!A;&P@8V%C:&5S(&1A=&%S971S(&9R;VT@=&AE(&-A
M8VAE+@H@("`@*B`*("`@("H@0'!A<F%M("`@('-T<FEN9R`@("`@($EF(&$@
M8V%C:&4@9W)O=7`@:7,@9VEV96X@;VYL>2!T:&4@9W)O=7`@=VEL;"!B92!F
M;'5S:&5D"B`@("`J($!R971U<FX@("!I;G1E9V5R("`@("!.=6UB97(@;V8@
M<F5M;W9E9"!D871A<V5T<RP@+3$@;VX@9F%I;'5R90H@("`@*B!`86-C97-S
M("`@<'5B;&EC"B`@("`J($!A8G-T<F%C=`H@("`@*B\*("`@(&9U;F-T:6]N
M(&9L=7-H*"1G<F]U<"D@>PH@("`@("`@("1T:&ES+3YF;'5S:%!R96QO860H
M*3L*("`@("`@("!R971U<FX@3E5,3#L*("`@('T@+R\@96YD(&9U;F,@9FQU
M<V@*"B`@("`O*BH*("`@("H@0VAE8VMS(&EF(&$@9&%T87-E="!E>&ES=',N
M"B`@("`J(`H@("`@*B!`<&%R86T@("`@<W1R:6YG("!D871A<V5T($E$"B`@
M("`J($!P87)A;2`@("!S=')I;F<@(&-A8VAE(&=R;W5P"B`@("`J($!R971U
M<FX@("!B;V]L96%N(`H@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J($!A
M8G-T<F%C=`H@("`@*B\*("`@(&9U;F-T:6]N(&ED17AI<W1S*"1I9"P@)&=R
M;W5P*2!["B`@("`@("`@<F5T=7)N($Y53$P["B`@("!]("\O(&5N9"!F=6YC
M(&ED17AI<W1S"@H@("`@+RHJ"B`@("`J(%-T87)T<R!T:&4@9V%R8F%G92!C
M;VQL96-T:6]N+@H@("`@*B`*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@
M*B!`86)S=')A8W0*("`@("HO"B`@("!F=6YC=&EO;B!G87)B86=E0V]L;&5C
M=&EO;B@I('L*("`@("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D*"D["B`@("!]
M("\O(&5N9"!F=6YC(&=A<F)A9V5#;VQL96-T:6]N"@H@("`@+RHJ"B`@("`J
M($1O97,@82!S<&5C=6QA=&EV92!P<F5L;V%D(&]F(&$@9&%T87-E=`H@("`@
M*@H@("`@*B!`<&%R86T@("`@<W1R:6YG("!D871A<V5T($E$"B`@("`J($!P
M87)A;2`@("!S=')I;F<@(&-A8VAE(&=R;W5P"B`@("`J($!R971U<FX@("!B
M;V]L96%N"B`@("`J+R`*("`@(&9U;F-T:6]N('!R96QO860H)&ED+"`D9W)O
M=7`I('L*("`@("`@("`O+R!W:&%T979E<B!H87!P96YS+"!R96UE;6)E<B!T
M:&4@<')E;&]A9&5D($E$"B`@("`@("`@)'1H:7,M/FED(#T@)&ED.PH@("`@
M("`@("1T:&ES+3YG<F]U<"`]("1G<F]U<#L@("`@("`@(`H*("`@("`@("!L
M:7-T*"1T:&ES+3YE>'!I<F5S+"`D=&AI<RT^8V%C:&5D871A+"`D=&AI<RT^
M=7-E<F1A=&$I(#T@)'1H:7,M/F9E=&-H*"1I9"P@)&=R;W5P*3L*"B`@("`@
M("`@:68@*$Y53$P@/3T]("1T:&ES+3YE>'!I<F5S*2!["B`@("`@("`@("`@
M("\O(%5U=7!S+"!U;FMN;W=N($E$"B`@("`@("`@("`@("1T:&ES+3YF;'5S
M:%!R96QO860H*3L*"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"@H@("`@("`@("1T:&ES+3YU;FMN;W=N(#T@9F%L<V4["@H@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?2`O+R!E;F0@9G5N8R!P<F5L;V%D"@H@("`@
M+RHJ"B`@("`J($9L=7-H97,@=&AE(&EN=&5R;F%L('!R96QO860@8G5F9F5R
M+@H@("`@*@H@("`@*B!S879E*"DL(')E;6]V92@I(&%N9"!F;'5S:"@I(&UU
M<W0@8V%L;"!T:&ES(&UE=&AO9`H@("`@*B!T;R!P<F5E=F5N="!D:69F97)E
M;F-E<R!B971W965N('1H92!P<F5L;V%D960@=F%L=65S(&%N9"`*("`@("H@
M=&AE(')E86P@8V%C:&4@8V]N=&5N=',N"B`@("`J"B`@("`J($!P87)A;2`@
M("!S=')I;F<@(&1A=&%S970@240L(&EF(&QE9G0@;W5T('1H92!P<F5L;V%D
M960@=F%L=65S('=I;&P@8F4@9FQU<VAE9"X@"B`@("`J("`@("`@("`@("`@
M("`@("`@($EF(&=I=F5N('1H92!P<F5L;V%D960@=F%L=65S('=I;&P@;VYL
M>2!B92!F;'5S:&5D(&EF('1H97D@87)E"B`@("`J("`@("`@("`@("`@("`@
M("`@(&5Q=6%L('1O('1H92!G:79E;B!I9"!A;F0@9W)O=7`*("`@("H@0'!A
M<F%M("`@('-T<FEN9R`@8V%C:&4@9W)O=7`*("`@("H@0'-E92`@<')E;&]A
M9"@I"B`@("`J+PH@("`@9G5N8W1I;VX@9FQU<VA0<F5L;V%D*"1I9"`]("<G
M+"`D9W)O=7`@/2`G9&5F875L="<I('L*("`@("`@("!I9B`H(21I9"!\?"`H
M)'1H:7,M/FED(#T]("1I9"`F)B`D=&AI<RT^9W)O=7`@/3T@)&=R;W5P*2D@
M>PH@("`@("`@("`@("`O+R!C;&5A<B!T:&4@:6YT97)N86P@<')E;&]A9"!V
M86QU97,*("`@("`@("`@("`@)'1H:7,M/FED(#T@)R<["B`@("`@("`@("`@
M("1T:&ES+3YG<F]U<"`]("<G.PH@("`@("`@("`@("`D=&AI<RT^8V%C:&5D
M871A(#T@)R<["B`@("`@("`@("`@("1T:&ES+3YU<V5R9&%T82`]("<G.PH@
M("`@("`@("`@("`D=&AI<RT^97AP:7)E<R`]("TQ.PH@("`@("`@("`@("`D
M=&AI<RT^=6YK;F]W;B`]('1R=64["B`@("`@("`@?0H@("`@?2`O+R!E;F0@
M9G5N8R!F;'5S:%!R96QO860*"B`@("`O*BH*("`@("H@26UP;W)T<R!T:&4@
M<F5Q=65S=&5D(&1A=&%F:65L9',@87,@;V)J96-T('9A<FEA8FQE<R!I9B!A
M;&QO=V5D"B`@("`J(`H@("`@*B!`<&%R86T@("`@87)R87D@("!,:7-T(&]F
M(&9I96QD<R!T;R!B92!I;7!O<G1E9"!A<R!O8FIE8W0@=F%R:6%B;&5S"B`@
M("`J($!P87)A;2`@("!A<G)A>2`@($QI<W0@;V8@86QL;W=E9"!D871A9FEE
M;&1S"B`@("`J+PH@("`@9G5N8W1I;VX@<V5T3W!T:6]N<R@D<F5Q=65S=&5D
M+"`D86QL;W=E9"D@>PH@("`@("`@(&9O<F5A8V@@*"1A;&QO=V5D(&%S("1K
M(#T^("1F:65L9"D*("`@("`@("`@("`@:68@*&ES<V5T*"1R97%U97-T961;
M)&9I96QD72DI"B`@("`@("`@("`@("`@("`D=&AI<RT^)&9I96QD(#T@)')E
M<75E<W1E9%LD9FEE;&1=.PH@("`@("`@("`@("`@("`@"B`@("!]("\O(&5N
M9"!F=6YC('-E=$]P=&EO;G,*"B`@("`O*BH*("`@("H@16YC;V1E<R!T:&4@
M9&%T82!F;W(@=&AE('-T;W)A9V4@8V]N=&%I;F5R+@H@("`@*B`*("`@("H@
M0'9A<B`@;6EX960@9&%T82!T;R!E;F-O9&4*("`@("HO"B`@("!F=6YC=&EO
M;B!E;F-O9&4H)&1A=&$I('L*("`@("`@("!I9B`H)V)A<V4V-"<@/3T@)'1H
M:7,M/F5N8V]D:6YG7VUO9&4I(`H@("`@("`@("`@("!R971U<FX@8F%S938T
M7V5N8V]D92AS97)I86QI>F4H)&1A=&$I*3L*("`@("`@("!E;'-E(`H@("`@
M("`@("`@("!R971U<FX@<V5R:6%L:7IE*"1D871A*3L*("`@('T@+R\@96YD
M(&9U;F,@96YC;V1E"@H@("`@"B`@("`O*BH*("`@("H@1&5C;V1E<R!T:&4@
M9&%T82!F<F]M('1H92!S=&]R86=E(&-O;G1A:6YE<BX*("`@("H@"B`@("`J
M($!V87(@(&UI>&5D"B`@("`J+PH@("`@9G5N8W1I;VX@9&5C;V1E*"1D871A
M*2!["B`@("`@("`@:68@*"=B87-E-C0G(#T]("1T:&ES+3YE;F-O9&EN9U]M
M;V1E*0H@("`@("`@("`@("!R971U<FX@=6YS97)I86QI>F4H8F%S938T7V1E
M8V]D92@D9&%T82DI.PH@("`@("`@(&5L<V4*("`@("`@("`@("`@<F5T=7)N
M('5N<V5R:6%L:7IE*"1D871A*3L*("`@('T@+R\@96YD(&9U;F,@9&5C;V1E
M"@H@("`@"B`@("`O*BH*("`@("H@5')A;G-L871E<R!H=6UA;B!R96%D86)L
M92]R96QA=&EV92!T:6UE<R!I;B!U;FEX=&EM90H@("`@*@H@("`@*B!`<&%R
M86T@(&UI>&5D("`@8V%N(&)E(&EN('1H92!F;VQL;W=I;F<@9F]R;6%T<SH*
M("`@("H@("`@("`@("`@("`@("!H=6UA;B!R96%D86)L92`@("`@("`@("`Z
M('EY>7EM;61D:&AM;5MS<UU=(&5G.B`R,#`Q,#,P.#`Y-3$P,`H@("`@*B`@
M("`@("`@("`@("`@(')E;&%T:79E(&EN('-E8V]N9',@*#$I(#H@*WAX("`@
M("`@("`@("`@("!E9SH@*S$P"B`@("`J("`@("`@("`@("`@("`@<F5L871I
M=F4@:6X@<V5C;VYD<R`H,BD@.B!X(#P@(#DT-C8X,3(P,"`@(&5G.B`Q,`H@
M("`@*B`@("`@("`@("`@("`@(&%B<V]L=71E('5N:7AT:6UE("`@("`@(#H@
M>"`\(#(Q-#<T.#,V-#@@("!E9SH@,C$T-S0X,S8T.`H@("`@*B`@("`@("`@
M("`@("`@('-E92!C;VUM96YT<R!I;B!C;V1E(&9O<B!D971A:6QS"B`@("`J
M($!R971U<FX@:6YT96=E<B!U;FEX('1I;65S=&%M<`H@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=$5X<&ER97-!8G-O;'5T92@D97AP:7)E<RD*("`@('L*("`@
M("`@("!I9B`H(21E>'!I<F5S*0H@("`@("`@("`@("!R971U<FX@,#L*("`@
M("`@("`O+V9O<B!A<&DM8V]M<&%T:6)I;&ET>2P@;VYE(&AA<R!N;W0@=&\@
M<')O=FED92!A("(K(BP*("`@("`@("`O+R!I9B!I;G1E9V5R(&ES(#P@.30V
M-C@Q,C`P("@]($IA;B`P,2`R,#`P(#`P.C`P.C`P*0H@("`@("`@(&EF("@G
M*R<@/3T@)&5X<&ER97-;,%T@?'P@)&5X<&ER97,@/"`Y-#8V.#$R,#`I"B`@
M("`@("`@>PH@("`@("`@("`@("!R971U<FXH=&EM92@I("L@)&5X<&ER97,I
M.PH@("`@("`@('T*("`@("`@("`O+VEF(&EN=&5G97(@:7,@/"`Q,#`P,#`P
M,#`P,#`@*#T@:6X@,S$T,"!Y96%R<RDL"B`@("`@("`@+R\@:70@;75S="!B
M92!A;B!A8G-O;'5T('5N:7AT:6UE"B`@("`@("`@+R\@*'-I;F-E('1H92`B
M:'5M86X@<F5A9&%B;&4B(&1E9FEN:71I;VX@87-K<R!F;W(@82!H:6=H97(@
M;G5M8F5R*0H@("`@("`@(&5L<V5I9B`H)&5X<&ER97,@/"`Q,#`P,#`P,#`P
M,#`I"B`@("`@("`@>PH@("`@("`@("`@("!R971U<FX@)&5X<&ER97,["B`@
M("`@("`@?0H@("`@("`@("\O(&5L<V4@:70G<R`B:'5M86X@<F5A9&%B;&4B
M.PH@("`@("`@(&5L<V4*("`@("`@("!["B`@("`@("`@("`@("1Y96%R(#T@
M<W5B<W1R*"1E>'!I<F5S+"`P+"`T*3L*("`@("`@("`@("`@)&UO;G1H(#T@
M<W5B<W1R*"1E>'!I<F5S+"`T+"`R*3L*("`@("`@("`@("`@)&1A>2`]('-U
M8G-T<B@D97AP:7)E<RP@-BP@,BD["B`@("`@("`@("`@("1H;W5R(#T@<W5B
M<W1R*"1E>'!I<F5S+"`X+"`R*3L*("`@("`@("`@("`@)&UI;G5T92`]('-U
M8G-T<B@D97AP:7)E<RP@,3`L(#(I.PH@("`@("`@("`@("`D<V5C;VYD(#T@
M<W5B<W1R*"1E>'!I<F5S+"`Q,BP@,BD["B`@("`@("`@("`@(')E='5R;B!M
M:W1I;64H)&AO=7(L("1M:6YU=&4L("1S96-O;F0L("1M;VYT:"P@)&1A>2P@
M)'EE87(I.PH@("`@("`@('T*("`@("`@("`*("`@('T@+R\@96YD(&9U;F,@
M9V5T17AP:7)E06)S;VQU=&4*("`@(`I]("\O(&5N9"!C;&%S<R!#;VYT86EN
M97(*/SX*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T-A8VAE+T%P<&QI8V%T:6]N+G!H
M<```````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3,P-3(@,3`U
M,34T,S,W,S`@,#(R-#0S`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\(%!%05(@.CH@0V%C:&4@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q
M.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R
M(&]F('1H92!02%`@;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B=6YD
M;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N
M9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I
M9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A
M<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@
M('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@
M8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%)I8VAA<F0@2&5Y
M97,@/')I8VAA<F1`<&AP9W5R=2YO<F<^("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)
M9#H@07!P;&EC871I;VXN<&AP+'8@,2XU(#(P,#,O,#$O,#0@,3$Z-30Z-#4@
M;6H@17AP("0*"G)E<75I<F5?;VYC92`G0V%C:&4N<&AP)SL*"B\O($%P<&QI
M8V%T:6]N(&QE=F5L('9A<FEA8FQE<PHO+PHO+R!0=7)P;W-E"B\O(%9A<FEA
M8FQE<R!T:&%T(&%R92!P97)S:7-E;G0@86-R;W-S(&%L;"!U<V5R('-E<W-I
M;VYS+`HO+R!N;W0@:G5S="!A('-P96-I9FEC('5S97(@86QA(&YO<FUA;"!S
M97-S:6]N<RX*+R\*+R\@57-A9V4Z"B\O"B\O($5X86UP;&4@,3H*+R\*+R\@
M)&%P<"`@/28@;F5W($-A8VAE7T%P<&QI8V%T:6]N*"D["B\O("1?05!0(#TF
M("1A<'`M/F=E=$1A=&$H*3L*+R\*+R\@26X@=&AI<R!C87-E('1H92`D7T%0
M4"!V87)I86)L92!I<R!A:VEN('1O('1H92`D7U-%4U-)3TX@=F%R:6%B;&4N
M"B\O($EF('EO=2!A9&0O<F5M;W9E('-T=69F+"!I="!W:6QL(&)E(')E9FQE
M8W1E9"!I;B!T:&4@;F5X="!R97%U97-T"B\O("AO9B!A;GD@=7-E<BDN"B\O
M"B\O($5X86UP;&4@,CH*+R\*+R\@)&9O;R`]("=3;VUE(&1A=&$G.PHO+R`D
M8F%R(#T@)U-O;64@;W1H97(@9&%T82<["B\O"B\O("1A<'`@/28@;F5W($-A
M8VAE7T%P<&QI8V%T:6]N*"D["B\O("1A<'`M/G)E9VES=&5R*"=F;V\G*3L*
M+R\@)&%P<"T^<F5G:7-T97(H)V)A<B<L("1B87(I.R`*+R\*+R\@)&9O;R`]
M("=$:69F97)E;G0@9&%T82<["B\O"B\O($EN('1H:7,@8V%S92!T:&4@=F%R
M:6%B;&5S(&%R92!R96=I<W1E<F5D('=I=&@@=&AE(')E9VES=&5R*"D@9G5N
M8W1I;VXN"B\O(%1H:7,@:7,@86MI;B!T;R!S97-S:6]N7W)E9VES=&5R*"DN
M"B\O"B\O($%S('=I=&@@<V5S<VEO;E]R96=I<W1E<B@I+"!T:&4@8V]N=&5N
M=',@;V8@=&AE('9A<FEA8FQE(&%T('1H92`J96YD*B!O9B!T:&4*+R\@<F5Q
M=65S="!I<R!R96=I<W1E<F5D(&%N9"!N;W0@870@=&AE('!O:6YT(&]F(')E
M9VES=')A=&EO;BX@5&AE<F5F;W)E(&EN('1H:7,*+R\@97AA;7!L92P@9F]R
M('1H92`D9F]O('9A<FEA8FQE+"!T:&4@<W1R:6YG("=$:69F97)E;G0@9&%T
M82<@:7,@<W1O<F5D(&%N9"!N;W0@"B\O("=3;VUE(&1A=&$G+B!4:&4@97AC
M97!T:6]N('1O('1H:7,@<G5L92!I<R!I9B!Y;W4@=7-E('1H92!S96-O;F0@
M87)G=6UE;G0@=&\*+R\@<F5G:7-T97(H*2!A<R!I;B!T:&4@<V5C;VYD(&-A
M;&P@=&\@:70@86)O=F4N(%1H:7,@=VEL;"!C875S92!T:&4@9&%T82!S=7!P
M;&EE9`HO+R!I;B!T:&4@<V5C;VYD(&%R9W5M96YT('1O(&)E('-T;W)E9"!A
M;F0@;F]T('1H92!C;VYT96YT<R!A="!T:&4@96YD(&]F('1H92!R97%U97-T
M+@HO+PHO+R!.;W1E.B!)9B!Y;W4@=7-E('1H:7,@;65T:&]D('=I=&@@<F5G
M:7-T97)?9VQO8F%L<R!T=7)N960@;VXL('1H92!V87)I86)L97,@=VEL;"!B
M90HO+R`@("`@("!A=71O;6%T:6-A;&QY(&=L;V)A;&QE9"!U<&]N('-T87)T
M=7`L("AI92X@=VAE;B!Y;W4@8W)E871E('1H92!O8FIE8W0I+@HO+PHO+R!.
M;W1E.B!)9B!Y;W4@<F5G:7-T97(@82!V87)I86)L92!T:&%T(&ES(&YO="!S
M970@=VAE;B!T:&4@<V-R:7!T(&9I;FES:&5S+"!I="!W:6QL"B\O("`@("`@
M(')E9VES=&5R960@87,@3E5,3"X*+R\*+R\*+R\@*BHJ(%EO=2!A<F4@<W1R
M;VYG;'D@<F5C;VUM96YD960@=&\@=7-E(&]N;'D@;VYE(&UE=&AO9"!O9B!T
M:&4@='=O(&%B;W9E+B`J*BH*+R\*+R\@*$EN(&9A8W0@:68@>6]U('5S92!T
M:&4@<F5G:7-T97(H*2!F=6YC=&EO;B!W:71H(')E9VES=&5R7V=L;V)A;',@
M3V9F+"!Y;W4@:&%V92!T;PHO+R`@=7-E('1H92`D7T%04"!M971H;V0@=&\@
M9V5T(&%T('1H92!D871A*2X*"F-L87-S($-A8VAE7T%P<&QI8V%T:6]N(&5X
M=&5N9',@0V%C:&4@>PH*("`@('9A<B`D9&%T83L*("`@('9A<B`D:60["B`@
M("!V87(@)&=R;W5P.PH@("`@=F%R("1R96=I<W1E<F5D7W9A<G,["@H@("`@
M+RHJ"B`@("`J($-O;G-T<G5C=&]R"B`@("`J"B`@("`J($!P87)A;2`@("!S
M=')I;F<@($YA;64@;V8@8V]N=&%I;F5R(&-L87-S"B`@("`J($!P87)A;2`@
M("!A<G)A>2`@($%R<F%Y('=I=&@@8V]N=&%I;F5R(&-L87-S(&]P=&EO;G,*
M("`@("HO"B`@("!F=6YC=&EO;B!#86-H95]!<'!L:6-A=&EO;B@D8V]N=&%I
M;F5R(#T@)V9I;&4G+"`D8V]N=&%I;F5R7V]P=&EO;G,@/2!A<G)A>2@G8V%C
M:&5?9&ER)R`]/B`G+W1M<"\G+"`G9FEL96YA;65?<')E9FEX)R`]/B`G8V%C
M:&5?)RDL("1I9"`]("=A<'!L:6-A=&EO;E]V87(G+"`D9W)O=7`@/2`G87!P
M;&EC871I;VY?8V%C:&4G*0H@("`@>PH@("`@("`@("1T:&ES+3YI9"`@("`]
M("1I9#L*("`@("`@("`D=&AI<RT^9W)O=7`@/2`D9W)O=7`["B`@("`@("`@
M)'1H:7,M/G)E9VES=&5R961?=F%R<R`](&%R<F%Y*"D["@H@("`@("`@("1T
M:&ES+3Y#86-H92@D8V]N=&%I;F5R+"`D8V]N=&%I;F5R7V]P=&EO;G,I.PH@
M("`@("`@("1T:&ES+3YD871A(#T@)'1H:7,M/FES0V%C:&5D*"1T:&ES+3YI
M9"P@)'1H:7,M/F=R;W5P*2`_('5N<V5R:6%L:7IE*"1T:&ES+3YG970H)'1H
M:7,M/FED+"`D=&AI<RT^9W)O=7`I*2`Z(&%R<F%Y*"D["@H@("`@("`@("\O
M($EF(')E9VES=&5R7V=L;V)A;',@;VXL(&=L;V)A;"!A;&P@<F5G:7-T97)E
M9"!V87)I86)L97,*("`@("`@("!I9B`H:6YI7V=E="@G<F5G:7-T97)?9VQO
M8F%L<R<I($%.1"!I<U]A<G)A>2@D=&AI<RT^9&%T82DI('L*("`@("`@("`@
M("`@9F]R96%C:"`H)'1H:7,M/F1A=&$@87,@)&ME>2`]/B`D=F%L=64I('L*
M("`@("`@("`@("`@("`@(&=L;V)A;"`D)&ME>3L*("`@("`@("`@("`@("`@
M("0D:V5Y(#T@)'9A;'5E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@*B!$97-T<G5C=&]R"B`@("`J"B`@("`J($=E=',@
M=F%L=65S(&]F(&%L;"!R96=I<W1E<F5D('9A<FEA8FQE<R!A;F0@<W1O<F5S
M('1H96TN(%1H96X@8V%L;',@<V%V92@I('1O"B`@("`J('=R:71E(&1A=&$@
M87=A>2X*("`@("HO"B`@("!F=6YC=&EO;B!?0V%C:&5?07!P;&EC871I;VXH
M*0H@("`@>PH@("`@("`@("\O($=E="!C;VYT96YT<R!O9B!A;&P@<F5G:7-T
M97)E9"!V87)I86)L97,*("`@("`@("!I9B`H:7-?87)R87DH)'1H:7,M/G)E
M9VES=&5R961?=F%R<RD@04Y$("%E;7!T>2@D=&AI<RT^<F5G:7-T97)E9%]V
M87)S*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^<F5G:7-T97)E
M9%]V87)S(&%S("1V87)N86UE*2!["B`@("`@("`@("`@("`@("!G;&]B86P@
M)"1V87)N86UE.PH@("`@("`@("`@("`@("`@)'1H:7,M/F1A=&%;)'9A<FYA
M;65=(#T@)"1V87)N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("`O+R!3879E('1H92!D871A"B`@("`@("`@)'1H:7,M/G-A=F4H)'1H
M:7,M/FED+"!S97)I86QI>F4H)'1H:7,M/F1A=&$I+"`P+"`D=&AI<RT^9W)O
M=7`I.PH@("`@?0H*("`@("\J*@H@("`@*B!R96=I<W1E<B@I"B`@("`J"B`@
M("`J(%)E9VES=&5R<R!A('9A<FEA8FQE('1O(&)E('-T;W)E9"X*("`@("H*
M("`@("H@0'!A<F%M("`@('-T<FEN9R`@3F%M92!O9B!V87)I86)L92!T;R!R
M96=I<W1E<@H@("`@*B!`<&%R86T@("`@;6EX960@("!/<'1I;VYA;"!D871A
M('1O('-T;W)E"B`@("`J+PH@("`@9G5N8W1I;VX@<F5G:7-T97(H)'9A<FYA
M;64L("1D871A(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-S970H)&1A
M=&$I*2!["B`@("`@("`@("`@("1T:&ES+3YD871A6R1V87)N86UE72`]("1D
M871A.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YR96=I
M<W1E<F5D7W9A<G-;72`]("1V87)N86UE.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("H@=6YR96=I<W1E<B@I"B`@("`J"B`@("`J(%5N<F5G:7-T
M97)S(&$@=F%R:6%B;&4@9G)O;2!B96EN9R!S=&]R960N"B`@("`J"B`@("`J
M($!P87)A;2`@("!S=')I;F<@($YA;64@;V8@=F%R:6%B;&4@=&\@=6YR96=I
M<W1E<@H@("`@*B\*("`@(&9U;F-T:6]N('5N<F5G:7-T97(H)'9A<FYA;64I
M"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YD871A6R1V87)N86UE
M72DI('L*("`@("`@("`@("`@=6YS970H)'1H:7,M/F1A=&%;)'9A<FYA;65=
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`J(&-L96%R*"D*("`@
M("H*("`@("H@4F5M;W9E<R!A;&P@<W1O<F5D(&1A=&$*("`@("HO"B`@("!F
M=6YC=&EO;B!C;&5A<B@I"B`@("!["B`@("`@("`@)'1H:7,M/F1A=&$@/2!A
M<G)A>2@I.PH@("`@?0H*("`@("\J*@H@("`@*B!G971$871A*"D*("`@("H*
M("`@("H@57-E('1H:7,@=&\@9V5T(&$@<F5F97)E;F-E('1O('1H92!D871A
M('1O(&UA;FEP=6QA=&4*("`@("H@:6X@8V%L;&EN9R!S8W)I<'0N($5G+B`D
M7T%04"`])B`D;V)J+3YG971$871A*"D["B`@("`J"B`@("`J($!R971U<FX@
M;6EX960@("!!(')E9F5R96YC92!T;R!T:&4@9&%T80H@("`@*B\*("`@(&9U
M;F-T:6]N("9G971$871A*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/F1A=&$["B`@("!]"GT*/SX`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O0V]N<V]L90``````````````````````
M````````````````````````````````````````````````````````````
M```P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S
M,S<S,"`P,C`P,#8`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]#;VYS;VQE
M+T=E=&]P="YP:'``````````````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#(R-3`P(#$P-3$U-#,S-S,P(#`R,C`S-P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*B!V:6TZ('-E="!E
M>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-#H@*B\*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#
M;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T
M;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P*+R\@
M?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I
M;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@=7)L
M.B`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0
M(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET
M('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO
M=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C
M86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@
M('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R
M.B!!;F1R96D@6FUI979S:VD@/&%N9')E:4!P:'`N;F5T/B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\*+R\@)$ED.B!'971O<'0N<&AP+'8@,2XR,2XT+C<@,C`P,R\Q
M,B\P-2`R,3HU-SHP,2!A;F1R96D@17AP("0*"G)E<75I<F5?;VYC92`G4$5!
M4BYP:'`G.PH*+RHJ"B`J($-O;6UA;F0M;&EN92!O<'1I;VYS('!A<G-I;F<@
M8VQA<W,N"B`J"B`J($!A=71H;W(@06YD<F5I(%IM:65V<VMI(#QA;F1R96E`
M<&AP+FYE=#X*("H*("HO"F-L87-S($-O;G-O;&5?1V5T;W!T('L*("`@("\J
M*@H@("`@("H@4&%R<V5S('1H92!C;VUM86YD+6QI;F4@;W!T:6]N<RX*("`@
M("`J"B`@("`@*B!4:&4@9FER<W0@<&%R86UE=&5R('1O('1H:7,@9G5N8W1I
M;VX@<VAO=6QD(&)E('1H92!L:7-T(&]F(&-O;6UA;F0M;&EN90H@("`@("H@
M87)G=6UE;G1S('=I=&AO=70@=&AE(&QE861I;F<@<F5F97)E;F-E('1O('1H
M92!R=6YN:6YG('!R;V=R86TN"B`@("`@*@H@("`@("H@5&AE('-E8V]N9"!P
M87)A;65T97(@:7,@82!S=')I;F<@;V8@86QL;W=E9"!S:&]R="!O<'1I;VYS
M+B!%86-H(&]F('1H90H@("`@("H@;W!T:6]N(&QE='1E<G,@8V%N(&)E(&9O
M;&QO=V5D(&)Y(&$@8V]L;VX@)SHG('1O('-P96-I9GD@=&AA="!T:&4@;W!T
M:6]N"B`@("`@*B!R97%U:7)E<R!A;B!A<F=U;65N="P@;W(@82!D;W5B;&4@
M8V]L;VX@)SHZ)R!T;R!S<&5C:69Y('1H870@=&AE(&]P=&EO;@H@("`@("H@
M=&%K97,@86X@;W!T:6]N86P@87)G=6UE;G0N"B`@("`@*@H@("`@("H@5&AE
M('1H:7)D(&%R9W5M96YT(&ES(&%N(&]P=&EO;F%L(&%R<F%Y(&]F(&%L;&]W
M960@;&]N9R!O<'1I;VYS+B!4:&4*("`@("`J(&QE861I;F<@)RTM)R!S:&]U
M;&0@;F]T(&)E(&EN8VQU9&5D(&EN('1H92!O<'1I;VX@;F%M92X@3W!T:6]N
M<R!T:&%T"B`@("`@*B!R97%U:7)E(&%N(&%R9W5M96YT('-H;W5L9"!B92!F
M;VQL;W=E9"!B>2`G/2<L(&%N9"!O<'1I;VYS('1H870@=&%K92!A;@H@("`@
M("H@;W!T:6]N(&%R9W5M96YT('-H;W5L9"!B92!F;VQL;W=E9"!B>2`G/3TG
M+@H@("`@("H*("`@("`J(%1H92!R971U<FX@=F%L=64@:7,@86X@87)R87D@
M;V8@='=O(&5L96UE;G1S.B!T:&4@;&ES="!O9B!P87)S960*("`@("`J(&]P
M=&EO;G,@86YD('1H92!L:7-T(&]F(&YO;BUO<'1I;VX@8V]M;6%N9"UL:6YE
M(&%R9W5M96YT<RX@16%C:"!E;G1R>2!I;@H@("`@("H@=&AE(&QI<W0@;V8@
M<&%R<V5D(&]P=&EO;G,@:7,@82!P86ER(&]F(&5L96UE;G1S("T@=&AE(&9I
M<G-T(&]N90H@("`@("H@<W!E8VEF:65S('1H92!O<'1I;VXL(&%N9"!T:&4@
M<V5C;VYD(&]N92!S<&5C:69I97,@=&AE(&]P=&EO;B!A<F=U;65N="P*("`@
M("`J(&EF('1H97)E('=A<R!O;F4N"B`@("`@*@H@("`@("H@3&]N9R!A;F0@
M<VAO<G0@;W!T:6]N<R!C86X@8F4@;6EX960N"B`@("`@*@H@("`@("H@36]S
M="!O9B!T:&4@<V5M86YT:6-S(&]F('1H:7,@9G5N8W1I;VX@87)E(&)A<V5D
M(&]N($=.52!G971O<'1?;&]N9R@I+@H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`@)&%R9W,@("`@("`@("`@(&%N(&%R<F%Y(&]F(&-O;6UA;F0M;&EN
M92!A<F=U;65N=',*("`@("`J($!P87)A;2!S=')I;F<@)'-H;W)T7V]P=&EO
M;G,@('-P96-I9FEE<R!T:&4@;&ES="!O9B!A;&QO=V5D('-H;W)T(&]P=&EO
M;G,*("`@("`J($!P87)A;2!A<G)A>2`@)&QO;F=?;W!T:6]N<R`@('-P96-I
M9FEE<R!T:&4@;&ES="!O9B!A;&QO=V5D(&QO;F<@;W!T:6]N<PH@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@='=O+65L96UE;G0@87)R87D@8V]N=&%I
M;FEN9R!T:&4@;&ES="!O9B!P87)S960@;W!T:6]N<R!A;F0*("`@("`J('1H
M92!N;VXM;W!T:6]N(&%R9W5M96YT<PH@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*@H@("`@("HO"B`@("!F=6YC=&EO;B!G971O<'0R*"1A
M<F=S+"`D<VAO<G1?;W!T:6]N<RP@)&QO;F=?;W!T:6]N<R`](&YU;&PI"B`@
M("!["B`@("`@("`@<F5T=7)N($-O;G-O;&5?1V5T;W!T.CID;T=E=&]P="@R
M+"`D87)G<RP@)'-H;W)T7V]P=&EO;G,L("1L;VYG7V]P=&EO;G,I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@5&AI<R!F=6YC=&EO;B!E>'!E8W1S("1A<F=S
M('1O('-T87)T('=I=&@@=&AE('-C<FEP="!N86UE("A03U-)6"US='EL92DN
M"B`@("`@*B!0<F5S97)V960@9F]R(&)A8VMW87)D<R!C;VUP871I8FEL:71Y
M+@H@("`@("H@0'-E92!G971O<'0R*"D*("`@("`J+R`@("`*("`@(&9U;F-T
M:6]N(&=E=&]P="@D87)G<RP@)'-H;W)T7V]P=&EO;G,L("1L;VYG7V]P=&EO
M;G,@/2!N=6QL*0H@("`@>PH@("`@("`@(')E='5R;B!#;VYS;VQE7T=E=&]P
M=#HZ9&]'971O<'0H,2P@)&%R9W,L("1S:&]R=%]O<'1I;VYS+"`D;&]N9U]O
M<'1I;VYS*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1H92!A8W1U86P@:6UP
M;&5M96YT871I;VX@;V8@=&AE(&%R9W5M96YT('!A<G-I;F<@8V]D92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9&]'971O<'0H)'9E<G-I;VXL("1A<F=S+"`D
M<VAO<G1?;W!T:6]N<RP@)&QO;F=?;W!T:6]N<R`](&YU;&PI"B`@("!["B`@
M("`@("`@+R\@:6X@8V%S92!Y;W4@<&%S<R!D:7)E8W1L>2!R96%D4$A007)G
M=B@I(&%S('1H92!F:7)S="!A<F<*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D87)G<RDI('L*("`@("`@("`@("`@<F5T=7)N("1A<F=S.PH@("`@("`@
M('T*("`@("`@("!I9B`H96UP='DH)&%R9W,I*2!["B`@("`@("`@("`@(')E
M='5R;B!A<G)A>2AA<G)A>2@I+"!A<G)A>2@I*3L*("`@("`@("!]"B`@("`@
M("`@)&]P=',@("`@(#T@87)R87DH*3L*("`@("`@("`D;F]N7V]P=',@/2!A
M<G)A>2@I.PH*("`@("`@("!S971T>7!E*"1A<F=S+"`G87)R87DG*3L*"B`@
M("`@("`@:68@*"1L;VYG7V]P=&EO;G,I('L*("`@("`@("`@("`@<V]R="@D
M;&]N9U]O<'1I;VYS*3L*("`@("`@("!]"@H@("`@("`@("\J"B`@("`@("`@
M("H@4')E<V5R=F4@8F%C:W=A<F1S(&-O;7!A=&EB:6QI='D@=VET:"!C86QL
M97)S('1H870@<F5L:65D(&]N"B`@("`@("`@("H@97)R;VYE;W5S(%!/4TE8
M(&9I>"X*("`@("`@("`@*B\*("`@("`@("!I9B`H)'9E<G-I;VX@/"`R*2![
M"B`@("`@("`@("`@(&EF("AI<W-E="@D87)G<ULP77LP?2D@)B8@)&%R9W-;
M,%U[,'T@(3T@)RTG*2!["B`@("`@("`@("`@("`@("!A<G)A>5]S:&EF="@D
M87)G<RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E<V5T
M*"1A<F=S*3L*("`@("`@("!W:&EL92`H;&ES="@D:2P@)&%R9RD@/2!E86-H
M*"1A<F=S*2D@>PH*("`@("`@("`@("`@+RH@5&AE('-P96-I86P@96QE;65N
M="`G+2TG(&UE86YS(&5X<&QI8VET(&5N9"!O9@H@("`@("`@("`@("`@("!O
M<'1I;VYS+B!4<F5A="!T:&4@<F5S="!O9B!T:&4@87)G=6UE;G1S(&%S(&YO
M;BUO<'1I;VYS"B`@("`@("`@("`@("`@(&%N9"!E;F0@=&AE(&QO;W`N("HO
M"B`@("`@("`@("`@(&EF("@D87)G(#T]("<M+2<I('L*("`@("`@("`@("`@
M("`@("1N;VY?;W!T<R`](&%R<F%Y7VUE<F=E*"1N;VY?;W!T<RP@87)R87E?
M<VQI8V4H)&%R9W,L("1I("L@,2DI.PH@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D87)G>S!]("$]("<M
M)R!\?"`H<W1R;&5N*"1A<F<I(#X@,2`F)B`D87)G>S%](#T]("<M)R`F)B`A
M)&QO;F=?;W!T:6]N<RDI('L*("`@("`@("`@("`@("`@("1N;VY?;W!T<R`]
M(&%R<F%Y7VUE<F=E*"1N;VY?;W!T<RP@87)R87E?<VQI8V4H)&%R9W,L("1I
M*2D["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?2!E;'-E
M:68@*'-T<FQE;B@D87)G*2`^(#$@)B8@)&%R9WLQ?2`]/2`G+2<I('L*("`@
M("`@("`@("`@("`@("1E<G)O<B`]($-O;G-O;&5?1V5T;W!T.CI?<&%R<V5,
M;VYG3W!T:6]N*'-U8G-T<B@D87)G+"`R*2P@)&QO;F=?;W!T:6]N<RP@)&]P
M=',L("1A<F=S*3L*("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1E<G)O<BDI"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1E<G)O<B`]
M($-O;G-O;&5?1V5T;W!T.CI?<&%R<V53:&]R=$]P=&EO;BAS=6)S='(H)&%R
M9RP@,2DL("1S:&]R=%]O<'1I;VYS+"`D;W!T<RP@)&%R9W,I.PH@("`@("`@
M("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R*2D*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@87)R87DH)&]P=',L("1N;VY?;W!T<RD[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P87)S95-H;W)T3W!T:6]N*"1A<F<L
M("1S:&]R=%]O<'1I;VYS+"`F)&]P=',L("8D87)G<RD*("`@('L*("`@("`@
M("!F;W(@*"1I(#T@,#L@)&D@/"!S=')L96XH)&%R9RD[("1I*RLI('L*("`@
M("`@("`@("`@)&]P="`]("1A<F=[)&E].PH@("`@("`@("`@("`D;W!T7V%R
M9R`](&YU;&P["@H@("`@("`@("`@("`O*B!4<GD@=&\@9FEN9"!T:&4@<VAO
M<G0@;W!T:6]N(&EN('1H92!S<&5C:69I97(@<W1R:6YG+B`J+PH@("`@("`@
M("`@("!I9B`H*"1S<&5C(#T@<W1R<W1R*"1S:&]R=%]O<'1I;VYS+"`D;W!T
M*2D@/3T](&9A;'-E('Q\("1A<F=[)&E](#T]("<Z)RD*("`@("`@("`@("`@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D-O
M;G-O;&5?1V5T;W!T.B!U;G)E8V]G;FEZ960@;W!T:6]N("TM("1O<'0B*3L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*'-T<FQE;B@D<W!E8RD@
M/B`Q("8F("1S<&5C>S%](#T]("<Z)RD@>PH@("`@("`@("`@("`@("`@:68@
M*'-T<FQE;B@D<W!E8RD@/B`R("8F("1S<&5C>S)](#T]("<Z)RD@>PH@("`@
M("`@("`@("`@("`@("`@(&EF("@D:2`K(#$@/"!S=')L96XH)&%R9RDI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@+RH@3W!T:6]N('1A:V5S(&%N(&]P
M=&EO;F%L(&%R9W5M96YT+B!5<V4@=&AE(')E;6%I;F1E<B!O9@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("!T:&4@87)G('-T<FEN9R!I9B!T:&5R92!I
M<R!A;GET:&EN9R!L969T+B`J+PH@("`@("`@("`@("`@("`@("`@("`@("`D
M;W!T<UM=(#T@87)R87DH)&]P="P@<W5B<W1R*"1A<F<L("1I("L@,2DI.PH@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("\J($]P=&EO;B!R97%U:7)E<R!A;B!A<F=U;65N="X@57-E('1H
M92!R96UA:6YD97(@;V8@=&AE(&%R9PH@("`@("`@("`@("`@("`@("`@("`@
M('-T<FEN9R!I9B!T:&5R92!I<R!A;GET:&EN9R!L969T+B`J+PH@("`@("`@
M("`@("`@("`@("`@(&EF("@D:2`K(#$@/"!S=')L96XH)&%R9RDI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&]P='-;72`](&%R<F%Y*"1O<'0L("!S
M=6)S='(H)&%R9RP@)&D@*R`Q*2D["B`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!I9B`H;&ES="@L
M("1O<'1?87)G*2`](&5A8V@H)&%R9W,I*0H@("`@("`@("`@("`@("`@("`@
M("`@("`O*B!%;'-E('5S92!T:&4@;F5X="!A<F=U;65N="X@*B\["B`@("`@
M("`@("`@("`@("`@("`@96QS90H@("`@("`@("`@("`@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B0V]N<V]L95]'971O<'0Z(&]P=&EO
M;B!R97%U:7)E<R!A;B!A<F=U;65N="`M+2`D;W!T(BD["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1O<'1S6UT@/2!A
M<G)A>2@D;W!T+"`D;W!T7V%R9RD["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?<&%R<V5,;VYG3W!T:6]N*"1A<F<L("1L;VYG7V]P=&EO;G,L
M("8D;W!T<RP@)B1A<F=S*0H@("`@>PH@("`@("`@($!L:7-T*"1O<'0L("1O
M<'1?87)G*2`](&5X<&QO9&4H)STG+"`D87)G*3L*("`@("`@("`D;W!T7VQE
M;B`]('-T<FQE;B@D;W!T*3L*"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@
M8V]U;G0H)&QO;F=?;W!T:6]N<RD[("1I*RLI('L*("`@("`@("`@("`@)&QO
M;F=?;W!T("`]("1L;VYG7V]P=&EO;G-;)&E=.PH@("`@("`@("`@("`D;W!T
M7W-T87)T(#T@<W5B<W1R*"1L;VYG7V]P="P@,"P@)&]P=%]L96XI.PH*("`@
M("`@("`@("`@+RH@3W!T:6]N(&1O97-N)W0@;6%T8V@N($=O(&]N('1O('1H
M92!N97AT(&]N92X@*B\*("`@("`@("`@("`@:68@*"1O<'1?<W1A<G0@(3T@
M)&]P="D*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH*("`@("`@("`@("`@
M)&]P=%]R97-T("`]('-U8G-T<B@D;&]N9U]O<'0L("1O<'1?;&5N*3L*"B`@
M("`@("`@("`@("\J($-H96-K('1H870@=&AE(&]P=&EO;G,@=6YI<75E;'D@
M;6%T8VAE<R!O;F4@;V8@=&AE(&%L;&]W960*("`@("`@("`@("`@("`@;W!T
M:6]N<RX@*B\*("`@("`@("`@("`@:68@*"1O<'1?<F5S="`A/2`G)R`F)B`D
M;W!T>S!]("$]("<])R`F)@H@("`@("`@("`@("`@("`@)&D@*R`Q(#P@8V]U
M;G0H)&QO;F=?;W!T:6]N<RD@)B8*("`@("`@("`@("`@("`@("1O<'0@/3T@
M<W5B<W1R*"1L;VYG7V]P=&EO;G-;)&DK,5TL(#`L("1O<'1?;&5N*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D-O;G-O
M;&5?1V5T;W!T.B!O<'1I;VX@+2TD;W!T(&ES(&%M8FEG=6]U<R(I.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!I9B`H<W5B<W1R*"1L;VYG7V]P="P@
M+3$I(#T]("<])RD@>PH@("`@("`@("`@("`@("`@:68@*'-U8G-T<B@D;&]N
M9U]O<'0L("TR*2`A/2`G/3TG*2!["B`@("`@("`@("`@("`@("`@("`@+RH@
M3&]N9R!O<'1I;VX@<F5Q=6ER97,@86X@87)G=6UE;G0N"B`@("`@("`@("`@
M("`@("`@("`@("`@5&%K92!T:&4@;F5X="!A<F=U;65N="!I9B!O;F4@=V%S
M;B=T('-P96-I9FEE9"X@*B\["B`@("`@("`@("`@("`@("`@("`@:68@*"%S
M=')L96XH)&]P=%]A<F<I("8F("$H;&ES="@L("1O<'1?87)G*2`](&5A8V@H
M)&%R9W,I*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@B0V]N<V]L95]'971O<'0Z(&]P=&EO;B`M+21O<'0@
M<F5Q=6ER97,@86X@87)G=6UE;G0B*3L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!I9B`H)&]P
M=%]A<F<I('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*")#;VYS;VQE7T=E=&]P=#H@;W!T:6]N("TM)&]P="!D;V5S;B=T(&%L
M;&]W(&%N(&%R9W5M96YT(BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1O<'1S6UT@/2!A<G)A>2@G+2TG("X@)&]P="P@)&]P=%]A<F<I.PH@("`@
M("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@B0V]N<V]L95]'971O<'0Z('5N<F5C;V=N:7IE9"!O
M<'1I;VX@+2TD;W!T(BD["B`@("!]"@H@("`@+RHJ"B`@("`J(%-A9F5L>2!R
M96%D('1H92`D87)G=B!02%`@87)R87D@86-R;W-S(&1I9F9E<F5N="!02%`@
M8V]N9FEG=7)A=&EO;G,N"B`@("`J(%=I;&P@=&%K92!C87)E(&]N(')E9VES
M=&5R7V=L;V)A;',@86YD(')E9VES=&5R7V%R9V-?87)G=B!I;FD@9&ER96-T
M:79E<PH@("`@*@H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B!`<F5T=7)N
M(&UI>&5D('1H92`D87)G=B!02%`@87)R87D@;W(@4$5!4B!E<G)O<B!I9B!N
M;W0@<F5G:7-T97)E9`H@("`@*B\*("`@(&9U;F-T:6]N(')E86102%!!<F=V
M*"D*("`@('L*("`@("`@("!G;&]B86P@)&%R9W8["B`@("`@("`@:68@*"%I
M<U]A<G)A>2@D87)G=BDI('L*("`@("`@("`@("`@:68@*"%`:7-?87)R87DH
M)%]315)615);)V%R9W8G72DI('L*("`@("`@("`@("`@("`@(&EF("@A0&ES
M7V%R<F%Y*"1'3$]"04Q36R=(5%107U-%4E9%4E]605)3)UU;)V%R9W8G72DI
M('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@B0V]N<V]L95]'971O<'0Z($-O=6QD(&YO="!R96%D(&-M9"!A<F=S("AR
M96=I<W1E<E]A<F=C7V%R9W8]3V9F/RDB*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG2%144%]315)615)?
M5D%24R==6R=A<F=V)UT["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T
M=7)N("1?4T525D526R=A<F=V)UT["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B`D87)G=CL*("`@('T*"GT*"C\^"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O9&]C<P``````````````````````````````
M```````````````````````````````````````````````````````````P
M,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<S
M,"`P,3<S,S0`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+TA45%!?
M4F5Q=65S=```````````````````````````````````````````````````
M`````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P,#`P(#$P-3$U-#,S-S,P(#`R,38R,P`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+V1O8W,O2%144%]297%U97-T+V1O8W,`````````````````````
M````````````````````````````````````````````,#`P-S4U(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S`@,#(R-34S`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R](5%107U)E<75E<W0O9&]C
M<R]E>&%M<&QE+G!H<```````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-38P-"`Q,#4Q
M-30S,S<S,"`P,C4P,#,`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,C`P,BP@4FEC:&%R9"!(97EE<R`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@06QL
M(')I9VAT<R!R97-E<G9E9"X@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R!\(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U
M<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U="`@("!\"B\O
M('P@;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@
M=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS("`@('P*+R\@?"!A<F4@;65T.B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O('P@;R!2961I<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S
M="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H="`@("`@('P*+R\@?"`@(&YO
M=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I
M;F<@9&ES8VQA:6UE<BX@("`@("`@?`HO+R!\(&\@4F5D:7-T<FEB=71I;VYS
M(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y
M<FEG:'0@("!\"B\O('P@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I
M;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@:6X@=&AE('P*+R\@
M?"`@(&1O8W5M96YT871I;VX@86YD+V]R(&]T:&5R(&UA=&5R:6%L<R!P<F]V
M:61E9"!W:71H('1H92!D:7-T<FEB=71I;VXN?`HO+R!\(&\@5&AE(&YA;65S
M(&]F('1H92!A=71H;W)S(&UA>2!N;W0@8F4@=7-E9"!T;R!E;F1O<G-E(&]R
M('!R;VUO=&4@("`@("!\"B\O('P@("!P<F]D=6-T<R!D97)I=F5D(&9R;VT@
M=&AI<R!S;V9T=V%R92!W:71H;W5T('-P96-I9FEC('!R:6]R('=R:71T96X@
M('P*+R\@?"`@('!E<FUI<W-I;VXN("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O('P@5$A)4R!33T945T%212!)4R!0
M4D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@04Y$($-/3E1224)5
M5$]24R`@('P*+R\@?"`B05,@25,B($%.1"!!3ED@15A04D534R!/4B!)35!,
M245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5"`@("`@?`HO+R!\
M($Q)34E4140@5$\L(%1(12!)35!,245$(%=!4E)!3E1)15,@3T8@34520TA!
M3E1!0DE,2519($%.1"!&251.15-3($9/4B!\"B\O('P@02!005)424-53$%2
M(%!54E!/4T4@05)%($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(
M12!#3U!94DE'2%0@('P*+R\@?"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4@
M3$E!0DQ%($9/4B!!3ED@1$E214-4+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@
M?`HO+R!\(%-014-)04PL($5814U03$%262P@3U(@0T].4T51545.5$E!3"!$
M04U!1T53("A)3D-,541)3D<L($)55"!.3U0@("`@("!\"B\O('P@3$E-251%
M1"!43RP@4%)/0U5214U%3E0@3T8@4U5"4U1)5%5412!'3T]$4R!/4B!315)6
M24-%4SL@3$]34R!/1B!54T4L('P*+R\@?"!$051!+"!/4B!04D]&2513.R!/
M4B!"55-)3D534R!)3E1%4E)54%1)3TXI($A/5T5615(@0T%54T5$($%.1"!/
M3B!!3ED@?`HO+R!\(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(15(@24X@
M0T].5%)!0U0L(%-44DE#5"!,24%"24Q)5%DL($]2(%1/4E0@("!\"B\O('P@
M*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]42$525TE312D@05))4TE.1R!)
M3B!!3ED@5T%9($]55"!/1B!42$4@55-%('P*+R\@?"!/1B!42$E3(%-/1E17
M05)%+"!%5D5.($E&($%$5DE3140@3T8@5$A%(%!/4U-)0DE,2519($]&(%-5
M0T@@1$%-04=%+B`@?`HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W(Z
M(%)I8VAA<F0@2&5Y97,@/')I8VAA<F1`<&AP9W5R=2YO<F<^("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"@H*+RHJ"BH@5&AI<R!W:6QL(&=R86(@82!W96)P86=E(&%N9"!D
M:7-P;&%Y(&ET"BHO"@EI;F-L=61E*"=(5%10+U)E<75E<W0N<&AP)RD["@H)
M)')E<2`]("9N97<@2%144%]297%U97-T*"=H='1P.B\O=W=W+G!H<"YN970G
M*3L*"21R97$M/G-E=$UE=&AO9"A(5%107U)%455%4U1?34542$]$7U!/4U0I
M.PH))')E<2T^861D4&]S=$1A=&$H)T9O;R<L("=B87(G*3L*"21R97$M/G-E
M;F1297%U97-T*"D["@DD<F5S<&]N<V4Q(#T@)')E<2T^9V5T4F5S<&]N<V5"
M;V1Y*"D["@D*"21R97$M/G-E=$UE=&AO9"A(5%107U)%455%4U1?34542$]$
M7T=%5"D["@DD<F5Q+3YS97154DPH)VAT='`Z+R]P96%R+G!H<"YN970G*3L*
M"21R97$M/F-L96%R4&]S=$1A=&$H*3L*"21R97$M/G-E;F1297%U97-T*"D[
M"@H))')E<W!O;G-E,B`]("1R97$M/F=E=%)E<W!O;G-E0F]D>2@I.PH*"65C
M:&\@)')E<W!O;G-E,3L*"65C:&\@)')E<W!O;G-E,CL*/SX`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]D;V-S+TA45%!?4F5Q=65S="]D;V-S+V1O=VYL;V%D+7!R;V=R
M97-S+G!H<````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`U-C0T(#$P-3$U-#,S-S,P(#`R-S`R-0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@06X@97AA;7!L92!O9B!,:7-T96YE<B!U<V%G92!W:71H($A4
M5%!?4F5Q=65S="X@5&AI<R!D;W=N;&]A9',@86YD('-A=F5S(`H@*B!T:&4@
M9FEL92!D:7-P;&%Y:6YG('1H92!P<F]G<F5S<R!B87(@:6X@=&AE('!R;V-E
M<W,N"B`J(`H@*B!.;W1E('1W;R!T:&EN9W,Z"B`J(#$I(%1H92!F:6QE('-H
M;W5L9"!B92!R=6X@:6X@8V]N<V]L92P@;F]T(&EN(&)R;W=S97(["B`J(#(I
M(%EO=2!S:&]U;&0@='5R;B!O=71P=70@8G5F9F5R:6YG($]&1B!F;W(@=&AI
M<R!T;R!W;W)K('!R;W!E<FQY+@H@*B`*("H@)$ED.B!D;W=N;&]A9"UP<F]G
M<F5S<RYP:'`L=B`Q+C$@,C`P,R\Q,"\R-R`Q,#HT.#HT.2!A=F(@17AP("0*
M("HO"@IR97%U:7)E7V]N8V4@)TA45%`O4F5Q=65S="YP:'`G.PIR97%U:7)E
M7V]N8V4@)TA45%`O4F5Q=65S="],:7-T96YE<BYP:'`G.PIR97%U:7)E7V]N
M8V4@)T-O;G-O;&4O4')O9W)E<W-"87(N<&AP)SL*"E!%05(Z.G-E=$5R<F]R
M2&%N9&QI;F<H4$5!4E]%4E)/4E]$244I.PH*<V5T7W1I;65?;&EM:70H,"D[
M"@IC;&%S<R!(5%107U)E<75E<W1?1&]W;FQO861,:7-T96YE<B!E>'1E;F1S
M($A45%!?4F5Q=65S=%],:7-T96YE<@I["B`@("\J*@H@("`@*B!(86YD;&4@
M9F]R('1H92!T87)G970@9FEL90H@("`@*B!`=F%R(&EN=`H@("`@*B\*("`@
M('9A<B`D7V9P.PH*("`@+RHJ"B`@("`J($-O;G-O;&5?4')O9W)E<W-"87(@
M:6YT86YC92!U<V5D('1O(&1I<W!L87D@=&AE(&EN9&EC871O<@H@("`@*B!`
M=F%R(&]B:F5C=`H@("`@*B\*("`@('9A<B`D7V)A<CL*"B`@("\J*@H@("`@
M*B!.86UE(&]F('1H92!T87)G970@9FEL90H@("`@*B!`=F%R('-T<FEN9PH@
M("`@*B\*("`@('9A<B`D7W1A<F=E=#L*"B`@("\J*@H@("`@*B!.=6UB97(@
M;V8@8GET97,@<F5C96EV960@<V\@9F%R"B`@("`J($!V87(@:6YT"B`@("`J
M+PH@("`@=F%R("1?<VEZ92`](#`["@H@("`@9G5N8W1I;VX@2%144%]297%U
M97-T7T1O=VYL;V%D3&ES=&5N97(H*0H@("`@>PH@("`@("`@("1T:&ES+3Y(
M5%107U)E<75E<W1?3&ES=&5N97(H*3L*("`@('T*"B`@("\J*@H@("`@*B!/
M<&5N<R!T:&4@=&%R9V5T(&9I;&4*("`@("H@0'!A<F%M('-T<FEN9R!487)G
M970@9FEL92!N86UE"B`@("`J($!T:')O=W,@4$5!4E]%<G)O<@H@("`@*B\*
M("`@(&9U;F-T:6]N('-E=%1A<F=E="@D=&%R9V5T*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?=&%R9V5T(#T@)'1A<F=E=#L*("`@("`@("`D=&AI<RT^7V9P
M(#T@0&9O<&5N*"1T87)G970L("=W8B<I.PH@("`@("`@(&EF("@A)'1H:7,M
M/E]F<"D@>PH@("`@("`@("`@("!014%2.CIR86ES945R<F]R*")#86YN;W0@
M;W!E;B`G>R1T87)G971])R(I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC
M=&EO;B!U<&1A=&4H)B1S=6)J96-T+"`D979E;G0L("1D871A(#T@;G5L;"D*
M("`@('L*("`@("`@("!S=VET8V@@*"1E=F5N="D@>PH@("`@("`@("`@("!C
M87-E("=S96YT4F5Q=65S="<Z(`H@("`@("`@("`@("`@("`@)'1H:7,M/E]T
M87)G970@/2!B87-E;F%M92@D<W5B:F5C="T^7W5R;"T^<&%T:"D["B`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V=O=$AE861E
M<G,G.@H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D871A6R=C;VYT96YT
M+61I<W!O<VET:6]N)UTI("8F"B`@("`@("`@("`@("`@("`@("`@<')E9U]M
M871C:"@G+V9I;&5N86UE/2(H6UXB72LI(B\G+"`D9&%T85LG8V]N=&5N="UD
M:7-P;W-I=&EO;B==+"`D;6%T8VAE<RDI('L*"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G-E=%1A<F=E="AB87-E;F%M92@D;6%T8VAE<ULQ72DI.PH@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^<V5T5&%R9V5T*"1T:&ES+3Y?=&%R9V5T*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("1T:&ES+3Y?8F%R(#TF(&YE=R!#;VYS
M;VQE7U!R;V=R97-S0F%R*`H@("`@("`@("`@("`@("`@("`@("<J("<@+B`D
M=&AI<RT^7W1A<F=E="`N("<@)69R86-T:6]N)2!+0B!;)6)A<B5=("5P97)C
M96YT)2<L("<]/B<L("<M)RP@"B`@("`@("`@("`@("`@("`@("`@-SDL("AI
M<W-E="@D9&%T85LG8V]N=&5N="UL96YG=&@G72D_(')O=6YD*"1D871A6R=C
M;VYT96YT+6QE;F=T:"==("\@,3`R-"DZ(#$P,"D*("`@("`@("`@("`@("`@
M("D["B`@("`@("`@("`@("`@("`D=&AI<RT^7W-I>F4@/2`P.PH@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=T:6-K)SH*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<VEZ92`K/2!S=')L96XH)&1A=&$I.PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]B87(M/G5P9&%T92AR;W5N9"@D=&AI
M<RT^7W-I>F4@+R`Q,#(T*2D["B`@("`@("`@("`@("`@("!F=W)I=&4H)'1H
M:7,M/E]F<"P@)&1A=&$I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("!C87-E("=G;W1";V1Y)SH*("`@("`@("`@("`@("`@(&9C;&]S
M92@D=&AI<RT^7V9P*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@(%!%05(Z.G)A:7-E17)R
M;W(H(E5N:&%N9&QE9"!E=F5N="`G>R1E=F5N='TG(BD["B`@("`@("`@?2`O
M+R!S=VET8V@*("`@('T*?0H*+R\@5')Y('5S:6YG(&%N>2!O=&AE<B!P86-K
M86=E(&EF('EO=2!L:6ME+"!B=70@8VAO;W-E('1H92!B:6=G97(@;VYE<PHO
M+R!T;R!B92!A8FQE('1O('-E92!T:&4@<')O9W)E<W,@8F%R"B1U<FP@/2`G
M:'1T<#HO+W!E87(N<&AP+FYE="]G970O2%1-3%]1=6EC:T9O<FTM<W1A8FQE
M)SL*"B1R97$@/28@;F5W($A45%!?4F5Q=65S="@D=7)L*3L*"B1D;W=N;&]A
M9"`])B!N97<@2%144%]297%U97-T7T1O=VYL;V%D3&ES=&5N97(H*3L*)')E
M<2T^871T86-H*"1D;W=N;&]A9"D["B1R97$M/G-E;F1297%U97-T*&9A;'-E
M*3L*/SX*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O1$(`
M````````````````````````````````````````````````````````````
M````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`P,#`@,3`U,34T,S,W,S`@,#$W-C(Q`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O9&]C<R]$0B]D;V,`````````````````````````````````
M```````````````````````````````````````````````P,#`W-34@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<S,"`P,C`S-C8`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+T1"+V1O8R]-04E.5$%)
M3D524P``````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,C4P(#$P
M-3$U-#,S-S,P(#`R,C$T,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!-86EN=&%I;F5R<R!F;W(@1$(@9&%T86)A<V4@8F%C
M:V5N9',O9')I=F5R<SH*"F1B87-E("`@.B!$86YI96P@0V]N=FES<V]R(#QD
M86YI96QC0'!H<"YN970^"F9B<W%L("`@.B!$86YI96P@0V]N=FES<V]R(#QD
M86YI96QC0'!H<"YN970^"B`@("`@("`@("!&<F%N:R!-+B!+<F]M86YN(#QF
M<F%N:T!K<F]M86YN+FEN9F\^"FEB87-E("`@.B!$86YI96P@0V]N=FES<V]R
M(#QD86YI96QC0'!H<"YN970^"FEF>"`@("`@.B!$86YI96P@0V]N=FES<V]R
M(#QD86YI96QC0'!H<"YN970^"FUS<6P@("`@.B!$86YI96P@0V]N=FES<V]R
M(#QD86YI96QC0'!H<"YN970^"FUS<W%L("`@.B!$86YI96P@0V]N=FES<V]R
M(#QD86YI96QC0'!H<"YN970^"FUY<W%L("`@.B!$86YI96P@0V]N=FES<V]R
M(#QD86YI96QC0'!H<"YN970^"FUY<W%L:2`@.B!$86YI96P@0V]N=FES<V]R
M(#QD86YI96QC0'!H<"YN970^"F]C:3@@("`@.B!$86YI96P@0V]N=FES<V]R
M(#QD86YI96QC0'!H<"YN970^"F]D8F,@("`@.B!$86YI96P@0V]N=FES<V]R
M(#QD86YI96QC0'!H<"YN970^"G!G<W%L("`@.B!$86YI96P@0V]N=FES<V]R
M(#QD86YI96QC0'!H<"YN970^"G-Q;&ET92`@.B!$86YI96P@0V]N=FES<V]R
M(#QD86YI96QC0'!H<"YN970^"G-Y8F%S92`@.B!$86YI96P@0V]N=FES<V]R
M(#QD86YI96QC0'!H<"YN970^"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+T1"+V1O8R]3
M5$%455,`````````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$P
M-C0U(#$P-3$U-#,S-S,P(#`R,30R,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!35$%455,@3T8@5$A%(%!%05(@1$(@4$%#
M2T%'10H]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*)$ED.B!35$%4
M55,L=B`Q+C,S(#(P,#4O,#(O,C(@,34Z-#4Z,S8@9&%N:65L8R!%>'`@)`HM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*"D1"($1R:79E<B!&96%T=7)E
M($UA=')I>`HM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*4WEM8F]L<SH*("!X
M("`]("!I;7!L96UE;G1E9"P@8G5T('=I=&AO=70@=&5S=',*("!T("`]("!I
M;7!L96UE;G1E9"P@8G5T(&]N92!O<B!M;W)E('1E<W1S(&9A:6P*("!4("`]
M("!I;7!L96UE;G1E9"P@<&%S<VEN9R!A;&P@=&5S=',*("!E("`]("!E;75L
M871E9"P@=VET:&]U="!T97-T<PH@(&P@(#T@(&5M=6QA=&5D+"!B=70@;VYE
M(&]R(&UO<F4@=&5S=',@9F%I;`H@($4@(#T@(&5M=6QA=&5D+"!P87-S:6YG
M(&%L;"!T97-T<PH@(&X@(#T@(')E='5R;G,@(FYO="!C87!A8FQE(@H@("T@
M(#T@(&YO(&EM<&QE;65N=&%T:6]N(&]F('1H:7,@9F5A='5R92!O<B!S=&%T
M=7,@=6YK;F]W;@H*("`@("`@("`@("`@("`@("`@("!F8G-Q;"`@("`@(&EF
M>"`@("`@(&US<W%L("`@("!M>7-Q;&D@("`@(&]D8F,@("`@('-Q;&ET90I&
M14%455)%("`@("`@("!D8F%S92`@?"`@:6)A<V4@('P@(&US<6P@("!\("!M
M>7-Q;"`@?"`@(&]C:3@@('P@('!G<W%L("!\("!S>6)A<V4*<VEM<&QE475E
M<GD@("`@("`M("`@(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!4("`@(%0@
M("`@5"`@("!4("`@(%0@("`@5"`@("!4"FYU;4-O;',@("`@("`@("`@>"`@
M("!4("`@(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!4("`@(%0@("`@5"`@
M("!4("`@(%0@("`@5`IN=6U2;W=S("`@("`@("`@('@@("`@5"`@("!%("`@
M($4@("`@5"`@("!4("`@(%0@("`@5"`@("!%("`@(%0@("`@5"`@("!4("`@
M(%0*97)R;W).871I=F4@("`@("!N("`@(%0@("`@5"`@("!4("`@(%0@("`@
M5"`@("!4("`@(%0@("`@5"`@("!4("`@(%0@("`@12`@("!4"G!R97!A<F4O
M97AE8W5T92`@92`@("!%("`@(%0@("`@12`@("!%("`@($4@("`@12`@("!%
M("`@(%0@("`@12`@("!%("`@($4@("`@10IS97%U96YC97,@("`@("`@(&X@
M("`@5"`@("!4("`@(&X@("`@5"`@("!4("`@(%0@("`@5"`@("!4("`@($4@
M("`@5"`@("!%("`@(%0*869F96-T9612;W=S("`@("!N("`@(%0@("`@12`@
M("!%("`@(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!4("`@($4@("`@5"`@
M("!4"F9E=&-H(&UO9&5S("`@("`@>"`@("!4("`@(%0@("`@5"`@("!4("`@
M(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!4("`@(%0@("`@5`IF971C:"!R
M;W<@8GD@;F\@('@@("`@>"`@("!N("`@(&X@("`@>"`@("!X("`@('@@("`@
M>"`@("!N("`@('@@("`@>"`@("!X("`@('@*=')A;G-A8W1I;VYS("`@("`M
M("`@(%0@("`@5"`@("!4("`@(&X@("`@5"`@("!4("`@(%0@("`@5"`@("!4
M("`@(%0@("`@;B`@("!4"F%U=&\M8V]M;6ET("`@("`@;B`@("!4("`@($4@
M("`@12`@("!N("`@($4@("`@12`@("!%("`@($4@("`@5"`@("!%("`@(&X@
M("`@10IE<G)O<B!M87!P:6YG("`@("T@("`@5"`@("!4("`@(%0@("`@5"`@
M("!4("`@(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!4("`@(%0*=&%B;&5)
M;F9O("`@("`@("!X("`@(%0@("`@5"`@("!T("`@(%0@("`@5"`@("!4("`@
M(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!4"@IG971,:7-T3V8H*2!465!%
M4PIT86)L97,@("`@("`@("`@("T@("`@5"`@("!4("`@(%0@("`@5"`@("!4
M("`@(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!4("`@(%0*=FEE=W,@("`@
M("`@("`@("`M("`@(%0@("`@5"`@("`M("`@("T@("`@5"`@("`M("`@("T@
M("`@+2`@("!4("`@(%0@("`@+2`@("!4"G5S97)S("`@("`@("`@("`@+2`@
M("!4("`@(%0@("`@+2`@("`M("`@("T@("`@5"`@("!4("`@("T@("`@+2`@
M("!4("`@("T@("`@+0ID871A8F%S97,@("`@("`@("T@("`@+2`@("`M("`@
M("T@("`@5"`@("`M("`@(%0@("`@5"`@("`M("`@(%0@("`@5"`@("`M("`@
M("T*9G5N8W1I;VYS("`@("`@("`M("`@(%0@("`@+2`@("`M("`@("T@("`@
M+2`@("`M("`@("T@("`@+2`@("`M("`@(%0@("`@+2`@("`M"G-Y;F]N>6US
M("`@("`@("`@+2`@("`M("`@("T@("`@+2`@("`M("`@("T@("`@+2`@("`M
M("`@(%0@("`@+2`@("`M("`@("T@("`@+0H*"E1E<W0@0V]N9F]R;6%N8V4*
M+2TM+2TM+2TM+2TM+2TM+0I3>6UB;VQS.@H@("`@;R`@/2`@5&5S="!P87-S
M960*("`@(%@@(#T@(%1E<W0@9F%I;&5D"B`@("!,("`]("!3;VUE('!O<G1I
M;VYS(&]F('1H92!T97-T(&9A:6QE9"!D=64@=&\@;&EM:71A=&EO;G,@:6X@
M4$A0(&]R($1"35,*("`@(&X@(#T@(%1E<W0@<F5T=7)N<R`B;F]T(&-A<&%B
M;&4B"B`@("`M("`]("!.;W0@=&5S=&5D"@H@("`@("`@("`@("`@("`@("`@
M(&9B<W%L("`@("`@:69X("`@("`@;7-S<6P@("`@(&UY<W%L:2`@("`@;V1B
M8R`@("`@<W%L:71E"B`@("`@("`@("`@("`@(&1B87-E("!\("!I8F%S92`@
M?"`@;7-Q;"`@('P@(&UY<W%L("!\("`@;V-I."`@?"`@<&=S<6P@('P@('-Y
M8F%S90HP,6-O;FYE8W0@("`@("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@
M("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\*,#)F971C
M:"`@("`@("`@("`M("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@
M(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O"C`S<VEM<&QE<75E<GD@("`@
M+2`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@
M;R`@("!O("`@(&\@("`@;PHP-&YU;6-O;',@("`@("`@("T@("`@;R`@("!O
M("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O
M("`@(&\*,#5S97%U96YC97,@("`@("`M("`@(&\@("`@;R`@("!O("`@(&\@
M("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O"C`V<')E
M<&5X96,@("`@("`@+2`@("!O("`@(&\@("`@;R`@("!,("`@(&\@("`@;R`@
M("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;PHP.&%F9F5C=&5D<F]W<R`@
M("T@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@
M(&\@("`@;R`@("!O("`@(&\*,#EN=6UR;W=S("`@("`@("`M("`@(&\@("`@
M;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@
M;R`@("!O"C$P97)R;W)M87`@("`@("`@+2`@("!O("`@(&\@("`@;R`@("!O
M("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;PHQ,71R
M86YS86-T:6]N<R`@("T@("`@;R`@("!O("`@(&\@("`@;B`@("!O("`@(&\@
M("`@;R`@("!O("`@(&\@("`@;R`@("!N("`@(&\*,3-L:6UI="`@("`@("`@
M("`M("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@
M("!O("`@(&\@("`@;R`@("!O"C$T9F5T8VAM;V1E7V]B:F4@+2`@("!O("`@
M(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@
M(&\@("`@;PHQ-7%U;W1E("`@("`@("`@("T@("`@;R`@("!O("`@(&\@("`@
M;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\*,39T
M86)L96EN9F\@("`@("`M("`@(&\@("`@;R`@("!,("`@(&\@("`@;R`@("!O
M("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O"C$W<75E<GD@("`@("`@
M("`@+2`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@
M("`@;R`@("!O("`@(&\@("`@;PHQ.&=E="`@("`@("`@("`@("T@("`@;R`@
M("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@
M("!O("`@(&\*,3EG971L:7-T;V8@("`@("`M("`@(&\@("`@;R`@("!O("`@
M(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O"@H*
M1$)-4R!697)S:6]N<R!497-T960*+2TM+2TM+2TM+2TM+2TM+2TM+2T*9&)A
M<V4@("!N+V$*9F)S<6P@("`T+C$N-@II8F%S92`@($9I<F5B:7)D(#$N-2XQ
M("`H4$A0(#4@;VYL>2D*:69X("`@("`W+C(@4W1A;F1A<F0@161T:71I;VX*
M;7-Q;"`@("`S+C8@("A02%`@<VYA<'-H;W1S(&1A=&5D(#(P,#4M,#(M,3@I
M"FUS<W%L("`@."XP+C<V,`IM>7-Q;"`@(#0N,"XR,0IM>7-Q;&D@(#0N,2XU
M("`H4$A0(#4@;VYL>2D*;V-I."`@("`Y+C(*;V1B8R`@("!$0C(@15-%(#@N
M,2!A;F0@35,@06-C97-S(#(P,#`*<&=S<6P@("`W+C0N,2!A;F0@."XP+C$*
M<W%L:71E("!02%`@-3H@97AT96YS:6]N+B`@4$A0(#0Z(%!%0TP@<VYA<'-H
M;W0N"G-Y8F%S92`@05-%(#$R+C4N,PH*5&5S=',@=V5R92!P97)F;W)M960@
M=6YD97(@8F]T:"!O9B!T:&4@9F]L;&]W:6YG(%!(4"!V97)S:6]N<PIU;FQE
M<R!O=&AE<G=I<V4@;F]T960Z"B`@("`T+C,N,3$M9&5V(&1A=&5D(#(P,#4M
M,#(M,C(*("`@(#4N,2XP+61E=B!D871E9"`R,#`U+3`R+3(R"@``````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O1$(O9&]C+U1%4U1%4E,`````
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3(S,#`@,3`U,34T
M,S,W,S`@,#(Q-3$U`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#T]/3T]/3T]/3T]/3T]/3T]/3T*2$]7(%1/(%1%4U0@4$5!
M4B!$0@H]/3T]/3T]/3T]/3T]/3T]/3T]"@HD260Z(%1%4U1%4E,L=B`Q+C(P
M(#(P,#4O,#(O,38@,#8Z,S,Z,3(@9&%N:65L8R!%>'`@)`H*"DE.5%)/1%5#
M5$E/3@H]/3T]/3T]/3T]/3T*"E1H97-E(&%R92!I;G-T<G5C=&EO;G,@9F]R
M('1E<W1I;F<@4$5!4B!$0B!O;B!A(%=I;F1O=W,@;6%C:&EN92!U<VEN9R!A
M"D-Y9W=I;B!"87-H('-H96QL+B`@061J=7-T('1H92!P871H<R!A;F0@8V]M
M;6%N9',@=&\@;6%T8V@@>6]U<B!S>7-T96TN"E1H:7,@8V]N9FEG=7)A=&EO
M;B!I<R!U<V5D(&)E8V%U<V4@=&AE<V4@<')E8VES92!S=&5P<R!A<F4@:VYO
M=VX@=&\@=V]R:RX*"DY/5$4Z("!9;W4@;75S="!L;V<@;VX@87,@82!U<V5R
M('=H:6-H(&AA<R!P97)M:7-S:6]N<R!T;R!M;V1I9GD@=&AE"F-O;G1E;G1S
M(&]F('EO=7(@4$A0(&5X96-U=&%B;&4G<R!D:7)E8W1O<GDN("!4:&ES(&ES
M(&YE8V5S<V%R>2!F;W(@8F]T:`IC;VYF:6=U<FEN9R!!3D0@<G5N;FEN9R!T
M:&4@=&5S="!S>7-T96TN"@H*24Y35$%,3$%424]."CT]/3T]/3T]/3T]/0H*
M3V)T86EN(%!(4"=S(%1E<W0@1G)A;65W;W)K"BTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+0I)9B!Y;W4@9&]N)W0@:&%V92!02%`G<R!T97-T(&9R86UE
M=V]R:RP@>6]U(&YE960@=&\@;V)T86EN(&ET+B`@5&AE<V4*<W1E<',@:6YC
M;'5D92!C:&%N9VEN9R!T:&4@=V]R:VEN9R!D:7)E8W1O<GDL(&1O=VYL;V%D
M:6YG(')U;BUT97-T<RYP:'`*=FEA($-64R!A;F0@8V]P>6EN9R!T:&4@9FEL
M92!I;G1O('!L86-E+B`@0VAA;F=E('1H92!R979I<VEO;B!F;&%G(&EN('1H
M90I#5E,@8V]M;6%N9"!A<R!A<'!R;W!R:6%T92!F;W(@>6]U<B!P<F5S96YT
M('9E<G-I;VX@;V8@4$A0+@H*(&-D(&,Z+W!R;V=R87XQ+W!H<`H@8W9S("UD
M(#IP<V5R=F5R.F-V<W)E861`8W9S+G!H<"YN970Z+W)E<&]S:71O<GD@;&]G
M:6X@("`C('!A<W-W;W)D(&ES('!H<&9I"B!C=G,@+60@.G!S97)V97(Z8W9S
M<F5A9$!C=G,N<&AP+FYE=#HO<F5P;W-I=&]R>2!C;R`M<B!02%!?-%\S(%P*
M("`@("`M9"!T97-T('!H<"US<F,O<G5N+71E<W1S+G!H<`H@8W`@=&5S="]R
M=6XM=&5S=',N<&AP("X*(')M("UR9B!T97-T"@H*3V)T86EN($1"(&%N9"!I
M=',@5&5S="!&<F%M97=O<FL*+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2T**B!)1B!014%2($1"($E3($%,4D5!1%D@24Y35$%,3$5$.@H*("!)
M9B!Y;W4@:&%V92!014%2($1"(&EN<W1A;&QE9"!A;')E861Y+"!G;V]D+B`@
M5&AE('1E<W0@<W5I=&4*("!I<R!I;B!P;&%C92X@($]P96X@=7`@82!C;VUM
M86YD+W-H96QL('!R;VUP="!A;F0@;6]V92!I;G1O"B`@=&AE('1E<W0@9&ER
M96-T;W)Y+@H*("`@8V0@/'!A=&@@=&\@<&5A<B!I;G-A;&P^+W1E<W1S+T1"
M+W1E<W1S"@HJ(%9)02!!($Y%5R!)3E-404Q,051)3TX@55-)3D<@5$A%(%!%
M05(@24Y35$%,3$52.@H*("!);G-T86QL:6YG(%!%05(@:&%S(&=O='1E;B!F
M86ER;'D@96%S>2X@($9O;&QO=R!T:&4@:6YS=')U8W1I;VYS"B`@9G)O;2!T
M:&4@;6%N=6%L.B`@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO:6YS
M=&%L;&%T:6]N+G!H<`H@($]N8V4@4$5!4B!A;F0@1$(@87)E(&EN<W1A;&QE
M9"P@;6]V92!T;R!T:&4@=&5S="!D:7)E8W1O<GDN"@H@("!C9"!P96%R+W1E
M<W1S+T1"+W1E<W1S"@HJ(%9)02!#5E,Z"@H@($-R96%T92!A(&QO8V%T:6]N
M('1O('-T;W)E('1H92!T97-T(&EN<W1A;&QA=&EO;B!O9B!$0B!A;F0@:71S
M"B`@=&5S="!S8W)I<'1S+@H*("`@;6MD:7(@9#HO<&5A<G1E<W0*("`@8V0@
M9#HO<&5A<G1E<W0*("`@8W9S("UD(#IP<V5R=F5R.F-V<W)E861`8W9S+G!H
M<"YN970Z+W)E<&]S:71O<GD@8V\@+5`@<&5A<B]$0@H*("!792!A<W-U;64@
M>6]U(&%L<F5A9'D@:&%V92!T:&4@4$5!4B!B87-E('!A8VMA9V4@:6YS=&%L
M;&5D+B`@268*("!Y;W4@9&]N)W0L('EO=2!W:6QL(&YE960@=&\@9&\@<V\L
M(&)U="!T:&4@:6YS=')U8W1I;VYS(&9O<@H@(&1O:6YG('1H870@87)E(&)E
M>6]N9"!T:&4@<V-O<&4@;V8@=&AI<R!D;V-U;65N="X@(%-E90H@(&AT='`Z
M+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+VEN<W1A;&QA=&EO;BYP:'`@9F]R
M(&UO<F4@:6YF;RX*"B`@36]V92!T;R!T:&4@=&5S="!D:7)E8W1O<GDN"@H@
M("!C9"!P96%R+T1"+W1E<W1S"@H*0V]P>2!T:&4@4W1A<G1E<B!3:&5L;"!3
M8W)I<'0@86YD($5D:70@=&AE(%!A=&AS"BTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0I4;R!M86ME('-T87)T:6YG
M('5P(&5A8V@@=&5S="!R=6X@96%S:65R+"!W92!H879E(&EN8VQU9&5D('1W
M;R!S:&5L;`IS8W)I<'1S+B`@5&AE(&]R:6=I;F%L(&9I;&5S(&%R92!N86UE
M9"`B<G5N+F-V<R(N("!4:&5Y(&YE960@=&\@8F4*<F5N86UE9"!T;R`B<G5N
M(B!S;R!#5E,@=V]N)W0@8F]T:&5R('EO=2!W:71H('1R86-K:6YG('1H96TN
M("!4:&5N+`IT:&4@<&%T:',@86YD(&9I;&4@;F%M97,@:6X@=&AE;2!N965D
M('1O(&)E('-E="!T;R!T:&]S92!U<V5D(&)Y"GEO=7(@<WES=&5M+@H*(&-P
M(')U;BYC=G,@<G5N"B!C:&UO9"`W-34@<G5N"B!V:2!R=6X*"B!C9"!D<FEV
M97(*(&-P(')U;BYC=G,@<G5N"B!C:&UO9"`W-34@<G5N"B!V:2!R=6X*"@I#
M;W!Y('1H92!3971U<"!&:6QE(&%N9"!%9&ET('1H92!$4TXG<PHM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0I4:&4@=&5S="!S=6ET
M92!C;VYT86EN<R!A(&9I;&4@=&AA="!S=&]R97,@=&AE($133B=S(&YE961E
M9"!T;PIC;VYN96-T('1O('EO=7(@9&%T86)A<V4N("!4:&4@;W)I9VEN86P@
M9FEL92!I<R`B<V5T=7`N:6YC+F-V<R(*86YD(&ET(&YE961S('1O(&)E(')E
M;F%M960@(G-E='5P+FEN8R(@<V\@0U93('=O;B=T('1R86-K(&ET+@I4:&5N
M('EO=2=L;"!N965D('1O(&5D:70@=&AE($133B=S(&EN(&ET+@H*(&-P('-E
M='5P+FEN8RYC=G,@<V5T=7`N:6YC"B!V:2!S971U<"YI;F,*"@I254X@5$A%
M(%1%4U13"CT]/3T]/3T]/3T]/3T*"E1O(')U;B!A;&P@=&5S=',Z("`N+W)U
M;@I4;R!R=6X@;VYE('1E<W0Z("`@+B]R=6X@/'1E<W0@9FEL92!N86UE/@I%
M>&%M<&QE.B`@("`@("`@("`@+B]R=6X@9&)?<&%R<V5D<VXN<&AP=`H*"E1E
M<W0@5'EP97,@86YD($QO8V%T:6]N<PHM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2T*=&5S=',@("`@("`@("`@("`@0V]M;6]N(%!%05(@1$(@=&5S=',*=&5S
M=',O9')I=F5R("`@("`@0V]M;6]N('1E<W1S(&9O<B!A;&P@=&AE(&1R:79E
M<G,*"@I297-U;'1S(&%N9"!7:&%T(%1O($1O(%=I=&@@5&AE;0HM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0I%86-H('1E<W0@=&AA="!F86EL
M<R!G96YE<F%T97,@82`N<&AP("AW:&EC:"!Y;W4@8V%N(&5X96-U=&4I+"!A
M("YE>'`**'1H92!E>'!E8W1E9"!O=71P=70I+"!A("YO=70@*'1H92!T97-T
M(&]U='!U="D@86YD(&$@+F1I9F8@*&$@9&EF9B`M=0IF<F]M('1H92`N97AP
M(&%N9"`N;W5T(&9I;&5S*2X*"DEF('EO=2!R=6X@=&AE('1E<W1S+"!P;&5A
M<V4@<F5P;W)T(&]R(&9I;&P@=&AE(%1%4U0@0T].1D]234%.0T4@=&%B;&4*
M:6X@=&AE(%-405154R!D;V-U;65N="X@($)E9F]R92!A;GD@8V]M;6ET('1O
M($-64R!B92!S=7)E('1O(')U;B!T:&4*=&5S=',@86YD(&YO=&AI;F<@9V]T
M(&)R;VME;B!W:71H('1H92!C:&%N9V4N"@I)9B!Y;W4@9V5T('1H92!M97-S
M86=E(")32TE0(BP@;65A;G,@=&AA="!T:&4@=&5S="!I="=S(&YO="!E>&5C
M=71E9"X*3&]O:R!A="!T:&4@1$(O=&5S=',O9')I=F5R+W-K:7!I9BYI;F,@
M=&\@<V5E('=H870G<R!T:&4@<')O8FQE;0HH<')O8F%B;'D@82!C;VYN96-T
M:6]N('!R;V)L96TI+@H*"D1"(%1%4U1%4B!-051225@*/3T]/3T]/3T]/3T]
M/3T]/0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9B<W%L("`@
M(&EF>"`@("!M<W-Q;"`@(&UY<W%L:2`@(&]D8F,@("!S<6QI=&4*5$535$52
M("`@("`@("`@("`@("`@("`@("`@(&1B87-E('P@:6)A<V4@?"`@;7-Q;"!\
M(&UY<W%L('P@(&]C:3@@?"!P9W-Q;"!\('-Y8F%S90I*;VAN($AO<G1O;B`@
M("`@("`@("`@("`@("`@("`M("`@+2`@("T@("!8("`@+2`@("T@("`M("`@
M+2`@("T@("`M("`@+2`@("T@("`M"E1I;2!::6-K=7,@("`@("`@("`@("`@
M("`@("`@("T@("`M("`@+2`@("T@("`M("`@+2`@("T@("`M("`@6"`@("T@
M("`M("`@+2`@("T*5&EM(%!A<FMI;B`@("`@("`@("`@("`@("`@("`@+2`@
M("T@("`M("`@+2`@("T@("`M("`@+2`@("T@("!8("`@+2`@("T@("`M("`@
M+0I0875L($=A<F1I;F5R("`@("`@("`@("`@("`@("`M("`@+2`@("T@("!8
M("`@+2`@("T@("`M("`@+2`@("T@("`M("`@+2`@("T@("`M"G!E=&5R=V)`
M:6%F<FEC82YC;VT@("`@("`@("`@("T@("`M("`@+2`@(%@@("`M("`@+2`@
M("T@("`M("`@+2`@("T@("`M("`@+2`@("T*1&%N:65L+"!!9&%M("`@("`@
M("`@("`@("`@("`@+2`@("T@("`M("`@+2`@("T@("`M("`@+2`@("T@("!8
M("`@+2`@("T@("`M("`@+0IS>FEI0'-Z:6ES;V9T+F-O;2`@("`@("`@("`@
M("`M("`@+2`@("T@("`M("`@+2`@("T@("`M("`@+2`@("T@("!8N2`@+2`@
M("T@("`M"FIM:#-`;&EN=7AF<F5A:RYC;VT@("`@("`@("`@("T@("`M("`@
M+2`@("T@("`M("`@+2`@("T@("`M("`@+2`@("T@("!8("`@+2`@("T*2V5V
M:6X@2&5N<FEK<V]N("`@("`@("`@("`@("`@+2`@("T@("`M("`@+2`@("T@
M("`M("`@+2`@("T@("!8("`@+2`@("T@("`M("`@+0I3=&EG($)A:VME;B`@
M("`@("`@("`@("`@("`@("`M("`@+2`@("T@("`M("`@+2`@("T@("!8("`@
M+2`@("T@("`M("`@6"`@("T@("`M"D-H=6-K($AA9V5N8G5C:"`@("`@("`@
M("`@("`@("T@("`M("`@+2`@("T@("`M("`@6"`@("T@("`M("`@+2`@("T@
M("`M("`@+2`@("T*3'5D;W9I8V\@36%G;F]C879A;&QO("`@("`@("`@+2`@
M("T@("!8("`@+2`@("T@("`M("`@+2`@("T@("`M("`@+2`@("T@("`M("`@
M+0I$86YI96P@0V]N=FES<V]R("`@("`@("`@("`@("!8("`@6"`@(%@@("`M
M("`@6"`@(%@@("!8("`@6"`@(%@@("!8LB`@6"`@(%@@("!8"@I-25-324Y'
M(%1%4U1%4E,@("`@("`@("`@("`@("`M("`@+2`@("T@("`M("`@+2`@("T@
M("`M("`@+2`@("T@("`M("`@+2`@("T@("`M"@I#;VUM96YT<SH*"ELQ73H@
M3T1"0R!U<VEN9R!)0DT@1$(R"ELR73H@3T1"0R!U<VEN9R!)0DT@1$(R(&%N
M9"!-4R!!8V-E<W,*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+V1O8W,O1$(O9&]C+TE$14%3````````````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#8U,S<@,3`U,34T,S,W,S`@,#(Q,C,P`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````$%B<W1R86-T960@
M5'EP97,@*%-T:6<I"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"@I$0B!N965D
M<R!A('-E="!O9B!T>7!E<R!R97!R97-E;G1I;F<@=&AE(&UO<W0@8V]M;6]N
M;'D@=7-E9"!T>7!E<R!I;@IA;&P@8F%C:V5N9',N("!4:&ES('1Y<&4@<V5T
M(&-O=6QD(&%L<V\@8F4@9V5A<F5D('1O=V%R9',@:6YT96=R871I;VX*=VET
M:"!T:&EN9W,@;&EK92!834PM4E!#+U-/05`@:6UP;&5M96YT871I;VYS+"!(
M5$U,(&9O<FT@8VQA<W-E<RP@971C+@H*4F5A;"!1=65R>2!087)S97(@*%-T
M:6<I"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H*5VET:"!A(')E86P@<75E
M<GD@<&%R<V5R+"!$0B!C86X@:6UP;&5M96YT(&UO<F4@;V8@:71S('!O<G1A
M8FEL:71Y"F)A<V5D(&]N('1H92!Q=65R>2P@:6YS=&5A9"!O9B!H879I;F<@
M<W5P<&]R="!F=6YC=&EO;G,@9F]R"F5V97)Y=&AI;F<N("!/;F4@97AA;7!L
M92!W;W5L9"!B92!,24U)5"P@86YO=&AE<B`B24Y315)4"BXN+B!215154DY)
M3D<B+@H*4&]R=&%B;&4@=')A;G-A8W1I;VYS("A3=&EG*0HM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM"@I)9B!$0B!C86X@<&%R<V4@<75E<FEE<R!E
M;F]U9V@@=&\@9&5T97)M:6YE('=H870@=&%B;&5S(&%R92!A9F9E8W1E9`IB
M>2!Q=65R:65S+"!I="!S:&]U;&0@8F4@<&]S<VEB;&4@=&\@;6%K92!A(')E
M<&QA>6%B;&4@=')A;G-A8W1I;VX*;&]G+B`@1TY/344@=7-E<R!A;B!834P@
M9F]R;6%T(&9O<B!C;VYF:6=U<F%T:6]N(&1A=&$@=&AA="!L971S('EO=0IC
M:&5C:W!O:6YT('-T871E(&]N8V4@:6X@82!W:&EL92P@86YD(')E=F5R="!T
M;R!T:&%T('-T871E(&QA=&5R+@I7:71H(&$@<VEM:6QA<B!A<'!R;V%C:"!F
M;W(@=')A;G-A8W1I;VYS(&EN($1"('=E(&-A;B!I;7!L96UE;G0*<&]R=&%B
M;&4@=')A;G-A8W1I;VYS(&%N9"!C:&5C:W!O:6YT:6YG(&5V96X@9F]R('1H
M92!D871A8F%S97,@=&AA=`ID;VXG="!S=7!P;W)T('1H96TN"@H*17)R;W(@
M<F5P;W)T:6YG(&-L96%N+75P+V1E8G5G("A4;VUA<RD*+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0I.;W<@96%C:"!D<FEV97(@:&%S
M(&ET<R!O=VX@<F%I<V5%<G)O<B!M971H;V0L(&-O;6UO;B!H87,@82!R86ES
M945R<F]R(&%N9`I$0B!H87,@82!$0E]E<G)O<B!C;&%S<R!A;F0@:71S(&]W
M;B!I<T5R<F]R*"D@;65T:&]D+B!4:&ES(&5R<F]R('-T=69F(`IO=F5R:&5A
M9"!C;W5L9"!B92!S:6UP;&EF:65D('=I=&@@;VYL>2!O;F4@<F%I<V5%<G)O
M<BP@9')O<&EN9R!T:&4@1$(@17)R;W(*8VQA<W,@86YD(&%L<V\@=&AE($1"
M.CII<T5R<F]R*"D@*'5S92!T:&4@4$5!4BYP:'`@;VYE<R!I;G-T96%D*2X*
M3W1H97(@:61E82!C;W5L9"!B92!T;R!A9&0@82!S>7-T96T@9F]R(&%L;&]W
M:6YG('!E;W!L92!A8V-E<W,@=&\@86QL('1H90IQ=65R:65S('-E;F1E9"!B
M>2!014%2($1"('1O('1H92!B86-K96YD+B!!;'-O(&$@;F5W(%!%05)?15)2
M3U)?1$5"54<*9FQA9R!T:&%T(&%U=&]M871I8V%L;'D@*'-H;W=\=')I9V=E
M<G,I(&1E8G5G(&EN9F\L('!E<FAA<',*=VET:"!A(&YE=R!014%27RA787)N
M:6YG?$1E8G5G*2!O8FIE8W0N"@I1=6]T92!C;&5A;BUU<"`H4W1I9RD*+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM"C$N($ME97`@<75O=&4@86YD('%U;W1E4W1R
M:6YG+"!B=70@;6]V92!Q=6]T:6YG(&]F('-T<FEN9W,@8F%C:R!I;G1O"B`@
M('%U;W1E4W1R:6YG(&%N9"!M86ME('%U;W1E(&-A;&P@:70@9F]R('-T<FEN
M9W,N"@HR+B!!9&0@86X@;W!T:6]N86P@(F]P97)A=&]R(B!P87)A;65T97(@
M=&\@<75O=&4@=&AA="!I<R!O;F4@;V8@(CTB+`H@("`B/"(L("(^(B!O<B`B
M/#XB('1H870@=VEL;"!B92!I;G-E<G1E9"!I;B!F<F]N="!O9B!T:&4@<75O
M=&5D('9A;'5E"B`@('5N;&5S<R!I="!I<R!.54Q,+"!I;B!W:&EC:"!C87-E
M(&ET('=I;&P@8F4@8V]N=F5R=&5D('1O("))4R(@*&9O<@H@("`B/2(I(&]R
M("))4R!.3U0B("AF;W(@=&AE(&]T:&5R<RDN"@I!=71O(&9R964@<W1A=&5M
M96YT<R`H5&]M87,I"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*0GD@
M<V5T=&EN9R!A('!A<F%M(&EN('%U97)Y*"D@;W(@9F]R('1H92!H;VQE($1"
M(&EN<W1A;F-E+"!014%2($1""F-O=6QD(&%U=&\M9G)E92!R97-U;'1S(&EN
M($1"7W)E<W5L="T^9F5T8V@H26YT;WQ2;W<I('=H96X@=&AE(&1R:79E<@IR
M971U<FYS(&9A;'-E+@H*1&%T871Y<&5S(&EN('!R97!A<F4@<WEN=&%X("A4
M;VUA<RD*+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*17AT
M96YD('1H92!A8W1U86P@<')E<&%R92]E>&5C=71E('!L86-E:&]L9&5R<R!T
M;R!S=7!P;W)T(&1A=&$@='EP97,L(&)O=&@*=&\@8VAE8VL@=&AE(&1A=&$@
M:6YT<F]D=6-E9"!T;R!T:&4@<75E<GD@86YD('1O(")C87-T(B!T:&4@<F5S
M=6QT"G1O(&YA=&EV92!P:'`@9&%T82!T>7!E<RX@17@Z"@HD<W%L(#T@(DE.
M4T525"!)3E1/('1A8FQE(%9!3%5%4R`H>WMI;G0H-"E]?2P@>WMB;V]L?7TL
M('M[9&%T92@G62UM+60G*7U]*2(["B1R;W<@/2`D9&(M/G%U97)Y*"1S<6PL
M(&%R<F%Y*#@L("=T)RP@)S(P,#$M,#0M,2<I*3L*"D9O<FUA=#H@>WL\9&%T
M85]T>7!E/B@\<&%R86TQ/BP\<&%R86TR/BE]?0H*(G!A<F%M(B!C;W5L9"!B
M92!T:&4@;6%X(&QE;F=H="!O9B!T:&4@9&%T82P@9&%T92!F;W)M871S+"!N
M;W1?;G5L;`IC:&5C:W,@;W(@9&5F875L="!V86QU97,N"@I/=&AE<B!I9&5A
M<R!C;W5L9"!B93H*"C$I"B1S<6P@/2`B24Y315)4($E.5$\@=&%B;&4@5D%,
M5453("@_+"`_+"`_*2(["B1S=&@@/2`D9&(M/G!R97!A<F4H)'-Q;"P@87)R
M87DH)VEN="@T*2<L("=B;V]L)RP@)V1A=&4G*3L*)')E<R`]("1D8BT^97AE
M8W5T92@D<W1H+"!A<G)A>2@D82P@)&(L("1C*3L*"C(I"B1S<6P@/2`B24Y3
M15)4($E.5$\@=&%B;&4@5D%,5453("@_+"`_+"`_*2(["B1P87)A;7,@/2!A
M<G)A>2@*"3`@/3X@87)R87DH)&$L("=I;G0H-"DG*2P*"3$@/3X@87)R87DH
M)&(L("=B;V]L)RD**3L*)')E<R`]("1D8BT^<75E<GDH)'-Q;"P@)'!A<F%M
M<RD["@I!=71O(&-O;FYE8W0@9F5A='5R92`H5&]M87,I"BTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2T*061D('1H92!A8FEL:71Y('1O(&-R96%T92!F
M;W(@97AA;7!L92!A(&QI9VAT(&%N9"!D=6UP($1"(&]B:F5C="!W:&EC:`IW
M:6QL(&]N;'D@<V5T('5P('1H92!C;VYN96-T:6]N('=H96X@;F5E9&5D+B!7
M:71H('1H870@<&5O<&QE(&-O=6QD"F-R96%T92!T:&4@1$(@;V)J96-T(&EN
M(&$@8V]M;6]N('!R97!E;F0@;W(@9&5F875L="!F:6QE('=I=&AO=70@=&AE
M"FYE960@=&\@=V%S=&4@<WES=&5M(')E<V]U<F-E<R!I9B!T:&4@=7-E(&]F
M('1H92!D871A8F%S92!I<R!F:6YA;&QY"FYO="!N965D960N"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]D;V-S+TYE=%]33510````````````````````````````````````````
M`````````````````````````````````````#`P,#<U-2``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S,P(#`R,#<R-0`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+V1O8W,O3F5T7U--5%`O9&]C<P``````````
M````````````````````````````````````````````````````````````
M,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W
M,S`@,#(Q-C4U`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R].971?
M4TU44"]D;V-S+V5X86UP;&5S````````````````````````````````````
M```````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#`P,"`Q,#4Q-30S,S<S,"`P,C,T-S,`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]D;V-S+TYE=%]33510+V1O8W,O97AA;7!L97,O8F%S:6,N<&AP
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`Q-S8U(#$P-3$U-#,S-S,P(#`R-3,U-0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`H*<F5Q=6ER92`G3F5T+U--5%`N<&AP)SL*"B1H;W-T(#T@)VUA:6PN97AA
M;7!L92YC;VTG.PHD9G)O;2`]("=U<V5R0&5X86UP;&4N8V]M)SL*)')C<'0@
M/2!A<G)A>2@G<F5C:7!I96YT,4!E>&%M<&QE+F-O;2<L("=R96-I<&EE;G0R
M0&5X86UP;&4N8V]M)RD["B1S=6)J(#T@(E-U8FIE8W0Z(%1E<W0@365S<V%G
M95QN(CL*)&)O9'D@/2`B0F]D>2!,:6YE(#%<;D)O9'D@3&EN92`R(CL*"B\J
M($-R96%T92!A(&YE=R!.971?4TU44"!O8FIE8W0N("HO"FEF("@A("@D<VUT
M<"`](&YE=R!.971?4TU44"@D:&]S="DI*2!["B`@("!D:64H(E5N86)L92!T
M;R!I;G-T86YT:6%T92!.971?4TU44"!O8FIE8W1<;B(I.PI]"@HO*B!#;VYN
M96-T('1O('1H92!33510('-E<G9E<BX@*B\*:68@*%!%05(Z.FES17)R;W(H
M)&4@/2`D<VUT<"T^8V]N;F5C="@I*2D@>PH@("`@9&EE*"1E+3YG971-97-S
M86=E*"D@+B`B7&XB*3L*?0H*+RH@4V5N9"!T:&4@)TU!24P@1E)/33HG(%--
M5%`@8V]M;6%N9"X@*B\*:68@*%!%05(Z.FES17)R;W(H)'-M='`M/FUA:6Q&
M<F]M*"1F<F]M*2DI('L*("`@(&1I92@B56YA8FQE('1O('-E="!S96YD97(@
M=&\@/"1F<F]M/EQN(BD["GT*"B\J($%D9')E<W,@=&AE(&UE<W-A9V4@=&\@
M96%C:"!O9B!T:&4@<F5C:7!I96YT<RX@*B\*9F]R96%C:"`H)')C<'0@87,@
M)'1O*2!["B`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S(#T@)'-M='`M/G)C
M<'14;R@D=&\I*2D@>PH@("`@("`@(&1I92@B56YA8FQE('1O(&%D9"!R96-I
M<&EE;G0@/"1T;SXZ("(@+B`D<F5S+3YG971-97-S86=E*"D@+B`B7&XB*3L*
M("`@('T*?0H*+RH@4V5T('1H92!B;V1Y(&]F('1H92!M97-S86=E+B`J+PII
M9B`H4$5!4CHZ:7-%<G)O<B@D<VUT<"T^9&%T82@D<W5B:B`N(")<<EQN(B`N
M("1B;V1Y*2DI('L*("`@(&1I92@B56YA8FQE('1O('-E;F0@9&%T85QN(BD[
M"GT*"B\J($1I<V-O;FYE8W0@9G)O;2!T:&4@4TU44"!S97)V97(N("HO"B1S
M;71P+3YD:7-C;VYN96-T*"D["@``````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]D;V-S+TYE=%]33510+V1O8W,O9W5I9&4N='AT````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$T,S0R(#$P-3$U-#,S-S,P(#`R
M,S4W-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B!4:&4@3F5T7U--5%`@4&%C:V%G
M90H]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"@HM+2TM+2TM+2TM+2TM+2TM+2TM
M+0H@57-E<B!$;V-U;65N=&%T:6]N"BTM+2TM+2TM+2TM+2TM+2TM+2TM"@HZ
M075T:&]R.B`@("!*;VX@4&%R:7-E"CI#;VYT86-T.B`@(&IO;D!P:'`N;F5T
M"CI$871E.B`@("`@("1$871E.B`R,#`U+S`S+S`T(#`S.C,U.C0U("0*.E)E
M=FES:6]N.B`@)%)E=FES:6]N.B`Q+C4@)`H*+BX@8V]N=&5N=',Z.B!486)L
M92!O9B!#;VYT96YT<PHN+B!S96-T:6]N+6YU;6)E<FEN9SHZ"@I$97!E;F1E
M;F-I97,*/3T]/3T]/3T]/3T]"@I4:&4@8%!%05)?17)R;W)@($-L87-S"BTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2T*"E1H92!.971?4TU44"!P86-K86=E('5S
M97,@=&AE(&!014%27T5R<F]R8%\@8VQA<W,@9F]R(&%L;"!O9B!I=',@8&5R
M<F]R"FAA;F1L:6YG8%\N"@I4:&4@8$YE=%]3;V-K971@(%!A8VMA9V4*+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM"@I4:&4@3F5T7U-O8VME=%\@<&%C:V%G
M92!I<R!U<V5D(&%S('1H92!B87-I<R!F;W(@86QL(&YE='=O<FL@8V]M;75N
M:6-A=&EO;G,N"@I4:&4@8$%U=&A?4T%33&`@4&%C:V%G90HM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+0H*5&AE(&!!=71H7U-!4TQ@7R!P86-K86=E(&ES(&%N
M(&]P=&EO;F%L(&1E<&5N9&5N8WDN("!)9B!I="!I<R!A=F%I;&%B;&4L('1H
M90I.971?4TU44"!P86-K86=E('=I;&P@8F4@86)L92!T;R!S=7!P;W)T('1H
M92!$24=%4U0M340U7R!A;F0@0U)!32U-1#5?(%--5%`*875T:&5N=&EC871I
M;VX@;65T:&]D<RX@($]T:&5R=VES92P@;VYL>2!T:&4@3$]'24Y?(&%N9"!0
M3$%)3E\@;65T:&]D<R!W:6QL"F)E(&%V86EL86)L92X*"D5R<F]R($AA;F1L
M:6YG"CT]/3T]/3T]/3T]/3T]"@I!;&P@;V8@=&AE($YE=%]33510(&-L87-S
M)W,@<'5B;&EC(&UE=&AO9',@<F5T=7)N(&$@4$5!4E]%<G)O<E\@;V)J96-T
M(&EF(&%N"F5R<F]R(&]C8W5R<RX@(%1H92!S=&%N9&%R9"!W87D@=&\@8VAE
M8VL@9F]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@:7,@8GD@=7-I;F<*8%!%05(Z
M.FES17)R;W(H*6!?.CH*"B`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@
M/2`D<VUT<"T^8V]N;F5C="@I*2D@>PH@("`@("`@(&1I92@D97)R;W(M/F=E
M=$UE<W-A9V4H*2D["B`@("!]"@HN+B!?4$5!4CHZ:7-%<G)O<B@I.B!H='1P
M.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]C;W)E+G!E87(N<&5A<BYI<V5R
M<F]R+G!H<`H*4TU44"!!=71H96YT:6-A=&EO;@H]/3T]/3T]/3T]/3T]/3T]
M/3T]"@I4:&4@3F5T7U--5%`@<&%C:V%G92!S=7!P;W)T<R!T:&4@4TU44"!A
M=71H96YT:6-A=&EO;B!S=&%N9&%R9"`H87,@9&5F:6YE9`IB>2!21D,M,C4U
M-%\I+B`@5&AE($YE=%]33510('!A8VMA9V4@<W5P<&]R=',@=&AE(&9O;&QO
M=VEN9R!A=71H96YT:6-A=&EO;@IM971H;V1S+"!I;B!O<F1E<B!O9B!P<F5F
M97)E;F-E.@H*+BX@7U)&0RTR-34T.B!H='1P.B\O=W=W+FEE=&8N;W)G+W)F
M8R]R9F,R-34T+G1X=`H*1$E'15-4+4U$-0HM+2TM+2TM+2TM"@I4:&4@1$E'
M15-4+4U$-2!A=71H96YT:6-A=&EO;B!M971H;V0@=7-E<R!@4E-!($1A=&$@
M4V5C=7)I='D@26YC+F!?)W,@340U"DUE<W-A9V4@1&EG97-T(&%L9V]R:71H
M;2X@($ET(&ES(&-O;G-I9&5R960@=&AE(&UO<W0@<V5C=7)E(&UE=&AO9"!O
M9B!33510"F%U=&AE;G1I8V%T:6]N+@H**BI.;W1E.BHJ(%1H92!$24=%4U0M
M340U(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"!I<R!O;FQY('-U<'!O<G1E9"!I
M9B!T:&4*05542%]305-,7R!P86-K86=E(&ES(&%V86EL86)L92X*"BXN(%]2
M4T$@1&%T82!396-U<FET>2!);F,N.B!H='1P.B\O=W=W+G)S87-E8W5R:71Y
M+F-O;2\*"D-204TM340U"BTM+2TM+2TM"@I4:&4@0U)!32U-1#4@875T:&5N
M=&EC871I;VX@;65T:&]D(&AA<R!B965N('-U<&5R<V5D960@8GD@=&AE($1)
M1T535"U-1#5?"FUE=&AO9"!I;B!T97)M<R!O9B!S96-U<FET>2X@($ET(&ES
M('!R;W9I9&5D(&AE<F4@9F]R(&-O;7!A=&EB:6QI='D@=VET:`IO;&1E<B!3
M3510('-E<G9E<G,@=&AA="!M87D@;F]T('-U<'!O<G0@=&AE(&YE=V5R($1)
M1T535"U-1#4@86QG;W)I=&AM+@H**BI.;W1E.BHJ(%1H92!#4D%-+4U$-2!A
M=71H96YT:6-A=&EO;B!M971H;V0@:7,@;VYL>2!S=7!P;W)T960@:68@=&AE
M"D%55$A?4T%33%\@<&%C:V%G92!I<R!A=F%I;&%B;&4N"@I,3T=)3@HM+2TM
M+0H*5&AE($Q/1TE.(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"!E;F-R>7!T<R!T
M:&4@=7-E<B=S('!A<W-W;W)D('5S:6YG('1H90I"87-E-C1?(&5N8V]D:6YG
M('-C:&5M92X@($)E8V%U<V4@9&5C<GEP=&EN9R!A($)A<V4V-"UE;F-O9&5D
M('-T<FEN9R!I<PIT<FEV:6%L+"!,3T=)3B!I<R!N;W0@8V]N<VED97)E9"!A
M('-E8W5R92!A=71H96YT:6-A=&EO;B!M971H;V0@86YD('-H;W5L9`IB92!A
M=F]I9&5D+@H*+BX@7T)A<V4V-#H@:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A
M;"]E;B]F=6YC=&EO;BYB87-E-C0M96YC;V1E+G!H<`H*4$Q!24X*+2TM+2T*
M"E1H92!03$%)3B!A=71H96YT:6-A=&EO;B!M971H;V0@<V5N9',@=&AE('5S
M97(G<R!P87-S=V]R9"!I;B!P;&%I;B!T97AT+@I4:&ES(&UE=&AO9"!O9B!A
M=71H96YT:6-A=&EO;B!I<R!N;W0@<V5C=7)E(&%N9"!S:&]U;&0@8F4@879O
M:61E9"X*"E-E8W5R92!#;VYN96-T:6]N<PH]/3T]/3T]/3T]/3T]/3T]/3T*
M"DEF(&!S96-U<F4@<V]C:V5T('1R86YS<&]R='-@7R!H879E(&)E96X@96YA
M8FQE9"!I;B!02%`L(&ET(&ES('!O<W-I8FQE('1O"F5S=&%B;&ES:"!A('-E
M8W5R92!C;VYN96-T:6]N('1O('1H92!R96UO=&4@4TU44"!S97)V97(Z.@H*
M("`@("1S;71P(#T@;F5W($YE=%]33510*"=S<VPZ+R]M86EL+F5X86UP;&4N
M8V]M)RP@-#8U*3L*"E1H:7,@97AA;7!L92!C;VYN96-T<R!T;R!@;6%I;"YE
M>&%M<&QE+F-O;6`@;VX@<&]R="`T-C4@*&$@8V]M;6]N(%--5%!3"G!O<G0I
M('5S:6YG('1H92!@<W-L.B\O8"!T<F%N<W!O<G0N"@HN+B!?<V5C=7)E('-O
M8VME="!T<F%N<W!O<G1S.B!H='1P.B\O=W=W+G!H<"YN970O=')A;G-P;W)T
M<PH*1&%T82!1=6]T:6YG"CT]/3T]/3T]/3T]/0H*0GD@9&5F875L="P@86QL
M(&]U=&)O=6YD('-T<FEN9R!D871A(&ES('%U;W1E9"!I;B!A8V-O<F1A;F-E
M('=I=&@@4TU44`IS=&%N9&%R9',N("!4:&ES(&UE86YS('1H870@86QL(&YA
M=&EV92!5;FEX("A@7%QN8"D@86YD($UA8R`H8%Q<<F`I(&QI;F4*96YD:6YG
M<R!A<F4@8V]N=F5R=&5D('1O($EN=&5R;F5T+7-T86YD87)D($-23$8@*&!<
M7')<7&Y@*2!L:6YE(&5N9&EN9W,N"D%L<V\L(&)E8V%U<V4@=&AE(%--5%`@
M<')O=&]C;VP@=7-E<R!A('-I;F=L92!L96%D:6YG('!E<FEO9"`H8"Y@*2!T
M;R!S:6=N86P*86X@96YD('1O('1H92!M97-S86=E(&1A=&$L('-I;F=L92!L
M96%D:6YG('!E<FEO9',@:6X@=&AE(&]R:6=I;F%L(&1A=&$*<W1R:6YG(&%R
M92`B9&]U8FQE9"(@*&4N9RX@(F`N+F`B*2X*"E1H97-E('-T<FEN9R!T<F%N
M<V9O<FUA=&EO;B!C86X@8F4@97AP96YS:79E('=H96X@;&%R9V4@8FQO8VMS
M(&]F(&1A=&$@87)E"FEN=F]L=F5D+B`@1F]R(&5X86UP;&4L('1H92!.971?
M4TU44"!P86-K86=E(&ES(&YO="!A=V%R92!O9B!-24U%('!A<G1S("AI=`IJ
M=7-T('-E97,@=&AE($U)344@;65S<V%G92!A<R!O;F4@8FEG('-T<FEN9R!O
M9B!C:&%R86-T97)S*2P@<V\@:70@:7,@;F]T"F%B;&4@=&\@<VMI<"!N;VXM
M=&5X="!A='1A8VAM96YT<R!W:&5N('-E87)C:&EN9R!F;W(@8VAA<F%C=&5R
M<R!T:&%T(&UA>0IN965D('1O(&)E('%U;W1E9"X*"D)E8V%U<V4@;V8@=&AI
M<RP@:70@:7,@<&]S<VEB;&4@=&\@97AT96YD('1H92!.971?4TU44"!C;&%S
M<R!I;B!O<F1E<B!T;PII;7!L96UE;G0@>6]U<B!O=VX@8W5S=&]M('%U;W1I
M;F<@<F]U=&EN92X@($IU<W0@8W)E871E(&$@;F5W(&-L87-S(&)A<V5D(&]N
M"G1H92!.971?4TU44"!C;&%S<R!A;F0@<F5I;7!L96UE;G0@=&AE(&!Q=6]T
M961A=&$H*6`@;65T:&]D.CH*"B`@("!R97%U:7)E("=.971?4TU44"YP:'`G
M.PH*("`@(&-L87-S($YE=%]335107V-U<W1O;2!E>'1E;F1S($YE=%]33510
M"B`@("!["B`@("`@("`@9G5N8W1I;VX@<75O=&5D871A*"1D871A*0H@("`@
M("`@('L*("`@("`@("`@("`@+RH@4&5R9F]R;2!C=7-T;VT@9&%T82!Q=6]T
M:6YG("HO"B`@("`@("`@?0H@("`@?0H*3F]T92!T:&%T('1H92!@)&1A=&%@
M('!A<F%M971E<B!W:6QL(&)E('!A<W-E9"!T;R!T:&4@8'%U;W1E9&%T82@I
M8"!F=6YC=&EO;@I@8GD@<F5F97)E;F-E8%\N("!4:&ES(&UE86YS('1H870@
M>6]U(&-A;B!O<&5R871E(&1I<F5C=&QY(&]N(&`D9&%T86`N("!)=`IA;'-O
M('1H92!O=F5R:&5A9"!O9B!C;W!Y:6YG(&$@;&%R9V4@8"1D871A8"!S=')I
M;F<@=&\@86YD(&9R;VT@=&AE"F!Q=6]T961A=&$H*6`@;65T:&]D+@H*+BX@
M7V)Y(')E9F5R96YC93H@:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A;"]E;B]L
M86YG=6%G92YR969E<F5N8V5S+G!A<W,N<&AP"@I$96)U9V=I;F<*/3T]/3T]
M/3T]"@I4:&4@3F5T7U--5%`@<&%C:V%G92!C;VYT86EN<R!B=6EL="UI;B!D
M96)U9V=I;F<@;W5T<'5T(')O=71I;F5S("AD:7-A8FQE9`IB>2!D969A=6QT
M*2X@($1E8G5G9VEN9R!O=71P=70@;75S="!B92!E>'!L:6-I=&QY(&5N86)L
M960@=FEA('1H92!S971$96)U9R@I"FUE=&AO9#HZ"@H@("`@)'-M='`M/G-E
M=$1E8G5G*'1R=64I.PH*5&AE(&1E8G5G9VEN9R!M97-S86=E<R!W:6QL(&)E
M('-E;G0@=&\@=&AE('-T86YD87)D(&]U='!U="!S=')E86TN"@I%>&%M<&QE
M<PH]/3T]/3T]/0H*0F%S:6,@57-E"BTM+2TM+2TM+0H*5&AE(&9O;&QO=VEN
M9R!S8W)I<'0@9&5M;VYS=')A=&5S(&AO=R!A('-I;7!L92!E;6%I;"!M97-S
M86=E(&-A;B!B92!S96YT"G5S:6YG('1H92!.971?4TU44"!P86-K86=E.CH*
M"B`@("!R97%U:7)E("=.970O4TU44"YP:'`G.PH*("`@("1H;W-T(#T@)VUA
M:6PN97AA;7!L92YC;VTG.PH@("`@)&9R;VT@/2`G=7-E<D!E>&%M<&QE+F-O
M;2<["B`@("`D<F-P="`](&%R<F%Y*"=R96-I<&EE;G0Q0&5X86UP;&4N8V]M
M)RP@)W)E8VEP:65N=#)`97AA;7!L92YC;VTG*3L*("`@("1S=6)J(#T@(E-U
M8FIE8W0Z(%1E<W0@365S<V%G95QN(CL*("`@("1B;V1Y(#T@(D)O9'D@3&EN
M92`Q7&Y";V1Y($QI;F4@,B(["@H@("`@+RH@0W)E871E(&$@;F5W($YE=%]3
M3510(&]B:F5C="X@*B\*("`@(&EF("@A("@D<VUT<"`](&YE=R!.971?4TU4
M4"@D:&]S="DI*2!["B`@("`@("`@9&EE*")5;F%B;&4@=&\@:6YS=&%N=&EA
M=&4@3F5T7U--5%`@;V)J96-T7&XB*3L*("`@('T*"B`@("`O*B!#;VYN96-T
M('1O('1H92!33510('-E<G9E<BX@*B\*("`@(&EF("A014%2.CII<T5R<F]R
M*"1E(#T@)'-M='`M/F-O;FYE8W0H*2DI('L*("`@("`@("!D:64H)&4M/F=E
M=$UE<W-A9V4H*2`N(")<;B(I.PH@("`@?0H*("`@("\J(%-E;F0@=&AE("=-
M04E,($923TTZ)R!33510(&-O;6UA;F0N("HO"B`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D<VUT<"T^;6%I;$9R;VTH)&9R;VTI*2D@>PH@("`@("`@(&1I92@B
M56YA8FQE('1O('-E="!S96YD97(@=&\@/"1F<F]M/EQN(BD["B`@("!]"@H@
M("`@+RH@061D<F5S<R!T:&4@;65S<V%G92!T;R!E86-H(&]F('1H92!R96-I
M<&EE;G1S+B`J+PH@("`@9F]R96%C:"`H)')C<'0@87,@)'1O*2!["B`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)')E<R`]("1S;71P+3YR8W!T5&\H)'1O
M*2DI('L*("`@("`@("`@("`@9&EE*")5;F%B;&4@=&\@861D(')E8VEP:65N
M="`\)'1O/CH@(B`N("1R97,M/F=E=$UE<W-A9V4H*2`N(")<;B(I.PH@("`@
M("`@('T*("`@('T*"B`@("`O*B!3970@=&AE(&)O9'D@;V8@=&AE(&UE<W-A
M9V4N("HO"B`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<VUT<"T^9&%T82@D<W5B
M:B`N(")<<EQN(B`N("1B;V1Y*2DI('L*("`@("`@("!D:64H(E5N86)L92!T
M;R!S96YD(&1A=&%<;B(I.PH@("`@?0H*("`@("\J($1I<V-O;FYE8W0@9G)O
M;2!T:&4@4TU44"!S97)V97(N("HO"B`@("`D<VUT<"T^9&ES8V]N;F5C="@I
M.PH*+BX@7U!%05)?17)R;W(Z(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L
M+V5N+V-O<F4N<&5A<BYP96%R+65R<F]R+G!H<`HN+B!?3F5T7U-O8VME=#H@
M:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+TYE=%]3;V-K970*+BX@7T%U
M=&A?4T%33#H@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T%U=&A?4T%3
M3`H*+BX@=FEM.B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P
M/30@97AP86YD=&%B('1E>'1W:61T:#TW-CH*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4&%R<V5R````
M````````````````````````````````````````````````````````````
M```````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q
M,#4Q-30S,S<S,"`P,C$S,3``(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D
M;V-S+UA-3%]087)S97(O97AA;7!L97,`````````````````````````````
M`````````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S,P(#`R,S$R-@`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U!A<G-E<B]E>&%M<&QE<R]X;6Q?
M<&%R<V5R7V9I;&4N<&AP````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P,S(@,3`U,34T,S,W,S`@
M,#(W,#8V`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_4$A0"B\J*@H@*B!E>&%M<&QE(&9O<B!834Q?4&%R<V5R7U-I;7!L
M90H@*@H@*B!`875T:&]R("`@("`@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P
M:'`M=&]O;',N;F5T/@H@*B!`<&%C:V%G92`@("`@6$U,7U!A<G-E<@H@*B!`
M<W5B<&%C:V%G92`@17AA;7!L97,*("HO"@HO*BH*("H@<F5Q=6ER92!T:&4@
M<&%R<V5R"B`J+PIR97%U:7)E7V]N8V4@)UA-3"]087)S97(N<&AP)SL*"F-L
M87-S(&UY4&%R<V5R(&5X=&5N9',@6$U,7U!A<G-E<@I["@H@("`@9G5N8W1I
M;VX@;7E087)S97(H*0H@("`@>PH@("`@("`@('!A<F5N=#HZ6$U,7U!A<G-E
M<B@I.PH@("`@?0H*("`@+RHJ"B`@("`J(&AA;F1L92!S=&%R="!E;&5M96YT
M"B`@("`J"B`@("`J($!A8V-E<W,@("!P<FEV871E"B`@("`J($!P87)A;2`@
M("!R97-O=7)C92`@("!X;6P@<&%R<V5R(')E<V]U<F-E"B`@("`J($!P87)A
M;2`@("!S=')I;F<@("`@("!N86UE(&]F('1H92!E;&5M96YT"B`@("`J($!P
M87)A;2`@("!A<G)A>2`@("`@("!A='1R:6)U=&5S"B`@("`J+PH@("`@9G5N
M8W1I;VX@<W1A<G1(86YD;&5R*"1X<"P@)&YA;64L("1A='1R:6)S*0H@("`@
M>PH@("`@("`@('!R:6YT9B@G:&%N9&QE('-T87)T('1A9SH@)7,\8G(@+SXG
M+"`D;F%M92D["B`@("!]"@H@("`O*BH*("`@("H@:&%N9&QE('-T87)T(&5L
M96UE;G0*("`@("H*("`@("H@0&%C8V5S<R`@('!R:79A=&4*("`@("H@0'!A
M<F%M("`@(')E<V]U<F-E("`@('AM;"!P87)S97(@<F5S;W5R8V4*("`@("H@
M0'!A<F%M("`@('-T<FEN9R`@("`@(&YA;64@;V8@=&AE(&5L96UE;G0*("`@
M("H@0'!A<F%M("`@(&%R<F%Y("`@("`@(&%T=')I8G5T97,*("`@("HO"B`@
M("!F=6YC=&EO;B!E;F1(86YD;&5R*"1X<"P@)&YA;64I"B`@("!["B`@("`@
M("`@<')I;G1F*"=H86YD;&4@96YD('1A9SH@)7,\8G(@+SXG+"`D;F%M92D[
M"B`@("!]"GT*"B1P(#T@)FYE=R!M>5!A<G-E<B@I.PH*)')E<W5L="`]("1P
M+3YS971);G!U=$9I;&4H)WAM;%]P87)S97)?9FEL92YX;6PG*3L*)')E<W5L
M="`]("1P+3YP87)S92@I.PH_/@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]8
M34Q?4&%R<V5R+V5X86UP;&5S+WAM;%]P87)S97)?:&%N9&QE<BYP:'``````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,3<W-B`Q,#4Q-30S,S<S,"`P,C<V,#(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]02%`*+RHJ"B`J(&5X86UP
M;&4@9F]R(%A-3%]087)S97)?4VEM<&QE"B`J"B`J($!A=71H;W(@("`@("!3
M=&5P:&%N(%-C:&UI9'0@/'-C:'-T0'!H<"UT;V]L<RYN970^"B`J($!P86-K
M86=E("`@("!834Q?4&%R<V5R"B`J($!S=6)P86-K86=E("!%>&%M<&QE<PH@
M*B\*"B\J*@H@*B!R97%U:7)E('1H92!P87)S97(*("HO"G)E<75I<F5?;VYC
M92`G6$U,+U!A<G-E<BYP:'`G.PH*8VQA<W,@;7E(86YD;&5R"GL*("`@+RHJ
M"B`@("`J(&AA;F1L92!S=&%R="!E;&5M96YT"B`@("`J"B`@("`J($!A8V-E
M<W,@("!P<FEV871E"B`@("`J($!P87)A;2`@("!R97-O=7)C92`@("!X;6P@
M<&%R<V5R(')E<V]U<F-E"B`@("`J($!P87)A;2`@("!S=')I;F<@("`@("!N
M86UE(&]F('1H92!E;&5M96YT"B`@("`J($!P87)A;2`@("!A<G)A>2`@("`@
M("!A='1R:6)U=&5S"B`@("`J+PH@("`@9G5N8W1I;VX@<W1A<G1(86YD;&5R
M*"1X<"P@)&YA;64L("1A='1R:6)S*0H@("`@>PH@("`@("`@('!R:6YT9B@G
M:&%N9&QE('-T87)T('1A9SH@)7,\8G(@+SXG+"`D;F%M92D["B`@("!]"@H@
M("`O*BH*("`@("H@:&%N9&QE('-T87)T(&5L96UE;G0*("`@("H*("`@("H@
M0&%C8V5S<R`@('!R:79A=&4*("`@("H@0'!A<F%M("`@(')E<V]U<F-E("`@
M('AM;"!P87)S97(@<F5S;W5R8V4*("`@("H@0'!A<F%M("`@('-T<FEN9R`@
M("`@(&YA;64@;V8@=&AE(&5L96UE;G0*("`@("H@0'!A<F%M("`@(&%R<F%Y
M("`@("`@(&%T=')I8G5T97,*("`@("HO"B`@("!F=6YC=&EO;B!E;F1(86YD
M;&5R*"1X<"P@)&YA;64I"B`@("!["B`@("`@("`@<')I;G1F*"=H86YD;&4@
M96YD('1A9SH@)7,\8G(@+SXG+"`D;F%M92D["B`@("!]"GT*"B1P(#T@)FYE
M=R!834Q?4&%R<V5R*"D["B1H(#T@)FYE=R!M>4AA;F1L97(H*3L*"B1R97-U
M;'0@/2`D<"T^<V5T26YP=71&:6QE*"=X;6Q?<&%R<V5R7V9I;&4N>&UL)RD[
M"B1R97-U;'0@/2`D<"T^<V5T2&%N9&QE<D]B:B@D:"D["B1R97-U;'0@/2`D
M<"T^<&%R<V4H*3L*/SX``'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M9&]C<R]834Q?4&%R<V5R+V5X86UP;&5S+WAM;%]P87)S97)?<VEM<&QE,2YP
M:'`````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,C$V-B`Q,#4Q-30S,S<S,"`P,C<U,S$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]02%`*+RHJ"B`J
M(&5X86UP;&4@9F]R(%A-3%]087)S97)?4VEM<&QE"B`J"B`J("1)9#H@>&UL
M7W!A<G-E<E]S:6UP;&4Q+G!H<"QV(#$N,R`R,#`T+S`U+S(X(#$V.C`Y.C0X
M('-C:'-T($5X<"`D"B`J"B`J($!A=71H;W(@("`@("!3=&5P:&%N(%-C:&UI
M9'0@/'-C:'-T0'!H<"UT;V]L<RYN970^"B`J($!P86-K86=E("`@("!834Q?
M4&%R<V5R"B`J($!S=6)P86-K86=E("!%>&%M<&QE<PH@*B\*"B\J*@H@*B!R
M97%U:7)E('1H92!P87)S97(*("HO"G)E<75I<F5?;VYC92`G6$U,+U!A<G-E
M<B]3:6UP;&4N<&AP)SL*"F-L87-S(&UY4&%R<V5R(&5X=&5N9',@6$U,7U!A
M<G-E<E]3:6UP;&4*>PH@("`@9G5N8W1I;VX@;7E087)S97(H*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y834Q?4&%R<V5R7U-I;7!L92@I.PH@("`@?0H*("`@
M+RHJ"B`@("`J(&AA;F1L92!T:&4@96QE;65N=`H@("`@*@H@("`@*B!4:&4@
M96QE;65N="!W:6QL(&)E(&AA;F1L960L(&]N8V4@:70G<R!C;&]S960*("`@
M("H*("`@("H@0&%C8V5S<R`@('!R:79A=&4*("`@("H@0'!A<F%M("`@('-T
M<FEN9R`@("`@(&YA;64@;V8@=&AE(&5L96UE;G0*("`@("H@0'!A<F%M("`@
M(&%R<F%Y("`@("`@(&%T=')I8G5T97,@;V8@=&AE(&5L96UE;G0*("`@("H@
M0'!A<F%M("`@('-T<FEN9R`@("`@(&-H87)A8W1E<B!D871A(&]F('1H92!E
M;&5M96YT"B`@("`J+PH@("`@9G5N8W1I;VX@:&%N9&QE16QE;65N="@D;F%M
M92P@)&%T=')I8G,L("1D871A*0H@("`@>PH@("`@("`@('!R:6YT9B@G:&%N
M9&QI;F<@)7,@:6X@=&%G(&1E<'1H("5D/&)R("\^)RP@)&YA;64L("1T:&ES
M+3YG971#=7)R96YT1&5P=&@H*2D["B`@("`@("`@<')I;G1F*"=C:&%R86-T
M97(@9&%T83H@)7,\8G(@+SXG+"`D9&%T82`I.PH@("`@("`@('!R:6YT("=!
M='1R:6)U=&5S.CQB<B`O/B<["B`@("`@("`@<')I;G0@)SQP<F4^)SL*("`@
M("`@("!P<FEN=%]R*"`D871T<FEB<R`I.PH@("`@("`@('!R:6YT("<\+W!R
M93XG.PH@("`@("`@('!R:6YT("<\8G(@+SXG.PH@("`@?0I]"@HD<"`]("9N
M97<@;7E087)S97(H*3L*"B1R97-U;'0@/2`D<"T^<V5T26YP=71&:6QE*"=X
M;6Q?<&%R<V5R7W-I;7!L93$N>&UL)RD["B1R97-U;'0@/2`D<"T^<&%R<V4H
M*3L*/SX`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]087)S97(O97AA;7!L
M97,O>&UL7W!A<G-E<E]S:6UP;&4Q+GAM;```````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,S$W(#$P-3$U
M-#,S-S,P(#`R-S4S-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\(2TM("1)9#H@>&UL7W!A<G-E<E]S:6UP;&4Q+GAM;"QV
M(#$N,B`R,#`T+S`U+S(T(#(Q.C0R.C,S('-C:'-T($5X<"`D("TM/@H\9F]O
M/@H@("`@/&)A<CYC;VYT96YT(&]F(&)A<CPO8F%R/@H@("`@/&5M<'1Y+SX*
M("`@(#QA<F=H(&9O;STB8F%R(CX*("`@("`@("!T97-T"B`@("`@("`@/'1O
M;6%T;SYP:7IZ83PO=&]M871O/@H@("`@/"]A<F=H/@H\+V9O;SX`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O9&]C<R]834Q?4&%R<V5R+V5X86UP;&5S+WAM;%]P87)S
M97)?<VEM<&QE,BYP:'`````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C4R-"`Q,#4Q-30S,S<S,"`P,C<U
M,S``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]02%`*+RHJ"B`J(&5X86UP;&4@9F]R(%A-3%]087)S97)?4VEM<&QE"B`J
M"B`J("1)9#H@>&UL7W!A<G-E<E]S:6UP;&4R+G!H<"QV(#$N,2`R,#`T+S`U
M+S(T(#(Q.C0R.C,S('-C:'-T($5X<"`D"B`J"B`J($!A=71H;W(@("`@("!3
M=&5P:&%N(%-C:&UI9'0@/'-C:'-T0'!H<"UT;V]L<RYN970^"B`J($!P86-K
M86=E("`@("!834Q?4&%R<V5R"B`J($!S=6)P86-K86=E("!%>&%M<&QE<PH@
M*B\*"B\J*@H@*B!R97%U:7)E('1H92!P87)S97(*("HO"G)E<75I<F5?;VYC
M92`G6$U,+U!A<G-E<B]3:6UP;&4N<&AP)SL*"F-L87-S(&UY4&%R<V5R,B!E
M>'1E;F1S(%A-3%]087)S97)?4VEM<&QE"GL*("`@(&9U;F-T:6]N(&UY4&%R
M<V5R*"D*("`@('L*("`@("`@("`D=&AI<RT^6$U,7U!A<G-E<E]3:6UP;&4H
M*3L*("`@('T*"B`@("\J*@H@("`@*B!H86YD;&4@=&AE(&-A=&5G;W)Y(&5L
M96UE;G0*("`@("H*("`@("H@5&AE(&5L96UE;G0@=VEL;"!B92!H86YD;&5D
M+"!O;F-E(&ET)W,@8VQO<V5D"B`@("`J"B`@("`J($!A8V-E<W,@("!P<FEV
M871E"B`@("`J($!P87)A;2`@("!S=')I;F<@("`@("!N86UE(&]F('1H92!E
M;&5M96YT"B`@("`J($!P87)A;2`@("!A<G)A>2`@("`@("!A='1R:6)U=&5S
M(&]F('1H92!E;&5M96YT"B`@("`J($!P87)A;2`@("!S=')I;F<@("`@("!C
M:&%R86-T97(@9&%T82!O9B!T:&4@96QE;65N=`H@("`@*B\*("`@(&9U;F-T
M:6]N(&AA;F1L945L96UE;G1?8V%T96=O<GDH)&YA;64L("1A='1R:6)S+"`D
M9&%T82D*("`@('L*("`@("`@("!P<FEN=&8H("=#871E9V]R>2!I<R`E<SQB
M<B`O/B<L("1D871A("D["B`@("!]"@H@("`O*BH*("`@("H@:&%N9&QE('1H
M92!N86UE(&5L96UE;G0*("`@("H*("`@("H@5&AE(&5L96UE;G0@=VEL;"!B
M92!H86YD;&5D+"!O;F-E(&ET)W,@8VQO<V5D"B`@("`J"B`@("`J($!A8V-E
M<W,@("!P<FEV871E"B`@("`J($!P87)A;2`@("!S=')I;F<@("`@("!N86UE
M(&]F('1H92!E;&5M96YT"B`@("`J($!P87)A;2`@("!A<G)A>2`@("`@("!A
M='1R:6)U=&5S(&]F('1H92!E;&5M96YT"B`@("`J($!P87)A;2`@("!S=')I
M;F<@("`@("!C:&%R86-T97(@9&%T82!O9B!T:&4@96QE;65N=`H@("`@*B\*
M("`@(&9U;F-T:6]N(&AA;F1L945L96UE;G1?;F%M92@D;F%M92P@)&%T=')I
M8G,L("1D871A*0H@("`@>PH@("`@("`@('!R:6YT9B@@)TYA;64@:7,@)7,\
M8G(@+SXG+"`D9&%T82`I.PH@("`@?0I]"@HD<"`]("9N97<@;7E087)S97(R
M*"D["B1R97-U;'0@/2`D<"T^<V5T26YP=71&:6QE*"=X;6Q?<&%R<V5R7W-I
M;7!L93(N>&UL)RD["B1P+3YS971-;V1E*"=F=6YC)RD["B1R97-U;'0@/2`D
M<"T^<&%R<V4H*3L*/SX`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]0
M87)S97(O97AA;7!L97,O>&UL7W!A<G-E<E]S:6UP;&4R+GAM;```````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P,C,P(#$P-3$U-#,S-S,P(#`R-S4S,0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\(2TM("1)9#H@>&UL7W!A<G-E<E]S
M:6UP;&4R+GAM;"QV(#$N,2`R,#`T+S`U+S(T(#(Q.C0R.C,S('-C:'-T($5X
M<"`D("TM/@H\<&%C:V%G93X*("`@(#QC871E9V]R>3Y834P\+V-A=&5G;W)Y
M/@H@("`@/&YA;64^6$U,7U!A<G-E<CPO;F%M93X*/"]P86-K86=E/@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4&%R<V5R+V5X86UP
M;&5S+WAM;%]P87)S97)?<VEM<&QE7VAA;F1L97(N<&AP````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C0W,B`Q,#4Q
M-30S,S<S,"`P,S$Q-#4`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]02%`*+RHJ"B`J(&5X86UP;&4@9F]R(%A-3%]087)S
M97)?4VEM<&QE"B`J"B`J("1)9#H@>&UL7W!A<G-E<E]S:6UP;&5?:&%N9&QE
M<BYP:'`L=B`Q+C$@,C`P-"\P-2\R-2`Q,SHR-CHT,B!S8VAS="!%>'`@)`H@
M*@H@*B!`875T:&]R("`@("`@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P:'`M
M=&]O;',N;F5T/@H@*B!`<&%C:V%G92`@("`@6$U,7U!A<G-E<@H@*B!`<W5B
M<&%C:V%G92`@17AA;7!L97,*("HO"@HO*BH*("H@<F5Q=6ER92!T:&4@<&%R
M<V5R"B`J+PIR97%U:7)E7V]N8V4@)UA-3"]087)S97(O4VEM<&QE+G!H<"<[
M"@IC;&%S<R!M>4AA;F1L97)3:6UP;&4*>PH@("`O*BH*("`@("H@:&%N9&QE
M('1H92!C871E9V]R>2!E;&5M96YT"B`@("`J"B`@("`J(%1H92!E;&5M96YT
M('=I;&P@8F4@:&%N9&QE9"P@;VYC92!I="=S(&-L;W-E9`H@("`@*@H@("`@
M*B!`86-C97-S("`@<')I=F%T90H@("`@*B!`<&%R86T@("`@<W1R:6YG("`@
M("`@;F%M92!O9B!T:&4@96QE;65N=`H@("`@*B!`<&%R86T@("`@87)R87D@
M("`@("`@871T<FEB=71E<R!O9B!T:&4@96QE;65N=`H@("`@*B!`<&%R86T@
M("`@<W1R:6YG("`@("`@8VAA<F%C=&5R(&1A=&$@;V8@=&AE(&5L96UE;G0*
M("`@("HO"B`@("!F=6YC=&EO;B!H86YD;&5%;&5M96YT7V-A=&5G;W)Y*"1N
M86UE+"`D871T<FEB<RP@)&1A=&$I"B`@("!["B`@("`@("`@<')I;G1F*"`G
M0V%T96=O<GD@:7,@)7,\8G(@+SXG+"`D9&%T82`I.PH@("`@?0H*("`@+RHJ
M"B`@("`J(&AA;F1L92!T:&4@;F%M92!E;&5M96YT"B`@("`J"B`@("`J(%1H
M92!E;&5M96YT('=I;&P@8F4@:&%N9&QE9"P@;VYC92!I="=S(&-L;W-E9`H@
M("`@*@H@("`@*B!`86-C97-S("`@<')I=F%T90H@("`@*B!`<&%R86T@("`@
M<W1R:6YG("`@("`@;F%M92!O9B!T:&4@96QE;65N=`H@("`@*B!`<&%R86T@
M("`@87)R87D@("`@("`@871T<FEB=71E<R!O9B!T:&4@96QE;65N=`H@("`@
M*B!`<&%R86T@("`@<W1R:6YG("`@("`@8VAA<F%C=&5R(&1A=&$@;V8@=&AE
M(&5L96UE;G0*("`@("HO"B`@("!F=6YC=&EO;B!H86YD;&5%;&5M96YT7VYA
M;64H)&YA;64L("1A='1R:6)S+"`D9&%T82D*("`@('L*("`@("`@("!P<FEN
M=&8H("=.86UE(&ES("5S/&)R("\^)RP@)&1A=&$@*3L*("`@('T*?0H*)'`@
M/2`F;F5W(%A-3%]087)S97)?4VEM<&QE*"D["B1H(#T@)FYE=R!M>4AA;F1L
M97)3:6UP;&4H*3L*)'`M/G-E=$AA;F1L97)/8FHH)&@I.PHD<F5S=6QT(#T@
M)'`M/G-E=$EN<'5T1FEL92@G>&UL7W!A<G-E<E]S:6UP;&4R+GAM;"<I.PHD
M<"T^<V5T36]D92@G9G5N8R<I.PHD<F5S=6QT(#T@)'`M/G!A<G-E*"D["C\^
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]D;V-S+UA-3%]087)S97(O97AA;7!L97,O>&UL7W!A<G-E<E]F:6QE+GAM
M;````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P,3(W(#$P-3$U-#,S-S,P(#`R-S$P,@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\9F]O/@H@("`@
M/&)A<CYC;VYT96YT(&]F(&)A<CPO8F%R/@H@("`@/&5M<'1Y+SX*("`@(#QA
M<F=H(&9O;STB8F%R(CYT97-T/"]A<F=H/@H\+V9O;SX`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R],;V<`
M````````````````````````````````````````````````````````````
M```````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#`P,"`Q,#4Q-30S,S<S,"`P,C`P-34`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]D;V-S+TQO9R]D;V-S````````````````````````````````
M`````````````````````````````````````````````#`P,#<U-2``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S,P(#`R,3`P-0`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O3&]G+V1O8W,O97AA;7!L
M97,`````````````````````````````````````````````````````````
M````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U
M,34T,S,W,S`@,#(R-C(S`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C
M<R],;V<O9&]C<R]E>&%M<&QE<R]C;VUP;W-I=&4N<&AP````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#0V,2`Q,#4Q-30S,S<S,"`P,C4T,38`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*"G)E<75I<F5?
M;VYC92`G3&]G+G!H<"<["@HD8V]N<V]L92`]("9,;V<Z.G-I;F=L971O;B@G
M8V]N<V]L92<L("<G+"`G5$535"<I.PHD9FEL92`]("9,;V<Z.G-I;F=L971O
M;B@G9FEL92<L("=O=70N;&]G)RP@)U1%4U0G*3L*"B1C;VUP;W-I=&4@/2`F
M3&]G.CIS:6YG;&5T;VXH)V-O;7!O<VET92<I.PHD8V]M<&]S:71E+3YA9&1#
M:&EL9"@D8V]N<V]L92D["B1C;VUP;W-I=&4M/F%D9$-H:6QD*"1F:6QE*3L*
M"B1C;VUP;W-I=&4M/FQO9R@G5&AI<R!E=F5N="!W:6QL(&)E(&QO9V=E9"!T
M;R!B;W1H(&AA;F1L97)S+B<I.PH`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O3&]G+V1O8W,O
M97AA;7!L97,O9&ES<&QA>2YP:'``````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`T
M,S`@,3`U,34T,S,W,S`@,#(U,#4U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TQO9RYP
M:'`G.PH*)&-O;F8@/2!A<G)A>2@G97)R;W)?<')E<&5N9"<@/3X@)SQF;VYT
M(&-O;&]R/2(C9F8P,#`P(CX\='0^)RP*("`@("`@("`@("`@("`G97)R;W)?
M87!P96YD)R`@/3X@)SPO='0^/"]F;VYT/B<I.PHD;&]G9V5R(#T@)DQO9SHZ
M<VEN9VQE=&]N*"=D:7-P;&%Y)RP@)R<L("<G+"`D8V]N9BP@4$5!4E],3T=?
M1$5"54<I.PIF;W(@*"1I(#T@,#L@)&D@/"`Q,#L@)&DK*RD@>PH@("`@)&QO
M9V=E<BT^;&]G*"),;V<@96YT<GD@)&DB*3L*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO9R]D;V-S+V5X86UP;&5S+V5R
M<F]R7VQO9RYP:'``````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,C4Q(#$P-3$U-#,S
M-S,P(#`R-30P,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`H*<F5Q=6ER95]O;F-E("=,;V<N<&AP)SL*"B1L;V=G
M97(@/2`F3&]G.CIS:6YG;&5T;VXH)V5R<F]R7VQO9R<L(%!%05)?3$]'7U19
M4$5?4UE35$5-+"`G:61E;G0G*3L*9F]R("@D:2`](#`[("1I(#P@,3`[("1I
M*RLI('L*("`@("1L;V=G97(M/FQO9R@B3&]G(&5N=')Y("1I(BD["GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O9&]C<R],;V<O9&]C<R]E>&%M<&QE<R]F:6QE+G!H<```````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#,S,"`Q,#4Q-30S,S<S,"`P,C0S,C8`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*"G)E<75I<F5?;VYC92`G3&]G+G!H<"<["@HD8V]N9B`](&%R<F%Y*"=M
M;V1E)R`]/B`P-C`P+"`G=&EM949O<FUA="<@/3X@)R58("5X)RD["B1L;V=G
M97(@/2`F3&]G.CIS:6YG;&5T;VXH)V9I;&4G+"`G;W5T+FQO9R<L("=I9&5N
M="<L("1C;VYF*3L*9F]R("@D:2`](#`[("1I(#P@,3`[("1I*RLI('L*("`@
M("1L;V=G97(M/FQO9R@B3&]G(&5N=')Y("1I(BD["GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O
M8W,O3&]G+V1O8W,O97AA;7!L97,O;6%I;"YP:'``````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`S-#(@,3`U,34T,S,W,S`@,#(T,S,T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"@IR97%U:7)E
M7V]N8V4@)TQO9RYP:'`G.PH*)&-O;F8@/2!A<G)A>2@G<W5B:F5C="<@/3X@
M)TEM<&]R=&%N="!,;V<@179E;G1S)RD["B1L;V=G97(@/2`F3&]G.CIS:6YG
M;&5T;VXH)VUA:6PG+"`G=V5B;6%S=&5R0&5X86UP;&4N8V]M)RP@)VED96YT
M)RP@)&-O;F8I.PIF;W(@*"1I(#T@,#L@)&D@/"`Q,#L@)&DK*RD@>PH@("`@
M)&QO9V=E<BT^;&]G*"),;V<@96YT<GD@)&DB*3L*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO9R]D;V-S
M+V5X86UP;&5S+VYU;&PN<&AP````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M,C`U(#$P-3$U-#,S-S,P(#`R-#,V,@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=,;V<N
M<&AP)SL*"B1L;V=G97(@/2`F3&]G.CIS:6YG;&5T;VXH)VYU;&PG*3L*9F]R
M("@D:2`](#`[("1I(#P@,3`[("1I*RLI('L*("`@("1L;V=G97(M/FQO9R@B
M3&]G(&5N=')Y("1I(BD["GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R],;V<O9&]C<R]E>&%M<&QE<R]O
M8G-E<G9E<E]M86EL+G!H<```````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3(Q-R`Q,#4Q-30S
M,S<S,"`P,C8R-#4`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"G)E<75I<F5?;VYC92`G3&]G+V]B<V5R=F5R+G!H
M<"<["@IC;&%S<R!,;V=?;V)S97)V97)?;6%I;"!E>'1E;F1S($QO9U]O8G-E
M<G9E<@I["B`@("!V87(@)%]T;R`]("<G.PH@("`@=F%R("1?<W5B:F5C="`]
M("<G.PH@("`@=F%R("1?<&%T=&5R;B`]("<G.PH*("`@(&9U;F-T:6]N($QO
M9U]O8G-E<G9E<E]M86EL*"1P<FEO<FET>2P@)&-O;F8I"B`@("!["B`@("`@
M("`@+RH@0V%L;"!T:&4@8F%S92!C;&%S<R!C;VYS=')U8W1O<BX@*B\*("`@
M("`@("`D=&AI<RT^3&]G7V]B<V5R=F5R*"1P<FEO<FET>2D["@H@("`@("`@
M("\J($-O;F9I9W5R92!T:&4@;V)S97)V97(N("HO"B`@("`@("`@)'1H:7,M
M/E]T;R`]("1C;VYF6R=T;R==.PH@("`@("`@("1T:&ES+3Y?<W5B:F5C="`]
M("1C;VYF6R=S=6)J96-T)UT["B`@("`@("`@)'1H:7,M/E]P871T97)N(#T@
M)&-O;F9;)W!A='1E<FXG73L*("`@('T*"B`@("!F=6YC=&EO;B!N;W1I9GDH
M)&5V96YT*0H@("`@>PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"1T:&ES+3Y?
M<&%T=&5R;BP@)&5V96YT6R=M97-S86=E)UTI("$](#`I('L*("`@("`@("`@
M("`@;6%I;"@D=&AI<RT^7W1O+"`D=&AI<RT^7W-U8FIE8W0L("1E=F5N=%LG
M;65S<V%G92==*3L*("`@("`@("!]"B`@("!]"GT*"C\^"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R],;V<O9&]C<R]E>&%M
M<&QE<R]P96%R7V5R<F]R7VAA;F1L97(N<&AP````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3$U-"`Q
M,#4Q-30S,S<S,"`P,C<R-3$`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G3&]G+G!H<"<[
M"@IF=6YC=&EO;B!E<G)O<DAA;F1L97(H)&5R<F]R*0I["B`@("!G;&]B86P@
M)&QO9V=E<CL*"B`@("`D;65S<V%G92`]("1E<G)O<BT^9V5T365S<V%G92@I
M.PH*("`@(&EF("@A96UP='DH)&5R<F]R+3YB86-K=')A8V5;,5U;)V9I;&4G
M72DI('L*("`@("`@("`D;65S<V%G92`N/2`G("@G("X@)&5R<F]R+3YB86-K
M=')A8V5;,5U;)V9I;&4G73L*("`@("`@("!I9B`H(65M<'1Y*"1E<G)O<BT^
M8F%C:W1R86-E6S%=6R=L:6YE)UTI*2!["B`@("`@("`@("`@("1M97-S86=E
M("X]("<@870@;&EN92`G("X@)&5R<F]R+3YB86-K=')A8V5;,5U;)VQI;F4G
M73L*("`@("`@("!]"B`@("`@("`@)&UE<W-A9V4@+CT@)RDG.PH@("`@?0H*
M("`@("1L;V=G97(M/FQO9R@D;65S<V%G92P@)&5R<F]R+3YC;V1E*3L*?0H*
M)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O;B@G8V]N<V]L92<L("<G+"`G:61E
M;G0G*3L*"E!%05(Z.G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]#04Q,
M0D%#2RP@)V5R<F]R2&%N9&QE<B<I.PI014%2.CIR86ES945R<F]R*"=4:&ES
M(&ES(&%N(&EN9F]R;6%T:6]N(&QO9R!M97-S86=E+B<L(%!%05)?3$]'7TE.
M1D\I.PH`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R],;V<O9&]C
M<R]E>&%M<&QE<R]P:'!?97)R;W)?:&%N9&QE<BYP:'``````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,30P,"`Q,#4Q-30S,S<S,"`P,C<Q,#,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G3&]G
M+G!H<"<["@IF=6YC=&EO;B!E<G)O<DAA;F1L97(H)&-O9&4L("1M97-S86=E
M+"`D9FEL92P@)&QI;F4I"GL*("`@(&=L;V)A;"`D;&]G9V5R.PH*("`@("\J
M($UA<"!T:&4@4$A0(&5R<F]R('1O(&$@3&]G('!R:6]R:71Y+B`J+PH@("`@
M<W=I=&-H("@D8V]D92D@>PH@("`@8V%S92!%7U=!4DY)3D<Z"B`@("!C87-E
M($5?55-%4E]705).24Y'.@H@("`@("`@("1P<FEO<FET>2`](%!%05)?3$]'
M7U=!4DY)3D<["B`@("`@("`@8G)E86L["B`@("!C87-E($5?3D]424-%.@H@
M("`@8V%S92!%7U5315)?3D]424-%.@H@("`@("`@("1P<FEO<FET>2`](%!%
M05)?3$]'7TY/5$E#13L*("`@("`@("!B<F5A:SL*("`@(&-A<V4@15]%4E)/
M4CH*("`@(&-A<V4@15]54T527T524D]2.@H@("`@("`@("1P<FEO<FET>2`]
M(%!%05)?3$]'7T524CL*("`@("`@("!B<F5A:SL*("`@(&1E9F%U;'0Z"B`@
M("`@("`@)'!R:6]T:71Y(#T@4$5!4E],3T=?24Y&3SL*("`@('T*"B`@("`D
M;&]G9V5R+3YL;V<H)&UE<W-A9V4@+B`G(&EN("<@+B`D9FEL92`N("<@870@
M;&EN92`G("X@)&QI;F4L"B`@("`@("`@("`@("`@("`@)'!R:6]R:71Y*3L*
M?0H*)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O;B@G8V]N<V]L92<L("<G+"`G
M:61E;G0G*3L*"G-E=%]E<G)O<E]H86YD;&5R*"=E<G)O<DAA;F1L97(G*3L*
M=')I9V=E<E]E<G)O<B@G5&AI<R!I<R!A;B!I;F9O<FUA=&EO;B!L;V<@;65S
M<V%G92XG+"!%7U5315)?3D]424-%*3L*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R],
M;V<O9&]C<R]E>&%M<&QE<R]S<6PN<&AP````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#,S-"`Q,#4Q-30S,S<S,"`P,C0R,3(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC
M92`G3&]G+G!H<"<["@HD8V]N9B`](&%R<F%Y*"=D<VXG(#T^("=P9W-Q;#HO
M+VIO;D!L;V-A;&AO<W0K=6YI>"]L;V=S)RD["B1L;V=G97(@/2`F3&]G.CIS
M:6YG;&5T;VXH)W-Q;"<L("=L;V=?=&%B;&4G+"`G:61E;G0G+"`D8V]N9BD[
M"F9O<B`H)&D@/2`P.R`D:2`\(#$P.R`D:2LK*2!["B`@("`D;&]G9V5R+3YL
M;V<H(DQO9R!E;G1R>2`D:2(I.PI]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O3&]G+V1O8W,O97AA
M;7!L97,O<W%L:71E+G!H<```````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`W-3$@
M,3`U,34T,S,W,S`@,#(T-S$W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TQO9RYP:'`G
M.PH*+RH@0W)E871I;F<@82!N97<@9&%T86)A<V4@8V]N;F5C=&EO;BX@*B\*
M)&-O;F8@/2!A<G)A>2@G9FEL96YA;64G(#T^("=L;V<N9&(G+"`G;6]D92<@
M/3X@,#8V-BP@)W!E<G-I<W1E;G0G(#T^('1R=64I.PHD;&]G9V5R(#TF($QO
M9SHZ9F%C=&]R>2@G<W%L:71E)RP@)VQO9U]T86)L92<L("=I9&5N="<L("1C
M;VYF*3L*)&QO9V=E<BT^;&]G*"=L;V=G:6YG(&%N(&5V96YT)RP@4$5!4E],
M3T=?5T%23DE.1RD["@HO*B!5<VEN9R!A;B!E>&ES=&EN9R!D871A8F%S92!C
M;VYN96-T:6]N+B`J+PHD9&(@/2!S<6QI=&5?;W!E;B@G;&]G+F1B)RP@,#8V
M-BP@)&5R<F]R*3L*)&QO9V=E<B`])B!,;V<Z.F9A8W1O<GDH)W-Q;&ET92<L
M("=L;V=?=&%B;&4G+"`G:61E;G0G+"`D9&(I.PHD;&]G9V5R+3YL;V<H)VQO
M9V=I;F<@86X@979E;G0G+"!014%27TQ/1U]705).24Y'*3L*<W%L:71E7V-L
M;W-E*"1D8BD["@``````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO9R]D;V-S+V5X86UP;&5S+W-Y<VQO
M9RYP:'```````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,C,T(#$P-3$U-#,S-S,P
M(#`R-#<S,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`H*<F5Q=6ER95]O;F-E("=,;V<N<&AP)SL*"B1L;V=G97(@
M/2`F3&]G.CIS:6YG;&5T;VXH)W-Y<VQO9R<L($Q/1U],3T-!3#`L("=I9&5N
M="<I.PIF;W(@*"1I(#T@,#L@)&D@/"`Q,#L@)&DK*RD@>PH@("`@)&QO9V=E
M<BT^;&]G*"),;V<@96YT<GD@)&DB*3L*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O9&]C<R],;V<O9&]C<R]E>&%M<&QE<R]W:6XN<&AP````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#,R,"`Q,#4Q-30S,S<S,"`P,C0R,#,`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M"G)E<75I<F5?;VYC92`G3&]G+G!H<"<["@HD8V]N9B`](&%R<F%Y*"=T:71L
M92<@/3X@)U-A;7!L92!,;V<@3W5T<'5T)RD["B1L;V=G97(@/2`F3&]G.CIS
M:6YG;&5T;VXH)W=I;B<L("=,;V=7:6YD;W<G+"`G:61E;G0G+"`D8V]N9BD[
M"F9O<B`H)&D@/2`P.R`D:2`\(#$P.R`D:2LK*2!["B`@("`D;&]G9V5R+3YL
M;V<H(DQO9R!E;G1R>2`D:2(I.PI]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O
M3&]G+V1O8W,O97AA;7!L97,O8V]N<V]L92YP:'``````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`R,C4@,3`U,34T,S,W,S`@,#(U,#4T`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"@IR97%U:7)E7V]N
M8V4@)TQO9RYP:'`G.PH*)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O;B@G8V]N
M<V]L92<L("<G+"`G:61E;G0G*3L*9F]R("@D:2`](#`[("1I(#P@,3`[("1I
M*RLI('L*("`@("1L;V=G97(M/FQO9R@B3&]G(&5N=')Y("1I(BD["GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO9R]D;V-S+V=U
M:61E+G1X=```````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,3(T-3`P
M(#$P-3$U-#,S-S,P(#`R,C<R-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````]/3T]/3T]/3T]/3T]/3T]/0H@5&AE($QO9R!0
M86-K86=E"CT]/3T]/3T]/3T]/3T]/3T]"@HM+2TM+2TM+2TM+2TM+2TM+2TM
M+0H@57-E<B!$;V-U;65N=&%T:6]N"BTM+2TM+2TM+2TM+2TM+2TM+2TM"@HZ
M075T:&]R.B`@("`@("`@2F]N(%!A<FES90HZ0V]N=&%C=#H@("`@("`@:F]N
M0'!H<"YN970*.D1A=&4Z("`@("`@("`@("1$871E.B`R,#`V+S`T+S(Q(#`U
M.C(U.C`Y("0*.E)E=FES:6]N.B`@("`@("12979I<VEO;CH@,2XR-2`D"@HN
M+B!C;VYT96YT<SHZ($-O;G1E;G1S"BXN('-E8W1I;VXM;G5M8F5R:6YG.CH*
M"E5S:6YG($QO9R!(86YD;&5R<PH]/3T]/3T]/3T]/3T]/3T]/3T*"E1H92!,
M;V<@<&%C:V%G92!I<R!I;7!L96UE;G1E9"!A<R!A(&9R86UE=V]R:R!T:&%T
M('-U<'!O<G1S('1H92!N;W1I;VX@;V8*8F%C:V5N9"US<&5C:69I8R!L;V<@
M:&%N9&QE<G,N("!4:&4@8F%S92!L;V=G:6YG(&]B:F5C="`H9&5F:6YE9"!B
M>2!T:&4@8$QO9PIC;&%S<V!?*2!I<R!P<FEM87)I;'D@86X@86)S=')A8W0@
M:6YT97)F86-E('1O('1H92!C=7)R96YT;'D@8V]N9FEG=7)E9`IH86YD;&5R
M+@H*02!W:61E('9A<FEE='D@;V8@:&%N9&QE<G,@87)E(&1I<W1R:6)U=&5D
M('=I=&@@=&AE($QO9R!P86-K86=E+"!A;F0L('-H;W5L9`IN;VYE(&]F('1H
M96T@9FET('EO=7(@87!P;&EC871I;VXG<R!N965D<RP@:70G<R!E87-Y('1O
M(&!W<FET92!Y;W5R(&]W;F!?7RX*"BXN(%],;V<@8VQA<W,Z(&AT='`Z+R]C
M=G,N<&AP+FYE="]C;RYP:'`O<&5A<B],;V<O3&]G+G!H<`I?7R!@0W5S=&]M
M($AA;F1L97)S8%\*"D-R96%T:6YG(&$@3&]G($]B:F5C=`HM+2TM+2TM+2TM
M+2TM+2TM+2TM+2T*5&AE<F4@87)E('1H<F5E('=A>7,@=&\@8W)E871E($QO
M9R!O8FIE8W1S.@H*("`@("T@57-I;F<@=&AE(&!@3&]G.CIF86-T;W)Y*"E@
M8"!M971H;V0*("`@("T@57-I;F<@=&AE(&!@3&]G.CIS:6YG;&5T;VXH*6!@
M(&UE=&AO9`H@("`@+2!$:7)E8W0@:6YS=&%N=&EA=&EO;@H*5&AE($9A8W1O
M<GD@365T:&]D"GY^?GY^?GY^?GY^?GY^?GY^?@I4:&4@8&!,;V<Z.F9A8W1O
M<GDH*6!@(&UE=&AO9"!I;7!L96UE;G1S('1H92!@1F%C=&]R>2!0871T97)N
M8%\N("!)="!A;&QO=W,*9F]R('1H92!P87)A;65T97)I>F5D(&-O;G-T<G5C
M=&EO;B!O9B!C;VYC<F5T92!,;V<@:6YS=&%N8V5S(&%T(')U;G1I;64N("!4
M:&4*9FER<W0@<&%R86UE=&5R('1O('1H92!@8$QO9SHZ9F%C=&]R>2@I8&`@
M;65T:&]D(&EN9&EC871E<R!T:&4@;F%M92!O9B!T:&4*8V]N8W)E=&4@:&%N
M9&QE<B!T;R!C<F5A=&4N("!4:&4@<F5S="!O9B!T:&4@<&%R86UE=&5R<R!W
M:6QL(&)E('!A<W-E9"!O;B!T;PIT:&4@:&%N9&QE<B=S(&-O;G-T<G5C=&]R
M("AS964@8$-O;F9I9W5R:6YG(&$@2&%N9&QE<F!?(&)E;&]W*2X*"E1H92!N
M97<@8&!,;V=@8"!I;G-T86YC92!I<R!R971U<FYE9"!B>2!R969E<F5N8V4N
M"@HZ.@H*("`@(')E<75I<F5?;VYC92`G3&]G+G!H<"<["@H@("`@)&-O;G-O
M;&4@/2`F3&]G.CIF86-T;W)Y*"=C;VYS;VQE)RP@)R<L("=415-4)RD["B`@
M("`D8V]N<V]L92T^;&]G*"=,;V=G:6YG('1O('1H92!C;VYS;VQE+B<I.PH*
M("`@("1F:6QE(#T@)DQO9SHZ9F%C=&]R>2@G9FEL92<L("=O=70N;&]G)RP@
M)U1%4U0G*3L*("`@("1F:6QE+3YL;V<H)TQO9V=I;F<@=&\@;W5T+FQO9RXG
M*3L*"BXN(%]&86-T;W)Y(%!A='1E<FXZ(&AT='`Z+R]W=W<N<&AP<&%T=&5R
M;G,N8V]M+VEN9&5X+G!H<"]A<G1I8VQE+V%R=&EC;&5V:65W+S0Y+S$O,2\*
M"E1H92!3:6YG;&5T;VX@365T:&]D"GY^?GY^?GY^?GY^?GY^?GY^?GY^"E1H
M92!@8$QO9SHZ<VEN9VQE=&]N*"E@8"!M971H;V0@:6UP;&5M96YT<R!T:&4@
M8%-I;F=L971O;B!0871T97)N8%\N("!4:&4*<VEN9VQE=&]N('!A='1E<FX@
M96YS=7)E<R!T:&%T(&]N;'D@82!S:6YG;&4@:6YS=&%N8V4@;V8@82!G:79E
M;B!L;V<@='EP92!A;F0*8V]N9FEG=7)A=&EO;B!I<R!E=F5R(&-R96%T960N
M("!4:&ES(&AA<R!T=V\@8F5N969I=',Z(&9I<G-T+"!I="!P<F5V96YT<PID
M=7!L:6-A=&4@8&!,;V=@8"!I;G-T86YC97,@9G)O;2!B96EN9R!C;VYS=')U
M8W1E9"P@86YD+"!S96-O;F0L(&ET(&=I=F5S(&%L;`IO9B!Y;W5R(&-O9&4@
M86-C97-S('1O('1H92!S86UE(&!@3&]G8&`@:6YS=&%N8V4N("!4:&4@;&%T
M=&5R(&ES(&5S<&5C:6%L;'D*:6UP;W)T86YT('=H96X@;&]G9VEN9R!T;R!F
M:6QE<R!B96-A=7-E(&]N;'D@82!S:6YG;&4@9FEL92!H86YD;&5R('=I;&P@
M;F5E9`IT;R!B92!M86YA9V5D+@H*5&AE(&!@3&]G.CIS:6YG;&5T;VXH*6!@
M(&UE=&AO9"=S('!A<F%M971E<G,@;6%T8V@@=&AE(&!@3&]G.CIF86-T;W)Y
M*"E@8`IM971H;V0N("!4:&4@;F5W(&!@3&]G8&`@:6YS=&%N8V4@:7,@<F5T
M=7)N960@8GD@<F5F97)E;F-E+@H*.CH*"B`@("!R97%U:7)E7V]N8V4@)TQO
M9RYP:'`G.PH*("`@("\J(%-A;64@8V]N<W1R=6-T:6]N('!A<F%M971E<G,@
M*B\*("`@("1A(#T@)DQO9SHZ<VEN9VQE=&]N*"=C;VYS;VQE)RP@)R<L("=4
M15-4)RD["B`@("`D8B`]("9,;V<Z.G-I;F=L971O;B@G8V]N<V]L92<L("<G
M+"`G5$535"<I.PH*("`@(&EF("@D82`]/3T@)&(I('L*("`@("`@("!E8VAO
M("<D82!A;F0@)&(@<&]I;G0@=&\@=&AE('-A;64@3&]G(&EN<W1A;F-E+B<@
M+B`B7&XB.PH@("`@?0H*("`@("\J($1I9F9E<F5N="!C;VYS=')U8W1I;VX@
M<&%R86UE=&5R<R`J+PH@("`@)&,@/2`F3&]G.CIS:6YG;&5T;VXH)V-O;G-O
M;&4G+"`G)RP@)U1%4U0Q)RD["B`@("`D9"`]("9,;V<Z.G-I;F=L971O;B@G
M8V]N<V]L92<L("<G+"`G5$535#(G*3L*"B`@("!I9B`H)&,@(3T]("1D*2![
M"B`@("`@("`@96-H;R`G)&,@86YD("1D('!O:6YT('1O(&1I9F9E<F5N="!,
M;V<@:6YS=&%N8V5S+B<@+B`B7&XB.PH@("`@?0H*+BX@7U-I;F=L971O;B!0
M871T97)N.B!H='1P.B\O=W=W+G!H<'!A='1E<FYS+F-O;2]I;F1E>"YP:'`O
M87)T:6-L92]A<G1I8VQE=FEE=R\V+S$O,2\*"D1I<F5C="!);G-T86YT:6%T
M:6]N"GY^?GY^?GY^?GY^?GY^?GY^?GY^"DET(&ES(&%L<V\@<&]S<VEB;&4@
M=&\@9&ER96-T;'D@:6YS=&%N=&EA=&4@8V]N8W)E=&4@8&!,;V=@8"!H86YD
M;&5R"FEN<W1A;F-E<RX@($AO=V5V97(L('1H:7,@;65T:&]D(&ES("HJ;F]T
M(')E8V]M;65N9&5D*BH@8F5C875S92!I="!C<F5A=&5S(&$*=&EG:'1E<B!C
M;W5P;&EN9R!B971W965N('EO=7(@87!P;&EC871I;VX@8V]D92!A;F0@=&AE
M($QO9R!P86-K86=E('1H86X@:7,*;F5C97-S87)Y+B`@57-E(&]F(&!T:&4@
M9F%C=&]R>2!M971H;V1@7R!O<B!@=&AE('-I;F=L971O;B!M971H;V1@7R!I
M<PIP<F5F97)R960N"@H*0V]N9FEG=7)I;F<@82!(86YD;&5R"BTM+2TM+2TM
M+2TM+2TM+2TM+2TM+0I!(&QO9R!H86YD;&5R)W,@8V]N9FEG=7)A=&EO;B!I
M<R!D971E<FUI;F5D(&)Y('1H92!A<F=U;65N=',@=7-E9"!I;B!I=',*8V]N
M<W1R=6-T:6]N+B`@2&5R92=S(&%N(&]V97)V:65W(&]F('1H;W-E('!A<F%M
M971E<G,Z.@H*("`@("\J(%5S:6YG('1H92!F86-T;W)Y(&UE=&AO9"`N+BX@
M*B\*("`@("9,;V<Z.F9A8W1O<GDH)&AA;F1L97(L("1N86UE+"`D:61E;G0L
M("1C;VYF+"`D;6%X3&5V96PI.PH*("`@("\J(%5S:6YG('1H92!S:6YG;&5T
M;VX@;65T:&]D("XN+B`J+PH@("`@)DQO9SHZ<VEN9VQE=&]N*"1H86YD;&5R
M+"`D;F%M92P@)&ED96YT+"`D8V]N9BP@)&UA>$QE=F5L*3L*"B`@("`O*B!5
M<VEN9R!D:7)E8W0@:6YS=&%N=&EA=&EO;B`N+BX@*B\*("`@(&YE=R!,;V=?
M:&%N9&QE<B@D;F%M92P@)&ED96YT+"`D8V]N9BP@)&UA>$QE=F5L*3L*"BLM
M+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@4&%R86UE=&5R("`@
M("!\(%1Y<&4@("`@("!\($1E<V-R:7!T:6]N("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"BL]/3T]/3T]/3T]/3T]/3TK/3T]/3T]/3T]
M/3TK/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3TK"GP@8&`D:&%N9&QE<F!@("!\(%-T<FEN9R`@("!\(%1H92!T>7!E
M(&]F($QO9R!H86YD;&5R('1O(&-O;G-T<G5C="X@(%1H:7,@("!\"GP@("`@
M("`@("`@("`@("!\("`@("`@("`@("!\('!A<F%M971E<B!I<R!O;FQY(&%V
M86EL86)L92!W:&5N(&!T:&4@9F%C=&]R>2!\"GP@("`@("`@("`@("`@("!\
M("`@("`@("`@("!\(&UE=&AO9&!?(&]R(&!T:&4@<VEN9VQE=&]N(&UE=&AO
M9&!?(&%R92!U<V5D+B!\"BLM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"GP@8&`D;F%M96!@("`@("!\(%-T<FEN9R`@("!\(%1H92!N86UE(&]F
M('1H92!L;V<@<F5S;W5R8V4@=&\@=VAI8V@@=&AE("`@("!\"GP@("`@("`@
M("`@("`@("!\("`@("`@("`@("!\(&5V96YT<R!W:6QL(&)E(&QO9V=E9"X@
M(%1H92!U<V4@;V8@=&AI<R!V86QU92!\"GP@("`@("`@("`@("`@("!\("`@
M("`@("`@("!\(&ES(&1E=&5R;6EN960@8GD@=&AE(&AA;F1L97(G<R!I;7!L
M96UE;G1A=&EO;BY\"GP@("`@("`@("`@("`@("!\("`@("`@("`@("!\($ET
M(&1E9F%U;'1S('1O(&%N(&5M<'1Y('-T<FEN9RX@("`@("`@("`@("`@("!\
M"BLM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&`D:61E;G1@
M8"`@("!\(%-T<FEN9R`@("!\($%N(&ED96YT:69I8V%T:6]N('-T<FEN9R!T
M:&%T('=I;&P@8F4@:6YC;'5D961\"GP@("`@("`@("`@("`@("!\("`@("`@
M("`@("!\(&EN(&%L;"!L;V<@979E;G1S(&QO9V=E9"!B>2!T:&ES(&AA;F1L
M97(N("`@("!\"GP@("`@("`@("`@("`@("!\("`@("`@("`@("!\(%1H:7,@
M=F%L=64@9&5F875L=',@=&\@86X@96UP='D@<W1R:6YG(&%N9"!C86Y\"GP@
M("`@("`@("`@("`@("!\("`@("`@("`@("!\(&)E(&-H86YG960@870@<G5N
M=&EM92!U<VEN9R!T:&4@8&!S971)9&5N="@I8&!\"GP@("`@("`@("`@("`@
M("!\("`@("`@("`@("!\(&UE=&AO9"X@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM
M+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"GP@8&`D8V]N9F!@("`@("!\($%R<F%Y("`@("!\($%S<V]C:6%T
M:79E(&%R<F%Y(&]F(&ME>2UV86QU92!P86ER<R!T:&%T(&%R92!\"GP@("`@
M("`@("`@("`@("!\("`@("`@("`@("!\('5S960@=&\@<W!E8VEF>2!A;GD@
M:&%N9&QE<BUS<&5C:69I8R!S971T:6YG<RY\"BLM+2TM+2TM+2TM+2TM+2TK
M+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"GP@8&`D;&5V96Q@8"`@("!\($EN=&5G97(@("!\
M($QO9R!M97-S86=E<R!U<"!T;R!A;F0@:6YC;'5D:6YG('1H:7,@;&5V96PN
M("!\"GP@("`@("`@("`@("`@("!\("`@("`@("`@("!\(%1H:7,@=F%L=64@
M9&5F875L=',@=&\@8&!014%27TQ/1U]$14)51V!@+B`@("!\"GP@("`@("`@
M("`@("`@("!\("`@("`@("`@("!\(%-E92!@3&]G($QE=F5L<V!?(&%N9"!@
M3&]G($QE=F5L($UA<VMS8%\N("`@("!\"BLM+2TM+2TM+2TM+2TM+2TK+2TM
M+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"@H*3&]G9VEN9R!A;B!%=F5N=`HM+2TM+2TM+2TM+2TM
M+2TM"D5V96YT<R!A<F4@;&]G9V5D('5S:6YG('1H92!@8&QO9R@I8&`@;65T
M:&]D.CH*"B`@("`D;&]G9V5R+3YL;V<H)TUE<W-A9V4G+"!014%27TQ/1U].
M3U1)0T4I.PH*5&AE(&9I<G-T(&%R9W5M96YT(&-O;G1A:6YS('1H92!L;V<@
M979E;G0G<R!M97-S86=E+B`@179E;B!T:&]U9V@@=&AE(&5V96YT(&ES"F%L
M=V%Y<R!L;V=G960@87,@82!S=')I;F<L(&ET(&ES('!O<W-I8FQE('1O('!A
M<W,@86X@;V)J96-T('1O('1H92!@8&QO9R@I8&`*;65T:&]D+B`@268@=&AE
M(&]B:F5C="!I;7!L96UE;G1S(&$@8&!G9713=')I;F<H*6!@(&UE=&AO9"P@
M82!@8'1O4W1R:6YG*"E@8`IM971H;V0@;W(@6F5N9"!%;F=I;F4@,B=S('-P
M96-I86P@8&!?7W1O4W1R:6YG*"E@8"!C87-T:6YG(&UE=&AO9"P@:70@=VEL
M;"!B90IU<V5D('1O(&1E=&5R;6EN92!T:&4@;V)J96-T)W,@<W1R:6YG(')E
M<')E<V5N=&%T:6]N+B`@3W1H97)W:7-E+"!T:&4*8'-E<FEA;&EZ961@7R!F
M;W)M(&]F('1H92!O8FIE8W0@=VEL;"!B92!L;V=G960N"@I4:&4@<V5C;VYD
M+"!O<'1I;VYA;"!A<F=U;65N="!S<&5C:69I97,@=&AE(&QO9R!E=F5N="=S
M('!R:6]R:71Y+B`@4V5E('1H90I@3&]G($QE=F5L<V!?('1A8FQE(&9O<B!T
M:&4@8V]M<&QE=&4@;&ES="!O9B!P<FEO<FET:65S+B`@5&AE(&1E9F%U;'0@
M<')I;W)I='D*:7,@4$5!4E],3T=?24Y&3RX*"E1H92!@8&QO9R@I8&`@;65T
M:&]D('=I;&P@<F5T=7)N(&!@=')U96!@(&EF('1H92!E=F5N="!W87,@<W5C
M8V5S<V9U;&QY"FQO9V=E9"X*"B)3:&]R=&-U="(@;65T:&]D<R!A<F4@86QS
M;R!A=F%I;&%B;&4@9F]R(&QO9V=I;F<@86X@979E;G0@870@82!S<&5C:69I
M8R!L;V<*;&5V96PN("!3964@=&AE(&!,;V<@3&5V96QS8%\@=&%B;&4@9F]R
M('1H92!C;VUP;&5T92!L:7-T+@H*+BX@7W-E<FEA;&EZ960Z(&AT='`Z+R]W
M=W<N<&AP+FYE="]S97)I86QI>F4*"@I,;V<@3&5V96QS"BTM+2TM+2TM+2T*
M5&AI<R!T86)L92!I<R!O<F1E<F5D(&)Y(&AI9VAE<W0@<')I;W)I='D@*&!@
M4$5!4E],3T=?14U%4D=@8"D@=&\@;&]W97-T"G!R:6]R:71Y("A@8%!%05)?
M3$]'7T1%0E5'8&`I+@H**RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM
M+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*?"!,979E;"`@("`@("`@("`@("`@("`@?"!3:&]R=&-U="`@("`@('P@
M1&5S8W)I<'1I;VX@("`@("`@("`@("`@("`@("`@("`@('P**ST]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]*ST]/3T]/3T]/3T]/3T]/2L]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/2L*?"!@8%!%05)?3$]'7T5-15)'8&`@
M("`@?"!@8&5M97)G*"E@8"`@('P@4WES=&5M(&ES('5N=7-A8FQE("`@("`@
M("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM
M+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M?"!@8%!%05)?3$]'7T%,15)48&`@("`@?"!@8&%L97)T*"E@8"`@('P@26UM
M961I871E(&%C=&EO;B!R97%U:7)E9"`@("`@("`@('P**RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8%!%05)?3$]'7T-2251@8"`@("`@
M?"!@8&-R:70H*6!@("`@('P@0W)I=&EC86P@8V]N9&ET:6]N<R`@("`@("`@
M("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM
M+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@
M8%!%05)?3$]'7T524F!@("`@("`@?"!@8&5R<B@I8&`@("`@('P@17)R;W(@
M8V]N9&ET:6]N<R`@("`@("`@("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*?"!@8%!%05)?3$]'7U=!4DY)3D=@8"`@?"!@
M8'=A<FYI;F<H*6!@('P@5V%R;FEN9R!C;VYD:71I;VYS("`@("`@("`@("`@
M("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM
M+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8%!%
M05)?3$]'7TY/5$E#16!@("`@?"!@8&YO=&EC92@I8&`@('P@3F]R;6%L(&)U
M="!S:6=N:69I8V%N="`@("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*?"!@8%!%05)?3$]'7TE.1D]@8"`@("`@?"!@8&EN
M9F\H*6!@("`@('P@26YF;W)M871I;VYA;"`@("`@("`@("`@("`@("`@("`@
M('P**RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8%!%05)?
M3$]'7T1%0E5'8&`@("`@?"!@8&1E8G5G*"E@8"`@('P@1&5B=6<M;&5V96P@
M;65S<V%G97,@("`@("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*"@I,;V<@3&5V96P@36%S:W,*+2TM+2TM+2TM+2TM+2TM
M"D1E9FEN:6YG(&$@;&]G(&QE=F5L(&UA<VL@86QL;W=S('EO=2!T;R!I;F-L
M=61E(&%N9"]O<B!E>&-L=61E('-P96-I9FEC(&QE=F5L<PIO9B!E=F5N=',@
M9G)O;2!B96EN9R!L;V=G960N("!4:&4@8&`D;&5V96Q@8"!C;VYS=')U8W1I
M;VX@<&%R86UE=&5R("AS964*8$-O;F9I9W5R:6YG(&$@2&%N9&QE<F!?*2!U
M<V5S('1H:7,@;65C:&%N:7-M('1O(&5X8VQU9&4@;&]G(&5V96YT<R!B96QO
M=R!A"F-E<G1A:6X@<')I;W)I='DL(&%N9"!I="=S('!O<W-I8FQE('1O(&1E
M9FEN92!M;W)E(&-O;7!L97@@;6%S:W,@;VYC92!T:&4@3&]G"F]B:F5C="!H
M87,@8F5E;B!C;VYS=')U8W1E9"X*"D5A8V@@<')I;W)I='D@:&%S(&$@<W!E
M8VEF:6,@;6%S:R!A<W-O8VEA=&5D('=I=&@@:70N("!4;R!C;VUP=71E(&$@
M<')I;W)I='DG<PIM87-K+"!U<V4@=&AE('-T871I8R!@8$QO9SHZ34%32R@I
M8&`@;65T:&]D.CH*"B`@("`D;6%S:R`]($QO9SHZ34%32RA014%27TQ/1U])
M3D9/*3L*"E1O(&-O;7!U=&4@=&AE(&UA<VL@9F]R(&%L;"!P<FEO<FET:65S
M('5P('1O+"!A;F0@:6YC;'5D:6YG+"!A(&-E<G1A:6X@;&5V96PL"G5S92!T
M:&4@8&!,;V<Z.DU!6"@I8&`@<W1A=&EC(&UE=&AO9#HZ"@H@("`@)&UA<VL@
M/2!,;V<Z.DU!6"A014%27TQ/1U])3D9/*3L*"E1O(&-O;7!U=&4@=&AE(&UA
M<VL@9F]R(&%L;"!P<FEO<FET:65S(&=R96%T97(@=&AA;B!O<B!E<75A;"!T
M;R!A(&-E<G1A:6X*;&5V96PL('5S92!T:&4@8&!,;V<Z.DU)3B@I8&`@<W1A
M=&EC(&UE=&AO9#HZ"@H@("`@)&UA<VL@/2!,;V<Z.DU)3BA014%27TQ/1U])
M3D9/*3L*"E1H92!A<'!L>2!T:&4@;6%S:RP@=7-E('1H92!@8'-E=$UA<VLH
M*6!@(&UE=&AO9#HZ"@H@("`@)&QO9V=E<BT^<V5T36%S:R@D;6%S:RD["@I-
M87-K<R!C86X@8F4@8F4@8V]M8FEN960@=7-I;F<@8FET=VES92!O<&5R871I
M;VYS+B`@5&\@<F5S=')I8W0@;&]G9VEN9R!T;PIO;FQY('1H;W-E(&5V96YT
M<R!M87)K960@87,@8&!014%27TQ/1U].3U1)0T5@8"!O<B!@8%!%05)?3$]'
M7T1%0E5'8&`Z.@H*("`@("1M87-K(#T@3&]G.CI-05-+*%!%05)?3$]'7TY/
M5$E#12D@?"!,;V<Z.DU!4TLH4$5!4E],3T=?1$5"54<I.PH@("`@)&QO9V=E
M<BT^<V5T36%S:R@D;6%S:RD["@I&;W(@8V]N=F5N:65N8V4L('1W;R!S<&5C
M:6%L(&UA<VMS(&%R92!P<F5D969I;F5D.B!@8%!%05)?3$]'7TY/3D5@8"!A
M;F0*8&!014%27TQ/1U]!3$Q@8"X@(&!@4$5!4E],3T=?04Q,8&`@:7,@97-P
M96-I86QL>2!U<V5F=6P@9F]R(&5X;'5D:6YG(&]N;'D*<W!E8VEF:6,@<')I
M;W)I=&EE<SHZ"@H@("`@)&UA<VL@/2!014%27TQ/1U]!3$P@7B!,;V<Z.DU!
M4TLH4$5!4E],3T=?3D]424-%*3L*("`@("1L;V=G97(M/G-E=$UA<VLH)&UA
M<VLI.PH*270@:7,@86QS;R!P;W-S:6)L92!T;R!R971R:65V92!A;F0@;6]D
M:69Y(&$@3&]G(&]B:F5C="=S(&5X:7-T:6YG(&UA<VLZ.@H*("`@("1M87-K
M(#T@)&QO9V=E<BT^9V5T36%S:R@I('P@3&]G.CI-05-+*%!%05)?3$]'7TE.
M1D\I.PH@("`@)&QO9V=E<BT^<V5T36%S:R@D;6%S:RD["@H*1FQU<VAI;F<@
M3&]G($5V96YT<PHM+2TM+2TM+2TM+2TM+2TM+2TM"E-O;64@;&]G(&AA;F1L
M97)S("AS=6-H(&%S(&!T:&4@8V]N<V]L92!H86YD;&5R8%\I('-U<'!O<G0@
M97AP;&EC:70*(F)U9F9E<FEN9R(N("!7:&5N(&)U9F9E<FEN9R!I<R!E;F%B
M;&5D+"!L;V<@979E;G1S('=O;B=T(&%C='5A;&QY(&)E('=R:71T96X*=&\@
M=&AE(&]U='!U="!S=')E86T@=6YT:6P@=&AE(&AA;F1L97(@:7,@8VQO<V5D
M+B`@3W1H97(@:&%N9&QE<G,@*'-U8V@@87,*8'1H92!F:6QE(&AA;F1L97)@
M7RD@<W5P<&]R="!I;7!L:6-I="!B=69F97)I;F<@8F5C875S92!T:&5Y('5S
M92!T:&4@;W!E<F%T:6YG"G-Y<W1E;2=S($E/(')O=71I;F5S+"!W:&EC:"!M
M87D@8G5F9F5R('1H92!O=71P=70N"@I)="=S('!O<W-I8FQE('1O(&9O<F-E
M('1H97-E(&AA;F1L97)S('1O(&9L=7-H('1H96ER(&]U='!U="P@:&]W979E
M<BP@8GD*8V%L;&EN9R!T:&5I<B!@8&9L=7-H*"E@8"!M971H;V0Z.@H*("`@
M("1C;VYF(#T@87)R87DH)V)U9F9E<FEN9R<@/3X@=')U92D["B`@("`D;&]G
M9V5R(#T@)DQO9SHZ<VEN9VQE=&]N*"=C;VYS;VQE)RP@)R<L("=T97-T)RP@
M)&-O;F8I.PH*("`@(&9O<B`H)&D@/2`P.R`D:2`\(#$P.R`D:2LK*2!["B`@
M("`@("`@)&QO9V=E<BT^;&]G*"=4:&ES(&5V96YT('=I;&P@8F4@8G5F9F5R
M960N)RD["B`@("!]"@H@("`@+RH@1FQU<V@@86QL(&]F('1H92!B=69F97)E
M9"!L;V<@979E;G1S+B`J+PH@("`@)&QO9V=E<BT^9FQU<V@H*3L*"B`@("!F
M;W(@*"1I(#T@,#L@)&D@/"`Q,#L@)&DK*RD@>PH@("`@("`@("1L;V=G97(M
M/FQO9R@G5&AI<R!E=F5N="!W:6QL(&)E(&)U9F9E<F5D+B<I.PH@("`@?0H*
M("`@("\J($EM<&QI8VET;'D@9FQU<V@@=&AE(&)U9F9E<F5D(&5V96YT<R!O
M;B!C;&]S92X@*B\*("`@("1L;V=G97(M/F-L;W-E*"D["@I!="!T:&ES('1I
M;64L('1H92!@8&9L=7-H*"E@8"!M971H;V0@:7,@;VYL>2!I;7!L96UE;G1E
M9"!B>2!@=&AE(&-O;G-O;&4*:&%N9&QE<F!?+"!@=&AE(&9I;&4@:&%N9&QE
M<F!?(&%N9"!@=&AE(&UA:6P@:&%N9&QE<F!?+@H*"E-T86YD87)D($QO9R!(
M86YD;&5R<PH]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"E1H92!#;VYS;VQE($AA
M;F1L97(*+2TM+2TM+2TM+2TM+2TM+2TM+0I4:&4@0V]N<V]L92!H86YD;&5R
M(&]U='!U=',@;&]G(&5V96YT<R!D:7)E8W1L>2!T;R!T:&4@8V]N<V]L92X@
M($ET('-U<'!O<G1S"F]U='!U="!B=69F97)I;F<@86YD(&-O;F9I9W5R86)L
M92!S=')I;F<@9F]R;6%T<RX*"D-O;F9I9W5R871I;VX*?GY^?GY^?GY^?GY^
M?@HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM
M+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(%!A<F%M971E
M<B`@("`@("`@('P@5'EP92`@("`@('P@1&5F875L="`@("`@("!\($1E<V-R
M:7!T:6]N("`@("`@("`@("`@("`@?`HK/3T]/3T]/3T]/3T]/3T]/3T]/2L]
M/3T]/3T]/3T]/2L]/3T]/3T]/3T]/3T]/3TK/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]*PI\(&!@<W1R96%M8&`@("`@("`@('P@1FEL92`@("`@('P@
M4U1$3U547R`@("`@("!\(%1H92!O=71P=70@<W1R96%M('1O('5S92X@?`HK
M+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM
M+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@8G5F9F5R:6YG
M8&`@("`@('P@0F]O;&5A;B`@('P@1F%L<V4@("`@("`@("!\(%-H;W5L9"!T
M:&4@;W5T<'5T(&)E("`@("`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@
M("`@("`@('P@("`@("`@("`@("`@("!\(&)U9F9E<F5D('5N=&EL('-H=71D
M;W=N/R`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM
M+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@
M;&EN949O<FUA=&!@("`@('P@4W1R:6YG("`@('P@8&`E,21S("4R)',@("!\
M($QO9R!L:6YE(&9O<FUA="`@("`@("`@("`@?`I\("`@("`@("`@("`@("`@
M("`@('P@("`@("`@("`@('P@6R4S)'-=("4T)'-@8"!\('-P96-I9FEC871I
M;VXN("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM
M+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PI\(&!@=&EM949O<FUA=&!@("`@('P@4W1R:6YG("`@('P@8&`E8B`E
M9"`@("`@("!\(%1I;64@<W1A;7`@9F]R;6%T("`@("`@("`@?`I\("`@("`@
M("`@("`@("`@("`@('P@("`@("`@("`@('P@)4@Z)4TZ)5-@8"`@("!\("AF
M;W(@<W1R9G1I;65?*2X@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM
M+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PH*+BX@7U-41$]55#H@:'1T<#HO+W=W=RYP:'`N;F5T
M+W=R87!P97)S+G!H<`HN+B!?<W1R9G1I;64Z(&AT='`Z+R]W=W<N<&AP+FYE
M="]S=')F=&EM90H*17AA;7!L90I^?GY^?GY^"CHZ"@H@("`@)&QO9V=E<B`]
M("9,;V<Z.G-I;F=L971O;B@G8V]N<V]L92<L("<G+"`G:61E;G0G*3L*("`@
M(&9O<B`H)&D@/2`P.R`D:2`\(#$P.R`D:2LK*2!["B`@("`@("`@)&QO9V=E
M<BT^;&]G*"),;V<@96YT<GD@)&DB*3L*("`@('T*"@I4:&4@1&ES<&QA>2!(
M86YD;&5R"BTM+2TM+2TM+2TM+2TM+2TM+2T*5&AE($1I<W!L87D@:&%N9&QE
M<B!S:6UP;'D@<')I;G1S('1H92!L;V<@979E;G1S(&)A8VL@=&\@=&AE(&)R
M;W=S97(N("!)=`IR97-P96-T<R!T:&4@8&!E<G)O<E]P<F5P96YD7W-T<FEN
M9V!@(&%N9"!@8&5R<F]R7V%P<&5N9%]S=')I;F=@8"!@97)R;W(*:&%N9&QI
M;F<@=F%L=65S8%\@86YD(&ES('5S969U;"!W:&5N(&!L;V=G:6YG(&9R;VT@
M<W1A;F1A<F0@97)R;W(@:&%N9&QE<G-@7RX*"D-O;F9I9W5R871I;VX*?GY^
M?GY^?GY^?GY^?@HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM
M+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\
M(%!A<F%M971E<B`@("`@("`@('P@5'EP92`@("`@('P@1&5F875L="`@("`@
M("!\($1E<V-R:7!T:6]N("`@("`@("`@("`@("`@?`HK/3T]/3T]/3T]/3T]
M/3T]/3T]/2L]/3T]/3T]/3T]/2L]/3T]/3T]/3T]/3T]/3TK/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]*PI\(&!@97)R;W)?<')E<&5N9&!@('P@4W1R
M:6YG("`@('P@4$A0($E.22!V86QU92!\(%1H:7,@<W1R:6YG('=I;&P@8F4@
M("`@("`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@
M("`@("`@("`@("!\('!R97!E;F1E9"!T;R!T:&4@;&]G("`@("`@?`I\("`@
M("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\
M(&]U='!U="X@("`@("`@("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM
M+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PI\(&!@97)R;W)?87!P96YD8&`@('P@4W1R:6YG
M("`@('P@4$A0($E.22!V86QU92!\(%1H:7,@<W1R:6YG('=I;&P@8F4@("`@
M("`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@
M("`@("`@("!\(&%P<&5N9&5D('1O('1H92!L;V<@("`@("`@?`I\("`@("`@
M("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\(&]U
M='!U="X@("`@("`@("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM
M+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PI\(&!@;&EN96)R96%K8&`@("`@('P@4W1R:6YG("`@
M('P@8&`\8G(@+SY<;F!@("!\(%1H:7,@<W1R:6YG(&ES('5S960@=&\@("`@
M?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@
M("`@("!\(')E<')E<V5N="!A(&QI;F4@8G)E86LN("`@?`HK+2TM+2TM+2TM
M+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PH*+BX@7V5R<F]R(&AA;F1L:6YG('9A
M;'5E<SH@:'1T<#HO+W=W=RYP:'`N;F5T+V5R<F]R9G5N8PH*17AA;7!L90I^
M?GY^?GY^"CHZ"@H@("`@)&-O;F8@/2!A<G)A>2@G97)R;W)?<')E<&5N9"<@
M/3X@)SQF;VYT(&-O;&]R/2(C9F8P,#`P(CX\='0^)RP*("`@("`@("`@("`@
M("`@("`@)V5R<F]R7V%P<&5N9"<@(#T^("<\+W1T/CPO9F]N=#XG*3L*("`@
M("1L;V=G97(@/2`F3&]G.CIS:6YG;&5T;VXH)V1I<W!L87DG+"`G)RP@)R<L
M("1C;VYF+"!014%27TQ/1U]$14)51RD["B`@("!F;W(@*"1I(#T@,#L@)&D@
M/"`Q,#L@)&DK*RD@>PH@("`@("`@("1L;V=G97(M/FQO9R@B3&]G(&5N=')Y
M("1I(BD["B`@("!]"@H*5&AE($5R<F]R7TQO9R!(86YD;&5R"BTM+2TM+2TM
M+2TM+2TM+2TM+2TM+0I4:&4@17)R;W)?3&]G(&AA;F1L97(@<V5N9',@;&]G
M(&5V96YT<R!T;R!02%`G<R!@97)R;W)?;&]G*"E@7R!F=6YC=&EO;BX*"D-O
M;F9I9W5R871I;VX*?GY^?GY^?GY^?GY^?@HK+2TM+2TM+2TM+2TM+2TM+2TM
M+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PI\(%!A<F%M971E<B`@("`@("`@('P@5'EP92`@("`@
M('P@1&5F875L="`@("`@("!\($1E<V-R:7!T:6]N("`@("`@("`@("`@("`@
M?`HK/3T]/3T]/3T]/3T]/3T]/3T]/2L]/3T]/3T]/3T]/2L]/3T]/3T]/3T]
M/3T]/3TK/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]*PI\(&!@9&5S=&EN
M871I;VY@8"`@('P@4W1R:6YG("`@('P@)R<@8"AE;7!T>2E@("!\($]P=&EO
M;F%L(&1E<W1I;F%T:6]N('9A;'5E?`I\("`@("`@("`@("`@("`@("`@('P@
M("`@("`@("`@('P@("`@("`@("`@("`@("!\(&9O<B!@97)R;W)?;&]G*"E@
M7RX@(%-E92`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@
M("`@("`@("`@("`@("!\(&!%<G)O<E],;V<@5'EP97-@7R!F;W(@("`@?`I\
M("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@
M("!\(&UO<F4@9&5T86EL<RX@("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM
M+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@97AT<F%?:&5A9&5R<V!@('P@4W1R
M:6YG("`@('P@)R<@8"AE;7!T>2E@("!\($%D9&ET:6]N86P@:&5A9&5R<R!T
M;R!P87-S?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@
M("`@("`@("`@("!\('1O('1H92!@;6%I;"@I8%\@9G5N8W1I;VX@?`I\("`@
M("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\
M('=H96X@=&AE("`@("`@("`@("`@("`@("`@?`I\("`@("`@("`@("`@("`@
M("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\(&!@4$5!4E],3T=?
M5%E015]-04E,8&`@("`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@
M("`@('P@("`@("`@("`@("`@("!\('1Y<&4@:7,@<W!E8VEF:65D+B`@("`@
M("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM
M+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PH*17)R;W)?
M3&]G(%1Y<&5S"GY^?GY^?GY^?GY^?GY^?@I!;&P@;V8@=&AE(&%V86EL86)L
M92!L;V<@='EP97,@87)E(&1E=&%I;&5D(&EN('1H92!@97)R;W)?;&]G*"E@
M7R!S96-T:6]N(&]F"G1H92!02%`@;6%N=6%L+B`@1F]R('EO=7(@8V]N=F5N
M:65N8V4L('1H92!,;V<@<&%C:V%G92!A;'-O(&1E9FEN97,@=&AE"F9O;&QO
M=VEN9R!C;VYS=&%N=',@=&AA="!C86X@8F4@=7-E9"!F;W(@=&AE(&!@)&YA
M;65@8"!H86YD;&5R(&-O;G-T<G5C=&EO;@IP87)A;65T97(N"@HK+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\($-O;G-T86YT("`@("`@("`@
M("`@("`@("`@?"!$97-C<FEP=&EO;B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HK/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]*ST]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M*PI\(&!@4$5!4E],3T=?5%E015]365-414U@8"`@?"!,;V<@979E;G1S(&%R
M92!S96YT('1O(%!(4"=S('-Y<W1E;2!L;V=G97(L("`@?`I\("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?"!W:&EC:"!U<V5S('1H92!O<&5R871I;F<@
M<WES=&5M)W,@;&]G9VEN9R`@("`@?`I\("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?"!M96-H86YI<VT@;W(@82!F:6QE("AD97!E;F1I;F<@;VX@=&AE
M('9A;'5E("`@?`I\("`@("`@("`@("`@("`@("`@("`@("`@("`@?"!O9B!T
M:&4@8&5R<F]R7VQO9R!C;VYF:6=U<F%T:6]N(&1I<F5C=&EV96!?*2X@?`HK
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@4$5!4E],3T=?
M5%E015]-04E,8&`@("`@?"!,;V<@979E;G1S(&%R92!S96YT('9I82!E;6%I
M;"!T;R!T:&4@861D<F5S<R`@?`I\("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?"!S<&5C:69I960@:6X@=&AE(&!@9&5S=&EN871I;VY@8"!V86QU92X@
M("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@
M4$5!4E],3T=?5%E015]$14)51V!@("`@?"!,;V<@979E;G1S(&%R92!S96YT
M('1H<F]U9V@@4$A0)W,@9&5B=6=G:6YG("`@?`I\("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?"!C;VYN96-T:6]N+B`@5&AI<R!W:6QL(&]N;'D@=V]R
M:R!I9B`@("`@("`@("`@?`I\("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?"!@<F5M;W1E(&1E8G5G9VEN9V!?(&AA<R!B965N(&5N86)L960N("!4:&4@
M("`@?`I\("`@("`@("`@("`@("`@("`@("`@("`@("`@?"!@8&1E<W1I;F%T
M:6]N8&`@=F%L=64@:7,@=7-E9"!T;R!S<&5C:69Y('1H92`@?`I\("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?"!H;W-T(&YA;64@;W(@25`@861D<F5S
M<R!O9B!T:&4@=&%R9V5T('-O8VME="X@?`HK+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PI\(&!@4$5!4E],3T=?5%E015]&24Q%8&`@("`@?"!,
M;V<@979E;G1S('=I;&P@8F4@87!P96YD960@=&\@=&AE(&9I;&4@;F%M960@
M?`I\("`@("`@("`@("`@("`@("`@("`@("`@("`@?"!B>2!T:&4@8&!D97-T
M:6YA=&EO;F!@('9A;'5E+B`@("`@("`@("`@("`@("`@?`HK+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PH*+BX@7V5R<F]R7VQO9R@I.B!H='1P
M.B\O=W=W+G!H<"YN970O97)R;W)?;&]G"BXN(%]M86EL*"DZ(&AT='`Z+R]W
M=W<N<&AP+FYE="]M86EL"BXN(%]E<G)O<E]L;V<@8V]N9FEG=7)A=&EO;B!D
M:7)E8W1I=F4Z(&AT='`Z+R]W=W<N<&AP+FYE="]E<G)O<F9U;F,C:6YI+F5R
M<F]R+6QO9PHN+B!?<F5M;W1E(&1E8G5G9VEN9SH@:'1T<#HO+W=W=RYP:'`N
M;F5T+VEN<W1A;&PN8V]N9FEG=7)E(VEN<W1A;&PN8V]N9FEG=7)E+F5N86)L
M92UD96)U9V=E<@H*17AA;7!L90I^?GY^?GY^"CHZ"@H@("`@)&QO9V=E<B`]
M("9,;V<Z.G-I;F=L971O;B@G97)R;W)?;&]G)RP@4$5!4E],3T=?5%E015]3
M65-414TL("=I9&5N="<I.PH@("`@9F]R("@D:2`](#`[("1I(#P@,3`[("1I
M*RLI('L*("`@("`@("`D;&]G9V5R+3YL;V<H(DQO9R!E;G1R>2`D:2(I.PH@
M("`@?0H*"E1H92!&:6QE($AA;F1L97(*+2TM+2TM+2TM+2TM+2TM+0I4:&4@
M1FEL92!H86YD;&5R('=R:71E<R!L;V<@979E;G1S('1O(&$@=&5X="!F:6QE
M('5S:6YG(&-O;F9I9W5R86)L92!S=')I;F<*9F]R;6%T<RX*"D-O;F9I9W5R
M871I;VX*?GY^?GY^?GY^?GY^?@HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM
M+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PI\(%!A<F%M971E<B`@("`@("`@('P@5'EP92`@("`@('P@1&5F
M875L="`@("`@("!\($1E<V-R:7!T:6]N("`@("`@("`@("`@("`@?`HK/3T]
M/3T]/3T]/3T]/3T]/3T]/2L]/3T]/3T]/3T]/2L]/3T]/3T]/3T]/3T]/3TK
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]*PI\(&!@87!P96YD8&`@("`@
M("`@('P@0F]O;&5A;B`@('P@5')U92`@("`@("`@("!\(%-H;W5L9"!N97<@
M;&]G(&5N=')I97,@8F4@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@
M("`@('P@("`@("`@("`@("`@("!\(&%P<&5N9"!T;R!A;B!E>&ES=&EN9R!L
M;V<@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@
M("`@("`@("!\(&9I;&4L(&]R('-H;W5L9"!T:&4@82!N97<@?`I\("`@("`@
M("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\(&QO
M9R!F:6QE(&]V97)W<FET92!A;B`@("`@?`I\("`@("`@("`@("`@("`@("`@
M('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\(&5X:7-T:6YG(&]N93\@
M("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM
M+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PI\(&!@;&]C:VEN9V!@("`@("`@('P@0F]O;&5A;B`@('P@1F%L<V4@("`@
M("`@("!\(%-H;W5L9"!A9'9I<V]R>2!F:6QE("`@("`@?`I\("`@("`@("`@
M("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\(&QO8VMI
M;F<@*'5S:6YG(&9L;V-K7RD@8F4@?`I\("`@("`@("`@("`@("`@("`@('P@
M("`@("`@("`@('P@("`@("`@("`@("`@("!\('5S960_("`@("`@("`@("`@
M("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM
M+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\
M(&!@;6]D96!@("`@("`@("`@('P@26YT96=E<B`@('P@,#8T-"`@("`@("`@
M("!\($]C=&%L(')E<')E<V5N=&%T:6]N(&]F("`@?`I\("`@("`@("`@("`@
M("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\('1H92!L;V<@
M9FEL92=S('!E<FUI<W-I;VYS?`I\("`@("`@("`@("`@("`@("`@('P@("`@
M("`@("`@('P@("`@("`@("`@("`@("!\(&UO9&4N("`@("`@("`@("`@("`@
M("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM
M+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@
M9&ER;6]D96!@("`@("`@('P@26YT96=E<B`@('P@,#<U-2`@("`@("`@("!\
M($]C=&%L(')E<')E<V5N=&%T:6]N(&]F("`@?`I\("`@("`@("`@("`@("`@
M("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\('1H92!F:6QE('!E
M<FUI<W-I;VX@;6]D92`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@
M("`@('P@("`@("`@("`@("`@("!\('1H870@=VEL;"!B92!U<V5D('=H96X@
M("`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@
M("`@("`@("!\(&-R96%T:6YG(&1I<F5C=&]R:65S('1H870@?`I\("`@("`@
M("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\(&1O
M(&YO="!A;')E861Y(&5X:7-T+B`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM
M+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PI\(&!@96]L8&`@("`@("`@("`@('P@4W1R:6YG("`@
M('P@3U,@9&5F875L="`@("!\(%1H92!E;F0M;VXM;&EN92!C:&%R86-T97(@
M?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@
M("`@("!\('-E<75E;F-E+B`@("`@("`@("`@("`@("`@?`HK+2TM+2TM+2TM
M+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@;&EN949O<FUA=&!@("`@('P@
M4W1R:6YG("`@('P@8&`E,21S("4R)',@("!\($QO9R!L:6YE(&9O<FUA="`@
M("`@("`@("`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@
M6R4S)'-=("4T)'-@8"!\('-P96-I9FEC871I;VXN("`@("`@("`@("`@?`HK
M+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM
M+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@=&EM949O<FUA
M=&!@("`@('P@4W1R:6YG("`@('P@8&`E8B`E9"`@("`@("!\(%1I;64@<W1A
M;7`@9F]R;6%T("`@("`@("`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@
M("`@("`@('P@)4@Z)4TZ)5-@8"`@("!\("AF;W(@<W1R9G1I;65?*2X@("`@
M("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM
M+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PH*+BX@
M7V9L;V-K.B!H='1P.B\O=W=W+G!H<"YN970O9FQO8VL*+BX@7W-T<F9T:6UE
M.B!H='1P.B\O=W=W+G!H<"YN970O<W1R9G1I;64*"E1H92!F:6QE(&AA;F1L
M97(@=VEL;"!O;FQY(&%T=&5M<'0@=&\@<V5T('1H92!@8&UO9&5@8"!V86QU
M92!I9B!I="!W87,*<F5S<&]N<VEB;&4@9F]R(&-R96%T:6YG('1H92!F:6QE
M+@H*17AA;7!L90I^?GY^?GY^"CHZ"@H@("`@)&-O;F8@/2!A<G)A>2@G;6]D
M92<@/3X@,#8P,"P@)W1I;65&;W)M870G(#T^("<E6"`E>"<I.PH@("`@)&QO
M9V=E<B`]("9,;V<Z.G-I;F=L971O;B@G9FEL92<L("=O=70N;&]G)RP@)VED
M96YT)RP@)&-O;F8I.PH@("`@9F]R("@D:2`](#`[("1I(#P@,3`[("1I*RLI
M('L*("`@("`@("`D;&]G9V5R+3YL;V<H(DQO9R!E;G1R>2`D:2(I.PH@("`@
M?0H*"E1H92!-86EL($AA;F1L97(*+2TM+2TM+2TM+2TM+2TM+0I4:&4@36%I
M;"!H86YD;&5R(&%G9W)E9V%T97,@82!S97-S:6]N)W,@;&]G(&5V96YT<R!A
M;F0@<V5N9',@=&AE;2!I;B!T:&4@8F]D>0IO9B!A;B!E;6%I;"!M97-S86=E
M('5S:6YG(%!(4"=S(&!M86EL*"E@7R!F=6YC=&EO;BX*"D-O;F9I9W5R871I
M;VX*?GY^?GY^?GY^?GY^?@HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM
M+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PI\(%!A<F%M971E<B`@("`@("`@('P@5'EP92`@("`@('P@1&5F875L
M="`@("`@("!\($1E<V-R:7!T:6]N("`@("`@("`@("`@("`@?`HK/3T]/3T]
M/3T]/3T]/3T]/3T]/2L]/3T]/3T]/3T]/2L]/3T]/3T]/3T]/3T]/3TK/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]*PI\(&!@9G)O;6!@("`@("`@("`@
M('P@4W1R:6YG("`@('P@<V5N9&UA:6Q?9G)O;2!\(%9A;'5E(&9O<B!T:&4@
M;65S<V%G92=S("`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@
M('P@24Y)('9A;'5E("`@("!\(&!@1G)O;3I@8"!H96%D97(N("`@("`@("`@
M?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM
M+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@<W5B:F5C
M=&!@("`@("`@('P@4W1R:6YG("`@('P@8&!;3&]G7VUA:6Q=("!\(%9A;'5E
M(&9O<B!T:&4@;65S<V%G92=S("`@?`I\("`@("`@("`@("`@("`@("`@('P@
M("`@("`@("`@('P@3&]G(&UE<W-A9V5@8"!\(&!@4W5B:F5C=#I@8"!H96%D
M97(N("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM
M+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\
M(&!@<')E86UB;&5@8"`@("`@('P@4W1R:6YG("`@('P@8&`@8"AE;7!T>2E@
M("!\(%!R96%M8FQE(&9O<B!T:&4@;65S<V%G92X@?`HK+2TM+2TM+2TM+2TM
M+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@;&EN949O<FUA=&!@("`@('P@4W1R
M:6YG("`@('P@8&`E,21S("4R)',@("!\($QO9R!L:6YE(&9O<FUA="`@("`@
M("`@("`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@6R4S
M)'-=("4T)'-@8"!\('-P96-I9FEC871I;VXN("`@("`@("`@("`@?`HK+2TM
M+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@=&EM949O<FUA=&!@
M("`@('P@4W1R:6YG("`@('P@8&`E8B`E9"`@("`@("!\(%1I;64@<W1A;7`@
M9F]R;6%T("`@("`@("`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@
M("`@('P@)4@Z)4TZ)5-@8"`@("!\("AF;W(@<W1R9G1I;65?*2X@("`@("`@
M("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM
M+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PH*+BX@7VUA
M:6PH*3H@:'1T<#HO+W=W=RYP:'`N;F5T+VUA:6P*"D5X86UP;&4*?GY^?GY^
M?@HZ.@H*("`@("1C;VYF(#T@87)R87DH)W-U8FIE8W0G(#T^("=);7!O<G1A
M;G0@3&]G($5V96YT<R<I.PH@("`@)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O
M;B@G;6%I;"<L("=W96)M87-T97)`97AA;7!L92YC;VTG+"`G:61E;G0G+"`D
M8V]N9BD["B`@("!F;W(@*"1I(#T@,#L@)&D@/"`Q,#L@)&DK*RD@>PH@("`@
M("`@("1L;V=G97(M/FQO9R@B3&]G(&5N=')Y("1I(BD["B`@("!]"@H*5&AE
M($U$0C(@2&%N9&QE<@HM+2TM+2TM+2TM+2TM+2TM"E1H92!-1$(R(&AA;F1L
M97(@:7,@<VEM:6QA<B!T;R!@=&AE(%-13"`H1$(I(&AA;F1L97)@7RP@8G5T
M(&EN<W1E860@;V8@=7-I;F<*=&AE(%!%05(@1$(@<&%C:V%G92P@:70@=7-E
M<R!T:&4@8$U$0C(@9&%T86)A<V4@86)S=')A8W1I;VX@<&%C:V%G96!?+@H*
M0V]N9FEG=7)A=&EO;@I^?GY^?GY^?GY^?GY^"BLM+2TM+2TM+2TM+2TM+2TM
M+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"GP@4&%R86UE=&5R("`@("`@("`@?"!4>7!E("`@
M("`@?"!$969A=6QT("`@("`@('P@1&5S8W)I<'1I;VX@("`@("`@("`@("`@
M("!\"BL]/3T]/3T]/3T]/3T]/3T]/3T]*ST]/3T]/3T]/3T]*ST]/3T]/3T]
M/3T]/3T]/2L]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3TK"GP@8&!D<VY@
M8"`@("`@("`@("`@?"!-:7AE9"`@("`@?"`G)R!@*&5M<'1Y*6`@('P@02!@
M1&%T82!3;W5R8V4@3F%M96!?+B`@("!\"GP@("`@("`@("`@("`@("`@("`@
M?"`@("`@("`@("`@?"`@("`@("`@("`@("`@('P@?')E<75I<F5D?"`@("`@
M("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM
M*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"GP@8&!O<'1I;VYS8&`@("`@("`@?"!!<G)A>2`@("`@?"!@8'!E<G-I<W1E
M;G1@8'P@06X@87)R87D@;V8@8$U$0C)@7R`@("`@("!\"GP@("`@("`@("`@
M("`@("`@("`@?"`@("`@("`@("`@?"`@("`@("`@("`@("`@('P@;W!T:6]N
M<RX@("`@("`@("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM
M+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"GP@8&!D8F!@("`@("`@("`@("`@?"!/8FIE8W0@("`@?"!.
M54Q,("`@("`@("`@('P@06X@97AI<W1I;F<@8$U$0C)@7R`@("`@("!\"GP@
M("`@("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"`@("`@("`@("`@("`@
M('P@;V)J96-T+B`@268@<W!E8VEF:65D+"`@("!\"GP@("`@("`@("`@("`@
M("`@("`@?"`@("`@("`@("`@?"`@("`@("`@("`@("`@('P@=&AI<R!O8FIE
M8W0@=VEL;"!B92!U<V5D+"!\"GP@("`@("`@("`@("`@("`@("`@?"`@("`@
M("`@("`@?"`@("`@("`@("`@("`@('P@86YD(&!@9'-N8&`@=VEL;"!B92`@
M("`@("!\"GP@("`@("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"`@("`@
M("`@("`@("`@('P@:6=N;W)E9"X@("`@("`@("`@("`@("`@("!\"BLM+2TM
M+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!S97%U96YC96!@("`@
M("`@?"!3=')I;F<@("`@?"!@8&QO9U]I9&!@("`@('P@5&AE(&YA;64@;V8@
M=&AE('-E<75E;F-E("!\"GP@("`@("`@("`@("`@("`@("`@?"`@("`@("`@
M("`@?"`@("`@("`@("`@("`@('P@=&\@=7-E('=H96X@9V5N97)A=&EN9R`@
M("!\"GP@("`@("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"`@("`@("`@
M("`@("`@('P@=6YI<75E(&5V96YT($E$<RX@("!5;F1E<B!\"GP@("`@("`@
M("`@("`@("`@("`@?"`@("`@("`@("`@?"`@("`@("`@("`@("`@('P@;6%N
M>2!D871A8F%S97,L('1H:7,@=VEL;"!\"GP@("`@("`@("`@("`@("`@("`@
M?"`@("`@("`@("`@?"`@("`@("`@("`@("`@('P@8F4@=7-E9"!A<R!T:&4@
M;F%M92!O9B`@("!\"GP@("`@("`@("`@("`@("`@("`@?"`@("`@("`@("`@
M?"`@("`@("`@("`@("`@('P@=&AE('-E<75E;F-E('1A8FQE+B`@("`@("!\
M"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM
M+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!I9&5N=$QI
M;6ET8&`@("`@?"!);G1E9V5R("`@?"`Q-B`@("`@("`@("`@('P@5&AE(&UA
M>&EM=6T@;&5N9W1H(&]F('1H92!\"GP@("`@("`@("`@("`@("`@("`@?"`@
M("`@("`@("`@?"`@("`@("`@("`@("`@('P@8&!I9&5N=&!@('-T<FEN9RX@
M("`@("`@("!\"GP@("`@("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"`@
M("`@("`@("`@("`@('P@*BI#:&%N9VEN9R!T:&ES('9A;'5E(&UA>2!\"GP@
M("`@("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"`@("`@("`@("`@("`@
M('P@<F5Q=6ER92!U<&1A=&5S('1O('1H92!344Q\"GP@("`@("`@("`@("`@
M("`@("`@?"`@("`@("`@("`@?"`@("`@("`@("`@("`@('P@<V-H96UA+"!A
M<R!W96QL+BHJ("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM
M+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"GP@8&!S:6YG;&5T;VY@8"`@("`@?"!";V]L96%N("`@?"!F86QS
M92`@("`@("`@('P@27,@=')U92P@=7-E(&$@<VEN9VQE=&]N("!\"GP@("`@
M("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"`@("`@("`@("`@("`@('P@
M9&%T86)A<V4@;V)J96-T('5S:6YG("`@("!\"GP@("`@("`@("`@("`@("`@
M("`@?"`@("`@("`@("`@?"`@("`@("`@("`@("`@('P@8$U$0C(Z.G-I;F=L
M971O;B@I8%\N("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM
M+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"@HN+B!?341",CH@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+TU$
M0C(*+BX@7TU$0C(@9&%T86)A<V4@86)S=')A8W1I;VX@<&%C:V%G93H@341"
M,E\*+BX@7TU$0C(Z.G-I;F=L971O;B@I.B!H='1P.B\O<&5A<BYP:'`N;F5T
M+W!A8VMA9V4O341",B]D;V-S+VQA=&5S="]-1$(R+TU$0C(N:'1M;"-M971H
M;V1S:6YG;&5T;VX*"E1H92!.=6QL($AA;F1L97(*+2TM+2TM+2TM+2TM+2TM
M+0I4:&4@3G5L;"!H86YD;&5R('-I;7!L>2!C;VYS=6UE<R!L;V<@979E;G1S
M("AA:VEN('1O('-E;F1I;F<@=&AE;2!T;PI@8"]D978O;G5L;&!@*2X@(&!,
M;V<@;&5V96P@;6%S:W-@7R!A<F4@<F5S<&5C=&5D+"!A;F0@=&AE(&5V96YT
M('=I;&P@<W1I;&P@8F4*<V5N="!T;R!A;GD@<F5G:7-T97)E9"!@;&]G(&]B
M<V5R=F5R<V!?+@H*17AA;7!L90I^?GY^?GY^"CHZ"@H@("`@)&QO9V=E<B`]
M("9,;V<Z.G-I;F=L971O;B@G;G5L;"<I.PH@("`@9F]R("@D:2`](#`[("1I
M(#P@,3`[("1I*RLI('L*("`@("`@("`D;&]G9V5R+3YL;V<H(DQO9R!E;G1R
M>2`D:2(I.PH@("`@?0H*"E1H92!344P@*$1"*2!(86YD;&5R"BTM+2TM+2TM
M+2TM+2TM+2TM+2TM"@I4:&4@4U%,(&AA;F1L97(@<V5N9',@;&]G(&5V96YT
M<R!T;R!A(&1A=&%B87-E('5S:6YG(&!014%2)W,@1$(@86)S=')A8W1I;VX*
M;&%Y97)@7RX*"BHJ3F]T93HJ*B!$=64@=&\@=&AE(&-O;G-T<F%I;G1S(&]F
M('1H92!D969A=6QT(&1A=&%B87-E('-C:&5M82P@=&AE(%-13`IH86YD;&5R
M(&QI;6ET<R!T:&4@;&5N9W1H(&]F('1H92!@8"1I9&5N=&!@('-T<FEN9R!T
M;R!S:7AT965N("@Q-BD@8VAA<F%C=&5R<RX*5&AI<R!L:6UI="!C86X@8F4@
M861J=7-T960@=7-I;F<@=&AE(&!@:61E;G1,:6UI=&!@(&-O;F9I9W5R871I
M;VX@<&%R86UE=&5R+@H*5&AE($QO9R!486)L90I^?GY^?GY^?GY^?GY^"E1H
M92!D969A=6QT(%-13"!T86)L92!U<V5D(&)Y('1H:7,@:&%N9&QE<B!L;V]K
M<R!L:6ME('1H:7,Z.@H*("`@($-214%412!404),12!L;V=?=&%B;&4@*`H@
M("`@("`@(&ED("`@("`@("`@($E.5"!.3U0@3E5,3"P*("`@("`@("!L;V=T
M:6UE("`@("!424U%4U1!35`@3D]4($Y53$PL"B`@("`@("`@:61E;G0@("`@
M("`@0TA!4B@Q-BD@3D]4($Y53$PL"B`@("`@("`@<')I;W)I='D@("`@24Y4
M($Y/5"!.54Q,+`H@("`@("`@(&UE<W-A9V4@("`@(%9!4D-(05(H,C`P*2P*
M("`@("`@("!04DE-05)9($M%62`H:60I"B`@("`I.PH*5&AI<R!I<R!T:&4@
M(FQO=V5S="!C;VUM;VX@9&5N;VUI;F%T;W(B('1H870@<VAO=6QD('=O<FL@
M86-R;W-S(&%L;"!344P*8V]M<&QI86YT(&1A=&%B87-E+B`@66]U(&UA>2!W
M86YT('1O(&UA:V4@9&%T86)A<V4M(&]R('-I=&4M<W!E8VEF:6,@8VAA;F=E
M<PIT;R!T:&ES('-C:&5M82!T;R!S=7!P;W)T('EO=7(@<W!E8VEF:6,@;F5E
M9',L(&AO=V5V97(N("!&;W(@97AA;7!L92P*8%!O<W1G<F5344Q@7R!U<V5R
M<R!M87D@<')E9F5R('1O('5S92!A(&!@5$585&!@('1Y<&4@9F]R('1H92!@
M8&UE<W-A9V5@8`IF:65L9"X*"BXN(%]0;W-T9W)E4U%,.B!H='1P.B\O=W=W
M+G!O<W1G<F5S<6PN;W)G+PH*0V]N9FEG=7)A=&EO;@I^?GY^?GY^?GY^?GY^
M"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM
M+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@4&%R86UE=&5R
M("`@("`@("`@?"!4>7!E("`@("`@?"!$969A=6QT("`@("`@('P@1&5S8W)I
M<'1I;VX@("`@("`@("`@("`@("!\"BL]/3T]/3T]/3T]/3T]/3T]/3T]*ST]
M/3T]/3T]/3T]*ST]/3T]/3T]/3T]/3T]/2L]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3TK"GP@8&!D<VY@8"`@("`@("`@("`@?"!-:7AE9"`@("`@?"`G
M)R!@*&5M<'1Y*6`@('P@02!@1&%T82!3;W5R8V4@3F%M96!?+B`@("!\"GP@
M("`@("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"`@("`@("`@("`@("`@
M('P@?')E<75I<F5D?"`@("`@("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM
M+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!S<6Q@8"`@("`@("`@("`@?"!3=')I
M;F<@("`@?"!\<W%L+61E9F%U;'1\('P@4U%,(&EN<V5R=&EO;B!S=&%T96UE
M;G0N("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM
M+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!O
M<'1I;VYS8&`@("`@("`@?"!!<G)A>2`@("`@?"!@8'!E<G-I<W1E;G1@8'P@
M06X@87)R87D@;V8@8$1"8%\@;W!T:6]N<RY\"BLM+2TM+2TM+2TM+2TM+2TM
M+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"GP@8&!D8F!@("`@("`@("`@("`@?"!/8FIE8W0@
M("`@?"!.54Q,("`@("`@("`@('P@06X@97AI<W1I;F<@8$1"8%\@;V)J96-T
M+B!\"GP@("`@("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"`@("`@("`@
M("`@("`@('P@268@<W!E8VEF:65D+"!T:&ES(&]B:F5C="!\"GP@("`@("`@
M("`@("`@("`@("`@?"`@("`@("`@("`@?"`@("`@("`@("`@("`@('P@=VEL
M;"!B92!U<V5D+"!A;F0@8&!D<VY@8"!\"GP@("`@("`@("`@("`@("`@("`@
M?"`@("`@("`@("`@?"`@("`@("`@("`@("`@('P@=VEL;"!B92!I9VYO<F5D
M+B`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM
M*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"GP@8&!S97%U96YC96!@("`@("`@?"!3=')I;F<@("`@?"!@8&QO9U]I9&!@
M("`@('P@5&AE(&YA;64@;V8@=&AE('-E<75E;F-E("!\"GP@("`@("`@("`@
M("`@("`@("`@?"`@("`@("`@("`@?"`@("`@("`@("`@("`@('P@=&\@=7-E
M('=H96X@9V5N97)A=&EN9R`@("!\"GP@("`@("`@("`@("`@("`@("`@?"`@
M("`@("`@("`@?"`@("`@("`@("`@("`@('P@=6YI<75E(&5V96YT($E$<RX@
M("!5;F1E<B!\"GP@("`@("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"`@
M("`@("`@("`@("`@('P@;6%N>2!D871A8F%S97,L('1H:7,@=VEL;"!\"GP@
M("`@("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"`@("`@("`@("`@("`@
M('P@8F4@=7-E9"!A<R!T:&4@;F%M92!O9B`@("!\"GP@("`@("`@("`@("`@
M("`@("`@?"`@("`@("`@("`@?"`@("`@("`@("`@("`@('P@=&AE('-E<75E
M;F-E('1A8FQE+B`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM
M+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"GP@8&!I9&5N=$QI;6ET8&`@("`@?"!);G1E9V5R("`@?"`Q-B`@
M("`@("`@("`@('P@5&AE(&UA>&EM=6T@;&5N9W1H(&]F('1H92!\"GP@("`@
M("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"`@("`@("`@("`@("`@('P@
M8&!I9&5N=&!@('-T<FEN9RX@("`@("`@("!\"GP@("`@("`@("`@("`@("`@
M("`@?"`@("`@("`@("`@?"`@("`@("`@("`@("`@('P@*BI#:&%N9VEN9R!T
M:&ES('9A;'5E(&UA>2!\"GP@("`@("`@("`@("`@("`@("`@?"`@("`@("`@
M("`@?"`@("`@("`@("`@("`@('P@<F5Q=6ER92!U<&1A=&5S('1O('1H92!3
M44Q\"GP@("`@("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"`@("`@("`@
M("`@("`@('P@<V-H96UA+"!A<R!W96QL+BHJ("`@("`@("!\"BLM+2TM+2TM
M+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"@I4:&4@;F%M92!O9B!T:&4@9&%T
M86)A<V4@=&%B;&4@=&\@=VAI8V@@=&AE(&QO9R!E;G1R:65S('=I;&P@8F4@
M=W)I='1E;B!I<PIS<&5C:69I960@=7-I;F<@=&AE(&!@)&YA;65@8"!C;VYS
M=')U8W1I;VX@<&%R86UE=&5R("AS964@8$-O;F9I9W5R:6YG(&$*2&%N9&QE
M<F!?*2X*"BXN('QS<6PM9&5F875L='P@<F5P;&%C93HZ(&!@24Y315)4($E.
M5$\@)'1A8FQE("AI9"P@;&]G=&EM92P@:61E;G0L('!R:6]R:71Y+"!M97-S
M86=E*2!604Q515,H/RP@0U524D5.5%]424U%4U1!35`L(#\L(#\L(#\I8&`*
M"BXN(%]$0CH@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1""BXN(%]0
M14%2)W,@1$(@86)S=')A8W1I;VX@;&%Y97(Z($1"7PHN+B!?1&%T82!3;W5R
M8V4@3F%M93H@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G
M92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP"@I%>&%M<&QE<PI^?GY^?GY^
M?@I5<VEN9R!A(&!$871A(%-O=7)C92!.86UE8%\@=&\@8W)E871E(&$@;F5W
M(&1A=&%B87-E(&-O;FYE8W1I;VXZ.@H*("`@("1C;VYF(#T@87)R87DH)V1S
M;B<@/3X@)W!G<W%L.B\O:F]N0&QO8V%L:&]S="MU;FEX+VQO9W,G*3L*("`@
M("1L;V=G97(@/2`F3&]G.CIS:6YG;&5T;VXH)W-Q;"<L("=L;V=?=&%B;&4G
M+"`G:61E;G0G+"`D8V]N9BD["B`@("!F;W(@*"1I(#T@,#L@)&D@/"`Q,#L@
M)&DK*RD@>PH@("`@("`@("1L;V=G97(M/FQO9R@B3&]G(&5N=')Y("1I(BD[
M"B`@("!]"@I5<VEN9R!A;B!E>&ES=&EN9R!@1$)@7R!O8FIE8W0Z.@H*("`@
M(')E<75I<F5?;VYC92`G1$(N<&AP)SL*("`@("1D8B`]("9$0CHZ8V]N;F5C
M="@G<&=S<6PZ+R]J;VY`;&]C86QH;W-T*W5N:7@O;&]G<R<I.PH*("`@("1C
M;VYF6R=D8B==(#T@)&1B.PH@("`@)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O
M;B@G<W%L)RP@)VQO9U]T86)L92<L("=I9&5N="<L("1C;VYF*3L*("`@(&9O
M<B`H)&D@/2`P.R`D:2`\(#$P.R`D:2LK*2!["B`@("`@("`@)&QO9V=E<BT^
M;&]G*"),;V<@96YT<GD@)&DB*3L*("`@('T*"@I4:&4@4W%L:71E($AA;F1L
M97(*+2TM+2TM+2TM+2TM+2TM+2TM"CI!=71H;W(Z("`@("`@("!"97)T<F%N
M9"!-86YS:6]N"CI#;VYT86-T.B`@("`@("!B;6%N<VEO;D!M86UA<V%M+F-O
M;0H*5&AE(%-Q;&ET92!H86YD;&5R('-E;F1S(&QO9R!E=F5N=',@=&\@86X@
M4W%L:71E(&1A=&%B87-E('5S:6YG('1H92!@;F%T:79E"E!(4"!S<6QI=&4@
M9G5N8W1I;VYS8%\N"@I)="!I<R!F87-T97(@=&AA;B!@=&AE(%-13"`H1$(I
M(&AA;F1L97)@7R!B96-A=7-E(')E<75E<W1S(&%R92!M861E(&1I<F5C=&QY
M"G1O('1H92!D871A8F%S92!W:71H;W5T('5S:6YG(&%N(&%B<W1R86-T:6]N
M(&QA>65R+B`@270@:7,@86QS;R!I;G1E<F5S=&EN9R!T;PIN;W1E('1H870@
M4W%L:71E(&1A=&%B87-E(&9I;&5S(&-A;B!B92!M;W9E9"P@8V]P:65D+"!A
M;F0@9&5L971E9"!O;B!Y;W5R"G-Y<W1E;2!J=7-T(&QI:V4@86YY(&]T:&5R
M(&9I;&5S+"!W:&EC:"!M86ME<R!L;V<@;6%N86=E;65N="!E87-I97(N("!,
M87-T(&)U=`IN;W0@;&5A<W0L('5S:6YG(&$@9&%T86)A<V4@=&\@;&]G('EO
M=7(@979E;G1S(&%L;&]W<R!Y;W4@=&\@=7-E(%-13"!Q=65R:65S"G1O(&-R
M96%T92!R97!O<G1S(&%N9"!S=&%T:7-T:6-S+@H*5VAE;B!U<VEN9R!A(&1A
M=&%B87-E(&%N9"!L;V=G:6YG(&$@;&]T(&]F(&5V96YT<RP@:70@:7,@<F5C
M;VUM96YD960@=&\@<W!L:70*=&AE(&1A=&%B87-E(&EN=&\@<VUA;&QE<B!D
M871A8F%S97,N("!4:&ES(&ES(&%L;&]W960@8GD@4W%L:71E+"!A;F0@>6]U
M(&-A;@IL871E<B!U<V4@=&AE(%-Q;&ET92!@051404-(8%\@<W1A=&5M96YT
M('1O('%U97)Y('EO=7(@;&]G(&1A=&%B87-E(&9I;&5S"F=L;V)A;&QY+@H*
M268@=&AE(&1A=&%B87-E(&1O97,@;F]T(&5X:7-T('=H96X@=&AE(&QO9R!I
M<R!O<&5N960L('-Q;&ET92!W:6QL('1R>2!T;PIC<F5A=&4@:70@875T;VUA
M=&EC86QL>2X@268@=&AE(&QO9R!T86)L92!D;V5S(&YO="!E>&ES="P@:70@
M=VEL;"!A;'-O(&)E"F%U=&]M871I8V%L;'D@8W)E871E9"X@(%1H92!T86)L
M92!C<F5A=&EO;B!U<V5S('1H92!F;VQL;W=I;F<@4U%,(')E<75E<W0Z.@H*
M("`@($-214%412!404),12!L;V=?=&%B;&4@*`H@("`@("`@(&ED("`@("`@
M("`@($E.5$5'15(@4%))34%262!+15D@3D]4($Y53$PL"B`@("`@("`@;&]G
M=&EM92`@("`@3D]4($Y53$PL"B`@("`@("`@:61E;G0@("`@("`@0TA!4B@Q
M-BD@3D]4($Y53$PL"B`@("`@("`@<')I;W)I='D@("`@24Y4($Y/5"!.54Q,
M+`H@("`@("`@(&UE<W-A9V4*("`@("D["@I#;VYF:6=U<F%T:6]N"GY^?GY^
M?GY^?GY^?GX**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM
M+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!0
M87)A;65T97(@("`@("`@("!\(%1Y<&4@("`@("!\($1E9F%U;'0@("`@("`@
M?"!$97-C<FEP=&EO;B`@("`@("`@("`@("`@('P**ST]/3T]/3T]/3T]/3T]
M/3T]/3TK/3T]/3T]/3T]/3TK/3T]/3T]/3T]/3T]/3T]*ST]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/2L*?"!@8&9I;&5N86UE8&`@("`@("!\(%-T<FEN
M9R`@("!\("<G(&`H96UP='DI8"`@?"!0871H('1O(&%N(%-Q;&ET92`@("`@
M("`@('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@
M("`@("`@("`@?"!D871A8F%S92X@?')E<75I<F5D?"`@("`@('P**RTM+2TM
M+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8&UO9&5@8"`@("`@("`@
M("!\($EN=&5G97(@("!\(#`V-C8@("`@("`@("`@?"!/8W1A;"!M;V1E('5S
M960@=&\@;W!E;B`@('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@
M("!\("`@("`@("`@("`@("`@?"!T:&4@9&%T86)A<V4N("`@("`@("`@("`@
M('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM
M+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8'!E<G-I
M<W1E;G1@8"`@("!\($)O;VQE86X@("!\(&9A;'-E("`@("`@("`@?"!5<V4@
M82!P97)S:7-T96YT("`@("`@("`@('P*?"`@("`@("`@("`@("`@("`@("!\
M("`@("`@("`@("!\("`@("`@("`@("`@("`@?"!C;VYN96-T:6]N+B`@("`@
M("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK
M+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M"D%N(&%L<F5A9'D@;W!E;F5D(&1A=&%B87-E(&-O;FYE8W1I;VX@8V%N(&%L
M<V\@8F4@<&%S<V5D(&%S('!A<F%M971E<B!I;G-T96%D"F]F('1H92!A8F]V
M92!C;VYF:6=U<F%T:6]N+B`@26X@=&AI<R!C87-E+"!C;&]S:6YG('1H92!D
M871A8F%S92!C;VYN96-T:6]N(&ES"G5P('1O('1H92!U<V5R+@H*+BX@7VYA
M=&EV92!02%`@<W%L:71E(&9U;F-T:6]N<SH@:'1T<#HO+W=W=RYP:'`N;F5T
M+W-Q;&ET90HN+B!?051404-(.B!H='1P.B\O=W=W+G-Q;&ET92YO<F<O;&%N
M9RYH=&UL(V%T=&%C:`H*17AA;7!L97,*?GY^?GY^?GX*57-I;F<@82!C;VYF
M:6=U<F%T:6]N('1O(&-R96%T92!A(&YE=R!D871A8F%S92!C;VYN96-T:6]N
M.CH*"B`@("`D8V]N9B`](&%R<F%Y*"=F:6QE;F%M92<@/3X@)VQO9RYD8B<L
M("=M;V1E)R`]/B`P-C8V+"`G<&5R<VES=&5N="<@/3X@=')U92D["B`@("`D
M;&]G9V5R(#TF($QO9SHZ9F%C=&]R>2@G<W%L:71E)RP@)VQO9U]T86)L92<L
M("=I9&5N="<L("1C;VYF*3L*("`@("1L;V=G97(M/FQO9R@G;&]G9VEN9R!A
M;B!E=F5N="<L(%!%05)?3$]'7U=!4DY)3D<I.PH*57-I;F<@86X@97AI<W1I
M;F<@8V]N;F5C=&EO;CHZ"@H@("`@)&1B(#T@<W%L:71E7V]P96XH)VQO9RYD
M8B<L(#`V-C8L("1E<G)O<BD["B`@("`D;&]G9V5R(#TF($QO9SHZ9F%C=&]R
M>2@G<W%L:71E)RP@)VQO9U]T86)L92<L("=I9&5N="<L("1D8BD["B`@("`D
M;&]G9V5R+3YL;V<H)VQO9V=I;F<@86X@979E;G0G+"!014%27TQ/1U]705).
M24Y'*3L*("`@('-Q;&ET95]C;&]S92@D9&(I.PH*"E1H92!3>7-L;V<@2&%N
M9&QE<@HM+2TM+2TM+2TM+2TM+2TM+2T*5&AE(%-Y<VQO9R!H86YD;&5R('-E
M;F1S(&QO9R!E=F5N=',@=&\@=&AE('-Y<W1E;2!L;V=G:6YG('-E<G9I8V4@
M*'-Y<VQO9R!O;@I5;FEX+6QI:V4@96YV:7)O;FUE;G1S(&]R('1H92!%=F5N
M="!,;V<@;VX@5VEN9&]W<R!S>7-T96US*2X@(%1H92!E=F5N=',@87)E"G-E
M;G0@=7-I;F<@4$A0)W,@8'-Y<VQO9R@I8%\@9G5N8W1I;VXN"@I&86-I;&ET
M:65S"GY^?GY^?GY^?GX**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*?"!#;VYS=&%N="`@("`@("`@("!\($-A=&5G;W)Y($1E<V-R:7!T:6]N
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P**ST]/3T]/3T]
M/3T]/3T]/3T]/3TK/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/2L*?"!@8$Q/1U]!551(8&`@("`@("!\
M(%-E8W5R:71Y("\@875T:&]R:7IA=&EO;B!M97-S86=E<SL@8&!,3T=?0554
M2%!2259@8"!I<WP*?"`@("`@("`@("`@("`@("`@("!\('!R969E<G)E9"!O
M;B!S>7-T96US('=H97)E(&ET(&ES(&1E9FEN960N("`@("`@("`@("`@('P*
M*RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8$Q/1U]!551(
M4%))5F!@("!\(%!R:79A=&4@<V5C=7)I='D@+R!A=71H;W)I>F%T:6]N(&UE
M<W-A9V5S("`@("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*?"!@8$Q/1U]#4D].8&`@("`@("!\($-L;V-K(&1A96UO;B`H
M8&!C<F]N8&`@86YD(&!@871@8"D@("`@("`@("`@("`@("`@("`@('P**RTM
M+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8$Q/1U]$045-3TY@
M8"`@("!\(%-Y<W1E;2!D865M;VX@<')O8V5S<V5S("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*?"!@8$Q/1U]+15).8&`@("`@("!\($ME<FYE;"!M97-S86=E<R`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P**RTM+2TM
M+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8$Q/1U],3T-!3#!@8"`N
M+B!\(%)E<V5R=F5D(&9O<B!L;V-A;"!U<V4[("HJ;F]T*BH@879A:6QA8FQE
M('5N9&5R("`@("`@('P*?"!@8$Q/1U],3T-!3#=@8"`@("!\(%=I;F1O=W,N
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8$Q/1U],
M4%)@8"`@("`@("!\(%!R:6YT97(@<W5B<WES=&5M("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*?"!@8$Q/1U]-04E,8&`@("`@("!\($UA:6P@<W5B<WES
M=&5M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M*RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8$Q/1U].15=3
M8&`@("`@("!\(%5314Y%5"!N97=S('-U8G-Y<W1E;2`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*?"!@8$Q/1U]365-,3T=@8"`@("!\($EN=&5R;F%L('-Y<VQO
M9R!M97-S86=E<R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P**RTM
M+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8$Q/1U]54T528&`@
M("`@("!\($=E;F5R:6,@=7-E<BUL979E;"!M97-S86=E<R`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*?"!@8$Q/1U]554-08&`@("`@("!\(%550U`@<W5B<WES=&5M("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P**RTM+2TM
M+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*"BXN(%]S>7-L;V<H*3H@:'1T
M<#HO+W=W=RYP:'`N;F5T+W-Y<VQO9PH*17AA;7!L90I^?GY^?GY^"CHZ"@H@
M("`@)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O;B@G<WES;&]G)RP@3$]'7TQ/
M0T%,,"P@)VED96YT)RD["B`@("!F;W(@*"1I(#T@,#L@)&D@/"`Q,#L@)&DK
M*RD@>PH@("`@("`@("1L;V=G97(M/FQO9R@B3&]G(&5N=')Y("1I(BD["B`@
M("!]"@H*5&AE(%=I;F1O=R!(86YD;&5R"BTM+2TM+2TM+2TM+2TM+2TM+0I4
M:&4@5VEN9&]W(&AA;F1L97(@<V5N9',@;&]G(&5V96YT<R!T;R!A('-E<&%R
M871E(&)R;W=S97(@=VEN9&]W+B`@5&AE"F]R:6=I;F%L(&ED96$@9F]R('1H
M:7,@:&%N9&QE<B!W87,@:6YS<&ER960@8GD@0W)A:6<@1&%V:7,G(%IE;F0N
M8V]M(&%R=&EC;&4*96YT:71L960@8")*879A4V-R:7!T(%!O=V5R(%!(4"!$
M96)U9V=I;F<B8%\N"@I#;VYF:6=U<F%T:6]N"GY^?GY^?GY^?GY^?GX**RTM
M+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!087)A;65T97(@("`@
M("`@("!\(%1Y<&4@("`@("!\($1E9F%U;'0@("`@("`@?"!$97-C<FEP=&EO
M;B`@("`@("`@("`@("`@('P**ST]/3T]/3T]/3T]/3T]/3T]/3TK/3T]/3T]
M/3T]/3TK/3T]/3T]/3T]/3T]/3T]*ST]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/2L*?"!@8'1I=&QE8&`@("`@("`@("!\(%-T<FEN9R`@("!\(&!@3&]G
M($]U='!U="`@?"!4:&4@=&ET;&4@;V8@=&AE(&]U='!U="`@('P*?"`@("`@
M("`@("`@("`@("`@("!\("`@("`@("`@("!\(%=I;F1O=V!@("`@("`@?"!W
M:6YD;W<N("`@("`@("`@("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM
M+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*?"!@8&-O;&]R<V!@("`@("`@("!\($%R<F%Y("`@
M("!\(&!23UD@1R!"259@7R`@?"!-87!P:6YG(&]F(&QO9R!P<FEO<FET:65S
M('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("AH:6=H('1O
M(&QO=RD@?"!T;R!C;VQO<G,N("`@("`@("`@("`@("`@('P**RTM+2TM+2TM
M+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*"BXN(%\B2F%V85-C<FEP="!0;W=E
M<B!02%`@1&5B=6=G:6YG(CH@:'1T<#HO+W=W=RYZ96YD+F-O;2]Z96YD+W1U
M="]T=71O<FEA;"U$96)U9TQI8BYP:'`*+BX@7U)/62!'($))5CH@:'1T<#HO
M+W=W=RYC:7,N<FET+F5D=2\*"D5X86UP;&4*?GY^?GY^?@HZ.@H*("`@("1C
M;VYF(#T@87)R87DH)W1I=&QE)R`]/B`G4V%M<&QE($QO9R!/=71P=70G*3L*
M("`@("1L;V=G97(@/2`F3&]G.CIS:6YG;&5T;VXH)W=I;B<L("=,;V=7:6YD
M;W<G+"`G:61E;G0G+"`D8V]N9BD["B`@("!F;W(@*"1I(#T@,#L@)&D@/"`Q
M,#L@)&DK*RD@>PH@("`@("`@("1L;V=G97(M/FQO9R@B3&]G(&5N=')Y("1I
M(BD["B`@("!]"@H*0V]M<&]S:71E($AA;F1L97)S"CT]/3T]/3T]/3T]/3T]
M/3T]/0I)="!I<R!O9G1E;B!U<V5F=6P@=&\@;&]G(&5V96YT<R!T;R!M=6QT
M:7!L92!H86YD;&5R<RX@(%1H92!,;V<@<&%C:V%G90IP<F]V:61E<R!A(&-O
M;7!O<VET:6YG('-Y<W1E;2!T:&%T(&UA<FMS('1H:7,@=&%S:R!T<FEV:6%L
M+@H*4W1A<G0@8GD@8W)E871I;F<@=&AE(&EN9&EV:61U86P@;&]G(&AA;F1L
M97)S.CH*"B`@("`D8V]N<V]L92`]("9,;V<Z.G-I;F=L971O;B@G8V]N<V]L
M92<L("<G+"`G5$535"<I.PH@("`@)&9I;&4@/2`F3&]G.CIS:6YG;&5T;VXH
M)V9I;&4G+"`G;W5T+FQO9R<L("=415-4)RD["@I4:&5N+"!C;VYS=')U8W0@
M82!C;VUP;W-I=&4@:&%N9&QE<B!A;F0@861D('1H92!I;F1I=FED=6%L(&AA
M;F1L97)S(&%S"F-H:6QD<F5N(&]F('1H92!C;VUP;W-I=&4Z.@H*("`@("1C
M;VUP;W-I=&4@/2`F3&]G.CIS:6YG;&5T;VXH)V-O;7!O<VET92<I.PH@("`@
M)&-O;7!O<VET92T^861D0VAI;&0H)&-O;G-O;&4I.PH@("`@)&-O;7!O<VET
M92T^861D0VAI;&0H)&9I;&4I.PH*5&AE(&-O;7!O<VET92!H86YD;&5R(&EM
M<&QE;65N=',@=&AE('-T86YD87)D(&!@3&]G8&`@:6YT97)F86-E('-O('EO
M=2!C86X@=7-E"FET(&IU<W0@;&EK92!A;GD@;V8@=&AE(&]T:&5R(&AA;F1L
M97)S.CH*"B`@("`D8V]M<&]S:71E+3YL;V<H)U1H:7,@979E;G0@=VEL;"!B
M92!L;V=G960@=&\@8F]T:"!H86YD;&5R<RXG*3L*"D-H:6QD<F5N(&-A;B!B
M92!R96UO=F5D(&9R;VT@=&AE(&-O;7!O<VET92!W:&5N('1H97DG<F4@;F]T
M(&QO;F=E<B!N965D960Z.@H*("`@("1C;VUP;W-I=&4M/G)E;6]V94-H:6QD
M*"1F:6QE*3L*"@I,;V<@3V)S97)V97)S"CT]/3T]/3T]/3T]/3T*3&]G(&]B
M<V5R=F5R<R!P<F]V:61E(&%N(&EM<&QE;65N=&%T:6]N(&]F('1H92!@;V)S
M97)V97(@<&%T=&5R;F!?+B`@26X@=&AE"F-O;G1E;G0@;V8@=&AE($QO9R!P
M86-K86=E+"!T:&5Y('!R;W9I9&4@82!M96-H86YI<VT@8GD@=VAI8V@@>6]U
M(&-A;B!E>&%M:6YE"BAI+F4N(&]B<V5R=F4I(&5A8V@@979E;G0@87,@:70@
M:7,@;&]G9V5D+B`@5&AI<R!A;&QO=W,@=&AE(&EM<&QE;65N=&%T:6]N(&]F
M"G-P96-I86P@8F5H879I;W(@8F%S960@;VX@=&AE(&-O;G1E;G1S(&]F(&$@
M;&]G(&5V96YT+B`@1F]R(&5X86UP;&4L('1H90IO8G-E<G9E<B!C;V1E(&-O
M=6QD('-E;F0@86X@86QE<G0@96UA:6P@:68@82!L;V<@979E;G0@8V]N=&%I
M;F5D('1H92!S=')I;F<*8&!004Y)0V!@+@H*0W)E871I;F<@82!L;V<@;V)S
M97)V97(@:6YV;VQV97,@:6UP;&5M96YT:6YG(&$@<W5B8VQA<W,@;V8@=&AE
M"F!@3&]G7V]B<V5R=F5R8&`@8VQA<W,N("!4:&4@<W5B8VQA<W,@;75S="!O
M=F5R<FED92!T:&4@8F%S92!C;&%S<R=S"F!@;F]T:69Y*"E@8"!M971H;V0N
M("!4:&ES(&UE=&AO9"!I<R!P87-S960@82!H87-H(&-O;G1A:6YI;F<@=&AE
M(&5V96YT)W,*<')I;W)I='D@86YD(&5V96YT+B`@5&AE('-U8F-L87-S)W,@
M:6UP;&5M96YT871I;VX@:7,@9G)E92!T;R!A8W0@=7!O;B!T:&ES"FEN9F]R
M;6%T:6]N(&EN(&%N>2!W87D@:70@;&EK97,N"@I,;V<@;V)S97)V97)S(&%R
M92!A='1A8VAE9"!T;R!@8$QO9V!@(&EN<W1A;F-E<R!V:6$@=&AE(&!@871T
M86-H*"E@8"!M971H;V0Z.@H*("`@("1O8G-E<G9E<B`]("9,;V=?;V)S97)V
M97(Z.F9A8W1O<GDH)WEO=7)4>7!E)RD["B`@("`D;&]G9V5R+3YA='1A8V@H
M)&]B<V5R=F5R*3L*"D]B<V5R=F5R<R!C86X@8F4@9&5T86-H960@=7-I;F<@
M=&AE(&!@9&5T86-H*"E@8"!M971H;V0Z.@H*("`@("1L;V=G97(M/F1E=&%C
M:"@D;V)S97)V97(I.PH*070@=&AI<R!T:6UE+"!N;R!C;VYC<F5T92!@8$QO
M9U]O8G-E<G9E<F!@(&EM<&QE;65N=&%T:6]N<R!A<F4@9&ES=')I8G5T960*
M=VET:"!T:&4@3&]G('!A8VMA9V4N"@HN+B!?;V)S97)V97(@<&%T=&5R;CH@
M:'1T<#HO+W!H<'!A='1E<FYS+F-O;2]I;F1E>"YP:'`O87)T:6-L92]A<G1I
M8VQE=FEE=R\R-R\Q+S$O"@H*3&]G9VEN9R!&<F]M(%-T86YD87)D($5R<F]R
M($AA;F1L97)S"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/0H*3&]G9VEN9R!02%`@17)R;W)S"BTM+2TM+2TM+2TM+2TM+2TM+0I02%`G
M<R!D969A=6QT(&5R<F]R(&AA;F1L97(@8V%N(&)E(&]V97)R:61D96X@=7-I
M;F<@=&AE(&!S971?97)R;W)?:&%N9&QE<B@I8%\*9G5N8W1I;VXN("!4:&4@
M8W5S=&]M(&5R<F]R(&AA;F1L:6YG(&9U;F-T:6]N(&-A;B!U<V4@82!G;&]B
M86P@3&]G(&EN<W1A;F-E('1O"FQO9R!T:&4@4$A0(&5R<F]R<RX*"BHJ3F]T
M93HJ*B!&871A;"!02%`@97)R;W)S(&-A;FYO="!B92!H86YD;&5D(&)Y(&$@
M8W5S=&]M(&5R<F]R(&AA;F1L97(@870@=&AI<PIT:6UE+@H*.CH*"B`@("!F
M=6YC=&EO;B!E<G)O<DAA;F1L97(H)&-O9&4L("1M97-S86=E+"`D9FEL92P@
M)&QI;F4I"B`@("!["B`@("`@("`@9VQO8F%L("1L;V=G97(["@H@("`@("`@
M("\J($UA<"!T:&4@4$A0(&5R<F]R('1O(&$@3&]G('!R:6]R:71Y+B`J+PH@
M("`@("`@('-W:71C:"`H)&-O9&4I('L*("`@("`@("!C87-E($5?5T%23DE.
M1SH*("`@("`@("!C87-E($5?55-%4E]705).24Y'.@H@("`@("`@("`@("`D
M<')I;W)I='D@/2!014%27TQ/1U]705).24Y'.PH@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("!C87-E($5?3D]424-%.@H@("`@("`@(&-A<V4@15]54T52
M7TY/5$E#13H*("`@("`@("`@("`@)'!R:6]R:71Y(#T@4$5!4E],3T=?3D]4
M24-%.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!C87-E($5?15)23U(Z
M"B`@("`@("`@8V%S92!%7U5315)?15)23U(Z"B`@("`@("`@("`@("1P<FEO
M<FET>2`](%!%05)?3$]'7T524CL*("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@9&5F875L=#H*("`@("`@("`@("`@)'!R:6]T:71Y(#T@4$5!4E],3T=?
M24Y&3SL*("`@("`@("!]"@H@("`@("`@("1L;V=G97(M/FQO9R@D;65S<V%G
M92`N("<@:6X@)R`N("1F:6QE("X@)R!A="!L:6YE("<@+B`D;&EN92P*("`@
M("`@("`@("`@("`@("`@("`@)'!R:6]R:71Y*3L*("`@('T*"B`@("!S971?
M97)R;W)?:&%N9&QE<B@G97)R;W)(86YD;&5R)RD["B`@("!T<FEG9V5R7V5R
M<F]R*"=4:&ES(&ES(&%N(&EN9F]R;6%T:6]N(&QO9R!M97-S86=E+B<L($5?
M55-%4E].3U1)0T4I.PH*+BX@7W-E=%]E<G)O<E]H86YD;&5R*"DZ(&AT='`Z
M+R]W=W<N<&AP+FYE="]S971?97)R;W)?:&%N9&QE<@H*3&]G9VEN9R!014%2
M($5R<F]R<PHM+2TM+2TM+2TM+2TM+2TM+2TM"E1H92!,;V<@<&%C:V%G92!C
M86X@8F4@=7-E9"!W:71H(&!014%2.CIS971%<G)O<DAA;F1L:6YG*"E@7R=S
M"F!@4$5!4E]%4E)/4E]#04Q,0D%#2V!@(&UE8VAA;FES;2!B>2!W<FET:6YG
M(&%N(&5R<F]R(&AA;F1L:6YG(&9U;F-T:6]N('1H870*=7-E<R!A(&=L;V)A
M;"!,;V<@:6YS=&%N8V4N("!(97)E)W,@86X@97AA;7!L93HZ"@H@("`@9G5N
M8W1I;VX@97)R;W)(86YD;&5R*"1E<G)O<BD*("`@('L*("`@("`@("!G;&]B
M86P@)&QO9V=E<CL*"B`@("`@("`@)&UE<W-A9V4@/2`D97)R;W(M/F=E=$UE
M<W-A9V4H*3L*"B`@("`@("`@:68@*"%E;7!T>2@D97)R;W(M/F)A8VMT<F%C
M95LQ75LG9FEL92==*2D@>PH@("`@("`@("`@("`D;65S<V%G92`N/2`G("@G
M("X@)&5R<F]R+3YB86-K=')A8V5;,5U;)V9I;&4G73L*("`@("`@("`@("`@
M:68@*"%E;7!T>2@D97)R;W(M/F)A8VMT<F%C95LQ75LG;&EN92==*2D@>PH@
M("`@("`@("`@("`@("`@)&UE<W-A9V4@+CT@)R!A="!L:6YE("<@+B`D97)R
M;W(M/F)A8VMT<F%C95LQ75LG;&EN92==.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1M97-S86=E("X]("<I)SL*("`@("`@("!]"@H@("`@("`@("1L
M;V=G97(M/FQO9R@D;65S<V%G92P@)&5R<F]R+3YC;V1E*3L*("`@('T*"B`@
M("!014%2.CIS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?0T%,3$)!0TLL
M("=E<G)O<DAA;F1L97(G*3L*("`@(%!%05(Z.G)A:7-E17)R;W(H)U1H:7,@
M:7,@86X@:6YF;W)M871I;VX@;&]G(&UE<W-A9V4N)RP@4$5!4E],3T=?24Y&
M3RD["@HN+B!?4$5!4CHZ<V5T17)R;W)(86YD;&EN9R@I.B!H='1P.B\O<&5A
M<BYP:'`N;F5T+VUA;G5A;"]E;B]C;W)E+G!E87(N<&5A<BYS971E<G)O<FAA
M;F1L:6YG+G!H<`H*"D-U<W1O;2!(86YD;&5R<PH]/3T]/3T]/3T]/3T]/3T*
M5&AE<F4@87)E('1I;65S('=H96X@=&AE('-T86YD87)D(&AA;F1L97)S(&%R
M96XG="!A('!E<F9E8W0@;6%T8V@@9F]R('EO=7(*;F5E9',N("!);B!T:&]S
M92!S:71U871I;VYS+"!T:&4@<V]L=71I;VX@;6EG:'0@8F4@=&\@=W)I=&4@
M82!C=7-T;VT@:&%N9&QE<BX*"E5S:6YG(&$@0W5S=&]M($AA;F1L97(*+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+0I5<VEN9R!A(&-U<W1O;2!,;V<@:&%N9&QE
M<B!I<R!V97)Y('-I;7!L92X@($]N8V4@=W)I='1E;B`H<V5E(&!7<FET:6YG
M($YE=PI(86YD;&5R<V!?(&%N9"!@17AT96YD:6YG($5X:7-T:6YG($AA;F1L
M97)S8%\@8F5L;W<I+"!Y;W4@:&%V92!T:&4@8VAO:6-E(&]F"G!L86-I;F<@
M=&AE(&9I;&4@:6X@>6]U<B!014%2(&EN<W1A;&QA=&EO;B=S(&UA:6X@8&!,
M;V<O8&`@9&ER96-T;W)Y("AU<W5A;&QY"G-O;65T:&EN9R!L:6ME(&!@+W5S
M<B]L;V-A;"]L:6(O<&AP+TQO9V!@(&]R(&!@0SI<<&AP7'!E87)<3&]G8&`I
M+"!W:&5R92!I=`IC86X@8F4@9F]U;F0@86YD('5S92!B>2!A;GD@4$A0(&%P
M<&QI8V%T:6]N(&]N('1H92!S>7-T96TL(&]R('!L86-I;F<@=&AE(&9I;&4*
M<V]M97=H97)E(&EN('EO=7(@87!P;&EC871I;VXG<R!L;V-A;"!H:65R87)C
M:'D@86YD(&EN8VQU9&EN9R!I="!B969O<F4@=&AE"G1H92!C=7-T;VT@3&]G
M(&]B:F5C="!I<R!C;VYS=')U8W1E9"X*"DUE=&AO9"`Q.B!(86YD;&5R(&EN
M('1H92!3=&%N9&%R9"!,;V-A=&EO;@I^?GY^?GY^?GY^?GY^?GY^?GY^?GY^
M?GY^?GY^?GY^?GY^?GY^?GY^?GX*069T97(@8V]P>6EN9R!T:&4@:&%N9&QE
M<B!F:6QE('1O('EO=7(@4$5!4B!I;G-T86QL871I;VXG<R!@8$QO9R]@8"!D
M:7)E8W1O<GDL"G-I;7!L>2!T<F5A="!T:&4@:&%N9&QE<B!A<R!I9B!I="!W
M97)E('!A<G0@;V8@=&AE('-T86YD87)D(&1I<W1R:6)U=&5D+B`@268*>6]U
M<B!H86YD;&5R(&ES(&YA;65D(&!@8W5S=&]M8&`@*&%N9"!T:&5R969O<F4@
M:6UP;&5M96YT960@8GD@82!C;&%S<R!N86UE9`I@8$QO9U]C=7-T;VU@8"DZ
M.@H*("`@(')E<75I<F5?;VYC92`G3&]G+G!H<"<["@H@("`@)&QO9V=E<B`]
M("9,;V<Z.F9A8W1O<GDH)V-U<W1O;2<L("<G+"`G0U535$]-)RD["@H*365T
M:&]D(#(Z($AA;F1L97(@:6X@82!#=7-T;VT@3&]C871I;VX*?GY^?GY^?GY^
M?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GX*268@>6]U('!R969E<B!S
M=&]R:6YG('EO=7(@:&%N9&QE<B!I;B!Y;W5R(&%P<&QI8V%T:6]N)W,@;&]C
M86P@:&EE<F%R8VAY+`IY;W4G;&P@;F5E9"!T;R!I;F-L=61E('1H870@9FEL
M92!B969O<F4@>6]U(&-A;B!C<F5A=&4@82!,;V<@:6YS=&%N8V4@8F%S960@
M;VX*:70N"@HZ.@H*("`@(')E<75I<F5?;VYC92`G3&]G+G!H<"<["B`@("!R
M97%U:7)E7V]N8V4@)TQO8V%L2&%N9&QE<G,O8W5S=&]M+G!H<"<["@H@("`@
M)&QO9V=E<B`]("9,;V<Z.F9A8W1O<GDH)V-U<W1O;2<L("<G+"`G0U535$]-
M)RD["@H*5W)I=&EN9R!.97<@2&%N9&QE<G,*+2TM+2TM+2TM+2TM+2TM+2TM
M+2T*"E1/1$\*"D5X=&5N9&EN9R!%>&ES=&EN9R!(86YD;&5R<PHM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2T*"E1/1$\*"@HN+B!\<F5Q=6ER961\(')E
M<&QA8V4Z.B`J*EMR97%U:7)E9%TJ*@H*+BX@=FEM.B!T86)S=&]P/30@<VAI
M9G1W:61T:#TT('-O9G1T86)S=&]P/30@97AP86YD=&%B('1E>'1W:61T:#TW
M."!F=#UR<W0Z"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O9&]C<R]$871E````````````````````````````````````````
M```````````````````````````````````````````P,#`W-34@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<S,"`P,C`R,3$`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+T1A=&4O3$E#14Y310``````
M````````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-3`W(#$P-3$U
M-#,S-S,P(#`R,3,P,0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A
M;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70@;6]D:69I8V%T:6]N
M"BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F;VQL;W=I;F<@
M8V]N9&ET:6]N<R!A<F4@;65T.@H*,2X@4F5D:7-T<FEB=71I;VYS(&]F('-O
M=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0@;F]T
M:6-E+"!T:`H@("!I<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL
M;W=I;F<@9&ES8VQA:6UE<BX*"C(N(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA
M<GD@9F]R;2!M=7-T(')E<')O9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT(&YO
M=&EC92P*("`@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL
M;W=I;F<@9&ES8VQA:6UE<B!I;B!T:&4@9&]C=6UE;G1A=&EO;B!A;F0O"B`@
M(&]R(&]T:&5R(&UA=&5R:6%L<R!P<F]V:61E9"!W:71H('1H92!D:7-T<FEB
M=71I;VXN"@HS+B!4:&4@;F%M92!O9B!T:&4@875T:&]R(&UA>2!N;W0@8F4@
M=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O9'5C=',@9&5R:79E9`H@
M("!F<F]M('1H:7,@<V]F='=A<F4@=VET:&]U="!S<&5C:69I8R!P<FEO<B!W
M<FET=&5N('!E<FUI<W-I;VXN"@I42$E3(%-/1E1705)%($E3(%!23U9)1$5$
M($)9(%1(12!!551(3U(@8&!!4R!)4R<G($%.1"!!3ED@15A04D534R!/4B!)
M35!,245$(%=!"E)204Y42453+"!)3D-,541)3D<L($)55"!.3U0@3$E-251%
M1"!43RP@5$A%($E-4$Q)140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24P*
M2519($%.1"!&251.15-3($9/4B!!(%!!4E1)0U5,05(@4%524$]312!!4D4@
M1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%(`I!551(3U(@0D4@
M3$E!0DQ%($9/4B!!3ED@1$E214-4+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@
M4U!%0TE!3"P@15A%35!,05)9+"!/4B!#"D].4T51545.5$E!3"!$04U!1T53
M("A)3D-,541)3D<L($)55"!.3U0@3$E-251%1"!43RP@4%)/0U5214U%3E0@
M3T8@4U5"4U1)5%5412`*1T]/1%,@3U(@4T525DE#15,[($Q/4U,@3T8@55-%
M+"!$051!+"!/4B!04D]&2513.R!/4B!"55-)3D534R!)3E1%4E)54%1)3TXI
M($A/5PI%5D52($-!55-%1"!!3D0@3TX@04Y9(%1(14]262!/1B!,24%"24Q)
M5%DL(%=(151(15(@24X@0T].5%)!0U0L(%-44DE#5"!,24%"24Q)"E19+"!/
M4B!43U)4("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I($%2
M25-)3D<@24X@04Y9(%=!62!/550@3T8@5$A%(%4*4T4@3T8@5$A)4R!33T94
M5T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(12!03U-324))3$E462!/1B!3
M54-(($1!34%'12X*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+V1O8W,O1&%T92]43T1/````````````````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#`S-S(@,3`U,34T,S,W,S`@,#(P-S8R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"T@1FEX(&]N8V4@
M=&AE('1I;65Z;VYE('!R;V)L96T*"BT@3VYC92!46B!W;W)K<R!N:6-E;'DL
M('5P9&%T92!T:&4@=&5S='5N:71?9&%T92!A;F0@=7-E"B`@=&AE(')E86P@
M=&EM97IO;F4@86YD(&1C="!T;R!C:&5C:R!T:&4@97AP96-T960@=&EM92!O
M9F9S970*"BT@0VQE86X@=&AE('1E<W0@8V%S97,@86YD(&%T;VUI8R!D:7-P
M;&%Y(&EN<W1E860@;V8@82!G;&]B86P@;VL@;W(@9F%I;&5D"@HM('=R:71E
M('1H92!D;V-S+BXN+@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+TYE=%]5
M4DP`````````````````````````````````````````````````````````
M`````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P,#`P(#$P-3$U-#,S-S,P(#`R,#8P-``@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+V1O8W,O3F5T7U523"]D;V-S````````````````````````````
M````````````````````````````````````````````,#`P-S4U(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S`@,#(Q-3,T`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R].971?55),+V1O8W,O97AA
M;7!L92YP:'``````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-C,V-"`Q,#4Q
M-30S,S<S,"`P,C,W-S``(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,C`P,BTR,#`S+"!2:6-H87)D($AE
M>65S("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M?"!!;&P@<FEG:'1S(')E<V5R=F5D+B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O('P@4F5D:7-T<FEB=71I;VX@86YD('5S92!I
M;B!S;W5R8V4@86YD(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T("`@
M('P*+R\@?"!M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@<')O=FED960@
M=&AA="!T:&4@9F]L;&]W:6YG(&-O;F1I=&EO;G,@("`@?`HO+R!\(&%R92!M
M970Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@?"!O(%)E9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D
M92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I9VAT("`@("`@?`HO+R!\
M("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O
M;&QO=VEN9R!D:7-C;&%I;65R+B`@("`@("!\"B\O('P@;R!2961I<W1R:6)U
M=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B;W9E
M(&-O<'ER:6=H="`@('P*+R\@?"`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O
M;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T:&4@
M?`HO+R!\("`@9&]C=6UE;G1A=&EO;B!A;F0O;W(@;W1H97(@;6%T97)I86QS
M('!R;W9I9&5D('=I=&@@=&AE(&1I<W1R:6)U=&EO;BY\(`HO+R!\(&\@5&AE
M(&YA;65S(&]F('1H92!A=71H;W)S(&UA>2!N;W0@8F4@=7-E9"!T;R!E;F1O
M<G-E(&]R('!R;VUO=&4@("`@("!\"B\O('P@("!P<F]D=6-T<R!D97)I=F5D
M(&9R;VT@=&AI<R!S;V9T=V%R92!W:71H;W5T('-P96-I9FEC('!R:6]R('=R
M:71T96X@('P*+R\@?"`@('!E<FUI<W-I;VXN("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@5$A)4R!33T945T%2
M12!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@04Y$($-/
M3E1224)55$]24R`@('P*+R\@?"`B05,@25,B($%.1"!!3ED@15A04D534R!/
M4B!)35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5"`@("`@
M?`HO+R!\($Q)34E4140@5$\L(%1(12!)35!,245$(%=!4E)!3E1)15,@3T8@
M34520TA!3E1!0DE,2519($%.1"!&251.15-3($9/4B!\"B\O('P@02!005)4
M24-53$%2(%!54E!/4T4@05)%($1)4T-,04E-140N($E.($Y/($5614Y4(%-(
M04Q,(%1(12!#3U!94DE'2%0@('P*+R\@?"!/5TY%4B!/4B!#3TY44DE"551/
M4E,@0D4@3$E!0DQ%($9/4B!!3ED@1$E214-4+"!)3D1)4D5#5"P@24Y#241%
M3E1!3"P@?`HO+R!\(%-014-)04PL($5814U03$%262P@3U(@0T].4T51545.
M5$E!3"!$04U!1T53("A)3D-,541)3D<L($)55"!.3U0@("`@("!\"B\O('P@
M3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8@4U5"4U1)5%5412!'3T]$4R!/
M4B!315)624-%4SL@3$]34R!/1B!54T4L('P*+R\@?"!$051!+"!/4B!04D]&
M2513.R!/4B!"55-)3D534R!)3E1%4E)54%1)3TXI($A/5T5615(@0T%54T5$
M($%.1"!/3B!!3ED@?`HO+R!\(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(
M15(@24X@0T].5%)!0U0L(%-44DE#5"!,24%"24Q)5%DL($]2(%1/4E0@("!\
M"B\O('P@*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]42$525TE312D@05))
M4TE.1R!)3B!!3ED@5T%9($]55"!/1B!42$4@55-%('P*+R\@?"!/1B!42$E3
M(%-/1E1705)%+"!%5D5.($E&($%$5DE3140@3T8@5$A%(%!/4U-)0DE,2519
M($]&(%-50T@@1$%-04=%+B`@?`HO+R!\("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!
M=71H;W(Z(%)I8VAA<F0@2&5Y97,@/')I8VAA<F0@870@<&AP(&YE=#X@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O("1)9#H@97AA;7!L92YP:'`L=B`Q+CD@,C`P-"\P
M-2\P."`Q-SHT.#HP."!R:6-H87)D($5X<"`D"B\J*@HJ(%1H:7,@97AA;7!L
M92!W:6QL(&1E8V]D92!T:&4@=7)L(&=I=F5N(&%N9"!D:7-P;&%Y(&ET<PHJ
M(&-O;G-T:71U96YT('!A<G1S+@HJ+PH*+R\):6YC;'5D92@G+BXO55),+G!H
M<"<I.PH):6YC;'5D92@G3F5T+U523"YP:'`G*3L*"@DO+R1U<FP@/2`F;F5W
M($YE=%]54DPH)VAT='!S.B\O=W=W+F5X86UP;&4N8V]M+V9O;R]B87(O:6YD
M97@N<&AP/V9O;SUB87(G*3L*"21U<FP@/2!N97<@3F5T7U523"@G:'1T<',Z
M+R]E>&%M<&QE+F-O;2]P;',O<&]R=&%L,S`O4$]25$%,,S`N=W=P;V)?<&%G
M92YC:&%N9V5T86)S/W!?8F%C:U]U<FP]:'1T<"4S024R1B4R1F5X86UP;&4N
M8V]M)3)&<V5R=FQE="4R1G!A9V4E,T9?<&%G96ED)3-$,S8P)3)#,S8V)3)#
M,S8X)3)#,S@R)3(V7V1A9"4S1'!O<G1A;#,P)3(V7W-C:&5M824S1%!/4E1!
M3#,P)F9O;SUB87(G*3L*/SX*/&AT;6P^"CQB;V1Y/@H*/'!R93X*4')O=&]C
M;VPN+BXZ(#P_/21U<FPM/G!R;W1O8V]L/SX*"E5S97)N86UE+BXN.B`\/STD
M=7)L+3YU<V5R/SX*"E!A<W-W;W)D+BXN.B`\/STD=7)L+3YP87-S/SX*"E-E
M<G9E<BXN+BXN.B`\/STD=7)L+3YH;W-T/SX*"E!O<G0N+BXN+BXN.B`\/STD
M=7)L+3YP;W)T/SX*"D9I;&4O<&%T:"XN.B`\/STD=7)L+3YP871H/SX*"E%U
M97)Y<W1R:6YG.B`\/W!R:6YT7W(H)'5R;"T^<75E<GES=')I;F<I/SX*"D%N
M8VAO<BXN+BXN.B`\/STD=7)L+3YA;F-H;W(_/@H*"D9U;&P@55),+BXN.B`\
M/STD=7)L+3YG9715<FPH*3\^"CPO<')E/@H*/"]B;V1Y/@H\+VAT;6P^"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O07)C:&EV95]487(`````
M````````````````````````````````````````````````````````````
M````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U
M,34T,S,W,S`@,#(Q-3(S`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C
M<R]!<F-H:79E7U1A<B]D;V-S````````````````````````````````````
M```````````````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<S,"`P,C(T-3,`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]D;V-S+T%R8VAI=F5?5&%R+V1O8W,O07)C:&EV95]4
M87(N='AT`````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#0T-C$P(#$P-3$U-#,S-S,P(#`R
M-30V-P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!$;V-U;65N=&%T:6]N(&9O<B!C;&%S<R!!<F-H:79E7U1A<@T*/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T-"DQA<W0@=7!D871E(#H@
M,C`P,2TP."TQ-0T*#0H-"@T*3W9E<G9I97<@.@T*+2TM+2TM+2TM+0T*#0H@
M(%1H92!!<F-H:79E7U1A<B!C;&%S<R!H96QP<R!I;B!C<F5A=&EN9R!A;F0@
M;6%N86=I;F<@1TY5(%1!4B!F;W)M870-"B`@9FEL97,@8V]M<')E<W-E9"!B
M>2!'3E4@6DE0(&]R(&YO="X@#0H@(%1H92!C;&%S<R!O9F9E<G,@8F%S:6,@
M9G5N8W1I;VYS(&QI:V4@8W)E871I;F<@86X@87)C:&EV92P@861D:6YG#0H@
M(&9I;&5S(&EN('1H92!A<F-H:79E+"!E>'1R86-T:6YG(&9I;&5S(&9R;VT@
M=&AE(&%R8VAI=F4@86YD(&QI<W1I;F<-"B`@=&AE(&%R8VAI=F4@8V]N=&5N
M="X@#0H@($ET(&%L<V\@<')O=FED92!A9'9A;F-E9"!F=6YC=&EO;G,@=&AA
M="!A;&QO=R!T:&4@861D:6YG(&%N9`T*("!E>'1R86-T:6]N(&]F(&9I;&5S
M('=I=&@@<&%T:"!M86YI<'5L871I;VXN(`T*#0H-"E-A;7!L92`Z#0HM+2TM
M+2TM+0T*#0H@("\O("TM+2TM($-R96%T:6YG('1H92!O8FIE8W0@*'5N8V]M
M<')E<W-E9"!A<F-H:79E*0T*("`D=&%R7V]B:F5C="`](&YE=R!!<F-H:79E
M7U1A<B@B=&%R;F%M92YT87(B*3L-"B`@)'1A<E]O8FIE8W0M/G-E=$5R<F]R
M2&%N9&QI;F<H4$5!4E]%4E)/4E]04DE.5"D[#0H-"B`@+R\@+2TM+2T@0W)E
M871I;F<@=&AE(&%R8VAI=F4-"B`@)'9?;&ES=%LP73TB9FEL92YT>'0B.PT*
M("`D=E]L:7-T6S%=/2)D871A+R([#0H@("1V7VQI<W1;,ET](F9I;&4N;&]G
M(CL-"B`@)'1A<E]O8FIE8W0M/F-R96%T92@D=E]L:7-T*3L-"@T*("`O+R`M
M+2TM+2!!9&1I;F<@9FEL97,-"B`@)'9?;&ES=%LP73TB9&5V+V9I;&4N='AT
M(CL-"B`@)'9?;&ES=%LQ73TB9&5V+V1A=&$O(CL-"B`@)'9?;&ES=%LR73TB
M;&]G+V9I;&4N;&]G(CL-"B`@)'1A<E]O8FIE8W0M/F%D9"@D=E]L:7-T*3L-
M"@T*("`O+R`M+2TM+2!!9&1I;F<@;6]R92!F:6QE<PT*("`D=&%R7V]B:F5C
M="T^861D*")R96QE87-E+VYE=V9I;&4N;&]G(')E;&5A<V4O<F5A9&UE+G1X
M="(I.PT*#0H@("\O("TM+2TM($QI<W1I;F<@=&AE(&-O;G1E;G0-"B`@:68@
M*"@D=E]L:7-T("`]("`D=&%R7V]B:F5C="T^;&ES=$-O;G1E;G0H*2D@(3T@
M,"D-"B`@("!F;W(@*"1I/3`[("1I/'-I>F5O9B@D=E]L:7-T*3L@)&DK*RD-
M"B`@("![#0H@("`@("!E8VAO(")&:6QE;F%M92`Z)R(N)'9?;&ES=%LD:5U;
M9FEL96YA;65=+B(G/&)R/B([#0H@("`@("!E8VAO("(@+G-I>F4@.B<B+B1V
M7VQI<W1;)&E=6W-I>F5=+B(G/&)R/B([#0H@("`@("!E8VAO("(@+FUT:6UE
M(#HG(BXD=E]L:7-T6R1I75MM=&EM95TN(B<@*"(N9&%T92@B;"!D4R!O9B!&
M(%D@:#II.G,@02(L("1V7VQI<W1;)&E=6VUT:6UE72DN(BD\8G(^(CL-"B`@
M("`@(&5C:&\@(B`N;6]D92`Z)R(N)'9?;&ES=%LD:5U;;6]D95TN(B<\8G(^
M(CL-"B`@("`@(&5C:&\@(B`N=6ED(#HG(BXD=E]L:7-T6R1I75MU:61=+B(G
M/&)R/B([#0H@("`@("!E8VAO("(@+F=I9"`Z)R(N)'9?;&ES=%LD:5U;9VED
M72XB)SQB<CXB.PT*("`@("`@96-H;R`B("YT>7!E9FQA9R`Z)R(N)'9?;&ES
M=%LD:5U;='EP969L86==+B(G/&)R/B([#0H@("`@?0T*#0H@("\O("TM+2TM
M($5X=')A8W1I;F<@=&AE(&%R8VAI=F4@:6X@9&ER96-T;W)Y(")I;G-T86QL
M(@T*("`D=&%R7V]B:F5C="T^97AT<F%C="@B:6YS=&%L;"(I.PT*#0H-"E!U
M8FQI8R!A<F=U;65N=',@.@T*+2TM+2TM+2TM+2TM+2TM+2TM#0H-"DYO;F4-
M"@T*#0I0=6)L:6,@365T:&]D<R`Z#0HM+2TM+2TM+2TM+2TM+2TM#0H-"DUE
M=&AO9"`Z($%R8VAI=F5?5&%R*"1P7W1A<FYA;64L("1C;VUP<F5S<R`](&YU
M;&PI#0I$97-C<FEP=&EO;B`Z#0H@($%R8VAI=F5?5&%R($-L87-S(&-O;G-T
M<G5C=&]R+B!4:&ES(&9L879O=7(@;V8@=&AE(&-O;G-T<G5C=&]R(&]N;'D-
M"B`@9&5C;&%R92!A(&YE=R!!<F-H:79E7U1A<B!O8FIE8W0L(&ED96YT:69Y
M:6YG(&ET(&)Y('1H92!N86UE(&]F('1H90T*("!T87(@9FEL92X-"B`@268@
M=&AE(&-O;7!R97-S(&%R9W5M96YT(&ES('-E="!T:&4@=&%R('=I;&P@8F4@
M<F5A9"!O<B!C<F5A=&5D(&%S(&$-"B`@9WII<"!O<B!B>C(@8V]M<')E<W-E
M9"!405(@9FEL92X@#0I!<F=U;65N=',@.@T*("`D<%]T87)N86UE(#H@02!V
M86QI9"!F:6QE;F%M92!F;W(@=&AE('1A<B!A<F-H:79E(&9I;&4N#0H@("1P
M7V-O;7!R97-S(#H@8V%N(&)E(&YU;&PL("=G>B<@;W(@)V)Z,B<N($9O<@T*
M("`@("`@("`@("`@("`@(&-O;7!A=&EB:6QI='D@<F5A<V]N(&ET(&-A;B!A
M;'-O(&)E('1R=64N(%1H:7,-"B`@("`@("`@("`@("`@("!P87)A;65T97(@
M:6YD:6-A=&5S(&EF(&=Z:7`@;W(@8GHR(&-O;7!R97-S:6]N#0H@("`@("`@
M("`@("`@("`@:7,@<F5Q=6ER960N(`T*4F5T=7)N('9A;'5E(#H-"B`@5&AE
M($%R8VAI=F5?5&%R(&]B:F5C="X-"E-A;7!L92`Z#0H@("1T87)?;V)J96-T
M(#T@;F5W($%R8VAI=F5?5&%R*")T87)N86UE+G1A<B(I.PT*("`D=&%R7V]B
M:F5C=%]C;VUP<F5S<V5D(#T@;F5W($%R8VAI=F5?5&%R*")T87)N86UE+G1G
M>B(L('1R=64I.PT*2&]W(&ET('=O<FMS(#H-"B`@26YI=&EA;&EZ92!T:&4@
M;V)J96-T+@T*#0I-971H;V0@.B!C<F5A=&4H)'!?9FEL96QI<W0I#0I$97-C
M<FEP=&EO;B`Z#0H@(%1H:7,@;65T:&]D(&-R96%T97,@=&AE(&%R8VAI=F4@
M9FEL92!A;F0@861D('1H92!F:6QE<R`O(&1I<F5C=&]R:65S#0H@('1H870@
M87)E(&QI<W1E9"!I;B`D<%]F:6QE;&ES="X@#0H@($EF('1H92!F:6QE(&%L
M<F5A9'D@97AI<W1S(&%N9"!I<R!W<FET86)L92P@:70@:7,@<F5P;&%C960@
M8GD@=&AE#0H@(&YE=R!T87(N($ET(&ES(&$@8W)E871E(&%N9"!N;W0@86X@
M861D+B!)9B!T:&4@9FEL92!E>&ES=',@86YD(&ES#0H@(')E860M;VYL>2!O
M<B!I<R!A(&1I<F5C=&]R>2!I="!I<R!N;W0@<F5P;&%C960N(%1H92!M971H
M;V0@<F5T=7)N#0H@(&9A;'-E(&%N9"!A(%!%05(@97)R;W(@=&5X="X@#0H@
M(%1H92`D<%]F:6QE;&ES="!P87)A;65T97(@8V%N(&)E(&%N(&%R<F%Y(&]F
M('-T<FEN9RP@96%C:"!S=')I;F<-"B`@<F5P<F5S96YT:6YG(&$@9FEL96YA
M;64@;W(@82!D:7)E8W1O<GD@;F%M92!W:71H('1H96ER('!A=&@@:68-"B`@
M;F5E9&5D+B!)="!C86X@86QS;R!B92!A('-I;F=L92!S=')I;F<@=VET:"!N
M86UE<R!S97!A<F%T960@8GD@80T*("!S:6YG;&4@8FQA;FLN(`T*("!3964@
M86QS;R!C<F5A=&5-;V1I9GDH*2!M971H;V0@9F]R(&UO<F4@9&5T86EL<RX-
M"D%R9W5M96YT<R`Z#0H@("1P7V9I;&5L:7-T(#H@06X@87)R87D@;V8@9FEL
M96YA;65S(&%N9"!D:7)E8W1O<GD@;F%M97,L(&]R(&$@<VEN9VQE#0H@('-T
M<FEN9R!W:71H(&YA;65S('-E<&%R871E9"!B>2!A('-I;F=L92!B;&%N:R!S
M<&%C92X@#0I2971U<FX@=F%L=64@.@T*("!T<G5E(&]N('-U8V-E<W,L(&9A
M;'-E(&]N(&5R<F]R+@T*4V%M<&QE(#$@.@T*("`D=&%R7V]B:F5C="`](&YE
M=R!!<F-H:79E7U1A<B@B=&%R;F%M92YT87(B*3L-"B`@)'1A<E]O8FIE8W0M
M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]04DE.5"D[("`O+R!/<'1I
M;VYA;"!E<G)O<B!H86YD;&EN9PT*("`D=E]L:7-T6S!=/2)F:6QE+G1X="([
M#0H@("1V7VQI<W1;,5T](F1A=&$O(CL@*$]P=&EO;F%L("<O)R!A="!T:&4@
M96YD*0T*("`D=E]L:7-T6S)=/2)F:6QE+FQO9R([#0H@("1T87)?;V)J96-T
M+3YC<F5A=&4H)'9?;&ES="D[#0I386UP;&4@,B`Z#0H@("1T87)?;V)J96-T
M(#T@;F5W($%R8VAI=F5?5&%R*")T87)N86UE+G1A<B(I.PT*("`D=&%R7V]B
M:F5C="T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U!224Y4*3L@("\O
M($]P=&EO;F%L(&5R<F]R(&AA;F1L:6YG#0H@("1T87)?;V)J96-T+3YC<F5A
M=&4H(F9I;&4N='AT(&1A=&$O(&9I;&4N;&]G(BD[#0I(;W<@:70@=V]R:W,@
M.@T*("!*=7-T(&-A;&QI;F<@=&AE(&-R96%T94UO9&EF>2@I(&UE=&AO9"!W
M:71H('1H92!R:6=H="!P87)A;65T97)S+@T*#0I-971H;V0@.B!C<F5A=&5-
M;V1I9GDH)'!?9FEL96QI<W0L("1P7V%D9%]D:7(L("1P7W)E;6]V95]D:7(@
M/2`B(BD-"D1E<V-R:7!T:6]N(#H-"B`@5&AI<R!M971H;V0@8W)E871E<R!T
M:&4@87)C:&EV92!F:6QE(&%N9"!A9&0@=&AE(&9I;&5S("\@9&ER96-T;W)I
M97,-"B`@=&AA="!A<F4@;&ES=&5D(&EN("1P7V9I;&5L:7-T+B`-"B`@268@
M=&AE(&9I;&4@86QR96%D>2!E>&ES=',@86YD(&ES('=R:71A8FQE+"!I="!I
M<R!R97!L86-E9"!B>2!T:&4-"B`@;F5W('1A<BX@270@:7,@82!C<F5A=&4@
M86YD(&YO="!A;B!A9&0N($EF('1H92!F:6QE(&5X:7-T<R!A;F0@:7,-"B`@
M<F5A9"UO;FQY(&]R(&ES(&$@9&ER96-T;W)Y(&ET(&ES(&YO="!R97!L86-E
M9"X@5&AE(&UE=&AO9"!R971U<FX-"B`@9F%L<V4@86YD(&$@4$5!4B!E<G)O
M<B!T97AT+B`-"B`@5&AE("1P7V9I;&5L:7-T('!A<F%M971E<B!C86X@8F4@
M86X@87)R87D@;V8@<W1R:6YG+"!E86-H('-T<FEN9PT*("!R97!R97-E;G1I
M;F<@82!F:6QE;F%M92!O<B!A(&1I<F5C=&]R>2!N86UE('=I=&@@=&AE:7(@
M<&%T:"!I9@T*("!N965D960N($ET(&-A;B!A;'-O(&)E(&$@<VEN9VQE('-T
M<FEN9R!W:71H(&YA;65S('-E<&%R871E9"!B>2!A#0H@('-I;F=L92!B;&%N
M:RX@#0H@(%1H92!P871H(&EN9&EC871E9"!I;B`D<%]R96UO=F5?9&ER('=I
M;&P@8F4@<F5M;W9E9"!F<F]M('1H90T*("!M96UO<FEZ960@<&%T:"!O9B!E
M86-H(&9I;&4@+R!D:7)E8W1O<GD@;&ES=&5D('=H96X@=&AI<R!P871H#0H@
M(&5X:7-T<RX@0GD@9&5F875L="!N;W1H:6YG(&ES(')E;6]V960@*&5M<'1Y
M('!A=&@@(B(I(`T*("!4:&4@<&%T:"!I;F1I8V%T960@:6X@)'!?861D7V1I
M<B!W:6QL(&)E(&%D9&5D(&%T('1H92!B96=I;FYI;F<@;V8-"B`@=&AE(&UE
M;6]R:7IE9"!P871H(&]F(&5A8V@@9FEL92`O(&1I<F5C=&]R>2!L:7-T960N
M($AO=V5V97(@:70@8V%N#0H@(&)E('-E="!T;R!E;7!T>2`B(BX@5&AE(&%D
M9&EN9R!O9B!A('!A=&@@:7,@9&]N92!A9G1E<B!T:&4@<F5M;W9I;F<-"B`@
M;V8@<&%T:"X@#0H@(%1H92!P871H(&%D9"]R96UO=F4@86)I;&ET>2!E;F%B
M;&5S('1H92!U<V5R('1O('!R97!A<F4@86X@87)C:&EV90T*("!F;W(@97AT
M<F%C=&EO;B!I;B!A(&1I9F9E<F5N="!P871H('1H86X@=&AE(&]R:6=I;B!F
M:6QE<R!A<F4N(`T*("!3964@86QS;R!A9&1-;V1I9GDH*2!M971H;V0@9F]R
M(&9I;&4@861D:6YG('!R;W!E<G1I97,N#0I!<F=U;65N=',@.@T*("`D<%]F
M:6QE;&ES="`Z($%N(&%R<F%Y(&]F(&9I;&5N86UE<R!A;F0@9&ER96-T;W)Y
M(&YA;65S+"!O<B!A('-I;F=L90T*("`@("`@("`@("`@("`@('-T<FEN9R!W
M:71H(&YA;65S('-E<&%R871E9"!B>2!A('-I;F=L92!B;&%N:R!S<&%C92X-
M"B`@)'!?861D7V1I<B`Z($$@<W1R:6YG('=H:6-H(&-O;G1A:6YS(&$@<&%T
M:"!T;R!B92!A9&1E9"!T;R!T:&4-"B`@("`@("`@("`@("`@(&UE;6]R:7IE
M9"!P871H(&]F(&5A8V@@96QE;65N="!I;B!T:&4@;&ES="X@#0H@("1P7W)E
M;6]V95]D:7(@.B!!('-T<FEN9R!W:&EC:"!C;VYT86EN<R!A('!A=&@@=&\@
M8F4@<F5M;W9E9"!F<F]M#0H@("`@("`@("`@("`@("`@("!T:&4@;65M;W)I
M>F5D('!A=&@@;V8@96%C:"!E;&5M96YT(&EN('1H92!L:7-T+"!W:&5N#0H)
M"2`@<F5L979A;G0N#0I2971U<FX@=F%L=64@.@T*("!T<G5E(&]N('-U8V-E
M<W,L(&9A;'-E(&]N(&5R<F]R+@T*4V%M<&QE(#$@.@T*("`D=&%R7V]B:F5C
M="`](&YE=R!!<F-H:79E7U1A<B@B=&%R;F%M92YT87(B*3L-"B`@)'1A<E]O
M8FIE8W0M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]04DE.5"D[("`O
M+R!/<'1I;VYA;"!E<G)O<B!H86YD;&EN9PT*("`D=E]L:7-T6S!=/2)F:6QE
M+G1X="([#0H@("1V7VQI<W1;,5T](F1A=&$O(CL@*$]P=&EO;F%L("<O)R!A
M="!T:&4@96YD*0T*("`D=E]L:7-T6S)=/2)F:6QE+FQO9R([#0H@("1T87)?
M;V)J96-T+3YC<F5A=&5-;V1I9GDH)'9?;&ES="P@(FEN<W1A;&PB*3L-"B`@
M+R\@9FEL97,@87)E('-T;W)E9"!I;B!T:&4@87)C:&EV92!A<R`Z#0H@("\O
M("`@:6YS=&%L;"]F:6QE+G1X=`T*("`O+R`@(&EN<W1A;&PO9&%T80T*("`O
M+R`@(&EN<W1A;&PO9&%T82]F:6QE,2YT>'0-"B`@+R\@("!I;G-T86QL+V1A
M=&$O+BXN(&%L;"!T:&4@9FEL97,@86YD('-U8BUD:7)S(&]F(&1A=&$O#0H@
M("\O("`@:6YS=&%L;"]F:6QE+FQO9PT*4V%M<&QE(#(@.@T*("`D=&%R7V]B
M:F5C="`](&YE=R!!<F-H:79E7U1A<B@B=&%R;F%M92YT87(B*3L-"B`@)'1A
M<E]O8FIE8W0M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]04DE.5"D[
M("`O+R!/<'1I;VYA;"!E<G)O<B!H86YD;&EN9PT*("`D=E]L:7-T6S!=/2)D
M978O9FEL92YT>'0B.PT*("`D=E]L:7-T6S%=/2)D978O9&%T82\B.R`H3W!T
M:6]N86P@)R\G(&%T('1H92!E;F0I#0H@("1V7VQI<W1;,ET](FQO9R]F:6QE
M+FQO9R([#0H@("1T87)?;V)J96-T+3YC<F5A=&5-;V1I9GDH)'9?;&ES="P@
M(FEN<W1A;&PB+"`B9&5V(BD[#0H@("\O(&9I;&5S(&%R92!S=&]R960@:6X@
M=&AE(&%R8VAI=F4@87,@.@T*("`O+R`@(&EN<W1A;&PO9FEL92YT>'0-"B`@
M+R\@("!I;G-T86QL+V1A=&$-"B`@+R\@("!I;G-T86QL+V1A=&$O9FEL93$N
M='AT#0H@("\O("`@:6YS=&%L;"]D871A+RXN+B!A;&P@=&AE(&9I;&5S(&%N
M9"!S=6(M9&ER<R!O9B!D871A+PT*("`O+R`@(&EN<W1A;&PO;&]G+V9I;&4N
M;&]G#0I(;W<@:70@=V]R:W,@.@T*("!/<&5N('1H92!F:6QE(&EN('=R:71E
M(&UO9&4@*&5R87-I;F<@=&AE(&5X:7-T:6YG(&]N92!I9B!O;F4I+`T*("!C
M86QL('1H92!?861D3&ES="@I(&UE=&AO9"!F;W(@861D:6YG('1H92!F:6QE
M<R!I;B!A;B!E;7!T>2!A<F-H:79E+`T*("!A9&0@=&AE('1A<B!F;V]T97(@
M*#4Q,B!B>71E<R!B;&]C:RDL(&-L;W-E('1H92!T87(@9FEL92X-"@T*#0I-
M971H;V0@.B!A9&1-;V1I9GDH)'!?9FEL96QI<W0L("1P7V%D9%]D:7(L("1P
M7W)E;6]V95]D:7(](B(I#0I$97-C<FEP=&EO;B`Z#0H@(%1H:7,@;65T:&]D
M(&%D9"!T:&4@9FEL97,@+R!D:7)E8W1O<FEE<R!L:7-T960@:6X@)'!?9FEL
M96QI<W0@870@=&AE#0H@(&5N9"!O9B!T:&4@97AI<W1I;F<@87)C:&EV92X@
M268@=&AE(&%R8VAI=F4@9&]E<R!N;W0@>65T(&5X:7-T<R!I=`T*("!I<R!C
M<F5A=&5D+@T*("!4:&4@)'!?9FEL96QI<W0@<&%R86UE=&5R(&-A;B!B92!A
M;B!A<G)A>2!O9B!S=')I;F<L(&5A8V@@<W1R:6YG#0H@(')E<')E<V5N=&EN
M9R!A(&9I;&5N86UE(&]R(&$@9&ER96-T;W)Y(&YA;64@=VET:"!T:&5I<B!P
M871H(&EF#0H@(&YE961E9"X@270@8V%N(&%L<V\@8F4@82!S:6YG;&4@<W1R
M:6YG('=I=&@@;F%M97,@<V5P87)A=&5D(&)Y(&$-"B`@<VEN9VQE(&)L86YK
M+B`-"B`@5&AE('!A=&@@:6YD:6-A=&5D(&EN("1P7W)E;6]V95]D:7(@=VEL
M;"!B92!R96UO=F5D(&9R;VT@=&AE#0H@(&UE;6]R:7IE9"!P871H(&]F(&5A
M8V@@9FEL92`O(&1I<F5C=&]R>2!L:7-T960@=VAE;B!T:&ES('!A=&@-"B`@
M97AI<W1S+B!">2!D969A=6QT(&YO=&AI;F<@:7,@<F5M;W9E9"`H96UP='D@
M<&%T:"`B(BD@#0H@(%1H92!P871H(&EN9&EC871E9"!I;B`D<%]A9&1?9&ER
M('=I;&P@8F4@861D960@870@=&AE(&)E9VEN;FEN9R!O9@T*("!T:&4@;65M
M;W)I>F5D('!A=&@@;V8@96%C:"!F:6QE("\@9&ER96-T;W)Y(&QI<W1E9"X@
M2&]W979E<B!I="!C86X-"B`@8F4@<V5T('1O(&5M<'1Y("(B+B!4:&4@861D
M:6YG(&]F(&$@<&%T:"!I<R!D;VYE(&%F=&5R('1H92!R96UO=FEN9PT*("!O
M9B!P871H+B`-"B`@5&AE('!A=&@@861D+W)E;6]V92!A8FEL:71Y(&5N86)L
M97,@=&AE('5S97(@=&\@<')E<&%R92!A;B!A<F-H:79E#0H@(&9O<B!E>'1R
M86-T:6]N(&EN(&$@9&EF9F5R96YT('!A=&@@=&AA;B!T:&4@;W)I9VEN(&9I
M;&5S(&%R92X@#0H@($EF(&$@9FEL92]D:7(@:7,@86QR96%D>2!I;B!T:&4@
M87)C:&EV92!I="!W:6QL(&]N;'D@8F4@861D960@870@=&AE#0H@(&5N9"!O
M9B!T:&4@87)C:&EV92X@5&AE<F4@:7,@;F\@=7!D871E(&]F('1H92!E>&ES
M=&EN9R!A<F-H:79E9`T*("!F:6QE+V1I<BX@2&]W979E<B!W:&EL92!E>'1R
M86-T:6YG('1H92!A<F-H:79E+"!T:&4@;&%S="!F:6QE('=I;&P-"B`@<F5P
M;&%C92!T:&4@9FER<W0@;VYE+B!4:&ES(')E<W5L=',@:6X@82!N;VYE(&]P
M=&EM:7IA=&EO;B!O9B!T:&4-"B`@87)C:&EV92!S:7IE+B`-"B`@268@82!F
M:6QE+V1I<B!D;V5S(&YO="!E>&ES="!T:&4@9FEL92]D:7(@:7,@:6=N;W)E
M9"X@2&]W979E<B!A;@T*("!E<G)O<B!T97AT(&ES('-E;F0@=&\@4$5!4B!E
M<G)O<BX@#0H@($EF(&$@9FEL92]D:7(@:7,@;F]T(')E861A8FQE('1H92!F
M:6QE+V1I<B!I<R!I9VYO<F5D+B!(;W=E=F5R(&%N#0H@(&5R<F]R('1E>'0@
M:7,@<V5N9"!T;R!014%2(&5R<F]R+B`-"B`@268@=&AE(')E<W5L=&EN9R!F
M:6QE;F%M92]D:7)N86UE("AA9G1E<B!T:&4@861D+W)E;6]V92!O<'1I;VX@
M;W(-"B`@;F]T*2!S=')I;F<@:7,@9W)E871E<B!T:&%N(#DY(&-H87(L('1H
M92!F:6QE+V1I<B!I<PT*("!I9VYO<F5D+B!(;W=E=F5R(&%N(&5R<F]R('1E
M>'0@:7,@<V5N9"!T;R!014%2(&5R<F]R+B`-"D%R9W5M96YT<R`Z#0H@("1P
M7V9I;&5L:7-T(#H@06X@87)R87D@;V8@9FEL96YA;65S(&%N9"!D:7)E8W1O
M<GD@;F%M97,L(&]R(&$@<VEN9VQE#0H@("`@("`@("`@("`@("`@<W1R:6YG
M('=I=&@@;F%M97,@<V5P87)A=&5D(&)Y(&$@<VEN9VQE(&)L86YK('-P86-E
M+B`-"B`@)'!?861D7V1I<B`Z($$@<W1R:6YG('=H:6-H(&-O;G1A:6YS(&$@
M<&%T:"!T;R!B92!A9&1E9"!T;R!T:&4-"B`@("`@("`@("`@("`@(&UE;6]R
M:7IE9"!P871H(&]F(&5A8V@@96QE;65N="!I;B!T:&4@;&ES="X@#0H@("1P
M7W)E;6]V95]D:7(@.B!!('-T<FEN9R!W:&EC:"!C;VYT86EN<R!A('!A=&@@
M=&\@8F4@<F5M;W9E9"!F<F]M#0H@("`@("`@("`@("`@("`@("!T:&4@;65M
M;W)I>F5D('!A=&@@;V8@96%C:"!E;&5M96YT(&EN('1H92!L:7-T+"!W:&5N
M#0H)"2`@<F5L979A;G0N#0I2971U<FX@=F%L=64@.@T*("!T<G5E(&]N('-U
M8V-E<W,L(&9A;'-E(&]N(&5R<F]R+@T*4V%M<&QE(#$@.@T*("`D=&%R7V]B
M:F5C="`](&YE=R!!<F-H:79E7U1A<B@B=&%R;F%M92YT87(B*3L-"B`@6RXN
M+ET-"B`@)'9?;&ES=%LP73TB9&5V+V9I;&4N='AT(CL-"B`@)'9?;&ES=%LQ
M73TB9&5V+V1A=&$O(CL@*$]P=&EO;F%L("<O)R!A="!T:&4@96YD*0T*("`D
M=E]L:7-T6S)=/2)L;V<O9FEL92YL;V<B.PT*("`D=&%R7V]B:F5C="T^861D
M36]D:69Y*"1V7VQI<W0L(")I;G-T86QL(BD[#0H@("\O(&9I;&5S(&%R92!S
M=&]R960@:6X@=&AE(&%R8VAI=F4@87,@.@T*("`O+R`@(&EN<W1A;&PO9FEL
M92YT>'0-"B`@+R\@("!I;G-T86QL+V1A=&$-"B`@+R\@("!I;G-T86QL+V1A
M=&$O9FEL93$N='AT#0H@("\O("`@:6YS=&%L;"]D871A+RXN+B!A;&P@=&AE
M(&9I;&5S(&%N9"!S=6(M9&ER<R!O9B!D871A+PT*("`O+R`@(&EN<W1A;&PO
M9FEL92YL;V<-"E-A;7!L92`R(#H-"B`@)'1A<E]O8FIE8W0@/2!N97<@07)C
M:&EV95]487(H(G1A<FYA;64N=&%R(BD[#0H@(%LN+BY=#0H@("1V7VQI<W1;
M,%T](F1E=B]F:6QE+G1X="([#0H@("1V7VQI<W1;,5T](F1E=B]D871A+R([
M("A/<'1I;VYA;"`G+R<@870@=&AE(&5N9"D-"B`@)'9?;&ES=%LR73TB;&]G
M+V9I;&4N;&]G(CL-"B`@)'1A<E]O8FIE8W0M/F%D9$UO9&EF>2@D=E]L:7-T
M+"`B:6YS=&%L;"(L(")D978B*3L-"B`@+R\@9FEL97,@87)E('-T;W)E9"!I
M;B!T:&4@87)C:&EV92!A<R`Z#0H@("\O("`@:6YS=&%L;"]F:6QE+G1X=`T*
M("`O+R`@(&EN<W1A;&PO9&%T80T*("`O+R`@(&EN<W1A;&PO9&%T82]F:6QE
M,2YT>'0-"B`@+R\@("!I;G-T86QL+V1A=&$O+BXN(&%L;"!T:&4@9FEL97,@
M86YD('-U8BUD:7)S(&]F(&1A=&$O#0H@("\O("`@:6YS=&%L;"]L;V<O9FEL
M92YL;V<-"DAO=R!I="!W;W)K<R`Z#0H@($EF('1H92!A<F-H:79E(&1O97,@
M;F]T(&5X:7-T<R!I="!C<F5A=&4@:70@86YD(&%D9"!T:&4@9FEL97,N#0H@
M($EF('1H92!A<F-H:79E(&1O97,@97AI<W1S(&%N9"!I<R!N;W0@8V]M<')E
M<W-E9"P@:70@;W!E;B!I="P@:G5M<`T*("!B969O<F4@=&AE(&QA<W0@96UP
M='D@-3$R(&)Y=&5S(&)L;V-K("AT87(@9F]O=&5R*2!A;F0@861D('1H92!F
M:6QE<PT*("!A="!T:&ES('!O:6YT+@T*("!)9B!T:&4@87)C:&EV92!D;V5S
M(&5X:7-T<R!A;F0@:7,@8V]M<')E<W-E9"P@82!T96UP;W)A<GD@8V]P>2!F
M:6QE#0H@(&ES(&-R96%T960N(%1H:7,@=&5M<&]R87)Y(&9I;&4@:7,@=&AE
M;B`G9WII<"<@<F5A9"!B;&]C:R!B>2!B;&]C:PT*("!U;G1I;"!T:&4@;&%S
M="!E;7!T>2!B;&]C:RX@5&AE(&YE=R!F:6QE<R!A<F4@=&AE;B!A9&1E9"!I
M;B!T:&4-"B`@8V]M<')E<W-E9"!F:6QE+@T*("!4:&4@861D:6YG(&]F(&9I
M;&5S(&ES(&1O;F4@8GD@9V]I;F<@=&AR;W5G:"!T:&4@9FEL92]D:7(@;&ES
M="P-"B`@861D:6YG(&9I;&5S('!E<B!F:6QE<RP@:6X@82!R96-U<G-I=F4@
M=V%Y('1H<F]U9V@@=&AE#0H@(&1I<F5C=&]R>2X@16%C:"!T:6UE(&$@<&%T
M:"!N965D('1O(&)E(&%D9&5D+W)E;6]V960@:70@:7,@9&]N90T*("!B969O
M<F4@=W)I=&EN9R!T:&4@9FEL92!H96%D97(@:6X@=&AE(&%R8VAI=F4N#0H-
M"DUE=&AO9"`Z(&%D9"@D<%]F:6QE;&ES="D-"D1E<V-R:7!T:6]N(#H-"B`@
M5&AI<R!M971H;V0@861D('1H92!F:6QE<R`O(&1I<F5C=&]R:65S(&QI<W1E
M9"!I;B`D<%]F:6QE;&ES="!A="!T:&4-"B`@96YD(&]F('1H92!E>&ES=&EN
M9R!A<F-H:79E+B!)9B!T:&4@87)C:&EV92!D;V5S(&YO="!Y970@97AI<W1S
M(&ET#0H@(&ES(&-R96%T960N(`T*("!4:&4@)'!?9FEL96QI<W0@<&%R86UE
M=&5R(&-A;B!B92!A;B!A<G)A>2!O9B!S=')I;F<L(&5A8V@@<W1R:6YG#0H@
M(')E<')E<V5N=&EN9R!A(&9I;&5N86UE(&]R(&$@9&ER96-T;W)Y(&YA;64@
M=VET:"!T:&5I<B!P871H(&EF#0H@(&YE961E9"X@270@8V%N(&%L<V\@8F4@
M82!S:6YG;&4@<W1R:6YG('=I=&@@;F%M97,@<V5P87)A=&5D(&)Y(&$-"B`@
M<VEN9VQE(&)L86YK+B`-"B`@4V5E(&%D9$UO9&EF>2@I(&UE=&AO9"!F;W(@
M9&5T86EL<R!A;F0@;&EM:71A=&EO;G,N#0I!<F=U;65N=',@.@T*("`D<%]F
M:6QE;&ES="`Z($%N(&%R<F%Y(&]F(&9I;&5N86UE<R!A;F0@9&ER96-T;W)Y
M(&YA;65S+"!O<B!A('-I;F=L90T*("!S=')I;F<@=VET:"!N86UE<R!S97!A
M<F%T960@8GD@82!S:6YG;&4@8FQA;FL@<W!A8V4N(`T*4F5T=7)N('9A;'5E
M(#H-"B`@=')U92!O;B!S=6-C97-S+"!F86QS92!O;B!E<G)O<BX-"E-A;7!L
M92`Q(#H-"B`@)'1A<E]O8FIE8W0@/2!N97<@07)C:&EV95]487(H(G1A<FYA
M;64N=&%R(BD[#0H@(%LN+BY=#0H@("1V7VQI<W1;,%T](F1E=B]F:6QE+G1X
M="([#0H@("1V7VQI<W1;,5T](F1E=B]D871A+R([("A/<'1I;VYA;"`G+R<@
M870@=&AE(&5N9"D-"B`@)'9?;&ES=%LR73TB;&]G+V9I;&4N;&]G(CL-"B`@
M)'1A<E]O8FIE8W0M/F%D9"@D=E]L:7-T*3L-"E-A;7!L92`R(#H-"B`@)'1A
M<E]O8FIE8W0@/2!N97<@07)C:&EV95]487(H(G1A<FYA;64N=&=Z(BP@=')U
M92D[#0H@(%LN+BY=#0H@("1V7VQI<W1;,%T](F1E=B]F:6QE+G1X="([#0H@
M("1V7VQI<W1;,5T](F1E=B]D871A+R([("A/<'1I;VYA;"`G+R<@870@=&AE
M(&5N9"D-"B`@)'9?;&ES=%LR73TB;&]G+V9I;&4N;&]G(CL-"B`@)'1A<E]O
M8FIE8W0M/F%D9"@D=E]L:7-T*3L-"DAO=R!I="!W;W)K<R`Z#0H@(%-I;7!L
M>2!C86QL('1H92!A9&1-;V1I9GDH*2!M971H;V0@=VET:"!T:&4@<FEG:'0@
M<&%R86UE=&5R<RX-"@T*365T:&]D(#H@861D4W1R:6YG*"1P7V9I;&5N86UE
M+"`D<%]S=')I;F<I#0I$97-C<FEP=&EO;B`Z#0H@(%1H:7,@;65T:&]D(&%D
M9"!A('-I;F=L92!S=')I;F<@87,@82!F:6QE(&%T('1H90T*("!E;F0@;V8@
M=&AE(&5X:7-T:6YG(&%R8VAI=F4N($EF('1H92!A<F-H:79E(&1O97,@;F]T
M('EE="!E>&ES=',@:70-"B`@:7,@8W)E871E9"X-"D%R9W5M96YT<R`Z#0H@
M("1P7V9I;&5N86UE(#H@02!S=')I;F<@=VAI8V@@8V]N=&%I;G,@=&AE(&9U
M;&P@9FEL96YA;64@<&%T:`T*("`@("`@("`@("`@("`@('1H870@=VEL;"!B
M92!A<W-O8VEA=&5D('=I=&@@=&AE('-T<FEN9RX-"B`@)'!?<W1R:6YG(#H@
M("!4:&4@8V]N=&5N="!O9B!T:&4@9FEL92!A9&1E9"!I;B!T:&4@87)C:&EV
M92X-"E)E='5R;B!V86QU92`Z#0H@('1R=64@;VX@<W5C8V5S<RP@9F%L<V4@
M;VX@97)R;W(N#0I386UP;&4@,2`Z#0H@("1V7V%R8VAI=F4@/2`F(&YE=R!!
M<F-H:79E7U1A<B@D<%]F:6QE;F%M92D[#0H@("1V7V%R8VAI=F4M/G-E=$5R
M<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]04DE.5"D[#0H@("1V7W)E<W5L="`]
M("1V7V%R8VAI=F4M/F%D9%-T<FEN9R@G9&%T82]T97-T+G1X="<L("=4:&ES
M(&ES('1H92!T97AT(&]F('1H92!S=')I;F<G*3L-"@T*#0I-971H;V0@.B!E
M>'1R86-T*"1P7W!A=&@@/2`B(BD-"D1E<V-R:7!T:6]N(#H-"B`@5&AI<R!M
M971H;V0@97AT<F%C="!A;&P@=&AE(&-O;G1E;G0@;V8@=&AE(&%R8VAI=F4@
M:6X@=&AE(&1I<F5C=&]R>0T*("!I;F1I8V%T960@8GD@)'!?<&%T:"Y)9B`D
M<%]P871H(&ES(&]P=&EO;F%L+"!I9B!N;W0@<V5T('1H92!A<F-H:79E#0H@
M(&ES(&5X=')A8W1E9"!I;B!T:&4@8W5R<F5N="!D:7)E8W1O<GDN(`T*("!7
M:&EL92!E>'1R86-T:6YG(&$@9FEL92P@:68@=&AE(&1I<F5C=&]R>2!P871H
M(&1O97,@;F]T(&5X:7-T<R!I="!I<PT*("!C<F5A=&5D+B`-"B`@4V5E(&5X
M=')A8W1-;V1I9GDH*2!F;W(@9&5T86EL<R!A;F0@;&EM:71A=&EO;G,N#0I!
M<F=U;65N=',@.@T*("`D<%]P871H(#H@3W!T:6]N86P@<&%T:"!W:&5R92!T
M:&4@9FEL97,O9&ER(&YE960@=&\@8GD@97AT<F%C=&5D+@T*4F5T=7)N('9A
M;'5E(#H-"B`@=')U92!O;B!S=6-C97-S+"!F86QS92!O;B!E<G)O<BX-"E-A
M;7!L92`Z#0H@("1T87)?;V)J96-T(#T@;F5W($%R8VAI=F5?5&%R*")T87)N
M86UE+G1A<B(I.PT*("`D=&%R7V]B:F5C="T^97AT<F%C="@I.PT*2&]W(&ET
M('=O<FMS(#H-"B`@4VEM<&QY(&-A;&P@=&AE(&5X=')A8W1-;V1I9GDH*2!M
M971H;V0@=VET:"!A<'!R;W!R:6%T92!P87)A;65T97)S+@T*#0I-971H;V0@
M.B!E>'1R86-T36]D:69Y*"1P7W!A=&@L("1P7W)E;6]V95]P871H*0T*1&5S
M8W)I<'1I;VX@.@T*("!4:&ES(&UE=&AO9"!E>'1R86-T(&%L;"!T:&4@8V]N
M=&5N="!O9B!T:&4@87)C:&EV92!I;B!T:&4@9&ER96-T;W)Y#0H@(&EN9&EC
M871E9"!B>2`D<%]P871H+B!7:&5N(')E;&5V86YT('1H92!M96UO<FEZ960@
M<&%T:"!O9B!T:&4-"B`@9FEL97,O9&ER(&-A;B!B92!M;V1I9FEE9"!B>2!R
M96UO=FEN9R!T:&4@)'!?<F5M;W9E7W!A=&@@<&%T:"!A="!T:&4-"B`@8F5G
M:6YN:6YG(&]F('1H92!F:6QE+V1I<B!P871H+B`-"B`@5VAI;&4@97AT<F%C
M=&EN9R!A(&9I;&4L(&EF('1H92!D:7)E8W1O<GD@<&%T:"!D;V5S(&YO="!E
M>&ES=',@:70@:7,-"B`@8W)E871E9"X@#0H@(%=H:6QE(&5X=')A8W1I;F<@
M82!F:6QE+"!I9B!T:&4@9FEL92!A;')E861Y(&5X:7-T<R!I="!I<R!R97!L
M86-E9`T*("!W:71H;W5T(&QO;VMI;F<@9F]R(&QA<W0@;6]D:69I8V%T:6]N
M(&1A=&4N(`T*("!7:&EL92!E>'1R86-T:6YG(&$@9FEL92P@:68@=&AE(&9I
M;&4@86QR96%D>2!E>&ES=',@86YD(&ES('=R:71E#0H@('!R;W1E8W1E9"P@
M=&AE(&5X=')A8W1I;VX@:7,@86)O<G1E9"X@#0H@(%=H:6QE(&5X=')A8W1I
M;F<@82!F:6QE+"!I9B!A(&1I<F5C=&]R>2!W:71H('1H92!S86UE(&YA;64@
M86QR96%D>0T*("!E>&ES=',L('1H92!E>'1R86-T:6]N(&ES(&%B;W)T960N
M(`T*("!7:&EL92!E>'1R86-T:6YG(&$@9&ER96-T;W)Y+"!I9B!A(&9I;&4@
M=VET:"!T:&4@<V%M92!N86UE(&%L<F5A9'D-"B`@97AI<W1S+"!T:&4@97AT
M<F%C=&EO;B!I<R!A8F]R=&5D+B`-"B`@5VAI;&4@97AT<F%C=&EN9R!A(&9I
M;&4O9&ER96-T;W)Y(&EF('1H92!D97-T:6YA=&EO;B!D:7)E8W1O<GD@97AI
M<W0-"B`@86YD(&ES('=R:71E('!R;W1E8W1E9"P@;W(@9&]E<R!N;W0@97AI
M<W0@8G5T(&-A;B!N;W0@8F4@8W)E871E9"P-"B`@=&AE(&5X=')A8W1I;VX@
M:7,@86)O<G1E9"X@#0H@($EF(&%F=&5R(&5X=')A8W1I;VX@86X@97AT<F%C
M=&5D(&9I;&4@9&]E<R!N;W0@<VAO=R!T:&4@8V]R<F5C=`T*("!S=&]R960@
M9FEL92!S:7IE+"!T:&4@97AT<F%C=&EO;B!I<R!A8F]R=&5D+B`-"B`@5VAE
M;B!T:&4@97AT<F%C=&EO;B!I<R!A8F]R=&5D+"!A(%!%05(@97)R;W(@=&5X
M="!I<R!S970@86YD(&9A;'-E#0H@(&ES(')E='5R;F5D+B!(;W=E=F5R('1H
M92!R97-U;'0@8V%N(&)E(&$@<&%R=&EA;"!E>'1R86-T:6]N('1H870@;6%Y
M#0H@(&YE960@=&\@8F4@;6%N=6%L;'D@8VQE86YE9"X@#0I!<F=U;65N=',@
M.@T*("`D<%]P871H(#H@5&AE('!A=&@@;V8@=&AE(&1I<F5C=&]R>2!W:&5R
M92!T:&4@9FEL97,O9&ER(&YE960@=&\@8GD-"B`@("`@("`@("`@(&5X=')A
M8W1E9"X@#0H@("1P7W)E;6]V95]P871H(#H@4&%R="!O9B!T:&4@;65M;W)I
M>F5D('!A=&@@=&AA="!C86X@8F4@<F5M;W9E9"!I9@T*("`@("`@("`@("`@
M("`@("`@('!R97-E;G0@870@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL92]D
M:7(@<&%T:"X@#0I2971U<FX@=F%L=64@.@T*("!T<G5E(&]N('-U8V-E<W,L
M(&9A;'-E(&]N(&5R<F]R+@T*4V%M<&QE(#H-"B`@+R\@26UA9VEN92!T87)N
M86UE+G1A<B!W:71H(&9I;&5S(#H-"B`@+R\@("!D978O9&%T82]F:6QE+G1X
M=`T*("`O+R`@(&1E=B]D871A+VQO9RYT>'0-"B`@+R\@("!R96%D;64N='AT
M#0H@("1T87)?;V)J96-T(#T@;F5W($%R8VAI=F5?5&%R*")T87)N86UE+G1A
M<B(I.PT*("`D=&%R7V]B:F5C="T^97AT<F%C=$UO9&EF>2@B:6YS=&%L;"(L
M(")D978B*3L-"B`@+R\@1FEL97,@=VEL;"!B92!E>'1R86-T960@=&AE<F4@
M.@T*("`O+R`@(&EN<W1A;&PO9&%T82]F:6QE+G1X=`T*("`O+R`@(&EN<W1A
M;&PO9&%T82]L;V<N='AT#0H@("\O("`@:6YS=&%L;"]R96%D;64N='AT#0I(
M;W<@:70@=V]R:W,@.@T*("!/<&5N('1H92!A<F-H:79E(&%N9"!C86QL(&$@
M;6]R92!G96YE<FEC(&9U;F-T:6]N('1H870@8V%N(&5X=')A8W0-"B`@;VYL
M>2!A('!A<G0@;V8@=&AE(&%R8VAI=F4@;W(@86QL('1H92!A<F-H:79E+B`-
M"B`@4V5E(&5X=')A8W1,:7-T*"D@;65T:&]D(&9O<B!M;W)E(&1E=&%I;',N
M#0H-"DUE=&AO9"`Z(&5X=')A8W1);E-T<FEN9R@D<%]F:6QE;F%M92D-"D1E
M<V-R:7!T:6]N(#H-"B`@5&AI<R!M971H;V0@97AT<F%C="!F<F]M('1H92!A
M<F-H:79E(&]N92!F:6QE(&ED96YT:69I960@8GD@)'!?9FEL96YA;64N#0H@
M(%1H92!R971U<FX@=F%L=64@:7,@82!S=')I;F<@=VET:"!T:&4@9FEL92!C
M;VYT96YT+"!O<B!.54Q,(&]N(&5R<F]R+B`-"D%R9W5M96YT<R`Z#0H@("1P
M7V9I;&5N86UE(#H@5&AE('!A=&@@;V8@=&AE(&9I;&4@=&\@97AT<F%C="!I
M;B!A('-T<FEN9RX@#0I2971U<FX@=F%L=64@.@T*("!A('-T<FEN9R!W:71H
M('1H92!F:6QE(&-O;G1E;G0@;W(@3E5,3"X-"E-A;7!L92`Z#0H@("\O($EM
M86=I;F4@=&%R;F%M92YT87(@=VET:"!F:6QE<R`Z#0H@("\O("`@9&5V+V1A
M=&$O9FEL92YT>'0-"B`@+R\@("!D978O9&%T82]L;V<N='AT#0H@("\O("`@
M9&5V+W)E861M92YT>'0-"B`@)'9?87)C:&EV92`]("8@;F5W($%R8VAI=F5?
M5&%R*"=T87)N86UE+G1A<B<I.PT*("`D=E]A<F-H:79E+3YS971%<G)O<DAA
M;F1L:6YG*%!%05)?15)23U)?4%))3E0I.PT*("`D=E]S=')I;F<@/2`D=E]A
M<F-H:79E+3YE>'1R86-T26Y3=')I;F<H)V1E=B]R96%D;64N='AT)RD[#0H@
M(&5C:&\@)'9?<W1R:6YG.PT*#0I-971H;V0@.B!L:7-T0V]N=&5N="@I#0I$
M97-C<FEP=&EO;B`Z#0H@(%1H:7,@;65T:&]D(')E='5R;G,@86X@87)R87D@
M;V8@87)R87ES('1H870@9&5S8W)I8F4@96%C:`T*("!F:6QE+V1I<F5C=&]R
M>2!P<F5S96YT(&EN('1H92!A<F-H:79E+B`-"B`@5&AE(&%R<F%Y(&ES(&YO
M="!S;W)T960L('-O(&ET('-H;W<@=&AE('!O<VET:6]N(&]F('1H92!F:6QE
M(&EN('1H90T*("!A<F-H:79E+B`-"B`@5&AE(&9I;&4@:6YF;W)M871I;VYS
M(&%R92`Z#0H@("`@)&9I;&5;9FEL96YA;65=(#H@3F%M92!A;F0@<&%T:"!O
M9B!T:&4@9FEL92]D:7(N#0H@("`@)&9I;&5;;6]D95T@.B!&:6QE('!E<FUI
M<W-I;VYS("AR97-U;'0@;V8@9FEL97!E<FUS*"DI#0H@("`@)&9I;&5;=6ED
M72`Z('5S97(@:60-"B`@("`D9FEL95MG:61=(#H@9W)O=7`@:60-"B`@("`D
M9FEL95MS:7IE72`Z(&9I;&5S:7IE#0H@("`@)&9I;&5;;71I;65=(#H@3&%S
M="!M;V1I9FEC871I;VX@=&EM92`H<F5S=6QT(&]F(&9I;&5M=&EM92@I*0T*
M("`@("1F:6QE6W1Y<&5F;&%G72`Z("(B(&9O<B!F:6QE+"`B-2(@9F]R(&1I
M<F5C=&]R>0T*07)G=6UE;G1S(#H-"E)E='5R;B!V86QU92`Z#0H@($%N(&%R
M<F%Y(&]F(&%R<F%Y<R!O<B`P(&]N(&5R<F]R+@T*4V%M<&QE(#H-"B`@)'1A
M<E]O8FIE8W0@/2!N97<@07)C:&EV95]487(H(G1A<FYA;64N=&%R(BD[#0H@
M(&EF("@H)'9?;&ES="`@/2`@)'1A<E]O8FIE8W0M/FQI<W1#;VYT96YT*"DI
M("$](#`I#0H@("`@9F]R("@D:3TP.R`D:3QS:7IE;V8H)'9?;&ES="D[("1I
M*RLI#0H@("`@>PT*("`@("`@96-H;R`B1FEL96YA;64@.B<B+B1V7VQI<W1;
M)&E=6V9I;&5N86UE72XB)SQB<CXB.PT*("`@("`@96-H;R`B("YS:7IE(#HG
M(BXD=E]L:7-T6R1I75MS:7IE72XB)SQB<CXB.PT*("`@("`@96-H;R`B("YM
M=&EM92`Z)R(N)'9?;&ES=%LD:5U;;71I;65=+B(G("@B+@T*("`@("`@("`@
M("!D871E*")L(&13(&]F($8@62!H.FDZ<R!!(BP@)'9?;&ES=%LD:5U;;71I
M;65=*2XB*3QB<CXB.PT*("`@("`@96-H;R`B("YM;V1E(#HG(BXD=E]L:7-T
M6R1I75MM;V1E72XB)SQB<CXB.PT*("`@("`@96-H;R`B("YU:60@.B<B+B1V
M7VQI<W1;)&E=6W5I9%TN(B<\8G(^(CL-"B`@("`@(&5C:&\@(B`N9VED(#HG
M(BXD=E]L:7-T6R1I75MG:61=+B(G/&)R/B([#0H@("`@("!E8VAO("(@+G1Y
M<&5F;&%G(#HG(BXD=E]L:7-T6R1I75MT>7!E9FQA9UTN(B<\8G(^(CL-"B`@
M("!]#0I(;W<@:70@=V]R:W,@.@T*("!#86QL('1H92!S86UE(&9U;F-T:6]N
M(&%S(&%N(&5X=')A8W0@:&]W979E<B!W:71H(&$@9FQA9R!T;R!O;FQY(&=O
M#0H@('1H<F]U9V@@=&AE(&%R8VAI=F4@=VET:&]U="!E>'1R86-T:6YG('1H
M92!F:6QE<RX@#0H-"DUE=&AO9"`Z(&5X=')A8W1,:7-T*"1P7V9I;&5L:7-T
M+"`D<%]P871H(#T@(B(L("1P7W)E;6]V95]P871H(#T@(B(I#0I$97-C<FEP
M=&EO;B`Z#0H@(%1H:7,@;65T:&]D(&5X=')A8W0@9G)O;2!T:&4@87)C:&EV
M92!O;FQY('1H92!F:6QE<R!I;F1I8V%T960@:6X@=&AE#0H@("1P7V9I;&5L
M:7-T+B!4:&5S92!F:6QE<R!A<F4@97AT<F%C=&5D(&EN('1H92!C=7)R96YT
M(&1I<F5C=&]R>2!O<@T*("!I;B!T:&4@9&ER96-T;W)Y(&EN9&EC871E9"!B
M>2!T:&4@;W!T:6]N86P@)'!?<&%T:"!P87)A;65T97(N(`T*("!)9B!I;F1I
M8V%T960@=&AE("1P7W)E;6]V95]P871H(&-A;B!B92!U<V5D(&EN('1H92!S
M86UE('=A>2!A<R!I="!I<PT*("!U<V5D(&EN(&5X=')A8W1-;V1I9GDH*2!M
M971H;V0N(`T*07)G=6UE;G1S(#H-"B`@)'!?9FEL96QI<W0@.B!!;B!A<G)A
M>2!O9B!F:6QE;F%M97,@86YD(&1I<F5C=&]R>2!N86UE<RP@;W(@82!S:6YG
M;&4-"B`@("`@("`@("`@("`@("!S=')I;F<@=VET:"!N86UE<R!S97!A<F%T
M960@8GD@82!S:6YG;&4@8FQA;FL@<W!A8V4N(`T*("`D<%]P871H(#H@5&AE
M('!A=&@@;V8@=&AE(&1I<F5C=&]R>2!W:&5R92!T:&4@9FEL97,O9&ER(&YE
M960@=&\@8GD-"B`@("`@("`@("`@(&5X=')A8W1E9"X@#0H@("1P7W)E;6]V
M95]P871H(#H@4&%R="!O9B!T:&4@;65M;W)I>F5D('!A=&@@=&AA="!C86X@
M8F4@<F5M;W9E9"!I9@T*("`@("`@("`@("`@("`@("`@('!R97-E;G0@870@
M=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL92]D:7(@<&%T:"X@#0I2971U<FX@
M=F%L=64@.@T*("!T<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N(&5R<F]R+@T*
M4V%M<&QE(#H-"B`@+R\@26UA9VEN92!T87)N86UE+G1A<B!W:71H(&9I;&5S
M(#H-"B`@+R\@("!D978O9&%T82]F:6QE+G1X=`T*("`O+R`@(&1E=B]D871A
M+VQO9RYT>'0-"B`@+R\@("!R96%D;64N='AT#0H@("1T87)?;V)J96-T(#T@
M;F5W($%R8VAI=F5?5&%R*")T87)N86UE+G1A<B(I.PT*("`D=&%R7V]B:F5C
M="T^97AT<F%C=$QI<W0H(F1E=B]D871A+V9I;&4N='AT(')E861M92YT>'0B
M+"`B:6YS=&%L;"(L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`B9&5V
M(BD[#0H@("\O($9I;&5S('=I;&P@8F4@97AT<F%C=&5D('1H97)E(#H-"B`@
M+R\@("!I;G-T86QL+V1A=&$O9FEL92YT>'0-"B`@+R\@("!I;G-T86QL+W)E
M861M92YT>'0-"DAO=R!I="!W;W)K<R`Z#0H@($=O('1H<F]U9V@@=&AE(&%R
M8VAI=F4@86YD(&5X=')A8W0@;VYL>2!T:&4@9FEL97,@<')E<V5N="!I;B!T
M:&4-"B`@;&ES="X@#0H-"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]397)V:6-E<U]7
M96%T:&5R````````````````````````````````````````````````````
M```````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P
M,"`Q,#4Q-30S,S<S,"`P,C(U-S8`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]D;V-S+U-E<G9I8V5S7U=E871H97(O97AA;7!L97,`````````````````
M`````````````````````````````````````#`P,#<U-2``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S,P(#`R-#0Q-``@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+V1O8W,O4V5R=FEC97-?5V5A=&AE<B]E>&%M
M<&QE<R]M971A<BUB87-I8RYP:'``````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#<P-3,@,3`U,34T,S,W
M,S`@,#(W-#`P`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@
M<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30@9F]L9&UE=&AO9#UM87)K97(Z
M("HO"@HO*BH*("H@0F%S:6,@97AA;7!L92!F;W(@=&AE($U%5$%2+U1!1BUS
M97)V:6-E"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J(#Q,24-%
M3E-%/@H@*B!#;W!Y<FEG:'0@*&,I(#(P,#4L($%L97AA;F1E<B!7:7)T>@H@
M*B!!;&P@<FEG:'1S(')E<V5R=F5D+@H@*B`*("H@4F5D:7-T<FEB=71I;VX@
M86YD('5S92!I;B!S;W5R8V4@86YD(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W
M:71H;W5T"B`J(&UO9&EF:6-A=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E
M9"!T:&%T('1H92!F;VQL;W=I;F<@8V]N9&ET:6]N<PH@*B!A<F4@;65T.@H@
M*B!O(%)E9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I
M;B!T:&4@86)O=F4@8V]P>7)I9VAT(&YO=&EC92P*("H@("!T:&ES(&QI<W0@
M;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R+@H@
M*B!O(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O
M9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT(&YO=&EC92P*("H@("!T:&ES(&QI
M<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R
M(&EN('1H92!D;V-U;65N=&%T:6]N"B`J("`@86YD+V]R(&]T:&5R(&UA=&5R
M:6%L<R!P<F]V:61E9"!W:71H('1H92!D:7-T<FEB=71I;VXN"B`J(&\@3F5I
M=&AE<B!T:&4@;F%M92!O9B!T:&4@<V]F='=A<F4@;F]R('1H92!N86UE<R!O
M9B!I=',@8V]N=')I8G5T;W)S"B`J("`@;6%Y(&)E('5S960@=&\@96YD;W)S
M92!O<B!P<F]M;W1E('!R;V1U8W1S(&1E<FEV960@9G)O;2!T:&ES('-O9G1W
M87)E"B`J("`@=VET:&]U="!S<&5C:69I8R!P<FEO<B!W<FET=&5N('!E<FUI
M<W-I;VXN"B`J(`H@*B!42$E3(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(
M12!#3U!94DE'2%0@2$],1$524R!!3D0@0T].5%))0E543U)3(")!4R!)4R(*
M("H@04Y$($%.62!%6%!215-3($]2($E-4$Q)140@5T%24D%.5$E%4RP@24Y#
M3%5$24Y'+"!"550@3D]4($Q)34E4140@5$\L(%1(10H@*B!)35!,245$(%=!
M4E)!3E1)15,@3T8@34520TA!3E1!0DE,2519($%.1"!&251.15-3($9/4B!!
M(%!!4E1)0U5,05(@4%524$]310H@*B!!4D4@1$E30TQ!24U%1"X@24X@3D\@
M159%3E0@4TA!3$P@5$A%($-/4%E224=(5"!/5TY%4B!/4B!#3TY44DE"551/
M4E,@0D4*("H@3$E!0DQ%($9/4B!!3ED@1$E214-4+"!)3D1)4D5#5"P@24Y#
M241%3E1!3"P@4U!%0TE!3"P@15A%35!,05)9+"!/4@H@*B!#3TY315%514Y4
M24%,($1!34%'15,@*$E.0TQ51$E.1RP@0E54($Y/5"!,24U)5$5$(%1/+"!0
M4D]#55)%345.5"!/1@H@*B!354)35$E4551%($=/3T13($]2(%-%4E9)0T53
M.R!,3U-3($]&(%5312P@1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,*
M("H@24Y415)255!424].*2!(3U=%5D52($-!55-%1"!!3D0@3TX@04Y9(%1(
M14]262!/1B!,24%"24Q)5%DL(%=(151(15(@24X*("H@0T].5%)!0U0L(%-4
M4DE#5"!,24%"24Q)5%DL($]2(%1/4E0@*$E.0TQ51$E.1R!.14=,24=%3D-%
M($]2($]42$525TE312D*("H@05))4TE.1R!)3B!!3ED@5T%9($]55"!/1B!4
M2$4@55-%($]&(%1(25,@4T]&5%=!4D4L($5614X@248@041625-%1"!/1B!4
M2$4*("H@4$]34TE"24Q)5%D@3T8@4U5#2"!$04U!1T4N"B`J(#PO3$E#14Y3
M13X*("H@"B`J($!C871E9V]R>2`@("!796(@4V5R=FEC97,*("H@0'!A8VMA
M9V4@("`@(%-E<G9I8V5S7U=E871H97(*("H@0&%U=&AO<B`@("`@($%L97AA
M;F1E<B!7:7)T>B`\86QE>$!P8S1P+FYE=#X*("H@0&-O<'ER:6=H="`@(#(P
M,#4@06QE>&%N9&5R(%=I<G1Z"B`J($!L:6-E;G-E("`@("!H='1P.B\O=W=W
M+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@0E-$
M($QI8V5N<V4*("H@0'9E<G-I;VX@("`@($-64SH@)$ED.B!M971A<BUB87-I
M8RYP:'`L=B`Q+C$Q(#(P,#4O,3$O,#@@,3<Z-3(Z-#(@97)U($5X<"`D"B`J
M($!L:6YK("`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4V5R
M=FEC97-?5V5A=&AE<@H@*B!`9FEL97-O=7)C90H@*B\*"G)E<75I<F5?;VYC
M92`B4V5R=FEC97,O5V5A=&AE<BYP:'`B.PH*+R\@3V)J96-T(&EN:71I86QI
M>F%T:6]N("T@97)R;W(@8VAE8VMI;F<@:7,@:6UP;W)T86YT+"!B96-A=7-E
M(&]F"B\O(&AA;F1L:6YG(&5X8V5P=&EO;G,@<W5C:"!A<R!M:7-S:6YG(%!%
M05(@;6]D=6QE<PHD;65T87(@/2`F4V5R=FEC97-?5V5A=&AE<CHZ<V5R=FEC
M92@B345405(B+"!A<G)A>2@B9&5B=6<B(#T^(#`I*3L*:68@*%-E<G9I8V5S
M7U=E871H97(Z.FES17)R;W(H)&UE=&%R*2D@>PH@("`@9&EE*")%<G)O<CH@
M(BXD;65T87(M/F=E=$UE<W-A9V4H*2XB7&XB*3L*?0H*+R\@4V5T('!A<F%M
M971E<G,@9F]R($1"(&%C8V5S<RP@;F5E9&5D(&9O<B!L;V-A=&EO;B!S96%R
M8VAE<PHD;65T87(M/G-E=$UE=&%R1$(H(G-Q;&ET93HO+VQO8V%L:&]S="\O
M=7-R+VQO8V%L+VQI8B]P:'`O9&%T82]397)V:6-E<U]796%T:&5R+W-E<G9I
M8V5S5V5A=&AE<D1"(BD["FEF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R
M*"1M971A<BDI('L*("`@(&5C:&\@(D5R<F]R.B`B+B1M971A<BT^9V5T365S
M<V%G92@I+B)<;B(["GT*"B\J($5R87-E(&-O;6UE;G1S('1O(&5N86)L92!C
M86-H:6YG"B1S=&%T=7,@/2`D;65T87(M/G-E=$-A8VAE*")F:6QE(BP@87)R
M87DH(F-A8VAE7V1I<B(@/3X@(B]T;7`O8V%C:&4O(BDI.PII9B`H4V5R=FEC
M97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@96-H;R`B17)R
M;W(Z("(N)'-T871U<RT^9V5T365S<V%G92@I+B)<;B(["GT**B\*"B1M971A
M<BT^<V5T56YI='-&;W)M870H(F-U<W1O;2(L(&%R<F%Y*`H@("`@(G=I;F0B
M("`@/3X@(FMT(BP*("`@(")V:7,B("`@(#T^(")K;2(L"B`@("`B:&5I9VAT
M(B`]/B`B9G0B+`H@("`@(G1E;7`B("`@/3X@(F,B+`H@("`@(G!R97,B("`@
M/3X@(FAP82(L"B`@("`B<F%I;B(@("`]/B`B:6XB*2D["B1M971A<BT^<V5T
M1&%T951I;65&;W)M870H(F0N;2Y9(BP@(D@Z:2(I.PH*+R\@1FER<W0@9V5T
M(&-O9&4@9F]R(&QO8V%T:6]N"B1S96%R8V@@/2`D;65T87(M/G-E87)C:$QO
M8V%T:6]N*")";VYN+"!'97)M86YY(BD["FEF("A397)V:6-E<U]796%T:&5R
M.CII<T5R<F]R*"1S96%R8V@I*2!["B`@("!D:64H(D5R<F]R.B`B+B1S96%R
M8V@M/F=E=$UE<W-A9V4H*2XB7&XB*3L*?0H*+R\@3F]W(&ET97)A=&4@=&AR
M;W5G:"!A=F%I;&%B;&4@9G5N8W1I;VYS(&9O<B!R971R:65V:6YG(&1A=&$*
M9F]R96%C:"`H87)R87DH(F=E=$QO8V%T:6]N(BP@(F=E=%=E871H97(B+"`B
M9V5T1F]R96-A<W0B*2!A<R`D9G5N8W1I;VXI('L*("`@("1D871A(#T@)&UE
M=&%R+3XD9G5N8W1I;VXH)'-E87)C:"D["B`@("!I9B`H4V5R=FEC97-?5V5A
M=&AE<CHZ:7-%<G)O<B@D9&%T82DI('L*("`@("`@("!E8VAO(")%<G)O<CH@
M(BXD9&%T82T^9V5T365S<V%G92@I+B)<;B(["B`@("`@("`@8V]N=&EN=64[
M"B`@("!]"@H@("`@=F%R7V1U;7`H)&1A=&$I.PI]"C\^"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O4V5R
M=FEC97-?5V5A=&AE<B]E>&%M<&QE<R]M971A<BUE>'1E;G-I=F4N<&AP````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P-C<Q-3(@,3`U,34T,S,W,S`@,#,P,S,W`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J('9I;3H@<V5T(&5X
M<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30@
M9F]L9&UE=&AO9#UM87)K97(Z("HO"@HO*BH*("H@16QA8F]R871E(&5X86UP
M;&4@9F]R('1H92!-151!4B]4048M<V5R=FEC90H@*@H@*B!796QL+"!T:&ES
M(&ES(&$@;6]R92!E;&%B;W)A=&4@97AA;7!L92!H;W<@=&\@8W)E871E(&$@
M;F5A="!L:71T;&4@<&%G90H@*B!W:71H(&9E=&-H:6YG($U%5$%2+U1!1B!D
M871A(&9R;VT@3D]!02!A;F0@<'5T=&EN9R!I="!I;G1O(&$@9&5S:6=N+@H@
M*B!))VT@;F]T('1O;R!P<F]U9"!O9B!M>2!D97-I9VXM<VMI;&QS+"!M;W-T
M(&]F('1H92!S='5F9B!H97)E(&ES('1A:V5N"B`J(&9R;VT@=&AE(&UE=&%R
M+6)L;V-K('=H:6-H(&-A;B!B92!F;W5N9"!W:71H:6X@=&AE($AO<F1E($9R
M86UE=V]R:RP*("H@8V]U<G1E<WD@;V8@4FEC:R!%;65R>2`M(&-R96%T:79E
M('!I>&5L<VAO=FEN9R!I<VXG="!M>2!D;VUA:6X@.BU0"B`J($DG=F4@=7-E
M9"!A($9I<F5F;W@@9F]R(&-H96-K:6YG('1H92!D97-I9VXL('-O(&1O;B=T
M(&)E('1O;PH@*B!D:7-A<'!O:6YT960L(&EF('1H92!P86=E(&QO;VMS('-H
M86)B>2!W:71H('1H92!)12P@;F]T('1H870@22!C87)E"B`J('9E<GD@;75C
M:"!A;GEW87D@.RTI"B`J($AA=F4@9G5N(0H@*B`*("H@4$A0('9E<G-I;VYS
M(#0@86YD(#4*("H*("H@/$Q)0T5.4T4^"B`J($-O<'ER:6=H="`H8RD@,C`P
M-2P@06QE>&%N9&5R(%=I<G1Z"B`J($%L;"!R:6=H=',@<F5S97)V960N"B`J
M(`H@*B!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN
M87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70*("H@;6]D:69I8V%T:6]N+"!A
M<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO=VEN9R!C;VYD
M:71I;VYS"B`J(&%R92!M970Z"B`J(&\@4F5D:7-T<FEB=71I;VYS(&]F('-O
M=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0@;F]T
M:6-E+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L
M;&]W:6YG(&1I<V-L86EM97(N"B`J(&\@4F5D:7-T<FEB=71I;VYS(&EN(&)I
M;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0@
M;F]T:6-E+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@
M9F]L;&]W:6YG(&1I<V-L86EM97(@:6X@=&AE(&1O8W5M96YT871I;VX*("H@
M("!A;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE(&1I
M<W1R:6)U=&EO;BX*("H@;R!.96ET:&5R('1H92!N86UE(&]F('1H92!S;V9T
M=V%R92!N;W(@=&AE(&YA;65S(&]F(&ET<R!C;VYT<FEB=71O<G,*("H@("!M
M87D@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O9'5C=',@9&5R
M:79E9"!F<F]M('1H:7,@<V]F='=A<F4*("H@("!W:71H;W5T('-P96-I9FEC
M('!R:6]R('=R:71T96X@<&5R;6ES<VEO;BX*("H@"B`J(%1(25,@4T]&5%=!
M4D4@25,@4%)/5DE$140@0ED@5$A%($-/4%E224=(5"!(3TQ$15)3($%.1"!#
M3TY44DE"551/4E,@(D%3($E3(@H@*B!!3D0@04Y9($584%)%4U,@3U(@24U0
M3$E%1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.3U0@3$E-251%1"!4
M3RP@5$A%"B`J($E-4$Q)140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)
M5%D@04Y$($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!4B!055)03U-%"B`J($%2
M12!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4@0T]065))1TA4
M($]73D52($]2($-/3E1224)55$]24R!"10H@*B!,24%"3$4@1D]2($%.62!$
M25)%0U0L($E.1$E214-4+"!)3D-)1$5.5$%,+"!34$5#24%,+"!%6$5-4$Q!
M4EDL($]2"B`J($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'+"!"
M550@3D]4($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&"B`J(%-50E-42515
M5$4@1T]/1%,@3U(@4T525DE#15,[($Q/4U,@3T8@55-%+"!$051!+"!/4B!0
M4D]&2513.R!/4B!"55-)3D534PH@*B!)3E1%4E)54%1)3TXI($A/5T5615(@
M0T%54T5$($%.1"!/3B!!3ED@5$A%3U)9($]&($Q)04))3$E462P@5TA%5$A%
M4B!)3@H@*B!#3TY44D%#5"P@4U1224-4($Q)04))3$E462P@3U(@5$]25"`H
M24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*0H@*B!!4DE324Y'
M($E.($%.62!705D@3U54($]&(%1(12!54T4@3T8@5$A)4R!33T945T%212P@
M159%3B!)1B!!1%9)4T5$($]&(%1(10H@*B!03U-324))3$E462!/1B!354-(
M($1!34%'12X*("H@/"],24-%3E-%/@H@*B`*("H@0&-A=&5G;W)Y("`@(%=E
M8B!397)V:6-E<PH@*B!`<&%C:V%G92`@("`@4V5R=FEC97-?5V5A=&AE<@H@
M*B!`875T:&]R("`@("`@06QE>&%N9&5R(%=I<G1Z(#QA;&5X0'!C-'`N;F5T
M/@H@*B!`8V]P>7)I9VAT("`@,C`P-2!!;&5X86YD97(@5VER='H*("H@0&QI
M8V5N<V4@("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O
M8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@("`@
M0U93.B`D260Z(&UE=&%R+65X=&5N<VEV92YP:'`L=B`Q+C$W(#(P,#4O,3$O
M,3,@,C(Z-#4Z,C$@97)U($5X<"`D"B`J($!L:6YK("`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O4V5R=FEC97-?5V5A=&AE<@H@*B!`9FEL
M97-O=7)C90H@*B\*"B\O+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0HO
M+R!4:&ES(&ES('1H92!A<F5A+"!W:&5R92!Y;W4@8V%N(&-U<W1O;6EZ92!T
M:&4@<V-R:7!T"B\O+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0HD;&]C
M871I;VX@("`@("`@(#T@(D)O;FXL($=E<FUA;GDB.R`O+R!4:&4@8VET>2!W
M92!W86YT('1O(&9E=&-H('1H92!D871A(&9O<BX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@+R\@5VAE<F4@=&AE('-E87)C:"!F=6YC
M=&EO;B!W:6QL(&QO;VL@9F]R"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("\O('1H92!)0T%/(&1A=&%B87-E("AG96YE<F%T960@=VET
M:"!T:&4*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M8G5I;&1-971A<D1"+G!H<"!S8W)I<'0I"B1D<VX@("`@("`@("`@("`@/2`B
M<W%L:71E.B\O;&]C86QH;W-T+R]U<W(O;&]C86PO;&EB+W!H<"]D871A+U-E
M<G9I8V5S7U=E871H97(O<V5R=FEC97-796%T:&5R1$(B.R`*)'-O=7)C94UE
M=&%R("`@("`](")H='1P(CL@("`@("`@("`@+R\@5&AI<R!S8W)I<'0@=VEL
M;"!P=6QL('1H92!-151!4B!D871A('9I82!H='1P"B1S;W5R8V54868@("`@
M("`@/2`B:'1T<"([("`@("`@("`@("\O("`@("`@("`@("`@("`@("`@("`@
M("`@("`@5$%&"B1S;W5R8V50871H365T87(@/2`B(CL@("`@("`@("`@("`@
M("\O($]N;'D@;F5E9&5D('=H96X@;F]N+7-T86YD87)D(&%C8V5S<R!I<R!U
M<V5D"B1S;W5R8V50871H5&%F("`@/2`B(CL@("`@("`@("`@("`@("\O"B1C
M86-H951Y<&4@("`@("`@/2`B(CL@("`@("`@("`@("`@("\O(%-E="!A('1Y
M<&4@*&9I;&4L(&1B+"!M9&(L("XN+BD@=&\*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@96YA8FQE(&-A8VAI;F<N"B1C86-H94]P
M="`@("`@("`@/2!A<G)A>2@I.R`@("`@("`@("\O($-A8VAE(&YE961S('9A
M<FEO=7,@;W!T:6]N<RP@9&5P96YD:6YG"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("\O(&]N('1H92!C;VYT86EN97(M='EP92`M('!L
M96%S92!C;VYS=6QT"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("\O('1H92!#86-H92!M86YU86P@+R!S;W5R8V5C;V1E(0HD=6YI='-&
M;W)M870@("`@(#T@(FUE=')I8R([("`@("`@("`O+R!4:&4@9F]R;6%T('1H
M92!U;FET<R!A<F4@9&ES<&QA>65D(&EN("T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@;65T<FEC+"!S=&%N9&%R9"!O<B!S;VUE
M(&-U<W1O;6EZ871I;VXN"B1D871E1F]R;6%T("`@("`@/2`B:BX@32!9(CL@
M("`@("`@("\O(%-E="!T:&4@9F]R;6%T('1H92!D871E(&ES(&1I<W!L87EE
M9"!I;@HD=&EM949O<FUA="`@("`@(#T@(D@Z:2([("`@("`@("`@("`O+R`@
M("`@("`@("`@("`@("`@("`@=&EM90HO+RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2T*"B\O($QO860@=&AE(%=E871H97(@8VQA<W,*<F5Q=6ER95]O
M;F-E(")397)V:6-E<R]796%T:&5R+G!H<"(["@HO+R!/8FIE8W0@:6YI=&EA
M;&EZ871I;VX@+2!E<G)O<B!C:&5C:VEN9R!I<R!I;7!O<G1A;G0L(&)E8V%U
M<V4@;V8*+R\@:&%N9&QI;F<@97AC97!T:6]N<R!S=6-H(&%S(&UI<W-I;F<@
M4$5!4B!M;V1U;&5S"B1M971A<B`]("9397)V:6-E<U]796%T:&5R.CIS97)V
M:6-E*")-971A<B(I.PII9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D
M;65T87(I*2!["B`@("!D:64H(D5R<F]R.B`B+B1M971A<BT^9V5T365S<V%G
M92@I+B)<;B(I.PI]"@HO+R!3970@<&%R86UE=&5R<R!F;W(@1$(@86-C97-S
M+"!N965D960@9F]R(&QO8V%T:6]N('-E87)C:&5S"B1M971A<BT^<V5T365T
M87)$0B@D9'-N*3L*:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)&UE
M=&%R*2D@>PH@("`@96-H;R`B17)R;W(Z("(N)&UE=&%R+3YG971-97-S86=E
M*"DN(EQN(CL*?0H*+R\@26YI=&EA;&EZ92!C86-H:6YG"FEF("AS=')L96XH
M)&-A8VAE5'EP92DI('L*("`@("1S=&%T=7,@/2`D;65T87(M/G-E=$-A8VAE
M*"1C86-H951Y<&4L("1C86-H94]P="D["B`@("!I9B`H4V5R=FEC97-?5V5A
M=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@("`@(&5C:&\@(D5R<F]R
M.B`B+B1S=&%T=7,M/F=E=$UE<W-A9V4H*2XB7&XB.PH@("`@?0I]"@HO+R!$
M969I;F4@=&AE('5N:71S(&9O<FUA="P@8G)I;F<@=&AE(')E=')I979E9"!F
M;W)M870@:6YT;PHO+R!S;VUE=&AI;F<@;6]R92!C;VUM;VXN+BX*)&UE=&%R
M+3YS9715;FET<T9O<FUA="@D=6YI='-&;W)M870I.PHD=6YI=',@/2`D;65T
M87(M/F=E=%5N:71S1F]R;6%T*"D["B1U;FET<ULB=&5M<")=("`@/2`B)F1E
M9SLB+G-T<G1O=7!P97(H)'5N:71S6R)T96UP(ETI.PHD=6YI='-;(G=I;F0B
M72`@(#T@(B9N8G-P.R(N<W1R7W)E<&QA8V4H(FMM:"(L(")K;2]H(BP@)'5N
M:71S6R)W:6YD(ETI.PHD=6YI='-;(G9I<R)=("`@(#T@(B9N8G-P.R(N)'5N
M:71S6R)V:7,B73L*)'5N:71S6R)H96EG:'0B72`]("(F;F)S<#LB+B1U;FET
M<ULB:&5I9VAT(ET["B1U;FET<ULB<')E<R)=("`@/2`B)FYB<W`[(BXD=6YI
M='-;(G!R97,B73L*)'5N:71S6R)R86EN(ET@("`]("(F;F)S<#LB+B1U;FET
M<ULB<F%I;B)=.PH*)&UE=&%R+3YS971-971A<E-O=7)C92@D<V]U<F-E365T
M87(L("1S;W5R8V50871H365T87(L("1S;W5R8V54868L("1S;W5R8V50871H
M5&%F*3L*"B\O(%-E="!D871E+2]T:6UE+69O<FUA=`HD;65T87(M/G-E=$1A
M=&54:6UE1F]R;6%T*"1D871E1F]R;6%T+"`D=&EM949O<FUA="D["@HO+R!3
M96%R8V@@9F]R(&1E9FEN960@;&]C871I;VX@86YD(&9E=&-H('1H92!F:7)S
M="!I=&5M(&9O=6YD+@HO+R!"86EL(&]U="!I9B!S;VUE=&AI;F<@8F%D(&AA
M<'!E;G,N+BX*)'-E87)C:"`]("1M971A<BT^<V5A<F-H3&]C871I;VXH)&QO
M8V%T:6]N+"!T<G5E*3L*:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H
M)'-E87)C:"DI('L*("`@(&1I92@B17)R;W(Z("(N)'-E87)C:"T^9V5T365S
M<V%G92@I+B)<;B(I.PI]"@HO+R!2971R:65V92!D871A+"!S=&]R92!I;B!V
M87)I86)L97,L(&)A:6P@;W5T(&]N(&5R<F]R"B1F971C:"`](&%R<F%Y*`H@
M("`@(FQO8V%T:6]N(B`]/B`B9V5T3&]C871I;VXB+`H@("`@(G=E871H97(B
M("`]/B`B9V5T5V5A=&AE<B(L"B`@("`B9F]R96-A<W0B(#T^(")G971&;W)E
M8V%S="(**3L*9F]R96%C:"`H)&9E=&-H(&%S("1V87)I86)L92`]/B`D9G5N
M8W1I;VXI('L*("`@("0D=F%R:6%B;&4@/2`D;65T87(M/B1F=6YC=&EO;B@D
M<V5A<F-H*3L*("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"0D
M=F%R:6%B;&4I*2!["B`@("`@("`@96-H;R`B17)R;W(Z("(N)"1V87)I86)L
M92T^9V5T365S<V%G92@I+B)<;B(["B`@("`@("`@8V]N=&EN=64["B`@("!]
M"GT*"B\O($YO=R!W92!O=71P=70@86QL('1H92!D871A+"!P;&5A<V4@9&]N
M)W0@97AP96-T(&5X=&5N<VEV92!C;VUM96YT<R!H97)E+"!T:&ES(&ES(&)A
M<VEC"B\O($A434PO0U-3('-T=69F+B!!;'-O('1H:7,@:7-N)W0@82!V97)Y
M(&9A;F-Y(&1E<VEG;BP@:70G<R!J=7-T('1O('-H;W<@>6]U+"!W:&%T"B\O
M('1H92!S8W)I<'0@:7,@86)L92!T;R!D;R`H86YD(&UO<F4@.RTI*2XN+@H_
M/@H\:'1M;#X*/&AE860^"B`@("`\=&ET;&4^4V5R=FEC97-?5V5A=&AE<CHZ
M345405(O5$%&/"]T:71L93X*("`@(#QS='EL92!T>7!E/2)T97AT+V-S<R(^
M"B`@("`@("`@+FYO<FUA;"`@("`@>R!F;VYT+69A;6EL>3H@07)I86PL($AE
M;'9E=&EC82P@<V%N<RUS97)I9CL@9F]N="US:7IE.B`Q,7!T.R!F;VYT+7=E
M:6=H=#H@;F]R;6%L.R!F;VYT+7-T>6QE.B!N;W)M86P@?0H@("`@("`@("YI
M=&%L:6,@("`@('L@9F]N="UW96EG:'0Z(&YO<FUA;#L@9F]N="US='EL93H@
M:71A;&EC('T*("`@("`@("`N8F]L9"`@("`@("![(&9O;G0M=V5I9VAT.B!B
M;VQD.R!F;VYT+7-T>6QE.B!N;W)M86P@?0H@("`@("`@("YB;VQD:71A;&EC
M('L@9F]N="UW96EG:'0Z(&)O;&0[(&9O;G0M<W1Y;&4Z(&ET86QI8R!]"B`@
M("`@("`@+G)E9&)O;&0@("`@>R!F;VYT+7=E:6=H=#H@8F]L9#L@9F]N="US
M='EL93H@;F]R;6%L.R!C;VQO<CH@(V9F,#`P,"!]"B`@("`@("`@+F)L=65B
M;VQD("`@>R!F;VYT+7=E:6=H=#H@8F]L9#L@9F]N="US='EL93H@;F]R;6%L
M.R!C;VQO<CH@(S`P,#!F9B!]"B`@("`@("`@+F)G9W)E>2`@("`@>R!B86-K
M9W)O=6YD+6-O;&]R.B`C93EE.64Y('T*("`@("`@("`N8F=K:&%K:2`@("![
M(&)A8VMG<F]U;F0M8V]L;W(Z("-D.&0X8S`@?0H@("`@("`@("YR96<@("`@
M("`@('L@9F]N="US:7IE.B`W<'0[('9E<G1I8V%L+6%L:6=N.B!S=7!E<B!]
M"B`@("`@("`@:6UG("`@("`@("`@>R!V97)T:6-A;"UA;&EG;CH@;6ED9&QE
M.R!B;W)D97(M<W1Y;&4Z(&YO;F4[(&)O<F1E<BUW:61T:#H@,'!X('T*("`@
M("`@("!A("`@("`@("`@("![(&9O;G0M=V5I9VAT.B!B;VQD.R!F;VYT+7-T
M>6QE.B!I=&%L:6,[(&-O;&]R.B`C.3DS,S`P.R!T97AT+61E8V]R871I;VXZ
M(&YO;F4@?0H@("`@("`@(&$Z=FES:71E9"`@('L@9F]N="UW96EG:'0Z(&)O
M;&0[(&9O;G0M<W1Y;&4Z(&ET86QI8SL@8V]L;W(Z(",Y.3,S,#`[('1E>'0M
M9&5C;W)A=&EO;CH@;F]N92!]"B`@("`@("`@83IH;W9E<B`@("`@>R!F;VYT
M+7=E:6=H=#H@8F]L9#L@9F]N="US='EL93H@:71A;&EC.R!C;VQO<CH@(V-C
M,S,P,#L@=&5X="UD96-O<F%T:6]N.B!U;F1E<FQI;F4@?0H@("`@("`@('1A
M8FQE("`@("`@('L@8F]R9&5R.B`P<'@@;F]N92!B;&%C:SL@8F]R9&5R+7-P
M86-I;F<Z(#!P>"!]"B`@("`@("`@=&0@("`@("`@("`@>R!F;VYT+69A;6EL
M>3H@07)I86PL($AE;'9E=&EC82P@<V%N<RUS97)I9CL@9F]N="US:7IE.B`Q
M,7!T.R!F;VYT+7=E:6=H=#H@;F]R;6%L.R!F;VYT+7-T>6QE.B!N;W)M86P@
M?0H@("`@/"]S='EL93X*/"]H96%D/@H\8F]D>2!C;&%S<STB;F]R;6%L(CX*
M/#]P:'`*+R\@1&5B=6<@;W5T<'5T<R!T:&4@<F%W(&1A=&$@9F5T8VAE9"!B
M>2!T:&4@9F]R96%C:"UL;V]P(&%B;W9E+"!J=7-T(&9O<B!C:&5C:VEN9RXN
M+@II9B`H:7-S970H)%]'151;(F1E8G5G(ETI*2!["B`@("!E8VAO("(\<')E
M/EQN(CL*("`@('9A<E]D=6UP*"1L;V-A=&EO;BP@)'=E871H97(L("1F;W)E
M8V%S="D["B`@("!E8VAO("(\+W!R93Y<;B(["GT@"C\^"CQS<&%N(&-L87-S
M/2)B;'5E8F]L9"(@<W1Y;&4](F9O;G0M<VEZ93H@,3-P="(^5V5A=&AE<B!&
M;W)E8V%S=#PO<W!A;CX@8W)E871E9"!W:71H(#QA('-T>6QE/2)F;VYT+7-I
M>F4Z(#$S<'0B(&AR968](FAT='`Z+R]P96%R+G!H<"YN970O(CY014%2<SPO
M83X@/&$@<W1Y;&4](F9O;G0M<VEZ93H@,3-P="(@:')E9CTB:'1T<#HO+W!E
M87(N<&AP+FYE="]P86-K86=E+U-E<G9I8V5S7U=E871H97(O(CY397)V:6-E
M<U]796%T:&5R/"]A/CQB<CX*/'1A8FQE('-T>6QE/2)W:61T:#H@,3`P)2(^
M"CQT<CX*("`@(#QT9#X*("`@("`@("`\=&%B;&4@8F]R9&5R/2(P(B!S='EL
M93TB8F]R9&5R+71O<#H@,G!X('-O;&ED(",U,C1B.3@[(&)O<F1E<BUB;W1T
M;VTZ(#)P>"!S;VQI9"`C93!E,V-E.R!B;W)D97(M;&5F=#H@,G!X('-O;&ED
M("-B.&(V8S$[(&)O<F1E<BUR:6=H=#H@,G!X('-O;&ED(",X8C@W83`[('=I
M9'1H.B`Q,#`E(CX*("`@("`@("`\='(@8VQA<W,](F)G:VAA:VDB/@H@("`@
M("`@("`@("`\=&0@8V]L<W!A;CTB-"(@<W1Y;&4](F)O<F1E<BUB;W1T;VTZ
M(#)P>"!S;VQI9"`C86)A9&$R(CX\<W!A;B!C;&%S<STB8F]L9"(^/#\])&QO
M8V%T:6]N6R)N86UE(ET_/B`H/#\])'-E87)C:#\^*3PO<W!A;CX\+W1D/@H@
M("`@("`@(#PO='(^"B`@("`@("`@/'1R/@H@("`@("`@("`@("`\=&0^/'-P
M86X@8VQA<W,](F)O;&0B/E-U;G)I<V4Z/"]S<&%N/B`\:6UG('-T>6QE/2)W
M:61T:#H@,CAP>#L@:&5I9VAT.B`Q,W!X.R!V97)T:6-A;"UA;&EG;CH@8F%S
M96QI;F4B(&%L=#TB4W5N<FES92(@<W)C/2)I;6%G97,O<W5N<FES92YG:68B
M/B`\/STD;&]C871I;VY;(G-U;G)I<V4B73\^/"]T9#X*("`@("`@("`@("`@
M/'1D/CQS<&%N(&-L87-S/2)B;VQD(CY3=6YS970Z/"]S<&%N/B`\:6UG('-T
M>6QE/2)W:61T:#H@,S!P>#L@:&5I9VAT.B`Q-7!X.R!V97)T:6-A;"UA;&EG
M;CH@8F%S96QI;F4B(&%L=#TB4W5N<V5T(B!S<F,](FEM86=E<R]S=6YS970N
M9VEF(CX@/#\])&QO8V%T:6]N6R)S=6YS970B73\^/"]T9#X*("`@("`@("`@
M("`@/'1D('-T>6QE/2)W:61T:#H@,3DP<'@B/B9N8G-P.SPO=&0^"B`@("`@
M("`@("`@(#QT9"!S='EL93TB=VED=&@Z(&%U=&\B/B9N8G-P.SPO=&0^"B`@
M("`@("`@/"]T<CX*("`@("`@("`\='(@<W1Y;&4](FAE:6=H=#H@,35P>"(^
M"B`@("`@("`@("`@(#QT9"!N;W=R87`^/'-P86X@8VQA<W,](F)O;&0B/E1E
M;7!E<F%T=7)E.CPO<W!A;CX@/#\]<F]U;F0H)'=E871H97);(G1E;7!E<F%T
M=7)E(ETL(#$I+B1U;FET<ULB=&5M<")=/SX\+W1D/@H@("`@("`@("`@("`\
M=&0@;F]W<F%P/CQS<&%N(&-L87-S/2)B;VQD(CY$97<@<&]I;G0Z/"]S<&%N
M/B`\/SUR;W5N9"@D=V5A=&AE<ELB9&5W4&]I;G0B72P@,2DN)'5N:71S6R)T
M96UP(ET_/CPO=&0^"B`@("`@("`@("`@(#QT9"!N;W=R87`^/'-P86X@8VQA
M<W,](F)O;&0B/D9E;'0@=&5M<&5R871U<F4Z/"]S<&%N/B`\/SUR;W5N9"@D
M=V5A=&AE<ELB9F5L=%1E;7!E<F%T=7)E(ETL(#$I+B1U;FET<ULB=&5M<")=
M/SX\+W1D/@H@("`@("`@("`@("`\=&0@<F]W<W!A;CTB-"(@=F%L:6=N/2)T
M;W`B/@H@("`@("`@("`@("`@("`@/'-P86X@8VQA<W,](F)O;&0B/E1R96YD
M.CPO<W!A;CX\8G(^"CP_<&AP"FEF("AI<W-E="@D=V5A=&AE<ELB=')E;F0B
M72D@)B8@<VEZ96]F*"1W96%T:&5R6R)T<F5N9")=*2D@>PH@("`@+R\@3W5T
M<'5T('1H92!T<F5N9',L(&QO;W`@=&AR;W5G:"!T:&4@87)R87ES+`H@("`@
M+R\@8V]N=F5R="!T:&4@<W1U9F8@=&\@;FEC92!L;V]K:6YG(&1E<VEG;BP@
M:F%D9&$L(&IA9&1A+BXN"B`@("!F;W)E86-H("@D=V5A=&AE<ELB=')E;F0B
M72!A<R`D=')E;F0I('L*("`@("`@("!F;W)E86-H("@D=')E;F0@87,@)&ME
M>2`]/B`D=F%L*2!["B`@("`@("`@("`@('-W:71C:"`H)&ME>2D@>PH@("`@
M("`@("`@("`@("`@8V%S92`B='EP92(Z"B`@("`@("`@("`@("`@("`@("`@
M<W=I=&-H("@D=F%L*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@
M(DY/4TE'(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S=')I;F<@
M/2`B3F\@4VEG;FEF:6-A;G0@5V5A=&AE<B(["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S
M92`B5$5-4$\B.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-T<FEN
M9R`](")496UP;W)A<GD@5V5A=&AE<B(["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B
M0D5#34<B.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-T<FEN9R`]
M(")796%T:&5R($)E8V]M:6YG(CL*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`D=F%L=64@(#T@(B(["B`@("`@("`@("`@("`@("`@("`@9F]R
M96%C:"`H87)R87DH(F9R;VTB+"`B=&\B+"`B870B*2!A<R`D=&EM92D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1R96YD6R1T:6UE
M72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V86QU92`N/2`B
M("(N)'1I;64N(B`B+B1T<F5N9%LD=&EM95T["B`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@*"1V86QU92`A/2`B(BD@/R`D=F%L=64@(#T@=')I;2@D=F%L=64I
M+B(Z(CHB(CL*("`@("`@("`@("`@("`@("`@("`D<W1R:6YG(#T@)SQS<&%N
M(&-L87-S/2)I=&%L:6,B/B<N)'-T<FEN9RXG/"]S<&%N/B<["B`@("`@("`@
M("`@("`@("`@("`@)'9A;'5E("`]("<\<W!A;B!C;&%S<STB:71A;&EC(CXG
M+B1V86QU92XG/"]S<&%N/B<["B`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@("`@("!C87-E(")W:6YD(CH*("`@("`@("`@("`@("`@
M("`@("`D<W1R:6YG(#T@(E=I;F0Z(CL*("`@("`@("`@("`@("`@("`@("`D
M=F%L=64@(#T@*'-T<G1O;&]W97(H)'1R96YD6R)W:6YD1&ER96-T:6]N(ETI
M(#T](")C86QM(BD@/R`B0V%L;2(@.B`B1G)O;2!T:&4@(BXD=')E;F1;(G=I
M;F1$:7)E8W1I;VXB72XB("@B+B1T<F5N9%LB=VEN9$1E9W)E97,B72XB)F1E
M9SLI(&%T("(N<F]U;F0H)'1R96YD6R)W:6YD(ETL(#$I+B1U;FET<ULB=VEN
M9")=.PH@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=')E;F1;(G=I
M;F1687)I86)I;&ET>2)=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M=F%L=64@+CT@(BP@=F%R:6%B;&4@9G)O;2`B+B1T<F5N9%LB=VEN9%9A<FEA
M8FEL:71Y(EU;(F9R;VTB72XB)F1E9SL@=&\@(BXD=')E;F1;(G=I;F1687)I
M86)I;&ET>2)=6R)T;R)=+B(F9&5G.R(["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=')E;F1;(G=I;F1'
M=7-T(ETI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU92`N/2`B
M+"!W:71H(&=U<W1S('5P('1O("(N<F]U;F0H)'1R96YD6R)W:6YD1W5S=")=
M+"`Q*2XD=6YI='-;(G=I;F0B73L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E
M(")V:7-I8FEL:71Y(CH*("`@("`@("`@("`@("`@("`@("`D<W1R:6YG(#T@
M(E9I<VEB:6QI='DZ(CL*("`@("`@("`@("`@("`@("`@("`D=F%L=64@(#T@
M<W1R=&]L;W=E<B@D=')E;F1;(G9I<U%U86QI9FEE<B)=*2XB("(N<F]U;F0H
M)'1R96YD6R)V:7-I8FEL:71Y(ETL(#$I+B1U;FET<ULB=FES(ET["B`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E(")C
M;&]U9',B.@H@("`@("`@("`@("`@("`@("`@("1S=')I;F<@/2`B0VQO=61S
M.B(["B`@("`@("`@("`@("`@("`@("`@)'9A;'5E("`]("(B.PH@("`@("`@
M("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D=F%L*3L@
M)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D8VQO=60@/2!U8W=O
M<F1S*"1V86Q;)&E=6R)A;6]U;G0B72D["B`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D=F%L6R1I75LB='EP92)=*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&-L;W5D("X]("(@(BXD=F%L6R1I75LB='EP
M92)=.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D=F%L6R1I75LB:&5I9VAT(ETI*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D8VQO=60@+CT@(B!A="`B+B1V
M86Q;)&E=6R)H96EG:'0B72XD=6YI='-;(FAE:6=H=")=.PH@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU
M92`N/2`D8VQO=60N(B`B.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@(F-O
M;F1I=&EO;B(Z"B`@("`@("`@("`@("`@("`@("`@)'-T<FEN9R`](")#;VYD
M:71I;VXZ(CL*("`@("`@("`@("`@("`@("`@("`D=F%L=64@(#T@=6-W;W)D
M<R@D=F%L*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@(&-A<V4@(G!R97-S=7)E(CH*("`@("`@("`@("`@("`@("`@("`D
M<W1R:6YG(#T@(E!R97-S=7)E.B(["B`@("`@("`@("`@("`@("`@("`@)'9A
M;'5E("`](')O=6YD*"1V86PL(#$I+B1U;FET<ULB<')E<R)=.PH@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`B9G)O
M;2(Z"B`@("`@("`@("`@("`@("!C87-E(")T;R(Z"B`@("`@("`@("`@("`@
M("!C87-E(")A="(Z"B`@("`@("`@("`@("`@("!C87-E(")W:6YD1&ER96-T
M:6]N(CH*("`@("`@("`@("`@("`@(&-A<V4@(G=I;F1$96=R965S(CH*("`@
M("`@("`@("`@("`@(&-A<V4@(G=I;F1687)I86)I;&ET>2(Z"B`@("`@("`@
M("`@("`@("!C87-E(")W:6YD1W5S="(Z"B`@("`@("`@("`@("`@("!C87-E
M(")V:7-1=6%L:69I97(B.@H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E
M(#(["B`@("`@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@
M("`@("1S=')I;F<@/2`B(CL@)'9A;'5E(#T@(B(["B`@("`@("`@("`@("`@
M("`@("`@=F%R7V1U;7`H)&ME>2P@)'9A;"D["B`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@('T*/SX*("`@("`@("`@("`@("`@(#P_
M/21S=')I;F<_/B`\/STD=F%L=64_/CQB<CX*/#]P:'`*("`@("`@("!]"@H@
M("`@?0I](&5L<V4@>PH_/@H@("`@("`@("`@("`@("`@;F]N93QB<CX*/#]P
M:'`*?0H_/@H@("`@("`@("`@("`@("`@/'-P86X@8VQA<W,](F)O;&0B/E)E
M;6%R:W,Z/"]S<&%N/CQB<CX*/#]P:'`*:68@*&ES<V5T*"1W96%T:&5R6R)R
M96UA<FLB72D@)B8@<VEZ96]F*"1W96%T:&5R6R)R96UA<FLB72DI('L*("`@
M("\O(%-A;64@9F]R('1H92!R96UA<FMS+"!E=F5N(&QE<W,@<W!E8W1A8W5L
M87(N+BX*("`@(&9O<F5A8V@H)'=E871H97);(G)E;6%R:R)=(&%S("1K97D@
M/3X@)'9A;"D@>PH@("`@("`@('-W:71C:"`H)&ME>2D@>PH@("`@("`@("`@
M("!C87-E(")A=71O<W1A=&EO;B(Z"B`@("`@("`@("`@(&-A<V4@(G!R97-S
M8VAG(CH*("`@("`@("`@("`@8V%S92`B;F]S<&5C:2(Z"B`@("`@("`@("`@
M(&-A<V4@(G-U;F1U<F%T:6]N(CH*("`@("`@("`@("`@8V%S92`B;6%I;G1A
M:6XB.@H@("`@("`@("`@("`@("`@)'-T<FEN9R`]("(B.PH@("`@("`@("`@
M("`@("`@)'9A;'5E("`]("1V86P["B`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@8V%S92`B<V5A<')E<W-U<F4B.@H@("`@("`@("`@("`@
M("`@)'-T<FEN9R`](")0<F5S<W5R92!A="!S96%L979E;#HB.PH@("`@("`@
M("`@("`@("`@)'9A;'5E("`](')O=6YD*"1V86PL(#$I+B1U;FET<ULB<')E
M<R)=.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@
M(C%H=&5M<"(Z"B`@("`@("`@("`@("`@("`D<W1R:6YG(#T@(E1E;7!E<F%T
M=7)E(&9O<B!L87-T(&AO=7(Z(CL*("`@("`@("`@("`@("`@("1V86QU92`@
M/2!R;W5N9"@D=F%L+"`Q*2XD=6YI='-;(G1E;7`B73L*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("(Q:&1E=R(Z"B`@("`@("`@
M("`@("`@("`D<W1R:6YG(#T@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B([
M"B`@("`@("`@("`@("`@("`D=F%L=64@(#T@<F]U;F0H)'9A;"P@,2DN)'5N
M:71S6R)T96UP(ET["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@8V%S92`B-FAM87AT96UP(CH*("`@("`@("`@("`@8V%S92`B-FAM:6YT
M96UP(CH*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'=E871H97);(G)E
M;6%R:R)=6R(V:&UA>'1E;7`B72D@)B8@(6ES<V5T*"1W96%T:&5R6R)R96UA
M<FLB75LB-FAM:6YT96UP(ETI*2!["B`@("`@("`@("`@("`@("`@("`@8V]N
M=&EN=64H,BD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M<W1R:6YG(#T@(DUA>"]-:6X@5&5M<"!F;W(@;&%S="`V(&AO=7)S.B(["B`@
M("`@("`@("`@("`@("`D=F%L=64@(#T@*&ES<V5T*"1W96%T:&5R6R)R96UA
M<FLB75LB-FAM87AT96UP(ETI*2`_(')O=6YD*"1W96%T:&5R6R)R96UA<FLB
M75LB-FAM87AT96UP(ETL(#$I+B1U;FET<ULB=&5M<")=(#H@(BTB.PH@("`@
M("`@("`@("`@("`@)'9A;'5E("X]("(O(CL*("`@("`@("`@("`@("`@("1V
M86QU92`N/2`H:7-S970H)'=E871H97);(G)E;6%R:R)=6R(V:&UI;G1E;7`B
M72DI(#\@<F]U;F0H)'=E871H97);(G)E;6%R:R)=6R(V:&UI;G1E;7`B72P@
M,2DN)'5N:71S6R)T96UP(ET@.B`B+2(["B`@("`@("`@("`@("`@("!U;G-E
M="@D=V5A=&AE<ELB<F5M87)K(EU;(C9H;6%X=&5M<")=*3L@=6YS970H)'=E
M871H97);(G)E;6%R:R)=6R(V:&UI;G1E;7`B72D["B`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@8V%S92`B,C1H;6%X=&5M<"(Z"B`@("`@
M("`@("`@(&-A<V4@(C(T:&UI;G1E;7`B.@H@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D=V5A=&AE<ELB<F5M87)K(EU;(C(T:&UA>'1E;7`B72D@)B8@
M(6ES<V5T*"1W96%T:&5R6R)R96UA<FLB75LB,C1H;6EN=&5M<")=*2D@>PH@
M("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E*#(I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)'-T<FEN9R`](")-87@O36EN(%1E;7`@
M9F]R(&QA<W0@,C0@:&]U<G,Z(CL*("`@("`@("`@("`@("`@("1V86QU92`@
M/2`H:7-S970H)'=E871H97);(G)E;6%R:R)=6R(R-&AM87AT96UP(ETI*2`_
M(')O=6YD*"1W96%T:&5R6R)R96UA<FLB75LB,C1H;6%X=&5M<")=+"`Q*2XD
M=6YI='-;(G1E;7`B72`Z("(M(CL*("`@("`@("`@("`@("`@("1V86QU92`N
M/2`B+R(["B`@("`@("`@("`@("`@("`D=F%L=64@+CT@*&ES<V5T*"1W96%T
M:&5R6R)R96UA<FLB75LB,C1H;6EN=&5M<")=*2D@/R!R;W5N9"@D=V5A=&AE
M<ELB<F5M87)K(EU;(C(T:&UI;G1E;7`B72P@,2DN)'5N:71S6R)T96UP(ET@
M.B`B+2(["B`@("`@("`@("`@("`@("!U;G-E="@D=V5A=&AE<ELB<F5M87)K
M(EU;(C(T:&UA>'1E;7`B72D[('5N<V5T*"1W96%T:&5R6R)R96UA<FLB75LB
M,C1H;6EN=&5M<")=*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("!C87-E(")S;F]W9&5P=&@B.@H@("`@("`@("`@("`@("`@)'-T<FEN
M9R`](")3;F]W(&1E<'1H.B(["B`@("`@("`@("`@("`@("`D=F%L=64@(#T@
M)'9A;"XD=6YI='-;(G)A:6XB73L*("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("!C87-E(")S;F]W97%U:78B.@H@("`@("`@("`@("`@("`@
M)'-T<FEN9R`](")7871E<B!E<75I=F%L96YT(&]F('-N;W<Z(CL*("`@("`@
M("`@("`@("`@("1V86QU92`@/2`D=F%L+B1U;FET<ULB<F%I;B)=.PH@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@(G-E;G-O<G,B
M.@H@("`@("`@("`@("`@("`@)'-T<FEN9R`]("(B.PH@("`@("`@("`@("`@
M("`@)'9A;'5E("`](&EM<&QO9&4H(CQB<CXB+"`D=F%L*3L*("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@
M("`@("`@)'-T<FEN9R`]("(B.R`D=F%L=64@/2`B(CL*("`@("`@("`@("`@
M("`@('9A<E]D=6UP*"1K97DL("1V86PI.PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@?0H_/@H@("`@("`@("`@("`@("`@/#\])'-T<FEN9S\^
M(#P_/21V86QU93\^/&)R/@H\/W!H<`H@("`@?0I](&5L<V4@>PH_/@H@("`@
M("`@("`@("`@("`@;F]N93QB<CX*/#]P:'`*?0H_/@H@("`@("`@("`@("`\
M+W1D/@H@("`@("`@(#PO='(^"B`@("`@("`@/'1R('-T>6QE/2)H96EG:'0Z
M(#$U<'@B/@H@("`@("`@("`@("`\=&0@8V]L<W!A;CTB,B(@<W1Y;&4](G=I
M9'1H.B`S,3!P>"(@;F]W<F%P/CQS<&%N(&-L87-S/2)B;VQD(CY0<F5S<W5R
M93H\+W-P86X^(#P_/7)O=6YD*"1W96%T:&5R6R)P<F5S<W5R92)=+"`Q*2XD
M=6YI='-;(G!R97,B73\^/"]T9#X*("`@("`@("`@("`@/'1D(&YO=W)A<#X\
M<W!A;B!C;&%S<STB8F]L9"(^2'5M:61I='DZ/"]S<&%N/B`\/STD=V5A=&AE
M<ELB:'5M:61I='DB73\^)3PO=&0^"B`@("`@("`@/"]T<CX*("`@("`@("`\
M='(@<W1Y;&4](FAE:6=H=#H@,35P>"(^"B`@("`@("`@("`@(#QT9"!C;VQS
M<&%N/2(R(B!N;W=R87`^"B`@("`@("`@("`@("`@("`\<W!A;B!C;&%S<STB
M8F]L9"(^5VEN9#H\+W-P86X^(#P_/7-T<G1O;&]W97(H)'=E871H97);(G=I
M;F1$:7)E8W1I;VXB72D@/3T@(F-A;&TB(#\@(D-A;&TB(#H@(D9R;VT@=&AE
M("(N)'=E871H97);(G=I;F1$:7)E8W1I;VXB72XB("@B+B1W96%T:&5R6R)W
M:6YD1&5G<F5E<R)=+B(F9&5G.RD@870@(BYR;W5N9"@D=V5A=&AE<ELB=VEN
M9")=+"`Q*2XD=6YI='-;(G=I;F0B73\^(`H@("`@("`@("`@("`@("`@/#\]
M:7-S970H)'=E871H97);(G=I;F1687)I86)I;&ET>2)=*2`_("(\8G(^=F%R
M:6%B;&4@9G)O;2`B+B1W96%T:&5R6R)W:6YD5F%R:6%B:6QI='DB75LB9G)O
M;2)=+B(F9&5G.R!T;R`B+B1W96%T:&5R6R)W:6YD5F%R:6%B:6QI='DB75LB
M=&\B72XB)F1E9SLB(#H@(B(_/B`*("`@("`@("`@("`@("`@(#P_/6ES<V5T
M*"1W96%T:&5R6R)W:6YD1W5S=")=*2`_("(\8G(^=VET:"!G=7-T<R!U<"!T
M;R`B+G)O=6YD*"1W96%T:&5R6R)W:6YD1W5S=")=+"`Q*2XD=6YI='-;(G=I
M;F0B72`Z("(B/SX@"B`@("`@("`@("`@(#PO=&0^"B`@("`@("`@("`@(#QT
M9"!V86QI9VX](G1O<"(@;F]W<F%P/CQS<&%N(&-L87-S/2)B;VQD(CY6:7-I
M8FEL:71Y.CPO<W!A;CX@/#\]<W1R=&]L;W=E<B@D=V5A=&AE<ELB=FES475A
M;&EF:65R(ETI/SX@/#\]<F]U;F0H)'=E871H97);(G9I<VEB:6QI='DB72P@
M,2DN)'5N:71S6R)V:7,B73\^/"]T9#X*("`@("`@("`\+W1R/@H@("`@("`@
M(#QT<CX*("`@("`@("`@("`@/'1D/CQS<&%N(&-L87-S/2)B;VQD(CY#=7)R
M96YT(&-O;F1I=&EO;CH\+W-P86X^/&)R/CP_/6ES<V5T*"1W96%T:&5R6R)C
M;VYD:71I;VXB72D@/R!U8W=O<F1S*"1W96%T:&5R6R)C;VYD:71I;VXB72D@
M.B`B3F\@4VEG;FEF:6-A;G0@5V5A=&AE<B(_/CPO=&0^"B`@("`@("`@("`@
M(#QT9#X\:6UG('-T>6QE/2)H96EG:'0Z(#,R<'@[('=I9'1H.B`S,G!X(B!A
M;'0](CP_/6ES<V5T*"1W96%T:&5R6R)C;VYD:71I;VXB72D@/R!U8W=O<F1S
M*"1W96%T:&5R6R)C;VYD:71I;VXB72D@.B`B3F\@4VEG;FEF:6-A;G0@5V5A
M=&AE<B(_/B(@<W)C/2)I;6%G97,O,S)X,S(O/#\])'=E871H97);(F-O;F1I
M=&EO;DEC;VXB73\^+G!N9R(^/"]T9#X*/#]P:'`*:68@*&ES<V5T*"1W96%T
M:&5R6R)P<F5C:7!I=&%T:6]N(ETI("8F('-I>F5O9B@D=V5A=&AE<ELB<')E
M8VEP:71A=&EO;B)=*2D@>PH@("`@+R\@3W5T<'5T(&$@;&EN92!F;W(@96%C
M:"!T>7!E(&]F('!R96-I<&ET871I;VXL"B`@("`O+R!D:7-T:6YG=6ES:"!B
M971W965N('-T<FEN9R!A;F0@;G5M97)I8R!V86QU97,*/SX*("`@("`@("`@
M("`@("`@(#QB<CX\<W!A;B!C;&%S<STB8F]L9"(^4')E8VEP:71A=&EO;CH\
M+W-P86X^/&)R/@H\/W!H<`H@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F
M*"1W96%T:&5R6R)P<F5C:7!I=&%T:6]N(ETI.R`D:2LK*2!["B`@("`@("`@
M)'!R96-I<"`](")L87-T("(N)'=E871H97);(G!R96-I<&ET871I;VXB75LD
M:5U;(FAO=7)S(ETN(F@Z("(N)'=E871H97);(G!R96-I<&ET871I;VXB75LD
M:5U;(F%M;W5N=")=.PH@("`@("`@("1P<F5C:7`@+CT@*&-T>7!E7V%L<&AA
M*"1W96%T:&5R6R)P<F5C:7!I=&%T:6]N(EU;)&E=6R)A;6]U;G0B72DI(#\@
M(B(@.B`D=6YI='-;(G)A:6XB73L*/SX*("`@("`@("`@("`@("`@(#P_/21P
M<F5C:7`_/CQB<CX*/#]P:'`*("`@('T*?0H_/@H@("`@("`@("`@("`\+W1D
M/@H@("`@("`@("`@("`\=&0@=F%L:6=N/2)T;W`B/@H@("`@("`@("`@("`@
M("`@/'-P86X@8VQA<W,](F)O;&0B/D-L;W5D<SH\+W-P86X^/&)R/@H\/W!H
M<`II9B`H:7-S970H)'=E871H97);(F-L;W5D<R)=*2`F)B!S:7IE;V8H)'=E
M871H97);(F-L;W5D<R)=*2D@>PH@("`@+R\@665A:"P@8VQO=61S+BXN('-A
M;64@87,@:6X@=&AE('1R96YD(&AA;F1L:6YG+BXN"B`@("!F;W(@*"1I(#T@
M,#L@)&D@/"!S:7IE;V8H)'=E871H97);(F-L;W5D<R)=*3L@)&DK*RD@>PH@
M("`@("`@("1C;&]U9"`]('5C=V]R9',H)'=E871H97);(F-L;W5D<R)=6R1I
M75LB86UO=6YT(ETI.PH@("`@("`@(&EF("AI<W-E="@D=V5A=&AE<ELB8VQO
M=61S(EU;)&E=6R)T>7!E(ETI*2!["B`@("`@("`@("`@("1C;&]U9"`N/2`B
M("(N)'=E871H97);(F-L;W5D<R)=6R1I75LB='EP92)=.PH@("`@("`@('T*
M("`@("`@("!I9B`H:7-S970H)'=E871H97);(F-L;W5D<R)=6R1I75LB:&5I
M9VAT(ETI*2!["B`@("`@("`@("`@("1C;&]U9"`N/2`B(&%T("(N)'=E871H
M97);(F-L;W5D<R)=6R1I75LB:&5I9VAT(ETN)'5N:71S6R)H96EG:'0B73L*
M("`@("`@("!]"C\^"B`@("`@("`@("`@("`@("`\/STD8VQO=60_/CQB<CX*
M/#]P:'`*("`@('T*?2!E;'-E('L*/SX*("`@("`@("`@("`@("`@($-L96%R
M($)E;&]W(#P_/21M971A<BT^8V]N=F5R=$1I<W1A;F-E*#$R,#`P+"`B9G0B
M+"`D=6YI='-;(FAE:6=H=")=*2XD=6YI='-;(FAE:6=H=")=/SX@"CP_<&AP
M"GT*/SX*("`@("`@("`@("`@/"]T9#X*("`@("`@("`\+W1R/@H@("`@("`@
M(#PO=&%B;&4^"B`@("`\+W1D/@H\+W1R/@H\='(^"B`@("`\=&0^"B`@("`@
M("`@/'1A8FQE('-T>6QE/2)B;W)D97(M=&]P.B`R<'@@<V]L:60@(S4R-&(Y
M.#L@8F]R9&5R+6)O='1O;3H@,G!X('-O;&ED("-E,&4S8V4[(&)O<F1E<BUL
M969T.B`R<'@@<V]L:60@(V(X8C9C,3L@8F]R9&5R+7)I9VAT.B`R<'@@<V]L
M:60@(SAB.#=A,#L@=VED=&@Z(#$P,"4B/@H@("`@("`@(#QT<B!C;&%S<STB
M8F=K:&%K:2(^"B`@("`@("`@("`@(#QT9"!C;VQS<&%N/2(S(B!A;&EG;CTB
M8V5N=&5R(B!S='EL93TB8F]R9&5R+6)O='1O;3H@,G!X('-O;&ED("-A8F%D
M83(B/CQS<&%N(&-L87-S/2)B;VQD(CY&;W)E8V%S="`H5$%&*3PO<W!A;CX\
M8G(^=F%L:60@9G)O;2`\<W!A;B!C;&%S<STB8F]L9"(^/#\])&9O<F5C87-T
M6R)V86QI9$9R;VTB73\^/"]S<&%N/B!T;R`\<W!A;B!C;&%S<STB8F]L9"(^
M/#\])&9O<F5C87-T6R)V86QI9%1O(ET_/CPO<W!A;CX\+W1D/@H@("`@("`@
M(#PO='(^"B`@("`@("`@/'1R('9A;&EG;CTB=&]P(CX*("`@("`@("`@("`@
M/'1D(&-O;'-P86X](C,B/@H@("`@("`@("`@("`@("`@/'1A8FQE('-T>6QE
M/2)W:61T:#H@,3`P)2(^"B`@("`@("`@("`@("`@("`\='(^"B`@("`@("`@
M("`@("`@("`@("`@/'1D(&%L:6=N/2)C96YT97(B(&-L87-S/2)B9VMH86MI
M(B!S='EL93TB:&5I9VAT.B`Q-7!X.R!B;W)D97(M=&]P.B`R<'@@<V]L:60@
M(V0X9#AC,#L@8F]R9&5R+7)I9VAT.B`R<'@@<V]L:60@(SAB.#=A,#L@8F]R
M9&5R+6QE9G0Z(#)P>"!S;VQI9"`C9#AD.&,P(CXF;F)S<#L\+W1D/@H@("`@
M("`@("`@("`@("`@("`@(#QT9"!A;&EG;CTB8V5N=&5R(B!S='EL93TB=VED
M=&@Z(#$X)2(^/'-P86X@8VQA<W,](F)O;&0B/DUE=&5O<F]L;V=I8V%L($-O
M;F1I=&EO;G,\+W-P86X^/"]T9#X*("`@("`@("`@("`@("`@("`@("`\=&0@
M86QI9VX](F-E;G1E<B(@<W1Y;&4](G=I9'1H.B`Q."4B(&-L87-S/2)B9V=R
M97DB/CQS<&%N(&-L87-S/2)B;VQD(CY7:6YD/"]S<&%N/CPO=&0^"B`@("`@
M("`@("`@("`@("`@("`@/'1D(&%L:6=N/2)C96YT97(B('-T>6QE/2)W:61T
M:#H@,3@E(CX\<W!A;B!C;&%S<STB8F]L9"(^5FES:6)I;&ET>3PO<W!A;CX\
M+W1D/@H@("`@("`@("`@("`@("`@("`@(#QT9"!A;&EG;CTB8V5N=&5R(B!S
M='EL93TB=VED=&@Z(#$X)2(@8VQA<W,](F)G9W)E>2(^/'-P86X@8VQA<W,]
M(F)O;&0B/D-L;W5D<SPO<W!A;CX\+W1D/@H@("`@("`@("`@("`@("`@("`@
M(#QT9"!A;&EG;CTB8V5N=&5R(B!S='EL93TB=VED=&@Z(#$X)2(^/'-P86X@
M8VQA<W,](F)O;&0B/D-O;F1I=&EO;CPO<W!A;CX\+W1D/@H@("`@("`@("`@
M("`@("`@/"]T<CX*/#]P:'`*)'1I;65S(#T@87)R87E?:V5Y<R@D9F]R96-A
M<W1;(G1I;64B72D["B1P<F4@("`](&%R<F%Y*")W:6YD(B`]/B`P+"`B=FES
M(B`]/B`P+"`B8VQO=61S(B`]/B`P+"`B8V]N9"(@/3X@,"D["B\O($]K+"!T
M:&4@9F]R96-A<W0@:7,@82!B:70@;6]R92!I;G1E<F5S=&EN9RP@87,@22=M
M('1A:VEN9R!A(&9E=PHO+R!P<F5C875T:6]N<R!H97)E('-O('1H870@=&AE
M('1A8FQE(&ES;B=T(&9I;&QE9"!U<"!T;R!T:&4@;6%X+@HO+R!O($EF(&$@
M=F%L=64@:7,@<F5P96%T960@:6X@=&AE(&YE>'0@;6%J;W(@=&EM97-L;W0@
M*&YO="!W:&5N"B\O("`@<VEG;FEF:6-A;G0@=V5A=&AE<B!C:&%N9V5S(&%R
M92!P<F]C97-S960I+"!I="=S(&YO="!P<FEN=&5D"B\O(&\@4VEG;FEF:6-A
M;G0@=V5A=&AE<B!G971S(&ET<R!O=VX@<F]W<RP@=VET:"!T:6UE<R!P<FEN
M=&5D(&YO<FUA;`HO+R`@(&%S(&EN(&]P<&]S:71I;VX@=&\@8F]L9"!P<FEN
M="!F;W(@;6%J;W(@=&EM97-L;W1S"B\O(&\@5&AE('=H:6QE*"1R;W<I+6-O
M;G-T<G5C="!B96QO=R!I<R!F;W(@:&%N9&QI;F<@=&AE('-I9VYI9FEC86YT
M"B\O("`@=V5A=&AE<BP@87,@22!P;VEN="`D<F]W('1O("1R;W=;(F9M8R)=
M(&%F=&5R=V%R9',L('=H97)E('1H90HO+R`@('-M86QL97(@8VAA;F=E<R!A
M<F4@;65N=&EO;F5D"F9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D9F]R96-A
M<W1;(G1I;64B72D[("1I*RLI('L*("`@("1R;W<@/2`D9F]R96-A<W1;(G1I
M;64B75LD=&EM97-;)&E=73L*"B`@("`O+R!#<F5A=&4@=&EM97-T86UP"B`@
M("`D<W1A<G0@/2`D=&EM97-;)&E=.PH@("`@:68@*"1I("L@,2`\('-I>F5O
M9B@D9F]R96-A<W1;(G1I;64B72DI('L*("`@("`@("`D96YD(#T@)'1I;65S
M6R1I("L@,5T["B`@("!](&5L<V4@>PH@("`@("`@("1E;F0@/2!S=6)S='(H
M)&9O<F5C87-T6R)V86QI9%)A=R)=+"`M,BDN(CHP,"(["B`@("`@("`@)&5N
M9"`]("@D96YD(#T]("(R-#HP,"(I(#\@(C`P.C`P(B`Z("1E;F0["B`@("!]
M"B`@("`D=&EM92`@("`]("1S=&%R="XB("T@(BXD96YD.PH@("`@)&-L87-S
M("`@/2`G(&-L87-S/2)B;VQD(B<["B`@("`O+R!4:&ES(&ES(&9O<B!O=71P
M=71T:6YG(")"96-O;6EN9R(L(")496UP;W)A<GDB(&%N9"!S=6-H"B`@("`D
M9FUC("`@("`](&ES<V5T*"1R;W=;(F9M8R)=*2`_("1R;W=;(F9M8R)=(#H@
M9F%L<V4[(`H@("`@)&9M8W1Y<&4@/2`B(CL*("`@("1F;6-C;G0@(#T@,#L*
M"B`@("!W:&EL92`H)')O=RD@>PH_/@H@("`@("`@("`@("`@("`@/'1R(&-L
M87-S/2)B9VMH86MI(CX*("`@("`@("`@("`@("`@("`@("`\=&0@<W1Y;&4]
M(FAE:6=H=#H@,7!X.R!E;7!T>2UC96QL<SH@<VAO=SL@8F]R9&5R+7)I9VAT
M.B`R<'@@<V]L:60@(SAB.#=A,#L@8F]R9&5R+6QE9G0Z(#)P>"!S;VQI9"`C
M9#AD.&,P(CX\+W1D/@H@("`@("`@("`@("`@("`@("`@(#QT9"!S='EL93TB
M:&5I9VAT.B`Q<'@B(&-O;'-P86X](C4B/CPO=&0^"B`@("`@("`@("`@("`@
M("`\+W1R/@H@("`@("`@("`@("`@("`@/'1R/@H@("`@("`@("`@("`@("`@
M("`@(#QT9"!A;&EG;CTB8V5N=&5R(B!C;&%S<STB8F=K:&%K:2(@<W1Y;&4]
M(F)O<F1E<BUR:6=H=#H@,G!X('-O;&ED(",X8C@W83`[(&)O<F1E<BUL969T
M.B`R<'@@<V]L:60@(V0X9#AC,"(@;F]W<F%P/CQS<&%N/#\])&-L87-S/SX^
M/#\])'1I;64_/CPO<W!A;CX\+W1D/@H@("`@("`@("`@("`@("`@("`@(#QT
M9"!A;&EG;CTB8V5N=&5R(CX\/STD9FUC='EP93\^/"]T9#X*/#]P:'`*("`@
M("`@("`O+R!4:&ES(&QO;W!S('1H<F]U9V@@=&AE(&%V86EL86)L92!D871A
M(&%N9"!P<F]C97-S97,@:70*("`@("`@("`O+R!F;W(@;W5T<'5T+"!T:&4@
M9&EF9F5R96YT(&UE=&AO9',@=V5R92!A;')E861Y('5S960@86)O=F4*("`@
M("`@("`O+R`H3VYL>2!D:69F97)E;F-E(&ES('1H92!C:&5C:VEN9R!F;W(@
M=&AE('!R92UV86QU97,N*0H@("`@("`@(&9O<F5A8V@H87)R87DH(G=I;F0B
M+"`B=FES(BP@(F-L;W5D<R(L(")C;VYD(BD@87,@)'9A;"D@>PH@("`@("`@
M("`@("!S=VET8V@@*"1V86PI('L*("`@("`@("`@("`@("`@(&-A<V4@(G=I
M;F0B.@H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)')O=ULB=VEN
M9$1I<F5C=&EO;B)=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<W1R
M:6YG(#T@(B9N8G-P.R(["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)'-T<FEN9R`]('-T<G1O;&]W97(H
M)')O=ULB=VEN9$1I<F5C=&EO;B)=*2`]/2`B8V%L;2(@/R`B0V%L;2(@.B`B
M1G)O;2!T:&4@(BXD<F]W6R)W:6YD1&ER96-T:6]N(ETN(B`H(BXD<F]W6R)W
M:6YD1&5G<F5E<R)=+B(F9&5G.RD\8G(^870@(BYR;W5N9"@D<F]W6R)W:6YD
M(ETL(#$I+B1U;FET<ULB=VEN9")=.PH@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)')O=ULB=VEN9%!R;V(B72DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1S=')I;F<@+CT@(B`H(BXD<F]W6R)W:6YD4')O
M8B)=+B(E)FYB<W`[4')O8BXI(CL*("`@("`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'-T<FEN9R`]/3T@)'!R
M95LB=VEN9")=*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<W1R
M:6YG(#T@(B9N8G-P.R(["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<')E6R)W:6YD(ET@
M/2`D<W1R:6YG.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1C;&%S<R`]("<@
M8VQA<W,](F)G9W)E>2(G.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@8V%S92`B=FES(CH*("`@("`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1R;W=;(G9I<VEB:6QI='DB72DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)'-T<FEN9R`]("(F;F)S<#LB.PH@("`@("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1S
M=')I;F<@/2!S=')T;VQO=V5R*"1R;W=;(G9I<U%U86QI9FEE<B)=*2XB("(N
M<F]U;F0H)')O=ULB=FES:6)I;&ET>2)=+"`Q*2XD=6YI='-;(G9I<R)=.PH@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)')O=ULB=FES4')O
M8B)=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-T<FEN9R`N
M/2`B("@B+B1R;W=;(G9I<U!R;V(B72XB)29N8G-P.U!R;V(N*2(["B`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"1S=')I;F<@/3T]("1P<F5;(G9I<R)=*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<W1R:6YG(#T@(B9N8G-P.R(["B`@("`@("`@("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<')E6R)V:7,B72`]("1S=')I;F<["B`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@)&-L87-S(#T@)R<["B`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@("`@("!C87-E(")C;&]U9',B.@H@("`@("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)')O=ULB8VQO=61S(ETI*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1S=')I;F<@/2`B)FYB<W`[(CL*("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>R`*("`@("`@("`@("`@("`@("`@("`@("`@
M)&-L;W5D<R`@/2`B(CL*("`@("`@("`@("`@("`@("`@("`@("`@9F]R("@D
M:B`](#`[("1J(#P@<VEZ96]F*"1R;W=;(F-L;W5D<R)=*3L@)&HK*RD@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-L;W5D(#T@=6-W;W)D<R@D
M<F]W6R)C;&]U9',B75LD:EU;(F%M;W5N=")=*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D<F]W6R)C;&]U9',B75LD:EU;(G1Y
M<&4B72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8VQO
M=60@+CT@(B`B+B1R;W=;(F-L;W5D<R)=6R1J75LB='EP92)=.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1R;W=;(F-L;W5D<R)=6R1J75LB:&5I9VAT(ETI
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-L;W5D("X]
M("(@870@(BXD<F]W6R)C;&]U9',B75LD:EU;(FAE:6=H=")=+B1U;FET<ULB
M:&5I9VAT(ET["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)')O=ULB8VQO=61S
M(EU;)&I=6R)P<F]B(ETI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&-L;W5D("X]("(@*"(N)')O=ULB8VQO=61S(EU;)&I=6R)P<F]B
M(ETN(B4F;F)S<#M0<F]B+BDB.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-L;W5D<R`N/2`D
M8VQO=60N(CQB<CXB.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("@D8VQO=61S(#T]/2`D<')E6R)C;&]U
M9',B72D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-T<FEN9R`]
M("(F;F)S<#LB.PH@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-T<FEN9R`@("`@("`@/2`D
M8VQO=61S.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!R95LB8VQO
M=61S(ET@/2`D8VQO=61S.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1C;&%S
M<R`]("<@8VQA<W,](F)G9W)E>2(G.PH@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@8V%S92`B8V]N9"(Z"B`@("`@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D<F]W6R)C;VYD:71I;VXB72D@?'P@*&ES
M<V5T*"1P<F5R;W<I("8F("1P<F5R;W=;(F-O;F1I=&EO;B)=(#T]("1R;W=;
M(F-O;F1I=&EO;B)=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<W1R
M:6YG(#T@(B9N8G-P.R(["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)'-T<FEN9R`]('5C=V]R9',H)')O
M=ULB8V]N9&ET:6]N(ETI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`D8VQA<W,@/2`G)SL*("`@("`@("`@("`@?0H_/@H@
M("`@("`@("`@("`@("`@("`@(#QT9"!V86QI9VX](G1O<"(\/STD8VQA<W,_
M/CX\/STD<W1R:6YG/SX\+W1D/@H\/W!H<`H@("`@("`@('T*/SX@("`@("`@
M("`@("`@("`@("`@(`H@("`@("`@("`@("`@("`@/"]T<CX*/#]P:'`*("`@
M("`@("`O+R!.;W<@8VAE8VL@9F]R('-I9VYI9FEC86YT('=E871H97(@8VAA
M;F=E<R!A;F0@;6]V90H@("`@("`@("\O('1H92!R;W<@86-C;W)D:6YG;'DN
M+BX@;6%Y8F4@=6=L>2!C;V1I;F<L(&)U="!T:&ES"B`@("`@("`@+R\@:7,@
M9F]R('-H;W=I;F<@9&5S:6=N+"!N;W0@9F]R(&9A;GD@<')O9W)A;6UI;F<@
M.RTI"B`@("`@("`@:68@*"1F;6,@)B8@)&9M8V-N="`\('-I>F5O9B@D9FUC
M*2D@>PH@("`@("`@("`@("`D<F]W("`@("`]("1F;6-;)&9M8V-N=%T["B`@
M("`@("`@("`@("1F;6-C;G0K*SL*("`@("`@("`@("`@)&9M8W1Y<&4@/2`D
M<F]W6R)T>7!E(ET["B`@("`@("`@("`@("\O($-H96-K(&EF('=E(&AA=F4@
M82!T:6UE<W1A;7`L(&1O;B=T(&]U='!U="!I9B!I="=S"B`@("`@("`@("`@
M("\O('1H92!S86UE(&%S('1H92!M86IO<BUT:6UE<VQO=`H@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1R;W=;(F9R;VTB72D@?'P@)')O=ULB9G)O;2)=+B(@
M+2`B+B1R;W=;(G1O(ET@/3T@)'1I;64I('L*("`@("`@("`@("`@("`@("1T
M:6UE(#T@(B9N8G-P.R(["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D=&EM92`@("`]("1R;W=;(F9R;VTB72XB("T@(BXD<F]W6R)T
M;R)=.PH@("`@("`@("`@("!]"B`@("`@("`@("`@('-W:71C:"`H)')O=ULB
M='EP92)=*2!["B`@("`@("`@("`@("`@("!C87-E(")04D]"(CH*("`@("`@
M("`@("`@("`@("`@("`D9FUC='EP92`]("(B.PH@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`B5$5-4$\B.@H@("`@
M("`@("`@("`@("`@("`@("1F;6-T>7!E(#T@(E1E;7!O<F%R>2(["B`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E(")"
M14--1R(Z"B`@("`@("`@("`@("`@("`@("`@)&9M8W1Y<&4@/2`B0F5C;VUI
M;F<B.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&EF("AI<W-E="@D<F]W6R)P<F]B86)I;&ET>2)=*2D@
M>PH@("`@("`@("`@("`@("`@)&9M8W1Y<&4@+CT@(B`H(BXD<F]W6R)P<F]B
M86)I;&ET>2)=+B(E)FYB<W`[4')O8BXI(CL*("`@("`@("`@("`@?0H@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1R;W<@/2!F86QS93L*("`@("`@
M("!]"B`@("!]"GT*/SX@("`@("`@("`@("`@("`@"B`@("`@("`@("`@("`@
M("`\='(^"B`@("`@("`@("`@("`@("`@("`@/'1D(&-L87-S/2)B9VMH86MI
M(B!S='EL93TB:&5I9VAT.B`Q<'@[(&5M<'1Y+6-E;&QS.B!S:&]W.R!B;W)D
M97(M8F]T=&]M.B`R<'@@<V]L:60@(V0X9#AC,#L@8F]R9&5R+6QE9G0Z(#)P
M>"!S;VQI9"`C9#AD.&,P.R!B;W)D97(M<FEG:'0Z(#)P>"!S;VQI9"`C.&(X
M-V$P(CX\+W1D/@H@("`@("`@("`@("`@("`@("`@(#QT9"!S='EL93TB:&5I
M9VAT.B`Q<'@B(&-O;'-P86X](C4B/CPO=&0^"B`@("`@("`@("`@("`@("`\
M+W1R/@H@("`@("`@("`@("`@("`@/"]T86)L93X*("`@("`@("`@("`@/"]T
M9#X*("`@("`@("`\+W1R/@H@("`@("`@(#QT<B!C;&%S<STB8F=K:&%K:2(^
M"B`@("`)("`@(#QT9"!S='EL93TB=VED=&@Z(#DS<'@[(&)O<F1E<BUT;W`Z
M(#)P>"!S;VQI9"`C86)A9&$R(CXF;F)S<#L\+W1D/@H@("`@("`@("`@("`\
M=&0@<W1Y;&4](F)O<F1E<BUT;W`Z(#)P>"!S;VQI9"`C86)A9&$R(CY5<&1A
M=&5D.B`H/#\]<W5B<W1R*"1W96%T:&5R6R)U<&1A=&4B72P@+34I/SXF;F)S
M<#LO)FYB<W`[/#\]<W5B<W1R*"1F;W)E8V%S=%LB=7!D871E(ETL("TU*3\^
M*3PO=&0^"B`@("`@("`@("`@(#QT9"!S='EL93TB8F]R9&5R+71O<#H@,G!X
M('-O;&ED("-A8F%D83(B(&%L:6=N/2)R:6=H="(^06QL('1I;65S(%540SPO
M=&0^"B`@("`@("`@/"]T<CX*("`@("`@("`\+W1A8FQE/@H@("`@/"]T9#X*
M/"]T<CX*/"]T86)L93X*/&$@:')E9CTB:F%V87-C<FEP=#IH:7-T;W)Y+F)A
M8VLH*2(^8F%C:SPO83X*/"]B;V1Y/@H\+VAT;6P^"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+V1O8W,O4V5R=FEC97-?5V5A=&AE<B]E>&%M<&QE
M<R]W96%T:&5R+F-O;2UB87-I8RYP:'``````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#8U-#8@,3`U,34T,S,W,S`@
M,#,P-3$R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI
M9G1W:61T:#TT('-O9G1T86)S=&]P/30@9F]L9&UE=&AO9#UM87)K97(Z("HO
M"@HO*BH*("H@0F%S:6,@97AA;7!L92!F;W(@=&AE(%=E871H97(N8V]M+7-E
M<G9I8V4*("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@/$Q)0T5.
M4T4^"B`J($-O<'ER:6=H="`H8RD@,C`P-2P@06QE>&%N9&5R(%=I<G1Z"B`J
M($%L;"!R:6=H=',@<F5S97)V960N"B`J(`H@*B!2961I<W1R:6)U=&EO;B!A
M;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I
M=&AO=70*("H@;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D
M('1H870@=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS"B`J(&%R92!M970Z"B`J
M(&\@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN
M('1H92!A8F]V92!C;W!Y<FEG:'0@;F]T:6-E+`H@*B`@('1H:7,@;&ES="!O
M9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N"B`J
M(&\@4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D
M=6-E('1H92!A8F]V92!C;W!Y<FEG:'0@;F]T:6-E+`H@*B`@('1H:7,@;&ES
M="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@
M:6X@=&AE(&1O8W5M96YT871I;VX*("H@("!A;F0O;W(@;W1H97(@;6%T97)I
M86QS('!R;W9I9&5D('=I=&@@=&AE(&1I<W1R:6)U=&EO;BX*("H@;R!.96ET
M:&5R('1H92!N86UE(&]F('1H92!S;V9T=V%R92!N;W(@=&AE(&YA;65S(&]F
M(&ET<R!C;VYT<FEB=71O<G,*("H@("!M87D@8F4@=7-E9"!T;R!E;F1O<G-E
M(&]R('!R;VUO=&4@<')O9'5C=',@9&5R:79E9"!F<F]M('1H:7,@<V]F='=A
M<F4*("H@("!W:71H;W5T('-P96-I9FEC('!R:6]R('=R:71T96X@<&5R;6ES
M<VEO;BX*("H@"B`J(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%
M($-/4%E224=(5"!(3TQ$15)3($%.1"!#3TY44DE"551/4E,@(D%3($E3(@H@
M*B!!3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!705)204Y42453+"!)3D-,
M541)3D<L($)55"!.3U0@3$E-251%1"!43RP@5$A%"B`J($E-4$Q)140@5T%2
M4D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,@1D]2($$@
M4$%25$E#54Q!4B!055)03U-%"B`J($%212!$25-#3$%)345$+B!)3B!.3R!%
M5D5.5"!32$%,3"!42$4@0T]065))1TA4($]73D52($]2($-/3E1224)55$]2
M4R!"10H@*B!,24%"3$4@1D]2($%.62!$25)%0U0L($E.1$E214-4+"!)3D-)
M1$5.5$%,+"!34$5#24%,+"!%6$5-4$Q!4EDL($]2"B`J($-/3E-%455%3E1)
M04P@1$%-04=%4R`H24Y#3%5$24Y'+"!"550@3D]4($Q)34E4140@5$\L(%!2
M3T-54D5-14Y4($]&"B`J(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,[
M($Q/4U,@3T8@55-%+"!$051!+"!/4B!04D]&2513.R!/4B!"55-)3D534PH@
M*B!)3E1%4E)54%1)3TXI($A/5T5615(@0T%54T5$($%.1"!/3B!!3ED@5$A%
M3U)9($]&($Q)04))3$E462P@5TA%5$A%4B!)3@H@*B!#3TY44D%#5"P@4U12
M24-4($Q)04))3$E462P@3U(@5$]25"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@
M3U(@3U1(15)725-%*0H@*B!!4DE324Y'($E.($%.62!705D@3U54($]&(%1(
M12!54T4@3T8@5$A)4R!33T945T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(
M10H@*B!03U-324))3$E462!/1B!354-(($1!34%'12X*("H@/"],24-%3E-%
M/@H@*B`*("H@0&-A=&5G;W)Y("`@(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G
M92`@("`@4V5R=FEC97-?5V5A=&AE<@H@*B!`875T:&]R("`@("`@06QE>&%N
M9&5R(%=I<G1Z(#QA;&5X0'!C-'`N;F5T/@H@*B!`8V]P>7)I9VAT("`@,C`P
M-2!!;&5X86YD97(@5VER='H*("H@0&QI8V5N<V4@("`@(&AT='`Z+R]W=W<N
M;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@
M3&EC96YS90H@*B!`=F5R<VEO;B`@("`@0U93.B`D260Z('=E871H97(N8V]M
M+6)A<VEC+G!H<"QV(#$N-R`R,#`U+S$Q+S`X(#$W.C4R.C0R(&5R=2!%>'`@
M)`H@*B!`;&EN:R`@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E
M+U-E<G9I8V5S7U=E871H97(*("H@0&9I;&5S;W5R8V4*("HO"@IR97%U:7)E
M7V]N8V4@(E-E<G9I8V5S+U=E871H97(N<&AP(CL*"B\O($]B:F5C="!I;FET
M:6%L:7IA=&EO;B`M(&5R<F]R(&-H96-K:6YG(&ES(&EM<&]R=&%N="P@8F5C
M875S92!O9@HO+R!H86YD;&EN9R!E>&-E<'1I;VYS('-U8V@@87,@;6ES<VEN
M9R!014%2(&UO9'5L97,*)'=E871H97)$;W1#;VT@/2`F4V5R=FEC97-?5V5A
M=&AE<CHZ<V5R=FEC92@B5V5A=&AE<D1O=$-O;2(L(&%R<F%Y*")D96)U9R(@
M/3X@,BP@(FAT='!4:6UE;W5T(B`]/B`S,"DI.PII9B`H4V5R=FEC97-?5V5A
M=&AE<CHZ:7-%<G)O<B@D=V5A=&AE<D1O=$-O;2DI('L*("`@(&1I92@B17)R
M;W(Z("(N)'=E871H97)$;W1#;VTM/F=E=$UE<W-A9V4H*2XB7&XB*3L*?0H*
M+R\@4V5T('=E871H97(N8V]M('!A<G1N97(@9&%T80HD=V5A=&AE<D1O=$-O
M;2T^<V5T06-C;W5N=$1A=&$H(CQ087)T;F5R240^(BP@(CQ,:6-E;G-E2V5Y
M/B(I.PH*+RH@17)A<V4@8V]M;65N=',@=&\@96YA8FQE(&-A8VAI;F<*)'-T
M871U<R`]("1W96%T:&5R1&]T0V]M+3YS971#86-H92@B9FEL92(L(&%R<F%Y
M*")C86-H95]D:7(B(#T^("(O=&UP+V-A8VAE+R(I*3L*:68@*%-E<G9I8V5S
M7U=E871H97(Z.FES17)R;W(H)'-T871U<RDI('L*("`@(&5C:&\@(D5R<F]R
M.B`B+B1S=&%T=7,M/F=E=$UE<W-A9V4H*2XB7&XB.PI]"BHO"@HD=V5A=&AE
M<D1O=$-O;2T^<V5T56YI='-&;W)M870H(FUE=')I8R(I.PHD=V5A=&AE<D1O
M=$-O;2T^<V5T1&%T951I;65&;W)M870H(F0N;2Y9(BP@(D@Z:2(I.PH*+R\@
M1FER<W0@9V5T(&-O9&4@9F]R(&QO8V%T:6]N"B1S96%R8V@@/2`D=V5A=&AE
M<D1O=$-O;2T^<V5A<F-H3&]C871I;VXH(D)O;FXL($=E<FUA;GDB*3L*:68@
M*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'-E87)C:"DI('L*("`@(&1I
M92@B17)R;W(Z("(N)'-E87)C:"T^9V5T365S<V%G92@I+B)<;B(I.PI]"@HO
M+R!.;W<@:71E<F%T92!T:')O=6=H(&%V86EL86)L92!F=6YC=&EO;G,@9F]R
M(')E=')I979I;F<@9&%T80IF;W)E86-H("AA<G)A>2@B9V5T3&]C871I;VXB
M+"`B9V5T5V5A=&AE<B(L(")G971&;W)E8V%S="(I(&%S("1F=6YC=&EO;BD@
M>PH@("`@)&1A=&$@/2`D=V5A=&AE<D1O=$-O;2T^)&9U;F-T:6]N*"1S96%R
M8V@I.PH@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)&1A=&$I
M*2!["B`@("`@("`@96-H;R`B17)R;W(Z("(N)&1A=&$M/F=E=$UE<W-A9V4H
M*2XB7&XB.PH@("`@("`@(&-O;G1I;G5E.PH@("`@?0H*("`@('9A<E]D=6UP
M*"1D871A*3L*?0H_/@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]D;V-S+U-E<G9I8V5S7U=E871H97(O97AA;7!L
M97,O=V5A=&AE<BYC;VTM97AT96YS:79E+G!H<````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#0U,S`R(#$P-3$U-#,S-S,P
M(#`S,30S-``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H
M:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT(&9O;&1M971H;V0];6%R:V5R.B`J
M+PH*+RHJ"B`J($5L86)O<F%T92!E>&%M<&QE(&9O<B!T:&4@1VQO8F%L5V5A
M=&AE<BUS97)V:6-E"B`J"B`J(%=E;&PL('1H:7,@:7,@82!M;W)E(&5L86)O
M<F%T92!E>&%M<&QE(&AO=R!T;R!C<F5A=&4@82!N96%T(&QI='1L92!P86=E
M"B`J('=I=&@@9F5T8VAI;F<@9&%T82!F<F]M('=E871H97(N8V]M(&%N9"!P
M=71T:6YG(&ET(&EN=&\@82!D97-I9VXN"B`J($DG;2!N;W0@=&]O('!R;W5D
M(&]F(&UY(&1E<VEG;BUS:VEL;',L(&UO<W0@;V8@=&AE('-T=69F(&AE<F4@
M:7,@=&%K96X*("H@9G)O;2!T:&4@=V5A=&AE<BUB;&]C:R!W:&EC:"!C86X@
M8F4@9F]U;F0@=VET:&EN('1H92!(;W)D92!&<F%M97=O<FLL"B`J(&-O=7)T
M97-Y(&]F(%)I8VL@16UE<GD@+2!C<F5A=&EV92!P:7AE;'-H;W9I;F<@:7-N
M)W0@;7D@9&]M86EN(#HM4`H@*B!))W9E('5S960@82!&:7)E9F]X(&9O<B!C
M:&5C:VEN9R!T:&4@9&5S:6=N+"!S;R!D;VXG="!B92!T;V\*("H@9&ES87!P
M;VEN=&5D+"!I9B!T:&4@<&%G92!L;V]K<R!S:&%B8GD@=VET:"!T:&4@244L
M(&YO="!T:&%T($D@8V%R90H@*B!V97)Y(&UU8V@@86YY=V%Y(#LM*0H@*B!)
M9B!Y;W4@=V%N="!T;R!K;F]W('=H97)E('EO=2!C86X@;V)T86EN('1H92!I
M8V]N<RP@<&QE87-E(')E9VES=&5R(&%T"B`J(&AT='`Z+R]W=W<N=V5A=&AE
M<BYC;VTO<V5R=FEC97,O>&UL;V%P+FAT;6P@86YD('EO=2=L;"!R96-E:79E
M(&%N(&5-86EL"B`J(&-O;G1A:6YI;F<@=&AE('!A<G1N97(@:60L('1H92!L
M:6-E;G-E(&ME>2!A;F0@82!L:6YK('!O:6YT:6YG('1O('1H90H@*B!31$LN
M(%!U="!T:&4@,S)X,S(@86YD('1H92!L;V=O<R!F;VQD97)S(&EN=&\@=&AE
M(&EM86=E<R\@9&ER96-T;W)Y+@H@*B!4:&4@9&5S:6=N('-H;W5L9"!A9&AE
M<F4@=&\@=&AE(&-O;G9E;G1I;VYS(&1E9FEN960@8GD@=&AE('=E871H97(N
M8V]M"B`J(%-$2RUG=6ED92P@=&AO=6=H($D@=V]N)W0@9VEV92!A;GD@;&5G
M86P@8V5R=&%I;G1Y(&9O<B!T:&ES("AO9B!C;W5R<V4I+@H@*B!(879E(&9U
M;B$*("H@"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J(#Q,24-%3E-%
M/@H@*B!#;W!Y<FEG:'0@*&,I(#(P,#4L($%L97AA;F1E<B!7:7)T>@H@*B!!
M;&P@<FEG:'1S(')E<V5R=F5D+@H@*B`*("H@4F5D:7-T<FEB=71I;VX@86YD
M('5S92!I;B!S;W5R8V4@86YD(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H
M;W5T"B`J(&UO9&EF:6-A=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T
M:&%T('1H92!F;VQL;W=I;F<@8V]N9&ET:6]N<PH@*B!A<F4@;65T.@H@*B!O
M(%)E9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T
M:&4@86)O=F4@8V]P>7)I9VAT(&YO=&EC92P*("H@("!T:&ES(&QI<W0@;V8@
M8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R+@H@*B!O
M(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C
M92!T:&4@86)O=F4@8V]P>7)I9VAT(&YO=&EC92P*("H@("!T:&ES(&QI<W0@
M;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN
M('1H92!D;V-U;65N=&%T:6]N"B`J("`@86YD+V]R(&]T:&5R(&UA=&5R:6%L
M<R!P<F]V:61E9"!W:71H('1H92!D:7-T<FEB=71I;VXN"B`J(&\@3F5I=&AE
M<B!T:&4@;F%M92!O9B!T:&4@<V]F='=A<F4@;F]R('1H92!N86UE<R!O9B!I
M=',@8V]N=')I8G5T;W)S"B`J("`@;6%Y(&)E('5S960@=&\@96YD;W)S92!O
M<B!P<F]M;W1E('!R;V1U8W1S(&1E<FEV960@9G)O;2!T:&ES('-O9G1W87)E
M"B`J("`@=VET:&]U="!S<&5C:69I8R!P<FEO<B!W<FET=&5N('!E<FUI<W-I
M;VXN"B`J(`H@*B!42$E3(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#
M3U!94DE'2%0@2$],1$524R!!3D0@0T].5%))0E543U)3(")!4R!)4R(*("H@
M04Y$($%.62!%6%!215-3($]2($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$
M24Y'+"!"550@3D]4($Q)34E4140@5$\L(%1(10H@*B!)35!,245$(%=!4E)!
M3E1)15,@3T8@34520TA!3E1!0DE,2519($%.1"!&251.15-3($9/4B!!(%!!
M4E1)0U5,05(@4%524$]310H@*B!!4D4@1$E30TQ!24U%1"X@24X@3D\@159%
M3E0@4TA!3$P@5$A%($-/4%E224=(5"!/5TY%4B!/4B!#3TY44DE"551/4E,@
M0D4*("H@3$E!0DQ%($9/4B!!3ED@1$E214-4+"!)3D1)4D5#5"P@24Y#241%
M3E1!3"P@4U!%0TE!3"P@15A%35!,05)9+"!/4@H@*B!#3TY315%514Y424%,
M($1!34%'15,@*$E.0TQ51$E.1RP@0E54($Y/5"!,24U)5$5$(%1/+"!04D]#
M55)%345.5"!/1@H@*B!354)35$E4551%($=/3T13($]2(%-%4E9)0T53.R!,
M3U-3($]&(%5312P@1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,*("H@
M24Y415)255!424].*2!(3U=%5D52($-!55-%1"!!3D0@3TX@04Y9(%1(14]2
M62!/1B!,24%"24Q)5%DL(%=(151(15(@24X*("H@0T].5%)!0U0L(%-44DE#
M5"!,24%"24Q)5%DL($]2(%1/4E0@*$E.0TQ51$E.1R!.14=,24=%3D-%($]2
M($]42$525TE312D*("H@05))4TE.1R!)3B!!3ED@5T%9($]55"!/1B!42$4@
M55-%($]&(%1(25,@4T]&5%=!4D4L($5614X@248@041625-%1"!/1B!42$4*
M("H@4$]34TE"24Q)5%D@3T8@4U5#2"!$04U!1T4N"B`J(#PO3$E#14Y313X*
M("H@"B`J($!C871E9V]R>2`@("!796(@4V5R=FEC97,*("H@0'!A8VMA9V4@
M("`@(%-E<G9I8V5S7U=E871H97(*("H@0&%U=&AO<B`@("`@($%L97AA;F1E
M<B!7:7)T>B`\86QE>$!P8S1P+FYE=#X*("H@0&-O<'ER:6=H="`@(#(P,#4@
M06QE>&%N9&5R(%=I<G1Z"B`J($!L:6-E;G-E("`@("!H='1P.B\O=W=W+F]P
M96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI
M8V5N<V4*("H@0'9E<G-I;VX@("`@($-64SH@)$ED.B!W96%T:&5R+F-O;2UE
M>'1E;G-I=F4N<&AP+'8@,2XQ-"`R,#`U+S$Q+S`X(#$W.C4R.C0R(&5R=2!%
M>'`@)`H@*B!`;&EN:R`@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K
M86=E+U-E<G9I8V5S7U=E871H97(*("H@0&9I;&5S;W5R8V4*("HO"@HO+RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*+R\@5&AI<R!I<R!T:&4@87)E
M82P@=VAE<F4@>6]U(&-A;B!C=7-T;VUI>F4@=&AE('-C<FEP=`HO+RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*)&QO8V%T:6]N("`@("`](")";VYN
M+"!'97)M86YY(CL@+R\@5&AE(&-I='D@=V4@=V%N="!T;R!F971C:"!T:&4@
M9&%T82!F;W(N"B1F;W)E8V%S=$1A>7,@/2`T.R`@("`@("`@("`@("`@("\O
M(%1H:7,@<F5G=6QA=&5S('1H92!A;6]U;G0@;V8@9&ES<&QA>65D"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(&1A=&5S(&EN('1H92!F
M;W)E8V%S="X@*#$@/#T@>"`\/2`Q,"D*)'!A<G1N97))1"`@("`]("(\4&%R
M=&YE<DE$/B([("`@+R\@07,@<')O=FED960@8GD@=V5A=&AE<BYC;VT@:6X@
M=&AE"B1L:6-E;G-E2V5Y("`@/2`B/$QI8V5N<V5+97D^(CL@("\O(')E9VES
M=')A=&EO;B!E36%I;"X*)&-A8VAE5'EP92`@("`]("(B.R`@("`@("`@("`@
M("`@+R\@4V5T(&$@='EP92`H9FEL92P@9&(L(&UD8BP@+BXN*2!T;PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!E;F%B;&4@8V%C:&EN
M9RX*)&-A8VAE3W!T("`@("`](&%R<F%Y*"D[("`@("`@("`@+R\@0V%C:&4@
M;F5E9',@=F%R:6]U<R!O<'1I;VYS+"!D97!E;F1I;F<*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@+R\@;VX@=&AE(&-O;G1A:6YE<BUT>7!E
M("T@<&QE87-E(&-O;G-U;'0*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+R\@=&AE($-A8VAE(&UA;G5A;"`O('-O=7)C96-O9&4A"B1U;FET
M<T9O<FUA="`@/2`B;65T<FEC(CL@("`@("`@("\O(%1H92!F;W)M870@=&AE
M('5N:71S(&%R92!D:7-P;&%Y960@:6X@+0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!M971R:6,L('-T86YD87)D(&]R('-O;64@8W5S
M=&]M:7IA=&EO;BX*)&1A=&5&;W)M870@("`](")9+6TM9"([("`@("`@("`@
M+R\@4V5T('1H92!F;W)M870@=&AE(&1A=&4@:7,@9&ES<&QA>65D(&EN"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O($-H86YG:6YG(&ET
M('=I;&P@8G)E86L@82!F97<@=&AI;F=S(&EN"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("\O('1H:7,@<V-R:7!T+"!B=70@=7-U86QL>2!Y
M;W4@8V%N(&1E9FEN90H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`O+R!T:&ES('1O('EO=7(@;&EK:6YG<RX*)'1I;65&;W)M870@("`](")(
M.FDB.R`@("`@("`@("`@+R\@4V5T('1H92!F;W)M870@=&AE('1I;64@:7,@
M9&ES<&QA>65D(&EN"B\O+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H*
M+R\@3&]A9"!T:&4@5V5A=&AE<B!C;&%S<PIR97%U:7)E7V]N8V4@(E-E<G9I
M8V5S+U=E871H97(N<&AP(CL*"B\O($]B:F5C="!I;FET:6%L:7IA=&EO;B`M
M(&5R<F]R(&-H96-K:6YG(&ES(&EM<&]R=&%N="P@8F5C875S92!O9@HO+R!H
M86YD;&EN9R!E>&-E<'1I;VYS('-U8V@@87,@;6ES<VEN9R!014%2(&UO9'5L
M97,*)'=E871H97)$;W1#;VT@/2`F4V5R=FEC97-?5V5A=&AE<CHZ<V5R=FEC
M92@B5V5A=&AE<D1O=$-O;2(L(&%R<F%Y*")H='1P5&EM96]U="(@/3X@,S`I
M*3L*:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'=E871H97)$;W1#
M;VTI*2!["B`@("!D:64H(D5R<F]R.B`B+B1W96%T:&5R1&]T0V]M+3YG971-
M97-S86=E*"DN(EQN(BD["GT*"B\O(%-E="!W96%T:&5R+F-O;2!P87)T;F5R
M(&1A=&$*)'=E871H97)$;W1#;VTM/G-E=$%C8V]U;G1$871A*"1P87)T;F5R
M240L("1L:6-E;G-E2V5Y*3L*"B\O($EN:71I86QI>F4@8V%C:&EN9PII9B`H
M<W1R;&5N*"1C86-H951Y<&4I*2!["B`@("`D<W1A='5S(#T@)'=E871H97)$
M;W1#;VTM/G-E=$-A8VAE*"1C86-H951Y<&4L("1C86-H94]P="D["B`@("!I
M9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@
M("`@(&5C:&\@(D5R<F]R.B`B+B1S=&%T=7,M/F=E=$UE<W-A9V4H*2XB7&XB
M.PH@("`@?0I]"@HO+R!$969I;F4@=&AE('5N:71S(&9O<FUA="P@8G)I;F<@
M=&AE(')E=')I979E9"!F;W)M870@:6YT;PHO+R!S;VUE=&AI;F<@;6]R92!C
M;VUM;VXN+BX*)'=E871H97)$;W1#;VTM/G-E=%5N:71S1F]R;6%T*"1U;FET
M<T9O<FUA="D["B1U;FET<R`]("1W96%T:&5R1&]T0V]M+3YG9715;FET<T9O
M<FUA="@I.PHD=6YI='-;(G1E;7`B72`@(#T@(B9D96<[(BYS=')T;W5P<&5R
M*"1U;FET<ULB=&5M<")=*3L*)'5N:71S6R)W:6YD(ET@("`]("(F;F)S<#LB
M+G-T<E]R97!L86-E*")K;6@B+"`B:VTO:"(L("1U;FET<ULB=VEN9")=*3L*
M)'5N:71S6R)V:7,B72`@("`]("(F;F)S<#LB+B1U;FET<ULB=FES(ET["B1U
M;FET<ULB:&5I9VAT(ET@/2`B)FYB<W`[(BXD=6YI='-;(FAE:6=H=")=.PHD
M=6YI='-;(G!R97,B72`@(#T@(B9N8G-P.R(N)'5N:71S6R)P<F5S(ET["B1U
M;FET<ULB<F%I;B)=("`@/2`B)FYB<W`[(BXD=6YI='-;(G)A:6XB73L*"B\O
M(%-E="!D871E+2]T:6UE+69O<FUA=`HD=V5A=&AE<D1O=$-O;2T^<V5T1&%T
M951I;65&;W)M870H)&1A=&5&;W)M870L("1T:6UE1F]R;6%T*3L*"B\O(%-E
M87)C:"!F;W(@9&5F:6YE9"!L;V-A=&EO;B!A;F0@9F5T8V@@=&AE(&9I<G-T
M(&ET96T@9F]U;F0N"B\O($)A:6P@;W5T(&EF('-O;65T:&EN9R!B860@:&%P
M<&5N<RXN+@HD<V5A<F-H(#T@)'=E871H97)$;W1#;VTM/G-E87)C:$QO8V%T
M:6]N*"1L;V-A=&EO;BP@=')U92D["FEF("A397)V:6-E<U]796%T:&5R.CII
M<T5R<F]R*"1S96%R8V@I*2!["B`@("!D:64H(D5R<F]R.B`B+B1S96%R8V@M
M/F=E=$UE<W-A9V4H*2XB7&XB*3L*?0H*+R\@4F5T<FEE=F4@9&%T82P@<W1O
M<F4@:6X@=F%R:6%B;&5S+"!B86EL(&]U="!O;B!E<G)O<@HD9F5T8V@@/2!A
M<G)A>2@*("`@(")L:6YK<R(@("`@/3X@(F=E=$QI;FMS(BP*("`@(")L;V-A
M=&EO;B(@/3X@(F=E=$QO8V%T:6]N(BP*("`@(")W96%T:&5R(B`@/3X@(F=E
M=%=E871H97(B+`H@("`@(F9O<F5C87-T(B`]/B`B9V5T1F]R96-A<W0B"BD[
M"F9O<F5A8V@@*"1F971C:"!A<R`D=F%R:6%B;&4@/3X@)&9U;F-T:6]N*2![
M"B`@("`D)'9A<FEA8FQE(#T@)'=E871H97)$;W1#;VTM/B1F=6YC=&EO;B@D
M<V5A<F-H+"`D9F]R96-A<W1$87ES*3L*("`@(&EF("A397)V:6-E<U]796%T
M:&5R.CII<T5R<F]R*"0D=F%R:6%B;&4I*2!["B`@("`@("`@96-H;R`B17)R
M;W(Z("(N)"1V87)I86)L92T^9V5T365S<V%G92@I+B)<;B(["B`@("`@("`@
M8V]N=&EN=64["B`@("!]"GT*"B\O(%=E(&YE960@=&AI<R!F;W(@<V]M92!T
M:6UE+6-H96-K<R!A;F0@9&ES<&QA>7,@;&%T97(*)'=U<&0@/2!S=')T;W1I
M;64H)'=E871H97);(G5P9&%T92)=*2`@*R!D871E*"):(BD["B1F=7!D(#T@
M<W1R=&]T:6UE*"1F;W)E8V%S=%LB=7!D871E(ETI("L@9&%T92@B6B(I.PHD
M9G5P("`]('-T<G1O=&EM92@D9F]R96-A<W1;(G5P9&%T92)=*2`K("1L;V-A
M=&EO;ELB=&EM97IO;F4B72`J(#,V,#`["@HO+R!#:&5C:RP@:68@=V4G<F4@
M:6X@=&AE(&%F=&5R;F]O;B!A;F0@:68@=&AE(&9O<F5C87-T('=A<R!U<&1A
M=&5D('EE="XN+@HO+R!4:&ES('1R:6=G97)S(&EF('1H92!D87DM9F]R96-A
M<W0@9F]R('1H92!C=7)R96YT(&1A>2!W:6QL(&=E="!S:&]W;BX*)&%F=&5R
M;F]O;B`]("@D;&]C871I;VY;(G1I;64B72`^("(Q,SHU.2(@?'P@9&%T92@B
M66UD(BP@)&9U<"D@/"!D871E*")9;60B*2D@/R!T<G5E(#H@9F%L<V4["@HO
M+R!4:&4@=7-U86P@;F]T871I;VX@9F]R(&-O;F1I=&EO;B!I8V]N<R!I<R!N
M=6UE<FEC+B!#:&5C:R!F;W(@;G5M97)I8R!I8V]N(&]R(")N82(@86YD('-E
M="!T;R`B;F$B(&EF('1H870G<R!N;W0@=&AE(&-A<V4*:68@*"$H8W1Y<&5?
M9&EG:70H)'=E871H97);(F-O;F1I=&EO;DEC;VXB72D@?'P@)'=E871H97);
M(F-O;F1I=&EO;DEC;VXB72`]/2`B;F$B*2D@>PH@("`@)'=E871H97);(F-O
M;F1I=&EO;DEC;VXB72`](")N82(["GT*"B\O($YO=R!W92!O=71P=70@86QL
M('1H92!D871A+"!P;&5A<V4@9&]N)W0@97AP96-T(&5X=&5N<VEV92!C;VUM
M96YT<R!H97)E+"!T:&ES(&ES(&)A<VEC"B\O($A434PO0U-3('-T=69F+B!!
M;'-O('1H:7,@:7-N)W0@82!V97)Y(&9A;F-Y(&1E<VEG;BP@:70G<R!J=7-T
M('1O('-H;W<@>6]U+"!W:&%T"B\O('1H92!S8W)I<'0@:7,@86)L92!T;R!D
M;R`H86YD(&UO<F4@.RTI*2XN+@H_/@H\:'1M;#X*/&AE860^"B`@("`\=&ET
M;&4^4V5R=FEC97-?5V5A=&AE<CHZ5V5A=&AE<F1O=&-O;3PO=&ET;&4^"B`@
M("`\<W1Y;&4@='EP93TB=&5X="]C<W,B/@H@("`@("`@("YN;W)M86P@("`@
M('L@9F]N="UF86UI;'DZ($%R:6%L+"!(96QV971I8V$L('-A;G,M<V5R:68[
M(&9O;G0M<VEZ93H@,3%P=#L@9F]N="UW96EG:'0Z(&YO<FUA;#L@9F]N="US
M='EL93H@;F]R;6%L('T*("`@("`@("`N:71A;&EC("`@("![(&9O;G0M=V5I
M9VAT.B!N;W)M86P[(&9O;G0M<W1Y;&4Z(&ET86QI8R!]"B`@("`@("`@+F)O
M;&0@("`@("`@>R!F;VYT+7=E:6=H=#H@8F]L9#L@9F]N="US='EL93H@;F]R
M;6%L('T*("`@("`@("`N8F]L9&ET86QI8R![(&9O;G0M=V5I9VAT.B!B;VQD
M.R!F;VYT+7-T>6QE.B!I=&%L:6,@?0H@("`@("`@("YR961B;VQD("`@('L@
M9F]N="UW96EG:'0Z(&)O;&0[(&9O;G0M<W1Y;&4Z(&YO<FUA;#L@8V]L;W(Z
M("-F9C`P,#`@?0H@("`@("`@("YB;'5E8F]L9"`@('L@9F]N="UW96EG:'0Z
M(&)O;&0[(&9O;G0M<W1Y;&4Z(&YO<FUA;#L@8V]L;W(Z(",P,#`P9F8@?0H@
M("`@("`@("YB9V=R97D@("`@('L@8F%C:V=R;W5N9"UC;VQO<CH@(V4Y93EE
M.2!]"B`@("`@("`@+F)G:VAA:VD@("`@>R!B86-K9W)O=6YD+6-O;&]R.B`C
M9#AD.&,P('T*("`@("`@("`N<F5G("`@("`@("![(&9O;G0M<VEZ93H@-W!T
M.R!V97)T:6-A;"UA;&EG;CH@<W5P97(@?0H@("`@("`@(&EM9R`@("`@("`@
M('L@=F5R=&EC86PM86QI9VXZ(&UI9&1L93L@8F]R9&5R+7-T>6QE.B!N;VYE
M.R!B;W)D97(M=VED=&@Z(#!P>"!]"B`@("`@("`@82`@("`@("`@("`@>R!F
M;VYT+7=E:6=H=#H@8F]L9#L@9F]N="US='EL93H@:71A;&EC.R!C;VQO<CH@
M(SDY,S,P,#L@=&5X="UD96-O<F%T:6]N.B!N;VYE('T*("`@("`@("!A.G9I
M<VET960@("![(&9O;G0M=V5I9VAT.B!B;VQD.R!F;VYT+7-T>6QE.B!I=&%L
M:6,[(&-O;&]R.B`C.3DS,S`P.R!T97AT+61E8V]R871I;VXZ(&YO;F4@?0H@
M("`@("`@(&$Z:&]V97(@("`@('L@9F]N="UW96EG:'0Z(&)O;&0[(&9O;G0M
M<W1Y;&4Z(&ET86QI8SL@8V]L;W(Z("-C8S,S,#`[('1E>'0M9&5C;W)A=&EO
M;CH@=6YD97)L:6YE('T*("`@("`@("!T86)L92`@("`@("![(&)O<F1E<CH@
M,'!X(&YO;F4@8FQA8VL[(&)O<F1E<BUS<&%C:6YG.B`P<'@@?0H@("`@("`@
M('1D("`@("`@("`@('L@9F]N="UF86UI;'DZ($%R:6%L+"!(96QV971I8V$L
M('-A;G,M<V5R:68[(&9O;G0M<VEZ93H@,3%P=#L@9F]N="UW96EG:'0Z(&YO
M<FUA;#L@9F]N="US='EL93H@;F]R;6%L('T*("`@(#PO<W1Y;&4^"CPO:&5A
M9#X*/&)O9'D@8VQA<W,](FYO<FUA;"(^"CP_<&AP"B\O($1E8G5G(&]U='!U
M=',@=&AE(')A=R!D871A(&9E=&-H960@8GD@=&AE(&9O<F5A8V@M;&]O<"!A
M8F]V92P@:G5S="!F;W(@8VAE8VMI;F<N+BX*:68@*&ES<V5T*"1?1T546R)D
M96)U9R)=*2D@>PH@("`@96-H;R`B/'!R93Y<;B(["B`@("!V87)?9'5M<"@D
M;&EN:W,L("1L;V-A=&EO;BP@)'=E871H97(L("1F;W)E8V%S="D["B`@("!E
M8VAO("(\+W!R93Y<;B(["GT@"C\^"CQS<&%N(&-L87-S/2)B;'5E8F]L9"(@
M<W1Y;&4](F9O;G0M<VEZ93H@,3-P="(^5V5A=&AE<B!&;W)E8V%S=#PO<W!A
M;CX@8W)E871E9"!W:71H(#QA('-T>6QE/2)F;VYT+7-I>F4Z(#$S<'0B(&AR
M968](FAT='`Z+R]P96%R+G!H<"YN970O(CY014%2<SPO83X@/&$@<W1Y;&4]
M(F9O;G0M<VEZ93H@,3-P="(@:')E9CTB:'1T<#HO+W!E87(N<&AP+FYE="]P
M86-K86=E+U-E<G9I8V5S7U=E871H97(O(CY397)V:6-E<U]796%T:&5R/"]A
M/CQB<CX*/'1A8FQE('-T>6QE/2)W:61T:#H@,3`P)2(^"CQT<CX*("`@(#QT
M9#X*("`@("`@("`\=&%B;&4@<W1Y;&4](F)O<F1E<BUT;W`Z(#)P>"!S;VQI
M9"`C-3(T8CDX.R!B;W)D97(M8F]T=&]M.B`R<'@@<V]L:60@(V4P93-C93L@
M8F]R9&5R+6QE9G0Z(#)P>"!S;VQI9"`C8CAB-F,Q.R!B;W)D97(M<FEG:'0Z
M(#)P>"!S;VQI9"`C.&(X-V$P.R!W:61T:#H@,3`P)2(^"B`@("`@("`@/'1R
M(&-L87-S/2)B9VMH86MI(CX*("`@("`@("`@("`@/'1D('-T>6QE/2)W:61T
M:#H@,S$P<'@[(&)O<F1E<BUB;W1T;VTZ(#)P>"!S;VQI9"`C86)A9&$R(B!C
M;VQS<&%N/2(R(CX\<W!A;B!C;&%S<STB8F]L9"(^/#\])&QO8V%T:6]N6R)N
M86UE(ET_/CPO<W!A;CX\+W1D/@H@("`@("`@("`@("`\=&0@<W1Y;&4](G=I
M9'1H.B`Q.3!P>#L@8F]R9&5R+6)O='1O;3H@,G!X('-O;&ED("-A8F%D83(B
M/CQS<&%N(&-L87-S/2)B;VQD(CY,;V-A;"!T:6UE.CPO<W!A;CX@/#\])&QO
M8V%T:6]N6R)T:6UE(ET_/B`H1TU4/#\]*"@D;&]C871I;VY;(G1I;65Z;VYE
M(ET@/"`P*2`_("(B(#H@(BLB*2XD;&]C871I;VY;(G1I;65Z;VYE(ET_/BD\
M+W1D/@H@("`@("`@("`@("`\=&0@<W1Y;&4](F)O<F1E<BUB;W1T;VTZ(#)P
M>"!S;VQI9"`C86)A9&$R(CXF;F)S<#L\+W1D/@H@("`@("`@(#PO='(^"B`@
M("`@("`@/'1R/@H@("`@("`@("`@("`\=&0^/'-P86X@8VQA<W,](F)O;&0B
M/E-U;G)I<V4Z/"]S<&%N/B`\:6UG('-T>6QE/2)W:61T:#H@,CAP>#L@:&5I
M9VAT.B`Q,W!X.R!V97)T:6-A;"UA;&EG;CH@8F%S96QI;F4B(&%L=#TB4W5N
M<FES92(@<W)C/2)I;6%G97,O<W5N<FES92YG:68B/B`\/STD;&]C871I;VY;
M(G-U;G)I<V4B73\^/"]T9#X*("`@("`@("`@("`@/'1D(&-O;'-P86X](C(B
M/CQS<&%N(&-L87-S/2)B;VQD(CY3=6YS970Z/"]S<&%N/B`\:6UG('-T>6QE
M/2)W:61T:#H@,S!P>#L@:&5I9VAT.B`Q-7!X.R!V97)T:6-A;"UA;&EG;CH@
M8F%S96QI;F4B(&%L=#TB4W5N<V5T(B!S<F,](FEM86=E<R]S=6YS970N9VEF
M(CX@/#\])&QO8V%T:6]N6R)S=6YS970B73\^/"]T9#X*("`@("`@("`@("`@
M/'1D(')O=W-P86X](C4B('9A;&EG;CTB;6ED9&QE(B!A;&EG;CTB8V5N=&5R
M(CX*("`@("`@("`@("`@("`@(#QT86)L92!S='EL93TB8F]R9&5R+71O<#H@
M,G!X('-O;&ED(",U,C1B.3@[(&)O<F1E<BUB;W1T;VTZ(#)P>"!S;VQI9"`C
M93!E,V-E.R!B;W)D97(M;&5F=#H@,G!X('-O;&ED("-B.&(V8S$[(&)O<F1E
M<BUR:6=H=#H@,G!X('-O;&ED(",X8C@W83`B/@H@("`@("`@("`@("`@("`@
M/'1R(&-L87-S/2)B9VMH86MI(CX*("`@("`@("`@("`@("`@("`@("`\=&0@
M86QI9VX](F-E;G1E<B(@<W1Y;&4](F)O<F1E<BUB;W1T;VTZ(#)P>"!S;VQI
M9"`C86)A9&$R(CX\<W!A;B!C;&%S<STB8F]L9"(^1F5A='5R960@;VX@/'-P
M86X@8VQA<W,](F)O;&1I=&%L:6,B/G=E871H97(N8V]M/'-P86X@8VQA<W,]
M(G)E9R(^)G)E9SL\+W-P86X^/"]S<&%N/CPO<W!A;CX\+W1D/@H@("`@("`@
M("`@("`@("`@/"]T<CX*/#]P:'`*+R\@3&]O<"!T:')O=6=H('1H92!M86YD
M871O<GD@;&EN:W,L(&YO=&AI;F<@<W!E8W1A8W5L87(*9F]R("@D:2`](#`[
M("1I(#P@<VEZ96]F*"1L:6YK<ULB<')O;6\B72D[("1I*RLI('L*/SX*("`@
M("`@("`@("`@("`@(#QT<B!C;&%S<STB8F=G<F5Y(CX*("`@("`@("`@("`@
M("`@("`@("`\=&0^/&$@:')E9CTB/#\])&QI;FMS6R)P<F]M;R)=6R1I75LB
M;&EN:R)=/SXB/CP_/21L:6YK<ULB<')O;6\B75LD:5U;(G1I=&QE(ET_/CPO
M83X\+W1D/@H@("`@("`@("`@("`@("`@/"]T<CX*/#]P:'`*?0H_/@H@("`@
M("`@("`@("`@("`@/"]T86)L93X*("`@("`@("`@("`@/"]T9#X*("`@("`@
M("`\+W1R/@H@("`@("`@(#QT<CX*("`@("`@("`@("`@/'1D/CQS<&%N(&-L
M87-S/2)B;VQD(CY496UP97)A='5R93H\+W-P86X^(#P_/7)O=6YD*"1W96%T
M:&5R6R)T96UP97)A='5R92)=+"`Q*2XD=6YI='-;(G1E;7`B73\^/"]T9#X*
M("`@("`@("`@("`@/'1D/CQS<&%N(&-L87-S/2)B;VQD(CY$97<@<&]I;G0Z
M/"]S<&%N/B`\/SUR;W5N9"@D=V5A=&AE<ELB9&5W4&]I;G0B72P@,2DN)'5N
M:71S6R)T96UP(ET_/CPO=&0^"B`@("`@("`@("`@(#QT9#X\<W!A;B!C;&%S
M<STB8F]L9"(^1F5L="!T96UP97)A='5R93H\+W-P86X^(#P_/7)O=6YD*"1W
M96%T:&5R6R)F96QT5&5M<&5R871U<F4B72P@,2DN)'5N:71S6R)T96UP(ET_
M/CPO=&0^"B`@("`@("`@/"]T<CX*("`@("`@("`\='(^"B`@("`@("`@("`@
M(#QT9"!C;VQS<&%N/2(R(CX\<W!A;B!C;&%S<STB8F]L9"(^4')E<W-U<F4Z
M/"]S<&%N/B`\/SUR;W5N9"@D=V5A=&AE<ELB<')E<W-U<F4B72P@,2DN)'5N
M:71S6R)P<F5S(ET_/B!A;F0@/#\])'=E871H97);(G!R97-S=7)E5')E;F0B
M73\^/"]T9#X*("`@("`@("`@("`@/'1D/CQS<&%N(&-L87-S/2)B;VQD(CY(
M=6UI9&ET>3H\+W-P86X^(#P_/21W96%T:&5R6R)H=6UI9&ET>2)=/SXE/"]T
M9#X*("`@("`@("`\+W1R/@H@("`@("`@(#QT<CX*("`@("`@("`@("`@/'1D
M(&-O;'-P86X](C(B/CQS<&%N(&-L87-S/2)B;VQD(CY7:6YD.CPO<W!A;CX@
M/#\]<W1R=&]L;W=E<B@D=V5A=&AE<ELB=VEN9$1I<F5C=&EO;B)=*2`]/2`B
M8V%L;2(@/R`B0V%L;2(@.B`B1G)O;2!T:&4@(BXD=V5A=&AE<ELB=VEN9$1I
M<F5C=&EO;B)=+B(@*"(N)'=E871H97);(G=I;F1$96=R965S(ETN(B9D96<[
M*2!A="`B+G)O=6YD*"1W96%T:&5R6R)W:6YD(ETL(#$I+B1U;FET<ULB=VEN
M9")=/SX\+W1D/@H@("`@("`@("`@("`\=&0^/'-P86X@8VQA<W,](F)O;&0B
M/E9I<VEB:6QI='DZ/"]S<&%N/B`\/SUR;W5N9"@D=V5A=&AE<ELB=FES:6)I
M;&ET>2)=+"`Q*2XD=6YI='-;(G9I<R)=/SX\+W1D/@H@("`@("`@(#PO='(^
M"B`@("`@("`@/'1R/@H@("`@("`@("`@("`\=&0^/'-P86X@8VQA<W,](F)O
M;&0B/D-U<G)E;G0@8V]N9&ET:6]N.CPO<W!A;CX\8G(^/#\])'=E871H97);
M(F-O;F1I=&EO;B)=/SX\+W1D/@H@("`@("`@("`@("`\=&0^/&EM9R!S='EL
M93TB:&5I9VAT.B`S,G!X.R!W:61T:#H@,S)P>"(@86QT/2(\/STD=V5A=&AE
M<ELB8V]N9&ET:6]N(ET_/B(@<W)C/2)I;6%G97,O,S)X,S(O/#\])'=E871H
M97);(F-O;F1I=&EO;DEC;VXB73\^+G!N9R(^/"]T9#X*("`@("`@("`@("`@
M/'1D('9A;&EG;CTB=&]P(CX\<W!A;B!C;&%S<STB8F]L9"(^558M26YD97@Z
M/"]S<&%N/B`\/STD=V5A=&AE<ELB=79);F1E>")=/SX@*#P_/21W96%T:&5R
M6R)U=E1E>'0B73\^*3PO=&0^"B`@("`@("`@/"]T<CX*("`@("`@("`\+W1A
M8FQE/@H@("`@/"]T9#X*/"]T<CX*/'1R/@H@("`@/'1D/@H@("`@("`@(#QT
M86)L92!S='EL93TB8F]R9&5R+71O<#H@,G!X('-O;&ED(",U,C1B.3@[(&)O
M<F1E<BUB;W1T;VTZ(#)P>"!S;VQI9"`C93!E,V-E.R!B;W)D97(M;&5F=#H@
M,G!X('-O;&ED("-B.&(V8S$[(&)O<F1E<BUR:6=H=#H@,G!X('-O;&ED(",X
M8C@W83`B/@H@("`@("`@(#QT<B!C;&%S<STB8F=K:&%K:2(^"B`@("`@("`@
M("`@(#QT9"!A;&EG;CTB8V5N=&5R(B!S='EL93TB8F]R9&5R+6)O='1O;3H@
M,G!X('-O;&ED("-A8F%D83(B(&-O;'-P86X](CP_/2@Q("L@)&9O<F5C87-T
M1&%Y<RD_/B(^/'-P86X@8VQA<W,](F)O;&0B/CP_/21F;W)E8V%S=$1A>7,_
M/BUD87D@9F]R96-A<W0\+W-P86X^/"]T9#X*("`@("`@("`\+W1R/@H@("`@
M("`@(#QT<B!V86QI9VX](G1O<"(^"B`@("`@("`@("`@(#QT9"!S='EL93TB
M=VED=&@Z(#$P)2(^"B`@("`@("`@("`@("`@("`\=&%B;&4@8VQA<W,](F)G
M:VAA:VDB('-T>6QE/2)W:61T:#H@,3`P)3L@8F]R9&5R+71O<#H@,G!X('-O
M;&ED("-D.&0X8S`[(&)O<F1E<BUB;W1T;VTZ(#)P>"!S;VQI9"`C9#AD.&,P
M.R!B;W)D97(M;&5F=#H@,G!X('-O;&ED("-D.&0X8S`[(&)O<F1E<BUR:6=H
M=#H@,G!X('-O;&ED(",X8C@W83`B/@H@("`@("`@("`@("`@("`@/'1R/@H@
M("`@("`@("`@("`@("`@("`@(#QT9"!A;&EG;CTB8V5N=&5R(B!S='EL93TB
M:&5I9VAT.B`Q-7!X(CXF;F)S<#L\+W1D/@H@("`@("`@("`@("`@("`@/'1R
M/@H@("`@("`@("`@("`@("`@("`@(#QT9"!A;&EG;CTB8V5N=&5R(B!S='EL
M93TB:&5I9VAT.B`T-7!X(CX\<W!A;B!C;&%S<STB8F]L9"(^5&5M<&5R871U
M<F4\+W-P86X^(#QS<&%N(&-L87-S/2)R961B;VQD(CY(:6=H/"]S<&%N/B`O
M(#QS<&%N(&-L87-S/2)B;'5E8F]L9"(^3&]W/"]S<&%N/CPO=&0^"B`@("`@
M("`@("`@("`@("`\+W1R/@H@("`@("`@("`@("`@("`@/'1R/@H@("`@("`@
M("`@("`@("`@("`@(#QT9"!A;&EG;CTB8V5N=&5R(B!S='EL93TB:&5I9VAT
M.B`Q-7!X(CXF;F)S<#L\+W1D/@H@("`@("`@("`@("`@("`@/"]T<CX*("`@
M("`@("`@("`@("`@(#QT<CX*("`@("`@("`@("`@("`@("`@("`\=&0@86QI
M9VX](F-E;G1E<B(@<W1Y;&4](FAE:6=H=#H@-S5P>"(^/'-P86X@8VQA<W,]
M(F)O;&0B/D-O;F1I=&EO;CPO<W!A;CX\+W1D/@H@("`@("`@("`@("`@("`@
M/"]T<CX*("`@("`@("`@("`@("`@(#QT<CX*("`@("`@("`@("`@("`@("`@
M("`\=&0@86QI9VX](F-E;G1E<B(@<W1Y;&4](FAE:6=H=#H@-#5P>"(^/'-P
M86X@8VQA<W,](F)O;&0B/E!R96-I<&ET871I;VX@<')O8F%B:6QI='D\+W-P
M86X^/"]T9#X*("`@("`@("`@("`@("`@(#PO='(^("`@("`@("`@("`@"B`@
M("`@("`@("`@("`@("`\='(^"B`@("`@("`@("`@("`@("`@("`@/'1D(&%L
M:6=N/2)C96YT97(B('-T>6QE/2)H96EG:'0Z(#0U<'@B/CQS<&%N(&-L87-S
M/2)B;VQD(CY7:6YD/"]S<&%N/CPO=&0^"B`@("`@("`@("`@("`@("`\+W1R
M/@H@("`@("`@("`@("`@("`@/'1R/@H@("`@("`@("`@("`@("`@("`@(#QT
M9"!A;&EG;CTB8V5N=&5R(B!S='EL93TB:&5I9VAT.B`Q-7!X(CX\<W!A;B!C
M;&%S<STB8F]L9"(^2'5M:61I='D\+W-P86X^/"]T9#X*("`@("`@("`@("`@
M("`@(#PO='(^"B`@("`@("`@("`@("`@("`\+W1A8FQE/@H@("`@("`@("`@
M("`\+W1D/@H\/W!H<`IF;W(@*"1D87D@/2`P.R`D9&%Y(#P@)&9O<F5C87-T
M1&%Y<SL@)&1A>2LK*2!["B`@("`O+R!3970@;F%M92!O9B!D87D*("`@(&EF
M("@D9&%Y(#T](#`I('L*("`@("`@("`D9&%Y;F%M92`](")4;V1A>2(["B`@
M("!](&5L<V5I9B`H)&1A>2`]/2`Q*2!["B`@("`@("`@)&1A>6YA;64@/2`B
M5&]M;W)R;W<B.PH@("`@?2!E;'-E('L*("`@("`@("`D9&%Y;F%M92`](&1A
M=&4H(FPB+"`D9G5P("L@)&1A>2`J(#@V-#`P*3L*("`@('T*("`@("\O($%F
M=&5R;F]O;B!I<R!O;FQY(&EM<&]R=&%N="!F;W(@=&]D87D*("`@("1A9G1E
M<FYO;VX@/2`H)&1A>2`]/2`P*2`_("1A9G1E<FYO;VX@.B!F86QS93L*"B`@
M("`O+R!4:&4@=7-U86P@;F]T871I;VX@9F]R(&-O;F1I=&EO;B!I8V]N<R!I
M<R!N=6UE<FEC+B!#:&5C:R!F;W(@;G5M97)I8R!I8V]N(&]R(")N82(@86YD
M('-E="!T;R`B;F$B(&EF('1H870G<R!N;W0@=&AE(&-A<V4*("`@(&EF("@A
M*&-T>7!E7V1I9VET*"1F;W)E8V%S=%LB9&%Y<R)=6R1D87E=6R)D87DB75LB
M8V]N9&ET:6]N26-O;B)=*2!\?"`D9F]R96-A<W1;(F1A>7,B75LD9&%Y75LB
M9&%Y(EU;(F-O;F1I=&EO;DEC;VXB72`]/2`B;F$B*2D@>PH@("`@("`@("1F
M;W)E8V%S=%LB9&%Y<R)=6R1D87E=6R)D87DB75LB8V]N9&ET:6]N26-O;B)=
M(#T@(FYA(CL*("`@('T*("`@(&EF("@A*&-T>7!E7V1I9VET*"1F;W)E8V%S
M=%LB9&%Y<R)=6R1D87E=6R)N:6=H=")=6R)C;VYD:71I;VY)8V]N(ETI('Q\
M("1F;W)E8V%S=%LB9&%Y<R)=6R1D87E=6R)N:6=H=")=6R)C;VYD:71I;VY)
M8V]N(ET@/3T@(FYA(BDI('L*("`@("`@("`D9F]R96-A<W1;(F1A>7,B75LD
M9&%Y75LB;FEG:'0B75LB8V]N9&ET:6]N26-O;B)=(#T@(FYA(CL*("`@('T*
M/SX*("`@("`@("`@("`@/'1D('-T>6QE/2)W:61T:#H@/#\]*#DP("\@)&9O
M<F5C87-T1&%Y<RD_/B4B/@H@("`@("`@("`@("`@("`@/'1A8FQE('-T>6QE
M/2)W:61T:#H@,3`P)2(\/STH)&1A>2`E(#(I(#\@)R!C;&%S<STB8F=G<F5Y
M(B<@.B`B(C\^/@H@("`@("`@("`@("`@("`@("`@(#QT<CX*("`@("`@("`@
M("`@("`@("`@("`@("`@/'1D(&%L:6=N/2)C96YT97(B(&-O;'-P86X](C(B
M('-T>6QE/2)H96EG:'0Z(#$U<'@B/CQS<&%N(&-L87-S/2)B;VQD(CX\/STD
M9&%Y;F%M93\^/"]S<&%N/CPO=&0^"B`@("`@("`@("`@("`@("`@("`@/"]T
M<CX*("`@("`@("`@("`@("`@("`@("`\='(^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#QT9"!A;&EG;CTB8V5N=&5R(B!C;VQS<&%N/2(R(B!S='EL93TB
M:&5I9VAT.B`T-7!X(CX\/STD869T97)N;V]N(#\@(B(@.B`G/'-P86X@8VQA
M<W,](G)E9&)O;&0B/B<N<F]U;F0H)&9O<F5C87-T6R)D87ES(EU;)&1A>5U;
M(G1E;7!E<F%T=7)E2&EG:")=+"`P*2XD=6YI='-;(G1E;7`B72XG/"]S<&%N
M/B`O("<_/CQS<&%N(&-L87-S/2)B;'5E8F]L9"(^/#\]<F]U;F0H)&9O<F5C
M87-T6R)D87ES(EU;)&1A>5U;(G1E;7!E<F%T=7)E3&]W(ETL(#`I+B1U;FET
M<ULB=&5M<")=/SX\+W-P86X^/"]T9#X*("`@("`@("`@("`@("`@("`@("`\
M+W1R/@H@("`@("`@("`@("`@("`@("`@(#QT<CX*("`@("`@("`@("`@("`@
M("`@("`@("`@/'1D(&%L:6=N/2)C96YT97(B('-T>6QE/2)W:61T:#H@-3`E
M.R!H96EG:'0Z(#$U<'@B/CP_/21A9G1E<FYO;VX@/R`B)FYB<W`[(B`Z("<\
M<W!A;B!C;&%S<STB8F]L9"(^1&%Y/"]S<&%N/B<_/CPO=&0^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#QT9"!A;&EG;CTB8V5N=&5R(B!S='EL93TB=VED
M=&@Z(#4P)3L@:&5I9VAT.B`Q-7!X(CX\<W!A;B!C;&%S<STB8F]L9"(^3FEG
M:'0\+W-P86X^/"]T9#X*("`@("`@("`@("`@("`@("`@("`\='(^"B`@("`@
M("`@("`@("`@("`@("`@/'1R/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M=&0@86QI9VX](F-E;G1E<B(@<W1Y;&4](FAE:6=H=#H@-S5P>"(@=F%L:61N
M/2)T;W`B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/#\])&%F=&5R
M;F]O;B`_("(F;F)S<#LB(#H@)SQI;6<@<W1Y;&4](FAE:6=H=#H@,S)P>#L@
M=VED=&@Z(#,R<'@B(&%L:6=N/2)T;W`B(&%L=#TB)RXD9F]R96-A<W1;(F1A
M>7,B75LD9&%Y75LB9&%Y(EU;(F-O;F1I=&EO;B)=+B<B('-R8STB:6UA9V5S
M+S,R>#,R+R<N)&9O<F5C87-T6R)D87ES(EU;)&1A>5U;(F1A>2)=6R)C;VYD
M:71I;VY)8V]N(ETN)RYP;F<B/B<_/CQB<CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#P_/21A9G1E<FYO;VX@/R`B)FYB<W`[(B`Z("1F;W)E8V%S
M=%LB9&%Y<R)=6R1D87E=6R)D87DB75LB8V]N9&ET:6]N(ET_/B`*("`@("`@
M("`@("`@("`@("`@("`@("`@/"]T9#X*("`@("`@("`@("`@("`@("`@("`@
M("`@/'1D(&%L:6=N/2)C96YT97(B('-T>6QE/2)H96EG:'0Z(#<U<'@B('9A
M;&ED;CTB=&]P(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QI;6<@
M<W1Y;&4](FAE:6=H=#H@,S)P>#L@=VED=&@Z(#,R<'@B(&%L:6=N/2)T;W`B
M(&%L=#TB/#\])&9O<F5C87-T6R)D87ES(EU;)&1A>5U;(FYI9VAT(EU;(F-O
M;F1I=&EO;B)=/SXB('-R8STB:6UA9V5S+S,R>#,R+SP_/21F;W)E8V%S=%LB
M9&%Y<R)=6R1D87E=6R)N:6=H=")=6R)C;VYD:71I;VY)8V]N(ET_/BYP;F<B
M/CQB<CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#P_/21F;W)E8V%S
M=%LB9&%Y<R)=6R1D87E=6R)N:6=H=")=6R)C;VYD:71I;VXB73\^(`H@("`@
M("`@("`@("`@("`@("`@("`@("`\+W1D/@H@("`@("`@("`@("`@("`@("`@
M(#PO='(^"B`@("`@("`@("`@("`@("`@("`@/'1R/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\=&0@86QI9VX](F-E;G1E<B(@<W1Y;&4](FAE:6=H=#H@
M-#5P>"(^/#\])&%F=&5R;F]O;B`_("(F;F)S<"(@.B`D9F]R96-A<W1;(F1A
M>7,B75LD9&%Y75LB9&%Y(EU;(G!R96-I<&ET871I;VXB72XB)2(_/CPO=&0^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#QT9"!A;&EG;CTB8V5N=&5R(B!S
M='EL93TB:&5I9VAT.B`T-7!X(CX\/STD9F]R96-A<W1;(F1A>7,B75LD9&%Y
M75LB;FEG:'0B75LB<')E8VEP:71A=&EO;B)=/SXE/"]T9#X*("`@("`@("`@
M("`@("`@("`@("`\+W1R/@H@("`@("`@("`@("`@("`@("`@(#QT<CX*("`@
M("`@("`@("`@("`@("`@("`@("`@/'1D(&%L:6=N/2)C96YT97(B('-T>6QE
M/2)H96EG:'0Z(#0U<'@B/CP_/21A9G1E<FYO;VX@/R`B)FYB<W`[(B`Z(')O
M=6YD*"1F;W)E8V%S=%LB9&%Y<R)=6R1D87E=6R)D87DB75LB=VEN9")=+"`P
M*2XD=6YI='-;(G=I;F0B72XB(&9R;VTF;F)S<#LB+B1F;W)E8V%S=%LB9&%Y
M<R)=6R1D87E=6R)D87DB75LB=VEN9$1I<F5C=&EO;B)=/SX\+W1D/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\=&0@86QI9VX](F-E;G1E<B(@<W1Y;&4]
M(FAE:6=H=#H@-#5P>"(^/#\]<F]U;F0H)&9O<F5C87-T6R)D87ES(EU;)&1A
M>5U;(FYI9VAT(EU;(G=I;F0B72P@,"DN)'5N:71S6R)W:6YD(ET_/B!F<F]M
M)FYB<W`[/#\])&9O<F5C87-T6R)D87ES(EU;)&1A>5U;(FYI9VAT(EU;(G=I
M;F1$:7)E8W1I;VXB73\^/"]T9#X*("`@("`@("`@("`@("`@("`@("`\+W1R
M/@H@("`@("`@("`@("`@("`@("`@(#QT<CX*("`@("`@("`@("`@("`@("`@
M("`@("`@/'1D(&%L:6=N/2)C96YT97(B('-T>6QE/2)H96EG:'0Z(#$U<'@B
M/CP_/21A9G1E<FYO;VX@/R`B(B`Z("1F;W)E8V%S=%LB9&%Y<R)=6R1D87E=
M6R)D87DB75LB:'5M:61I='DB72XB)2(_/CPO=&0^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#QT9"!A;&EG;CTB8V5N=&5R(B!S='EL93TB:&5I9VAT.B`Q
M-7!X(CX\/STD9F]R96-A<W1;(F1A>7,B75LD9&%Y75LB;FEG:'0B75LB:'5M
M:61I='DB73\^)3PO=&0^"B`@("`@("`@("`@("`@("`@("`@/"]T<CX*("`@
M("`@("`@("`@("`@(#PO=&%B;&4^"B`@("`@("`@("`@(#PO=&0^"CP_<&AP
M"GT*/SX*("`@("`@("`\+W1R/@H@("`@("`@(#QT<B!C;&%S<STB8F=K:&%K
M:2(^"B`@("`)("`@(#QT9"!S='EL93TB8F]R9&5R+71O<#H@,G!X('-O;&ED
M("-A8F%D83(B/B9N8G-P.SPO=&0^"B`@("`@("`@("`@(#QT9"!S='EL93TB
M8F]R9&5R+71O<#H@,G!X('-O;&ED("-A8F%D83(B/E5P9&%T960Z("@\/SUD
M871E*"1T:6UE1F]R;6%T+"`D=W5P9"D_/B9N8G-P.R\F;F)S<#L\/SUD871E
M*"1T:6UE1F]R;6%T+"`D9G5P9"D_/BD\+W1D/@H@("`@("`@("`@("`\=&0@
M86QI9VX](G)I9VAT(B!S='EL93TB8F]R9&5R+71O<#H@,G!X('-O;&ED("-A
M8F%D83(B(&-O;'-P86X](CP_/2@D9F]R96-A<W1$87ES("T@,2D_/B(^5V5A
M=&AE<B!D871A('!R;W9I9&5D(&)Y(#QA(&AR968](FAT='`Z+R]W=W<N=V5A
M=&AE<BYC;VTO/W!R;V0]>&]A<"9P87(]/#\])'!A<G1N97))1#\^(CYW96%T
M:&5R+F-O;3QS<&%N(&-L87-S/2)R96<B/B9R96<[/"]S<&%N/CPO83X\82!H
M<F5F/2)H='1P.B\O=W=W+G=E871H97(N8V]M+S]P<F]D/7AO87`F<&%R/3P_
M/21P87)T;F5R240_/B(^/&EM9R!S='EL93TB:&5I9VAT.B`S,G!X.R!W:61T
M:#H@-#-P>"(@86QT/2)W96%T:&5R+F-O;2A2*2!L;V=O(B!S<F,](FEM86=E
M<R]L;V=O<R]45T-L;V=O7S,R<'@N<&YG(CX\+V$^/"]T9#X*("`@("`@("`\
M+W1R/@H@("`@("`@(#PO=&%B;&4^"B`@("`\+W1D/@H\+W1R/@H\+W1A8FQE
M/@H\82!H<F5F/2)J879A<V-R:7!T.FAI<W1O<GDN8F%C:R@I(CYB86-K/"]A
M/@H\+V)O9'D^"CPO:'1M;#X*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]D;V-S+U-E<G9I8V5S7U=E871H97(O97AA;7!L97,O96IS92UB87-I
M8RYP:'```````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`V,C0S(#$P-3$U-#,S-S,P(#`R-S(Q-@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S
M;V9T=&%B<W1O<#TT(&9O;&1M971H;V0];6%R:V5R.B`J+PH*+RHJ"B`J($)A
M<VEC(&5X86UP;&4@9F]R('1H92!%2E-%+7-E<G9I8V4*("H*("H@4$A0('9E
M<G-I;VYS(#0@86YD(#4*("H*("H@/$Q)0T5.4T4^"B`J($-O<'ER:6=H="`H
M8RD@,C`P-2P@06QE>&%N9&5R(%=I<G1Z"B`J($%L;"!R:6=H=',@<F5S97)V
M960N"B`J(`H@*B!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A
M;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70*("H@;6]D:69I8V%T
M:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO=VEN
M9R!C;VYD:71I;VYS"B`J(&%R92!M970Z"B`J(&\@4F5D:7-T<FEB=71I;VYS
M(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG
M:'0@;F]T:6-E+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T
M:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N"B`J(&\@4F5D:7-T<FEB=71I;VYS
M(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y
M<FEG:'0@;F]T:6-E+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N
M9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@:6X@=&AE(&1O8W5M96YT871I
M;VX*("H@("!A;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@
M=&AE(&1I<W1R:6)U=&EO;BX*("H@;R!.96ET:&5R('1H92!N86UE(&]F('1H
M92!S;V9T=V%R92!N;W(@=&AE(&YA;65S(&]F(&ET<R!C;VYT<FEB=71O<G,*
M("H@("!M87D@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O9'5C
M=',@9&5R:79E9"!F<F]M('1H:7,@<V]F='=A<F4*("H@("!W:71H;W5T('-P
M96-I9FEC('!R:6]R('=R:71T96X@<&5R;6ES<VEO;BX*("H@"B`J(%1(25,@
M4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($-/4%E224=(5"!(3TQ$15)3
M($%.1"!#3TY44DE"551/4E,@(D%3($E3(@H@*B!!3D0@04Y9($584%)%4U,@
M3U(@24U03$E%1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.3U0@3$E-
M251%1"!43RP@5$A%"B`J($E-4$Q)140@5T%24D%.5$E%4R!/1B!-15)#2$%.
M5$%"24Q)5%D@04Y$($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!4B!055)03U-%
M"B`J($%212!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4@0T]0
M65))1TA4($]73D52($]2($-/3E1224)55$]24R!"10H@*B!,24%"3$4@1D]2
M($%.62!$25)%0U0L($E.1$E214-4+"!)3D-)1$5.5$%,+"!34$5#24%,+"!%
M6$5-4$Q!4EDL($]2"B`J($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$
M24Y'+"!"550@3D]4($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&"B`J(%-5
M0E-425155$4@1T]/1%,@3U(@4T525DE#15,[($Q/4U,@3T8@55-%+"!$051!
M+"!/4B!04D]&2513.R!/4B!"55-)3D534PH@*B!)3E1%4E)54%1)3TXI($A/
M5T5615(@0T%54T5$($%.1"!/3B!!3ED@5$A%3U)9($]&($Q)04))3$E462P@
M5TA%5$A%4B!)3@H@*B!#3TY44D%#5"P@4U1224-4($Q)04))3$E462P@3U(@
M5$]25"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*0H@*B!!
M4DE324Y'($E.($%.62!705D@3U54($]&(%1(12!54T4@3T8@5$A)4R!33T94
M5T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(10H@*B!03U-324))3$E462!/
M1B!354-(($1!34%'12X*("H@/"],24-%3E-%/@H@*B`*("H@0&-A=&5G;W)Y
M("`@(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G92`@("`@4V5R=FEC97-?5V5A
M=&AE<@H@*B!`875T:&]R("`@("`@06QE>&%N9&5R(%=I<G1Z(#QA;&5X0'!C
M-'`N;F5T/@H@*B!`8V]P>7)I9VAT("`@,C`P-2!!;&5X86YD97(@5VER='H*
M("H@0&QI8V5N<V4@("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC
M96YS97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO
M;B`@("`@0U93.B`D260Z(&5J<V4M8F%S:6,N<&AP+'8@,2XT(#(P,#4O,3$O
M,#@@,3<Z-3(Z-#(@97)U($5X<"`D"B`J($!L:6YK("`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O4V5R=FEC97-?5V5A=&AE<@H@*B!`9FEL
M97-O=7)C90H@*B\*(`IR97%U:7)E7V]N8V4@(E-E<G9I8V5S+U=E871H97(N
M<&AP(CL*"B\O($]B:F5C="!I;FET:6%L:7IA=&EO;B`M(&5R<F]R(&-H96-K
M:6YG(&ES(&EM<&]R=&%N="P@8F5C875S92!O9@HO+R!H86YD;&EN9R!E>&-E
M<'1I;VYS('-U8V@@87,@;6ES<VEN9R!014%2(&UO9'5L97,@;W(@;F]T(&)E
M:6YG(&]N;&EN90HD96IS92`]("9397)V:6-E<U]796%T:&5R.CIS97)V:6-E
M*")%:G-E(BP@87)R87DH(F1E8G5G(B`]/B`R*2D["FEF("A397)V:6-E<U]7
M96%T:&5R.CII<T5R<F]R*"1E:G-E*2D@>PH@("`@9&EE*")%<G)O<CH@(BXD
M96IS92T^9V5T365S<V%G92@I+B)<;B(I.PI]"@HO*B!%<F%S92!C;VUM96YT
M<R!T;R!E;F%B;&4@8V%C:&EN9PHD<W1A='5S(#T@)&5J<V4M/G-E=$-A8VAE
M*")F:6QE(BP@87)R87DH(F-A8VAE7V1I<B(@/3X@(B]T;7`O8V%C:&4O(BDI
M.PII9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@
M("`@96-H;R`B17)R;W(Z("(N)'-T871U<RT^9V5T365S<V%G92@I+B)<;B([
M"GT**B\*"B1E:G-E+3YS9715;FET<T9O<FUA="@B;65T<FEC(BD["B1E:G-E
M+3YS971$871E5&EM949O<FUA="@B9"YM+EDB+"`B2#II(BD["@HD;&]C871I
M;VX@/2`B.#$V,3$B.R`O+R!!<W!E;BP@0T\*+R\D;&]C871I;VX@/2`B,#(Q
M,34B.R`O+R!";W-T;VXL($U!"B\O)&QO8V%T:6]N(#T@(CDV-SDY(CL@+R\@
M4&%G;R!086=O+"!!4PHO+R1L;V-A=&EO;B`]("(P.3`P.2([("\O($%R;65D
M($9O<F-E<R!%=7)O<&4@+3X@17)R;W(*"B\O($YO=R!I=&5R871E('1H<F]U
M9V@@879A:6QA8FQE(&9U;F-T:6]N<R!F;W(@<F5T<FEE=FEN9R!D871A"F9O
M<F5A8V@@*&%R<F%Y*")G971,;V-A=&EO;B(L(")G971796%T:&5R(BP@(F=E
M=$9O<F5C87-T(BD@87,@)&9U;F-T:6]N*2!["B`@("`D9&%T82`]("1E:G-E
M+3XD9G5N8W1I;VXH)&QO8V%T:6]N*3L*("`@(&EF("A397)V:6-E<U]796%T
M:&5R.CII<T5R<F]R*"1D871A*2D@>PH@("`@("`@(&5C:&\@(D5R<F]R.B`B
M+B1D871A+3YG971-97-S86=E*"DN(EQN(CL*("`@("`@("!C;VYT:6YU93L*
M("`@('T*"B`@("!V87)?9'5M<"@D9&%T82D["GT*/SX*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O9&]C<R]397)V:6-E<U]796%T:&5R+V5X86UP;&5S+V=L;V)A;'=E
M871H97(M8F%S:6,N<&AP```````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P-C0Q,"`Q,#4Q-30S,S<S,"`P,S$Q,#0`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@
M<V]F='1A8G-T;W`]-"!F;VQD;65T:&]D/6UA<FME<CH@*B\*"B\J*@H@*B!"
M87-I8R!E>&%M<&QE(&9O<B!T:&4@1VQO8F%L5V5A=&AE<BUS97)V:6-E"B`J
M"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J(#Q,24-%3E-%/@H@*B!#
M;W!Y<FEG:'0@*&,I(#(P,#4L($%L97AA;F1E<B!7:7)T>@H@*B!!;&P@<FEG
M:'1S(')E<V5R=F5D+@H@*B`*("H@4F5D:7-T<FEB=71I;VX@86YD('5S92!I
M;B!S;W5R8V4@86YD(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T"B`J
M(&UO9&EF:6-A=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H
M92!F;VQL;W=I;F<@8V]N9&ET:6]N<PH@*B!A<F4@;65T.@H@*B!O(%)E9&ES
M=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@86)O
M=F4@8V]P>7)I9VAT(&YO=&EC92P*("H@("!T:&ES(&QI<W0@;V8@8V]N9&ET
M:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R+@H@*B!O(%)E9&ES
M=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C92!T:&4@
M86)O=F4@8V]P>7)I9VAT(&YO=&EC92P*("H@("!T:&ES(&QI<W0@;V8@8V]N
M9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN('1H92!D
M;V-U;65N=&%T:6]N"B`J("`@86YD+V]R(&]T:&5R(&UA=&5R:6%L<R!P<F]V
M:61E9"!W:71H('1H92!D:7-T<FEB=71I;VXN"B`J(&\@3F5I=&AE<B!T:&4@
M;F%M92!O9B!T:&4@<V]F='=A<F4@;F]R('1H92!N86UE<R!O9B!I=',@8V]N
M=')I8G5T;W)S"B`J("`@;6%Y(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M
M;W1E('!R;V1U8W1S(&1E<FEV960@9G)O;2!T:&ES('-O9G1W87)E"B`J("`@
M=VET:&]U="!S<&5C:69I8R!P<FEO<B!W<FET=&5N('!E<FUI<W-I;VXN"B`J
M(`H@*B!42$E3(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'
M2%0@2$],1$524R!!3D0@0T].5%))0E543U)3(")!4R!)4R(*("H@04Y$($%.
M62!%6%!215-3($]2($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"
M550@3D]4($Q)34E4140@5$\L(%1(10H@*B!)35!,245$(%=!4E)!3E1)15,@
M3T8@34520TA!3E1!0DE,2519($%.1"!&251.15-3($9/4B!!(%!!4E1)0U5,
M05(@4%524$]310H@*B!!4D4@1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!
M3$P@5$A%($-/4%E224=(5"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4*("H@
M3$E!0DQ%($9/4B!!3ED@1$E214-4+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@
M4U!%0TE!3"P@15A%35!,05)9+"!/4@H@*B!#3TY315%514Y424%,($1!34%'
M15,@*$E.0TQ51$E.1RP@0E54($Y/5"!,24U)5$5$(%1/+"!04D]#55)%345.
M5"!/1@H@*B!354)35$E4551%($=/3T13($]2(%-%4E9)0T53.R!,3U-3($]&
M(%5312P@1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,*("H@24Y415)2
M55!424].*2!(3U=%5D52($-!55-%1"!!3D0@3TX@04Y9(%1(14]262!/1B!,
M24%"24Q)5%DL(%=(151(15(@24X*("H@0T].5%)!0U0L(%-44DE#5"!,24%"
M24Q)5%DL($]2(%1/4E0@*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]42$52
M5TE312D*("H@05))4TE.1R!)3B!!3ED@5T%9($]55"!/1B!42$4@55-%($]&
M(%1(25,@4T]&5%=!4D4L($5614X@248@041625-%1"!/1B!42$4*("H@4$]3
M4TE"24Q)5%D@3T8@4U5#2"!$04U!1T4N"B`J(#PO3$E#14Y313X*("H@"B`J
M($!C871E9V]R>2`@("!796(@4V5R=FEC97,*("H@0'!A8VMA9V4@("`@(%-E
M<G9I8V5S7U=E871H97(*("H@0&%U=&AO<B`@("`@($%L97AA;F1E<B!7:7)T
M>B`\86QE>$!P8S1P+FYE=#X*("H@0&-O<'ER:6=H="`@(#(P,#4@06QE>&%N
M9&5R(%=I<G1Z"B`J($!L:6-E;G-E("`@("!H='1P.B\O=W=W+F]P96YS;W5R
M8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*
M("H@0'9E<G-I;VX@("`@($-64SH@)$ED.B!G;&]B86QW96%T:&5R+6)A<VEC
M+G!H<"QV(#$N-2`R,#`U+S$Q+S`X(#$W.C4R.C0R(&5R=2!%>'`@)`H@*B!`
M;&EN:R`@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U-E<G9I
M8V5S7U=E871H97(*("H@0&9I;&5S;W5R8V4*("HO"@IR97%U:7)E7V]N8V4@
M(E-E<G9I8V5S+U=E871H97(N<&AP(CL*"B\O($]B:F5C="!I;FET:6%L:7IA
M=&EO;B`M(&5R<F]R(&-H96-K:6YG(&ES(&EM<&]R=&%N="P@8F5C875S92!O
M9@HO+R!H86YD;&EN9R!E>&-E<'1I;VYS('-U8V@@87,@;6ES<VEN9R!014%2
M(&UO9'5L97,@;W(@;F]T(&)E:6YG(&]N;&EN90HD9VQO8F%L=V5A=&AE<B`]
M("9397)V:6-E<U]796%T:&5R.CIS97)V:6-E*")';&]B86Q796%T:&5R(BP@
M87)R87DH(F1E8G5G(B`]/B`R*2D["FEF("A397)V:6-E<U]796%T:&5R.CII
M<T5R<F]R*"1G;&]B86QW96%T:&5R*2D@>PH@("`@9&EE*")%<G)O<CH@(BXD
M9VQO8F%L=V5A=&AE<BT^9V5T365S<V%G92@I+B)<;B(I.PI]"@HO*B!%<F%S
M92!C;VUM96YT<R!T;R!E;F%B;&4@8V%C:&EN9PHD<W1A='5S(#T@)&=L;V)A
M;'=E871H97(M/G-E=$-A8VAE*")F:6QE(BP@87)R87DH(F-A8VAE7V1I<B(@
M/3X@(B]T;7`O8V%C:&4O(BDI.PII9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%
M<G)O<B@D<W1A='5S*2D@>PH@("`@96-H;R`B17)R;W(Z("(N)'-T871U<RT^
M9V5T365S<V%G92@I+B)<;B(["GT**B\*"B1G;&]B86QW96%T:&5R+3YS9715
M;FET<T9O<FUA="@B;65T<FEC(BD["B1G;&]B86QW96%T:&5R+3YS971$871E
M5&EM949O<FUA="@B9"YM+EDB+"`B2#II(BD["@HO+R!&:7)S="!G970@8V]D
M92!F;W(@;&]C871I;VX*)'-E87)C:"`]("1G;&]B86QW96%T:&5R+3YS96%R
M8VA,;V-A=&EO;B@B2V]E;&X@+R!";VYN(BD["FEF("A397)V:6-E<U]796%T
M:&5R.CII<T5R<F]R*"1S96%R8V@I*2!["B`@("!D:64H(D5R<F]R.B`B+B1S
M96%R8V@M/F=E=$UE<W-A9V4H*2XB7&XB*3L*?0H*+R\@3F]W(&ET97)A=&4@
M=&AR;W5G:"!A=F%I;&%B;&4@9G5N8W1I;VYS(&9O<B!R971R:65V:6YG(&1A
M=&$*9F]R96%C:"`H87)R87DH(F=E=$QO8V%T:6]N(BP@(F=E=%=E871H97(B
M+"`B9V5T1F]R96-A<W0B*2!A<R`D9G5N8W1I;VXI('L*("`@("1D871A(#T@
M)&=L;V)A;'=E871H97(M/B1F=6YC=&EO;B@D<V5A<F-H*3L*("`@(&EF("A3
M97)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1D871A*2D@>PH@("`@("`@(&5C
M:&\@(D5R<F]R.B`B+B1D871A+3YG971-97-S86=E*"DN(EQN(CL*("`@("`@
M("!C;VYT:6YU93L*("`@('T*"B`@("!V87)?9'5M<"@D9&%T82D["GT*/SX*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+V1O8W,O6$U,7U5T:6P`````````````````````````````````
M````````````````````````````````````````````,#`P-S4U(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S`@,#(P-S<Q`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?571I;"]E>&%M<&QE
M<P``````````````````````````````````````````````````````````
M```````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q
M-30S,S<S,"`P,C(V,#<`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S
M+UA-3%]5=&EL+V5X86UP;&5S+V5X86UP;&4R+G!H<```````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`U-S`U(#$P-3$U-#,S-S,P(#`R-3$R,P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/U!(4`T*+RHJ#0H@*B!S
M979E<F%L(&5X86UP;&5S(&9O<B!T:&4@;65T:&]D<R!O9B!834Q?571I;`T*
M("H-"B`J("1)9#H@97AA;7!L93(N<&AP+'8@,2XX(#(P,#0O,#8O,C<@,3@Z
M,3<Z,SD@<V-H<W0@17AP("0-"B`J#0H@*B!`875T:&]R("`@("`@4W1E<&AA
M;B!38VAM:61T#0H@*B!`<&%C:V%G92`@("`@6$U,7U5T:6P-"B`J($!S=6)P
M86-K86=E("!E>&%M<&QE<PT*("H@0&-A=&5G;W)Y("`@(%A-3`T*("HO#0H@
M("`@97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L-"@T*("`@(')E<75I<F5?;VYC
M92`G6$U,+U5T:6PN<&AP)SL-"@T*("`@("\J*@T*("`@("H@8W)E871I;F<@
M82!S=&%R="!E;&5M96YT#0H@("`@*B\-"B`@("!P<FEN="`B8W)E871I;F<@
M82!S=&%R="!E;&5M96YT.CQB<CXB.PT*("`@('!R:6YT(&AT;6QE;G1I=&EE
M<RA834Q?571I;#HZ8W)E871E4W1A<G1%;&5M96YT*")M>4YS.FUY5&%G(BP@
M87)R87DH(F9O;R(@/3X@(F)A<B(I+"`B:'1T<#HO+W=W=RYW,V,N;W)G+VUY
M3G,C(BDI.PT*("`@('!R:6YT(")<;CQB<CX\8G(^7&XB.PT*#0H-"B`@("`O
M*BH-"B`@("`J(&-R96%T:6YG(&$@<W1A<G0@96QE;65N=`T*("`@("HO#0H@
M("`@<')I;G0@(F-R96%T:6YG(&$@<W1A<G0@96QE;65N=#H\8G(^(CL-"B`@
M("!P<FEN="!H=&UL96YT:71I97,H6$U,7U5T:6PZ.F-R96%T95-T87)T16QE
M;65N="@B;7E486<B+"!A<G)A>2@I+"`B:'1T<#HO+W=W=RYW,V,N;W)G+VUY
M3G,C(BDI.PT*("`@('!R:6YT(")<;CQB<CX\8G(^7&XB.PT*#0H@("`@+RHJ
M#0H@("`@*B!C<F5A=&EN9R!A('-T87)T(&5L96UE;G0-"B`@("`J+PT*("`@
M('!R:6YT(")C<F5A=&EN9R!A('-T87)T(&5L96UE;G0Z/&)R/B([#0H@("`@
M<')I;G0@(CQP<F4^(CL-"B`@("!P<FEN="!H=&UL96YT:71I97,H6$U,7U5T
M:6PZ.F-R96%T95-T87)T16QE;65N="@B;7E486<B+"!A<G)A>2@@(F9O;R(@
M/3X@(F)A<B(L(")A<F=H(B`]/B`B=&]M871O(B`I+"`B:'1T<#HO+W=W=RYW
M,V,N;W)G+VUY3G,C(BP@=')U92DI.PT*("`@('!R:6YT("(\+W!R93XB.PT*
M("`@('!R:6YT(")<;CQB<CX\8G(^7&XB.PT*#0H-"B`@("`O*BH-"B`@("`J
M(&-R96%T:6YG(&%N(&5N9"!E;&5M96YT#0H@("`@*B\-"B`@("!P<FEN="`B
M8W)E871I;F<@86X@96YD(&5L96UE;G0Z/&)R/B([#0H@("`@<')I;G0@:'1M
M;&5N=&ET:65S*%A-3%]5=&EL.CIC<F5A=&5%;F1%;&5M96YT*")M>4YS.FUY
M5&%G(BDI.PT*("`@('!R:6YT(")<;CQB<CX\8G(^7&XB.PT*#0H@("`@+RHJ
M#0H@("`@*B!C<F5A=&EN9R!A($-$871A('-E8W1I;VX-"B`@("`J+PT*("`@
M('!R:6YT(")C<F5A=&EN9R!A($-$871A('-E8W1I;VXZ/&)R/B([#0H@("`@
M<')I;G0@:'1M;&5N=&ET:65S*%A-3%]5=&EL.CIC<F5A=&5#1&%T85-E8W1I
M;VXH(DD@86T@8V]N=&5N="XB*2D[#0H@("`@<')I;G0@(EQN/&)R/CQB<CY<
M;B([#0H-"B`@("`O*BH-"B`@("`J(&-R96%T:6YG(&$@8V]M;65N=`T*("`@
M("HO#0H@("`@<')I;G0@(F-R96%T:6YG(&$@8V]M;65N=#H\8G(^(CL-"B`@
M("!P<FEN="!H=&UL96YT:71I97,H6$U,7U5T:6PZ.F-R96%T94-O;6UE;G0H
M(DD@86T@82!C;VUM96YT+B(I*3L-"B`@("!P<FEN="`B7&X\8G(^/&)R/EQN
M(CL-"@T*("`@("\J*@T*("`@("H@8W)E871I;F<@86X@6$U,('1A9R!W:71H
M(&UU;'1I;&EN92!M;V1E#0H@("`@*B\-"B`@("`D=&%G(#T@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`B<6YA;64B("`@("`@("`]/B`B9F]O.F)A<B(L
M#0H@("`@("`@("`@("`@("`@("`B;F%M97-P86-E57)I(B`]/B`B:'1T<#HO
M+V9O;RYC;VTB+`T*("`@("`@("`@("`@("`@("`@(F%T=')I8G5T97,B("`@
M/3X@87)R87DH(")K97DB(#T^(")V86QU92(L(")A<F=H(B`]/B`B9G)U:70F
M=F5G971A8FQE(B`I+`T*("`@("`@("`@("`@("`@("`@(F-O;G1E;G0B("`@
M("`@/3X@(DDG;2!I;G-I9&4@=&AE('1A9R`F(&-O;G1A:6X@9&%N9V5R;W5S
M(&-H87)S(@T*("`@("`@("`@("`@("`@("D[#0H-"B`@("!P<FEN="`B8W)E
M871I;F<@82!T86<@=VET:"!Q=6%L:69I960@;F%M92!A;F0@;F%M97-P86-E
M57)I.CQB<CY<;B([#0H@("`@<')I;G0@(CQP<F4^(CL-"B`@("!P<FEN="!H
M=&UL96YT:71I97,H6$U,7U5T:6PZ.F-R96%T951A9T9R;VU!<G)A>2@D=&%G
M+"!834Q?551)3%]215!,04-%7T5.5$E42453+"!T<G5E*2D[#0H@("`@<')I
M;G0@(CPO<')E/B([#0H@("`@<')I;G0@(EQN/&)R/CQB<CY<;B([#0H-"B`@
M("`O*BH-"B`@("`J(&-R96%T92!A;B!A='1R:6)U=&4@<W1R:6YG('=I=&AO
M=70@<F5P;&%C:6YG('1H92!E;G1I=&EE<PT*("`@("HO#0H@("`@)&%T=',@
M/2!A<G)A>2@@)W-E<FEE<R<@/3X@)U-T87)S:WD@)F%M<#L@2'5T8V@G+"`G
M8VAA;FYE;"<@/3X@)T%"0R<@*3L-"B`@("!P<FEN="`B8W)E871I;F<@82!A
M='1R:6)U=&4@<W1R:6YG+"!E;G1I=&EE<R!I;B!V86QU97,@86QR96%D>2!H
M860@8F5E;B!R97!L86-E9#H\8G(^(CL-"B`@("!P<FEN="!H=&UL96YT:71I
M97,H6$U,7U5T:6PZ.F%T=')I8G5T97-4;U-T<FEN9R@D871T<RP@=')U92P@
M9F%L<V4L(&9A;'-E+"!F86QS92P@6$U,7U5424Q?14Y4251)15-?3D].12DI
M.PT*("`@('!R:6YT(")<;CQB<CX\8G(^7&XB.PT*#0H@("`@+RHJ#0H@("`@
M*B!U<VEN9R!T:&4@87)R87DM<WEN=&%X(&9O<B!A='1R:6)U=&5S5&]3=')I
M;F<H*0T*("`@("HO#0H@("`@)&%T=',@/2!A<G)A>2@@)W-E<FEE<R<@/3X@
M)U-T87)S:WD@)F%M<#L@2'5T8V@G+"`G8VAA;FYE;"<@/3X@)T%"0R<@*3L-
M"B`@("!P<FEN="`B=7-I;F<@=&AE(&%R<F%Y+7-Y;G1A>"!F;W(@871T<FEB
M=71E<U1O4W1R:6YG*"D\8G(^(CL-"B`@("!P<FEN="!H=&UL96YT:71I97,H
M6$U,7U5T:6PZ.F%T=')I8G5T97-4;U-T<FEN9R@D871T<RP@87)R87DH)V5N
M=&ET:65S)R`]/B!834Q?551)3%]%3E1)5$E%4U].3TY%*2DI.PT*("`@('!R
M:6YT(")<;CQB<CX\8G(^7&XB.PT*#0H-"C\^````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U5T:6PO97AA;7!L
M97,O97AA;7!L92YP:'``````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,38P-C`@,3`U
M,34T,S,W,S`@,#(U,#,U`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_4$A0#0HO*BH-"B`J('-E=F5R86P@97AA;7!L97,@
M9F]R('1H92!M971H;V1S(&]F(%A-3%]5=&EL#0H@*@T*("H@)$ED.B!E>&%M
M<&QE+G!H<"QV(#$N,3(@,C`P-"\Q,B\R,R`Q,SHR,CHP,"!S8VAS="!%>'`@
M)`T*("H-"B`J($!A=71H;W(@("`@("!3=&5P:&%N(%-C:&UI9'0-"B`J($!P
M86-K86=E("`@("!834Q?571I;`T*("H@0'-U8G!A8VMA9V4@(&5X86UP;&5S
M#0H@*B!`8V%T96=O<GD@("`@6$U,#0H@*B\-"B`@("!E<G)O<E]R97!O<G1I
M;F<H15]!3$PI.PT*#0H@("`@<F5Q=6ER95]O;F-E("=834PO571I;"YP:'`G
M.PT*("`@(`T*("`@("\J*@T*("`@("H@<F5P;&%C:6YG(%A-3"!E;G1I=&EE
M<PT*("`@("HO#0H@("`@<')I;G0@(G)E<&QA8V4@6$U,(&5N=&ET:65S.CQB
M<CY<;B([#0H@("`@<')I;G0@6$U,7U5T:6PZ.G)E<&QA8V5%;G1I=&EE<R@B
M5&AI<R!S=')I;F<@8V]N=&%I;G,@/"`F(#XN(BD[#0H@("`@<')I;G0@(EQN
M/&)R/CQB<CY<;B([#0H-"B`@("`O*BH-"B`@("`J(')E=F5R<VEN9R!834P@
M96YT:71I97,-"B`@("`J+PT*("`@('!R:6YT(")R97!L86-E(%A-3"!E;G1I
M=&EE<SH\8G(^7&XB.PT*("`@('!R:6YT(%A-3%]5=&EL.CIR979E<G-E16YT
M:71I97,H(E1H:7,@<W1R:6YG(&-O;G1A:6YS("9L=#L@)F%M<#L@)F=T.RXB
M*3L-"B`@("!P<FEN="`B7&X\8G(^/&)R/EQN(CL-"@T*("`@("\J*@T*("`@
M("H@8G5I;&1I;F<@6$U,(&1E8VQA<F%T:6]N#0H@("`@*B\-"B`@("!P<FEN
M="`B8G5I;&1I;F<@6$U,(&1E8VQA<F%T:6]N.CQB<CY<;B([#0H@("`@<')I
M;G0@:'1M;'-P96-I86QC:&%R<RA834Q?571I;#HZ9V5T6$U,1&5C;&%R871I
M;VXH*2D[#0H@("`@<')I;G0@(EQN/&)R/CQB<CY<;B([#0H-"B`@("!P<FEN
M="`B8G5I;&1I;F<@6$U,(&1E8VQA<F%T:6]N('=I=&@@861D:71I;VYA;"!A
M='1R:6)U=&5S.CQB<CXB.PT*("`@('!R:6YT(&AT;6QS<&5C:6%L8VAA<G,H
M6$U,7U5T:6PZ.F=E=%A-3$1E8VQA<F%T:6]N*"(Q+C`B+"`B551&+3@B+"!T
M<G5E*2D[#0H@("`@<')I;G0@(EQN/&)R/CQB<CY<;B([#0H-"B`@("`O*BH-
M"B`@("`J(&)U:6QD:6YG(&1O8W5M96YT('1Y<&4@9&5C;&%R871I;VX-"B`@
M("`J+PT*("`@('!R:6YT(")B=6EL9&EN9R!$;V-4>7!E(&1E8VQA<F%T:6]N
M.CQB<CY<;B([#0H@("`@<')I;G0@:'1M;'-P96-I86QC:&%R<RA834Q?571I
M;#HZ9V5T1&]C5'EP941E8VQA<F%T:6]N*"=P86-K86=E)RP@)VAT='`Z+R]P
M96%R+G!H<"YN970O9'1D+W!A8VMA9V4M,2XP)RDI.PT*("`@('!R:6YT(")<
M;CQB<CX\8G(^7&XB.PT*#0H@("`@<')I;G0@(F)U:6QD:6YG($1O8U1Y<&4@
M9&5C;&%R871I;VX@=VET:"!P=6)L:6,@240@*&1O97,@;F]T(&5X:7-T*3H\
M8G(^7&XB.PT*("`@('!R:6YT(&AT;6QS<&5C:6%L8VAA<G,H6$U,7U5T:6PZ
M.F=E=$1O8U1Y<&5$96-L87)A=&EO;B@G<&%C:V%G92<L(&%R<F%Y*"=U<FDG
M(#T^("=H='1P.B\O<&5A<BYP:'`N;F5T+V1T9"]P86-K86=E+3$N,"<L("=I
M9"<@/3X@)RTO+U!(4"\O4$5!4B]$5$0@4$%#2T%'12`P+C$G*2DI.PT*("`@
M('!R:6YT(")<;CQB<CX\8G(^7&XB.PT*#0H@("`@<')I;G0@(F)U:6QD:6YG
M($1O8U1Y<&4@9&5C;&%R871I;VX@=VET:"!I;G1E<FYA;"!$5$0Z/&)R/EQN
M(CL-"B`@("!P<FEN="`B/'!R93XB.PT*("`@('!R:6YT(&AT;6QS<&5C:6%L
M8VAA<G,H6$U,7U5T:6PZ.F=E=$1O8U1Y<&5$96-L87)A=&EO;B@G<&%C:V%G
M92<L("=H='1P.B\O<&5A<BYP:'`N;F5T+V1T9"]P86-K86=E+3$N,"<L("<\
M(45,14U%3E0@861D:71I;VYA;$EN9F\@*"-00T1!5$$I/B<I*3L-"B`@("!P
M<FEN="`B/"]P<F4^(CL-"B`@("!P<FEN="`B7&X\8G(^/&)R/EQN(CL-"@T*
M("`@("\J*@T*("`@("H@8W)E871I;F<@86X@871T<FEB=71E('-T<FEN9PT*
M("`@("HO#0H@("`@)&%T="`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@
M(F9O;R(@("`]/B`@(F)A<B(L#0H@("`@("`@("`@("`@("`@("`B87)G:"(@
M(#T^("`B=&]M871O(@T*("`@("`@("`@("`@("`@("D[#0H-"B`@("!P<FEN
M="`B8V]N=F5R=&EN9R!A<G)A>2!T;R!S=')I;F<Z/&)R/EQN(CL-"B`@("!P
M<FEN="!834Q?571I;#HZ871T<FEB=71E<U1O4W1R:6YG*"1A='0I.PT*("`@
M('!R:6YT(")<;CQB<CX\8G(^7&XB.PT*#0H-"B`@("`O*BH-"B`@("`J(&-R
M96%T:6YG(&%N(&%T=')I8G5T92!S=')I;F<@=VET:"!L:6YE8G)E86MS#0H@
M("`@*B\-"B`@("`D871T(#T@87)R87DH#0H@("`@("`@("`@("`@("`@("`B
M9F]O(B`@(#T^("`B8F%R(BP-"B`@("`@("`@("`@("`@("`@(")A<F=H(B`@
M/3X@(")T;VUA=&\B#0H@("`@("`@("`@("`@("`@*3L-"@T*("`@('!R:6YT
M(")C;VYV97)T:6YG(&%R<F%Y('1O('-T<FEN9R`H:6YC;'5D:6YG(&QI;F4@
M8G)E86MS*3H\8G(^7&XB.PT*("`@('!R:6YT("(\<')E/B([#0H@("`@<')I
M;G0@6$U,7U5T:6PZ.F%T=')I8G5T97-4;U-T<FEN9R@D871T+"!T<G5E+"!T
M<G5E*3L-"B`@("!P<FEN="`B/"]P<F4^(CL-"B`@("!P<FEN="`B7&X\8G(^
M/&)R/EQN(CL-"@T*#0H@("`@+RHJ#0H@("`@*B!S<&QI='1I;F<@82!Q=6%L
M:69I960@=&%G(&YA;64-"B`@("`J+PT*("`@('!R:6YT(")S<&QI='1I;F<@
M<75A;&EF:65D('1A9R!N86UE.CQB<CY<;B([#0H@("`@<')I;G0@(CQP<F4^
M(CL-"B`@("!P<FEN=%]R*%A-3%]5=&EL.CIS<&QI=%%U86QI9FEE9$YA;64H
M(GAS;'0Z<W1Y;&5S:&5E="(I*3L-"B`@("!P<FEN="`B/"]P<F4^(CL-"B`@
M("!P<FEN="`B7&X\8G(^7&XB.PT*#0H-"B`@("`O*BH-"B`@("`J('-P;&ET
M=&EN9R!A('%U86QI9FEE9"!T86<@;F%M92`H;F\@;F%M97-P86-E*0T*("`@
M("HO#0H@("`@<')I;G0@(G-P;&ET=&EN9R!Q=6%L:69I960@=&%G(&YA;64@
M*&YO(&YA;65S<&%C92DZ/&)R/EQN(CL-"B`@("!P<FEN="`B/'!R93XB.PT*
M("`@('!R:6YT7W(H6$U,7U5T:6PZ.G-P;&ET475A;&EF:65D3F%M92@B9F]O
M(BDI.PT*("`@('!R:6YT("(\+W!R93XB.PT*("`@('!R:6YT(")<;CQB<CY<
M;B([#0H-"B`@("`O*BH-"B`@("`J('-P;&ET=&EN9R!A('%U86QI9FEE9"!T
M86<@;F%M92`H;F\@;F%M97-P86-E+"!B=70@9&5F875L="!N86UE<W!A8V4@
M<W!E8VEF:65D*0T*("`@("HO#0H@("`@<')I;G0@(G-P;&ET=&EN9R!Q=6%L
M:69I960@=&%G(&YA;64@*&YO(&YA;65S<&%C92P@8G5T(&1E9F%U;'0@;F%M
M97-P86-E('-P96-I9FEE9"DZ/&)R/EQN(CL-"B`@("!P<FEN="`B/'!R93XB
M.PT*("`@('!R:6YT7W(H6$U,7U5T:6PZ.G-P;&ET475A;&EF:65D3F%M92@B
M9F]O(BP@(F)A<B(I*3L-"B`@("!P<FEN="`B/"]P<F4^(CL-"B`@("!P<FEN
M="`B7&X\8G(^7&XB.PT*#0H@("`@+RHJ#0H@("`@*B!V97)I9GEI;F<@6$U,
M(&YA;65S#0H@("`@*B\-"B`@("!P<FEN="`B=F5R:69Y:6YG("=->2!P<FEV
M871E('1A9R<Z/&)R/EQN(CL-"B`@("!P<FEN="`B/'!R93XB.PT*("`@('!R
M:6YT7W(H6$U,7U5T:6PZ.FES5F%L:61N86UE*"=->2!0<FEV871E(%1A9R<I
M*3L-"B`@("!P<FEN="`B/"]P<F4^(CL-"B`@("!P<FEN="`B7&X\8G(^/&)R
M/EQN(CL-"B`@("`-"B`@("!P<FEN="`B=F5R:69Y:6YG("<M37E486<G.CQB
M<CY<;B([#0H@("`@<')I;G0@(CQP<F4^(CL-"B`@("!P<FEN=%]R*%A-3%]5
M=&EL.CII<U9A;&ED;F%M92@G+4UY5&%G)RDI.PT*("`@('!R:6YT("(\+W!R
M93XB.PT*("`@('!R:6YT(")<;CQB<CX\8G(^7&XB.PT*#0H@("`@+RHJ#0H@
M("`@*B!C<F5A=&EN9R!A;B!834P@=&%G#0H@("`@*B\-"B`@("`D=&%G(#T@
M87)R87DH#0H@("`@("`@("`@("`@("`@("`B;F%M97-P86-E(B`@(#T^(")F
M;V\B+`T*("`@("`@("`@("`@("`@("`@(FQO8V%L4&%R="(@("`]/B`B8F%R
M(BP-"B`@("`@("`@("`@("`@("`@(")A='1R:6)U=&5S(B`@/3X@87)R87DH
M(")K97DB(#T^(")V86QU92(L(")A<F=H(B`]/B`B9G)U:70F=F5G971A8FQE
M(B`I+`T*("`@("`@("`@("`@("`@("`@(F-O;G1E;G0B("`@("`]/B`B22=M
M(&EN<VED92!T:&4@=&%G(@T*("`@("`@("`@("`@("`@("D[#0H-"B`@("!P
M<FEN="`B8W)E871I;F<@82!T86<@=VET:"!N86UE<W!A8V4@86YD(&QO8V%L
M('!A<G0Z/&)R/B([#0H@("`@<')I;G0@:'1M;&5N=&ET:65S*%A-3%]5=&EL
M.CIC<F5A=&5486=&<F]M07)R87DH)'1A9RDI.PT*("`@('!R:6YT(")<;CQB
M<CX\8G(^7&XB.PT*#0H@("`@+RHJ#0H@("`@*B!C<F5A=&EN9R!A;B!834P@
M=&%G#0H@("`@*B\-"B`@("`D=&%G(#T@87)R87DH#0H@("`@("`@("`@("`@
M("`@("`B<6YA;64B("`@("`@("`]/B`B9F]O.F)A<B(L#0H@("`@("`@("`@
M("`@("`@("`B;F%M97-P86-E57)I(B`]/B`B:'1T<#HO+V9O;RYC;VTB+`T*
M("`@("`@("`@("`@("`@("`@(F%T=')I8G5T97,B("`@/3X@87)R87DH(")K
M97DB(#T^(")V86QU92(L(")A<F=H(B`]/B`B9G)U:70F=F5G971A8FQE(B`I
M+`T*("`@("`@("`@("`@("`@("`@(F-O;G1E;G0B("`@("`@/3X@(DDG;2!I
M;G-I9&4@=&AE('1A9R(-"B`@("`@("`@("`@("`@("`I.PT*#0H@("`@<')I
M;G0@(F-R96%T:6YG(&$@=&%G('=I=&@@<75A;&EF:65D(&YA;64@86YD(&YA
M;65S<&%C955R:3H\8G(^7&XB.PT*("`@('!R:6YT(&AT;6QE;G1I=&EE<RA8
M34Q?571I;#HZ8W)E871E5&%G1G)O;4%R<F%Y*"1T86<I*3L-"B`@("!P<FEN
M="`B7&X\8G(^/&)R/EQN(CL-"@T*("`@("\J*@T*("`@("H@8W)E871I;F<@
M86X@6$U,('1A9PT*("`@("HO#0H@("`@)'1A9R`](&%R<F%Y*`T*("`@("`@
M("`@("`@("`@("`@(G%N86UE(B`@("`@("`@/3X@(F)A<B(L#0H@("`@("`@
M("`@("`@("`@("`B;F%M97-P86-E57)I(B`]/B`B:'1T<#HO+V9O;RYC;VTB
M+`T*("`@("`@("`@("`@("`@("`@(F%T=')I8G5T97,B("`@/3X@87)R87DH
M(")K97DB(#T^(")V86QU92(L(")A<F=H(B`]/B`B9G)U:70F=F5G971A8FQE
M(B`I#0H@("`@("`@("`@("`@("`@*3L-"@T*("`@('!R:6YT(")C<F5A=&EN
M9R!A;B!E;7!T>2!T86<@=VET:&]U="!N86UE<W!A8V4@8G5T(&YA;65S<&%C
M92!5<FDZ/&)R/EQN(CL-"B`@("!P<FEN="!H=&UL96YT:71I97,H6$U,7U5T
M:6PZ.F-R96%T951A9T9R;VU!<G)A>2@D=&%G*2D[#0H@("`@<')I;G0@(EQN
M/&)R/CQB<CY<;B([#0H-"B`@("`O*BH-"B`@("`J(&-R96%T:6YG(&%N(%A-
M3"!T86<@=VET:"!A($-$871A(%-E8W1I;VX-"B`@("`J+PT*("`@("1T86<@
M/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@(")Q;F%M92(@("`@("`@(#T^
M(")F;V\B+`T*("`@("`@("`@("`@("`@("`@(F%T=')I8G5T97,B("`@/3X@
M87)R87DH(")K97DB(#T^(")V86QU92(L(")A<F=H(B`]/B`B9G)U:70F=F5G
M971A8FQE(B`I+`T*("`@("`@("`@("`@("`@("`@(F-O;G1E;G0B("`@("`@
M/3X@(DDG;2!I;G-I9&4@=&AE('1A9R(-"B`@("`@("`@("`@("`@("`I.PT*
M#0H@("`@<')I;G0@(F-R96%T:6YG(&$@=&%G('=I=&@@0T1A=&$@<V5C=&EO
M;CH\8G(^7&XB.PT*("`@('!R:6YT(&AT;6QE;G1I=&EE<RA834Q?571I;#HZ
M8W)E871E5&%G1G)O;4%R<F%Y*"1T86<L(%A-3%]55$E,7T-$051!7U-%0U1)
M3TXI*3L-"B`@("!P<FEN="`B7&X\8G(^/&)R/EQN(CL-"@T*("`@("\J*@T*
M("`@("H@8W)E871I;F<@86X@6$U,('1A9R!W:71H(&$@0T1A=&$@4V5C=&EO
M;@T*("`@("HO#0H@("`@)'1A9R`](&%R<F%Y*`T*("`@("`@("`@("`@("`@
M("`@(G%N86UE(B`@("`@("`@/3X@(F9O;R(L#0H@("`@("`@("`@("`@("`@
M("`B871T<FEB=71E<R(@("`]/B!A<G)A>2@@(FME>2(@/3X@(G9A;'5E(BP@
M(F%R9V@B(#T^(")T_'3\(B`I+`T*("`@("`@("`@("`@("`@("`@(F-O;G1E
M;G0B("`@("`@/3X@(D%L<V\@6$A434PM=&%G<R!C86X@8F4@8W)E871E9"!A
M;F0@2%1-3"!E;G1I=&EE<R!C86X@8F4@<F5P;&%C960@Q"#D(-P@]B`\/BXB
M#0H@("`@("`@("`@("`@("`@*3L-"@T*("`@('!R:6YT(")C<F5A=&EN9R!A
M('1A9R!W:71H($A434P@96YT:71I97,Z/&)R/EQN(CL-"B`@("!P<FEN="!H
M=&UL96YT:71I97,H6$U,7U5T:6PZ.F-R96%T951A9T9R;VU!<G)A>2@D=&%G
M+"!834Q?551)3%]%3E1)5$E%4U](5$U,*2D[#0H@("`@<')I;G0@(EQN/&)R
M/CQB<CY<;B([#0H-"B`@("`O*BH-"B`@("`J(&-R96%T:6YG(&%N(%A-3"!T
M86<@=VET:"!C<F5A=&5486<-"B`@("`J+PT*("`@('!R:6YT(")C<F5A=&EN
M9R!A('1A9R!W:71H(&-R96%T951A9SH\8G(^(CL-"B`@("!P<FEN="!H=&UL
M96YT:71I97,H6$U,7U5T:6PZ.F-R96%T951A9R@B;7E.<SIM>51A9R(L(&%R
M<F%Y*")F;V\B(#T^(")B87(B*2P@(E1H:7,@:7,@:6YS:61E('1H92!T86<B
M+"`B:'1T<#HO+W=W=RYW,V,N;W)G+VUY3G,C(BDI.PT*("`@('!R:6YT(")<
M;CQB<CX\8G(^7&XB.PT*#0H@("`@#0H@("`@+RHJ#0H@("`@*B!T<GEI;F<@
M=&\@8W)E871E(&%N(%A-3"!T86<@=VET:"!A;B!A<G)A>2!A<R!C;VYT96YT
M#0H@("`@*B\-"B`@("`D=&%G(#T@87)R87DH#0H@("`@("`@("`@("`@("`@
M("`B<6YA;64B("`@("`@("`]/B`B8F%R(BP-"B`@("`@("`@("`@("`@("`@
M(")C;VYT96YT(B`@("`@(#T^(&%R<F%Y*"`B9F]O(B`]/B`B8F%R(B`I#0H@
M("`@("`@("`@("`@("`@*3L-"B`@("!P<FEN="`B=')Y:6YG('1O(&-R96%T
M92!A;B!834P@=&%G('=I=&@@86X@87)R87D@87,@8V]N=&5N=#H\8G(^7&XB
M.PT*("`@('!R:6YT("(\<')E/B([#0H@("`@<')I;G1?<BA834Q?571I;#HZ
M8W)E871E5&%G1G)O;4%R<F%Y*"1T86<I*3L-"B`@("!P<FEN="`B/"]P<F4^
M(CL-"B`@("!P<FEN="`B7&X\8G(^/&)R/EQN(CL-"B`@("`-"B`@("`O*BH-
M"B`@("`J('1R>6EN9R!T;R!C<F5A=&4@86X@6$U,('1A9R!W:71H;W5T(&$@
M;F%M90T*("`@("HO#0H@("`@)'1A9R`](&%R<F%Y*`T*("`@("`@("`@("`@
M("`@("`@(F%T=')I8G5T97,B("`@/3X@87)R87DH(")F;V\B(#T^(")B87(B
M("DL#0H@("`@("`@("`@("`@("`@*3L-"B`@("!P<FEN="`B=')Y:6YG('1O
M(&-R96%T92!A;B!834P@=&%G('=I=&AO=70@82!N86UE.CQB<CY<;B([#0H@
M("`@<')I;G0@(CQP<F4^(CL-"B`@("!P<FEN=%]R*%A-3%]5=&EL.CIC<F5A
M=&5486=&<F]M07)R87DH)'1A9RDI.PT*("`@('!R:6YT("(\+W!R93XB.PT*
M("`@('!R:6YT(")<;CQB<CX\8G(^7&XB.PT*/SX`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE
M<@``````````````````````````````````````````````````````````
M```````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q
M,#4Q-30S,S<S,"`P,C(Q-C4`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D
M;V-S+UA-3%]397)I86QI>F5R+V5X86UP;&5S````````````````````````
M`````````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S,P(#`R-#`P,P`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O
M<V5R:6%L:7IE06YD16YC;V1E+G!H<```````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(V,S8@,3`U,34T,S,W,S`@
M,#,P,S,R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_4$A0"B\J*@H@*B!%>&%M<&QE('1O(&1E;6]N<W1R871E('1H92!E
M;F-O9&5&=6YC=&EO;B!A;F0@9&5C;V1E1G5N8W1I;VX*("H@;W!T:6]N<RX*
M("H*("H@5&AI<R!A;&QO=W,@>6]U('1O(&%P<&QY(&-A;&QB86-K<R!T;R!Y
M;W5R(&1A=&$@=&AA="!I<R!C86QL960*("H@;VX@86QL('-T<FEN9W,@=VAI
M;&4@<V5R:6%L:7II;F<@86YD('5N<V5R:6%L:7II;F<N"B`J"B`J($!A=71H
M;W(@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P:'`N;F5T/@H@*B\*("`@(&5R
M<F]R7W)E<&]R=&EN9RA%7T%,3"D["@H@("`@<F5Q=6ER95]O;F-E("=834PO
M4V5R:6%L:7IE<BYP:'`G.PH@("`@<F5Q=6ER95]O;F-E("=834PO56YS97)I
M86QI>F5R+G!H<"<["@H@("`@)&]P=&EO;G,@/2!A<G)A>2@*("`@("`@("`@
M("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E])3D1%3E0@("`@
M("`@("`@("`@("`]/B`G("`@("<L"B`@("`@("`@("`@("`@("`@("`@("!8
M34Q?4T5224%,25I%4E]/4%1)3TY?3$E.14)214%+4R`@("`@("`@("`@/3X@
M(EQN(BP*("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]0
M5$E/3E]30T%,05)?05-?05144DE"551%4R`]/B!T<G5E+`H@("`@("`@("`@
M("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7T5.0T]$15]&54Y#
M("`@("`@("`@(#T^("=S=')T;W5P<&5R)PH@("`@("`@("`@("`@("`@("`@
M("D["B`@("`*("`@("1F;V\@/2!N97<@<W1D0VQA<W,H*3L*("`@("1F;V\M
M/F)A<B`](&YE=R!S=&1#;&%S<R@I.PH@("`@)&9O;RT^8F%R+3YT97-T("`]
M("=4:&ES(&ES(&$@=&5S="XG.PH@("`@)&9O;RT^8F%R+3YV86QU92`]("=4
M:&ES(&ES(&$@=F%L=64N)SL*("`@(`H@("`@)'-E<FEA;&EZ97(@/2`F;F5W
M(%A-3%]397)I86QI>F5R*"1O<'1I;VYS*3L*("`@(`H@("`@)')E<W5L="`]
M("1S97)I86QI>F5R+3YS97)I86QI>F4H)&9O;RD["B`@("`*("`@(&EF("@D
M<F5S=6QT(#T]/2!T<G5E*2!["@D))'AM;"`]("1S97)I86QI>F5R+3YG9713
M97)I86QI>F5D1&%T82@I.PH@("`@?0H*("`@(&5C:&\)(CQP<F4^(CL*("`@
M('!R:6YT7W(H(&AT;6QS<&5C:6%L8VAA<G,H)'AM;"D@*3L*("`@(&5C:&\)
M(CPO<')E/B(["@H@("`@)'5N<V5R:6%L:7IE<B`]("9N97<@6$U,7U5N<V5R
M:6%L:7IE<B@I.PH@("`@)'5N<V5R:6%L:7IE<BT^<V5T3W!T:6]N*"=P87)S
M94%T=')I8G5T97,G+"!T<G5E*3L*("`@("1U;G-E<FEA;&EZ97(M/G-E=$]P
M=&EO;B@G9&5C;V1E1G5N8W1I;VXG+"`G<W1R=&]L;W=E<B<I.PH*("`@("1R
M97-U;'0@/2`D=6YS97)I86QI>F5R+3YU;G-E<FEA;&EZ92@D>&UL*3L*("`@
M(`H@("`@96-H;R`G/'!R93XG.PH@("`@<')I;G1?<B@D=6YS97)I86QI>F5R
M+3YG9715;G-E<FEA;&EZ961$871A*"DI.PH@("`@96-H;R`G/"]P<F4^)SL*
M/SX`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]8
M34Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S97)I86QI>F5!<G)A>5=I=&A/8FIE
M8W1S+G!H<``````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,C,W,B`Q,#4Q-30S,S<S,"`P,S$W,S,`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]02%`*+RHJ"B`J(%1H:7,@
M97AA;7!L92!S:&]W<R!H;W<@=&\@8W)E871E(&%N(%)$1B!D;V-U;65N=`H@
M*B!W:71H(&$@9F5W(&QI;F5S(&]F(&-O9&4N"B`J(%1H:7,@8V%N(&%L<V\@
M8F4@9&]N92!W:71H(&UO9&4@/3X@<VEM<&QE>&UL"B`J"B`J($!A=71H;W(@
M4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P:'`N;F5T/@H@*B!`<V5E("`@('-E
M<FEA;&EZ94EN9&5X961!<G)A>2YP:'`*("HO"B`@("!E<G)O<E]R97!O<G1I
M;F<H15]!3$PI.PH*("`@(')E<75I<F5?;VYC92`G6$U,+U-E<FEA;&EZ97(N
M<&AP)SL*"B`@("`D;W!T:6]N<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@
M("`@("`@("`B:6YD96YT(B`@("`@("`@("`]/B`B("`@("(L"B`@("`@("`@
M("`@("`@("`@("`@("`@(")L:6YE8G)E86LB("`@("`@(#T^(")<;B(L"B`@
M("`@("`@("`@("`@("`@("`@("`@(")T>7!E2&EN=',B("`@("`@(#T^(&9A
M;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`B861D1&5C;"(@("`@("`@
M("`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`B96YC;V1I;F<B
M("`@("`@("`]/B`B551&+3@B"B`@("`@("`@("`@("`@("`@("`@*3L*("`@
M(`H@("`@)'-E<FEA;&EZ97(@/2!N97<@6$U,7U-E<FEA;&EZ97(H)&]P=&EO
M;G,I.PH*("`@("1S97)I86QI>F5R+3YS971%<G)O<DAA;F1L:6YG*%!%05)?
M15)23U)?1$E%*3L*("`@(`H@("`@)&%R<F%Y(#T@87)R87DH"B`@("`@("`@
M("`@("`@("`@("`@;F5W('-T9$-L87-S*"DL"B`@("`@("`@("`@("`@("`@
M("`@;F5W('-T9$-L87-S*"D*("`@("`@("`@("`@("`@("`@("`I.PH@("`@
M"B`@("`D<F5S=6QT(#T@)'-E<FEA;&EZ97(M/G-E<FEA;&EZ92@D87)R87DI
M.PH@("`@"B`@("!I9B@@)')E<W5L="`]/3T@=')U92`I('L*("`@("`@("!E
M8VAO("`@("(\<')E/B(["B`@("`@("`@96-H;R`@("!H=&UL96YT:71I97,H
M)'-E<FEA;&EZ97(M/F=E=%-E<FEA;&EZ961$871A*"DI.PH@("`@("`@(&5C
M:&\@("`@(CPO<')E/B(["B`@("!]"@H@("`@)')E<W5L="`]("1S97)I86QI
M>F5R+3YS97)I86QI>F4H)&%R<F%Y+"!A<G)A>2@@)V-L87-S07-486=.86UE
M)R`]/B!T<G5E("DI.PH@("`@"B`@("!I9B@@)')E<W5L="`]/3T@=')U92`I
M('L*("`@("`@("!E8VAO("`@("(\<')E/B(["B`@("`@("`@96-H;R`@("!H
M=&UL96YT:71I97,H)'-E<FEA;&EZ97(M/F=E=%-E<FEA;&EZ961$871A*"DI
M.PH@("`@("`@(&5C:&\@("`@(CPO<')E/B(["B`@("!]"B`@("`*/SX`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP;&5S
M+W-E<FEA;&EZ94-$871A+G!H<````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q-#<R(#$P-3$U-#,S-S,P
M(#`R-S0V,P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/U!(4`HO*BH*("H@6$U,(%-E<FEA;&EZ97(@97AA;7!L90H@*@H@
M*B!4:&ES(&5X86UP;&4@;6%K97,@=7-E(&]F('1H92!#1&%T82!S96-T:6]N
M<R!O<'1I;VX*("H*("H@0&%U=&AO<B`@4W1E<&AA;B!38VAM:61T(#QS8VAS
M=$!P:'`N;F5T/@H@*B\*97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L*<F5Q=6ER
M95]O;F-E("=834PO4V5R:6%L:7IE<BYP:'`G.PH*)'-E<FEA;&EZ97(@/2!N
M97<@6$U,7U-E<FEA;&EZ97(H*3L*)'-E<FEA;&EZ97(M/G-E=$]P=&EO;BA8
M34Q?4T5224%,25I%4E]/4%1)3TY?24Y$14Y4+"`G("`@("<I.PHD<V5R:6%L
M:7IE<BT^<V5T3W!T:6]N*%A-3%]315))04Q)6D527T]05$E/3E]$149!54Q4
M7U1!1RP@)VET96TG*3L*)'-E<FEA;&EZ97(M/G-E=$]P=&EO;BA834Q?4T52
M24%,25I%4E]/4%1)3TY?0T1!5$%?4T5#5$E/3E,L('1R=64I.PH*)&1A=&$@
M/2!A<G)A>2@*("`@("`@("`@("`G9F]O)R`]/B`G5&AI<R!I<R!S;VUE('1E
M>'0N+BXG+`H@("`@("`@("`@("=B87(G(#T^("<F(&5V96X@;6]R92!T97AT
M+BXN)RP*("`@("`@("`@("`G=&5S="<@/3X@87)R87DH)T9O;R<L("=&;V\@
M)B!B87(G*0H)"0DI.PH*)')E<W5L="`]("1S97)I86QI>F5R+3YS97)I86QI
M>F4H)&1A=&$I.PH*:68H("1R97-U;'0@/3T]('1R=64@*2!["@DD>&UL(#T@
M)'-E<FEA;&EZ97(M/F=E=%-E<FEA;&EZ961$871A*"D["B`@("!E8VAO("<\
M<')E/B<["B`@("!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'AM;"D["B`@("!E
M8VAO("<\+W!R93XG.PI](&5L<V4@>PH@("`@)')E<W5L="T^9V5T365S<V%G
M92@I.PH@("`@97AI="@I.PI]"C\^````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X
M86UP;&5S+W-E<FEA;&EZ945M<'1Y07)R87DN<&AP````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,#8Q(#$P-3$U
M-#,S-S,P(#`S,#4W-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/U!(4`HO*BH*("H@5&AI<R!S:&]W<R!T:&%T(%A-3%]3
M97)I86QI>F5R(&ES(&%B;&4@=&\@=V]R:R!W:71H"B`J(&5M<'1Y(&%R<F%Y
M<PH@*@H@*B!`875T:&]R(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE
M=#X*("HO"F5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["G)E<75I<F5?;VYC92`G
M6$U,+U5N<V5R:6%L:7IE<BYP:'`G.PH*)'AM;"`](#P\/"!%3T8*/&%U=&]P
M86=E7V]P=&EO;G,@7V-L87-S/2)A=71O<&%G95]O<'1I;VYS(B`*7W1Y<&4]
M(F]B:F5C="(^"CQV97)S:6]N(%]T>7!E/2)S=')I;F<B/C$N,#PO=F5R<VEO
M;CX*/&]P=&EO;G,@7W1Y<&4](F%R<F%Y(B`O/@H\+V%U=&]P86=E7V]P=&EO
M;G,^"D5/1CL*"B1U;G-E<FEA;&EZ97(@/2!N97<@6$U,7U5N<V5R:6%L:7IE
M<B@I.PHD<F5S=6QT(#T@)'5N<V5R:6%L:7IE<BT^=6YS97)I86QI>F4H)'AM
M;"D["@II9B@@)')E<W5L="`]/3T@=')U92`I('L*("`@(&5C:&\@)SQP<F4^
M)SL*("`@('!R:6YT7W(H)'5N<V5R:6%L:7IE<BT^9V5T56YS97)I86QI>F5D
M1&%T82@I*3L*("`@(&5C:&\@)SPO<')E/B<["GT*/SX`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI
M>F5R+V5X86UP;&5S+W-E<FEA;&EZ94EN9&5X961!<G)A>2YP:'``````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S-S`U
M(#$P-3$U-#,S-S,P(#`S,3`V-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/U!(4`HO*BH*("H@5&AI<R!E>&%M<&QE(&1E
M;6]N<W1R871E<R!T:&4@=7-E(&]F"B`J(&UO9&4@/3X@<VEM<&QE>&UL"B`J
M"B`J($ET(&-A;B!B92!U<V5D('1O('-E<FEA;&EZ92!A;B!I;F1E>&5D(&%R
M<F%Y"B`J(&QI:V4@97AT+W-I;7!L97AM;"!D;V5S+"!B>2!U<VEN9R!T:&4@
M;F%M90H@*B!O9B!T:&4@<&%R96YT('1A9RP@=VAI;&4@;VUI='1I;F<@=&AI
M<R!T86<N"B`J"B`J($!A=71H;W(@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P
M:'`N;F5T/@H@*B\*("`@(&5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["B`@("`*
M("`@(')E<75I<F5?;VYC92`G6$U,+U-E<FEA;&EZ97(N<&AP)SL*"B`@("`D
M;W!T:6]N<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("!834Q?
M4T5224%,25I%4E]/4%1)3TY?24Y$14Y4("`@("`@(#T^("<@("`@)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7TQ)
M3D5"4D5!2U,@("`]/B`B7&XB+`H)"0D)"0E834Q?4T5224%,25I%4E]/4%1)
M3TY?4D]/5%].04U%("`@(#T^("=R9&8Z4D1&)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7U)/3U1?05144DE"4R`]
M/B!A<G)A>2@G=F5R<VEO;B<@/3X@)S`N.3$G*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7TU/1$4@("`@("`@("`]
M/B!834Q?4T5224%,25I%4E]-3T1%7U-)35!,15A-3`H@("`@("`@("`@("`@
M("`@("`@("D["B`@("`*("`@("1S97)I86QI>F5R(#T@;F5W(%A-3%]397)I
M86QI>F5R*"1O<'1I;VYS*3L*"B`@("`*("`@("1R9&8@/2!A<G)A>2@*"0D)
M"2=C:&%N;F5L)R`]/B!A<G)A>2@*"0D)"0D)"0D))W1I=&QE)R`]/B`G17AA
M;7!L92!21$8@8VAA;FYE;"<L"@D)"0D)"0D)"2=L:6YK)R`@/3X@)VAT='`Z
M+R]W=W<N<&AP+71O;VQS+F1E)RP*"0D)"0D)"0D))VEM86=E)PD]/@EA<G)A
M>2@*"0D)"0D)"0D)"0D)"0DG=&ET;&4G"3T^("=%>&%M<&QE(&EM86=E)RP*
M"0D)"0D)"0D)"0D)"0DG=7)L)PD]/@DG:'1T<#HO+W=W=RYP:'`M=&]O;',N
M9&4O:6UA9V4N9VEF)RP*"0D)"0D)"0D)"0D)"0DG;&EN:R<)/3X))VAT='`Z
M+R]W=W<N<&AP+71O;VQS+F1E)PH)"0D)"0D)"0D)"0D)*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)VET96TG("`@/3X@(&%R<F%Y
M*`H@("`@("`@("`@("`)"0D)"0D)"0D)"6%R<F%Y*`H@("`@("`@("`@("`)
M"0D)"0D)"0D)"0DG=&ET;&4G"3T^("=%>&%M<&QE(&ET96TG+`H@("`@("`@
M("`@("`)"0D)"0D)"0D)"0DG;&EN:R<)/3X@)VAT='`Z+R]E>&%M<&QE+F-O
M;2<*("`@("`@("`@("`@"0D)"0D)"0D)"0DI+`H@("`@("`@("`@("`)"0D)
M"0D)"0D)"6%R<F%Y*`H@("`@("`@("`@("`)"0D)"0D)"0D)"0DG=&ET;&4G
M"3T^("=!;F]T:&5R(&ET96TG+`H@("`@("`@("`@("`)"0D)"0D)"0D)"0DG
M;&EN:R<)/3X@)VAT='`Z+R]E>&%M<&QE+F-O;2<*("`@("`@("`@("`@"0D)
M"0D)"0D)"0DI+`H@("`@("`@("`@("`)"0D)"0D)"0D)"6%R<F%Y*`H@("`@
M("`@("`@("`)"0D)"0D)"0D)"0DG=&ET;&4G"3T^("=)('1H:6YK('EO=2!G
M970@:70N+BXG+`H@("`@("`@("`@("`)"0D)"0D)"0D)"0DG;&EN:R<)/3X@
M)VAT='`Z+R]E>&%M<&QE+F-O;2<*("`@("`@("`@("`@"0D)"0D)"0D)"0DI
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("D*"0D)"0D)"0DI"B`@("`@("`@("`@("`@("`@("`@*3L*
M("`@(`H@("`@)')E<W5L="`]("1S97)I86QI>F5R+3YS97)I86QI>F4H)')D
M9BD["B`@("`*("`@(&EF*"`D<F5S=6QT(#T]/2!T<G5E("D@>PH@("`@("`@
M(&5C:&\@("`@)SQP<F4^)SL*("`@("`@("!E8VAO("`@(&AT;6QE;G1I=&EE
M<R@D<V5R:6%L:7IE<BT^9V5T4V5R:6%L:7IE9$1A=&$H*2D["B`@("`@("`@
M96-H;R`@("`G/"]P<F4^)SL*("`@('T*/SX`````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E
M>&%M<&QE<R]S97)I86QI>F5);F1E>&5D07)R87E7:71H0V]N=&5X="YP:'``
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C$V-2`Q,#4Q
M-30S,S<S,"`P,S,R-C<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]02%`*+RHJ"B`J(%1H:7,@97AA;7!L92!D96UO;G-T
M<F%T97,@=&AE('5S92!O9@H@*B!M;V1E(#T^('-I;7!L97AM;`H@*@H@*B!)
M="!C86X@8F4@=7-E9"!T;R!S97)I86QI>F4@86X@:6YD97AE9"!A<G)A>0H@
M*B!L:6ME(&5X="]S:6UP;&5X;6P@9&]E<RP@8GD@=7-I;F<@=&AE(&YA;64*
M("H@;V8@=&AE('!A<F5N="!T86<L('=H:6QE(&]M:71T:6YG('1H:7,@=&%G
M+@H@*@H@*B!`875T:&]R(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE
M=#X*("HO"B`@("!E<G)O<E]R97!O<G1I;F<H15]!3$PI.PH@("`@"B`@("!R
M97%U:7)E7V]N8V4@)UA-3"]397)I86QI>F5R+G!H<"<["@H@("`@)&]P=&EO
M;G,@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!
M3$E:15)?3U!424].7TE.1$5.5"`@("`@("`]/B`G("`@("<L"B`@("`@("`@
M("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E],24Y%0E)%
M04M3("`@/3X@(EQN(BP*("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%
M4DE!3$E:15)?3U!424].7T1%1D%53%1?5$%'("`]/B!A<G)A>2@I+`H@("`@
M("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?1$5&
M055,5%]404<@(#T^(&%R<F%Y*"=F;V]S)R`]/B`G9F]O)RP@)V)A<G,G(#T^
M("=B87(G*0H@("`@("`@("`@("`@("`@("`@("D["B`@("`*("`@("1S97)I
M86QI>F5R(#T@;F5W(%A-3%]397)I86QI>F5R*"1O<'1I;VYS*3L*("`@(`H@
M("`@)&1A=&$@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G9F]O<R<@
M/3X@87)R87DH)V]N92!F;V\G+"`G='=O(&9O;W,G+"`G=&AR964@9F]O<R<I
M+`H@("`@("`@("`@("`@("`@("`@("=B87)S)R`]/B!A<G)A>2@G;VYE(&)A
M<B<L("=T=V\@8F%R<R<L("=T:')E92!B87)S)RDL"B`@("`@("`@("`@("`@
M("`I.PH*("`@("1R97-U;'0@/2`D<V5R:6%L:7IE<BT^<V5R:6%L:7IE*"1D
M871A*3L*("`@(`H@("`@:68H("1R97-U;'0@/3T]('1R=64@*2!["B`@("`@
M("`@96-H;R`@("`G/'!R93XG.PH@("`@("`@(&5C:&\@("`@:'1M;&5N=&ET
M:65S*"1S97)I86QI>F5R+3YG971397)I86QI>F5D1&%T82@I*3L*("`@("`@
M("!E8VAO("`@("<\+W!R93XG.PH@("`@?0H_/@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W-E<FEA;&EZ94YU;&Q0
M<F]P97)T:65S+G!H<````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`S,3$S(#$P-3$U-#,S-S,P(#`S,30W,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/U!(4`HO*BH*
M("H@5&AI<R!E>&%M<&QE(&1E;6]N<W1R871E<R!T:&4@=7-E(&]F"B`J(&EG
M;F]R94YU;&P@/3X@=')U90H@*@H@*B!)="!C86X@8F4@=7-E9"!T;R!S97)I
M86QI>F4@86X@:6YD97AE9"!A<G)A>0H@*B!L:6ME(&5X="]S:6UP;&5X;6P@
M9&]E<RP@8GD@=7-I;F<@=&AE(&YA;64*("H@;V8@=&AE('!A<F5N="!T86<L
M('=H:6QE(&]M:71T:6YG('1H:7,@=&%G+@H@*@H@*B!`875T:&]R(%-T97!H
M86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("HO"B`@("!E<G)O<E]R97!O
M<G1I;F<H15]!3$PI.PH@("`@"B`@("!R97%U:7)E7V]N8V4@)UA-3"]397)I
M86QI>F5R+G!H<"<["@H@("`@)&]P=&EO;G,@/2!A<G)A>2@*("`@("`@("`@
M("`@("`@("`@("`@("`@(FEN9&5N="(@("`@("`@("`]/B`G("`@("<L"B`@
M("`@("`@("`@("`@("`@("`@("`@(")L:6YE8G)E86LB("`@("`@/3X@(EQN
M(BP*("`@("`@("`@("`@("`@("`@("`I.PH@("`@"B`@("`D<V5R:6%L:7IE
M<B`](&YE=R!834Q?4V5R:6%L:7IE<B@D;W!T:6]N<RD["B`@("`*("`@("1O
M8FIE8W0@/2!N97<@<W1D0VQA<W,H*3L*("`@("1O8FIE8W0M/F9O;R`]("=B
M87(G.PH@("`@)&]B:F5C="T^8F%R(#T@;G5L;#L*("`@(`H@("`@)&%R<F%Y
M(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)V9O;R<@/3X@)V)A<B<L
M"B`@("`@("`@("`@("`@("`@("`@)V)A<B<@/3X@;G5L;`H@("`@("`@("`@
M("`@("`@*3L*("`@(`H@("`@)')E<W5L="`]("1S97)I86QI>F5R+3YS97)I
M86QI>F4H)&]B:F5C="D["B`@("`*("`@(&EF*"`D<F5S=6QT(#T]/2!T<G5E
M("D@>PH@("`@("`@(&5C:&\@("`@(CQP<F4^(CL*("`@("`@("!E8VAO("`@
M(&AT;6QE;G1I=&EE<R@D<V5R:6%L:7IE<BT^9V5T4V5R:6%L:7IE9$1A=&$H
M*2D["B`@("`@("`@96-H;R`@("`B/"]P<F4^(CL*("`@('T*"B`@("`D<F5S
M=6QT(#T@)'-E<FEA;&EZ97(M/G-E<FEA;&EZ92@D87)R87DI.PH@("`@"B`@
M("!I9B@@)')E<W5L="`]/3T@=')U92`I('L*("`@("`@("!E8VAO("`@("(\
M<')E/B(["B`@("`@("`@96-H;R`@("!H=&UL96YT:71I97,H)'-E<FEA;&EZ
M97(M/F=E=%-E<FEA;&EZ961$871A*"DI.PH@("`@("`@(&5C:&\@("`@(CPO
M<')E/B(["B`@("!]"B`@("`*("`@("1S97)I86QI>F5R+3YS971/<'1I;VXH
M)VEG;F]R94YU;&PG+"!T<G5E*3L*("`@("1R97-U;'0@/2`D<V5R:6%L:7IE
M<BT^<V5R:6%L:7IE*"1O8FIE8W0I.PH@("`@"B`@("!I9B@@)')E<W5L="`]
M/3T@=')U92`I('L*("`@("`@("!E8VAO("`@("(\<')E/B(["B`@("`@("`@
M96-H;R`@("!H=&UL96YT:71I97,H)'-E<FEA;&EZ97(M/F=E=%-E<FEA;&EZ
M961$871A*"DI.PH@("`@("`@(&5C:&\@("`@(CPO<')E/B(["B`@("!]"B`@
M("`*("`@("1R97-U;'0@/2`D<V5R:6%L:7IE<BT^<V5R:6%L:7IE*"1A<G)A
M>2D["B`@("`*("`@(&EF*"`D<F5S=6QT(#T]/2!T<G5E("D@>PH@("`@("`@
M(&5C:&\@("`@(CQP<F4^(CL*("`@("`@("!E8VAO("`@(&AT;6QE;G1I=&EE
M<R@D<V5R:6%L:7IE<BT^9V5T4V5R:6%L:7IE9$1A=&$H*2D["B`@("`@("`@
M96-H;R`@("`B/"]P<F4^(CL*("`@('T*/SX`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C
M<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S97)I86QI>F5/8FIE8W0N<&AP
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,C,T-B`Q,#4Q-30S,S<S,"`P,C<W,38`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]02%`*+RHJ"B`J(%1H
M:7,@:7,@:G5S="!A(&)A<VEC(&5X86UP;&4@=&AA="!S:&]W<PH@*B!H;W<@
M;V)J96-T<R!C86X@8F4@<V5R:6%L:7IE9"!S;R!T:&5Y(&-A;@H@*B!B92!F
M=6QL>2!R97-T;W)E9"!L871E<BX*("H*("H@0&%U=&AO<B!3=&5P:&%N(%-C
M:&UI9'0@/'-C:'-T0'!H<"YN970^"B`J+PH*+RHJ"B`J($5X86UP;&4@8VQA
M<W,@=&AA="!I;7!L96UE;G1S(%]?<VQE97`H*0H@*@H@*B!`<&%C:V%G92`@
M("!834Q?4V5R:6%L:7IE<@H@*B!`<W5B<&%C:V%G92!%>&%M<&QE<PH@*B\*
M8VQA<W,@37E#;&%S<PI["B`@("!V87(@)&9O;R`]("=4:&ES(&ES(&9O;RXG
M.PH@("`@=F%R("1B87(@/2`G5&AI<R!I<R!B87(N)SL*("`@(`H@("`@9G5N
M8W1I;VX@7U]S;&5E<"@I"B`@("!["B`@("`@("`@<F5T=7)N(&%R<F%Y*"=F
M;V\G*3L*("`@('T*?0H*97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L*"B\J*@H@
M*B!,;V%D(%A-3%]397)I86QI>F5R"B`J+PIR97%U:7)E7V]N8V4@)UA-3"]3
M97)I86QI>F5R+G!H<"<["@H*+R\@=&AI<R!I<R!J=7-T('1O(&=E="!A(&YE
M<W1E9"!O8FIE8W0*)'!E87)%<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H)U1H
M:7,@:7,@:G5S="!A;B!E<G)O<B!O8FIE8W0G+#$R,RD["@HD;W!T:6]N<R`]
M(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@(")I;F1E;G0B("`@("`@("`@
M/3X@(B`@("`B+`H@("`@("`@("`@("`@("`@("`@(")L:6YE8G)E86LB("`@
M("`@/3X@(EQN(BP*("`@("`@("`@("`@("`@("`@("`B9&5F875L=%1A9TYA
M;64B(#T^(")U;FYA;65D271E;2(L"B`@("`@("`@("`@("`@("`@("`@(G1Y
M<&5(:6YT<R(@("`@("`]/B!T<G5E"B`@("`@("`@("`@("`@("`I.PH*)&9O
M;R`@("`]("`@;F5W('-T9$-L87-S.PHD9F]O+3YV86QU92`](")->2!V86QU
M92(["B1F;V\M/F5R<F]R(#T@)'!E87)%<G)O<CL*)&9O;RT^>&UL("`@/2`B
M8V]O;"(["@HD9F]O+3YO8FH)/2!N97<@37E#;&%S<R@I.PHD9F]O+3YA<G(@
M("`](&%R<F%Y*"D["B1F;V\M/GIE<F\@(#T@,#L*"@HD<V5R:6%L:7IE<B`]
M("9N97<@6$U,7U-E<FEA;&EZ97(H)&]P=&EO;G,I.PH*)')E<W5L="`]("1S
M97)I86QI>F5R+3YS97)I86QI>F4H)&9O;RD["@II9B@@)')E<W5L="`]/3T@
M=')U92`I('L*"21X;6P@/2`D<V5R:6%L:7IE<BT^9V5T4V5R:6%L:7IE9$1A
M=&$H*3L*?0H*96-H;R`G/'!R93XG.PIE8VAO(&AT;6QS<&5C:6%L8VAA<G,H
M)'AM;"D["F5C:&\@)SPO<')E/B<["C\^````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP
M;&5S+W-E<FEA;&EZ95)$1BYP:'``````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`T,S8T(#$P-3$U-#,S
M-S,P(#`R-S$R-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/U!(4`HO*BH*("H@5&AI<R!E>&%M<&QE('-H;W=S(&AO=R!T
M;R!C<F5A=&4@86X@4D1&(&1O8W5M96YT"B`J('=I=&@@82!F97<@;&EN97,@
M;V8@8V]D92X*("H@5&AI<R!C86X@86QS;R!B92!D;VYE('=I=&@@;6]D92`]
M/B!S:6UP;&5X;6P*("H*("H@0&%U=&AO<B!3=&5P:&%N(%-C:&UI9'0@/'-C
M:'-T0'!H<"YN970^"B`J($!S964@("`@<V5R:6%L:7IE26YD97AE9$%R<F%Y
M+G!H<`H@*B\*("`@(&5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["@H@("`@<F5Q
M=6ER95]O;F-E("=834PO4V5R:6%L:7IE<BYP:'`G.PH*("`@("1O<'1I;VYS
M(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@(")I;F1E;G0B("`@
M("`@("`@(#T^("(@("`@(BP*("`@("`@("`@("`@("`@("`@("`@("`@(FQI
M;F5B<F5A:R(@("`@("`@/3X@(EQN(BP*("`@("`@("`@("`@("`@("`@("`@
M("`@(G1Y<&5(:6YT<R(@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@
M("`@("`@("`@(")A9&1$96-L(B`@("`@("`@(#T^('1R=64L"B`@("`@("`@
M("`@("`@("`@("`@("`@(")E;F-O9&EN9R(@("`@("`@(#T^(")55$8M."(L
M"@D)"0D)"2)R;V]T3F%M92(@("`@("`@(#T^(")R9&8Z4D1&(BP*("`@("`@
M("`@("`@("`@("`@("`@("`@(G)O;W1!='1R:6)U=&5S(B`@/3X@87)R87DH
M(G9E<G-I;VXB(#T^("(P+CDQ(BDL"@D)"0D)"2)D969A=6QT5&%G3F%M92(@
M(#T^(")I=&5M(BP*("`@("`@("`@("`@("`@("`@("`@("`@(F%T=')I8G5T
M97-!<G)A>2(@/3X@(E]A='1R:6)U=&5S(@H@("`@("`@("`@("`@("`@("`@
M("D["B`@("`*("`@("1S97)I86QI>F5R(#T@;F5W(%A-3%]397)I86QI>F5R
M*"1O<'1I;VYS*3L*"B`@("`*("`@("1R9&8@("`@/2`@(&%R<F%Y*`H)"0D)
M"0DB8VAA;FYE;"(@/3X@87)R87DH"@D)"0D)"0D)"0D)(G1I=&QE(B`]/B`B
M17AA;7!L92!21$8@8VAA;FYE;"(L"@D)"0D)"0D)"0D)(FQI;FLB("`]/B`B
M:'1T<#HO+W=W=RYP:'`M=&]O;',N9&4B+`H)"0D)"0D)"0D)"2)I;6%G92()
M/3X)87)R87DH"@D)"0D)"0D)"0D)"0D)"0DB=&ET;&4B"3T^(")%>&%M<&QE
M(&EM86=E(BP*"0D)"0D)"0D)"0D)"0D)"2)U<FPB"3T^"2)H='1P.B\O=W=W
M+G!H<"UT;V]L<RYD92]I;6%G92YG:68B+`H)"0D)"0D)"0D)"0D)"0D)(FQI
M;FLB"3T^"2)H='1P.B\O=W=W+G!H<"UT;V]L<RYD92(*"0D)"0D)"0D)"0D)
M"0D)*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`B7V%T=')I8G5T97,B(#T^(&%R<F%Y*"`B<F1F.F%B;W5T(B`]/B`B
M:'1T<#HO+V5X86UP;&4N8V]M+V9O;V)A<BYH=&UL(B`I+`H)"0D)"0D)"0D)
M"6%R<F%Y*`H)"0D)"0D)"0D)"0DB=&ET;&4B"3T^(")%>&%M<&QE(&ET96TB
M+`H)"0D)"0D)"0D)"0DB;&EN:R()/3X@(FAT='`Z+R]E>&%M<&QE+F-O;2(L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(")?871T<FEB=71E<R(@/3X@87)R87DH(")R9&8Z86)O=70B(#T^(")H
M='1P.B\O97AA;7!L92YC;VTO9F]O8F%R+FAT;6PB("D*"0D)"0D)"0D)"0DI
M+`H)"0D)"0D)"0D)"6%R<F%Y*`H)"0D)"0D)"0D)"0DB=&ET;&4B"3T^(")!
M;F]T:&5R(&ET96TB+`H)"0D)"0D)"0D)"0DB;&EN:R()/3X@(FAT='`Z+R]E
M>&%M<&QE+F-O;2(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(")?871T<FEB=71E<R(@/3X@87)R87DH(")R9&8Z
M86)O=70B(#T^(")H='1P.B\O97AA;7!L92YC;VTO9F]O8F%R+FAT;6PB("D*
M"0D)"0D)"0D)"0DI+`H)"0D)"0D)"0D)"6%R<F%Y*`H)"0D)"0D)"0D)"0DB
M=&ET;&4B"3T^("))('1H:6YK('EO=2!G970@:70N+BXB+`H)"0D)"0D)"0D)
M"0DB;&EN:R()/3X@(FAT='`Z+R]E>&%M<&QE+F-O;2(L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(")?871T<FEB
M=71E<R(@/3X@87)R87DH(")R9&8Z86)O=70B(#T^(")H='1P.B\O97AA;7!L
M92YC;VTO9F]O8F%R+FAT;6PB("D*"0D)"0D)"0D)"0DI"@D)"0D)"0D)"0DI
M"B`@("`@("`@("`@("`@("`@("`@*3L*("`@(`H@("`@)')E<W5L="`]("1S
M97)I86QI>F5R+3YS97)I86QI>F4H)')D9BD["B`@("`*("`@(&EF*"`D<F5S
M=6QT(#T]/2!T<G5E("D@>PH@("`@("`@(&5C:&\@("`@(CQP<F4^(CL*("`@
M("`@("!E8VAO("`@(&AT;6QE;G1I=&EE<R@D<V5R:6%L:7IE<BT^9V5T4V5R
M:6%L:7IE9$1A=&$H*2D["B`@("`@("`@96-H;R`@("`B/"]P<F4^(CL*("`@
M('T*/SX`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I
M86QI>F5R+V5X86UP;&5S+W-E<FEA;&EZ95-E;&5C=&EV94%T=')I8G5T97,N
M<&AP`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S
M,34Q(#$P-3$U-#,S-S,P(#`S,C0W-0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/U!(4`HO*BH*("H@5&AI<R!S:&]W<R!T
M:&%T(%A-3%]397)I86QI>F5R(&ES(&%B;&4@=&\@=V]R:R!W:71H"B`J(&5M
M<'1Y(&%R<F%Y<PH@*@H@*B!`875T:&]R(%-T97!H86X@4V-H;6ED="`\<V-H
M<W1`<&AP+FYE=#X*("HO"F5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["G)E<75I
M<F5?;VYC92`G6$U,+U-E<FEA;&EZ97(N<&AP)SL*"B1D871A(#T@87)R87DH
M"B`@("`@("`@("`@("`@("!A<G)A>2@G;F%M92<@/3X@)U-U<&5R;6%N)RP@
M)V%G92<@/3X@,S0L("=R96%L;F%M92<@/3X@)T-L87)K($ME;G0G*2P*("`@
M("`@("`@("`@("`@(&%R<F%Y*"=N86UE)R`]/B`G0F%T;6%N)RP@)V%G92<@
M/3X@,S(L("=R96%L;F%M92<@/3X@)T)R=6-E(%=A>6YE)RDL"B`@("`@("`@
M("`@("`@("`G=FEL;&%I;B<@/3X@87)R87DH)VYA;64G(#T^("=0<F]F97-S
M;W(@6F]O;2<L("=A9V4G(#T^("=U;FMN;W=N)RP@)W)E86QN86UE)R`]/B`G
M2'5N=&5R(%IO;&]M;VXG*0H@("`@("`@("`@("`I.PH*)'-E<FEA;&EZ97(@
M/2!N97<@6$U,7U-E<FEA;&EZ97(H*3L*)'-E<FEA;&EZ97(M/G-E=$]P=&EO
M;BA834Q?4T5224%,25I%4E]/4%1)3TY?24Y$14Y4+"`G("`@("<I.PHD<V5R
M:6%L:7IE<BT^<V5T3W!T:6]N*%A-3%]315))04Q)6D527T]05$E/3E]$149!
M54Q47U1!1RP@)VAE<F\G*3L*"B1S97)I86QI>F5R+3YS97)I86QI>F4H)&1A
M=&$I.PIE8VAO("<\<')E/B<["F5C:&\@(D1E9F%U;'0@8F5H879I;W5R.EQN
M(CL*96-H;R!H=&UL<W!E8VEA;&-H87)S*"1S97)I86QI>F5R+3YG971397)I
M86QI>F5D1&%T82@I*3L*96-H;R`G/"]P<F4^)SL*"B1S97)I86QI>F5R+3YS
M971/<'1I;VXH6$U,7U-%4DE!3$E:15)?3U!424].7U-#04Q!4E]!4U]!5%12
M24)55$53+"!T<G5E*3L*"B1S97)I86QI>F5R+3YS97)I86QI>F4H)&1A=&$I
M.PIE8VAO("<\<')E/B<["F5C:&\@(EA-3%]315))04Q)6D527T]05$E/3E]3
M0T%,05)?05-?05144DE"551%4R`]('1R=64Z7&XB.PIE8VAO(&AT;6QS<&5C
M:6%L8VAA<G,H)'-E<FEA;&EZ97(M/F=E=%-E<FEA;&EZ961$871A*"DI.PIE
M8VAO("<\+W!R93XG.PH*)'-E<FEA;&EZ97(M/G-E=$]P=&EO;BA834Q?4T52
M24%,25I%4E]/4%1)3TY?4T-!3$%27T%37T%45%))0E5415,L(&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=H97)O)R`@("`]/B!A<G)A>2@G
M;F%M92<L("=A9V4G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=FEL
M;&%I;B<@/3X@87)R87DH)W)E86QN86UE)RD*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`I"B`@("`@("`@("`@("`@("`@("`@("`I.PH*)'-E<FEA;&EZ
M97(M/G-E<FEA;&EZ92@D9&%T82D["F5C:&\@)SQP<F4^)SL*96-H;R`B6$U,
M7U-%4DE!3$E:15)?3U!424].7U-#04Q!4E]!4U]!5%1224)55$53(&ES(&%N
M(&%R<F%Y.EQN(CL*96-H;R!H=&UL<W!E8VEA;&-H87)S*"1S97)I86QI>F5R
M+3YG971397)I86QI>F5D1&%T82@I*3L*96-H;R`G/"]P<F4^)SL*/SX`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE
M<B]E>&%M<&QE<R]S97)I86QI>F57:71H071T<FEB=71E<RYP:'``````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C(S-B`Q
M,#4Q-30S,S<S,"`P,S$T-S``(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]02%`*+RHJ"B`J(%A-3"!397)I86QI>F5R(&5X
M86UP;&4*("H*("H@5&AI<R!E>&%M<&QE(&1E;6]N<W1R871E<RP@:&]W(%A-
M3%]397)I86QI>F5R(&ES(&%B;&4*("H@=&\@<V5R:6%L:7IE('-C86QA<B!V
M86QU97,@87,@86X@871T<FEB=71E(&EN<W1E860@;V8@82!N97-T960@=&%G
M+@H@*@H@*B!4:&4@<V%M92!S=')U8W1U<F4@;&EK92!I;B!S97)I86QI>F5/
M8FIE8W0N<&AP(&ES('-E<FEA;&EZ960N"B`J"B`J($!A=71H;W(@(%-T97!H
M86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("HO"B`@("!E<G)O<E]R97!O
M<G1I;F<H15]!3$PI.PH*("`@(')E<75I<F5?;VYC92`G6$U,+U-E<FEA;&EZ
M97(N<&AP)SL*"B`@("`D;W!T:6]N<R`](&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("`@("`B:6YD96YT(B`@("`@("`@("`@("`]/B`B("`@("(L"B`@
M("`@("`@("`@("`@("`@("`@("`@(")L:6YE8G)E86LB("`@("`@("`@(#T^
M(")<;B(L"B`@("`@("`@("`@("`@("`@("`@("`@(")D969A=6QT5&%G3F%M
M92(@("`@(#T^(")U;FYA;65D271E;2(L"@D)"0D)"2)S8V%L87)!<T%T=')I
M8G5T97,B(#T^('1R=64L"B`@("`@("`@("`@("`@("`@("`@*3L*("`@(`H@
M("`@+R\@=&AI<R!I<R!J=7-T('1O(&=E="!A(&YE<W1E9"!O8FIE8W0*("`@
M("1P96%R17)R;W(@/2!014%2.CIR86ES945R<F]R*"=4:&ES(&ES(&IU<W0@
M86X@97)R;W(@;V)J96-T)RPQ,C,I.PH)"B`@("`D9F]O("`@(#T@("!N97<@
M<W1D0VQA<W,["B`@("`*("`@("1F;V\M/G9A;'5E(#T@(DUY('9A;'5E(CL*
M("`@("1F;V\M/F5R<F]R(#T@)'!E87)%<G)O<CL*("`@("1F;V\M/GAM;"`@
M(#T@(F-O;VPB.PH@("`@"B`@("`D<V5R:6%L:7IE<B`](&YE=R!834Q?4V5R
M:6%L:7IE<B@D;W!T:6]N<RD["B`@("`*("`@("1R97-U;'0@/2`D<V5R:6%L
M:7IE<BT^<V5R:6%L:7IE*"1F;V\I.PH@("`@"B`@("!I9B@@)')E<W5L="`]
M/3T@=')U92`I('L*"0DD>&UL(#T@)'-E<FEA;&EZ97(M/F=E=%-E<FEA;&EZ
M961$871A*"D["@H)("`@(&5C:&\)(CQP<F4^(CL*"2`@("!P<FEN=%]R*"!H
M=&UL<W!E8VEA;&-H87)S*"1X;6PI("D["@D@("`@96-H;PDB/"]P<F4^(CL*
M("`@('T@96QS92!["@D)96-H;PDB/'!R93XB.PH)"7!R:6YT7W(H)')E<W5L
M="D["@D)96-H;PDB/"]P<F4^(CL*"7T*"C\^````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W-E<FEA;&EZ95=I
M=&A!='1R:6)U=&5S,BYP:'```````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`R-#,U(#$P-3$U-#,S-S,P(#`S,34U,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/U!(4`HO
M*BH*("H@6$U,(%-E<FEA;&EZ97(@97AA;7!L90H@*@H@*B!4:&ES(&5X86UP
M;&4@9&5M;VYS=')A=&5S+"!H;W<@6$U,7U-E<FEA;&EZ97(@:7,@86)L90H@
M*B!T;R!S97)I86QI>F4@<')E9&5F:6YE9"!V86QU97,@87,@=&AE(&%T=')I
M8G5T97,@;V8@82!T86<*("H*("H@0&%U=&AO<B`@4W1E<&AA;B!38VAM:61T
M(#QS8VAS=$!P:'`N;F5T/@H@*B\*("`@(&5R<F]R7W)E<&]R=&EN9RA%7T%,
M3"D["@H@("`@<F5Q=6ER95]O;F-E("=834PO4V5R:6%L:7IE<BYP:'`G.PH*
M("`@("1O<'1I;VYS(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@
M(")I;F1E;G0B("`@("`@("`@("`@(#T^("(@("`@(BP*("`@("`@("`@("`@
M("`@("`@("`@("`@(FQI;F5B<F5A:R(@("`@("`@("`@/3X@(EQN(BP*("`@
M("`@("`@("`@("`@("`@("`@("`@(F1E9F%U;'1486=.86UE(B`@("`@/3X@
M(G5N;F%M961)=&5M(BP*"0D)"0D)(G-C86QA<D%S071T<FEB=71E<R(@/3X@
M9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@(")A='1R:6)U=&5S07)R
M87DB("`@(#T^("=?871T<FEB=71E<R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@(")C;VYT96YT3F%M92(@("`@("`@(#T^("=?8V]N=&5N="<*("`@("`@
M("`@("`@("`@("`@("`I.PH*("`@("1D871A(#T@87)R87DH"B`@("`@("`@
M("`@("`@("`@("`@)V9O;R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=?871T<FEB=71E<R<@/3X@87)R87DH("=V
M97)S:6]N)R`]/B`G,2XP)RP@)V9O;R<@/3X@)V)A<B<@*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)U]C;VYT96YT)R`@("`]/B`G
M=&5S="<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("DL"B`@
M("`@("`@("`@("`@("`@("`@)W-C:'-T)R`]/B`G4W1E<&AA;B!38VAM:61T
M)PH@("`@("`@("`@("`@("`@*3L@("`@"B`@("`*("`@("1S97)I86QI>F5R
M(#T@;F5W(%A-3%]397)I86QI>F5R*"1O<'1I;VYS*3L*("`@(`H@("`@)')E
M<W5L="`]("1S97)I86QI>F5R+3YS97)I86QI>F4H)&1A=&$I.PH@("`@"B`@
M("!I9B@@)')E<W5L="`]/3T@=')U92`I('L*"0DD>&UL(#T@)'-E<FEA;&EZ
M97(M/F=E=%-E<FEA;&EZ961$871A*"D["@H)("`@(&5C:&\)(CQP<F4^(CL*
M"2`@("!P<FEN=%]R*"!H=&UL<W!E8VEA;&-H87)S*"1X;6PI("D["@D@("`@
M96-H;PDB/"]P<F4^(CL*("`@('T@96QS92!["@D)96-H;PDB/'!R93XB.PH)
M"7!R:6YT7W(H)')E<W5L="D["@D)96-H;PDB/"]P<F4^(CL*"7T*"C\^````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ
M97(O97AA;7!L97,O<V5R:6%L:7IE5VET:$-O;6UE;G0N<&AP````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(Q,#`@
M,3`U,34T,S,W,S`@,#,P-S,R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_4$A0"B\J*@H@*B!4:&ES(&ES(&IU<W0@82!B
M87-I8R!E>&%M<&QE('1H870@<VAO=W,*("H@:&]W(&]B:F5C=',@8V%N(&)E
M('-E<FEA;&EZ960@<V\@=&AE>2!C86X*("H@8F4@9G5L;'D@<F5S=&]R960@
M;&%T97(N"B`J"B`J($!A=71H;W(@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P
M:'`N;F5T/@H@*B\*("`@(&5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["@H@("`@
M<F5Q=6ER95]O;F-E("=834PO4V5R:6%L:7IE<BYP:'`G.PH*("`@("1O<'1I
M;VYS(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))
M04Q)6D527T]05$E/3E])3D1%3E0@("`@("`]/B`G("`@("<L"B`@("`@("`@
M("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E],24Y%0E)%
M04M3("`]/B`B7&XB+`H@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T52
M24%,25I%4E]/4%1)3TY?0T]-345.5%]+15D@/3X@)V-O;6UE;G0G"B`@("`@
M("`@("`@("`@("`@("`@*3L*("`@(`H@("`@)&9O;R`](&YE=R!S=&1#;&%S
M<SL*("`@("1F;V\M/F-O;6UE;G0@/2`G5&AI<R!I<R!A(&-O;6UE;G0G.PH@
M("`@)&9O;RT^=F%L=64@("`]("=->2!V86QU92<["B`@("`*("`@("1F;V\M
M/F)A<B`@("`@/2!N97<@<W1D0VQA<W,H*3L*("`@("1F;V\M/F)A<BT^=F%L
M=64@("`]("=!;F]T:&5R('9A;'5E)SL*("`@("1F;V\M/F)A<BT^8V]M;65N
M="`]("=!;F]T:&5R(&-O;6UE;G0G.PH@("`@"B`@("`D9F]O+3YT;VUA=&\@
M("`@("`@("`@/2!N97<@<W1D0VQA<W,H*3L*("`@("1F;V\M/G1O;6%T;RT^
M8V]M;65N="`]("=!;F0@82!L87-T(&-O;6UE;G0G.PH@("`@"B`@("`D<V5R
M:6%L:7IE<B`]("9N97<@6$U,7U-E<FEA;&EZ97(H)&]P=&EO;G,I.PH@("`@
M"B`@("`D<F5S=6QT(#T@)'-E<FEA;&EZ97(M/G-E<FEA;&EZ92@D9F]O*3L*
M("`@(`H@("`@:68@*"1R97-U;'0@/3T]('1R=64I('L*"0DD>&UL(#T@)'-E
M<FEA;&EZ97(M/F=E=%-E<FEA;&EZ961$871A*"D["B`@("!]"@H@("`@96-H
M;R`G/'!R93XG.PH@("`@<')I;G1?<BAH=&UL<W!E8VEA;&-H87)S*"1X;6PI
M*3L*("`@(&5C:&\@)SPO<')E/B<["C\^````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]E>&%M<&QE+GAM
M;``````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#$R,B`Q,#4Q-30S,S<S,"`P,C8R,S(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/'AM;#X*
M("`@(#QT97-T(&9O;STB8F%R(CX*("`@("`@("!497-T"B`@("`@("`@/'1A
M9SYT97-T/"]T86<^"B`@("`\+W1E<W0^"CPO>&UL/@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O
M6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O<V5R:6%L:7IE5VET:$1T9"YP:'``
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#(P,#<@,3`U,34T,S,W,S`@,#,P,#4Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_4$A0"B\J*@H@*B!4:&ES
M(&5X86UP;&4@<VAO=W,@:&]W('1O(&%D9"!A($1O8U1Y<&4@1&5C;&%R871I
M;VX@=&\@=&AE(%A-3"!D;V-U;65N=`H@*@H@*B!`875T:&]R(%-T97!H86X@
M4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("HO"B`@("!E<G)O<E]R97!O<G1I
M;F<H15]!3$PI.PH*("`@(')E<75I<F5?;VYC92`G6$U,+U-E<FEA;&EZ97(N
M<&AP)SL*"B`@("`D;W!T:6]N<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@
M("`@("`@("`B:6YD96YT(B`@("`@/3X@(B`@("`B+`H@("`@("`@("`@("`@
M("`@("`@("`@("`B;&EN96)R96%K(B`@/3X@(EQN(BP*("`@("`@("`@("`@
M("`@("`@("`@("`@(F%D9$1E8VPB("`@(#T^('1R=64L"B`@("`@("`@("`@
M("`@("`@("`@("`@(")A9&1$;V-T>7!E(B`]/B!T<G5E+`H@("`@("`@("`@
M("`@("`@("`@("`@("`B9&]C='EP92(@("`@/3X@87)R87DH"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U<FDG
M(#T^("=H='1P.B\O<&5A<BYP:'`N;F5T+V1T9"]P86-K86=E+3$N,"<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=I9"<@/3X@)RTO+U!(4"\O4$5!4B]$5$0@4$%#2T%'12`P+C$G"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("D*("`@
M("`@("`@("`@("`@("`@("`I.PH@("`@"B`@("`D<V5R:6%L:7IE<B`](&YE
M=R!834Q?4V5R:6%L:7IE<B@D;W!T:6]N<RD["@H@("`@)&9O;R`@("`]("`@
M4$5!4CHZ<F%I<V5%<G)O<B@B2G5S="!A('1E<W0B+"`Q,C,T*3L@("`@"B`@
M("`*("`@("1R97-U;'0@/2`D<V5R:6%L:7IE<BT^<V5R:6%L:7IE*"1F;V\I
M.PH@("`@"B`@("!I9B@@)')E<W5L="`]/3T@=')U92`I('L*("`@("`@("!E
M8VAO("`@("(\<')E/B(["B`@("`@("`@96-H;R`@("!H=&UL96YT:71I97,H
M)'-E<FEA;&EZ97(M/F=E=%-E<FEA;&EZ961$871A*"DI.PH@("`@("`@(&5C
M:&\@("`@(CPO<')E/B(["B`@("!]"C\^````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE
M<R]S97)I86QI>F57:71H26YD96YT961!='1R:6)U=&5S+G!H<``````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C8Q,B`Q,#4Q-30S,S<S
M,"`P,S,Q-#$`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]02%`*+RHJ"B`J(%A-3"!397)I86QI>F5R(&5X86UP;&4*("H*
M("H@5&AI<R!E>&%M<&QE(&1E;6]N<W1R871E<RP@:&]W(%A-3%]397)I86QI
M>F5R(&ES(&%B;&4*("H@=&\@<V5R:6%L:7IE('-C86QA<B!V86QU97,@87,@
M86X@871T<FEB=71E(&EN<W1E860@;V8@82!N97-T960@=&%G+@H@*@H@*B!)
M;B!T:&ES(&5X86UP;&4@=&%G<R!W:71H(&UO<F4@=&AA;B!O;F4@871T<FEB
M=71E(&)E8V]M90H@*B!M=6QT:6QI;F4@=&%G<RP@87,@96%C:"!A='1R:6)U
M=&4@9V5T<R!W<FET=&5N('1O(&$*("H@<V5P87)A=&4@;&EN92!A<R`G:6YD
M96YT071T<FEB=71E<R<@:7,@<V5T('1O("=?875T;R<N"B`J"B`J($!A=71H
M;W(@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("HO"B`@("!E
M<G)O<E]R97!O<G1I;F<H15]!3$PI.PH@("`@<F5Q=6ER95]O;F-E("=834PO
M4V5R:6%L:7IE<BYP:'`G.PH*("`@("1O<'1I;VYS(#T@87)R87DH"B`@("`@
M("`@("`@("`@("`@("`@("`@(")I;F1E;G0B("`@("`@("`@("`@(#T^("(@
M("`@(BP*("`@("`@("`@("`@("`@("`@("`@("`@(FQI;F5B<F5A:R(@("`@
M("`@("`@/3X@(EQN(BP*("`@("`@("`@("`@("`@("`@("`@("`@(G1Y<&5(
M:6YT<R(@("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@
M("`@(")D969A=6QT5&%G3F%M92(@("`@(#T^(")U;FYA;65D271E;2(L"B`@
M("`@("`@("`@("`@("`@("`@("`@(")S8V%L87)!<T%T=')I8G5T97,B(#T^
M('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@(")I;F1E;G1!='1R:6)U
M=&5S(B`@(#T^(")?875T;R(*("`@("`@("`@("`@("`@("`@("`I.PH@("`@
M"B`@("`O+R!T:&ES(&ES(&IU<W0@=&\@9V5T(&$@;F5S=&5D(&]B:F5C=`H@
M("`@)'!E87)%<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H)U1H:7,@:7,@:G5S
M="!A;B!E<G)O<B!O8FIE8W0G+#$R,RD["@D*("`@("1F;V\@("`@/2`@(&YE
M=R!S=&1#;&%S<SL*("`@(`H@("`@)&9O;RT^=F%L=64@/2`B37D@=F%L=64B
M.PH@("`@)&9O;RT^97)R;W(@/2`D<&5A<D5R<F]R.PH@("`@)&9O;RT^>&UL
M("`@/2`B8V]O;"(["B`@("`*("`@("1S97)I86QI>F5R(#T@;F5W(%A-3%]3
M97)I86QI>F5R*"1O<'1I;VYS*3L*("`@(`H@("`@)')E<W5L="`]("1S97)I
M86QI>F5R+3YS97)I86QI>F4H)&9O;RD["B`@("`*("`@(&EF*"`D<F5S=6QT
M(#T]/2!T<G5E("D@>PH)"21X;6P@/2`D<V5R:6%L:7IE<BT^9V5T4V5R:6%L
M:7IE9$1A=&$H*3L*"@D@("`@96-H;PDB/'!R93XB.PH)("`@('!R:6YT7W(H
M(&AT;6QS<&5C:6%L8VAA<G,H)'AM;"D@*3L*"2`@("!E8VAO"2(\+W!R93XB
M.PH@("`@?2!E;'-E('L*"0EE8VAO"2(\<')E/B(["@D)<')I;G1?<B@D<F5S
M=6QT*3L*"0EE8VAO"2(\+W!R93XB.PH)?0H*/SX`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S
M+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W-E<FEA;&EZ95=I=&A.86UE<W!A
M8V4N<&AP`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`R,#,S(#$P-3$U-#,S-S,P(#`S,3(S,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/U!(4`HO*BH*("H@17AA
M;7!L92!T:&%T(&-R96%T97,@=&%G<R!W:71H(&$@;F%M97-P86-E"B`J"B`J
M($!A=71H;W(@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P:'`N;F5T/@H@*B\*
M97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L*"G)E<75I<F5?;VYC92`G6$U,+U-E
M<FEA;&EZ97(N<&AP)SL*"B1O<'1I;VYS(#T@87)R87DH"B`@("`@("`@("`@
M("`@("`@("`@)VEN9&5N="<@("`@("`@("`]/B`G("`G+`H@("`@("`@("`@
M("`@("`@("`@("=L:6YE8G)E86LG("`@("`@/3X@(EQN(BP*("`@("`@("`@
M("`@("`@("`@("`G9&5F875L=%1A9TYA;64G(#T^("=I=&5M)RP*("`@("`@
M("`@("`@("`@("`@("`G;F%M97-P86-E)R`@("`@(#T^("=F;V\G"B`@("`@
M("`@("`@("`@("`I.PH*)&9O;R`@("`]("`@;F5W('-T9$-L87-S.PHD9F]O
M+3YV86QU92`]("=->2!V86QU92<["B1F;V\M/GAM;"`@(#T@)V-O;VPG.PH*
M)&9O;RT^;V)J"3T@;F5W('-T9$-L87-S.PHD9F]O+3YA<G(@("`](&%R<F%Y
M*"D["B1F;V\M/GIE<F\@(#T@,#L*"B1S97)I86QI>F5R(#T@)FYE=R!834Q?
M4V5R:6%L:7IE<B@D;W!T:6]N<RD["@HD<F5S=6QT(#T@)'-E<FEA;&EZ97(M
M/G-E<FEA;&EZ92@D9F]O*3L*"FEF*"`D<F5S=6QT(#T]/2!T<G5E("D@>PH)
M)'AM;"`]("1S97)I86QI>F5R+3YG971397)I86QI>F5D1&%T82@I.PI]"@IE
M8VAO"2<\<')E/B<["G!R:6YT7W(H(&AT;6QS<&5C:6%L8VAA<G,H)'AM;"D@
M*3L*96-H;PDG/"]P<F4^)SL*"B\O(&%L<V\@<&%S<R!T:&4@55))"B1S97)I
M86QI>F5R+3YS971/<'1I;VXH)VYA;65S<&%C92<L(&%R<F%Y*"=B87(G+"`G
M:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+UA-3%]397)I86QI>F5R)RDI
M.PH*)')E<W5L="`]("1S97)I86QI>F5R+3YS97)I86QI>F4H)&9O;RD["@II
M9B@@)')E<W5L="`]/3T@=')U92`I('L*"21X;6P@/2`D<V5R:6%L:7IE<BT^
M9V5T4V5R:6%L:7IE9$1A=&$H*3L*?0H*96-H;PDG/'!R93XG.PIP<FEN=%]R
M*"!H=&UL<W!E8VEA;&-H87)S*"1X;6PI("D["F5C:&\))SPO<')E/B<["C\^
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L
M97,O<V5R:6%L:7IE5VET:%1A9TUA<"YP:'``````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#0Q-#0@,3`U,34T,S,W
M,S`@,#,P-3$S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_4$A0"B\J*@H@*B!834P@4V5R:6%L:7IE<B!E>&%M<&QE"B`J
M"B`J(%1H:7,@97AA;7!L92!D96UO;G-T<F%T97,L(&AO=R!834Q?4V5R:6%L
M:7IE<B!I<R!A8FQE"B`J('1O('-E<FEA;&EZ92!S8V%L87(@=F%L=65S(&%S
M(&%N(&%T=')I8G5T92!I;G-T96%D(&]F(&$@;F5S=&5D('1A9RX*("H*("H@
M26X@=&AI<R!E>&%M<&QE('1A9W,@=VET:"!M;W)E('1H86X@;VYE(&%T=')I
M8G5T92!B96-O;64*("H@;75L=&EL:6YE('1A9W,L(&%S(&5A8V@@871T<FEB
M=71E(&=E=',@=W)I='1E;B!T;R!A"B`J('-E<&%R871E(&QI;F4@87,@)VEN
M9&5N=$%T=')I8G5T97,G(&ES('-E="!T;R`G7V%U=&\G+@H@*@H@*B!`875T
M:&]R("!3=&5P:&%N(%-C:&UI9'0@/'-C:'-T0'!H<"YN970^"B`J+PH@("`@
M97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L*("`@(')E<75I<F5?;VYC92`G6$U,
M+U-E<FEA;&EZ97(N<&AP)SL*"B`@("`D;W!T:6]N<R`](&%R<F%Y*`H@("`@
M("`@("`@("`@("`@("`@("`@("`G:6YD96YT)R`@("`@("`@("`@("`]/B`G
M("`@("<L"B`@("`@("`@("`@("`@("`@("`@("`@("=L:6YE8G)E86LG("`@
M("`@("`@(#T^(")<;B(L"B`@("`@("`@("`@("`@("`@("`@("`@("=M;V1E
M)R`@("`@("`@("`@("`@(#T^("=S:6UP;&5X;6PG+`H@("`@("`@("`@("`@
M("`@("`@("`@("`G<F]O=$YA;64G"0D)(#T^("=I=&5M<R<*("`@("`@("`@
M("`@("`@("`@("`I.PH*("`@("1D871A(#T@87)R87DH"@D)"0D))VET96TG
M(#T^(&%R<F%Y*"!A<G)A>2@*"0D)"0D)"0D)"2=T:71L92<@("`@("`@/3X@
M)T9O;V)A<B$G+`H)"0D)"0D)"0D))V1E<V-R:7!T:6]N)R`]/B`G5&AI<R!I
M<R!S;VUE('1E>'0N+BXN)RP*"0D)"0D)"0D)"2=L:6YK)R`@("`@("`@/3X@
M)VAT='`Z+R]F;V]B87(N8V]M)PH)"0D)"0D)"0DI+`H)"0D)"0D)"0EA<G)A
M>2@*"0D)"0D)"0D)"2=T:71L92<@("`@("`@/3X@)T9O;V)A<C(A)RP*"0D)
M"0D)"0D)"2=D97-C<FEP=&EO;B<@/3X@)U1H:7,@:7,@<V]M92!T97AT+OP@
M)G5U;6P[(.0@]B<L"@D)"0D)"0D)"0DG;&EN:R<@("`@("`@(#T^("=H='1P
M.B\O9F]O8F%R+F-O;2<*"0D)"0D)"0D)*0H)"0D)"0D)"2D*"2`@("`)"0D)
M"0D)"0D)"0D*("`@(`D)"2D["B`@("`@("`@("`@("`@("`@("`@"B`@("`*
M("`@("1S97)I86QI>F5R(#T@;F5W(%A-3%]397)I86QI>F5R*"1O<'1I;VYS
M*3L*("`@(`H@("`@)')E<W5L="`]("1S97)I86QI>F5R+3YS97)I86QI>F4H
M)&1A=&$I.PH@("`@"B`@("!I9B@@)')E<W5L="`]/3T@=')U92`I('L*"0DD
M>&UL(#T@)'-E<FEA;&EZ97(M/F=E=%-E<FEA;&EZ961$871A*"D["@H)("`@
M(&5C:&\))SQP<F4^)SL*"2`@("!P<FEN=%]R*"!H=&UL<W!E8VEA;&-H87)S
M*"1X;6PI("D["@D@("`@96-H;PDG/"]P<F4^)SL*("`@('T@96QS92!["@D)
M96-H;PDG/'!R93XG.PH)"7!R:6YT7W(H)')E<W5L="D["@D)96-H;PDG/"]P
M<F4^)SL*"7T*"@DD;F5W3W!T:6]N<R`](&%R<F%Y*`H)"0D)"0DG<F]O=$YA
M;64G(#T^("=B;V1Y)RP*"0D)"0D))W)E<&QA8V5%;G1I=&EE<R<@/3X@6$U,
M7U-%4DE!3$E:15)?14Y4251)15-?2%1-3"P*"0D)"0D))W1A9TUA<"<@("`]
M/B!A<G)A>2@*"0D)"0D)("`@("`@("`@("`@("`@("`@("`@("=I=&5M)R`@
M("`@("`@/3X@)V1I=B<L"@D)"0D)"2`@("`@("`@("`@("`@("`@("`@("`G
M=&ET;&4G("`@("`@(#T^("=H,2<L"@D)"0D)"2`@("`@("`@("`@("`@("`@
M("`@("`G9&5S8W)I<'1I;VXG(#T^("=P)RP*"0D)"0D)("`@("`@("`@("`@
M("`@("`@("`@("=L:6YK)R`@("`@("`@/3X@)W1T)PH)"0D)"0D@("`@("`@
M("`@("`@("`@("`I"@D)"0D)*3L*"0H@("`@)')E<W5L="`]("1S97)I86QI
M>F5R+3YS97)I86QI>F4H)&1A=&$L("1N97=/<'1I;VYS*3L*("`@(`H@("`@
M:68H("1R97-U;'0@/3T]('1R=64@*2!["@D))'AM;"`]("1S97)I86QI>F5R
M+3YG971397)I86QI>F5D1&%T82@I.PH*"2`@("!E8VAO"2<\<')E/B<["@D@
M("`@<')I;G1?<B@@:'1M;'-P96-I86QC:&%R<R@D>&UL*2`I.PH)("`@(&5C
M:&\))SPO<')E/B<["B`@("!](&5L<V4@>PH)"65C:&\))SQP<F4^)SL*"0EP
M<FEN=%]R*"1R97-U;'0I.PH)"65C:&\))SPO<')E/B<["@E]"@H_/@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA
M;&EZ97(O97AA;7!L97,O=6YS97)I86QI>F5!;GE834PN<&AP````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#4P
M-C$@,3`U,34T,S,W,S`@,#,P,38P`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_4$A0"B\J*@H@*B!4:&ES(&5X86UP;&4@
M<VAO=W,@9&EF9F5R96YT(&UE=&AO9',@:&]W"B`J(%A-3%]5;G-E<FEA;&EZ
M97(@8V%N(&)E('5S960@=&\@8W)E871E(&1A=&$@<W1R=6-T=7)E<PH@*B!F
M<F]M(%A-3"!D;V-U;65N=',N"B`J"B`J($!A=71H;W(@(%-T97!H86X@4V-H
M;6ED="`\<V-H<W1`<&AP+FYE=#X*("HO"F5R<F]R7W)E<&]R=&EN9RA%7T%,
M3"D["@HO+R!T:&ES(&ES(&$@<VEM<&QE(%A-3"!D;V-U;65N=`HD>&UL(#T@
M)SQU<V5R<SXG("X*("`@("`@("<@(#QU<V5R(&AA;F1L93TB<V-H<W0B/E-T
M97!H86X@4V-H;6ED=#PO=7-E<CXG("X*("`@("`@("<@(#QU<V5R(&AA;F1L
M93TB;6HB/DUA<G1I;B!*86YS96X\+W5S97(^)R`N"B`@("`@("`G("`\9W)O
M=7`@;F%M93TB<6$B/E!%05(@44$@5&5A;3PO9W)O=7`^)R`N"B`@("`@("`G
M("`\9F]O(&ED/2)T97-T(CY4:&ES(&ES(&AA;F1L960@8GD@=&AE(&1E9F%U
M;'0@:V5Y071T<FEB=71E/"]F;V\^)R`N"B`@("`@("`G("`\9F]O(&ED/2)T
M97-T,B(^06YO=&AE<B!F;V\@=&%G/"]F;V\^)R`N"B`@("`@("`G/"]U<V5R
M<SXG.PH*<F5Q=6ER95]O;F-E("=834PO56YS97)I86QI>F5R+G!H<"<["@HO
M+R!C;VUP;&5X('-T<G5C='5R97,@87)E(&%R<F%Y<RP@=&AE(&ME>2!I<R!T
M:&4@871T<FEB=71E("=H86YD;&4G(&]R("=N86UE)RP@:68@:&%N9&QE(&ES
M(&YO="!P<F5S96YT"B1O<'1I;VYS(#T@87)R87DH"B`@("`@("`@("`@("`@
M("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?0T]-4$Q%6%194$4@/3X@)V%R
M<F%Y)RP*("`@("`@("`@("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/
M3E]!5%1224)55$5?2T59(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G=7-E<B<@("`@(#T^("=H86YD;&4G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G9W)O=7`G("`@(#T^("=N86UE)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)R-D969A=6QT)R`]/B`G:60G"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I"B`@("`@
M("`@("`@("`@("`I.PH*+R\@(&)E(&-A<F5F=6P@=&\@86QW87ES('5S92!T
M:&4@86UP97)S86YD(&EN(&9R;VYT(&]F('1H92!N97<@;W!E<F%T;W(@"B1U
M;G-E<FEA;&EZ97(@/2`F;F5W(%A-3%]5;G-E<FEA;&EZ97(H)&]P=&EO;G,I
M.PH*+R\@=7-E<FEA;&EZ92!T:&4@9&]C=6UE;G0*)'-T871U<R`]("1U;G-E
M<FEA;&EZ97(M/G5N<V5R:6%L:7IE*"1X;6PL(&9A;'-E*3L@("`@"@II9B`H
M4$5!4CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@96-H;R`G17)R;W(Z("<@
M+B`D<W1A='5S+3YG971-97-S86=E*"D["GT@96QS92!["B`@("`D9&%T82`]
M("1U;G-E<FEA;&EZ97(M/F=E=%5N<V5R:6%L:7IE9$1A=&$H*3L*("`@(&5C
M:&\@)SQP<F4^)SL*("`@('!R:6YT7W(H)&1A=&$I.PH@("`@96-H;R`G/"]P
M<F4^)SL*?0H*"B\O('5N<V5R:6%L:7IE(&ET(&%G86EN(&%N9"!C:&%N9V4@
M=&AE(&-O;7!L97A4>7!E(&]P=&EO;@HO+R!B=70@;&5A=F4@;W1H97(@;W!T
M:6]N<R!U;G1O=6-H960*+R\@;F]W(&-O;7!L97@@='EP97,@=VEL;"!B92!A
M;B!O8FIE8W0L(&%N9"!T:&4@<')O<&5R='D@;F%M92!W:6QL(&)E(&EN('1H
M90HO+R!A='1R:6)U=&4@)VAA;F1L92<*)'-T871U<R`]("1U;G-E<FEA;&EZ
M97(M/G5N<V5R:6%L:7IE*"1X;6PL(&9A;'-E+"!A<G)A>2A834Q?54Y315))
M04Q)6D527T]05$E/3E]#3TU03$585%E012`]/B`G;V)J96-T)RDI.PH*:68@
M*%!%05(Z.FES17)R;W(H)'-T871U<RDI('L*("`@(&5C:&\@)T5R<F]R.B`G
M("X@)'-T871U<RT^9V5T365S<V%G92@I.PI](&5L<V4@>PH@("`@)&1A=&$@
M/2`D=6YS97)I86QI>F5R+3YG9715;G-E<FEA;&EZ961$871A*"D["B`@("!E
M8VAO("<\<')E/B<["B`@("!P<FEN=%]R*"1D871A*3L*("`@(&5C:&\@)SPO
M<')E/B<["GT*"B\O('5N<V5R:6%L:7IE(&ET(&%G86EN(&%N9"!C:&%N9V4@
M=&AE(&-O;7!L97A4>7!E(&]P=&EO;@HO+R!A;F0@<F5S970@86QL(&]T:&5R
M(&]P=&EO;G,*+R\@3F]W+"!T:&5R92=S(&YO(&ME>2!S;R!T:&4@=&%G<R!A
M<F4@<W1O<F5D(&EN(&%N(&%R<F%Y"B1S=&%T=7,@/2`D=6YS97)I86QI>F5R
M+3YU;G-E<FEA;&EZ92@D>&UL+"!F86QS92P@87)R87DH6$U,7U5.4T5224%,
M25I%4E]/4%1)3TY?3U9%4E))1$5?3U!424].4R`]/B!T<G5E+"!834Q?54Y3
M15))04Q)6D527T]05$E/3E]#3TU03$585%E012`]/B`G;V)J96-T)RDI.R`@
M("`*"FEF("A014%2.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@("!E8VAO("=%
M<G)O<CH@)R`N("1S=&%T=7,M/F=E=$UE<W-A9V4H*3L*?2!E;'-E('L*("`@
M("1D871A(#T@)'5N<V5R:6%L:7IE<BT^9V5T56YS97)I86QI>F5D1&%T82@I
M.PH@("`@96-H;R`G/'!R93XG.PH@("`@<')I;G1?<B@D9&%T82D["B`@("!E
M8VAO("<\+W!R93XG.PI]"C\^````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]U
M;G-E<FEA;&EZ94-L87-S3F%M97,N<&AP```````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C,P-B`Q,#4Q-30S,S<S,"`P
M,S$Q,#``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]02%`*+RHJ"B`J($5X86UP;&4@=&AA="!S:&]W<R!H;W<@=&\@:6YF
M;'5E;F-E('1H92!C;&%S<V5S('1H870@87)E(&-R96%T960N"B`J"B`J($!A
M=71H;W(@("`@("!3=&5P:&%N(%-C:&UI9'0@/'-C:'-T0'!H<"YN970^"B`J
M($!C871E9V]R>2`@("!834P*("H@0'!A8VMA9V4@("`@(%A-3%]397)I86QI
M>F5R"B`J($!S=6)P86-K86=E("!%>&%M<&QE<PH@*B\*97)R;W)?<F5P;W)T
M:6YG*$5?04Q,*3L*"B\J*@H@*B!U<V5S(%A-3%]5;G-E<FEA;&EZ97(*("HO
M"G)E<75I<F5?;VYC92`G6$U,+U5N<V5R:6%L:7IE<BYP:'`G.PH*)'AM;"`]
M(#P\/$5/5`H\<F]O=#X*("`@/&9O;SX*("`@("`\='EP93YB87(\+W1Y<&4^
M"B`@(#PO9F]O/@H@("`\8F%R('1Y<&4](F9O;R(O/@H\+W)O;W0^"D5/5#L*
M"F-L87-S(&9O;PI["GT*8VQA<W,@8F%R"GL*?0H*96-H;R`G/'!R93XG.PHO
M+R`@8F4@8V%R969U;"!T;R!A;'=A>7,@=7-E('1H92!A;7!E<G-A;F0@:6X@
M9G)O;G0@;V8@=&AE(&YE=R!O<&5R871O<B`*)'5N<V5R:6%L:7IE<B`]("9N
M97<@6$U,7U5N<V5R:6%L:7IE<B@I.PHD=6YS97)I86QI>F5R+3YS971/<'1I
M;VXH6$U,7U5.4T5224%,25I%4E]/4%1)3TY?0T]-4$Q%6%194$4L("=O8FIE
M8W0G*3L*)'5N<V5R:6%L:7IE<BT^<V5T3W!T:6]N*%A-3%]53E-%4DE!3$E:
M15)?3U!424].7T%45%))0E5415-?4$%24T4L('1R=64I.PHD=6YS97)I86QI
M>F5R+3YS971/<'1I;VXH6$U,7U5.4T5224%,25I%4E]/4%1)3TY?4D5455).
M7U)%4U5,5"P@=')U92D["@HD9&%T82`]("1U;G-E<FEA;&EZ97(M/G5N<V5R
M:6%L:7IE*"1X;6PI.R`@("`*=F%R7V1U;7`H)&1A=&$I.PH*96-H;R`B1&\@
M;F]T('5S92!T86=N86UE(&%S(&-L87-S(&YA;65<;B(["B1U;G-E<FEA;&EZ
M97(M/G-E=$]P=&EO;BA834Q?54Y315))04Q)6D527T]05$E/3E]404=?05-?
M0TQ!4U-.04U%+"!F86QS92D["B1D871A(#T@)'5N<V5R:6%L:7IE<BT^=6YS
M97)I86QI>F4H)'AM;"D[("`@(`IV87)?9'5M<"@@)&1A=&$@*3L*"F5C:&\@
M(E5S92!A(&1I9F9E<F5N="!D969A=6QT(&-L87-S7&XB.PHD=6YS97)I86QI
M>F5R+3YS971/<'1I;VXH6$U,7U5.4T5224%,25I%4E]/4%1)3TY?1$5&055,
M5%]#3$%34RP@)V9O;R<I.PHD9&%T82`]("1U;G-E<FEA;&EZ97(M/G5N<V5R
M:6%L:7IE*"1X;6PI.R`@("`*=F%R7V1U;7`H("1D871A("D["@IE8VAO("<\
M+W!R93XG.PH_/@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-
M3%]397)I86QI>F5R+V5X86UP;&5S+W5N<V5R:6%L:7IE16YC;V1E9"YP:'``
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`Q-C8U(#$P-3$U-#,S-S,P(#`S,#0Q-P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/U!(4`HO*BH*("H@5&AI<R!E
M>&%M<&QE('-H;W=S(&AO=R!T;R!S970@82!D:69F97)E;G0@=&%R9V5T(&5N
M8V]D:6YG"B`J"B`J($!A=71H;W(@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`
M<&AP+FYE=#X*("HO"F5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["@IR97%U:7)E
M7V]N8V4@)UA-3"]5;G-E<FEA;&EZ97(N<&AP)SL*"B1X;6P@/2`G/&1I8W0^
M"B`@(#QW;W)D/@H@("`@(#QE;CYC:&EC:V5N=VEN9W,\+V5N/@H@("`@(#QD
M93XG+G5T9CA?96YC;V1E*"=(Y&AN8VAE;F9L_&=E;"<I+B<\+V1E/@H@("`\
M+W=O<F0^"B`\+V1I8W0^)SL*("`@(`HO+R!S<&5C:69Y(&1I9F9E<F5N="!S
M;W5R8V4@86YD('1A<F=E="!E;F-O9&EN9W,*)&]P=&EO;G,@/2!A<G)A>2@*
M("`@("`@("`@("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?14Y#
M3T1)3D=?4T]54D-%(#T^("=55$8M."<L"B`@("`@("`@("`@("`@("`@(%A-
M3%]53E-%4DE!3$E:15)?3U!424].7T5.0T]$24Y'7U1!4D=%5"`]/B`G25-/
M+3@X-3DM,2<*("`@("`@("`@("`@("`@("D["@H@("`@("`@("`@("`@("`@
M"B\O("!B92!C87)E9G5L('1O(&%L=V%Y<R!U<V4@=&AE(&%M<&5R<V%N9"!I
M;B!F<F]N="!O9B!T:&4@;F5W(&]P97)A=&]R(`HD=6YS97)I86QI>F5R(#T@
M)FYE=R!834Q?56YS97)I86QI>F5R*"1O<'1I;VYS*3L*"B\O('5S97)I86QI
M>F4@=&AE(&1O8W5M96YT"B1S=&%T=7,@/2`D=6YS97)I86QI>F5R+3YU;G-E
M<FEA;&EZ92@D>&UL*3L*"FEF("A014%2.CII<T5R<F]R*"1S=&%T=7,I*2![
M"B`@("!E8VAO("=%<G)O<CH@)R`N("1S=&%T=7,M/F=E=$UE<W-A9V4H*3L*
M?2!E;'-E('L*("`@("1D871A(#T@)'5N<V5R:6%L:7IE<BT^9V5T56YS97)I
M86QI>F5D1&%T82@I.PH@("`@96-H;R`G/'!R93XG.PH@("`@<')I;G1?<B@D
M9&%T82D["B`@("!E8VAO("<\+W!R93XG.PI]"C\^````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D
M;V-S+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W5N<V5R:6%L:7IE16YU;2YP
M:'```````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`R,C0S(#$P-3$U-#,S-S,P(#`R-S<U,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/U!(4`HO*BH*("H@
M5&AI<R!E>&%M<&QE('-H;W=S(&AO=R!T;R!U<V4@=&AE(%A-3%]53E-%4DE!
M3$E:15)?3U!424].7T9/4D-%7T5.54T*("H@;W!T:6]N"B`J"B`J($!A=71H
M;W(@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("HO"F5R<F]R
M7W)E<&]R=&EN9RA%7T%,3"D["@IR97%U:7)E7V]N8V4@)UA-3"]5;G-E<FEA
M;&EZ97(N<&AP)SL*"B1X;6PQ(#T@)SQR;V]T/@H@("`\:71E;3X*("`@("`\
M;F%M93YS8VAS=#PO;F%M93X*("`@/"]I=&5M/@H@("`\:71E;3X*("`@("`\
M;F%M93YL=6-K96,\+VYA;64^"B`@(#PO:71E;3X*(#PO<F]O=#XG.PH@("`@
M"B1X;6PR(#T@)SQR;V]T/@H@("`\:71E;3X*("`@("`\;F%M93YS8VAS=#PO
M;F%M93X*("`@/"]I=&5M/@H@/"]R;V]T/B<["B`@("`*)&]P=&EO;G,@/2!A
M<G)A>2@*("`@("`@("`@("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)
M3TY?1D]20T5?14Y532`]/B!A<G)A>2@G:71E;2<I"B`@("`@("`@("`@("`@
M("`I.PH*("`@("`@("`@("`@("`@(`HO+R`@8F4@8V%R969U;"!T;R!A;'=A
M>7,@=7-E('1H92!A;7!E<G-A;F0@:6X@9G)O;G0@;V8@=&AE(&YE=R!O<&5R
M871O<B`*)'5N<V5R:6%L:7IE<B`]("9N97<@6$U,7U5N<V5R:6%L:7IE<B@D
M;W!T:6]N<RD["@HO+R!U<V5R:6%L:7IE('1H92!D;V-U;65N=`HD<W1A='5S
M(#T@)'5N<V5R:6%L:7IE<BT^=6YS97)I86QI>F4H)'AM;#$I.PH*:68@*%!%
M05(Z.FES17)R;W(H)'-T871U<RDI('L*("`@(&5C:&\@)T5R<F]R.B`G("X@
M)'-T871U<RT^9V5T365S<V%G92@I.PI](&5L<V4@>PH@("`@)&1A=&$@/2`D
M=6YS97)I86QI>F5R+3YG9715;G-E<FEA;&EZ961$871A*"D["B`@("!E8VAO
M("<\<')E/B<["B`@("!P<FEN=%]R*"1D871A*3L*("`@(&5C:&\@)SPO<')E
M/B<["GT*"B\O('5S97)I86QI>F4@=&AE(&1O8W5M96YT"B1S=&%T=7,@/2`D
M=6YS97)I86QI>F5R+3YU;G-E<FEA;&EZ92@D>&UL,BD["@II9B`H4$5!4CHZ
M:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@96-H;R`G17)R;W(Z("<@+B`D<W1A
M='5S+3YG971-97-S86=E*"D["GT@96QS92!["B`@("`D9&%T82`]("1U;G-E
M<FEA;&EZ97(M/F=E=%5N<V5R:6%L:7IE9$1A=&$H*3L*("`@(&5C:&\@)SQP
M<F4^)SL*("`@('!R:6YT7W(H)&1A=&$I.PH@("`@96-H;R`G/"]P<F4^)SL*
M?0H_/@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA
M;7!L97,O=6YS97)I86QI>F5/8FIE8W0N<&AP````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(W,#`@,3`U,34T
M,S,W,S`@,#,P,C4S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_4$A0"B\J*@H@*B!4:&ES(&5X86UP;&4@<VAO=W,@:&]W
M(%A-3%]397)I86QI>F5R(&%N9"!834Q?56YS97)I86QI>F5R"B`J('=O<FL@
M=&]G971H97(N"B`J"B`J($$@<W1R=6-T=7)E(&ES('-E<FEA;&EZ960@86YD
M(&QA=&5R(&ET)W,@=6YS97)I86QI>F5D(&9R;VT@=&AE"B`J(')E<W5L=&EN
M9R!834P@9&]C=6UE;G0N"B`J"B`J($!A=71H;W(@(%-T97!H86X@4V-H;6ED
M="`\<V-H<W1`<&AP+FYE=#X*("HO"F5R<F]R7W)E<&]R=&EN9RA%7T%,3"D[
M"@IR97%U:7)E7V]N8V4@)UA-3"]397)I86QI>F5R+G!H<"<["G)E<75I<F5?
M;VYC92`G6$U,+U5N<V5R:6%L:7IE<BYP:'`G.PHO+R!T:&ES(&ES(&IU<W0@
M=&\@9V5T(&$@;F5S=&5D(&]B:F5C=`HD<&5A<D5R<F]R(#T@4$5!4CHZ<F%I
M<V5%<G)O<B@G5&AI<R!I<R!J=7-T(&%N(&5R<F]R(&]B:F5C="<L,3(S*3L*
M"B1O<'1I;VYS(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@6$U,7U-%
M4DE!3$E:15)?3U!424].7TE.1$5.5"`@("`@(#T^("<@("`@)RP*("`@("`@
M("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?3$E.14)214%+
M4R`@/3X@(EQN(BP*("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%
M4E]/4%1)3TY?1$5&055,5%]404<@/3X@)W5N;F%M961)=&5M)RP*("`@("`@
M("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?5%E014A)3E13
M("`@/3X@=')U90H@("`@("`@("`@("`@("`@*3L*"B1F;V\@/2!N97<@<W1D
M0VQA<W,H*3L*)&9O;RT^=F%L=64@/2`G37D@=F%L=64G.PHD9F]O+3YE<G)O
M<B`]("1P96%R17)R;W(["B1F;V\M/GAM;"`@(#T@87)R87DH)U1H:7,@:7,G
M(#T^("=C;V]L)RD["B1F;V\M/G)E<V]U<F-E(#T@9F]P96XH7U]&24Q%7U\L
M("=R)RD["@HD<V5R:6%L:7IE<B`](&YE=R!834Q?4V5R:6%L:7IE<B@D;W!T
M:6]N<RD["B1R97-U;'0@/2`D<V5R:6%L:7IE<BT^<V5R:6%L:7IE*"1F;V\I
M.PH*:68@*"1R97-U;'0@/3T]('1R=64I('L*("`@("1X;6P@/2`D<V5R:6%L
M:7IE<BT^9V5T4V5R:6%L:7IE9$1A=&$H*3L*?0H*96-H;R`G/'!R93XG.PIE
M8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'AM;"D["F5C:&\@)SPO<')E/B<["@HO
M+R`@8F4@8V%R969U;"!T;R!A;'=A>7,@=7-E('1H92!A;7!E<G-A;F0@:6X@
M9G)O;G0@;V8@=&AE(&YE=R!O<&5R871O<B`*)'5N<V5R:6%L:7IE<B`]("9N
M97<@6$U,7U5N<V5R:6%L:7IE<B@I.PH*)'-T871U<R`]("1U;G-E<FEA;&EZ
M97(M/G5N<V5R:6%L:7IE*"1X;6PI.R`@("`*"FEF("A014%2.CII<T5R<F]R
M*"1S=&%T=7,I*2!["B`@("!E8VAO("=%<G)O<CH@)R`N("1S=&%T=7,M/F=E
M=$UE<W-A9V4H*3L*?2!E;'-E('L*("`@("1D871A(#T@)'5N<V5R:6%L:7IE
M<BT^9V5T56YS97)I86QI>F5D1&%T82@I.PH@("`@96-H;R`G/'!R93XG.PH@
M("`@<')I;G1?<B@D9&%T82D["B`@("!E8VAO("<\+W!R93XG.PI]"C\^````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]U;G-E<FEA;&EZ95)$1BYP
M:'`````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P-#$R,B`Q,#4Q-30S,S<S,"`P,C<T-C``(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]02%`*+RHJ"B`J
M(%1H:7,@97AA;7!L92!S:&]W<R!H;W<@=&\@8W)E871E(&%N>2!O8FIE8W0*
M("H@9G)O;2!A;B!834P@9&]C=6UE;G0N($EN('1H:7,@8V%S92!W92!G970*
M("H@<V]M92!A9V=R96=A=&5D(&]B:F5C=',@9F]R(&-H86YN96P@86YD(&ET
M96US"B`J(&9R;VT@86X@4E-3(&9E960N"B`J"B`J($!A=71H;W(@(%-T97!H
M86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("HO"F5R<F]R7W)E<&]R=&EN
M9RA%7T%,3"D["@IR97%U:7)E7V]N8V4@)UA-3"]5;G-E<FEA;&EZ97(N<&AP
M)SL*"B\J*@HJ(&-L87-S(&9O<B!T:&4@4D1&(&1O8W5E;6YT"BH**@HJ+PIC
M;&%S<R!R9&9$;V-U;65N=`I["B`@("!V87(@)&-H86YN96P["B`@("!V87(@
M)&ET96T["@H@("`@9G5N8W1I;VX@9V5T271E;7,H)&%M;W5N="D*("`@('L*
M("`@("`@("!R971U<FX@87)R87E?<W!L:6-E*"1T:&ES+3YI=&5M+#`L)&%M
M;W5N="D["B`@("!]"GT*"@HO*BH**B!C;&%S<R!T:&%T(&ES('5S960@9F]R
M(&$@8VAA;FYE;"!I;B!T:&4@4E-3(&9I;&4**@HJ('EO=2!C;W5L9"!I;7!L
M96UE;G0@=VAA=&5V97(@>6]U(&QI:V4@:6X@=&AI<R!C;&%S<RP**B!P<F]P
M97)T:65S('=I;&P@8F4@<V5T(&9R;VT@=&AE(%A-3"!D;V-U;65N=`HJ+PIC
M;&%S<R!C:&%N;F5L"GL*("`@(&9U;F-T:6]N(&=E=%1I=&QE*"D*("`@('L*
M("`@("`@("!R971U<FX@("1T:&ES+3YT:71L93L*("`@('T*?0H*+RHJ"BH@
M8VQA<W,@=&AA="!I<R!U<V5D(&9O<B!A;B!I=&5M(&EN('1H92!24U,@9FEL
M90HJ"BH@>6]U(&-O=6QD(&EM<&QE;65N="!W:&%T979E<B!Y;W4@;&EK92!I
M;B!T:&ES(&-L87-S+`HJ('!R;W!E<G1I97,@=VEL;"!B92!S970@9G)O;2!T
M:&4@6$U,(&1O8W5M96YT"BHO"F-L87-S(&ET96T*>PH@("`@9G5N8W1I;VX@
M9V5T5&ET;&4H*0H@("`@>PH@("`@("`@(')E='5R;B`@)'1H:7,M/G1I=&QE
M.PH@("`@?0I]"@H*)&]P=&EO;G,@/2!A<G)A>2@*("`@("`@("`@("`@("`@
M("!834Q?54Y315))04Q)6D527T]05$E/3E]#3TU03$585%E012`]/B`G;V)J
M96-T)RP*("`@("`@("`@("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/
M3E]404=?34%0("`@("`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)D9CI2
M1$8G(#T^("=R9&9$;V-U;65N="<L("`@+R\@=&AI<R!I<R!U<V5D('1O('-P
M96-I9GD@82!C;&%S<VYA;64@9F]R('1H92!R;V]T('1A9PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("D*("`@("`@("`@("`@("`@("D["@HO+R`@8F4@8V%R969U;"!T;R!A;'=A
M>7,@=7-E('1H92!A;7!E<G-A;F0@:6X@9G)O;G0@;V8@=&AE(&YE=R!O<&5R
M871O<B`*)'5N<V5R:6%L:7IE<B`]("9N97<@6$U,7U5N<V5R:6%L:7IE<B@D
M;W!T:6]N<RD["@HD<W1A='5S(#T@)'5N<V5R:6%L:7IE<BT^=6YS97)I86QI
M>F4H)VAT='`Z+R]P96%R+G!H<"YN970O9F5E9',O;&%T97-T+G)S<R<L=')U
M92D[("`@(`H*:68@*%!%05(Z.FES17)R;W(H)'-T871U<RDI('L*("`@(&5C
M:&\@)T5R<F]R.B`G("X@)'-T871U<RT^9V5T365S<V%G92@I.PI](&5L<V4@
M>PH@("`@)')S<R`]("1U;G-E<FEA;&EZ97(M/F=E=%5N<V5R:6%L:7IE9$1A
M=&$H*3L*"B`@("!E8VAO("=4:&ES(&AA<R!B965N(')E='5R;F5D(&)Y(%A-
M3%]5;G-E<FEA;&EZ97(Z/&)R/B<["B`@("`*("`@(&5C:&\@)SQP<F4^)SL*
M("`@('!R:6YT7W(H)')S<RD["B`@("!E8VAO("<\+W!R93XG.PH*("`@(&5C
M:&\@)SQB<CX\8G(^4F]O="!486=N86UE.B`G+B1U;G-E<FEA;&EZ97(M/F=E
M=%)O;W1.86UE*"DN)SQB<CXG.PH@("`@"B`@("!E8VAO("=4:71L92!O9B!T
M:&4@8VAA;FYE;#H@)RXD<G-S+3YC:&%N;F5L+3YG9714:71L92@I+B<\8G(^
M)SL*"B`@("`D:71E;7,@/2`D<G-S+3YG971)=&5M<R@S*3L*("`@(&5C:&\@
M)SQB<CY4:71L97,@;V8@=&AE(&QA<W0@=&AR964@<F5L96%S97,Z/&)R/B<[
M"B`@("!F;W)E86-H("@D:71E;7,@87,@)&ET96TI('L*("`@("`@("!E8VAO
M("=4:71L92`Z("<N)&ET96TM/F=E=%1I=&QE*"DN)SQB<CXG.PH@("`@?0I]
M"C\^````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]U;G-E
M<FEA;&EZ95=H:71E<W!A8V4N<&AP```````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C$S,"`Q,#4Q-30S,S<S,"`P,S$Q
M,S8`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]02%`*+RHJ"B`J(%1H:7,@97AA;7!L92!S:&]W<R!H;W<@=&\@<V5T(&$@
M9&EF9F5R96YT('1A<F=E="!E;F-O9&EN9PH@*@H@*B!`875T:&]R("!3=&5P
M:&%N(%-C:&UI9'0@/'-C:'-T0'!H<"YN970^"B`J+PIE<G)O<E]R97!O<G1I
M;F<H15]!3$PI.PH*<F5Q=6ER95]O;F-E("=834PO56YS97)I86QI>F5R+G!H
M<"<["@HD>&UL(#T@)SQX;6P^"B`@(#QS=')I;F<^"B`@(`H@("`@5&AI<R!8
M34P*("`@(&1O8W5M96YT"B`@("!C;VYT86EN<PH@("`@;&EN92!B<F5A:W,N
M"@H@("`\+W-T<FEN9SX*(#PO>&UL/B<["@H*+R\@(&)E(&-A<F5F=6P@=&\@
M86QW87ES('5S92!T:&4@86UP97)S86YD(&EN(&9R;VYT(&]F('1H92!N97<@
M;W!E<F%T;W(@"B1U;G-E<FEA;&EZ97(@/2`F;F5W(%A-3%]5;G-E<FEA;&EZ
M97(H*3L*)'5N<V5R:6%L:7IE<BT^<V5T3W!T:6]N*%A-3%]53E-%4DE!3$E:
M15)?3U!424].7U)%5%523E]215-53%0L('1R=64I.PH*96-H;R`G/'!R93XG
M.PH*96-H;R`B1&5F875L="!B96AA=FEO<B`H6$U,7U5.4T5224%,25I%4E]7
M2$E415-004-%7U1224TI7&XB.PHD9&%T82`]("1U;G-E<FEA;&EZ97(M/G5N
M<V5R:6%L:7IE*"1X;6PI.PIV87)?9'5M<"@D9&%T82D["F5C:&\@(EQN7&XB
M.PH*96-H;R`B3F]R;6%L:7IE('=H:71E<W!A8V4@*%A-3%]53E-%4DE!3$E:
M15)?5TA)5$534$%#15].3U)-04Q)6D4I7&XB.PHD=6YS97)I86QI>F5R+3YS
M971/<'1I;VXH6$U,7U5.4T5224%,25I%4E]/4%1)3TY?5TA)5$534$%#12P@
M6$U,7U5.4T5224%,25I%4E]72$E415-004-%7TY/4DU!3$E:12D["B1D871A
M(#T@)'5N<V5R:6%L:7IE<BT^=6YS97)I86QI>F4H)'AM;"D["G9A<E]D=6UP
M*"1D871A*3L*96-H;R`B7&Y<;B(["@IE8VAO(")+965P('=H:71E<W!A8V4@
M*%A-3%]53E-%4DE!3$E:15)?5TA)5$534$%#15]+1450*5QN(CL*)'5N<V5R
M:6%L:7IE<BT^<V5T3W!T:6]N*%A-3%]53E-%4DE!3$E:15)?3U!424].7U=(
M251%4U!!0T4L(%A-3%]53E-%4DE!3$E:15)?5TA)5$534$%#15]+1450*3L*
M)&1A=&$@/2`D=6YS97)I86QI>F5R+3YU;G-E<FEA;&EZ92@D>&UL*3L*=F%R
M7V1U;7`H)&1A=&$I.PH*96-H;R`G/"]P<F4^)SL*/SX`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]3
M97)I86QI>F5R+V5X86UP;&5S+W5N<V5R:6%L:7IE5VET:$%T=')I8G5T97,N
M<&AP`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`Q-#,T(#$P-3$U-#,S-S,P(#`S,C`S,@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/U!(4`HO*BH*("H@5&AI<R!E>&%M
M<&QE('-H;W=S(&AO=R!T;R!P87)S92!A='1R:6)U=&5S(&9R;VT*("H@6$U,
M('1A9W,N"B`J"B`J($!A=71H;W(@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`
M<&AP+FYE=#X*("H@0'5S97,@("`@97AA;7!L92YX;6P*("HO"F5R<F]R7W)E
M<&]R=&EN9RA%7T%,3"D["@IR97%U:7)E7V]N8V4@)UA-3"]5;G-E<FEA;&EZ
M97(N<&AP)SL*"B1O<'1I;VYS(#T@87)R87DH"B`@("`@("`@("`@("`@("`@
M(%A-3%]53E-%4DE!3$E:15)?3U!424].7T%45%))0E5415-?4$%24T4@("`@
M/3X@=')U92P*("`@("`@("`@("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/
M4%1)3TY?05144DE"551%4U]!4E)!64M%62`]/B!F86QS90H@("`@("`@("`@
M("`@("`@*3L*"B\O("!B92!C87)E9G5L('1O(&%L=V%Y<R!U<V4@=&AE(&%M
M<&5R<V%N9"!I;B!F<F]N="!O9B!T:&4@;F5W(&]P97)A=&]R(`HD=6YS97)I
M86QI>F5R(#T@)FYE=R!834Q?56YS97)I86QI>F5R*"1O<'1I;VYS*3L*"B\O
M('5S97)I86QI>F4@=&AE(&1O8W5M96YT"B1S=&%T=7,@/2`D=6YS97)I86QI
M>F5R+3YU;G-E<FEA;&EZ92@G97AA;7!L92YX;6PG+"!T<G5E*3L*"FEF("A0
M14%2.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@("!E8VAO("=%<G)O<CH@)R`N
M("1S=&%T=7,M/F=E=$UE<W-A9V4H*3L*?2!E;'-E('L*("`@("1D871A(#T@
M)'5N<V5R:6%L:7IE<BT^9V5T56YS97)I86QI>F5D1&%T82@I.PH@("`@96-H
M;R`G/'!R93XG.PH@("`@<')I;G1?<B@D9&%T82D["B`@("!E8VAO("<\+W!R
M93XG.PI]"C\^````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S
M+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W5N<V5R:6%L:7IE5VET:%1A9TUA
M<"YP:'```````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`S,3<U(#$P-3$U-#,S-S,P(#`S,3`V,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/U!(4`HO*BH*("H@5&AI
M<R!E>&%M<&QE('-H;W=S(&AO=R!T;R!U<V4@=&AE('1A9TUA<"!O<'1I;VXN
M"B`J"B`J($!A=71H;W(@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE
M=#X*("HO"F5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["@HO+R!T:&ES(&ES(&$@
M<VEM<&QE(%A-3"!D;V-U;65N=`HD>&UL(#T@)SQR;V]T/B<@+@H@("`@("`@
M)R`@/&9O;SY&3T\\+V9O;SXG("X*("`@("`@("<@(#QB87(^0D%2/"]B87(^
M)R`N"B`@("`@("`G/"]R;V]T/B<["@IR97%U:7)E7V]N8V4@)UA-3"]5;G-E
M<FEA;&EZ97(N<&AP)SL*"B\O(&-O;7!L97@@<W1R=6-T=7)E<R!A<F4@87)R
M87ES+"!T:&4@:V5Y(&ES('1H92!A='1R:6)U=&4@)VAA;F1L92<@;W(@)VYA
M;64G+"!I9B!H86YD;&4@:7,@;F]T('!R97-E;G0*)&]P=&EO;G,@/2!A<G)A
M>2@*("`@("`@("`@("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/3E]#
M3TU03$585%E012`]/B`G87)R87DG+`H@("`@("`@("`@("`@("`@(%A-3%]5
M3E-%4DE!3$E:15)?3U!424].7U1!1U]-05`@("`@(#T^(&%R<F%Y*`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G9F]O)R`]/B`G8F%R)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V)A
M<B<@/3X@)V9O;R<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`I"B`@("`@("`@("`@("`@("`I
M.PH*+R\@(&)E(&-A<F5F=6P@=&\@86QW87ES('5S92!T:&4@86UP97)S86YD
M(&EN(&9R;VYT(&]F('1H92!N97<@;W!E<F%T;W(@"B1U;G-E<FEA;&EZ97(@
M/2`F;F5W(%A-3%]5;G-E<FEA;&EZ97(H)&]P=&EO;G,I.PH*+R\@=7-E<FEA
M;&EZ92!T:&4@9&]C=6UE;G0*)'-T871U<R`]("1U;G-E<FEA;&EZ97(M/G5N
M<V5R:6%L:7IE*"1X;6PL(&9A;'-E*3L@("`@"@II9B`H4$5!4CHZ:7-%<G)O
M<B@D<W1A='5S*2D@>PH@("`@96-H;R`G17)R;W(Z("<@+B`D<W1A='5S+3YG
M971-97-S86=E*"D["GT@96QS92!["B`@("`D9&%T82`]("1U;G-E<FEA;&EZ
M97(M/F=E=%5N<V5R:6%L:7IE9$1A=&$H*3L*("`@(&5C:&\@)SQP<F4^)SL*
M("`@('!R:6YT7W(H)&1A=&$I.PH@("`@96-H;R`G/"]P<F4^)SL*?0H*+R\@
M82!T860@;6]R92!C;VUP;&5X"B1X;6P@/2`G/')O;W0^)R`N"B`@("`@("`G
M("`\9F]O/B<N"B`@("`@("`G("`@(#QT;VUA=&\^-#4\+W1O;6%T;SXG+@H@
M("`@("`@)R`@/"]F;V\^)RX*("`@("`@("<@(#QB87(^)RX*("`@("`@("<@
M("`@/'1O;6%T;SXS,3PO=&]M871O/B<N"B`@("`@("`G("`\+V)A<CXG+@H@
M("`@("`@)SPO<F]O=#XG.PH*+R\@=7-E<FEA;&EZ92!T:&4@9&]C=6UE;G0*
M)'-T871U<R`]("1U;G-E<FEA;&EZ97(M/G5N<V5R:6%L:7IE*"1X;6PL(&9A
M;'-E*3L@("`@"@II9B`H4$5!4CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@
M96-H;R`G17)R;W(Z("<@+B`D<W1A='5S+3YG971-97-S86=E*"D["GT@96QS
M92!["B`@("`D9&%T82`]("1U;G-E<FEA;&EZ97(M/F=E=%5N<V5R:6%L:7IE
M9$1A=&$H*3L*("`@(&5C:&\@)SQP<F4^)SL*("`@('!R:6YT7W(H)&1A=&$I
M.PH@("`@96-H;R`G/"]P<F4^)SL*?0H_/@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?
M4V5R:6%L:7IE<B]E>&%M<&QE<R]U;G-E<FEA;&EZ95=I=&A4>7!E1W5E<W-I
M;F<N<&AP```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,38V-B`Q,#4Q-30S,S<S,"`P,S(S-#$`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]02%`*+RHJ"B`J($5X86UP;&4@
M=&AA="!S:&]W<R!H;W<@=&\@=7-E(%A-3%]5;G-E<FEA;&EZ97(@=&\*("H@
M875T;VUA=&EC86QL>2!A9&IU<W0@=&AE('1Y<&4@;V8@=&AE(&1A=&$*("H*
M("H@0&%U=&AO<B`@("`@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE
M=#X*("H@0&-A=&5G;W)Y("`@(%A-3`H@*B!`<&%C:V%G92`@("`@6$U,7U-E
M<FEA;&EZ97(*("H@0'-U8G!A8VMA9V4@($5X86UP;&5S"B`J+PIE<G)O<E]R
M97!O<G1I;F<H15]!3$PI.PH*+RHJ"B`J('5S97,@6$U,7U5N<V5R:6%L:7IE
M<@H@*B\*<F5Q=6ER95]O;F-E("<N+B]5;G-E<FEA;&EZ97(N<&AP)SL*"B1X
M;6P@/2`\/#Q%3U0*/')O;W0^"B`@(#QS=')I;F<^2G5S="!A('-T<FEN9RXN
M+CPO<W1R:6YG/@H@("`\8F]O;&5A;E9A;'5E/G1R=64\+V)O;VQE86Y686QU
M93X*("`@/&9O;SXM-38S/"]F;V\^"B`@(#QB87(^-"XW,S<S-CPO8F%R/@H@
M("`\87)R87D@9F]O/2)F86QS92(@8F%R/2(Q,B(^=')U93PO87)R87D^"CPO
M<F]O=#X*14]4.PH*)'5N<V5R:6%L:7IE<B`]("9N97<@6$U,7U5N<V5R:6%L
M:7IE<B@I.PHD=6YS97)I86QI>F5R+3YS971/<'1I;VXH6$U,7U5.4T5224%,
M25I%4E]/4%1)3TY?0T]-4$Q%6%194$4L("=A<G)A>2<I.PHD=6YS97)I86QI
M>F5R+3YS971/<'1I;VXH6$U,7U5.4T5224%,25I%4E]/4%1)3TY?05144DE"
M551%4U]005)312P@=')U92D["B1U;G-E<FEA;&EZ97(M/G-E=$]P=&EO;BA8
M34Q?54Y315))04Q)6D527T]05$E/3E]215154DY?4D5354Q4+"!T<G5E*3L*
M)'5N<V5R:6%L:7IE<BT^<V5T3W!T:6]N*%A-3%]53E-%4DE!3$E:15)?3U!4
M24].7T=515-37U194$53+"!T<G5E*3L*"B1D871A(#T@)'5N<V5R:6%L:7IE
M<BT^=6YS97)I86QI>F4H)'AM;"D[("`@(`IE8VAO("<\<')E/B<["G9A<E]D
M=6UP*"1D871A*3L*96-H;R`G/"]P<F4^)SL*/SX`````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C
M<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S97)I86QI>F5!;F12971U<FXN
M<&AP```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,3$T,2`Q,#4Q-30S,S<S,"`P,S`T,#(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]02%`*+RHJ"B`J($5X
M86UP;&4@=&AA="!U<V5S('1H92!R971U<FY297-U;'0@;W!T:6]N('1O(&1I
M<F5C=&QY(')E='5R;B!T:&4@<V5R:6%L:7IE9`H@*B!834P@9&]C=6UE;G0@
M:6X@=&AE('-E<FEA;&EZ92@I(&UE=&AO9"X*("H*("H@0&%U=&AO<B!3=&5P
M:&%N(%-C:&UI9'0@/'-C:'-T0'!H<"YN970^"B`J+PIE<G)O<E]R97!O<G1I
M;F<H15]!3$PI.PH*<F5Q=6ER95]O;F-E("=834PO4V5R:6%L:7IE<BYP:'`G
M.PH*)&]P=&EO;G,@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("!834Q?
M4T5224%,25I%4E]/4%1)3TY?24Y$14Y4("`@("`@("`]/B`G("`@("<L"B`@
M("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7U)%5%52
M3E]215-53%0@/3X@=')U90H@("`@("`@("`@("`@("`@*3L*"B1S97)I86QI
M>F5R(#T@)FYE=R!834Q?4V5R:6%L:7IE<B@D;W!T:6]N<RD["@HD9F]O(#T@
M4$5!4CHZ<F%I<V5%<G)O<B@G2G5S="!A('1E<W0G+"`Q,C,T*3L*"B1R97-U
M;'0@/2`D<V5R:6%L:7IE<BT^<V5R:6%L:7IE*"1F;V\I.PH*96-H;R`G/'!R
M93XG.PIE8VAO(&AT;6QS<&5C:6%L8VAA<G,H)')E<W5L="D["F5C:&\@)SPO
M<')E/B<["C\^````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O9&]C<R]33T%0````````````````````````````````````````````
M```````````````````````````````````````P,#`W-34@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<S,"`P,C`P-S8`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L90``````````
M````````````````````````````````````````````````````````````
M`#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S
M-S,P(#`R,34S,0`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O4T]!
M4"]E>&%M<&QE+V%T=&%C:&UE;G0N<&AP````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#$U,C4@,3`U,34T,S,W,S`@,#(T-#4T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"G)E<75I<F5?;VYC92@B
M4T]!4"]#;&EE;G0N<&AP(BD["G)E<75I<F5?;VYC92@B4T]!4"]T97-T+W1E
M<W0N=71I;&ET>2YP:'`B*3L*<F5Q=6ER95]O;F-E*")33T%0+U9A;'5E+G!H
M<"(I.PH*)&9I;&5N86UE(#T@)V%T=&%C:&UE;G0N<&AP)SL*)'8@/2`@;F5W
M(%-/05!?071T86-H;65N="@G=&5S="<L)W1E>'0O<&QA:6XG+"1F:6QE;F%M
M92D["B1M971H;V1686QU92`](&YE=R!33T%07U9A;'5E*"=T97-T871T86-H
M)RP@)U-T<G5C="<L(&%R<F%Y*"1V*2D["@HD8VQI96YT(#T@;F5W(%-/05!?
M0VQI96YT*"=M86EL=&\Z=7-E<D!D;VUA:6XN8V]M)RD["B,@8V%L;&EN9R!W
M:71H(&UI;64*)')E<W`@/2`D8VQI96YT+3YC86QL*"=E8VAO36EM94%T=&%C
M:&UE;G0G+&%R<F%Y*"1V*2P*("`@("`@("`@("`@("`@(&%R<F%Y*"=A='1A
M8VAM96YT<R<]/B=-:6UE)RP*("`@("`@("`@("`@("`@("=N86UE<W!A8V4G
M/3XG:'1T<#HO+W-O87!I;G1E<F]P+F]R9R\G+`H@("`@("`@("`@("`@("`@
M)V9R;VTG/3XG=7-E<D!D;VUA:6XN8V]M)RP*("`@("`@("`@("`@("`@("=H
M;W-T)ST^)W-M='`N9&]M86EN+F-O;2<I*3L*<')I;G0@)&-L:65N="T^=VER
M92XB7&Y<;EQN(CL*<')I;G1?<B@D<F5S<"D["@HC(&-A;&QI;F<@=VET:"!$
M24U%"B1R97-P(#T@)&-L:65N="T^8V%L;"@G96-H;TUI;65!='1A8VAM96YT
M)RQA<G)A>2@D=BDI.PHC($1)344@:&%S(&YU;&P@<W!A8V5S+"!C:&%N9V4@
M=&AE;2!S;R!W92!C86X@<V5E('1H92!W:7)E"B1W:7)E(#T@<W1R7W)E<&QA
M8V4H(EPP(BPG*B<L)&-L:65N="T^=VER92D["G!R:6YT("1W:7)E+B)<;EQN
M7&XB.PIP<FEN=%]R*"1R97-P*3L*/SX`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O
M8W,O4T]!4"]E>&%M<&QE+V-O;5]C;&EE;G0N<&AP````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#0R,C8@,3`U,34T,S,W,S`@,#(T-#0Q`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\O"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O
M('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE
M8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P@("`@("!\
M"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H
M92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L
M92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE
M(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I
M;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@
M82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@
M=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U
M=&AO<G,Z(%-H86YE($-A<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/B`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O"B\O("1)9#H@8V]M7V-L:65N="YP:'`L=B`Q+C,@,C`P
M-2\P,R\Q,"`R,SHQ-CHT,"!Y=6YO<V@@17AP("0*+R\*+R\@4T]!4%-T<G5C
M="!I<R!D969I;F5D(&EN('1H92!F;VQL;W=I;F<@9FEL90IR97%U:7)E7V]N
M8V4@)V5X86UP;&5?='EP97,N<&AP)SL*"B\J(&IU<W0@82!S:6UP;&4@97AA
M;7!L92!O9B!U<VEN9R!-4R!33T%0(&]N('=I;C,R(&%S(&$@8VQI96YT"B`@
M('1O('1H92!P:'`@<V5R=F5R+B`@*B\*"B\O;&]A9"!#3TT@4T]!4"!C;&EE
M;G0@;V)J96-T"B1S;V%P8VQI96YT(#T@;F5W($-/32@B35-33T%0+E-O87!#
M;&EE;G0S,"(I.PH*+R]C;VYN96-T('1O('=E8B!S97)V:6-E"B1S;V%P8VQI
M96YT+3YM<W-O87!I;FET*")H='1P.B\O;&]C86QH;W-T+U-/05`O97AA;7!L
M92]S97)V97(N<&AP/W=S9&PB*3L*"B\O;V)T86EN(')E<W5L="!F<F]M('=E
M8B!S97)V:6-E(&UE=&AO9`HD<F5T(#T@)'-O87!C;&EE;G0M/F5C:&]3=')I
M;F<H(E1H:7,@:7,@82!T97-T(2(I.PIP<FEN="@B)')E=%QN(BD["@HD<F5T
M(#T@)'-O87!C;&EE;G0M/F5C:&]3=')I;F=3:6UP;&4H(E1H:7,@:7,@86YO
M=&AE<B!T97-T(2(I.PIP<FEN="@B)')E=%QN(BD["@HC('1H92!F;VQL;W=I
M;F<@8V%U<V5S(&%N(&5X8V5P=&EO;B!I;B!T:&4@0T]-(&5X=&5N<VEO;@H*
M(R1R970@/2`D<V]A<&-L:65N="T^9&EV:61E*#(R+#<I.PHC<')I;G0@)'-O
M87!C;&EE;G0M/F9A=6QT8V]D93L*(W!R:6YT("1S;V%P8VQI96YT+3YF875L
M='-T<FEN9SL*(W!R:6YT*"(R,B\W/21R971<;B(I.PHC<')I;G1?<B@D<F5T
M*3L*(R1R970@/2`D<V]A<&-L:65N="T^9&EV:61E*#(R+#`I.PHC<')I;G0H
M(C(R+S`])')E=%QN(BD["@HC)'-T<G5C="`](&YE=R!33T%04W1R=6-T*"=T
M97-T('-T<FEN9R<L,3(S+#$R,RXQ,C,I.PHC)')E="`]("1S;V%P8VQI96YT
M+3YE8VAO4W1R=6-T*"1S=')U8W0I.PHC<')I;G1?<B@D<F5T*3L*"B,D<F5T
M(#T@)'-O87!C;&EE;G0M/F5C:&]3=')U8W1!<U-I;7!L951Y<&5S*"1S=')U
M8W0I.PHC<')I;G1?<B@D<F5T*3L*"C\^````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+V1O8W,O4T]!4"]E>&%M<&QE+V1I<V-O7W-E<G9E<BYP:'``
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,C(R,#`@,3`U,34T,S,W,S`@,#(U,#`T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!6
M97)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'
M<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE
M(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS
M92P@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K
M86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\
M(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O
M<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO
M+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE
M87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H
M<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@
M("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\($%U=&AO<CH@1&UI=')I(%9I;F]G<F%D;W8@/&1I;6ET<FE`=FEN
M;V=R861O=BYD93X@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@9&ES8V]?<V5R=F5R+G!H
M<"QV(#$N-2`R,#`U+S`S+S$P(#(S.C$V.C0P('EU;F]S:"!%>'`@)`H*+RH*
M("!4:&ES(&5X86UP;&4@<VAO=W,@:&]W('1O(&UA<FL@=7`@82!S97)V97(@
M;V)J96-T('-O('1H870*("!W<V1L(&9I;&5S(&UA>2!B92!D>6YA;6EC86QY
M(&=E;F5R871E9"!B>2!T:&4@<V]A<`H@('-E<G9E<BX@(%1H:7,@86QS;R!P
M<F]V:61E<R!A8V-E<W,@=&\@82!G96YE<F%T960@1$E30T\@9&]C=6UE;G0N
M"B`@5&AE(&9A8W0@=&AA="!T:&ES(&5X86UP;&4@:&%S(&%N($U0,R!C;&%S
M<R!I<R!I;B!N;R!W87D*("!R96QA=&5D('1O($1)4T-/+B`[*0H@(`H@($1)
M4T-/.B!H='1P.B\O;7-D;BYM:6-R;W-O9G0N8V]M+VUS9&YM86<O:7-S=65S
M+S`R+S`R+WAM;"]D969A=6QT+F%S<'@*("`*("!!('5R;"!A8V-E<W-I;F<@
M=&AI<R!S97)V97(@=V]U;&0@;&]O:R!L:6ME.@H@(`H@(&AT='`Z+R]L;V-A
M;&AO<W0O9&ES8V]?<V5R=F5R+G!H<#]W<V1L("AG96YE<F%T92!74T1,(&9I
M;&4I"B`@:'1T<#HO+VQO8V%L:&]S="]D:7-C;U]S97)V97(N<&AP("A'150@
M<F5Q=65S="!G96YE<F%T97,@1$E30T\I"B`@:'1T<#HO+VQO8V%L:&]S="]D
M:7-C;U]S97)V97(N<&AP("A03U-4(&9O<B!N;W)M86P@<V]A<"!R97%U97-T
M<RD**B\*"F5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["G)E<75I<F5?;VYC92`G
M4T]!4"]397)V97(N<&AP)SL*"F-L87-S($U0,T1"7T-L87-S('L*("`@('9A
M<B`D7U]D:7-P871C:%]M87`@/2!A<G)A>2@I.PH@("`@=F%R("1?7W1Y<&5D
M968@("`@(#T@87)R87DH*3L*("`@(`H@("`@9G5N8W1I;VX@35`S1$)?0VQA
M<W,@*"D@>PH@("`@("`@("\J*@H@("`@("`@("H@=&AE(&]N;'D@=V%Y('1O
M(&1E<V-R:6)E(&%L;"!M971H;V1S(&EN(%=31$P@*&UE<W-A9V5S+`H@("`@
M("`@("H@4&]R=%1Y<&4M;W!E<F%T:6]N<R!A;F0@8FEN9&EN9W,I(&ES('1O
M('5S92!?7V1I<W!A=&-H7VUA<`H@("`@("`@("H@=&\@9&5S8W)I8F4@979E
M<GD@;65T:&]D("AE=F5N(&UE=&AO9',@=7-I;F<@<VEM<&QE(&1A=&$@"B`@
M("`@("`@*B!T>7!E<R!I;B`G:6XG(&%N9"`G;W5T)R!P87)A;65T97)S+BXN
M*0H@("`@("`@("HO"B`@("`@("`@"B`@("`@("`@)'1H:7,M/E]?9&ES<&%T
M8VA?;6%P6R=387E(86QL;R==(#T*("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@*("`@("`@("`@("`@("`@("`@("`@("`@)VEN)R`]/B!A<G)A>2@G:6YP
M=70G(#T^("=S=')I;F<G*2P*("`@("`@("`@("`@("`@("`@("`@("`@)V]U
M="<@/3X@87)R87DH)W)E='5R;B<@/3X@)W-T<FEN9R<I"B`@("`@("`@("`@
M("`@("`@("`@*3L*("`@("`@("`@("`@("`@("`@("`*("`@("`@("`D=&AI
M<RT^7U]D:7-P871C:%]M87!;)U-A>51H:7-.5&EM97,G72`]"B`@("`@("`@
M("`@("`@("`@("`@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=I
M;B<@/3X@87)R87DH)U-A>51H:7,G/3XG<W1R:6YG)RPG3E1I;65S)R`]/B`G
M:6YT)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("=O=70G(#T^(&%R<F%Y
M*"=R971U<FXG(#T^("=[=7)N.DU0,T1"?4%R<F%Y3V93=')I;F=S)RD*("`@
M("`@("`@("`@("`@("`@("`I.PH@("`@("`@("`@("`@("`@("`@(`H@("`@
M("`@("1T:&ES+3Y?7V1I<W!A=&-H7VUA<%LG1V5T35`S5')A8VMS)UT@/0H@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@
M("`@("`G:6XG(#T^(&%R<F%Y*"=Q=65R>2<@/3X@)W-T<FEN9R<I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`G;W5T)R`]/B!A<G)A>2@G<F5T=7)N)R`]
M/B`G>W5R;CI-4#-$0GU'971-4#-4<F%C:W-297-U;'0G*0H@("`@("`@("`@
M("`@("`@("`@("D["B`@("`@("`@("`@("`@("`@("`@"B`@("`@("`@)'1H
M:7,M/E]?9&ES<&%T8VA?;6%P6R=!9&1-4#-4<F%C:R==(#T*("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@)VEN
M)R`]/B!A<G)A>2@G35`S5')A8VLG(#T^("=[=7)N.DU0,T1"?4U0,U1R86-K
M)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("=O=70G(#T^(&%R<F%Y*"=R
M971U<FXG(#T^("=[=7)N.DU0,T1"?4%D9$U0,U1R86-K4F5S=6QT)RD*("`@
M("`@("`@("`@("`@("`@("`I.PH*("`@("`@("`O*BH*("`@("`@("`J($D@
M=7-E(%]?='EP961E9B!T;R!D97-C<FEB92!U<V5R9&5F:6YE9"!4>7!E<R!I
M;B!74T1,+@H@("`@("`@("H@4W1R=6-T<R!A;F0@;VYE+61I;65N<VEO;F%L
M(&%R<F%Y<R!A<F4@<W5P<&]R=&5D.@H@("`@("`@("H@4W1R=6-T(&5X86UP
M;&4Z("1T:&ES+3Y?7W1Y<&5D969;)U1Y<&5.86UE)UT@/2!A<G)A>2@G5F%R
M3F%M92<@/3X@)WAS9%1Y<&4G+"`N+BX@*3L*("`@("`@("`J("`@(&]R("1T
M:&ES+3Y?7W1Y<&5D969;)U1Y<&5.86UE)UT@/2!A<G)A>2@G5F%R3F%M92<@
M/3X@)WMN86UE<W!A8V5]4V]M94]T:&5R5'EP92<I.PH@("`@("`@("H@07)R
M87D@97AA;7!L93H@)'1H:7,M/E]?='EP961E9ELG5'EP94YA;64G72`](&%R
M<F%Y*&%R<F%Y*"=I=&5M)R`]/B`G>'-D5'EP92<I*3L*("`@("`@("`J("`@
M(&]R("1T:&ES+3Y?7W1Y<&5D969;)U1Y<&5.86UE)UT@/2!A<G)A>2AA<G)A
M>2@G:71E;2<@/3X@)WMN86UE<W!A8V5]4V]M94]T:&5R5'EP92<I*3L*("`@
M("`@("`J+PH@("`@"B`@("`@("`@+RHJ"B`@("`@("`@*B!3=')U8W0@)TU0
M,U1R86-K)PH@("`@("`@("HO"B`@("`@("`@)'1H:7,M/E]?='EP961E9ELG
M35`S5')A8VLG72`](`H@("`@("`@("`@("`@("`@("`@(&%R<F%Y*`H@("`@
M("`@("`@("`@("`@("`@("`@("`G5&ET;&4G(#T^("=S=')I;F<G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`G07)T:7-T)R`]/B`G<W1R:6YG)RP@"B`@
M("`@("`@("`@("`@("`@("`@("`@("=!;&)U;2<@/3X@)W-T<FEN9R<L(`H@
M("`@("`@("`@("`@("`@("`@("`@("`G665A<B<@/3X@)VEN="<L(`H@("`@
M("`@("`@("`@("`@("`@("`@("`G1V5N<F4G(#T^("=I;G0G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`G0V]M;65N="<@/3X@)W-T<FEN9R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("=#;VUP;W-E<B<@/3X@)W-T<FEN9R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("=/<FEG7T%R=&ES="<@/3X@)W-T<FEN
M9R<L"B`@("`@("`@("`@("`@("`@("`@("`@("=54DPG(#T^("=S=')I;F<G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`G16YC;V1E9%]B>2<@/3X@)W-T
M<FEN9R<*("`@("`@("`@("`@("`@("`@("`I.PH@("`@("`@("`@("`@("`@
M("`@(`H@("`@("`@("`@("`@("`@("`@(`H@("`@("`@("`@("`@("`@("`@
M(`H@("`@("`@("\J*@H@("`@("`@("H@35`S5')A8VMS07)R87D@+2!A<G)A
M>2!O9B`G35`S5')A8VLG('-T<G5C=',*("`@("`@("`J+PH@("`@("`@("1T
M:&ES+3Y?7W1Y<&5D969;)TU0,U1R86-K<T%R<F%Y)UT@/2`*("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:71E;2<@/3X@)WMU
M<FXZ35`S1$)]35`S5')A8VLG"B`@("`@("`@("`@("`@("`@("`@("`@("D*
M("`@("`@("`@("`@("`@("`@("`I.PH@("`@("`@("`@("`@("`@("`@(`H@
M("`@("`@("\J*@H@("`@("`@("H@4W1R=6-T("=-971H;V1$96)U9R<*("`@
M("`@("`J+PH@("`@("`@("1T:&ES+3Y?7W1Y<&5D969;)TUE=&AO9$1E8G5G
M)UT@/2`*("`@("`@("`@("`@("`@("`@("!A<G)A>2@*("`@("`@("`@("`@
M("`@("`@("`@("`@)W)C)R`]/B`G8F]O;&5A;B<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("=%<G).;R<@/3X@)VEN="<L(`H@("`@("`@("`@("`@("`@
M("`@("`@("`G17)R;W(G(#T^("=S=')I;F<G"B`@("`@("`@("`@("`@("`@
M("`@*3L*("`@("`@("`@("`@("`@("`@("`*("`@("`@("`O*BH*("`@("`@
M("`J(')E='5R;B!3=')U8W0@;V8@;65T:&]D($=E=$U0,U1R86-K<PH@("`@
M("`@("HO"B`@("`@("`@)'1H:7,M/E]?='EP961E9ELG1V5T35`S5')A8VMS
M4F5S=6QT)UT@/2`*("`@("`@("`@("`@("`@("`@("!A<G)A>2@*("`@("`@
M("`@("`@("`@("`@("`@("`@)TUE=&AO9$1E8G5G)R`]/B`G>W5R;CI-4#-$
M0GU-971H;V1$96)U9R<L"B`@("`@("`@("`@("`@("`@("`@("`@("=-4#-4
M<F%C:W,G(#T^("=[=7)N.DU0,T1"?4U0,U1R86-K<T%R<F%Y)PH@("`@("`@
M("`@("`@("`@("`@("D["B`@("`@("`@("`@("`@("`@("`@"B`@("`@("`@
M+RHJ"B`@("`@("`@*B!R971U<FX@4W1R=6-T(&]F(&UE=&AO9"!!9&1-4#-4
M<F%C:PH@("`@("`@("HO"B`@("`@("`@)'1H:7,M/E]?='EP961E9ELG061D
M35`S5')A8VM297-U;'0G72`](`H@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*`H@("`@("`@("`@("`@("`@("`@("`@("`G365T:&]D1&5B=6<G(#T^("=[
M=7)N.DU0,T1"?4UE=&AO9$1E8G5G)PH@("`@("`@("`@("`@("`@("`@("D[
M"B`@("`@("`@("`@("`@("`@("`@"B`@("`@("`@+RHJ"B`@("`@("`@*B!!
M<G)A>2!O9B!S=')I;F=S"B`@("`@("`@*B\*("`@("`@("`D=&AI<RT^7U]T
M>7!E9&5F6R=!<G)A>4]F4W1R:6YG<R==(#T@"B`@("`@("`@("`@("`@("`@
M("`@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=I=&5M
M)ST^)W-T<FEN9R<I"B`@("`@("`@("`@("`@("`@("`@*3L*("`@(`H@("`@
M?0H@("`@"B`@("`*("`@(&9U;F-T:6]N(%-A>4AA;&QO*"1N86UE*2!["B`@
M("`@("`@<F5T=7)N(")(86QL;RP@(B`N("1N86UE.PH@("`@?0H@("`@"B`@
M("`*("`@(&9U;F-T:6]N(%-A>51H:7-.5&EM97,H)%-A>51H:7,L)$Y4:6UE
M<RD@>PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1.5&EM97,[("1I*RLI
M('L*("`@("`@("`@("`@)')E='5R;ELD:5T@/2`D4V%Y5&AI<R`N("(@)&DB
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@;F5W(%-/05!?5F%L=64H)W)E
M='5R;B<L)WMU<FXZ35`S1$)]07)R87E/9E-T<FEN9W,G+"1R971U<FXI.PH@
M("`@?0H@("`@"B`@("`*("`@(&9U;F-T:6]N($=E=$U0,U1R86-K<R@D<75E
M<GD@/2`B(BD@>PH@("`@("`@(&9O<B@D:2`](#`[("1I(#P@-3L@)&DK*RD@
M>PH@("`@("`@("`@("`D=&AI<RT^35`S5')A8VMS6R1I72`](&YE=R!33T%0
M7U9A;'5E*`H@("`@("`@("`@("`@("`@("`@("=I=&5M)RP*("`@("`@("`@
M("`@("`@("`@("`G>W5R;CI-4#-$0GU-4#-4<F%C:R<L"B`@("`@("`@("`@
M("`@("`@("`@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@(")4:71L
M92(@("`@("`@("`]/B!N97<@4T]!4%]686QU92@B5&ET;&4B+")S=')I;F<B
M+")S;VUE('1R86-K("1I(BDL"B`@("`@("`@("`@("`@("`@("`@("`@(")!
M<G1I<W0B("`@("`@("`]/B!N97<@4T]!4%]686QU92@B07)T:7-T(BPB<W1R
M:6YG(BPB<V]M92!A<G1I<W0@)&DB*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@(D%L8G5M(B`@("`@("`@(#T^(&YE=R!33T%07U9A;'5E*")!;&)U;2(L
M(G-T<FEN9R(L(G-O;64@86QB=6T@)&DB*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@(EEE87(B("`@("`@("`@(#T^(&YE=R!33T%07U9A;'5E*")996%R
M(BPB:6YT(BPH:6YT96=E<BDQ.3DY*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@(D=E;G)E(B`@("`@("`@(#T^(&YE=R!33T%07U9A;'5E*")'96YR92(L
M(FEN="(L*&EN=&5G97(I,3`P*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M(D-O;6UE;G0B("`@("`@(#T^(&YE=R!33T%07U9A;'5E*")#;VUM96YT(BPB
M<W1R:6YG(BPB8FQA8FQA("1I(BDL"B`@("`@("`@("`@("`@("`@("`@("`@
M(")#;VUP;W-E<B(@("`@("`]/B!N97<@4T]!4%]686QU92@B0V]M<&]S97(B
M+")S=')I;F<B+"(B*2P*("`@("`@("`@("`@("`@("`@("`@("`@(D]R:6=?
M07)T:7-T(B`@(#T^(&YE=R!33T%07U9A;'5E*")/<FEG7T%R=&ES="(L(G-T
M<FEN9R(L(B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`B55),(B`@("`@
M("`@("`@/3X@;F5W(%-/05!?5F%L=64H(E523"(L(G-T<FEN9R(L(B(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`B16YC;V1E9%]B>2(@("`@/3X@;F5W
M(%-/05!?5F%L=64H(D5N8V]D961?8GDB+")S=')I;F<B+"(B*0H@("`@("`@
M("`@("`@("`@("`@("`@("`I"B`@("`@("`@("`@("`@("`I.PH@("`@("`@
M('T*("`@("`@("`*("`@("`@("`D365T:&]D1&5B=6=;(G)C(ET@("`@/2!N
M97<@4T]!4%]686QU92@B<F,B+")B;V]L96%N(BQT<G5E*3L*("`@("`@("`D
M365T:&]D1&5B=6=;(D5R<DYO(ET@/2!N97<@4T]!4%]686QU92@B17)R3F\B
M+")I;G0B+"AI;G1E9V5R*3`I.PH@("`@("`@("1-971H;V1$96)U9ULB17)R
M;W(B72`](&YE=R!33T%07U9A;'5E*")%<G)O<B(L(G-T<FEN9R(L(B(I.PH@
M("`@("`@("`@("`*("`@("`@("!R971U<FX@;F5W(%-/05!?5F%L=64H)W)E
M='5R;B<L)WMU<FXZ35`S1$)]1V5T35`S5')A8VMS4F5S=6QT)RQA<G)A>2@*
M("`@("`@("`@("`@("`@("`@("`B365T:&]D1&5B=6<B(#T^(&YE=R!33T%0
M7U9A;'5E*"=-971H;V1$96)U9R<L)WMU<FXZ35`S1$)]365T:&]D1&5B=6<G
M+"1-971H;V1$96)U9RDL"B`@("`@("`@("`@("`@("`@("`@(DU0,U1R86-K
M<R(@("`]/B!N97<@4T]!4%]686QU92@G35`S5')A8VMS)RPG>W5R;CI-4#-$
M0GU-4#-4<F%C:W-!<G)A>2<L)'1H:7,M/DU0,U1R86-K<RD*("`@("`@("`@
M("`@("`@("`@("`I"B`@("`@("`@("`@("`@("`I.PH@("`@?0H@("`@"B`@
M("`*("`@(&9U;F-T:6]N($%D9$U0,U1R86-K*"1-4#-4<F%C:RD@>PH@("`@
M("`@(",@=V5L;"P@;&5T<R!I;6%G:6YE(&AE<F4@<V]M92!C;V1E(&9O<B!A
M9&1I;F<@9VEV96X@;7`S=')A8VL@=&\@9&(@;W(@=VAA=&5V97(N+BX*("`@
M("`@("`D365T:&]D1&5B=6=;(G)C(ET@("`@/2!N97<@4T]!4%]686QU92@B
M<F,B+")B;V]L96%N(BQT<G5E*3L*("`@("`@("`D365T:&]D1&5B=6=;(D5R
M<DYO(ET@/2!N97<@4T]!4%]686QU92@B17)R3F\B+")I;G0B+"AI;G1E9V5R
M*3`I.PH@("`@("`@("1-971H;V1$96)U9ULB17)R;W(B72`](&YE=R!33T%0
M7U9A;'5E*")%<G)O<B(L(G-T<FEN9R(L(B(I.PH@("`@("`@(`H@("`@("`@
M(')E='5R;B!N97<@4T]!4%]686QU92@G<F5T=7)N)RPG>W5R;CI-4#-$0GU!
M9&1-4#-4<F%C:U)E<W5L="<L87)R87DH"B`@("`@("`@("`@("`@("`@("`@
M(DUE=&AO9$1E8G5G(B`]/B!N97<@4T]!4%]686QU92@G365T:&]D1&5B=6<G
M+"=[=7)N.DU0,T1"?4UE=&AO9$1E8G5G)RPD365T:&]D1&5B=6<I"B`@("`@
M("`@("`@("`@("`@("`@*0H@("`@("`@("`@("`@("`@*3L*("`@('T*("`@
M(`H@("`@"B`@("!F=6YC=&EO;B!?7V1I<W!A=&-H*"1M971H;V1N86UE*2![
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?7V1I<W!A=&-H7VUA<%LD;65T
M:&]D;F%M95TI*0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]?9&ES<&%T
M8VA?;6%P6R1M971H;V1N86UE73L*("`@("`@("!R971U<FX@3E5,3#L*("`@
M('T*?0H*)'-E<G9E<B`](&YE=R!33T%07U-E<G9E<CL*)'-E<G9E<BT^7V%U
M=&]?=')A;G-L871I;VX@/2!T<G5E.PHD35`S1$)?0VQA<W,@/2!N97<@35`S
M1$)?0VQA<W,H*3L*)'-E<G9E<BT^861D3V)J96-T36%P*"1-4#-$0E]#;&%S
M<RPG=7)N.DU0,T1")RD["@H*:68@*&ES<V5T*"1?4T525D526R=215%515-4
M7TU%5$A/1"==*2`F)@H@("`@)%]315)615);)U)%455%4U1?34542$]$)UT]
M/2=03U-4)RD@>PH@("`@)'-E<G9E<BT^<V5R=FEC92@D2%144%]205=?4$]3
M5%]$051!*3L*?2!E;'-E('L*("`@(')E<75I<F5?;VYC92`G4T]!4"]$:7-C
M;RYP:'`G.PH@("`@)&1I<V-O(#T@;F5W(%-/05!?1$E30T]?4V5R=F5R*"1S
M97)V97(L(DU0,T1"(BD["B`@("!H96%D97(H(D-O;G1E;G0M='EP93H@=&5X
M="]X;6PB*3L*("`@(&EF("AI<W-E="@D7U-%4E9%4ELG455%4EE?4U1224Y'
M)UTI("8F"B`@("`@("!S=')C87-E8VUP*"1?4T525D526R=1545265]35%))
M3D<G72PG=W-D;"<I/3TP*2!["B`@("`@("`@96-H;R`D9&ES8V\M/F=E=%=3
M1$PH*3L*("`@('T@96QS92!["B`@("`@("`@96-H;R`D9&ES8V\M/F=E=$1)
M4T-/*"D["B`@("!]"B`@("!E>&ET.PI]"C\^````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+U-/05`O
M97AA;7!L92]E;6%I;%]C;&EE;G0N<&AP````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`S,S(R(#$P-3$U-#,S-S,P(#`R-#<T-@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO+PHO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER
M:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E
M<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@?`HO+R!\('1H
M870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,
M24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P
M,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\
M($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC
M96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T
M;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M
M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!3
M:&%N92!#87)A=F5O(#Q3:&%N94!#87)A=F5O+F-O;3X@("!0;W)T('1O(%!%
M05(@86YD(&UO<F4@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+PHO+R`D260Z(&5M86EL7V-L:65N="YP:'`L=B`Q+C0@,C`P-2\P,R\Q
M,"`R,SHQ-CHT,"!Y=6YO<V@@17AP("0*+R\*"B\J"E1H:7,@<F5A9',@82!M
M97-S86=E(&9R;VT@<W1D:6XL(&%N9"!C86QL<R!T:&4@<V]A<"!S97)V97(@
M9&5F:6YE9`H*66]U(&-A;B!U<V4@=&AI<R!F<F]M('%M86EL(&)Y(&-R96%T
M:6YG(&$@+G%M86EL+7-O87!T97-T(&9I;&4@=VET:#H*("`@('P@+W5S<B]B
M:6XO<&AP("]P871H+W1O+V5M86EL7W-E<G9E<BYP:'`**B\*"B,@:6YC;'5D
M92!T:&4@96UA:6P@<V5R=F5R(&-L87-S"G)E<75I<F5?;VYC92`G4T]!4"]3
M97)V97(O16UA:6PN<&AP)SL*"B1S97)V97(@/2!N97<@4T]!4%]397)V97)?
M16UA:6P["@HC(')E860@<W1D:6X*)&9I;B`](&9O<&5N*"=P:'`Z+R]S=&1I
M;B<L)W)B)RD["FEF("@A)&9I;BD@97AI="@P*3L*"B1E;6%I;"`]("<G.PIW
M:&EL92`H(69E;V8H)&9I;BD@)B8@)&1A=&$@/2!F<F5A9"@D9FEN+"`X,#DV
M*2D@>PH@("1E;6%I;"`N/2`D9&%T83L*?0H*9F-L;W-E*"1F:6XI.PH*"B1R
M97-P;VYS92`]("1S97)V97(M/F-L:65N="@D96UA:6PI.PH*<')I;G1?<B@D
M<F5S<&]N<V4I.PH*/SX`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]33T%0+V5X86UP
M;&4O96UA:6Q?9V%T97=A>2YP:'``````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S0W
M,R`Q,#4Q-30S,S<S,"`P,C4Q-#``(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+R\*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@
M*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N
M(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*+R\@?"!T:&%T(&ES
M(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y3
M12P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT
M+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y
M;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@
M86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@
M("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y
M;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@4VAA;F4@
M0V%R879E;R`\4VAA;F5`0V%R879E;RYC;VT^("`@4&]R="!T;R!014%2(&%N
M9"!M;W)E("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*
M+R\@)$ED.B!E;6%I;%]G871E=V%Y+G!H<"QV(#$N-2`R,#`U+S`S+S$P(#(S
M.C$V.C0P('EU;F]S:"!%>'`@)`HO+PH*+RH*5&AI<R!R96%D<R!A(&UE<W-A
M9V4@9G)O;2!S=&1I;BP@86YD('!A<W-E<R!T:&4@<F5Q=65S="!T;PIA('-O
M87`@<V5R=F5R(')E<VED:6YG(&]N(&$@=V5B('-E<G9E<BP@<V5N9',@=&AE
M(')E<W!O;G-E"F]U="!A<R!A;B!E;6%I;`H*66]U(&-A;B!U<V4@=&AI<R!F
M<F]M('%M86EL(&)Y(&-R96%T:6YG(&$@+G%M86EL+7-O87!G871E=V%Y(&9I
M;&4@=VET:#H*("`@('P@+W5S<B]B:6XO<&AP("]P871H+W1O+V5M86EL7W-E
M<G9E<BYP:'`**B\*"B,@:6YC;'5D92!T:&4@96UA:6P@<V5R=F5R(&-L87-S
M"G)E<75I<F5?;VYC92`G4T]!4"]397)V97(O16UA:6Q?1V%T97=A>2YP:'`G
M.PH*(R!R96%D('-T9&EN"B1F:6X@/2!F;W!E;B@G<&AP.B\O<W1D:6XG+"=R
M8B<I.PII9B`H(21F:6XI(&5X:70H,"D["@HD96UA:6P@/2`G)SL*=VAI;&4@
M*"%F96]F*"1F:6XI("8F("1D871A(#T@9G)E860H)&9I;BP@.#`Y-BDI('L*
M("`D96UA:6P@+CT@)&1A=&$["GT*"F9C;&]S92@D9FEN*3L*"B,@9&]I="$*
M)'-E<G9E<B`](&YE=R!33T%07U-E<G9E<E]%;6%I;%]'871E=V%Y*"D["B1S
M97)V97(M/G-E<G9I8V4H)&1A=&$L("=H='1P.B\O;&]C86QH;W-T+W-O87`O
M97AA;7!L92]S97)V97(N<&AP)RD["C\^````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O4T]!4"]E>&%M<&QE+V5M
M86EL7W!O<%]G871E=V%Y+G!H<```````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#4P,#,@,3`U
M,34T,S,W,S`@,#(V,#`U`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q
M.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R
M(&]F('1H92!02%`@;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B=6YD
M;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N
M9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I
M9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A
M<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@
M('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@
M8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%-H86YE($-A<F%V
M96\@/%-H86YE0$-A<F%V96\N8V]M/B`@(%!O<G0@=&\@4$5!4B!A;F0@;6]R
M92`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)
M9#H@96UA:6Q?<&]P7V=A=&5W87DN<&AP+'8@,2XV(#(P,#4O,#,O,3`@,C,Z
M,38Z-#`@>75N;W-H($5X<"`D"B\O"@HO*B!I;F-L=61E('1H92!%;6%I;"!S
M97)V97(@8VQA<W,L('=H:6-H(&MN;W=S(&AO=R!T;PH@("!P87)S92!A('-T
M86YD87)D(&5M86EL(&%S(&$@<V]A<"!M97-S86=E("HO"@IR97%U:7)E7V]N
M8V4@)U-/05`O4V5R=F5R+T5M86EL7T=A=&5W87DN<&AP)SL*"B\J(&EN8VQU
M9&4@82!C;&%S<R!T;R!A8V-E<W,@4$]0,R`J+PH*<F5Q=6ER95]O;F-E("=.
M970O4$]0,RYP:'`G.PH*+RH@8W)E871E('1H92!33T%0(%-E<G9E<B!O8FIE
M8W0@*B\*"B1S97)V97(@/2!N97<@4T]!4%]397)V97)?16UA:6Q?1V%T97=A
M>2@G:'1T<#HO+VQO8V%L:&]S="]S;V%P7VEN=&5R;W`O<V5R=F5R7W)O=6YD
M,BYP:'`G*3L*"B\J('1E;&P@<V5R=F5R('1O('1R86YS;&%T92!T;R!C;&%S
M<V5S('=E('!R;W9I9&4@:68@<&]S<VEB;&4@*B\*)'-E<G9E<BT^7V%U=&]?
M=')A;G-L871I;VX@/2!T<G5E.PH*<F5Q=6ER95]O;F-E("=E>&%M<&QE7W-E
M<G9E<BYP:'`G.PH*)'-O87!C;&%S<R`](&YE=R!33T%07T5X86UP;&5?4V5R
M=F5R*"D["B1S97)V97(M/F%D9$]B:F5C=$UA<"@D<V]A<&-L87-S+"=U<FXZ
M4T]!4%]%>&%M<&QE7U-E<G9E<B<I.PH*"B\J($-O;FYE8W0@=&\@82!03U`S
M('-E<G9E<B!A;F0@<F5A9"!T:&4@;65S<V%G97,@*B\*"B1P;W`S(#TF(&YE
M=R!.971?4$]0,R@I.PII9B`H)'!O<#,M/F-O;FYE8W0H)VQO8V%L:&]S="<L
M(#$Q,"DI('L*("`@(&EF("@D<&]P,RT^;&]G:6XH)W5S97)N86UE)RP@)W!A
M<W-W;W)D)RDI('L*("`@("`@("`D;&ES=&EN9R`]("1P;W`S+3YG971,:7-T
M:6YG*"D["@H)+RH@;F]W(&QO;W`@=&AR;W5G:"!E86-H(&UE<W-A9V4L(&%N
M9"!C86QL('1H92`*("`@("`@("`@("!33T%0('-E<G9E<B!W:71H('1H870@
M;65S<V%G92`J+PH*("`@("`@("!F;W)E86-H("@D;&ES=&EN9R!A<R`D;7-G
M*2!["@H@("`@("`@("`@("`D96UA:6P@/2`D<&]P,RT^9V5T37-G*"1M<V=;
M)VUS9U]I9"==*3L*"B`@("`@("`@("`@("\J('1H:7,@:7,@=VAE<F4@=V4@
M86-T=6%L;'D@:&%N9&QE('1H92!33T%0"B`@("`@("`@("`@("`@(')E<W!O
M;G-E+B`@5&AE(%-/05`Z.E-E<G9E<CHZ16UA:6P@8VQA<W,@=V4*("`@("`@
M("`@("`@("`@87)E('5S:6YG('=I;&P@<V5N9"!T:&4@4T]!4"!R97-P;VYS
M92!T;R`*("`@("`@("`@("`@("`@=&AE('-E;F1E<B!V:6$@96UA:6PN("HO
M"@H@("`@("`@("`@("!I9B`H)&5M86EL*2`D<V5R=F5R+3YS97)V:6-E*"1E
M;6%I;"D["@H@("`@("`@("`@("`C)'!O<#,M/F1E;&5T94US9R@D;7-G6R=M
M<V=?:60G72D["B`@("`@("`@?0H@("`@?0H@("`@)'!O<#,M/F1I<V-O;FYE
M8W0H*3L*?0H_/@H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O9&]C<R]33T%0+V5X86UP;&4O96UA:6Q?<&]P7W-E<G9E<BYP
M:'`````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P-#<T,2`Q,#4Q-30S,S<S,"`P,C4V-C(`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0
M(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0
M($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I
M;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E
M;G-E+"`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A
M8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O
M('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@
M8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\
M"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P
M;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`
M<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY
M+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@075T:&]R<SH@4VAA;F4@0V%R879E;R`\4VAA;F5`0V%R879E
M;RYC;VT^("`@4&]R="!T;R!014%2(&%N9"!M;W)E("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!E;6%I;%]P;W!?<V5R
M=F5R+G!H<"QV(#$N-B`R,#`U+S`S+S$P(#(S.C$V.C0P('EU;F]S:"!%>'`@
M)`HO+PH*+RH@:6YC;'5D92!T:&4@16UA:6P@<V5R=F5R(&-L87-S+"!W:&EC
M:"!K;F]W<R!H;W<@=&\*("`@<&%R<V4@82!S=&%N9&%R9"!E;6%I;"!A<R!A
M('-O87`@;65S<V%G92`J+PH*<F5Q=6ER95]O;F-E("=33T%0+U-E<G9E<B]%
M;6%I;"YP:'`G.PH*+RH@:6YC;'5D92!A(&-L87-S('1O(&%C8V5S<R!03U`S
M("HO"@IR97%U:7)E7V]N8V4@)TYE="]03U`S+G!H<"<["@HO*B!C<F5A=&4@
M=&AE(%-/05`@4V5R=F5R(&]B:F5C="`J+PH*)'-E<G9E<B`](&YE=R!33T%0
M7U-E<G9E<E]%;6%I;#L*"B\J('1E;&P@<V5R=F5R('1O('1R86YS;&%T92!T
M;R!C;&%S<V5S('=E('!R;W9I9&4@:68@<&]S<VEB;&4@*B\*)'-E<G9E<BT^
M7V%U=&]?=')A;G-L871I;VX@/2!T<G5E.PH*<F5Q=6ER95]O;F-E("=E>&%M
M<&QE7W-E<G9E<BYP:'`G.PH*)'-O87!C;&%S<R`](&YE=R!33T%07T5X86UP
M;&5?4V5R=F5R*"D["B1S97)V97(M/F%D9$]B:F5C=$UA<"@D<V]A<&-L87-S
M+"=U<FXZ4T]!4%]%>&%M<&QE7U-E<G9E<B<I.PH*"B\J($-O;FYE8W0@=&\@
M82!03U`S('-E<G9E<B!A;F0@<F5A9"!T:&4@;65S<V%G97,@*B\*"B1P;W`S
M(#TF(&YE=R!.971?4$]0,R@I.PII9B`H)'!O<#,M/F-O;FYE8W0H)VQO8V%L
M:&]S="<L(#$Q,"DI('L*("`@(&EF("@D<&]P,RT^;&]G:6XH)W5S97)N86UE
M)RP@)W!A<W-W;W)D)RDI('L*("`@("`@("`D;&ES=&EN9R`]("1P;W`S+3YG
M971,:7-T:6YG*"D["@H)+RH@;F]W(&QO;W`@=&AR;W5G:"!E86-H(&UE<W-A
M9V4L(&%N9"!C86QL('1H92`*("`@("`@("`@("!33T%0('-E<G9E<B!W:71H
M('1H870@;65S<V%G92`J+PH*("`@("`@("!F;W)E86-H("@D;&ES=&EN9R!A
M<R`D;7-G*2!["@H@("`@("`@("`@("`D96UA:6P@/2`D<&]P,RT^9V5T37-G
M*"1M<V=;)VUS9U]I9"==*3L*"B`@("`@("`@("`@("\J('1H:7,@:7,@=VAE
M<F4@=V4@86-T=6%L;'D@:&%N9&QE('1H92!33T%0"B`@("`@("`@("`@("`@
M(')E<W!O;G-E+B`@5&AE(%-/05`Z.E-E<G9E<CHZ16UA:6P@8VQA<W,@=V4*
M("`@("`@("`@("`@("`@87)E('5S:6YG('=I;&P@<V5N9"!T:&4@4T]!4"!R
M97-P;VYS92!T;R`*("`@("`@("`@("`@("`@=&AE('-E;F1E<B!V:6$@96UA
M:6PN("HO"@H@("`@("`@("`@("!I9B`H)&5M86EL*2!["B`@("`@("`@("`@
M("`@("`D<V5R=F5R+3YC;&EE;G0H)&5M86EL*3L*"B`@("`@("`@("`@("`@
M("`D<&]P,RT^9&5L971E37-G*"1M<V=;)VUS9U]I9"==*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@('T*("`@("1P;W`S+3YD:7-C;VYN96-T*"D[
M"GT*/SX*`````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]33T%0+V5X86UP;&4O96UA:6Q?
M<V5R=F5R+G!H<```````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S8U,"`Q,#4Q-30S
M,S<S,"`P,C4P,#(`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M
M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H
M:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@
M=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@
M=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES
M("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO
M="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U
M;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO
M+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y
M(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@4VAA;F4@0V%R879E;R`\
M4VAA;F5`0V%R879E;RYC;VT^("`@4&]R="!T;R!014%2(&%N9"!M;W)E("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!E
M;6%I;%]S97)V97(N<&AP+'8@,2XU(#(P,#4O,#,O,3`@,C,Z,38Z-#`@>75N
M;W-H($5X<"`D"B\O"@HO*@I4:&ES(')E861S(&$@;65S<V%G92!F<F]M('-T
M9&EN+"!A;F0@8V%L;',@=&AE('-O87`@<V5R=F5R(&1E9FEN960*"EEO=2!C
M86X@=7-E('1H:7,@9G)O;2!Q;6%I;"!B>2!C<F5A=&EN9R!A("YQ;6%I;"US
M;V%P=&5S="!F:6QE('=I=&@Z"B`@("!\("]U<W(O8FEN+W!H<"`O<&%T:"]T
M;R]E;6%I;%]S97)V97(N<&AP"BHO"@HC(&EN8VQU9&4@=&AE(&5M86EL('-E
M<G9E<B!C;&%S<PIR97%U:7)E7V]N8V4@)U-/05`O4V5R=F5R+T5M86EL+G!H
M<"<["@HD<V5R=F5R(#T@;F5W(%-/05!?4V5R=F5R7T5M86EL.PH*+RH@=&5L
M;"!S97)V97(@=&\@=')A;G-L871E('1O(&-L87-S97,@=V4@<')O=FED92!I
M9B!P;W-S:6)L92`J+PHD<V5R=F5R+3Y?875T;U]T<F%N<VQA=&EO;B`]('1R
M=64["@IR97%U:7)E7V]N8V4@)V5X86UP;&5?<V5R=F5R+G!H<"<["@HD<V]A
M<&-L87-S(#T@;F5W(%-/05!?17AA;7!L95]397)V97(H*3L*)'-E<G9E<BT^
M861D3V)J96-T36%P*"1S;V%P8VQA<W,L)W5R;CI33T%07T5X86UP;&5?4V5R
M=F5R)RD["@HC(')E860@<W1D:6X*)&9I;B`](&9O<&5N*"=P:'`Z+R]S=&1I
M;B<L)W)B)RD["FEF("@A)&9I;BD@97AI="@P*3L*"B1E;6%I;"`]("<G.PIW
M:&EL92`H(69E;V8H)&9I;BD@)B8@)&1A=&$@/2!F<F5A9"@D9FEN+"`X,#DV
M*2D@>PH@("1E;6%I;"`N/2`D9&%T83L*?0H*9F-L;W-E*"1F:6XI.PH*(R!D
M;VET(0HD<V5R=F5R+3YS97)V:6-E*"1E;6%I;"D["@H_/@``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+V1O8W,O4T]!4"]E>&%M<&QE+V5X86UP;&5?<V5R
M=F5R+G!H<```````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,30R-34@,3`U,34T,S,W,S`@
M,#(U,S4Q`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@
M5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O
M=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!0
M2%`@;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@
M=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@
M("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E
M+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P
M.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C
M96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE
M('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E
M+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L
M:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE
M9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%-H86YE($-A<F%V96\@/%-H86YE
M0$-A<F%V96\N8V]M/B`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@97AA;7!L
M95]S97)V97(N<&AP+'8@,2XU(#(P,#4O,#,O,3`@,C,Z,38Z-#`@>75N;W-H
M($5X<"`D"B\O"@HO+R!F:7)S="P@:6YC;'5D92!T:&4@4T]!4"]397)V97(@
M8VQA<W,*<F5Q=6ER95]O;F-E("=33T%0+U9A;'5E+G!H<"<["G)E<75I<F5?
M;VYC92`G4T]!4"]&875L="YP:'`G.PH*+R\@4T]!4%-T<G5C="!I<R!D969I
M;F5D(&EN('1H92!F;VQL;W=I;F<@9FEL90IR97%U:7)E7V]N8V4@)V5X86UP
M;&5?='EP97,N<&AP)SL*"B\O(&-R96%T92!A(&-L87-S(&9O<B!Y;W5R('-O
M87`@9G5N8W1I;VYS"F-L87-S(%-/05!?17AA;7!L95]397)V97(@>PH@("`@
M+RHJ"B`@("`@*B!4:&4@9&ES<&%C=&-H(&UA<"!D;V5S(&YO="!N965D('1O
M(&)E('5S960L(&)U="!A:61S"B`@("`@*B!T:&4@<V5R=F5R(&-L87-S(&EN
M(&MN;W=I;F<@=VAA="!P87)A;65T97)S(&%R92!U<V5D"B`@("`@*B!W:71H
M('1H92!F=6YC=&EO;G,N("!4:&ES(&ES('1H92!/3DQ9('=A>2!T;R!H879E
M"B`@("`@*B!M=6QT:7!L92!/550@<&%R86UE=&5R<RX@($EF('EO=2!U<V4@
M82!D:7-P871C:"!M87`L('EO=0H@("`@("H@35535"!A9&0@04Q,(&9U;F-T
M:6]N<R!Y;W4@=VES:"!T;R!A;&QO=R!B92!C86QL960N("!)9@H@("`@("H@
M>6]U(&1O(&YO="!U<V4@82!D:7-P871C:"!M87`L('1H96X@86YY('!U8FQI
M8R!F=6YC=&EO;@H@("`@("H@8V%N(&)E(&-A;&QE9"!F<F]M('-O87`@*&EN
M('!H<#0L('=E(&-O;G-I9&5R('1H:7,@=&\@8F4*("`@("`J(&%N>2!F=6YC
M=&EO;B!I;B!T:&4@8VQA<W,@=6YL97-S(&ET('-T87)T<R!W:71H('5N9&5R
M<V-O<F4L"B`@("`@*B!P:'`U('-U<'!O<G0@:7,@;F]T(&-O;7!L971E('EE
M="!I;B!T:&ES(')E9V%R9"DN("`*("`@("`J(&EF('EO=2!D;R!N;W0@9&5F
M:6YE(&EN+V]U="!P87)A;65T97)S+"!T:&4@9G5N8W1I;VX@8V%N(&)E"B`@
M("`@*B!C86QL960@=VET:"!P87)A;65T97)S+"!B=70@;F\@=F%L:61A=&EO
M;B!O;B!P87)A;65T97)S('=I;&P*("`@("`J(&]C8W5R92X*("`@("`J+PH@
M("`@=F%R("1?7V1I<W!A=&-H7VUA<"`](&%R<F%Y*"D["@H@("`@9G5N8W1I
M;VX@4T]!4%]%>&%M<&QE7U-E<G9E<B@I('L*("`@("`@("`O*BH*("`@("`@
M("`J('=H96X@9V5N97)A=&EN9R!W<V1L(&9O<B!A('-E<G9E<BP@>6]U(&AA
M=F4@=&\@9&5F:6YE"B`@("`@("`@*B!A;GD@<W!E8VEA;"!C;VUP;&5X('1Y
M<&5S('1H870@>6]U('5S92`H:64@8VQA<W-E<RDN"B`@("`@("`@*B!U<VEN
M9R!A(&YA;65S<&%C92!I9"!B969O<F4@=&AE('1Y<&4@=VEL;"!C<F5A=&4@
M86X*("`@("`@("`J('AM;"!S8VAE;6$@=VET:"!T:&4@=&%R9V5T3F%M97-P
M86-E(&9O<B!T:&4@='EP90H@("`@("`@("H@;75L=&EP;&4@='EP97,@=VET
M:"!T:&4@<V%M92!N86UE<W!A8V4@=VEL;"!A<'!E87(*("`@("`@("`J(&EN
M('1H92!S86UE('-C:&5M82!S96-T:6]N+B`@='EP97,@=VET:"!D:69F97)E
M;G0*("`@("`@("`J(&YA;65S<&%C97,@=VEL;"!B92!I;B!S97!E<F%T92!S
M8VAE;6$@<V5C=&EO;G,N"B`@("`@("`@*B!T:&4@9F]L;&]W:6YG(%-/05!3
M=')U8W0@='EP961E9B!C;V]R97-P;VYD<R!T;R!T:&4*("`@("`@("`J(%-/
M05!3=')U8W0@8VQA<W,@86)O=F4N"B`@("`@("`@*B\*("`@("`@("`D=&AI
M<RT^7U]T>7!E9&5F6R=[:'1T<#HO+W-O87!I;G1E<F]P+F]R9R]X<V1]4T]!
M4%-T<G5C="==(#T@"B`@("`@("`@("`@("`@("`@("`@87)R87DH"B`@("`@
M("`@("`@("`@("`@("`@("`@("=V87)3=')I;F<G(#T^("=S=')I;F<G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`G=F%R26YT)R`]/B`G:6YT)RP@"B`@
M("`@("`@("`@("`@("`@("`@("`@("=V87)&;&]A="<@/3X@)V9L;V%T)PH@
M("`@("`@("`@("`@("`@("`@("`@("`@*3L*"B`@("`@("`@+R\@86X@86QI
M87-E9"!F=6YC=&EO;B!W:71H(&UU;'1I<&QE(&]U="!P87)A;65T97)S"@DD
M=&AI<RT^7U]D:7-P871C:%]M87!;)V5C:&]3=')U8W1!<U-I;7!L951Y<&5S
M)UT@/0H)"6%R<F%Y*"=I;B<@/3X@87)R87DH)VEN<'5T4W1R=6-T)R`]/B`G
M>VAT='`Z+R]S;V%P:6YT97)O<"YO<F<O>'-D?5-/05!3=')U8W0G*2P*"0D@
M("`@("`G;W5T)R`]/B!A<G)A>2@G;W5T<'5T4W1R:6YG)R`]/B`G<W1R:6YG
M)RP@)V]U='!U=$EN=&5G97(G(#T^("=I;G0G+"`G;W5T<'5T1FQO870G(#T^
M("=F;&]A="<I+`H)"2`@("`@("=A;&EA<R<@/3X@)VUY16-H;U-T<G5C=$%S
M4VEM<&QE5'EP97,G"@D)("`@("`@*3L*"21T:&ES+3Y?7V1I<W!A=&-H7VUA
M<%LG96-H;U-T<FEN9U-I;7!L92==(#T*"0EA<G)A>2@G:6XG(#T^(&%R<F%Y
M*"=I;G!U=%-T<FEN9U-I;7!L92<@/3X@)W-T<FEN9R<I+`H)"2`@("`@("=O
M=70G(#T^(&%R<F%Y*"=O=71P=713=')I;F=3:6UP;&4G(#T^("=S=')I;F<G
M*2P*"0D@("`@("`I.PH))'1H:7,M/E]?9&ES<&%T8VA?;6%P6R=E8VAO4W1R
M:6YG)UT@/0H)"6%R<F%Y*"=I;B<@/3X@87)R87DH)VEN<'5T4W1R:6YG)R`]
M/B`G<W1R:6YG)RDL"@D)("`@("`@)V]U="<@/3X@87)R87DH)V]U='!U=%-T
M<FEN9R<@/3X@)W-T<FEN9R<I+`H)"2`@("`@("D["@DD=&AI<RT^7U]D:7-P
M871C:%]M87!;)V1I=FED92==(#T*"0EA<G)A>2@G:6XG(#T^(&%R<F%Y*"=D
M:79I9&5N9"<@/3X@)VEN="<L("=D:79I<V]R)R`]/B`G:6YT)RDL"@D)("`@
M("`@)V]U="<@/3X@87)R87DH)V]U='!U=$9L;V%T)R`]/B`G9FQO870G*2P*
M"0D@("`@("`I.PH))'1H:7,M/E]?9&ES<&%T8VA?;6%P6R=E8VAO4W1R=6-T
M)UT@/0H)"6%R<F%Y*"=I;B<@/3X@87)R87DH)VEN<'5T4W1R=6-T)R`]/B`G
M>VAT='`Z+R]S;V%P:6YT97)O<"YO<F<O>'-D?5-/05!3=')U8W0G*2P*"0D@
M("`@("`G;W5T)R`]/B!A<G)A>2@G;W5T<'5T4W1R=6-T)R`]/B`G>VAT='`Z
M+R]S;V%P:6YT97)O<"YO<F<O>'-D?5-/05!3=')U8W0G*2P*"0D@("`@("`I
M.PH)"@DD=&AI<RT^7U]D:7-P871C:%]M87!;)V5C:&]-:6UE071T86-H;65N
M="==(#T@87)R87DH*3L*("`@('T*"B`@("`O*B!T:&ES('!R:79A=&4@9G5N
M8W1I;VX@:7,@8V%L;&5D(&]N(&)Y(%-/05!?4V5R=F5R('1O(&1E=&5R;6EN
M92!A;GD*("`@("`@("!S<&5C:6%L(&1I<W!A=&-H(&EN9F]R;6%T:6]N('1H
M870@;6EG:'0@8F4@;F5C97-S87)Y+B`@5&AI<RP@9F]R(&5X86UP;&4L"B`@
M("`@("`@8V%N(&)E('5S960@=&\@<V5T('5P(&$@9&ES<&%T8V@@;6%P(&9O
M<B!F=6YC=&EO;G,@=&AA="!R971U<FX@;75L=&EP;&4*("`@("`@("!/550@
M<&%R86UE=&5R<R`J+PH@("`@9G5N8W1I;VX@7U]D:7-P871C:"@D;65T:&]D
M;F%M92D@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7U]D:7-P871C:%]M
M87!;)&UE=&AO9&YA;65=*2D*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M7V1I<W!A=&-H7VUA<%LD;65T:&]D;F%M95T["B`@("`@("`@<F5T=7)N($Y5
M3$P["B`@("!]"@H@("`@+R\@82!S:6UP;&4@96-H;U-T<FEN9R!F=6YC=&EO
M;@H@("`@9G5N8W1I;VX@96-H;U-T<FEN9U-I;7!L92@D:6YP=713=')I;F<I
M"B`@("!["@ER971U<FX@)&EN<'5T4W1R:6YG.PH@("`@?0H@("`@"B`@("`O
M+R!A;B!E>'!L:6-I="!E8VAO<W1R:6YG(&9U;F-T:6]N"B`@("!F=6YC=&EO
M;B!E8VAO4W1R:6YG*"1I;G!U=%-T<FEN9RD*("`@('L*"7)E='5R;B!N97<@
M4T]!4%]686QU92@G;W5T<'5T4W1R:6YG)RPG<W1R:6YG)RPD:6YP=713=')I
M;F<I.PH@("`@?0H*("`@(&9U;F-T:6]N(&1I=FED92@D9&EV:61E;F0L("1D
M:79I<V]R*0H@("`@>PH@("`@("`@("\O('1H92!S;V%P('-E<G9E<B!W;W5L
M9"!N;W)M86QL>2!C871C:"!E<G)O<G,@;&EK92!T:&ES"B`@("`@("`@+R\@
M86YD(')E='5R;B!A(&9A=6QT+"!B=70@=&AI<R!I<R!H;W<@>6]U(&1O(&ET
M('EO=7)S96QF+@H@("`@("`@(&EF("@D9&EV:7-O<B`]/2`P*0H@("`@("`@
M("`@("!R971U<FX@;F5W(%-/05!?1F%U;'0H)UEO=2!C86YN;W0@9&EV:61E
M(&)Y('IE<F\G+"`G0VQI96YT)RD["B`@("`@("`@96QS90H@("`@("`@("`@
M("!R971U<FX@)&1I=FED96YD("\@)&1I=FES;W(["B`@("!]"@H@("`@9G5N
M8W1I;VX@96-H;U-T<G5C="@D:6YP=713=')U8W0I"B`@("!["B`@("`@("`@
M<F5T=7)N("1I;G!U=%-T<G5C="T^7U]T;U]S;V%P*"=O=71P=713=')U8W0G
M*3L*"2-R971U<FX@;F5W(%-/05!?5F%L=64H)V]U='!U=%-T<G5C="<L)WMH
M='1P.B\O<V]A<&EN=&5R;W`N;W)G+WAS9'U33T%04W1R=6-T)RPD:6YP=713
M=')U8W0I.PH@("`@?0H@("`@"B`@("`O*BH*("`@("`J(&5C:&]3=')U8W1!
M<U-I;7!L951Y<&5S"B`@("`@*B!T86ME<R!A(%-/05!3=')U8W0@87,@:6YP
M=70L(&%N9"!R971U<FYS(&5A8V@@;V8@:71S(&5L96UE;G1S"B`@("`@*B!A
M<R!/550@<&%R86UE=&5R<PH@("`@("H*("`@("`J('1H:7,@9G5N8W1I;VX@
M:7,@86QS;R!A;&EA<V5D('-O('EO=2!H879E('1O(&-A;&P@:70@=VET:`H@
M("`@("H@96-H;U-T<G5C=$%S4VEM<&QE5'EP97,*("`@("`J"B`@("`@*B!3
M3T%04W1R=6-T(&ES(&1E9FEN960@87,Z"B`@("`@*@H@("`@("H@<W1R=6-T
M(%-/05!3=')U8W0Z"B`@("`@*B`@("!S=')I;F<@=F%R4W1R:6YG"B`@("`@
M*B`@("!I;G1E9V5R('9A<DEN=`H@("`@("H@("`@9FQO870@=F%R1FQO870*
M("`@("`J"B`@("`@*B\*("`@(&9U;F-T:6]N(&UY16-H;U-T<G5C=$%S4VEM
M<&QE5'EP97,H)'-T<G5C="D*("`@('L*"2,@8V]N=F5R="!A(%-/05!3=')U
M8W0@=&\@86X@87)R87D*"7)E='5R;B!A<G)A>2@*"2`@("!N97<@4T]!4%]6
M86QU92@G;W5T<'5T4W1R:6YG)RPG<W1R:6YG)RPD<W1R=6-T+3YV87)3=')I
M;F<I+`H)("`@(&YE=R!33T%07U9A;'5E*"=O=71P=71);G1E9V5R)RPG:6YT
M)RPD<W1R=6-T+3YV87));G0I+`H)("`@(&YE=R!33T%07U9A;'5E*"=O=71P
M=71&;&]A="<L)V9L;V%T)RPD<W1R=6-T+3YV87)&;&]A="D*"2`@("`I.PH@
M("`@?0H@("`@"B`@("!F=6YC=&EO;B!E8VAO36EM94%T=&%C:&UE;G0H)'-T
M=69F*0H@("`@>PH@("`@("`@(')E='5R;B!N97<@4T]!4%]!='1A8VAM96YT
M*"=R971U<FXG+"=A<'!L:6-A=&EO;B]O8W1E="US=')E86TG+$Y53$PL)'-T
M=69F*3L*("`@('T@("`@"GT*"C\^````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L
M92]E>&%M<&QE7W1Y<&5S+G!H<```````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-C,W
M(#$P-3$U-#,S-S,P(#`R-3(Q,``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`H*+RH**B!T:&ES(&ES(&$@9&%T82!T
M>7!E('1H870@:7,@=7-E9"!I;B!33T%0($EN=&5R;W`@=&5S=&EN9RP@8G5T
M(&ES"BH@:&5R92!A<R!A;B!E>&%M<&QE(&]F('5S:6YG(&-O;7!L97@@='EP
M97,N("!7:&5N('1H92!C;&%S<R!I<PHJ(&1E<V5R:6%L:7IE9"!F<F]M(&$@
M4T]!4"!M97-S86=E+"!I="=S(&-O;G-T<G5C=&]R($E3($Y/5"!#04Q,140A
M"BH@4V\@>6]U<B!T>7!E(&-L87-S97,@;F5E9"!T;R!B96AA=F4@:6X@82!W
M87D@=&AA="!W:6QL('=O<FL**B!W:71H('1H870N"BH**B!3;VUE('1Y<&5S
M(&UA>2!N965D(&UO<F4@97AP;&EC:70@<V5R:6%L:7IA=&EO;B!F;W(@4T]!
M4"X@(%1H90HJ(%]?=&]?<V]A<"!F=6YC=&EO;B!A;&QO=W,@>6]U('1O(&)E
M('9E<GD@97AP;&EC:70@:6X@8G5I;&1I;F<@=&AE"BH@4T]!4%]686QU92!S
M=')U8W1U<F5S+B`@5&AE('-O87`@;&EB<F%R>2!D;V5S(&YO="!C86QL('1H
M:7,@9&ER96-T;'DL"BH@>6]U('=O=6QD(&-A;&P@:70@9G)O;2!Y;W5R('-O
M87`@<V5R=F5R(&-L87-S+"!E8VAO4W1R=6-T(&EN('1H92!S97)V97(**B!C
M;&%S<R!I<R!A;B!E>&%M<&QE(&]F(&1O:6YG('1H:7,N"BHO"F-L87-S(%-/
M05!3=')U8W0@>PH@("`@=F%R("1V87)3=')I;F<["B`@("!V87(@)'9A<DEN
M=#L*("`@('9A<B`D=F%R1FQO870["B`@("!F=6YC=&EO;B!33T%04W1R=6-T
M*"1S/4Y53$PL("1I/4Y53$PL("1F/4Y53$PI('L*("`@("`@("`D=&AI<RT^
M=F%R4W1R:6YG(#T@)',["B`@("`@("`@)'1H:7,M/G9A<DEN="`]("1I.PH@
M("`@("`@("1T:&ES+3YV87)&;&]A="`]("1F.PH@("`@?0H@("`@"B`@("!F
M=6YC=&EO;B`F7U]T;U]S;V%P*"1N86UE(#T@)VEN<'5T4W1R=6-T)RP@)&AE
M861E<CUF86QS92P@)&UU<W15;F1E<G-T86YD/3`L("1A8W1O<CTG:'1T<#HO
M+W-C:&5M87,N>&UL<V]A<"YO<F<O<V]A<"]A8W1O<B]N97AT)RD*("`@('L*
M("`@("`@("`D:6YN97);72`])B!N97<@4T]!4%]686QU92@G=F%R4W1R:6YG
M)RPG<W1R:6YG)RPD=&AI<RT^=F%R4W1R:6YG*3L*("`@("`@("`D:6YN97);
M72`])B!N97<@4T]!4%]686QU92@G=F%R26YT)RPG:6YT)RPD=&AI<RT^=F%R
M26YT*3L*("`@("`@("`D:6YN97);72`])B!N97<@4T]!4%]686QU92@G=F%R
M1FQO870G+"=F;&]A="<L)'1H:7,M/G9A<D9L;V%T*3L*("`@("`@("!I9B`H
M)&AE861E<BD@>PH@("`@("`@("`@("!R971U<FX@;F5W(%-/05!?2&5A9&5R
M*"1N86UE+"=[:'1T<#HO+W-O87!I;G1E<F]P+F]R9R]X<V1]4T]!4%-T<G5C
M="<L)&EN;F5R+"1M=7-T56YD97)S=&%N9"PD86-T;W(I.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@;F5W(%-/05!?5F%L=64H)&YA;64L)WMH='1P.B\O
M<V]A<&EN=&5R;W`N;W)G+WAS9'U33T%04W1R=6-T)RPD:6YN97(I.PH@("`@
M("`@(`H@("`@?0I]"@H_/@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+V1O8W,O4T]!4"]E>&%M<&QE+W-E<G9E<BYP:'``````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#,W-#4@,3`U,34T,S,W,S`@,#(S-C0P`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!6
M97)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'
M<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE
M(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS
M92P@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K
M86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\
M(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O
M<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO
M+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE
M87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H
M<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@
M("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\($%U=&AO<G,Z(%-H86YE($-A<F%V96\@/%-H86YE0$-A<F%V96\N
M8V]M/B`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@<V5R=F5R+G!H<"QV(#$N
M,3`@,C`P-2\P,R\Q,"`R,SHQ-CHT,"!Y=6YO<V@@17AP("0*+R\*"B\O(&9I
M<G-T+"!I;F-L=61E('1H92!33T%0+U-E<G9E<B!C;&%S<PIR97%U:7)E7V]N
M8V4@)U-/05`O4V5R=F5R+G!H<"<["@HD<V5R=F5R(#T@;F5W(%-/05!?4V5R
M=F5R.PHO*B!T96QL('-E<G9E<B!T;R!T<F%N<VQA=&4@=&\@8VQA<W-E<R!W
M92!P<F]V:61E(&EF('!O<W-I8FQE("HO"B1S97)V97(M/E]A=71O7W1R86YS
M;&%T:6]N(#T@=')U93L*"G)E<75I<F5?;VYC92`G97AA;7!L95]S97)V97(N
M<&AP)SL*"B1S;V%P8VQA<W,@/2!N97<@4T]!4%]%>&%M<&QE7U-E<G9E<B@I
M.PHD<V5R=F5R+3YA9&1/8FIE8W1-87`H)'-O87!C;&%S<RPG=7)N.E-/05!?
M17AA;7!L95]397)V97(G*3L*"FEF("AI<W-E="@D7U-%4E9%4ELG4D515453
M5%]-151(3T0G72D@)B8*("`@("1?4T525D526R=215%515-47TU%5$A/1"==
M/3TG4$]35"<I('L*("`@("1S97)V97(M/G-E<G9I8V4H)$A45%!?4D%77U!/
M4U1?1$%402D["GT@96QS92!["B`@("!R97%U:7)E7V]N8V4@)U-/05`O1&ES
M8V\N<&AP)SL*("`@("1D:7-C;R`](&YE=R!33T%07T1)4T-/7U-E<G9E<B@D
M<V5R=F5R+"=397)V97)%>&%M<&QE)RD["B`@("!H96%D97(H(D-O;G1E;G0M
M='EP93H@=&5X="]X;6PB*3L*("`@(&EF("AI<W-E="@D7U-%4E9%4ELG455%
M4EE?4U1224Y')UTI("8F"B`@("`@("!S=')C87-E8VUP*"1?4T525D526R=1
M545265]35%))3D<G72PG=W-D;"<I/3TP*2!["B`@("`@("`@96-H;R`D9&ES
M8V\M/F=E=%=31$PH*3L*("`@('T@96QS92!["B`@("`@("`@96-H;R`D9&ES
M8V\M/F=E=$1)4T-/*"D["B`@("!]"B`@("!E>&ET.PI]"C\^````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]D;V-S+U-/05`O97AA;7!L92]S97)V97(R+G!H<```````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`U,#4S(#$P-3$U-#,S-S,P(#`R,S<Q-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO+PHO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO
M;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S
M=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L("`@
M("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I
M;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I
M;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F
M('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O
M8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S
M96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T
M('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!!=71H;W)S.B!3:&%N92!#87)A=F5O(#Q3:&%N94!#87)A=F5O+F-O;3X@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z('-E<G9E<C(N<&AP+'8@,2XS(#(P
M,#4O,#,O,3`@,C,Z,38Z-#`@>75N;W-H($5X<"`D"B\O"@HO+R!F:7)S="P@
M:6YC;'5D92!T:&4@4T]!4"]397)V97(@8VQA<W,*<F5Q=6ER95]O;F-E("=3
M3T%0+U-E<G9E<BYP:'`G.PH*)'-E<G9E<B`](&YE=R!33T%07U-E<G9E<CL*
M+RH@=&5L;"!S97)V97(@=&\@=')A;G-L871E('1O(&-L87-S97,@=V4@<')O
M=FED92!I9B!P;W-S:6)L92`J+PHD<V5R=F5R+3Y?875T;U]T<F%N<VQA=&EO
M;B`]('1R=64["@HO*B!4:&ES(&ES(&$@<VEM<&QE(&5X86UP;&4@;V8@:6UP
M;&5M96YT:6YG(&$@8W5S=&]M"B`@(&-A;&P@:&%N9&QE<BX@($EF('EO=2!D
M;R!T:&ES+"!T:&4@<V]A<"!S97)V97(@=VEL;"!I9VYO<F4*("`@;V)J96-T
M<R!O<B!F=6YC=&EO;G,@861D960@=&\@:70L(&%N9"!W:6QL(&-A;&P@>6]U
M<B!H86YD;&5R"B`@(&9O<B`J*D%,3"HJ('-O87`@8V%L;',@=&AE('-E<G9E
M<B!R96-E:79E<RP@=V5T:&5R('1H92!C86QL"B`@(&ES(&1E9FEN960@:6X@
M>6]U<B!74T1,(&]R(&YO="X@(%1H92!H86YD;&5R(')E8V5I=F5S('1W;PH@
M("!A<F=U;65N=',L('1H92!M971H;V0@;F%M92!B96EN9R!C86QL960L(&%N
M9"!T:&4@87)G=6UE;G1S"B`@('-E;G0@9F]R('1H870@8V%L;"X**B\*9G5N
M8W1I;VX@;7E#86QL2&%N9&QE<B@D;65T:&]D;F%M92P@)&%R9W,I"GL*("`@
M(&=L;V)A;"`D<V]A<&-L87-S.PH@("`@<F5T=7)N($!C86QL7W5S97)?9G5N
M8U]A<G)A>2AA<G)A>2@D<V]A<&-L87-S+"`D;65T:&]D;F%M92DL)&%R9W,I
M.PI]"B1S97)V97(M/G-E=$-A;&Q(86YD;&5R*"=M>4-A;&Q(86YD;&5R)RQF
M86QS92D["@IR97%U:7)E7V]N8V4@)V5X86UP;&5?<V5R=F5R+G!H<"<["@HD
M<V]A<&-L87-S(#T@;F5W(%-/05!?17AA;7!L95]397)V97(H*3L*)'-E<G9E
M<BT^861D3V)J96-T36%P*"1S;V%P8VQA<W,L)W5R;CI33T%07T5X86UP;&5?
M4V5R=F5R)RD["@II9B`H:7-S970H)%]315)615);)U)%455%4U1?34542$]$
M)UTI("8F"B`@("`D7U-%4E9%4ELG4D5154535%]-151(3T0G73T])U!/4U0G
M*2!["B`@("`D<V5R=F5R+3YS97)V:6-E*"1(5%107U)!5U]03U-47T1!5$$I
M.PI](&5L<V4@>PH@("`@<F5Q=6ER95]O;F-E("=33T%0+T1I<V-O+G!H<"<[
M"B`@("`D9&ES8V\@/2!N97<@4T]!4%]$25-#3U]397)V97(H)'-E<G9E<BPG
M4V5R=F5R17AA;7!L92<I.PH@("`@:&5A9&5R*")#;VYT96YT+71Y<&4Z('1E
M>'0O>&UL(BD["B`@("!I9B`H:7-S970H)%]315)615);)U%515)97U-44DE.
M1R==*2`F)@H@("`@("`@<W1R8V%S96-M<"@D7U-%4E9%4ELG455%4EE?4U12
M24Y')UTL)W=S9&PG*3T],"D@>PH@("`@("`@(&5C:&\@)&1I<V-O+3YG9717
M4T1,*"D["B`@("!](&5L<V4@>PH@("`@("`@(&5C:&\@)&1I<V-O+3YG971$
M25-#3R@I.PH@("`@?0H@("`@97AI=#L*?0H_/@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O4T]!4"]E>&%M
M<&QE+W-M='`N<&AP````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,R
M-S,@,3`U,34T,S,W,S`@,#(S,S$Q`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC
M*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R
M+C`R(&]F('1H92!02%`@;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B
M=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L
M(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U
M(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N
M9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@
M("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U
M(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%-H86YE($-A
M<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/B`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O
M("1)9#H@<VUT<"YP:'`L=B`Q+C4@,C`P-2\P,R\Q,"`R,SHQ-CHT,"!Y=6YO
M<V@@17AP("0*+R\*+R\@:6YC;'5D92!S;V%P(&-L:65N="!C;&%S<PII;F-L
M=61E*")33T%0+T-L:65N="YP:'`B*3L*"B1S;V%P8VQI96YT(#T@;F5W(%-/
M05!?0VQI96YT*")M86EL=&\Z=7-E<D!D;VUA:6XN8V]M(BD["B1O<'1I;VYS
M(#T@87)R87DH)VYA;65S<&%C92<]/B=H='1P.B\O<V]A<&EN=&5R;W`N;W)G
M+R<L)V9R;VTG/3XG=7-E<D!D;VUA:6XN8V]M)RPG:&]S="<]/B=L;V-A;&AO
M<W0G*3L*)')E='5R;B`]("1S;V%P8VQI96YT+3YC86QL*")E8VAO4W1R:6YG
M(BQA<G)A>2@B:6YP=713=')I;F<B/3XB=&AI<R!I<R!A('1E<W0B*2P@)&]P
M=&EO;G,I.PHD<F5T=7)N(#T@)'-O87!C;&EE;G0M/F-A;&PH(F5C:&]3=')I
M;F=!<G)A>2(L87)R87DH)VEN<'5T4W1R:6YG07)R87DG(#T^(&%R<F%Y*"=G
M;V]D)RPG8F%D)RPG=6=L>2<I*2P@)&]P=&EO;G,I.PHO+R!D;VXG="!E>'!E
M8W0@;75C:"!O9B!A(')E<W5L="$*<')I;G1?<B@D<F5T=7)N*3L*<')I;G0@
M(CQB<CY<;B(N)'-O87!C;&EE;G0M/G=I<F4["C\^"@H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L92]S
M=&]C:W%U;W1E+G!H<```````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`T-#$R(#$P
M-3$U-#,S-S,P(#`R-#4R,P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\:'1M;#X\8F]D>3X*/#\*+R\*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y
M<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V
M97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*+R\@?"!T
M:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@
M3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?
M,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI
M8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@
M=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@
M;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@
M4VAA;F4@0V%R879E;R`\4VAA;F5`0V%R879E;RYC;VT^("`@4&]R="!T;R!0
M14%2(&%N9"!M;W)E("`@?`HO+R!\($%U=&AO<G,Z($1I971R:6-H($%Y86QA
M(#QD:65T<FEC:$!G86YX-"YC;VT^($]R:6=I;F%L($%U=&AO<B`@("`@("`@
M('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@
M<W1O8VMQ=6]T92YP:'`L=B`Q+C<@,C`P-2\P,R\Q,"`R,SHQ-CHT,"!Y=6YO
M<V@@17AP("0*+R\*+R\@:6YC;'5D92!S;V%P(&-L:65N="!C;&%S<PII;F-L
M=61E*")33T%0+T-L:65N="YP:'`B*3L*"G!R:6YT("(\8G(^7&X\<W1R;VYG
M/G=S9&PZ/"]S=')O;F<^(CL*)'=S9&P@/2!N97<@4T]!4%]74T1,*")H='1P
M.B\O<V5R=FEC97,N>&UE=&AO9',N;F5T+W-O87`O=7)N.GAM971H;V1S+61E
M;&%Y960M<75O=&5S+G=S9&PB*3L*)'-O87!C;&EE;G0@/2`D=W-D;"T^9V5T
M4')O>'DH*3L*<')I;G1?<B@D<V]A<&-L:65N="T^9V5T475O=&4H(FEB;2(I
M*3L*<')I;G0@(EQN7&XB.PH*:68@*&5X=&5N<VEO;E]L;V%D960H)V]V97)L
M;V%D)RDI('L*"7!R:6YT(")<;CQB<CX\<W1R;VYG/F]V97)L;V%D960Z/"]S
M=')O;F<^(CL*"21R970@/2`D<V]A<&-L:65N="T^9V5T475O=&4H(FEB;2(I
M.PH)<')I;G1?<B@D<F5T*3L*"7!R:6YT(")<;EQN(CL*?0IU;G-E="@D<V]A
M<&-L:65N="D["@IP<FEN="`B7&X\8G(^/'-T<F]N9SYN;VX@=W-D;#H\+W-T
M<F]N9SXB.PHD<V]A<&-L:65N="`](&YE=R!33T%07T-L:65N="@B:'1T<#HO
M+W-E<G9I8V5S+GAM971H;V1S+FYE=#HX,"]S;V%P(BD["B1N86UE<W!A8V4@
M/2`B=7)N.GAM971H;V1S+61E;&%Y960M<75O=&5S(CL*+RHJ"B`J('-O;64@
M<V]A<"!S97)V97)S(')E<75I<F4@82!3;V%P86-T:6]N(&AT='`@:&5A9&5R
M+B`@4$5!4CHZ4T]!4"!D;V5S"B`J(&YO="!U<V4@=&AE;2!I;B!A;GD@=V%Y
M+"!O=&AE<B!T;R!S96YD('1H96T@:68@>6]U('-U<'!L>2!T:&5M+@H@*B!S
M;V%P86-T:6]N(&ES(&1E<')E8V%T960@:6X@;&%T97(@4T]!4"!V97)S:6]N
M<RX*("HO"B1S;V%P86-T:6]N(#T@(G5R;CIX;65T:&]D<RUD96QA>65D+7%U
M;W1E<R-G9711=6]T92(["B1R970@/2`D<V]A<&-L:65N="T^8V%L;"@B9V5T
M475O=&4B+&%R<F%Y*")S>6UB;VPB/3XB:6)M(BDL)&YA;65S<&%C92PD<V]A
M<&%C=&EO;BD["G!R:6YT7W(H)')E="D["G!R:6YT(")<;EQN(CL*=6YS970H
M)'-O87!C;&EE;G0I.PH*/SX*/"]H=&UL/CPO8F]D>3X*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+U-/
M05`O97AA;7!L92]T8W!?8VQI96YT+G!H<```````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`S-#`P(#$P-3$U-#,S-S,P(#`R-#0T,@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO+PHO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O
M<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O
M('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@?`HO+R!\
M('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL
M92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@
M=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@
M;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@
M=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T
M92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A
M;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S
M.B!3:&%N92!(86YN82`\:6]R9'E?871?:6]R9'E?9&]T7V-O;3X@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+PHO+R`D260Z('1C<%]C;&EE;G0N<&AP+'8@,2XS(#(P,#4O,#,O
M,3`@,C,Z,38Z-#`@>75N;W-H($5X<"`D"B\O"@IR97%U:7)E7V]N8V4H)U-/
M05`O0VQI96YT+G!H<"<I.PH*(R!C;&EE;G0*)'-O87!C;&EE;G0@/2!N97<@
M4T]!4%]#;&EE;G0H(G1C<#HO+S$R-RXP+C`N,3HX,B(I.PH*(R!N86UE<W!A
M8V4*)&]P=&EO;G,@/2!A<G)A>2@G;F%M97-P86-E)R`]/B`G=7)N.E-/05!?
M17AA;7!L95]397)V97(G+"`G=')A8V4G(#T^(#$I.PH*(R!O;F4*)'!A<F%M
M<R`](&%R<F%Y*")S=')I;F<B(#T^(")T:&ES(&ES('-T<FEN9R`Q(BD["B1R
M970Q(#T@)'-O87!C;&EE;G0M/F-A;&PH(F5C:&]3=')I;F<B+"`D<&%R86US
M+"`D;W!T:6]N<RD["B,@96-H;R`B5TE213H@7&XB+B1S;V%P8VQI96YT+3Y?
M7V=E=%]W:7)E*"D["G!R:6YT7W(H)')E=#$I.PIE8VAO("(\8G(@+SY<;B([
M"@HC('1W;PHD<&%R86US(#T@87)R87DH(G-T<FEN9R(@/3X@(G1H:7,@:7,@
M<W1R:6YG(#(B*3L*)')E=#(@/2`D<V]A<&-L:65N="T^8V%L;"@B96-H;U-T
M<FEN9R(L("1P87)A;7,L("1O<'1I;VYS*3L*(R!E8VAO(")725)%.B!<;B(N
M)'-O87!C;&EE;G0M/E]?9V5T7W=I<F4H*3L*<')I;G1?<B@D<F5T,BD["F5C
M:&\@(CQB<B`O/EQN(CL*"C\^````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]33T%0+V5X
M86UP;&4O=&-P7V1A96UO;BYP;```````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,S$U-R`Q,#4Q-30S,S<S,"`P,C0R-C0`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````(R$O=7-R+V)I;B]P97)L("UW"G5S92!S
M=')I8W0["@H]:&5A9#$@4VEM<&QE(%-/05`@5$-0(%-E<G9E<@H*("`@(%-I
M;7!L92!33T%0(%1#4"!397)V97(@=VET:"!T97-T(&-L87-S("AJ=7-T('1O
M(&-H96-K('1H:6YG<R!A<F4@=V]R:VEN9RD*"B`@("!"969O<F4@>6]U(')U
M;B!T:&ES('1E<W0@<V5R=F5R('EO=2!W:6QL(&YE960@<V]M92!P97)L(&-L
M87-S97,L(&YA;65L>3H*("`@("`@("!33T%0.CI,:71E"B`@("`@("`@2&]O
M:SHZ3&5X5W)A<"`H:68@>6]U('=A;G0@=&\@<V5E('-O;64@9&5B=6=G:6YG
M*0H*("`@("`@("!&;&5E(&]F9B!T;R!T:&4@0U!!3B!I9B!Y;W4@;F5E9"!T
M:&5M(#HI"@H@("`@5&\@<G5N('1Y<&4@)W!E<FP@/&9I;&5N86UE/B<@86YD
M(&EF('EO=2!D;VYT(&=E="!A;GD@97)R;W)S+"!I="=S('1I;64*("`@('1O
M(&=O('=R:71E('-O;64@8V]D92!T;R!C;VYN96-T+@H]8W5T"@IU<V4@4T]!
M4#HZ5')A;G-P;W)T.CI40U`@<7<H=')A8V4I.PIU<V4@1&%T83HZ1'5M<&5R
M.PH*"B,C(R,C(R,C(R,C(R,*(R,@:68@>6]U('=A;G0@=&\@<V5E(&EN8V]M
M:6YG+V]U=&=O:6YG(')A=R!X;6P*(R,@=6YC;VUM96YT('1H92!F;VQL;W=I
M;F<N"@HC=7-E($AO;VLZ.DQE>%=R87`["B-W<F%P("I)3SHZ4V5S<VEO;D1A
M=&$Z.G)E860L('!O<W0@/3X@7"9S:&]W7W)E860["B-W<F%P("I)3SHZ4V5S
M<VEO;D1A=&$Z.G=R:71E+"!P;W-T(#T^(%PF<VAO=U]W<FET93L*"B,C"B,C
M(R,C(R,C(R,C(R,*"@IM>2`D9&%E;6]N(#T@4T]!4#HZ5')A;G-P;W)T.CI4
M0U`Z.E-E<G9E<BT^;F5W*`H@("`@3&]C86Q!9&1R(#T^("<Q,C<N,"XP+C$G
M+`H@("`@3&]C86Q0;W)T(#T^("<X,B<L"B`@("!,:7-T96X@("`@/3X@-2P*
M("`@(%)E=7-E("`@("`]/B`Q"BD["@HC(&1I<W!A=&-H"B1D865M;VXM/F1I
M<W!A=&-H7W1O*"=33T%07T5X86UP;&5?4V5R=F5R)RD["B1D865M;VXM/FAA
M;F1L93L*"B,C(R,C(R,C(R,C(R,*(R,@8V%L;&)A8VL@9G5N8W1I;VYS(&9O
M<B!(;V]K.CI,97A7<F%P.PHC(PH*(R!S:&]W(&EN8V]M:6YG('AM;`IS=6(@
M<VAO=U]R96%D('L*("`@('!R:6YT("0O+"<C(R!R96%D(",C)RPD+SL*("`@
M('!R:6YT($1U;7!E<B@D7ULP72D["GT*"B,@<VAO=R!O=71G;VEN9R!X;6P*
M<W5B('-H;W=?=W)I=&4@>PH@("`@<')I;G0@)"\L)R,C('=R:71E(",C)RPD
M+SL*("`@('!R:6YT($1U;7!E<B@D7ULP72D["GT*(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,*"@H*(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,*(R!33T%07T5X86UP;&5?4V5R=F5R"B,@4VEM<&QE
M('1E<W0@8VQA<W,L(&UE=&AO9"!T97-T(')E='5R;G,@9&]U8FQE('=H870@
M>6]U('-E;F0@=&\@:70L('1H871S(&%L;"$*(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,*<&%C:V%G92!33T%07T5X86UP;&5?4V5R=F5R
M.PH*<W5B(&5C:&]3=')I;F<@>PH@("`@<F5T=7)N("1?6S%=('@@,CL*?0H*
M,3L*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O4T]!4"]E>&%M<&QE
M+W1C<%]S97)V97(N<&AP````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,Q,C$@
M,3`U,34T,S,W,S`@,#(T-#<R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC
M*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R
M+C`R(&]F('1H92!02%`@;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B
M=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L
M(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U
M(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N
M9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@
M("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U
M(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%-H86YE($-A
M<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/B`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O
M("1)9#H@=&-P7W-E<G9E<BYP:'`L=B`Q+C0@,C`P-2\P,R\Q,"`R,SHQ-CHT
M,"!Y=6YO<V@@17AP("0*+R\*"B\O(&9I<G-T+"!I;F-L=61E('1H92!33T%0
M+U-E<G9E<B!C;&%S<PIR97%U:7)E7V]N8V4@)U-/05`O4V5R=F5R+U1#4"YP
M:'`G.PIS971?=&EM95]L:6UI="@P*3L*"B1S97)V97(@/2!N97<@4T]!4%]3
M97)V97)?5$-0*"(Q,C<N,"XP+C$B+#@R*3L*+RH@=&5L;"!S97)V97(@=&\@
M=')A;G-L871E('1O(&-L87-S97,@=V4@<')O=FED92!I9B!P;W-S:6)L92`J
M+PHD<V5R=F5R+3Y?875T;U]T<F%N<VQA=&EO;B`]('1R=64["@IR97%U:7)E
M7V]N8V4@)V5X86UP;&5?<V5R=F5R+G!H<"<["@HD<V]A<&-L87-S(#T@;F5W
M(%-/05!?17AA;7!L95]397)V97(H*3L*)'-E<G9E<BT^861D3V)J96-T36%P
M*"1S;V%P8VQA<W,L)W5R;CI33T%07T5X86UP;&5?4V5R=F5R)RD["B1S97)V
M97(M/G)U;B@I.PH_/@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L92]W<V1L
M7V-L:65N="YP:'``````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`V-#8T(#$P-3$U
M-#,S-S,P(#`R-#8T,@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY
M-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O
M9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE
M9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@
M:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@
M;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E
M('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\
M"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O
M<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!3:&%N92!#87)A=F5O
M(#Q3:&%N94!#87)A=F5O+F-O;3X@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z
M('=S9&Q?8VQI96YT+G!H<"QV(#$N,R`R,#`U+S`S+S$P(#(S.C$V.C0P('EU
M;F]S:"!%>'`@)`HO+PII;F-L=61E*")33T%0+T-L:65N="YP:'`B*3L*"B\J
M*@H@*B!T:&ES(&-L:65N="!R=6YS(&%G86EN<W0@=&AE(&5X86UP;&4@<V5R
M=F5R(&EN(%-/05`O97AA;7!L92]S97)V97(N<&AP"B`J(&ET(&1O97,@;F]T
M('5S92!74T1,('1O(')U;B!T:&5S92!R97%U97-T<RP@8G5T('1H870@8V%N
M(&)E(&-H86YG960@96%S:6QY(&)Y('-I;7!L>0H@*B!A9&1I;F<@)S]W<V1L
M)R!T;R!T:&4@96YD(&]F('1H92!U<FPN"B`J+PHD=W-D;"`](&YE=R!33T%0
M7U=31$PH(FAT='`Z+R]L;V-A;&AO<W0O4T]!4"]E>&%M<&QE+W-E<G9E<BYP
M:'`_=W-D;"(I.PHD<V]A<&-L:65N="`]("1W<V1L+3YG9710<F]X>2@I.PH*
M)')E="`]("1S;V%P8VQI96YT+3YE8VAO4W1R:6YG4VEM<&QE*")T:&ES(&ES
M(&$@=&5S="!S=')I;F<B*3L*(W!R:6YT("1S;V%P8VQI96YT+3Y?7V=E=%]W
M:7)E*"D["G!R:6YT7W(H)')E="D[96-H;R`B/&)R/EQN(CL*"B1R970@/2`D
M<V]A<&-L:65N="T^96-H;U-T<FEN9R@B=&AI<R!I<R!A('1E<W0@<W1R:6YG
M(BD["G!R:6YT7W(H)')E="D[96-H;R`B/&)R/EQN(CL*"B1R970@/2`D<V]A
M<&-L:65N="T^9&EV:61E*#(R+#<I.PHC('!R:6YT("1S;V%P8VQI96YT+3Y?
M7V=E=%]W:7)E*"D["FEF("A014%2.CII<T5R<F]R*"1R970I*0H@("`@<')I
M;G0H(D5R<F]R.B`B("X@)')E="T^9V5T365S<V%G92@I("X@(CQB<CY<;B(I
M.PIE;'-E"B`@("!P<FEN="@B475O=&EE;G0@:7,@(B`N("1R970@+B`B/&)R
M/EQN(BD["@HD<F5T(#T@)'-O87!C;&EE;G0M/F1I=FED92@R,BPP*3L*:68@
M*%!%05(Z.FES17)R;W(H)')E="DI"B`@("!P<FEN="@B17)R;W(Z("(@+B`D
M<F5T+3YG971-97-S86=E*"D@+B`B/&)R/EQN(BD["F5L<V4*("`@('!R:6YT
M*")1=6]T:65N="!I<R`B("X@)')E="`N("(\8G(^7&XB*3L*"@HO+R!33T%0
M4W1R=6-T(&ES(&1E9FEN960@:6X@=&AE(&9O;&QO=VEN9R!F:6QE"G)E<75I
M<F5?;VYC92`G97AA;7!L95]T>7!E<RYP:'`G.PH*)'-T<G5C="`](&YE=R!3
M3T%04W1R=6-T*"=T97-T('-T<FEN9R<L,3(S+#$R,RXQ,C,I.PH*+RH@<V5N
M9"!A;B!O8FIE8W0L(&=E="!A;B!O8FIE8W0@8F%C:R`J+PHO*B!T96QL(&-L
M:65N="!T;R!T<F%N<VQA=&4@=&\@8VQA<W-E<R!W92!P<F]V:61E(&EF('!O
M<W-I8FQE("HO"B1S;V%P8VQI96YT+3Y?875T;U]T<F%N<VQA=&EO;B`]('1R
M=64["B\J(&]R('EO=2!C86X@97AP;&EC:71L>2!S970@=&AE('1R86YS;&%T
M:6]N(&9O<@H@("!A('-P96-I9FEC(&-L87-S+B`@875T;U]T<F%N<VQA=&EO
M;B!W;W)K<R!F;W(@86QL(&-A<V5S+`H@("!B=70@;W!E;G,@04Y9(&-L87-S
M(&EN('1H92!S8W)I<'0@=&\@8F4@=7-E9"!A<R!A(&1A=&$@='EP92P*("`@
M86YD(&UA>2!N;W0@8F4@9&5S:7)E86)L92X@(&)O=&@@8V%N(&)E('5S960@
M;VX@8VQI96YT(&]R"B`@('-E<G9E<B`J+PHD<V]A<&-L:65N="T^7U]S971?
M='EP95]T<F%N<VQA=&EO;B@G>VAT='`Z+R]S;V%P:6YT97)O<"YO<F<O>'-D
M?5-/05!3=')U8W0G+"=33T%04W1R=6-T)RD["B1R970@/2`D<V]A<&-L:65N
M="T^96-H;U-T<G5C="@D<W1R=6-T+3Y?7W1O7W-O87`H*2D["B-P<FEN="`D
M<V]A<&-L:65N="T^7U]G971?=VER92@I.PIP<FEN=%]R*"1R970I.PH*+RHJ
M"B`J(%!(4"!D;V5S;B=T('-U<'!O<G0@;75L=&EP;&4@3U54('!A<F%M971E
M<G,@:6X@9G5N8W1I;VX@8V%L;',L('-O('=E"B`J(&UU<W0@9&\@82!L:71T
M;&4@=V]R:R!T;R!M86ME(&ET(&AA<'!E;B!H97)E+B`@5&AI<R!R97%U:7)E
M<R!K;F]W;&5D9V4@;VX@=&AE"B`J(&1E=F5L;W!E<G,@<&%R="!T;R!F:6=U
M<F4@;W5T(&AO=R!T:&5Y('=A;G0@=&\@9&5A;"!W:71H(&ET+@H@*B\*)')E
M="`]("1S;V%P8VQI96YT+3YE8VAO4W1R=6-T07-3:6UP;&54>7!E<R@D<W1R
M=6-T+3Y?7W1O7W-O87`H*2D["FEF("A014%2.CII<T5R<F]R*"1R970I*2![
M"B`@("!P<FEN="@B17)R;W(Z("(@+B`D<F5T+3YG971-97-S86=E*"D@+B`B
M/&)R/EQN(BD["GT@96QS92!["B`@("!L:7-T*"1S=')I;F<L("1I;G0L("1F
M;&]A="D@/2!A<G)A>5]V86QU97,H)')E="D["GT*96-H;R`B=F%R4W1R:6YG
M.B`D<W1R:6YG/&)R/EQN=F%R26YT.B`D:6YT/&)R/EQN=F%R1FQO870Z("1F
M;&]A=#QB<CY<;B(["@H_/@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]33T%0+V5X86UP;&4O8VQI
M96YT+G!H<```````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,#`Q-2`Q,#4Q
M-30S,S<S,"`P,C,U-S0`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y
M.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@
M;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L
M960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD
M(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O
M<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED
M(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R
M92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O
M<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@
M?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C
M;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@4VAA;F4@0V%R879E
M;R`\4VAA;F5`0V%R879E;RYC;VT^("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED
M.B!C;&EE;G0N<&AP+'8@,2XQ,"`R,#`U+S`S+S$P(#(S.C$V.C,Y('EU;F]S
M:"!%>'`@)`HO+PII;F-L=61E*")33T%0+T-L:65N="YP:'`B*3L*"B\J*@H@
M*B!T:&ES(&-L:65N="!R=6YS(&%G86EN<W0@=&AE(&5X86UP;&4@<V5R=F5R
M(&EN(%-/05`O97AA;7!L92]S97)V97(N<&AP"B`J(&ET(&1O97,@;F]T('5S
M92!74T1,('1O(')U;B!T:&5S92!R97%U97-T<RP@8G5T('1H870@8V%N(&)E
M(&-H86YG960@96%S:6QY(&)Y('-I;7!L>0H@*B!A9&1I;F<@)S]W<V1L)R!T
M;R!T:&4@96YD(&]F('1H92!U<FPN"B`J+PHD<V]A<&-L:65N="`](&YE=R!3
M3T%07T-L:65N="@B:'1T<#HO+VQO8V%L:&]S="]33T%0+V5X86UP;&4O<V5R
M=F5R+G!H<"(I.PHO+R!T:&ES(&YA;65S<&%C92!I<R!T:&4@<V%M92!A<R!D
M96-L87)E9"!I;B!S97)V97(N<&AP"B1O<'1I;VYS(#T@87)R87DH)VYA;65S
M<&%C92<@/3X@)W5R;CI33T%07T5X86UP;&5?4V5R=F5R)RP*("`@("`@("`@
M("`@("`@("`G=')A8V4G(#T^(#$I.PH*)')E="`]("1S;V%P8VQI96YT+3YC
M86QL*")E8VAO4W1R:6YG4VEM<&QE(BP*("`@("`@("`@("`@("`@("`@("`@
M("`@("1P87)A;7,@/2!A<G)A>2@B:6YP=713=')I;F=3:6UP;&4B/3XB=&AI
M<R!I<R!A('1E<W0@<W1R:6YG(BDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`D;W!T:6]N<RD["B-P<FEN="`D<V]A<&-L:65N="T^7U]G971?=VER92@I
M.PIP<FEN=%]R*"1R970I.V5C:&\@(CQB<CY<;B(["@HD<F5T(#T@)'-O87!C
M;&EE;G0M/F-A;&PH(F5C:&]3=')I;F<B+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@)'!A<F%M<R`](&%R<F%Y*")I;G!U=%-T<FEN9R(]/B)T:&ES(&ES
M(&$@=&5S="!S=')I;F<B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("1O
M<'1I;VYS*3L*<')I;G1?<B@D<F5T*3ME8VAO("(\8G(^7&XB.PH*)')E="`]
M("1S;V%P8VQI96YT+3YC86QL*")D:79I9&4B+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!A<F%M<R`](&%R<F%Y*")D:79I9&5N9"(]/C(R+")D:79I
M<V]R(CT^-RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`D;W!T:6]N<RD[
M"B,@<')I;G0@)'-O87!C;&EE;G0M/E]?9V5T7W=I<F4H*3L*:68@*%!%05(Z
M.FES17)R;W(H)')E="DI"B`@("!P<FEN="@B17)R;W(Z("(@+B`D<F5T+3YG
M971-97-S86=E*"D@+B`B/&)R/EQN(BD["F5L<V4*("`@('!R:6YT*")1=6]T
M:65N="!I<R`B("X@)')E="`N("(\8G(^7&XB*3L*"B1R970@/2`D<V]A<&-L
M:65N="T^8V%L;"@B9&EV:61E(BP*("`@("`@("`@("`@("`@("`@("`@("`@
M("1P87)A;7,@/2!A<G)A>2@B9&EV:61E;F0B/3XR,BPB9&EV:7-O<B(]/C`I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@)&]P=&EO;G,I.PII9B`H4$5!
M4CHZ:7-%<G)O<B@D<F5T*2D*("`@('!R:6YT*")%<G)O<CH@(B`N("1R970M
M/F=E=$UE<W-A9V4H*2`N("(\8G(^7&XB*3L*96QS90H@("`@<')I;G0H(E%U
M;W1I96YT(&ES("(@+B`D<F5T("X@(CQB<CY<;B(I.PH*"B\O(%-/05!3=')U
M8W0@:7,@9&5F:6YE9"!I;B!T:&4@9F]L;&]W:6YG(&9I;&4*<F5Q=6ER95]O
M;F-E("=E>&%M<&QE7W1Y<&5S+G!H<"<["@HD<W1R=6-T(#T@;F5W(%-/05!3
M=')U8W0H)W1E<W0@<W1R:6YG)RPQ,C,L,3(S+C$R,RD["@HO*B!S96YD(&%N
M(&]B:F5C="P@9V5T(&%N(&]B:F5C="!B86-K("HO"B\J('1E;&P@8VQI96YT
M('1O('1R86YS;&%T92!T;R!C;&%S<V5S('=E('!R;W9I9&4@:68@<&]S<VEB
M;&4@*B\*)'-O87!C;&EE;G0M/E]A=71O7W1R86YS;&%T:6]N(#T@=')U93L*
M+RH@;W(@>6]U(&-A;B!E>'!L:6-I=&QY('-E="!T:&4@=')A;G-L871I;VX@
M9F]R"B`@(&$@<W!E8VEF:6,@8VQA<W,N("!A=71O7W1R86YS;&%T:6]N('=O
M<FMS(&9O<B!A;&P@8V%S97,L"B`@(&)U="!O<&5N<R!!3ED@8VQA<W,@:6X@
M=&AE('-C<FEP="!T;R!B92!U<V5D(&%S(&$@9&%T82!T>7!E+`H@("!A;F0@
M;6%Y(&YO="!B92!D97-I<F5A8FQE+B`@8F]T:"!C86X@8F4@=7-E9"!O;B!C
M;&EE;G0@;W(*("`@<V5R=F5R("HO"B1S;V%P8VQI96YT+3Y?7W-E=%]T>7!E
M7W1R86YS;&%T:6]N*"=[:'1T<#HO+W-O87!I;G1E<F]P+F]R9R]X<V1]4T]!
M4%-T<G5C="<L)U-/05!3=')U8W0G*3L*)')E="`]("1S;V%P8VQI96YT+3YC
M86QL*")E8VAO4W1R=6-T(BP*("`@("`@("`@("`@("`@("`@("`@("`@("1P
M(#T@87)R87DH)VEN<'5T4W1R=6-T)R`]/B`D<W1R=6-T+3Y?7W1O7W-O87`H
M*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`D;W!T:6]N<RD["B-P<FEN
M="`D<V]A<&-L:65N="T^7U]G971?=VER92@I.PIP<FEN=%]R*"1R970I.PH*
M+RHJ"B`J(%!(4"!D;V5S;B=T('-U<'!O<G0@;75L=&EP;&4@3U54('!A<F%M
M971E<G,@:6X@9G5N8W1I;VX@8V%L;',L('-O('=E"B`J(&UU<W0@9&\@82!L
M:71T;&4@=V]R:R!T;R!M86ME(&ET(&AA<'!E;B!H97)E+B`@5&AI<R!R97%U
M:7)E<R!K;F]W;&5D9V4@;VX@=&AE"B`J(&1E=F5L;W!E<G,@<&%R="!T;R!F
M:6=U<F4@;W5T(&AO=R!T:&5Y('=A;G0@=&\@9&5A;"!W:71H(&ET+@H@*B\*
M)')E="`]("1S;V%P8VQI96YT+3YC86QL*")E8VAO4W1R=6-T07-3:6UP;&54
M>7!E<R(L"B`@("`@("`@("`@("`@("`@("`@("`@("`D<"`](&%R<F%Y*"=I
M;G!U=%-T<G5C="<@/3X@)'-T<G5C="T^7U]T;U]S;V%P*"DI+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@)&]P=&EO;G,I.PII9B`H4$5!4CHZ:7-%<G)O
M<B@D<F5T*2D@>PH@("`@<')I;G0H(D5R<F]R.B`B("X@)')E="T^9V5T365S
M<V%G92@I("X@(CQB<CY<;B(I.PI](&5L<V4@>PH@("`@;&ES="@D<W1R:6YG
M+"`D:6YT+"`D9FQO870I(#T@87)R87E?=F%L=65S*"1R970I.PI]"F5C:&\@
M(G9A<E-T<FEN9SH@)'-T<FEN9SQB<CY<;G9A<DEN=#H@)&EN=#QB<CY<;G9A
M<D9L;V%T.B`D9FQO870\8G(^7&XB.PH*/SX`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]D;V-S+TYE=%]&5%``````````````````````````
M`````````````````````````````````````````````````````#`P,#<U
M-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S,P(#`R
M,#4W,P`@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O3F5T7T944"]E
M>&%M<&QE````````````````````````````````````````````````````
M````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P
M,#`@,3`U,34T,S,W,S`@,#(R,C(V`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O9&]C<R].971?1E10+V5X86UP;&4O:6YD97@N<&AP````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`Q,C,P,R`Q,#4Q-30S,S<S,"`P,C0Q,C0`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*"B\J
M('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O
M9G1T86)S=&]P/30Z("HO"@HO*BH*("H@3F5T7T944"!G96YE<F%L(&5X86UP
M;&4N"B`J"B`J($=E;F5R86P@97AA;7!L92!F:6QE(&9O<B!T:&4@=7-A9V4@
M;V8@3F5T7T944"X*("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@
M3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I
M;VX@,RXP(&]F('1H92!02%`@;&EC96YS90H@*B!T:&%T(&ES(&%V86EL86)L
M92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG
M(%5223H*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@
M($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H92!02%`@
M3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T
M:&4@=V5B+"!P;&5A<V4*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N
M;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J
M"B`J($!C871E9V]R>2`@($YE='=O<FMI;F<*("H@0'!A8VMA9V4@("`@1E10
M"B`J($!A=71H;W(@("`@(%1O8FEA<R!38VAL:71T(#QT;V)Y0'!H<"YN970^
M"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L
M:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@
M(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@:6YD
M97@N<&AP+'8@,2XT(#(P,#4O,#(O,C,@,3(Z,3(Z,C,@=&]B>2!%>'`@)`H@
M*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O3F5T
M7T944`H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE
M87-E(#`N,"XQ"B`J+PH*<F5Q=6ER95]O;F-E("=.970O1E10+G!H<"<["G)E
M<75I<F5?;VYC92`G5F%R7T1U;7`N<&AP)SL*"B\J*@H@*B!3971T:6YG('5P
M('1E<W0@=F%R:6%B;&5S+B!4:&4@9F]L;&]W:6YG('9A<FEA8FQE<R!H879E
M('1O(&)E('-E=`H@*B!U<"P@=&\@<W5I=&4@=&AE(&YE961S(&]F('EO=7(@
M96YV:7)O;FUE;G0N"B`J+PH*)&AO<W0@("`@("`@("`@(#T@)R<["B1P;W)T
M("`@("`@("`@("`](#(Q.PHD=7-E<B`@("`@("`@("`@/2`G)SL*)'!A<W,@
M("`@("`@("`@(#T@)R<["@HO+R!4:&4@;&]C86P@8F%S92!D:7)E8W1O<GD@
M9F]R($944"!O<&5R871I;VYS+@HD8F%S941I<B`@("`@("`@/2`G+B]T97-T
M+R<["B\O(%1H92!D:7)E8W1O<GD@=&\@=7!L;V%D('1O('1H92!&5%`@<V5R
M=F5R(&9O<B!T97-T:6YG+@HD=&5S=%5P1&ER("`@("`@/2`G=&5S=%]U<"\G
M.PHO+R!4:&4@9&ER96-T;W)Y('1O(&1O=VYL;V%D('1O(&9O<B!T97-T:6YG
M+@HD=&5S=$1O=VY$:7(@("`@/2`G=&5S=%]D;W=N+R<["B\O(%1H92!F:6QE
M(&9O<B!S:6YG;&4@9FEL92!U<"T@86YD(&1O=VYL;V%D('1E<W1I;F<N"B1S
M:6YG;&5497-T1FEL92`]("=T97-T+GII<"<["@HO+R!);FET:6%L:7II;F<@
M5F%R7U9A<E]$=6UP.CID:7-P;&%Y"FEF("AI<W-E="@D7U-%4E9%4BDI('L*
M("`@("\O(%-E='5P(&9O<B!D:7-P;&%Y:6YG(%A(5$U,(&]U='!U="X*("`@
M(%9A<E]$=6UP.CID:7-P;&%Y26YI="AA<G)A>2@*("`@("`@("`G9&ES<&QA
M>5]M;V1E)ST^)UA(5$U,7U1E>'0G"B`@("`I+"!A<G)A>2@*("`@("`@("`G
M;6]D92<]/B=N;W)M86PG+`H@("`@("`@("=O9F9S970G/3XT"B`@("`I*3L*
M("`@("\O($AE861L:6YE(&9U;F-T:6]N(&9O<B!82%1-3"!O=71P=70N"B`@
M("!F=6YC=&EO;B!H96%D("@@)'1E>'0@*2!["B`@("`@("`@96-H;R`G/&)R
M("\^/&(^)RXD=&5X="XG/"]B/CQB<B`O/B<["B`@("!]"GT@96QS92!["B`@
M("`O+R!3971U<"!F;W(@9&ES<&QA>6EN9R!C;VYS;VQE(&]U='!U="X*("`@
M(%9A<E]$=6UP.CID:7-P;&%Y26YI="AA<G)A>2@G9&ES<&QA>5]M;V1E)ST^
M)U1E>'0G*2D["B`@("`O+R!(96%D;&EN92!F=6YC=&EO;B!F;W(@6$A434P@
M;W5T<'5T+@H@("`@9G5N8W1I;VX@:&5A9"`H("1T97AT("D@>PH@("`@("`@
M(&5C:&\@(EQN+2TM("(N)'1E>'0N(B`M+2U<;B(["B`@("!]"GT*"FAE860H
M(EPD9G1P(#T@;F5W($YE=%]&5%`H*3LB*3L*)&9T<"`](&YE=R!.971?1E10
M*"D["@IH96%D*")<)&9T<"T^<V5T2&]S=&YA;64H)&AO<W0I(BD["E9A<E]$
M=6UP.CID:7-P;&%Y*"1F='`M/G-E=$AO<W1N86UE*"1H;W-T*2D["@IH96%D
M*")<)&9T<"T^<V5T4&]R="@D<&]R="DB*3L*5F%R7T1U;7`Z.F1I<W!L87DH
M)&9T<"T^<V5T4&]R="@D<&]R="DI.PH*:&5A9"@B7"1F='`M/F-O;FYE8W0H
M)&AO<W0L("1P;W)T*2(I.PI687)?1'5M<#HZ9&ES<&QA>2@D9G1P+3YC;VYN
M96-T*"DI.PH*:&5A9"@B7"1F='`M/G-E=%5S97)N86UE*"1U<V5R*2(I.PI6
M87)?1'5M<#HZ9&ES<&QA>2@D9G1P+3YS9715<V5R;F%M92@D=7-E<BDI.PH*
M:&5A9"@B7"1F='`M/G-E=%!A<W-W;W)D*'AX>"DB*3L*5F%R7T1U;7`Z.F1I
M<W!L87DH)&9T<"T^<V5T4&%S<W=O<F0H)'!A<W,I*3L*"FAE860H(EPD9G1P
M+3YL;V=I;B@D=7-E<BP@>'AX*2(I.PI687)?1'5M<#HZ9&ES<&QA>2@D9G1P
M+3YL;V=I;B@D=7-E<BP@)'!A<W,I*3L*"FAE860H(EPD9G1P+3YP=V0H*2(I
M.PI687)?1'5M<#HZ9&ES<&QA>2@D9G1P+3YP=V0H*2D["@IH96%D*")<)&9T
M<"T^;',H;G5L;"P@3D547T944%]$25)37T9)3$53*2(I.PI687)?1'5M<#HZ
M9&ES<&QA>2@D9G1P+3YL<RAN=6QL+"!.151?1E107T1)4E-?1DE,15,I*3L*
M"FAE860H(EPD9G1P+3YM:V1I<B@D8F%S941I<BDB*3L*5F%R7T1U;7`Z.F1I
M<W!L87DH)&9T<"T^;6MD:7(H)&)A<V5$:7(I*3L*"FAE860H(EPD9G1P+3YC
M9"@D8F%S941I<BDB*3L*5F%R7T1U;7`Z.F1I<W!L87DH)&9T<"T^8V0H)&)A
M<V5$:7(I*3L*"FAE860H(EPD9G1P+3YL<RAN=6QL+"!.151?1E107U)!5TQ)
M4U0I(BD["E9A<E]$=6UP.CID:7-P;&%Y*"1F='`M/FQS*&YU;&PL($Y%5%]&
M5%!?4D%73$E35"DI.PH*:&5A9"@B7"1F='`M/G!U="@D8F%S941I<B1S:6YG
M;&5497-T1FEL92P@)'-I;F=L951E<W1&:6QE*2(I.PI687)?1'5M<#HZ9&ES
M<&QA>2@D9G1P+3YP=70H)&)A<V5$:7(N)'-I;F=L951E<W1&:6QE+"`D<VEN
M9VQE5&5S=$9I;&4I*3L*"FAE860H(EPD9G1P+3YL<RAN=6QL+"!.151?1E10
M7T9)3$537T].3%DI(BD["E9A<E]$=6UP.CID:7-P;&%Y*"1F='`M/FQS*&YU
M;&PL($Y%5%]&5%!?1DE,15-?3TY,62DI.PH*:&5A9"@B7"1F='`M/G!U="@D
M8F%S941I<B1S:6YG;&5497-T1FEL92P@)'-I;F=L951E<W1&:6QE+"!T<G5E
M*2(I.PI687)?1'5M<#HZ9&ES<&QA>2@D9G1P+3YP=70H)&)A<V5$:7(N)'-I
M;F=L951E<W1&:6QE+"`D<VEN9VQE5&5S=$9I;&4L('1R=64I*3L*"FAE860H
M(EPD9G1P+3YL<RAN=6QL+"!.151?1E107T9)3$537T].3%DI(BD["E9A<E]$
M=6UP.CID:7-P;&%Y*"1F='`M/FQS*&YU;&PL($Y%5%]&5%!?1DE,15-?3TY,
M62DI.PH*:&5A9"@B7"1F='`M/FUD=&TH)'-I;F=L951E<W1&:6QE+"`G9"YM
M+ED@2#II.G,G*2(I.PI687)?1'5M<#HZ9&ES<&QA>2@D9G1P+3YM9'1M*"1S
M:6YG;&5497-T1FEL92P@)V0N;2Y9)RDI.PH*:&5A9"@B7"1F='`M/G-I>F4H
M)'-I;F=L951E<W1&:6QE*2(I.PI687)?1'5M<#HZ9&ES<&QA>2@D9G1P+3YS
M:7IE*"1S:6YG;&5497-T1FEL92DI.PH*:&5A9"@B7"1F='`M/F=E="@D<VEN
M9VQE5&5S=$9I;&4L("1B87-E1&ER)'-I;F=L951E<W1&:6QE+"!T<G5E*2(I
M.PI687)?1'5M<#HZ9&ES<&QA>2@D9G1P+3YG970H)'-I;F=L951E<W1&:6QE
M+"`D8F%S941I<BXD<VEN9VQE5&5S=$9I;&4L('1R=64I*3L*"FAE860H(EPD
M9G1P+3YC:&UO9"@D<VEN9VQE5&5S=$9I;&4L(#<P,"DB*3L*5F%R7T1U;7`Z
M.F1I<W!L87DH)&9T<"T^8VAM;V0H)'-I;F=L951E<W1&:6QE+"`W,#`I*3L*
M"FAE860H(EPD9G1P+3YL<RAN=6QL+"!.151?1E107T9)3$537T].3%DI(BD[
M"E9A<E]$=6UP.CID:7-P;&%Y*"1F='`M/FQS*&YU;&PL($Y%5%]&5%!?1DE,
M15-?3TY,62DI.PH*:&5A9"@B7"1F='`M/F-D*"<N+B\G*2(I.PI687)?1'5M
M<#HZ9&ES<&QA>2@D9G1P+3YC9"@G+BXO)RDI.PH*:&5A9"@B7"1F='`M/F-H
M;6]D4F5C=7)S:79E*"1B87-E1&ER+"`W-S<I(BD["E9A<E]$=6UP.CID:7-P
M;&%Y*"1F='`M/F-H;6]D4F5C=7)S:79E*"1B87-E1&ER+"`W-S<I*3L*"FAE
M860H(EPD9G1P+3YL<RAN=6QL+"!.151?1E107T1)4E-?3TY,62DB*3L*5F%R
M7T1U;7`Z.F1I<W!L87DH)&9T<"T^;',H;G5L;"P@3D547T944%]$25)37T].
M3%DI*3L*"FAE860H(EPD9G1P+3YP=71296-U<G-I=F4H)&)A<V5$:7(D=&5S
M=%5P1&ER+"`D8F%S941I<B1T97-T57!$:7(I(BD["E9A<E]$=6UP.CID:7-P
M;&%Y*"1F='`M/G!U=%)E8W5R<VEV92@D8F%S941I<BXD=&5S=%5P1&ER+"`D
M8F%S941I<BXD=&5S=%5P1&ER*2D["@IH96%D*")<)&9T<"T^<'5T4F5C=7)S
M:79E*"1B87-E1&ER)'1E<W15<$1I<BP@)&)A<V5$:7(D=&5S=%5P1&ER*2(I
M.PI687)?1'5M<#HZ9&ES<&QA>2@D9G1P+3YP=71296-U<G-I=F4H)&)A<V5$
M:7(N)'1E<W15<$1I<BP@)&)A<V5$:7(N)'1E<W15<$1I<BP@=')U92DI.PH*
M:&5A9"@B7"1F='`M/F-D*"1B87-E1&ER.B1T97-T57!$:7(I(BD["E9A<E]$
M=6UP.CID:7-P;&%Y*"1F='`M/F-D*"1B87-E1&ER+B1T97-T57!$:7(I*3L*
M"FAE860H(EPD9G1P+3YL<RAN=6QL+"!.151?1E107T1)4E-?1DE,15,I(BD[
M"E9A<E]$=6UP.CID:7-P;&%Y*"1F='`M/FQS*&YU;&PL($Y%5%]&5%!?1$E2
M4U]&24Q%4RDI.PH*:&5A9"@B7"1F='`M/F-D*"XN+RXN+RDB*3L*5F%R7T1U
M;7`Z.F1I<W!L87DH)&9T<"T^8V0H)RXN+RXN+R<I*3L*"FAE860H(EPD9G1P
M+3YG971296-U<G-I=F4H)&)A<V5$:7(D=&5S=%5P1&ER+"`D8F%S941I<B1T
M97-T1&]W;D1I<BDB*3L*5F%R7T1U;7`Z.F1I<W!L87DH)&9T<"T^9V5T4F5C
M=7)S:79E*"1B87-E1&ER+B1T97-T57!$:7(L("1B87-E1&ER+B1T97-T1&]W
M;D1I<BP@=')U92DI.PH*:&5A9"@B7"1F='`M/G)M*"1B87-E1&ER+"!T<G5E
M*2(I.PI687)?1'5M<#HZ9&ES<&QA>2@D9G1P+3YR;2@D8F%S941I<BP@=')U
M92DI.PH*:&5A9"@B7"1F='`M/FQS*&YU;&PL($Y%5%]&5%!?1$E24U]/3DQ9
M*2(I.PI687)?1'5M<#HZ9&ES<&QA>2@D9G1P+3YL<RAN=6QL+"!.151?1E10
M7T1)4E-?3TY,62DI.PH*:&5A9"@B7"1F='`M/F1I<V-O;FYE8W0H*2(I.PI6
M87)?1'5M<#HZ9&ES<&QA>2@D9G1P+3YD:7-C;VYN96-T*"DI.PH_/@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R].971?1E10+V5X86UP
M;&4O;V)S97)V97(N<&AP````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,S`W,B`Q
M,#4Q-30S,S<S,"`P,C0V-3``(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`-"@T*+RH@=FEM.B!S970@97AP86YD=&%B
M('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A8G-T;W`]-#H@*B\-"@T*
M+RHJ#0H@*B!.971?1E10(&]B<V5R=F5R(&5X86UP;&4N#0H@*@T*("H@3F5T
M($944"!/8G-E<G9E<B!E>&%M<&QE('1O('5S92!W:71H($A434Q?4')O9W)E
M<W,@<&%C:V%G90T*("H@*%!(4"`T(#X](%!(4"`T+C,N,"D-"B`J#0H@*B!0
M2%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U
M<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0
M(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O
M<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R
M92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E
M#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N
M(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O
M<GD@("!.971W;W)K:6YG#0H@*B!`<&%C:V%G92`@("!&5%`-"B`J($!A=71H
M;W(@("`@(%1O8FEA<R!38VAL:71T(#QT;V)Y0'!H<"YN970^#0H@*B!`875T
M:&]R("`@("!,875R96YT($QA=FEL;&4@/'!E87)`;&%U<F5N="UL879I;&QE
M+F]R9SX-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P
M#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S
M7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@
M)$ED.B!O8G-E<G9E<BYP:'`L=B`Q+C(@,C`P-2\P,B\R,R`Q,CHQ,CHR,R!T
M;V)Y($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T
M+W!A8VMA9V4O3F5T7T944`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N
M<&AP+FYE="]P86-K86=E+TA434Q?4')O9W)E<W,-"B`J($!S:6YC92`@("`@
M($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XS+C`-"B`J+PT*#0IR
M97%U:7)E7V]N8V4@)TYE="]&5%`N<&AP)SL-"G)E<75I<F5?;VYC92`G3F5T
M+T944"]/8G-E<G9E<BYP:'`G.PT*<F5Q=6ER95]O;F-E("=(5$U,+U!R;V=R
M97-S+G!H<"<[#0H-"B\J*@T*("H@26YI=&EA;&EZ:6YG('1E<W0@=F%R:6%B
M;&5S("AR97%U:7)E9"$I#0H@*B\-"B1F='`@/2!A<G)A>2@-"B`@("`G:&]S
M="<@/3X@)R<L#0H@("`@)W!O<G0G(#T^(#(Q+`T*("`@("=U<V5R)R`]/B`G
M)RP-"B`@("`G<&%S<R<@/3X@)R<-"BD[("`@(`T*#0HD9&5S="`]("=T;7`G
M.R`@("`@("`@("`@("`@("`@("`O+R!T:&ES(&1I<F5C=&]R>2!M=7-T(&5X
M:7-T<R!I;B!Y;W5R(&9T<"!S97)V97(@(0T*)&]V97)W<FET92`]('1R=64[
M("`@("`@("`@("`@("`@+R\@;W9E<G=R:71E(&%L;"!E>&ES=&EN9R!F:6QE
M<R!O;B!T:&4@9G1P('-E<G9E<@T*)&9I;&5S(#T@87)R87DH#0H@("`@)TA4
M34Q?4')O9W)E<W,M,2XR+C`N=&=Z)RP-"B`@("`G<&AP-&5V97(N<&YG)R`@
M("`@("`@("`@("`@("\O(&EN:71I86QI>FEN9R!C;VYT96YT<R`H<F5Q=6ER
M960A*2!F:6QE*',I(&UU<W0@97AI<W1S#0HI.R`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!F:6QE*',I('1O('5P;&]A9`T*#0H-"B\O#0HO
M+R`Q+B!$969I;F5S('1H92!&5%`O4')O9W)E<W,@3V)S97)V97(@#0HO+PT*
M8VQA<W,@3V)S97)V97)?4')O9W)E<W-5<&QO860@97AT96YD<R!.971?1E10
M7T]B<V5R=F5R#0I[#0H@("`@=F%R("1P<F]G<F5S<SL-"@T*("`@(&9U;F-T
M:6]N($]B<V5R=F5R7U!R;V=R97-S57!L;V%D*"8D<')O9W)E<W,I#0H@("`@
M>PT*("`@("`@("`O*B!#86QL('1H92!B87-E(&-L87-S(&-O;G-T<G5C=&]R
M+B`J+PT*("`@("`@("!P87)E;G0Z.DYE=%]&5%!?3V)S97)V97(H*3L-"@T*
M("`@("`@("`O*BH-"B`@("`@("`@("`@0V]N9FEG=7)E('1H92!O8G-E<G9E
M<CH-"B`@("`@("`@("`@#0H@("`@("`@("`@($)E('-U<F4@=&\@:&%V92!A
M;B!I;F1E=&5R;6EN871E('!R;V=R97-S(&UE=&5R('=H96X-"B`@("`@("`@
M("`@0&QI;FL@:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A;"]E;B]F=6YC=&EO
M;BYF='`M;F(M<'5T+G!H<`T*("`@("`@("`@("!S=&]R97,@82!F:6QE(&]N
M('1H92!&5%`@<V5R=F5R("AN;VXM8FQO8VMI;F<I#0H@("`@("`@("`J+PT*
M("`@("`@("`D=&AI<RT^<')O9W)E<W,@/28@)'!R;V=R97-S.PT*("`@("`@
M("`D=&AI<RT^<')O9W)E<W,M/G-E=$EN9&5T97)M:6YA=&4H=')U92D[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@;F]T:69Y*"1E=F5N="D-"B`@("![#0H@
M("`@("`@("1T:&ES+3YP<F]G<F5S<RT^9&ES<&QA>2@I.PT*("`@("`@("`D
M=&AI<RT^<')O9W)E<W,M/G-L965P*"D[#0H@("`@("`@("`@("`@("`@(`T*
M("`@("`@("!I9B`H)'1H:7,M/G!R;V=R97-S+3YG971097)C96YT0V]M<&QE
M=&4H*2`]/2`Q*2![#0H@("`@("`@("`@("`D=&AI<RT^<')O9W)E<W,M/G-E
M=%9A;'5E*#`I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'1H
M:7,M/G!R;V=R97-S+3YI;F-686QU92@I.PT*("`@("`@("!]#0H@("`@?0T*
M?0T*#0HO+PT*+R\@,BX@9&5F:6YE<R!T:&4@<')O9W)E<W,@;65T97(@#0HO
M+PT*)&UE=&5R(#T@;F5W($A434Q?4')O9W)E<W,H*3L-"B1U:2`]("8@)&UE
M=&5R+3YG971522@I.PT*)'5I+3YS9710<F]G<F5S<T%T=')I8G5T97,H87)R
M87DH#0H@("`@)V)A8VMG<F]U;F0M8V]L;W(G(#T^("<C93!E,&4P)PT**2D[
M("`@("`@("`-"B1U:2T^<V5T4W1R:6YG071T<FEB=71E<RAA<G)A>2@-"B`@
M("`G8V]L;W(G("`]/B`G(SDY-B<L#0H@("`@)V)A8VMG<F]U;F0M8V]L;W(G
M(#T^("<C0T-#0SDY)PT**2D[("`@("`@("`-"B1U:2T^<V5T0V5L;$%T=')I
M8G5T97,H87)R87DH#0H@("`@)V%C=&EV92UC;VQO<B<@/3X@)R,Y.38G#0HI
M*3L-"@T*)&UE=&5R+3YS971!;FEM4W!E960H,C`P*3L-"B1M971E<BT^<V5T
M26YC<F5M96YT*#$P*3L-"B1M971E<BT^<V5T4W1R:6YG4&%I;G1E9"AT<G5E
M*3L@("`@("\O(&=E="!S<&%C92!F;W(@=&AE('-T<FEN9PT*)&UE=&5R+3YS
M9713=')I;F<H(B(I.R`@("`@("`@("`@("`@+R\@8G5T(&1O;B=T('!A:6YT
M(&ET#0HD;65T97(M/G-E=$EN9&5T97)M:6YA=&4H=')U92D[("`@("`O+R!P
M<F]G<F5S<R!M971E<B!S=&%R="!I;B!I;F1E=&5R;6EN871E(&UO9&4-"C\^
M#0H\(41/0U194$4@:'1M;"!054),24,@(BTO+U<S0R\O1%1$(%A(5$U,(#$N
M,"!4<F%N<VET:6]N86PO+T5.(@T*("`@(")H='1P.B\O=W=W+G<S+F]R9R]4
M4B]X:'1M;#$O1%1$+WAH=&UL,2UT<F%N<VET:6]N86PN9'1D(CX-"CQH=&UL
M('AM;&YS/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY+WAH=&UL(CX-"CQH96%D
M/@T*/'1I=&QE/D944"]0<F]G<F5S<R!/8G-E<G9E<B!E>&%M<&QE/"]T:71L
M93X-"CQS='EL92!T>7!E/2)T97AT+V-S<R(^#0H\(2TM#0IB;V1Y('L-"B`@
M("!B86-K9W)O=6YD+6-O;&]R.B`C0T-#0SDY.PT*("`@(&-O;&]R.B`C.3DV
M.PT*("`@(&9O;G0M9F%M:6QY.B!697)D86YA+"!!<FEA;#L-"GT-"@T*/#]P
M:'`@96-H;R`D;65T97(M/F=E=%-T>6QE*"D[(#\^#0HO+R`M+3X-"CPO<W1Y
M;&4^#0H\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^#0H\(2TM#0H\
M/W!H<"!E8VAO("1M971E<BT^9V5T4V-R:7!T*"D[(#\^#0HO+RTM/@T*/"]S
M8W)I<'0^#0H\+VAE860^#0H\8F]D>3X-"@T*/#]P:'`@#0IE8VAO("1M971E
M<BT^=&](=&UL*"D[#0I`<V5T7W1I;65?;&EM:70H,"D[("`O+R!U;FQI;6ET
M960@=&EM92!O<&5R871I;VX@*')E;6]V960@,S!S(&1E9F%U;'0@<F5S=')I
M8W1I;VXI#0H-"B1F(#T@;F5W($YE=%]&5%`H*3L-"@T*+R\-"B\O(#,N(&-O
M;FYE8W0@=&\@=&AE($944"!S97)V97(@#0HO+PT*)')E="`]("1F+3YC;VYN
M96-T*"1F='!;)VAO<W0G72P@)&9T<%LG<&]R="==*3L-"FEF("A014%2.CII
M<T5R<F]R*"1R970I*2![#0H@("`@9&EE*"1R970M/F=E=$UE<W-A9V4H*2D[
M#0I]#0IP<FEN=&8H)V-O;FYE8W1E9"!A="`\8CXE<SPO8CX\8G(@+SXG+"`D
M9G1P6R=H;W-T)UTI.PT*#0HO+PT*+R\@-"X@;&]G:6X@=&\@=&AE($944"!S
M97)V97(@87,@82!W96QL+6MN;W=N('5S97(-"B\O#0HD<F5T(#T@)&8M/FQO
M9VEN*"1F='!;)W5S97(G72P@)&9T<%LG<&%S<R==*3L-"FEF("A014%2.CII
M<T5R<F]R*"1R970I*2![#0H@("`@)&8M/F1I<V-O;FYE8W0H*3L-"B`@("!D
M:64H)')E="T^9V5T365S<V%G92@I*3L-"GT-"G!R:6YT9B@G;&]G:6X@87,@
M/&(^)7,\+V(^/&)R("\^)RP@)&9T<%LG=7-E<B==*3L-"@T*+R\-"B\O(#4N
M(&-H86YG97,@9&ER96-T;W)Y('1O(&9I;F%L(&1E<W1I;F%T:6]N(&9O<B!U
M<&QO860@;W!E<F%T:6]N#0HO+PT*)')E="`]("1F+3YC9"@D9&5S="D[#0II
M9B`H4$5!4CHZ:7-%<G)O<B@D<F5T*2D@>PT*("`@("1F+3YD:7-C;VYN96-T
M*"D[#0H@("`@9&EE*"1R970M/F=E=$UE<W-A9V4H*2D[#0I]#0H-"B\O#0HO
M+R`V+B!A='1A8VAS(&%N(&EN<W1A;F-E(&]F('1H92!&5%`O4')O9W)E<W,@
M<W5B8VQA<W,@;V)S97)V97(-"B\O#0HD;V)S97)V97(@/2!N97<@3V)S97)V
M97)?4')O9W)E<W-5<&QO860H)&UE=&5R*3L-"B1O:R`]("1F+3YA='1A8V@H
M)&]B<V5R=F5R*3L-"FEF("@A)&]K*2![#0H@("`@9&EE*"=C86YN;W0@871T
M86-H(&$@1E10($]B<V5R=F5R)RD[#0I]#0H-"B\O#0HO+R`W+B!M;W9E<R!F
M:6QE<R!O;B!T:&4@1E10('-E<G9E<@T*+R\-"F9O<F5A8V@H)&9I;&5S(&%S
M("1F:6QE*2![#0H@("`@)')E="`]("1F+3YP=70H)&9I;&4L(&)A<V5N86UE
M*"1F:6QE*2P@)&]V97)W<FET92D[#0H@("`@:68@*%!%05(Z.FES17)R;W(H
M)')E="DI('L-"B`@("`):68@*"@D<F5T+3YG971#;V1E*"D@/3T@3D547T94
M4%]%4E)?3U9%4E=2251%4D5-3U1%1DE,15]&3U)"241$14XI(&%N9"`H(21O
M=F5R=W)I=&4I*2![#0H@("`@"2`@("!P<FEN=&8H)R5S(#QB<B`O/B<L("1R
M970M/F=E=$UE<W-A9V4H*2D[#0H@("`@"2`@("!C;VYT:6YU93L@("\O(&ET
M(&ES(&IU<W0@82!W87)N:6YG('=H96X@7"1O=F5R=W)I=&4@=F%R:6%B;&4@
M:7,@<V5T('1O(&9A;'-E#0H@("`@"7T-"B`@("`@("`@9&EE*"1R970M/F=E
M=$UE<W-A9V4H*2D[#0H@("`@?0T*("`@('!R:6YT9B@G/&(^)7,\+V(^('1R
M86YS9F5R(&-O;7!L971E9"`\8G(@+SXG+"!B87-E;F%M92@D9FEL92DI.PT*
M?0T*)&8M/F1E=&%C:"@D;V)S97)V97(I.PT*#0HO+PT*+R\@."X@8VAE8VMS
M(&EF(&9I;&5S(&%R92!R96%L;'D@;VX@=&AE($944"!S97)V97(-"B\O#0HD
M<F5T(#T@)&8M/FQS*&YU;&PL($Y%5%]&5%!?4D%73$E35"D[#0II9B`H4$5!
M4CHZ:7-%<G)O<B@D<F5T*2D@>PT*("`@("1F+3YD:7-C;VYN96-T*"D[#0H@
M("`@9&EE*"1R970M/F=E=$UE<W-A9V4H*2D[#0I]#0IP<FEN="`G/'!R93XG
M.PT*=F%R7V1U;7`H)')E="D[#0IP<FEN="`G/"]P<F4^)SL-"@T*+R\-"B\O
M(#DN('-A>7,@9V]O9&)Y92!T;R!T:&4@1E10('-E<G9E<B`A#0HO+PT*)&8M
M/F1I<V-O;FYE8W0H*3L-"F5C:&\@)T1O;F4A)SL-"C\^#0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+TYE=%]&5%`O97AA;7!L92]E
M>'1E;G-I;VYS+FEN:0``````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,C$S(#$P-3$U
M-#,S-S,P(#`R-3(P,P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````[(%1H:7,@9FEL92!C86X@9&5T97)M:6YE(&9I;&4M97AT
M96YS:6]N(&%N9"!W971H97(@=&\@=')A;G-F97(@=&AE;2!I;B`*.R!B:6YA
M<GDM(&]R(&%S8VEI+6UO9&4N(%1H92!T=V\@9&EF9F5R96YT('9A;'5E<R!F
M;W(@9FEL92UM;V1E<R!A<F4Z"CL*.R!&5%!?05-#24D@*'=H:6-H(&5Q=6%L
M<R`P*0H[($944%]"24Y!4ED@*'=H:6-H(&5Q=6%L<R`Q*0H["CL@5&AI<R!F
M:6QE('=I;&P@8F4@9&ER96-T;'D@<&%R<V5D(&)Y('!A<G-E7VEN:5]F:6QE
M*"DL('-O(&)E=V%R92!O9B!M86MI;F<@;6ES=&%K97,*.R!I;G-I9&4@=&AI
M<R!F:6QE+"!O<B!Y;W5R(&%P<&QI8V%T:6]N(&UA>2!C<F%S:"P@979E<GET
M:6UE('EO=2!P87)S92!Y;W5R(&9I;&4N"CL*.R!9;W4@8V%N(&AA=F4@;6]R
M92!T:&%N(#$@9FEL92!C;VYT86EN:6YG(&5X=&5N<VEO;BUS971T:6YG<RP@
M9F]R(&1I9F9E<F5N="!K:6YD<R!O9@H[(&%P<&QI8V%T:6]N+"!S97)V97(@
M;W(@8V%S92X@0G5T(&)E=V%R92P@:68@>6]U)W9E('!A<G-E9"!A(&9I;&4@
M:6YT;R!Y;W5R($YE=%]&5%`M;V)J96-T+`H[(&%N9"!A9G1E<B!T:&%T('EO
M=2!P87)S92!A;F]T:&5R(&9I;&4L('1H92!O;&0@<V5T=&EN9W,@=VEL;"!B
M92!O=F5R=W)I=&5N(0H["CL@05-#24DM17AT96YS:6]N<SH*"EM!4T-)25T*
M"F%S8R`](#`*87-C>"`](#`*87-P(#T@,`IA<W!X(#T@,`IB87,@/2`P"F)A
M<V@@/2`P"F)A="`](#`*8R`](#`*8V9C(#T@,`IC9FT@/2`P"F-G:2`](#`*
M8VQA<W,@/2`P"F-O;F8@/2`P"F-S<R`](#`*:"`](#`*:&AC(#T@,`IH:&L@
M/2`P"FAP<"`](#`*:'1A(#T@,`IH=&T@/2`P"FAT;6P@/2`P"FEN8R`](#`*
M;F9O(#T@,`II;FD@/2`P"FEN9B`](#`*:F%V(#T@,`IJ879A(#T@,`IJ<R`]
M(#`*:G-P(#T@,`IL;V<@/2`P"FYF;R`](#`*<&%S(#T@,`IP:'`@/2`P"G!H
M<#,@/2`P"G!H<#0@/2`P"G!H=&UL(#T@,`IP;"`](#`*<W9G(#T@,`IS:"`]
M(#`*<VAT;6P@/2`P"G1C;"`](#`*=&5X="`](#`*='AT(#T@,`IV8B`](#`*
M=F)S(#T@,`IW;6P@/2`P"GAH=&T@/2`P"GAH=&UL(#T@,`IX;6P@/2`P"GAS
M9"`](#`*>'-L(#T@,`IX<VP@/2`P"GAS;'0@/2`P"GAU;"`](#`*"CL@0DE.
M05)9+45X=&5N<VEO;G,*"EM"24Y!4EE="@IJ<&<@/2`Q"F=I9B`](#$*8FUP
M(#T@,0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+V1A=&$`````````````````````````````````````````````````````
M````````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S`@,#$W,S$U`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O9&%T82]014%2````````````````````````
M```````````````````````````````````````````````````````````P
M,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<S
M,"`P,C`P-#0`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D871A+U!%05(O
M=&5M<&QA=&4N<W!E8P``````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`T,#,U(#$P-3$U-#,S-S,P(#`R,C8Q-``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!3=6UM87)Y.B!014%2.B!`<W5M;6%R
M>4`-"DYA;64Z($!R<&U?<&%C:V%G94`-"E9E<G-I;VXZ($!V97)S:6]N0`T*
M4F5L96%S93H@,0T*3&EC96YS93H@0')E;&5A<V5?;&EC96YS94`-"D=R;W5P
M.B!$979E;&]P;65N="],:6)R87)I97,-"E-O=7)C93H@:'1T<#HO+T!M87-T
M97)?<V5R=F5R0"]G970O0'!A8VMA9V5`+25[=F5R<VEO;GTN=&=Z#0I"=6EL
M9%)O;W0Z("5[7W1M<'!A=&A]+R5[;F%M97TM<F]O=`T*55),.B!H='1P.B\O
M0&UA<W1E<E]S97)V97)`+W!A8VMA9V4O0'!A8VMA9V5`#0I0<F5F:7@Z("5[
M7W!R969I>'T-"D)U:6QD07)C:&ET96-T=7)E<SH@0&%R8VA`#0I`97AT<F%?
M:&5A9&5R<T`-"@T*)61E<V-R:7!T:6]N#0I`9&5S8W)I<'1I;VY`#0H-"B5P
M<F5P#0IR;2`M<F8@)7MB=6EL9')O;W1]+RH-"B5S971U<"`M8R`M5`T*(R!8
M6%@@4V]U<F-E(&9I;&5S(&QO8V%T:6]N(&ES(&UI<W-I;F<@:&5R92!I;B!P
M96%R(&-M9`T*<&5A<B`M=B`M8R`E>V)U:6QD<F]O='TO<&5A<G)C(%P-"B`@
M("`@("`@+60@<&AP7V1I<CTE>U]L:6)D:7)]+W!H<"]P96%R(%P-"B`@("`@
M("`@+60@9&]C7V1I<CTO9&]C<R!<#0H@("`@("`@("UD(&)I;E]D:7(])7M?
M8FEN9&ER?2!<#0H@("`@("`@("UD(&1A=&%?9&ER/25[7VQI8F1I<GTO<&AP
M+W!E87(O9&%T82!<#0H@("`@("`@("UD('1E<W1?9&ER/25[7VQI8F1I<GTO
M<&AP+W!E87(O=&5S=',@7`T*("`@("`@("`M9"!E>'1?9&ER/25[7VQI8F1I
M<GT@7$!E>'1R85]C;VYF:6=`#0H@("`@("`@("US#0H-"B5B=6EL9`T*96-H
M;R!"=6EL9%)O;W0])7MB=6EL9')O;W1]#0H-"B5P;W-T=6X-"B,@:68@<F5F
M8V]U;G0@/2`P('1H96X@<&%C:V%G92!H87,@8F5E;B!R96UO=F5D("AN;W0@
M=7!G<F%D960I#0II9B!;("(D,2(@+65Q("(P(B!=.R!T:&5N#0H@("`@<&5A
M<B!U;FEN<W1A;&P@+2UN;V1E<',@+7(@0'!O<W-I8FQE7V-H86YN96Q`0'!A
M8VMA9V5`#0H@("`@<FT@0')P;5]X;6Q?9&ER0"]`<&%C:V%G94`N>&UL#0IF
M:0T*#0H-"B5P;W-T#0HC(&EF(')E9F-O=6YT(#T@,B!T:&5N('!A8VMA9V4@
M:&%S(&)E96X@=7!G<F%D960-"FEF(%L@(B0Q(B`M9V4@(C(B(%T[('1H96X-
M"B`@("!P96%R('5P9W)A9&4@+2UN;V1E<',@+7(@0')P;5]X;6Q?9&ER0"]`
M<&%C:V%G94`N>&UL#0IE;'-E#0H@("`@<&5A<B!I;G-T86QL("TM;F]D97!S
M("UR($!R<&U?>&UL7V1I<D`O0'!A8VMA9V5`+GAM;`T*9FD-"@T*)6EN<W1A
M;&P-"G!E87(@+6,@)7MB=6EL9')O;W1]+W!E87)R8R!I;G-T86QL("TM;F]D
M97!S("U2("5[8G5I;&1R;V]T?2!<#0H@("`@("`@("124$U?4T]54D-%7T1)
M4B]`<&%C:V%G94`M)7MV97)S:6]N?2YT9WH-"G)M("5[8G5I;&1R;V]T?2]P
M96%R<F,-"G)M("5[8G5I;&1R;V]T?2\E>U]L:6)D:7)]+W!H<"]P96%R+RYF
M:6QE;6%P#0IR;2`E>V)U:6QD<F]O='TO)7M?;&EB9&ER?2]P:'`O<&5A<B\N
M;&]C:PT*<FT@+7)F("5[8G5I;&1R;V]T?2\E>U]L:6)D:7)]+W!H<"]P96%R
M+RYR96=I<W1R>0T*:68@6R`B0&1O8U]F:6QE<T`B("$]("(B(%T[('1H96X-
M"B`@("`@;78@)7MB=6EL9')O;W1]+V1O8W,O0'!A8VMA9V5`+RH@+@T*("`@
M("!R;2`M<F8@)7MB=6EL9')O;W1]+V1O8W,-"F9I#0IM:V1I<B`M<"`E>V)U
M:6QD<F]O='U`<G!M7WAM;%]D:7)`#0IT87(@+7AZ9B`D4E!-7U-/55)#15]$
M25(O0'!A8VMA9V5`+25[=F5R<VEO;GTN=&=Z('!A8VMA9V5`<&%C:V%G93)X
M;6Q`+GAM;`T*8W`@+7`@<&%C:V%G94!P86-K86=E,GAM;$`N>&UL("5[8G5I
M;&1R;V]T?4!R<&U?>&UL7V1I<D`O0'!A8VMA9V5`+GAM;`T*#0HC<FT@+7)F
M("5[8G5I;&1R;V]T?2\J#0HC<&5A<B`M<2!I;G-T86QL("U2("5[8G5I;&1R
M;V]T?2`M;B!P86-K86=E0'!A8VMA9V4R>&UL0"YX;6P-"B-M:V1I<B`M<"`E
M>V)U:6QD<F]O='U`<G!M7WAM;%]D:7)`#0HC8W`@+7`@<&%C:V%G94!P86-K
M86=E,GAM;$`N>&UL("5[8G5I;&1R;V]T?4!R<&U?>&UL7V1I<D`O0'!A8VMA
M9V5`+GAM;`T*#0HE9FEL97,-"B`@("`E9&5F871T<B@M+')O;W0L<F]O="D-
M"B`@("`E9&]C($!D;V-?9FEL97-`#0H@("`@+PT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]D871A+U!%05(O<&%C:V%G92YD=&0`````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`V-C0V(#$P-3$U-#,S-S,P(#`R,C(R-P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\(2TM#0H@("`@
M("1)9#H@<&%C:V%G92YD=&0L=B`Q+C,X(#(P,#4O,3$O,3(@,#(Z,C,Z,#<@
M8V5L;&]G($5X<"`D#0H-"B`@("`@5&AI<R!I<R!T:&4@4$5!4B!P86-K86=E
M(&1E<V-R:7!T:6]N+"!V97)S:6]N(#$N,"X-"B`@("`@270@<VAO=6QD(&)E
M('5S960@=VET:"!T:&4@:6YF;W)M86P@<'5B;&EC(&ED96YT:69I97(Z#0H-
M"B`@("`@("`@("(M+R]02%`@1W)O=7`O+T141"!014%2(%!A8VMA9V4@,2XP
M+R]%3B\O6$U,(@T*#0H@("`@($-O<'ER:6=H="`H8RD@,3DY-RTR,#`U(%1H
M92!02%`@1W)O=7`@("`@("`@("`@("`@#0H-"B`@("`@5&AI<R!S;W5R8V4@
M9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP,"!O9B!T:&4@4$A0(&QI
M8V5N<V4L#0H@("`@('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G
M92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,-"B`@("`@879A:6QA8FQE
M(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T#0H@("`@(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N(`T*("`@("!)9B!Y;W4@
M9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD
M(&%R92!U;F%B;&4@=&\-"B`@("`@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O
M<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\-"B`@("`@;&EC
M96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I
M871E;'DN#0H-"B`@("`@075T:&]R<SH-"B`@("`@("`@(%-T:6<@4RX@0F%K
M:V5N(#QS<V)`9F%S="YN;SX-"B`@("`@("`@($=R96=O<GD@0F5A=F5R(#QC
M96QL;V=`<&AP+FYE=#X-"@T*("`M+3X-"CPA14Y42519("4@3E5-0D52(")#
M1$%402(^#0H\(45,14U%3E0@<&%C:V%G92`H;F%M92QS=6UM87)Y+&1E<V-R
M:7!T:6]N+&QI8V5N<V4_+&UA:6YT86EN97)S+')E;&5A<V4L8VAA;F=E;&]G
M/RD^#0H\(4%45$Q)4U0@<&%C:V%G92!T>7!E("`@("AS;W5R8V5\8FEN87)Y
M?&5M<'1Y*2`B96UP='DB#0H@("`@("`@("`@("`@("`@("!V97)S:6]N($-$
M051!("`@("`@("`@("`@("`@("`C4D5154E2140-"B`@("`@("`@("`@("`@
M("`@('!A8VMA9V5R=F5R<VEO;B!#1$%402`@("`@("`@("-)35!,245$/@T*
M#0H\(45,14U%3E0@;F%M92`H(U!#1$%402D^#0H-"CPA14Q%345.5"!S=6UM
M87)Y("@C4$-$051!*3X-"@T*/"%%3$5-14Y4(&QI8V5N<V4@*"-00T1!5$$I
M/@T*#0H\(45,14U%3E0@9&5S8W)I<'1I;VX@*"-00T1!5$$I/@T*#0H\(45,
M14U%3E0@;6%I;G1A:6YE<G,@*&UA:6YT86EN97(I*SX-"@T*/"%%3$5-14Y4
M(&UA:6YT86EN97(@*'5S97)\<F]L97QN86UE?&5M86EL*2L^#0H-"CPA14Q%
M345.5"!U<V5R("@C4$-$051!*3X-"@T*/"%%3$5-14Y4(')O;&4@*"-00T1!
M5$$I/@T*#0H\(45,14U%3E0@96UA:6P@*"-00T1!5$$I/@T*#0H\(45,14U%
M3E0@8VAA;F=E;&]G("AR96QE87-E*2L^#0H-"CPA14Q%345.5"!R96QE87-E
M("AV97)S:6]N+&1A=&4L;&EC96YS92QS=&%T92QN;W1E<RQW87)N:6YG<S\L
M<')O=FED97,J+&1E<',_+&-O;F9I9W5R96]P=&EO;G,_+&9I;&5L:7-T/RD^
M#0H-"CPA14Q%345.5"!V97)S:6]N("@C4$-$051!*3X-"@T*/"%%3$5-14Y4
M(&1A=&4@*"-00T1!5$$I/@T*#0H\(45,14U%3E0@<W1A=&4@*"-00T1!5$$I
M/@T*#0H\(45,14U%3E0@;F]T97,@*"-00T1!5$$I/@T*#0H\(45,14U%3E0@
M=V%R;FEN9W,@*"-00T1!5$$I/@T*#0H\(45,14U%3E0@9&5P<R`H9&5P*BD^
M#0H-"CPA14Q%345.5"!D97`@*"-00T1!5$$I/@T*/"%!5%1,25-4(&1E<"!T
M>7!E("`@("AP:V=\97AT?'!H<"D@(U)%455)4D5$#0H)("`@("`@("`@("`@
M("`@("`@("`@("!R96P@("`@("AH87-\97%\;'1\;&5\9W1\9V4I("`@("`@
M("`@("`@("`@("`@("`@("`@("`C24U03$E%1`T*"2`@("`@("`@("`@("`@
M("`@("`@("`@=F5R<VEO;B!#1$%402`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`C24U03$E%1`T*"2`@("`@("`@("`@("`@("`@("`@
M("`@;W!T:6]N86P@*'EE<WQN;RD@("`@("=N;R<^#0H-"CPA14Q%345.5"!C
M;VYF:6=U<F5O<'1I;VYS("AC;VYF:6=U<F5O<'1I;VXI*SX-"@T*/"%%3$5-
M14Y4(&-O;F9I9W5R96]P=&EO;B!%35!463X-"CPA05143$E35"!C;VYF:6=U
M<F5O<'1I;VX@;F%M92!#1$%402`C4D5154E2140-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!D969A=6QT($-$051!("-)
M35!,245$#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<')O;7!T($-$051!("-215%525)%1#X-"@T*/"%%3$5-14Y4('!R
M;W9I9&5S($5-4%19/@T*/"%!5%1,25-4('!R;W9I9&5S('1Y<&4@*&5X='QP
M<F]G?&-L87-S?&9U;F-T:6]N?&9E871U<F5\87!I*2`C4D5154E2140-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;F%M92!#1$%402`C4D51
M54E2140-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@97AT96YD
M<R!#1$%402`C24U03$E%1#X-"CPA14Q%345.5"!F:6QE;&ES="`H9&ER?&9I
M;&4I*SX-"@T*/"%%3$5-14Y4(&1I<B`H9&ER?&9I;&4I*SX-"CPA05143$E3
M5"!D:7(@;F%M92`@("`@("`@("`@0T1!5$$@(U)%455)4D5$#0H@("`@("`@
M("`@("`@(')O;&4@("`@("`@("`@("AP:'!\97AT?'-R8WQT97-T?&1O8WQD
M871A?'-C<FEP="D@)W!H<"<-"B`@("`@("`@("`@("`@8F%S96EN<W1A;&QD
M:7(@0T1!5$$@(TE-4$Q)140^#0H-"CPA14Q%345.5"!F:6QE("AR97!L86-E
M*BD^#0H\(4%45$Q)4U0@9FEL92!R;VQE("`@("`@("`@("`H<&AP?&5X='QS
M<F-\=&5S='QD;V-\9&%T87QS8W)I<'0I("=P:'`G#0H@("`@("`@("`@("`@
M("!D96)U9R`@("`@("`@("`H;F%\;VY\;V9F*2`@("`@("`@)VYA)PT*("`@
M("`@("`@("`@("`@9F]R;6%T("`@("`@("`@0T1!5$$@("`@("`@("`@("`@
M("-)35!,245$#0H@("`@("`@("`@("`@("!B87-E:6YS=&%L;&1I<B!#1$%4
M02`@("`@("`@("`@("`@(TE-4$Q)140-"B`@("`@("`@("`@("`@('!L871F
M;W)M("`@("`@($-$051!("`@("`@("`@("`@("`C24U03$E%1`T*("`@("`@
M("`@("`@("`@;60U<W5M("`@("`@("`@0T1!5$$@("`@("`@("`@("`@("-)
M35!,245$#0H@("`@("`@("`@("`@("!N86UE("`@("`@("`@("!#1$%402`@
M("`@("`@("`@("`@(U)%455)4D5$#0H@("`@("`@("`@("`@("!I;G-T86QL
M+6%S("`@("!#1$%402`@("`@("`@("`@("`@(TE-4$Q)140^#0H-"CPA14Q%
M345.5"!R97!L86-E($5-4%19/@T*/"%!5%1,25-4(')E<&QA8V4@='EP92`H
M<&AP+6-O;G-T?'!E87(M8V]N9FEG?'!A8VMA9V4M:6YF;RD@(U)%455)4D5$
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F<F]M($-$051!("-2
M15%525)%1`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&\@0T1!
M5$$@(U)%455)4D5$/@T*#0H-"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O9&%T82]-86EL7TUI;64`````````````````````````````````````
M```````````````````````````````````````P,#`W-34@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<S,"`P,C$Q-#8`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]D871A+TUA:6Q?36EM92]X;6%I;"YX<VP`
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`T,3(W(#$P-3$U-#,S
M-S,P(#`R,S`W,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/WAM;"!V97)S:6]N/2(Q+C`B(&5N8V]D:6YG/2))4T\M.#@U
M.2TQ(C\^#0H\>'-L.G-T>6QE<VAE970@=F5R<VEO;CTB,2XP(B!X;6QN<SIX
M<VP](FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3DO6%-,+U1R86YS9F]R;2(@>&UL
M;G,Z9F\](FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3DO6%-,+T9O<FUA="(^#0H\
M>'-L.F]U='!U="!M971H;V0](G1E>'0B(&]M:70M>&UL+61E8VQA<F%T:6]N
M/2)Y97,B(&EN9&5N=#TB;F\B+SX-"CQX<VPZ<')E<V5R=F4M<W!A8V4@96QE
M;65N=',](FAE861E<G9A;'5E('!A<F%M=F%L=64@8F]D>2(O/@T*#0H)/'AS
M;#IT96UP;&%T92!N86UE/2)M:6UE<&%R="(^#0H-"@D)/'AS;#IV87)I86)L
M92!N86UE/2)B;W5N9&%R>2(^#0H)"0D)/'AS;#IF;W(M96%C:"!S96QE8W0]
M(BXO:&5A9&5R(CX-"@D)"0D)/'AS;#II9B!T97-T/2)S=')I;F<H+B]H96%D
M97)N86UE*2`]("=#;VYT96YT+51Y<&4G(CX-"@D)"0D)"3QX<VPZ9F]R+65A
M8V@@<V5L96-T/2(N+W!A<F%M971E<B(^#0H)"0D)"0D)/'AS;#II9B!T97-T
M/2)S=')I;F<H+B]P87)A;6YA;64I(#T@)V)O=6YD87)Y)R(^#0H)"0D)"0D)
M"3QX<VPZ=F%L=64M;V8@<V5L96-T/2)P87)A;79A;'5E(B\^#0H)"0D)"0D)
M/"]X<VPZ:68^#0H)"0D)"0D\+WAS;#IF;W(M96%C:#X-"@D)"0D)/"]X<VPZ
M:68^#0H)"0D)/"]X<VPZ9F]R+65A8V@^#0H)"3PO>'-L.G9A<FEA8FQE/@T*
M#0H)"3QX<VPZ9F]R+65A8V@@<V5L96-T/2)H96%D97(B/@T*#0H)"0D\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB:&5A9&5R;F%M92(O/@T*"0D)/'AS;#IT97AT
M/CH@/"]X<VPZ=&5X=#X-"@D)"3QX<VPZ=F%L=64M;V8@<V5L96-T/2)H96%D
M97)V86QU92(O/@T*#0H)"0D\>'-L.FEF('1E<W0](F-O=6YT*"XO<&%R86UE
M=&5R*2`](#`B/@T*"0D)"3QX<VPZ=&5X=#XF(S$S.R8C,3`[/"]X<VPZ=&5X
M=#X-"@D)"3PO>'-L.FEF/@T*#0H)"0D\>'-L.F9O<BUE86-H('-E;&5C=#TB
M<&%R86UE=&5R(CX-"@D)"0D\>'-L.G1E>'0^.R8C,3,[)B,Q,#LF(S`Y.SPO
M>'-L.G1E>'0^#0H)"0D)/'AS;#IV86QU92UO9B!S96QE8W0](G!A<F%M;F%M
M92(O/@T*"0D)"3QX<VPZ=&5X=#X](CPO>'-L.G1E>'0^#0H)"0D)/'AS;#IV
M86QU92UO9B!S96QE8W0](G!A<F%M=F%L=64B+SX-"@D)"0D\>'-L.G1E>'0^
M(CPO>'-L.G1E>'0^#0H)"0D\+WAS;#IF;W(M96%C:#X-"@T*"0D)/'AS;#II
M9B!T97-T/2)C;W5N="@N+W!A<F%M971E<BD@/B`P(CX-"@D)"0D\>'-L.G1E
M>'0^)B,Q,SLF(S$P.SPO>'-L.G1E>'0^#0H)"0D\+WAS;#II9CX-"@T*"0D\
M+WAS;#IF;W(M96%C:#X-"@T*"0D\>'-L.G1E>'0^)B,Q,SLF(S$P.SPO>'-L
M.G1E>'0^#0H-"@D)/"$M+2!7:&EC:"!T;R!D;RP@<')I;G0@82!B;V1Y(&]R
M('!R;V-E<W,@<W5B<&%R=',_("TM/@T*"0D\>'-L.F-H;V]S93X-"@D)"3QX
M<VPZ=VAE;B!T97-T/2)C;W5N="@N+VUI;65P87)T*2`](#`B/@T*"0D)"3QX
M<VPZ=F%L=64M;V8@<V5L96-T/2)B;V1Y(B\^#0H)"0D)/'AS;#IT97AT/B8C
M,3,[)B,Q,#L\+WAS;#IT97AT/@T*"0D)/"]X<VPZ=VAE;CX-"@T*"0D)/'AS
M;#IO=&AE<G=I<V4^#0H)"0D)/'AS;#IF;W(M96%C:"!S96QE8W0](FUI;65P
M87)T(CX-"@D)"0D)/'AS;#IT97AT/BTM/"]X<VPZ=&5X=#X\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB)&)O=6YD87)Y(B\^/'AS;#IT97AT/B8C,3,[)B,Q,#L\
M+WAS;#IT97AT/@T*"0D)"0D\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB;6EM
M97!A<G0B+SX-"@D)"0D\+WAS;#IF;W(M96%C:#X-"@T*"0D)"3QX<VPZ=&5X
M=#XM+3PO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](B1B;W5N9&%R
M>2(O/CQX<VPZ=&5X=#XM+28C,3,[)B,Q,#L\+WAS;#IT97AT/@T*#0H)"0D\
M+WAS;#IO=&AE<G=I<V4^#0H)"3PO>'-L.F-H;V]S93X-"@D\+WAS;#IT96UP
M;&%T93X-"@T*/"$M+2!4:&ES(&ES('=H97)E('1H92!S='EL97-H965T(')E
M86QL>2!S=&%R=',L(&UA=&-H:6YG('1H92!T;W`@;&5V96P@96UA:6P@96QE
M;65N="`M+3X-"@D\>'-L.G1E;7!L871E(&UA=&-H/2)E;6%I;"(^#0H)"3QX
M<VPZ8V%L;"UT96UP;&%T92!N86UE/2)M:6UE<&%R="(O/@T*"3PO>'-L.G1E
M;7!L871E/@T*#0H\+WAS;#IS='EL97-H965T/@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D871A+TUA:6Q?36EM
M92]X;6%I;"YD=&0`````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q
M,#8V(#$P-3$U-#,S-S,P(#`R,S`S-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/WAM;"!V97)S:6]N/2(Q+C`B(&5N8V]D
M:6YG/2))4T\M.#@U.2TQ(C\^#0H-"CPA14Y42519(&QT("(F(S,X.R,V,#LB
M/@T*/"%%3E1)5%D@9W0@(B8C-C([(CX-"CPA14Y42519(&%M<"`B)B,S.#LC
M,S@[(CX-"CPA14Y42519(&%P;W,@(B8C,SD[(CX-"CPA14Y42519('%U;W0@
M(B8C,S0[(CX-"CPA14Y42519(&-R;&8@(B8C,3,[)B,Q,#LB/@T*#0H\(45,
M14U%3E0@96UA:6P@*&AE861E<BLL("AB;V1Y('P@;6EM97!A<G0K*2D^#0H\
M(45,14U%3E0@;6EM97!A<G0@*&AE861E<BLL("AB;V1Y('P@;6EM97!A<G0K
M*2D^#0H\(45,14U%3E0@8F]D>2`H(U!#1$%402D^#0H\(45,14U%3E0@:&5A
M9&5R("@H:&5A9&5R;F%M97QH96%D97)V86QU97QP87)A;65T97(I*BD^#0H\
M(45,14U%3E0@:&5A9&5R;F%M92`H(U!#1$%402D^#0H\(45,14U%3E0@:&5A
M9&5R=F%L=64@*"-00T1!5$$I/@T*/"%%3$5-14Y4('!A<F%M971E<B`H*'!A
M<F%M;F%M97QP87)A;79A;'5E*2LI/@T*/"%%3$5-14Y4('!A<F%M=F%L=64@
M*"-00T1!5$$I/@T*/"%%3$5-14Y4('!A<F%M;F%M92`H(U!#1$%402D^#0H-
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D871A+TQO
M9P``````````````````````````````````````````````````````````
M`````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,#`P(#$P-3$U-#,S-S,P(#`R,#`S-@`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+V1A=&$O3&]G+VUI<V,`````````````````````````````
M````````````````````````````````````````````````,#`P-S4U(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S`@,#(P-S<Q
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&%T82],;V<O;6ES8R]L;V<N
M<W%L````````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#0P-R`Q
M,#4Q-30S,S<S,"`P,C(S-3,`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+2T@)$ED.B!L;V<N<W%L+'8@,2XQ(#(P,#0O,#,O
M,3D@,#@Z,#`Z,3`@:F]N($5X<"`D"@I#4D5!5$4@5$%"3$4@;&]G7W1A8FQE
M("@*("`@(&ED("`@("`@("`@($E.5"!.3U0@3E5,3"P*("`@(&QO9W1I;64@
M("`@(%1)34535$%-4"!.3U0@3E5,3"P*("`@(&ED96YT("`@("`@($-(05(H
M,38I($Y/5"!.54Q,+`H@("`@<')I;W)I='D@("`@24Y4($Y/5"!.54Q,+`H@
M("`@;65S<V%G92`@("`@5D%20TA!4B@R,#`I+`H@("`@4%))34%262!+15D@
M*&ED*0HI.PH`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+V1A=&$O4V5R=FEC97-?5V5A=&AE<@``````````
M````````````````````````````````````````````````````````,#`P
M-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S`@
M,#(R-34W`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&%T82]397)V:6-E
M<U]796%T:&5R+VEM86=E<P``````````````````````````````````````
M```````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,#`P,"`Q,#4Q-30S,S<S,"`P,C0P,C0`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]D871A+U-E<G9I8V5S7U=E871H97(O:6UA9V5S+W-U;G-E="YG:68`
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`P-#,T(#$P-3$U-#,S-S,P(#`R-C$Q-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!'248X.6$>
M``\`Q```_NWJ^589_V%'_WHD_X-N_SP;;C@@_<W%_K2GU;2IBV-+Q3P,NJ*8
MJ8M^_):"TI*"_YDS____````````````````````````````````````````
M````````````````(?D$```````L`````!X`#P``!9E@)(YD:9YHJJZF(YC(
MRYY'(2*'*"#L09`Y0"$GR"$*`!8@($A&=D_',QF0SI;(2"R2>``>VBQT!1`T
M(X^&PL!6-!(1PCD"X*7D"<.B$.@'%@8,5@`$!3(E"`1)#09]`X^/?09P1P56
M)CX$>0&0$)X0D0H/!8HP!TX`"IR?K*`#"PTC3B,"!88$#@H#K:T#`0H'+H<S
MQ,7&(B$`.P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&%T82]3
M97)V:6-E<U]796%T:&5R+VEM86=E<R]S=6YR:7-E+F=I9@``````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#0T,2`Q,#4Q-30S,S<S,"`P,C8R-C$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````1TE&.#EA'``-`,0``.RPG?V/
M=5Q4)/_Y^/##"O]9-/]S3__T*/S&M_WCVO_A%I^2@/\Z%I!^0?_NZ[Z0>?__
M,____P``````````````````````````````````````````````````````
M`"'Y!```````+``````<``T```6>8"2.9&F>Z!@4)E`,:027".-$`2(70(P8
MLX'.P=`5=`!&(N8H%)817L00B#H&C.I@=FHJ([\(X.%XB&U17<IA>$8>BX9@
M+FB8V[=(0FU:`00$!`J#!'(+`3!L#`8E``9+"X"#!P>#"@0"/0$,#`!<(@D!
M`7^"E`<0E(0"#UEY(@`(5S(-#9,0M[>5F`TB`ZYM3J("MKBYJ@@K0#'+*"$`
M.P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1A=&$O4V5R=FEC97-?5V5A
M=&AE<B]B=6EL9$UE=&%R1$(N<&AP````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,S<T-S(@
M,3`U,34T,S,W,S`@,#(U-C8R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````",A+W5S<B]L;V-A;"]B:6XO<&AP"CP_<&AP"B\J
M('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O
M9G1T86)S=&]P/30@9F]L9&UE=&AO9#UM87)K97(Z("HO"@HO*BH*("H@5&AI
M<R!S8W)I<'0@9&]W;FQO861S+"!S879E<R!A;F0@<')O8V5S<V5S('1H92!T
M97AT9FEL97,@;F5E9&5D(&9O<@H@*B!T:&4@8G5I;&1I;F<@=&AE(&1A=&%B
M87-E<R!T;R!E;F%B;&4@<V5A<F-H:6YG(&9O<B!-151!4B!S=&%T:6]N<RX*
M("H*("H@66]U(&-A;B!D;W=N;&]A9"!T:&4@;&]C871I;VYS+"!W:&EC:"!I
M<R!A(&1A=&%B87-E(&]F(&%B;W5T(#$R,#`P('=O<FQD+0H@*B!W:61E(&QO
M8V%T:6]N<RP@=VAI8V@@8V%N(&)E('5S960@=&\@9&5T97)M:6YE('1H92!C
M;V]R9&EN871E<R!O9B!Y;W5R"B`J(&-I='D@;W(@>6]U(&-A;B!D;W=N;&]A
M9"!A(&9I;&4@=VET:"`V-3`P(&%I<G!O<G1S('!R;W9I9&EN9R!T:&4@;65T
M87(*("H@9&%T82X@5&AI<R!D871A8F%S92!I<R!U<V5D(&9O<B!T:&4@;F5X
M="U-151!4BUS=&%T:6]N('-E87)C:"X@4&QE87-E('-E90H@*B!T:&4@87!R
M;W!R:6%T92!D;V-U;65N=&%T:6]N(&EN('1H92!397)V:6-E<U]796%T:&5R
M7TUE=&%R(&-L87-S+@H@*@H@*B!&;W(@=7-A9V4@;V8@=&AI<R!S8W)I<'0L
M(&EN=F]K92!W:71H("<M:"<N"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U
M"B`J"B`J(#Q,24-%3E-%/@H@*B!#;W!Y<FEG:'0@*&,I(#(P,#4L($%L97AA
M;F1E<B!7:7)T>@H@*B!!;&P@<FEG:'1S(')E<V5R=F5D+@H@*@H@*B!2961I
M<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS
M+"!W:71H(&]R('=I=&AO=70*("H@;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET
M=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS"B`J
M(&%R92!M970Z"B`J(&\@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C;V1E
M(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0@;F]T:6-E+`H@*B`@
M('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I
M<V-L86EM97(N"B`J(&\@4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M
M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0@;F]T:6-E+`H@
M*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG
M(&1I<V-L86EM97(@:6X@=&AE(&1O8W5M96YT871I;VX*("H@("!A;F0O;W(@
M;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE(&1I<W1R:6)U=&EO
M;BX*("H@;R!.96ET:&5R('1H92!N86UE(&]F('1H92!S;V9T=V%R92!N;W(@
M=&AE(&YA;65S(&]F(&ET<R!C;VYT<FEB=71O<G,*("H@("!M87D@8F4@=7-E
M9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O9'5C=',@9&5R:79E9"!F<F]M
M('1H:7,@<V]F='=A<F4*("H@("!W:71H;W5T('-P96-I9FEC('!R:6]R('=R
M:71T96X@<&5R;6ES<VEO;BX*("H*("H@5$A)4R!33T945T%212!)4R!04D]6
M241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@04Y$($-/3E1224)55$]2
M4R`B05,@25,B"B`J($%.1"!!3ED@15A04D534R!/4B!)35!,245$(%=!4E)!
M3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5"!,24U)5$5$(%1/+"!42$4*("H@
M24U03$E%1"!705)204Y42453($]&($U%4D-(04Y404))3$E462!!3D0@1DE4
M3D534R!&3U(@02!005)424-53$%2(%!54E!/4T4*("H@05)%($1)4T-,04E-
M140N($E.($Y/($5614Y4(%-(04Q,(%1(12!#3U!94DE'2%0@3U=.15(@3U(@
M0T].5%))0E543U)3($)%"B`J($Q)04),12!&3U(@04Y9($1)4D5#5"P@24Y$
M25)%0U0L($E.0TE$14Y404PL(%-014-)04PL($5814U03$%262P@3U(*("H@
M0T].4T51545.5$E!3"!$04U!1T53("A)3D-,541)3D<L($)55"!.3U0@3$E-
M251%1"!43RP@4%)/0U5214U%3E0@3T8*("H@4U5"4U1)5%5412!'3T]$4R!/
M4B!315)624-%4SL@3$]34R!/1B!54T4L($1!5$$L($]2(%!23T9)5%,[($]2
M($)54TE.15-3"B`J($E.5$524E505$E/3BD@2$]7159%4B!#0553140@04Y$
M($].($%.62!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52($E."B`J($-/
M3E1204-4+"!35%))0U0@3$E!0DE,2519+"!/4B!43U)4("A)3D-,541)3D<@
M3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I"B`J($%225-)3D<@24X@04Y9(%=!
M62!/550@3T8@5$A%(%5312!/1B!42$E3(%-/1E1705)%+"!%5D5.($E&($%$
M5DE3140@3T8@5$A%"B`J(%!/4U-)0DE,2519($]&(%-50T@@1$%-04=%+@H@
M*B`\+TQ)0T5.4T4^"B`J"B`J($!C871E9V]R>2`@("!796(@4V5R=FEC97,*
M("H@0'!A8VMA9V4@("`@(%-E<G9I8V5S7U=E871H97(*("H@0'-U8G!A8VMA
M9V4@(&)U:6QD365T87)$0@H@*B!`875T:&]R("`@("`@06QE>&%N9&5R(%=I
M<G1Z(#QA;&5X0'!C-'`N;F5T/@H@*B!`8V]P>7)I9VAT("`@,C`P-2!!;&5X
M86YD97(@5VER='H*("H@0&QI8V5N<V4@("`@(&AT='`Z+R]W=W<N;W!E;G-O
M=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS
M90H@*B!`=F5R<VEO;B`@("`@0U93.B`D260Z(&)U:6QD365T87)$0BYP:'`L
M=B`Q+C(S(#(P,#4O,3$O,3,@,C$Z-38Z,34@97)U($5X<"`D"B`J($!L:6YK
M("`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4V5R=FEC97-?
M5V5A=&AE<@H@*B!`;&EN:R`@("`@("`@:'1T<#HO+W=E871H97(N;F]A82YG
M;W8O=&<O<VET92YS:'1M;`H@*B!`9FEL97-O=7)C90H@*B\*"G)E<75I<F5?
M;VYC92`B1$(N<&AP(CL*"B\O('M[>R!C;VYS=&%N=',*+R\@>WM[(&YA='5R
M86P@8V]N<W1A;G1S(&%N9"!M96%S=7)E<PID969I;F4H(E-%4E9)0T537U=%
M051(15)?4D%$25537T5!4E1((BP@-C,W."XQ-2D["B\O('U]?0HO+R!]?7T*
M"B\O('M[>R!397)V:6-E<U]796%T:&5R7V-H96-K1&%T82@I"B\J*@H@*B!3
M97)V:6-E<U]796%T:&5R7V-H96-K1&%T80H@*@H@*B!#:&5C:W,@=&AE(&1A
M=&$@9F]R(&$@8V5R=&%I;B!S=')I;F<M;&5N9W1H(&%N9"!I9B!I="!E:71H
M97(@8V]N<VES=',@;V8*("H@82!C97)T86EN(&-H87(M='EP92!O<B!A('-T
M<FEN9R!O9B`B+2(@87,@<F5P;&%C96UE;G0N"B`J"B`J($!P87)A;2`@(&%R
M<F%Y("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&$@("`@("`@("`@
M(%1H92!D871A('1O(&)E(&-H96-K960*("H@0'!A<F%M("`@87)R87D@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9&%T84]R9&5R("`@("`@0F5C875S
M92!T:&4@9&%T82!I<R!I;B!D:69F97)E;G0@;&]C871I;VYS+"!W92!P<F]V
M:61E('1H:7,*("H@0')E='5R;B`@8F]O;`H@*B\*9G5N8W1I;VX@4V5R=FEC
M97-?5V5A=&AE<E]C:&5C:T1A=&$H)&1A=&$L("1D871A3W)D97(I"GL*("`@
M("1R971U<FX@/2!T<G5E.PH@("`@9F]R96%C:"`H)&1A=&%/<F1E<B!A<R`D
M='EP92`]/B`D:61X*2!["B`@("`@("`@<W=I=&-H("AS=')T;VQO=V5R*"1T
M>7!E*2D@>PH@("`@("`@("`@("!C87-E(")B(CH*("`@("`@("`@("`@("`@
M("1L96X@(#T@,CL*("`@("`@("`@("`@("`@("1F=6YC(#T@(F-T>7!E7V1I
M9VET(CL*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E
M(")S(CH*("`@("`@("`@("`@("`@("1L96X@(#T@,SL*("`@("`@("`@("`@
M("`@("1F=6YC(#T@(F-T>7!E7V1I9VET(CL*("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("!C87-E(")I(CH*("`@("`@("`@("`@("`@("1L
M96X@(#T@-#L*("`@("`@("`@("`@("`@("1F=6YC(#T@(F-T>7!E7V%L;G5M
M(CL*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!D969A=6QT
M.@H@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H@("`@("`@(&EF
M("@H<W1R;&5N*"1D871A6R1I9'A=*2`A/2`D;&5N*2!\?"`H(21F=6YC*"1D
M871A6R1I9'A=*2`F)B`H)&1A=&%;)&ED>%T@(3T@<W1R7W)E<&5A="@B+2(L
M("1L96XI*2DI('L*("`@("`@("`@("`@)')E='5R;B`](&9A;'-E.PH@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@("!]"B`@("!R971U<FX@)')E
M='5R;CL*?0HO+R!]?7T*"B\O('M[>R!397)V:6-E<U]796%T:&5R7V=E=$YE
M>'1!<F<H*0HO*BH*("H@4V5R=FEC97-?5V5A=&AE<E]G971.97AT07)G"B`J
M"B`J($-H96-K<RP@:68@=&AE(&YE>'0@87)G=6UE;G0@:7,@82!P87)A;65T
M97(@=&\@82!P<F5D96-E<W-I;F<@;W!T:6]N+@H@*B!2971U<FYS(&5I=&AE
M<B!T:&%T('!A<F%M971E<B!O<B!F86QS92P@:68@=&AE(&YE>'0@87)G=6UE
M;G0@:7,@86X@;W!T:6]N"B`J"B`J($!P87)A;2`@(&EN="`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&,@("`@("`@("`@("`@($EN=&5R;F%L(&%R
M9W5M96YT(&-O=6YT97(*("H@0')E='5R;B`@<W1R:6YG?&)O;VP*("HO"F9U
M;F-T:6]N(%-E<G9I8V5S7U=E871H97)?9V5T3F5X=$%R9R@F)&,I"GL*("`@
M(&EF("@H*"1C("L@,2D@/"`D7U-%4E9%4ELB87)G8R)=*2`F)B`H)%]315)6
M15);(F%R9W8B75LD8R`K(#%=>S!]("$]("(M(BDI('L*("`@("`@("`D8RLK
M.PH@("`@("`@(')E='5R;B`D7U-%4E9%4ELB87)G=B)=6R1C73L*("`@('T@
M96QS92!["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0I]"B\O('U]?0H*
M+R\@1FER<W0@<V5T(&$@9F5W('9A<FEA8FQE<R!F;W(@<')O8V5S<VEN9R!T
M:&4@;W!T:6]N<PHD;6]D95-E="`@(#T@9F%L<V4["B1S879E1FEL92`@/2!F
M86QS93L*)'!R:6YT2&5L<"`](&9A;'-E.PHD:6YV3W!T("`@(#T@9F%L<V4[
M"B1V97)B;W-E("`@/2`P.PHD9&)4>7!E("`@(#T@(FUY<W%L(CL*)&1B4')O
M="`@("`](")U;FEX(CL*)&1B3F%M92`@("`](")S97)V:6-E<U=E871H97)$
M0B(["B1D8E5S97(@("`@/2`B<F]O="(["B1D8E!A<W,@("`@/2`B(CL*)&1B
M2&]S="`@("`](")L;V-A;&AO<W0B.PHD9&)/<'1I;VYS(#T@87)R87DH*3L*
M)'5S97)&:6QE("`]("(B.PH*+R\@271E<F%T92!T:')O=6=H('1H92!A<F=U
M;65N=',@86YD(&-H96-K('1H96ER('9A;&ED:71Y"F9O<B`H)&,@/2`Q.R`D
M8R`\("1?4T525D526R)A<F=C(ET[("1C*RLI('L*("`@('-W:71C:"`H)%]3
M15)615);(F%R9W8B75LD8UU[,7TI('L*("`@("`@("!C87-E(")L(CH*("`@
M("`@("`@("`@+R\@;&]C871I;VXM;6]D92P@:68@86YO=&AE<B!M;V1E(&ES
M('-E="P@8F%I;"!O=70*("`@("`@("`@("`@:68@*"1M;V1E4V5T*2!["B`@
M("`@("`@("`@("`@("`D<')I;G1(96QP(#T@=')U93L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1M;V1E4V5T("`@/2!T<G5E.PH@
M("`@("`@("`@("`@("`@)&9I;&5087)T("`](")B8G-S<R(["B`@("`@("`@
M("`@("`@("`D=&%B;&5.86UE(#T@(FUE=&%R3&]C871I;VYS(CL*("`@("`@
M("`@("`@("`@("1D871A3W)D97(@/2!A<G)A>2@B8B(@/3X@,"P@(G,B(#T^
M(#$L(")I(B`]/B`R*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("!C87-E(")A(CH*("`@("`@("`@("`@+R\@9&ET;R!F;W(@
M86ER<&]R="UM;V1E"B`@("`@("`@("`@(&EF("@D;6]D95-E="D@>PH@("`@
M("`@("`@("`@("`@)'!R:6YT2&5L<"`]('1R=64["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D;6]D95-E="`@(#T@=')U93L*("`@
M("`@("`@("`@("`@("1F:6QE4&%R="`@/2`B8V-C8R(["B`@("`@("`@("`@
M("`@("`D=&%B;&5.86UE(#T@(FUE=&%R06ER<&]R=',B.PH@("`@("`@("`@
M("`@("`@)&1A=&%/<F1E<B`](&%R<F%Y*")B(B`]/B`Q+"`B<R(@/3X@,BP@
M(FDB(#T^(#`I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@(&-A<V4@(F8B.@H@("`@("`@("`@("`O+R!F:6QE+69L86<@=V%S
M('!R;W9I9&5D+"!C:&5C:R!I9B!N97AT(&%R9W5M96YT(&ES(&$@<W1R:6YG
M"B`@("`@("`@("`@(&EF("@H)'5S97)&:6QE(#T@4V5R=FEC97-?5V5A=&AE
M<E]G971.97AT07)G*"1C*2D@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@
M("`D<')I;G1(96QP(#T@=')U93L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("!C87-E(")S(CH*("`@("`@("`@("`@+R\@268@
M>6]U(&1O=VYL;V%D('1H92!F:6QE+"!I="!W:6QL(&)E('-A=F5D('1O(&1I
M<VL*("`@("`@("`@("`@)'-A=F5&:6QE("`@("`@/2!T<G5E.PH@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("!C87-E(")T(CH*("`@("`@("`@("`@+R\@
M5&AE('1Y<&4@;V8@=&AE($1"('1O(&)E('5S960*("`@("`@("`@("`@:68@
M*"@D9&)4>7!E(#T@4V5R=FEC97-?5V5A=&AE<E]G971.97AT07)G*"1C*2D@
M/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D<')I;G1(96QP(#T@=')U
M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!C
M87-E(")R(CH*("`@("`@("`@("`@+R\@5&AE('!R;W1O8V]L(&]F('1H92!$
M0B!T;R!B92!U<V5D"B`@("`@("`@("`@(&EF("@H)&1B4')O="`](%-E<G9I
M8V5S7U=E871H97)?9V5T3F5X=$%R9R@D8RDI(#T]/2!F86QS92D@>PH@("`@
M("`@("`@("`@("`@)'!R:6YT2&5L<"`]('1R=64["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@8V%S92`B9"(Z"B`@("`@("`@
M("`@("\O(%1H92!N86UE(&]F('1H92!$0B!T;R!B92!U<V5D"B`@("`@("`@
M("`@(&EF("@H)&1B3F%M92`](%-E<G9I8V5S7U=E871H97)?9V5T3F5X=$%R
M9R@D8RDI(#T]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@)'!R:6YT2&5L
M<"`]('1R=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@8V%S92`B=2(Z"B`@("`@("`@("`@("\O(%1H92!U<V5R(&]F('1H
M92!$0B!T;R!B92!U<V5D"B`@("`@("`@("`@(&EF("@H)&1B57-E<B`](%-E
M<G9I8V5S7U=E871H97)?9V5T3F5X=$%R9R@D8RDI(#T]/2!F86QS92D@>PH@
M("`@("`@("`@("`@("`@)'!R:6YT2&5L<"`]('1R=64["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@8G)E86L["B`@("`@("`@8V%S92`B<"(Z"B`@("`@
M("`@("`@("\O(%1H92!P87-S=V]R9"!O9B!T:&4@1$(@=&\@8F4@=7-E9`H@
M("`@("`@("`@("!I9B`H*"1D8E!A<W,@/2!397)V:6-E<U]796%T:&5R7V=E
M=$YE>'1!<F<H)&,I*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1P
M<FEN=$AE;'`@/2!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@(&-A<V4@(F@B.@H@("`@("`@("`@("`O+R!4:&4@:&]S
M="!O9B!T:&4@1$(@=&\@8F4@=7-E9`H@("`@("`@("`@("!I9B`H*"1D8DAO
M<W0@/2!397)V:6-E<U]796%T:&5R7V=E=$YE>'1!<F<H)&,I*2`]/3T@9F%L
M<V4I('L*("`@("`@("`@("`@("`@("1P<FEN=$AE;'`@/2!T<G5E.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@(&-A<V4@(F\B
M.@H@("`@("`@("`@("`O+R!/<'1I;VYS(&9O<B!T:&4@1$(*("`@("`@("`@
M("`@:68@*"@D;W!T:6]N<R`](%-E<G9I8V5S7U=E871H97)?9V5T3F5X=$%R
M9R@D8RDI(#T]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@)'!R:6YT2&5L
M<"`]('1R=64["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D;W!T:6]N<R`@(#T@97AP;&]D92@B+"(L("1O<'1I;VYS*3L*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1O<'1I;VYS(&%S("1O<'1I;VXI('L*("`@
M("`@("`@("`@("`@("`@("`D;W!T4&%I<B`](&5X<&QO9&4H(CTB+"`D;W!T
M:6]N*3L*("`@("`@("`@("`@("`@("`@("`D9&)/<'1I;VYS6R1O<'1086ER
M6S!=72`]("1O<'1086ER6S%=.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@(&-A<V4@(G8B.@H@
M("`@("`@("`@("`O+R!I;F-R96%S92!V97)B;W-I='D*("`@("`@("`@("`@
M9F]R("@D:2`](#$[("1I(#P@<W1R;&5N*"1?4T525D526R)A<F=V(EU;)&-=
M*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@:68@*"1?4T525D526R)A<F=V
M(EU;)&-=>R1I?2`]/2`B=B(I('L*("`@("`@("`@("`@("`@("`@("`D=F5R
M8F]S92LK.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D:6YV3W!T("`@(#T@=')U93L*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`O
M+R!A<F=U;65N="!N;W0@=F%L:60L(&)A:6P@;W5T"B`@("`@("`@("`@("1I
M;G9/<'0@("`@/2!T<G5E.PH@("`@("`@("`@("!B<F5A:SL*("`@('T*("`@
M(&EF("@D:6YV3W!T*2!["B`@("`@("`@+R\@<V5E(&%B;W9E"B`@("`@("`@
M)'!R:6YT2&5L<"`]('1R=64["B`@("`@("`@96-H;R`B26YV86QI9"!O<'1I
M;VXZ("<B+B1?4T525D526R)A<F=V(EU;)&-=+B(G7&XB.PH@("`@("`@(&)R
M96%K.PH@("`@?0I]"@HO+R!H96QP+6UE<W-A9V4*:68@*"$D;6]D95-E="!\
M?"`D<')I;G1(96QP*2!["B`@("!E8VAO(")5<V%G93H@(BYB87-E;F%M92@D
M7U-%4E9%4ELB87)G=B)=6S!=+"`B+G!H<"(I+B(@+6Q\+6$@6V]P=&EO;G-=
M7&XB.PH@("`@96-H;R`B3W!T:6]N<SI<;B(["B`@("!E8VAO("(@("UL("`@
M("`@("`@("`@("!B=6EL9"!L;V-A=&EO;G-$0EQN(CL*("`@(&5C:&\@(B`@
M+6$@("`@("`@("`@("`@(&)U:6QD(&%I<G!O<G1S1$)<;B(["B`@("!E8VAO
M("(@("UF(#QF:6QE/B`@("`@("!U<V4@/&9I;&4^(&%S(&EN<'5T7&XB.PH@
M("`@96-H;R`B("`M<R`@("`@("`@("`@("`@<V%V92!D;W=N;&]A9&5D(&9I
M;&4@=&\@9&ES:UQN(CL*("`@(&5C:&\@(B`@+70@/&1B='EP93X@("`@('1Y
M<&4@;V8@=&AE($1"('1O(&)E('5S961<;B(["B`@("!E8VAO("(@("UR(#QD
M8G!R;W1O8V]L/B!P<F]T;V-O;"`M+2TM+5PB+2TM+2TM+2TM+5QN(CL*("`@
M(&5C:&\@(B`@+60@/&1B;F%M93X@("`@(&YA;64@+2TM+2TM+2TM7"(M+2TM
M+2TM+2TM7&XB.PH@("`@96-H;R`B("`M=2`\9&)U<V5R/B`@("`@=7-E<B`M
M+2TM+2TM+2U<(BTM+2TM+2TM+2U<;B(["B`@("!E8VAO("(@("UP(#QD8G!A
M<W,^("`@("!P87-S("TM+2TM+2TM+5PB+2TM+2TM+2TM+5QN(CL*("`@(&5C
M:&\@(B`@+6@@/&1B:&]S=#X@("`@(&AO<W0@+2TM+2TM+2TM7"(M+2TM+2TM
M+2TM7&XB.PH@("`@96-H;R`B("`M;R`\9&)O<'1I;VYS/B`@;W!T:6]N<R`M
M+2TM+2U<(BTM+2TM+2TM+2U<;B(["B`@("!E8VAO("(@("`@("`@("`@("`@
M("`@("!I;B!T:&4@;F]T871I;VX@;W!T:6]N/79A;'5E+"XN+EQN(CL*("`@
M(&5C:&\@(B`@+78@("`@("`@("`@("`@(&1I<W!L87D@=F5R8F]S92!D96)U
M9V=I;F<@;65S<V%G97-<;B(["B`@("!E8VAO("(@("`@("`@("`@("`@("`@
M("!M=6QT:7!L92`M=B!I;F-R96%S97,@=F5R8F]S:71Y7&XB.PH@("`@97AI
M="@R-34I.PI]"@HO+R!C:&5C:RP@:68@>FQI8B!I<R!A=F%I;&%B;&4*:68@
M*&5X=&5N<VEO;E]L;V%D960H(GIL:6(B*2D@>PH@("`@)&]P96X@(#T@(F=Z
M;W!E;B(["B`@("`D8VQO<V4@/2`B9WIC;&]S92(["B`@("`D9FEL97,@/2!A
M<G)A>2@*("`@("`@("`D=7-E<D9I;&4L(")N<V1?(BXD9FEL95!A<G0L(")N
M<V1?(BXD9FEL95!A<G0N(BYT>'0B+`H@("`@("`@(")N<V1?(BXD9FEL95!A
M<G0N(BYG>B(L(")H='1P.B\O=V5A=&AE<BYN;V%A+F=O=B]D871A+VYS9%\B
M+B1F:6QE4&%R="XB+F=Z(@H@("`@*3L*?2!E;'-E('L*("`@("1O<&5N("`]
M(")F;W!E;B(["B`@("`D8VQO<V4@/2`B9F-L;W-E(CL*("`@("1F:6QE<R`]
M(&%R<F%Y*`H@("`@("`@("1U<V5R1FEL92P@(FYS9%\B+B1F:6QE4&%R="P@
M(FYS9%\B+B1F:6QE4&%R="XB+G1X="(L"B`@("`@("`@(FAT='`Z+R]W96%T
M:&5R+FYO86$N9V]V+V1A=&$O;G-D7R(N)&9I;&5087)T+B(N='AT(@H@("`@
M*3L*?0HO+R!T:&5N('1R>2!T;R!O<&5N(&$@<V]U<F-E(&EN('1H92!G:79E
M;B!O<F1E<@IF;W)E86-H("@D9FEL97,@87,@)&9I;&4I('L*("`@("1F<"`]
M($`D;W!E;B@D9FEL92P@(G)B(BD["B`@("!I9B`H)&9P*2!["B`@("`@("`@
M+R\@9F]U;F0@82!V86QI9"!S;W5R8V4*("`@("`@("!I9B`H)'9E<F)O<V4@
M/B`P*2!["B`@("`@("`@("`@(&5C:&\@(E-E<G9I8V5S7U=E871H97(Z(%5S
M:6YG("<B+B1F:6QE+B(G(&%S('-O=7)C92Y<;B(["B`@("`@("`@?0H@("`@
M("`@(&EF("@D<V%V949I;&4@)B8@(69I;&5?97AI<W1S*"1F:6QE*2D@>PH@
M("`@("`@("`@("`O+R!A<'!A<F5N=&QY('=E('=A;G0@=&\@<V%V92!T:&4@
M9FEL92P@86YD(&ET)W,@82!R96UO=&4@9FEL90H@("`@("`@("`@("`D9FEL
M92`](&)A<V5N86UE*"1F:6QE*3L*("`@("`@("`@("`@)&9P<R`]($`D;W!E
M;B@D9FEL92P@(G=B(BD["B`@("`@("`@("`@(&EF("@A)&9P<RD@>PH@("`@
M("`@("`@("`@("`@96-H;R`B4V5R=FEC97-?5V5A=&AE<CH@0V]U;&1N)W0@
M<V%V92!T;R`G(BXD9FEL92XB)R%<;B(["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("!I9B`H)'9E<F)O<V4@/B`P*2!["B`@("`@("`@
M("`@("`@("`@("`@96-H;R`B4V5R=FEC97-?5V5A=&AE<CH@4V%V:6YG('-O
M=7)C92!T;R`G(BXD9FEL92XB)RY<;B(["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`O+R!R96%D(&9R;VT@9FEL97!O:6YT97(@86YD('-A
M=F4@=&\@9&ES:PH@("`@("`@("`@("`@("`@=VAI;&4@*"1L:6YE(#T@9G)E
M860H)&9P+"`Q,#(T*2D@>PH@("`@("`@("`@("`@("`@("`@(&9W<FET92@D
M9G!S+"`D;&EN92P@<W1R;&5N*"1L:6YE*2D["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`O+R!U;F9O<G1U;F%T96QY('IL:6(@9&]E<R!N
M;W0@<W5P<&]R="!R+W<@;VX@82!R97-O=7)C92P*("`@("`@("`@("`@("`@
M("\O('-O(&YO(')E=VEN9"`M/B!M;W9E("1F<"!T;R!N97<@9FEL92!O;B!D
M:7-K"B`@("`@("`@("`@("`@("`D8VQO<V4H)&9P*3L*("`@("`@("`@("`@
M("`@("1C;&]S92@D9G!S*3L*("`@("`@("`@("`@("`@("1F<"`]($`D;W!E
M;B@D9FEL92P@(G)B(BD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@8G)E86L["B`@("!]"GT*:68@*"$D9G`I('L*("`@("\O(&YO(&9I;&5S
M(&9O=6YD+"!O<B!C;VYN96-T:6]N(&YO="!A=F%I;&%B;&4N+BX@8F%I;"!O
M=70*("`@(&1I92@B4V5R=FEC97-?5V5A=&AE<CH@4V]U<F-E9FEL92!N<V1?
M(BXD9FEL95!A<G0N(B!N;W0@9F]U;F0A7&XB*3L*?0H*)&1S;B`@("`@/2`D
M9&)4>7!E+B(Z+R\B+B1D8E5S97(N(CHB+B1D8E!A<W,N(D`B+B1D8E!R;W0N
M(BLB+B1D8DAO<W0N(B\B+B1D8DYA;64["B1D<VYI;F9O(#T@87)R87DH"B`@
M("`B<&AP='EP92(@(#T^("1D8E1Y<&4L"B`@("`B<')O=&]C;VPB(#T^("1D
M8E!R;W0L"B`@("`B=7-E<FYA;64B(#T^("1D8E5S97(L"B`@("`B<&%S<W=O
M<F0B(#T^("1D8E!A<W,L"B`@("`B:&]S='-P96,B(#T^("1D8DAO<W0L"B`@
M("`B9&%T86)A<V4B(#T^("1D8DYA;64L"B`@("`B;6]D92(@("`@(#T^("(P
M-C0T(@HI.PH*)&1B("`]($1".CIC;VYN96-T*"1D<VYI;F9O+"`D9&)/<'1I
M;VYS*3L*:68@*$1".CII<T5R<F]R*"1D8BDI('L*("`@(&5C:&\@(E-E<G9I
M8V5S7U=E871H97(Z($-O;FYE8W1I;VX@=&\@1$(@=VET:"`G(BXD9&)4>7!E
M+B(Z+R\B+B1D8E5S97(N(CI005-30"(N)&1B2&]S="XB+R(N)&1B3F%M92XB
M)R!F86EL960A7&XB.PH@("`@9&EE*"1D8BT^9V5T365S<V%G92@I+B)<;B(I
M.PI](&5L<V4@>PH@("`@+R\@5&5S="P@:68@=V4@:&%V92!T;R!S=VEP92!O
M<B!C<F5A=&4@=&AE('1A8FQE(&9I<G-T"B`@("`D<V5L96-T(#T@(E-%3$5#
M5"`J($923TT@(BXD=&%B;&5.86UE.PH@("`@)')E<W5L="`]("1D8BT^<75E
M<GDH)'-E;&5C="D["@H@("`@:68@*$1".CII<T5R<F]R*"1R97-U;'0I*2![
M"B`@("`@("`@+R\@0W)E871E(&YE=R!T86)L90H@("`@("`@("1C<F5A=&4@
M/2`B0U)%051%(%1!0DQ%("(N)'1A8FQE3F%M92XB*&ED(&EN="QB;&]C:R!I
M;G0L<W1A=&EO;B!I;G0L:6-A;R!V87)C:&%R*#0I+&YA;64@=F%R8VAA<B@X
M,"DL<W1A=&4@=F%R8VAA<B@R*2QC;W5N=')Y('9A<F-H87(H-3`I+'=M;R!I
M;G0L;&%T:71U9&4@9FQO870L;&]N9VET=61E(&9L;V%T+&5L979A=&EO;B!F
M;&]A="QX(&9L;V%T+'D@9FQO870L>B!F;&]A="DB.PH@("`@("`@(&EF("@D
M=F5R8F]S92`^(#`I('L*("`@("`@("`@("`@96-H;R`B4V5R=FEC97-?5V5A
M=&AE<CH@0W)E871I;F<@=&%B;&4@)R(N)'1A8FQE3F%M92XB)RY<;B(["B`@
M("`@("`@?0H@("`@("`@("1R97-U;'0@(#T@)&1B+3YQ=65R>2@D8W)E871E
M*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@
M("`@("`@9&EE*"1R97-U;'0M/F=E=$UE<W-A9V4H*2XB7&XB*3L*("`@("`@
M("!]"B`@("!](&5L<V4@>PH@("`@("`@("\O($1E;&5T92!T:&4@;VQD('-T
M=69F"B`@("`@("`@)&1E;&5T92`](")$14Q%5$4@1E)/32`B+B1T86)L94YA
M;64["B`@("`@("`@:68@*"1V97)B;W-E(#X@,"D@>PH@("`@("`@("`@("!E
M8VAO(")397)V:6-E<U]796%T:&5R.B!$96QE=&EN9R!F<F]M('1A8FQE("<B
M+B1T86)L94YA;64N(B<N7&XB.PH@("`@("`@('T*("`@("`@("`D<F5S=6QT
M(#T@)&1B+3YQ=65R>2@D9&5L971E*3L*("`@("`@("!I9B`H1$(Z.FES17)R
M;W(H)')E<W5L="DI('L*("`@("`@("`@("`@9&EE*"1R97-U;'0M/F=E=$UE
M<W-A9V4H*2XB7&XB*3L*("`@("`@("!]"B`@("!]"@H@("`@+R\@3VLL($1"
M('-H;W5L9"!B92!U<"!A;F0@<G5N;FEN9R!N;W<L(&QE="=S('-H;W9E(&EN
M('1H92!D871A"B`@("`D;&EN92`@(#T@,#L*("`@("1E<G)O<B`@/2`P.PH@
M("`@+R\@<F5A9"!D871A(&9R;VT@9FEL90H@("`@=VAI;&4@*"1D871A(#T@
M9F=E=&-S=B@D9G`L(#$P,#`L("([(BDI('L*("`@("`@("`O+R!#:&5C:R!F
M;W(@=F%L:60@9&%T80H@("`@("`@(&EF("@H<VEZ96]F*"1D871A*2`\(#DI
M('Q\("%397)V:6-E<U]796%T:&5R7V-H96-K1&%T82@D9&%T82P@)&1A=&%/
M<F1E<BDI('L*("`@("`@("`@("`@("`@(&5C:&\@(E-E<G9I8V5S7U=E871H
M97(Z($EN=F%L:60@9&%T82!I;B!F:6QE(5QN(CL*("`@("`@("`@("`@("`@
M(&5C:&\@(EQT3&EN92`B+B@D;&EN92`K(#$I+B(Z("(N:6UP;&]D92@B.R(L
M("1D871A*2XB7&XB.PH@("`@("`@("`@("`@("`@)&5R<F]R*RL["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@8V%L8W5L871E(&QA=&ET=61E
M(&%N9"!L;VYG:71U9&4*("`@("`@("`@("`@+R\@:70@8V]M97,@:6X@82!D
M9&0M;6U;+7-S74Y\4WQ%?%<@9F]R;6%T"B`@("`@("`@("`@("1C;V]R9"`]
M(&%R<F%Y*"`B;&%T:71U9&4B(#T^(#<L(")L;VYG:71U9&4B(#T^(#@I.PH@
M("`@("`@("`@("!F;W)E86-H("@D8V]O<F0@87,@)&QA=&QO;B`]/B`D84ED
M*2!["B`@("`@("`@("`@("`@("!P<F5G7VUA=&-H*"(O7BA<9'LQ+#-]*2TH
M7&1[,2PR?2DH+2A<9'LQ+#)]*2D_*%M.4T5772DD+R(L("1D871A6R1A261=
M+"`D<F5S=6QT*3L*("`@("`@("`@("`@("`@("1[)&QA=&QO;GT@/2`P.R`D
M9F%C=&]R(#T@,3L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1R97-U;'0@
M87,@)'9A<BD@>PH@("`@("`@("`@("`@("`@("`@(&EF("@H<W1R;&5N*"1V
M87(I(#X@,"D@)B8@8W1Y<&5?9&EG:70H)'9A<BDI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'LD;&%T;&]N?2`K/2`D=F%R("\@)&9A8W1O<CL*("`@
M("`@("`@("`@("`@("`@("`@("`@)&9A8W1O<B`J/2`V,#L*("`@("`@("`@
M("`@("`@("`@("!](&5L<V5I9B`H8W1Y<&5?86QP:&$H)'9A<BD@)B8@:6Y?
M87)R87DH)'9A<BP@87)R87DH(E,B+"`B5R(I*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D>R1L871L;VY]("H]("@M,2D["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`O+R!#86QC=6QA=&4@=&AE(&-A<G1E<VEA;B!C;V]R9&EN871E
M<R!F;W(@;&%T:71U9&4@86YD(&QO;F=I='5D90H@("`@("`@("`@("`D=&AE
M=&$@/2!D96<R<F%D*"1L871I='5D92D["B`@("`@("`@("`@("1P:&D@("`]
M(&1E9S)R860H)&QO;F=I='5D92D["@H@("`@("`@("`@("`D>"`](%-%4E9)
M0T537U=%051(15)?4D%$25537T5!4E1(("H@8V]S*"1P:&DI("H@8V]S*"1T
M:&5T82D["B`@("`@("`@("`@("1Y(#T@4T525DE#15-?5T5!5$A%4E]2041)
M55-?14%25$@@*B!S:6XH)'!H:2D@*B!C;W,H)'1H971A*3L*("`@("`@("`@
M("`@)'H@/2!315)624-%4U]714%42$527U)!1$E54U]%05)42"`@("`@("`@
M("`@("`J('-I;B@D=&AE=&$I.PH*("`@("`@("`@("`@+R\@0VAE8VL@9F]R
M(&5L979A=&EO;B!I;B!D871A"B`@("`@("`@("`@("1E;&5V871I;VX@/2!I
M<U]N=6UE<FEC*"1D871A6S$Q72D@/R`D9&%T85LQ,5T@.B`P.PH*("`@("`@
M("`@("`@+R\@:6YT96=E<G,Z(&-O;G9E<G0@(BTM(B!F:65L9',@=&\@;G5L
M;"P@96UP='D@9FEE;&1S('1O(#`*("`@("`@("`@("`@9F]R96%C:"`H87)R
M87DH)&1A=&%/<F1E<ELB8B)=+"`D9&%T84]R9&5R6R)S(ETL(#8I(&%S("1I
M*2!["B`@("`@("`@("`@("`@("!I9B`H<W1R<&]S*"1D871A6R1I72P@(BTM
M(BD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`@("`@)&1A=&%;)&E=
M(#T@(FYU;&PB.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1D871A6R1I
M72`]/2`B(BD@>PH@("`@("`@("`@("`@("`@("`@("1D871A6R1I72`](#`[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("\O('-T<FEN9W,Z('%U;W1E"B`@("`@("`@("`@(&9O<F5A8V@@*&%R<F%Y
M*"1D871A3W)D97);(FDB72P@,RP@-"P@-2D@87,@)&DI('L*("`@("`@("`@
M("`@("`@("1D871A6R1I72`]("1D8BT^<75O=&4H)&1A=&%;)&E=*3L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@+R\@:6YS97)T(&1A=&$*("`@("`@
M("`@("`@)&EN<V5R="`@/2`B24Y315)4($E.5$\@(BXD=&%B;&5.86UE+B(@
M5D%,5453*"(N*"1L:6YE("T@)&5R<F]R*2XB+"(["B`@("`@("`@("`@("1I
M;G-E<G0@+CT@)&1A=&%;)&1A=&%/<F1E<ELB8B)=72XB+"(N)&1A=&%;)&1A
M=&%/<F1E<ELB<R)=72XB+"(["B`@("`@("`@("`@("1I;G-E<G0@+CT@)&1A
M=&%;)&1A=&%/<F1E<ELB:2)=72XB+"(N)&1A=&%;,UTN(BPB+B1D871A6S1=
M+B(L(CL*("`@("`@("`@("`@)&EN<V5R="`N/2`D9&%T85LU72XB+"(N)&1A
M=&%;-ETN(BPB+G)O=6YD*"1L871I='5D92P@-"DN(BPB.PH@("`@("`@("`@
M("`D:6YS97)T("X](')O=6YD*"1L;VYG:71U9&4L(#0I+B(L(BXD96QE=F%T
M:6]N+B(L(BYR;W5N9"@D>"P@-"DN(BPB.PH@("`@("`@("`@("`D:6YS97)T
M("X](')O=6YD*"1Y+"`T*2XB+"(N<F]U;F0H)'HL(#0I+B(I(CL*"B`@("`@
M("`@("`@("1R97-U;'0@/2`D9&(M/G%U97)Y*"1I;G-E<G0I.PH@("`@("`@
M("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@
M("`@(&5C:&\@(EQT3&EN92`B+B@D;&EN92`K(#$I+B(Z("(N)&EN<V5R="XB
M7&XB.PH@("`@("`@("`@("`@("`@96-H;R`D<F5S=6QT+3YG971-97-S86=E
M*"DN(EQN(CL*("`@("`@("`@("`@("`@("1E<G)O<BLK.PH@("`@("`@("`@
M("!](&5L<V5I9B@D=F5R8F]S92`^(#(I('L*("`@("`@("`@("`@("`@(&5C
M:&\@)&EN<V5R="XB7&XB.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@("1L:6YE*RL["B`@("!]"B`@("`O+R!C;VUM:70@86YD(&-L;W-E"B`@
M("`D9&(M/F1I<V-O;FYE8W0H*3L*("`@(&EF("@D=F5R8F]S92`^(#`@?'P@
M)&5R<F]R(#X@,"D@>PH@("`@("`@(&5C:&\@(E-E<G9I8V5S7U=E871H97(Z
M("(N*"1L:6YE("T@)&5R<F]R*2XB("(N)'1A8FQE3F%M92XB(&%D9&5D("([
M"B`@("`@("`@96-H;R`B=&\@9&%T86)A<V4@)R(N)&1B3F%M92XB)R`H(BXD
M97)R;W(N(B!E<G)O<BAS*2DN7&XB.PH@("`@?0I]"B1C;&]S92@D9G`I.PH_
M/@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+V1A=&$O6$U,7U-E<FEA;&EZ97(`````````````````````````````
M````````````````````````````````````````,#`P-S4U(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S`@,#(R,30V`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O9&%T82]834Q?4V5R:6%L:7IE<B]D;V,`
M````````````````````````````````````````````````````````````
M```P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S
M,S<S,"`P,C(W,3,`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D871A+UA-
M3%]397)I86QI>F5R+V1O8R]T;V1O+G1X=```````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`Q,#8P(#$P-3$U-#,S-S,P(#`R-#0W-0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!43T1/.@HM+2TM+0HM(&EN=')O
M9'5C92!C;VYS=&%N=',@9F]R(&]P=&EO;G,@=&\@879O:60@='EP;W,*"E1/
M1$\@6$U,7U-E<FEA;&EZ97(Z"BTM+2TM+2TM+2TM+2TM+2TM+2TM"BT@9FEN
M9"!A('=A>2!T;R!D971E8W0@<F5F97)E;F-E<R!I;B!T:&4@<W1R=6-T=7)E
M(&%N9"!A9&0@:60O:61R968@871T<FEB=71E<PHM('-E<FEA;&EZ92!S;VUE
M(&]T:&5R('-T<G5C='5R97,L(&5S<&5C:6%L;'D@6%!A=&@@<F5T=7)N('9A
M;'5E<PHM(&-U<W1O;2!S97)I86QI>F%T:6]N(&]F(&]B:F5C=',*"E1/1$\@
M6$U,7U5N<V5R:6%L:7IE<CH*+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0HM('-U
M<'!O<G0@9F]R('AM;#IS<&%C92!A='1R:6)U=&4*+2!S970@='EP97,@9F]R
M(&-E<G1A:6X@=&%G<R`H;&EK92!I;B!P871#;VYF:6=U<F%T:6]N*0HM(&YA
M;65S<&%C92!S=7!P;W)T"BT@8W5S=&]M('5N<V5R:6%L:7IA=&EO;B!F;W(@
M;V)J96-T<R`H<W1A=&EC('5N<V5R:6%L:7IE*"D@;W(@9G)O;5A-3"@I(&UE
M=&AO9',I"BT@=6YS97)I86QI>F4@<F5F97)E;F-E<R!U<VEN9R!I9"]I9')E
M9@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D
M871A+T-A8VAE````````````````````````````````````````````````
M`````````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S,P(#`R,#,R,``@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+V1A=&$O0V%C:&4O0V]N=&%I;F5R````````````
M````````````````````````````````````````````````````````,#`P
M-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S`@
M,#(R,C0R`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&%T82]#86-H92]#
M;VYT86EN97(O;61B7V-A8VAE7W-C:&5M82YX;6P`````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,C4W-2`Q,#4Q-30S,S<S,"`P,C8R-C$`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]X;6P@=F5R<VEO;CTB,2XP(B!E;F-O
M9&EN9STB25-/+3@X-3DM,2(@/SX-"CQD871A8F%S93X-"@T*(#QN86UE/F1B
M;F%M93PO;F%M93X-"B`\8W)E871E/C$\+V-R96%T93X-"B`\9&5S8W)I<'1I
M;VX^(#PO9&5S8W)I<'1I;VX^#0H-"B`\=&%B;&4^#0H@(#QN86UE/F-A8VAE
M/"]N86UE/@T*("`\9&5S8W)I<'1I;VX^(#PO9&5S8W)I<'1I;VX^#0H-"B`@
M/&1E8VQA<F%T:6]N/@T*#0H@("`\9FEE;&0^#0H@("`@("`\;F%M93Y)1#PO
M;F%M93X-"B`@("`@(#QT>7!E/G1E>'0\+W1Y<&4^#0H@("`@("`\;&5N9W1H
M/C,R/"]L96YG=&@^#0H@("`@("`\9&5F875L=#X\+V1E9F%U;'0^#0H@("`@
M("`\;F]T;G5L;#XQ/"]N;W1N=6QL/@T*("`@/"]F:65L9#X-"@T*("`@/&9I
M96QD/@T*("`@("`@/&YA;64^8V%C:&5G<F]U<#PO;F%M93X-"B`@("`@(#QT
M>7!E/G1E>'0\+W1Y<&4^#0H@("`@("`\;&5N9W1H/C$R-SPO;&5N9W1H/@T*
M("`@("`@/&1E9F%U;'0^/"]D969A=6QT/@T*("`@("`@/&YO=&YU;&P^,3PO
M;F]T;G5L;#X-"B`@(#PO9FEE;&0^#0H-"B`@(#QF:65L9#X-"B`@("`@(#QN
M86UE/F-A8VAE9&%T83PO;F%M93X-"B`@("`@(#QT>7!E/F-L;V(\+W1Y<&4^
M#0H@("`@("`\9&5F875L=#X\+V1E9F%U;'0^#0H@("`@("`\;F]T;G5L;#XQ
M/"]N;W1N=6QL/@T*("`@/"]F:65L9#X-"@T*("`@/&9I96QD/@T*("`@("`@
M/&YA;64^=7-E<F1A=&$\+VYA;64^#0H@("`@("`\='EP93YT97AT/"]T>7!E
M/@T*("`@("`@/&QE;F=T:#XR-34\+VQE;F=T:#X-"B`@("`@(#QD969A=6QT
M/CPO9&5F875L=#X-"B`@(#PO9FEE;&0^#0H-"B`@(#QF:65L9#X-"B`@("`@
M(#QN86UE/F5X<&ER97,\+VYA;64^#0H@("`@("`\='EP93YI;G1E9V5R/"]T
M>7!E/@T*("`@("`@/&1E9F%U;'0^,#PO9&5F875L=#X-"B`@("`@(#QN;W1N
M=6QL/C$\+VYO=&YU;&P^#0H@("`\+V9I96QD/@T*#0H@("`\9FEE;&0^#0H@
M("`@("`\;F%M93YC:&%N9V5D/"]N86UE/@T*("`@("`@/'1Y<&4^:6YT96=E
M<CPO='EP93X-"B`@("`@(#QD969A=6QT/C`\+V1E9F%U;'0^#0H@("`@("`\
M;F]T;G5L;#XQ/"]N;W1N=6QL/@T*("`@/"]F:65L9#X-"@T*#0H@("`\:6YD
M97@^#0H@("`@/&YA;64^:61?:6YD97@\+VYA;64^#0H@("`@/'5N:7%U93XQ
M/"]U;FEQ=64^#0H@("`@/&9I96QD/B`\;F%M93YI9#PO;F%M93X@/"]F:65L
M9#X-"B`@("`\9FEE;&0^(#QN86UE/F-A8VAE9W)O=7`\+VYA;64^(#PO9FEE
M;&0^#0H@("`\+VEN9&5X/@T*#0H-"B`@(#QI;F1E>#X-"B`@("`\;F%M93YE
M>'!I<F5S7VEN9&5X/"]N86UE/@T*("`@(#QF:65L9#X@/&YA;64^97AP:7)E
M<SPO;F%M93X@/"]F:65L9#X-"B`@(#PO:6YD97@^#0H-"B`@/"]D96-L87)A
M=&EO;CX-"B`\+W1A8FQE/@T*#0H\+V1A=&%B87-E/@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]834P`````````````````````````````````````````
M`````````````````````````````````````````````````#`P,#<U-2``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S,Q(#`Q-S`T
M-0`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+UA-3"]24$,`````````````
M````````````````````````````````````````````````````````````
M````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@
M,3`U,34T,S,W,S$@,#$W-#<Q`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M6$U,+U)00R]397)V97(N<&AP````````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`U,C,T-R`Q,#4Q-30S,S<S,2`P,C$U-#(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"B\J('9I
M;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T
M86)S=&]P/30Z("HO"@HO*BH*("H@4V5R=F5R(&-O;6UA;F1S(&9O<B!O=7(@
M4$A0(&EM<&QE;65N=&%T:6]N(&]F('1H92!834PM4E!#('!R;W1O8V]L"B`J
M"B`J(%1H:7,@:7,@82!014%2+6EF:65D('9E<G-I;VX@;V8@57-E9G5L(&EN
M8R=S(%A-3"U24$,@9F]R(%!(4"X*("H@270@:&%S('-U<'!O<G0@9F]R($A4
M5%`@=')A;G-P;W)T+"!P<F]X:65S(&%N9"!A=71H96YT:6-A=&EO;BX*("H*
M("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@3&EC96YS
M92!I<R!G<F%N=&5D('1O('5S92!O<B!M;V1I9GD@=&AI<R!S;V9T=V%R90H@
M*B`H(EA-3"U24$,@9F]R(%!(4"(I(&9O<B!C;VUM97)C:6%L(&]R(&YO;BUC
M;VUM97)C:6%L('5S92!P<F]V:61E9"!T:&4*("H@8V]P>7)I9VAT(&]F('1H
M92!A=71H;W(@:7,@<')E<V5R=F5D(&EN(&%N>2!D:7-T<FEB=71E9"!O<B!D
M97)I=F%T:79E('=O<FLN"B`J"B`J(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$
M140@0ED@5$A%($%55$A/4B`B05,@25,B($%.1"!!3ED@15A04D534T5$($]2
M"B`J($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4($Q)
M34E4140@5$\L(%1(12!)35!,245$(%=!4E)!3E1)15,*("H@3T8@34520TA!
M3E1!0DE,2519($%.1"!&251.15-3($9/4B!!(%!!4E1)0U5,05(@4%524$]3
M12!!4D4@1$E30TQ!24U%1"X*("H@24X@3D\@159%3E0@4TA!3$P@5$A%($%5
M5$A/4B!"12!,24%"3$4@1D]2($%.62!$25)%0U0L($E.1$E214-4+`H@*B!)
M3D-)1$5.5$%,+"!34$5#24%,+"!%6$5-4$Q!4EDL($]2($-/3E-%455%3E1)
M04P@1$%-04=%4R`H24Y#3%5$24Y'+"!"550*("H@3D]4($Q)34E4140@5$\L
M(%!23T-54D5-14Y4($]&(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,[
M($Q/4U,@3T8@55-%+`H@*B!$051!+"!/4B!04D]&2513.R!/4B!"55-)3D53
M4R!)3E1%4E)54%1)3TXI($A/5T5615(@0T%54T5$($%.1"!/3B!!3ED*("H@
M5$A%3U)9($]&($Q)04))3$E462P@5TA%5$A%4B!)3B!#3TY44D%#5"P@4U12
M24-4($Q)04))3$E462P@3U(@5$]25`H@*B`H24Y#3%5$24Y'($Y%1TQ)1T5.
M0T4@3U(@3U1(15)725-%*2!!4DE324Y'($E.($%.62!705D@3U54($]&(%1(
M12!54T4@3T8*("H@5$A)4R!33T945T%212P@159%3B!)1B!!1%9)4T5$($]&
M(%1(12!03U-324))3$E462!/1B!354-(($1!34%'12X*("H*("H@0&-A=&5G
M;W)Y("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E("`@(%A-3%]24$,*("H@
M0&%U=&AO<B`@("`@161D($1U;6)I;&P@/&5D9$!U<V5F=6QI;F,N8V]M/@H@
M*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W1I9T!P:'`N;F5T/@H@*B!`
M875T:&]R("`@("!-87)T:6X@2F%N<V5N(#QM:D!P:'`N;F5T/@H@*B!`875T
M:&]R("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J
M($!C;W!Y<FEG:'0@(#$Y.3DM,C`P,2!%9&0@1'5M8FEL;"P@,C`P,2TR,#`U
M(%1H92!02%`@1W)O=7`*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%-E<G9E
M<BYP:'`L=B`Q+C,S(#(P,#8O,#$O,30@,C(Z,S`Z,S$@9&%N:65L8R!%>'`@
M)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O
M6$U,7U)00PH@*B\*"@HO*BH*("H@4'5L;"!I;B!T:&4@6$U,7U)00R!C;&%S
M<PH@*B\*<F5Q=6ER95]O;F-E("=834PO4E!#+G!H<"<["@H*+RHJ"B`J('-I
M9VYA='5R92!F;W(@<WES=&5M+FQI<W1-971H;V1S.B!R971U<FX@/2!A<G)A
M>2P*("H@<&%R86UE=&5R<R`](&$@<W1R:6YG(&]R(&YO=&AI;F<*("H@0&=L
M;V)A;"!A<G)A>2`D1TQ/0D%,4ULG6$U,7U)00U]397)V97)?;&ES=$UE=&AO
M9'-?<VEG)UT*("HO"B1'3$]"04Q36R=834Q?4E!#7U-E<G9E<E]L:7-T365T
M:&]D<U]S:6<G72`](&%R<F%Y*`H@("`@87)R87DH)$=,3T)!3%-;)UA-3%]2
M4$-?07)R87DG72P*("`@("`@("`@("1'3$]"04Q36R=834Q?4E!#7U-T<FEN
M9R=="B`@("`I+`H@("`@87)R87DH)$=,3T)!3%-;)UA-3%]24$-?07)R87DG
M72D**3L*"B\J*@H@*B!D;V-S=')I;F<@9F]R('-Y<W1E;2YL:7-T365T:&]D
M<PH@*B!`9VQO8F%L('-T<FEN9R`D1TQ/0D%,4ULG6$U,7U)00U]397)V97)?
M;&ES=$UE=&AO9'-?9&]C)UT*("HO"B1'3$]"04Q36R=834Q?4E!#7U-E<G9E
M<E]L:7-T365T:&]D<U]D;V,G72`]("=4:&ES(&UE=&AO9"!L:7-T<R!A;&P@
M=&AE)PH@("`@("`@("X@)R!M971H;V1S('1H870@=&AE(%A-3"U24$,@<V5R
M=F5R(&MN;W=S(&AO=R!T;R!D:7-P871C:"<["@HO*BH*("H@<VEG;F%T=7)E
M(&9O<B!S>7-T96TN;65T:&]D4VEG;F%T=7)E.B!R971U<FX@/2!A<G)A>2P*
M("H@<&%R86UE=&5R<R`]('-T<FEN9PH@*B!`9VQO8F%L(&%R<F%Y("1'3$]"
M04Q36R=834Q?4E!#7U-E<G9E<E]M971H;V13:6=N871U<F5?<VEG)UT*("HO
M"B1'3$]"04Q36R=834Q?4E!#7U-E<G9E<E]M971H;V13:6=N871U<F5?<VEG
M)UT@/2!A<G)A>2@*("`@(&%R<F%Y*"1'3$]"04Q36R=834Q?4E!#7T%R<F%Y
M)UTL"B`@("`@("`@("`D1TQ/0D%,4ULG6$U,7U)00U]3=')I;F<G70H@("`@
M*0HI.PH*+RHJ"B`J(&1O8W-T<FEN9R!F;W(@<WES=&5M+FUE=&AO9%-I9VYA
M='5R90H@*B!`9VQO8F%L('-T<FEN9R`D1TQ/0D%,4ULG6$U,7U)00U]397)V
M97)?;65T:&]D4VEG;F%T=7)E7V1O8R=="B`J+PHD1TQ/0D%,4ULG6$U,7U)0
M0U]397)V97)?;65T:&]D4VEG;F%T=7)E7V1O8R==(#T@)U)E='5R;G,@86X@
M87)R87D@;V8@:VYO=VXG"B`@("`@("`@+B`G('-I9VYA='5R97,@*&%N(&%R
M<F%Y(&]F(&%R<F%Y<RD@9F]R('1H92!M971H;V0@;F%M92!P87-S960N($EF
M)PH@("`@("`@("X@)R!N;R!S:6=N871U<F5S(&%R92!K;F]W;BP@<F5T=7)N
M<R!A(&YO;F4M87)R87D@*'1E<W0@9F]R('1Y<&4@(3TG"B`@("`@("`@+B`G
M(&%R<F%Y('1O(&1E=&5C="!M:7-S:6YG('-I9VYA='5R92DG.PH*+RHJ"B`J
M('-I9VYA='5R92!F;W(@<WES=&5M+FUE=&AO9$AE;'`Z(')E='5R;B`]('-T
M<FEN9RP*("H@<&%R86UE=&5R<R`]('-T<FEN9PH@*B!`9VQO8F%L(&%R<F%Y
M("1'3$]"04Q36R=834Q?4E!#7U-E<G9E<E]M971H;V1(96QP7W-I9R=="B`J
M+PHD1TQ/0D%,4ULG6$U,7U)00U]397)V97)?;65T:&]D2&5L<%]S:6<G72`]
M(&%R<F%Y*`H@("`@87)R87DH)$=,3T)!3%-;)UA-3%]24$-?4W1R:6YG)UTL
M"B`@("`@("`@("`D1TQ/0D%,4ULG6$U,7U)00U]3=')I;F<G70H@("`@*0HI
M.PH*+RHJ"B`J(&1O8W-T<FEN9R!F;W(@;65T:&]D2&5L<`H@*B!`9VQO8F%L
M('-T<FEN9R`D1TQ/0D%,4ULG6$U,7U)00U]397)V97)?;65T:&]D2&5L<%]D
M;V,G70H@*B\*)$=,3T)!3%-;)UA-3%]24$-?4V5R=F5R7VUE=&AO9$AE;'!?
M9&]C)UT@/2`G4F5T=7)N<R!H96QP('1E>'0@:68@9&5F:6YE9"<*("`@("`@
M("`N("<@9F]R('1H92!M971H;V0@<&%S<V5D+"!O=&AE<G=I<V4@<F5T=7)N
M<R!A;B!E;7!T>2!S=')I;F<G.PH*+RHJ"B`J(&1I<W!A=&-H(&UA<"!F;W(@
M=&AE(&%U=&]M871I8V%L;'D@9&5C;&%R960@6$U,+5)00R!M971H;V1S+@H@
M*B!`9VQO8F%L(&%R<F%Y("1'3$]"04Q36R=834Q?4E!#7U-E<G9E<E]D;6%P
M)UT*("HO"B1'3$]"04Q36R=834Q?4E!#7U-E<G9E<E]D;6%P)UT@/2!A<G)A
M>2@*("`@("=S>7-T96TN;&ES=$UE=&AO9',G(#T^(&%R<F%Y*`H@("`@("`@
M("=F=6YC=&EO;B<@(#T^("=834Q?4E!#7U-E<G9E<E]L:7-T365T:&]D<R<L
M"B`@("`@("`@)W-I9VYA='5R92<@/3X@)$=,3T)!3%-;)UA-3%]24$-?4V5R
M=F5R7VQI<W1-971H;V1S7W-I9R==+`H@("`@("`@("=D;V-S=')I;F<G(#T^
M("1'3$]"04Q36R=834Q?4E!#7U-E<G9E<E]L:7-T365T:&]D<U]D;V,G70H@
M("`@*2P*("`@("=S>7-T96TN;65T:&]D2&5L<"<@/3X@87)R87DH"B`@("`@
M("`@)V9U;F-T:6]N)R`@/3X@)UA-3%]24$-?4V5R=F5R7VUE=&AO9$AE;'`G
M+`H@("`@("`@("=S:6=N871U<F4G(#T^("1'3$]"04Q36R=834Q?4E!#7U-E
M<G9E<E]M971H;V1(96QP7W-I9R==+`H@("`@("`@("=D;V-S=')I;F<G(#T^
M("1'3$]"04Q36R=834Q?4E!#7U-E<G9E<E]M971H;V1(96QP7V1O8R=="B`@
M("`I+`H@("`@)W-Y<W1E;2YM971H;V13:6=N871U<F4G(#T^(&%R<F%Y*`H@
M("`@("`@("=F=6YC=&EO;B<@(#T^("=834Q?4E!#7U-E<G9E<E]M971H;V13
M:6=N871U<F4G+`H@("`@("`@("=S:6=N871U<F4G(#T^("1'3$]"04Q36R=8
M34Q?4E!#7U-E<G9E<E]M971H;V13:6=N871U<F5?<VEG)UTL"B`@("`@("`@
M)V1O8W-T<FEN9R<@/3X@)$=,3T)!3%-;)UA-3%]24$-?4V5R=F5R7VUE=&AO
M9%-I9VYA='5R95]D;V,G70H@("`@*0HI.PH*+RHJ"B`J($!G;&]B86P@<W1R
M:6YG("1'3$]"04Q36R=834Q?4E!#7U-E<G9E<E]D96)U9VEN9F\G70H@*B\*
M)$=,3T)!3%-;)UA-3%]24$-?4V5R=F5R7V1E8G5G:6YF;R==(#T@)R<["@H*
M+RHJ"B`J($QI<W1S(&%L;"!T:&4@;65T:&]D<R!T:&%T('1H92!834PM4E!#
M('-E<G9E<B!K;F]W<R!H;W<@=&\@9&ES<&%T8V@*("H*("H@0')E='5R;B!O
M8FIE8W0@(&$@;F5W(%A-3%]24$-?4F5S<&]N<V4@;V)J96-T"B`J+PIF=6YC
M=&EO;B!834Q?4E!#7U-E<G9E<E]L:7-T365T:&]D<R@D<V5R=F5R+"`D;2D*
M>PH@("`@9VQO8F%L("1834Q?4E!#7V5R<BP@)%A-3%]24$-?<W1R+"`D6$U,
M7U)00U]397)V97)?9&UA<#L*"B`@("`D=B`](&YE=R!834Q?4E!#7U9A;'5E
M*"D["B`@("`D;W5T07(@/2!A<G)A>2@I.PH@("`@9F]R96%C:"`H)'-E<G9E
M<BT^9&UA<"!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`D;W5T07);72`]
M(&YE=R!834Q?4E!#7U9A;'5E*"1K97DL("=S=')I;F<G*3L*("`@('T*("`@
M(&9O<F5A8V@@*"1834Q?4E!#7U-E<G9E<E]D;6%P(&%S("1K97D@/3X@)'9A
M;"D@>PH@("`@("`@("1O=71!<EM=(#T@;F5W(%A-3%]24$-?5F%L=64H)&ME
M>2P@)W-T<FEN9R<I.PH@("`@?0H@("`@)'8M/F%D9$%R<F%Y*"1O=71!<BD[
M"B`@("!R971U<FX@;F5W(%A-3%]24$-?4F5S<&]N<V4H)'8I.PI]"@HO*BH*
M("H@4F5T=7)N<R!A;B!A<G)A>2!O9B!K;F]W;B!S:6=N871U<F5S("AA;B!A
M<G)A>2!O9B!A<G)A>7,I"B`J(&9O<B!T:&4@9VEV96X@;65T:&]D"B`J"B`J
M($EF(&YO('-I9VYA='5R97,@87)E(&MN;W=N+"!R971U<FYS(&$@;F]N92UA
M<G)A>0H@*B`H=&5S="!F;W(@='EP92`A/2!A<G)A>2!T;R!D971E8W0@;6ES
M<VEN9R!S:6=N871U<F4I"B`J"B`J($!R971U<FX@;V)J96-T("!A(&YE=R!8
M34Q?4E!#7U)E<W!O;G-E(&]B:F5C=`H@*B\*9G5N8W1I;VX@6$U,7U)00U]3
M97)V97)?;65T:&]D4VEG;F%T=7)E*"1S97)V97(L("1M*0I["B`@("!G;&]B
M86P@)%A-3%]24$-?97)R+"`D6$U,7U)00U]S='(L("1834Q?4E!#7U-E<G9E
M<E]D;6%P.PH*("`@("1M971H3F%M92`]("1M+3YG971087)A;2@P*3L*("`@
M("1M971H3F%M92`]("1M971H3F%M92T^<V-A;&%R=F%L*"D["B`@("!I9B`H
M<W1R<&]S*"1M971H3F%M92P@)W-Y<W1E;2XG*2`]/3T@,"D@>PH@("`@("`@
M("1D;6%P(#T@)%A-3%]24$-?4V5R=F5R7V1M87`["B`@("`@("`@)'-Y<T-A
M;&P@/2`Q.PH@("`@?2!E;'-E('L*("`@("`@("`D9&UA<"`]("1S97)V97(M
M/F1M87`["B`@("`@("`@)'-Y<T-A;&P@/2`P.PH@("`@?0H@("`@+R\@('!R
M:6YT("(\(2TM("1[;65T:$YA;65]("TM/EQN(CL*("`@(&EF("AI<W-E="@D
M9&UA<%LD;65T:$YA;65=*2D@>PH@("`@("`@(&EF("@D9&UA<%LD;65T:$YA
M;65=6R=S:6=N871U<F4G72D@>PH@("`@("`@("`@("`D<VEG<R`](&%R<F%Y
M*"D["B`@("`@("`@("`@("1T:&5S:6=S(#T@)&1M87!;)&UE=&A.86UE75LG
M<VEG;F%T=7)E)UT["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I
M>F5O9B@D=&AE<VEG<RD[("1I*RLI('L*("`@("`@("`@("`@("`@("1C=7)S
M:6<@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@)&EN4VEG(#T@)'1H97-I
M9W-;)&E=.PH@("`@("`@("`@("`@("`@9F]R("@D:B`](#`[("1J(#P@<VEZ
M96]F*"1I;E-I9RD[("1J*RLI('L*("`@("`@("`@("`@("`@("`@("`D8W5R
M<VEG6UT@/2!N97<@6$U,7U)00U]686QU92@D:6Y3:6=;)&I=+"`G<W1R:6YG
M)RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<VEG<UM=
M(#T@;F5W(%A-3%]24$-?5F%L=64H)&-U<G-I9RP@)V%R<F%Y)RD["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)'(@/2!N97<@6$U,7U)00U]297-P;VYS
M92AN97<@6$U,7U)00U]686QU92@D<VEG<RP@)V%R<F%Y)RDI.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1R(#T@;F5W(%A-3%]24$-?4F5S<&]N
M<V4H;F5W(%A-3%]24$-?5F%L=64H)W5N9&5F)RP@)W-T<FEN9R<I*3L*("`@
M("`@("!]"B`@("!](&5L<V4@>PH@("`@("`@("1R(#T@;F5W(%A-3%]24$-?
M4F5S<&]N<V4H,"P@)%A-3%]24$-?97)R6R=I;G1R;W-P96-T7W5N:VYO=VXG
M72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1834Q?4E!#
M7W-T<ELG:6YT<F]S<&5C=%]U;FMN;W=N)UTI.PH@("`@?0H@("`@<F5T=7)N
M("1R.PI]"@HO*BH*("H@4F5T=7)N<R!H96QP('1E>'0@:68@9&5F:6YE9"!F
M;W(@=&AE(&UE=&AO9"!P87-S960L(&]T:&5R=VES92!R971U<FYS"B`J(&%N
M(&5M<'1Y('-T<FEN9PH@*@H@*B!`<F5T=7)N(&]B:F5C="`@82!N97<@6$U,
M7U)00U]297-P;VYS92!O8FIE8W0*("HO"F9U;F-T:6]N(%A-3%]24$-?4V5R
M=F5R7VUE=&AO9$AE;'`H)'-E<G9E<BP@)&TI"GL*("`@(&=L;V)A;"`D6$U,
M7U)00U]E<G(L("1834Q?4E!#7W-T<BP@)%A-3%]24$-?4V5R=F5R7V1M87`[
M"@H@("`@)&UE=&A.86UE(#T@)&TM/F=E=%!A<F%M*#`I.PH@("`@)&UE=&A.
M86UE(#T@)&UE=&A.86UE+3YS8V%L87)V86PH*3L*("`@(&EF("AS=')P;W,H
M)&UE=&A.86UE+"`G<WES=&5M+B<I(#T]/2`P*2!["B`@("`@("`@)&1M87`@
M/2`D6$U,7U)00U]397)V97)?9&UA<#L*("`@("`@("`D<WES0V%L;"`](#$[
M"B`@("!](&5L<V4@>PH@("`@("`@("1D;6%P(#T@)'-E<G9E<BT^9&UA<#L*
M("`@("`@("`D<WES0V%L;"`](#`["B`@("!]"@H@("`@:68@*&ES<V5T*"1D
M;6%P6R1M971H3F%M95TI*2!["B`@("`@("`@:68@*"1D;6%P6R1M971H3F%M
M95U;)V1O8W-T<FEN9R==*2!["B`@("`@("`@("`@("1R(#T@;F5W(%A-3%]2
M4$-?4F5S<&]N<V4H;F5W(%A-3%]24$-?5F%L=64H)&1M87!;)&UE=&A.86UE
M75LG9&]C<W1R:6YG)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S=')I;F<G*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D<B`](&YE=R!834Q?4E!#7U)E<W!O
M;G-E*&YE=R!834Q?4E!#7U9A;'5E*"<G+"`G<W1R:6YG)RDI.PH@("`@("`@
M('T*("`@('T@96QS92!["B`@("`@("`@)'(@/2!N97<@6$U,7U)00U]297-P
M;VYS92@P+"`D6$U,7U)00U]E<G);)VEN=')O<W!E8W1?=6YK;F]W;B==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)%A-3%]24$-?
M<W1R6R=I;G1R;W-P96-T7W5N:VYO=VXG72D["B`@("!]"B`@("!R971U<FX@
M)'(["GT*"B\J*@H@*B!`<F5T=7)N('9O:60*("HO"F9U;F-T:6]N(%A-3%]2
M4$-?4V5R=F5R7V1E8G5G;7-G*"1M*0I["B`@("!G;&]B86P@)%A-3%]24$-?
M4V5R=F5R7V1E8G5G:6YF;SL*("`@("1834Q?4E!#7U-E<G9E<E]D96)U9VEN
M9F\@/2`D6$U,7U)00U]397)V97)?9&5B=6=I;F9O("X@)&T@+B`B7&XB.PI]
M"@H*+RHJ"B`J($$@<V5R=F5R(&9O<B!R96-E:79I;F<@86YD(')E<&QY:6YG
M('1O(%A-3"!24$,@<F5Q=65S=',*("H*("H@/&-O9&4^"B`J("1S97)V97(@
M/2!N97<@6$U,7U)00U]397)V97(H"B`J("`@("!A<G)A>2@*("H@("`@("`@
M("`G:7-A;C@G(#T^"B`J("`@("`@("`@("`@(&%R<F%Y*`H@*B`@("`@("`@
M("`@("`@("`@)V9U;F-T:6]N)R`]/B`G:7-?."<L"B`J("`@("`@("`@("`@
M("`@("`G<VEG;F%T=7)E)R`]/@H@*B`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@*("H@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=B;V]L
M96%N)RP@)VEN="<I+`H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)V)O;VQE86XG+"`G:6YT)RP@)V)O;VQE86XG*2P*("H@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"=B;V]L96%N)RP@)W-T<FEN9R<I+`H@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V)O;VQE86XG+"`G
M<W1R:6YG)RP@)V)O;VQE86XG*2P*("H@("`@("`@("`@("`@("`@("`@("`@
M*2P*("H@("`@("`@("`@("`@("`@("=D;V-S=')I;F<G(#T^("=)<R!T:&4@
M=F%L=64@86X@.#\G"B`J("`@("`@("`@("`@("DL"B`J("`@("`I+`H@*B`@
M("`@,2P*("H@("`@(#`*("H@*3L@"B`J(#PO8V]D93X*("H*("H@0&-A=&5G
M;W)Y("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E("`@(%A-3%]24$,*("H@
M0&%U=&AO<B`@("`@161D($1U;6)I;&P@/&5D9$!U<V5F=6QI;F,N8V]M/@H@
M*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W1I9T!P:'`N;F5T/@H@*B!`
M875T:&]R("`@("!-87)T:6X@2F%N<V5N(#QM:D!P:'`N;F5T/@H@*B!`875T
M:&]R("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J
M($!C;W!Y<FEG:'0@(#$Y.3DM,C`P,2!%9&0@1'5M8FEL;"P@,C`P,2TR,#`U
M(%1H92!02%`@1W)O=7`*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+C@*
M("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+UA-
M3%]24$,*("HO"F-L87-S(%A-3%]24$-?4V5R=F5R"GL*("`@("\J*@H@("`@
M("H@5&AE(&1I<W!A=&-H(&UA<"P@;&ES=&EN9R!T:&4@;65T:&]D<R!T:&ES
M('-E<G9E<B!P<F]V:61E<RX*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1D;6%P(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1H92!P
M<F5S96YT(')E<W!O;G-E)W,@96YC;V1I;F<*("`@("`J($!V87(@<W1R:6YG
M"B`@("`@*B!`<V5E(%A-3%]24$-?365S<V%G93HZ9V5T16YC;V1I;F<H*0H@
M("`@("HO"B`@("!V87(@)&5N8V]D:6YG(#T@)R<["@H@("`@+RHJ"B`@("`@
M*B!$96)U9R!M;V1E("@P(#T@;V9F+"`Q(#T@;VXI"B`@("`@*B!`=F%R(&EN
M=&5G97(*("`@("`J+PH@("`@=F%R("1D96)U9R`](#`["@H@("`@+RHJ"B`@
M("`@*B!4:&4@<F5S<&]N<V4G<R!(5%10(&AE861E<G,*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D<V5R=F5R7VAE861E<G,@/2`G)SL*
M"B`@("`O*BH*("`@("`J(%1H92!R97-P;VYS92=S(%A-3"!P87EL;V%D"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)'-E<G9E<E]P87EL
M;V%D(#T@)R<["@H*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(@9F]R('1H
M92!834Q?4E!#7U-E<G9E<B!C;&%S<PH@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`D9&ES<$UA<"`@('1H92!D:7-P871C:"!M87`N($%N(&%S<V]C:6%T
M:79E(&%R<F%Y"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@97AP
M;&%I;FEN9R!E86-H(&9U;F-T:6]N+B!4:&4@:V5Y<R!O9B!T:&4@;6%I;@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y(&%R92!T:&4@
M<')O8V5D=7)E(&YA;65S('5S960@8GD@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@8VQI96YT<RX@5&AE('9A;'5E(&ES(&%N;W1H97(@
M87-S;V-I871I=F4@87)R87D*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("!T:&%T(&-O;G1A:6YS('5P('1O('1H<F5E(&5L96UE;G1S.@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@*R!4:&4@)V9U;F-T:6]N
M)R!E;&5M96YT)W,@=F%L=64@:7,@=&AE(&YA;64*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@;V8@=&AE(&9U;F-T:6]N(&]R(&UE=&AO
M9"!T:&%T(&=E=',@8V%L;&5D+@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!4;R!D969I;F4@82!C;&%S<R<@;65T:&]D.B`G8VQA<W,Z
M.FUE=&AO9"<N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`K
M(%1H92`G<VEG;F%T=7)E)R!E;&5M96YT("AO<'1I;VYA;"D@:7,@86X*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87D@9&5S8W)I
M8FEN9R!T:&4@<F5T=7)N('9A;'5E<R!A;F0*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@<&%R86UE=&5R<PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@*R!4:&4@)V1O8W-T<FEN9R<@96QE;65N="`H
M;W!T:6]N86PI(&ES(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<W1R:6YG(&1E<V-R:6)I;F<@=VAA="!T:&4@;65T:&]D(&1O97,*
M("`@("`J($!P87)A;2!I;G0@)'-E<G9I8V5.;W<@('-H;W5L9"!T:&4@2%14
M4"!R97-P;VYS92!B92!S96YT(&YO=S\*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`H,2`]('EE<RP@,"`](&YO*0H@("`@("H@0'!A<F%M(&EN
M="`D9&5B=6<@("`@("`@<VAO=6QD(&1E8G5G(&]U='!U="!B92!D:7-P;&%Y
M960_"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@*#$@/2!Y97,L
M(#`@/2!N;RD*("`@("`J"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@
M("`@9G5N8W1I;VX@6$U,7U)00U]397)V97(H)&1I<W!-87`L("1S97)V:6-E
M3F]W(#T@,2P@)&1E8G5G(#T@,"D*("`@('L*("`@("`@("!G;&]B86P@)$A4
M5%!?4D%77U!/4U1?1$%403L*"B`@("`@("`@:68@*"1D96)U9RD@>PH@("`@
M("`@("`@("`D=&AI<RT^9&5B=6<@/2`Q.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1T:&ES+3YD96)U9R`](#`["B`@("`@("`@?0H*("`@("`@
M("`D=&AI<RT^9&UA<"`]("1D:7-P36%P.PH*("`@("`@("!I9B`H)'-E<G9I
M8V5.;W<I('L*("`@("`@("`@("`@)'1H:7,M/G-E<G9I8V4H*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^8W)E871E4V5R=F5R4&%Y
M;&]A9"@I.PH@("`@("`@("`@("`D=&AI<RT^8W)E871E4V5R=F5R2&5A9&5R
M<R@I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($!R971U<FX@
M<W1R:6YG("!T:&4@9&5B=6<@:6YF;W)M871I;VX@:68@9&5B=6<@9&5B=6<@
M;6]D92!I<R!O;@H@("`@("HO"B`@("!F=6YC=&EO;B!S97)I86QI>F5$96)U
M9R@I"B`@("!["B`@("`@("`@9VQO8F%L("1834Q?4E!#7U-E<G9E<E]D96)U
M9VEN9F\L("1(5%107U)!5U]03U-47T1!5$$["@H@("`@("`@(&EF("@D=&AI
M<RT^9&5B=6<I('L*("`@("`@("`@("`@6$U,7U)00U]397)V97)?9&5B=6=M
M<V<H)W9V=B!03U-4($1!5$$@4D5#14E6140@0ED@4T525D52('9V=B<@+B`B
M7&XB"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)$A4
M5%!?4D%77U!/4U1?1$%400H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`N(")<;B(@+B`G7EY>($5.1"!03U-4($1!5$$@7EY>)RD["B`@
M("`@("`@?0H*("`@("`@("!I9B`H)%A-3%]24$-?4V5R=F5R7V1E8G5G:6YF
M;R`A/2`G)RD@>PH@("`@("`@("`@("!R971U<FX@(CPA+2T@4$5!4B!834Q?
M4E!#(%-%4E9%4B!$14)51R!)3D9/.EQN7&XB"B`@("`@("`@("`@("`@("`@
M("`N('!R96=?<F5P;&%C92@G+RTH/STM*2\G+"`G+2`G+"`D6$U,7U)00U]3
M97)V97)?9&5B=6=I;F9O*0H@("`@("`@("`@("`@("`@("`@+B`B+2T^7&XB
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!396YD<R!T:&4@<F5S<&]N
M<V4*("`@("`J"B`@("`@*B!4:&4@96YC;V1I;F<@86YD(&-O;G1E;G0M='EP
M92!A<F4@9&5T97)M:6YE9"!B>0H@("`@("H@6$U,7U)00U]-97-S86=E.CIG
M971%;F-O9&EN9R@I"B`@("`@*@H@("`@("H@0')E='5R;B!V;VED"B`@("`@
M*@H@("`@("H@0'5S97,@6$U,7U)00U]397)V97(Z.F-R96%T95-E<G9E<E!A
M>6QO860H*2P*("`@("`J("`@("`@(%A-3%]24$-?4V5R=F5R.CIC<F5A=&53
M97)V97)(96%D97)S*"D*("`@("`J+PH@("`@9G5N8W1I;VX@<V5R=FEC92@I
M"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^<V5R=F5R7W!A>6QO860I('L*
M("`@("`@("`@("`@)'1H:7,M/F-R96%T95-E<G9E<E!A>6QO860H*3L*("`@
M("`@("!]"B`@("`@("`@:68@*"$D=&AI<RT^<V5R=F5R7VAE861E<G,I('L*
M("`@("`@("`@("`@)'1H:7,M/F-R96%T95-E<G9E<DAE861E<G,H*3L*("`@
M("`@("!]"@H@("`@("`@("\J"B`@("`@("`@("H@)'-E<G9E<E]H96%D97)S
M(&YE961S('1O(')E;6%I;B!A('-T<FEN9R!F;W(@8V]M<&%T:6)I;&ET>2!W
M:71H"B`@("`@("`@("H@;VQD('-C<FEP=',@=7-I;F<@=&AI<R!P86-K86=E
M+"!B=70@4$A0(#0N-"XR(&YO(&QO;F=E<B!A;&QO=W,*("`@("`@("`@*B!L
M:6YE(&)R96%K<R!I;B!H96%D97(H*2!C86QL<RX@(%-O+"!W92!S<&QI="!E
M86-H(&AE861E<B!I;G1O"B`@("`@("`@("H@86X@:6YD:79I9'5A;"!C86QL
M+B`@5&AE(&EN:71I86P@<F5P;&%C92!H86YD;&5S('1H92!O9F8@8VAA;F-E
M"B`@("`@("`@("H@=&AA="!S;VUE;VYE(&-O;7!O<V5D(&$@<VEN9VQE(&AE
M861E<B!W:71H(&UU;'1I<&QE(&QI;F5S+"!W:&EC:`H@("`@("`@("`J('1H
M92!21D-S(&%L;&]W+@H@("`@("`@("`J+PH@("`@("`@("1T:&ES+3YS97)V
M97)?:&5A9&5R<R`]('!R96=?<F5P;&%C92@B+UM<<EQN72M;(%QT72LO(BP@
M)R`G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!T<FEM*"1T:&ES+3YS97)V97)?:&5A9&5R<RDI.PH@("`@("`@("1H
M96%D97)S(#T@<')E9U]S<&QI="@B+UM<<EQN72LO(BP@)'1H:7,M/G-E<G9E
M<E]H96%D97)S*3L*("`@("`@("!F;W)E86-H("@D:&5A9&5R<R!A<R`D:&5A
M9&5R*0H@("`@("`@('L*("`@("`@("`@("`@:&5A9&5R*"1H96%D97(I.PH@
M("`@("`@('T*"B`@("`@("`@<')I;G0@)'1H:7,M/G-E<G9E<E]P87EL;V%D
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5N97)A=&5S('1H92!P87EL;V%D
M(&%N9"!P=71S(&ET(&EN('1H92`D<V5R=F5R7W!A>6QO860@<')O<&5R='D*
M("`@("`J"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J"B`@("`@*B!`=7-E
M<R!834Q?4E!#7U-E<G9E<CHZ<&%R<V5297%U97-T*"DL(%A-3%]24$-?4V5R
M=F5R.CHD96YC;V1I;F<L"B`@("`@*B`@("`@("!834Q?4E!#7U)E<W!O;G-E
M.CIS97)I86QI>F4H*2P@6$U,7U)00U]397)V97(Z.G-E<FEA;&EZ941E8G5G
M*"D*("`@("`J+PH@("`@9G5N8W1I;VX@8W)E871E4V5R=F5R4&%Y;&]A9"@I
M"B`@("!["B`@("`@("`@)'(@/2`D=&AI<RT^<&%R<V5297%U97-T*"D["B`@
M("`@("`@)'1H:7,M/G-E<G9E<E]P87EL;V%D(#T@)SP_>&UL('9E<G-I;VX]
M(C$N,"(@96YC;V1I;F<](B<*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+B`D=&AI<RT^96YC;V1I;F<@+B`G(C\^)R`N(")<;B(*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@+B`D=&AI<RT^<V5R:6%L:7IE1&5B=6<H
M*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("1R+3YS97)I86QI
M>F4H*3L*("`@('T*"B`@("`O*BH*("`@("`J($1E=&5R;6EN97,@=&AE($A4
M5%`@:&5A9&5R<R!A;F0@<'5T<R!T:&5M(&EN('1H92`D<V5R=F5R7VAE861E
M<G,*("`@("`J('!R;W!E<G1Y"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M96%N("!44E5%(&EF(&]K87DL($9!3%-%(&EF("1S97)V97)?<&%Y;&]A9"!I
M<VXG="!S970N"B`@("`@*@H@("`@("H@0'5S97,@6$U,7U)00U]397)V97(Z
M.F-R96%T95-E<G9E<E!A>6QO860H*2P*("`@("`J("`@("`@(%A-3%]24$-?
M4V5R=F5R.CHD<V5R=F5R7VAE861E<G,*("`@("`J+PH@("`@9G5N8W1I;VX@
M8W)E871E4V5R=F5R2&5A9&5R<R@I"B`@("!["B`@("`@("`@:68@*"$D=&AI
M<RT^<V5R=F5R7W!A>6QO860I('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^<V5R=F5R7VAE861E<G,@/2`G
M0V]N=&5N="U,96YG=&@Z("<*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+B!S=')L96XH)'1H:7,M/G-E<G9E<E]P87EL;V%D*2`N(")<<EQN(@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("=#;VYT96YT+51Y<&4Z
M('1E>'0O>&UL.R<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G
M(&-H87)S970])R`N("1T:&ES+3YE;F-O9&EN9SL*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($!R971U<FX@87)R87D*("`@
M("`J+PH@("`@9G5N8W1I;VX@=F5R:69Y4VEG;F%T=7)E*"1I;BP@)'-I9RD*
M("`@('L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'-I9RD[
M("1I*RLI('L*("`@("`@("`@("`@+R\@8VAE8VL@96%C:"!P;W-S:6)L92!S
M:6=N871U<F4@:6X@='5R;@H@("`@("`@("`@("`D8W5R<VEG(#T@)'-I9ULD
M:5T["B`@("`@("`@("`@(&EF("AS:7IE;V8H)&-U<G-I9RD@/3T@)&EN+3YG
M971.=6U087)A;7,H*2`K(#$I('L*("`@("`@("`@("`@("`@("1I='-/2R`]
M(#$["B`@("`@("`@("`@("`@("!F;W(@*"1N(#T@,#L@)&X@/"`D:6XM/F=E
M=$YU;5!A<F%M<R@I.R`D;BLK*2!["B`@("`@("`@("`@("`@("`@("`@)'`@
M/2`D:6XM/F=E=%!A<F%M*"1N*3L*("`@("`@("`@("`@("`@("`@("`O+R!P
M<FEN="`B/"$M+2`D<"`M+3Y<;B(["B`@("`@("`@("`@("`@("`@("`@:68@
M*"1P+3YK:6YD3V8H*2`]/2`G<V-A;&%R)RD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D<'0@/2`D<"T^<V-A;&%R='EP*"D["B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)'!T(#T@
M)'`M/FMI;F1/9B@I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`O+R`D;BLQ(&%S(&9I<G-T('1Y<&4@;V8@<VEG(&ES(')E
M='5R;B!T>7!E"B`@("`@("`@("`@("`@("`@("`@:68@*"1P="`A/2`D8W5R
M<VEG6R1N*S%=*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1I='-/2R`]
M(#`["B`@("`@("`@("`@("`@("`@("`@("`@("1P;F\@/2`D;BLQ.PH@("`@
M("`@("`@("`@("`@("`@("`@("`D=V%N=&5D(#T@)&-U<G-I9ULD;BLQ73L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&=O="`]("1P=#L*("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"1I='-/2RD@
M>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>2@Q*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I
M9B`H:7-S970H)'=A;G1E9"DI('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y
M*#`L(")786YT960@)'MW86YT961]+"!G;W0@)'MG;W1](&%T('!A<F%M("1[
M<&YO?2(I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1A;&QO=V5D
M(#T@87)R87DH*3L*("`@("`@("`@("`@9F]R96%C:"`H)'-I9R!A<R`D=F%L
M*2!["B`@("`@("`@("`@("`@("!E;F0H)'9A;"D["B`@("`@("`@("`@("`@
M("`D86QL;W=E9%M=(#T@:V5Y*"1V86PI.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1A;&QO=V5D(#T@87)R87E?=6YI<75E*"1A;&QO=V5D*3L*("`@
M("`@("`@("`@)&QA<W0@/2!C;W5N="@D86QL;W=E9"D@+2`Q.PH@("`@("`@
M("`@("!I9B`H)&QA<W0@/B`P*2!["B`@("`@("`@("`@("`@("`D86QL;W=E
M9%LD;&%S=%T@/2`G;W(@)R`N("1A;&QO=V5D6R1L87-T73L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!R971U<FX@87)R87DH,"P*("`@("`@("`@("`@
M("`@("`@("`@("`@("=3:6=N871U<F4@<&5R;6ET<R`G("X@:6UP;&]D92@G
M+"`G+"`D86QL;W=E9"D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`N("<@<&%R86UE=&5R<R!B=70@=&AE(')E<75E<W0@:&%D("<*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`N("1I;BT^9V5T3G5M4&%R86US
M*"DI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($!R971U<FX@
M;V)J96-T("!A(&YE=R!834Q?4E!#7U)E<W!O;G-E(&]B:F5C=`H@("`@("H*
M("`@("`J($!U<V5S(%A-3%]24$-?365S<V%G93HZ9V5T16YC;V1I;F<H*2P@
M6$U,7U)00U]397)V97(Z.B1E;F-O9&EN9PH@("`@("HO"B`@("!F=6YC=&EO
M;B!P87)S95)E<75E<W0H)&1A=&$@/2`G)RD*("`@('L*("`@("`@("!G;&]B
M86P@)%A-3%]24$-?>&@L("1(5%107U)!5U]03U-47T1!5$$L"B`@("`@("`@
M("`@("`@("`D6$U,7U)00U]E<G(L("1834Q?4E!#7W-T<BP@)%A-3%]24$-?
M97)R>&UL+`H@("`@("`@("`@("`@("`@)%A-3%]24$-?9&5F96YC;V1I;F<L
M("1834Q?4E!#7U-E<G9E<E]D;6%P.PH*("`@("`@("!I9B`H)&1A=&$@/3T@
M)R<I('L*("`@("`@("`@("`@)&1A=&$@/2`D2%144%]205=?4$]35%]$051!
M.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/F5N8V]D:6YG(#T@6$U,7U)0
M0U]-97-S86=E.CIG971%;F-O9&EN9R@D9&%T82D["B`@("`@("`@)'!A<G-E
M<E]R97-O=7)C92`]('AM;%]P87)S97)?8W)E871E*"1T:&ES+3YE;F-O9&EN
M9RD["B`@("`@("`@)'!A<G-E<B`]("AI;G0I("1P87)S97)?<F5S;W5R8V4[
M"@H@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=(#T@87)R87DH*3L*("`@
M("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG8VTG72`@("`@/2`P.PH@("`@
M("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=I<V8G72`@("`](#`["B`@("`@
M("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W!A<F%M<R==(#T@87)R87DH*3L*
M("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG;65T:&]D)UT@/2`G)SL*
M("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG<W1A8VLG72`](&%R<F%Y
M*"D["0H@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=V86QU97-T86-K
M)UT@/2!A<G)A>2@I.PD*"B`@("`@("`@)'!L:7-T(#T@)R<["@H@("`@("`@
M("\O(&1E8V]M<&]S92!I;F-O;6EN9R!834P@:6YT;R!R97%U97-T('-T<G5C
M='5R90H*("`@("`@("!X;6Q?<&%R<V5R7W-E=%]O<'1I;VXH)'!A<G-E<E]R
M97-O=7)C92P@6$U,7T]05$E/3E]#05-%7T9/3$1)3D<L('1R=64I.PH@("`@
M("`@('AM;%]S971?96QE;65N=%]H86YD;&5R*"1P87)S97)?<F5S;W5R8V4L
M("=834Q?4E!#7W-E)RP@)UA-3%]24$-?964G*3L*("`@("`@("!X;6Q?<V5T
M7V-H87)A8W1E<E]D871A7VAA;F1L97(H)'!A<G-E<E]R97-O=7)C92P@)UA-
M3%]24$-?8V0G*3L*("`@("`@("!I9B`H(7AM;%]P87)S92@D<&%R<V5R7W)E
M<V]U<F-E+"`D9&%T82P@,2DI('L*("`@("`@("`@("`@+R\@<F5T=7)N(%A-
M3"!E<G)O<B!A<R!A(&9A=6QT0V]D90H@("`@("`@("`@("`D<B`](&YE=R!8
M34Q?4E!#7U)E<W!O;G-E*#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)%A-3%]24$-?97)R>&UL*WAM;%]G971?97)R;W)?8V]D
M92@D<&%R<V5R7W)E<V]U<F-E*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!S<')I;G1F*"=834P@97)R;W(Z("5S(&%T(&QI;F4@
M)60G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@>&UL7V5R<F]R7W-T<FEN9RAX;6Q?9V5T7V5R<F]R7V-O9&4H)'!A
M<G-E<E]R97-O=7)C92DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@>&UL7V=E=%]C=7)R96YT7VQI;F5?;G5M8F5R
M*"1P87)S97)?<F5S;W5R8V4I*2D["B`@("`@("`@("`@('AM;%]P87)S97)?
M9G)E92@D<&%R<V5R7W)E<V]U<F-E*3L*("`@("`@("!](&5L<V5I9B`H)%A-
M3%]24$-?>&A;)'!A<G-E<EU;)VES9B==/C$I('L*("`@("`@("`@("`@)'(@
M/2!N97<@6$U,7U)00U]297-P;VYS92@P+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1834Q?4E!#7V5R<ELG:6YV86QI9%]R97%U
M97-T)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)%A-3%]24$-?<W1R6R=I;G9A;&ED7W)E<75E<W0G70H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("X@)SH@)PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("X@)%A-3%]24$-?>&A;)'!A<G-E
M<EU;)VES9E]R96%S;VXG72D["B`@("`@("`@("`@('AM;%]P87)S97)?9G)E
M92@D<&%R<V5R7W)E<V]U<F-E*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!X;6Q?<&%R<V5R7V9R964H)'!A<G-E<E]R97-O=7)C92D["B`@("`@
M("`@("`@("1M(#T@;F5W(%A-3%]24$-?365S<V%G92@D6$U,7U)00U]X:%LD
M<&%R<V5R75LG;65T:&]D)UTI.PH@("`@("`@("`@("`O+R!N;W<@861D('!A
M<F%M971E<G,@:6X*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ
M96]F*"1834Q?4E!#7WAH6R1P87)S97)=6R=P87)A;7,G72D[("1I*RLI('L*
M("`@("`@("`@("`@("`@("\O('!R:6YT("<\(2TM("<@+B`D6$U,7U)00U]X
M:%LD<&%R<V5R75LG<&%R86US)UU;)&E=+B`B+2T^7&XB.PH@("`@("`@("`@
M("`@("`@)'!L:7-T("X]("(D:2`M("(@+B!V87)?97AP;W)T*"1834Q?4E!#
M7WAH6R1P87)S97)=6R=P87)A;7,G75LD:5TL('1R=64I("X@(B!<;B(["B`@
M("`@("`@("`@("`@("`D;2T^861D4&%R86TH)%A-3%]24$-?>&A;)'!A<G-E
M<EU;)W!A<F%M<R==6R1I72D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M(&EF("@D=&AI<RT^9&5B=6<I('L*("`@("`@("`@("`@("`@(%A-3%]24$-?
M4V5R=F5R7V1E8G5G;7-G*"1P;&ES="D["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("\O(&YO=R!T;R!D96%L('=I=&@@=&AE(&UE=&AO9`H@("`@("`@
M("`@("`D;65T:$YA;64@/2`D6$U,7U)00U]X:%LD<&%R<V5R75LG;65T:&]D
M)UT["B`@("`@("`@("`@(&EF("AS=')P;W,H)&UE=&A.86UE+"`G<WES=&5M
M+B<I(#T]/2`P*2!["B`@("`@("`@("`@("`@("`D9&UA<"`]("1834Q?4E!#
M7U-E<G9E<E]D;6%P.PH@("`@("`@("`@("`@("`@)'-Y<T-A;&P@/2`Q.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&1M87`@/2`D
M=&AI<RT^9&UA<#L*("`@("`@("`@("`@("`@("1S>7-#86QL(#T@,#L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@:68@*&ES<V5T*"1D;6%P6R1M971H
M3F%M95U;)V9U;F-T:6]N)UTI"B`@("`@("`@("`@("`@("`F)B!I<U]S=')I
M;F<H)&1M87!;)&UE=&A.86UE75LG9G5N8W1I;VXG72D*("`@("`@("`@("`@
M("`@("8F('-T<G!O<R@D9&UA<%LD;65T:$YA;65=6R=F=6YC=&EO;B==+"`G
M.CHG*2`A/3T@9F%L<V4I"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@
M("1D;6%P6R1M971H3F%M95U;)V9U;F-T:6]N)UT@/0H@("`@("`@("`@("`@
M("`@("`@("`@("!E>'!L;V1E*"<Z.B<L("1D;6%P6R1M971H3F%M95U;)V9U
M;F-T:6]N)UTI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H:7-S
M970H)&1M87!;)&UE=&A.86UE75LG9G5N8W1I;VXG72D*("`@("`@("`@("`@
M("`@("8F(&ES7V-A;&QA8FQE*"1D;6%P6R1M971H3F%M95U;)V9U;F-T:6]N
M)UTI*0H@("`@("`@("`@("!["B`@("`@("`@("`@("`@("`O+R!D:7-P871C
M:"!I9B!E>&ES=',*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&UA<%LD
M;65T:$YA;65=6R=S:6=N871U<F4G72DI('L*("`@("`@("`@("`@("`@("`@
M("`D<W(@/2`D=&AI<RT^=F5R:69Y4VEG;F%T=7)E*"1M+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1M87!;
M)&UE=&A.86UE75LG<VEG;F%T=7)E)UT@*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&1M87!;)&UE=&A.86UE75LG
M<VEG;F%T=7)E)UTI('Q\("1S<ELP72D@>PH@("`@("`@("`@("`@("`@("`@
M("\O(&EF(&YO('-I9VYA='5R92!O<B!C;W)R96-T('-I9VYA='5R90H@("`@
M("`@("`@("`@("`@("`@(&EF("@D<WES0V%L;"D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D<B`](&-A;&Q?=7-E<E]F=6YC*"1D;6%P6R1M971H3F%M
M95U;)V9U;F-T:6]N)UTL("1T:&ES+"`D;2D["B`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)'(@/2!C86QL
M7W5S97)?9G5N8R@D9&UA<%LD;65T:$YA;65=6R=F=6YC=&EO;B==+"`D;2D[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&EF
M("@A:7-?82@D<BP@)UA-3%]24$-?4F5S<&]N<V4G*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D<B`](&YE=R!834Q?4E!#7U)E<W!O;G-E*#`L("18
M34Q?4E!#7V5R<ELG;F]T7W)E<W!O;G-E7V]B:F5C="==+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1834Q?
M4E!#7W-T<ELG;F]T7W)E<W!O;G-E7V]B:F5C="==*3L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1R(#T@;F5W(%A-3%]24$-?4F5S<&]N<V4H,"P@)%A-3%]2
M4$-?97)R6R=I;F-O<G)E8W1?<&%R86US)UTL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D6$U,7U)00U]S=');)VEN
M8V]R<F5C=%]P87)A;7,G70H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+B`G.B`G("X@)'-R6S%=*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("\O(&5L<V4@<')E<&%R92!E<G)O<B!R97-P;VYS90H@("`@("`@("`@("`@
M("`@)'(@/2!N97<@6$U,7U)00U]297-P;VYS92@P+"`D6$U,7U)00U]E<G);
M)W5N:VYO=VY?;65T:&]D)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1834Q?4E!#7W-T<ELG=6YK;F]W;E]M971H;V0G
M72D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R
M.PH@("`@?0H*("`@("\J*@H@("`@("H@16-H;W,@8F%C:R!T:&4@:6YP=70@
M<&%C:V5T(&%S(&$@<W1R:6YG('9A;'5E"B`@("`@*@H@("`@("H@0')E='5R
M;B!V;VED"B`@("`@*@H@("`@("H@57-E9G5L(&9O<B!D96)U9V=I;F<N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&5C:&]);G!U="@I"B`@("!["B`@("`@("`@
M9VQO8F%L("1(5%107U)!5U]03U-47T1!5$$["@H@("`@("`@("1R(#T@;F5W
M(%A-3%]24$-?4F5S<&]N<V4H,"D["B`@("`@("`@)'(M/GAV(#T@;F5W(%A-
M3%]24$-?5F%L=64H(B=!:&$@<V%I9"!).B`G(B`N("1(5%107U)!5U]03U-4
M7T1!5$$L("=S=')I;F<G*3L*("`@("`@("!P<FEN="`D<BT^<V5R:6%L:7IE
M*"D["B`@("!]"GT*"B\J"B`J($QO8V%L('9A<FEA8FQE<SH*("H@=&%B+7=I
M9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J(&,M:&%N9VEN9RUC;VUM
M96YT+65N9&5R+7`Z(&YI;`H@*B!%;F0Z"B`J+PH*/SX*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+UA-3"]24$,O1'5M<"YP:'``
M````````````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3(P-S0@
M,3`U,34T,S,W,S$@,#(Q,3<R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"@HO*B!V:6TZ('-E="!E>'!A;F1T86(@
M=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PH*+RHJ
M"B`J($9U;F-T:6]N(&%N9"!C;&%S<R!T;R!D=6UP(%A-3%]24$-?5F%L=64@
M;V)J96-T<R!I;B!A(&YI8V4@=V%Y"B`J"B`J(%-H;W5L9"!B92!H96QP9G5L
M(&%S(&$@;F]R;6%L('9A<E]D=6UP*"XN*2!D:7-P;&%Y<R!A;&P@:6YT97)N
M86QS('=H:6-H"B`J(&1O97-N)W0@<F5A;&QY(&=I=F4@>6]U(&%N(&]V97)V
M:65W(&1U92!T;R!T;V\@;75C:"!I;F9O<FUA=&EO;BX*("H*("H@0&-A=&5G
M;W)Y("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E("`@(%A-3%]24$,*("H@
M0&%U=&AO<B`@("`@0VAR:7-T:6%N(%=E:7-K92`\8W=E:7-K94!P:'`N;F5T
M/@H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@1'5M<"YP:'`L=B`Q+C<@,C`P
M-2\P,2\R-"`P,SHT-SHU-2!D86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]834Q?4E!#"B`J+PH*"B\J
M*@H@*B!0=6QL(&EN('1H92!834Q?4E!#(&-L87-S"B`J+PIR97%U:7)E7V]N
M8V4@)UA-3"]24$,N<&AP)SL*"@HO*BH*("H@1V5N97)A=&5S('1H92!D=6UP
M(&]F('1H92!834Q?4E!#7U9A;'5E(&%N9"!E8VAO97,@:70*("H*("H@0'!A
M<F%M(&]B:F5C="`D=F%L=64@('1H92!834Q?4E!#7U9A;'5E(&]B:F5C="!T
M;R!D=6UP"B`J"B`J($!R971U<FX@=F]I9`H@*B\*9G5N8W1I;VX@6$U,7U)0
M0U]$=6UP*"1V86QU92D*>PH@("`@)&1U;7!E<B`](&YE=R!834Q?4E!#7T1U
M;7`H*3L*("`@(&5C:&\@)&1U;7!E<BT^9V5N97)A=&5$=6UP*"1V86QU92D[
M"GT*"@HO*BH*("H@0VQA<W,@=VAI8V@@9V5N97)A=&5S(&$@9'5M<"!O9B!A
M(%A-3%]24$-?5F%L=64@;V)J96-T"B`J"B`J($!C871E9V]R>2`@(%=E8B!3
M97)V:6-E<PH@*B!`<&%C:V%G92`@("!834Q?4E!#"B`J($!A=71H;W(@("`@
M($-H<FES=&EA;B!796ES:V4@/&-W96ES:V5`<&AP+FYE=#X*("H@0'9E<G-I
M;VX@("`@4F5L96%S93H@,2XT+C@*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E
M87(N<&AP+FYE="]P86-K86=E+UA-3%]24$,*("HO"F-L87-S(%A-3%]24$-?
M1'5M<`I["B`@("`O*BH*("`@("`J(%1H92!I;F1E;G1A=&EO;B!A<G)A>2!C
M86-H90H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&%R26YD
M96YT("`@("`@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@5&AE('-P86-E
M<R!U<V5D(&9O<B!I;F1E;G1I;F<@=&AE(%A-3`H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1S=')"87-E26YD96YT(#T@)R`@("`G.PH*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@9'5M<"!I;B!834P@9F]R;6%T
M('=I=&AO=70@<')I;G1I;F<@:70@;W5T"B`@("`@*@H@("`@("H@0'!A<F%M
M(&]B:F5C="`D=F%L=64@("!T:&4@6$U,7U)00U]686QU92!O8FIE8W0@=&\@
M9'5M<`H@("`@("H@0'!A<F%M(&EN="`@("`D;DQE=F5L("!T:&4@;&5V96P@
M;V8@:6YD96YT871I;VX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M=&AE(&1U;7`*("`@("`J+PH@("`@9G5N8W1I;VX@9V5N97)A=&5$=6UP*"1V
M86QU92P@)&Y,979E;"`](#`I"B`@("!["B`@("`@("`@:68@*"%I<U]O8FIE
M8W0H)'9A;'5E*2`F)B!G971?8VQA<W,H)'9A;'5E*2`A/2`G>&UL7W)P8U]V
M86QU92<I('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+G!H<"<[
M"B`@("`@("`@("`@(%!%05(Z.G)A:7-E17)R;W(H)U1R:65D('1O(&1U;7`@
M;F]N+5A-3%]24$-?5F%L=64@=F%R:6%B;&4G("X@(EQR7&XB+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#`L(%!%05)?15)23U)?4%))3E0I.PH@
M("`@("`@("`@("!I9B`H:7-?;V)J96-T*"1V86QU92DI('L*("`@("`@("`@
M("`@("`@("1S=')4>7!E(#T@9V5T7V-L87-S*"1V86QU92D["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<W1R5'EP92`](&=E='1Y
M<&4H)'9A;'5E*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/F=E=$EN9&5N="@D;DQE=F5L*2`N("=.3U0@02!834Q?4E!#7U9A
M;'5E.B`G"B`@("`@("`@("`@("`@("`@("`N("1S=')4>7!E("X@(EQR7&XB
M.PH@("`@("`@('T*"B`@("`@("`@<W=I=&-H("@D=F%L=64M/FMI;F1/9B@I
M*2!["B`@("`@("`@8V%S92`G<W1R=6-T)SH*("`@("`@("`@("`@)')E="`]
M("1T:&ES+3YG96Y3=')U8W0H)'9A;'5E+"`D;DQE=F5L*3L*("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@8V%S92`G87)R87DG.@H@("`@("`@("`@("`D
M<F5T(#T@)'1H:7,M/F=E;D%R<F%Y*"1V86QU92P@)&Y,979E;"D["B`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@(&-A<V4@)W-C86QA<B<Z"B`@("`@("`@
M("`@("1R970@/2`D=&AI<RT^9V5N4V-A;&%R*"1V86QU92T^<V-A;&%R=F%L
M*"DL("1N3&5V96PI.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!D969A
M=6QT.@H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*("`@
M("`@("`@("`@4$5!4CHZ<F%I<V5%<G)O<B@G26QL96=A;"!T>7!E("(G("X@
M)'9A;'5E+3YK:6YD3V8H*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("X@)R(@:6X@6$U,7U)00U]686QU92<@+B`B7')<;B(L(#`L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@4$5!4E]%4E)/4E]04DE.5"D["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)')E=#L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE('-C86QA<B!V86QU92!D=6UP"B`@("`@*@H@("`@
M("H@0'!A<F%M(&]B:F5C="`D=F%L=64@("!T:&4@<V-A;&%R(%A-3%]24$-?
M5F%L=64@;V)J96-T('1O(&1U;7`*("`@("`J($!P87)A;2!I;G0@("`@)&Y,
M979E;"`@=&AE(&QE=F5L(&]F(&EN9&5N=&%T:6]N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@($1U;7!E9"!V97)S:6]N(&]F('1H92!S8V%L87(@
M=F%L=64*("`@("`J+PH@("`@9G5N8W1I;VX@9V5N4V-A;&%R*"1V86QU92P@
M)&Y,979E;"D*("`@('L*("`@("`@("!I9B`H9V5T='EP92@D=F%L=64I(#T]
M("=O8FIE8W0G*2!["B`@("`@("`@("`@("1S=')#;&%S<R`]("<@)R`N(&=E
M=%]C;&%S<R@D=F%L=64I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1S=')#;&%S<R`]("<G.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H
M:7,M/F=E=$EN9&5N="@D;DQE=F5L*2`N(&=E='1Y<&4H)'9A;'5E*2`N("1S
M=')#;&%S<PH@("`@("`@("`@("`@("`N("<@)R`N("1V86QU92`N(")<<EQN
M(CL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&1U;7`@;V8@
M82!S=')U8W0*("`@("`J"B`@("`@*B!`<&%R86T@;V)J96-T("1V86QU92`@
M('1H92!S=')U8W0@6$U,7U)00U]686QU92!O8FIE8W0@=&\@9'5M<`H@("`@
M("H@0'!A<F%M(&EN="`@("`D;DQE=F5L("!T:&4@;&5V96P@;V8@:6YD96YT
M871I;VX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@1'5M<&5D('9E
M<G-I;VX@;V8@=&AE('-C86QA<B!V86QU90H@("`@("HO"B`@("!F=6YC=&EO
M;B!G96Y3=')U8W0H)'9A;'5E+"`D;DQE=F5L*0H@("`@>PH@("`@("`@("1V
M86QU92T^<W1R=6-T<F5S970H*3L*("`@("`@("`D<W1R3W5T<'5T(#T@)'1H
M:7,M/F=E=$EN9&5N="@D;DQE=F5L*2`N("=S=')U8W0G("X@(EQR7&XB.PH@
M("`@("`@('=H:6QE("AL:7-T*"1K97DL("1K97EV86PI(#T@)'9A;'5E+3YS
M=')U8W1E86-H*"DI('L*("`@("`@("`@("`@)'-T<D]U='!U="`N/2`D=&AI
M<RT^9V5T26YD96YT*"1N3&5V96P@*R`Q*2`N("1K97D@+B`B7')<;B(["B`@
M("`@("`@("`@("1S=')/=71P=70@+CT@)'1H:7,M/F=E;F5R871E1'5M<"@D
M:V5Y=F%L+"`D;DQE=F5L("L@,BD["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B`D<W1R3W5T<'5T.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&4@9'5M<"!O9B!A;B!A<G)A>0H@("`@("H*("`@("`J($!P87)A;2!O8FIE
M8W0@)'9A;'5E("`@=&AE(&%R<F%Y(%A-3%]24$-?5F%L=64@;V)J96-T('1O
M(&1U;7`*("`@("`J($!P87)A;2!I;G0@("`@)&Y,979E;"`@=&AE(&QE=F5L
M(&]F(&EN9&5N=&%T:6]N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M($1U;7!E9"!V97)S:6]N(&]F('1H92!S8V%L87(@=F%L=64*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5N07)R87DH)'9A;'5E+"`D;DQE=F5L*0H@("`@>PH@
M("`@("`@("1N4VEZ92`@("`@/2`D=F%L=64M/F%R<F%Y<VEZ92@I.PH@("`@
M("`@("1S=')/=71P=70@/2`D=&AI<RT^9V5T26YD96YT*"1N3&5V96PI("X@
M)V%R<F%Y)R`N(")<<EQN(CL*("`@("`@("!F;W(H)&Y!(#T@,#L@)&Y!(#P@
M)&Y3:7IE.R`D;D$K*RD@>PH@("`@("`@("`@("`D<W1R3W5T<'5T("X]("1T
M:&ES+3YG971);F1E;G0H)&Y,979E;"`K(#$I("X@)&Y!("X@(EQR7&XB.PH@
M("`@("`@("`@("`D<W1R3W5T<'5T("X]("1T:&ES+3YG96YE<F%T941U;7`H
M)'9A;'5E+3YA<G)A>6UE;2@D;D$I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&Y,979E;"`K(#(I.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)'-T<D]U='!U=#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE(&EN9&5N="!F;W(@82!S<&5C:69I8R!L979E
M;"!A;F0@8V%C:&5S(&ET(&9O<B!F87-T97(@=7-E"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN="`D;DQE=F5L("!T:&4@;&5V96P*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@=&AE(&EN9&5N=&5D('-T<FEN9PH@("`@("HO"B`@
M("!F=6YC=&EO;B!G971);F1E;G0H)&Y,979E;"D*("`@('L*("`@("`@("!I
M9B`H(6ES<V5T*"1T:&ES+3YA<DEN9&5N=%LD;DQE=F5L72DI('L*("`@("`@
M("`@("`@)'1H:7,M/F%R26YD96YT6R1N3&5V96Q=(#T@<W1R7W)E<&5A="@D
M=&AI<RT^<W1R0F%S94EN9&5N="P@)&Y,979E;"D["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D=&AI<RT^87));F1E;G1;)&Y,979E;%T["B`@("!]"GT*
M"B\J"B`J($QO8V%L('9A<FEA8FQE<SH*("H@=&%B+7=I9'1H.B`T"B`J(&,M
M8F%S:6,M;V9F<V5T.B`T"B`J(&,M:&%N9VEN9RUC;VUM96YT+65N9&5R+7`Z
M(&YI;`H@*B!%;F0Z"B`J+PH*/SX*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+UA-3"]087)S97(`````````````````````````````````````
M````````````````````````````````````````````,#`P-S4U(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S$@,#(P,S`Q`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O6$U,+U!A<G-E<B]3:6UP;&4N<&AP
M````````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R,#(P-"`Q,#4Q
M-30S,S<S,2`P,C(S,C``(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y
M.3<M,C`P-"!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O
M9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L
M960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD
M(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O
M<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED
M(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R
M92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O
M<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@
M?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C
M;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R.B!3=&5P:&%N(%-C:&UI
M9'0@/'-C:'-T0'!H<"UT;V]L<RYN970^("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED
M.B!3:6UP;&4N<&AP+'8@,2XV(#(P,#4O,#,O,C4@,3<Z,3,Z,3`@<V-H<W0@
M17AP("0*"B\J*@H@*B!3:6UP;&4@6$U,('!A<G-E<B!C;&%S<RX*("H*("H@
M5&AI<R!C;&%S<R!I<R!A('-I;7!L:69I960@=F5R<VEO;B!O9B!834Q?4&%R
M<V5R+@H@*B!);B!M;W-T(%A-3"!A<'!L:6-A=&EO;G,@=&AE(')E86P@86-T
M:6]N(&ES(&5X96-U=&5D+`H@*B!W:&5N(&$@8VQO<VEN9R!T86<@:7,@9F]U
M;F0N"B`J"B`J(%A-3%]087)S97)?4VEM<&QE(&%L;&]W<R!Y;W4@=&\@:G5S
M="!I;7!L96UE;G0@;VYE(&-A;&QB86-K"B`J(&9O<B!E86-H('1A9R!T:&%T
M('=I;&P@<F5C96EV92!T:&4@=&%G('=I=&@@:71S(&%T=')I8G5T97,*("H@
M86YD($-$871A"B`J"B`J($!C871E9V]R>2!834P*("H@0'!A8VMA9V4@6$U,
M7U!A<G-E<@H@*B!`875T:&]R("!3=&5P:&%N(%-C:&UI9'0@/'-C:'-T0'!H
M<"UT;V]L<RYN970^"B`J+PH*+RHJ"B`J(&)U:6QT(&]N(%A-3%]087)S97(*
M("HO"G)E<75I<F5?;VYC92`G6$U,+U!A<G-E<BYP:'`G.PH*+RHJ"B`J(%-I
M;7!L92!834P@<&%R<V5R(&-L87-S+@H@*@H@*B!4:&ES(&-L87-S(&ES(&$@
M<VEM<&QI9FEE9"!V97)S:6]N(&]F(%A-3%]087)S97(N"B`J($EN(&UO<W0@
M6$U,(&%P<&QI8V%T:6]N<R!T:&4@<F5A;"!A8W1I;VX@:7,@97AE8W5T960L
M"B`J('=H96X@82!C;&]S:6YG('1A9R!I<R!F;W5N9"X*("H*("H@6$U,7U!A
M<G-E<E]3:6UP;&4@86QL;W=S('EO=2!T;R!J=7-T(&EM<&QE;65N="!O;F4@
M8V%L;&)A8VL*("H@9F]R(&5A8V@@=&%G('1H870@=VEL;"!R96-E:79E('1H
M92!T86<@=VET:"!I=',@871T<FEB=71E<PH@*B!A;F0@0T1A=&$N"B`J"B`J
M(#QC;V1E/@H@*B!R97%U:7)E7V]N8V4@)RXN+U!A<G-E<B]3:6UP;&4N<&AP
M)SL*("H*("H@8VQA<W,@;7E087)S97(@97AT96YD<R!834Q?4&%R<V5R7U-I
M;7!L90H@*B!["B`J("`@("!F=6YC=&EO;B!M>5!A<G-E<B@I"B`J("`@("![
M"B`J("`@("`@("`D=&AI<RT^6$U,7U!A<G-E<E]3:6UP;&4H*3L*("H@("`@
M("!]"B`J(`H@*B`@("!F=6YC=&EO;B!H86YD;&5%;&5M96YT*"1N86UE+"`D
M871T<FEB<RP@)&1A=&$I"B`J("`@("!["B`J("`@("`@("`@<')I;G1F*"=H
M86YD;&4@)7,\8G(^)RP@)&YA;64I.PH@*B`@("`@?0H@*B!]"B`J(`H@*B`D
M<"`]("9N97<@;7E087)S97(H*3L*("H@"B`J("1R97-U;'0@/2`D<"T^<V5T
M26YP=71&:6QE*"=M>41O8RYX;6PG*3L*("H@)')E<W5L="`]("1P+3YP87)S
M92@I.PH@*B`\+V-O9&4^"B`J"B`J($!C871E9V]R>2!834P*("H@0'!A8VMA
M9V4@6$U,7U!A<G-E<@H@*B!`875T:&]R("!3=&5P:&%N(%-C:&UI9'0@/'-C
M:'-T0'!H<"UT;V]L<RYN970^"B`J+PIC;&%S<R!834Q?4&%R<V5R7U-I;7!L
M92!E>'1E;F1S(%A-3%]087)S97(*>PH@("`O*BH*("`@("H@96QE;65N="!S
M=&%C:PH@("`@*@H@("`@*B!`86-C97-S("`@<')I=F%T90H@("`@*B!`=F%R
M("`@("`@87)R87D*("`@("HO"B`@("!V87(@)%]E;%-T86-K(#T@87)R87DH
M*3L*"B`@("\J*@H@("`@*B!A;&P@8VAA<F%C=&5R(&1A=&$*("`@("H*("`@
M("H@0&%C8V5S<R`@('!R:79A=&4*("`@("H@0'9A<B`@("`@(&%R<F%Y"B`@
M("`J+PH@("`@=F%R("1?9&%T82`](&%R<F%Y*"D["@H@("`O*BH*("`@("H@
M96QE;65N="!D97!T:`H@("`@*@H@("`@*B!`86-C97-S("`@<')I=F%T90H@
M("`@*B!`=F%R("`@("`@:6YT96=E<@H@("`@*B\*("`@('9A<B`D7V1E<'1H
M(#T@,#L*"B`@("`O*BH*("`@("`J($UA<'!I;F<@9G)O;2!E>'!A="!H86YD
M;&5R(&9U;F-T:6]N('1O(&-L87-S(&UE=&AO9"X*("`@("`J"B`@("`@*B!`
M=F%R("!A<G)A>0H@("`@("HO"B`@("!V87(@)&AA;F1L97(@/2!A<G)A>2@*
M("`@("`@("`G9&5F875L=%]H86YD;&5R)R`@("`@("`@("`@("`@("`@("`]
M/B`G9&5F875L=$AA;F1L97(G+`H@("`@("`@("=P<F]C97-S:6YG7VEN<W1R
M=6-T:6]N7VAA;F1L97(G("`@(#T^("=P:4AA;F1L97(G+`H@("`@("`@("=U
M;G!A<G-E9%]E;G1I='E?9&5C;%]H86YD;&5R)R`@("`@(#T^("=U;G!A<G-E
M9$AA;F1L97(G+`H@("`@("`@("=N;W1A=&EO;E]D96-L7VAA;F1L97(G("`@
M("`@("`@("`@(#T^("=N;W1A=&EO;DAA;F1L97(G+`H@("`@("`@("=E>'1E
M<FYA;%]E;G1I='E?<F5F7VAA;F1L97(G("`@("`@(#T^("=E;G1I='ER969(
M86YD;&5R)PH@("`@*3L*("`@(`H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&%N
M(%A-3"!P87)S97(N"B`@("`@*@H@("`@("H@5&AI<R!I<R!N965D960@9F]R
M(%!(4#0@8V]M<&%T:6)I;&ET>2P@:70@=VEL;`H@("`@("H@8V%L;"!T:&4@
M8V]N<W1R=6-T;W(L('=H96X@82!N97<@:6YS=&%N8V4@:7,@8W)E871E9"X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S<F-E;F,@<V]U<F-E(&-H
M87)S970@96YC;V1I;F<L('5S92!.54Q,("AD969A=6QT*2!T;R!U<V4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("!W:&%T979E<B!T:&4@9&]C=6UE
M;G0@<W!E8VEF:65S"B`@("`@*B!`<&%R86T@<W1R:6YG("1M;V1E("`@:&]W
M('1H:7,@<&%R<V5R(&]B:F5C="!S:&]U;&0@=V]R:RP@(F5V96YT(B!F;W(*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!H86YD;&5%;&5M96YT*"DL
M(")F=6YC(B!T;R!H879E(&ET(&-A;&P@9G5N8W1I;VYS"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@;F%M960@869T97(@96QE;65N=',@*&AA;F1L
M945L96UE;G1?)&YA;64H*2D*("`@("`J($!P87)A;2!S=')I;F<@)'1G96YC
M("!A('9A;&ED('1A<F=E="!E;F-O9&EN9PH@("`@("HO"B`@("!F=6YC=&EO
M;B!834Q?4&%R<V5R7U-I;7!L92@D<W)C96YC(#T@;G5L;"P@)&UO9&4@/2`G
M979E;G0G+"`D=&=T96YC(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^
M6$U,7U!A<G-E<B@D<W)C96YC+"`D;6]D92P@)'1G=&5N8RD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!I;FET<R!T:&4@:&%N9&QE<G,*("`@("`J"B`@("`@
M*B!`86-C97-S("!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]I;FET
M2&%N9&QE<G,H*0H@("`@>PH@("`@("`@(&EF("@A:7-?;V)J96-T*"1T:&ES
M+3Y?:&%N9&QE<D]B:BDI('L*("`@("`@("`@("`@)'1H:7,M/E]H86YD;&5R
M3V)J(#T@)B1T:&ES.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES+3YM
M;V1E("$]("=F=6YC)R`F)B`D=&AI<RT^;6]D92`A/2`G979E;G0G*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G56YS=7!P;W)T
M960@;6]D92!G:79E;B<L(%A-3%]005)315)?15)23U)?54Y355!03U)4141?
M34]$12D["B`@("`@("`@?0H@("`@("`@('AM;%]S971?;V)J96-T*"1T:&ES
M+3YP87)S97(L("1T:&ES+3Y?:&%N9&QE<D]B:BD["@H@("`@("`@('AM;%]S
M971?96QE;65N=%]H86YD;&5R*"1T:&ES+3YP87)S97(L(&%R<F%Y*"8D=&AI
M<RP@)W-T87)T2&%N9&QE<B<I+"!A<G)A>2@F)'1H:7,L("=E;F1(86YD;&5R
M)RDI.PH@("`@("`@('AM;%]S971?8VAA<F%C=&5R7V1A=&%?:&%N9&QE<B@D
M=&AI<RT^<&%R<V5R+"!A<G)A>2@F)'1H:7,L("=C9&%T84AA;F1L97(G*2D[
M"B`@("`@("`@"B`@("`@("`@+RHJ"B`@("`@("`@("H@<V5T(&%D9&ET:6]N
M86P@:&%N9&QE<G,@9F]R(&-H87)A8W1E<B!D871A+"!E;G1I=&EE<RP@971C
M+@H@("`@("`@("`J+PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YH86YD;&5R
M(&%S("1X;6Q?9G5N8R`]/B`D;65T:&]D*2!["B`@("`@("`@("`@(&EF("AM
M971H;V1?97AI<W1S*"1T:&ES+3Y?:&%N9&QE<D]B:BP@)&UE=&AO9"DI('L*
M("`@("`@("`@("`@("`@("1X;6Q?9G5N8R`]("=X;6Q?<V5T7R<@+B`D>&UL
M7V9U;F,["B`@("`@("`@("`@("`@("`D>&UL7V9U;F,H)'1H:7,M/G!A<G-E
M<BP@)&UE=&AO9"D["B`@("`@("`@("`@('T*"0E]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!297-E="!T:&4@<&%R<V5R+@H@("`@("H*("`@("`J(%1H:7,@
M86QL;W=S('EO=2!T;R!U<V4@;VYE('!A<G-E<B!I;G-T86YC90H@("`@("H@
M=&\@<&%R<V4@;75L=&EP;&4@6$U,(&1O8W5M96YT<RX*("`@("`J"B`@("`@
M*B!`86-C97-S("`@<'5B;&EC"B`@("`@*B!`<F5T=7)N("`@8F]O;&5A;GQO
M8FIE8W0@("`@('1R=64@;VX@<W5C8V5S<RP@4$5!4E]%<G)O<B!O=&AE<G=I
M<V4*("`@("`J+PH@("`@9G5N8W1I;VX@<F5S970H*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?96Q3=&%C:R`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/E]D
M871A("`@(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^7V1E<'1H("`@/2`P
M.PH@("`@("`@(`H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V-R96%T92@I
M.PH@("`@("`@(&EF("@D=&AI<RT^:7-%<G)O<B@@)')E<W5L="`I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("\J*@H@("`@*B!S=&%R="!H86YD;&5R
M"B`@("`J"B`@("`J(%!U<VAE<R!A='1R:6)U=&5S(&%N9"!T86=N86UE(&]N
M=&\@82!S=&%C:PH@("`@*@H@("`@*B!`86-C97-S("`@<')I=F%T90H@("`@
M*B!`9FEN86P*("`@("H@0'!A<F%M("`@(')E<V]U<F-E("`@('AM;"!P87)S
M97(@<F5S;W5R8V4*("`@("H@0'!A<F%M("`@('-T<FEN9R`@("`@(&5L96UE
M;G0@;F%M90H@("`@*B!`<&%R86T@("`@87)R87D@("`@("`@871T<FEB=71E
M<PH@("`@*B\*("`@(&9U;F-T:6]N('-T87)T2&%N9&QE<B@D>'`L("1E;&5M
M+"`F)&%T=')I8G,I"B`@("!["B`@("`@("`@87)R87E?<'5S:"@D=&AI<RT^
M7V5L4W1A8VLL(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=N86UE)R`@("`]/B`D96QE;2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G871T<FEB<R<@
M/3X@)&%T=')I8G,*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("D*("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`D=&AI<RT^
M7V1E<'1H*RL["B`@("`@("`@)'1H:7,M/E]D871A6R1T:&ES+3Y?9&5P=&A=
M(#T@)R<["B`@("!]"@H@("`O*BH*("`@("H@96YD(&AA;F1L97(*("`@("H*
M("`@("H@4'5L;',@871T<FEB=71E<R!A;F0@=&%G;F%M92!F<F]M(&$@<W1A
M8VL*("`@("H*("`@("H@0&%C8V5S<R`@('!R:79A=&4*("`@("H@0&9I;F%L
M"B`@("`J($!P87)A;2`@("!R97-O=7)C92`@("!X;6P@<&%R<V5R(')E<V]U
M<F-E"B`@("`J($!P87)A;2`@("!S=')I;F<@("`@("!E;&5M96YT(&YA;64*
M("`@("HO"B`@("!F=6YC=&EO;B!E;F1(86YD;&5R*"1X<"P@)&5L96TI"B`@
M("!["B`@("`@("`@)&5L("`@/2!A<G)A>5]P;W`H)'1H:7,M/E]E;%-T86-K
M*3L*("`@("`@("`D9&%T82`]("1T:&ES+3Y?9&%T85LD=&AI<RT^7V1E<'1H
M73L*("`@("`@("`D=&AI<RT^7V1E<'1H+2T["@H@("`@("`@('-W:71C:"`H
M)'1H:7,M/FUO9&4I('L*("`@("`@("`@("`@8V%S92`G979E;G0G.@H@("`@
M("`@("`@("`@("`@)'1H:7,M/E]H86YD;&5R3V)J+3YH86YD;&5%;&5M96YT
M*"1E;%LG;F%M92==+"`D96Q;)V%T=')I8G,G72P@)&1A=&$I.PH@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@)V9U;F,G.@H@("`@
M("`@("`@("`@("`@)&9U;F,@/2`G:&%N9&QE16QE;65N=%\G("X@)&5L96T[
M"B`@("`@("`@("`@("`@("!I9B`H<W1R8VAR*"1F=6YC+"`G+B<I*2!["B`@
M("`@("`@("`@("`@("`@("`@)&9U;F,@/2!S=')?<F5P;&%C92@G+B<L("=?
M)RP@)&9U;F,I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M:68@*&UE=&AO9%]E>&ES=',H)'1H:7,M/E]H86YD;&5R3V)J+"`D9G5N8RDI
M('L*("`@("`@("`@("`@("`@("`@("!C86QL7W5S97)?9G5N8RAA<G)A>2@F
M)'1H:7,M/E]H86YD;&5R3V)J+"`D9G5N8RDL("1E;%LG;F%M92==+"`D96Q;
M)V%T=')I8G,G72P@)&1A=&$I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@?0H@("`@?0H*("`@+RHJ"B`@("`J
M(&AA;F1L92!C:&%R86-T97(@9&%T80H@("`@*@H@("`@*B!`86-C97-S("`@
M<')I=F%T90H@("`@*B!`9FEN86P*("`@("H@0'!A<F%M("`@(')E<V]U<F-E
M("`@('AM;"!P87)S97(@<F5S;W5R8V4*("`@("H@0'!A<F%M("`@('-T<FEN
M9R`@("`@(&1A=&$*("`@("HO"B`@("!F=6YC=&EO;B!C9&%T84AA;F1L97(H
M)'AP+"`D9&%T82D*("`@('L*("`@("`@("`D=&AI<RT^7V1A=&%;)'1H:7,M
M/E]D97!T:%T@+CT@)&1A=&$["B`@("!]"@H@("`O*BH*("`@("H@:&%N9&QE
M(&$@=&%G"B`@("`J"B`@("`J($EM<&QE;65N="!T:&ES(&EN('EO=7(@<&%R
M<V5R(`H@("`@*@H@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J($!A8G-T
M<F%C=`H@("`@*B!`<&%R86T@("`@<W1R:6YG("`@("`@96QE;65N="!N86UE
M"B`@("`J($!P87)A;2`@("!A<G)A>2`@("`@("!A='1R:6)U=&5S"B`@("`J
M($!P87)A;2`@("!S=')I;F<@("`@("!C:&%R86-T97(@9&%T80H@("`@*B\*
M("`@(&9U;F-T:6]N(&AA;F1L945L96UE;G0H)&YA;64L("1A='1R:6)S+"`D
M9&%T82D*("`@('L*("`@('T*"B`@("\J*@H@("`@*B!G970@=&AE(&-U<G)E
M;G0@=&%G(&1E<'1H"B`@("`J"B`@("`J(%1H92!R;V]T('1A9R!I<R!I;B!D
M97!T:"`P+@H@("`@*@H@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J($!R
M971U<FX@("!I;G1E9V5R"B`@("`J+PH@("`@9G5N8W1I;VX@9V5T0W5R<F5N
M=$1E<'1H*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]D97!T:#L*
M("`@('T*"B`@("\J*@H@("`@*B!A9&0@<V]M92!S=')I;F<@=&\@=&AE(&-U
M<G)E;G0@9&1A=&$N"B`@("`J"B`@("`J(%1H:7,@:7,@8V]M;6]N;'D@;F5E
M9&5D+"!W:&5N(&$@9&]C=6UE;G0@:7,@<&%R<V5D(')E8W5R<VEV96QY+@H@
M("`@*@H@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J($!P87)A;2`@("!S
M=')I;F<@("`@("!D871A('1O(&%D9`H@("`@*B!`<F5T=7)N("`@=F]I9`H@
M("`@*B\*("`@(&9U;F-T:6]N(&%D9%1O1&%T82@@)&1A=&$@*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?9&%T85LD=&AI<RT^7V1E<'1H72`N/2`D9&%T83L*
M("`@('T*?0H_/@H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O6$U,+U!A<G-E<BYP:'``````````````````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`T-3`U-B`Q,#4Q-30S,S<S,2`P
M,C$Q,#,`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O
M('P@4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P-"!4
M:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U
M<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0
M(&QI8V5N<V4L("`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T
M:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@
M("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M
M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E
M:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@
M=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M
M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI
M8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D
M:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@075T:&]R.B!3=&EG($)A:VME;B`\<W-B0&9A<W0N
M;F\^("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\
M("`@("`@("`@5&]M87,@5BY6+D-O>"`\8V]X0&ED96-N970N8V]M/B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@("`@("`@(%-T97!H
M86X@4V-H;6ED="`\<V-H<W1`<&AP+71O;VQS+FYE=#X@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+PHO+R`D260Z(%!A<G-E<BYP:'`L=B`Q+C(V(#(P,#4O,#DO,C,@,3$Z-3$Z
M,3`@<V-H<W0@17AP("0*"B\J*@H@*B!834P@4&%R<V5R(&-L87-S+@H@*@H@
M*B!4:&ES(&ES(&%N(%A-3"!P87)S97(@8F%S960@;VX@4$A0)W,@(GAM;"(@
M97AT96YS:6]N+`H@*B!B87-E9"!O;B!T:&4@8G5N9&QE9"!E>'!A="!L:6)R
M87)Y+@H@*@H@*B!`8V%T96=O<GD@6$U,"B`J($!P86-K86=E(%A-3%]087)S
M97(*("H@0&%U=&AO<B`@4W1I9R!"86MK96X@/'-S8D!F87-T+FYO/@H@*B!`
M875T:&]R("!4;VUA<R!6+E8N0V]X(#QC;WA`:61E8VYE="YC;VT^"B`J($!A
M=71H;W(@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+71O;VQS+FYE=#X*
M("HO"@HO*BH*("H@=7-E<R!014%2)W,@97)R;W(@:&%N9&QI;F<*("HO"G)E
M<75I<F5?;VYC92`G4$5!4BYP:'`G.PH*+RHJ"B`J(')E<V]U<F-E(&-O=6QD
M(&YO="!B92!C<F5A=&5D"B`J+PID969I;F4H)UA-3%]005)315)?15)23U)?
M3D]?4D533U520T4G+"`R,#`I.PH*+RHJ"B`J('5N<W5P<&]R=&5D(&UO9&4*
M("HO"F1E9FEN92@G6$U,7U!!4E-%4E]%4E)/4E]53E-54%!/4E1%1%]-3T1%
M)RP@,C`Q*3L*"B\J*@H@*B!I;G9A;&ED(&5N8V]D:6YG('=A<R!G:79E;@H@
M*B\*9&5F:6YE*"=834Q?4$%24T527T524D]27TE.5D%,241?14Y#3T1)3D<G
M+"`R,#(I.PH*+RHJ"B`J('-P96-I9FEE9"!F:6QE(&-O=6QD(&YO="!B92!R
M96%D"B`J+PID969I;F4H)UA-3%]005)315)?15)23U)?1DE,15].3U1?4D5!
M1$%"3$4G+"`R,#,I.PH*+RHJ"B`J(&EN=F%L:60@:6YP=70*("HO"F1E9FEN
M92@G6$U,7U!!4E-%4E]%4E)/4E])3E9!3$E$7TE.4%54)RP@,C`T*3L*"B\J
M*@H@*B!R96UO=&4@9FEL92!C86YN;W0@8F4@<F5T<FEE=F5D(&EN('-A9F4@
M;6]D90H@*B\*9&5F:6YE*"=834Q?4$%24T527T524D]27U)%34]412<L(#(P
M-2D["@HO*BH*("H@6$U,(%!A<G-E<B!C;&%S<RX*("H*("H@5&AI<R!I<R!A
M;B!834P@<&%R<V5R(&)A<V5D(&]N(%!(4"=S(")X;6PB(&5X=&5N<VEO;BP*
M("H@8F%S960@;VX@=&AE(&)U;F1L960@97AP870@;&EB<F%R>2X*("H*("H@
M3F]T97,Z"B`J("T@270@<F5Q=6ER97,@4$A0(#0N,"XT<&PQ(&]R(&=R96%T
M97(*("H@+2!&<F]M(')E=FES:6]N(#$N,3<L('1H92!F=6YC=&EO;B!N86UE
M<R!U<V5D(&)Y('1H92`G9G5N8R<@;6]D90H@*B`@(&%R92!I;B!T:&4@9F]R
M;6%T(")X;6QT86=?)&5L96TB+"!F;W(@97AA;7!L93H@=7-E(")X;6QT86=?
M;F%M92(*("H@("!T;R!H86YD;&4@=&AE(#QN86UE/CPO;F%M93X@=&%G<R!O
M9B!Y;W5R('AM;"!F:6QE+@H@*@H@*B!`8V%T96=O<GD@6$U,"B`J($!P86-K
M86=E(%A-3%]087)S97(*("H@0&%U=&AO<B`@4W1I9R!"86MK96X@/'-S8D!F
M87-T+FYO/@H@*B!`875T:&]R("!4;VUA<R!6+E8N0V]X(#QC;WA`:61E8VYE
M="YC;VT^"B`J($!A=71H;W(@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP
M+71O;VQS+FYE=#X*("H@0'1O9&\@("`@8W)E871E(%A-3%]087)S97)?3F%M
M97-P86-E('1O('!A<G-E(&1O8W5M96YT<R!W:71H(&YA;65S<&%C97,*("H@
M0'1O9&\@("`@8W)E871E(%A-3%]087)S97)?4'5L;`H@*B!`=&]D;R`@("!4
M97-T<R!T:&%T(&YE960@=&\@8F4@;6%D93H*("H@("`@("`@("`@+2!M:7AI
M;F<@8VAA<F%C=&5R(&5N8V]D:6YG<PH@*B`@("`@("`@("`M(&$@=&5S="!U
M<VEN9R!A;&P@97AP870@:&%N9&QE<G,*("H@("`@("`@("`@+2!O<'1I;VYS
M("AF;VQD:6YG+"!O=71P=70@8VAA<G-E="D*("H@("`@("`@("`@+2!D:69F
M97)E;G0@<&%R<VEN9R!M;V1E<PH@*B\*8VQA<W,@6$U,7U!A<G-E<B!E>'1E
M;F1S(%!%05(*>PH@("`@+R\@>WM[('!R;W!E<G1I97,*"B`@("\J*@H@("`@
M("H@6$U,('!A<G-E<B!H86YD;&4*("`@("`J"B`@("`@*B!`=F%R("!R97-O
M=7)C90H@("`@("H@0'-E92`@>&UL7W!A<G-E<E]C<F5A=&4H*0H@("`@("HO
M"B`@("!V87(@)'!A<G-E<CL*"B`@("`O*BH*("`@("`J($9I;&4@:&%N9&QE
M(&EF('!A<G-I;F<@9G)O;2!A(&9I;&4*("`@("`J"B`@("`@*B!`=F%R("!R
M97-O=7)C90H@("`@("HO"B`@("!V87(@)&9P.PH*("`@("\J*@H@("`@("H@
M5VAE=&AE<B!T;R!D;R!C87-E(&9O;&1I;F<*("`@("`J"B`@("`@*B!)9B!S
M970@=&\@=')U92P@86QL('1A9R!A;F0@871T<FEB=71E(&YA;65S('=I;&P*
M("`@("`J(&)E(&-O;G9E<G1E9"!T;R!54%!%4B!#05-%+@H@("`@("H*("`@
M("`J($!V87(@(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1F;VQD:6YG(#T@
M=')U93L*"B`@("`O*BH*("`@("`J($UO9&4@;V8@;W!E<F%T:6]N+"!O;F4@
M;V8@(F5V96YT(B!O<B`B9G5N8R(*("`@("`J"B`@("`@*B!`=F%R("!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1M;V1E.PH*("`@("\J*@H@("`@("H@36%P
M<&EN9R!F<F]M(&5X<&%T(&AA;F1L97(@9G5N8W1I;VX@=&\@8VQA<W,@;65T
M:&]D+@H@("`@("H*("`@("`J($!V87(@(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D:&%N9&QE<B`](&%R<F%Y*`H@("`@("`@("=C:&%R86-T97)?9&%T85]H
M86YD;&5R)R`@("`@("`@("`@(#T^("=C9&%T84AA;F1L97(G+`H@("`@("`@
M("=D969A=6QT7VAA;F1L97(G("`@("`@("`@("`@("`@("`@(#T^("=D969A
M=6QT2&%N9&QE<B<L"B`@("`@("`@)W!R;V-E<W-I;F=?:6YS=')U8W1I;VY?
M:&%N9&QE<B<@("`@/3X@)W!I2&%N9&QE<B<L"B`@("`@("`@)W5N<&%R<V5D
M7V5N=&ET>5]D96-L7VAA;F1L97(G("`@("`@/3X@)W5N<&%R<V5D2&%N9&QE
M<B<L"B`@("`@("`@)VYO=&%T:6]N7V1E8VQ?:&%N9&QE<B<@("`@("`@("`@
M("`@/3X@)VYO=&%T:6]N2&%N9&QE<B<L"B`@("`@("`@)V5X=&5R;F%L7V5N
M=&ET>5]R969?:&%N9&QE<B<@("`@("`@/3X@)V5N=&ET>7)E9DAA;F1L97(G
M"B`@("`I.PH*("`@("\J*@H@("`@("H@<V]U<F-E(&5N8V]D:6YG"B`@("`@
M*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1S<F-E;F,[
M"@H@("`@+RHJ"B`@("`@*B!T87)G970@96YC;V1I;F<*("`@("`J"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)'1G=&5N8SL*"B`@("`O
M*BH*("`@("`J(&AA;F1L97(@;V)J96-T"B`@("`@*@H@("`@("H@0'9A<B!O
M8FIE8W0*("`@("`J+PH@("`@=F%R("1?:&%N9&QE<D]B:CL*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!C;VYS=')U8W1O<@H*("`@("\J*@H@("`@("H@0W)E
M871E<R!A;B!834P@<&%R<V5R+@H@("`@("H*("`@("`J(%1H:7,@:7,@;F5E
M9&5D(&9O<B!02%`T(&-O;7!A=&EB:6QI='DL(&ET('=I;&P*("`@("`J(&-A
M;&P@=&AE(&-O;G-T<G5C=&]R+"!W:&5N(&$@;F5W(&EN<W1A;F-E(&ES(&-R
M96%T960N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<W)C96YC('-O
M=7)C92!C:&%R<V5T(&5N8V]D:6YG+"!U<V4@3E5,3"`H9&5F875L="D@=&\@
M=7-E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@=VAA=&5V97(@=&AE
M(&1O8W5M96YT('-P96-I9FEE<PH@("`@("H@0'!A<F%M('-T<FEN9R`D;6]D
M92`@(&AO=R!T:&ES('!A<G-E<B!O8FIE8W0@<VAO=6QD('=O<FLL(")E=F5N
M="(@9F]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<W1A<G1E;&5M
M96YT+V5N9&5L96UE;G0M='EP92!E=F5N=',L(")F=6YC(@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@('1O(&AA=F4@:70@8V%L;"!F=6YC=&EO;G,@
M;F%M960@869T97(@96QE;65N=',*("`@("`J($!P87)A;2!S=')I;F<@)'1G
M96YC("!A('9A;&ED('1A<F=E="!E;F-O9&EN9PH@("`@("HO"B`@("!F=6YC
M=&EO;B!834Q?4&%R<V5R*"1S<F-E;F,@/2!N=6QL+"`D;6]D92`]("=E=F5N
M="<L("1T9W1E;F,@/2!N=6QL*0H@("`@>PH@("`@("`@(%A-3%]087)S97(Z
M.E]?8V]N<W1R=6-T*"1S<F-E;F,L("1M;V1E+"`D=&=T96YC*3L*("`@('T*
M("`@("\O('U]?0H*("`@("\J*@H@("`@("H@4$A0-2!C;VYS=')U8W1O<@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-R8V5N8R!S;W5R8V4@8VAA
M<G-E="!E;F-O9&EN9RP@=7-E($Y53$P@*&1E9F%U;'0I('1O('5S90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@('=H871E=F5R('1H92!D;V-U;65N
M="!S<&5C:69I97,*("`@("`J($!P87)A;2!S=')I;F<@)&UO9&4@("!H;W<@
M=&AI<R!P87)S97(@;V)J96-T('-H;W5L9"!W;W)K+"`B979E;G0B(&9O<@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@('-T87)T96QE;65N="]E;F1E
M;&5M96YT+71Y<&4@979E;G1S+"`B9G5N8R(*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!T;R!H879E(&ET(&-A;&P@9G5N8W1I;VYS(&YA;65D(&%F
M=&5R(&5L96UE;G1S"B`@("`@*B!`<&%R86T@<W1R:6YG("1T9V5N8R`@82!V
M86QI9"!T87)G970@96YC;V1I;F<*("`@("`J+PH@("`@9G5N8W1I;VX@7U]C
M;VYS=')U8W0H)'-R8V5N8R`](&YU;&PL("1M;V1E(#T@)V5V96YT)RP@)'1G
M=&5N8R`](&YU;&PI"B`@("!["B`@("`@("`@)'1H:7,M/E!%05(H)UA-3%]0
M87)S97)?17)R;W(G*3L*"B`@("`@("`@)'1H:7,M/FUO9&4@("`]("1M;V1E
M.PH@("`@("`@("1T:&ES+3YS<F-E;F,@/2`D<W)C96YC.PH@("`@("`@("1T
M:&ES+3YT9W1E;F,@/2`D=&=T96YC.PH@("`@?0H@("`@+R\@?7U]"@H@("`@
M+RHJ"B`@("`@*B!3971S('1H92!M;V1E(&]F('1H92!P87)S97(N"B`@("`@
M*@H@("`@("H@4&]S<VEB;&4@;6]D97,@87)E.@H@("`@("H@+2!F=6YC"B`@
M("`@*B`M(&5V96YT"B`@("`@*@H@("`@("H@66]U(&-A;B!S970@=&AE(&UO
M9&4@=7-I;F<@=&AE('-E8V]N9"!P87)A;65T97(*("`@("`J(&EN('1H92!C
M;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!O;FQY
M(&YE961E9"P@=VAE;B!S=VET8VAI;F<@=&\@82!N97<*("`@("`J(&UO9&4@
M870@82!L871E<B!P;VEN="X*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L
M:6,*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("!M;V1E+"!E:71H
M97(@)V9U;F,G(&]R("=E=F5N="<*("`@("`J($!R971U<FX@(&)O;VQE86Y\
M;V)J96-T("!T<G5E(&]N('-U8V-E<W,L(%!%05)?17)R;W(@;W1H97)W:7-E
M("`@"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$UO9&4H)&UO9&4I"B`@("![
M"B`@("`@("`@:68@*"1M;V1E("$]("=F=6YC)R`F)B`D;6]D92`A/2`G979E
M;G0G*2!["B`@("`@("`@("`@("1T:&ES+3YR86ES945R<F]R*"=5;G-U<'!O
M<G1E9"!M;V1E(&=I=F5N)RP@6$U,7U!!4E-%4E]%4E)/4E]53E-54%!/4E1%
M1%]-3T1%*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YM;V1E(#T@)&UO
M9&4["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!3971S('1H92!O8FIE8W0L('1H870@=VEL;"!H86YD;&4@=&AE(%A-3"!E
M=F5N=',*("`@("`J"B`@("`@*B!4:&ES(&%L;&]W<R!Y;W4@=&\@8W)E871E
M(&$@:&%N9&QE<B!O8FIE8W0@:6YD97!E;F1E;G0@;V8@=&AE"B`@("`@*B!P
M87)S97(@;V)J96-T('1H870@>6]U(&%R92!U<VEN9R!A;F0@96%S:6QY('-W
M:71C:"!T:&4@=6YD97)L>6EN9PH@("`@("H@<&%R<V5R+@H@("`@("H*("`@
M("`J($EF(&YO(&]B:F5C="!W:6QL(&)E('-E="P@6$U,7U!A<G-E<B!A<W-U
M;65S('1H870@>6]U"B`@("`@*B!E>'1E;F0@=&AI<R!C;&%S<R!A;F0@:&%N
M9&QE('1H92!E=F5N=',@:6X@)'1H:7,N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R`@<'5B;&EC"B`@("`@*B!`<&%R86T@("!O8FIE8W0@("`@("!O8FIE8W0@
M=&\@:&%N9&QE('1H92!E=F5N=',*("`@("`J($!R971U<FX@(&)O;VQE86X@
M("`@('=I;&P@86QW87ES(')E='5R;B!T<G5E"B`@("`@*B!`<VEN8V4@("!V
M,2XR+C!B971A,PH@("`@("HO"B`@("!F=6YC=&EO;B!S971(86YD;&5R3V)J
M*"8D;V)J*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:&%N9&QE<D]B:B`]("8D
M;V)J.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@26YI="!T:&4@96QE;65N="!H86YD;&5R<PH@("`@("H*("`@("`J($!A
M8V-E<W,@('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7VEN:71(86YD
M;&5R<R@I"B`@("!["B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D=&AI<RT^
M<&%R<V5R*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("!I9B`H(6ES7V]B:F5C="@D=&AI<RT^7VAA;F1L97)/8FHI
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?:&%N9&QE<D]B:B`]("8D=&AI<SL*
M("`@("`@("!]"B`@("`@("`@<W=I=&-H("@D=&AI<RT^;6]D92D@>PH*("`@
M("`@("`@("`@8V%S92`G9G5N8R<Z"B`@("`@("`@("`@("`@("!X;6Q?<V5T
M7V]B:F5C="@D=&AI<RT^<&%R<V5R+"`D=&AI<RT^7VAA;F1L97)/8FHI.PH@
M("`@("`@("`@("`@("`@>&UL7W-E=%]E;&5M96YT7VAA;F1L97(H)'1H:7,M
M/G!A<G-E<BP@87)R87DH)B1T:&ES+"`G9G5N8U-T87)T2&%N9&QE<B<I+"!A
M<G)A>2@F)'1H:7,L("=F=6YC16YD2&%N9&QE<B<I*3L*("`@("`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G979E;G0G.@H@("`@("`@
M("`@("`@("`@>&UL7W-E=%]O8FIE8W0H)'1H:7,M/G!A<G-E<BP@)'1H:7,M
M/E]H86YD;&5R3V)J*3L*("`@("`@("`@("`@("`@('AM;%]S971?96QE;65N
M=%]H86YD;&5R*"1T:&ES+3YP87)S97(L("=S=&%R=$AA;F1L97(G+"`G96YD
M2&%N9&QE<B<I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H)U5N<W5P<&]R=&5D(&UO9&4@9VEV96XG+"!834Q?4$%24T527T52
M4D]27U5.4U504$]25$5$7TU/1$4I.PH@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@?0H*"B`@("`@("`@+RHJ"B`@("`@("`@("H@<V5T(&%D9&ET
M:6]N86P@:&%N9&QE<G,@9F]R(&-H87)A8W1E<B!D871A+"!E;G1I=&EE<RP@
M971C+@H@("`@("`@("`J+PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YH86YD
M;&5R(&%S("1X;6Q?9G5N8R`]/B`D;65T:&]D*2!["B`@("`@("`@("`@(&EF
M("AM971H;V1?97AI<W1S*"1T:&ES+3Y?:&%N9&QE<D]B:BP@)&UE=&AO9"DI
M('L*("`@("`@("`@("`@("`@("1X;6Q?9G5N8R`]("=X;6Q?<V5T7R<@+B`D
M>&UL7V9U;F,["B`@("`@("`@("`@("`@("`D>&UL7V9U;F,H)'1H:7,M/G!A
M<G-E<BP@)&UE=&AO9"D["B`@("`@("`@("`@('T*"0E]"B`@("!]"@H@("`@
M+R\@>WM[(%]C<F5A=&4H*0H*("`@("\J*@H@("`@("H@8W)E871E('1H92!8
M34P@<&%R<V5R(')E<V]U<F-E"B`@("`@*@H@("`@("H@2&%S(&)E96X@;6]V
M960@9G)O;2!T:&4@8V]N<W1R=6-T;W(@=&\@879O:60*("`@("`J('!R;V)L
M96US('=I=&@@;V)J96-T(')E9F5R96YC97,N"B`@("`@*@H@("`@("H@1G5R
M=&AE<FUO<F4@:70@86QL;W=S('5S(')E='5R;FEN9R!A;B!E<G)O<@H@("`@
M("H@:68@<V]M971H:6YG(&9A:6QS+@H@("`@("H*("`@("`J($!A8V-E<W,@
M("!P<FEV871E"B`@("`@*B!`<F5T=7)N("`@8F]O;&5A;GQO8FIE8W0@("`@
M('1R=64@;VX@<W5C8V5S<RP@4$5!4E]%<G)O<B!O=&AE<G=I<V4*("`@("`J
M"B`@("`@*B!`<V5E('AM;%]P87)S97)?8W)E871E"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]C<F5A=&4H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^<W)C
M96YC(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1X<"`]($!X;6Q?<&%R<V5R
M7V-R96%T92@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1X<"`]
M($!X;6Q?<&%R<V5R7V-R96%T92@D=&AI<RT^<W)C96YC*3L*("`@("`@("!]
M"B`@("`@("`@:68@*&ES7W)E<V]U<F-E*"1X<"DI('L*("`@("`@("`@("`@
M:68@*"1T:&ES+3YT9W1E;F,@(3T](&YU;&PI('L*("`@("`@("`@("`@("`@
M(&EF("@A0'AM;%]P87)S97)?<V5T7V]P=&EO;B@D>'`L(%A-3%]/4%1)3TY?
M5$%21T547T5.0T]$24Y'+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YT9W1E;F,I*2!["B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=I;G9A;&ED('1A
M<F=E="!E;F-O9&EN9R<L(%A-3%]005)315)?15)23U)?24Y604Q)1%]%3D-/
M1$E.1RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)'1H:7,M/G!A<G-E<B`]("1X<#L*("`@("`@("`@("`@)')E<W5L
M="`]("1T:&ES+3Y?:6YI=$AA;F1L97)S*"1T:&ES+3YM;V1E*3L*("`@("`@
M("`@("`@:68@*"1T:&ES+3YI<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!X;6Q?<&%R<V5R7W-E=%]O<'1I;VXH)'AP+"!834Q?3U!424].7T-!
M4T5?1D],1$E.1RP@)'1H:7,M/F9O;&1I;F<I.PH*("`@("`@("`@("`@<F5T
M=7)N('1R=64["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@G56YA8FQE('1O(&-R96%T92!834P@<&%R<V5R(')E<V]U<F-E
M+B<L(%A-3%]005)315)?15)23U)?3D]?4D533U520T4I.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(')E<V5T*"D*"B`@("`O*BH*("`@("`J(%)E
M<V5T('1H92!P87)S97(N"B`@("`@*@H@("`@("H@5&AI<R!A;&QO=W,@>6]U
M('1O('5S92!O;F4@<&%R<V5R(&EN<W1A;F-E"B`@("`@*B!T;R!P87)S92!M
M=6QT:7!L92!834P@9&]C=6UE;G1S+@H@("`@("H*("`@("`J($!A8V-E<W,@
M("!P=6)L:6,*("`@("`J($!R971U<FX@("!B;V]L96%N?&]B:F5C="`@("`@
M=')U92!O;B!S=6-C97-S+"!014%27T5R<F]R(&]T:&5R=VES90H@("`@("HO
M"B`@("!F=6YC=&EO;B!R97-E="@I"B`@("!["B`@("`@("`@)')E<W5L="`]
M("1T:&ES+3Y?8W)E871E*"D["B`@("`@("`@:68@*"1T:&ES+3YI<T5R<F]R
M*"`D<F5S=6QT("DI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[('-E=$EN<'5T1FEL92@I"@H@("`@+RHJ"B`@("`@*B!3
M971S('1H92!I;G!U="!X;6P@9FEL92!T;R!B92!P87)S960*("`@("`J"B`@
M("`@*B!`<&%R86T@("`@<W1R:6YG("`@("`@1FEL96YA;64@*&9U;&P@<&%T
M:"D*("`@("`J($!R971U<FX@("!R97-O=7)C92`@("!F;W!E;B!H86YD;&4@
M;V8@=&AE(&=I=F5N(&9I;&4*("`@("`J($!T:')O=W,@("!834Q?4&%R<V5R
M7T5R<F]R"B`@("`@*B!`<V5E("`@("`@<V5T26YP=70H*2P@<V5T26YP=713
M=')I;F<H*2P@<&%R<V4H*0H@("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@
M("HO"B`@("!F=6YC=&EO;B!S971);G!U=$9I;&4H)&9I;&4I"B`@("!["B`@
M("`@("`@+RHJ"B`@("`@("`@("H@8VAE8VLL(&EF(&9I;&4@:7,@82!R96UO
M=&4@9FEL90H@("`@("`@("`J+PH@("`@("`@(&EF("AE<F5G:2@G7BAH='1P
M?&9T<"DZ+R\G+"!S=6)S='(H)&9I;&4L(#`L(#$P*2DI('L*("`@("`@("`@
M("`@:68@*"%I;FE?9V5T*"=A;&QO=U]U<FQ?9F]P96XG*2D@>PH@("`@("`@
M("`@("`)<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=296UO=&4@9FEL97,@
M8V%N;F]T(&)E('!A<G-E9"P@87,@<V%F92!M;V1E(&ES(&5N86)L960N)RP@
M6$U,7U!!4E-%4E]%4E)/4E]214U/5$4I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@("`@(`H@("`@("`@("1F<"`]($!F;W!E;B@D9FEL92P@)W)B
M)RD["B`@("`@("`@:68@*&ES7W)E<V]U<F-E*"1F<"DI('L*("`@("`@("`@
M("`@)'1H:7,M/F9P(#T@)&9P.PH@("`@("`@("`@("!R971U<FX@)&9P.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)T9I
M;&4@8V]U;&0@;F]T(&)E(&]P96YE9"XG+"!834Q?4$%24T527T524D]27T9)
M3$5?3D]47U)%041!0DQ%*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!S971);G!U=%-T<FEN9R@I"B`@("`*("`@("\J*@H@("`@("H@6$U,7U!A
M<G-E<CHZ<V5T26YP=713=')I;F<H*0H@("`@("H@"B`@("`@*B!3971S('1H
M92!X;6P@:6YP=70@9G)O;2!A('-T<FEN9PH@("`@("H@"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1D871A(&$@<W1R:6YG(&-O;G1A:6YI;F<@=&AE(%A-3"!D
M;V-U;65N=`H@("`@("H@0')E='5R;B!N=6QL"B`@("`@*BHO"B`@("!F=6YC
M=&EO;B!S971);G!U=%-T<FEN9R@D9&%T82D*("`@('L*("`@("`@("`D=&AI
M<RT^9G`@/2`D9&%T83L*("`@("`@("!R971U<FX@;G5L;#L*("`@('T*("`@
M(`H@("`@+R\@?7U]"B`@("`O+R![>WL@<V5T26YP=70H*0H*("`@("\J*@H@
M("`@("H@4V5T<R!T:&4@9FEL92!H86YD;&4@=&\@=7-E('=I=&@@<&%R<V4H
M*2X*("`@("`J"B`@("`@*B!9;W4@<VAO=6QD('5S92!S971);G!U=$9I;&4H
M*2!O<B!S971);G!U=%-T<FEN9R@I(&EF('EO=0H@("`@("H@<&%S<R!A('-T
M<FEN9R`*("`@("`J"B`@("`@*B!`<&%R86T@("`@;6EX960@("1F<"`@0V%N
M(&)E(&5I=&AE<B!A(')E<V]U<F-E(')E='5R;F5D(&9R;VT@9F]P96XH*2P*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!A(%523"P@82!L;V-A;"!F
M:6QE;F%M92!O<B!A('-T<FEN9RX*("`@("`J($!A8V-E<W,@("!P=6)L:6,*
M("`@("`J($!S964@("`@("!P87)S92@I"B`@("`@*B!`=7-E<R`@("`@<V5T
M26YP=713=')I;F<H*2P@<V5T26YP=71&:6QE*"D*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5T26YP=70H)&9P*0H@("`@>PH@("`@("`@(&EF("AI<U]R97-O
M=7)C92@D9G`I*2!["B`@("`@("`@("`@("1T:&ES+3YF<"`]("1F<#L*("`@
M("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H@("`@("`@("\O('-E
M92!I9B!I="=S(&%N(&%B<V]L=71E(%523"`H:&%S(&$@<V-H96UE(&%T('1H
M92!B96=I;FYI;F<I"B`@("`@("`@96QS96EF("AE<F5G:2@G7EMA+7I=*SHO
M+R<L('-U8G-T<B@D9G`L(#`L(#$P*2DI('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YS971);G!U=$9I;&4H)&9P*3L*("`@("`@("!]"B`@("`@("`@
M+R\@<V5E(&EF(&ET)W,@82!L;V-A;"!F:6QE"B`@("`@("`@96QS96EF("AF
M:6QE7V5X:7-T<R@D9G`I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<V5T26YP=71&:6QE*"1F<"D["B`@("`@("`@?0H@("`@("`@("\O(&ET(&UU
M<W0@8F4@82!S=')I;F<*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)'1H
M:7,M/F9P(#T@)&9P.PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G26QL96=A
M;"!I;G!U="!F;W)M870G+"!834Q?4$%24T527T524D]27TE.5D%,241?24Y0
M550I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('!A<G-E*"D*"B`@
M("`O*BH*("`@("`J($-E;G1R86P@<&%R<VEN9R!F=6YC=&EO;BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N("`@=')U97QO8FIE8W0@4$5!4B!E<G)O<B`@("`@
M<F5T=7)N<R!T<G5E(&]N('-U8V-E<W,L(&]R(&$@4$5!4E]%<G)O<B!O=&AE
M<G=I<V4*("`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("`J+PH@("`@9G5N
M8W1I;VX@<&%R<V4H*0H@("`@>PH@("`@("`@("\J*@H@("`@("`@("`J(')E
M<V5T('1H92!P87)S97(*("`@("`@("`@*B\*("`@("`@("`D<F5S=6QT(#T@
M)'1H:7,M/G)E<V5T*"D["B`@("`@("`@:68@*"1T:&ES+3YI<T5R<F]R*"1R
M97-U;'0I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@
M('T*("`@("`@("`O+R!I9B`D=&AI<RT^9G`@=V%S(&9O<&5N960@<')E=FEO
M=7-L>0H@("`@("`@(&EF("AI<U]R97-O=7)C92@D=&AI<RT^9G`I*2!["B`@
M("`@("`@"B`@("`@("`@("`@('=H:6QE("@D9&%T82`](&9R96%D*"1T:&ES
M+3YF<"P@-#`Y-BDI('L*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/E]P
M87)S95-T<FEN9R@D9&%T82P@9F5O9B@D=&AI<RT^9G`I*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1E<G)O<B`]("8D=&AI<RT^<F%I<V5%<G)O<B@I.PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YF<F5E*"D["B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@("\O(&]T:&5R=VES92P@)'1H:7,M/F9P(&UU
M<W0@8F4@82!S=')I;F<*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I
M9B`H(21T:&ES+3Y?<&%R<V53=')I;F<H)'1H:7,M/F9P+"!T<G5E*2D@>PH@
M("`@("`@("`@("`@("`@)&5R<F]R(#T@)B1T:&ES+3YR86ES945R<F]R*"D[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^9G)E92@I.PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1E<G)O<CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M("`@("`D=&AI<RT^9G)E92@I.PH*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O*BH*("`@("`J(%A-3%]087)S97(Z.E]P87)S95-T<FEN9R@I
M"B`@("`@*B`*("`@("`J($!P87)A;2!S=')I;F<@)&1A=&$*("`@("`J($!P
M87)A;2!B;V]L96%N("1E;V8*("`@("`J($!R971U<FX@8F]O;`H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<V5E('!A<G-E4W1R:6YG*"D*("`@
M("`J*B\*("`@(&9U;F-T:6]N(%]P87)S95-T<FEN9R@D9&%T82P@)&5O9B`]
M(&9A;'-E*0H@("`@>PH@("`@("`@(')E='5R;B!X;6Q?<&%R<V4H)'1H:7,M
M/G!A<G-E<BP@)&1A=&$L("1E;V8I.PH@("`@?0H@("`@"B`@("`O+R!]?7T*
M("`@("\O('M[>R!P87)S95-T<FEN9R@I"@H@("`@+RHJ"B`@("`@*B!834Q?
M4&%R<V5R.CIP87)S95-T<FEN9R@I"B`@("`@*B`*("`@("`J(%!A<G-E<R!A
M('-T<FEN9RX*("`@("`J"B`@("`@*B!`<&%R86T@("`@<W1R:6YG("`D9&%T
M82!834P@9&%T80H@("`@("H@0'!A<F%M("`@(&)O;VQE86X@)&5O9B`@268@
M<V5T(&%N9"!44E5%+"!D871A(&ES('1H92!L87-T('!I96-E(&]F(&1A=&$@
M<V5N="!I;B!T:&ES('!A<G-E<@H@("`@("H@0'1H<F]W<R`@(%A-3%]087)S
M97)?17)R;W(*("`@("`J($!R971U<FX@("!096%R($5R<F]R?'1R=64@("!T
M<G5E(&]N('-U8V-E<W,@;W(@82!014%2($5R<F]R"B`@("`@*B!`<V5E("`@
M("`@7W!A<G-E4W1R:6YG*"D*("`@("`J+PH@("`@9G5N8W1I;VX@<&%R<V53
M=')I;F<H)&1A=&$L("1E;V8@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H
M(6ES<V5T*"1T:&ES+3YP87)S97(I('Q\("%I<U]R97-O=7)C92@D=&AI<RT^
M<&%R<V5R*2D@>PH@("`@("`@("`@("`D=&AI<RT^<F5S970H*3L*("`@("`@
M("!]"B`@("`@("`@"B`@("`@("`@:68@*"$D=&AI<RT^7W!A<G-E4W1R:6YG
M*"1D871A+"`D96]F*2D@>PH@("`@("`@("`@("1E<G)O<B`]("8D=&AI<RT^
M<F%I<V5%<G)O<B@I.PH@("`@("`@("`@("1T:&ES+3YF<F5E*"D["B`@("`@
M("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@(&EF("@D
M96]F(#T]/2!T<G5E*2!["B`@("`@("`@("`@("1T:&ES+3YF<F5E*"D["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H@("`@"B`@("`O
M*BH*("`@("`J(%A-3%]087)S97(Z.F9R964H*0H@("`@("H@"B`@("`@*B!&
M<F5E('1H92!I;G1E<FYA;"!R97-O=7)C97,@87-S;V-I871E9"!W:71H('1H
M92!P87)S97(*("`@("`J(`H@("`@("H@0')E='5R;B!N=6QL"B`@("`@*BHO
M"B`@("!F=6YC=&EO;B!F<F5E*"D*("`@('L*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/G!A<G-E<BD@)B8@:7-?<F5S;W5R8V4H)'1H:7,M/G!A<G-E<BDI
M('L*("`@("`@("`@("`@>&UL7W!A<G-E<E]F<F5E*"1T:&ES+3YP87)S97(I
M.PH@("`@("`@("`@("!U;G-E="@@)'1H:7,M/G!A<G-E<B`I.PH@("`@("`@
M('T*("`@("`@("!I9B`H:7-S970H)'1H:7,M/F9P*2`F)B!I<U]R97-O=7)C
M92@D=&AI<RT^9G`I*2!["B`@("`@("`@("`@(&9C;&]S92@D=&AI<RT^9G`I
M.PH@("`@("`@('T*("`@("`@("!U;G-E="@D=&AI<RT^9G`I.PH@("`@("`@
M(')E='5R;B!N=6QL.PH@("`@?0H@("`@"B`@("`O*BH*("`@("`J(%A-3%]0
M87)S97(Z.G)A:7-E17)R;W(H*0H@("`@("H@"B`@("`@*B!4:')O=W,@82!8
M34Q?4&%R<V5R7T5R<F]R"B`@("`@*B`*("`@("`J($!P87)A;2!S=')I;F<@
M("1M<V<@("!T:&4@97)R;W(@;65S<V%G90H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)&5C;V1E('1H92!E<G)O<B!M97-S86=E(&-O9&4*("`@("`J($!R971U
M<FX@6$U,7U!A<G-E<E]%<G)O<B`*("`@("`J*B\*("`@(&9U;F-T:6]N(')A
M:7-E17)R;W(H)&US9R`](&YU;&PL("1E8V]D92`](#`I"B`@("!["B`@("`@
M("`@)&US9R`]("%I<U]N=6QL*"1M<V<I(#\@)&US9R`Z("1T:&ES+3YP87)S
M97(["B`@("`@("`@)&5R<B`]("9N97<@6$U,7U!A<G-E<E]%<G)O<B@D;7-G
M+"`D96-O9&4I.PH@("`@("`@(')E='5R;B!P87)E;G0Z.G)A:7-E17)R;W(H
M)&5R<BD["B`@("!]"B`@("`*("`@("\O('U]?0H@("`@+R\@>WM[(&9U;F-3
M=&%R=$AA;F1L97(H*0H*("`@(&9U;F-T:6]N(&9U;F-3=&%R=$AA;F1L97(H
M)'AP+"`D96QE;2P@)&%T=')I8G,I"B`@("!["B`@("`@("`@)&9U;F,@/2`G
M>&UL=&%G7R<@+B`D96QE;3L*("`@("`@("!I9B`H<W1R8VAR*"1F=6YC+"`G
M+B<I*2!["B`@("`@("`@("`@("1F=6YC(#T@<W1R7W)E<&QA8V4H)RXG+"`G
M7R<L("1F=6YC*3L*("`@("`@("!]"B`@("`@("`@:68@*&UE=&AO9%]E>&ES
M=',H)'1H:7,M/E]H86YD;&5R3V)J+"`D9G5N8RDI('L*("`@("`@("`@("`@
M8V%L;%]U<V5R7V9U;F,H87)R87DH)B1T:&ES+3Y?:&%N9&QE<D]B:BP@)&9U
M;F,I+"`D>'`L("1E;&5M+"`D871T<FEB<RD["B`@("`@("`@?2!E;'-E:68@
M*&UE=&AO9%]E>&ES=',H)'1H:7,M/E]H86YD;&5R3V)J+"`G>&UL=&%G)RDI
M('L*("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F,H87)R87DH)B1T:&ES+3Y?
M:&%N9&QE<D]B:BP@)WAM;'1A9R<I+"`D>'`L("1E;&5M+"`D871T<FEB<RD[
M"B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&9U;F-%
M;F1(86YD;&5R*"D*"B`@("!F=6YC=&EO;B!F=6YC16YD2&%N9&QE<B@D>'`L
M("1E;&5M*0H@("`@>PH@("`@("`@("1F=6YC(#T@)WAM;'1A9U\G("X@)&5L
M96T@+B`G7R<["B`@("`@("`@:68@*'-T<F-H<B@D9G5N8RP@)RXG*2D@>PH@
M("`@("`@("`@("`D9G5N8R`]('-T<E]R97!L86-E*"<N)RP@)U\G+"`D9G5N
M8RD["B`@("`@("`@?0H@("`@("`@(&EF("AM971H;V1?97AI<W1S*"1T:&ES
M+3Y?:&%N9&QE<D]B:BP@)&9U;F,I*2!["B`@("`@("`@("`@(&-A;&Q?=7-E
M<E]F=6YC*&%R<F%Y*"8D=&AI<RT^7VAA;F1L97)/8FHL("1F=6YC*2P@)'AP
M+"`D96QE;2D["B`@("`@("`@?2!E;'-E:68@*&UE=&AO9%]E>&ES=',H)'1H
M:7,M/E]H86YD;&5R3V)J+"`G>&UL=&%G7R<I*2!["B`@("`@("`@("`@(&-A
M;&Q?=7-E<E]F=6YC*&%R<F%Y*"8D=&AI<RT^7VAA;F1L97)/8FHL("=X;6QT
M86=?)RDL("1X<"P@)&5L96TI.PH@("`@("`@('T*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!S=&%R=$AA;F1L97(H*0H*("`@("\J*@H@("`@("H*
M("`@("`J($!A8G-T<F%C=`H@("`@("HO"B`@("!F=6YC=&EO;B!S=&%R=$AA
M;F1L97(H)'AP+"`D96QE;2P@)B1A='1R:6)S*0H@("`@>PH@("`@("`@(')E
M='5R;B!.54Q,.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&5N9$AA
M;F1L97(H*0H*("`@("\J*@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@
M("HO"B`@("!F=6YC=&EO;B!E;F1(86YD;&5R*"1X<"P@)&5L96TI"B`@("![
M"B`@("`@("`@<F5T=7)N($Y53$P["B`@("!]"@H*("`@("\O('U]?6UE"GT*
M"B\J*@H@*B!E<G)O<B!C;&%S<RP@<F5P;&%C97,@4$5!4E]%<G)O<@H@*@H@
M*B!!;B!I;G-T86YC92!O9B!T:&ES(&-L87-S('=I;&P@8F4@<F5T=7)N960*
M("H@:68@86X@97)R;W(@;V-C=7)S(&EN<VED92!834Q?4&%R<V5R+@H@*@H@
M*B!4:&5R92!A<F4@=&AR964@861V86YT86=E<R!O=F5R('5S:6YG('1H92!S
M=&%N9&%R9"!014%27T5R<F]R.@H@*B`M($%L;"!M97-S86=E<R!W:6QL(&)E
M('!R969I>&5D"B`J("T@8VAE8VL@9F]R(%A-3%]087)S97(@97)R;W(L('5S
M:6YG(&ES7V$H("1E<G)O<BP@)UA-3%]087)S97)?17)R;W(G("D*("H@+2!M
M97-S86=E<R!C86X@8F4@9V5N97)A=&5D(&9R;VT@=&AE('AM;%]P87)S97(@
M<F5S;W5R8V4*("H*("H@0'!A8VMA9V4@6$U,7U!A<G-E<@H@*B!`86-C97-S
M("!P=6)L:6,*("H@0'-E92`@("`@4$5!4E]%<G)O<@H@*B\*8VQA<W,@6$U,
M7U!A<G-E<E]%<G)O<B!E>'1E;F1S(%!%05)?17)R;W(*>PH@("`@+R\@>WM[
M('!R;W!E<G1I97,*"B`@("\J*@H@("`@*B!P<F5F:7@@9F]R(&%L;"!M97-S
M86=E<PH@("`@*@H@("`@*B!`=F%R("`@("`@<W1R:6YG"B`@("`J+R`@("`*
M("`@('9A<B`D97)R;W)?;65S<V%G95]P<F5F:7@@/2`G6$U,7U!A<G-E<CH@
M)SL*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VYS=')U8W1O<B@I"B`@("\J
M*@H@("`@*B!C;VYS=')U8W0@82!N97<@97)R;W(@:6YS=&%N8V4*("`@("H*
M("`@("H@66]U(&UA>2!E:71H97(@<&%S<R!A(&UE<W-A9V4@;W(@86X@>&UL
M7W!A<G-E<B!R97-O=7)C92!A<R!F:7)S=`H@("`@*B!P87)A;65T97(N($EF
M(&$@<F5S;W5R8V4@:&%S(&)E96X@<&%S<V5D+"!T:&4@;&%S="!E<G)O<B!T
M:&%T"B`@("`J(&AA<'!E;F5D('=I;&P@8F4@<F5T<FEE=F5D(&%N9"!R971U
M<FYE9"X*("`@("H*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B!`<&%R
M86T@("`@<W1R:6YG?')E<V]U<F-E("`@("!M97-S86=E(&]R('!A<G-E<B!R
M97-O=7)C90H@("`@*B!`<&%R86T@("`@:6YT96=E<B`@("`@("`@("`@("!E
M<G)O<B!C;V1E"B`@("`J($!P87)A;2`@("!I;G1E9V5R("`@("`@("`@("`@
M(&5R<F]R(&AA;F1L:6YG"B`@("`J($!P87)A;2`@("!I;G1E9V5R("`@("`@
M("`@("`@(&5R<F]R(&QE=F5L"B`@("`J+R`@("`*("`@(&9U;F-T:6]N(%A-
M3%]087)S97)?17)R;W(H)&US9V]R<&%R<V5R(#T@)W5N:VYO=VX@97)R;W(G
M+"`D8V]D92`](#`L("1M;V1E(#T@4$5!4E]%4E)/4E]215154DXL("1L979E
M;"`]($5?55-%4E].3U1)0T4I"B`@("!["B`@("`@("`@:68@*&ES7W)E<V]U
M<F-E*"1M<V=O<G!A<G-E<BDI('L*("`@("`@("`@("`@)&-O9&4@/2!X;6Q?
M9V5T7V5R<F]R7V-O9&4H)&US9V]R<&%R<V5R*3L*("`@("`@("`@("`@)&US
M9V]R<&%R<V5R(#T@<W!R:6YT9B@G)7,@870@6$U,(&EN<'5T(&QI;F4@)60Z
M)60G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('AM;%]E
M<G)O<E]S=')I;F<H)&-O9&4I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('AM;%]G971?8W5R<F5N=%]L:6YE7VYU;6)E<B@D;7-G;W)P
M87)S97(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('AM
M;%]G971?8W5R<F5N=%]C;VQU;6Y?;G5M8F5R*"1M<V=O<G!A<G-E<BDI.PH@
M("`@("`@('T*("`@("`@("`D=&AI<RT^4$5!4E]%<G)O<B@D;7-G;W)P87)S
M97(L("1C;V1E+"`D;6]D92P@)&QE=F5L*3L*("`@('T*("`@("\O('U]?0I]
M"C\^````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O6$U,+U5T:6PN<&AP````````````````````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`V-3,V,R`Q,#4Q-30S,S<S,2`P,C`U-C<`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]02%`-"B\J
M('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT.B`J
M+PT*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\(%!(4"!6
M97)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PT*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,B!4:&4@4$A0
M($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@5&AI<R!S;W5R8V4@
M9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP(&]F('1H92!02%`@;&EC
M96YS92P@("`@("`@?`T*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES
M('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\
M#0HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`T*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E
M:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@
M=&\@("!\#0HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E
M+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P-"B\O('P@
M;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM
M961I871E;'DN("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK#0HO+R!\($%U=&AO<G,Z(%-T97!H86X@4V-H;6ED="`\
M<V-H<W1`<&AP+71O;VQS+FYE=#X@("`@("`@("`@("`@("`@("`@("`@('P-
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\-"B\O("`@("1)
M9#H@571I;"YP:'`L=B`Q+C(T(#(P,#0O,3(O,C,@,3,Z,C$Z-3D@<V-H<W0@
M17AP("0-"@T*+RHJ#0H@*B!E<G)O<B!C;V1E(&9O<B!I;G9A;&ED(&-H87)S
M(&EN(%A-3"!N86UE#0H@*B\-"F1E9FEN92@B6$U,7U5424Q?15)23U)?24Y6
M04Q)1%]#2$%24R(L(#4Q*3L-"@T*+RHJ#0H@*B!E<G)O<B!C;V1E(&9O<B!I
M;G9A;&ED(&-H87)S(&EN(%A-3"!N86UE#0H@*B\-"F1E9FEN92@B6$U,7U54
M24Q?15)23U)?24Y604Q)1%]35$%25"(L(#4R*3L-"@T*+RHJ#0H@*B!E<G)O
M<B!C;V1E(&9O<B!N;VXM<V-A;&%R('1A9R!C;VYT96YT#0H@*B\-"F1E9FEN
M92@B6$U,7U5424Q?15)23U)?3D].7U-#04Q!4E]#3TY414Y4(BP@-C`I.PT*
M("`@(`T*+RHJ#0H@*B!E<G)O<B!C;V1E(&9O<B!M:7-S:6YG('1A9R!N86UE
M#0H@*B\-"F1E9FEN92@B6$U,7U5424Q?15)23U)?3D]?5$%'7TY!344B+"`V
M,2D[#0H@("`@#0HO*BH-"B`J(')E<&QA8V4@6$U,(&5N=&ET:65S#0H@*B\-
M"F1E9FEN92@B6$U,7U5424Q?4D503$%#15]%3E1)5$E%4R(L(#$I.PT*#0HO
M*BH-"B`J(&5M8F5D9"!C;VYT96YT(&EN(&$@0T1A=&$@4V5C=&EO;@T*("HO
M#0ID969I;F4H(EA-3%]55$E,7T-$051!7U-%0U1)3TXB+"`U*3L-"@T*+RHJ
M#0H@*B!D;R!N;W0@<F5P;&%C92!E;G1I=&ET97,-"B`J+PT*9&5F:6YE*")8
M34Q?551)3%]%3E1)5$E%4U].3TY%(BP@,"D[#0H-"B\J*@T*("H@<F5P;&%C
M92!A;&P@6$U,(&5N=&ET:71E<PT*("H@5&AI<R!S971T:6YG('=I;&P@<F5P
M;&%C92`\+"`^+"`B+"`G(&%N9"`F#0H@*B\-"F1E9FEN92@B6$U,7U5424Q?
M14Y4251)15-?6$U,(BP@,2D[#0H-"B\J*@T*("H@<F5P;&%C92!O;FQY(')E
M<75I<F5D(%A-3"!E;G1I=&ET97,-"B`J(%1H:7,@<V5T=&EN9R!W:6QL(')E
M<&QA8V4@/"P@(B!A;F0@)@T*("HO#0ID969I;F4H(EA-3%]55$E,7T5.5$E4
M24537UA-3%]215%525)%1"(L(#(I.PT*#0HO*BH-"B`J(')E<&QA8V4@2%1-
M3"!E;G1I=&ET97,-"B`J($!L:6YK("`@(&AT='`Z+R]W=W<N<&AP+FYE="]H
M=&UL96YT:71I97,-"B`J+PT*9&5F:6YE*")834Q?551)3%]%3E1)5$E%4U](
M5$U,(BP@,RD[#0H-"B\J*@T*("H@0V]L;&%P<V4@86QL(&5M<'1Y('1A9W,N
M#0H@*B\-"F1E9FEN92@B6$U,7U5424Q?0T],3$%04T5?04Q,(BP@,2D[#0H-
M"B\J*@T*("H@0V]L;&%P<V4@;VYL>2!E;7!T>2!82%1-3"!T86=S('1H870@
M:&%V92!N;R!E;F0@=&%G+@T*("HO#0ID969I;F4H(EA-3%]55$E,7T-/3$Q!
M4%-%7UA(5$U,7T].3%DB+"`R*3L-"@T*+RHJ#0H@*B!U=&EL:71Y(&-L87-S
M(&9O<B!W;W)K:6YG('=I=&@@6$U,(&1O8W5M96YT<PT*("H-"B`J($!C871E
M9V]R>2!834P-"B`J($!P86-K86=E("!834Q?571I;`T*("H@0'9E<G-I;VX@
M(#$N,2XP#0H@*B!`875T:&]R("`@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P
M:'`N;F5T/@T*("HO#0IC;&%S<R!834Q?571I;"![#0H-"B`@("\J*@T*("`@
M("H@<F5T=7)N($%022!V97)S:6]N#0H@("`@*@T*("`@("H@0&%C8V5S<R`@
M('!U8FQI8PT*("`@("H@0'-T871I8PT*("`@("H@0')E='5R;B`@('-T<FEN
M9R`@)'9E<G-I;VX@05!)('9E<G-I;VX-"B`@("`J+PT*("`@(&9U;F-T:6]N
M(&%P:59E<G-I;VXH*0T*("`@('L-"B`@("`@("`@<F5T=7)N("<Q+C$G.PT*
M("`@('T-"@T*("`@+RHJ#0H@("`@*B!R97!L86-E(%A-3"!E;G1I=&EE<PT*
M("`@("H-"B`@("`J(%=I=&@@=&AE(&]P=&EO;F%L('-E8V]N9"!P87)A;65T
M97(L('EO=2!M87D@<V5L96-T+"!W:&EC:`T*("`@("H@96YT:71I97,@<VAO
M=6QD(&)E(')E<&QA8V5D+@T*("`@("H-"B`@("`J(#QC;V1E/@T*("`@("H@
M<F5Q=6ER95]O;F-E("=834PO571I;"YP:'`G.PT*("`@("H@#0H@("`@*B`O
M+R!R97!L86-E(%A-3"!E;G1I=&5S.@T*("`@("H@)'-T<FEN9R`](%A-3%]5
M=&EL.CIR97!L86-E16YT:71I97,H(E1H:7,@<W1R:6YG(&-O;G1A:6YS(#P@
M)B`^+B(I.PT*("`@("H@/"]C;V1E/@T*("`@("H-"B`@("`J($!A8V-E<W,@
M("!P=6)L:6,-"B`@("`J($!S=&%T:6,-"B`@("`J($!P87)A;2`@("!S=')I
M;F<@('-T<FEN9R!W:&5R92!834P@<W!E8VEA;"!C:&%R<R!S:&]U;&0@8F4@
M<F5P;&%C960-"B`@("`J($!P87)A;2`@("!I;G1E9V5R('-E='1I;F<@9F]R
M(&5N=&ET:65S(&EN(&%T=')I8G5T92!V86QU97,@*&]N92!O9B!834Q?551)
M3%]%3E1)5$E%4U]834PL(%A-3%]55$E,7T5.5$E424537UA-3%]215%525)%
M1"P@6$U,7U5424Q?14Y4251)15-?2%1-3"D-"B`@("`J($!R971U<FX@("!S
M=')I;F<@('-T<FEN9R!W:71H(')E<&QA8V5D(&-H87)S#0H@("`@*B!`<V5E
M("`@("`@<F5V97)S945N=&ET:65S*"D-"B`@("`J+PT*("`@(&9U;F-T:6]N
M(')E<&QA8V5%;G1I=&EE<R@D<W1R:6YG+"`D<F5P;&%C945N=&ET:65S(#T@
M6$U,7U5424Q?14Y4251)15-?6$U,*0T*("`@('L-"B`@("`@("`@<W=I=&-H
M("@D<F5P;&%C945N=&ET:65S*2![#0H@("`@("`@("`@("!C87-E(%A-3%]5
M5$E,7T5.5$E424537UA-3#H-"B`@("`@("`@("`@("`@("!R971U<FX@<W1R
M='(H)'-T<FEN9RQA<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("<F)R`@/3X@)R9A;7`[)RP-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<^)R`@/3X@)R9G=#LG
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)SPG("`]/B`G)FQT.R<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G(B<@(#T^("<F<75O=#LG+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)UPG)R`]/B`G)F%P;W,[
M)R`I*3L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A
M<V4@6$U,7U5424Q?14Y4251)15-?6$U,7U)%455)4D5$.@T*("`@("`@("`@
M("`@("`@(')E='5R;B!S=')T<B@D<W1R:6YG+&%R<F%Y*`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R8G("`]/B`G)F%M
M<#LG+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)SPG("`]/B`G)FQT.R<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G(B<@(#T^("<F<75O=#LG("DI.PT*("`@("`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92!834Q?551)3%]%
M3E1)5$E%4U](5$U,.@T*("`@("`@("`@("`@("`@(')E='5R;B!H=&UL96YT
M:71I97,H)'-T<FEN9RD[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N("1S=')I;F<[#0H@("`@?0T*#0H@("`O
M*BH-"B`@("`J(')E=F5R<V4@6$U,(&5N=&ET:65S#0H@("`@*@T*("`@("H@
M5VET:"!T:&4@;W!T:6]N86P@<V5C;VYD('!A<F%M971E<BP@>6]U(&UA>2!S
M96QE8W0L('=H:6-H#0H@("`@*B!E;G1I=&EE<R!S:&]U;&0@8F4@<F5V97)S
M960N#0H@("`@*@T*("`@("H@/&-O9&4^#0H@("`@*B!R97%U:7)E7V]N8V4@
M)UA-3"]5=&EL+G!H<"<[#0H@("`@*B`-"B`@("`J("\O(')E=F5R<V4@6$U,
M(&5N=&ET97,Z#0H@("`@*B`D<W1R:6YG(#T@6$U,7U5T:6PZ.G)E=F5R<V5%
M;G1I=&EE<R@B5&AI<R!S=')I;F<@8V]N=&%I;G,@)FQT.R`F86UP.R`F9W0[
M+B(I.PT*("`@("H@/"]C;V1E/@T*("`@("H-"B`@("`J($!A8V-E<W,@("!P
M=6)L:6,-"B`@("`J($!S=&%T:6,-"B`@("`J($!P87)A;2`@("!S=')I;F<@
M('-T<FEN9R!W:&5R92!834P@<W!E8VEA;"!C:&%R<R!S:&]U;&0@8F4@<F5P
M;&%C960-"B`@("`J($!P87)A;2`@("!I;G1E9V5R('-E='1I;F<@9F]R(&5N
M=&ET:65S(&EN(&%T=')I8G5T92!V86QU97,@*&]N92!O9B!834Q?551)3%]%
M3E1)5$E%4U]834PL(%A-3%]55$E,7T5.5$E424537UA-3%]215%525)%1"P@
M6$U,7U5424Q?14Y4251)15-?2%1-3"D-"B`@("`J($!R971U<FX@("!S=')I
M;F<@('-T<FEN9R!W:71H(')E<&QA8V5D(&-H87)S#0H@("`@*B!`<V5E("`@
M("`@<F5P;&%C945N=&ET:65S*"D-"B`@("`J+PT*("`@(&9U;F-T:6]N(')E
M=F5R<V5%;G1I=&EE<R@D<W1R:6YG+"`D<F5P;&%C945N=&ET:65S(#T@6$U,
M7U5424Q?14Y4251)15-?6$U,*0T*("`@('L-"B`@("`@("`@<W=I=&-H("@D
M<F5P;&%C945N=&ET:65S*2![#0H@("`@("`@("`@("!C87-E(%A-3%]55$E,
M7T5.5$E424537UA-3#H-"B`@("`@("`@("`@("`@("!R971U<FX@<W1R='(H
M)'-T<FEN9RQA<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("<F86UP.R<@(#T^("<F)RP-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("<F9W0[)R`@(#T^("<^)RP-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<F
M;'0[)R`@(#T^("<\)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("<F<75O=#LG(#T^("<B)RP-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("<F87!O<SLG(#T^("=<)R<@
M*2D[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E
M(%A-3%]55$E,7T5.5$E424537UA-3%]215%525)%1#H-"B`@("`@("`@("`@
M("`@("!R971U<FX@<W1R='(H)'-T<FEN9RQA<G)A>2@-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<F86UP.R<@(#T^("<F
M)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("<F;'0[)R`@(#T^("<\)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("<F<75O=#LG(#T^("<B)R`I*3L-"B`@("`@("`@
M("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@6$U,7U5424Q?14Y4
M251)15-?2%1-3#H-"B`@("`@("`@("`@("`@("`D87)R(#T@87)R87E?9FQI
M<"AG971?:'1M;%]T<F%N<VQA=&EO;E]T86)L92A(5$U,7T5.5$E42453*2D[
M#0H@("`@("`@("`@("`@("`@<F5T=7)N('-T<G1R*"1S=')I;F<L("1A<G(I
M.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B`D<W1R:6YG.PT*("`@('T-"@T*("`@+RHJ#0H@("`@*B!B=6EL
M9"!A;B!X;6P@9&5C;&%R871I;VX-"B`@("`J#0H@("`@*B`\8V]D93X-"B`@
M("`J(')E<75I<F5?;VYC92`G6$U,+U5T:6PN<&AP)SL-"B`@("`J(`T*("`@
M("H@+R\@9V5T(&%N(%A-3"!D96-L87)A=&EO;CH-"B`@("`J("1X;6Q$96-L
M(#T@6$U,7U5T:6PZ.F=E=%A-3$1E8VQA<F%T:6]N*"(Q+C`B+"`B551&+3@B
M+"!T<G5E*3L-"B`@("`J(#PO8V]D93X-"B`@("`J#0H@("`@*B!`86-C97-S
M("`@<'5B;&EC#0H@("`@*B!`<W1A=&EC#0H@("`@*B!`<&%R86T@("`@<W1R
M:6YG("`D=F5R<VEO;B`@("`@>&UL('9E<G-I;VX-"B`@("`J($!P87)A;2`@
M("!S=')I;F<@("1E;F-O9&EN9R`@("!C:&%R86-T97(@96YC;V1I;F<-"B`@
M("`J($!P87)A;2`@("!B;V]L96%N("1S=&%N9$%L;VYE("!D;V-U;65N="!I
M<R!S=&%N9&%L;VYE("AO<B!N;W0I#0H@("`@*B!`<F5T=7)N("`@<W1R:6YG
M("`D9&5C;"!X;6P@9&5C;&%R871I;VX-"B`@("`J($!U<V5S("`@("!834Q?
M571I;#HZ871T<FEB=71E<U1O4W1R:6YG*"D@=&\@<V5R:6%L:7IE('1H92!A
M='1R:6)U=&5S(&]F('1H92!834P@9&5C;&%R871I;VX-"B`@("`J+PT*("`@
M(&9U;F-T:6]N(&=E=%A-3$1E8VQA<F%T:6]N*"1V97)S:6]N(#T@(C$N,"(L
M("1E;F-O9&EN9R`](&YU;&PL("1S=&%N9&%L;VYE(#T@;G5L;"D-"B`@("![
M#0H@("`@("`@("1A='1R:6)U=&5S(#T@87)R87DH#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(G9E<G-I;VXB(#T^("1V97)S:6]N+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@+R\@861D(&5N8V]D
M:6YG#0H@("`@("`@(&EF("@D96YC;V1I;F<@(3T](&YU;&PI('L-"B`@("`@
M("`@("`@("1A='1R:6)U=&5S6R)E;F-O9&EN9R)=(#T@)&5N8V]D:6YG.PT*
M("`@("`@("!]#0H@("`@("`@("\O(&%D9"!S=&%N9&%L;VYE+"!I9B!S<&5C
M:69I960-"B`@("`@("`@:68@*"1S=&%N9&%L;VYE("$]/2!N=6QL*2![#0H@
M("`@("`@("`@("`D871T<FEB=71E<ULB<W1A;F1A;&]N92)=(#T@)'-T86YD
M86QO;F4@/R`B>65S(B`Z(")N;R([#0H@("`@("`@('T-"B`@("`@("`@#0H@
M("`@("`@(')E='5R;B!S<')I;G1F*"(\/WAM;"5S/SXB+"!834Q?571I;#HZ
M871T<FEB=71E<U1O4W1R:6YG*"1A='1R:6)U=&5S+"!F86QS92DI.PT*("`@
M('T-"@T*("`@+RHJ#0H@("`@*B!B=6EL9"!A(&1O8W5M96YT('1Y<&4@9&5C
M;&%R871I;VX-"B`@("`J#0H@("`@*B`\8V]D93X-"B`@("`J(')E<75I<F5?
M;VYC92`G6$U,+U5T:6PN<&AP)SL-"B`@("`J(`T*("`@("H@+R\@9V5T(&$@
M9&]C='EP92!D96-L87)A=&EO;CH-"B`@("`J("1X;6Q$96-L(#T@6$U,7U5T
M:6PZ.F=E=$1O8U1Y<&5$96-L87)A=&EO;B@B<F]O=%1A9R(L(FUY1&]C5'EP
M92YD=&0B*3L-"B`@("`J(#PO8V]D93X-"B`@("`J#0H@("`@*B!`86-C97-S
M("`@<'5B;&EC#0H@("`@*B!`<W1A=&EC#0H@("`@*B!`<&%R86T@("`@<W1R
M:6YG("`D<F]O="`@("`@("`@(&YA;64@;V8@=&AE(')O;W0@=&%G#0H@("`@
M*B!`<&%R86T@("`@<W1R:6YG("`D=7)I("`@("`@("`@('5R:2!O9B!T:&4@
M9&]C='EP92!D969I;FET:6]N("AO<B!A<G)A>2!W:71H('5R:2!A;F0@<'5B
M;&EC(&ED*0T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)&EN=&5R;F%L1'1D
M("!I;G1E<FYA;"!D=&0@96YT<FEE<R`@(`T*("`@("H@0')E='5R;B`@('-T
M<FEN9R`@)&1E8VP@("`@("`@("!D;V-T>7!E(&1E8VQA<F%T:6]N#0H@("`@
M*B!`<VEN8V4@("`@,"XR#0H@("`@*B\-"B`@("!F=6YC=&EO;B!G971$;V-4
M>7!E1&5C;&%R871I;VXH)')O;W0L("1U<FD@/2!N=6QL+"`D:6YT97)N86Q$
M=&0@/2!N=6QL*0T*("`@('L-"B`@("`@("`@:68@*&ES7V%R<F%Y*"1U<FDI
M*2![#0H@("`@("`@("`@("`D<F5F(#T@<W!R:6YT9B@@)R!054),24,@(B5S
M(B`B)7,B)RP@)'5R:5LB:60B72P@)'5R:5LB=7)I(ET@*3L-"B`@("`@("`@
M?2!E;'-E:68@*"%E;7!T>2@D=7)I*2D@>PT*("`@("`@("`@("`@)')E9B`]
M('-P<FEN=&8H("<@4UE35$5-("(E<R(G+"`D=7)I("D[#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`D<F5F(#T@(B([#0H@("`@("`@('T-"@T*
M("`@("`@("!I9B`H96UP='DH)&EN=&5R;F%L1'1D*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N('-P<FEN=&8H(CPA1$]#5%E012`E<R5S/B(L("1R;V]T+"`D
M<F5F*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(')E='5R;B!S
M<')I;G1F*"(\(41/0U194$4@)7,E<R!;7&XE<UQN73XB+"`D<F]O="P@)')E
M9BP@)&EN=&5R;F%L1'1D*3L-"B`@("`@("`@?0T*("`@('T-"@T*("`@+RHJ
M#0H@("`@*B!C<F5A=&4@<W1R:6YG(')E<')E<V5N=&%T:6]N(&]F(&%N(&%T
M=')I8G5T92!L:7-T#0H@("`@*@T*("`@("H@/&-O9&4^#0H@("`@*B!R97%U
M:7)E7V]N8V4@)UA-3"]5=&EL+G!H<"<[#0H@("`@*B`-"B`@("`J("\O(&)U
M:6QD(&%N(&%T=')I8G5T92!S=')I;F<-"B`@("`J("1A='0@/2!A<G)A>2@-
M"B`@("`J("`@("`@("`@("`@("`B9F]O(B`@(#T^("`B8F%R(BP-"B`@("`J
M("`@("`@("`@("`@("`B87)G:"(@(#T^("`B=&]M871O(@T*("`@("H@("`@
M("`@("`@("`I.PT*("`@("H-"B`@("`J("1A='1,:7-T(#T@6$U,7U5T:6PZ
M.F%T=')I8G5T97-4;U-T<FEN9R@D871T*3L@("`@#0H@("`@*B`\+V-O9&4^
M#0H@("`@*@T*("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("H@0'-T871I
M8PT*("`@("H@0'!A<F%M("`@(&%R<F%Y("`@("`@("`@)&%T=')I8G5T97,@
M("`@("`@(&%T=')I8G5T92!A<G)A>0T*("`@("H@0'!A<F%M("`@(&)O;VQE
M86Y\87)R87D@)'-O<G0@("`@("`@("`@("`@('-O<G0@871T<FEB=71E(&QI
M<W0@86QP:&%B971I8V%L;'DL(&UA>2!A;'-O(&)E(&%N(&%S<V]C(&%R<F%Y
M(&-O;G1A:6YI;F<@=&AE(&ME>7,@)W-O<G0G+"`G;75L=&EL:6YE)RP@)VEN
M9&5N="<L("=L:6YE8G)E86LG(&%N9"`G96YT:71I97,G#0H@("`@*B!`<&%R
M86T@("`@8F]O;&5A;B`@("`@("`D;75L=&EL:6YE("`@("`@("`@=7-E(&QI
M;F5B<F5A:W,L(&EF(&UO<F4@=&AA;B!O;F4@871T<FEB=71E(&ES(&=I=F5N
M#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`@("`@("`D:6YD96YT("`@("`@
M("`@("`@<W1R:6YG('5S960@9F]R(&EN9&5N=&%T:6]N(&]F(&UU;'1I;&EN
M92!A='1R:6)U=&5S#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`@("`@("`D
M;&EN96)R96%K("`@("`@("`@<W1R:6YG('5S960@9F]R(&QI;F5B<F5A:W,@
M;V8@;75L=&EL:6YE(&%T=')I8G5T97,-"B`@("`J($!P87)A;2`@("!I;G1E
M9V5R("`@("`@("1E;G1I=&EE<R`@("`@("`@("!S971T:6YG(&9O<B!E;G1I
M=&EE<R!I;B!A='1R:6)U=&4@=F%L=65S("AO;F4@;V8@6$U,7U5424Q?14Y4
M251)15-?3D].12P@6$U,7U5424Q?14Y4251)15-?6$U,+"!834Q?551)3%]%
M3E1)5$E%4U]834Q?4D5154E2140L(%A-3%]55$E,7T5.5$E424537TA434PI
M#0H@("`@*B!`<F5T=7)N("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<W1R:6YG(')E<')E<V5N=&%T:6]N(&]F('1H92!A='1R:6)U=&5S
M#0H@("`@*B!`=7-E<R`@("`@6$U,7U5T:6PZ.G)E<&QA8V5%;G1I=&EE<R@I
M('1O(')E<&QA8V4@6$U,(&5N=&ET:65S(&EN(&%T=')I8G5T92!V86QU97,-
M"B`@("`J($!T;V1O("`@("!A;&QO=R!S;W)T(&%L<V\@=&\@8F4@86X@;W!T
M:6]N<R!A<G)A>0T*("`@("HO#0H@("`@9G5N8W1I;VX@871T<FEB=71E<U1O
M4W1R:6YG*"1A='1R:6)U=&5S+"`D<V]R="`]('1R=64L("1M=6QT:6QI;F4@
M/2!F86QS92P@)&EN9&5N="`]("<@("`@)RP@)&QI;F5B<F5A:R`](")<;B(L
M("1E;G1I=&EE<R`](%A-3%]55$E,7T5.5$E424537UA-3"D-"B`@("![#0H@
M("`@("`@("\J*@T*("`@("`@("`@*B!S96-O;F0@<&%R86UE=&5R(&UA>2!B
M92!A;B!A<G)A>0T*("`@("`@("`@*B\-"B`@("`@("`@:68@*&ES7V%R<F%Y
M*"1S;W)T*2D@>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1S;W)T6R=M=6QT
M:6QI;F4G72DI('L-"B`@("`@("`@("`@("`@("`D;75L=&EL:6YE(#T@)'-O
M<G1;)VUU;'1I;&EN92==.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M:68@*&ES<V5T*"1S;W)T6R=I;F1E;G0G72DI('L-"B`@("`@("`@("`@("`@
M("`D:6YD96YT(#T@)'-O<G1;)VEN9&5N="==.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@:68@*&ES<V5T*"1S;W)T6R=L:6YE8G)E86LG72DI('L-
M"B`@("`@("`@("`@("`@("`D;75L=&EL:6YE(#T@)'-O<G1;)VQI;F5B<F5A
M:R==.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1S
M;W)T6R=E;G1I=&EE<R==*2D@>PT*("`@("`@("`@("`@("`@("1E;G1I=&EE
M<R`]("1S;W)T6R=E;G1I=&EE<R==.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@:68@*&ES<V5T*"1S;W)T6R=S;W)T)UTI*2![#0H@("`@("`@("`@
M("`@("`@)'-O<G0@/2`D<V]R=%LG<V]R="==.PT*("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`D<V]R="`]('1R=64[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)'-T<FEN9R`]("<G.PT*("`@
M("`@("!I9B`H:7-?87)R87DH)&%T=')I8G5T97,I("8F("%E;7!T>2@D871T
M<FEB=71E<RDI('L-"B`@("`@("`@("`@(&EF("@D<V]R="D@>PT*("`@("`@
M("`@("`@("`@(&MS;W)T*"1A='1R:6)U=&5S*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(&EF*"`A)&UU;'1I;&EN92!\?"!C;W5N="@D871T<FEB
M=71E<RD@/3T@,2D@>PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1A='1R
M:6)U=&5S(&%S("1K97D@/3X@)'9A;'5E*2![#0H@("`@("`@("`@("`@("`@
M("`@(&EF("@D96YT:71I97,@(3T@6$U,7U5424Q?14Y4251)15-?3D].12D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1E;G1I=&EE<R`]/3T@
M6$U,7U5424Q?0T1!5$%?4T5#5$E/3BD@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@"21E;G1I=&EE<R`](%A-3%]55$E,7T5.5$E424537UA-3#L-"B`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1V86QU92`](%A-3%]5=&EL.CIR97!L86-E16YT:71I97,H)'9A;'5E
M+"`D96YT:71I97,I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("1S=')I;F<@+CT@)R`G+B1K97DN)STB)RXD=F%L=64N
M)R(G.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@)&9I<G-T(#T@=')U93L-"B`@("`@("`@("`@
M("`@("!F;W)E86-H("@D871T<FEB=71E<R!A<R`D:V5Y(#T^("1V86QU92D@
M>PT*("`@("`@("`@("`@("`@("`@("!I9B`H)&5N=&ET:65S("$](%A-3%]5
M5$E,7T5.5$E424537TY/3D4I('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1V86QU92`](%A-3%]5=&EL.CIR97!L86-E16YT:71I97,H)'9A;'5E+"`D
M96YT:71I97,I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@D9FER<W0I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1S=')I;F<@+CT@(B`B+B1K97DN)STB)RXD=F%L=64N)R(G.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)&9I<G-T(#T@9F%L<V4[#0H@("`@("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D<W1R:6YG("X]("1L:6YE8G)E86LN)&EN9&5N="XD:V5Y+B<](B<N)'9A
M;'5E+B<B)SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@)'-T<FEN9SL-"B`@("!]#0H-"B`@("\J*@T*("`@("H@0V]L;&%P<V5S
M(&5M<'1Y('1A9W,N#0H@("`@*@T*("`@("H@0&%C8V5S<R`@('!U8FQI8PT*
M("`@("H@0'-T871I8PT*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)'AM;"`@
M6$U,#0H@("`@*B!`<&%R86T@("`@:6YT96=E<B`D;6]D92!7:&5T:&5R('1O
M(&-O;&QA<'-E(&%L;"!E;7!T>2!T86=S("A834Q?551)3%]#3TQ,05!315]!
M3$PI(&]R(&]N;'D@6$A434P@*%A-3%]55$E,7T-/3$Q!4%-%7UA(5$U,7T].
M3%DI(&]N97,N#0H@("`@*B!`<F5T=7)N("`@<W1R:6YG("`D>&UL("!834P-
M"B`@("`J+PT*("`@(&9U;F-T:6]N(&-O;&QA<'-E16UP='E486=S*"1X;6PL
M("1M;V1E(#T@6$U,7U5424Q?0T],3$%04T5?04Q,*2![#0H@("`@("`@(&EF
M("@D;6]D92`]/2!834Q?551)3%]#3TQ,05!315]82%1-3%]/3DQ9*2![#0H@
M("`@("`@("`@("!R971U<FX@<')E9U]R97!L86-E*`T*("`@("`@("`@("`@
M("`G+SPH87)E87QB87-E?&)R?&-O;'QH<GQI;6=\:6YP=71\;&EN:WQM971A
M?'!A<F%M*2A;7CY=*BD^/%PO7%PQ/B]S)RP-"B`@("`@("`@("`@("`@)SQ<
M7#%<7#(@+SXG+`T*("`@("`@("`@("`@("`D>&UL#0H@("`@("`@("`@("`I
M.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@<F5T=7)N('!R96=?
M<F5P;&%C92@-"B`@("`@("`@("`@("`@)R\\*%QW*RDH6UX^72HI/CQ<+UQ<
M,3XO<R<L#0H@("`@("`@("`@("`@("<\7%PQ7%PR("\^)RP-"B`@("`@("`@
M("`@("`@)'AM;`T*("`@("`@("`@("`@*3L-"B`@("`@("`@?0T*("`@('T-
M"@T*("`@+RHJ#0H@("`@*B!C<F5A=&4@82!T86<-"B`@("`J#0H@("`@*B!4
M:&ES(&UE=&AO9"!W:6QL(&-A;&P@6$U,7U5T:6PZ.F-R96%T951A9T9R;VU!
M<G)A>2@I+"!W:&EC:`T*("`@("H@:7,@;6]R92!F;&5X:6)L92X-"B`@("`J
M#0H@("`@*B`\8V]D93X-"B`@("`J(')E<75I<F5?;VYC92`G6$U,+U5T:6PN
M<&AP)SL-"B`@("`J(`T*("`@("H@+R\@8W)E871E(&%N(%A-3"!T86<Z#0H@
M("`@*B`D=&%G(#T@6$U,7U5T:6PZ.F-R96%T951A9R@B;7E.<SIM>51A9R(L
M(&%R<F%Y*")F;V\B(#T^(")B87(B*2P@(E1H:7,@:7,@:6YS:61E('1H92!T
M86<B+"`B:'1T<#HO+W=W=RYW,V,N;W)G+VUY3G,C(BD[#0H@("`@*B`\+V-O
M9&4^#0H@("`@*@T*("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("H@0'-T
M871I8PT*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)'%N86UE("`@("`@("`@
M("`@('%U86QI9FEE9"!T86=N86UE("AI;F-L=61I;F<@;F%M97-P86-E*0T*
M("`@("H@0'!A<F%M("`@(&%R<F%Y("`@)&%T=')I8G5T97,@("`@("`@(&%R
M<F%Y(&-O;G1A:6YG(&%T=')I8G5T97,-"B`@("`J($!P87)A;2`@("!M:7AE
M9"`@("1C;VYT96YT#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D;F%M97-P
M86-E57)I("`@("`@55))(&]F('1H92!N86UE<W!A8V4-"B`@("`J($!P87)A
M;2`@("!I;G1E9V5R("1R97!L86-E16YT:71I97,@("!W:&5T:&5R('1O(')E
M<&QA8V4@6$U,('-P96-I86P@8VAA<G,@:6X@8V]N=&5N="P@96UB961D(&ET
M(&EN(&$@0T1A=&$@<V5C=&EO;B!O<B!N;VYE(&]F(&)O=&@-"B`@("`J($!P
M87)A;2`@("!B;V]L96%N("1M=6QT:6QI;F4@("`@("`@("!W:&5T:&5R('1O
M(&-R96%T92!A(&UU;'1I;&EN92!T86<@=VAE<F4@96%C:"!A='1R:6)U=&4@
M9V5T<R!W<FET=&5N('1O(&$@<VEN9VQE(&QI;F4-"B`@("`J($!P87)A;2`@
M("!S=')I;F<@("1I;F1E;G0@("`@("`@("`@("!S=')I;F<@=7-E9"!T;R!I
M;F1E;G0@871T<FEB=71E<R`H7V%U=&\@:6YD96YT<R!A='1R:6)U=&5S('-O
M('1H97D@<W1A<G0@870@=&AE('-A;64@8V]L=6UN*0T*("`@("H@0'!A<F%M
M("`@('-T<FEN9R`@)&QI;F5B<F5A:R`@("`@("`@('-T<FEN9R!U<V5D(&9O
M<B!L:6YE8G)E86MS#0H@("`@*B!`<F5T=7)N("`@<W1R:6YG("`D<W1R:6YG
M("`@("`@("`@("`@6$U,('1A9PT*("`@("H@0'-E92`@("`@(%A-3%]5=&EL
M.CIC<F5A=&5486=&<F]M07)R87DH*0T*("`@("H@0'5S97,@("`@(%A-3%]5
M=&EL.CIC<F5A=&5486=&<F]M07)R87DH*2!T;R!C<F5A=&4@=&AE('1A9PT*
M("`@("HO#0H@("`@9G5N8W1I;VX@8W)E871E5&%G*"1Q;F%M92P@)&%T=')I
M8G5T97,@/2!A<G)A>2@I+"`D8V]N=&5N="`](&YU;&PL("1N86UE<W!A8V55
M<FD@/2!N=6QL+"`D<F5P;&%C945N=&ET:65S(#T@6$U,7U5424Q?4D503$%#
M15]%3E1)5$E%4RP@)&UU;'1I;&EN92`](&9A;'-E+"`D:6YD96YT(#T@(E]A
M=71O(BP@)&QI;F5B<F5A:R`](")<;B(I#0H@("`@>PT*("`@("`@("`D=&%G
M(#T@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`B<6YA;64B("`@("`@
M/3X@)'%N86UE+`T*("`@("`@("`@("`@("`@("`@("`@(F%T=')I8G5T97,B
M(#T^("1A='1R:6)U=&5S#0H@("`@("`@("`@("`@("`@("`@("D[#0H-"B`@
M("`@("`@+R\@861D('1A9R!C;VYT96YT#0H@("`@("`@(&EF("@D8V]N=&5N
M="`A/3T@;G5L;"D@>PT*("`@("`@("`@("`@)'1A9ULB8V]N=&5N=")=(#T@
M)&-O;G1E;G0[#0H@("`@("`@('T-"B`@("`@("`@#0H@("`@("`@("\O(&%D
M9"!N86UE<W!A8V4@57)I#0H@("`@("`@(&EF("@D;F%M97-P86-E57)I("$]
M/2!N=6QL*2![#0H@("`@("`@("`@("`D=&%G6R)N86UE<W!A8V55<FDB72`]
M("1N86UE<W!A8V55<FD[#0H@("`@("`@('T-"@T*("`@("`@("!R971U<FX@
M6$U,7U5T:6PZ.F-R96%T951A9T9R;VU!<G)A>2@D=&%G+"`D<F5P;&%C945N
M=&ET:65S+"`D;75L=&EL:6YE+"`D:6YD96YT+"`D;&EN96)R96%K*3L-"B`@
M("!]#0H-"B`@("\J*@T*("`@("H@8W)E871E(&$@=&%G(&9R;VT@86X@87)R
M87D-"B`@("`J('1H:7,@;65T:&]D(&%W86ET<R!A;B!A<G)A>2!I;B!T:&4@
M9F]L;&]W:6YG(&9O<FUA=`T*("`@("H@/'!R93X-"B`@("`J(&%R<F%Y*`T*
M("`@("H@(")Q;F%M92(@("`@("`@(#T^("1Q;F%M92`@("`@("`@("\O('%U
M86QI9FEE9"!N86UE(&]F('1H92!T86<-"B`@("`J("`B;F%M97-P86-E(B`@
M("`]/B`D;F%M97-P86-E("`@("`O+R!N86UE<W!A8V4@<')E9FEX("AO<'1I
M;VYA;"P@:68@<6YA;64@:7,@<W!E8VEF:65D(&]R(&YO(&YA;65S<&%C92D-
M"B`@("`J("`B;&]C86QP87)T(B`@("`]/B`D;&]C86QP87)T+"`@("`O+R!L
M;V-A;"!P87)T(&]F('1H92!T86=N86UE("AO<'1I;VYA;"P@:68@<6YA;64@
M:7,@<W!E8VEF:65D*0T*("`@("H@(")A='1R:6)U=&5S(B`@(#T^(&%R<F%Y
M*"DL("`@("`@("\O(&%R<F%Y(&-O;G1A:6YI;F<@86QL(&%T=')I8G5T97,@
M*&]P=&EO;F%L*0T*("`@("H@(")C;VYT96YT(B`@("`@(#T^("1C;VYT96YT
M+"`@("`@("\O('1A9R!C;VYT96YT("AO<'1I;VYA;"D-"B`@("`J("`B;F%M
M97-P86-E57)I(B`]/B`D;F%M97-P86-E57)I("`O+R!N86UE<W!A8V55<FD@
M9F]R('1H92!G:79E;B!N86UE<W!A8V4@*&]P=&EO;F%L*0T*("`@("H@("`I
M#0H@("`@*B`\+W!R93X-"B`@("`J#0H@("`@*B`\8V]D93X-"B`@("`J(')E
M<75I<F5?;VYC92`G6$U,+U5T:6PN<&AP)SL-"B`@("`J(`T*("`@("H@)'1A
M9R`](&%R<F%Y*`T*("`@("H@("`@("`@("`@(")Q;F%M92(@("`@("`@(#T^
M(")F;V\Z8F%R(BP-"B`@("`J("`@("`@("`@("`B;F%M97-P86-E57)I(B`]
M/B`B:'1T<#HO+V9O;RYC;VTB+`T*("`@("H@("`@("`@("`@(")A='1R:6)U
M=&5S(B`@(#T^(&%R<F%Y*"`B:V5Y(B`]/B`B=F%L=64B+"`B87)G:"(@/3X@
M(F9R=6ET)G9E9V5T86)L92(@*2P-"B`@("`J("`@("`@("`@("`B8V]N=&5N
M="(@("`@("`]/B`B22=M(&EN<VED92!T:&4@=&%G(BP-"B`@("`J("`@("`@
M("`@("`@*3L-"B`@("`J("\O(&-R96%T:6YG(&$@=&%G('=I=&@@<75A;&EF
M:65D(&YA;64@86YD(&YA;65S<&%C955R:0T*("`@("H@)'-T<FEN9R`](%A-
M3%]5=&EL.CIC<F5A=&5486=&<F]M07)R87DH)'1A9RD[#0H@("`@*B`\+V-O
M9&4^#0H@("`@*@T*("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("H@0'-T
M871I8PT*("`@("H@0'!A<F%M("`@(&%R<F%Y("`@)'1A9R`@("`@("`@("`@
M("`@('1A9R!D969I;FET:6]N#0H@("`@*B!`<&%R86T@("`@:6YT96=E<B`D
M<F5P;&%C945N=&ET:65S("`@=VAE=&AE<B!T;R!R97!L86-E(%A-3"!S<&5C
M:6%L(&-H87)S(&EN(&-O;G1E;G0L(&5M8F5D9"!I="!I;B!A($-$871A('-E
M8W1I;VX@;W(@;F]N92!O9B!B;W1H#0H@("`@*B!`<&%R86T@("`@8F]O;&5A
M;B`D;75L=&EL:6YE("`@("`@("`@=VAE=&AE<B!T;R!C<F5A=&4@82!M=6QT
M:6QI;F4@=&%G('=H97)E(&5A8V@@871T<FEB=71E(&=E=',@=W)I='1E;B!T
M;R!A('-I;F=L92!L:6YE#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D:6YD
M96YT("`@("`@("`@("`@<W1R:6YG('5S960@=&\@:6YD96YT(&%T=')I8G5T
M97,@*%]A=71O(&EN9&5N=',@871T<FEB=71E<R!S;R!T:&5Y('-T87)T(&%T
M('1H92!S86UE(&-O;'5M;BD-"B`@("`J($!P87)A;2`@("!S=')I;F<@("1L
M:6YE8G)E86L@("`@("`@("!S=')I;F<@=7-E9"!F;W(@;&EN96)R96%K<PT*
M("`@("H@0')E='5R;B`@('-T<FEN9R`@)'-T<FEN9R`@("`@("`@("`@(%A-
M3"!T86<-"B`@("`J($!S964@("`@("!834Q?571I;#HZ8W)E871E5&%G*"D-
M"B`@("`J($!U<V5S("`@("!834Q?571I;#HZ871T<FEB=71E<U1O4W1R:6YG
M*"D@=&\@<V5R:6%L:7IE('1H92!A='1R:6)U=&5S(&]F('1H92!T86<-"B`@
M("`J($!U<V5S("`@("!834Q?571I;#HZ<W!L:711=6%L:69I961.86UE*"D@
M=&\@9V5T(&QO8V%L('!A<G0@86YD(&YA;65S<&%C92!O9B!A('%U86QI9FEE
M9"!N86UE#0H@("`@*B\-"B`@("!F=6YC=&EO;B!C<F5A=&5486=&<F]M07)R
M87DH)'1A9RP@)')E<&QA8V5%;G1I=&EE<R`](%A-3%]55$E,7U)%4$Q!0T5?
M14Y4251)15,L("1M=6QT:6QI;F4@/2!F86QS92P@)&EN9&5N="`](")?875T
M;R(L("1L:6YE8G)E86L@/2`B7&XB("D-"B`@("![#0H@("`@("`@(&EF("AI
M<W-E="@D=&%G6R=C;VYT96YT)UTI("8F("%I<U]S8V%L87(H)'1A9ULG8V]N
M=&5N="==*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%A-3%]5=&EL.CIR86ES
M945R<F]R*"`G4W5P<&QI960@;F]N+7-C86QA<B!V86QU92!A<R!T86<@8V]N
M=&5N="<L(%A-3%]55$E,7T524D]27TY/3E]30T%,05)?0T].5$5.5"`I.PT*
M("`@("`@("!]#0H-"B`@("`@("`@:68@*"%I<W-E="@D=&%G6R=Q;F%M92==
M*2`F)B`A:7-S970H)'1A9ULG;&]C86Q087)T)UTI*2![#0H@("`@("`@("`@
M("!R971U<FX@6$U,7U5T:6PZ.G)A:7-E17)R;W(H("=9;W4@;75S="!E:71H
M97(@<W5P<&QY(&$@<75A;&EF:65D(&YA;64@*'%N86UE*2!O<B!L;V-A;"!T
M86<@;F%M92`H;&]C86Q087)T*2XG+"!834Q?551)3%]%4E)/4E].3U]404=?
M3D%-12`I.PT*("`@("`@("!]#0H-"B`@("`@("`@+R\@:68@;F\@871T<FEB
M=71E<R!H878@8F5E;B!S970L('5S92!E;7!T>2!A='1R:6)U=&5S#0H@("`@
M("`@(&EF("@A:7-S970H)'1A9ULB871T<FEB=71E<R)=*2!\?"`A:7-?87)R
M87DH)'1A9ULB871T<FEB=71E<R)=*2D@>PT*("`@("`@("`@("`@)'1A9ULB
M871T<FEB=71E<R)=(#T@87)R87DH*3L-"B`@("`@("`@?0T*("`@("`@("`-
M"B`@("`@("`@+R\@<75A;&EF:65D(&YA;64@:7,@;F]T(&=I=F5N#0H@("`@
M("`@(&EF("@A:7-S970H)'1A9ULB<6YA;64B72DI('L-"B`@("`@("`@("`@
M("\O(&-H96-K(&9O<B!N86UE<W!A8V4-"B`@("`@("`@("`@(&EF("AI<W-E
M="@D=&%G6R)N86UE<W!A8V4B72D@)B8@(65M<'1Y*"1T86=;(FYA;65S<&%C
M92)=*2D@>PT*("`@("`@("`@("`@("`@("1T86=;(G%N86UE(ET@/2`D=&%G
M6R)N86UE<W!A8V4B72XB.B(N)'1A9ULB;&]C86Q087)T(ET[#0H@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1T86=;(G%N86UE(ET@
M/2`D=&%G6R)L;V-A;%!A<G0B73L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M+R\@;F%M97-P86-E(%5222!I<R!S970L(&)U="!N;R!N86UE<W!A8V4-"B`@
M("`@("`@?2!E;'-E:68@*&ES<V5T*"1T86=;(FYA;65S<&%C955R:2)=*2`F
M)B`A:7-S970H)'1A9ULB;F%M97-P86-E(ETI*2![#0H@("`@("`@("`@("`D
M<&%R=',@/2!834Q?571I;#HZ<W!L:711=6%L:69I961.86UE*"1T86=;(G%N
M86UE(ETI.PT*("`@("`@("`@("`@)'1A9ULB;&]C86Q087)T(ET@/2`D<&%R
M='-;(FQO8V%L4&%R=")=.PT*("`@("`@("`@("`@:68@*&ES<V5T*"1P87)T
M<ULB;F%M97-P86-E(ETI*2![#0H@("`@("`@("`@("`@("`@)'1A9ULB;F%M
M97-P86-E(ET@/2`D<&%R='-;(FYA;65S<&%C92)=.PT*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H-"B`@("`@("`@:68@*&ES<V5T*"1T86=;(FYA;65S
M<&%C955R:2)=*2`F)B`A96UP='DH)'1A9ULB;F%M97-P86-E57)I(ETI*2![
M#0H@("`@("`@("`@("`O+R!I<R!A(&YA;65S<&%C92!G:79E;@T*("`@("`@
M("`@("`@:68@*&ES<V5T*"1T86=;(FYA;65S<&%C92)=*2`F)B`A96UP='DH
M)'1A9ULB;F%M97-P86-E(ETI*2![#0H@("`@("`@("`@("`@("`@)'1A9ULB
M871T<FEB=71E<R)=6R)X;6QN<SHB+B1T86=;(FYA;65S<&%C92)=72`]("1T
M86=;(FYA;65S<&%C955R:2)=.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`O+R!D969I;F4@=&AI<R!5<FD@87,@=&AE(&1E9F%U
M;'0@;F%M97-P86-E#0H@("`@("`@("`@("`@("`@)'1A9ULB871T<FEB=71E
M<R)=6R)X;6QN<R)=(#T@)'1A9ULB;F%M97-P86-E57)I(ET[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"@T*("`@("`@("`O+R!C:&5C:R!F;W(@;75L
M=&EL:6YE(&%T=')I8G5T97,-"B`@("`@("`@:68@*"1M=6QT:6QI;F4@/3T]
M('1R=64I('L-"B`@("`@("`@("`@(&EF("@D:6YD96YT(#T]/2`B7V%U=&\B
M*2![#0H@("`@("`@("`@("`@("`@)&EN9&5N="`]('-T<E]R97!E870H(B`B
M+"`H<W1R;&5N*"1T86=;(G%N86UE(ETI*S(I*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("`-"B`@("`@("`@+R\@8W)E871E(&%T=')I
M8G5T92!L:7-T#0H@("`@("`@("1A='1,:7-T("`@(#T@("!834Q?571I;#HZ
M871T<FEB=71E<U1O4W1R:6YG*"1T86=;)V%T=')I8G5T97,G72P@=')U92P@
M)&UU;'1I;&EN92P@)&EN9&5N="P@)&QI;F5B<F5A:RP@)')E<&QA8V5%;G1I
M=&EE<R`I.PT*("`@("`@("!I9B`H(6ES<V5T*"1T86=;)V-O;G1E;G0G72D@
M?'P@*'-T<FEN9RDD=&%G6R=C;VYT96YT)UT@/3T@)R<I('L-"B`@("`@("`@
M("`@("1T86<@("`@/2`@('-P<FEN=&8H)SPE<R5S("\^)RP@)'1A9ULG<6YA
M;64G72P@)&%T=$QI<W0I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@<W=I=&-H("@D<F5P;&%C945N=&ET:65S*2![#0H@("`@("`@("`@("`@
M("`@8V%S92!834Q?551)3%]%3E1)5$E%4U].3TY%.@T*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!C87-E(%A-3%]55$E,
M7T-$051!7U-%0U1)3TXZ#0H@("`@("`@("`@("`@("`@("`@("1T86=;)V-O
M;G1E;G0G72`](%A-3%]5=&EL.CIC<F5A=&5#1&%T85-E8W1I;VXH)'1A9ULG
M8V]N=&5N="==*3L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@
M("`@("`@("`@("`@9&5F875L=#H-"B`@("`@("`@("`@("`@("`@("`@)'1A
M9ULG8V]N=&5N="==(#T@6$U,7U5T:6PZ.G)E<&QA8V5%;G1I=&EE<R@D=&%G
M6R=C;VYT96YT)UTL("1R97!L86-E16YT:71I97,I.PT*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1T
M86<@("`@/2`@('-P<FEN=&8H)SPE<R5S/B5S/"\E<SXG+"`D=&%G6R=Q;F%M
M92==+"`D871T3&ES="P@)'1A9ULG8V]N=&5N="==+"`D=&%G6R=Q;F%M92==
M("D[#0H@("`@("`@('T@("`@("`@(`T*("`@("`@("!R971U<FX@("1T86<[
M#0H@("`@?0T*#0H@("`O*BH-"B`@("`J(&-R96%T92!A('-T87)T(&5L96UE
M;G0-"B`@("`J#0H@("`@*B`\8V]D93X-"B`@("`J(')E<75I<F5?;VYC92`G
M6$U,+U5T:6PN<&AP)SL-"B`@("`J(`T*("`@("H@+R\@8W)E871E(&%N(%A-
M3"!S=&%R="!E;&5M96YT.@T*("`@("H@)'1A9R`](%A-3%]5=&EL.CIC<F5A
M=&53=&%R=$5L96UE;G0H(FUY3G,Z;7E486<B+"!A<G)A>2@B9F]O(B`]/B`B
M8F%R(BD@+")H='1P.B\O=W=W+G<S8RYO<F<O;7E.<R,B*3L-"B`@("`J(#PO
M8V]D93X-"B`@("`J#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B!`
M<W1A=&EC#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D<6YA;64@("`@("`@
M("`@("`@<75A;&EF:65D('1A9VYA;64@*&EN8VQU9&EN9R!N86UE<W!A8V4I
M#0H@("`@*B!`<&%R86T@("`@87)R87D@("`D871T<FEB=71E<R`@("`@("`@
M87)R87D@8V]N=&%I;F<@871T<FEB=71E<PT*("`@("H@0'!A<F%M("`@('-T
M<FEN9R`@)&YA;65S<&%C955R:2`@("`@(%5222!O9B!T:&4@;F%M97-P86-E
M#0H@("`@*B!`<&%R86T@("`@8F]O;&5A;B`D;75L=&EL:6YE("`@("`@("`@
M=VAE=&AE<B!T;R!C<F5A=&4@82!M=6QT:6QI;F4@=&%G('=H97)E(&5A8V@@
M871T<FEB=71E(&=E=',@=W)I='1E;B!T;R!A('-I;F=L92!L:6YE#0H@("`@
M*B!`<&%R86T@("`@<W1R:6YG("`D:6YD96YT("`@("`@("`@("`@<W1R:6YG
M('5S960@=&\@:6YD96YT(&%T=')I8G5T97,@*%]A=71O(&EN9&5N=',@871T
M<FEB=71E<R!S;R!T:&5Y('-T87)T(&%T('1H92!S86UE(&-O;'5M;BD-"B`@
M("`J($!P87)A;2`@("!S=')I;F<@("1L:6YE8G)E86L@("`@("`@("!S=')I
M;F<@=7-E9"!F;W(@;&EN96)R96%K<PT*("`@("H@0')E='5R;B`@('-T<FEN
M9R`@)'-T<FEN9R`@("`@("`@("`@(%A-3"!S=&%R="!E;&5M96YT#0H@("`@
M*B!`<V5E("`@("`@6$U,7U5T:6PZ.F-R96%T945N9$5L96UE;G0H*2P@6$U,
M7U5T:6PZ.F-R96%T951A9R@I#0H@("`@*B\-"B`@("!F=6YC=&EO;B!C<F5A
M=&53=&%R=$5L96UE;G0H)'%N86UE+"`D871T<FEB=71E<R`](&%R<F%Y*"DL
M("1N86UE<W!A8V55<FD@/2!N=6QL+"`D;75L=&EL:6YE(#T@9F%L<V4L("1I
M;F1E;G0@/2`G7V%U=&\G+"`D;&EN96)R96%K(#T@(EQN(BD-"B`@("![#0H@
M("`@("`@("\O(&EF(&YO(&%T=')I8G5T97,@:&%V(&)E96X@<V5T+"!U<V4@
M96UP='D@871T<FEB=71E<PT*("`@("`@("!I9B`H(6ES<V5T*"1A='1R:6)U
M=&5S*2!\?"`A:7-?87)R87DH)&%T=')I8G5T97,I*2![#0H@("`@("`@("`@
M("`D871T<FEB=71E<R`](&%R<F%Y*"D[#0H@("`@("`@('T-"B`@("`@("`@
M#0H@("`@("`@(&EF("@D;F%M97-P86-E57)I("$](&YU;&PI('L-"B`@("`@
M("`@("`@("1P87)T<R`](%A-3%]5=&EL.CIS<&QI=%%U86QI9FEE9$YA;64H
M)'%N86UE*3L-"B`@("`@("`@?0T*#0H@("`@("`@("\O(&-H96-K(&9O<B!M
M=6QT:6QI;F4@871T<FEB=71E<PT*("`@("`@("!I9B`H)&UU;'1I;&EN92`]
M/3T@=')U92D@>PT*("`@("`@("`@("`@:68@*"1I;F1E;G0@/3T](")?875T
M;R(I('L-"B`@("`@("`@("`@("`@("`D:6YD96YT(#T@<W1R7W)E<&5A="@B
M("(L("AS=')L96XH)'%N86UE*2LR*2D[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"@T*("`@("`@("!I9B`H)&YA;65S<&%C955R:2`A/2!N=6QL*2![
M#0H@("`@("`@("`@("`O+R!I<R!A(&YA;65S<&%C92!G:79E;@T*("`@("`@
M("`@("`@:68@*&ES<V5T*"1P87)T<ULB;F%M97-P86-E(ETI("8F("%E;7!T
M>2@D<&%R='-;(FYA;65S<&%C92)=*2D@>PT*("`@("`@("`@("`@("`@("1A
M='1R:6)U=&5S6R)X;6QN<SHB+B1P87)T<ULB;F%M97-P86-E(EU=(#T@)&YA
M;65S<&%C955R:3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@+R\@9&5F:6YE('1H:7,@57)I(&%S('1H92!D969A=6QT(&YA;65S
M<&%C90T*("`@("`@("`@("`@("`@("1A='1R:6)U=&5S6R)X;6QN<R)=(#T@
M)&YA;65S<&%C955R:3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*#0H@
M("`@("`@("\O(&-R96%T92!A='1R:6)U=&4@;&ES=`T*("`@("`@("`D871T
M3&ES="`@("`]("`@6$U,7U5T:6PZ.F%T=')I8G5T97-4;U-T<FEN9R@D871T
M<FEB=71E<RP@=')U92P@)&UU;'1I;&EN92P@)&EN9&5N="P@)&QI;F5B<F5A
M:RD[#0H@("`@("`@("1E;&5M96YT("`@(#T@("!S<')I;G1F*"(\)7,E<SXB
M+"`D<6YA;64L("1A='1,:7-T*3L-"B`@("`@("`@<F5T=7)N("`D96QE;65N
M=#L-"B`@("!]#0H-"B`@("\J*@T*("`@("H@8W)E871E(&%N(&5N9"!E;&5M
M96YT#0H@("`@*@T*("`@("H@/&-O9&4^#0H@("`@*B!R97%U:7)E7V]N8V4@
M)UA-3"]5=&EL+G!H<"<[#0H@("`@*B`-"B`@("`J("\O(&-R96%T92!A;B!8
M34P@<W1A<G0@96QE;65N=#H-"B`@("`J("1T86<@/2!834Q?571I;#HZ8W)E
M871E16YD16QE;65N="@B;7E.<SIM>51A9R(I.PT*("`@("H@/"]C;V1E/@T*
M("`@("H-"B`@("`J($!A8V-E<W,@("!P=6)L:6,-"B`@("`J($!S=&%T:6,-
M"B`@("`J($!P87)A;2`@("!S=')I;F<@("1Q;F%M92`@("`@("`@("`@("!Q
M=6%L:69I960@=&%G;F%M92`H:6YC;'5D:6YG(&YA;65S<&%C92D-"B`@("`J
M($!R971U<FX@("!S=')I;F<@("1S=')I;F<@("`@("`@("`@("!834P@96YD
M(&5L96UE;G0-"B`@("`J($!S964@("`@("!834Q?571I;#HZ8W)E871E4W1A
M<G1%;&5M96YT*"DL(%A-3%]5=&EL.CIC<F5A=&5486<H*0T*("`@("HO#0H@
M("`@9G5N8W1I;VX@8W)E871E16YD16QE;65N="@D<6YA;64I#0H@("`@>PT*
M("`@("`@("`D96QE;65N="`@("`]("`@<W!R:6YT9B@B/"\E<SXB+"`D<6YA
M;64I.PT*("`@("`@("!R971U<FX@("1E;&5M96YT.PT*("`@('T-"B`@("`-
M"B`@("\J*@T*("`@("H@8W)E871E(&%N(%A-3"!C;VUM96YT#0H@("`@*@T*
M("`@("H@/&-O9&4^#0H@("`@*B!R97%U:7)E7V]N8V4@)UA-3"]5=&EL+G!H
M<"<[#0H@("`@*B`-"B`@("`J("\O(&-R96%T92!A;B!834P@<W1A<G0@96QE
M;65N=#H-"B`@("`J("1T86<@/2!834Q?571I;#HZ8W)E871E0V]M;65N="@B
M22!A;2!A(&-O;6UE;G0B*3L-"B`@("`J(#PO8V]D93X-"B`@("`J#0H@("`@
M*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B!`<W1A=&EC#0H@("`@*B!`<&%R
M86T@("`@<W1R:6YG("`D8V]N=&5N="`@("`@("`@("`@8V]N=&5N="!O9B!T
M:&4@8V]M;65N=`T*("`@("H@0')E='5R;B`@('-T<FEN9R`@)&-O;6UE;G0@
M("`@("`@("`@(%A-3"!C;VUM96YT#0H@("`@*B\-"B`@("!F=6YC=&EO;B!C
M<F5A=&5#;VUM96YT*"1C;VYT96YT*0T*("`@('L-"B`@("`@("`@)&-O;6UE
M;G0@("`@/2`@('-P<FEN=&8H(CPA+2T@)7,@+2T^(BP@)&-O;G1E;G0I.PT*
M("`@("`@("!R971U<FX@("1C;VUM96YT.PT*("`@('T-"B`@("`-"B`@("\J
M*@T*("`@("H@8W)E871E(&$@0T1A=&$@<V5C=&EO;@T*("`@("H-"B`@("`J
M(#QC;V1E/@T*("`@("H@<F5Q=6ER95]O;F-E("=834PO571I;"YP:'`G.PT*
M("`@("H@#0H@("`@*B`O+R!C<F5A=&4@82!#1&%T82!S96-T:6]N#0H@("`@
M*B`D=&%G(#T@6$U,7U5T:6PZ.F-R96%T94-$871A4V5C=&EO;B@B22!A;2!C
M;VYT96YT+B(I.PT*("`@("H@/"]C;V1E/@T*("`@("H-"B`@("`J($!A8V-E
M<W,@("!P=6)L:6,-"B`@("`J($!S=&%T:6,-"B`@("`J($!P87)A;2`@("!S
M=')I;F<@("1D871A("`@("`@("`@("`@("!D871A(&]F('1H92!#1&%T82!S
M96-T:6]N#0H@("`@*B!`<F5T=7)N("`@<W1R:6YG("`D<W1R:6YG("`@("`@
M("`@("`@0T1A=&$@<V5C=&EO;B!W:71H(&-O;G1E;G0-"B`@("`J+PT*("`@
M(&9U;F-T:6]N(&-R96%T94-$871A4V5C=&EO;B@D9&%T82D-"B`@("![#0H@
M("`@("`@(')E='5R;B`@<W!R:6YT9B@B/"%;0T1!5$%;)7-=73XB+"`D9&%T
M82D[#0H@("`@?0T*#0H@("`O*BH-"B`@("`J('-P;&ET('%U86QI9FEE9"!N
M86UE(&%N9"!R971U<FX@;F%M97-P86-E(&%N9"!L;V-A;"!P87)T#0H@("`@
M*@T*("`@("H@/&-O9&4^#0H@("`@*B!R97%U:7)E7V]N8V4@)UA-3"]5=&EL
M+G!H<"<[#0H@("`@*B`-"B`@("`J("\O('-P;&ET('%U86QI9FEE9"!T86<-
M"B`@("`J("1P87)T<R`](%A-3%]5=&EL.CIS<&QI=%%U86QI9FEE9$YA;64H
M(GAS;'0Z<W1Y;&5S:&5E="(I.PT*("`@("H@/"]C;V1E/@T*("`@("H@=&AE
M(')E='5R;F5D(&%R<F%Y('=I;&P@8V]N=&%I;B!T=V\@96QE;65N=',Z#0H@
M("`@*B`\<')E/@T*("`@("H@87)R87DH#0H@("`@*B`@("`@("`B;F%M97-P
M86-E(B`]/B`B>'-L="(L#0H@("`@*B`@("`@("`B;&]C86Q087)T(B`]/B`B
M<W1Y;&5S:&5E="(-"B`@("`J("`@("`@*3L-"B`@("`J(#PO<')E/@T*("`@
M("H-"B`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@*B!`<W1A=&EC#0H@("`@
M*B!`<&%R86T@('-T<FEN9R`@("`D<6YA;64@("`@("!Q=6%L:69I960@=&%G
M(&YA;64-"B`@("`J($!P87)A;2`@<W1R:6YG("`@("1D969A=6QT3G,@(&1E
M9F%U;'0@;F%M97-P86-E("AO<'1I;VYA;"D-"B`@("`J($!R971U<FX@87)R
M87D@("`@("1P87)T<R`@("`@(&%R<F%Y(&-O;G1A:6YI;F<@;F%M97-P86-E
M(&%N9"!L;V-A;"!P87)T#0H@("`@*B\-"B`@("!F=6YC=&EO;B!S<&QI=%%U
M86QI9FEE9$YA;64H)'%N86UE+"`D9&5F875L=$YS(#T@;G5L;"D-"B`@("![
M#0H@("`@("`@(&EF("AS=')S='(H)'%N86UE+"`G.B<I*2![#0H@("`@("`@
M("`@("`D=&UP(#T@97AP;&]D92@B.B(L("1Q;F%M92D[#0H@("`@("`@("`@
M("!R971U<FX@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@("`@(")N
M86UE<W!A8V4B(#T^("1T;7!;,%TL#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@(")L;V-A;%!A<G0B(#T^("1T;7!;,5T-"B`@("`@("`@("`@("`@("`@
M("`@("`@("D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("`@("`@(")N86UE<W!A8V4B(#T^("1D969A=6QT
M3G,L#0H@("`@("`@("`@("`@("`@("`@("`@(FQO8V%L4&%R="(@/3X@)'%N
M86UE#0H@("`@("`@("`@("`@("`@("`@("D[#0H@("`@?0T*#0H@("`O*BH-
M"B`@("`J(&-H96-K+"!W:&5T:&5R('-T<FEN9R!I<R!V86QI9"!834P@;F%M
M90T*("`@("H-"B`@("`J(#QP/EA-3"!N86UE<R!A<F4@=7-E9"!F;W(@=&%G
M;F%M92P@871T<FEB=71E(&YA;65S(&%N9"!V87)I;W5S#0H@("`@*B!O=&AE
M<BP@;&5S<V5R(&MN;W=N(&5N=&ET:65S+CPO<#X-"B`@("`J(#QP/D%N(%A-
M3"!N86UE(&UA>2!O;FQY(&-O;G-I<W0@;V8@86QP:&%N=6UE<FEC(&-H87)A
M8W1E<G,L#0H@("`@*B!D87-H97,L('5N9&5S8V]R97,@86YD('!E<FEO9',L
M(&%N9"!H87,@=&\@<W1A<G0@=VET:"!A(&QE='1E<@T*("`@("H@;W(@86X@
M=6YD97)S8V]R92X-"B`@("`J(#PO<#X-"B`@("`J#0H@("`@*B`\8V]D93X-
M"B`@("`J(')E<75I<F5?;VYC92`G6$U,+U5T:6PN<&AP)SL-"B`@("`J(`T*
M("`@("H@+R\@=F5R:69Y('1A9R!N86UE#0H@("`@*B`D<F5S=6QT(#T@6$U,
M7U5T:6PZ.FES5F%L:61.86UE*")I;G9A;&ED5&%G/R(I.PT*("`@("H@:68@
M*%A-3%]5=&EL.CII<T5R<F]R*"1R97-U;'0I*2![#0H@("`@*B`@("!P<FEN
M="`B26YV86QI9"!834P@;F%M93H@(B`N("1R97-U;'0M/F=E=$UE<W-A9V4H
M*3L-"B`@("`J('T-"B`@("`J(#PO8V]D93X-"B`@("`J#0H@("`@*B!`86-C
M97-S("!P=6)L:6,-"B`@("`J($!S=&%T:6,-"B`@("`J($!P87)A;2`@('-T
M<FEN9R`@)'-T<FEN9R!S=')I;F<@=&AA="!S:&]U;&0@8F4@8VAE8VME9`T*
M("`@("H@0')E='5R;B`@;6EX960@("`D=F%L:60@('1R=64L(&EF('-T<FEN
M9R!I<R!A('9A;&ED(%A-3"!N86UE+"!014%2(&5R<F]R(&]T:&5R=VES90T*
M("`@("H@0'1O9&\@("`@<W5P<&]R="!F;W(@;W1H97(@8VAA<G-E=',-"B`@
M("`J+PT*("`@(&9U;F-T:6]N(&ES5F%L:61.86UE*"1S=')I;F<I#0H@("`@
M>PT*("`@("`@("`O+R!C:&5C:R!F;W(@:6YV86QI9"!C:&%R<PT*("`@("`@
M("!I9B`H(7!R96=?;6%T8V@H(B]>6ULZ86QN=6TZ75]<+2Y=)"\B+"`D<W1R
M:6YG>S!]*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%A-3%]5=&EL.CIR86ES
M945R<F]R*"`B6$U,(&YA;65S(&UA>2!O;FQY('-T87)T('=I=&@@;&5T=&5R
M(&]R('5N9&5R<V-O<F4B+"!834Q?551)3%]%4E)/4E])3E9!3$E$7U-405)4
M("D[#0H@("`@("`@('T-"B`@("`@("`@#0H@("`@("`@("\O(&-H96-K(&9O
M<B!I;G9A;&ED(&-H87)S#0H@("`@("`@(&EF("@A<')E9U]M871C:"@B+UXH
M6V$M>D$M6E]=*%MA+7I!+5HP+3E?7"U<+ETJ*3\Z*3];82UZ02U:7UTH6V$M
M>D$M6C`M.5]<+5PN72LI/R0O(BP@)'-T<FEN9RDI('L-"B`@("`@("`@("`@
M(')E='5R;B!834Q?571I;#HZ<F%I<V5%<G)O<B@@(EA-3"!N86UE<R!M87D@
M;VYL>2!C;VYT86EN(&%L<&AA;G5M97)I8R!C:&%R<RP@<&5R:6]D+"!H>7!H
M96XL(&-O;&]N(&%N9"!U;F1E<G-C;W)E<R(L(%A-3%]55$E,7T524D]27TE.
M5D%,241?0TA!4E,@*3L-"B`@("`@("`@('T-"B`@("`@("`@+R\@6$U,(&YA
M;64@:7,@=F%L:60-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@
M("`O*BH-"B`@("`J(')E<&QA8V5M96YT(&9O<B!834Q?571I;#HZ<F%I<V5%
M<G)O<@T*("`@("H-"B`@("`J($%V;VED<R!T:&4@;F5C97-S:71Y('1O(&%L
M=V%Y<R!R97%U:7)E#0H@("`@*B!014%2+G!H<`T*("`@("H-"B`@("`J($!A
M8V-E<W,@("!P=6)L:6,-"B`@("`J($!P87)A;2`@("!S=')I;F<@("`@("!E
M<G)O<B!M97-S86=E#0H@("`@*B!`<&%R86T@("`@:6YT96=E<B`@("`@97)R
M;W(@8V]D90T*("`@("H@0')E='5R;B`@(&]B:F5C="!014%27T5R<F]R#0H@
M("`@*B\-"B`@("!F=6YC=&EO;B!R86ES945R<F]R*"1M<V<L("1C;V1E*0T*
M("`@('L-"B`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+G!H<"<[#0H@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"1M<V<L("1C;V1E*3L-"B`@
M("!]#0I]#0H_/@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]834PO56YS
M97)I86QI>F5R+G!H<```````````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#8W-#,Q(#$P-3$U-#,S-S,Q(#`R,C,R-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/U!(4`HO*B!V:6TZ('-E="!E
M>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT
M.B`J+PH*+RHJ"B`J(%A-3%]5;G-E<FEA;&EZ97(*("H*("H@4&%R<V5S(&%N
M>2!834P@9&]C=6UE;G0@:6YT;R!02%`@9&%T82!S=')U8W1U<F5S+@H@*@H@
M*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O
M=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(
M4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O
M<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@H@*B!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@
M<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@
M=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90H@
M*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA
M:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@
M6$U,"B`J($!P86-K86=E("`@(%A-3%]397)I86QI>F5R"B`J($!A=71H;W(@
M("`@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("H@0&-O<'ER
M:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N
M<V4@,RXP"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!5;G-E<FEA;&EZ97(N
M<&AP+'8@,2XS.2`R,#`U+S`Y+S(X(#$Q.C$Y.C4V('-C:'-T($5X<"`D"B`J
M($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]834Q?
M4V5R:6%L:7IE<@H@*B!`<V5E("`@("`@("!834Q?56YS97)I86QI>F5R"B`J
M+PH*+RHJ"B`J('5S97,@4$5!4B!E<G)O<B!M86YA9V5M=`H@*B\*<F5Q=6ER
M95]O;F-E("=014%2+G!H<"<["@HO*BH*("H@=7-E<R!834Q?4&%R<V5R('1O
M('5N<V5R:6%L:7IE(&1O8W5M96YT"B`J+PIR97%U:7)E7V]N8V4@)UA-3"]0
M87)S97(N<&AP)SL*"B\J*@H@*B!O<'1I;VXZ($-O;G9E<G0@;F5S=&5D('1A
M9W,@=&\@87)R87D@;W(@;V)J96-T"B`J"B`J(%!O<W-I8FQE('9A;'5E<SH*
M("H@+2!A<G)A>0H@*B`M(&]B:F5C=`H@*B`M(&%S<V]C:6%T:79E(&%R<F%Y
M('1O(&1E9FEN92!T:&ES(&]P=&EO;B!P97(@=&%G(&YA;64*("HO"F1E9FEN
M92@G6$U,7U5.4T5224%,25I%4E]/4%1)3TY?0T]-4$Q%6%194$4G+"`G8V]M
M<&QE>%1Y<&4G*3L*"B\J*@H@*B!O<'1I;VXZ($YA;64@;V8@=&AE(&%T=')I
M8G5T92!T:&%T('-T;W)E<R!T:&4@;W)I9VEN86P@:V5Y"B`J"B`J(%!O<W-I
M8FQE('9A;'5E<SH*("H@+2!A;GD@<W1R:6YG"B`J+PID969I;F4H)UA-3%]5
M3E-%4DE!3$E:15)?3U!424].7T%45%))0E5415]+15DG+"`G:V5Y071T<FEB
M=71E)RD["@HO*BH*("H@;W!T:6]N.B!.86UE(&]F('1H92!A='1R:6)U=&4@
M=&AA="!S=&]R97,@=&AE('1Y<&4*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@
M*B`M(&%N>2!S=')I;F<*("HO"F1E9FEN92@G6$U,7U5.4T5224%,25I%4E]/
M4%1)3TY?05144DE"551%7U194$4G+"`G='EP94%T=')I8G5T92<I.PH*+RHJ
M"B`J(&]P=&EO;CH@3F%M92!O9B!T:&4@871T<FEB=71E('1H870@<W1O<F5S
M('1H92!C;&%S<R!N86UE"B`J"B`J(%!O<W-I8FQE('9A;'5E<SH*("H@+2!A
M;GD@<W1R:6YG"B`J+PID969I;F4H)UA-3%]53E-%4DE!3$E:15)?3U!424].
M7T%45%))0E5415]#3$%34R<L("=C;&%S<T%T=')I8G5T92<I.PH*+RHJ"B`J
M(&]P=&EO;CH@5VAE=&AE<B!T;R!U<V4@=&AE('1A9R!N86UE(&%S(&$@8VQA
M<W,@;F%M90H@*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J("T@=')U92!O<B!F
M86QS90H@*B\*9&5F:6YE*"=834Q?54Y315))04Q)6D527T]05$E/3E]404=?
M05-?0TQ!4U-.04U%)RP@)W1A9T%S0VQA<W,G*3L*"B\J*@H@*B!O<'1I;VXZ
M($YA;64@;V8@=&AE(&1E9F%U;'0@8VQA<W,*("H*("H@4&]S<VEB;&4@=F%L
M=65S.@H@*B`M(&%N>2!S=')I;F<*("HO"F1E9FEN92@G6$U,7U5.4T5224%,
M25I%4E]/4%1)3TY?1$5&055,5%]#3$%34R<L("=D969A=6QT0VQA<W,G*3L*
M"B\J*@H@*B!O<'1I;VXZ(%=H971H97(@=&\@<&%R<V4@871T<FEB=71E<PH@
M*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J("T@=')U92!O<B!F86QS90H@*B\*
M9&5F:6YE*"=834Q?54Y315))04Q)6D527T]05$E/3E]!5%1224)55$537U!!
M4E-%)RP@)W!A<G-E071T<FEB=71E<R<I.PH*+RHJ"B`J(&]P=&EO;CH@2V5Y
M(&]F('1H92!A<G)A>2!T;R!S=&]R92!A='1R:6)U=&5S("AI9B!A;GDI"B`J
M"B`J(%!O<W-I8FQE('9A;'5E<SH*("H@+2!A;GD@<W1R:6YG"B`J("T@9F%L
M<V4@*&1I<V%B;&5D*0H@*B\*9&5F:6YE*"=834Q?54Y315))04Q)6D527T]0
M5$E/3E]!5%1224)55$537T%24D%92T59)RP@)V%T=')I8G5T97-!<G)A>2<I
M.PH*+RHJ"B`J(&]P=&EO;CH@<W1R:6YG('1O('!R97!E;F0@871T<FEB=71E
M(&YA;64@*&EF(&%N>2D*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M(&%N
M>2!S=')I;F<*("H@+2!F86QS92`H9&ES86)L960I"B`J+PID969I;F4H)UA-
M3%]53E-%4DE!3$E:15)?3U!424].7T%45%))0E5415-?4%)%4$5.1"<L("=P
M<F5P96YD071T<FEB=71E<R<I.PH*+RHJ"B`J(&]P=&EO;CH@:V5Y('1O('-T
M;W)E('1H92!C;VYT96YT+"!I9B!834Q?54Y315))04Q)6D527T]05$E/3E]!
M5%1224)55$537U!!4E-%(&ES('5S960*("H*("H@4&]S<VEB;&4@=F%L=65S
M.@H@*B`M(&%N>2!S=')I;F<*("HO"F1E9FEN92@G6$U,7U5.4T5224%,25I%
M4E]/4%1)3TY?0T].5$5.5%]+15DG+"`G8V]N=&5N=$YA;64G*3L*"B\J*@H@
M*B!O<'1I;VXZ(&UA<"!T86<@;F%M97,*("H*("H@4&]S<VEB;&4@=F%L=65S
M.@H@*B`M(&%S<V]C:6%T:79E(&%R<F%Y"B`J+PID969I;F4H)UA-3%]53E-%
M4DE!3$E:15)?3U!424].7U1!1U]-05`G+"`G=&%G36%P)RD["@HO*BH*("H@
M;W!T:6]N.B!L:7-T(&]F('1A9W,@=&AA="!W:6QL(&%L=V%Y<R!B92!E;G5M
M97)A=&5D"B`J"B`J(%!O<W-I8FQE('9A;'5E<SH*("H@+2!I;F1E>&5D(&%R
M<F%Y"B`J+PID969I;F4H)UA-3%]53E-%4DE!3$E:15)?3U!424].7T9/4D-%
M7T5.54TG+"`G9F]R8V5%;G5M)RD["@HO*BH*("H@;W!T:6]N.B!%;F-O9&EN
M9R!O9B!T:&4@6$U,(&1O8W5M96YT"B`J"B`J(%!O<W-I8FQE('9A;'5E<SH*
M("H@+2!55$8M.`H@*B`M($E33RTX.#4Y+3$*("HO"F1E9FEN92@G6$U,7U5.
M4T5224%,25I%4E]/4%1)3TY?14Y#3T1)3D=?4T]54D-%)RP@)V5N8V]D:6YG
M)RD["@HO*BH*("H@;W!T:6]N.B!$97-I<F5D('1A<F=E="!E;F-O9&EN9R!O
M9B!T:&4@9&%T80H@*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J("T@551&+3@*
M("H@+2!)4T\M.#@U.2TQ"B`J+PID969I;F4H)UA-3%]53E-%4DE!3$E:15)?
M3U!424].7T5.0T]$24Y'7U1!4D=%5"<L("=T87)G971%;F-O9&EN9R<I.PH*
M+RHJ"B`J(&]P=&EO;CH@0V%L;&)A8VL@=&AA="!W:6QL(&)E(&%P<&QI960@
M=&\@=&5X='5A;"!D871A"B`J"B`J(%!O<W-I8FQE('9A;'5E<SH*("H@+2!A
M;GD@=F%L:60@4$A0(&-A;&QB86-K"B`J+PID969I;F4H)UA-3%]53E-%4DE!
M3$E:15)?3U!424].7T1%0T]$15]&54Y#)RP@)V1E8V]D949U;F-T:6]N)RD[
M"@HO*BH*("H@;W!T:6]N.B!W:&5T:&5R('1O(')E='5R;B!T:&4@<F5S=6QT
M(&]F('1H92!U;G-E<FEA;&EZ871I;VX@9G)O;2!U;G-E<FEA;&EZ92@I"B`J
M"B`J(%!O<W-I8FQE('9A;'5E<SH*("H@+2!T<G5E"B`J("T@9F%L<V4@*&1E
M9F%U;'0I"B`J+PID969I;F4H)UA-3%]53E-%4DE!3$E:15)?3U!424].7U)%
M5%523E]215-53%0G+"`G<F5T=7)N4F5S=6QT)RD["@HO*BH*("H@;W!T:6]N
M.B!S970@=&AE('=H:71E<W!A8V4@8F5H879I;W5R"B`J"B`J(%!O<W-I8FQE
M('9A;'5E<SH*("H@+2!834Q?54Y315))04Q)6D527U=(251%4U!!0T5?2T5%
M4`H@*B`M(%A-3%]53E-%4DE!3$E:15)?5TA)5$534$%#15]44DE-"B`J("T@
M6$U,7U5.4T5224%,25I%4E]72$E415-004-%7TY/4DU!3$E:10H@*B\*9&5F
M:6YE*"=834Q?54Y315))04Q)6D527T]05$E/3E]72$E415-004-%)RP@)W=H
M:71E<W!A8V4G*3L*"B\J*@H@*B!+965P(&%L;"!W:&ET97-P86-E"B`J+PID
M969I;F4H)UA-3%]53E-%4DE!3$E:15)?5TA)5$534$%#15]+1450)RP@)VME
M97`G*3L*"B\J*@H@*B!R96UO=F4@=VAI=&5S<&%C92!F<F]M('-T87)T(&%N
M9"!E;F0@;V8@=&AE(&1A=&$*("HO"F1E9FEN92@G6$U,7U5.4T5224%,25I%
M4E]72$E415-004-%7U1224TG+"`G=')I;2<I.PH*+RHJ"B`J(&YO<FUA;&EZ
M92!W:&ET97-P86-E"B`J+PID969I;F4H)UA-3%]53E-%4DE!3$E:15)?5TA)
M5$534$%#15].3U)-04Q)6D4G+"`G;F]R;6%L:7IE)RD["@HO*BH*("H@;W!T
M:6]N.B!W:&5T:&5R('1O(&]V=F5R<FED92!A;&P@;W!T:6]N<R!T:&%T(&AA
M=F4@8F5E;B!S970@8F5F;W)E"B`J"B`J(%!O<W-I8FQE('9A;'5E<SH*("H@
M+2!T<G5E"B`J("T@9F%L<V4@*&1E9F%U;'0I"B`J+PID969I;F4H)UA-3%]5
M3E-%4DE!3$E:15)?3U!424].7T]615)2241%7T]05$E/3E,G+"`G;W9E<G)I
M9&5/<'1I;VYS)RD["@HO*BH*("H@;W!T:6]N.B!L:7-T(&]F('1A9W,L('1H
M870@=VEL;"!N;W0@8F4@=7-E9"!A<R!K97ES"B`J+PID969I;F4H)UA-3%]5
M3E-%4DE!3$E:15)?3U!424].7TE'3D]215]+15E3)RP@)VEG;F]R94ME>7,G
M*3L*"B\J*@H@*B!O<'1I;VXZ('=H971H97(@=&\@=7-E('1Y<&4@9W5E<W-I
M;F<@9F]R('-C86QA<B!V86QU97,*("HO"F1E9FEN92@G6$U,7U5.4T5224%,
M25I%4E]/4%1)3TY?1U5%4U-?5%E015,G+"`G9W5E<W-4>7!E<R<I.PH*+RHJ
M"B`J(&5R<F]R(&-O9&4@9F]R(&YO('-E<FEA;&EZ871I;VX@9&]N90H@*B\*
M9&5F:6YE*"=834Q?54Y315))04Q)6D527T524D]27TY/7U5.4T5224%,25I!
M5$E/3B<L(#$U,2D["@HO*BH*("H@6$U,7U5N<V5R:6%L:7IE<@H@*@H@*B!C
M;&%S<R!T;R!U;G-E<FEA;&EZ92!834P@9&]C=6UE;G1S('1H870@:&%V92!B
M965N(&-R96%T960@=VET:`H@*B!834Q?4V5R:6%L:7IE<BX@5&\@=6YS97)I
M86QI>F4@86X@6$U,(&1O8W5M96YT('EO=2!H879E('1O(&%D9`H@*B!T>7!E
M(&AI;G1S('1O('1H92!834Q?4V5R:6%L:7IE<B!O<'1I;VYS+@H@*@H@*B!)
M9B!N;R!T>7!E(&AI;G1S(&%R92!A=F%I;&%B;&4L(%A-3%]5;G-E<FEA;&EZ
M97(@=VEL;"!G=65S<R!H;W<*("H@=&AE('1A9W,@<VAO=6QD(&)E('1R96%T
M960L('1H870@;65A;G,@8V]M<&QE>"!S=')U8W1U<F5S('=I;&P@8F4*("H@
M87)R87ES(&%N9"!T86=S('=I=&@@;VYL>2!#1&%T82!I;B!T:&5M('=I;&P@
M8F4@<W1R:6YG<RX*("H*("H@/&-O9&4^"B`J(')E<75I<F5?;VYC92`G6$U,
M+U5N<V5R:6%L:7IE<BYP:'`G.PH@*@H@*B`O+R`@8F4@8V%R969U;"!T;R!A
M;'=A>7,@=7-E('1H92!A;7!E<G-A;F0@:6X@9G)O;G0@;V8@=&AE(&YE=R!O
M<&5R871O<@H@*B`D=6YS97)I86QI>F5R(#T@)FYE=R!834Q?56YS97)I86QI
M>F5R*"D["B`J"B`J("1U;G-E<FEA;&EZ97(M/G5N<V5R:6%L:7IE*"1X;6PI
M.PH@*@H@*B`D9&%T82`]("1U;G-E<FEA;&EZ97(M/F=E=%5N<V5R:6%L:7IE
M9$1A=&$H*3L*("H@/&-O9&4^"B`J"B`J"B`J($!C871E9V]R>2`@(%A-3`H@
M*B!`<&%C:V%G92`@("!834Q?4V5R:6%L:7IE<@H@*B!`875T:&]R("`@("!3
M=&5P:&%N(%-C:&UI9'0@/'-C:'-T0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@
M(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N
M,`H@*B!`=F5R<VEO;B`@("!296QE87-E.B`P+C$X+C`*("H@0&QI;FL@("`@
M("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+UA-3%]397)I86QI>F5R
M"B`J($!S964@("`@("`@(%A-3%]397)I86QI>F5R"B`J+PIC;&%S<R!834Q?
M56YS97)I86QI>F5R(&5X=&5N9',@4$5!4@I["B`@("\J*@H@("`@*B!L:7-T
M(&]F(&%L;"!A=F%I;&%B;&4@;W!T:6]N<PH@("`@*@H@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("H@0'9A<B`@("!A<G)A>0H@("`@*B\*("`@('9A<B`D
M7VMN;W=N3W!T:6]N<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?3U!424].7T-/35!,15A465!%
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!
M3$E:15)?3U!424].7T%45%))0E5415]+15DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?05144DE"
M551%7U194$4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6$U,
M7U5.4T5224%,25I%4E]/4%1)3TY?05144DE"551%7T-,05-3+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?3U!4
M24].7U1!1U]!4U]#3$%34TY!344L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?1$5&055,5%]#3$%3
M4RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!834Q?54Y315))
M04Q)6D527T]05$E/3E]!5%1224)55$537U!!4E-%+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?3U!424].7T%4
M5%))0E5415-?05)205E+15DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?05144DE"551%4U]04D50
M14Y$+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]53E-%
M4DE!3$E:15)?3U!424].7T-/3E1%3E1?2T59+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?3U!424].7U1!1U]-
M05`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U5.4T52
M24%,25I%4E]/4%1)3TY?1D]20T5?14Y532P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/3E]%3D-/1$E.
M1U]33U520T4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6$U,
M7U5.4T5224%,25I%4E]/4%1)3TY?14Y#3T1)3D=?5$%21T54+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?3U!4
M24].7T1%0T]$15]&54Y#+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(%A-3%]53E-%4DE!3$E:15)?3U!424].7U)%5%523E]215-53%0L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U5.4T5224%,25I%
M4E]/4%1)3TY?5TA)5$534$%#12P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/3E])1TY/4D5?2T594RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!834Q?54Y315))04Q)
M6D527T]05$E/3E]'54534U]465!%4PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`I.PH@("`O*BH*("`@("H@9&5F875L="!O<'1I;VYS(&9O<B!T
M:&4@<V5R:6%L:7IA=&EO;@H@("`@*@H@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("H@0'9A<B`@("!A<G)A>0H@("`@*B\*("`@('9A<B`D7V1E9F%U;'1/
M<'1I;VYS(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("!834Q?
M54Y315))04Q)6D527T]05$E/3E]#3TU03$585%E012`@("`@("`@(#T^("=A
M<G)A>2<L("`@("`@("`@("`@("`@("\O(&-O;7!L97@@='EP97,@=VEL;"!B
M92!C;VYV97)T960@=&\@87)R87ES+"!I9B!N;R!T>7!E(&AI;G0@:7,@9VEV
M96X*("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?
M3U!424].7T%45%))0E5415]+15D@("`@("`@/3X@)U]O<FEG:6YA;$ME>2<L
M("`@("`@("`@+R\@9V5T(&%R<F%Y(&ME>2]P<F]P97)T>2!N86UE(&9R;VT@
M=&AI<R!A='1R:6)U=&4*("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]5
M3E-%4DE!3$E:15)?3U!424].7T%45%))0E5415]465!%("`@("`@/3X@)U]T
M>7!E)RP@("`@("`@("`@("`@("`@+R\@9V5T('1Y<&4@9G)O;2!T:&ES(&%T
M=')I8G5T90H@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U5.4T5224%,
M25I%4E]/4%1)3TY?05144DE"551%7T-,05-3("`@("`]/B`G7V-L87-S)RP@
M("`@("`@("`@("`@("`O+R!G970@8VQA<W,@9G)O;2!T:&ES(&%T=')I8G5T
M92`H:68@;F]T(&=I=F5N+"!U<V4@=&%G(&YA;64I"B`@("`@("`@("`@("`@
M("`@("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/3E]404=?05-?0TQ!
M4U-.04U%("`@(#T^('1R=64L("`@("`@("`@("`@("`@("`@("\O('5S92!T
M:&4@=&%G;F%M92!A<R!T:&4@8VQA<W-N86UE"B`@("`@("`@("`@("`@("`@
M("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/3E]$149!54Q47T-,05-3
M("`@("`@(#T^("=S=&1#;&%S<R<L("`@("`@("`@("`@("\O(&YA;64@;V8@
M=&AE(&-L87-S('1H870@:7,@=7-E9"!T;R!C<F5A=&4@;V)J96-T<PH@("`@
M("`@("`@("`@("`@("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?
M05144DE"551%4U]005)312`@("`]/B!F86QS92P@("`@("`@("`@("`@("`@
M("`O+R!P87)S92!T:&4@871T<FEB=71E<R!O9B!T:&4@=&%G(&EN=&\@86X@
M87)R87D*("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:
M15)?3U!424].7T%45%))0E5415-?05)205E+15D@/3X@9F%L<V4L("`@("`@
M("`@("`@("`@("`@+R\@<&%R<V4@=&AE;2!I;G1O('-P97)A=&4@87)R87D@
M*'-P96-I9GD@;F%M92!O9B!A<G)A>2!H97)E*0H@("`@("`@("`@("`@("`@
M("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?05144DE"551%4U]0
M4D5014Y$("`]/B`G)RP@("`@("`@("`@("`@("`@("`@("`O+R!P<F5P96YD
M(&%T=')I8G5T92!N86UE<R!W:71H('1H:7,@<W1R:6YG"B`@("`@("`@("`@
M("`@("`@("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/3E]#3TY414Y4
M7TM%62`@("`@("`@(#T^("=?8V]N=&5N="<L("`@("`@("`@("`@("\O('!U
M="!C9&%T82!F;W5N9"!I;B!A('1A9R!T:&%T(&AA<R!B965N(&-O;G9E<G1E
M9"!T;R!A(&-O;7!L97@@='EP92!I;B!T:&ES(&ME>0H@("`@("`@("`@("`@
M("`@("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?5$%'7TU!4"`@
M("`@("`@("`@("`]/B!A<G)A>2@I+"`@("`@("`@("`@("`@("`O+R!U<V4@
M=&AI<R!T;R!M87`@=&%G;F%M97,*("`@("`@("`@("`@("`@("`@("`@("`@
M(%A-3%]53E-%4DE!3$E:15)?3U!424].7T9/4D-%7T5.54T@("`@("`@("`@
M/3X@87)R87DH*2P@("`@("`@("`@("`@("`@+R\@=&AE<V4@=&%G<R!W:6QL
M(&%L=V%Y<R!B92!A;B!I;F1E>&5D(&%R<F%Y"B`@("`@("`@("`@("`@("`@
M("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/3E]%3D-/1$E.1U]33U52
M0T4@("`@(#T^(&YU;&PL("`@("`@("`@("`@("`@("`@("\O('-P96-I9GD@
M=&AE(&5N8V]D:6YG(&-H87)A8W1E<B!O9B!T:&4@9&]C=6UE;G0@=&\@<&%R
M<V4*("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?
M3U!424].7T5.0T]$24Y'7U1!4D=%5"`@("`@/3X@;G5L;"P@("`@("`@("`@
M("`@("`@("`@+R\@<W!E8VEF>2!T:&4@=&%R9V5T(&5N8V]D:6YG"B`@("`@
M("`@("`@("`@("`@("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/3E]$
M14-/1$5?1E5.0R`@("`@("`@(#T^(&YU;&PL("`@("`@("`@("`@("`@("`@
M("\O(&9U;F-T:6]N('5S960@=&\@9&5C;V1E(&1A=&$*("`@("`@("`@("`@
M("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?3U!424].7U)%5%523E]2
M15-53%0@("`@("`@/3X@9F%L<V4L("`@("`@("`@("`@("`@("`@+R\@=6YS
M97)I86QI>F4H*2!R971U<FYS('1H92!R97-U;'0@;V8@=&AE('5N<V5R:6%L
M:7IA=&EO;B!I;G-T96%D(&]F('1R=64*("`@("`@("`@("`@("`@("`@("`@
M("`@(%A-3%]53E-%4DE!3$E:15)?3U!424].7U=(251%4U!!0T4@("`@("`@
M("`@/3X@6$U,7U5.4T5224%,25I%4E]72$E415-004-%7U1224TL("\O(')E
M;6]V92!W:&ET97-P86-E(&%R;W5N9"!D871A"B`@("`@("`@("`@("`@("`@
M("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/3E])1TY/4D5?2T594R`@
M("`@("`@(#T^(&%R<F%Y*"DL("`@("`@("`@("`@("`@("\O($QI<W0@;V8@
M=&%G<R!T:&%T('=I;&P@875T;VUA=&EC86QL>2!B92!A9&1E9"!T;R!T:&4@
M<&%R96YT+"!I;G-T96%D(&]F(&%D9&EN9R!A(&YE=R!K97D*("`@("`@("`@
M("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?3U!424].7T=515-3
M7U194$53("`@("`@("`@/3X@9F%L<V4@("`@("`@("`@("`@("`@("`@+R\@
M5VAE=&AE<B!T;R!U<V4@='EP92!G=65S<VEN9PH@("`@("`@("`@("`@("`@
M("`@("`@("`I.PH*("`@+RHJ"B`@("`J(&-U<G)E;G0@;W!T:6]N<R!F;W(@
M=&AE('-E<FEA;&EZ871I;VX*("`@("H*("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("H@0'9A<B`@("!A<G)A>0H@("`@*B\*("`@('9A<B`D;W!T:6]N<R`]
M(&%R<F%Y*"D["@H@("`O*BH*("`@("H@=6YS97)I86QI>F5D(&1A=&$*("`@
M("H*("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`J($!V87(@("`@<W1R:6YG
M"B`@("`J+PH@("`@=F%R("1?=6YS97)I86QI>F5D1&%T82`](&YU;&P["@H@
M("`O*BH*("`@("H@;F%M92!O9B!T:&4@<F]O="!T86<*("`@("H*("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`J($!V87(@("`@<W1R:6YG"B`@("`J+PH@
M("`@=F%R("1?<F]O="`](&YU;&P["@H@("`O*BH*("`@("H@<W1A8VL@9F]R
M(&%L;"!D871A('1H870@:7,@9F]U;F0*("`@("H*("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`J($!V87(@("`@87)R87D*("`@("HO"B`@("!V87(@)%]D
M871A4W1A8VL@(#T@("!A<G)A>2@I.PH*("`@+RHJ"B`@("`J('-T86-K(&9O
M<B!A;&P@=F%L=65S('1H870@87)E(&=E;F5R871E9`H@("`@*@H@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("H@0'9A<B`@("!A<G)A>0H@("`@*B\*("`@
M('9A<B`D7W9A;%-T86-K("`]("`@87)R87DH*3L*"B`@("\J*@H@("`@*B!C
M=7)R96YT('1A9R!D97!T:`H@("`@*@H@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("H@0'9A<B`@("!I;G0*("`@("HO"B`@("!V87(@)%]D97!T:"`](#`[
M"@H@("`O*BH*("`@("H@6$U,7U!A<G-E<B!I;G-T86YC90H@("`@*@H@("`@
M*B!`86-C97-S("`@<')I=F%T90H@("`@*B!`=F%R("`@("`@;V)J96-T(%A-
M3%]087)S97(*("`@("HO"B`@("!V87(@)%]P87)S97(@/2!N=6QL.PH@("`@
M"B`@("\J*@H@("`@*B!C;VYS=')U8W1O<@H@("`@*@H@("`@*B!`86-C97-S
M("`@<'5B;&EC"B`@("`J($!P87)A;2`@("!M:7AE9"`@("1O<'1I;VYS("`@
M(&%R<F%Y(&-O;G1A:6YI;F<@;W!T:6]N<R!F;W(@=&AE('5N<V5R:6%L:7IA
M=&EO;@H@("`@*B\*("`@(&9U;F-T:6]N(%A-3%]5;G-E<FEA;&EZ97(H)&]P
M=&EO;G,@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D;W!T
M:6]N<RDI('L*("`@("`@("`@("`@)'1H:7,M/F]P=&EO;G,@/2!A<G)A>5]M
M97)G92@D=&AI<RT^7V1E9F%U;'1/<'1I;VYS+"`D;W!T:6]N<RD["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/F]P=&EO;G,@/2`D=&AI
M<RT^7V1E9F%U;'1/<'1I;VYS.PH@("`@("`@('T*("`@('T*"B`@("\J*@H@
M("`@*B!R971U<FX@05!)('9E<G-I;VX*("`@("H*("`@("H@0&%C8V5S<R`@
M('!U8FQI8PH@("`@*B!`<W1A=&EC"B`@("`J($!R971U<FX@("!S=')I;F<@
M("1V97)S:6]N($%022!V97)S:6]N"B`@("`J+PH@("`@9G5N8W1I;VX@87!I
M5F5R<VEO;B@I"B`@("!["B`@("`@("`@<F5T=7)N("<P+C$X+C`G.PH@("`@
M?0H*("`@+RHJ"B`@("`J(')E<V5T(&%L;"!O<'1I;VYS('1O(&1E9F%U;'0@
M;W!T:6]N<PH@("`@*@H@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J($!S
M964@("`@("!S971/<'1I;VXH*2P@6$U,7U5N<V5R:6%L:7IE<B@I+"!S971/
M<'1I;VYS*"D*("`@("HO"B`@("!F=6YC=&EO;B!R97-E=$]P=&EO;G,H*0H@
M("`@>PH@("`@("`@("1T:&ES+3YO<'1I;VYS(#T@)'1H:7,M/E]D969A=6QT
M3W!T:6]N<SL*("`@('T*"B`@("\J*@H@("`@*B!S970@86X@;W!T:6]N"B`@
M("`J"B`@("`J(%EO=2!C86X@=7-E('1H:7,@;65T:&]D(&EF('EO=2!D;R!N
M;W0@=V%N="!T;R!S970@86QL(&]P=&EO;G,@:6X@=&AE(&-O;G-T<G5C=&]R
M"B`@("`J"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("H@0'-E92`@("`@
M(')E<V5T3W!T:6]N*"DL(%A-3%]5;G-E<FEA;&EZ97(H*2P@<V5T3W!T:6]N
M<R@I"B`@("`J+PH@("`@9G5N8W1I;VX@<V5T3W!T:6]N*"1N86UE+"`D=F%L
M=64I"B`@("!["B`@("`@("`@)'1H:7,M/F]P=&EO;G-;)&YA;65=(#T@)'9A
M;'5E.PH@("`@?0H*("`@+RHJ"B`@("`J('-E=',@<V5V97)A;"!O<'1I;VYS
M(&%T(&]N8V4*("`@("H*("`@("H@66]U(&-A;B!U<V4@=&AI<R!M971H;V0@
M:68@>6]U(&1O(&YO="!W86YT('1O('-E="!A;&P@;W!T:6]N<R!I;B!T:&4@
M8V]N<W1R=6-T;W(*("`@("H*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@
M*B!`<V5E("`@("`@<F5S971/<'1I;VXH*2P@6$U,7U5N<V5R:6%L:7IE<B@I
M+"!S971/<'1I;VXH*0H@("`@*B\*("`@(&9U;F-T:6]N('-E=$]P=&EO;G,H
M)&]P=&EO;G,I"B`@("!["B`@("`@("`@)'1H:7,M/F]P=&EO;G,@/2!A<G)A
M>5]M97)G92@D=&AI<RT^;W!T:6]N<RP@)&]P=&EO;G,I.PH@("`@?0H*("`@
M+RHJ"B`@("`J('5N<V5R:6%L:7IE(&1A=&$*("`@("H*("`@("H@0&%C8V5S
M<R`@('!U8FQI8PH@("`@*B!`<&%R86T@("`@;6EX960@("`@)&1A=&$@("`@
M(&1A=&$@=&\@=6YS97)I86QI>F4@*'-T<FEN9RP@9FEL96YA;64@;W(@<F5S
M;W5R8V4I"B`@("`J($!P87)A;2`@("!B;V]L96%N("`D:7-&:6QE("`@9&%T
M82!S:&]U;&0@8F4@=')E871E9"!A<R!A(&9I;&4*("`@("H@0'!A<F%M("`@
M(&%R<F%Y("`@("1O<'1I;VYS("!O<'1I;VYS('1H870@=VEL;"!O=F5R<FED
M92!T:&4@9VQO8F%L(&]P=&EO;G,@9F]R('1H:7,@8V%L;`H@("`@*B!`<F5T
M=7)N("`@8F]O;&5A;B`@)'-U8V-E<W,*("`@("HO"B`@("!F=6YC=&EO;B!U
M;G-E<FEA;&EZ92@D9&%T82P@)&ES1FEL92`](&9A;'-E+"`D;W!T:6]N<R`]
M(&YU;&PI"B`@("!["B`@("`@("`@)'1H:7,M/E]U;G-E<FEA;&EZ961$871A
M(#T@;G5L;#L*("`@("`@("`D=&AI<RT^7W)O;W0@/2!N=6QL.PH*("`@("`@
M("`O+R!I9B!O<'1I;VYS(&AA=F4@8F5E;B!S<&5C:69I960L('5S92!T:&5M
M(&EN<W1E860*("`@("`@("`O+R!O9B!T:&4@<')E=FEO=7-L>2!D969I;F5D
M(&]N97,*("`@("`@("!I9B`H:7-?87)R87DH)&]P=&EO;G,I*2!["B`@("`@
M("`@("`@("1O<'1I;VYS0F%K(#T@)'1H:7,M/F]P=&EO;G,["B`@("`@("`@
M("`@(&EF("AI<W-E="@D;W!T:6]N<UM834Q?54Y315))04Q)6D527T]05$E/
M3E]/5D524DE$15]/4%1)3TY372D@)B8@)&]P=&EO;G-;6$U,7U5.4T5224%,
M25I%4E]/4%1)3TY?3U9%4E))1$5?3U!424].4UT@/3T@=')U92D@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/F]P=&EO;G,@/2!A<G)A>5]M97)G92@D=&AI
M<RT^7V1E9F%U;'1/<'1I;VYS+"`D;W!T:6]N<RD["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D=&AI<RT^;W!T:6]N<R`](&%R<F%Y
M7VUE<F=E*"1T:&ES+3YO<'1I;VYS+"`D;W!T:6]N<RD["B`@("`@("`@("`@
M('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;W!T:6]N<T)A:R`]
M(&YU;&P["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7W9A;%-T86-K(#T@
M87)R87DH*3L*("`@("`@("`D=&AI<RT^7V1A=&%3=&%C:R`](&%R<F%Y*"D[
M"B`@("`@("`@)'1H:7,M/E]D97!T:"`](#`["@H@("`@("`@("1T:&ES+3Y?
M8W)E871E4&%R<V5R*"D["B`@("`@("`@"B`@("`@("`@:68@*&ES7W-T<FEN
M9R@D9&%T82DI('L*("`@("`@("`@("`@:68@*"1I<T9I;&4I('L*("`@("`@
M("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7W!A<G-E<BT^<V5T26YP=71&
M:6QE*"1D871A*3L*("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1R97-U;'0I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<F5S=6QT
M(#T@)'1H:7,M/E]P87)S97(M/G!A<G-E*"D["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]P87)S97(M
M/G!A<G-E4W1R:6YG*"1D871A+'1R=64I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`D=&AI<RT^7W!A<G-E<BT^<V5T26YP
M=70H)&1A=&$I.PH@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7W!A<G-E
M<BT^<&%R<V4H*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^;W!T
M:6]N<UM834Q?54Y315))04Q)6D527T]05$E/3E]215154DY?4D5354Q472`]
M/3T@=')U92D@>PH@("`@("`@(`DD<F5T=7)N(#T@)'1H:7,M/E]U;G-E<FEA
M;&EZ961$871A.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R971U
M<FX@/2!T<G5E.PH@("`@("`@('T*"B`@("`@("`@:68@*"1O<'1I;VYS0F%K
M("$]/2!N=6QL*2!["B`@("`@("`@("`@("1T:&ES+3YO<'1I;VYS(#T@)&]P
M=&EO;G-"86L["B`@("`@("`@?0H*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D<F5T=7)N.PH@("`@?0H*("`@+RHJ
M"B`@("`J(&=E="!T:&4@<F5S=6QT(&]F('1H92!S97)I86QI>F%T:6]N"B`@
M("`J"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J($!R971U<FX@<W1R:6YG
M("`D<V5R:6%L:7IE9$1A=&$*("`@("HO"B`@("!F=6YC=&EO;B!G9715;G-E
M<FEA;&EZ961$871A*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]R;V]T
M(#T]/2!N=6QL*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@G3F\@=6YS97)I86QI>F5D(&1A=&$@879A:6QA8FQE+B!5<V4@6$U,
M7U5N<V5R:6%L:7IE<CHZ=6YS97)I86QI>F4H*2!F:7)S="XG+"!834Q?54Y3
M15))04Q)6D527T524D]27TY/7U5.4T5224%,25I!5$E/3BD["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D=&AI<RT^7W5N<V5R:6%L:7IE9$1A=&$["B`@
M("!]"@H@("`O*BH*("`@("H@9V5T('1H92!N86UE(&]F('1H92!R;V]T('1A
M9PH@("`@*@H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B!`<F5T=7)N('-T
M<FEN9R`@)')O;W1.86UE"B`@("`J+PH@("`@9G5N8W1I;VX@9V5T4F]O=$YA
M;64H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7W)O;W0@/3T](&YU;&PI
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=.;R!U
M;G-E<FEA;&EZ960@9&%T82!A=F%I;&%B;&4N(%5S92!834Q?56YS97)I86QI
M>F5R.CIU;G-E<FEA;&EZ92@I(&9I<G-T+B<L(%A-3%]53E-%4DE!3$E:15)?
M15)23U)?3D]?54Y315))04Q)6D%424].*3L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?<F]O=#L*("`@('T*"B`@("\J*@H@("`@*B!3=&%R
M="!E;&5M96YT(&AA;F1L97(@9F]R(%A-3"!P87)S97(*("`@("H*("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`J($!P87)A;2`@;V)J96-T("1P87)S97(@
M(%A-3"!P87)S97(@;V)J96-T"B`@("`J($!P87)A;2`@<W1R:6YG("1E;&5M
M96YT(%A-3"!E;&5M96YT"B`@("`J($!P87)A;2`@87)R87D@("1A='1R:6)S
M(&%T=')I8G5T97,@;V8@6$U,('1A9PH@("`@*B!`<F5T=7)N('9O:60*("`@
M("HO"B`@("!F=6YC=&EO;B!S=&%R=$AA;F1L97(H)'!A<G-E<BP@)&5L96UE
M;G0L("1A='1R:6)S*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D871T<FEB
M<ULD=&AI<RT^;W!T:6]N<UM834Q?54Y315))04Q)6D527T]05$E/3E]!5%12
M24)55$5?5%E015U=*2D@>PH@("`@("`@("`@("`D='EP92`]("1A='1R:6)S
M6R1T:&ES+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?3U!424].7T%45%))
M0E5415]465!%75T["B`@("`@("`@("`@("1G=65S<U1Y<&4@/2!F86QS93L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D='EP92`]("=S=')I;F<G
M.PH@("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;6$U,7U5.4T5224%,
M25I%4E]/4%1)3TY?1U5%4U-?5%E015-=(#T]/2!T<G5E*2!["B`@("`@("`@
M("`@("`@("`D9W5E<W-4>7!E(#T@=')U93L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1G=65S<U1Y<&4@/2!F86QS93L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS
M6UA-3%]53E-%4DE!3$E:15)?3U!424].7T1%0T]$15]&54Y#72`A/3T@;G5L
M;"D@>PH@("`@("`@("`@("`D871T<FEB<R`](&%R<F%Y7VUA<"@D=&AI<RT^
M;W!T:6]N<UM834Q?54Y315))04Q)6D527T]05$E/3E]$14-/1$5?1E5.0UTL
M("1A='1R:6)S*3L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@)'1H:7,M
M/E]D97!T:"LK.PH@("`@("`@("1T:&ES+3Y?9&%T85-T86-K6R1T:&ES+3Y?
M9&5P=&A=(#T@;G5L;#L*"B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3YO
M<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?3U!424].7U1!1U]-05!=*2`F)B!I
M<W-E="@D=&AI<RT^;W!T:6]N<UM834Q?54Y315))04Q)6D527T]05$E/3E]4
M04=?34%075LD96QE;65N=%TI*2!["B`@("`@("`@("`@("1E;&5M96YT(#T@
M)'1H:7,M/F]P=&EO;G-;6$U,7U5.4T5224%,25I%4E]/4%1)3TY?5$%'7TU!
M4%U;)&5L96UE;G1=.PH@("`@("`@('T*"B`@("`@("`@)'9A;"`](&%R<F%Y
M*`H@("`@("`@("`@("`@("`@("`@("`G;F%M92<@("`@("`@("`]/B`D96QE
M;65N="P*("`@("`@("`@("`@("`@("`@("`@)W9A;'5E)R`@("`@("`@/3X@
M;G5L;"P*("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`@("`@("`@/3X@
M)'1Y<&4L"B`@("`@("`@("`@("`@("`@("`@("=G=65S<U1Y<&4G("`@(#T^
M("1G=65S<U1Y<&4L"B`@("`@("`@("`@("`@("`@("`@("=C:&EL9')E;DME
M>7,G(#T^(&%R<F%Y*"DL"B`@("`@("`@("`@("`@("`@("`@("=A9V=R96=+
M97ES)R`@(#T^(&%R<F%Y*"D*("`@("`@("`@("`@("`@("`@("`I.PH*("`@
M("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;6$U,7U5.4T5224%,25I%4E]/4%1)
M3TY?05144DE"551%4U]005)315T@/3T@=')U92`F)B`H8V]U;G0H)&%T=')I
M8G,I(#X@,"DI('L*("`@("`@("`@("`@)'9A;%LG8VAI;&1R96XG72`](&%R
M<F%Y*"D["B`@("`@("`@("`@("1V86Q;)W1Y<&4G72`@/2`D=&AI<RT^7V=E
M=$-O;7!L97A4>7!E*"1E;&5M96YT*3L*("`@("`@("`@("`@)'9A;%LG8VQA
M<W,G72`]("1E;&5M96YT.PH*("`@("`@("`@("`@:68@*"1T:&ES+3YO<'1I
M;VYS6UA-3%]53E-%4DE!3$E:15)?3U!424].7T=515-37U194$5372`]/3T@
M=')U92D@>PH@("`@("`@("`@("`))&%T=')I8G,@/2`D=&AI<RT^7V=U97-S
M06YD4V5T5'EP97,H)&%T=')I8G,I.PH@("`@("`@("`@("!]("`@("`@("`@
M("`@"B`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<UM834Q?54Y315))
M04Q)6D527T]05$E/3E]!5%1224)55$537T%24D%92T5972`A/2!F86QS92D@
M>PH@("`@("`@("`@("`@("`@)'9A;%LG8VAI;&1R96XG75LD=&AI<RT^;W!T
M:6]N<UM834Q?54Y315))04Q)6D527T]05$E/3E]!5%1224)55$537T%24D%9
M2T5975T@/2`D871T<FEB<SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1A='1R:6)S(&%S("1A='1R:6(@/3X@)'9A
M;'5E*2!["B`@("`@("`@("`@("`@("`@("`@)'9A;%LG8VAI;&1R96XG75LD
M=&AI<RT^;W!T:6]N<UM834Q?54Y315))04Q)6D527T]05$E/3E]!5%1224)5
M5$537U!215!%3D1=+B1A='1R:6)=(#T@)'9A;'5E.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D:V5Y071T
M<B`](&9A;'-E.PH@("`@("`@(`H@("`@("`@(&EF("AI<U]S=')I;F<H)'1H
M:7,M/F]P=&EO;G-;6$U,7U5.4T5224%,25I%4E]/4%1)3TY?05144DE"551%
M7TM%65TI*2!["B`@("`@("`@("`@("1K97E!='1R(#T@)'1H:7,M/F]P=&EO
M;G-;6$U,7U5.4T5224%,25I%4E]/4%1)3TY?05144DE"551%7TM%65T["B`@
M("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y*"1T:&ES+3YO<'1I;VYS6UA-3%]5
M3E-%4DE!3$E:15)?3U!424].7T%45%))0E5415]+15E=*2D@>PH@("`@("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/F]P=&EO;G-;6$U,7U5.4T5224%,25I%
M4E]/4%1)3TY?05144DE"551%7TM%65U;)&5L96UE;G1=*2D@>PH@("`@("`@
M("`@("`@("`@)&ME>4%T='(@/2`D=&AI<RT^;W!T:6]N<UM834Q?54Y315))
M04Q)6D527T]05$E/3E]!5%1224)55$5?2T5975LD96QE;65N=%T["B`@("`@
M("`@("`@('T@96QS96EF("AI<W-E="@D=&AI<RT^;W!T:6]N<UM834Q?54Y3
M15))04Q)6D527T]05$E/3E]!5%1224)55$5?2T5975LG(V1E9F%U;'0G72DI
M('L*("`@("`@("`@("`@("`@("1K97E!='1R(#T@)'1H:7,M/F]P=&EO;G-;
M6$U,7U5.4T5224%,25I%4E]/4%1)3TY?05144DE"551%7TM%65U;)R-D969A
M=6QT)UT["B`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D=&AI<RT^;W!T
M:6]N<UM834Q?54Y315))04Q)6D527T]05$E/3E]!5%1224)55$5?2T5975LG
M7U]D969A=6QT)UTI*2!["B`@("`@("`@("`@("`@("`O+R!K965P('1H:7,@
M9F]R($)#"B`@("`@("`@("`@("`@("`D:V5Y071T<B`]("1T:&ES+3YO<'1I
M;VYS6UA-3%]53E-%4DE!3$E:15)?3U!424].7T%45%))0E5415]+15E=6R=?
M7V1E9F%U;'0G73L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`*
M("`@("`@("!I9B`H)&ME>4%T='(@(3T](&9A;'-E("8F(&ES<V5T*"1A='1R
M:6)S6R1K97E!='1R72DI('L*("`@("`@("`@("`@)'9A;%LG;F%M92==(#T@
M)&%T=')I8G-;)&ME>4%T=')=.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES
M<V5T*"1A='1R:6)S6R1T:&ES+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?
M3U!424].7T%45%))0E5415]#3$%34UU=*2D@>PH@("`@("`@("`@("`D=F%L
M6R=C;&%S<R==(#T@)&%T=')I8G-;)'1H:7,M/F]P=&EO;G-;6$U,7U5.4T52
M24%,25I%4E]/4%1)3TY?05144DE"551%7T-,05-375T["B`@("`@("`@?0H*
M("`@("`@("!A<G)A>5]P=7-H*"1T:&ES+3Y?=F%L4W1A8VLL("1V86PI.PH@
M("`@?0H*("`@+RHJ"B`@("`J(%1R>2!T;R!G=65S<R!T:&4@='EP92!O9B!S
M979E<F%L('9A;'5E<R!A;F0*("`@("H@<V5T('1H96T@86-C;W)D:6YG;'D*
M("`@("H*("`@("H@0&%C8V5S<R`@('!R:79A=&4*("`@("H@0'!A<F%M("`@
M(&%R<F%Y("`@("`@87)R87DL(&-O;G1A:6YI;F<@=&AE('9A;'5E<PH@("`@
M*B!`<F5T=7)N("`@87)R87D@("`@("!A<G)A>2P@8V]N=&%I;FEN9R!T:&4@
M=F%L=65S('=I=&@@=&AE:7(@8V]R<F5C="!T>7!E<R`*("`@("HO"B`@("!F
M=6YC=&EO;B!?9W5E<W-!;F139714>7!E<R@D87)R87DI"B`@("!["B`@("`@
M("`@9F]R96%C:"`H)&%R<F%Y(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@
M("`@"21A<G)A>5LD:V5Y72`]("1T:&ES+3Y?9W5E<W-!;F139714>7!E*"1V
M86QU92D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D87)R87D["B`@("!]
M"B`@("`*("`@+RHJ"B`@("`J(%1R>2!T;R!G=65S<R!T:&4@='EP92!O9B!A
M('9A;'5E(&%N9`H@("`@*B!S970@:70@86-C;W)D:6YG;'D*("`@("H*("`@
M("H@0&%C8V5S<R`@('!R:79A=&4*("`@("H@0'!A<F%M("`@('-T<FEN9R`@
M("`@(&-H87)A8W1E<B!D871A"B`@("`J($!R971U<FX@("!M:7AE9"`@("`@
M("!V86QU92!W:71H('1H92!B97-T(&UA=&-H:6YG('1Y<&4*("`@("HO"B`@
M("!F=6YC=&EO;B!?9W5E<W-!;F139714>7!E*"1V86QU92D*("`@('L*("`@
M("`@("!I9B`H)'9A;'5E(#T]/2`G=')U92<I('L*("`@("`@("`@("`@<F5T
M=7)N('1R=64["B`@("`@("`@?0H@("`@("`@(&EF("@D=F%L=64@/3T]("=F
M86QS92<I('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M("`@("`@("!I9B`H)'9A;'5E(#T]/2`G3E5,3"<I('L*("`@("`@("`@("`@
M<F5T=7)N(&YU;&P["B`@("`@("`@?0H@("`@("`@(&EF("AP<F5G7VUA=&-H
M*"<O7ELM*UT_6S`M.5U[,2Q])"\G+"`D=F%L=64I*2!["B`@("`@("`@"7)E
M='5R;B!I;G1V86PH)'9A;'5E*3L*("`@("`@("!]"B`@("`@("`@:68@*'!R
M96=?;6%T8V@H)R]>6RTK73];,"TY77LQ+'U<+ELP+3E=>S$L?20O)RP@)'9A
M;'5E*2D@>PH@("`@("`@(`ER971U<FX@9&]U8FQE=F%L*"1V86QU92D["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`H<W1R:6YG*21V86QU93L*("`@('T*
M("`@(`H@("`O*BH*("`@("H@16YD(&5L96UE;G0@:&%N9&QE<B!F;W(@6$U,
M('!A<G-E<@H@("`@*@H@("`@*B!`86-C97-S('!R:79A=&4*("`@("H@0'!A
M<F%M("!O8FIE8W0@6$U,('!A<G-E<B!O8FIE8W0*("`@("H@0'!A<F%M("!S
M=')I;F<*("`@("H@0')E='5R;B!V;VED"B`@("`J+PH@("`@9G5N8W1I;VX@
M96YD2&%N9&QE<B@D<&%R<V5R+"`D96QE;65N="D*("`@('L*("`@("`@("`D
M=F%L=64@/2!A<G)A>5]P;W`H)'1H:7,M/E]V86Q3=&%C:RD["B`@("`@("`@
M<W=I=&-H("@D=&AI<RT^;W!T:6]N<UM834Q?54Y315))04Q)6D527T]05$E/
M3E]72$E415-004-%72D@>PH@("`@("`@("`@("!C87-E(%A-3%]53E-%4DE!
M3$E:15)?5TA)5$534$%#15]+1450.@H@("`@("`@("`@("`@("`@)&1A=&$@
M/2`D=&AI<RT^7V1A=&%3=&%C:ULD=&AI<RT^7V1E<'1H73L*("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E(%A-3%]53E-%4DE!3$E:
M15)?5TA)5$534$%#15].3U)-04Q)6D4Z"B`@("`@("`@("`@("`@("`D9&%T
M82`]('1R:6TH<')E9U]R97!L86-E*"<O7'-<<RLO;2<L("<@)RP@)'1H:7,M
M/E]D871A4W1A8VM;)'1H:7,M/E]D97!T:%TI*3L*("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("!C87-E(%A-3%]53E-%4DE!3$E:15)?5TA)
M5$534$%#15]44DE-.@H@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@
M("`@("`@)&1A=&$@(#T@=')I;2@D=&AI<RT^7V1A=&%3=&%C:ULD=&AI<RT^
M7V1E<'1H72D["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@
M("`@("`@("\O(&%D:G5S="!T>7!E(&]F('1H92!V86QU90H@("`@("`@('-W
M:71C:"AS=')T;VQO=V5R*"1V86QU95LG='EP92==*2D@>PH*("`@("`@("`@
M("`@+R\@=6YS97)I86QI>F4@86X@;V)J96-T"B`@("`@("`@("`@(&-A<V4@
M)V]B:F5C="<Z"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'9A;'5E6R=C
M;&%S<R==*2D@>PH@("`@("`@("`@("`@("`@("`@("1C;&%S<VYA;64@(#T@
M)'9A;'5E6R=C;&%S<R==.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`D8VQA<W-N86UE(#T@)R<["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`O+R!I;G-T86YT:6%T92!T:&4@8VQA
M<W,*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<UM834Q?54Y3
M15))04Q)6D527T]05$E/3E]404=?05-?0TQ!4U-.04U%72`]/3T@=')U92`F
M)B!C;&%S<U]E>&ES=',H)&-L87-S;F%M92DI('L*("`@("`@("`@("`@("`@
M("`@("`D=F%L=65;)W9A;'5E)UT@/2`F;F5W("1C;&%S<VYA;64["B`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1V86QU
M95LG=F%L=64G72`]("9N97<@)'1H:7,M/F]P=&EO;G-;6$U,7U5.4T5224%,
M25I%4E]/4%1)3TY?1$5&055,5%]#3$%34UT["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!I9B`H=')I;2@D9&%T82D@(3T]("<G*2!["B`@
M("`@("`@("`@("`@("`@("`@:68@*"1V86QU95LG9W5E<W-4>7!E)UT@/3T]
M('1R=64I('L*("`@("`@("`@("`@("`@("`@("`))&1A=&$@/2`D=&AI<RT^
M7V=U97-S06YD4V5T5'EP92@D9&%T82D["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@("1V86QU95LG8VAI;&1R96XG75LD=&AI
M<RT^;W!T:6]N<UM834Q?54Y315))04Q)6D527T]05$E/3E]#3TY414Y47TM%
M65U=(#T@)&1A=&$["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@
M("`@+R\@<V5T('!R;W!E<G1I97,*("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1V86QU95LG8VAI;&1R96XG72!A<R`D<')O<"`]/B`D<')O<%9A;"D@>PH@
M("`@("`@("`@("`@("`@("`@("\O(&-H96-K('=H971H97(@=&AE<F4@:7,@
M82!S<&5C:6%L(&UE=&AO9"!T;R!S970@=&AI<R!P<F]P97)T>0H@("`@("`@
M("`@("`@("`@("`@("1S971-971H;V0@/2`G<V5T)RXD<')O<#L*("`@("`@
M("`@("`@("`@("`@("!I9B`H;65T:&]D7V5X:7-T<R@D=F%L=65;)W9A;'5E
M)UTL("1S971-971H;V0I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&-A
M;&Q?=7-E<E]F=6YC*&%R<F%Y*"8D=F%L=65;)W9A;'5E)UTL("1S971-971H
M;V0I+"`D<')O<%9A;"D["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E6R=V86QU92==+3XD<')O
M<"`]("1P<F]P5F%L.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("\O("!C:&5C:R!F;W(@;6%G:6,@
M9G5N8W1I;VX*("`@("`@("`@("`@("`@(&EF("AM971H;V1?97AI<W1S*"1V
M86QU95LG=F%L=64G72P@)U]?=V%K975P)RDI('L*("`@("`@("`@("`@("`@
M("`@("`D=F%L=65;)W9A;'5E)UTM/E]?=V%K975P*"D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("\O
M('5N<V5R:6%L:7IE(&%N(&%R<F%Y"B`@("`@("`@("`@(&-A<V4@)V%R<F%Y
M)SH*("`@("`@("`@("`@("`@(&EF("AT<FEM*"1D871A*2`A/3T@)R<I('L*
M("`@("`@("`@("`@("`@("`@("!I9B`H)'9A;'5E6R=G=65S<U1Y<&4G72`]
M/3T@=')U92D@>PH@("`@("`@("`@("`@("`@("`@(`DD9&%T82`]("1T:&ES
M+3Y?9W5E<W-!;F139714>7!E*"1D871A*3L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@)'9A;'5E6R=C:&EL9')E;B==6R1T
M:&ES+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?3U!424].7T-/3E1%3E1?
M2T5975T@/2`D9&%T83L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D=F%L=65;)V-H:6QD<F5N)UTI*2!["B`@("`@("`@
M("`@("`@("`@("`@)'9A;'5E6R=V86QU92==(#T@)'9A;'5E6R=C:&EL9')E
M;B==.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`D=F%L=65;)W9A;'5E)UT@/2!A<G)A>2@I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`O+R!U
M;G-E<FEA;&EZ92!A(&YU;&P@=F%L=64*("`@("`@("`@("`@8V%S92`G;G5L
M;"<Z"B`@("`@("`@("`@("`@("`D9&%T82`](&YU;&P["B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@("\O('5N<V5R:6%L:7IE(&$@<F5S
M;W5R8V4@/3X@=&AI<R!I<R!N;W0@<&]S<VEB;&4@.BTH"B`@("`@("`@("`@
M(&-A<V4@)W)E<V]U<F-E)SH*("`@("`@("`@("`@("`@("1V86QU95LG=F%L
M=64G72`]("1D871A.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("`O+R!U;G-E<FEA;&EZ92!A;GD@<V-A;&%R('9A;'5E"B`@("`@("`@
M("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!I9B`H)'9A;'5E6R=G=65S
M<U1Y<&4G72`]/3T@=')U92D@>PH@("`@("`@("`@("`@("`@("`@("1D871A
M(#T@)'1H:7,M/E]G=65S<T%N9%-E=%1Y<&4H)&1A=&$I.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!S971T>7!E*"1D
M871A+"`D=F%L=65;)W1Y<&4G72D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@(`H@("`@("`@("`@("`@("`@)'9A;'5E6R=V86QU92==(#T@)&1A
M=&$["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@("`@("`@
M)'!A<F5N="`](&%R<F%Y7W!O<"@D=&AI<RT^7W9A;%-T86-K*3L*("`@("`@
M("!I9B`H)'!A<F5N="`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D=&AI<RT^
M7W5N<V5R:6%L:7IE9$1A=&$@/2`F)'9A;'5E6R=V86QU92==.PH@("`@("`@
M("`@("`D=&AI<RT^7W)O;W0@/2`F)'9A;'5E6R=N86UE)UT["B`@("`@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("\O('!A<F5N="!H87,@=&\@8F4@86X@87)R87D*("`@("`@("`@("`@:68@
M*"%I<W-E="@D<&%R96YT6R=C:&EL9')E;B==*2!\?"`A:7-?87)R87DH)'!A
M<F5N=%LG8VAI;&1R96XG72DI('L*("`@("`@("`@("`@("`@("1P87)E;G1;
M)V-H:6QD<F5N)UT@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@:68@*"%I
M;E]A<G)A>2@D<&%R96YT6R=T>7!E)UTL(&%R<F%Y*"=A<G)A>2<L("=O8FIE
M8W0G*2DI('L*("`@("`@("`@("`@("`@("`@("`D<&%R96YT6R=T>7!E)UT@
M/2`D=&AI<RT^7V=E=$-O;7!L97A4>7!E*"1P87)E;G1;)VYA;64G72D["B`@
M("`@("`@("`@("`@("`@("`@:68@*"1P87)E;G1;)W1Y<&4G72`]/2`G;V)J
M96-T)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<&%R96YT6R=C;&%S
M<R==(#T@)'!A<F5N=%LG;F%M92==.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M:68@*&EN7V%R<F%Y*"1E;&5M96YT+"`D=&AI<RT^;W!T:6]N<UM834Q?54Y3
M15))04Q)6D527T]05$E/3E])1TY/4D5?2T594UTI*2!["B`@("`@("`@("`@
M("`@("`D:6=N;W)E2V5Y(#T@=')U93L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@"21I9VYO<F5+97D@/2!F86QS93L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`*("`@("`@("`@("`@:68@*"%E;7!T>2@D=F%L=65;
M)VYA;64G72D@)B8@)&EG;F]R94ME>2`]/3T@9F%L<V4I('L*("`@("`@("`@
M("`@("`@("\O('1H97)E(&%L<F5A9'D@:&%S(&)E96X@82!T86<@=VET:"!T
M:&ES(&YA;64*("`@("`@("`@("`@("`@(&EF("AI;E]A<G)A>2@D=F%L=65;
M)VYA;64G72P@)'!A<F5N=%LG8VAI;&1R96Y+97ES)UTI('Q\(&EN7V%R<F%Y
M*"1V86QU95LG;F%M92==+"`D=&AI<RT^;W!T:6]N<UM834Q?54Y315))04Q)
M6D527T]05$E/3E]&3U)#15]%3E5-72DI('L*("`@("`@("`@("`@("`@("`@
M("`O+R!N;R!A9V=R96=A=&4@:&%S(&)E96X@8W)E871E9"!F;W(@=&AI<R!T
M86<*("`@("`@("`@("`@("`@("`@("!I9B`H(6EN7V%R<F%Y*"1V86QU95LG
M;F%M92==+"`D<&%R96YT6R=A9V=R96=+97ES)UTI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D<&%R96YT6R=C:&EL9')E;B==6R1V
M86QU95LG;F%M92==72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1P87)E;G1;)V-H:6QD<F5N)UU;)'9A;'5E6R=N86UE)UU=(#T@87)R87DH
M)'!A<F5N=%LG8VAI;&1R96XG75LD=F%L=65;)VYA;64G75TI.PH@("`@("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!A<F5N=%LG8VAI;&1R96XG75LD=F%L=65;)VYA;64G75T@
M/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y7W!U<V@H)'!A<F5N=%LG86=G<F5G2V5Y
M<R==+"`D=F%L=65;)VYA;64G72D["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y7W!U<V@H)'!A<F5N=%LG8VAI;&1R
M96XG75LD=F%L=65;)VYA;64G75TL("1V86QU95LG=F%L=64G72D["B`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1P87)E
M;G1;)V-H:6QD<F5N)UU;)'9A;'5E6R=N86UE)UU=(#T@)B1V86QU95LG=F%L
M=64G73L*("`@("`@("`@("`@("`@("`@("!A<G)A>5]P=7-H*"1P87)E;G1;
M)V-H:6QD<F5N2V5Y<R==+"`D=F%L=65;)VYA;64G72D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!A
M<G)A>5]P=7-H*"1P87)E;G1;)V-H:6QD<F5N)UTL("1V86QU95LG=F%L=64G
M72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@87)R87E?<'5S:"@D=&AI
M<RT^7W9A;%-T86-K+"`D<&%R96YT*3L*("`@("`@("!]"@H@("`@("`@("1T
M:&ES+3Y?9&5P=&@M+3L*("`@('T*"B`@("\J*@H@("`@*B!(86YD;&5R(&9O
M<B!C:&%R86-T97(@9&%T80H@("`@*@H@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("H@0'!A<F%M("!O8FIE8W0@6$U,('!A<G-E<B!O8FIE8W0*("`@("H@
M0'!A<F%M("!S=')I;F<@0T1!5$$*("`@("H@0')E='5R;B!V;VED"B`@("`J
M+PH@("`@9G5N8W1I;VX@8V1A=&%(86YD;&5R*"1P87)S97(L("1C9&%T82D*
M("`@('L*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;6$U,7U5.4T5224%,
M25I%4E]/4%1)3TY?1$5#3T1%7T953D-=("$]/2!N=6QL*2!["B`@("`@("`@
M("`@("1C9&%T82`](&-A;&Q?=7-E<E]F=6YC*"1T:&ES+3YO<'1I;VYS6UA-
M3%]53E-%4DE!3$E:15)?3U!424].7T1%0T]$15]&54Y#72P@)&-D871A*3L*
M("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]D871A4W1A8VM;)'1H:7,M/E]D
M97!T:%T@+CT@)&-D871A.PH@("`@?0H*("`@+RHJ"B`@("`J(&=E="!T:&4@
M8V]M<&QE>"!T>7!E+"!T:&%T('-H;W5L9"!B92!U<V5D(&9O<B!A('-P96-I
M9FEE9"!T86<*("`@("H*("`@("H@0&%C8V5S<R`@('!R:79A=&4*("`@("H@
M0'!A<F%M("`@('-T<FEN9R`@("`@(&YA;64@;V8@=&AE('1A9PH@("`@*B!`
M<F5T=7)N("`@<W1R:6YG("`@("`@8V]M<&QE>"!T>7!E("@G87)R87DG(&]R
M("=O8FIE8W0G*0H@("`@*B\*("`@(&9U;F-T:6]N(%]G971#;VUP;&5X5'EP
M92@D=&%G;F%M92D*("`@('L*("`@("`@("!I9B`H:7-?<W1R:6YG*"1T:&ES
M+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?3U!424].7T-/35!,15A465!%
M72DI('L*("`@("`@("`)<F5T=7)N("1T:&ES+3YO<'1I;VYS6UA-3%]53E-%
M4DE!3$E:15)?3U!424].7T-/35!,15A465!%73L*("`@("`@("!]"B`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?
M3U!424].7T-/35!,15A465!%75LD=&%G;F%M95TI*2!["B`@("`@("`@"7)E
M='5R;B`D=&AI<RT^;W!T:6]N<UM834Q?54Y315))04Q)6D527T]05$E/3E]#
M3TU03$585%E015U;)'1A9VYA;65=.PH@("`@("`@('T*("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/F]P=&EO;G-;6$U,7U5.4T5224%,25I%4E]/4%1)3TY?
M0T]-4$Q%6%194$5=6R<C9&5F875L="==*2D@>PH@("`@("`@(`ER971U<FX@
M)'1H:7,M/F]P=&EO;G-;6$U,7U5.4T5224%,25I%4E]/4%1)3TY?0T]-4$Q%
M6%194$5=6R<C9&5F875L="==.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M)V%R<F%Y)SL*("`@('T*("`@(`H@("`O*BH*("`@("H@8W)E871E('1H92!8
M34Q?4&%R<V5R(&EN<W1A;F-E"B`@("`J"B`@("`J($!A8V-E<W,@("`@<')I
M=F%T90H@("`@*B!`<F5T=7)N("`@(&)O;VQE86X*("`@("HO"B`@("!F=6YC
M=&EO;B!?8W)E871E4&%R<V5R*"D*("`@('L*("`@("`@("!I9B`H:7-?;V)J
M96-T*"1T:&ES+3Y?<&%R<V5R*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A
M<G-E<BT^9G)E92@I.PH@("`@("`@("`@("!U;G-E="@D=&AI<RT^7W!A<G-E
M<BD["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?<&%R<V5R(#T@)FYE=R!8
M34Q?4&%R<V5R*"1T:&ES+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?3U!4
M24].7T5.0T]$24Y'7U-/55)#15TL("=E=F5N="<L("1T:&ES+3YO<'1I;VYS
M6UA-3%]53E-%4DE!3$E:15)?3U!424].7T5.0T]$24Y'7U1!4D=%5%TI.PH@
M("`@("`@("1T:&ES+3Y?<&%R<V5R+3YF;VQD:6YG(#T@9F%L<V4["B`@("`@
M("`@)'1H:7,M/E]P87)S97(M/G-E=$AA;F1L97)/8FHH)'1H:7,I.PH@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0I]"C\^````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]834PO4V5R:6%L:7IE<BYP:'``````````````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,3$R-#<R(#$P-3$U-#,S-S,Q
M(#`R,3<U-0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/U!(4`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H
M:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J(%A-3%]397)I
M86QI>F5R"B`J"B`J($-R96%T97,@6$U,(&1O8W5M96YT<R!F<F]M(%!(4"!D
M871A('-T<G5C='5R97,@;&EK92!A<G)A>7,L(&]B:F5C=',@;W(@<V-A;&%R
M<RX*("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@
M5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F
M('1H92!02%`@;&EC96YS90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D
M:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A
M;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P
M;&5A<V4*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E
M(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E
M9V]R>2`@(%A-3`H@*B!`<&%C:V%G92`@("!834Q?4V5R:6%L:7IE<@H@*B!`
M875T:&]R("`@("!3=&5P:&%N(%-C:&UI9'0@/'-C:'-T0'!H<"YN970^"B`J
M($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E
M;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(
M4"!,:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@4V5R:6%L
M:7IE<BYP:'`L=B`Q+C0W(#(P,#4O,#DO,S`@,3,Z-#`Z,S`@<V-H<W0@17AP
M("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E
M+UA-3%]397)I86QI>F5R"B`J($!S964@("`@("`@(%A-3%]5;G-E<FEA;&EZ
M97(*("HO"@HO*BH*("H@=7-E<R!014%2(&5R<F]R(&UA;F%G96UE;G0*("HO
M"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PH*+RHJ"B`J('5S97,@6$U,7U5T
M:6P@=&\@8W)E871E(%A-3"!T86=S"B`J+PIR97%U:7)E7V]N8V4@)UA-3"]5
M=&EL+G!H<"<["@HO*BH*("H@;W!T:6]N.B!S=')I;F<@=7-E9"!F;W(@:6YD
M96YT871I;VX*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M(&%N>2!S=')I
M;F<@*&1E9F%U;'0@:7,@86YY('-T<FEN9RD*("HO"F1E9FEN92@G6$U,7U-%
M4DE!3$E:15)?3U!424].7TE.1$5.5"<L("=I;F1E;G0G*3L*"B\J*@H@*B!O
M<'1I;VXZ('-T<FEN9R!U<V5D(&9O<B!L:6YE8G)E86MS"B`J"B`J(%!O<W-I
M8FQE('9A;'5E<SH*("H@+2!A;GD@<W1R:6YG("AD969A=6QT(&ES(%QN*0H@
M*B\*9&5F:6YE*"=834Q?4T5224%,25I%4E]/4%1)3TY?3$E.14)214%+4R<L
M("=L:6YE8G)E86LG*3L*"B\J*@H@*B!O<'1I;VXZ(&5N86)L92!T>7!E(&AI
M;G1S"B`J"B`J(%!O<W-I8FQE('9A;'5E<SH*("H@+2!T<G5E"B`J("T@9F%L
M<V4*("HO"F1E9FEN92@G6$U,7U-%4DE!3$E:15)?3U!424].7U194$5(24Y4
M4R<L("=T>7!E2&EN=',G*3L*"B\J*@H@*B!O<'1I;VXZ(&%D9"!A;B!834P@
M9&5C;&%R871I;VX*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M('1R=64*
M("H@+2!F86QS90H@*B\*9&5F:6YE*"=834Q?4T5224%,25I%4E]/4%1)3TY?
M6$U,7T1%0TQ?14Y!0DQ%1"<L("=A9&1$96-L)RD["@HO*BH*("H@;W!T:6]N
M.B!E;F-O9&EN9R!O9B!T:&4@9&]C=6UE;G0*("H*("H@4&]S<VEB;&4@=F%L
M=65S.@H@*B`M(&%N>2!V86QI9"!E;F-O9&EN9PH@*B`M(&YU;&P@*&1E9F%U
M;'0I"B`J+PID969I;F4H)UA-3%]315))04Q)6D527T]05$E/3E]834Q?14Y#
M3T1)3D<G+"`G96YC;V1I;F<G*3L*"B\J*@H@*B!O<'1I;VXZ(&1E9F%U;'0@
M;F%M92!F;W(@=&%G<PH@*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J("T@86YY
M('-T<FEN9R`H6$U,7U-E<FEA;&EZ97)?5&%G(&ES(&1E9F%U;'0I"B`J+PID
M969I;F4H)UA-3%]315))04Q)6D527T]05$E/3E]$149!54Q47U1!1R<L("=D
M969A=6QT5&%G3F%M92<I.PH*+RHJ"B`J(&]P=&EO;CH@=7-E(&-L87-S;F%M
M92!F;W(@;V)J96-T<R!I;B!I;F1E>&5D(&%R<F%Y<PH@*@H@*B!0;W-S:6)L
M92!V86QU97,Z"B`J("T@=')U92`H9&5F875L="D*("H@+2!F86QS90H@*B\*
M9&5F:6YE*"=834Q?4T5224%,25I%4E]/4%1)3TY?0TQ!4U-.04U%7T%37U1!
M1TY!344G+"`G8VQA<W-!<U1A9TYA;64G*3L*"B\J*@H@*B!O<'1I;VXZ(&%T
M=')I8G5T92!W:&5R92!O<FEG:6YA;"!K97D@:7,@<W1O<F5D"B`J"B`J(%!O
M<W-I8FQE('9A;'5E<SH*("H@+2!A;GD@<W1R:6YG("AD969A=6QT(&ES(%]O
M<FEG:6YA;$ME>2D*("HO"F1E9FEN92@G6$U,7U-%4DE!3$E:15)?3U!424].
M7T%45%))0E5415]+15DG+"`G:V5Y071T<FEB=71E)RD["@HO*BH*("H@;W!T
M:6]N.B!A='1R:6)U=&4@9F]R('1Y<&4@*&]N;'D@:68@='EP94AI;G1S(#T^
M('1R=64I"B`J"B`J(%!O<W-I8FQE('9A;'5E<SH*("H@+2!A;GD@<W1R:6YG
M("AD969A=6QT(&ES(%]T>7!E*0H@*B\*9&5F:6YE*"=834Q?4T5224%,25I%
M4E]/4%1)3TY?05144DE"551%7U194$4G+"`G='EP94%T=')I8G5T92<I.PH*
M+RHJ"B`J(&]P=&EO;CH@871T<FEB=71E(&9O<B!C;&%S<R`H;VYL>2!I9B!T
M>7!E2&EN=',@/3X@=')U92D*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M
M(&%N>2!S=')I;F<@*&1E9F%U;'0@:7,@7V-L87-S*0H@*B\*9&5F:6YE*"=8
M34Q?4T5224%,25I%4E]/4%1)3TY?05144DE"551%7T-,05-3)RP@)V-L87-S
M071T<FEB=71E)RD["@HO*BH*("H@;W!T:6]N.B!S8V%L87(@=F%L=65S("AS
M=')I;F=S+"!I;G1S+"XN*2!W:6QL(&)E('-E<FEA;&EZ960@87,@871T<FEB
M=71E"B`J"B`J(%!O<W-I8FQE('9A;'5E<SH*("H@+2!T<G5E"B`J("T@9F%L
M<V4@*&1E9F%U;'0I"B`J("T@87)R87D@=VAI8V@@<V5T<R!T:&ES(&]P=&EO
M;B!O;B!A('!E<BUT86<@8F%S:7,*("HO"F1E9FEN92@G6$U,7U-%4DE!3$E:
M15)?3U!424].7U-#04Q!4E]!4U]!5%1224)55$53)RP@)W-C86QA<D%S071T
M<FEB=71E<R<I.PH*+RHJ"B`J(&]P=&EO;CH@<')E<&5N9"!S=')I;F<@9F]R
M(&%T=')I8G5T97,*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M(&%N>2!S
M=')I;F<@*&1E9F%U;'0@:7,@86YY('-T<FEN9RD*("HO"F1E9FEN92@G6$U,
M7U-%4DE!3$E:15)?3U!424].7U!215!%3D1?05144DE"551%4R<L("=P<F5P
M96YD071T<FEB=71E<R<I.PH*+RHJ"B`J(&]P=&EO;CH@:6YD96YT('1H92!A
M='1R:6)U=&5S+"!I9B!S970@=&\@)U]A=71O)RP@:70@=VEL;"!I;F1E;G0@
M871T<FEB=71E<R!S;R!T:&5Y(&%L;"!S=&%R="!A="!T:&4@<V%M92!C;VQU
M;6X*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M('1R=64*("H@+2!F86QS
M92`H9&5F875L="D*("HO"F1E9FEN92@G6$U,7U-%4DE!3$E:15)?3U!424].
M7TE.1$5.5%]!5%1224)55$53)RP@)VEN9&5N=$%T=')I8G5T97,G*3L*"B\J
M*@H@*B!O<'1I;VXZ('5S92`G<VEM<&QE>&UL)R!T;R!U<V4@<&%R96YT(&YA
M;64@87,@=&%G;F%M92!I9B!T<F%N<V9O<FUI;F<@86X@:6YD97AE9"!A<G)A
M>0H@*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J("T@6$U,7U-%4DE!3$E:15)?
M34]$15]$149!54Q4("AD969A=6QT*0H@*B`M(%A-3%]315))04Q)6D527TU/
M1$5?4TE-4$Q%6$U,"B`J+PID969I;F4H)UA-3%]315))04Q)6D527T]05$E/
M3E]-3T1%)RP@)VUO9&4G*3L*"B\J*@H@*B!O<'1I;VXZ(&%D9"!A(&1O8W1Y
M<&4@9&5C;&%R871I;VX*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M('1R
M=64*("H@+2!F86QS92`H9&5F875L="D*("HO"F1E9FEN92@G6$U,7U-%4DE!
M3$E:15)?3U!424].7T1/0U194$5?14Y!0DQ%1"<L("=A9&1$;V-T>7!E)RD[
M"@HO*BH*("H@;W!T:6]N.B!S=7!P;'D@82!S=')I;F<@;W(@86X@87)R87D@
M=VET:"!I9"!A;F0@=7)I("A[0'-E92!834Q?571I;#HZ9V5T1&]C='EP941E
M8VQA<F%T:6]N*"E]"B`J"B`J(%!O<W-I8FQE('9A;'5E<SH*("H@+2!S=')I
M;F<*("H@+2!A<G)A>0H@*B\*9&5F:6YE*"=834Q?4T5224%,25I%4E]/4%1)
M3TY?1$]#5%E012<L("=D;V-T>7!E)RD["@HO*BH*("H@;W!T:6]N.B!N86UE
M(&]F('1H92!R;V]T('1A9PH@*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J("T@
M<W1R:6YG"B`J("T@;G5L;"`H9&5F875L="D*("HO"F1E9FEN92@G6$U,7U-%
M4DE!3$E:15)?3U!424].7U)/3U1?3D%-12<L("=R;V]T3F%M92<I.PH*+RHJ
M"B`J(&]P=&EO;CH@871T<FEB=71E<R!O9B!T:&4@<F]O="!T86<*("H*("H@
M4&]S<VEB;&4@=F%L=65S.@H@*B`M(&%R<F%Y"B`J+PID969I;F4H)UA-3%]3
M15))04Q)6D527T]05$E/3E]23T]47T%45%))0E,G+"`G<F]O=$%T=')I8G5T
M97,G*3L*"B\J*@H@*B!O<'1I;VXZ(&%L;"!V86QU97,@:6X@=&AI<R!K97D@
M=VEL;"!B92!T<F5A=&5D(&%S(&%T=')I8G5T97,*("H*("H@4&]S<VEB;&4@
M=F%L=65S.@H@*B`M(&%R<F%Y"B`J+PID969I;F4H)UA-3%]315))04Q)6D52
M7T]05$E/3E]!5%1224)55$537TM%62<L("=A='1R:6)U=&5S07)R87DG*3L*
M"B\J*@H@*B!O<'1I;VXZ('1H:7,@=F%L=64@=VEL;"!B92!U<V5D(&1I<F5C
M=&QY(&%S(&-O;G1E;G0L(&EN<W1E860@;V8@8W)E871I;F<@82!N97<@=&%G
M+"!M87D@;VYL>2!B92!U<V5D(&EN(&-O;FIU8W1I;VX@=VET:"!A='1R:6)U
M=&5S07)R87D*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M('-T<FEN9PH@
M*B`M(&YU;&P@*&1E9F%U;'0I"B`J+PID969I;F4H)UA-3%]315))04Q)6D52
M7T]05$E/3E]#3TY414Y47TM%62<L("=C;VYT96YT3F%M92<I.PH*+RHJ"B`J
M(&]P=&EO;CH@=&AI<R!V86QU92!W:6QL(&)E('5S960@:6X@82!C;VUM96YT
M+"!I;G-T96%D(&]F(&-R96%T:6YG(&$@;F5W('1A9PH@*@H@*B!0;W-S:6)L
M92!V86QU97,Z"B`J("T@<W1R:6YG"B`J("T@;G5L;"`H9&5F875L="D*("HO
M"F1E9FEN92@G6$U,7U-%4DE!3$E:15)?3U!424].7T-/34U%3E1?2T59)RP@
M)V-O;6UE;G1.86UE)RD["@HO*BH*("H@;W!T:6]N.B!T86<@;F%M97,@=&AA
M="!W:6QL(&)E(&-H86YG960*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M
M(&%R<F%Y"B`J+PID969I;F4H)UA-3%]315))04Q)6D527T]05$E/3E]404=-
M05`G+"`G=&%G36%P)RD["@HO*BH*("H@;W!T:6]N.B!F=6YC=&EO;B!T:&%T
M('=I;&P@8F4@87!P;&EE9"!B969O<F4@<V5R:6%L:7II;F<*("H*("H@4&]S
M<VEB;&4@=F%L=65S.@H@*B`M(&%N>2!V86QI9"!02%`@8V%L;&)A8VL*("HO
M"F1E9FEN92@G6$U,7U-%4DE!3$E:15)?3U!424].7T5.0T]$15]&54Y#)RP@
M)V5N8V]D949U;F-T:6]N)RD["@HO*BH*("H@;W!T:6]N.B!F=6YC=&EO;B!T
M:&%T('=I;&P@8F4@87!P;&EE9"!B969O<F4@<V5R:6%L:7II;F<*("H*("H@
M4&]S<VEB;&4@=F%L=65S.@H@*B`M('-T<FEN9PH@*B`M(&YU;&P@*&1E9F%U
M;'0I"B`J+PID969I;F4H)UA-3%]315))04Q)6D527T]05$E/3E].04U%4U!!
M0T4G+"`G;F%M97-P86-E)RD["@HO*BH*("H@;W!T:6]N.B!T>7!E(&]F(&5N
M=&ET:65S('1O(')E<&QA8V4*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M
M(%A-3%]315))04Q)6D527T5.5$E424537TY/3D4*("H@+2!834Q?4T5224%,
M25I%4E]%3E1)5$E%4U]834P@*&1E9F%U;'0I"B`J("T@6$U,7U-%4DE!3$E:
M15)?14Y4251)15-?6$U,7U)%455)4D5$"B`J("T@6$U,7U-%4DE!3$E:15)?
M14Y4251)15-?2%1-3`H@*B\*9&5F:6YE*"=834Q?4T5224%,25I%4E]/4%1)
M3TY?14Y4251)15,G+"`G<F5P;&%C945N=&ET:65S)RD["@HO*BH*("H@;W!T
M:6]N.B!W:&5T:&5R('1O(')E='5R;B!T:&4@<F5S=6QT(&]F('1H92!S97)I
M86QI>F%T:6]N(&9R;VT@<V5R:6%L:7IE*"D*("H*("H@4&]S<VEB;&4@=F%L
M=65S.@H@*B`M('1R=64*("H@+2!F86QS92`H9&5F875L="D*("HO"F1E9FEN
M92@G6$U,7U-%4DE!3$E:15)?3U!424].7U)%5%523E]215-53%0G+"`G<F5T
M=7)N4F5S=6QT)RD["@HO*BH*("H@;W!T:6]N.B!W:&5T:&5R('1O(&EG;F]R
M92!P<F]P97)T:65S('1H870@87)E('-E="!T;R!N=6QL"B`J"B`J(%!O<W-I
M8FQE('9A;'5E<SH*("H@+2!T<G5E"B`J("T@9F%L<V4@*&1E9F%U;'0I"B`J
M+PID969I;F4H)UA-3%]315))04Q)6D527T]05$E/3E])1TY/4D5?3E5,3"<L
M("=I9VYO<F5.=6QL)RD["@HO*BH*("H@;W!T:6]N.B!W:&5T:&5R('1O('5S
M92!C9&%T82!S96-T:6]N<R!F;W(@8VAA<F%C=&5R(&1A=&$*("H*("H@4&]S
M<VEB;&4@=F%L=65S.@H@*B`M('1R=64*("H@+2!F86QS92`H9&5F875L="D*
M("HO"F1E9FEN92@G6$U,7U-%4DE!3$E:15)?3U!424].7T-$051!7U-%0U1)
M3TY3)RP@)V-D871A)RD["@H*+RHJ"B`J(&1E9F%U;'0@;6]D90H@*B\*9&5F
M:6YE*"=834Q?4T5224%,25I%4E]-3T1%7T1%1D%53%0G+"`G9&5F875L="<I
M.PH*+RHJ"B`J(%-I;7!L95A-3"!M;V1E"B`J"B`J(%=H96X@<V5R:6%L:7II
M;F<@:6YD97AE9"!A<G)A>7,L('1H92!K97D@;V8@=&AE('!A<F5N="!V86QU
M92!I<R!U<V5D(&%S(&$@=&%G;F%M92X*("HO"F1E9FEN92@G6$U,7U-%4DE!
M3$E:15)?34]$15]324U03$5834PG+"`G<VEM<&QE>&UL)RD["B`@("`@("`@
M("`@("`@("`@("`@("`@("`*+RHJ"B`J(&5R<F]R(&-O9&4@9F]R(&YO('-E
M<FEA;&EZ871I;VX@9&]N90H@*B\*9&5F:6YE*"=834Q?4T5224%,25I%4E]%
M4E)/4E].3U]315))04Q)6D%424].)RP@-3$I.PH*+RHJ"B`J(&1O(&YO="!R
M97!L86-E(&5N=&ET:71E<PH@*B\*9&5F:6YE*"=834Q?4T5224%,25I%4E]%
M3E1)5$E%4U].3TY%)RP@6$U,7U5424Q?14Y4251)15-?3D].12D["@HO*BH*
M("H@<F5P;&%C92!A;&P@6$U,(&5N=&ET:71E<PH@*B!4:&ES('-E='1I;F<@
M=VEL;"!R97!L86-E(#PL(#XL("(L("<@86YD("8*("HO"F1E9FEN92@G6$U,
M7U-%4DE!3$E:15)?14Y4251)15-?6$U,)RP@6$U,7U5424Q?14Y4251)15-?
M6$U,*3L*"B\J*@H@*B!R97!L86-E(&]N;'D@<F5Q=6ER960@6$U,(&5N=&ET
M:71E<PH@*B!4:&ES('-E='1I;F<@=VEL;"!R97!L86-E(#PL("(@86YD("8*
M("HO"F1E9FEN92@G6$U,7U-%4DE!3$E:15)?14Y4251)15-?6$U,7U)%455)
M4D5$)RP@6$U,7U5424Q?14Y4251)15-?6$U,7U)%455)4D5$*3L*"B\J*@H@
M*B!R97!L86-E($A434P@96YT:71I=&5S"B`J($!L:6YK("`@(&AT='`Z+R]W
M=W<N<&AP+FYE="]H=&UL96YT:71I97,*("HO"F1E9FEN92@G6$U,7U-%4DE!
M3$E:15)?14Y4251)15-?2%1-3"<L(%A-3%]55$E,7T5.5$E424537TA434PI
M.PH*+RHJ"B`J($-R96%T97,@6$U,(&1O8W5M96YT<R!F<F]M(%!(4"!D871A
M('-T<G5C='5R97,@;&EK92!A<G)A>7,L(&]B:F5C=',@;W(@<V-A;&%R<RX*
M("H*("H@=&AI<R!C;&%S<R!C86X@8F4@=7-E9"!I;B!T=V\@;6]D97,Z"B`J
M"B`J("`Q+B!C<F5A=&4@86X@6$U,(&1O8W5M96YT(&9R;VT@86X@87)R87D@
M;W(@;V)J96-T('1H870@:7,@<')O8V5S<V5D(&)Y(&]T:&5R"B`J("`@(&%P
M<&QI8V%T:6]N<RX@5&AA="!M96%N<RP@>6]U(&-A;B!C<F5A=&4@82!21$8@
M9&]C=6UE;G0@9G)O;2!A;B!A<G)A>2!I;B!T:&4*("H@("`@9F]L;&]W:6YG
M(&9O<FUA=#H*("H*("H@("`@)&1A=&$@/2!A<G)A>2@*("H@("`@("`@("`@
M("`@("=C:&%N;F5L)R`]/B!A<G)A>2@*("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W1I=&QE)R`]/B`G17AA;7!L92!21$8@8VAA;FYE;"<L"B`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=L:6YK)R`@/3X@)VAT='`Z
M+R]W=W<N<&AP+71O;VQS+F1E)RP*("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VEM86=E)R`]/B!A<G)A>2@*("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W1I=&QE)R`]/B`G17AA;7!L92!I;6%G
M92<L"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=U<FPG("`@/3X@)VAT='`Z+R]W=W<N<&AP+71O;VQS+F1E+VEM86=E+F=I
M9B<L"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=L:6YK)R`@/3X@)VAT='`Z+R]W=W<N<&AP+71O;VQS+F1E)PH@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I+`H@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@*("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G=&ET;&4G(#T^("=%>&%M<&QE(&ET
M96TG+`H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=L:6YK
M)R`@/3X@)VAT='`Z+R]E>&%M<&QE+F-O;2<*("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`I+`H@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G=&ET;&4G(#T^("=!;F]T:&5R($5X86UP;&4@:71E;2<L"B`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)VQI;FLG("`]/B`G:'1T<#HO
M+V5X86UP;&4N;W)G)PH@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("D*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I"B`J("`@
M("`@("`@("`@("D["B`J"B`J("`@=&\@8W)E871E(&$@4D1&(&1O8W5M96YT
M(&9R;VT@=&AI<R!A<G)A>2!D;R!T:&4@9F]L;&]W:6YG.@H@*@H@*B`@(')E
M<75I<F5?;VYC92`G6$U,+U-E<FEA;&EZ97(N<&AP)SL*("H*("H@("`D;W!T
M:6]N<R`](&%R<F%Y*`H@*B`@("`@("`@("`@("`@("`@("`@(%A-3%]315))
M04Q)6D527T]05$E/3E])3D1%3E0@("`@("`]/B`B7'0B+"`@("`@("`@+R\@
M:6YD96YT('=I=&@@=&%B<PH@*B`@("`@("`@("`@("`@("`@("`@(%A-3%]3
M15))04Q)6D527T]05$E/3E],24Y%0E)%04M3("`]/B`B7&XB+"`@("`@("`@
M+R\@=7-E(%5.25@@;&EN92!B<F5A:W,*("H@("`@("`@("`@("`@("`@("`@
M("!834Q?4T5224%,25I%4E]/4%1)3TY?4D]/5%].04U%("`@/3X@)W)D9CI2
M1$8G+"`@("\O(')O;W0@=&%G"B`J("`@("`@("`@("`@("`@("`@("`@6$U,
M7U-%4DE!3$E:15)?3U!424].7T1%1D%53%1?5$%'(#T^("=I=&5M)R`@("`@
M("`O+R!T86<@9F]R('9A;'5E<R!W:71H(&YU;65R:6,@:V5Y<PH@*B`@("D[
M"B`J"B`J("`@)'-E<FEA;&EZ97(@/2!N97<@6$U,7U-E<FEA;&EZ97(H)&]P
M=&EO;G,I.PH@*B`@("1R9&8@("`@("`@(#T@)'-E<FEA;&EZ97(M/G-E<FEA
M;&EZ92@D9&%T82D["B`J"B`J(%EO=2!W:6QL(&=E="!A(&-O;7!L971E(%A-
M3"!D;V-U;65N="!T:&%T(&-A;B!B92!P<F]C97-S960@;&EK92!A;GD@4D1&
M(&1O8W5M96YT+@H@*@H@*B`R+B!T:&ES(&-L87-S97,@8V%N(&)E('5S960@
M=&\@<V5R:6%L:7IE(&%N>2!D871A('-T<G5C='5R92!I;B!A('=A>2!T:&%T
M(&ET(&-A;@H@*B`@("!L871E<B!B92!U;G-E<FEA;&EZ960@86=A:6XN"B`J
M("`@(%A-3%]397)I86QI>F5R('=I;&P@<W1O<F4@=&AE('1Y<&4@;V8@=&AE
M('9A;'5E(&%N9"!A9&1I=&EO;F%L(&UE=&$@:6YF;W)M871I;VX*("H@("`@
M:6X@871T<FEB=71E<R!O9B!T:&4@<W5R<F]U;F1I;F<@=&%G+B!4:&ES(&UE
M870@:6YF;W)M871I;VX@8V%N(&QA=&5R(&)E('5S960*("H@("`@=&\@<F5S
M=&]R92!T:&4@;W)I9VEN86P@9&%T82!S=')U8W1U<F4@:6X@4$A0+B!)9B!Y
M;W4@=V%N="!834Q?4V5R:6%L:7IE<@H@*B`@("!T;R!A9&0@;65T82!I;F9O
M<FUA=&EO;B!T;R!T:&4@=&%G<RP@861D"B`J"B`J("`@("`@6$U,7U-%4DE!
M3$E:15)?3U!424].7U194$5(24Y44R`]/B!T<G5E"B`J"B`J("`@('1O('1H
M92!O<'1I;VYS(&%R<F%Y(&EN('1H92!C;VYS=')U8W1O<BX*("H*("H@0&-A
M=&5G;W)Y("`@6$U,"B`J($!P86-K86=E("`@(%A-3%]397)I86QI>F5R"B`J
M($!A=71H;W(@("`@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*
M("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI
M8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@
M4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#`N,3@N
M,`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O
M6$U,7U-E<FEA;&EZ97(*("H@0'-E92`@("`@("`@6$U,7U5N<V5R:6%L:7IE
M<@H@*B\*8VQA<W,@6$U,7U-E<FEA;&EZ97(@97AT96YD<R!014%2"GL*("`@
M+RHJ"B`@("`J(&QI<W0@;V8@86QL(&%V86EL86)L92!O<'1I;VYS"B`@("`J
M"B`@("`J($!A8V-E<W,@<')I=F%T90H@("`@*B!`=F%R("`@(&%R<F%Y"B`@
M("`J+PH@("`@=F%R("1?:VYO=VY/<'1I;VYS(#T@87)R87DH"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/
M3E])3D1%3E0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%A-
M3%]315))04Q)6D527T]05$E/3E],24Y%0E)%04M3+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?5%E0
M14A)3E13+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!834Q?
M4T5224%,25I%4E]/4%1)3TY?6$U,7T1%0TQ?14Y!0DQ%1"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].
M7UA-3%]%3D-/1$E.1RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@6$U,7U-%4DE!3$E:15)?3U!424].7T1%1D%53%1?5$%'+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)
M3TY?0TQ!4U-.04U%7T%37U1!1TY!344L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]!5%1224)55$5?
M2T59+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T52
M24%,25I%4E]/4%1)3TY?05144DE"551%7U194$4L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]!5%12
M24)55$5?0TQ!4U,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%A-3%]315))04Q)6D527T]05$E/3E]30T%,05)?05-?05144DE"551%4RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:
M15)?3U!424].7U!215!%3D1?05144DE"551%4RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7TE.1$5.
M5%]!5%1224)55$53+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!834Q?4T5224%,25I%4E]/4%1)3TY?34]$12P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7T1/0U19
M4$5?14Y!0DQ%1"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M6$U,7U-%4DE!3$E:15)?3U!424].7T1/0U194$4L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]23T]4
M7TY!344L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]3
M15))04Q)6D527T]05$E/3E]23T]47T%45%))0E,L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]!5%12
M24)55$537TM%62P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M6$U,7U-%4DE!3$E:15)?3U!424].7T-/3E1%3E1?2T59+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?
M0T]-345.5%]+15DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%A-3%]315))04Q)6D527T]05$E/3E]404=-05`L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]%3D-/
M1$5?1E5.0RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6$U,
M7U-%4DE!3$E:15)?3U!424].7TY!34534$%#12P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7T5.5$E4
M2453+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T52
M24%,25I%4E]/4%1)3TY?4D5455).7U)%4U5,5"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7TE'3D]2
M15].54Q,+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!834Q?
M4T5224%,25I%4E]/4%1)3TY?0T1!5$%?4T5#5$E/3E,*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`I.PH@("`@"B`@("\J*@H@("`@*B!D969A
M=6QT(&]P=&EO;G,@9F]R('1H92!S97)I86QI>F%T:6]N"B`@("`J"B`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@*B!`=F%R("`@(&%R<F%Y"B`@("`J+PH@
M("`@=F%R("1?9&5F875L=$]P=&EO;G,@/2!A<G)A>2@*("`@("`@("`@("`@
M("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E])3D1%3E0@("`@
M("`@("`@("`@("`]/B`G)RP@("`@("`@("`@("`@("`@("`@("\O('-T<FEN
M9R!U<V5D(&9O<B!I;F1E;G1A=&EO;@H@("`@("`@("`@("`@("`@("`@("`@
M("`@6$U,7U-%4DE!3$E:15)?3U!424].7TQ)3D5"4D5!2U,@("`@("`@("`@
M(#T^(")<;B(L("`@("`@("`@("`@("`@("`@+R\@<W1R:6YG('5S960@9F]R
M(&YE=VQI;F5S"B`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,
M25I%4E]/4%1)3TY?5%E014A)3E13("`@("`@("`@("`@/3X@9F%L<V4L("`@
M("`@("`@("`@("`@("`O+R!A=71O;6%T:6-A;&QY(&%D9"!T>7!E(&AI;B!A
M='1R:6)U=&5S"B`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,
M25I%4E]/4%1)3TY?6$U,7T1%0TQ?14Y!0DQ%1"`@("`@/3X@9F%L<V4L("`@
M("`@("`@("`@("`@("`O+R!A9&0@86X@6$U,(&1E8VQA<F%T:6]N"B`@("`@
M("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?6$U,
M7T5.0T]$24Y'("`@("`@("`@/3X@;G5L;"P@("`@("`@("`@("`@("`@("`O
M+R!E;F-O9&EN9R!S<&5C:69I960@:6X@=&AE(%A-3"!D96-L87)A=&EO;@H@
M("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].
M7T1%1D%53%1?5$%'("`@("`@("`@(#T^("=834Q?4V5R:6%L:7IE<E]486<G
M+"`@+R\@=&%G('5S960@9F]R(&EN9&5X960@87)R87ES(&]R(&EN=F%L:60@
M;F%M97,*("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D52
M7T]05$E/3E]#3$%34TY!345?05-?5$%'3D%-12`]/B!F86QS92P@("`@("`@
M("`@("`@("`@("\O('5S92!C;&%S<VYA;64@9F]R(&]B:F5C=',@:6X@:6YD
M97AE9"!A<G)A>7,*("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))
M04Q)6D527T]05$E/3E]!5%1224)55$5?2T59("`@("`@("`]/B`G7V]R:6=I
M;F%L2V5Y)RP@("`@("`@("\O(&%T=')I8G5T92!W:&5R92!O<FEG:6YA;"!K
M97D@:7,@<W1O<F5D"B`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T52
M24%,25I%4E]/4%1)3TY?05144DE"551%7U194$4@("`@("`@/3X@)U]T>7!E
M)RP@("`@("`@("`@("`@("`O+R!A='1R:6)U=&4@9F]R('1Y<&4@*&]N;'D@
M:68@='EP94AI;G1S(#T^('1R=64I"B`@("`@("`@("`@("`@("`@("`@("`@
M("!834Q?4T5224%,25I%4E]/4%1)3TY?05144DE"551%7T-,05-3("`@("`@
M/3X@)U]C;&%S<R<L("`@("`@("`@("`@("`O+R!A='1R:6)U=&4@9F]R(&-L
M87-S(&]F(&]B:F5C=',@*&]N;'D@:68@='EP94AI;G1S(#T^('1R=64I"B`@
M("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?
M4T-!3$%27T%37T%45%))0E5415,@/3X@9F%L<V4L("`@("`@("`@("`@("`@
M("`O+R!S8V%L87(@=F%L=65S("AS=')I;F=S+"!I;G1S+"XN*2!W:6QL(&)E
M('-E<FEA;&EZ960@87,@871T<FEB=71E"B`@("`@("`@("`@("`@("`@("`@
M("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?4%)%4$5.1%]!5%1224)55$53
M("`@/3X@)R<L("`@("`@("`@("`@("`@("`@("`O+R!P<F5P96YD('-T<FEN
M9R!F;W(@871T<FEB=71E<PH@("`@("`@("`@("`@("`@("`@("`@("`@6$U,
M7U-%4DE!3$E:15)?3U!424].7TE.1$5.5%]!5%1224)55$53("`@(#T^(&9A
M;'-E+"`@("`@("`@("`@("`@("`@+R\@:6YD96YT('1H92!A='1R:6)U=&5S
M+"!I9B!S970@=&\@)U]A=71O)RP@:70@=VEL;"!I;F1E;G0@871T<FEB=71E
M<R!S;R!T:&5Y(&%L;"!S=&%R="!A="!T:&4@<V%M92!C;VQU;6X*("`@("`@
M("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]-3T1%
M("`@("`@("`@("`@("`@("`]/B!834Q?4T5224%,25I%4E]-3T1%7T1%1D%5
M3%0L("`@("`@("`@("`@("\O('5S92!834Q?4T5224%,25I%4E]-3T1%7U-)
M35!,15A-3"!T;R!U<V4@<&%R96YT(&YA;64@87,@=&%G;F%M92!I9B!T<F%N
M<V9O<FUI;F<@86X@:6YD97AE9"!A<G)A>0H@("`@("`@("`@("`@("`@("`@
M("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7T1/0U194$5?14Y!0DQ%1"`@
M("`@(#T^(&9A;'-E+"`@("`@("`@("`@("`@("`@+R\@861D(&$@9&]C='EP
M92!D96-L87)A=&EO;@H@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%
M4DE!3$E:15)?3U!424].7T1/0U194$4@("`@("`@("`@("`@(#T^(&YU;&PL
M("`@("`@("`@("`@("`@("`@+R\@<W5P<&QY(&$@<W1R:6YG(&]R(&%N(&%R
M<F%Y('=I=&@@:60@86YD('5R:2`H>T!S964@6$U,7U5T:6PZ.F=E=$1O8W1Y
M<&5$96-L87)A=&EO;B@I?0H@("`@("`@("`@("`@("`@("`@("`@("`@6$U,
M7U-%4DE!3$E:15)?3U!424].7U)/3U1?3D%-12`@("`@("`@("`@(#T^(&YU
M;&PL("`@("`@("`@("`@("`@("`@+R\@;F%M92!O9B!T:&4@<F]O="!T86<*
M("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/
M3E]23T]47T%45%))0E,@("`@("`@("`]/B!A<G)A>2@I+"`@("`@("`@("`@
M("`@("\O(&%T=')I8G5T97,@;V8@=&AE(')O;W0@=&%G"B`@("`@("`@("`@
M("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?05144DE"551%
M4U]+15D@("`@("`@/3X@;G5L;"P@("`@("`@("`@("`@("`@("`O+R!A;&P@
M=F%L=65S(&EN('1H:7,@:V5Y('=I;&P@8F4@=')E871E9"!A<R!A='1R:6)U
M=&5S"B`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/
M4%1)3TY?0T].5$5.5%]+15D@("`@("`@("`@/3X@;G5L;"P@("`@("`@("`@
M("`@("`@("`O+R!T:&ES('9A;'5E('=I;&P@8F4@=7-E9"!D:7)E8W1L>2!A
M<R!C;VYT96YT+"!I;G-T96%D(&]F(&-R96%T:6YG(&$@;F5W('1A9RP@;6%Y
M(&]N;'D@8F4@=7-E9"!I;B!C;VYJ=6-T:6]N('=I=&@@871T<FEB=71E<T%R
M<F%Y"B`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/
M4%1)3TY?0T]-345.5%]+15D@("`@("`@("`@/3X@;G5L;"P@("`@("`@("`@
M("`@("`@("`O+R!T:&ES('9A;'5E('=I;&P@8F4@=7-E9"!D:7)E8W1L>2!A
M<R!C;VUM96YT+"!I;G-T96%D(&]F(&-R96%T:6YG(&$@;F5W('1A9RP@;6%Y
M(&]N;'D@8F4@=7-E9"!I;B!C;VYJ=6-T:6]N('=I=&@@871T<FEB=71E<T%R
M<F%Y"B`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/
M4%1)3TY?5$%'34%0("`@("`@("`@("`@("`@/3X@87)R87DH*2P@("`@("`@
M("`@("`@("`O+R!T86<@;F%M97,@=&AA="!W:6QL(&)E(&-H86YG960*("`@
M("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]%
M3D-/1$5?1E5.0R`@("`@("`@("`]/B!N=6QL+"`@("`@("`@("`@("`@("`@
M("\O(&9U;F-T:6]N('1H870@=VEL;"!B92!A<'!L:65D(&)E9F]R92!S97)I
M86QI>FEN9PH@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:
M15)?3U!424].7TY!34534$%#12`@("`@("`@("`@(#T^(&YU;&PL("`@("`@
M("`@("`@("`@("`@+R\@;F%M97-P86-E('1O('5S90H@("`@("`@("`@("`@
M("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7T5.5$E42453("`@
M("`@("`@("`@(#T^(%A-3%]315))04Q)6D527T5.5$E424537UA-3"P@+R\@
M='EP92!O9B!E;G1I=&EE<R!T;R!R97!L86-E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7U)%5%523E]215-53%0@
M("`@("`@(#T^(&9A;'-E+"`@("`@("`@("`@("`@("`@+R\@<V5R:6%L:7IE
M*"D@<F5T=7)N<R!T:&4@<F5S=6QT(&]F('1H92!S97)I86QI>F%T:6]N(&EN
M<W1E860@;V8@=')U90H@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%
M4DE!3$E:15)?3U!424].7TE'3D]215].54Q,("`@("`@("`@(#T^(&9A;'-E
M+"`@("`@("`@("`@("`@("`@+R\@:6=N;W)E('!R;W!E<G1I97,@=&AA="!A
M<F4@<V5T('1O(&YU;&P*("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]3
M15))04Q)6D527T]05$E/3E]#1$%405]314-424].4R`@("`@("`]/B!F86QS
M92`@("`@("`@("`@("`@("`@("\O(%=H971H97(@=&\@=7-E(&-D871A('-E
M8W1I;VYS(&9O<B!P;&%I;B!C:&%R86-T97(@9&%T80H@("`@("`@("`@("`@
M("`@("`@("`@("`I.PH*("`@+RHJ"B`@("`J(&]P=&EO;G,@9F]R('1H92!S
M97)I86QI>F%T:6]N"B`@("`J"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J
M($!V87(@("`@87)R87D*("`@("HO"B`@("!V87(@)&]P=&EO;G,@/2!A<G)A
M>2@I.PH*("`@+RHJ"B`@("`J(&-U<G)E;G0@=&%G(&1E<'1H"B`@("`J"B`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@*B!`=F%R("`@(&EN=&5G97(*("`@
M("HO"B`@("!V87(@)%]T86=$97!T:"`](#`["@H@("`O*BH*("`@("H@<V5R
M:6QI86QI>F5D(')E<')E<V5N=&%T:6]N(&]F('1H92!D871A"B`@("`J"B`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@*B!`=F%R("`@('-T<FEN9PH@("`@
M*B\*("`@('9A<B`D7W-E<FEA;&EZ961$871A(#T@;G5L;#L*("`@(`H@("`O
M*BH*("`@("H@8V]N<W1R=6-T;W(*("`@("H*("`@("H@0&%C8V5S<R`@('!U
M8FQI8PH@("`@*B!`<&%R86T@("`@;6EX960@("`D;W!T:6]N<R`@("!A<G)A
M>2!C;VYT86EN:6YG(&]P=&EO;G,@9F]R('1H92!S97)I86QI>F%T:6]N"B`@
M("`J+PH@("`@9G5N8W1I;VX@6$U,7U-E<FEA;&EZ97(H("1O<'1I;VYS(#T@
M;G5L;"`I"B`@("!["B`@("`@("`@)'1H:7,M/E!%05(H*3L*("`@("`@("!I
M9B`H:7-?87)R87DH)&]P=&EO;G,I*2!["B`@("`@("`@("`@("1T:&ES+3YO
M<'1I;VYS(#T@87)R87E?;65R9V4H)'1H:7,M/E]D969A=6QT3W!T:6]N<RP@
M)&]P=&EO;G,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES
M+3YO<'1I;VYS(#T@)'1H:7,M/E]D969A=6QT3W!T:6]N<SL*("`@("`@("!]
M"B`@("!]"@H@("`O*BH*("`@("H@<F5T=7)N($%022!V97)S:6]N"B`@("`J
M"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("H@0'-T871I8PH@("`@*B!`
M<F5T=7)N("`@<W1R:6YG("`D=F5R<VEO;B!!4$D@=F5R<VEO;@H@("`@*B\*
M("`@(&9U;F-T:6]N(&%P:59E<G-I;VXH*0H@("`@>PH@("`@("`@(')E='5R
M;B`G,"XQ."XP)SL*("`@('T*"B`@("\J*@H@("`@*B!R97-E="!A;&P@;W!T
M:6]N<R!T;R!D969A=6QT(&]P=&EO;G,*("`@("H*("`@("H@0&%C8V5S<R`@
M('!U8FQI8PH@("`@*B!`<V5E("`@("`@<V5T3W!T:6]N*"DL(%A-3%]397)I
M86QI>F5R*"D*("`@("HO"B`@("!F=6YC=&EO;B!R97-E=$]P=&EO;G,H*0H@
M("`@>PH@("`@("`@("1T:&ES+3YO<'1I;VYS(#T@)'1H:7,M/E]D969A=6QT
M3W!T:6]N<SL*("`@('T*"B`@("\J*@H@("`@*B!S970@86X@;W!T:6]N"B`@
M("`J"B`@("`J(%EO=2!C86X@=7-E('1H:7,@;65T:&]D(&EF('EO=2!D;R!N
M;W0@=V%N="!T;R!S970@86QL(&]P=&EO;G,@:6X@=&AE(&-O;G-T<G5C=&]R
M"B`@("`J"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("H@0'-E92`@("`@
M(')E<V5T3W!T:6]N*"DL(%A-3%]397)I86QI>F5R*"D*("`@("HO"B`@("!F
M=6YC=&EO;B!S971/<'1I;VXH)&YA;64L("1V86QU92D*("`@('L*("`@("`@
M("`D=&AI<RT^;W!T:6]N<ULD;F%M95T@/2`D=F%L=64["B`@("!]"B`@("`*
M("`@+RHJ"B`@("`J('-E=',@<V5V97)A;"!O<'1I;VYS(&%T(&]N8V4*("`@
M("H*("`@("H@66]U(&-A;B!U<V4@=&AI<R!M971H;V0@:68@>6]U(&1O(&YO
M="!W86YT('1O('-E="!A;&P@;W!T:6]N<R!I;B!T:&4@8V]N<W1R=6-T;W(*
M("`@("H*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B!`<V5E("`@("`@
M<F5S971/<'1I;VXH*2P@6$U,7U5N<V5R:6%L:7IE<B@I+"!S971/<'1I;VXH
M*0H@("`@*B\*("`@(&9U;F-T:6]N('-E=$]P=&EO;G,H)&]P=&EO;G,I"B`@
M("!["B`@("`@("`@)'1H:7,M/F]P=&EO;G,@/2!A<G)A>5]M97)G92@D=&AI
M<RT^;W!T:6]N<RP@)&]P=&EO;G,I.PH@("`@?0H*("`@+RHJ"B`@("`J('-E
M<FEA;&EZ92!D871A"B`@("`J"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@
M("H@0'!A<F%M("`@(&UI>&5D("`@("1D871A(&1A=&$@=&\@<V5R:6%L:7IE
M"B`@("`J($!R971U<FX@("!B;V]L96%N("!T<G5E(&]N('-U8V-E<W,L('!E
M87(@97)R;W(@;VX@9F%I;'5R90H@("`@*B\*("`@(&9U;F-T:6]N('-E<FEA
M;&EZ92@D9&%T82P@)&]P=&EO;G,@/2!N=6QL*0H@("`@>PH@("`@("`@("\O
M(&EF(&]P=&EO;G,@:&%V92!B965N('-P96-I9FEE9"P@=7-E('1H96T@:6YS
M=&5A9`H@("`@("`@("\O(&]F('1H92!P<F5V:6]U<VQY(&1E9FEN960@;VYE
M<PH@("`@("`@(&EF("AI<U]A<G)A>2@D;W!T:6]N<RDI('L*("`@("`@("`@
M("`@)&]P=&EO;G-"86L@/2`D=&AI<RT^;W!T:6]N<SL*("`@("`@("`@("`@
M:68@*&ES<V5T*"1O<'1I;VYS6R=O=F5R<FED94]P=&EO;G,G72D@)B8@)&]P
M=&EO;G-;)V]V97)R:61E3W!T:6]N<R==(#T]('1R=64I('L*("`@("`@("`@
M("`@("`@("1T:&ES+3YO<'1I;VYS(#T@87)R87E?;65R9V4H)'1H:7,M/E]D
M969A=6QT3W!T:6]N<RP@)&]P=&EO;G,I.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/F]P=&EO;G,@/2!A<G)A>5]M97)G
M92@D=&AI<RT^;W!T:6]N<RP@)&]P=&EO;G,I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&]P=&EO;G-"86L@/2!N=6QL
M.PH@("`@("`@('T*("`@("`@("`*("`@("`@("`O+R`@<W1A<G0@9&5P=&@@
M:7,@>F5R;PH@("`@("`@("1T:&ES+3Y?=&%G1&5P=&@@/2`P.PH*("`@("`@
M("`D<F]O=$%T=')I8G5T97,@/2`D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,
M25I%4E]/4%1)3TY?4D]/5%]!5%1224)373L*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7TY!34534$%#
M15TI("8F(&ES7V%R<F%Y*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D52
M7T]05$E/3E].04U%4U!!0T5=*2D@>PH@("`@("`@(`DD<F]O=$%T=')I8G5T
M97-;)WAM;&YS.B<N)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!4
M24].7TY!34534$%#15U;,%U=(#T@)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!
M3$E:15)?3U!424].7TY!34534$%#15U;,5T["B`@("`@("`@?0H@("`@("`@
M(`H@("`@("`@("1T:&ES+3Y?<V5R:6%L:7IE9$1A=&$@/2`G)SL*("`@("`@
M("`O+R!S97)I86QI>F4@86X@87)R87D*("`@("`@("!I9B`H:7-?87)R87DH
M)&1A=&$I*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^;W!T:6]N
M<UM834Q?4T5224%,25I%4E]/4%1)3TY?4D]/5%].04U%72DI('L*("`@("`@
M("`@("`@("`@("1T86=.86UE(#T@)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!
M3$E:15)?3U!424].7U)/3U1?3D%-15T["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D=&%G3F%M92`]("=A<G)A>2<["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?<V5R:6%L:7IE9$1A=&$@+CT@
M)'1H:7,M/E]S97)I86QI>F5!<G)A>2@D9&%T82P@)'1A9TYA;64L("1R;V]T
M071T<FEB=71E<RD["B`@("`@("`@?2!E;'-E:68@*&ES7V]B:F5C="@D9&%T
M82DI('L*("`@("`@("`@("`@+R\@<V5R:6%L:7IE(&%N(&]B:F5C=`H@("`@
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:
M15)?3U!424].7U)/3U1?3D%-15TI*2!["B`@("`@("`@("`@("`@("`D=&%G
M3F%M92`]("1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]2
M3T]47TY!345=.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)'1A9TYA;64@/2!G971?8VQA<W,H)&1A=&$I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1T:&ES+3Y?<V5R:6%L:7IE9$1A=&$@+CT@)'1H:7,M
M/E]S97)I86QI>F5/8FIE8W0H)&1A=&$L("1T86=.86UE+"`D<F]O=$%T=')I
M8G5T97,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T86<@/2!A
M<G)A>2@I.PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/F]P=&EO;G-;
M6$U,7U-%4DE!3$E:15)?3U!424].7U)/3U1?3D%-15TI*2!["B`@("`@("`@
M("`@("`@("`D=&%G6R=Q;F%M92==(#T@)'1H:7,M/F]P=&EO;G-;6$U,7U-%
M4DE!3$E:15)?3U!424].7U)/3U1?3D%-15T["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D=&%G6R=Q;F%M92==(#T@9V5T='EP92@D
M9&%T82D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1T:&ES+3YO
M<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]465!%2$E.5%-=(#T]/2!T
M<G5E*2!["B`@("`@("`@("`@("`@("`D<F]O=$%T=')I8G5T97-;)'1H:7,M
M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7T%45%))0E5415]465!%
M75T@/2!G971T>7!E*"1D871A*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!`<V5T='EP92@D9&%T82P@)W-T<FEN9R<I.PH@("`@("`@("`@("`D=&%G
M6R=C;VYT96YT)UT@("`@/2`D9&%T83L*("`@("`@("`@("`@)'1A9ULG871T
M<FEB=71E<R==(#T@)')O;W1!='1R:6)U=&5S.PH@("`@("`@("`@("`D=&AI
M<RT^7W-E<FEA;&EZ961$871A(#T@)'1H:7,M/E]C<F5A=&5834Q486<H)'1A
M9RD["B`@("`@("`@?0H@("`@("`@(`H@("`@("`@("\O(&%D9"!D;V-T>7!E
M(&1E8VQA<F%T:6]N"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6UA-3%]3
M15))04Q)6D527T]05$E/3E]$3T-465!%7T5.04),141=(#T]/2!T<G5E*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?<V5R:6%L:7IE9$1A=&$@/2!834Q?571I
M;#HZ9V5T1&]C='EP941E8VQA<F%T:6]N*"1T86=.86UE+"`D=&AI<RT^;W!T
M:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?1$]#5%E015TI"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`D=&AI<RT^;W!T:6]N<UM8
M34Q?4T5224%,25I%4E]/4%1)3TY?3$E.14)214%+4UT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`N("1T:&ES+3Y?<V5R:6%L:7IE9$1A
M=&$["B`@("`@("`@?0H*("`@("`@("`O+R`@8G5I;&0@>&UL(&1E8VQA<F%T
M:6]N"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D52
M7T]05$E/3E]834Q?1$5#3%]%3D%"3$5$72D@>PH@("`@("`@("`@("`D871T
M<R`](&%R<F%Y*"D["B`@("`@("`@("`@("1T:&ES+3Y?<V5R:6%L:7IE9$1A
M=&$@/2!834Q?571I;#HZ9V5T6$U,1&5C;&%R871I;VXH)S$N,"<L("1T:&ES
M+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]834Q?14Y#3T1)3D==
M*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)'1H:7,M
M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7TQ)3D5"4D5!2U-="B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`D=&AI<RT^7W-E
M<FEA;&EZ961$871A.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES+3YO
M<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]215154DY?4D5354Q472`]
M/3T@=')U92D@>PH@("`@("`@(`DD<F5S=6QT(#T@)'1H:7,M/E]S97)I86QI
M>F5D1&%T83L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5S=6QT
M(#T@=')U93L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@:68@*"1O<'1I
M;VYS0F%K("$]/2!N=6QL*2!["B`@("`@("`@("`@("1T:&ES+3YO<'1I;VYS
M(#T@)&]P=&EO;G-"86L["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@('T*"B`@("\J*@H@("`@*B!G970@=&AE(')E<W5L="!O9B!T
M:&4@<V5R:6%L:7IA=&EO;@H@("`@*@H@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@*B!`<F5T=7)N('-T<FEN9R!S97)I86QI>F5D(%A-3`H@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%-E<FEA;&EZ961$871A*"D*("`@('L*("`@("`@("!I
M9B`H)'1H:7,M/E]S97)I86QI>F5D1&%T82`]/2!N=6QL*2!["B`@("`@("`@
M("`@(')E='5R;B`@)'1H:7,M/G)A:7-E17)R;W(H)TYO('-E<FEA;&EZ960@
M9&%T82!A=F%I;&%B;&4N(%5S92!834Q?4V5R:6%L:7IE<CHZ<V5R:6%L:7IE
M*"D@9FER<W0N)RP@6$U,7U-%4DE!3$E:15)?15)23U)?3D]?4T5224%,25I!
M5$E/3BD["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^7W-E<FEA
M;&EZ961$871A.PH@("`@?0H@("`@"B`@("\J*@H@("`@*B!S97)I86QI>F4@
M86YY('9A;'5E"B`@("`J"B`@("`J(%1H:7,@;65T:&]D(&-H96-K<R!F;W(@
M=&AE('1Y<&4@;V8@=&AE('9A;'5E(&%N9"!C86QL<R!T:&4@87!P<F]P<FEA
M=&4@;65T:&]D"B`@("`J"B`@("`J($!A8V-E<W,@<')I=F%T90H@("`@*B!`
M<&%R86T@(&UI>&5D("`@("`D=F%L=64*("`@("H@0'!A<F%M("!S=')I;F<@
M("`@)'1A9TYA;64*("`@("H@0'!A<F%M("!A<G)A>2`@("`@)&%T=')I8G5T
M97,*("`@("H@0')E='5R;B!S=')I;F<*("`@("HO"B`@("!F=6YC=&EO;B!?
M<V5R:6%L:7IE5F%L=64H)'9A;'5E+"`D=&%G3F%M92`](&YU;&PL("1A='1R
M:6)U=&5S(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH
M)'9A;'5E*2D@>PH@("`@("`@("`@("`D>&UL(#T@)'1H:7,M/E]S97)I86QI
M>F5!<G)A>2@D=F%L=64L("1T86=.86UE+"`D871T<FEB=71E<RD["B`@("`@
M("`@?2!E;'-E:68@*&ES7V]B:F5C="@D=F%L=64I*2!["B`@("`@("`@("`@
M("1X;6P@/2`D=&AI<RT^7W-E<FEA;&EZ94]B:F5C="@D=F%L=64L("1T86=.
M86UE*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&%G(#T@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@)W%N86UE)R`@("`@(#T^
M("1T86=.86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("=A='1R:6)U
M=&5S)R`]/B`D871T<FEB=71E<RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`G8V]N=&5N="<@("`@/3X@)'9A;'5E"B`@("`@("`@("`@("`@("`@("`@
M("`@("D["B`@("`@("`@("`@("1X;6P@/2`D=&AI<RT^7V-R96%T95A-3%1A
M9R@D=&%G*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1X;6P["B`@("!]
M"B`@("`*("`@+RHJ"B`@("`J('-E<FEA;&EZ92!A;B!A<G)A>0H@("`@*@H@
M("`@*B!`86-C97-S("`@<')I=F%T90H@("`@*B!`<&%R86T@("`@87)R87D@
M("`D87)R87D@("`@("`@87)R87D@=&\@<V5R:6%L:7IE"B`@("`J($!P87)A
M;2`@("!S=')I;F<@("1T86=.86UE("`@("!N86UE(&]F('1H92!R;V]T('1A
M9PH@("`@*B!`<&%R86T@("`@87)R87D@("`D871T<FEB=71E<R`@871T<FEB
M=71E<R!F;W(@=&AE(')O;W0@=&%G"B`@("`J($!R971U<FX@("!S=')I;F<@
M("1S=')I;F<@("`@("!S97)I86QI>F5D(&1A=&$*("`@("H@0'5S97,@("`@
M(%A-3%]5=&EL.CII<U9A;&ED3F%M92@I('1O(&-H96-K+"!W:&5T:&5R(&ME
M>2!H87,@=&\@8F4@<W5B<W1I='5T960*("`@("HO"B`@("!F=6YC=&EO;B!?
M<V5R:6%L:7IE07)R87DH)B1A<G)A>2P@)'1A9TYA;64@/2!N=6QL+"`D871T
M<FEB=71E<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)%]C;VYT96YT(#T@
M;G5L;#L*("`@("`@("`D7V-O;6UE;G0@/2!N=6QL.PH*("`@("`@("`O+R!C
M:&5C:R!F;W(@8V]M;65N=`H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<UM8
M34Q?4T5224%,25I%4E]/4%1)3TY?0T]-345.5%]+15E=("$]/2!N=6QL*2![
M"B`@("`@("`@("`@(&EF("AI<W-E="@D87)R87E;)'1H:7,M/F]P=&EO;G-;
M6$U,7U-%4DE!3$E:15)?3U!424].7T-/34U%3E1?2T5975TI*2!["B`@("`@
M("`@("`@("`@("`D7V-O;6UE;G0@/2`D87)R87E;)'1H:7,M/F]P=&EO;G-;
M6$U,7U-%4DE!3$E:15)?3U!424].7T-/34U%3E1?2T5975T["B`@("`@("`@
M("`@("`@("!U;G-E="@D87)R87E;)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!
M3$E:15)?3U!424].7T-/34U%3E1?2T5975TI.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@(`H@("`@("`@("\J*@H@("`@("`@("`J(&-H96-K
M(&9O<B!S<&5C:6%L(&%T=')I8G5T97,*("`@("`@("`@*B\*("`@("`@("!I
M9B`H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7T%45%))
M0E5415-?2T5972`A/3T@;G5L;"D@>PH@("`@("`@("`@("!I9B`H:7-S970H
M)&%R<F%Y6R1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]!
M5%1224)55$537TM%65U=*2D@>PH@("`@("`@("`@("`@("`@)&%T=')I8G5T
M97,@/2`D87)R87E;)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!4
M24].7T%45%))0E5415-?2T5975T["B`@("`@("`@("`@("`@("!U;G-E="@D
M87)R87E;)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7T%4
M5%))0E5415-?2T5975TI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("\J
M*@H@("`@("`@("`@("`@*B!C:&5C:R!F;W(@<W!E8VEA;"!C;VYT96YT"B`@
M("`@("`@("`@("`J+PH@("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;
M6$U,7U-%4DE!3$E:15)?3U!424].7T-/3E1%3E1?2T5972`A/3T@;G5L;"D@
M>PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A<G)A>5LD=&AI<RT^;W!T
M:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?0T].5$5.5%]+15E=72DI('L*
M("`@("`@("`@("`@("`@("`@("`D7V-O;G1E;G0@/2`D87)R87E;)'1H:7,M
M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7T-/3E1%3E1?2T5975T[
M"B`@("`@("`@("`@("`@("`@("`@=6YS970H)&%R<F%Y6R1T:&ES+3YO<'1I
M;VYS6UA-3%]315))04Q)6D527T]05$E/3E]#3TY414Y47TM%65U=*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@:68@*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E])
M1TY/4D5?3E5,3%T@/3T]('1R=64I('L*("`@("`@("`)9F]R96%C:"`H87)R
M87E?:V5Y<R@D87)R87DI(&%S("1K97DI('L*("`@("`@("`)"6EF("AI<U]N
M=6QL*"1A<G)A>5LD:V5Y72DI('L*("`@("`@("`)"0EU;G-E="@D87)R87E;
M)&ME>5TI.PH@("`@("`@(`D)?0H@("`@("`@(`E]"B`@("`@("`@?0H*("`@
M("`@("`O*@H@("`@("`@("H@:68@;6]D92!I<R!S970@=&\@<VEM<&QE6$U,
M+"!C:&5C:R!W:&5T:&5R"B`@("`@("`@*B!T:&4@87)R87D@:7,@87-S;V-I
M871I=F4@;W(@:6YD97AE9`H@("`@("`@("HO"B`@("`@("`@:68@*&ES7V%R
M<F%Y*"1A<G)A>2D@)B8@(65M<'1Y*"1A<G)A>2D@)B8@)'1H:7,M/F]P=&EO
M;G-;6$U,7U-%4DE!3$E:15)?3U!424].7TU/1$5=(#T](%A-3%]315))04Q)
M6D527TU/1$5?4TE-4$Q%6$U,*2!["B`@("`@("`@("`@("1I;F1E>&5D(#T@
M=')U93L*("`@("`@("`@("`@9F]R96%C:"`H)&%R<F%Y(&%S("1K97D@/3X@
M)'9A;"D@>PH@("`@("`@("`@("`@("`@:68@*"%I<U]I;G0H)&ME>2DI('L*
M("`@("`@("`@("`@("`@("`@("`D:6YD97AE9"`](&9A;'-E.PH@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"@H@("`@("`@("`@("!I9B`H)&EN9&5X960@)B8@)'1H:7,M/F]P
M=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7TU/1$5=(#T](%A-3%]315))
M04Q)6D527TU/1$5?4TE-4$Q%6$U,*2!["B`@("`@("`@("`@("`@("`D<W1R
M:6YG(#T@)R<["B`@("`@("`@("`@("`@("!F;W)E86-H("@D87)R87D@87,@
M)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@("`@("`@("`@)'-T<FEN9R`N
M/2`D=&AI<RT^7W-E<FEA;&EZ959A;'5E*"`D=F%L+"`D=&%G3F%M92P@)&%T
M=')I8G5T97,I.PH@("`@("`@("`@("`@("`@("`@(`H@("`@("`@("`@("`@
M("`@("`@("1S=')I;F<@+CT@)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:
M15)?3U!424].7TQ)3D5"4D5!2U-=.PH@("`@("`@("`@("`@("`@("`@("\O
M(&1O(&EN9&5N=&%T:6]N"B`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES
M+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E])3D1%3E1=(3T];G5L
M;"`F)B`D=&AI<RT^7W1A9T1E<'1H/C`I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)'-T<FEN9R`N/2!S=')?<F5P96%T*"1T:&ES+3YO<'1I;VYS6UA-
M3%]315))04Q)6D527T]05$E/3E])3D1%3E1=+"`D=&AI<RT^7W1A9T1E<'1H
M*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!R971U<FX@<G1R:6TH)'-T<FEN9RD["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@)'-C86QA<D%S071T
M<FEB=71E<R`](&9A;'-E.PH@("`@("`@(&EF("AI<U]A<G)A>2@D=&AI<RT^
M;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?4T-!3$%27T%37T%45%))
M0E5415-=*2`F)B!I<W-E="@D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%
M4E]/4%1)3TY?4T-!3$%27T%37T%45%))0E5415-=6R1T86=.86UE72DI('L*
M("`@("`@("`@("`@)'-C86QA<D%S071T<FEB=71E<R`]("1T:&ES+3YO<'1I
M;VYS6UA-3%]315))04Q)6D527T]05$E/3E]30T%,05)?05-?05144DE"551%
M4UU;)'1A9TYA;65=.PH@("`@("`@('T@96QS96EF("@D=&AI<RT^;W!T:6]N
M<UM834Q?4T5224%,25I%4E]/4%1)3TY?4T-!3$%27T%37T%45%))0E5415-=
M(#T]/2!T<G5E*2!["B`@("`@("`@("`@("1S8V%L87)!<T%T=')I8G5T97,@
M/2!T<G5E.PH@("`@("`@('T*("`@("`@("`*("`@("`@("!I9B`H)'-C86QA
M<D%S071T<FEB=71E<R`]/3T@=')U92D@>PH@("`@("`@("`@("`D=&AI<RT^
M97AP96-T17)R;W(H)RHG*3L*("`@("`@("`@("`@9F]R96%C:"`H)&%R<F%Y
M(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?
M<V-A;&%R*"1V86QU92D@)B8@*%A-3%]5=&EL.CII<U9A;&ED3F%M92@D:V5Y
M*2`]/3T@=')U92DI('L*("`@("`@("`@("`@("`@("`@("!U;G-E="@D87)R
M87E;)&ME>5TI.PH@("`@("`@("`@("`@("`@("`@("1A='1R:6)U=&5S6R1T
M:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]04D5014Y$7T%4
M5%))0E5415-=+B1K97E=(#T@)'9A;'5E.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3YP;W!%>'!E8W0H*3L*
M("`@("`@("!](&5L<V5I9B`H:7-?87)R87DH)'-C86QA<D%S071T<FEB=71E
M<RDI('L*("`@("`@("`@("`@)'1H:7,M/F5X<&5C=$5R<F]R*"<J)RD["B`@
M("`@("`@("`@(&9O<F5A8V@@*"1S8V%L87)!<T%T=')I8G5T97,@87,@)&ME
M>2D@>PH@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D87)R87E;)&ME>5TI
M*2!["B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`D=F%L=64@/2`D87)R87E;)&ME>5T[
M"B`@("`@("`@("`@("`@("!I9B`H:7-?<V-A;&%R*"1V86QU92D@)B8@*%A-
M3%]5=&EL.CII<U9A;&ED3F%M92@D:V5Y*2`]/3T@=')U92DI('L*("`@("`@
M("`@("`@("`@("`@("!U;G-E="@D87)R87E;)&ME>5TI.PH@("`@("`@("`@
M("`@("`@("`@("1A='1R:6)U=&5S6R1T:&ES+3YO<'1I;VYS6UA-3%]315))
M04Q)6D527T]05$E/3E]04D5014Y$7T%45%))0E5415-=+B1K97E=(#T@)'9A
M;'5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1T:&ES+3YP;W!%>'!E8W0H*3L*("`@("`@("!]"@H@("`@("`@("\O
M(&-H96-K(&9O<B!E;7!T>2!A<G)A>2`]/B!C<F5A=&4@96UP='D@=&%G"B`@
M("`@("`@:68@*&5M<'1Y*"1A<G)A>2DI('L*("`@("`@("`@("`@)'1A9R`]
M(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W%N86UE)R`@
M("`@(#T^("1T86=.86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V-O;G1E;G0G("`@(#T^("1?8V]N=&5N="P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=A='1R:6)U=&5S)R`]/B`D871T<FEB=71E<PH@("`@("`@
M("`@("`@("`@("`@("`@("`I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1T:&ES+3Y?=&%G1&5P=&@K*SL*("`@("`@("`@("`@)'1M<"`]("1T
M:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E],24Y%0E)%04M3
M73L*("`@("`@("`@("`@9F]R96%C:"`H)&%R<F%Y(&%S("1K97D@/3X@)'9A
M;'5E*2!["B`@("`@("`@("`@("`@("`O+R!D;R!I;F1E;G1A=&EO;@H@("`@
M("`@("`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D52
M7T]05$E/3E])3D1%3E1=(3T];G5L;"`F)B`D=&AI<RT^7W1A9T1E<'1H/C`I
M('L*("`@("`@("`@("`@("`@("`@("`D=&UP("X]('-T<E]R97!E870H)'1H
M:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7TE.1$5.5%TL("1T
M:&ES+3Y?=&%G1&5P=&@I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%
M4E]/4%1)3TY?5$%'34%075LD:V5Y72DI('L*("`@("`@("`@("`@("`@("`@
M("`D:V5Y(#T@)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].
M7U1!1TU!4%U;)&ME>5T["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`@("`@+R\@8V]P>2!K97D*("`@("`@("`@("`@("`@("1O<FEG2V5Y(#T@
M)&ME>3L*("`@("`@("`@("`@("`@("1T:&ES+3YE>'!E8W1%<G)O<B@G*B<I
M.PH@("`@("`@("`@("`@("`@+R\@:V5Y(&-A;FYO="!B92!U<V5D(&%S('1A
M9VYA;64@/3X@=7-E(&1E9F%U;'0@=&%G"B`@("`@("`@("`@("`@("`D=F%L
M:60@/2!834Q?571I;#HZ:7-686QI9$YA;64H)&ME>2D["B`@("`@("`@("`@
M("`@("`D=&AI<RT^<&]P17AP96-T*"D["B`@("`@("`@("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D=F%L:60I*2!["B`@("`@("`@("`@("`@("`@("`@
M:68@*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]#3$%3
M4TY!345?05-?5$%'3D%-15T@)B8@:7-?;V)J96-T*"1V86QU92DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&ME>2`](&=E=%]C;&%S<R@D=F%L=64I
M.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1K97D@/2`D=&AI<RT^7V=E=$1E9F%U;'1486=N86UE*"1T
M86=.86UE*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`D871T<R`](&%R<F%Y*"D["B`@("`@("`@
M("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!4
M24].7U194$5(24Y44UT@/3T]('1R=64I('L*("`@("`@("`@("`@("`@("`@
M("`D871T<ULD=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?
M05144DE"551%7U194$5=72`](&=E='1Y<&4H)'9A;'5E*3L*("`@("`@("`@
M("`@("`@("`@("!I9B`H)&ME>2`A/3T@)&]R:6=+97DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&%T='-;)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!
M3$E:15)?3U!424].7T%45%))0E5415]+15E=72`]("AS=')I;F<I)&]R:6=+
M97D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@("1T;7`@+CT@)'1H:7,M/E]C<F5A=&5834Q486<H
M87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G<6YA;64G("`@("`@/3X@)&ME>2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A
M='1R:6)U=&5S)R`]/B`D871T<RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=C;VYT96YT)R`@("`]/B`D
M=F%L=64@*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("D["B`@("`@("`@("`@("`@("`D=&UP("X]("1T:&ES+3YO<'1I
M;VYS6UA-3%]315))04Q)6D527T]05$E/3E],24Y%0E)%04M373L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`*("`@("`@("`@("`@)'1H:7,M/E]T86=$
M97!T:"TM.PH@("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;6$U,7U-%
M4DE!3$E:15)?3U!424].7TE.1$5.5%TA/3UN=6QL("8F("1T:&ES+3Y?=&%G
M1&5P=&@^,"D@>PH@("`@("`@("`@("`@("`@)'1M<"`N/2!S=')?<F5P96%T
M*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E])3D1%3E1=
M+"`D=&AI<RT^7W1A9T1E<'1H*3L*("`@("`@("`@("`@?0H@("`@"B`@("`@
M("`@("`@(&EF("AT<FEM*"1T;7`I(#T]/2`G)RD@>PH@("`@("`@("`@("`@
M("`@)'1M<"`](&YU;&P["B`@("`@("`@("`@('T*("`@("`@("`@("`@"B`@
M("`@("`@("`@("1T86<@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@
M("`@("`G<6YA;64G("`@("`@/3X@)'1A9TYA;64L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V-O;G1E;G0G("`@(#T^("1T;7`L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V%T=')I8G5T97,G(#T^("1A='1R:6)U=&5S"B`@
M("`@("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@?0H@("`@("`@(&EF
M("@D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?5%E014A)
M3E1372`]/3T@=')U92D@>PH@("`@("`@("`@("!I9B`H(6ES<V5T*"1T86=;
M)V%T=')I8G5T97,G75LD=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/
M4%1)3TY?05144DE"551%7U194$5=72DI('L*("`@("`@("`@("`@("`@("1T
M86=;)V%T=')I8G5T97,G75LD=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%
M4E]/4%1)3TY?05144DE"551%7U194$5=72`]("=A<G)A>2<["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("1S=')I;F<@/2`G)SL*("`@("`@
M("!I9B`H(6ES7VYU;&PH)%]C;VUM96YT*2D@>PH@("`@("`@(`DD<W1R:6YG
M("X](%A-3%]5=&EL.CIC<F5A=&5#;VUM96YT*"1?8V]M;65N="D["B`@("`@
M("`@"21S=')I;F<@+CT@)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?
M3U!424].7TQ)3D5"4D5!2U-=.PH@("`@("`@("`@("!I9B`H)'1H:7,M/F]P
M=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7TE.1$5.5%TA/3UN=6QL("8F
M("1T:&ES+3Y?=&%G1&5P=&@^,"D@>PH@("`@("`@("`@("`@("`@)'-T<FEN
M9R`N/2!S=')?<F5P96%T*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D52
M7T]05$E/3E])3D1%3E1=+"`D=&AI<RT^7W1A9T1E<'1H*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@("`@("`D<W1R:6YG("X]("1T:&ES+3Y?8W)E
M871E6$U,5&%G*"1T86<L(&9A;'-E*3L*("`@("`@("!R971U<FX@)'-T<FEN
M9SL*("`@('T*"B`@("\J*@H@("`@*B!G970@=&AE(&YA;64@;V8@=&AE(&1E
M9F%U;'0@=&%G+@H@("`@*@H@("`@*B!4:&4@;F%M92!O9B!T:&4@<&%R96YT
M('1A9R!N965D<R!T;R!B92!P87-S960@87,@=&AE"B`@("`J(&1E9F%U;'0@
M;F%M92!C86X@9&5P96YD(&]N('1H92!C;VYT97AT+@H@("`@*@H@("`@*B!`
M<&%R86T@('-T<FEN9R`@("`@;F%M92!O9B!T:&4@<&%R96YT('1A9PH@("`@
M*B!`<F5T=7)N('-T<FEN9R`@("`@9&5F875L="!T86<@;F%M90H@("`@*B\*
M("`@(&9U;F-T:6]N(%]G971$969A=6QT5&%G;F%M92@D<&%R96YT*0H@("`@
M>PH@("`@("`@(&EF("AI<U]S=')I;F<H)'1H:7,M/F]P=&EO;G-;6$U,7U-%
M4DE!3$E:15)?3U!424].7T1%1D%53%1?5$%'72DI('L*("`@("`@("`)<F5T
M=7)N("1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]$149!
M54Q47U1!1UT["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?1$5&055,5%]404==6R1P
M87)E;G1=*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F]P=&EO;G-;
M6$U,7U-%4DE!3$E:15)?3U!424].7T1%1D%53%1?5$%'75LD<&%R96YT73L*
M("`@("`@("!](&5L<V5I9B`H:7-S970H)'1H:7,M/F]P=&EO;G-;6$U,7U-%
M4DE!3$E:15)?3U!424].7T1%1D%53%1?5$%'75LG(V1E9F%U;'0G72DI('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)
M6D527T]05$E/3E]$149!54Q47U1!1UU;)R-D969A=6QT)UT["B`@("`@("`@
M?2!E;'-E:68@*&ES<V5T*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D52
M7T]05$E/3E]$149!54Q47U1!1UU;)U]?9&5F875L="==*2D@>PH@("`@("`@
M("`@("`O+R!K965P('1H:7,@9F]R($)#"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?1$5&055,5%]4
M04==6R=?7V1E9F%U;'0G73L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("=8
M34Q?4V5R:6%L:7IE<E]486<G.PH@("`@?0H@("`@"B`@("\J*@H@("`@*B!S
M97)I86QI>F4@86X@;V)J96-T"B`@("`J"B`@("`J($!A8V-E<W,@("!P<FEV
M871E"B`@("`J($!P87)A;2`@("!O8FIE8W0@("1O8FIE8W0@;V)J96-T('1O
M('-E<FEA;&EZ90H@("`@*B!`<F5T=7)N("`@<W1R:6YG("`D<W1R:6YG('-E
M<FEA;&EZ960@9&%T80H@("`@*B\*("`@(&9U;F-T:6]N(%]S97)I86QI>F5/
M8FIE8W0H)B1O8FIE8W0L("1T86=.86UE(#T@;G5L;"P@)&%T=')I8G5T97,@
M/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("\O(&-H96-K(&9O<B!M86=I8R!F
M=6YC=&EO;@H@("`@("`@(&EF("AM971H;V1?97AI<W1S*"1O8FIE8W0L("=?
M7W-L965P)RDI('L*("`@("`@("`@("`@)'!R;W!.86UE<R`]("1O8FIE8W0M
M/E]?<VQE97`H*3L*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1P<F]P3F%M
M97,I*2!["B`@("`@("`@("`@(`DD<')O<&5R=&EE<R`](&%R<F%Y*"D["B`@
M("`@("`@("`@(`EF;W)E86-H("@D<')O<$YA;65S(&%S("1P<F]P3F%M92D@
M>PH@("`@("`@("`@("`)"21P<F]P97)T:65S6R1P<F]P3F%M95T@/2`D;V)J
M96-T+3XD<')O<$YA;64["B`@("`@("`@("`@(`E]"B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D<')O<&5R=&EE<R`](&=E=%]O8FIE
M8W1?=F%R<R@D;V)J96-T*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1P<F]P97)T:65S(#T@9V5T7V]B:F5C=%]V87)S
M*"1O8FIE8W0I.PH@("`@("`@('T*"B`@("`@("`@:68@*&5M<'1Y*"1T86=.
M86UE*2D@>PH@("`@("`@("`@("`D=&%G3F%M92`](&=E=%]C;&%S<R@D;V)J
M96-T*3L*("`@("`@("!]"@H@("`@("`@("\O('1Y<&5H:6YT<R!A8W1I=F%T
M960_"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D52
M7T]05$E/3E]465!%2$E.5%-=(#T]/2!T<G5E*2!["B`@("`@("`@("`@("1A
M='1R:6)U=&5S6R1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/
M3E]!5%1224)55$5?5%E015U=("`]("=O8FIE8W0G.PH@("`@("`@("`@("`D
M871T<FEB=71E<ULD=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)
M3TY?05144DE"551%7T-,05-375T@/2`@9V5T7V-L87-S*"1O8FIE8W0I.PH@
M("`@("`@('T*("`@("`@("`D<W1R:6YG(#T@)'1H:7,M/E]S97)I86QI>F5!
M<G)A>2@D<')O<&5R=&EE<RP@)'1A9TYA;64L("1A='1R:6)U=&5S*3L*("`@
M("`@("!R971U<FX@)'-T<FEN9SL*("`@('T*("`*("`@+RHJ"B`@("`J(&-R
M96%T92!A('1A9R!F<F]M(&%N(&%R<F%Y"B`@("`J('1H:7,@;65T:&]D(&%W
M86ET<R!A;B!A<G)A>2!I;B!T:&4@9F]L;&]W:6YG(&9O<FUA=`H@("`@*B!A
M<G)A>2@*("`@("H@("`@("`@)W%N86UE)R`@("`@("`@/3X@)'1A9TYA;64L
M"B`@("`J("`@("`@("=A='1R:6)U=&5S)R`@(#T^(&%R<F%Y*"DL"B`@("`J
M("`@("`@("=C;VYT96YT)R`@("`@(#T^("1C;VYT96YT+"`@("`@("\O(&]P
M=&EO;F%L"B`@("`J("`@("`@("=N86UE<W!A8V4G("`@(#T^("1N86UE<W!A
M8V4@("`@("\O(&]P=&EO;F%L"B`@("`J("`@("`@("=N86UE<W!A8V55<FDG
M(#T^("1N86UE<W!A8V55<FD@("\O(&]P=&EO;F%L"B`@("`J("`@*0H@("`@
M*@H@("`@*B!`86-C97-S("`@<')I=F%T90H@("`@*B!`<&%R86T@("`@87)R
M87D@("`D=&%G('1A9R!D969I;FET:6]N"B`@("`J($!P87)A;2`@("!B;V]L
M96%N("1R97!L86-E16YT:71I97,@=VAE=&AE<B!T;R!R97!L86-E(%A-3"!E
M;G1I=&EE<R!I;B!C;VYT96YT(&]R(&YO=`H@("`@*B!`<F5T=7)N("`@<W1R
M:6YG("`D<W1R:6YG(%A-3"!T86<*("`@("HO"B`@("!F=6YC=&EO;B!?8W)E
M871E6$U,5&%G*"1T86<L("1F:7)S=$-A;&P@/2!T<G5E*0H@("`@>PH@("`@
M("`@("\O(&)U:6QD(&9U;&QY('%U86QI9FEE9"!T86<@;F%M90H@("`@("`@
M(&EF("@D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?3D%-
M15-004-%72`A/3T@;G5L;"D@>PH@("`@("`@(`EI9B`H:7-?87)R87DH)'1H
M:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7TY!34534$%#15TI
M*2!["B`@("`@("`@"0DD=&%G6R=Q;F%M92==(#T@)'1H:7,M/F]P=&EO;G-;
M6$U,7U-%4DE!3$E:15)?3U!424].7TY!34534$%#15U;,%T@+B`G.B<@+B`D
M=&%G6R=Q;F%M92==.PH@("`@("`@(`E](&5L<V4@>PH@("`@("`@(`D))'1A
M9ULG<6YA;64G72`]("1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]0
M5$E/3E].04U%4U!!0T5=("X@)SHG("X@)'1A9ULG<6YA;64G73L*("`@("`@
M("`)?0H@("`@("`@('T*"B`@("`@("`@+R\@871T<FEB=71E(&EN9&5N=&%T
M:6]N"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D52
M7T]05$E/3E])3D1%3E1?05144DE"551%4UT@(3T](&9A;'-E*2!["B`@("`@
M("`@("`@("1M=6QT:6QI;F4@/2!T<G5E.PH@("`@("`@("`@("`D:6YD96YT
M("`@(#T@<W1R7W)E<&5A="@D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%
M4E]/4%1)3TY?24Y$14Y472P@)'1H:7,M/E]T86=$97!T:"D["@H@("`@("`@
M("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].
M7TE.1$5.5%]!5%1224)55$5372`]/2`G7V%U=&\G*2!["B`@("`@("`@("`@
M("`@("`D:6YD96YT("X]('-T<E]R97!E870H)R`G+"`H<W1R;&5N*"1T86=;
M)W%N86UE)UTI*S(I*3L*"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D:6YD96YT("X]("1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)
M6D527T]05$E/3E])3D1%3E1?05144DE"551%4UT["B`@("`@("`@("`@('T*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;75L=&EL:6YE(#T@9F%L
M<V4["B`@("`@("`@("`@("1I;F1E;G0@("`@/2!F86QS93L*("`@("`@("!]
M"@H@("`@("`@(&EF("AI<U]A<G)A>2@D=&%G6R=C;VYT96YT)UTI*2!["B`@
M("`@("`@("`@(&EF("AE;7!T>2@D=&%G6R=C;VYT96YT)UTI*2!["B`@("`@
M("`@("`@("`@("`D=&%G6R=C;VYT96YT)UT@/2`@("<G.PH@("`@("`@("`@
M("!]"B`@("`@("`@?2!E;'-E:68H:7-?<V-A;&%R*"1T86=;)V-O;G1E;G0G
M72D@)B8@*'-T<FEN9RDD=&%G6R=C;VYT96YT)UT@/3T@)R<I('L*("`@("`@
M("`@("`@)'1A9ULG8V]N=&5N="==(#T@("`G)SL*("`@("`@("!]"@H@("`@
M("`@("\O(')E<&QA8V4@6$U,(&5N=&ET:65S("AO;FQY(&YE961E9"P@:68@
M=&AI<R!I<R!N;W0@82!N97-T960@8V%L;"D*("`@("`@("!I9B`H)&9I<G-T
M0V%L;"`]/3T@=')U92D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO
M;G-;6$U,7U-%4DE!3$E:15)?3U!424].7T-$051!7U-%0U1)3TY372`]/3T@
M=')U92D@>PH@("`@("`@("`@("`@("`@)')E<&QA8V5%;G1I=&EE<R`](%A-
M3%]55$E,7T-$051!7U-%0U1)3TX["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@"2`@("`D<F5P;&%C945N=&ET:65S(#T@)'1H:7,M/F]P=&EO
M;G-;6$U,7U-%4DE!3$E:15)?3U!424].7T5.5$E4245373L*("`@("`@("`@
M("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R97!L86-E16YT
M:71I97,@/2!834Q?4T5224%,25I%4E]%3E1)5$E%4U].3TY%.PH@("`@("`@
M('T*("`@("`@("!I9B`H:7-?<V-A;&%R*"1T86=;)V-O;G1E;G0G72D@?'P@
M:7-?;G5L;"@D=&%G6R=C;VYT96YT)UTI*2!["B`@("`@("`@("`@(&EF("@D
M=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?14Y#3T1%7T95
M3D-=*2!["B`@("`@("`@("`@("`@("!I9B`H)&9I<G-T0V%L;"`]/3T@=')U
M92D@>PH@("`@("`@("`@("`@("`@"21T86=;)V-O;G1E;G0G72`](&-A;&Q?
M=7-E<E]F=6YC*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/
M3E]%3D-/1$5?1E5.0UTL("1T86=;)V-O;G1E;G0G72D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@(`DD=&%G6R=A='1R:6)U=&5S)UT@/2!A<G)A
M>5]M87`H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7T5.
M0T]$15]&54Y#72P@)'1A9ULG871T<FEB=71E<R==*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D=&%G(#T@6$U,7U5T:6PZ.F-R96%T951A9T9R;VU!
M<G)A>2@D=&%G+"`D<F5P;&%C945N=&ET:65S+"`D;75L=&EL:6YE+"`D:6YD
M96YT+"`D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?3$E.
M14)214%+4UTI.PH@("`@("`@('T@96QS96EF("AI<U]A<G)A>2@D=&%G6R=C
M;VYT96YT)UTI*2!["B`@("`@("`@("`@("1T86<@("`@/2`@("1T:&ES+3Y?
M<V5R:6%L:7IE07)R87DH)'1A9ULG8V]N=&5N="==+"`D=&%G6R=Q;F%M92==
M+"`D=&%G6R=A='1R:6)U=&5S)UTI.PH@("`@("`@('T@96QS96EF("AI<U]O
M8FIE8W0H)'1A9ULG8V]N=&5N="==*2D@>PH@("`@("`@("`@("`D=&%G("`@
M(#T@("`D=&AI<RT^7W-E<FEA;&EZ94]B:F5C="@D=&%G6R=C;VYT96YT)UTL
M("1T86=;)W%N86UE)UTL("1T86=;)V%T=')I8G5T97,G72D["B`@("`@("`@
M?2!E;'-E:68@*&ES7W)E<V]U<F-E*"1T86=;)V-O;G1E;G0G72DI('L*("`@
M("`@("`@("`@<V5T='EP92@D=&%G6R=C;VYT96YT)UTL("=S=')I;F<G*3L*
M("`@("`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D52
M7T]05$E/3E]%3D-/1$5?1E5.0UTI('L*("`@("`@("`@("`@"6EF("@D<F5P
M;&%C945N=&ET:65S(#T]/2!T<G5E*2!["B`@("`@("`@("`@("`@("`@("`@
M)'1A9ULG8V]N=&5N="==(#T@8V%L;%]U<V5R7V9U;F,H)'1H:7,M/F]P=&EO
M;G-;6$U,7U-%4DE!3$E:15)?3U!424].7T5.0T]$15]&54Y#72P@)'1A9ULG
M8V]N=&5N="==*3L*("`@("`@("`@("`@"7T*("`@("`@("`@("`@"21T86=;
M)V%T=')I8G5T97,G72`](&%R<F%Y7VUA<"@D=&AI<RT^;W!T:6]N<UM834Q?
M4T5224%,25I%4E]/4%1)3TY?14Y#3T1%7T953D-=+"`D=&%G6R=A='1R:6)U
M=&5S)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T86<@/2!834Q?
M571I;#HZ8W)E871E5&%G1G)O;4%R<F%Y*"1T86<L("1R97!L86-E16YT:71I
M97,I.PH@("`@("`@('T*("`@("`@("!R971U<FX@("1T86<["B`@("!]"GT*
M/SX`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+UA-3"]24$,N<&AP````````````````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`Q-C`S,S(@,3`U,34T,S,W,S$@,#(P,C8V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"@HO
M*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S
M;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J(%!(4"!I;7!L96UE;G1A=&EO;B!O
M9B!T:&4@6$U,+5)00R!P<F]T;V-O;`H@*@H@*B!4:&ES(&ES(&$@4$5!4BUI
M9FEE9"!V97)S:6]N(&]F(%5S969U;"!I;F,G<R!834PM4E!#(&9O<B!02%`N
M"B`J($ET(&AA<R!S=7!P;W)T(&9O<B!(5%10('1R86YS<&]R="P@<')O>&EE
M<R!A;F0@875T:&5N=&EC871I;VXN"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N
M9"`U"B`J"B`J($Q)0T5.4T4Z($QI8V5N<V4@:7,@9W)A;G1E9"!T;R!U<V4@
M;W(@;6]D:69Y('1H:7,@<V]F='=A<F4*("H@*")834PM4E!#(&9O<B!02%`B
M*2!F;W(@8V]M;65R8VEA;"!O<B!N;VXM8V]M;65R8VEA;"!U<V4@<')O=FED
M960@=&AE"B`J(&-O<'ER:6=H="!O9B!T:&4@875T:&]R(&ES('!R97-E<G9E
M9"!I;B!A;GD@9&ES=')I8G5T960@;W(@9&5R:79A=&EV92!W;W)K+@H@*@H@
M*B!42$E3(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!!551(3U(@(D%3
M($E3(B!!3D0@04Y9($584%)%4U-%1"!/4@H@*B!)35!,245$(%=!4E)!3E1)
M15,L($E.0TQ51$E.1RP@0E54($Y/5"!,24U)5$5$(%1/+"!42$4@24U03$E%
M1"!705)204Y42453"B`J($]&($U%4D-(04Y404))3$E462!!3D0@1DE43D53
M4R!&3U(@02!005)424-53$%2(%!54E!/4T4@05)%($1)4T-,04E-140N"B`J
M($E.($Y/($5614Y4(%-(04Q,(%1(12!!551(3U(@0D4@3$E!0DQ%($9/4B!!
M3ED@1$E214-4+"!)3D1)4D5#5"P*("H@24Y#241%3E1!3"P@4U!%0TE!3"P@
M15A%35!,05)9+"!/4B!#3TY315%514Y424%,($1!34%'15,@*$E.0TQ51$E.
M1RP@0E54"B`J($Y/5"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1B!354)3
M5$E4551%($=/3T13($]2(%-%4E9)0T53.R!,3U-3($]&(%5312P*("H@1$%4
M02P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,@24Y415)255!424].*2!(3U=%
M5D52($-!55-%1"!!3D0@3TX@04Y9"B`J(%1(14]262!/1B!,24%"24Q)5%DL
M(%=(151(15(@24X@0T].5%)!0U0L(%-44DE#5"!,24%"24Q)5%DL($]2(%1/
M4E0*("H@*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]42$525TE312D@05))
M4TE.1R!)3B!!3ED@5T%9($]55"!/1B!42$4@55-%($]&"B`J(%1(25,@4T]&
M5%=!4D4L($5614X@248@041625-%1"!/1B!42$4@4$]34TE"24Q)5%D@3T8@
M4U5#2"!$04U!1T4N"B`J"B`J($!C871E9V]R>2`@(%=E8B!397)V:6-E<PH@
M*B!`<&%C:V%G92`@("!834Q?4E!#"B`J($!A=71H;W(@("`@($5D9"!$=6UB
M:6QL(#QE9&1`=7-E9G5L:6YC+F-O;3X*("H@0&%U=&AO<B`@("`@4W1I9R!"
M86MK96X@/'-T:6=`<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@36%R=&EN($IA
M;G-E;B`\;6I`<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I
M<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DY+3(P
M,#$@161D($1U;6)I;&PL(#(P,#$M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!V
M97)S:6]N("`@($-64SH@)$ED.B!24$,N<&AP+'8@,2XY-2`R,#`V+S`T+S$V
M(#$U.C`T.C4S(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]P86-K86=E+UA-3%]24$,*("HO"@H*:68@*"%F=6YC
M=&EO;E]E>&ES=',H)WAM;%]P87)S97)?8W)E871E)RDI('L*("`@(&EN8VQU
M9&5?;VYC92`G4$5!4BYP:'`G.PH@("`@4$5!4CHZ;&]A9$5X=&5N<VEO;B@G
M>&UL)RD["GT*"B\J*B-`*PH@*B!%<G)O<B!C;VYS=&%N=',*("HO"B\J*@H@
M*B!087)A;65T97(@=F%L=65S(&1O;B=T(&UA=&-H('!A<F%M971E<B!T>7!E
M<PH@*B\*9&5F:6YE*"=834Q?4E!#7T524D]27TE.5D%,241?5%E012<L(#$P
M,2D["B\J*@H@*B!087)A;65T97(@9&5C;&%R960@=&\@8F4@;G5M97)I8R!B
M=70@=&AE('9A;'5E<R!A<F4@;F]T"B`J+PID969I;F4H)UA-3%]24$-?15)2
M3U)?3D].7TY5345224-?1D]53D0G+"`Q,#(I.PHO*BH*("H@0V]M;75N:6-A
M=&EO;B!E<G)O<@H@*B\*9&5F:6YE*"=834Q?4E!#7T524D]27T-/3DY%0U1)
M3TY?1D%)3$5$)RP@,3`S*3L*+RHJ"B`J(%1H92!A<G)A>2!O<B!S=')U8W0@
M:&%S(&%L<F5A9'D@8F5E;B!S=&%R=&5D"B`J+PID969I;F4H)UA-3%]24$-?
M15)23U)?04Q214%$65])3DE424%,25I%1"<L(#$P-"D["B\J*@H@*B!);F-O
M<G)E8W0@<&%R86UE=&5R<R!S=6)M:71T960*("HO"F1E9FEN92@G6$U,7U)0
M0U]%4E)/4E])3D-/4E)%0U1?4$%204U3)RP@,3`U*3L*+RHJ"B`J(%!R;V=R
M86UM:6YG(&5R<F]R(&)Y(&1E=F5L;W!E<@H@*B\*9&5F:6YE*"=834Q?4E!#
M7T524D]27U!23T=204U-24Y')RP@,3`V*3L*+RHJ(T`M*B\*"@HO*BH*("H@
M1&%T82!T>7!E<PH@*B!`9VQO8F%L('-T<FEN9R`D1TQ/0D%,4ULG6$U,7U)0
M0U])-"=="B`J+PHD1TQ/0D%,4ULG6$U,7U)00U])-"==(#T@)VDT)SL*"B\J
M*@H@*B!$871A('1Y<&5S"B`J($!G;&]B86P@<W1R:6YG("1'3$]"04Q36R=8
M34Q?4E!#7TEN="=="B`J+PHD1TQ/0D%,4ULG6$U,7U)00U]);G0G72`]("=I
M;G0G.PH*+RHJ"B`J($1A=&$@='EP97,*("H@0&=L;V)A;"!S=')I;F<@)$=,
M3T)!3%-;)UA-3%]24$-?0F]O;&5A;B=="B`J+PHD1TQ/0D%,4ULG6$U,7U)0
M0U]";V]L96%N)UT@/2`G8F]O;&5A;B<["@HO*BH*("H@1&%T82!T>7!E<PH@
M*B!`9VQO8F%L('-T<FEN9R`D1TQ/0D%,4ULG6$U,7U)00U]$;W5B;&4G70H@
M*B\*)$=,3T)!3%-;)UA-3%]24$-?1&]U8FQE)UT@/2`G9&]U8FQE)SL*"B\J
M*@H@*B!$871A('1Y<&5S"B`J($!G;&]B86P@<W1R:6YG("1'3$]"04Q36R=8
M34Q?4E!#7U-T<FEN9R=="B`J+PHD1TQ/0D%,4ULG6$U,7U)00U]3=')I;F<G
M72`]("=S=')I;F<G.PH*+RHJ"B`J($1A=&$@='EP97,*("H@0&=L;V)A;"!S
M=')I;F<@)$=,3T)!3%-;)UA-3%]24$-?1&%T951I;64G70H@*B\*)$=,3T)!
M3%-;)UA-3%]24$-?1&%T951I;64G72`]("=D871E5&EM92YI<V\X-C`Q)SL*
M"B\J*@H@*B!$871A('1Y<&5S"B`J($!G;&]B86P@<W1R:6YG("1'3$]"04Q3
M6R=834Q?4E!#7T)A<V4V-"=="B`J+PHD1TQ/0D%,4ULG6$U,7U)00U]"87-E
M-C0G72`]("=B87-E-C0G.PH*+RHJ"B`J($1A=&$@='EP97,*("H@0&=L;V)A
M;"!S=')I;F<@)$=,3T)!3%-;)UA-3%]24$-?07)R87DG70H@*B\*)$=,3T)!
M3%-;)UA-3%]24$-?07)R87DG72`]("=A<G)A>2<["@HO*BH*("H@1&%T82!T
M>7!E<PH@*B!`9VQO8F%L('-T<FEN9R`D1TQ/0D%,4ULG6$U,7U)00U]3=')U
M8W0G70H@*B\*)$=,3T)!3%-;)UA-3%]24$-?4W1R=6-T)UT@/2`G<W1R=6-T
M)SL*"@HO*BH*("H@1&%T82!T>7!E(&UE=&$M='EP97,*("H@0&=L;V)A;"!A
M<G)A>2`D1TQ/0D%,4ULG6$U,7U)00U]4>7!E<R=="B`J+PHD1TQ/0D%,4ULG
M6$U,7U)00U]4>7!E<R==(#T@87)R87DH"B`@("`D1TQ/0D%,4ULG6$U,7U)0
M0U])-"==("`@("`@(#T^(#$L"B`@("`D1TQ/0D%,4ULG6$U,7U)00U]);G0G
M72`@("`@(#T^(#$L"B`@("`D1TQ/0D%,4ULG6$U,7U)00U]";V]L96%N)UT@
M(#T^(#$L"B`@("`D1TQ/0D%,4ULG6$U,7U)00U]3=')I;F<G72`@(#T^(#$L
M"B`@("`D1TQ/0D%,4ULG6$U,7U)00U]$;W5B;&4G72`@(#T^(#$L"B`@("`D
M1TQ/0D%,4ULG6$U,7U)00U]$871E5&EM92==(#T^(#$L"B`@("`D1TQ/0D%,
M4ULG6$U,7U)00U]"87-E-C0G72`@(#T^(#$L"B`@("`D1TQ/0D%,4ULG6$U,
M7U)00U]!<G)A>2==("`@(#T^(#(L"B`@("`D1TQ/0D%,4ULG6$U,7U)00U]3
M=')U8W0G72`@(#T^(#,L"BD["@H*+RHJ"B`J($5R<F]R(&UE<W-A9V4@;G5M
M8F5R<PH@*B!`9VQO8F%L(&%R<F%Y("1'3$]"04Q36R=834Q?4E!#7V5R<B==
M"B`J+PHD1TQ/0D%,4ULG6$U,7U)00U]E<G(G72`](&%R<F%Y*`H@("`@)W5N
M:VYO=VY?;65T:&]D)R`@("`@(#T^(#$L"B`@("`G:6YV86QI9%]R971U<FXG
M("`@("`@/3X@,BP*("`@("=I;F-O<G)E8W1?<&%R86US)R`@("`]/B`S+`H@
M("`@)VEN=')O<W!E8W1?=6YK;F]W;B<@(#T^(#0L"B`@("`G:'1T<%]E<G)O
M<B<@("`@("`@("`@/3X@-2P*("`@("=N;W1?<F5S<&]N<V5?;V)J96-T)R`]
M/B`V+`H@("`@)VEN=F%L:61?<F5Q=65S="<@("`@(#T^(#<L"BD["@HO*BH*
M("H@17)R;W(@;65S<V%G92!S=')I;F=S"B`J($!G;&]B86P@87)R87D@)$=,
M3T)!3%-;)UA-3%]24$-?<W1R)UT*("HO"B1'3$]"04Q36R=834Q?4E!#7W-T
M<B==(#T@87)R87DH"B`@("`G=6YK;F]W;E]M971H;V0G("`@("`@/3X@)U5N
M:VYO=VX@;65T:&]D)RP*("`@("=I;G9A;&ED7W)E='5R;B<@("`@("`]/B`G
M26YV86QI9"!R971U<FX@<&%Y;&]A9#H@96YA8FQE(&1E8G5G9VEN9R!T;R!E
M>&%M:6YE(&EN8V]M:6YG('!A>6QO860G+`H@("`@)VEN8V]R<F5C=%]P87)A
M;7,G("`@(#T^("=);F-O<G)E8W0@<&%R86UE=&5R<R!P87-S960@=&\@;65T
M:&]D)RP*("`@("=I;G1R;W-P96-T7W5N:VYO=VXG("`]/B`G0V%N7"=T(&EN
M=')O<W!E8W0Z(&UE=&AO9"!U;FMN;W=N)RP*("`@("=H='1P7V5R<F]R)R`@
M("`@("`@("`]/B`G1&ED;EPG="!R96-E:79E(#(P,"!/2R!F<F]M(')E;6]T
M92!S97)V97(N)RP*("`@("=N;W1?<F5S<&]N<V5?;V)J96-T)R`]/B`G5&AE
M(')E<75E<W1E9"!M971H;V0@9&ED;EPG="!R971U<FX@86X@6$U,7U)00U]2
M97-P;VYS92!O8FIE8W0N)RP*("`@("=I;G9A;&ED7W)E<75E<W0G("`@("`]
M/B`G26YV86QI9"!R97%U97-T('!A>6QO860G+`HI.PH*"B\J*@H@*B!$969A
M=6QT(%A-3"!E;F-O9&EN9R`H25-/+3@X-3DM,2P@551&+3@@;W(@55,M05-#
M24DI"B`J($!G;&]B86P@<W1R:6YG("1'3$]"04Q36R=834Q?4E!#7V1E9F5N
M8V]D:6YG)UT*("HO"B1'3$]"04Q36R=834Q?4E!#7V1E9F5N8V]D:6YG)UT@
M/2`G551&+3@G.PH*+RHJ"B`J(%5S97(@97)R;W(@8V]D97,@<W1A<G0@870@
M.#`P"B`J($!G;&]B86P@:6YT("1'3$]"04Q36R=834Q?4E!#7V5R<G5S97(G
M70H@*B\*)$=,3T)!3%-;)UA-3%]24$-?97)R=7-E<B==(#T@.#`P.PH*+RHJ
M"B`J(%A-3"!P87)S92!E<G)O<B!C;V1E<R!S=&%R="!A="`Q,#`*("H@0&=L
M;V)A;"!I;G0@)$=,3T)!3%-;)UA-3%]24$-?97)R>&UL)UT*("HO"B1'3$]"
M04Q36R=834Q?4E!#7V5R<GAM;"==(#T@,3`P.PH*"B\J*@H@*B!#;VUP;W-E
M(&)A8VMS;&%S:&5S(&9O<B!E<V-A<&EN9R!R96=E>'`*("H@0&=L;V)A;"!S
M=')I;F<@)$=,3T)!3%-;)UA-3%]24$-?8F%C:W-L87-H)UT*("HO"B1'3$]"
M04Q36R=834Q?4E!#7V)A8VMS;&%S:"==(#T@8VAR*#DR*2`N(&-H<B@Y,BD[
M"@H*+RHJ"B`J(%9A;&ED('!A<F5N=',@;V8@6$U,(&5L96UE;G1S"B`J($!G
M;&]B86P@87)R87D@)$=,3T)!3%-;)UA-3%]24$-?=F%L:61?<&%R96YT<R==
M"B`J+PHD1TQ/0D%,4ULG6$U,7U)00U]V86QI9%]P87)E;G1S)UT@/2!A<G)A
M>2@*("`@("="3T],14%.)R`]/B!A<G)A>2@G5D%,544G*2P*("`@("=)-"<@
M/3X@87)R87DH)U9!3%5%)RDL"B`@("`G24Y4)R`]/B!A<G)A>2@G5D%,544G
M*2P*("`@("=35%))3D<G(#T^(&%R<F%Y*"=604Q512<I+`H@("`@)T1/54),
M12<@/3X@87)R87DH)U9!3%5%)RDL"B`@("`G1$%4151)344N25-/.#8P,2<@
M/3X@87)R87DH)U9!3%5%)RDL"B`@("`G0D%3138T)R`]/B!A<G)A>2@G5D%,
M544G*2P*("`@("=!4E)!62<@/3X@87)R87DH)U9!3%5%)RDL"B`@("`G4U12
M54-4)R`]/B!A<G)A>2@G5D%,544G*2P*("`@("=005)!32<@/3X@87)R87DH
M)U!!4D%-4R<I+`H@("`@)TU%5$A/1$Y!344G(#T^(&%R<F%Y*"=-151(3T1#
M04Q,)RDL"B`@("`G4$%204U3)R`]/B!A<G)A>2@G34542$]$0T%,3"<L("=-
M151(3T1215-03TY312<I+`H@("`@)TU%34)%4B<@/3X@87)R87DH)U-44E5#
M5"<I+`H@("`@)TY!344G(#T^(&%R<F%Y*"=-14U"15(G*2P*("`@("=$051!
M)R`]/B!A<G)A>2@G05)205DG*2P*("`@("=&055,5"<@/3X@87)R87DH)TU%
M5$A/1%)%4U!/3E-%)RDL"B`@("`G5D%,544G(#T^(&%R<F%Y*"=-14U"15(G
M+"`G1$%402<L("=005)!32<L("=&055,5"<I+`HI.PH*"B\J*@H@*B!3=&]R
M97,@<W1A=&4@9'5R:6YG('!A<G-I;F<*("H*("H@<75I8VL@97AP;&%N871I
M;VX@;V8@8V]M<&]N96YT<SH*("H@("`K(&%C("`@("`](&%C8W5M=6QA=&5S
M('9A;'5E<PH@*B`@("L@<70@("`@(#T@9&5C:61E<R!I9B!Q=6]T97,@87)E
M(&YE961E9"!F;W(@979A;'5A=&EO;@H@*B`@("L@8VT@("`@(#T@9&5N;W1E
M<R!S=')U8W0@;W(@87)R87D@*&-O;6UA(&YE961E9"D*("H@("`K(&ES9B`@
M("`](&EN9&EC871E<R!A(&9A=6QT"B`J("`@*R!L=B`@("`@/2!I;F1I8V%T
M97,@(FQO;VMI;F<@9F]R(&$@=F%L=64B.B!I;7!L96UE;G1S('1H92!L;V=I
M8PH@*B`@("`@("`@("`@("`@('1O(&%L;&]W('9A;'5E<R!W:71H(&YO('1Y
M<&5S('1O(&)E('-T<FEN9W,*("H@("`K('!A<F%M<R`]('-T;W)E<R!P87)A
M;65T97)S(&EN(&UE=&AO9"!C86QL<PH@*B`@("L@;65T:&]D(#T@<W1O<F5S
M(&UE=&AO9"!N86UE"B`J"B`J($!G;&]B86P@87)R87D@)$=,3T)!3%-;)UA-
M3%]24$-?>&@G70H@*B\*)$=,3T)!3%-;)UA-3%]24$-?>&@G72`](&%R<F%Y
M*"D["@H*+RHJ"B`J(%-T87)T(&5L96UE;G0@:&%N9&QE<B!F;W(@=&AE(%A-
M3"!P87)S97(*("H*("H@0')E='5R;B!V;VED"B`J+PIF=6YC=&EO;B!834Q?
M4E!#7W-E*"1P87)S97)?<F5S;W5R8V4L("1N86UE+"`D871T<G,I"GL*("`@
M(&=L;V)A;"`D6$U,7U)00U]X:"P@)%A-3%]24$-?=F%L:61?<&%R96YT<SL*
M"B`@("`D<&%R<V5R(#T@*&EN="D@)'!A<G-E<E]R97-O=7)C93L*"B`@("`O
M+R!I9B!I;G9A;&ED('AM;')P8R!A;')E861Y(&1E=&5C=&5D+"!S:VEP(&%L
M;"!P<F]C97-S:6YG"B`@("!I9B`H)%A-3%]24$-?>&A;)'!A<G-E<EU;)VES
M9B==(#X](#(I('L*("`@("`@("!R971U<FX["B`@("!]"@H@("`@+R\@8VAE
M8VL@9F]R(&-O<G)E8W0@96QE;65N="!N97-T:6YG"B`@("`O+R!T;W`@;&5V
M96P@96QE;65N="!C86X@;VYL>2!B92!O9B`R('1Y<&5S"B`@("!I9B`H8V]U
M;G0H)%A-3%]24$-?>&A;)'!A<G-E<EU;)W-T86-K)UTI(#T](#`I('L*("`@
M("`@("!I9B`H)&YA;64@(3T@)TU%5$A/1%)%4U!/3E-%)R`F)B`D;F%M92`A
M/2`G34542$]$0T%,3"<I('L*("`@("`@("`@("`@)%A-3%]24$-?>&A;)'!A
M<G-E<EU;)VES9B==(#T@,CL*("`@("`@("`@("`@)%A-3%]24$-?>&A;)'!A
M<G-E<EU;)VES9E]R96%S;VXG72`]("=M:7-S:6YG('1O<"!L979E;"!X;6QR
M<&,@96QE;65N="<["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"B`@
M("!](&5L<V4@>PH@("`@("`@("\O(&YO="!T;W`@;&5V96P@96QE;65N=#H@
M<V5E(&EF('!A<F5N="!I<R!/2PH@("`@("`@(&EF("@A:6Y?87)R87DH)%A-
M3%]24$-?>&A;)'!A<G-E<EU;)W-T86-K)UU;,%TL("1834Q?4E!#7W9A;&ED
M7W!A<F5N='-;)&YA;65=*2D@>PH@("`@("`@("`@("`D;F%M92`]('!R96=?
M<F5P;&%C92@G6UYA+7I!+5HP+3DN7RU=)RP@)R<L("1N86UE*3L*("`@("`@
M("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)VES9B==(#T@,CL*("`@("`@
M("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)VES9E]R96%S;VXG72`](")X
M;6QR<&,@96QE;65N="`D;F%M92!C86YN;W0@8F4@8VAI;&0@;V8@>R1834Q?
M4E!#7WAH6R1P87)S97)=6R=S=&%C:R==6S!=?2(["B`@("`@("`@("`@(')E
M='5R;CL*("`@("`@("!]"B`@("!]"@H@("`@<W=I=&-H("@D;F%M92D@>PH@
M("`@8V%S92`G4U1254-4)SH*("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R
M75LG8VTG72LK.PH*("`@("`@("`O+R!T=7)N('%U;W1I;F<@;V9F"B`@("`@
M("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W%T)UT@/2`P.PH*("`@("`@("`D
M8W5R7W9A;"`](&%R<F%Y*"D["B`@("`@("`@)&-U<E]V86Q;)W9A;'5E)UT@
M/2!A<G)A>2@I.PH@("`@("`@("1C=7)?=F%L6R=M96UB97)S)UT@/2`Q.PH@
M("`@("`@(&%R<F%Y7W5N<VAI9G0H)%A-3%]24$-?>&A;)'!A<G-E<EU;)W9A
M;'5E<W1A8VLG72P@)&-U<E]V86PI.PH@("`@("`@(&)R96%K.PH*("`@(&-A
M<V4@)T%24D%9)SH*("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG8VTG
M72LK.PH*("`@("`@("`O+R!T=7)N('%U;W1I;F<@;V9F"B`@("`@("`@)%A-
M3%]24$-?>&A;)'!A<G-E<EU;)W%T)UT@/2`P.PH*("`@("`@("`D8W5R7W9A
M;"`](&%R<F%Y*"D["B`@("`@("`@)&-U<E]V86Q;)W9A;'5E)UT@/2!A<G)A
M>2@I.PH@("`@("`@("1C=7)?=F%L6R=M96UB97)S)UT@/2`P.PH@("`@("`@
M(&%R<F%Y7W5N<VAI9G0H)%A-3%]24$-?>&A;)'!A<G-E<EU;)W9A;'5E<W1A
M8VLG72P@)&-U<E]V86PI.PH@("`@("`@(&)R96%K.PH*("`@(&-A<V4@)TY!
M344G.@H@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=A8R==(#T@)R<[
M"B`@("`@("`@8G)E86L["@H@("`@8V%S92`G1D%53%0G.@H@("`@("`@("18
M34Q?4E!#7WAH6R1P87)S97)=6R=I<V8G72`](#$["B`@("`@("`@8G)E86L[
M"@H@("`@8V%S92`G4$%204TG.@H@("`@("`@("1834Q?4E!#7WAH6R1P87)S
M97)=6R=V86QU97-T86-K)UT@/2!A<G)A>2@I.PH@("`@("`@(&)R96%K.PH*
M("`@(&-A<V4@)U9!3%5%)SH*("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R
M75LG;'8G72`](#$["B`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W9T
M)UT@/2`D1TQ/0D%,4ULG6$U,7U)00U]3=')I;F<G73L*("`@("`@("`D6$U,
M7U)00U]X:%LD<&%R<V5R75LG86,G72`]("<G.PH@("`@("`@("1834Q?4E!#
M7WAH6R1P87)S97)=6R=Q="==(#T@,#L*("`@("`@("`O+R!L;V]K(&9O<B!A
M('9A;'5E.B!I9B!T:&ES(&ES('-T:6QL(#$@8GD@=&AE"B`@("`@("`@+R\@
M=&EM92!W92!R96%C:"!T:&4@9FER<W0@9&%T82!S96=M96YT('1H96X@=&AE
M('1Y<&4@:7,@<W1R:6YG"B`@("`@("`@+R\@8GD@:6UP;&EC871I;VX@86YD
M('=E(&YE960@=&\@861D(&EN(&$@<75O=&4*("`@("`@("!B<F5A:SL*"B`@
M("!C87-E("=)-"<Z"B`@("!C87-E("=)3E0G.@H@("`@8V%S92`G4U1224Y'
M)SH*("`@(&-A<V4@)T)/3TQ%04XG.@H@("`@8V%S92`G1$]50DQ%)SH*("`@
M(&-A<V4@)T1!5$5424U%+DE33S@V,#$G.@H@("`@8V%S92`G0D%3138T)SH*
M("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG86,G72`]("<G.R`O+R!R
M97-E="!T:&4@86-C=6UU;&%T;W(*"B`@("`@("`@:68@*"1N86UE(#T]("=$
M051%5$E-12Y)4T\X-C`Q)R!\?"`D;F%M92`]/2`G4U1224Y')RD@>PH@("`@
M("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG<70G72`](#$["@H@("`@
M("`@("`@("!I9B`H)&YA;64@/3T@)T1!5$5424U%+DE33S@V,#$G*2!["B`@
M("`@("`@("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG=G0G72`]("1'
M3$]"04Q36R=834Q?4E!#7T1A=&54:6UE)UT["B`@("`@("`@("`@('T*"B`@
M("`@("`@?2!E;'-E:68@*"1N86UE(#T]("="05-%-C0G*2!["B`@("`@("`@
M("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=Q="==(#T@,CL*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`O+R!.;R!Q=6]T:6YG(&ES(')E<75I<F5D
M(&AE<F4@+2T@8G5T"B`@("`@("`@("`@("\O(&%T('1H92!E;F0@;V8@=&AE
M(&5L96UE;G0@=V4@;75S="!C:&5C:PH@("`@("`@("`@("`O+R!F;W(@9&%T
M82!F;W)M870@97)R;W)S+@H@("`@("`@("`@("`D6$U,7U)00U]X:%LD<&%R
M<V5R75LG<70G72`](#`["B`@("`@("`@?0H@("`@("`@(&)R96%K.PH*("`@
M(&-A<V4@)TU%34)%4B<Z"B`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;
M)V%C)UT@/2`G)SL*("`@("`@("!B<F5A:SL*"B`@("!C87-E("=$051!)SH*
M("`@(&-A<V4@)TU%5$A/1$-!3$PG.@H@("`@8V%S92`G34542$]$3D%-12<Z
M"B`@("!C87-E("=-151(3T1215-03TY312<Z"B`@("!C87-E("=005)!35,G
M.@H@("`@("`@("\O('9A;&ED(&5L96UE;G1S('1H870@861D(&QI='1L92!T
M;R!P<F]C97-S:6YG"B`@("`@("`@8G)E86L["B`@("!]"@H*("`@("\O(%-A
M=F4@8W5R<F5N="!E;&5M96YT('1O('-T86-K"B`@("!A<G)A>5]U;G-H:69T
M*"1834Q?4E!#7WAH6R1P87)S97)=6R=S=&%C:R==+"`D;F%M92D["@H@("`@
M:68@*"1N86UE("$]("=604Q512<I('L*("`@("`@("`D6$U,7U)00U]X:%LD
M<&%R<V5R75LG;'8G72`](#`["B`@("!]"GT*"B\J*@H@*B!%;F0@96QE;65N
M="!H86YD;&5R(&9O<B!T:&4@6$U,('!A<G-E<@H@*@H@*B!`<F5T=7)N('9O
M:60*("HO"F9U;F-T:6]N(%A-3%]24$-?964H)'!A<G-E<E]R97-O=7)C92P@
M)&YA;64I"GL*("`@(&=L;V)A;"`D6$U,7U)00U]X:#L*"B`@("`D<&%R<V5R
M(#T@*&EN="D@)'!A<G-E<E]R97-O=7)C93L*"B`@("!I9B`H)%A-3%]24$-?
M>&A;)'!A<G-E<EU;)VES9B==(#X](#(I('L*("`@("`@("!R971U<FX["B`@
M("!]"@H@("`@+R\@<'5S:"!T:&ES(&5L96UE;G0@9G)O;2!S=&%C:PH@("`@
M+R\@3D(Z(&EF(%A-3"!V86QI9&%T97,L(&-O<G)E8W0@;W!E;FEN9R]C;&]S
M:6YG(&ES(&=U87)A;G1E960@86YD"B`@("`O+R!W92!D;R!N;W0@:&%V92!T
M;R!C:&5C:R!F;W(@)&YA;64@/3T@)&-U<G)?96QE;2X*("`@("\O('=E(&%L
M<V\@8VAE8VME9"!F;W(@<')O<&5R(&YE<W1I;F<@870@<W1A<G0@;V8@96QE
M;65N=',N+BX*("`@("1C=7)R7V5L96T@/2!A<G)A>5]S:&EF="@D6$U,7U)0
M0U]X:%LD<&%R<V5R75LG<W1A8VLG72D["@H@("`@<W=I=&-H("@D;F%M92D@
M>PH@("`@8V%S92`G4U1254-4)SH*("`@(&-A<V4@)T%24D%9)SH*("`@("1C
M=7)?=F%L(#T@87)R87E?<VAI9G0H)%A-3%]24$-?>&A;)'!A<G-E<EU;)W9A
M;'5E<W1A8VLG72D["B`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG=F%L=64G
M72`]("1C=7)?=F%L6R=V86QU92==.PH@("`@("`@("1834Q?4E!#7WAH6R1P
M87)S97)=6R=V="==(#T@<W1R=&]L;W=E<B@D;F%M92D["B`@("`@("`@)%A-
M3%]24$-?>&A;)'!A<G-E<EU;)V-M)UTM+3L*("`@("`@("!B<F5A:SL*"B`@
M("!C87-E("=.04U%)SH*("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=V86QU
M97-T86-K)UU;,%U;)VYA;64G72`]("1834Q?4E!#7WAH6R1P87)S97)=6R=A
M8R==.PH@("`@("`@(&)R96%K.PH*("`@(&-A<V4@)T)/3TQ%04XG.@H@("`@
M("`@("\O('-P96-I86P@8V%S92!H97)E.B!W92!T<F%N<VQA=&4@8F]O;&5A
M;B`Q(&]R(#`@:6YT;R!02%`*("`@("`@("`O+R!C;VYS=&%N=',@=')U92!O
M<B!F86QS90H@("`@("`@(&EF("@D6$U,7U)00U]X:%LD<&%R<V5R75LG86,G
M72`]/2`G,2<I('L*("`@("`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;
M)V%C)UT@/2`G=')U92<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)%A-3%]24$-?>&A;)'!A<G-E<EU;)V%C)UT@/2`G9F%L<V4G.PH@("`@("`@
M('T*"B`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W9T)UT@/2!S=')T
M;VQO=V5R*"1N86UE*3L*("`@("`@("`O+R!$<F]P('1H<F]U9V@@:6YT96YT
M:6]N86QL>2X*"B`@("!C87-E("=)-"<Z"B`@("!C87-E("=)3E0G.@H@("`@
M8V%S92`G4U1224Y')SH*("`@(&-A<V4@)T1/54),12<Z"B`@("!C87-E("=$
M051%5$E-12Y)4T\X-C`Q)SH*("`@(&-A<V4@)T)!4T4V-"<Z"B`@("`@("`@
M:68@*"1834Q?4E!#7WAH6R1P87)S97)=6R=Q="==(#T](#$I('L*("`@("`@
M("`@("`@+R\@=V4@=7-E(&1O=6)L92!Q=6]T97,@<F%T:&5R('1H86X@<VEN
M9VQE('-O(&)A8VMS;&%S:&EF:6-A=&EO;B!W;W)K<R!/2PH@("`@("`@("`@
M("`D6$U,7U)00U]X:%LD<&%R<V5R75LG=F%L=64G72`]("1834Q?4E!#7WAH
M6R1P87)S97)=6R=A8R==.PH@("`@("`@('T@96QS96EF("@D6$U,7U)00U]X
M:%LD<&%R<V5R75LG<70G72`]/2`R*2!["B`@("`@("`@("`@("1834Q?4E!#
M7WAH6R1P87)S97)=6R=V86QU92==(#T@8F%S938T7V1E8V]D92@D6$U,7U)0
M0U]X:%LD<&%R<V5R75LG86,G72D["B`@("`@("`@?2!E;'-E:68@*"1N86UE
M(#T]("="3T],14%.)RD@>PH@("`@("`@("`@("`D6$U,7U)00U]X:%LD<&%R
M<V5R75LG=F%L=64G72`]("1834Q?4E!#7WAH6R1P87)S97)=6R=A8R==.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O('=E(&AA=F4@86X@230L
M($E.5"!O<B!A($1/54),10H@("`@("`@("`@("`O+R!W92!M=7-T(&-H96-K
M('1H870@;VYL>2`P,3(S-#4V-S@Y+2X\<W!A8V4^(&%R92!C:&%R86-T97)S
M(&AE<F4*("`@("`@("`@("`@:68@*"%E<F5G*")>6RLM73];,#$R,S0U-C<X
M.2!<=%PN72LD(BP@)%A-3%]24$-?>&A;)'!A<G-E<EU;)V%C)UTI*2!["B`@
M("`@("`@("`@("`@("!834Q?4E!#7T)A<V4Z.G)A:7-E17)R;W(H)TYO;BUN
M=6UE<FEC('9A;'5E(')E8V5I=F5D(&EN($E.5"!O<B!$3U5"3$4G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]24$-?
M15)23U)?3D].7TY5345224-?1D]53D0I.PH@("`@("`@("`@("`@("`@)%A-
M3%]24$-?>&A;)'!A<G-E<EU;)W9A;'5E)UT@/2!834Q?4E!#7T524D]27TY/
M3E].54U%4DE#7T9/54Y$.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@+R\@:70G<R!O:RP@861D(&ET(&]N"B`@("`@("`@("`@("`@
M("`D6$U,7U)00U]X:%LD<&%R<V5R75LG=F%L=64G72`]("1834Q?4E!#7WAH
M6R1P87)S97)=6R=A8R==.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG86,G72`]("<G.PH@("`@("`@
M("1834Q?4E!#7WAH6R1P87)S97)=6R=Q="==(#T@,#L*("`@("`@("`D6$U,
M7U)00U]X:%LD<&%R<V5R75LG;'8G72`](#,[("\O(&EN9&EC871E('=E)W9E
M(&9O=6YD(&$@=F%L=64*("`@("`@("!B<F5A:SL*"B`@("!C87-E("=604Q5
M12<Z"B`@("`@("`@:68@*"1834Q?4E!#7WAH6R1P87)S97)=6R=V="==(#T]
M("1'3$]"04Q36R=834Q?4E!#7U-T<FEN9R==*2!["B`@("`@("`@("`@(&EF
M("AS=')L96XH)%A-3%]24$-?>&A;)'!A<G-E<EU;)V%C)UTI(#X@,"D@>PH@
M("`@("`@("`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W9A;'5E)UT@
M/2`D6$U,7U)00U]X:%LD<&%R<V5R75LG86,G73L*("`@("`@("`@("`@?2!E
M;'-E:68@*"1834Q?4E!#7WAH6R1P87)S97)=6R=L=B==(#T](#$I('L*("`@
M("`@("`@("`@("`@("\O(%1H92`\=F%L=64^(&5L96UE;G0@=V%S(&5M<'1Y
M+@H@("`@("`@("`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W9A;'5E
M)UT@/2`G)SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)'1E
M;7`@/2!N97<@6$U,7U)00U]686QU92@D6$U,7U)00U]X:%LD<&%R<V5R75LG
M=F%L=64G72P@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W9T)UTI.PH*("`@("`@
M("`D8W5R7W9A;"`](&%R<F%Y7W-H:69T*"1834Q?4E!#7WAH6R1P87)S97)=
M6R=V86QU97-T86-K)UTI.PH@("`@("`@(&EF("AI<U]A<G)A>2@D8W5R7W9A
M;"DI('L*("`@("`@("`@("`@:68@*"1C=7)?=F%L6R=M96UB97)S)UT]/3`I
M('L*("`@("`@("`@("`@("`@("1C=7)?=F%L6R=V86QU92==6UT@/2`D=&5M
M<#L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1834Q?
M4E!#7WAH6R1P87)S97)=6R=V86QU92==(#T@)'1E;7`["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@87)R87E?=6YS:&EF="@D6$U,7U)00U]X:%LD<&%R
M<V5R75LG=F%L=65S=&%C:R==+"`D8W5R7W9A;"D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W9A;'5E)UT@
M/2`D=&5M<#L*("`@("`@("!]"B`@("`@("`@8G)E86L["@H@("`@8V%S92`G
M345-0D52)SH*("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG86,G72`]
M("<G.PH@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=Q="==(#T@,#L*
M"B`@("`@("`@)&-U<E]V86P@/2!A<G)A>5]S:&EF="@D6$U,7U)00U]X:%LD
M<&%R<V5R75LG=F%L=65S=&%C:R==*3L*("`@("`@("!I9B`H:7-?87)R87DH
M)&-U<E]V86PI*2!["B`@("`@("`@("`@(&EF("@D8W5R7W9A;%LG;65M8F5R
M<R==/3TQ*2!["B`@("`@("`@("`@("`@("`D8W5R7W9A;%LG=F%L=64G75LD
M8W5R7W9A;%LG;F%M92==72`]("1834Q?4E!#7WAH6R1P87)S97)=6R=V86QU
M92==.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&%R<F%Y7W5N<VAI9G0H
M)%A-3%]24$-?>&A;)'!A<G-E<EU;)W9A;'5E<W1A8VLG72P@)&-U<E]V86PI
M.PH@("`@("`@('T*("`@("`@("!B<F5A:SL*"B`@("!C87-E("=$051!)SH*
M("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG86,G72`]("<G.PH@("`@
M("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=Q="==(#T@,#L*("`@("`@("!B
M<F5A:SL*"B`@("!C87-E("=005)!32<Z"B`@("`@("`@)%A-3%]24$-?>&A;
M)'!A<G-E<EU;)W!A<F%M<R==6UT@/2`D6$U,7U)00U]X:%LD<&%R<V5R75LG
M=F%L=64G73L*("`@("`@("!B<F5A:SL*"B`@("!C87-E("=-151(3T1.04U%
M)SH*("`@(&-A<V4@)U)00TU%5$A/1$Y!344G.@H@("`@("`@("1834Q?4E!#
M7WAH6R1P87)S97)=6R=M971H;V0G72`](&5R96=?<F5P;&%C92@B7EM<;EQR
M7'0@72LB+"`G)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)V%C
M)UTI.PH@("`@("`@(&)R96%K.PH@("`@?0H*("`@("\O(&EF(&ET)W,@82!V
M86QI9"!T>7!E(&YA;64L('-E="!T:&4@='EP90H@("`@:68@*&ES<V5T*"1'
M3$]"04Q36R=834Q?4E!#7U1Y<&5S)UU;<W1R=&]L;W=E<B@D;F%M92E=*2D@
M>PH@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=V="==(#T@<W1R=&]L
M;W=E<B@D;F%M92D["B`@("!]"GT*"B\J*@H@*B!#:&%R86-T97(@9&%T82!H
M86YD;&5R(&9O<B!T:&4@6$U,('!A<G-E<@H@*@H@*B!`<F5T=7)N('9O:60*
M("HO"F9U;F-T:6]N(%A-3%]24$-?8V0H)'!A<G-E<E]R97-O=7)C92P@)&1A
M=&$I"GL*("`@(&=L;V)A;"`D6$U,7U)00U]X:"P@)%A-3%]24$-?8F%C:W-L
M87-H.PH*("`@("1P87)S97(@/2`H:6YT*2`D<&%R<V5R7W)E<V]U<F-E.PH*
M("`@(&EF("@D6$U,7U)00U]X:%LD<&%R<V5R75LG;'8G72`A/2`S*2!["B`@
M("`@("`@+R\@(FQO;VMF;W)V86QU93T],R(@;65A;G,@=&AA="!W92=V92!F
M;W5N9"!A;B!E;G1I<F4@=F%L=64*("`@("`@("`O+R!A;F0@<VAO=6QD(&1I
M<V-A<F0@86YY(&9U<G1H97(@8VAA<F%C=&5R(&1A=&$*"B`@("`@("`@:68@
M*"1834Q?4E!#7WAH6R1P87)S97)=6R=L=B==(#T](#$I('L*("`@("`@("`@
M("`@+R\@:68@=V4G=F4@9F]U;F0@=&5X="!A;F0@=V4G<F4@:G5S="!I;B!A
M(#QV86QU93X@=&AE;@H@("`@("`@("`@("`O+R!T=7)N('%U;W1I;F<@;VXL
M(&%S('1H:7,@=VEL;"!B92!A('-T<FEN9PH@("`@("`@("`@("`D6$U,7U)0
M0U]X:%LD<&%R<V5R75LG<70G72`](#$["B`@("`@("`@("`@("\O(&%N9"!S
M87D@=V4G=F4@9F]U;F0@82!V86QU90H@("`@("`@("`@("`D6$U,7U)00U]X
M:%LD<&%R<V5R75LG;'8G72`](#(["B`@("`@("`@?0H*("`@("`@("`O+R!R
M97!L86-E(&-H87)A8W1E<G,@=&AA="!E=F%L('=O=6QD"B`@("`@("`@+R\@
M9&\@<W!E8VEA;"!T:&EN9W,@=VET:`H@("`@("`@(&EF("@A:7-S970H)%A-
M3%]24$-?>&A;)'!A<G-E<EU;)V%C)UTI*2!["B`@("`@("`@("`@("1834Q?
M4E!#7WAH6R1P87)S97)=6R=A8R==(#T@)R<["B`@("`@("`@?0H@("`@("`@
M("1834Q?4E!#7WAH6R1P87)S97)=6R=A8R==("X]("1D871A.PH@("`@?0I]
M"@HO*BH*("H@5&AE(&-O;6UO;B!M971H;V1S(&%N9"!P<F]P97)T:65S(&9O
M<B!A;&P@;V8@=&AE(%A-3%]24$,@8VQA<W-E<PH@*@H@*B!`8V%T96=O<GD@
M("!796(@4V5R=FEC97,*("H@0'!A8VMA9V4@("`@6$U,7U)00PH@*B!`875T
M:&]R("`@("!%9&0@1'5M8FEL;"`\961D0'5S969U;&EN8RYC;VT^"B`J($!A
M=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS=&EG0'!H<"YN970^"B`J($!A=71H
M;W(@("`@($UA<G1I;B!*86YS96X@/&UJ0'!H<"YN970^"B`J($!A=71H;W(@
M("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O
M<'ER:6=H="`@,3DY.2TR,#`Q($5D9"!$=6UB:6QL+"`R,#`Q+3(P,#4@5&AE
M(%!(4"!'<F]U<`H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.`H@*B!`
M;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O6$U,7U)0
M0PH@*B\*8VQA<W,@6$U,7U)00U]"87-E('L*"B`@("`O*BH*("`@("`J(%!%
M05(@17)R;W(@:&%N9&QI;F<*("`@("`J"B`@("`@*B!`<F5T=7)N(&]B:F5C
M="`@4$5!4E]%<G)O<B!O8FIE8W0*("`@("`J+PH@("`@9G5N8W1I;VX@<F%I
M<V5%<G)O<B@D;7-G+"`D8V]D92D*("`@('L*("`@("`@("!I;F-L=61E7V]N
M8V4@)U!%05(N<&AP)SL*("`@("`@("!I9B`H:7-?;V)J96-T*$`D=&AI<RDI
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H9V5T7V-L
M87-S*"1T:&ES*2`N("<Z("<@+B`D;7-G+"`D8V]D92D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)UA-
M3%]24$,Z("<@+B`D;7-G+"`D8V]D92D["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@5&5L;"!W:&5T:&5R('-O;65T:&EN9R!I<R!A(%!%05)?
M17)R;W(@;V)J96-T"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1V86QU
M92`@=&AE(&ET96T@=&\@8VAE8VL*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VP@('=H971H97(@)'9A;'5E(&ES(&$@4$5!4E]%<G)O<B!O8FIE8W0@;W(@
M;F]T"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@:7-%<G)O<B@D=F%L=64I"B`@("!["B`@("`@("`@<F5T=7)N
M(&ES7V$H)'9A;'5E+"`G4$5!4E]%<G)O<B<I.PH@("`@?0I]"@HO*BH*("H@
M5&AE(&UE=&AO9',@86YD('!R;W!E<G1I97,@9F]R('-U8FUI='1I;F<@6$U,
M(%)00R!R97%U97-T<PH@*@H@*B!`8V%T96=O<GD@("!796(@4V5R=FEC97,*
M("H@0'!A8VMA9V4@("`@6$U,7U)00PH@*B!`875T:&]R("`@("!%9&0@1'5M
M8FEL;"`\961D0'5S969U;&EN8RYC;VT^"B`J($!A=71H;W(@("`@(%-T:6<@
M0F%K:V5N(#QS=&EG0'!H<"YN970^"B`J($!A=71H;W(@("`@($UA<G1I;B!*
M86YS96X@/&UJ0'!H<"YN970^"B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV
M:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY.2TR
M,#`Q($5D9"!$=6UB:6QL+"`R,#`Q+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`
M=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.`H@*B!`;&EN:R`@("`@("!H='1P
M.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O6$U,7U)00PH@*B\*8VQA<W,@6$U,
M7U)00U]#;&EE;G0@97AT96YD<R!834Q?4E!#7T)A<V4@>PH*("`@("\J*@H@
M("`@("H@5&AE('!A=&@@86YD(&YA;64@;V8@=&AE(%)00R!S97)V97(@<V-R
M:7!T('EO=2!W86YT('1H92!R97%U97-T('1O(&=O('1O"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)'!A=&@@/2`G)SL*"B`@("`O*BH*
M("`@("`J(%1H92!N86UE(&]F('1H92!R96UO=&4@<V5R=F5R('1O(&-O;FYE
M8W0@=&\*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D<V5R
M=F5R(#T@)R<["@H@("`@+RHJ"B`@("`@*B!4:&4@<')O=&]C;VP@=&\@=7-E
M(&EN(&-O;G1A8W1I;F<@=&AE(')E;6]T92!S97)V97(*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D<')O=&]C;VP@/2`G:'1T<#HO+R<[
M"@H@("`@+RHJ"B`@("`@*B!4:&4@<&]R="!F;W(@8V]N;F5C=&EN9R!T;R!T
M:&4@<F5M;W1E('-E<G9E<@H@("`@("H*("`@("`J(%1H92!D969A=6QT(&ES
M(#@P(&9O<B!H='1P.B\O(&-O;FYE8W1I;VYS"B`@("`@*B!A;F0@-#0S(&9O
M<B!H='1P<SHO+R!A;F0@<W-L.B\O(&-O;FYE8W1I;VYS+@H@("`@("H*("`@
M("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)'!O<G0@/2`X,#L*
M"B`@("`O*BH*("`@("`J($$@=7-E<B!N86UE(&9O<B!A8V-E<W-I;F<@=&AE
M(%)00R!S97)V97(*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`<V5E(%A-
M3%]24$-?0VQI96YT.CIS971#<F5D96YT:6%L<R@I"B`@("`@*B\*("`@('9A
M<B`D=7-E<FYA;64@/2`G)SL*"B`@("`O*BH*("`@("`J($$@<&%S<W=O<F0@
M9F]R(&%C8V5S<VEN9R!T:&4@4E!#('-E<G9E<@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J($!S964@6$U,7U)00U]#;&EE;G0Z.G-E=$-R961E;G1I86QS
M*"D*("`@("`J+PH@("`@=F%R("1P87-S=V]R9"`]("<G.PH*("`@("\J*@H@
M("`@("H@5&AE(&YA;64@;V8@=&AE('!R;WAY('-E<G9E<B!T;R!U<V4L(&EF
M(&%N>0H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1P<F]X
M>2`]("<G.PH*("`@("\J*@H@("`@("H@5&AE('!R;W1O8V]L('1O('5S92!I
M;B!C;VYT86-T:6YG('1H92!P<F]X>2!S97)V97(L(&EF(&%N>0H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1P<F]X>5]P<F]T;V-O;"`]
M("=H='1P.B\O)SL*"B`@("`O*BH*("`@("`J(%1H92!P;W)T(&9O<B!C;VYN
M96-T:6YG('1O('1H92!P<F]X>2!S97)V97(*("`@("`J"B`@("`@*B!4:&4@
M9&5F875L="!I<R`X,#@P(&9O<B!H='1P.B\O(&-O;FYE8W1I;VYS"B`@("`@
M*B!A;F0@-#0S(&9O<B!H='1P<SHO+R!A;F0@<W-L.B\O(&-O;FYE8W1I;VYS
M+@H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@
M)'!R;WAY7W!O<G0@/2`X,#@P.PH*("`@("\J*@H@("`@("H@02!U<V5R(&YA
M;64@9F]R(&%C8V5S<VEN9R!T:&4@<')O>'D@<V5R=F5R"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)'!R;WAY7W5S97(@/2`G)SL*"B`@
M("`O*BH*("`@("`J($$@<&%S<W=O<F0@9F]R(&%C8V5S<VEN9R!T:&4@<')O
M>'D@<V5R=F5R"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@
M)'!R;WAY7W!A<W,@/2`G)SL*"B`@("`O*BH*("`@("`J(%1H92!E<G)O<B!N
M=6UB97(L(&EF(&%N>0H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@
M('9A<B`D97)R;F\@/2`P.PH*("`@("\J*@H@("`@("H@5&AE(&5R<F]R(&UE
M<W-A9V4L(&EF(&%N>0H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1E<G)S='(@/2`G)SL*"B`@("`O*BH*("`@("`J(%1H92!C=7)R96YT
M(&1E8G5G(&UO9&4@*#$@/2!O;BP@,"`](&]F9BD*("`@("`J($!V87(@:6YT
M96=E<@H@("`@("HO"B`@("!V87(@)&1E8G5G(#T@,#L*"B`@("`O*BH*("`@
M("`J(%1H92!(5%10(&AE861E<G,@9F]R('1H92!C=7)R96YT(')E<75E<W0N
M"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)&AE861E<G,@
M/2`G)SL*"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!O8FIE8W0G<R!P<F]P
M97)T:65S"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'!A=&@@("`@
M("`@('1H92!P871H(&%N9"!N86UE(&]F('1H92!24$,@<V5R=F5R('-C<FEP
M=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!Y;W4@=V%N
M="!T:&4@<F5Q=65S="!T;R!G;R!T;PH@("`@("H@0'!A<F%M('-T<FEN9R`@
M)'-E<G9E<B`@("`@('1H92!54DP@;V8@=&AE(')E;6]T92!S97)V97(@=&\@
M8V]N;F5C="!T;RX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@268@=&AI<R!P87)A;65T97(@9&]E<VXG="!S<&5C:69Y(&$*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<')O=&]C;VP@86YD("1P
M;W)T(&ES(#0T,RP@<W-L.B\O(&ES"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%S<W5M960N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M<&]R="`@("`@("`@82!P;W)T(&9O<B!C;VYN96-T:6YG('1O('1H92!R96UO
M=&4@<V5R=F5R+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!$969A=6QT<R!T;R`X,"!F;W(@:'1T<#HO+R!C;VYN96-T:6]N<R!A;F0*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@-#0S(&9O<B!H
M='1P<SHO+R!A;F0@<W-L.B\O(&-O;FYE8W1I;VYS+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`@)'!R;WAY("`@("`@('1H92!54DP@;V8@=&AE('!R;WAY('-E
M<G9E<B!T;R!U<V4L(&EF(&%N>2X*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@268@=&AI<R!P87)A;65T97(@9&]E<VXG="!S<&5C:69Y
M(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<')O=&]C
M;VP@86YD("1P;W)T(&ES(#0T,RP@<W-L.B\O(&ES"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%S<W5M960N"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D<')O>'E?<&]R="`@82!P;W)T(&9O<B!C;VYN96-T:6YG('1O
M('1H92!R96UO=&4@<V5R=F5R+@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!$969A=6QT<R!T;R`X,#@P(&9O<B!H='1P.B\O(&-O;FYE
M8W1I;VYS(&%N9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`T-#,@9F]R(&AT='!S.B\O(&%N9"!S<VPZ+R\@8V]N;F5C=&EO;G,N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("`D<')O>'E?=7-E<B`@82!U<V5R(&YA;64@
M9F]R(&%C8V5S<VEN9R!T:&4@<')O>'D@<V5R=F5R"B`@("`@*B!`<&%R86T@
M<W1R:6YG("`D<')O>'E?<&%S<R`@82!P87-S=V]R9"!F;W(@86-C97-S:6YG
M('1H92!P<F]X>2!S97)V97(*("`@("`J"B`@("`@*B!`<F5T=7)N('9O:60*
M("`@("`J+PH@("`@9G5N8W1I;VX@6$U,7U)00U]#;&EE;G0H)'!A=&@L("1S
M97)V97(L("1P;W)T(#T@,"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1P<F]X>2`]("<G+"`D<')O>'E?<&]R="`](#`L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<')O>'E?=7-E<B`]("<G+"`D<')O>'E?<&%S<R`]
M("<G*0H@("`@>PH@("`@("`@("1T:&ES+3YP871H("`@("`@(#T@)'!A=&@[
M"B`@("`@("`@)'1H:7,M/G!R;WAY7W5S97(@/2`D<')O>'E?=7-E<CL*("`@
M("`@("`D=&AI<RT^<')O>'E?<&%S<R`]("1P<F]X>5]P87-S.PH*("`@("`@
M("!P<F5G7VUA=&-H*"=`7BAH='1P.B\O?&AT='!S.B\O?'-S;#HO+RD_*"XJ
M*21`)RP@)'-E<G9E<BP@)&UA=&-H*3L*("`@("`@("!I9B`H)&UA=&-H6S%=
M(#T]("<G*2!["B`@("`@("`@("`@(&EF("@D<&]R="`]/2`T-#,I('L*("`@
M("`@("`@("`@("`@("1T:&ES+3YS97)V97(@("`]("1M871C:%LR73L*("`@
M("`@("`@("`@("`@("1T:&ES+3YP<F]T;V-O;"`]("=S<VPZ+R\G.PH@("`@
M("`@("`@("`@("`@)'1H:7,M/G!O<G0@("`@(#T@-#0S.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E<G9E<B`]("1M
M871C:%LR73L*("`@("`@("`@("`@("`@(&EF("@D<&]R="D@>PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YP;W)T(#T@)'!O<G0["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V5I9B`H)&UA=&-H
M6S%=(#T]("=H='1P.B\O)RD@>PH@("`@("`@("`@("`D=&AI<RT^<V5R=F5R
M(#T@)&UA=&-H6S)=.PH@("`@("`@("`@("!I9B`H)'!O<G0I('L*("`@("`@
M("`@("`@("`@("1T:&ES+3YP;W)T(#T@)'!O<G0["B`@("`@("`@("`@('T*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^<V5R=F5R("`@
M/2`D;6%T8VA;,ET["B`@("`@("`@("`@("1T:&ES+3YP<F]T;V-O;"`]("=S
M<VPZ+R\G.PH@("`@("`@("`@("!I9B`H)'!O<G0I('L*("`@("`@("`@("`@
M("`@("1T:&ES+3YP;W)T(#T@)'!O<G0["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<&]R="`](#0T,SL*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1P<F]X>2D@>PH@("`@("`@
M("`@("!P<F5G7VUA=&-H*"=`7BAH='1P.B\O?&AT='!S.B\O?'-S;#HO+RD_
M*"XJ*21`)RP@)'!R;WAY+"`D;6%T8V@I.PH@("`@("`@("`@("!I9B`H)&UA
M=&-H6S%=(#T]("<G*2!["B`@("`@("`@("`@("`@("!I9B`H)'!R;WAY7W!O
M<G0@/3T@-#0S*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G!R;WAY
M("`@("`@("`@(#T@)&UA=&-H6S)=.PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YP<F]X>5]P<F]T;V-O;"`]("=S<VPZ+R\G.PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YP<F]X>5]P;W)T("`@("`](#0T,SL*("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G!R
M;WAY(#T@)&UA=&-H6S)=.PH@("`@("`@("`@("`@("`@("`@(&EF("@D<')O
M>'E?<&]R="D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<')O
M>'E?<&]R="`]("1P<F]X>5]P;W)T.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E:68@*"1M871C
M:%LQ72`]/2`G:'1T<#HO+R<I('L*("`@("`@("`@("`@("`@("1T:&ES+3YP
M<F]X>2`]("1M871C:%LR73L*("`@("`@("`@("`@("`@(&EF("@D<')O>'E?
M<&]R="D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YP<F]X>5]P;W)T
M(#T@)'!R;WAY7W!O<G0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D=&AI<RT^<')O>'D@("`@("`@
M("`@/2`D;6%T8VA;,ET["B`@("`@("`@("`@("`@("`D=&AI<RT^<')O>'E?
M<')O=&]C;VP@/2`G<W-L.B\O)SL*("`@("`@("`@("`@("`@(&EF("@D<')O
M>'E?<&]R="D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YP<F]X>5]P
M;W)T(#T@)'!R;WAY7W!O<G0["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YP<F]X>5]P;W)T(#T@-#0S.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@0VAA;F=E('1H92!C=7)R96YT(&1E8G5G(&UO
M9&4*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("1I;B`@=VAE<F4@,2`](&]N
M+"`P(#T@;V9F"B`@("`@*@H@("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-E=$1E8G5G*"1I;BD*("`@('L*("`@("`@("!I9B`H
M)&EN*2!["B`@("`@("`@("`@("1T:&ES+3YD96)U9R`](#$["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/F1E8G5G(#T@,#L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=7-E<FYA;64@86YD('!A
M<W-W;W)D('!R;W!E<G1I97,@9F]R(&-O;FYE8W1I;F<@=&\@=&AE(%)00R!S
M97)V97(*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U("!T:&4@=7-E
M<B!N86UE"B`@("`@*B!`<&%R86T@<W1R:6YG("1P("!T:&4@<&%S<W=O<F0*
M("`@("`J"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J"B`@("`@*B!`<V5E
M(%A-3%]24$-?0VQI96YT.CHD=7-E<FYA;64L(%A-3%]24$-?0VQI96YT.CHD
M<&%S<W=O<F0*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T0W)E9&5N=&EA;',H
M)'4L("1P*0H@("`@>PH@("`@("`@("1T:&ES+3YU<V5R;F%M92`]("1U.PH@
M("`@("`@("1T:&ES+3YP87-S=V]R9"`]("1P.PH@("`@?0H*("`@("\J*@H@
M("`@("H@5')A;G-M:70@=&AE(%)00R!R97%U97-T('9I82!(5%10(#$N,"!P
M<F]T;V-O;`H@("`@("H*("`@("`J($!P87)A;2!O8FIE8W0@)&US9R`@("`@
M("!T:&4@6$U,7U)00U]-97-S86=E(&]B:F5C=`H@("`@("H@0'!A<F%M(&EN
M="`@("`D=&EM96]U="`@(&AO=R!M86YY('-E8V]N9',@=&\@=V%I="!F;W(@
M=&AE(')E<75E<W0*("`@("`J"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@86X@
M6$U,7U)00U]297-P;VYS92!O8FIE8W0N("`P(&ES(')E='5R;F5D(&EF(&%N
M>0H@("`@("H@("`@("`@("`@("`@("`@("!P<F]B;&5M<R!H87!P96XN"B`@
M("`@*@H@("`@("H@0'-E92!834Q?4E!#7TUE<W-A9V4L(%A-3%]24$-?0VQI
M96YT.CI834Q?4E!#7T-L:65N="@I+`H@("`@("H@("`@("!834Q?4E!#7T-L
M:65N=#HZ<V5T0W)E9&5N=&EA;',H*0H@("`@("HO"B`@("!F=6YC=&EO;B!S
M96YD*"1M<V<L("1T:6UE;W5T(#T@,"D*("`@('L*("`@("`@("!I9B`H(6ES
M7V$H)&US9RP@)UA-3%]24$-?365S<V%G92<I*2!["B`@("`@("`@("`@("1T
M:&ES+3YE<G)S='(@/2`G<V5N9"@I7"=S("1M<V<@<&%R86UE=&5R(&UU<W0@
M8F4@86XG"B`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G(%A-3%]24$-?
M365S<V%G92!O8FIE8W0N)SL*("`@("`@("`@("`@)'1H:7,M/G)A:7-E17)R
M;W(H)'1H:7,M/F5R<G-T<BP@6$U,7U)00U]%4E)/4E]04D]'4D%-34E.1RD[
M"B`@("`@("`@("`@(')E='5R;B`P.PH@("`@("`@('T*("`@("`@("`D;7-G
M+3YD96)U9R`]("1T:&ES+3YD96)U9SL*("`@("`@("!R971U<FX@)'1H:7,M
M/G-E;F1087EL;V%D2%144#$P*"1M<V<L("1T:&ES+3YS97)V97(L("1T:&ES
M+3YP;W)T+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1I;65O=70L("1T:&ES+3YU<V5R;F%M92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YP87-S=V]R9"D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!4<F%N<VUI="!T:&4@4E!#(')E<75E<W0@
M=FEA($A45%`@,2XP('!R;W1O8V]L"B`@("`@*@H@("`@("H@4F5Q=65S=',@
M<VAO=6QD(&)E('-E;G0@=7-I;F<@6$U,7U)00U]#;&EE;G0@<V5N9"@I(')A
M=&AE<B!T:&%N"B`@("`@*B!C86QL:6YG('1H:7,@;65T:&]D(&1I<F5C=&QY
M+@H@("`@("H*("`@("`J($!P87)A;2!O8FIE8W0@)&US9R`@("`@("!T:&4@
M6$U,7U)00U]-97-S86=E(&]B:F5C=`H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<V5R=F5R("`@('1H92!S97)V97(@=&\@<V5N9"!T:&4@<F5Q=65S="!T;PH@
M("`@("H@0'!A<F%M(&EN="`@("`D<&]R="`@("`@('1H92!S97)V97(@<&]R
M="!S96YD('1H92!R97%U97-T('1O"B`@("`@*B!`<&%R86T@:6YT("`@("1T
M:6UE;W5T("`@:&]W(&UA;GD@<V5C;VYD<R!T;R!W86ET(&9O<B!T:&4@<F5Q
M=65S=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!B969O<F4@
M9VEV:6YG('5P"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R;F%M92`@82!U
M<V5R(&YA;64@9F]R(&%C8V5S<VEN9R!T:&4@4E!#('-E<G9E<@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<&%S<W=O<F0@(&$@<&%S<W=O<F0@9F]R(&%C8V5S
M<VEN9R!T:&4@4E!#('-E<G9E<@H@("`@("H*("`@("`J($!R971U<FX@;V)J
M96-T("!A;B!834Q?4E!#7U)E<W!O;G-E(&]B:F5C="X@(#`@:7,@<F5T=7)N
M960@:68@86YY"B`@("`@*B`@("`@("`@("`@("`@("`@('!R;V)L96US(&AA
M<'!E;BX*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@("H@
M0'-E92!834Q?4E!#7T-L:65N=#HZ<V5N9"@I"B`@("`@*B\*("`@(&9U;F-T
M:6]N('-E;F1087EL;V%D2%144#$P*"1M<V<L("1S97)V97(L("1P;W)T+"`D
M=&EM96]U="`](#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=7-E<FYA;64@/2`G)RP@)'!A<W-W;W)D(#T@)R<I"B`@("!["B`@("`@("`@
M+RH*("`@("`@("`@*B!)9B!W92=R92!U<VEN9R!A('!R;WAY(&]P96X@82!S
M;V-K970@=&\@=&AE('!R;WAY('-E<G9E<@H@("`@("`@("`J(&EN<W1E860@
M=&\@=&AE('AM;"UR<&,@<V5R=F5R"B`@("`@("`@("HO"B`@("`@("`@:68@
M*"1T:&ES+3YP<F]X>2D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/G!R;WAY
M7W!R;W1O8V]L(#T]("=H='1P.B\O)RD@>PH@("`@("`@("`@("`@("`@)'!R
M;W1O8V]L(#T@)R<["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D<')O=&]C;VP@/2`D=&AI<RT^<')O>'E?<')O=&]C;VP["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@:68@*"1T:6UE;W5T(#X@,"D@>PH@("`@
M("`@("`@("`@("`@)&9P(#T@0&9S;V-K;W!E;B@D<')O=&]C;VP@+B`D=&AI
M<RT^<')O>'DL("1T:&ES+3YP<F]X>5]P;W)T+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^97)R;F\L("1T:&ES+3YE<G)S='(L
M("1T:6UE;W5T*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1F<"`]($!F<V]C:V]P96XH)'!R;W1O8V]L("X@)'1H:7,M/G!R;WAY
M+"`D=&AI<RT^<')O>'E?<&]R="P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/F5R<FYO+"`D=&AI<RT^97)R<W1R*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@D=&AI
M<RT^<')O=&]C;VP@/3T@)VAT='`Z+R\G*2!["B`@("`@("`@("`@("`@("`D
M<')O=&]C;VP@/2`G)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1P<F]T;V-O;"`]("1T:&ES+3YP<F]T;V-O;#L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!I9B`H)'1I;65O=70@/B`P*2!["B`@("`@("`@
M("`@("`@("`D9G`@/2!`9G-O8VMO<&5N*"1P<F]T;V-O;"`N("1S97)V97(L
M("1P;W)T+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^97)R;F\L("1T:&ES+3YE<G)S='(L("1T:6UE;W5T*3L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1F<"`]($!F<V]C:V]P96XH
M)'!R;W1O8V]L("X@)'-E<G9E<BP@)'!O<G0L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YE<G)N;RP@)'1H:7,M/F5R<G-T<BD[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J"B`@("`@("`@
M("H@2G5S="!R86ES:6YG('1H92!E<G)O<B!W:71H;W5T(')E='5R;FEN9R!I
M="!I<R!S=')A;F=E+`H@("`@("`@("`J(&)U="!K965P(&ET(&AE<F4@9F]R
M(&)A8VMW87)D<R!C;VUP871I8FEL:71Y+@H@("`@("`@("`J+PH@("`@("`@
M(&EF("@A)&9P("8F("1T:&ES+3YP<F]X>2D@>PH@("`@("`@("`@("`D=&AI
M<RT^<F%I<V5%<G)O<B@G0V]N;F5C=&EO;B!T;R!P<F]X>2!S97)V97(@)PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("1T:&ES+3YP<F]X>2`N
M("<Z)R`N("1T:&ES+3YP<F]X>5]P;W)T"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("X@)R!F86EL960N("<@+B`D=&AI<RT^97)R<W1R+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4E!#7T524D]27T-/3DY%
M0U1)3TY?1D%)3$5$*3L*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@
M?2!E;'-E:68@*"$D9G`I('L*("`@("`@("`@("`@)'1H:7,M/G)A:7-E17)R
M;W(H)T-O;FYE8W1I;VX@=&\@4E!#('-E<G9E<B`G"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("X@)'-E<G9E<B`N("<Z)R`N("1P;W)T"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("X@)R!F86EL960N("<@+B`D=&AI
M<RT^97)R<W1R+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!834Q?
M4E!#7T524D]27T-/3DY%0U1)3TY?1D%)3$5$*3L*("`@("`@("`@("`@<F5T
M=7)N(#`["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1I;65O=70I('L*("`@
M("`@("`@("`@+RH*("`@("`@("`@("`@("H@57-I;F<@<V]C:V5T7W-E=%]T
M:6UE;W5T*"D@8F5C875S92!S=')E86U?<V5T7W1I;65O=70H*0H@("`@("`@
M("`@("`@*B!W87,@:6YT<F]D=6-E9"!I;B`T+C,N,"P@8G5T('=E(&YE960@
M=&\@<W5P<&]R="`T+C(N,"X*("`@("`@("`@("`@("HO"B`@("`@("`@("`@
M('-O8VME=%]S971?=&EM96]U="@D9G`L("1T:6UE;W5T*3L*("`@("`@("!]
M"@H@("`@("`@("\O(%!R92UE;7!T:79E($)#(&AA8VMS(&9O<B!F;V]L<R!C
M86QL:6YG('-E;F1087EL;V%D2%144#$P*"D@9&ER96-T;'D*("`@("`@("!I
M9B`H)'5S97)N86UE("$]("1T:&ES+3YU<V5R;F%M92D@>PH@("`@("`@("`@
M("`D=&AI<RT^<V5T0W)E9&5N=&EA;',H)'5S97)N86UE+"`D<&%S<W=O<F0I
M.PH@("`@("`@('T*"B`@("`@("`@+R\@3VYL>2!C<F5A=&4@=&AE('!A>6QO
M860@:68@:70@=V%S(&YO="!C<F5A=&5D('!R979I;W5S;'D*("`@("`@("!I
M9B`H96UP='DH)&US9RT^<&%Y;&]A9"DI('L*("`@("`@("`@("`@)&US9RT^
M8W)E871E4&%Y;&]A9"@I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^8W)E
M871E2&5A9&5R<R@D;7-G*3L*"B`@("`@("`@)&]P("`]("1T:&ES+3YH96%D
M97)S("X@(EQR7&Y<<EQN(CL*("`@("`@("`D;W`@+CT@)&US9RT^<&%Y;&]A
M9#L*"B`@("`@("`@:68@*"%F<'5T<R@D9G`L("1O<"P@<W1R;&5N*"1O<"DI
M*2!["B`@("`@("`@("`@("1T:&ES+3YE<G)S='(@/2`G5W)I=&4@97)R;W(G
M.PH@("`@("`@("`@("!R971U<FX@,#L*("`@("`@("!]"B`@("`@("`@)')E
M<W`@/2`D;7-G+3YP87)S95)E<W!O;G-E1FEL92@D9G`I.PH*("`@("`@("`D
M;65T82`]('-O8VME=%]G971?<W1A='5S*"1F<"D["B`@("`@("`@:68@*"1M
M971A6R=T:6UE9%]O=70G72D@>PH@("`@("`@("`@("!F8VQO<V4H)&9P*3L*
M("`@("`@("`@("`@)'1H:7,M/F5R<G-T<B`]("=24$,@<V5R=F5R(&1I9"!N
M;W0@<V5N9"!R97-P;VYS92!B969O<F4@=&EM96]U="XG.PH@("`@("`@("`@
M("`D=&AI<RT^<F%I<V5%<G)O<B@D=&AI<RT^97)R<W1R+"!834Q?4E!#7T52
M4D]27T-/3DY%0U1)3TY?1D%)3$5$*3L*("`@("`@("`@("`@<F5T=7)N(#`[
M"B`@("`@("`@?0H*("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@("!R971U
M<FX@)')E<W`["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S('1H
M92!(5%10(&AE861E<G,@86YD('!U=',@:70@:6X@=&AE("1H96%D97)S('!R
M;W!E<G1Y"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="`D;7-G("`@("`@
M('1H92!834Q?4E!#7TUE<W-A9V4@;V)J96-T"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!44E5%(&EF(&]K87DL($9!3%-%(&EF('1H92!M97-S
M86=E('!A>6QO860@:7-N)W0@<V5T+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')O=&5C=&5D"B`@("`@*B\*("`@(&9U;F-T:6]N(&-R96%T94AE861E<G,H
M)&US9RD*("`@('L*("`@("`@("!I9B`H96UP='DH)&US9RT^<&%Y;&]A9"DI
M('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@
M("!I9B`H)'1H:7,M/G!R;WAY*2!["B`@("`@("`@("`@("1T:&ES+3YH96%D
M97)S(#T@)U!/4U0@)R`N("1T:&ES+3YP<F]T;V-O;"`N("1T:&ES+3YS97)V
M97(["B`@("`@("`@("`@(&EF("@D=&AI<RT^<')O>'E?<&]R="D@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/FAE861E<G,@+CT@)SHG("X@)'1H:7,M/G!O
M<G0["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("1T:&ES+3YH96%D97)S(#T@)U!/4U0@)SL*("`@("`@("!]"B`@("`@("`@
M)'1H:7,M/FAE861E<G,@+CT@)'1H:7,M/G!A=&@N("(@2%144"\Q+C!<<EQN
M(CL*"B`@("`@("`@)'1H:7,M/FAE861E<G,@+CT@(E5S97(M06=E;G0Z(%!%
M05(@6$U,7U)00UQR7&XB.PH@("`@("`@("1T:&ES+3YH96%D97)S("X]("=(
M;W-T.B`G("X@)'1H:7,M/G-E<G9E<B`N(")<<EQN(CL*"B`@("`@("`@:68@
M*"1T:&ES+3YP<F]X>2`F)B`D=&AI<RT^<')O>'E?=7-E<BD@>PH@("`@("`@
M("`@("`D=&AI<RT^:&5A9&5R<R`N/2`G4')O>'DM075T:&]R:7IA=&EO;CH@
M0F%S:6,@)PH@("`@("`@("`@("`@("`@("`@("`N(&)A<V4V-%]E;F-O9&4H
M(B1T:&ES+3YP<F]X>5]U<V5R.B1T:&ES+3YP<F]X>5]P87-S(BD*("`@("`@
M("`@("`@("`@("`@("`@+B`B7')<;B(["B`@("`@("`@?0H*("`@("`@("`O
M+R!T:&%N:W,@=&\@1W)A;G0@4F%U<V-H97(@/&=R86YT-T!F:7)S='=O<FQD
M+FYE=#X@9F]R('1H:7,*("`@("`@("!I9B`H)'1H:7,M/G5S97)N86UE*2![
M"B`@("`@("`@("`@("1T:&ES+3YH96%D97)S("X]("=!=71H;W)I>F%T:6]N
M.B!"87-I8R`G"B`@("`@("`@("`@("`@("`@("`@("X@8F%S938T7V5N8V]D
M92@B)'1H:7,M/G5S97)N86UE.B1T:&ES+3YP87-S=V]R9"(I"B`@("`@("`@
M("`@("`@("`@("`@("X@(EQR7&XB.PH@("`@("`@('T*"B`@("`@("`@)'1H
M:7,M/FAE861E<G,@+CT@(D-O;G1E;G0M5'EP93H@=&5X="]X;6Q<<EQN(CL*
M("`@("`@("`D=&AI<RT^:&5A9&5R<R`N/2`G0V]N=&5N="U,96YG=&@Z("<@
M+B!S=')L96XH)&US9RT^<&%Y;&]A9"D["B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"GT*"B\J*@H@*B!4:&4@;65T:&]D<R!A;F0@<')O<&5R=&EE<R!F
M;W(@:6YT97)P<F5T:6YG(')E<W!O;G-E<R!T;R!834P@4E!#(')E<75E<W1S
M"B`J"B`J($!C871E9V]R>2`@(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G92`@
M("!834Q?4E!#"B`J($!A=71H;W(@("`@($5D9"!$=6UB:6QL(#QE9&1`=7-E
M9G5L:6YC+F-O;3X*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-T:6=`
M<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@36%R=&EN($IA;G-E;B`\;6I`<&AP
M+FYE=#X*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L
M8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DY+3(P,#$@161D($1U;6)I
M;&PL(#(P,#$M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!V97)S:6]N("`@(%)E
M;&5A<V4Z(#$N-"XX"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN
M970O<&%C:V%G92]834Q?4E!#"B`J+PIC;&%S<R!834Q?4E!#7U)E<W!O;G-E
M(&5X=&5N9',@6$U,7U)00U]"87-E"GL*("`@('9A<B`D>'8["B`@("!V87(@
M)&9N.PH@("`@=F%R("1F<SL*("`@('9A<B`D:&1R<SL*"B`@("`O*BH*("`@
M("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!834Q?4E!#
M7U)E<W!O;G-E*"1V86PL("1F8V]D92`](#`L("1F<W1R(#T@)R<I"B`@("![
M"B`@("`@("`@:68@*"1F8V]D92`A/2`P*2!["B`@("`@("`@("`@("1T:&ES
M+3YF;B`]("1F8V]D93L*("`@("`@("`@("`@)'1H:7,M/F9S(#T@:'1M;'-P
M96-I86QC:&%R<R@D9G-T<BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'1H:7,M/GAV(#T@)'9A;#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&5R<F]R(&-O9&4*("`@("`J+PH@
M("`@9G5N8W1I;VX@9F%U;'1#;V1E*"D*("`@('L*("`@("`@("!I9B`H:7-S
M970H)'1H:7,M/F9N*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F9N
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`P.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($!R971U<FX@<W1R:6YG("!T
M:&4@97)R;W(@<W1R:6YG"B`@("`@*B\*("`@(&9U;F-T:6]N(&9A=6QT4W1R
M:6YG*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F9S.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0')E='5R;B!M:7AE9"`@=&AE('9A;'5E"B`@("`@
M*B\*("`@(&9U;F-T:6]N('9A;'5E*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/GAV.PH@("`@?0H*("`@("\J*@H@("`@("H@0')E='5R;B!S=')I
M;F<@('1H92!E<G)O<B!M97-S86=E(&EN(%A-3"!F;W)M870*("`@("`J+PH@
M("`@9G5N8W1I;VX@<V5R:6%L:7IE*"D*("`@('L*("`@("`@("`D<G,@/2`B
M/&UE=&AO9%)E<W!O;G-E/EQN(CL*("`@("`@("!I9B`H)'1H:7,M/F9N*2![
M"B`@("`@("`@("`@("1R<R`N/2`B/&9A=6QT/@H@(#QV86QU93X*("`@(#QS
M=')U8W0^"B`@("`@(#QM96UB97(^"B`@("`@("`@/&YA;64^9F%U;'1#;V1E
M/"]N86UE/@H@("`@("`@(#QV86QU93X\:6YT/B(@+B`D=&AI<RT^9FX@+B`B
M/"]I;G0^/"]V86QU93X*("`@("`@/"]M96UB97(^"B`@("`@(#QM96UB97(^
M"B`@("`@("`@/&YA;64^9F%U;'13=')I;F<\+VYA;64^"B`@("`@("`@/'9A
M;'5E/CQS=')I;F<^(B`N("1T:&ES+3YF<R`N("(\+W-T<FEN9SX\+W9A;'5E
M/@H@("`@("`\+VUE;6)E<CX*("`@(#PO<W1R=6-T/@H@(#PO=F%L=64^"CPO
M9F%U;'0^(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<G,@+CT@
M(CQP87)A;7,^7&X\<&%R86T^7&XB("X@)'1H:7,M/GAV+3YS97)I86QI>F4H
M*2`N"B`@("`@("`@(CPO<&%R86T^7&X\+W!A<F%M<SXB.PH@("`@("`@('T*
M("`@("`@("`D<G,@+CT@(EQN/"]M971H;V1297-P;VYS93XB.PH@("`@("`@
M(')E='5R;B`D<G,["B`@("!]"GT*"B\J*@H@*B!4:&4@;65T:&]D<R!A;F0@
M<')O<&5R=&EE<R!F;W(@8V]M<&]S:6YG(%A-3"!24$,@;65S<V%G97,*("H*
M("H@0&-A=&5G;W)Y("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E("`@(%A-
M3%]24$,*("H@0&%U=&AO<B`@("`@161D($1U;6)I;&P@/&5D9$!U<V5F=6QI
M;F,N8V]M/@H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W1I9T!P:'`N
M;F5T/@H@*B!`875T:&]R("`@("!-87)T:6X@2F%N<V5N(#QM:D!P:'`N;F5T
M/@H@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H
M<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3DM,C`P,2!%9&0@1'5M8FEL;"P@
M,C`P,2TR,#`U(%1H92!02%`@1W)O=7`*("H@0'9E<G-I;VX@("`@4F5L96%S
M93H@,2XT+C@*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P
M86-K86=E+UA-3%]24$,*("HO"F-L87-S(%A-3%]24$-?365S<V%G92!E>'1E
M;F1S(%A-3%]24$-?0F%S90I["B`@("`O*BH*("`@("`J(%1H92!C=7)R96YT
M(&1E8G5G(&UO9&4@*#$@/2!O;BP@,"`](&]F9BD*("`@("`J($!V87(@:6YT
M96=E<@H@("`@("HO"B`@("!V87(@)&1E8G5G(#T@,#L*"B`@("`O*BH*("`@
M("`J(%1H92!E;F-O9&EN9R!T;R!B92!U<V5D(&9O<B!O=71G;VEN9R!M97-S
M86=E<PH@("`@("H*("`@("`J($1E9F%U;'1S('1O('1H92!V86QU92!O9B`\
M=F%R/B1'3$]"04Q36R=834Q?4E!#7V1E9F5N8V]D:6YG)UT\+W9A<CX*("`@
M("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("H@0'-E92!834Q?4E!#7TUE
M<W-A9V4Z.G-E=%-E;F1%;F-O9&EN9R@I+`H@("`@("H@("`@("`D1TQ/0D%,
M4ULG6$U,7U)00U]D969E;F-O9&EN9R==+"!834Q?4E!#7TUE<W-A9V4Z.GAM
M;%]H96%D97(H*0H@("`@("HO"B`@("!V87(@)'-E;F1?96YC;V1I;F<@/2`G
M)SL*"B`@("`O*BH*("`@("`J(%1H92!M971H;V0@<')E<V5N=&QY(&)E:6YG
M(&5V86QU871E9`H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1M971H;V1N86UE(#T@)R<["@H@("`@+RHJ"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*B\*("`@('9A<B`D<&%R86US(#T@87)R87DH*3L*"B`@("`O*BH*
M("`@("`J(%1H92!834P@;65S<V%G92!B96EN9R!G96YE<F%T960*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D<&%Y;&]A9"`]("<G.PH*
M("`@("\J*@H@("`@("H@4VAO=6QD(&5X=')A(&QI;F4@8G)E86MS(&)E(')E
M;6]V960@9G)O;2!T:&4@<&%Y;&]A9#\*("`@("`J($!S:6YC92!0<F]P97)T
M>2!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N-@H@("`@("H@0'9A<B!B
M;V]L96%N"B`@("`@*B\*("`@('9A<B`D<F5M;W9E7V5X=')A7VQI;F5S(#T@
M=')U93L*"B`@("`O*BH*("`@("`J(%1H92!834P@<F5S<&]N<V4@9G)O;2!T
M:&4@<F5M;W1E('-E<G9E<@H@("`@("H@0'-I;F-E(%!R;W!E<G1Y(&%V86EL
M86)L92!S:6YC92!296QE87-E(#$N-"XV"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("HO"B`@("!V87(@)')E<W!O;G-E7W!A>6QO860@/2`G)SL*"@H@("`@
M+RHJ"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@
M6$U,7U)00U]-97-S86=E*"1M971H+"`D<&%R<R`](#`I"B`@("!["B`@("`@
M("`@)'1H:7,M/FUE=&AO9&YA;64@/2`D;65T:#L*("`@("`@("!I9B`H:7-?
M87)R87DH)'!A<G,I("8F('-I>F5O9B@D<&%R<RD@/B`P*2!["B`@("`@("`@
M("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D<&%R<RD[("1I*RLI('L*
M("`@("`@("`@("`@("`@("1T:&ES+3YA9&1087)A;2@D<&%R<ULD:5TI.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M4')O9'5C97,@=&AE(%A-3"!D96-L87)A=&EO;B!I;F-L=61I;F<@=&AE(&5N
M8V]D:6YG(&%T=')I8G5T90H@("`@("H*("`@("`J(%1H92!E;F-O9&EN9R!I
M<R!D971E<FUI;F5D(&)Y('1H:7,@8VQA<W,G(#QV87(^)'-E;F1?96YC;V1I
M;F<\+W9A<CX*("`@("`J('!R;W!E<G1Y+B`@268@=&AE(#QV87(^)'-E;F1?
M96YC;V1I;F<\+W9A<CX@<')O<&5R='D@:7,@;F]T('-E="P@=7-E"B`@("`@
M*B`\=F%R/B1'3$]"04Q36R=834Q?4E!#7V1E9F5N8V]D:6YG)UT\+W9A<CXN
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!834P@9&5C;&%R
M871I;VX@86YD(#QM971H;V1#86QL/B!E;&5M96YT"B`@("`@*@H@("`@("H@
M0'-E92!834Q?4E!#7TUE<W-A9V4Z.G-E=%-E;F1%;F-O9&EN9R@I+`H@("`@
M("H@("`@("!834Q?4E!#7TUE<W-A9V4Z.B1S96YD7V5N8V]D:6YG+"`D1TQ/
M0D%,4ULG6$U,7U)00U]D969E;F-O9&EN9R=="B`@("`@*B\*("`@(&9U;F-T
M:6]N('AM;%]H96%D97(H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D6$U,7U)0
M0U]D969E;F-O9&EN9SL*"B`@("`@("`@:68@*"$D=&AI<RT^<V5N9%]E;F-O
M9&EN9RD@>PH@("`@("`@("`@("`D=&AI<RT^<V5N9%]E;F-O9&EN9R`]("18
M34Q?4E!#7V1E9F5N8V]D:6YG.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M)SP_>&UL('9E<G-I;VX](C$N,"(@96YC;V1I;F<](B<@+B`D=&AI<RT^<V5N
M9%]E;F-O9&EN9R`N("<B/SXG"B`@("`@("`@("`@("`@("X@(EQN/&UE=&AO
M9$-A;&P^7&XB.PH@("`@?0H*("`@("\J*@H@("`@("H@0')E='5R;B!S=')I
M;F<@('1H92!C;&]S:6YG(#PO;65T:&]D0V%L;#X@=&%G"B`@("`@*B\*("`@
M(&9U;F-T:6]N('AM;%]F;V]T97(H*0H@("`@>PH@("`@("`@(')E='5R;B`B
M/"]M971H;V1#86QL/EQN(CL*("`@('T*"B`@("`O*BH*("`@("`J($9I;&QS
M('1H92!834Q?4E!#7TUE<W-A9V4Z.B1P87EL;V%D('!R;W!E<G1Y"B`@("`@
M*@H@("`@("H@4&%R="!O9B!T:&4@<')O8V5S<R!M86ME<R!S=7)E(&%L;"!L
M:6YE(&5N9&EN9W,@87)E(&EN($1/4R!F;W)M870*("`@("`J("A#4DQ&*2P@
M=VAI8V@@:7,@<')O8F%B;'D@<F5Q=6ER960@8GD@<W!E8VEF:6-A=&EO;G,N
M"B`@("`@*@H@("`@("H@0')E='5R;B!V;VED"B`@("`@*@H@("`@("H@0'5S
M97,@6$U,7U)00U]-97-S86=E.CIX;6Q?:&5A9&5R*"DL(%A-3%]24$-?365S
M<V%G93HZ>&UL7V9O;W1E<B@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&-R96%T
M95!A>6QO860H*0H@("`@>PH@("`@("`@("1T:&ES+3YP87EL;V%D(#T@)'1H
M:7,M/GAM;%]H96%D97(H*3L*("`@("`@("`D=&AI<RT^<&%Y;&]A9"`N/2`G
M/&UE=&AO9$YA;64^)R`N("1T:&ES+3YM971H;V1N86UE("X@(CPO;65T:&]D
M3F%M93Y<;B(["B`@("`@("`@)'1H:7,M/G!A>6QO860@+CT@(CQP87)A;7,^
M7&XB.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D=&AI<RT^
M<&%R86US*3L@)&DK*RD@>PH@("`@("`@("`@("`D<"`]("1T:&ES+3YP87)A
M;7-;)&E=.PH@("`@("`@("`@("`D=&AI<RT^<&%Y;&]A9"`N/2`B/'!A<F%M
M/EQN(B`N("1P+3YS97)I86QI>F4H*2`N("(\+W!A<F%M/EQN(CL*("`@("`@
M("!]"B`@("`@("`@)'1H:7,M/G!A>6QO860@+CT@(CPO<&%R86US/EQN(CL*
M("`@("`@("`D=&AI<RT^<&%Y;&]A9"`N/2`D=&AI<RT^>&UL7V9O;W1E<B@I
M.PH@("`@("`@(&EF("@D=&AI<RT^<F5M;W9E7V5X=')A7VQI;F5S*2!["B`@
M("`@("`@("`@("1T:&ES+3YP87EL;V%D(#T@97)E9U]R97!L86-E*");7')<
M;ETK(BP@(EQR7&XB+"`D=&AI<RT^<&%Y;&]A9"D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'1H:7,M/G!A>6QO860@/2!E<F5G7W)E<&QA8V4H
M(EQR7&Y\7&Y\7')\7&Y<<B(L(")<<EQN(BP@)'1H:7,M/G!A>6QO860I.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($!R971U<FX@<W1R:6YG
M("!T:&4@;F%M92!O9B!T:&4@;65T:&]D"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&UE=&AO9"@D;65T:"`]("<G*0H@("`@>PH@("`@("`@(&EF("@D;65T:"`A
M/2`G)RD@>PH@("`@("`@("`@("`D=&AI<RT^;65T:&]D;F%M92`]("1M971H
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/FUE=&AO9&YA;64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE('!A
M>6QO860*("`@("`J+PH@("`@9G5N8W1I;VX@<V5R:6%L:7IE*"D*("`@('L*
M("`@("`@("`D=&AI<RT^8W)E871E4&%Y;&]A9"@I.PH@("`@("`@(')E='5R
M;B`D=&AI<RT^<&%Y;&]A9#L*("`@('T*"B`@("`O*BH*("`@("`J($!R971U
M<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1087)A;2@D<&%R*0H@
M("`@>PH@("`@("`@("1T:&ES+3YP87)A;7-;72`]("1P87(["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!/8G1A:6YS(&%N(%A-3%]24$-?5F%L=64@;V)J96-T
M(&9O<B!T:&4@9VEV96X@<&%R86UE=&5R"B`@("`@*@H@("`@("H@0'!A<F%M
M(&EN="`D:2`@=&AE(&EN9&5X(&YU;6)E<B!O9B!T:&4@<&%R86UE=&5R('1O
M(&]B=&%I;@H@("`@("H*("`@("`J($!R971U<FX@;V)J96-T("!T:&4@6$U,
M7U)00U]686QU92!O8FIE8W0N"B`@("`@*B`@("`@("`@("`@("`@("`@($EF
M('1H92!P87)A;65T97(@9&]E<VXG="!E>&ES="P@86X@6$U,7U)00U]297-P
M;VYS92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'-I;F-E(%)E='5R;G,@6$U,
M7U)00U]297-P;VYS92!O8FIE8W0@;VX@97)R;W(@<VEN8V4@4F5L96%S92`Q
M+C,N,`H@("`@("HO"B`@("!F=6YC=&EO;B!G971087)A;2@D:2D*("`@('L*
M("`@("`@("!G;&]B86P@)%A-3%]24$-?97)R+"`D6$U,7U)00U]S='(["@H@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^<&%R86US6R1I72DI('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YP87)A;7-;)&E=.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1T:&ES+3YR86ES945R<F]R*"=4:&4@<W5B;6ET
M=&5D(')E<75E<W0@9&ED(&YO="!C;VYT86EN('1H:7,@<&%R86UE=&5R)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U)00U]%4E)/4E])
M3D-/4E)%0U1?4$%204U3*3L*("`@("`@("`@("`@<F5T=7)N(&YE=R!834Q?
M4E!#7U)E<W!O;G-E*#`L("1834Q?4E!#7V5R<ELG:6YC;W)R96-T7W!A<F%M
M<R==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)%A-3%]24$-?<W1R6R=I;F-O<G)E8W1?<&%R86US)UTI.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($!R971U<FX@:6YT("!T:&4@;G5M8F5R
M(&]F('!A<F%M971E<G,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3G5M4&%R
M86US*"D*("`@('L*("`@("`@("!R971U<FX@<VEZ96]F*"1T:&ES+3YP87)A
M;7,I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@6$U,(&1E8VQA
M<F%T:6]N)W,@96YC;V1I;F<@871T<FEB=71E"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D='EP92`@=&AE(&5N8V]D:6YG('1Y<&4@*$E33RTX.#4Y
M+3$L(%541BTX(&]R(%53+4%30TE)*0H@("`@("H*("`@("`J($!R971U<FX@
M=F]I9`H@("`@("H*("`@("`J($!S964@6$U,7U)00U]-97-S86=E.CHD<V5N
M9%]E;F-O9&EN9RP@6$U,7U)00U]-97-S86=E.CIX;6Q?:&5A9&5R*"D*("`@
M("`J($!S:6YC92!-971H;V0@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XR
M+C`*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T4V5N9$5N8V]D:6YG*"1T>7!E
M*0H@("`@>PH@("`@("`@("1T:&ES+3YS96YD7V5N8V]D:6YG(#T@)'1Y<&4[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F4@=&AE(%A-3"=S(&5N
M8V]D:6YG('9I82!T:&4@96YC;V1I;F<@871T<FEB=71E"B`@("`@*B!I;B!T
M:&4@6$U,(&1E8VQA<F%T:6]N"B`@("`@*@H@("`@("H@268@=&AE(&5N8V]D
M:6YG('!A<F%M971E<B!I<R!N;W0@<V5T(&]R(&ES(&YO="!)4T\M.#@U.2TQ
M+"!55$8M.`H@("`@("H@;W(@55,M05-#24DL("1834Q?4E!#7V1E9F5N8V]D
M:6YG('=I;&P@8F4@<F5T=7)N960N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9&%T82`@=&AE(%A-3"!T:&%T('=I;&P@8F4@<&%R<V5D"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!E;F-O9&EN9R!T;R!B92!U
M<V5D"B`@("`@*@H@("`@("H@0&QI;FL@("!H='1P.B\O<&AP+FYE="]X;6Q?
M<&%R<V5R7V-R96%T90H@("`@("H@0'-I;F-E("!-971H;V0@879A:6QA8FQE
M('-I;F-E(%)E;&5A<V4@,2XR+C`*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M16YC;V1I;F<H)&1A=&$I"B`@("!["B`@("`@("`@9VQO8F%L("1834Q?4E!#
M7V1E9F5N8V]D:6YG.PH*("`@("`@("!I9B`H<')E9U]M871C:"@G+SQ</WAM
M;%M>/ETJ7',J96YC;V1I;F=<<RH]7',J6UPG(ETH6UXB7"==*BE;7"<B72]I
M)RP*("`@("`@("`@("`@("`@("`@("`@("`D9&%T82P@)&UA=&-H*2D*("`@
M("`@("!["B`@("`@("`@("`@("1M871C:%LQ72`]('1R:6TH<W1R=&]U<'!E
M<B@D;6%T8VA;,5TI*3L*("`@("`@("`@("`@<W=I=&-H("@D;6%T8VA;,5TI
M('L*("`@("`@("`@("`@("`@(&-A<V4@)TE33RTX.#4Y+3$G.@H@("`@("`@
M("`@("`@("`@8V%S92`G551&+3@G.@H@("`@("`@("`@("`@("`@8V%S92`G
M55,M05-#24DG.@H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D;6%T8VA;
M,5T["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@
M("`@9&5F875L=#H*("`@("`@("`@("`@("`@("`@("!R971U<FX@)%A-3%]2
M4$-?9&5F96YC;V1I;F<["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@)%A-3%]24$-?9&5F96YC;V1I;F<["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0')E='5R;B!O8FIE8W0@
M(&$@;F5W(%A-3%]24$-?4F5S<&]N<V4@;V)J96-T"B`@("`@*B\*("`@(&9U
M;F-T:6]N('!A<G-E4F5S<&]N<V5&:6QE*"1F<"D*("`@('L*("`@("`@("`D
M:7!D(#T@)R<["B`@("`@("`@=VAI;&4@*"1D871A(#T@0&9R96%D*"1F<"P@
M.#$Y,BDI('L*("`@("`@("`@("`@)&EP9"`N/2`D9&%T83L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YP87)S95)E<W!O;G-E*"1I<&0I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0')E='5R;B!O8FIE8W0@(&$@;F5W(%A-
M3%]24$-?4F5S<&]N<V4@;V)J96-T"B`@("`@*B\*("`@(&9U;F-T:6]N('!A
M<G-E4F5S<&]N<V4H)&1A=&$@/2`G)RD*("`@('L*("`@("`@("!G;&]B86P@
M)%A-3%]24$-?>&@L("1834Q?4E!#7V5R<BP@)%A-3%]24$-?<W1R+"`D6$U,
M7U)00U]D969E;F-O9&EN9SL*"B`@("`@("`@)&5N8V]D:6YG(#T@)'1H:7,M
M/F=E=$5N8V]D:6YG*"1D871A*3L*("`@("`@("`D<&%R<V5R7W)E<V]U<F-E
M(#T@>&UL7W!A<G-E<E]C<F5A=&4H)&5N8V]D:6YG*3L*("`@("`@("`D<&%R
M<V5R(#T@*&EN="D@)'!A<G-E<E]R97-O=7)C93L*"B`@("`@("`@)%A-3%]2
M4$-?>&@@/2!A<G)A>2@I.PH@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=
M(#T@87)R87DH*3L*"B`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)V-M
M)UT@/2`P.PH@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=I<V8G72`]
M(#`["B`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)V%C)UT@/2`G)SL*
M("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG<70G72`]("<G.PH@("`@
M("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=S=&%C:R==(#T@87)R87DH*3L*
M("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG=F%L=65S=&%C:R==(#T@
M87)R87DH*3L*"B`@("`@("`@>&UL7W!A<G-E<E]S971?;W!T:6]N*"1P87)S
M97)?<F5S;W5R8V4L(%A-3%]/4%1)3TY?0T%315]&3TQ$24Y'+"!T<G5E*3L*
M("`@("`@("!X;6Q?<V5T7V5L96UE;G1?:&%N9&QE<B@D<&%R<V5R7W)E<V]U
M<F-E+"`G6$U,7U)00U]S92<L("=834Q?4E!#7V5E)RD["B`@("`@("`@>&UL
M7W-E=%]C:&%R86-T97)?9&%T85]H86YD;&5R*"1P87)S97)?<F5S;W5R8V4L
M("=834Q?4E!#7V-D)RD["@H@("`@("`@("1H9')F;F0@/2`P.PH@("`@("`@
M(&EF("@D=&AI<RT^9&5B=6<I('L*("`@("`@("`@("`@<')I;G0@(EQN/'!R
M93XM+2U'3U0M+2U<;B(["B`@("`@("`@("`@('!R:6YT(&ES<V5T*"1?4T52
M5D526R=315)615)?4%)/5$]#3TPG72D@/R!H=&UL<W!E8VEA;&-H87)S*"1D
M871A*2`Z("1D871A.PH@("`@("`@("`@("!P<FEN="`B7&XM+2U%3D0M+2T\
M+W!R93Y<;B(["B`@("`@("`@?0H*("`@("`@("`O+R!3964@:68@<F5S<&]N
M<V4@:7,@82`R,#`@;W(@82`Q,#`@=&AE;B!A(#(P,"P@96QS92!R86ES92!E
M<G)O<BX*("`@("`@("`O+R!"=70@;VYL>2!D;R!T:&ES(&EF('=E)W)E('5S
M:6YG('1H92!(5%10('!R;W1O8V]L+@H@("`@("`@(&EF("AE<F5G*"=>2%14
M4"<L("1D871A*2`F)@H@("`@("`@("`@("`A97)E9R@G7DA45%`O6S`M.5PN
M72L@,C`P("<L("1D871A*2`F)@H@("`@("`@("`@("`A<')E9U]M871C:"@G
M0%Y(5%10+ULP+3E<+ETK(#$P6S`M.5TH6T$M6F$M>B!=*RD_6UQR7&Y=*TA4
M5%`O6S`M.5PN72L@,C`P0"<L("1D871A*2D*("`@("`@("!["B`@("`@("`@
M("`@("`@("`D97)R<W1R(#T@<W5B<W1R*"1D871A+"`P+"!S=')P;W,H)&1A
M=&$L(")<;B(I("T@,2D["B`@("`@("`@("`@("`@("!E<G)O<E]L;V<H)TA4
M5%`@97)R;W(L(&=O="!R97-P;VYS93H@)R`N("1E<G)S='(I.PH@("`@("`@
M("`@("`@("`@)'(@/2!N97<@6$U,7U)00U]297-P;VYS92@P+"`D6$U,7U)0
M0U]E<G);)VAT='!?97)R;W(G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)%A-3%]24$-?<W1R6R=H='1P7V5R<F]R)UT@
M+B`G("@G("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&5R<G-T<B`N("<I)RD["B`@("`@("`@("`@("`@("!X;6Q?<&%R
M<V5R7V9R964H)'!A<G-E<E]R97-O=7)C92D["B`@("`@("`@("`@("`@("!R
M971U<FX@)'(["B`@("`@("`@?0H*("`@("`@("`O+R!G;W1T82!G970@<FED
M(&]F(&AE861E<G,@:&5R90H@("`@("`@(&EF("@A)&AD<F9N9"`F)B`H)&)R
M<&]S(#T@<W1R<&]S*"1D871A+")<<EQN7')<;B(I*2D@>PH@("`@("`@("`@
M("`D6$U,7U)00U]X:%LD<&%R<V5R75LG:&$G72`]('-U8G-T<B@D9&%T82P@
M,"P@)&)R<&]S*3L*("`@("`@("`@("`@)&1A=&$@/2!S=6)S='(H)&1A=&$L
M("1B<G!O<R`K(#0I.PH@("`@("`@("`@("`D:&1R9FYD(#T@,3L*("`@("`@
M("!]"@H@("`@("`@("\J"B`@("`@("`@("H@8F4@=&]L97)A;G0@;V8@:G5N
M:R!A9G1E<B!M971H;V1297-P;VYS90H@("`@("`@("`J("AE+F<N(&IA=F%S
M8W)I<'0@875T;VUA=&EC86QL>2!I;G-E<G1E9"!B>2!F<F5E(&AO<W1S*0H@
M("`@("`@("`J('1H86YK<R!T;R!,=6-A($UA<FEA;F\@/&QU8V$N;6%R:6%N
M;T!E;6%I;"YI=#X*("`@("`@("`@*B\*("`@("`@("`D9&%T82`]('-U8G-T
M<B@D9&%T82P@,"P@<W1R<&]S*"1D871A+"`B/"]M971H;V1297-P;VYS93XB
M*2`K(#$W*3L*("`@("`@("`D=&AI<RT^<F5S<&]N<V5?<&%Y;&]A9"`]("1D
M871A.PH*("`@("`@("!I9B`H(7AM;%]P87)S92@D<&%R<V5R7W)E<V]U<F-E
M+"`D9&%T82P@<VEZ96]F*"1D871A*2DI('L*("`@("`@("`@("`@+R\@=&AA
M;FMS('1O(%!E=&5R($MO8VMS(#QP971E<BYK;V-K<T!B87EG871E+F-O;3X*
M("`@("`@("`@("`@:68@*'AM;%]G971?8W5R<F5N=%]L:6YE7VYU;6)E<B@D
M<&%R<V5R7W)E<V]U<F-E*2`]/2`Q*2!["B`@("`@("`@("`@("`@("`D97)R
M<W1R(#T@)UA-3"!E<G)O<B!A="!L:6YE(#$L(&-H96-K(%523"<["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D97)R<W1R(#T@<W!R
M:6YT9B@G6$U,(&5R<F]R.B`E<R!A="!L:6YE("5D)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('AM;%]E<G)O<E]S=')I;F<H>&UL7V=E
M=%]E<G)O<E]C;V1E*"1P87)S97)?<F5S;W5R8V4I*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('AM;%]G971?8W5R<F5N=%]L:6YE7VYU
M;6)E<B@D<&%R<V5R7W)E<V]U<F-E*2D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@97)R;W)?;&]G*"1E<G)S='(I.PH@("`@("`@("`@("`D<B`](&YE
M=R!834Q?4E!#7U)E<W!O;G-E*#`L("1834Q?4E!#7V5R<ELG:6YV86QI9%]R
M971U<FXG72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D6$U,7U)00U]S=');)VEN=F%L:61?<F5T=7)N)UTI.PH@("`@("`@("`@
M("!X;6Q?<&%R<V5R7V9R964H)'!A<G-E<E]R97-O=7)C92D["B`@("`@("`@
M("`@(')E='5R;B`D<CL*("`@("`@("!]"@H@("`@("`@('AM;%]P87)S97)?
M9G)E92@D<&%R<V5R7W)E<V]U<F-E*3L*"B`@("`@("`@:68@*"1T:&ES+3YD
M96)U9RD@>PH@("`@("`@("`@("!P<FEN="`B7&X\<')E/BTM+5!!4E-%1"TM
M+5QN(CL*("`@("`@("`@("`@=F%R7V1U;7`H)%A-3%]24$-?>&A;)'!A<G-E
M<EU;)W9A;'5E)UTI.PH@("`@("`@("`@("!P<FEN="`B+2TM14Y$+2TM/"]P
M<F4^7&XB.PH@("`@("`@('T*"B`@("`@("`@:68@*"1834Q?4E!#7WAH6R1P
M87)S97)=6R=I<V8G72`^(#$I('L*("`@("`@("`@("`@)'(@/2!N97<@6$U,
M7U)00U]297-P;VYS92@P+"`D6$U,7U)00U]E<G);)VEN=F%L:61?<F5T=7)N
M)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)%A-
M3%]24$-?<W1R6R=I;G9A;&ED7W)E='5R;B==+B<@)RXD6$U,7U)00U]X:%LD
M<&%R<V5R75LG:7-F7W)E87-O;B==*3L*("`@("`@("!](&5L<V5I9B`H(6ES
M7V]B:F5C="@D6$U,7U)00U]X:%LD<&%R<V5R75LG=F%L=64G72DI('L*("`@
M("`@("`@("`@+R\@=&AE;B!S;VUE=&AI;F<@;V1D(&AA<R!H87!P96YE9`H@
M("`@("`@("`@("`O+R!A;F0@:70G<R!T:6UE('1O(&=E;F5R871E(&$@8VQI
M96YT('-I9&4@97)R;W(*("`@("`@("`@("`@+R\@:6YD:6-A=&EN9R!S;VUE
M=&AI;F<@;V1D('=E;G0@;VX*("`@("`@("`@("`@)'(@/2!N97<@6$U,7U)0
M0U]297-P;VYS92@P+"`D6$U,7U)00U]E<G);)VEN=F%L:61?<F5T=7)N)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)%A-3%]2
M4$-?<W1R6R=I;G9A;&ED7W)E='5R;B==*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D=B`]("1834Q?4E!#7WAH6R1P87)S97)=6R=V86QU92==
M.PH@("`@("`@("`@("`D86QL3TL],3L*("`@("`@("`@("`@:68@*"1834Q?
M4E!#7WAH6R1P87)S97)=6R=I<V8G72D@>PH@("`@("`@("`@("`@("`@)&8@
M/2`D=BT^<W1R=6-T;65M*"=F875L=$-O9&4G*3L*("`@("`@("`@("`@("`@
M("1F<R`]("1V+3YS=')U8W1M96TH)V9A=6QT4W1R:6YG)RD["B`@("`@("`@
M("`@("`@("`D<B`](&YE=R!834Q?4E!#7U)E<W!O;G-E*"1V+"`D9BT^<V-A
M;&%R=F%L*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1F<RT^<V-A;&%R=F%L*"DI.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)'(@/2!N97<@6$U,7U)00U]297-P;VYS92@D
M=BD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@)'(M/FAD<G,@
M/2!S<&QI="@B7'(_7&XB+"`D6$U,7U)00U]X:%LD<&%R<V5R75LG:&$G75LQ
M72D["B`@("`@("`@<F5T=7)N("1R.PH@("`@?0I]"@HO*BH*("H@5&AE(&UE
M=&AO9',@86YD('!R;W!E<G1I97,@=&AA="!R97!R97-E;G0@9&%T82!I;B!8
M34P@4E!#(&9O<FUA=`H@*@H@*B!`8V%T96=O<GD@("!796(@4V5R=FEC97,*
M("H@0'!A8VMA9V4@("`@6$U,7U)00PH@*B!`875T:&]R("`@("!%9&0@1'5M
M8FEL;"`\961D0'5S969U;&EN8RYC;VT^"B`J($!A=71H;W(@("`@(%-T:6<@
M0F%K:V5N(#QS=&EG0'!H<"YN970^"B`J($!A=71H;W(@("`@($UA<G1I;B!*
M86YS96X@/&UJ0'!H<"YN970^"B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV
M:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY.2TR
M,#`Q($5D9"!$=6UB:6QL+"`R,#`Q+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`
M=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.`H@*B!`;&EN:R`@("`@("!H='1P
M.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O6$U,7U)00PH@*B\*8VQA<W,@6$U,
M7U)00U]686QU92!E>'1E;F1S(%A-3%]24$-?0F%S90I["B`@("!V87(@)&UE
M(#T@87)R87DH*3L*("`@('9A<B`D;7ET>7!E(#T@,#L*"B`@("`O*BH*("`@
M("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!834Q?4E!#
M7U9A;'5E*"1V86P@/2`M,2P@)'1Y<&4@/2`G)RD*("`@('L*("`@("`@("`D
M=&AI<RT^;64@/2!A<G)A>2@I.PH@("`@("`@("1T:&ES+3YM>71Y<&4@/2`P
M.PH@("`@("`@(&EF("@D=F%L("$]("TQ('Q\("1T>7!E("$]("<G*2!["B`@
M("`@("`@("`@(&EF("@D='EP92`]/2`G)RD@>PH@("`@("`@("`@("`@("`@
M)'1Y<&4@/2`G<W1R:6YG)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I
M9B`H(6%R<F%Y7VME>5]E>&ES=',H)'1Y<&4L("1'3$]"04Q36R=834Q?4E!#
M7U1Y<&5S)UTI*2!["B`@("`@("`@("`@("`@("`O+R!86%@*("`@("`@("`@
M("`@("`@("\O(&YE960@<V]M92!W87D@=&\@<F5P;W)T('1H:7,@97)R;W(*
M("`@("`@("`@("`@?2!E;'-E:68@*"1'3$]"04Q36R=834Q?4E!#7U1Y<&5S
M)UU;)'1Y<&5=(#T](#$I('L*("`@("`@("`@("`@("`@("1T:&ES+3YA9&13
M8V%L87(H)'9A;"P@)'1Y<&4I.PH@("`@("`@("`@("!](&5L<V5I9B`H)$=,
M3T)!3%-;)UA-3%]24$-?5'EP97,G75LD='EP95T@/3T@,BD@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/F%D9$%R<F%Y*"1V86PI.PH@("`@("`@("`@("!]
M(&5L<V5I9B`H)$=,3T)!3%-;)UA-3%]24$-?5'EP97,G75LD='EP95T@/3T@
M,RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/F%D9%-T<G5C="@D=F%L*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($!R971U<FX@:6YT("!R971U<FYS(#$@:68@<W5C8V5S<V9U;"!O<B`P(&EF
M('1H97)E(&%R92!P<F]B;&5M<PH@("`@("HO"B`@("!F=6YC=&EO;B!A9&13
M8V%L87(H)'9A;"P@)'1Y<&4@/2`G<W1R:6YG)RD*("`@('L*("`@("`@("!I
M9B`H)'1H:7,M/FUY='EP92`]/2`Q*2!["B`@("`@("`@("`@("1T:&ES+3YR
M86ES945R<F]R*"=38V%L87(@8V%N(&AA=F4@;VYL>2!O;F4@=F%L=64G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4E!#7T524D]27TE.
M5D%,241?5%E012D["B`@("`@("`@("`@(')E='5R;B`P.PH@("`@("`@('T*
M("`@("`@("`D='EP96]F(#T@)$=,3T)!3%-;)UA-3%]24$-?5'EP97,G75LD
M='EP95T["B`@("`@("`@:68@*"1T>7!E;V8@(3T@,2D@>PH@("`@("`@("`@
M("`D=&AI<RT^<F%I<V5%<G)O<B@B3F]T(&$@<V-A;&%R('1Y<&4@*"1[='EP
M96]F?2DB+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4E!#
M7T524D]27TE.5D%,241?5%E012D["B`@("`@("`@("`@(')E='5R;B`P.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"1T>7!E(#T]("1'3$]"04Q36R=834Q?
M4E!#7T)O;VQE86XG72D@>PH@("`@("`@("`@("!I9B`H<W1R8V%S96-M<"@D
M=F%L+"`G=')U92<I(#T](#`*("`@("`@("`@("`@("`@('Q\("1V86P@/3T@
M,0H@("`@("`@("`@("`@("`@?'P@*"1V86P@/3T@=')U92`F)B!S=')C87-E
M8VUP*"1V86PL("=F86QS92<I*2D*("`@("`@("`@("`@>PH@("`@("`@("`@
M("`@("`@)'9A;"`](#$["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D=F%L(#T@,#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@:68@*"1T:&ES+3YM>71Y<&4@/3T@,BD@>PH@("`@("`@("`@("`O
M+R!W92=R92!A9&1I;F<@=&\@86X@87)R87D@:&5R90H@("`@("`@("`@("`D
M87(@/2`D=&AI<RT^;65;)V%R<F%Y)UT["B`@("`@("`@("`@("1A<EM=(#T@
M;F5W(%A-3%]24$-?5F%L=64H)'9A;"P@)'1Y<&4I.PH@("`@("`@("`@("`D
M=&AI<RT^;65;)V%R<F%Y)UT@/2`D87(["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@+R\@82!S8V%L87(L('-O('-E="!T:&4@=F%L=64@86YD(')E
M;65M8F5R('=E)W)E('-C86QA<@H@("`@("`@("`@("`D=&AI<RT^;65;)'1Y
M<&5=(#T@)'9A;#L*("`@("`@("`@("`@)'1H:7,M/FUY='EP92`]("1T>7!E
M;V8["B`@("`@("`@?0H@("`@("`@(')E='5R;B`Q.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0')E='5R;B!I;G0@(')E='5R;G,@,2!I9B!S=6-C97-S9G5L
M(&]R(#`@:68@=&AE<F4@87)E('!R;V)L96US"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%D9$%R<F%Y*"1V86QS*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^
M;7ET>7!E("$](#`I('L*("`@("`@("`@("`@)'1H:7,M/G)A:7-E17)R;W(H
M"B`@("`@("`@("`@("`@("`@("`@)T%L<F5A9'D@:6YI=&EA;&EZ960@87,@
M82!;)R`N("1T:&ES+3YK:6YD3V8H*2`N("==)RP*("`@("`@("`@("`@("`@
M("`@("!834Q?4E!#7T524D]27T%,4D5!1%E?24Y)5$E!3$E:140I.PH@("`@
M("`@("`@("!R971U<FX@,#L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/FUY
M='EP92`]("1'3$]"04Q36R=834Q?4E!#7U1Y<&5S)UU;)V%R<F%Y)UT["B`@
M("`@("`@)'1H:7,M/FUE6R=A<G)A>2==(#T@)'9A;',["B`@("`@("`@<F5T
M=7)N(#$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!`<F5T=7)N(&EN="`@<F5T
M=7)N<R`Q(&EF('-U8V-E<W-F=6P@;W(@,"!I9B!T:&5R92!A<F4@<')O8FQE
M;7,*("`@("`J+PH@("`@9G5N8W1I;VX@861D4W1R=6-T*"1V86QS*0H@("`@
M>PH@("`@("`@(&EF("@D=&AI<RT^;7ET>7!E("$](#`I('L*("`@("`@("`@
M("`@)'1H:7,M/G)A:7-E17)R;W(H"B`@("`@("`@("`@("`@("`@("`@)T%L
M<F5A9'D@:6YI=&EA;&EZ960@87,@82!;)R`N("1T:&ES+3YK:6YD3V8H*2`N
M("==)RP*("`@("`@("`@("`@("`@("`@("!834Q?4E!#7T524D]27T%,4D5!
M1%E?24Y)5$E!3$E:140I.PH@("`@("`@("`@("!R971U<FX@,#L*("`@("`@
M("!]"B`@("`@("`@)'1H:7,M/FUY='EP92`]("1'3$]"04Q36R=834Q?4E!#
M7U1Y<&5S)UU;)W-T<G5C="==.PH@("`@("`@("1T:&ES+3YM95LG<W1R=6-T
M)UT@/2`D=F%L<SL*("`@("`@("!R971U<FX@,3L*("`@('T*"B`@("`O*BH*
M("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!D=6UP
M*"1A<BD*("`@('L*("`@("`@("!R97-E="@D87(I.PH@("`@("`@(&9O<F5A
M8V@@*"1A<B!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@96-H;R`B
M)&ME>2`]/B`D=F%L/&)R("\^(CL*("`@("`@("`@("`@:68@*"1K97D@/3T@
M)V%R<F%Y)RD@>PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)'9A;"!A<R`D
M:V5Y,B`]/B`D=F%L,BD@>PH@("`@("`@("`@("`@("`@("`@(&5C:&\@(BTM
M("1K97DR(#T^("1V86PR/&)R("\^(CL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($!R
M971U<FX@<W1R:6YG("!T:&4@9&%T82!T>7!E(&]F('1H92!C=7)R96YT('9A
M;'5E"B`@("`@*B\*("`@(&9U;F-T:6]N(&MI;F1/9B@I"B`@("!["B`@("`@
M("`@<W=I=&-H("@D=&AI<RT^;7ET>7!E*2!["B`@("`@("`@8V%S92`S.@H@
M("`@("`@("`@("!R971U<FX@)W-T<G5C="<["@H@("`@("`@(&-A<V4@,CH*
M("`@("`@("`@("`@<F5T=7)N("=A<G)A>2<["@H@("`@("`@(&-A<V4@,3H*
M("`@("`@("`@("`@<F5T=7)N("=S8V%L87(G.PH*("`@("`@("!D969A=6QT
M.@H@("`@("`@("`@("!R971U<FX@)W5N9&5F)SL*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&1A=&$@:6X@
M6$U,(&9O<FUA=`H@("`@("HO"B`@("!F=6YC=&EO;B!S97)I86QI>F5D871A
M*"1T>7`L("1V86PI"B`@("!["B`@("`@("`@)')S(#T@)R<["B`@("`@("`@
M:68@*"%A<G)A>5]K97E?97AI<W1S*"1T>7`L("1'3$]"04Q36R=834Q?4E!#
M7U1Y<&5S)UTI*2!["B`@("`@("`@("`@("\O(%A86`H@("`@("`@("`@("`O
M+R!N965D('-O;64@=V%Y('1O(')E<&]R="!T:&ES(&5R<F]R"B`@("`@("`@
M("`@(')E='5R;CL*("`@("`@("!]"B`@("`@("`@<W=I=&-H("@D1TQ/0D%,
M4ULG6$U,7U)00U]4>7!E<R==6R1T>7!=*2!["B`@("`@("`@8V%S92`S.@H@
M("`@("`@("`@("`O+R!S=')U8W0*("`@("`@("`@("`@)')S("X]("(\<W1R
M=6-T/EQN(CL*("`@("`@("`@("`@<F5S970H)'9A;"D["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1V86P@87,@)&ME>3(@/3X@)'9A;#(I('L*("`@("`@("`@
M("`@("`@("1R<R`N/2`B/&UE;6)E<CX\;F%M93XD>VME>3)]/"]N86UE/EQN
M(CL*("`@("`@("`@("`@("`@("1R<R`N/2`D=&AI<RT^<V5R:6%L:7IE=F%L
M*"1V86PR*3L*("`@("`@("`@("`@("`@("1R<R`N/2`B/"]M96UB97(^7&XB
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1R<R`N/2`G/"]S=')U8W0^
M)SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@,CH*("`@("`@
M("`@("`@+R\@87)R87D*("`@("`@("`@("`@)')S("X]("(\87)R87D^7&X\
M9&%T83Y<;B(["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O
M9B@D=F%L*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@)')S("X]("1T:&ES
M+3YS97)I86QI>F5V86PH)'9A;%LD:5TI.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1R<R`N/2`B/"]D871A/EQN/"]A<G)A>3XB.PH@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@8V%S92`Q.@H@("`@("`@("`@("!S=VET8V@@
M*"1T>7`I('L*("`@("`@("`@("`@8V%S92`D1TQ/0D%,4ULG6$U,7U)00U]"
M87-E-C0G73H*("`@("`@("`@("`@("`@("1R<R`N/2`B/"1[='EP?3XB("X@
M8F%S938T7V5N8V]D92@D=F%L*2`N("(\+R1[='EP?3XB.PH@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@)$=,3T)!3%-;)UA-3%]2
M4$-?0F]O;&5A;B==.@H@("`@("`@("`@("`@("`@)')S("X]("(\)'MT>7!]
M/B(@+B`H)'9A;"`_("<Q)R`Z("<P)RD@+B`B/"\D>W1Y<'T^(CL*("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("1'3$]"04Q36R=8
M34Q?4E!#7U-T<FEN9R==.@H@("`@("`@("`@("`@("`@)')S("X]("(\)'MT
M>7!]/B(@+B!H=&UL<W!E8VEA;&-H87)S*"1V86PI+B`B/"\D>W1Y<'T^(CL*
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!D969A=6QT.@H@
M("`@("`@("`@("`@("`@)')S("X]("(\)'MT>7!]/B1[=F%L?3PO)'MT>7!]
M/B(["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R
M<SL*("`@('T*"B`@("`O*BH*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@
M9&%T82!I;B!834P@9F]R;6%T"B`@("`@*B\*("`@(&9U;F-T:6]N('-E<FEA
M;&EZ92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YS97)I86QI>F5V
M86PH)'1H:7,I.PH@("`@?0H*("`@("\J*@H@("`@("H@0')E='5R;B!S=')I
M;F<@('1H92!D871A(&EN(%A-3"!F;W)M870*("`@("`J+PH@("`@9G5N8W1I
M;VX@<V5R:6%L:7IE=F%L*"1O*0H@("`@>PH@("`@("`@(&EF("@A:7-?;V)J
M96-T*"1O*2!\?"!E;7!T>2@D;RT^;64I('Q\("%I<U]A<G)A>2@D;RT^;64I
M*2!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("!]"B`@("`@("`@
M)&%R(#T@)&\M/FUE.PH@("`@("`@(')E<V5T*"1A<BD["B`@("`@("`@;&ES
M="@D='EP+"`D=F%L*2`](&5A8V@H)&%R*3L*("`@("`@("!R971U<FX@)SQV
M86QU93XG("X@("1T:&ES+3YS97)I86QI>F5D871A*"1T>7`L("1V86PI("X@
M("(\+W9A;'5E/EQN(CL*("`@('T*"B`@("`O*BH*("`@("`J($!R971U<FX@
M;6EX960@('1H92!C;VYT96YT<R!O9B!T:&4@96QE;65N="!R97%U97-T960*
M("`@("`J+PH@("`@9G5N8W1I;VX@<W1R=6-T;65M*"1M*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^;65;)W-T<G5C="==6R1M73L*("`@('T*"B`@
M("`O*BH*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO
M;B!S=')U8W1R97-E="@I"B`@("!["B`@("`@("`@<F5S970H)'1H:7,M/FUE
M6R=S=')U8W0G72D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!`<F5T=7)N("!T
M:&4@:V5Y+W9A;'5E('!A:7(@;V8@=&AE('-T<G5C="=S(&-U<G)E;G0@96QE
M;65N=`H@("`@("HO"B`@("!F=6YC=&EO;B!S=')U8W1E86-H*"D*("`@('L*
M("`@("`@("!R971U<FX@96%C:"@D=&AI<RT^;65;)W-T<G5C="==*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($!R971U<FX@;6EX960@('1H92!C=7)R96YT
M('9A;'5E"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E='9A;"@I"B`@("!["B`@
M("`@("`@+R\@54Y35$%"3$4*"B`@("`@("`@<F5S970H)'1H:7,M/FUE*3L*
M("`@("`@("`D8B`](&-U<G)E;G0H)'1H:7,M/FUE*3L*"B`@("`@("`@+R\@
M8V]N=')I8G5T960@8GD@22!3;V9E<BP@,C`P,2TP,RTR-`H@("`@("`@("\O
M(&%D9"!S=7!P;W)T(&9O<B!N97-T960@87)R87ES('1O('-C86QA<G9A;`H@
M("`@("`@("\O(&DG=F4@8W)E871E9"!A(&YE=R!M971H;V0@:&5R92P@<V\@
M87,@=&\*("`@("`@("`O+R!P<F5S97)V92!B86-K(&-O;7!A=&EB:6QI='D*
M"B`@("`@("`@:68@*&ES7V%R<F%Y*"1B*2D@>PH@("`@("`@("`@("!F;W)E
M86-H("@D8B!A<R`D:60@/3X@)&-O;G0I('L*("`@("`@("`@("`@("`@("1B
M6R1I9%T@/2`D8V]N="T^<V-A;&%R=F%L*"D["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@("\O(&%D9"!S=7!P;W)T(&9O<B!S=')U8W1U<F5S
M(&1I<F5C=&QY(&5N8V]D:6YG('!H<"!O8FIE8W1S"B`@("`@("`@:68@*&ES
M7V]B:F5C="@D8BDI('L*("`@("`@("`@("`@)'0@/2!G971?;V)J96-T7W9A
M<G,H)&(I.PH@("`@("`@("`@("!F;W)E86-H("@D="!A<R`D:60@/3X@)&-O
M;G0I('L*("`@("`@("`@("`@("`@("1T6R1I9%T@/2`D8V]N="T^<V-A;&%R
M=F%L*"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@9F]R96%C:"`H)'0@
M87,@)&ED(#T^("1C;VYT*2!["B`@("`@("`@("`@("`@("`D8BT^)&ED(#T@
M)&-O;G0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O(&5N
M9"!C;VYT<FEB"B`@("`@("`@<F5T=7)N("1B.PH@("`@?0H*("`@("\J*@H@
M("`@("H@0')E='5R;B!M:7AE9`H@("`@("HO"B`@("!F=6YC=&EO;B!S8V%L
M87)V86PH*0H@("`@>PH@("`@("`@(')E<V5T*"1T:&ES+3YM92D["B`@("`@
M("`@<F5T=7)N(&-U<G)E;G0H)'1H:7,M/FUE*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($!R971U<FX@<W1R:6YG"B`@("`@*B\*("`@(&9U;F-T:6]N('-C
M86QA<G1Y<"@I"B`@("!["B`@("`@("`@<F5S970H)'1H:7,M/FUE*3L*("`@
M("`@("`D82`](&ME>2@D=&AI<RT^;64I.PH@("`@("`@(&EF("@D82`]/2`D
M1TQ/0D%,4ULG6$U,7U)00U])-"==*2!["B`@("`@("`@("`@("1A(#T@)$=,
M3T)!3%-;)UA-3%]24$-?26YT)UT["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B`D83L*("`@('T*"B`@("`O*BH*("`@("`J($!R971U<FX@;6EX960@('1H
M92!S=')U8W0G<R!C=7)R96YT(&5L96UE;G0*("`@("`J+PH@("`@9G5N8W1I
M;VX@87)R87EM96TH)&TI"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YM
M95LG87)R87DG75LD;5T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!`<F5T=7)N
M(&EN="`@=&AE(&YU;6)E<B!O9B!E;&5M96YT<R!I;B!T:&4@87)R87D*("`@
M("`J+PH@("`@9G5N8W1I;VX@87)R87ES:7IE*"D*("`@('L*("`@("`@("!R
M97-E="@D=&AI<RT^;64I.PH@("`@("`@(&QI<W0H)&$L("1B*2`](&5A8V@H
M)'1H:7,M/FUE*3L*("`@("`@("!R971U<FX@<VEZ96]F*"1B*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($1E=&5R;6EN97,@:68@=&AE(&ET96T@<W5B;6ET
M=&5D(&ES(&%N(%A-3%]24$-?5F%L=64@;V)J96-T"B`@("`@*@H@("`@("H@
M0'!A<F%M(&UI>&5D("1V86P@('1H92!V87)I86)L92!T;R!B92!E=F%L=6%T
M960*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@(%12544@:68@=&AE(&ET
M96T@:7,@86X@6$U,7U)00U]686QU92!O8FIE8W0*("`@("`J"B`@("`@*B!`
M<W1A=&EC"B`@("`@*B!`<VEN8V4@365T:&]D(&%V86EL86)L92!S:6YC92!2
M96QE87-E(#$N,RXP"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES5F%L=64H)'9A
M;"D*("`@('L*("`@("`@("!R971U<FX@*'-T<G1O;&]W97(H9V5T7V-L87-S
M*"1V86PI*2`]/2`G>&UL7W)P8U]V86QU92<I.PH@("`@?0I]"@HO*BH*("H@
M4F5T=7)N(&%N($E33S@V,#$@96YC;V1E9"!S=')I;F<*("H*("H@5VAI;&4@
M=&EM97IO;F5S(&]U9VAT('1O(&)E('-U<'!O<G1E9"P@=&AE(%A-3"U24$,@
M<W!E8R!S87ES.@H@*@H@*B`B1&]N)W0@87-S=6UE(&$@=&EM97IO;F4N($ET
M('-H;W5L9"!B92!S<&5C:69I960@8GD@=&AE('-E<G9E<B!I;B!I=',*("H@
M9&]C=6UE;G1A=&EO;B!W:&%T(&%S<W5M<'1I;VYS(&ET(&UA:V5S(&%B;W5T
M('1I;65Z;VYE<RXB"B`J"B`J(%1H:7,@<F]U=&EN92!A;'=A>7,@87-S=6UE
M<R!L;V-A;'1I;64@=6YL97-S("1U=&,@:7,@<V5T('1O(#$L(&EN('=H:6-H
M"B`J(&-A<V4@551#(&ES(&%S<W5M960@86YD(&%N(&%D:G5S=&UE;G0@9F]R
M(&QO8V%L92!I<R!M861E('=H96X@96YC;V1I;F<N"B`J"B`J($!R971U<FX@
M<W1R:6YG("!T:&4@9F]R;6%T=&5D(&1A=&4*("HO"F9U;F-T:6]N(%A-3%]2
M4$-?:7-O.#8P,5]E;F-O9&4H)'1I;65T+"`D=71C(#T@,"D*>PH@("`@:68@
M*"$D=71C*2!["B`@("`@("`@)'0@/2!S=')F=&EM92@G)5DE;25D5"5(.B5-
M.B53)RP@)'1I;65T*3L*("`@('T@96QS92!["B`@("`@("`@:68@*&9U;F-T
M:6]N7V5X:7-T<R@G9VUS=')F=&EM92<I*2!["B`@("`@("`@("`@("\O(&=M
M<W1R9G1I;64@9&]E<VXG="!E>&ES="!I;B!S;VUE('9E<G-I;VYS"B`@("`@
M("`@("`@("\O(&]F(%!(4`H@("`@("`@("`@("`D="`](&=M<W1R9G1I;64H
M)R59)6TE9%0E2#HE33HE4R<L("1T:6UE="D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'0@/2!S=')F=&EM92@G)5DE;25D5"5(.B5-.B53)RP@
M)'1I;65T("T@9&%T92@G6B<I*3L*("`@("`@("!]"B`@("!]"B`@("!R971U
M<FX@)'0["GT*"B\J*@H@*B!#;VYV97)T(&$@9&%T971I;64@<W1R:6YG(&EN
M=&\@82!5;FEX('1I;65S=&%M<`H@*@H@*B!7:&EL92!T:6UE>F]N97,@;W5G
M:'0@=&\@8F4@<W5P<&]R=&5D+"!T:&4@6$U,+5)00R!S<&5C('-A>7,Z"B`J
M"B`J(")$;VXG="!A<W-U;64@82!T:6UE>F]N92X@270@<VAO=6QD(&)E('-P
M96-I9FEE9"!B>2!T:&4@<V5R=F5R(&EN(&ET<PH@*B!D;V-U;65N=&%T:6]N
M('=H870@87-S=6UP=&EO;G,@:70@;6%K97,@86)O=70@=&EM97IO;F5S+B(*
M("H*("H@5&AI<R!R;W5T:6YE(&%L=V%Y<R!A<W-U;65S(&QO8V%L=&EM92!U
M;FQE<W,@)'5T8R!I<R!S970@=&\@,2P@:6X@=VAI8V@*("H@8V%S92!55$,@
M:7,@87-S=6UE9"!A;F0@86X@861J=7-T;65N="!F;W(@;&]C86QE(&ES(&UA
M9&4@=VAE;B!E;F-O9&EN9RX*("H*("H@0')E='5R;B!I;G0@('1H92!U;FEX
M('1I;65S=&%M<"!O9B!T:&4@9&%T92!S=6)M:71T960*("HO"F9U;F-T:6]N
M(%A-3%]24$-?:7-O.#8P,5]D96-O9&4H)&ED871E+"`D=71C(#T@,"D*>PH@
M("`@)'0@/2`P.PH@("`@:68@*&5R96<H)RA;,"TY77LT?2DH6S`M.5U[,GTI
M*%LP+3E=>S)]*50H6S`M.5U[,GTI.BA;,"TY77LR?2DZ*%LP+3E=>S)]*2<L
M("1I9&%T92P@)')E9W,I*2!["B`@("`@("`@:68@*"1U=&,I('L*("`@("`@
M("`@("`@)'0@/2!G;6UK=&EM92@D<F5G<ULT72P@)')E9W-;-5TL("1R96=S
M6S9=+"`D<F5G<ULR72P@)')E9W-;,UTL("1R96=S6S%=*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D="`](&UK=&EM92@D<F5G<ULT72P@)')E
M9W-;-5TL("1R96=S6S9=+"`D<F5G<ULR72P@)')E9W-;,UTL("1R96=S6S%=
M*3L*("`@("`@("!]"B`@("!]"B`@("!R971U<FX@)'0["GT*"B\J*@H@*B!#
M;VYV97)T<R!A;B!834Q?4E!#7U9A;'5E(&]B:F5C="!I;G1O(&YA=&EV92!0
M2%`@='EP97,*("H*("H@0'!A<F%M(&]B:F5C="`D6$U,7U)00U]V86P@('1H
M92!834Q?4E!#7U9A;'5E(&]B:F5C="!T;R!D96-O9&4*("H*("H@0')E='5R
M;B!M:7AE9"`@=&AE(%!(4"!V86QU97,*("HO"F9U;F-T:6]N(%A-3%]24$-?
M9&5C;V1E*"1834Q?4E!#7W9A;"D*>PH@("`@)&MI;F0@/2`D6$U,7U)00U]V
M86PM/FMI;F1/9B@I.PH*("`@(&EF("@D:VEN9"`]/2`G<V-A;&%R)RD@>PH@
M("`@("`@(')E='5R;B`D6$U,7U)00U]V86PM/G-C86QA<G9A;"@I.PH*("`@
M('T@96QS96EF("@D:VEN9"`]/2`G87)R87DG*2!["B`@("`@("`@)'-I>F4@
M/2`D6$U,7U)00U]V86PM/F%R<F%Y<VEZ92@I.PH@("`@("`@("1A<G(@/2!A
M<G)A>2@I.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1S:7IE.R`D:2LK
M*2!["B`@("`@("`@("`@("1A<G);72`](%A-3%]24$-?9&5C;V1E*"1834Q?
M4E!#7W9A;"T^87)R87EM96TH)&DI*3L*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N("1A<G(["@H@("`@?2!E;'-E:68@*"1K:6YD(#T]("=S=')U8W0G*2![
M"B`@("`@("`@)%A-3%]24$-?=F%L+3YS=')U8W1R97-E="@I.PH@("`@("`@
M("1A<G(@/2!A<G)A>2@I.PH@("`@("`@('=H:6QE("AL:7-T*"1K97DL("1V
M86QU92D@/2`D6$U,7U)00U]V86PM/G-T<G5C=&5A8V@H*2D@>PH@("`@("`@
M("`@("`D87)R6R1K97E=(#T@6$U,7U)00U]D96-O9&4H)'9A;'5E*3L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("1A<G(["B`@("!]"GT*"B\J*@H@*B!#
M;VYV97)T<R!N871I=F4@4$A0('1Y<&5S(&EN=&\@86X@6$U,7U)00U]686QU
M92!O8FIE8W0*("H*("H@0'!A<F%M(&UI>&5D("1P:'!?=F%L("!T:&4@4$A0
M('9A;'5E(&]R('9A<FEA8FQE('EO=2!W86YT(&5N8V]D960*("H*("H@0')E
M='5R;B!O8FIE8W0@('1H92!834Q?4E!#7U9A;'5E(&]B:F5C=`H@*B\*9G5N
M8W1I;VX@6$U,7U)00U]E;F-O9&4H)'!H<%]V86PI"GL*("`@("1T>7!E(#T@
M9V5T='EP92@D<&AP7W9A;"D["B`@("`D6$U,7U)00U]V86P@/2!N97<@6$U,
M7U)00U]686QU93L*"B`@("!S=VET8V@@*"1T>7!E*2!["B`@("!C87-E("=A
M<G)A>2<Z"B`@("`@("`@:68@*&5M<'1Y*"1P:'!?=F%L*2D@>PH@("`@("`@
M("`@("`D6$U,7U)00U]V86PM/F%D9$%R<F%Y*"1P:'!?=F%L*3L*("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@?0H@("`@("`@("1T;7`@/2!A<G)A>5]D
M:69F*&%R<F%Y7VME>7,H)'!H<%]V86PI+"!R86YG92@P+"!C;W5N="@D<&AP
M7W9A;"DM,2DI.PH@("`@("`@(&EF("AE;7!T>2@D=&UP*2D@>PH@("`@("`@
M("`@("1A<G(@/2!A<G)A>2@I.PH@("`@("`@("`@(&9O<F5A8V@@*"1P:'!?
M=F%L(&%S("1K(#T^("1V*2!["B`@("`@("`@("`@("`@("1A<G);)&M=(#T@
M6$U,7U)00U]E;F-O9&4H)'8I.PH@("`@("`@("`@('T*("`@("`@("`@("`D
M6$U,7U)00U]V86PM/F%D9$%R<F%Y*"1A<G(I.PH@("`@("`@("`@(&)R96%K
M.PH@("`@("`@('T*("`@("`@("`O+R!F86QL('1H;W5G:"!I9B!I="=S(&YO
M="!A;B!E;G5M97)A=&5D(&%R<F%Y"@H@("`@8V%S92`G;V)J96-T)SH*("`@
M("`@("`D87)R(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D<&AP7W9A
M;"!A<R`D:R`]/B`D=BD@>PH@("`@("`@("`@("`D87)R6R1K72`](%A-3%]2
M4$-?96YC;V1E*"1V*3L*("`@("`@("!]"B`@("`@("`@)%A-3%]24$-?=F%L
M+3YA9&13=')U8W0H)&%R<BD["B`@("`@("`@8G)E86L["@H@("`@8V%S92`G
M:6YT96=E<B<Z"B`@("`@("`@)%A-3%]24$-?=F%L+3YA9&138V%L87(H)'!H
M<%]V86PL("1'3$]"04Q36R=834Q?4E!#7TEN="==*3L*("`@("`@("!B<F5A
M:SL*"B`@("!C87-E("=D;W5B;&4G.@H@("`@("`@("1834Q?4E!#7W9A;"T^
M861D4V-A;&%R*"1P:'!?=F%L+"`D1TQ/0D%,4ULG6$U,7U)00U]$;W5B;&4G
M72D["B`@("`@("`@8G)E86L["@H@("`@8V%S92`G<W1R:6YG)SH*("`@(&-A
M<V4@)TY53$PG.@H@("`@("`@(&EF("AE<F5G*"=>6S`M.5U[.'U<5'LQ?5LP
M+3E=>S)]7#I;,"TY77LR?5PZ6S`M.5U[,GTD)RP@)'!H<%]V86PI*2!["B`@
M("`@("`@("`@("1834Q?4E!#7W9A;"T^861D4V-A;&%R*"1P:'!?=F%L+"`D
M1TQ/0D%,4ULG6$U,7U)00U]$871E5&EM92==*3L*("`@("`@("!](&5L<V5I
M9B`H<')E9U]M871C:"@G+UM>7'@R,"U<>#=%7'@P.5QX,$%<>#!$72\G+"`D
M<&AP7W9A;"DI('L*("`@("`@("`@("`@+R\@0VAA<F%C=&5R<R!O=&AE<B!T
M:&%N(&%L<&AA+6YU;65R:6,L('!U;F-T=6%T:6]N+"!34"P@5$%"+`H@("`@
M("`@("`@("`O+R!,1B!A;F0@0U(@8G)E86L@=&AE(%A-3"!P87)S97(L(&5N
M8V]D92!V86QU92!V:6$@0F%S92`V-"X*("`@("`@("`@("`@)%A-3%]24$-?
M=F%L+3YA9&138V%L87(H)'!H<%]V86PL("1'3$]"04Q36R=834Q?4E!#7T)A
M<V4V-"==*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D6$U,7U)0
M0U]V86PM/F%D9%-C86QA<B@D<&AP7W9A;"P@)$=,3T)!3%-;)UA-3%]24$-?
M4W1R:6YG)UTI.PH@("`@("`@('T*("`@("`@("!B<F5A:SL*"B`@("!C87-E
M("=B;V]L96%N)SH*("`@("`@("`O+R!!9&0@<W5P<&]R="!F;W(@96YC;V1I
M;F<O9&5C;V1I;F<@;V8@8F]O;&5A;G,L('-I;F-E('1H97D*("`@("`@("`O
M+R!A<F4@<W5P<&]R=&5D(&EN(%!(4`H@("`@("`@("\O(&)Y(#Q'7T=I=6YT
M85\R,#`Q+3`R+3(Y/@H@("`@("`@("1834Q?4E!#7W9A;"T^861D4V-A;&%R
M*"1P:'!?=F%L+"`D1TQ/0D%,4ULG6$U,7U)00U]";V]L96%N)UTI.PH@("`@
M("`@(&)R96%K.PH*("`@(&-A<V4@)W5N:VYO=VX@='EP92<Z"B`@("!D969A
M=6QT.@H@("`@("`@("1834Q?4E!#7W9A;"`](&9A;'-E.PH@("`@?0H@("`@
M<F5T=7)N("1834Q?4E!#7W9A;#L*?0H*+RH*("H@3&]C86P@=F%R:6%B;&5S
M.@H@*B!T86(M=VED=&@Z(#0*("H@8RUB87-I8RUO9F9S970Z(#0*("H@8RUH
M86YG:6YG+6-O;6UE;G0M96YD97(M<#H@;FEL"B`J($5N9#H*("HO"@H_/@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+T1"````````````````````````````````````````````````
M````````````````````````````````````````````,#`P-S4U(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S$@,#$V-C<R`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O1$(O8V]M;6]N+G!H<```````````
M````````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#(P-S4V-R`Q,#4Q
M-30S,S<S,2`P,C`W-S,`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S
M=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO"@HO*BH*("H@
M0V]N=&%I;G,@=&AE($1"7V-O;6UO;B!B87-E(&-L87-S"B`J"B`J(%!(4"!V
M97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I
M;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N
M<V4*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED
M92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E
M(&$@8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@
M=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@
M82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@
M82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S
M90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!3=&EG($)A:VME
M;B`\<W-B0'!H<"YN970^"B`J($!A=71H;W(@("`@(%1O;6%S(%8N5BX@0V]X
M(#QC;WA`:61E8VYE="YC;VT^"B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV
M:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR
M,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V
M97)S:6]N("`@($-64SH@)$ED.B!C;VUM;VXN<&AP+'8@,2XQ,S<@,C`P-2\P
M-"\P-R`Q-#HR-SHS-2!D86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B\*"B\J*@H@*B!/8G1A
M:6X@=&AE(%!%05(@8VQA<W,@<V\@:70@8V%N(&)E(&5X=&5N9&5D(&9R;VT*
M("HO"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PH*+RHJ"B`J($1"7V-O;6UO
M;B!I<R!T:&4@8F%S92!C;&%S<R!F<F]M('=H:6-H(&5A8V@@9&%T86)A<V4@
M9')I=F5R(&-L87-S(&5X=&5N9',*("H*("H@06QL(&-O;6UO;B!M971H;V1S
M(&%R92!D96-L87)E9"!H97)E+B`@268@82!G:79E;B!$0DU3(&1R:79E<B!C
M;VYT86EN<PH@*B!A('!A<G1I8W5L87(@;65T:&]D+"!T:&%T(&UE=&AO9"!W
M:6QL(&]V97)L;V%D('1H92!O;F4@:&5R92X*("H*("H@0&-A=&5G;W)Y("`@
M1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@4W1I
M9R!"86MK96X@/'-S8D!P:'`N;F5T/@H@*B!`875T:&]R("`@("!4;VUA<R!6
M+E8N($-O>"`\8V]X0&ED96-N970N8V]M/@H@*B!`875T:&]R("`@("!$86YI
M96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@
M(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N
M,`H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C<N-@H@*B!`;&EN:R`@("`@
M("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO"F-L87-S($1"
M7V-O;6UO;B!E>'1E;F1S(%!%05(*>PH@("`@+R\@>WM[('!R;W!E<G1I97,*
M"B`@("`O*BH*("`@("`J(%1H92!C=7)R96YT(&1E9F%U;'0@9F5T8V@@;6]D
M90H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D9F5T8VAM
M;V1E(#T@1$)?1D540TA-3T1%7T]21$52140["@H@("`@+RHJ"B`@("`@*B!4
M:&4@;F%M92!O9B!T:&4@8VQA<W,@:6YT;R!W:&EC:"!R97-U;'1S('-H;W5L
M9"!B92!F971C:&5D('=H96X*("`@("`J($1"7T9%5$-(34]$15]/0DI%0U0@
M:7,@:6X@969F96-T"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J
M+PH@("`@=F%R("1F971C:&UO9&5?;V)J96-T7V-L87-S(#T@)W-T9$-L87-S
M)SL*"B`@("`O*BH*("`@("`J(%=A<R!A(&-O;FYE8W1I;VX@<')E<V5N="!W
M:&5N('1H92!O8FIE8W0@=V%S('-E<FEA;&EZ960H*3\*("`@("`J($!V87(@
M8F]O;`H@("`@("H@0'-E92!$0E]C;VUM;VXZ.E]?<VQE97`H*2P@1$)?8V]M
M;6]N.CI?7W=A:V4H*0H@("`@("HO"B`@("!V87(@)'=A<U]C;VYN96-T960@
M/2!N=6QL.PH*("`@("\J*@H@("`@("H@5&AE(&UO<W0@<F5C96YT;'D@97AE
M8W5T960@<75E<GD*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D;&%S=%]Q=65R>2`]("<G.PH*("`@("\J*@H@("`@("H@4G5N+71I;64@
M8V]N9FEG=7)A=&EO;B!O<'1I;VYS"B`@("`@*@H@("`@("H@5&AE("=O<'1I
M;6EZ92<@;W!T:6]N(&AA<R!B965N(&1E<')E8V%T960N("!5<V4@=&AE("=P
M;W)T86)I;&ET>2<*("`@("`J(&]P=&EO;B!I;G-T96%D+@H@("`@("H*("`@
M("`J($!V87(@87)R87D*("`@("`J($!S964@1$)?8V]M;6]N.CIS971/<'1I
M;VXH*0H@("`@("HO"B`@("!V87(@)&]P=&EO;G,@/2!A<G)A>2@*("`@("`@
M("`G<F5S=6QT7V)U9F9E<FEN9R<@/3X@-3`P+`H@("`@("`@("=P97)S:7-T
M96YT)R`]/B!F86QS92P*("`@("`@("`G<W-L)R`]/B!F86QS92P*("`@("`@
M("`G9&5B=6<G(#T^(#`L"B`@("`@("`@)W-E<6YA;65?9F]R;6%T)R`]/B`G
M)7-?<V5Q)RP*("`@("`@("`G875T;V9R964G(#T^(&9A;'-E+`H@("`@("`@
M("=P;W)T86)I;&ET>2<@/3X@1$)?4$]25$%"24Q)5%E?3D].12P*("`@("`@
M("`G;W!T:6UI>F4G(#T^("=P97)F;W)M86YC92<L("`O+R!$97!R96-A=&5D
M+B`@57-E("=P;W)T86)I;&ET>2<N"B`@("`I.PH*("`@("\J*@H@("`@("H@
M5&AE('!A<F%M971E<G,@9G)O;2!T:&4@;6]S="!R96-E;G1L>2!E>&5C=71E
M9"!Q=65R>0H@("`@("H@0'9A<B!A<G)A>0H@("`@("H@0'-I;F-E(%!R;W!E
M<G1Y(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-RXP"B`@("`@*B\*("`@
M('9A<B`D;&%S=%]P87)A;65T97)S(#T@87)R87DH*3L*"B`@("`O*BH*("`@
M("`J(%1H92!E;&5M96YT<R!F<F]M(&5A8V@@<')E<&%R960@<W1A=&5M96YT
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D<')E<&%R95]T
M;VME;G,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@5&AE(&1A=&$@='EP
M97,@;V8@=&AE('9A<FEO=7,@96QE;65N=',@:6X@96%C:"!P<F5P87)E9"!S
M=&%T96UE;G0*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1P
M<F5P87)E7W1Y<&5S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1H92!P
M<F5P87)E9"!Q=65R:65S"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@
M('9A<B`D<')E<&%R961?<75E<FEE<R`](&%R<F%Y*"D["@H*("`@("\O('U]
M?0H@("`@+R\@>WM[($1"7V-O;6UO;@H*("`@("\J*@H@("`@("H@5&AI<R!C
M;VYS=')U8W1O<B!C86QL<R`\:V)D/B1T:&ES+3Y014%2*"=$0E]%<G)O<B<I
M/"]K8F0^"B`@("`@*@H@("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@
M(&9U;F-T:6]N($1"7V-O;6UO;B@I"B`@("!["B`@("`@("`@)'1H:7,M/E!%
M05(H)T1"7T5R<F]R)RD["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M7U]S;&5E<"@I"@H@("`@+RHJ"B`@("`@*B!!=71O;6%T:6-A;&QY(&EN9&EC
M871E<R!W:&EC:"!P<F]P97)T:65S('-H;W5L9"!B92!S879E9`H@("`@("H@
M=VAE;B!02%`G<R!S97)I86QI>F4H*2!F=6YC=&EO;B!I<R!C86QL960*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!T:&4@87)R87D@;V8@<')O<&5R
M=&EE<R!N86UE<R!T:&%T('-H;W5L9"!B92!S879E9`H@("`@("HO"B`@("!F
M=6YC=&EO;B!?7W-L965P*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/F-O
M;FYE8W1I;VXI('L*("`@("`@("`@("`@+R\@1&]N)W0@9&ES8V]N;F5C="@I
M+"!P96]P;&4@=7-E('-E<FEA;&EZ92@I(&9O<B!M86YY(')E87-O;G,*("`@
M("`@("`@("`@)'1H:7,M/G=A<U]C;VYN96-T960@/2!T<G5E.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YW87-?8V]N;F5C=&5D(#T@
M9F%L<V4["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^875T
M;V-O;6UI="DI('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"=A=71O8V]M
M;6ET)RP*("`@("`@("`@("`@("`@("`@("`@("`@("=D8G-Y;G1A>"<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`G9'-N)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("=F96%T=7)E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`G9F5T8VAM;V1E)RP*("`@("`@("`@("`@("`@("`@("`@("`@("=F971C
M:&UO9&5?;V)J96-T7V-L87-S)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("=O<'1I;VYS)RP*("`@("`@("`@("`@("`@("`@("`@("`@("=W87-?8V]N
M;F5C=&5D)RP*("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"=D8G-Y;G1A>"<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`G9'-N)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("=F96%T=7)E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`G
M9F5T8VAM;V1E)RP*("`@("`@("`@("`@("`@("`@("`@("`@("=F971C:&UO
M9&5?;V)J96-T7V-L87-S)RP*("`@("`@("`@("`@("`@("`@("`@("`@("=O
M<'1I;VYS)RP*("`@("`@("`@("`@("`@("`@("`@("`@("=W87-?8V]N;F5C
M=&5D)RP*("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@?0H@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(%]?=V%K975P*"D*"B`@("`O*BH*("`@
M("`J($%U=&]M871I8V%L;'D@<F5C;VYN96-T<R!T;R!T:&4@9&%T86)A<V4@
M=VAE;B!02%`G<R!U;G-E<FEA;&EZ92@I"B`@("`@*B!F=6YC=&EO;B!I<R!C
M86QL960*("`@("`J"B`@("`@*B!4:&4@<F5C;VYN96-T:6]N(&%T=&5M<'0@
M:7,@;VYL>2!P97)F;W)M960@:68@=&AE(&]B:F5C="!W87,@8V]N;F5C=&5D
M"B`@("`@*B!A="!T:&4@=&EM92!02%`G<R!S97)I86QI>F4H*2!F=6YC=&EO
M;B!W87,@<G5N+@H@("`@("H*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO
M"B`@("!F=6YC=&EO;B!?7W=A:V5U<"@I"B`@("!["B`@("`@("`@:68@*"1T
M:&ES+3YW87-?8V]N;F5C=&5D*2!["B`@("`@("`@("`@("1T:&ES+3YC;VYN
M96-T*"1T:&ES+3YD<VXL("1T:&ES+3YO<'1I;VYS*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@7U]T;U-T<FEN9R@I"@H@("`@
M+RHJ"B`@("`@*B!!=71O;6%T:6,@<W1R:6YG(&-O;G9E<G-I;VX@9F]R(%!(
M4"`U"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(&$@<W1R:6YG(&1E
M<V-R:6)I;F<@=&AE(&-U<G)E;G0@4$5!4B!$0B!O8FIE8W0*("`@("`J"B`@
M("`@*B!`<VEN8V4@365T:&]D(&%V86EL86)L92!S:6YC92!296QE87-E(#$N
M-RXP"B`@("`@*B\*("`@(&9U;F-T:6]N(%]?=&]3=')I;F<H*0H@("`@>PH@
M("`@("`@("1I;F9O(#T@<W1R=&]L;W=E<BAG971?8VQA<W,H)'1H:7,I*3L*
M("`@("`@("`D:6YF;R`N/2`@)SH@*'!H<'1Y<&4])R`N("1T:&ES+3YP:'!T
M>7!E("X*("`@("`@("`@("`@("`@("`@)RP@9&)S>6YT87@])R`N("1T:&ES
M+3YD8G-Y;G1A>"`N"B`@("`@("`@("`@("`@("`@("<I)SL*("`@("`@("!I
M9B`H)'1H:7,M/F-O;FYE8W1I;VXI('L*("`@("`@("`@("`@)&EN9F\@+CT@
M)R!;8V]N;F5C=&5D72<["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D:6YF
M;SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!T;U-T<FEN9R@I"@H@
M("`@+RHJ"B`@("`@*B!$15!214-!5$5$.B`@4W1R:6YG(&-O;G9E<G-I;VX@
M;65T:&]D"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(&$@<W1R:6YG
M(&1E<V-R:6)I;F<@=&AE(&-U<G)E;G0@4$5!4B!$0B!O8FIE8W0*("`@("`J
M"B`@("`@*B!`9&5P<F5C871E9"!-971H;V0@9&5P<F5C871E9"!I;B!296QE
M87-E(#$N-RXP"B`@("`@*B\*("`@(&9U;F-T:6]N('1O4W1R:6YG*"D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/E]?=&]3=')I;F<H*3L*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!Q=6]T95-T<FEN9R@I"@H@("`@+RHJ
M"B`@("`@*B!$15!214-!5$5$.B!1=6]T97,@82!S=')I;F<@<V\@:70@8V%N
M(&)E('-A9F5L>2!U<V5D('=I=&AI;B!S=')I;F<*("`@("`J(&1E;&EM:71E
M<G,@:6X@82!Q=65R>0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T
M<FEN9R`@=&AE('-T<FEN9R!T;R!B92!Q=6]T960*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@=&AE('%U;W1E9"!S=')I;F<*("`@("`J"B`@("`@
M*B!`<V5E($1"7V-O;6UO;CHZ<75O=&53;6%R="@I+"!$0E]C;VUM;VXZ.F5S
M8V%P95-I;7!L92@I"B`@("`@*B!`9&5P<F5C871E9"!-971H;V0@9&5P<F5C
M871E9"!S;VUE('1I;64@8F5F;W)E(%)E;&5A<V4@,2XR"B`@("`@*B\*("`@
M(&9U;F-T:6]N('%U;W1E4W1R:6YG*"1S=')I;F<I"B`@("!["B`@("`@("`@
M)'-T<FEN9R`]("1T:&ES+3YQ=6]T92@D<W1R:6YG*3L*("`@("`@("!I9B`H
M)'-T<FEN9WLP?2`]/2`B)R(I('L*("`@("`@("`@("`@<F5T=7)N('-U8G-T
M<B@D<W1R:6YG+"`Q+"`M,2D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D
M<W1R:6YG.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('%U;W1E*"D*
M"B`@("`O*BH*("`@("`J($1%4%)%0T%4140Z(%%U;W1E<R!A('-T<FEN9R!S
M;R!I="!C86X@8F4@<V%F96QY('5S960@:6X@82!Q=65R>0H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'-T<FEN9R`@=&AE('-T<FEN9R!T;R!Q=6]T
M90H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@<75O=&5D('-T
M<FEN9R!O<B!T:&4@<W1R:6YG(#QS86UP/DY53$P\+W-A;7`^"B`@("`@*B`@
M("`@("`@("`@("`@("`@(&EF('1H92!V86QU92!S=6)M:71T960@:7,@/&MB
M9#YN=6QL/"]K8F0^+@H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIQ
M=6]T95-M87)T*"DL($1"7V-O;6UO;CHZ97-C87!E4VEM<&QE*"D*("`@("`J
M($!D97!R96-A=&5D($1E<')E8V%T960@:6X@<F5L96%S92`Q+C8N,`H@("`@
M("HO"B`@("!F=6YC=&EO;B!Q=6]T92@D<W1R:6YG(#T@;G5L;"D*("`@('L*
M("`@("`@("!R971U<FX@*"1S=')I;F<@/3T](&YU;&PI(#\@)TY53$PG"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(G(B`N('-T<E]R
M97!L86-E*"(G(BP@(B<G(BP@)'-T<FEN9RD@+B`B)R(["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@<75O=&5)9&5N=&EF:65R*"D*"B`@("`O*BH*
M("`@("`J(%%U;W1E<R!A('-T<FEN9R!S;R!I="!C86X@8F4@<V%F96QY('5S
M960@87,@82!T86)L92!O<B!C;VQU;6X@;F%M90H@("`@("H*("`@("`J($1E
M;&EM:71I;F<@<W1Y;&4@9&5P96YD<R!O;B!W:&EC:"!D871A8F%S92!D<FEV
M97(@:7,@8F5I;F<@=7-E9"X*("`@("`J"B`@("`@*B!.3U1%.B!J=7-T(&)E
M8V%U<V4@>6]U($-!3B!U<V4@9&5L:6UI=&5D(&ED96YT:69I97)S(&1O97-N
M)W0@;65A;@H@("`@("H@>6]U(%-(3U5,1"!U<V4@=&AE;2X@($EN(&=E;F5R
M86PL('1H97D@96YD('5P(&-A=7-I;F<@=V%Y(&UO<F4*("`@("`J('!R;V)L
M96US('1H86X@=&AE>2!S;VQV92X*("`@("`J"B`@("`@*B!0;W)T86)I;&ET
M>2!I<R!B<F]K96X@8GD@=7-I;F<@=&AE(&9O;&QO=VEN9R!C:&%R86-T97)S
M(&EN<VED90H@("`@("H@9&5L:6UI=&5D(&ED96YT:69I97)S.@H@("`@("H@
M("`K(&)A8VMT:6-K("@\:V)D/F`\+VMB9#XI("TM(&1U92!T;R!->5-13`H@
M("`@("H@("`K(&1O=6)L92!Q=6]T92`H/&MB9#XB/"]K8F0^*2`M+2!D=64@
M=&\@3W)A8VQE"B`@("`@*B`@("L@8G)A8VME=',@*#QK8F0^6SPO:V)D/B!O
M<B`\:V)D/ET\+VMB9#XI("TM(&1U92!T;R!!8V-E<W,*("`@("`J"B`@("`@
M*B!$96QI;6ET960@:61E;G1I9FEE<G,@87)E(&MN;W=N('1O(&=E;F5R86QL
M>2!W;W)K(&-O<G)E8W1L>2!U;F1E<@H@("`@("H@=&AE(&9O;&QO=VEN9R!D
M<FEV97)S.@H@("`@("H@("`K(&US<W%L"B`@("`@*B`@("L@;7ES<6P*("`@
M("`J("`@*R!M>7-Q;&D*("`@("`J("`@*R!O8VDX"B`@("`@*B`@("L@;V1B
M8RAA8V-E<W,I"B`@("`@*B`@("L@;V1B8RAD8C(I"B`@("`@*B`@("L@<&=S
M<6P*("`@("`J("`@*R!S<6QI=&4*("`@("`J("`@*R!S>6)A<V4@*&UU<W0@
M97AE8W5T92`\:V)D/G-E="!Q=6]T961?:61E;G1I9FEE<B!O;CPO:V)D/B!S
M;VUE=&EM90H@("`@("H@("`@('!R:6]R('1O('5S92D*("`@("`J"B`@("`@
M*B!);G1E<D)A<V4@9&]E<VXG="!S965M('1O(&)E(&%B;&4@=&\@=7-E(&1E
M;&EM:71E9"!I9&5N=&EF:65R<PH@("`@("H@=FEA(%!(4"`T+B`@5&AE>2!W
M;W)K(&9I;F4@=6YD97(@4$A0(#4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<W1R("!T:&4@:61E;G1I9FEE<B!N86UE('1O(&)E('%U;W1E9`H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@<75O=&5D(&ED96YT
M:69I97(*("`@("`J"B`@("`@*B!`<VEN8V4@365T:&]D(&%V86EL86)L92!S
M:6YC92!296QE87-E(#$N-BXP"B`@("`@*B\*("`@(&9U;F-T:6]N('%U;W1E
M261E;G1I9FEE<B@D<W1R*0H@("`@>PH@("`@("`@(')E='5R;B`G(B<@+B!S
M=')?<F5P;&%C92@G(B<L("<B(B<L("1S='(I("X@)R(G.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[('%U;W1E4VUA<G0H*0H*("`@("\J*@H@("`@
M("H@1F]R;6%T<R!I;G!U="!S;R!I="!C86X@8F4@<V%F96QY('5S960@:6X@
M82!Q=65R>0H@("`@("H*("`@("`J(%1H92!O=71P=70@9&5P96YD<R!O;B!T
M:&4@4$A0(&1A=&$@='EP92!O9B!I;G!U="!A;F0@=&AE(&1A=&%B87-E"B`@
M("`@*B!T>7!E(&)E:6YG('5S960N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI
M>&5D("1I;B`@=&AE(&1A=&$@=&\@8F4@9F]R;6%T=&5D"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@=&AE(&9O<FUA='1E9"!D871A+B`@5&AE(&9O
M<FUA="!D97!E;F1S(&]N('1H92!I;G!U="=S"B`@("`@*B`@("`@("`@("`@
M("`@("`@4$A0('1Y<&4Z"B`@("`@*B`\=6P^"B`@("`@*B`@/&QI/@H@("`@
M("H@("`@/&MB9#YI;G!U=#PO:V)D/B`M/B`\<V%M<#YR971U<FYS/"]S86UP
M/@H@("`@("H@(#PO;&D^"B`@("`@*B`@/&QI/@H@("`@("H@("`@/&MB9#YN
M=6QL/"]K8F0^("T^('1H92!S=')I;F<@/'-A;7`^3E5,3#PO<V%M<#X*("`@
M("`J("`\+VQI/@H@("`@("H@(#QL:3X*("`@("`J("`@(#QK8F0^:6YT96=E
M<CPO:V)D/B!O<B`\:V)D/F1O=6)L93PO:V)D/B`M/B!T:&4@=6YQ=6]T960@
M;G5M8F5R"B`@("`@*B`@/"]L:3X*("`@("`J("`\;&D^"B`@("`@*B`@("`\
M:V)D/F)O;VP\+VMB9#X@+3X@;W5T<'5T(&1E<&5N9',@;VX@=&AE(&1R:79E
M<B!I;B!U<V4*("`@("`J("`@($UO<W0@9')I=F5R<R!R971U<FX@:6YT96=E
M<G,Z(#QS86UP/C$\+W-A;7`^(&EF"B`@("`@*B`@("`\:V)D/G1R=64\+VMB
M9#X@;W(@/'-A;7`^,#PO<V%M<#X@:68*("`@("`J("`@(#QK8F0^9F%L<V4\
M+VMB9#XN"B`@("`@*B`@("!3;VUE(')E='5R;B!S=')I;F=S.B`\<V%M<#Y4
M4E5%/"]S86UP/B!I9@H@("`@("H@("`@/&MB9#YT<G5E/"]K8F0^(&]R(#QS
M86UP/D9!3%-%/"]S86UP/B!I9@H@("`@("H@("`@/&MB9#YF86QS93PO:V)D
M/BX*("`@("`J("`@($9I;F%L;'D@;VYE(')E='5R;G,@<W1R:6YG<SH@/'-A
M;7`^5#PO<V%M<#X@:68*("`@("`J("`@(#QK8F0^=')U93PO:V)D/B!O<B`\
M<V%M<#Y&/"]S86UP/B!I9@H@("`@("H@("`@/&MB9#YF86QS93PO:V)D/BX@
M2&5R92!I<R!A(&QI<W0@;V8@96%C:"!$0DU3+`H@("`@("H@("`@=&AE('9A
M;'5E<R!R971U<FYE9"!A;F0@=&AE('-U9V=E<W1E9"!C;VQU;6X@='EP93H*
M("`@("`J("`@(#QU;#X*("`@("`J("`@("`@/&QI/@H@("`@("H@("`@("`@
M(#QK8F0^9&)A<V4\+VMB9#X@+3X@/'-A;7`^5"]&/"]S86UP/@H@("`@("H@
M("`@("`@("@\:V)D/DQO9VEC86P\+VMB9#XI"B`@("`@*B`@("`@(#PO;&D^
M"B`@("`@*B`@("`@(#QL:3X*("`@("`J("`@("`@("`\:V)D/F9B87-E/"]K
M8F0^("T^(#QS86UP/E12544O1D%,4T4\+W-A;7`^"B`@("`@*B`@("`@("`@
M*#QK8F0^0D]/3$5!3CPO:V)D/BD*("`@("`J("`@("`@/"]L:3X*("`@("`J
M("`@("`@/&QI/@H@("`@("H@("`@("`@(#QK8F0^:6)A<V4\+VMB9#X@+3X@
M/'-A;7`^,2\P/"]S86UP/@H@("`@("H@("`@("`@("@\:V)D/E--04Q,24Y4
M/"]K8F0^*2!;,5T*("`@("`J("`@("`@/"]L:3X*("`@("`J("`@("`@/&QI
M/@H@("`@("H@("`@("`@(#QK8F0^:69X/"]K8F0^("T^(#QS86UP/C$O,#PO
M<V%M<#X*("`@("`J("`@("`@("`H/&MB9#Y334%,3$E.5#PO:V)D/BD@6S%=
M"B`@("`@*B`@("`@(#PO;&D^"B`@("`@*B`@("`@(#QL:3X*("`@("`J("`@
M("`@("`\:V)D/FUS<6P\+VMB9#X@+3X@/'-A;7`^,2\P/"]S86UP/@H@("`@
M("H@("`@("`@("@\:V)D/DE.5$5'15(\+VMB9#XI"B`@("`@*B`@("`@(#PO
M;&D^"B`@("`@*B`@("`@(#QL:3X*("`@("`J("`@("`@("`\:V)D/FUS<W%L
M/"]K8F0^("T^(#QS86UP/C$O,#PO<V%M<#X*("`@("`J("`@("`@("`H/&MB
M9#Y"250\+VMB9#XI"B`@("`@*B`@("`@(#PO;&D^"B`@("`@*B`@("`@(#QL
M:3X*("`@("`J("`@("`@("`\:V)D/FUY<W%L/"]K8F0^("T^(#QS86UP/C$O
M,#PO<V%M<#X*("`@("`J("`@("`@("`H/&MB9#Y424Y924Y4*#$I/"]K8F0^
M*0H@("`@("H@("`@("`\+VQI/@H@("`@("H@("`@("`\;&D^"B`@("`@*B`@
M("`@("`@/&MB9#YM>7-Q;&D\+VMB9#X@+3X@/'-A;7`^,2\P/"]S86UP/@H@
M("`@("H@("`@("`@("@\:V)D/E1)3EE)3E0H,2D\+VMB9#XI"B`@("`@*B`@
M("`@(#PO;&D^"B`@("`@*B`@("`@(#QL:3X*("`@("`J("`@("`@("`\:V)D
M/F]C:3@\+VMB9#X@+3X@/'-A;7`^,2\P/"]S86UP/@H@("`@("H@("`@("`@
M("@\:V)D/DY534)%4B@Q*3PO:V)D/BD*("`@("`J("`@("`@/"]L:3X*("`@
M("`J("`@("`@/&QI/@H@("`@("H@("`@("`@(#QK8F0^;V1B8SPO:V)D/B`M
M/B`\<V%M<#XQ+S`\+W-A;7`^"B`@("`@*B`@("`@("`@*#QK8F0^4TU!3$Q)
M3E0\+VMB9#XI(%LQ70H@("`@("H@("`@("`\+VQI/@H@("`@("H@("`@("`\
M;&D^"B`@("`@*B`@("`@("`@/&MB9#YP9W-Q;#PO:V)D/B`M/B`\<V%M<#Y4
M4E5%+T9!3%-%/"]S86UP/@H@("`@("H@("`@("`@("@\:V)D/D)/3TQ%04X\
M+VMB9#XI"B`@("`@*B`@("`@(#PO;&D^"B`@("`@*B`@("`@(#QL:3X*("`@
M("`J("`@("`@("`\:V)D/G-Q;&ET93PO:V)D/B`M/B`\<V%M<#XQ+S`\+W-A
M;7`^"B`@("`@*B`@("`@("`@*#QK8F0^24Y414=%4CPO:V)D/BD*("`@("`J
M("`@("`@/"]L:3X*("`@("`J("`@("`@/&QI/@H@("`@("H@("`@("`@(#QK
M8F0^<WEB87-E/"]K8F0^("T^(#QS86UP/C$O,#PO<V%M<#X*("`@("`J("`@
M("`@("`H/&MB9#Y424Y924Y4*#$I/"]K8F0^*0H@("`@("H@("`@("`\+VQI
M/@H@("`@("H@("`@/"]U;#X*("`@("`J("`@(%LQ72!!8V-O;6UO9&%T92!T
M:&4@;&]W97-T(&-O;6UO;B!D96YO;6EN871O<B!B96-A=7-E(&YO="!A;&P*
M("`@("`J("`@('9E<G-I;VYS(&]F(&AA=F4@/&MB9#Y"3T],14%./"]K8F0^
M+@H@("`@("H@(#PO;&D^"B`@("`@*B`@/&QI/@H@("`@("H@("`@;W1H97(@
M*&EN8VQU9&EN9R!S=')I;F=S(&%N9"!N=6UE<FEC('-T<FEN9W,I("T^"B`@
M("`@*B`@("!T:&4@9&%T82!W:71H('-I;F=L92!Q=6]T97,@97-C87!E9"!B
M>2!P<F5C965D:6YG"B`@("`@*B`@("!S:6YG;&4@<75O=&5S+"!B86-K<VQA
M<VAE<R!A<F4@97-C87!E9"!B>2!P<F5C965D:6YG"B`@("`@*B`@("!B86-K
M<VQA<VAE<RP@=&AE;B!T:&4@=VAO;&4@<W1R:6YG(&ES(&5N8V%P<W5L871E
M9`H@("`@("H@("`@8F5T=V5E;B!S:6YG;&4@<75O=&5S"B`@("`@*B`@/"]L
M:3X*("`@("`J(#PO=6P^"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ
M.F5S8V%P95-I;7!L92@I"B`@("`@*B!`<VEN8V4@365T:&]D(&%V86EL86)L
M92!S:6YC92!296QE87-E(#$N-BXP"B`@("`@*B\*("`@(&9U;F-T:6]N('%U
M;W1E4VUA<G0H)&EN*0H@("`@>PH@("`@("`@(&EF("AI<U]I;G0H)&EN*2!\
M?"!I<U]D;W5B;&4H)&EN*2D@>PH@("`@("`@("`@("!R971U<FX@)&EN.PH@
M("`@("`@('T@96QS96EF("AI<U]B;V]L*"1I;BDI('L*("`@("`@("`@("`@
M<F5T=7)N("1I;B`_(#$@.B`P.PH@("`@("`@('T@96QS96EF("AI<U]N=6QL
M*"1I;BDI('L*("`@("`@("`@("`@<F5T=7)N("=.54Q,)SL*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@(B<B("X@)'1H:7,M/F5S8V%P
M95-I;7!L92@D:6XI("X@(B<B.PH@("`@("`@('T*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!E<V-A<&53:6UP;&4H*0H*("`@("\J*@H@("`@("H@
M17-C87!E<R!A('-T<FEN9R!A8V-O<F1I;F<@=&\@=&AE(&-U<G)E;G0@1$)-
M4R=S('-T86YD87)D<PH@("`@("H*("`@("`J($EN(%-13&ET92P@=&AI<R!M
M86ME<R!T:&EN9W,@<V%F92!F;W(@:6YS97)T<R]U<&1A=&5S+"!B=70@;6%Y
M"B`@("`@*B!C875S92!P<F]B;&5M<R!W:&5N('!E<F9O<FUI;F<@=&5X="!C
M;VUP87)I<V]N<R!A9V%I;G-T(&-O;'5M;G,*("`@("`J(&-O;G1A:6YI;F<@
M8FEN87)Y(&1A=&$N(%-E92!T:&4*("`@("`J('M`;&EN:R!H='1P.B\O<&AP
M+FYE="]S<6QI=&5?97-C87!E7W-T<FEN9R!02%`@;6%N=6%L?2!F;W(@;6]R
M92!I;F9O+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T<B`@=&AE
M('-T<FEN9R!T;R!B92!E<V-A<&5D"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@('1H92!E<V-A<&5D('-T<FEN9PH@("`@("H*("`@("`J($!S964@
M1$)?8V]M;6]N.CIQ=6]T95-M87)T*"D*("`@("`J($!S:6YC92!-971H;V0@
M879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XV+C`*("`@("`J+PH@("`@9G5N
M8W1I;VX@97-C87!E4VEM<&QE*"1S='(I"B`@("!["B`@("`@("`@<F5T=7)N
M('-T<E]R97!L86-E*"(G(BP@(B<G(BP@)'-T<BD["B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@<')O=FED97,H*0H*("`@("\J*@H@("`@("H@5&5L
M;',@=VAE=&AE<B!T:&4@<')E<V5N="!D<FEV97(@<W5P<&]R=',@82!G:79E
M;B!F96%T=7)E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F5A='5R
M92`@=&AE(&9E871U<F4@>6]U)W)E(&-U<FEO=7,@86)O=70*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VP@('=H971H97(@=&AI<R!D<FEV97(@<W5P<&]R
M=',@)&9E871U<F4*("`@("`J+PH@("`@9G5N8W1I;VX@<')O=FED97,H)&9E
M871U<F4I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YF96%T=7)E<ULD
M9F5A='5R95T["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<V5T1F5T
M8VA-;V1E*"D*"B`@("`O*BH*("`@("`J(%-E=',@=&AE(&9E=&-H(&UO9&4@
M=&AA="!S:&]U;&0@8F4@=7-E9"!B>2!D969A=6QT(&9O<B!Q=65R>2!R97-U
M;'1S"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&9E=&-H;6]D92`@
M("!$0E]&151#2$U/1$5?3U)$15)%1"P@1$)?1D540TA-3T1%7T%34T]#"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!O<B!$0E]&151#
M2$U/1$5?3T)*14-4"B`@("`@*B!`<&%R86T@<W1R:6YG("1O8FIE8W1?8VQA
M<W,@('1H92!C;&%S<R!N86UE(&]F('1H92!O8FIE8W0@=&\@8F4@<F5T=7)N
M960*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)Y('1H
M92!F971C:"!M971H;V1S('=H96X@=&AE"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!$0E]&151#2$U/1$5?3T)*14-4(&UO9&4@:7,@
M<V5L96-T960N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!)9B!N;R!C;&%S<R!I<R!S<&5C:69I960@8GD@9&5F875L="!A(&-A<W0*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1O(&]B:F5C
M="!F<F]M('1H92!A<W-O8R!A<G)A>2!R;W<@=VEL;"!B90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@9&]N92X@(%1H97)E(&ES(&%L
M<V\@=&AE('!O<VEB:6QI='D@=&\@=7-E"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!A;F0@97AT96YD('1H92`G1$)?<F]W)R!C;&%S
M<RX*("`@("`J"B`@("`@*B!`<V5E($1"7T9%5$-(34]$15]/4D1%4D5$+"!$
M0E]&151#2$U/1$5?05-33T,L($1"7T9%5$-(34]$15]/0DI%0U0*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V5T1F5T8VA-;V1E*"1F971C:&UO9&4L("1O8FIE
M8W1?8VQA<W,@/2`G<W1D0VQA<W,G*0H@("`@>PH@("`@("`@('-W:71C:"`H
M)&9E=&-H;6]D92D@>PH@("`@("`@("`@("!C87-E($1"7T9%5$-(34]$15]/
M0DI%0U0Z"B`@("`@("`@("`@("`@("`D=&AI<RT^9F5T8VAM;V1E7V]B:F5C
M=%]C;&%S<R`]("1O8FIE8W1?8VQA<W,["B`@("`@("`@("`@(&-A<V4@1$)?
M1D540TA-3T1%7T]21$52140Z"B`@("`@("`@("`@(&-A<V4@1$)?1D540TA-
M3T1%7T%34T]#.@H@("`@("`@("`@("`@("`@)'1H:7,M/F9E=&-H;6]D92`]
M("1F971C:&UO9&4["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@9&5F875L=#H*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@G:6YV86QI9"!F971C:&UO9&4@;6]D92<I.PH@("`@("`@('T*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!S971/<'1I;VXH*0H*("`@
M("\J*@H@("`@("H@4V5T<R!R=6XM=&EM92!C;VYF:6=U<F%T:6]N(&]P=&EO
M;G,@9F]R(%!%05(@1$(*("`@("`J"B`@("`@*B!/<'1I;VYS+"!T:&5I<B!D
M871A('1Y<&5S+"!D969A=6QT('9A;'5E<R!A;F0@9&5S8W)I<'1I;VXZ"B`@
M("`@*B`\=6P^"B`@("`@*B`\;&D^"B`@("`@*B`\=F%R/F%U=&]F<F5E/"]V
M87(^(#QK8F0^8F]O;&5A;CPO:V)D/B`](#QS86UP/F9A;'-E/"]S86UP/@H@
M("`@("H@("`@("`\8G(@+SYS:&]U;&0@<F5S=6QT<R!B92!F<F5E9"!A=71O
M;6%T:6-A;&QY('=H96X@=&AE<F4@87)E(&YO"B`@("`@*B`@("`@("`@("`@
M(&UO<F4@<F]W<S\*("`@("`J(#PO;&D^/&QI/@H@("`@("H@/'9A<CYR97-U
M;'1?8G5F9F5R:6YG/"]V87(^(#QK8F0^:6YT96=E<CPO:V)D/B`](#QS86UP
M/C4P,#PO<V%M<#X*("`@("`J("`@("`@/&)R("\^:&]W(&UA;GD@<F]W<R!O
M9B!T:&4@<F5S=6QT('-E="!S:&]U;&0@8F4@8G5F9F5R960_"B`@("`@*B`@
M("`@(#QB<B`O/DEN(&UY<W%L.B!M>7-Q;%]U;F)U9F9E<F5D7W%U97)Y*"D@
M:7,@=7-E9"!I;G-T96%D(&]F"B`@("`@*B`@("`@("`@("`@(&UY<W%L7W%U
M97)Y*"D@:68@=&AI<R!V86QU92!I<R`P+B`@*%)E;&5A<V4@,2XW+C`I"B`@
M("`@*B`@("`@(#QB<B`O/DEN(&]C:3@Z('1H:7,@=F%L=64@:7,@<&%S<V5D
M('1O(&]C:7-E='!R969E=&-H*"DN"B`@("`@*B`@("`@("`@("`@("A296QE
M87-E(#$N-RXP*0H@("`@("H@/"]L:3X\;&D^"B`@("`@*B`\=F%R/F1E8G5G
M/"]V87(^(#QK8F0^:6YT96=E<CPO:V)D/B`](#QS86UP/C`\+W-A;7`^"B`@
M("`@*B`@("`@(#QB<B`O/F1E8G5G(&QE=F5L"B`@("`@*B`\+VQI/CQL:3X*
M("`@("`J(#QV87(^<&5R<VES=&5N=#PO=F%R/B`\:V)D/F)O;VQE86X\+VMB
M9#X@/2`\<V%M<#YF86QS93PO<V%M<#X*("`@("`J("`@("`@/&)R("\^<VAO
M=6QD('1H92!C;VYN96-T:6]N(&)E('!E<G-I<W1E;G0_"B`@("`@*B`\+VQI
M/CQL:3X*("`@("`J(#QV87(^<&]R=&%B:6QI='D\+W9A<CX@/&MB9#YI;G1E
M9V5R/"]K8F0^(#T@/'-A;7`^1$)?4$]25$%"24Q)5%E?3D].13PO<V%M<#X*
M("`@("`J("`@("`@/&)R("\^<&]R=&%B:6QI='D@;6]D92!C;VYS=&%N="`H
M<V5E(&)E;&]W*0H@("`@("H@/"]L:3X\;&D^"B`@("`@*B`\=F%R/G-E<6YA
M;65?9F]R;6%T/"]V87(^(#QK8F0^<W1R:6YG/"]K8F0^(#T@/'-A;7`^)7-?
M<V5Q/"]S86UP/@H@("`@("H@("`@("`\8G(@+SYT:&4@<W!R:6YT9B@I(&9O
M<FUA="!S=')I;F<@=7-E9"!O;B!S97%U96YC92!N86UE<RX@(%1H:7,*("`@
M("`J("`@("`@("`@("`@9F]R;6%T(&ES(&%P<&QI960@=&\@<V5Q=65N8V4@
M;F%M97,@<&%S<V5D('1O"B`@("`@*B`@("`@("`@("`@(&-R96%T95-E<75E
M;F-E*"DL(&YE>'1)1"@I(&%N9"!D<F]P4V5Q=65N8V4H*2X*("`@("`J(#PO
M;&D^/&QI/@H@("`@("H@/'9A<CYS<VP\+W9A<CX@/&MB9#YB;V]L96%N/"]K
M8F0^(#T@/'-A;7`^9F%L<V4\+W-A;7`^"B`@("`@*B`@("`@(#QB<B`O/G5S
M92!S<VP@=&\@8V]N;F5C=#\*("`@("`J(#PO;&D^"B`@("`@*B`\+W5L/@H@
M("`@("H*("`@("`J("TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM"B`@("`@*@H@("`@("H@4$]25$%"24Q)5%D@34]$15,*("`@
M("`J"B`@("`@*B!4:&5S92!M;V1E<R!A<F4@8FET=VES960L('-O('1H97D@
M8V%N(&)E(&-O;6)I;F5D('5S:6YG(#QK8F0^?#PO:V)D/@H@("`@("H@86YD
M(')E;6]V960@=7-I;F<@/&MB9#Y>/"]K8F0^+B`@4V5E('1H92!E>&%M<&QE
M<R!S96-T:6]N(&)E;&]W(&]N(&AO=PH@("`@("H@=&\@9&\@=&AI<RX*("`@
M("`J"B`@("`@*B`\<V%M<#Y$0E]03U)404))3$E465].3TY%/"]S86UP/@H@
M("`@("H@='5R;B!O9F8@86QL('!O<G1A8FEL:71Y(&9E871U<F5S"B`@("`@
M*@H@("`@("H@5&AI<R!M;V1E(&=E=',@875T;VUA=&EC86QL>2!T=7)N960@
M;VX@:68@=&AE(&1E<')E8V%T960*("`@("`J(#QV87(^;W!T:6UI>F4\+W9A
M<CX@;W!T:6]N(&=E=',@<V5T('1O(#QS86UP/G!E<F9O<FUA;F-E/"]S86UP
M/BX*("`@("`J"B`@("`@*@H@("`@("H@/'-A;7`^1$)?4$]25$%"24Q)5%E?
M3$]715)#05-%/"]S86UP/@H@("`@("H@8V]N=F5R="!N86UE<R!O9B!T86)L
M97,@86YD(&9I96QD<R!T;R!L;W=E<B!C87-E('=H96X@=7-I;F<*("`@("`J
M(#QK8F0^9V5T*B@I/"]K8F0^+"`\:V)D/F9E=&-H*B@I/"]K8F0^(&%N9"`\
M:V)D/G1A8FQE26YF;R@I/"]K8F0^"B`@("`@*@H@("`@("H@5&AI<R!M;V1E
M(&=E=',@875T;VUA=&EC86QL>2!T=7)N960@;VX@:6X@=&AE(&9O;&QO=VEN
M9R!D871A8F%S97,*("`@("`J(&EF('1H92!D97!R96-A=&5D(&]P=&EO;B`\
M=F%R/F]P=&EM:7IE/"]V87(^(&=E=',@<V5T('1O"B`@("`@*B`\<V%M<#YP
M;W)T86)I;&ET>3PO<V%M<#XZ"B`@("`@*B`K(&]C:3@*("`@("`J"B`@("`@
M*@H@("`@("H@/'-A;7`^1$)?4$]25$%"24Q)5%E?4E1224T\+W-A;7`^"B`@
M("`@*B!R:6=H="!T<FEM('1H92!D871A(&]U='!U="!B>2`\:V)D/F=E="HH
M*3PO:V)D/B`\:V)D/F9E=&-H*B@I/"]K8F0^"B`@("`@*@H@("`@("H*("`@
M("`J(#QS86UP/D1"7U!/4E1!0DE,25197T1%3$5415]#3U5.5#PO<V%M<#X*
M("`@("`J(&9O<F-E(')E<&]R=&EN9R!T:&4@;G5M8F5R(&]F(')O=W,@9&5L
M971E9`H@("`@("H*("`@("`J(%-O;64@1$)-4R=S(&1O;B=T(&-O=6YT('1H
M92!N=6UB97(@;V8@<F]W<R!D96QE=&5D('=H96X@<&5R9F]R;6EN9PH@("`@
M("H@<VEM<&QE(#QK8F0^1$5,151%($923TT@=&%B;&5N86UE/"]K8F0^('%U
M97)I97,N("!4:&ES('!O<G1A8FEL:71Y"B`@("`@*B!M;V1E('1R:6-K<R!S
M=6-H($1"35,G<R!I;G1O('1E;&QI;F<@=&AE(&-O=6YT(&)Y(&%D9&EN9PH@
M("`@("H@/'-A;7`^5TA%4D4@,3TQ/"]S86UP/B!T;R!T:&4@96YD(&]F(#QK
M8F0^1$5,151%/"]K8F0^('%U97)I97,N"B`@("`@*@H@("`@("H@5&AI<R!M
M;V1E(&=E=',@875T;VUA=&EC86QL>2!T=7)N960@;VX@:6X@=&AE(&9O;&QO
M=VEN9R!D871A8F%S97,*("`@("`J(&EF('1H92!D97!R96-A=&5D(&]P=&EO
M;B`\=F%R/F]P=&EM:7IE/"]V87(^(&=E=',@<V5T('1O"B`@("`@*B`\<V%M
M<#YP;W)T86)I;&ET>3PO<V%M<#XZ"B`@("`@*B`K(&9B<W%L"B`@("`@*B`K
M(&UY<W%L"B`@("`@*B`K(&UY<W%L:0H@("`@("H@*R!S<6QI=&4*("`@("`J
M"B`@("`@*@H@("`@("H@/'-A;7`^1$)?4$]25$%"24Q)5%E?3E5-4D]74SPO
M<V%M<#X*("`@("`J(&5N86)L92!H86-K('1H870@;6%K97,@/&MB9#YN=6U2
M;W=S*"D\+VMB9#X@=V]R:R!I;B!/<F%C;&4*("`@("`J"B`@("`@*B!4:&ES
M(&UO9&4@9V5T<R!A=71O;6%T:6-A;&QY('1U<FYE9"!O;B!I;B!T:&4@9F]L
M;&]W:6YG(&1A=&%B87-E<PH@("`@("H@:68@=&AE(&1E<')E8V%T960@;W!T
M:6]N(#QV87(^;W!T:6UI>F4\+W9A<CX@9V5T<R!S970@=&\*("`@("`J(#QS
M86UP/G!O<G1A8FEL:71Y/"]S86UP/CH*("`@("`J("L@;V-I.`H@("`@("H*
M("`@("`J"B`@("`@*B`\<V%M<#Y$0E]03U)404))3$E465]%4E)/4E,\+W-A
M;7`^"B`@("`@*B!M86ME<R!C97)T86EN(&5R<F]R(&UE<W-A9V5S(&EN(&-E
M<G1A:6X@9')I=F5R<R!C;VUP871I8FQE"B`@("`@*B!W:71H('1H;W-E(&9R
M;VT@;W1H97(@1$)-4R=S"B`@("`@*@H@("`@("H@*R!M>7-Q;"P@;7ES<6QI
M.B`@8VAA;F=E('5N:7%U92]P<FEM87)Y(&ME>2!C;VYS=')A:6YT<PH@("`@
M("H@("!$0E]%4E)/4E]!3%)%04197T5825-44R`M/B!$0E]%4E)/4E]#3TY3
M5%)!24Y4"B`@("`@*@H@("`@("H@*R!O9&)C*&%C8V5S<RDZ("!-4R=S($]$
M0D,@9')I=F5R(')E<&]R=',@)VYO('-U8V@@9FEE;&0G(&%S(&-O9&4*("`@
M("`J("`@,#<P,#$L('=H:6-H(&UE86YS("=T;V\@9F5W('!A<F%M971E<G,N
M)R`@5VAE;B!T:&ES(&]P=&EO;B!I<R!O;@H@("`@("H@("!T:&%T(&-O9&4@
M9V5T<R!M87!P960@=&\@1$)?15)23U)?3D]354-(1DE%3$0N"B`@("`@*B`@
M($1"7T524D]27TU)4TU!5$-(("T^($1"7T524D]27TY/4U5#2$9)14Q$"B`@
M("`@*@H@("`@("H@/'-A;7`^1$)?4$]25$%"24Q)5%E?3E5,3%]43U]%35!4
M63PO<V%M<#X*("`@("`J(&-O;G9E<G0@;G5L;"!V86QU97,@=&\@96UP='D@
M<W1R:6YG<R!I;B!D871A(&]U='!U="!B>2!G970J*"D@86YD"B`@("`@*B!F
M971C:"HH*2X@($YE961E9"!B96-A=7-E($]R86-L92!C;VYS:61E<G,@96UP
M='D@<W1R:6YG<R!T;R!B92!N=6QL+`H@("`@("H@=VAI;&4@;6]S="!O=&AE
M<B!$0DU3)W,@:VYO=R!T:&4@9&EF9F5R96YC92!B971W965N(&5M<'1Y(&%N
M9"!N=6QL+@H@("`@("H*("`@("`J"B`@("`@*B`\<V%M<#Y$0E]03U)404))
M3$E465]!3$P\+W-A;7`^"B`@("`@*B!T=7)N(&]N(&%L;"!P;W)T86)I;&ET
M>2!F96%T=7)E<PH@("`@("H*("`@("`J("TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM"B`@("`@*@H@("`@("H@17AA;7!L92`Q
M+B!3:6UP;&4@<V5T3W!T:6]N*"D@97AA;7!L90H@("`@("H@/&-O9&4^"B`@
M("`@*B`D9&(M/G-E=$]P=&EO;B@G875T;V9R964G+"!T<G5E*3L*("`@("`J
M(#PO8V]D93X*("`@("`J"B`@("`@*B!%>&%M<&QE(#(N(%!O<G1A8FEL:71Y
M(&9O<B!L;W=E<F-A<VEN9R!A;F0@=')I;6UI;F<*("`@("`J(#QC;V1E/@H@
M("`@("H@)&1B+3YS971/<'1I;VXH)W!O<G1A8FEL:71Y)RP*("`@("`J("`@
M("`@("`@("`@("`@("!$0E]03U)404))3$E465],3U=%4D-!4T4@?"!$0E]0
M3U)404))3$E465]25%))32D["B`@("`@*B`\+V-O9&4^"B`@("`@*@H@("`@
M("H@17AA;7!L92`S+B!!;&P@<&]R=&%B:6QI='D@;W!T:6]N<R!E>&-E<'0@
M=')I;6UI;F<*("`@("`J(#QC;V1E/@H@("`@("H@)&1B+3YS971/<'1I;VXH
M)W!O<G1A8FEL:71Y)RP*("`@("`J("`@("`@("`@("`@("`@("!$0E]03U)4
M04))3$E465]!3$P@7B!$0E]03U)404))3$E465]25%))32D["B`@("`@*B`\
M+V-O9&4^"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;W!T:6]N(&]P
M=&EO;B!N86UE"B`@("`@*B!`<&%R86T@;6EX960@("1V86QU92!V86QU92!F
M;W(@=&AE(&]P=&EO;@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/
M2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*
M("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ)&]P=&EO;G,*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V5T3W!T:6]N*"1O<'1I;VXL("1V86QU92D*("`@
M('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/F]P=&EO;G-;)&]P=&EO;ETI
M*2!["B`@("`@("`@("`@("1T:&ES+3YO<'1I;VYS6R1O<'1I;VY=(#T@)'9A
M;'5E.PH*("`@("`@("`@("`@+RH*("`@("`@("`@("`@("H@0F%C:W=A<F1S
M(&-O;7!A=&EB:6QI='D@8VAE8VL@9F]R('1H92!D97!R96-A=&5D("=O<'1I
M;6EZ92<*("`@("`@("`@("`@("H@;W!T:6]N+B`@1&]N92!H97)E(&EN(&-A
M<V4@<V5T=&EN9W,@8VAA;F=E(&%F=&5R(&-O;FYE8W1I;F<N"B`@("`@("`@
M("`@("`J+PH@("`@("`@("`@("!I9B`H)&]P=&EO;B`]/2`G;W!T:6UI>F4G
M*2!["B`@("`@("`@("`@("`@("!I9B`H)'9A;'5E(#T]("=P;W)T86)I;&ET
M>2<I('L*("`@("`@("`@("`@("`@("`@("!S=VET8V@@*"1T:&ES+3YP:'!T
M>7!E*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)V]C:3@G.@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F]P=&EO;G-;)W!O
M<G1A8FEL:71Y)UT@/0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!$0E]03U)404))3$E465],3U=%4D-!4T4@?`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!$0E]03U)404))3$E465].54U23U=3
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@("`@("`@("`@("`@(&-A<V4@)V9B<W%L)SH*("`@("`@("`@("`@("`@
M("`@("`@("`@8V%S92`G;7ES<6PG.@H@("`@("`@("`@("`@("`@("`@("`@
M("!C87-E("=M>7-Q;&DG.@H@("`@("`@("`@("`@("`@("`@("`@("!C87-E
M("=S<6QI=&4G.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@/0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!$0E]03U)404))3$E465]$14Q%5$5?0T]53E0[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==(#T@
M1$)?4$]25$%"24Q)5%E?3D].13L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(G5N:VYO=VX@;W!T
M:6]N("1O<'1I;VXB*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G
M971/<'1I;VXH*0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@=F%L=64@
M;V8@86X@;W!T:6]N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;W!T
M:6]N("!T:&4@;W!T:6]N(&YA;64@>6]U)W)E(&-U<FEO=7,@86)O=70*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!T:&4@;W!T:6]N)W,@=F%L=64*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3W!T:6]N*"1O<'1I;VXI"B`@("![
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YO<'1I;VYS6R1O<'1I;VY=*2D@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F]P=&EO;G-;)&]P=&EO;ET[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B
M=6YK;F]W;B!O<'1I;VX@)&]P=&EO;B(I.PH@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[('!R97!A<F4H*0H*("`@("\J*@H@("`@("H@4')E<&%R97,@
M82!Q=65R>2!F;W(@;75L=&EP;&4@97AE8W5T:6]N('=I=&@@97AE8W5T92@I
M"B`@("`@*@H@("`@("H@0W)E871E<R!A('%U97)Y('1H870@8V%N(&)E(')U
M;B!M=6QT:7!L92!T:6UE<RX@($5A8V@@=&EM92!I="!I<R!R=6XL"B`@("`@
M*B!T:&4@<&QA8V5H;VQD97)S+"!I9B!A;GDL('=I;&P@8F4@<F5P;&%C960@
M8GD@=&AE(&-O;G1E;G1S(&]F"B`@("`@*B!E>&5C=71E*"DG<R`D9&%T82!A
M<F=U;65N="X*("`@("`J"B`@("`@*B!4:')E92!T>7!E<R!O9B!P;&%C96AO
M;&1E<G,@8V%N(&)E('5S960Z"B`@("`@*B`@("L@/&MB9#X_/"]K8F0^("!S
M8V%L87(@=F%L=64@*&DN92X@<W1R:6YG<RP@:6YT96=E<G,I+B`@5&AE('-Y
M<W1E;0H@("`@("H@("`@("`@("`@("`@("`@("`@=VEL;"!A=71O;6%T:6-A
M;&QY('%U;W1E(&%N9"!E<V-A<&4@=&AE(&1A=&$N"B`@("`@*B`@("L@/&MB
M9#XA/"]K8F0^("!V86QU92!I<R!I;G-E<G1E9"`G87,@:7,G"B`@("`@*B`@
M("L@/&MB9#XF/"]K8F0^("!R97%U:7)E<R!A(&9I;&4@;F%M92X@(%1H92!F
M:6QE)W,@8V]N=&5N=',@9V5T"B`@("`@*B`@("`@("`@("`@("`@("`@("!I
M;G-E<G1E9"!I;G1O('1H92!Q=65R>2`H:2YE+B!S879I;F<@8FEN87)Y"B`@
M("`@*B`@("`@("`@("`@("`@("`@("!D871A(&EN(&$@9&(I"B`@("`@*@H@
M("`@("H@17AA;7!L92`Q+@H@("`@("H@/&-O9&4^"B`@("`@*B`D<W1H(#T@
M)&1B+3YP<F5P87)E*"=)3E-%4E0@24Y43R!T8FP@*&$L(&(L(&,I(%9!3%5%
M4R`H/RP@(2P@)BDG*3L*("`@("`J("1D871A(#T@87)R87DH"B`@("`@*B`@
M("`@(DIO:&XG<R!T97AT(BP*("`@("`J("`@("`B)VET)R=S(&=O;V0G(BP*
M("`@("`J("`@("`G9FEL96YA;64N='AT)PH@("`@("H@*3L*("`@("`J("1R
M97,@/2`D9&(M/F5X96-U=&4H)'-T:"P@)&1A=&$I.PH@("`@("H@/"]C;V1E
M/@H@("`@("H*("`@("`J(%5S92!B86-K<VQA<VAE<R!T;R!E<V-A<&4@<&QA
M8V5H;VQD97(@8VAA<F%C=&5R<R!I9B!Y;W4@9&]N)W0@=V%N=`H@("`@("H@
M=&AE;2!T;R!B92!I;G1E<G!R971E9"!A<R!P;&%C96AO;&1E<G,Z"B`@("`@
M*B`\<')E/@H@("`@("H@("`@(E501$%412!F;V\@4T54(&-O;#T_(%=(15)%
M(&-O;#TG;W9E<B!<)B!U;F1E<B<B"B`@("`@*B`\+W!R93X*("`@("`J"B`@
M("`@*B!7:71H('-O;64@9&%T86)A<V4@8F%C:V5N9',L('1H:7,@:7,@96UU
M;&%T960N"B`@("`@*@H@("`@("H@>T!I;G1E<FYA;"!I8F%S92!A;F0@;V-I
M."!H879E('1H96ER(&]W;B!P<F5P87)E*"D@;65T:&]D<RY]?0H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'%U97)Y("!T:&4@<75E<GD@=&\@8F4@
M<')E<&%R960*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!$0B!S=&%T
M96UE;G0@<F5S;W5R8V4@;VX@<W5C8V5S<RX@02!$0E]%<G)O<B!O8FIE8W0*
M("`@("`J("`@("`@("`@("`@("`@("!O;B!F86EL=7)E+@H@("`@("H*("`@
M("`J($!S964@1$)?8V]M;6]N.CIE>&5C=71E*"D*("`@("`J+PH@("`@9G5N
M8W1I;VX@<')E<&%R92@D<75E<GDI"B`@("!["B`@("`@("`@)'1O:V5N<R`@
M(#T@<')E9U]S<&QI="@G+R@H/SPA7%Q<*5LF/R%=*2\G+"`D<75E<GDL("TQ
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@4%)%1U]34$Q)5%]$
M14Q)35]#05!455)%*3L*("`@("`@("`D=&]K96X@("`@(#T@,#L*("`@("`@
M("`D='EP97,@("`@(#T@87)R87DH*3L*("`@("`@("`D;F5W=&]K96YS(#T@
M87)R87DH*3L*"B`@("`@("`@9F]R96%C:"`H)'1O:V5N<R!A<R`D=F%L*2![
M"B`@("`@("`@("`@('-W:71C:"`H)'9A;"D@>PH@("`@("`@("`@("`@("`@
M8V%S92`G/R<Z"B`@("`@("`@("`@("`@("`@("`@)'1Y<&5S6R1T;VME;BLK
M72`]($1"7U!!4D%-7U-#04Q!4CL*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@("`@(&-A<V4@)R8G.@H@("`@("`@("`@("`@("`@
M("`@("1T>7!E<ULD=&]K96XK*UT@/2!$0E]005)!35]/4$%1544["B`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E("<A
M)SH*("`@("`@("`@("`@("`@("`@("`D='EP97-;)'1O:V5N*RM=(#T@1$)?
M4$%204U?34E30SL*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@)&YE=W1O
M:V5N<UM=(#T@<')E9U]R97!L86-E*"<O7%Q<*%LF/R%=*2\G+"`B7%PQ(BP@
M)'9A;"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1T:&ES
M+3YP<F5P87)E7W1O:V5N<UM=(#T@)B1N97=T;VME;G,["B`@("`@("`@96YD
M*"1T:&ES+3YP<F5P87)E7W1O:V5N<RD["@H@("`@("`@("1K(#T@:V5Y*"1T
M:&ES+3YP<F5P87)E7W1O:V5N<RD["B`@("`@("`@)'1H:7,M/G!R97!A<F5?
M='EP97-;)&M=(#T@)'1Y<&5S.PH@("`@("`@("1T:&ES+3YP<F5P87)E9%]Q
M=65R:65S6R1K72`](&EM<&QO9&4H)R`G+"`D;F5W=&]K96YS*3L*"B`@("`@
M("`@<F5T=7)N("1K.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&%U
M=&]0<F5P87)E*"D*"B`@("`O*BH*("`@("`J($%U=&]M871I8V%L>2!G96YE
M<F%T97,@86X@:6YS97)T(&]R('5P9&%T92!Q=65R>2!A;F0@<&%S<R!I="!T
M;R!P<F5P87)E*"D*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T86)L
M92`@("`@("`@('1H92!T86)L92!N86UE"B`@("`@*B!`<&%R86T@87)R87D@
M("1T86)L95]F:65L9',@('1H92!A<G)A>2!O9B!F:65L9"!N86UE<PH@("`@
M("H@0'!A<F%M(&EN="`@("`D;6]D92`@("`@("`@("!A('1Y<&4@;V8@<75E
M<GD@=&\@;6%K93H*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@($1"7T%55$]1545265])3E-%4E0@;W(@1$)?05543U%515)97U501$%4
M10H@("`@("H@0'!A<F%M('-T<FEN9R`D=VAE<F4@("`@("`@("!F;W(@=7!D
M871E('%U97)I97,Z('1H92!72$5212!C;&%U<V4@=&\*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%P<&5N9"!T;R!T:&4@4U%,('-T
M871E;65N="X@($1O;B=T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I;F-L=61E('1H92`B5TA%4D4B(&ME>7=O<F0N"B`@("`@*@H@
M("`@("H@0')E='5R;B!R97-O=7)C92`@=&AE('%U97)Y(&AA;F1L90H@("`@
M("H*("`@("`J($!U<V5S($1"7V-O;6UO;CHZ<')E<&%R92@I+"!$0E]C;VUM
M;VXZ.F)U:6QD36%N:7!344PH*0H@("`@("HO"B`@("!F=6YC=&EO;B!A=71O
M4')E<&%R92@D=&%B;&4L("1T86)L95]F:65L9',L("1M;V1E(#T@1$)?0554
M3U%515)97TE.4T525"P*("`@("`@("`@("`@("`@("`@("`@("`@("1W:&5R
M92`](&9A;'-E*0H@("`@>PH@("`@("`@("1Q=65R>2`]("1T:&ES+3YB=6EL
M9$UA;FEP4U%,*"1T86)L92P@)'1A8FQE7V9I96QD<RP@)&UO9&4L("1W:&5R
M92D["B`@("`@("`@:68@*$1".CII<T5R<F]R*"1Q=65R>2DI('L*("`@("`@
M("`@("`@<F5T=7)N("1Q=65R>3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1T:&ES+3YP<F5P87)E*"1Q=65R>2D["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@875T;T5X96-U=&4H*0H*("`@("\J*@H@("`@("H@075T;VUA
M=&EC86QY(&=E;F5R871E<R!A;B!I;G-E<G0@;W(@=7!D871E('%U97)Y(&%N
M9"!C86QL('!R97!A<F4H*0H@("`@("H@86YD(&5X96-U=&4H*2!W:71H(&ET
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&%B;&4@("`@("`@("!T
M:&4@=&%B;&4@;F%M90H@("`@("H@0'!A<F%M(&%R<F%Y("`D9FEE;&1S7W9A
M;'5E<R!T:&4@87-S;V-I871I=F4@87)R87D@=VAE<F4@)&ME>2!I<R!A"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F:65L9"!N86UE
M(&%N9"`D=F%L=64@:71S('9A;'5E"B`@("`@*B!`<&%R86T@:6YT("`@("1M
M;V1E("`@("`@("`@(&$@='EP92!O9B!Q=65R>2!T;R!M86ME.@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1$)?05543U%515)97TE.
M4T525"!O<B!$0E]!551/455%4EE?55!$051%"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1W:&5R92`@("`@("`@(&9O<B!U<&1A=&4@<75E<FEE<SH@=&AE(%=(
M15)%(&-L875S92!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@87!P96YD('1O('1H92!344P@<W1A=&5M96YT+B`@1&]N)W0*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EN8VQU9&4@=&AE
M(")72$5212(@:V5Y=V]R9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!A(&YE=R!$0E]R97-U;'0@;V)J96-T(&9O<B!S=6-C97-S9G5L(%-%3$5#
M5"!Q=65R:65S"B`@("`@*B`@("`@("`@("`@("`@("`@;W(@1$)?3TL@9F]R
M('-U8V-E<W-U;"!D871A(&UA;FEP=6QA=&EO;B!Q=65R:65S+@H@("`@("H@
M("`@("`@("`@("`@("`@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N
M"B`@("`@*@H@("`@("H@0'5S97,@1$)?8V]M;6]N.CIA=71O4')E<&%R92@I
M+"!$0E]C;VUM;VXZ.F5X96-U=&4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!A
M=71O17AE8W5T92@D=&%B;&4L("1F:65L9'-?=F%L=65S+"`D;6]D92`]($1"
M7T%55$]1545265])3E-%4E0L"B`@("`@("`@("`@("`@("`@("`@("`@("`D
M=VAE<F4@/2!F86QS92D*("`@('L*("`@("`@("`D<W1H(#T@)'1H:7,M/F%U
M=&]0<F5P87)E*"1T86)L92P@87)R87E?:V5Y<R@D9FEE;&1S7W9A;'5E<RDL
M("1M;V1E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=H
M97)E*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)'-T:"DI('L*("`@("`@
M("`@("`@<F5T=7)N("1S=&@["B`@("`@("`@?0H@("`@("`@("1R970@/28@
M)'1H:7,M/F5X96-U=&4H)'-T:"P@87)R87E?=F%L=65S*"1F:65L9'-?=F%L
M=65S*2D["B`@("`@("`@)'1H:7,M/F9R9650<F5P87)E9"@D<W1H*3L*("`@
M("`@("!R971U<FX@)')E=#L*"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@8G5I;&1-86YI<%-13"@I"@H@("`@+RHJ"B`@("`@*B!0<F]D=6-E<R!A
M;B!344P@<75E<GD@<W1R:6YG(&9O<B!A=71O4')E<&%R92@I"B`@("`@*@H@
M("`@("H@17AA;7!L93H*("`@("`J(#QP<F4^"B`@("`@*B!B=6EL9$UA;FEP
M4U%,*"=T86)L95]S<6PG+"!A<G)A>2@G9FEE;&0Q)RP@)V9I96QD,B<L("=F
M:65L9#,G*2P*("`@("`J("`@("`@("`@("`@("`@1$)?05543U%515)97TE.
M4T525"D["B`@("`@*B`\+W!R93X*("`@("`J"B`@("`@*B!4:&%T(')E='5R
M;G,*("`@("`J(#QS86UP/@H@("`@("H@24Y315)4($E.5$\@=&%B;&5?<W%L
M("AF:65L9#$L9FEE;&0R+&9I96QD,RD@5D%,5453("@_+#\L/RD*("`@("`J
M(#PO<V%M<#X*("`@("`J"B`@("`@*B!.3U1%4SH*("`@("`J("`@+2!4:&ES
M(&)E;&]N9W,@;6]R92!T;R!A(%-13"!"=6EL9&5R(&-L87-S+"!B=70@=&AI
M<R!I<R!A('-I;7!L90H@("`@("H@("`@(&9A8VEL:71Y+@H@("`@("H@("`M
M($)E(&-A<F5F=6QL(2!)9B!Y;W4@9&]N)W0@9VEV92!A("1W:&5R92!P87)A
M;2!W:71H(&%N(%501$%410H@("`@("H@("`@('%U97)Y+"!A;&P@=&AE(')E
M8V]R9',@;V8@=&AE('1A8FQE('=I;&P@8F4@=7!D871E9"$*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1T86)L92`@("`@("`@('1H92!T86)L92!N
M86UE"B`@("`@*B!`<&%R86T@87)R87D@("1T86)L95]F:65L9',@('1H92!A
M<G)A>2!O9B!F:65L9"!N86UE<PH@("`@("H@0'!A<F%M(&EN="`@("`D;6]D
M92`@("`@("`@("!A('1Y<&4@;V8@<75E<GD@=&\@;6%K93H*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@($1"7T%55$]1545265])3E-%
M4E0@;W(@1$)?05543U%515)97U501$%410H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=VAE<F4@("`@("`@("!F;W(@=7!D871E('%U97)I97,Z('1H92!72$52
M12!C;&%U<V4@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&%P<&5N9"!T;R!T:&4@4U%,('-T871E;65N="X@($1O;B=T"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I;F-L=61E('1H92`B
M5TA%4D4B(&ME>7=O<F0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M('1H92!S<6P@<75E<GD@9F]R(&%U=&]0<F5P87)E*"D*("`@("`J+PH@("`@
M9G5N8W1I;VX@8G5I;&1-86YI<%-13"@D=&%B;&4L("1T86)L95]F:65L9',L
M("1M;V1E+"`D=VAE<F4@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H8V]U
M;G0H)'1A8FQE7V9I96QD<RD@/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?3D5%1%]-3U)%7T1!5$$I.PH@
M("`@("`@('T*("`@("`@("`D9FER<W0@/2!T<G5E.PH@("`@("`@('-W:71C
M:"`H)&UO9&4I('L*("`@("`@("`@("`@8V%S92!$0E]!551/455%4EE?24Y3
M15)4.@H@("`@("`@("`@("`@("`@)'9A;'5E<R`]("<G.PH@("`@("`@("`@
M("`@("`@)&YA;65S(#T@)R<["B`@("`@("`@("`@("`@("!F;W)E86-H("@D
M=&%B;&5?9FEE;&1S(&%S("1V86QU92D@>PH@("`@("`@("`@("`@("`@("`@
M(&EF("@D9FER<W0I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&9I<G-T
M(#T@9F%L<V4["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&YA;65S("X]("<L)SL*("`@("`@("`@("`@
M("`@("`@("`@("`@)'9A;'5E<R`N/2`G+"<["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("1N86UE<R`N/2`D=F%L=64["B`@
M("`@("`@("`@("`@("`@("`@)'9A;'5E<R`N/2`G/R<["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!R971U<FX@(DE.4T525"!)3E1/("1T
M86)L92`H)&YA;65S*2!604Q515,@*"1V86QU97,I(CL*("`@("`@("`@("`@
M8V%S92!$0E]!551/455%4EE?55!$051%.@H@("`@("`@("`@("`@("`@)'-E
M="`]("<G.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1A8FQE7V9I96QD
M<R!A<R`D=F%L=64I('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&9I<G-T
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1F:7)S="`](&9A;'-E.PH@
M("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1S970@+CT@)RPG.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("`D<V5T("X]("(D=F%L=64@/2`_(CL*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1S<6P@/2`B55!$051%("1T
M86)L92!3150@)'-E="(["B`@("`@("`@("`@("`@("!I9B`H)'=H97)E*2![
M"B`@("`@("`@("`@("`@("`@("`@)'-Q;"`N/2`B(%=(15)%("1W:&5R92([
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!R971U<FX@)'-Q
M;#L*("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E]364Y405@I.PH@("`@("`@
M('T*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!E>&5C=71E*"D*"B`@
M("`O*BH*("`@("`J($5X96-U=&5S(&$@1$(@<W1A=&5M96YT('!R97!A<F5D
M('=I=&@@<')E<&%R92@I"B`@("`@*@H@("`@("H@17AA;7!L92`Q+@H@("`@
M("H@/&-O9&4^"B`@("`@*B`D<W1H(#T@)&1B+3YP<F5P87)E*"=)3E-%4E0@
M24Y43R!T8FP@*&$L(&(L(&,I(%9!3%5%4R`H/RP@(2P@)BDG*3L*("`@("`J
M("1D871A(#T@87)R87DH"B`@("`@*B`@("`@(DIO:&XG<R!T97AT(BP*("`@
M("`J("`@("`B)VET)R=S(&=O;V0G(BP*("`@("`J("`@("`G9FEL96YA;64N
M='AT)PH@("`@("H@*3L*("`@("`J("1R97,@/28@)&1B+3YE>&5C=71E*"1S
M=&@L("1D871A*3L*("`@("`J(#PO8V]D93X*("`@("`J"B`@("`@*B!`<&%R
M86T@<F5S;W5R8V4@)'-T;70@(&$@1$(@<W1A=&5M96YT(')E<V]U<F-E(')E
M='5R;F5D(&9R;VT@<')E<&%R92@I"B`@("`@*B!`<&%R86T@;6EX960@("`@
M)&1A=&$@(&%R<F%Y+"!S=')I;F<@;W(@;G5M97)I8R!D871A('1O(&)E('5S
M960@:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&5X96-U=&EO
M;B!O9B!T:&4@<W1A=&5M96YT+B`@475A;G1I='D@;V8@:71E;7,*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@('!A<W-E9"!M=7-T(&UA=&-H('%U
M86YT:71Y(&]F('!L86-E:&]L9&5R<R!I;@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@<75E<GDZ("!M96%N:6YG(#$@<&QA8V5H;VQD97(@9F]R
M(&YO;BUA<G)A>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@<&%R
M86UE=&5R<R!O<B`Q('!L86-E:&]L9&5R('!E<B!A<G)A>2!E;&5M96YT+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@(&$@;F5W($1"7W)E<W5L="!O
M8FIE8W0@9F]R('-U8V-E<W-F=6P@4T5,14-4('%U97)I97,*("`@("`J("`@
M("`@("`@("`@("`@("!O<B!$0E]/2R!F;W(@<W5C8V5S<W5L(&1A=&$@;6%N
M:7!U;&%T:6]N('%U97)I97,N"B`@("`@*B`@("`@("`@("`@("`@("`@02!$
M0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B![0&EN
M=&5R;F%L(&EB87-E(&%N9"!O8VDX(&AA=F4@=&AE:7(@;W=N(&5X96-U=&4H
M*2!M971H;V1S+GU]"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G!R
M97!A<F4H*0H@("`@("HO"B`@("!F=6YC=&EO;B`F97AE8W5T92@D<W1M="P@
M)&1A=&$@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1R96%L<75E<GD@/2`D
M=&AI<RT^97AE8W5T945M=6QA=&51=65R>2@D<W1M="P@)&1A=&$I.PH@("`@
M("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5A;'%U97)Y*2D@>PH@("`@("`@("`@
M("!R971U<FX@)')E86QQ=65R>3L*("`@("`@("!]"B`@("`@("`@)')E<W5L
M="`]("1T:&ES+3YS:6UP;&51=65R>2@D<F5A;'%U97)Y*3L*"B`@("`@("`@
M:68@*"1R97-U;'0@/3T]($1"7T]+('Q\($1".CII<T5R<F]R*"1R97-U;'0I
M*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1T;7`@/28@;F5W($1"7W)E<W5L="@D=&AI<RP@
M)')E<W5L="D["B`@("`@("`@("`@(')E='5R;B`D=&UP.PH@("`@("`@('T*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!E>&5C=71E16UU;&%T95%U
M97)Y*"D*"B`@("`O*BH*("`@("`J($5M=6QA=&5S(&5X96-U=&EN9R!P<F5P
M87)E9"!S=&%T96UE;G1S(&EF('1H92!$0DU3(&YO="!S=7!P;W)T('1H96T*
M("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)'-T;70@(&$@1$(@<W1A
M=&5M96YT(')E<V]U<F-E(')E='5R;F5D(&9R;VT@97AE8W5T92@I"B`@("`@
M*B!`<&%R86T@;6EX960@("`@)&1A=&$@(&%R<F%Y+"!S=')I;F<@;W(@;G5M
M97)I8R!D871A('1O(&)E('5S960@:6X*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@(&5X96-U=&EO;B!O9B!T:&4@<W1A=&5M96YT+B`@475A;G1I
M='D@;V8@:71E;7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('!A
M<W-E9"!M=7-T(&UA=&-H('%U86YT:71Y(&]F('!L86-E:&]L9&5R<R!I;@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@<75E<GDZ("!M96%N:6YG
M(#$@<&QA8V5H;VQD97(@9F]R(&YO;BUA<G)A>0H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@<&%R86UE=&5R<R!O<B`Q('!L86-E:&]L9&5R('!E
M<B!A<G)A>2!E;&5M96YT+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(&$@<W1R:6YG(&-O;G1A:6YI;F<@=&AE(')E86P@<75E<GD@<G5N('=H96X@
M96UU;&%T:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@<')E<&%R92]E>&5C
M=71E+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@
M("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@("H@0'-E92!$0E]C;VUM;VXZ
M.F5X96-U=&4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!E>&5C=71E16UU;&%T
M95%U97)Y*"1S=&UT+"`D9&%T82`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M)'-T;70@/2`H:6YT*21S=&UT.PH@("`@("`@("1D871A(#T@*&%R<F%Y*21D
M871A.PH@("`@("`@("1T:&ES+3YL87-T7W!A<F%M971E<G,@/2`D9&%T83L*
M"B`@("`@("`@:68@*&-O=6YT*"1T:&ES+3YP<F5P87)E7W1Y<&5S6R1S=&UT
M72D@(3T@8V]U;G0H)&1A=&$I*2!["B`@("`@("`@("`@("1T:&ES+3YL87-T
M7W%U97)Y(#T@)'1H:7,M/G!R97!A<F5D7W%U97)I97-;)'-T;71=.PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?34E3
M34%40T@I.PH@("`@("`@('T*"B`@("`@("`@)')E86QQ=65R>2`]("1T:&ES
M+3YP<F5P87)E7W1O:V5N<ULD<W1M=%U;,%T["@H@("`@("`@("1I(#T@,#L*
M("`@("`@("!F;W)E86-H("@D9&%T82!A<R`D=F%L=64I('L*("`@("`@("`@
M("`@:68@*"1T:&ES+3YP<F5P87)E7W1Y<&5S6R1S=&UT75LD:5T@/3T@1$)?
M4$%204U?4T-!3$%2*2!["B`@("`@("`@("`@("`@("`D<F5A;'%U97)Y("X]
M("1T:&ES+3YQ=6]T95-M87)T*"1V86QU92D["B`@("`@("`@("`@('T@96QS
M96EF("@D=&AI<RT^<')E<&%R95]T>7!E<ULD<W1M=%U;)&E=(#T]($1"7U!!
M4D%-7T]005%512D@>PH@("`@("`@("`@("`@("`@)&9P(#T@0&9O<&5N*"1V
M86QU92P@)W)B)RD["B`@("`@("`@("`@("`@("!I9B`H(21F<"D@>PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%
M4E)/4E]!0T-%4U-?5DE/3$%424].*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("1R96%L<75E<GD@+CT@)'1H:7,M/G%U;W1E4VUA<G0H
M9G)E860H)&9P+"!F:6QE<VEZ92@D=F%L=64I*2D["B`@("`@("`@("`@("`@
M("!F8VQO<V4H)&9P*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1R96%L<75E<GD@+CT@)'9A;'5E.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`D<F5A;'%U97)Y("X]("1T:&ES+3YP<F5P87)E7W1O:V5N
M<ULD<W1M=%U;*RLD:5T["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E
M86QQ=65R>3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!E>&5C=71E
M375L=&EP;&4H*0H*("`@("\J*@H@("`@("H@4&5R9F]R;7,@<V5V97)A;"!E
M>&5C=71E*"D@8V%L;',@;VX@=&AE('-A;64@<W1A=&5M96YT(&AA;F1L90H@
M("`@("H*("`@("`J("1D871A(&UU<W0@8F4@86X@87)R87D@:6YD97AE9"!N
M=6UE<FEC86QL>0H@("`@("H@9G)O;2`P+"!O;F4@97AE8W5T92!C86QL(&ES
M(&1O;F4@9F]R(&5V97)Y(")R;W<B(&EN('1H92!A<G)A>2X*("`@("`J"B`@
M("`@*B!)9B!A;B!E<G)O<B!O8V-U<G,@9'5R:6YG(&5X96-U=&4H*2P@97AE
M8W5T94UU;'1I<&QE*"D@9&]E<R!N;W0*("`@("`J(&5X96-U=&4@=&AE('5N
M9FEN:7-H960@<F]W<RP@8G5T(')A=&AE<B!R971U<FYS('1H870@97)R;W(N
M"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1S=&UT("!Q=65R>2!H
M86YD;&4@9G)O;2!P<F5P87)E*"D*("`@("`J($!P87)A;2!A<G)A>2`@("`D
M9&%T82`@;G5M97)I8R!A<G)A>2!C;VYT86EN:6YG('1H90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@9&%T82!T;R!I;G-E<G0@:6YT;R!T:&4@
M<75E<GD*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C
M8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@
M("`@("H@0'-E92!$0E]C;VUM;VXZ.G!R97!A<F4H*2P@1$)?8V]M;6]N.CIE
M>&5C=71E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@97AE8W5T94UU;'1I<&QE
M*"1S=&UT+"`D9&%T82D*("`@('L*("`@("`@("!F;W)E86-H("@D9&%T82!A
M<R`D=F%L=64I('L*("`@("`@("`@("`@)')E<R`])B`D=&AI<RT^97AE8W5T
M92@D<W1M="P@)'9A;'5E*3L*("`@("`@("`@("`@:68@*$1".CII<T5R<F]R
M*"1R97,I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9G)E95!R97!A<F5D*"D*"B`@("`O
M*BH*("`@("`J($9R965S('1H92!I;G1E<FYA;"!R97-O=7)C97,@87-S;V-I
M871E9"!W:71H(&$@<')E<&%R960@<75E<GD*("`@("`J"B`@("`@*B!`<&%R
M86T@<F5S;W5R8V4@)'-T;70@("`@("`@("`@('1H92!P<F5P87)E9"!S=&%T
M96UE;G0G<R!02%`@<F5S;W5R8V4*("`@("`J($!P87)A;2!B;V]L("`@("`D
M9G)E95]R97-O=7)C92`@<VAO=6QD('1H92!02%`@<F5S;W5R8V4@8F4@9G)E
M960@=&]O/PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@57-E(&9A;'-E(&EF('EO=2!N965D('1O(&=E="!D871A"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F<F]M('1H92!R97-U
M;'0@<V5T(&QA=&5R+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;"`@5%)5
M12!O;B!S=6-C97-S+"!&04Q312!I9B`D<F5S=6QT(&ES(&EN=F%L:60*("`@
M("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ<')E<&%R92@I"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&9R9650<F5P87)E9"@D<W1M="P@)&9R965?<F5S;W5R
M8V4@/2!T<G5E*0H@("`@>PH@("`@("`@("1S=&UT(#T@*&EN="DD<W1M=#L*
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/G!R97!A<F5?=&]K96YS6R1S=&UT
M72DI('L*("`@("`@("`@("`@=6YS970H)'1H:7,M/G!R97!A<F5?=&]K96YS
M6R1S=&UT72D["B`@("`@("`@("`@('5N<V5T*"1T:&ES+3YP<F5P87)E7W1Y
M<&5S6R1S=&UT72D["B`@("`@("`@("`@('5N<V5T*"1T:&ES+3YP<F5P87)E
M9%]Q=65R:65S6R1S=&UT72D["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@;6]D:69Y475E<GDH*0H*("`@("\J*@H@("`@("H@
M0VAA;F=E<R!A('%U97)Y('-T<FEN9R!F;W(@=F%R:6]U<R!$0DU3('-P96-I
M9FEC(')E87-O;G,*("`@("`J"B`@("`@*B!)="!I<R!D969I;F5D(&AE<F4@
M=&\@96YS=7)E(&%L;"!D<FEV97)S(&AA=F4@=&AI<R!M971H;V0@879A:6QA
M8FQE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'%U97)Y("!T:&4@
M<75E<GD@<W1R:6YG('1O(&UO9&EF>0H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!T:&4@;6]D:69I960@<75E<GD@<W1R:6YG"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J($!S964@1$)?;7ES<6PZ.FUO
M9&EF>5%U97)Y*"DL($1"7V]C:3@Z.FUO9&EF>5%U97)Y*"DL"B`@("`@*B`@
M("`@($1"7W-Q;&ET93HZ;6]D:69Y475E<GDH*0H@("`@("HO"B`@("!F=6YC
M=&EO;B!M;V1I9GE1=65R>2@D<75E<GDI"B`@("!["B`@("`@("`@<F5T=7)N
M("1Q=65R>3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!M;V1I9GE,
M:6UI=%%U97)Y*"D*"B`@("`O*BH*("`@("`J($%D9',@3$E-250@8VQA=7-E
M<R!T;R!A('%U97)Y('-T<FEN9R!A8V-O<F1I;F<@=&\@8W5R<F5N="!$0DU3
M('-T86YD87)D<PH@("`@("H*("`@("`J($ET(&ES(&1E9FEN960@:&5R92!T
M;R!A<W-U<F4@=&AA="!A;&P@:6UP;&5M96YT871I;VYS"B`@("`@*B!H879E
M('1H:7,@;65T:&]D(&1E9FEN960N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<75E<GD@("!T:&4@<75E<GD@=&\@;6]D:69Y"B`@("`@*B!`<&%R
M86T@:6YT("`@("1F<F]M("`@('1H92!R;W<@=&\@<W1A<G0@=&\@9F5T8VAI
M;F<@*#`@/2!T:&4@9FER<W0@<F]W*0H@("`@("H@0'!A<F%M(&EN="`@("`D
M8V]U;G0@("!T:&4@;G5M8F5R<R!O9B!R;W=S('1O(&9E=&-H"B`@("`@*B!`
M<&%R86T@;6EX960@("1P87)A;7,@(&%R<F%Y+"!S=')I;F<@;W(@;G5M97)I
M8R!D871A('1O(&)E('5S960@:6X*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@(&5X96-U=&EO;B!O9B!T:&4@<W1A=&5M96YT+B`@475A;G1I='D@
M;V8@:71E;7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('!A<W-E
M9"!M=7-T(&UA=&-H('%U86YT:71Y(&]F('!L86-E:&]L9&5R<R!I;@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@<75E<GDZ("!M96%N:6YG(#$@
M<&QA8V5H;VQD97(@9F]R(&YO;BUA<G)A>0H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@<&%R86UE=&5R<R!O<B`Q('!L86-E:&]L9&5R('!E<B!A
M<G)A>2!E;&5M96YT+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T
M:&4@<75E<GD@<W1R:6YG('=I=&@@3$E-250@8VQA=7-E<R!A9&1E9`H@("`@
M("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&UO9&EF>4QI;6ET475E<GDH)'%U97)Y+"`D9G)O;2P@)&-O=6YT+"`D
M<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!R971U<FX@)'%U97)Y
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('%U97)Y*"D*"B`@("`O
M*BH*("`@("`J(%-E;F1S(&$@<75E<GD@=&\@=&AE(&1A=&%B87-E('-E<G9E
M<@H@("`@("H*("`@("`J(%1H92!Q=65R>2!S=')I;F<@8V%N(&)E(&5I=&AE
M<B!A(&YO<FUA;"!S=&%T96UE;G0@=&\@8F4@<V5N="!D:7)E8W1L>0H@("`@
M("H@=&\@=&AE('-E<G9E<B!/4B!I9B`\=F%R/B1P87)A;7,\+W9A<CX@87)E
M('!A<W-E9"!T:&4@<75E<GD@8V%N(&AA=F4*("`@("`J('!L86-E:&]L9&5R
M<R!A;F0@:70@=VEL;"!B92!P87-S960@=&AR;W5G:"!P<F5P87)E*"D@86YD
M(&5X96-U=&4H*2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1Q=65R
M>2`@('1H92!344P@<75E<GD@;W(@=&AE('-T871E;65N="!T;R!P<F5P87)E
M"B`@("`@*B!`<&%R86T@;6EX960@("1P87)A;7,@(&%R<F%Y+"!S=')I;F<@
M;W(@;G5M97)I8R!D871A('1O(&)E('5S960@:6X*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@(&5X96-U=&EO;B!O9B!T:&4@<W1A=&5M96YT+B`@
M475A;G1I='D@;V8@:71E;7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@('!A<W-E9"!M=7-T(&UA=&-H('%U86YT:71Y(&]F('!L86-E:&]L9&5R
M<R!I;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@<75E<GDZ("!M
M96%N:6YG(#$@<&QA8V5H;VQD97(@9F]R(&YO;BUA<G)A>0H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@<&%R86UE=&5R<R!O<B`Q('!L86-E:&]L
M9&5R('!E<B!A<G)A>2!E;&5M96YT+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(&$@;F5W($1"7W)E<W5L="!O8FIE8W0@9F]R('-U8V-E<W-F=6P@
M4T5,14-4('%U97)I97,*("`@("`J("`@("`@("`@("`@("`@("!O<B!$0E]/
M2R!F;W(@<W5C8V5S<W5L(&1A=&$@;6%N:7!U;&%T:6]N('%U97)I97,N"B`@
M("`@*B`@("`@("`@("`@("`@("`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I
M;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L="P@1$)?8V]M;6]N
M.CIP<F5P87)E*"DL($1"7V-O;6UO;CHZ97AE8W5T92@I"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9Q=65R>2@D<75E<GDL("1P87)A;7,@/2!A<G)A>2@I*0H@
M("`@>PH@("`@("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@/B`P*2!["B`@("`@
M("`@("`@("1S=&@@/2`D=&AI<RT^<')E<&%R92@D<75E<GDI.PH@("`@("`@
M("`@("!I9B`H1$(Z.FES17)R;W(H)'-T:"DI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D<W1H.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1R970@
M/28@)'1H:7,M/F5X96-U=&4H)'-T:"P@)'!A<F%M<RD["B`@("`@("`@("`@
M("1T:&ES+3YF<F5E4')E<&%R960H)'-T:"P@9F%L<V4I.PH@("`@("`@("`@
M("!R971U<FX@)')E=#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M=&AI<RT^;&%S=%]P87)A;65T97)S(#T@87)R87DH*3L*("`@("`@("`@("`@
M)')E<W5L="`]("1T:&ES+3YS:6UP;&51=65R>2@D<75E<GDI.PH@("`@("`@
M("`@("!I9B`H)')E<W5L="`]/3T@1$)?3TL@?'P@1$(Z.FES17)R;W(H)')E
M<W5L="DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1M<"`])B!N97<@
M1$)?<F5S=6QT*"1T:&ES+"`D<F5S=6QT*3L*("`@("`@("`@("`@("`@(')E
M='5R;B`D=&UP.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&QI;6ET475E<GDH*0H*("`@("\J*@H@("`@
M("H@1V5N97)A=&5S(&%N9"!E>&5C=71E<R!A($Q)34E4('%U97)Y"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<75E<GD@("!T:&4@<75E<GD*("`@
M("`J($!P87)A;2!I;G1R("`@)&9R;VT@("`@=&AE(')O=R!T;R!S=&%R="!T
M;R!F971C:&EN9R`H,"`]('1H92!F:7)S="!R;W<I"B`@("`@*B!`<&%R86T@
M:6YT("`@("1C;W5N="`@('1H92!N=6UB97)S(&]F(')O=W,@=&\@9F5T8V@*
M("`@("`J($!P87)A;2!M:7AE9"`@)'!A<F%M<R`@87)R87DL('-T<FEN9R!O
M<B!N=6UE<FEC(&1A=&$@=&\@8F4@=7-E9"!I;@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@97AE8W5T:6]N(&]F('1H92!S=&%T96UE;G0N("!1
M=6%N=&ET>2!O9B!I=&5M<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@<&%S<V5D(&UU<W0@;6%T8V@@<75A;G1I='D@;V8@<&QA8V5H;VQD97)S
M(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!Q=65R>3H@(&UE
M86YI;F<@,2!P;&%C96AO;&1E<B!F;W(@;F]N+6%R<F%Y"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("!P87)A;65T97)S(&]R(#$@<&QA8V5H;VQD
M97(@<&5R(&%R<F%Y(&5L96UE;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@82!N97<@1$)?<F5S=6QT(&]B:F5C="!F;W(@<W5C8V5S<V9U;"!3
M14Q%0U0@<75E<FEE<PH@("`@("H@("`@("`@("`@("`@("`@(&]R($1"7T]+
M(&9O<B!S=6-C97-S=6P@9&%T82!M86YI<'5L871I;VX@<75E<FEE<RX*("`@
M("`J("`@("`@("`@("`@("`@("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F;&EM:711=65R>2@D<75E<GDL
M("1F<F]M+"`D8V]U;G0L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@
M("`@("1Q=65R>2`]("1T:&ES+3YM;V1I9GE,:6UI=%%U97)Y*"1Q=65R>2P@
M)&9R;VTL("1C;W5N="P@)'!A<F%M<RD["B`@("`@("`@:68@*$1".CII<T5R
M<F]R*"1Q=65R>2DI>PH@("`@("`@("`@("!R971U<FX@)'%U97)Y.PH@("`@
M("`@('T*("`@("`@("`D<F5S=6QT(#TF("1T:&ES+3YQ=65R>2@D<75E<GDL
M("1P87)A;7,I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=$0E]R97-U
M;'0G*2D@>PH@("`@("`@("`@("`D<F5S=6QT+3YS971/<'1I;VXH)VQI;6ET
M7V9R;VTG+"`D9G)O;2D["B`@("`@("`@("`@("1R97-U;'0M/G-E=$]P=&EO
M;B@G;&EM:71?8V]U;G0G+"`D8V]U;G0I.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G
M971/;F4H*0H*("`@("\J*@H@("`@("H@1F5T8VAE<R!T:&4@9FER<W0@8V]L
M=6UN(&]F('1H92!F:7)S="!R;W<@9G)O;2!A('%U97)Y(')E<W5L=`H@("`@
M("H*("`@("`J(%1A:V5S(&-A<F4@;V8@9&]I;F<@=&AE('%U97)Y(&%N9"!F
M<F5E:6YG('1H92!R97-U;'1S('=H96X@9FEN:7-H960N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<75E<GD@("!T:&4@4U%,('%U97)Y"B`@("`@
M*B!`<&%R86T@;6EX960@("1P87)A;7,@(&%R<F%Y+"!S=')I;F<@;W(@;G5M
M97)I8R!D871A('1O(&)E('5S960@:6X*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@(&5X96-U=&EO;B!O9B!T:&4@<W1A=&5M96YT+B`@475A;G1I
M='D@;V8@:71E;7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('!A
M<W-E9"!M=7-T(&UA=&-H('%U86YT:71Y(&]F('!L86-E:&]L9&5R<R!I;@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@<75E<GDZ("!M96%N:6YG
M(#$@<&QA8V5H;VQD97(@9F]R(&YO;BUA<G)A>0H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@<&%R86UE=&5R<R!O<B`Q('!L86-E:&]L9&5R('!E
M<B!A<G)A>2!E;&5M96YT+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M('1H92!R971U<FYE9"!V86QU92!O9B!T:&4@<75E<GDN"B`@("`@*B`@("`@
M("`@("`@("`@("`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@)F=E=$]N92@D<75E<GDL("1P87)A;7,@/2!A
M<G)A>2@I*0H@("`@>PH@("`@("`@("1P87)A;7,@/2`H87)R87DI)'!A<F%M
M<SL*("`@("`@("`O+R!M;V1I9GE,:6UI=%%U97)Y*"D@=V]U;&0@8F4@;FEC
M92!H97)E+"!B=70@:70@8V%U<V5S($)#(&ES<W5E<PH@("`@("`@(&EF("AS
M:7IE;V8H)'!A<F%M<RD@/B`P*2!["B`@("`@("`@("`@("1S=&@@/2`D=&AI
M<RT^<')E<&%R92@D<75E<GDI.PH@("`@("`@("`@("!I9B`H1$(Z.FES17)R
M;W(H)'-T:"DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<W1H.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1R97,@/28@)'1H:7,M/F5X96-U=&4H
M)'-T:"P@)'!A<F%M<RD["B`@("`@("`@("`@("1T:&ES+3YF<F5E4')E<&%R
M960H)'-T:"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)')E<R`]
M)B`D=&AI<RT^<75E<GDH)'%U97)Y*3L*("`@("`@("!]"@H@("`@("`@(&EF
M("A$0CHZ:7-%<G)O<B@D<F5S*2D@>PH@("`@("`@("`@("!R971U<FX@)')E
M<SL*("`@("`@("!]"@H@("`@("`@("1E<G(@/2`D<F5S+3YF971C:$EN=&\H
M)')O=RP@1$)?1D540TA-3T1%7T]21$52140I.PH@("`@("`@("1R97,M/F9R
M964H*3L*"B`@("`@("`@:68@*"1E<G(@(3T]($1"7T]+*2!["B`@("`@("`@
M("`@(')E='5R;B`D97)R.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R
M;W=;,%T["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9V5T4F]W*"D*
M"B`@("`O*BH*("`@("`J($9E=&-H97,@=&AE(&9I<G-T(')O=R!O9B!D871A
M(')E='5R;F5D(&9R;VT@82!Q=65R>2!R97-U;'0*("`@("`J"B`@("`@*B!4
M86ME<R!C87)E(&]F(&1O:6YG('1H92!Q=65R>2!A;F0@9G)E96EN9R!T:&4@
M<F5S=6QT<R!W:&5N(&9I;FES:&5D+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'%U97)Y("`@=&AE(%-13"!Q=65R>0H@("`@("H@0'!A<F%M(&UI
M>&5D("`D<&%R86US("!A<G)A>2P@<W1R:6YG(&]R(&YU;65R:6,@9&%T82!T
M;R!B92!U<V5D(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!E
M>&5C=71I;VX@;V8@=&AE('-T871E;65N="X@(%%U86YT:71Y(&]F(&ET96US
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!P87-S960@;75S="!M
M871C:"!Q=6%N=&ET>2!O9B!P;&%C96AO;&1E<G,@:6X*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@('%U97)Y.B`@;65A;FEN9R`Q('!L86-E:&]L
M9&5R(&9O<B!N;VXM87)R87D*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@('!A<F%M971E<G,@;W(@,2!P;&%C96AO;&1E<B!P97(@87)R87D@96QE
M;65N="X*("`@("`J($!P87)A;2!I;G0@)&9E=&-H;6]D92`@=&AE(&9E=&-H
M(&UO9&4@=&\@=7-E"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@=&AE
M(&9I<G-T(')O=R!O9B!R97-U;'1S(&%S(&%N(&%R<F%Y+@H@("`@("H@("`@
M("`@("`@("`@("`@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N("9G9712;W<H)'%U97)Y+"`D<&%R86US(#T@
M87)R87DH*2P*("`@("`@("`@("`@("`@("`@("`@)&9E=&-H;6]D92`]($1"
M7T9%5$-(34]$15]$149!54Q4*0H@("`@>PH@("`@("`@("\O(&-O;7!A="!C
M:&5C:RP@=&AE('!A<F%M<R!A;F0@9F5T8VAM;V1E('!A<F%M971E<G,@=7-E
M9"!T;PH@("`@("`@("\O(&AA=F4@=&AE(&]P<&]S:71E(&]R9&5R"B`@("`@
M("`@:68@*"%I<U]A<G)A>2@D<&%R86US*2D@>PH@("`@("`@("`@("!I9B`H
M:7-?87)R87DH)&9E=&-H;6]D92DI('L*("`@("`@("`@("`@("`@(&EF("@D
M<&%R86US(#T]/2!N=6QL*2!["B`@("`@("`@("`@("`@("`@("`@)'1M<"`]
M($1"7T9%5$-(34]$15]$149!54Q4.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`D=&UP(#T@)'!A<F%M<SL*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1P87)A;7,@/2`D9F5T8VAM
M;V1E.PH@("`@("`@("`@("`@("`@)&9E=&-H;6]D92`]("1T;7`["B`@("`@
M("`@("`@('T@96QS96EF("@D<&%R86US("$]/2!N=6QL*2!["B`@("`@("`@
M("`@("`@("`D9F5T8VAM;V1E(#T@)'!A<F%M<SL*("`@("`@("`@("`@("`@
M("1P87)A;7,@/2!A<G)A>2@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@("\O(&UO9&EF>4QI;6ET475E<GDH*2!W;W5L9"!B92!N:6-E(&AE
M<F4L(&)U="!I="!C875S97,@0D,@:7-S=65S"B`@("`@("`@:68@*'-I>F5O
M9B@D<&%R86US*2`^(#`I('L*("`@("`@("`@("`@)'-T:"`]("1T:&ES+3YP
M<F5P87)E*"1Q=65R>2D["B`@("`@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D
M<W1H*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1S=&@["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)')E<R`])B`D=&AI<RT^97AE8W5T92@D<W1H
M+"`D<&%R86US*3L*("`@("`@("`@("`@)'1H:7,M/F9R9650<F5P87)E9"@D
M<W1H*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5S(#TF("1T
M:&ES+3YQ=65R>2@D<75E<GDI.PH@("`@("`@('T*"B`@("`@("`@:68@*$1"
M.CII<T5R<F]R*"1R97,I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S.PH@
M("`@("`@('T*"B`@("`@("`@)&5R<B`]("1R97,M/F9E=&-H26YT;R@D<F]W
M+"`D9F5T8VAM;V1E*3L*"B`@("`@("`@)')E<RT^9G)E92@I.PH*("`@("`@
M("!I9B`H)&5R<B`A/3T@1$)?3TLI('L*("`@("`@("`@("`@<F5T=7)N("1E
M<G(["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')O=SL*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!G971#;VPH*0H*("`@("\J*@H@("`@("H@
M1F5T8VAE<R!A('-I;F=L92!C;VQU;6X@9G)O;2!A('%U97)Y(')E<W5L="!A
M;F0@<F5T=7)N<R!I="!A<R!A;@H@("`@("H@:6YD97AE9"!A<G)A>0H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'%U97)Y("`@=&AE(%-13"!Q=65R
M>0H@("`@("H@0'!A<F%M(&UI>&5D("`D8V]L("`@("!W:&EC:"!C;VQU;6X@
M=&\@<F5T=7)N("AI;G1E9V5R(%MC;VQU;6X@;G5M8F5R+`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@<W1A<G1I;F<@870@,%T@;W(@<W1R:6YG
M(%MC;VQU;6X@;F%M95TI"B`@("`@*B!`<&%R86T@;6EX960@("1P87)A;7,@
M(&%R<F%Y+"!S=')I;F<@;W(@;G5M97)I8R!D871A('1O(&)E('5S960@:6X*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&5X96-U=&EO;B!O9B!T
M:&4@<W1A=&5M96YT+B`@475A;G1I='D@;V8@:71E;7,*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@('!A<W-E9"!M=7-T(&UA=&-H('%U86YT:71Y
M(&]F('!L86-E:&]L9&5R<R!I;@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@<75E<GDZ("!M96%N:6YG(#$@<&QA8V5H;VQD97(@9F]R(&YO;BUA
M<G)A>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@<&%R86UE=&5R
M<R!O<B`Q('!L86-E:&]L9&5R('!E<B!A<G)A>2!E;&5M96YT+@H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@('1H92!R97-U;'1S(&%S(&%N(&%R<F%Y
M+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@
M*B!`<V5E($1"7V-O;6UO;CHZ<75E<GDH*0H@("`@("HO"B`@("!F=6YC=&EO
M;B`F9V5T0V]L*"1Q=65R>2P@)&-O;"`](#`L("1P87)A;7,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@("1P87)A;7,@/2`H87)R87DI)'!A<F%M<SL*("`@
M("`@("!I9B`H<VEZ96]F*"1P87)A;7,I(#X@,"D@>PH@("`@("`@("`@("`D
M<W1H(#T@)'1H:7,M/G!R97!A<F4H)'%U97)Y*3L*"B`@("`@("`@("`@(&EF
M("A$0CHZ:7-%<G)O<B@D<W1H*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1S=&@["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1R97,@/28@)'1H
M:7,M/F5X96-U=&4H)'-T:"P@)'!A<F%M<RD["B`@("`@("`@("`@("1T:&ES
M+3YF<F5E4')E<&%R960H)'-T:"D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)')E<R`])B`D=&AI<RT^<75E<GDH)'%U97)Y*3L*("`@("`@("!]
M"@H@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S*2D@>PH@("`@("`@("`@
M("!R971U<FX@)')E<SL*("`@("`@("!]"@H@("`@("`@("1F971C:&UO9&4@
M/2!I<U]I;G0H)&-O;"D@/R!$0E]&151#2$U/1$5?3U)$15)%1"`Z($1"7T9%
M5$-(34]$15]!4U-/0SL*"B`@("`@("`@:68@*"%I<U]A<G)A>2@D<F]W(#T@
M)')E<RT^9F5T8VA2;W<H)&9E=&-H;6]D92DI*2!["B`@("`@("`@("`@("1R
M970@/2!A<G)A>2@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF
M("@A87)R87E?:V5Y7V5X:7-T<R@D8V]L+"`D<F]W*2D@>PH@("`@("`@("`@
M("`@("`@)')E="`])B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E].3U-5
M0TA&245,1"D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D<F5T(#T@87)R87DH)')O=ULD8V]L72D["B`@("`@("`@("`@("`@("!W
M:&EL92`H:7-?87)R87DH)')O=R`]("1R97,M/F9E=&-H4F]W*"1F971C:&UO
M9&4I*2D@>PH@("`@("`@("`@("`@("`@("`@("1R971;72`]("1R;W=;)&-O
M;%T["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("1R97,M/F9R964H*3L*"B`@("`@("`@:68@*$1".CII<T5R
M<F]R*"1R;W<I*2!["B`@("`@("`@("`@("1R970@/2`D<F]W.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1R970["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@9V5T07-S;V,H*0H*("`@("\J*@H@("`@("H@1F5T8VAE<R!A
M;B!E;G1I<F4@<75E<GD@<F5S=6QT(&%N9"!R971U<FYS(&ET(&%S(&%N"B`@
M("`@*B!A<W-O8VEA=&EV92!A<G)A>2!U<VEN9R!T:&4@9FER<W0@8V]L=6UN
M(&%S('1H92!K97D*("`@("`J"B`@("`@*B!)9B!T:&4@<F5S=6QT('-E="!C
M;VYT86EN<R!M;W)E('1H86X@='=O(&-O;'5M;G,L('1H92!V86QU90H@("`@
M("H@=VEL;"!B92!A;B!A<G)A>2!O9B!T:&4@=F%L=65S(&9R;VT@8V]L=6UN
M(#(M;BX@($EF('1H92!R97-U;'0*("`@("`J('-E="!C;VYT86EN<R!O;FQY
M('1W;R!C;VQU;6YS+"!T:&4@<F5T=7)N960@=F%L=64@=VEL;"!B92!A"B`@
M("`@*B!S8V%L87(@=VET:"!T:&4@=F%L=64@;V8@=&AE('-E8V]N9"!C;VQU
M;6X@*'5N;&5S<R!F;W)C960@=&\@86X*("`@("`J(&%R<F%Y('=I=&@@=&AE
M("1F;W)C95]A<G)A>2!P87)A;65T97(I+B`@02!$0B!E<G)O<B!C;V1E(&ES
M"B`@("`@*B!R971U<FYE9"!O;B!E<G)O<G,N("!)9B!T:&4@<F5S=6QT('-E
M="!C;VYT86EN<R!F97=E<B!T:&%N('1W;PH@("`@("H@8V]L=6UN<RP@82!$
M0E]%4E)/4E]44E5.0T%4140@97)R;W(@:7,@<F5T=7)N960N"B`@("`@*@H@
M("`@("H@1F]R(&5X86UP;&4L(&EF('1H92!T86)L92`B;7ET86)L92(@8V]N
M=&%I;G,Z"B`@("`@*@H@("`@("H@/'!R93X*("`@("`J("!)1"`@("`@(%1%
M6%0@("`@("`@1$%410H@("`@("H@+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2T*("`@("`J("`Q("`@("`@("=O;F4G("`@("`@.30T-C<Y-#`X
M"B`@("`@*B`@,B`@("`@("`G='=O)R`@("`@(#DT-#8W.30P.`H@("`@("H@
M(#,@("`@("`@)W1H<F5E)R`@("`Y-#0V-SDT,#@*("`@("`J(#PO<')E/@H@
M("`@("H*("`@("`J(%1H96X@=&AE(&-A;&P@9V5T07-S;V,H)U-%3$5#5"!I
M9"QT97AT($923TT@;7ET86)L92<I(')E='5R;G,Z"B`@("`@*B`\<')E/@H@
M("`@("H@("!A<G)A>2@*("`@("`J("`@("`G,2<@/3X@)V]N92<L"B`@("`@
M*B`@("`@)S(G(#T^("=T=V\G+`H@("`@("H@("`@("<S)R`]/B`G=&AR964G
M+`H@("`@("H@("`I"B`@("`@*B`\+W!R93X*("`@("`J"B`@("`@*B`N+BYW
M:&EL92!T:&4@8V%L;"!G971!<W-O8R@G4T5,14-4(&ED+'1E>'0L9&%T92!&
M4D]-(&UY=&%B;&4G*2!R971U<FYS.@H@("`@("H@/'!R93X*("`@("`J("`@
M87)R87DH"B`@("`@*B`@("`@)S$G(#T^(&%R<F%Y*"=O;F4G+"`G.30T-C<Y
M-#`X)RDL"B`@("`@*B`@("`@)S(G(#T^(&%R<F%Y*"=T=V\G+"`G.30T-C<Y
M-#`X)RDL"B`@("`@*B`@("`@)S,G(#T^(&%R<F%Y*"=T:')E92<L("<Y-#0V
M-SDT,#@G*0H@("`@("H@("`I"B`@("`@*B`\+W!R93X*("`@("`J"B`@("`@
M*B!)9B!T:&4@;6]R92!T:&%N(&]N92!R;W<@;V-C=7)S('=I=&@@=&AE('-A
M;64@=F%L=64@:6X@=&AE"B`@("`@*B!F:7)S="!C;VQU;6XL('1H92!L87-T
M(')O=R!O=F5R=W)I=&5S(&%L;"!P<F5V:6]U<R!O;F5S(&)Y"B`@("`@*B!D
M969A=6QT+B`@57-E('1H92`D9W)O=7`@<&%R86UE=&5R(&EF('EO=2!D;VXG
M="!W86YT('1O"B`@("`@*B!O=F5R=W)I=&4@;&EK92!T:&ES+B`@17AA;7!L
M93H*("`@("`J"B`@("`@*B`\<')E/@H@("`@("H@9V5T07-S;V,H)U-%3$5#
M5"!C871E9V]R>2QI9"QN86UE($923TT@;7ET86)L92<L(&9A;'-E+"!N=6QL
M+`H@("`@("H@("`@("`@("`@1$)?1D540TA-3T1%7T%34T]#+"!T<G5E*2!R
M971U<FYS.@H@("`@("H*("`@("`J("`@87)R87DH"B`@("`@*B`@("`@)S$G
M(#T^(&%R<F%Y*&%R<F%Y*"=I9"<@/3X@)S0G+"`G;F%M92<@/3X@)VYU;6)E
M<B!F;W5R)RDL"B`@("`@*B`@("`@("`@("`@("`@("`@(&%R<F%Y*"=I9"<@
M/3X@)S8G+"`G;F%M92<@/3X@)VYU;6)E<B!S:7@G*0H@("`@("H@("`@("`@
M("`@("`I+`H@("`@("H@("`@("<Y)R`]/B!A<G)A>2AA<G)A>2@G:60G(#T^
M("<T)RP@)VYA;64G(#T^("=N=6UB97(@9F]U<B<I+`H@("`@("H@("`@("`@
M("`@("`@("`@("!A<G)A>2@G:60G(#T^("<V)RP@)VYA;64G(#T^("=N=6UB
M97(@<VEX)RD*("`@("`J("`@("`@("`@("`@*0H@("`@("H@("`I"B`@("`@
M*B`\+W!R93X*("`@("`J"B`@("`@*B!+965P(&EN(&UI;F0@=&AA="!D871A
M8F%S92!F=6YC=&EO;G,@:6X@4$A0('5S=6%L;'D@<F5T=7)N('-T<FEN9PH@
M("`@("H@=F%L=65S(&9O<B!R97-U;'1S(')E9V%R9&QE<W,@;V8@=&AE(&1A
M=&%B87-E)W,@:6YT97)N86P@='EP92X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1Q=65R>2`@("`@("`@=&AE(%-13"!Q=65R>0H@("`@("H@0'!A
M<F%M(&)O;VP@("`D9F]R8V5?87)R87D@('5S960@;VYL>2!W:&5N('1H92!Q
M=65R>2!R971U<FYS"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&5X86-T;'D@='=O(&-O;'5M;G,N("!)9B!T<G5E+"!T:&4@=F%L=65S
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&]F('1H92!R
M971U<FYE9"!A<G)A>2!W:6QL(&)E(&]N92UE;&5M96YT"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y<R!I;G-T96%D(&]F('-C
M86QA<G,N"B`@("`@*B!`<&%R86T@;6EX960@("1P87)A;7,@("`@("`@87)R
M87DL('-T<FEN9R!O<B!N=6UE<FEC(&1A=&$@=&\@8F4@=7-E9"!I;@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!E>&5C=71I;VX@;V8@
M=&AE('-T871E;65N="X@(%%U86YT:71Y(&]F"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&ET96US('!A<W-E9"!M=7-T(&UA=&-H('%U
M86YT:71Y(&]F"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('!L86-E:&]L9&5R<R!I;B!Q=65R>3H@(&UE86YI;F<@,0H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!P;&%C96AO;&1E<B!F;W(@;F]N
M+6%R<F%Y('!A<F%M971E<G,@;W(*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@,2!P;&%C96AO;&1E<B!P97(@87)R87D@96QE;65N="X*
M("`@("`J($!P87)A;2!I;G0@("`D9F5T8VAM;V1E("`@("!T:&4@9F5T8V@@
M;6]D92!T;R!U<V4*("`@("`J($!P87)A;2!B;V]L("`D9W)O=7`@("`@("`@
M("!I9B!T<G5E+"!T:&4@=F%L=65S(&]F('1H92!R971U<FYE9"!A<G)A>0H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I<R!W<F%P<&5D
M(&EN(&%N;W1H97(@87)R87DN("!)9B!T:&4@<V%M90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!K97D@=F%L=64@*&EN('1H92!F:7)S
M="!C;VQU;6XI(')E<&5A=',*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:71S96QF+"!T:&4@=F%L=65S('=I;&P@8F4@87!P96YD960@
M=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AI<R!A
M<G)A>2!I;G-T96%D(&]F(&]V97)W<FET:6YG('1H90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!E>&ES=&EN9R!V86QU97,N"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@=&AE(&%S<V]C:6%T:79E(&%R<F%Y
M(&-O;G1A:6YI;F<@=&AE('%U97)Y(')E<W5L=',N"B`@("`@*B`@("`@("`@
M("`@("`@("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B`F9V5T07-S;V,H)'%U97)Y+"`D9F]R8V5?87)R87D@
M/2!F86QS92P@)'!A<F%M<R`](&%R<F%Y*"DL"B`@("`@("`@("`@("`@("`@
M("`@("`@)&9E=&-H;6]D92`]($1"7T9%5$-(34]$15]$149!54Q4+"`D9W)O
M=7`@/2!F86QS92D*("`@('L*("`@("`@("`D<&%R86US(#T@*&%R<F%Y*21P
M87)A;7,["B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US*2`^(#`I('L*("`@
M("`@("`@("`@)'-T:"`]("1T:&ES+3YP<F5P87)E*"1Q=65R>2D["@H@("`@
M("`@("`@("!I9B`H1$(Z.FES17)R;W(H)'-T:"DI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D<W1H.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M<F5S(#TF("1T:&ES+3YE>&5C=71E*"1S=&@L("1P87)A;7,I.PH@("`@("`@
M("`@("`D=&AI<RT^9G)E95!R97!A<F5D*"1S=&@I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1R97,@/28@)'1H:7,M/G%U97)Y*"1Q=65R>2D[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@?0H@("`@("`@(&EF
M("@D9F5T8VAM;V1E(#T]($1"7T9%5$-(34]$15]$149!54Q4*2!["B`@("`@
M("`@("`@("1F971C:&UO9&4@/2`D=&AI<RT^9F5T8VAM;V1E.PH@("`@("`@
M('T*("`@("`@("`D8V]L<R`]("1R97,M/FYU;4-O;',H*3L*"B`@("`@("`@
M:68@*"1C;VQS(#P@,BD@>PH@("`@("`@("`@("`D=&UP(#TF("1T:&ES+3YR
M86ES945R<F]R*$1"7T524D]27U1254Y#051%1"D["B`@("`@("`@("`@(')E
M='5R;B`D=&UP.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L=',@/2!A<G)A
M>2@I.PH*("`@("`@("!I9B`H)&-O;',@/B`R('Q\("1F;W)C95]A<G)A>2D@
M>PH@("`@("`@("`@("`O+R!R971U<FX@87)R87D@=F%L=65S"B`@("`@("`@
M("`@("\O(%A86"!T:&ES('!A<G0@8V%N(&)E(&]P=&EM:7IE9`H@("`@("`@
M("`@("!I9B`H)&9E=&-H;6]D92`]/2!$0E]&151#2$U/1$5?05-33T,I('L*
M("`@("`@("`@("`@("`@('=H:6QE("AI<U]A<G)A>2@D<F]W(#T@)')E<RT^
M9F5T8VA2;W<H1$)?1D540TA-3T1%7T%34T]#*2DI('L*("`@("`@("`@("`@
M("`@("`@("!R97-E="@D<F]W*3L*("`@("`@("`@("`@("`@("`@("`D:V5Y
M(#T@8W5R<F5N="@D<F]W*3L*("`@("`@("`@("`@("`@("`@("!U;G-E="@D
M<F]W6VME>2@D<F]W*5TI.PH@("`@("`@("`@("`@("`@("`@(&EF("@D9W)O
M=7`I('L*("`@("`@("`@("`@("`@("`@("`@("`@)')E<W5L='-;)&ME>5U;
M72`]("1R;W<["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)')E<W5L='-;)&ME>5T@/2`D<F]W.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?2!E;'-E:68@*"1F971C:&UO9&4@/3T@1$)?1D540TA-3T1%7T]"2D5#
M5"D@>PH@("`@("`@("`@("`@("`@=VAI;&4@*"1R;W<@/2`D<F5S+3YF971C
M:%)O=RA$0E]&151#2$U/1$5?3T)*14-4*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1A<G(@/2!G971?;V)J96-T7W9A<G,H)')O=RD["B`@("`@("`@("`@
M("`@("`@("`@)&ME>2`](&-U<G)E;G0H)&%R<BD["B`@("`@("`@("`@("`@
M("`@("`@:68@*"1G<F]U<"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M<F5S=6QT<ULD:V5Y75M=(#T@)')O=SL*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<F5S=6QT<ULD:V5Y
M72`]("1R;W<["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@=VAI
M;&4@*&ES7V%R<F%Y*"1R;W<@/2`D<F5S+3YF971C:%)O=RA$0E]&151#2$U/
M1$5?3U)$15)%1"DI*2!["B`@("`@("`@("`@("`@("`@("`@+R\@=V4@<VAI
M9G0@87=A>2!T:&4@9FER<W0@96QE;65N="!T;R!G970*("`@("`@("`@("`@
M("`@("`@("`O+R!I;F1I8V5S(')U;FYI;F<@9G)O;2`P(&%G86EN"B`@("`@
M("`@("`@("`@("`@("`@)&ME>2`](&%R<F%Y7W-H:69T*"1R;W<I.PH@("`@
M("`@("`@("`@("`@("`@(&EF("@D9W)O=7`I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)')E<W5L='-;)&ME>5U;72`]("1R;W<["B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)')E
M<W5L='-;)&ME>5T@/2`D<F]W.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M1$(Z.FES17)R;W(H)')O=RDI('L*("`@("`@("`@("`@("`@("1R97-U;'1S
M(#T@)')O=SL*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("\O(')E='5R;B!S8V%L87(@=F%L=65S"B`@("`@("`@("`@('=H
M:6QE("AI<U]A<G)A>2@D<F]W(#T@)')E<RT^9F5T8VA2;W<H1$)?1D540TA-
M3T1%7T]21$52140I*2D@>PH@("`@("`@("`@("`@("`@:68@*"1G<F]U<"D@
M>PH@("`@("`@("`@("`@("`@("`@("1R97-U;'1S6R1R;W=;,%U=6UT@/2`D
M<F]W6S%=.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D<F5S=6QT<ULD<F]W6S!=72`]("1R;W=;,5T["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*$1".CII
M<T5R<F]R*"1R;W<I*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT<R`]("1R
M;W<["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1R97,M/F9R
M964H*3L*"B`@("`@("`@<F5T=7)N("1R97-U;'1S.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&=E=$%L;"@I"@H@("`@+RHJ"B`@("`@*B!&971C
M:&5S(&%L;"!O9B!T:&4@<F]W<R!F<F]M(&$@<75E<GD@<F5S=6QT"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<75E<GD@("`@("!T:&4@4U%,('%U
M97)Y"B`@("`@*B!`<&%R86T@;6EX960@("1P87)A;7,@("`@(&%R<F%Y+"!S
M=')I;F<@;W(@;G5M97)I8R!D871A('1O(&)E('5S960@:6X*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&5X96-U=&EO;B!O9B!T:&4@<W1A
M=&5M96YT+B`@475A;G1I='D@;V8*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&ET96US('!A<W-E9"!M=7-T(&UA=&-H('%U86YT:71Y(&]F
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!P;&%C96AO;&1E
M<G,@:6X@<75E<GDZ("!M96%N:6YG(#$*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('!L86-E:&]L9&5R(&9O<B!N;VXM87)R87D@<&%R86UE
M=&5R<R!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@,2!P
M;&%C96AO;&1E<B!P97(@87)R87D@96QE;65N="X*("`@("`J($!P87)A;2!I
M;G0@("`@)&9E=&-H;6]D92`@=&AE(&9E=&-H(&UO9&4@=&\@=7-E.@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@*R!$0E]&151#2$U/1$5?
M3U)$15)%1`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@*R!$
M0E]&151#2$U/1$5?05-33T,*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("L@1$)?1D540TA-3T1%7T]21$52140@?"!$0E]&151#2$U/1$5?
M1DQ)4%!%1`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@*R!$
M0E]&151#2$U/1$5?05-33T,@?"!$0E]&151#2$U/1$5?1DQ)4%!%1`H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@('1H92!N97-T960@87)R87DN("!!
M($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B`F9V5T06QL*"1Q=65R>2P@)'!A<F%M<R`](&%R<F%Y*"DL"B`@("`@
M("`@("`@("`@("`@("`@("1F971C:&UO9&4@/2!$0E]&151#2$U/1$5?1$5&
M055,5"D*("`@('L*("`@("`@("`O+R!C;VUP870@8VAE8VLL('1H92!P87)A
M;7,@86YD(&9E=&-H;6]D92!P87)A;65T97)S('5S960@=&\*("`@("`@("`O
M+R!H879E('1H92!O<'!O<VET92!O<F1E<@H@("`@("`@(&EF("@A:7-?87)R
M87DH)'!A<F%M<RDI('L*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1F971C
M:&UO9&4I*2!["B`@("`@("`@("`@("`@("!I9B`H)'!A<F%M<R`]/3T@;G5L
M;"D@>PH@("`@("`@("`@("`@("`@("`@("1T;7`@/2!$0E]&151#2$U/1$5?
M1$5&055,5#L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@)'1M<"`]("1P87)A;7,["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`D<&%R86US(#T@)&9E=&-H;6]D93L*("`@("`@("`@
M("`@("`@("1F971C:&UO9&4@/2`D=&UP.PH@("`@("`@("`@("!](&5L<V5I
M9B`H)'!A<F%M<R`A/3T@;G5L;"D@>PH@("`@("`@("`@("`@("`@)&9E=&-H
M;6]D92`]("1P87)A;7,["B`@("`@("`@("`@("`@("`D<&%R86US(#T@87)R
M87DH*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*'-I
M>F5O9B@D<&%R86US*2`^(#`I('L*("`@("`@("`@("`@)'-T:"`]("1T:&ES
M+3YP<F5P87)E*"1Q=65R>2D["@H@("`@("`@("`@("!I9B`H1$(Z.FES17)R
M;W(H)'-T:"DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<W1H.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`D<F5S(#TF("1T:&ES+3YE>&5C=71E
M*"1S=&@L("1P87)A;7,I.PH@("`@("`@("`@("`D=&AI<RT^9G)E95!R97!A
M<F5D*"1S=&@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R97,@
M/28@)'1H:7,M/G%U97)Y*"1Q=65R>2D["B`@("`@("`@?0H*("`@("`@("!I
M9B`H)')E<R`]/3T@1$)?3TL@?'P@1$(Z.FES17)R;W(H)')E<RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@?0H*("`@("`@("`D<F5S
M=6QT<R`](&%R<F%Y*"D["B`@("`@("`@=VAI;&4@*$1"7T]+(#T]/2`D<F5S
M+3YF971C:$EN=&\H)')O=RP@)&9E=&-H;6]D92DI('L*("`@("`@("`@("`@
M:68@*"1F971C:&UO9&4@)B!$0E]&151#2$U/1$5?1DQ)4%!%1"D@>PH@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)')O=R!A<R`D:V5Y(#T^("1V86PI('L*
M("`@("`@("`@("`@("`@("`@("`D<F5S=6QT<ULD:V5Y75M=(#T@)'9A;#L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1R97-U;'1S6UT@/2`D<F]W.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`D<F5S+3YF<F5E*"D["@H@("`@("`@(&EF("A$
M0CHZ:7-%<G)O<B@D<F]W*2D@>PH@("`@("`@("`@("`D=&UP(#TF("1T:&ES
M+3YR86ES945R<F]R*"1R;W<I.PH@("`@("`@("`@("!R971U<FX@)'1M<#L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R97-U;'1S.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&%U=&]#;VUM:70H*0H*("`@("\J*@H@("`@
M("H@16YA8FQE<R!O<B!D:7-A8FQE<R!A=71O;6%T:6,@8V]M;6ET<PH@("`@
M("H*("`@("`J($!P87)A;2!B;V]L("1O;F]F9B`@=')U92!T=7)N<R!I="!O
M;BP@9F%L<V4@='5R;G,@:70@;V9F"B`@("`@*@H@("`@("H@0')E='5R;B!I
M;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!I9B!T
M:&4@9')I=F5R"B`@("`@*B`@("`@("`@("`@("`@(&1O97-N)W0@<W5P<&]R
M="!A=71O+6-O;6UI='1I;F<@=')A;G-A8W1I;VYS+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!A=71O0V]M;6ET*"1O;F]F9B`](&9A;'-E*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E].3U1?0T%0
M04),12D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]M;6ET*"D*
M"B`@("`O*BH*("`@("`J($-O;6UI=',@=&AE(&-U<G)E;G0@=')A;G-A8W1I
M;VX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S
M<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-O;6UI="@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*$1"7T524D]27TY/5%]#05!!0DQ%*3L*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!R;VQL8F%C:R@I"@H@("`@+RHJ"B`@("`@
M*B!2979E<G1S('1H92!C=7)R96YT('1R86YS86-T:6]N"B`@("`@*@H@("`@
M("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R;VQL
M8F%C:R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*$1"7T524D]27TY/5%]#05!!0DQ%*3L*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!N=6U2;W=S*"D*"B`@("`O*BH*("`@("`J($1E=&5R;6EN97,@
M=&AE(&YU;6)E<B!O9B!R;W=S(&EN(&$@<75E<GD@<F5S=6QT"B`@("`@*@H@
M("`@("H@0'!A<F%M(')E<V]U<F-E("1R97-U;'0@('1H92!Q=65R>2!R97-U
M;'0@:61E;FEF:65R('!R;V1U8V5D(&)Y(%!(4`H@("`@("H*("`@("`J($!R
M971U<FX@:6YT("!T:&4@;G5M8F5R(&]F(')O=W,N("!!($1"7T5R<F]R(&]B
M:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!N=6U2;W=S
M*"1R97-U;'0I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*$1"7T524D]27TY/5%]#05!!0DQ%*3L*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!A9F9E8W1E9%)O=W,H*0H*("`@("\J*@H@("`@("H@1&5T
M97)M:6YE<R!T:&4@;G5M8F5R(&]F(')O=W,@869F96-T960@8GD@82!D871A
M(&UA;FEU<&QA=&EO;B!Q=65R>0H@("`@("H*("`@("`J(#`@:7,@<F5T=7)N
M960@9F]R('%U97)I97,@=&AA="!D;VXG="!M86YI<'5L871E(&1A=&$N"B`@
M("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB97(@;V8@<F]W<RX@
M($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&%F9F5C=&5D4F]W<R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*$1"7T524D]27TY/5%]#05!!0DQ%*3L*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!G971397%U96YC94YA;64H*0H*("`@
M("\J*@H@("`@("H@1V5N97)A=&5S('1H92!N86UE('5S960@:6YS:61E('1H
M92!D871A8F%S92!F;W(@82!S97%U96YC90H@("`@("H*("`@("`J(%1H92!C
M<F5A=&5397%U96YC92@I(&1O8V)L;V-K(&-O;G1A:6YS(&YO=&5S(&%B;W5T
M('-T;W)I;F<@<V5Q=65N8V4*("`@("`J(&YA;65S+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'-Q;B`@=&AE('-E<75E;F-E)W,@<'5B;&EC(&YA
M;64*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE('-E<75E;F-E
M)W,@;F%M92!I;B!T:&4@8F%C:V5N9`H@("`@("H*("`@("`J($!A8V-E<W,@
M<')O=&5C=&5D"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ8W)E871E4V5Q=65N
M8V4H*2P@1$)?8V]M;6]N.CID<F]P4V5Q=65N8V4H*2P*("`@("`J("`@("`@
M1$)?8V]M;6]N.CIN97AT240H*2P@1$)?8V]M;6]N.CIS971/<'1I;VXH*0H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971397%U96YC94YA;64H)'-Q;BD*("`@
M('L*("`@("`@("!R971U<FX@<W!R:6YT9B@D=&AI<RT^9V5T3W!T:6]N*"=S
M97%N86UE7V9O<FUA="<I+`H@("`@("`@("`@("`@("`@("`@("`@('!R96=?
M<F5P;&%C92@G+UM>82UZ,"TY7RY=+VDG+"`G7R<L("1S<6XI*3L*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!N97AT260H*0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@;F5X="!F<F5E(&ED(&EN(&$@<V5Q=65N8V4*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<V5Q7VYA;64@(&YA;64@;V8@
M=&AE('-E<75E;F-E"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;VYD96UA;F0@
M('=H96X@=')U92P@=&AE('-E<65N8V4@:7,@875T;VUA=&EC86QL>0H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8W)E871E9"!I9B!I="!D
M;V5S(&YO="!E>&ES=`H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@
M;F5X="!I9"!N=6UB97(@:6X@=&AE('-E<75E;F-E+@H@("`@("H@("`@("`@
M("`@("`@("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*
M("`@("`J($!S964@1$)?8V]M;6]N.CIC<F5A=&5397%U96YC92@I+"!$0E]C
M;VUM;VXZ.F1R;W!397%U96YC92@I+`H@("`@("H@("`@("!$0E]C;VUM;VXZ
M.F=E=%-E<75E;F-E3F%M92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&YE>'1)
M9"@D<V5Q7VYA;64L("1O;F1E;6%N9"`]('1R=64I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27TY/5%]#05!!0DQ%
M*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!C<F5A=&5397%U96YC
M92@I"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&$@;F5W('-E<75E;F-E"B`@
M("`@*@H@("`@("H@5&AE(&YA;64@;V8@82!G:79E;B!S97%U96YC92!I<R!D
M971E<FUI;F5D(&)Y('!A<W-I;F<@=&AE('-T<FEN9PH@("`@("H@<')O=FED
M960@:6X@=&AE(#QV87(^)'-E<5]N86UE/"]V87(^(&%R9W5M96YT('1H<F]U
M9V@@4$A0)W,@<W!R:6YT9B@I"B`@("`@*B!F=6YC=&EO;B!U<VEN9R!T:&4@
M=F%L=64@9G)O;2!T:&4@/'9A<CYS97%N86UE7V9O<FUA=#PO=F%R/B!O<'1I
M;VX@87,*("`@("`J('1H92!S<')I;G1F*"DG<R!F;W)M870@87)G=6UE;G0N
M"B`@("`@*@H@("`@("H@/'9A<CYS97%N86UE7V9O<FUA=#PO=F%R/B!I<R!S
M970@=FEA('-E=$]P=&EO;B@I+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'-E<5]N86UE("!N86UE(&]F('1H92!N97<@<V5Q=65N8V4*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$
M0E]C;VUM;VXZ.F1R;W!397%U96YC92@I+"!$0E]C;VUM;VXZ.F=E=%-E<75E
M;F-E3F%M92@I+`H@("`@("H@("`@("!$0E]C;VUM;VXZ.FYE>'1)1"@I"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&-R96%T95-E<75E;F-E*"1S97%?;F%M92D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)2
M3U)?3D]47T-!4$%"3$4I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&1R;W!397%U96YC92@I"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&$@<V5Q
M=65N8V4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S97%?;F%M92`@
M;F%M92!O9B!T:&4@<V5Q=65N8V4@=&\@8F4@9&5L971E9`H@("`@("H*("`@
M("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O
M;6UO;CHZ8W)E871E4V5Q=65N8V4H*2P@1$)?8V]M;6]N.CIG971397%U96YC
M94YA;64H*2P*("`@("`J("`@("`@1$)?8V]M;6]N.CIN97AT240H*0H@("`@
M("HO"B`@("!F=6YC=&EO;B!D<F]P4V5Q=65N8V4H)'-E<5]N86UE*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E].
M3U1?0T%004),12D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<F%I
M<V5%<G)O<B@I"@H@("`@+RHJ"B`@("`@*B!#;VUM=6YI8V%T97,@86X@97)R
M;W(@86YD(&EN=F]K92!E<G)O<B!C86QL8F%C:W,L(&5T8PH@("`@("H*("`@
M("`J($)A<VEC86QL>2!A('=R87!P97(@9F]R(%!%05(Z.G)A:7-E17)R;W(@
M=VET:&]U="!T:&4@;65S<V%G92!S=')I;F<N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&UI>&5D("`@:6YT96=E<B!E<G)O<B!C;V1E+"!O<B!A(%!%05(@97)R
M;W(@;V)J96-T("AA;&P*("`@("`J("`@("`@("`@("`@("`@("!O=&AE<B!P
M87)A;65T97)S(&%R92!I9VYO<F5D(&EF('1H:7,@<&%R86UE=&5R(&ES"B`@
M("`@*B`@("`@("`@("`@("`@("`@86X@;V)J96-T"B`@("`@*B!`<&%R86T@
M:6YT("`@("!E<G)O<B!M;V1E+"!S964@4$5!4E]%<G)O<B!D;V-S"B`@("`@
M*B!`<&%R86T@;6EX960@("!I9B!E<G)O<B!M;V1E(&ES(%!%05)?15)23U)?
M5%))1T=%4BP@=&AI<R!I<R!T:&4*("`@("`J("`@("`@("`@("`@("`@("!E
M<G)O<B!L979E;"`H15]54T527TY/5$E#12!E=&,I+B`@268@97)R;W(@;6]D
M92!I<PH@("`@("H@("`@("`@("`@("`@("`@(%!%05)?15)23U)?0T%,3$)!
M0TLL('1H:7,@:7,@=&AE(&-A;&QB86-K(&9U;F-T:6]N+`H@("`@("H@("`@
M("`@("`@("`@("`@(&5I=&AE<B!A<R!A(&9U;F-T:6]N(&YA;64L(&]R(&%S
M(&%N(&%R<F%Y(&]F(&%N"B`@("`@*B`@("`@("`@("`@("`@("`@;V)J96-T
M(&%N9"!M971H;V0@;F%M92X@($9O<B!O=&AE<B!E<G)O<B!M;V1E<R!T:&ES
M"B`@("`@*B`@("`@("`@("`@("`@("`@<&%R86UE=&5R(&ES(&EG;F]R960N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("!E>'1R82!D96)U9R!I;F9O<FUA=&EO
M;BX@($1E9F%U;'1S('1O('1H92!L87-T"B`@("`@*B`@("`@("`@("`@("`@
M("`@<75E<GD@86YD(&YA=&EV92!E<G)O<B!C;V1E+@H@("`@("H@0'!A<F%M
M(&UI>&5D("`@;F%T:79E(&5R<F]R(&-O9&4L(&EN=&5G97(@;W(@<W1R:6YG
M(&1E<&5N9&EN9R!T:&4*("`@("`J("`@("`@("`@("`@("`@("!B86-K96YD
M"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE8W0@('1H92!014%27T5R<F]R
M(&]B:F5C=`H@("`@("H*("`@("`J($!S964@4$5!4E]%<G)O<@H@("`@("HO
M"B`@("!F=6YC=&EO;B`F<F%I<V5%<G)O<B@D8V]D92`]($1"7T524D]2+"`D
M;6]D92`](&YU;&PL("1O<'1I;VYS(#T@;G5L;"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("1U<V5R:6YF;R`](&YU;&PL("1N871I=F5C;V1E(#T@;G5L
M;"D*("`@('L*("`@("`@("`O+R!4:&4@97)R;W(@:7,@>65T(&$@1$(@97)R
M;W(@;V)J96-T"B`@("`@("`@:68@*&ES7V]B:F5C="@D8V]D92DI('L*("`@
M("`@("`@("`@+R\@8F5C875S92!W92!T:&4@<W1A=&EC(%!%05(Z.G)A:7-E
M17)R;W(L(&]U<B!G;&]B86P*("`@("`@("`@("`@+R\@:&%N9&QE<B!S:&]U
M;&0@8F4@=7-E9"!I9B!I="!I<R!S970*("`@("`@("`@("`@:68@*"1M;V1E
M(#T]/2!N=6QL("8F("%E;7!T>2@D=&AI<RT^7V1E9F%U;'1?97)R;W)?;6]D
M92DI('L*("`@("`@("`@("`@("`@("1M;V1E("`@(#T@)'1H:7,M/E]D969A
M=6QT7V5R<F]R7VUO9&4["B`@("`@("`@("`@("`@("`D;W!T:6]N<R`]("1T
M:&ES+3Y?9&5F875L=%]E<G)O<E]O<'1I;VYS.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1T;7`@/2!014%2.CIR86ES945R<F]R*"1C;V1E+"!N=6QL
M+"`D;6]D92P@)&]P=&EO;G,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&YU;&PL(&YU;&PL('1R=64I.PH@("`@("`@("`@("!R971U
M<FX@)'1M<#L*("`@("`@("!]"@H@("`@("`@(&EF("@D=7-E<FEN9F\@/3T]
M(&YU;&PI('L*("`@("`@("`@("`@)'5S97)I;F9O(#T@)'1H:7,M/FQA<W1?
M<75E<GD["B`@("`@("`@?0H*("`@("`@("!I9B`H)&YA=&EV96-O9&4I('L*
M("`@("`@("`@("`@)'5S97)I;F9O("X]("<@6VYA=&EV96-O9&4])R`N('1R
M:6TH)&YA=&EV96-O9&4I("X@)UTG.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1U<V5R:6YF;R`N/2`G(%M$0B!%<G)O<CH@)R`N($1".CIE<G)O
M<DUE<W-A9V4H)&-O9&4I("X@)UTG.PH@("`@("`@('T*"B`@("`@("`@)'1M
M<"`](%!%05(Z.G)A:7-E17)R;W(H;G5L;"P@)&-O9&4L("1M;V1E+"`D;W!T
M:6]N<RP@)'5S97)I;F9O+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=$0E]%<G)O<B<L('1R=64I.PH@("`@("`@(')E='5R;B`D=&UP.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&5R<F]R3F%T:79E*"D*"B`@
M("`O*BH*("`@("`J($=E=',@=&AE($1"35,G(&YA=&EV92!E<G)O<B!C;V1E
M('!R;V1U8V5D(&)Y('1H92!L87-T('%U97)Y"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@=&AE($1"35,G(&5R<F]R(&-O9&4N("!!($1"7T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!E<G)O
M<DYA=&EV92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*$1"7T524D]27TY/5%]#05!!0DQ%*3L*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!E<G)O<D-O9&4H*0H*("`@("\J*@H@("`@("H@36%P<R!N
M871I=F4@97)R;W(@8V]D97,@=&\@1$(G<R!P;W)T86)L92!O;F5S"B`@("`@
M*@H@("`@("H@57-E<R!T:&4@/'9A<CXD97)R;W)C;V1E7VUA<#PO=F%R/B!P
M<F]P97)T>2!D969I;F5D(&EN(&5A8V@@9')I=F5R+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F=\:6YT("1N871I=F5C;V1E("!T:&4@97)R;W(@8V]D
M92!R971U<FYE9"!B>2!T:&4@1$)-4PH@("`@("H*("`@("`J($!R971U<FX@
M:6YT("!T:&4@<&]R=&%B;&4@1$(@97)R;W(@8V]D92X@(%)E='5R;B!$0E]%
M4E)/4B!I9B!T:&4*("`@("`J("`@("`@("`@("`@("`@8W5R<F5N="!D<FEV
M97(@9&]E<VXG="!H879E(&$@;6%P<&EN9R!F;W(@=&AE"B`@("`@*B`@("`@
M("`@("`@("`@("1N871I=F5C;V1E('-U8FUI='1E9"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@97)R;W)#;V1E*"1N871I=F5C;V1E*0H@("`@>PH@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^97)R;W)C;V1E7VUA<%LD;F%T:79E8V]D95TI
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^97)R;W)C;V1E7VUA<%LD
M;F%T:79E8V]D95T["B`@("`@("`@?0H@("`@("`@("\O($9A;&P@8F%C:R!T
M;R!$0E]%4E)/4B!I9B!T:&5R92!W87,@;F\@;6%P<&EN9RX*("`@("`@("!R
M971U<FX@1$)?15)23U(["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M97)R;W)-97-S86=E*"D*"B`@("`O*BH*("`@("`J($UA<',@82!$0B!E<G)O
M<B!C;V1E('1O(&$@=&5X='5A;"!M97-S86=E"B`@("`@*@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&1B8V]D92`@=&AE($1"(&5R<F]R(&-O9&4*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&5R<F]R(&UE<W-A9V4@8V]R
M<F5S<&]N9&EN9R!T;R!T:&4@97)R;W(@8V]D90H@("`@("H@("`@("`@("`@
M("`@("`@("!S=6)M:71T960N("!&04Q312!I9B!T:&4@97)R;W(@8V]D92!I
M<R!U;FMN;W=N+@H@("`@("H*("`@("`J($!S964@1$(Z.F5R<F]R365S<V%G
M92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&5R<F]R365S<V%G92@D9&)C;V1E
M*0H@("`@>PH@("`@("`@(')E='5R;B!$0CHZ97)R;W)-97-S86=E*"1T:&ES
M+3YE<G)O<F-O9&5?;6%P6R1D8F-O9&5=*3L*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!T86)L94EN9F\H*0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!I;F9O<FUA=&EO;B!A8F]U="!A('1A8FQE(&]R(&$@<F5S=6QT('-E=`H@
M("`@("H*("`@("`J(%1H92!F;W)M870@;V8@=&AE(')E<W5L=&EN9R!A<G)A
M>2!D97!E;F1S(&]N('=H:6-H(#QV87(^)&UO9&4\+W9A<CX*("`@("`J('EO
M=2!S96QE8W0N("!4:&4@<V%M<&QE(&]U='!U="!B96QO=R!I<R!B87-E9"!O
M;B!T:&ES('%U97)Y.@H@("`@("H@/'!R93X*("`@("`J("`@(%-%3$5#5"!T
M8FQ&;V\N9FQD240L('1B;$9O;RYF;&10:&]N92P@=&)L0F%R+F9L9$ED"B`@
M("`@*B`@("!&4D]-('1B;$9O;PH@("`@("H@("`@2D])3B!T8FQ"87(@3TX@
M=&)L1F]O+F9L9$ED(#T@=&)L0F%R+F9L9$ED"B`@("`@*B`\+W!R93X*("`@
M("`J"B`@("`@*B`\=6P^"B`@("`@*B`\;&D^"B`@("`@*@H@("`@("H@/&MB
M9#YN=6QL/"]K8F0^("AD969A=6QT*0H@("`@("H@("`\<')E/@H@("`@("H@
M("!;,%T@/3X@07)R87D@*`H@("`@("H@("`@("`@6W1A8FQE72`]/B!T8FQ&
M;V\*("`@("`J("`@("`@(%MN86UE72`]/B!F;&1)9`H@("`@("H@("`@("`@
M6W1Y<&5=(#T^(&EN=`H@("`@("H@("`@("`@6VQE;ET@/3X@,3$*("`@("`J
M("`@("`@(%MF;&%G<UT@/3X@<')I;6%R>5]K97D@;F]T7VYU;&P*("`@("`J
M("`@*0H@("`@("H@("!;,5T@/3X@07)R87D@*`H@("`@("H@("`@("`@6W1A
M8FQE72`]/B!T8FQ&;V\*("`@("`J("`@("`@(%MN86UE72`]/B!F;&10:&]N
M90H@("`@("H@("`@("`@6W1Y<&5=(#T^('-T<FEN9PH@("`@("H@("`@("`@
M6VQE;ET@/3X@,C`*("`@("`J("`@("`@(%MF;&%G<UT@/3X*("`@("`J("`@
M*0H@("`@("H@("!;,ET@/3X@07)R87D@*`H@("`@("H@("`@("`@6W1A8FQE
M72`]/B!T8FQ"87(*("`@("`J("`@("`@(%MN86UE72`]/B!F;&1)9`H@("`@
M("H@("`@("`@6W1Y<&5=(#T^(&EN=`H@("`@("H@("`@("`@6VQE;ET@/3X@
M,3$*("`@("`J("`@("`@(%MF;&%G<UT@/3X@<')I;6%R>5]K97D@;F]T7VYU
M;&P*("`@("`J("`@*0H@("`@("H@("`\+W!R93X*("`@("`J"B`@("`@*B`\
M+VQI/CQL:3X*("`@("`J"B`@("`@*B`\:V)D/D1"7U1!0DQ%24Y&3U]/4D1%
M4CPO:V)D/@H@("`@("H*("`@("`J("`@/'`^26X@861D:71I;VX@=&\@=&AE
M(&EN9F]R;6%T:6]N(&9O=6YD(&EN('1H92!D969A=6QT(&]U='!U="P*("`@
M("`J("`@82!N;W1A=&EO;B!O9B!T:&4@;G5M8F5R(&]F(&-O;'5M;G,@:7,@
M<')O=FED960@8GD@=&AE"B`@("`@*B`@(#QS86UP/FYU;5]F:65L9',\+W-A
M;7`^(&5L96UE;G0@=VAI;&4@=&AE(#QS86UP/F]R9&5R/"]S86UP/@H@("`@
M("H@("!E;&5M96YT('!R;W9I9&5S(&%N(&%R<F%Y('=I=&@@=&AE(&-O;'5M
M;B!N86UE<R!A<R!T:&4@:V5Y<R!A;F0*("`@("`J("`@=&AE:7(@;&]C871I
M;VX@:6YD97@@;G5M8F5R("AC;W)R97-P;VYD:6YG('1O('1H92!K97ES(&EN
M('1H90H@("`@("H@("!T:&4@9&5F875L="!O=71P=70I(&%S('1H92!V86QU
M97,N/"]P/@H@("`@("H*("`@("`J("`@/'`^268@82!R97-U;'0@<V5T(&AA
M<R!I9&5N=&EC86P@9FEE;&0@;F%M97,L('1H92!L87-T(&]N92!I<PH@("`@
M("H@("!U<V5D+CPO<#X*("`@("`J"B`@("`@*B`@(#QP<F4^"B`@("`@*B`@
M(%MN=6U?9FEE;&1S72`]/B`S"B`@("`@*B`@(%MO<F1E<ET@/3X@07)R87D@
M*`H@("`@("H@("`@("`@6V9L9$ED72`]/B`R"B`@("`@*B`@("`@("!;9FQD
M5')A;G-=(#T^(#$*("`@("`J("`@*0H@("`@("H@("`\+W!R93X*("`@("`J
M"B`@("`@*B`\+VQI/CQL:3X*("`@("`J"B`@("`@*B`\:V)D/D1"7U1!0DQ%
M24Y&3U]/4D1%4E1!0DQ%/"]K8F0^"B`@("`@*@H@("`@("H@("`\<#Y3:6UI
M;&%R('1O(#QK8F0^1$)?5$%"3$5)3D9/7T]21$52/"]K8F0^(&)U="!A9&1S
M(&UO<F4*("`@("`J("`@9&EM96YS:6]N<R!T;R!T:&4@87)R87D@:6X@=VAI
M8V@@=&AE('1A8FQE(&YA;65S(&%R92!K97ES(&%N9`H@("`@("H@("!T:&4@
M9FEE;&0@;F%M97,@87)E('-U8BUK97ES+B`@5&AI<R!I<R!H96QP9G5L(&9O
M<B!Q=65R:65S('1H870*("`@("`J("`@:F]I;B!T86)L97,@=VAI8V@@:&%V
M92!I9&5N=&EC86P@9FEE;&0@;F%M97,N/"]P/@H@("`@("H*("`@("`J("`@
M/'!R93X*("`@("`J("`@6VYU;5]F:65L9'-=(#T^(#,*("`@("`J("`@6V]R
M9&5R=&%B;&5=(#T^($%R<F%Y("@*("`@("`J("`@("`@(%MT8FQ&;V]=(#T^
M($%R<F%Y("@*("`@("`J("`@("`@("`@("!;9FQD261=(#T^(#`*("`@("`J
M("`@("`@("`@("!;9FQD4&AO;F5=(#T^(#$*("`@("`J("`@("`@("D*("`@
M("`J("`@("`@(%MT8FQ"87)=(#T^($%R<F%Y("@*("`@("`J("`@("`@("`@
M("!;9FQD261=(#T^(#(*("`@("`J("`@("`@("D*("`@("`J("`@*0H@("`@
M("H@("`\+W!R93X*("`@("`J"B`@("`@*B`\+VQI/@H@("`@("H@/"]U;#X*
M("`@("`J"B`@("`@*B!4:&4@/'-A;7`^9FQA9W,\+W-A;7`^(&5L96UE;G0@
M8V]N=&%I;G,@82!S<&%C92!S97!A<F%T960@;&ES=`H@("`@("H@;V8@97AT
M<F$@:6YF;W)M871I;VX@86)O=70@=&AE(&9I96QD+B`@5&AI<R!D871A(&ES
M(&EN8V]N<VES=&5N=`H@("`@("H@8F5T=V5E;B!$0DU3)W,@9'5E('1O('1H
M92!W87D@96%C:"!$0DU3('=O<FMS+@H@("`@("H@("`K(#QS86UP/G!R:6UA
M<GE?:V5Y/"]S86UP/@H@("`@("H@("`K(#QS86UP/G5N:7%U95]K97D\+W-A
M;7`^"B`@("`@*B`@("L@/'-A;7`^;75L=&EP;&5?:V5Y/"]S86UP/@H@("`@
M("H@("`K(#QS86UP/FYO=%]N=6QL/"]S86UP/@H@("`@("H*("`@("`J($UO
M<W0@1$)-4R=S(&]N;'D@<')O=FED92!T:&4@/'-A;7`^=&%B;&4\+W-A;7`^
M(&%N9"`\<V%M<#YF;&%G<SPO<V%M<#X*("`@("`J(&5L96UE;G1S(&EF(#QV
M87(^)')E<W5L=#PO=F%R/B!I<R!A('1A8FQE(&YA;64N("!4:&4@9F]L;&]W
M:6YG($1"35,G<PH@("`@("H@<')O=FED92!F=6QL(&EN9F]R;6%T:6]N(&9R
M;VT@<75E<FEE<SH*("`@("`J("`@*R!F8G-Q;`H@("`@("H@("`K(&UY<W%L
M"B`@("`@*@H@("`@("H@268@=&AE("=P;W)T86)I;&ET>2<@;W!T:6]N(&AA
M<R`\<V%M<#Y$0E]03U)404))3$E465],3U=%4D-!4T4\+W-A;7`^"B`@("`@
M*B!T=7)N960@;VXL('1H92!N86UE<R!O9B!T86)L97,@86YD(&9I96QD<R!W
M:6QL(&)E(&QO=V5R8V%S960N"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C
M='QS=')I;F<@("1R97-U;'0@($1"7W)E<W5L="!O8FIE8W0@9G)O;2!A('%U
M97)Y(&]R(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!S=')I;F<@8V]N=&%I;FEN9R!T:&4@;F%M92!O9B!A('1A8FQE+@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%=H:6QE('1H:7,@
M86QS;R!A8V-E<'1S(&$@<75E<GD@<F5S=6QT"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@<F5S;W5R8V4@:61E;G1I9FEE<BP@=&AI
M<R!B96AA=FEO<B!I<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&1E<')E8V%T960N"B`@("`@*B!`<&%R86T@:6YT("`D;6]D92`@
M(&5I=&AE<B!U;G5S960@;W(@;VYE(&]F('1H92!T86)L94EN9F\@;6]D97,Z
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(#QK8F0^1$)?5$%"3$5)3D9/
M7T]21$525$%"3$4\+VMB9#XL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M(#QK8F0^1$)?5$%"3$5)3D9/7T]21$52/"]K8F0^(&]R"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@(#QK8F0^1$)?5$%"3$5)3D9/7T953$P\+VMB9#X@
M*'=H:6-H(&1O97,@8F]T:"DN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M(%1H97-E(&%R92!B:71W:7-E+"!S;R!T:&4@9FER<W0@='=O(&-A;B!B90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("!C;VUB:6YE9"!U<VEN9R`\:V)D
M/GP\+VMB9#XN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@86X@87-S
M;V-I871I=F4@87)R87D@=VET:"!T:&4@:6YF;W)M871I;VX@<F5Q=65S=&5D
M+@H@("`@("H@("`@("`@("`@("`@("`@($$@1$)?17)R;W(@;V)J96-T(&]N
M(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G-E=$]P
M=&EO;B@I"B`@("`@*B\*("`@(&9U;F-T:6]N('1A8FQE26YF;R@D<F5S=6QT
M+"`D;6]D92`](&YU;&PI"B`@("!["B`@("`@("`@+RH*("`@("`@("`@*B!)
M9B!T:&4@1$)?/&1R:79E<CX@8VQA<W,@:&%S(&$@=&%B;&5);F9O*"D@;65T
M:&]D+"!T:&%T(&]N90H@("`@("`@("`J(&]V97)R:61E<R!T:&ES(&]N92X@
M($)U="P@:68@=&AE(&1R:79E<B!D;V5S;B=T(&AA=F4@;VYE+`H@("`@("`@
M("`J('1H:7,@;65T:&]D(')U;G,@86YD('1E;&QS('5S97)S(&%B;W5T('1H
M870@9F%C="X*("`@("`@("`@*B\*("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H1$)?15)23U)?3D]47T-!4$%"3$4I.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&=E=%1A8FQE<R@I"@H@("`@+RHJ"B`@("`@*B!,
M:7-T<R!T:&4@=&%B;&5S(&EN('1H92!C=7)R96YT(&1A=&%B87-E"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@=&AE(&QI<W0@;V8@=&%B;&5S+B`@
M02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`
M9&5P<F5C871E9"!-971H;V0@9&5P<F5C871E9"!S;VUE('1I;64@8F5F;W)E
M(%)E;&5A<V4@,2XR"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1A8FQE<R@I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YG971,:7-T3V8H)W1A8FQE
M<R<I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&=E=$QI<W1/9B@I
M"@H@("`@+RHJ"B`@("`@*B!,:7-T<R!I;G1E<FYA;"!D871A8F%S92!I;F9O
M<FUA=&EO;@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@('1Y
M<&4@;V8@:6YF;W)M871I;VX@8F5I;F<@<V]U9VAT+@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@($-O;6UO;B!I=&5M<R!B96EN9R!S;W5G:'0@87)E
M.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('1A8FQE<RP@9&%T86)A
M<V5S+"!U<V5R<RP@=FEE=W,L(&9U;F-T:6]N<PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@($5A8V@@1$)-4R=S(&AA<R!I=',@;W=N(&-A<&%B:6QI
M=&EE<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!A;B!A<G)A>2!L
M:7-T:6YG('1H92!I=&5M<R!S;W5G:'0N"B`@("`@*B`@("`@("`@("`@("`@
M("`@02!$0B!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T3&ES=$]F*"1T>7!E*0H@("`@>PH@("`@("`@("1S
M<6P@/2`D=&AI<RT^9V5T4W!E8VEA;%%U97)Y*"1T>7!E*3L*("`@("`@("!I
M9B`H)'-Q;"`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D=&AI<RT^;&%S=%]Q
M=65R>2`]("<G.PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H1$)?15)23U)?54Y355!03U)4140I.PH@("`@("`@('T@96QS96EF("AI
M<U]I;G0H)'-Q;"D@?'P@1$(Z.FES17)R;W(H)'-Q;"DI('L*("`@("`@("`@
M("`@+R\@4')E=FEO=7,@97)R;W(*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*"1S<6PI.PH@("`@("`@('T@96QS96EF("AI<U]A<G)A
M>2@D<W%L*2D@>PH@("`@("`@("`@("`O+R!!;')E861Y('1H92!R97-U;'0*
M("`@("`@("`@("`@<F5T=7)N("1S<6P["B`@("`@("`@?0H@("`@("`@("\O
M($QA=6YC:"!T:&ES('%U97)Y"B`@("`@("`@<F5T=7)N("1T:&ES+3YG971#
M;VPH)'-Q;"D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9V5T4W!E
M8VEA;%%U97)Y*"D*"B`@("`O*BH*("`@("`J($]B=&%I;G,@=&AE('%U97)Y
M('-T<FEN9R!N965D960@9F]R(&QI<W1I;F<@82!G:79E;B!T>7!E(&]F(&]B
M:F5C=',*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E("!T:&4@
M:VEN9"!O9B!O8FIE8W1S('EO=2!W86YT('1O(')E=')I979E"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@('1H92!344P@<75E<GD@<W1R:6YG(&]R
M(&YU;&P@:68@=&AE(&1R:79E<B!D;V5S;B=T"B`@("`@*B`@("`@("`@("`@
M("`@("`@('-U<'!O<G0@=&AE(&]B:F5C="!T>7!E(')E<75E<W1E9`H@("`@
M("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B!`<V5E($1"7V-O
M;6UO;CHZ9V5T3&ES=$]F*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4W!E
M8VEA;%%U97)Y*"1T>7!E*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<BA$0E]%4E)/4E]53E-54%!/4E1%1"D["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@7W)T<FEM07)R87E686QU97,H*0H*("`@("\J
M*@H@("`@("H@4FEG:'0M=')I;7,@86QL('-T<FEN9W,@:6X@86X@87)R87D*
M("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&%R<F%Y("!T:&4@87)R87D@
M=&\@8F4@=')I;6UE9"`H<&%S<V5D(&)Y(')E9F5R96YC92D*("`@("`J"B`@
M("`@*B!`<F5T=7)N('9O:60*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E
M8W1E9`H@("`@("HO"B`@("!F=6YC=&EO;B!?<G1R:6U!<G)A>59A;'5E<R@F
M)&%R<F%Y*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1A<G)A>2!A<R`D:V5Y
M(#T^("1V86QU92D@>PH@("`@("`@("`@("!I9B`H:7-?<W1R:6YG*"1V86QU
M92DI('L*("`@("`@("`@("`@("`@("1A<G)A>5LD:V5Y72`](')T<FEM*"1V
M86QU92D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@7V-O;G9E<G1.=6QL07)R87E686QU97-4;T5M<'1Y
M*"D*"B`@("`O*BH*("`@("`J($-O;G9E<G1S(&%L;"!N=6QL('9A;'5E<R!I
M;B!A;B!A<G)A>2!T;R!E;7!T>2!S=')I;F=S"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("`D87)R87D@('1H92!A<G)A>2!T;R!B92!D92UN=6QL:69I
M960@*'!A<W-E9"!B>2!R969E<F5N8V4I"B`@("`@*@H@("`@("H@0')E='5R
M;B!V;VED"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V-O;G9E<G1.=6QL07)R87E686QU97-4;T5M<'1Y
M*"8D87)R87DI"B`@("!["B`@("`@("`@9F]R96%C:"`H)&%R<F%Y(&%S("1K
M97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@(&EF("AI<U]N=6QL*"1V86QU
M92DI('L*("`@("`@("`@("`@("`@("1A<G)A>5LD:V5Y72`]("<G.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0I]"@HO*@H@
M*B!,;V-A;"!V87)I86)L97,Z"B`J('1A8BUW:61T:#H@-`H@*B!C+6)A<VEC
M+6]F9G-E=#H@-`H@*B!%;F0Z"B`J+PH*/SX*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+T1"+V9B<W%L+G!H<```````````````````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-34U-C4@,3`U,34T,S,W,S$@,#(P
M-C$Q`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"@HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T
M=VED=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J(%1H92!014%2($1"
M(&1R:79E<B!F;W(@4$A0)W,@9F)S<6P@97AT96YS:6]N"B`J(&9O<B!I;G1E
M<F%C=&EN9R!W:71H($9R;VYT0F%S92!D871A8F%S97,*("H*("H@4$A0('9E
M<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL
M92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS
M90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E
M+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@
M82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T
M;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*("H@<V5N9"!A
M(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A
M(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E
M"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@($9R86YK($TN($MR
M;VUA;FX@/&9R86YK0&9R;VYT8F%S92YC;VT^"B`J($!A=71H;W(@("`@($1A
M;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H
M="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@
M,RXP"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!F8G-Q;"YP:'`L=B`Q+C@R
M(#(P,#4O,#,O,#0@,C,Z,3(Z,S8@9&%N:65L8R!%>'`@)`H@*B!`;&EN:R`@
M("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO"@HO*BH*
M("H@3V)T86EN('1H92!$0E]C;VUM;VX@8VQA<W,@<V\@:70@8V%N(&)E(&5X
M=&5N9&5D(&9R;VT*("HO"G)E<75I<F5?;VYC92`G1$(O8V]M;6]N+G!H<"<[
M"@HO*BH*("H@5&AE(&UE=&AO9',@4$5!4B!$0B!U<V5S('1O(&EN=&5R86-T
M('=I=&@@4$A0)W,@9F)S<6P@97AT96YS:6]N"B`J(&9O<B!I;G1E<F%C=&EN
M9R!W:71H($9R;VYT0F%S92!D871A8F%S97,*("H*("H@5&AE<V4@;65T:&]D
M<R!O=F5R;&]A9"!T:&4@;VYE<R!D96-L87)E9"!I;B!$0E]C;VUM;VXN"B`J
M"B`J($!C871E9V]R>2`@($1A=&%B87-E"B`J($!P86-K86=E("`@($1""B`J
M($!A=71H;W(@("`@($9R86YK($TN($MR;VUA;FX@/&9R86YK0&9R;VYT8F%S
M92YC;VT^"B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE
M;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@
M1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@(%)E
M;&5A<V4Z(#$N-RXV"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN
M970O<&%C:V%G92]$0@H@*B!`<VEN8V4@("`@("!#;&%S<R!F=6YC=&EO;F%L
M('-I;F-E(%)E;&5A<V4@,2XW+C`*("HO"F-L87-S($1"7V9B<W%L(&5X=&5N
M9',@1$)?8V]M;6]N"GL*("`@("\O('M[>R!P<F]P97)T:65S"@H@("`@+RHJ
M"B`@("`@*B!4:&4@1$(@9')I=F5R('1Y<&4@*&UY<W%L+"!O8VDX+"!O9&)C
M+"!E=&,N*0H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1P
M:'!T>7!E(#T@)V9B<W%L)SL*"B`@("`O*BH*("`@("`J(%1H92!D871A8F%S
M92!S>6YT87@@=F%R:6%N="!T;R!B92!U<V5D("AD8C(L(&%C8V5S<RP@971C
M+BDL(&EF(&%N>0H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1D8G-Y;G1A>"`]("=F8G-Q;"<["@H@("`@+RHJ"B`@("`@*B!4:&4@8V%P
M86)I;&ET:65S(&]F('1H:7,@1$(@:6UP;&5M96YT871I;VX*("`@("`J"B`@
M("`@*B!4:&4@)VYE=U]L:6YK)R!E;&5M96YT(&-O;G1A:6YS('1H92!02%`@
M=F5R<VEO;B!T:&%T(&9I<G-T('!R;W9I9&5D"B`@("`@*B!N97=?;&EN:R!S
M=7!P;W)T(&9O<B!T:&ES($1"35,N("!#;VYT86EN<R!F86QS92!I9B!I="=S
M('5N<W5P<&]R=&5D+@H@("`@("H*("`@("`J($UE86YI;F<@;V8@=&AE("=L
M:6UI="<@96QE;65N=#H*("`@("`J("`@*R`G96UU;&%T92<@/2!E;75L871E
M('=I=&@@9F5T8V@@<F]W(&)Y(&YU;6)E<@H@("`@("H@("`K("=A;'1E<B<@
M("`](&%L=&5R('1H92!Q=65R>0H@("`@("H@("`K(&9A;'-E("`@("`]('-K
M:7`@<F]W<PH@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1F96%T=7)E<R`](&%R<F%Y*`H@("`@("`@("=L:6UI="<@("`@("`@
M("`]/B`G86QT97(G+`H@("`@("`@("=N97=?;&EN:R<@("`@("`]/B!F86QS
M92P*("`@("`@("`G;G5M<F]W<R<@("`@("`@/3X@=')U92P*("`@("`@("`G
M<&-O;FYE8W0G("`@("`@/3X@=')U92P*("`@("`@("`G<')E<&%R92<@("`@
M("`@/3X@9F%L<V4L"B`@("`@("`@)W-S;"<@("`@("`@("`@(#T^(&9A;'-E
M+`H@("`@("`@("=T<F%N<V%C=&EO;G,G("`]/B!T<G5E+`H@("`@*3L*"B`@
M("`O*BH*("`@("`J($$@;6%P<&EN9R!O9B!N871I=F4@97)R;W(@8V]D97,@
M=&\@1$(@97)R;W(@8V]D97,*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1E<G)O<F-O9&5?;6%P(#T@87)R87DH"B`@("`@("`@(#(R(#T^
M($1"7T524D]27U-93E1!6"P*("`@("`@("`@.#4@/3X@1$)?15)23U)?04Q2
M14%$65]%6$E35%,L"B`@("`@("`@,3`X(#T^($1"7T524D]27U-93E1!6"P*
M("`@("`@("`Q,38@/3X@1$)?15)23U)?3D]354-(5$%"3$4L"B`@("`@("`@
M,3(T(#T^($1"7T524D]27U9!3%5%7T-/54Y47T].7U)/5RP*("`@("`@("`R
M,34@/3X@1$)?15)23U)?3D]354-(1DE%3$0L"B`@("`@("`@,C$W(#T^($1"
M7T524D]27TE.5D%,241?3E5-0D52+`H@("`@("`@(#(R-B`]/B!$0E]%4E)/
M4E].3U-50TA&245,1"P*("`@("`@("`R,S$@/3X@1$)?15)23U)?24Y604Q)
M1"P*("`@("`@("`R,SD@/3X@1$)?15)23U)?5%)53D-!5$5$+`H@("`@("`@
M(#(U,2`]/B!$0E]%4E)/4E]364Y405@L"B`@("`@("`@,C8V(#T^($1"7T52
M4D]27TY/5%]&3U5.1"P*("`@("`@("`S-3<@/3X@1$)?15)23U)?0T].4U12
M04E.5%].3U1?3E5,3"P*("`@("`@("`S-3@@/3X@1$)?15)23U)?0T].4U12
M04E.5"P*("`@("`@("`S-C`@/3X@1$)?15)23U)?0T].4U1204E.5"P*("`@
M("`@("`S-C$@/3X@1$)?15)23U)?0T].4U1204E.5"P*("`@("D["@H@("`@
M+RHJ"B`@("`@*B!4:&4@<F%W(&1A=&%B87-E(&-O;FYE8W1I;VX@8W)E871E
M9"!B>2!02%`*("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J+PH@("`@=F%R
M("1C;VYN96-T:6]N.PH*("`@("\J*@H@("`@("H@5&AE($133B!I;F9O<FUA
M=&EO;B!F;W(@8V]N;F5C=&EN9R!T;R!A(&1A=&%B87-E"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D9'-N(#T@87)R87DH*3L*"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@8V]N<W1R=6-T;W(*"B`@("`O*BH*("`@("`J
M(%1H:7,@8V]N<W1R=6-T;W(@8V%L;',@/&MB9#XD=&AI<RT^1$)?8V]M;6]N
M*"D\+VMB9#X*("`@("`J"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@
M("`@9G5N8W1I;VX@1$)?9F)S<6PH*0H@("`@>PH@("`@("`@("1T:&ES+3Y$
M0E]C;VUM;VXH*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VYN
M96-T*"D*"B`@("`O*BH*("`@("`J($-O;FYE8W0@=&\@=&AE(&1A=&%B87-E
M('-E<G9E<BP@;&]G(&EN(&%N9"!O<&5N('1H92!D871A8F%S90H@("`@("H*
M("`@("`J($1O;B=T(&-A;&P@=&AI<R!M971H;V0@9&ER96-T;'DN("!5<V4@
M1$(Z.F-O;FYE8W0H*2!I;G-T96%D+@H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`D9'-N("`@("`@("`@=&AE(&1A=&$@<V]U<F-E(&YA;64*("`@("`J
M($!P87)A;2!B;V]L("`D<&5R<VES=&5N="`@<VAO=6QD('1H92!C;VYN96-T
M:6]N(&)E('!E<G-I<W1E;G0_"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@
M($1"7T]+(&]N('-U8V-E<W,N($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;FYE8W0H)&1S;BP@)'!E<G-I
M<W1E;G0@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H(5!%05(Z.FQO861%
M>'1E;G-I;VXH)V9B<W%L)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*$1"7T524D]27T585$5.4TE/3E].3U1?1D]53D0I.PH@
M("`@("`@('T*"B`@("`@("`@)'1H:7,M/F1S;B`]("1D<VX["B`@("`@("`@
M:68@*"1D<VY;)V1B<WEN=&%X)UTI('L*("`@("`@("`@("`@)'1H:7,M/F1B
M<WEN=&%X(#T@)&1S;ELG9&)S>6YT87@G73L*("`@("`@("!]"@H@("`@("`@
M("1P87)A;7,@/2!A<G)A>2@*("`@("`@("`@("`@)&1S;ELG:&]S='-P96,G
M72`_("1D<VY;)VAO<W1S<&5C)UT@.B`G;&]C86QH;W-T)RP*("`@("`@("`@
M("`@)&1S;ELG=7-E<FYA;64G72`_("1D<VY;)W5S97)N86UE)UT@.B!N=6QL
M+`H@("`@("`@("`@("`D9'-N6R=P87-S=V]R9"==(#\@)&1S;ELG<&%S<W=O
M<F0G72`Z(&YU;&PL"B`@("`@("`@*3L*"B`@("`@("`@)&-O;FYE8W1?9G5N
M8W1I;VX@/2`D<&5R<VES=&5N="`_("=F8G-Q;%]P8V]N;F5C="<@.B`G9F)S
M<6Q?8V]N;F5C="<["@H@("`@("`@("1I;FD@/2!I;FE?9V5T*"=T<F%C:U]E
M<G)O<G,G*3L*("`@("`@("`D<&AP7V5R<F]R;7-G(#T@)R<["B`@("`@("`@
M:68@*"1I;FDI('L*("`@("`@("`@("`@)'1H:7,M/F-O;FYE8W1I;VX@/2!`
M8V%L;%]U<V5R7V9U;F-?87)R87DH)&-O;FYE8W1?9G5N8W1I;VXL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EN
M:5]S970H)W1R86-K7V5R<F]R<R<L(#$I.PH@("`@("`@("`@("`D=&AI<RT^
M8V]N;F5C=&EO;B`]($!C86QL7W5S97)?9G5N8U]A<G)A>2@D8V]N;F5C=%]F
M=6YC=&EO;BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'!A<F%M<RD["B`@("`@("`@("`@(&EN:5]S
M970H)W1R86-K7V5R<F]R<R<L("1I;FDI.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"$D=&AI<RT^8V]N;F5C=&EO;BD@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?0T].3D5#5%]&04E,140L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N=6QL+"!N=6QL
M+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!H<%]E<G)O<FUS9RD["B`@("`@("`@?0H*("`@("`@("!I9B`H)&1S;ELG
M9&%T86)A<V4G72D@>PH@("`@("`@("`@("!I9B`H(4!F8G-Q;%]S96QE8W1?
M9&(H)&1S;ELG9&%T86)A<V4G72P@)'1H:7,M/F-O;FYE8W1I;VXI*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/F9B<W%L4F%I<V5%<G)O<B@I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@1$)?
M3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9&ES8V]N;F5C="@I
M"@H@("`@+RHJ"B`@("`@*B!$:7-C;VYN96-T<R!F<F]M('1H92!D871A8F%S
M92!S97)V97(*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@(%12544@;VX@
M<W5C8V5S<RP@1D%,4T4@;VX@9F%I;'5R90H@("`@("HO"B`@("!F=6YC=&EO
M;B!D:7-C;VYN96-T*"D*("`@('L*("`@("`@("`D<F5T(#T@0&9B<W%L7V-L
M;W-E*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`D=&AI<RT^8V]N;F5C
M=&EO;B`](&YU;&P["B`@("`@("`@<F5T=7)N("1R970["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@<VEM<&QE475E<GDH*0H*("`@("\J*@H@("`@
M("H@4V5N9',@82!Q=65R>2!T;R!T:&4@9&%T86)A<V4@<V5R=F5R"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`@=&AE(%-13"!Q=65R>2!S=')I;F<*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("`K(&$@4$A0(')E<W5L="!R
M97-R;W5C92!F;W(@<W5C8V5S<V9U;"!314Q%0U0@<75E<FEE<PH@("`@("H@
M("`@("`@("`@("`@("`@*R!T:&4@1$)?3TL@8V]N<W1A;G0@9F]R(&]T:&5R
M('-U8V-E<W-F=6P@<75E<FEE<PH@("`@("H@("`@("`@("`@("`@("`@*R!A
M($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E"B`@("`@*B\*("`@(&9U;F-T
M:6]N('-I;7!L95%U97)Y*"1Q=65R>2D*("`@('L*("`@("`@("`D=&AI<RT^
M;&%S=%]Q=65R>2`]("1Q=65R>3L*("`@("`@("`D<75E<GD@/2`D=&AI<RT^
M;6]D:69Y475E<GDH)'%U97)Y*3L*("`@("`@("`D<F5S=6QT(#T@0&9B<W%L
M7W%U97)Y*"(D<75E<GD[(BP@)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@
M(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F9B
M<W%L4F%I<V5%<G)O<B@I.PH@("`@("`@('T*("`@("`@("`O+R!$971E<FUI
M;F4@=VAI8V@@<75E<FEE<R!T:&%T('-H;W5L9"!R971U<FX@9&%T82P@86YD
M('=H:6-H"B`@("`@("`@+R\@<VAO=6QD(')E='5R;B!A;B!E<G)O<B!C;V1E
M(&]N;'DN"B`@("`@("`@:68@*$1".CII<TUA;FEP*"1Q=65R>2DI('L*("`@
M("`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!N97AT
M4F5S=6QT*"D*"B`@("`O*BH*("`@("`J($UO=F4@=&AE(&EN=&5R;F%L(&9B
M<W%L(')E<W5L="!P;VEN=&5R('1O('1H92!N97AT(&%V86EL86)L92!R97-U
M;'0*("`@("`J"B`@("`@*B!`<&%R86T@82!V86QI9"!F8G-Q;"!R97-U;'0@
M<F5S;W5R8V4*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H*
M("`@("`J($!R971U<FX@=')U92!I9B!A(')E<W5L="!I<R!A=F%I;&%B;&4@
M;W1H97)W:7-E(')E='5R;B!F86QS90H@("`@("HO"B`@("!F=6YC=&EO;B!N
M97AT4F5S=6QT*"1R97-U;'0I"B`@("!["B`@("`@("`@<F5T=7)N($!F8G-Q
M;%]N97AT7W)E<W5L="@D<F5S=6QT*3L*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!F971C:$EN=&\H*0H*("`@("\J*@H@("`@("H@4&QA8V5S(&$@
M<F]W(&9R;VT@=&AE(')E<W5L="!S970@:6YT;R!T:&4@9VEV96X@87)R87D*
M("`@("`J"B`@("`@*B!&;W)M871I;F<@;V8@=&AE(&%R<F%Y(&%N9"!T:&4@
M9&%T82!T:&5R96EN(&%R92!C;VYF:6=U<F%B;&4N"B`@("`@*B!3964@1$)?
M<F5S=6QT.CIF971C:$EN=&\H*2!F;W(@;6]R92!I;F9O<FUA=&EO;BX*("`@
M("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L
M;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z.F9E=&-H26YT
M;R@I(&EN<W1E860N("!)="!C86XG="!B92!D96-L87)E9"`B<')O=&5C=&5D
M(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@82!S97!A<F%T92!O8FIE
M8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1R97-U;'0@("`@
M=&AE('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@("H@0'!A<F%M(&%R<F%Y
M("`@("1A<G(@("`@("`@=&AE(')E9F5R96YC960@87)R87D@=&\@<'5T('1H
M92!D871A(&EN"B`@("`@*B!`<&%R86T@:6YT("`@("`@)&9E=&-H;6]D92!H
M;W<@=&AE(')E<W5L=&EN9R!A<G)A>2!S:&]U;&0@8F4@:6YD97AE9`H@("`@
M("H@0'!A<F%M(&EN="`@("`@("1R;W=N=6T@("`@=&AE(')O=R!N=6UB97(@
M=&\@9F5T8V@@*#`@/2!F:7)S="!R;W<I"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@1$)?3TL@;VX@<W5C8V5S<RP@3E5,3"!W:&5N('1H92!E;F0@
M;V8@82!R97-U;'0@<V5T(&ES"B`@("`@*B`@("`@("`@("`@("`@("`@<F5A
M8VAE9"!O<B!O;B!F86EL=7)E"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U
M;'0Z.F9E=&-H26YT;R@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&9E=&-H26YT
M;R@D<F5S=6QT+"`F)&%R<BP@)&9E=&-H;6]D92P@)')O=VYU;2`](&YU;&PI
M"B`@("!["B`@("`@("`@:68@*"1R;W=N=6T@(3T](&YU;&PI('L*("`@("`@
M("`@("`@:68@*"%`9F)S<6Q?9&%T85]S965K*"1R97-U;'0L("1R;W=N=6TI
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!I9B`H)&9E=&-H;6]D92`F($1"7T9%5$-(
M34]$15]!4U-/0RD@>PH@("`@("`@("`@("`D87)R(#T@0&9B<W%L7V9E=&-H
M7V%R<F%Y*"1R97-U;'0L($9"4U%,7T%34T]#*3L*("`@("`@("`@("`@:68@
M*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)
M5%E?3$]715)#05-%("8F("1A<G(I('L*("`@("`@("`@("`@("`@("1A<G(@
M/2!A<G)A>5]C:&%N9V5?:V5Y7V-A<V4H)&%R<BP@0T%315],3U=%4BD["B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D87)R
M(#T@0&9B<W%L7V9E=&-H7W)O=R@D<F5S=6QT*3L*("`@("`@("!]"B`@("`@
M("`@:68@*"$D87)R*2!["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@
M("`@('T*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y
M)UT@)B!$0E]03U)404))3$E465]25%))32D@>PH@("`@("`@("`@("`D=&AI
M<RT^7W)T<FEM07)R87E686QU97,H)&%R<BD["B`@("`@("`@?0H@("`@("`@
M(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!
M0DE,25197TY53$Q?5$]?14U05%DI('L*("`@("`@("`@("`@)'1H:7,M/E]C
M;VYV97)T3G5L;$%R<F%Y5F%L=65S5&]%;7!T>2@D87)R*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&9R965297-U;'0H*0H*("`@("\J*@H@("`@("H@1&5L971E<R!T
M:&4@<F5S=6QT('-E="!A;F0@9G)E97,@=&AE(&UE;6]R>2!O8V-U<&EE9"!B
M>2!T:&4@<F5S=6QT('-E=`H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES
M(&YO="!M96%N="!T;R!B92!C86QL960@9&ER96-T;'DN("!5<V4*("`@("`J
M($1"7W)E<W5L=#HZ9G)E92@I(&EN<W1E860N("!)="!C86XG="!B92!D96-L
M87)E9"`B<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@
M82!S97!A<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U
M<F-E("1R97-U;'0@(%!(4"=S('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;"`@5%)512!O;B!S=6-C97-S+"!&04Q3
M12!I9B`D<F5S=6QT(&ES(&EN=F%L:60*("`@("`J"B`@("`@*B!`<V5E($1"
M7W)E<W5L=#HZ9G)E92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&9R965297-U
M;'0H)')E<W5L="D*("`@('L*("`@("`@("!R971U<FX@0&9B<W%L7V9R965?
M<F5S=6QT*"1R97-U;'0I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&%U=&]#;VUM:70H*0H*("`@("\J*@H@("`@("H@16YA8FQE<R!O<B!D:7-A
M8FQE<R!A=71O;6%T:6,@8V]M;6ET<PH@("`@("H*("`@("`J($!P87)A;2!B
M;V]L("1O;F]F9B`@=')U92!T=7)N<R!I="!O;BP@9F%L<V4@='5R;G,@:70@
M;V9F"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E
M<W,N("!!($1"7T5R<F]R(&]B:F5C="!I9B!T:&4@9')I=F5R"B`@("`@*B`@
M("`@("`@("`@("`@(&1O97-N)W0@<W5P<&]R="!A=71O+6-O;6UI='1I;F<@
M=')A;G-A8W1I;VYS+@H@("`@("HO"B`@("!F=6YC=&EO;B!A=71O0V]M;6ET
M*"1O;F]F9CUF86QS92D*("`@('L*("`@("`@("!I9B`H)&]N;V9F*2!["B`@
M("`@("`@("`@("1T:&ES+3YQ=65R>2@B4T54($-/34U)5"!44E5%(BD["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/G%U97)Y*")3150@
M0T]-34E4($9!3%-%(BD["B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[(&-O;6UI="@I"@H@("`@+RHJ"B`@("`@*B!#;VUM:71S('1H
M92!C=7)R96YT('1R86YS86-T:6]N"B`@("`@*@H@("`@("H@0')E='5R;B!I
M;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VUM:70H*0H@("`@>PH@
M("`@("`@($!F8G-Q;%]C;VUM:70H*3L*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!R;VQL8F%C:R@I"@H@("`@+RHJ"B`@("`@*B!2979E<G1S('1H
M92!C=7)R96YT('1R86YS86-T:6]N"B`@("`@*@H@("`@("H@0')E='5R;B!I
M;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R;VQL8F%C:R@I"B`@("![
M"B`@("`@("`@0&9B<W%L7W)O;&QB86-K*"D["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@;G5M0V]L<R@I"@H@("`@+RHJ"B`@("`@*B!'971S('1H
M92!N=6UB97(@;V8@8V]L=6UN<R!I;B!A(')E<W5L="!S970*("`@("`J"B`@
M("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I
M<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z.FYU;4-O;',H*2!I;G-T
M96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*("`@("`J
M(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@("`@
M("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT("!02%`G<R!Q=65R
M>2!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@
M=&AE(&YU;6)E<B!O9B!C;VQU;6YS+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@
M9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ;G5M0V]L
M<R@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&YU;4-O;',H)')E<W5L="D*("`@
M('L*("`@("`@("`D8V]L<R`]($!F8G-Q;%]N=6U?9FEE;&1S*"1R97-U;'0I
M.PH@("`@("`@(&EF("@A)&-O;',I('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YF8G-Q;%)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N("1C;VQS.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YU;5)O
M=W,H*0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@;G5M8F5R(&]F(')O=W,@
M:6X@82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@:7,@
M;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@("H@
M1$)?<F5S=6QT.CIN=6U2;W=S*"D@:6YS=&5A9"X@($ET(&-A;B=T(&)E(&1E
M8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E($1"7W)E<W5L="!I
M<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<F5S
M;W5R8V4@)')E<W5L="`@4$A0)W,@<75E<GD@<F5S=6QT(')E<V]U<F-E"B`@
M("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB97(@;V8@<F]W<RX@
M($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@
M0'-E92!$0E]R97-U;'0Z.FYU;5)O=W,H*0H@("`@("HO"B`@("!F=6YC=&EO
M;B!N=6U2;W=S*"1R97-U;'0I"B`@("!["B`@("`@("`@)')O=W,@/2!`9F)S
M<6Q?;G5M7W)O=W,H)')E<W5L="D["B`@("`@("`@:68@*"1R;W=S(#T]/2!N
M=6QL*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9F)S<6Q286ES945R
M<F]R*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F]W<SL*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!A9F9E8W1E9%)O=W,H*0H*("`@("\J
M*@H@("`@("H@1&5T97)M:6YE<R!T:&4@;G5M8F5R(&]F(')O=W,@869F96-T
M960@8GD@82!D871A(&UA;FEU<&QA=&EO;B!Q=65R>0H@("`@("H*("`@("`J
M(#`@:7,@<F5T=7)N960@9F]R('%U97)I97,@=&AA="!D;VXG="!M86YI<'5L
M871E(&1A=&$N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB
M97(@;V8@<F]W<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&%F9F5C=&5D4F]W<R@I"B`@("!["B`@("`@
M("`@:68@*$1".CII<TUA;FEP*"1T:&ES+3YL87-T7W%U97)Y*2D@>PH@("`@
M("`@("`@("`D<F5S=6QT(#T@0&9B<W%L7V%F9F5C=&5D7W)O=W,H)'1H:7,M
M/F-O;FYE8W1I;VXI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R
M97-U;'0@/2`P.PH@("`@("`@('T*("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;F5X=$ED*"D*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE(&YE>'0@9G)E92!I9"!I;B!A('-E<75E
M;F-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'-E<5]N86UE("!N
M86UE(&]F('1H92!S97%U96YC90H@("`@("H@0'!A<F%M(&)O;VQE86X@)&]N
M9&5M86YD("!W:&5N('1R=64L('1H92!S97%E;F-E(&ES(&%U=&]M871I8V%L
M;'D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-R96%T960@
M:68@:70@9&]E<R!N;W0@97AI<W0*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN
M="`@=&AE(&YE>'0@:60@;G5M8F5R(&EN('1H92!S97%U96YC92X*("`@("`J
M("`@("`@("`@("`@("`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*
M("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ;F5X=$E$*"DL($1"7V-O
M;6UO;CHZ9V5T4V5Q=65N8V5.86UE*"DL"B`@("`@*B`@("`@($1"7V9B<W%L
M.CIC<F5A=&5397%U96YC92@I+"!$0E]F8G-Q;#HZ9')O<%-E<75E;F-E*"D*
M("`@("`J+PH@("`@9G5N8W1I;VX@;F5X=$ED*"1S97%?;F%M92P@)&]N9&5M
M86YD(#T@=')U92D*("`@('L*("`@("`@("`D<V5Q;F%M92`]("1T:&ES+3YG
M971397%U96YC94YA;64H)'-E<5]N86UE*3L*("`@("`@("!D;R!["B`@("`@
M("`@("`@("1R97!E870@/2`P.PH@("`@("`@("`@("`D=&AI<RT^<'5S:$5R
M<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PH@("`@("`@("`@("`D
M<F5S=6QT(#T@)'1H:7,M/G%U97)Y*"=314Q%0U0@54Y)455%($923TT@)R`N
M("1S97%N86UE*3L*("`@("`@("`@("`@)'1H:7,M/G!O<$5R<F]R2&%N9&QI
M;F<H*3L*("`@("`@("`@("`@:68@*"1O;F1E;6%N9"`F)B!$0CHZ:7-%<G)O
M<B@D<F5S=6QT*2`F)@H@("`@("`@("`@("`@("`@)')E<W5L="T^9V5T0V]D
M92@I(#T]($1"7T524D]27TY/4U5#2%1!0DQ%*2!["B`@("`@("`@("`@("`@
M("`D<F5P96%T(#T@,3L*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI
M<RT^8W)E871E4V5Q=65N8V4H)'-E<5]N86UE*3L*("`@("`@("`@("`@("`@
M(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)')E<&5A="`](#`["B`@
M("`@("`@("`@('T*("`@("`@("!]('=H:6QE("@D<F5P96%T*3L*("`@("`@
M("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YF8G-Q;%)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@
M("`@)')E<W5L="T^9F5T8VA);G1O*"1T;7`L($1"7T9%5$-(34]$15]/4D1%
M4D5$*3L*("`@("`@("!R971U<FX@)'1M<%LP73L*("`@('T*"B`@("`O*BH*
M("`@("`J($-R96%T97,@82!N97<@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1S97%?;F%M92`@;F%M92!O9B!T:&4@;F5W('-E<75E
M;F-E"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E
M<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@
M("`J($!S964@1$)?8V]M;6]N.CIC<F5A=&5397%U96YC92@I+"!$0E]C;VUM
M;VXZ.F=E=%-E<75E;F-E3F%M92@I+`H@("`@("H@("`@("!$0E]F8G-Q;#HZ
M;F5X=$E$*"DL($1"7V9B<W%L.CID<F]P4V5Q=65N8V4H*0H@("`@("HO"B`@
M("!F=6YC=&EO;B!C<F5A=&5397%U96YC92@D<V5Q7VYA;64I"B`@("!["B`@
M("`@("`@)'-E<6YA;64@/2`D=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S97%?
M;F%M92D["B`@("`@("`@)')E<R`]("1T:&ES+3YQ=65R>2@G0U)%051%(%1!
M0DQ%("<@+B`D<V5Q;F%M90H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+B`G("AI9"!)3E1%1T52($Y/5"!.54Q,+"<*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("X@)R!04DE-05)9($M%62AI9"DI)RD["B`@("`@("`@:68@
M*"1R97,I('L*("`@("`@("`@("`@)')E<R`]("1T:&ES+3YQ=65R>2@G4T54
M(%5.25%512`](#`@1D]2("<@+B`D<V5Q;F%M92D["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D<F5S.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&1R;W!397%U96YC92@I"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&$@<V5Q
M=65N8V4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S97%?;F%M92`@
M;F%M92!O9B!T:&4@<V5Q=65N8V4@=&\@8F4@9&5L971E9`H@("`@("H*("`@
M("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O
M;6UO;CHZ9')O<%-E<75E;F-E*"DL($1"7V-O;6UO;CHZ9V5T4V5Q=65N8V5.
M86UE*"DL"B`@("`@*B`@("`@($1"7V9B<W%L.CIN97AT240H*2P@1$)?9F)S
M<6PZ.F-R96%T95-E<75E;F-E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9')O
M<%-E<75E;F-E*"1S97%?;F%M92D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/G%U97)Y*"=$4D]0(%1!0DQ%("<@+B`D=&AI<RT^9V5T4V5Q=65N8V5.
M86UE*"1S97%?;F%M92D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@
M)R!215-44DE#5"<I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&UO
M9&EF>4QI;6ET475E<GDH*0H*("`@("\J*@H@("`@("H@061D<R!,24U)5"!C
M;&%U<V5S('1O(&$@<75E<GD@<W1R:6YG(&%C8V]R9&EN9R!T;R!C=7)R96YT
M($1"35,@<W1A;F1A<F1S"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<75E<GD@("!T:&4@<75E<GD@=&\@;6]D:69Y"B`@("`@*B!`<&%R86T@:6YT
M("`@("1F<F]M("`@('1H92!R;W<@=&\@<W1A<G0@=&\@9F5T8VAI;F<@*#`@
M/2!T:&4@9FER<W0@<F]W*0H@("`@("H@0'!A<F%M(&EN="`@("`D8V]U;G0@
M("!T:&4@;G5M8F5R<R!O9B!R;W=S('1O(&9E=&-H"B`@("`@*B!`<&%R86T@
M;6EX960@("1P87)A;7,@(&%R<F%Y+"!S=')I;F<@;W(@;G5M97)I8R!D871A
M('1O(&)E('5S960@:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M(&5X96-U=&EO;B!O9B!T:&4@<W1A=&5M96YT+B`@475A;G1I='D@;V8@:71E
M;7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('!A<W-E9"!M=7-T
M(&UA=&-H('%U86YT:71Y(&]F('!L86-E:&]L9&5R<R!I;@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@<75E<GDZ("!M96%N:6YG(#$@<&QA8V5H
M;VQD97(@9F]R(&YO;BUA<G)A>0H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@<&%R86UE=&5R<R!O<B`Q('!L86-E:&]L9&5R('!E<B!A<G)A>2!E
M;&5M96YT+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@<75E
M<GD@<W1R:6YG('=I=&@@3$E-250@8VQA=7-E<R!A9&1E9`H@("`@("H*("`@
M("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B\*("`@(&9U;F-T:6]N(&UO
M9&EF>4QI;6ET475E<GDH)'%U97)Y+"`D9G)O;2P@)&-O=6YT+"`D<&%R86US
M(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H1$(Z.FES36%N:7`H)'%U
M97)Y*2D@>PH@("`@("`@("`@("!R971U<FX@<')E9U]R97!L86-E*"<O7BA;
M7',H72DJ4T5,14-4+VDG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(")<7#%314Q%0U0@5$]0*"1C;W5N="DB+"`D<75E<GDI.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!P<F5G7W)E<&QA8V4H)R\H
M6UQS*%TI*E-%3$5#5"]I)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`B7%PQ4T5,14-4(%1/4"@D9G)O;2P@)&-O=6YT*2(L("1Q=65R>2D[
M"B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('%U;W1E
M4VUA<G0H*0H*("`@("\J*@H@("`@("H@1F]R;6%T<R!I;G!U="!S;R!I="!C
M86X@8F4@<V%F96QY('5S960@:6X@82!Q=65R>0H@("`@("H*("`@("`J($!P
M87)A;2!M:7AE9"`D:6X@('1H92!D871A('1O(&)E(&9O<FUA='1E9`H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@('1H92!F;W)M871T960@9&%T82X@
M(%1H92!F;W)M870@9&5P96YD<R!O;B!T:&4@:6YP=70G<PH@("`@("H@("`@
M("`@("`@("`@("`@(%!(4"!T>7!E.@H@("`@("H@("`@("`@("`@("`@("`@
M("L@;G5L;"`]('1H92!S=')I;F<@/'-A;7`^3E5,3#PO<V%M<#X*("`@("`J
M("`@("`@("`@("`@("`@("`K(&)O;VQE86X@/2!S=')I;F<@/'-A;7`^5%)5
M13PO<V%M<#X@;W(@/'-A;7`^1D%,4T4\+W-A;7`^"B`@("`@*B`@("`@("`@
M("`@("`@("`@*R!I;G1E9V5R(&]R(&1O=6)L92`]('1H92!U;G%U;W1E9"!N
M=6UB97(*("`@("`J("`@("`@("`@("`@("`@("`K(&]T:&5R("AI;F-L=61I
M;F<@<W1R:6YG<R!A;F0@;G5M97)I8R!S=')I;F=S*2`]"B`@("`@*B`@("`@
M("`@("`@("`@("`@("!T:&4@9&%T82!E<V-A<&5D(&%C8V]R9&EN9R!T;R!&
M<F]N=$)A<V4G<R!S971T:6YG<PH@("`@("H@("`@("`@("`@("`@("`@("`@
M=&AE;B!E;F-A<'-U;&%T960@8F5T=V5E;B!S:6YG;&4@<75O=&5S"B`@("`@
M*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G%U;W1E4VUA<G0H*0H@("`@("H@
M0'-I;F-E($UE=&AO9"!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C8N,`H@
M("`@("HO"B`@("!F=6YC=&EO;B!Q=6]T95-M87)T*"1I;BD*("`@('L*("`@
M("`@("!I9B`H:7-?:6YT*"1I;BD@?'P@:7-?9&]U8FQE*"1I;BDI('L*("`@
M("`@("`@("`@<F5T=7)N("1I;CL*("`@("`@("!](&5L<V5I9B`H:7-?8F]O
M;"@D:6XI*2!["B`@("`@("`@("`@(')E='5R;B`D:6X@/R`G5%)512<@.B`G
M1D%,4T4G.PH@("`@("`@('T@96QS96EF("AI<U]N=6QL*"1I;BDI('L*("`@
M("`@("`@("`@<F5T=7)N("=.54Q,)SL*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!R971U<FX@(B<B("X@)'1H:7,M/F5S8V%P95-I;7!L92@D:6XI
M("X@(B<B.PH@("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!F8G-Q;%)A:7-E17)R;W(H*0H*("`@("\J*@H@("`@("H@4')O9'5C97,@
M82!$0E]%<G)O<B!O8FIE8W0@<F5G87)D:6YG('1H92!C=7)R96YT('!R;V)L
M96T*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("1E<G)N;R`@:68@=&AE(&5R
M<F]R(&ES(&)E:6YG(&UA;G5A;&QY(')A:7-E9"!P87-S(&$*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@1$)?15)23U(J(&-O;G-T86YT(&AE<F4N("!)
M9B!T:&ES(&ES;B=T('!A<W-E9`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("!T:&4@97)R;W(@:6YF;W)M871I;VX@9V%T:&5R960@9G)O;2!T:&4@1$)-
M4RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@=&AE($1"7T5R<F]R
M(&]B:F5C=`H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIR86ES945R
M<F]R*"DL"B`@("`@*B`@("`@($1"7V9B<W%L.CIE<G)O<DYA=&EV92@I+"!$
M0E]C;VUM;VXZ.F5R<F]R0V]D92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&9B
M<W%L4F%I<V5%<G)O<B@D97)R;F\@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF
M("@D97)R;F\@/3T](&YU;&PI('L*("`@("`@("`@("`@)&5R<FYO(#T@)'1H
M:7,M/F5R<F]R0V]D92AF8G-Q;%]E<G)N;R@D=&AI<RT^8V]N;F5C=&EO;BDI
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M)&5R<FYO+"!N=6QL+"!N=6QL+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!`9F)S<6Q?97)R;W(H)'1H:7,M/F-O;FYE8W1I;VXI
M*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!E<G)O<DYA=&EV92@I
M"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!$0DU3)R!N871I=F4@97)R;W(@
M8V]D92!P<F]D=6-E9"!B>2!T:&4@;&%S="!Q=65R>0H@("`@("H*("`@("`J
M($!R971U<FX@:6YT("!T:&4@1$)-4R<@97)R;W(@8V]D90H@("`@("HO"B`@
M("!F=6YC=&EO;B!E<G)O<DYA=&EV92@I"B`@("!["B`@("`@("`@<F5T=7)N
M($!F8G-Q;%]E<G)N;R@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@=&%B;&5);F9O*"D*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@:6YF;W)M871I;VX@86)O=70@82!T86)L92!O<B!A(')E<W5L
M="!S970*("`@("`J"B`@("`@*B!`<&%R86T@;V)J96-T?'-T<FEN9R`@)')E
M<W5L="`@1$)?<F5S=6QT(&]B:F5C="!F<F]M(&$@<75E<GD@;W(@80H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S=')I;F<@8V]N
M=&%I;FEN9R!T:&4@;F%M92!O9B!A('1A8FQE+@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!7:&EL92!T:&ES(&%L<V\@86-C97!T
M<R!A('%U97)Y(')E<W5L=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!R97-O=7)C92!I9&5N=&EF:65R+"!T:&ES(&)E:&%V:6]R
M(&ES"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&1E
M<')E8V%T960N"B`@("`@*B!`<&%R86T@:6YT("`@("`@("`@("`@)&UO9&4@
M("`@82!V86QI9"!T86)L94EN9F\@;6]D90H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@(&%N(&%S<V]C:6%T:79E(&%R<F%Y('=I=&@@=&AE(&EN9F]R
M;6%T:6]N(')E<75E<W1E9"X*("`@("`J("`@("`@("`@("`@("`@("!!($1"
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@
M1$)?8V]M;6]N.CIT86)L94EN9F\H*0H@("`@("HO"B`@("!F=6YC=&EO;B!T
M86)L94EN9F\H)')E<W5L="P@)&UO9&4@/2!N=6QL*0H@("`@>PH@("`@("`@
M(&EF("AI<U]S=')I;F<H)')E<W5L="DI('L*("`@("`@("`@("`@+RH*("`@
M("`@("`@("`@("H@4')O8F%B;'D@<F5C96EV960@82!T86)L92!N86UE+@H@
M("`@("`@("`@("`@*B!#<F5A=&4@82!R97-U;'0@<F5S;W5R8V4@:61E;G1I
M9FEE<BX*("`@("`@("`@("`@("HO"B`@("`@("`@("`@("1I9"`]($!F8G-Q
M;%]L:7-T7V9I96QD<R@D=&AI<RT^9'-N6R=D871A8F%S92==+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E<W5L="P@)'1H:7,M
M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@("`D9V]T7W-T<FEN9R`]('1R=64[
M"B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1R97-U;'0M/G)E<W5L="DI('L*
M("`@("`@("`@("`@+RH*("`@("`@("`@("`@("H@4')O8F%B;'D@<F5C96EV
M960@82!R97-U;'0@;V)J96-T+@H@("`@("`@("`@("`@*B!%>'1R86-T('1H
M92!R97-U;'0@<F5S;W5R8V4@:61E;G1I9FEE<BX*("`@("`@("`@("`@("HO
M"B`@("`@("`@("`@("1I9"`]("1R97-U;'0M/G)E<W5L=#L*("`@("`@("`@
M("`@)&=O=%]S=')I;F<@/2!F86QS93L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`O*@H@("`@("`@("`@("`@*B!0<F]B86)L>2!R96-E:79E9"!A
M(')E<W5L="!R97-O=7)C92!I9&5N=&EF:65R+@H@("`@("`@("`@("`@*B!#
M;W!Y(&ET+@H@("`@("`@("`@("`@*B!$97!R96-A=&5D+B`@2&5R92!F;W(@
M8V]M<&%T:6)I;&ET>2!O;FQY+@H@("`@("`@("`@("`@*B\*("`@("`@("`@
M("`@)&ED(#T@)')E<W5L=#L*("`@("`@("`@("`@)&=O=%]S=')I;F<@/2!F
M86QS93L*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-?<F5S;W5R8V4H)&ED
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F9B<W%L4F%I<V5%<G)O
M<BA$0E]%4E)/4E].145$7TU/4D5?1$%402D["B`@("`@("`@?0H*("`@("`@
M("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)4
M04))3$E465],3U=%4D-!4T4I('L*("`@("`@("`@("`@)&-A<V5?9G5N8R`]
M("=S=')T;VQO=V5R)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M8V%S95]F=6YC(#T@)W-T<G9A;"<["B`@("`@("`@?0H*("`@("`@("`D8V]U
M;G0@/2!`9F)S<6Q?;G5M7V9I96QD<R@D:60I.PH@("`@("`@("1R97,@("`]
M(&%R<F%Y*"D["@H@("`@("`@(&EF("@D;6]D92D@>PH@("`@("`@("`@("`D
M<F5S6R=N=6U?9FEE;&1S)UT@/2`D8V]U;G0["B`@("`@("`@?0H*("`@("`@
M("!F;W(@*"1I(#T@,#L@)&D@/"`D8V]U;G0[("1I*RLI('L*("`@("`@("`@
M("`@)')E<ULD:5T@/2!A<G)A>2@*("`@("`@("`@("`@("`@("=T86)L92<@
M/3X@)&-A<V5?9G5N8RA`9F)S<6Q?9FEE;&1?=&%B;&4H)&ED+"`D:2DI+`H@
M("`@("`@("`@("`@("`@)VYA;64G("`]/B`D8V%S95]F=6YC*$!F8G-Q;%]F
M:65L9%]N86UE*"1I9"P@)&DI*2P*("`@("`@("`@("`@("`@("=T>7!E)R`@
M/3X@0&9B<W%L7V9I96QD7W1Y<&4H)&ED+"`D:2DL"B`@("`@("`@("`@("`@
M("`G;&5N)R`@(#T^($!F8G-Q;%]F:65L9%]L96XH)&ED+"`D:2DL"B`@("`@
M("`@("`@("`@("`G9FQA9W,G(#T^($!F8G-Q;%]F:65L9%]F;&%G<R@D:60L
M("1I*2P*("`@("`@("`@("`@*3L*("`@("`@("`@("`@:68@*"1M;V1E("8@
M1$)?5$%"3$5)3D9/7T]21$52*2!["B`@("`@("`@("`@("`@("`D<F5S6R=O
M<F1E<B==6R1R97-;)&E=6R=N86UE)UU=(#T@)&D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@:68@*"1M;V1E("8@1$)?5$%"3$5)3D9/7T]21$525$%"
M3$4I('L*("`@("`@("`@("`@("`@("1R97-;)V]R9&5R=&%B;&4G75LD<F5S
M6R1I75LG=&%B;&4G75U;)')E<ULD:5U;)VYA;64G75T@/2`D:3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@9G)E92!T:&4@<F5S=6QT
M(&]N;'D@:68@=V4@=V5R92!C86QL960@;VX@82!T86)L90H@("`@("`@(&EF
M("@D9V]T7W-T<FEN9RD@>PH@("`@("`@("`@("!`9F)S<6Q?9G)E95]R97-U
M;'0H)&ED*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R97,["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9V5T4W!E8VEA;%%U97)Y*"D*"B`@
M("`O*BH*("`@("`J($]B=&%I;G,@=&AE('%U97)Y('-T<FEN9R!N965D960@
M9F]R(&QI<W1I;F<@82!G:79E;B!T>7!E(&]F(&]B:F5C=',*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1T>7!E("!T:&4@:VEN9"!O9B!O8FIE8W1S
M('EO=2!W86YT('1O(')E=')I979E"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@('1H92!344P@<75E<GD@<W1R:6YG(&]R(&YU;&P@:68@=&AE(&1R
M:79E<B!D;V5S;B=T"B`@("`@*B`@("`@("`@("`@("`@("`@('-U<'!O<G0@
M=&AE(&]B:F5C="!T>7!E(')E<75E<W1E9`H@("`@("H*("`@("`J($!A8V-E
M<W,@<')O=&5C=&5D"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ9V5T3&ES=$]F
M*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4W!E8VEA;%%U97)Y*"1T>7!E
M*0H@("`@>PH@("`@("`@('-W:71C:"`H)'1Y<&4I('L*("`@("`@("`@("`@
M8V%S92`G=&%B;&5S)SH*("`@("`@("`@("`@("`@(')E='5R;B`G4T5,14-4
M(")T86)L95]N86UE(B!&4D]-(&EN9F]R;6%T:6]N7W-C:&5M82YT86)L97,G
M"B`@("`@("`@("`@("`@("`@("`@("`@+B`G('0P+"!I;F9O<FUA=&EO;E]S
M8VAE;6$N<V-H96UA=&$@=#$G"B`@("`@("`@("`@("`@("`@("`@("`@+B`G
M(%=(15)%('0P+G-C:&5M85]P:SUT,2YS8VAE;6%?<&L@04Y$)PH@("`@("`@
M("`@("`@("`@("`@("`@("X@)R`B=&%B;&5?='EP92(@/2!<)T)!4T4@5$%"
M3$5<)R<*("`@("`@("`@("`@("`@("`@("`@("`N("<@04Y$(")S8VAE;6%?
M;F%M92(@/2!C=7)R96YT7W-C:&5M82<["B`@("`@("`@("`@(&-A<V4@)W9I
M97=S)SH*("`@("`@("`@("`@("`@(')E='5R;B`G4T5,14-4(")T86)L95]N
M86UE(B!&4D]-(&EN9F]R;6%T:6]N7W-C:&5M82YT86)L97,G"B`@("`@("`@
M("`@("`@("`@("`@("`@+B`G('0P+"!I;F9O<FUA=&EO;E]S8VAE;6$N<V-H
M96UA=&$@=#$G"B`@("`@("`@("`@("`@("`@("`@("`@+B`G(%=(15)%('0P
M+G-C:&5M85]P:SUT,2YS8VAE;6%?<&L@04Y$)PH@("`@("`@("`@("`@("`@
M("`@("`@("X@)R`B=&%B;&5?='EP92(@/2!<)U9)15=<)R<*("`@("`@("`@
M("`@("`@("`@("`@("`N("<@04Y$(")S8VAE;6%?;F%M92(@/2!C=7)R96YT
M7W-C:&5M82<["B`@("`@("`@("`@(&-A<V4@)W5S97)S)SH*("`@("`@("`@
M("`@("`@(')E='5R;B`G4T5,14-4(")U<V5R7VYA;64B(&9R;VT@:6YF;W)M
M871I;VY?<V-H96UA+G5S97)S)SL@"B`@("`@("`@("`@(&-A<V4@)V9U;F-T
M:6]N<R<Z"B`@("`@("`@("`@("`@("!R971U<FX@)U-%3$5#5"`B<F]U=&EN
M95]N86UE(B!&4D]-)PH@("`@("`@("`@("`@("`@("`@("`@("X@)R!I;F9O
M<FUA=&EO;E]S8VAE;6$N<'-M7W)O=71I;F5S)PH@("`@("`@("`@("`@("`@
M("`@("`@("X@)R!T,"P@:6YF;W)M871I;VY?<V-H96UA+G-C:&5M871A('0Q
M)PH@("`@("`@("`@("`@("`@("`@("`@("X@)R!72$5212!T,"YS8VAE;6%?
M<&L]=#$N<V-H96UA7W!K)PH@("`@("`@("`@("`@("`@("`@("`@("X@)R!!
M3D0@(G)O=71I;F5?:VEN9"(]7"=&54Y#5$E/3EPG)PH@("`@("`@("`@("`@
M("`@("`@("`@("X@)R!!3D0@(G-C:&5M85]N86UE(B`](&-U<G)E;G1?<V-H
M96UA)SL*("`@("`@("`@("`@8V%S92`G<')O8V5D=7)E<R<Z"B`@("`@("`@
M("`@("`@("!R971U<FX@)U-%3$5#5"`B<F]U=&EN95]N86UE(B!&4D]-)PH@
M("`@("`@("`@("`@("`@("`@("`@("X@)R!I;F9O<FUA=&EO;E]S8VAE;6$N
M<'-M7W)O=71I;F5S)PH@("`@("`@("`@("`@("`@("`@("`@("X@)R!T,"P@
M:6YF;W)M871I;VY?<V-H96UA+G-C:&5M871A('0Q)PH@("`@("`@("`@("`@
M("`@("`@("`@("X@)R!72$5212!T,"YS8VAE;6%?<&L]=#$N<V-H96UA7W!K
M)PH@("`@("`@("`@("`@("`@("`@("`@("X@)R!!3D0@(G)O=71I;F5?:VEN
M9"(]7"=04D]#14154D5<)R<*("`@("`@("`@("`@("`@("`@("`@("`N("<@
M04Y$(")S8VAE;6%?;F%M92(@/2!C=7)R96YT7W-C:&5M82<["B`@("`@("`@
M("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@
M("`@("!]"B`@("!]"@H@("`@+R\@?7U]"GT*"B\J"B`J($QO8V%L('9A<FEA
M8FQE<SH*("H@=&%B+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J
M($5N9#H*("HO"@H_/@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]$0B]I8F%S92YP:'``````````````````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,3`Q-30P(#$P-3$U-#,S-S,Q(#`R,#4T-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`H*+RH@
M=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F
M='1A8G-T;W`]-#H@*B\*"B\J*@H@*B!4:&4@4$5!4B!$0B!D<FEV97(@9F]R
M(%!(4"=S(&EN=&5R8F%S92!E>'1E;G-I;VX*("H@9F]R(&EN=&5R86-T:6YG
M('=I=&@@26YT97)B87-E(&%N9"!&:7)E8FER9"!D871A8F%S97,*("H*("H@
M5VAI;&4@=&AI<R!C;&%S<R!W;W)K<R!W:71H(%!(4"`T+"!02%`G<R!);G1E
M<D)A<V4@97AT96YS:6]N(&ES"B`J('5N<W1A8FQE(&EN(%!(4"`T+B`@57-E
M(%!(4"`U+@H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%
M3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S
M+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55))
M.@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@
M>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E
M;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W
M96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@
M<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@
M0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U
M=&AO<B`@("`@4W1E<FQI;F<@2'5G:&5S(#QS=&5R;&EN9T!P:'`N;F5T/@H@
M*B!`875T:&]R("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN
M970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J
M($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT
M>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@
M:6)A<V4N<&AP+'8@,2XQ,#D@,C`P-2\P,R\P-"`R,SHQ,CHS-B!D86YI96QC
M($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]$0@H@*B\*"B\J*@H@*B!/8G1A:6X@=&AE($1"7V-O;6UO;B!C;&%S
M<R!S;R!I="!C86X@8F4@97AT96YD960@9G)O;0H@*B\*<F5Q=6ER95]O;F-E
M("=$0B]C;VUM;VXN<&AP)SL*"B\J*@H@*B!4:&4@;65T:&]D<R!014%2($1"
M('5S97,@=&\@:6YT97)A8W0@=VET:"!02%`G<R!I;G1E<F)A<V4@97AT96YS
M:6]N"B`J(&9O<B!I;G1E<F%C=&EN9R!W:71H($EN=&5R8F%S92!A;F0@1FER
M96)I<F0@9&%T86)A<V5S"B`J"B`J(%1H97-E(&UE=&AO9',@;W9E<FQO860@
M=&AE(&]N97,@9&5C;&%R960@:6X@1$)?8V]M;6]N+@H@*@H@*B!7:&EL92!T
M:&ES(&-L87-S('=O<FMS('=I=&@@4$A0(#0L(%!(4"=S($EN=&5R0F%S92!E
M>'1E;G-I;VX@:7,*("H@=6YS=&%B;&4@:6X@4$A0(#0N("!5<V4@4$A0(#4N
M"B`J"B`J($Y/5$E#13H@(&QI;6ET475E<GDH*2!O;FQY('=O<FMS(&9O<B!&
M:7)E8FER9"X*("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA
M9V4@("`@1$(*("H@0&%U=&AO<B`@("`@4W1E<FQI;F<@2'5G:&5S(#QS=&5R
M;&EN9T!P:'`N;F5T/@H@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES<V]R
M(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4
M:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R<VEO
M;B`@("!296QE87-E.B`Q+C<N-@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A
M<BYP:'`N;F5T+W!A8VMA9V4O1$(*("H@0'-I;F-E("`@("`@0VQA<W,@8F5C
M86UE('-T86)L92!I;B!296QE87-E(#$N-RXP"B`J+PIC;&%S<R!$0E]I8F%S
M92!E>'1E;F1S($1"7V-O;6UO;@I["B`@("`O+R![>WL@<')O<&5R=&EE<PH*
M("`@("\J*@H@("`@("H@5&AE($1"(&1R:79E<B!T>7!E("AM>7-Q;"P@;V-I
M."P@;V1B8RP@971C+BD*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@
M('9A<B`D<&AP='EP92`]("=I8F%S92<["@H@("`@+RHJ"B`@("`@*B!4:&4@
M9&%T86)A<V4@<WEN=&%X('9A<FEA;G0@=&\@8F4@=7-E9"`H9&(R+"!A8V-E
M<W,L(&5T8RXI+"!I9B!A;GD*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*
M("`@('9A<B`D9&)S>6YT87@@/2`G:6)A<V4G.PH*("`@("\J*@H@("`@("H@
M5&AE(&-A<&%B:6QI=&EE<R!O9B!T:&ES($1"(&EM<&QE;65N=&%T:6]N"B`@
M("`@*@H@("`@("H@5&AE("=N97=?;&EN:R<@96QE;65N="!C;VYT86EN<R!T
M:&4@4$A0('9E<G-I;VX@=&AA="!F:7)S="!P<F]V:61E9`H@("`@("H@;F5W
M7VQI;FL@<W5P<&]R="!F;W(@=&AI<R!$0DU3+B`@0V]N=&%I;G,@9F%L<V4@
M:68@:70G<R!U;G-U<'!O<G1E9"X*("`@("`J"B`@("`@*B!-96%N:6YG(&]F
M('1H92`G;&EM:70G(&5L96UE;G0Z"B`@("`@*B`@("L@)V5M=6QA=&4G(#T@
M96UU;&%T92!W:71H(&9E=&-H(')O=R!B>2!N=6UB97(*("`@("`J("`@*R`G
M86QT97(G("`@/2!A;'1E<B!T:&4@<75E<GD*("`@("`J("`@*R!F86QS92`@
M("`@/2!S:VEP(')O=W,*("`@("`J"B`@("`@*B!.3U1%.B!O;FQY(&9I<F5B
M:7)D('-U<'!O<G1S(&QI;6ET+@H@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1F96%T=7)E<R`](&%R<F%Y*`H@("`@("`@("=L
M:6UI="<@("`@("`@("`]/B!F86QS92P*("`@("`@("`G;F5W7VQI;FLG("`@
M("`@/3X@9F%L<V4L"B`@("`@("`@)VYU;7)O=W,G("`@("`@(#T^("=E;75L
M871E)RP*("`@("`@("`G<&-O;FYE8W0G("`@("`@/3X@=')U92P*("`@("`@
M("`G<')E<&%R92<@("`@("`@/3X@=')U92P*("`@("`@("`G<W-L)R`@("`@
M("`@("`@/3X@9F%L<V4L"B`@("`@("`@)W1R86YS86-T:6]N<R<@(#T^('1R
M=64L"B`@("`I.PH*("`@("\J*@H@("`@("H@02!M87!P:6YG(&]F(&YA=&EV
M92!E<G)O<B!C;V1E<R!T;R!$0B!E<G)O<B!C;V1E<PH@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)&5R<F]R8V]D95]M87`@/2!A<G)A>2@*
M("`@("`@("`M,3`T(#T^($1"7T524D]27U-93E1!6"P*("`@("`@("`M,34P
M(#T^($1"7T524D]27T%#0T534U]624],051)3TXL"B`@("`@("`@+3$U,2`]
M/B!$0E]%4E)/4E]!0T-%4U-?5DE/3$%424].+`H@("`@("`@("TQ-34@/3X@
M1$)?15)23U)?3D]354-(5$%"3$4L"B`@("`@("`@+3$U-R`]/B!$0E]%4E)/
M4E].3U-50TA&245,1"P*("`@("`@("`M,34X(#T^($1"7T524D]27U9!3%5%
M7T-/54Y47T].7U)/5RP*("`@("`@("`M,3<P(#T^($1"7T524D]27TU)4TU!
M5$-(+`H@("`@("`@("TQ-S$@/3X@1$)?15)23U)?34E334%40T@L"B`@("`@
M("`@+3$W,B`]/B!$0E]%4E)/4E])3E9!3$E$+`H@("`@("`@("\O("TR,#0@
M/3X@("\O($-O=F5R<R!T;V\@;6%N>2!E<G)O<G,L(&YE960@=&\@=7-E(')E
M9V5X(&]N(&US9PH@("`@("`@("TR,#4@/3X@1$)?15)23U)?3D]354-(1DE%
M3$0L"B`@("`@("`@+3(P-B`]/B!$0E]%4E)/4E].3U-50TA&245,1"P*("`@
M("`@("`M,C`X(#T^($1"7T524D]27TE.5D%,240L"B`@("`@("`@+3(Q.2`]
M/B!$0E]%4E)/4E].3U-50TA404),12P*("`@("`@("`M,CDW(#T^($1"7T52
M4D]27T-/3E-44D%)3E0L"B`@("`@("`@+3,P,R`]/B!$0E]%4E)/4E])3E9!
M3$E$+`H@("`@("`@("TT,3,@/3X@1$)?15)23U)?24Y604Q)1%].54U"15(L
M"B`@("`@("`@+34S,"`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@("`@
M("TU-3$@/3X@1$)?15)23U)?04-#15-37U9)3TQ!5$E/3BP*("`@("`@("`M
M-34R(#T^($1"7T524D]27T%#0T534U]624],051)3TXL"B`@("`@("`@+R\@
M+38P-R`]/B`@+R\@0V]V97)S('1O;R!M86YY(&5R<F]R<RP@;F5E9"!T;R!U
M<V4@<F5G97@@;VX@;7-G"B`@("`@("`@+38R-2`]/B!$0E]%4E)/4E]#3TY3
M5%)!24Y47TY/5%].54Q,+`H@("`@("`@("TX,#,@/3X@1$)?15)23U)?0T].
M4U1204E.5"P*("`@("`@("`M.#`T(#T^($1"7T524D]27U9!3%5%7T-/54Y4
M7T].7U)/5RP*("`@("`@("`M.3`T(#T^($1"7T524D]27T-/3DY%0U1?1D%)
M3$5$+`H@("`@("`@("TY,C(@/3X@1$)?15)23U)?3D]354-(1$(L"B`@("`@
M("`@+3DR,R`]/B!$0E]%4E)/4E]#3TY.14-47T9!24Q%1"P*("`@("`@("`M
M.3(T(#T^($1"7T524D]27T-/3DY%0U1?1D%)3$5$"B`@("`I.PH*("`@("\J
M*@H@("`@("H@5&AE(')A=R!D871A8F%S92!C;VYN96-T:6]N(&-R96%T960@
M8GD@4$A0"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D
M8V]N;F5C=&EO;CL*"B`@("`O*BH*("`@("`J(%1H92!$4TX@:6YF;W)M871I
M;VX@9F]R(&-O;FYE8W1I;F<@=&\@82!D871A8F%S90H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)&1S;B`](&%R<F%Y*"D["@H*("`@("\J
M*@H@("`@("H@5&AE(&YU;6)E<B!O9B!R;W=S(&%F9F5C=&5D(&)Y(&$@9&%T
M82!M86YI<'5L871I;VX@<75E<GD*("`@("`J($!V87(@:6YT96=E<@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D869F96-T960@
M/2`P.PH*("`@("\J*@H@("`@("H@4VAO=6QD(&1A=&$@;6%N:7!U;&%T:6]N
M('%U97)I97,@8F4@8V]M;6ET=&5D(&%U=&]M871I8V%L;'D_"B`@("`@*B!`
M=F%R(&)O;VP*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V
M87(@)&%U=&]C;VUM:70@/2!T<G5E.PH*("`@("\J*@H@("`@("H@5&AE('!R
M97!A<F5D('-T871E;65N="!H86YD;&4@9G)O;2!T:&4@;6]S="!R96-E;G1L
M>2!E>&5C=71E9"!S=&%T96UE;G0*("`@("`J"B`@("`@*B![0&EN=&5R;F%L
M("!-86EN;'D@:&5R92!B96-A=7-E('1H92!);G1E<D)A<V4O1FER96)I<F0@
M05!)(&ES(&]N;'D*("`@("`J(&%B;&4@=&\@<F5T<FEE=F4@9&%T82!F<F]M
M(')E<W5L="!S971S(&EF('1H92!S=&%T96UN="!H86YD;&4@:7,*("`@("`J
M('-T:6QL(&EN('-C;W!E+GU]"B`@("`@*@H@("`@("H@0'9A<B!R97-O=7)C
M90H@("`@("HO"B`@("!V87(@)&QA<W1?<W1M=#L*"B`@("`O*BH*("`@("`J
M($ES('1H92!G:79E;B!P<F5P87)E9"!S=&%T96UE;G0@82!D871A(&UA;FEP
M=6QA=&EO;B!Q=65R>3\*("`@("`J($!V87(@87)R87D*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)&UA;FEP7W%U97)Y(#T@87)R
M87DH*3L*"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]N<W1R=6-T;W(*"B`@
M("`O*BH*("`@("`J(%1H:7,@8V]N<W1R=6-T;W(@8V%L;',@/&MB9#XD=&AI
M<RT^1$)?8V]M;6]N*"D\+VMB9#X*("`@("`J"B`@("`@*B!`<F5T=7)N('9O
M:60*("`@("`J+PH@("`@9G5N8W1I;VX@1$)?:6)A<V4H*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y$0E]C;VUM;VXH*3L*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!C;VYN96-T*"D*"B`@("`O*BH*("`@("`J($-O;FYE8W0@=&\@
M=&AE(&1A=&%B87-E('-E<G9E<BP@;&]G(&EN(&%N9"!O<&5N('1H92!D871A
M8F%S90H@("`@("H*("`@("`J($1O;B=T(&-A;&P@=&AI<R!M971H;V0@9&ER
M96-T;'DN("!5<V4@1$(Z.F-O;FYE8W0H*2!I;G-T96%D+@H@("`@("H*("`@
M("`J(%!%05(@1$(G<R!I8F%S92!D<FEV97(@<W5P<&]R=',@=&AE(&9O;&QO
M=VEN9R!E>'1R82!$4TX@;W!T:6]N<SH*("`@("`J("`@*R!B=69F97)S("`@
M(%1H92!N=6UB97(@;V8@9&%T86)A<V4@8G5F9F5R<R!T;R!A;&QO8V%T92!F
M;W(@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@<V5R=F5R+7-I9&4@8V%C
M:&4N"B`@("`@*B`@("L@8VAA<G-E="`@("!4:&4@9&5F875L="!C:&%R86-T
M97(@<V5T(&9O<B!A(&1A=&%B87-E+@H@("`@("H@("`K(&1I86QE8W0@("`@
M5&AE(&1E9F%U;'0@4U%,(&1I86QE8W0@9F]R(&%N>2!S=&%T96UE;G0*("`@
M("`J("`@("`@("`@("`@("`@("!E>&5C=71E9"!W:71H:6X@82!C;VYN96-T
M:6]N+B`@1&5F875L=',@=&\@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@
M:&EG:&5S="!O;F4@<W5P<&]R=&5D(&)Y(&-L:65N="!L:6)R87)I97,N"B`@
M("`@*B`@("`@("`@("`@("`@("`@1G5N8W1I;VYA;"!O;FQY('=I=&@@26YT
M97)"87-E(#8@86YD('5P+@H@("`@("H@("`K(')O;&4@("`@("`@1G5N8W1I
M;VYA;"!O;FQY('=I=&@@26YT97)"87-E(#4@86YD('5P+@H@("`@("H*("`@
M("`J($!P87)A;2!A<G)A>2`D9'-N("`@("`@("`@=&AE(&1A=&$@<V]U<F-E
M(&YA;64*("`@("`J($!P87)A;2!B;V]L("`D<&5R<VES=&5N="`@<VAO=6QD
M('1H92!C;VYN96-T:6]N(&)E('!E<G-I<W1E;G0_"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N($$@1$)?17)R;W(@;V)J
M96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;FYE8W0H
M)&1S;BP@)'!E<G-I<W1E;G0@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H
M(5!%05(Z.FQO861%>'1E;G-I;VXH)VEN=&5R8F%S92<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E]%6%1%3E-)
M3TY?3D]47T9/54Y$*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YD<VX@
M/2`D9'-N.PH@("`@("`@(&EF("@D9'-N6R=D8G-Y;G1A>"==*2!["B`@("`@
M("`@("`@("1T:&ES+3YD8G-Y;G1A>"`]("1D<VY;)V1B<WEN=&%X)UT["B`@
M("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^9&)S>6YT87@@/3T@)V9I<F5B
M:7)D)RD@>PH@("`@("`@("`@("`D=&AI<RT^9F5A='5R97-;)VQI;6ET)UT@
M/2`G86QT97(G.PH@("`@("`@('T*"B`@("`@("`@)'!A<F%M<R`](&%R<F%Y
M*`H@("`@("`@("`@("`D9'-N6R=H;W-T<W!E8R=="B`@("`@("`@("`@("`@
M("`@("`@/R`H)&1S;ELG:&]S='-P96,G72`N("<Z)R`N("1D<VY;)V1A=&%B
M87-E)UTI"B`@("`@("`@("`@("`@("`@("`@.B`D9'-N6R=D871A8F%S92==
M+`H@("`@("`@("`@("`D9'-N6R=U<V5R;F%M92==(#\@)&1S;ELG=7-E<FYA
M;64G72`Z(&YU;&PL"B`@("`@("`@("`@("1D<VY;)W!A<W-W;W)D)UT@/R`D
M9'-N6R=P87-S=V]R9"==(#H@;G5L;"P*("`@("`@("`@("`@:7-S970H)&1S
M;ELG8VAA<G-E="==*2`_("1D<VY;)V-H87)S970G72`Z(&YU;&PL"B`@("`@
M("`@("`@(&ES<V5T*"1D<VY;)V)U9F9E<G,G72D@/R`D9'-N6R=B=69F97)S
M)UT@.B!N=6QL+`H@("`@("`@("`@("!I<W-E="@D9'-N6R=D:6%L96-T)UTI
M(#\@)&1S;ELG9&EA;&5C="==(#H@;G5L;"P*("`@("`@("`@("`@:7-S970H
M)&1S;ELG<F]L92==*2`@("`_("1D<VY;)W)O;&4G72`Z(&YU;&PL"B`@("`@
M("`@*3L*"B`@("`@("`@)&-O;FYE8W1?9G5N8W1I;VX@/2`D<&5R<VES=&5N
M="`_("=I8F%S95]P8V]N;F5C="<@.B`G:6)A<V5?8V]N;F5C="<["@H@("`@
M("`@("1T:&ES+3YC;VYN96-T:6]N(#T@0&-A;&Q?=7-E<E]F=6YC7V%R<F%Y
M*"1C;VYN96-T7V9U;F-T:6]N+"`D<&%R86US*3L*("`@("`@("!I9B`H(21T
M:&ES+3YC;VYN96-T:6]N*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M:6)A<V5286ES945R<F]R*$1"7T524D]27T-/3DY%0U1?1D%)3$5$*3L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[(&1I<V-O;FYE8W0H*0H*("`@("\J*@H@("`@("H@1&ES
M8V]N;F5C=',@9G)O;2!T:&4@9&%T86)A<V4@<V5R=F5R"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L("!44E5%(&]N('-U8V-E<W,L($9!3%-%(&]N(&9A
M:6QU<F4*("`@("`J+PH@("`@9G5N8W1I;VX@9&ES8V]N;F5C="@I"B`@("![
M"B`@("`@("`@)')E="`]($!I8F%S95]C;&]S92@D=&AI<RT^8V]N;F5C=&EO
M;BD["B`@("`@("`@)'1H:7,M/F-O;FYE8W1I;VX@/2!N=6QL.PH@("`@("`@
M(')E='5R;B`D<F5T.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('-I
M;7!L95%U97)Y*"D*"B`@("`O*BH*("`@("`J(%-E;F1S(&$@<75E<GD@=&\@
M=&AE(&1A=&%B87-E('-E<G9E<@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@('1H92!344P@<75E<GD@<W1R:6YG"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@*R!A(%!(4"!R97-U;'0@<F5S<F]U8V4@9F]R('-U8V-E<W-F
M=6P@4T5,14-4('%U97)I97,*("`@("`J("`@("`@("`@("`@("`@("L@=&AE
M($1"7T]+(&-O;G-T86YT(&9O<B!O=&AE<B!S=6-C97-S9G5L('%U97)I97,*
M("`@("`J("`@("`@("`@("`@("`@("L@82!$0E]%<G)O<B!O8FIE8W0@;VX@
M9F%I;'5R90H@("`@("HO"B`@("!F=6YC=&EO;B!S:6UP;&51=65R>2@D<75E
M<GDI"B`@("!["B`@("`@("`@)&ES;6%N:7`@/2!$0CHZ:7--86YI<"@D<75E
M<GDI.PH@("`@("`@("1T:&ES+3YL87-T7W%U97)Y(#T@)'%U97)Y.PH@("`@
M("`@("1Q=65R>2`]("1T:&ES+3YM;V1I9GE1=65R>2@D<75E<GDI.PH@("`@
M("`@("1R97-U;'0@/2!`:6)A<V5?<75E<GDH)'1H:7,M/F-O;FYE8W1I;VXL
M("1Q=65R>2D["@H@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/FEB87-E4F%I<V5%<G)O<B@I.PH@("`@("`@('T*
M("`@("`@("!I9B`H)'1H:7,M/F%U=&]C;VUM:70@)B8@)&ES;6%N:7`I('L*
M("`@("`@("`@("`@0&EB87-E7V-O;6UI="@D=&AI<RT^8V]N;F5C=&EO;BD[
M"B`@("`@("`@?0H@("`@("`@(&EF("@D:7-M86YI<"D@>PH@("`@("`@("`@
M("`D=&AI<RT^869F96-T960@/2`D<F5S=6QT.PH@("`@("`@("`@("!R971U
M<FX@1$)?3TL["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M
M/F%F9F5C=&5D(#T@,#L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("`@("`@?0H@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&UO9&EF>4QI
M;6ET475E<GDH*0H*("`@("\J*@H@("`@("H@061D<R!,24U)5"!C;&%U<V5S
M('1O(&$@<75E<GD@<W1R:6YG(&%C8V]R9&EN9R!T;R!C=7)R96YT($1"35,@
M<W1A;F1A<F1S"B`@("`@*@H@("`@("H@3VYL>2!W;W)K<R!W:71H($9I<F5B
M:7)D+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'%U97)Y("`@=&AE
M('%U97)Y('1O(&UO9&EF>0H@("`@("H@0'!A<F%M(&EN="`@("`D9G)O;2`@
M("!T:&4@<F]W('1O('-T87)T('1O(&9E=&-H:6YG("@P(#T@=&AE(&9I<G-T
M(')O=RD*("`@("`J($!P87)A;2!I;G0@("`@)&-O=6YT("`@=&AE(&YU;6)E
M<G,@;V8@<F]W<R!T;R!F971C:`H@("`@("H@0'!A<F%M(&UI>&5D("`D<&%R
M86US("!A<G)A>2P@<W1R:6YG(&]R(&YU;65R:6,@9&%T82!T;R!B92!U<V5D
M(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!E>&5C=71I;VX@
M;V8@=&AE('-T871E;65N="X@(%%U86YT:71Y(&]F(&ET96US"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!P87-S960@;75S="!M871C:"!Q=6%N
M=&ET>2!O9B!P;&%C96AO;&1E<G,@:6X*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@('%U97)Y.B`@;65A;FEN9R`Q('!L86-E:&]L9&5R(&9O<B!N
M;VXM87)R87D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('!A<F%M
M971E<G,@;W(@,2!P;&%C96AO;&1E<B!P97(@87)R87D@96QE;65N="X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE('%U97)Y('-T<FEN9R!W
M:71H($Q)34E4(&-L875S97,@861D960*("`@("`J"B`@("`@*B!`86-C97-S
M('!R;W1E8W1E9`H@("`@("HO"B`@("!F=6YC=&EO;B!M;V1I9GE,:6UI=%%U
M97)Y*"1Q=65R>2P@)&9R;VTL("1C;W5N="P@)'!A<F%M<R`](&%R<F%Y*"DI
M"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YD<VY;)V1B<WEN=&%X)UT@/3T@
M)V9I<F5B:7)D)RD@>PH@("`@("`@("`@("`D<75E<GD@/2!P<F5G7W)E<&QA
M8V4H)R]>*%M<<RA=*2I314Q%0U0O:2<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`B4T5,14-4($9)4E-4("1C;W5N="!32TE0("1F<F]M
M(BP@)'%U97)Y*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1Q=65R>3L*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!N97AT4F5S=6QT*"D*"B`@
M("`O*BH*("`@("`J($UO=F4@=&AE(&EN=&5R;F%L(&EB87-E(')E<W5L="!P
M;VEN=&5R('1O('1H92!N97AT(&%V86EL86)L92!R97-U;'0*("`@("`J"B`@
M("`@*B!`<&%R86T@82!V86QI9"!F8G-Q;"!R97-U;'0@<F5S;W5R8V4*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H*("`@("`J($!R971U
M<FX@=')U92!I9B!A(')E<W5L="!I<R!A=F%I;&%B;&4@;W1H97)W:7-E(')E
M='5R;B!F86QS90H@("`@("HO"B`@("!F=6YC=&EO;B!N97AT4F5S=6QT*"1R
M97-U;'0I"B`@("!["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&9E=&-H26YT;R@I"@H@("`@+RHJ"B`@("`@
M*B!0;&%C97,@82!R;W<@9G)O;2!T:&4@<F5S=6QT('-E="!I;G1O('1H92!G
M:79E;B!A<G)A>0H@("`@("H*("`@("`J($9O<FUA=&EN9R!O9B!T:&4@87)R
M87D@86YD('1H92!D871A('1H97)E:6X@87)E(&-O;F9I9W5R86)L92X*("`@
M("`J(%-E92!$0E]R97-U;'0Z.F9E=&-H26YT;R@I(&9O<B!M;W)E(&EN9F]R
M;6%T:6]N+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES(&YO="!M96%N
M="!T;R!B92!C86QL960@9&ER96-T;'DN("!5<V4*("`@("`J($1"7W)E<W5L
M=#HZ9F5T8VA);G1O*"D@:6YS=&5A9"X@($ET(&-A;B=T(&)E(&1E8VQA<F5D
M(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E($1"7W)E<W5L="!I<R!A('-E
M<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@
M)')E<W5L="`@("!T:&4@<75E<GD@<F5S=6QT(')E<V]U<F-E"B`@("`@*B!`
M<&%R86T@87)R87D@("`@)&%R<B`@("`@("!T:&4@<F5F97)E;F-E9"!A<G)A
M>2!T;R!P=70@=&AE(&1A=&$@:6X*("`@("`J($!P87)A;2!I;G0@("`@("`D
M9F5T8VAM;V1E(&AO=R!T:&4@<F5S=6QT:6YG(&%R<F%Y('-H;W5L9"!B92!I
M;F1E>&5D"B`@("`@*B!`<&%R86T@:6YT("`@("`@)')O=VYU;2`@("!T:&4@
M<F]W(&YU;6)E<B!T;R!F971C:"`H,"`](&9I<G-T(')O=RD*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!$0E]/2R!O;B!S=6-C97-S+"!.54Q,('=H
M96X@=&AE(&5N9"!O9B!A(')E<W5L="!S970@:7,*("`@("`J("`@("`@("`@
M("`@("`@("!R96%C:&5D(&]R(&]N(&9A:6QU<F4*("`@("`J"B`@("`@*B!`
M<V5E($1"7W)E<W5L=#HZ9F5T8VA);G1O*"D*("`@("`J+PH@("`@9G5N8W1I
M;VX@9F5T8VA);G1O*"1R97-U;'0L("8D87)R+"`D9F5T8VAM;V1E+"`D<F]W
M;G5M(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H)')O=VYU;2`A/3T@;G5L
M;"D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/FEB87-E4F%I<V5%<G)O
M<BA$0E]%4E)/4E].3U1?0T%004),12D["B`@("`@("`@?0H@("`@("`@(&EF
M("@D9F5T8VAM;V1E("8@1$)?1D540TA-3T1%7T%34T]#*2!["B`@("`@("`@
M("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)VEB87-E7V9E=&-H7V%S<V]C)RDI
M('L*("`@("`@("`@("`@("`@("1A<G(@/2!`:6)A<V5?9F5T8VA?87-S;V,H
M)')E<W5L="D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D87)R(#T@9V5T7V]B:F5C=%]V87)S*&EB87-E7V9E=&-H7V]B:F5C="@D
M<F5S=6QT*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1T:&ES
M+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?3$]7
M15)#05-%("8F("1A<G(I('L*("`@("`@("`@("`@("`@("1A<G(@/2!A<G)A
M>5]C:&%N9V5?:V5Y7V-A<V4H)&%R<BP@0T%315],3U=%4BD["B`@("`@("`@
M("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D87)R(#T@0&EB
M87-E7V9E=&-H7W)O=R@D<F5S=6QT*3L*("`@("`@("!]"B`@("`@("`@:68@
M*"$D87)R*2!["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*
M("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$
M0E]03U)404))3$E465]25%))32D@>PH@("`@("`@("`@("`D=&AI<RT^7W)T
M<FEM07)R87E686QU97,H)&%R<BD["B`@("`@("`@?0H@("`@("`@(&EF("@D
M=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,2519
M7TY53$Q?5$]?14U05%DI('L*("`@("`@("`@("`@)'1H:7,M/E]C;VYV97)T
M3G5L;$%R<F%Y5F%L=65S5&]%;7!T>2@D87)R*3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&9R965297-U;'0H*0H*("`@("\J*@H@("`@("H@1&5L971E<R!T:&4@<F5S
M=6QT('-E="!A;F0@9G)E97,@=&AE(&UE;6]R>2!O8V-U<&EE9"!B>2!T:&4@
M<F5S=6QT('-E=`H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES(&YO="!M
M96%N="!T;R!B92!C86QL960@9&ER96-T;'DN("!5<V4*("`@("`J($1"7W)E
M<W5L=#HZ9G)E92@I(&EN<W1E860N("!)="!C86XG="!B92!D96-L87)E9"`B
M<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@82!S97!A
M<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1R
M97-U;'0@(%!(4"=S('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;"`@5%)512!O;B!S=6-C97-S+"!&04Q312!I9B`D
M<F5S=6QT(&ES(&EN=F%L:60*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L
M=#HZ9G)E92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&9R965297-U;'0H)')E
M<W5L="D*("`@('L*("`@("`@("!R971U<FX@0&EB87-E7V9R965?<F5S=6QT
M*"1R97-U;'0I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&9R9651
M=65R>2@I"@H@("`@9G5N8W1I;VX@9G)E95%U97)Y*"1Q=65R>2D*("`@('L*
M("`@("`@("!`:6)A<V5?9G)E95]Q=65R>2@D<75E<GDI.PH@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&%F9F5C
M=&5D4F]W<R@I"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S('1H92!N=6UB
M97(@;V8@<F]W<R!A9F9E8W1E9"!B>2!A(&1A=&$@;6%N:75P;&%T:6]N('%U
M97)Y"B`@("`@*@H@("`@("H@,"!I<R!R971U<FYE9"!F;W(@<75E<FEE<R!T
M:&%T(&1O;B=T(&UA;FEP=6QA=&4@9&%T82X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!R;W=S+B`@02!$0E]%<G)O<B!O8FIE
M8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@869F96-T9612
M;W=S*"D*("`@('L*("`@("`@("!I9B`H:7-?:6YT96=E<B@D=&AI<RT^869F
M96-T960I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^869F96-T960[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^:6)A<V5286ES945R
M<F]R*$1"7T524D]27TY/5%]#05!!0DQ%*3L*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!N=6U#;VQS*"D*"B`@("`O*BH*("`@("`J($=E=',@=&AE
M(&YU;6)E<B!O9B!C;VQU;6YS(&EN(&$@<F5S=6QT('-E=`H@("`@("H*("`@
M("`J(%1H:7,@;65T:&]D(&ES(&YO="!M96%N="!T;R!B92!C86QL960@9&ER
M96-T;'DN("!5<V4*("`@("`J($1"7W)E<W5L=#HZ;G5M0V]L<R@I(&EN<W1E
M860N("!)="!C86XG="!B92!D96-L87)E9"`B<')O=&5C=&5D(@H@("`@("H@
M8F5C875S92!$0E]R97-U;'0@:7,@82!S97!A<F%T92!O8FIE8W0N"B`@("`@
M*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1R97-U;'0@(%!(4"=S('%U97)Y
M(')E<W5L="!R97-O=7)C90H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T
M:&4@;G5M8F5R(&]F(&-O;'5M;G,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F
M86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?<F5S=6QT.CIN=6U#;VQS
M*"D*("`@("`J+PH@("`@9G5N8W1I;VX@;G5M0V]L<R@D<F5S=6QT*0H@("`@
M>PH@("`@("`@("1C;VQS(#T@0&EB87-E7VYU;5]F:65L9',H)')E<W5L="D[
M"B`@("`@("`@:68@*"$D8V]L<RD@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/FEB87-E4F%I<V5%<G)O<B@I.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@)&-O;',["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<')E<&%R
M92@I"@H@("`@+RHJ"B`@("`@*B!0<F5P87)E<R!A('%U97)Y(&9O<B!M=6QT
M:7!L92!E>&5C=71I;VX@=VET:"!E>&5C=71E*"DN"B`@("`@*@H@("`@("H@
M<')E<&%R92@I(')E<75I<F5S(&$@9V5N97)I8R!Q=65R>2!A<R!S=')I;F<@
M;&EK92`\8V]D93X*("`@("`J("`@($E.4T525"!)3E1/(&YU;6)E<G,@5D%,
M5453("@_+"`_+"`_*0H@("`@("H@/"]C;V1E/BX@(%1H92`\:V)D/C\\+VMB
M9#X@8VAA<F%C=&5R<R!A<F4@<&QA8V5H;VQD97)S+@H@("`@("H*("`@("`J
M(%1H<F5E('1Y<&5S(&]F('!L86-E:&]L9&5R<R!C86X@8F4@=7-E9#H*("`@
M("`J("`@*R`\:V)D/C\\+VMB9#X@(&$@<75O=&5D('-C86QA<B!V86QU92P@
M:2YE+B!S=')I;F=S+"!I;G1E9V5R<PH@("`@("H@("`K(#QK8F0^(3PO:V)D
M/B`@=F%L=64@:7,@:6YS97)T960@)V%S(&ES)PH@("`@("H@("`K(#QK8F0^
M)CPO:V)D/B`@<F5Q=6ER97,@82!F:6QE(&YA;64N("!4:&4@9FEL92=S(&-O
M;G1E;G1S(&=E=`H@("`@("H@("`@("`@("`@("`@("`@("`@("!I;G-E<G1E
M9"!I;G1O('1H92!Q=65R>2`H:2YE+B!S879I;F<@8FEN87)Y"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@(&1A=&$@:6X@82!D8BD*("`@("`J"B`@("`@
M*B!5<V4@8F%C:W-L87-H97,@=&\@97-C87!E('!L86-E:&]L9&5R(&-H87)A
M8W1E<G,@:68@>6]U(&1O;B=T('=A;G0*("`@("`J('1H96T@=&\@8F4@:6YT
M97)P<F5T960@87,@<&QA8V5H;VQD97)S+B`@17AA;7!L93H@/&-O9&4^"B`@
M("`@*B`@("`B55!$051%(&9O;R!3150@8V]L/3\@5TA%4D4@8V]L/2=O=F5R
M(%PF('5N9&5R)R(*("`@("`J(#PO8V]D93X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1Q=65R>2!Q=65R>2!T;R!B92!P<F5P87)E9`H@("`@("H@
M0')E='5R;B!M:7AE9"!$0B!S=&%T96UE;G0@<F5S;W5R8V4@;VX@<W5C8V5S
M<RX@1$)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<')E<&%R92@D<75E<GDI"B`@("!["B`@("`@("`@)'1O:V5N<R`@(#T@<')E
M9U]S<&QI="@G+R@H/SPA7%Q<*5LF/R%=*2\G+"`D<75E<GDL("TQ+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@4%)%1U]34$Q)5%]$14Q)35]#
M05!455)%*3L*("`@("`@("`D=&]K96X@("`@/2`P.PH@("`@("`@("1T>7!E
M<R`@("`](&%R<F%Y*"D["B`@("`@("`@)&YE=W%U97)Y(#T@)R<["@H@("`@
M("`@(&9O<F5A8V@@*"1T;VME;G,@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@
M("`@("`@('-W:71C:"`H)'9A;"D@>PH@("`@("`@("`@("`@("`@8V%S92`G
M/R<Z"B`@("`@("`@("`@("`@("`@("`@)'1Y<&5S6R1T;VME;BLK72`]($1"
M7U!!4D%-7U-#04Q!4CL*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@("`@(&-A<V4@)R8G.@H@("`@("`@("`@("`@("`@("`@("1T
M>7!E<ULD=&]K96XK*UT@/2!$0E]005)!35]/4$%1544["B`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E("<A)SH*("`@
M("`@("`@("`@("`@("`@("`D='EP97-;)'1O:V5N*RM=(#T@1$)?4$%204U?
M34E30SL*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@)'1O:V5N<ULD:V5Y
M72`]('!R96=?<F5P;&%C92@G+UQ<7"A;)C\A72DO)RP@(EQ<,2(L("1V86PI
M.PH@("`@("`@("`@("`@("`@("`@("1N97=Q=65R>2`N/2`D=&]K96YS6R1K
M97E=("X@)S\G.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D
M;F5W<75E<GD@/2!S=6)S='(H)&YE=W%U97)Y+"`P+"`M,2D["B`@("`@("`@
M)'1H:7,M/FQA<W1?<75E<GD@/2`D<75E<GD["B`@("`@("`@)&YE=W%U97)Y
M(#T@)'1H:7,M/FUO9&EF>5%U97)Y*"1N97=Q=65R>2D["B`@("`@("`@)'-T
M;70@/2!`:6)A<V5?<')E<&%R92@D=&AI<RT^8V]N;F5C=&EO;BP@)&YE=W%U
M97)Y*3L*("`@("`@("`D=&AI<RT^<')E<&%R95]T>7!E<ULH:6YT*21S=&UT
M72`]("1T>7!E<SL*("`@("`@("`D=&AI<RT^;6%N:7!?<75E<GE;*&EN="DD
M<W1M=%T@("`]($1".CII<TUA;FEP*"1Q=65R>2D["B`@("`@("`@<F5T=7)N
M("1S=&UT.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&5X96-U=&4H
M*0H*("`@("\J*@H@("`@("H@17AE8W5T97,@82!$0B!S=&%T96UE;G0@<')E
M<&%R960@=VET:"!P<F5P87)E*"DN"B`@("`@*@H@("`@("H@0'!A<F%M(')E
M<V]U<F-E("`D<W1M="`@82!$0B!S=&%T96UE;G0@<F5S;W5R8V4@<F5T=7)N
M960@9G)O;2!P<F5P87)E*"D*("`@("`J($!P87)A;2!M:7AE9"`@)&1A=&$@
M(&%R<F%Y+"!S=')I;F<@;W(@;G5M97)I8R!D871A('1O(&)E('5S960@:6X*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@(&5X96-U=&EO;B!O9B!T:&4@
M<W1A=&5M96YT+B`@475A;G1I='D@;V8@:71E;7,*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@('!A<W-E9"!M=7-T(&UA=&-H('%U86YT:71Y(&]F('!L
M86-E:&]L9&5R<R!I;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@<75E
M<GDZ("!M96%N:6YG(#$@9F]R(&YO;BUA<G)A>2!I=&5M<R!O<B!T:&4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@('%U86YT:71Y(&]F(&5L96UE;G1S
M(&EN('1H92!A<G)A>2X*("`@("`J($!R971U<FX@;V)J96-T("!A(&YE=R!$
M0E]297-U;'0@;W(@82!$0E]%<G)O<B!W:&5N(&9A:6P*("`@("`J($!S964@
M1$)?:6)A<V4Z.G!R97!A<F4H*0H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@)F5X96-U=&4H)'-T;70L("1D871A(#T@87)R
M87DH*2D*("`@('L*("`@("`@("`D9&%T82`]("AA<G)A>2DD9&%T83L*("`@
M("`@("`D=&AI<RT^;&%S=%]P87)A;65T97)S(#T@)&1A=&$["@H@("`@("`@
M("1T>7!E<R`])B`D=&AI<RT^<')E<&%R95]T>7!E<ULH:6YT*21S=&UT73L*
M("`@("`@("!I9B`H8V]U;G0H)'1Y<&5S*2`A/2!C;W5N="@D9&%T82DI('L*
M("`@("`@("`@("`@)'1M<"`])B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/
M4E]-25--051#2"D["B`@("`@("`@("`@(')E='5R;B`D=&UP.PH@("`@("`@
M('T*"B`@("`@("`@)&D@/2`P.PH@("`@("`@(&9O<F5A8V@@*"1D871A(&%S
M("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@(&EF("@D='EP97-;)&E=
M(#T]($1"7U!!4D%-7TU)4T,I('L*("`@("`@("`@("`@("`@("\J"B`@("`@
M("`@("`@("`@("`@*B!I8F%S92!D;V5S;B=T('-E96T@=&\@:&%V92!T:&4@
M86)I;&ET>2!T;R!P87-S(&$*("`@("`@("`@("`@("`@("`J('!A<F%M971E
M<B!A;&]N9R!U;F-H86YG960L('-O('-T<FEP(&]F9B!Q=6]T97,@9G)O;2!S
M=&%R=`H@("`@("`@("`@("`@("`@("H@86YD(&5N9"P@<&QU<R!T=7)N('1W
M;R!S:6YG;&4@<75O=&5S('1O(&]N92!S:6YG;&4@<75O=&4L"B`@("`@("`@
M("`@("`@("`@*B!I;B!O<F1E<B!T;R!A=F]I9"!T:&4@<75O=&5S(&=E='1I
M;F<@97-C87!E9"!B>0H@("`@("`@("`@("`@("`@("H@:6)A<V4@86YD(&5N
M9&EN9R!U<"!I;B!T:&4@9&%T86)A<V4N"B`@("`@("`@("`@("`@("`@*B\*
M("`@("`@("`@("`@("`@("1D871A6R1K97E=(#T@<')E9U]R97!L86-E*"(O
M7B<H+BHI)R0O(BP@(EQ<,2(L("1D871A6R1K97E=*3L*("`@("`@("`@("`@
M("`@("1D871A6R1K97E=(#T@<W1R7W)E<&QA8V4H(B<G(BP@(B<B+"`D9&%T
M85LD:V5Y72D["B`@("`@("`@("`@('T@96QS96EF("@D='EP97-;)&E=(#T]
M($1"7U!!4D%-7T]005%512D@>PH@("`@("`@("`@("`@("`@)&9P(#T@0&9O
M<&5N*"1D871A6R1K97E=+"`G<F(G*3L*("`@("`@("`@("`@("`@(&EF("@A
M)&9P*2!["B`@("`@("`@("`@("`@("`@("`@)'1M<"`])B`D=&AI<RT^<F%I
M<V5%<G)O<BA$0E]%4E)/4E]!0T-%4U-?5DE/3$%424].*3L*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)'1M<#L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("1D871A6R1K97E=(#T@9G)E860H)&9P+"!F:6QE<VEZ
M92@D9&%T85LD:V5Y72DI.PH@("`@("`@("`@("`@("`@9F-L;W-E*"1F<"D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&DK*SL*("`@("`@("!]"@H@
M("`@("`@(&%R<F%Y7W5N<VAI9G0H)&1A=&$L("1S=&UT*3L*"B`@("`@("`@
M)')E<R`](&-A;&Q?=7-E<E]F=6YC7V%R<F%Y*"=I8F%S95]E>&5C=71E)RP@
M)&1A=&$I.PH@("`@("`@(&EF("@A)')E<RD@>PH@("`@("`@("`@("`D=&UP
M(#TF("1T:&ES+3YI8F%S95)A:7-E17)R;W(H*3L*("`@("`@("`@("`@<F5T
M=7)N("1T;7`["B`@("`@("`@?0H@("`@("`@("\J(%A86"!N965D('1H:7,_
M"B`@("`@("`@:68@*"1T:&ES+3YA=71O8V]M;6ET("8F("1T:&ES+3YM86YI
M<%]Q=65R>5LH:6YT*21S=&UT72D@>PH@("`@("`@("`@("!`:6)A<V5?8V]M
M;6ET*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("!]*B\*("`@("`@("`D
M=&AI<RT^;&%S=%]S=&UT(#T@)'-T;70["B`@("`@("`@:68@*"1T:&ES+3YM
M86YI<%]Q=65R>5LH:6YT*21S=&UT72D@>PH@("`@("`@("`@("`D=&UP(#T@
M1$)?3TL["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1M<"`])B!N
M97<@1$)?<F5S=6QT*"1T:&ES+"`D<F5S*3L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("1T;7`["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&<F5E<R!T:&4@
M:6YT97)N86P@<F5S;W5R8V5S(&%S<V]C:6%T960@=VET:"!A('!R97!A<F5D
M('%U97)Y"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1S=&UT("`@
M("`@("`@("!T:&4@<')E<&%R960@<W1A=&5M96YT)W,@4$A0(')E<V]U<F-E
M"B`@("`@*B!`<&%R86T@8F]O;"`@("`@)&9R965?<F5S;W5R8V4@('-H;W5L
M9"!T:&4@4$A0(')E<V]U<F-E(&)E(&9R965D('1O;S\*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%5S92!F86QS92!I9B!Y;W4@
M;F5E9"!T;R!G970@9&%T80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@9G)O;2!T:&4@<F5S=6QT('-E="!L871E<BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VP@(%12544@;VX@<W5C8V5S<RP@1D%,4T4@
M:68@)')E<W5L="!I<R!I;G9A;&ED"B`@("`@*@H@("`@("H@0'-E92!$0E]I
M8F%S93HZ<')E<&%R92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&9R9650<F5P
M87)E9"@D<W1M="P@)&9R965?<F5S;W5R8V4@/2!T<G5E*0H@("`@>PH@("`@
M("`@(&EF("@A:7-?<F5S;W5R8V4H)'-T;70I*2!["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@:68@*"1F<F5E7W)E<V]U
M<F-E*2!["B`@("`@("`@("`@($!I8F%S95]F<F5E7W%U97)Y*"1S=&UT*3L*
M("`@("`@("!]"B`@("`@("`@=6YS970H)'1H:7,M/G!R97!A<F5?=&]K96YS
M6RAI;G0I)'-T;71=*3L*("`@("`@("!U;G-E="@D=&AI<RT^<')E<&%R95]T
M>7!E<ULH:6YT*21S=&UT72D["B`@("`@("`@=6YS970H)'1H:7,M/FUA;FEP
M7W%U97)Y6RAI;G0I)'-T;71=*3L*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!A=71O0V]M;6ET*"D*"B`@("`O
M*BH*("`@("`J($5N86)L97,@;W(@9&ES86)L97,@875T;VUA=&EC(&-O;6UI
M=',*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;"`D;VYO9F8@('1R=64@='5R
M;G,@:70@;VXL(&9A;'-E('1U<FYS(&ET(&]F9@H@("`@("H*("`@("`J($!R
M971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE
M8W0@:68@=&AE(&1R:79E<@H@("`@("H@("`@("`@("`@("`@("!D;V5S;B=T
M('-U<'!O<G0@875T;RUC;VUM:71T:6YG('1R86YS86-T:6]N<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@875T;T-O;6UI="@D;VYO9F8@/2!F86QS92D*("`@
M('L*("`@("`@("`D=&AI<RT^875T;V-O;6UI="`]("1O;F]F9B`_(#$@.B`P
M.PH@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!C;VUM:70H*0H*("`@("\J*@H@("`@("H@0V]M;6ET<R!T:&4@
M8W5R<F5N="!T<F%N<V%C=&EO;@H@("`@("H*("`@("`J($!R971U<FX@:6YT
M("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I
M;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]M;6ET*"D*("`@('L*("`@
M("`@("!R971U<FX@0&EB87-E7V-O;6UI="@D=&AI<RT^8V]N;F5C=&EO;BD[
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<F]L;&)A8VLH*0H*("`@
M("\J*@H@("`@("H@4F5V97)T<R!T:&4@8W5R<F5N="!T<F%N<V%C=&EO;@H@
M("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@
M02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F]L;&)A8VLH*0H@("`@>PH@("`@("`@(')E='5R;B!`:6)A<V5?
M<F]L;&)A8VLH)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[('1R86YS86-T:6]N26YI="@I"@H@("`@9G5N8W1I;VX@
M=')A;G-A8W1I;VY);FET*"1T<F%N<U]A<F=S(#T@,"D*("`@('L*("`@("`@
M("!R971U<FX@)'1R86YS7V%R9W,*("`@("`@("`@("`@("`@(#\@0&EB87-E
M7W1R86YS*"1T<F%N<U]A<F=S+"`D=&AI<RT^8V]N;F5C=&EO;BD*("`@("`@
M("`@("`@("`@(#H@0&EB87-E7W1R86YS*"D["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@;F5X=$ED*"D*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE(&YE>'0@9G)E92!I9"!I;B!A('-E<75E;F-E"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`@)'-E<5]N86UE("!N86UE(&]F('1H92!S97%U96YC
M90H@("`@("H@0'!A<F%M(&)O;VQE86X@)&]N9&5M86YD("!W:&5N('1R=64L
M('1H92!S97%E;F-E(&ES(&%U=&]M871I8V%L;'D*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&-R96%T960@:68@:70@9&]E<R!N;W0@97AI
M<W0*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YE>'0@:60@;G5M
M8F5R(&EN('1H92!S97%U96YC92X*("`@("`J("`@("`@("`@("`@("`@02!$
M0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E
M($1"7V-O;6UO;CHZ;F5X=$E$*"DL($1"7V-O;6UO;CHZ9V5T4V5Q=65N8V5.
M86UE*"DL"B`@("`@*B`@("`@($1"7VEB87-E.CIC<F5A=&5397%U96YC92@I
M+"!$0E]I8F%S93HZ9')O<%-E<75E;F-E*"D*("`@("`J+PH@("`@9G5N8W1I
M;VX@;F5X=$ED*"1S97%?;F%M92P@)&]N9&5M86YD(#T@=')U92D*("`@('L*
M("`@("`@("`D<W%N(#T@<W1R=&]U<'!E<B@D=&AI<RT^9V5T4V5Q=65N8V5.
M86UE*"1S97%?;F%M92DI.PH@("`@("`@("1R97!E870@/2`P.PH@("`@("`@
M(&1O('L*("`@("`@("`@("`@)'1H:7,M/G!U<VA%<G)O<DAA;F1L:6YG*%!%
M05)?15)23U)?4D5455).*3L*("`@("`@("`@("`@)')E<W5L="`])B`D=&AI
M<RT^<75E<GDH(E-%3$5#5"!'14Y?240H)'MS<6Y]+"`Q*2`B"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G1E)/32!21$(D1T5.15)!
M5$]24R`G"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`B
M5TA%4D4@4D1"7"1'14Y%4D%43U)?3D%-13TG)'MS<6Y])R(I.PH@("`@("`@
M("`@("`D=&AI<RT^<&]P17)R;W)(86YD;&EN9R@I.PH@("`@("`@("`@("!I
M9B`H)&]N9&5M86YD("8F($1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@
M("`@("`@("`@("`D<F5P96%T(#T@,3L*("`@("`@("`@("`@("`@("1R97-U
M;'0@/2`D=&AI<RT^8W)E871E4V5Q=65N8V4H)'-E<5]N86UE*3L*("`@("`@
M("`@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)')E<&5A
M="`](#`["B`@("`@("`@("`@('T*("`@("`@("!]('=H:6QE("@D<F5P96%T
M*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1R97-U;'0I.PH@("`@
M("`@('T*("`@("`@("`D87)R(#T@)')E<W5L="T^9F5T8VA2;W<H1$)?1D54
M0TA-3T1%7T]21$52140I.PH@("`@("`@("1R97-U;'0M/F9R964H*3L*("`@
M("`@("!R971U<FX@)&%R<ELP73L*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!C<F5A=&5397%U96YC92@I"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S
M(&$@;F5W('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<V5Q7VYA;64@(&YA;64@;V8@=&AE(&YE=R!S97%U96YC90H@("`@("H*("`@
M("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O
M;6UO;CHZ8W)E871E4V5Q=65N8V4H*2P@1$)?8V]M;6]N.CIG971397%U96YC
M94YA;64H*2P*("`@("`J("`@("`@1$)?:6)A<V4Z.FYE>'1)1"@I+"!$0E]I
M8F%S93HZ9')O<%-E<75E;F-E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@8W)E
M871E4V5Q=65N8V4H)'-E<5]N86UE*0H@("`@>PH@("`@("`@("1S<6X@/2!S
M=')T;W5P<&5R*"1T:&ES+3YG971397%U96YC94YA;64H)'-E<5]N86UE*2D[
M"B`@("`@("`@)'1H:7,M/G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?
M4D5455).*3L*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/G%U97)Y*")#4D5!
M5$4@1T5.15)!5$]2("1[<W%N?2(I.PH@("`@("`@("1T:&ES+3YP;W!%<G)O
M<DAA;F1L:6YG*"D["@H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(&1R;W!397%U96YC92@I"@H@("`@+RHJ
M"B`@("`@*B!$96QE=&5S(&$@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1S97%?;F%M92`@;F%M92!O9B!T:&4@<V5Q=65N8V4@=&\@
M8F4@9&5L971E9`H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O
M;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@
M("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ9')O<%-E<75E;F-E*"DL($1"
M7V-O;6UO;CHZ9V5T4V5Q=65N8V5.86UE*"DL"B`@("`@*B`@("`@($1"7VEB
M87-E.CIN97AT240H*2P@1$)?:6)A<V4Z.F-R96%T95-E<75E;F-E*"D*("`@
M("`J+PH@("`@9G5N8W1I;VX@9')O<%-E<75E;F-E*"1S97%?;F%M92D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/G%U97)Y*"=$14Q%5$4@1E)/32!2
M1$(D1T5.15)!5$]24R`G"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`N
M(")72$5212!21$)<)$=%3D52051/4E].04U%/2<B"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`N('-T<G1O=7!P97(H)'1H:7,M/F=E=%-E<75E;F-E
M3F%M92@D<V5Q7VYA;64I*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+B`B)R(I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(%]I8F%S949I
M96QD1FQA9W,H*0H*("`@("\J*@H@("`@("H@1V5T('1H92!C;VQU;6XG<R!F
M;&%G<PH@("`@("H*("`@("`J(%-U<'!O<G1S(")P<FEM87)Y7VME>2(L(")U
M;FEQ=65?:V5Y(BP@(FYO=%]N=6QL(BP@(F1E9F%U;'0B+`H@("`@("H@(F-O
M;7!U=&5D(B!A;F0@(F)L;V(B+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&9I96QD7VYA;64@('1H92!N86UE(&]F('1H92!F:65L9`H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=&%B;&5?;F%M92`@=&AE(&YA;64@;V8@=&AE('1A
M8FQE"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!F;&%G<PH@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC
M=&EO;B!?:6)A<V5&:65L9$9L86=S*"1F:65L9%]N86UE+"`D=&%B;&5?;F%M
M92D*("`@('L*("`@("`@("`D<W%L(#T@)U-%3$5#5"!2+E)$0B1#3TY35%)!
M24Y47U194$4@0U194$4G"B`@("`@("`@("`@("`@("XG($923TT@4D1")$E.
M1$587U-%1TU%3E13($DG"B`@("`@("`@("`@("`@("XG("!*3TE.(%)$0B12
M14Q!5$E/3E]#3TY35%)!24Y44R!2($].($DN4D1")$E.1$587TY!344]4BY2
M1$(D24Y$15A?3D%-12<*("`@("`@("`@("`@("`@+B<@5TA%4D4@22Y21$(D
M1DE%3$1?3D%-13U<)R<@+B`D9FEE;&1?;F%M92`N("=<)R<*("`@("`@("`@
M("`@("`@+B<@($%.1"!54%!%4BA2+E)$0B1214Q!5$E/3E].04U%*3U<)R<@
M+B!S=')T;W5P<&5R*"1T86)L95]N86UE*2`N("=<)R<["@H@("`@("`@("1R
M97-U;'0@/2!`:6)A<V5?<75E<GDH)'1H:7,M/F-O;FYE8W1I;VXL("1S<6PI
M.PH@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/FEB87-E4F%I<V5%<G)O<B@I.PH@("`@("`@('T*"B`@("`@("`@
M)&9L86=S(#T@)R<["B`@("`@("`@:68@*"1O8FH@/2!`:6)A<V5?9F5T8VA?
M;V)J96-T*"1R97-U;'0I*2!["B`@("`@("`@("`@($!I8F%S95]F<F5E7W)E
M<W5L="@D<F5S=6QT*3L*("`@("`@("`@("`@:68@*&ES<V5T*"1O8FHM/D-4
M65!%*2`@)B8@=')I;2@D;V)J+3Y#5%E012D@/3T@)U!224U!4ED@2T59)RD@
M>PH@("`@("`@("`@("`@("`@)&9L86=S("X]("=P<FEM87)Y7VME>2`G.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AI<W-E="@D;V)J+3Y#5%E0
M12D@("8F('1R:6TH)&]B:BT^0U194$4I(#T]("=53DE1544G*2!["B`@("`@
M("`@("`@("`@("`D9FQA9W,@+CT@)W5N:7%U95]K97D@)SL*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@)'-Q;"`]("=314Q%0U0@4BY21$(D
M3E5,3%]&3$%'($%3($Y&3$%'+"<*("`@("`@("`@("`@("`@+B<@(%(N4D1"
M)$1%1D%53%1?4T]54D-%($%3($133U520T4L)PH@("`@("`@("`@("`@("`N
M)R`@1BY21$(D1DE%3$1?5%E012!!4R!&5%E012PG"B`@("`@("`@("`@("`@
M("XG("!&+E)$0B1#3TU0551%1%]33U520T4@05,@0U-/55)#12<*("`@("`@
M("`@("`@("`@+B<@1E)/32!21$(D4D5,051)3TY?1DE%3$13(%(@)PH@("`@
M("`@("`@("`@("`N)R`@2D])3B!21$(D1DE%3$13($8@3TX@4BY21$(D1DE%
M3$1?4T]54D-%/48N4D1")$9)14Q$7TY!344G"B`@("`@("`@("`@("`@("XG
M(%=(15)%(%504$52*%(N4D1")%)%3$%424].7TY!344I/5PG)R`N('-T<G1O
M=7!P97(H)'1A8FQE7VYA;64I("X@)UPG)PH@("`@("`@("`@("`@("`N)R`@
M04Y$(%(N4D1")$9)14Q$7TY!344]7"<G("X@)&9I96QD7VYA;64@+B`G7"<G
M.PH*("`@("`@("`D<F5S=6QT(#T@0&EB87-E7W%U97)Y*"1T:&ES+3YC;VYN
M96-T:6]N+"`D<W%L*3L*("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YI8F%S95)A:7-E17)R;W(H*3L*("`@("`@
M("!]"B`@("`@("`@:68@*"1O8FH@/2!`:6)A<V5?9F5T8VA?;V)J96-T*"1R
M97-U;'0I*2!["B`@("`@("`@("`@($!I8F%S95]F<F5E7W)E<W5L="@D<F5S
M=6QT*3L*("`@("`@("`@("`@:68@*&ES<V5T*"1O8FHM/DY&3$%'*2D@>PH@
M("`@("`@("`@("`@("`@)&9L86=S("X]("=N;W1?;G5L;"`G.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("AI<W-E="@D;V)J+3Y$4T]54D-%*2D@
M>PH@("`@("`@("`@("`@("`@)&9L86=S("X]("=D969A=6QT("<["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@:68@*&ES<V5T*"1O8FHM/D-33U520T4I
M*2!["B`@("`@("`@("`@("`@("`D9FQA9W,@+CT@)V-O;7!U=&5D("<["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES<V5T*"1O8FHM/D9465!%
M*2`@)B8@)&]B:BT^1E194$4@/3T@,C8Q*2!["B`@("`@("`@("`@("`@("`D
M9FQA9W,@+CT@)V)L;V(@)SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N('1R:6TH)&9L86=S*3L*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!I8F%S95)A:7-E17)R;W(H*0H*("`@("\J*@H@("`@("H@
M4')O9'5C97,@82!$0E]%<G)O<B!O8FIE8W0@<F5G87)D:6YG('1H92!C=7)R
M96YT('!R;V)L96T*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("1E<G)N;R`@
M:68@=&AE(&5R<F]R(&ES(&)E:6YG(&UA;G5A;&QY(')A:7-E9"!P87-S(&$*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@1$)?15)23U(J(&-O;G-T86YT
M(&AE<F4N("!)9B!T:&ES(&ES;B=T('!A<W-E9`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("!T:&4@97)R;W(@:6YF;W)M871I;VX@9V%T:&5R960@9G)O
M;2!T:&4@1$)-4RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@=&AE
M($1"7T5R<F]R(&]B:F5C=`H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N
M.CIR86ES945R<F]R*"DL"B`@("`@*B`@("`@($1"7VEB87-E.CIE<G)O<DYA
M=&EV92@I+"!$0E]I8F%S93HZ97)R;W)#;V1E*"D*("`@("`J+PH@("`@9G5N
M8W1I;VX@)FEB87-E4F%I<V5%<G)O<B@D97)R;F\@/2!N=6QL*0H@("`@>PH@
M("`@("`@(&EF("@D97)R;F\@/3T](&YU;&PI('L*("`@("`@("`@("`@)&5R
M<FYO(#T@)'1H:7,M/F5R<F]R0V]D92@D=&AI<RT^97)R;W).871I=F4H*2D[
M"B`@("`@("`@?0H@("`@("`@("1T;7`@/28@)'1H:7,M/G)A:7-E17)R;W(H
M)&5R<FYO+"!N=6QL+"!N=6QL+"!N=6QL+"!`:6)A<V5?97)R;7-G*"DI.PH@
M("`@("`@(')E='5R;B`D=&UP.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&5R<F]R3F%T:79E*"D*"B`@("`O*BH*("`@("`J($=E=',@=&AE($1"
M35,G(&YA=&EV92!E<G)O<B!C;V1E('!R;V1U8V5D(&)Y('1H92!L87-T('%U
M97)Y"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!$0DU3)R!E<G)O
M<B!C;V1E+B`@3E5,3"!I9B!T:&5R92!I<R!N;R!E<G)O<B!C;V1E+@H@("`@
M("H*("`@("`J($!S:6YC92!-971H;V0@879A:6QA8FQE('-I;F-E(%)E;&5A
M<V4@,2XW+C`*("`@("`J+PH@("`@9G5N8W1I;VX@97)R;W).871I=F4H*0H@
M("`@>PH@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)VEB87-E7V5R<F-O
M9&4G*2D@>PH@("`@("`@("`@("!R971U<FX@0&EB87-E7V5R<F-O9&4H*3L*
M("`@("`@("!]"B`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>1'EN86UI8R!3
M44P@17)R;W(@4U%,(&5R<F]R(&-O9&4@/2`H6S`M.2U=*RDO:2<L"B`@("`@
M("`@("`@("`@("`@("`@("`@0&EB87-E7V5R<FUS9R@I+"`D;2DI('L*("`@
M("`@("`@("`@<F5T=7)N("AI;G0I)&U;,5T["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B!N=6QL.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&5R
M<F]R0V]D92@I"@H@("`@+RHJ"B`@("`@*B!-87!S(&YA=&EV92!E<G)O<B!C
M;V1E<R!T;R!$0B=S('!O<G1A8FQE(&]N97,*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT("1N871I=F5C;V1E("!T:&4@97)R;W(@8V]D92!R971U<FYE9"!B
M>2!T:&4@1$)-4PH@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@<&]R
M=&%B;&4@1$(@97)R;W(@8V]D92X@(%)E='5R;B!$0E]%4E)/4B!I9B!T:&4*
M("`@("`J("`@("`@("`@("`@("`@8W5R<F5N="!D<FEV97(@9&]E<VXG="!H
M879E(&$@;6%P<&EN9R!F;W(@=&AE"B`@("`@*B`@("`@("`@("`@("`@("1N
M871I=F5C;V1E('-U8FUI='1E9"X*("`@("`J"B`@("`@*B!`<VEN8V4@365T
M:&]D(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-RXP"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&5R<F]R0V]D92@D;F%T:79E8V]D92`](&YU;&PI"B`@("![
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YE<G)O<F-O9&5?;6%P6R1N871I
M=F5C;V1E72DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YE<G)O<F-O
M9&5?;6%P6R1N871I=F5C;V1E73L*("`@("`@("!]"@H@("`@("`@('-T871I
M8R`D97)R;W)?<F5G97AP<SL*("`@("`@("!I9B`H(6ES<V5T*"1E<G)O<E]R
M96=E>'!S*2D@>PH@("`@("`@("`@("`D97)R;W)?<F5G97AP<R`](&%R<F%Y
M*`H@("`@("`@("`@("`@("`@)R]G96YE<F%T;W(@+BH@:7,@;F]T(&1E9FEN
M960O)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27U-93E1!6"P@
M("\O(&9O<B!C;VUP870N('<@:6)A<V5?97)R8V]D92@I"B`@("`@("`@("`@
M("`@("`G+W1A8FQE+BHH;F]T(&5X:7-T?&YO="!F;W5N9'QU;FMN;W=N*2]I
M)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27TY/4U5#2%1!0DQ%
M+`H@("`@("`@("`@("`@("`@)R]T86)L92`N*B!A;')E861Y(&5X:7-T<R]I
M)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27T%,4D5!1%E?15A)
M4U13+`H@("`@("`@("`@("`@("`@)R]U;G-U8V-E<W-F=6P@;65T861A=&$@
M=7!D871E("XJ(&9A:6QE9"!A='1E;7!T('1O('-T;W)E(&1U<&QI8V%T92!V
M86QU92]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27T%,4D5!
M1%E?15A)4U13+`H@("`@("`@("`@("`@("`@)R]U;G-U8V-E<W-F=6P@;65T
M861A=&$@=7!D871E("XJ(&YO="!F;W5N9"]I)PH@("`@("`@("`@("`@("`@
M("`@(#T^($1"7T524D]27TY/5%]&3U5.1"P*("`@("`@("`@("`@("`@("<O
M=F%L:61A=&EO;B!E<G)O<B!F;W(@8V]L=6UN("XJ('9A;'5E(")<*EPJ7"H@
M;G5L;"]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27T-/3E-4
M4D%)3E1?3D]47TY53$PL"B`@("`@("`@("`@("`@("`G+W9I;VQA=&EO;B!O
M9B!;7'<@72L@8V]N<W1R86EN="]I)PH@("`@("`@("`@("`@("`@("`@(#T^
M($1"7T524D]27T-/3E-44D%)3E0L"B`@("`@("`@("`@("`@("`G+V-O;G9E
M<G-I;VX@97)R;W(@9G)O;2!S=')I;F<O:2<*("`@("`@("`@("`@("`@("`@
M("`]/B!$0E]%4E)/4E])3E9!3$E$7TY534)%4BP*("`@("`@("`@("`@("`@
M("<O;F\@<&5R;6ES<VEO;B!F;W(O:2<*("`@("`@("`@("`@("`@("`@("`]
M/B!$0E]%4E)/4E]!0T-%4U-?5DE/3$%424].+`H@("`@("`@("`@("`@("`@
M)R]A<FET:&UE=&EC(&5X8V5P=&EO;BP@;G5M97)I8R!O=F5R9FQO=RP@;W(@
M<W1R:6YG('1R=6YC871I;VXO:2<*("`@("`@("`@("`@("`@("`@("`]/B!$
M0E]%4E)/4E])3E9!3$E$+`H@("`@("`@("`@("`I.PH@("`@("`@('T*"B`@
M("`@("`@)&5R<F]R;7-G(#T@0&EB87-E7V5R<FUS9R@I.PH@("`@("`@(&9O
M<F5A8V@@*"1E<G)O<E]R96=E>'!S(&%S("1R96=E>'`@/3X@)&-O9&4I('L*
M("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)')E9V5X<"P@)&5R<F]R;7-G
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1C;V1E.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]%4E)/4CL*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!T86)L94EN9F\H*0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!I;F9O<FUA=&EO;B!A8F]U="!A('1A8FQE(&]R(&$@
M<F5S=6QT('-E=`H@("`@("H*("`@("`J($Y/5$4Z(&]N;'D@<W5P<&]R=',@
M)W1A8FQE)R!A;F0@)V9L86=S)R!I9B`\=F%R/B1R97-U;'0\+W9A<CX*("`@
M("`J(&ES(&$@=&%B;&4@;F%M92X*("`@("`J"B`@("`@*B!`<&%R86T@;V)J
M96-T?'-T<FEN9R`@)')E<W5L="`@1$)?<F5S=6QT(&]B:F5C="!F<F]M(&$@
M<75E<GD@;W(@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!S=')I;F<@8V]N=&%I;FEN9R!T:&4@;F%M92!O9B!A('1A8FQE+@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!7:&EL92!T
M:&ES(&%L<V\@86-C97!T<R!A('%U97)Y(')E<W5L=`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!R97-O=7)C92!I9&5N=&EF:65R
M+"!T:&ES(&)E:&%V:6]R(&ES"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&1E<')E8V%T960N"B`@("`@*B!`<&%R86T@:6YT("`@
M("`@("`@("`@)&UO9&4@("`@82!V86QI9"!T86)L94EN9F\@;6]D90H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@(&%N(&%S<V]C:6%T:79E(&%R<F%Y
M('=I=&@@=&AE(&EN9F]R;6%T:6]N(')E<75E<W1E9"X*("`@("`J("`@("`@
M("`@("`@("`@("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@
M("H*("`@("`J($!S964@1$)?8V]M;6]N.CIT86)L94EN9F\H*0H@("`@("HO
M"B`@("!F=6YC=&EO;B!T86)L94EN9F\H)')E<W5L="P@)&UO9&4@/2!N=6QL
M*0H@("`@>PH@("`@("`@(&EF("AI<U]S=')I;F<H)')E<W5L="DI('L*("`@
M("`@("`@("`@+RH*("`@("`@("`@("`@("H@4')O8F%B;'D@<F5C96EV960@
M82!T86)L92!N86UE+@H@("`@("`@("`@("`@*B!#<F5A=&4@82!R97-U;'0@
M<F5S;W5R8V4@:61E;G1I9FEE<BX*("`@("`@("`@("`@("HO"B`@("`@("`@
M("`@("1I9"`]($!I8F%S95]Q=65R>2@D=&AI<RT^8V]N;F5C=&EO;BP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(")314Q%0U0@*B!&4D]-("1R
M97-U;'0@5TA%4D4@,3TP(BD["B`@("`@("`@("`@("1G;W1?<W1R:6YG(#T@
M=')U93L*("`@("`@("!](&5L<V5I9B`H:7-S970H)')E<W5L="T^<F5S=6QT
M*2D@>PH@("`@("`@("`@("`O*@H@("`@("`@("`@("`@*B!0<F]B86)L>2!R
M96-E:79E9"!A(')E<W5L="!O8FIE8W0N"B`@("`@("`@("`@("`J($5X=')A
M8W0@=&AE(')E<W5L="!R97-O=7)C92!I9&5N=&EF:65R+@H@("`@("`@("`@
M("`@*B\*("`@("`@("`@("`@)&ED(#T@)')E<W5L="T^<F5S=6QT.PH@("`@
M("`@("`@("`D9V]T7W-T<FEN9R`](&9A;'-E.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("\J"B`@("`@("`@("`@("`J(%!R;V)A8FQY(')E8V5I
M=F5D(&$@<F5S=6QT(')E<V]U<F-E(&ED96YT:69I97(N"B`@("`@("`@("`@
M("`J($-O<'D@:70N"B`@("`@("`@("`@("`J($1E<')E8V%T960N("!(97)E
M(&9O<B!C;VUP871I8FEL:71Y(&]N;'DN"B`@("`@("`@("`@("`J+PH@("`@
M("`@("`@("`D:60@/2`D<F5S=6QT.PH@("`@("`@("`@("`D9V]T7W-T<FEN
M9R`](&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I<U]R97-O=7)C
M92@D:60I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^:6)A<V5286ES
M945R<F]R*$1"7T524D]27TY%141?34]215]$051!*3L*("`@("`@("!]"@H@
M("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"
M7U!/4E1!0DE,25197TQ/5T520T%312D@>PH@("`@("`@("`@("`D8V%S95]F
M=6YC(#T@)W-T<G1O;&]W97(G.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1C87-E7V9U;F,@/2`G<W1R=F%L)SL*("`@("`@("!]"@H@("`@("`@
M("1C;W5N="`]($!I8F%S95]N=6U?9FEE;&1S*"1I9"D["B`@("`@("`@)')E
M<R`@(#T@87)R87DH*3L*"B`@("`@("`@:68@*"1M;V1E*2!["B`@("`@("`@
M("`@("1R97-;)VYU;5]F:65L9',G72`]("1C;W5N=#L*("`@("`@("!]"@H@
M("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1C;W5N=#L@)&DK*RD@>PH@("`@
M("`@("`@("`D:6YF;R`]($!I8F%S95]F:65L9%]I;F9O*"1I9"P@)&DI.PH@
M("`@("`@("`@("`D<F5S6R1I72`](&%R<F%Y*`H@("`@("`@("`@("`@("`@
M)W1A8FQE)R`]/B`D9V]T7W-T<FEN9R`_("1C87-E7V9U;F,H)')E<W5L="D@
M.B`G)RP*("`@("`@("`@("`@("`@("=N86UE)R`@/3X@)&-A<V5?9G5N8R@D
M:6YF;ULG;F%M92==*2P*("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@)&EN
M9F];)W1Y<&4G72P*("`@("`@("`@("`@("`@("=L96XG("`@/3X@)&EN9F];
M)VQE;F=T:"==+`H@("`@("`@("`@("`@("`@)V9L86=S)R`]/B`H)&=O=%]S
M=')I;F<I"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`_("1T:&ES+3Y?
M:6)A<V5&:65L9$9L86=S*"1I;F9O6R=N86UE)UTL("1R97-U;'0I"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`Z("<G+`H@("`@("`@("`@("`I.PH@
M("`@("`@("`@("!I9B`H)&UO9&4@)B!$0E]404),14E.1D]?3U)$15(I('L*
M("`@("`@("`@("`@("`@("1R97-;)V]R9&5R)UU;)')E<ULD:5U;)VYA;64G
M75T@/2`D:3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&UO9&4@
M)B!$0E]404),14E.1D]?3U)$15)404),12D@>PH@("`@("`@("`@("`@("`@
M)')E<ULG;W)D97)T86)L92==6R1R97-;)&E=6R=T86)L92==75LD<F5S6R1I
M75LG;F%M92==72`]("1I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("`O+R!F<F5E('1H92!R97-U;'0@;VYL>2!I9B!W92!W97)E(&-A;&QE
M9"!O;B!A('1A8FQE"B`@("`@("`@:68@*"1G;W1?<W1R:6YG*2!["B`@("`@
M("`@("`@($!I8F%S95]F<F5E7W)E<W5L="@D:60I.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@)')E<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!G9713<&5C:6%L475E<GDH*0H*("`@("\J*@H@("`@("H@3V)T86EN<R!T
M:&4@<75E<GD@<W1R:6YG(&YE961E9"!F;W(@;&ES=&EN9R!A(&=I=F5N('1Y
M<&4@;V8@;V)J96-T<PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1Y
M<&4@('1H92!K:6YD(&]F(&]B:F5C=',@>6]U('=A;G0@=&\@<F5T<FEE=F4*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(%-13"!Q=65R>2!S
M=')I;F<@;W(@;G5L;"!I9B!T:&4@9')I=F5R(&1O97-N)W0*("`@("`J("`@
M("`@("`@("`@("`@("`@<W5P<&]R="!T:&4@;V)J96-T('1Y<&4@<F5Q=65S
M=&5D"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J($!S
M964@1$)?8V]M;6]N.CIG971,:7-T3V8H*0H@("`@("HO"B`@("!F=6YC=&EO
M;B!G9713<&5C:6%L475E<GDH)'1Y<&4I"B`@("!["B`@("`@("`@<W=I=&-H
M("@D='EP92D@>PH@("`@("`@("`@("!C87-E("=T86)L97,G.@H@("`@("`@
M("`@("`@("`@<F5T=7)N("=314Q%0U0@1$E35$E.0U0@4BY21$(D4D5,051)
M3TY?3D%-12!&4D]-("<*("`@("`@("`@("`@("`@("`@("`@("`N("=21$(D
M4D5,051)3TY?1DE%3$13(%(@5TA%4D4@4BY21$(D4UE35$5-7T9,04<],"<[
M"B`@("`@("`@("`@(&-A<V4@)W9I97=S)SH*("`@("`@("`@("`@("`@(')E
M='5R;B`G4T5,14-4($1)4U1)3D-4(%)$0B1624577TY!344@9G)O;2!21$(D
M5DE%5U]214Q!5$E/3E,G.PH@("`@("`@("`@("!C87-E("=U<V5R<R<Z"B`@
M("`@("`@("`@("`@("!R971U<FX@)U-%3$5#5"!$25-424Y#5"!21$(D55-%
M4B!&4D]-(%)$0B154T527U!2259)3$5'15,G.PH@("`@("`@("`@("!D969A
M=6QT.@H@("`@("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H@
M("`@?0H*("`@("\O('U]?0H*?0H*+RH*("H@3&]C86P@=F%R:6%B;&5S.@H@
M*B!T86(M=VED=&@Z(#0*("H@8RUB87-I8RUO9F9S970Z(#0*("H@16YD.@H@
M*B\*"C\^"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+T1"+VEF>"YP:'``````````````````````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-#8W,C`@,3`U,34T,S,W,S$@
M,#(P,C8Q`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"@HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H
M:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J(%1H92!014%2
M($1"(&1R:79E<B!F;W(@4$A0)W,@:69X(&5X=&5N<VEO;@H@*B!F;W(@:6YT
M97)A8W1I;F<@=VET:"!);F9O<FUI>"!D871A8F%S97,*("H*("H@4$A0('9E
M<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL
M92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS
M90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E
M+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@
M82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T
M;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*("H@<V5N9"!A
M(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A
M(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E
M"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@(%1O;6%S(%8N5BY#
M;W@@/&-O>$!I9&5C;F5T+F-O;3X*("H@0&%U=&AO<B`@("`@1&%N:65L($-O
M;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW
M+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@
M0'9E<G-I;VX@("`@0U93.B`D260Z(&EF>"YP:'`L=B`Q+C<P(#(P,#4O,#(O
M,C`@,#`Z-#0Z-#@@9&%N:65L8R!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P
M.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO"@HO*BH*("H@3V)T86EN
M('1H92!$0E]C;VUM;VX@8VQA<W,@<V\@:70@8V%N(&)E(&5X=&5N9&5D(&9R
M;VT*("HO"G)E<75I<F5?;VYC92`G1$(O8V]M;6]N+G!H<"<["@HO*BH*("H@
M5&AE(&UE=&AO9',@4$5!4B!$0B!U<V5S('1O(&EN=&5R86-T('=I=&@@4$A0
M)W,@:69X(&5X=&5N<VEO;@H@*B!F;W(@:6YT97)A8W1I;F<@=VET:"!);F9O
M<FUI>"!D871A8F%S97,*("H*("H@5&AE<V4@;65T:&]D<R!O=F5R;&]A9"!T
M:&4@;VYE<R!D96-L87)E9"!I;B!$0E]C;VUM;VXN"B`J"B`J($UO<F4@:6YF
M;R!O;B!);F9O<FUI>"!E<G)O<G,@8V%N(&)E(&9O=6YD(&%T.@H@*B!H='1P
M.B\O=W=W+FEN9F]R;6EX+F-O;2]A;G-W97)S+V5N9VQI<V@O:65R<F]R<RYH
M=&T*("H*("H@5$]$3SH*("H@("`M('-E="!N965D960@96YV($EN9F]R;6EX
M('9A<G,@;VX@8V]N;F5C=`H@*B`@("T@:6UP;&5M96YT(&YA=&EV92!P<F5P
M87)E+V5X96-U=&4*("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A
M8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@5&]M87,@5BY6+D-O>"`\8V]X
M0&ED96-N970N8V]M/@H@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES<V]R
M(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4
M:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R<VEO
M;B`@("!296QE87-E.B`Q+C<N-@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A
M<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO"F-L87-S($1"7VEF>"!E>'1E;F1S
M($1"7V-O;6UO;@I["B`@("`O+R![>WL@<')O<&5R=&EE<PH*("`@("\J*@H@
M("`@("H@5&AE($1"(&1R:79E<B!T>7!E("AM>7-Q;"P@;V-I."P@;V1B8RP@
M971C+BD*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D<&AP
M='EP92`]("=I9G@G.PH*("`@("\J*@H@("`@("H@5&AE(&1A=&%B87-E('-Y
M;G1A>"!V87)I86YT('1O(&)E('5S960@*&1B,BP@86-C97-S+"!E=&,N*2P@
M:68@86YY"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)&1B
M<WEN=&%X(#T@)VEF>"<["@H@("`@+RHJ"B`@("`@*B!4:&4@8V%P86)I;&ET
M:65S(&]F('1H:7,@1$(@:6UP;&5M96YT871I;VX*("`@("`J"B`@("`@*B!4
M:&4@)VYE=U]L:6YK)R!E;&5M96YT(&-O;G1A:6YS('1H92!02%`@=F5R<VEO
M;B!T:&%T(&9I<G-T('!R;W9I9&5D"B`@("`@*B!N97=?;&EN:R!S=7!P;W)T
M(&9O<B!T:&ES($1"35,N("!#;VYT86EN<R!F86QS92!I9B!I="=S('5N<W5P
M<&]R=&5D+@H@("`@("H*("`@("`J($UE86YI;F<@;V8@=&AE("=L:6UI="<@
M96QE;65N=#H*("`@("`J("`@*R`G96UU;&%T92<@/2!E;75L871E('=I=&@@
M9F5T8V@@<F]W(&)Y(&YU;6)E<@H@("`@("H@("`K("=A;'1E<B<@("`](&%L
M=&5R('1H92!Q=65R>0H@("`@("H@("`K(&9A;'-E("`@("`]('-K:7`@<F]W
M<PH@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1F
M96%T=7)E<R`](&%R<F%Y*`H@("`@("`@("=L:6UI="<@("`@("`@("`]/B`G
M96UU;&%T92<L"B`@("`@("`@)VYE=U]L:6YK)R`@("`@(#T^(&9A;'-E+`H@
M("`@("`@("=N=6UR;W=S)R`@("`@("`]/B`G96UU;&%T92<L"B`@("`@("`@
M)W!C;VYN96-T)R`@("`@(#T^('1R=64L"B`@("`@("`@)W!R97!A<F4G("`@
M("`@(#T^(&9A;'-E+`H@("`@("`@("=S<VPG("`@("`@("`@("`]/B!F86QS
M92P*("`@("`@("`G=')A;G-A8W1I;VYS)R`@/3X@=')U92P*("`@("D["@H@
M("`@+RHJ"B`@("`@*B!!(&UA<'!I;F<@;V8@;F%T:79E(&5R<F]R(&-O9&5S
M('1O($1"(&5R<F]R(&-O9&5S"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*
M("`@('9A<B`D97)R;W)C;V1E7VUA<"`](&%R<F%Y*`H@("`@("`@("<M,C`Q
M)R`@("`]/B!$0E]%4E)/4E]364Y405@L"B`@("`@("`@)RTR,#8G("`@(#T^
M($1"7T524D]27TY/4U5#2%1!0DQ%+`H@("`@("`@("<M,C$W)R`@("`]/B!$
M0E]%4E)/4E].3U-50TA&245,1"P*("`@("`@("`G+3(S-B<@("`@/3X@1$)?
M15)23U)?5D%,545?0T]53E1?3TY?4D]7+`H@("`@("`@("<M,C,Y)R`@("`]
M/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@("`@("<M,C4S)R`@("`]/B!$
M0E]%4E)/4E]364Y405@L"B`@("`@("`@)RTR.3(G("`@(#T^($1"7T524D]2
M7T-/3E-44D%)3E1?3D]47TY53$PL"B`@("`@("`@)RTS,3`G("`@(#T^($1"
M7T524D]27T%,4D5!1%E?15A)4U13+`H@("`@("`@("<M,S$V)R`@("`]/B!$
M0E]%4E)/4E]!3%)%04197T5825-44RP*("`@("`@("`G+3,Q.2<@("`@/3X@
M1$)?15)23U)?3D]47T9/54Y$+`H@("`@("`@("<M,S(Y)R`@("`]/B!$0E]%
M4E)/4E].3T1"4T5,14-4140L"B`@("`@("`@)RTS-#8G("`@(#T^($1"7T52
M4D]27T-/3E-44D%)3E0L"B`@("`@("`@)RTS.#8G("`@(#T^($1"7T524D]2
M7T-/3E-44D%)3E1?3D]47TY53$PL"B`@("`@("`@)RTS.3$G("`@(#T^($1"
M7T524D]27T-/3E-44D%)3E1?3D]47TY53$PL"B`@("`@("`@)RTU-30G("`@
M(#T^($1"7T524D]27U-93E1!6"P*("`@("`@("`G+38Y,2<@("`@/3X@1$)?
M15)23U)?0T].4U1204E.5"P*("`@("`@("`G+38Y,B<@("`@/3X@1$)?15)2
M3U)?0T].4U1204E.5"P*("`@("`@("`G+3<P,R<@("`@/3X@1$)?15)23U)?
M0T].4U1204E.5%].3U1?3E5,3"P*("`@("`@("`G+3$R,#0G("`@/3X@1$)?
M15)23U)?24Y604Q)1%]$051%+`H@("`@("`@("<M,3(P-2<@("`]/B!$0E]%
M4E)/4E])3E9!3$E$7T1!5$4L"B`@("`@("`@)RTQ,C`V)R`@(#T^($1"7T52
M4D]27TE.5D%,241?1$%412P*("`@("`@("`G+3$R,#DG("`@/3X@1$)?15)2
M3U)?24Y604Q)1%]$051%+`H@("`@("`@("<M,3(Q,"<@("`]/B!$0E]%4E)/
M4E])3E9!3$E$7T1!5$4L"B`@("`@("`@)RTQ,C$R)R`@(#T^($1"7T524D]2
M7TE.5D%,241?1$%412P*("`@("`@("`G+3$R,3,G("`@/3X@1$)?15)23U)?
M24Y604Q)1%].54U"15(L"B`@("`I.PH*("`@("\J*@H@("`@("H@5&AE(')A
M=R!D871A8F%S92!C;VYN96-T:6]N(&-R96%T960@8GD@4$A0"B`@("`@*B!`
M=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D8V]N;F5C=&EO;CL*"B`@
M("`O*BH*("`@("`J(%1H92!$4TX@:6YF;W)M871I;VX@9F]R(&-O;FYE8W1I
M;F<@=&\@82!D871A8F%S90H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)&1S;B`](&%R<F%Y*"D["@H*("`@("\J*@H@("`@("H@4VAO=6QD
M(&1A=&$@;6%N:7!U;&%T:6]N('%U97)I97,@8F4@8V]M;6ET=&5D(&%U=&]M
M871I8V%L;'D_"B`@("`@*B!`=F%R(&)O;VP*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("HO"B`@("!V87(@)&%U=&]C;VUM:70@/2!T<G5E.PH*("`@
M("\J*@H@("`@("H@5&AE('%U86YT:71Y(&]F('1R86YS86-T:6]N<R!B96=U
M;@H@("`@("H*("`@("`J('M`:6YT97)N86P@(%=H:6QE('1H:7,@:7,@<')I
M=F%T92P@:70@8V%N)W0@86-T=6%L;'D@8F4@9&5S:6=N871E9`H@("`@("H@
M<')I=F%T92!I;B!02%`@-2!B96-A=7-E(&ET(&ES(&1I<F5C=&QY(&%C8V5S
M<V5D(&EN('1H92!T97-T('-U:71E+GU]"B`@("`@*@H@("`@("H@0'9A<B!I
M;G1E9V5R"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R
M("1T<F%N<V%C=&EO;E]O<&-O=6YT(#T@,#L*"B`@("`O*BH*("`@("`J(%1H
M92!N=6UB97(@;V8@<F]W<R!A9F9E8W1E9"!B>2!A(&1A=&$@;6%N:7!U;&%T
M:6]N('%U97)Y"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!V87(@)&%F9F5C=&5D(#T@,#L*"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@8V]N<W1R=6-T;W(*"B`@("`O*BH*("`@("`J
M(%1H:7,@8V]N<W1R=6-T;W(@8V%L;',@/&MB9#XD=&AI<RT^1$)?8V]M;6]N
M*"D\+VMB9#X*("`@("`J"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@
M("`@9G5N8W1I;VX@1$)?:69X*"D*("`@('L*("`@("`@("`D=&AI<RT^1$)?
M8V]M;6]N*"D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]N;F5C
M="@I"@H@("`@+RHJ"B`@("`@*B!#;VYN96-T('1O('1H92!D871A8F%S92!S
M97)V97(L(&QO9R!I;B!A;F0@;W!E;B!T:&4@9&%T86)A<V4*("`@("`J"B`@
M("`@*B!$;VXG="!C86QL('1H:7,@;65T:&]D(&1I<F5C=&QY+B`@57-E($1"
M.CIC;VYN96-T*"D@:6YS=&5A9"X*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)&1S;B`@("`@("`@('1H92!D871A('-O=7)C92!N86UE"B`@("`@*B!`
M<&%R86T@8F]O;"`@)'!E<G-I<W1E;G0@('-H;W5L9"!T:&4@8V]N;F5C=&EO
M;B!B92!P97)S:7-T96YT/PH@("`@("H*("`@("`J($!R971U<FX@:6YT("!$
M0E]/2R!O;B!S=6-C97-S+B!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VYN96-T*"1D<VXL("1P97)S:7-T
M96YT(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"%014%2.CIL;V%D17AT
M96YS:6]N*"=I;F9O<FUI>"<I("8F"B`@("`@("`@("`@("%014%2.CIL;V%D
M17AT96YS:6]N*"=);F9O<FUI>"<I*0H@("`@("`@('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27T585$5.4TE/3E].
M3U1?1D]53D0I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/F1S;B`]("1D
M<VX["B`@("`@("`@:68@*"1D<VY;)V1B<WEN=&%X)UTI('L*("`@("`@("`@
M("`@)'1H:7,M/F1B<WEN=&%X(#T@)&1S;ELG9&)S>6YT87@G73L*("`@("`@
M("!]"@H@("`@("`@("1D8FAO<W0@/2`D9'-N6R=H;W-T<W!E8R==(#\@)T`G
M("X@)&1S;ELG:&]S='-P96,G72`Z("<G.PH@("`@("`@("1D8FYA;64@/2`D
M9'-N6R=D871A8F%S92==(#\@)&1S;ELG9&%T86)A<V4G72`N("1D8FAO<W0@
M.B`G)SL*("`@("`@("`D=7-E<B`]("1D<VY;)W5S97)N86UE)UT@/R`D9'-N
M6R=U<V5R;F%M92==(#H@)R<["B`@("`@("`@)'!W(#T@)&1S;ELG<&%S<W=O
M<F0G72`_("1D<VY;)W!A<W-W;W)D)UT@.B`G)SL*"B`@("`@("`@)&-O;FYE
M8W1?9G5N8W1I;VX@/2`D<&5R<VES=&5N="`_("=I9GA?<&-O;FYE8W0G(#H@
M)VEF>%]C;VYN96-T)SL*"B`@("`@("`@)'1H:7,M/F-O;FYE8W1I;VX@/2!`
M)&-O;FYE8W1?9G5N8W1I;VXH)&1B;F%M92P@)'5S97(L("1P=RD["B`@("`@
M("`@:68@*"%I<U]R97-O=7)C92@D=&AI<RT^8V]N;F5C=&EO;BDI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YI9GA286ES945R<F]R*$1"7T524D]2
M7T-/3DY%0U1?1D%)3$5$*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"
M7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&1I<V-O;FYE8W0H
M*0H*("`@("\J*@H@("`@("H@1&ES8V]N;F5C=',@9G)O;2!T:&4@9&%T86)A
M<V4@<V5R=F5R"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L("!44E5%(&]N
M('-U8V-E<W,L($9!3%-%(&]N(&9A:6QU<F4*("`@("`J+PH@("`@9G5N8W1I
M;VX@9&ES8V]N;F5C="@I"B`@("!["B`@("`@("`@)')E="`]($!I9GA?8VQO
M<V4H)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@("1T:&ES+3YC;VYN96-T
M:6]N(#T@;G5L;#L*("`@("`@("!R971U<FX@)')E=#L*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!S:6UP;&51=65R>2@I"@H@("`@+RHJ"B`@("`@
M*B!396YD<R!A('%U97)Y('1O('1H92!D871A8F%S92!S97)V97(*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("!T:&4@4U%,('%U97)Y('-T<FEN9PH@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@("L@82!02%`@<F5S=6QT(')E
M<W)O=6-E(&9O<B!S=6-C97-S9G5L(%-%3$5#5"!Q=65R:65S"B`@("`@*B`@
M("`@("`@("`@("`@("`K('1H92!$0E]/2R!C;VYS=&%N="!F;W(@;W1H97(@
M<W5C8V5S<V9U;"!Q=65R:65S"B`@("`@*B`@("`@("`@("`@("`@("`K(&$@
M1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4*("`@("`J+PH@("`@9G5N8W1I
M;VX@<VEM<&QE475E<GDH)'%U97)Y*0H@("`@>PH@("`@("`@("1I<VUA;FEP
M(#T@1$(Z.FES36%N:7`H)'%U97)Y*3L*("`@("`@("`D=&AI<RT^;&%S=%]Q
M=65R>2`]("1Q=65R>3L*("`@("`@("`D=&AI<RT^869F96-T960@("`](&YU
M;&P["B`@("`@("`@:68@*'!R96=?;6%T8V@H)R\H4T5,14-4*2]I)RP@)'%U
M97)Y*2D@>R`@("`O+U1%4U1-13H@57-E("%$0CHZ:7--86YI<"@I/PH@("`@
M("`@("`@("`O+R!T:&4@<V-R;VQL(&ES(&YE961E9"!F;W(@9F5T8VAI;F<@
M86)S;VQU=&4@<F]W(&YU;6)E<G,*("`@("`@("`@("`@+R\@:6X@82!S96QE
M8W0@<75E<GD@<F5S=6QT"B`@("`@("`@("`@("1R97-U;'0@/2!`:69X7W%U
M97)Y*"1Q=65R>2P@)'1H:7,M/F-O;FYE8W1I;VXL($E&6%]30U)/3$PI.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@A)'1H:7,M/F%U=&]C
M;VUM:70@)B8@)&ES;6%N:7`I('L*("`@("`@("`@("`@("`@(&EF("@D=&AI
M<RT^=')A;G-A8W1I;VY?;W!C;W5N="`]/2`P*2!["B`@("`@("`@("`@("`@
M("`@("`@)')E<W5L="`]($!I9GA?<75E<GDH)T)%1TE.(%=/4DLG+"`D=&AI
M<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@("`@("`@("`@:68@*"$D<F5S
M=6QT*2!["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M:69X4F%I<V5%<G)O<B@I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1T:&ES+3YT<F%N<V%C=&EO
M;E]O<&-O=6YT*RL["B`@("`@("`@("`@('T*("`@("`@("`@("`@)')E<W5L
M="`]($!I9GA?<75E<GDH)'%U97)Y+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@
M("`@("`@?0H@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/FEF>%)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@
M("`@)'1H:7,M/F%F9F5C=&5D(#T@0&EF>%]A9F9E8W1E9%]R;W=S*"1R97-U
M;'0I.PH@("`@("`@("\O($1E=&5R;6EN92!W:&EC:"!Q=65R:65S('-H;W5L
M9"!R971U<FX@9&%T82P@86YD('=H:6-H"B`@("`@("`@+R\@<VAO=6QD(')E
M='5R;B!A;B!E<G)O<B!C;V1E(&]N;'DN"B`@("`@("`@:68@*'!R96=?;6%T
M8V@H)R\H4T5,14-4*2]I)RP@)'%U97)Y*2D@>PH@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("!]"B`@("`@("`@+R\@6%A8(%1E<W1M93H@
M9G)E92!R97-U;'1S(&EN<VED92!A('1R86YS86-T:6]N"B`@("`@("`@+R\@
M;6%Y(&-A=7-E('1O('-T;W`@:70@86YD(&-O;6UI="!T:&4@=V]R:S\*"B`@
M("`@("`@+R\@4F5S=6QT(&AA<R!T;R!B92!F<F5E9"!E=F5N('=I=&@@82!I
M;G-E<G0@;W(@=7!D871E"B`@("`@("`@0&EF>%]F<F5E7W)E<W5L="@D<F5S
M=6QT*3L*"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[(&YE>'1297-U;'0H*0H*("`@("\J*@H@("`@("H@36]V
M92!T:&4@:6YT97)N86P@:69X(')E<W5L="!P;VEN=&5R('1O('1H92!N97AT
M(&%V86EL86)L92!R97-U;'0*("`@("`J"B`@("`@*B!`<&%R86T@82!V86QI
M9"!F8G-Q;"!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("H*("`@("`J($!R971U<FX@=')U92!I9B!A(')E<W5L
M="!I<R!A=F%I;&%B;&4@;W1H97)W:7-E(')E='5R;B!F86QS90H@("`@("HO
M"B`@("!F=6YC=&EO;B!N97AT4F5S=6QT*"1R97-U;'0I"B`@("!["B`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&%F9F5C=&5D4F]W<R@I"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S('1H
M92!N=6UB97(@;V8@<F]W<R!A9F9E8W1E9"!B>2!A(&1A=&$@;6%N:75P;&%T
M:6]N('%U97)Y"B`@("`@*@H@("`@("H@,"!I<R!R971U<FYE9"!F;W(@<75E
M<FEE<R!T:&%T(&1O;B=T(&UA;FEP=6QA=&4@9&%T82X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!R;W=S+B`@02!$0E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@869F
M96-T9612;W=S*"D*("`@('L*("`@("`@("!I9B`H1$(Z.FES36%N:7`H)'1H
M:7,M/FQA<W1?<75E<GDI*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M869F96-T960["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M(#`["B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&9E
M=&-H26YT;R@I"@H@("`@+RHJ"B`@("`@*B!0;&%C97,@82!R;W<@9G)O;2!T
M:&4@<F5S=6QT('-E="!I;G1O('1H92!G:79E;B!A<G)A>0H@("`@("H*("`@
M("`J($9O<FUA=&EN9R!O9B!T:&4@87)R87D@86YD('1H92!D871A('1H97)E
M:6X@87)E(&-O;F9I9W5R86)L92X*("`@("`J(%-E92!$0E]R97-U;'0Z.F9E
M=&-H26YT;R@I(&9O<B!M;W)E(&EN9F]R;6%T:6]N+@H@("`@("H*("`@("`J
M(%1H:7,@;65T:&]D(&ES(&YO="!M96%N="!T;R!B92!C86QL960@9&ER96-T
M;'DN("!5<V4*("`@("`J($1"7W)E<W5L=#HZ9F5T8VA);G1O*"D@:6YS=&5A
M9"X@($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B
M96-A=7-E($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J
M"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@("!T:&4@<75E<GD@
M<F5S=6QT(')E<V]U<F-E"B`@("`@*B!`<&%R86T@87)R87D@("`@)&%R<B`@
M("`@("!T:&4@<F5F97)E;F-E9"!A<G)A>2!T;R!P=70@=&AE(&1A=&$@:6X*
M("`@("`J($!P87)A;2!I;G0@("`@("`D9F5T8VAM;V1E(&AO=R!T:&4@<F5S
M=6QT:6YG(&%R<F%Y('-H;W5L9"!B92!I;F1E>&5D"B`@("`@*B!`<&%R86T@
M:6YT("`@("`@)')O=VYU;2`@("!T:&4@<F]W(&YU;6)E<B!T;R!F971C:"`H
M,"`](&9I<G-T(')O=RD*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!$
M0E]/2R!O;B!S=6-C97-S+"!.54Q,('=H96X@=&AE(&5N9"!O9B!A(')E<W5L
M="!S970@:7,*("`@("`J("`@("`@("`@("`@("`@("!R96%C:&5D(&]R(&]N
M(&9A:6QU<F4*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ9F5T8VA)
M;G1O*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9F5T8VA);G1O*"1R97-U;'0L
M("8D87)R+"`D9F5T8VAM;V1E+"`D<F]W;G5M(#T@;G5L;"D*("`@('L*("`@
M("`@("!I9B`H*"1R;W=N=6T@(3T](&YU;&PI("8F("@D<F]W;G5M(#P@,"DI
M('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H@("`@("`@
M(&EF("@D<F]W;G5M(#T]/2!N=6QL*2!["B`@("`@("`@("`@("\J"B`@("`@
M("`@("`@("`J($5V96X@=&AO=6=H(&9E=&-H7W)O=R@I('-H;W5L9"!R971U
M<FX@=&AE(&YE>'0@<F]W("!I9@H@("`@("`@("`@("`@*B`D<F]W;G5M(&ES
M(&YU;&PL(&ET(&1O97-N)W0@:6X@86QL(&-A<V5S+B`@0G5G(#4Y."X*("`@
M("`@("`@("`@("HO"B`@("`@("`@("`@("1R;W=N=6T@/2`G3D585"<["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@26YD97@@<W1A<G1S(&%T
M(')O=R`Q+"!U;FQI:V4@;6]S="!$0DU3)W,@<W1A<G1I;F<@870@,"X*("`@
M("`@("`@("`@)')O=VYU;2LK.PH@("`@("`@('T*("`@("`@("!I9B`H(21A
M<G(@/2!`:69X7V9E=&-H7W)O=R@D<F5S=6QT+"`D<F]W;G5M*2D@>PH@("`@
M("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("`@("`@:68@*"1F
M971C:&UO9&4@(3T]($1"7T9%5$-(34]$15]!4U-/0RD@>PH@("`@("`@("`@
M("`D:3TP.PH@("`@("`@("`@("`D;W)D97(@/2!A<G)A>2@I.PH@("`@("`@
M("`@("!F;W)E86-H("@D87)R(&%S("1V86PI('L*("`@("`@("`@("`@("`@
M("1O<F1E<ELD:2LK72`]("1V86P["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)&%R<B`]("1O<F1E<CL*("`@("`@("!](&5L<V5I9B`H)&9E=&-H;6]D
M92`]/2!$0E]&151#2$U/1$5?05-33T,@)B8*("`@("`@("`@("`@("`@("`@
M)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E4
M65],3U=%4D-!4T4I"B`@("`@("`@>PH@("`@("`@("`@("`D87)R(#T@87)R
M87E?8VAA;F=E7VME>5]C87-E*"1A<G(L($-!4T5?3$]715(I.PH@("`@("`@
M('T*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@
M)B!$0E]03U)404))3$E465]25%))32D@>PH@("`@("`@("`@("`D=&AI<RT^
M7W)T<FEM07)R87E686QU97,H)&%R<BD["B`@("`@("`@?0H@("`@("`@(&EF
M("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,
M25197TY53$Q?5$]?14U05%DI('L*("`@("`@("`@("`@)'1H:7,M/E]C;VYV
M97)T3G5L;$%R<F%Y5F%L=65S5&]%;7!T>2@D87)R*3L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&YU;4-O;',H*0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@;G5M8F5R
M(&]F(&-O;'5M;G,@:6X@82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@5&AI
M<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@
M(%5S90H@("`@("H@1$)?<F5S=6QT.CIN=6U#;VQS*"D@:6YS=&5A9"X@($ET
M(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E
M($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@
M*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@<75E<GD@<F5S=6QT
M(')E<V]U<F-E"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB
M97(@;V8@8V]L=6UN<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N
M"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.FYU;4-O;',H*0H@("`@
M("HO"B`@("!F=6YC=&EO;B!N=6U#;VQS*"1R97-U;'0I"B`@("!["B`@("`@
M("`@:68@*"$D8V]L<R`]($!I9GA?;G5M7V9I96QD<R@D<F5S=6QT*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/FEF>%)A:7-E17)R;W(H*3L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("1C;VQS.PH@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[(&9R965297-U;'0H*0H*("`@("\J*@H@("`@("H@1&5L
M971E<R!T:&4@<F5S=6QT('-E="!A;F0@9G)E97,@=&AE(&UE;6]R>2!O8V-U
M<&EE9"!B>2!T:&4@<F5S=6QT('-E=`H@("`@("H*("`@("`J(%1H:7,@;65T
M:&]D(&ES(&YO="!M96%N="!T;R!B92!C86QL960@9&ER96-T;'DN("!5<V4*
M("`@("`J($1"7W)E<W5L=#HZ9G)E92@I(&EN<W1E860N("!)="!C86XG="!B
M92!D96-L87)E9"`B<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U
M;'0@:7,@82!S97!A<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M
M(')E<V]U<F-E("1R97-U;'0@(%!(4"=S('%U97)Y(')E<W5L="!R97-O=7)C
M90H@("`@("H*("`@("`J($!R971U<FX@8F]O;"`@5%)512!O;B!S=6-C97-S
M+"!&04Q312!I9B`D<F5S=6QT(&ES(&EN=F%L:60*("`@("`J"B`@("`@*B!`
M<V5E($1"7W)E<W5L=#HZ9G)E92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&9R
M965297-U;'0H)')E<W5L="D*("`@('L*("`@("`@("!R971U<FX@0&EF>%]F
M<F5E7W)E<W5L="@D<F5S=6QT*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!A=71O0V]M;6ET*"D*"B`@("`O*BH*("`@("`J($5N86)L97,@;W(@
M9&ES86)L97,@875T;VUA=&EC(&-O;6UI=',*("`@("`J"B`@("`@*B!`<&%R
M86T@8F]O;"`D;VYO9F8@('1R=64@='5R;G,@:70@;VXL(&9A;'-E('1U<FYS
M(&ET(&]F9@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S
M=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@:68@=&AE(&1R:79E<@H@("`@
M("H@("`@("`@("`@("`@("!D;V5S;B=T('-U<'!O<G0@875T;RUC;VUM:71T
M:6YG('1R86YS86-T:6]N<RX*("`@("`J+PH@("`@9G5N8W1I;VX@875T;T-O
M;6UI="@D;VYO9F8@/2!T<G5E*0H@("`@>PH@("`@("`@("\O(%A86"!I9B`D
M=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`^(#`L('=E('-H;W5L9"!P<F]B
M86)L>0H@("`@("`@("\O(&ES<W5E(&$@=V%R;FEN9R!H97)E+@H@("`@("`@
M("1T:&ES+3YA=71O8V]M;6ET(#T@)&]N;V9F(#\@=')U92`Z(&9A;'-E.PH@
M("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!C;VUM:70H*0H*("`@("\J*@H@("`@("H@0V]M;6ET<R!T:&4@8W5R
M<F5N="!T<F%N<V%C=&EO;@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$
M0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]M;6ET*"D*("`@('L*("`@("`@
M("!I9B`H)'1H:7,M/G1R86YS86-T:6]N7V]P8V]U;G0@/B`P*2!["B`@("`@
M("`@("`@("1R97-U;'0@/2!`:69X7W%U97)Y*"=#3TU-250@5T]22R<L("1T
M:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`@("`@)'1H:7,M/G1R86YS86-T
M:6]N7V]P8V]U;G0@/2`P.PH@("`@("`@("`@("!I9B`H(21R97-U;'0I('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^:69X4F%I<V5%<G)O<B@I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/
M2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!R;VQL8F%C:R@I"@H@
M("`@+RHJ"B`@("`@*B!2979E<G1S('1H92!C=7)R96YT('1R86YS86-T:6]N
M"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N
M("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!R;VQL8F%C:R@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YT
M<F%N<V%C=&EO;E]O<&-O=6YT(#X@,"D@>PH@("`@("`@("`@("`D<F5S=6QT
M(#T@0&EF>%]Q=65R>2@G4D],3$)!0TL@5T]22R<L("1T:&ES+3YC;VYN96-T
M:6]N*3L*("`@("`@("`@("`@)'1H:7,M/G1R86YS86-T:6]N7V]P8V]U;G0@
M/2`P.PH@("`@("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^:69X4F%I<V5%<G)O<B@I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!I9GA286ES945R<F]R*"D*"B`@("`O*BH*
M("`@("`J(%!R;V1U8V5S(&$@1$)?17)R;W(@;V)J96-T(')E9V%R9&EN9R!T
M:&4@8W5R<F5N="!P<F]B;&5M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`D
M97)R;F\@(&EF('1H92!E<G)O<B!I<R!B96EN9R!M86YU86QL>2!R86ES960@
M<&%S<R!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@($1"7T524D]2*B!C
M;VYS=&%N="!H97)E+B`@268@=&AI<R!I<VXG="!P87-S960*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@=&AE(&5R<F]R(&EN9F]R;6%T:6]N(&=A=&AE
M<F5D(&9R;VT@=&AE($1"35,N"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE
M8W0@('1H92!$0E]%<G)O<B!O8FIE8W0*("`@("`J"B`@("`@*B!`<V5E($1"
M7V-O;6UO;CHZ<F%I<V5%<G)O<B@I+`H@("`@("H@("`@("!$0E]I9G@Z.F5R
M<F]R3F%T:79E*"DL($1"7VEF>#HZ97)R;W)#;V1E*"D*("`@("`J+PH@("`@
M9G5N8W1I;VX@:69X4F%I<V5%<G)O<B@D97)R;F\@/2!N=6QL*0H@("`@>PH@
M("`@("`@(&EF("@D97)R;F\@/3T](&YU;&PI('L*("`@("`@("`@("`@)&5R
M<FYO(#T@)'1H:7,M/F5R<F]R0V]D92AI9GA?97)R;W(H*2D["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D97)R;F\L(&YU
M;&PL(&YU;&PL(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YE<G)O<DYA=&EV92@I*3L*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!E<G)O<DYA=&EV92@I"@H@("`@+RHJ"B`@("`@*B!'971S
M('1H92!$0DU3)R!N871I=F4@97)R;W(@8V]D92!A;F0@;65S<V%G92!P<F]D
M=6-E9"!B>2!T:&4@;&%S="!Q=65R>0H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!T:&4@1$)-4R<@97)R;W(@8V]D92!A;F0@;65S<V%G90H@("`@
M("HO"B`@("!F=6YC=&EO;B!E<G)O<DYA=&EV92@I"B`@("!["B`@("`@("`@
M<F5T=7)N($!I9GA?97)R;W(H*2`N("<@)R`N($!I9GA?97)R;W)M<V<H*3L*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!E<G)O<D-O9&4H*0H*("`@
M("\J*@H@("`@("H@36%P<R!N871I=F4@97)R;W(@8V]D97,@=&\@1$(G<R!P
M;W)T86)L92!O;F5S+@H@("`@("H*("`@("`J(%)E<75I<F5S('1H870@=&AE
M($1"(&EM<&QE;65N=&%T:6]N)W,@8V]N<W1R=6-T;W(@9FEL;',*("`@("`J
M(&EN('1H92`\=F%R/B1E<G)O<F-O9&5?;6%P/"]V87(^('!R;W!E<G1Y+@H@
M("`@("H*("`@("`J($!P87)A;2`@<W1R:6YG("`D;F%T:79E8V]D92`@97)R
M;W(@8V]D92!R971U<FYE9"!B>2!T:&4@9&%T86)A<V4*("`@("`J($!R971U
M<FX@:6YT(&$@<&]R=&%B;&4@1$(@97)R;W(@8V]D92P@;W(@1$)?15)23U(@
M:68@=&AI<R!$0@H@("`@("H@:6UP;&5M96YT871I;VX@:&%S(&YO(&UA<'!I
M;F<@9F]R('1H92!G:79E;B!E<G)O<B!C;V1E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!E<G)O<D-O9&4H)&YA=&EV96-O9&4I"B`@("!["B`@("`@("`@:68@
M*&5R96<H)U-13$-/1$4]*"XJ*5TG+"`D;F%T:79E8V]D92P@)&UA=&-H*2D@
M>PH@("`@("`@("`@("`D8V]D92`]("1M871C:%LQ73L*("`@("`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3YE<G)O<F-O9&5?;6%P6R1C;V1E72DI('L*("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^97)R;W)C;V1E7VUA<%LD8V]D
M95T["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"
M7T524D]2.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('1A8FQE26YF
M;R@I"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&EN9F]R;6%T:6]N(&%B;W5T
M(&$@=&%B;&4@;W(@82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@3D]413H@
M;VYL>2!S=7!P;W)T<R`G=&%B;&4G(&EF(#QV87(^)')E<W5L=#PO=F%R/B!I
M<R!A('1A8FQE(&YA;64N"B`@("`@*@H@("`@("H@268@86YA;'EZ:6YG(&$@
M<75E<GD@<F5S=6QT(&%N9"!T:&4@<F5S=6QT(&AA<R!D=7!L:6-A=&4@9FEE
M;&0@;F%M97,L"B`@("`@*B!A;B!E<G)O<B!W:6QL(&)E(')A:7-E9"!S87EI
M;F<*("`@("`J(#QS86UP/F-A;B=T(&1I<W1I;F=U:7-H(&1U<&QI8V%T92!F
M:65L9"!N86UE<SPO<V%M<#XN"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C
M='QS=')I;F<@("1R97-U;'0@($1"7W)E<W5L="!O8FIE8W0@9G)O;2!A('%U
M97)Y(&]R(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<W1R:6YG(&-O;G1A:6YI;F<@=&AE(&YA;64@;V8@82!T86)L92X*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@5VAI;&4@=&AI
M<R!A;'-O(&%C8V5P=',@82!Q=65R>2!R97-U;'0*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@<F5S;W5R8V4@:61E;G1I9FEE<BP@
M=&AI<R!B96AA=FEO<B!I<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!D97!R96-A=&5D+@H@("`@("H@0'!A<F%M(&EN="`@("`@
M("`@("`@("1M;V1E("`@(&$@=F%L:60@=&%B;&5);F9O(&UO9&4*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!A;B!A<W-O8VEA=&EV92!A<G)A>2!W
M:71H('1H92!I;F9O<FUA=&EO;B!R97%U97-T960N"B`@("`@*B`@("`@("`@
M("`@("`@("`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J
M"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ=&%B;&5);F9O*"D*("`@("`J($!S
M:6YC92!-971H;V0@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XV+C`*("`@
M("`J+PH@("`@9G5N8W1I;VX@=&%B;&5);F9O*"1R97-U;'0L("1M;V1E(#T@
M;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?<W1R:6YG*"1R97-U;'0I*2![
M"B`@("`@("`@("`@("\J"B`@("`@("`@("`@("`J(%!R;V)A8FQY(')E8V5I
M=F5D(&$@=&%B;&4@;F%M92X*("`@("`@("`@("`@("H@0W)E871E(&$@<F5S
M=6QT(')E<V]U<F-E(&ED96YT:69I97(N"B`@("`@("`@("`@("`J+PH@("`@
M("`@("`@("`D:60@/2!`:69X7W%U97)Y*")314Q%0U0@*B!&4D]-("1R97-U
M;'0@5TA%4D4@,3TP(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@("1G;W1?<W1R:6YG(#T@
M=')U93L*("`@("`@("!](&5L<V5I9B`H:7-S970H)')E<W5L="T^<F5S=6QT
M*2D@>PH@("`@("`@("`@("`O*@H@("`@("`@("`@("`@*B!0<F]B86)L>2!R
M96-E:79E9"!A(')E<W5L="!O8FIE8W0N"B`@("`@("`@("`@("`J($5X=')A
M8W0@=&AE(')E<W5L="!R97-O=7)C92!I9&5N=&EF:65R+@H@("`@("`@("`@
M("`@*B\*("`@("`@("`@("`@)&ED(#T@)')E<W5L="T^<F5S=6QT.PH@("`@
M("`@("`@("`D9V]T7W-T<FEN9R`](&9A;'-E.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("\J"B`@("`@("`@("`@("`J(%!R;V)A8FQY(')E8V5I
M=F5D(&$@<F5S=6QT(')E<V]U<F-E(&ED96YT:69I97(N"B`@("`@("`@("`@
M("`J($-O<'D@:70N"B`@("`@("`@("`@("`J+PH@("`@("`@("`@("`D:60@
M/2`D<F5S=6QT.PH@("`@("`@("`@("`D9V]T7W-T<FEN9R`](&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D:60I*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^:69X4F%I<V5%<G)O<BA$0E]%4E)/
M4E].145$7TU/4D5?1$%402D["B`@("`@("`@?0H*("`@("`@("`D9FQD<R`]
M($!I9GA?9FEE;&1P<F]P97)T:65S*"1I9"D["B`@("`@("`@)&-O=6YT(#T@
M0&EF>%]N=6U?9FEE;&1S*"1I9"D["@H@("`@("`@(&EF("AC;W5N="@D9FQD
M<RD@(3T@)&-O=6YT*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@B8V%N)W0@9&ES=&EN9W5I<V@@9'5P;&EC871E(&9I96QD(&YA
M;65S(BD["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;
M)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465],3U=%4D-!4T4I('L*
M("`@("`@("`@("`@)&-A<V5?9G5N8R`]("=S=')T;VQO=V5R)SL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D8V%S95]F=6YC(#T@)W-T<G9A;"<[
M"B`@("`@("`@?0H*("`@("`@("`D:2`@(#T@,#L*("`@("`@("`D<F5S(#T@
M87)R87DH*3L*"B`@("`@("`@:68@*"1M;V1E*2!["B`@("`@("`@("`@("1R
M97-;)VYU;5]F:65L9',G72`]("1C;W5N=#L*("`@("`@("!]"@H@("`@("`@
M(&9O<F5A8V@@*"1F;&1S(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@
M("`@("1P<F]P<R`](&5X<&QO9&4H)SLG+"`D=F%L=64I.PH@("`@("`@("`@
M("`D<F5S6R1I72`](&%R<F%Y*`H@("`@("`@("`@("`@("`@)W1A8FQE)R`]
M/B`D9V]T7W-T<FEN9R`_("1C87-E7V9U;F,H)')E<W5L="D@.B`G)RP*("`@
M("`@("`@("`@("`@("=N86UE)R`@/3X@)&-A<V5?9G5N8R@D:V5Y*2P*("`@
M("`@("`@("`@("`@("=T>7!E)R`@/3X@)'!R;W!S6S!=+`H@("`@("`@("`@
M("`@("`@)VQE;B<@("`]/B`D<')O<'-;,5TL"B`@("`@("`@("`@("`@("`G
M9FQA9W,G(#T^("1P<F]P<ULT72`]/2`G3B<@/R`G;F]T7VYU;&PG(#H@)R<L
M"B`@("`@("`@("`@("D["B`@("`@("`@("`@(&EF("@D;6]D92`F($1"7U1!
M0DQ%24Y&3U]/4D1%4BD@>PH@("`@("`@("`@("`@("`@)')E<ULG;W)D97(G
M75LD<F5S6R1I75LG;F%M92==72`]("1I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&EF("@D;6]D92`F($1"7U1!0DQ%24Y&3U]/4D1%4E1!0DQ%*2![
M"B`@("`@("`@("`@("`@("`D<F5S6R=O<F1E<G1A8FQE)UU;)')E<ULD:5U;
M)W1A8FQE)UU=6R1R97-;)&E=6R=N86UE)UU=(#T@)&D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)&DK*SL*("`@("`@("!]"@H@("`@("`@("\O(&9R
M964@=&AE(')E<W5L="!O;FQY(&EF('=E('=E<F4@8V%L;&5D(&]N(&$@=&%B
M;&4*("`@("`@("!I9B`H)&=O=%]S=')I;F<I('L*("`@("`@("`@("`@0&EF
M>%]F<F5E7W)E<W5L="@D:60I.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M)')E<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G9713<&5C:6%L
M475E<GDH*0H*("`@("\J*@H@("`@("H@3V)T86EN<R!T:&4@<75E<GD@<W1R
M:6YG(&YE961E9"!F;W(@;&ES=&EN9R!A(&=I=F5N('1Y<&4@;V8@;V)J96-T
M<PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@('1H92!K:6YD
M(&]F(&]B:F5C=',@>6]U('=A;G0@=&\@<F5T<FEE=F4*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@=&AE(%-13"!Q=65R>2!S=')I;F<@;W(@;G5L
M;"!I9B!T:&4@9')I=F5R(&1O97-N)W0*("`@("`J("`@("`@("`@("`@("`@
M("`@<W5P<&]R="!T:&4@;V)J96-T('1Y<&4@<F5Q=65S=&5D"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J($!S964@1$)?8V]M;6]N
M.CIG971,:7-T3V8H*0H@("`@("HO"B`@("!F=6YC=&EO;B!G9713<&5C:6%L
M475E<GDH)'1Y<&4I"B`@("!["B`@("`@("`@<W=I=&-H("@D='EP92D@>PH@
M("`@("`@("`@("!C87-E("=T86)L97,G.@H@("`@("`@("`@("`@("`@<F5T
M=7)N("=314Q%0U0@=&%B;F%M92!&4D]-('-Y<W1A8FQE<R!72$5212!T86)I
M9"`^/2`Q,#`G.PH@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@
M("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H*
M?0H*+RH*("H@3&]C86P@=F%R:6%B;&5S.@H@*B!T86(M=VED=&@Z(#0*("H@
M8RUB87-I8RUO9F9S970Z(#0*("H@16YD.@H@*B\*"C\^"@``````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O1$(O;7-Q;"YP:'``````````````````
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`U-C4U,B`Q,#4Q-30S
M,S<S,2`P,C`T-3,`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P
M/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO"@HO*BH*("H@5&AE
M(%!%05(@1$(@9')I=F5R(&9O<B!02%`G<R!M<W%L(&5X=&5N<VEO;@H@*B!F
M;W(@:6YT97)A8W1I;F<@=VET:"!-:6YI(%-13"!D871A8F%S97,*("H*("H@
M4$A0)W,@;5-13"!E>'1E;G-I;VX@9&ED('=E:7)D('1H:6YG<R!W:71H($Y5
M3$P@=F%L=65S('!R:6]R('1O(%!(4`H@*B`T+C,N,3$@86YD(#4N,"XT+B`@
M36%K92!S=7)E('EO=7(@=F5R<VEO;B!O9B!02%`@;65E=',@;W(@97AC965D
M<PH@*B!T:&]S92!V97)S:6]N<RX*("H*("H@4$A0('9E<G-I;VYS(#0@86YD
M(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T
M('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90H@*B!T:&%T(&ES
M(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@
M9F]L;&]W:6YG(%5223H*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F"B`J
M('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@
M=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*("H@<V5N9"!A(&YO=&4@=&\@;&EC
M96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I
M871E;'DN"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E"B`J($!P86-K86=E
M("`@($1""B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE
M;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@
M1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@($-6
M4SH@)$ED.B!M<W%L+G!H<"QV(#$N-3<@,C`P-2\P,B\R,B`P-SHR-CHT-B!D
M86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN
M970O<&%C:V%G92]$0@H@*B\*"B\J*@H@*B!/8G1A:6X@=&AE($1"7V-O;6UO
M;B!C;&%S<R!S;R!I="!C86X@8F4@97AT96YD960@9G)O;0H@*B\*<F5Q=6ER
M95]O;F-E("=$0B]C;VUM;VXN<&AP)SL*"B\J*@H@*B!4:&4@;65T:&]D<R!0
M14%2($1"('5S97,@=&\@:6YT97)A8W0@=VET:"!02%`G<R!M<W%L(&5X=&5N
M<VEO;@H@*B!F;W(@:6YT97)A8W1I;F<@=VET:"!-:6YI(%-13"!D871A8F%S
M97,*("H*("H@5&AE<V4@;65T:&]D<R!O=F5R;&]A9"!T:&4@;VYE<R!D96-L
M87)E9"!I;B!$0E]C;VUM;VXN"B`J"B`J(%!(4"=S(&U344P@97AT96YS:6]N
M(&1I9"!W96ER9"!T:&EN9W,@=VET:"!.54Q,('9A;'5E<R!P<FEO<B!T;R!0
M2%`*("H@-"XS+C$Q(&%N9"`U+C`N-"X@($UA:V4@<W5R92!Y;W5R('9E<G-I
M;VX@;V8@4$A0(&UE971S(&]R(&5X8V5E9',*("H@=&AO<V4@=F5R<VEO;G,N
M"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E"B`J($!P86-K86=E("`@($1"
M"B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP
M+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*
M("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z
M(#$N-RXV"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]$0@H@*B!`<VEN8V4@("`@("!#;&%S<R!N;W0@9G5N8W1I;VYA;"!U
M;G1I;"!296QE87-E(#$N-RXP"B`J+PIC;&%S<R!$0E]M<W%L(&5X=&5N9',@
M1$)?8V]M;6]N"GL*("`@("\O('M[>R!P<F]P97)T:65S"@H@("`@+RHJ"B`@
M("`@*B!4:&4@1$(@9')I=F5R('1Y<&4@*&UY<W%L+"!O8VDX+"!O9&)C+"!E
M=&,N*0H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1P:'!T
M>7!E(#T@)VUS<6PG.PH*("`@("\J*@H@("`@("H@5&AE(&1A=&%B87-E('-Y
M;G1A>"!V87)I86YT('1O(&)E('5S960@*&1B,BP@86-C97-S+"!E=&,N*2P@
M:68@86YY"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)&1B
M<WEN=&%X(#T@)VUS<6PG.PH*("`@("\J*@H@("`@("H@5&AE(&-A<&%B:6QI
M=&EE<R!O9B!T:&ES($1"(&EM<&QE;65N=&%T:6]N"B`@("`@*@H@("`@("H@
M5&AE("=N97=?;&EN:R<@96QE;65N="!C;VYT86EN<R!T:&4@4$A0('9E<G-I
M;VX@=&AA="!F:7)S="!P<F]V:61E9`H@("`@("H@;F5W7VQI;FL@<W5P<&]R
M="!F;W(@=&AI<R!$0DU3+B`@0V]N=&%I;G,@9F%L<V4@:68@:70G<R!U;G-U
M<'!O<G1E9"X*("`@("`J"B`@("`@*B!-96%N:6YG(&]F('1H92`G;&EM:70G
M(&5L96UE;G0Z"B`@("`@*B`@("L@)V5M=6QA=&4G(#T@96UU;&%T92!W:71H
M(&9E=&-H(')O=R!B>2!N=6UB97(*("`@("`J("`@*R`G86QT97(G("`@/2!A
M;'1E<B!T:&4@<75E<GD*("`@("`J("`@*R!F86QS92`@("`@/2!S:VEP(')O
M=W,*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D
M9F5A='5R97,@/2!A<G)A>2@*("`@("`@("`G;&EM:70G("`@("`@("`@/3X@
M)V5M=6QA=&4G+`H@("`@("`@("=N97=?;&EN:R<@("`@("`]/B!F86QS92P*
M("`@("`@("`G;G5M<F]W<R<@("`@("`@/3X@=')U92P*("`@("`@("`G<&-O
M;FYE8W0G("`@("`@/3X@=')U92P*("`@("`@("`G<')E<&%R92<@("`@("`@
M/3X@9F%L<V4L"B`@("`@("`@)W-S;"<@("`@("`@("`@(#T^(&9A;'-E+`H@
M("`@("`@("=T<F%N<V%C=&EO;G,G("`]/B!F86QS92P*("`@("D["@H@("`@
M+RHJ"B`@("`@*B!!(&UA<'!I;F<@;V8@;F%T:79E(&5R<F]R(&-O9&5S('1O
M($1"(&5R<F]R(&-O9&5S"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@
M('9A<B`D97)R;W)C;V1E7VUA<"`](&%R<F%Y*`H@("`@*3L*"B`@("`O*BH*
M("`@("`J(%1H92!R87<@9&%T86)A<V4@8V]N;F5C=&EO;B!C<F5A=&5D(&)Y
M(%!(4`H@("`@("H@0'9A<B!R97-O=7)C90H@("`@("HO"B`@("!V87(@)&-O
M;FYE8W1I;VX["@H@("`@+RHJ"B`@("`@*B!4:&4@1%-.(&EN9F]R;6%T:6]N
M(&9O<B!C;VYN96-T:6YG('1O(&$@9&%T86)A<V4*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1D<VX@/2!A<G)A>2@I.PH*"B`@("`O*BH*
M("`@("`J(%1H92!Q=65R>2!R97-U;'0@<F5S;W5R8V4@8W)E871E9"!B>2!0
M2%`*("`@("`J"B`@("`@*B!5<V5D('1O(&UA:V4@869F96-T9612;W=S*"D@
M=V]R:RX@($]N;'D@8V]N=&%I;G,@=&AE(')E<W5L="!F;W(*("`@("`J(&1A
M=&$@;6%N:7!U;&%T:6]N('%U97)I97,N("!#;VYT86EN<R!F86QS92!F;W(@
M;W1H97(@<75E<FEE<RX*("`@("`J"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?<F5S=6QT
M.PH*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VYS=')U8W1O<@H*("`@("\J
M*@H@("`@("H@5&AI<R!C;VYS=')U8W1O<B!C86QL<R`\:V)D/B1T:&ES+3Y$
M0E]C;VUM;VXH*3PO:V)D/@H@("`@("H*("`@("`J($!R971U<FX@=F]I9`H@
M("`@("HO"B`@("!F=6YC=&EO;B!$0E]M<W%L*"D*("`@('L*("`@("`@("`D
M=&AI<RT^1$)?8V]M;6]N*"D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@8V]N;F5C="@I"@H@("`@+RHJ"B`@("`@*B!#;VYN96-T('1O('1H92!D
M871A8F%S92!S97)V97(L(&QO9R!I;B!A;F0@;W!E;B!T:&4@9&%T86)A<V4*
M("`@("`J"B`@("`@*B!$;VXG="!C86QL('1H:7,@;65T:&]D(&1I<F5C=&QY
M+B`@57-E($1".CIC;VYN96-T*"D@:6YS=&5A9"X*("`@("`J"B`@("`@*B!%
M>&%M<&QE(&]F(&AO=R!T;R!C;VYN96-T.@H@("`@("H@/&-O9&4^"B`@("`@
M*B!R97%U:7)E7V]N8V4@)T1"+G!H<"<["B`@("`@*B`*("`@("`J("\O("1D
M<VX@/2`G;7-Q;#HO+VAO<W1N86UE+V1B;F%M92<[("`O+R!U<V4@82!40U`@
M8V]N;F5C=&EO;@H@("`@("H@)&1S;B`]("=M<W%L.B\O+V1B;F%M92<[("`@
M("`@("`@("`@("\O('5S92!A('-O8VME=`H@("`@("H@)&]P=&EO;G,@/2!A
M<G)A>2@*("`@("`J("`@("`G<&]R=&%B:6QI='DG(#T^($1"7U!/4E1!0DE,
M25197T%,3"P*("`@("`J("D["B`@("`@*B`*("`@("`J("1D8B`])B!$0CHZ
M8V]N;F5C="@D9'-N+"`D;W!T:6]N<RD["B`@("`@*B!I9B`H4$5!4CHZ:7-%
M<G)O<B@D9&(I*2!["B`@("`@*B`@("`@9&EE*"1D8BT^9V5T365S<V%G92@I
M*3L*("`@("`J('T*("`@("`J(#PO8V]D93X*("`@("`J"B`@("`@*B!`<&%R
M86T@87)R87D@)&1S;B`@("`@("`@('1H92!D871A('-O=7)C92!N86UE"B`@
M("`@*B!`<&%R86T@8F]O;"`@)'!E<G-I<W1E;G0@('-H;W5L9"!T:&4@8V]N
M;F5C=&EO;B!B92!P97)S:7-T96YT/PH@("`@("H*("`@("`J($!R971U<FX@
M:6YT("!$0E]/2R!O;B!S=6-C97-S+B!!($1"7T5R<F]R(&]B:F5C="!O;B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VYN96-T*"1D<VXL("1P
M97)S:7-T96YT(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"%014%2.CIL
M;V%D17AT96YS:6]N*"=M<W%L)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*$1"7T524D]27T585$5.4TE/3E].3U1?1D]53D0I
M.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/F1S;B`]("1D<VX["B`@("`@
M("`@:68@*"1D<VY;)V1B<WEN=&%X)UTI('L*("`@("`@("`@("`@)'1H:7,M
M/F1B<WEN=&%X(#T@)&1S;ELG9&)S>6YT87@G73L*("`@("`@("!]"@H@("`@
M("`@("1P87)A;7,@/2!A<G)A>2@I.PH@("`@("`@(&EF("@D9'-N6R=H;W-T
M<W!E8R==*2!["B`@("`@("`@("`@("1P87)A;7-;72`]("1D<VY;)W!O<G0G
M70H@("`@("`@("`@("`@("`@("`@("`@("`_("1D<VY;)VAO<W1S<&5C)UT@
M+B`G+"<@+B`D9'-N6R=P;W)T)UT*("`@("`@("`@("`@("`@("`@("`@("`@
M.B`D9'-N6R=H;W-T<W!E8R==.PH@("`@("`@('T*"B`@("`@("`@)&-O;FYE
M8W1?9G5N8W1I;VX@/2`D<&5R<VES=&5N="`_("=M<W%L7W!C;VYN96-T)R`Z
M("=M<W%L7V-O;FYE8W0G.PH*("`@("`@("`D:6YI(#T@:6YI7V=E="@G=')A
M8VM?97)R;W)S)RD["B`@("`@("`@)'!H<%]E<G)O<FUS9R`]("<G.PH@("`@
M("`@(&EF("@D:6YI*2!["B`@("`@("`@("`@("1T:&ES+3YC;VYN96-T:6]N
M(#T@0&-A;&Q?=7-E<E]F=6YC7V%R<F%Y*"1C;VYN96-T7V9U;F-T:6]N+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<&%R86US*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!I;FE?<V5T*"=T<F%C:U]E<G)O<G,G+"`Q*3L*("`@("`@("`@("`@)'1H
M:7,M/F-O;FYE8W1I;VX@/2!`8V%L;%]U<V5R7V9U;F-?87)R87DH)&-O;FYE
M8W1?9G5N8W1I;VXL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1P87)A;7,I.PH@("`@("`@("`@("!I
M;FE?<V5T*"=T<F%C:U]E<G)O<G,G+"`D:6YI*3L*("`@("`@("!]"@H@("`@
M("`@(&EF("@A)'1H:7,M/F-O;FYE8W1I;VXI('L*("`@("`@("`@("`@:68@
M*"@D97)R(#T@0&US<6Q?97)R;W(H*2D@(3T@)R<I('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E]#3TY.14-4
M7T9!24Q%1"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!N=6QL+"!N=6QL+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1E<G(I.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"
M7T524D]27T-/3DY%0U1?1D%)3$5$+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&YU;&PL(&YU;&PL(&YU;&PL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!H<%]E<G)O<FUS
M9RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@A0&US
M<6Q?<V5L96-T7V1B*"1D<VY;)V1A=&%B87-E)UTL("1T:&ES+3YC;VYN96-T
M:6]N*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/FUS<6Q286ES945R
M<F]R*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!D:7-C;VYN96-T*"D*"B`@("`O*BH*
M("`@("`J($1I<V-O;FYE8W1S(&9R;VT@=&AE(&1A=&%B87-E('-E<G9E<@H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;"`@5%)512!O;B!S=6-C97-S+"!&
M04Q312!O;B!F86EL=7)E"B`@("`@*B\*("`@(&9U;F-T:6]N(&1I<V-O;FYE
M8W0H*0H@("`@>PH@("`@("`@("1R970@/2!`;7-Q;%]C;&]S92@D=&AI<RT^
M8V]N;F5C=&EO;BD["B`@("`@("`@)'1H:7,M/F-O;FYE8W1I;VX@/2!N=6QL
M.PH@("`@("`@(')E='5R;B`D<F5T.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[('-I;7!L95%U97)Y*"D*"B`@("`O*BH*("`@("`J(%-E;F1S(&$@
M<75E<GD@=&\@=&AE(&1A=&%B87-E('-E<G9E<@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@('1H92!344P@<75E<GD@<W1R:6YG"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@*R!A(%!(4"!R97-U;'0@<F5S<F]U8V4@9F]R
M('-U8V-E<W-F=6P@4T5,14-4('%U97)I97,*("`@("`J("`@("`@("`@("`@
M("`@("L@=&AE($1"7T]+(&-O;G-T86YT(&9O<B!O=&AE<B!S=6-C97-S9G5L
M('%U97)I97,*("`@("`J("`@("`@("`@("`@("`@("L@82!$0E]%<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R90H@("`@("HO"B`@("!F=6YC=&EO;B!S:6UP;&51
M=65R>2@D<75E<GDI"B`@("!["B`@("`@("`@)'1H:7,M/FQA<W1?<75E<GD@
M/2`D<75E<GD["B`@("`@("`@)'%U97)Y(#T@)'1H:7,M/FUO9&EF>5%U97)Y
M*"1Q=65R>2D["B`@("`@("`@)')E<W5L="`]($!M<W%L7W%U97)Y*"1Q=65R
M>2P@)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@(&EF("@A)')E<W5L="D@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/FUS<6Q286ES945R<F]R*"D[
M"B`@("`@("`@?0H@("`@("`@("\O($1E=&5R;6EN92!W:&EC:"!Q=65R:65S
M('1H870@<VAO=6QD(')E='5R;B!D871A+"!A;F0@=VAI8V@*("`@("`@("`O
M+R!S:&]U;&0@<F5T=7)N(&%N(&5R<F]R(&-O9&4@;VYL>2X*("`@("`@("!I
M9B`H1$(Z.FES36%N:7`H)'%U97)Y*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7W)E<W5L="`]("1R97-U;'0["B`@("`@("`@("`@(')E='5R;B!$0E]/2SL*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7W)E<W5L="`]
M(&9A;'-E.PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]
M"B`@("!]"@H*("`@("\O('U]?0H@("`@+R\@>WM[(&YE>'1297-U;'0H*0H*
M("`@("\J*@H@("`@("H@36]V92!T:&4@:6YT97)N86P@;7-Q;"!R97-U;'0@
M<&]I;G1E<B!T;R!T:&4@;F5X="!A=F%I;&%B;&4@<F5S=6QT"B`@("`@*@H@
M("`@("H@0'!A<F%M(&$@=F%L:60@9F)S<6P@<F5S=6QT(')E<V]U<F-E"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<F5T
M=7)N('1R=64@:68@82!R97-U;'0@:7,@879A:6QA8FQE(&]T:&5R=VES92!R
M971U<FX@9F%L<V4*("`@("`J+PH@("`@9G5N8W1I;VX@;F5X=%)E<W5L="@D
M<F5S=6QT*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!F971C:$EN=&\H*0H*("`@("\J*@H@("`@
M("H@4&QA8V5S(&$@<F]W(&9R;VT@=&AE(')E<W5L="!S970@:6YT;R!T:&4@
M9VEV96X@87)R87D*("`@("`J"B`@("`@*B!&;W)M871I;F<@;V8@=&AE(&%R
M<F%Y(&%N9"!T:&4@9&%T82!T:&5R96EN(&%R92!C;VYF:6=U<F%B;&4N"B`@
M("`@*B!3964@1$)?<F5S=6QT.CIF971C:$EN=&\H*2!F;W(@;6]R92!I;F9O
M<FUA=&EO;BX*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A
M;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U
M;'0Z.F9E=&-H26YT;R@I(&EN<W1E860N("!)="!C86XG="!B92!D96-L87)E
M9"`B<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@82!S
M97!A<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@4$A0)W,@;5-13"!E>'1E
M;G-I;VX@9&ED('=E:7)D('1H:6YG<R!W:71H($Y53$P@=F%L=65S('!R:6]R
M('1O(%!(4`H@("`@("H@-"XS+C$Q(&%N9"`U+C`N-"X@($UA:V4@<W5R92!Y
M;W5R('9E<G-I;VX@;V8@4$A0(&UE971S(&]R(&5X8V5E9',*("`@("`J('1H
M;W-E('9E<G-I;VYS+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D
M<F5S=6QT("`@('1H92!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J($!P
M87)A;2!A<G)A>2`@("`D87)R("`@("`@('1H92!R969E<F5N8V5D(&%R<F%Y
M('1O('!U="!T:&4@9&%T82!I;@H@("`@("H@0'!A<F%M(&EN="`@("`@("1F
M971C:&UO9&4@:&]W('1H92!R97-U;'1I;F<@87)R87D@<VAO=6QD(&)E(&EN
M9&5X960*("`@("`J($!P87)A;2!I;G0@("`@("`D<F]W;G5M("`@('1H92!R
M;W<@;G5M8F5R('1O(&9E=&-H("@P(#T@9FER<W0@<F]W*0H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@($1"7T]+(&]N('-U8V-E<W,L($Y53$P@=VAE
M;B!T:&4@96YD(&]F(&$@<F5S=6QT('-E="!I<PH@("`@("H@("`@("`@("`@
M("`@("`@(')E86-H960@;W(@;VX@9F%I;'5R90H@("`@("H*("`@("`J($!S
M964@1$)?<F5S=6QT.CIF971C:$EN=&\H*0H@("`@("HO"B`@("!F=6YC=&EO
M;B!F971C:$EN=&\H)')E<W5L="P@)B1A<G(L("1F971C:&UO9&4L("1R;W=N
M=6T@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@D<F]W;G5M("$]/2!N=6QL
M*2!["B`@("`@("`@("`@(&EF("@A0&US<6Q?9&%T85]S965K*"1R97-U;'0L
M("1R;W=N=6TI*2!["B`@("`@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H)&9E=&-H;6]D92`F
M($1"7T9%5$-(34]$15]!4U-/0RD@>PH@("`@("`@("`@("`D87)R(#T@0&US
M<6Q?9F5T8VA?87)R87DH)')E<W5L="P@35-13%]!4U-/0RD["B`@("`@("`@
M("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/
M4E1!0DE,25197TQ/5T520T%312`F)B`D87)R*2!["B`@("`@("`@("`@("`@
M("`D87)R(#T@87)R87E?8VAA;F=E7VME>5]C87-E*"1A<G(L($-!4T5?3$]7
M15(I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&%R<B`]($!M<W%L7V9E=&-H7W)O=R@D<F5S=6QT*3L*("`@("`@("!]
M"B`@("`@("`@:68@*"$D87)R*2!["B`@("`@("`@("`@(')E='5R;B!N=6QL
M.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A
M8FEL:71Y)UT@)B!$0E]03U)404))3$E465]25%))32D@>PH@("`@("`@("`@
M("`D=&AI<RT^7W)T<FEM07)R87E686QU97,H)&%R<BD["B`@("`@("`@?0H@
M("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"
M7U!/4E1!0DE,25197TY53$Q?5$]?14U05%DI('L*("`@("`@("`@("`@)'1H
M:7,M/E]C;VYV97)T3G5L;$%R<F%Y5F%L=65S5&]%;7!T>2@D87)R*3L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[(&9R965297-U;'0H*0H*("`@("\J*@H@("`@("H@1&5L
M971E<R!T:&4@<F5S=6QT('-E="!A;F0@9G)E97,@=&AE(&UE;6]R>2!O8V-U
M<&EE9"!B>2!T:&4@<F5S=6QT('-E=`H@("`@("H*("`@("`J(%1H:7,@;65T
M:&]D(&ES(&YO="!M96%N="!T;R!B92!C86QL960@9&ER96-T;'DN("!5<V4*
M("`@("`J($1"7W)E<W5L=#HZ9G)E92@I(&EN<W1E860N("!)="!C86XG="!B
M92!D96-L87)E9"`B<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U
M;'0@:7,@82!S97!A<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M
M(')E<V]U<F-E("1R97-U;'0@(%!(4"=S('%U97)Y(')E<W5L="!R97-O=7)C
M90H@("`@("H*("`@("`J($!R971U<FX@8F]O;"`@5%)512!O;B!S=6-C97-S
M+"!&04Q312!I9B`D<F5S=6QT(&ES(&EN=F%L:60*("`@("`J"B`@("`@*B!`
M<V5E($1"7W)E<W5L=#HZ9G)E92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&9R
M965297-U;'0H)')E<W5L="D*("`@('L*("`@("`@("!R971U<FX@0&US<6Q?
M9G)E95]R97-U;'0H)')E<W5L="D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@;G5M0V]L<R@I"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!N=6UB
M97(@;V8@8V]L=6UN<R!I;B!A(')E<W5L="!S970*("`@("`J"B`@("`@*B!4
M:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY
M+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z.FYU;4-O;',H*2!I;G-T96%D+B`@
M270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*("`@("`J(&)E8V%U
M<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@("`@("H*("`@
M("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT("!02%`G<R!Q=65R>2!R97-U
M;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YU
M;6)E<B!O9B!C;VQU;6YS+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M92X*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ;G5M0V]L<R@I"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&YU;4-O;',H)')E<W5L="D*("`@('L*("`@
M("`@("`D8V]L<R`]($!M<W%L7VYU;5]F:65L9',H)')E<W5L="D["B`@("`@
M("`@:68@*"$D8V]L<RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/FUS
M<6Q286ES945R<F]R*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D8V]L
M<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!N=6U2;W=S*"D*"B`@
M("`O*BH*("`@("`J($=E=',@=&AE(&YU;6)E<B!O9B!R;W=S(&EN(&$@<F5S
M=6QT('-E=`H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES(&YO="!M96%N
M="!T;R!B92!C86QL960@9&ER96-T;'DN("!5<V4*("`@("`J($1"7W)E<W5L
M=#HZ;G5M4F]W<R@I(&EN<W1E860N("!)="!C86XG="!B92!D96-L87)E9"`B
M<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@82!S97!A
M<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1R
M97-U;'0@(%!(4"=S('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@("H*("`@
M("`J($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F(')O=W,N("!!($1"7T5R
M<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?
M<F5S=6QT.CIN=6U2;W=S*"D*("`@("`J+PH@("`@9G5N8W1I;VX@;G5M4F]W
M<R@D<F5S=6QT*0H@("`@>PH@("`@("`@("1R;W=S(#T@0&US<6Q?;G5M7W)O
M=W,H)')E<W5L="D["B`@("`@("`@:68@*"1R;W=S(#T]/2!F86QS92D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/FUS<6Q286ES945R<F]R*"D["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D<F]W<SL*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!A9F9E8W1E9"@I"@H@("`@+RHJ"B`@("`@*B!$971E
M<FUI;F5S('1H92!N=6UB97(@;V8@<F]W<R!A9F9E8W1E9"!B>2!A(&1A=&$@
M;6%N:75P;&%T:6]N('%U97)Y"B`@("`@*@H@("`@("H@,"!I<R!R971U<FYE
M9"!F;W(@<75E<FEE<R!T:&%T(&1O;B=T(&UA;FEP=6QA=&4@9&%T82X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!R;W=S+B`@
M02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@869F96-T9612;W=S*"D*("`@('L*("`@("`@("!I9B`H(21T:&ES
M+3Y?<F5S=6QT*2!["B`@("`@("`@("`@(')E='5R;B`P.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@;7-Q;%]A9F9E8W1E9%]R;W=S*"1T:&ES+3Y?<F5S
M=6QT*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!N97AT260H*0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;F5X="!F<F5E(&ED(&EN(&$@
M<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<V5Q7VYA
M;64@(&YA;64@;V8@=&AE('-E<75E;F-E"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D;VYD96UA;F0@('=H96X@=')U92P@=&AE('-E<65N8V4@:7,@875T;VUA
M=&EC86QL>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8W)E
M871E9"!I9B!I="!D;V5S(&YO="!E>&ES=`H@("`@("H*("`@("`J($!R971U
M<FX@:6YT("!T:&4@;F5X="!I9"!N=6UB97(@:6X@=&AE('-E<75E;F-E+@H@
M("`@("H@("`@("`@("`@("`@("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E+@H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIN97AT240H*2P@
M1$)?8V]M;6]N.CIG971397%U96YC94YA;64H*2P*("`@("`J("`@("`@1$)?
M;7-Q;#HZ8W)E871E4V5Q=65N8V4H*2P@1$)?;7-Q;#HZ9')O<%-E<75E;F-E
M*"D*("`@("`J+PH@("`@9G5N8W1I;VX@;F5X=$ED*"1S97%?;F%M92P@)&]N
M9&5M86YD(#T@=')U92D*("`@('L*("`@("`@("`D<V5Q;F%M92`]("1T:&ES
M+3YG971397%U96YC94YA;64H)'-E<5]N86UE*3L*("`@("`@("`D<F5P96%T
M(#T@9F%L<V4["B`@("`@("`@9&\@>PH@("`@("`@("`@("`D=&AI<RT^<'5S
M:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PH@("`@("`@("`@
M("`D<F5S=6QT(#TF("1T:&ES+3YQ=65R>2@B4T5,14-4(%]S97$@1E)/32`D
M>W-E<6YA;65](BD["B`@("`@("`@("`@("1T:&ES+3YP;W!%<G)O<DAA;F1L
M:6YG*"D["B`@("`@("`@("`@(&EF("@D;VYD96UA;F0@)B8@1$(Z.FES17)R
M;W(H)')E<W5L="D@)B8*("`@("`@("`@("`@("`@("1R97-U;'0M/F=E=$-O
M9&4H*2`]/2!$0E]%4E)/4E].3U-50TA404),12D@>PH@("`@("`@("`@("`@
M("`@)')E<&5A="`]('1R=64["B`@("`@("`@("`@("`@("`D=&AI<RT^<'5S
M:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PH@("`@("`@("`@
M("`@("`@)')E<W5L="`]("1T:&ES+3YC<F5A=&5397%U96YC92@D<V5Q7VYA
M;64I.PH@("`@("`@("`@("`@("`@)'1H:7,M/G!O<$5R<F]R2&%N9&QI;F<H
M*3L*("`@("`@("`@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@
M>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@D<F5S=6QT*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1R97!E870@/2!F86QS93L*("`@("`@
M("`@("`@?0H@("`@("`@('T@=VAI;&4@*"1R97!E870I.PH@("`@("`@(&EF
M("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H)')E<W5L="D["B`@("`@("`@?0H@("`@("`@
M("1A<G(@/2`D<F5S=6QT+3YF971C:%)O=RA$0E]&151#2$U/1$5?3U)$15)%
M1"D["B`@("`@("`@)')E<W5L="T^9G)E92@I.PH@("`@("`@(')E='5R;B`D
M87)R6S!=.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&-R96%T95-E
M<75E;F-E*"D*"B`@("`O*BH*("`@("`J($-R96%T97,@82!N97<@<V5Q=65N
M8V4*("`@("`J"B`@("`@*B!!;'-O(&-R96%T97,@82!N97<@=&%B;&4@=&\@
M87-S;V-I871E('1H92!S97%U96YC92!W:71H+B`@57-E<PH@("`@("H@82!S
M97!A<F%T92!T86)L92!T;R!E;G-U<F4@<&]R=&%B:6QI='D@=VET:"!O=&AE
M<B!D<FEV97)S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-E<5]N
M86UE("!N86UE(&]F('1H92!N97<@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J
M96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ
M.F-R96%T95-E<75E;F-E*"DL($1"7V-O;6UO;CHZ9V5T4V5Q=65N8V5.86UE
M*"DL"B`@("`@*B`@("`@($1"7VUS<6PZ.FYE>'1)1"@I+"!$0E]M<W%L.CID
M<F]P4V5Q=65N8V4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!C<F5A=&5397%U
M96YC92@D<V5Q7VYA;64I"B`@("!["B`@("`@("`@)'-E<6YA;64@/2`D=&AI
M<RT^9V5T4V5Q=65N8V5.86UE*"1S97%?;F%M92D["B`@("`@("`@)')E<R`]
M("1T:&ES+3YQ=65R>2@G0U)%051%(%1!0DQ%("<@+B`D<V5Q;F%M90H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@+B`G("AI9"!)3E1%1T52($Y/5"!.
M54Q,*2<I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S*2D@>PH@("`@
M("`@("`@("!R971U<FX@)')E<SL*("`@("`@("!]"B`@("`@("`@)')E<R`]
M("1T:&ES+3YQ=65R>2@B0U)%051%(%-%455%3D-%($].("1[<V5Q;F%M97TB
M*3L*("`@("`@("!R971U<FX@)')E<SL*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!D<F]P4V5Q=65N8V4H*0H*("`@("\J*@H@("`@("H@1&5L971E
M<R!A('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5Q
M7VYA;64@(&YA;64@;V8@=&AE('-E<75E;F-E('1O(&)E(&1E;&5T960*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@
M1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E
M92!$0E]C;VUM;VXZ.F1R;W!397%U96YC92@I+"!$0E]C;VUM;VXZ.F=E=%-E
M<75E;F-E3F%M92@I+`H@("`@("H@("`@("!$0E]M<W%L.CIN97AT240H*2P@
M1$)?;7-Q;#HZ8W)E871E4V5Q=65N8V4H*0H@("`@("HO"B`@("!F=6YC=&EO
M;B!D<F]P4V5Q=65N8V4H)'-E<5]N86UE*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^<75E<GDH)T123U`@5$%"3$4@)R`N("1T:&ES+3YG971397%U
M96YC94YA;64H)'-E<5]N86UE*2D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@<75O=&5)9&5N=&EF:65R*"D*"B`@("`O*BH*("`@("`J(&U344P@
M9&]E<R!N;W0@<W5P<&]R="!D96QI;6ET960@:61E;G1I9FEE<G,*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1S='(@('1H92!I9&5N=&EF:65R(&YA
M;64@=&\@8F4@<75O=&5D"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE8W0@
M(&$@1$)?17)R;W(@;V)J96-T"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM
M;VXZ.G%U;W1E261E;G1I9FEE<B@I"B`@("`@*B!`<VEN8V4@365T:&]D(&%V
M86EL86)L92!S:6YC92!296QE87-E(#$N-RXP"B`@("`@*B\*("`@(&9U;F-T
M:6]N('%U;W1E261E;G1I9FEE<B@D<W1R*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E]53E-54%!/4E1%1"D["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@97-C87!E4VEM<&QE*"D*"B`@
M("`O*BH*("`@("`J($5S8V%P97,@82!S=')I;F<@86-C;W)D:6YG('1O('1H
M92!C=7)R96YT($1"35,G<R!S=&%N9&%R9',*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1S='(@('1H92!S=')I;F<@=&\@8F4@97-C87!E9`H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@97-C87!E9"!S=')I;F<*
M("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ<75O=&53;6%R="@I"B`@
M("`@*B!`<VEN8V4@365T:&]D(&%V86EL86)L92!S:6YC92!296QE87-E(#$N
M-RXP"B`@("`@*B\*("`@(&9U;F-T:6]N(&5S8V%P95-I;7!L92@D<W1R*0H@
M("`@>PH@("`@("`@(')E='5R;B!A9&1S;&%S:&5S*"1S='(I.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(&US<6Q286ES945R<F]R*"D*"B`@("`O
M*BH*("`@("`J(%!R;V1U8V5S(&$@1$)?17)R;W(@;V)J96-T(')E9V%R9&EN
M9R!T:&4@8W5R<F5N="!P<F]B;&5M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN
M="`D97)R;F\@(&EF('1H92!E<G)O<B!I<R!B96EN9R!M86YU86QL>2!R86ES
M960@<&%S<R!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@($1"7T524D]2
M*B!C;VYS=&%N="!H97)E+B`@268@=&AI<R!I<VXG="!P87-S960*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@=&AE(&5R<F]R(&EN9F]R;6%T:6]N(&=A
M=&AE<F5D(&9R;VT@=&AE($1"35,N"B`@("`@*@H@("`@("H@0')E='5R;B!O
M8FIE8W0@('1H92!$0E]%<G)O<B!O8FIE8W0*("`@("`J"B`@("`@*B!`<V5E
M($1"7V-O;6UO;CHZ<F%I<V5%<G)O<B@I+`H@("`@("H@("`@("!$0E]M<W%L
M.CIE<G)O<DYA=&EV92@I+"!$0E]M<W%L.CIE<G)O<D-O9&4H*0H@("`@("HO
M"B`@("!F=6YC=&EO;B!M<W%L4F%I<V5%<G)O<B@D97)R;F\@/2!N=6QL*0H@
M("`@>PH@("`@("`@("1N871I=F4@/2`D=&AI<RT^97)R;W).871I=F4H*3L*
M("`@("`@("!I9B`H)&5R<FYO(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1E
M<G)N;R`]("1T:&ES+3YE<G)O<D-O9&4H)&YA=&EV92D["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D97)R;F\L(&YU;&PL
M(&YU;&PL(&YU;&PL("1N871I=F4I.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&5R<F]R3F%T:79E*"D*"B`@("`O*BH*("`@("`J($=E=',@=&AE
M($1"35,G(&YA=&EV92!E<G)O<B!M97-S86=E('!R;V1U8V5D(&)Y('1H92!L
M87-T('%U97)Y"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!$
M0DU3)R!E<G)O<B!M97-S86=E"B`@("`@*B\*("`@(&9U;F-T:6]N(&5R<F]R
M3F%T:79E*"D*("`@('L*("`@("`@("!R971U<FX@0&US<6Q?97)R;W(H*3L*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!E<G)O<D-O9&4H*0H*("`@
M("\J*@H@("`@("H@1&5T97)M:6YE<R!014%2.CI$0B!E<G)O<B!C;V1E(&9R
M;VT@=&AE(&1A=&%B87-E)W,@=&5X="!E<G)O<B!M97-S86=E"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D97)R;W)M<V<@('1H92!E<G)O<B!M97-S
M86=E(')E='5R;F5D(&9R;VT@=&AE(&1A=&%B87-E"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G1E9V5R("!T:&4@97)R;W(@;G5M8F5R(&9R;VT@82!$0E]%
M4E)/4BH@8V]N<W1A;G0*("`@("`J+PH@("`@9G5N8W1I;VX@97)R;W)#;V1E
M*"1E<G)O<FUS9RD*("`@('L*("`@("`@("!S=&%T:6,@)&5R<F]R7W)E9V5X
M<',["B`@("`@("`@:68@*"%I<W-E="@D97)R;W)?<F5G97AP<RDI('L*("`@
M("`@("`@("`@)&5R<F]R7W)E9V5X<',@/2!A<G)A>2@*("`@("`@("`@("`@
M("`@("<O7D%C8V5S<R!T;R!D871A8F%S92!D96YI960O:2<*("`@("`@("`@
M("`@("`@("`@("`]/B!$0E]%4E)/4E]!0T-%4U-?5DE/3$%424].+`H@("`@
M("`@("`@("`@("`@)R]>0F%D(&EN9&5X(&YA;64O:2<*("`@("`@("`@("`@
M("`@("`@("`]/B!$0E]%4E)/4E]!3%)%04197T5825-44RP*("`@("`@("`@
M("`@("`@("<O7D)A9"!O<F1E<B!F:65L9"]I)PH@("`@("`@("`@("`@("`@
M("`@(#T^($1"7T524D]27U-93E1!6"P*("`@("`@("`@("`@("`@("<O7D)A
M9"!T>7!E(&9O<B!C;VUP87)I<V]N+VDG"B`@("`@("`@("`@("`@("`@("`@
M/3X@1$)?15)23U)?4UE.5$%8+`H@("`@("`@("`@("`@("`@)R]>0V%N7"=T
M('!E<F9O<FT@3$E+12!O;B]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"
M7T524D]27U-93E1!6"P*("`@("`@("`@("`@("`@("<O7D-A;EPG="!U<V4@
M5$585"!F:65L9',@:6X@3$E+12!C;VUP87)I<V]N+VDG"B`@("`@("`@("`@
M("`@("`@("`@/3X@1$)?15)23U)?4UE.5$%8+`H@("`@("`@("`@("`@("`@
M)R]>0V]U;&1N7"=T(&-R96%T92!T96UP;W)A<GD@=&%B;&4O:2<*("`@("`@
M("`@("`@("`@("`@("`]/B!$0E]%4E)/4E]#04Y.3U1?0U)%051%+`H@("`@
M("`@("`@("`@("`@)R]>17)R;W(@8W)E871I;F<@=&%B;&4@9FEL92]I)PH@
M("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27T-!3DY/5%]#4D5!5$4L
M"B`@("`@("`@("`@("`@("`G+UY&:65L9"`N*B!C86YN;W0@8F4@;G5L;"0O
M:2<*("`@("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/4E]#3TY35%)!24Y4
M7TY/5%].54Q,+`H@("`@("`@("`@("`@("`@)R]>26YD97@@*&9I96QD?&-O
M;F1I=&EO;BD@+BH@8V%N;F]T(&)E(&YU;&PD+VDG"B`@("`@("`@("`@("`@
M("`@("`@/3X@1$)?15)23U)?4UE.5$%8+`H@("`@("`@("`@("`@("`@)R]>
M26YV86QI9"!D871E(&9O<FUA="]I)PH@("`@("`@("`@("`@("`@("`@(#T^
M($1"7T524D]27TE.5D%,241?1$%412P*("`@("`@("`@("`@("`@("<O7DEN
M=F%L:60@=&EM92!F;W)M870O:2<*("`@("`@("`@("`@("`@("`@("`]/B!$
M0E]%4E)/4E])3E9!3$E$+`H@("`@("`@("`@("`@("`@)R]>3&ET97)A;"!V
M86QU92!F;W(@+BH@:7,@=W)O;F<@='EP920O:2<*("`@("`@("`@("`@("`@
M("`@("`]/B!$0E]%4E)/4E])3E9!3$E$7TY534)%4BP*("`@("`@("`@("`@
M("`@("<O7DYO($1A=&%B87-E(%-E;&5C=&5D+VDG"B`@("`@("`@("`@("`@
M("`@("`@/3X@1$)?15)23U)?3D]$0E-%3$5#5$5$+`H@("`@("`@("`@("`@
M("`@)R]>3F\@=F%L=64@<W!E8VEF:65D(&9O<B!F:65L9"]I)PH@("`@("`@
M("`@("`@("`@("`@(#T^($1"7T524D]27U9!3%5%7T-/54Y47T].7U)/5RP*
M("`@("`@("`@("`@("`@("<O7DYO;B!U;FEQ=64@=F%L=64@9F]R('5N:7%U
M92!I;F1E>"]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27T-/
M3E-44D%)3E0L"B`@("`@("`@("`@("`@("`G+UY/=70@;V8@;65M;W)Y(&9O
M<B!T96UP;W)A<GD@=&%B;&4O:2<*("`@("`@("`@("`@("`@("`@("`]/B!$
M0E]%4E)/4E]#04Y.3U1?0U)%051%+`H@("`@("`@("`@("`@("`@)R]>4&5R
M;6ES<VEO;B!D96YI960O:2<*("`@("`@("`@("`@("`@("`@("`]/B!$0E]%
M4E)/4E]!0T-%4U-?5DE/3$%424].+`H@("`@("`@("`@("`@("`@)R]>4F5F
M97)E;F-E('1O('5N+7-E;&5C=&5D('1A8FQE+VDG"B`@("`@("`@("`@("`@
M("`@("`@/3X@1$)?15)23U)?4UE.5$%8+`H@("`@("`@("`@("`@("`@)R]>
M<WEN=&%X(&5R<F]R+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)2
M3U)?4UE.5$%8+`H@("`@("`@("`@("`@("`@)R]>5&%B;&4@+BH@97AI<W1S
M)"]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27T%,4D5!1%E?
M15A)4U13+`H@("`@("`@("`@("`@("`@)R]>56YK;F]W;B!D871A8F%S92]I
M)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27TY/4U5#2$1"+`H@
M("`@("`@("`@("`@("`@)R]>56YK;F]W;B!F:65L9"]I)PH@("`@("`@("`@
M("`@("`@("`@(#T^($1"7T524D]27TY/4U5#2$9)14Q$+`H@("`@("`@("`@
M("`@("`@)R]>56YK;F]W;B`H:6YD97A\<WES=&5M('9A<FEA8FQE*2]I)PH@
M("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27TY/5%]&3U5.1"P*("`@
M("`@("`@("`@("`@("<O7E5N:VYO=VX@=&%B;&4O:2<*("`@("`@("`@("`@
M("`@("`@("`]/B!$0E]%4E)/4E].3U-50TA404),12P*("`@("`@("`@("`@
M("`@("<O7E5N<75A;&EF:65D(&9I96QD+VDG"B`@("`@("`@("`@("`@("`@
M("`@/3X@1$)?15)23U)?4UE.5$%8+`H@("`@("`@("`@("`I.PH@("`@("`@
M('T*"B`@("`@("`@9F]R96%C:"`H)&5R<F]R7W)E9V5X<',@87,@)')E9V5X
M<"`]/B`D8V]D92D@>PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@D<F5G
M97AP+"`D97)R;W)M<V<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&-O
M9&4["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"
M7T524D]2.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('1A8FQE26YF
M;R@I"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&EN9F]R;6%T:6]N(&%B;W5T
M(&$@=&%B;&4@;W(@82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@0'!A<F%M
M(&]B:F5C='QS=')I;F<@("1R97-U;'0@($1"7W)E<W5L="!O8FIE8W0@9G)O
M;2!A('%U97)Y(&]R(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@<W1R:6YG(&-O;G1A:6YI;F<@=&AE(&YA;64@;V8@82!T86)L
M92X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@5VAI
M;&4@=&AI<R!A;'-O(&%C8V5P=',@82!Q=65R>2!R97-U;'0*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5S;W5R8V4@:61E;G1I
M9FEE<BP@=&AI<R!B96AA=FEO<B!I<PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!D97!R96-A=&5D+@H@("`@("H@0'!A<F%M(&EN
M="`@("`@("`@("`@("1M;V1E("`@(&$@=F%L:60@=&%B;&5);F9O(&UO9&4*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!A;B!A<W-O8VEA=&EV92!A
M<G)A>2!W:71H('1H92!I;F9O<FUA=&EO;B!R97%U97-T960N"B`@("`@*B`@
M("`@("`@("`@("`@("`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*
M("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ<V5T3W!T:6]N*"D*("`@
M("`J+PH@("`@9G5N8W1I;VX@=&%B;&5);F9O*"1R97-U;'0L("1M;V1E(#T@
M;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?<W1R:6YG*"1R97-U;'0I*2![
M"B`@("`@("`@("`@("\J"B`@("`@("`@("`@("`J(%!R;V)A8FQY(')E8V5I
M=F5D(&$@=&%B;&4@;F%M92X*("`@("`@("`@("`@("H@0W)E871E(&$@<F5S
M=6QT(')E<V]U<F-E(&ED96YT:69I97(N"B`@("`@("`@("`@("`J+PH@("`@
M("`@("`@("`D:60@/2!`;7-Q;%]Q=65R>2@B4T5,14-4("H@1E)/32`D<F5S
M=6QT(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-O
M;FYE8W1I;VXI.PH@("`@("`@("`@("`D9V]T7W-T<FEN9R`]('1R=64["B`@
M("`@("`@?2!E;'-E:68@*&ES<V5T*"1R97-U;'0M/G)E<W5L="DI('L*("`@
M("`@("`@("`@+RH*("`@("`@("`@("`@("H@4')O8F%B;'D@<F5C96EV960@
M82!R97-U;'0@;V)J96-T+@H@("`@("`@("`@("`@*B!%>'1R86-T('1H92!R
M97-U;'0@<F5S;W5R8V4@:61E;G1I9FEE<BX*("`@("`@("`@("`@("HO"B`@
M("`@("`@("`@("1I9"`]("1R97-U;'0M/G)E<W5L=#L*("`@("`@("`@("`@
M)&=O=%]S=')I;F<@/2!F86QS93L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`O*@H@("`@("`@("`@("`@*B!0<F]B86)L>2!R96-E:79E9"!A(')E
M<W5L="!R97-O=7)C92!I9&5N=&EF:65R+@H@("`@("`@("`@("`@*B!#;W!Y
M(&ET+@H@("`@("`@("`@("`@*B!$97!R96-A=&5D+B`@2&5R92!F;W(@8V]M
M<&%T:6)I;&ET>2!O;FQY+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@
M)&ED(#T@)')E<W5L=#L*("`@("`@("`@("`@)&=O=%]S=')I;F<@/2!F86QS
M93L*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-?<F5S;W5R8V4H)&ED*2D@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)2
M3U)?3D5%1%]-3U)%7T1!5$$I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T
M:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?
M3$]715)#05-%*2!["B`@("`@("`@("`@("1C87-E7V9U;F,@/2`G<W1R=&]L
M;W=E<B<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&-A<V5?9G5N
M8R`]("=S=')V86PG.PH@("`@("`@('T*"B`@("`@("`@)&-O=6YT(#T@0&US
M<6Q?;G5M7V9I96QD<R@D:60I.PH@("`@("`@("1R97,@("`](&%R<F%Y*"D[
M"@H@("`@("`@(&EF("@D;6]D92D@>PH@("`@("`@("`@("`D<F5S6R=N=6U?
M9FEE;&1S)UT@/2`D8V]U;G0["B`@("`@("`@?0H*("`@("`@("!F;W(@*"1I
M(#T@,#L@)&D@/"`D8V]U;G0[("1I*RLI('L*("`@("`@("`@("`@)'1M<"`]
M($!M<W%L7V9E=&-H7V9I96QD*"1I9"D["@H@("`@("`@("`@("`D9FQA9W,@
M/2`G)SL*("`@("`@("`@("`@:68@*"1T;7`M/FYO=%]N=6QL*2!["B`@("`@
M("`@("`@("`@("`D9FQA9W,@+CT@)VYO=%]N=6QL("<["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@:68@*"1T;7`M/G5N:7%U92D@>PH@("`@("`@("`@
M("`@("`@)&9L86=S("X]("=U;FEQ=65?:V5Y("<["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)&9L86=S(#T@=')I;2@D9FQA9W,I.PH*("`@("`@("`@
M("`@)')E<ULD:5T@/2!A<G)A>2@*("`@("`@("`@("`@("`@("=T86)L92<@
M/3X@)&-A<V5?9G5N8R@D=&UP+3YT86)L92DL"B`@("`@("`@("`@("`@("`G
M;F%M92<@(#T^("1C87-E7V9U;F,H)'1M<"T^;F%M92DL"B`@("`@("`@("`@
M("`@("`G='EP92<@(#T^("1T;7`M/G1Y<&4L"B`@("`@("`@("`@("`@("`G
M;&5N)R`@(#T^(&US<6Q?9FEE;&1?;&5N*"1I9"P@)&DI+`H@("`@("`@("`@
M("`@("`@)V9L86=S)R`]/B`D9FQA9W,L"B`@("`@("`@("`@("D["@H@("`@
M("`@("`@("!I9B`H)&UO9&4@)B!$0E]404),14E.1D]?3U)$15(I('L*("`@
M("`@("`@("`@("`@("1R97-;)V]R9&5R)UU;)')E<ULD:5U;)VYA;64G75T@
M/2`D:3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&UO9&4@)B!$
M0E]404),14E.1D]?3U)$15)404),12D@>PH@("`@("`@("`@("`@("`@)')E
M<ULG;W)D97)T86)L92==6R1R97-;)&E=6R=T86)L92==75LD<F5S6R1I75LG
M;F%M92==72`]("1I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`O+R!F<F5E('1H92!R97-U;'0@;VYL>2!I9B!W92!W97)E(&-A;&QE9"!O
M;B!A('1A8FQE"B`@("`@("`@:68@*"1G;W1?<W1R:6YG*2!["B`@("`@("`@
M("`@($!M<W%L7V9R965?<F5S=6QT*"1I9"D["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B`D<F5S.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&=E
M=%-P96-I86Q1=65R>2@I"@H@("`@+RHJ"B`@("`@*B!/8G1A:6X@82!L:7-T
M(&]F(&$@9VEV96X@='EP92!O9B!O8FIE8W1S"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D='EP92`@=&AE(&MI;F0@;V8@;V)J96-T<R!Y;W4@=V%N
M="!T;R!R971R:65V90H@("`@("H*("`@("`J($!R971U<FX@87)R87D@('1H
M92!A<G)A>2!C;VYT86EN:6YG('1H92!L:7-T(&]F(&]B:F5C=',@<F5Q=65S
M=&5D"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J($!S
M964@1$)?8V]M;6]N.CIG971,:7-T3V8H*0H@("`@("HO"B`@("!F=6YC=&EO
M;B!G9713<&5C:6%L475E<GDH)'1Y<&4I"B`@("!["B`@("`@("`@<W=I=&-H
M("@D='EP92D@>PH@("`@("`@("`@("!C87-E("=D871A8F%S97,G.@H@("`@
M("`@("`@("`@("`@)&ED(#T@0&US<6Q?;&ES=%]D8G,H)'1H:7,M/F-O;FYE
M8W1I;VXI.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A
M<V4@)W1A8FQE<R<Z"B`@("`@("`@("`@("`@("`D:60@/2!`;7-Q;%]L:7-T
M7W1A8FQE<R@D=&AI<RT^9'-N6R=D871A8F%S92==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-O;FYE8W1I;VXI
M.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&1E9F%U;'0Z
M"B`@("`@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("`@
M("`@:68@*"$D:60I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM<W%L
M4F%I<V5%<G)O<B@I.PH@("`@("`@('T*("`@("`@("`D;W5T(#T@87)R87DH
M*3L*("`@("`@("!W:&EL92`H)')O=R`]($!M<W%L7V9E=&-H7W)O=R@D:60I
M*2!["B`@("`@("`@("`@("1O=71;72`]("1R;W=;,%T["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B`D;W5T.PH@("`@?0H*("`@("\O('U]?0H*?0H*+RH*
M("H@3&]C86P@=F%R:6%B;&5S.@H@*B!T86(M=VED=&@Z(#0*("H@8RUB87-I
M8RUO9F9S970Z(#0*("H@16YD.@H@*B\*"C\^"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O1$(O;7-S<6PN<&AP````````
M````````````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`V-38T-B`Q
M,#4Q-30S,S<S,2`P,C`V-#(`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T
M86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO"@HO*BH*
M("H@5&AE(%!%05(@1$(@9')I=F5R(&9O<B!02%`G<R!M<W-Q;"!E>'1E;G-I
M;VX*("H@9F]R(&EN=&5R86-T:6YG('=I=&@@36EC<F]S;V9T(%-13"!397)V
M97(@9&%T86)A<V5S"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J
M($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S
M:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA="!I<R!A=F%I;&%B
M;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN
M9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N
M("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@H@*B!T:&4@4$A0
M($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@
M=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP
M+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@
M*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@("!$0@H@
M*B!`875T:&]R("`@("!3=&5R;&EN9R!(=6=H97,@/'-T97)L:6YG0'!H<"YN
M970^"B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`
M<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O
M=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@($-64SH@
M)$ED.B!M<W-Q;"YP:'`L=B`Q+C@S(#(P,#4O,#,O,#<@,3@Z,C0Z-3$@9&%N
M:65L8R!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T
M+W!A8VMA9V4O1$(*("HO"@HO*BH*("H@3V)T86EN('1H92!$0E]C;VUM;VX@
M8VQA<W,@<V\@:70@8V%N(&)E(&5X=&5N9&5D(&9R;VT*("HO"G)E<75I<F5?
M;VYC92`G1$(O8V]M;6]N+G!H<"<["@HO*BH*("H@5&AE(&UE=&AO9',@4$5!
M4B!$0B!U<V5S('1O(&EN=&5R86-T('=I=&@@4$A0)W,@;7-S<6P@97AT96YS
M:6]N"B`J(&9O<B!I;G1E<F%C=&EN9R!W:71H($UI8W)O<V]F="!344P@4V5R
M=F5R(&1A=&%B87-E<PH@*@H@*B!4:&5S92!M971H;V1S(&]V97)L;V%D('1H
M92!O;F5S(&1E8VQA<F5D(&EN($1"7V-O;6UO;BX*("H*("H@0&-A=&5G;W)Y
M("`@1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@
M4W1E<FQI;F<@2'5G:&5S(#QS=&5R;&EN9T!P:'`N;F5T/@H@*B!`875T:&]R
M("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C
M;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C<N-@H@*B!`
M;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO
M"F-L87-S($1"7VUS<W%L(&5X=&5N9',@1$)?8V]M;6]N"GL*("`@("\O('M[
M>R!P<F]P97)T:65S"@H@("`@+RHJ"B`@("`@*B!4:&4@1$(@9')I=F5R('1Y
M<&4@*&UY<W%L+"!O8VDX+"!O9&)C+"!E=&,N*0H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1P:'!T>7!E(#T@)VUS<W%L)SL*"B`@("`O
M*BH*("`@("`J(%1H92!D871A8F%S92!S>6YT87@@=F%R:6%N="!T;R!B92!U
M<V5D("AD8C(L(&%C8V5S<RP@971C+BDL(&EF(&%N>0H@("`@("H@0'9A<B!S
M=')I;F<*("`@("`J+PH@("`@=F%R("1D8G-Y;G1A>"`]("=M<W-Q;"<["@H@
M("`@+RHJ"B`@("`@*B!4:&4@8V%P86)I;&ET:65S(&]F('1H:7,@1$(@:6UP
M;&5M96YT871I;VX*("`@("`J"B`@("`@*B!4:&4@)VYE=U]L:6YK)R!E;&5M
M96YT(&-O;G1A:6YS('1H92!02%`@=F5R<VEO;B!T:&%T(&9I<G-T('!R;W9I
M9&5D"B`@("`@*B!N97=?;&EN:R!S=7!P;W)T(&9O<B!T:&ES($1"35,N("!#
M;VYT86EN<R!F86QS92!I9B!I="=S('5N<W5P<&]R=&5D+@H@("`@("H*("`@
M("`J($UE86YI;F<@;V8@=&AE("=L:6UI="<@96QE;65N=#H*("`@("`J("`@
M*R`G96UU;&%T92<@/2!E;75L871E('=I=&@@9F5T8V@@<F]W(&)Y(&YU;6)E
M<@H@("`@("H@("`K("=A;'1E<B<@("`](&%L=&5R('1H92!Q=65R>0H@("`@
M("H@("`K(&9A;'-E("`@("`]('-K:7`@<F]W<PH@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1F96%T=7)E<R`](&%R<F%Y*`H@
M("`@("`@("=L:6UI="<@("`@("`@("`]/B`G96UU;&%T92<L"B`@("`@("`@
M)VYE=U]L:6YK)R`@("`@(#T^(&9A;'-E+`H@("`@("`@("=N=6UR;W=S)R`@
M("`@("`]/B!T<G5E+`H@("`@("`@("=P8V]N;F5C="<@("`@("`]/B!T<G5E
M+`H@("`@("`@("=P<F5P87)E)R`@("`@("`]/B!F86QS92P*("`@("`@("`G
M<W-L)R`@("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@)W1R86YS86-T:6]N
M<R<@(#T^('1R=64L"B`@("`I.PH*("`@("\J*@H@("`@("H@02!M87!P:6YG
M(&]F(&YA=&EV92!E<G)O<B!C;V1E<R!T;R!$0B!E<G)O<B!C;V1E<PH@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("`O+R!86%@@061D(&AE<F4@97)R
M;W(@8V]D97,@:64Z("=3,3`P12<@/3X@1$)?15)23U)?4UE.5$%8"B`@("!V
M87(@)&5R<F]R8V]D95]M87`@/2!A<G)A>2@*("`@("`@("`Q,3`@("`]/B!$
M0E]%4E)/4E]604Q515]#3U5.5%]/3E]23U<L"B`@("`@("`@,34U("`@/3X@
M1$)?15)23U)?3D]354-(1DE%3$0L"B`@("`@("`@,3<P("`@/3X@1$)?15)2
M3U)?4UE.5$%8+`H@("`@("`@(#(P-R`@(#T^($1"7T524D]27TY/4U5#2$9)
M14Q$+`H@("`@("`@(#(P."`@(#T^($1"7T524D]27TY/4U5#2%1!0DQ%+`H@
M("`@("`@(#(T-2`@(#T^($1"7T524D]27TE.5D%,241?3E5-0D52+`H@("`@
M("`@(#4Q-2`@(#T^($1"7T524D]27T-/3E-44D%)3E1?3D]47TY53$PL"B`@
M("`@("`@-30W("`@/3X@1$)?15)23U)?0T].4U1204E.5"P*("`@("`@("`Q
M.3$S("`]/B!$0E]%4E)/4E]!3%)%04197T5825-44RP*("`@("`@("`R-C(W
M("`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@("`@(#(W,30@(#T^($1"
M7T524D]27T%,4D5!1%E?15A)4U13+`H@("`@("`@(#,W,#$@(#T^($1"7T52
M4D]27TY/4U5#2%1!0DQ%+`H@("`@("`@(#@Q,S0@(#T^($1"7T524D]27T1)
M5EI%4D\L"B`@("`I.PH*("`@("\J*@H@("`@("H@5&AE(')A=R!D871A8F%S
M92!C;VYN96-T:6]N(&-R96%T960@8GD@4$A0"B`@("`@*B!`=F%R(')E<V]U
M<F-E"B`@("`@*B\*("`@('9A<B`D8V]N;F5C=&EO;CL*"B`@("`O*BH*("`@
M("`J(%1H92!$4TX@:6YF;W)M871I;VX@9F]R(&-O;FYE8W1I;F<@=&\@82!D
M871A8F%S90H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&1S
M;B`](&%R<F%Y*"D["@H*("`@("\J*@H@("`@("H@4VAO=6QD(&1A=&$@;6%N
M:7!U;&%T:6]N('%U97)I97,@8F4@8V]M;6ET=&5D(&%U=&]M871I8V%L;'D_
M"B`@("`@*B!`=F%R(&)O;VP*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("HO"B`@("!V87(@)&%U=&]C;VUM:70@/2!T<G5E.PH*("`@("\J*@H@("`@
M("H@5&AE('%U86YT:71Y(&]F('1R86YS86-T:6]N<R!B96=U;@H@("`@("H*
M("`@("`J('M`:6YT97)N86P@(%=H:6QE('1H:7,@:7,@<')I=F%T92P@:70@
M8V%N)W0@86-T=6%L;'D@8F4@9&5S:6=N871E9`H@("`@("H@<')I=F%T92!I
M;B!02%`@-2!B96-A=7-E(&ET(&ES(&1I<F5C=&QY(&%C8V5S<V5D(&EN('1H
M92!T97-T('-U:71E+GU]"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1T<F%N<V%C
M=&EO;E]O<&-O=6YT(#T@,#L*"B`@("`O*BH*("`@("`J(%1H92!D871A8F%S
M92!S<&5C:69I960@:6X@=&AE($133@H@("`@("H*("`@("`J($ET)W,@82!F
M:7@@=&\@86QL;W<@8V%L;',@=&\@9&EF9F5R96YT(&1A=&%B87-E<R!I;B!T
M:&4@<V%M92!S8W)I<'0N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]D8B`](&YU
M;&P["@H*("`@("\O('U]?0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R"@H@("`@
M+RHJ"B`@("`@*B!4:&ES(&-O;G-T<G5C=&]R(&-A;&QS(#QK8F0^)'1H:7,M
M/D1"7V-O;6UO;B@I/"]K8F0^"B`@("`@*@H@("`@("H@0')E='5R;B!V;VED
M"B`@("`@*B\*("`@(&9U;F-T:6]N($1"7VUS<W%L*"D*("`@('L*("`@("`@
M("`D=&AI<RT^1$)?8V]M;6]N*"D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@8V]N;F5C="@I"@H@("`@+RHJ"B`@("`@*B!#;VYN96-T('1O('1H
M92!D871A8F%S92!S97)V97(L(&QO9R!I;B!A;F0@;W!E;B!T:&4@9&%T86)A
M<V4*("`@("`J"B`@("`@*B!$;VXG="!C86QL('1H:7,@;65T:&]D(&1I<F5C
M=&QY+B`@57-E($1".CIC;VYN96-T*"D@:6YS=&5A9"X*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@)&1S;B`@("`@("`@('1H92!D871A('-O=7)C92!N
M86UE"B`@("`@*B!`<&%R86T@8F]O;"`@)'!E<G-I<W1E;G0@('-H;W5L9"!T
M:&4@8V]N;F5C=&EO;B!B92!P97)S:7-T96YT/PH@("`@("H*("`@("`J($!R
M971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B!!($1"7T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VYN96-T*"1D
M<VXL("1P97)S:7-T96YT(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"%0
M14%2.CIL;V%D17AT96YS:6]N*"=M<W-Q;"<I("8F("%014%2.CIL;V%D17AT
M96YS:6]N*"=S>6)A<V4G*0H@("`@("`@("`@("`F)B`A4$5!4CHZ;&]A9$5X
M=&5N<VEO;B@G<WEB87-E7V-T)RDI"B`@("`@("`@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?15A414Y324].7TY/
M5%]&3U5.1"D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^9'-N(#T@)&1S
M;CL*("`@("`@("!I9B`H)&1S;ELG9&)S>6YT87@G72D@>PH@("`@("`@("`@
M("`D=&AI<RT^9&)S>6YT87@@/2`D9'-N6R=D8G-Y;G1A>"==.PH@("`@("`@
M('T*"B`@("`@("`@)'!A<F%M<R`](&%R<F%Y*`H@("`@("`@("`@("`D9'-N
M6R=H;W-T<W!E8R==(#\@)&1S;ELG:&]S='-P96,G72`Z("=L;V-A;&AO<W0G
M+`H@("`@("`@("`@("`D9'-N6R=U<V5R;F%M92==(#\@)&1S;ELG=7-E<FYA
M;64G72`Z(&YU;&PL"B`@("`@("`@("`@("1D<VY;)W!A<W-W;W)D)UT@/R`D
M9'-N6R=P87-S=V]R9"==(#H@;G5L;"P*("`@("`@("`I.PH@("`@("`@(&EF
M("@D9'-N6R=P;W)T)UTI('L*("`@("`@("`@("`@)'!A<F%M<ULP72`N/2`H
M*'-U8G-T<BA02%!?3U,L(#`L(#,I(#T]("=724XG*2`_("<L)R`Z("<Z)RD*
M("`@("`@("`@("`@("`@("`@("`@("`@+B`D9'-N6R=P;W)T)UT["B`@("`@
M("`@?0H*("`@("`@("`D8V]N;F5C=%]F=6YC=&EO;B`]("1P97)S:7-T96YT
M(#\@)VUS<W%L7W!C;VYN96-T)R`Z("=M<W-Q;%]C;VYN96-T)SL*"B`@("`@
M("`@)'1H:7,M/F-O;FYE8W1I;VX@/2!`8V%L;%]U<V5R7V9U;F-?87)R87DH
M)&-O;FYE8W1?9G5N8W1I;VXL("1P87)A;7,I.PH*("`@("`@("!I9B`H(21T
M:&ES+3YC;VYN96-T:6]N*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<BA$0E]%4E)/4E]#3TY.14-47T9!24Q%1"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YU;&PL(&YU;&PL(&YU;&PL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!`;7-S<6Q?
M9V5T7VQA<W1?;65S<V%G92@I*3L*("`@("`@("!]"B`@("`@("`@:68@*"1D
M<VY;)V1A=&%B87-E)UTI('L*("`@("`@("`@("`@:68@*"%`;7-S<6Q?<V5L
M96-T7V1B*"1D<VY;)V1A=&%B87-E)UTL("1T:&ES+3YC;VYN96-T:6]N*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"
M7T524D]27TY/1$)314Q%0U1%1"P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!N=6QL+"!N=6QL+"!N=6QL+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($!M<W-Q;%]G971?;&%S
M=%]M97-S86=E*"DI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES
M+3Y?9&(@/2`D9'-N6R=D871A8F%S92==.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9&ES
M8V]N;F5C="@I"@H@("`@+RHJ"B`@("`@*B!$:7-C;VYN96-T<R!F<F]M('1H
M92!D871A8F%S92!S97)V97(*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@
M(%12544@;VX@<W5C8V5S<RP@1D%,4T4@;VX@9F%I;'5R90H@("`@("HO"B`@
M("!F=6YC=&EO;B!D:7-C;VYN96-T*"D*("`@('L*("`@("`@("`D<F5T(#T@
M0&US<W%L7V-L;W-E*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`D=&AI
M<RT^8V]N;F5C=&EO;B`](&YU;&P["B`@("`@("`@<F5T=7)N("1R970["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<VEM<&QE475E<GDH*0H*("`@
M("\J*@H@("`@("H@4V5N9',@82!Q=65R>2!T;R!T:&4@9&%T86)A<V4@<V5R
M=F5R"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@=&AE(%-13"!Q=65R
M>2!S=')I;F<*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("`K(&$@4$A0
M(')E<W5L="!R97-R;W5C92!F;W(@<W5C8V5S<V9U;"!314Q%0U0@<75E<FEE
M<PH@("`@("H@("`@("`@("`@("`@("`@*R!T:&4@1$)?3TL@8V]N<W1A;G0@
M9F]R(&]T:&5R('-U8V-E<W-F=6P@<75E<FEE<PH@("`@("H@("`@("`@("`@
M("`@("`@*R!A($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-I;7!L95%U97)Y*"1Q=65R>2D*("`@('L*("`@("`@
M("`D:7-M86YI<"`]($1".CII<TUA;FEP*"1Q=65R>2D["B`@("`@("`@)'1H
M:7,M/FQA<W1?<75E<GD@/2`D<75E<GD["B`@("`@("`@:68@*"%`;7-S<6Q?
M<V5L96-T7V1B*"1T:&ES+3Y?9&(L("1T:&ES+3YC;VYN96-T:6]N*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/FUS<W%L4F%I<V5%<G)O<BA$0E]%
M4E)/4E].3T1"4T5,14-4140I.PH@("`@("`@('T*("`@("`@("`D<75E<GD@
M/2`D=&AI<RT^;6]D:69Y475E<GDH)'%U97)Y*3L*("`@("`@("!I9B`H(21T
M:&ES+3YA=71O8V]M;6ET("8F("1I<VUA;FEP*2!["B`@("`@("`@("`@(&EF
M("@D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`]/2`P*2!["B`@("`@("`@
M("`@("`@("`D<F5S=6QT(#T@0&US<W%L7W%U97)Y*"="14=)3B!44D%.)RP@
M)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@("`@("`@:68@*"$D<F5S
M=6QT*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM<W-Q
M;%)A:7-E17)R;W(H*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="LK.PH@
M("`@("`@('T*("`@("`@("`D<F5S=6QT(#T@0&US<W%L7W%U97)Y*"1Q=65R
M>2P@)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@(&EF("@A)')E<W5L="D@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/FUS<W%L4F%I<V5%<G)O<B@I
M.PH@("`@("`@('T*("`@("`@("`O+R!$971E<FUI;F4@=VAI8V@@<75E<FEE
M<R!T:&%T('-H;W5L9"!R971U<FX@9&%T82P@86YD('=H:6-H"B`@("`@("`@
M+R\@<VAO=6QD(')E='5R;B!A;B!E<G)O<B!C;V1E(&]N;'DN"B`@("`@("`@
M<F5T=7)N("1I<VUA;FEP(#\@1$)?3TL@.B`D<F5S=6QT.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&YE>'1297-U;'0H*0H*("`@("\J*@H@("`@
M("H@36]V92!T:&4@:6YT97)N86P@;7-S<6P@<F5S=6QT('!O:6YT97(@=&\@
M=&AE(&YE>'0@879A:6QA8FQE(')E<W5L=`H@("`@("H*("`@("`J($!P87)A
M;2!A('9A;&ED(&9B<W%L(')E<W5L="!R97-O=7)C90H@("`@("H*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("H@0')E='5R;B!T<G5E(&EF
M(&$@<F5S=6QT(&ES(&%V86EL86)L92!O=&AE<G=I<V4@<F5T=7)N(&9A;'-E
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&YE>'1297-U;'0H)')E<W5L="D*("`@
M('L*("`@("`@("!R971U<FX@0&US<W%L7VYE>'1?<F5S=6QT*"1R97-U;'0I
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&9E=&-H26YT;R@I"@H@
M("`@+RHJ"B`@("`@*B!0;&%C97,@82!R;W<@9G)O;2!T:&4@<F5S=6QT('-E
M="!I;G1O('1H92!G:79E;B!A<G)A>0H@("`@("H*("`@("`J($9O<FUA=&EN
M9R!O9B!T:&4@87)R87D@86YD('1H92!D871A('1H97)E:6X@87)E(&-O;F9I
M9W5R86)L92X*("`@("`J(%-E92!$0E]R97-U;'0Z.F9E=&-H26YT;R@I(&9O
M<B!M;W)E(&EN9F]R;6%T:6]N+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D
M(&ES(&YO="!M96%N="!T;R!B92!C86QL960@9&ER96-T;'DN("!5<V4*("`@
M("`J($1"7W)E<W5L=#HZ9F5T8VA);G1O*"D@:6YS=&5A9"X@($ET(&-A;B=T
M(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E($1"7W)E
M<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R
M86T@<F5S;W5R8V4@)')E<W5L="`@("!T:&4@<75E<GD@<F5S=6QT(')E<V]U
M<F-E"B`@("`@*B!`<&%R86T@87)R87D@("`@)&%R<B`@("`@("!T:&4@<F5F
M97)E;F-E9"!A<G)A>2!T;R!P=70@=&AE(&1A=&$@:6X*("`@("`J($!P87)A
M;2!I;G0@("`@("`D9F5T8VAM;V1E(&AO=R!T:&4@<F5S=6QT:6YG(&%R<F%Y
M('-H;W5L9"!B92!I;F1E>&5D"B`@("`@*B!`<&%R86T@:6YT("`@("`@)')O
M=VYU;2`@("!T:&4@<F]W(&YU;6)E<B!T;R!F971C:"`H,"`](&9I<G-T(')O
M=RD*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!$0E]/2R!O;B!S=6-C
M97-S+"!.54Q,('=H96X@=&AE(&5N9"!O9B!A(')E<W5L="!S970@:7,*("`@
M("`J("`@("`@("`@("`@("`@("!R96%C:&5D(&]R(&]N(&9A:6QU<F4*("`@
M("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ9F5T8VA);G1O*"D*("`@("`J
M+PH@("`@9G5N8W1I;VX@9F5T8VA);G1O*"1R97-U;'0L("8D87)R+"`D9F5T
M8VAM;V1E+"`D<F]W;G5M(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H)')O
M=VYU;2`A/3T@;G5L;"D@>PH@("`@("`@("`@("!I9B`H(4!M<W-Q;%]D871A
M7W-E96LH)')E<W5L="P@)')O=VYU;2DI('L*("`@("`@("`@("`@("`@(')E
M='5R;B!N=6QL.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF
M("@D9F5T8VAM;V1E("8@1$)?1D540TA-3T1%7T%34T]#*2!["B`@("`@("`@
M("`@("1A<G(@/2!`;7-S<6Q?9F5T8VA?87)R87DH)')E<W5L="P@35-344Q?
M05-33T,I.PH@("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A
M8FEL:71Y)UT@)B!$0E]03U)404))3$E465],3U=%4D-!4T4@)B8@)&%R<BD@
M>PH@("`@("`@("`@("`@("`@)&%R<B`](&%R<F%Y7V-H86YG95]K97E?8V%S
M92@D87)R+"!#05-%7TQ/5T52*3L*("`@("`@("`@("`@?0H@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1A<G(@/2!`;7-S<6Q?9F5T8VA?<F]W*"1R
M97-U;'0I.PH@("`@("`@('T*("`@("`@("!I9B`H(21A<G(I('L*("`@("`@
M("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI
M<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197U)4
M4DE-*2!["B`@("`@("`@("`@("1T:&ES+3Y?<G1R:6U!<G)A>59A;'5E<R@D
M87)R*3L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P
M;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?3E5,3%]43U]%35!462D@
M>PH@("`@("`@("`@("`D=&AI<RT^7V-O;G9E<G1.=6QL07)R87E686QU97-4
M;T5M<'1Y*"1A<G(I.PH@("`@("`@('T*("`@("`@("!R971U<FX@1$)?3TL[
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9G)E95)E<W5L="@I"@H@
M("`@+RHJ"B`@("`@*B!$96QE=&5S('1H92!R97-U;'0@<V5T(&%N9"!F<F5E
M<R!T:&4@;65M;W)Y(&]C8W5P:65D(&)Y('1H92!R97-U;'0@<V5T"B`@("`@
M*@H@("`@("H@5&AI<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE
M9"!D:7)E8W1L>2X@(%5S90H@("`@("H@1$)?<F5S=6QT.CIF<F5E*"D@:6YS
M=&5A9"X@($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@
M*B!B96-A=7-E($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@
M("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@<75E
M<GD@<F5S=6QT(')E<V]U<F-E"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M("!44E5%(&]N('-U8V-E<W,L($9!3%-%(&EF("1R97-U;'0@:7,@:6YV86QI
M9`H@("`@("H*("`@("`J($!S964@1$)?<F5S=6QT.CIF<F5E*"D*("`@("`J
M+PH@("`@9G5N8W1I;VX@9G)E95)E<W5L="@D<F5S=6QT*0H@("`@>PH@("`@
M("`@(')E='5R;B!`;7-S<6Q?9G)E95]R97-U;'0H)')E<W5L="D["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;G5M0V]L<R@I"@H@("`@+RHJ"B`@
M("`@*B!'971S('1H92!N=6UB97(@;V8@8V]L=6UN<R!I;B!A(')E<W5L="!S
M970*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@
M8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z.FYU
M;4-O;',H*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E
M8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@
M;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT
M("!02%`G<R!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!C;VQU;6YS+B`@02!$0E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7W)E
M<W5L=#HZ;G5M0V]L<R@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&YU;4-O;',H
M)')E<W5L="D*("`@('L*("`@("`@("`D8V]L<R`]($!M<W-Q;%]N=6U?9FEE
M;&1S*"1R97-U;'0I.PH@("`@("`@(&EF("@A)&-O;',I('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YM<W-Q;%)A:7-E17)R;W(H*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1C;VQS.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&YU;5)O=W,H*0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@;G5M
M8F5R(&]F(')O=W,@:6X@82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@5&AI
M<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@
M(%5S90H@("`@("H@1$)?<F5S=6QT.CIN=6U2;W=S*"D@:6YS=&5A9"X@($ET
M(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E
M($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@
M*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@<75E<GD@<F5S=6QT
M(')E<V]U<F-E"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB
M97(@;V8@<F]W<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@
M("`@*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.FYU;5)O=W,H*0H@("`@("HO
M"B`@("!F=6YC=&EO;B!N=6U2;W=S*"1R97-U;'0I"B`@("!["B`@("`@("`@
M)')O=W,@/2!`;7-S<6Q?;G5M7W)O=W,H)')E<W5L="D["B`@("`@("`@:68@
M*"1R;W=S(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/FUS<W%L4F%I<V5%<G)O<B@I.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M)')O=W,["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@875T;T-O;6UI
M="@I"@H@("`@+RHJ"B`@("`@*B!%;F%B;&5S(&]R(&1I<V%B;&5S(&%U=&]M
M871I8R!C;VUM:71S"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VP@)&]N;V9F
M("!T<G5E('1U<FYS(&ET(&]N+"!F86QS92!T=7)N<R!I="!O9F8*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?
M17)R;W(@;V)J96-T(&EF('1H92!D<FEV97(*("`@("`J("`@("`@("`@("`@
M("`@9&]E<VXG="!S=7!P;W)T(&%U=&\M8V]M;6ET=&EN9R!T<F%N<V%C=&EO
M;G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%U=&]#;VUM:70H)&]N;V9F(#T@
M9F%L<V4I"B`@("!["B`@("`@("`@+R\@6%A8(&EF("1T:&ES+3YT<F%N<V%C
M=&EO;E]O<&-O=6YT(#X@,"P@=V4@<VAO=6QD('!R;V)A8FQY"B`@("`@("`@
M+R\@:7-S=64@82!W87)N:6YG(&AE<F4N"B`@("`@("`@)'1H:7,M/F%U=&]C
M;VUM:70@/2`D;VYO9F8@/R!T<G5E(#H@9F%L<V4["B`@("`@("`@<F5T=7)N
M($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&-O;6UI="@I
M"@H@("`@+RHJ"B`@("`@*B!#;VUM:71S('1H92!C=7)R96YT('1R86YS86-T
M:6]N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E
M<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!C;VUM:70H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^
M=')A;G-A8W1I;VY?;W!C;W5N="`^(#`I('L*("`@("`@("`@("`@:68@*"%`
M;7-S<6Q?<V5L96-T7V1B*"1T:&ES+3Y?9&(L("1T:&ES+3YC;VYN96-T:6]N
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM<W-Q;%)A:7-E
M17)R;W(H1$)?15)23U)?3D]$0E-%3$5#5$5$*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D<F5S=6QT(#T@0&US<W%L7W%U97)Y*"=#3TU-250@5%)!
M3B<L("1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`@("`@)'1H:7,M/G1R
M86YS86-T:6]N7V]P8V]U;G0@/2`P.PH@("`@("`@("`@("!I9B`H(21R97-U
M;'0I('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;7-S<6Q286ES
M945R<F]R*"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(')O;&QB
M86-K*"D*"B`@("`O*BH*("`@("`J(%)E=F5R=',@=&AE(&-U<G)E;G0@=')A
M;G-A8W1I;VX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@
M<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(')O;&QB86-K*"D*("`@('L*("`@("`@("!I9B`H
M)'1H:7,M/G1R86YS86-T:6]N7V]P8V]U;G0@/B`P*2!["B`@("`@("`@("`@
M(&EF("@A0&US<W%L7W-E;&5C=%]D8B@D=&AI<RT^7V1B+"`D=&AI<RT^8V]N
M;F5C=&EO;BDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;7-S
M<6Q286ES945R<F]R*$1"7T524D]27TY/1$)314Q%0U1%1"D["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)')E<W5L="`]($!M<W-Q;%]Q=65R>2@G4D],
M3$)!0TL@5%)!3B<L("1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`@("`@
M)'1H:7,M/G1R86YS86-T:6]N7V]P8V]U;G0@/2`P.PH@("`@("`@("`@("!I
M9B`H(21R97-U;'0I('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M;7-S<6Q286ES945R<F]R*"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&%F9F5C=&5D4F]W<R@I"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S
M('1H92!N=6UB97(@;V8@<F]W<R!A9F9E8W1E9"!B>2!A(&1A=&$@;6%N:75P
M;&%T:6]N('%U97)Y"B`@("`@*@H@("`@("H@,"!I<R!R971U<FYE9"!F;W(@
M<75E<FEE<R!T:&%T(&1O;B=T(&UA;FEP=6QA=&4@9&%T82X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!R;W=S+B`@02!$0E]%
M<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M869F96-T9612;W=S*"D*("`@('L*("`@("`@("!I9B`H1$(Z.FES36%N:7`H
M)'1H:7,M/FQA<W1?<75E<GDI*2!["B`@("`@("`@("`@("1R97,@/2!`;7-S
M<6Q?<75E<GDH)W-E;&5C="!`0')O=V-O=6YT)RP@)'1H:7,M/F-O;FYE8W1I
M;VXI.PH@("`@("`@("`@("!I9B`H(21R97,I('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^;7-S<6Q286ES945R<F]R*"D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)&%R(#T@0&US<W%L7V9E=&-H7W)O=R@D<F5S*3L*
M("`@("`@("`@("`@:68@*"$D87(I('L*("`@("`@("`@("`@("`@("1R97-U
M;'0@/2`P.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M0&US<W%L7V9R965?<F5S=6QT*"1R97,I.PH@("`@("`@("`@("`@("`@)')E
M<W5L="`]("1A<ELP73L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1R97-U;'0@/2`P.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!N
M97AT260H*0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;F5X="!F<F5E
M(&ED(&EN(&$@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("`D<V5Q7VYA;64@(&YA;64@;V8@=&AE('-E<75E;F-E"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D;VYD96UA;F0@('=H96X@=')U92P@=&AE('-E<65N8V4@
M:7,@875T;VUA=&EC86QL>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@8W)E871E9"!I9B!I="!D;V5S(&YO="!E>&ES=`H@("`@("H*("`@
M("`J($!R971U<FX@:6YT("!T:&4@;F5X="!I9"!N=6UB97(@:6X@=&AE('-E
M<75E;F-E+@H@("`@("H@("`@("`@("`@("`@("!!($1"7T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIN
M97AT240H*2P@1$)?8V]M;6]N.CIG971397%U96YC94YA;64H*2P*("`@("`J
M("`@("`@1$)?;7-S<6PZ.F-R96%T95-E<75E;F-E*"DL($1"7VUS<W%L.CID
M<F]P4V5Q=65N8V4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!N97AT260H)'-E
M<5]N86UE+"`D;VYD96UA;F0@/2!T<G5E*0H@("`@>PH@("`@("`@("1S97%N
M86UE(#T@)'1H:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I.PH@("`@
M("`@(&EF("@A0&US<W%L7W-E;&5C=%]D8B@D=&AI<RT^7V1B+"`D=&AI<RT^
M8V]N;F5C=&EO;BDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM<W-Q
M;%)A:7-E17)R;W(H1$)?15)23U)?3D]$0E-%3$5#5$5$*3L*("`@("`@("!]
M"B`@("`@("`@)')E<&5A="`](#`["B`@("`@("`@9&\@>PH@("`@("`@("`@
M("`D=&AI<RT^<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI
M.PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/G%U97)Y*"))3E-%4E0@
M24Y43R`D<V5Q;F%M92`H=F%P;W(I(%9!3%5%4R`H,"DB*3L*("`@("`@("`@
M("`@)'1H:7,M/G!O<$5R<F]R2&%N9&QI;F<H*3L*("`@("`@("`@("`@:68@
M*"1O;F1E;6%N9"`F)B!$0CHZ:7-%<G)O<B@D<F5S=6QT*2`F)@H@("`@("`@
M("`@("`@("`@*"1R97-U;'0M/F=E=$-O9&4H*2`]/2!$0E]%4E)/4B!\?"`D
M<F5S=6QT+3YG971#;V1E*"D@/3T@1$)?15)23U)?3D]354-(5$%"3$4I*0H@
M("`@("`@("`@("!["B`@("`@("`@("`@("`@("`D<F5P96%T(#T@,3L*("`@
M("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^8W)E871E4V5Q=65N8V4H
M)'-E<5]N86UE*3L*("`@("`@("`@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D
M<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@D<F5S=6QT*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?2!E;'-E:68@*"%$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@
M("`@("`@("`@("`@)')E<W5L="`])B`D=&AI<RT^<75E<GDH(E-%3$5#5"!`
M0$E$14Y42519($923TT@)'-E<6YA;64B*3L*("`@("`@("`@("`@("`@("1R
M97!E870@/2`P.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)')E<&5A="`](&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@?2!W
M:&EL92`H)')E<&5A="D["B`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97-U
M;'0I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D
M<F5S=6QT*3L*("`@("`@("!]"B`@("`@("`@)')E<W5L="`]("1R97-U;'0M
M/F9E=&-H4F]W*$1"7T9%5$-(34]$15]/4D1%4D5$*3L*("`@("`@("!R971U
M<FX@)')E<W5L=%LP73L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@
M82!N97<@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S
M97%?;F%M92`@;F%M92!O9B!T:&4@;F5W('-E<75E;F-E"B`@("`@*@H@("`@
M("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?8V]M
M;6]N.CIC<F5A=&5397%U96YC92@I+"!$0E]C;VUM;VXZ.F=E=%-E<75E;F-E
M3F%M92@I+`H@("`@("H@("`@("!$0E]M<W-Q;#HZ;F5X=$E$*"DL($1"7VUS
M<W%L.CID<F]P4V5Q=65N8V4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!C<F5A
M=&5397%U96YC92@D<V5Q7VYA;64I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3YQ=65R>2@G0U)%051%(%1!0DQ%("<*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("X@)'1H:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("<@*%MI9%T@6VEN=%T@
M241%3E1)5%D@*#$L(#$I($Y/5"!.54Q,+"<*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("X@)R!;=F%P;W)=(%MI;G1=($Y53$PI)RD["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@9')O<%-E<75E;F-E*"D*"B`@("`O*BH*
M("`@("`J($1E;&5T97,@82!S97%U96YC90H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'-E<5]N86UE("!N86UE(&]F('1H92!S97%U96YC92!T;R!B
M92!D96QE=&5D"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N
M('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@
M("H*("`@("`J($!S964@1$)?8V]M;6]N.CID<F]P4V5Q=65N8V4H*2P@1$)?
M8V]M;6]N.CIG971397%U96YC94YA;64H*2P*("`@("`J("`@("`@1$)?;7-S
M<6PZ.FYE>'1)1"@I+"!$0E]M<W-Q;#HZ8W)E871E4V5Q=65N8V4H*0H@("`@
M("HO"B`@("!F=6YC=&EO;B!D<F]P4V5Q=65N8V4H)'-E<5]N86UE*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^<75E<GDH)T123U`@5$%"3$4@)R`N
M("1T:&ES+3YG971397%U96YC94YA;64H)'-E<5]N86UE*2D["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@<75O=&5)9&5N=&EF:65R*"D*"B`@("`O
M*BH*("`@("`J(%%U;W1E<R!A('-T<FEN9R!S;R!I="!C86X@8F4@<V%F96QY
M('5S960@87,@82!T86)L92!O<B!C;VQU;6X@;F%M90H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'-T<B`@:61E;G1I9FEE<B!N86UE('1O(&)E('%U
M;W1E9`H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!Q=6]T960@:61E
M;G1I9FEE<B!S=')I;F<*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ
M<75O=&5)9&5N=&EF:65R*"D*("`@("`J($!S:6YC92!-971H;V0@879A:6QA
M8FQE('-I;F-E(%)E;&5A<V4@,2XV+C`*("`@("`J+PH@("`@9G5N8W1I;VX@
M<75O=&5)9&5N=&EF:65R*"1S='(I"B`@("!["B`@("`@("`@<F5T=7)N("=;
M)R`N('-T<E]R97!L86-E*"==)RP@)UU=)RP@)'-T<BD@+B`G72<["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;7-S<6Q286ES945R<F]R*"D*"B`@
M("`O*BH*("`@("`J(%!R;V1U8V5S(&$@1$)?17)R;W(@;V)J96-T(')E9V%R
M9&EN9R!T:&4@8W5R<F5N="!P<F]B;&5M"B`@("`@*@H@("`@("H@0'!A<F%M
M(&EN="`D97)R;F\@(&EF('1H92!E<G)O<B!I<R!B96EN9R!M86YU86QL>2!R
M86ES960@<&%S<R!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@($1"7T52
M4D]2*B!C;VYS=&%N="!H97)E+B`@268@=&AI<R!I<VXG="!P87-S960*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@=&AE(&5R<F]R(&EN9F]R;6%T:6]N
M(&=A=&AE<F5D(&9R;VT@=&AE($1"35,N"B`@("`@*@H@("`@("H@0')E='5R
M;B!O8FIE8W0@('1H92!$0E]%<G)O<B!O8FIE8W0*("`@("`J"B`@("`@*B!`
M<V5E($1"7V-O;6UO;CHZ<F%I<V5%<G)O<B@I+`H@("`@("H@("`@("!$0E]M
M<W-Q;#HZ97)R;W).871I=F4H*2P@1$)?;7-S<6PZ.F5R<F]R0V]D92@I"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&US<W%L4F%I<V5%<G)O<B@D8V]D92`](&YU
M;&PI"B`@("!["B`@("`@("`@)&UE<W-A9V4@/2!`;7-S<6Q?9V5T7VQA<W1?
M;65S<V%G92@I.PH@("`@("`@(&EF("@A)&-O9&4I('L*("`@("`@("`@("`@
M)&-O9&4@/2`D=&AI<RT^97)R;W).871I=F4H*3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1T:&ES+3YE<G)O<D-O9&4H
M)&-O9&4L("1M97-S86=E*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@;G5L;"P@;G5L;"P@;G5L;"P@(B1C;V1E("T@)&UE<W-A9V4B*3L*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!E<G)O<DYA=&EV92@I"@H@
M("`@+RHJ"B`@("`@*B!'971S('1H92!$0DU3)R!N871I=F4@97)R;W(@8V]D
M92!P<F]D=6-E9"!B>2!T:&4@;&%S="!Q=65R>0H@("`@("H*("`@("`J($!R
M971U<FX@:6YT("!T:&4@1$)-4R<@97)R;W(@8V]D90H@("`@("HO"B`@("!F
M=6YC=&EO;B!E<G)O<DYA=&EV92@I"B`@("!["B`@("`@("`@)')E<R`]($!M
M<W-Q;%]Q=65R>2@G<V5L96-T($!`15)23U(@87,@17)R;W)#;V1E)RP@)'1H
M:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@(&EF("@A)')E<RD@>PH@("`@("`@
M("`@("!R971U<FX@1$)?15)23U(["B`@("`@("`@?0H@("`@("`@("1R;W<@
M/2!`;7-S<6Q?9F5T8VA?<F]W*"1R97,I.PH@("`@("`@(')E='5R;B`D<F]W
M6S!=.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&5R<F]R0V]D92@I
M"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S(%!%05(Z.D1"(&5R<F]R(&-O
M9&4@9G)O;2!M<W-Q;"=S(&YA=&EV92!C;V1E<RX*("`@("`J"B`@("`@*B!)
M9B`\=F%R/B1N871I=F5C;V1E/"]V87(^(&ES;B=T(&MN;W=N('EE="P@:70@
M=VEL;"!B92!L;V]K960@=7`N"B`@("`@*@H@("`@("H@0'!A<F%M("!M:7AE
M9"`@)&YA=&EV96-O9&4@(&US<W%L(&5R<F]R(&-O9&4L(&EF(&MN;W=N"B`@
M("`@*B!`<F5T=7)N(&EN=&5G97(@(&%N(&5R<F]R(&YU;6)E<B!F<F]M(&$@
M1$(@97)R;W(@8V]N<W1A;G0*("`@("`J($!S964@97)R;W).871I=F4H*0H@
M("`@("HO"B`@("!F=6YC=&EO;B!E<G)O<D-O9&4H)&YA=&EV96-O9&4@/2!N
M=6QL+"`D;7-G(#T@)R<I"B`@("!["B`@("`@("`@:68@*"$D;F%T:79E8V]D
M92D@>PH@("`@("`@("`@("`D;F%T:79E8V]D92`]("1T:&ES+3YE<G)O<DYA
M=&EV92@I.PH@("`@("`@('T*("`@("`@("!I9B`H:7-S970H)'1H:7,M/F5R
M<F]R8V]D95]M87!;)&YA=&EV96-O9&5=*2D@>PH@("`@("`@("`@("!I9B`H
M)&YA=&EV96-O9&4@/3T@,S<P,0H@("`@("`@("`@("`@("`@)B8@<')E9U]M
M871C:"@G+T-A;FYO="!D<F]P('1H92!I;F1E>"]I)RP@)&US9RDI"B`@("`@
M("`@("`@('L*("`@("`@("`@("`@("`@(')E='5R;B!$0E]%4E)/4E].3U1?
M1D]53D0["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YE<G)O<F-O9&5?;6%P6R1N871I=F5C;V1E73L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@1$)?15)23U(["B`@("`@("`@?0H@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[('1A8FQE26YF;R@I"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS(&EN9F]R;6%T:6]N(&%B;W5T(&$@=&%B;&4@;W(@
M82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@3D]413H@;VYL>2!S=7!P;W)T
M<R`G=&%B;&4G(&%N9"`G9FQA9W,G(&EF(#QV87(^)')E<W5L=#PO=F%R/@H@
M("`@("H@:7,@82!T86)L92!N86UE+@H@("`@("H*("`@("`J($!P87)A;2!O
M8FIE8W1\<W1R:6YG("`D<F5S=6QT("!$0E]R97-U;'0@;V)J96-T(&9R;VT@
M82!Q=65R>2!O<B!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('-T<FEN9R!C;VYT86EN:6YG('1H92!N86UE(&]F(&$@=&%B;&4N
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%=H:6QE
M('1H:7,@86QS;R!A8V-E<'1S(&$@<75E<GD@<F5S=6QT"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E<V]U<F-E(&ED96YT:69I
M97(L('1H:7,@8F5H879I;W(@:7,*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@9&5P<F5C871E9"X*("`@("`J($!P87)A;2!I;G0@
M("`@("`@("`@("`D;6]D92`@("!A('9A;&ED('1A8FQE26YF;R!M;V1E"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@86X@87-S;V-I871I=F4@87)R
M87D@=VET:"!T:&4@:6YF;W)M871I;VX@<F5Q=65S=&5D+@H@("`@("H@("`@
M("`@("`@("`@("`@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@
M("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G1A8FQE26YF;R@I"B`@("`@
M*B\*("`@(&9U;F-T:6]N('1A8FQE26YF;R@D<F5S=6QT+"`D;6]D92`](&YU
M;&PI"B`@("!["B`@("`@("`@:68@*&ES7W-T<FEN9R@D<F5S=6QT*2D@>PH@
M("`@("`@("`@("`O*@H@("`@("`@("`@("`@*B!0<F]B86)L>2!R96-E:79E
M9"!A('1A8FQE(&YA;64N"B`@("`@("`@("`@("`J($-R96%T92!A(')E<W5L
M="!R97-O=7)C92!I9&5N=&EF:65R+@H@("`@("`@("`@("`@*B\*("`@("`@
M("`@("`@:68@*"%`;7-S<6Q?<V5L96-T7V1B*"1T:&ES+3Y?9&(L("1T:&ES
M+3YC;VYN96-T:6]N*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YM<W-Q;%)A:7-E17)R;W(H1$)?15)23U)?3D]$0E-%3$5#5$5$*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D:60@/2!`;7-S<6Q?<75E<GDH(E-%
M3$5#5"`J($923TT@)')E<W5L="!72$5212`Q/3`B+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@
M("`@("`D9V]T7W-T<FEN9R`]('1R=64["B`@("`@("`@?2!E;'-E:68@*&ES
M<V5T*"1R97-U;'0M/G)E<W5L="DI('L*("`@("`@("`@("`@+RH*("`@("`@
M("`@("`@("H@4')O8F%B;'D@<F5C96EV960@82!R97-U;'0@;V)J96-T+@H@
M("`@("`@("`@("`@*B!%>'1R86-T('1H92!R97-U;'0@<F5S;W5R8V4@:61E
M;G1I9FEE<BX*("`@("`@("`@("`@("HO"B`@("`@("`@("`@("1I9"`]("1R
M97-U;'0M/G)E<W5L=#L*("`@("`@("`@("`@)&=O=%]S=')I;F<@/2!F86QS
M93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*@H@("`@("`@("`@
M("`@*B!0<F]B86)L>2!R96-E:79E9"!A(')E<W5L="!R97-O=7)C92!I9&5N
M=&EF:65R+@H@("`@("`@("`@("`@*B!#;W!Y(&ET+@H@("`@("`@("`@("`@
M*B!$97!R96-A=&5D+B`@2&5R92!F;W(@8V]M<&%T:6)I;&ET>2!O;FQY+@H@
M("`@("`@("`@("`@*B\*("`@("`@("`@("`@)&ED(#T@)')E<W5L=#L*("`@
M("`@("`@("`@)&=O=%]S=')I;F<@/2!F86QS93L*("`@("`@("!]"@H@("`@
M("`@(&EF("@A:7-?<F5S;W5R8V4H)&ED*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/FUS<W%L4F%I<V5%<G)O<BA$0E]%4E)/4E].145$7TU/4D5?
M1$%402D["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;
M)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465],3U=%4D-!4T4I('L*
M("`@("`@("`@("`@)&-A<V5?9G5N8R`]("=S=')T;VQO=V5R)SL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D8V%S95]F=6YC(#T@)W-T<G9A;"<[
M"B`@("`@("`@?0H*("`@("`@("`D8V]U;G0@/2!`;7-S<6Q?;G5M7V9I96QD
M<R@D:60I.PH@("`@("`@("1R97,@("`](&%R<F%Y*"D["@H@("`@("`@(&EF
M("@D;6]D92D@>PH@("`@("`@("`@("`D<F5S6R=N=6U?9FEE;&1S)UT@/2`D
M8V]U;G0["B`@("`@("`@?0H*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D
M8V]U;G0[("1I*RLI('L*("`@("`@("`@("`@)')E<ULD:5T@/2!A<G)A>2@*
M("`@("`@("`@("`@("`@("=T86)L92<@/3X@)&=O=%]S=')I;F<@/R`D8V%S
M95]F=6YC*"1R97-U;'0I(#H@)R<L"B`@("`@("`@("`@("`@("`G;F%M92<@
M(#T^("1C87-E7V9U;F,H0&US<W%L7V9I96QD7VYA;64H)&ED+"`D:2DI+`H@
M("`@("`@("`@("`@("`@)W1Y<&4G("`]/B!`;7-S<6Q?9FEE;&1?='EP92@D
M:60L("1I*2P*("`@("`@("`@("`@("`@("=L96XG("`@/3X@0&US<W%L7V9I
M96QD7VQE;F=T:"@D:60L("1I*2P*("`@("`@("`@("`@("`@("\O(%=E(&]N
M;'D@<W5P<&]R="!F;&%G<R!F;W(@=&%B;&4*("`@("`@("`@("`@("`@("=F
M;&%G<R<@/3X@)&=O=%]S=')I;F<*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/R`D=&AI<RT^7VUS<W%L7V9I96QD7V9L86=S*"1R97-U;'0L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!`;7-S<6Q?9FEE;&1?;F%M92@D:60L("1I*2D*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@.B`G)RP*("`@("`@("`@("`@*3L*("`@("`@("`@
M("`@:68@*"1M;V1E("8@1$)?5$%"3$5)3D9/7T]21$52*2!["B`@("`@("`@
M("`@("`@("`D<F5S6R=O<F1E<B==6R1R97-;)&E=6R=N86UE)UU=(#T@)&D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1M;V1E("8@1$)?5$%"
M3$5)3D9/7T]21$525$%"3$4I('L*("`@("`@("`@("`@("`@("1R97-;)V]R
M9&5R=&%B;&4G75LD<F5S6R1I75LG=&%B;&4G75U;)')E<ULD:5U;)VYA;64G
M75T@/2`D:3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@
M9G)E92!T:&4@<F5S=6QT(&]N;'D@:68@=V4@=V5R92!C86QL960@;VX@82!T
M86)L90H@("`@("`@(&EF("@D9V]T7W-T<FEN9RD@>PH@("`@("`@("`@("!`
M;7-S<6Q?9G)E95]R97-U;'0H)&ED*3L*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N("1R97,["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@7VUS<W%L
M7V9I96QD7V9L86=S*"D*"B`@("`O*BH*("`@("`J($=E="!A(&-O;'5M;B=S
M(&9L86=S"B`@("`@*@H@("`@("H@4W5P<&]R=',@(FYO=%]N=6QL(BP@(G!R
M:6UA<GE?:V5Y(BP*("`@("`J(")A=71O7VEN8W)E;65N="(@*&US<W%L(&ED
M96YT:71Y*2P@(G1I;65S=&%M<"(@*&US<W%L('1I;65S=&%M<"DL"B`@("`@
M*B`B=6YI<75E7VME>2(@*&US<W%L('5N:7%U92!I;F1E>"P@=6YI<75E(&-H
M96-K(&]R('!R:6UA<GE?:V5Y*2!A;F0*("`@("`J(")M=6QT:7!L95]K97DB
M("AM=6QT:6ME>2!I;F1E>"D*("`@("`J"B`@("`@*B!M<W-Q;"!T:6UE<W1A
M;7`@:7,@3D]4('-I;6EL87(@=&\@=&AE(&UY<W%L('1I;65S=&%M<"!S;R!T
M:&ES(&ES(&UA>6)E"B`@("`@*B!N;W0@=7-E9G5L(&%T(&%L;"`M(&ES('1H
M92!B96AA=FEO=7(@;V8@;7ES<6Q?9FEE;&1?9FQA9W,@=&AA="!P<FEM87)Y
M"B`@("`@*B!K97ES(&%R92!A;'=A>2!U;FEQ=64_(&ES('1H92!I;G1E<G!R
M971A=&EO;B!O9B!M=6QT:7!L95]K97D@8V]R<F5C=#\*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1T86)L92`@('1H92!T86)L92!N86UE"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1C;VQU;6X@('1H92!F:65L9"!N86UE"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!F;&%G<PH@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0&%U=&AO<B!*;V5R;B!"87)T
M:&5L(#QJ7V)A<G1H96Q`=V5B+F1E/@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M;7-S<6Q?9FEE;&1?9FQA9W,H)'1A8FQE+"`D8V]L=6UN*0H@("`@>PH@("`@
M("`@('-T871I8R`D=&%B;&5.86UE(#T@;G5L;#L*("`@("`@("!S=&%T:6,@
M)&9L86=S(#T@87)R87DH*3L*"B`@("`@("`@:68@*"1T86)L92`A/2`D=&%B
M;&5.86UE*2!["@H@("`@("`@("`@("`D9FQA9W,@/2!A<G)A>2@I.PH@("`@
M("`@("`@("`D=&%B;&5.86UE(#T@)'1A8FQE.PH*("`@("`@("`@("`@+R\@
M9V5T('5N:7%U92!A;F0@<')I;6%R>2!K97ES"B`@("`@("`@("`@("1R97,@
M/2`D=&AI<RT^9V5T06QL*")%6$5#(%-07TA%3%!)3D1%6%LD=&%B;&5=(BP@
M1$)?1D540TA-3T1%7T%34T]#*3L*"B`@("`@("`@("`@(&9O<F5A8V@@*"1R
M97,@87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@)&ME>7,@/2!E>'!L;V1E
M*"<L("<L("1V86Q;)VEN9&5X7VME>7,G72D["@H@("`@("`@("`@("`@("`@
M:68@*'-I>F5O9B@D:V5Y<RD@/B`Q*2!["B`@("`@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)&ME>7,@87,@)&ME>2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7V%D9%]F;&%G*"1F;&%G<ULD:V5Y72P@)VUU;'1I<&QE
M7VME>2<I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("!I9B`H<W1R<&]S*"1V86Q;)VEN9&5X7V1E
M<V-R:7!T:6]N)UTL("=P<FEM87)Y(&ME>2<I*2!["B`@("`@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)&ME>7,@87,@)&ME>2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7V%D9%]F;&%G*"1F;&%G<ULD:V5Y72P@)W!R
M:6UA<GE?:V5Y)RD["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?2!E;'-E:68@*'-T<G!O<R@D=F%L6R=I;F1E>%]D97-C<FEP=&EO
M;B==+"`G=6YI<75E)RDI('L*("`@("`@("`@("`@("`@("`@("!F;W)E86-H
M("@D:V5Y<R!A<R`D:V5Y*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?861D7V9L86<H)&9L86=S6R1K97E=+"`G=6YI<75E7VME>2<I.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@+R\@9V5T(&%U=&]?:6YC<F5M96YT+"!N
M;W1?;G5L;"!A;F0@=&EM97-T86UP"B`@("`@("`@("`@("1R97,@/2`D=&AI
M<RT^9V5T06QL*")%6$5#(%-07T-/3%5-3E-;)'1A8FQE72(L($1"7T9%5$-(
M34]$15]!4U-/0RD["@H@("`@("`@("`@("!F;W)E86-H("@D<F5S(&%S("1V
M86PI('L*("`@("`@("`@("`@("`@("1V86P@/2!A<G)A>5]C:&%N9V5?:V5Y
M7V-A<V4H)'9A;"P@0T%315],3U=%4BD["B`@("`@("`@("`@("`@("!I9B`H
M)'9A;%LG;G5L;&%B;&4G72`]/2`G,"<I('L*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V%D9%]F;&%G*"1F;&%G<ULD=F%L6R=C;VQU;6Y?;F%M92==
M72P@)VYO=%]N=6QL)RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!I9B`H<W1R<&]S*"1V86Q;)W1Y<&5?;F%M92==+"`G:61E;G1I='DG
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?861D7V9L86<H)&9L
M86=S6R1V86Q;)V-O;'5M;E]N86UE)UU=+"`G875T;U]I;F-R96UE;G0G*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("AS=')P;W,H
M)'9A;%LG='EP95]N86UE)UTL("=T:6UE<W1A;7`G*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?861D7V9L86<H)&9L86=S6R1V86Q;)V-O;'5M
M;E]N86UE)UU=+"`G=&EM97-T86UP)RD["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("AA<G)A>5]K97E?
M97AI<W1S*"1C;VQU;6XL("1F;&%G<RDI('L*("`@("`@("`@("`@<F5T=7)N
M*&EM<&QO9&4H)R`G+"`D9FQA9W-;)&-O;'5M;ETI*3L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N("<G.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(%]A9&1?9FQA9R@I"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@<W1R:6YG('1O
M('1H92!F;&%G<R!A<G)A>2!I9B!T:&4@9FQA9R!I<R!N;W0@>65T(&EN('1H
M97)E"B`@("`@*B`M(&EF('1H97)E(&ES(&YO(&9L86<@<')E<V5N="!T:&4@
M87)R87D@:7,@8W)E871E9`H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`@
M)B1A<G)A>2`@=&AE(')E9F5R96YC92!T;R!T:&4@9FQA9RUA<G)A>0H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=F%L=64@("!T:&4@9FQA9R!V86QU90H@("`@
M("H*("`@("`J($!R971U<FX@=F]I9`H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H@0&%U=&AO<B!*;V5R;B!"87)T:&5L(#QJ7V)A<G1H
M96Q`=V5B+F1E/@H@("`@("HO"B`@("!F=6YC=&EO;B!?861D7V9L86<H)B1A
M<G)A>2P@)'9A;'5E*0H@("`@>PH@("`@("`@(&EF("@A:7-?87)R87DH)&%R
M<F%Y*2D@>PH@("`@("`@("`@("`D87)R87D@/2!A<G)A>2@D=F%L=64I.PH@
M("`@("`@('T@96QS96EF("@A:6Y?87)R87DH)'9A;'5E+"`D87)R87DI*2![
M"B`@("`@("`@("`@(&%R<F%Y7W!U<V@H)&%R<F%Y+"`D=F%L=64I.PH@("`@
M("`@('T*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G9713<&5C:6%L
M475E<GDH*0H*("`@("\J*@H@("`@("H@3V)T86EN<R!T:&4@<75E<GD@<W1R
M:6YG(&YE961E9"!F;W(@;&ES=&EN9R!A(&=I=F5N('1Y<&4@;V8@;V)J96-T
M<PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@('1H92!K:6YD
M(&]F(&]B:F5C=',@>6]U('=A;G0@=&\@<F5T<FEE=F4*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@=&AE(%-13"!Q=65R>2!S=')I;F<@;W(@;G5L
M;"!I9B!T:&4@9')I=F5R(&1O97-N)W0*("`@("`J("`@("`@("`@("`@("`@
M("`@<W5P<&]R="!T:&4@;V)J96-T('1Y<&4@<F5Q=65S=&5D"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J($!S964@1$)?8V]M;6]N
M.CIG971,:7-T3V8H*0H@("`@("HO"B`@("!F=6YC=&EO;B!G9713<&5C:6%L
M475E<GDH)'1Y<&4I"B`@("!["B`@("`@("`@<W=I=&-H("@D='EP92D@>PH@
M("`@("`@("`@("!C87-E("=T86)L97,G.@H@("`@("`@("`@("`@("`@<F5T
M=7)N(")314Q%0U0@;F%M92!&4D]-('-Y<V]B:F5C=',@5TA%4D4@='EP92`]
M("=5)R(*("`@("`@("`@("`@("`@("`@("`@("`N("<@3U)$15(@0ED@;F%M
M92<["B`@("`@("`@("`@(&-A<V4@)W9I97=S)SH*("`@("`@("`@("`@("`@
M(')E='5R;B`B4T5,14-4(&YA;64@1E)/32!S>7-O8FIE8W1S(%=(15)%('1Y
M<&4@/2`G5B<B.PH@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@
M("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0I]
M"@HO*@H@*B!,;V-A;"!V87)I86)L97,Z"B`J('1A8BUW:61T:#H@-`H@*B!C
M+6)A<VEC+6]F9G-E=#H@-`H@*B!%;F0Z"B`J+PH*/SX*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]$0B]M>7-Q;"YP:'``````````````````````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#<W,#0W(#$P-3$U-#,S-S,Q
M(#`R,#8T-@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`H*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S
M:&EF='=I9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*"B\J*@H@*B!4:&4@4$5!
M4B!$0B!D<FEV97(@9F]R(%!(4"=S(&UY<W%L(&5X=&5N<VEO;@H@*B!F;W(@
M:6YT97)A8W1I;F<@=VET:"!->5-13"!D871A8F%S97,*("H*("H@4$A0('9E
M<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL
M92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS
M90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E
M+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@
M82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T
M;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*("H@<V5N9"!A
M(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A
M(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E
M"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N
M(#QS<V)`<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O
M<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@
M5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I
M;VX@("`@0U93.B`D260Z(&UY<W%L+G!H<"QV(#$N,3$W(#(P,#4O,#,O,CD@
M,34Z,#,Z,C8@9&%N:65L8R!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO"@HO*BH*("H@3V)T86EN('1H
M92!$0E]C;VUM;VX@8VQA<W,@<V\@:70@8V%N(&)E(&5X=&5N9&5D(&9R;VT*
M("HO"G)E<75I<F5?;VYC92`G1$(O8V]M;6]N+G!H<"<["@HO*BH*("H@5&AE
M(&UE=&AO9',@4$5!4B!$0B!U<V5S('1O(&EN=&5R86-T('=I=&@@4$A0)W,@
M;7ES<6P@97AT96YS:6]N"B`J(&9O<B!I;G1E<F%C=&EN9R!W:71H($UY4U%,
M(&1A=&%B87-E<PH@*@H@*B!4:&5S92!M971H;V1S(&]V97)L;V%D('1H92!O
M;F5S(&1E8VQA<F5D(&EN($1"7V-O;6UO;BX*("H*("H@0&-A=&5G;W)Y("`@
M1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@4W1I
M9R!"86MK96X@/'-S8D!P:'`N;F5T/@H@*B!`875T:&]R("`@("!$86YI96P@
M0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y
M.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@
M*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C<N-@H@*B!`;&EN:R`@("`@("!H
M='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO"F-L87-S($1"7VUY
M<W%L(&5X=&5N9',@1$)?8V]M;6]N"GL*("`@("\O('M[>R!P<F]P97)T:65S
M"@H@("`@+RHJ"B`@("`@*B!4:&4@1$(@9')I=F5R('1Y<&4@*&UY<W%L+"!O
M8VDX+"!O9&)C+"!E=&,N*0H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@
M("`@=F%R("1P:'!T>7!E(#T@)VUY<W%L)SL*"B`@("`O*BH*("`@("`J(%1H
M92!D871A8F%S92!S>6YT87@@=F%R:6%N="!T;R!B92!U<V5D("AD8C(L(&%C
M8V5S<RP@971C+BDL(&EF(&%N>0H@("`@("H@0'9A<B!S=')I;F<*("`@("`J
M+PH@("`@=F%R("1D8G-Y;G1A>"`]("=M>7-Q;"<["@H@("`@+RHJ"B`@("`@
M*B!4:&4@8V%P86)I;&ET:65S(&]F('1H:7,@1$(@:6UP;&5M96YT871I;VX*
M("`@("`J"B`@("`@*B!4:&4@)VYE=U]L:6YK)R!E;&5M96YT(&-O;G1A:6YS
M('1H92!02%`@=F5R<VEO;B!T:&%T(&9I<G-T('!R;W9I9&5D"B`@("`@*B!N
M97=?;&EN:R!S=7!P;W)T(&9O<B!T:&ES($1"35,N("!#;VYT86EN<R!F86QS
M92!I9B!I="=S('5N<W5P<&]R=&5D+@H@("`@("H*("`@("`J($UE86YI;F<@
M;V8@=&AE("=L:6UI="<@96QE;65N=#H*("`@("`J("`@*R`G96UU;&%T92<@
M/2!E;75L871E('=I=&@@9F5T8V@@<F]W(&)Y(&YU;6)E<@H@("`@("H@("`K
M("=A;'1E<B<@("`](&%L=&5R('1H92!Q=65R>0H@("`@("H@("`K(&9A;'-E
M("`@("`]('-K:7`@<F]W<PH@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1F96%T=7)E<R`](&%R<F%Y*`H@("`@("`@("=L:6UI
M="<@("`@("`@("`]/B`G86QT97(G+`H@("`@("`@("=N97=?;&EN:R<@("`@
M("`]/B`G-"XR+C`G+`H@("`@("`@("=N=6UR;W=S)R`@("`@("`]/B!T<G5E
M+`H@("`@("`@("=P8V]N;F5C="<@("`@("`]/B!T<G5E+`H@("`@("`@("=P
M<F5P87)E)R`@("`@("`]/B!F86QS92P*("`@("`@("`G<W-L)R`@("`@("`@
M("`@/3X@9F%L<V4L"B`@("`@("`@)W1R86YS86-T:6]N<R<@(#T^('1R=64L
M"B`@("`I.PH*("`@("\J*@H@("`@("H@02!M87!P:6YG(&]F(&YA=&EV92!E
M<G)O<B!C;V1E<R!T;R!$0B!E<G)O<B!C;V1E<PH@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)&5R<F]R8V]D95]M87`@/2!A<G)A>2@*("`@
M("`@("`Q,#`T(#T^($1"7T524D]27T-!3DY/5%]#4D5!5$4L"B`@("`@("`@
M,3`P-2`]/B!$0E]%4E)/4E]#04Y.3U1?0U)%051%+`H@("`@("`@(#$P,#8@
M/3X@1$)?15)23U)?0T%.3D]47T-214%412P*("`@("`@("`Q,#`W(#T^($1"
M7T524D]27T%,4D5!1%E?15A)4U13+`H@("`@("`@(#$P,#@@/3X@1$)?15)2
M3U)?0T%.3D]47T123U`L"B`@("`@("`@,3`R,B`]/B!$0E]%4E)/4E]!3%)%
M04197T5825-44RP*("`@("`@("`Q,#0T(#T^($1"7T524D]27T%#0T534U]6
M24],051)3TXL"B`@("`@("`@,3`T-B`]/B!$0E]%4E)/4E].3T1"4T5,14-4
M140L"B`@("`@("`@,3`T."`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@
M("`@(#$P-#D@/3X@1$)?15)23U)?3D]354-(1$(L"B`@("`@("`@,3`U,"`]
M/B!$0E]%4E)/4E]!3%)%04197T5825-44RP*("`@("`@("`Q,#4Q(#T^($1"
M7T524D]27TY/4U5#2%1!0DQ%+`H@("`@("`@(#$P-30@/3X@1$)?15)23U)?
M3D]354-(1DE%3$0L"B`@("`@("`@,3`V,2`]/B!$0E]%4E)/4E]!3%)%0419
M7T5825-44RP*("`@("`@("`Q,#8R(#T^($1"7T524D]27T%,4D5!1%E?15A)
M4U13+`H@("`@("`@(#$P-C0@/3X@1$)?15)23U)?4UE.5$%8+`H@("`@("`@
M(#$P.3$@/3X@1$)?15)23U)?3D]47T9/54Y$+`H@("`@("`@(#$Q,#`@/3X@
M1$)?15)23U)?3D]47TQ/0TM%1"P*("`@("`@("`Q,3,V(#T^($1"7T524D]2
M7U9!3%5%7T-/54Y47T].7U)/5RP*("`@("`@("`Q,30R(#T^($1"7T524D]2
M7T%#0T534U]624],051)3TXL"B`@("`@("`@,3$T-B`]/B!$0E]%4E)/4E].
M3U-50TA404),12P*("`@("`@("`Q,C$V(#T^($1"7T524D]27T-/3E-44D%)
M3E0L"B`@("`@("`@,3(Q-R`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@
M*3L*"B`@("`O*BH*("`@("`J(%1H92!R87<@9&%T86)A<V4@8V]N;F5C=&EO
M;B!C<F5A=&5D(&)Y(%!(4`H@("`@("H@0'9A<B!R97-O=7)C90H@("`@("HO
M"B`@("!V87(@)&-O;FYE8W1I;VX["@H@("`@+RHJ"B`@("`@*B!4:&4@1%-.
M(&EN9F]R;6%T:6]N(&9O<B!C;VYN96-T:6YG('1O(&$@9&%T86)A<V4*("`@
M("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1D<VX@/2!A<G)A>2@I
M.PH*"B`@("`O*BH*("`@("`J(%-H;W5L9"!D871A(&UA;FEP=6QA=&EO;B!Q
M=65R:65S(&)E(&-O;6UI='1E9"!A=71O;6%T:6-A;&QY/PH@("`@("H@0'9A
M<B!B;V]L"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R
M("1A=71O8V]M;6ET(#T@=')U93L*"B`@("`O*BH*("`@("`J(%1H92!Q=6%N
M=&ET>2!O9B!T<F%N<V%C=&EO;G,@8F5G=6X*("`@("`J"B`@("`@*B![0&EN
M=&5R;F%L("!7:&EL92!T:&ES(&ES('!R:79A=&4L(&ET(&-A;B=T(&%C='5A
M;&QY(&)E(&1E<VEG;F%T960*("`@("`J('!R:79A=&4@:6X@4$A0(#4@8F5C
M875S92!I="!I<R!D:7)E8W1L>2!A8V-E<W-E9"!I;B!T:&4@=&5S="!S=6ET
M92Y]?0H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D=')A;G-A8W1I;VY?;W!C;W5N
M="`](#`["@H@("`@+RHJ"B`@("`@*B!4:&4@9&%T86)A<V4@<W!E8VEF:65D
M(&EN('1H92!$4TX*("`@("`J"B`@("`@*B!)="=S(&$@9FEX('1O(&%L;&]W
M(&-A;&QS('1O(&1I9F9E<F5N="!D871A8F%S97,@:6X@=&AE('-A;64@<V-R
M:7!T+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?9&(@/2`G)SL*"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@8V]N<W1R=6-T;W(*"B`@("`O*BH*("`@("`J(%1H
M:7,@8V]N<W1R=6-T;W(@8V%L;',@/&MB9#XD=&AI<RT^1$)?8V]M;6]N*"D\
M+VMB9#X*("`@("`J"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@
M9G5N8W1I;VX@1$)?;7ES<6PH*0H@("`@>PH@("`@("`@("1T:&ES+3Y$0E]C
M;VUM;VXH*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VYN96-T
M*"D*"B`@("`O*BH*("`@("`J($-O;FYE8W0@=&\@=&AE(&1A=&%B87-E('-E
M<G9E<BP@;&]G(&EN(&%N9"!O<&5N('1H92!D871A8F%S90H@("`@("H*("`@
M("`J($1O;B=T(&-A;&P@=&AI<R!M971H;V0@9&ER96-T;'DN("!5<V4@1$(Z
M.F-O;FYE8W0H*2!I;G-T96%D+@H@("`@("H*("`@("`J(%!%05(@1$(G<R!M
M>7-Q;"!D<FEV97(@<W5P<&]R=',@=&AE(&9O;&QO=VEN9R!E>'1R82!$4TX@
M;W!T:6]N<SH*("`@("`J("`@*R!N97=?;&EN:R`@("`@($EF('-E="!T;R!T
M<G5E+"!C875S97,@<W5B<V5Q=65N="!C86QL<R!T;R!C;VYN96-T*"D*("`@
M("`J("`@("`@("`@("`@("`@("`@("!T;R!R971U<FX@82!N97<@8V]N;F5C
M=&EO;B!L:6YK(&EN<W1E860@;V8@=&AE"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@97AI<W1I;F<@;VYE+B`@5T%23DE.1SH@=&AI<R!I<R!N;W0@<&]R
M=&%B;&4@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("!O=&AE<B!$0DU3
M)W,N($%V86EL86)L92!S:6YC92!014%2($1"(#$N-RXP+@H@("`@("H@("`K
M(&-L:65N=%]F;&%G<R`@06YY(&-O;6)I;F%T:6]N(&]F($U94U%,7T-,245.
M5%\J(&-O;G-T86YT<RX*("`@("`J("`@("`@("`@("`@("`@("`@("!/;FQY
M('5S960@:68@4$A0(&ES(&%T('9E<G-I;VX@-"XS+C`@;W(@9W)E871E<BX*
M("`@("`J("`@("`@("`@("`@("`@("`@("!!=F%I;&%B;&4@<VEN8V4@4$5!
M4B!$0B`Q+C<N,"X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&1S;B`@
M("`@("`@('1H92!D871A('-O=7)C92!N86UE"B`@("`@*B!`<&%R86T@8F]O
M;"`@)'!E<G-I<W1E;G0@('-H;W5L9"!T:&4@8V]N;F5C=&EO;B!B92!P97)S
M:7-T96YT/PH@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S
M=6-C97-S+B!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!C;VYN96-T*"1D<VXL("1P97)S:7-T96YT(#T@9F%L
M<V4I"B`@("!["B`@("`@("`@:68@*"%014%2.CIL;V%D17AT96YS:6]N*"=M
M>7-Q;"<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<BA$0E]%4E)/4E]%6%1%3E-)3TY?3D]47T9/54Y$*3L*("`@("`@("!]"@H@
M("`@("`@("1T:&ES+3YD<VX@/2`D9'-N.PH@("`@("`@(&EF("@D9'-N6R=D
M8G-Y;G1A>"==*2!["B`@("`@("`@("`@("1T:&ES+3YD8G-Y;G1A>"`]("1D
M<VY;)V1B<WEN=&%X)UT["B`@("`@("`@?0H*("`@("`@("`D<&%R86US(#T@
M87)R87DH*3L*("`@("`@("!I9B`H)&1S;ELG<')O=&]C;VPG72`F)B`D9'-N
M6R=P<F]T;V-O;"==(#T]("=U;FEX)RD@>PH@("`@("`@("`@("`D<&%R86US
M6S!=(#T@)SHG("X@)&1S;ELG<V]C:V5T)UT["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'!A<F%M<ULP72`]("1D<VY;)VAO<W1S<&5C)UT@/R`D
M9'-N6R=H;W-T<W!E8R=="B`@("`@("`@("`@("`@("`@("`@("`@("`Z("=L
M;V-A;&AO<W0G.PH@("`@("`@("`@("!I9B`H)&1S;ELG<&]R="==*2!["B`@
M("`@("`@("`@("`@("`D<&%R86US6S!=("X]("<Z)R`N("1D<VY;)W!O<G0G
M73L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D<&%R86US6UT@
M/2`D9'-N6R=U<V5R;F%M92==(#\@)&1S;ELG=7-E<FYA;64G72`Z(&YU;&P[
M"B`@("`@("`@)'!A<F%M<UM=(#T@)&1S;ELG<&%S<W=O<F0G72`_("1D<VY;
M)W!A<W-W;W)D)UT@.B!N=6QL.PH*("`@("`@("!I9B`H(21P97)S:7-T96YT
M*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D9'-N6R=N97=?;&EN:R==*0H@
M("`@("`@("`@("`@("`@)B8@*"1D<VY;)VYE=U]L:6YK)UT@/3T@)W1R=64G
M('Q\("1D<VY;)VYE=U]L:6YK)UT@/3T]('1R=64I*0H@("`@("`@("`@("![
M"B`@("`@("`@("`@("`@("`D<&%R86US6UT@/2!T<G5E.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'!A<F%M<UM=(#T@9F%L<V4[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*'9E<G-I;VY?
M8V]M<&%R92AP:'!V97)S:6]N*"DL("<T+C,N,"<L("<^/2<I*2!["B`@("`@
M("`@("`@("1P87)A;7-;72`](&ES<V5T*"1D<VY;)V-L:65N=%]F;&%G<R==
M*0H@("`@("`@("`@("`@("`@("`@("`@("`_("1D<VY;)V-L:65N=%]F;&%G
M<R==(#H@;G5L;#L*("`@("`@("!]"@H@("`@("`@("1C;VYN96-T7V9U;F-T
M:6]N(#T@)'!E<G-I<W1E;G0@/R`G;7ES<6Q?<&-O;FYE8W0G(#H@)VUY<W%L
M7V-O;FYE8W0G.PH*("`@("`@("`D:6YI(#T@:6YI7V=E="@G=')A8VM?97)R
M;W)S)RD["B`@("`@("`@)'!H<%]E<G)O<FUS9R`]("<G.PH@("`@("`@(&EF
M("@D:6YI*2!["B`@("`@("`@("`@("1T:&ES+3YC;VYN96-T:6]N(#T@0&-A
M;&Q?=7-E<E]F=6YC7V%R<F%Y*"1C;VYN96-T7V9U;F-T:6]N+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<&%R86US*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I;FE?
M<V5T*"=T<F%C:U]E<G)O<G,G+"`Q*3L*("`@("`@("`@("`@)'1H:7,M/F-O
M;FYE8W1I;VX@/2!`8V%L;%]U<V5R7V9U;F-?87)R87DH)&-O;FYE8W1?9G5N
M8W1I;VXL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P87)A;7,I.PH@("`@("`@("`@("!I;FE?<V5T
M*"=T<F%C:U]E<G)O<G,G+"`D:6YI*3L*("`@("`@("!]"@H@("`@("`@(&EF
M("@A)'1H:7,M/F-O;FYE8W1I;VXI('L*("`@("`@("`@("`@:68@*"@D97)R
M(#T@0&UY<W%L7V5R<F]R*"DI("$]("<G*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?0T].3D5#5%]&04E,
M140L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M;G5L;"P@;G5L;"P@;G5L;"P@"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&5R<BD["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)2
M3U)?0T].3D5#5%]&04E,140L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@;G5L;"P@;G5L;"P@;G5L;"P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&AP7V5R<F]R;7-G*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1D<VY;)V1A
M=&%B87-E)UTI('L*("`@("`@("`@("`@:68@*"%`;7ES<6Q?<V5L96-T7V1B
M*"1D<VY;)V1A=&%B87-E)UTL("1T:&ES+3YC;VYN96-T:6]N*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM>7-Q;%)A:7-E17)R;W(H*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7V1B(#T@)&1S;ELG
M9&%T86)A<V4G73L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!$0E]/2SL*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!D:7-C;VYN96-T*"D*"B`@
M("`O*BH*("`@("`J($1I<V-O;FYE8W1S(&9R;VT@=&AE(&1A=&%B87-E('-E
M<G9E<@H@("`@("H*("`@("`J($!R971U<FX@8F]O;"`@5%)512!O;B!S=6-C
M97-S+"!&04Q312!O;B!F86EL=7)E"B`@("`@*B\*("`@(&9U;F-T:6]N(&1I
M<V-O;FYE8W0H*0H@("`@>PH@("`@("`@("1R970@/2!`;7ES<6Q?8VQO<V4H
M)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@("1T:&ES+3YC;VYN96-T:6]N
M(#T@;G5L;#L*("`@("`@("!R971U<FX@)')E=#L*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!S:6UP;&51=65R>2@I"@H@("`@+RHJ"B`@("`@*B!3
M96YD<R!A('%U97)Y('1O('1H92!D871A8F%S92!S97)V97(*("`@("`J"B`@
M("`@*B!'96YE<F%L;'D@=7-E<R!M>7-Q;%]Q=65R>2@I+B`@268@>6]U('=A
M;G0@=&\@=7-E"B`@("`@*B!M>7-Q;%]U;F)U9F9E<F5D7W%U97)Y*"D@<V5T
M('1H92`B<F5S=6QT7V)U9F9E<FEN9R(@;W!T:6]N('1O(#`@=7-I;F<*("`@
M("`J('-E=$]P=&EO;G,H*2X@(%1H:7,@;W!T:6]N('=A<R!A9&1E9"!I;B!2
M96QE87-E(#$N-RXP+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@('1H
M92!344P@<75E<GD@<W1R:6YG"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@*R!A(%!(4"!R97-U;'0@<F5S<F]U8V4@9F]R('-U8V-E<W-F=6P@4T5,
M14-4('%U97)I97,*("`@("`J("`@("`@("`@("`@("`@("L@=&AE($1"7T]+
M(&-O;G-T86YT(&9O<B!O=&AE<B!S=6-C97-S9G5L('%U97)I97,*("`@("`J
M("`@("`@("`@("`@("`@("L@82!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M90H@("`@("HO"B`@("!F=6YC=&EO;B!S:6UP;&51=65R>2@D<75E<GDI"B`@
M("!["B`@("`@("`@)&ES;6%N:7`@/2!$0CHZ:7--86YI<"@D<75E<GDI.PH@
M("`@("`@("1T:&ES+3YL87-T7W%U97)Y(#T@)'%U97)Y.PH@("`@("`@("1Q
M=65R>2`]("1T:&ES+3YM;V1I9GE1=65R>2@D<75E<GDI.PH@("`@("`@(&EF
M("@D=&AI<RT^7V1B*2!["B`@("`@("`@("`@(&EF("@A0&UY<W%L7W-E;&5C
M=%]D8B@D=&AI<RT^7V1B+"`D=&AI<RT^8V]N;F5C=&EO;BDI('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^;7ES<6Q286ES945R<F]R*$1"7T52
M4D]27TY/1$)314Q%0U1%1"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("`@("`@:68@*"$D=&AI<RT^875T;V-O;6UI="`F)B`D:7-M86YI<"D@>PH@
M("`@("`@("`@("!I9B`H)'1H:7,M/G1R86YS86-T:6]N7V]P8V]U;G0@/3T@
M,"D@>PH@("`@("`@("`@("`@("`@)')E<W5L="`]($!M>7-Q;%]Q=65R>2@G
M4T54($%55$]#3TU-250],"<L("1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@
M("`@("`@("`@("1R97-U;'0@/2!`;7ES<6Q?<75E<GDH)T)%1TE.)RP@)'1H
M:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@("`@("`@:68@*"$D<F5S=6QT
M*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM>7-Q;%)A
M:7-E17)R;W(H*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="LK.PH@("`@
M("`@('T*("`@("`@("!I9B`H(21T:&ES+3YO<'1I;VYS6R=R97-U;'1?8G5F
M9F5R:6YG)UTI('L*("`@("`@("`@("`@)')E<W5L="`]($!M>7-Q;%]U;F)U
M9F9E<F5D7W%U97)Y*"1Q=65R>2P@)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1R97-U;'0@/2!`;7ES<6Q?<75E
M<GDH)'%U97)Y+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@?0H@("`@
M("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/FUY<W%L4F%I<V5%<G)O<B@I.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?
M<F5S;W5R8V4H)')E<W5L="DI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!N97AT4F5S=6QT*"D*"B`@("`O*BH*("`@
M("`J($UO=F4@=&AE(&EN=&5R;F%L(&UY<W%L(')E<W5L="!P;VEN=&5R('1O
M('1H92!N97AT(&%V86EL86)L92!R97-U;'0*("`@("`J"B`@("`@*B!4:&ES
M(&UE=&AO9"!H87,@;F]T(&)E96X@:6UP;&5M96YT960@>65T+@H@("`@("H*
M("`@("`J($!P87)A;2!A('9A;&ED('-Q;"!R97-U;'0@<F5S;W5R8V4*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&9A;'-E"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&YE>'1297-U;'0H)')E<W5L="D*("`@('L*("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9F5T8VA);G1O*"D*
M"B`@("`O*BH*("`@("`J(%!L86-E<R!A(')O=R!F<F]M('1H92!R97-U;'0@
M<V5T(&EN=&\@=&AE(&=I=F5N(&%R<F%Y"B`@("`@*@H@("`@("H@1F]R;6%T
M:6YG(&]F('1H92!A<G)A>2!A;F0@=&AE(&1A=&$@=&AE<F5I;B!A<F4@8V]N
M9FEG=7)A8FQE+@H@("`@("H@4V5E($1"7W)E<W5L=#HZ9F5T8VA);G1O*"D@
M9F]R(&UO<F4@:6YF;W)M871I;VXN"B`@("`@*@H@("`@("H@5&AI<R!M971H
M;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@
M("`@("H@1$)?<F5S=6QT.CIF971C:$EN=&\H*2!I;G-T96%D+B`@270@8V%N
M)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?
M<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@("`@("H*("`@("`J($!P
M87)A;2!R97-O=7)C92`D<F5S=6QT("`@('1H92!Q=65R>2!R97-U;'0@<F5S
M;W5R8V4*("`@("`J($!P87)A;2!A<G)A>2`@("`D87)R("`@("`@('1H92!R
M969E<F5N8V5D(&%R<F%Y('1O('!U="!T:&4@9&%T82!I;@H@("`@("H@0'!A
M<F%M(&EN="`@("`@("1F971C:&UO9&4@:&]W('1H92!R97-U;'1I;F<@87)R
M87D@<VAO=6QD(&)E(&EN9&5X960*("`@("`J($!P87)A;2!I;G0@("`@("`D
M<F]W;G5M("`@('1H92!R;W<@;G5M8F5R('1O(&9E=&-H("@P(#T@9FER<W0@
M<F]W*0H@("`@("H*("`@("`J($!R971U<FX@;6EX960@($1"7T]+(&]N('-U
M8V-E<W,L($Y53$P@=VAE;B!T:&4@96YD(&]F(&$@<F5S=6QT('-E="!I<PH@
M("`@("H@("`@("`@("`@("`@("`@(')E86-H960@;W(@;VX@9F%I;'5R90H@
M("`@("H*("`@("`J($!S964@1$)?<F5S=6QT.CIF971C:$EN=&\H*0H@("`@
M("HO"B`@("!F=6YC=&EO;B!F971C:$EN=&\H)')E<W5L="P@)B1A<G(L("1F
M971C:&UO9&4L("1R;W=N=6T@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@D
M<F]W;G5M("$]/2!N=6QL*2!["B`@("`@("`@("`@(&EF("@A0&UY<W%L7V1A
M=&%?<V5E:R@D<F5S=6QT+"`D<F]W;G5M*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(&YU;&P["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@
M:68@*"1F971C:&UO9&4@)B!$0E]&151#2$U/1$5?05-33T,I('L*("`@("`@
M("`@("`@)&%R<B`]($!M>7-Q;%]F971C:%]A<G)A>2@D<F5S=6QT+"!-65-1
M3%]!4U-/0RD["B`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R
M=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197TQ/5T520T%312`F)B`D87)R
M*2!["B`@("`@("`@("`@("`@("`D87)R(#T@87)R87E?8VAA;F=E7VME>5]C
M87-E*"1A<G(L($-!4T5?3$]715(I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&%R<B`]($!M>7-Q;%]F971C:%]R;W<H
M)')E<W5L="D["B`@("`@("`@?0H@("`@("`@(&EF("@A)&%R<BD@>PH@("`@
M("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("`@("`@:68@*"1T
M:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?
M4E1224TI('L*("`@("`@("`@("`@+RH*("`@("`@("`@("`@("H@179E;B!T
M:&]U9V@@=&AI<R!$0DU3(&%L<F5A9'D@=')I;7,@;W5T<'5T+"!W92!D;R!T
M:&ES(&)E8V%U<V4*("`@("`@("`@("`@("H@82!F:65L9"!M:6=H="!H879E
M(&EN=&5N=&EO;F%L('=H:71E<W!A8V4@870@=&AE(&5N9"!T:&%T"B`@("`@
M("`@("`@("`J(&=E=',@<F5M;W9E9"!B>2!$0E]03U)404))3$E465]25%))
M32!U;F1E<B!A;F]T:&5R(&1R:79E<BX*("`@("`@("`@("`@("HO"B`@("`@
M("`@("`@("1T:&ES+3Y?<G1R:6U!<G)A>59A;'5E<R@D87)R*3L*("`@("`@
M("!]"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==
M("8@1$)?4$]25$%"24Q)5%E?3E5,3%]43U]%35!462D@>PH@("`@("`@("`@
M("`D=&AI<RT^7V-O;G9E<G1.=6QL07)R87E686QU97-4;T5M<'1Y*"1A<G(I
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@9G)E95)E<W5L="@I"@H@("`@+RHJ"B`@("`@
M*B!$96QE=&5S('1H92!R97-U;'0@<V5T(&%N9"!F<F5E<R!T:&4@;65M;W)Y
M(&]C8W5P:65D(&)Y('1H92!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@5&AI
M<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@
M(%5S90H@("`@("H@1$)?<F5S=6QT.CIF<F5E*"D@:6YS=&5A9"X@($ET(&-A
M;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E($1"
M7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@*B!`
M<&%R86T@<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@<75E<GD@<F5S=6QT(')E
M<V]U<F-E"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L("!44E5%(&]N('-U
M8V-E<W,L($9!3%-%(&EF("1R97-U;'0@:7,@:6YV86QI9`H@("`@("H*("`@
M("`J($!S964@1$)?<F5S=6QT.CIF<F5E*"D*("`@("`J+PH@("`@9G5N8W1I
M;VX@9G)E95)E<W5L="@D<F5S=6QT*0H@("`@>PH@("`@("`@(')E='5R;B!`
M;7ES<6Q?9G)E95]R97-U;'0H)')E<W5L="D["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@;G5M0V]L<R@I"@H@("`@+RHJ"B`@("`@*B!'971S('1H
M92!N=6UB97(@;V8@8V]L=6UN<R!I;B!A(')E<W5L="!S970*("`@("`J"B`@
M("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I
M<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z.FYU;4-O;',H*2!I;G-T
M96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*("`@("`J
M(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@("`@
M("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT("!02%`G<R!Q=65R
M>2!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@
M=&AE(&YU;6)E<B!O9B!C;VQU;6YS+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@
M9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ;G5M0V]L
M<R@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&YU;4-O;',H)')E<W5L="D*("`@
M('L*("`@("`@("`D8V]L<R`]($!M>7-Q;%]N=6U?9FEE;&1S*"1R97-U;'0I
M.PH@("`@("`@(&EF("@A)&-O;',I('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YM>7-Q;%)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N("1C;VQS.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YU;5)O
M=W,H*0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@;G5M8F5R(&]F(')O=W,@
M:6X@82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@:7,@
M;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@("H@
M1$)?<F5S=6QT.CIN=6U2;W=S*"D@:6YS=&5A9"X@($ET(&-A;B=T(&)E(&1E
M8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E($1"7W)E<W5L="!I
M<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<F5S
M;W5R8V4@)')E<W5L="`@4$A0)W,@<75E<GD@<F5S=6QT(')E<V]U<F-E"B`@
M("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB97(@;V8@<F]W<RX@
M($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@
M0'-E92!$0E]R97-U;'0Z.FYU;5)O=W,H*0H@("`@("HO"B`@("!F=6YC=&EO
M;B!N=6U2;W=S*"1R97-U;'0I"B`@("!["B`@("`@("`@)')O=W,@/2!`;7ES
M<6Q?;G5M7W)O=W,H)')E<W5L="D["B`@("`@("`@:68@*"1R;W=S(#T]/2!N
M=6QL*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;7ES<6Q286ES945R
M<F]R*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F]W<SL*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!A=71O0V]M;6ET*"D*"B`@("`O*BH*
M("`@("`J($5N86)L97,@;W(@9&ES86)L97,@875T;VUA=&EC(&-O;6UI=',*
M("`@("`J"B`@("`@*B!`<&%R86T@8F]O;"`D;VYO9F8@('1R=64@='5R;G,@
M:70@;VXL(&9A;'-E('1U<FYS(&ET(&]F9@H@("`@("H*("`@("`J($!R971U
M<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@
M:68@=&AE(&1R:79E<@H@("`@("H@("`@("`@("`@("`@("!D;V5S;B=T('-U
M<'!O<G0@875T;RUC;VUM:71T:6YG('1R86YS86-T:6]N<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@875T;T-O;6UI="@D;VYO9F8@/2!F86QS92D*("`@('L*
M("`@("`@("`O+R!86%@@:68@)'1H:7,M/G1R86YS86-T:6]N7V]P8V]U;G0@
M/B`P+"!W92!S:&]U;&0@<')O8F%B;'D*("`@("`@("`O+R!I<W-U92!A('=A
M<FYI;F<@:&5R92X*("`@("`@("`D=&AI<RT^875T;V-O;6UI="`]("1O;F]F
M9B`_('1R=64@.B!F86QS93L*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]M;6ET*"D*"B`@("`O*BH*("`@
M("`J($-O;6UI=',@=&AE(&-U<G)E;G0@=')A;G-A8W1I;VX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R
M;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O
M;6UI="@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YT<F%N<V%C=&EO;E]O
M<&-O=6YT(#X@,"D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]D8BD@>PH@
M("`@("`@("`@("`@("`@:68@*"%`;7ES<6Q?<V5L96-T7V1B*"1T:&ES+3Y?
M9&(L("1T:&ES+3YC;VYN96-T:6]N*2D@>PH@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^;7ES<6Q286ES945R<F]R*$1"7T524D]27TY/1$)3
M14Q%0U1%1"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)')E<W5L="`]($!M>7-Q;%]Q=65R>2@G0T]-34E4)RP@)'1H
M:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@("`D<F5S=6QT(#T@0&UY<W%L
M7W%U97)Y*"=3150@05543T-/34U)5#TQ)RP@)'1H:7,M/F-O;FYE8W1I;VXI
M.PH@("`@("`@("`@("`D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`](#`[
M"B`@("`@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YM>7-Q;%)A:7-E17)R;W(H*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@<F]L;&)A8VLH*0H*("`@("\J*@H@("`@("H@
M4F5V97)T<R!T:&4@8W5R<F5N="!T<F%N<V%C=&EO;@H@("`@("H*("`@("`J
M($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F]L;&)A
M8VLH*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^=')A;G-A8W1I;VY?;W!C
M;W5N="`^(#`I('L*("`@("`@("`@("`@:68@*"1T:&ES+3Y?9&(I('L*("`@
M("`@("`@("`@("`@(&EF("@A0&UY<W%L7W-E;&5C=%]D8B@D=&AI<RT^7V1B
M+"`D=&AI<RT^8V]N;F5C=&EO;BDI('L*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/FUY<W%L4F%I<V5%<G)O<BA$0E]%4E)/4E].3T1"4T5,
M14-4140I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1R97-U;'0@/2!`;7ES<6Q?<75E<GDH)U)/3$Q"04-+)RP@)'1H
M:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@("`D<F5S=6QT(#T@0&UY<W%L
M7W%U97)Y*"=3150@05543T-/34U)5#TQ)RP@)'1H:7,M/F-O;FYE8W1I;VXI
M.PH@("`@("`@("`@("`D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`](#`[
M"B`@("`@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YM>7-Q;%)A:7-E17)R;W(H*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@869F96-T9612;W=S*"D*"B`@("`O*BH*("`@
M("`J($1E=&5R;6EN97,@=&AE(&YU;6)E<B!O9B!R;W=S(&%F9F5C=&5D(&)Y
M(&$@9&%T82!M86YI=7!L871I;VX@<75E<GD*("`@("`J"B`@("`@*B`P(&ES
M(')E='5R;F5D(&9O<B!Q=65R:65S('1H870@9&]N)W0@;6%N:7!U;&%T92!D
M871A+@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F
M(')O=W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!A9F9E8W1E9%)O=W,H*0H@("`@>PH@("`@("`@(&EF
M("A$0CHZ:7--86YI<"@D=&AI<RT^;&%S=%]Q=65R>2DI('L*("`@("`@("`@
M("`@<F5T=7)N($!M>7-Q;%]A9F9E8W1E9%]R;W=S*"1T:&ES+3YC;VYN96-T
M:6]N*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@,#L*
M("`@("`@("!]"B`@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YE>'1)
M9"@I"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!N97AT(&9R964@:60@
M:6X@82!S97%U96YC90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1S
M97%?;F%M92`@;F%M92!O9B!T:&4@<V5Q=65N8V4*("`@("`J($!P87)A;2!B
M;V]L96%N("1O;F1E;6%N9"`@=VAE;B!T<G5E+"!T:&4@<V5Q96YC92!I<R!A
M=71O;6%T:6-A;&QY"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!C<F5A=&5D(&EF(&ET(&1O97,@;F]T(&5X:7-T"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G0@('1H92!N97AT(&ED(&YU;6)E<B!I;B!T:&4@<V5Q=65N
M8V4N"B`@("`@*B`@("`@("`@("`@("`@($$@1$)?17)R;W(@;V)J96-T(&]N
M(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.FYE>'1)
M1"@I+"!$0E]C;VUM;VXZ.F=E=%-E<75E;F-E3F%M92@I+`H@("`@("H@("`@
M("!$0E]M>7-Q;#HZ8W)E871E4V5Q=65N8V4H*2P@1$)?;7ES<6PZ.F1R;W!3
M97%U96YC92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&YE>'1)9"@D<V5Q7VYA
M;64L("1O;F1E;6%N9"`]('1R=64I"B`@("!["B`@("`@("`@)'-E<6YA;64@
M/2`D=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S97%?;F%M92D["B`@("`@("`@
M9&\@>PH@("`@("`@("`@("`D<F5P96%T(#T@,#L*("`@("`@("`@("`@)'1H
M:7,M/G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L*("`@
M("`@("`@("`@)')E<W5L="`]("1T:&ES+3YQ=65R>2@B55!$051%("1[<V5Q
M;F%M97T@(BX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M4T54(&ED/4Q!4U1?24Y315)47TE$*&ED*S$I)RD["B`@("`@("`@("`@("1T
M:&ES+3YP;W!%<G)O<DAA;F1L:6YG*"D["B`@("`@("`@("`@(&EF("@D<F5S
M=6QT(#T]/2!$0E]/2RD@>PH@("`@("`@("`@("`@("`@+R\@0T]-34].($-!
M4T4*("`@("`@("`@("`@("`@("1I9"`]($!M>7-Q;%]I;G-E<G1?:60H)'1H
M:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@("`@("`@:68@*"1I9"`A/2`P
M*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1I9#L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("\O($5-4%19(%-%42!404),10H@
M("`@("`@("`@("`@("`@+R\@4V5Q=65N8V4@=&%B;&4@;75S="!B92!E;7!T
M>2!F;W(@<V]M92!R96%S;VXL('-O(&9I;&P*("`@("`@("`@("`@("`@("\O
M(&ET(&%N9"!R971U<FX@,2!A;F0@;V)T86EN(&$@=7-E<BUL979E;"!L;V-K
M"B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F=E=$]N92@B4T5,
M14-4($=%5%],3T-+*"<D>W-E<6YA;65]7VQO8VLG+#$P*2(I.PH@("`@("`@
M("`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1R97-U;'0I
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"1R97-U
M;'0@/3T@,"D@>PH@("`@("`@("`@("`@("`@("`@("\O($9A:6QE9"!T;R!G
M970@=&AE(&QO8VL*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/FUY<W%L4F%I<V5%<G)O<BA$0E]%4E)/4E].3U1?3$]#2T5$*3L*("`@("`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O+R!A9&0@=&AE(&1E9F%U
M;'0@=F%L=64*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^<75E
M<GDH(E)%4$Q!0T4@24Y43R`D>W-E<6YA;65]("AI9"D@5D%,5453("@P*2(I
M.PH@("`@("`@("`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97-U;'0I*2![
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*"1R97-U;'0I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@
M("\O(%)E;&5A<V4@=&AE(&QO8VL*("`@("`@("`@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^9V5T3VYE*"=314Q%0U0@4D5,14%315],3T-+*"<*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@(B<D>W-E<6YA
M;65]7VQO8VLG*2(I.PH@("`@("`@("`@("`@("`@:68@*$1".CII<T5R<F]R
M*"1R97-U;'0I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*"1R97-U;'0I.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@+R\@5V4@:VYO=R!W:&%T('1H92!R97-U;'0@=VEL;"!B
M92P@<V\@;F\@;F5E9"!T;R!T<GD@86=A:6X*("`@("`@("`@("`@("`@(')E
M='5R;B`Q.PH*("`@("`@("`@("`@?2!E;'-E:68@*"1O;F1E;6%N9"`F)B!$
M0CHZ:7-%<G)O<B@D<F5S=6QT*2`F)@H@("`@("`@("`@("`@("`@)')E<W5L
M="T^9V5T0V]D92@I(#T]($1"7T524D]27TY/4U5#2%1!0DQ%*0H@("`@("`@
M("`@("!["B`@("`@("`@("`@("`@("`O+R!/3D1%34%.1"!404),12!#4D5!
M5$E/3@H@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YC<F5A=&53
M97%U96YC92@D<V5Q7VYA;64I.PH@("`@("`@("`@("`@("`@:68@*$1".CII
M<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*"1R97-U;'0I.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D<F5P96%T(#T@,3L*("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@('T@96QS96EF("A$0CHZ:7-%
M<G)O<B@D<F5S=6QT*2`F)@H@("`@("`@("`@("`@("`@("`@("`@)')E<W5L
M="T^9V5T0V]D92@I(#T]($1"7T524D]27T%,4D5!1%E?15A)4U13*0H@("`@
M("`@("`@("!["B`@("`@("`@("`@("`@("`O+R!"04-+5T%21%,@0T]-4$%4
M"B`@("`@("`@("`@("`@("`O+R!S964@7T)#<V5Q=65N8V4H*2!C;VUM96YT
M"B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]"0W-E<75E;F-E
M*"1S97%N86UE*3L*("`@("`@("`@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D
M<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@D<F5S=6QT*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("1R97!E870@/2`Q.PH@("`@("`@("`@("!]"B`@("`@("`@
M?2!W:&EL92`H)')E<&5A="D["@H@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@D<F5S=6QT*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!C<F5A=&5397%U96YC92@I"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&$@
M;F5W('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5Q
M7VYA;64@(&YA;64@;V8@=&AE(&YE=R!S97%U96YC90H@("`@("H*("`@("`J
M($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO
M;CHZ8W)E871E4V5Q=65N8V4H*2P@1$)?8V]M;6]N.CIG971397%U96YC94YA
M;64H*2P*("`@("`J("`@("`@1$)?;7ES<6PZ.FYE>'1)1"@I+"!$0E]M>7-Q
M;#HZ9')O<%-E<75E;F-E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@8W)E871E
M4V5Q=65N8V4H)'-E<5]N86UE*0H@("`@>PH@("`@("`@("1S97%N86UE(#T@
M)'1H:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I.PH@("`@("`@("1R
M97,@/2`D=&AI<RT^<75E<GDH)T-214%412!404),12`G("X@)'-E<6YA;64*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)R`H:60@24Y414=%4B!5
M3E-)1TY%1"!!551/7TE.0U)%345.5"!.3U0@3E5,3"PG"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`N("<@4%))34%262!+15DH:60I*2<I.PH@("`@
M("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S*2D@>PH@("`@("`@("`@("!R971U
M<FX@)')E<SL*("`@("`@("!]"B`@("`@("`@+R\@:6YS97)T('EI96QD<R!V
M86QU92`Q+"!N97AT260@8V%L;"!W:6QL(&=E;F5R871E($E$(#(*("`@("`@
M("`D<F5S(#T@)'1H:7,M/G%U97)Y*"))3E-%4E0@24Y43R`D>W-E<6YA;65]
M("AI9"D@5D%,5453("@P*2(I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D
M<F5S*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("!]"B`@
M("`@("`@+R\@<V\@<F5S970@=&\@>F5R;PH@("`@("`@(')E='5R;B`D=&AI
M<RT^<75E<GDH(E501$%412`D>W-E<6YA;65](%-%5"!I9"`](#`B*3L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!D<F]P4V5Q=65N8V4H*0H*("`@
M("\J*@H@("`@("H@1&5L971E<R!A('-E<75E;F-E"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<V5Q7VYA;64@(&YA;64@;V8@=&AE('-E<75E;F-E
M('1O(&)E(&1E;&5T960*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?
M3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N
M"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F1R;W!397%U96YC92@I
M+"!$0E]C;VUM;VXZ.F=E=%-E<75E;F-E3F%M92@I+`H@("`@("H@("`@("!$
M0E]M>7-Q;#HZ;F5X=$E$*"DL($1"7VUY<W%L.CIC<F5A=&5397%U96YC92@I
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&1R;W!397%U96YC92@D<V5Q7VYA;64I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YQ=65R>2@G1%)/4"!404),
M12`G("X@)'1H:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I*3L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!?0D-S97%U96YC92@I"@H@("`@
M+RHJ"B`@("`@*B!"86-K=V%R9',@8V]M<&%T:6)I;&ET>2!W:71H(&]L9"!S
M97%U96YC92!E;75L871I;VX@:6UP;&5M96YT871I;VX*("`@("`J("AC;&5A
M;B!U<"!T:&4@9'5P97,I"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<V5Q;F%M92`@=&AE('-E<75E;F-E(&YA;64@=&\@8VQE86X@=7`*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VP@('1R=64@;VX@<W5C8V5S<RX@($$@1$)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]"0W-E<75E;F-E*"1S
M97%N86UE*0H@("`@>PH@("`@("`@("\O($]B=&%I;B!A('5S97(M;&5V96P@
M;&]C:RXN+B!T:&ES('=I;&P@<F5L96%S92!A;GD@<')E=FEO=7,*("`@("`@
M("`O+R!A<'!L:6-A=&EO;B!L;V-K<RP@8G5T('5N;&EK92!,3T-+(%1!0DQ%
M4RP@:70@9&]E<R!N;W0@86)O<G0*("`@("`@("`O+R!T:&4@8W5R<F5N="!T
M<F%N<V%C=&EO;B!A;F0@:7,@;75C:"!L97-S(&9R97%U96YT;'D@=7-E9"X*
M("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F=E=$]N92@B4T5,14-4($=%5%],
M3T-+*"<D>W-E<6YA;65]7VQO8VLG+#$P*2(I.PH@("`@("`@(&EF("A$0CHZ
M:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@("`@("!]"B`@("`@("`@:68@*"1R97-U;'0@/3T@,"D@>PH@("`@
M("`@("`@("`O+R!&86EL960@=&\@9V5T('1H92!L;V-K+"!C86XG="!D;R!T
M:&4@8V]N=F5R<VEO;BP@8F%I;`H@("`@("`@("`@("`O+R!W:71H(&$@1$)?
M15)23U)?3D]47TQ/0TM%1"!E<G)O<@H@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/FUY<W%L4F%I<V5%<G)O<BA$0E]%4E)/4E].3U1?3$]#2T5$*3L*("`@
M("`@("!]"@H@("`@("`@("1H:6=H97-T7VED(#T@)'1H:7,M/F=E=$]N92@B
M4T5,14-4($U!6"AI9"D@1E)/32`D>W-E<6YA;65](BD["B`@("`@("`@:68@
M*$1".CII<T5R<F]R*"1H:6=H97-T7VED*2D@>PH@("`@("`@("`@("!R971U
M<FX@)&AI9VAE<W1?:60["B`@("`@("`@?0H@("`@("`@("\O(%1H:7,@<VAO
M=6QD(&MI;&P@86QL(')O=W,@97AC97!T('1H92!H:6=H97-T"B`@("`@("`@
M+R\@5V4@<VAO=6QD('!R;V)A8FQY(&1O('-O;65T:&EN9R!I9B`D:&EG:&5S
M=%]I9"!I<VXG=`H@("`@("`@("\O(&YU;65R:6,L(&)U="!))VT@870@82!L
M;W-S(&%S(&AO=R!T;R!H86YD;&4@=&AA="XN+@H@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^<75E<GDH)T1%3$5412!&4D]-("<@+B`D<V5Q;F%M90H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`B(%=(15)%(&ED(#P^("1H
M:6=H97-T7VED(BD["B`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97-U;'0I
M*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@
M("`@("`@+R\@268@86YO=&AE<B!T:')E860@:&%S(&)E96X@=V%I=&EN9R!F
M;W(@=&AI<R!L;V-K+`H@("`@("`@("\O(&ET('=I;&P@9V\@=&AR=2!T:&4@
M86)O=F4@<')O8V5D=7)E+"!B=70@=VEL;"!H879E(&YO"B`@("`@("`@+R\@
M<F5A;"!E9F9E8W0*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F=E=$]N92@B
M4T5,14-4(%)%3$5!4T5?3$]#2R@G)'MS97%N86UE?5]L;V-K)RDB*3L*("`@
M("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('%U;W1E261E;G1I9FEE
M<B@I"@H@("`@+RHJ"B`@("`@*B!1=6]T97,@82!S=')I;F<@<V\@:70@8V%N
M(&)E('-A9F5L>2!U<V5D(&%S(&$@=&%B;&4@;W(@8V]L=6UN(&YA;64*("`@
M("`J"B`@("`@*B!->5-13"!C86XG="!H86YD;&4@=&AE(&)A8VMT:6-K(&-H
M87)A8W1E<B`H/&MB9#Y@/"]K8F0^*2!I;@H@("`@("H@=&%B;&4@;W(@8V]L
M=6UN(&YA;65S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T<B`@
M:61E;G1I9FEE<B!N86UE('1O(&)E('%U;W1E9`H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!Q=6]T960@:61E;G1I9FEE<B!S=')I;F<*("`@("`J
M"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ<75O=&5)9&5N=&EF:65R*"D*("`@
M("`J($!S:6YC92!-971H;V0@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XV
M+C`*("`@("`J+PH@("`@9G5N8W1I;VX@<75O=&5)9&5N=&EF:65R*"1S='(I
M"B`@("!["B`@("`@("`@<F5T=7)N("=@)R`N("1S='(@+B`G8"<["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<75O=&4H*0H*("`@("\J*@H@("`@
M("H@0&1E<')E8V%T960@($1E<')E8V%T960@:6X@<F5L96%S92`Q+C8N,`H@
M("`@("HO"B`@("!F=6YC=&EO;B!Q=6]T92@D<W1R*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^<75O=&53;6%R="@D<W1R*3L*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!E<V-A<&53:6UP;&4H*0H*("`@("\J*@H@("`@
M("H@17-C87!E<R!A('-T<FEN9R!A8V-O<F1I;F<@=&\@=&AE(&-U<G)E;G0@
M1$)-4R=S('-T86YD87)D<PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'-T<B`@=&AE('-T<FEN9R!T;R!B92!E<V-A<&5D"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@('1H92!E<V-A<&5D('-T<FEN9PH@("`@("H*("`@
M("`J($!S964@1$)?8V]M;6]N.CIQ=6]T95-M87)T*"D*("`@("`J($!S:6YC
M92!-971H;V0@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XV+C`*("`@("`J
M+PH@("`@9G5N8W1I;VX@97-C87!E4VEM<&QE*"1S='(I"B`@("!["B`@("`@
M("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G;7ES<6Q?<F5A;%]E<V-A<&5?<W1R
M:6YG)RDI('L*("`@("`@("`@("`@<F5T=7)N($!M>7-Q;%]R96%L7V5S8V%P
M95]S=')I;F<H)'-T<BP@)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B!`;7ES<6Q?97-C87!E7W-T<FEN
M9R@D<W1R*3L*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@;6]D:69Y475E<GDH*0H*("`@("\J*@H@("`@("H@0VAA;F=E<R!A('%U
M97)Y('-T<FEN9R!F;W(@=F%R:6]U<R!$0DU3('-P96-I9FEC(')E87-O;G,*
M("`@("`J"B`@("`@*B!4:&ES(&QI='1L92!H86-K(&QE=',@>6]U(&MN;W<@
M:&]W(&UA;GD@<F]W<R!W97)E(&1E;&5T960*("`@("`J('=H96X@<G5N;FEN
M9R!A(")$14Q%5$4@1E)/32!T86)L92(@<75E<GDN("!/;FQY(&EM<&QE;65N
M=&5D"B`@("`@*B!I9B!T:&4@1$)?4$]25$%"24Q)5%E?1$5,151%7T-/54Y4
M('!O<G1A8FEL:71Y(&]P=&EO;B!I<R!O;BX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1Q=65R>2`@=&AE('%U97)Y('-T<FEN9R!T;R!M;V1I9GD*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&UO9&EF:65D('%U
M97)Y('-T<FEN9PH@("`@("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@
M("`@*B!`<V5E($1"7V-O;6UO;CHZ<V5T3W!T:6]N*"D*("`@("`J+PH@("`@
M9G5N8W1I;VX@;6]D:69Y475E<GDH)'%U97)Y*0H@("`@>PH@("`@("`@(&EF
M("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,
M25197T1%3$5415]#3U5.5"D@>PH@("`@("`@("`@("`O+R`B1$5,151%($92
M3TT@=&%B;&4B(&=I=F5S(#`@869F96-T960@<F]W<R!I;B!->5-13"X*("`@
M("`@("`@("`@+R\@5&AI<R!L:71T;&4@:&%C:R!L971S('EO=2!K;F]W(&AO
M=R!M86YY(')O=W,@=V5R92!D96QE=&5D+@H@("`@("`@("`@("!I9B`H<')E
M9U]M871C:"@G+UY<<RI$14Q%5$5<<RM&4D]-7',K*%Q3*RE<<RHD+VDG+"`D
M<75E<GDI*2!["B`@("`@("`@("`@("`@("`D<75E<GD@/2!P<F5G7W)E<&QA
M8V4H)R]>7',J1$5,151%7',K1E)/35QS*RA<4RLI7',J)"\G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=$14Q%5$4@1E)/32!<
M,2!72$5212`Q/3$G+"`D<75E<GDI.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D<75E<GD["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@;6]D:69Y3&EM:711=65R>2@I"@H@("`@+RHJ"B`@("`@*B!!
M9&1S($Q)34E4(&-L875S97,@=&\@82!Q=65R>2!S=')I;F<@86-C;W)D:6YG
M('1O(&-U<G)E;G0@1$)-4R!S=&%N9&%R9',*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1Q=65R>2`@('1H92!Q=65R>2!T;R!M;V1I9GD*("`@("`J
M($!P87)A;2!I;G0@("`@)&9R;VT@("`@=&AE(')O=R!T;R!S=&%R="!T;R!F
M971C:&EN9R`H,"`]('1H92!F:7)S="!R;W<I"B`@("`@*B!`<&%R86T@:6YT
M("`@("1C;W5N="`@('1H92!N=6UB97)S(&]F(')O=W,@=&\@9F5T8V@*("`@
M("`J($!P87)A;2!M:7AE9"`@)'!A<F%M<R`@87)R87DL('-T<FEN9R!O<B!N
M=6UE<FEC(&1A=&$@=&\@8F4@=7-E9"!I;@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@97AE8W5T:6]N(&]F('1H92!S=&%T96UE;G0N("!1=6%N
M=&ET>2!O9B!I=&5M<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M<&%S<V5D(&UU<W0@;6%T8V@@<75A;G1I='D@;V8@<&QA8V5H;VQD97)S(&EN
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!Q=65R>3H@(&UE86YI
M;F<@,2!P;&%C96AO;&1E<B!F;W(@;F]N+6%R<F%Y"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("!P87)A;65T97)S(&]R(#$@<&QA8V5H;VQD97(@
M<&5R(&%R<F%Y(&5L96UE;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@('1H92!Q=65R>2!S=')I;F<@=VET:"!,24U)5"!C;&%U<V5S(&%D9&5D
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J+PH@("`@
M9G5N8W1I;VX@;6]D:69Y3&EM:711=65R>2@D<75E<GDL("1F<F]M+"`D8V]U
M;G0L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("A$0CHZ
M:7--86YI<"@D<75E<GDI*2!["B`@("`@("`@("`@(')E='5R;B`D<75E<GD@
M+B`B($Q)34E4("1C;W5N="(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N("1Q=65R>2`N("(@3$E-250@)&9R;VTL("1C;W5N="(["B`@
M("`@("`@?0H@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&UY<W%L4F%I
M<V5%<G)O<B@I"@H@("`@+RHJ"B`@("`@*B!0<F]D=6-E<R!A($1"7T5R<F]R
M(&]B:F5C="!R96=A<F1I;F<@=&AE(&-U<G)E;G0@<')O8FQE;0H@("`@("H*
M("`@("`J($!P87)A;2!I;G0@)&5R<FYO("!I9B!T:&4@97)R;W(@:7,@8F5I
M;F<@;6%N=6%L;'D@<F%I<V5D('!A<W,@80H@("`@("H@("`@("`@("`@("`@
M("`@("`@("!$0E]%4E)/4BH@8V]N<W1A;G0@:&5R92X@($EF('1H:7,@:7-N
M)W0@<&%S<V5D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@('1H92!E<G)O
M<B!I;F9O<FUA=&EO;B!G871H97)E9"!F<F]M('1H92!$0DU3+@H@("`@("H*
M("`@("`J($!R971U<FX@;V)J96-T("!T:&4@1$)?17)R;W(@;V)J96-T"B`@
M("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G)A:7-E17)R;W(H*2P*("`@
M("`J("`@("`@1$)?;7ES<6PZ.F5R<F]R3F%T:79E*"DL($1"7V-O;6UO;CHZ
M97)R;W)#;V1E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@;7ES<6Q286ES945R
M<F]R*"1E<G)N;R`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"1E<G)N;R`]
M/3T@;G5L;"D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O
M<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465]%4E)/4E,I('L*("`@("`@
M("`@("`@("`@("1T:&ES+3YE<G)O<F-O9&5?;6%P6S$P,C)=(#T@1$)?15)2
M3U)?0T].4U1204E.5#L*("`@("`@("`@("`@("`@("1T:&ES+3YE<G)O<F-O
M9&5?;6%P6S$P-#A=(#T@1$)?15)23U)?0T].4U1204E.5%].3U1?3E5,3#L*
M("`@("`@("`@("`@("`@("1T:&ES+3YE<G)O<F-O9&5?;6%P6S$P-C)=(#T@
M1$)?15)23U)?0T].4U1204E.5#L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("\O($1O:6YG('1H:7,@:6X@8V%S92!M;V1E(&-H86YG
M97,@9'5R:6YG(')U;G1I;64N"B`@("`@("`@("`@("`@("`D=&AI<RT^97)R
M;W)C;V1E7VUA<%LQ,#(R72`]($1"7T524D]27T%,4D5!1%E?15A)4U13.PH@
M("`@("`@("`@("`@("`@)'1H:7,M/F5R<F]R8V]D95]M87!;,3`T.%T@/2!$
M0E]%4E)/4E]#3TY35%)!24Y4.PH@("`@("`@("`@("`@("`@)'1H:7,M/F5R
M<F]R8V]D95]M87!;,3`V,ET@/2!$0E]%4E)/4E]!3%)%04197T5825-44SL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D97)R;F\@/2`D=&AI<RT^97)R
M;W)#;V1E*&UY<W%L7V5R<FYO*"1T:&ES+3YC;VYN96-T:6]N*2D["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D97)R;F\L
M(&YU;&PL(&YU;&PL(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@($!M>7-Q;%]E<G)N;R@D=&AI<RT^8V]N;F5C=&EO;BD@+B`G("HJ
M("<@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!`;7ES<6Q?
M97)R;W(H)'1H:7,M/F-O;FYE8W1I;VXI*3L*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!E<G)O<DYA=&EV92@I"@H@("`@+RHJ"B`@("`@*B!'971S
M('1H92!$0DU3)R!N871I=F4@97)R;W(@8V]D92!P<F]D=6-E9"!B>2!T:&4@
M;&%S="!Q=65R>0H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@1$)-
M4R<@97)R;W(@8V]D90H@("`@("HO"B`@("!F=6YC=&EO;B!E<G)O<DYA=&EV
M92@I"B`@("!["B`@("`@("`@<F5T=7)N($!M>7-Q;%]E<G)N;R@D=&AI<RT^
M8V]N;F5C=&EO;BD["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@=&%B
M;&5);F9O*"D*"B`@("`O*BH*("`@("`J(%)E='5R;G,@:6YF;W)M871I;VX@
M86)O=70@82!T86)L92!O<B!A(')E<W5L="!S970*("`@("`J"B`@("`@*B!`
M<&%R86T@;V)J96-T?'-T<FEN9R`@)')E<W5L="`@1$)?<F5S=6QT(&]B:F5C
M="!F<F]M(&$@<75E<GD@;W(@80H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!S=')I;F<@8V]N=&%I;FEN9R!T:&4@;F%M92!O9B!A
M('1A8FQE+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!7:&EL92!T:&ES(&%L<V\@86-C97!T<R!A('%U97)Y(')E<W5L=`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R97-O=7)C92!I
M9&5N=&EF:65R+"!T:&ES(&)E:&%V:6]R(&ES"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&1E<')E8V%T960N"B`@("`@*B!`<&%R
M86T@:6YT("`@("`@("`@("`@)&UO9&4@("`@82!V86QI9"!T86)L94EN9F\@
M;6]D90H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(&%N(&%S<V]C:6%T
M:79E(&%R<F%Y('=I=&@@=&AE(&EN9F]R;6%T:6]N(')E<75E<W1E9"X*("`@
M("`J("`@("`@("`@("`@("`@("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E+@H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIT86)L94EN9F\H
M*0H@("`@("HO"B`@("!F=6YC=&EO;B!T86)L94EN9F\H)')E<W5L="P@)&UO
M9&4@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]S=')I;F<H)')E<W5L
M="DI('L*("`@("`@("`@("`@+RH*("`@("`@("`@("`@("H@4')O8F%B;'D@
M<F5C96EV960@82!T86)L92!N86UE+@H@("`@("`@("`@("`@*B!#<F5A=&4@
M82!R97-U;'0@<F5S;W5R8V4@:61E;G1I9FEE<BX*("`@("`@("`@("`@("HO
M"B`@("`@("`@("`@("1I9"`]($!M>7-Q;%]L:7-T7V9I96QD<R@D=&AI<RT^
M9'-N6R=D871A8F%S92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)')E<W5L="P@)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@
M("`@("`D9V]T7W-T<FEN9R`]('1R=64["B`@("`@("`@?2!E;'-E:68@*&ES
M<V5T*"1R97-U;'0M/G)E<W5L="DI('L*("`@("`@("`@("`@+RH*("`@("`@
M("`@("`@("H@4')O8F%B;'D@<F5C96EV960@82!R97-U;'0@;V)J96-T+@H@
M("`@("`@("`@("`@*B!%>'1R86-T('1H92!R97-U;'0@<F5S;W5R8V4@:61E
M;G1I9FEE<BX*("`@("`@("`@("`@("HO"B`@("`@("`@("`@("1I9"`]("1R
M97-U;'0M/G)E<W5L=#L*("`@("`@("`@("`@)&=O=%]S=')I;F<@/2!F86QS
M93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*@H@("`@("`@("`@
M("`@*B!0<F]B86)L>2!R96-E:79E9"!A(')E<W5L="!R97-O=7)C92!I9&5N
M=&EF:65R+@H@("`@("`@("`@("`@*B!#;W!Y(&ET+@H@("`@("`@("`@("`@
M*B!$97!R96-A=&5D+B`@2&5R92!F;W(@8V]M<&%T:6)I;&ET>2!O;FQY+@H@
M("`@("`@("`@("`@*B\*("`@("`@("`@("`@)&ED(#T@)')E<W5L=#L*("`@
M("`@("`@("`@)&=O=%]S=')I;F<@/2!F86QS93L*("`@("`@("!]"@H@("`@
M("`@(&EF("@A:7-?<F5S;W5R8V4H)&ED*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/FUY<W%L4F%I<V5%<G)O<BA$0E]%4E)/4E].145$7TU/4D5?
M1$%402D["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;
M)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465],3U=%4D-!4T4I('L*
M("`@("`@("`@("`@)&-A<V5?9G5N8R`]("=S=')T;VQO=V5R)SL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D8V%S95]F=6YC(#T@)W-T<G9A;"<[
M"B`@("`@("`@?0H*("`@("`@("`D8V]U;G0@/2!`;7ES<6Q?;G5M7V9I96QD
M<R@D:60I.PH@("`@("`@("1R97,@("`](&%R<F%Y*"D["@H@("`@("`@(&EF
M("@D;6]D92D@>PH@("`@("`@("`@("`D<F5S6R=N=6U?9FEE;&1S)UT@/2`D
M8V]U;G0["B`@("`@("`@?0H*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D
M8V]U;G0[("1I*RLI('L*("`@("`@("`@("`@)')E<ULD:5T@/2!A<G)A>2@*
M("`@("`@("`@("`@("`@("=T86)L92<@/3X@)&-A<V5?9G5N8RA`;7ES<6Q?
M9FEE;&1?=&%B;&4H)&ED+"`D:2DI+`H@("`@("`@("`@("`@("`@)VYA;64G
M("`]/B`D8V%S95]F=6YC*$!M>7-Q;%]F:65L9%]N86UE*"1I9"P@)&DI*2P*
M("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@0&UY<W%L7V9I96QD7W1Y<&4H
M)&ED+"`D:2DL"B`@("`@("`@("`@("`@("`G;&5N)R`@(#T^($!M>7-Q;%]F
M:65L9%]L96XH)&ED+"`D:2DL"B`@("`@("`@("`@("`@("`G9FQA9W,G(#T^
M($!M>7-Q;%]F:65L9%]F;&%G<R@D:60L("1I*2P*("`@("`@("`@("`@*3L*
M("`@("`@("`@("`@:68@*"1M;V1E("8@1$)?5$%"3$5)3D9/7T]21$52*2![
M"B`@("`@("`@("`@("`@("`D<F5S6R=O<F1E<B==6R1R97-;)&E=6R=N86UE
M)UU=(#T@)&D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1M;V1E
M("8@1$)?5$%"3$5)3D9/7T]21$525$%"3$4I('L*("`@("`@("`@("`@("`@
M("1R97-;)V]R9&5R=&%B;&4G75LD<F5S6R1I75LG=&%B;&4G75U;)')E<ULD
M:5U;)VYA;64G75T@/2`D:3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@+R\@9G)E92!T:&4@<F5S=6QT(&]N;'D@:68@=V4@=V5R92!C86QL
M960@;VX@82!T86)L90H@("`@("`@(&EF("@D9V]T7W-T<FEN9RD@>PH@("`@
M("`@("`@("!`;7ES<6Q?9G)E95]R97-U;'0H)&ED*3L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N("1R97,["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@9V5T4W!E8VEA;%%U97)Y*"D*"B`@("`O*BH*("`@("`J($]B=&%I;G,@
M=&AE('%U97)Y('-T<FEN9R!N965D960@9F]R(&QI<W1I;F<@82!G:79E;B!T
M>7!E(&]F(&]B:F5C=',*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T
M>7!E("!T:&4@:VEN9"!O9B!O8FIE8W1S('EO=2!W86YT('1O(')E=')I979E
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!344P@<75E<GD@
M<W1R:6YG(&]R(&YU;&P@:68@=&AE(&1R:79E<B!D;V5S;B=T"B`@("`@*B`@
M("`@("`@("`@("`@("`@('-U<'!O<G0@=&AE(&]B:F5C="!T>7!E(')E<75E
M<W1E9`H@("`@("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B!`
M<V5E($1"7V-O;6UO;CHZ9V5T3&ES=$]F*"D*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T4W!E8VEA;%%U97)Y*"1T>7!E*0H@("`@>PH@("`@("`@('-W:71C
M:"`H)'1Y<&4I('L*("`@("`@("`@("`@8V%S92`G=&%B;&5S)SH*("`@("`@
M("`@("`@("`@(')E='5R;B`G4TA/5R!404),15,G.PH@("`@("`@("`@("!C
M87-E("=U<V5R<R<Z"B`@("`@("`@("`@("`@("!R971U<FX@)U-%3$5#5"!$
M25-424Y#5"!5<V5R($923TT@;7ES<6PN=7-E<B<["B`@("`@("`@("`@(&-A
M<V4@)V1A=&%B87-E<R<Z"B`@("`@("`@("`@("`@("!R971U<FX@)U-(3U<@
M1$%404)!4T53)SL*("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@
M("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*
M"GT*"B\J"B`J($QO8V%L('9A<FEA8FQE<SH*("H@=&%B+7=I9'1H.B`T"B`J
M(&,M8F%S:6,M;V9F<V5T.B`T"B`J($5N9#H*("HO"@H_/@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O1$(O
M;7ES<6QI+G!H<```````````````````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#$P,C$R,B`Q,#4Q-30S,S<S,2`P,C`W-S8`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*"B\J('9I;3H@
M<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S
M=&]P/30Z("HO"@HO*BH*("H@5&AE(%!%05(@1$(@9')I=F5R(&9O<B!02%`G
M<R!M>7-Q;&D@97AT96YS:6]N"B`J(&9O<B!I;G1E<F%C=&EN9R!W:71H($UY
M4U%,(&1A=&%B87-E<PH@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@
M*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R
M<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA
M8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I
M;F<@55)).@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT
M+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(
M4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H
M('1H92!W96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H
M<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*
M("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*
M("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N
M;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@
M*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N
M='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@0U93.B`D260Z
M(&UY<W%L:2YP:'`L=B`Q+C8Y(#(P,#4O,#,O,#0@,C,Z,3(Z,S8@9&%N:65L
M8R!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A
M8VMA9V4O1$(*("HO"@HO*BH*("H@3V)T86EN('1H92!$0E]C;VUM;VX@8VQA
M<W,@<V\@:70@8V%N(&)E(&5X=&5N9&5D(&9R;VT*("HO"G)E<75I<F5?;VYC
M92`G1$(O8V]M;6]N+G!H<"<["@HO*BH*("H@5&AE(&UE=&AO9',@4$5!4B!$
M0B!U<V5S('1O(&EN=&5R86-T('=I=&@@4$A0)W,@;7ES<6QI(&5X=&5N<VEO
M;@H@*B!F;W(@:6YT97)A8W1I;F<@=VET:"!->5-13"!D871A8F%S97,*("H*
M("H@5&AI<R!I<R!F;W(@37E344P@=F5R<VEO;G,@-"XQ(&%N9"!A8F]V92X@
M(%)E<75I<F5S(%!(4"`U+@H@*@H@*B!.;W1E('1H870@<&5R<VES=&5N="!C
M;VYN96-T:6]N<R!N;R!L;VYG97(@97AI<W0N"B`J"B`J(%1H97-E(&UE=&AO
M9',@;W9E<FQO860@=&AE(&]N97,@9&5C;&%R960@:6X@1$)?8V]M;6]N+@H@
M*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@("!$0@H@
M*B!`875T:&]R("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN
M970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J
M($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT
M>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q
M+C<N-@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA
M9V4O1$(*("H@0'-I;F-E("`@("`@0VQA<W,@9G5N8W1I;VYA;"!S:6YC92!2
M96QE87-E(#$N-BXS"B`J+PIC;&%S<R!$0E]M>7-Q;&D@97AT96YD<R!$0E]C
M;VUM;VX*>PH@("`@+R\@>WM[('!R;W!E<G1I97,*"B`@("`O*BH*("`@("`J
M(%1H92!$0B!D<FEV97(@='EP92`H;7ES<6PL(&]C:3@L(&]D8F,L(&5T8RXI
M"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)'!H<'1Y<&4@
M/2`G;7ES<6QI)SL*"B`@("`O*BH*("`@("`J(%1H92!D871A8F%S92!S>6YT
M87@@=F%R:6%N="!T;R!B92!U<V5D("AD8C(L(&%C8V5S<RP@971C+BDL(&EF
M(&%N>0H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1D8G-Y
M;G1A>"`]("=M>7-Q;&DG.PH*("`@("\J*@H@("`@("H@5&AE(&-A<&%B:6QI
M=&EE<R!O9B!T:&ES($1"(&EM<&QE;65N=&%T:6]N"B`@("`@*@H@("`@("H@
M5&AE("=N97=?;&EN:R<@96QE;65N="!C;VYT86EN<R!T:&4@4$A0('9E<G-I
M;VX@=&AA="!F:7)S="!P<F]V:61E9`H@("`@("H@;F5W7VQI;FL@<W5P<&]R
M="!F;W(@=&AI<R!$0DU3+B`@0V]N=&%I;G,@9F%L<V4@:68@:70G<R!U;G-U
M<'!O<G1E9"X*("`@("`J"B`@("`@*B!-96%N:6YG(&]F('1H92`G;&EM:70G
M(&5L96UE;G0Z"B`@("`@*B`@("L@)V5M=6QA=&4G(#T@96UU;&%T92!W:71H
M(&9E=&-H(')O=R!B>2!N=6UB97(*("`@("`J("`@*R`G86QT97(G("`@/2!A
M;'1E<B!T:&4@<75E<GD*("`@("`J("`@*R!F86QS92`@("`@/2!S:VEP(')O
M=W,*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D
M9F5A='5R97,@/2!A<G)A>2@*("`@("`@("`G;&EM:70G("`@("`@("`@/3X@
M)V%L=&5R)RP*("`@("`@("`G;F5W7VQI;FLG("`@("`@/3X@9F%L<V4L"B`@
M("`@("`@)VYU;7)O=W,G("`@("`@(#T^('1R=64L"B`@("`@("`@)W!C;VYN
M96-T)R`@("`@(#T^(&9A;'-E+`H@("`@("`@("=P<F5P87)E)R`@("`@("`]
M/B!F86QS92P*("`@("`@("`G<W-L)R`@("`@("`@("`@/3X@=')U92P*("`@
M("`@("`G=')A;G-A8W1I;VYS)R`@/3X@=')U92P*("`@("D["@H@("`@+RHJ
M"B`@("`@*B!!(&UA<'!I;F<@;V8@;F%T:79E(&5R<F]R(&-O9&5S('1O($1"
M(&5R<F]R(&-O9&5S"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D97)R;W)C;V1E7VUA<"`](&%R<F%Y*`H@("`@("`@(#$P,#0@/3X@1$)?
M15)23U)?0T%.3D]47T-214%412P*("`@("`@("`Q,#`U(#T^($1"7T524D]2
M7T-!3DY/5%]#4D5!5$4L"B`@("`@("`@,3`P-B`]/B!$0E]%4E)/4E]#04Y.
M3U1?0U)%051%+`H@("`@("`@(#$P,#<@/3X@1$)?15)23U)?04Q214%$65]%
M6$E35%,L"B`@("`@("`@,3`P."`]/B!$0E]%4E)/4E]#04Y.3U1?1%)/4"P*
M("`@("`@("`Q,#(R(#T^($1"7T524D]27T%,4D5!1%E?15A)4U13+`H@("`@
M("`@(#$P-#0@/3X@1$)?15)23U)?04-#15-37U9)3TQ!5$E/3BP*("`@("`@
M("`Q,#0V(#T^($1"7T524D]27TY/1$)314Q%0U1%1"P*("`@("`@("`Q,#0X
M(#T^($1"7T524D]27T-/3E-44D%)3E0L"B`@("`@("`@,3`T.2`]/B!$0E]%
M4E)/4E].3U-50TA$0BP*("`@("`@("`Q,#4P(#T^($1"7T524D]27T%,4D5!
M1%E?15A)4U13+`H@("`@("`@(#$P-3$@/3X@1$)?15)23U)?3D]354-(5$%"
M3$4L"B`@("`@("`@,3`U-"`]/B!$0E]%4E)/4E].3U-50TA&245,1"P*("`@
M("`@("`Q,#8Q(#T^($1"7T524D]27T%,4D5!1%E?15A)4U13+`H@("`@("`@
M(#$P-C(@/3X@1$)?15)23U)?04Q214%$65]%6$E35%,L"B`@("`@("`@,3`V
M-"`]/B!$0E]%4E)/4E]364Y405@L"B`@("`@("`@,3`Y,2`]/B!$0E]%4E)/
M4E].3U1?1D]53D0L"B`@("`@("`@,3$P,"`]/B!$0E]%4E)/4E].3U1?3$]#
M2T5$+`H@("`@("`@(#$Q,S8@/3X@1$)?15)23U)?5D%,545?0T]53E1?3TY?
M4D]7+`H@("`@("`@(#$Q-#(@/3X@1$)?15)23U)?04-#15-37U9)3TQ!5$E/
M3BP*("`@("`@("`Q,30V(#T^($1"7T524D]27TY/4U5#2%1!0DQ%+`H@("`@
M("`@(#$R,38@/3X@1$)?15)23U)?0T].4U1204E.5"P*("`@("`@("`Q,C$W
M(#T^($1"7T524D]27T-/3E-44D%)3E0L"B`@("`I.PH*("`@("\J*@H@("`@
M("H@5&AE(')A=R!D871A8F%S92!C;VYN96-T:6]N(&-R96%T960@8GD@4$A0
M"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D8V]N;F5C
M=&EO;CL*"B`@("`O*BH*("`@("`J(%1H92!$4TX@:6YF;W)M871I;VX@9F]R
M(&-O;FYE8W1I;F<@=&\@82!D871A8F%S90H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)&1S;B`](&%R<F%Y*"D["@H*("`@("\J*@H@("`@
M("H@4VAO=6QD(&1A=&$@;6%N:7!U;&%T:6]N('%U97)I97,@8F4@8V]M;6ET
M=&5D(&%U=&]M871I8V%L;'D_"B`@("`@*B!`=F%R(&)O;VP*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)&%U=&]C;VUM:70@/2!T
M<G5E.PH*("`@("\J*@H@("`@("H@5&AE('%U86YT:71Y(&]F('1R86YS86-T
M:6]N<R!B96=U;@H@("`@("H*("`@("`J('M`:6YT97)N86P@(%=H:6QE('1H
M:7,@:7,@<')I=F%T92P@:70@8V%N)W0@86-T=6%L;'D@8F4@9&5S:6=N871E
M9`H@("`@("H@<')I=F%T92!I;B!02%`@-2!B96-A=7-E(&ET(&ES(&1I<F5C
M=&QY(&%C8V5S<V5D(&EN('1H92!T97-T('-U:71E+GU]"B`@("`@*@H@("`@
M("H@0'9A<B!I;G1E9V5R"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M+PH@("`@=F%R("1T<F%N<V%C=&EO;E]O<&-O=6YT(#T@,#L*"B`@("`O*BH*
M("`@("`J(%1H92!D871A8F%S92!S<&5C:69I960@:6X@=&AE($133@H@("`@
M("H*("`@("`J($ET)W,@82!F:7@@=&\@86QL;W<@8V%L;',@=&\@9&EF9F5R
M96YT(&1A=&%B87-E<R!I;B!T:&4@<V%M92!S8W)I<'0N"B`@("`@*@H@("`@
M("H@0'9A<B!S=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO
M"B`@("!V87(@)%]D8B`]("<G.PH*("`@("\J*@H@("`@("H@07)R87D@9F]R
M(&-O;G9E<G1I;F<@35E344Q)7RI?1DQ!1R!C;VYS=&%N=',@=&\@=&5X="!V
M86QU97,*("`@("`J($!V87(@("`@87)R87D*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B!`<VEN8V4@(%!R;W!E<G1Y(&%V86EL86)L92!S:6YC92!2
M96QE87-E(#$N-BXU"B`@("`@*B\*("`@('9A<B`D;7ES<6QI7V9L86=S(#T@
M87)R87DH"B`@("`@("`@35E344Q)7TY/5%].54Q,7T9,04<@("`@("`@(#T^
M("=N;W1?;G5L;"<L"B`@("`@("`@35E344Q)7U!225]+15E?1DQ!1R`@("`@
M("`@(#T^("=P<FEM87)Y7VME>2<L"B`@("`@("`@35E344Q)7U5.25%515]+
M15E?1DQ!1R`@("`@(#T^("=U;FEQ=65?:V5Y)RP*("`@("`@("!-65-13$E?
M355,5$E03$5?2T597T9,04<@("`@/3X@)VUU;'1I<&QE7VME>2<L"B`@("`@
M("`@35E344Q)7T),3T)?1DQ!1R`@("`@("`@("`@(#T^("=B;&]B)RP*("`@
M("`@("!-65-13$E?54Y324=.141?1DQ!1R`@("`@("`@/3X@)W5N<VEG;F5D
M)RP*("`@("`@("!-65-13$E?6D523T9)3$Q?1DQ!1R`@("`@("`@/3X@)WIE
M<F]F:6QL)RP*("`@("`@("!-65-13$E?05543U])3D-214U%3E1?1DQ!1R`@
M/3X@)V%U=&]?:6YC<F5M96YT)RP*("`@("`@("!-65-13$E?5$E-15-404U0
M7T9,04<@("`@("`@/3X@)W1I;65S=&%M<"<L"B`@("`@("`@35E344Q)7U-%
M5%]&3$%'("`@("`@("`@("`@(#T^("=S970G+`H@("`@("`@("\O($U94U%,
M25].54U?1DQ!1R`@("`@("`@("`@("`]/B`G;G5M97)I8R<L("`O+R!U;FYE
M8V5S<V%R>0H@("`@("`@("\O($U94U%,25]005)47TM%65]&3$%'("`@("`@
M("`]/B`G;75L=&EP;&5?:V5Y)RP@("\O(&1U<&QI8V%T=FEE"B`@("`@("`@
M35E344Q)7T=23U507T9,04<@("`@("`@("`@(#T^("=G<F]U<%]B>2<*("`@
M("D["@H@("`@+RHJ"B`@("`@*B!!<G)A>2!F;W(@8V]N=F5R=&EN9R!-65-1
M3$E?5%E015\J(&-O;G-T86YT<R!T;R!T97AT('9A;'5E<PH@("`@("H@0'9A
M<B`@("!A<G)A>0H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S:6YC
M92`@4')O<&5R='D@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XV+C4*("`@
M("`J+PH@("`@=F%R("1M>7-Q;&E?='EP97,@/2!A<G)A>2@*("`@("`@("!-
M65-13$E?5%E015]$14-)34%,("`@("`]/B`G9&5C:6UA;"<L"B`@("`@("`@
M35E344Q)7U194$5?5$E.62`@("`@("`@/3X@)W1I;GEI;G0G+`H@("`@("`@
M($U94U%,25]465!%7U-(3U)4("`@("`@(#T^("=I;G0G+`H@("`@("`@($U9
M4U%,25]465!%7TQ/3D<@("`@("`@(#T^("=I;G0G+`H@("`@("`@($U94U%,
M25]465!%7T9,3T%4("`@("`@(#T^("=F;&]A="<L"B`@("`@("`@35E344Q)
M7U194$5?1$]50DQ%("`@("`@/3X@)V1O=6)L92<L"B`@("`@("`@+R\@35E3
M44Q)7U194$5?3E5,3"`@("`@("`@/3X@)T1%1D%53%0@3E5,3"<L("`O+R!L
M970@9FQA9W,@:&%N9&QE(&ET"B`@("`@("`@35E344Q)7U194$5?5$E-15-4
M04U0("`@/3X@)W1I;65S=&%M<"<L"B`@("`@("`@35E344Q)7U194$5?3$].
M1TQ/3D<@("`@/3X@)V)I9VEN="<L"B`@("`@("`@35E344Q)7U194$5?24Y4
M,C0@("`@("`@/3X@)VUE9&EU;6EN="<L"B`@("`@("`@35E344Q)7U194$5?
M1$%412`@("`@("`@/3X@)V1A=&4G+`H@("`@("`@($U94U%,25]465!%7U1)
M344@("`@("`@(#T^("=T:6UE)RP*("`@("`@("!-65-13$E?5%E015]$051%
M5$E-12`@("`]/B`G9&%T971I;64G+`H@("`@("`@($U94U%,25]465!%7UE%
M05(@("`@("`@(#T^("=Y96%R)RP*("`@("`@("!-65-13$E?5%E015].15=$
M051%("`@("`]/B`G9&%T92<L"B`@("`@("`@35E344Q)7U194$5?14Y532`@
M("`@("`@/3X@)V5N=6TG+`H@("`@("`@($U94U%,25]465!%7U-%5"`@("`@
M("`@(#T^("=S970G+`H@("`@("`@($U94U%,25]465!%7U1)3EE?0DQ/0B`@
M(#T^("=T:6YY8FQO8B<L"B`@("`@("`@35E344Q)7U194$5?345$255-7T),
M3T(@/3X@)VUE9&EU;6)L;V(G+`H@("`@("`@($U94U%,25]465!%7TQ/3D=?
M0DQ/0B`@(#T^("=L;VYG8FQO8B<L"B`@("`@("`@35E344Q)7U194$5?0DQ/
M0B`@("`@("`@/3X@)V)L;V(G+`H@("`@("`@($U94U%,25]465!%7U9!4E]3
M5%))3D<@(#T^("=V87)C:&%R)RP*("`@("`@("!-65-13$E?5%E015]35%))
M3D<@("`@("`]/B`G8VAA<B<L"B`@("`@("`@35E344Q)7U194$5?1T5/3454
M4ED@("`@/3X@)V=E;VUE=')Y)RP*("`@("D["@H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&-O;G-T<G5C=&]R"@H@("`@+RHJ"B`@("`@*B!4:&ES(&-O;G-T
M<G5C=&]R(&-A;&QS(#QK8F0^)'1H:7,M/D1"7V-O;6UO;B@I/"]K8F0^"B`@
M("`@*@H@("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N
M($1"7VUY<W%L:2@I"B`@("!["B`@("`@("`@)'1H:7,M/D1"7V-O;6UO;B@I
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&-O;FYE8W0H*0H*("`@
M("\J*@H@("`@("H@0V]N;F5C="!T;R!T:&4@9&%T86)A<V4@<V5R=F5R+"!L
M;V<@:6X@86YD(&]P96X@=&AE(&1A=&%B87-E"B`@("`@*@H@("`@("H@1&]N
M)W0@8V%L;"!T:&ES(&UE=&AO9"!D:7)E8W1L>2X@(%5S92!$0CHZ8V]N;F5C
M="@I(&EN<W1E860N"B`@("`@*@H@("`@("H@4$5!4B!$0B=S(&UY<W%L:2!D
M<FEV97(@<W5P<&]R=',@=&AE(&9O;&QO=VEN9R!E>'1R82!$4TX@;W!T:6]N
M<SH*("`@("`J("`@*R!7:&5N('1H92`G<W-L)R`D;W!T:6]N('!A<W-E9"!T
M;R!$0CHZ8V]N;F5C="@I(&ES('1R=64Z"B`@("`@*B`@("`@*R!K97D@("`@
M("!4:&4@<&%T:"!T;R!T:&4@:V5Y(&9I;&4N"B`@("`@*B`@("`@*R!C97)T
M("`@("!4:&4@<&%T:"!T;R!T:&4@8V5R=&EF:6-A=&4@9FEL92X*("`@("`J
M("`@("`K(&-A("`@("`@(%1H92!P871H('1O('1H92!C97)T:69I8V%T92!A
M=71H;W)I='D@9FEL92X*("`@("`J("`@("`K(&-A<&%T:"`@(%1H92!P871H
M('1O(&$@9&ER96-T;W)Y('1H870@8V]N=&%I;G,@=')U<W1E9"!34TP*("`@
M("`J("`@("`@("`@("`@("`@("!#02!C97)T:69I8V%T97,@:6X@<&5M(&9O
M<FUA="X*("`@("`J("`@("`K(&-I<&AE<B`@(%1H92!L:7-T(&]F(&%L;&]W
M86)L92!C:7!H97)S(&9O<B!34TP@96YC<GEP=&EO;BX*("`@("`J"B`@("`@
M*B!%>&%M<&QE(&]F(&AO=R!T;R!C;VYN96-T('5S:6YG(%-33#H*("`@("`J
M(#QC;V1E/@H@("`@("H@<F5Q=6ER95]O;F-E("=$0BYP:'`G.PH@("`@("H@
M"B`@("`@*B`D9'-N(#T@87)R87DH"B`@("`@*B`@("`@)W!H<'1Y<&4G("`]
M/B`G;7ES<6QI)RP*("`@("`J("`@("`G=7-E<FYA;64G(#T^("=S;VUE=7-E
M<B<L"B`@("`@*B`@("`@)W!A<W-W;W)D)R`]/B`G87!A<W-W9"<L"B`@("`@
M*B`@("`@)VAO<W1S<&5C)R`]/B`G;&]C86QH;W-T)RP*("`@("`J("`@("`G
M9&%T86)A<V4G(#T^("=T:&5D8B<L"B`@("`@*B`@("`@)VME>2<@("`@("`]
M/B`G8VQI96YT+6ME>2YP96TG+`H@("`@("H@("`@("=C97)T)R`@("`@/3X@
M)V-L:65N="UC97)T+G!E;2<L"B`@("`@*B`@("`@)V-A)R`@("`@("`]/B`G
M8V%C97)T+G!E;2<L"B`@("`@*B`@("`@)V-A<&%T:"<@("`]/B`G+W!A=&@O
M=&\O8V$O9&ER)RP*("`@("`J("`@("`G8VEP:&5R)R`@(#T^("=!15,G+`H@
M("`@("H@*3L*("`@("`J(`H@("`@("H@)&]P=&EO;G,@/2!A<G)A>2@*("`@
M("`J("`@("`G<W-L)R`]/B!T<G5E+`H@("`@("H@*3L*("`@("`J(`H@("`@
M("H@)&1B(#TF($1".CIC;VYN96-T*"1D<VXL("1O<'1I;VYS*3L*("`@("`J
M(&EF("A014%2.CII<T5R<F]R*"1D8BDI('L*("`@("`J("`@("!D:64H)&1B
M+3YG971-97-S86=E*"DI.PH@("`@("H@?0H@("`@("H@/"]C;V1E/@H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D9'-N("`@("`@("`@=&AE(&1A=&$@
M<V]U<F-E(&YA;64*("`@("`J($!P87)A;2!B;V]L("`D<&5R<VES=&5N="`@
M<VAO=6QD('1H92!C;VYN96-T:6]N(&)E('!E<G-I<W1E;G0_"B`@("`@*@H@
M("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N($$@1$)?17)R
M;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O
M;FYE8W0H)&1S;BP@)'!E<G-I<W1E;G0@/2!F86QS92D*("`@('L*("`@("`@
M("!I9B`H(5!%05(Z.FQO861%>'1E;G-I;VXH)VUY<W%L:2<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E]%6%1%
M3E-)3TY?3D]47T9/54Y$*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YD
M<VX@/2`D9'-N.PH@("`@("`@(&EF("@D9'-N6R=D8G-Y;G1A>"==*2!["B`@
M("`@("`@("`@("1T:&ES+3YD8G-Y;G1A>"`]("1D<VY;)V1B<WEN=&%X)UT[
M"B`@("`@("`@?0H*("`@("`@("`D:6YI(#T@:6YI7V=E="@G=')A8VM?97)R
M;W)S)RD["B`@("`@("`@:6YI7W-E="@G=')A8VM?97)R;W)S)RP@,2D["B`@
M("`@("`@)'!H<%]E<G)O<FUS9R`]("<G.PH*("`@("`@("!I9B`H)'1H:7,M
M/F=E=$]P=&EO;B@G<W-L)RD@/3T]('1R=64I('L*("`@("`@("`@("`@)&EN
M:70@/2!M>7-Q;&E?:6YI="@I.PH@("`@("`@("`@("!M>7-Q;&E?<W-L7W-E
M="@*("`@("`@("`@("`@("`@("1I;FET+`H@("`@("`@("`@("`@("`@96UP
M='DH)&1S;ELG:V5Y)UTI("`@(#\@;G5L;"`Z("1D<VY;)VME>2==+`H@("`@
M("`@("`@("`@("`@96UP='DH)&1S;ELG8V5R="==*2`@(#\@;G5L;"`Z("1D
M<VY;)V-E<G0G72P*("`@("`@("`@("`@("`@(&5M<'1Y*"1D<VY;)V-A)UTI
M("`@("`_(&YU;&P@.B`D9'-N6R=C82==+`H@("`@("`@("`@("`@("`@96UP
M='DH)&1S;ELG8V%P871H)UTI(#\@;G5L;"`Z("1D<VY;)V-A<&%T:"==+`H@
M("`@("`@("`@("`@("`@96UP='DH)&1S;ELG8VEP:&5R)UTI(#\@;G5L;"`Z
M("1D<VY;)V-I<&AE<B=="B`@("`@("`@("`@("D["B`@("`@("`@("`@(&EF
M("@D=&AI<RT^8V]N;F5C=&EO;B`]($!M>7-Q;&E?<F5A;%]C;VYN96-T*`H@
M("`@("`@("`@("`@("`@("`@("1I;FET+`H@("`@("`@("`@("`@("`@("`@
M("1D<VY;)VAO<W1S<&5C)UTL"B`@("`@("`@("`@("`@("`@("`@)&1S;ELG
M=7-E<FYA;64G72P*("`@("`@("`@("`@("`@("`@("`D9'-N6R=P87-S=V]R
M9"==+`H@("`@("`@("`@("`@("`@("`@("1D<VY;)V1A=&%B87-E)UTL"B`@
M("`@("`@("`@("`@("`@("`@)&1S;ELG<&]R="==+`H@("`@("`@("`@("`@
M("`@("`@("1D<VY;)W-O8VME="==*2D*("`@("`@("`@("`@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/F-O;FYE8W1I;VX@/2`D:6YI=#L*("`@("`@("`@
M("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YC;VYN
M96-T:6]N(#T@0&UY<W%L:5]C;VYN96-T*`H@("`@("`@("`@("`@("`@)&1S
M;ELG:&]S='-P96,G72P*("`@("`@("`@("`@("`@("1D<VY;)W5S97)N86UE
M)UTL"B`@("`@("`@("`@("`@("`D9'-N6R=P87-S=V]R9"==+`H@("`@("`@
M("`@("`@("`@)&1S;ELG9&%T86)A<V4G72P*("`@("`@("`@("`@("`@("1D
M<VY;)W!O<G0G72P*("`@("`@("`@("`@("`@("1D<VY;)W-O8VME="=="B`@
M("`@("`@("`@("D["B`@("`@("`@?0H*("`@("`@("!I;FE?<V5T*"=T<F%C
M:U]E<G)O<G,G+"`D:6YI*3L*"B`@("`@("`@:68@*"$D=&AI<RT^8V]N;F5C
M=&EO;BD@>PH@("`@("`@("`@("!I9B`H*"1E<G(@/2!`;7ES<6QI7V-O;FYE
M8W1?97)R;W(H*2D@(3T@)R<I('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E]#3TY.14-47T9!24Q%1"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N=6QL+"!N
M=6QL+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1E<G(I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27T-/3DY%
M0U1?1D%)3$5$+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&YU;&PL(&YU;&PL(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'!H<%]E<G)O<FUS9RD["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@D9'-N6R=D871A8F%S92==
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?9&(@/2`D9'-N6R=D871A8F%S92==
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&1I<V-O;FYE8W0H*0H*("`@("\J*@H@("`@
M("H@1&ES8V]N;F5C=',@9G)O;2!T:&4@9&%T86)A<V4@<V5R=F5R"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L("!44E5%(&]N('-U8V-E<W,L($9!3%-%
M(&]N(&9A:6QU<F4*("`@("`J+PH@("`@9G5N8W1I;VX@9&ES8V]N;F5C="@I
M"B`@("!["B`@("`@("`@)')E="`]($!M>7-Q;&E?8VQO<V4H)'1H:7,M/F-O
M;FYE8W1I;VXI.PH@("`@("`@("1T:&ES+3YC;VYN96-T:6]N(#T@;G5L;#L*
M("`@("`@("!R971U<FX@)')E=#L*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!S:6UP;&51=65R>2@I"@H@("`@+RHJ"B`@("`@*B!396YD<R!A('%U
M97)Y('1O('1H92!D871A8F%S92!S97)V97(*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("!T:&4@4U%,('%U97)Y('-T<FEN9PH@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@("L@82!02%`@<F5S=6QT(')E<W)O=6-E(&9O<B!S
M=6-C97-S9G5L(%-%3$5#5"!Q=65R:65S"B`@("`@*B`@("`@("`@("`@("`@
M("`K('1H92!$0E]/2R!C;VYS=&%N="!F;W(@;W1H97(@<W5C8V5S<V9U;"!Q
M=65R:65S"B`@("`@*B`@("`@("`@("`@("`@("`K(&$@1$)?17)R;W(@;V)J
M96-T(&]N(&9A:6QU<F4*("`@("`J+PH@("`@9G5N8W1I;VX@<VEM<&QE475E
M<GDH)'%U97)Y*0H@("`@>PH@("`@("`@("1I<VUA;FEP(#T@1$(Z.FES36%N
M:7`H)'%U97)Y*3L*("`@("`@("`D=&AI<RT^;&%S=%]Q=65R>2`]("1Q=65R
M>3L*("`@("`@("`D<75E<GD@/2`D=&AI<RT^;6]D:69Y475E<GDH)'%U97)Y
M*3L*("`@("`@("!I9B`H)'1H:7,M/E]D8BD@>PH@("`@("`@("`@("!I9B`H
M(4!M>7-Q;&E?<V5L96-T7V1B*"1T:&ES+3YC;VYN96-T:6]N+"`D=&AI<RT^
M7V1B*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM>7-Q;&E2
M86ES945R<F]R*$1"7T524D]27TY/1$)314Q%0U1%1"D["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@:68@*"$D=&AI<RT^875T;V-O;6UI="`F
M)B`D:7-M86YI<"D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/G1R86YS86-T
M:6]N7V]P8V]U;G0@/3T@,"D@>PH@("`@("`@("`@("`@("`@)')E<W5L="`]
M($!M>7-Q;&E?<75E<GDH)'1H:7,M/F-O;FYE8W1I;VXL("=3150@05543T-/
M34U)5#TP)RD["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@0&UY<W%L:5]Q
M=65R>2@D=&AI<RT^8V]N;F5C=&EO;BP@)T)%1TE.)RD["B`@("`@("`@("`@
M("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/FUY<W%L:5)A:7-E17)R;W(H*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^=')A;G-A8W1I
M;VY?;W!C;W5N="LK.PH@("`@("`@('T*("`@("`@("`D<F5S=6QT(#T@0&UY
M<W%L:5]Q=65R>2@D=&AI<RT^8V]N;F5C=&EO;BP@)'%U97)Y*3L*("`@("`@
M("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM
M>7-Q;&E286ES945R<F]R*"D["B`@("`@("`@?0H@("`@("`@(&EF("AI<U]O
M8FIE8W0H)')E<W5L="DI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!N97AT4F5S=6QT*"D*"B`@("`O*BH*("`@("`J
M($UO=F4@=&AE(&EN=&5R;F%L(&UY<W%L(')E<W5L="!P;VEN=&5R('1O('1H
M92!N97AT(&%V86EL86)L92!R97-U;'0N"B`@("`@*@H@("`@("H@5&AI<R!M
M971H;V0@:&%S(&YO="!B965N(&EM<&QE;65N=&5D('EE="X*("`@("`J"B`@
M("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="!A('9A;&ED('-Q;"!R97-U
M;'0@<F5S;W5R8V4*("`@("`J($!R971U<FX@9F%L<V4*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&YE>'1297-U;'0H)')E
M<W5L="D*("`@('L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@9F5T8VA);G1O*"D*"B`@("`O*BH*("`@("`J
M(%!L86-E<R!A(')O=R!F<F]M('1H92!R97-U;'0@<V5T(&EN=&\@=&AE(&=I
M=F5N(&%R<F%Y"B`@("`@*@H@("`@("H@1F]R;6%T:6YG(&]F('1H92!A<G)A
M>2!A;F0@=&AE(&1A=&$@=&AE<F5I;B!A<F4@8V]N9FEG=7)A8FQE+@H@("`@
M("H@4V5E($1"7W)E<W5L=#HZ9F5T8VA);G1O*"D@9F]R(&UO<F4@:6YF;W)M
M871I;VXN"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@:7,@;F]T(&UE86YT
M('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@("H@1$)?<F5S=6QT
M.CIF971C:$EN=&\H*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@
M(G!R;W1E8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P
M87)A=&4@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D
M<F5S=6QT("`@('1H92!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J($!P
M87)A;2!A<G)A>2`@("`D87)R("`@("`@('1H92!R969E<F5N8V5D(&%R<F%Y
M('1O('!U="!T:&4@9&%T82!I;@H@("`@("H@0'!A<F%M(&EN="`@("`@("1F
M971C:&UO9&4@:&]W('1H92!R97-U;'1I;F<@87)R87D@<VAO=6QD(&)E(&EN
M9&5X960*("`@("`J($!P87)A;2!I;G0@("`@("`D<F]W;G5M("`@('1H92!R
M;W<@;G5M8F5R('1O(&9E=&-H("@P(#T@9FER<W0@<F]W*0H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@($1"7T]+(&]N('-U8V-E<W,L($Y53$P@=VAE
M;B!T:&4@96YD(&]F(&$@<F5S=6QT('-E="!I<PH@("`@("H@("`@("`@("`@
M("`@("`@(')E86-H960@;W(@;VX@9F%I;'5R90H@("`@("H*("`@("`J($!S
M964@1$)?<F5S=6QT.CIF971C:$EN=&\H*0H@("`@("HO"B`@("!F=6YC=&EO
M;B!F971C:$EN=&\H)')E<W5L="P@)B1A<G(L("1F971C:&UO9&4L("1R;W=N
M=6T@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@D<F]W;G5M("$]/2!N=6QL
M*2!["B`@("`@("`@("`@(&EF("@A0&UY<W%L:5]D871A7W-E96LH)')E<W5L
M="P@)')O=VYU;2DI('L*("`@("`@("`@("`@("`@(')E='5R;B!N=6QL.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@D9F5T8VAM;V1E
M("8@1$)?1D540TA-3T1%7T%34T]#*2!["B`@("`@("`@("`@("1A<G(@/2!`
M;7ES<6QI7V9E=&-H7V%R<F%Y*"1R97-U;'0L($U94U%,25]!4U-/0RD["B`@
M("`@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F
M($1"7U!/4E1!0DE,25197TQ/5T520T%312`F)B`D87)R*2!["B`@("`@("`@
M("`@("`@("`D87)R(#T@87)R87E?8VAA;F=E7VME>5]C87-E*"1A<G(L($-!
M4T5?3$]715(I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&%R<B`]($!M>7-Q;&E?9F5T8VA?<F]W*"1R97-U;'0I.PH@
M("`@("`@('T*("`@("`@("!I9B`H(21A<G(I('L*("`@("`@("`@("`@<F5T
M=7)N(&YU;&P["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N
M<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197U)44DE-*2!["B`@
M("`@("`@("`@("\J"B`@("`@("`@("`@("`J($5V96X@=&AO=6=H('1H:7,@
M1$)-4R!A;')E861Y('1R:6US(&]U='!U="P@=V4@9&\@=&AI<R!B96-A=7-E
M"B`@("`@("`@("`@("`J(&$@9FEE;&0@;6EG:'0@:&%V92!I;G1E;G1I;VYA
M;"!W:&ET97-P86-E(&%T('1H92!E;F0@=&AA=`H@("`@("`@("`@("`@*B!G
M971S(')E;6]V960@8GD@1$)?4$]25$%"24Q)5%E?4E1224T@=6YD97(@86YO
M=&AE<B!D<FEV97(N"B`@("`@("`@("`@("`J+PH@("`@("`@("`@("`D=&AI
M<RT^7W)T<FEM07)R87E686QU97,H)&%R<BD["B`@("`@("`@?0H@("`@("`@
M(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!
M0DE,25197TY53$Q?5$]?14U05%DI('L*("`@("`@("`@("`@)'1H:7,M/E]C
M;VYV97)T3G5L;$%R<F%Y5F%L=65S5&]%;7!T>2@D87)R*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&9R965297-U;'0H*0H*("`@("\J*@H@("`@("H@1&5L971E<R!T
M:&4@<F5S=6QT('-E="!A;F0@9G)E97,@=&AE(&UE;6]R>2!O8V-U<&EE9"!B
M>2!T:&4@<F5S=6QT('-E=`H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES
M(&YO="!M96%N="!T;R!B92!C86QL960@9&ER96-T;'DN("!5<V4*("`@("`J
M($1"7W)E<W5L=#HZ9G)E92@I(&EN<W1E860N("!)="!C86XG="!B92!D96-L
M87)E9"`B<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@
M82!S97!A<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U
M<F-E("1R97-U;'0@(%!(4"=S('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;"`@5%)512!O;B!S=6-C97-S+"!&04Q3
M12!I9B`D<F5S=6QT(&ES(&EN=F%L:60*("`@("`J"B`@("`@*B!`<V5E($1"
M7W)E<W5L=#HZ9G)E92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&9R965297-U
M;'0H)')E<W5L="D*("`@('L*("`@("`@("!R971U<FX@0&UY<W%L:5]F<F5E
M7W)E<W5L="@D<F5S=6QT*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!N=6U#;VQS*"D*"B`@("`O*BH*("`@("`J($=E=',@=&AE(&YU;6)E<B!O
M9B!C;VQU;6YS(&EN(&$@<F5S=6QT('-E=`H@("`@("H*("`@("`J(%1H:7,@
M;65T:&]D(&ES(&YO="!M96%N="!T;R!B92!C86QL960@9&ER96-T;'DN("!5
M<V4*("`@("`J($1"7W)E<W5L=#HZ;G5M0V]L<R@I(&EN<W1E860N("!)="!C
M86XG="!B92!D96-L87)E9"`B<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$
M0E]R97-U;'0@:7,@82!S97!A<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@
M0'!A<F%M(')E<V]U<F-E("1R97-U;'0@(%!(4"=S('%U97)Y(')E<W5L="!R
M97-O=7)C90H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;G5M8F5R
M(&]F(&-O;'5M;G,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@
M("`@("H*("`@("`J($!S964@1$)?<F5S=6QT.CIN=6U#;VQS*"D*("`@("`J
M+PH@("`@9G5N8W1I;VX@;G5M0V]L<R@D<F5S=6QT*0H@("`@>PH@("`@("`@
M("1C;VQS(#T@0&UY<W%L:5]N=6U?9FEE;&1S*"1R97-U;'0I.PH@("`@("`@
M(&EF("@A)&-O;',I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM>7-Q
M;&E286ES945R<F]R*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D8V]L
M<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!N=6U2;W=S*"D*"B`@
M("`O*BH*("`@("`J($=E=',@=&AE(&YU;6)E<B!O9B!R;W=S(&EN(&$@<F5S
M=6QT('-E=`H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES(&YO="!M96%N
M="!T;R!B92!C86QL960@9&ER96-T;'DN("!5<V4*("`@("`J($1"7W)E<W5L
M=#HZ;G5M4F]W<R@I(&EN<W1E860N("!)="!C86XG="!B92!D96-L87)E9"`B
M<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@82!S97!A
M<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1R
M97-U;'0@(%!(4"=S('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@("H*("`@
M("`J($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F(')O=W,N("!!($1"7T5R
M<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?
M<F5S=6QT.CIN=6U2;W=S*"D*("`@("`J+PH@("`@9G5N8W1I;VX@;G5M4F]W
M<R@D<F5S=6QT*0H@("`@>PH@("`@("`@("1R;W=S(#T@0&UY<W%L:5]N=6U?
M<F]W<R@D<F5S=6QT*3L*("`@("`@("!I9B`H)')O=W,@/3T](&YU;&PI('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM>7-Q;&E286ES945R<F]R*"D[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F]W<SL*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!A=71O0V]M;6ET*"D*"B`@("`O*BH*("`@("`J
M($5N86)L97,@;W(@9&ES86)L97,@875T;VUA=&EC(&-O;6UI=',*("`@("`J
M"B`@("`@*B!`<&%R86T@8F]O;"`D;VYO9F8@('1R=64@='5R;G,@:70@;VXL
M(&9A;'-E('1U<FYS(&ET(&]F9@H@("`@("H*("`@("`J($!R971U<FX@:6YT
M("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@:68@=&AE
M(&1R:79E<@H@("`@("H@("`@("`@("`@("`@("!D;V5S;B=T('-U<'!O<G0@
M875T;RUC;VUM:71T:6YG('1R86YS86-T:6]N<RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@875T;T-O;6UI="@D;VYO9F8@/2!F86QS92D*("`@('L*("`@("`@
M("`O+R!86%@@:68@)'1H:7,M/G1R86YS86-T:6]N7V]P8V]U;G0@/B`P+"!W
M92!S:&]U;&0@<')O8F%B;'D*("`@("`@("`O+R!I<W-U92!A('=A<FYI;F<@
M:&5R92X*("`@("`@("`D=&AI<RT^875T;V-O;6UI="`]("1O;F]F9B`_('1R
M=64@.B!F86QS93L*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@8V]M;6ET*"D*"B`@("`O*BH*("`@("`J($-O
M;6UI=',@=&AE(&-U<G)E;G0@=')A;G-A8W1I;VX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J
M96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;6UI="@I
M"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT
M(#X@,"D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]D8BD@>PH@("`@("`@
M("`@("`@("`@:68@*"%`;7ES<6QI7W-E;&5C=%]D8B@D=&AI<RT^8V]N;F5C
M=&EO;BP@)'1H:7,M/E]D8BDI('L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/FUY<W%L:5)A:7-E17)R;W(H1$)?15)23U)?3D]$0E-%3$5#
M5$5$*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D<F5S=6QT(#T@0&UY<W%L:5]Q=65R>2@D=&AI<RT^8V]N;F5C=&EO
M;BP@)T-/34U)5"<I.PH@("`@("`@("`@("`D<F5S=6QT(#T@0&UY<W%L:5]Q
M=65R>2@D=&AI<RT^8V]N;F5C=&EO;BP@)U-%5"!!551/0T]-34E4/3$G*3L*
M("`@("`@("`@("`@)'1H:7,M/G1R86YS86-T:6]N7V]P8V]U;G0@/2`P.PH@
M("`@("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^;7ES<6QI4F%I<V5%<G)O<B@I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!R;VQL8F%C:R@I"@H@("`@+RHJ"B`@("`@*B!2
M979E<G1S('1H92!C=7)R96YT('1R86YS86-T:6]N"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B
M:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R;VQL8F%C
M:R@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O
M=6YT(#X@,"D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]D8BD@>PH@("`@
M("`@("`@("`@("`@:68@*"%`;7ES<6QI7W-E;&5C=%]D8B@D=&AI<RT^8V]N
M;F5C=&EO;BP@)'1H:7,M/E]D8BDI('L*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/FUY<W%L:5)A:7-E17)R;W(H1$)?15)23U)?3D]$0E-%
M3$5#5$5$*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D<F5S=6QT(#T@0&UY<W%L:5]Q=65R>2@D=&AI<RT^8V]N;F5C
M=&EO;BP@)U)/3$Q"04-+)RD["B`@("`@("`@("`@("1R97-U;'0@/2!`;7ES
M<6QI7W%U97)Y*"1T:&ES+3YC;VYN96-T:6]N+"`G4T54($%55$]#3TU-250]
M,2<I.PH@("`@("`@("`@("`D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`]
M(#`["B`@("`@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YM>7-Q;&E286ES945R<F]R*"D["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(&%F9F5C=&5D4F]W<R@I"@H@("`@+RHJ
M"B`@("`@*B!$971E<FUI;F5S('1H92!N=6UB97(@;V8@<F]W<R!A9F9E8W1E
M9"!B>2!A(&1A=&$@;6%N:75P;&%T:6]N('%U97)Y"B`@("`@*@H@("`@("H@
M,"!I<R!R971U<FYE9"!F;W(@<75E<FEE<R!T:&%T(&1O;B=T(&UA;FEP=6QA
M=&4@9&%T82X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E
M<B!O9B!R;W=S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@869F96-T9612;W=S*"D*("`@('L*("`@("`@
M("!I9B`H1$(Z.FES36%N:7`H)'1H:7,M/FQA<W1?<75E<GDI*2!["B`@("`@
M("`@("`@(')E='5R;B!`;7ES<6QI7V%F9F5C=&5D7W)O=W,H)'1H:7,M/F-O
M;FYE8W1I;VXI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R
M;B`P.PH@("`@("`@('T*("`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M;F5X=$ED*"D*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&YE>'0@9G)E
M92!I9"!I;B!A('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`@)'-E<5]N86UE("!N86UE(&]F('1H92!S97%U96YC90H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)&]N9&5M86YD("!W:&5N('1R=64L('1H92!S97%E;F-E
M(&ES(&%U=&]M871I8V%L;'D*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&-R96%T960@:68@:70@9&]E<R!N;W0@97AI<W0*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&EN="`@=&AE(&YE>'0@:60@;G5M8F5R(&EN('1H92!S
M97%U96YC92X*("`@("`J("`@("`@("`@("`@("`@02!$0E]%<G)O<B!O8FIE
M8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ
M;F5X=$E$*"DL($1"7V-O;6UO;CHZ9V5T4V5Q=65N8V5.86UE*"DL"B`@("`@
M*B`@("`@($1"7VUY<W%L:3HZ8W)E871E4V5Q=65N8V4H*2P@1$)?;7ES<6QI
M.CID<F]P4V5Q=65N8V4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!N97AT260H
M)'-E<5]N86UE+"`D;VYD96UA;F0@/2!T<G5E*0H@("`@>PH@("`@("`@("1S
M97%N86UE(#T@)'1H:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I.PH@
M("`@("`@(&1O('L*("`@("`@("`@("`@)')E<&5A="`](#`["B`@("`@("`@
M("`@("1T:&ES+3YP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%52
M3BD["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^<75E<GDH)U501$%4
M12`G("X@)'-E<6YA;64*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`N("<@4T54(&ED(#T@3$%35%])3E-%4E1?240H:60@*R`Q*2<I.PH@
M("`@("`@("`@("`D=&AI<RT^<&]P17)R;W)(86YD;&EN9R@I.PH@("`@("`@
M("`@("!I9B`H)')E<W5L="`]/3T@1$)?3TLI('L*("`@("`@("`@("`@("`@
M("\O($-/34U/3B!#05-%"B`@("`@("`@("`@("`@("`D:60@/2!`;7ES<6QI
M7VEN<V5R=%]I9"@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@("`@
M("!I9B`H)&ED("$](#`I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)&ED.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\O($5-
M4%19(%-%42!404),10H@("`@("`@("`@("`@("`@+R\@4V5Q=65N8V4@=&%B
M;&4@;75S="!B92!E;7!T>2!F;W(@<V]M92!R96%S;VXL"B`@("`@("`@("`@
M("`@("`O+R!S;R!F:6QL(&ET(&%N9"!R971U<FX@,0H@("`@("`@("`@("`@
M("`@+R\@3V)T86EN(&$@=7-E<BUL979E;"!L;V-K"B`@("`@("`@("`@("`@
M("`D<F5S=6QT(#T@)'1H:7,M/F=E=$]N92@G4T5,14-4($=%5%],3T-+*"<*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@(B<D
M>W-E<6YA;65]7VQO8VLG+"`Q,"DB*3L*("`@("`@("`@("`@("`@(&EF("A$
M0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D<F5S=6QT*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&EF("@D<F5S=6QT(#T](#`I('L*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/FUY<W%L:5)A:7-E17)R
M;W(H1$)?15)23U)?3D]47TQ/0TM%1"D["B`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`@("`@+R\@861D('1H92!D969A=6QT('9A;'5E"B`@("`@
M("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/G%U97)Y*"=215!,04-%($E.
M5$\@)R`N("1S97%N86UE"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("X@)R`H:60I(%9!3%5%4R`H,"DG*3L*("`@("`@("`@("`@
M("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D<F5S=6QT*3L*("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O+R!296QE87-E('1H
M92!L;V-K"B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F=E=$]N
M92@G4T5,14-4(%)%3$5!4T5?3$]#2R@G"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`N("(G)'MS97%N86UE?5]L;V-K)RDB*3L*
M("`@("`@("`@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@
M("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D
M<F5S=6QT*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("\O
M(%=E(&MN;W<@=VAA="!T:&4@<F5S=6QT('=I;&P@8F4L('-O(&YO(&YE960@
M=&\@=')Y(&%G86EN"B`@("`@("`@("`@("`@("!R971U<FX@,3L*"B`@("`@
M("`@("`@('T@96QS96EF("@D;VYD96UA;F0@)B8@1$(Z.FES17)R;W(H)')E
M<W5L="D@)B8*("`@("`@("`@("`@("`@("1R97-U;'0M/F=E=$-O9&4H*2`]
M/2!$0E]%4E)/4E].3U-50TA404),12D*("`@("`@("`@("`@>PH@("`@("`@
M("`@("`@("`@+R\@3TY$14U!3D0@5$%"3$4@0U)%051)3TX*("`@("`@("`@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^8W)E871E4V5Q=65N8V4H)'-E<5]N
M86UE*3L*"B`@("`@("`@("`@("`@("`O+R!3:6YC92!C<F5A=&5397%U96YC
M92!I;FET:6%L:7IE<R!T:&4@240@=&\@8F4@,2P*("`@("`@("`@("`@("`@
M("\O('=E(&1O(&YO="!N965D('1O(')E=')I979E('1H92!)1"!A9V%I;B`H
M;W(@=V4@=VEL;"!G970@,BD*("`@("`@("`@("`@("`@(&EF("A$0CHZ:7-%
M<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@D<F5S=6QT*3L*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@+R\@1FER<W0@240@;V8@82!N
M97=L>2!C<F5A=&5D('-E<75E;F-E(&ES(#$*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@,3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@('T@
M96QS96EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2`F)@H@("`@("`@("`@("`@
M("`@("`@("`@)')E<W5L="T^9V5T0V]D92@I(#T]($1"7T524D]27T%,4D5!
M1%E?15A)4U13*0H@("`@("`@("`@("!["B`@("`@("`@("`@("`@("`O+R!"
M04-+5T%21%,@0T]-4$%4"B`@("`@("`@("`@("`@("`O+R!S964@7T)#<V5Q
M=65N8V4H*2!C;VUM96YT"B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H
M:7,M/E]"0W-E<75E;F-E*"1S97%N86UE*3L*("`@("`@("`@("`@("`@(&EF
M("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D<F5S=6QT*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1R97!E870@/2`Q.PH@("`@("`@
M("`@("!]"B`@("`@("`@?2!W:&EL92`H)')E<&5A="D["@H@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D<F5S=6QT*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($-R96%T97,@82!N97<@<V5Q=65N8V4*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1S97%?;F%M92`@;F%M92!O9B!T:&4@;F5W('-E
M<75E;F-E"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U
M8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*
M("`@("`J($!S964@1$)?8V]M;6]N.CIC<F5A=&5397%U96YC92@I+"!$0E]C
M;VUM;VXZ.F=E=%-E<75E;F-E3F%M92@I+`H@("`@("H@("`@("!$0E]M>7-Q
M;&DZ.FYE>'1)1"@I+"!$0E]M>7-Q;&DZ.F1R;W!397%U96YC92@I"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-R96%T95-E<75E;F-E*"1S97%?;F%M92D*("`@
M('L*("`@("`@("`D<V5Q;F%M92`]("1T:&ES+3YG971397%U96YC94YA;64H
M)'-E<5]N86UE*3L*("`@("`@("`D<F5S(#T@)'1H:7,M/G%U97)Y*"=#4D5!
M5$4@5$%"3$4@)R`N("1S97%N86UE"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`N("<@*&ED($E.5$5'15(@54Y324=.140@05543U])3D-214U%3E0@
M3D]4($Y53$PL)PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G(%!2
M24U!4ED@2T59*&ED*2DG*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E
M<RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@?0H@("`@
M("`@("\O(&EN<V5R="!Y:65L9',@=F%L=64@,2P@;F5X=$ED(&-A;&P@=VEL
M;"!G96YE<F%T92!)1"`R"B`@("`@("`@<F5T=7)N("1T:&ES+3YQ=65R>2@B
M24Y315)4($E.5$\@)'MS97%N86UE?2`H:60I(%9!3%5%4R`H,"DB*3L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!D<F]P4V5Q=65N8V4H*0H*("`@
M("\J*@H@("`@("H@1&5L971E<R!A('-E<75E;F-E"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<V5Q7VYA;64@(&YA;64@;V8@=&AE('-E<75E;F-E
M('1O(&)E(&1E;&5T960*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?
M3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N
M"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F1R;W!397%U96YC92@I
M+"!$0E]C;VUM;VXZ.F=E=%-E<75E;F-E3F%M92@I+`H@("`@("H@("`@("!$
M0E]M>7-Q;#HZ;F5X=$E$*"DL($1"7VUY<W%L.CIC<F5A=&5397%U96YC92@I
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&1R;W!397%U96YC92@D<V5Q7VYA;64I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YQ=65R>2@G1%)/4"!404),
M12`G("X@)'1H:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I*3L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!?0D-S97%U96YC92@I"@H@("`@
M+RHJ"B`@("`@*B!"86-K=V%R9',@8V]M<&%T:6)I;&ET>2!W:71H(&]L9"!S
M97%U96YC92!E;75L871I;VX@:6UP;&5M96YT871I;VX*("`@("`J("AC;&5A
M;B!U<"!T:&4@9'5P97,I"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<V5Q;F%M92`@=&AE('-E<75E;F-E(&YA;64@=&\@8VQE86X@=7`*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VP@('1R=64@;VX@<W5C8V5S<RX@($$@1$)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]"0W-E<75E;F-E*"1S
M97%N86UE*0H@("`@>PH@("`@("`@("\O($]B=&%I;B!A('5S97(M;&5V96P@
M;&]C:RXN+B!T:&ES('=I;&P@<F5L96%S92!A;GD@<')E=FEO=7,*("`@("`@
M("`O+R!A<'!L:6-A=&EO;B!L;V-K<RP@8G5T('5N;&EK92!,3T-+(%1!0DQ%
M4RP@:70@9&]E<R!N;W0@86)O<G0*("`@("`@("`O+R!T:&4@8W5R<F5N="!T
M<F%N<V%C=&EO;B!A;F0@:7,@;75C:"!L97-S(&9R97%U96YT;'D@=7-E9"X*
M("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F=E=$]N92@B4T5,14-4($=%5%],
M3T-+*"<D>W-E<6YA;65]7VQO8VLG+#$P*2(I.PH@("`@("`@(&EF("A$0CHZ
M:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@("`@("!]"B`@("`@("`@:68@*"1R97-U;'0@/3T@,"D@>PH@("`@
M("`@("`@("`O+R!&86EL960@=&\@9V5T('1H92!L;V-K+"!C86XG="!D;R!T
M:&4@8V]N=F5R<VEO;BP@8F%I;`H@("`@("`@("`@("`O+R!W:71H(&$@1$)?
M15)23U)?3D]47TQ/0TM%1"!E<G)O<@H@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/FUY<W%L:5)A:7-E17)R;W(H1$)?15)23U)?3D]47TQ/0TM%1"D["B`@
M("`@("`@?0H*("`@("`@("`D:&EG:&5S=%]I9"`]("1T:&ES+3YG971/;F4H
M(E-%3$5#5"!-05@H:60I($923TT@)'MS97%N86UE?2(I.PH@("`@("`@(&EF
M("A$0CHZ:7-%<G)O<B@D:&EG:&5S=%]I9"DI('L*("`@("`@("`@("`@<F5T
M=7)N("1H:6=H97-T7VED.PH@("`@("`@('T*"B`@("`@("`@+R\@5&AI<R!S
M:&]U;&0@:VEL;"!A;&P@<F]W<R!E>&-E<'0@=&AE(&AI9VAE<W0*("`@("`@
M("`O+R!792!S:&]U;&0@<')O8F%B;'D@9&\@<V]M971H:6YG(&EF("1H:6=H
M97-T7VED(&ES;B=T"B`@("`@("`@+R\@;G5M97)I8RP@8G5T($DG;2!A="!A
M(&QO<W,@87,@:&]W('1O(&AA;F1L92!T:&%T+BXN"B`@("`@("`@)')E<W5L
M="`]("1T:&ES+3YQ=65R>2@G1$5,151%($923TT@)R`N("1S97%N86UE"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("(@5TA%4D4@:60@/#X@
M)&AI9VAE<W1?:60B*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L
M="DI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*
M("`@("`@("`O+R!)9B!A;F]T:&5R('1H<F5A9"!H87,@8F5E;B!W86ET:6YG
M(&9O<B!T:&ES(&QO8VLL"B`@("`@("`@+R\@:70@=VEL;"!G;R!T:')U('1H
M92!A8F]V92!P<F]C961U<F4L(&)U="!W:6QL(&AA=F4@;F\*("`@("`@("`O
M+R!R96%L(&5F9F5C=`H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^9V5T3VYE
M*")314Q%0U0@4D5,14%315],3T-+*"<D>W-E<6YA;65]7VQO8VLG*2(I.PH@
M("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@
M("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<75O=&5)9&5N=&EF
M:65R*"D*"B`@("`O*BH*("`@("`J(%%U;W1E<R!A('-T<FEN9R!S;R!I="!C
M86X@8F4@<V%F96QY('5S960@87,@82!T86)L92!O<B!C;VQU;6X@;F%M90H@
M("`@("H*("`@("`J($UY4U%,(&-A;B=T(&AA;F1L92!T:&4@8F%C:W1I8VL@
M8VAA<F%C=&5R("@\:V)D/F`\+VMB9#XI(&EN"B`@("`@*B!T86)L92!O<B!C
M;VQU;6X@;F%M97,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<W1R
M("!I9&5N=&EF:65R(&YA;64@=&\@8F4@<75O=&5D"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@('%U;W1E9"!I9&5N=&EF:65R('-T<FEN9PH@("`@
M("H*("`@("`J($!S964@1$)?8V]M;6]N.CIQ=6]T94ED96YT:69I97(H*0H@
M("`@("H@0'-I;F-E($UE=&AO9"!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q
M+C8N,`H@("`@("HO"B`@("!F=6YC=&EO;B!Q=6]T94ED96YT:69I97(H)'-T
M<BD*("`@('L*("`@("`@("!R971U<FX@)V`G("X@)'-T<B`N("=@)SL*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!E<V-A<&53:6UP;&4H*0H*("`@
M("\J*@H@("`@("H@17-C87!E<R!A('-T<FEN9R!A8V-O<F1I;F<@=&\@=&AE
M(&-U<G)E;G0@1$)-4R=S('-T86YD87)D<PH@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'-T<B`@=&AE('-T<FEN9R!T;R!B92!E<V-A<&5D"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!E<V-A<&5D('-T<FEN9PH@
M("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIQ=6]T95-M87)T*"D*("`@
M("`J($!S:6YC92!-971H;V0@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XV
M+C`*("`@("`J+PH@("`@9G5N8W1I;VX@97-C87!E4VEM<&QE*"1S='(I"B`@
M("!["B`@("`@("`@<F5T=7)N($!M>7-Q;&E?<F5A;%]E<V-A<&5?<W1R:6YG
M*"1T:&ES+3YC;VYN96-T:6]N+"`D<W1R*3L*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!M;V1I9GE,:6UI=%%U97)Y*"D*"B`@("`O*BH*("`@("`J
M($%D9',@3$E-250@8VQA=7-E<R!T;R!A('%U97)Y('-T<FEN9R!A8V-O<F1I
M;F<@=&\@8W5R<F5N="!$0DU3('-T86YD87)D<PH@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'%U97)Y("`@=&AE('%U97)Y('1O(&UO9&EF>0H@("`@
M("H@0'!A<F%M(&EN="`@("`D9G)O;2`@("!T:&4@<F]W('1O('-T87)T('1O
M(&9E=&-H:6YG("@P(#T@=&AE(&9I<G-T(')O=RD*("`@("`J($!P87)A;2!I
M;G0@("`@)&-O=6YT("`@=&AE(&YU;6)E<G,@;V8@<F]W<R!T;R!F971C:`H@
M("`@("H@0'!A<F%M(&UI>&5D("`D<&%R86US("!A<G)A>2P@<W1R:6YG(&]R
M(&YU;65R:6,@9&%T82!T;R!B92!U<V5D(&EN"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("!E>&5C=71I;VX@;V8@=&AE('-T871E;65N="X@(%%U
M86YT:71Y(&]F(&ET96US"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("!P87-S960@;75S="!M871C:"!Q=6%N=&ET>2!O9B!P;&%C96AO;&1E<G,@
M:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('%U97)Y.B`@;65A
M;FEN9R`Q('!L86-E:&]L9&5R(&9O<B!N;VXM87)R87D*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@('!A<F%M971E<G,@;W(@,2!P;&%C96AO;&1E
M<B!P97(@87)R87D@96QE;65N="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@=&AE('%U97)Y('-T<FEN9R!W:71H($Q)34E4(&-L875S97,@861D
M960*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@("HO"B`@
M("!F=6YC=&EO;B!M;V1I9GE,:6UI=%%U97)Y*"1Q=65R>2P@)&9R;VTL("1C
M;W5N="P@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*$1"
M.CII<TUA;FEP*"1Q=65R>2DI('L*("`@("`@("`@("`@<F5T=7)N("1Q=65R
M>2`N("(@3$E-250@)&-O=6YT(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@)'%U97)Y("X@(B!,24U)5"`D9G)O;2P@)&-O=6YT(CL*
M("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;7ES<6QI
M4F%I<V5%<G)O<B@I"@H@("`@+RHJ"B`@("`@*B!0<F]D=6-E<R!A($1"7T5R
M<F]R(&]B:F5C="!R96=A<F1I;F<@=&AE(&-U<G)E;G0@<')O8FQE;0H@("`@
M("H*("`@("`J($!P87)A;2!I;G0@)&5R<FYO("!I9B!T:&4@97)R;W(@:7,@
M8F5I;F<@;6%N=6%L;'D@<F%I<V5D('!A<W,@80H@("`@("H@("`@("`@("`@
M("`@("`@("`@("!$0E]%4E)/4BH@8V]N<W1A;G0@:&5R92X@($EF('1H:7,@
M:7-N)W0@<&%S<V5D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@('1H92!E
M<G)O<B!I;F9O<FUA=&EO;B!G871H97)E9"!F<F]M('1H92!$0DU3+@H@("`@
M("H*("`@("`J($!R971U<FX@;V)J96-T("!T:&4@1$)?17)R;W(@;V)J96-T
M"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G)A:7-E17)R;W(H*2P*
M("`@("`J("`@("`@1$)?;7ES<6QI.CIE<G)O<DYA=&EV92@I+"!$0E]C;VUM
M;VXZ.F5R<F]R0V]D92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&UY<W%L:5)A
M:7-E17)R;W(H)&5R<FYO(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H)&5R
M<FYO(#T]/2!N=6QL*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N
M<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197T524D]24RD@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/F5R<F]R8V]D95]M87!;,3`R,ET@/2!$
M0E]%4E)/4E]#3TY35%)!24Y4.PH@("`@("`@("`@("`@("`@)'1H:7,M/F5R
M<F]R8V]D95]M87!;,3`T.%T@/2!$0E]%4E)/4E]#3TY35%)!24Y47TY/5%].
M54Q,.PH@("`@("`@("`@("`@("`@)'1H:7,M/F5R<F]R8V]D95]M87!;,3`V
M,ET@/2!$0E]%4E)/4E]#3TY35%)!24Y4.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@+R\@1&]I;F<@=&AI<R!I;B!C87-E(&UO9&4@
M8VAA;F=E<R!D=7)I;F<@<G5N=&EM92X*("`@("`@("`@("`@("`@("1T:&ES
M+3YE<G)O<F-O9&5?;6%P6S$P,C)=(#T@1$)?15)23U)?04Q214%$65]%6$E3
M5%,["B`@("`@("`@("`@("`@("`D=&AI<RT^97)R;W)C;V1E7VUA<%LQ,#0X
M72`]($1"7T524D]27T-/3E-44D%)3E0["B`@("`@("`@("`@("`@("`D=&AI
M<RT^97)R;W)C;V1E7VUA<%LQ,#8R72`]($1"7T524D]27T%,4D5!1%E?15A)
M4U13.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1E<G)N;R`]("1T:&ES
M+3YE<G)O<D-O9&4H;7ES<6QI7V5R<FYO*"1T:&ES+3YC;VYN96-T:6]N*2D[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D
M97)R;F\L(&YU;&PL(&YU;&PL(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@($!M>7-Q;&E?97)R;F\H)'1H:7,M/F-O;FYE8W1I;VXI
M("X@)R`J*B`G("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M0&UY<W%L:5]E<G)O<B@D=&AI<RT^8V]N;F5C=&EO;BDI.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&5R<F]R3F%T:79E*"D*"B`@("`O*BH*("`@
M("`J($=E=',@=&AE($1"35,G(&YA=&EV92!E<G)O<B!C;V1E('!R;V1U8V5D
M(&)Y('1H92!L87-T('%U97)Y"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@
M('1H92!$0DU3)R!E<G)O<B!C;V1E"B`@("`@*B\*("`@(&9U;F-T:6]N(&5R
M<F]R3F%T:79E*"D*("`@('L*("`@("`@("!R971U<FX@0&UY<W%L:5]E<G)N
M;R@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@=&%B;&5);F9O*"D*"B`@("`O*BH*("`@("`J(%)E='5R;G,@:6YF
M;W)M871I;VX@86)O=70@82!T86)L92!O<B!A(')E<W5L="!S970*("`@("`J
M"B`@("`@*B!`<&%R86T@;V)J96-T?'-T<FEN9R`@)')E<W5L="`@1$)?<F5S
M=6QT(&]B:F5C="!F<F]M(&$@<75E<GD@;W(@80H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!S=')I;F<@8V]N=&%I;FEN9R!T:&4@
M;F%M92!O9B!A('1A8FQE+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!7:&EL92!T:&ES(&%L<V\@86-C97!T<R!A('%U97)Y(')E
M<W5L=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R
M97-O=7)C92!I9&5N=&EF:65R+"!T:&ES(&)E:&%V:6]R(&ES"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&1E<')E8V%T960N"B`@
M("`@*B!`<&%R86T@:6YT("`@("`@("`@("`@)&UO9&4@("`@82!V86QI9"!T
M86)L94EN9F\@;6]D90H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(&%N
M(&%S<V]C:6%T:79E(&%R<F%Y('=I=&@@=&AE(&EN9F]R;6%T:6]N(')E<75E
M<W1E9"X*("`@("`J("`@("`@("`@("`@("`@("!!($1"7T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIS
M971/<'1I;VXH*0H@("`@("HO"B`@("!F=6YC=&EO;B!T86)L94EN9F\H)')E
M<W5L="P@)&UO9&4@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]S=')I
M;F<H)')E<W5L="DI('L*("`@("`@("`@("`@+RH*("`@("`@("`@("`@("H@
M4')O8F%B;'D@<F5C96EV960@82!T86)L92!N86UE+@H@("`@("`@("`@("`@
M*B!#<F5A=&4@82!R97-U;'0@<F5S;W5R8V4@:61E;G1I9FEE<BX*("`@("`@
M("`@("`@("HO"B`@("`@("`@("`@("1I9"`]($!M>7-Q;&E?<75E<GDH)'1H
M:7,M/F-O;FYE8W1I;VXL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(E-%3$5#5"`J($923TT@)')E<W5L="!,24U)5"`P(BD["B`@("`@("`@
M("`@("1G;W1?<W1R:6YG(#T@=')U93L*("`@("`@("!](&5L<V5I9B`H:7-S
M970H)')E<W5L="T^<F5S=6QT*2D@>PH@("`@("`@("`@("`O*@H@("`@("`@
M("`@("`@*B!0<F]B86)L>2!R96-E:79E9"!A(')E<W5L="!O8FIE8W0N"B`@
M("`@("`@("`@("`J($5X=')A8W0@=&AE(')E<W5L="!R97-O=7)C92!I9&5N
M=&EF:65R+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@)&ED(#T@)')E
M<W5L="T^<F5S=6QT.PH@("`@("`@("`@("`D9V]T7W-T<FEN9R`](&9A;'-E
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J"B`@("`@("`@("`@
M("`J(%!R;V)A8FQY(')E8V5I=F5D(&$@<F5S=6QT(')E<V]U<F-E(&ED96YT
M:69I97(N"B`@("`@("`@("`@("`J($-O<'D@:70N"B`@("`@("`@("`@("`J
M($1E<')E8V%T960N("!(97)E(&9O<B!C;VUP871I8FEL:71Y(&]N;'DN"B`@
M("`@("`@("`@("`J+PH@("`@("`@("`@("`D:60@/2`D<F5S=6QT.PH@("`@
M("`@("`@("`D9V]T7W-T<FEN9R`](&9A;'-E.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"%I<U]A*"1I9"P@)VUY<W%L:5]R97-U;'0G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/FUY<W%L:5)A:7-E17)R;W(H1$)?15)23U)?
M3D5%1%]-3U)%7T1!5$$I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES
M+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?3$]7
M15)#05-%*2!["B`@("`@("`@("`@("1C87-E7V9U;F,@/2`G<W1R=&]L;W=E
M<B<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&-A<V5?9G5N8R`]
M("=S=')V86PG.PH@("`@("`@('T*"B`@("`@("`@)&-O=6YT(#T@0&UY<W%L
M:5]N=6U?9FEE;&1S*"1I9"D["B`@("`@("`@)')E<R`@(#T@87)R87DH*3L*
M"B`@("`@("`@:68@*"1M;V1E*2!["B`@("`@("`@("`@("1R97-;)VYU;5]F
M:65L9',G72`]("1C;W5N=#L*("`@("`@("!]"@H@("`@("`@(&9O<B`H)&D@
M/2`P.R`D:2`\("1C;W5N=#L@)&DK*RD@>PH@("`@("`@("`@("`D=&UP(#T@
M0&UY<W%L:5]F971C:%]F:65L9"@D:60I.PH*("`@("`@("`@("`@)&9L86=S
M(#T@)R<["B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YM>7-Q;&E?9FQA
M9W,@87,@)&-O;G-T(#T^("1M96%N<RD@>PH@("`@("`@("`@("`@("`@:68@
M*"1T;7`M/F9L86=S("8@)&-O;G-T*2!["B`@("`@("`@("`@("`@("`@("`@
M)&9L86=S("X]("1M96%N<R`N("<@)SL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)'1M<"T^9&5F*2!["B`@("`@
M("`@("`@("`@("`D9FQA9W,@+CT@)V1E9F%U;'1?)R`N(')A=W5R;&5N8V]D
M92@D=&UP+3YD968I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1F;&%G
M<R`]('1R:6TH)&9L86=S*3L*"B`@("`@("`@("`@("1R97-;)&E=(#T@87)R
M87DH"B`@("`@("`@("`@("`@("`G=&%B;&4G(#T^("1C87-E7V9U;F,H)'1M
M<"T^=&%B;&4I+`H@("`@("`@("`@("`@("`@)VYA;64G("`]/B`D8V%S95]F
M=6YC*"1T;7`M/FYA;64I+`H@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B!I
M<W-E="@D=&AI<RT^;7ES<6QI7W1Y<&5S6R1T;7`M/G1Y<&5=*0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`_("1T:&ES+3YM>7-Q;&E?
M='EP97-;)'1M<"T^='EP95T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@.B`G=6YK;F]W;B<L"B`@("`@("`@("`@("`@("`G;&5N)R`@
M(#T^("1T;7`M/FUA>%]L96YG=&@L"B`@("`@("`@("`@("`@("`G9FQA9W,G
M(#T^("1F;&%G<RP*("`@("`@("`@("`@*3L*"B`@("`@("`@("`@(&EF("@D
M;6]D92`F($1"7U1!0DQ%24Y&3U]/4D1%4BD@>PH@("`@("`@("`@("`@("`@
M)')E<ULG;W)D97(G75LD<F5S6R1I75LG;F%M92==72`]("1I.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("@D;6]D92`F($1"7U1!0DQ%24Y&3U]/
M4D1%4E1!0DQ%*2!["B`@("`@("`@("`@("`@("`D<F5S6R=O<F1E<G1A8FQE
M)UU;)')E<ULD:5U;)W1A8FQE)UU=6R1R97-;)&E=6R=N86UE)UU=(#T@)&D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O(&9R964@=&AE
M(')E<W5L="!O;FQY(&EF('=E('=E<F4@8V%L;&5D(&]N(&$@=&%B;&4*("`@
M("`@("!I9B`H)&=O=%]S=')I;F<I('L*("`@("`@("`@("`@0&UY<W%L:5]F
M<F5E7W)E<W5L="@D:60I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)')E
M<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G9713<&5C:6%L475E
M<GDH*0H*("`@("\J*@H@("`@("H@3V)T86EN<R!T:&4@<75E<GD@<W1R:6YG
M(&YE961E9"!F;W(@;&ES=&EN9R!A(&=I=F5N('1Y<&4@;V8@;V)J96-T<PH@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@('1H92!K:6YD(&]F
M(&]B:F5C=',@>6]U('=A;G0@=&\@<F5T<FEE=F4*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@=&AE(%-13"!Q=65R>2!S=')I;F<@;W(@;G5L;"!I
M9B!T:&4@9')I=F5R(&1O97-N)W0*("`@("`J("`@("`@("`@("`@("`@("`@
M<W5P<&]R="!T:&4@;V)J96-T('1Y<&4@<F5Q=65S=&5D"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J($!S964@1$)?8V]M;6]N.CIG
M971,:7-T3V8H*0H@("`@("HO"B`@("!F=6YC=&EO;B!G9713<&5C:6%L475E
M<GDH)'1Y<&4I"B`@("!["B`@("`@("`@<W=I=&-H("@D='EP92D@>PH@("`@
M("`@("`@("!C87-E("=T86)L97,G.@H@("`@("`@("`@("`@("`@<F5T=7)N
M("=32$]7(%1!0DQ%4R<["B`@("`@("`@("`@(&-A<V4@)W5S97)S)SH*("`@
M("`@("`@("`@("`@(')E='5R;B`G4T5,14-4($1)4U1)3D-4(%5S97(@1E)/
M32!M>7-Q;"YU<V5R)SL*("`@("`@("`@("`@8V%S92`G9&%T86)A<V5S)SH*
M("`@("`@("`@("`@("`@(')E='5R;B`G4TA/5R!$051!0D%315,G.PH@("`@
M("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@<F5T=7)N(&YU;&P[
M"B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H*?0H*+RH*("H@3&]C86P@
M=F%R:6%B;&5S.@H@*B!T86(M=VED=&@Z(#0*("H@8RUB87-I8RUO9F9S970Z
M(#0*("H@16YD.@H@*B\*"C\^"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T1"+V]C:3@N<&AP````````
M````````````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`Q,#8U-C8@
M,3`U,34T,S,W,S$@,#(P,S0R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"@HO*B!V:6TZ('-E="!E>'!A;F1T86(@
M=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PH*+RHJ
M"B`J(%1H92!014%2($1"(&1R:79E<B!F;W(@4$A0)W,@;V-I."!E>'1E;G-I
M;VX*("H@9F]R(&EN=&5R86-T:6YG('=I=&@@3W)A8VQE(&1A=&%B87-E<PH@
M*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES
M('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE
M(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE
M('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@H@*B!H='1P
M.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N
M;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A
M<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S
M90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N
M(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y
M("`@1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@
M2F%M97,@3"X@4&EN92`\:FQP0'9A;&EN=7@N8V]M/@H@*B!`875T:&]R("`@
M("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y
M<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E
M;G-E(#,N,`H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@;V-I."YP:'`L=B`Q
M+C$P,R`R,#`U+S`T+S$Q(#$U.C$P.C(R(&1A;FEE;&,@17AP("0*("H@0&QI
M;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J+PH*
M+RHJ"B`J($]B=&%I;B!T:&4@1$)?8V]M;6]N(&-L87-S('-O(&ET(&-A;B!B
M92!E>'1E;F1E9"!F<F]M"B`J+PIR97%U:7)E7V]N8V4@)T1"+V-O;6UO;BYP
M:'`G.PH*+RHJ"B`J(%1H92!M971H;V1S(%!%05(@1$(@=7-E<R!T;R!I;G1E
M<F%C="!W:71H(%!(4"=S(&]C:3@@97AT96YS:6]N"B`J(&9O<B!I;G1E<F%C
M=&EN9R!W:71H($]R86-L92!D871A8F%S97,*("H*("H@1&5F:6YI=&5L>2!W
M;W)K<R!W:71H('9E<G-I;VYS(#@@86YD(#D@;V8@3W)A8VQE+@H@*@H@*B!4
M:&5S92!M971H;V1S(&]V97)L;V%D('1H92!O;F5S(&1E8VQA<F5D(&EN($1"
M7V-O;6UO;BX*("H*("H@0F4@87=A<F4N+BX@($]#245R<F]R*"D@;VYL>2!A
M<'!E87)S('1O(')E='5R;B!A;GET:&EN9R!W:&5N(&=I=F5N(&$*("H@<W1A
M=&5M96YT+"!S;R!F=6YC=&EO;G,@<F5T=7)N('1H92!G96YE<FEC($1"7T52
M4D]2(&EN<W1E860@;V8@;6]R90H@*B!U<V5F=6P@97)R;W)S('1H870@:&%V
M92!T;R!D;R!W:71H(&9E961B86-K(&9R;VT@=&AE(&1A=&%B87-E+@H@*@H@
M*B!`8V%T96=O<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@("!$0@H@*B!`
M875T:&]R("`@("!*86UE<R!,+B!0:6YE(#QJ;'!`=F%L:6YU>"YC;VT^"B`J
M($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE
M=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@
M0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N
M-RXV"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G
M92]$0@H@*B\*8VQA<W,@1$)?;V-I."!E>'1E;F1S($1"7V-O;6UO;@I["B`@
M("`O+R![>WL@<')O<&5R=&EE<PH*("`@("\J*@H@("`@("H@5&AE($1"(&1R
M:79E<B!T>7!E("AM>7-Q;"P@;V-I."P@;V1B8RP@971C+BD*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D<&AP='EP92`]("=O8VDX)SL*
M"B`@("`O*BH*("`@("`J(%1H92!D871A8F%S92!S>6YT87@@=F%R:6%N="!T
M;R!B92!U<V5D("AD8C(L(&%C8V5S<RP@971C+BDL(&EF(&%N>0H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1D8G-Y;G1A>"`]("=O8VDX
M)SL*"B`@("`O*BH*("`@("`J(%1H92!C87!A8FEL:71I97,@;V8@=&AI<R!$
M0B!I;7!L96UE;G1A=&EO;@H@("`@("H*("`@("`J(%1H92`G;F5W7VQI;FLG
M(&5L96UE;G0@8V]N=&%I;G,@=&AE(%!(4"!V97)S:6]N('1H870@9FER<W0@
M<')O=FED960*("`@("`J(&YE=U]L:6YK('-U<'!O<G0@9F]R('1H:7,@1$)-
M4RX@($-O;G1A:6YS(&9A;'-E(&EF(&ET)W,@=6YS=7!P;W)T960N"B`@("`@
M*@H@("`@("H@365A;FEN9R!O9B!T:&4@)VQI;6ET)R!E;&5M96YT.@H@("`@
M("H@("`K("=E;75L871E)R`](&5M=6QA=&4@=VET:"!F971C:"!R;W<@8GD@
M;G5M8F5R"B`@("`@*B`@("L@)V%L=&5R)R`@(#T@86QT97(@=&AE('%U97)Y
M"B`@("`@*B`@("L@9F%L<V4@("`@(#T@<VMI<"!R;W=S"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&9E871U<F5S(#T@87)R
M87DH"B`@("`@("`@)VQI;6ET)R`@("`@("`@(#T^("=A;'1E<B<L"B`@("`@
M("`@)VYE=U]L:6YK)R`@("`@(#T^("<U+C`N,"<L"B`@("`@("`@)VYU;7)O
M=W,G("`@("`@(#T^("=S=6)Q=65R>2<L"B`@("`@("`@)W!C;VYN96-T)R`@
M("`@(#T^('1R=64L"B`@("`@("`@)W!R97!A<F4G("`@("`@(#T^('1R=64L
M"B`@("`@("`@)W-S;"<@("`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("=T
M<F%N<V%C=&EO;G,G("`]/B!T<G5E+`H@("`@*3L*"B`@("`O*BH*("`@("`J
M($$@;6%P<&EN9R!O9B!N871I=F4@97)R;W(@8V]D97,@=&\@1$(@97)R;W(@
M8V]D97,*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1E<G)O
M<F-O9&5?;6%P(#T@87)R87DH"B`@("`@("`@,2`@("`]/B!$0E]%4E)/4E]#
M3TY35%)!24Y4+`H@("`@("`@(#DP,"`@/3X@1$)?15)23U)?4UE.5$%8+`H@
M("`@("`@(#DP-"`@/3X@1$)?15)23U)?3D]354-(1DE%3$0L"B`@("`@("`@
M.3$S("`]/B!$0E]%4E)/4E]604Q515]#3U5.5%]/3E]23U<L"B`@("`@("`@
M.3(Q("`]/B!$0E]%4E)/4E]364Y405@L"B`@("`@("`@.3(S("`]/B!$0E]%
M4E)/4E]364Y405@L"B`@("`@("`@.30R("`]/B!$0E]%4E)/4E].3U-50TA4
M04),12P*("`@("`@("`Y-34@(#T^($1"7T524D]27T%,4D5!1%E?15A)4U13
M+`H@("`@("`@(#$T,#`@/3X@1$)?15)23U)?0T].4U1204E.5%].3U1?3E5,
M3"P*("`@("`@("`Q-#`Q(#T^($1"7T524D]27TE.5D%,240L"B`@("`@("`@
M,30P-R`]/B!$0E]%4E)/4E]#3TY35%)!24Y47TY/5%].54Q,+`H@("`@("`@
M(#$T,3@@/3X@1$)?15)23U)?3D]47T9/54Y$+`H@("`@("`@(#$T-S8@/3X@
M1$)?15)23U)?1$E66D523RP*("`@("`@("`Q-S(R(#T^($1"7T524D]27TE.
M5D%,241?3E5-0D52+`H@("`@("`@(#(R.#D@/3X@1$)?15)23U)?3D]354-(
M5$%"3$4L"B`@("`@("`@,C(Y,2`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@
M("`@("`@(#(R.3(@/3X@1$)?15)23U)?0T].4U1204E.5"P*("`@("`@("`R
M-#0Y(#T^($1"7T524D]27T-/3E-44D%)3E0L"B`@("`I.PH*("`@("\J*@H@
M("`@("H@5&AE(')A=R!D871A8F%S92!C;VYN96-T:6]N(&-R96%T960@8GD@
M4$A0"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D8V]N
M;F5C=&EO;CL*"B`@("`O*BH*("`@("`J(%1H92!$4TX@:6YF;W)M871I;VX@
M9F]R(&-O;FYE8W1I;F<@=&\@82!D871A8F%S90H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)&1S;B`](&%R<F%Y*"D["@H*("`@("\J*@H@
M("`@("H@4VAO=6QD(&1A=&$@;6%N:7!U;&%T:6]N('%U97)I97,@8F4@8V]M
M;6ET=&5D(&%U=&]M871I8V%L;'D_"B`@("`@*B!`=F%R(&)O;VP*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)&%U=&]C;VUM:70@
M/2!T<G5E.PH*("`@("\J*@H@("`@("H@4W1O<F5S('1H92`D9&%T82!P87-S
M960@=&\@97AE8W5T92@I(&EN('1H92!O8VDX(&1R:79E<@H@("`@("H*("`@
M("`J($=E=',@<F5S970@=&\@87)R87DH*2!W:&5N('-I;7!L95%U97)Y*"D@
M:7,@<G5N+@H@("`@("H*("`@("`J($YE961E9"!I;B!C87-E('5S97(@=V%N
M=',@=&\@8V%L;"!N=6U2;W=S*"D@869T97(@<')E<&%R92]E>&5C=71E"B`@
M("`@*B!W87,@=7-E9"X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?9&%T82`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@<F5S=6QT(&]R('-T871E;65N
M="!H86YD;&4@9G)O;2!T:&4@;6]S="!R96-E;G1L>2!E>&5C=71E9"!Q=65R
M>0H@("`@("H@0'9A<B!R97-O=7)C90H@("`@("HO"B`@("!V87(@)&QA<W1?
M<W1M=#L*"B`@("`O*BH*("`@("`J($ES('1H92!G:79E;B!P<F5P87)E9"!S
M=&%T96UE;G0@82!D871A(&UA;FEP=6QA=&EO;B!Q=65R>3\*("`@("`J($!V
M87(@87)R87D*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V
M87(@)&UA;FEP7W%U97)Y(#T@87)R87DH*3L*"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@8V]N<W1R=6-T;W(*"B`@("`O*BH*("`@("`J(%1H:7,@8V]N<W1R
M=6-T;W(@8V%L;',@/&MB9#XD=&AI<RT^1$)?8V]M;6]N*"D\+VMB9#X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@
M1$)?;V-I."@I"B`@("!["B`@("`@("`@)'1H:7,M/D1"7V-O;6UO;B@I.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&-O;FYE8W0H*0H*("`@("\J
M*@H@("`@("H@0V]N;F5C="!T;R!T:&4@9&%T86)A<V4@<V5R=F5R+"!L;V<@
M:6X@86YD(&]P96X@=&AE(&1A=&%B87-E"B`@("`@*@H@("`@("H@1&]N)W0@
M8V%L;"!T:&ES(&UE=&AO9"!D:7)E8W1L>2X@(%5S92!$0CHZ8V]N;F5C="@I
M(&EN<W1E860N"B`@("`@*@H@("`@("H@268@4$A0(&ES(&%T('9E<G-I;VX@
M-2XP+C`@;W(@9W)E871E<CH*("`@("`J("`@*R!'96YE<F%L;'DL(&]C:5]C
M;VYN96-T*"D@;W(@;V-I7W!C;VYN96-T*"D@87)E('5S960N"B`@("`@*B`@
M("L@0G5T(&EF('1H92!N97=?;&EN:R!$4TX@;W!T:6]N(&ES('-E="!T;R!T
M<G5E+"!O8VE?;F5W7V-O;FYE8W0H*0H@("`@("H@("`@(&ES('5S960N"B`@
M("`@*@H@("`@("H@5VAE;B!U<VEN9R!02%`@=F5R<VEO;B`T+G@L($]#24QO
M9V]N*"D@;W(@3T-)4$QO9V]N*"D@87)E('5S960N"B`@("`@*@H@("`@("H@
M4$5!4B!$0B=S(&]C:3@@9')I=F5R('-U<'!O<G1S('1H92!F;VQL;W=I;F<@
M97AT<F$@1%-.(&]P=&EO;G,Z"B`@("`@*B`@("L@8VAA<G-E="`@("`@("!4
M:&4@8VAA<F%C=&5R('-E="!T;R!B92!U<V5D(&]N('1H92!C;VYN96-T:6]N
M+@H@("`@("H@("`@("`@("`@("`@("`@("`@($]N;'D@=7-E9"!I9B!02%`@
M:7,@870@=F5R<VEO;B`U+C`N,"!O<B!G<F5A=&5R"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@86YD('1H92!/<F%C;&4@<V5R=F5R(&ES(&%T(#DN,B!O
M<B!G<F5A=&5R+@H@("`@("H@("`@("`@("`@("`@("`@("`@($%V86EL86)L
M92!S:6YC92!014%2($1"(#$N-RXP+@H@("`@("H@("`K(&YE=U]L:6YK("`@
M("`@268@<V5T('1O('1R=64L(&-A=7-E<R!S=6)S97%U96YT(&-A;&QS('1O
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@8V]N;F5C="@I('1O(')E='5R
M;B!A(&YE=R!C;VYN96-T:6]N(&QI;FL*("`@("`J("`@("`@("`@("`@("`@
M("`@("!I;G-T96%D(&]F('1H92!E>&ES=&EN9R!O;F4N("!705).24Y'.B!T
M:&ES(&ES"B`@("`@*B`@("`@("`@("`@("`@("`@("`@;F]T('!O<G1A8FQE
M('1O(&]T:&5R($1"35,G<RX*("`@("`J("`@("`@("`@("`@("`@("`@("!!
M=F%I;&%B;&4@<VEN8V4@4$5!4B!$0B`Q+C<N,"X*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)&1S;B`@("`@("`@('1H92!D871A('-O=7)C92!N86UE
M"B`@("`@*B!`<&%R86T@8F]O;"`@)'!E<G-I<W1E;G0@('-H;W5L9"!T:&4@
M8V]N;F5C=&EO;B!B92!P97)S:7-T96YT/PH@("`@("H*("`@("`J($!R971U
M<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B!!($1"7T5R<F]R(&]B:F5C="!O
M;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VYN96-T*"1D<VXL
M("1P97)S:7-T96YT(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"%014%2
M.CIL;V%D17AT96YS:6]N*"=O8VDX)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27T585$5.4TE/3E].3U1?1D]5
M3D0I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/F1S;B`]("1D<VX["B`@
M("`@("`@:68@*"1D<VY;)V1B<WEN=&%X)UTI('L*("`@("`@("`@("`@)'1H
M:7,M/F1B<WEN=&%X(#T@)&1S;ELG9&)S>6YT87@G73L*("`@("`@("!]"@H@
M("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V]C:5]C;VYN96-T)RDI('L*
M("`@("`@("`@("`@:68@*&ES<V5T*"1D<VY;)VYE=U]L:6YK)UTI"B`@("`@
M("`@("`@("`@("`F)B`H)&1S;ELG;F5W7VQI;FLG72`]/2`G=')U92<@?'P@
M)&1S;ELG;F5W7VQI;FLG72`]/3T@=')U92DI"B`@("`@("`@("`@('L*("`@
M("`@("`@("`@("`@("1C;VYN96-T7V9U;F-T:6]N(#T@)V]C:5]N97=?8V]N
M;F5C="<["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M8V]N;F5C=%]F=6YC=&EO;B`]("1P97)S:7-T96YT(#\@)V]C:5]P8V]N;F5C
M="<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`G;V-I
M7V-O;FYE8W0G.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!"86-K
M=V%R9',@8V]M<&%T:6)I;&ET>2!W:71H($1"(#P@,2XW+C`*("`@("`@("`@
M("`@:68@*&5M<'1Y*"1D<VY;)V1A=&%B87-E)UTI("8F("%E;7!T>2@D9'-N
M6R=H;W-T<W!E8R==*2D@>PH@("`@("`@("`@("`@("`@)&1B(#T@)&1S;ELG
M:&]S='-P96,G73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1D8B`]("1D<VY;)V1A=&%B87-E)UT["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("1C:&%R(#T@96UP='DH)&1S;ELG8VAA<G-E="==*2`_(&YU
M;&P@.B`D9'-N6R=C:&%R<V5T)UT["B`@("`@("`@("`@("1T:&ES+3YC;VYN
M96-T:6]N(#T@0"1C;VYN96-T7V9U;F-T:6]N*"1D<VY;)W5S97)N86UE)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1D<VY;)W!A<W-W;W)D)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D8BP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-H
M87(I.PH@("`@("`@("`@("`D97)R;W(@/2!/0TE%<G)O<B@I.PH@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1E<G)O<BD@)B8@)&5R<F]R6R=C;V1E)UT@/3T@
M,3(U-#$I('L*("`@("`@("`@("`@("`@("\O($-O=6QD;B=T(&9I;F0@5$Y3
M(&QI<W1E;F5R+B`@5')Y(&1I<F5C="!C;VYN96-T:6]N+@H@("`@("`@("`@
M("`@("`@)'1H:7,M/F-O;FYE8W1I;VX@/2!`)&-O;FYE8W1?9G5N8W1I;VXH
M)&1S;ELG=7-E<FYA;64G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D<VY;)W!A<W-W;W)D)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-H87(I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&-O;FYE8W1?9G5N
M8W1I;VX@/2`D<&5R<VES=&5N="`_("=/0TE03&]G;VXG(#H@)T]#24QO9V]N
M)SL*("`@("`@("`@("`@:68@*"1D<VY;)VAO<W1S<&5C)UTI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3YC;VYN96-T:6]N(#T@0"1C;VYN96-T7V9U;F-T
M:6]N*"1D<VY;)W5S97)N86UE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9'-N6R=P87-S=V]R
M9"==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&1S;ELG:&]S='-P96,G72D["B`@("`@("`@("`@
M('T@96QS96EF("@D9'-N6R=U<V5R;F%M92==('Q\("1D<VY;)W!A<W-W;W)D
M)UTI('L*("`@("`@("`@("`@("`@("1T:&ES+3YC;VYN96-T:6]N(#T@0"1C
M;VYN96-T7V9U;F-T:6]N*"1D<VY;)W5S97)N86UE)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M9'-N6R=P87-S=V]R9"==*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@:68@*"$D=&AI<RT^8V]N;F5C=&EO;BD@>PH@("`@("`@("`@("`D
M97)R;W(@/2!/0TE%<G)O<B@I.PH@("`@("`@("`@("`D97)R;W(@/2`H:7-?
M87)R87DH)&5R<F]R*2D@/R`D97)R;W);)VUE<W-A9V4G72`Z(&YU;&P["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E]#
M3TY.14-47T9!24Q%1"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&YU;&PL(&YU;&PL(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D97)R;W(I.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9&ES
M8V]N;F5C="@I"@H@("`@+RHJ"B`@("`@*B!$:7-C;VYN96-T<R!F<F]M('1H
M92!D871A8F%S92!S97)V97(*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@
M(%12544@;VX@<W5C8V5S<RP@1D%,4T4@;VX@9F%I;'5R90H@("`@("HO"B`@
M("!F=6YC=&EO;B!D:7-C;VYN96-T*"D*("`@('L*("`@("`@("!I9B`H9G5N
M8W1I;VY?97AI<W1S*"=O8VE?8VQO<V4G*2D@>PH@("`@("`@("`@("`D<F5T
M(#T@0&]C:5]C;&]S92@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)')E="`]($!/0TE,;V=/9F8H)'1H:7,M/F-O
M;FYE8W1I;VXI.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^8V]N;F5C=&EO
M;B`](&YU;&P["B`@("`@("`@<F5T=7)N("1R970["B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@<VEM<&QE475E<GDH*0H*("`@("\J*@H@("`@("H@
M4V5N9',@82!Q=65R>2!T;R!T:&4@9&%T86)A<V4@<V5R=F5R"B`@("`@*@H@
M("`@("H@5&\@9&5T97)M:6YE(&AO=R!M86YY(')O=W,@;V8@82!R97-U;'0@
M<V5T(&=E="!B=69F97)E9"!U<VEN9PH@("`@("H@;V-I<V5T<')E9F5T8V@H
M*2P@<V5E('1H92`B<F5S=6QT7V)U9F9E<FEN9R(@;W!T:6]N(&EN('-E=$]P
M=&EO;G,H*2X*("`@("`J(%1H:7,@;W!T:6]N('=A<R!A9&1E9"!I;B!296QE
M87-E(#$N-RXP+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@('1H92!3
M44P@<75E<GD@<W1R:6YG"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@
M*R!A(%!(4"!R97-U;'0@<F5S<F]U8V4@9F]R('-U8V-E<W-F=6P@4T5,14-4
M('%U97)I97,*("`@("`J("`@("`@("`@("`@("`@("L@=&AE($1"7T]+(&-O
M;G-T86YT(&9O<B!O=&AE<B!S=6-C97-S9G5L('%U97)I97,*("`@("`J("`@
M("`@("`@("`@("`@("L@82!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R90H@
M("`@("HO"B`@("!F=6YC=&EO;B!S:6UP;&51=65R>2@D<75E<GDI"B`@("![
M"B`@("`@("`@)'1H:7,M/E]D871A(#T@87)R87DH*3L*("`@("`@("`D=&AI
M<RT^;&%S=%]P87)A;65T97)S(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^
M;&%S=%]Q=65R>2`]("1Q=65R>3L*("`@("`@("`D<75E<GD@/2`D=&AI<RT^
M;6]D:69Y475E<GDH)'%U97)Y*3L*("`@("`@("`D<F5S=6QT(#T@0$]#25!A
M<G-E*"1T:&ES+3YC;VYN96-T:6]N+"`D<75E<GDI.PH@("`@("`@(&EF("@A
M)')E<W5L="D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F]C:3A286ES
M945R<F]R*"D["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^875T;V-O
M;6UI="D@>PH@("`@("`@("`@("`D<W5C8V5S<R`]($!/0TE%>&5C=71E*"1R
M97-U;'0L3T-)7T-/34U)5%]/3E]354-#15-3*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D<W5C8V5S<R`]($!/0TE%>&5C=71E*"1R97-U;'0L
M3T-)7T1%1D%53%0I.PH@("`@("`@('T*("`@("`@("!I9B`H(21S=6-C97-S
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;V-I.%)A:7-E17)R;W(H
M)')E<W5L="D["B`@("`@("`@?0H@("`@("`@("1T:&ES+3YL87-T7W-T;70@
M/2`D<F5S=6QT.PH@("`@("`@(&EF("A$0CHZ:7--86YI<"@D<75E<GDI*2![
M"B`@("`@("`@("`@(')E='5R;B!$0E]/2SL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!`;V-I<V5T<')E9F5T8V@H)')E<W5L="P@)'1H:7,M/F]P
M=&EO;G-;)W)E<W5L=%]B=69F97)I;F<G72D["B`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!N97AT4F5S=6QT*"D*"B`@("`O*BH*("`@("`J($UO=F4@=&AE(&EN
M=&5R;F%L(&]R86-L92!R97-U;'0@<&]I;G1E<B!T;R!T:&4@;F5X="!A=F%I
M;&%B;&4@<F5S=6QT"B`@("`@*@H@("`@("H@0'!A<F%M(&$@=F%L:60@;V-I
M."!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("H*("`@("`J($!R971U<FX@=')U92!I9B!A(')E<W5L="!I<R!A
M=F%I;&%B;&4@;W1H97)W:7-E(')E='5R;B!F86QS90H@("`@("HO"B`@("!F
M=6YC=&EO;B!N97AT4F5S=6QT*"1R97-U;'0I"B`@("!["B`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&9E=&-H
M26YT;R@I"@H@("`@+RHJ"B`@("`@*B!0;&%C97,@82!R;W<@9G)O;2!T:&4@
M<F5S=6QT('-E="!I;G1O('1H92!G:79E;B!A<G)A>0H@("`@("H*("`@("`J
M($9O<FUA=&EN9R!O9B!T:&4@87)R87D@86YD('1H92!D871A('1H97)E:6X@
M87)E(&-O;F9I9W5R86)L92X*("`@("`J(%-E92!$0E]R97-U;'0Z.F9E=&-H
M26YT;R@I(&9O<B!M;W)E(&EN9F]R;6%T:6]N+@H@("`@("H*("`@("`J(%1H
M:7,@;65T:&]D(&ES(&YO="!M96%N="!T;R!B92!C86QL960@9&ER96-T;'DN
M("!5<V4*("`@("`J($1"7W)E<W5L=#HZ9F5T8VA);G1O*"D@:6YS=&5A9"X@
M($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A
M=7-E($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@
M("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@("!T:&4@<75E<GD@<F5S
M=6QT(')E<V]U<F-E"B`@("`@*B!`<&%R86T@87)R87D@("`@)&%R<B`@("`@
M("!T:&4@<F5F97)E;F-E9"!A<G)A>2!T;R!P=70@=&AE(&1A=&$@:6X*("`@
M("`J($!P87)A;2!I;G0@("`@("`D9F5T8VAM;V1E(&AO=R!T:&4@<F5S=6QT
M:6YG(&%R<F%Y('-H;W5L9"!B92!I;F1E>&5D"B`@("`@*B!`<&%R86T@:6YT
M("`@("`@)')O=VYU;2`@("!T:&4@<F]W(&YU;6)E<B!T;R!F971C:"`H,"`]
M(&9I<G-T(')O=RD*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!$0E]/
M2R!O;B!S=6-C97-S+"!.54Q,('=H96X@=&AE(&5N9"!O9B!A(')E<W5L="!S
M970@:7,*("`@("`J("`@("`@("`@("`@("`@("!R96%C:&5D(&]R(&]N(&9A
M:6QU<F4*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ9F5T8VA);G1O
M*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9F5T8VA);G1O*"1R97-U;'0L("8D
M87)R+"`D9F5T8VAM;V1E+"`D<F]W;G5M(#T@;G5L;"D*("`@('L*("`@("`@
M("!I9B`H)')O=VYU;2`A/3T@;G5L;"D@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?3D]47T-!4$%"3$4I.PH@("`@
M("`@('T*("`@("`@("!I9B`H)&9E=&-H;6]D92`F($1"7T9%5$-(34]$15]!
M4U-/0RD@>PH@("`@("`@("`@("`D;6]R961A=&$@/2!`3T-)1F5T8VA);G1O
M*"1R97-U;'0L)&%R<BQ/0TE?05-33T,K3T-)7U)%5%523E].54Q,4RM/0TE?
M4D5455).7TQ/0E,I.PH@("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;
M)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465],3U=%4D-!4T4@)B8*
M("`@("`@("`@("`@("`@("1M;W)E9&%T82D*("`@("`@("`@("`@>PH@("`@
M("`@("`@("`@("`@)&%R<B`](&%R<F%Y7V-H86YG95]K97E?8V%S92@D87)R
M+"!#05-%7TQ/5T52*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1M;W)E9&%T82`]($]#249E=&-H26YT;R@D<F5S=6QT
M+"1A<G(L3T-)7U)%5%523E].54Q,4RM/0TE?4D5455).7TQ/0E,I.PH@("`@
M("`@('T*("`@("`@("!I9B`H(21M;W)E9&%T82D@>PH@("`@("`@("`@("!R
M971U<FX@;G5L;#L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YO<'1I
M;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?4E1224TI('L*
M("`@("`@("`@("`@)'1H:7,M/E]R=')I;4%R<F%Y5F%L=65S*"1A<G(I.PH@
M("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL
M:71Y)UT@)B!$0E]03U)404))3$E465].54Q,7U1/7T5-4%19*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?8V]N=F5R=$YU;&Q!<G)A>59A;'5E<U1O16UP='DH
M)&%R<BD["B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!F<F5E4F5S=6QT*"D*"B`@("`O*BH*
M("`@("`J($1E;&5T97,@=&AE(')E<W5L="!S970@86YD(&9R965S('1H92!M
M96UO<GD@;V-C=7!I960@8GD@=&AE(')E<W5L="!S970*("`@("`J"B`@("`@
M*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I<F5C
M=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z.F9R964H*2!I;G-T96%D+B`@
M270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*("`@("`J(&)E8V%U
M<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@("`@("H*("`@
M("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT("!02%`G<R!Q=65R>2!R97-U
M;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@(%12544@
M;VX@<W5C8V5S<RP@1D%,4T4@:68@)')E<W5L="!I<R!I;G9A;&ED"B`@("`@
M*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.F9R964H*0H@("`@("HO"B`@("!F
M=6YC=&EO;B!F<F5E4F5S=6QT*"1R97-U;'0I"B`@("!["B`@("`@("`@<F5T
M=7)N($!/0TE&<F5E4W1A=&5M96YT*"1R97-U;'0I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1G)E97,@=&AE(&EN=&5R;F%L(')E<V]U<F-E<R!A<W-O8VEA
M=&5D('=I=&@@82!P<F5P87)E9"!Q=65R>0H@("`@("H*("`@("`J($!P87)A
M;2!R97-O=7)C92`D<W1M="`@("`@("`@("`@=&AE('!R97!A<F5D('-T871E
M;65N="=S(')E<V]U<F-E"B`@("`@*B!`<&%R86T@8F]O;"`@("`@)&9R965?
M<F5S;W5R8V4@('-H;W5L9"!T:&4@4$A0(')E<V]U<F-E(&)E(&9R965D('1O
M;S\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%5S
M92!F86QS92!I9B!Y;W4@;F5E9"!T;R!G970@9&%T80H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@9G)O;2!T:&4@<F5S=6QT('-E
M="!L871E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@(%12544@;VX@
M<W5C8V5S<RP@1D%,4T4@:68@)')E<W5L="!I<R!I;G9A;&ED"B`@("`@*@H@
M("`@("H@0'-E92!$0E]O8VDX.CIP<F5P87)E*"D*("`@("`J+PH@("`@9G5N
M8W1I;VX@9G)E95!R97!A<F5D*"1S=&UT+"`D9G)E95]R97-O=7)C92`]('1R
M=64I"B`@("!["B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D<W1M="DI('L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("!I
M9B`H)&9R965?<F5S;W5R8V4I('L*("`@("`@("`@("`@0&]C:69R965S=&%T
M96UE;G0H)'-T;70I.PH@("`@("`@('T*("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/G!R97!A<F5?='EP97-;*&EN="DD<W1M=%TI*2!["B`@("`@("`@("`@
M('5N<V5T*"1T:&ES+3YP<F5P87)E7W1Y<&5S6RAI;G0I)'-T;71=*3L*("`@
M("`@("`@("`@=6YS970H)'1H:7,M/FUA;FEP7W%U97)Y6RAI;G0I)'-T;71=
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&YU;5)O=W,H*0H*("`@("\J*@H@("`@("H@1V5T
M<R!T:&4@;G5M8F5R(&]F(')O=W,@:6X@82!R97-U;'0@<V5T"B`@("`@*@H@
M("`@("H@3VYL>2!W;W)K<R!I9B!T:&4@1$)?4$]25$%"24Q)5%E?3E5-4D]7
M4R!P;W)T86)I;&ET>2!O<'1I;VX*("`@("`J(&ES('1U<FYE9"!O;BX*("`@
M("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L
M;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z.FYU;5)O=W,H
M*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*
M("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T
M+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT("!02%`G
M<R!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&EN="`@=&AE(&YU;6)E<B!O9B!R;W=S+B`@02!$0E]%<G)O<B!O8FIE8W0@
M;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ;G5M
M4F]W<R@I+"!$0E]C;VUM;VXZ.G-E=$]P=&EO;B@I"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&YU;5)O=W,H)')E<W5L="D*("`@('L*("`@("`@("`O+R!E;75L
M871E(&YU;5)O=W,@9F]R($]R86-L92X@('EU8VLN"B`@("`@("`@:68@*"1T
M:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?
M3E5-4D]74R`F)@H@("`@("`@("`@("`D<F5S=6QT(#T]/2`D=&AI<RT^;&%S
M=%]S=&UT*0H@("`@("`@('L*("`@("`@("`@("`@)&-O=6YT<75E<GD@/2`G
M4T5,14-4($-/54Y4*"HI($923TT@*"<N)'1H:7,M/FQA<W1?<75E<GDN)RDG
M.PH@("`@("`@("`@("`D<V%V95]Q=65R>2`]("1T:&ES+3YL87-T7W%U97)Y
M.PH@("`@("`@("`@("`D<V%V95]S=&UT(#T@)'1H:7,M/FQA<W1?<W1M=#L*
M"B`@("`@("`@("`@(&EF("AC;W5N="@D=&AI<RT^7V1A=&$I*2!["B`@("`@
M("`@("`@("`@("`D<VUT(#T@)'1H:7,M/G!R97!A<F4H)U-%3$5#5"!#3U5.
M5"@J*2!&4D]-("@G+B1T:&ES+3YL87-T7W%U97)Y+B<I)RD["B`@("`@("`@
M("`@("`@("`D8V]U;G0@/2`D=&AI<RT^97AE8W5T92@D<VUT+"`D=&AI<RT^
M7V1A=&$I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)&-O=6YT(#TF("1T:&ES+3YQ=65R>2@D8V]U;G1Q=65R>2D["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D8V]U;G0I('Q\
M"B`@("`@("`@("`@("`@("!$0CHZ:7-%<G)O<B@D<F]W(#T@)&-O=6YT+3YF
M971C:%)O=RA$0E]&151#2$U/1$5?3U)$15)%1"DI*0H@("`@("`@("`@("![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^;&%S=%]Q=65R>2`]("1S879E7W%U
M97)Y.PH@("`@("`@("`@("`@("`@)'1H:7,M/FQA<W1?<W1M="`]("1S879E
M7W-T;70["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H1$)?15)23U)?3D]47T-!4$%"3$4I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(')E='5R;B`D<F]W6S!=.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?3D]47T-!4$%"3$4I.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YU;4-O;',H*0H*("`@("\J
M*@H@("`@("H@1V5T<R!T:&4@;G5M8F5R(&]F(&-O;'5M;G,@:6X@82!R97-U
M;'0@<V5T"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@:7,@;F]T(&UE86YT
M('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@("H@1$)?<F5S=6QT
M.CIN=6U#;VQS*"D@:6YS=&5A9"X@($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P
M<F]T96-T960B"B`@("`@*B!B96-A=7-E($1"7W)E<W5L="!I<R!A('-E<&%R
M871E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E
M<W5L="`@4$A0)W,@<75E<GD@<F5S=6QT(')E<V]U<F-E"B`@("`@*@H@("`@
M("H@0')E='5R;B!I;G0@('1H92!N=6UB97(@;V8@8V]L=6UN<RX@($$@1$)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$
M0E]R97-U;'0Z.FYU;4-O;',H*0H@("`@("HO"B`@("!F=6YC=&EO;B!N=6U#
M;VQS*"1R97-U;'0I"B`@("!["B`@("`@("`@)&-O;',@/2!`3T-)3G5M0V]L
M<R@D<F5S=6QT*3L*("`@("`@("!I9B`H(21C;VQS*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^;V-I.%)A:7-E17)R;W(H)')E<W5L="D["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D8V]L<SL*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!P<F5P87)E*"D*"B`@("`O*BH*("`@("`J(%!R97!A<F5S
M(&$@<75E<GD@9F]R(&UU;'1I<&QE(&5X96-U=&EO;B!W:71H(&5X96-U=&4H
M*2X*("`@("`J"B`@("`@*B!7:71H(&]C:3@L('1H:7,@:7,@96UU;&%T960N
M"B`@("`@*@H@("`@("H@<')E<&%R92@I(')E<75I<F5S(&$@9V5N97)I8R!Q
M=65R>2!A<R!S=')I;F<@;&EK92`\8V]D93X*("`@("`J("`@($E.4T525"!)
M3E1/(&YU;6)E<G,@5D%,5453("@_+"`_+"`_*0H@("`@("H@/"]C;V1E/BX@
M(%1H92`\:V)D/C\\+VMB9#X@8VAA<F%C=&5R<R!A<F4@<&QA8V5H;VQD97)S
M+@H@("`@("H*("`@("`J(%1H<F5E('1Y<&5S(&]F('!L86-E:&]L9&5R<R!C
M86X@8F4@=7-E9#H*("`@("`J("`@*R`\:V)D/C\\+VMB9#X@(&$@<75O=&5D
M('-C86QA<B!V86QU92P@:2YE+B!S=')I;F=S+"!I;G1E9V5R<PH@("`@("H@
M("`K(#QK8F0^(3PO:V)D/B`@=F%L=64@:7,@:6YS97)T960@)V%S(&ES)PH@
M("`@("H@("`K(#QK8F0^)CPO:V)D/B`@<F5Q=6ER97,@82!F:6QE(&YA;64N
M("!4:&4@9FEL92=S(&-O;G1E;G1S(&=E=`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("!I;G-E<G1E9"!I;G1O('1H92!Q=65R>2`H:2YE+B!S879I;F<@
M8FEN87)Y"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(&1A=&$@:6X@82!D
M8BD*("`@("`J"B`@("`@*B!5<V4@8F%C:W-L87-H97,@=&\@97-C87!E('!L
M86-E:&]L9&5R(&-H87)A8W1E<G,@:68@>6]U(&1O;B=T('=A;G0*("`@("`J
M('1H96T@=&\@8F4@:6YT97)P<F5T960@87,@<&QA8V5H;VQD97)S+B`@17AA
M;7!L93H@/&-O9&4^"B`@("`@*B`@("`B55!$051%(&9O;R!3150@8V]L/3\@
M5TA%4D4@8V]L/2=O=F5R(%PF('5N9&5R)R(*("`@("`J(#PO8V]D93X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1Q=65R>2`@=&AE('%U97)Y('1O
M(&)E('!R97!A<F5D"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@1$(@
M<W1A=&5M96YT(')E<V]U<F-E(&]N('-U8V-E<W,N($1"7T5R<F]R(&]N(&9A
M:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]O8VDX.CIE>&5C=71E*"D*
M("`@("`J+PH@("`@9G5N8W1I;VX@<')E<&%R92@D<75E<GDI"B`@("!["B`@
M("`@("`@)'1O:V5N<R`@(#T@<')E9U]S<&QI="@G+R@H/SPA7%Q<*5LF/R%=
M*2\G+"`D<75E<GDL("TQ+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@4%)%1U]34$Q)5%]$14Q)35]#05!455)%*3L*("`@("`@("`D8FEN9',@
M("`@/2!C;W5N="@D=&]K96YS*2`M(#$["B`@("`@("`@)'1O:V5N("`@(#T@
M,#L*("`@("`@("`D='EP97,@("`@/2!A<G)A>2@I.PH@("`@("`@("1N97=Q
M=65R>2`]("<G.PH*("`@("`@("!F;W)E86-H("@D=&]K96YS(&%S("1K97D@
M/3X@)'9A;"D@>PH@("`@("`@("`@("!S=VET8V@@*"1V86PI('L*("`@("`@
M("`@("`@("`@(&-A<V4@)S\G.@H@("`@("`@("`@("`@("`@("`@("1T>7!E
M<ULD=&]K96XK*UT@/2!$0E]005)!35]30T%,05(["B`@("`@("`@("`@("`@
M("`@("`@=6YS970H)'1O:V5N<ULD:V5Y72D["B`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E("<F)SH*("`@("`@("`@
M("`@("`@("`@("`D='EP97-;)'1O:V5N*RM=(#T@1$)?4$%204U?3U!!455%
M.PH@("`@("`@("`@("`@("`@("`@('5N<V5T*"1T;VME;G-;)&ME>5TI.PH@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S
M92`G(2<Z"B`@("`@("`@("`@("`@("`@("`@)'1Y<&5S6R1T;VME;BLK72`]
M($1"7U!!4D%-7TU)4T,["B`@("`@("`@("`@("`@("`@("`@=6YS970H)'1O
M:V5N<ULD:V5Y72D["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@("`@("1T;VME
M;G-;)&ME>5T@/2!P<F5G7W)E<&QA8V4H)R]<7%PH6R8_(5TI+R<L(")<7#$B
M+"`D=F%L*3L*("`@("`@("`@("`@("`@("`@("!I9B`H)&ME>2`A/2`D8FEN
M9',I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&YE=W%U97)Y("X]("1T
M;VME;G-;)&ME>5T@+B`G.F)I;F0G("X@)'1O:V5N.PH@("`@("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1N97=Q
M=65R>2`N/2`D=&]K96YS6R1K97E=.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)'1H:7,M/FQA<W1?
M<75E<GD@/2`D<75E<GD["B`@("`@("`@)&YE=W%U97)Y(#T@)'1H:7,M/FUO
M9&EF>5%U97)Y*"1N97=Q=65R>2D["B`@("`@("`@:68@*"$D<W1M="`]($!/
M0TE087)S92@D=&AI<RT^8V]N;F5C=&EO;BP@)&YE=W%U97)Y*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/F]C:3A286ES945R<F]R*"D["B`@("`@
M("`@?0H@("`@("`@("1T:&ES+3YP<F5P87)E7W1Y<&5S6RAI;G0I)'-T;71=
M(#T@)'1Y<&5S.PH@("`@("`@("1T:&ES+3YM86YI<%]Q=65R>5LH:6YT*21S
M=&UT72`]($1".CII<TUA;FEP*"1Q=65R>2D["B`@("`@("`@<F5T=7)N("1S
M=&UT.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&5X96-U=&4H*0H*
M("`@("\J*@H@("`@("H@17AE8W5T97,@82!$0B!S=&%T96UE;G0@<')E<&%R
M960@=VET:"!P<F5P87)E*"DN"B`@("`@*@H@("`@("H@5&\@9&5T97)M:6YE
M(&AO=R!M86YY(')O=W,@;V8@82!R97-U;'0@<V5T(&=E="!B=69F97)E9"!U
M<VEN9PH@("`@("H@;V-I<V5T<')E9F5T8V@H*2P@<V5E('1H92`B<F5S=6QT
M7V)U9F9E<FEN9R(@;W!T:6]N(&EN('-E=$]P=&EO;G,H*2X*("`@("`J(%1H
M:7,@;W!T:6]N('=A<R!A9&1E9"!I;B!296QE87-E(#$N-RXP+@H@("`@("H*
M("`@("`J($!P87)A;2!R97-O=7)C92`@)'-T;70@(&$@1$(@<W1A=&5M96YT
M(')E<V]U<F-E(')E='5R;F5D(&9R;VT@<')E<&%R92@I"B`@("`@*B!`<&%R
M86T@;6EX960@("1D871A("!A<G)A>2P@<W1R:6YG(&]R(&YU;65R:6,@9&%T
M82!T;R!B92!U<V5D(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!E
M>&5C=71I;VX@;V8@=&AE('-T871E;65N="X@(%%U86YT:71Y(&]F(&ET96US
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!P87-S960@;75S="!M871C
M:"!Q=6%N=&ET>2!O9B!P;&%C96AO;&1E<G,@:6X*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@('%U97)Y.B`@;65A;FEN9R`Q(&9O<B!N;VXM87)R87D@
M:71E;7,@;W(@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!Q=6%N
M=&ET>2!O9B!E;&5M96YT<R!I;B!T:&4@87)R87DN"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@<F5T=7)N<R!A;B!O:6,X(')E<W5L="!R97-O=7)C
M92!F;W(@<W5C8V5S<V9U;"!314Q%0U0*("`@("`J("`@("`@("`@("`@("`@
M('%U97)I97,L($1"7T]+(&9O<B!O=&AE<B!S=6-C97-S9G5L('%U97)I97,N
M"B`@("`@*B`@("`@("`@("`@("`@("!!($1"(&5R<F]R(&]B:F5C="!I<R!R
M971U<FYE9"!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?;V-I
M.#HZ<')E<&%R92@I"B`@("`@*B\*("`@(&9U;F-T:6]N("9E>&5C=71E*"1S
M=&UT+"`D9&%T82`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)&1A=&$@/2`H
M87)R87DI)&1A=&$["B`@("`@("`@)'1H:7,M/FQA<W1?<&%R86UE=&5R<R`]
M("1D871A.PH@("`@("`@("1T:&ES+3Y?9&%T82`]("1D871A.PH*("`@("`@
M("`D='EP97,@/28@)'1H:7,M/G!R97!A<F5?='EP97-;*&EN="DD<W1M=%T[
M"B`@("`@("`@:68@*&-O=6YT*"1T>7!E<RD@(3T@8V]U;G0H)&1A=&$I*2![
M"B`@("`@("`@("`@("1T;7`@/28@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)2
M3U)?34E334%40T@I.PH@("`@("`@("`@("!R971U<FX@)'1M<#L*("`@("`@
M("!]"@H@("`@("`@("1I(#T@,#L*("`@("`@("!F;W)E86-H("@D9&%T82!A
M<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("!I9B`H)'1Y<&5S6R1I
M72`]/2!$0E]005)!35]-25-#*2!["B`@("`@("`@("`@("`@("`O*@H@("`@
M("`@("`@("`@("`@("H@3W)A8VQE(&1O97-N)W0@<V5E;2!T;R!H879E('1H
M92!A8FEL:71Y('1O('!A<W,@80H@("`@("`@("`@("`@("`@("H@<&%R86UE
M=&5R(&%L;VYG('5N8VAA;F=E9"P@<V\@<W1R:7`@;V9F('%U;W1E<R!F<F]M
M('-T87)T"B`@("`@("`@("`@("`@("`@*B!A;F0@96YD+"!P;'5S('1U<FX@
M='=O('-I;F=L92!Q=6]T97,@=&\@;VYE('-I;F=L92!Q=6]T92P*("`@("`@
M("`@("`@("`@("`J(&EN(&]R9&5R('1O(&%V;VED('1H92!Q=6]T97,@9V5T
M=&EN9R!E<V-A<&5D(&)Y"B`@("`@("`@("`@("`@("`@*B!/<F%C;&4@86YD
M(&5N9&EN9R!U<"!I;B!T:&4@9&%T86)A<V4N"B`@("`@("`@("`@("`@("`@
M*B\*("`@("`@("`@("`@("`@("1D871A6R1K97E=(#T@<')E9U]R97!L86-E
M*"(O7B<H+BHI)R0O(BP@(EQ<,2(L("1D871A6R1K97E=*3L*("`@("`@("`@
M("`@("`@("1D871A6R1K97E=(#T@<W1R7W)E<&QA8V4H(B<G(BP@(B<B+"`D
M9&%T85LD:V5Y72D["B`@("`@("`@("`@('T@96QS96EF("@D='EP97-;)&E=
M(#T]($1"7U!!4D%-7T]005%512D@>PH@("`@("`@("`@("`@("`@)&9P(#T@
M0&9O<&5N*"1D871A6R1K97E=+"`G<F(G*3L*("`@("`@("`@("`@("`@(&EF
M("@A)&9P*2!["B`@("`@("`@("`@("`@("`@("`@)'1M<"`])B`D=&AI<RT^
M<F%I<V5%<G)O<BA$0E]%4E)/4E]!0T-%4U-?5DE/3$%424].*3L*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)'1M<#L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("1D871A6R1K97E=(#T@9G)E860H)&9P+"!F:6QE
M<VEZ92@D9&%T85LD:V5Y72DI.PH@("`@("`@("`@("`@("`@9F-L;W-E*"1F
M<"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%`3T-)0FEN9$)Y
M3F%M92@D<W1M="P@)SIB:6YD)R`N("1I+"`D9&%T85LD:V5Y72P@+3$I*2![
M"B`@("`@("`@("`@("`@("`D=&UP(#T@)'1H:7,M/F]C:3A286ES945R<F]R
M*"1S=&UT*3L*("`@("`@("`@("`@("`@(')E='5R;B`D=&UP.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1I*RL["B`@("`@("`@?0H@("`@("`@(&EF
M("@D=&AI<RT^875T;V-O;6UI="D@>PH@("`@("`@("`@("`D<W5C8V5S<R`]
M($!/0TE%>&5C=71E*"1S=&UT+"!/0TE?0T]-34E47T].7U-50T-%4U,I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1S=6-C97-S(#T@0$]#245X
M96-U=&4H)'-T;70L($]#25]$149!54Q4*3L*("`@("`@("!]"B`@("`@("`@
M:68@*"$D<W5C8V5S<RD@>PH@("`@("`@("`@("`D=&UP(#T@)'1H:7,M/F]C
M:3A286ES945R<F]R*"1S=&UT*3L*("`@("`@("`@("`@<F5T=7)N("1T;7`[
M"B`@("`@("`@?0H@("`@("`@("1T:&ES+3YL87-T7W-T;70@/2`D<W1M=#L*
M("`@("`@("!I9B`H)'1H:7,M/FUA;FEP7W%U97)Y6RAI;G0I)'-T;71=*2![
M"B`@("`@("`@("`@("1T;7`@/2!$0E]/2SL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!`;V-I<V5T<')E9F5T8V@H)'-T;70L("1T:&ES+3YO<'1I
M;VYS6R=R97-U;'1?8G5F9F5R:6YG)UTI.PH@("`@("`@("`@("`D=&UP(#TF
M(&YE=R!$0E]R97-U;'0H)'1H:7,L("1S=&UT*3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1T;7`["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M875T;T-O;6UI="@I"@H@("`@+RHJ"B`@("`@*B!%;F%B;&5S(&]R(&1I<V%B
M;&5S(&%U=&]M871I8R!C;VUM:71S"B`@("`@*@H@("`@("H@0'!A<F%M(&)O
M;VP@)&]N;V9F("!T<G5E('1U<FYS(&ET(&]N+"!F86QS92!T=7)N<R!I="!O
M9F8*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S
M<RX@($$@1$)?17)R;W(@;V)J96-T(&EF('1H92!D<FEV97(*("`@("`J("`@
M("`@("`@("`@("`@9&]E<VXG="!S=7!P;W)T(&%U=&\M8V]M;6ET=&EN9R!T
M<F%N<V%C=&EO;G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%U=&]#;VUM:70H
M)&]N;V9F(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1H:7,M/F%U=&]C;VUM
M:70@/2`H8F]O;"DD;VYO9F8[.PH@("`@("`@(')E='5R;B!$0E]/2SL*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VUM:70H*0H*("`@("\J*@H@
M("`@("H@0V]M;6ET<R!T:&4@8W5R<F5N="!T<F%N<V%C=&EO;@H@("`@("H*
M("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%
M<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M8V]M;6ET*"D*("`@('L*("`@("`@("`D<F5S=6QT(#T@0$]#24-O;6UI="@D
M=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^;V-I.%)A:7-E17)R;W(H*3L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[(')O;&QB86-K*"D*"B`@("`O*BH*("`@("`J(%)E=F5R
M=',@=&AE(&-U<G)E;G0@=')A;G-A8W1I;VX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')O;&QB86-K*"D*
M("`@('L*("`@("`@("`D<F5S=6QT(#T@0$]#25)O;&QB86-K*"1T:&ES+3YC
M;VYN96-T:6]N*3L*("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YO8VDX4F%I<V5%<G)O<B@I.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@869F96-T9612;W=S*"D*"B`@("`O*BH*("`@("`J($1E=&5R;6EN
M97,@=&AE(&YU;6)E<B!O9B!R;W=S(&%F9F5C=&5D(&)Y(&$@9&%T82!M86YI
M=7!L871I;VX@<75E<GD*("`@("`J"B`@("`@*B`P(&ES(')E='5R;F5D(&9O
M<B!Q=65R:65S('1H870@9&]N)W0@;6%N:7!U;&%T92!D871A+@H@("`@("H*
M("`@("`J($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F(')O=W,N("!!($1"
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!A9F9E8W1E9%)O=W,H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^;&%S
M=%]S=&UT(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/F]C:3A286ES945R<F]R*"D["B`@("`@("`@?0H@("`@("`@("1R97-U;'0@
M/2!`3T-)4F]W0V]U;G0H)'1H:7,M/FQA<W1?<W1M="D["B`@("`@("`@:68@
M*"1R97-U;'0@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^;V-I.%)A:7-E17)R;W(H)'1H:7,M/FQA<W1?<W1M="D["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[(&UO9&EF>5%U97)Y*"D*"B`@("`O*BH*("`@("`J($-H86YG
M97,@82!Q=65R>2!S=')I;F<@9F]R('9A<FEO=7,@1$)-4R!S<&5C:69I8R!R
M96%S;VYS"B`@("`@*@H@("`@("H@(E-%3$5#5"`R*S(B(&UU<W0@8F4@(E-%
M3$5#5"`R*S(@1E)/32!D=6%L(B!I;B!/<F%C;&4N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<75E<GD@('1H92!Q=65R>2!S=')I;F<@=&\@;6]D
M:69Y"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!M;V1I9FEE
M9"!Q=65R>2!S=')I;F<*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E8W1E
M9`H@("`@("HO"B`@("!F=6YC=&EO;B!M;V1I9GE1=65R>2@D<75E<GDI"B`@
M("!["B`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>7',J4T5,14-4+VDG+"`D
M<75E<GDI("8F"B`@("`@("`@("`@("%P<F5G7VUA=&-H*"<O7'-&4D]-7',O
M:2<L("1Q=65R>2DI('L*("`@("`@("`@("`@)'%U97)Y("X]("<@1E)/32!D
M=6%L)SL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1Q=65R>3L*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!M;V1I9GE,:6UI=%%U97)Y*"D*"B`@
M("`O*BH*("`@("`J($%D9',@3$E-250@8VQA=7-E<R!T;R!A('%U97)Y('-T
M<FEN9R!A8V-O<F1I;F<@=&\@8W5R<F5N="!$0DU3('-T86YD87)D<PH@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'%U97)Y("`@=&AE('%U97)Y('1O
M(&UO9&EF>0H@("`@("H@0'!A<F%M(&EN="`@("`D9G)O;2`@("!T:&4@<F]W
M('1O('-T87)T('1O(&9E=&-H:6YG("@P(#T@=&AE(&9I<G-T(')O=RD*("`@
M("`J($!P87)A;2!I;G0@("`@)&-O=6YT("`@=&AE(&YU;6)E<G,@;V8@<F]W
M<R!T;R!F971C:`H@("`@("H@0'!A<F%M(&UI>&5D("`D<&%R86US("!A<G)A
M>2P@<W1R:6YG(&]R(&YU;65R:6,@9&%T82!T;R!B92!U<V5D(&EN"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("!E>&5C=71I;VX@;V8@=&AE('-T
M871E;65N="X@(%%U86YT:71Y(&]F(&ET96US"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("!P87-S960@;75S="!M871C:"!Q=6%N=&ET>2!O9B!P
M;&%C96AO;&1E<G,@:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M('%U97)Y.B`@;65A;FEN9R`Q('!L86-E:&]L9&5R(&9O<B!N;VXM87)R87D*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('!A<F%M971E<G,@;W(@
M,2!P;&%C96AO;&1E<B!P97(@87)R87D@96QE;65N="X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@=&AE('%U97)Y('-T<FEN9R!W:71H($Q)34E4
M(&-L875S97,@861D960*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E8W1E
M9`H@("`@("HO"B`@("!F=6YC=&EO;B!M;V1I9GE,:6UI=%%U97)Y*"1Q=65R
M>2P@)&9R;VTL("1C;W5N="P@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@
M("`@("`@+R\@3&5T($]R86-L92!R971U<FX@=&AE(&YA;64@;V8@=&AE(&-O
M;'5M;G,@:6YS=&5A9"!O9@H@("`@("`@("\O(&-O9&EN9R!A(")H;VUE(B!3
M44P@<&%R<V5R"@H@("`@("`@(&EF("AC;W5N="@D<&%R86US*2D@>PH@("`@
M("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/G!R97!A<F4H(E-%3$5#5"`J($92
M3TT@*"1Q=65R>2D@(@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+B`G5TA%4D4@3E5,3"`]($Y53$PG*3L*("`@("`@("`@("`@)'1M
M<"`])B`D=&AI<RT^97AE8W5T92@D<F5S=6QT+"`D<&%R86US*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D<5]F:65L9',@/2`B4T5,14-4("H@
M1E)/32`H)'%U97)Y*2!72$5212!.54Q,(#T@3E5,3"(["@H@("`@("`@("`@
M("!I9B`H(21R97-U;'0@/2!`3T-)4&%R<V4H)'1H:7,M/F-O;FYE8W1I;VXL
M("1Q7V9I96QD<RDI('L*("`@("`@("`@("`@("`@("1T:&ES+3YL87-T7W%U
M97)Y(#T@)'%?9FEE;&1S.PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YO8VDX4F%I<V5%<G)O<B@I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("@A0$]#245X96-U=&4H)')E<W5L="P@3T-)7T1%1D%53%0I*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^;&%S=%]Q=65R>2`]("1Q7V9I96QD<SL*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;V-I.%)A:7-E17)R;W(H
M)')E<W5L="D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1N
M8V]L<R`]($]#24YU;4-O;',H)')E<W5L="D["B`@("`@("`@)&-O;',@(#T@
M87)R87DH*3L*("`@("`@("!F;W(@*"`D:2`](#$[("1I(#P]("1N8V]L<SL@
M)&DK*R`I('L*("`@("`@("`@("`@)&-O;'-;72`]("<B)R`N($]#24-O;'5M
M;DYA;64H)')E<W5L="P@)&DI("X@)R(G.PH@("`@("`@('T*("`@("`@("`D
M9FEE;&1S(#T@:6UP;&]D92@G+"`G+"`D8V]L<RD["B`@("`@("`@+R\@6%A8
M(%1E<W0@=&AA="`H=&EP(&)Y($IO:&X@3&EM*0H@("`@("`@("\O:68@*'!R
M96=?;6%T8V@H)R]>7',J4T5,14-47',K+VES)RP@)'%U97)Y+"`D;6%T8V@I
M*2!["B`@("`@("`@+R\@("`@+R\@26YT<F]D=6-E('1H92!&25)35%]23U=3
M($]R86-L92!Q=65R>2!O<'1I;6EZ97(*("`@("`@("`O+R`@("`D<75E<GD@
M/2!S=6)S='(H)'%U97)Y+"!S=')L96XH)&UA=&-H6S!=*2P@<W1R;&5N*"1Q
M=65R>2DI.PH@("`@("`@("\O("`@("1Q=65R>2`](")314Q%0U0@+RH@*T9)
M4E-47U)/5U,@*B\@(B`N("1Q=65R>3L*("`@("`@("`O+WT*"B`@("`@("`@
M+R\@0V]N<W1R=6-T('1H92!Q=65R>0H@("`@("`@("\O(&UO<F4@870Z(&AT
M='`Z+R]M87)C+G1H96%I;7-G<F]U<"YC;VTO/VP]<&AP+61B)FT].3DX,S$Y
M-3@Q,#$R,3(F=STR"B`@("`@("`@+R\@4&5R:&%P<R!T:&ES(&-O=6QD(&)E
M(&]P=&EM:7IE9"!W:71H('1H92!U<V4@;V8@56YI;VYS"B`@("`@("`@)'%U
M97)Y(#T@(E-%3$5#5"`D9FEE;&1S($923TTB+@H@("`@("`@("`@("`@("`@
M("(@("A314Q%0U0@<F]W;G5M(&%S(&QI;F5N=6TL("1F:65L9',@1E)/32(N
M"B`@("`@("`@("`@("`@("`@(B`@("`@("@D<75E<GDI(BX*("`@("`@("`@
M("`@("`@("`G("!72$5212!R;W=N=6T@/#T@)RX@*"1F<F]M("L@)&-O=6YT
M*2`N"B`@("`@("`@("`@("`@("`@)RD@5TA%4D4@;&EN96YU;2`^/2`G("X@
M*RLD9G)O;3L*("`@("`@("!R971U<FX@)'%U97)Y.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&YE>'1)9"@I"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS('1H92!N97AT(&9R964@:60@:6X@82!S97%U96YC90H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@("1S97%?;F%M92`@;F%M92!O9B!T:&4@<V5Q
M=65N8V4*("`@("`J($!P87)A;2!B;V]L96%N("1O;F1E;6%N9"`@=VAE;B!T
M<G5E+"!T:&4@<V5Q96YC92!I<R!A=71O;6%T:6-A;&QY"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!C<F5A=&5D(&EF(&ET(&1O97,@;F]T
M(&5X:7-T"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N97AT(&ED
M(&YU;6)E<B!I;B!T:&4@<V5Q=65N8V4N"B`@("`@*B`@("`@("`@("`@("`@
M($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@
M0'-E92!$0E]C;VUM;VXZ.FYE>'1)1"@I+"!$0E]C;VUM;VXZ.F=E=%-E<75E
M;F-E3F%M92@I+`H@("`@("H@("`@("!$0E]O8VDX.CIC<F5A=&5397%U96YC
M92@I+"!$0E]O8VDX.CID<F]P4V5Q=65N8V4H*0H@("`@("HO"B`@("!F=6YC
M=&EO;B!N97AT260H)'-E<5]N86UE+"`D;VYD96UA;F0@/2!T<G5E*0H@("`@
M>PH@("`@("`@("1S97%N86UE(#T@)'1H:7,M/F=E=%-E<75E;F-E3F%M92@D
M<V5Q7VYA;64I.PH@("`@("`@("1R97!E870@/2`P.PH@("`@("`@(&1O('L*
M("`@("`@("`@("`@)'1H:7,M/F5X<&5C=$5R<F]R*$1"7T524D]27TY/4U5#
M2%1!0DQ%*3L*("`@("`@("`@("`@)')E<W5L="`])B`D=&AI<RT^<75E<GDH
M(E-%3$5#5"`D>W-E<6YA;65]+FYE>'1V86P@1E)/32!D=6%L(BD["B`@("`@
M("`@("`@("1T:&ES+3YP;W!%>'!E8W0H*3L*("`@("`@("`@("`@:68@*"1O
M;F1E;6%N9"`F)B!$0CHZ:7-%<G)O<B@D<F5S=6QT*2`F)@H@("`@("`@("`@
M("`@("`@)')E<W5L="T^9V5T0V]D92@I(#T]($1"7T524D]27TY/4U5#2%1!
M0DQ%*2!["B`@("`@("`@("`@("`@("`D<F5P96%T(#T@,3L*("`@("`@("`@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^8W)E871E4V5Q=65N8V4H)'-E<5]N
M86UE*3L*("`@("`@("`@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT
M*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@D<F5S=6QT*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1R97!E870@/2`P.PH@("`@("`@
M("`@("!]"B`@("`@("`@?2!W:&EL92`H)')E<&5A="D["B`@("`@("`@:68@
M*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@D<F5S=6QT*3L*("`@("`@("!]"B`@("`@("`@
M)&%R<B`]("1R97-U;'0M/F9E=&-H4F]W*$1"7T9%5$-(34]$15]/4D1%4D5$
M*3L*("`@("`@("!R971U<FX@)&%R<ELP73L*("`@('T*"B`@("`O*BH*("`@
M("`J($-R96%T97,@82!N97<@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1S97%?;F%M92`@;F%M92!O9B!T:&4@;F5W('-E<75E;F-E
M"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N
M("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J
M($!S964@1$)?8V]M;6]N.CIC<F5A=&5397%U96YC92@I+"!$0E]C;VUM;VXZ
M.F=E=%-E<75E;F-E3F%M92@I+`H@("`@("H@("`@("!$0E]O8VDX.CIN97AT
M240H*2P@1$)?;V-I.#HZ9')O<%-E<75E;F-E*"D*("`@("`J+PH@("`@9G5N
M8W1I;VX@8W)E871E4V5Q=65N8V4H)'-E<5]N86UE*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^<75E<GDH)T-214%412!315%514Y#12`G"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`N("1T:&ES+3YG971397%U96YC94YA
M;64H)'-E<5]N86UE*2D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M9')O<%-E<75E;F-E*"D*"B`@("`O*BH*("`@("`J($1E;&5T97,@82!S97%U
M96YC90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-E<5]N86UE("!N
M86UE(&]F('1H92!S97%U96YC92!T;R!B92!D96QE=&5D"B`@("`@*@H@("`@
M("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?8V]M
M;6]N.CID<F]P4V5Q=65N8V4H*2P@1$)?8V]M;6]N.CIG971397%U96YC94YA
M;64H*2P*("`@("`J("`@("`@1$)?;V-I.#HZ;F5X=$E$*"DL($1"7V]C:3@Z
M.F-R96%T95-E<75E;F-E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9')O<%-E
M<75E;F-E*"1S97%?;F%M92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/G%U97)Y*"=$4D]0(%-%455%3D-%("<*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("X@)'1H:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I*3L*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!O8VDX4F%I<V5%<G)O<B@I
M"@H@("`@+RHJ"B`@("`@*B!0<F]D=6-E<R!A($1"7T5R<F]R(&]B:F5C="!R
M96=A<F1I;F<@=&AE(&-U<G)E;G0@<')O8FQE;0H@("`@("H*("`@("`J($!P
M87)A;2!I;G0@)&5R<FYO("!I9B!T:&4@97)R;W(@:7,@8F5I;F<@;6%N=6%L
M;'D@<F%I<V5D('!A<W,@80H@("`@("H@("`@("`@("`@("`@("`@("`@("!$
M0E]%4E)/4BH@8V]N<W1A;G0@:&5R92X@($EF('1H:7,@:7-N)W0@<&%S<V5D
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@('1H92!E<G)O<B!I;F9O<FUA
M=&EO;B!G871H97)E9"!F<F]M('1H92!$0DU3+@H@("`@("H*("`@("`J($!R
M971U<FX@;V)J96-T("!T:&4@1$)?17)R;W(@;V)J96-T"B`@("`@*@H@("`@
M("H@0'-E92!$0E]C;VUM;VXZ.G)A:7-E17)R;W(H*2P*("`@("`J("`@("`@
M1$)?;V-I.#HZ97)R;W).871I=F4H*2P@1$)?;V-I.#HZ97)R;W)#;V1E*"D*
M("`@("`J+PH@("`@9G5N8W1I;VX@;V-I.%)A:7-E17)R;W(H)&5R<FYO(#T@
M;G5L;"D*("`@('L*("`@("`@("!I9B`H)&5R<FYO(#T]/2!N=6QL*2!["B`@
M("`@("`@("`@("1E<G)O<B`]($!/0TE%<G)O<B@D=&AI<RT^8V]N;F5C=&EO
M;BD["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D=&AI
M<RT^97)R;W)#;V1E*"1E<G)O<ELG8V]D92==*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&YU;&PL(&YU;&PL(&YU;&PL("1E<G)O
M<ELG;65S<V%G92==*3L*("`@("`@("!](&5L<V5I9B`H:7-?<F5S;W5R8V4H
M)&5R<FYO*2D@>PH@("`@("`@("`@("`D97)R;W(@/2!`3T-)17)R;W(H)&5R
M<FYO*3L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1T
M:&ES+3YE<G)O<D-O9&4H)&5R<F]R6R=C;V1E)UTI+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@;G5L;"P@;G5L;"P@;G5L;"P@)&5R
M<F]R6R=M97-S86=E)UTI.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H)'1H:7,M/F5R<F]R0V]D92@D97)R;F\I*3L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!E<G)O<DYA=&EV92@I"@H@("`@
M+RHJ"B`@("`@*B!'971S('1H92!$0DU3)R!N871I=F4@97)R;W(@8V]D92!P
M<F]D=6-E9"!B>2!T:&4@;&%S="!Q=65R>0H@("`@("H*("`@("`J($!R971U
M<FX@:6YT("!T:&4@1$)-4R<@97)R;W(@8V]D92X@($9!3%-%(&EF('1H92!C
M;V1E(&-O=6QD(&YO="!B90H@("`@("H@("`@("`@("`@("`@("!D971E<FUI
M;F5D"B`@("`@*B\*("`@(&9U;F-T:6]N(&5R<F]R3F%T:79E*"D*("`@('L*
M("`@("`@("!I9B`H:7-?<F5S;W5R8V4H)'1H:7,M/FQA<W1?<W1M="DI('L*
M("`@("`@("`@("`@)&5R<F]R(#T@0$]#245R<F]R*"1T:&ES+3YL87-T7W-T
M;70I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1E<G)O<B`]($!/
M0TE%<G)O<B@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@?0H@("`@("`@
M(&EF("AI<U]A<G)A>2@D97)R;W(I*2!["B`@("`@("`@("`@(')E='5R;B`D
M97)R;W);)V-O9&4G73L*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('1A8FQE26YF;R@I"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS(&EN9F]R;6%T:6]N(&%B;W5T(&$@=&%B
M;&4@;W(@82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@3D]413H@;VYL>2!S
M=7!P;W)T<R`G=&%B;&4G(&%N9"`G9FQA9W,G(&EF(#QV87(^)')E<W5L=#PO
M=F%R/@H@("`@("H@:7,@82!T86)L92!N86UE+@H@("`@("H*("`@("`J($Y/
M5$4Z(&9L86=S('=O;B=T(&-O;G1A:6X@:6YD97@@:6YF;W)M871I;VXN"B`@
M("`@*@H@("`@("H@0'!A<F%M(&]B:F5C='QS=')I;F<@("1R97-U;'0@($1"
M7W)E<W5L="!O8FIE8W0@9G)O;2!A('%U97)Y(&]R(&$*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R:6YG(&-O;G1A:6YI;F<@
M=&AE(&YA;64@;V8@82!T86)L92X*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@5VAI;&4@=&AI<R!A;'-O(&%C8V5P=',@82!Q=65R
M>2!R97-U;'0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<F5S;W5R8V4@:61E;G1I9FEE<BP@=&AI<R!B96AA=FEO<B!I<PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!D97!R96-A=&5D
M+@H@("`@("H@0'!A<F%M(&EN="`@("`@("`@("`@("1M;V1E("`@(&$@=F%L
M:60@=&%B;&5);F9O(&UO9&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!A;B!A<W-O8VEA=&EV92!A<G)A>2!W:71H('1H92!I;F9O<FUA=&EO;B!R
M97%U97-T960N"B`@("`@*B`@("`@("`@("`@("`@("`@02!$0E]%<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO
M;CHZ=&%B;&5);F9O*"D*("`@("`J+PH@("`@9G5N8W1I;VX@=&%B;&5);F9O
M*"1R97-U;'0L("1M;V1E(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H)'1H
M:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465],
M3U=%4D-!4T4I('L*("`@("`@("`@("`@)&-A<V5?9G5N8R`]("=S=')T;VQO
M=V5R)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D8V%S95]F=6YC
M(#T@)W-T<G9A;"<["B`@("`@("`@?0H*("`@("`@("`D<F5S(#T@87)R87DH
M*3L*"B`@("`@("`@:68@*&ES7W-T<FEN9R@D<F5S=6QT*2D@>PH@("`@("`@
M("`@("`O*@H@("`@("`@("`@("`@*B!0<F]B86)L>2!R96-E:79E9"!A('1A
M8FQE(&YA;64N"B`@("`@("`@("`@("`J($-R96%T92!A(')E<W5L="!R97-O
M=7)C92!I9&5N=&EF:65R+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@
M)')E<W5L="`]('-T<G1O=7!P97(H)')E<W5L="D["B`@("`@("`@("`@("1Q
M7V9I96QD<R`]("=314Q%0U0@8V]L=6UN7VYA;64L(&1A=&%?='EP92P@9&%T
M85]L96YG=&@L("<*("`@("`@("`@("`@("`@("`@("`@("`@+B`G;G5L;&%B
M;&4@)PH@("`@("`@("`@("`@("`@("`@("`@("`N("=&4D]-('5S97)?=&%B
M7V-O;'5M;G,@)PH@("`@("`@("`@("`@("`@("`@("`@("`N(")72$5212!T
M86)L95]N86UE/2<D<F5S=6QT)R!/4D1%4B!"62!C;VQU;6Y?:60B.PH*("`@
M("`@("`@("`@)'1H:7,M/FQA<W1?<75E<GD@/2`D<5]F:65L9',["@H@("`@
M("`@("`@("!I9B`H(21S=&UT(#T@0$]#25!A<G-E*"1T:&ES+3YC;VYN96-T
M:6]N+"`D<5]F:65L9',I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/F]C:3A286ES945R<F]R*$1"7T524D]27TY%141?34]215]$051!*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(4!/0TE%>&5C=71E*"1S
M=&UT+"!/0TE?1$5&055,5"DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^;V-I.%)A:7-E17)R;W(H)'-T;70I.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`D:2`](#`["B`@("`@("`@("`@('=H:6QE("A`3T-)1F5T
M8V@H)'-T;70I*2!["B`@("`@("`@("`@("`@("`D<F5S6R1I72`](&%R<F%Y
M*`H@("`@("`@("`@("`@("`@("`@("=T86)L92<@/3X@)&-A<V5?9G5N8R@D
M<F5S=6QT*2P*("`@("`@("`@("`@("`@("`@("`G;F%M92<@(#T^("1C87-E
M7V9U;F,H0$]#25)E<W5L="@D<W1M="P@,2DI+`H@("`@("`@("`@("`@("`@
M("`@("=T>7!E)R`@/3X@0$]#25)E<W5L="@D<W1M="P@,BDL"B`@("`@("`@
M("`@("`@("`@("`@)VQE;B<@("`]/B!`3T-)4F5S=6QT*"1S=&UT+"`S*2P*
M("`@("`@("`@("`@("`@("`@("`G9FQA9W,G(#T^("A`3T-)4F5S=6QT*"1S
M=&UT+"`T*2`]/2`G3B<I(#\@)VYO=%]N=6QL)R`Z("<G+`H@("`@("`@("`@
M("`@("`@*3L*("`@("`@("`@("`@("`@(&EF("@D;6]D92`F($1"7U1!0DQ%
M24Y&3U]/4D1%4BD@>PH@("`@("`@("`@("`@("`@("`@("1R97-;)V]R9&5R
M)UU;)')E<ULD:5U;)VYA;64G75T@/2`D:3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&EF("@D;6]D92`F($1"7U1!0DQ%24Y&3U]/4D1%
M4E1!0DQ%*2!["B`@("`@("`@("`@("`@("`@("`@)')E<ULG;W)D97)T86)L
M92==6R1R97-;)&E=6R=T86)L92==75LD<F5S6R1I75LG;F%M92==72`]("1I
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&DK*SL*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1M;V1E*2!["B`@("`@("`@
M("`@("`@("`D<F5S6R=N=6U?9FEE;&1S)UT@/2`D:3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!`3T-)1G)E95-T871E;65N="@D<W1M="D["@H@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(&EF("AI<W-E="@D<F5S=6QT+3YR
M97-U;'0I*2!["B`@("`@("`@("`@("`@("`O*@H@("`@("`@("`@("`@("`@
M("H@4')O8F%B;'D@<F5C96EV960@82!R97-U;'0@;V)J96-T+@H@("`@("`@
M("`@("`@("`@("H@17AT<F%C="!T:&4@<F5S=6QT(')E<V]U<F-E(&ED96YT
M:69I97(N"B`@("`@("`@("`@("`@("`@*B\*("`@("`@("`@("`@("`@("1R
M97-U;'0@/2`D<F5S=6QT+3YR97-U;'0["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("1R97,@/2!A<G)A>2@I.PH*("`@("`@("`@("`@:68@*"1R97-U
M;'0@/3T]("1T:&ES+3YL87-T7W-T;70I('L*("`@("`@("`@("`@("`@("1C
M;W5N="`]($!/0TE.=6U#;VQS*"1R97-U;'0I.PH@("`@("`@("`@("`@("`@
M:68@*"1M;V1E*2!["B`@("`@("`@("`@("`@("`@("`@)')E<ULG;G5M7V9I
M96QD<R==(#T@)&-O=6YT.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@9F]R("@D:2`](#`[("1I(#P@)&-O=6YT.R`D:2LK*2!["B`@("`@
M("`@("`@("`@("`@("`@)')E<ULD:5T@/2!A<G)A>2@*("`@("`@("`@("`@
M("`@("`@("`@("`@)W1A8FQE)R`]/B`G)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@)VYA;64G("`]/B`D8V%S95]F=6YC*$!/0TE#;VQU;6Y.86UE*"1R
M97-U;'0L("1I*S$I*2P*("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G
M("`]/B!`3T-)0V]L=6UN5'EP92@D<F5S=6QT+"`D:2LQ*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@)VQE;B<@("`]/B!`3T-)0V]L=6UN4VEZ92@D<F5S
M=6QT+"`D:2LQ*2P*("`@("`@("`@("`@("`@("`@("`@("`@)V9L86=S)R`]
M/B`G)RP*("`@("`@("`@("`@("`@("`@("`I.PH@("`@("`@("`@("`@("`@
M("`@(&EF("@D;6]D92`F($1"7U1!0DQ%24Y&3U]/4D1%4BD@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D<F5S6R=O<F1E<B==6R1R97-;)&E=6R=N86UE
M)UU=(#T@)&D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@(&EF("@D;6]D92`F($1"7U1!0DQ%24Y&3U]/4D1%4E1!0DQ%*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1R97-;)V]R9&5R=&%B;&4G75LD
M<F5S6R1I75LG=&%B;&4G75U;)')E<ULD:5U;)VYA;64G75T@/2`D:3L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H1$)?15)23U)?3D]47T-!4$%"3$4I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5S.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&=E=%-P96-I86Q1=65R>2@I"@H@("`@+RHJ"B`@
M("`@*B!/8G1A:6YS('1H92!Q=65R>2!S=')I;F<@;F5E9&5D(&9O<B!L:7-T
M:6YG(&$@9VEV96X@='EP92!O9B!O8FIE8W1S"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D='EP92`@=&AE(&MI;F0@;V8@;V)J96-T<R!Y;W4@=V%N
M="!T;R!R971R:65V90H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T
M:&4@4U%,('%U97)Y('-T<FEN9R!O<B!N=6QL(&EF('1H92!D<FEV97(@9&]E
M<VXG=`H@("`@("H@("`@("`@("`@("`@("`@("!S=7!P;W)T('1H92!O8FIE
M8W0@='EP92!R97%U97-T960*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E
M8W1E9`H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F=E=$QI<W1/9B@I"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=%-P96-I86Q1=65R>2@D='EP92D*("`@('L*
M("`@("`@("!S=VET8V@@*"1T>7!E*2!["B`@("`@("`@("`@(&-A<V4@)W1A
M8FQE<R<Z"B`@("`@("`@("`@("`@("!R971U<FX@)U-%3$5#5"!T86)L95]N
M86UE($923TT@=7-E<E]T86)L97,G.PH@("`@("`@("`@("!C87-E("=S>6YO
M;GEM<R<Z"B`@("`@("`@("`@("`@("!R971U<FX@)U-%3$5#5"!S>6YO;GEM
M7VYA;64@1E)/32!U<V5R7W-Y;F]N>6US)SL*("`@("`@("`@("`@9&5F875L
M=#H*("`@("`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*("`@
M('T*"B`@("`O+R!]?7T*"GT*"B\J"B`J($QO8V%L('9A<FEA8FQE<SH*("H@
M=&%B+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J($5N9#H*("HO
M"@H_/@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T1"+V]D8F,N
M<&AP````````````````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P-C0T-38@,3`U,34T,S,W,S$@,#(P-#$P`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@HO*B!V:6TZ('-E="!E
M>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT
M.B`J+PH*+RHJ"B`J(%1H92!014%2($1"(&1R:79E<B!F;W(@4$A0)W,@;V1B
M8R!E>'1E;G-I;VX*("H@9F]R(&EN=&5R86-T:6YG('=I=&@@9&%T86)A<V5S
M('9I82!/1$)#(&-O;FYE8W1I;VYS"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N
M9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C
M="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA="!I
M<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE
M(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@H@
M*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET
M('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N;W1E('1O(&QI
M8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D
M:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@*B!`<&%C:V%G
M92`@("!$0@H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN
M970^"B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`
M<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O
M=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@($-64SH@
M)$ED.B!O9&)C+G!H<"QV(#$N-S@@,C`P-2\P,B\R."`P,3HT,CHQ-R!D86YI
M96QC($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O
M<&%C:V%G92]$0@H@*B\*"B\J*@H@*B!/8G1A:6X@=&AE($1"7V-O;6UO;B!C
M;&%S<R!S;R!I="!C86X@8F4@97AT96YD960@9G)O;0H@*B\*<F5Q=6ER95]O
M;F-E("=$0B]C;VUM;VXN<&AP)SL*"B\J*@H@*B!4:&4@;65T:&]D<R!014%2
M($1"('5S97,@=&\@:6YT97)A8W0@=VET:"!02%`G<R!O9&)C(&5X=&5N<VEO
M;@H@*B!F;W(@:6YT97)A8W1I;F<@=VET:"!D871A8F%S97,@=FEA($]$0D,@
M8V]N;F5C=&EO;G,*("H*("H@5&AE<V4@;65T:&]D<R!O=F5R;&]A9"!T:&4@
M;VYE<R!D96-L87)E9"!I;B!$0E]C;VUM;VXN"B`J"B`J($UO<F4@:6YF;R!O
M;B!/1$)#(&5R<F]R<R!C;W5L9"!B92!F;W5N9"!H97)E.@H@*B!H='1P.B\O
M;7-D;BYM:6-R;W-O9G0N8V]M+VQI8G)A<GDO9&5F875L="YA<W`_=7)L/2]L
M:6)R87)Y+V5N+75S+W1R8FQS<6PO=')?97)R7V]D8F-?-7-T>BYA<W`*("H*
M("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@
M0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@H@*B!`875T
M:&]R("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J
M($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E
M;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(
M4"!,:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C<N-@H@
M*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*
M("HO"F-L87-S($1"7V]D8F,@97AT96YD<R!$0E]C;VUM;VX*>PH@("`@+R\@
M>WM[('!R;W!E<G1I97,*"B`@("`O*BH*("`@("`J(%1H92!$0B!D<FEV97(@
M='EP92`H;7ES<6PL(&]C:3@L(&]D8F,L(&5T8RXI"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)'!H<'1Y<&4@/2`G;V1B8R<["@H@("`@
M+RHJ"B`@("`@*B!4:&4@9&%T86)A<V4@<WEN=&%X('9A<FEA;G0@=&\@8F4@
M=7-E9"`H9&(R+"!A8V-E<W,L(&5T8RXI+"!I9B!A;GD*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D9&)S>6YT87@@/2`G<W%L.3(G.PH*
M("`@("\J*@H@("`@("H@5&AE(&-A<&%B:6QI=&EE<R!O9B!T:&ES($1"(&EM
M<&QE;65N=&%T:6]N"B`@("`@*@H@("`@("H@5&AE("=N97=?;&EN:R<@96QE
M;65N="!C;VYT86EN<R!T:&4@4$A0('9E<G-I;VX@=&AA="!F:7)S="!P<F]V
M:61E9`H@("`@("H@;F5W7VQI;FL@<W5P<&]R="!F;W(@=&AI<R!$0DU3+B`@
M0V]N=&%I;G,@9F%L<V4@:68@:70G<R!U;G-U<'!O<G1E9"X*("`@("`J"B`@
M("`@*B!-96%N:6YG(&]F('1H92`G;&EM:70G(&5L96UE;G0Z"B`@("`@*B`@
M("L@)V5M=6QA=&4G(#T@96UU;&%T92!W:71H(&9E=&-H(')O=R!B>2!N=6UB
M97(*("`@("`J("`@*R`G86QT97(G("`@/2!A;'1E<B!T:&4@<75E<GD*("`@
M("`J("`@*R!F86QS92`@("`@/2!S:VEP(')O=W,*("`@("`J"B`@("`@*B!.
M3U1%.B!4:&4@9F5A='5R92!S970@;V8@=&AE(&9O;&QO=VEN9R!D<FEV97)S
M(&%R92!D:69F97)E;G0@=&AA;@H@("`@("H@=&AE(&1E9F%U;'0Z"B`@("`@
M*B`@("L@<V]L:60Z("=T<F%N<V%C=&EO;G,G(#T@=')U90H@("`@("H@("`K
M(&YA=FES:6]N.B`G;&EM:70G(#T@9F%L<V4*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D9F5A='5R97,@/2!A<G)A>2@*("`@
M("`@("`G;&EM:70G("`@("`@("`@/3X@)V5M=6QA=&4G+`H@("`@("`@("=N
M97=?;&EN:R<@("`@("`]/B!F86QS92P*("`@("`@("`G;G5M<F]W<R<@("`@
M("`@/3X@=')U92P*("`@("`@("`G<&-O;FYE8W0G("`@("`@/3X@=')U92P*
M("`@("`@("`G<')E<&%R92<@("`@("`@/3X@9F%L<V4L"B`@("`@("`@)W-S
M;"<@("`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("=T<F%N<V%C=&EO;G,G
M("`]/B!F86QS92P*("`@("D["@H@("`@+RHJ"B`@("`@*B!!(&UA<'!I;F<@
M;V8@;F%T:79E(&5R<F]R(&-O9&5S('1O($1"(&5R<F]R(&-O9&5S"B`@("`@
M*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D97)R;W)C;V1E7VUA<"`]
M(&%R<F%Y*`H@("`@("`@("<P,3`P-"<@/3X@1$)?15)23U)?5%)53D-!5$5$
M+`H@("`@("`@("<P-S`P,2<@/3X@1$)?15)23U)?34E334%40T@L"B`@("`@
M("`@)S(Q4S`Q)R`]/B!$0E]%4E)/4E]604Q515]#3U5.5%]/3E]23U<L"B`@
M("`@("`@)S(Q4S`R)R`]/B!$0E]%4E)/4E]-25--051#2"P*("`@("`@("`G
M,C(P,#$G(#T^($1"7T524D]27TE.5D%,240L"B`@("`@("`@)S(R,#`S)R`]
M/B!$0E]%4E)/4E])3E9!3$E$7TY534)%4BP*("`@("`@("`G,C(P,#4G(#T^
M($1"7T524D]27TE.5D%,241?3E5-0D52+`H@("`@("`@("<R,C`P."<@/3X@
M1$)?15)23U)?24Y604Q)1%]$051%+`H@("`@("`@("<R,C`Q,B<@/3X@1$)?
M15)23U)?1$E66D523RP*("`@("`@("`G,C,P,#`G(#T^($1"7T524D]27T-/
M3E-44D%)3E0L"B`@("`@("`@)S(S-3`R)R`]/B!$0E]%4E)/4E]#3TY35%)!
M24Y47TY/5%].54Q,+`H@("`@("`@("<R,S4P,R<@/3X@1$)?15)23U)?0T].
M4U1204E.5"P*("`@("`@("`G,C,U,#0G(#T^($1"7T524D]27T-/3E-44D%)
M3E0L"B`@("`@("`@)S(S-3`U)R`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@
M("`@("`@("<R-#`P,"<@/3X@1$)?15)23U)?24Y604Q)1"P*("`@("`@("`G
M,S0P,#`G(#T^($1"7T524D]27TE.5D%,240L"B`@("`@("`@)S,W,#`P)R`]
M/B!$0E]%4E)/4E]364Y405@L"B`@("`@("`@)S0R,#`P)R`]/B!$0E]%4E)/
M4E]364Y405@L"B`@("`@("`@)S0R-C`Q)R`]/B!$0E]%4E)/4E]364Y405@L
M"B`@("`@("`@)TE-,#`Q)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@
M("`@("`G4S`P,#`G(#T^($1"7T524D]27TY/4U5#2%1!0DQ%+`H@("`@("`@
M("=3,#`P,2<@/3X@1$)?15)23U)?04Q214%$65]%6$E35%,L"B`@("`@("`@
M)U,P,#`R)R`]/B!$0E]%4E)/4E].3U-50TA404),12P*("`@("`@("`G4S`P
M,3$G(#T^($1"7T524D]27T%,4D5!1%E?15A)4U13+`H@("`@("`@("=3,#`Q
M,B<@/3X@1$)?15)23U)?3D]47T9/54Y$+`H@("`@("`@("=3,#`R,2<@/3X@
M1$)?15)23U)?04Q214%$65]%6$E35%,L"B`@("`@("`@)U,P,#(R)R`]/B!$
M0E]%4E)/4E].3U-50TA&245,1"P*("`@("`@("`G4S$P,#DG(#T^($1"7T52
M4D]27TE.5D%,240L"B`@("`@("`@)U,Q,#DP)R`]/B!$0E]%4E)/4E])3E9!
M3$E$+`H@("`@("`@("=3,4,P,"<@/3X@1$)?15)23U)?3D]47T-!4$%"3$4L
M"B`@("`I.PH*("`@("\J*@H@("`@("H@5&AE(')A=R!D871A8F%S92!C;VYN
M96-T:6]N(&-R96%T960@8GD@4$A0"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@
M("`@*B\*("`@('9A<B`D8V]N;F5C=&EO;CL*"B`@("`O*BH*("`@("`J(%1H
M92!$4TX@:6YF;W)M871I;VX@9F]R(&-O;FYE8W1I;F<@=&\@82!D871A8F%S
M90H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&1S;B`](&%R
M<F%Y*"D["@H*("`@("\J*@H@("`@("H@5&AE(&YU;6)E<B!O9B!R;W=S(&%F
M9F5C=&5D(&)Y(&$@9&%T82!M86YI<'5L871I;VX@<75E<GD*("`@("`J($!V
M87(@:6YT96=E<@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@
M('9A<B`D869F96-T960@/2`P.PH*"B`@("`O+R!]?7T*("`@("\O('M[>R!C
M;VYS=')U8W1O<@H*("`@("\J*@H@("`@("H@5&AI<R!C;VYS=')U8W1O<B!C
M86QL<R`\:V)D/B1T:&ES+3Y$0E]C;VUM;VXH*3PO:V)D/@H@("`@("H*("`@
M("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!$0E]O9&)C
M*"D*("`@('L*("`@("`@("`D=&AI<RT^1$)?8V]M;6]N*"D["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@8V]N;F5C="@I"@H@("`@+RHJ"B`@("`@
M*B!#;VYN96-T('1O('1H92!D871A8F%S92!S97)V97(L(&QO9R!I;B!A;F0@
M;W!E;B!T:&4@9&%T86)A<V4*("`@("`J"B`@("`@*B!$;VXG="!C86QL('1H
M:7,@;65T:&]D(&1I<F5C=&QY+B`@57-E($1".CIC;VYN96-T*"D@:6YS=&5A
M9"X*("`@("`J"B`@("`@*B!014%2($1")W,@;V1B8R!D<FEV97(@<W5P<&]R
M=',@=&AE(&9O;&QO=VEN9R!E>'1R82!$4TX@;W!T:6]N<SH*("`@("`J("`@
M*R!C=7)S;W(@(%1H92!T>7!E(&]F(&-U<G-O<B!T;R!B92!U<V5D(&9O<B!T
M:&ES(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1D
M<VX@("`@("`@("!T:&4@9&%T82!S;W5R8V4@;F%M90H@("`@("H@0'!A<F%M
M(&)O;VP@("1P97)S:7-T96YT("!S:&]U;&0@=&AE(&-O;FYE8W1I;VX@8F4@
M<&5R<VES=&5N=#\*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@
M;VX@<W5C8V5S<RX@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@8V]N;F5C="@D9'-N+"`D<&5R<VES=&5N="`]
M(&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@A4$5!4CHZ;&]A9$5X=&5N<VEO
M;B@G;V1B8R<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<BA$0E]%4E)/4E]%6%1%3E-)3TY?3D]47T9/54Y$*3L*("`@("`@("!]
M"@H@("`@("`@("1T:&ES+3YD<VX@/2`D9'-N.PH@("`@("`@(&EF("@D9'-N
M6R=D8G-Y;G1A>"==*2!["B`@("`@("`@("`@("1T:&ES+3YD8G-Y;G1A>"`]
M("1D<VY;)V1B<WEN=&%X)UT["B`@("`@("`@?0H@("`@("`@('-W:71C:"`H
M)'1H:7,M/F1B<WEN=&%X*2!["B`@("`@("`@("`@(&-A<V4@)V%C8V5S<R<Z
M"B`@("`@("`@("`@(&-A<V4@)V1B,B<Z"B`@("`@("`@("`@(&-A<V4@)W-O
M;&ED)SH*("`@("`@("`@("`@("`@("1T:&ES+3YF96%T=7)E<ULG=')A;G-A
M8W1I;VYS)UT@/2!T<G5E.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@(&-A<V4@)VYA=FES:6]N)SH*("`@("`@("`@("`@("`@("1T:&ES
M+3YF96%T=7)E<ULG;&EM:70G72`](&9A;'-E.PH@("`@("`@('T*"B`@("`@
M("`@+RH*("`@("`@("`@*B!4:&ES(&ES(&AE87(@9F]R(&)A8VMW87)D<R!C
M;VUP871I8FEL:71Y+B!3:&]U;&0@:&%V92!B965N('5S:6YG"B`@("`@("`@
M("H@)V1A=&%B87-E)R!A;&P@86QO;F<L(&)U="!P<FEO<B!T;R`Q+C8N,%)#
M,R`G:&]S='-P96,G('=A<R!U<V5D+@H@("`@("`@("`J+PH@("`@("`@(&EF
M("@D9'-N6R=D871A8F%S92==*2!["B`@("`@("`@("`@("1O9&)C9'-N(#T@
M)&1S;ELG9&%T86)A<V4G73L*("`@("`@("!](&5L<V5I9B`H)&1S;ELG:&]S
M='-P96,G72D@>PH@("`@("`@("`@("`D;V1B8V1S;B`]("1D<VY;)VAO<W1S
M<&5C)UT["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&]D8F-D<VX@
M/2`G;&]C86QH;W-T)SL*("`@("`@("!]"@H@("`@("`@("1C;VYN96-T7V9U
M;F-T:6]N(#T@)'!E<G-I<W1E;G0@/R`G;V1B8U]P8V]N;F5C="<@.B`G;V1B
M8U]C;VYN96-T)SL*"B`@("`@("`@:68@*&5M<'1Y*"1D<VY;)V-U<G-O<B==
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`]($`D8V]N;F5C
M=%]F=6YC=&EO;B@D;V1B8V1S;BP@)&1S;ELG=7-E<FYA;64G72P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&1S;ELG<&%S<W=O<F0G72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'1H:7,M/F-O;FYE8W1I;VX@/2!`)&-O;FYE8W1?9G5N8W1I;VXH)&]D
M8F-D<VXL("1D<VY;)W5S97)N86UE)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D<VY;)W!A<W-W;W)D
M)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1D<VY;)V-U<G-O<B==*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("@A:7-?<F5S;W5R8V4H)'1H:7,M/F-O;FYE8W1I;VXI*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E]#3TY.
M14-47T9!24Q%1"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&YU;&PL(&YU;&PL(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^97)R;W).871I=F4H*2D["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!D:7-C;VYN96-T*"D*"B`@("`O*BH*("`@("`J($1I<V-O;FYE
M8W1S(&9R;VT@=&AE(&1A=&%B87-E('-E<G9E<@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;"`@5%)512!O;B!S=6-C97-S+"!&04Q312!O;B!F86EL=7)E
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&1I<V-O;FYE8W0H*0H@("`@>PH@("`@
M("`@("1E<G(@/2!`;V1B8U]C;&]S92@D=&AI<RT^8V]N;F5C=&EO;BD["B`@
M("`@("`@)'1H:7,M/F-O;FYE8W1I;VX@/2!N=6QL.PH@("`@("`@(')E='5R
M;B`D97)R.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('-I;7!L95%U
M97)Y*"D*"B`@("`O*BH*("`@("`J(%-E;F1S(&$@<75E<GD@=&\@=&AE(&1A
M=&%B87-E('-E<G9E<@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@('1H
M92!344P@<75E<GD@<W1R:6YG"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@*R!A(%!(4"!R97-U;'0@<F5S<F]U8V4@9F]R('-U8V-E<W-F=6P@4T5,
M14-4('%U97)I97,*("`@("`J("`@("`@("`@("`@("`@("L@=&AE($1"7T]+
M(&-O;G-T86YT(&9O<B!O=&AE<B!S=6-C97-S9G5L('%U97)I97,*("`@("`J
M("`@("`@("`@("`@("`@("L@82!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M90H@("`@("HO"B`@("!F=6YC=&EO;B!S:6UP;&51=65R>2@D<75E<GDI"B`@
M("!["B`@("`@("`@)'1H:7,M/FQA<W1?<75E<GD@/2`D<75E<GD["B`@("`@
M("`@)'%U97)Y(#T@)'1H:7,M/FUO9&EF>5%U97)Y*"1Q=65R>2D["B`@("`@
M("`@)')E<W5L="`]($!O9&)C7V5X96,H)'1H:7,M/F-O;FYE8W1I;VXL("1Q
M=65R>2D["B`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^;V1B8U)A:7-E17)R;W(H*3L@+R\@6%A8($524D]235-'
M"B`@("`@("`@?0H@("`@("`@("\O($1E=&5R;6EN92!W:&EC:"!Q=65R:65S
M('1H870@<VAO=6QD(')E='5R;B!D871A+"!A;F0@=VAI8V@*("`@("`@("`O
M+R!S:&]U;&0@<F5T=7)N(&%N(&5R<F]R(&-O9&4@;VYL>2X*("`@("`@("!I
M9B`H1$(Z.FES36%N:7`H)'%U97)Y*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M869F96-T960@/2`D<F5S=6QT.R`O+R!&;W(@869F96-T9612;W=S*"D*("`@
M("`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@("`@('T*("`@("`@("`D=&AI
M<RT^869F96-T960@/2`P.PH@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YE>'1297-U;'0H*0H*("`@("\J
M*@H@("`@("H@36]V92!T:&4@:6YT97)N86P@;V1B8R!R97-U;'0@<&]I;G1E
M<B!T;R!T:&4@;F5X="!A=F%I;&%B;&4@<F5S=6QT"B`@("`@*@H@("`@("H@
M0'!A<F%M(&$@=F%L:60@9F)S<6P@<F5S=6QT(')E<V]U<F-E"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<F5T=7)N('1R
M=64@:68@82!R97-U;'0@:7,@879A:6QA8FQE(&]T:&5R=VES92!R971U<FX@
M9F%L<V4*("`@("`J+PH@("`@9G5N8W1I;VX@;F5X=%)E<W5L="@D<F5S=6QT
M*0H@("`@>PH@("`@("`@(')E='5R;B!`;V1B8U]N97AT7W)E<W5L="@D<F5S
M=6QT*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!F971C:$EN=&\H
M*0H*("`@("\J*@H@("`@("H@4&QA8V5S(&$@<F]W(&9R;VT@=&AE(')E<W5L
M="!S970@:6YT;R!T:&4@9VEV96X@87)R87D*("`@("`J"B`@("`@*B!&;W)M
M871I;F<@;V8@=&AE(&%R<F%Y(&%N9"!T:&4@9&%T82!T:&5R96EN(&%R92!C
M;VYF:6=U<F%B;&4N"B`@("`@*B!3964@1$)?<F5S=6QT.CIF971C:$EN=&\H
M*2!F;W(@;6]R92!I;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!4:&ES(&UE
M=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E
M"B`@("`@*B!$0E]R97-U;'0Z.F9E=&-H26YT;R@I(&EN<W1E860N("!)="!C
M86XG="!B92!D96-L87)E9"`B<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$
M0E]R97-U;'0@:7,@82!S97!A<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@
M0'!A<F%M(')E<V]U<F-E("1R97-U;'0@("`@=&AE('%U97)Y(')E<W5L="!R
M97-O=7)C90H@("`@("H@0'!A<F%M(&%R<F%Y("`@("1A<G(@("`@("`@=&AE
M(')E9F5R96YC960@87)R87D@=&\@<'5T('1H92!D871A(&EN"B`@("`@*B!`
M<&%R86T@:6YT("`@("`@)&9E=&-H;6]D92!H;W<@=&AE(')E<W5L=&EN9R!A
M<G)A>2!S:&]U;&0@8F4@:6YD97AE9`H@("`@("H@0'!A<F%M(&EN="`@("`@
M("1R;W=N=6T@("`@=&AE(')O=R!N=6UB97(@=&\@9F5T8V@@*#`@/2!F:7)S
M="!R;W<I"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@1$)?3TL@;VX@
M<W5C8V5S<RP@3E5,3"!W:&5N('1H92!E;F0@;V8@82!R97-U;'0@<V5T(&ES
M"B`@("`@*B`@("`@("`@("`@("`@("`@<F5A8VAE9"!O<B!O;B!F86EL=7)E
M"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.F9E=&-H26YT;R@I"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&9E=&-H26YT;R@D<F5S=6QT+"`F)&%R<BP@
M)&9E=&-H;6]D92P@)')O=VYU;2`](&YU;&PI"B`@("!["B`@("`@("`@)&%R
M<B`](&%R<F%Y*"D["B`@("`@("`@:68@*"1R;W=N=6T@(3T](&YU;&PI('L*
M("`@("`@("`@("`@)')O=VYU;2LK.R`O+R!/1$)#(&9I<G-T(')O=R!I<R`Q
M"B`@("`@("`@("`@(&EF("AV97)S:6]N7V-O;7!A<F4H<&AP=F5R<VEO;B@I
M+"`G-"XR+C`G+"`G9V4G*2D@>PH@("`@("`@("`@("`@("`@)&-O;',@/2!`
M;V1B8U]F971C:%]I;G1O*"1R97-U;'0L("1A<G(L("1R;W=N=6TI.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&-O;',@/2!`;V1B
M8U]F971C:%]I;G1O*"1R97-U;'0L("1R;W=N=6TL("1A<G(I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&-O;',@/2!`
M;V1B8U]F971C:%]I;G1O*"1R97-U;'0L("1A<G(I.PH@("`@("`@('T*("`@
M("`@("!I9B`H(21C;VQS*2!["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@
M("`@("`@('T*("`@("`@("!I9B`H)&9E=&-H;6]D92`A/3T@1$)?1D540TA-
M3T1%7T]21$52140I('L*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@
M8V]U;G0H)&%R<BD[("1I*RLI('L*("`@("`@("`@("`@("`@("1C;VQ.86UE
M(#T@0&]D8F-?9FEE;&1?;F%M92@D<F5S=6QT+"`D:2LQ*3L*("`@("`@("`@
M("`@("`@("1A6R1C;VQ.86UE72`]("1A<G);)&E=.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG
M72`F($1"7U!/4E1!0DE,25197TQ/5T520T%312D@>PH@("`@("`@("`@("`@
M("`@)&$@/2!A<G)A>5]C:&%N9V5?:V5Y7V-A<V4H)&$L($-!4T5?3$]715(I
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1A<G(@/2`D83L*("`@("`@
M("!]"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==
M("8@1$)?4$]25$%"24Q)5%E?4E1224TI('L*("`@("`@("`@("`@)'1H:7,M
M/E]R=')I;4%R<F%Y5F%L=65S*"1A<G(I.PH@("`@("`@('T*("`@("`@("!I
M9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))
M3$E465].54Q,7U1/7T5-4%19*2!["B`@("`@("`@("`@("1T:&ES+3Y?8V]N
M=F5R=$YU;&Q!<G)A>59A;'5E<U1O16UP='DH)&%R<BD["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!F<F5E4F5S=6QT*"D*"B`@("`O*BH*("`@("`J($1E;&5T97,@=&AE
M(')E<W5L="!S970@86YD(&9R965S('1H92!M96UO<GD@;V-C=7!I960@8GD@
M=&AE(')E<W5L="!S970*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N
M;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$
M0E]R97-U;'0Z.F9R964H*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R
M960@(G!R;W1E8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@
M<V5P87)A=&4@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C
M92`D<F5S=6QT("!02%`G<R!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VP@(%12544@;VX@<W5C8V5S<RP@1D%,4T4@
M:68@)')E<W5L="!I<R!I;G9A;&ED"B`@("`@*@H@("`@("H@0'-E92!$0E]R
M97-U;'0Z.F9R964H*0H@("`@("HO"B`@("!F=6YC=&EO;B!F<F5E4F5S=6QT
M*"1R97-U;'0I"B`@("!["B`@("`@("`@<F5T=7)N($!O9&)C7V9R965?<F5S
M=6QT*"1R97-U;'0I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YU
M;4-O;',H*0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@;G5M8F5R(&]F(&-O
M;'5M;G,@:6X@82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@5&AI<R!M971H
M;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@
M("`@("H@1$)?<F5S=6QT.CIN=6U#;VQS*"D@:6YS=&5A9"X@($ET(&-A;B=T
M(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E($1"7W)E
M<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R
M86T@<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@<75E<GD@<F5S=6QT(')E<V]U
M<F-E"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB97(@;V8@
M8V]L=6UN<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@
M*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.FYU;4-O;',H*0H@("`@("HO"B`@
M("!F=6YC=&EO;B!N=6U#;VQS*"1R97-U;'0I"B`@("!["B`@("`@("`@)&-O
M;',@/2!`;V1B8U]N=6U?9FEE;&1S*"1R97-U;'0I.PH@("`@("`@(&EF("@A
M)&-O;',I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YO9&)C4F%I<V5%
M<G)O<B@I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&-O;',["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@869F96-T9612;W=S*"D*"B`@("`O
M*BH*("`@("`J($1E=&5R;6EN97,@=&AE(&YU;6)E<B!O9B!R;W=S(&%F9F5C
M=&5D(&)Y(&$@9&%T82!M86YI=7!L871I;VX@<75E<GD*("`@("`J"B`@("`@
M*B`P(&ES(')E='5R;F5D(&9O<B!Q=65R:65S('1H870@9&]N)W0@;6%N:7!U
M;&%T92!D871A+@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;G5M
M8F5R(&]F(')O=W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!A9F9E8W1E9%)O=W,H*0H@("`@>PH@("`@
M("`@(&EF("AE;7!T>2@D=&AI<RT^869F96-T960I*2![("`O+R!);B!C87-E
M(&]F(%-%3$5#5"!S=&US"B`@("`@("`@("`@(')E='5R;B`P.PH@("`@("`@
M('T*("`@("`@("`D;G)O=W,@/2!`;V1B8U]N=6U?<F]W<R@D=&AI<RT^869F
M96-T960I.PH@("`@("`@(&EF("@D;G)O=W,@/3T@+3$I('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YO9&)C4F%I<V5%<G)O<B@I.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@)&YR;W=S.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&YU;5)O=W,H*0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@;G5M
M8F5R(&]F(')O=W,@:6X@82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@3F]T
M(&%L;"!/1$)#(&1R:79E<G,@<W5P<&]R="!T:&ES(&9U;F-T:6]N86QI='DN
M("!)9B!T:&5Y(&1O;B=T"B`@("`@*B!A($1"7T5R<F]R(&]B:F5C="!F;W(@
M1$)?15)23U)?54Y355!03U)4140@:7,@<F5T=7)N960N"B`@("`@*@H@("`@
M("H@5&AI<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E
M8W1L>2X@(%5S90H@("`@("H@1$)?<F5S=6QT.CIN=6U2;W=S*"D@:6YS=&5A
M9"X@($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B
M96-A=7-E($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J
M"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@<75E<GD@
M<F5S=6QT(')E<V]U<F-E"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H
M92!N=6UB97(@;V8@<F]W<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.FYU;5)O=W,H*0H@
M("`@("HO"B`@("!F=6YC=&EO;B!N=6U2;W=S*"1R97-U;'0I"B`@("!["B`@
M("`@("`@)&YR;W=S(#T@0&]D8F-?;G5M7W)O=W,H)')E<W5L="D["B`@("`@
M("`@:68@*"1N<F]W<R`]/2`M,2D@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/F]D8F-286ES945R<F]R*$1"7T524D]27U5.4U504$]25$5$*3L*("`@
M("`@("!]"B`@("`@("`@:68@*"1N<F]W<R`]/3T@9F%L<V4I('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YO9&)C4F%I<V5%<G)O<B@I.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)&YR;W=S.PH@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[('%U;W1E261E;G1I9FEE<B@I"@H@("`@+RHJ"B`@("`@*B!1
M=6]T97,@82!S=')I;F<@<V\@:70@8V%N(&)E('-A9F5L>2!U<V5D(&%S(&$@
M=&%B;&4@;W(@8V]L=6UN(&YA;64*("`@("`J"B`@("`@*B!5<V4@)VUS<W%L
M)R!A<R!T:&4@9&)S>6YT87@@:6X@=&AE($1"($133B!O;FQY(&EF('EO=2=V
M92!U;F-H96-K960*("`@("`J(")5<V4@04Y322!Q=6]T960@:61E;G1I9FEE
M<G,B('=H96X@<V5T=&EN9R!U<"!T:&4@3T1"0R!D871A('-O=7)C92X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S='(@(&ED96YT:69I97(@;F%M
M92!T;R!B92!Q=6]T960*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M<75O=&5D(&ED96YT:69I97(@<W1R:6YG"B`@("`@*@H@("`@("H@0'-E92!$
M0E]C;VUM;VXZ.G%U;W1E261E;G1I9FEE<B@I"B`@("`@*B!`<VEN8V4@365T
M:&]D(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-BXP"B`@("`@*B\*("`@
M(&9U;F-T:6]N('%U;W1E261E;G1I9FEE<B@D<W1R*0H@("`@>PH@("`@("`@
M('-W:71C:"`H)'1H:7,M/F1S;ELG9&)S>6YT87@G72D@>PH@("`@("`@("`@
M("!C87-E("=A8V-E<W,G.@H@("`@("`@("`@("`@("`@<F5T=7)N("=;)R`N
M("1S='(@+B`G72<["B`@("`@("`@("`@(&-A<V4@)VUS<W%L)SH*("`@("`@
M("`@("`@8V%S92`G<WEB87-E)SH*("`@("`@("`@("`@("`@(')E='5R;B`G
M6R<@+B!S=')?<F5P;&%C92@G72<L("==72<L("1S='(I("X@)UTG.PH@("`@
M("`@("`@("!C87-E("=M>7-Q;"<Z"B`@("`@("`@("`@(&-A<V4@)VUY<W%L
M:2<Z"B`@("`@("`@("`@("`@("!R971U<FX@)V`G("X@)'-T<B`N("=@)SL*
M("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@(')E='5R;B`G
M(B<@+B!S=')?<F5P;&%C92@G(B<L("<B(B<L("1S='(I("X@)R(G.PH@("`@
M("`@('T*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!Q=6]T92@I"@H@
M("`@+RHJ"B`@("`@*B!`9&5P<F5C871E9"`@1&5P<F5C871E9"!I;B!R96QE
M87-E(#$N-BXP"B`@("`@*B!`:6YT97)N86P*("`@("`J+PH@("`@9G5N8W1I
M;VX@<75O=&4H)'-T<BD*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G%U
M;W1E4VUA<G0H)'-T<BD["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M;F5X=$ED*"D*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&YE>'0@9G)E
M92!I9"!I;B!A('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`@)'-E<5]N86UE("!N86UE(&]F('1H92!S97%U96YC90H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)&]N9&5M86YD("!W:&5N('1R=64L('1H92!S97%E;F-E
M(&ES(&%U=&]M871I8V%L;'D*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&-R96%T960@:68@:70@9&]E<R!N;W0@97AI<W0*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&EN="`@=&AE(&YE>'0@:60@;G5M8F5R(&EN('1H92!S
M97%U96YC92X*("`@("`J("`@("`@("`@("`@("`@02!$0E]%<G)O<B!O8FIE
M8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ
M;F5X=$E$*"DL($1"7V-O;6UO;CHZ9V5T4V5Q=65N8V5.86UE*"DL"B`@("`@
M*B`@("`@($1"7V]D8F,Z.F-R96%T95-E<75E;F-E*"DL($1"7V]D8F,Z.F1R
M;W!397%U96YC92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&YE>'1)9"@D<V5Q
M7VYA;64L("1O;F1E;6%N9"`]('1R=64I"B`@("!["B`@("`@("`@)'-E<6YA
M;64@/2`D=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S97%?;F%M92D["B`@("`@
M("`@)')E<&5A="`](#`["B`@("`@("`@9&\@>PH@("`@("`@("`@("`D=&AI
M<RT^<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PH@("`@
M("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/G%U97)Y*")U<&1A=&4@)'MS97%N
M86UE?2!S970@:60@/2!I9"`K(#$B*3L*("`@("`@("`@("`@)'1H:7,M/G!O
M<$5R<F]R2&%N9&QI;F<H*3L*("`@("`@("`@("`@:68@*"1O;F1E;6%N9"`F
M)B!$0CHZ:7-%<G)O<B@D<F5S=6QT*2`F)@H@("`@("`@("`@("`@("`@)')E
M<W5L="T^9V5T0V]D92@I(#T]($1"7T524D]27TY/4U5#2%1!0DQ%*2!["B`@
M("`@("`@("`@("`@("`D<F5P96%T(#T@,3L*("`@("`@("`@("`@("`@("1T
M:&ES+3YP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD["B`@
M("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F-R96%T95-E<75E;F-E
M*"1S97%?;F%M92D["B`@("`@("`@("`@("`@("`D=&AI<RT^<&]P17)R;W)(
M86YD;&EN9R@I.PH@("`@("`@("`@("`@("`@:68@*$1".CII<T5R<F]R*"1R
M97-U;'0I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*"1R97-U;'0I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@)')E<W5L="`]("1T:&ES+3YQ=65R>2@B:6YS97)T(&EN=&\@
M)'MS97%N86UE?2`H:60I('9A;'5E<R@P*2(I.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)')E<&5A="`](#`["B`@("`@("`@("`@
M('T*("`@("`@("!]('=H:6QE("@D<F5P96%T*3L*"B`@("`@("`@:68@*$1"
M.CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@D<F5S=6QT*3L*("`@("`@("!]"@H@("`@("`@("1R
M97-U;'0@/2`D=&AI<RT^<75E<GDH(G-E;&5C="!I9"!F<F]M("1[<V5Q;F%M
M97TB*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`D
M<F]W(#T@)')E<W5L="T^9F5T8VA2;W<H1$)?1D540TA-3T1%7T]21$52140I
M.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F]W('Q\("$D<F]W*2D@>PH@
M("`@("`@("`@("!R971U<FX@)')O=SL*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D<F]W6S!=.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E<R!A
M(&YE=R!S97%U96YC90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-E
M<5]N86UE("!N86UE(&]F('1H92!N97<@<V5Q=65N8V4*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM
M;VXZ.F-R96%T95-E<75E;F-E*"DL($1"7V-O;6UO;CHZ9V5T4V5Q=65N8V5.
M86UE*"DL"B`@("`@*B`@("`@($1"7V]D8F,Z.FYE>'1)1"@I+"!$0E]O9&)C
M.CID<F]P4V5Q=65N8V4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!C<F5A=&53
M97%U96YC92@D<V5Q7VYA;64I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3YQ=65R>2@G0U)%051%(%1!0DQ%("<*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("X@)'1H:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`N("<@*&ED(&EN=&5G97(@3D]4
M($Y53$PL)PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G(%!224U!
M4ED@2T59*&ED*2DG*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!D
M<F]P4V5Q=65N8V4H*0H*("`@("\J*@H@("`@("H@1&5L971E<R!A('-E<75E
M;F-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5Q7VYA;64@(&YA
M;64@;V8@=&AE('-E<75E;F-E('1O(&)E(&1E;&5T960*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM
M;VXZ.F1R;W!397%U96YC92@I+"!$0E]C;VUM;VXZ.F=E=%-E<75E;F-E3F%M
M92@I+`H@("`@("H@("`@("!$0E]O9&)C.CIN97AT240H*2P@1$)?;V1B8SHZ
M8W)E871E4V5Q=65N8V4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!D<F]P4V5Q
M=65N8V4H)'-E<5]N86UE*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M<75E<GDH)T123U`@5$%"3$4@)R`N("1T:&ES+3YG971397%U96YC94YA;64H
M)'-E<5]N86UE*2D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@875T
M;T-O;6UI="@I"@H@("`@+RHJ"B`@("`@*B!%;F%B;&5S(&]R(&1I<V%B;&5S
M(&%U=&]M871I8R!C;VUM:71S"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VP@
M)&]N;V9F("!T<G5E('1U<FYS(&ET(&]N+"!F86QS92!T=7)N<R!I="!O9F8*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@
M($$@1$)?17)R;W(@;V)J96-T(&EF('1H92!D<FEV97(*("`@("`J("`@("`@
M("`@("`@("`@9&]E<VXG="!S=7!P;W)T(&%U=&\M8V]M;6ET=&EN9R!T<F%N
M<V%C=&EO;G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%U=&]#;VUM:70H)&]N
M;V9F(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"%`;V1B8U]A=71O8V]M
M;6ET*"1T:&ES+3YC;VYN96-T:6]N+"`D;VYO9F8I*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^;V1B8U)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&-O;6UI="@I"@H@("`@+RHJ"B`@("`@*B!#;VUM:71S('1H92!C=7)R
M96YT('1R86YS86-T:6]N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"
M7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VUM:70H*0H@("`@>PH@("`@("`@
M(&EF("@A0&]D8F-?8V]M;6ET*"1T:&ES+3YC;VYN96-T:6]N*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/F]D8F-286ES945R<F]R*"D["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!R;VQL8F%C:R@I"@H@("`@+RHJ"B`@("`@*B!2979E<G1S
M('1H92!C=7)R96YT('1R86YS86-T:6]N"B`@("`@*@H@("`@("H@0')E='5R
M;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O
M;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R;VQL8F%C:R@I"B`@
M("!["B`@("`@("`@:68@*"%`;V1B8U]R;VQL8F%C:R@D=&AI<RT^8V]N;F5C
M=&EO;BDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YO9&)C4F%I<V5%
M<G)O<B@I.PH@("`@("`@('T*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;V1B8U)A:7-E17)R;W(H*0H*("`@
M("\J*@H@("`@("H@4')O9'5C97,@82!$0E]%<G)O<B!O8FIE8W0@<F5G87)D
M:6YG('1H92!C=7)R96YT('!R;V)L96T*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT("1E<G)N;R`@:68@=&AE(&5R<F]R(&ES(&)E:6YG(&UA;G5A;&QY(')A
M:7-E9"!P87-S(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@1$)?15)2
M3U(J(&-O;G-T86YT(&AE<F4N("!)9B!T:&ES(&ES;B=T('!A<W-E9`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("!T:&4@97)R;W(@:6YF;W)M871I;VX@
M9V%T:&5R960@9G)O;2!T:&4@1$)-4RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&]B:F5C="`@=&AE($1"7T5R<F]R(&]B:F5C=`H@("`@("H*("`@("`J($!S
M964@1$)?8V]M;6]N.CIR86ES945R<F]R*"DL"B`@("`@*B`@("`@($1"7V]D
M8F,Z.F5R<F]R3F%T:79E*"DL($1"7V-O;6UO;CHZ97)R;W)#;V1E*"D*("`@
M("`J+PH@("`@9G5N8W1I;VX@;V1B8U)A:7-E17)R;W(H)&5R<FYO(#T@;G5L
M;"D*("`@('L*("`@("`@("!I9B`H)&5R<FYO(#T]/2!N=6QL*2!["B`@("`@
M("`@("`@('-W:71C:"`H)'1H:7,M/F1B<WEN=&%X*2!["B`@("`@("`@("`@
M("`@("!C87-E("=A8V-E<W,G.@H@("`@("`@("`@("`@("`@("`@(&EF("@D
M=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,2519
M7T524D]24RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^97)R
M;W)C;V1E7VUA<%LG,#<P,#$G72`]($1"7T524D]27TY/4U5#2$9)14Q$.PH@
M("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@("`@("\O($1O:6YG('1H:7,@:6X@8V%S92!M;V1E(&-H86YG97,@9'5R
M:6YG(')U;G1I;64N"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YE
M<G)O<F-O9&5?;6%P6R<P-S`P,2==(#T@1$)?15)23U)?34E334%40T@["B`@
M("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@("`D;F%T
M:79E7V-O9&4@/2!O9&)C7V5R<F]R*"1T:&ES+3YC;VYN96-T:6]N*3L*"B`@
M("`@("`@("`@("`@("`@("`@+R\@4S$P,#`@:7,@9F]R(")'96YE<F%L($5R
M<F]R+B(@($QE="=S(&)E(&UO<F4@<W!E8VEF:6,N"B`@("`@("`@("`@("`@
M("`@("`@:68@*"1N871I=F5?8V]D92`]/2`G4S$P,#`G*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1E<G)O<FUS9R`](&]D8F-?97)R;W)M<V<H)'1H
M:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@("`@("`@("`@("`@("!S=&%T
M:6,@)&5R<F]R7W)E9V5X<',["B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)&5R<F]R7W)E9V5X<',I*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D97)R;W)?<F5G97AP<R`](&%R<F%Y*`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("<O:6YC;'5D97,@<F5L871E9"!R96-O
M<F1S+B0O:2<@(#T^($1"7T524D]27T-/3E-44D%)3E0L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)R]C86YN;W0@8V]N=&%I;B!A($YU;&P@
M=F%L=64O:2<@/3X@1$)?15)23U)?0T].4U1204E.5%].3U1?3E5,3"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&5R
M<F]R7W)E9V5X<',@87,@)')E9V5X<"`]/B`D8V]D92D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)')E9V5X<"P@)&5R
M<F]R;7-G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D8V]D92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&YU;&PL(&YU;&PL(&YU;&PL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F%T:79E
M7V-O9&4@+B`G("<@+B`D97)R;W)M<V<I.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@("`@("1E<G)N;R`]($1"7T524D]2.PH@("`@("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1E
M<G)N;R`]("1T:&ES+3YE<G)O<D-O9&4H)&YA=&EV95]C;V1E*3L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@("`@("1E
M<G)N;R`]("1T:&ES+3YE<G)O<D-O9&4H;V1B8U]E<G)O<B@D=&AI<RT^8V]N
M;F5C=&EO;BDI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D97)R;F\L(&YU;&PL(&YU;&PL(&YU
M;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YE
M<G)O<DYA=&EV92@I*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!E
M<G)O<DYA=&EV92@I"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!$0DU3)R!N
M871I=F4@97)R;W(@8V]D92!A;F0@;65S<V%G92!P<F]D=6-E9"!B>2!T:&4@
M;&%S="!Q=65R>0H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@
M1$)-4R<@97)R;W(@8V]D92!A;F0@;65S<V%G90H@("`@("HO"B`@("!F=6YC
M=&EO;B!E<G)O<DYA=&EV92@I"B`@("!["B`@("`@("`@:68@*"%I<U]R97-O
M=7)C92@D=&AI<RT^8V]N;F5C=&EO;BDI('L*("`@("`@("`@("`@<F5T=7)N
M($!O9&)C7V5R<F]R*"D@+B`G("<@+B!`;V1B8U]E<G)O<FUS9R@I.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@0&]D8F-?97)R;W(H)'1H:7,M/F-O;FYE
M8W1I;VXI("X@)R`G("X@0&]D8F-?97)R;W)M<V<H)'1H:7,M/F-O;FYE8W1I
M;VXI.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('1A8FQE26YF;R@I
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&EN9F]R;6%T:6]N(&%B;W5T(&$@
M=&%B;&4@;W(@82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@0'!A<F%M(&]B
M:F5C='QS=')I;F<@("1R97-U;'0@($1"7W)E<W5L="!O8FIE8W0@9G)O;2!A
M('%U97)Y(&]R(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<W1R:6YG(&-O;G1A:6YI;F<@=&AE(&YA;64@;V8@82!T86)L92X*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@5VAI;&4@
M=&AI<R!A;'-O(&%C8V5P=',@82!Q=65R>2!R97-U;'0*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5S;W5R8V4@:61E;G1I9FEE
M<BP@=&AI<R!B96AA=FEO<B!I<PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!D97!R96-A=&5D+@H@("`@("H@0'!A<F%M(&EN="`@
M("`@("`@("`@("1M;V1E("`@(&$@=F%L:60@=&%B;&5);F9O(&UO9&4*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!A;B!A<W-O8VEA=&EV92!A<G)A
M>2!W:71H('1H92!I;F9O<FUA=&EO;B!R97%U97-T960N"B`@("`@*B`@("`@
M("`@("`@("`@("`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@
M("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ=&%B;&5);F9O*"D*("`@("`J
M($!S:6YC92!-971H;V0@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XW+C`*
M("`@("`J+PH@("`@9G5N8W1I;VX@=&%B;&5);F9O*"1R97-U;'0L("1M;V1E
M(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?<W1R:6YG*"1R97-U;'0I
M*2!["B`@("`@("`@("`@("\J"B`@("`@("`@("`@("`J(%!R;V)A8FQY(')E
M8V5I=F5D(&$@=&%B;&4@;F%M92X*("`@("`@("`@("`@("H@0W)E871E(&$@
M<F5S=6QT(')E<V]U<F-E(&ED96YT:69I97(N"B`@("`@("`@("`@("`J+PH@
M("`@("`@("`@("`D:60@/2!`;V1B8U]E>&5C*"1T:&ES+3YC;VYN96-T:6]N
M+"`B4T5,14-4("H@1E)/32`D<F5S=6QT(BD["B`@("`@("`@("`@(&EF("@A
M)&ED*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/F]D8F-286ES
M945R<F]R*"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&=O=%]S=')I
M;F<@/2!T<G5E.PH@("`@("`@('T@96QS96EF("AI<W-E="@D<F5S=6QT+3YR
M97-U;'0I*2!["B`@("`@("`@("`@("\J"B`@("`@("`@("`@("`J(%!R;V)A
M8FQY(')E8V5I=F5D(&$@<F5S=6QT(&]B:F5C="X*("`@("`@("`@("`@("H@
M17AT<F%C="!T:&4@<F5S=6QT(')E<V]U<F-E(&ED96YT:69I97(N"B`@("`@
M("`@("`@("`J+PH@("`@("`@("`@("`D:60@/2`D<F5S=6QT+3YR97-U;'0[
M"B`@("`@("`@("`@("1G;W1?<W1R:6YG(#T@9F%L<V4["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@+RH*("`@("`@("`@("`@("H@4')O8F%B;'D@
M<F5C96EV960@82!R97-U;'0@<F5S;W5R8V4@:61E;G1I9FEE<BX*("`@("`@
M("`@("`@("H@0V]P>2!I="X*("`@("`@("`@("`@("H@1&5P<F5C871E9"X@
M($AE<F4@9F]R(&-O;7!A=&EB:6QI='D@;VYL>2X*("`@("`@("`@("`@("HO
M"B`@("`@("`@("`@("1I9"`]("1R97-U;'0["B`@("`@("`@("`@("1G;W1?
M<W1R:6YG(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES7W)E
M<V]U<F-E*"1I9"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YO9&)C
M4F%I<V5%<G)O<BA$0E]%4E)/4E].145$7TU/4D5?1$%402D["B`@("`@("`@
M?0H*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@
M)B!$0E]03U)404))3$E465],3U=%4D-!4T4I('L*("`@("`@("`@("`@)&-A
M<V5?9G5N8R`]("=S=')T;VQO=V5R)SL*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D8V%S95]F=6YC(#T@)W-T<G9A;"<["B`@("`@("`@?0H*("`@
M("`@("`D8V]U;G0@/2!`;V1B8U]N=6U?9FEE;&1S*"1I9"D["B`@("`@("`@
M)')E<R`@(#T@87)R87DH*3L*"B`@("`@("`@:68@*"1M;V1E*2!["B`@("`@
M("`@("`@("1R97-;)VYU;5]F:65L9',G72`]("1C;W5N=#L*("`@("`@("!]
M"@H@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1C;W5N=#L@)&DK*RD@>PH@
M("`@("`@("`@("`D8V]L(#T@)&D@*R`Q.PH@("`@("`@("`@("`D<F5S6R1I
M72`](&%R<F%Y*`H@("`@("`@("`@("`@("`@)W1A8FQE)R`]/B`D9V]T7W-T
M<FEN9R`_("1C87-E7V9U;F,H)')E<W5L="D@.B`G)RP*("`@("`@("`@("`@
M("`@("=N86UE)R`@/3X@)&-A<V5?9G5N8RA`;V1B8U]F:65L9%]N86UE*"1I
M9"P@)&-O;"DI+`H@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B!`;V1B8U]F
M:65L9%]T>7!E*"1I9"P@)&-O;"DL"B`@("`@("`@("`@("`@("`G;&5N)R`@
M(#T^($!O9&)C7V9I96QD7VQE;B@D:60L("1C;VPI+`H@("`@("`@("`@("`@
M("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`@("`@*3L*("`@("`@("`@("`@
M:68@*"1M;V1E("8@1$)?5$%"3$5)3D9/7T]21$52*2!["B`@("`@("`@("`@
M("`@("`D<F5S6R=O<F1E<B==6R1R97-;)&E=6R=N86UE)UU=(#T@)&D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1M;V1E("8@1$)?5$%"3$5)
M3D9/7T]21$525$%"3$4I('L*("`@("`@("`@("`@("`@("1R97-;)V]R9&5R
M=&%B;&4G75LD<F5S6R1I75LG=&%B;&4G75U;)')E<ULD:5U;)VYA;64G75T@
M/2`D:3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@9G)E
M92!T:&4@<F5S=6QT(&]N;'D@:68@=V4@=V5R92!C86QL960@;VX@82!T86)L
M90H@("`@("`@(&EF("@D9V]T7W-T<FEN9RD@>PH@("`@("`@("`@("!`;V1B
M8U]F<F5E7W)E<W5L="@D:60I.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M)')E<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G9713<&5C:6%L
M475E<GDH*0H*("`@("\J*@H@("`@("H@3V)T86EN<R!T:&4@<75E<GD@<W1R
M:6YG(&YE961E9"!F;W(@;&ES=&EN9R!A(&=I=F5N('1Y<&4@;V8@;V)J96-T
M<PH@("`@("H*("`@("`J(%1H86YK<R!T;R!S>6UB;VPQ0&=M86EL+F-O;2!A
M;F0@4&AI;&EP<&4N2F%U<VEO;G-`,3%A8F%C=7,N8V]M+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'1Y<&4@('1H92!K:6YD(&]F(&]B:F5C=',@
M>6]U('=A;G0@=&\@<F5T<FEE=F4*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@=&AE(&QI<W0@;V8@;V)J96-T<R!R97%U97-T960*("`@("`J"B`@
M("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@("H@0'-E92!$0E]C;VUM;VXZ
M.F=E=$QI<W1/9B@I"B`@("`@*B!`<VEN8V4@365T:&]D(&%V86EL86)L92!S
M:6YC92!296QE87-E(#$N-RXP"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-P
M96-I86Q1=65R>2@D='EP92D*("`@('L*("`@("`@("!S=VET8V@@*"1T>7!E
M*2!["B`@("`@("`@("`@(&-A<V4@)V1A=&%B87-E<R<Z"B`@("`@("`@("`@
M("`@("!I9B`H(69U;F-T:6]N7V5X:7-T<R@G;V1B8U]D871A7W-O=7)C92<I
M*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`D<F5S(#T@0&]D8F-?9&%T85]S
M;W5R8V4H)'1H:7,M/F-O;FYE8W1I;VXL(%-13%]&151#2%]&25)35"D["B`@
M("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)')E<RDI('L*("`@("`@("`@
M("`@("`@("`@("`D;W5T(#T@87)R87DH)')E<ULG<V5R=F5R)UTI.PH@("`@
M("`@("`@("`@("`@("`@('=H:6QE*"1R97,@/2!`;V1B8U]D871A7W-O=7)C
M92@D=&AI<RT^8V]N;F5C=&EO;BP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@4U%,7T9%5$-(7TY%6%0I*0H@
M("`@("`@("`@("`@("`@("`@('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&]U=%M=(#T@)')E<ULG<V5R=F5R)UT["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D;W5T.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/F]D8F-286ES945R<F]R*"D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G=&%B;&5S)SH*
M("`@("`@("`@("`@8V%S92`G<V-H96UA+G1A8FQE<R<Z"B`@("`@("`@("`@
M("`@("`D:V5E<"`]("=404),12<["B`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@8V%S92`G=FEE=W,G.@H@("`@("`@("`@("`@("`@)&ME
M97`@/2`G5DE%5R<["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@9&5F875L=#H*("`@("`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@
M("`@('T*"B`@("`@("`@+RH*("`@("`@("`@*B!296UO=FEN9R!N;VXM8V]N
M9F]R;6EN9R!I=&5M<R!I;B!T:&4@=VAI;&4@;&]O<"!R871H97(@=&AA;@H@
M("`@("`@("`J(&EN('1H92!O9&)C7W1A8FQE<R@I(&-A;&P@8F5C875S92!S
M;VUE(&)A8VME;F1S(&-H;VME(&]N('1H:7,Z"B`@("`@("`@("H@("`@(&]D
M8F-?=&%B;&5S*"1T:&ES+3YC;VYN96-T:6]N+"`G)RP@)R<L("<G+"`G5$%"
M3$4G*0H@("`@("`@("`J+PH@("`@("`@("1R97,@(#T@0&]D8F-?=&%B;&5S
M*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("!I9B`H(21R97,I('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YO9&)C4F%I<V5%<G)O<B@I.PH@("`@
M("`@('T*("`@("`@("`D;W5T(#T@87)R87DH*3L*("`@("`@("!W:&EL92`H
M)')O=R`](&]D8F-?9F5T8VA?87)R87DH)')E<RDI('L*("`@("`@("`@("`@
M:68@*"1R;W=;)U1!0DQ%7U194$4G72`A/2`D:V5E<"D@>PH@("`@("`@("`@
M("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@
M*"1T>7!E(#T]("=S8VAE;6$N=&%B;&5S)RD@>PH@("`@("`@("`@("`@("`@
M)&]U=%M=(#T@)')O=ULG5$%"3$5?4T-(14TG72`N("<N)R`N("1R;W=;)U1!
M0DQ%7TY!344G73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1O=71;72`]("1R;W=;)U1!0DQ%7TY!344G73L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!R971U<FX@)&]U=#L*("`@('T*"B`@("`O
M+R!]?7T*"GT*"B\J"B`J($QO8V%L('9A<FEA8FQE<SH*("H@=&%B+7=I9'1H
M.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J($5N9#H*("HO"@H_/@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+T1"+W!G<W%L+G!H<```````````````````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`Q,#4V-3$@,3`U,34T,S,W,S$@,#(P-C(P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"@HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED
M=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J(%1H92!014%2($1"(&1R
M:79E<B!F;W(@4$A0)W,@<&=S<6P@97AT96YS:6]N"B`J(&9O<B!I;G1E<F%C
M=&EN9R!W:71H(%!O<W1G<F5344P@9&%T86)A<V5S"B`J"B`J(%!(4"!V97)S
M:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@
M:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*
M("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@
M8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@
M;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N
M;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C
M;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@
M*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!2=6D@2&ER;VMA=V$@
M/&AI<F]K87=A0'!H<"YN970^"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N
M(#QS<V)`<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O
M<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@
M5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I
M;VX@("`@0U93.B`D260Z('!G<W%L+G!H<"QV(#$N,3(V(#(P,#4O,#,O,#0@
M,C,Z,3(Z,S8@9&%N:65L8R!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO"@HO*BH*("H@3V)T86EN('1H
M92!$0E]C;VUM;VX@8VQA<W,@<V\@:70@8V%N(&)E(&5X=&5N9&5D(&9R;VT*
M("HO"G)E<75I<F5?;VYC92`G1$(O8V]M;6]N+G!H<"<["@HO*BH*("H@5&AE
M(&UE=&AO9',@4$5!4B!$0B!U<V5S('1O(&EN=&5R86-T('=I=&@@4$A0)W,@
M<&=S<6P@97AT96YS:6]N"B`J(&9O<B!I;G1E<F%C=&EN9R!W:71H(%!O<W1G
M<F5344P@9&%T86)A<V5S"B`J"B`J(%1H97-E(&UE=&AO9',@;W9E<FQO860@
M=&AE(&]N97,@9&5C;&%R960@:6X@1$)?8V]M;6]N+@H@*@H@*B!`8V%T96=O
M<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@
M("!2=6D@2&ER;VMA=V$@/&AI<F]K87=A0'!H<"YN970^"B`J($!A=71H;W(@
M("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@
M1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I
M9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS
M92`S+C`*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XW+C8*("H@0&QI;FL@
M("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J+PIC;&%S
M<R!$0E]P9W-Q;"!E>'1E;F1S($1"7V-O;6UO;@I["B`@("`O+R![>WL@<')O
M<&5R=&EE<PH*("`@("\J*@H@("`@("H@5&AE($1"(&1R:79E<B!T>7!E("AM
M>7-Q;"P@;V-I."P@;V1B8RP@971C+BD*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D<&AP='EP92`]("=P9W-Q;"<["@H@("`@+RHJ"B`@
M("`@*B!4:&4@9&%T86)A<V4@<WEN=&%X('9A<FEA;G0@=&\@8F4@=7-E9"`H
M9&(R+"!A8V-E<W,L(&5T8RXI+"!I9B!A;GD*("`@("`J($!V87(@<W1R:6YG
M"B`@("`@*B\*("`@('9A<B`D9&)S>6YT87@@/2`G<&=S<6PG.PH*("`@("\J
M*@H@("`@("H@5&AE(&-A<&%B:6QI=&EE<R!O9B!T:&ES($1"(&EM<&QE;65N
M=&%T:6]N"B`@("`@*@H@("`@("H@5&AE("=N97=?;&EN:R<@96QE;65N="!C
M;VYT86EN<R!T:&4@4$A0('9E<G-I;VX@=&AA="!F:7)S="!P<F]V:61E9`H@
M("`@("H@;F5W7VQI;FL@<W5P<&]R="!F;W(@=&AI<R!$0DU3+B`@0V]N=&%I
M;G,@9F%L<V4@:68@:70G<R!U;G-U<'!O<G1E9"X*("`@("`J"B`@("`@*B!-
M96%N:6YG(&]F('1H92`G;&EM:70G(&5L96UE;G0Z"B`@("`@*B`@("L@)V5M
M=6QA=&4G(#T@96UU;&%T92!W:71H(&9E=&-H(')O=R!B>2!N=6UB97(*("`@
M("`J("`@*R`G86QT97(G("`@/2!A;'1E<B!T:&4@<75E<GD*("`@("`J("`@
M*R!F86QS92`@("`@/2!S:VEP(')O=W,*("`@("`J"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D9F5A='5R97,@/2!A<G)A>2@*("`@("`@
M("`G;&EM:70G("`@("`@("`@/3X@)V%L=&5R)RP*("`@("`@("`G;F5W7VQI
M;FLG("`@("`@/3X@)S0N,RXP)RP*("`@("`@("`G;G5M<F]W<R<@("`@("`@
M/3X@=')U92P*("`@("`@("`G<&-O;FYE8W0G("`@("`@/3X@=')U92P*("`@
M("`@("`G<')E<&%R92<@("`@("`@/3X@9F%L<V4L"B`@("`@("`@)W-S;"<@
M("`@("`@("`@(#T^('1R=64L"B`@("`@("`@)W1R86YS86-T:6]N<R<@(#T^
M('1R=64L"B`@("`I.PH*("`@("\J*@H@("`@("H@02!M87!P:6YG(&]F(&YA
M=&EV92!E<G)O<B!C;V1E<R!T;R!$0B!E<G)O<B!C;V1E<PH@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&5R<F]R8V]D95]M87`@/2!A<G)A
M>2@*("`@("D["@H@("`@+RHJ"B`@("`@*B!4:&4@<F%W(&1A=&%B87-E(&-O
M;FYE8W1I;VX@8W)E871E9"!B>2!02%`*("`@("`J($!V87(@<F5S;W5R8V4*
M("`@("`J+PH@("`@=F%R("1C;VYN96-T:6]N.PH*("`@("\J*@H@("`@("H@
M5&AE($133B!I;F9O<FUA=&EO;B!F;W(@8V]N;F5C=&EN9R!T;R!A(&1A=&%B
M87-E"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D9'-N(#T@
M87)R87DH*3L*"@H@("`@+RHJ"B`@("`@*B!3:&]U;&0@9&%T82!M86YI<'5L
M871I;VX@<75E<FEE<R!B92!C;VUM:71T960@875T;VUA=&EC86QL>3\*("`@
M("`J($!V87(@8F]O;`H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@('9A<B`D875T;V-O;6UI="`]('1R=64["@H@("`@+RHJ"B`@("`@*B!4
M:&4@<75A;G1I='D@;V8@=')A;G-A8W1I;VYS(&)E9W5N"B`@("`@*@H@("`@
M("H@>T!I;G1E<FYA;"`@5VAI;&4@=&AI<R!I<R!P<FEV871E+"!I="!C86XG
M="!A8W1U86QL>2!B92!D97-I9VYA=&5D"B`@("`@*B!P<FEV871E(&EN(%!(
M4"`U(&)E8V%U<V4@:70@:7,@9&ER96-T;'D@86-C97-S960@:6X@=&AE('1E
M<W0@<W5I=&4N?7T*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)'1R86YS86-T:6]N
M7V]P8V]U;G0@/2`P.PH*("`@("\J*@H@("`@("H@5&AE(&YU;6)E<B!O9B!R
M;W=S(&%F9F5C=&5D(&)Y(&$@9&%T82!M86YI<'5L871I;VX@<75E<GD*("`@
M("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)&%F9F5C=&5D(#T@
M,#L*"B`@("`O*BH*("`@("`J(%1H92!C=7)R96YT(')O=R!B96EN9R!L;V]K
M960@870@:6X@9F5T8VA);G1O*"D*("`@("`J($!V87(@87)R87D*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)')O=R`](&%R<F%Y
M*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@;G5M8F5R(&]F(')O=W,@:6X@82!G
M:79E;B!R97-U;'0@<V5T"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?;G5M7W)O=W,@/2!A<G)A
M>2@I.PH*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VYS=')U8W1O<@H*("`@
M("\J*@H@("`@("H@5&AI<R!C;VYS=')U8W1O<B!C86QL<R`\:V)D/B1T:&ES
M+3Y$0E]C;VUM;VXH*3PO:V)D/@H@("`@("H*("`@("`J($!R971U<FX@=F]I
M9`H@("`@("HO"B`@("!F=6YC=&EO;B!$0E]P9W-Q;"@I"B`@("!["B`@("`@
M("`@)'1H:7,M/D1"7V-O;6UO;B@I.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&-O;FYE8W0H*0H*("`@("\J*@H@("`@("H@0V]N;F5C="!T;R!T
M:&4@9&%T86)A<V4@<V5R=F5R+"!L;V<@:6X@86YD(&]P96X@=&AE(&1A=&%B
M87-E"B`@("`@*@H@("`@("H@1&]N)W0@8V%L;"!T:&ES(&UE=&AO9"!D:7)E
M8W1L>2X@(%5S92!$0CHZ8V]N;F5C="@I(&EN<W1E860N"B`@("`@*@H@("`@
M("H@4$5!4B!$0B=S('!G<W%L(&1R:79E<B!S=7!P;W)T<R!T:&4@9F]L;&]W
M:6YG(&5X=')A($133B!O<'1I;VYS.@H@("`@("H@("`K(&-O;FYE8W1?=&EM
M96]U="`@2&]W(&UA;GD@<V5C;VYD<R!T;R!W86ET(&9O<B!A(&-O;FYE8W1I
M;VX@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!B92!E<W1A8FQI
M<VAE9"X@($%V86EL86)L92!S:6YC92!014%2($1"(#$N-RXP+@H@("`@("H@
M("`K(&YE=U]L:6YK("`@("`@("`@268@<V5T('1O('1R=64L(&-A=7-E<R!S
M=6)S97%U96YT(&-A;&QS('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@8V]N;F5C="@I('1O(')E='5R;B!A(&YE=R!C;VYN96-T:6]N(&QI;FL*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!I;G-T96%D(&]F('1H92!E
M>&ES=&EN9R!O;F4N("!705).24Y'.B!T:&ES(&ES"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@;F]T('!O<G1A8FQE('1O(&]T:&5R($1"35,G<RX@
M($%V86EL86)L92!O;FQY"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M:68@4$A0(&ES(#X](#0N,RXP(&%N9"!014%2($1"(&ES(#X](#$N-RXP+@H@
M("`@("H@("`K(&]P=&EO;G,@("`@("`@("`@0V]M;6%N9"!L:6YE(&]P=&EO
M;G,@=&\@8F4@<V5N="!T;R!T:&4@<V5R=F5R+@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@($%V86EL86)L92!S:6YC92!014%2($1"(#$N-BXT+@H@
M("`@("H@("`K('-E<G9I8V4@("`@("`@("`@4W!E8VEF:65S(&$@<V5R=FEC
M92!N86UE(&EN('!G7W-E<G9I8V4N8V]N9B!T:&%T"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@:&]L9',@861D:71I;VYA;"!C;VYN96-T:6]N('!A
M<F%M971E<G,N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@079A:6QA
M8FQE('-I;F-E(%!%05(@1$(@,2XW+C`N"B`@("`@*B`@("L@<W-L;6]D92`@
M("`@("`@("!(;W<@<VAO=6QD(%-33"!B92!U<V5D('=H96X@8V]N;F5C=&EN
M9S\@(%9A;'5E<SH*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!D:7-A
M8FQE+"!A;&QO=RP@<')E9F5R(&]R(')E<75I<F4N"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@079A:6QA8FQE('-I;F-E(%!%05(@1$(@,2XW+C`N
M"B`@("`@*B`@("L@='1Y("`@("`@("`@("`@("!4:&ES('=A<R!U<V5D('1O
M('-P96-I9GD@=VAE<F4@=&\@<V5N9"!S97)V97(*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!D96)U9R!O=71P=70N("!!=F%I;&%B;&4@<VEN8V4@
M4$5!4B!$0B`Q+C8N-"X*("`@("`J"B`@("`@*B!%>&%M<&QE(&]F(&-O;FYE
M8W1I;F<@=&\@82!N97<@;&EN:R!V:6$@82!S;V-K970Z"B`@("`@*B`\8V]D
M93X*("`@("`J(')E<75I<F5?;VYC92`G1$(N<&AP)SL*("`@("`J(`H@("`@
M("H@)&1S;B`]("=P9W-Q;#HO+W5S97(Z<&%S<T!U;FEX*"]T;7`I+V1B;F%M
M93]N97=?;&EN:SUT<G5E)SL*("`@("`J("1O<'1I;VYS(#T@87)R87DH"B`@
M("`@*B`@("`@)W!O<G1A8FEL:71Y)R`]/B!$0E]03U)404))3$E465]!3$PL
M"B`@("`@*B`I.PH@("`@("H@"B`@("`@*B`D9&(@/28@1$(Z.F-O;FYE8W0H
M)&1S;BP@)&]P=&EO;G,I.PH@("`@("H@:68@*%!%05(Z.FES17)R;W(H)&1B
M*2D@>PH@("`@("H@("`@(&1I92@D9&(M/F=E=$UE<W-A9V4H*2D["B`@("`@
M*B!]"B`@("`@*B`\+V-O9&4^"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1D<VX@("`@("`@("!T:&4@9&%T82!S;W5R8V4@;F%M90H@("`@("H@0'!A
M<F%M(&)O;VP@("1P97)S:7-T96YT("!S:&]U;&0@=&AE(&-O;FYE8W1I;VX@
M8F4@<&5R<VES=&5N=#\*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?
M3TL@;VX@<W5C8V5S<RX@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*
M("`@("`J"B`@("`@*B!`;&EN:R!H='1P.B\O=W=W+G!O<W1G<F5S<6PN;W)G
M+V1O8W,O8W5R<F5N="]S=&%T:6,O;&EB<'$N:'1M;"-,24)042U#3TY.14-4
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;FYE8W0H)&1S;BP@)'!E<G-I<W1E
M;G0@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H(5!%05(Z.FQO861%>'1E
M;G-I;VXH)W!G<W%L)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*$1"7T524D]27T585$5.4TE/3E].3U1?1D]53D0I.PH@("`@
M("`@('T*"B`@("`@("`@)'1H:7,M/F1S;B`]("1D<VX["B`@("`@("`@:68@
M*"1D<VY;)V1B<WEN=&%X)UTI('L*("`@("`@("`@("`@)'1H:7,M/F1B<WEN
M=&%X(#T@)&1S;ELG9&)S>6YT87@G73L*("`@("`@("!]"@H@("`@("`@("1P
M<F]T;V-O;"`]("1D<VY;)W!R;W1O8V]L)UT@/R`D9'-N6R=P<F]T;V-O;"==
M(#H@)W1C<"<["@H@("`@("`@("1P87)A;7,@/2!A<G)A>2@G)RD["B`@("`@
M("`@:68@*"1P<F]T;V-O;"`]/2`G=&-P)RD@>PH@("`@("`@("`@("!I9B`H
M)&1S;ELG:&]S='-P96,G72D@>PH@("`@("`@("`@("`@("`@)'!A<F%M<ULP
M72`N/2`G:&]S=#TG("X@)&1S;ELG:&]S='-P96,G73L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!I9B`H)&1S;ELG<&]R="==*2!["B`@("`@("`@("`@
M("`@("`D<&%R86US6S!=("X]("<@<&]R=#TG("X@)&1S;ELG<&]R="==.PH@
M("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E:68@*"1P<F]T;V-O;"`]/2`G
M=6YI>"<I('L*("`@("`@("`@("`@+R\@06QL;W<@9F]R('!G('-O8VME="!I
M;B!N;VXM<W1A;F1A<F0@;&]C871I;VYS+@H@("`@("`@("`@("!I9B`H)&1S
M;ELG<V]C:V5T)UTI('L*("`@("`@("`@("`@("`@("1P87)A;7-;,%T@+CT@
M)VAO<W0])R`N("1D<VY;)W-O8VME="==.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&EF("@D9'-N6R=P;W)T)UTI('L*("`@("`@("`@("`@("`@("1P
M87)A;7-;,%T@+CT@)R!P;W)T/2<@+B`D9'-N6R=P;W)T)UT["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@:68@*"1D<VY;)V1A=&%B87-E)UTI
M('L*("`@("`@("`@("`@)'!A<F%M<ULP72`N/2`G(&1B;F%M93U<)R<@+B!A
M9&1S;&%S:&5S*"1D<VY;)V1A=&%B87-E)UTI("X@)UPG)SL*("`@("`@("!]
M"B`@("`@("`@:68@*"1D<VY;)W5S97)N86UE)UTI('L*("`@("`@("`@("`@
M)'!A<F%M<ULP72`N/2`G('5S97(]7"<G("X@861D<VQA<VAE<R@D9'-N6R=U
M<V5R;F%M92==*2`N("=<)R<["B`@("`@("`@?0H@("`@("`@(&EF("@D9'-N
M6R=P87-S=V]R9"==*2!["B`@("`@("`@("`@("1P87)A;7-;,%T@+CT@)R!P
M87-S=V]R9#U<)R<@+B!A9&1S;&%S:&5S*"1D<VY;)W!A<W-W;W)D)UTI("X@
M)UPG)SL*("`@("`@("!]"B`@("`@("`@:68@*"%E;7!T>2@D9'-N6R=O<'1I
M;VYS)UTI*2!["B`@("`@("`@("`@("1P87)A;7-;,%T@+CT@)R!O<'1I;VYS
M/2<@+B`D9'-N6R=O<'1I;VYS)UT["B`@("`@("`@?0H@("`@("`@(&EF("@A
M96UP='DH)&1S;ELG='1Y)UTI*2!["B`@("`@("`@("`@("1P87)A;7-;,%T@
M+CT@)R!T='D])R`N("1D<VY;)W1T>2==.PH@("`@("`@('T*("`@("`@("!I
M9B`H(65M<'1Y*"1D<VY;)V-O;FYE8W1?=&EM96]U="==*2D@>PH@("`@("`@
M("`@("`D<&%R86US6S!=("X]("<@8V]N;F5C=%]T:6UE;W5T/2<@+B`D9'-N
M6R=C;VYN96-T7W1I;65O=70G73L*("`@("`@("!]"B`@("`@("`@:68@*"%E
M;7!T>2@D9'-N6R=S<VQM;V1E)UTI*2!["B`@("`@("`@("`@("1P87)A;7-;
M,%T@+CT@)R!S<VQM;V1E/2<@+B`D9'-N6R=S<VQM;V1E)UT["B`@("`@("`@
M?0H@("`@("`@(&EF("@A96UP='DH)&1S;ELG<V5R=FEC92==*2D@>PH@("`@
M("`@("`@("`D<&%R86US6S!=("X]("<@<V5R=FEC93TG("X@)&1S;ELG<V5R
M=FEC92==.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1D<VY;)VYE
M=U]L:6YK)UTI"B`@("`@("`@("`@("8F("@D9'-N6R=N97=?;&EN:R==(#T]
M("=T<G5E)R!\?"`D9'-N6R=N97=?;&EN:R==(#T]/2!T<G5E*2D*("`@("`@
M("!["B`@("`@("`@("`@(&EF("AV97)S:6]N7V-O;7!A<F4H<&AP=F5R<VEO
M;B@I+"`G-"XS+C`G+"`G/CTG*2D@>PH@("`@("`@("`@("`@("`@)'!A<F%M
M<UM=(#T@4$=344Q?0T].3D5#5%]&3U)#15].15<["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@("1C;VYN96-T7V9U;F-T:6]N(#T@)'!E<G-I
M<W1E;G0@/R`G<&=?<&-O;FYE8W0G(#H@)W!G7V-O;FYE8W0G.PH*("`@("`@
M("`D:6YI(#T@:6YI7V=E="@G=')A8VM?97)R;W)S)RD["B`@("`@("`@)'!H
M<%]E<G)O<FUS9R`]("<G.PH@("`@("`@(&EF("@D:6YI*2!["B`@("`@("`@
M("`@("1T:&ES+3YC;VYN96-T:6]N(#T@0&-A;&Q?=7-E<E]F=6YC7V%R<F%Y
M*"1C;VYN96-T7V9U;F-T:6]N+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86US*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!I;FE?<V5T*"=T<F%C:U]E<G)O<G,G
M+"`Q*3L*("`@("`@("`@("`@)'1H:7,M/F-O;FYE8W1I;VX@/2!`8V%L;%]U
M<V5R7V9U;F-?87)R87DH)&-O;FYE8W1?9G5N8W1I;VXL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P
M87)A;7,I.PH@("`@("`@("`@("!I;FE?<V5T*"=T<F%C:U]E<G)O<G,G+"`D
M:6YI*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A)'1H:7,M/F-O;FYE8W1I
M;VXI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"
M7T524D]27T-/3DY%0U1?1D%)3$5$+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@;G5L;"P@;G5L;"P@;G5L;"P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1P:'!?97)R;W)M<V<I.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@9&ES8V]N;F5C="@I"@H@("`@+RHJ"B`@("`@*B!$:7-C
M;VYN96-T<R!F<F]M('1H92!D871A8F%S92!S97)V97(*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VP@(%12544@;VX@<W5C8V5S<RP@1D%,4T4@;VX@9F%I
M;'5R90H@("`@("HO"B`@("!F=6YC=&EO;B!D:7-C;VYN96-T*"D*("`@('L*
M("`@("`@("`D<F5T(#T@0'!G7V-L;W-E*"1T:&ES+3YC;VYN96-T:6]N*3L*
M("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`](&YU;&P["B`@("`@("`@<F5T
M=7)N("1R970["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<VEM<&QE
M475E<GDH*0H*("`@("\J*@H@("`@("H@4V5N9',@82!Q=65R>2!T;R!T:&4@
M9&%T86)A<V4@<V5R=F5R"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@
M=&AE(%-13"!Q=65R>2!S=')I;F<*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("`K(&$@4$A0(')E<W5L="!R97-R;W5C92!F;W(@<W5C8V5S<V9U;"!3
M14Q%0U0@<75E<FEE<PH@("`@("H@("`@("`@("`@("`@("`@*R!T:&4@1$)?
M3TL@8V]N<W1A;G0@9F]R(&]T:&5R('-U8V-E<W-F=6P@<75E<FEE<PH@("`@
M("H@("`@("`@("`@("`@("`@*R!A($1"7T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E"B`@("`@*B\*("`@(&9U;F-T:6]N('-I;7!L95%U97)Y*"1Q=65R>2D*
M("`@('L*("`@("`@("`D:7-M86YI<"`]($1".CII<TUA;FEP*"1Q=65R>2D[
M"B`@("`@("`@)'1H:7,M/FQA<W1?<75E<GD@/2`D<75E<GD["B`@("`@("`@
M)'%U97)Y(#T@)'1H:7,M/FUO9&EF>5%U97)Y*"1Q=65R>2D["B`@("`@("`@
M:68@*"$D=&AI<RT^875T;V-O;6UI="`F)B`D:7-M86YI<"D@>PH@("`@("`@
M("`@("!I9B`H)'1H:7,M/G1R86YS86-T:6]N7V]P8V]U;G0@/3T@,"D@>PH@
M("`@("`@("`@("`@("`@)')E<W5L="`]($!P9U]E>&5C*"1T:&ES+3YC;VYN
M96-T:6]N+"`G8F5G:6X[)RD["B`@("`@("`@("`@("`@("!I9B`H(21R97-U
M;'0I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G!G<W%L
M4F%I<V5%<G)O<B@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT*RL["B`@
M("`@("`@?0H@("`@("`@("1R97-U;'0@/2!`<&=?97AE8R@D=&AI<RT^8V]N
M;F5C=&EO;BP@)'%U97)Y*3L*("`@("`@("!I9B`H(21R97-U;'0I('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YP9W-Q;%)A:7-E17)R;W(H*3L*("`@
M("`@("!]"B`@("`@("`@+R\@1&5T97)M:6YE('=H:6-H('%U97)I97,@=&AA
M="!S:&]U;&0@<F5T=7)N(&1A=&$L(&%N9"!W:&EC:`H@("`@("`@("\O('-H
M;W5L9"!R971U<FX@86X@97)R;W(@8V]D92!O;FQY+@H@("`@("`@(&EF("@D
M:7-M86YI<"D@>PH@("`@("`@("`@("`D=&AI<RT^869F96-T960@/2!`<&=?
M869F96-T961?<F]W<R@D<F5S=6QT*3L*("`@("`@("`@("`@<F5T=7)N($1"
M7T]+.PH@("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H*"<O7EQS*EPH*EQS
M*BA314Q%0U1\15A03$%)3GQ32$]7*5QS+W-I)RP@)'%U97)Y*2D@>PH@("`@
M("`@("`@("`O*B!0;W-T9W)E4U%,(&-O;6UA;F1S.@H@("`@("`@("`@("`@
M("!!0D]25"P@04Q415(L($)%1TE.+"!#3$]312P@0TQ54U1%4BP@0T]-34E4
M+"!#3U!9+`H@("`@("`@("`@("`@("!#4D5!5$4L($1%0TQ!4D4L($1%3$54
M12P@1%)/4"!404),12P@15A03$%)3BP@1D540T@L"B`@("`@("`@("`@("`@
M($=204Y4+"!)3E-%4E0L($Q)4U1%3BP@3$]!1"P@3$]#2RP@34]612P@3D]4
M2499+"!215-%5"P*("`@("`@("`@("`@("`@4D563TM%+"!23TQ,0D%#2RP@
M4T5,14-4+"!314Q%0U0@24Y43RP@4T54+"!32$]7+`H@("`@("`@("`@("`@
M("!53DQ)4U1%3BP@55!$051%+"!604-554T*("`@("`@("`@("`@*B\*("`@
M("`@("`@("`@)'1H:7,M/G)O=ULH:6YT*21R97-U;'1=(#T@,#L@+R\@<F5S
M970@=&AE(')O=R!C;W5N=&5R+@H@("`@("`@("`@("`D;G5M<F]W<R`]("1T
M:&ES+3YN=6U2;W=S*"1R97-U;'0I.PH@("`@("`@("`@("!I9B`H:7-?;V)J
M96-T*"1N=6UR;W=S*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1N=6UR
M;W=S.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?;G5M7W)O
M=W-;*&EN="DD<F5S=6QT72`]("1N=6UR;W=S.PH@("`@("`@("`@("`D=&AI
M<RT^869F96-T960@/2`P.PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^869F96-T960@
M/2`P.PH@("`@("`@("`@("!R971U<FX@1$)?3TL["B`@("`@("`@?0H@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YE>'1297-U;'0H*0H*("`@("\J
M*@H@("`@("H@36]V92!T:&4@:6YT97)N86P@<&=S<6P@<F5S=6QT('!O:6YT
M97(@=&\@=&AE(&YE>'0@879A:6QA8FQE(')E<W5L=`H@("`@("H*("`@("`J
M($!P87)A;2!A('9A;&ED(&9B<W%L(')E<W5L="!R97-O=7)C90H@("`@("H*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("H@0')E='5R;B!T
M<G5E(&EF(&$@<F5S=6QT(&ES(&%V86EL86)L92!O=&AE<G=I<V4@<F5T=7)N
M(&9A;'-E"B`@("`@*B\*("`@(&9U;F-T:6]N(&YE>'1297-U;'0H)')E<W5L
M="D*("`@('L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@9F5T8VA);G1O*"D*"B`@("`O*BH*("`@("`J(%!L
M86-E<R!A(')O=R!F<F]M('1H92!R97-U;'0@<V5T(&EN=&\@=&AE(&=I=F5N
M(&%R<F%Y"B`@("`@*@H@("`@("H@1F]R;6%T:6YG(&]F('1H92!A<G)A>2!A
M;F0@=&AE(&1A=&$@=&AE<F5I;B!A<F4@8V]N9FEG=7)A8FQE+@H@("`@("H@
M4V5E($1"7W)E<W5L=#HZ9F5T8VA);G1O*"D@9F]R(&UO<F4@:6YF;W)M871I
M;VXN"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@:7,@;F]T(&UE86YT('1O
M(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@("H@1$)?<F5S=6QT.CIF
M971C:$EN=&\H*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R
M;W1E8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A
M=&4@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S
M=6QT("`@('1H92!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J($!P87)A
M;2!A<G)A>2`@("`D87)R("`@("`@('1H92!R969E<F5N8V5D(&%R<F%Y('1O
M('!U="!T:&4@9&%T82!I;@H@("`@("H@0'!A<F%M(&EN="`@("`@("1F971C
M:&UO9&4@:&]W('1H92!R97-U;'1I;F<@87)R87D@<VAO=6QD(&)E(&EN9&5X
M960*("`@("`J($!P87)A;2!I;G0@("`@("`D<F]W;G5M("`@('1H92!R;W<@
M;G5M8F5R('1O(&9E=&-H("@P(#T@9FER<W0@<F]W*0H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@($1"7T]+(&]N('-U8V-E<W,L($Y53$P@=VAE;B!T
M:&4@96YD(&]F(&$@<F5S=6QT('-E="!I<PH@("`@("H@("`@("`@("`@("`@
M("`@(')E86-H960@;W(@;VX@9F%I;'5R90H@("`@("H*("`@("`J($!S964@
M1$)?<F5S=6QT.CIF971C:$EN=&\H*0H@("`@("HO"B`@("!F=6YC=&EO;B!F
M971C:$EN=&\H)')E<W5L="P@)B1A<G(L("1F971C:&UO9&4L("1R;W=N=6T@
M/2!N=6QL*0H@("`@>PH@("`@("`@("1R97-U;'1?:6YT(#T@*&EN="DD<F5S
M=6QT.PH@("`@("`@("1R;W=N=6T@/2`H)')O=VYU;2`A/3T@;G5L;"D@/R`D
M<F]W;G5M(#H@)'1H:7,M/G)O=ULD<F5S=6QT7VEN=%T["B`@("`@("`@:68@
M*"1R;W=N=6T@/CT@)'1H:7,M/E]N=6U?<F]W<ULD<F5S=6QT7VEN=%TI('L*
M("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H@("`@("`@(&EF
M("@D9F5T8VAM;V1E("8@1$)?1D540TA-3T1%7T%34T]#*2!["B`@("`@("`@
M("`@("1A<G(@/2!`<&=?9F5T8VA?87)R87DH)')E<W5L="P@)')O=VYU;2P@
M4$=344Q?05-33T,I.PH@("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;
M)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465],3U=%4D-!4T4@)B8@
M)&%R<BD@>PH@("`@("`@("`@("`@("`@)&%R<B`](&%R<F%Y7V-H86YG95]K
M97E?8V%S92@D87)R+"!#05-%7TQ/5T52*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1A<G(@/2!`<&=?9F5T8VA?<F]W
M*"1R97-U;'0L("1R;W=N=6TI.PH@("`@("`@('T*("`@("`@("!I9B`H(21A
M<G(I('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H@("`@
M("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/
M4E1!0DE,25197U)44DE-*2!["B`@("`@("`@("`@("1T:&ES+3Y?<G1R:6U!
M<G)A>59A;'5E<R@D87)R*3L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES
M+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?3E5,
M3%]43U]%35!462D@>PH@("`@("`@("`@("`D=&AI<RT^7V-O;G9E<G1.=6QL
M07)R87E686QU97-4;T5M<'1Y*"1A<G(I.PH@("`@("`@('T*("`@("`@("`D
M=&AI<RT^<F]W6R1R97-U;'1?:6YT72`]("LK)')O=VYU;3L*("`@("`@("!R
M971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9G)E
M95)E<W5L="@I"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S('1H92!R97-U;'0@
M<V5T(&%N9"!F<F5E<R!T:&4@;65M;W)Y(&]C8W5P:65D(&)Y('1H92!R97-U
M;'0@<V5T"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@:7,@;F]T(&UE86YT
M('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@("H@1$)?<F5S=6QT
M.CIF<F5E*"D@:6YS=&5A9"X@($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T
M96-T960B"B`@("`@*B!B96-A=7-E($1"7W)E<W5L="!I<R!A('-E<&%R871E
M(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L
M="`@4$A0)W,@<75E<GD@<F5S=6QT(')E<V]U<F-E"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L("!44E5%(&]N('-U8V-E<W,L($9!3%-%(&EF("1R97-U
M;'0@:7,@:6YV86QI9`H@("`@("H*("`@("`J($!S964@1$)?<F5S=6QT.CIF
M<F5E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9G)E95)E<W5L="@D<F5S=6QT
M*0H@("`@>PH@("`@("`@(&EF("AI<U]R97-O=7)C92@D<F5S=6QT*2D@>PH@
M("`@("`@("`@("!U;G-E="@D=&AI<RT^<F]W6RAI;G0I)')E<W5L=%TI.PH@
M("`@("`@("`@("!U;G-E="@D=&AI<RT^7VYU;5]R;W=S6RAI;G0I)')E<W5L
M=%TI.PH@("`@("`@("`@("`D=&AI<RT^869F96-T960@/2`P.PH@("`@("`@
M("`@("!R971U<FX@0'!G7V9R965R97-U;'0H)')E<W5L="D["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!Q=6]T92@I"@H@("`@+RHJ"B`@("`@*B!`9&5P<F5C871E9"`@
M1&5P<F5C871E9"!I;B!R96QE87-E(#$N-BXP"B`@("`@*B!`:6YT97)N86P*
M("`@("`J+PH@("`@9G5N8W1I;VX@<75O=&4H)'-T<BD*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/G%U;W1E4VUA<G0H)'-T<BD["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@<75O=&53;6%R="@I"@H@("`@+RHJ"B`@("`@
M*B!&;W)M871S(&EN<'5T('-O(&ET(&-A;B!B92!S869E;'D@=7-E9"!I;B!A
M('%U97)Y"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1I;B`@=&AE(&1A
M=&$@=&\@8F4@9F]R;6%T=&5D"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@=&AE(&9O<FUA='1E9"!D871A+B`@5&AE(&9O<FUA="!D97!E;F1S(&]N
M('1H92!I;G!U="=S"B`@("`@*B`@("`@("`@("`@("`@("`@4$A0('1Y<&4Z
M"B`@("`@*B`@("`@("`@("`@("`@("`@*R!N=6QL(#T@=&AE('-T<FEN9R`\
M<V%M<#Y.54Q,/"]S86UP/@H@("`@("H@("`@("`@("`@("`@("`@("L@8F]O
M;&5A;B`]('-T<FEN9R`\<V%M<#Y44E5%/"]S86UP/B!O<B`\<V%M<#Y&04Q3
M13PO<V%M<#X*("`@("`J("`@("`@("`@("`@("`@("`K(&EN=&5G97(@;W(@
M9&]U8FQE(#T@=&AE('5N<75O=&5D(&YU;6)E<@H@("`@("H@("`@("`@("`@
M("`@("`@("L@;W1H97(@*&EN8VQU9&EN9R!S=')I;F=S(&%N9"!N=6UE<FEC
M('-T<FEN9W,I(#T*("`@("`J("`@("`@("`@("`@("`@("`@('1H92!D871A
M(&5S8V%P960@86-C;W)D:6YG('1O($UY4U%,)W,@<V5T=&EN9W,*("`@("`J
M("`@("`@("`@("`@("`@("`@('1H96X@96YC87!S=6QA=&5D(&)E='=E96X@
M<VEN9VQE('%U;W1E<PH@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIQ
M=6]T95-M87)T*"D*("`@("`J($!S:6YC92!-971H;V0@879A:6QA8FQE('-I
M;F-E(%)E;&5A<V4@,2XV+C`*("`@("`J+PH@("`@9G5N8W1I;VX@<75O=&53
M;6%R="@D:6XI"B`@("!["B`@("`@("`@:68@*&ES7VEN="@D:6XI('Q\(&ES
M7V1O=6)L92@D:6XI*2!["B`@("`@("`@("`@(')E='5R;B`D:6X["B`@("`@
M("`@?2!E;'-E:68@*&ES7V)O;VPH)&EN*2D@>PH@("`@("`@("`@("!R971U
M<FX@)&EN(#\@)U12544G(#H@)T9!3%-%)SL*("`@("`@("!](&5L<V5I9B`H
M:7-?;G5L;"@D:6XI*2!["B`@("`@("`@("`@(')E='5R;B`G3E5,3"<["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("(G(B`N("1T:&ES
M+3YE<V-A<&53:6UP;&4H)&EN*2`N("(G(CL*("`@("`@("!]"B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@97-C87!E4VEM<&QE*"D*"B`@("`O*BH*
M("`@("`J($5S8V%P97,@82!S=')I;F<@86-C;W)D:6YG('1O('1H92!C=7)R
M96YT($1"35,G<R!S=&%N9&%R9',*("`@("`J"B`@("`@*B![0&EN=&5R;F%L
M(%!O<W1G<F5344P@=')E871S(&$@8F%C:W-L87-H(&%S(&%N(&5S8V%P92!C
M:&%R86-T97(L"B`@("`@*B!S;R!T:&5Y(&%R92!E<V-A<&5D(&%S('=E;&PN
M"B`@("`@*@H@("`@("H@3F]T('5S:6YG('!G7V5S8V%P95]S=')I;F<H*2!Y
M970@8F5C875S92!I="!R97%U:7)E<R!0;W-T9W)E4U%,"B`@("`@*B!T;R!B
M92!A="!V97)S:6]N(#<N,B!O<B!G<F5A=&5R+GU]"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<W1R("!T:&4@<W1R:6YG('1O(&)E(&5S8V%P960*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&5S8V%P960@<W1R
M:6YG"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G%U;W1E4VUA<G0H
M*0H@("`@("H@0'-I;F-E($UE=&AO9"!A=F%I;&%B;&4@<VEN8V4@4F5L96%S
M92`Q+C8N,`H@("`@("HO"B`@("!F=6YC=&EO;B!E<V-A<&53:6UP;&4H)'-T
M<BD*("`@('L*("`@("`@("!R971U<FX@<W1R7W)E<&QA8V4H(B<B+"`B)R<B
M+"!S=')?<F5P;&%C92@G7%PG+"`G7%Q<7"<L("1S='(I*3L*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!N=6U#;VQS*"D*"B`@("`O*BH*("`@("`J
M($=E=',@=&AE(&YU;6)E<B!O9B!C;VQU;6YS(&EN(&$@<F5S=6QT('-E=`H@
M("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES(&YO="!M96%N="!T;R!B92!C
M86QL960@9&ER96-T;'DN("!5<V4*("`@("`J($1"7W)E<W5L=#HZ;G5M0V]L
M<R@I(&EN<W1E860N("!)="!C86XG="!B92!D96-L87)E9"`B<')O=&5C=&5D
M(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@82!S97!A<F%T92!O8FIE
M8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1R97-U;'0@(%!(
M4"=S('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@("H*("`@("`J($!R971U
M<FX@:6YT("!T:&4@;G5M8F5R(&]F(&-O;'5M;G,N("!!($1"7T5R<F]R(&]B
M:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?<F5S=6QT
M.CIN=6U#;VQS*"D*("`@("`J+PH@("`@9G5N8W1I;VX@;G5M0V]L<R@D<F5S
M=6QT*0H@("`@>PH@("`@("`@("1C;VQS(#T@0'!G7VYU;69I96QD<R@D<F5S
M=6QT*3L*("`@("`@("!I9B`H(21C;VQS*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<&=S<6Q286ES945R<F]R*"D["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B`D8V]L<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!N
M=6U2;W=S*"D*"B`@("`O*BH*("`@("`J($=E=',@=&AE(&YU;6)E<B!O9B!R
M;W=S(&EN(&$@<F5S=6QT('-E=`H@("`@("H*("`@("`J(%1H:7,@;65T:&]D
M(&ES(&YO="!M96%N="!T;R!B92!C86QL960@9&ER96-T;'DN("!5<V4*("`@
M("`J($1"7W)E<W5L=#HZ;G5M4F]W<R@I(&EN<W1E860N("!)="!C86XG="!B
M92!D96-L87)E9"`B<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U
M;'0@:7,@82!S97!A<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M
M(')E<V]U<F-E("1R97-U;'0@(%!(4"=S('%U97)Y(')E<W5L="!R97-O=7)C
M90H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F(')O
M=W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@
M("`J($!S964@1$)?<F5S=6QT.CIN=6U2;W=S*"D*("`@("`J+PH@("`@9G5N
M8W1I;VX@;G5M4F]W<R@D<F5S=6QT*0H@("`@>PH@("`@("`@("1R;W=S(#T@
M0'!G7VYU;7)O=W,H)')E<W5L="D["B`@("`@("`@:68@*"1R;W=S(#T]/2!N
M=6QL*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<&=S<6Q286ES945R
M<F]R*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F]W<SL*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!A=71O0V]M;6ET*"D*"B`@("`O*BH*
M("`@("`J($5N86)L97,@;W(@9&ES86)L97,@875T;VUA=&EC(&-O;6UI=',*
M("`@("`J"B`@("`@*B!`<&%R86T@8F]O;"`D;VYO9F8@('1R=64@='5R;G,@
M:70@;VXL(&9A;'-E('1U<FYS(&ET(&]F9@H@("`@("H*("`@("`J($!R971U
M<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@
M:68@=&AE(&1R:79E<@H@("`@("H@("`@("`@("`@("`@("!D;V5S;B=T('-U
M<'!O<G0@875T;RUC;VUM:71T:6YG('1R86YS86-T:6]N<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@875T;T-O;6UI="@D;VYO9F8@/2!F86QS92D*("`@('L*
M("`@("`@("`O+R!86%@@:68@)'1H:7,M/G1R86YS86-T:6]N7V]P8V]U;G0@
M/B`P+"!W92!S:&]U;&0@<')O8F%B;'D*("`@("`@("`O+R!I<W-U92!A('=A
M<FYI;F<@:&5R92X*("`@("`@("`D=&AI<RT^875T;V-O;6UI="`]("1O;F]F
M9B`_('1R=64@.B!F86QS93L*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]M;6ET*"D*"B`@("`O*BH*("`@
M("`J($-O;6UI=',@=&AE(&-U<G)E;G0@=')A;G-A8W1I;VX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R
M;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O
M;6UI="@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YT<F%N<V%C=&EO;E]O
M<&-O=6YT(#X@,"D@>PH@("`@("`@("`@("`O+R`H9&ES86)L960I(&AA8VL@
M=&\@<VAU="!U<"!E<G)O<B!M97-S86=E<R!F<F]M(&QI8G!Q+F$*("`@("`@
M("`@("`@+R]`9F-L;W-E*$!F;W!E;B@B<&AP.B\O<W1D97)R(BP@(G<B*2D[
M"B`@("`@("`@("`@("1R97-U;'0@/2!`<&=?97AE8R@D=&AI<RT^8V]N;F5C
M=&EO;BP@)V5N9#LG*3L*("`@("`@("`@("`@)'1H:7,M/G1R86YS86-T:6]N
M7V]P8V]U;G0@/2`P.PH@("`@("`@("`@("!I9B`H(21R97-U;'0I('L*("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<&=S<6Q286ES945R<F]R*"D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(')O;&QB86-K*"D*"B`@
M("`O*BH*("`@("`J(%)E=F5R=',@=&AE(&-U<G)E;G0@=')A;G-A8W1I;VX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@
M($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(')O;&QB86-K*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/G1R
M86YS86-T:6]N7V]P8V]U;G0@/B`P*2!["B`@("`@("`@("`@("1R97-U;'0@
M/2!`<&=?97AE8R@D=&AI<RT^8V]N;F5C=&EO;BP@)V%B;W)T.R<I.PH@("`@
M("`@("`@("`D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`](#`["B`@("`@
M("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YP9W-Q;%)A:7-E17)R;W(H*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@869F96-T9612;W=S*"D*"B`@("`O*BH*("`@("`J($1E
M=&5R;6EN97,@=&AE(&YU;6)E<B!O9B!R;W=S(&%F9F5C=&5D(&)Y(&$@9&%T
M82!M86YI=7!L871I;VX@<75E<GD*("`@("`J"B`@("`@*B`P(&ES(')E='5R
M;F5D(&9O<B!Q=65R:65S('1H870@9&]N)W0@;6%N:7!U;&%T92!D871A+@H@
M("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F(')O=W,N
M("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!A9F9E8W1E9%)O=W,H*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^869F96-T960["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M;F5X=$ED*"D*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&YE>'0@9G)E
M92!I9"!I;B!A('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`@)'-E<5]N86UE("!N86UE(&]F('1H92!S97%U96YC90H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)&]N9&5M86YD("!W:&5N('1R=64L('1H92!S97%E;F-E
M(&ES(&%U=&]M871I8V%L;'D*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&-R96%T960@:68@:70@9&]E<R!N;W0@97AI<W0*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&EN="`@=&AE(&YE>'0@:60@;G5M8F5R(&EN('1H92!S
M97%U96YC92X*("`@("`J("`@("`@("`@("`@("`@02!$0E]%<G)O<B!O8FIE
M8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ
M;F5X=$E$*"DL($1"7V-O;6UO;CHZ9V5T4V5Q=65N8V5.86UE*"DL"B`@("`@
M*B`@("`@($1"7W!G<W%L.CIC<F5A=&5397%U96YC92@I+"!$0E]P9W-Q;#HZ
M9')O<%-E<75E;F-E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@;F5X=$ED*"1S
M97%?;F%M92P@)&]N9&5M86YD(#T@=')U92D*("`@('L*("`@("`@("`D<V5Q
M;F%M92`]("1T:&ES+3YG971397%U96YC94YA;64H)'-E<5]N86UE*3L*("`@
M("`@("`D<F5P96%T(#T@9F%L<V4["B`@("`@("`@9&\@>PH@("`@("`@("`@
M("`D=&AI<RT^<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI
M.PH@("`@("`@("`@("`D<F5S=6QT(#TF("1T:&ES+3YQ=65R>2@B4T5,14-4
M($Y%6%1604PH)R1[<V5Q;F%M97TG*2(I.PH@("`@("`@("`@("`D=&AI<RT^
M<&]P17)R;W)(86YD;&EN9R@I.PH@("`@("`@("`@("!I9B`H)&]N9&5M86YD
M("8F($1".CII<T5R<F]R*"1R97-U;'0I("8F"B`@("`@("`@("`@("`@("`D
M<F5S=6QT+3YG971#;V1E*"D@/3T@1$)?15)23U)?3D]354-(5$%"3$4I('L*
M("`@("`@("`@("`@("`@("1R97!E870@/2!T<G5E.PH@("`@("`@("`@("`@
M("`@)'1H:7,M/G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).
M*3L*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^8W)E871E4V5Q
M=65N8V4H)'-E<5]N86UE*3L*("`@("`@("`@("`@("`@("1T:&ES+3YP;W!%
M<G)O<DAA;F1L:6YG*"D["B`@("`@("`@("`@("`@("!I9B`H1$(Z.FES17)R
M;W(H)')E<W5L="DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H)')E<W5L="D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<F5P96%T(#T@
M9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!]('=H:6QE("@D<F5P96%T
M*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1R97-U;'0I.PH@("`@
M("`@('T*("`@("`@("`D87)R(#T@)')E<W5L="T^9F5T8VA2;W<H1$)?1D54
M0TA-3T1%7T]21$52140I.PH@("`@("`@("1R97-U;'0M/F9R964H*3L*("`@
M("`@("!R971U<FX@)&%R<ELP73L*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!C<F5A=&5397%U96YC92@I"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S
M(&$@;F5W('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<V5Q7VYA;64@(&YA;64@;V8@=&AE(&YE=R!S97%U96YC90H@("`@("H*("`@
M("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O
M;6UO;CHZ8W)E871E4V5Q=65N8V4H*2P@1$)?8V]M;6]N.CIG971397%U96YC
M94YA;64H*2P*("`@("`J("`@("`@1$)?<&=S<6PZ.FYE>'1)1"@I+"!$0E]P
M9W-Q;#HZ9')O<%-E<75E;F-E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@8W)E
M871E4V5Q=65N8V4H)'-E<5]N86UE*0H@("`@>PH@("`@("`@("1S97%N86UE
M(#T@)'1H:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I.PH@("`@("`@
M("1R97-U;'0@/2`D=&AI<RT^<75E<GDH(D-214%412!315%514Y#12`D>W-E
M<6YA;65](BD["B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@9')O<%-E<75E;F-E*"D*"B`@("`O*BH*("`@
M("`J($1E;&5T97,@82!S97%U96YC90H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'-E<5]N86UE("!N86UE(&]F('1H92!S97%U96YC92!T;R!B92!D
M96QE=&5D"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U
M8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*
M("`@("`J($!S964@1$)?8V]M;6]N.CID<F]P4V5Q=65N8V4H*2P@1$)?8V]M
M;6]N.CIG971397%U96YC94YA;64H*2P*("`@("`J("`@("`@1$)?<&=S<6PZ
M.FYE>'1)1"@I+"!$0E]P9W-Q;#HZ8W)E871E4V5Q=65N8V4H*0H@("`@("HO
M"B`@("!F=6YC=&EO;B!D<F]P4V5Q=65N8V4H)'-E<5]N86UE*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^<75E<GDH)T123U`@4T51545.0T4@)PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`D=&AI<RT^9V5T4V5Q=65N
M8V5.86UE*"1S97%?;F%M92DI.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&UO9&EF>4QI;6ET475E<GDH*0H*("`@("\J*@H@("`@("H@061D<R!,
M24U)5"!C;&%U<V5S('1O(&$@<75E<GD@<W1R:6YG(&%C8V]R9&EN9R!T;R!C
M=7)R96YT($1"35,@<W1A;F1A<F1S"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<75E<GD@("!T:&4@<75E<GD@=&\@;6]D:69Y"B`@("`@*B!`<&%R
M86T@:6YT("`@("1F<F]M("`@('1H92!R;W<@=&\@<W1A<G0@=&\@9F5T8VAI
M;F<@*#`@/2!T:&4@9FER<W0@<F]W*0H@("`@("H@0'!A<F%M(&EN="`@("`D
M8V]U;G0@("!T:&4@;G5M8F5R<R!O9B!R;W=S('1O(&9E=&-H"B`@("`@*B!`
M<&%R86T@;6EX960@("1P87)A;7,@(&%R<F%Y+"!S=')I;F<@;W(@;G5M97)I
M8R!D871A('1O(&)E('5S960@:6X*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@(&5X96-U=&EO;B!O9B!T:&4@<W1A=&5M96YT+B`@475A;G1I='D@
M;V8@:71E;7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('!A<W-E
M9"!M=7-T(&UA=&-H('%U86YT:71Y(&]F('!L86-E:&]L9&5R<R!I;@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@<75E<GDZ("!M96%N:6YG(#$@
M<&QA8V5H;VQD97(@9F]R(&YO;BUA<G)A>0H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@<&%R86UE=&5R<R!O<B`Q('!L86-E:&]L9&5R('!E<B!A
M<G)A>2!E;&5M96YT+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T
M:&4@<75E<GD@<W1R:6YG('=I=&@@3$E-250@8VQA=7-E<R!A9&1E9`H@("`@
M("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&UO9&EF>4QI;6ET475E<GDH)'%U97)Y+"`D9G)O;2P@)&-O=6YT+"`D
M<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!R971U<FX@(B1Q=65R
M>2!,24U)5"`D8V]U;G0@3T9&4T54("1F<F]M(CL*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!P9W-Q;%)A:7-E17)R;W(H*0H*("`@("\J*@H@("`@
M("H@4')O9'5C97,@82!$0E]%<G)O<B!O8FIE8W0@<F5G87)D:6YG('1H92!C
M=7)R96YT('!R;V)L96T*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("1E<G)N
M;R`@:68@=&AE(&5R<F]R(&ES(&)E:6YG(&UA;G5A;&QY(')A:7-E9"!P87-S
M(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@1$)?15)23U(J(&-O;G-T
M86YT(&AE<F4N("!)9B!T:&ES(&ES;B=T('!A<W-E9`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("!T:&4@97)R;W(@:6YF;W)M871I;VX@9V%T:&5R960@
M9G)O;2!T:&4@1$)-4RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@
M=&AE($1"7T5R<F]R(&]B:F5C=`H@("`@("H*("`@("`J($!S964@1$)?8V]M
M;6]N.CIR86ES945R<F]R*"DL"B`@("`@*B`@("`@($1"7W!G<W%L.CIE<G)O
M<DYA=&EV92@I+"!$0E]P9W-Q;#HZ97)R;W)#;V1E*"D*("`@("`J+PH@("`@
M9G5N8W1I;VX@<&=S<6Q286ES945R<F]R*"1E<G)N;R`](&YU;&PI"B`@("![
M"B`@("`@("`@)&YA=&EV92`]("1T:&ES+3YE<G)O<DYA=&EV92@I.PH@("`@
M("`@(&EF("@D97)R;F\@/3T](&YU;&PI('L*("`@("`@("`@("`@)&5R<FYO
M(#T@)'1H:7,M/F5R<F]R0V]D92@D;F%T:79E*3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1E<G)N;RP@;G5L;"P@;G5L
M;"P@;G5L;"P@)&YA=&EV92D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@97)R;W).871I=F4H*0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@1$)-
M4R<@;F%T:79E(&5R<F]R(&UE<W-A9V4@<')O9'5C960@8GD@=&AE(&QA<W0@
M<75E<GD*("`@("`J"B`@("`@*B![0&EN=&5R;F%L($5R<F]R(&UE<W-A9V5S
M(&%R92!U<V5D(&EN<W1E860@;V8@97)R;W(@8V]D97,@"B`@("`@*B!I;B!O
M<F1E<B!T;R!S=7!P;W)T(&]L9&5R('9E<G-I;VYS(&]F(%!O<W1G<F5344PN
M?7T*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE($1"35,G(&5R
M<F]R(&UE<W-A9V4*("`@("`J+PH@("`@9G5N8W1I;VX@97)R;W).871I=F4H
M*0H@("`@>PH@("`@("`@(')E='5R;B!`<&=?97)R;W)M97-S86=E*"1T:&ES
M+3YC;VYN96-T:6]N*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!E
M<G)O<D-O9&4H*0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE<R!014%2.CI$
M0B!E<G)O<B!C;V1E(&9R;VT@=&AE(&1A=&%B87-E)W,@=&5X="!E<G)O<B!M
M97-S86=E+@H@("`@("H*("`@("`J($!P87)A;2`@<W1R:6YG("`D97)R;W)M
M<V<@(&5R<F]R(&UE<W-A9V4@<F5T=7)N960@9G)O;2!T:&4@9&%T86)A<V4*
M("`@("`J($!R971U<FX@:6YT96=E<B`@86X@97)R;W(@;G5M8F5R(&9R;VT@
M82!$0B!E<G)O<B!C;VYS=&%N=`H@("`@("HO"B`@("!F=6YC=&EO;B!E<G)O
M<D-O9&4H)&5R<F]R;7-G*0H@("`@>PH@("`@("`@('-T871I8R`D97)R;W)?
M<F5G97AP<SL*("`@("`@("!I9B`H(6ES<V5T*"1E<G)O<E]R96=E>'!S*2D@
M>PH@("`@("`@("`@("`D97)R;W)?<F5G97AP<R`](&%R<F%Y*`H@("`@("`@
M("`@("`@("`@)R\H<F5L871I;VY\<V5Q=65N8V5\=&%B;&4I+BID;V5S(&YO
M="!E>&ES='QC;&%S<R`N*B!N;W0@9F]U;F0O:2<*("`@("`@("`@("`@("`@
M("`@("`]/B!$0E]%4E)/4E].3U-50TA404),12P*("`@("`@("`@("`@("`@
M("<O:6YD97@@+BH@9&]E<R!N;W0@97AI<W0O)PH@("`@("`@("`@("`@("`@
M("`@(#T^($1"7T524D]27TY/5%]&3U5.1"P*("`@("`@("`@("`@("`@("<O
M8V]L=6UN("XJ(&1O97,@;F]T(&5X:7-T+VDG"B`@("`@("`@("`@("`@("`@
M("`@/3X@1$)?15)23U)?3D]354-(1DE%3$0L"B`@("`@("`@("`@("`@("`G
M+W)E;&%T:6]N("XJ(&%L<F5A9'D@97AI<W1S+VDG"B`@("`@("`@("`@("`@
M("`@("`@/3X@1$)?15)23U)?04Q214%$65]%6$E35%,L"B`@("`@("`@("`@
M("`@("`G+RAD:79I9&5\9&EV:7-I;VXI(&)Y('IE<F\D+VDG"B`@("`@("`@
M("`@("`@("`@("`@/3X@1$)?15)23U)?1$E66D523RP*("`@("`@("`@("`@
M("`@("<O<&=?871O:3H@97)R;W(@:6X@+BHZ(&-A;EPG="!P87)S92`O:2<*
M("`@("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/4E])3E9!3$E$7TY534)%
M4BP*("`@("`@("`@("`@("`@("<O:6YV86QI9"!I;G!U="!S>6YT87@@9F]R
M*"!T>7!E*3\@*&EN=&5G97)\;G5M97)I8RDO:2<*("`@("`@("`@("`@("`@
M("`@("`]/B!$0E]%4E)/4E])3E9!3$E$7TY534)%4BP*("`@("`@("`@("`@
M("`@("<O=F%L=64@+BH@:7,@;W5T(&]F(')A;F=E(&9O<B!T>7!E(%QW*FEN
M="]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27TE.5D%,241?
M3E5-0D52+`H@("`@("`@("`@("`@("`@)R]I;G1E9V5R(&]U="!O9B!R86YG
M92]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27TE.5D%,241?
M3E5-0D52+`H@("`@("`@("`@("`@("`@)R]V86QU92!T;V\@;&]N9R!F;W(@
M='EP92!C:&%R86-T97(O:2<*("`@("`@("`@("`@("`@("`@("`]/B!$0E]%
M4E)/4E])3E9!3$E$+`H@("`@("`@("`@("`@("`@)R]A='1R:6)U=&4@+BH@
M;F]T(&9O=6YD?')E;&%T:6]N("XJ(&1O97,@;F]T(&AA=F4@871T<FEB=71E
M+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?3D]354-(1DE%
M3$0L"B`@("`@("`@("`@("`@("`G+V-O;'5M;B`N*B!S<&5C:69I960@:6X@
M55-)3D<@8VQA=7-E(&1O97,@;F]T(&5X:7-T(&EN("AL969T?')I9VAT*2!T
M86)L92]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27TY/4U5#
M2$9)14Q$+`H@("`@("`@("`@("`@("`@)R]P87)S97(Z('!A<G-E(&5R<F]R
M(&%T(&]R(&YE87(O:2<*("`@("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/
M4E]364Y405@L"B`@("`@("`@("`@("`@("`G+W-Y;G1A>"!E<G)O<B!A="\G
M"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?4UE.5$%8+`H@("`@
M("`@("`@("`@("`@)R]C;VQU;6X@<F5F97)E;F-E("XJ(&ES(&%M8FEG=6]U
M<R]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27U-93E1!6"P*
M("`@("`@("`@("`@("`@("<O<&5R;6ES<VEO;B!D96YI960O)PH@("`@("`@
M("`@("`@("`@("`@(#T^($1"7T524D]27T%#0T534U]624],051)3TXL"B`@
M("`@("`@("`@("`@("`G+W9I;VQA=&5S(&YO="UN=6QL(&-O;G-T<F%I;G0O
M)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27T-/3E-44D%)3E1?
M3D]47TY53$PL"B`@("`@("`@("`@("`@("`G+W9I;VQA=&5S(%M<=R!=*R!C
M;VYS=')A:6YT+R<*("`@("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/4E]#
M3TY35%)!24Y4+`H@("`@("`@("`@("`@("`@)R]R969E<F5N=&EA;"!I;G1E
M9W)I='D@=FEO;&%T:6]N+R<*("`@("`@("`@("`@("`@("`@("`]/B!$0E]%
M4E)/4E]#3TY35%)!24Y4+`H@("`@("`@("`@("`@("`@)R]M;W)E(&5X<')E
M<W-I;VYS('1H86X@=&%R9V5T(&-O;'5M;G,O:2<*("`@("`@("`@("`@("`@
M("`@("`]/B!$0E]%4E)/4E]604Q515]#3U5.5%]/3E]23U<L"B`@("`@("`@
M("`@("D["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1E<G)O<E]R96=E
M>'!S(&%S("1R96=E>'`@/3X@)&-O9&4I('L*("`@("`@("`@("`@:68@*'!R
M96=?;6%T8V@H)')E9V5X<"P@)&5R<F]R;7-G*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1C;V1E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@("\O($9A;&P@8F%C:R!T;R!$0E]%4E)/4B!I9B!T:&5R92!W87,@;F\@
M;6%P<&EN9RX*("`@("`@("!R971U<FX@1$)?15)23U(["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@=&%B;&5);F9O*"D*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@:6YF;W)M871I;VX@86)O=70@82!T86)L92!O<B!A(')E<W5L
M="!S970*("`@("`J"B`@("`@*B!.3U1%.B!O;FQY('-U<'!O<G1S("=T86)L
M92<@86YD("=F;&%G<R<@:68@/'9A<CXD<F5S=6QT/"]V87(^"B`@("`@*B!I
M<R!A('1A8FQE(&YA;64N"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C='QS
M=')I;F<@("1R97-U;'0@($1"7W)E<W5L="!O8FIE8W0@9G)O;2!A('%U97)Y
M(&]R(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M<W1R:6YG(&-O;G1A:6YI;F<@=&AE(&YA;64@;V8@82!T86)L92X*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@5VAI;&4@=&AI<R!A
M;'-O(&%C8V5P=',@82!Q=65R>2!R97-U;'0*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@<F5S;W5R8V4@:61E;G1I9FEE<BP@=&AI
M<R!B96AA=FEO<B!I<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!D97!R96-A=&5D+@H@("`@("H@0'!A<F%M(&EN="`@("`@("`@
M("`@("1M;V1E("`@(&$@=F%L:60@=&%B;&5);F9O(&UO9&4*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y("!A;B!A<W-O8VEA=&EV92!A<G)A>2!W:71H
M('1H92!I;F9O<FUA=&EO;B!R97%U97-T960N"B`@("`@*B`@("`@("`@("`@
M("`@("`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@
M("`@*B!`<V5E($1"7V-O;6UO;CHZ=&%B;&5);F9O*"D*("`@("`J+PH@("`@
M9G5N8W1I;VX@=&%B;&5);F9O*"1R97-U;'0L("1M;V1E(#T@;G5L;"D*("`@
M('L*("`@("`@("!I9B`H:7-?<W1R:6YG*"1R97-U;'0I*2!["B`@("`@("`@
M("`@("\J"B`@("`@("`@("`@("`J(%!R;V)A8FQY(')E8V5I=F5D(&$@=&%B
M;&4@;F%M92X*("`@("`@("`@("`@("H@0W)E871E(&$@<F5S=6QT(')E<V]U
M<F-E(&ED96YT:69I97(N"B`@("`@("`@("`@("`J+PH@("`@("`@("`@("`D
M:60@/2!`<&=?97AE8R@D=&AI<RT^8V]N;F5C=&EO;BP@(E-%3$5#5"`J($92
M3TT@)')E<W5L="!,24U)5"`P(BD["B`@("`@("`@("`@("1G;W1?<W1R:6YG
M(#T@=')U93L*("`@("`@("!](&5L<V5I9B`H:7-S970H)')E<W5L="T^<F5S
M=6QT*2D@>PH@("`@("`@("`@("`O*@H@("`@("`@("`@("`@*B!0<F]B86)L
M>2!R96-E:79E9"!A(')E<W5L="!O8FIE8W0N"B`@("`@("`@("`@("`J($5X
M=')A8W0@=&AE(')E<W5L="!R97-O=7)C92!I9&5N=&EF:65R+@H@("`@("`@
M("`@("`@*B\*("`@("`@("`@("`@)&ED(#T@)')E<W5L="T^<F5S=6QT.PH@
M("`@("`@("`@("`D9V]T7W-T<FEN9R`](&9A;'-E.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("\J"B`@("`@("`@("`@("`J(%!R;V)A8FQY(')E
M8V5I=F5D(&$@<F5S=6QT(')E<V]U<F-E(&ED96YT:69I97(N"B`@("`@("`@
M("`@("`J($-O<'D@:70N"B`@("`@("`@("`@("`J($1E<')E8V%T960N("!(
M97)E(&9O<B!C;VUP871I8FEL:71Y(&]N;'DN"B`@("`@("`@("`@("`J+PH@
M("`@("`@("`@("`D:60@/2`D<F5S=6QT.PH@("`@("`@("`@("`D9V]T7W-T
M<FEN9R`](&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I<U]R97-O
M=7)C92@D:60I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<&=S<6Q2
M86ES945R<F]R*$1"7T524D]27TY%141?34]215]$051!*3L*("`@("`@("!]
M"@H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F
M($1"7U!/4E1!0DE,25197TQ/5T520T%312D@>PH@("`@("`@("`@("`D8V%S
M95]F=6YC(#T@)W-T<G1O;&]W97(G.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1C87-E7V9U;F,@/2`G<W1R=F%L)SL*("`@("`@("!]"@H@("`@
M("`@("1C;W5N="`]($!P9U]N=6UF:65L9',H)&ED*3L*("`@("`@("`D<F5S
M("`@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H)&UO9&4I('L*("`@("`@("`@
M("`@)')E<ULG;G5M7V9I96QD<R==(#T@)&-O=6YT.PH@("`@("`@('T*"B`@
M("`@("`@9F]R("@D:2`](#`[("1I(#P@)&-O=6YT.R`D:2LK*2!["B`@("`@
M("`@("`@("1R97-;)&E=(#T@87)R87DH"B`@("`@("`@("`@("`@("`G=&%B
M;&4G(#T^("1G;W1?<W1R:6YG(#\@)&-A<V5?9G5N8R@D<F5S=6QT*2`Z("<G
M+`H@("`@("`@("`@("`@("`@)VYA;64G("`]/B`D8V%S95]F=6YC*$!P9U]F
M:65L9&YA;64H)&ED+"`D:2DI+`H@("`@("`@("`@("`@("`@)W1Y<&4G("`]
M/B!`<&=?9FEE;&1T>7!E*"1I9"P@)&DI+`H@("`@("`@("`@("`@("`@)VQE
M;B<@("`]/B!`<&=?9FEE;&1S:7IE*"1I9"P@)&DI+`H@("`@("`@("`@("`@
M("`@)V9L86=S)R`]/B`D9V]T7W-T<FEN9PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`_("1T:&ES+3Y?<&=&:65L9$9L86=S*"1I9"P@)&DL("1R97-U
M;'0I"B`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@)R<L"B`@("`@("`@
M("`@("D["B`@("`@("`@("`@(&EF("@D;6]D92`F($1"7U1!0DQ%24Y&3U]/
M4D1%4BD@>PH@("`@("`@("`@("`@("`@)')E<ULG;W)D97(G75LD<F5S6R1I
M75LG;F%M92==72`]("1I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("@D;6]D92`F($1"7U1!0DQ%24Y&3U]/4D1%4E1!0DQ%*2!["B`@("`@("`@
M("`@("`@("`D<F5S6R=O<F1E<G1A8FQE)UU;)')E<ULD:5U;)W1A8FQE)UU=
M6R1R97-;)&E=6R=N86UE)UU=(#T@)&D["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("\O(&9R964@=&AE(')E<W5L="!O;FQY(&EF('=E('=E
M<F4@8V%L;&5D(&]N(&$@=&%B;&4*("`@("`@("!I9B`H)&=O=%]S=')I;F<I
M('L*("`@("`@("`@("`@0'!G7V9R965R97-U;'0H)&ED*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1R97,["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@7W!G1FEE;&1&;&%G<R@I"@H@("`@+RHJ"B`@("`@*B!'970@82!C
M;VQU;6XG<R!F;&%G<PH@("`@("H*("`@("`J(%-U<'!O<G1S(")N;W1?;G5L
M;"(L(")D969A=6QT7W9A;'5E(BP@(G!R:6UA<GE?:V5Y(BP@(G5N:7%U95]K
M97DB"B`@("`@*B!A;F0@(FUU;'1I<&QE7VME>2(N("!4:&4@9&5F875L="!V
M86QU92!I<R!P87-S960@=&AR;W5G:`H@("`@("H@<F%W=7)L96YC;V1E*"D@
M:6X@8V%S92!T:&5R92!A<F4@<W!A8V5S(&EN(&ET+@H@("`@("H*("`@("`J
M($!P87)A;2!I;G0@)')E<V]U<F-E("`@=&AE(%!O<W1G<F5344P@<F5S=6QT
M(&ED96YT:69I97(*("`@("`J($!P87)A;2!I;G0@)&YU;5]F:65L9"`@=&AE
M(&9I96QD(&YU;6)E<@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T
M:&4@9FQA9W,*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M+PH@("`@9G5N8W1I;VX@7W!G1FEE;&1&;&%G<R@D<F5S;W5R8V4L("1N=6U?
M9FEE;&0L("1T86)L95]N86UE*0H@("`@>PH@("`@("`@("1F:65L9%]N86UE
M(#T@0'!G7V9I96QD;F%M92@D<F5S;W5R8V4L("1N=6U?9FEE;&0I.PH*("`@
M("`@("`D<F5S=6QT(#T@0'!G7V5X96,H)'1H:7,M/F-O;FYE8W1I;VXL(")3
M14Q%0U0@9BYA='1N;W1N=6QL+"!F+F%T=&AA<V1E9@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@($923TT@<&=?871T<FEB=71E(&8L('!G7V-L
M87-S('1A8BP@<&=?='EP92!T>7`*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!72$5212!T86(N<F5L;F%M92`]('1Y<"YT>7!N86UE"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@04Y$('1Y<"YT>7!R96QI9"`]
M(&8N871T<F5L:60*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!!
M3D0@9BYA='1N86UE(#T@)R1F:65L9%]N86UE)PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@($%.1"!T86(N<F5L;F%M92`]("<D=&%B;&5?;F%M
M92<B*3L*("`@("`@("!I9B`H0'!G7VYU;7)O=W,H)')E<W5L="D@/B`P*2![
M"B`@("`@("`@("`@("1R;W<@/2!`<&=?9F5T8VA?<F]W*"1R97-U;'0L(#`I
M.PH@("`@("`@("`@("`D9FQA9W,@(#T@*"1R;W=;,%T@/3T@)W0G*2`_("=N
M;W1?;G5L;"`G(#H@)R<["@H@("`@("`@("`@("!I9B`H)')O=ULQ72`]/2`G
M="<I('L*("`@("`@("`@("`@("`@("1R97-U;'0@/2!`<&=?97AE8R@D=&AI
M<RT^8V]N;F5C=&EO;BP@(E-%3$5#5"!A+F%D<W)C"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@($923TT@<&=?871T<FEB=71E(&8L('!G
M7V-L87-S('1A8BP@<&=?='EP92!T>7`L('!G7V%T=')D968@80H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!72$5212!T86(N<F5L;F%M
M92`]('1Y<"YT>7!N86UE($%.1"!T>7`N='EP<F5L:60@/2!F+F%T=')E;&ED
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($%.1"!F+F%T
M=')E;&ED(#T@82YA9')E;&ED($%.1"!F+F%T=&YA;64@/2`G)&9I96QD7VYA
M;64G"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($%.1"!T
M86(N<F5L;F%M92`]("<D=&%B;&5?;F%M92<@04Y$(&8N871T;G5M(#T@82YA
M9&YU;2(I.PH@("`@("`@("`@("`@("`@)')O=R`]($!P9U]F971C:%]R;W<H
M)')E<W5L="P@,"D["B`@("`@("`@("`@("`@("`D;G5M(#T@<')E9U]R97!L
M86-E*"(O)R@N*BDG.CI<=RLO(BP@(EQ<,2(L("1R;W=;,%TI.PH@("`@("`@
M("`@("`@("`@)&9L86=S("X]("=D969A=6QT7R<@+B!R87=U<FQE;F-O9&4H
M)&YU;2D@+B`G("<["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D9FQA9W,@/2`G)SL*("`@("`@("!]"B`@("`@("`@)')E
M<W5L="`]($!P9U]E>&5C*"1T:&ES+3YC;VYN96-T:6]N+"`B4T5,14-4(&DN
M:6YD:7-U;FEQ=64L(&DN:6YD:7-P<FEM87)Y+"!I+FEN9&ME>0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@($923TT@<&=?871T<FEB=71E(&8L
M('!G7V-L87-S('1A8BP@<&=?='EP92!T>7`L('!G7VEN9&5X(&D*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!72$5212!T86(N<F5L;F%M92`]
M('1Y<"YT>7!N86UE"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M04Y$('1Y<"YT>7!R96QI9"`](&8N871T<F5L:60*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!!3D0@9BYA='1R96QI9"`](&DN:6YD<F5L:60*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!!3D0@9BYA='1N86UE
M(#T@)R1F:65L9%]N86UE)PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@($%.1"!T86(N<F5L;F%M92`]("<D=&%B;&5?;F%M92<B*3L*("`@("`@
M("`D8V]U;G0@/2!`<&=?;G5M<F]W<R@D<F5S=6QT*3L*"B`@("`@("`@9F]R
M("@D:2`](#`[("1I(#P@)&-O=6YT(#L@)&DK*RD@>PH@("`@("`@("`@("`D
M<F]W(#T@0'!G7V9E=&-H7W)O=R@D<F5S=6QT+"`D:2D["B`@("`@("`@("`@
M("1K97ES(#T@97AP;&]D92@G("<L("1R;W=;,ETI.PH*("`@("`@("`@("`@
M:68@*&EN7V%R<F%Y*"1N=6U?9FEE;&0@*R`Q+"`D:V5Y<RDI('L*("`@("`@
M("`@("`@("`@("1F;&%G<R`N/2`H)')O=ULP72`]/2`G="<@)B8@)')O=ULQ
M72`]/2`G9B<I(#\@)W5N:7%U95]K97D@)R`Z("<G.PH@("`@("`@("`@("`@
M("`@)&9L86=S("X]("@D<F]W6S%=(#T]("=T)RD@/R`G<')I;6%R>5]K97D@
M)R`Z("<G.PH@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1K97ES*2`^(#$I
M"B`@("`@("`@("`@("`@("`@("`@)&9L86=S("X]("=M=6QT:7!L95]K97D@
M)SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R
M:6TH)&9L86=S*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G9713
M<&5C:6%L475E<GDH*0H*("`@("\J*@H@("`@("H@3V)T86EN<R!T:&4@<75E
M<GD@<W1R:6YG(&YE961E9"!F;W(@;&ES=&EN9R!A(&=I=F5N('1Y<&4@;V8@
M;V)J96-T<PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@('1H
M92!K:6YD(&]F(&]B:F5C=',@>6]U('=A;G0@=&\@<F5T<FEE=F4*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(%-13"!Q=65R>2!S=')I;F<@
M;W(@;G5L;"!I9B!T:&4@9')I=F5R(&1O97-N)W0*("`@("`J("`@("`@("`@
M("`@("`@("`@<W5P<&]R="!T:&4@;V)J96-T('1Y<&4@<F5Q=65S=&5D"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J($!S964@1$)?
M8V]M;6]N.CIG971,:7-T3V8H*0H@("`@("HO"B`@("!F=6YC=&EO;B!G9713
M<&5C:6%L475E<GDH)'1Y<&4I"B`@("!["B`@("`@("`@<W=I=&-H("@D='EP
M92D@>PH@("`@("`@("`@("!C87-E("=T86)L97,G.@H@("`@("`@("`@("`@
M("`@<F5T=7)N("=314Q%0U0@8RYR96QN86UE($%3(").86UE(B<*("`@("`@
M("`@("`@("`@("`@("`@("`@+B`G($923TT@<&=?8VQA<W,@8RP@<&=?=7-E
M<B!U)PH@("`@("`@("`@("`@("`@("`@("`@("`N("<@5TA%4D4@8RYR96QO
M=VYE<B`]('4N=7-E<WES:60G"B`@("`@("`@("`@("`@("`@("`@("`@("X@
M(B!!3D0@8RYR96QK:6YD(#T@)W(G(@H@("`@("`@("`@("`@("`@("`@("`@
M("`N("<@04Y$($Y/5"!%6$E35%,G"B`@("`@("`@("`@("`@("`@("`@("`@
M("X@)R`H4T5,14-4(#$@1E)/32!P9U]V:65W<R<*("`@("`@("`@("`@("`@
M("`@("`@("`@+B`G("!72$5212!V:65W;F%M92`](&,N<F5L;F%M92DG"B`@
M("`@("`@("`@("`@("`@("`@("`@("X@(B!!3D0@8RYR96QN86UE("%^("=>
M*'!G7WQS<6Q?*2<B"B`@("`@("`@("`@("`@("`@("`@("`@("X@)R!53DE/
M3B<*("`@("`@("`@("`@("`@("`@("`@("`@+B`G(%-%3$5#5"!C+G)E;&YA
M;64@05,@(DYA;64B)PH@("`@("`@("`@("`@("`@("`@("`@("`N("<@1E)/
M32!P9U]C;&%S<R!C)PH@("`@("`@("`@("`@("`@("`@("`@("`N("(@5TA%
M4D4@8RYR96QK:6YD(#T@)W(G(@H@("`@("`@("`@("`@("`@("`@("`@("`N
M("<@04Y$($Y/5"!%6$E35%,G"B`@("`@("`@("`@("`@("`@("`@("`@("X@
M)R`H4T5,14-4(#$@1E)/32!P9U]V:65W<R<*("`@("`@("`@("`@("`@("`@
M("`@("`@+B`G("!72$5212!V:65W;F%M92`](&,N<F5L;F%M92DG"B`@("`@
M("`@("`@("`@("`@("`@("`@("X@)R!!3D0@3D]4($5825-44R<*("`@("`@
M("`@("`@("`@("`@("`@("`@+B`G("A314Q%0U0@,2!&4D]-('!G7W5S97(G
M"B`@("`@("`@("`@("`@("`@("`@("`@("X@)R`@5TA%4D4@=7-E<WES:60@
M/2!C+G)E;&]W;F5R*2<*("`@("`@("`@("`@("`@("`@("`@("`@+B`B($%.
M1"!C+G)E;&YA;64@(7X@)UYP9U\G(CL*("`@("`@("`@("`@8V%S92`G<V-H
M96UA+G1A8FQE<R<Z"B`@("`@("`@("`@("`@("!R971U<FX@(E-%3$5#5"!S
M8VAE;6%N86UE('Q\("<N)R!\?"!T86)L96YA;64B"B`@("`@("`@("`@("`@
M("`@("`@("`@("X@)R!!4R`B3F%M92(G"B`@("`@("`@("`@("`@("`@("`@
M("`@("X@)R!&4D]-('!G7V-A=&%L;V<N<&=?=&%B;&5S)PH@("`@("`@("`@
M("`@("`@("`@("`@("`N("<@5TA%4D4@<V-H96UA;F%M92!.3U0@24XG"B`@
M("`@("`@("`@("`@("`@("`@("`@("X@(B`H)W!G7V-A=&%L;V<G+"`G:6YF
M;W)M871I;VY?<V-H96UA)RP@)W!G7W1O87-T)RDB.PH@("`@("`@("`@("!C
M87-E("=V:65W<R<Z"B`@("`@("`@("`@("`@("`O+R!486)L92!C;VQS.B!V
M:65W;F%M92!\('9I97=O=VYE<B!\(&1E9FEN:71I;VX*("`@("`@("`@("`@
M("`@(')E='5R;B`G4T5,14-4('9I97=N86UE(&9R;VT@<&=?=FEE=W,@5TA%
M4D4@<V-H96UA;F%M92<*("`@("`@("`@("`@("`@("`@("`@("`@+B`B($Y/
M5"!)3B`H)VEN9F]R;6%T:6]N7W-C:&5M82<L("=P9U]C871A;&]G)RDB.PH@
M("`@("`@("`@("!C87-E("=U<V5R<R<Z"B`@("`@("`@("`@("`@("`O+R!C
M;VQS.B!U<V5N86UE('QU<V5S>7-I9'QU<V5C<F5A=&5D8GQU<V5T<F%C97QU
M<V5S=7!E<GQU<V5C871U<&1\<&%S<W=D("!\=F%L=6YT:6P*("`@("`@("`@
M("`@("`@(')E='5R;B`G4T5,14-4('5S96YA;64@1E)/32!P9U]U<V5R)SL*
M("`@("`@("`@("`@8V%S92`G9&%T86)A<V5S)SH*("`@("`@("`@("`@("`@
M(')E='5R;B`G4T5,14-4(&1A=&YA;64@1E)/32!P9U]D871A8F%S92<["B`@
M("`@("`@("`@(&-A<V4@)V9U;F-T:6]N<R<Z"B`@("`@("`@("`@(&-A<V4@
M)W!R;V-E9'5R97,G.@H@("`@("`@("`@("`@("`@<F5T=7)N("=314Q%0U0@
M<')O;F%M92!&4D]-('!G7W!R;V,@5TA%4D4@<')O;W=N97(@/#X@,2<["B`@
M("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!R971U<FX@;G5L
M;#L*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"@I]"@HO*@H@*B!,;V-A
M;"!V87)I86)L97,Z"B`J('1A8BUW:61T:#H@-`H@*B!C+6)A<VEC+6]F9G-E
M=#H@-`H@*B!%;F0Z"B`J+PH*/SX*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]$0B]S>6)A<V4N<&AP````````````````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#8V-#`S(#$P-3$U-#,S-S,Q(#`R,#<V,0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`H*+RH@
M=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F
M='1A8G-T;W`]-#H@*B\*"B\J*@H@*B!4:&4@4$5!4B!$0B!D<FEV97(@9F]R
M(%!(4"=S('-Y8F%S92!E>'1E;G-I;VX*("H@9F]R(&EN=&5R86-T:6YG('=I
M=&@@4WEB87-E(&1A=&%B87-E<PH@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@
M-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@
M=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@
M879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F
M;VQL;W=I;F<@55)).@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S
M7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@
M=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T
M:')O=6=H('1H92!W96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E
M;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA
M=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@
M("`@1$(*("H@0&%U=&AO<B`@("`@4W1E<FQI;F<@2'5G:&5S(#QS=&5R;&EN
M9T!P:'`N;F5T/@H@*B!`875T:&]R("`@("!!;G3T;FEO($-A<FQO<R!696[B
M;F-I;R!*^FYI;W(@/&9L;W)I<&%`<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@
M1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I
M9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS
M92`S+C`*("H@0'9E<G-I;VX@("`@0U93.B`D260Z('-Y8F%S92YP:'`L=B`Q
M+C<X(#(P,#4O,#(O,C`@,#`Z-#0Z-#@@9&%N:65L8R!%>'`@)`H@*B!`;&EN
M:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO"@HO
M*BH*("H@3V)T86EN('1H92!$0E]C;VUM;VX@8VQA<W,@<V\@:70@8V%N(&)E
M(&5X=&5N9&5D(&9R;VT*("HO"G)E<75I<F5?;VYC92`G1$(O8V]M;6]N+G!H
M<"<["@HO*BH*("H@5&AE(&UE=&AO9',@4$5!4B!$0B!U<V5S('1O(&EN=&5R
M86-T('=I=&@@4$A0)W,@<WEB87-E(&5X=&5N<VEO;@H@*B!F;W(@:6YT97)A
M8W1I;F<@=VET:"!3>6)A<V4@9&%T86)A<V5S"B`J"B`J(%1H97-E(&UE=&AO
M9',@;W9E<FQO860@=&AE(&]N97,@9&5C;&%R960@:6X@1$)?8V]M;6]N+@H@
M*@H@*B!705).24Y'.B`@5&AI<R!D<FEV97(@;6%Y(&9A:6P@=VET:"!M=6QT
M:7!L92!C;VYN96-T:6]N<R!U;F1E<B!T:&4*("H@<V%M92!U<V5R+W!A<W,O
M:&]S="!A;F0@9&EF9F5R96YT(&1A=&%B87-E<RX*("H*("H@0&-A=&5G;W)Y
M("`@1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@
M4W1E<FQI;F<@2'5G:&5S(#QS=&5R;&EN9T!P:'`N;F5T/@H@*B!`875T:&]R
M("`@("!!;G3T;FEO($-A<FQO<R!696[B;F-I;R!*^FYI;W(@/&9L;W)I<&%`
M<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N
M:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(
M4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@
M4F5L96%S93H@,2XW+C8*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP
M+FYE="]P86-K86=E+T1""B`J+PIC;&%S<R!$0E]S>6)A<V4@97AT96YD<R!$
M0E]C;VUM;VX*>PH@("`@+R\@>WM[('!R;W!E<G1I97,*"B`@("`O*BH*("`@
M("`J(%1H92!$0B!D<FEV97(@='EP92`H;7ES<6PL(&]C:3@L(&]D8F,L(&5T
M8RXI"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)'!H<'1Y
M<&4@/2`G<WEB87-E)SL*"B`@("`O*BH*("`@("`J(%1H92!D871A8F%S92!S
M>6YT87@@=F%R:6%N="!T;R!B92!U<V5D("AD8C(L(&%C8V5S<RP@971C+BDL
M(&EF(&%N>0H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1D
M8G-Y;G1A>"`]("=S>6)A<V4G.PH*("`@("\J*@H@("`@("H@5&AE(&-A<&%B
M:6QI=&EE<R!O9B!T:&ES($1"(&EM<&QE;65N=&%T:6]N"B`@("`@*@H@("`@
M("H@5&AE("=N97=?;&EN:R<@96QE;65N="!C;VYT86EN<R!T:&4@4$A0('9E
M<G-I;VX@=&AA="!F:7)S="!P<F]V:61E9`H@("`@("H@;F5W7VQI;FL@<W5P
M<&]R="!F;W(@=&AI<R!$0DU3+B`@0V]N=&%I;G,@9F%L<V4@:68@:70G<R!U
M;G-U<'!O<G1E9"X*("`@("`J"B`@("`@*B!-96%N:6YG(&]F('1H92`G;&EM
M:70G(&5L96UE;G0Z"B`@("`@*B`@("L@)V5M=6QA=&4G(#T@96UU;&%T92!W
M:71H(&9E=&-H(')O=R!B>2!N=6UB97(*("`@("`J("`@*R`G86QT97(G("`@
M/2!A;'1E<B!T:&4@<75E<GD*("`@("`J("`@*R!F86QS92`@("`@/2!S:VEP
M(')O=W,*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D9F5A='5R97,@/2!A<G)A>2@*("`@("`@("`G;&EM:70G("`@("`@("`@
M/3X@)V5M=6QA=&4G+`H@("`@("`@("=N97=?;&EN:R<@("`@("`]/B!F86QS
M92P*("`@("`@("`G;G5M<F]W<R<@("`@("`@/3X@=')U92P*("`@("`@("`G
M<&-O;FYE8W0G("`@("`@/3X@=')U92P*("`@("`@("`G<')E<&%R92<@("`@
M("`@/3X@9F%L<V4L"B`@("`@("`@)W-S;"<@("`@("`@("`@(#T^(&9A;'-E
M+`H@("`@("`@("=T<F%N<V%C=&EO;G,G("`]/B!T<G5E+`H@("`@*3L*"B`@
M("`O*BH*("`@("`J($$@;6%P<&EN9R!O9B!N871I=F4@97)R;W(@8V]D97,@
M=&\@1$(@97)R;W(@8V]D97,*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1E<G)O<F-O9&5?;6%P(#T@87)R87DH"B`@("`I.PH*("`@("\J
M*@H@("`@("H@5&AE(')A=R!D871A8F%S92!C;VYN96-T:6]N(&-R96%T960@
M8GD@4$A0"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D
M8V]N;F5C=&EO;CL*"B`@("`O*BH*("`@("`J(%1H92!$4TX@:6YF;W)M871I
M;VX@9F]R(&-O;FYE8W1I;F<@=&\@82!D871A8F%S90H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)&1S;B`](&%R<F%Y*"D["@H*("`@("\J
M*@H@("`@("H@4VAO=6QD(&1A=&$@;6%N:7!U;&%T:6]N('%U97)I97,@8F4@
M8V]M;6ET=&5D(&%U=&]M871I8V%L;'D_"B`@("`@*B!`=F%R(&)O;VP*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)&%U=&]C;VUM
M:70@/2!T<G5E.PH*("`@("\J*@H@("`@("H@5&AE('%U86YT:71Y(&]F('1R
M86YS86-T:6]N<R!B96=U;@H@("`@("H*("`@("`J('M`:6YT97)N86P@(%=H
M:6QE('1H:7,@:7,@<')I=F%T92P@:70@8V%N)W0@86-T=6%L;'D@8F4@9&5S
M:6=N871E9`H@("`@("H@<')I=F%T92!I;B!02%`@-2!B96-A=7-E(&ET(&ES
M(&1I<F5C=&QY(&%C8V5S<V5D(&EN('1H92!T97-T('-U:71E+GU]"B`@("`@
M*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J+PH@("`@=F%R("1T<F%N<V%C=&EO;E]O<&-O=6YT(#T@,#L*"B`@
M("`O*BH*("`@("`J(%1H92!D871A8F%S92!S<&5C:69I960@:6X@=&AE($13
M3@H@("`@("H*("`@("`J($ET)W,@82!F:7@@=&\@86QL;W<@8V%L;',@=&\@
M9&EF9F5R96YT(&1A=&%B87-E<R!I;B!T:&4@<V%M92!S8W)I<'0N"B`@("`@
M*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("HO"B`@("!V87(@)%]D8B`]("<G.PH*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!C;VYS=')U8W1O<@H*("`@("\J*@H@("`@("H@5&AI<R!C;VYS=')U
M8W1O<B!C86QL<R`\:V)D/B1T:&ES+3Y$0E]C;VUM;VXH*3PO:V)D/@H@("`@
M("H*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!$
M0E]S>6)A<V4H*0H@("`@>PH@("`@("`@("1T:&ES+3Y$0E]C;VUM;VXH*3L*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VYN96-T*"D*"B`@("`O
M*BH*("`@("`J($-O;FYE8W0@=&\@=&AE(&1A=&%B87-E('-E<G9E<BP@;&]G
M(&EN(&%N9"!O<&5N('1H92!D871A8F%S90H@("`@("H*("`@("`J($1O;B=T
M(&-A;&P@=&AI<R!M971H;V0@9&ER96-T;'DN("!5<V4@1$(Z.F-O;FYE8W0H
M*2!I;G-T96%D+@H@("`@("H*("`@("`J(%!%05(@1$(G<R!S>6)A<V4@9')I
M=F5R('-U<'!O<G1S('1H92!F;VQL;W=I;F<@97AT<F$@1%-.(&]P=&EO;G,Z
M"B`@("`@*B`@("L@87!P;F%M92`@("`@("!4:&4@87!P;&EC871I;VX@;F%M
M92!T;R!U<V4@;VX@=&AI<R!C;VYN96-T:6]N+@H@("`@("H@("`@("`@("`@
M("`@("`@("`@079A:6QA8FQE('-I;F-E(%!%05(@1$(@,2XW+C`N"B`@("`@
M*B`@("L@8VAA<G-E="`@("`@("!4:&4@8VAA<F%C=&5R('-E="!T;R!U<V4@
M;VX@=&AI<R!C;VYN96-T:6]N+@H@("`@("H@("`@("`@("`@("`@("`@("`@
M079A:6QA8FQE('-I;F-E(%!%05(@1$(@,2XW+C`N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1D<VX@("`@("`@("!T:&4@9&%T82!S;W5R8V4@;F%M
M90H@("`@("H@0'!A<F%M(&)O;VP@("1P97)S:7-T96YT("!S:&]U;&0@=&AE
M(&-O;FYE8W1I;VX@8F4@<&5R<VES=&5N=#\*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@02!$0E]%<G)O<B!O8FIE8W0@
M;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]N;F5C="@D9'-N
M+"`D<&5R<VES=&5N="`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@A4$5!
M4CHZ;&]A9$5X=&5N<VEO;B@G<WEB87-E)RD@)B8*("`@("`@("`@("`@(5!%
M05(Z.FQO861%>'1E;G-I;VXH)W-Y8F%S95]C="<I*0H@("`@("`@('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27T58
M5$5.4TE/3E].3U1?1D]53D0I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M
M/F1S;B`]("1D<VX["B`@("`@("`@:68@*"1D<VY;)V1B<WEN=&%X)UTI('L*
M("`@("`@("`@("`@)'1H:7,M/F1B<WEN=&%X(#T@)&1S;ELG9&)S>6YT87@G
M73L*("`@("`@("!]"@H@("`@("`@("1D<VY;)VAO<W1S<&5C)UT@/2`D9'-N
M6R=H;W-T<W!E8R==(#\@)&1S;ELG:&]S='-P96,G72`Z("=L;V-A;&AO<W0G
M.PH@("`@("`@("1D<VY;)W!A<W-W;W)D)UT@/2`A96UP='DH)&1S;ELG<&%S
M<W=O<F0G72D@/R`D9'-N6R=P87-S=V]R9"==(#H@9F%L<V4["B`@("`@("`@
M)&1S;ELG8VAA<G-E="==(#T@:7-S970H)&1S;ELG8VAA<G-E="==*2`_("1D
M<VY;)V-H87)S970G72`Z(&9A;'-E.PH@("`@("`@("1D<VY;)V%P<&YA;64G
M72`](&ES<V5T*"1D<VY;)V%P<&YA;64G72D@/R`D9'-N6R=A<'!N86UE)UT@
M.B!F86QS93L*"B`@("`@("`@)&-O;FYE8W1?9G5N8W1I;VX@/2`D<&5R<VES
M=&5N="`_("=S>6)A<V5?<&-O;FYE8W0G(#H@)W-Y8F%S95]C;VYN96-T)SL*
M"B`@("`@("`@:68@*"1D<VY;)W5S97)N86UE)UTI('L*("`@("`@("`@("`@
M)'1H:7,M/F-O;FYE8W1I;VX@/2!`)&-O;FYE8W1?9G5N8W1I;VXH)&1S;ELG
M:&]S='-P96,G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&1S;ELG=7-E<FYA;64G72P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1S
M;ELG<&%S<W=O<F0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&1S;ELG8VAA<G-E="==+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M9'-N6R=A<'!N86UE)UTI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E]#3TY.14-47T9!
M24Q%1"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YU
M;&PL(&YU;&PL(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G5&AE($133B!D:60@;F]T(&-O;G1A:6X@82!U<V5R;F%M92XG
M*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A)'1H:7,M/F-O;FYE8W1I;VXI
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T52
M4D]27T-/3DY%0U1?1D%)3$5$+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@;G5L;"P@;G5L;"P@;G5L;"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@($!S>6)A<V5?9V5T7VQA<W1?;65S<V%G
M92@I*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D9'-N6R=D871A8F%S92==
M*2!["B`@("`@("`@("`@(&EF("@A0'-Y8F%S95]S96QE8W1?9&(H)&1S;ELG
M9&%T86)A<V4G72P@)'1H:7,M/F-O;FYE8W1I;VXI*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?3D]$0E-%
M3$5#5$5$+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&YU;&PL(&YU;&PL(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@0'-Y8F%S95]G971?;&%S=%]M97-S86=E*"DI
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?9&(@/2`D9'-N
M6R=D871A8F%S92==.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N($1"7T]+
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&1I<V-O;FYE8W0H*0H*
M("`@("\J*@H@("`@("H@1&ES8V]N;F5C=',@9G)O;2!T:&4@9&%T86)A<V4@
M<V5R=F5R"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L("!44E5%(&]N('-U
M8V-E<W,L($9!3%-%(&]N(&9A:6QU<F4*("`@("`J+PH@("`@9G5N8W1I;VX@
M9&ES8V]N;F5C="@I"B`@("!["B`@("`@("`@)')E="`]($!S>6)A<V5?8VQO
M<V4H)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@("1T:&ES+3YC;VYN96-T
M:6]N(#T@;G5L;#L*("`@("`@("!R971U<FX@)')E=#L*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!S:6UP;&51=65R>2@I"@H@("`@+RHJ"B`@("`@
M*B!396YD<R!A('%U97)Y('1O('1H92!D871A8F%S92!S97)V97(*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("!T:&4@4U%,('%U97)Y('-T<FEN9PH@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@("L@82!02%`@<F5S=6QT(')E
M<W)O=6-E(&9O<B!S=6-C97-S9G5L(%-%3$5#5"!Q=65R:65S"B`@("`@*B`@
M("`@("`@("`@("`@("`K('1H92!$0E]/2R!C;VYS=&%N="!F;W(@;W1H97(@
M<W5C8V5S<V9U;"!Q=65R:65S"B`@("`@*B`@("`@("`@("`@("`@("`K(&$@
M1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4*("`@("`J+PH@("`@9G5N8W1I
M;VX@<VEM<&QE475E<GDH)'%U97)Y*0H@("`@>PH@("`@("`@("1I<VUA;FEP
M(#T@1$(Z.FES36%N:7`H)'%U97)Y*3L*("`@("`@("`D=&AI<RT^;&%S=%]Q
M=65R>2`]("1Q=65R>3L*("`@("`@("!I9B`H(4!S>6)A<V5?<V5L96-T7V1B
M*"1T:&ES+3Y?9&(L("1T:&ES+3YC;VYN96-T:6]N*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G-Y8F%S95)A:7-E17)R;W(H1$)?15)23U)?3D]$
M0E-%3$5#5$5$*3L*("`@("`@("!]"B`@("`@("`@)'%U97)Y(#T@)'1H:7,M
M/FUO9&EF>5%U97)Y*"1Q=65R>2D["B`@("`@("`@:68@*"$D=&AI<RT^875T
M;V-O;6UI="`F)B`D:7-M86YI<"D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M
M/G1R86YS86-T:6]N7V]P8V]U;G0@/3T@,"D@>PH@("`@("`@("`@("`@("`@
M)')E<W5L="`]($!S>6)A<V5?<75E<GDH)T)%1TE.(%1204Y304-424].)RP@
M)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@("`@("`@:68@*"$D<F5S
M=6QT*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YS>6)A
M<V5286ES945R<F]R*"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)'1H:7,M/G1R86YS86-T:6]N7V]P8V]U;G0K*SL*
M("`@("`@("!]"B`@("`@("`@)')E<W5L="`]($!S>6)A<V5?<75E<GDH)'%U
M97)Y+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@:68@*"$D<F5S=6QT
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<WEB87-E4F%I<V5%<G)O
M<B@I.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?<F5S;W5R8V4H)')E<W5L
M="DI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@
M("`@("`@("\O($1E=&5R;6EN92!W:&EC:"!Q=65R:65S('1H870@<VAO=6QD
M(')E='5R;B!D871A+"!A;F0@=VAI8V@*("`@("`@("`O+R!S:&]U;&0@<F5T
M=7)N(&%N(&5R<F]R(&-O9&4@;VYL>2X*("`@("`@("!R971U<FX@)&ES;6%N
M:7`@/R!$0E]/2R`Z("1R97-U;'0["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@;F5X=%)E<W5L="@I"@H@("`@+RHJ"B`@("`@*B!-;W9E('1H92!I
M;G1E<FYA;"!S>6)A<V4@<F5S=6QT('!O:6YT97(@=&\@=&AE(&YE>'0@879A
M:6QA8FQE(')E<W5L=`H@("`@("H*("`@("`J($!P87)A;2!A('9A;&ED('-Y
M8F%S92!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("H*("`@("`J($!R971U<FX@=')U92!I9B!A(')E<W5L="!I
M<R!A=F%I;&%B;&4@;W1H97)W:7-E(')E='5R;B!F86QS90H@("`@("HO"B`@
M("!F=6YC=&EO;B!N97AT4F5S=6QT*"1R97-U;'0I"B`@("!["B`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&9E
M=&-H26YT;R@I"@H@("`@+RHJ"B`@("`@*B!0;&%C97,@82!R;W<@9G)O;2!T
M:&4@<F5S=6QT('-E="!I;G1O('1H92!G:79E;B!A<G)A>0H@("`@("H*("`@
M("`J($9O<FUA=&EN9R!O9B!T:&4@87)R87D@86YD('1H92!D871A('1H97)E
M:6X@87)E(&-O;F9I9W5R86)L92X*("`@("`J(%-E92!$0E]R97-U;'0Z.F9E
M=&-H26YT;R@I(&9O<B!M;W)E(&EN9F]R;6%T:6]N+@H@("`@("H*("`@("`J
M(%1H:7,@;65T:&]D(&ES(&YO="!M96%N="!T;R!B92!C86QL960@9&ER96-T
M;'DN("!5<V4*("`@("`J($1"7W)E<W5L=#HZ9F5T8VA);G1O*"D@:6YS=&5A
M9"X@($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B
M96-A=7-E($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J
M"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@("!T:&4@<75E<GD@
M<F5S=6QT(')E<V]U<F-E"B`@("`@*B!`<&%R86T@87)R87D@("`@)&%R<B`@
M("`@("!T:&4@<F5F97)E;F-E9"!A<G)A>2!T;R!P=70@=&AE(&1A=&$@:6X*
M("`@("`J($!P87)A;2!I;G0@("`@("`D9F5T8VAM;V1E(&AO=R!T:&4@<F5S
M=6QT:6YG(&%R<F%Y('-H;W5L9"!B92!I;F1E>&5D"B`@("`@*B!`<&%R86T@
M:6YT("`@("`@)')O=VYU;2`@("!T:&4@<F]W(&YU;6)E<B!T;R!F971C:"`H
M,"`](&9I<G-T(')O=RD*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!$
M0E]/2R!O;B!S=6-C97-S+"!.54Q,('=H96X@=&AE(&5N9"!O9B!A(')E<W5L
M="!S970@:7,*("`@("`J("`@("`@("`@("`@("`@("!R96%C:&5D(&]R(&]N
M(&9A:6QU<F4*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ9F5T8VA)
M;G1O*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9F5T8VA);G1O*"1R97-U;'0L
M("8D87)R+"`D9F5T8VAM;V1E+"`D<F]W;G5M(#T@;G5L;"D*("`@('L*("`@
M("`@("!I9B`H)')O=VYU;2`A/3T@;G5L;"D@>PH@("`@("`@("`@("!I9B`H
M(4!S>6)A<V5?9&%T85]S965K*"1R97-U;'0L("1R;W=N=6TI*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("!I9B`H)&9E=&-H;6]D92`F($1"7T9%5$-(34]$15]!4U-/
M0RD@>PH@("`@("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=S>6)A<V5?
M9F5T8VA?87-S;V,G*2D@>PH@("`@("`@("`@("`@("`@)&%R<B`]($!S>6)A
M<V5?9F5T8VA?87-S;V,H)')E<W5L="D["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("!I9B`H)&%R<B`]($!S>6)A<V5?9F5T8VA?87)R
M87DH)')E<W5L="DI('L*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D
M87)R(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("AI<U]I;G0H)&ME>2DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('5N<V5T*"1A<G);)&ME>5TI.PH@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N
M<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197TQ/5T520T%312`F
M)B`D87)R*2!["B`@("`@("`@("`@("`@("`D87)R(#T@87)R87E?8VAA;F=E
M7VME>5]C87-E*"1A<G(L($-!4T5?3$]715(I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&%R<B`]($!S>6)A<V5?9F5T
M8VA?<F]W*"1R97-U;'0I.PH@("`@("`@('T*("`@("`@("!I9B`H(21A<G(I
M('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H@("`@("`@
M(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!
M0DE,25197U)44DE-*2!["B`@("`@("`@("`@("1T:&ES+3Y?<G1R:6U!<G)A
M>59A;'5E<R@D87)R*3L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YO
M<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?3E5,3%]4
M3U]%35!462D@>PH@("`@("`@("`@("`D=&AI<RT^7V-O;G9E<G1.=6QL07)R
M87E686QU97-4;T5M<'1Y*"1A<G(I.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9G)E95)E
M<W5L="@I"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S('1H92!R97-U;'0@<V5T
M(&%N9"!F<F5E<R!T:&4@;65M;W)Y(&]C8W5P:65D(&)Y('1H92!R97-U;'0@
M<V5T"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@:7,@;F]T(&UE86YT('1O
M(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@("H@1$)?<F5S=6QT.CIF
M<F5E*"D@:6YS=&5A9"X@($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T
M960B"B`@("`@*B!B96-A=7-E($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B
M:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@
M4$A0)W,@<75E<GD@<F5S=6QT(')E<V]U<F-E"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L("!44E5%(&]N('-U8V-E<W,L($9!3%-%(&EF("1R97-U;'0@
M:7,@:6YV86QI9`H@("`@("H*("`@("`J($!S964@1$)?<F5S=6QT.CIF<F5E
M*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9G)E95)E<W5L="@D<F5S=6QT*0H@
M("`@>PH@("`@("`@(')E='5R;B!`<WEB87-E7V9R965?<F5S=6QT*"1R97-U
M;'0I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YU;4-O;',H*0H*
M("`@("\J*@H@("`@("H@1V5T<R!T:&4@;G5M8F5R(&]F(&-O;'5M;G,@:6X@
M82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@:7,@;F]T
M(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@("H@1$)?
M<F5S=6QT.CIN=6U#;VQS*"D@:6YS=&5A9"X@($ET(&-A;B=T(&)E(&1E8VQA
M<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E($1"7W)E<W5L="!I<R!A
M('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R
M8V4@)')E<W5L="`@4$A0)W,@<75E<GD@<F5S=6QT(')E<V]U<F-E"B`@("`@
M*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB97(@;V8@8V]L=6UN<RX@
M($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@
M0'-E92!$0E]R97-U;'0Z.FYU;4-O;',H*0H@("`@("HO"B`@("!F=6YC=&EO
M;B!N=6U#;VQS*"1R97-U;'0I"B`@("!["B`@("`@("`@)&-O;',@/2!`<WEB
M87-E7VYU;5]F:65L9',H)')E<W5L="D["B`@("`@("`@:68@*"$D8V]L<RD@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G-Y8F%S95)A:7-E17)R;W(H
M*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1C;VQS.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&YU;5)O=W,H*0H*("`@("\J*@H@("`@("H@
M1V5T<R!T:&4@;G5M8F5R(&]F(')O=W,@:6X@82!R97-U;'0@<V5T"B`@("`@
M*@H@("`@("H@5&AI<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE
M9"!D:7)E8W1L>2X@(%5S90H@("`@("H@1$)?<F5S=6QT.CIN=6U2;W=S*"D@
M:6YS=&5A9"X@($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@
M("`@*B!B96-A=7-E($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*
M("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@
M<75E<GD@<F5S=6QT(')E<V]U<F-E"B`@("`@*@H@("`@("H@0')E='5R;B!I
M;G0@('1H92!N=6UB97(@;V8@<F]W<RX@($$@1$)?17)R;W(@;V)J96-T(&]N
M(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.FYU;5)O
M=W,H*0H@("`@("HO"B`@("!F=6YC=&EO;B!N=6U2;W=S*"1R97-U;'0I"B`@
M("!["B`@("`@("`@)')O=W,@/2!`<WEB87-E7VYU;5]R;W=S*"1R97-U;'0I
M.PH@("`@("`@(&EF("@D<F]W<R`]/3T@9F%L<V4I('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YS>6)A<V5286ES945R<F]R*"D["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B`D<F]W<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!A9F9E8W1E9%)O=W,H*0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE
M<R!T:&4@;G5M8F5R(&]F(')O=W,@869F96-T960@8GD@82!D871A(&UA;FEU
M<&QA=&EO;B!Q=65R>0H@("`@("H*("`@("`J(#`@:7,@<F5T=7)N960@9F]R
M('%U97)I97,@=&AA="!D;VXG="!M86YI<'5L871E(&1A=&$N"B`@("`@*@H@
M("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB97(@;V8@<F]W<RX@($$@1$)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%F9F5C=&5D4F]W<R@I"B`@("!["B`@("`@("`@:68@*$1".CII<TUA;FEP
M*"1T:&ES+3YL87-T7W%U97)Y*2D@>PH@("`@("`@("`@("`D<F5S=6QT(#T@
M0'-Y8F%S95]A9F9E8W1E9%]R;W=S*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5S=6QT(#T@,#L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[(&YE>'1)9"@I"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!N97AT(&9R964@:60@:6X@82!S97%U96YC90H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@("1S97%?;F%M92`@;F%M92!O9B!T:&4@<V5Q=65N
M8V4*("`@("`J($!P87)A;2!B;V]L96%N("1O;F1E;6%N9"`@=VAE;B!T<G5E
M+"!T:&4@<V5Q96YC92!I<R!A=71O;6%T:6-A;&QY"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!C<F5A=&5D(&EF(&ET(&1O97,@;F]T(&5X
M:7-T"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N97AT(&ED(&YU
M;6)E<B!I;B!T:&4@<V5Q=65N8V4N"B`@("`@*B`@("`@("`@("`@("`@($$@
M1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E
M92!$0E]C;VUM;VXZ.FYE>'1)1"@I+"!$0E]C;VUM;VXZ.F=E=%-E<75E;F-E
M3F%M92@I+`H@("`@("H@("`@("!$0E]S>6)A<V4Z.F-R96%T95-E<75E;F-E
M*"DL($1"7W-Y8F%S93HZ9')O<%-E<75E;F-E*"D*("`@("`J+PH@("`@9G5N
M8W1I;VX@;F5X=$ED*"1S97%?;F%M92P@)&]N9&5M86YD(#T@=')U92D*("`@
M('L*("`@("`@("`D<V5Q;F%M92`]("1T:&ES+3YG971397%U96YC94YA;64H
M)'-E<5]N86UE*3L*("`@("`@("!I9B`H(4!S>6)A<V5?<V5L96-T7V1B*"1T
M:&ES+3Y?9&(L("1T:&ES+3YC;VYN96-T:6]N*2D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G-Y8F%S95)A:7-E17)R;W(H1$)?15)23U)?3D]$0E-%
M3$5#5$5$*3L*("`@("`@("!]"B`@("`@("`@)')E<&5A="`](#`["B`@("`@
M("`@9&\@>PH@("`@("`@("`@("`D=&AI<RT^<'5S:$5R<F]R2&%N9&QI;F<H
M4$5!4E]%4E)/4E]215154DXI.PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H
M:7,M/G%U97)Y*"))3E-%4E0@24Y43R`D<V5Q;F%M92`H=F%P;W(I(%9!3%5%
M4R`H,"DB*3L*("`@("`@("`@("`@)'1H:7,M/G!O<$5R<F]R2&%N9&QI;F<H
M*3L*("`@("`@("`@("`@:68@*"1O;F1E;6%N9"`F)B!$0CHZ:7-%<G)O<B@D
M<F5S=6QT*2`F)@H@("`@("`@("`@("`@("`@*"1R97-U;'0M/F=E=$-O9&4H
M*2`]/2!$0E]%4E)/4B!\?"`D<F5S=6QT+3YG971#;V1E*"D@/3T@1$)?15)2
M3U)?3D]354-(5$%"3$4I*0H@("`@("`@("`@("!["B`@("`@("`@("`@("`@
M("`D<F5P96%T(#T@,3L*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI
M<RT^8W)E871E4V5Q=65N8V4H)'-E<5]N86UE*3L*("`@("`@("`@("`@("`@
M(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D<F5S=6QT*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E:68@*"%$0CHZ:7-%<G)O
M<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@)')E<W5L="`])B`D=&AI
M<RT^<75E<GDH(E-%3$5#5"!`0$E$14Y42519($923TT@)'-E<6YA;64B*3L*
M("`@("`@("`@("`@("`@("1R97!E870@/2`P.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)')E<&5A="`](&9A;'-E.PH@("`@("`@
M("`@("!]"B`@("`@("`@?2!W:&EL92`H)')E<&5A="D["B`@("`@("`@:68@
M*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@D<F5S=6QT*3L*("`@("`@("!]"B`@("`@("`@
M)')E<W5L="`]("1R97-U;'0M/F9E=&-H4F]W*$1"7T9%5$-(34]$15]/4D1%
M4D5$*3L*("`@("`@("!R971U<FX@)')E<W5L=%LP73L*("`@('T*"B`@("`O
M*BH*("`@("`J($-R96%T97,@82!N97<@<V5Q=65N8V4*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1S97%?;F%M92`@;F%M92!O9B!T:&4@;F5W('-E
M<75E;F-E"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U
M8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*
M("`@("`J($!S964@1$)?8V]M;6]N.CIC<F5A=&5397%U96YC92@I+"!$0E]C
M;VUM;VXZ.F=E=%-E<75E;F-E3F%M92@I+`H@("`@("H@("`@("!$0E]S>6)A
M<V4Z.FYE>'1)1"@I+"!$0E]S>6)A<V4Z.F1R;W!397%U96YC92@I"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-R96%T95-E<75E;F-E*"1S97%?;F%M92D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/G%U97)Y*"=#4D5!5$4@5$%"3$4@
M)PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`D=&AI<RT^9V5T4V5Q
M=65N8V5.86UE*"1S97%?;F%M92D*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("X@)R`H:60@;G5M97)I8R@Q,"P@,"D@241%3E1)5%D@3D]4($Y53$PL
M)PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G('9A<&]R(&EN="!.
M54Q,*2<I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&1R;W!397%U
M96YC92@I"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&$@<V5Q=65N8V4*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S97%?;F%M92`@;F%M92!O9B!T
M:&4@<V5Q=65N8V4@=&\@8F4@9&5L971E9`H@("`@("H*("`@("`J($!R971U
M<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@
M;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ9')O
M<%-E<75E;F-E*"DL($1"7V-O;6UO;CHZ9V5T4V5Q=65N8V5.86UE*"DL"B`@
M("`@*B`@("`@($1"7W-Y8F%S93HZ;F5X=$E$*"DL($1"7W-Y8F%S93HZ8W)E
M871E4V5Q=65N8V4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!D<F]P4V5Q=65N
M8V4H)'-E<5]N86UE*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<75E
M<GDH)T123U`@5$%"3$4@)R`N("1T:&ES+3YG971397%U96YC94YA;64H)'-E
M<5]N86UE*2D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@875T;T-O
M;6UI="@I"@H@("`@+RHJ"B`@("`@*B!%;F%B;&5S(&]R(&1I<V%B;&5S(&%U
M=&]M871I8R!C;VUM:71S"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VP@)&]N
M;V9F("!T<G5E('1U<FYS(&ET(&]N+"!F86QS92!T=7)N<R!I="!O9F8*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@
M1$)?17)R;W(@;V)J96-T(&EF('1H92!D<FEV97(*("`@("`J("`@("`@("`@
M("`@("`@9&]E<VXG="!S=7!P;W)T(&%U=&\M8V]M;6ET=&EN9R!T<F%N<V%C
M=&EO;G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%U=&]#;VUM:70H)&]N;V9F
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@+R\@6%A8(&EF("1T:&ES+3YT<F%N
M<V%C=&EO;E]O<&-O=6YT(#X@,"P@=V4@<VAO=6QD('!R;V)A8FQY"B`@("`@
M("`@+R\@:7-S=64@82!W87)N:6YG(&AE<F4N"B`@("`@("`@)'1H:7,M/F%U
M=&]C;VUM:70@/2`D;VYO9F8@/R!T<G5E(#H@9F%L<V4["B`@("`@("`@<F5T
M=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&-O;6UI
M="@I"@H@("`@+RHJ"B`@("`@*B!#;VUM:71S('1H92!C=7)R96YT('1R86YS
M86-T:6]N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U
M8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!C;VUM:70H*0H@("`@>PH@("`@("`@(&EF("@D=&AI
M<RT^=')A;G-A8W1I;VY?;W!C;W5N="`^(#`I('L*("`@("`@("`@("`@:68@
M*"%`<WEB87-E7W-E;&5C=%]D8B@D=&AI<RT^7V1B+"`D=&AI<RT^8V]N;F5C
M=&EO;BDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<WEB87-E
M4F%I<V5%<G)O<BA$0E]%4E)/4E].3T1"4T5,14-4140I.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1R97-U;'0@/2!`<WEB87-E7W%U97)Y*"=#3TU-
M250G+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@("1T:&ES+3YT
M<F%N<V%C=&EO;E]O<&-O=6YT(#T@,#L*("`@("`@("`@("`@:68@*"$D<F5S
M=6QT*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G-Y8F%S95)A
M:7-E17)R;W(H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R
M971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<F]L
M;&)A8VLH*0H*("`@("\J*@H@("`@("H@4F5V97)T<R!T:&4@8W5R<F5N="!T
M<F%N<V%C=&EO;@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O
M;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@<F]L;&)A8VLH*0H@("`@>PH@("`@("`@(&EF
M("@D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`^(#`I('L*("`@("`@("`@
M("`@:68@*"%`<WEB87-E7W-E;&5C=%]D8B@D=&AI<RT^7V1B+"`D=&AI<RT^
M8V]N;F5C=&EO;BDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<WEB87-E4F%I<V5%<G)O<BA$0E]%4E)/4E].3T1"4T5,14-4140I.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1R97-U;'0@/2!`<WEB87-E7W%U97)Y
M*"=23TQ,0D%#2R<L("1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`@("`@
M)'1H:7,M/G1R86YS86-T:6]N7V]P8V]U;G0@/2`P.PH@("`@("`@("`@("!I
M9B`H(21R97-U;'0I('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<WEB87-E4F%I<V5%<G)O<B@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!S>6)A<V5286ES945R<F]R*"D*"B`@("`O*BH*("`@("`J(%!R;V1U
M8V5S(&$@1$)?17)R;W(@;V)J96-T(')E9V%R9&EN9R!T:&4@8W5R<F5N="!P
M<F]B;&5M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`D97)R;F\@(&EF('1H
M92!E<G)O<B!I<R!B96EN9R!M86YU86QL>2!R86ES960@<&%S<R!A"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@($1"7T524D]2*B!C;VYS=&%N="!H97)E
M+B`@268@=&AI<R!I<VXG="!P87-S960*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@=&AE(&5R<F]R(&EN9F]R;6%T:6]N(&=A=&AE<F5D(&9R;VT@=&AE
M($1"35,N"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE8W0@('1H92!$0E]%
M<G)O<B!O8FIE8W0*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ<F%I
M<V5%<G)O<B@I+`H@("`@("H@("`@("!$0E]S>6)A<V4Z.F5R<F]R3F%T:79E
M*"DL($1"7W-Y8F%S93HZ97)R;W)#;V1E*"D*("`@("`J+PH@("`@9G5N8W1I
M;VX@<WEB87-E4F%I<V5%<G)O<B@D97)R;F\@/2!N=6QL*0H@("`@>PH@("`@
M("`@("1N871I=F4@/2`D=&AI<RT^97)R;W).871I=F4H*3L*("`@("`@("!I
M9B`H)&5R<FYO(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1E<G)N;R`]("1T
M:&ES+3YE<G)O<D-O9&4H)&YA=&EV92D["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D97)R;F\L(&YU;&PL(&YU;&PL(&YU
M;&PL("1N871I=F4I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&5R
M<F]R3F%T:79E*"D*"B`@("`O*BH*("`@("`J($=E=',@=&AE($1"35,G(&YA
M=&EV92!E<G)O<B!M97-S86=E('!R;V1U8V5D(&)Y('1H92!L87-T('%U97)Y
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!$0DU3)R!E<G)O
M<B!M97-S86=E"B`@("`@*B\*("`@(&9U;F-T:6]N(&5R<F]R3F%T:79E*"D*
M("`@('L*("`@("`@("!R971U<FX@0'-Y8F%S95]G971?;&%S=%]M97-S86=E
M*"D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@97)R;W)#;V1E*"D*
M"B`@("`O*BH*("`@("`J($1E=&5R;6EN97,@4$5!4CHZ1$(@97)R;W(@8V]D
M92!F<F]M('1H92!D871A8F%S92=S('1E>'0@97)R;W(@;65S<V%G92X*("`@
M("`J"B`@("`@*B!`<&%R86T@('-T<FEN9R`@)&5R<F]R;7-G("!E<G)O<B!M
M97-S86=E(')E='5R;F5D(&9R;VT@=&AE(&1A=&%B87-E"B`@("`@*B!`<F5T
M=7)N(&EN=&5G97(@(&%N(&5R<F]R(&YU;6)E<B!F<F]M(&$@1$(@97)R;W(@
M8V]N<W1A;G0*("`@("`J+PH@("`@9G5N8W1I;VX@97)R;W)#;V1E*"1E<G)O
M<FUS9RD*("`@('L*("`@("`@("!S=&%T:6,@)&5R<F]R7W)E9V5X<',["B`@
M("`@("`@:68@*"%I<W-E="@D97)R;W)?<F5G97AP<RDI('L*("`@("`@("`@
M("`@)&5R<F]R7W)E9V5X<',@/2!A<G)A>2@*("`@("`@("`@("`@("`@("<O
M26YC;W)R96-T('-Y;G1A>"!N96%R+R<*("`@("`@("`@("`@("`@("`@("`]
M/B!$0E]%4E)/4E]364Y405@L"B`@("`@("`@("`@("`@("`G+UY5;F-L;W-E
M9"!Q=6]T92!B969O<F4@=&AE(&-H87)A8W1E<B!S=')I;F<@6UPB7"==+BI;
M7")<)UU<+B\G"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?4UE.
M5$%8+`H@("`@("`@("`@("`@("`@)R]);7!L:6-I="!C;VYV97)S:6]N("AF
M<F]M(&1A=&%T>7!E?&]F($Y5345224,@=F%L=64I+VDG"B`@("`@("`@("`@
M("`@("`@("`@/3X@1$)?15)23U)?24Y604Q)1%].54U"15(L"B`@("`@("`@
M("`@("`@("`G+T-A;FYO="!D<F]P('1H92!T86)L92!;7")<)UTN*UM<(EPG
M72P@8F5C875S92!I="!D;V5S;EPG="!E>&ES="!I;B!T:&4@<WES=&5M(&-A
M=&%L;V=S7"XO)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27TY/
M4U5#2%1!0DQ%+`H@("`@("`@("`@("`@("`@)R]/;FQY('1H92!O=VYE<B!O
M9B!O8FIE8W0@6UPB7"==+BM;7")<)UT@;W(@82!U<V5R('=I=&@@4WES=&5M
M($%D;6EN:7-T<F%T;W(@7"A305PI(')O;&4@8V%N(')U;B!T:&ES(&-O;6UA
M;F1<+B\G"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?04-#15-3
M7U9)3TQ!5$E/3BP*("`@("`@("`@("`@("`@("<O7BXK('!E<FUI<W-I;VX@
M9&5N:65D(&]N(&]B:F5C="`N*RP@9&%T86)A<V4@+BLL(&]W;F5R("XK+R<*
M("`@("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/4E]!0T-%4U-?5DE/3$%4
M24].+`H@("`@("`@("`@("`@("`@)R]>+BH@<&5R;6ES<VEO;B!D96YI960L
M(&1A=&%B87-E("XK+"!O=VYE<B`N*R\G"B`@("`@("`@("`@("`@("`@("`@
M/3X@1$)?15)23U)?04-#15-37U9)3TQ!5$E/3BP*("`@("`@("`@("`@("`@
M("<O6UXN*ET@;F]T(&9O=6YD7"XO)PH@("`@("`@("`@("`@("`@("`@(#T^
M($1"7T524D]27TY/4U5#2%1!0DQ%+`H@("`@("`@("`@("`@("`@)R]4:&5R
M92!I<R!A;')E861Y(&%N(&]B:F5C="!N86UE9"\G"B`@("`@("`@("`@("`@
M("`@("`@/3X@1$)?15)23U)?04Q214%$65]%6$E35%,L"B`@("`@("`@("`@
M("`@("`G+TEN=F%L:60@8V]L=6UN(&YA;64O)PH@("`@("`@("`@("`@("`@
M("`@(#T^($1"7T524D]27TY/4U5#2$9)14Q$+`H@("`@("`@("`@("`@("`@
M)R]D;V5S(&YO="!A;&QO=R!N=6QL('9A;'5E<R\G"B`@("`@("`@("`@("`@
M("`@("`@/3X@1$)?15)23U)?0T].4U1204E.5%].3U1?3E5,3"P*("`@("`@
M("`@("`@("`@("<O0V]M;6%N9"!H87,@8F5E;B!A8F]R=&5D+R<*("`@("`@
M("`@("`@("`@("`@("`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@("`@
M("`@("`@("`@)R]>0V%N;F]T(&1R;W`@=&AE(&EN9&5X("XJ(&)E8V%U<V4@
M:70@9&]E<VY<)W0@97AI<W0O:2<*("`@("`@("`@("`@("`@("`@("`]/B!$
M0E]%4E)/4E].3U1?1D]53D0L"B`@("`@("`@("`@("`@("`G+UY4:&5R92!I
M<R!A;')E861Y(&%N(&EN9&5X+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@
M1$)?15)23U)?04Q214%$65]%6$E35%,L"B`@("`@("`@("`@("`@("`G+UY4
M:&5R92!A<F4@9F5W97(@8V]L=6UN<R!I;B!T:&4@24Y315)4('-T871E;65N
M="!T:&%N('9A;'5E<R!S<&5C:69I960O:2<*("`@("`@("`@("`@("`@("`@
M("`]/B!$0E]%4E)/4E]604Q515]#3U5.5%]/3E]23U<L"B`@("`@("`@("`@
M("D["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D97)R;W)?<F5G97AP
M<R!A<R`D<F5G97AP(#T^("1C;V1E*2!["B`@("`@("`@("`@(&EF("AP<F5G
M7VUA=&-H*"1R96=E>'`L("1E<G)O<FUS9RDI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D8V]D93L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!R971U<FX@1$)?15)23U(["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@=&%B;&5);F9O*"D*"B`@("`O*BH*("`@("`J(%)E='5R;G,@:6YF;W)M
M871I;VX@86)O=70@82!T86)L92!O<B!A(')E<W5L="!S970*("`@("`J"B`@
M("`@*B!.3U1%.B!O;FQY('-U<'!O<G1S("=T86)L92<@86YD("=F;&%G<R<@
M:68@/'9A<CXD<F5S=6QT/"]V87(^"B`@("`@*B!I<R!A('1A8FQE(&YA;64N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C='QS=')I;F<@("1R97-U;'0@
M($1"7W)E<W5L="!O8FIE8W0@9G)O;2!A('%U97)Y(&]R(&$*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R:6YG(&-O;G1A:6YI
M;F<@=&AE(&YA;64@;V8@82!T86)L92X*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@5VAI;&4@=&AI<R!A;'-O(&%C8V5P=',@82!Q
M=65R>2!R97-U;'0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<F5S;W5R8V4@:61E;G1I9FEE<BP@=&AI<R!B96AA=FEO<B!I<PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!D97!R96-A
M=&5D+@H@("`@("H@0'!A<F%M(&EN="`@("`@("`@("`@("1M;V1E("`@(&$@
M=F%L:60@=&%B;&5);F9O(&UO9&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!A;B!A<W-O8VEA=&EV92!A<G)A>2!W:71H('1H92!I;F9O<FUA=&EO
M;B!R97%U97-T960N"B`@("`@*B`@("`@("`@("`@("`@("`@02!$0E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O
M;6UO;CHZ=&%B;&5);F9O*"D*("`@("`J($!S:6YC92!-971H;V0@879A:6QA
M8FQE('-I;F-E(%)E;&5A<V4@,2XV+C`*("`@("`J+PH@("`@9G5N8W1I;VX@
M=&%B;&5);F9O*"1R97-U;'0L("1M;V1E(#T@;G5L;"D*("`@('L*("`@("`@
M("!I9B`H:7-?<W1R:6YG*"1R97-U;'0I*2!["B`@("`@("`@("`@("\J"B`@
M("`@("`@("`@("`J(%!R;V)A8FQY(')E8V5I=F5D(&$@=&%B;&4@;F%M92X*
M("`@("`@("`@("`@("H@0W)E871E(&$@<F5S=6QT(')E<V]U<F-E(&ED96YT
M:69I97(N"B`@("`@("`@("`@("`J+PH@("`@("`@("`@("!I9B`H(4!S>6)A
M<V5?<V5L96-T7V1B*"1T:&ES+3Y?9&(L("1T:&ES+3YC;VYN96-T:6]N*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YS>6)A<V5286ES945R
M<F]R*$1"7T524D]27TY/1$)314Q%0U1%1"D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)&ED(#T@0'-Y8F%S95]Q=65R>2@B4T5,14-4("H@1E)/32`D
M<F5S=6QT(%=(15)%(#$],"(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@("`D9V]T7W-T
M<FEN9R`]('1R=64["B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1R97-U;'0M
M/G)E<W5L="DI('L*("`@("`@("`@("`@+RH*("`@("`@("`@("`@("H@4')O
M8F%B;'D@<F5C96EV960@82!R97-U;'0@;V)J96-T+@H@("`@("`@("`@("`@
M*B!%>'1R86-T('1H92!R97-U;'0@<F5S;W5R8V4@:61E;G1I9FEE<BX*("`@
M("`@("`@("`@("HO"B`@("`@("`@("`@("1I9"`]("1R97-U;'0M/G)E<W5L
M=#L*("`@("`@("`@("`@)&=O=%]S=')I;F<@/2!F86QS93L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`O*@H@("`@("`@("`@("`@*B!0<F]B86)L
M>2!R96-E:79E9"!A(')E<W5L="!R97-O=7)C92!I9&5N=&EF:65R+@H@("`@
M("`@("`@("`@*B!#;W!Y(&ET+@H@("`@("`@("`@("`@*B!$97!R96-A=&5D
M+B`@2&5R92!F;W(@8V]M<&%T:6)I;&ET>2!O;FQY+@H@("`@("`@("`@("`@
M*B\*("`@("`@("`@("`@)&ED(#T@)')E<W5L=#L*("`@("`@("`@("`@)&=O
M=%]S=')I;F<@/2!F86QS93L*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-?
M<F5S;W5R8V4H)&ED*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G-Y
M8F%S95)A:7-E17)R;W(H1$)?15)23U)?3D5%1%]-3U)%7T1!5$$I.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET
M>2==("8@1$)?4$]25$%"24Q)5%E?3$]715)#05-%*2!["B`@("`@("`@("`@
M("1C87-E7V9U;F,@/2`G<W1R=&]L;W=E<B<["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&-A<V5?9G5N8R`]("=S=')V86PG.PH@("`@("`@('T*
M"B`@("`@("`@)&-O=6YT(#T@0'-Y8F%S95]N=6U?9FEE;&1S*"1I9"D["B`@
M("`@("`@)')E<R`@(#T@87)R87DH*3L*"B`@("`@("`@:68@*"1M;V1E*2![
M"B`@("`@("`@("`@("1R97-;)VYU;5]F:65L9',G72`]("1C;W5N=#L*("`@
M("`@("!]"@H@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1C;W5N=#L@)&DK
M*RD@>PH@("`@("`@("`@("`D9B`]($!S>6)A<V5?9F5T8VA?9FEE;&0H)&ED
M+"`D:2D["B`@("`@("`@("`@("\O(&-O;'5M;E]S;W5R8V4@:7,@;V9T96X@
M8FQA;FL*("`@("`@("`@("`@)')E<ULD:5T@/2!A<G)A>2@*("`@("`@("`@
M("`@("`@("=T86)L92<@/3X@)&=O=%]S=')I;F<*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/R`D8V%S95]F=6YC*"1R97-U;'0I"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#H@)&-A<V5?9G5N8R@D9BT^8V]L=6UN7W-O=7)C
M92DL"B`@("`@("`@("`@("`@("`G;F%M92<@(#T^("1C87-E7V9U;F,H)&8M
M/FYA;64I+`H@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`D9BT^='EP92P*
M("`@("`@("`@("`@("`@("=L96XG("`@/3X@)&8M/FUA>%]L96YG=&@L"B`@
M("`@("`@("`@("`@("`G9FQA9W,G(#T^("<G+`H@("`@("`@("`@("`I.PH@
M("`@("`@("`@("!I9B`H)')E<ULD:5U;)W1A8FQE)UTI('L*("`@("`@("`@
M("`@("`@("1R97-;)&E=6R=F;&%G<R==(#T@)'1H:7,M/E]S>6)A<V5?9FEE
M;&1?9FQA9W,H"B`@("`@("`@("`@("`@("`@("`@("`@("1R97-;)&E=6R=T
M86)L92==+"`D<F5S6R1I75LG;F%M92==*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!I9B`H)&UO9&4@)B!$0E]404),14E.1D]?3U)$15(I('L*("`@
M("`@("`@("`@("`@("1R97-;)V]R9&5R)UU;)')E<ULD:5U;)VYA;64G75T@
M/2`D:3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&UO9&4@)B!$
M0E]404),14E.1D]?3U)$15)404),12D@>PH@("`@("`@("`@("`@("`@)')E
M<ULG;W)D97)T86)L92==6R1R97-;)&E=6R=T86)L92==75LD<F5S6R1I75LG
M;F%M92==72`]("1I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`O+R!F<F5E('1H92!R97-U;'0@;VYL>2!I9B!W92!W97)E(&-A;&QE9"!O
M;B!A('1A8FQE"B`@("`@("`@:68@*"1G;W1?<W1R:6YG*2!["B`@("`@("`@
M("`@($!S>6)A<V5?9G)E95]R97-U;'0H)&ED*3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1R97,["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M7W-Y8F%S95]F:65L9%]F;&%G<R@I"@H@("`@+RHJ"B`@("`@*B!'970@=&AE
M(&9L86=S(&9O<B!A(&9I96QD"B`@("`@*@H@("`@("H@0W5R<F5N=&QY('-U
M<'!O<G1S.@H@("`@("H@("L@/'-A;7`^=6YI<75E7VME>3PO<V%M<#X@("`@
M*'5N:7%U92!I;F1E>"P@=6YI<75E(&-H96-K(&]R('!R:6UA<GE?:V5Y*0H@
M("`@("H@("L@/'-A;7`^;75L=&EP;&5?:V5Y/"]S86UP/B`@*&UU;'1I+6ME
M>2!I;F1E>"D*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D=&%B;&4@
M("!T:&4@=&%B;&4@;F%M90H@("`@("H@0'!A<F%M('-T<FEN9R`@)&-O;'5M
M;B`@=&AE(&9I96QD(&YA;64*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@<W!A8V4@9&5L:6UI=&5D('-T<FEN9R!O9B!F;&%G<RX@($5M<'1Y('-T
M<FEN9R!I9B!N;VYE+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("HO"B`@("!F=6YC=&EO;B!?<WEB87-E7V9I96QD7V9L86=S*"1T86)L
M92P@)&-O;'5M;BD*("`@('L*("`@("`@("!S=&%T:6,@)'1A8FQE3F%M92`]
M(&YU;&P["B`@("`@("`@<W1A=&EC("1F;&%G<R`](&%R<F%Y*"D["@H@("`@
M("`@(&EF("@D=&%B;&4@(3T@)'1A8FQE3F%M92D@>PH@("`@("`@("`@("`D
M9FQA9W,@/2!A<G)A>2@I.PH@("`@("`@("`@("`D=&%B;&5.86UE(#T@)'1A
M8FQE.PH*("`@("`@("`@("`@+R\@9V5T('5N:7%U92]P<FEM87)Y(&ME>7,*
M("`@("`@("`@("`@)')E<R`]("1T:&ES+3YG971!;&PH(G-P7VAE;'!I;F1E
M>"`D=&%B;&4B+"!$0E]&151#2$U/1$5?05-33T,I.PH*("`@("`@("`@("`@
M:68@*"%I<W-E="@D<F5S6S!=6R=I;F1E>%]D97-C<FEP=&EO;B==*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!F;W)E86-H("@D<F5S(&%S("1V86PI('L*("`@("`@("`@("`@
M("`@("1K97ES(#T@97AP;&]D92@G+"`G+"!T<FEM*"1V86Q;)VEN9&5X7VME
M>7,G72DI.PH*("`@("`@("`@("`@("`@(&EF("AS:7IE;V8H)&ME>7,I(#X@
M,2D@>PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1K97ES(&%S("1K
M97DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1?9FQA
M9R@D9FQA9W-;)&ME>5TL("=M=6QT:7!L95]K97DG*3L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@
M:68@*'-T<G!O<R@D=F%L6R=I;F1E>%]D97-C<FEP=&EO;B==+"`G=6YI<75E
M)RDI('L*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D:V5Y<R!A<R`D
M:V5Y*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?861D7V9L
M86<H)&9L86=S6R1K97E=+"`G=6YI<75E7VME>2<I.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@
M("`@("!]"@H@("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"1C;VQU;6XL
M("1F;&%G<RDI('L*("`@("`@("`@("`@<F5T=7)N*&EM<&QO9&4H)R`G+"`D
M9FQA9W-;)&-O;'5M;ETI*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`G
M)SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!?861D7V9L86<H*0H*
M("`@("\J*@H@("`@("H@061D<R!A('-T<FEN9R!T;R!T:&4@9FQA9W,@87)R
M87D@:68@=&AE(&9L86<@:7,@;F]T('EE="!I;B!T:&5R90H@("`@("H@+2!I
M9B!T:&5R92!I<R!N;R!F;&%G('!R97-E;G0@=&AE(&%R<F%Y(&ES(&-R96%T
M960*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@("1A<G)A>2`@<F5F97)E
M;F-E(&]F(&9L86=S(&%R<F%Y('1O(&%D9"!A('9A;'5E('1O"B`@("`@*B!`
M<&%R86T@;6EX960@("1V86QU92`@=F%L=64@=&\@861D('1O('1H92!F;&%G
M(&%R<F%Y"B`@("`@*@H@("`@("H@0')E='5R;B!V;VED"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A9&1?
M9FQA9R@F)&%R<F%Y+"`D=F%L=64I"B`@("!["B`@("`@("`@:68@*"%I<U]A
M<G)A>2@D87)R87DI*2!["B`@("`@("`@("`@("1A<G)A>2`](&%R<F%Y*"1V
M86QU92D["B`@("`@("`@?2!E;'-E:68@*"%I;E]A<G)A>2@D=F%L=64L("1A
M<G)A>2DI('L*("`@("`@("`@("`@87)R87E?<'5S:"@D87)R87DL("1V86QU
M92D["B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&=E
M=%-P96-I86Q1=65R>2@I"@H@("`@+RHJ"B`@("`@*B!/8G1A:6YS('1H92!Q
M=65R>2!S=')I;F<@;F5E9&5D(&9O<B!L:7-T:6YG(&$@9VEV96X@='EP92!O
M9B!O8FIE8W1S"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@
M=&AE(&MI;F0@;V8@;V)J96-T<R!Y;W4@=V%N="!T;R!R971R:65V90H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@4U%,('%U97)Y('-T<FEN
M9R!O<B!N=6QL(&EF('1H92!D<FEV97(@9&]E<VXG=`H@("`@("H@("`@("`@
M("`@("`@("`@("!S=7!P;W)T('1H92!O8FIE8W0@='EP92!R97%U97-T960*
M("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@("H@0'-E92!$
M0E]C;VUM;VXZ.F=E=$QI<W1/9B@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%-P96-I86Q1=65R>2@D='EP92D*("`@('L*("`@("`@("!S=VET8V@@*"1T
M>7!E*2!["B`@("`@("`@("`@(&-A<V4@)W1A8FQE<R<Z"B`@("`@("`@("`@
M("`@("!R971U<FX@(E-%3$5#5"!N86UE($923TT@<WES;V)J96-T<R!72$52
M12!T>7!E(#T@)U4G(@H@("`@("`@("`@("`@("`@("`@("`@("X@)R!/4D1%
M4B!"62!N86UE)SL*("`@("`@("`@("`@8V%S92`G=FEE=W,G.@H@("`@("`@
M("`@("`@("`@<F5T=7)N(")314Q%0U0@;F%M92!&4D]-('-Y<V]B:F5C=',@
M5TA%4D4@='EP92`]("=6)R(["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@
M("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("!]"@H@("`@
M+R\@?7U]"@I]"@HO*@H@*B!,;V-A;"!V87)I86)L97,Z"B`J('1A8BUW:61T
M:#H@-`H@*B!C+6)A<VEC+6]F9G-E=#H@-`H@*B!%;F0Z"B`J+PH*/SX*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O1$(O<W1O<F%G92YP:'``````````````````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`S-3`P-"`Q,#4Q-30S,S<S,2`P,C$Q,S``
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T
M:#TT('-O9G1T86)S=&]P/30Z("HO"@HO*BH*("H@4')O=FED97,@86X@;V)J
M96-T(&EN=&5R9F%C92!T;R!A('1A8FQE(')O=PH@*@H@*B!02%`@=F5R<VEO
M;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES
M('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J
M('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B
M(&%T('1H92!F;VQL;W=I;F<@55)).@H@*B!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O
M<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B
M=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90H@*B!S96YD(&$@;F]T
M92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P
M>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@
M0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-T
M:6=`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@
M1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@($-6
M4SH@)$ED.B!S=&]R86=E+G!H<"QV(#$N,C$@,C`P-2\P,B\P,B`P,CHU-#HU
M,2!D86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H
M<"YN970O<&%C:V%G92]$0@H@*B\*"B\J*@H@*B!/8G1A:6X@=&AE($1"(&-L
M87-S('-O(&ET(&-A;B!B92!E>'1E;F1E9"!F<F]M"B`J+PIR97%U:7)E7V]N
M8V4@)T1"+G!H<"<["@HO*BH*("H@4')O=FED97,@86X@;V)J96-T(&EN=&5R
M9F%C92!T;R!A('1A8FQE(')O=PH@*@H@*B!)="!L971S('EO=2!A9&0L(&1E
M;&5T92!A;F0@8VAA;F=E(')O=W,@=7-I;F<@;V)J96-T<R!R871H97(@=&AA
M;B!344P*("H@<W1A=&5M96YT<RX*("H*("H@0&-A=&5G;W)Y("`@1&%T86)A
M<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK
M96X@/'-T:6=`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H
M92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N
M("`@(%)E;&5A<V4Z(#$N-RXV"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R
M+G!H<"YN970O<&%C:V%G92]$0@H@*B\*8VQA<W,@1$)?<W1O<F%G92!E>'1E
M;F1S(%!%05(*>PH@("`@+R\@>WM[('!R;W!E<G1I97,*"B`@("`O*BH@=&AE
M(&YA;64@;V8@=&AE('1A8FQE("AO<B!V:65W+"!I9B!T:&4@8F%C:V5N9"!D
M871A8F%S92!S=7!P;W)T<PH@("`@("`@('5P9&%T97,@:6X@=FEE=W,I('=E
M(&AO;&0@9&%T82!F<F]M("HO"B`@("!V87(@)%]T86)L92`](&YU;&P["@H@
M("`@+RHJ('=H:6-H(&-O;'5M;BAS*2!I;B!T:&4@=&%B;&4@8V]N=&%I;G,@
M<')I;6%R>2!K97ES+"!C86X@8F4@80H@("`@("`@('-T<FEN9R!F;W(@<VEN
M9VQE+6-O;'5M;B!P<FEM87)Y(&ME>7,L(&]R(&%N(&%R<F%Y(&]F('-T<FEN
M9W,*("`@("`@("!F;W(@;75L=&EP;&4M8V]L=6UN('!R:6UA<GD@:V5Y<R`J
M+PH@("`@=F%R("1?:V5Y8V]L=6UN(#T@;G5L;#L*"B`@("`O*BH@1$(@8V]N
M;F5C=&EO;B!H86YD;&4@=7-E9"!F;W(@86QL('1R86YS86-T:6]N<R`J+PH@
M("`@=F%R("1?9&)H(#T@;G5L;#L*"B`@("`O*BH@86X@87-S;V,@=VET:"!T
M:&4@;F%M97,@;V8@9&%T86)A<V4@9FEE;&1S('-T;W)E9"!A<R!P<F]P97)T
M:65S"B`@("`@("`@:6X@=&AI<R!O8FIE8W0@*B\*("`@('9A<B`D7W!R;W!E
M<G1I97,@/2!A<G)A>2@I.PH*("`@("\J*B!A;B!A<W-O8R!W:71H('1H92!N
M86UE<R!O9B!T:&4@<')O<&5R=&EE<R!I;B!T:&ES(&]B:F5C="!T:&%T"B`@
M("`@("`@:&%V92!B965N(&-H86YG960@<VEN8V4@=&AE>2!W97)E(&9E=&-H
M960@9G)O;2!T:&4@9&%T86)A<V4@*B\*("`@('9A<B`D7V-H86YG97,@/2!A
M<G)A>2@I.PH*("`@("\J*B!F;&%G('1H870@9&5C:61E<R!I9B!D871A(&EN
M('1H:7,@;V)J96-T(&-A;B!B92!C:&%N9V5D+@H@("`@("`@(&]B:F5C=',@
M=&AA="!D;VXG="!H879E('1H96ER('1A8FQE)W,@:V5Y(&-O;'5M;B!I;B!T
M:&5I<@H@("`@("`@('!R;W!E<G1Y(&QI<W1S('=I;&P@8F4@9FQA9V=E9"!A
M<R!R96%D+6]N;'DN("HO"B`@("!V87(@)%]R96%D;VYL>2`](&9A;'-E.PH*
M("`@("\J*B!F=6YC=&EO;B!O<B!M971H;V0@=&AA="!I;7!L96UE;G1S(&$@
M=F%L:61A=&]R(&9O<B!F:65L9',@=&AA=`H@("`@("`@(&%R92!S970L('1H
M:7,@=F%L:61A=&]R(&9U;F-T:6]N(')E='5R;G,@=')U92!I9B!T:&4@9FEE
M;&0@:7,*("`@("`@("!V86QI9"P@9F%L<V4@:68@;F]T("HO"B`@("!V87(@
M)%]V86QI9&%T;W(@/2!N=6QL.PH*("`@("\O('U]?0H@("`@+R\@>WM[(&-O
M;G-T<G5C=&]R"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("H*
M("`@("`J($!P87)A;2`D=&%B;&4@<W1R:6YG('1H92!N86UE(&]F('1H92!D
M871A8F%S92!T86)L90H@("`@("H*("`@("`J($!P87)A;2`D:V5Y8V]L=6UN
M(&UI>&5D('-T<FEN9R!W:71H(&YA;64@;V8@:V5Y(&-O;'5M;BP@;W(@87)R
M87D@;V8*("`@("`J('-T<FEN9W,@:68@=&AE('1A8FQE(&AA<R!A('!R:6UA
M<GD@:V5Y(&]F(&UO<F4@=&AA;B!O;F4@8V]L=6UN"B`@("`@*@H@("`@("H@
M0'!A<F%M("1D8F@@;V)J96-T(&1A=&%B87-E(&-O;FYE8W1I;VX@;V)J96-T
M"B`@("`@*@H@("`@("H@0'!A<F%M("1V86QI9&%T;W(@;6EX960@9G5N8W1I
M;VX@;W(@;65T:&]D('5S960@=&\@=F%L:61A=&4*("`@("`J(&5A8V@@;F5W
M('9A;'5E+"!C86QL960@=VET:"!T:')E92!P87)A;65T97)S.B!T:&4@;F%M
M92!O9B!T:&4*("`@("`J(&9I96QD+V-O;'5M;B!T:&%T(&ES(&-H86YG:6YG
M+"!A(')E9F5R96YC92!T;R!T:&4@;F5W('9A;'5E(&%N9`H@("`@("H@82!R
M969E<F5N8V4@=&\@=&AI<R!O8FIE8W0*("`@("`J"B`@("`@*B\*("`@(&9U
M;F-T:6]N($1"7W-T;W)A9V4H)'1A8FQE+"`D:V5Y8V]L=6UN+"`F)&1B:"P@
M)'9A;&ED871O<B`](&YU;&PI"B`@("!["B`@("`@("`@)'1H:7,M/E!%05(H
M)T1"7T5R<F]R)RD["B`@("`@("`@)'1H:7,M/E]T86)L92`]("1T86)L93L*
M("`@("`@("`D=&AI<RT^7VME>6-O;'5M;B`]("1K97EC;VQU;6X["B`@("`@
M("`@)'1H:7,M/E]D8F@@/2`D9&)H.PH@("`@("`@("1T:&ES+3Y?<F5A9&]N
M;'D@/2!F86QS93L*("`@("`@("`D=&AI<RT^7W9A;&ED871O<B`]("1V86QI
M9&%T;W(["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@7VUA:V57:&5R
M92@I"@H@("`@+RHJ"B`@("`@*B!5=&EL:71Y(&UE=&AO9"!T;R!B=6EL9"!A
M(")72$5212(@8VQA=7-E('1O(&QO8V%T92!O=7)S96QV97,@:6X*("`@("`J
M('1H92!T86)L92X*("`@("`J"B`@("`@*B!86%@@9G5T=7)E(&EM<')O=F5M
M96YT.B!U<V4@<F]W:61S/PH@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("HO"B`@("!F=6YC=&EO;B!?;6%K95=H97)E*"1K97EV86P@/2!N
M=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D=&AI<RT^7VME>6-O
M;'5M;BDI('L*("`@("`@("`@("`@:68@*"1K97EV86P@/3T](&YU;&PI('L*
M("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D=&AI
M<RT^7VME>6-O;'5M;BD[("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`D
M:V5Y=F%L6UT@/2`D=&AI<RT^>R1T:&ES+3Y?:V5Y8V]L=6UN6R1I77T["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)'=H
M97)E8VQA=7-E(#T@)R<["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M('-I>F5O9B@D=&AI<RT^7VME>6-O;'5M;BD[("1I*RLI('L*("`@("`@("`@
M("`@("`@(&EF("@D:2`^(#`I('L*("`@("`@("`@("`@("`@("`@("`D=VAE
M<F5C;&%U<V4@+CT@)R!!3D0@)SL*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("1W:&5R96-L875S92`N/2`D=&AI<RT^7VME>6-O;'5M;ELD
M:5T["B`@("`@("`@("`@("`@("!I9B`H:7-?;G5L;"@D:V5Y=F%L6R1I72DI
M('L*("`@("`@("`@("`@("`@("`@("`O+R!T:&5R92=S(&YO="!M=6-H('!O
M:6YT(&EN(&AA=FEN9R!A($Y53$P@:V5Y+`H@("`@("`@("`@("`@("`@("`@
M("\O(&)U="!W92!S=7!P;W)T(&ET(&%N>7=A>0H@("`@("`@("`@("`@("`@
M("`@("1W:&5R96-L875S92`N/2`G($E3($Y53$PG.PH@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=VAE<F5C;&%U<V4@
M+CT@)R`]("<@+B`D=&AI<RT^7V1B:"T^<75O=&4H)&ME>79A;%LD:5TI.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@:68@*"1K97EV86P@/3T](&YU;&PI('L*("`@("`@
M("`@("`@("`@("1K97EV86P@/2!`)'1H:7,M/GLD=&AI<RT^7VME>6-O;'5M
M;GT["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'=H97)E8VQA=7-E(#T@
M)'1H:7,M/E]K97EC;VQU;6X["B`@("`@("`@("`@(&EF("AI<U]N=6QL*"1K
M97EV86PI*2!["B`@("`@("`@("`@("`@("`O+R!T:&5R92=S(&YO="!M=6-H
M('!O:6YT(&EN(&AA=FEN9R!A($Y53$P@:V5Y+`H@("`@("`@("`@("`@("`@
M+R\@8G5T('=E('-U<'!O<G0@:70@86YY=V%Y"B`@("`@("`@("`@("`@("`D
M=VAE<F5C;&%U<V4@+CT@)R!)4R!.54Q,)SL*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1W:&5R96-L875S92`N/2`G(#T@)R`N("1T
M:&ES+3Y?9&)H+3YQ=6]T92@D:V5Y=F%L*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@("`@("!R971U<FX@)'=H97)E8VQA=7-E.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[('-E='5P*"D*"B`@("`O*BH*("`@("`J($UE
M=&AO9"!U<V5D('1O(&EN:71I86QI>F4@82!$0E]S=&]R86=E(&]B:F5C="!F
M<F]M('1H90H@("`@("H@8V]N9FEG=7)E9"!T86)L92X*("`@("`J"B`@("`@
M*B!`<&%R86T@)&ME>79A;"!M:7AE9"!T:&4@:V5Y6W-=(&]F('1H92!R;W<@
M=&\@9F5T8V@@*'-T<FEN9R!O<B!A<G)A>2D*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&EN="!$0E]/2R!O;B!S=6-C97-S+"!A($1"(&5R<F]R(&EF(&YO=`H@
M("`@("HO"B`@("!F=6YC=&EO;B!S971U<"@D:V5Y=F%L*0H@("`@>PH@("`@
M("`@("1W:&5R96-L875S92`]("1T:&ES+3Y?;6%K95=H97)E*"1K97EV86PI
M.PH@("`@("`@("1Q=65R>2`]("=314Q%0U0@*B!&4D]-("<@+B`D=&AI<RT^
M7W1A8FQE("X@)R!72$5212`G("X@)'=H97)E8VQA=7-E.PH@("`@("`@("1S
M=&@@/2`D=&AI<RT^7V1B:"T^<75E<GDH)'%U97)Y*3L*("`@("`@("!I9B`H
M1$(Z.FES17)R;W(H)'-T:"DI('L*("`@("`@("`@("`@<F5T=7)N("1S=&@[
M"B`@("`@("`@?0H@("`@("`@("1R;W<@/2`D<W1H+3YF971C:%)O=RA$0E]&
M151#2$U/1$5?05-33T,I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F]W
M*2D@>PH@("`@("`@("`@("!R971U<FX@)')O=SL*("`@("`@("!]"B`@("`@
M("`@:68@*"$D<F]W*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<BAN=6QL+"!$0E]%4E)/4E].3U1?1D]53D0L(&YU;&PL(&YU;&PL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<75E<GDL
M(&YU;&PL('1R=64I.PH@("`@("`@('T*("`@("`@("!F;W)E86-H("@D<F]W
M(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("1T:&ES+3Y?<')O
M<&5R=&EE<ULD:V5Y72`]('1R=64["B`@("`@("`@("`@("1T:&ES+3XD:V5Y
M(#T@)'9A;'5E.PH@("`@("`@('T*("`@("`@("!R971U<FX@1$)?3TL["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@:6YS97)T*"D*"B`@("`O*BH*
M("`@("`J($-R96%T92!A(&YE=R`H96UP='DI(')O=R!I;B!T:&4@8V]N9FEG
M=7)E9"!T86)L92!F;W(@=&AI<PH@("`@("H@;V)J96-T+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!I;G-E<G0H)&YE=W!K*0H@("`@>PH@("`@("`@(&EF("AI
M<U]A<G)A>2@D=&AI<RT^7VME>6-O;'5M;BDI('L*("`@("`@("`@("`@)'!R
M:6UA<GEK97D@/2`D=&AI<RT^7VME>6-O;'5M;CL*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D<')I;6%R>6ME>2`](&%R<F%Y*"1T:&ES+3Y?:V5Y
M8V]L=6UN*3L*("`@("`@("!]"B`@("`@("`@<V5T='EP92@D;F5W<&LL(")A
M<G)A>2(I.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D<')I
M;6%R>6ME>2D[("1I*RLI('L*("`@("`@("`@("`@)'!K=F%L<UM=(#T@)'1H
M:7,M/E]D8F@M/G%U;W1E*"1N97=P:ULD:5TI.PH@("`@("`@('T*"B`@("`@
M("`@)'-T:"`]("1T:&ES+3Y?9&)H+3YQ=65R>2@B24Y315)4($E.5$\@)'1H
M:7,M/E]T86)L92`H(B`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I;7!L;V1E*"(L(BP@)'!R:6UA<GEK97DI("X@(BD@5D%,5453*"(@
M+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:6UP;&]D92@B
M+"(L("1P:W9A;',I("X@(BDB*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H
M)'-T:"DI('L*("`@("`@("`@("`@<F5T=7)N("1S=&@["B`@("`@("`@?0H@
M("`@("`@(&EF("AS:7IE;V8H)&YE=W!K*2`]/2`Q*2!["B`@("`@("`@("`@
M("1N97=P:R`]("1N97=P:ULP73L*("`@("`@("!]"B`@("`@("`@)'1H:7,M
M/G-E='5P*"1N97=P:RD["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M=&]3=')I;F<H*0H*("`@("\J*@H@("`@("H@3W5T<'5T(&$@<VEM<&QE(&1E
M<V-R:7!T:6]N(&]F('1H:7,@1$)?<W1O<F%G92!O8FIE8W0N"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R!O8FIE8W0@9&5S8W)I<'1I;VX*("`@("`J+PH@("`@
M9G5N8W1I;VX@=&]3=')I;F<H*0H@("`@>PH@("`@("`@("1I;F9O(#T@<W1R
M=&]L;W=E<BAG971?8VQA<W,H)'1H:7,I*3L*("`@("`@("`D:6YF;R`N/2`B
M("AT86)L93TB.PH@("`@("`@("1I;F9O("X]("1T:&ES+3Y?=&%B;&4["B`@
M("`@("`@)&EN9F\@+CT@(BP@:V5Y8V]L=6UN/2(["B`@("`@("`@:68@*&ES
M7V%R<F%Y*"1T:&ES+3Y?:V5Y8V]L=6UN*2D@>PH@("`@("`@("`@("`D:6YF
M;R`N/2`B*"(@+B!I;7!L;V1E*"(L(BP@)'1H:7,M/E]K97EC;VQU;6XI("X@
M(BDB.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1I;F9O("X]("1T
M:&ES+3Y?:V5Y8V]L=6UN.PH@("`@("`@('T*("`@("`@("`D:6YF;R`N/2`B
M+"!D8F@](CL*("`@("`@("!I9B`H:7-?;V)J96-T*"1T:&ES+3Y?9&)H*2D@
M>PH@("`@("`@("`@("`D:6YF;R`N/2`D=&AI<RT^7V1B:"T^=&]3=')I;F<H
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D:6YF;R`N/2`B;G5L
M;"(["B`@("`@("`@?0H@("`@("`@("1I;F9O("X]("(I(CL*("`@("`@("!I
M9B`H<VEZ96]F*"1T:&ES+3Y?<')O<&5R=&EE<RDI('L*("`@("`@("`@("`@
M)&EN9F\@+CT@(B!;;&]A9&5D+"!K97D](CL*("`@("`@("`@("`@)&ME>6YA
M;64@/2`D=&AI<RT^7VME>6-O;'5M;CL*("`@("`@("`@("`@:68@*&ES7V%R
M<F%Y*"1K97EN86UE*2D@>PH@("`@("`@("`@("`@("`@)&EN9F\@+CT@(B@B
M.PH@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F*"1K
M97EN86UE*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D:2`^
M(#`I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F\@+CT@(BPB.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D:6YF
M;R`N/2`D=&AI<RT^)&ME>6YA;65;)&E=.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@)&EN9F\@+CT@(BDB.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)&EN9F\@+CT@)'1H:7,M/B1K97EN86UE
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1I;F9O("X](")=(CL*("`@
M("`@("!]"B`@("`@("`@:68@*'-I>F5O9B@D=&AI<RT^7V-H86YG97,I*2![
M"B`@("`@("`@("`@("1I;F9O("X]("(@6VUO9&EF:65D72(["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D:6YF;SL*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!D=6UP*"D*"B`@("`O*BH*("`@("`J($1U;7`@=&AE(&-O;G1E
M;G1S(&]F('1H:7,@;V)J96-T('1O(")S=&%N9&%R9"!O=71P=70B+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!D=6UP*"D*("`@('L*("`@("`@("!F;W)E86-H
M("@D=&AI<RT^7W!R;W!E<G1I97,@87,@)'!R;W`@/3X@)&9O;RD@>PH@("`@
M("`@("`@("!P<FEN="`B)'!R;W`@/2`B.PH@("`@("`@("`@("!P<FEN="!H
M=&UL96YT:71I97,H)'1H:7,M/B1P<F]P*3L*("`@("`@("`@("`@<')I;G0@
M(CQB<B`O/EQN(CL*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@)F-R96%T92@I"@H@("`@+RHJ"B`@("`@*B!3=&%T:6,@;65T:&]D
M('5S960@=&\@8W)E871E(&YE=R!$0B!S=&]R86=E(&]B:F5C=',N"B`@("`@
M*B!`<&%R86T@)&1A=&$@87-S;V,N(&%R<F%Y('=H97)E('1H92!K97ES(&%R
M92!T:&4@;F%M97,*("`@("`J("`@("`@("`@("`@("!O9B!P<F]P97)T:65S
M+V-O;'5M;G,*("`@("`J($!R971U<FX@;V)J96-T(&$@;F5W(&EN<W1A;F-E
M(&]F($1"7W-T;W)A9V4@;W(@82!S=6)C;&%S<R!O9B!I=`H@("`@("HO"B`@
M("!F=6YC=&EO;B`F8W)E871E*"1T86)L92P@)B1D871A*0H@("`@>PH@("`@
M("`@("1C;&%S<VYA;64@/2!S=')T;VQO=V5R*&=E=%]C;&%S<R@D=&AI<RDI
M.PH@("`@("`@("1O8FH@/28@;F5W("1C;&%S<VYA;64H)'1A8FQE*3L*("`@
M("`@("!F;W)E86-H("@D9&%T82!A<R`D;F%M92`]/B`D=F%L=64I('L*("`@
M("`@("`@("`@)&]B:BT^7W!R;W!E<G1I97-;)&YA;65=(#T@=')U93L*("`@
M("`@("`@("`@)&]B:BT^)&YA;64@/2`F)'9A;'5E.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@)&]B:CL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!L;V%D1G)O;5%U97)Y*"D*"B`@("`O*BH*("`@("`J($QO861S(&1A=&$@
M:6YT;R!T:&ES(&]B:F5C="!F<F]M('1H92!G:79E;B!Q=65R>2X@($EF('1H
M:7,*("`@("`J(&]B:F5C="!A;')E861Y(&-O;G1A:6YS('1A8FQE(&1A=&$L
M(&-H86YG97,@=VEL;"!B92!S879E9"!A;F0*("`@("`J('1H92!O8FIE8W0@
M<F4M:6YI=&EA;&EZ960@9FER<W0N"B`@("`@*@H@("`@("H@0'!A<F%M("1Q
M=65R>2!344P@<75E<GD*("`@("`J"B`@("`@*B!`<&%R86T@)'!A<F%M<R!P
M87)A;65T97(@;&ES="!I;B!C87-E('EO=2!W86YT('1O('5S90H@("`@("H@
M<')E<&%R92]E>&5C=71E(&UO9&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN
M="!$0E]/2R!O;B!S=6-C97-S+"!$0E]705).24Y'7U)%041?3TY,62!I9B!T
M:&4*("`@("`J(')E='5R;F5D(&]B:F5C="!I<R!R96%D+6]N;'D@*&)E8V%U
M<V4@=&AE(&]B:F5C="=S('-P96-I9FEE9`H@("`@("H@:V5Y(&-O;'5M;B!W
M87,@;F]T(&9O=6YD(&%M;VYG('1H92!C;VQU;6YS(')E='5R;F5D(&)Y("1Q
M=65R>2DL"B`@("`@*B!O<B!A;F]T:&5R($1"(&5R<F]R(&-O9&4@:6X@8V%S
M92!O9B!E<G)O<G,N"B`@("`@*B\*+R\@6%A8(&-O;6UE;G1E9"!O=70@9F]R
M(&YO=PHO*@H@("`@9G5N8W1I;VX@;&]A9$9R;VU1=65R>2@D<75E<GDL("1P
M87)A;7,@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AS:7IE;V8H)'1H:7,M
M/E]P<F]P97)T:65S*2D@>PH@("`@("`@("`@("!I9B`H<VEZ96]F*"1T:&ES
M+3Y?8VAA;F=E<RDI('L*("`@("`@("`@("`@("`@("1T:&ES+3YS=&]R92@I
M.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C:&%N9V5S(#T@87)R87DH*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7W!R;W!E<G1I97,@
M/2!A<G)A>2@I.PH@("`@("`@('T*("`@("`@("`D<F]W9&%T82`]("1T:&ES
M+3Y?9&)H+3YG9712;W<H)'%U97)Y+"!$0E]&151#2$U/1$5?05-33T,L("1P
M87)A;7,I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F]W9&%T82DI('L*
M("`@("`@("`@("`@<F5T=7)N("1R;W=D871A.PH@("`@("`@('T*("`@("`@
M("!R97-E="@D<F]W9&%T82D["B`@("`@("`@)&9O=6YD7VME>6-O;'5M;B`]
M(&9A;'-E.PH@("`@("`@('=H:6QE("AL:7-T*"1K97DL("1V86QU92D@/2!E
M86-H*"1R;W=D871A*2D@>PH@("`@("`@("`@("!I9B`H)&ME>2`]/2`D=&AI
M<RT^7VME>6-O;'5M;BD@>PH@("`@("`@("`@("`@("`@)&9O=6YD7VME>6-O
M;'5M;B`]('1R=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M
M/E]P<F]P97)T:65S6R1K97E=(#T@=')U93L*("`@("`@("`@("`@)'1H:7,M
M/B1K97D@/2`F)'9A;'5E.PH@("`@("`@("`@("!U;G-E="@D=F%L=64I.R`O
M+R!H879E('1O('5N<V5T+"!O<B!A;&P@<')O<&5R=&EE<R!W:6QL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("\O(')E9F5R('1O('1H92!S86UE('9A
M;'5E"B`@("`@("`@?0H@("`@("`@(&EF("@A)&9O=6YD7VME>6-O;'5M;BD@
M>PH@("`@("`@("`@("`D=&AI<RT^7W)E861O;FQY(#T@=')U93L*("`@("`@
M("`@("`@<F5T=7)N($1"7U=!4DY)3D=?4D5!1%]/3DQ9.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"B`J+PH*("`@("\O('U]?0H@
M("`@+R\@>WM[('-E="@I"@H@("`@+RHJ"B`@("`@*B!-;V1I9GD@86X@871T
M<FEU=&4@=F%L=64N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E="@D<')O<&5R
M='DL("1N97=V86QU92D*("`@('L*("`@("`@("`O+R!O;FQY(&-H86YG92!I
M9B`D<')O<&5R='D@:7,@:VYO=VX@86YD(&]B:F5C="!I<R!N;W0*("`@("`@
M("`O+R!R96%D+6]N;'D*("`@("`@("!I9B`H)'1H:7,M/E]R96%D;VYL>2D@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H;G5L;"P@
M1$)?5T%23DE.1U]214%$7T].3%DL(&YU;&PL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!N=6QL+"!N=6QL+"!N=6QL+"!T<G5E*3L*
M("`@("`@("!]"B`@("`@("`@:68@*$!I<W-E="@D=&AI<RT^7W!R;W!E<G1I
M97-;)'!R;W!E<G1Y72DI('L*("`@("`@("`@("`@:68@*&5M<'1Y*"1T:&ES
M+3Y?=F%L:61A=&]R*2D@>PH@("`@("`@("`@("`@("`@)'9A;&ED(#T@=')U
M93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1V86QI
M9"`]($!C86QL7W5S97)?9G5N8R@D=&AI<RT^7W9A;&ED871O<BP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W1A
M8FQE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1P<F]P97)T>2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D;F5W=F%L=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/B1P<F]P97)T>2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RD["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@:68@*"1V86QI9"D@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/B1P<F]P97)T>2`]("1N97=V86QU93L*("`@("`@("`@("`@
M("`@(&EF("AE;7!T>2@D=&AI<RT^7V-H86YG97-;)'!R;W!E<G1Y72DI('L*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-H86YG97-;)'!R;W!E<G1Y
M72`](#`["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?8VAA;F=E<ULD<')O<&5R='E=*RL["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H;G5L;"P@1$)?15)23U)?24Y6
M04Q)1"P@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!N=6QL+"`B:6YV86QI9"!F:65L9#H@)'!R;W!E<G1Y(BP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N=6QL+"!T
M<G5E*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@=')U93L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*&YU
M;&PL($1"7T524D]27TY/4U5#2$9)14Q$+"!N=6QL+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!N=6QL+"`B=6YK;F]W;B!F:65L9#H@)'!R
M;W!E<G1Y(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;G5L
M;"P@=')U92D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@)F=E="@I
M"@H@("`@+RHJ"B`@("`@*B!&971C:"!A;B!A='1R:6)U=&4@=F%L=64N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R!A='1R:6)U=&4@;F%M90H@("`@
M("H*("`@("`J($!R971U<FX@871T<FEB=71E(&-O;G1E;G1S+"!O<B!N=6QL
M(&EF('1H92!A='1R:6)U=&4@;F%M92!I<PH@("`@("H@=6YK;F]W;@H@("`@
M("HO"B`@("!F=6YC=&EO;B`F9V5T*"1P<F]P97)T>2D*("`@('L*("`@("`@
M("`O+R!O;FQY(')E='5R;B!I9B`D<')O<&5R='D@:7,@:VYO=VX*("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]P<F]P97)T:65S6R1P<F]P97)T>5TI*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^)'!R;W!E<G1Y.PH@("`@("`@
M('T*("`@("`@("`D=&UP(#T@;G5L;#L*("`@("`@("!R971U<FX@)'1M<#L*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!?1$)?<W1O<F%G92@I"@H@
M("`@+RHJ"B`@("`@*B!$97-T<G5C=&]R+"!C86QL<R!$0E]S=&]R86=E.CIS
M=&]R92@I(&EF('1H97)E(&%R92!C:&%N9V5S"B`@("`@*B!T:&%T(&%R92!T
M;R!B92!K97!T+@H@("`@("HO"B`@("!F=6YC=&EO;B!?1$)?<W1O<F%G92@I
M"B`@("!["B`@("`@("`@:68@*'-I>F5O9B@D=&AI<RT^7V-H86YG97,I*2![
M"B`@("`@("`@("`@("1T:&ES+3YS=&]R92@I.PH@("`@("`@('T*("`@("`@
M("`D=&AI<RT^7W!R;W!E<G1I97,@/2!A<G)A>2@I.PH@("`@("`@("1T:&ES
M+3Y?8VAA;F=E<R`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/E]T86)L92`]
M(&YU;&P["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<W1O<F4H*0H*
M("`@("\J*@H@("`@("H@4W1O<F5S(&-H86YG97,@=&\@=&AI<R!O8FIE8W0@
M:6X@=&AE(&1A=&%B87-E+@H@("`@("H*("`@("`J($!R971U<FX@1$)?3TL@
M;W(@82!$0B!E<G)O<@H@("`@("HO"B`@("!F=6YC=&EO;B!S=&]R92@I"B`@
M("!["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]C:&%N9V5S(&%S("1N86UE
M(#T^("1F;V\I('L*("`@("`@("`@("`@)'!A<F%M<UM=(#T@)B1T:&ES+3XD
M;F%M93L*("`@("`@("`@("`@)'9A<G-;72`]("1N86UE("X@)R`](#\G.PH@
M("`@("`@('T*("`@("`@("!I9B`H)'9A<G,I('L*("`@("`@("`@("`@)'%U
M97)Y(#T@)U501$%412`G("X@)'1H:7,M/E]T86)L92`N("<@4T54("<@+@H@
M("`@("`@("`@("`@("`@:6UP;&]D92@G+"`G+"`D=F%R<RD@+B`G(%=(15)%
M("<@+@H@("`@("`@("`@("`@("`@)'1H:7,M/E]M86ME5VAE<F4H*3L*("`@
M("`@("`@("`@)'-T;70@/2`D=&AI<RT^7V1B:"T^<')E<&%R92@D<75E<GDI
M.PH@("`@("`@("`@("`D<F5S(#T@)'1H:7,M/E]D8F@M/F5X96-U=&4H)'-T
M;70L("1P87)A;7,I.PH@("`@("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E
M<RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1T:&ES+3Y?8VAA;F=E<R`](&%R<F%Y*"D["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!R96UO=F4H*0H*("`@("\J*@H@("`@("H@4F5M;W9E
M('1H92!R;W<@<F5P<F5S96YT960@8GD@=&AI<R!O8FIE8W0@9G)O;2!T:&4@
M9&%T86)A<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!$0E]/2R!O
M<B!A($1"(&5R<F]R"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V92@I"B`@
M("!["B`@("`@("`@:68@*"1T:&ES+3Y?<F5A9&]N;'DI('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*&YU;&PL($1"7U=!4DY)3D=?
M4D5!1%]/3DQ9+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@;G5L;"P@;G5L;"P@;G5L;"P@=')U92D["B`@("`@("`@?0H@
M("`@("`@("1Q=65R>2`]("=$14Q%5$4@1E)/32`G("X@)'1H:7,M/E]T86)L
M92`N)R!72$5212`G+@H@("`@("`@("`@("`D=&AI<RT^7VUA:V57:&5R92@I
M.PH@("`@("`@("1R97,@/2`D=&AI<RT^7V1B:"T^<75E<GDH)'%U97)Y*3L*
M("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1R97,["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1T:&ES
M+3Y?<')O<&5R=&EE<R!A<R`D<')O<"`]/B`D9F]O*2!["B`@("`@("`@("`@
M('5N<V5T*"1T:&ES+3XD<')O<"D["B`@("`@("`@?0H@("`@("`@("1T:&ES
M+3Y?<')O<&5R=&EE<R`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/E]C:&%N
M9V5S(#T@87)R87DH*3L*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@
M("`@+R\@?7U]"GT*"B\J"B`J($QO8V%L('9A<FEA8FQE<SH*("H@=&%B+7=I
M9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J($5N9#H*("HO"@H_/@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]$0B]S
M<6QI=&4N<&AP````````````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#<R,30U(#$P-3$U-#,S-S,Q(#`R,#<W-``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`H*+RH@=FEM.B!S
M970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A8G-T
M;W`]-#H@*B\*"B\J*@H@*B!4:&4@4$5!4B!$0B!D<FEV97(@9F]R(%!(4"=S
M('-Q;&ET92!E>'1E;G-I;VX*("H@9F]R(&EN=&5R86-T:6YG('=I=&@@4U%,
M:71E(&1A=&%B87-E<PH@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@
M*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R
M<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA
M8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I
M;F<@55)).@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT
M+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(
M4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H
M('1H92!W96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H
M<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*
M("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*
M("H@0&%U=&AO<B`@("`@57)S($=E:')I9R`\=7)S0&-I<F-L92YC:#X*("H@
M0&%U=&AO<B`@("`@36EK82!4=75P;VQA(#QT=75P;VQA0&%P<&5L<VEI;FDN
M;F5T/@H@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC
M0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R
M;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,"`S+C`*("H@0'9E<G-I;VX@("`@
M0U93.B`D260Z('-Q;&ET92YP:'`L=B`Q+C$P.2`R,#`U+S`S+S$P(#`Q.C(R
M.C0X(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N
M<&AP+FYE="]P86-K86=E+T1""B`J+PH*+RHJ"B`J($]B=&%I;B!T:&4@1$)?
M8V]M;6]N(&-L87-S('-O(&ET(&-A;B!B92!E>'1E;F1E9"!F<F]M"B`J+PIR
M97%U:7)E7V]N8V4@)T1"+V-O;6UO;BYP:'`G.PH*+RHJ"B`J(%1H92!M971H
M;V1S(%!%05(@1$(@=7-E<R!T;R!I;G1E<F%C="!W:71H(%!(4"=S('-Q;&ET
M92!E>'1E;G-I;VX*("H@9F]R(&EN=&5R86-T:6YG('=I=&@@4U%,:71E(&1A
M=&%B87-E<PH@*@H@*B!4:&5S92!M971H;V1S(&]V97)L;V%D('1H92!O;F5S
M(&1E8VQA<F5D(&EN($1"7V-O;6UO;BX*("H*("H@3D]424-%.B`@5&AI<R!D
M<FEV97(@;F5E9',@4$A0)W,@=')A8VM?97)R;W)S(&EN:2!S971T:6YG('1O
M(&)E(&]N+@H@*B!)="!I<R!A=71O;6%T:6-A;&QY('1U<FYE9"!O;B!W:&5N
M(&-O;FYE8W1I;F<@=&\@=&AE(&1A=&%B87-E+@H@*B!-86ME('-U<F4@>6]U
M<B!S8W)I<'1S(&1O;B=T('1U<FX@:70@;V9F+@H@*@H@*B!`8V%T96=O<GD@
M("!$871A8F%S90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!5
M<G,@1V5H<FEG(#QU<G-`8VER8VQE+F-H/@H@*B!`875T:&]R("`@("!-:6MA
M(%1U=7!O;&$@/'1U=7!O;&%`87!P96QS:6EN:2YN970^"B`J($!A=71H;W(@
M("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O
M<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@
M("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI
M8V5N<V4@,RXP(#,N,`H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C<N-@H@
M*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*
M("HO"F-L87-S($1"7W-Q;&ET92!E>'1E;F1S($1"7V-O;6UO;@I["B`@("`O
M+R![>WL@<')O<&5R=&EE<PH*("`@("\J*@H@("`@("H@5&AE($1"(&1R:79E
M<B!T>7!E("AM>7-Q;"P@;V-I."P@;V1B8RP@971C+BD*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D<&AP='EP92`]("=S<6QI=&4G.PH*
M("`@("\J*@H@("`@("H@5&AE(&1A=&%B87-E('-Y;G1A>"!V87)I86YT('1O
M(&)E('5S960@*&1B,BP@86-C97-S+"!E=&,N*2P@:68@86YY"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)&1B<WEN=&%X(#T@)W-Q;&ET
M92<["@H@("`@+RHJ"B`@("`@*B!4:&4@8V%P86)I;&ET:65S(&]F('1H:7,@
M1$(@:6UP;&5M96YT871I;VX*("`@("`J"B`@("`@*B!4:&4@)VYE=U]L:6YK
M)R!E;&5M96YT(&-O;G1A:6YS('1H92!02%`@=F5R<VEO;B!T:&%T(&9I<G-T
M('!R;W9I9&5D"B`@("`@*B!N97=?;&EN:R!S=7!P;W)T(&9O<B!T:&ES($1"
M35,N("!#;VYT86EN<R!F86QS92!I9B!I="=S('5N<W5P<&]R=&5D+@H@("`@
M("H*("`@("`J($UE86YI;F<@;V8@=&AE("=L:6UI="<@96QE;65N=#H*("`@
M("`J("`@*R`G96UU;&%T92<@/2!E;75L871E('=I=&@@9F5T8V@@<F]W(&)Y
M(&YU;6)E<@H@("`@("H@("`K("=A;'1E<B<@("`](&%L=&5R('1H92!Q=65R
M>0H@("`@("H@("`K(&9A;'-E("`@("`]('-K:7`@<F]W<PH@("`@("H*("`@
M("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1F96%T=7)E<R`](&%R
M<F%Y*`H@("`@("`@("=L:6UI="<@("`@("`@("`]/B`G86QT97(G+`H@("`@
M("`@("=N97=?;&EN:R<@("`@("`]/B!F86QS92P*("`@("`@("`G;G5M<F]W
M<R<@("`@("`@/3X@=')U92P*("`@("`@("`G<&-O;FYE8W0G("`@("`@/3X@
M=')U92P*("`@("`@("`G<')E<&%R92<@("`@("`@/3X@9F%L<V4L"B`@("`@
M("`@)W-S;"<@("`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("=T<F%N<V%C
M=&EO;G,G("`]/B!F86QS92P*("`@("D["@H@("`@+RHJ"B`@("`@*B!!(&UA
M<'!I;F<@;V8@;F%T:79E(&5R<F]R(&-O9&5S('1O($1"(&5R<F]R(&-O9&5S
M"B`@("`@*@H@("`@("H@>T!I;G1E<FYA;"`@17)R;W(@8V]D97,@86-C;W)D
M:6YG('1O('-Q;&ET95]E>&5C+B`@4V5E('1H92!O;FQI;F4*("`@("`J(&UA
M;G5A;"!A="!H='1P.B\O<W%L:71E+F]R9R]C7VEN=&5R9F%C92YH=&UL(&9O
M<B!I;F9O+@H@("`@("H@5&AI<R!E<G)O<B!H86YD;&EN9R!B87-E9"!O;B!S
M<6QI=&5?97AE8R!I<R!N;W0@>65T(&EM<&QE;65N=&5D+GU]"B`@("`@*@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&5R<F]R8V]D95]M
M87`@/2!A<G)A>2@*("`@("D["@H@("`@+RHJ"B`@("`@*B!4:&4@<F%W(&1A
M=&%B87-E(&-O;FYE8W1I;VX@8W)E871E9"!B>2!02%`*("`@("`J($!V87(@
M<F5S;W5R8V4*("`@("`J+PH@("`@=F%R("1C;VYN96-T:6]N.PH*("`@("\J
M*@H@("`@("H@5&AE($133B!I;F9O<FUA=&EO;B!F;W(@8V]N;F5C=&EN9R!T
M;R!A(&1A=&%B87-E"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D9'-N(#T@87)R87DH*3L*"@H@("`@+RHJ"B`@("`@*B!344QI=&4@9&%T
M82!T>7!E<PH@("`@("H*("`@("`J($!L:6YK(&AT='`Z+R]W=W<N<W%L:71E
M+F]R9R]D871A='EP97,N:'1M;`H@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1K97EW;W)D<R`](&%R<F%Y("@*("`@("`@("`G
M0DQ/0B<@("`@("`]/B`G)RP*("`@("`@("`G0D]/3$5!3B<@("`]/B`G)RP*
M("`@("`@("`G0TA!4D%#5$52)R`]/B`G)RP*("`@("`@("`G0TQ/0B<@("`@
M("`]/B`G)RP*("`@("`@("`G1DQ/050G("`@("`]/B`G)RP*("`@("`@("`G
M24Y414=%4B<@("`]/B`G)RP*("`@("`@("`G2T59)R`@("`@("`]/B`G)RP*
M("`@("`@("`G3D%424].04PG("`]/B`G)RP*("`@("`@("`G3E5-15))0R<@
M("`]/B`G)RP*("`@("`@("`G3E9!4D-(05(G("`]/B`G)RP*("`@("`@("`G
M4%))34%262<@("`]/B`G)RP*("`@("`@("`G5$585"<@("`@("`]/B`G)RP*
M("`@("`@("`G5$E-15-404U0)R`]/B`G)RP*("`@("`@("`G54Y)455%)R`@
M("`]/B`G)RP*("`@("`@("`G5D%20TA!4B<@("`]/B`G)RP*("`@("`@("`G
M5D%264E.1R<@("`]/B`G)RP*("`@("D["@H@("`@+RHJ"B`@("`@*B!4:&4@
M;6]S="!R96-E;G0@97)R;W(@;65S<V%G92!F<F]M("1P:'!?97)R;W)M<V<*
M("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J+PH@("`@=F%R("1?;&%S=&5R<F]R(#T@)R<["@H*("`@("\O('U]?0H@
M("`@+R\@>WM[(&-O;G-T<G5C=&]R"@H@("`@+RHJ"B`@("`@*B!4:&ES(&-O
M;G-T<G5C=&]R(&-A;&QS(#QK8F0^)'1H:7,M/D1"7V-O;6UO;B@I/"]K8F0^
M"B`@("`@*@H@("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T
M:6]N($1"7W-Q;&ET92@I"B`@("!["B`@("`@("`@)'1H:7,M/D1"7V-O;6UO
M;B@I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&-O;FYE8W0H*0H*
M("`@("\J*@H@("`@("H@0V]N;F5C="!T;R!T:&4@9&%T86)A<V4@<V5R=F5R
M+"!L;V<@:6X@86YD(&]P96X@=&AE(&1A=&%B87-E"B`@("`@*@H@("`@("H@
M1&]N)W0@8V%L;"!T:&ES(&UE=&AO9"!D:7)E8W1L>2X@(%5S92!$0CHZ8V]N
M;F5C="@I(&EN<W1E860N"B`@("`@*@H@("`@("H@4$5!4B!$0B=S('-Q;&ET
M92!D<FEV97(@<W5P<&]R=',@=&AE(&9O;&QO=VEN9R!E>'1R82!$4TX@;W!T
M:6]N<SH*("`@("`J("`@*R!M;V1E("!4:&4@<&5R;6ES<VEO;G,@9F]R('1H
M92!D871A8F%S92!F:6QE+"!I;B!F;W5R(&1I9VET"B`@("`@*B`@("`@("`@
M("`@(&-H;6]D(&]C=&%L(&9O<FUA="`H96<@(C`V,#`B*2X*("`@("`J"B`@
M("`@*B!%>&%M<&QE(&]F(&-O;FYE8W1I;F<@=&\@82!D871A8F%S92!I;B!R
M96%D+6]N;'D@;6]D93H*("`@("`J(#QC;V1E/@H@("`@("H@<F5Q=6ER95]O
M;F-E("=$0BYP:'`G.PH@("`@("H@"B`@("`@*B`D9'-N(#T@)W-Q;&ET93HO
M+R]P871H+V%N9"]N86UE+V]F+V1B+V9I;&4_;6]D93TP-#`P)SL*("`@("`J
M("1O<'1I;VYS(#T@87)R87DH"B`@("`@*B`@("`@)W!O<G1A8FEL:71Y)R`]
M/B!$0E]03U)404))3$E465]!3$PL"B`@("`@*B`I.PH@("`@("H@"B`@("`@
M*B`D9&(@/28@1$(Z.F-O;FYE8W0H)&1S;BP@)&]P=&EO;G,I.PH@("`@("H@
M:68@*%!%05(Z.FES17)R;W(H)&1B*2D@>PH@("`@("H@("`@(&1I92@D9&(M
M/F=E=$UE<W-A9V4H*2D["B`@("`@*B!]"B`@("`@*B`\+V-O9&4^"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("1D<VX@("`@("`@("!T:&4@9&%T82!S
M;W5R8V4@;F%M90H@("`@("H@0'!A<F%M(&)O;VP@("1P97)S:7-T96YT("!S
M:&]U;&0@=&AE(&-O;FYE8W1I;VX@8F4@<&5R<VES=&5N=#\*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@02!$0E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]N
M;F5C="@D9'-N+"`D<&5R<VES=&5N="`](&9A;'-E*0H@("`@>PH@("`@("`@
M(&EF("@A4$5!4CHZ;&]A9$5X=&5N<VEO;B@G<W%L:71E)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27T585$5.
M4TE/3E].3U1?1D]53D0I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/F1S
M;B`]("1D<VX["B`@("`@("`@:68@*"1D<VY;)V1B<WEN=&%X)UTI('L*("`@
M("`@("`@("`@)'1H:7,M/F1B<WEN=&%X(#T@)&1S;ELG9&)S>6YT87@G73L*
M("`@("`@("!]"@H@("`@("`@(&EF("@D9'-N6R=D871A8F%S92==*2!["B`@
M("`@("`@("`@(&EF("@A9FEL95]E>&ES=',H)&1S;ELG9&%T86)A<V4G72DI
M('L*("`@("`@("`@("`@("`@(&EF("@A=&]U8V@H)&1S;ELG9&%T86)A<V4G
M72DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G-Q;&ET
M95)A:7-E17)R;W(H1$)?15)23U)?3D]47T9/54Y$*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&1S;ELG;6]D92==
M*2!\?`H@("`@("`@("`@("`@("`@("`@("%I<U]N=6UE<FEC*"1D<VY;)VUO
M9&4G72DI"B`@("`@("`@("`@("`@("!["B`@("`@("`@("`@("`@("`@("`@
M)&UO9&4@/2`P-C0T.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`D;6]D92`](&]C=&1E8R@D9'-N6R=M;V1E)UTI.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"%C:&UO9"@D
M9'-N6R=D871A8F%S92==+"`D;6]D92DI('L*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G-Q;&ET95)A:7-E17)R;W(H1$)?15)23U)?3D]4
M7T9/54Y$*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF
M("@A9FEL95]E>&ES=',H)&1S;ELG9&%T86)A<V4G72DI('L*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G-Q;&ET95)A:7-E17)R;W(H1$)?
M15)23U)?3D]47T9/54Y$*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!I9B`H(6ES7V9I;&4H)&1S;ELG9&%T86)A<V4G
M72DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<W%L:71E4F%I
M<V5%<G)O<BA$0E]%4E)/4E])3E9!3$E$*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!I9B`H(6ES7W)E861A8FQE*"1D<VY;)V1A=&%B87-E)UTI*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G-Q;&ET95)A:7-E17)R
M;W(H1$)?15)23U)?04-#15-37U9)3TQ!5$E/3BD["B`@("`@("`@("`@('T*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G-Q
M;&ET95)A:7-E17)R;W(H1$)?15)23U)?04-#15-37U9)3TQ!5$E/3BD["B`@
M("`@("`@?0H*("`@("`@("`D8V]N;F5C=%]F=6YC=&EO;B`]("1P97)S:7-T
M96YT(#\@)W-Q;&ET95]P;W!E;B<@.B`G<W%L:71E7V]P96XG.PH*("`@("`@
M("`O+R!T<F%C:U]E<G)O<G,@;75S="!R96UA:6X@;VX@9F]R('-I;7!L95%U
M97)Y*"D*("`@("`@("!I;FE?<V5T*"=T<F%C:U]E<G)O<G,G+"`Q*3L*("`@
M("`@("`D<&AP7V5R<F]R;7-G(#T@)R<["@H@("`@("`@(&EF("@A)'1H:7,M
M/F-O;FYE8W1I;VX@/2!`)&-O;FYE8W1?9G5N8W1I;VXH)&1S;ELG9&%T86)A
M<V4G72DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*$1"7T524D]27TY/1$)314Q%0U1%1"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&YU;&PL(&YU;&PL(&YU;&PL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<&AP7V5R<F]R;7-G*3L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[(&1I<V-O;FYE8W0H*0H*("`@("\J*@H@("`@("H@1&ES
M8V]N;F5C=',@9G)O;2!T:&4@9&%T86)A<V4@<V5R=F5R"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L("!44E5%(&]N('-U8V-E<W,L($9!3%-%(&]N(&9A
M:6QU<F4*("`@("`J+PH@("`@9G5N8W1I;VX@9&ES8V]N;F5C="@I"B`@("![
M"B`@("`@("`@)')E="`]($!S<6QI=&5?8VQO<V4H)'1H:7,M/F-O;FYE8W1I
M;VXI.PH@("`@("`@("1T:&ES+3YC;VYN96-T:6]N(#T@;G5L;#L*("`@("`@
M("!R971U<FX@)')E=#L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!S
M:6UP;&51=65R>2@I"@H@("`@+RHJ"B`@("`@*B!396YD<R!A('%U97)Y('1O
M('1H92!D871A8F%S92!S97)V97(*("`@("`J"B`@("`@*B!.3U1)0T4Z("!4
M:&ES(&UE=&AO9"!N965D<R!02%`G<R!T<F%C:U]E<G)O<G,@:6YI('-E='1I
M;F<@=&\@8F4@;VXN"B`@("`@*B!)="!I<R!A=71O;6%T:6-A;&QY('1U<FYE
M9"!O;B!W:&5N(&-O;FYE8W1I;F<@=&\@=&AE(&1A=&%B87-E+@H@("`@("H@
M36%K92!S=7)E('EO=7(@<V-R:7!T<R!D;VXG="!T=7)N(&ET(&]F9BX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("!T:&4@4U%,('%U97)Y('-T<FEN
M9PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@("L@82!02%`@<F5S=6QT
M(')E<W)O=6-E(&9O<B!S=6-C97-S9G5L(%-%3$5#5"!Q=65R:65S"B`@("`@
M*B`@("`@("`@("`@("`@("`K('1H92!$0E]/2R!C;VYS=&%N="!F;W(@;W1H
M97(@<W5C8V5S<V9U;"!Q=65R:65S"B`@("`@*B`@("`@("`@("`@("`@("`K
M(&$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4*("`@("`J+PH@("`@9G5N
M8W1I;VX@<VEM<&QE475E<GDH)'%U97)Y*0H@("`@>PH@("`@("`@("1I<VUA
M;FEP(#T@1$(Z.FES36%N:7`H)'%U97)Y*3L*("`@("`@("`D=&AI<RT^;&%S
M=%]Q=65R>2`]("1Q=65R>3L*("`@("`@("`D<75E<GD@/2`D=&AI<RT^;6]D
M:69Y475E<GDH)'%U97)Y*3L*"B`@("`@("`@)'!H<%]E<G)O<FUS9R`]("<G
M.PH*("`@("`@("`D<F5S=6QT(#T@0'-Q;&ET95]Q=65R>2@D<75E<GDL("1T
M:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`D=&AI<RT^7VQA<W1E<G)O<B`]
M("1P:'!?97)R;W)M<V<@/R`D<&AP7V5R<F]R;7-G(#H@)R<["@H@("`@("`@
M("1T:&ES+3YR97-U;'0@/2`D<F5S=6QT.PH@("`@("`@(&EF("@A)'1H:7,M
M/G)E<W5L="D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G-Q;&ET95)A
M:7-E17)R;W(H;G5L;"D["B`@("`@("`@?0H*("`@("`@("`O+R!S<6QI=&5?
M<75E<GDH*2!S965M<R!T;R!A;&QW87ES(')E='5R;B!A(')E<V]U<F-E"B`@
M("`@("`@+R\@<V\@8V%N="!U<V4@=&AA="X@57-I;F<@)&ES;6%N:7`@:6YS
M=&5A9`H@("`@("`@(&EF("@A)&ES;6%N:7`I('L*("`@("`@("`@("`@)&YU
M;5)O=W,@/2`D=&AI<RT^;G5M4F]W<R@D<F5S=6QT*3L*("`@("`@("`@("`@
M:68@*&ES7V]B:F5C="@D;G5M4F]W<RDI('L*("`@("`@("`@("`@("`@("\O
M('=E)W9E(&=O="!014%27T5R<F]R"B`@("`@("`@("`@("`@("!R971U<FX@
M)&YU;5)O=W,["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!N97AT4F5S=6QT*"D*"B`@("`O*BH*
M("`@("`J($UO=F4@=&AE(&EN=&5R;F%L('-Q;&ET92!R97-U;'0@<&]I;G1E
M<B!T;R!T:&4@;F5X="!A=F%I;&%B;&4@<F5S=6QT"B`@("`@*@H@("`@("H@
M0'!A<F%M(')E<V]U<F-E("1R97-U;'0@('1H92!V86QI9"!S<6QI=&4@<F5S
M=6QT(')E<V]U<F-E"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L("!T<G5E
M(&EF(&$@<F5S=6QT(&ES(&%V86EL86)L92!O=&AE<G=I<V4@<F5T=7)N(&9A
M;'-E"B`@("`@*B\*("`@(&9U;F-T:6]N(&YE>'1297-U;'0H)')E<W5L="D*
M("`@('L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@9F5T8VA);G1O*"D*"B`@("`O*BH*("`@("`J(%!L86-E
M<R!A(')O=R!F<F]M('1H92!R97-U;'0@<V5T(&EN=&\@=&AE(&=I=F5N(&%R
M<F%Y"B`@("`@*@H@("`@("H@1F]R;6%T:6YG(&]F('1H92!A<G)A>2!A;F0@
M=&AE(&1A=&$@=&AE<F5I;B!A<F4@8V]N9FEG=7)A8FQE+@H@("`@("H@4V5E
M($1"7W)E<W5L=#HZ9F5T8VA);G1O*"D@9F]R(&UO<F4@:6YF;W)M871I;VXN
M"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E
M(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@("H@1$)?<F5S=6QT.CIF971C
M:$EN=&\H*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E
M8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@
M;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT
M("`@('1H92!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J($!P87)A;2!A
M<G)A>2`@("`D87)R("`@("`@('1H92!R969E<F5N8V5D(&%R<F%Y('1O('!U
M="!T:&4@9&%T82!I;@H@("`@("H@0'!A<F%M(&EN="`@("`@("1F971C:&UO
M9&4@:&]W('1H92!R97-U;'1I;F<@87)R87D@<VAO=6QD(&)E(&EN9&5X960*
M("`@("`J($!P87)A;2!I;G0@("`@("`D<F]W;G5M("`@('1H92!R;W<@;G5M
M8F5R('1O(&9E=&-H("@P(#T@9FER<W0@<F]W*0H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@($1"7T]+(&]N('-U8V-E<W,L($Y53$P@=VAE;B!T:&4@
M96YD(&]F(&$@<F5S=6QT('-E="!I<PH@("`@("H@("`@("`@("`@("`@("`@
M(')E86-H960@;W(@;VX@9F%I;'5R90H@("`@("H*("`@("`J($!S964@1$)?
M<F5S=6QT.CIF971C:$EN=&\H*0H@("`@("HO"B`@("!F=6YC=&EO;B!F971C
M:$EN=&\H)')E<W5L="P@)B1A<G(L("1F971C:&UO9&4L("1R;W=N=6T@/2!N
M=6QL*0H@("`@>PH@("`@("`@(&EF("@D<F]W;G5M("$]/2!N=6QL*2!["B`@
M("`@("`@("`@(&EF("@A0'-Q;&ET95]S965K*"1T:&ES+3YR97-U;'0L("1R
M;W=N=6TI*2!["B`@("`@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H)&9E=&-H;6]D92`F($1"
M7T9%5$-(34]$15]!4U-/0RD@>PH@("`@("`@("`@("`D87)R(#T@0'-Q;&ET
M95]F971C:%]A<G)A>2@D<F5S=6QT+"!344Q)5$5?05-33T,I.PH@("`@("`@
M("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]0
M3U)404))3$E465],3U=%4D-!4T4@)B8@)&%R<BD@>PH@("`@("`@("`@("`@
M("`@)&%R<B`](&%R<F%Y7V-H86YG95]K97E?8V%S92@D87)R+"!#05-%7TQ/
M5T52*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1A<G(@/2!`<W%L:71E7V9E=&-H7V%R<F%Y*"1R97-U;'0L(%-13$E4
M15].54TI.PH@("`@("`@('T*("`@("`@("!I9B`H(21A<G(I('L*("`@("`@
M("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI
M<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197U)4
M4DE-*2!["B`@("`@("`@("`@("\J"B`@("`@("`@("`@("`J($5V96X@=&AO
M=6=H('1H:7,@1$)-4R!A;')E861Y('1R:6US(&]U='!U="P@=V4@9&\@=&AI
M<R!B96-A=7-E"B`@("`@("`@("`@("`J(&$@9FEE;&0@;6EG:'0@:&%V92!I
M;G1E;G1I;VYA;"!W:&ET97-P86-E(&%T('1H92!E;F0@=&AA=`H@("`@("`@
M("`@("`@*B!G971S(')E;6]V960@8GD@1$)?4$]25$%"24Q)5%E?4E1224T@
M=6YD97(@86YO=&AE<B!D<FEV97(N"B`@("`@("`@("`@("`J+PH@("`@("`@
M("`@("`D=&AI<RT^7W)T<FEM07)R87E686QU97,H)&%R<BD["B`@("`@("`@
M?0H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F
M($1"7U!/4E1!0DE,25197TY53$Q?5$]?14U05%DI('L*("`@("`@("`@("`@
M)'1H:7,M/E]C;VYV97)T3G5L;$%R<F%Y5F%L=65S5&]%;7!T>2@D87)R*3L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&9R965297-U;'0H*0H*("`@("\J*@H@("`@("H@
M1&5L971E<R!T:&4@<F5S=6QT('-E="!A;F0@9G)E97,@=&AE(&UE;6]R>2!O
M8V-U<&EE9"!B>2!T:&4@<F5S=6QT('-E=`H@("`@("H*("`@("`J(%1H:7,@
M;65T:&]D(&ES(&YO="!M96%N="!T;R!B92!C86QL960@9&ER96-T;'DN("!5
M<V4*("`@("`J($1"7W)E<W5L=#HZ9G)E92@I(&EN<W1E860N("!)="!C86XG
M="!B92!D96-L87)E9"`B<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R
M97-U;'0@:7,@82!S97!A<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A
M<F%M(')E<V]U<F-E("1R97-U;'0@(%!(4"=S('%U97)Y(')E<W5L="!R97-O
M=7)C90H@("`@("H*("`@("`J($!R971U<FX@8F]O;"`@5%)512!O;B!S=6-C
M97-S+"!&04Q312!I9B`D<F5S=6QT(&ES(&EN=F%L:60*("`@("`J"B`@("`@
M*B!`<V5E($1"7W)E<W5L=#HZ9G)E92@I"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&9R965297-U;'0H)B1R97-U;'0I"B`@("!["B`@("`@("`@+R\@6%A8($YO
M(&YA=&EV92!F<F5E/PH@("`@("`@(&EF("@A:7-?<F5S;W5R8V4H)')E<W5L
M="DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@
M("`@("`D<F5S=6QT(#T@;G5L;#L*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!N=6U#;VQS*"D*"B`@("`O*BH*
M("`@("`J($=E=',@=&AE(&YU;6)E<B!O9B!C;VQU;6YS(&EN(&$@<F5S=6QT
M('-E=`H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES(&YO="!M96%N="!T
M;R!B92!C86QL960@9&ER96-T;'DN("!5<V4*("`@("`J($1"7W)E<W5L=#HZ
M;G5M0V]L<R@I(&EN<W1E860N("!)="!C86XG="!B92!D96-L87)E9"`B<')O
M=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@82!S97!A<F%T
M92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1R97-U
M;'0@(%!(4"=S('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@("H*("`@("`J
M($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F(&-O;'5M;G,N("!!($1"7T5R
M<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?
M<F5S=6QT.CIN=6U#;VQS*"D*("`@("`J+PH@("`@9G5N8W1I;VX@;G5M0V]L
M<R@D<F5S=6QT*0H@("`@>PH@("`@("`@("1C;VQS(#T@0'-Q;&ET95]N=6U?
M9FEE;&1S*"1R97-U;'0I.PH@("`@("`@(&EF("@A)&-O;',I('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YS<6QI=&5286ES945R<F]R*"D["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D8V]L<SL*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!N=6U2;W=S*"D*"B`@("`O*BH*("`@("`J($=E=',@=&AE
M(&YU;6)E<B!O9B!R;W=S(&EN(&$@<F5S=6QT('-E=`H@("`@("H*("`@("`J
M(%1H:7,@;65T:&]D(&ES(&YO="!M96%N="!T;R!B92!C86QL960@9&ER96-T
M;'DN("!5<V4*("`@("`J($1"7W)E<W5L=#HZ;G5M4F]W<R@I(&EN<W1E860N
M("!)="!C86XG="!B92!D96-L87)E9"`B<')O=&5C=&5D(@H@("`@("H@8F5C
M875S92!$0E]R97-U;'0@:7,@82!S97!A<F%T92!O8FIE8W0N"B`@("`@*@H@
M("`@("H@0'!A<F%M(')E<V]U<F-E("1R97-U;'0@(%!(4"=S('%U97)Y(')E
M<W5L="!R97-O=7)C90H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@
M;G5M8F5R(&]F(')O=W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("H*("`@("`J($!S964@1$)?<F5S=6QT.CIN=6U2;W=S*"D*("`@
M("`J+PH@("`@9G5N8W1I;VX@;G5M4F]W<R@D<F5S=6QT*0H@("`@>PH@("`@
M("`@("1R;W=S(#T@0'-Q;&ET95]N=6U?<F]W<R@D<F5S=6QT*3L*("`@("`@
M("!I9B`H)')O=W,@/3T](&YU;&PI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YS<6QI=&5286ES945R<F]R*"D["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D<F]W<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!A9F9E
M8W1E9"@I"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S('1H92!N=6UB97(@
M;V8@<F]W<R!A9F9E8W1E9"!B>2!A(&1A=&$@;6%N:75P;&%T:6]N('%U97)Y
M"B`@("`@*@H@("`@("H@,"!I<R!R971U<FYE9"!F;W(@<75E<FEE<R!T:&%T
M(&1O;B=T(&UA;FEP=6QA=&4@9&%T82X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&EN="`@=&AE(&YU;6)E<B!O9B!R;W=S+B`@02!$0E]%<G)O<B!O8FIE8W0@
M;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@869F96-T9612;W=S
M*"D*("`@('L*("`@("`@("!R971U<FX@0'-Q;&ET95]C:&%N9V5S*"1T:&ES
M+3YC;VYN96-T:6]N*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!D
M<F]P4V5Q=65N8V4H*0H*("`@("\J*@H@("`@("H@1&5L971E<R!A('-E<75E
M;F-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5Q7VYA;64@(&YA
M;64@;V8@=&AE('-E<75E;F-E('1O(&)E(&1E;&5T960*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM
M;VXZ.F1R;W!397%U96YC92@I+"!$0E]C;VUM;VXZ.F=E=%-E<75E;F-E3F%M
M92@I+`H@("`@("H@("`@("!$0E]S<6QI=&4Z.FYE>'1)1"@I+"!$0E]S<6QI
M=&4Z.F-R96%T95-E<75E;F-E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9')O
M<%-E<75E;F-E*"1S97%?;F%M92D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/G%U97)Y*"=$4D]0(%1!0DQ%("<@+B`D=&AI<RT^9V5T4V5Q=65N8V5.
M86UE*"1S97%?;F%M92DI.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E
M<R!A(&YE=R!S97%U96YC90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'-E<5]N86UE("!N86UE(&]F('1H92!N97<@<V5Q=65N8V4*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R
M;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C
M;VUM;VXZ.F-R96%T95-E<75E;F-E*"DL($1"7V-O;6UO;CHZ9V5T4V5Q=65N
M8V5.86UE*"DL"B`@("`@*B`@("`@($1"7W-Q;&ET93HZ;F5X=$E$*"DL($1"
M7W-Q;&ET93HZ9')O<%-E<75E;F-E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@
M8W)E871E4V5Q=65N8V4H)'-E<5]N86UE*0H@("`@>PH@("`@("`@("1S97%N
M86UE(#T@)'1H:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I.PH@("`@
M("`@("1Q=65R>2`@(#T@)T-214%412!404),12`G("X@)'-E<6YA;64@+@H@
M("`@("`@("`@("`@("`@("`@)R`H:60@24Y414=%4B!53E-)1TY%1"!04DE-
M05)9($M%62D@)SL*("`@("`@("`D<F5S=6QT("`]("1T:&ES+3YQ=65R>2@D
M<75E<GDI.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@
M("`@("`@("`@("!R971U<FXH)')E<W5L="D["B`@("`@("`@?0H@("`@("`@
M("1Q=65R>2`@(#T@(D-214%412!44DE'1T52("1[<V5Q;F%M97U?8VQE86YU
M<"!!1E1%4B!)3E-%4E0@3TX@)'-E<6YA;64*("`@("`@("`@("`@("`@("`@
M("!"14=)3@H@("`@("`@("`@("`@("`@("`@("`@("!$14Q%5$4@1E)/32`D
M<V5Q;F%M92!72$5212!I9#Q,05-47TE.4T525%]23U=)1"@I.PH@("`@("`@
M("`@("`@("`@("`@($5.1"`B.PH@("`@("`@("1R97-U;'0@(#T@)'1H:7,M
M/G%U97)Y*"1Q=65R>2D["B`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97-U
M;'0I*2!["B`@("`@("`@("`@(')E='5R;B@D<F5S=6QT*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;F5X=$ED*"D*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE(&YE>'0@9G)E92!I9"!I;B!A('-E<75E
M;F-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'-E<5]N86UE("!N
M86UE(&]F('1H92!S97%U96YC90H@("`@("H@0'!A<F%M(&)O;VQE86X@)&]N
M9&5M86YD("!W:&5N('1R=64L('1H92!S97%E;F-E(&ES(&%U=&]M871I8V%L
M;'D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-R96%T960@
M:68@:70@9&]E<R!N;W0@97AI<W0*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN
M="`@=&AE(&YE>'0@:60@;G5M8F5R(&EN('1H92!S97%U96YC92X*("`@("`J
M("`@("`@("`@("`@("`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*
M("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ;F5X=$E$*"DL($1"7V-O
M;6UO;CHZ9V5T4V5Q=65N8V5.86UE*"DL"B`@("`@*B`@("`@($1"7W-Q;&ET
M93HZ8W)E871E4V5Q=65N8V4H*2P@1$)?<W%L:71E.CID<F]P4V5Q=65N8V4H
M*0H@("`@("HO"B`@("!F=6YC=&EO;B!N97AT260H)'-E<5]N86UE+"`D;VYD
M96UA;F0@/2!T<G5E*0H@("`@>PH@("`@("`@("1S97%N86UE(#T@)'1H:7,M
M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I.PH*("`@("`@("!D;R!["B`@
M("`@("`@("`@("1R97!E870@/2`P.PH@("`@("`@("`@("`D=&AI<RT^<'5S
M:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PH@("`@("`@("`@
M("`D<F5S=6QT(#T@)'1H:7,M/G%U97)Y*"))3E-%4E0@24Y43R`D<V5Q;F%M
M92`H:60I(%9!3%5%4R`H3E5,3"DB*3L*("`@("`@("`@("`@)'1H:7,M/G!O
M<$5R<F]R2&%N9&QI;F<H*3L*("`@("`@("`@("`@:68@*"1R97-U;'0@/3T]
M($1"7T]+*2!["B`@("`@("`@("`@("`@("`D:60@/2!`<W%L:71E7VQA<W1?
M:6YS97)T7W)O=VED*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`@("`@
M("`@(&EF("@D:60@(3T@,"D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D:60["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS96EF
M("@D;VYD96UA;F0@)B8@1$(Z.FES17)R;W(H)')E<W5L="D@)B8*("`@("`@
M("`@("`@("`@("`@("`@("1R97-U;'0M/F=E=$-O9&4H*2`]/2!$0E]%4E)/
M4E].3U-50TA404),12D*("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@
M)')E<W5L="`]("1T:&ES+3YC<F5A=&5397%U96YC92@D<V5Q7VYA;64I.PH@
M("`@("`@("`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1R
M97-U;'0I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D<F5P96%T(#T@,3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T@=VAI;&4@*"1R97!E870I.PH*("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)')E<W5L="D["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@9V5T1&)&:6QE4W1A=',H*0H*("`@("\J*@H@
M("`@("H@1V5T('1H92!F:6QE('-T871S(&9O<B!T:&4@8W5R<F5N="!D871A
M8F%S90H@("`@("H*("`@("`J(%!O<W-I8FQE(&%R9W5M96YT<R!A<F4@9&5V
M+"!I;F\L(&UO9&4L(&YL:6YK+"!U:60L(&=I9"P@<F1E=BP@<VEZ92P*("`@
M("`J(&%T:6UE+"!M=&EM92P@8W1I;64L(&)L:W-I>F4L(&)L;V-K<R!O<B!A
M(&YU;65R:6,@:V5Y(&)E='=E96X*("`@("`J(#`@86YD(#$R+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&%R9R`@=&AE(&%R<F%Y(&ME>2!F;W(@
M<W1A=',H*0H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(&%N(&%R<F%Y
M(&]N(&%N('5N<W!E8VEF:65D(&ME>2P@:6YT96=E<B!O;B!A('!A<W-E9`H@
M("`@("H@("`@("`@("`@("`@("`@87)G(&%N9"!F86QS92!A="!A('-T871S
M(&5R<F]R"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1B1FEL95-T871S*"1A
M<F<@/2`G)RD*("`@('L*("`@("`@("`D<W1A=',@/2!S=&%T*"1T:&ES+3YD
M<VY;)V1A=&%B87-E)UTI.PH@("`@("`@(&EF("@D<W1A=',@/3T@9F%L<V4I
M('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@
M("!I9B`H:7-?87)R87DH)'-T871S*2D@>PH@("`@("`@("`@("!I9B`H:7-?
M;G5M97)I8R@D87)G*2D@>PH@("`@("`@("`@("`@("`@:68@*"@H:6YT*21A
M<F<@/#T@,3(I("8@*"AI;G0I)&%R9R`^/2`P*2D@>PH@("`@("`@("`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(')E='5R;B`D<W1A='-;)&%R9R!=.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S*'1R:6TH)&%R9RDL
M("1S=&%T<RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<W1A='-;)&%R
M9R!=.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D
M<W1A=',["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@97-C87!E4VEM
M<&QE*"D*"B`@("`O*BH*("`@("`J($5S8V%P97,@82!S=')I;F<@86-C;W)D
M:6YG('1O('1H92!C=7)R96YT($1"35,G<R!S=&%N9&%R9',*("`@("`J"B`@
M("`@*B!);B!344QI=&4L('1H:7,@;6%K97,@=&AI;F=S('-A9F4@9F]R(&EN
M<V5R=',O=7!D871E<RP@8G5T(&UA>0H@("`@("H@8V%U<V4@<')O8FQE;7,@
M=VAE;B!P97)F;W)M:6YG('1E>'0@8V]M<&%R:7-O;G,@86=A:6YS="!C;VQU
M;6YS"B`@("`@*B!C;VYT86EN:6YG(&)I;F%R>2!D871A+B!3964@=&AE"B`@
M("`@*B![0&QI;FL@:'1T<#HO+W!H<"YN970O<W%L:71E7V5S8V%P95]S=')I
M;F<@4$A0(&UA;G5A;'T@9F]R(&UO<F4@:6YF;RX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1S='(@('1H92!S=')I;F<@=&\@8F4@97-C87!E9`H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@97-C87!E9"!S=')I
M;F<*("`@("`J"B`@("`@*B!`<VEN8V4@365T:&]D(&%V86EL86)L92!S:6YC
M92!296QE87-E(#$N-BXQ"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ97-C87!E
M4VEM<&QE*"D*("`@("`J+PH@("`@9G5N8W1I;VX@97-C87!E4VEM<&QE*"1S
M='(I"B`@("!["B`@("`@("`@<F5T=7)N($!S<6QI=&5?97-C87!E7W-T<FEN
M9R@D<W1R*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!M;V1I9GE,
M:6UI=%%U97)Y*"D*"B`@("`O*BH*("`@("`J($%D9',@3$E-250@8VQA=7-E
M<R!T;R!A('%U97)Y('-T<FEN9R!A8V-O<F1I;F<@=&\@8W5R<F5N="!$0DU3
M('-T86YD87)D<PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'%U97)Y
M("`@=&AE('%U97)Y('1O(&UO9&EF>0H@("`@("H@0'!A<F%M(&EN="`@("`D
M9G)O;2`@("!T:&4@<F]W('1O('-T87)T('1O(&9E=&-H:6YG("@P(#T@=&AE
M(&9I<G-T(')O=RD*("`@("`J($!P87)A;2!I;G0@("`@)&-O=6YT("`@=&AE
M(&YU;6)E<G,@;V8@<F]W<R!T;R!F971C:`H@("`@("H@0'!A<F%M(&UI>&5D
M("`D<&%R86US("!A<G)A>2P@<W1R:6YG(&]R(&YU;65R:6,@9&%T82!T;R!B
M92!U<V5D(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!E>&5C
M=71I;VX@;V8@=&AE('-T871E;65N="X@(%%U86YT:71Y(&]F(&ET96US"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!P87-S960@;75S="!M871C
M:"!Q=6%N=&ET>2!O9B!P;&%C96AO;&1E<G,@:6X*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@('%U97)Y.B`@;65A;FEN9R`Q('!L86-E:&]L9&5R
M(&9O<B!N;VXM87)R87D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M('!A<F%M971E<G,@;W(@,2!P;&%C96AO;&1E<B!P97(@87)R87D@96QE;65N
M="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE('%U97)Y('-T
M<FEN9R!W:71H($Q)34E4(&-L875S97,@861D960*("`@("`J"B`@("`@*B!`
M86-C97-S('!R;W1E8W1E9`H@("`@("HO"B`@("!F=6YC=&EO;B!M;V1I9GE,
M:6UI=%%U97)Y*"1Q=65R>2P@)&9R;VTL("1C;W5N="P@)'!A<F%M<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@<F5T=7)N("(D<75E<GD@3$E-250@)&-O
M=6YT($]&1E-%5"`D9G)O;2(["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@;6]D:69Y475E<GDH*0H*("`@("\J*@H@("`@("H@0VAA;F=E<R!A('%U
M97)Y('-T<FEN9R!F;W(@=F%R:6]U<R!$0DU3('-P96-I9FEC(')E87-O;G,*
M("`@("`J"B`@("`@*B!4:&ES(&QI='1L92!H86-K(&QE=',@>6]U(&MN;W<@
M:&]W(&UA;GD@<F]W<R!W97)E(&1E;&5T960*("`@("`J('=H96X@<G5N;FEN
M9R!A(")$14Q%5$4@1E)/32!T86)L92(@<75E<GDN("!/;FQY(&EM<&QE;65N
M=&5D"B`@("`@*B!I9B!T:&4@1$)?4$]25$%"24Q)5%E?1$5,151%7T-/54Y4
M('!O<G1A8FEL:71Y(&]P=&EO;B!I<R!O;BX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1Q=65R>2`@=&AE('%U97)Y('-T<FEN9R!T;R!M;V1I9GD*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&UO9&EF:65D('%U
M97)Y('-T<FEN9PH@("`@("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@
M("`@*B!`<V5E($1"7V-O;6UO;CHZ<V5T3W!T:6]N*"D*("`@("`J+PH@("`@
M9G5N8W1I;VX@;6]D:69Y475E<GDH)'%U97)Y*0H@("`@>PH@("`@("`@(&EF
M("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,
M25197T1%3$5415]#3U5.5"D@>PH@("`@("`@("`@("!I9B`H<')E9U]M871C
M:"@G+UY<<RI$14Q%5$5<<RM&4D]-7',K*%Q3*RE<<RHD+VDG+"`D<75E<GDI
M*2!["B`@("`@("`@("`@("`@("`D<75E<GD@/2!P<F5G7W)E<&QA8V4H)R]>
M7',J1$5,151%7',K1E)/35QS*RA<4RLI7',J)"\G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=$14Q%5$4@1E)/32!<,2!72$52
M12`Q/3$G+"`D<75E<GDI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D<75E<GD["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@<W%L:71E4F%I<V5%<G)O<B@I"@H@("`@+RHJ"B`@("`@*B!0<F]D=6-E
M<R!A($1"7T5R<F]R(&]B:F5C="!R96=A<F1I;F<@=&AE(&-U<G)E;G0@<')O
M8FQE;0H@("`@("H*("`@("`J($!P87)A;2!I;G0@)&5R<FYO("!I9B!T:&4@
M97)R;W(@:7,@8F5I;F<@;6%N=6%L;'D@<F%I<V5D('!A<W,@80H@("`@("H@
M("`@("`@("`@("`@("`@("`@("!$0E]%4E)/4BH@8V]N<W1A;G0@:&5R92X@
M($EF('1H:7,@:7-N)W0@<&%S<V5D"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@('1H92!E<G)O<B!I;F9O<FUA=&EO;B!G871H97)E9"!F<F]M('1H92!$
M0DU3+@H@("`@("H*("`@("`J($!R971U<FX@;V)J96-T("!T:&4@1$)?17)R
M;W(@;V)J96-T"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G)A:7-E
M17)R;W(H*2P*("`@("`J("`@("`@1$)?<W%L:71E.CIE<G)O<DYA=&EV92@I
M+"!$0E]S<6QI=&4Z.F5R<F]R0V]D92@I"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-Q;&ET95)A:7-E17)R;W(H)&5R<FYO(#T@;G5L;"D*("`@('L*("`@("`@
M("`D;F%T:79E(#T@)'1H:7,M/F5R<F]R3F%T:79E*"D["B`@("`@("`@:68@
M*"1E<G)N;R`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D97)R;F\@/2`D=&AI
M<RT^97)R;W)#;V1E*"1N871I=F4I.PH@("`@("`@('T*"B`@("`@("`@)&5R
M<F]R8V]D92`]($!S<6QI=&5?;&%S=%]E<G)O<B@D=&AI<RT^8V]N;F5C=&EO
M;BD["B`@("`@("`@)'5S97)I;F9O(#T@(B1E<G)O<F-O9&4@*BH@)'1H:7,M
M/FQA<W1?<75E<GDB.PH*("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H)&5R<FYO+"!N=6QL+"!N=6QL+"`D=7-E<FEN9F\L("1N871I=F4I.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&5R<F]R3F%T:79E*"D*"B`@
M("`O*BH*("`@("`J($=E=',@=&AE($1"35,G(&YA=&EV92!E<G)O<B!M97-S
M86=E('!R;V1U8V5D(&)Y('1H92!L87-T('%U97)Y"B`@("`@*@H@("`@("H@
M>T!I;G1E<FYA;"!4:&ES(&ES('5S960@=&\@<F5T<FEE=F4@;6]R92!M96%N
M:6YG9G5L;"!E<G)O<B!M97-S86=E<PH@("`@("H@8F5C875S92!S<6QI=&5?
M;&%S=%]E<G)O<B@I(&1O97,@;F]T('!R;W9I9&4@861E<75A=&4@:6YF;RY]
M?0H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@1$)-4R<@97)R
M;W(@;65S<V%G90H@("`@("HO"B`@("!F=6YC=&EO;B!E<G)O<DYA=&EV92@I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;&%S=&5R<F]R.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&5R<F]R0V]D92@I"@H@("`@+RHJ
M"B`@("`@*B!$971E<FUI;F5S(%!%05(Z.D1"(&5R<F]R(&-O9&4@9G)O;2!T
M:&4@9&%T86)A<V4G<R!T97AT(&5R<F]R(&UE<W-A9V4*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1E<G)O<FUS9R`@=&AE(&5R<F]R(&UE<W-A9V4@
M<F5T=7)N960@9G)O;2!T:&4@9&%T86)A<V4*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&EN=&5G97(@('1H92!$0B!E<G)O<B!N=6UB97(*("`@("`J+PH@("`@
M9G5N8W1I;VX@97)R;W)#;V1E*"1E<G)O<FUS9RD*("`@('L*("`@("`@("!S
M=&%T:6,@)&5R<F]R7W)E9V5X<',["B`@("`@("`@:68@*"%I<W-E="@D97)R
M;W)?<F5G97AP<RDI('L*("`@("`@("`@("`@)&5R<F]R7W)E9V5X<',@/2!A
M<G)A>2@*("`@("`@("`@("`@("`@("<O7FYO('-U8V@@=&%B;&4Z+R<@/3X@
M1$)?15)23U)?3D]354-(5$%"3$4L"B`@("`@("`@("`@("`@("`G+UYN;R!S
M=6-H(&EN9&5X.B\G(#T^($1"7T524D]27TY/5%]&3U5.1"P*("`@("`@("`@
M("`@("`@("<O7BAT86)L97QI;F1E>"D@+BH@86QR96%D>2!E>&ES=',D+R<@
M/3X@1$)?15)23U)?04Q214%$65]%6$E35%,L"B`@("`@("`@("`@("`@("`G
M+U!224U!4ED@2T59(&UU<W0@8F4@=6YI<75E+VDG(#T^($1"7T524D]27T-/
M3E-44D%)3E0L"B`@("`@("`@("`@("`@("`G+VES(&YO="!U;FEQ=64O)R`]
M/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@("`@("`@("`@("`@)R]C;VQU
M;6YS("XJ(&%R92!N;W0@=6YI<75E+VDG(#T^($1"7T524D]27T-/3E-44D%)
M3E0L"B`@("`@("`@("`@("`@("`G+W5N:7%U96YE<W,@8V]N<W1R86EN="!F
M86EL960O)R`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@("`@("`@("`@
M("`@)R]M87D@;F]T(&)E($Y53$PO)R`]/B!$0E]%4E)/4E]#3TY35%)!24Y4
M7TY/5%].54Q,+`H@("`@("`@("`@("`@("`@)R]>;F\@<W5C:"!C;VQU;6XZ
M+R<@/3X@1$)?15)23U)?3D]354-(1DE%3$0L"B`@("`@("`@("`@("`@("`G
M+V-O;'5M;B!N;W0@<')E<V5N="!I;B!B;W1H('1A8FQE<R]I)R`]/B!$0E]%
M4E)/4E].3U-50TA&245,1"P*("`@("`@("`@("`@("`@("<O7FYE87(@(BXJ
M(CH@<WEN=&%X(&5R<F]R)"\G(#T^($1"7T524D]27U-93E1!6"P*("`@("`@
M("`@("`@("`@("<O6S`M.5TK('9A;'5E<R!F;W(@6S`M.5TK(&-O;'5M;G,O
M:2<@/3X@1$)?15)23U)?5D%,545?0T]53E1?3TY?4D]7+`H@("`@("`@("`@
M("`I.PH@("`@("`@('T*("`@("`@("!F;W)E86-H("@D97)R;W)?<F5G97AP
M<R!A<R`D<F5G97AP(#T^("1C;V1E*2!["B`@("`@("`@("`@(&EF("AP<F5G
M7VUA=&-H*"1R96=E>'`L("1E<G)O<FUS9RDI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D8V]D93L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("`O+R!&86QL(&)A8VL@=&\@1$)?15)23U(@:68@=&AE<F4@=V%S(&YO(&UA
M<'!I;F<N"B`@("`@("`@<F5T=7)N($1"7T524D]2.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[('1A8FQE26YF;R@I"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS(&EN9F]R;6%T:6]N(&%B;W5T(&$@=&%B;&4*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("`@("`@("`@)')E<W5L="`@82!S=')I;F<@8V]N
M=&%I;FEN9R!T:&4@;F%M92!O9B!A('1A8FQE"B`@("`@*B!`<&%R86T@:6YT
M("`@("`@("`@("`@)&UO9&4@("`@82!V86QI9"!T86)L94EN9F\@;6]D90H@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@(&%N(&%S<V]C:6%T:79E(&%R
M<F%Y('=I=&@@=&AE(&EN9F]R;6%T:6]N(')E<75E<W1E9"X*("`@("`J("`@
M("`@("`@("`@("`@("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@
M("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIT86)L94EN9F\H*0H@("`@
M("H@0'-I;F-E($UE=&AO9"!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C<N
M,`H@("`@("HO"B`@("!F=6YC=&EO;B!T86)L94EN9F\H)')E<W5L="P@)&UO
M9&4@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]S=')I;F<H)')E<W5L
M="DI('L*("`@("`@("`@("`@+RH*("`@("`@("`@("`@("H@4')O8F%B;'D@
M<F5C96EV960@82!T86)L92!N86UE+@H@("`@("`@("`@("`@*B!#<F5A=&4@
M82!R97-U;'0@<F5S;W5R8V4@:61E;G1I9FEE<BX*("`@("`@("`@("`@("HO
M"B`@("`@("`@("`@("1I9"`]($!S<6QI=&5?87)R87E?<75E<GDH)'1H:7,M
M/F-O;FYE8W1I;VXL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(E!204=-02!T86)L95]I;F9O*"<D<F5S=6QT)RD[(BP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!344Q)5$5?05-33T,I
M.PH@("`@("`@("`@("`D9V]T7W-T<FEN9R`]('1R=64["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'1H:7,M/FQA<W1?<75E<GD@/2`G)SL*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27TY/
M5%]#05!!0DQ%+"!N=6QL+"!N=6QL+"!N=6QL+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)U1H:7,@1$)-4R!C86X@;F]T(&]B=&%I
M;B!T86)L94EN9F\G("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("<@9G)O;2!R97-U;'0@<V5T<R<I.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]2
M5$%"24Q)5%E?3$]715)#05-%*2!["B`@("`@("`@("`@("1C87-E7V9U;F,@
M/2`G<W1R=&]L;W=E<B<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)&-A<V5?9G5N8R`]("=S=')V86PG.PH@("`@("`@('T*"B`@("`@("`@)&-O
M=6YT(#T@8V]U;G0H)&ED*3L*("`@("`@("`D<F5S("`@/2!A<G)A>2@I.PH*
M("`@("`@("!I9B`H)&UO9&4I('L*("`@("`@("`@("`@)')E<ULG;G5M7V9I
M96QD<R==(#T@)&-O=6YT.PH@("`@("`@('T*"B`@("`@("`@9F]R("@D:2`]
M(#`[("1I(#P@)&-O=6YT.R`D:2LK*2!["B`@("`@("`@("`@(&EF("AS=')P
M;W,H)&ED6R1I75LG='EP92==+"`G*"<I("$]/2!F86QS92D@>PH@("`@("`@
M("`@("`@("`@)&)I=',@/2!E>'!L;V1E*"<H)RP@)&ED6R1I75LG='EP92==
M*3L*("`@("`@("`@("`@("`@("1T>7!E(#T@)&)I='-;,%T["B`@("`@("`@
M("`@("`@("`D;&5N("`](')T<FEM*"1B:71S6S%=+"<I)RD["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D='EP92`]("1I9%LD:5U;
M)W1Y<&4G73L*("`@("`@("`@("`@("`@("1L96X@(#T@,#L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@)&9L86=S(#T@)R<["B`@("`@("`@("`@(&EF
M("@D:61;)&E=6R=P:R==*2!["B`@("`@("`@("`@("`@("`D9FQA9W,@+CT@
M)W!R:6UA<GE?:V5Y("<["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@
M*"1I9%LD:5U;)VYO=&YU;&PG72D@>PH@("`@("`@("`@("`@("`@)&9L86=S
M("X]("=N;W1?;G5L;"`G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("@D:61;)&E=6R=D9FQT7W9A;'5E)UT@(3T](&YU;&PI('L*("`@("`@("`@
M("`@("`@("1F;&%G<R`N/2`G9&5F875L=%\G("X@<F%W=7)L96YC;V1E*"1I
M9%LD:5U;)V1F;'1?=F%L=64G72D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)&9L86=S(#T@=')I;2@D9FQA9W,I.PH*("`@("`@("`@("`@)')E<ULD
M:5T@/2!A<G)A>2@*("`@("`@("`@("`@("`@("=T86)L92<@/3X@)&-A<V5?
M9G5N8R@D<F5S=6QT*2P*("`@("`@("`@("`@("`@("=N86UE)R`@/3X@)&-A
M<V5?9G5N8R@D:61;)&E=6R=N86UE)UTI+`H@("`@("`@("`@("`@("`@)W1Y
M<&4G("`]/B`D='EP92P*("`@("`@("`@("`@("`@("=L96XG("`@/3X@)&QE
M;BP*("`@("`@("`@("`@("`@("=F;&%G<R<@/3X@)&9L86=S+`H@("`@("`@
M("`@("`I.PH*("`@("`@("`@("`@:68@*"1M;V1E("8@1$)?5$%"3$5)3D9/
M7T]21$52*2!["B`@("`@("`@("`@("`@("`D<F5S6R=O<F1E<B==6R1R97-;
M)&E=6R=N86UE)UU=(#T@)&D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M:68@*"1M;V1E("8@1$)?5$%"3$5)3D9/7T]21$525$%"3$4I('L*("`@("`@
M("`@("`@("`@("1R97-;)V]R9&5R=&%B;&4G75LD<F5S6R1I75LG=&%B;&4G
M75U;)')E<ULD:5U;)VYA;64G75T@/2`D:3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1R97,["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@9V5T4W!E8VEA;%%U97)Y*"D*"B`@("`O*BH*("`@("`J
M($]B=&%I;G,@=&AE('%U97)Y('-T<FEN9R!N965D960@9F]R(&QI<W1I;F<@
M82!G:79E;B!T>7!E(&]F(&]B:F5C=',*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1T>7!E("!T:&4@:VEN9"!O9B!O8FIE8W1S('EO=2!W86YT('1O
M(')E=')I979E"B`@("`@*B!`<&%R86T@87)R87D@("1A<F=S("!344Q)5$4@
M1%))5D52($].3%DZ(&$@<')I=F%T92!A<G)A>2!O9B!A<F=U;65N=',*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("!U<V5D(&)Y('1H92!G9713<&5C
M:6%L475E<GDH*2X@($1O(&YO="!U<V4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!T:&ES(&1I<F5C=&QY+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!T:&4@4U%,('%U97)Y('-T<FEN9R!O<B!N=6QL(&EF('1H92!D
M<FEV97(@9&]E<VXG=`H@("`@("H@("`@("`@("`@("`@("`@("!S=7!P;W)T
M('1H92!O8FIE8W0@='EP92!R97%U97-T960*("`@("`J"B`@("`@*B!`86-C
M97-S('!R;W1E8W1E9`H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F=E=$QI<W1/
M9B@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-P96-I86Q1=65R>2@D='EP
M92P@)&%R9W,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("@A:7-?87)R
M87DH)&%R9W,I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@G;F\@:V5Y('-P96-I9FEE9"<L(&YU;&PL(&YU;&PL(&YU;&PL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G07)G=6UE;G0@
M:&%S('1O(&)E(&%N(&%R<F%Y+B<I.PH@("`@("`@('T*"B`@("`@("`@<W=I
M=&-H("@D='EP92D@>PH@("`@("`@("`@("!C87-E("=M87-T97(G.@H@("`@
M("`@("`@("`@("`@<F5T=7)N("=314Q%0U0@*B!&4D]-('-Q;&ET95]M87-T
M97([)SL*("`@("`@("`@("`@8V%S92`G=&%B;&5S)SH*("`@("`@("`@("`@
M("`@(')E='5R;B`B4T5,14-4(&YA;64@1E)/32!S<6QI=&5?;6%S=&5R(%=(
M15)%('1Y<&4])W1A8FQE)R`B"B`@("`@("`@("`@("`@("`@("`@("`@+B`G
M54Y)3TX@04Q,(%-%3$5#5"!N86UE($923TT@<W%L:71E7W1E;7!?;6%S=&5R
M("<*("`@("`@("`@("`@("`@("`@("`@("`N(")72$5212!T>7!E/2=T86)L
M92<@3U)$15(@0ED@;F%M93LB.PH@("`@("`@("`@("!C87-E("=S8VAE;6$G
M.@H@("`@("`@("`@("`@("`@<F5T=7)N("=314Q%0U0@<W%L($923TT@*%-%
M3$5#5"`J($923TT@<W%L:71E7VUA<W1E<B`G"B`@("`@("`@("`@("`@("`@
M("`@("`@+B`G54Y)3TX@04Q,(%-%3$5#5"`J($923TT@<W%L:71E7W1E;7!?
M;6%S=&5R*2`G"B`@("`@("`@("`@("`@("`@("`@("`@+B`B5TA%4D4@='EP
M92$])VUE=&$G("(*("`@("`@("`@("`@("`@("`@("`@("`N("=/4D1%4B!"
M62!T8FQ?;F%M92P@='EP92!$15-#+"!N86UE.R<["B`@("`@("`@("`@(&-A
M<V4@)W-C:&5M87@G.@H@("`@("`@("`@("!C87-E("=S8VAE;6%?>"<Z"B`@
M("`@("`@("`@("`@("`O*@H@("`@("`@("`@("`@("`@("H@57-E(&QI:V4Z
M"B`@("`@("`@("`@("`@("`@*B`D<F5S(#T@)&1B+3YQ=65R>2@D9&(M/F=E
M=%-P96-I86Q1=65R>2@G<V-H96UA7W@G+`H@("`@("`@("`@("`@("`@("H@
M("`@("`@("`@("`@("`@("`@87)R87DH)W1A8FQE)R`]/B`G=&%B;&4S)RDI
M*3L*("`@("`@("`@("`@("`@("`J+PH@("`@("`@("`@("`@("`@<F5T=7)N
M("=314Q%0U0@<W%L($923TT@*%-%3$5#5"`J($923TT@<W%L:71E7VUA<W1E
M<B`G"B`@("`@("`@("`@("`@("`@("`@("`@+B`G54Y)3TX@04Q,(%-%3$5#
M5"`J($923TT@<W%L:71E7W1E;7!?;6%S=&5R*2`G"B`@("`@("`@("`@("`@
M("`@("`@("`@+B`B5TA%4D4@=&)L7VYA;64@3$E+12`G>R1A<F=S6R=T86)L
M92==?2<@(@H@("`@("`@("`@("`@("`@("`@("`@("X@(D%.1"!T>7!E(3TG
M;65T82<@(@H@("`@("`@("`@("`@("`@("`@("`@("X@)T]21$52($)9('1Y
M<&4@1$530RP@;F%M93LG.PH@("`@("`@("`@("!C87-E("=A;'1E<B<Z"B`@
M("`@("`@("`@("`@("`O*@H@("`@("`@("`@("`@("`@("H@4U%,:71E(&1O
M97,@;F]T('-U<'!O<G0@04Q415(@5$%"3$4[('1H:7,@:7,@82!H96QP97(@
M<75E<GD*("`@("`@("`@("`@("`@("`J('1O(&AA;F1L92!T:&ES+B`G=&%B
M;&4G(')E<')E<V5N=',@=&AE('1A8FQE(&YA;64L("=R;W=S)PH@("`@("`@
M("`@("`@("`@("H@=&AE(&YE=W,@<F]W<R!T;R!C<F5A=&4L("=S879E)R!T
M:&4@<F]W*',I('1O(&ME97`@7W=I=&A?"B`@("`@("`@("`@("`@("`@*B!T
M:&4@9&%T82X*("`@("`@("`@("`@("`@("`J"B`@("`@("`@("`@("`@("`@
M*B!5<V4@;&EK93H*("`@("`@("`@("`@("`@("`J("1A<F=S(#T@87)R87DH
M"B`@("`@("`@("`@("`@("`@*B`@("`@)W1A8FQE)R`]/B`D=&%B;&4L"B`@
M("`@("`@("`@("`@("`@*B`@("`@)W)O=W,G("`]/B`B:60@24Y414=%4B!0
M4DE-05)9($M%62P@9FER<W1N86UE(%1%6%0L('-U<FYA;64@5$585"P@9&%T
M971I;64@5$585"(L"B`@("`@("`@("`@("`@("`@*B`@("`@)W-A=F4G("`]
M/B`B3E5,3"P@=&ET96PL(&-O;G1E;G0L(&1A=&5T:6UE(@H@("`@("`@("`@
M("`@("`@("H@*3L*("`@("`@("`@("`@("`@("`J("1R97,@/2`D9&(M/G%U
M97)Y*"`D9&(M/F=E=%-P96-I86Q1=65R>2@G86QT97(G+"`D87)G<RDI.PH@
M("`@("`@("`@("`@("`@("HO"B`@("`@("`@("`@("`@("`D<F]W<R`]('-T
M<G1R*"1A<F=S6R=R;W=S)UTL("1T:&ES+3YK97EW;W)D<RD["@H@("`@("`@
M("`@("`@("`@)'$@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G0D5'
M24X@5%)!3E-!0U1)3TXG+`H@("`@("`@("`@("`@("`@("`@(")#4D5!5$4@
M5$5-4$]205)9(%1!0DQ%('LD87)G<ULG=&%B;&4G77U?8F%C:W5P("A[)&%R
M9W-;)W)O=W,G77TI(BP*("`@("`@("`@("`@("`@("`@("`B24Y315)4($E.
M5$\@>R1A<F=S6R=T86)L92==?5]B86-K=7`@4T5,14-4('LD87)G<ULG<V%V
M92==?2!&4D]-('LD87)G<ULG=&%B;&4G77TB+`H@("`@("`@("`@("`@("`@
M("`@(")$4D]0(%1!0DQ%('LD87)G<ULG=&%B;&4G77TB+`H@("`@("`@("`@
M("`@("`@("`@(")#4D5!5$4@5$%"3$4@>R1A<F=S6R=T86)L92==?2`H>R1A
M<F=S6R=R;W=S)UU]*2(L"B`@("`@("`@("`@("`@("`@("`@(DE.4T525"!)
M3E1/('LD87)G<ULG=&%B;&4G77T@4T5,14-4('LD<F]W<WT@1E)/32![)&%R
M9W-;)W1A8FQE)UU]7V)A8VMU<"(L"B`@("`@("`@("`@("`@("`@("`@(D12
M3U`@5$%"3$4@>R1A<F=S6R=T86)L92==?5]B86-K=7`B+`H@("`@("`@("`@
M("`@("`@("`@("=#3TU-250G+`H@("`@("`@("`@("`@("`@*3L*"B`@("`@
M("`@("`@("`@("`O*@H@("`@("`@("`@("`@("`@("H@5&AI<R!I<R!A(&1I
M<G1Y(&AA8VLL('-I;F-E('1H92!A8F]V92!Q=65R>2!W:6QL(&YO="!G970*
M("`@("`@("`@("`@("`@("`J(&5X96-U=&5D('=I=&@@82!S:6YG;&4@<75E
M<GD@8V%L;"!S;R!H97)E('1H92!Q=65R>2!M971H;V0*("`@("`@("`@("`@
M("`@("`J('=I;&P@8F4@8V%L;&5D(&1I<F5C=&QY(&%N9"!R971U<FX@82!S
M96QE8W0@:6YS=&5A9"X*("`@("`@("`@("`@("`@("`J+PH@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)'$@87,@)'%U97)Y*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G%U97)Y*"1Q=65R>2D["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!R971U<FX@(E-%3$5#5"`J($923TT@>R1A<F=S
M6R=T86)L92==?3LB.PH@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@
M("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H@("`@?0H*("`@("\O('U]
M?0I]"@HO*@H@*B!,;V-A;"!V87)I86)L97,Z"B`J('1A8BUW:61T:#H@-`H@
M*B!C+6)A<VEC+6]F9G-E=#H@-`H@*B!%;F0Z"B`J+PH*/SX*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]$0B]D8F%S92YP:'``````````
M````````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#,V-C`Q(#$P
M-3$U-#,S-S,Q(#`R,#4T-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`H*+RH@=FEM.B!S970@97AP86YD=&%B('1A
M8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*"B\J*@H@
M*B!4:&4@4$5!4B!$0B!D<FEV97(@9F]R(%!(4"=S(&1B87-E(&5X=&5N<VEO
M;@H@*B!F;W(@:6YT97)A8W1I;F<@=VET:"!D0F%S92!D871A8F%S97,*("H*
M("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S
M;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!0
M2%`@;&EC96YS90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E
M('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*
M("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M
M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@
M($1A=&%B87-E"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@(%1O
M;6%S(%8N5BX@0V]X(#QC;WA`:61E8VYE="YC;VT^"B`J($!A=71H;W(@("`@
M($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER
M:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N
M<V4@,RXP"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!D8F%S92YP:'`L=B`Q
M+C,Y(#(P,#4O,#(O,3D@,C,Z,C4Z,C4@9&%N:65L8R!%>'`@)`H@*B!`;&EN
M:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO"@HO
M*BH*("H@3V)T86EN('1H92!$0E]C;VUM;VX@8VQA<W,@<V\@:70@8V%N(&)E
M(&5X=&5N9&5D(&9R;VT*("HO"G)E<75I<F5?;VYC92`G1$(O8V]M;6]N+G!H
M<"<["@HO*BH*("H@5&AE(&UE=&AO9',@4$5!4B!$0B!U<V5S('1O(&EN=&5R
M86-T('=I=&@@4$A0)W,@9&)A<V4@97AT96YS:6]N"B`J(&9O<B!I;G1E<F%C
M=&EN9R!W:71H(&1"87-E(&1A=&%B87-E<PH@*@H@*B!4:&5S92!M971H;V1S
M(&]V97)L;V%D('1H92!O;F5S(&1E8VQA<F5D(&EN($1"7V-O;6UO;BX*("H*
M("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@
M0&%U=&AO<B`@("`@5&]M87,@5BY6+B!#;W@@/&-O>$!I9&5C;F5T+F-O;3X*
M("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N
M;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@
M*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N
M='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@4F5L96%S93H@
M,2XW+C8*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K
M86=E+T1""B`J+PIC;&%S<R!$0E]D8F%S92!E>'1E;F1S($1"7V-O;6UO;@I[
M"B`@("`O+R![>WL@<')O<&5R=&EE<PH*("`@("\J*@H@("`@("H@5&AE($1"
M(&1R:79E<B!T>7!E("AM>7-Q;"P@;V-I."P@;V1B8RP@971C+BD*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D<&AP='EP92`]("=D8F%S
M92<["@H@("`@+RHJ"B`@("`@*B!4:&4@9&%T86)A<V4@<WEN=&%X('9A<FEA
M;G0@=&\@8F4@=7-E9"`H9&(R+"!A8V-E<W,L(&5T8RXI+"!I9B!A;GD*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D9&)S>6YT87@@/2`G
M9&)A<V4G.PH*("`@("\J*@H@("`@("H@5&AE(&-A<&%B:6QI=&EE<R!O9B!T
M:&ES($1"(&EM<&QE;65N=&%T:6]N"B`@("`@*@H@("`@("H@5&AE("=N97=?
M;&EN:R<@96QE;65N="!C;VYT86EN<R!T:&4@4$A0('9E<G-I;VX@=&AA="!F
M:7)S="!P<F]V:61E9`H@("`@("H@;F5W7VQI;FL@<W5P<&]R="!F;W(@=&AI
M<R!$0DU3+B`@0V]N=&%I;G,@9F%L<V4@:68@:70G<R!U;G-U<'!O<G1E9"X*
M("`@("`J"B`@("`@*B!-96%N:6YG(&]F('1H92`G;&EM:70G(&5L96UE;G0Z
M"B`@("`@*B`@("L@)V5M=6QA=&4G(#T@96UU;&%T92!W:71H(&9E=&-H(')O
M=R!B>2!N=6UB97(*("`@("`J("`@*R`G86QT97(G("`@/2!A;'1E<B!T:&4@
M<75E<GD*("`@("`J("`@*R!F86QS92`@("`@/2!S:VEP(')O=W,*("`@("`J
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D9F5A='5R97,@
M/2!A<G)A>2@*("`@("`@("`G;&EM:70G("`@("`@("`@/3X@9F%L<V4L"B`@
M("`@("`@)VYE=U]L:6YK)R`@("`@(#T^(&9A;'-E+`H@("`@("`@("=N=6UR
M;W=S)R`@("`@("`]/B!T<G5E+`H@("`@("`@("=P8V]N;F5C="<@("`@("`]
M/B!F86QS92P*("`@("`@("`G<')E<&%R92<@("`@("`@/3X@9F%L<V4L"B`@
M("`@("`@)W-S;"<@("`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("=T<F%N
M<V%C=&EO;G,G("`]/B!F86QS92P*("`@("D["@H@("`@+RHJ"B`@("`@*B!!
M(&UA<'!I;F<@;V8@;F%T:79E(&5R<F]R(&-O9&5S('1O($1"(&5R<F]R(&-O
M9&5S"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D97)R;W)C
M;V1E7VUA<"`](&%R<F%Y*`H@("`@*3L*"B`@("`O*BH*("`@("`J(%1H92!R
M87<@9&%T86)A<V4@8V]N;F5C=&EO;B!C<F5A=&5D(&)Y(%!(4`H@("`@("H@
M0'9A<B!R97-O=7)C90H@("`@("HO"B`@("!V87(@)&-O;FYE8W1I;VX["@H@
M("`@+RHJ"B`@("`@*B!4:&4@1%-.(&EN9F]R;6%T:6]N(&9O<B!C;VYN96-T
M:6YG('1O(&$@9&%T86)A<V4*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1D<VX@/2!A<G)A>2@I.PH*"B`@("`O*BH*("`@("`J($$@;65A
M;G,@;V8@96UU;&%T:6YG(')E<W5L="!R97-O=7)C97,*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1R97-?<F]W(#T@87)R87DH*3L*"B`@
M("`O*BH*("`@("`J(%1H92!Q=6%N=&ET>2!O9B!R97-U;'1S('-O(&9A<@H@
M("`@("H*("`@("`J($9O<B!E;75L871I;F<@<F5S=6QT(')E<V]U<F-E<RX*
M("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1R
M97-U;'0@/2`P.PH*("`@("\J*@H@("`@("H@36%P<R!D8F%S92!D871A('1Y
M<&4@:60G<R!T;R!H=6UA;B!R96%D86)L92!S=')I;F=S"B`@("`@*@H@("`@
M("H@5&AE(&AU;6%N(')E861A8FQE('9A;'5E<R!A<F4@8F%S960@;VX@=&AE
M(&]U='!U="!O9B!02%`G<PH@("`@("H@9&)A<V5?9V5T7VAE861E<E]I;F9O
M*"D@9G5N8W1I;VXN"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("H@
M0'-I;F-E(%!R;W!E<G1Y(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-RXP
M"B`@("`@*B\*("`@('9A<B`D='EP97,@/2!A<G)A>2@*("`@("`@("`G0R<@
M/3X@)V-H87)A8W1E<B<L"B`@("`@("`@)T0G(#T^("=D871E)RP*("`@("`@
M("`G3"<@/3X@)V)O;VQE86XG+`H@("`@("`@("=-)R`]/B`G;65M;R<L"B`@
M("`@("`@)TXG(#T^("=N=6UB97(G+`H@("`@*3L*"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@8V]N<W1R=6-T;W(*"B`@("`O*BH*("`@("`J(%1H:7,@8V]N
M<W1R=6-T;W(@8V%L;',@/&MB9#XD=&AI<RT^1$)?8V]M;6]N*"D\+VMB9#X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I
M;VX@1$)?9&)A<V4H*0H@("`@>PH@("`@("`@("1T:&ES+3Y$0E]C;VUM;VXH
M*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VYN96-T*"D*"B`@
M("`O*BH*("`@("`J($-O;FYE8W0@=&\@=&AE(&1A=&%B87-E(&%N9"!C<F5A
M=&4@:70@:68@:70@9&]E<VXG="!E>&ES=`H@("`@("H*("`@("`J($1O;B=T
M(&-A;&P@=&AI<R!M971H;V0@9&ER96-T;'DN("!5<V4@1$(Z.F-O;FYE8W0H
M*2!I;G-T96%D+@H@("`@("H*("`@("`J(%!%05(@1$(G<R!D8F%S92!D<FEV
M97(@<W5P<&]R=',@=&AE(&9O;&QO=VEN9R!E>'1R82!$4TX@;W!T:6]N<SH*
M("`@("`J("`@*R!M;V1E("`@($%N(&EN=&5G97(@<W!E8VEF>6EN9R!T:&4@
M<F5A9"]W<FET92!M;V1E('1O('5S90H@("`@("H@("`@("`@("`@("`@("@P
M(#T@<F5A9"!O;FQY+"`Q(#T@=W)I=&4@;VYL>2P@,B`](')E860O=W)I=&4I
M+@H@("`@("H@("`@("`@("`@("`@($%V86EL86)L92!S:6YC92!014%2($1"
M(#$N-RXP+@H@("`@("H@("`K(&9I96QD<R`@06X@87)R87D@;V8@87)R87ES
M('1H870@4$A0)W,@9&)A<V5?8W)E871E*"D@9G5N8W1I;VX@;F5E9',*("`@
M("`J("`@("`@("`@("`@("!T;R!C<F5A=&4@82!N97<@9&%T86)A<V4N("!4
M:&ES(&EN9F]R;6%T:6]N(&ES('5S960@:68@=&AE"B`@("`@*B`@("`@("`@
M("`@("`@9$)A<V4@9FEL92!S<&5C:69I960@:6X@=&AE(")D871A8F%S92(@
M<V5G;65N="!O9B!T:&4@1%-."B`@("`@*B`@("`@("`@("`@("`@9&]E<R!N
M;W0@97AI<W0N("!&;W(@;6]R92!I;F9O+"!S964@=&AE(%!(4"!M86YU86PG
M<PH@("`@("H@("`@("`@("`@("`@('M`;&EN:R!H='1P.B\O<&AP+FYE="]D
M8F%S95]C<F5A=&4@9&)A<V5?8W)E871E*"E]('!A9V4N"B`@("`@*B`@("`@
M("`@("`@("`@079A:6QA8FQE('-I;F-E(%!%05(@1$(@,2XW+C`N"B`@("`@
M*@H@("`@("H@17AA;7!L92!O9B!H;W<@=&\@8V]N;F5C="!A;F0@97-T86)L
M:7-H(&$@;F5W(&1"87-E(&9I;&4@:68@;F5C97-S87)Y.@H@("`@("H@/&-O
M9&4^"B`@("`@*B!R97%U:7)E7V]N8V4@)T1"+G!H<"<["B`@("`@*@H@("`@
M("H@)&1S;B`](&%R<F%Y*`H@("`@("H@("`@("=P:'!T>7!E)R`@/3X@)V1B
M87-E)RP*("`@("`J("`@("`G9&%T86)A<V4G(#T^("<O<&%T:"]A;F0O;F%M
M92]O9B]D8F%S92]F:6QE)RP*("`@("`J("`@("`G;6]D92<@("`@(#T^(#(L
M"B`@("`@*B`@("`@)V9I96QD<R<@("`]/B!A<G)A>2@*("`@("`J("`@("`@
M("`@87)R87DH)V$G+"`G3B<L(#4L(#`I+`H@("`@("H@("`@("`@("!A<G)A
M>2@G8B<L("=#)RP@-#`I+`H@("`@("H@("`@("`@("!A<G)A>2@G8R<L("=#
M)RP@,C4U*2P*("`@("`J("`@("`@("`@87)R87DH)V0G+"`G0R<L(#(P*2P*
M("`@("`J("`@("`I+`H@("`@("H@*3L*("`@("`J("1O<'1I;VYS(#T@87)R
M87DH"B`@("`@*B`@("`@)V1E8G5G)R`@("`@("`]/B`R+`H@("`@("H@("`@
M("=P;W)T86)I;&ET>2<@/3X@1$)?4$]25$%"24Q)5%E?04Q,+`H@("`@("H@
M*3L*("`@("`J"B`@("`@*B`D9&(@/28@1$(Z.F-O;FYE8W0H)&1S;BP@)&]P
M=&EO;G,I.PH@("`@("H@:68@*%!%05(Z.FES17)R;W(H)&1B*2D@>PH@("`@
M("H@("`@(&1I92@D9&(M/F=E=$UE<W-A9V4H*2D["B`@("`@*B!]"B`@("`@
M*B`\+V-O9&4^"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1D<VX@("`@
M("`@("!T:&4@9&%T82!S;W5R8V4@;F%M90H@("`@("H@0'!A<F%M(&)O;VP@
M("1P97)S:7-T96YT("!S:&]U;&0@=&AE(&-O;FYE8W1I;VX@8F4@<&5R<VES
M=&5N=#\*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C
M8V5S<RX@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@8V]N;F5C="@D9'-N+"`D<&5R<VES=&5N="`](&9A;'-E
M*0H@("`@>PH@("`@("`@(&EF("@A4$5!4CHZ;&]A9$5X=&5N<VEO;B@G9&)A
M<V4G*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M1$)?15)23U)?15A414Y324].7TY/5%]&3U5.1"D["B`@("`@("`@?0H*("`@
M("`@("`D=&AI<RT^9'-N(#T@)&1S;CL*("`@("`@("!I9B`H)&1S;ELG9&)S
M>6YT87@G72D@>PH@("`@("`@("`@("`D=&AI<RT^9&)S>6YT87@@/2`D9'-N
M6R=D8G-Y;G1A>"==.PH@("`@("`@('T*"B`@("`@("`@+RH*("`@("`@("`@
M*B!4=7)N('1R86-K7V5R<F]R<R!O;B!F;W(@96YT:7)E('-C<FEP="!S:6YC
M92`D<&AP7V5R<F]R;7-G"B`@("`@("`@("H@:7,@=&AE(&]N;'D@=V%Y('1O
M(&9I;F0@97)R;W)S(&9R;VT@=&AE(&1B87-E(&5X=&5N<VEO;BX*("`@("`@
M("`@*B\*("`@("`@("!I;FE?<V5T*"=T<F%C:U]E<G)O<G,G+"`Q*3L*("`@
M("`@("`D<&AP7V5R<F]R;7-G(#T@)R<["@H@("`@("`@(&EF("@A9FEL95]E
M>&ES=',H)&1S;ELG9&%T86)A<V4G72DI('L*("`@("`@("`@("`@)'1H:7,M
M/F1S;ELG;6]D92==(#T@,CL*("`@("`@("`@("`@:68@*&5M<'1Y*"1D<VY;
M)V9I96QD<R==*2!\?"`A:7-?87)R87DH)&1S;ELG9FEE;&1S)UTI*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)2
M3U)?0T].3D5#5%]&04E,140L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@;G5L;"P@;G5L;"P@;G5L;"P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=&AE(&1B87-E(&9I;&4@
M9&]E<R!N;W0@97AI<W0@86YD("<*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`N("=I="!C;W5L9"!N;W0@8F4@8W)E871E9"!B
M96-A=7-E("<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`N("=T:&4@(F9I96QD<R(@96QE;65N="!O9B!T:&4@1%-.("<*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("=I<R!N
M;W0@<')O<&5R;'D@<V5T)RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)'1H:7,M/F-O;FYE8W1I;VX@/2!`9&)A<V5?8W)E871E*"1D<VY;)V1A=&%B
M87-E)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9'-N6R=F:65L9',G72D["B`@("`@("`@("`@(&EF("@A)'1H
M:7,M/F-O;FYE8W1I;VXI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E]#3TY.14-47T9!24Q%1"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N=6QL+"!N=6QL
M+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=T:&4@9&)A<V4@9FEL92!D;V5S(&YO="!E>&ES="!A;F0@)PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)W1H92!A
M='1E;7!T('1O(&-R96%T92!I="!F86EL960Z("<*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`N("1P:'!?97)R;W)M<V<I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^9'-N6R=M;V1E)UTI*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^9'-N6R=M;V1E)UT@/2`P.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1T:&ES+3YC;VYN96-T:6]N(#T@0&1B87-E7V]P96XH)&1S;ELG
M9&%T86)A<V4G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^9'-N6R=M;V1E)UTI.PH@("`@("`@("`@("!I
M9B`H(21T:&ES+3YC;VYN96-T:6]N*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?0T].3D5#5%]&04E,140L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;G5L
M;"P@;G5L;"P@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<&AP7V5R<F]R;7-G*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@9&ES8V]N;F5C="@I"@H@("`@+RHJ"B`@("`@*B!$:7-C
M;VYN96-T<R!F<F]M('1H92!D871A8F%S92!S97)V97(*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VP@(%12544@;VX@<W5C8V5S<RP@1D%,4T4@;VX@9F%I
M;'5R90H@("`@("HO"B`@("!F=6YC=&EO;B!D:7-C;VYN96-T*"D*("`@('L*
M("`@("`@("`D<F5T(#T@0&1B87-E7V-L;W-E*"1T:&ES+3YC;VYN96-T:6]N
M*3L*("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`](&YU;&P["B`@("`@("`@
M<F5T=7)N("1R970["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@)G%U
M97)Y*"D*"B`@("!F=6YC=&EO;B`F<75E<GDH)'%U97)Y(#T@;G5L;"D*("`@
M('L*("`@("`@("`O+R!E;75L871E(')E<W5L="!R97-O=7)C97,*("`@("`@
M("`D=&AI<RT^<F5S7W)O=ULH:6YT*21T:&ES+3YR97-U;'1=(#T@,#L*("`@
M("`@("`D=&UP(#TF(&YE=R!$0E]R97-U;'0H)'1H:7,L("1T:&ES+3YR97-U
M;'0K*RD["B`@("`@("`@<F5T=7)N("1T;7`["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@9F5T8VA);G1O*"D*"B`@("`O*BH*("`@("`J(%!L86-E
M<R!A(')O=R!F<F]M('1H92!R97-U;'0@<V5T(&EN=&\@=&AE(&=I=F5N(&%R
M<F%Y"B`@("`@*@H@("`@("H@1F]R;6%T:6YG(&]F('1H92!A<G)A>2!A;F0@
M=&AE(&1A=&$@=&AE<F5I;B!A<F4@8V]N9FEG=7)A8FQE+@H@("`@("H@4V5E
M($1"7W)E<W5L=#HZ9F5T8VA);G1O*"D@9F]R(&UO<F4@:6YF;W)M871I;VXN
M"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E
M(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@("H@1$)?<F5S=6QT.CIF971C
M:$EN=&\H*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E
M8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@
M;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT
M("`@('1H92!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J($!P87)A;2!A
M<G)A>2`@("`D87)R("`@("`@('1H92!R969E<F5N8V5D(&%R<F%Y('1O('!U
M="!T:&4@9&%T82!I;@H@("`@("H@0'!A<F%M(&EN="`@("`@("1F971C:&UO
M9&4@:&]W('1H92!R97-U;'1I;F<@87)R87D@<VAO=6QD(&)E(&EN9&5X960*
M("`@("`J($!P87)A;2!I;G0@("`@("`D<F]W;G5M("`@('1H92!R;W<@;G5M
M8F5R('1O(&9E=&-H("@P(#T@9FER<W0@<F]W*0H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@($1"7T]+(&]N('-U8V-E<W,L($Y53$P@=VAE;B!T:&4@
M96YD(&]F(&$@<F5S=6QT('-E="!I<PH@("`@("H@("`@("`@("`@("`@("`@
M(')E86-H960@;W(@;VX@9F%I;'5R90H@("`@("H*("`@("`J($!S964@1$)?
M<F5S=6QT.CIF971C:$EN=&\H*0H@("`@("HO"B`@("!F=6YC=&EO;B!F971C
M:$EN=&\H)')E<W5L="P@)B1A<G(L("1F971C:&UO9&4L("1R;W=N=6T@/2!N
M=6QL*0H@("`@>PH@("`@("`@(&EF("@D<F]W;G5M(#T]/2!N=6QL*2!["B`@
M("`@("`@("`@("1R;W=N=6T@/2`D=&AI<RT^<F5S7W)O=ULH:6YT*21R97-U
M;'1=*RL["B`@("`@("`@?0H@("`@("`@(&EF("@D9F5T8VAM;V1E("8@1$)?
M1D540TA-3T1%7T%34T]#*2!["B`@("`@("`@("`@("1A<G(@/2!`9&)A<V5?
M9V5T7W)E8V]R9%]W:71H7VYA;65S*"1T:&ES+3YC;VYN96-T:6]N+"`D<F]W
M;G5M*3L*("`@("`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I
M;&ET>2==("8@1$)?4$]25$%"24Q)5%E?3$]715)#05-%("8F("1A<G(I('L*
M("`@("`@("`@("`@("`@("1A<G(@/2!A<G)A>5]C:&%N9V5?:V5Y7V-A<V4H
M)&%R<BP@0T%315],3U=%4BD["B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D87)R(#T@0&1B87-E7V=E=%]R96-O<F0H)'1H
M:7,M/F-O;FYE8W1I;VXL("1R;W=N=6TI.PH@("`@("`@('T*("`@("`@("!I
M9B`H(21A<G(I('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@
M?0H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F
M($1"7U!/4E1!0DE,25197U)44DE-*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M<G1R:6U!<G)A>59A;'5E<R@D87)R*3L*("`@("`@("!]"B`@("`@("`@:68@
M*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)
M5%E?3E5,3%]43U]%35!462D@>PH@("`@("`@("`@("`D=&AI<RT^7V-O;G9E
M<G1.=6QL07)R87E686QU97-4;T5M<'1Y*"1A<G(I.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@;G5M0V]L<R@I"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!N=6UB97(@
M;V8@8V]L=6UN<R!I;B!A(')E<W5L="!S970*("`@("`J"B`@("`@*B!4:&ES
M(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@
M57-E"B`@("`@*B!$0E]R97-U;'0Z.FYU;4-O;',H*2!I;G-T96%D+B`@270@
M8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*("`@("`J(&)E8V%U<V4@
M1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@("`@("H*("`@("`J
M($!P87)A;2!R97-O=7)C92`D<F5S=6QT("!02%`G<R!Q=65R>2!R97-U;'0@
M<F5S;W5R8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E
M<B!O9B!C;VQU;6YS+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*
M("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ;G5M0V]L<R@I"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&YU;4-O;',H)&9O;RD*("`@('L*("`@("`@("!R
M971U<FX@0&1B87-E7VYU;69I96QD<R@D=&AI<RT^8V]N;F5C=&EO;BD["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;G5M4F]W<R@I"@H@("`@+RHJ
M"B`@("`@*B!'971S('1H92!N=6UB97(@;V8@<F]W<R!I;B!A(')E<W5L="!S
M970*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@
M8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z.FYU
M;5)O=W,H*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E
M8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@
M;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT
M("!02%`G<R!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!R;W=S+B`@02!$0E]%<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L
M=#HZ;G5M4F]W<R@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&YU;5)O=W,H)&9O
M;RD*("`@('L*("`@("`@("!R971U<FX@0&1B87-E7VYU;7)E8V]R9',H)'1H
M:7,M/F-O;FYE8W1I;VXI.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M('%U;W1E4VUA<G0H*0H*("`@("\J*@H@("`@("H@1F]R;6%T<R!I;G!U="!S
M;R!I="!C86X@8F4@<V%F96QY('5S960@:6X@82!Q=65R>0H@("`@("H*("`@
M("`J($!P87)A;2!M:7AE9"`D:6X@('1H92!D871A('1O(&)E(&9O<FUA='1E
M9`H@("`@("H*("`@("`J($!R971U<FX@;6EX960@('1H92!F;W)M871T960@
M9&%T82X@(%1H92!F;W)M870@9&5P96YD<R!O;B!T:&4@:6YP=70G<PH@("`@
M("H@("`@("`@("`@("`@("`@(%!(4"!T>7!E.@H@("`@("H@("`@("`@("`@
M("`@("`@("L@;G5L;"`]('1H92!S=')I;F<@/'-A;7`^3E5,3#PO<V%M<#X*
M("`@("`J("`@("`@("`@("`@("`@("`K(&)O;VQE86X@/2`\<V%M<#Y4/"]S
M86UP/B!I9B!T<G5E(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`\<V%M
M<#Y&/"]S86UP/B!I9B!F86QS92X@(%5S92!T:&4@/&MB9#Y,;V=I8V%L/"]K
M8F0^"B`@("`@*B`@("`@("`@("`@("`@("`@("!D871A('1Y<&4N"B`@("`@
M*B`@("`@("`@("`@("`@("`@*R!I;G1E9V5R(&]R(&1O=6)L92`]('1H92!U
M;G%U;W1E9"!N=6UB97(*("`@("`J("`@("`@("`@("`@("`@("`K(&]T:&5R
M("AI;F-L=61I;F<@<W1R:6YG<R!A;F0@;G5M97)I8R!S=')I;F=S*2`]"B`@
M("`@*B`@("`@("`@("`@("`@("`@("!T:&4@9&%T82!W:71H('-I;F=L92!Q
M=6]T97,@97-C87!E9"!B>2!P<F5C965D:6YG"B`@("`@*B`@("`@("`@("`@
M("`@("`@("!S:6YG;&4@<75O=&5S('1H96X@=&AE('=H;VQE('-T<FEN9R!I
M<R!E;F-A<'-U;&%T960*("`@("`J("`@("`@("`@("`@("`@("`@(&)E='=E
M96X@<VEN9VQE('%U;W1E<PH@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N
M.CIQ=6]T95-M87)T*"D*("`@("`J($!S:6YC92!-971H;V0@879A:6QA8FQE
M('-I;F-E(%)E;&5A<V4@,2XV+C`*("`@("`J+PH@("`@9G5N8W1I;VX@<75O
M=&53;6%R="@D:6XI"B`@("!["B`@("`@("`@:68@*&ES7VEN="@D:6XI('Q\
M(&ES7V1O=6)L92@D:6XI*2!["B`@("`@("`@("`@(')E='5R;B`D:6X["B`@
M("`@("`@?2!E;'-E:68@*&ES7V)O;VPH)&EN*2D@>PH@("`@("`@("`@("!R
M971U<FX@)&EN(#\@)U0G(#H@)T8G.PH@("`@("`@('T@96QS96EF("AI<U]N
M=6QL*"1I;BDI('L*("`@("`@("`@("`@<F5T=7)N("=.54Q,)SL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@(B<B("X@)'1H:7,M/F5S
M8V%P95-I;7!L92@D:6XI("X@(B<B.PH@("`@("`@('T*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!T86)L94EN9F\H*0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!I;F9O<FUA=&EO;B!A8F]U="!T:&4@8W5R<F5N="!D871A8F%S
M90H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D<F5S=6QT("!42$E3($E3
M(%5.55-%1"!)3B!$0D%312X@(%1H92!C=7)R96YT(&1A=&%B87-E"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@:7,@97AA;6EN960@<F5G87)D;&5S
M<R!O9B!W:&%T(&ES('!R;W9I9&5D(&AE<F4N"B`@("`@*B!`<&%R86T@:6YT
M("`@)&UO9&4@("`@82!V86QI9"!T86)L94EN9F\@;6]D90H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@(&%N(&%S<V]C:6%T:79E(&%R<F%Y('=I=&@@
M=&AE(&EN9F]R;6%T:6]N(')E<75E<W1E9"X*("`@("`J("`@("`@("`@("`@
M("`@("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@
M("`J($!S964@1$)?8V]M;6]N.CIT86)L94EN9F\H*0H@("`@("H@0'-I;F-E
M($UE=&AO9"!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C<N,`H@("`@("HO
M"B`@("!F=6YC=&EO;B!T86)L94EN9F\H)')E<W5L="`](&YU;&PL("1M;V1E
M(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=D
M8F%S95]G971?:&5A9&5R7VEN9F\G*2D@>PH@("`@("`@("`@("`D:60@/2!`
M9&)A<V5?9V5T7VAE861E<E]I;F9O*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@
M("`@("`@("`@:68@*"$D:60@)B8@)'!H<%]E<G)O<FUS9RD@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]2+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YU;&PL
M(&YU;&PL(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!H<%]E<G)O<FUS9RD["B`@("`@("`@("`@('T*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`O*@H@("`@("`@("`@("`@*B!4:&ES
M('-E9VUE;G0@9F]R(%!(4"`T(&ES(&QO;W-E;'D@8F%S960@;VX@8V]D92!B
M>0H@("`@("`@("`@("`@*B!(861I(%)U<VEA:"`\9&5E9V]S0'EA:&]O+F-O
M;3X@:6X@=&AE(&-O;6UE;G1S(&]N"B`@("`@("`@("`@("`J('1H92!D0F%S
M92!R969E<F5N8V4@<&%G92!I;B!T:&4@4$A0(&UA;G5A;"X*("`@("`@("`@
M("`@("HO"B`@("`@("`@("`@("1D8B`]($!F;W!E;B@D=&AI<RT^9'-N6R=D
M871A8F%S92==+"`G<B<I.PH@("`@("`@("`@("!I9B`H(21D8BD@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]2
M7T-/3DY%0U1?1D%)3$5$+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&YU;&PL(&YU;&PL(&YU;&PL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!H<%]E<G)O<FUS9RD["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1I9"`](&%R<F%Y*"D["B`@("`@
M("`@("`@("1I("`](#`["@H@("`@("`@("`@("`D;&EN92`](&9R96%D*"1D
M8BP@,S(I.PH@("`@("`@("`@("!W:&EL92`H(69E;V8H)&1B*2D@>PH@("`@
M("`@("`@("`@("`@)&QI;F4@/2!F<F5A9"@D9&(L(#,R*3L*("`@("`@("`@
M("`@("`@(&EF("AS=6)S='(H)&QI;F4L(#`L(#$I(#T](&-H<B@Q,RDI('L*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@)'!O<R`]('-T<G!O<RAS=6)S
M='(H)&QI;F4L(#`L(#$P*2P@8VAR*#`I*3L*("`@("`@("`@("`@("`@("`@
M("`D<&]S(#T@*"1P;W,@/3T@,"`_(#$P(#H@)'!O<RD["B`@("`@("`@("`@
M("`@("`@("`@)&ED6R1I72`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@
M("`@("`G;F%M92<@("`]/B!S=6)S='(H)&QI;F4L(#`L("1P;W,I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`G='EP92<@("`]/B`D=&AI<RT^='EP97-;
M<W5B<W1R*"1L:6YE+"`Q,2P@,2E=+`H@("`@("`@("`@("`@("`@("`@("`@
M("`G;&5N9W1H)R`]/B!O<F0H<W5B<W1R*"1L:6YE+"`Q-BP@,2DI+`H@("`@
M("`@("`@("`@("`@("`@("`@("`G<')E8VES:6]N)R`]/B!O<F0H<W5B<W1R
M*"1L:6YE+"`Q-RP@,2DI+`H@("`@("`@("`@("`@("`@("`@("D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D:2LK.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!F8VQO<V4H)&1B*3L*("`@("`@("!]"@H@("`@
M("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/
M4E1!0DE,25197TQ/5T520T%312D@>PH@("`@("`@("`@("`D8V%S95]F=6YC
M(#T@)W-T<G1O;&]W97(G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1C87-E7V9U;F,@/2`G<W1R=F%L)SL*("`@("`@("!]"@H@("`@("`@("1R
M97,@("`](&%R<F%Y*"D["B`@("`@("`@)&-O=6YT(#T@8V]U;G0H)&ED*3L*
M"B`@("`@("`@:68@*"1M;V1E*2!["B`@("`@("`@("`@("1R97-;)VYU;5]F
M:65L9',G72`]("1C;W5N=#L*("`@("`@("!]"@H@("`@("`@(&9O<B`H)&D@
M/2`P.R`D:2`\("1C;W5N=#L@)&DK*RD@>PH@("`@("`@("`@("`D<F5S6R1I
M72`](&%R<F%Y*`H@("`@("`@("`@("`@("`@)W1A8FQE)R`]/B`D=&AI<RT^
M9'-N6R=D871A8F%S92==+`H@("`@("`@("`@("`@("`@)VYA;64G("`]/B`D
M8V%S95]F=6YC*"1I9%LD:5U;)VYA;64G72DL"B`@("`@("`@("`@("`@("`G
M='EP92<@(#T^("1I9%LD:5U;)W1Y<&4G72P*("`@("`@("`@("`@("`@("=L
M96XG("`@/3X@)&ED6R1I75LG;&5N9W1H)UTL"B`@("`@("`@("`@("`@("`G
M9FQA9W,G(#T^("<G"B`@("`@("`@("`@("D["B`@("`@("`@("`@(&EF("@D
M;6]D92`F($1"7U1!0DQ%24Y&3U]/4D1%4BD@>PH@("`@("`@("`@("`@("`@
M)')E<ULG;W)D97(G75LD<F5S6R1I75LG;F%M92==72`]("1I.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("@D;6]D92`F($1"7U1!0DQ%24Y&3U]/
M4D1%4E1!0DQ%*2!["B`@("`@("`@("`@("`@("`D<F5S6R=O<F1E<G1A8FQE
M)UU;)')E<ULD:5U;)W1A8FQE)UU=6R1R97-;)&E=6R=N86UE)UU=(#T@)&D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S
M.PH@("`@?0H*("`@("\O('U]?0I]"@HO*@H@*B!,;V-A;"!V87)I86)L97,Z
M"B`J('1A8BUW:61T:#H@-`H@*B!C+6)A<VEC+6]F9G-E=#H@-`H@*B!%;F0Z
M"B`J+PH*/SX*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O3&]G````````````````
M````````````````````````````````````````````````````````````
M```````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P
M,"`Q,#4Q-30S,S<S,2`P,3<Q,C8`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B],;V<O8V]M<&]S:71E+G!H<```````````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#$Q-S8W(#$P-3$U-#,S-S,Q(#`R,3<S-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@)$AE861E<CH@+W)E<&]S:71O<GDO<&5A<B],;V<O3&]G+V-O;7!O<VET
M92YP:'`L=B`Q+C(V(#(P,#4O,#@O,C0@,#4Z,#DZ-#4@:F]N($5X<"`D"B`J
M("1(;W)D93H@:&]R9&4O;&EB+TQO9R]C;VUP;W-I=&4N<&AP+'8@,2XR(#(P
M,#`O,#8O,C@@,C$Z,S8Z,3,@:F]N($5X<"`D"B`J"B`J($!V97)S:6]N("12
M979I<VEO;CH@,2XR-B`D"B`J($!P86-K86=E($QO9PH@*B\*"B\J*@H@*B!4
M:&4@3&]G7V-O;7!O<VET93HZ(&-L87-S(&EM<&QE;65N=',@82!#;VUP;W-I
M=&4@<&%T=&5R;B!W:&EC:`H@*B!A;&QO=W,@;75L=&EP;&4@3&]G(&EM<&QE
M;65N=&%T:6]N<R!T;R!R96-E:79E('1H92!S86UE(&5V96YT<RX*("H*("H@
M0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J
M($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!P:'`N;F5T/@H@*@H@*B!`<VEN
M8V4@2&]R9&4@,2XS"B`J($!S:6YC92!,;V<@,2XP"B`J($!P86-K86=E($QO
M9PH@*@H@*B!`97AA;7!L92!C;VUP;W-I=&4N<&AP("`@57-I;F<@=&AE(&-O
M;7!O<VET92!H86YD;&5R+@H@*B\*8VQA<W,@3&]G7V-O;7!O<VET92!E>'1E
M;F1S($QO9PI["B`@("`O*BH*("`@("`J($%R<F%Y(&AO;&1I;F<@86QL(&]F
M('1H92!,;V<@:6YS=&%N8V5S('1O('=H:6-H(&QO9R!E=F5N=',@<VAO=6QD
M(&)E"B`@("`@*B!S96YT+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]C:&EL9')E
M;B`](&%R<F%Y*"D["@H*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE
M=R!C;VUP;W-I=&4@3&]G(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`@("1N86UE("`@("`@(%1H:7,@<&%R86UE=&5R(&ES(&EG;F]R
M960N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`@("1I9&5N="`@("`@(%1H:7,@
M<&%R86UE=&5R(&ES(&EG;F]R960N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`@
M("1C;VYF("`@("`@(%1H:7,@<&%R86UE=&5R(&ES(&EG;F]R960N"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`@("1L979E;"`@("`@(%1H:7,@<&%R86UE=&5R
M(&ES(&EG;F]R960N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@3&]G7V-O;7!O<VET92@D;F%M92P@)&ED96YT
M(#T@)R<L("1C;VYF(#T@87)R87DH*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&QE=F5L(#T@4$5!4E],3T=?1$5"54<I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]I9&5N="`]("1I9&5N=#L*("`@('T*"B`@("`O*BH*("`@("`J
M($]P96YS('1H92!C:&EL9"!C;VYN96-T:6]N<RX*("`@("`J"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!O<&5N*"D*("`@
M('L*("`@("`@("!I9B`H(21T:&ES+3Y?;W!E;F5D*2!["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3Y?8VAI;&1R96X@87,@)&ED(#T^("1C:&EL9"D@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C:&EL9')E;ELD:61=+3YO<&5N
M*"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]O<&5N960@
M/2!T<G5E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-L;W-E
M<R!A;GD@8VAI;&0@:6YS=&%N8V5S+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L;W-E*"D*("`@('L*("`@
M("`@("!I9B`H)'1H:7,M/E]O<&5N960I('L*("`@("`@("`@("`@9F]R96%C
M:"`H)'1H:7,M/E]C:&EL9')E;B!A<R`D:60@/3X@)&-H:6QD*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7V-H:6QD<F5N6R1I9%TM/F-L;W-E*"D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]O<&5N960@/2!F86QS
M93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!&;'5S:&5S(&%L
M;"!O<&5N(&-H:6QD(&EN<W1A;F-E<RX*("`@("`J"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("H@0'-I;F-E($QO9R`Q+C@N,@H@("`@("HO"B`@("!F
M=6YC=&EO;B!F;'5S:"@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?;W!E
M;F5D*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?8VAI;&1R96X@
M87,@)&ED(#T^("1C:&EL9"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C
M:&EL9')E;ELD:61=+3YF;'5S:"@I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@4V5N9',@)&UE<W-A9V4@86YD("1P
M<FEO<FET>2!T;R!E86-H(&-H:6QD(&]F('1H:7,@8V]M<&]S:71E+@H@("`@
M("H*("`@("`J($!P87)A;2!M:7AE9"`@("`@)&UE<W-A9V4@("`@4W1R:6YG
M(&]R(&]B:F5C="!C;VYT86EN:6YG('1H92!M97-S86=E"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('1O(&QO9RX*("`@("`J($!P87)A
M;2!S=')I;F<@("`@)'!R:6]R:71Y("`@*&]P=&EO;F%L*2!4:&4@<')I;W)I
M='D@;V8@=&AE(&UE<W-A9V4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%9A;&ED('9A;'5E<R!A<F4Z(%!%05)?3$]'7T5-15)'+`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!014%27TQ/1U]!
M3$525"P@4$5!4E],3T=?0U))5"P*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@4$5!4E],3T=?15)2+"!014%27TQ/1U]705).24Y'+`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!014%27TQ/1U].
M3U1)0T4L(%!%05)?3$]'7TE.1D\L(&%N9`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!014%27TQ/1U]$14)51RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE(&5N=')Y(&ES('-U8V-E
M<W-F=6QL>2!L;V=G960N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@;&]G*"1M97-S86=E+"`D<')I;W)I='D@
M/2!N=6QL*0H@("`@>PH@("`@("`@("\J($EF(&$@<')I;W)I='D@:&%S;B=T
M(&)E96X@<W!E8VEF:65D+"!U<V4@=&AE(&1E9F%U;'0@=F%L=64N("HO"B`@
M("`@("`@:68@*"1P<FEO<FET>2`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D
M<')I;W)I='D@/2`D=&AI<RT^7W!R:6]R:71Y.PH@("`@("`@('T*"B`@("`@
M("`@9F]R96%C:"`H)'1H:7,M/E]C:&EL9')E;B!A<R`D:60@/3X@)&-H:6QD
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?8VAI;&1R96Y;)&ED72T^;&]G*"1M
M97-S86=E+"`D<')I;W)I='DI.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M
M/E]A;FYO=6YC92AA<G)A>2@G<')I;W)I='DG(#T^("1P<FEO<FET>2P@)VUE
M<W-A9V4G(#T^("1M97-S86=E*2D["@H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T<G5E(&EF('1H:7,@:7,@
M82!C;VUP;W-I=&4N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&EF('1H:7,@:7,@82!C;VUP;W-I=&4@8VQA<W,N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@:7-#;VUP
M;W-I=&4H*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5T<R!T:&ES(&ED96YT:69I8V%T:6]N('-T<FEN9R!F
M;W(@86QL(&]F('1H:7,@8V]M<&]S:71E)W,@8VAI;&1R96XN"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`@("`D:61E;G0@("`@("!4:&4@;F5W(&ED
M96YT:69I8V%T:6]N('-T<FEN9RX*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("H@0'-I;F-E("!,;V<@,2XV+C<*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5T261E;G0H)&ED96YT*0H@("`@>PH@("`@("`@("\J($-A;&P@
M;W5R(&)A<V4@8VQA<W,G<R!S971)9&5N="@I(&UE=&AO9"X@*B\*("`@("`@
M("!P87)E;G0Z.G-E=$ED96YT*"1I9&5N="D["@H@("`@("`@("\J("XN+B!A
M;F0@=&AE;B!C86QL('-E=$ED96YT*"D@;VX@86QL(&]F(&]U<B!C:&EL9')E
M;BX@*B\*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V-H:6QD<F5N(&%S("1I
M9"`]/B`D8VAI;&0I('L*("`@("`@("`@("`@)'1H:7,M/E]C:&EL9')E;ELD
M:61=+3YS971)9&5N="@D:61E;G0I.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($%D9',@82!,;V<@:6YS=&%N8V4@=&\@=&AE(&QI<W0@;V8@
M8VAI;&1R96XN"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="`@("`D8VAI
M;&0@("`@("!4:&4@3&]G(&EN<W1A;F-E('1O(&%D9"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE($QO9R!I;G-T86YC92!W
M87,@<W5C8V5S<V9U;&QY(&%D9&5D+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$-H:6QD*"8D8VAI;&0I
M"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E('1H:7,@:7,@82!,;V<@:6YS
M=&%N8V4N("HO"B`@("`@("`@:68@*"%I<U]A*"1C:&EL9"P@)TQO9R<I*2![
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@
M("1T:&ES+3Y?8VAI;&1R96Y;)&-H:6QD+3Y?:61=(#T@)B1C:&EL9#L*"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO
M=F5S(&$@3&]G(&EN<W1A;F-E(&9R;VT@=&AE(&QI<W0@;V8@8VAI;&1R96XN
M"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="`@("`D8VAI;&0@("`@("!4
M:&4@3&]G(&EN<W1A;F-E('1O(')E;6]V92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%1R=64@:68@=&AE($QO9R!I;G-T86YC92!W87,@<W5C
M8V5S<V9U;&QY(')E;6]V960N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E0VAI;&0H)&-H:6QD*0H@
M("`@>PH@("`@("`@(&EF("@A:7-?82@D8VAI;&0L("=,;V<G*2!\?"`A:7-S
M970H)'1H:7,M/E]C:&EL9')E;ELD8VAI;&0M/E]I9%TI*2!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@('5N<V5T*"1T
M:&ES+3Y?8VAI;&1R96Y;)&-H:6QD+3Y?:61=*3L*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@I]"@```````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O3&]G+V1A96UO;BYP:'``````````````````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`Q-3`S-"`Q,#4Q-30S,S<S,2`P,C$Q-C0`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+R\@)$ED.B!D865M;VXN<&AP+'8@,2XR(#(P,#4O,#(O,C8@,30Z-#@Z
M-3@@8VAA9V5N8G4@17AP("0*"B\J*@H@*B!4:&4@3&]G7V1A96UO;B!C;&%S
M<R!I<R!A(&-O;F-R971E(&EM<&QE;65N=&%T:6]N(&]F('1H92!,;V<Z.@H@
M*B!A8G-T<F%C="!C;&%S<R!W:&EC:"!S96YD<R!M97-S86=E<R!T;R!S>7-L
M;V<@9&%E;6]N(&]N(%5.25@M;&EK92!M86-H:6YE<RX*("H@5&AI<R!C;&%S
M<R!U<V5S('1H92!S>7-L;V<@<')O=&]C;VPZ(&AT='`Z+R]W=W<N:65T9BYO
M<F<O<F9C+W)F8S,Q-C0N='AT"B`J"B`J($!A=71H;W(@($)A<G0@=F%N(&1E
M<B!38VAA;G,@/'-C:&%N<T!D9',N;FP^"B`J($!V97)S:6]N("12979I<VEO
M;CH@,2XR("0*("H@0'!A8VMA9V4@3&]G"B`J+PIC;&%S<R!,;V=?9&%E;6]N
M(&5X=&5N9',@3&]G"GL*("`@("\J*@H@("`@("H@26YT96=E<B!H;VQD:6YG
M('1H92!L;V<@9F%C:6QI='D@=&\@=7-E+@H@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J+PH@("`@=F%R("1?;F%M92`]($Q/1U]$045-3TX["@H@("`@+RHJ
M"B`@("`@*B!687(@:&]L9&EN9R!T:&4@<F5S;W5R8V4@<&]I;G1E<B!T;R!T
M:&4@<V]C:V5T"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A
M<B`D7W-O8VME=#L*"B`@("`O*BH*("`@("`J(%1H92!I<"!A9&1R97-S(&]R
M('-E<G9E<FYA;64*("`@("`J($!S964@:'1T<#HO+W=W=RYP:'`N;F5T+VUA
M;G5A;"]E;B]T<F%N<W!O<G1S+G!H<`H@("`@("H@0'9A<B!S=')I;F<*("`@
M("`J+PH@("`@=F%R("1?:7`@/2`G,3(W+C`N,"XQ)SL*"B`@("`O*BH*("`@
M("`J(%!R;W1O8V]L('1O('5S92`H=&-P+"!U9'`L(&5T8RXI"B`@("`@*B!`
M<V5E(&AT='`Z+R]W=W<N<&AP+FYE="]M86YU86PO96XO=')A;G-P;W)T<RYP
M:'`*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W!R;W1O
M(#T@)W5D<"<["@H@("`@+RHJ"B`@("`@*B!0;W)T('1O(&-O;FYE8W0@=&\*
M("`@("`J($!V87(@:6YT"B`@("`@*B\*("`@('9A<B`D7W!O<G0@/2`U,30[
M"@H@("`@+RHJ"B`@("`@*B!-87AI;75M(&UE<W-A9V4@;&5N9W1H(&EN(&)Y
M=&5S"B`@("`@*B!`=F%R(&EN=`H@("`@("HO"B`@("!V87(@)%]M87AS:7IE
M(#T@-#`Y-CL*"B`@("`O*BH*("`@("`J(%-O8VME="!T:6UE;W5T(&EN('-E
M8V]N9',*("`@("`J($!V87(@:6YT"B`@("`@*B\*("`@('9A<B`D7W1I;65O
M=70@/2`Q.PH*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!N97<@<WES
M;&]G(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE
M("`@("!4:&4@<WES;&]G(&9A8VEL:71Y+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D:61E;G0@("`@5&AE(&ED96YT:71Y('-T<FEN9RX*("`@("`J($!P87)A
M;2!A<G)A>2`@)&-O;F8@("`@(%1H92!C;VYF:6=U<F%T:6]N(&%R<F%Y+@H@
M("`@("H@0'!A<F%M(&EN="`@("`D;6%X3&5V96P@36%X:6UU;2!L979E;"!A
M="!W:&EC:"!T;R!L;V<N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!,;V=?9&%E;6]N*"1N86UE+"`D:61E;G0@/2`G)RP@
M)&-O;F8@/2!A<G)A>2@I+`H@("`@("`@("`@("`@("`@("`@("`@("`D;&5V
M96P@/2!014%27TQ/1U]$14)51RD*("`@('L*("`@("`@("`O*B!%;G-U<F4@
M=V4@:&%V92!A('9A;&ED(&EN=&5G97(@=F%L=64@9F]R("1N86UE+B`J+PH@
M("`@("`@(&EF("AE;7!T>2@D;F%M92D@?'P@(6ES7VEN="@D;F%M92DI('L*
M("`@("`@("`@("`@)&YA;64@/2!,3T=?4UE33$]'.PH@("`@("`@('T*"B`@
M("`@("`@)'1H:7,M/E]I9"`](&UD-2AM:6-R;W1I;64H*2D["B`@("`@("`@
M)'1H:7,M/E]N86UE(#T@)&YA;64["B`@("`@("`@)'1H:7,M/E]I9&5N="`]
M("1I9&5N=#L*("`@("`@("`D=&AI<RT^7VUA<VL@/2!,;V<Z.E505$\H)&QE
M=F5L*3L*"B`@("`@("`@:68@*&ES<V5T*"1C;VYF6R=I<"==*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7VEP(#T@)&-O;F9;)VEP)UT["B`@("`@("`@?0H@
M("`@("`@(&EF("AI<W-E="@D8V]N9ELG<')O=&\G72DI('L*("`@("`@("`@
M("`@)'1H:7,M/E]P<F]T;R`]("1C;VYF6R=P<F]T;R==.PH@("`@("`@('T*
M("`@("`@("!I9B`H:7-S970H)&-O;F9;)W!O<G0G72DI('L*("`@("`@("`@
M("`@)'1H:7,M/E]P;W)T(#T@)&-O;F9;)W!O<G0G73L*("`@("`@("!]"B`@
M("`@("`@:68@*&ES<V5T*"1C;VYF6R=M87AS:7IE)UTI*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?;6%X<VEZ92`]("1C;VYF6R=M87AS:7IE)UT["B`@("`@
M("`@?0H@("`@("`@(&EF("AI<W-E="@D8V]N9ELG=&EM96]U="==*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7W1I;65O=70@/2`D8V]N9ELG=&EM96]U="==
M.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7W!R;W1O(#T@)'1H:7,M/E]P
M<F]T;R`N("<Z+R\G.PH*("`@("`@("!R96=I<W1E<E]S:'5T9&]W;E]F=6YC
M=&EO;BAA<G)A>2@F)'1H:7,L("=?3&]G7V1A96UO;B<I*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($1E<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%],;V=?9&%E;6]N*"D*
M("`@('L*("`@("`@("`D=&AI<RT^8VQO<V4H*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($]P96YS(&$@8V]N;F5C=&EO;B!T;R!T:&4@<WES=&5M(&QO9V=E
M<BP@:68@:70@:&%S(&YO="!A;')E861Y"B`@("`@*B!B965N(&]P96YE9"X@
M(%1H:7,@:7,@:6UP;&EC:71L>2!C86QL960@8GD@;&]G*"DL(&EF(&YE8V5S
M<V%R>2X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&]P96XH*0H@("`@>PH@("`@("`@(&EF("@A)'1H:7,M/E]O<&5N960I
M('L*("`@("`@("`@("`@)'1H:7,M/E]O<&5N960@/2`H8F]O;"DH)'1H:7,M
M/E]S;V-K970@/2!`9G-O8VMO<&5N*`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!R;W1O("X@)'1H
M:7,M/E]I<"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P;W)T+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D97)R;F\L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E<G)S
M='(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?=&EM96]U="DI.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@)'1H:7,M/E]O<&5N960["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M;&]S97,@=&AE(&-O;FYE8W1I;VX@=&\@=&AE('-Y<W1E;2!L;V=G97(L(&EF
M(&ET(&ES(&]P96XN"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!C;&]S92@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?
M;W!E;F5D*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W!E;F5D(#T@9F%L<V4[
M"B`@("`@("`@("`@(')E='5R;B!F8VQO<V4H)'1H:7,M/E]S;V-K970I.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*
M("`@("`J(%-E;F1S("1M97-S86=E('1O('1H92!C=7)R96YT;'D@;W!E;B!S
M>7-L;V<@8V]N;F5C=&EO;BX@($-A;&QS"B`@("`@*B!O<&5N*"D@:68@;F5C
M97-S87)Y+B!!;'-O('!A<W-E<R!T:&4@;65S<V%G92!A;&]N9R!T;R!A;GD@
M3&]G7V]B<V5R=F5R"B`@("`@*B!I;G-T86YC97,@=&AA="!A<F4@;V)S97)V
M:6YG('1H:7,@3&]G+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&UE
M<W-A9V4@(%1H92!T97AT=6%L(&UE<W-A9V4@=&\@8F4@;&]G9V5D+@H@("`@
M("H@0'!A<F%M(&EN="`D<')I;W)I='D@*&]P=&EO;F%L*2!4:&4@<')I;W)I
M='D@;V8@=&AE(&UE<W-A9V4N("!686QI9`H@("`@("H@("`@("`@("`@("`@
M("`@("!V86QU97,@87)E.B!,3T=?14U%4D<L($Q/1U]!3$525"P@3$]'7T-2
M250L"B`@("`@*B`@("`@("`@("`@("`@("`@($Q/1U]%4E(L($Q/1U]705).
M24Y'+"!,3T=?3D]424-%+"!,3T=?24Y&3RP*("`@("`J("`@("`@("`@("`@
M("`@("`@86YD($Q/1U]$14)51RX@(%1H92!D969A=6QT(&ES($Q/1U])3D9/
M+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@
M;&]G*"1M97-S86=E+"`D<')I;W)I='D@/2!N=6QL*0H@("`@>PH@("`@("`@
M("\J($EF(&$@<')I;W)I='D@:&%S;B=T(&)E96X@<W!E8VEF:65D+"!U<V4@
M=&AE(&1E9F%U;'0@=F%L=64N("HO"B`@("`@("`@:68@*"1P<FEO<FET>2`]
M/3T@;G5L;"D@>PH@("`@("`@("`@("`D<')I;W)I='D@/2`D=&AI<RT^7W!R
M:6]R:71Y.PH@("`@("`@('T*"B`@("`@("`@+RH@06)O<G0@96%R;'D@:68@
M=&AE('!R:6]R:71Y(&ES(&%B;W9E('1H92!M87AI;75M(&QO9V=I;F<@;&5V
M96PN("HO"B`@("`@("`@:68@*"$D=&AI<RT^7VES36%S:V5D*"1P<FEO<FET
M>2DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@+RH@268@=&AE(&-O;FYE8W1I;VX@:7-N)W0@;W!E;B!A;F0@8V%N
M)W0@8F4@;W!E;F5D+"!R971U<FX@9F%I;'5R92X@*B\*("`@("`@("!I9B`H
M(21T:&ES+3Y?;W!E;F5D("8F("$D=&AI<RT^;W!E;B@I*2!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("\J($5X=')A
M8W0@=&AE('-T<FEN9R!R97!R97-E;G1A=&EO;B!O9B!T:&4@;65S<V%G92X@
M*B\*("`@("`@("`D;65S<V%G92`]("1T:&ES+3Y?97AT<F%C=$UE<W-A9V4H
M)&UE<W-A9V4I.PH*("`@("`@("`O*B!3970@=&AE(&9A8VEL:71Y(&QE=F5L
M+B`J+PH@("`@("`@("1F86-I;&ET>5]L979E;"`](&EN='9A;"@D=&AI<RT^
M7VYA;64I("L*("`@("`@("`@("`@("`@("`@("`@("`@("!I;G1V86PH)'1H
M:7,M/E]T;U-Y<VQO9R@D<')I;W)I='DI*3L*"B`@("`@("`@+RH@4')E<&5N
M9"!I9&5N="!I;F9O+B`J+PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]I
M9&5N="DI('L*("`@("`@("`@("`@)&UE<W-A9V4@/2`D=&AI<RT^7VED96YT
M("X@)R`G("X@)&UE<W-A9V4["B`@("`@("`@?0H*("`@("`@("`O*B!#:&5C
M:R!F;W(@;65S<V%G92!L96YG=&@N("HO"B`@("`@("`@:68@*'-T<FQE;B@D
M;65S<V%G92D@/B`D=&AI<RT^7VUA>'-I>F4I('L*("`@("`@("`@("`@)&UE
M<W-A9V4@/2!S=6)S='(H)&UE<W-A9V4L(#`L("@D=&AI<RT^7VUA>'-I>F4I
M("T@,3`I("X@)R!;+BXN72<["B`@("`@("`@?0H*("`@("`@("`O*B!7<FET
M92!T;R!S;V-K970N("HO"B`@("`@("`@9G=R:71E*"1T:&ES+3Y?<V]C:V5T
M+"`G/"<@+B`D9F%C:6QI='E?;&5V96P@+B`G/B<@+B`D;65S<V%G92`N(")<
M;B(I.PH*("`@("`@("`D=&AI<RT^7V%N;F]U;F-E*&%R<F%Y*"=P<FEO<FET
M>2<@/3X@)'!R:6]R:71Y+"`G;65S<V%G92<@/3X@)&UE<W-A9V4I*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($-O;G9E<G1S(&$@4$5!4E],3T=?*B!C;VYS
M=&%N="!I;G1O(&$@<WES;&]G($Q/1U\J(&-O;G-T86YT+@H@("`@("H*("`@
M("`J(%1H:7,@9G5N8W1I;VX@97AI<W1S(&)E8V%U<V4L('5N9&5R(%=I;F1O
M=W,L(&YO="!A;&P@;V8@=&AE($Q/1U\J"B`@("`@*B!C;VYS=&%N=',@:&%V
M92!U;FEQ=64@=F%L=65S+B`@26YS=&5A9"P@=&AE(%!%05)?3$]'7RH@=V5R
M92!I;G1R;V1U8V5D"B`@("`@*B!F;W(@9VQO8F%L('5S92P@=VET:"!T:&4@
M8V]N=F5R<VEO;B!T;R!T:&4@3$]'7RH@8V]N<W1A;G1S(&ME<'0@;&]C86P@
M=&\*("`@("`J('1O('1H92!S>7-L;V<@9')I=F5R+@H@("`@("H*("`@("`J
M($!P87)A;2!I;G0@)'!R:6]R:71Y("`@("!014%27TQ/1U\J('9A;'5E('1O
M(&-O;G9E<G0@=&\@3$]'7RH@=F%L=64N"B`@("`@*@H@("`@("H@0')E='5R
M;B`@5&AE($Q/1U\J(')E<')E<V5N=&%T:6]N(&]F("1P<FEO<FET>2X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I
M;VX@7W1O4WES;&]G*"1P<FEO<FET>2D*("`@('L*("`@("`@("!S=&%T:6,@
M)'!R:6]R:71I97,@/2!A<G)A>2@*("`@("`@("`@("`@4$5!4E],3T=?14U%
M4D<@("`]/B!,3T=?14U%4D<L"B`@("`@("`@("`@(%!%05)?3$]'7T%,15)4
M("`@/3X@3$]'7T%,15)4+`H@("`@("`@("`@("!014%27TQ/1U]#4DE4("`@
M(#T^($Q/1U]#4DE4+`H@("`@("`@("`@("!014%27TQ/1U]%4E(@("`@(#T^
M($Q/1U]%4E(L"B`@("`@("`@("`@(%!%05)?3$]'7U=!4DY)3D<@/3X@3$]'
M7U=!4DY)3D<L"B`@("`@("`@("`@(%!%05)?3$]'7TY/5$E#12`@/3X@3$]'
M7TY/5$E#12P*("`@("`@("`@("`@4$5!4E],3T=?24Y&3R`@("`]/B!,3T=?
M24Y&3RP*("`@("`@("`@("`@4$5!4E],3T=?1$5"54<@("`]/B!,3T=?1$5"
M54<*("`@("`@("`I.PH*("`@("`@("`O*B!)9B!W92=R92!P87-S960@86X@
M=6YK;F]W;B!P<FEO<FET>2P@9&5F875L="!T;R!,3T=?24Y&3RX@*B\*("`@
M("`@("!I9B`H(6ES7VEN="@D<')I;W)I='DI('Q\("%I;E]A<G)A>2@D<')I
M;W)I='DL("1P<FEO<FET:65S*2D@>PH@("`@("`@("`@("!R971U<FX@3$]'
M7TE.1D\["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'!R:6]R:71I97-;
M)'!R:6]R:71Y73L*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O3&]G+V1I
M<W!L87DN<&AP````````````````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P-S`V,R`Q,#4Q-30S,S<S,2`P,C$S-S$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J("1(96%D
M97(Z("]R97!O<VET;W)Y+W!E87(O3&]G+TQO9R]D:7-P;&%Y+G!H<"QV(#$N
M."`R,#`U+S`X+S`V(#(S.C(X.C,U(&IO;B!%>'`@)`H@*@H@*B!`=F5R<VEO
M;B`D4F5V:7-I;VXZ(#$N."`D"B`J($!P86-K86=E($QO9PH@*B\*"B\J*@H@
M*B!4:&4@3&]G7V1I<W!L87D@8VQA<W,@:7,@82!C;VYC<F5T92!I;7!L96UE
M;G1A=&EO;B!O9B!T:&4@3&]G.CH*("H@86)S=')A8W0@8VQA<W,@=VAI8V@@
M=W)I=&5S(&UE<W-A9V4@:6YT;R!B<F]W<V5R(&EN('5S=6%L(%!(4"!M86YE
M<BX*("H@5&AI<R!M87D@8F4@=7-E9G5L(&)E8V%U<V4@=VAE;B!Y;W4@=7-E
M(%!%05(Z.G-E=$5R<F]R2&%N9&QI;F<@:6X*("H@4$5!4E]%4E)/4E]#04Q,
M0D%#2R!M;V1E(&5R<F]R(&UE<W-A9V5S(&%R92!N;W0@9&ES<&QA>65D(&)Y
M"B`J(%!(4"!E<G)O<B!H86YD;&5R+@H@*@H@*B!`875T:&]R("!0875L(%EA
M;F-H96YK;R`\<'5S:&5R0&EN86-O+G)U/@H@*B!`<VEN8V4@("!,;V<@,2XX
M+C`*("H@0'!A8VMA9V4@3&]G"B`J"B`J($!E>&%M<&QE(&1I<W!L87DN<&AP
M("`@("!5<VEN9R!T:&4@9&ES<&QA>2!H86YD;&5R+@H@*B\*8VQA<W,@3&]G
M7V1I<W!L87D@97AT96YD<R!,;V<*>PH@("`@+RHJ"B`@("`@*B!3=')I;F<@
M=&\@;W5T<'5T(&)E9F]R92!A;B!E<G)O<B!M97-S86=E"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A
M<B`D7V5R<F]R7W!R97!E;F0@/2`G)SL*"B`@("`O*BH*("`@("`J(%-T<FEN
M9R!T;R!O=71P=70@869T97(@86X@97)R;W(@;65S<V%G90H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V
M87(@)%]E<G)O<E]A<'!E;F0@/2`G)SL*"B`@("`O*BH*("`@("`J(%-T<FEN
M9R!U<V5D('1O(')E<')E<V5N="!A(&QI;F4@8G)E86LN"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A
M<B`D7VQI;F5B<F5A:R`]("(\8G(@+SY<;B(["@H@("`@+RHJ"B`@("`@*B!#
M;VYS=')U8W1S(&$@;F5W($QO9U]D:7-P;&%Y(&]B:F5C="X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("!)9VYO<F5D+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D:61E;G0@("`@5&AE(&ED96YT:71Y('-T<FEN9RX*
M("`@("`J($!P87)A;2!A<G)A>2`@)&-O;F8@("`@(%1H92!C;VYF:6=U<F%T
M:6]N(&%R<F%Y+@H@("`@("H@0'!A<F%M(&EN="`@("`D;&5V96P@("`@3&]G
M(&UE<W-A9V5S('5P('1O(&%N9"!I;F-L=61I;F<@=&AI<R!L979E;"X*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N($QO9U]D
M:7-P;&%Y*"1N86UE(#T@)R<L("1I9&5N="`]("<G+"`D8V]N9B`](&%R<F%Y
M*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`D;&5V96P@/2!014%27TQ/
M1U]$14)51RD*("`@('L*("`@("`@("`D=&AI<RT^7VED(#T@;60U*&UI8W)O
M=&EM92@I*3L*("`@("`@("`D=&AI<RT^7VED96YT(#T@)&ED96YT.PH@("`@
M("`@("1T:&ES+3Y?;6%S:R`]($QO9SHZ55!43R@D;&5V96PI.PH*("`@("`@
M("!I9B`H:7-S970H)&-O;F9;)V5R<F]R7W!R97!E;F0G72DI('L*("`@("`@
M("`@("`@)'1H:7,M/E]E<G)O<E]P<F5P96YD(#T@)&-O;F9;)V5R<F]R7W!R
M97!E;F0G73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^
M7V5R<F]R7W!R97!E;F0@/2!I;FE?9V5T*"=E<G)O<E]P<F5P96YD7W-T<FEN
M9R<I.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1C;VYF6R=E<G)O
M<E]A<'!E;F0G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]E<G)O<E]A<'!E
M;F0@/2`D8V]N9ELG97)R;W)?87!P96YD)UT["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'1H:7,M/E]E<G)O<E]A<'!E;F0@/2!I;FE?9V5T*"=E
M<G)O<E]A<'!E;F1?<W1R:6YG)RD["B`@("`@("`@?0H*("`@("`@("!I9B`H
M:7-S970H)&-O;F9;)VQI;F5B<F5A:R==*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^7VQI;F5B<F5A:R`]("1C;VYF6R=L:6YE8G)E86LG73L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!7<FET97,@)&UE<W-A9V4@=&\@=&AE
M('1E>'0@8G)O=W-E<BX@06QS;RP@<&%S<V5S('1H92!M97-S86=E"B`@("`@
M*B!A;&]N9R!T;R!A;GD@3&]G7V]B<V5R=F5R(&EN<W1A;F-E<R!T:&%T(&%R
M92!O8G-E<G9I;F<@=&AI<R!,;V<N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI
M>&5D("`D;65S<V%G92`@("!3=')I;F<@;W(@;V)J96-T(&-O;G1A:6YI;F<@
M=&AE(&UE<W-A9V4@=&\@;&]G+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')I
M;W)I='D@5&AE('!R:6]R:71Y(&]F('1H92!M97-S86=E+B`@5F%L:60*("`@
M("`J("`@("`@("`@("`@("`@("`@=F%L=65S(&%R93H@4$5!4E],3T=?14U%
M4D<L(%!%05)?3$]'7T%,15)4+`H@("`@("H@("`@("`@("`@("`@("`@("!0
M14%27TQ/1U]#4DE4+"!014%27TQ/1U]%4E(L(%!%05)?3$]'7U=!4DY)3D<L
M"B`@("`@*B`@("`@("`@("`@("`@("`@(%!%05)?3$]'7TY/5$E#12P@4$5!
M4E],3T=?24Y&3RP@86YD(%!%05)?3$]'7T1%0E5'+@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,@;W(@9F%L<V4@;VX@9F%I;'5R
M92X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&QO9R@D;65S<V%G92P@)'!R:6]R:71Y(#T@;G5L;"D*("`@('L*("`@("`@
M("`O*B!)9B!A('!R:6]R:71Y(&AA<VXG="!B965N('-P96-I9FEE9"P@=7-E
M('1H92!D969A=6QT('9A;'5E+B`J+PH@("`@("`@(&EF("@D<')I;W)I='D@
M/3T](&YU;&PI('L*("`@("`@("`@("`@)'!R:6]R:71Y(#T@)'1H:7,M/E]P
M<FEO<FET>3L*("`@("`@("!]"@H@("`@("`@("\J($%B;W)T(&5A<FQY(&EF
M('1H92!P<FEO<FET>2!I<R!A8F]V92!T:&4@;6%X:6UU;2!L;V=G:6YG(&QE
M=F5L+B`J+PH@("`@("`@(&EF("@A)'1H:7,M/E]I<TUA<VME9"@D<')I;W)I
M='DI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@
M("`@("`@("\J($5X=')A8W0@=&AE('-T<FEN9R!R97!R97-E;G1A=&EO;B!O
M9B!T:&4@;65S<V%G92X@*B\*("`@("`@("`D;65S<V%G92`]("1T:&ES+3Y?
M97AT<F%C=$UE<W-A9V4H)&UE<W-A9V4I.PH*("`@("`@("`O*B!"=6EL9"!A
M;F0@;W5T<'5T('1H92!C;VUP;&5T92!L;V<@;&EN92X@*B\*("`@("`@("!E
M8VAO("1T:&ES+3Y?97)R;W)?<')E<&5N9"`N"B`@("`@("`@("`@("`G/&(^
M)R`N('5C9FER<W0H)'1H:7,M/G!R:6]R:71Y5&]3=')I;F<H)'!R:6]R:71Y
M*2D@+B`G/"]B/CH@)RX*("`@("`@("`@("`@(&YL,F)R*&AT;6QS<&5C:6%L
M8VAA<G,H)&UE<W-A9V4I*2`N"B`@("`@("`@("`@("`D=&AI<RT^7V5R<F]R
M7V%P<&5N9"`N("1T:&ES+3Y?;&EN96)R96%K.PH*("`@("`@("`O*B!.;W1I
M9GD@;V)S97)V97)S(&%B;W5T('1H:7,@;&]G(&UE<W-A9V4N("HO"B`@("`@
M("`@)'1H:7,M/E]A;FYO=6YC92AA<G)A>2@G<')I;W)I='DG(#T^("1P<FEO
M<FET>2P@)VUE<W-A9V4G(#T^("1M97-S86=E*2D["@H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O3&]G+V5R<F]R7VQO9RYP:'``````````````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-C`V-"`Q,#4Q-30S,S<S,2`P,C$W
M,38`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J("1(96%D97(Z("]R97!O<VET;W)Y+W!E87(O3&]G+TQO
M9R]E<G)O<E]L;V<N<&AP+'8@,2XW(#(P,#4O,#(O,C8@,30Z-#@Z-3@@8VAA
M9V5N8G4@17AP("0*("H*("H@0'9E<G-I;VX@)%)E=FES:6]N.B`Q+C<@)`H@
M*B!`<&%C:V%G92!,;V<*("HO"@HO*BH*("H@5&AE($QO9U]E<G)O<E]L;V<@
M8VQA<W,@:7,@82!C;VYC<F5T92!I;7!L96UE;G1A=&EO;B!O9B!T:&4@3&]G
M(&%B<W1R86-T"B`J(&-L87-S('1H870@;&]G<R!M97-S86=E<R!U<VEN9R!0
M2%`G<R!E<G)O<E]L;V<H*2!F=6YC=&EO;BX*("H*("H@0&%U=&AO<B`@2F]N
M(%!A<FES92`\:F]N0'!H<"YN970^"B`J($!S:6YC92`@($QO9R`Q+C<N,`H@
M*B!`<&%C:V%G92!,;V<*("H*("H@0&5X86UP;&4@97)R;W)?;&]G+G!H<"`@
M(%5S:6YG('1H92!E<G)O<E]L;V<@:&%N9&QE<BX*("HO"F-L87-S($QO9U]E
M<G)O<E]L;V<@97AT96YD<R!,;V<*>PH@("`@+RHJ"B`@("`@*B!4:&4@97)R
M;W)?;&]G*"D@;&]G('1Y<&4N"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]T>7!E(#T@4$5!
M4E],3T=?5%E015]365-414T["@H@("`@+RHJ"B`@("`@*B!4:&4@='EP92US
M<&5C:69I8R!D97-T:6YA=&EO;B!V86QU92X*("`@("`J($!V87(@<W1R:6YG
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?9&5S
M=&EN871I;VX@/2`G)SL*"B`@("`O*BH*("`@("`J($%D9&ET:6]N86P@:&5A
M9&5R<R!T;R!P87-S('1O('1H92!M86EL*"D@9G5N8W1I;VX@=VAE;B!T:&4*
M("`@("`J(%!%05)?3$]'7U194$5?34%)3"!T>7!E(&ES('5S960N"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@('9A<B`D7V5X=')A7VAE861E<G,@/2`G)SL*"B`@("`O*BH*("`@("`J
M($-O;G-T<G5C=',@82!N97<@3&]G7V5R<F]R7VQO9R!O8FIE8W0N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@26=N;W)E9"X*("`@
M("`J($!P87)A;2!S=')I;F<@)&ED96YT("`@(%1H92!I9&5N=&ET>2!S=')I
M;F<N"B`@("`@*B!`<&%R86T@87)R87D@("1C;VYF("`@("!4:&4@8V]N9FEG
M=7)A=&EO;B!A<G)A>2X*("`@("`J($!P87)A;2!I;G0@("`@)&QE=F5L("`@
M($QO9R!M97-S86=E<R!U<"!T;R!A;F0@:6YC;'5D:6YG('1H:7,@;&5V96PN
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!,
M;V=?97)R;W)?;&]G*"1N86UE+"`D:61E;G0@/2`G)RP@)&-O;F8@/2!A<G)A
M>2@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`D;&5V96P@/2!014%2
M7TQ/1U]$14)51RD*("`@('L*("`@("`@("`D=&AI<RT^7VED(#T@;60U*&UI
M8W)O=&EM92@I*3L*("`@("`@("`D=&AI<RT^7W1Y<&4@/2`D;F%M93L*("`@
M("`@("`D=&AI<RT^7VED96YT(#T@)&ED96YT.PH@("`@("`@("1T:&ES+3Y?
M;6%S:R`]($QO9SHZ55!43R@D;&5V96PI.PH*("`@("`@("!I9B`H(65M<'1Y
M*"1C;VYF6R=D97-T:6YA=&EO;B==*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7V1E<W1I;F%T:6]N(#T@)&-O;F9;)V1E<W1I;F%T:6]N)UT["B`@("`@("`@
M?0H@("`@("`@(&EF("@A96UP='DH)&-O;F9;)V5X=')A7VAE861E<G,G72DI
M('L*("`@("`@("`@("`@)'1H:7,M/E]E>'1R85]H96%D97)S(#T@)&-O;F9;
M)V5X=')A7VAE861E<G,G73L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!,;V=S("1M97-S86=E('5S:6YG(%!(4"=S(&5R<F]R7VQO9R@I(&9U
M;F-T:6]N+B`@5&AE(&UE<W-A9V4@:7,@86QS;PH@("`@("H@<&%S<V5D(&%L
M;VYG('1O(&%N>2!,;V=?;V)S97)V97(@:6YS=&%N8V5S('1H870@87)E(&]B
M<V5R=FEN9R!T:&ES($QO9RX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@
M("1M97-S86=E("`@4W1R:6YG(&]R(&]B:F5C="!C;VYT86EN:6YG('1H92!M
M97-S86=E('1O(&QO9RX*("`@("`J($!P87)A;2!S=')I;F<@)'!R:6]R:71Y
M(%1H92!P<FEO<FET>2!O9B!T:&4@;65S<V%G92X@(%9A;&ED"B`@("`@*B`@
M("`@("`@("`@("`@("`@('9A;'5E<R!A<F4Z(%!%05)?3$]'7T5-15)'+"!0
M14%27TQ/1U]!3$525"P*("`@("`J("`@("`@("`@("`@("`@("`@4$5!4E],
M3T=?0U))5"P@4$5!4E],3T=?15)2+"!014%27TQ/1U]705).24Y'+`H@("`@
M("H@("`@("`@("`@("`@("`@("!014%27TQ/1U].3U1)0T4L(%!%05)?3$]'
M7TE.1D\L(&%N9"!014%27TQ/1U]$14)51RX*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5')U92!O;B!S=6-C97-S(&]R(&9A;'-E(&]N(&9A:6QU<F4N"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!L;V<H
M)&UE<W-A9V4L("1P<FEO<FET>2`](&YU;&PI"B`@("!["B`@("`@("`@+RH@
M268@82!P<FEO<FET>2!H87-N)W0@8F5E;B!S<&5C:69I960L('5S92!T:&4@
M9&5F875L="!V86QU92X@*B\*("`@("`@("!I9B`H)'!R:6]R:71Y(#T]/2!N
M=6QL*2!["B`@("`@("`@("`@("1P<FEO<FET>2`]("1T:&ES+3Y?<')I;W)I
M='D["B`@("`@("`@?0H*("`@("`@("`O*B!!8F]R="!E87)L>2!I9B!T:&4@
M<')I;W)I='D@:7,@86)O=F4@=&AE(&UA>&EM=6T@;&]G9VEN9R!L979E;"X@
M*B\*("`@("`@("!I9B`H(21T:&ES+3Y?:7--87-K960H)'!R:6]R:71Y*2D@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@
M("`O*B!%>'1R86-T('1H92!S=')I;F<@<F5P<F5S96YT871I;VX@;V8@=&AE
M(&UE<W-A9V4N("HO"B`@("`@("`@)&UE<W-A9V4@/2`D=&AI<RT^7V5X=')A
M8W1-97-S86=E*"1M97-S86=E*3L*"B`@("`@("`@)'-U8V-E<W,@/2!E<G)O
M<E]L;V<H)'1H:7,M/E]I9&5N="`N("<Z("<@+B`D;65S<V%G92P@)'1H:7,M
M/E]T>7!E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M9&5S=&EN871I;VXL("1T:&ES+3Y?97AT<F%?:&5A9&5R<RD["@H@("`@("`@
M("1T:&ES+3Y?86YN;W5N8V4H87)R87DH)W!R:6]R:71Y)R`]/B`D<')I;W)I
M='DL("=M97-S86=E)R`]/B`D;65S<V%G92DI.PH*("`@("`@("!R971U<FX@
M)'-U8V-E<W,["B`@("!]"@I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+TQO9R]F:6QE+G!H<```````````````````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,C$U-C$@,3`U,34T,S,W,S$@,#(P
M-C0R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B`D2&5A9&5R.B`O<F5P;W-I=&]R>2]P96%R+TQO9R],
M;V<O9FEL92YP:'`L=B`Q+C0U(#(P,#8O,#$O,3$@,#<Z-38Z,S<@:F]N($5X
M<"`D"B`J"B`J($!V97)S:6]N("12979I<VEO;CH@,2XT-2`D"B`J($!P86-K
M86=E($QO9PH@*B\*"B\J*@H@*B!4:&4@3&]G7V9I;&4@8VQA<W,@:7,@82!C
M;VYC<F5T92!I;7!L96UE;G1A=&EO;B!O9B!T:&4@3&]G(&%B<W1R86-T"B`J
M(&-L87-S('1H870@;&]G<R!M97-S86=E<R!T;R!A('1E>'0@9FEL92X*("H@
M"B`J($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!P:'`N;F5T/@H@*B!`875T
M:&]R("!2;VUA;B!.975H875S97(@/&YE=6AA=7-E<D!B96QL879I<W1A+F-Z
M/@H@*B!`<VEN8V4@("!,;V<@,2XP"B`J($!P86-K86=E($QO9PH@*@H@*B!`
M97AA;7!L92!F:6QE+G!H<"`@("!5<VEN9R!T:&4@9FEL92!H86YD;&5R+@H@
M*B\*8VQA<W,@3&]G7V9I;&4@97AT96YD<R!,;V<*>PH@("`@+RHJ"B`@("`@
M*B!3=')I;F<@8V]N=&%I;FEN9R!T:&4@;F%M92!O9B!T:&4@;&]G(&9I;&4N
M"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*B\*("`@('9A<B`D7V9I;&5N86UE(#T@)W!H<"YL;V<G.PH*("`@("\J
M*@H@("`@("H@2&%N9&QE('1O('1H92!L;V<@9FEL92X*("`@("`J($!V87(@
M<F5S;W5R8V4*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V
M87(@)%]F<"`](&9A;'-E.PH*("`@("\J*@H@("`@("H@4VAO=6QD(&YE=R!L
M;V<@96YT<FEE<R!B92!A<'!E;F0@=&\@86X@97AI<W1I;F<@;&]G(&9I;&4L
M(&]R('-H;W5L9"!T:&4*("`@("`J(&$@;F5W(&QO9R!F:6QE(&]V97)W<FET
M92!A;B!E>&ES=&EN9R!O;F4_"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]A<'!E;F0@/2!T
M<G5E.PH*("`@("\J*@H@("`@("H@4VAO=6QD(&%D=FES;W)Y(&9I;&4@;&]C
M:VEN9R`H:2YE+BP@9FQO8VLH*2D@8F4@=7-E9#\*("`@("`J($!V87(@8F]O
M;&5A;@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D
M7VQO8VMI;F<@/2!F86QS93L*"B`@("`O*BH*("`@("`J($EN=&5G97(@*&EN
M(&]C=&%L*2!C;VYT86EN:6YG('1H92!L;V<@9FEL92=S('!E<FUI<W-I;VYS
M(&UO9&4N"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("HO"B`@("!V87(@)%]M;V1E(#T@,#8T-#L*"B`@("`O*BH*
M("`@("`J($EN=&5G97(@*&EN(&]C=&%L*2!S<&5C:69Y:6YG('1H92!F:6QE
M('!E<FUI<W-I;VX@;6]D92!T:&%T('=I;&P@8F4*("`@("`J('5S960@=VAE
M;B!C<F5A=&EN9R!D:7)E8W1O<FEE<R!T:&%T(&1O(&YO="!A;')E861Y(&5X
M:7-T+@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@=F%R("1?9&ER;6]D92`](#`W-34["@H@("`@+RHJ
M"B`@("`@*B!3=')I;F<@8V]N=&%I;FEN9R!T:&4@9F]R;6%T(&]F(&$@;&]G
M(&QI;F4N"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*B\*("`@('9A<B`D7VQI;F5&;W)M870@/2`G)3$D<R`E,B1S
M(%LE,R1S72`E-"1S)SL*"B`@("`O*BH*("`@("`J(%-T<FEN9R!C;VYT86EN
M:6YG('1H92!T:6UE<W1A;7`@9F]R;6%T+B`@270@=VEL;"!B92!P87-S960@
M9&ER96-T;'D@=&\*("`@("`J('-T<F9T:6UE*"DN("!.;W1E('1H870@=&AE
M('1I;65S=&%M<"!S=')I;F<@=VEL;"!G96YE<F%T960@=7-I;F<@=&AE"B`@
M("`@*B!C=7)R96YT(&QO8V%L92X*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?=&EM949O<FUA
M="`]("<E8B`E9"`E2#HE33HE4R<["@H@("`@+RHJ"B`@("`@*B!3=')I;F<@
M8V]N=&%I;FEN9R!T:&4@96YD+6]N+6QI;F4@8VAA<F%C=&5R('-E<75E;F-E
M+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("HO"B`@("!V87(@)%]E;VP@/2`B7&XB.PH*("`@("\J*@H@("`@("H@
M0V]N<W1R=6-T<R!A(&YE=R!,;V=?9FEL92!O8FIE8W0N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@26=N;W)E9"X*("`@("`J($!P
M87)A;2!S=')I;F<@)&ED96YT("`@(%1H92!I9&5N=&ET>2!S=')I;F<N"B`@
M("`@*B!`<&%R86T@87)R87D@("1C;VYF("`@("!4:&4@8V]N9FEG=7)A=&EO
M;B!A<G)A>2X*("`@("`J($!P87)A;2!I;G0@("`@)&QE=F5L("`@($QO9R!M
M97-S86=E<R!U<"!T;R!A;F0@:6YC;'5D:6YG('1H:7,@;&5V96PN"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!,;V=?9FEL
M92@D;F%M92P@)&ED96YT(#T@)R<L("1C;VYF(#T@87)R87DH*2P*("`@("`@
M("`@("`@("`@("`@("`@("1L979E;"`](%!%05)?3$]'7T1%0E5'*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?:60@/2!M9#4H;6EC<F]T:6UE*"DI.PH@("`@
M("`@("1T:&ES+3Y?9FEL96YA;64@/2`D;F%M93L*("`@("`@("`D=&AI<RT^
M7VED96YT(#T@)&ED96YT.PH@("`@("`@("1T:&ES+3Y?;6%S:R`]($QO9SHZ
M55!43R@D;&5V96PI.PH*("`@("`@("!I9B`H:7-S970H)&-O;F9;)V%P<&5N
M9"==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V%P<&5N9"`]("1C;VYF6R=A
M<'!E;F0G73L*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D8V]N9ELG
M;&]C:VEN9R==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VQO8VMI;F<@/2`D
M8V]N9ELG;&]C:VEN9R==.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T
M>2@D8V]N9ELG;6]D92==*2D@>PH@("`@("`@("`@("!I9B`H:7-?<W1R:6YG
M*"1C;VYF6R=M;V1E)UTI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VUO
M9&4@/2!O8W1D96,H)&-O;F9;)VUO9&4G72D["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VUO9&4@/2`D8V]N9ELG;6]D
M92==.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H(65M
M<'1Y*"1C;VYF6R=D:7)M;V1E)UTI*2!["B`@("`@("`@("`@(&EF("AI<U]S
M=')I;F<H)&-O;F9;)V1I<FUO9&4G72DI('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?9&ER;6]D92`](&]C=&1E8R@D8V]N9ELG9&ER;6]D92==*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?9&ER
M;6]D92`]("1C;VYF6R=D:7)M;V1E)UT["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(&EF("@A96UP='DH)&-O;F9;)VQI;F5&;W)M870G72DI
M('L*("`@("`@("`@("`@)'1H:7,M/E]L:6YE1F]R;6%T(#T@<W1R7W)E<&QA
M8V4H87)R87E?:V5Y<R@D=&AI<RT^7V9O<FUA=$UA<"DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W9A;'5E
M<R@D=&AI<RT^7V9O<FUA=$UA<"DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1C;VYF6R=L:6YE1F]R;6%T)UTI.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D8V]N9ELG=&EM949O<FUA
M="==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W1I;65&;W)M870@/2`D8V]N
M9ELG=&EM949O<FUA="==.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T
M>2@D8V]N9ELG96]L)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?96]L(#T@
M)&-O;F9;)V5O;"==.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T
M:&ES+3Y?96]L(#T@*'-T<G-T<BA02%!?3U,L("=724XG*2D@/R`B7')<;B(@
M.B`B7&XB.PH@("`@("`@('T*"B`@("`@("`@<F5G:7-T97)?<VAU=&1O=VY?
M9G5N8W1I;VXH87)R87DH)B1T:&ES+"`G7TQO9U]F:6QE)RDI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1&5S=')U8W1O<@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?3&]G7V9I;&4H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V]P96YE
M9"D@>PH@("`@("`@("`@("`D=&AI<RT^8VQO<V4H*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S('1H92!G:79E;B!D:7)E8W1O
M<GD@<&%T:"X@($EF('1H92!P87)E;G0@9&ER96-T;W)I97,@9&]N)W0*("`@
M("`J(&%L<F5A9'D@97AI<W0L('1H97D@=VEL;"!B92!C<F5A=&5D+"!T;V\N
M"B`@("`@*@H@("`@("H@5&AI<R!I;7!L96UE;G1A=&EO;B!I<R!I;G-P:7)E
M9"!B>2!0>71H;VXG<R!O<RYM86ME9&ER<R!F=6YC=&EO;BX*("`@("`J"B`@
M("`@*B!`<&%R86T@("!S=')I;F<@("1P871H("`@("`@(%1H92!F=6QL(&1I
M<F5C=&]R>2!P871H('1O(&-R96%T92X*("`@("`J($!P87)A;2`@(&EN=&5G
M97(@)&UO9&4@("`@("`@5&AE('!E<FUI<W-I;VYS(&UO9&4@=VET:"!W:&EC
M:"!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9&ER
M96-T;W)I97,@=VEL;"!B92!C<F5A=&5D+@H@("`@("H*("`@("`J($!R971U
M<FX@(%1R=64@:68@=&AE(&9U;&P@<&%T:"!I<R!S=6-C97-S9G5L;'D@8W)E
M871E9"!O<B!A;')E861Y"B`@("`@*B`@("`@("`@("!E>&ES=',N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO
M;B!?;6MP871H*"1P871H+"`D;6]D92`](#`W,#`I"B`@("!["B`@("`@("`@
M+RH@4V5P87)A=&4@=&AE(&QA<W0@<&%T:&YA;64@8V]M<&]N96YT(&9R;VT@
M=&AE(')E<W0@;V8@=&AE('!A=&@N("HO"B`@("`@("`@)&AE860@/2!D:7)N
M86UE*"1P871H*3L*("`@("`@("`D=&%I;"`](&)A<V5N86UE*"1P871H*3L*
M"B`@("`@("`@+RH@36%K92!S=7)E('=E)W9E('-P;&ET('1H92!P871H(&EN
M=&\@='=O(&-O;7!L971E(&-O;7!O;F5N=',N("HO"B`@("`@("`@:68@*&5M
M<'1Y*"1T86EL*2D@>PH@("`@("`@("`@("`D:&5A9"`](&1I<FYA;64H)'!A
M=&@I.PH@("`@("`@("`@("`D=&%I;"`](&)A<V5N86UE*"1P871H*3L*("`@
M("`@("!]"@H@("`@("`@("\J(%)E8W5R<V4@=7`@=&AE('!A=&@@:68@;W5R
M(&-U<G)E;G0@<V5G;65N="!D;V5S(&YO="!E>&ES="X@*B\*("`@("`@("!I
M9B`H(65M<'1Y*"1H96%D*2`F)B`A96UP='DH)'1A:6PI("8F("%I<U]D:7(H
M)&AE860I*2!["B`@("`@("`@("`@("1T:&ES+3Y?;6MP871H*"1H96%D+"`D
M;6]D92D["B`@("`@("`@?0H*("`@("`@("`O*B!#<F5A=&4@=&AI<R!S96=M
M96YT(&]F('1H92!P871H+B`J+PH@("`@("`@(')E='5R;B!`;6MD:7(H)&AE
M860L("1M;V1E*3L*("`@('T*"B`@("`O*BH*("`@("`J($]P96YS('1H92!L
M;V<@9FEL92!F;W(@;W5T<'5T+B`@268@=&AE('-P96-I9FEE9"!L;V<@9FEL
M92!D;V5S(&YO=`H@("`@("H@86QR96%D>2!E>&ES="P@:70@=VEL;"!B92!C
M<F5A=&5D+B`@0GD@9&5F875L="P@;F5W(&QO9R!E;G1R:65S(&%R90H@("`@
M("H@87!P96YD960@=&\@=&AE(&5N9"!O9B!T:&4@;&]G(&9I;&4N"B`@("`@
M*@H@("`@("H@5&AI<R!I<R!I;7!L:6-I=&QY(&-A;&QE9"!B>2!L;V<H*2P@
M:68@;F5C97-S87)Y+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&]P96XH*0H@("`@>PH@("`@("`@(&EF("@A
M)'1H:7,M/E]O<&5N960I('L*("`@("`@("`@("`@+RH@268@=&AE(&QO9R!F
M:6QE)W,@9&ER96-T;W)Y(&1O97-N)W0@97AI<W0L(&-R96%T92!I="X@*B\*
M("`@("`@("`@("`@:68@*"%I<U]D:7(H9&ER;F%M92@D=&AI<RT^7V9I;&5N
M86UE*2DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;6MP871H*"1T:&ES
M+3Y?9FEL96YA;64L("1T:&ES+3Y?9&ER;6]D92D["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("\J($1E=&5R;6EN92!W:&5T:&5R('1H92!L;V<@9FEL
M92!N965D<R!T;R!B92!C<F5A=&5D+B`J+PH@("`@("`@("`@("`D8W)E871I
M;F<@/2`A9FEL95]E>&ES=',H)'1H:7,M/E]F:6QE;F%M92D["@H@("`@("`@
M("`@("`O*B!/8G1A:6X@82!H86YD;&4@=&\@=&AE(&QO9R!F:6QE+B`J+PH@
M("`@("`@("`@("`D=&AI<RT^7V9P(#T@9F]P96XH)'1H:7,M/E]F:6QE;F%M
M92P@*"1T:&ES+3Y?87!P96YD*2`_("=A)R`Z("=W)RD["@H@("`@("`@("`@
M("`O*B!792!C;VYS:61E<B!T:&4@9FEL92`B;W!E;F5D(B!I9B!W92!H879E
M(&$@=F%L:60@9FEL92!P;VEN=&5R+B`J+PH@("`@("`@("`@("`D=&AI<RT^
M7V]P96YE9"`]("@D=&AI<RT^7V9P("$]/2!F86QS92D["@H@("`@("`@("`@
M("`O*B!!='1E;7!T('1O('-E="!T:&4@9FEL92=S('!E<FUI<W-I;VYS(&EF
M('=E(&IU<W0@8W)E871E9"!I="X@*B\*("`@("`@("`@("`@:68@*"1C<F5A
M=&EN9R`F)B`D=&AI<RT^7V]P96YE9"D@>PH@("`@("`@("`@("`@("`@8VAM
M;V0H)'1H:7,M/E]F:6QE;F%M92P@)'1H:7,M/E]M;V1E*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;W!E;F5D
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0VQO<V5S('1H92!L;V<@9FEL92!I
M9B!I="!I<R!O<&5N+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&-L;W-E*"D*("`@('L*("`@("`@("`O*B!)
M9B!T:&4@;&]G(&9I;&4@:7,@;W!E;BP@8VQO<V4@:70N("HO"B`@("`@("`@
M:68@*"1T:&ES+3Y?;W!E;F5D("8F(&9C;&]S92@D=&AI<RT^7V9P*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7V]P96YE9"`](&9A;'-E.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("@D=&AI<RT^7V]P96YE9"`]/3T@9F%L<V4I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1FQU<VAE<R!A;&P@<&5N9&EN9R!D871A
M('1O('1H92!F:6QE(&AA;F1L92X*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("H@0'-I;F-E($QO9R`Q+C@N,@H@("`@("HO"B`@("!F=6YC
M=&EO;B!F;'5S:"@I"B`@("!["B`@("`@("`@<F5T=7)N(&9F;'5S:"@D=&AI
M<RT^7V9P*3L*("`@('T*"B`@("`O*BH*("`@("`J($QO9W,@)&UE<W-A9V4@
M=&\@=&AE(&]U='!U="!W:6YD;W<N("!4:&4@;65S<V%G92!I<R!A;'-O('!A
M<W-E9"!A;&]N9PH@("`@("H@=&\@86YY($QO9U]O8G-E<G9E<B!I;G-T86YC
M97,@=&AA="!A<F4@;V)S97)V:6YG('1H:7,@3&]G+@H@("`@("H*("`@("`J
M($!P87)A;2!M:7AE9"`@)&UE<W-A9V4@(%-T<FEN9R!O<B!O8FIE8W0@8V]N
M=&%I;FEN9R!T:&4@;65S<V%G92!T;R!L;V<N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1P<FEO<FET>2!4:&4@<')I;W)I='D@;V8@=&AE(&UE<W-A9V4N("!6
M86QI9`H@("`@("H@("`@("`@("`@("`@("`@("!V86QU97,@87)E.B!014%2
M7TQ/1U]%34521RP@4$5!4E],3T=?04Q%4E0L"B`@("`@*B`@("`@("`@("`@
M("`@("`@(%!%05)?3$]'7T-2250L(%!%05)?3$]'7T524BP@4$5!4E],3T=?
M5T%23DE.1RP*("`@("`J("`@("`@("`@("`@("`@("`@4$5!4E],3T=?3D]4
M24-%+"!014%27TQ/1U])3D9/+"!A;F0@4$5!4E],3T=?1$5"54<N"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<R!O<B!F86QS92!O
M;B!F86EL=7)E+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@;&]G*"1M97-S86=E+"`D<')I;W)I='D@/2!N=6QL*0H@("`@
M>PH@("`@("`@("\J($EF(&$@<')I;W)I='D@:&%S;B=T(&)E96X@<W!E8VEF
M:65D+"!U<V4@=&AE(&1E9F%U;'0@=F%L=64N("HO"B`@("`@("`@:68@*"1P
M<FEO<FET>2`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D<')I;W)I='D@/2`D
M=&AI<RT^7W!R:6]R:71Y.PH@("`@("`@('T*"B`@("`@("`@+RH@06)O<G0@
M96%R;'D@:68@=&AE('!R:6]R:71Y(&ES(&%B;W9E('1H92!M87AI;75M(&QO
M9V=I;F<@;&5V96PN("HO"B`@("`@("`@:68@*"$D=&AI<RT^7VES36%S:V5D
M*"1P<FEO<FET>2DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*"B`@("`@("`@+RH@268@=&AE(&QO9R!F:6QE(&ES;B=T(&%L<F5A
M9'D@;W!E;BP@;W!E;B!I="!N;W<N("HO"B`@("`@("`@:68@*"$D=&AI<RT^
M7V]P96YE9"`F)B`A)'1H:7,M/F]P96XH*2D@>PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O*B!%>'1R86-T('1H92!S
M=')I;F<@<F5P<F5S96YT871I;VX@;V8@=&AE(&UE<W-A9V4N("HO"B`@("`@
M("`@)&UE<W-A9V4@/2`D=&AI<RT^7V5X=')A8W1-97-S86=E*"1M97-S86=E
M*3L*"B`@("`@("`@+RH@0G5I;&0@=&AE('-T<FEN9R!C;VYT86EN:6YG('1H
M92!C;VUP;&5T92!L;V<@;&EN92X@*B\*("`@("`@("`D;&EN92`]("1T:&ES
M+3Y?9F]R;6%T*"1T:&ES+3Y?;&EN949O<FUA="P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('-T<F9T:6UE*"1T:&ES+3Y?=&EM949O<FUA="DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<')I;W)I='DL("1M
M97-S86=E*2`N("1T:&ES+3Y?96]L.PH*("`@("`@("`O*B!)9B!L;V-K:6YG
M(&ES(&5N86)L960L(&%C<75I<F4@86X@97AC;'5S:79E(&QO8VL@;VX@=&AE
M(&9I;&4N("HO"B`@("`@("`@:68@*"1T:&ES+3Y?;&]C:VEN9RD@>PH@("`@
M("`@("`@("!F;&]C:R@D=&AI<RT^7V9P+"!,3T-+7T58*3L*("`@("`@("!]
M"@H@("`@("`@("\J(%=R:71E('1H92!L;V<@;&EN92!T;R!T:&4@;&]G(&9I
M;&4N("HO"B`@("`@("`@)'-U8V-E<W,@/2`H9G=R:71E*"1T:&ES+3Y?9G`L
M("1L:6YE*2`A/3T@9F%L<V4I.PH*("`@("`@("`O*B!5;FQO8VL@=&AE(&9I
M;&4@;F]W('1H870@=V4G<F4@9FEN:7-H960@=W)I=&EN9R!T;R!I="X@*B\@
M"B`@("`@("`@:68@*"1T:&ES+3Y?;&]C:VEN9RD@>PH@("`@("`@("`@("!F
M;&]C:R@D=&AI<RT^7V9P+"!,3T-+7U5.*3L*("`@("`@("!]"@H@("`@("`@
M("\J($YO=&EF>2!O8G-E<G9E<G,@86)O=70@=&AI<R!L;V<@;65S<V%G92X@
M*B\*("`@("`@("`D=&AI<RT^7V%N;F]U;F-E*&%R<F%Y*"=P<FEO<FET>2<@
M/3X@)'!R:6]R:71Y+"`G;65S<V%G92<@/3X@)&UE<W-A9V4I*3L*"B`@("`@
M("`@<F5T=7)N("1S=6-C97-S.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O3&]G+VUA:6PN<&AP````````````````
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q-C`P,R`Q,#4Q-30S
M,S<S,2`P,C`V-#``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J("1(96%D97(Z("]R97!O<VET;W)Y+W!E
M87(O3&]G+TQO9R]M86EL+G!H<"QV(#$N,C0@,C`P-B\P,2\S,"`P-3HS-SHQ
M."!J;VX@17AP("0*("H*("H@0'9E<G-I;VX@)%)E=FES:6]N.B`Q+C(T("0*
M("H@0'!A8VMA9V4@3&]G"B`J+PH*+RHJ"B`J(%1H92!,;V=?;6%I;"!C;&%S
M<R!I<R!A(&-O;F-R971E(&EM<&QE;65N=&%T:6]N(&]F('1H92!,;V<Z.B!A
M8G-T<F%C="!C;&%S<PH@*B!W:&EC:"!S96YD<R!L;V<@;65S<V%G97,@=&\@
M82!M86EL8F]X+@H@*B!4:&4@;6%I;"!I<R!A8W1U86QL>2!S96YT('=H96X@
M>6]U(&-L;W-E*"D@=&AE(&QO9V=E<BP@;W(@=VAE;B!T:&4@9&5S=')U8W1O
M<@H@*B!I<R!C86QL960@*'=H96X@=&AE('-C<FEP="!I<R!T97)M:6YA=&5D
M*2X*("H*("H@4$Q%05-%($Y/5$4@=&AA="!Y;W4@;75S="!C<F5A=&4@82!,
M;V=?;6%I;"!O8FIE8W0@=7-I;F<@/28L(&QI:V4@=&AI<R`Z"B`J("`D;&]G
M9V5R(#TF($QO9SHZ9F%C=&]R>2@B;6%I;"(L(")R96-I<&EE;G1`97AA;7!L
M92YC;VTB+"`N+BXI"B`J"B`J(%1H:7,@:7,@82!014%2(')E<75I<F5M96YT
M(&9O<B!D97-T<G5C=&]R<R!T;R!W;W)K('!R;W!E<FQY+@H@*B!3964@:'1T
M<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO8VQA<W,N<&5A<BYP:'`*("H*
M("H@0&%U=&AO<B`@4F]N;FEE($=A<F-I82`\<F]N;FEE0&UK,BYN970^"B`J
M($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!P:'`N;F5T/@H@*B!`<VEN8V4@
M("!,;V<@,2XS"B`J($!P86-K86=E($QO9PH@*@H@*B!`97AA;7!L92!M86EL
M+G!H<"`@("!5<VEN9R!T:&4@;6%I;"!H86YD;&5R+@H@*B\*8VQA<W,@3&]G
M7VUA:6P@97AT96YD<R!,;V<*>PH@("`@+RHJ"B`@("`@*B!3=')I;F<@:&]L
M9&EN9R!T:&4@<F5C:7!I96YT)W,@96UA:6P@861D<F5S<RX*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@
M=F%R("1?<F5C:7!I96YT(#T@)R<["@H@("`@+RHJ"B`@("`@*B!3=')I;F<@
M:&]L9&EN9R!T:&4@<V5N9&5R)W,@96UA:6P@861D<F5S<RX*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@
M=F%R("1?9G)O;2`]("<G.PH*("`@("\J*@H@("`@("H@4W1R:6YG(&AO;&1I
M;F<@=&AE(&5M86EL)W,@<W5B:F5C="X*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?<W5B:F5C
M="`]("=;3&]G7VUA:6Q=($QO9R!M97-S86=E)SL*"B`@("`O*BH*("`@("`J
M(%-T<FEN9R!H;VQD:6YG(&%N(&]P=&EO;F%L('!R96%M8FQE(&9O<B!T:&4@
M;&]G(&UE<W-A9V5S+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]P<F5A;6)L92`]("<G.PH*
M("`@("\J*@H@("`@("H@4W1R:6YG(&-O;G1A:6YI;F<@=&AE(&9O<FUA="!O
M9B!A(&QO9R!L:6YE+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]L:6YE1F]R;6%T(#T@)R4Q
M)',@)3(D<R!;)3,D<UT@)30D<R<["@H@("`@+RHJ"B`@("`@*B!3=')I;F<@
M8V]N=&%I;FEN9R!T:&4@=&EM97-T86UP(&9O<FUA="X@($ET('=I;&P@8F4@
M<&%S<V5D(&1I<F5C=&QY('1O"B`@("`@*B!S=')F=&EM92@I+B`@3F]T92!T
M:&%T('1H92!T:6UE<W1A;7`@<W1R:6YG('=I;&P@9V5N97)A=&5D('5S:6YG
M('1H90H@("`@("H@8W5R<F5N="!L;V-A;&4N"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7W1I
M;65&;W)M870@/2`G)6(@)60@)4@Z)4TZ)5,G.PH*("`@("\J*@H@("`@("H@
M4W1R:6YG(&AO;&1I;F<@=&AE(&UA:6P@;65S<V%G92!B;V1Y+@H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@
M("!V87(@)%]M97-S86=E(#T@)R<["@H*("`@("\J*@H@("`@("H@0V]N<W1R
M=6-T<R!A(&YE=R!,;V=?;6%I;"!O8FIE8W0N"B`@("`@*@H@("`@("H@2&5R
M92!I<R!H;W<@>6]U(&-A;B!C=7-T;VUI>F4@=&AE(&UA:6P@9')I=F5R('=I
M=&@@=&AE(&-O;F9;72!H87-H(#H*("`@("`J("`@)&-O;F9;)V9R;VTG72`@
M("`Z('1H92!M86EL)W,@(D9R;VTB(&AE861E<B!L:6YE+`H@("`@("H@("`D
M8V]N9ELG<W5B:F5C="==(#H@=&AE(&UA:6PG<R`B4W5B:F5C="(@;&EN92X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@5&AE(&9I
M;&5N86UE(&]F('1H92!L;V=F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M:61E;G0@("`@(%1H92!I9&5N=&ET>2!S=')I;F<N"B`@("`@*B!`<&%R86T@
M87)R87D@("1C;VYF("`@("`@5&AE(&-O;F9I9W5R871I;VX@87)R87DN"B`@
M("`@*B!`<&%R86T@:6YT("`@("1L979E;"`@("`@3&]G(&UE<W-A9V5S('5P
M('1O(&%N9"!I;F-L=61I;F<@=&AI<R!L979E;"X*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N($QO9U]M86EL*"1N86UE+"`D
M:61E;G0@/2`G)RP@)&-O;F8@/2!A<G)A>2@I+`H@("`@("`@("`@("`@("`@
M("`@("`@)&QE=F5L(#T@4$5!4E],3T=?1$5"54<I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]I9"`](&UD-2AM:6-R;W1I;64H*2D["B`@("`@("`@)'1H:7,M
M/E]R96-I<&EE;G0@/2`D;F%M93L*("`@("`@("`D=&AI<RT^7VED96YT(#T@
M)&ED96YT.PH@("`@("`@("1T:&ES+3Y?;6%S:R`]($QO9SHZ55!43R@D;&5V
M96PI.PH*("`@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=F<F]M)UTI*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?9G)O;2`]("1C;VYF6R=F<F]M)UT["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]F<F]M(#T@:6YI7V=E
M="@G<V5N9&UA:6Q?9G)O;2<I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E
M;7!T>2@D8V]N9ELG<W5B:F5C="==*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7W-U8FIE8W0@/2`D8V]N9ELG<W5B:F5C="==.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"%E;7!T>2@D8V]N9ELG<')E86UB;&4G72DI('L*("`@("`@("`@
M("`@)'1H:7,M/E]P<F5A;6)L92`]("1C;VYF6R=P<F5A;6)L92==.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D8V]N9ELG;&EN949O<FUA="==
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VQI;F5&;W)M870@/2!S=')?<F5P
M;&%C92AA<G)A>5]K97ES*"1T:&ES+3Y?9F]R;6%T36%P*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87E?=F%L
M=65S*"1T:&ES+3Y?9F]R;6%T36%P*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&-O;F9;)VQI;F5&;W)M870G72D[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=T:6UE1F]R
M;6%T)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?=&EM949O<FUA="`]("1C
M;VYF6R=T:6UE1F]R;6%T)UT["B`@("`@("`@?0H*("`@("`@("`O*B!R96=I
M<W1E<B!T:&4@9&5S=')U8W1O<B`J+PH@("`@("`@(')E9VES=&5R7W-H=71D
M;W=N7V9U;F-T:6]N*&%R<F%Y*"8D=&AI<RP@)U],;V=?;6%I;"<I*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($1E<W1R=6-T;W(N($-A;&QS(&-L;W-E*"DN
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%],;V=?;6%I;"@I"B`@("!["B`@("`@("`@)'1H:7,M/F-L;W-E
M*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3=&%R=',@82!N97<@;6%I;"!M
M97-S86=E+@H@("`@("H@5&AI<R!I<R!I;7!L:6-I=&QY(&-A;&QE9"!B>2!L
M;V<H*2P@:68@;F5C97-S87)Y+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&]P96XH*0H@("`@>PH@("`@("`@
M(&EF("@A)'1H:7,M/E]O<&5N960I('L*("`@("`@("`@("`@:68@*"%E;7!T
M>2@D=&AI<RT^7W!R96%M8FQE*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]M97-S86=E(#T@)'1H:7,M/E]P<F5A;6)L92`N(")<<EQN7')<;B(["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]O<&5N960@/2!T<G5E
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;W!E;F5D.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0VQO<V5S('1H92!M97-S86=E+"!I9B!I
M="!I<R!O<&5N+"!A;F0@<V5N9',@=&AE(&UA:6PN"B`@("`@*B!4:&ES(&ES
M(&EM<&QI8VET;'D@8V%L;&5D(&)Y('1H92!D97-T<G5C=&]R+"!I9B!N96-E
M<W-A<GDN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@8VQO<V4H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^
M7V]P96YE9"D@>PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?;65S
M<V%G92DI('L*("`@("`@("`@("`@("`@("1H96%D97)S(#T@(D9R;VTZ("1T
M:&ES+3Y?9G)O;5QR7&XB.PH@("`@("`@("`@("`@("`@)&AE861E<G,@+CT@
M(E5S97(M06=E;G0Z($QO9U]M86EL(CL*"B`@("`@("`@("`@("`@("!I9B`H
M;6%I;"@D=&AI<RT^7W)E8VEP:65N="P@)'1H:7,M/E]S=6)J96-T+"`D=&AI
M<RT^7VUE<W-A9V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`D:&5A9&5R
M<RD@/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("!E<G)O<E]L;V<H
M(DQO9U]M86EL.B!&86EL=7)E(&5X96-U=&EN9R!M86EL*"DB+"`P*3L*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`@("`@+RH@0VQE87(@=&AE(&UE<W-A9V4@<W1R
M:6YG(&YO=R!T:&%T('1H92!E;6%I;"!H87,@8F5E;B!S96YT+B`J+PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]M97-S86=E(#T@)R<["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)'1H:7,M/E]O<&5N960@/2!F86QS93L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`H)'1H:7,M/E]O<&5N960@/3T](&9A;'-E
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($9L=7-H97,@=&AE(&QO9R!O=71P
M=70@8GD@9F]R8VEN9R!T:&4@96UA:6P@;65S<V%G92!T;R!B92!S96YT(&YO
M=RX*("`@("`J($5V96YT<R!T:&%T(&%R92!L;V=G960@869T97(@9FQU<V@H
M*2!I<R!C86QL960@=VEL;"!B92!A<'!E;F1E9"!T;R!A"B`@("`@*B!N97<@
M96UA:6P@;65S<V%G92X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("H@0'-I;F-E($QO9R`Q+C@N,@H@("`@("HO"B`@("!F=6YC=&EO;B!F
M;'5S:"@I"B`@("!["B`@("`@("`@+RH*("`@("`@("`@*B!)="=S('-U9F9I
M8VEE;G0@=&\@<VEM<&QY(&-A;&P@8VQO<V4H*2!T;R!F;'5S:"!T:&4@;W5T
M<'5T+@H@("`@("`@("`J(%1H92!N97AT(&-A;&P@=&\@;&]G*"D@=VEL;"!C
M875S92!T:&4@:&%N9&QE<B!T;R!B92!R96]P96YE9"X*("`@("`@("`@*B\*
M("`@("`@("!R971U<FX@)'1H:7,M/F-L;W-E*"D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!7<FET97,@)&UE<W-A9V4@=&\@=&AE(&-U<G)E;G1L>2!O<&5N
M(&UA:6P@;65S<V%G92X*("`@("`J($-A;&QS(&]P96XH*2P@:68@;F5C97-S
M87)Y+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`@)&UE<W-A9V4@(%-T
M<FEN9R!O<B!O8FIE8W0@8V]N=&%I;FEN9R!T:&4@;65S<V%G92!T;R!L;V<N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1P<FEO<FET>2!4:&4@<')I;W)I='D@
M;V8@=&AE(&UE<W-A9V4N("!686QI9`H@("`@("H@("`@("`@("`@("`@("`@
M("!V86QU97,@87)E.B!014%27TQ/1U]%34521RP@4$5!4E],3T=?04Q%4E0L
M"B`@("`@*B`@("`@("`@("`@("`@("`@(%!%05)?3$]'7T-2250L(%!%05)?
M3$]'7T524BP@4$5!4E],3T=?5T%23DE.1RP*("`@("`J("`@("`@("`@("`@
M("`@("`@4$5!4E],3T=?3D]424-%+"!014%27TQ/1U])3D9/+"!A;F0@4$5!
M4E],3T=?1$5"54<N"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@
M<W5C8V5S<R!O<B!F86QS92!O;B!F86EL=7)E+@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@;&]G*"1M97-S86=E+"`D<')I
M;W)I='D@/2!N=6QL*0H@("`@>PH@("`@("`@("\J($EF(&$@<')I;W)I='D@
M:&%S;B=T(&)E96X@<W!E8VEF:65D+"!U<V4@=&AE(&1E9F%U;'0@=F%L=64N
M("HO"B`@("`@("`@:68@*"1P<FEO<FET>2`]/3T@;G5L;"D@>PH@("`@("`@
M("`@("`D<')I;W)I='D@/2`D=&AI<RT^7W!R:6]R:71Y.PH@("`@("`@('T*
M"B`@("`@("`@+RH@06)O<G0@96%R;'D@:68@=&AE('!R:6]R:71Y(&ES(&%B
M;W9E('1H92!M87AI;75M(&QO9V=I;F<@;&5V96PN("HO"B`@("`@("`@:68@
M*"$D=&AI<RT^7VES36%S:V5D*"1P<FEO<FET>2DI('L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+RH@268@=&AE(&UE
M<W-A9V4@:7-N)W0@;W!E;B!A;F0@8V%N)W0@8F4@;W!E;F5D+"!R971U<FX@
M9F%I;'5R92X@*B\*("`@("`@("!I9B`H(21T:&ES+3Y?;W!E;F5D("8F("$D
M=&AI<RT^;W!E;B@I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@("\J($5X=')A8W0@=&AE('-T<FEN9R!R97!R97-E
M;G1A=&EO;B!O9B!T:&4@;65S<V%G92X@*B\*("`@("`@("`D;65S<V%G92`]
M("1T:&ES+3Y?97AT<F%C=$UE<W-A9V4H)&UE<W-A9V4I.PH*("`@("`@("`O
M*B!"=6EL9"!T:&4@<W1R:6YG(&-O;G1A:6YI;F<@=&AE(&-O;7!L971E(&QO
M9R!L:6YE+B`J+PH@("`@("`@("1T:&ES+3Y?;65S<V%G92`N/2`D=&AI<RT^
M7V9O<FUA="@D=&AI<RT^7VQI;F5&;W)M870L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('-T<F9T:6UE*"1T:&ES+3Y?=&EM
M949O<FUA="DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1P<FEO<FET>2P@)&UE<W-A9V4I("X@(EQR7&XB.PH*("`@("`@
M("`O*B!.;W1I9GD@;V)S97)V97)S(&%B;W5T('1H:7,@;&]G(&UE<W-A9V4N
M("HO"B`@("`@("`@)'1H:7,M/E]A;FYO=6YC92AA<G)A>2@G<')I;W)I='DG
M(#T^("1P<FEO<FET>2P@)VUE<W-A9V4G(#T^("1M97-S86=E*2D["@H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B],;V<O;6-A;"YP:'``````````````
M````````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$Q-3(U(#$P-3$U
M-#,S-S,Q(#`R,#8S-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@)$AE861E<CH@+W)E<&]S:71O<GDO
M<&5A<B],;V<O3&]G+VUC86PN<&AP+'8@,2XQ."`R,#`U+S`R+S(V(#$T.C0X
M.C4X(&-H86=E;F)U($5X<"`D"B`J("1(;W)D93H@:&]R9&4O;&EB+TQO9R]M
M8V%L+G!H<"QV(#$N,B`R,#`P+S`V+S(X(#(Q.C,V.C$S(&IO;B!%>'`@)`H@
M*@H@*B!`=F5R<VEO;B`D4F5V:7-I;VXZ(#$N,3@@)`H@*B!`<&%C:V%G92!,
M;V<*("HO"@HO*BH*("H@5&AE($QO9U]M8V%L(&-L87-S(&ES(&$@8V]N8W)E
M=&4@:6UP;&5M96YT871I;VX@;V8@=&AE($QO9SHZ"B`J(&%B<W1R86-T(&-L
M87-S('=H:6-H('-E;F1S(&UE<W-A9V5S('1O(&$@;&]C86P@;W(@<F5M;W1E
M(&-A;&5N9&%R"B`J('-T;W)E(&%C8V5S<V5D('1H<F]U9V@@34-!3"X*("H*
M("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J($!S:6YC92!(;W)D92`Q+C,*("H@0'-I;F-E($QO9R`Q+C`*("H@0'!A
M8VMA9V4@3&]G"B`J+PIC;&%S<R!,;V=?;6-A;"!E>'1E;F1S($QO9PI["B`@
M("`O*BH*("`@("`J(&AO;&1I;F<@=&AE(&-A;&5N9&%R('-P96-I9FEC871I
M;VX@=&\@8V]N;F5C="!T;RX*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?8V%L96YD87(@/2`G
M>VQO8V%L:&]S="]M<W1O<F5])SL*"B`@("`O*BH*("`@("`J(&AO;&1I;F<@
M=&AE('5S97)N86UE('1O('5S92X*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?=7-E<FYA;64@
M/2`G)SL*"B`@("`O*BH*("`@("`J(&AO;&1I;F<@=&AE('!A<W-W;W)D('1O
M('5S92X*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@=F%R("1?<&%S<W=O<F0@/2`G)SL*"B`@("`O*BH*
M("`@("`J(&AO;&1I;F<@=&AE(&]P=&EO;G,@=&\@<&%S<R!T;R!T:&4@8V%L
M96YD87(@<W1R96%M+@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?;W!T:6]N<R`](#`["@H@
M("`@+RHJ"B`@("`@*B!297-O=7)C94E$(&]F('1H92!-0T%,('-T<F5A;2X*
M("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J+PH@("`@=F%R("1?<W1R96%M(#T@)R<["@H@("`@+RHJ"B`@("`@*B!)
M;G1E9V5R(&AO;&1I;F<@=&AE(&QO9R!F86-I;&ET>2!T;R!U<V4N"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@('9A<B`D7VYA;64@/2!,3T=?4UE33$]'.PH*"B`@("`O*BH*("`@("`J
M($-O;G-T<G5C=',@82!N97<@3&]G7VUC86P@;V)J96-T+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@(%1H92!C871E9V]R>2!T;R!U
M<V4@9F]R(&]U<B!E=F5N=',N"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9&5N
M="`@("!4:&4@:61E;G1I='D@<W1R:6YG+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("`D8V]N9B`@("`@5&AE(&-O;F9I9W5R871I;VX@87)R87DN"B`@("`@*B!`
M<&%R86T@:6YT("`@("1L979E;"`@("!,;V<@;65S<V%G97,@=7`@=&\@86YD
M(&EN8VQU9&EN9R!T:&ES(&QE=F5L+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@3&]G7VUC86PH)&YA;64L("1I9&5N="`]
M("<G+"`D8V]N9B`](&%R<F%Y*"DL"B`@("`@("`@("`@("`@("`@("`@("`D
M;&5V96P@/2!014%27TQ/1U]$14)51RD*("`@('L*("`@("`@("`D=&AI<RT^
M7VED(#T@;60U*&UI8W)O=&EM92@I*3L*("`@("`@("`D=&AI<RT^7VYA;64@
M/2`D;F%M93L*("`@("`@("`D=&AI<RT^7VED96YT(#T@)&ED96YT.PH@("`@
M("`@("1T:&ES+3Y?;6%S:R`]($QO9SHZ55!43R@D;&5V96PI.PH@("`@("`@
M("1T:&ES+3Y?8V%L96YD87(@/2`D8V]N9ELG8V%L96YD87(G73L*("`@("`@
M("`D=&AI<RT^7W5S97)N86UE(#T@)&-O;F9;)W5S97)N86UE)UT["B`@("`@
M("`@)'1H:7,M/E]P87-S=V]R9"`]("1C;VYF6R=P87-S=V]R9"==.PH@("`@
M("`@("1T:&ES+3Y?;W!T:6]N<R`]("1C;VYF6R=O<'1I;VYS)UT["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!/<&5N<R!A(&-A;&5N9&%R('-T<F5A;2P@:68@
M:70@:&%S(&YO="!A;')E861Y(&)E96X*("`@("`J(&]P96YE9"X@5&AI<R!I
M<R!I;7!L:6-I=&QY(&-A;&QE9"!B>2!L;V<H*2P@:68@;F5C97-S87)Y+@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@;W!E
M;B@I"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^7V]P96YE9"D@>PH@("`@
M("`@("`@("`D=&AI<RT^7W-T<F5A;2`](&UC86Q?;W!E;B@D=&AI<RT^7V-A
M;&5N9&%R+"`D=&AI<RT^7W5S97)N86UE+`H@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P87-S=V]R9"P@)'1H:7,M/E]O<'1I;VYS*3L*("`@("`@("`@("`@
M)'1H:7,M/E]O<&5N960@/2!T<G5E.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?;W!E;F5D.PH@("`@?0H*("`@("\J*@H@("`@("H@0VQO
M<V5S('1H92!C86QE;F1A<B!S=')E86TL(&EF(&ET(&ES(&]P96XN"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!C;&]S92@I
M"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?;W!E;F5D*2!["B`@("`@("`@
M("`@(&UC86Q?8VQO<V4H)'1H:7,M/E]S=')E86TI.PH@("`@("`@("`@("`D
M=&AI<RT^7V]P96YE9"`](&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("@D=&AI<RT^7V]P96YE9"`]/3T@9F%L<V4I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@3&]G<R`D;65S<V%G92!A;F0@87-S;V-I871E9"!I;F9O<FUA
M=&EO;B!T;R!T:&4@8W5R<F5N=&QY(&]P96X*("`@("`J(&-A;&5N9&%R('-T
M<F5A;2X@0V%L;',@;W!E;B@I(&EF(&YE8V5S<V%R>2X@06QS;R!P87-S97,@
M=&AE"B`@("`@*B!M97-S86=E(&%L;VYG('1O(&%N>2!,;V=?;V)S97)V97(@
M:6YS=&%N8V5S('1H870@87)E(&]B<V5R=FEN9PH@("`@("H@=&AI<R!,;V<N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("`D;65S<V%G92`@4W1R:6YG
M(&]R(&]B:F5C="!C;VYT86EN:6YG('1H92!M97-S86=E('1O(&QO9RX*("`@
M("`J($!P87)A;2!S=')I;F<@)'!R:6]R:71Y(%1H92!P<FEO<FET>2!O9B!T
M:&4@;65S<V%G92X@5F%L:60*("`@("`J("`@("`@("`@("`@("`@("`@=F%L
M=65S(&%R93H@4$5!4E],3T=?14U%4D<L(%!%05)?3$]'7T%,15)4+`H@("`@
M("H@("`@("`@("`@("`@("`@("!014%27TQ/1U]#4DE4+"!014%27TQ/1U]%
M4E(L(%!%05)?3$]'7U=!4DY)3D<L"B`@("`@*B`@("`@("`@("`@("`@("`@
M(%!%05)?3$]'7TY/5$E#12P@4$5!4E],3T=?24Y&3RP@86YD(%!%05)?3$]'
M7T1%0E5'+@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E
M<W,@;W(@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&QO9R@D;65S<V%G92P@)'!R:6]R:71Y
M(#T@;G5L;"D*("`@('L*("`@("`@("`O*B!)9B!A('!R:6]R:71Y(&AA<VXG
M="!B965N('-P96-I9FEE9"P@=7-E('1H92!D969A=6QT('9A;'5E+B`J+PH@
M("`@("`@(&EF("@D<')I;W)I='D@/3T](&YU;&PI('L*("`@("`@("`@("`@
M)'!R:6]R:71Y(#T@)'1H:7,M/E]P<FEO<FET>3L*("`@("`@("!]"@H@("`@
M("`@("\J($%B;W)T(&5A<FQY(&EF('1H92!P<FEO<FET>2!I<R!A8F]V92!T
M:&4@;6%X:6UU;2!L;V=G:6YG(&QE=F5L+B`J+PH@("`@("`@(&EF("@A)'1H
M:7,M/E]I<TUA<VME9"@D<')I;W)I='DI*2!["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("\J($EF('1H92!C;VYN96-T
M:6]N(&ES;B=T(&]P96X@86YD(&-A;B=T(&)E(&]P96YE9"P@<F5T=7)N(&9A
M:6QU<F4N("HO"B`@("`@("`@:68@*"$D=&AI<RT^7V]P96YE9"`F)B`A)'1H
M:7,M/F]P96XH*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("`O*B!%>'1R86-T('1H92!S=')I;F<@<F5P<F5S96YT
M871I;VX@;V8@=&AE(&UE<W-A9V4N("HO"B`@("`@("`@)&UE<W-A9V4@/2`D
M=&AI<RT^7V5X=')A8W1-97-S86=E*"1M97-S86=E*3L*"B`@("`@("`@)&1A
M=&5?<W1R(#T@9&%T92@G63IN.FHZ1SII.G,G*3L*("`@("`@("`D9&%T97,@
M/2!E>'!L;V1E*"<Z)RP@)&1A=&5?<W1R*3L*"B`@("`@("`@;6-A;%]E=F5N
M=%]I;FET*"1T:&ES+3Y?<W1R96%M*3L*("`@("`@("!M8V%L7V5V96YT7W-E
M=%]T:71L92@D=&AI<RT^7W-T<F5A;2P@)'1H:7,M/E]I9&5N="D["B`@("`@
M("`@;6-A;%]E=F5N=%]S971?8V%T96=O<GDH)'1H:7,M/E]S=')E86TL("1T
M:&ES+3Y?;F%M92D["B`@("`@("`@;6-A;%]E=F5N=%]S971?9&5S8W)I<'1I
M;VXH)'1H:7,M/E]S=')E86TL("1M97-S86=E*3L*("`@("`@("!M8V%L7V5V
M96YT7V%D9%]A='1R:6)U=&4H)'1H:7,M/E]S=')E86TL("=P<FEO<FET>2<L
M("1P<FEO<FET>2D["B`@("`@("`@;6-A;%]E=F5N=%]S971?<W1A<G0H)'1H
M:7,M/E]S=')E86TL("1D871E<ULP72P@)&1A=&5S6S%=+"`D9&%T97-;,ETL
M"B`@("`@("`@("`@("1D871E<ULS72P@)&1A=&5S6S1=+"`D9&%T97-;-5TI
M.PH@("`@("`@(&UC86Q?979E;G1?<V5T7V5N9"@D=&AI<RT^7W-T<F5A;2P@
M)&1A=&5S6S!=+"`D9&%T97-;,5TL("1D871E<ULR72P*("`@("`@("`@("`@
M)&1A=&5S6S-=+"`D9&%T97-;-%TL("1D871E<ULU72D["B`@("`@("`@;6-A
M;%]A<'!E;F1?979E;G0H)'1H:7,M/E]S=')E86TI.PH*("`@("`@("`D=&AI
M<RT^7V%N;F]U;F-E*&%R<F%Y*"=P<FEO<FET>2<@/3X@)'!R:6]R:71Y+"`G
M;65S<V%G92<@/3X@)&UE<W-A9V4I*3L*"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O3&]G+VUD8C(N<&AP````
M````````````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R-3$U
M-R`Q,#4Q-30S,S<S,2`P,C`U-30`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J("1(96%D97(Z("]R97!O
M<VET;W)Y+W!E87(O3&]G+TQO9R]M9&(R+G!H<"QV(#$N-2`R,#`V+S`Q+S`X
M(#`S.C,U.C0T(&IO;B!%>'`@)`H@*@H@*B!`=F5R<VEO;B`D4F5V:7-I;VXZ
M(#$N-2`D"B`J($!P86-K86=E($QO9PH@*B\*"B\J*B!014%2)W,@341",B!P
M86-K86=E("HO"G)E<75I<F5?;VYC92`G341",BYP:'`G.PI-1$(R.CIL;V%D
M1FEL92@G1&%T92<I.PH*+RHJ"B`J(%1H92!,;V=?;61B,B!C;&%S<R!I<R!A
M(&-O;F-R971E(&EM<&QE;65N=&%T:6]N(&]F('1H92!,;V<Z.B!A8G-T<F%C
M="!C;&%S<PH@*B!W:&EC:"!S96YD<R!M97-S86=E<R!T;R!A;B!344P@<V5R
M=F5R+B`@16%C:"!E;G1R>2!O8V-U<&EE<R!A('-E<&%R871E(')O=PH@*B!I
M;B!T:&4@9&%T86)A<V4N"B`J"B`J(%1H:7,@:6UP;&5M96YT871I;VX@=7-E
M<R!014%2)W,@341",B!D871A8F%S92!A8G-T<F%C=&EO;B!L87EE<BX*("H*
M("H@0U)%051%(%1!0DQ%(&QO9U]T86)L92`H"B`J("!I9"`@("`@("`@("!)
M3E0@3D]4($Y53$PL"B`J("!L;V=T:6UE("`@("!424U%4U1!35`@3D]4($Y5
M3$PL"B`J("!I9&5N="`@("`@("!#2$%2*#$V*2!.3U0@3E5,3"P*("H@('!R
M:6]R:71Y("`@($E.5"!.3U0@3E5,3"P*("H@(&UE<W-A9V4@("`@(%9!4D-(
M05(H,C`P*2P*("H@(%!224U!4ED@2T59("AI9"D*("H@*3L*("H*("H@0&%U
M=&AO<B`@3'5K87,@4VUI=&@@/'-M:71H0&)A8VME;F1M961I82YC;VT^"B`J
M($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!P:'`N;F5T/@H@*B!`<VEN8V4@
M("!,;V<@,2XY+C`*("H@0'!A8VMA9V4@3&]G"B`J+PIC;&%S<R!,;V=?;61B
M,B!E>'1E;F1S($QO9PI["B`@("`O*BH*("`@("`J(%9A<FEA8FQE(&-O;G1A
M:6YI;F<@=&AE($133B!I;F9O<FUA=&EO;BX*("`@("`J($!V87(@;6EX960*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]D<VX@
M/2`G)SL*"B`@("`O*BH*("`@("`J($%R<F%Y(&-O;G1A:6YI;F<@;W5R('-E
M="!O9B!$0B!C;VYF:6=U<F%T:6]N(&]P=&EO;G,N"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?
M;W!T:6]N<R`](&%R<F%Y*"=P97)S:7-T96YT)R`]/B!T<G5E*3L*"B`@("`O
M*BH*("`@("`J($]B:F5C="!H;VQD:6YG('1H92!D871A8F%S92!H86YD;&4N
M"B`@("`@*B!`=F%R(&]B:F5C=`H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*B\*("`@('9A<B`D7V1B(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%)E
M<V]U<F-E(&AO;&1I;F<@=&AE('!R97!A<F5D('-T871E;65N="!H86YD;&4N
M"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J+PH@("`@=F%R("1?<W1A=&5M96YT(#T@;G5L;#L*"B`@("`O*BH*
M("`@("`J($9L86<@:6YD:6-A=&EN9R!T:&%T('=E)W)E('5S:6YG(&%N(&5X
M:7-T:6YG(&1A=&%B87-E(&-O;FYE8W1I;VXN"B`@("`@*B!`=F%R(&)O;VQE
M86X*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]E
M>&ES=&EN9T-O;FYE8W1I;VX@/2!F86QS93L*"B`@("`O*BH*("`@("`J(%-T
M<FEN9R!H;VQD:6YG('1H92!D871A8F%S92!T86)L92!T;R!U<V4N"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@('9A<B`D7W1A8FQE(#T@)VQO9U]T86)L92<["@H@("`@+RHJ"B`@("`@
M*B!3=')I;F<@:&]L9&EN9R!T:&4@;F%M92!O9B!T:&4@240@<V5Q=65N8V4N
M"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*B\*("`@('9A<B`D7W-E<75E;F-E(#T@)VQO9U]I9"<["@H@("`@+RHJ
M"B`@("`@*B!-87AI;75M(&QE;F=T:"!O9B!T:&4@)&ED96YT('-T<FEN9RX@
M(%1H:7,@8V]R<F5S<&]N9',@=&\@=&AE('-I>F4@;V8*("`@("`J('1H92`G
M:61E;G0G(&-O;'5M;B!I;B!T:&4@4U%,('1A8FQE+@H@("`@("H@0'9A<B!I
M;G1E9V5R"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R
M("1?:61E;G1,:6UI="`](#$V.PH*("`@("\J*@H@("`@("H@4V5T(&]F(&9I
M96QD('1Y<&5S('5S960@:6X@=&AE(&1A=&%B87-E('1A8FQE+@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@
M('9A<B`D7W1Y<&5S(#T@87)R87DH"B`@("`@("`@)VED)R`@("`@("`@/3X@
M)VEN=&5G97(G+`H@("`@("`@("=L;V=T:6UE)R`@(#T^("=T:6UE<W1A;7`G
M+`H@("`@("`@("=I9&5N="<@("`@(#T^("=T97AT)RP*("`@("`@("`G<')I
M;W)I='DG("`]/B`G=&5X="<L"B`@("`@("`@)VUE<W-A9V4G("`@/3X@)V-L
M;V(G"B`@("`I.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!S
M<6P@;&]G9VEN9R!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;F%M92`@("`@("`@(%1H92!T87)G970@4U%,('1A8FQE+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D:61E;G0@("`@("`@(%1H92!I9&5N=&EF:6-A=&EO
M;B!F:65L9"X*("`@("`J($!P87)A;2!A<G)A>2`D8V]N9B`@("`@("`@("!4
M:&4@8V]N;F5C=&EO;B!C;VYF:6=U<F%T:6]N(&%R<F%Y+@H@("`@("H@0'!A
M<F%M(&EN="`D;&5V96P@("`@("`@("`@($QO9R!M97-S86=E<R!U<"!T;R!A
M;F0@:6YC;'5D:6YG('1H:7,@;&5V96PN"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!,;V=?;61B,B@D;F%M92P@)&ED96YT
M(#T@)R<L("1C;VYF(#T@87)R87DH*2P*("`@("`@("`@("`@("`@("`@("`@
M)&QE=F5L(#T@4$5!4E],3T=?1$5"54<I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]I9"`](&UD-2AM:6-R;W1I;64H*2D["B`@("`@("`@)'1H:7,M/E]T86)L
M92`]("1N86UE.PH@("`@("`@("1T:&ES+3Y?;6%S:R`]($QO9SHZ55!43R@D
M;&5V96PI.PH*("`@("`@("`O*B!)9B!A;B!O<'1I;VYS(&%R<F%Y('=A<R!P
M<F]V:61E9"P@=7-E(&ET+B`J+PH@("`@("`@(&EF("AI<W-E="@D8V]N9ELG
M;W!T:6]N<R==*2`F)B!I<U]A<G)A>2@D8V]N9ELG;W!T:6]N<R==*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7V]P=&EO;G,@/2`D8V]N9ELG;W!T:6]N<R==
M.PH@("`@("`@('T*"B`@("`@("`@+RH@268@82!S<&5C:69I8R!S97%U96YC
M92!N86UE('=A<R!P<F]V:61E9"P@=7-E(&ET+B`J+PH@("`@("`@(&EF("@A
M96UP='DH)&-O;F9;)W-E<75E;F-E)UTI*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?<V5Q=65N8V4@/2`D8V]N9ELG<V5Q=65N8V4G73L*("`@("`@("!]"@H@
M("`@("`@("\J($EF(&$@<W!E8VEF:6,@<V5Q=65N8V4@;F%M92!W87,@<')O
M=FED960L('5S92!I="X@*B\*("`@("`@("!I9B`H:7-S970H)&-O;F9;)VED
M96YT3&EM:70G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]I9&5N=$QI;6ET
M(#T@)&-O;F9;)VED96YT3&EM:70G73L*("`@("`@("!]"@H@("`@("`@("\J
M($YO=R!T:&%T('1H92!I9&5N="!L:6UI="!I<R!C;VYF:7)M960L('-E="!T
M:&4@:61E;G0@<W1R:6YG+B`J+PH@("`@("`@("1T:&ES+3YS971)9&5N="@D
M:61E;G0I.PH*("`@("`@("`O*B!)9B!A;B!E>&ES=&EN9R!D871A8F%S92!C
M;VYN96-T:6]N('=A<R!P<F]V:61E9"P@=7-E(&ET+B`J+PH@("`@("`@(&EF
M("AI<W-E="@D8V]N9ELG9&(G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]D
M8B`]("8D8V]N9ELG9&(G73L*("`@("`@("`@("`@)'1H:7,M/E]E>&ES=&EN
M9T-O;FYE8W1I;VX@/2!T<G5E.PH@("`@("`@("`@("`D=&AI<RT^7V]P96YE
M9"`]('1R=64["B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1C;VYF6R=S:6YG
M;&5T;VXG72DI('L*("`@("`@("`@("`@)'1H:7,M/E]D8B`]("9-1$(R.CIS
M:6YG;&5T;VXH)&-O;F9;)W-I;F=L971O;B==+"`D=&AI<RT^7V]P=&EO;G,I
M.PH@("`@("`@("`@("`D=&AI<RT^7V5X:7-T:6YG0V]N;F5C=&EO;B`]('1R
M=64["B`@("`@("`@("`@("1T:&ES+3Y?;W!E;F5D(#T@=')U93L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7V1S;B`]("1C;VYF6R=D
M<VXG73L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!/<&5N<R!A
M(&-O;FYE8W1I;VX@=&\@=&AE(&1A=&%B87-E+"!I9B!I="!H87,@;F]T(&%L
M<F5A9'D*("`@("`J(&)E96X@;W!E;F5D+B!4:&ES(&ES(&EM<&QI8VET;'D@
M8V%L;&5D(&)Y(&QO9R@I+"!I9B!N96-E<W-A<GDN"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N("`@5')U92!O;B!S=6-C97-S+"!F86QS92!O;B!F
M86EL=7)E+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N
M8W1I;VX@;W!E;B@I"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^7V]P96YE
M9"D@>PH@("`@("`@("`@("`O*B!5<V4@=&AE($133B!A;F0@;W!T:6]N<R!T
M;R!C<F5A=&4@82!D871A8F%S92!C;VYN96-T:6]N+B`J+PH@("`@("`@("`@
M("`D=&AI<RT^7V1B(#T@)DU$0C(Z.F-O;FYE8W0H)'1H:7,M/E]D<VXL("1T
M:&ES+3Y?;W!T:6]N<RD["B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1T:&ES+3Y?9&(I*2!["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($-R96%T92!A('!R97!A
M<F5D('-T871E;65N="!F;W(@<F5P96%T960@=7-E(&EN(&QO9R@I+B`J+PH@
M("`@("`@("`@("!I9B`H(21T:&ES+3Y?<')E<&%R95-T871E;65N="@I*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("\J(%=E(&YO=R!C;VYS:61E<B!O=70@8V]N;F5C=&EO
M;B!O<&5N+B`J+PH@("`@("`@("`@("`D=&AI<RT^7V]P96YE9"`]('1R=64[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]O<&5N960["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#;&]S97,@=&AE(&-O;FYE8W1I;VX@=&\@
M=&AE(&1A=&%B87-E(&EF(&ET(&ES('-T:6QL(&]P96X@86YD('=E('=E<F4*
M("`@("`J('1H92!O;F5S('1H870@;W!E;F5D(&ET+B`@270@:7,@=&AE(&-A
M;&QE<B=S(')E<W!O;G-I8FQE('1O(&-L;W-E(&%N"B`@("`@*B!E>&ES=&EN
M9R!C;VYN96-T:6]N('1H870@=V%S('!A<W-E9"!T;R!U<R!V:6$@)&-O;F9;
M)V1B)UTN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("`@5')U92!O
M;B!S=6-C97-S+"!F86QS92!O;B!F86EL=7)E+@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@8VQO<V4H*0H@("`@>PH@("`@
M("`@("\J($EF('=E(&AA=F4@82!S=&%T96UE;G0@;V)J96-T+"!F<F5E(&ET
M+B`J+PH@("`@("`@(&EF("AI<U]O8FIE8W0H)'1H:7,M/E]S=&%T96UE;G0I
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?<W1A=&5M96YT+3YF<F5E*"D["B`@
M("`@("`@("`@("1T:&ES+3Y?<W1A=&5M96YT(#T@;G5L;#L*("`@("`@("!]
M"@H@("`@("`@("\J($EF('=E(&]P96YE9"!T:&4@9&%T86)A<V4@8V]N;F5C
M=&EO;BP@9&ES8V]N;F5C="!I="X@*B\*("`@("`@("!I9B`H)'1H:7,M/E]O
M<&5N960@)B8@(21T:&ES+3Y?97AI<W1I;F=#;VYN96-T:6]N*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?;W!E;F5D(#T@9F%L<V4["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7V1B+3YD:7-C;VYN96-T*"D["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@*"1T:&ES+3Y?;W!E;F5D(#T]/2!F86QS92D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!3971S('1H:7,@3&]G(&EN<W1A;F-E)W,@:61E
M;G1I9FEC871I;VX@<W1R:6YG+B`@3F]T92!T:&%T('1H:7,*("`@("`J(%-1
M3"US<&5C:69I8R!I;7!L96UE;G1A=&EO;B!W:6QL(&QI;6ET('1H92!L96YG
M=&@@;V8@=&AE("1I9&5N="!S=')I;F<*("`@("`J('1O('-I>'1E96X@*#$V
M*2!C:&%R86-T97)S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("`@
M)&ED96YT("`@("`@5&AE(&YE=R!I9&5N=&EF:6-A=&EO;B!S=')I;F<N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<VEN8V4@("!,
M;V<@,2XX+C4*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T261E;G0H)&ED96YT
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:61E;G0@/2!S=6)S='(H)&ED96YT
M+"`P+"`D=&AI<RT^7VED96YT3&EM:70I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@26YS97)T<R`D;65S<V%G92!T;R!T:&4@8W5R<F5N=&QY(&]P96X@9&%T
M86)A<V4N("!#86QL<R!O<&5N*"DL"B`@("`@*B!I9B!N96-E<W-A<GDN("!!
M;'-O('!A<W-E<R!T:&4@;65S<V%G92!A;&]N9R!T;R!A;GD@3&]G7V]B<V5R
M=F5R"B`@("`@*B!I;G-T86YC97,@=&AA="!A<F4@;V)S97)V:6YG('1H:7,@
M3&]G+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`@)&UE<W-A9V4@(%-T
M<FEN9R!O<B!O8FIE8W0@8V]N=&%I;FEN9R!T:&4@;65S<V%G92!T;R!L;V<N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1P<FEO<FET>2!4:&4@<')I;W)I='D@
M;V8@=&AE(&UE<W-A9V4N("!686QI9`H@("`@("H@("`@("`@("`@("`@("`@
M("!V86QU97,@87)E.B!014%27TQ/1U]%34521RP@4$5!4E],3T=?04Q%4E0L
M"B`@("`@*B`@("`@("`@("`@("`@("`@(%!%05)?3$]'7T-2250L(%!%05)?
M3$]'7T524BP@4$5!4E],3T=?5T%23DE.1RP*("`@("`J("`@("`@("`@("`@
M("`@("`@4$5!4E],3T=?3D]424-%+"!014%27TQ/1U])3D9/+"!A;F0@4$5!
M4E],3T=?1$5"54<N"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@
M<W5C8V5S<R!O<B!F86QS92!O;B!F86EL=7)E+@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@;&]G*"1M97-S86=E+"`D<')I
M;W)I='D@/2!N=6QL*0H@("`@>PH@("`@("`@("\J($EF(&$@<')I;W)I='D@
M:&%S;B=T(&)E96X@<W!E8VEF:65D+"!U<V4@=&AE(&1E9F%U;'0@=F%L=64N
M("HO"B`@("`@("`@:68@*"1P<FEO<FET>2`]/3T@;G5L;"D@>PH@("`@("`@
M("`@("`D<')I;W)I='D@/2`D=&AI<RT^7W!R:6]R:71Y.PH@("`@("`@('T*
M"B`@("`@("`@+RH@06)O<G0@96%R;'D@:68@=&AE('!R:6]R:71Y(&ES(&%B
M;W9E('1H92!M87AI;75M(&QO9V=I;F<@;&5V96PN("HO"B`@("`@("`@:68@
M*"$D=&AI<RT^7VES36%S:V5D*"1P<FEO<FET>2DI('L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+RH@268@=&AE(&-O
M;FYE8W1I;VX@:7-N)W0@;W!E;B!A;F0@8V%N)W0@8F4@;W!E;F5D+"!R971U
M<FX@9F%I;'5R92X@*B\*("`@("`@("!I9B`H(21T:&ES+3Y?;W!E;F5D("8F
M("$D=&AI<RT^;W!E;B@I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!]"@H@("`@("`@("\J($EF('=E(&1O;B=T(&%L<F5A9'D@:&%V
M92!A('-T871E;65N="!O8FIE8W0L(&-R96%T92!O;F4N("HO"B`@("`@("`@
M:68@*"%I<U]O8FIE8W0H)'1H:7,M/E]S=&%T96UE;G0I("8F("$D=&AI<RT^
M7W!R97!A<F53=&%T96UE;G0H*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("`O*B!%>'1R86-T('1H92!S=')I;F<@
M<F5P<F5S96YT871I;VX@;V8@=&AE(&UE<W-A9V4N("HO"B`@("`@("`@)&UE
M<W-A9V4@/2`D=&AI<RT^7V5X=')A8W1-97-S86=E*"1M97-S86=E*3L*"B`@
M("`@("`@+RH@0G5I;&0@;W5R('-E="!O9B!V86QU97,@9F]R('1H:7,@;&]G
M(&5N=')Y+B`J+PH@("`@("`@("1V86QU97,@/2!A<G)A>2@*("`@("`@("`@
M("`@)VED)R`@("`@("`]/B`D=&AI<RT^7V1B+3YN97AT260H)'1H:7,M/E]S
M97%U96YC92DL"B`@("`@("`@("`@("=L;V=T:6UE)R`@/3X@341",E]$871E
M.CIM9&).;W<H*2P*("`@("`@("`@("`@)VED96YT)R`@("`]/B`D=&AI<RT^
M7VED96YT+`H@("`@("`@("`@("`G<')I;W)I='DG(#T^("1P<FEO<FET>2P*
M("`@("`@("`@("`@)VUE<W-A9V4G("`]/B`D;65S<V%G90H@("`@("`@("D[
M"@H@("`@("`@("\J($5X96-U=&4@=&AE(%-13"!Q=65R>2!F;W(@=&AI<R!L
M;V<@96YT<GD@:6YS97)T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?9&(M/F5X
M<&5C=$5R<F]R*$U$0C)?15)23U)?3D]354-(5$%"3$4I.PH@("`@("`@("1R
M97-U;'0@/2`F)'1H:7,M/E]S=&%T96UE;G0M/F5X96-U=&4H)'9A;'5E<RD[
M"B`@("`@("`@)'1H:7,M/E]D8BT^<&]P17AP96-T*"D["@H@("`@("`@("\J
M($%T=&5M<'0@=&\@:&%N9&QE(&%N>2!E<G)O<G,N("HO"B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@+RH@5V4@
M8V%N(&]N;'D@:&%N9&QE($U$0C)?15)23U)?3D]354-(5$%"3$4@97)R;W)S
M+B`J+PH@("`@("`@("`@("!I9B`H)')E<W5L="T^9V5T0V]D92@I("$]($U$
M0C)?15)23U)?3D]354-(5$%"3$4I('L*("`@("`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@071T96UP
M="!T;R!C<F5A=&4@=&AE('1A<F=E="!T86)L92X@*B\*("`@("`@("`@("`@
M:68@*"$D=&AI<RT^7V-R96%T951A8FQE*"DI('L*("`@("`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@
M4F5C<F5A=&4@;W5R('!R97!A<F5D('-T871E;65N="!R97-O=7)C92X@*B\*
M("`@("`@("`@("`@)'1H:7,M/E]S=&%T96UE;G0M/F9R964H*3L*("`@("`@
M("`@("`@:68@*"$D=&AI<RT^7W!R97!A<F53=&%T96UE;G0H*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`O*B!!='1E;7!T('1O(')E+65X96-U=&4@=&AE(&EN<V5R=&EO
M;B!Q=65R>2X@*B\*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?<W1A
M=&5M96YT+3YE>&5C=71E*"1V86QU97,I.PH@("`@("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D=&AI
M<RT^7V%N;F]U;F-E*&%R<F%Y*"=P<FEO<FET>2<@/3X@)'!R:6]R:71Y+"`G
M;65S<V%G92<@/3X@)&UE<W-A9V4I*3L*"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@=&AE(&QO9R!T86)L92!I
M;B!T:&4@9&%T86)A<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!4<G5E(&]N('-U8V-E<W,@;W(@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?8W)E871E
M5&%B;&4H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9&(M/FQO861-;V1U;&4H
M)TUA;F%G97(G+"!N=6QL+"!T<G5E*3L*("`@("`@("`D<F5S=6QT(#T@)'1H
M:7,M/E]D8BT^;6%N86=E<BT^8W)E871E5&%B;&4H"B`@("`@("`@("`@("1T
M:&ES+3Y?=&%B;&4L"B`@("`@("`@("`@(&%R<F%Y*`H@("`@("`@("`@("`@
M("`@)VED)R`@("`@("`@/3X@87)R87DH)W1Y<&4G(#T^("1T:&ES+3Y?='EP
M97-;)VED)UTI+`H@("`@("`@("`@("`@("`@)VQO9W1I;64G("`@/3X@87)R
M87DH)W1Y<&4G(#T^("1T:&ES+3Y?='EP97-;)VQO9W1I;64G72DL"B`@("`@
M("`@("`@("`@("`G:61E;G0G("`@("`]/B!A<G)A>2@G='EP92<@/3X@)'1H
M:7,M/E]T>7!E<ULG:61E;G0G72DL"B`@("`@("`@("`@("`@("`G<')I;W)I
M='DG("`]/B!A<G)A>2@G='EP92<@/3X@)'1H:7,M/E]T>7!E<ULG<')I;W)I
M='DG72DL"B`@("`@("`@("`@("`@("`G;65S<V%G92<@("`]/B!A<G)A>2@G
M='EP92<@/3X@)'1H:7,M/E]T>7!E<ULG;65S<V%G92==*0H@("`@("`@("`@
M("`I"B`@("`@("`@*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S
M=6QT*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*
M("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^;6%N86=E<BT^8W)E871E
M26YD97@H"B`@("`@("`@("`@("1T:&ES+3Y?=&%B;&4L"B`@("`@("`@("`@
M("=U;FEQ=65?:60G+`H@("`@("`@("`@("!A<G)A>2@G9FEE;&1S)R`]/B!A
M<G)A>2@G:60G(#T^('1R=64I+"`G=6YI<75E)R`]/B!T<G5E*0H@("`@("`@
M("D["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<W5L="DI('L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!0<F5P87)E('1H92!3
M44P@:6YS97)T:6]N('-T871E;65N="X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@(%1R=64@:68@=&AE('-T871E;65N="!W87,@<W5C8V5S<V9U
M;&QY(&-R96%T960N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@
M("`@("H@0'-I;F-E("`@3&]G(#$N.2XP"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]P<F5P87)E4W1A=&5M96YT*"D*("`@('L*("`@("`@("`D=&AI<RT^7W-T
M871E;65N="`]("8D=&AI<RT^7V1B+3YP<F5P87)E*`H@("`@("`@("`@("`@
M("`@)TE.4T525"!)3E1/("<@+B`D=&AI<RT^7W1A8FQE("X*("`@("`@("`@
M("`@("`@("<@*&ED+"!L;V=T:6UE+"!I9&5N="P@<')I;W)I='DL(&UE<W-A
M9V4I)R`N"B`@("`@("`@("`@("`@("`G(%9!3%5%4R@Z:60L(#IL;V=T:6UE
M+"`Z:61E;G0L(#IP<FEO<FET>2P@.FUE<W-A9V4I)RP*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?='EP97,L($U$0C)?4%)%4$%215]-04Y)4"D["@H@("`@
M("`@("\J(%)E='5R;B!S=6-C97-S(&EF('=E(&1I9&XG="!G96YE<F%T92!A
M;B!E<G)O<BX@*B\*("`@("`@("!R971U<FX@*%!%05(Z.FES17)R;W(H)'1H
M:7,M/E]S=&%T96UE;G0I(#T]/2!F86QS92D["B`@("!]"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+TQO9R]N=6QL+G!H<```````````````````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#0P,#8@,3`U,34T,S,W,S$@
M,#(P-C<P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B`D2&5A9&5R.B`O<F5P;W-I=&]R>2]P96%R+TQO
M9R],;V<O;G5L;"YP:'`L=B`Q+C0@,C`P-2\P,B\R-B`Q-#HT.#HU."!C:&%G
M96YB=2!%>'`@)`H@*@H@*B!`=F5R<VEO;B`D4F5V:7-I;VXZ(#$N-"`D"B`J
M($!P86-K86=E($QO9PH@*B\*"B\J*@H@*B!4:&4@3&]G7VYU;&P@8VQA<W,@
M:7,@82!C;VYC<F5T92!I;7!L96UE;G1A=&EO;B!O9B!T:&4@3&]G.CH@86)S
M=')A8W0*("H@8VQA<W,N("!)="!S:6UP;'D@8V]N<W5M97,@;&]G(&5V96YT
M<RX*("H*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N0'!H<"YN970^"B`J
M($!S:6YC92`@($QO9R`Q+C@N,@H@*B!`<&%C:V%G92!,;V<*("H*("H@0&5X
M86UP;&4@;G5L;"YP:'`@("`@57-I;F<@=&AE(&YU;&P@:&%N9&QE<BX*("HO
M"F-L87-S($QO9U]N=6QL(&5X=&5N9',@3&]G"GL*("`@("\J*@H@("`@("H@
M0V]N<W1R=6-T<R!A(&YE=R!,;V=?;G5L;"!O8FIE8W0N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@26=N;W)E9"X*("`@("`J($!P
M87)A;2!S=')I;F<@)&ED96YT("`@(%1H92!I9&5N=&ET>2!S=')I;F<N"B`@
M("`@*B!`<&%R86T@87)R87D@("1C;VYF("`@("!4:&4@8V]N9FEG=7)A=&EO
M;B!A<G)A>2X*("`@("`J($!P87)A;2!I;G0@("`@)&QE=F5L("`@($QO9R!M
M97-S86=E<R!U<"!T;R!A;F0@:6YC;'5D:6YG('1H:7,@;&5V96PN"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!,;V=?;G5L
M;"@D;F%M92P@)&ED96YT(#T@)R<L("1C;VYF(#T@87)R87DH*2P*"0D)"0D@
M("1L979E;"`](%!%05)?3$]'7T1%0E5'*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?:60@/2!M9#4H;6EC<F]T:6UE*"DI.PH@("`@("`@("1T:&ES+3Y?:61E
M;G0@/2`D:61E;G0["B`@("`@("`@)'1H:7,M/E]M87-K(#T@3&]G.CI54%1/
M*"1L979E;"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3:6UP;'D@8V]N<W5M
M97,@=&AE(&QO9R!E=F5N="X@(%1H92!M97-S86=E('=I;&P@<W1I;&P@8F4@
M<&%S<V5D"B`@("`@*B!A;&]N9R!T;R!A;GD@3&]G7V]B<V5R=F5R(&EN<W1A
M;F-E<R!T:&%T(&%R92!O8G-E<G9I;F<@=&AI<R!,;V<N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&UI>&5D("`D;65S<V%G92`@("!3=')I;F<@;W(@;V)J96-T
M(&-O;G1A:6YI;F<@=&AE(&UE<W-A9V4@=&\@;&]G+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<')I;W)I='D@5&AE('!R:6]R:71Y(&]F('1H92!M97-S86=E
M+B`@5F%L:60*("`@("`J("`@("`@("`@("`@("`@("`@=F%L=65S(&%R93H@
M4$5!4E],3T=?14U%4D<L(%!%05)?3$]'7T%,15)4+`H@("`@("H@("`@("`@
M("`@("`@("`@("!014%27TQ/1U]#4DE4+"!014%27TQ/1U]%4E(L(%!%05)?
M3$]'7U=!4DY)3D<L"B`@("`@*B`@("`@("`@("`@("`@("`@(%!%05)?3$]'
M7TY/5$E#12P@4$5!4E],3T=?24Y&3RP@86YD(%!%05)?3$]'7T1%0E5'+@H@
M("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,@;W(@9F%L
M<V4@;VX@9F%I;'5R92X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&QO9R@D;65S<V%G92P@)'!R:6]R:71Y(#T@;G5L;"D*
M("`@('L*("`@("`@("`O*B!)9B!A('!R:6]R:71Y(&AA<VXG="!B965N('-P
M96-I9FEE9"P@=7-E('1H92!D969A=6QT('9A;'5E+B`J+PH@("`@("`@(&EF
M("@D<')I;W)I='D@/3T](&YU;&PI('L*("`@("`@("`@("`@)'!R:6]R:71Y
M(#T@)'1H:7,M/E]P<FEO<FET>3L*("`@("`@("!]"@H@("`@("`@("\J($%B
M;W)T(&5A<FQY(&EF('1H92!P<FEO<FET>2!I<R!A8F]V92!T:&4@;6%X:6UU
M;2!L;V=G:6YG(&QE=F5L+B`J+PH@("`@("`@(&EF("@A)'1H:7,M/E]I<TUA
M<VME9"@D<')I;W)I='DI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?86YN;W5N8V4H87)R87DH)W!R
M:6]R:71Y)R`]/B`D<')I;W)I='DL("=M97-S86=E)R`]/B`D;65S<V%G92DI
M.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+TQO9R]O8G-E<G9E<BYP:'``
M````````````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3`P-3<@
M,3`U,34T,S,W,S$@,#(Q-34P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B`D2&5A9&5R.B`O<F5P;W-I
M=&]R>2]P96%R+TQO9R],;V<O;V)S97)V97(N<&AP+'8@,2XQ."`R,#`V+S`T
M+S(U(#`V.C`R.C(S(&IO;B!%>'`@)`H@*B`D2&]R9&4Z(&AO<F1E+VQI8B],
M;V<O;V)S97)V97(N<&AP+'8@,2XU(#(P,#`O,#8O,C@@,C$Z,S8Z,3,@:F]N
M($5X<"`D"B`J"B`J($!V97)S:6]N("12979I<VEO;CH@,2XQ."`D"B`J($!P
M86-K86=E($QO9PH@*B\*"B\J*@H@*B!4:&4@3&]G7V]B<V5R=F5R.CH@8VQA
M<W,@:6UP;&5M96YT<R!T:&4@3V)S97)V97(@96YD(&]F(&$@4W5B:F5C="U/
M8G-E<G9E<@H@*B!P871T97)N(&9O<B!W871C:&EN9R!L;V<@86-T:79I='D@
M86YD('1A:VEN9R!A8W1I;VYS(&]N(&5X8V5P=&EO;F%L(&5V96YT<RX*("H*
M("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<VEN8V4@("!,;V<@,2XP"B`J
M($!P86-K86=E($QO9PH@*@H@*B!`97AA;7!L92!O8G-E<G9E<E]M86EL+G!H
M<"`@($%N(&5X86UP;&4@3&]G7V]B<V5R=F5R(&EM<&QE;65N=&%T:6]N+@H@
M*B\*8VQA<W,@3&]G7V]B<V5R=F5R"GL*("`@("\J*@H@("`@("H@26YS=&%N
M8V4M<W!E8VEF:6,@=6YI<75E(&ED96YT:69I8V%T:6]N(&YU;6)E<BX*("`@
M("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("HO"B`@("!V87(@)%]I9"`](#`["@H@("`@+RHJ"B`@("`@*B!4
M:&4@;6EN:6UU;2!P<FEO<FET>2!L979E;"!O9B!M97-S86=E('1H870@=V4@
M=V%N="!T;R!H96%R(&%B;W5T+@H@("`@("H@4$5!4E],3T=?14U%4D<@:7,@
M=&AE(&AI9VAE<W0@<')I;W)I='DL('-O('=E('=I;&P@;VYL>2!H96%R(&UE
M<W-A9V5S"B`@("`@*B!W:71H(&%N(&EN=&5G97(@<')I;W)I='D@=F%L=64@
M;&5S<R!T:&%N(&]R(&5Q=6%L('1O(&]U<G,N("!)="!D969A=6QT<PH@("`@
M("H@=&\@4$5!4E],3T=?24Y&3RP@=VAI8V@@;&ES=&5N<R!T;R!E=F5R>71H
M:6YG(&5X8V5P="!014%27TQ/1U]$14)51RX*("`@("`J"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A
M<B`D7W!R:6]R:71Y(#T@4$5!4E],3T=?24Y&3SL*"B`@("`O*BH*("`@("`J
M($-R96%T97,@82!N97<@8F%S:6,@3&]G7V]B<V5R=F5R(&EN<W1A;F-E+@H@
M("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("`@)'!R:6]R:71Y("`@5&AE
M(&AI9VAE<W0@<')I;W)I='D@870@=VAI8V@@=&\@<F5C96EV90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!L;V<@979E;G0@;F]T:69I
M8V%T:6]N<RX*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!,;V=?;V)S97)V97(H)'!R:6]R:71Y(#T@4$5!4E],
M3T=?24Y&3RD*("`@('L*("`@("`@("`D=&AI<RT^7VED(#T@;60U*&UI8W)O
M=&EM92@I*3L*("`@("`@("`D=&AI<RT^7W!R:6]R:71Y(#T@)'!R:6]R:71Y
M.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@
M;F5W(&-O;F-R971E($QO9U]O8G-E<G9E<B!I;G-T86YC92!O9B!T:&4@<F5Q
M=65S=&5D"B`@("`@*B!T>7!E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@("`@)'1Y<&4@("`@("`@5&AE('1Y<&4@;V8@8V]N8W)E871E($QO9U]O
M8G-E<G9E<B!S=6)C;&%S<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!T;R!R971U<FXN"B`@("`@*B!`<&%R86T@:6YT96=E<B`@("1P
M<FEO<FET>2`@(%1H92!H:6=H97-T('!R:6]R:71Y(&%T('=H:6-H('1O(')E
M8V5I=F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;&]G
M(&5V96YT(&YO=&EF:6-A=&EO;G,N"B`@("`@*B!`<&%R86T@87)R87D@("`@
M("1C;VYF("`@("`@($]P=&EO;F%L(&%S<V]C:6%T:79E(&%R<F%Y(&]F(&%D
M9&ET:6]N86P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M8V]N9FEG=7)A=&EO;B!V86QU97,N"B`@("`@*@H@("`@("H@0')E='5R;B!O
M8FIE8W0@("`@("`@("`@("`@("!4:&4@;F5W;'D@8W)E871E9"!C;VYC<F5T
M92!,;V=?;V)S97)V97(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:6YS=&%N8V4L(&]R(&YU;&P@;VX@86X@97)R;W(N"B`@("`@*B\*
M("`@(&9U;F-T:6]N("9F86-T;W)Y*"1T>7!E+"`D<')I;W)I='D@/2!014%2
M7TQ/1U])3D9/+"`D8V]N9B`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1Y
M<&4@/2!S=')T;VQO=V5R*"1T>7!E*3L*("`@("`@("`D8VQA<W,@/2`G3&]G
M7V]B<V5R=F5R7R<@+B`D='EP93L*"B`@("`@("`@+RH*("`@("`@("`@*B!)
M9B!T:&4@9&5S:7)E9"!C;&%S<R!A;')E861Y(&5X:7-T<R`H8F5C875S92!T
M:&4@8V%L;&5R(&AA<R!S=7!P;&EE9`H@("`@("`@("`J(&ET(&9R;VT@<V]M
M92!C=7-T;VT@;&]C871I;VXI+"!S:6UP;'D@:6YS=&%N=&EA=&4@86YD(')E
M='5R;B!A(&YE=PH@("`@("`@("`J(&EN<W1A;F-E+@H@("`@("`@("`J+PH@
M("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@
M("`D;V)J96-T(#T@)FYE=R`D8VQA<W,H)'!R:6]R:71Y+"`D8V]N9BD["B`@
M("`@("`@("`@(')E='5R;B`D;V)J96-T.PH@("`@("`@('T*"B`@("`@("`@
M+RH@4W5P<&]R="!B;W1H('1H92!N97<M<W1Y;&4@86YD(&]L9"US='EL92!F
M:6QE(&YA;6EN9R!C;VYV96YT:6]N<RX@*B\*("`@("`@("`D;F5W<W1Y;&4@
M/2!T<G5E.PH@("`@("`@("1C;&%S<V9I;&4@/2!D:7)N86UE*%]?1DE,15]?
M*2`N("<O;V)S97)V97)?)R`N("1T>7!E("X@)RYP:'`G.PH*("`@("`@("!I
M9B`H(69I;&5?97AI<W1S*"1C;&%S<V9I;&4I*2!["B`@("`@("`@("`@("1C
M;&%S<V9I;&4@/2`G3&]G+R<@+B`D='EP92`N("<N<&AP)SL*("`@("`@("`@
M("`@)&YE=W-T>6QE(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O*@H@
M("`@("`@("`J($%T=&5M<'0@=&\@:6YC;'5D92!O=7(@=F5R<VEO;B!O9B!T
M:&4@;F%M960@8VQA<W,L(&)U="!D;VXG="!T<F5A=`H@("`@("`@("`J(&$@
M9F%I;'5R92!A<R!F871A;"X@(%1H92!C86QL97(@;6%Y(&AA=F4@86QR96%D
M>2!I;F-L=61E9"!T:&5I<B!O=VX*("`@("`@("`@*B!V97)S:6]N(&]F('1H
M92!N86UE9"!C;&%S<RX*("`@("`@("`@*B\*("`@("`@("!`:6YC;'5D95]O
M;F-E("1C;&%S<V9I;&4["@H@("`@("`@("\J($EF('1H92!C;&%S<R!E>&ES
M=',L(')E='5R;B!A(&YE=R!I;G-T86YC92!O9B!I="X@*B\*("`@("`@("!I
M9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@+RH@4W5P
M<&]R="!B;W1H(&YE=RUS='EL92!A;F0@;VQD+7-T>6QE(&-O;G-T<G5C=&EO
M;BX@*B\*("`@("`@("`@("`@:68@*"1N97=S='EL92D@>PH@("`@("`@("`@
M("`@("`@)&]B:F5C="`]("9N97<@)&-L87-S*"1P<FEO<FET>2P@)&-O;F8I
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&]B:F5C
M="`]("9N97<@)&-L87-S*"1P<FEO<FET>2D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@<F5T=7)N("1O8FIE8W0["B`@("`@("`@?0H*("`@("`@("`D
M;G5L;"`](&YU;&P["B`@("`@("`@<F5T=7)N("1N=6QL.PH@("`@?0H*("`@
M("\J*@H@("`@("H@5&AI<R!I<R!A('-T=6(@;65T:&]D('1O(&UA:V4@<W5R
M92!T:&%T($QO9U]/8G-E<G9E<B!C;&%S<V5S(&1O"B`@("`@*B!S;VUE=&AI
M;F<@=VAE;B!T:&5Y(&%R92!N;W1I9FEE9"!O9B!A(&UE<W-A9V4N("!4:&4@
M9&5F875L="!B96AA=FEO<@H@("`@("H@:7,@=&\@:G5S="!P<FEN="!T:&4@
M;65S<V%G92P@=VAI8V@@:7,@;V)V:6]U<VQY(&YO="!D97-I<F5A8FQE(&EN
M"B`@("`@*B!P<F%C=&EC86QL>2!A;GD@<VET=6%T:6]N("T@=VAI8V@@:7,@
M=VAY('EO=2!N965D('1O(&]V97)R:61E('1H:7,*("`@("`J(&UE=&AO9"X@
M.BD*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@("`@("1E=F5N="`@("`@
M($$@:&%S:"!D97-C<FEB:6YG('1H92!L;V<@979E;G0N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&YO=&EF>2@D979E;G0I"B`@("!["B`@("`@("`@<')I;G1?
M<B@D979E;G0I.PH@("`@?0I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O3&]G+W-Q;"YP:'``````````````````````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R,3`W,R`Q,#4Q-30S,S<S
M,2`P,C`U,C``(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J("1(96%D97(Z("]R97!O<VET;W)Y+W!E87(O
M3&]G+TQO9R]S<6PN<&AP+'8@,2XT,"`R,#`V+S`Q+S`S(#`T.C$R.C0U(&IO
M;B!%>'`@)`H@*B`D2&]R9&4Z(&AO<F1E+VQI8B],;V<O<W%L+G!H<"QV(#$N
M,3(@,C`P,"\P."\Q-B`R,#HR-SHS-"!C:'5C:R!%>'`@)`H@*@H@*B!`=F5R
M<VEO;B`D4F5V:7-I;VXZ(#$N-#`@)`H@*B!`<&%C:V%G92!,;V<*("HO"@HO
M*@H@*B!792!R97%U:7)E('1H92!014%2($1"(&-L87-S+B`@5&AI<R!I<R!G
M96YE<F%L;'D@9&5F:6YE9"!I;B!T:&4@1$(N<&AP(&9I;&4L"B`J(&)U="!I
M="=S('!O<W-I8FQE('1H870@=&AE(&-A;&QE<B!M87D@:&%V92!P<F]V:61E
M9"!T:&4@1$(@8VQA<W,L(&]R(&$*("H@8V]M<&%T:6)L92!W<F%P<&5R("AS
M=6-H(&%S('1H92!O;F4@<VAI<'!E9"!W:71H($U$0C(I+"!S;R!W92!F:7)S
M="!C:&5C:PH@*B!F;W(@86X@97AI<W1I;F<@)T1")R!C;&%S<R!B969O<F4@
M:6YC;'5D:6YG("=$0BYP:'`G+@H@*B\*:68@*"%C;&%S<U]E>&ES=',H)T1"
M)RDI('L*("`@(')E<75I<F5?;VYC92`G1$(N<&AP)SL*?0H*+RHJ"B`J(%1H
M92!,;V=?<W%L(&-L87-S(&ES(&$@8V]N8W)E=&4@:6UP;&5M96YT871I;VX@
M;V8@=&AE($QO9SHZ"B`J(&%B<W1R86-T(&-L87-S('=H:6-H('-E;F1S(&UE
M<W-A9V5S('1O(&%N(%-13"!S97)V97(N("!%86-H(&5N=')Y"B`J(&]C8W5P
M:65S(&$@<V5P87)A=&4@<F]W(&EN('1H92!D871A8F%S92X*("H*("H@5&AI
M<R!I;7!L96UE;G1A=&EO;B!U<V5S(%!(4"=S(%!%05(@9&%T86)A<V4@86)S
M=')A8W1I;VX@;&%Y97(N"B`J"B`J($-214%412!404),12!L;V=?=&%B;&4@
M*`H@*B`@:60@("`@("`@("`@24Y4($Y/5"!.54Q,+`H@*B`@;&]G=&EM92`@
M("`@5$E-15-404U0($Y/5"!.54Q,+`H@*B`@:61E;G0@("`@("`@0TA!4B@Q
M-BD@3D]4($Y53$PL"B`J("!P<FEO<FET>2`@("!)3E0@3D]4($Y53$PL"B`J
M("!M97-S86=E("`@("!605)#2$%2*#(P,"DL"B`J("!04DE-05)9($M%62`H
M:60I"B`J("D["B`J"B`J($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!P:'`N
M;F5T/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'-I;F-E("`@3&]G(#$N
M,`H@*B!`<&%C:V%G92!,;V<*("H*("H@0&5X86UP;&4@<W%L+G!H<"`@("`@
M57-I;F<@=&AE(%-13"!H86YD;&5R+@H@*B\*8VQA<W,@3&]G7W-Q;"!E>'1E
M;F1S($QO9PI["B`@("`O*BH*("`@("`J(%9A<FEA8FQE(&-O;G1A:6YI;F<@
M=&AE($133B!I;F9O<FUA=&EO;BX*("`@("`J($!V87(@;6EX960*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]D<VX@/2`G)SL*
M"B`@("`O*BH*("`@("`J(%-T<FEN9R!C;VYT86EN:6YG('1H92!344P@:6YS
M97)T:6]N('-T871E;65N="X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7W-Q;"`]
M("<G.PH*("`@("\J*@H@("`@("H@07)R87D@8V]N=&%I;FEN9R!O=7(@<V5T
M(&]F($1"(&-O;F9I9W5R871I;VX@;W!T:6]N<RX*("`@("`J($!V87(@87)R
M87D*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]O
M<'1I;VYS(#T@87)R87DH)W!E<G-I<W1E;G0G(#T^('1R=64I.PH*("`@("\J
M*@H@("`@("H@3V)J96-T(&AO;&1I;F<@=&AE(&1A=&%B87-E(&AA;F1L92X*
M("`@("`J($!V87(@;V)J96-T"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J+PH@("`@=F%R("1?9&(@/2!N=6QL.PH*("`@("\J*@H@("`@("H@4F5S
M;W5R8V4@:&]L9&EN9R!T:&4@<')E<&%R960@<W1A=&5M96YT(&AA;F1L92X*
M("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("HO"B`@("!V87(@)%]S=&%T96UE;G0@/2!N=6QL.PH*("`@("\J*@H@
M("`@("H@1FQA9R!I;F1I8V%T:6YG('1H870@=V4G<F4@=7-I;F<@86X@97AI
M<W1I;F<@9&%T86)A<V4@8V]N;F5C=&EO;BX*("`@("`J($!V87(@8F]O;&5A
M;@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7V5X
M:7-T:6YG0V]N;F5C=&EO;B`](&9A;'-E.PH*("`@("\J*@H@("`@("H@4W1R
M:6YG(&AO;&1I;F<@=&AE(&1A=&%B87-E('1A8FQE('1O('5S92X*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@
M("`@=F%R("1?=&%B;&4@/2`G;&]G7W1A8FQE)SL*"B`@("`O*BH*("`@("`J
M(%-T<FEN9R!H;VQD:6YG('1H92!N86UE(&]F('1H92!)1"!S97%U96YC92X*
M("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J+PH@("`@=F%R("1?<V5Q=65N8V4@/2`G;&]G7VED)SL*"B`@("`O*BH*
M("`@("`J($UA>&EM=6T@;&5N9W1H(&]F('1H92`D:61E;G0@<W1R:6YG+B`@
M5&AI<R!C;W)R97-P;VYD<R!T;R!T:&4@<VEZ92!O9@H@("`@("H@=&AE("=I
M9&5N="<@8V]L=6UN(&EN('1H92!344P@=&%B;&4N"B`@("`@*B!`=F%R(&EN
M=&5G97(*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@
M)%]I9&5N=$QI;6ET(#T@,38["@H*("`@("\J*@H@("`@("H@0V]N<W1R=6-T
M<R!A(&YE=R!S<6P@;&]G9VEN9R!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;F%M92`@("`@("`@(%1H92!T87)G970@4U%,('1A8FQE
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:61E;G0@("`@("`@(%1H92!I9&5N
M=&EF:6-A=&EO;B!F:65L9"X*("`@("`J($!P87)A;2!A<G)A>2`D8V]N9B`@
M("`@("`@("!4:&4@8V]N;F5C=&EO;B!C;VYF:6=U<F%T:6]N(&%R<F%Y+@H@
M("`@("H@0'!A<F%M(&EN="`D;&5V96P@("`@("`@("`@($QO9R!M97-S86=E
M<R!U<"!T;R!A;F0@:6YC;'5D:6YG('1H:7,@;&5V96PN"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!,;V=?<W%L*"1N86UE
M+"`D:61E;G0@/2`G)RP@)&-O;F8@/2!A<G)A>2@I+`H@("`@("`@("`@("`@
M("`@("`@("`D;&5V96P@/2!014%27TQ/1U]$14)51RD*("`@('L*("`@("`@
M("`D=&AI<RT^7VED(#T@;60U*&UI8W)O=&EM92@I*3L*("`@("`@("`D=&AI
M<RT^7W1A8FQE(#T@)&YA;64["B`@("`@("`@)'1H:7,M/E]M87-K(#T@3&]G
M.CI54%1/*"1L979E;"D["@H@("`@("`@("\J($YO=R!T:&%T('=E(&AA=F4@
M82!T86)L92!N86UE+"!A<W-I9VX@;W5R(%-13"!S=&%T96UE;G0N("HO"B`@
M("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W-Q;"DI('L*("`@("`@("`@("`@
M)'1H:7,M/E]S<6P@/2`D8V]N9ELG<W%L)UT["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'1H:7,M/E]S<6P@/2`G24Y315)4($E.5$\@)R`N("1T
M:&ES+3Y?=&%B;&4@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("<@*&ED
M+"!L;V=T:6UE+"!I9&5N="P@<')I;W)I='DL(&UE<W-A9V4I)R`N"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@)R!604Q515,H/RP@0U524D5.5%]424U%
M4U1!35`L(#\L(#\L(#\I)SL*("`@("`@("!]"@H@("`@("`@("\J($EF(&%N
M(&]P=&EO;G,@87)R87D@=V%S('!R;W9I9&5D+"!U<V4@:70N("HO"B`@("`@
M("`@:68@*&ES<V5T*"1C;VYF6R=O<'1I;VYS)UTI("8F(&ES7V%R<F%Y*"1C
M;VYF6R=O<'1I;VYS)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W!T:6]N
M<R`]("1C;VYF6R=O<'1I;VYS)UT["B`@("`@("`@?0H*("`@("`@("`O*B!)
M9B!A('-P96-I9FEC('-E<75E;F-E(&YA;64@=V%S('!R;W9I9&5D+"!U<V4@
M:70N("HO"B`@("`@("`@:68@*"%E;7!T>2@D8V]N9ELG<V5Q=65N8V4G72DI
M('L*("`@("`@("`@("`@)'1H:7,M/E]S97%U96YC92`]("1C;VYF6R=S97%U
M96YC92==.PH@("`@("`@('T*"B`@("`@("`@+RH@268@82!S<&5C:69I8R!S
M97%U96YC92!N86UE('=A<R!P<F]V:61E9"P@=7-E(&ET+B`J+PH@("`@("`@
M(&EF("AI<W-E="@D8V]N9ELG:61E;G1,:6UI="==*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7VED96YT3&EM:70@/2`D8V]N9ELG:61E;G1,:6UI="==.PH@
M("`@("`@('T*"B`@("`@("`@+RH@3F]W('1H870@=&AE(&ED96YT(&QI;6ET
M(&ES(&-O;F9I<FUE9"P@<V5T('1H92!I9&5N="!S=')I;F<N("HO"B`@("`@
M("`@)'1H:7,M/G-E=$ED96YT*"1I9&5N="D["@H@("`@("`@("\J($EF(&%N
M(&5X:7-T:6YG(&1A=&%B87-E(&-O;FYE8W1I;VX@=V%S('!R;W9I9&5D+"!U
M<V4@:70N("HO"B`@("`@("`@:68@*&ES<V5T*"1C;VYF6R=D8B==*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7V1B(#T@)B1C;VYF6R=D8B==.PH@("`@("`@
M("`@("`D=&AI<RT^7V5X:7-T:6YG0V]N;F5C=&EO;B`]('1R=64["B`@("`@
M("`@("`@("1T:&ES+3Y?;W!E;F5D(#T@=')U93L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D=&AI<RT^7V1S;B`]("1C;VYF6R=D<VXG73L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!/<&5N<R!A(&-O;FYE8W1I
M;VX@=&\@=&AE(&1A=&%B87-E+"!I9B!I="!H87,@;F]T(&%L<F5A9'D*("`@
M("`J(&)E96X@;W!E;F5D+B!4:&ES(&ES(&EM<&QI8VET;'D@8V%L;&5D(&)Y
M(&QO9R@I+"!I9B!N96-E<W-A<GDN"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("`@5')U92!O;B!S=6-C97-S+"!F86QS92!O;B!F86EL=7)E+@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@;W!E
M;B@I"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^7V]P96YE9"D@>PH@("`@
M("`@("`@("`O*B!5<V4@=&AE($133B!A;F0@;W!T:6]N<R!T;R!C<F5A=&4@
M82!D871A8F%S92!C;VYN96-T:6]N+B`J+PH@("`@("`@("`@("`D=&AI<RT^
M7V1B(#T@)D1".CIC;VYN96-T*"1T:&ES+3Y?9'-N+"`D=&AI<RT^7V]P=&EO
M;G,I.PH@("`@("`@("`@("!I9B`H1$(Z.FES17)R;W(H)'1H:7,M/E]D8BDI
M('L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@+RH@0W)E871E(&$@<')E<&%R960@<W1A=&5M96YT
M(&9O<B!R97!E871E9"!U<V4@:6X@;&]G*"DN("HO"B`@("`@("`@("`@(&EF
M("@A)'1H:7,M/E]P<F5P87)E4W1A=&5M96YT*"DI('L*("`@("`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M+RH@5V4@;F]W(&-O;G-I9&5R(&]U="!C;VYN96-T:6]N(&]P96XN("HO"B`@
M("`@("`@("`@("1T:&ES+3Y?;W!E;F5D(#T@=')U93L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D=&AI<RT^7V]P96YE9#L*("`@('T*"B`@("`O*BH*
M("`@("`J($-L;W-E<R!T:&4@8V]N;F5C=&EO;B!T;R!T:&4@9&%T86)A<V4@
M:68@:70@:7,@<W1I;&P@;W!E;B!A;F0@=V4@=V5R90H@("`@("H@=&AE(&]N
M97,@=&AA="!O<&5N960@:70N("!)="!I<R!T:&4@8V%L;&5R)W,@<F5S<&]N
M<VEB;&4@=&\@8VQO<V4@86X*("`@("`J(&5X:7-T:6YG(&-O;FYE8W1I;VX@
M=&AA="!W87,@<&%S<V5D('1O('5S('9I82`D8V]N9ELG9&(G72X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@("!4<G5E(&]N('-U8V-E<W,L(&9A
M;'-E(&]N(&9A:6QU<F4N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!C;&]S92@I"B`@("!["B`@("`@("`@:68@*"1T:&ES
M+3Y?;W!E;F5D("8F("$D=&AI<RT^7V5X:7-T:6YG0V]N;F5C=&EO;BD@>PH@
M("`@("`@("`@("`D=&AI<RT^7V]P96YE9"`](&9A;'-E.PH@("`@("`@("`@
M("`D=&AI<RT^7V1B+3YF<F5E4')E<&%R960H)'1H:7,M/E]S=&%T96UE;G0I
M.PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]D8BT^9&ES8V]N;F5C="@I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("@D=&AI<RT^7V]P96YE9"`]
M/3T@9F%L<V4I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&ES($QO
M9R!I;G-T86YC92=S(&ED96YT:69I8V%T:6]N('-T<FEN9RX@($YO=&4@=&AA
M="!T:&ES"B`@("`@*B!344PM<W!E8VEF:6,@:6UP;&5M96YT871I;VX@=VEL
M;"!L:6UI="!T:&4@;&5N9W1H(&]F('1H92`D:61E;G0@<W1R:6YG"B`@("`@
M*B!T;R!S:7AT965N("@Q-BD@8VAA<F%C=&5R<RX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`@("1I9&5N="`@("`@(%1H92!N97<@:61E;G1I9FEC
M871I;VX@<W1R:6YG+@H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@
M("`@("H@0'-I;F-E("`@3&]G(#$N."XU"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-E=$ED96YT*"1I9&5N="D*("`@('L*("`@("`@("`D=&AI<RT^7VED96YT
M(#T@<W5B<W1R*"1I9&5N="P@,"P@)'1H:7,M/E]I9&5N=$QI;6ET*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($EN<V5R=',@)&UE<W-A9V4@=&\@=&AE(&-U
M<G)E;G1L>2!O<&5N(&1A=&%B87-E+B`@0V%L;',@;W!E;B@I+`H@("`@("H@
M:68@;F5C97-S87)Y+B`@06QS;R!P87-S97,@=&AE(&UE<W-A9V4@86QO;F<@
M=&\@86YY($QO9U]O8G-E<G9E<@H@("`@("H@:6YS=&%N8V5S('1H870@87)E
M(&]B<V5R=FEN9R!T:&ES($QO9RX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX
M960@("1M97-S86=E("!3=')I;F<@;W(@;V)J96-T(&-O;G1A:6YI;F<@=&AE
M(&UE<W-A9V4@=&\@;&]G+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')I;W)I
M='D@5&AE('!R:6]R:71Y(&]F('1H92!M97-S86=E+B`@5F%L:60*("`@("`J
M("`@("`@("`@("`@("`@("`@=F%L=65S(&%R93H@4$5!4E],3T=?14U%4D<L
M(%!%05)?3$]'7T%,15)4+`H@("`@("H@("`@("`@("`@("`@("`@("!014%2
M7TQ/1U]#4DE4+"!014%27TQ/1U]%4E(L(%!%05)?3$]'7U=!4DY)3D<L"B`@
M("`@*B`@("`@("`@("`@("`@("`@(%!%05)?3$]'7TY/5$E#12P@4$5!4E],
M3T=?24Y&3RP@86YD(%!%05)?3$]'7T1%0E5'+@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!4<G5E(&]N('-U8V-E<W,@;W(@9F%L<V4@;VX@9F%I;'5R92X*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&QO
M9R@D;65S<V%G92P@)'!R:6]R:71Y(#T@;G5L;"D*("`@('L*("`@("`@("`O
M*B!)9B!A('!R:6]R:71Y(&AA<VXG="!B965N('-P96-I9FEE9"P@=7-E('1H
M92!D969A=6QT('9A;'5E+B`J+PH@("`@("`@(&EF("@D<')I;W)I='D@/3T]
M(&YU;&PI('L*("`@("`@("`@("`@)'!R:6]R:71Y(#T@)'1H:7,M/E]P<FEO
M<FET>3L*("`@("`@("!]"@H@("`@("`@("\J($%B;W)T(&5A<FQY(&EF('1H
M92!P<FEO<FET>2!I<R!A8F]V92!T:&4@;6%X:6UU;2!L;V=G:6YG(&QE=F5L
M+B`J+PH@("`@("`@(&EF("@A)'1H:7,M/E]I<TUA<VME9"@D<')I;W)I='DI
M*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@
M("`@("\J($EF('1H92!C;VYN96-T:6]N(&ES;B=T(&]P96X@86YD(&-A;B=T
M(&)E(&]P96YE9"P@<F5T=7)N(&9A:6QU<F4N("HO"B`@("`@("`@:68@*"$D
M=&AI<RT^7V]P96YE9"`F)B`A)'1H:7,M/F]P96XH*2D@>PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!W92!D
M;VXG="!A;')E861Y(&AA=F4@;W5R('-T871E;65N="!O8FIE8W0@>65T+"!C
M<F5A=&4@:70N("HO"B`@("`@("`@:68@*"%I<U]O8FIE8W0H)'1H:7,M/E]S
M=&%T96UE;G0I("8F("$D=&AI<RT^7W!R97!A<F53=&%T96UE;G0H*2D@>PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O
M*B!%>'1R86-T('1H92!S=')I;F<@<F5P<F5S96YT871I;VX@;V8@=&AE(&UE
M<W-A9V4N("HO"B`@("`@("`@)&UE<W-A9V4@/2`D=&AI<RT^7V5X=')A8W1-
M97-S86=E*"1M97-S86=E*3L*"B`@("`@("`@+RH@0G5I;&0@;W5R('-E="!O
M9B!V86QU97,@9F]R('1H:7,@;&]G(&5N=')Y+B`J+PH@("`@("`@("1I9"`]
M("1T:&ES+3Y?9&(M/FYE>'1)9"@D=&AI<RT^7W-E<75E;F-E*3L*("`@("`@
M("`D=F%L=65S(#T@87)R87DH)&ED+"`D=&AI<RT^7VED96YT+"`D<')I;W)I
M='DL("1M97-S86=E*3L*"B`@("`@("`@+RH@17AE8W5T92!T:&4@4U%,('%U
M97)Y(&9O<B!T:&ES(&QO9R!E;G1R>2!I;G-E<G1I;VXN("HO"B`@("`@("`@
M)')E<W5L="`])B`D=&AI<RT^7V1B+3YE>&5C=71E*"1T:&ES+3Y?<W1A=&5M
M96YT+"`D=F%L=65S*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L
M="DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@)'1H:7,M/E]A;FYO=6YC92AA<G)A>2@G<')I;W)I='DG(#T^("1P
M<FEO<FET>2P@)VUE<W-A9V4G(#T^("1M97-S86=E*2D["@H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4')E<&%R92!T:&4@
M4U%,(&EN<V5R=&EO;B!S=&%T96UE;G0N"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!4<G5E(&EF('1H92!S=&%T96UE;G0@=V%S('-U8V-E<W-F
M=6QL>2!C<F5A=&5D+@H@("`@("H*("`@("`J($!A8V-E<W,@('!R:79A=&4*
M("`@("`J($!S:6YC92`@($QO9R`Q+CDN,0H@("`@("HO"B`@("!F=6YC=&EO
M;B!?<')E<&%R95-T871E;65N="@I"B`@("!["B`@("`@("`@)'1H:7,M/E]S
M=&%T96UE;G0@/2`D=&AI<RT^7V1B+3YP<F5P87)E*"1T:&ES+3Y?<W%L*3L*
M"B`@("`@("`@+RH@4F5T=7)N('-U8V-E<W,@:68@=V4@9&ED;B=T(&=E;F5R
M871E(&%N(&5R<F]R+B`J+PH@("`@("`@(')E='5R;B`H1$(Z.FES17)R;W(H
M)'1H:7,M/E]S=&%T96UE;G0I(#T]/2!F86QS92D["B`@("!]"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B],;V<O<W%L:71E+G!H<```````
M````````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$U-38R(#$P
M-3$U-#,S-S,Q(#`R,3(S,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@)$AE861E<CH@+W)E<&]S:71O
M<GDO<&5A<B],;V<O3&]G+W-Q;&ET92YP:'`L=B`Q+C4@,C`P-2\Q,B\P-2`P
M-3HS.#HS,2!J;VX@17AP("0*("H*("H@0'9E<G-I;VX@)%)E=FES:6]N.B`Q
M+C4@)`H@*B!`<&%C:V%G92!,;V<*("HO"@HO*BH*("H@5&AE($QO9U]S<6QI
M=&4@8VQA<W,@:7,@82!C;VYC<F5T92!I;7!L96UE;G1A=&EO;B!O9B!T:&4@
M3&]G.CH*("H@86)S=')A8W0@8VQA<W,@=VAI8V@@<V5N9',@;65S<V%G97,@
M=&\@86X@4W%L:71E(&1A=&%B87-E+@H@*B!%86-H(&5N=')Y(&]C8W5P:65S
M(&$@<V5P87)A=&4@<F]W(&EN('1H92!D871A8F%S92X*("H*("H@5&AI<R!I
M;7!L96UE;G1A=&EO;B!U<V5S(%!(4"!N871I=F4@4W%L:71E(&9U;F-T:6]N
M<RX*("H*("H@0U)%051%(%1!0DQ%(&QO9U]T86)L92`H"B`J("!I9"`@("`@
M("`@("!)3E1%1T52(%!224U!4ED@2T59($Y/5"!.54Q,+`H@*B`@;&]G=&EM
M92`@("`@3D]4($Y53$PL"B`J("!I9&5N="`@("`@("!#2$%2*#$V*2!.3U0@
M3E5,3"P*("H@('!R:6]R:71Y("`@($E.5"!.3U0@3E5,3"P*("H@(&UE<W-A
M9V4*("H@*3L*("H*("H@0&%U=&AO<B`@0F5R=')A;F0@36%N<VEO;B`\8FUA
M;G-I;VY`;6%M87-A;2YC;VT^"B`J($!A=71H;W(@($IO;B!087)I<V4@/&IO
M;D!P:'`N;F5T/@H@*B!`<VEN8V4@("!,;V<@,2XX+C,*("H@0'!A8VMA9V4@
M3&]G"B`J"B`J($!E>&%M<&QE('-Q;&ET92YP:'`@("`@("!5<VEN9R!T:&4@
M4W%L:71E(&AA;F1L97(N"B`J+PIC;&%S<R!,;V=?<W%L:71E(&5X=&5N9',@
M3&]G"GL*("`@("\J*@H@("`@("H@07)R87D@8V]N=&%I;FEN9R!T:&4@8V]N
M;F5C=&EO;B!D969A=6QT<PH@("`@("H@0'9A<B!A<G)A>0H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7V]P=&EO;G,@/2!A<G)A
M>2@G;6]D92<@("`@("`@/3X@,#8V-BP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`G<&5R<VES=&5N="<@/3X@9F%L<V4I.PH*("`@("\J*@H@("`@("H@
M3V)J96-T(&AO;&1I;F<@=&AE(&1A=&%B87-E(&AA;F1L92X*("`@("`J($!V
M87(@;V)J96-T"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@
M=F%R("1?9&(@/2!N=6QL.PH*("`@("\J*@H@("`@("H@1FQA9R!I;F1I8V%T
M:6YG('1H870@=V4G<F4@=7-I;F<@86X@97AI<W1I;F<@9&%T86)A<V4@8V]N
M;F5C=&EO;BX*("`@("`J($!V87(@8F]O;&5A;@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*B\*("`@('9A<B`D7V5X:7-T:6YG0V]N;F5C=&EO;B`]
M(&9A;'-E.PH*("`@("\J*@H@("`@("H@4W1R:6YG(&AO;&1I;F<@=&AE(&1A
M=&%B87-E('1A8FQE('1O('5S92X*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?=&%B;&4@/2`G
M;&]G7W1A8FQE)SL*"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W
M('-Q;"!L;V=G:6YG(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1N86UE("`@("`@("`@5&AE('1A<F=E="!344P@=&%B;&4N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1I9&5N="`@("`@("`@5&AE(&ED96YT:69I8V%T
M:6]N(&9I96QD+@H@("`@("H@0'!A<F%M(&UI>&5D("`D8V]N9B`@("`@("`@
M($-A;B!B92!A;B!A<G)A>2!O9B!C;VYF:6=U<F%T:6]N(&]P=&EO;G,@=7-E
M9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1O(&]P96X@
M82!N97<@9&%T86)A<V4@8V]N;F5C=&EO;@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&]R(&%N(&%L<F5A9'D@;W!E;F5D('-Q;&ET92!C
M;VYN96-T:6]N+@H@("`@("H@0'!A<F%M(&EN="`@("`D;&5V96P@("`@("`@
M($QO9R!M97-S86=E<R!U<"!T;R!A;F0@:6YC;'5D:6YG('1H:7,@;&5V96PN
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!,
M;V=?<W%L:71E*"1N86UE+"`D:61E;G0@/2`G)RP@)B1C;VYF+"`D;&5V96P@
M/2!014%27TQ/1U]$14)51RD*("`@('L*("`@("`@("`D=&AI<RT^7VED(#T@
M;60U*&UI8W)O=&EM92@I*3L*("`@("`@("`D=&AI<RT^7W1A8FQE(#T@)&YA
M;64["B`@("`@("`@)'1H:7,M/E]I9&5N="`]("1I9&5N=#L*("`@("`@("`D
M=&AI<RT^7VUA<VL@/2!,;V<Z.E505$\H)&QE=F5L*3L*"B`@("`@("`@:68@
M*&ES7V%R<F%Y*"1C;VYF*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D8V]N
M9B!A<R`D:R`]/B`D;W!T*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V]P
M=&EO;G-;)&M=(#T@)&]P=#L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("\O($EF(&%N(&5X:7-T:6YG(&1A=&%B87-E(&-O
M;FYE8W1I;VX@=V%S('!R;W9I9&5D+"!U<V4@:70N"B`@("`@("`@("`@("1T
M:&ES+3Y?9&(@/28@)&-O;F8["B`@("`@("`@("`@("1T:&ES+3Y?97AI<W1I
M;F=#;VYN96-T:6]N(#T@=')U93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!/<&5N<R!A(&-O;FYE8W1I;VX@=&\@=&AE(&1A=&%B87-E+"!I
M9B!I="!H87,@;F]T(&%L<F5A9'D*("`@("`J(&)E96X@;W!E;F5D+B!4:&ES
M(&ES(&EM<&QI8VET;'D@8V%L;&5D(&)Y(&QO9R@I+"!I9B!N96-E<W-A<GDN
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("`@5')U92!O;B!S=6-C
M97-S+"!F86QS92!O;B!F86EL=7)E+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@;W!E;B@I"B`@("!["B`@("`@("`@:68@
M*&ES7W)E<V]U<F-E*"1T:&ES+3Y?9&(I*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?;W!E;F5D(#T@=')U93L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M8W)E871E5&%B;&4H*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O
M*B!3970@=&AE(&-O;FYE8W1I;VX@9G5N8W1I;VX@8F%S960@;VX@=&AE("=P
M97)S:7-T96YT)R!O<'1I;VXN("HO"B`@("`@("`@("`@(&EF("AE;7!T>2@D
M=&AI<RT^7V]P=&EO;G-;)W!E<G-I<W1E;G0G72DI('L*("`@("`@("`@("`@
M("`@("1C;VYN96-T1G5N8W1I;VX@/2`G<W%L:71E7V]P96XG.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&-O;FYE8W1&=6YC=&EO
M;B`]("=S<6QI=&5?<&]P96XG.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`O*B!!='1E;7!T('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+B`J+PH@
M("`@("`@("`@("!I9B`H)'1H:7,M/E]D8B`]("1C;VYN96-T1G5N8W1I;VXH
M)'1H:7,M/E]O<'1I;VYS6R=F:6QE;F%M92==+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*&EN="DD=&AI<RT^7V]P
M=&EO;G-;)VUO9&4G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1E<G)O<BDI('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?;W!E;F5D(#T@=')U93L*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7V-R96%T951A8FQE*"D["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D=&AI<RT^7V]P96YE9#L*("`@('T*"B`@("`O
M*BH*("`@("`J($-L;W-E<R!T:&4@8V]N;F5C=&EO;B!T;R!T:&4@9&%T86)A
M<V4@:68@:70@:7,@<W1I;&P@;W!E;B!A;F0@=V4@=V5R90H@("`@("H@=&AE
M(&]N97,@=&AA="!O<&5N960@:70N("!)="!I<R!T:&4@8V%L;&5R)W,@<F5S
M<&]N<VEB;&4@=&\@8VQO<V4@86X*("`@("`J(&5X:7-T:6YG(&-O;FYE8W1I
M;VX@=&AA="!W87,@<&%S<V5D('1O('5S('9I82`D8V]N9ELG9&(G72X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@("!4<G5E(&]N('-U8V-E<W,L
M(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("HO"B`@("!F=6YC=&EO;B!C;&]S92@I"B`@("!["B`@("`@("`@+RH@5V4@
M;F5V97(@8VQO<V4@97AI<W1I;F<@8V]N;F5C=&EO;G,N("HO"B`@("`@("`@
M:68@*"1T:&ES+3Y?97AI<W1I;F=#;VYN96-T:6]N*2!["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^
M7V]P96YE9"D@>PH@("`@("`@("`@("`D=&AI<RT^7V]P96YE9"`](&9A;'-E
M.PH@("`@("`@("`@("!S<6QI=&5?8VQO<V4H)'1H:7,M/E]D8BD["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@*"1T:&ES+3Y?;W!E;F5D(#T]/2!F86QS
M92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!);G-E<G1S("1M97-S86=E('1O
M('1H92!C=7)R96YT;'D@;W!E;B!D871A8F%S92X@($-A;&QS(&]P96XH*2P*
M("`@("`J(&EF(&YE8V5S<V%R>2X@($%L<V\@<&%S<V5S('1H92!M97-S86=E
M(&%L;VYG('1O(&%N>2!,;V=?;V)S97)V97(*("`@("`J(&EN<W1A;F-E<R!T
M:&%T(&%R92!O8G-E<G9I;F<@=&AI<R!,;V<N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&UI>&5D("`D;65S<V%G92`@4W1R:6YG(&]R(&]B:F5C="!C;VYT86EN
M:6YG('1H92!M97-S86=E('1O(&QO9RX*("`@("`J($!P87)A;2!S=')I;F<@
M)'!R:6]R:71Y(%1H92!P<FEO<FET>2!O9B!T:&4@;65S<V%G92X@(%9A;&ED
M"B`@("`@*B`@("`@("`@("`@("`@("`@('9A;'5E<R!A<F4Z(%!%05)?3$]'
M7T5-15)'+"!014%27TQ/1U]!3$525"P*("`@("`J("`@("`@("`@("`@("`@
M("`@4$5!4E],3T=?0U))5"P@4$5!4E],3T=?15)2+"!014%27TQ/1U]705).
M24Y'+`H@("`@("H@("`@("`@("`@("`@("`@("!014%27TQ/1U].3U1)0T4L
M(%!%05)?3$]'7TE.1D\L(&%N9"!014%27TQ/1U]$14)51RX*("`@("`J($!R
M971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S(&]R(&9A;'-E(&]N(&9A
M:6QU<F4N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC
M=&EO;B!L;V<H)&UE<W-A9V4L("1P<FEO<FET>2`](&YU;&PI"B`@("!["B`@
M("`@("`@+RH@268@82!P<FEO<FET>2!H87-N)W0@8F5E;B!S<&5C:69I960L
M('5S92!T:&4@9&5F875L="!V86QU92X@*B\*("`@("`@("!I9B`H)'!R:6]R
M:71Y(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1P<FEO<FET>2`]("1T:&ES
M+3Y?<')I;W)I='D["B`@("`@("`@?0H*("`@("`@("`O*B!!8F]R="!E87)L
M>2!I9B!T:&4@<')I;W)I='D@:7,@86)O=F4@=&AE(&UA>&EM=6T@;&]G9VEN
M9R!L979E;"X@*B\*("`@("`@("!I9B`H(21T:&ES+3Y?:7--87-K960H)'!R
M:6]R:71Y*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("`O*B!)9B!T:&4@8V]N;F5C=&EO;B!I<VXG="!O<&5N(&%N
M9"!C86XG="!B92!O<&5N960L(')E='5R;B!F86EL=7)E+B`J+PH@("`@("`@
M(&EF("@A)'1H:7,M/E]O<&5N960@)B8@(21T:&ES+3YO<&5N*"DI('L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+R\@
M17AT<F%C="!T:&4@<W1R:6YG(')E<')E<V5N=&%T:6]N(&]F('1H92!M97-S
M86=E+@H@("`@("`@("1M97-S86=E(#T@)'1H:7,M/E]E>'1R86-T365S<V%G
M92@D;65S<V%G92D["@H@("`@("`@("\O($)U:6QD('1H92!344P@<75E<GD@
M9F]R('1H:7,@;&]G(&5N=')Y(&EN<V5R=&EO;BX*("`@("`@("`D<2`]('-P
M<FEN=&8H)TE.4T525"!)3E1/(%LE<UT@*&QO9W1I;64L(&ED96YT+"!P<FEO
M<FET>2P@;65S<V%G92D@)R`N"B`@("`@("`@("`@("`@("`@("`@(")604Q5
M15,@*"<E<R<L("<E<R<L("5D+"`G)7,G*2(L"B`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?=&%B;&4L"B`@("`@("`@("`@("`@("`@("`@('-T<F9T
M:6UE*"<E62TE;2TE9"`E2#HE33HE4R<L('1I;64H*2DL"B`@("`@("`@("`@
M("`@("`@("`@('-Q;&ET95]E<V-A<&5?<W1R:6YG*"1T:&ES+3Y?:61E;G0I
M+`H@("`@("`@("`@("`@("`@("`@("`D<')I;W)I='DL"B`@("`@("`@("`@
M("`@("`@("`@('-Q;&ET95]E<V-A<&5?<W1R:6YG*"1M97-S86=E*2D["B`@
M("`@("`@:68@*"$H)')E<R`]($!S<6QI=&5?=6YB=69F97)E9%]Q=65R>2@D
M=&AI<RT^7V1B+"`D<2DI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]A;FYO=6YC92AA<G)A>2@G<')I
M;W)I='DG(#T^("1P<FEO<FET>2P@)VUE<W-A9V4G(#T^("1M97-S86=E*2D[
M"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0VAE8VMS('=H971H97(@=&AE(&QO9R!T86)L92!E>&ES=',@86YD(&-R96%T
M97,@:70@:68@;F5C97-S87)Y+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5')U92!O;B!S=6-C97-S(&]R(&9A;'-E(&]N(&9A:6QU<F4N"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V-R
M96%T951A8FQE*"D*("`@('L*("`@("`@("`D<2`](")314Q%0U0@;F%M92!&
M4D]-('-Q;&ET95]M87-T97(@5TA%4D4@;F%M93TG(B`N("1T:&ES+3Y?=&%B
M;&4@+@H@("`@("`@("`@("`@(B<@04Y$('1Y<&4])W1A8FQE)R(["@H@("`@
M("`@("1R97,@/2!S<6QI=&5?<75E<GDH)'1H:7,M/E]D8BP@)'$I.PH*("`@
M("`@("!I9B`H<W%L:71E7VYU;5]R;W=S*"1R97,I(#T](#`I('L*("`@("`@
M("`@("`@)'$@/2`G0U)%051%(%1!0DQ%(%LG("X@)'1H:7,M/E]T86)L92`N
M("==("@G("X*("`@("`@("`@("`@("`@("`G:60@24Y414=%4B!04DE-05)9
M($M%62!.3U0@3E5,3"P@)R`N"B`@("`@("`@("`@("`@("`@)VQO9W1I;64@
M3D]4($Y53$PL("<@+@H@("`@("`@("`@("`@("`@("=I9&5N="!#2$%2*#$V
M*2!.3U0@3E5,3"P@)R`N"B`@("`@("`@("`@("`@("`@)W!R:6]R:71Y($E.
M5"!.3U0@3E5,3"P@)R`N"B`@("`@("`@("`@("`@("`@)VUE<W-A9V4I)SL*
M"B`@("`@("`@("`@(&EF("@A*"1R97,@/2!S<6QI=&5?=6YB=69F97)E9%]Q
M=65R>2@D=&AI<RT^7V1B+"`D<2DI*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B],;V<O<WES;&]G+G!H<```````````````````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$Q-#$U(#$P-3$U-#,S-S,Q(#`R,3(T
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@)$AE861E<CH@+W)E<&]S:71O<GDO<&5A<B],;V<O3&]G
M+W-Y<VQO9RYP:'`L=B`Q+C(S(#(P,#4O,#(O,C8@,30Z-#@Z-3D@8VAA9V5N
M8G4@17AP("0*("H@)$AO<F1E.B!H;W)D92]L:6(O3&]G+W-Y<VQO9RYP:'`L
M=B`Q+C8@,C`P,"\P-B\R."`R,3HS-CHQ,R!J;VX@17AP("0*("H*("H@0'9E
M<G-I;VX@)%)E=FES:6]N.B`Q+C(S("0*("H@0'!A8VMA9V4@3&]G"B`J+PH*
M+RHJ"B`J(%1H92!,;V=?<WES;&]G(&-L87-S(&ES(&$@8V]N8W)E=&4@:6UP
M;&5M96YT871I;VX@;V8@=&AE($QO9SHZ"B`J(&%B<W1R86-T(&-L87-S('=H
M:6-H('-E;F1S(&UE<W-A9V5S('1O('-Y<VQO9R!O;B!53DE8+6QI:V4@;6%C
M:&EN97,*("H@*%!(4"!E;75L871E<R!T:&ES('=I=&@@=&AE($5V96YT($QO
M9R!O;B!7:6YD;W=S(&UA8VAI;F5S*2X*("H*("H@0&%U=&AO<B`@0VAU8VL@
M2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E
M(#$N,PH@*B!`<VEN8V4@("!,;V<@,2XP"B`J($!P86-K86=E($QO9PH@*@H@
M*B!`97AA;7!L92!S>7-L;V<N<&AP("`@("`@57-I;F<@=&AE('-Y<VQO9R!H
M86YD;&5R+@H@*B\*8VQA<W,@3&]G7W-Y<VQO9R!E>'1E;F1S($QO9PI["B`@
M("`O*BH*("`@("H@26YT96=E<B!H;VQD:6YG('1H92!L;V<@9F%C:6QI='D@
M=&\@=7-E+@H@("`@*B!`=F%R('-T<FEN9PH@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("HO"B`@("!V87(@)%]N86UE(#T@3$]'7U-94TQ/1SL*"B`@("`O
M*BH*("`@("`J($-O;G-T<G5C=',@82!N97<@<WES;&]G(&]B:F5C="X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("!4:&4@<WES;&]G
M(&9A8VEL:71Y+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:61E;G0@("`@5&AE
M(&ED96YT:71Y('-T<FEN9RX*("`@("`J($!P87)A;2!A<G)A>2`@)&-O;F8@
M("`@(%1H92!C;VYF:6=U<F%T:6]N(&%R<F%Y+@H@("`@("H@0'!A<F%M(&EN
M="`@("`D;&5V96P@("`@3&]G(&UE<W-A9V5S('5P('1O(&%N9"!I;F-L=61I
M;F<@=&AI<R!L979E;"X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N($QO9U]S>7-L;V<H)&YA;64L("1I9&5N="`]("<G+"`D
M8V]N9B`](&%R<F%Y*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("1L979E
M;"`](%!%05)?3$]'7T1%0E5'*0H@("`@>PH@("`@("`@("\J($5N<W5R92!W
M92!H879E(&$@=F%L:60@:6YT96=E<B!V86QU92!F;W(@)&YA;64N("HO"B`@
M("`@("`@:68@*&5M<'1Y*"1N86UE*2!\?"`A:7-?:6YT*"1N86UE*2D@>PH@
M("`@("`@("`@("`D;F%M92`]($Q/1U]365-,3T<["B`@("`@("`@?0H*("`@
M("`@("`D=&AI<RT^7VED(#T@;60U*&UI8W)O=&EM92@I*3L*("`@("`@("`D
M=&AI<RT^7VYA;64@/2`D;F%M93L*("`@("`@("`D=&AI<RT^7VED96YT(#T@
M)&ED96YT.PH@("`@("`@("1T:&ES+3Y?;6%S:R`]($QO9SHZ55!43R@D;&5V
M96PI.PH@("`@?0H*("`@("\J*@H@("`@("H@3W!E;G,@82!C;VYN96-T:6]N
M('1O('1H92!S>7-T96T@;&]G9V5R+"!I9B!I="!H87,@;F]T(&%L<F5A9'D*
M("`@("`J(&)E96X@;W!E;F5D+B`@5&AI<R!I<R!I;7!L:6-I=&QY(&-A;&QE
M9"!B>2!L;V<H*2P@:68@;F5C97-S87)Y+@H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J+PH@("`@9G5N8W1I;VX@;W!E;B@I"B`@("!["B`@("`@("`@
M:68@*"$D=&AI<RT^7V]P96YE9"D@>PH@("`@("`@("`@("!O<&5N;&]G*"1T
M:&ES+3Y?:61E;G0L($Q/1U]0240L("1T:&ES+3Y?;F%M92D["B`@("`@("`@
M("`@("1T:&ES+3Y?;W!E;F5D(#T@=')U93L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D=&AI<RT^7V]P96YE9#L*("`@('T*"B`@("`O*BH*("`@("`J
M($-L;W-E<R!T:&4@8V]N;F5C=&EO;B!T;R!T:&4@<WES=&5M(&QO9V=E<BP@
M:68@:70@:7,@;W!E;BX*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&-L;W-E*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M
M/E]O<&5N960I('L*("`@("`@("`@("`@8VQO<V5L;V<H*3L*("`@("`@("`@
M("`@)'1H:7,M/E]O<&5N960@/2!F86QS93L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`H)'1H:7,M/E]O<&5N960@/3T](&9A;'-E*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E;F1S("1M97-S86=E('1O('1H92!C=7)R96YT;'D@
M;W!E;B!S>7-L;V<@8V]N;F5C=&EO;BX@($-A;&QS"B`@("`@*B!O<&5N*"D@
M:68@;F5C97-S87)Y+B!!;'-O('!A<W-E<R!T:&4@;65S<V%G92!A;&]N9R!T
M;R!A;GD@3&]G7V]B<V5R=F5R"B`@("`@*B!I;G-T86YC97,@=&AA="!A<F4@
M;V)S97)V:6YG('1H:7,@3&]G+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE
M9"`D;65S<V%G92!3=')I;F<@;W(@;V)J96-T(&-O;G1A:6YI;F<@=&AE(&UE
M<W-A9V4@=&\@;&]G+@H@("`@("H@0'!A<F%M(&EN="`D<')I;W)I='D@*&]P
M=&EO;F%L*2!4:&4@<')I;W)I='D@;V8@=&AE(&UE<W-A9V4N("!686QI9`H@
M("`@("H@("`@("`@("`@("`@("`@("!V86QU97,@87)E.B!014%27TQ/1U]%
M34521RP@4$5!4E],3T=?04Q%4E0L"B`@("`@*B`@("`@("`@("`@("`@("`@
M(%!%05)?3$]'7T-2250L(%!%05)?3$]'7T524BP@4$5!4E],3T=?5T%23DE.
M1RP*("`@("`J("`@("`@("`@("`@("`@("`@4$5!4E],3T=?3D]424-%+"!0
M14%27TQ/1U])3D9/+"!A;F0@4$5!4E],3T=?1$5"54<N"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<R!O<B!F86QS92!O;B!F86EL
M=7)E+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I
M;VX@;&]G*"1M97-S86=E+"`D<')I;W)I='D@/2!N=6QL*0H@("`@>PH@("`@
M("`@("\J($EF(&$@<')I;W)I='D@:&%S;B=T(&)E96X@<W!E8VEF:65D+"!U
M<V4@=&AE(&1E9F%U;'0@=F%L=64N("HO"B`@("`@("`@:68@*"1P<FEO<FET
M>2`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D<')I;W)I='D@/2`D=&AI<RT^
M7W!R:6]R:71Y.PH@("`@("`@('T*"B`@("`@("`@+RH@06)O<G0@96%R;'D@
M:68@=&AE('!R:6]R:71Y(&ES(&%B;W9E('1H92!M87AI;75M(&QO9V=I;F<@
M;&5V96PN("HO"B`@("`@("`@:68@*"$D=&AI<RT^7VES36%S:V5D*"1P<FEO
M<FET>2DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M"B`@("`@("`@+RH@268@=&AE(&-O;FYE8W1I;VX@:7-N)W0@;W!E;B!A;F0@
M8V%N)W0@8F4@;W!E;F5D+"!R971U<FX@9F%I;'5R92X@*B\*("`@("`@("!I
M9B`H(21T:&ES+3Y?;W!E;F5D("8F("$D=&AI<RT^;W!E;B@I*2!["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("\J($5X
M=')A8W0@=&AE('-T<FEN9R!R97!R97-E;G1A=&EO;B!O9B!T:&4@;65S<V%G
M92X@*B\*("`@("`@("`D;65S<V%G92`]("1T:&ES+3Y?97AT<F%C=$UE<W-A
M9V4H)&UE<W-A9V4I.PH*("`@("`@("!I9B`H(7-Y<VQO9R@D=&AI<RT^7W1O
M4WES;&]G*"1P<FEO<FET>2DL("1M97-S86=E*2D@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V%N;F]U
M;F-E*&%R<F%Y*"=P<FEO<FET>2<@/3X@)'!R:6]R:71Y+"`G;65S<V%G92<@
M/3X@)&UE<W-A9V4I*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#;VYV97)T<R!A(%!%05)?3$]'7RH@8V]N<W1A;G0@
M:6YT;R!A('-Y<VQO9R!,3T=?*B!C;VYS=&%N="X*("`@("`J"B`@("`@*B!4
M:&ES(&9U;F-T:6]N(&5X:7-T<R!B96-A=7-E+"!U;F1E<B!7:6YD;W=S+"!N
M;W0@86QL(&]F('1H92!,3T=?*@H@("`@("H@8V]N<W1A;G1S(&AA=F4@=6YI
M<75E('9A;'5E<RX@($EN<W1E860L('1H92!014%27TQ/1U\J('=E<F4@:6YT
M<F]D=6-E9`H@("`@("H@9F]R(&=L;V)A;"!U<V4L('=I=&@@=&AE(&-O;G9E
M<G-I;VX@=&\@=&AE($Q/1U\J(&-O;G-T86YT<R!K97!T(&QO8V%L('1O"B`@
M("`@*B!T;R!T:&4@<WES;&]G(&1R:79E<BX*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT("1P<FEO<FET>2`@("`@4$5!4E],3T=?*B!V86QU92!T;R!C;VYV
M97)T('1O($Q/1U\J('9A;'5E+@H@("`@("H*("`@("`J($!R971U<FX@(%1H
M92!,3T=?*B!R97!R97-E;G1A=&EO;B!O9B`D<')I;W)I='DN"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]T
M;U-Y<VQO9R@D<')I;W)I='DI"B`@("!["B`@("`@("`@<W1A=&EC("1P<FEO
M<FET:65S(#T@87)R87DH"B`@("`@("`@("`@(%!%05)?3$]'7T5-15)'("`@
M/3X@3$]'7T5-15)'+`H@("`@("`@("`@("!014%27TQ/1U]!3$525"`@(#T^
M($Q/1U]!3$525"P*("`@("`@("`@("`@4$5!4E],3T=?0U))5"`@("`]/B!,
M3T=?0U))5"P*("`@("`@("`@("`@4$5!4E],3T=?15)2("`@("`]/B!,3T=?
M15)2+`H@("`@("`@("`@("!014%27TQ/1U]705).24Y'(#T^($Q/1U]705).
M24Y'+`H@("`@("`@("`@("!014%27TQ/1U].3U1)0T4@(#T^($Q/1U].3U1)
M0T4L"B`@("`@("`@("`@(%!%05)?3$]'7TE.1D\@("`@/3X@3$]'7TE.1D\L
M"B`@("`@("`@("`@(%!%05)?3$]'7T1%0E5'("`@/3X@3$]'7T1%0E5'"B`@
M("`@("`@*3L*"B`@("`@("`@+RH@268@=V4G<F4@<&%S<V5D(&%N('5N:VYO
M=VX@<')I;W)I='DL(&1E9F%U;'0@=&\@3$]'7TE.1D\N("HO"B`@("`@("`@
M:68@*"%I<U]I;G0H)'!R:6]R:71Y*2!\?"`A:6Y?87)R87DH)'!R:6]R:71Y
M+"`D<')I;W)I=&EE<RDI('L*("`@("`@("`@("`@<F5T=7)N($Q/1U])3D9/
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1P<FEO<FET:65S6R1P<FEO
M<FET>5T["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O3&]G+W=I;BYP:'``````````````````````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q-S(V,R`Q,#4Q-30S,S<S
M,2`P,C`U,C0`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J("1(96%D97(Z("]R97!O<VET;W)Y+W!E87(O
M3&]G+TQO9R]W:6XN<&AP+'8@,2XQ."`R,#`V+S`S+S`R(#`S.C`V.C0S(&IO
M;B!%>'`@)`H@*@H@*B!`=F5R<VEO;B`D4F5V:7-I;VXZ(#$N,3@@)`H@*B!`
M<&%C:V%G92!,;V<*("HO"@HO*BH*("H@5&AE($QO9U]W:6X@8VQA<W,@:7,@
M82!C;VYC<F5T92!I;7!L96UE;G1A=&EO;B!O9B!T:&4@3&]G(&%B<W1R86-T
M"B`J(&-L87-S('1H870@;&]G<R!M97-S86=E<R!T;R!A('-E<&%R871E(&)R
M;W=S97(@=VEN9&]W+@H@*@H@*B!4:&4@8V]N8V5P="!F;W(@=&AI<R!L;V<@
M:&%N9&QE<B!I<R!B87-E9"!O;B!P87)T(&)Y($-R86EG($1A=FES)R!A<G1I
M8VQE"B`J(&5N=&ET;&5D(")*879A4V-R:7!T(%!O=V5R(%!(4"!$96)U9V=I
M;F<Z"B`J"B`J("!H='1P.B\O=W=W+GIE;F0N8V]M+WIE;F0O='5T+W1U=&]R
M:6%L+41E8G5G3&EB+G!H<`H@*@H@*B!`875T:&]R("!*;VX@4&%R:7-E(#QJ
M;VY`<&AP+FYE=#X*("H@0'-I;F-E("`@3&]G(#$N-RXP"B`J($!P86-K86=E
M($QO9PH@*@H@*B!`97AA;7!L92!W:6XN<&AP("`@("!5<VEN9R!T:&4@=VEN
M9&]W(&AA;F1L97(N"B`J+PIC;&%S<R!,;V=?=VEN(&5X=&5N9',@3&]G"GL*
M("`@("\J*@H@("`@("H@5&AE(&YA;64@;V8@=&AE(&]U='!U="!W:6YD;W<N
M"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*B\*("`@('9A<B`D7VYA;64@/2`G3&]G5VEN9&]W)SL*"B`@("`O*BH*
M("`@("`J(%1H92!T:71L92!O9B!T:&4@;W5T<'5T('=I;F1O=RX*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@
M("`@=F%R("1?=&ET;&4@/2`G3&]G($]U='!U="!7:6YD;W<G.PH*("`@("\J
M*@H@("`@("H@36%P<&EN9R!O9B!L;V<@<')I;W)I=&EE<R!T;R!C;VQO<G,N
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J+PH@("`@=F%R("1?8V]L;W)S(#T@87)R87DH"B`@("`@("`@("`@("`@
M("`@("`@("`@(%!%05)?3$]'7T5-15)'("`@/3X@)W)E9"<L"B`@("`@("`@
M("`@("`@("`@("`@("`@(%!%05)?3$]'7T%,15)4("`@/3X@)V]R86YG92<L
M"B`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?3$]'7T-2250@("`@/3X@
M)WEE;&QO=R<L"B`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?3$]'7T52
M4B`@("`@/3X@)V=R965N)RP*("`@("`@("`@("`@("`@("`@("`@("`@4$5!
M4E],3T=?5T%23DE.1R`]/B`G8FQU92<L"B`@("`@("`@("`@("`@("`@("`@
M("`@(%!%05)?3$]'7TY/5$E#12`@/3X@)VEN9&EG;R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@(%!%05)?3$]'7TE.1D\@("`@/3X@)W9I;VQE="<L"B`@
M("`@("`@("`@("`@("`@("`@("`@(%!%05)?3$]'7T1%0E5'("`@/3X@)V)L
M86-K)PH@("`@("`@("`@("`@("`@("`@("D["@H@("`@+RHJ"B`@("`@*B!3
M=')I;F<@8G5F9F5R('1H870@:&]L9',@;&EN92!T:&%T(&%R92!P96YD:6YG
M(&]U='!U="X*("`@("`J($!V87(@87)R87D*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("HO"B`@("!V87(@)%]B=69F97(@/2!A<G)A>2@I.PH*("`@
M("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!,;V=?=VEN(&]B:F5C="X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("!)9VYO<F5D
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:61E;G0@("`@5&AE(&ED96YT:71Y
M('-T<FEN9RX*("`@("`J($!P87)A;2!A<G)A>2`@)&-O;F8@("`@(%1H92!C
M;VYF:6=U<F%T:6]N(&%R<F%Y+@H@("`@("H@0'!A<F%M(&EN="`@("`D;&5V
M96P@("`@3&]G(&UE<W-A9V5S('5P('1O(&%N9"!I;F-L=61I;F<@=&AI<R!L
M979E;"X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T
M:6]N($QO9U]W:6XH)&YA;64L("1I9&5N="`]("<G+"`D8V]N9B`](&%R<F%Y
M*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@)&QE=F5L(#T@4$5!4E],
M3T=?1$5"54<I"B`@("!["B`@("`@("`@)'1H:7,M/E]I9"`](&UD-2AM:6-R
M;W1I;64H*2D["B`@("`@("`@)'1H:7,M/E]N86UE(#T@)&YA;64["B`@("`@
M("`@)'1H:7,M/E]I9&5N="`]("1I9&5N=#L*("`@("`@("`D=&AI<RT^7VUA
M<VL@/2!,;V<Z.E505$\H)&QE=F5L*3L*"B`@("`@("`@:68@*&ES<V5T*"1C
M;VYF6R=T:71L92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W1I=&QE(#T@
M)&-O;F9;)W1I=&QE)UT["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D
M8V]N9ELG8V]L;W)S)UTI("8F(&ES7V%R<F%Y*"1C;VYF6R=C;VQO<G,G72DI
M('L*("`@("`@("`@("`@)'1H:7,M/E]C;VQO<G,@/2`D8V]N9ELG8V]L;W)S
M)UT["B`@("`@("`@?0H*("`@("`@("!R96=I<W1E<E]S:'5T9&]W;E]F=6YC
M=&EO;BAA<G)A>2@F)'1H:7,L("=?3&]G7W=I;B<I*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($1E<W1R=6-T;W(*("`@("`J+PH@("`@9G5N8W1I;VX@7TQO
M9U]W:6XH*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V]P96YE9"!\?"`H
M8V]U;G0H)'1H:7,M/E]B=69F97(I(#X@,"DI('L*("`@("`@("`@("`@)'1H
M:7,M/F-L;W-E*"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M5&AE(&9I<G-T('1I;64@;W!E;B@I(&ES(&-A;&QE9"P@:70@=VEL;"!O<&5N
M(&$@;F5W(&)R;W=S97(@=VEN9&]W(&%N9`H@("`@("H@<')E<&%R92!I="!F
M;W(@;W5T<'5T+@H@("`@("H*("`@("`J(%1H:7,@:7,@:6UP;&EC:71L>2!C
M86QL960@8GD@;&]G*"DL(&EF(&YE8V5S<V%R>2X*("`@("`J"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!O<&5N*"D*("`@
M('L*("`@("`@("!I9B`H(21T:&ES+3Y?;W!E;F5D*2!["B`@("`@("`@("`@
M("1W:6X@/2`D=&AI<RT^7VYA;64["@H@("`@("`@("`@("!I9B`H(65M<'1Y
M*"1T:&ES+3Y?:61E;G0I*2!["B`@("`@("`@("`@("`@("`D:61E;G1(96%D
M97(@/2`B)'=I;BYD;V-U;65N="YW<FET96QN*"<\=&@^261E;G0\+W1H/B<I
M(CL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1I9&5N
M=$AE861E<B`]("<G.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!E8VAO
M(#P\/"!%3D1?3T9?4T-225!4"CQS8W)I<'0@;&%N9W5A9V4](DIA=F%38W)I
M<'0B/@HD=VEN(#T@=VEN9&]W+F]P96XH)R<L("=[)'1H:7,M/E]N86UE?2<L
M("=T;V]L8F%R/6YO+'-C<F]L;&)A<G,L=VED=&@]-C`P+&AE:6=H=#TT,#`G
M*3L*)'=I;BYD;V-U;65N="YW<FET96QN*"<\:'1M;#XG*3L*)'=I;BYD;V-U
M;65N="YW<FET96QN*"<\:&5A9#XG*3L*)'=I;BYD;V-U;65N="YW<FET96QN
M*"<\=&ET;&4^>R1T:&ES+3Y?=&ET;&5]/"]T:71L93XG*3L*)'=I;BYD;V-U
M;65N="YW<FET96QN*"<\<W1Y;&4@='EP93TB=&5X="]C<W,B/B<I.PHD=VEN
M+F1O8W5M96YT+G=R:71E;&XH)V)O9'D@>R!F;VYT+69A;6EL>3H@;6]N;W-P
M86-E.R!F;VYT+7-I>F4Z(#AP=#L@?2<I.PHD=VEN+F1O8W5M96YT+G=R:71E
M;&XH)W1D+'1H('L@9F]N="US:7IE.B`X<'0[('TG*3L*)'=I;BYD;V-U;65N
M="YW<FET96QN*"=T9"QT:"![(&)O<F1E<BUB;W1T;VTZ(",Y.3DY.3D@<V]L
M:60@,7!X.R!])RD["B1W:6XN9&]C=6UE;G0N=W)I=&5L;B@G=&0L=&@@>R!B
M;W)D97(M<FEG:'0Z(",Y.3DY.3D@<V]L:60@,7!X.R!])RD["B1W:6XN9&]C
M=6UE;G0N=W)I=&5L;B@G='(@>R!T97AT+6%L:6=N.B!L969T.R!V97)T:6-A
M;"UA;&EG;CH@=&]P.R!])RD["B1W:6XN9&]C=6UE;G0N=W)I=&5L;B@G/"]S
M='EL93XG*3L*)'=I;BYD;V-U;65N="YW<FET96QN*"<\+VAE860^)RD["B1W
M:6XN9&]C=6UE;G0N=W)I=&5L;B@G/&)O9'D^)RD["B1W:6XN9&]C=6UE;G0N
M=W)I=&5L;B@G/'1A8FQE(&)O<F1E<CTB,"(@8V5L;'!A9&1I;F<](C(B(&-E
M;&QS<&%C:6YG/2(P(CXG*3L*)'=I;BYD;V-U;65N="YW<FET96QN*"<\='(^
M/'1H/E1I;64\+W1H/B<I.PHD:61E;G1(96%D97(*)'=I;BYD;V-U;65N="YW
M<FET96QN*"<\=&@^4')I;W)I='D\+W1H/CQT:"!W:61T:#TB,3`P)2(^365S
M<V%G93PO=&@^/"]T<CXG*3L*/"]S8W)I<'0^"D5.1%]/1E]30U))4%0["B`@
M("`@("`@("`@("1T:&ES+3Y?;W!E;F5D(#T@=')U93L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D=&AI<RT^7V]P96YE9#L*("`@('T*"B`@("`O*BH*
M("`@("`J($-L;W-E<R!T:&4@;W5T<'5T('-T<F5A;2!I9B!I="!I<R!O<&5N
M+B`@268@=&AE<F4@87)E('-T:6QL('!E;F1I;F<*("`@("`J(&QI;F5S(&EN
M('1H92!O=71P=70@8G5F9F5R+"!T:&4@;W5T<'5T('=I;F1O=R!W:6QL(&)E
M(&]P96YE9"!S;R!T:&%T"B`@("`@*B!T:&4@8G5F9F5R(&-A;B!B92!D<F%I
M;F5D+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-L;W-E*"D*("`@('L*("`@("`@("`O*@H@("`@("`@("`J
M($EF('1H97)E(&%R92!S=&EL;"!L:6YE<R!W86ET:6YG('1O(&)E('=R:71T
M96XL(&]P96X@=&AE(&]U='!U=`H@("`@("`@("`J('=I;F1O=R!S;R!T:&%T
M('=E(&-A;B!D<F%I;B!T:&4@8G5F9F5R+@H@("`@("`@("`J+PH@("`@("`@
M(&EF("@A)'1H:7,M/E]O<&5N960@)B8@*&-O=6YT*"1T:&ES+3Y?8G5F9F5R
M*2`^(#`I*2!["B`@("`@("`@("`@("1T:&ES+3YO<&5N*"D["B`@("`@("`@
M?0H*("`@("`@("!I9B`H)'1H:7,M/E]O<&5N960I('L*("`@("`@("`@("`@
M)'1H:7,M/E]W<FET96QN*"<\+W1A8FQE/B<I.PH@("`@("`@("`@("`D=&AI
M<RT^7W=R:71E;&XH)SPO8F]D>3X\+VAT;6P^)RD["B`@("`@("`@("`@("1T
M:&ES+3Y?;W!E;F5D(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@*"1T:&ES+3Y?;W!E;F5D(#T]/2!F86QS92D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!7<FET97,@82!S:6YG;&4@;&EN92!O9B!T97AT('1O('1H92!O
M=71P=70@=VEN9&]W+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("`@
M)&QI;F4@("!4:&4@;&EN92!O9B!T97AT('1O('=R:71E+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?=W)I
M=&5L;B@D;&EN92D*("`@('L*("`@("`@("`O*B!!9&0@=&AI<R!L:6YE('1O
M(&]U<B!O=71P=70@8G5F9F5R+B`J+PH@("`@("`@("1T:&ES+3Y?8G5F9F5R
M6UT@/2`D;&EN93L*"B`@("`@("`@+RH@0G5F9F5R('1H92!O=71P=70@=6YT
M:6P@=&AI<R!P86=E)W,@:&5A9&5R<R!H879E(&)E96X@<V5N="X@*B\*("`@
M("`@("!I9B`H(6AE861E<G-?<V5N="@I*2!["B`@("`@("`@("`@(')E='5R
M;CL*("`@("`@("!]"@H@("`@("`@("\J($EF('=E(&AA=F5N)W0@86QR96%D
M>2!O<&5N960@=&AE(&]U='!U="!W:6YD;W<L(&1O('-O(&YO=RX@*B\*("`@
M("`@("!I9B`H(21T:&ES+3Y?;W!E;F5D("8F("$D=&AI<RT^;W!E;B@I*2![
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@
M("\J($1R86EN('1H92!B=69F97(@=&\@=&AE(&]U='!U="!W:6YD;W<N("HO
M"B`@("`@("`@)'=I;B`]("1T:&ES+3Y?;F%M93L*("`@("`@("!F;W)E86-H
M("@D=&AI<RT^7V)U9F9E<B!A<R`D;&EN92D@>PH@("`@("`@("`@("!E8VAO
M("(\<V-R:7!T(&QA;F=U86=E/2=*879A4V-R:7!T)SY<;B(["B`@("`@("`@
M("`@(&5C:&\@(B1W:6XN9&]C=6UE;G0N=W)I=&5L;B@G(B`N(&%D9'-L87-H
M97,H)&QI;F4I("X@(B<I.UQN(CL*("`@("`@("`@("`@96-H;R`B<V5L9BYF
M;V-U<R@I.UQN(CL*("`@("`@("`@("`@96-H;R`B/"]S8W)I<'0^7&XB.PH@
M("`@("`@('T*"B`@("`@("`@+RH@3F]W('1H870@=&AE(&)U9F9E<B!H87,@
M8F5E;B!D<F%I;F5D+"!C;&5A<B!I="X@*B\*("`@("`@("`D=&AI<RT^7V)U
M9F9E<B`](&%R<F%Y*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!,;V=S("1M
M97-S86=E('1O('1H92!O=71P=70@=VEN9&]W+B`@5&AE(&UE<W-A9V4@:7,@
M86QS;R!P87-S960@86QO;F<*("`@("`J('1O(&%N>2!,;V=?;V)S97)V97(@
M:6YS=&%N8V5S('1H870@87)E(&]B<V5R=FEN9R!T:&ES($QO9RX*("`@("`J
M"B`@("`@*B!`<&%R86T@;6EX960@("1M97-S86=E("!3=')I;F<@;W(@;V)J
M96-T(&-O;G1A:6YI;F<@=&AE(&UE<W-A9V4@=&\@;&]G+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<')I;W)I='D@5&AE('!R:6]R:71Y(&]F('1H92!M97-S
M86=E+B`@5F%L:60*("`@("`J("`@("`@("`@("`@("`@("`@=F%L=65S(&%R
M93H@4$5!4E],3T=?14U%4D<L(%!%05)?3$]'7T%,15)4+`H@("`@("H@("`@
M("`@("`@("`@("`@("!014%27TQ/1U]#4DE4+"!014%27TQ/1U]%4E(L(%!%
M05)?3$]'7U=!4DY)3D<L"B`@("`@*B`@("`@("`@("`@("`@("`@(%!%05)?
M3$]'7TY/5$E#12P@4$5!4E],3T=?24Y&3RP@86YD(%!%05)?3$]'7T1%0E5'
M+@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,@;W(@
M9F%L<V4@;VX@9F%I;'5R92X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&QO9R@D;65S<V%G92P@)'!R:6]R:71Y(#T@;G5L
M;"D*("`@('L*("`@("`@("`O*B!)9B!A('!R:6]R:71Y(&AA<VXG="!B965N
M('-P96-I9FEE9"P@=7-E('1H92!D969A=6QT('9A;'5E+B`J+PH@("`@("`@
M(&EF("@D<')I;W)I='D@/3T](&YU;&PI('L*("`@("`@("`@("`@)'!R:6]R
M:71Y(#T@)'1H:7,M/E]P<FEO<FET>3L*("`@("`@("!]"@H@("`@("`@("\J
M($%B;W)T(&5A<FQY(&EF('1H92!P<FEO<FET>2!I<R!A8F]V92!T:&4@;6%X
M:6UU;2!L;V=G:6YG(&QE=F5L+B`J+PH@("`@("`@(&EF("@A)'1H:7,M/E]I
M<TUA<VME9"@D<')I;W)I='DI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"@H@("`@("`@("\J($5X=')A8W0@=&AE('-T<FEN9R!R
M97!R97-E;G1A=&EO;B!O9B!T:&4@;65S<V%G92X@*B\*("`@("`@("`D;65S
M<V%G92`]("1T:&ES+3Y?97AT<F%C=$UE<W-A9V4H)&UE<W-A9V4I.PH*("`@
M("`@("!L:7-T*"1U<V5C+"`D<V5C*2`](&5X<&QO9&4H)R`G+"!M:6-R;W1I
M;64H*2D["@H@("`@("`@("\J($)U:6QD('1H92!O=71P=70@;&EN92!T:&%T
M(&-O;G1A:6YS('1H92!L;V<@96YT<GD@<F]W+B`J+PH@("`@("`@("1L:6YE
M("`]("<\='(^)SL*("`@("`@("`D;&EN92`N/2!S<')I;G1F*"<\=&0^)7,N
M)7,\+W1D/B<L"B`@("`@("`@("`@("`@("`@("`@("`@("!S=')F=&EM92@G
M)50G+"`D<V5C*2P@<W5B<W1R*"1U<V5C+"`R+"`R*2D["B`@("`@("`@:68@
M*"%E;7!T>2@D=&AI<RT^7VED96YT*2D@>PH@("`@("`@("`@("`D;&EN92`N
M/2`G/'1D/B<@+B`D=&AI<RT^7VED96YT("X@)SPO=&0^)SL*("`@("`@("!]
M"B`@("`@("`@)&QI;F4@+CT@)SQT9#XG("X@=6-F:7)S="@D=&AI<RT^<')I
M;W)I='E4;U-T<FEN9R@D<')I;W)I='DI*2`N("<\+W1D/B<["B`@("`@("`@
M)&QI;F4@+CT@<W!R:6YT9B@G/'1D('-T>6QE/2)C;VQO<CH@)7,B/B5S/"]T
M9#XG+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C;VQO<G-;
M)'!R:6]R:71Y72P*("`@("`@("`@("`@("`@("`@("`@("`@('!R96=?<F5P
M;&%C92@G+UQR7&Y\7&Y\7'(O)RP@)SQB<B`O/B<L("1M97-S86=E*2D["B`@
M("`@("`@)&QI;F4@+CT@)SPO='(^)SL*"B`@("`@("`@)'1H:7,M/E]W<FET
M96QN*"1L:6YE*3L*"B`@("`@("`@)'1H:7,M/E]A;FYO=6YC92AA<G)A>2@G
M<')I;W)I='DG(#T^("1P<FEO<FET>2P@)VUE<W-A9V4G(#T^("1M97-S86=E
M*2D["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+TQO9R]C;VYS
M;VQE+G!H<```````````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,3(S,S,@,3`U,34T,S,W,S$@,#(Q,S8R`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B`D2&5A9&5R
M.B`O<F5P;W-I=&]R>2]P96%R+TQO9R],;V<O8V]N<V]L92YP:'`L=B`Q+C(R
M(#(P,#8O,#$O,3$@,#<Z-38Z,S<@:F]N($5X<"`D"B`J"B`J($!V97)S:6]N
M("12979I<VEO;CH@,2XR,B`D"B`J($!P86-K86=E($QO9PH@*B\*"B\J*@H@
M*B!4:&4@3&]G7V-O;G-O;&4@8VQA<W,@:7,@82!C;VYC<F5T92!I;7!L96UE
M;G1A=&EO;B!O9B!T:&4@3&]G.CH*("H@86)S=')A8W0@8VQA<W,@=VAI8V@@
M=W)I=&5S(&UE<W-A9V4@=&\@=&AE('1E>'0@8V]N<V]L92X*("H@"B`J($!A
M=71H;W(@($IO;B!087)I<V4@/&IO;D!P:'`N;F5T/@H@*B!`<VEN8V4@("!,
M;V<@,2XQ"B`J($!P86-K86=E($QO9PH@*@H@*B!`97AA;7!L92!C;VYS;VQE
M+G!H<"`@("`@57-I;F<@=&AE(&-O;G-O;&4@:&%N9&QE<BX*("HO"F-L87-S
M($QO9U]C;VYS;VQE(&5X=&5N9',@3&]G"GL*("`@("\J*@H@("`@("H@2&%N
M9&QE('1O('1H92!C=7)R96YT(&]U='!U="!S=')E86TN"B`@("`@*B!`=F%R
M(')E<V]U<F-E"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@
M=F%R("1?<W1R96%M(#T@4U1$3U54.PH*("`@("\J*@H@("`@("H@4VAO=6QD
M('1H92!O=71P=70@8F4@8G5F9F5R960@;W(@9&ES<&QA>65D(&EM;65D:6%T
M96QY/PH@("`@("H@0'9A<B!S=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("HO"B`@("!V87(@)%]B=69F97)I;F<@/2!F86QS93L*"B`@("`O
M*BH*("`@("`J(%-T<FEN9R!H;VQD:6YG('1H92!B=69F97)E9"!O=71P=70N
M"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*B\*("`@('9A<B`D7V)U9F9E<B`]("<G.PH*("`@("\J*@H@("`@("H@
M4W1R:6YG(&-O;G1A:6YI;F<@=&AE(&9O<FUA="!O9B!A(&QO9R!L:6YE+@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("HO"B`@("!V87(@)%]L:6YE1F]R;6%T(#T@)R4Q)',@)3(D<R!;)3,D<UT@
M)30D<R<["@H@("`@+RHJ"B`@("`@*B!3=')I;F<@8V]N=&%I;FEN9R!T:&4@
M=&EM97-T86UP(&9O<FUA="X@($ET('=I;&P@8F4@<&%S<V5D(&1I<F5C=&QY
M('1O"B`@("`@*B!S=')F=&EM92@I+B`@3F]T92!T:&%T('1H92!T:6UE<W1A
M;7`@<W1R:6YG('=I;&P@9V5N97)A=&5D('5S:6YG('1H90H@("`@("H@8W5R
M<F5N="!L;V-A;&4N"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7W1I;65&;W)M870@/2`G)6(@
M)60@)4@Z)4TZ)5,G.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE
M=R!,;V=?8V]N<V]L92!O8FIE8W0N"B`@("`@*B`*("`@("`J($!P87)A;2!S
M=')I;F<@)&YA;64@("`@($EG;F]R960N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1I9&5N="`@("!4:&4@:61E;G1I='D@<W1R:6YG+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("`D8V]N9B`@("`@5&AE(&-O;F9I9W5R871I;VX@87)R87DN"B`@
M("`@*B!`<&%R86T@:6YT("`@("1L979E;"`@("!,;V<@;65S<V%G97,@=7`@
M=&\@86YD(&EN8VQU9&EN9R!T:&ES(&QE=F5L+@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@3&]G7V-O;G-O;&4H)&YA;64L
M("1I9&5N="`]("<G+"`D8V]N9B`](&%R<F%Y*"DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`D;&5V96P@/2!014%27TQ/1U]$14)51RD*("`@('L*("`@
M("`@("`D=&AI<RT^7VED(#T@;60U*&UI8W)O=&EM92@I*3L*("`@("`@("`D
M=&AI<RT^7VED96YT(#T@)&ED96YT.PH@("`@("`@("1T:&ES+3Y?;6%S:R`]
M($QO9SHZ55!43R@D;&5V96PI.PH*("`@("`@("!I9B`H(65M<'1Y*"1C;VYF
M6R=S=')E86TG72DI('L*("`@("`@("`@("`@)'1H:7,M/E]S=')E86T@/2`D
M8V]N9ELG<W1R96%M)UT["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H
M)&-O;F9;)V)U9F9E<FEN9R==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V)U
M9F9E<FEN9R`]("1C;VYF6R=B=69F97)I;F<G73L*("`@("`@("!]"@H@("`@
M("`@(&EF("@A96UP='DH)&-O;F9;)VQI;F5&;W)M870G72DI('L*("`@("`@
M("`@("`@)'1H:7,M/E]L:6YE1F]R;6%T(#T@<W1R7W)E<&QA8V4H87)R87E?
M:V5Y<R@D=&AI<RT^7V9O<FUA=$UA<"DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W9A;'5E<R@D=&AI<RT^
M7V9O<FUA=$UA<"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1C;VYF6R=L:6YE1F]R;6%T)UTI.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"%E;7!T>2@D8V]N9ELG=&EM949O<FUA="==*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7W1I;65&;W)M870@/2`D8V]N9ELG=&EM949O
M<FUA="==.PH@("`@("`@('T*"B`@("`@("`@+RH*("`@("`@("`@*B!)9B!O
M=71P=70@8G5F9F5R:6YG(&AA<R!B965N(')E<75E<W1E9"P@=V4@;F5E9"!T
M;R!R96=I<W1E<B!A"B`@("`@("`@("H@<VAU=&1O=VX@9G5N8W1I;VX@=&AA
M="!W:6QL(&1U;7`@=&AE(&)U9F9E<B!U<&]N('1E<FUI;F%T:6]N+@H@("`@
M("`@("`J+PH@("`@("`@(&EF("@D=&AI<RT^7V)U9F9E<FEN9RD@>PH@("`@
M("`@("`@("!R96=I<W1E<E]S:'5T9&]W;E]F=6YC=&EO;BAA<G)A>2@F)'1H
M:7,L("=?3&]G7V-O;G-O;&4G*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@1&5S=')U8W1O<@H@("`@("HO"B`@("!F=6YC=&EO;B!?3&]G
M7V-O;G-O;&4H*0H@("`@>PH@("`@("`@("1T:&ES+3YC;&]S92@I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@0VQO<V5S('1H92!O=71P=70@<W1R96%M+@H@
M("`@("H*("`@("`J(%1H:7,@<F5S=6QT<R!I;B!A(&-A;&P@=&\@9FQU<V@H
M*2X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-I;F-E
M($QO9R`Q+CDN,`H@("`@("HO"B`@("!F=6YC=&EO;B!C;&]S92@I"B`@("![
M"B`@("`@("`@)'1H:7,M/F9L=7-H*"D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!&;'5S:&5S(&%L;"!P96YD:6YG("@B8G5F9F5R960B*2!D871A('1O('1H
M92!O=71P=70@<W1R96%M+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B!`<VEN8V4@3&]G(#$N."XR"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&9L=7-H*"D*("`@('L*("`@("`@("`O*@H@("`@("`@("`J($EF(&]U='!U
M="!B=69F97)I;F<@:7,@96YA8FQE9"P@9'5M<"!T:&4@8V]N=&5N=',@;V8@
M=&AE(&)U9F9E<B!T;PH@("`@("`@("`J('1H92!O=71P=70@<W1R96%M+@H@
M("`@("`@("`J+PH@("`@("`@(&EF("@D=&AI<RT^7V)U9F9E<FEN9R`F)B`H
M<W1R;&5N*"1T:&ES+3Y?8G5F9F5R*2`^(#`I*2!["B`@("`@("`@("`@(&9W
M<FET92@D=&AI<RT^7W-T<F5A;2P@)'1H:7,M/E]B=69F97(I.PH@("`@("`@
M("`@("`D=&AI<RT^7V)U9F9E<B`]("<G.PH@("`@("`@('T*(`H@("`@("`@
M(')E='5R;B!F9FQU<V@H)'1H:7,M/E]S=')E86TI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@5W)I=&5S("1M97-S86=E('1O('1H92!T97AT(&-O;G-O;&4N
M($%L<V\L('!A<W-E<R!T:&4@;65S<V%G90H@("`@("H@86QO;F<@=&\@86YY
M($QO9U]O8G-E<G9E<B!I;G-T86YC97,@=&AA="!A<F4@;V)S97)V:6YG('1H
M:7,@3&]G+@H@("`@("H@"B`@("`@*B!`<&%R86T@;6EX960@("1M97-S86=E
M("`@(%-T<FEN9R!O<B!O8FIE8W0@8V]N=&%I;FEN9R!T:&4@;65S<V%G92!T
M;R!L;V<N"B`@("`@*B!`<&%R86T@<W1R:6YG("1P<FEO<FET>2!4:&4@<')I
M;W)I='D@;V8@=&AE(&UE<W-A9V4N("!686QI9`H@("`@("H@("`@("`@("`@
M("`@("`@("!V86QU97,@87)E.B!014%27TQ/1U]%34521RP@4$5!4E],3T=?
M04Q%4E0L"B`@("`@*B`@("`@("`@("`@("`@("`@(%!%05)?3$]'7T-2250L
M(%!%05)?3$]'7T524BP@4$5!4E],3T=?5T%23DE.1RP*("`@("`J("`@("`@
M("`@("`@("`@("`@4$5!4E],3T=?3D]424-%+"!014%27TQ/1U])3D9/+"!A
M;F0@4$5!4E],3T=?1$5"54<N"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R
M=64@;VX@<W5C8V5S<R!O<B!F86QS92!O;B!F86EL=7)E+@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@;&]G*"1M97-S86=E
M+"`D<')I;W)I='D@/2!N=6QL*0H@("`@>PH@("`@("`@("\J($EF(&$@<')I
M;W)I='D@:&%S;B=T(&)E96X@<W!E8VEF:65D+"!U<V4@=&AE(&1E9F%U;'0@
M=F%L=64N("HO"B`@("`@("`@:68@*"1P<FEO<FET>2`]/3T@;G5L;"D@>PH@
M("`@("`@("`@("`D<')I;W)I='D@/2`D=&AI<RT^7W!R:6]R:71Y.PH@("`@
M("`@('T*"B`@("`@("`@+RH@06)O<G0@96%R;'D@:68@=&AE('!R:6]R:71Y
M(&ES(&%B;W9E('1H92!M87AI;75M(&QO9V=I;F<@;&5V96PN("HO"B`@("`@
M("`@:68@*"$D=&AI<RT^7VES36%S:V5D*"1P<FEO<FET>2DI('L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+RH@17AT
M<F%C="!T:&4@<W1R:6YG(')E<')E<V5N=&%T:6]N(&]F('1H92!M97-S86=E
M+B`J+PH@("`@("`@("1M97-S86=E(#T@)'1H:7,M/E]E>'1R86-T365S<V%G
M92@D;65S<V%G92D["@H@("`@("`@("\J($)U:6QD('1H92!S=')I;F<@8V]N
M=&%I;FEN9R!T:&4@8V]M<&QE=&4@;&]G(&QI;F4N("HO"B`@("`@("`@)&QI
M;F4@/2`D=&AI<RT^7V9O<FUA="@D=&AI<RT^7VQI;F5&;W)M870L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!S=')F=&EM92@D=&AI<RT^7W1I
M;65&;W)M870I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!R
M:6]R:71Y+"`D;65S<V%G92D@+B`B7&XB.PH*("`@("`@("`O*@H@("`@("`@
M("`J($EF(&)U9F9E<FEN9R!I<R!E;F%B;&5D+"!A<'!E;F0@=&AI<R!L:6YE
M('1O('1H92!O=71P=70@8G5F9F5R+@H@("`@("`@("`J($]T:&5R=VES92P@
M<')I;G0@=&AE(&QI;F4@=&\@=&AE(&]U='!U="!S=')E86T@:6UM961I871E
M;'DN"B`@("`@("`@("HO"B`@("`@("`@:68@*"1T:&ES+3Y?8G5F9F5R:6YG
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?8G5F9F5R("X]("1L:6YE.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(&9W<FET92@D=&AI<RT^7W-T<F5A
M;2P@)&QI;F4I.PH@("`@("`@('T*"B`@("`@("`@+RH@3F]T:69Y(&]B<V5R
M=F5R<R!A8F]U="!T:&ES(&QO9R!M97-S86=E+B`J+PH@("`@("`@("1T:&ES
M+3Y?86YN;W5N8V4H87)R87DH)W!R:6]R:71Y)R`]/B`D<')I;W)I='DL("=M
M97-S86=E)R`]/B`D;65S<V%G92DI.PH*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+U-/05``````````````````````````````````
M````````````````````````````````````````````````````````,#`P
M-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S$@
M,#$W,30W`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4T]!4"]4<F%N<W!O
M<G0`````````````````````````````````````````````````````````
M```````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,#`P,"`Q,#4Q-30S,S<S,2`P,C$Q-#,`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]33T%0+U1R86YS<&]R="]33510+G!H<```````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#$V,S(T(#$P-3$U-#,S-S,Q(#`R,C4R-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@5&AI<R!F:6QE(&-O;G1A:6YS('1H92!C;V1E(&9O<B!A;B!33510
M('1R86YS<&]R="!L87EE<BX*("H*("H@5&AI<R!C;V1E(&ES('-T:6QL(&$@
M<F]U9V@@86YD('5N=&5S=&5D(&1R869T+@H@*B!43T1/.@H@*B`@<W=I=&-H
M('1O('!E87(@;6%I;"!S='5F9@H@*B`@<VUT<"!A=71H96YT:6-A=&EO;@H@
M*B`@<VUT<"!S<VP@<W5P<&]R=`H@*B`@86)I;&ET>2!T;R!D969I;F4@<VUT
M<"!O<'1I;VYS("AE;F-O9&EN9RP@9G)O;2P@971C+BD*("H*("H@4$A0('9E
M<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL
M92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N
M<V4L"B`J('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T
M:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@879A:6QA8FQE(&%T"B`J('1H<F]U
M9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T(&AT='`Z+R]W=W<N<&AP+FYE="]L
M:6-E;G-E+S)?,#(N='AT+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!A
M(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B
M=&%I;B!I=`H@*B!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E
M('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X*("H@
M;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@
M("!796(@4V5R=FEC97,*("H@0'!A8VMA9V4@("`@4T]!4`H@*B!`875T:&]R
M("`@("!3:&%N92!#87)A=F5O(#Q3:&%N94!#87)A=F5O+F-O;3X*("H@0&-O
M<'ER:6=H="`@,C`P,RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@
M("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0@(%!(4"!,
M:6-E;G-E(#(N,#(*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE
M="]P86-K86=E+U-/05`*("HO"@IR97%U:7)E7V]N8V4@)U-/05`O0F%S92YP
M:'`G.PIR97%U:7)E7V]N8V4@)TUA:6PO<VUT<"YP:'`G.PH*+RHJ"B`J("!3
M3510(%1R86YS<&]R="!F;W(@4T]!4`H@*@H@*B!I;7!L96UE;G1S(%-/05`M
M4TU44"!A<R!D969I;F5D(&%T"B`J(&AT='`Z+R]W=W<N<&]C:V5T<V]A<"YC
M;VTO<W!E8W,O<VUT<&)I;F1I;F<O"B`J"B`J(%1/1$\Z('5S92!014%2('-M
M='`@86YD($UI;64@8VQA<W-E<PH@*@H@*B!`86-C97-S('!U8FQI8PH@*B!`
M<&%C:V%G92!33T%0"B`J($!A=71H;W(@4VAA;F4@0V%R879E;R`\<VAA;F5`
M<&AP+FYE=#X*("HO"F-L87-S(%-/05!?5')A;G-P;W)T7U--5%`@97AT96YD
M<R!33T%07T)A<V4*>PH*("`@('9A<B`D8W)E9&5N=&EA;',@/2`G)SL*("`@
M('9A<B`D=&EM96]U="`](#0[("\O(&-O;FYE8W0@=&EM96]U=`H@("`@=F%R
M("1U<FQP87)T<R`]($Y53$P["B`@("!V87(@)'5R;"`]("<G.PH@("`@=F%R
M("1I;F-O;6EN9U]P87EL;V%D(#T@)R<["B`@("!V87(@)%]U<V5R06=E;G0@
M/2!33T%07TQ)0E)!4EE?3D%-13L*("`@('9A<B`D96YC;V1I;F<@/2!33T%0
M7T1%1D%53%1?14Y#3T1)3D<["B`@("!V87(@)&AO<W0@/2`G,3(W+C`N,"XQ
M)SL*("`@('9A<B`D<&]R="`](#(U.PH@("`@=F%R("1A=71H(#T@3E5,3#L*
M("`@("\J*@H@("`@*B!33T%07U1R86YS<&]R=%]33510($-O;G-T<G5C=&]R
M"B`@("`J"B`@("`J($!P87)A;2!S=')I;F<@)%523"`@("!M86EL=&\Z861D
M<F5S<PH@("`@*@H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B\*("`@(&9U
M;F-T:6]N(%-/05!?5')A;G-P;W)T7U--5%`H)%523"P@)&5N8V]D:6YG/2=5
M4RU!4T-)22<I"B`@("!["B`@("`@("`@<&%R96YT.CI33T%07T)A<V4H)U--
M5%`G*3L*("`@("`@("`D=&AI<RT^96YC;V1I;F<@/2`D96YC;V1I;F<["B`@
M("`@("`@)'1H:7,M/G5R;'!A<G1S(#T@0'!A<G-E7W5R;"@D55),*3L*("`@
M("`@("`D=&AI<RT^=7)L(#T@)%523#L*("`@('T*"B`@("`O*BH*("`@("H@
M<V5N9"!A;F0@<F5C96EV92!S;V%P(&1A=&$*("`@("H*("`@("H@0'!A<F%M
M('-T<FEN9R`F)&US9R`@("`@("!O=71G;VEN9R!P;W-T(&1A=&$*("`@("H@
M0'!A<F%M('-T<FEN9R`D86-T:6]N("`@("`@4T]!4"!!8W1I;VX@:&5A9&5R
M(&1A=&$*("`@("H@0'!A<F%M(&EN="`D=&EM96]U="`@<V]C:V5T('1I;65O
M=70L(&1E9F%U;'0@,"!O<B!O9F8*("`@("H*("`@("H@0')E='5R;B!S=')I
M;F<@)B1R97-P;VYS92`@(')E<W!O;G-E(&1A=&$L(&UI;G5S(&AT='`@:&5A
M9&5R<PH@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N
M('-E;F0H)B1M<V<L("`O*F%R<F%Y*B\@)&]P=&EO;G,@/2!.54Q,*0H@("`@
M>PH@("`@("`@("1T:&ES+3YI;F-O;6EN9U]P87EL;V%D(#T@)R<["B`@("`@
M("`@)'1H:7,M/F]U=&=O:6YG7W!A>6QO860@/2`F)&US9SL*("`@("`@("!I
M9B`H(21T:&ES+3Y?=F%L:61A=&55<FPH*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/F9A=6QT.PH@("`@("`@('T*("`@("`@("!I9B`H(21O<'1I
M;VYS('Q\("%A<G)A>5]K97E?97AI<W1S*"=F<F]M)RPD;W!T:6]N<RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(DYO
M($923TT@861D<F5S<R!T;R!S96YD(&UE<W-A9V4@=VET:"(I.PH@("`@("`@
M('T*"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=H;W-T)UTI*2`D=&AI
M<RT^:&]S="`]("1O<'1I;VYS6R=H;W-T)UT["B`@("`@("`@:68@*&ES<V5T
M*"1O<'1I;VYS6R=P;W)T)UTI*2`D=&AI<RT^<&]R="`]("1O<'1I;VYS6R=P
M;W)T)UT["B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=A=71H)UTI*2`D
M=&AI<RT^875T:"`]("1O<'1I;VYS6R=A=71H)UT["B`@("`@("`@:68@*&ES
M<V5T*"1O<'1I;VYS6R=U<V5R;F%M92==*2D@)'1H:7,M/G5S97)N86UE(#T@
M)&]P=&EO;G-;)W5S97)N86UE)UT["B`@("`@("`@:68@*&ES<V5T*"1O<'1I
M;VYS6R=P87-S=V]R9"==*2D@)'1H:7,M/G!A<W-W;W)D(#T@)&]P=&EO;G-;
M)W!A<W-W;W)D)UT["@H@("`@("`@("1H96%D97)S(#T@87)R87DH*3L*("`@
M("`@("`D:&5A9&5R<ULG1G)O;2==(#T@)&]P=&EO;G-;)V9R;VTG73L*("`@
M("`@("`D:&5A9&5R<ULG6"U-86EL97(G72`]("1T:&ES+3Y?=7-E<D%G96YT
M.PH@("`@("`@("1H96%D97)S6R=-24U%+59E<G-I;VXG72`]("<Q+C`G.PH@
M("`@("`@("1H96%D97)S6R=-97-S86=E+4E$)UT@/2!M9#4H=&EM92@I*2XG
M+G-O87!`)RXD=&AI<RT^:&]S=#L*("`@("`@("`D:&5A9&5R<ULG5&\G72`]
M("1T:&ES+3YU<FQP87)T<ULG<&%T:"==.PH@("`@("`@(&EF("AA<G)A>5]K
M97E?97AI<W1S*"=S;V%P86-T:6]N)RP@)&]P=&EO;G,I*2!["B`@("`@("`@
M("`@("1H96%D97)S6R=3;V%P86-T:6]N)UT@/2`B7")[)&]P=&EO;G-;)W-O
M87!A8W1I;VXG77U<(B(["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H
M)&]P=&EO;G-;)VAE861E<G,G72DI"B`@("`@("`@("`@("1H96%D97)S(#T@
M87)R87E?;65R9V4H)&AE861E<G,L("1O<'1I;VYS6R=H96%D97)S)UTI.PH*
M("`@("`@("`O+R!I9B!T:&4@8V]N=&5N="!T>7!E(&ES(&%L<F5A9'D@<V5T
M+"!W92!A<W-U;64@=&AA="!-:6UE(&5N8V]D:6YG"B`@("`@("`@+R\@:7,@
M86QR96%D>2!D;VYE"B`@("`@("`@:68@*&ES<V5T*"1H96%D97)S6R=#;VYT
M96YT+51Y<&4G72DI('L*("`@("`@("`@("`@)&]U="`]("1M<V<["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@9&\@82!S:6UP;&4@:6YL:6YE
M($UI;64@96YC;V1I;F<*("`@("`@("`@("`@)&AE861E<G-;)T-O;G1E;G0M
M1&ES<&]S:71I;VXG72`]("=I;FQI;F4G.PH@("`@("`@("`@("`D:&5A9&5R
M<ULG0V]N=&5N="U4>7!E)UT@/2`B=&5X="]X;6P[(&-H87)S970]7"(D=&AI
M<RT^96YC;V1I;F=<(B(["B`@("`@("`@("`@(&EF("AA<G)A>5]K97E?97AI
M<W1S*"=T<F%N<V9E<BUE;F-O9&EN9R<L("1O<'1I;VYS*2D@>PH@("`@("`@
M("`@("`@("`@:68@*'-T<F-A<V5C;7`H)&]P=&EO;G-;)W1R86YS9F5R+65N
M8V]D:6YG)UTL)W%U;W1E9"UP<FEN=&%B;&4G*3T],"D@>PH@("`@("`@("`@
M("`@("`@("`@("1H96%D97)S6R=#;VYT96YT+51R86YS9F5R+45N8V]D:6YG
M)UT@/2`D;W!T:6]N<ULG=')A;G-F97(M96YC;V1I;F<G73L*("`@("`@("`@
M("`@("`@("`@("`D;W5T(#T@)B1M<V<["B`@("`@("`@("`@("`@("!](&5L
M<V4@:68@*'-T<F-A<V5C;7`H)&]P=&EO;G-;)W1R86YS9F5R+65N8V]D:6YG
M)UTL)V)A<V4V-"<I/3TP*2!["B`@("`@("`@("`@("`@("`@("`@)&AE861E
M<G-;)T-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<G72`]("=B87-E-C0G.PH@
M("`@("`@("`@("`@("`@("`@("1O=70@/2!C:'5N:U]S<&QI="AB87-E-C1?
M96YC;V1E*"1M<V<I+#<V+")<;B(I.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O
M87!&875L="@B26YV86QI9"!4<F%N<V9E<B!%;F-O9&EN9SH@>R1O<'1I;VYS
M6R=T<F%N<V9E<BUE;F-O9&EN9R==?2(I.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+R\@9&5F875L
M="!T;R!B87-E-C0*("`@("`@("`@("`@("`@("1H96%D97)S6R=#;VYT96YT
M+51R86YS9F5R+45N8V]D:6YG)UT@/2`G8F%S938T)SL*("`@("`@("`@("`@
M("`@("1O=70@/2!C:'5N:U]S<&QI="AB87-E-C1?96YC;V1E*"1M<V<I*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&AE861E<G-;)U-U
M8FIE8W0G72`](&%R<F%Y7VME>5]E>&ES=',H)W-U8FIE8W0G+"`D;W!T:6]N
M<RD@/R`D;W!T:6]N<ULG<W5B:F5C="==(#H@)U-/05`@365S<V%G92<["@H@
M("`@("`@(&9O<F5A8V@@*"1H96%D97)S(&%S("1K97D@/3X@)'9A;'5E*2![
M"B`@("`@("`@("`@("1H96%D97)?=&5X="`N/2`B)&ME>3H@)'9A;'5E7&XB
M.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^;W5T9V]I;F=?<&%Y;&]A9"`]
M("1H96%D97)?=&5X="XB7')<;B(N)'1H:7,M/F]U=&=O:6YG7W!A>6QO860[
M"B`@("`@("`@(R!W92!W86YT('1O(')E='5R;B!A('!R;W!E<B!834P@;65S
M<V%G90H*("`@("`@("`D;6%I;&5R7W!A<F%M<R`](&%R<F%Y*`H@("`@("`@
M("`@("`G:&]S="<@/3X@)'1H:7,M/FAO<W0L"B`@("`@("`@("`@("=P;W)T
M)R`]/B`D=&AI<RT^<&]R="P*("`@("`@("`@("`@)W5S97)N86UE)R`]/B`D
M=&AI<RT^=7-E<FYA;64L"B`@("`@("`@("`@("=P87-S=V]R9"<@/3X@)'1H
M:7,M/G!A<W-W;W)D+`H@("`@("`@("`@("`G875T:"<@/3X@)'1H:7,M/F%U
M=&@*("`@("`@("`I.PH@("`@("`@("1M86EL97(@/28@;F5W($UA:6Q?<VUT
M<"@D;6%I;&5R7W!A<F%M<RD["B`@("`@("`@)')E<W5L="`]("1M86EL97(M
M/G-E;F0H)'1H:7,M/G5R;'!A<G1S6R=P871H)UTL("1H96%D97)S+"`D;W5T
M*3L*("`@("`@("`C)')E<W5L="`](&UA:6PH)'1H:7,M/G5R;'!A<G1S6R=P
M871H)UTL("1H96%D97)S6R=3=6)J96-T)UTL("1O=70L("1H96%D97)?=&5X
M="D["@H@("`@("`@(&EF("@A4$5!4CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@
M("`@("`@("`@("`D=F%L(#TF(&YE=R!33T%07U9A;'5E*"=-97-S86=E+4E$
M)RPG<W1R:6YG)RPD:&5A9&5R<ULG365S<V%G92U)1"==*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D<W9A;%M=(#TF(&YE=R!33T%07U9A;'5E
M*"=F875L=&-O9&4G+"=13F%M92<L)U-/05`M14Y6.D-L:65N="<I.PH@("`@
M("`@("`@("`D<W9A;%M=(#TF(&YE=R!33T%07U9A;'5E*"=F875L='-T<FEN
M9R<L)W-T<FEN9R<L(F-O=6QD;B=T('-E;F0@4TU44"!M97-S86=E('1O('LD
M=&AI<RT^=7)L<&%R='-;)W!A=&@G77TB*3L*("`@("`@("`@("`@)'9A;"`]
M)B!N97<@4T]!4%]686QU92@G1F%U;'0G+"=3=')U8W0G+"1S=F%L*3L*("`@
M("`@("!]"@H@("`@("`@("1M<6YA;64@/28@;F5W(%%.86UE*"1M971H;V0L
M("1N86UE<W!A8V4I.PH@("`@("`@("1M971H;V1686QU92`])B!N97<@4T]!
M4%]686QU92@G4F5S<&]N<V4G+"`G4W1R=6-T)RP@87)R87DH)'9A;"DI.PH*
M("`@("`@("`D=&AI<RT^:6YC;VUI;F=?<&%Y;&]A9"`])B`D=&AI<RT^7VUA
M:V5%;G9E;&]P92@D;65T:&]D5F%L=64L("1T:&ES+3YH96%D97)S+"`D=&AI
M<RT^96YC;V1I;F<I.PH*("`@("`@("!R971U<FX@)'1H:7,M/FEN8V]M:6YG
M7W!A>6QO860["B`@("!]"@H@("`@+RHJ"B`@("`J('-E="!D871A(&9O<B!H
M='1P(&%U=&AE;G1I8V%T:6]N"B`@("`J(&-R96%T97,@075T:&]R:7IA=&EO
M;B!H96%D97(*("`@("H*("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<FYA;64@
M("!U<V5R;F%M90H@("`@*B!`<&%R86T@<W1R:6YG("1P87-S=V]R9"`@(')E
M<W!O;G-E(&1A=&$L(&UI;G5S(&AT='`@:&5A9&5R<PH@("`@*@H@("`@*B!`
M<F5T=7)N(&YO;F4*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("HO"B`@("!F
M=6YC=&EO;B!S971#<F5D96YT:6%L<R@D=7-E<FYA;64L("1P87-S=V]R9"D*
M("`@('L*("`@("`@("`D=&AI<RT^=7-E<FYA;64@/2`D=7-E<FYA;64["B`@
M("`@("`@)'1H:7,M/G!A<W-W;W)D(#T@)'!A<W-W;W)D.PH@("`@?0H*("`@
M("\O('!R:79A=&4@;65M8F5R<PH*("`@("\J*@H@("`@*B!V86QI9&%T92!U
M<FP@9&%T82!P87-S960@=&\@8V]N<W1R=6-T;W(*("`@("H*("`@("H@0')E
M='5R;B!B;V]L96%N"B`@("`J($!A8V-E<W,@<')I=F%T90H@("`@*B\*("`@
M(&9U;F-T:6]N(%]V86QI9&%T955R;"@I"B`@("!["B`@("`@("`@:68@*"`A
M(&ES7V%R<F%Y*"1T:&ES+3YU<FQP87)T<RD@*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?<F%I<V53;V%P1F%U;'0H(E5N86)L92!T;R!P87)S92!54DP@)'5R
M;"(I.PH@("`@("`@("`@("!R971U<FX@1D%,4T4["B`@("`@("`@?0H@("`@
M("`@(&EF("@A:7-S970H)'1H:7,M/G5R;'!A<G1S6R=S8VAE;64G72D@?'P*
M("`@("`@("`@("`@<W1R8V%S96-M<"@D=&AI<RT^=7)L<&%R='-;)W-C:&5M
M92==+"`G;6%I;'1O)RD@(3T@,"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]R86ES95-O87!&875L="@B56YA8FQE('1O('!A<G-E(%523"`D=7)L(BD[
M"B`@("`@("`@("`@("`@("!R971U<FX@1D%,4T4["B`@("`@("`@?0H@("`@
M("`@(&EF("@A:7-S970H)'1H:7,M/G5R;'!A<G1S6R=P871H)UTI*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(E5N86)L92!T;R!P
M87)S92!54DP@)'5R;"(I.PH@("`@("`@("`@("!R971U<FX@1D%,4T4["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B!44E5%.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+U-/05`O5')A;G-P;W)T+U1#4"YP:'``````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,3`V-#<@,3`U,34T,S,W,S$@,#(R,S<Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B!4:&ES(&9I;&4@8V]N=&%I;G,@=&AE(&-O9&4@9F]R(&$@5$-0
M('1R86YS<&]R="!L87EE<BX*("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*
M("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O
M('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L"B`J('1H870@:7,@
M8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%
M+"!A;F0@:7,@879A:6QA8FQE(&%T"B`J('1H<F]U9V@@=&AE('=O<FQD+7=I
M9&4M=V5B(&%T(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT
M+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(
M4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I=`H@*B!T:')O
M=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O
M(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X*("H@;6%I;"!Y;W4@82!C;W!Y
M(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!796(@4V5R=FEC97,*
M("H@0'!A8VMA9V4@("`@4T]!4`H@*B!`875T:&]R("`@("!3:&%N92!(86YN
M82`\:6]R9'E?871?:6]R9'E?9&]T7V-O;3X*("H@0&-O<'ER:6=H="`@,C`P
M,RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0@(%!(4"!,:6-E;G-E(#(N,#(*
M("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U-/
M05`*("HO"@IR97%U:7)E7V]N8V4@)U-/05`O0F%S92YP:'`G.PH*+RHJ"B`J
M(%1#4"!T<F%N<W!O<G0@9F]R(%-/05`N"B`J"B`J($!T;V1O("`@('5S92!.
M971?4V]C:V5T.R!I;7!L96UE;G0@<V]M92!S96-U<FET>2!S8VAE;64[(&EM
M<&QE;65N="!S=7!P;W)T"B`J("`@("`@("`@(&9O<B!A='1A8VAM96YT<PH@
M*B!`86-C97-S("!P=6)L:6,*("H@0'!A8VMA9V4@4T]!4`H@*B!`875T:&]R
M("!3:&%N92!(86YN82`\:6]R9'E?871?:6]R9'E?9&]T7V-O;3X*("HO"F-L
M87-S(%-/05!?5')A;G-P;W)T7U1#4"!E>'1E;F1S(%-/05!?0F%S95]/8FIE
M8W0*>PH*("`@('9A<B`D:&5A9&5R<R`](&%R<F%Y*"D["B`@("!V87(@)'5R
M;'!A<G1S(#T@3E5,3#L*("`@('9A<B`D=7)L(#T@)R<["B`@("!V87(@)&EN
M8V]M:6YG7W!A>6QO860@/2`G)SL*("`@('9A<B`D7W5S97)!9V5N="`](%-/
M05!?3$E"4D%265].04U%.PH@("`@=F%R("1E;F-O9&EN9R`](%-/05!?1$5&
M055,5%]%3D-/1$E.1SL*("`@('9A<B`D<F5S=6QT7V5N8V]D:6YG(#T@)U54
M1BTX)SL*("`@('9A<B`D<F5S=6QT7V-O;G1E;G1?='EP93L*"B`@("`O*BH*
M("`@("`J('-O8VME=`H@("`@("HO"B`@("!V87(@)'-O8VME="`]("<G.PH*
M("`@("\J*@H@("`@("H@4T]!4%]4<F%N<W!O<G1?5$-0($-O;G-T<G5C=&]R
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D55),("`@(&AT='`@=7)L
M('1O('-O87`@96YD<&]I;G0*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!33T%07U1R86YS<&]R=%]40U`H)%52
M3"P@)&5N8V]D:6YG(#T@4T]!4%]$149!54Q47T5.0T]$24Y'*0H@("`@>PH@
M("`@("`@('!A<F5N=#HZ4T]!4%]"87-E7T]B:F5C="@G5$-0)RD["B`@("`@
M("`@)'1H:7,M/G5R;'!A<G1S(#T@0'!A<G-E7W5R;"@D55),*3L*("`@("`@
M("`D=&AI<RT^=7)L(#T@)%523#L*("`@("`@("`D=&AI<RT^96YC;V1I;F<@
M/2`D96YC;V1I;F<["B`@("!]"@H@("`@9G5N8W1I;VX@7W-O8VME=%]P:6YG
M*"D*("`@('L*("`@("`@("`O+R!86%@@:&]W(&1O('=E(')E<W1A<G0@869T
M97(@<V]C:V5T7W-H=71D;W=N/PH@("`@("`@("\O:68@*"$D=&AI<RT^<V]C
M:V5T*2!["B`@("`@("`@("`@(",@8W)E871E('-O8VME="!R97-O=7)C90H@
M("`@("`@("`@("`D=&AI<RT^<V]C:V5T(#T@0'-O8VME=%]C<F5A=&4H049?
M24Y%5"P@4T]#2U]35%)%04TL(%-/3%]40U`I.PH@("`@("`@("`@("!I9B`H
M)'1H:7,M/G-O8VME="`\(#`I(')E='5R;B`P.PH*("`@("`@("`@("`@(R!C
M;VYN96-T"B`@("`@("`@("`@("1R97-U;'0@/2!S;V-K971?8V]N;F5C="@D
M=&AI<RT^<V]C:V5T+"`D=&AI<RT^=7)L<&%R='-;)VAO<W0G72P@)'1H:7,M
M/G5R;'!A<G1S6R=P;W)T)UTI.PH@("`@("`@("`@("!I9B`H)')E<W5L="`\
M(#`I(')E='5R;B`P.PH@("`@("`@("\O?0H@("`@("`@(')E='5R;B`Q.PH@
M("`@?0H*("`@("\J*@H@("`@("H@<V5N9"!A;F0@<F5C96EV92!S;V%P(&1A
M=&$*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("8D;7-G("`@("`@(&]U
M=&=O:6YG('!O<W0@9&%T80H@("`@("H@0'!A<F%M('-T<FEN9R`D86-T:6]N
M("`@("`@4T]!4"!!8W1I;VX@:&5A9&5R(&1A=&$*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9WQF875L="!R97-P;VYS90H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@)G-E;F0H)B1M<V<L("1O<'1I
M;VYS(#T@3E5,3"D*("`@('L*("`@("`@("`D=&AI<RT^:6YC;VUI;F=?<&%Y
M;&]A9"`]("<G.PH@("`@("`@("1T:&ES+3YO=71G;VEN9U]P87EL;V%D(#T@
M)B1M<V<["B`@("`@("`@:68@*"$D=&AI<RT^7W9A;&ED871E57)L*"DI(')E
M='5R;B`D=&AI<RT^9F%U;'0["@H@("`@("`@("\O(&-H96-K(&9O<B!40U`@
M<V-H96UE"B`@("`@("`@:68@*'-T<F-A<V5C;7`H)'1H:7,M/G5R;'!A<G1S
M6R=S8VAE;64G72P@)U1#4"<I(#T](#`I('L*("`@("`@("`@("`@+R\@8VAE
M8VL@8V]N;F5C=&EO;@H@("`@("`@("`@("!I9B`H(21T:&ES+3Y?<V]C:V5T
M7W!I;F<H*2D*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E
M4V]A<$9A=6QT*"=E<G)O<B!O;B`G+B1T:&ES+3YU<FPN)R!R96%S;VX@)RYS
M;V-K971?<W1R97)R;W(H<V]C:V5T7VQA<W1?97)R;W(H)'1H:7,M/G-O8VME
M="DI*3L*"B`@("`@("`@("`@("\O('=R:71E('1O('1H92!S;V-K970*("`@
M("`@("`@("`@:68@*"%`<V]C:V5T7W=R:71E*"1T:&ES+3YS;V-K970L("1T
M:&ES+3YO=71G;VEN9U]P87EL;V%D+"!S=')L96XH)'1H:7,M/F]U=&=O:6YG
M7W!A>6QO860I*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M<F%I<V53;V%P1F%U;'0H)T5R<F]R('-E;F1I;F<@9&%T82!T;R`G+B1T:&ES
M+3YU<FPN)R!R96%S;VX@)RYS;V-K971?<W1R97)R;W(H<V]C:V5T7VQA<W1?
M97)R;W(H)'1H:7,M/G-O8VME="DI*3L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@+R\@<VAU=&1O=VX@=W)I=&EN9PH@("`@("`@("`@("!I9B@A<V]C
M:V5T7W-H=71D;W=N*"1T:&ES+3YS;V-K970L(#$I*0H@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(F-A;B=T(&-H86YG
M92!S;V-K970@;6]D92!T;R!R96%D+B(I.PH*("`@("`@("`@("`@+R\@<F5A
M9"!E=F5R>71H:6YG('=E(&-A;BX*("`@("`@("`@("`@=VAI;&4H)&)U9B`]
M($!S;V-K971?<F5A9"@D=&AI<RT^<V]C:V5T+"`Q,#(T+"!02%!?0DE.05)9
M7U)%040I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^:6YC;VUI;F=?<&%Y
M;&]A9"`N/2`D8G5F.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!R
M971U<FX@<&%Y;&]A9"!O<B!D:64*("`@("`@("`@("`@:68@*"1T:&ES+3YI
M;F-O;6EN9U]P87EL;V%D*0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YI;F-O;6EN9U]P87EL;V%D.PH*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?<F%I<V53;V%P1F%U;'0H(D5R<F]R(')E=F5I=FEN9R!D871A(&9R;VT@
M(BXD=&AI<RT^=7)L*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI
M<RT^7W)A:7-E4V]A<$9A=6QT*"=);G9A;&ED('5R;"!S8VAE;64@)RXD=&AI
M<RT^=7)L*3L*("`@('T*"B`@("`O*BH*("`@("`J('9A;&ED871E('5R;"!D
M871A('!A<W-E9"!T;R!C;VYS=')U8W1O<@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]V86QI9&%T955R;"@I"B`@("!["B`@("`@("`@:68@*"`A
M(&ES7V%R<F%Y*"1T:&ES+3YU<FQP87)T<RD@*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?<F%I<V53;V%P1F%U;'0H(E5N86)L92!T;R!P87)S92!54DP@)'5R
M;"(I.PH@("`@("`@("`@("!R971U<FX@1D%,4T4["B`@("`@("`@?0H@("`@
M("`@(&EF("@A:7-S970H)'1H:7,M/G5R;'!A<G1S6R=H;W-T)UTI*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(DYO(&AO<W0@:6X@
M55),("1U<FPB*3L*("`@("`@("`@("`@<F5T=7)N($9!3%-%.PH@("`@("`@
M('T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YU<FQP87)T<ULG<&%T:"==
M*2!\?"`A)'1H:7,M/G5R;'!A<G1S6R=P871H)UTI"B`@("`@("`@("`@("1T
M:&ES+3YU<FQP87)T<ULG<&%T:"==(#T@)R\G.PH@("`@("`@(')E='5R;B!4
M4E5%.PH@("`@?0H*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4T]!
M4"]4<F%N<W!O<G0O2%144"YP:'``````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`T-S0S,2`Q,#4Q-30S,S<S,2`P,C(U,C,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H
M:7,@9FEL92!C;VYT86EN<R!T:&4@8V]D92!F;W(@82!(5%10('1R86YS<&]R
M="!L87EE<BX*("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#
M14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@
M,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L"B`J('1H870@:7,@8G5N9&QE9"!W
M:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@
M879A:6QA8FQE(&%T"B`J('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E
M(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I=`H@*B!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O(&QI8V5N<V5`
M<&AP+FYE="!S;R!W92!C86X*("H@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+@H@*@H@*B!`8V%T96=O<GD@("!796(@4V5R=FEC97,*("H@0'!A8VMA
M9V4@("`@4T]!4`H@*B!`875T:&]R("`@("!3:&%N92!#87)A=F5O(#Q3:&%N
M94!#87)A=F5O+F-O;3X*("H@0&-O<'ER:6=H="`@,C`P,RTR,#`U(%1H92!0
M2%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,E\P,BYT>'0@(%!(4"!,:6-E;G-E(#(N,#(*("H@0&QI;FL@("`@
M("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U-/05`*("HO"@HO*BH*
M("H@2%144"!4<F%N<W!O<G0@8VQA<W,*("H*("H@0'!A8VMA9V4@(%-/05`*
M("H@0&-A=&5G;W)Y(%=E8E]397)V:6-E<PH@*B\*"B\J*@H@*B!.965D960@
M0VQA<W-E<PH@*B\*<F5Q=6ER95]O;F-E("=33T%0+T)A<V4N<&AP)SL*"B\J
M*@H@*B`@2%144"!4<F%N<W!O<G0@9F]R(%-/05`*("H*("H@0&%C8V5S<R!P
M=6)L:6,*("H@0'!A8VMA9V4@4T]!4`H@*B!`875T:&]R(%-H86YE($-A<F%V
M96\@/'-H86YE0'!H<"YN970^"B`J+PIC;&%S<R!33T%07U1R86YS<&]R=%](
M5%10(&5X=&5N9',@4T]!4%]"87-E"GL*"B`@("`O*BH*("`@("`J($)A<VEC
M($%U=&@@<W1R:6YG"B`@("`@*@H@("`@("H@0'9A<B`@87)R87D*("`@("`J
M+PH@("`@=F%R("1H96%D97)S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J
M($-O;VMI97,*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@
M('9A<B`D8V]O:VEE<SL*"B`@("`O*BH*("`@("`J"B`@("`@*B!`=F%R("!I
M;G0@8V]N;F5C=&EO;B!T:6UE;W5T(&EN('-E8V]N9',@+2`P(#T@;F]N90H@
M("`@("HO"B`@("!V87(@)'1I;65O=70@/2`T.PH*("`@("\J*@H@("`@("H@
M07)R87D@8V]N=&%I;FEN9R!U<FQP87)T<R`M('!A<G-E7W5R;"@I"B`@("`@
M*@H@("`@("H@0'9A<B`@;6EX960*("`@("`J+PH@("`@=F%R("1U<FQP87)T
M<R`]($Y53$P["@H@("`@+RHJ"B`@("`@*B!#;VYN96-T:6]N(&5N9'!O:6YT
M("T@55),"B`@("`@*@H@("`@("H@0'9A<B`@<W1R:6YG"B`@("`@*B\*("`@
M('9A<B`D=7)L(#T@)R<["@H@("`@+RHJ"B`@("`@*B!);F-O;6EN9R!P87EL
M;V%D"B`@("`@*@H@("`@("H@0'9A<B`@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D:6YC;VUI;F=?<&%Y;&]A9"`]("<G.PH*("`@("\J*@H@("`@("H@2%14
M4"U297%U97-T(%5S97(M06=E;G0*("`@("`J"B`@("`@*B!`=F%R("!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1?=7-E<D%G96YT(#T@4T]!4%],24)205)9
M7TY!344["@H@("`@+RHJ"B`@("`@*B!(5%10($5N8V]D:6YG"B`@("`@*@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1E;F-O9&EN9R`]
M(%-/05!?1$5&055,5%]%3D-/1$E.1SL*"B`@("`O*BH*("`@("`J($A45%`M
M4F5S<&]N<V4@0V]N=&5N="U4>7!E(&5N8V]D:6YG"B`@("`@*@H@("`@("H@
M=V4@87-S=6UE(%541BTX(&EF(&YO(&5N8V]D:6YG(&ES('-E=`H@("`@("H@
M0'9A<B`@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D<F5S=6QT7V5N8V]D:6YG
M(#T@)U541BTX)SL*"B`@("`O*BH*("`@("`J($A45%`M4F5S<&]N<V4@0V]N
M=&5N="U4>7!E"B`@("`@*B\*("`@('9A<B`D<F5S=6QT7V-O;G1E;G1?='EP
M93L*"B`@("!V87(@)')E<W5L=%]H96%D97)S(#T@87)R87DH*3L*"B`@("!V
M87(@)')E<W5L=%]C;V]K:65S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J
M(%-/05!?5')A;G-P;W)T7TA45%`@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("154DP@("`@:'1T<"!U<FP@=&\@<V]A<"!E;F1P
M;VEN=`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R
M86T@('-T<FEN9R`D55))"B`@("`@*B!`<&%R86T@('-T<FEN9R`D96YC;V1I
M;F<@(&5N8V]D:6YG('1O('5S90H@("`@("HO"B`@("!F=6YC=&EO;B!33T%0
M7U1R86YS<&]R=%](5%10*"154DPL("1E;F-O9&EN9R`](%-/05!?1$5&055,
M5%]%3D-/1$E.1RD*("`@('L*("`@("`@("!P87)E;G0Z.E-/05!?0F%S92@G
M2%144"<I.PH@("`@("`@("1T:&ES+3YU<FQP87)T<R`]($!P87)S95]U<FPH
M)%523"D["B`@("`@("`@)'1H:7,M/G5R;"`]("154DP["B`@("`@("`@)'1H
M:7,M/F5N8V]D:6YG(#T@)&5N8V]D:6YG.PH@("`@?0H*("`@("\J*@H@("`@
M("H@<V5N9"!A;F0@<F5C96EV92!S;V%P(&1A=&$*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG(&]U=&=O:6YG('!O<W0@9&%T80H@("`@("H@0'!A<F%M
M(&%R<F%Y("!O<'1I;VYS"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F=\
M9F%U;'0@<F5S<&]N<V4*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N("9S96YD*"8D;7-G+"`D;W!T:6]N<R`](&YU;&PI"B`@
M("!["B`@("`@("`@:68@*"$D=&AI<RT^7W9A;&ED871E57)L*"DI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YF875L=#L*("`@("`@("!]"@H@("`@
M("`@(&EF("AI<W-E="@D;W!T:6]N<ULG=&EM96]U="==*2D*("`@("`@("`@
M("`@)'1H:7,M/G1I;65O=70@/2`H:6YT*21O<'1I;VYS6R=T:6UE;W5T)UT[
M"@H@("`@("`@(&EF("AS=')C87-E8VUP*"1T:&ES+3YU<FQP87)T<ULG<V-H
M96UE)UTL("=(5%10)RD@/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]S96YD2%144"@D;7-G+"`D;W!T:6]N<RD["B`@("`@("`@?2!E;'-E
M(&EF("AS=')C87-E8VUP*"1T:&ES+3YU<FQP87)T<ULG<V-H96UE)UTL("=(
M5%104R<I(#T](#`I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<V5N
M9$A45%!3*"1M<V<L("1O<'1I;VYS*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=);G9A;&ED('5R;"!S8VAE
M;64@)RXD=&AI<RT^=7)L*3L*("`@('T*"B`@("`O*BH*("`@("`J('-E="!D
M871A(&9O<B!H='1P(&%U=&AE;G1I8V%T:6]N"B`@("`@*B!C<F5A=&5S($%U
M=&AO<FEZ871I;VX@:&5A9&5R"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=7-E<FYA;64@("!U<V5R;F%M90H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<&%S<W=O<F0@("!R97-P;VYS92!D871A+"!M:6YU<R!H='1P(&AE861E<G,*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&YO;F4*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$-R961E;G1I86QS*"1U<V5R
M;F%M92P@)'!A<W-W;W)D*0H@("`@>PH@("`@("`@("1T:&ES+3YH96%D97)S
M6R=!=71H;W)I>F%T:6]N)UT@/2`G0F%S:6,@)R`N(&)A<V4V-%]E;F-O9&4H
M)'5S97)N86UE("X@)SHG("X@)'!A<W-W;W)D*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($%D9"!A(&-O;VMI90H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B!`<&%R86T@('-T<FEN9R`@)&YA;64@("!C;V]K:64@;F%M
M90H@("`@("H@0'!A<F%M("!M:7AE9"`@("1V86QU92`@8V]O:VEE('9A;'5E
M"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@861D
M0V]O:VEE*"1N86UE+"`D=F%L=64I"B`@("!["B`@("`@("`@)'1H:7,M/F-O
M;VMI97-;)&YA;65=/21V86QU93L*("`@('T*"B`@("`O+R!P<FEV871E(&UE
M=&AO9',*"B`@("`O*BH*("`@("`J($=E;F5R871E<R!T:&4@8V]R<F5C="!H
M96%D97)S(&9O<B!T:&4@8V]O:VEE<PH@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]G96Y#;V]K:65(96%D97(H*0H@("`@>PH@("`@("`@(&9O<F5A8V@@
M*"1T:&ES+3YC;V]K:65S(&%S("1N86UE/3XD=F%L=64I('L*("`@("`@("`@
M("`@)&-O;VMI97,@/2`H:7-S970H)&-O;VMI97,I(#\@)&-O;VMI97,N("<[
M("<@.B`G)RD@+@H@("`@("`@("`@("`@("`@("`@("`@("!U<FQE;F-O9&4H
M)&YA;64I("X@)STG("X@=7)L96YC;V1E*"1V86QU92D["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B`D8V]O:VEE<SL*("`@('T*"B`@("`O*BH*("`@("`J
M('9A;&ED871E('5R;"!D871A('!A<W-E9"!T;R!C;VYS=')U8W1O<@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0')E='5R;B!B;V]L
M96%N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]V86QI9&%T955R;"@I"B`@("![
M"B`@("`@("`@:68@*"`A(&ES7V%R<F%Y*"1T:&ES+3YU<FQP87)T<RD@*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(E5N86)L92!T
M;R!P87)S92!54DP@(B`N("1T:&ES+3YU<FPI.PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/G5R;'!A<G1S6R=H;W-T)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<F%I
M<V53;V%P1F%U;'0H(DYO(&AO<W0@:6X@55),("(@+B`D=&AI<RT^=7)L*3L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("!I
M9B`H(6ES<V5T*"1T:&ES+3YU<FQP87)T<ULG<&]R="==*2D@>PH*("`@("`@
M("`@("`@:68@*'-T<F-A<V5C;7`H)'1H:7,M/G5R;'!A<G1S6R=S8VAE;64G
M72P@)TA45%`G*2`]/2`P*0H@("`@("`@("`@("`@("`@)'1H:7,M/G5R;'!A
M<G1S6R=P;W)T)UT@/2`X,#L*("`@("`@("`@("`@96QS92!I9B`H<W1R8V%S
M96-M<"@D=&AI<RT^=7)L<&%R='-;)W-C:&5M92==+"`G2%144%,G*2`]/2`P
M*0H@("`@("`@("`@("`@("`@)'1H:7,M/G5R;'!A<G1S6R=P;W)T)UT@/2`T
M-#,["@H@("`@("`@('T*("`@("`@("!I9B`H:7-S970H)'1H:7,M/G5R;'!A
M<G1S6R=U<V5R)UTI*2!["B`@("`@("`@("`@("1T:&ES+3YS971#<F5D96YT
M:6%L<RAU<FQD96-O9&4H)'1H:7,M/G5R;'!A<G1S6R=U<V5R)UTI+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!U<FQD96-O9&4H)'1H
M:7,M/G5R;'!A<G1S6R=P87-S)UTI*3L*("`@("`@("!]"B`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^=7)L<&%R='-;)W!A=&@G72D@?'P@(21T:&ES+3YU
M<FQP87)T<ULG<&%T:"==*0H@("`@("`@("`@("`D=&AI<RT^=7)L<&%R='-;
M)W!A=&@G72`]("<O)SL*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O*BH*("`@("`J($9I;F1S(&]U="!W:&%T(&ES('1H92!E;F-O9&EN9RX*
M("`@("`J"B`@("`@*B!3971S('1H92!O8FIE8W0@<')O<&5R='D@86-C;W)D
M:6YG;'DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`
M<&%R86T@(&%R<F%Y("1H96%D97)S("!H96%D97)S"B`@("`@*B!`<F5T=7)N
M('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@7W!A<G-E16YC;V1I;F<H)&AE
M861E<G,I"B`@("!["B`@("`@("`@)&@@/2!S=')I<W1R*"1H96%D97)S+"`G
M0V]N=&5N="U4>7!E)RD["B`@("`@("`@<')E9U]M871C:%]A;&PH)R]>0V]N
M=&5N="U4>7!E.EQS*B@N*BDD+VEM)RP@)&@L("1C="P@4%)%1U]3151?3U)$
M15(I.PH@("`@("`@("1N(#T@8V]U;G0H)&-T*3L*("`@("`@("`D8W0@/2`D
M8W1;)&X@+2`Q73L*("`@("`@("`D=&AI<RT^<F5S=6QT7V-O;G1E;G1?='EP
M92`]('-T<E]R97!L86-E*")<<B(L("<G+"`D8W1;,5TI.PH@("`@("`@(&EF
M("AP<F5G7VUA=&-H*"<O*"XJ/RDH/SH[7',_8VAA<G-E=#TI*"XJ*2]I)RP@
M)'1H:7,M/G)E<W5L=%]C;VYT96YT7W1Y<&4L("1M*2D@>PH@("`@("`@("`@
M("`O+R!S=')I<"!T:&4@<W1R:6YG(&]F(%QR"B`@("`@("`@("`@("1T:&ES
M+3YR97-U;'1?8V]N=&5N=%]T>7!E(#T@)&U;,5T["B`@("`@("`@("`@(&EF
M("AC;W5N="@D;2D@/B`R*2!["B`@("`@("`@("`@("`@("`D96YC(#T@<W1R
M=&]U<'!E<BAS=')?<F5P;&%C92@G(B<L("<G+"`D;5LR72DI.PH@("`@("`@
M("`@("`@("`@:68@*&EN7V%R<F%Y*"1E;F,L("1T:&ES+3Y?96YC;V1I;F=S
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YR97-U;'1?96YC;V1I
M;F<@/2`D96YC.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@("\O(&1E86P@=VET:"!B<F]K96X@<V5R=F5R<R!T
M:&%T(&1O;B=T('-E="!C;VYT96YT('1Y<&4@;VX@9F%U;'1S"B`@("`@("`@
M:68@*"$D=&AI<RT^<F5S=6QT7V-O;G1E;G1?='EP92D@)'1H:7,M/G)E<W5L
M=%]C;VYT96YT7W1Y<&4@/2`G=&5X="]X;6PG.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4&%R<V5S('1H92!H96%D97)S"B`@("`@*@H@("`@("H@0'!A<F%M
M("!A<G)A>2`D:&5A9&5R<R!T:&4@:&5A9&5R<PH@("`@("H@0')E='5R;B!V
M;VED"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P87)S94AE861E<G,H)&AE861E
M<G,I"B`@("!["B`@("`@("`@+RH@;&%R9V5L>2!B;W)R;W=E9"!F<F]M($A4
M5%!?4F5Q=65S="`J+PH@("`@("`@("1T:&ES+3YR97-U;'1?:&5A9&5R<R`]
M(&%R<F%Y*"D["B`@("`@("`@)&AE861E<G,@/2!S<&QI="@B7'(_7&XB+"`D
M:&5A9&5R<RD["B`@("`@("`@9F]R96%C:"`H)&AE861E<G,@87,@)'9A;'5E
M*2!["B`@("`@("`@("`@(&EF("AS=')P;W,H)'9A;'5E+"<Z)RD@/3T](&9A
M;'-E*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<F5S=6QT7VAE861E<G-;
M,%T])'9A;'5E.PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@;&ES="@D;F%M92PD=F%L=64I(#T@<W!L:70H
M)SHG+"1V86QU92D["B`@("`@("`@("`@("1H96%D97)N86UE(#T@<W1R=&]L
M;W=E<B@D;F%M92D["B`@("`@("`@("`@("1H96%D97)V86QU92`]('1R:6TH
M)'9A;'5E*3L*("`@("`@("`@("`@)'1H:7,M/G)E<W5L=%]H96%D97)S6R1H
M96%D97)N86UE73TD:&5A9&5R=F%L=64["@H@("`@("`@("`@("!I9B`H)&AE
M861E<FYA;64@/3T@)W-E="UC;V]K:64G*2!["B`@("`@("`@("`@("`@("`O
M+R!087)S92!A(%-E=$-O;VMI92!H96%D97(@=&\@9FEL;"!?8V]O:VEE<R!A
M<G)A>0H@("`@("`@("`@("`@("`@)&-O;VMI92`](&%R<F%Y*`H@("`@("`@
M("`@("`@("`@("`@("=E>'!I<F5S)R`]/B!N=6QL+`H@("`@("`@("`@("`@
M("`@("`@("=D;VUA:6XG("`]/B`D=&AI<RT^=7)L<&%R='-;)VAO<W0G72P*
M("`@("`@("`@("`@("`@("`@("`G<&%T:"<@("`@/3X@;G5L;"P*("`@("`@
M("`@("`@("`@("`@("`G<V5C=7)E)R`@/3X@9F%L<V4*("`@("`@("`@("`@
M("`@("D["@H@("`@("`@("`@("`@("`@+R\@3VYL>2!A(&YA;64]=F%L=64@
M<&%I<@H@("`@("`@("`@("`@("`@:68@*"%S=')P;W,H)&AE861E<G9A;'5E
M+"`G.R<I*2!["B`@("`@("`@("`@("`@("`@("`@;&ES="@D8V]O:VEE6R=N
M86UE)UTL("1C;V]K:65;)W9A;'5E)UTI(#T@87)R87E?;6%P*"=T<FEM)RP@
M97AP;&]D92@G/2<L("1H96%D97)V86QU92DI.PH@("`@("`@("`@("`@("`@
M("`@("1C;V]K:65;)VYA;64G72`@/2!U<FQD96-O9&4H)&-O;VMI95LG;F%M
M92==*3L*("`@("`@("`@("`@("`@("`@("`D8V]O:VEE6R=V86QU92==(#T@
M=7)L9&5C;V1E*"1C;V]K:65;)W9A;'5E)UTI.PH*("`@("`@("`@("`@("`@
M("\O(%-O;64@;W!T:6]N86P@<&%R86UE=&5R<R!A<F4@<W5P<&QI960*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&5L
M96UE;G1S(#T@97AP;&]D92@G.R<L("1H96%D97)V86QU92D["B`@("`@("`@
M("`@("`@("`@("`@;&ES="@D8V]O:VEE6R=N86UE)UTL("1C;V]K:65;)W9A
M;'5E)UTI(#T@87)R87E?;6%P*"=T<FEM)RP@97AP;&]D92@G/2<L("1E;&5M
M96YT<ULP72DI.PH@("`@("`@("`@("`@("`@("`@("1C;V]K:65;)VYA;64G
M72`@/2!U<FQD96-O9&4H)&-O;VMI95LG;F%M92==*3L*("`@("`@("`@("`@
M("`@("`@("`D8V]O:VEE6R=V86QU92==(#T@=7)L9&5C;V1E*"1C;V]K:65;
M)W9A;'5E)UTI.PH*("`@("`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,3L@
M)&D@/"!C;W5N="@D96QE;65N=',I.R1I*RLI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@;&ES="`H)&5L3F%M92P@)&5L5F%L=64I(#T@87)R87E?;6%P
M*"=T<FEM)RP@97AP;&]D92@G/2<L("1E;&5M96YT<ULD:5TI*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"=S96-U<F4G(#T]("1E;$YA;64I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;V]K:65;)W-E8W5R92==
M(#T@=')U93L*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"=E
M>'!I<F5S)R`]/2`D96Q.86UE*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D8V]O:VEE6R=E>'!I<F5S)UT@/2!S=')?<F5P;&%C92@G(B<L("<G
M+"`D96Q686QU92D["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF
M("@G<&%T:"<@/3T@)&5L3F%M92!/4B`G9&]M86EN)R`]/2`D96Q.86UE*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]O:VEE6R1E;$YA;65=
M(#T@=7)L9&5C;V1E*"1E;%9A;'5E*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;V]K
M:65;)&5L3F%M95T@/2`D96Q686QU93L*("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("1T:&ES+3YR97-U;'1?8V]O:VEE<UM=(#T@)&-O
M;VMI93L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E;6]V92!H='1P(&AE861E<G,@9G)O;2!R97-P;VYS90H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;&5A;@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P87)S95)E<W!O;G-E*"D*("`@
M('L*("`@("`@("!I9B`H<')E9U]M871C:"@B+UXH+BH_*5QR/UQN7'(_7&XH
M+BHI+W,B+"`D=&AI<RT^:6YC;VUI;F=?<&%Y;&]A9"P@)&UA=&-H*2D@>PH@
M("`@("`@("`@("`C)'1H:7,M/G)E<W!O;G-E(#T@<')E9U]R97!L86-E*"(O
M6UQR?%QN72\B+"`G)RP@)&UA=&-H6S)=*3L*("`@("`@("`@("`@)'1H:7,M
M/G)E<W!O;G-E(#TF("1M871C:%LR73L*("`@("`@("`@("`@+R\@9FEN9"!T
M:&4@<F5S<&]N<V4@97)R;W(L('-O;64@<V5R=F5R<R!R97-P;VYS92!W:71H
M(#4P,"!F;W(@<V]A<"!F875L=',*("`@("`@("`@("`@)'1H:7,M/E]P87)S
M94AE861E<G,H)&UA=&-H6S%=*3L*"B`@("`@("`@("`@(&QI<W0H)'!R;W1O
M8V]L+"`D8V]D92P@)&US9RD@/2!S<V-A;F8H)'1H:7,M/G)E<W5L=%]H96%D
M97)S6S!=+"`G)7,@)7,@)7,G*3L*("`@("`@("`@("`@=6YS970H)'1H:7,M
M/G)E<W5L=%]H96%D97)S6S!=*3L*"B`@("`@("`@("`@('-W:71C:"@D8V]D
M92D@>PH@("`@("`@("`@("`@("`@8V%S92`Q,#`Z("\O($-O;G1I;G5E"B`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^:6YC;VUI;F=?<&%Y;&]A9"`]("1M
M871C:%LR73L*("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A
M<G-E4F5S<&]N<V4H*3L*("`@("`@("`@("`@("`@(&-A<V4@-#`P.@H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(DA45%`@
M4F5S<&]N<V4@)&-O9&4@0F%D(%)E<75E<W0B*3L*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@("`@("!C87-E(#0P,3H*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")(5%10(%)E<W!O;G-E("1C;V1E
M($%U=&AE;G1I8V%T:6]N($9A:6QE9"(I.PH@("`@("`@("`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@("`@(&-A<V4@-#`S.@H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<F%I<V53;V%P1F%U;'0H(DA45%`@4F5S<&]N<V4@)&-O9&4@1F]R
M8FED9&5N(BD["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S
M92`T,#0Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&
M875L="@B2%144"!297-P;VYS92`D8V]D92!.;W0@1F]U;F0B*3L*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E(#0P-SH*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")(5%10(%)E<W!O
M;G-E("1C;V1E(%!R;WAY($%U=&AE;G1I8V%T:6]N(%)E<75I<F5D(BD["B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`T,#@Z"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&875L="@B2%144"!2
M97-P;VYS92`D8V]D92!297%U97-T(%1I;65O=70B*3L*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("!C87-E(#0Q,#H*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")(5%10(%)E<W!O;G-E("1C
M;V1E($=O;F4B*3L*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!D
M969A=6QT.@H@("`@("`@("`@("`@("`@("`@(&EF("@D8V]D92`^/2`T,#`@
M)B8@)&-O9&4@/"`U,#`I('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]R86ES95-O87!&875L="@B2%144"!297-P;VYS92`D8V]D92!.;W0@
M1F]U;F0L(%-E<G9E<B!M97-S86=E.B`D;7-G(BD["B`@("`@("`@("`@("`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?<&%R<V5%;F-O
M9&EN9R@D;6%T8VA;,5TI.PH*("`@("`@("`@("`@:68@*"1T:&ES+3YR97-U
M;'1?8V]N=&5N=%]T>7!E(#T]("=A<'!L:6-A=&EO;B]D:6UE)RD@>PH@("`@
M("`@("`@("`@("`@+R\@6%A8('%U:6-K(&AA8VL@:6YS97)T:6]N(&]F($1)
M344*("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1T:&ES+3Y?
M9&5C;V1E1$E-14UE<W-A9V4H)'1H:7,M/G)E<W!O;G-E+"1T:&ES+3YH96%D
M97)S+"1T:&ES+3YA='1A8VAM96YT<RDI*2!["B`@("`@("`@("`@("`@("`@
M("`@+R\@7V1E8V]D941)345-97-S86=E(&%L<F5A9'D@<F%I<V5D("1T:&ES
M+3YF875L=`H@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1T:&ES+3YR97-U;'1?
M8V]N=&5N=%]T>7!E(#T@)'1H:7,M/FAE861E<G-;)V-O;G1E;G0M='EP92==
M.PH@("`@("`@("`@("!](&5L<V4@:68@*'-T<FES='(H)'1H:7,M/G)E<W5L
M=%]C;VYT96YT7W1Y<&4L)VUU;'1I<&%R="]R96QA=&5D)RDI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3YR97-P;VYS92`]("1T:&ES+3YI;F-O;6EN9U]P
M87EL;V%D.PH@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'1H
M:7,M/E]D96-O9&5-:6UE365S<V%G92@D=&AI<RT^<F5S<&]N<V4L)'1H:7,M
M/FAE861E<G,L)'1H:7,M/F%T=&%C:&UE;G1S*2DI('L*("`@("`@("`@("`@
M("`@("`@("`O+R!?9&5C;V1E36EM94UE<W-A9V4@86QR96%D>2!R86ES960@
M)'1H:7,M/F9A=6QT"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@:68@*"1T
M:&ES+3YR97-U;'1?8V]N=&5N=%]T>7!E("$]("=T97AT+WAM;"<I('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)'1H:7,M/G)E
M<W!O;G-E*3L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`O+R!I9B!N;R!C;VYT96YT+"!R971U<FX@
M9F%L<V4*("`@("`@("`@("`@<F5T=7)N('-T<FQE;B@D=&AI<RT^<F5S<&]N
M<V4I(#X@,#L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]R86ES95-O87!&
M875L="@G26YV86QI9"!(5%10(%)E<W!O;G-E)RD["B`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E(&AT='`@<F5Q
M=65S="P@:6YC;'5D:6YG(&AE861E<G,L(&9O<B!O=71G;VEN9R!R97%U97-T
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@("8D;7-G("`@;W5T9V]I
M;F<@4T]!4"!P86-K86=E"B`@("`@*B!`<&%R86T@)&]P=&EO;G,*("`@("`J
M($!R971U<FX@<W1R:6YG(&]U=&=O:6YG7W!A>6QO860*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B`F7V=E=%)E<75E<W0H
M)B1M<V<L("1O<'1I;VYS*0H@("`@>PH@("`@("`@("1A8W1I;VX@/2!I<W-E
M="@D;W!T:6]N<ULG<V]A<&%C=&EO;B==*3\D;W!T:6]N<ULG<V]A<&%C=&EO
M;B==.B<G.PH@("`@("`@("1F=6QL<&%T:"`]("1T:&ES+3YU<FQP87)T<ULG
M<&%T:"==+@H@("`@("`@("`@("`@("`@("`@("`@("`H:7-S970H)'1H:7,M
M/G5R;'!A<G1S6R=Q=65R>2==*3\G/R<N)'1H:7,M/G5R;'!A<G1S6R=Q=65R
M>2==.B<G*2X*("`@("`@("`@("`@("`@("`@("`@("`@*&ES<V5T*"1T:&ES
M+3YU<FQP87)T<ULG9G)A9VUE;G0G72D_)R,G+B1T:&ES+3YU<FQP87)T<ULG
M9G)A9VUE;G0G73HG)RD["@H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG
M<')O>'E?:&]S="==*2D@>PH@("`@("`@("`@("`D9G5L;'!A=&@@/2`G:'1T
M<#HO+R<@+B`D=&AI<RT^=7)L<&%R='-;)VAO<W0G72`N("<Z)R`N("1T:&ES
M+3YU<FQP87)T<ULG<&]R="==("X@)&9U;&QP871H.PH@("`@("`@('T*"B`@
M("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=P<F]X>5]U<V5R)UTI*2!["B`@
M("`@("`@("`@("1T:&ES+3YH96%D97)S6R=0<F]X>2U!=71H;W)I>F%T:6]N
M)UT@/2`G0F%S:6,@)R`N(&)A<V4V-%]E;F-O9&4H)&]P=&EO;G-;)W!R;WAY
M7W5S97(G72XB.B(N)&]P=&EO;G-;)W!R;WAY7W!A<W,G72D["B`@("`@("`@
M?0H*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W5S97(G72DI('L*("`@
M("`@("`@("`@)'1H:7,M/G-E=$-R961E;G1I86QS*"1O<'1I;VYS6R=U<V5R
M)UTL("1O<'1I;VYS6R=P87-S)UTI.PH@("`@("`@('T*"B`@("`@("`@)'1H
M:7,M/FAE861E<G-;)U5S97(M06=E;G0G72`]("1T:&ES+3Y?=7-E<D%G96YT
M.PH@("`@("`@("1T:&ES+3YH96%D97)S6R=(;W-T)UT@/2`D=&AI<RT^=7)L
M<&%R='-;)VAO<W0G73L*("`@("`@("`D=&AI<RT^:&5A9&5R<ULG0V]N=&5N
M="U4>7!E)UT@/2`B=&5X="]X;6P[(&-H87)S970])'1H:7,M/F5N8V]D:6YG
M(CL*("`@("`@("`D=&AI<RT^:&5A9&5R<ULG0V]N=&5N="U,96YG=&@G72`]
M('-T<FQE;B@D;7-G*3L*("`@("`@("`D=&AI<RT^:&5A9&5R<ULG4T]!4$%C
M=&EO;B==(#T@(EPB)&%C=&EO;EPB(CL*("`@("`@("!I9B`H:7-S970H)&]P
M=&EO;G-;)VAE861E<G,G72DI('L*("`@("`@("`@("`@)'1H:7,M/FAE861E
M<G,@/2!A<G)A>5]M97)G92@D=&AI<RT^:&5A9&5R<RP@)&]P=&EO;G-;)VAE
M861E<G,G72D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^8V]O:VEE<R`]
M(&%R<F%Y*"D["B`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG;F]C;V]K
M:65S)UTI('Q\("$D;W!T:6]N<ULG;F]C;V]K:65S)UTI('L*("`@("`@("`@
M("`@+R\@861D('1H92!C;V]K:65S('=E(&=O="!F<F]M('1H92!L87-T(')E
M<75E<W0*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YR97-U;'1?8V]O
M:VEE<RDI('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YR97-U
M;'1?8V]O:VEE<R!A<R`D8V]O:VEE*2!["B`@("`@("`@("`@("`@("`@("`@
M:68@*"1C;V]K:65;)V1O;6%I;B==(#T]("1T:&ES+3YU<FQP87)T<ULG:&]S
M="==*0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8V]O:VEE<ULD
M8V]O:VEE6R=N86UE)UU=/21C;V]K:65;)W9A;'5E)UT["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@+R\@861D
M(&-O;VMI97,@=&AE('5S97(@=V%N=',@=&\@<V5T"B`@("`@("`@:68@*&ES
M<V5T*"1O<'1I;VYS6R=C;V]K:65S)UTI*2!["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1O<'1I;VYS6R=C;V]K:65S)UT@87,@)&-O;VMI92D@>PH@("`@("`@
M("`@("`@("`@:68@*"1C;V]K:65;)V1O;6%I;B==(#T]("1T:&ES+3YU<FQP
M87)T<ULG:&]S="==*0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC;V]K
M:65S6R1C;V]K:65;)VYA;64G75T])&-O;VMI95LG=F%L=64G73L*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/F-O
M;VMI97,I*2!["B`@("`@("`@("`@("1T:&ES+3YH96%D97)S6R=#;V]K:64G
M72`]("1T:&ES+3Y?9V5N0V]O:VEE2&5A9&5R*"D["B`@("`@("`@?0H@("`@
M("`@("1H96%D97)S(#T@)R<["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/FAE
M861E<G,@87,@)&L@/3X@)'8I('L*("`@("`@("`@("`@)&AE861E<G,@+CT@
M(B1K.B`D=EQR7&XB.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^;W5T9V]I
M;F=?<&%Y;&]A9"`]"B`@("`@("`@("`@("`@("`B4$]35"`D9G5L;'!A=&@@
M2%144"\Q+C!<<EQN(BX*("`@("`@("`@("`@("`@("1H96%D97)S+B)<<EQN
M(BX*("`@("`@("`@("`@("`@("1M<V<["B`@("`@("`@<F5T=7)N("1T:&ES
M+3YO=71G;VEN9U]P87EL;V%D.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5N
M9"!O=71G;VEN9R!R97%U97-T+"!A;F0@<F5A9"]P87)S92!R97-P;VYS90H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("8D;7-G("`@;W5T9V]I;F<@
M4T]!4"!P86-K86=E"B`@("`@*B!`<&%R86T@<W1R:6YG("`D86-T:6]N("`@
M4T]!4"!!8W1I;VX*("`@("`J($!R971U<FX@<W1R:6YG("8D<F5S<&]N<V4@
M("!R97-P;VYS92!D871A+"!M:6YU<R!H='1P(&AE861E<G,*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B`F7W-E;F1(5%10
M*"8D;7-G+"`D;W!T:6]N<RD*("`@('L*("`@("`@("`D=&AI<RT^:6YC;VUI
M;F=?<&%Y;&]A9"`]("<G.PH@("`@("`@("1T:&ES+3Y?9V5T4F5Q=65S="@D
M;7-G+"`D;W!T:6]N<RD["B`@("`@("`@)&AO<W0@/2`D=&AI<RT^=7)L<&%R
M='-;)VAO<W0G73L*("`@("`@("`D<&]R="`]("1T:&ES+3YU<FQP87)T<ULG
M<&]R="==.PH@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG<')O>'E?:&]S
M="==*2D@>PH@("`@("`@("`@("`D:&]S="`]("1O<'1I;VYS6R=P<F]X>5]H
M;W-T)UT["B`@("`@("`@("`@("1P;W)T(#T@:7-S970H)&]P=&EO;G-;)W!R
M;WAY7W!O<G0G72D@/R`D;W!T:6]N<ULG<')O>'E?<&]R="==(#H@.#`X,#L*
M("`@("`@("!]"B`@("`@("`@+R\@<V5N9`H@("`@("`@(&EF("@D=&AI<RT^
M=&EM96]U="`^(#`I('L*("`@("`@("`@("`@)&9P(#T@0&9S;V-K;W!E;B@D
M:&]S="P@)'!O<G0L("1T:&ES+3YE<G)N;RP@)'1H:7,M/F5R<FUS9RP@)'1H
M:7,M/G1I;65O=70I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1F
M<"`]($!F<V]C:V]P96XH)&AO<W0L("1P;W)T+"`D=&AI<RT^97)R;F\L("1T
M:&ES+3YE<G)M<V<I.PH@("`@("`@('T*("`@("`@("!I9B`H(21F<"D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&875L="@B0V]N
M;F5C="!%<G)O<B!T;R`D:&]S=#HD<&]R="(I.PH@("`@("`@('T*("`@("`@
M("!I9B`H)'1H:7,M/G1I;65O=70@/B`P*2!["B`@("`@("`@("`@("\O('-O
M;64@8G5I;&1S(&]F('!H<"!D;R!N;W0@<W5P<&]R="!T:&ES+"!S:6QE;F-E
M"B`@("`@("`@("`@("\O('1H92!W87)N:6YG"B`@("`@("`@("`@($!S;V-K
M971?<V5T7W1I;65O=70H)&9P+"`D=&AI<RT^=&EM96]U="D["B`@("`@("`@
M?0H@("`@("`@(&EF("@A9G!U=',H)&9P+"`D=&AI<RT^;W5T9V]I;F=?<&%Y
M;&]A9"P@<W1R;&5N*"1T:&ES+3YO=71G;VEN9U]P87EL;V%D*2DI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(D5R<F]R
M(%!/4U1I;F<@1&%T82!T;R`D:&]S="(I.PH@("`@("`@('T*"B`@("`@("`@
M+R\@9V5T(')E<&]N<V4*("`@("`@("`O+R!86%@@=&EM92!C;VYS=6UE<@H@
M("`@("`@(&1O('L*("`@("`@("`@("`@)&1A=&$@/2!F<F5A9"@D9G`L(#0P
M.38I.PH@("`@("`@("`@("`D7W1M<%]S=&%T=7,@/2!S;V-K971?9V5T7W-T
M871U<R@D9G`I.PH@("`@("`@("`@("!I9B`H)%]T;7!?<W1A='5S6R=T:6UE
M9%]O=70G72D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I
M<V53;V%P1F%U;'0H(E1I;65D(&]U="!R96%D(&9R;VT@)&AO<W0B*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3YI;F-O
M;6EN9U]P87EL;V%D("X]("1D871A.PH@("`@("`@("`@("!]"B`@("`@("`@
M?2!W:&EL92`H(21?=&UP7W-T871U<ULG96]F)UTI.PH*("`@("`@("!F8VQO
M<V4H)&9P*3L*"B`@("`@("`@:68@*"$D=&AI<RT^7W!A<G-E4F5S<&]N<V4H
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F9A=6QT.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)'1H:7,M/G)E<W!O;G-E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5N9"!O=71G;VEN9R!R97%U97-T+"!A;F0@<F5A9"]P
M87)S92!R97-P;VYS92P@=FEA($A45%!3"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`@)B1M<V<@("!O=71G;VEN9R!33T%0('!A8VMA9V4*("`@("`J
M($!P87)A;2!S=')I;F<@("1A8W1I;VX@("!33T%0($%C=&EO;@H@("`@("H@
M0')E='5R;B!S=')I;F<@)B1R97-P;VYS92`@(')E<W!O;G-E(&1A=&$L(&UI
M;G5S(&AT='`@:&5A9&5R<PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*B\*("`@(&9U;F-T:6]N("9?<V5N9$A45%!3*"8D;7-G+"`D;W!T:6]N<RD*
M("`@('L*("`@("`@("`O*B!.3U1%(%1H:7,@9G5N8W1I;VX@=7-E<R!T:&4@
M0U523"!F=6YC=&EO;G,*("`@("`@("`@*B`@66]U<B!P:'`@;75S="!B92!C
M;VUP:6QE9"!W:71H($-54DP*("`@("`@("`@*B\*("`@("`@("!I9B`H(65X
M=&5N<VEO;E]L;V%D960H)V-U<FPG*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/E]R86ES95-O87!&875L="@G0U523"!%>'1E;G-I;VX@:7,@<F5Q
M=6ER960@9F]R($A45%!3)RD["B`@("`@("`@?0H*("`@("`@("`D8V@@/2!C
M=7)L7VEN:70H*3L*"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=P<F]X
M>5]H;W-T)UTI*2!["B`@("`@("`@("`@("\O("1O<'1I;VYS6R=H='1P7W!R
M;WAY)UT@/3T@)VAO<W1N86UE.G!O<G0G"B`@("`@("`@("`@("1H;W-T(#T@
M)&]P=&EO;G-;)W!R;WAY7VAO<W0G73L*("`@("`@("`@("`@)'!O<G0@/2!I
M<W-E="@D;W!T:6]N<ULG<')O>'E?<&]R="==*2`_("1O<'1I;VYS6R=P<F]X
M>5]P;W)T)UT@.B`X,#@P.PH@("`@("`@("`@("!C=7)L7W-E=&]P="@D8V@L
M($-54DQ/4%1?4%)/6%DL("1H;W-T("X@(CHB("X@)'!O<G0I.PH@("`@("`@
M('T*"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=P<F]X>5]U<V5R)UTI
M*2!["B`@("`@("`@("`@("\O("1O<'1I;VYS6R=H='1P7W!R;WAY7W5S97)P
M=R==(#T]("=U<V5R;F%M93IP87-S=V]R9"<*("`@("`@("`@("`@8W5R;%]S
M971O<'0H)&-H+"!#55),3U!47U!23UA955-%4E!71"P@)&]P=&EO;G-;)W!R
M;WAY7W5S97(G72`N("<Z)R`N("1O<'1I;VYS6R=P<F]X>5]P87-S)UTI.PH@
M("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=U<V5R)UTI
M*2!["B`@("`@("`@("`@(&-U<FQ?<V5T;W!T*"1C:"P@0U523$]05%]54T52
M4%=$+"`D;W!T:6]N<ULG=7-E<B==("X@)SHG("X@)&]P=&EO;G-;)W!A<W,G
M72D["B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S
M;V%P86-T:6]N)UTI*2!["B`@("`@("`@("`@("1O<'1I;VYS6R=S;V%P86-T
M:6]N)UT@/2`G)SL*("`@("`@("!]"B`@("`@("`@8W5R;%]S971O<'0H)&-H
M+"!#55),3U!47TA45%!(14%$15(@+"`@("!A<G)A>2@G0V]N=&5N="U4>7!E
M.B!T97AT+WAM;#MC:&%R<V5T/2<@+B`D=&AI<RT^96YC;V1I;F<L("=33T%0
M06-T:6]N.B`B)RXD;W!T:6]N<ULG<V]A<&%C=&EO;B==+B<B)RDI.PH@("`@
M("`@(&-U<FQ?<V5T;W!T*"1C:"P@0U523$]05%]54T5204=%3E0@+"`@("`@
M)'1H:7,M/E]U<V5R06=E;G0I.PH*("`@("`@("!I9B`H)'1H:7,M/G1I;65O
M=70I('L*("`@("`@("`@("`@8W5R;%]S971O<'0H)&-H+"!#55),3U!47U1)
M345/550L("1T:&ES+3YT:6UE;W5T*3L@+R]T:6UE<R!O=70@869T97(@-',*
M("`@("`@("!]"@H@("`@("`@(&-U<FQ?<V5T;W!T*"1C:"P@0U523$]05%]0
M3U-41DE%3$13+"`@("`@("`D;7-G*3L*("`@("`@("!C=7)L7W-E=&]P="@D
M8V@L($-54DQ/4%1?55),+"`@("`@("`@("`@("`@)'1H:7,M/G5R;"D["B`@
M("`@("`@8W5R;%]S971O<'0H)&-H+"!#55),3U!47U!/4U0L("`@("`@("`@
M("`@(#$I.PH@("`@("`@(&-U<FQ?<V5T;W!T*"1C:"P@0U523$]05%]&04E,
M3TY%4E)/4BP@("`@("`P*3L*("`@("`@("!C=7)L7W-E=&]P="@D8V@L($-5
M4DQ/4%1?1D],3$]73$]#051)3TXL("`@,2D["B`@("`@("`@8W5R;%]S971O
M<'0H)&-H+"!#55),3U!47U)%5%523E1204Y31D52+"`@(#$I.PH@("`@("`@
M(&-U<FQ?<V5T;W!T*"1C:"P@0U523$]05%](14%$15(L("`@("`@("`@("`Q
M*3L*("`@("`@("!I9B`H9&5F:6YE9"@G0U523$]05%](5%107U9%4E-)3TXG
M*2D@>PH@("`@("`@("`@("!C=7)L7W-E=&]P="@D8V@L($-54DQ/4%1?2%14
M4%]615)324].+"`Q*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D
M;W!T:6]N<ULG8W5R;"==*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D;W!T
M:6]N<ULG8W5R;"==(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`@
M("`@8W5R;%]S971O<'0H)&-H+"`D:V5Y+"`D=F%L*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@+R\@4V%V92!T:&4@;W5T9V]I;F<@6$U,
M+B!4:&ES(&1O97-N)W0@<75I=&4@;6%T8V@@7W-E;F1(5%10"B`@("`@("`@
M+R\@87,@0U523"!G96YE<F%T97,@=&AE(&AE861E<G,L(&)U="!H879I;F<@
M=&AE(%A-3"!I<PH@("`@("`@("\O('5S=6%L;'D@=&AE(&UO<W0@:6UP;W)T
M86YT('!A<G0@9F]R('1R86-I;F<O9&5B=6=G:6YG+@H@("`@("`@("1T:&ES
M+3YO=71G;VEN9U]P87EL;V%D(#T@)&US9SL*"B`@("`@("`@)'1H:7,M/FEN
M8V]M:6YG7W!A>6QO860@/2!C=7)L7V5X96,H)&-H*3L*("`@("`@("!I9B`H
M(21T:&ES+3YI;F-O;6EN9U]P87EL;V%D*2!["B`@("`@("`@("`@("1M(#T@
M)V-U<FQ?97AE8R!E<G)O<B`G("X@8W5R;%]E<G)N;R@D8V@I("X@)R`G("X@
M8W5R;%]E<G)O<B@D8V@I.PH@("`@("`@("`@("!C=7)L7V-L;W-E*"1C:"D[
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"1M
M*3L*("`@("`@("!]"B`@("`@("`@8W5R;%]C;&]S92@D8V@I.PH*("`@("`@
M("!I9B`H(21T:&ES+3Y?<&%R<V5297-P;VYS92@I*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^9F%U;'0["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)'1H:7,M/G)E<W!O;G-E.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+U-/05`O4V5R=F5R````````````````````
M````````````````````````````````````````````````````````````
M,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W
M,S$@,#(P-#$U`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4T]!4"]397)V
M97(O5$-0+G!H<```````````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P-C<Q-2`Q,#4Q-30S,S<S,2`P,C$V-#0`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J(%1H:7,@9FEL
M92!C;VYT86EN<R!T:&4@8V]D92!F;W(@=&AE(%1#4"!33T%0('-E<G9E<BX*
M("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T
M:&4@4$A0(&QI8V5N<V4L"B`J('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@
M<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@879A:6QA8FQE
M(&%T"B`J('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@
M=6YA8FQE('1O(&]B=&%I;B!I=`H@*B!T:')O=6=H('1H92!W;W)L9"UW:61E
M+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S
M;R!W92!C86X*("H@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@
M*B!`8V%T96=O<GD@("!796(@4V5R=FEC97,*("H@0'!A8VMA9V4@("`@4T]!
M4`H@*B!`875T:&]R("`@("!3:&%N92!#87)A=F5O(#Q3:&%N94!#87)A=F5O
M+F-O;3X@("!0;W)T('1O(%!%05(@86YD(&UO<F4*("H@0&-O<'ER:6=H="`@
M,C`P,RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0@(%!(4"!,:6-E;G-E(#(N
M,#(*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E
M+U-/05`*("HO"@IR97%U:7)E7V]N8V4@)U-/05`O4V5R=F5R+G!H<"<["@HO
M*BH*("H@4T]!4"!397)V97(@0VQA<W,@=&AA="!I;7!L96UE;G1S(&$@5$-0
M(%-/05`@4V5R=F5R+@H@*B!H='1P.B\O=W=W+G!O8VME='-O87`N8V]M+W-P
M96-S+W-M='!B:6YD:6YG+PH@*@H@*B!4:&ES(&-L87-S(&]V97)R:61E<R!T
M:&4@9&5F875L="!(5%10('-E<G9E<BP@<')O=FED:6YG('1H92!A8FEL:71Y
M('1O"B`J(&%C8V5P="!S;V-K970@8V]N;F5C=&EO;G,@86YD(&5X96-U=&4@
M4T]!4"!C86QL<RX*("H*("H@5$]$3SH*("H@("!U<V4@3F5T7U-O8VME=`H@
M*B`@(&EM<&QE;65N="!S;VUE('-E8W5R:71Y('-C:&5M90H@*B`@(&EM<&QE
M;65N="!S=7!P;W)T(&9O<B!A='1A8VAM96YT<PH@*@H@*B!`86-C97-S("`@
M<'5B;&EC"B`J($!P86-K86=E("!33T%0"B`J($!A=71H;W(@("!3:&%N92!#
M87)A=F5O(#QS:&%N94!P:'`N;F5T/@H@*B\*8VQA<W,@4T]!4%]397)V97)?
M5$-0(&5X=&5N9',@4T]!4%]397)V97(@>PH*("`@('9A<B`D:&5A9&5R<R`]
M(&%R<F%Y*"D["B`@("!V87(@)&QO8V%L861D<CL*("`@('9A<B`D<&]R=#L*
M("`@('9A<B`D;&ES=&5N.PH@("`@=F%R("1R975S93L*"B`@("!F=6YC=&EO
M;B!33T%07U-E<G9E<E]40U`H)&QO8V%L861D<B`]("<Q,C<N,"XP+C$G+"`D
M<&]R="`](#$P,#`P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1L
M:7-T96X@/2`U+"`D<F5U<V4@/2!T<G5E*0H@("`@>PH@("`@("`@('!A<F5N
M=#HZ4T]!4%]397)V97(H*3L*("`@("`@("`D=&AI<RT^;&]C86QA9&1R(#T@
M)&QO8V%L861D<CL*("`@("`@("`D=&AI<RT^<&]R="`]("1P;W)T.PH@("`@
M("`@("1T:&ES+3YL:7-T96X@/2`D;&ES=&5N.PH@("`@("`@("1T:&ES+3YR
M975S92`]("1R975S93L*("`@('T*"B`@("!F=6YC=&EO;B!R=6XH*0H@("`@
M>PH@("`@("`@(&EF("@H)'-O8VL@/2!S;V-K971?8W)E871E*$%&7TE.150L
M(%-/0TM?4U1214%-+"`P*2D@/"`P*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=S;V-K971?8W)E871E*"D@9F%I;&5D
M+B!296%S;VXZ("<@+B!S;V-K971?<W1R97)R;W(H)'-O8VLI*3L*("`@("`@
M("!]"B`@("`@("`@:68@*"1T:&ES+3YR975S92`F)@H@("`@("`@("`@("`A
M0'-O8VME=%]S971O<'0H)'-O8VLL(%-/3%]33T-+150L(%-/7U)%55-%041$
M4BP@,2DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P
M1F%U;'0H)W-O8VME=%]S971O<'0H*2!F86EL960N(%)E87-O;CH@)R`N('-O
M8VME=%]S=')E<G)O<BAS;V-K971?;&%S=%]E<G)O<B@D<V]C:RDI*3L*("`@
M("`@("!]"B`@("`@("`@:68@*"@D<F5T(#T@<V]C:V5T7V)I;F0H)'-O8VLL
M("1T:&ES+3YL;V-A;&%D9'(L("1T:&ES+3YP;W)T*2D@/"`P*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=S;V-K971?
M8FEN9"@I(&9A:6QE9"X@4F5A<V]N.B`G("X@<V]C:V5T7W-T<F5R<F]R*"1R
M970I*3L*("`@("`@("!]"B`@("`@("`@:68@*"@D<F5T(#T@<V]C:V5T7VQI
M<W1E;B@D<V]C:RP@)'1H:7,M/FQI<W1E;BDI(#P@,"D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&875L="@G<V]C:V5T7VQI<W1E
M;B@I(&9A:6QE9"X@4F5A<V]N.B`G("X@<V]C:V5T7W-T<F5R<F]R*"1R970I
M*3L*("`@("`@("!]"@H@("`@("`@('=H:6QE("AT<G5E*2!["B`@("`@("`@
M("`@("1D871A(#T@;G5L;#L*("`@("`@("`@("`@:68@*"@D;7-G<V]C:R`]
M('-O8VME=%]A8V-E<'0H)'-O8VLI*2`\(#`I('L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)W-O8VME=%]A8V-E<'0H*2!F86EL
M960N(%)E87-O;CH@)R`N('-O8VME=%]S=')E<G)O<B@D;7-G<V]C:RDI.PH@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@=VAI;&4@*"1B=68@/2!S;V-K971?<F5A9"@D;7-G<V]C:RP@.#$Y,BDI
M('L*("`@("`@("`@("`@("`@(&EF("@A)&)U9B`]('1R:6TH)&)U9BDI('L*
M("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("1D871A("X]("1B=68["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@(&EF("@D9&%T82D@>PH@("`@("`@("`@("`@("`@
M)')E<W!O;G-E(#T@)'1H:7,M/G-E<G9I8V4H)&1A=&$I.PH@("`@("`@("`@
M("`@("`@+RH@5W)I=&4@=&\@=&AE('-O8VME="X@*B\*("`@("`@("`@("`@
M("`@(&EF("@A<V]C:V5T7W=R:71E*"1M<V=S;V-K+"`D<F5S<&]N<V4L('-T
M<FQE;B@D<F5S<&]N<V4I*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=%<G)O<B!S96YD:6YG(')E<W!O
M;G-E(&1A=&$@<F5A<V]N("<@+B!S;V-K971?<W1R97)R;W(H*2D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@('-O8VME
M=%]C;&]S92`H)&US9W-O8VLI.PH@("`@("`@('T*"B`@("`@("`@<V]C:V5T
M7V-L;W-E("@D<V]C:RD["B`@("!]"@H@("`@9G5N8W1I;VX@<V5R=FEC92@F
M)&1A=&$I"B`@("!["B`@("`@("`@+RH@5$]$3SH@=V4@;F5E9"!T;R!H86YD
M;&4@871T86-H;65N=',@<V]M96AO=RX@*B\*("`@("`@("!R971U<FX@)'1H
M:7,M/G!A<G-E4F5Q=65S="@D9&%T82P@)&%T=&%C:&UE;G1S*3L*("`@('T*
M?0H`````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U-/05`O4V5R
M=F5R+T5M86EL+G!H<```````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,38U,3<@,3`U,34T,S,W,S$@,#(R,C0V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!4:&ES(&9I
M;&4@8V]N=&%I;G,@=&AE(&-O9&4@9F]R('1H92!E;6%I;"!33T%0('-E<G9E
M<BX*("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@
M5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O
M9B!T:&4@4$A0(&QI8V5N<V4L"B`J('1H870@:7,@8G5N9&QE9"!W:71H('1H
M:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@879A:6QA
M8FQE(&%T"B`J('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A
M<F4@=6YA8FQE('1O(&]B=&%I;B!I=`H@*B!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE
M="!S;R!W92!C86X*("H@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@
M*@H@*B!`8V%T96=O<GD@("!796(@4V5R=FEC97,*("H@0'!A8VMA9V4@("`@
M4T]!4`H@*B!`875T:&]R("`@("!3:&%N92!#87)A=F5O(#Q3:&%N94!#87)A
M=F5O+F-O;3X@("!0;W)T('1O(%!%05(@86YD(&UO<F4*("H@0&-O<'ER:6=H
M="`@,C`P,RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0@(%!(4"!,:6-E;G-E
M(#(N,#(*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K
M86=E+U-/05`*("HO"@IR97%U:7)E7V]N8V4@)U-/05`O4V5R=F5R+G!H<"<[
M"G)E<75I<F5?;VYC92`G4T]!4"]#;&EE;G0N<&AP)SL*<F5Q=6ER95]O;F-E
M("=33T%0+U1R86YS<&]R="YP:'`G.PIR97%U:7)E7V]N8V4@)TUA:6PO;6EM
M941E8V]D92YP:'`G.PH*+RHJ"B`J(%-/05`@4V5R=F5R($-L87-S('1H870@
M:6UP;&5M96YT<R!A;B!E;6%I;"!33T%0('-E<G9E<BX*("H@:'1T<#HO+W=W
M=RYP;V-K971S;V%P+F-O;2]S<&5C<R]S;71P8FEN9&EN9R\*("H*("H@5&AI
M<R!C;&%S<R!O=F5R<FED97,@=&AE(&1E9F%U;'0@2%144"!S97)V97(L('!R
M;W9I9&EN9R!T:&4@86)I;&ET>2!T;PH@*B!P87)S92!A;B!E;6%I;"!M97-S
M86=E(&%N9"!E>&5C=71E(%-/05`@8V%L;',N("!4:&ES(&-L87-S($1/15,@
M3D]4('!O<"!T:&4*("H@;65S<V%G93L@=&AE(&UE<W-A9V4L(&-O;7!L971E
M('=I=&@@:&5A9&5R<RP@;75S="!B92!P87-S960@:6X@87,@80H@*B!P87)A
M;65T97(@=&\@=&AE('-E<G9I8V4@9G5N8W1I;VX@8V%L;"X*("H*("H@0&%C
M8V5S<R`@('!U8FQI8PH@*B!`<&%C:V%G92`@4T]!4`H@*B!`875T:&]R("`@
M4VAA;F4@0V%R879E;R`\<VAA;F5`<&AP+FYE=#X*("HO"F-L87-S(%-/05!?
M4V5R=F5R7T5M86EL(&5X=&5N9',@4T]!4%]397)V97(@>PH*("`@('9A<B`D
M:&5A9&5R<R`](&%R<F%Y*"D["@H@("`@9G5N8W1I;VX@4T]!4%]397)V97)?
M16UA:6PH)'-E;F1?<F5S<&]N<V4@/2!T<G5E*0H@("`@>PH@("`@("`@('!A
M<F5N=#HZ4T]!4%]397)V97(H*3L*("`@("`@("`D=&AI<RT^<V5N9%]R97-P
M;VYS92`]("1S96YD7W)E<W!O;G-E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5M;W9E<R!(5%10(&AE861E<G,@9G)O;2!R97-P;VYS92X*("`@("`J"B`@
M("`@*B!43T1/.B!U<V4@4$5!4B!E;6%I;"!C;&%S<V5S"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J+PH@("`@9G5N8W1I;VX@7W!A<G-E16UA:6PH)B1D871A*0H@("`@>PH@
M("`@("`@(&EF("AP<F5G7VUA=&-H*"(O7B@N*C\I7'(_7&Y<<C]<;B@N*BDO
M<R(L("1D871A+"`D;6%T8V@I*2!["@H@("`@("`@("`@("!I9B`H<')E9U]M
M871C:%]A;&PH)R]>*"XJ/RDZ7',K*"XJ*20O;2<L("1M871C:%LQ72P@)&UA
M=&-H97,I*2!["B`@("`@("`@("`@("`@("`D:&,@/2!C;W5N="@D;6%T8VAE
M<ULP72D["B`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D:&,[
M("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^:&5A9&5R<UMS
M=')T;VQO=V5R*"1M871C:&5S6S%=6R1I72E=(#T@=')I;2@D;6%T8VAE<ULR
M75LD:5TI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!I9B`H(7-T<FES='(H)'1H:7,M/FAE861E<G-;)V-O;G1E;G0M
M='EP92==+"`G=&5X="]X;6PG*2D@>PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<F%I<V53;V%P1F%U;'0H)TEN=F%L:60@0V]N=&5N="!4>7!E)RP@
M)R<L("<G+"`G0VQI96YT)RD["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H<W1R8V%S
M96-M<"@D=&AI<RT^:&5A9&5R<ULG8V]N=&5N="UT<F%N<V9E<BUE;F-O9&EN
M9R==+"`G8F%S938T)RD]/3`I('L*("`@("`@("`@("`@("`@("\J(%5N9F]L
M9"!L:6YE<RX@*B\*("`@("`@("`@("`@("`@("1E;F-T97AT(#T@<')E9U]R
M97!L86-E*"(O6UQR?%QN72\B+"`G)RP@)&UA=&-H6S)=*3L*("`@("`@("`@
M("`@("`@("1D871A(#T@8F%S938T7V1E8V]D92@D96YC=&5X="D["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D9&%T82`]("1M871C
M:%LR73L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@268@;F\@8V]N
M=&5N="P@<F5T=7)N(&9A;'-E+B`J+PH@("`@("`@("`@("!R971U<FX@<W1R
M;&5N*"1T:&ES+3YR97%U97-T*2`^(#`["B`@("`@("`@?0H*("`@("`@("`D
M=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=);G9A;&ED($5M86EL($9O<FUA="<L
M("<G+"`G)RP@)T-L:65N="<I.PH*("`@("`@("!R971U<FX@9F%L<V4["B`@
M("!]"@H@("`@9G5N8W1I;VX@8VQI96YT*"8D9&%T82D*("`@('L*("`@("`@
M("`D871T86-H;65N=',@/2!A<G)A>2@I.PH*("`@("`@("`O*B!)9B!N96ET
M:&5R(&UA=&-H97,L('=E)VQL(&IU<W0@=')Y(&ET(&%N>7=A>2X@*B\*("`@
M("`@("!I9B`H<W1R:7-T<B@D9&%T82P@)T-O;G1E;G0M5'EP93H@87!P;&EC
M871I;VXO9&EM92<I*2!["B`@("`@("`@("`@("1T:&ES+3Y?9&5C;V1E1$E-
M14UE<W-A9V4H)&1A=&$L("1T:&ES+3YH96%D97)S+"`D871T86-H;65N=',I
M.PH@("`@("`@("`@("`D=7-E16YC;V1I;F<@/2`G1$E-12<["B`@("`@("`@
M?2!E;'-E:68@*'-T<FES='(H)&1A=&$L("=-24U%+59E<G-I;VXZ)RDI('L*
M("`@("`@("`@("`@+RH@5&AI<R!I<R!A(&UI;64@;65S<V%G92P@;&5T)W,@
M9&5C;V1E(&ET+B`J+PH@("`@("`@("`@("`D=&AI<RT^7V1E8V]D94UI;65-
M97-S86=E*"1D871A+"`D=&AI<RT^:&5A9&5R<RP@)&%T=&%C:&UE;G1S*3L*
M("`@("`@("`@("`@)'5S945N8V]D:6YG(#T@)TUI;64G.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("\J(%1H92!O;&0@9F%L;&)A8VLL(&)U="!D
M96-O9&5-:6UE365S<V%G92!H86YD;&5S('1H:6YG<R!F:6YE+B`J+PH@("`@
M("`@("`@("`D=&AI<RT^7W!A<G-E16UA:6PH)&1A=&$I.PH@("`@("`@('T*
M"B`@("`@("`@+RH@1V5T('1H92!C:&%R86-T97(@96YC;V1I;F<@;V8@=&AE
M(&EN8V]M:6YG(')E<75E<W0@=')E870@:6YC;VUI;F<*("`@("`@("`@*B!D
M871A(&%S(%541BTX(&EF(&YO(&5N8V]D:6YG('-E="X@*B\*("`@("`@("!I
M9B`H(21T:&ES+3YS;V%P9F%U;'0@)B8*("`@("`@("`@("`@(21T:&ES+3Y?
M9V5T0V]N=&5N=$5N8V]D:6YG*"1T:&ES+3YH96%D97)S6R=C;VYT96YT+71Y
M<&4G72DI('L*("`@("`@("`@("`@)'1H:7,M/GAM;%]E;F-O9&EN9R`](%-/
M05!?1$5&055,5%]%3D-/1$E.1SL*("`@("`@("`@("`@+RH@06X@96YC;V1I
M;F<@=V4@9&]N)W0@=6YD97)S=&%N9"P@<F5T=7)N(&$@9F%U;'0N("HO"B`@
M("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)U5N<W5P<&]R=&5D
M(&5N8V]D:6YG+"!U<V4@;VYE(&]F($E33RTX.#4Y+3$L(%53+4%30TE)+"!5
M5$8M."<L("<G+"`G)RP@)U-E<G9E<B<I.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"1T:&ES+3YS;V%P9F%U;'0I('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YS;V%P9F%U;'0M/F=E=$9A=6QT*"D["B`@("`@("`@?0H*("`@("`@
M("`D8VQI96YT(#TF(&YE=R!33T%07T-L:65N="AN=6QL*3L*"B`@("`@("`@
M<F5T=7)N("1C;&EE;G0M/E]?<&%R<V4H)&1A=&$L("1T:&ES+3YX;6Q?96YC
M;V1I;F<L("1T:&ES+3YA='1A8VAM96YT<RD["B`@("!]"@H@("`@9G5N8W1I
M;VX@<V5R=FEC92@F)&1A=&$L("1E;F1P;VEN="`]("<G+"`D<V5N9%]R97-P
M;VYS92`]('1R=64L"B`@("`@("`@("`@("`@("`@("`@("1D=6UP(#T@9F%L
M<V4I"B`@("!["B`@("`@("`@)'1H:7,M/F5N9'!O:6YT(#T@)&5N9'!O:6YT
M.PH@("`@("`@("1A='1A8VAM96YT<R`](&%R<F%Y*"D["B`@("`@("`@)&AE
M861E<G,@/2!A<G)A>2@I.PH*("`@("`@("`O*B!)9B!N96ET:&5R(&UA=&-H
M97,L('=E)VQL(&IU<W0@=')Y(&ET(&%N>7=A>2X@*B\*("`@("`@("!I9B`H
M<W1R:7-T<B@D9&%T82P@)T-O;G1E;G0M5'EP93H@87!P;&EC871I;VXO9&EM
M92<I*2!["B`@("`@("`@("`@("1T:&ES+3Y?9&5C;V1E1$E-14UE<W-A9V4H
M)&1A=&$L("1T:&ES+3YH96%D97)S+"`D871T86-H;65N=',I.PH@("`@("`@
M("`@("`D=7-E16YC;V1I;F<@/2`G1$E-12<["B`@("`@("`@?2!E;'-E:68@
M*'-T<FES='(H)&1A=&$L("=-24U%+59E<G-I;VXZ)RDI('L*("`@("`@("`@
M("`@+RH@5&AI<R!I<R!A(&UI;64@;65S<V%G92P@;&5T)W,@9&5C;V1E(&ET
M+B`J+PH@("`@("`@("`@("`D=&AI<RT^7V1E8V]D94UI;65-97-S86=E*"1D
M871A+"`D=&AI<RT^:&5A9&5R<RP@)&%T=&%C:&UE;G1S*3L*("`@("`@("`@
M("`@)'5S945N8V]D:6YG(#T@)TUI;64G.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("\J(%1H92!O;&0@9F%L;&)A8VLL(&)U="!D96-O9&5-:6UE
M365S<V%G92!H86YD;&5S('1H:6YG<R!F:6YE+B`J+PH@("`@("`@("`@("`D
M=&AI<RT^7W!A<G-E16UA:6PH)&1A=&$I.PH@("`@("`@('T*"B`@("`@("`@
M+RH@1V5T('1H92!C:&%R86-T97(@96YC;V1I;F<@;V8@=&AE(&EN8V]M:6YG
M(')E<75E<W0@=')E870@:6YC;VUI;F<*("`@("`@("`@*B!D871A(&%S(%54
M1BTX(&EF(&YO(&5N8V]D:6YG('-E="X@*B\*("`@("`@("!I9B`H(21R97-P
M;VYS92`F)@H@("`@("`@("`@("`A)'1H:7,M/E]G971#;VYT96YT16YC;V1I
M;F<H)'1H:7,M/FAE861E<G-;)V-O;G1E;G0M='EP92==*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^>&UL7V5N8V]D:6YG(#T@4T]!4%]$149!54Q47T5.0T]$
M24Y'.PH@("`@("`@("`@("`O*B!!;B!E;F-O9&EN9R!W92!D;VXG="!U;F1E
M<G-T86YD+"!R971U<FX@82!F875L="X@*B\*("`@("`@("`@("`@)'1H:7,M
M/E]R86ES95-O87!&875L="@G56YS=7!P;W)T960@96YC;V1I;F<L('5S92!O
M;F4@;V8@25-/+3@X-3DM,2P@55,M05-#24DL(%541BTX)RP@)R<L("<G+"`G
M4V5R=F5R)RD["B`@("`@("`@("`@("1R97-P;VYS92`]("1T:&ES+3YG971&
M875L=$UE<W-A9V4H*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^
M<V]A<&9A=6QT*2!["B`@("`@("`@("`@("1R97-P;VYS92`]("1T:&ES+3YS
M;V%P9F%U;'0M/FUE<W-A9V4H*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D<V]A<%]M<V<@/2`D=&AI<RT^<&%R<V5297%U97-T*"1D871A+"1A
M='1A8VAM96YT<RD["@H@("`@("`@("`@("`O*B!(86YD;&4@36EM92!O<B!$
M24U%(&5N8V]D:6YG+B`J+PH@("`@("`@("`@("`O*B!43T1/.B!$24U%($5N
M8V]D:6YG('-H;W5L9"!M;W9E('1O('1H92!T<F%N<W!O<G0L(&1O(&ET(&AE
M<F4*("`@("`@("`@("`@("H@9F]R(&YO=R!A;F0@9F]R(&5A<V4@;V8@9V5T
M=&EN9R!I="!D;VYE+B`J+PH@("`@("`@("`@("!I9B`H8V]U;G0H)'1H:7,M
M/E]?871T86-H;65N=',I*2!["B`@("`@("`@("`@("`@("!I9B`H)'5S945N
M8V]D:6YG(#T]("=-:6UE)RD@>PH@("`@("`@("`@("`@("`@("`@("1S;V%P
M7VUS9R`]("1T:&ES+3Y?;6%K94UI;65-97-S86=E*"1S;V%P7VUS9RD["B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("\J
M($1E9F%U;'0@:7,@1$E-12X@*B\*("`@("`@("`@("`@("`@("`@("`D<V]A
M<%]M<V<@/2`D=&AI<RT^7VUA:V5$24U%365S<V%G92@D<V]A<%]M<V<I.PH@
M("`@("`@("`@("`@("`@("`@("1H96%D97);)T-O;G1E;G0M5'EP92==(#T@
M)V%P<&QI8V%T:6]N+V1I;64G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'-O87!?;7-G*2D@>PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V53;V%P1F%U;'0H
M)'-O87!?;7-G*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1S;V%P7VUS9RDI('L*("`@("`@
M("`@("`@("`@("1R97-P;VYS92`]("1S;V%P7VUS9ULG8F]D>2==.PH@("`@
M("`@("`@("`@("`@:68@*&-O=6YT*"1S;V%P7VUS9ULG:&5A9&5R<R==*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1H96%D97)S(#T@)'-O87!?;7-G6R=H
M96%D97)S)UT["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D<F5S<&]N<V4@/2`D<V]A<%]M<V<["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^<V5N
M9%]R97-P;VYS92D@>PH@("`@("`@("`@("!I9B`H)&1U;7`I('L*("`@("`@
M("`@("`@("`@('!R:6YT("1R97-P;VYS93L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1F<F]M(#T@87)R87E?:V5Y7V5X:7-T<R@G
M<F5P;'DM=&\G+"`D=&AI<RT^:&5A9&5R<RD@/R`D=&AI<RT^:&5A9&5R<ULG
M<F5P;'DM=&\G72`Z("1T:&ES+3YH96%D97)S6R=F<F]M)UT["@H@("`@("`@
M("`@("`@("`@)'-O87!?=')A;G-P;W)T(#TF(%-/05!?5')A;G-P;W)T.CIG
M9714<F%N<W!O<G0H)VUA:6QT;SHG("X@)&9R;VTL("1T:&ES+3YR97-P;VYS
M95]E;F-O9&EN9RD["B`@("`@("`@("`@("`@("`D9G)O;2`]("1T:&ES+3YE
M;F1P;VEN="`_("1T:&ES+3YE;F1P;VEN="`Z("1T:&ES+3YH96%D97)S6R=T
M;R==.PH@("`@("`@("`@("`@("`@)&AE861E<G-;)TEN+5)E<&QY+51O)UT@
M/2`D=&AI<RT^:&5A9&5R<ULG;65S<V%G92UI9"==.PH@("`@("`@("`@("`@
M("`@)&]P=&EO;G,@/2!A<G)A>2@G9G)O;2<@/3X@)&9R;VTL("=S=6)J96-T
M)R`]/B`D=&AI<RT^:&5A9&5R<ULG<W5B:F5C="==+"`G:&5A9&5R<R<@/3X@
M)&AE861E<G,I.PH@("`@("`@("`@("`@("`@)'-O87!?=')A;G-P;W)T+3YS
M96YD*"1R97-P;VYS92P@)&]P=&EO;G,I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@?0I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4T]!4"]3
M97)V97(O16UA:6Q?1V%T97=A>2YP:'``````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`Q,C4U-B`Q,#4Q-30S,S<S,2`P,C,W,C8`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H:7,@
M9FEL92!C;VYT86EN<R!T:&4@8V]D92!F;W(@=&AE(&5M86EL+4A45%`@4T]!
M4"!G871E=V%Y('-E<G9E<BX*("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*
M("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O
M('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L"B`J('1H870@:7,@
M8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%
M+"!A;F0@:7,@879A:6QA8FQE(&%T"B`J('1H<F]U9V@@=&AE('=O<FQD+7=I
M9&4M=V5B(&%T(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT
M+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(
M4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I=`H@*B!T:')O
M=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O
M(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X*("H@;6%I;"!Y;W4@82!C;W!Y
M(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!796(@4V5R=FEC97,*
M("H@0'!A8VMA9V4@("`@4T]!4`H@*B!`875T:&]R("`@("!3:&%N92!#87)A
M=F5O(#Q3:&%N94!#87)A=F5O+F-O;3X@("!0;W)T('1O(%!%05(@86YD(&UO
M<F4*("H@0&-O<'ER:6=H="`@,C`P,RTR,#`U(%1H92!02%`@1W)O=7`*("H@
M0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT
M>'0@(%!(4"!,:6-E;G-E(#(N,#(*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E
M87(N<&AP+FYE="]P86-K86=E+U-/05`*("HO"@IR97%U:7)E7V]N8V4@)U-/
M05`O4V5R=F5R+T5M86EL+G!H<"<["G)E<75I<F5?;VYC92`G4T]!4"]4<F%N
M<W!O<G0N<&AP)SL*"B\J*@H@*B!33T%0(%-E<G9E<B!#;&%S<R!T:&%T(&EM
M<&QE;65N=',@86X@96UA:6P@4T]!4"!S97)V97(N"B`J(&AT='`Z+R]W=W<N
M<&]C:V5T<V]A<"YC;VTO<W!E8W,O<VUT<&)I;F1I;F<O"B`J"B`J(%1H:7,@
M8VQA<W,@;W9E<G)I9&5S('1H92!D969A=6QT($A45%`@<V5R=F5R+"!P<F]V
M:61I;F<@=&AE(&%B:6QI='D@=&\*("H@<&%R<V4@86X@96UA:6P@;65S<V%G
M92!A;F0@97AE8W5T92!S;V%P(&-A;&QS+B`@5&AI<R!C;&%S<R!$3T53($Y/
M5"!P;W`@=&AE"B`J(&UE<W-A9V4[('1H92!M97-S86=E+"!C;VUP;&5T92!W
M:71H(&AE861E<G,L(&UU<W0@8F4@<&%S<V5D(&EN(&%S(&$*("H@<&%R86UE
M=&5R('1O('1H92!S97)V:6-E(&9U;F-T:6]N(&-A;&PN"B`J"B`J(%1H:7,@
M8VQA<W,@8V%L;',@82!P<F]V:61E9"!(5%10(%-/05`@<V5R=F5R+"!F;W)W
M87)D:6YG('1H92!E;6%I;"!R97%U97-T+`H@*B!T:&5N('-E;F1I;F<@=&AE
M($A45%`@<F5S<&]N<V4@;W5T(&%S(&%N(&5M86EL+@H@*@H@*B!`86-C97-S
M("`@<'5B;&EC"B`J($!P86-K86=E("!33T%0"B`J($!A=71H;W(@("!3:&%N
M92!#87)A=F5O(#QS:&%N94!P:'`N;F5T/@H@*B\*8VQA<W,@4T]!4%]397)V
M97)?16UA:6Q?1V%T97=A>2!E>'1E;F1S(%-/05!?4V5R=F5R7T5M86EL('L*
M"B`@("!V87(@)&=A=&5W87D@/2!N=6QL.PH@("`@=F%R("1D=6UP(#T@9F%L
M<V4["@H@("`@9G5N8W1I;VX@4T]!4%]397)V97)?16UA:6Q?1V%T97=A>2@D
M9V%T97=A>2`]("<G+"`D<V5N9%]R97-P;VYS92`]('1R=64L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D=6UP(#T@9F%L<V4I
M"B`@("!["B`@("`@("`@<&%R96YT.CI33T%07U-E<G9E<B@I.PH@("`@("`@
M("1T:&ES+3YS96YD7W)E<W!O;G-E(#T@)'-E;F1?<F5S<&]N<V4["B`@("`@
M("`@)'1H:7,M/F=A=&5W87D@/2`D9V%T97=A>3L*("`@("`@("`D=&AI<RT^
M9'5M<"`]("1D=6UP.PH@("`@?0H*("`@(&9U;F-T:6]N('-E<G9I8V4H)B1D
M871A+"`D9V%T97=A>2`]("<G+"`D96YD<&]I;G0@/2`G)RP*("`@("`@("`@
M("`@("`@("`@("`@)'-E;F1?<F5S<&]N<V4@/2!T<G5E+"`D9'5M<"`](&9A
M;'-E*0H@("`@>PH@("`@("`@("1T:&ES+3YE;F1P;VEN="`]("1E;F1P;VEN
M=#L*("`@("`@("`D<F5S<&]N<V4@/2`G)SL*("`@("`@("`D=7-E16YC;V1I
M;F<@/2`G36EM92<["B`@("`@("`@)&]P=&EO;G,@/2!A<G)A>2@I.PH@("`@
M("`@(&EF("@A)&=A=&5W87DI('L*("`@("`@("`@("`@)&=A=&5W87D@/2`D
M=&AI<RT^9V%T97=A>3L*("`@("`@("!]"@H@("`@("`@("\J(%=E(&AA=F4@
M82!F=6QL('-E="!O9B!H96%D97)S+"!N965D('1O(&9I;F0@=&AE(&9I<G-T
M(&)L86YK"B`@("`@("`@("H@;&EN92X@*B\*("`@("`@("`D=&AI<RT^7W!A
M<G-E16UA:6PH)&1A=&$I.PH@("`@("`@(&EF("@D=&AI<RT^9F%U;'0I('L*
M("`@("`@("`@("`@)')E<W!O;G-E(#T@)'1H:7,M/F9A=6QT+3YM97-S86=E
M*"D["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^:&5A9&5R<ULG8V]N
M=&5N="UT>7!E)UT@/3T@)V%P<&QI8V%T:6]N+V1I;64G*0H@("`@("`@("`@
M("`D=7-E16YC;V1I;F<@/2`G1$E-12<["@H@("`@("`@("\J($-A;&P@=&AE
M($A45%`@4V5R=F5R+B`J+PH@("`@("`@(&EF("@A)')E<W!O;G-E*2!["B`@
M("`@("`@("`@("1S;V%P7W1R86YS<&]R="`])B!33T%07U1R86YS<&]R=#HZ
M9V5T5')A;G-P;W)T*"1G871E=V%Y+"`D=&AI<RT^>&UL7V5N8V]D:6YG*3L*
M("`@("`@("`@("`@:68@*"1S;V%P7W1R86YS<&]R="T^9F%U;'0I('L*("`@
M("`@("`@("`@("`@("1R97-P;VYS92`]("1S;V%P7W1R86YS<&]R="T^9F%U
M;'0M/FUE<W-A9V4H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@+RH@4V5N9"!T:&4@;65S<V%G92X@*B\*("`@("`@("!I9B`H(21R97-P
M;VYS92D@>PH@("`@("`@("`@("`D;W!T:6]N<ULG<V]A<&%C=&EO;B==(#T@
M)'1H:7,M/FAE861E<G-;)W-O87!A8W1I;VXG73L*("`@("`@("`@("`@)&]P
M=&EO;G-;)VAE861E<G,G75LG0V]N=&5N="U4>7!E)UT@/2`D=&AI<RT^:&5A
M9&5R<ULG8V]N=&5N="UT>7!E)UT["@H@("`@("`@("`@("`D<F5S<&]N<V4@
M/2`D<V]A<%]T<F%N<W!O<G0M/G-E;F0H)&1A=&$L("1O<'1I;VYS*3L*("`@
M("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YH96%D97)S6R=M:6UE+79E<G-I
M;VXG72DI"B`@("`@("`@("`@("`@("`D;W!T:6]N<ULG:&5A9&5R<R==6R=-
M24U%+59E<G-I;VXG72`]("1T:&ES+3YH96%D97)S6R=M:6UE+79E<G-I;VXG
M73L*"B`@("`@("`@("`@(&EF("@D<V]A<%]T<F%N<W!O<G0M/F9A=6QT*2![
M"B`@("`@("`@("`@("`@("`D<F5S<&]N<V4@/2`D<V]A<%]T<F%N<W!O<G0M
M/F9A=6QT+3YM97-S86=E*"D["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D<V]A<%]T<F%N<W!O<G0M/G1R86YS<&]R
M="T^871T86-H;65N=',@87,@)&-I9"`]/B`D8F]D>2D@>PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YA='1A8VAM96YT<UM=(#T@87)R87DH)V)O9'DG
M(#T^("1B;V1Y+"`G8VED)R`]/B`D8VED+"`G96YC;V1I;F<G(#T^("=B87-E
M-C0G*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("AC
M;W5N="@D=&AI<RT^7U]A='1A8VAM96YT<RDI('L*("`@("`@("`@("`@("`@
M("`@("!I9B`H)'5S945N8V]D:6YG(#T]("=-:6UE)RD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D<V]A<%]M<V<@/2`D=&AI<RT^7VUA:V5-:6UE365S
M<V%G92@D<F5S<&]N<V4I.PH@("`@("`@("`@("`@("`@("`@("`@("`D;W!T
M:6]N<ULG:&5A9&5R<R==6R=-24U%+59E<G-I;VXG72`]("<Q+C`G.PH@("`@
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M("`@("\J($1E9F%U;'0@:7,@1$E-12X@*B\*("`@("`@("`@("`@("`@("`@
M("`@("`@)'-O87!?;7-G(#T@)'1H:7,M/E]M86ME1$E-14UE<W-A9V4H)')E
M<W!O;G-E*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&]P=&EO;G-;)VAE
M861E<G,G75LG0V]N=&5N="U4>7!E)UT@/2`G87!P;&EC871I;VXO9&EM92<[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1S;V%P7VUS9RDI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)'-O87!?
M;7-G*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@:68@*&ES7V%R<F%Y*"1S;V%P7VUS9RDI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)')E<W!O;G-E(#T@)'-O87!?;7-G6R=B;V1Y)UT["B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AC;W5N="@D<V]A<%]M<V=;)VAE861E
M<G,G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D;W!T:6]N<ULG:&5A9&5R<R==*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1O<'1I;VYS6R=H96%D97)S)UT@/2!A<G)A>5]M97)G
M92@D;W!T:6]N<ULG:&5A9&5R<R==+"`D<V]A<%]M<V=;)VAE861E<G,G72D[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1O<'1I;VYS6R=H96%D97)S)UT@
M/2`D<V]A<%]M<V=;)VAE861E<G,G73L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES+3YS96YD7W)E<W!O;G-E*2![
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^9'5M<"!\?"`D9'5M<"D@>PH@("`@
M("`@("`@("`@("`@<')I;G0@)')E<W!O;G-E.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)&9R;VT@/2!A<G)A>5]K97E?97AI<W1S
M*"=R97!L>2UT;R<L("1T:&ES+3YH96%D97)S*2`_("1T:&ES+3YH96%D97)S
M6R=R97!L>2UT;R==(#H@)'1H:7,M/FAE861E<G-;)V9R;VTG73L*"B`@("`@
M("`@("`@("`@("`D<V]A<%]T<F%N<W!O<G0@/28@4T]!4%]4<F%N<W!O<G0Z
M.F=E=%1R86YS<&]R="@G;6%I;'1O.B<@+B`D9G)O;2P@)'1H:7,M/G)E<W!O
M;G-E7V5N8V]D:6YG*3L*("`@("`@("`@("`@("`@("1F<F]M(#T@)'1H:7,M
M/F5N9'!O:6YT(#\@)'1H:7,M/F5N9'!O:6YT(#H@)'1H:7,M/FAE861E<G-;
M)W1O)UT["B`@("`@("`@("`@("`@("`D:&5A9&5R<R`](&%R<F%Y*"=);BU2
M97!L>2U4;R<@/3X@)'1H:7,M/FAE861E<G-;)VUE<W-A9V4M:60G72D["B`@
M("`@("`@("`@("`@("`D;W!T:6]N<R`](&%R<F%Y*"=F<F]M)R`]/B`D9G)O
M;2P@)W-U8FIE8W0G/3X@)'1H:7,M/FAE861E<G-;)W-U8FIE8W0G72P@)VAE
M861E<G,G(#T^("1H96%D97)S*3L*("`@("`@("`@("`@("`@("1S;V%P7W1R
M86YS<&]R="T^<V5N9"@D<F5S<&]N<V4L("1O<'1I;VYS*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@('T*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O4T]!4"]4>7!E````````````````````````
M```````````````````````````````````````````````````````````P
M,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<S
M,2`P,C`P-S``(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]33T%0+U1Y<&4O
M9'5R871I;VXN<&AP````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#$S-#`V(#$P-3$U-#,S-S,Q(#`R,C4Q,0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*@IH='1P.B\O=W=W+G<S
M+F]R9R]44B]X;6QS8VAE;6$M,B\*"EM$969I;FET:6]N.ET@("!D=7)A=&EO
M;B!R97!R97-E;G1S(&$@9'5R871I;VX@;V8@=&EM92X@5&AE('9A;'5E('-P
M86-E(&]F"F1U<F%T:6]N(&ES(&$@<VEX+61I;65N<VEO;F%L('-P86-E('=H
M97)E('1H92!C;V]R9&EN871E<R!D97-I9VYA=&4@=&AE"D=R96=O<FEA;B!Y
M96%R+"!M;VYT:"P@9&%Y+"!H;W5R+"!M:6YU=&4L(&%N9"!S96-O;F0@8V]M
M<&]N96YT<PID969I;F5D(&EN("`U+C4N,RXR(&]F(%M)4T\@.#8P,5TL(')E
M<W!E8W1I=F5L>2X@5&AE<V4@8V]M<&]N96YT<R!A<F4*;W)D97)E9"!I;B!T
M:&5I<B!S:6=N:69I8V%N8V4@8GD@=&AE:7(@;W)D97(@;V8@87!P96%R86YC
M92!I+F4N(&%S('EE87(L"FUO;G1H+"!D87DL(&AO=7(L(&UI;G5T92P@86YD
M('-E8V]N9"X@"@HS+C(N-BXQ($QE>&EC86P@<F5P<F5S96YT871I;VX*5&AE
M(&QE>&EC86P@<F5P<F5S96YT871I;VX@9F]R(&1U<F%T:6]N(&ES('1H92!;
M25-/(#@V,#%=(&5X=&5N9&5D"F9O<FUA="!0;EEN($UN1%1N2"!N36Y3+"!W
M:&5R92!N62!R97!R97-E;G1S('1H92!N=6UB97(@;V8*>65A<G,L(&Y-('1H
M92!N=6UB97(@;V8@;6]N=&AS+"!N1"!T:&4@;G5M8F5R(&]F(&1A>7,L("=4
M)R!I<R!T:&4*9&%T92]T:6UE('-E<&%R871O<BP@;D@@=&AE(&YU;6)E<B!O
M9B!H;W5R<RP@;DT@=&AE(&YU;6)E<B!O9@IM:6YU=&5S(&%N9"!N4R!T:&4@
M;G5M8F5R(&]F('-E8V]N9',N(%1H92!N=6UB97(@;V8@<V5C;VYD<PIC86X@
M:6YC;'5D92!D96-I;6%L(&1I9VET<R!T;R!A<F)I=')A<GD@<')E8VES:6]N
M+@H*5&AE('9A;'5E<R!O9B!T:&4@665A<BP@36]N=&@L($1A>2P@2&]U<B!A
M;F0@36EN=71E<R!C;VUP;VYE;G1S"F%R92!N;W0@<F5S=')I8W1E9"!B=70@
M86QL;W<@86X@87)B:71R87)Y(&EN=&5G97(N(%-I;6EL87)L>2P@=&AE"G9A
M;'5E(&]F('1H92!396-O;F1S(&-O;7!O;F5N="!A;&QO=W,@86X@87)B:71R
M87)Y(&1E8VEM86PN"E1H=7,L('1H92!L97AI8V%L(')E<')E<V5N=&%T:6]N
M(&]F(&1U<F%T:6]N(&1O97,@;F]T(&9O;&QO=R!T:&4*86QT97)N871I=F4@
M9F]R;6%T(&]F("`U+C4N,RXR+C$@;V8@6TE33R`X-C`Q72X*"D%N(&]P=&EO
M;F%L('!R96-E9&EN9R!M:6YU<R!S:6=N("@G+2<I(&ES(&%L;&]W960L('1O
M(&EN9&EC871E(&$*;F5G871I=F4@9'5R871I;VXN($EF('1H92!S:6=N(&ES
M(&]M:71T960@82!P;W-I=&EV92!D=7)A=&EO;B!I<PII;F1I8V%T960N(%-E
M92!A;'-O($E33R`X-C`Q($1A=&4@86YD(%1I;64@1F]R;6%T<R`H1"DN(`H*
M1F]R(&5X86UP;&4L('1O(&EN9&EC871E(&$@9'5R871I;VX@;V8@,2!Y96%R
M+"`R(&UO;G1H<RP@,R!D87ES+`HQ,"!H;W5R<RP@86YD(#,P(&UI;G5T97,L
M(&]N92!W;W5L9"!W<FET93H@4#%9,DTS1%0Q,$@S,$TN"D]N92!C;W5L9"!A
M;'-O(&EN9&EC871E(&$@9'5R871I;VX@;V8@;6EN=7,@,3(P(&1A>7,@87,Z
M("U0,3(P1"X@"@I2961U8V5D('!R96-I<VEO;B!A;F0@=')U;F-A=&5D(')E
M<')E<V5N=&%T:6]N<R!O9B!T:&ES(&9O<FUA=`IA<F4@86QL;W=E9"!P<F]V
M:61E9"!T:&5Y(&-O;F9O<FT@=&\@=&AE(&9O;&QO=VEN9SH@"@I)9B!T:&4@
M;G5M8F5R(&]F('EE87)S+"!M;VYT:',L(&1A>7,L(&AO=7)S+"!M:6YU=&5S
M+"!O<B!S96-O;F1S"FEN(&%N>2!E>'!R97-S:6]N(&5Q=6%L<R!Z97)O+"!T
M:&4@;G5M8F5R(&%N9"!I=',@8V]R<F5S<&]N9&EN9PID97-I9VYA=&]R("IM
M87DJ(&)E(&]M:71T960N($AO=V5V97(L(&%T(&QE87-T(&]N92!N=6UB97(@
M86YD"FET<R!D97-I9VYA=&]R("IM=7-T*B!B92!P<F5S96YT+B`*5&AE('-E
M8V]N9',@<&%R="`J;6%Y*B!H879E(&$@9&5C:6UA;"!F<F%C=&EO;BX@"E1H
M92!D97-I9VYA=&]R("=4)R!S:&%L;"!B92!A8G-E;G0@:68@86QL(&]F('1H
M92!T:6UE(&ET96US(&%R92!A8G-E;G0N"E1H92!D97-I9VYA=&]R("=0)R!M
M=7-T(&%L=V%Y<R!B92!P<F5S96YT+B`*1F]R(&5X86UP;&4L(%`Q,S0W62P@
M4#$S-#=-(&%N9"!0,5DR350R2"!A<F4@86QL(&%L;&]W960[(%`P63$S-#=-
M"F%N9"!0,%DQ,S0W33!$(&%R92!A;&QO=V5D+B!0+3$S-#=-(&ES(&YO="!A
M;&QO=V5D(&%L=&AO=6=H("U0,3,T-TT*:7,@86QL;W=E9"X@4#%9,DU4(&ES
M(&YO="!A;&QO=V5D+B`*"BHO"@HO*B!T:&ES(&ES(&]N;'D@86X@87!R;WAI
M;6%T:6]N(&]F(&1U<F%T:6]N+"!M;W)E('=O<FL@<W1I;&P@=&\@9&\N"B`@
M('-E92!A8F]V92!S8VAE;6$@=7)L(&9O<B!M;W)E(&EN9F\@;VX@9'5R871I
M;VX*("`@"B`@(%1/1$\Z(&9I9W5R92!O=70@8F5S="!A<')O>&EM871I;VX@
M9F]R('EE87(@86YD(&UO;G1H(&-O;G9E<G-I;VX@=&\@<V5C;VYD<PHJ+PH@
M("`*)&5R96=?9'5R871I;VX@/2`G*"TI/U`H6S`M.5TK62D_*%LP+3E=*TTI
M/RA;,"TY72M$*3]4/RA;,"TY72M(*3\H6S`M.5TK32D_*%LP+3E=*U,I/R<[
M"F-L87-S(%-/05!?5'EP95]D=7)A=&EO;@I["B`@("`O+R!F;W)M870@4&Y9
M;DUN1%1N2&Y-;E,*("`@(&9U;F-T:6]N('5N:7A?=&]?9'5R871I;VXH)'-E
M8V]N9',I('L*("`@("`@("!R971U<FX@4T]!4%]4>7!E7V1U<F%T:6]N.CIG
M971D=7)A=&EO;B@D<V5C;VYD<RD["B`@("!]"B`@("`*("`@(&9U;F-T:6]N
M(&UO9"@D82P@)&(L("8D9"P@)B1R*2!["B`@("`@("`@)&0@/2!F;&]O<B@@
M)&$@+R`D8B`I.PH@("`@("`@("1R(#T@)&$@)2`D8CL*("`@('T*("`@(`H@
M("`@9G5N8W1I;VX@9V5T9'5R871I;VXH)'-E8V]N9',I('L*("`@("`@("`D
M;F5G(#T@)R<["B`@("`@("`@:68@*"1S96-O;F1S(#P@,"D@>PH@("`@("`@
M("`@("`D;F5G(#T@)RTG.PH@("`@("`@("`@("`D<V5C;VYD<R`]("1S96-O
M;F1S("H@+3$["B`@("`@("`@?0H@("`@("`@(`H@("`@("`@("1?;6D@/2`V
M,#L*("`@("`@("`D7V@@/2`D7VUI("H@-C`["B`@("`@("`@)%]D(#T@)%]H
M("H@,C0["B`@("`@("`@+R\@6%A8(&AO=R!D;R!W92!P<F]P97)L>2!H86YD
M;&4@;6]N=&@@86YD('EE87(@=F%L=65S/PH@("`@("`@("1?;2`]("1?9"`J
M(#,P.PH@("`@("`@("1?>2`]("1?9"`J(#,V-3L*"B`@("`@("`@4T]!4%]4
M>7!E7V1U<F%T:6]N.CIM;V0H)'-E8V]N9',L("1?>2P@)'DL("1S96-O;F1S
M*3L*("`@("`@("!33T%07U1Y<&5?9'5R871I;VXZ.FUO9"@D<V5C;VYD<RP@
M)%]M+"`D;2P@)'-E8V]N9',I.PH@("`@("`@(%-/05!?5'EP95]D=7)A=&EO
M;CHZ;6]D*"1S96-O;F1S+"`D7V0L("1D+"`D<V5C;VYD<RD["B`@("`@("`@
M4T]!4%]4>7!E7V1U<F%T:6]N.CIM;V0H)'-E8V]N9',L("1?:"P@)&@L("1S
M96-O;F1S*3L*("`@("`@("!33T%07U1Y<&5?9'5R871I;VXZ.FUO9"@D<V5C
M;VYD<RP@)%]M:2P@)&UI+"`D<RD["B`@("`@("`@"B`@("`@("`@)&1U<F%T
M:6]N(#T@)&YE9RXG4"<["B`@("`@("`@:68@*"1Y*2`D9'5R871I;VX@+CT@
M)'DN)UDG.PH@("`@("`@(&EF("@D;2D@)&1U<F%T:6]N("X]("1M+B=-)SL*
M("`@("`@("!I9B`H)&0I("1D=7)A=&EO;B`N/2`D9"XG1"<["B`@("`@("`@
M:68@*"1H('Q\("1M:2!\?"`D<RD@)&1U<F%T:6]N("X])U0G.PH@("`@("`@
M(&EF("@D:"D@)&1U<F%T:6]N("X]("1H+B=()SL*("`@("`@("!I9B`H)&UI
M*2`D9'5R871I;VX@+CT@)&UI+B=-)SL*("`@("`@("!I9B`H)',I("1D=7)A
M=&EO;B`N/2`D<RXG4R<["B`@("`@("`@:68@*"1D=7)A=&EO;B`]/2`G4"<@
M?'P@)&1U<F%T:6]N(#T]("<M4"<I("1D=7)A=&EO;B`]("=05#!3)SL*("`@
M("`@("!R971U<FX@)&1U<F%T:6]N.PH@("`@?0H@("`@"B`@("!F=6YC=&EO
M;B!M:V1U<F%T:6]N*"1N+"`D62P@)$UO+"`D1"P@)$@L("1-:2P@)%,I('L*
M("`@("`@("`D7VUI(#T@-C`["B`@("`@("`@)%]H(#T@)%]M:2`J(#8P.PH@
M("`@("`@("1?9"`]("1?:"`J(#(T.PH@("`@("`@("\O(%A86"!H;W<@9&\@
M=V4@<')O<&5R;'D@:&%N9&QE(&UO;G1H(&%N9"!Y96%R('9A;'5E<S\*("`@
M("`@("`D7VT@/2`D7V0@*B`S,#L*("`@("`@("`D7WD@/2`D7V0@*B`S-C4[
M"B`@("`@("`@"B`@("`@("`@)'-E8R`]("19("H@)%]Y("L@)$UO("H@)%]M
M("L@)$0@*B`D7V0@*R`D2"`J("1?:"`K("1-:2`J("1?;6D@*R`D4SL*("`@
M("`@("!I9B`H)&X@/3T@)RTG*2`D<V5C(#T@)'-E8R`J("TQ.PH@("`@("`@
M(')E='5R;B`D<V5C.PH@("`@?0H@("`@"B`@("!F=6YC=&EO;B!D=7)A=&EO
M;E]T;U]U;FEX*"1D=7)A=&EO;BD@>PH@("`@("`@(&=L;V)A;"`D97)E9U]D
M=7)A=&EO;CL*("`@("`@("!I9B`H97)E9R@D97)E9U]D=7)A=&EO;BPD9'5R
M871I;VXL)')E9W,I*2!["B`@("`@("`@("`@(')E='5R;B!33T%07U1Y<&5?
M9'5R871I;VXZ.FUK9'5R871I;VXH)')E9W-;,5TL("1R96=S6S)=+"`D<F5G
M<ULS72P@)')E9W-;-%TL("1R96=S6S5=+"`D<F5G<ULV72P@)')E9W-;-UTI
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@1D%,4T4["B`@("!]"B`@("`*
M("`@(&9U;F-T:6]N(&ES7V1U<F%T:6]N*"1D=7)A=&EO;BD@>PH@("`@("`@
M(&=L;V)A;"`D97)E9U]D=7)A=&EO;CL*("`@("`@("!R971U<FX@97)E9R@D
M97)E9U]D=7)A=&EO;BPD9'5R871I;VXL)')E9W,I.PH@("`@?0H@("`@"B`@
M("!F=6YC=&EO;B!?=&5S="@D=&EM92D@>PH@("`@("`@(&EF("A33T%07U1Y
M<&5?9'5R871I;VXZ.FES7V1U<F%T:6]N*"1T:6UE*2D@>PH@("`@("`@("`@
M("`D="`](%-/05!?5'EP95]D=7)A=&EO;CHZ9'5R871I;VY?=&]?=6YI>"@D
M=&EM92D["B`@("`@("`@("`@(&5C:&\@(D1U<F%T:6]N.B`D=&EM92!I<R`B
M+B1T+B(@<V5C;VYD<UQN(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D="`](%-/05!?5'EP95]D=7)A=&EO;CHZ=6YI>%]T;U]D=7)A=&EO;B@D
M=&EM92D["B`@("`@("`@("`@(&5C:&\@(E-E8V]N9',Z("1T:6UE(&ES("(N
M)'0N(B!D=7)A=&EO;EQN(CL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T
M.PH@("`@?0H@("`@"B`@("!F=6YC=&EO;B!A9&0H)&0Q+"`D9#(I('L*("`@
M("`@("`D<S$@/2!33T%07U1Y<&5?9'5R871I;VXZ.F1U<F%T:6]N7W1O7W5N
M:7@H)&0Q*3L*("`@("`@("`D<S(@/2!33T%07U1Y<&5?9'5R871I;VXZ.F1U
M<F%T:6]N7W1O7W5N:7@H)&0R*3L*("`@("`@("!R971U<FX@4T]!4%]4>7!E
M7V1U<F%T:6]N.CIU;FEX7W1O7V1U<F%T:6]N*"1S,2`K("1S,BD["B`@("!]
M"B`@("`*("`@(&9U;F-T:6]N('-U8G1R86-T*"1D,2P@)&0R*2!["B`@("`@
M("`@)',Q(#T@4T]!4%]4>7!E7V1U<F%T:6]N.CID=7)A=&EO;E]T;U]U;FEX
M*"1D,2D["B`@("`@("`@)',R(#T@4T]!4%]4>7!E7V1U<F%T:6]N.CID=7)A
M=&EO;E]T;U]U;FEX*"1D,BD["B`@("`@("`@<F5T=7)N(%-/05!?5'EP95]D
M=7)A=&EO;CHZ=6YI>%]T;U]D=7)A=&EO;B@D<S$@+2`D<S(I.PH@("`@?0H*
M?0H*+RH@=&5S=',@*B\*"B1T(#T@4T]!4%]4>7!E7V1U<F%T:6]N.CI?=&5S
M="@G4#%9,DTS1%0Q,$@S,$TG*3L*4T]!4%]4>7!E7V1U<F%T:6]N.CI?=&5S
M="@D="D["B1T(#T@4T]!4%]4>7!E7V1U<F%T:6]N.CI?=&5S="@G+5`Q,C!$
M)RD["E-/05!?5'EP95]D=7)A=&EO;CHZ7W1E<W0H)'0I.PH*+R\@9'5R871I
M;VX@<VEN8V4@,3DW,`HD="`](%-/05!?5'EP95]D=7)A=&EO;CHZ7W1E<W0H
M=&EM92@I*3L*4T]!4%]4>7!E7V1U<F%T:6]N.CI?=&5S="@D="D["@IP<FEN
M="`B061D('-H;W5L9"!B92!05#!3.B`B+E-/05!?5'EP95]D=7)A=&EO;CHZ
M861D*"<M4#$R,$0G+"=0-$TG*2XB7&XB.PIP<FEN="`B4W5B=')A8W0@<VAO
M=6QD(&)E(%!4,%,Z("(N4T]!4%]4>7!E7V1U<F%T:6]N.CIS=6)T<F%C="@G
M4#$R,$0G+"=0-$TG*2XB7&XB.PH_/@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U-/05`O5'EP92]H97A"
M:6YA<GDN<&AP````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,U
M,3(@,3`U,34T,S,W,S$@,#(R-C$R`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT
M("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO
M;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I
M<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.
M4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X
M="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@
M>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E
M(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@
M("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@
M>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%-H86YE
M($-A<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/B`@(%!O<G0@=&\@4$5!4B!A
M;F0@;6]R92`@('P*+R\@?"!!=71H;W)S.B!$:65T<FEC:"!!>6%L82`\9&EE
M=')I8VA`9V%N>#0N8V]M/B!/<FEG:6YA;"!!=71H;W(@("`@("`@("!\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z(&AE>$)I
M;F%R>2YP:'`L=B`Q+C8@,C`P-2\P,R\Q,"`R,SHQ-CHS.2!Y=6YO<V@@17AP
M("0*+R\*8VQA<W,@4T]!4%]4>7!E7VAE>$)I;F%R>0I["B`@("!F=6YC=&EO
M;B!T;U]B:6XH)'9A;'5E*0H@("`@>PH@("`@("`@("1L96X@/2!S=')L96XH
M)'9A;'5E*3L*("`@("`@("!R971U<FX@<&%C:R@G2"<@+B`D;&5N+"`D=F%L
M=64I.PH@("`@?0H@("`@9G5N8W1I;VX@=&]?:&5X*"1V86QU92D*("`@('L*
M("`@("`@("!R971U<FX@8FEN,FAE>"@D=F%L=64I.PH@("`@?0H@("`@9G5N
M8W1I;VX@:7-?:&5X8FEN*"1V86QU92D*("`@('L*("`@("`@("`C(&9I<G-T
M('-E92!I9B!T:&5R92!A<F4@86YY(&EN=F%L:60@8VAA<G,*("`@("`@("`D
M;"`]('-T<FQE;B@D=F%L=64I.PH*("`@("`@("!I9B`H)&P@/"`Q('Q\('-T
M<G-P;B@D=F%L=64L("<P,3(S-#4V-S@Y04)#1$5&86)C9&5F)RD@(3T@)&PI
M(')E='5R;B!&04Q313L*"B`@("`@("`@)&)I;B`](%-/05!?5'EP95]H97A"
M:6YA<GDZ.G1O7V)I;B@D=F%L=64I.PH@("`@("`@("1H97@@/2!33T%07U1Y
M<&5?:&5X0FEN87)Y.CIT;U]H97@H)&)I;BD["B`@("`@("`@<F5T=7)N('-T
M<F-A<V5C;7`H)'9A;'5E+"`D:&5X*2`]/2`P.PH@("`@?0I]"@H_/@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]33T%0+U1Y<&4O9&%T951I;64N
M<&AP````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$R-30P(#$P
M-3$U-#,S-S,Q(#`R,C0Q-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@
M,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O
M('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP
M,B!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@?`HO+R!\('1H870@:7,@8G5N
M9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A
M;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@
M=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D
M:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@
M87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@
M=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@
M("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A
M(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!3:&%N92!#87)A
M=F5O(#Q3:&%N94!#87)A=F5O+F-O;3X@("!0;W)T('1O(%!%05(@86YD(&UO
M<F4@("!\"B\O('P@075T:&]R<SH@1&EE=')I8V@@07EA;&$@/&1I971R:6-H
M0&=A;G@T+F-O;3X@3W)I9VEN86P@075T:&]R("`@("`@("`@?`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!D871E5&EM92YP
M:'`L=B`Q+C<@,C`P-2\P,R\Q,"`R,SHQ-CHS.2!Y=6YO<V@@17AP("0*+R\*
M8VQA<W,@4T]!4%]4>7!E7V1A=&54:6UE"GL*("`@('9A<B`D97)E9U]I<V\X
M-C`Q(#T@)R@M/ULP+3E=>S1]*2TH6S`M.5U[,GTI+2A;,"TY77LR?2E4*%LP
M+3E=>S)]*3HH6S`M.5U[,GTI.BA;,"TY77LR?2DH7"Y;,"TY72HI/RA:?%LK
M7"U=6S`M.5U[-'U\6RM<+5U;,"TY77LR?3I;,"TY77LR?2D_)SL*("`@("`@
M("`C(B@M/ULP+3E=>S1]*2TB+B`@+R\@8V5N='5R:65S("8@>65A<G,@0T-9
M62T*("`@("`@("`C(BA;,"TY77LR?2DM(BX@("\O(&UO;G1H<R!-32T*("`@
M("`@("`C(BA;,"TY77LR?2DB+B`@("`O+R!D87ES($1$"B`@("`@("`@(R)4
M(BX@("`@("`@("`@("`@("`@("`@("\O('-E<&%R871O<B!4"B`@("`@("`@
M(R(H6S`M.5U[,GTI.B(N("`O+R!H;W5R<R!H:#H*("`@("`@("`C(BA;,"TY
M77LR?2DZ(BX@("\O(&UI;G5T97,@;6TZ"B`@("`@("`@(R(H6S`M.5U[,GTI
M*%PN6S`M.5TJ*3\B+B`O+R!S96-O;F1S('-S+G-S+BXN"B`@("`@("`@(R(H
M6GQ;*UPM75LP+3E=>S1]?%LK7"U=6S`M.5U[,GTZ6S`M.5U[,GTI/R([("\O
M(%H@=&\@:6YD:6-A=&4@551#+"`M+RM(2#I-33I34RY34RXN+B!F;W(@;&]C
M86P@='HG<PH@("`@("`@(",@:68@;F\@.'1H(')E9R`H6BD@87-S=6UE<R!5
M5$,*("`@('9A<B`D=&EM97-T86UP(#T@+3$["B`@("`*("`@(&9U;F-T:6]N
M(%-/05!?5'EP95]D871E5&EM92@D9&%T92`]("TQ*0H@("`@>PH@("`@("`@
M(&EF("@D9&%T92`]/2`M,2D@)&1A=&4@/2!T:6UE*"D["@H@("`@("`@(&EF
M("AG971T>7!E*"1D871E*2`]/2`G:6YT96=E<B<I('L*("`@("`@("`@("`@
M)'1H:7,M/G1I;65S=&%M<"`]("1D871E.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1T:&ES+3YT:6UE<W1A;7`@/2`D=&AI<RT^=&]5;FEX=&EM
M92@D9&%T92D["B`@("`@("`@?0H@("`@?0H@("`@"B`@("!F=6YC=&EO;B!T
M;U-/05`H)&1A=&4@/2!.54Q,*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^=&]55$,H)&1A=&4I.PH@("`@?0H@("`@"B`@("!F=6YC=&EO;B!T;U-T
M<FEN9R@D=&EM97-T86UP(#T@,"D*("`@('L*("`@("`@("!I9B`H(21T:6UE
M<W1A;7`I("1T:6UE<W1A;7`@/2`D=&AI<RT^=&EM97-T86UP.PH@("`@("`@
M(&EF("@D=&EM97-T86UP(#P@,"D@<F5T=7)N(#`["@H@("`@("`@(')E='5R
M;B!D871E*"=9+6TM9%Q42#II.G-/)RPD=&EM97-T86UP*3L*("`@('T*("`@
M(`H@("`@9G5N8W1I;VX@7W-P;&ET*"1D871E<W1R*0H@("`@>PH@("`@("`@
M(&EF("@A)&1A=&5S='(I"B`@("`@("`@("`@("1D871E<W1R(#T@)'1H:7,M
M/G1O4W1R:6YG*"D["B`@("`@("`@96QS92!I9B`H9V5T='EP92@D9&%T97-T
M<BD@/3T@)VEN=&5G97(G*0H@("`@("`@("`@("`D9&%T97-T<B`]("1T:&ES
M+3YT;U-T<FEN9R@D9&%T97-T<BD["B`@("`@("`@("`@(`H@("`@("`@(&EF
M("AE<F5G*"1T:&ES+3YE<F5G7VES;S@V,#$L)&1A=&5S='(L)')E9W,I*2![
M"B`@("`@("`@("`@(&EF("@D<F5G<ULX72`A/2`G)R`F)B`D<F5G<ULX72`A
M/2`G6B<I('L*("`@("`@("`@("`@("`@("1O<"`]('-U8G-T<B@D<F5G<ULX
M72PP+#$I.PH@("`@("`@("`@("`@("`@)&@@/2!S=6)S='(H)')E9W-;.%TL
M,2PR*3L*("`@("`@("`@("`@("`@(&EF("AS=')S='(H)')E9W-;.%TL)SHG
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1M(#T@<W5B<W1R*"1R96=S6SA=
M+#0L,BD["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("1M(#T@<W5B<W1R*"1R96=S6SA=+#,L,BD["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!I9B`H)&]P(#T]("<K)RD@>PH@("`@
M("`@("`@("`@("`@("`@("1R96=S6S1=(#T@)')E9W-;-%T@+2`D:#L*("`@
M("`@("`@("`@("`@("`@("!I9B`H)')E9W-;-%T@/"`P*2`D<F5G<ULT72`K
M/2`R-#L*("`@("`@("`@("`@("`@("`@("`D<F5G<ULU72`]("1R96=S6S5=
M("T@)&T["B`@("`@("`@("`@("`@("`@("`@:68@*"1R96=S6S5=(#P@,"D@
M)')E9W-;-5T@*ST@-C`["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("1R96=S6S1=(#T@)')E9W-;-%T@*R`D:#L*("`@
M("`@("`@("`@("`@("`@("!I9B`H)')E9W-;-%T@/B`R,RD@)')E9W-;-%T@
M+3T@,C0["B`@("`@("`@("`@("`@("`@("`@)')E9W-;-5T@/2`D<F5G<ULU
M72`K("1M.PH@("`@("`@("`@("`@("`@("`@(&EF("@D<F5G<ULU72`^(#4Y
M*2`D<F5G<ULU72`M/2`V,#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!R971U<FX@)')E9W,["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B!&04Q313L*("`@('T*("`@(`H@("`@9G5N8W1I;VX@=&]5
M5$,H)&1A=&5S='(@/2!.54Q,*0H@("`@>PH@("`@("`@("1R96=S(#T@)'1H
M:7,M/E]S<&QI="@D9&%T97-T<BD["@H@("`@("`@(&EF("@D<F5G<RD@>PH@
M("`@("`@("`@("!R971U<FX@<W!R:6YT9B@G)3`T9"TE,#)D+24P,F14)3`R
M9#HE,#)D.B4P,F1:)RPD<F5G<ULQ72PD<F5G<ULR72PD<F5G<ULS72PD<F5G
M<ULT72PD<F5G<ULU72PD<F5G<ULV72D["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)R<["B`@("!]"@H@("`@9G5N8W1I;VX@=&]5;FEX=&EM92@D9&%T
M97-T<B`]($Y53$PI"B`@("!["B`@("`@("`@)')E9W,@/2`D=&AI<RT^7W-P
M;&ET*"1D871E<W1R*3L*("`@("`@("!I9B`H)')E9W,I('L*("`@("`@("`@
M("`@<F5T=7)N('-T<G1O=&EM92@B)')E9W-;,5TM)')E9W-;,ETM)')E9W-;
M,UT@)')E9W-;-%TZ)')E9W-;-5TZ)')E9W-;-EU:(BD["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B`M,3L*("`@('T*"B`@("!F=6YC=&EO;B!C;VUP87)E
M*"1D871E,2P@)&1A=&4R(#T@3E5,3"D*("`@('L*("`@("`@("!I9B`H)&1A
M=&4R(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1D871E,B`]("1D871E,3L*
M("`@("`@("`@("`@)&1A=&4Q(#T@)'1H:7,M/G1I;65S=&%M<#L*("`@("`@
M("!]"B`@("`@("`@:68@*"%I<U]N=6UE<FEC*"1D871E,2DI"B`@("`@("`@
M("`@("1D871E,2`]("1T:&ES+3YT;U5N:7AT:6UE*"1D871E,2D["B`@("`@
M("`@:68@*"%I<U]N=6UE<FEC*"1D871E,BDI"B`@("`@("`@("`@("1D871E
M,B`]("1T:&ES+3YT;U5N:7AT:6UE*"1D871E,BD["B`@("`@("`@:68@*"1D
M871E,2`A/2`M,2`F)B`D9&%T93(@(3T@+3$I(')E='5R;B`D9&%T93$@+2`D
M9&%T93(["B`@("`@("`@<F5T=7)N("TQ.PH@("`@?0H@("`@"B`@("!F=6YC
M=&EO;B!?=&5S="@D;W)I9R`]("<R,#`Q+3`T+3(U5#`Y.C,Q.C0Q+3`W,#`G
M*0H@("`@>PH@("`@("`@("1U=&,@/2`D=&AI<RT^=&]55$,H)&]R:6<I.PH@
M("`@("`@("1T<S$@/2`D=&AI<RT^=&]5;FEX=&EM92@D;W)I9RD["B`@("`@
M("`@)'1S,B`]("1T:&ES+3YT;U5N:7AT:6UE*"1U=&,I.PH@("`@("`@("1B
M,2`]("1T:&ES+3YT;U-T<FEN9R@D=',Q*3L*("`@("`@("`D8C(@/2`D=&AI
M<RT^=&]3=')I;F<H)'1S,BD["B`@("`@("`@<')I;G0@(F]R:6<Z("1O<FEG
M7&XB.PH@("`@("`@('!R:6YT(")O<FEG('1O551#.B`D=71C7&XB.PH@("`@
M("`@('!R:6YT(")O<FEG('1S.B`D=',Q7&XB.PH@("`@("`@('!R:6YT(")U
M=&,@=',Z("1T<S)<;B(["B`@("`@("`@<')I;G0@(F]R:6<@=',@8F%C:SH@
M)&(Q7&XB.PH@("`@("`@('!R:6YT(")U=&,@=',@8F%C:SH@)&(R7&XB.PH@
M("`@("`@(&EF("@D8C$@(3T@)&]R:6<@?'P@)&(R("$]("1O<FEG*2!["B`@
M("`@("`@("`@(&5C:&\@(D5R<F]R(&EN(&ES;S@V,#$@8V]N=F5R<VEO;G-<
M;B(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@96-H;R`B9&%T951I
M;64@3TM<;B(["B`@("`@("`@?0H@("`@?0I]"@HC('1H97-E('-H;W5L9"!A
M;&P@;6%T8V@*(R1D(#T@;F5W(%-/05!?5'EP95]D871E5&EM92@I.PHC96-H
M;R`D9"T^8V]M<&%R92@B,C`P,2TP-"TR-50R,#HS,3HT,5HB+"(R,#`Q+3`T
M+3(U5#(P.C,Q.C0Q6B(I+B)<;B(["B-E8VAO("1D+3YC;VUP87)E*"(R,#`Q
M+3`T+3(U5#(P.C,Q.C0Q6B(L(C(P,#$M,#0M,C54,3(Z,S$Z-#$M,#@P,"(I
M+B)<;B(["B-E8VAO("1D+3YC;VUP87)E*"(R,#`Q+3`T+3(U5#(P.C,Q.C0Q
M6B(L(C(P,#$M,#0M,C54,3(Z,S$Z-#$M,#@Z,#`B*2XB7&XB.PH*/SX`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]33T%0+W1O;VQS````````````````````````````````````````
M`````````````````````````````````````````#`P,#<U-2``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S,Q(#`R,#,P-P`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+U-/05`O=&]O;',O9V5N<')O>'DN<&AP
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`V,C,@,3`U,34T
M,S,W,S$@,#(R-S4S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"F5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["G)E<75I
M<F5?;VYC92`G4T]!4"]74T1,+G!H<"<["@HO*BH*("H@9V5N<')O>'D*("H*
M("H@82!C;VUM86YD(&QI;F4@=&]O;"!F;W(@9V5N97)A=&EN9R!33T%0('!R
M;WAI97,@9G)O;2!74T1,(&9I;&5S"B`J"B`J(&=E;G!R;WAY+G!H<"!H='1P
M.B\O<VET92]F;V\N=W-D;"`^(&9O;RYP:'`*("H*("HO"@IF=6YC=&EO;B!D
M;U]W<V1L*"1U<FDI('L*("`@("1W<V1L(#TF(&YE=R!33T%07U=31$PH)'5R
M:2D["B`@("!P<FEN="`D=W-D;"T^9V5N97)A=&5!;&Q0<F]X:65S*"D["GT*
M96-H;R`B/#]P:'!<;EQN<F5Q=6ER95]O;F-E("=33T%0+T-L:65N="YP:'`G
M.UQN7&XB.PID;U]W<V1L*"1?4T525D526R=A<F=V)UU;,5TI.PIE8VAO(")<
M;C\^(CL*/SX`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]33T%0+U-E<G9E<BYP:'``````````````````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#<P-S,S(#$P-3$U-#,S-S,Q(#`R,3(Q
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@5&AI<R!F:6QE(&-O;G1A:6YS('1H92!C;V1E(&9O<B!T
M:&4@4T]!4"!S97)V97(N"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J
M"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V
M97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+`H@*B!T:&%T(&ES(&)U
M;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@
M86YD(&ES(&%V86EL86)L92!A=`H@*B!T:')O=6=H('1H92!W;W)L9"UW:61E
M+7=E8B!A="!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@
M;&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70*("H@=&AR;W5G
M:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R!L
M:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N"B`J(&UA:6P@>6]U(&$@8V]P>2!I
M;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@5V5B(%-E<G9I8V5S"B`J
M($!P86-K86=E("`@(%-/05`*("H@0&%U=&AO<B`@("`@1&EE=')I8V@@07EA
M;&$@/&1I971R:6-H0&=A;G@T+F-O;3X@3W)I9VEN86P@075T:&]R"B`J($!A
M=71H;W(@("`@(%-H86YE($-A<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/B`@
M(%!O<G0@=&\@4$5!4B!A;F0@;6]R90H@*B!`875T:&]R("`@("!#:'5C:R!(
M86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX@("!-86EN=&5N86YC90H@*B!`
M875T:&]R("`@("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/B`@("`@
M("!-86EN=&5N86YC90H@*B!`8V]P>7)I9VAT("`R,#`S+3(P,#4@5&AE(%!(
M4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\R7S`R+G1X="`@4$A0($QI8V5N<V4@,BXP,@H@*B!`;&EN:R`@("`@
M("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4T]!4`H@*B\*"G)E<75I
M<F5?;VYC92`G4T]!4"]"87-E+G!H<"<["G)E<75I<F5?;VYC92`G4T]!4"]&
M875L="YP:'`G.PIR97%U:7)E7V]N8V4@)U-/05`O4&%R<V5R+G!H<"<["G)E
M<75I<F5?;VYC92`G4T]!4"]686QU92YP:'`G.PIR97%U:7)E7V]N8V4@)U-/
M05`O5U-$3"YP:'`G.PH*+RHJ"B`J(%-/05`@4V5R=F5R($-L87-S"B`J"B`J
M($]R:6=I;F%L>2!B87-E9"!O;B!33T%0>#0@8GD@1&EE=')I8V@@07EA;&$*
M("H@:'1T<#HO+V1I971R:6-H+F=A;G@T+F-O;2]S;V%P>#0*("H*("H@0&%C
M8V5S<R`@('!U8FQI8PH@*B!`<&%C:V%G92`@4T]!4`H@*B!`875T:&]R("`@
M4VAA;F4@0V%R879E;R`\<VAA;F5`<&AP+FYE=#X@0V]N=F5R<VEO;B!T;R!0
M14%2(&%N9"!U<&1A=&5S"B`J($!A=71H;W(@("!$:65T<FEC:"!!>6%L82`\
M9&EE=')I8VA`9V%N>#0N8V]M/B!/<FEG:6YA;"!!=71H;W(*("HO"F-L87-S
M(%-/05!?4V5R=F5R(&5X=&5N9',@4T]!4%]"87-E"GL*("`@("\J*@H@("`@
M("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1D:7-P871C
M:%]M87`@/2!A<G)A>2@I.R`O+R!C<F5A=&4@96UP='D@9&ES<&%T8V@@;6%P
M"B`@("!V87(@)&1I<W!A=&-H7V]B:F5C=',@/2!A<G)A>2@I.PH@("`@=F%R
M("1S;V%P;V)J96-T(#T@;G5L;#L*("`@('9A<B`D8V%L;%]M971H;V1N86UE
M(#T@;G5L;#L*("`@('9A<B`D8V%L;$AA;F1L97(@/2!N=6QL.PH@("`@=F%R
M("1C86QL5F%L:61A=&EO;B`]('1R=64["@H@("`@+RHJ"B`@("`@*B!!(&QI
M<W0@;V8@:&5A9&5R<R!T:&%T(&%R92!G;VEN9R!T;R!B92!S96YT(&)A8VL@
M=&\@=&AE(&-L:65N="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D:&5A9&5R<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@
M*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1R97%U97-T
M(#T@)R<["@H@("`@+RHJ"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<@(%A-
M3"U%;F-O9&EN9PH@("`@("HO"B`@("!V87(@)'AM;%]E;F-O9&EN9R`](%-/
M05!?1$5&055,5%]%3D-/1$E.1SL*("`@('9A<B`D<F5S<&]N<V5?96YC;V1I
M;F<@/2`G551&+3@G.PH*("`@('9A<B`D<F5S=6QT(#T@)W-U8V-E<W-F=6PG
M.R`O+R!F;W(@;&]G9VEN9R!I;G1E<F]P(')E<W5L=',@=&\@9&(*"B`@("!V
M87(@)&5N9'!O:6YT(#T@)R<[("\O('1H92!U<FD@=&\@344A"@H@("`@=F%R
M("1S97)V:6-E(#T@)R<[("\O<V]A<&%C=&EO;B!H96%D97(*("`@('9A<B`D
M;65T:&]D7VYA;65S<&%C92`](&YU;&P["B`@("!V87(@)%]?;W!T:6]N<R`]
M(&%R<F%Y*"=U<V4G(#T^("=E;F-O9&5D)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W-T>6QE)R`]/B`G<G!C)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W!A<F%M971E<G,G(#T^(#`I.PH*("`@(&9U;F-T:6]N(%-/
M05!?4V5R=F5R*"1O<'1I;VYS(#T@;G5L;"D*("`@('L*("`@("`@("!I;FE?
M<V5T*"=T<F%C:U]E<G)O<G,G+"`Q*3L*("`@("`@("!P87)E;G0Z.E-/05!?
M0F%S92@G4V5R=F5R)RD["@H@("`@("`@(&EF("AI<U]A<G)A>2@D;W!T:6]N
M<RDI('L*("`@("`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=U<V4G72DI
M('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;)W5S92==(#T@
M)&]P=&EO;G-;)W5S92==.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("AI<W-E="@D;W!T:6]N<ULG<W1Y;&4G72DI('L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?7V]P=&EO;G-;)W-T>6QE)UT@/2`D;W!T:6]N<ULG<W1Y;&4G
M73L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H:7-S970H)&]P=&EO
M;G-;)W!A<F%M971E<G,G72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M7V]P=&EO;G-;)W!A<F%M971E<G,G72`]("1O<'1I;VYS6R=P87)A;65T97)S
M)UT["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@+R\@87-S=6UE
M('=E(&5N8V]D92!W:71H('-E8W1I;VX@-0H@("`@("`@("1T:&ES+3Y?<V5C
M=&EO;C4@/2!T<G5E.PH@("`@("`@(&EF("@D=&AI<RT^7U]O<'1I;VYS6R=U
M<V4G73T])VQI=&5R86PG*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V5C=&EO
M;C4@/2!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!%
M<G)O<B!H86YD;&5R(&9O<B!E<G)O<G,@=&AA="!H87!P96X@:6X@<')O>&EE
M9"!M971H;V1S+@H@("`@("H*("`@("`J(%1O(&%L=V%Y<R!R971U<FX@82!V
M86QI9"!33T%0(')E<W!O;G-E(&5V96X@;VX@97)R;W)S('1H870@9&]N)W0@
M:&%P<&5N"B`@("`@*B!I;B!T:&ES(&-O9&4L('1H92!E<G)O<G,@87)E(&-A
M=&-H960L('1R86YS9F]R;65D('1O(&$@4T]!4"!F875L="!A;F0*("`@("`J
M(&EM;65D:6%T96QY('-E;G0@=&\@=&AE(&-L:65N="X*("`@("`J"B`@("`@
M*B!`<V5E(&AT='`Z+R]W=W<N<&AP+FYE="]S971?97)R;W)?:&%N9&QE<@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?97)R;W)(86YD;&5R*"1E<G)N;RP@)&5R
M<FUS9RP@)&9I;&5N86UE+"`D;&EN96YU;2P@)'9A<G,I"B`@("!["B`@("`@
M("`@+RH@5&AE(&5R<F]R(&AA;F1L97(@<VAO=6QD(&EG;F]R92`G,"<@97)R
M;W)S+"!E9RX@:&ED9&5N(&)Y($`@+2!S964*("`@("`@("`@*B!T:&4@<V5T
M7V5R<F]R7VAA;F1L97(@;6%N=6%L('!A9V4N("AT:&%N:W,@=&\@06QA;B!+
M;F]W;&5S*2X@*B\*("`@("`@("!I9B`H(21E<G)N;R!\?"`D97)R;F\@/3T@
M15].3U1)0T4I('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@
M("`@("`@)'1H:7,M/F9A=6QT(#TF(&YE=R!33T%07T9A=6QT*"1E<G)M<V<L
M("=397)V97(G+"`G4$A0)RP@(D5R<FYO.B`D97)R;F]<;D9I;&5N86UE.B`D
M9FEL96YA;65<;DQI;F5N;SH@)&QI;F5N=6U<;B(I.PH*("`@("`@("`D=&AI
M<RT^7W-E;F1297-P;VYS92@I.PH@("`@("`@(&5X:70["B`@("!]"@H@("`@
M9G5N8W1I;VX@7V=E=$-O;G1E;G1%;F-O9&EN9R@D8V]N=&5N=%]T>7!E*0H@
M("`@>PH@("`@("`@("\J($=E="!T:&4@8VAA<F%C=&5R(&5N8V]D:6YG(&]F
M('1H92!I;F-O;6EN9R!R97%U97-T('1R96%T(&EN8V]M:6YG"B`@("`@("`@
M("H@9&%T82!A<R!55$8M."!I9B!N;R!E;F-O9&EN9R!S970N("HO"B`@("`@
M("`@)'1H:7,M/GAM;%]E;F-O9&EN9R`]("=55$8M."<["B`@("`@("`@:68@
M*'-T<G!O<R@D8V]N=&5N=%]T>7!E+"`G/2<I*2!["B`@("`@("`@("`@("1E
M;F,@/2!S=')T;W5P<&5R*'-T<E]R97!L86-E*"<B)RP@)R<L('-U8G-T<BAS
M=')S='(H)&-O;G1E;G1?='EP92P@)STG*2P@,2DI*3L*("`@("`@("`@("`@
M:68@*"%I;E]A<G)A>2@D96YC+"`D=&AI<RT^7V5N8V]D:6YG<RDI('L*("`@
M("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D=&AI<RT^>&UL7V5N8V]D:6YG(#T@)&5N8SL*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*"B`@("`O*BH*("`@("`J
M(%!A<G-E<R!R97%U97-T(&%N9"!P;W-T<R!R97-P;VYS92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<V5R=FEC92@D9&%T82P@)&5N9'!O:6YT(#T@)R<L("1T
M97-T(#T@9F%L<V4I"B`@("!["B`@("`@("`@)')E<W!O;G-E(#T@;G5L;#L*
M("`@("`@("`D871T86-H;65N=',@/2!A<G)A>2@I.PH@("`@("`@("1U<V5%
M;F-O9&EN9R`]("=$24U%)SL*"B`@("`@("`@+RH@1FEG=7)E(&]U="!O=7(@
M96YD<&]I;G0N("HO"B`@("`@("`@)'1H:7,M/F5N9'!O:6YT(#T@)&5N9'!O
M:6YT.PH@("`@("`@(&EF("@A)'1E<W0@)B8@(21T:&ES+3YE;F1P;VEN="D@
M>PH@("`@("`@("`@("`O*B!792=L;"!T<GD@=&\@8G5I;&0@;W5R(&5N9'!O
M:6YT+B`J+PH@("`@("`@("`@("`D=&AI<RT^96YD<&]I;G0@/2`G:'1T<#HO
M+R<@+B`D7U-%4E9%4ELG4T525D527TY!344G73L*("`@("`@("`@("`@:68@
M*"1?4T525D526R=315)615)?4$]25"==*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^96YD<&]I;G0@+CT@)SHG("X@)%]315)615);)U-%4E9%4E]03U)4
M)UT["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/F5N9'!O:6YT
M("X]("1?4T525D526R=30U))4%1?3D%-12==.PH@("`@("`@('T*"B`@("`@
M("`@+RH@1V5T('1H92!C:&%R86-T97(@96YC;V1I;F<@;V8@=&AE(&EN8V]M
M:6YG(')E<75E<W0@=')E870@:6YC;VUI;F<*("`@("`@("`@*B!D871A(&%S
M(%541BTX(&EF(&YO(&5N8V]D:6YG('-E="X@*B\*("`@("`@("!I9B`H:7-S
M970H)%]315)615);)T-/3E1%3E1?5%E012==*2D@>PH@("`@("`@("`@("!I
M9B`H<W1R8V%S96-M<"@D7U-%4E9%4ELG0T].5$5.5%]465!%)UTL("=A<'!L
M:6-A=&EO;B]D:6UE)RD@/3T@,"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]D96-O9&5$24U%365S<V%G92@D9&%T82P@)&AE861E<G,L("1A='1A8VAM
M96YT<RD["B`@("`@("`@("`@("`@("`D=7-E16YC;V1I;F<@/2`G1$E-12<[
M"B`@("`@("`@("`@('T@96QS96EF("AS=')I<W1R*"1?4T525D526R=#3TY4
M14Y47U194$4G72P@)VUU;'1I<&%R="]R96QA=&5D)RDI('L*("`@("`@("`@
M("`@("`@("\J(%1H:7,@:7,@82!M:6UE(&UE<W-A9V4L(&QE="=S(&1E8V]D
M92!I="X@*B\*("`@("`@("`@("`@("`@("1D871A(#T@)T-O;G1E;G0M5'EP
M93H@)R`N"B`@("`@("`@("`@("`@("`@("`@<W1R:7!S;&%S:&5S*"1?4T52
M5D526R=#3TY414Y47U194$4G72D@+@H@("`@("`@("`@("`@("`@("`@(")<
M<EQN7')<;B(@+B`D9&%T83L*("`@("`@("`@("`@("`@("1T:&ES+3Y?9&5C
M;V1E36EM94UE<W-A9V4H)&1A=&$L("1H96%D97)S+"`D871T86-H;65N=',I
M.PH@("`@("`@("`@("`@("`@)'5S945N8V]D:6YG(#T@)TUI;64G.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&EF("@A:7-S970H)&AE861E<G-;)V-O
M;G1E;G0M='EP92==*2D@>PH@("`@("`@("`@("`@("`@)&AE861E<G-;)V-O
M;G1E;G0M='EP92==(#T@<W1R:7!S;&%S:&5S*"1?4T525D526R=#3TY414Y4
M7U194$4G72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"$D=&AI
M<RT^9F%U;'0@)B8*("`@("`@("`@("`@("`@("$D=&AI<RT^7V=E=$-O;G1E
M;G1%;F-O9&EN9R@D:&5A9&5R<ULG8V]N=&5N="UT>7!E)UTI*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^>&UL7V5N8V]D:6YG(#T@4T]!4%]$149!54Q4
M7T5.0T]$24Y'.PH@("`@("`@("`@("`@("`@+RH@1F]U;F0@96YC;V1I;F<@
M=V4@9&]N)W0@=6YD97)S=&%N9#L@<F5T=7)N(&$@9F%U;'0N("HO"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=5;G-U<'!O<G1E
M9"!E;F-O9&EN9RP@=7-E(&]N92!O9B!)4T\M.#@U.2TQ+"!54RU!4T-)22P@
M551&+3@G+"`G)RP@)R<L("=397)V97(G*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@+RH@268@=&AI<R!I<R!N;W0@82!03U-4('=I=&@@
M0V]N=&5N="U4>7!E('1E>'0O>&UL+"!T<GD@=&\@<F5T=7)N(&$*("`@("`@
M("`@*B!74T1,(&9I;&4N("HO"B`@("`@("`@:68@*"$D=&AI<RT^9F%U;'0@
M)B8@(21T97-T("8F"B`@("`@("`@("`@("@D7U-%4E9%4ELG4D5154535%]-
M151(3T0G72`A/2`G4$]35"<@?'P*("`@("`@("`@("`@('-T<FYC;7`H)&AE
M861E<G-;)V-O;G1E;G0M='EP92==+"`G=&5X="]X;6PG+"`X*2`A/2`P*2D@
M>PH@("`@("`@("`@("`O*B!4:&ES(&ES(&YO="!P;W-S:6)L>2!A('9A;&ED
M(%-/05`@<F5Q=65S="P@=')Y('1O(')E='5R;B!A(%=31$P*("`@("`@("`@
M("`@("H@9FEL92X@*B\*("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&
M875L="@G26YV86QI9"!33T%0(')E<75E<W0L(&UU<W0@8F4@4$]35"!W:71H
M(&-O;G1E;G0M='EP93H@=&5X="]X;6PL(&=O=#H@)R`N("AI<W-E="@D:&5A
M9&5R<ULG8V]N=&5N="UT>7!E)UTI(#\@)&AE861E<G-;)V-O;G1E;G0M='EP
M92==(#H@)TYO=&AI;F<A)RDL("<G+"`G)RP@)U-E<G9E<B<I.PH@("`@("`@
M('T*"B`@("`@("`@:68@*"$D=&AI<RT^9F%U;'0I('L*("`@("`@("`@("`@
M+RH@)')E<W!O;G-E(&ES(&$@4T]!4%]-<V<@;V)J96-T+B`J+PH@("`@("`@
M("`@("`D<V]A<%]M<V<@/2`D=&AI<RT^<&%R<V5297%U97-T*"1D871A+"`D
M871T86-H;65N=',I.PH*("`@("`@("`@("`@+RH@2&%N9&QE($UI;64@;W(@
M1$E-12!E;F-O9&EN9RX@*B\*("`@("`@("`@("`@+RH@5$]$3SH@1$E-12!D
M96-O9&EN9R!S:&]U;&0@;6]V92!T;R!T:&4@=')A;G-P;W)T+"!D;R!I="!H
M97)E"B`@("`@("`@("`@("`J(&9O<B!N;W<@86YD(&9O<B!E87-E(&]F(&=E
M='1I;F<@:70@9&]N92X@*B\*("`@("`@("`@("`@:68@*&-O=6YT*"1T:&ES
M+3Y?7V%T=&%C:&UE;G1S*2D@>PH@("`@("`@("`@("`@("`@:68@*"1U<V5%
M;F-O9&EN9R`]/2`G36EM92<I('L*("`@("`@("`@("`@("`@("`@("`D<V]A
M<%]M<V<@/2`D=&AI<RT^7VUA:V5-:6UE365S<V%G92@D<V]A<%]M<V<I.PH@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`O
M+R!D969A=6QT(&ES(&1I;64*("`@("`@("`@("`@("`@("`@("`D<V]A<%]M
M<V<@/2`D=&AI<RT^7VUA:V5$24U%365S<V%G92@D<V]A<%]M<V<I.PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YH96%D97)S6R=#;VYT96YT+51Y<&4G
M72`]("=A<'!L:6-A=&EO;B]D:6UE)SL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1S;V%P7VUS9RDI('L*
M("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E4V]A<$9A
M=6QT*"1S;V%P7VUS9RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D<V]A<%]M<V<I*2!["B`@
M("`@("`@("`@("`@("`D<F5S<&]N<V4@/2`D<V]A<%]M<V=;)V)O9'DG73L*
M("`@("`@("`@("`@("`@(&EF("AC;W5N="@D<V]A<%]M<V=;)VAE861E<G,G
M72DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^:&5A9&5R<R`]("1S
M;V%P7VUS9ULG:&5A9&5R<R==.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)')E<W!O;G-E(#T@)'-O
M87!?;7-G.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D=&AI
M<RT^7W-E;F1297-P;VYS92@D<F5S<&]N<V4I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4V5N9',@=&AE(&9I;F%L($A45%`@<F5S<&]N<V4@=&\@=&AE(&-L
M:65N="P@:6YC;'5D:6YG('1H92!(5%10(&AE861E<@H@("`@("H@86YD('1H
M92!(5%10(&)O9'DN"B`@("`@*@H@("`@("H@268@86X@97)R;W(@:&%P<&5N
M960L(&ET(')E='5R;G,@82!33T%0(&9A=6QT(&EN<W1E860@;V8@=&AE(')E
M<W!O;G-E"B`@("`@*B!B;V1Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)')E<W!O;G-E("!4:&4@<F5S<&]N<V4@8F]D>2X*("`@("`J+PH@("`@
M9G5N8W1I;VX@7W-E;F1297-P;VYS92@D<F5S<&]N<V4@/2`G)RD*("`@('L*
M("`@("`@("`O*B!-86ME(&1I<W1I;F-T:6]N(&)E='=E96X@=&AE(&1I9F9E
M<F5N="!305!)<RP@<G5N;FEN9R!02%`@87,@0T=)(&]R"B`@("`@("`@("H@
M87,@82!M;V1U;&4N("HO"B`@("`@("`@:68@*'-T<FES='(H<&AP7W-A<&E?
M;F%M92@I+"`G8V=I)RD@/3T](#`I('L*("`@("`@("`@("`@)&AD<G-?='EP
M92`]("=3=&%T=7,Z)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M:&1R<U]T>7!E(#T@)TA45%`O,2XQ)SL*("`@("`@("!]"@H@("`@("`@(&EF
M("@D=&AI<RT^9F%U;'0I('L*("`@("`@("`@("`@)&AD<G,@/2`B)&AD<G-?
M='EP92`U,#`@4V]A<"!&875L=%QR7&XB.PH@("`@("`@("`@("`D<F5S<&]N
M<V4@/2`D=&AI<RT^9F%U;'0M/FUE<W-A9V4H*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D:&1R<R`]("(D:&1R<U]T>7!E(#(P,"!/2UQR7&XB
M.PH@("`@("`@('T*("`@("`@("!H96%D97(H)&AD<G,I.PH*("`@("`@("`D
M=&AI<RT^:&5A9&5R<ULG4V5R=F5R)UT@/2!33T%07TQ)0E)!4EE?3D%-13L*
M("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YH96%D97)S6R=#;VYT96YT+51Y
M<&4G72DI('L*("`@("`@("`@("`@)'1H:7,M/FAE861E<G-;)T-O;G1E;G0M
M5'EP92==(#T@)W1E>'0O>&UL.R!C:&%R<V5T/2<@+@H@("`@("`@("`@("`@
M("`@)'1H:7,M/G)E<W!O;G-E7V5N8V]D:6YG.PH@("`@("`@('T*("`@("`@
M("`D=&AI<RT^:&5A9&5R<ULG0V]N=&5N="U,96YG=&@G72`]('-T<FQE;B@D
M<F5S<&]N<V4I.PH*("`@("`@("!F;W)E86-H("@D=&AI<RT^:&5A9&5R<R!A
M<R`D:R`]/B`D=BD@>PH@("`@("`@("`@("!H96%D97(H(B1K.B`D=B(I.PH@
M("`@("`@("`@("`D:&1R<R`N/2`B)&LZ("1V7')<;B(["B`@("`@("`@?0H*
M("`@("`@("`D=&AI<RT^<F5S<&]N<V4@/2`D:&1R<R`N(")<<EQN(B`N("1R
M97-P;VYS93L*("`@("`@("!P<FEN="`D<F5S<&]N<V4["B`@("!]"@H@("`@
M9G5N8W1I;VX@)F-A;&Q-971H;V0H)&UE=&AO9&YA;64L("8D87)G<RD*("`@
M('L*("`@("`@("!I9B`H)'1H:7,M/F-A;&Q(86YD;&5R*2!["B`@("`@("`@
M("`@(')E='5R;B!`8V%L;%]U<V5R7V9U;F-?87)R87DH)'1H:7,M/F-A;&Q(
M86YD;&5R+"!A<G)A>2@D;65T:&]D;F%M92P@)&%R9W,I*3L*("`@("`@("!]
M"@H@("`@("`@('-E=%]E<G)O<E]H86YD;&5R*&%R<F%Y*"1T:&ES+"`G7V5R
M<F]R2&%N9&QE<B<I*3L*"B`@("`@("`@:68@*"1A<F=S*2!["B`@("`@("`@
M("`@("\J($-A;&P@;65T:&]D('=I=&@@<&%R86UE=&5R<RX@*B\*("`@("`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3YS;V%P;V)J96-T*2`F)B!I<U]O8FIE
M8W0H)'1H:7,M/G-O87!O8FIE8W0I*2!["B`@("`@("`@("`@("`@("`D<F5T
M(#T@0&-A;&Q?=7-E<E]F=6YC7V%R<F%Y*&%R<F%Y*"8D=&AI<RT^<V]A<&]B
M:F5C="P@)&UE=&AO9&YA;64I+"`D87)G<RD["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D<F5T(#T@0&-A;&Q?=7-E<E]F=6YC7V%R
M<F%Y*"1M971H;V1N86UE+"`D87)G<RD["B`@("`@("`@("`@('T*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`O*B!#86QL(&UE=&AO9"!W:71H;W5R
M('!A<F%M971E<G,N("HO"B`@("`@("`@("`@(&EF("AI<U]O8FIE8W0H)'1H
M:7,M/G-O87!O8FIE8W0I*2!["B`@("`@("`@("`@("`@("`D<F5T(#T@0&-A
M;&Q?=7-E<E]F=6YC*&%R<F%Y*"8D=&AI<RT^<V]A<&]B:F5C="P@)&UE=&AO
M9&YA;64I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1R970@/2!`8V%L;%]U<V5R7V9U;F,H)&UE=&AO9&YA;64I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R97-T;W)E7V5R<F]R7VAA;F1L
M97(H*3L*"B`@("`@("`@<F5T=7)N("1R970["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#<F5A=&5S(%-/05!?5F%L=64@;V)J96-T('=I=&@@<F5T=7)N('9A
M;'5E<R!F<F]M(&UE=&AO9"X*("`@("`J(%5S97,@;65T:&]D('-I9VYA='5R
M92!T;R!D971E<FUI;F4@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@8G5I
M;&1297-U;'0H)B1M971H;V1?<F5S<&]N<V4L("8D<F5T=7)N7W1Y<&4L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`D<F5T=7)N7VYA;64@/2`G<F5T=7)N
M)RP@)&YA;65S<&%C92`]("<G*0H@("`@>PH@("`@("`@(&EF("AI<U]A*"1M
M971H;V1?<F5S<&]N<V4L("=33T%07U9A;'5E)RDI('L*("`@("`@("`@("`@
M)')E='5R;E]V86P@/2!A<G)A>2@D;65T:&]D7W)E<W!O;G-E*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H:7-?87)R87DH)')E='5R;E]T
M>7!E*2`F)B!I<U]A<G)A>2@D;65T:&]D7W)E<W!O;G-E*2D@>PH@("`@("`@
M("`@("`@("`@)&D@/2`P.PH*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1R
M971U<FY?='EP92!A<R`D:V5Y(#T^("1T>7!E*2!["B`@("`@("`@("`@("`@
M("`@("`@:68@*&ES7VYU;65R:6,H)&ME>2DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&ME>2`]("=I=&5M)SL*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@:68@*&ES7V$H)&UE=&AO9%]R97-P;VYS
M95LD:5TL)W-O87!?=F%L=64G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D<F5T=7)N7W9A;%M=(#T@)&UE=&AO9%]R97-P;VYS95LD:2LK73L*("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D<6X@/28@;F5W(%%.86UE*"1K97DL("1N86UE<W!A8V4I.PH@("`@
M("`@("`@("`@("`@("`@("`@("`D<F5T=7)N7W9A;%M=(#TF(&YE=R!33T%0
M7U9A;'5E*"1Q;BT^9G%N*"DL("1T>7!E+"`D;65T:&]D7W)E<W!O;G-E6R1I
M*RM=*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!I9B`H:7-?
M87)R87DH)')E='5R;E]T>7!E*2D@>PH@("`@("`@("`@("`@("`@("`@("1K
M97ES(#T@87)R87E?:V5Y<R@D<F5T=7)N7W1Y<&4I.PH@("`@("`@("`@("`@
M("`@("`@(&EF("@A:7-?;G5M97)I8R@D:V5Y<ULP72DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)')E='5R;E]N86UE(#T@)&ME>7-;,%T["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1V86QU97,@
M/2!A<G)A>5]V86QU97,H)')E='5R;E]T>7!E*3L*("`@("`@("`@("`@("`@
M("`@("`D<F5T=7)N7W1Y<&4@/2`D=F%L=65S6S!=.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)'%N(#TF(&YE=R!13F%M92@D<F5T=7)N
M7VYA;64L("1N86UE<W!A8V4I.PH@("`@("`@("`@("`@("`@)')E='5R;E]V
M86P@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@)')E='5R;E]V86Q;72`]
M)B!N97<@4T]!4%]686QU92@D<6XM/F9Q;B@I+"`D<F5T=7)N7W1Y<&4L("1M
M971H;V1?<F5S<&]N<V4I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D<F5T=7)N7W9A;#L*("`@('T*"B`@("!F=6YC=&EO;B!P
M87)S95)E<75E<W0H)&1A=&$@/2`G)RP@)&%T=&%C:&UE;G1S(#T@;G5L;"D*
M("`@('L*("`@("`@("`O*B!087)S92!R97-P;VYS92P@9V5T(%-/05!?4&%R
M<V5R(&]B:F5C="X@*B\*("`@("`@("`D<&%R<V5R(#TF(&YE=R!33T%07U!A
M<G-E<B@D9&%T82P@)'1H:7,M/GAM;%]E;F-O9&EN9RP@)&%T=&%C:&UE;G1S
M*3L*("`@("`@("`O*B!)9B!F875L="!O8V-U<G)E9"!D=7)I;F<@;65S<V%G
M92!P87)S:6YG+B`J+PH@("`@("`@(&EF("@D<&%R<V5R+3YF875L="D@>PH@
M("`@("`@("`@("`D=&AI<RT^9F%U;'0@/2`D<&%R<V5R+3YF875L=#L*("`@
M("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H*("`@("`@("`O*B!(
M86YD;&4@;65S<V%G92!H96%D97)S+B`J+PH@("`@("`@("1R97%U97-T7VAE
M861E<G,@/2`D<&%R<V5R+3YG971(96%D97)S*"D["B`@("`@("`@)&AE861E
M<E]R97-U;'1S(#T@87)R87DH*3L*"B`@("`@("`@:68@*"1R97%U97-T7VAE
M861E<G,I('L*("`@("`@("`@("`@:68@*"%I<U]A*"1R97%U97-T7VAE861E
M<G,L("=33T%07U9A;'5E)RDI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<F%I<V53;V%P1F%U;'0H)U!A<G-E<B!D:60@;F]T(')E='5R;B!33T%07U9A
M;'5E(&]B:F5C=#H@)R`N("1R97%U97-T7VAE861E<G,L("<G+"`G)RP@)U-E
M<G9E<B<I.PH@("`@("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@:68@*"1R97%U97-T7VAE861E<G,M/G9A;'5E
M*2!["B`@("`@("`@("`@("`@("`O*B!(86YD;&4@:&5A9&5R<R!N;W<N("HO
M"B`@("`@("`@("`@("`@("!F;W)E86-H("@D<F5Q=65S=%]H96%D97)S+3YV
M86QU92!A<R`D:&5A9&5R7W9A;"D@>PH@("`@("`@("`@("`@("`@("`@("1F
M7V5X:7-T<R`]("1T:&ES+3YV86QI9&%T94UE=&AO9"@D:&5A9&5R7W9A;"T^
M;F%M92P@)&AE861E<E]V86PM/FYA;65S<&%C92D["@H@("`@("`@("`@("`@
M("`@("`@("\J(%1/1$\Z('1H:7,@9&]E<R!N;W0@=&%K92!I;G1O(&%C8V]U
M;G0@;65S<V%G92!R;W5T:6YG"B`@("`@("`@("`@("`@("`@("`@("H@>65T
M+B`J+PH@("`@("`@("`@("`@("`@("`@("1M>6%C=&]R(#T@(21H96%D97)?
M=F%L+3YA8W1O<B!\?`H@("`@("`@("`@("`@("`@("`@("`@("`D:&5A9&5R
M7W9A;"T^86-T;W(@/3T@)VAT='`Z+R]S8VAE;6%S+GAM;'-O87`N;W)G+W-O
M87`O86-T;W(O;F5X="<@?'P*("`@("`@("`@("`@("`@("`@("`@("`@)&AE
M861E<E]V86PM/F%C=&]R(#T]("1T:&ES+3YE;F1P;VEN=#L*"B`@("`@("`@
M("`@("`@("`@("`@:68@*"$D9E]E>&ES=',@)B8@)&AE861E<E]V86PM/FUU
M<W1U;F1E<G-T86YD("8F("1M>6%C=&]R*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)TD@9&]N7"=T('5N9&5R
M<W1A;F0@:&5A9&5R("<@+B`D:&5A9&5R7W9A;"T^;F%M92P@)R<L("<G+"`G
M375S=%5N9&5R<W1A;F0G*3L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N(&YU;&P["B`@("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@("`@("`O*B!792!O;FQY(&AA;F1L92!T:&4@:&5A9&5R(&EF(&ET)W,@
M9F]R('5S+B`J+PH@("`@("`@("`@("`@("`@("`@("1I<V]K(#T@)&9?97AI
M<W1S("8F("1M>6%C=&]R.PH*("`@("`@("`@("`@("`@("`@("!I9B`H)&ES
M;VLI('L*("`@("`@("`@("`@("`@("`@("`@("`@+RH@0V%L;"!O=7(@:&5A
M9&5R(&YO=R$@*B\*("`@("`@("`@("`@("`@("`@("`@("`@)&AE861E<E]M
M971H;V0@/2`D:&5A9&5R7W9A;"T^;F%M93L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&AE861E<E]D871A(#T@87)R87DH)'1H:7,M/E]D96-O9&4H)&AE
M861E<E]V86PI*3L*("`@("`@("`@("`@("`@("`@("`@("`@+RH@268@=&AE
M<F4@87)E('!A<F%M971E<G,@=&\@<&%S<RX@*B\*("`@("`@("`@("`@("`@
M("`@("`@("`@)&AR(#TF("1T:&ES+3YC86QL365T:&]D*"1H96%D97)?;65T
M:&]D+"`D:&5A9&5R7V1A=&$I.PH@("`@("`@("`@("`@("`@("`@("`@("`D
M:&5A9&5R7W)E<W5L='-;72`](&%R<F%Y7W-H:69T*"1T:&ES+3YB=6EL9%)E
M<W5L="@D:'(L("1T:&ES+3YR971U<FY?='EP92P@)&AE861E<E]M971H;V0L
M("1H96%D97)?=F%L+3YN86UE<W!A8V4I*3L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("\J($AA;F1L92!T:&4@;65T:&]D(&-A;&PN("HO"B`@("`@
M("`@+RH@179A;'5A=&4@;65S<V%G92P@9V5T=&EN9R!B86-K(&$@4T]!4%]6
M86QU92!O8FIE8W0N("HO"B`@("`@("`@)'1H:7,M/F-A;&Q?;65T:&]D;F%M
M92`]("1T:&ES+3YM971H;V1N86UE(#T@)'!A<G-E<BT^<F]O=%]S=')U8W1?
M;F%M95LP73L*"B`@("`@("`@+RH@1FEG=7)E(&]U="!T:&4@;65T:&]D(&YA
M;65S<&%C92X@*B\*("`@("`@("`D=&AI<RT^;65T:&]D7VYA;65S<&%C92`]
M("1P87)S97(M/FUE<W-A9V5;)'!A<G-E<BT^<F]O=%]S=')U8W1;,%U=6R=N
M86UE<W!A8V4G73L*"B`@("`@("`@:68@*"1T:&ES+3Y?=W-D;"D@>PH@("`@
M("`@("`@("`D=&AI<RT^7W-E=%-C:&5M859E<G-I;VXH)'1H:7,M/E]W<V1L
M+3YX<V0I.PH@("`@("`@("`@("`D9&%T84AA;F1L97(@/2`D=&AI<RT^7W=S
M9&PM/F=E=$1A=&%(86YD;&5R*"1T:&ES+3YM971H;V1N86UE+"`D=&AI<RT^
M;65T:&]D7VYA;65S<&%C92D["B`@("`@("`@("`@(&EF("@D9&%T84AA;F1L
M97(I"B`@("`@("`@("`@("`@("`D=&AI<RT^8V%L;%]M971H;V1N86UE(#T@
M)'1H:7,M/FUE=&AO9&YA;64@/2`D9&%T84AA;F1L97(["@H@("`@("`@("`@
M("`D=&AI<RT^7W!O<G1.86UE(#T@)'1H:7,M/E]W<V1L+3YG9710;W)T3F%M
M92@D=&AI<RT^;65T:&]D;F%M92D["B`@("`@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1T:&ES+3Y?<&]R=$YA;64I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]R86ES95-O87!&875L="@D=&AI<RT^7W!O<G1.86UE
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D;W!$871A(#T@)'1H:7,M
M/E]W<V1L+3YG971/<&5R871I;VY$871A*"1T:&ES+3Y?<&]R=$YA;64L("1T
M:&ES+3YM971H;V1N86UE*3L*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&]P1&%T82DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7W)A:7-E4V]A<$9A=6QT*"1O<$1A=&$I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;)W-T>6QE)UT@/2`D;W!$871A6R=S
M='EL92==.PH@("`@("`@("`@("`D=&AI<RT^7U]O<'1I;VYS6R=U<V4G72`]
M("1O<$1A=&%;)V]U='!U="==6R=U<V4G73L*("`@("`@("`@("`@)'1H:7,M
M/E]?;W!T:6]N<ULG<&%R86UE=&5R<R==(#T@)&]P1&%T85LG<&%R86UE=&5R
M<R==.PH@("`@("`@('T*"B`@("`@("`@+RH@1&]E<R!M971H;V0@97AI<W0_
M("HO"B`@("`@("`@:68@*"$D=&AI<RT^;65T:&]D;F%M92!\?`H@("`@("`@
M("`@("`A)'1H:7,M/G9A;&ED871E365T:&]D*"1T:&ES+3YM971H;V1N86UE
M+"`D=&AI<RT^;65T:&]D7VYA;65S<&%C92DI('L*("`@("`@("`@("`@)'1H
M:7,M/E]R86ES95-O87!&875L="@G;65T:&]D("(G("X@)'1H:7,M/FUE=&AO
M9%]N86UE<W!A8V4@+B`D=&AI<RT^;65T:&]D;F%M92`N("<B(&YO="!D969I
M;F5D(&EN('-E<G9I8V4G+"`G)RP@)R<L("=397)V97(G*3L*("`@("`@("`@
M("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H*("`@("`@("!I9B`H(21R97%U
M97-T7W9A;"`]("1P87)S97(M/F=E=%)E<W!O;G-E*"DI('L*("`@("`@("`@
M("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-?82@D
M<F5Q=65S=%]V86PL("=33T%07U9A;'5E)RDI('L*("`@("`@("`@("`@)'1H
M:7,M/E]R86ES95-O87!&875L="@G4&%R<V5R(&1I9"!N;W0@<F5T=7)N(%-/
M05!?5F%L=64@;V)J96-T.B`G("X@)')E<75E<W1?=F%L+"`G)RP@)R<L("=3
M97)V97(G*3L*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H*
M("`@("`@("`O*B!697)I9GD@=&AA="!33T%07U9A;'5E(&]B:F5C=',@:6X@
M<F5Q=65S="!M871C:"!T:&4@;65T:&]D<PH@("`@("`@("`J('-I9VYA='5R
M92X@*B\*("`@("`@("!I9B`H(21T:&ES+3YV97)I9GE-971H;V0H)')E<75E
M<W1?=F%L*2D@>PH@("`@("`@("`@("`O*B!V97)I9GE-971H;V0H*2!C<F5A
M=&5S('1H92!F875L="X@*B\*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@
M("`@("`@?0H*("`@("`@("`O*B!.965D('1O('-E="!S<&5C:6%L(&5R<F]R
M(&1E=&5C=&EO;B!I;G-I9&4@=&AE('9A;'5E(&-L87-S('1O"B`@("`@("`@
M("H@9&EF9F5R96YT:6%T92!B971W965N(&YO('!A<F%M<R!P87-S960L(&%N
M9"!A;B!E<G)O<B!D96-O9&EN9RX@*B\*("`@("`@("`D<F5Q=65S=%]D871A
M(#T@)'1H:7,M/E]?9&5C;V1E4F5Q=65S="@D<F5Q=65S=%]V86PI.PH@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1R97%U97-T7V1A=&$I*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"1R97%U97-T
M7V1A=&$I.PH@("`@("`@('T*("`@("`@("`D;65T:&]D7W)E<W!O;G-E(#TF
M("1T:&ES+3YC86QL365T:&]D*"1T:&ES+3YC86QL7VUE=&AO9&YA;64L("1R
M97%U97-T7V1A=&$I.PH*("`@("`@("!I9B`H)'1H:7,M/E]?;W!T:6]N<ULG
M<&%R86UE=&5R<R==('Q\"B`@("`@("`@("`@("$D;65T:&]D7W)E<W!O;G-E
M('Q\"B`@("`@("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;)W-T>6QE)UT]/2=R
M<&,G*2!["B`@("`@("`@("`@("\J($=E="!T:&4@;65T:&]D(')E<W5L="X@
M*B\*("`@("`@("`@("`@:68@*&ES7VYU;&PH)&UE=&AO9%]R97-P;VYS92DI
M('L*("`@("`@("`@("`@("`@("1R971U<FY?=F%L(#T@;G5L;#L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1R971U<FY?=F%L(#T@
M)'1H:7,M/F)U:6QD4F5S=6QT*"1M971H;V1?<F5S<&]N<V4L("1T:&ES+3YR
M971U<FY?='EP92D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1Q;B`]
M)B!N97<@44YA;64H)'1H:7,M/FUE=&AO9&YA;64@+B`G4F5S<&]N<V4G+"`D
M=&AI<RT^;65T:&]D7VYA;65S<&%C92D["B`@("`@("`@("`@("1M971H;V16
M86QU92`])B!N97<@4T]!4%]686QU92@D<6XM/F9Q;B@I+"`G4W1R=6-T)RP@
M)')E='5R;E]V86PI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1M
M971H;V1686QU92`])B`D;65T:&]D7W)E<W!O;G-E.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@)'1H:7,M/E]M86ME16YV96QO<&4H)&UE=&AO9%9A;'5E
M+"`D:&5A9&5R7W)E<W5L=',L("1T:&ES+3YR97-P;VYS95]E;F-O9&EN9RD[
M"B`@("!]"@H@("`@9G5N8W1I;VX@)E]?9&5C;V1E4F5Q=65S="@D<F5Q=65S
M="P@)'-H:69T(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"$D<F5Q=65S
M="D@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"@H@("`@
M("`@("\J($-H96-K(&9O<B!V86QI9"!R97-P;VYS92X@*B\*("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D<F5Q=65S="DI('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)')E<75E<W0I.PH@("`@("`@
M('T@96QS92!I9B`H(6ES7V$H)')E<75E<W0L("=33T%07U9A;'5E)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)TEN
M=F%L:60@9&%T82!I;B!S97)V97(Z.E]?9&5C;V1E4F5Q=65S="<I.PH@("`@
M("`@('T*"B`@("`@("`@+RH@1&5C;V1E('1O(&YA=&EV92!P:'`@9&%T871Y
M<&4N("HO"B`@("`@("`@)')E<75E<W1!<G)A>2`]("1T:&ES+3Y?9&5C;V1E
M*"1R97%U97-T*3L*("`@("`@("`O*B!&875L=#\@*B\*("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D<F5Q=65S=$%R<F%Y*2D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]R86ES95-O87!&875L="@D<F5Q=65S=$%R<F%Y*3L*
M("`@("`@("!]"B`@("`@("`@:68@*&ES7V]B:F5C="@D<F5Q=65S=$%R<F%Y
M*2`F)@H@("`@("`@("`@("!G971?8VQA<W,H)')E<75E<W1!<G)A>2D@/3T@
M)W-T9$-L87-S)RD@>PH@("`@("`@("`@("`D<F5Q=65S=$%R<F%Y(#T@9V5T
M7V]B:F5C=%]V87)S*"1R97%U97-T07)R87DI.PH@("`@("`@('T@96QS96EF
M("@D=&AI<RT^7U]O<'1I;VYS6R=S='EL92==(#T]("=D;V-U;65N="<I('L*
M("`@("`@("`@("`@)')E<75E<W1!<G)A>2`](&%R<F%Y*"1R97%U97-T07)R
M87DI.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?87)R87DH)')E<75E<W1!
M<G)A>2DI('L*("`@("`@("`@("`@:68@*&ES<V5T*"1R97%U97-T07)R87E;
M)V9A=6QT8V]D92==*2!\?`H@("`@("`@("`@("`@("`@:7-S970H)')E<75E
M<W1!<G)A>5LG4T]!4"U%3E8Z9F%U;'1C;V1E)UTI*2!["B`@("`@("`@("`@
M("`@("`D9F%U;'1C;V1E(#T@)&9A=6QT<W1R:6YG(#T@)&9A=6QT9&5T86EL
M(#T@)&9A=6QT86-T;W(@/2`G)SL*("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1R97%U97-T07)R87D@87,@)&L@/3X@)'8I('L*("`@("`@("`@("`@("`@
M("`@("!I9B`H<W1R:7-T<B@D:RP@)V9A=6QT8V]D92<I*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1F875L=&-O9&4@/2`D=CL*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@:68@*'-T<FES='(H)&LL
M("=F875L='-T<FEN9R<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1F
M875L='-T<FEN9R`]("1V.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("!I9B`H<W1R:7-T<B@D:RP@)V1E=&%I;"<I*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1F875L=&1E=&%I;"`]("1V.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H<W1R
M:7-T<B@D:RP@)V9A=6QT86-T;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D9F%U;'1A8W1O<B`]("1V.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7W)A:7-E4V]A<$9A=6QT*"1F875L='-T<FEN9RP@)&9A=6QT9&5T86EL
M+"`D9F%U;'1A8W1O<BP@)&9A=6QT8V]D92D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@+RH@4F5T=7)N(&%R<F%Y(&]F(')E='5R;B!V86QU97,N("HO
M"B`@("`@("`@("`@(&EF("@D<VAI9G0@)B8@8V]U;G0H)')E<75E<W1!<G)A
M>2D@/3T@,2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y7W-H:69T
M*"1R97%U97-T07)R87DI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E
M='5R;B`D<F5Q=65S=$%R<F%Y.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M)')E<75E<W1!<G)A>3L*("`@('T*"B`@("!F=6YC=&EO;B!V97)I9GE-971H
M;V0H)')E<75E<W0I"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^8V%L;%9A
M;&ED871I;VXI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@
M?0H*("`@("`@("`D<&%R86US(#T@)')E<75E<W0M/G9A;'5E.PH*("`@("`@
M("`O*B!'970@=&AE(&1I<W!A=&-H(&UA<"!I9B!O;F4@97AI<W1S+B`J+PH@
M("`@("`@("1M87`@/2!N=6QL.PH@("`@("`@(&EF("AA<G)A>5]K97E?97AI
M<W1S*"1T:&ES+3YM971H;V1N86UE+"`D=&AI<RT^9&ES<&%T8VA?;6%P*2D@
M>PH@("`@("`@("`@("`D;6%P(#T@)'1H:7,M/F1I<W!A=&-H7VUA<%LD=&AI
M<RT^;65T:&]D;F%M95T["B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES
M+3YS;V%P;V)J96-T*2D@>PH@("`@("`@("`@("!I9B`H;65T:&]D7V5X:7-T
M<R@D=&AI<RT^<V]A<&]B:F5C="P@)U]?9&ES<&%T8V@G*2D@>PH@("`@("`@
M("`@("`@("`@)&UA<"`]("1T:&ES+3YS;V%P;V)J96-T+3Y?7V1I<W!A=&-H
M*"1T:&ES+3YM971H;V1N86UE*3L*("`@("`@("`@("`@?2!E;'-E:68@*&UE
M=&AO9%]E>&ES=',H)'1H:7,M/G-O87!O8FIE8W0L("1T:&ES+3YM971H;V1N
M86UE*2D@>PH@("`@("`@("`@("`@("`@+RH@3F\@;6%P+"!A;&P@<'5B;&EC
M(&9U;F-T:6]N<R!A<F4@4T]!4"!F=6YC=&EO;G,N("HO"B`@("`@("`@("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M("`@("!I9B`H(21M87`I('L*("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O
M87!&875L="@G4T]!4"!R97%U97-T('-P96-I9FEE9"!A;B!U;FAA;F1L960@
M;65T:&]D("(G("X@)'1H:7,M/FUE=&AO9&YA;64@+B`G(B<L("<G+"`G)RP@
M)T-L:65N="<I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("`O*B!)9B!W92!A;&EA<V5D('1H92!33T%0(&UE=&AO9"!N
M86UE('1O(&$@4$A0(&9U;F-T:6]N+"!C:&%N9V4*("`@("`@("`@*B!C86QL
M7VUE=&AO9&YA;64@<V\@=V4@9&\@=&AE(')I9VAT('1H:6YG+B`J+PH@("`@
M("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"=A;&EA<R<L("1M87`I("8F("%E
M;7!T>2@D;6%P6R=A;&EA<R==*2D@>PH@("`@("`@("`@("`D=&AI<RT^8V%L
M;%]M971H;V1N86UE(#T@)&UA<%LG86QI87,G73L*("`@("`@("!]"@H@("`@
M("`@("\J($EF('1H97)E(&%R92!I;G!U="!P87)A;65T97)S(')E<75I<F5D
M+B`J+PH@("`@("`@(&EF("@D<VEG(#T@)&UA<%LG:6XG72D@>PH@("`@("`@
M("`@("`D=&AI<RT^:6YP=71?=F%L=64@/2!C;W5N="@D<VEG*3L*("`@("`@
M("`@("`@)'1H:7,M/G)E='5R;E]T>7!E(#T@:7-?87)R87DH)&UA<%LG;W5T
M)UTI(#\@)&UA<%LG;W5T)UT@.B!F86QS93L*("`@("`@("`@("`@:68@*&ES
M7V%R<F%Y*"1P87)A;7,I*2!["B`@("`@("`@("`@("`@("`O*B!686QI9&%T
M92!T:&4@;G5M8F5R(&]F('!A<F%M971E<G,N("HO"B`@("`@("`@("`@("`@
M("!I9B`H8V]U;G0H)'!A<F%M<RD@/3T@8V]U;G0H)'-I9RDI('L*("`@("`@
M("`@("`@("`@("`@("`O*B!-86ME(&%R<F%Y(&]F('!A<F%M('1Y<&5S+B`J
M+PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)'!A
M<F%M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1P6UT@/2!S=')T;VQO
M=V5R*"1P87)A;2T^='EP92D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("1S:6=?="`](&%R<F%Y7W9A;'5E<R@D<VEG*3L*
M("`@("`@("`@("`@("`@("`@("`O*B!686QI9&%T92!E86-H('!A<F%M)W,@
M='EP92X@*B\*("`@("`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@
M/"!C;W5N="@D<"D[("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M+RH@268@4T]!4"!T>7!E<R!D;R!N;W0@;6%T8V@L(&ET)W,@<W1I;&P@9FEN
M92!I9B!T:&4*("`@("`@("`@("`@("`@("`@("`@("`@("H@;6%P<&5D('!H
M<"!T>7!E<R!M871C:"!T:&ES(&%L;&]W<R!U<VEN9R!P;&%I;B!02%`*("`@
M("`@("`@("`@("`@("`@("`@("`@("H@=F%R:6%B;&5S('1O('=O<FL@*&DN
M92X@<W1U9F8@;&EK92!$96-I;6%L('=O=6QD"B`@("`@("`@("`@("`@("`@
M("`@("`@("`J(&9A:6P@;W1H97)W:7-E*2X@5V4@8V]N<VED97(@=&AI<R!O
M;FQY(&5R<F]R(&EF('1H90H@("`@("`@("`@("`@("`@("`@("`@("`@*B!T
M>7!E<R!E>&ES="!I;B!O=7(@='EP92!M87!S+"!A;F0@=&AE>2!D:69F97(N
M("HO"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AS=')C87-E8VUP*"1S
M:6=?=%LD:5TL("1P6R1I72D@(3T@,"`F)@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:7-S970H)'1H:7,M/E]T>7!E;6%P6U-/05!?6$U,7U-#2$5-
M05]615)324].75LD<VEG7W1;)&E=72D@)B8*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('-T<F-A<V5C;7`H)'1H:7,M/E]T>7!E;6%P6U-/05!?6$U,
M7U-#2$5-05]615)324].75LD<VEG7W1;)&E=72P@)'1H:7,M/E]T>7!E;6%P
M6U-/05!?6$U,7U-#2$5-05]615)324].75LD<%LD:5U=*2`A/2`P*2!["@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M(#T@)'!A<F%M<ULD
M:5T["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)A:7-E
M4V]A<$9A=6QT*")33T%0(')E<75E<W0@8V]N=&%I;F5D(&UI<VUA=&-H:6YG
M('!A<F%M971E<G,@;V8@;F%M92`D<&%R86TM/FYA;64@:&%D('1Y<&4@6WLD
M<%LD:5U]72P@=VAI8V@@9&ED(&YO="!M871C:"!S:6=N871U<F4G<R!T>7!E
M.B!;>R1S:6=?=%LD:5U]72P@;6%T8VAE9#\@(B`N("AS=')C87-E8VUP*"1S
M:6=?=%LD:5TL("1P6R1I72DI+"`G)RP@)R<L("=#;&EE;G0G*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@+RH@5W)O;F<@;G5M8F5R(&]F
M('!A<F%M<RX@*B\*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)A:7-E
M4V]A<$9A=6QT*"=33T%0(')E<75E<W0@8V]N=&%I;F5D(&EN8V]R<F5C="!N
M=6UB97(@;V8@<&%R86UE=&5R<RX@;65T:&]D("(G("X@)'1H:7,M/FUE=&AO
M9&YA;64@+B`G(B!R97%U:7)E9"`G("X@8V]U;G0H)'-I9RD@+B`G(&%N9"!R
M97%U97-T('!R;W9I9&5D("<@+B!C;W5N="@D<&%R86US*2P@)R<L("<G+"`G
M0VQI96YT)RD["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@+RH@3F\@<&%R86US+B`J+PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]R86ES95-O87!&875L="@G4T]!4"!R97%U97-T(&-O;G1A:6YE9"!I
M;F-O<G)E8W0@;G5M8F5R(&]F('!A<F%M971E<G,N(&UE=&AO9"`B)R`N("1T
M:&ES+3YM971H;V1N86UE("X@)R(@<F5Q=6ER97,@)R`N(&-O=6YT*"1S:6<I
M("X@)R!P87)A;65T97)S+"!A;F0@<F5Q=65S="!P<F]V:61E9"!N;VYE+B<L
M("<G+"`G)RP@)T-L:65N="<I.PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!792=L
M;"!T<GD@:70@86YY=V%Y+B`J+PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@(&9U;F-T:6]N('9A;&ED871E365T:&]D*"1M971H;V1N86UE+"`D
M;F%M97-P86-E(#T@;G5L;"D*("`@('L*("`@("`@("!U;G-E="@D=&AI<RT^
M<V]A<&]B:F5C="D["@H@("`@("`@(&EF("@A)'1H:7,M/F-A;&Q686QI9&%T
M:6]N*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@
M("`@("`@+RH@3F\@4T]!4"!A8V-E<W,@=&\@<')I=F%T92!F=6YC=&EO;G,N
M("HO"B`@("`@("`@:68@*"1M971H;V1N86UE6S!=(#T]("=?)RD@>PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O*B!I
M9B!I="=S(&EN(&]U<B!F=6YC=&EO;B!L:7-T+"!O:R`J+PH@("`@("`@(&EF
M("AA<G)A>5]K97E?97AI<W1S*"1M971H;V1N86UE+"`D=&AI<RT^9&ES<&%T
M8VA?;6%P*2`F)@H@("`@("`@("`@("`H(21N86UE<W!A8V4@?'P*("`@("`@
M("`@("`@("%A<G)A>5]K97E?97AI<W1S*"=N86UE<W!A8V4G+"`D=&AI<RT^
M9&ES<&%T8VA?;6%P6R1M971H;V1N86UE72D@?'P*("`@("`@("`@("`@("1N
M86UE<W!A8V4@/3T@)'1H:7,M/F1I<W!A=&-H7VUA<%LD;65T:&]D;F%M95U;
M)VYA;65S<&%C92==*2D@>PH@("`@("`@("`@("!I9B`H87)R87E?:V5Y7V5X
M:7-T<R@G;F%M97-P86-E)RP@)'1H:7,M/F1I<W!A=&-H7VUA<%LD;65T:&]D
M;F%M95TI*0H@("`@("`@("`@("`@("`@)'1H:7,M/FUE=&AO9%]N86UE<W!A
M8V4@/2`D=&AI<RT^9&ES<&%T8VA?;6%P6R1M971H;V1N86UE75LG;F%M97-P
M86-E)UT["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@
M("`@("`@+RH@:68@:70G<R!I;B!A;B!O8FIE8W0L(&ET)W,@;VL@*B\*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/F1I<W!A=&-H7V]B:F5C='-;)&YA;65S
M<&%C95TI*2!["B`@("`@("`@("`@("1C(#T@8V]U;G0H)'1H:7,M/F1I<W!A
M=&-H7V]B:F5C='-;)&YA;65S<&%C95TI.PH@("`@("`@("`@("!F;W(@*"1I
M(#T@,#L@)&D@/"`D8SL@)&DK*RD@>PH@("`@("`@("`@("`@("`@)&]B:B`]
M)B`D=&AI<RT^9&ES<&%T8VA?;V)J96-T<ULD;F%M97-P86-E75LD:5T["B`@
M("`@("`@("`@("`@("`O*B!)9B!W92!H879E(&$@9&ES<&%T8V@@;6%P+"!A
M;F0@=&AE(&9U;F-T:6]N(&ES(&YO="!I;B!T:&4*("`@("`@("`@("`@("`@
M("`J(&1I<W!A=&-H(&UA<"P@=&AE;B!I="!I<R!N;W0@8V%L;&%B;&4A("HO
M"B`@("`@("`@("`@("`@("!I9B`H;65T:&]D7V5X:7-T<R@D;V)J+"`G7U]D
M:7-P871C:"<I*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1O8FHM/E]?
M9&ES<&%T8V@H)&UE=&AO9&YA;64I*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YM971H;V1?;F%M97-P86-E(#T@)&YA;65S<&%C93L*("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-O87!O8FIE8W0@/28@)&]B
M:CL*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E:68@*&UE
M=&AO9%]E>&ES=',H)&]B:BP@)&UE=&AO9&YA;64I*2!["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/FUE=&AO9%]N86UE<W!A8V4@/2`D;F%M97-P86-E
M.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS;V%P;V)J96-T(#TF("1O
M8FH["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!F86QS93L*("`@('T*"B`@("!F=6YC=&EO;B!A9&1/8FIE8W1-87`H
M)B1O8FHL("1N86UE<W!A8V4@/2!N=6QL+"`D<V5R=FEC95]N86UE(#T@)T1E
M9F%U;'0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("1S97)V:6-E7V1E
M<V,@/2`G)RD*("`@('L*("`@("`@("!I9B`H(21N86UE<W!A8V4I('L*("`@
M("`@("`@("`@:68@*&ES<V5T*"1O8FHM/FYA;65S<&%C92DI('L*("`@("`@
M("`@("`@("`@("\O(%A86"!A(&)I="!O9B!B86-K=V%R9',@8V]M<&%T:6)I
M;&ET>0H@("`@("`@("`@("`@("`@)&YA;65S<&%C92`]("1O8FHM/FYA;65S
M<&%C93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<F%I<V53;V%P1F%U;'0H)TYO(&YA;65S<&%C92!P<F]V:61E9"!F
M;W(@8VQA<W,A)RP@)R<L("<G+"`G4V5R=F5R)RD["B`@("`@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^9&ES<&%T8VA?;V)J96-T<ULD;F%M97-P
M86-E72DI('L*("`@("`@("`@("`@)'1H:7,M/F1I<W!A=&-H7V]B:F5C='-;
M)&YA;65S<&%C95T@/2!A<G)A>2@I.PH@("`@("`@('T*("`@("`@("`D=&AI
M<RT^9&ES<&%T8VA?;V)J96-T<ULD;F%M97-P86-E75M=(#TF("1O8FH["@H@
M("`@("`@("\O($-R96%T92!I;G1E<FYA;"!74T1,('-T<G5C='5R97,@9F]R
M(&]B:F5C=`H*("`@("`@("`O+R!86%@@0F5C875S92!S;VUE(&EN=&5R;F%L
M('=O<FMI;F=S(&]F(%!%05(Z.E-/05`@9&5C:61E('=H971H97(@=&\*("`@
M("`@("`O+R!D;R!C97)T86EN('1H:6YG<R!B>2!T:&4@<')E<V5N8V4@;W(@
M86)S96YC92!O9B!?=W-D;"P@=V4@<VAO=6QD"B`@("`@("`@+R\@;VYL>2!C
M<F5A=&4@82!?=W-D;"!S=')U8W1U<F4@:68@=V4@:VYO=R!W92!C86X@9FEL
M;"!I=#L@:68*("`@("`@("`O+R!?7V1I<W!A=&-H7VUA<"!O<B!?7W1Y<&5D
M968@9F]R('1H92!O8FIE8W0@:7,@;6ES<VEN9RP@=V4@<VAO=6QD"B`@("`@
M("`@+R\@879O:60@8W)E871I;F<@:70N($QA=&5R+"!W:&5N('=E(&%R92!U
M<VEN9R!02%`@-2!I;G1R;W-P96-T:6]N+"!W90H@("`@("`@("\O('=I;&P@
M8F4@86)L92!T;R!M86ME('1H92!D871A(&9O<B!A;&P@;V)J96-T<R!W:71H
M;W5T(&%N>2!E>'1R80H@("`@("`@("\O(&EN9F]R;6%T:6]N(&9R;VT@=&AE
M(&1E=F5L;W!E<G,L(&%N9"!T:&ES(&-O;F1I=&EO;B!S:&]U;&0@8F4*("`@
M("`@("`O+R!D<F]P<&5D+@H*("`@("`@("`O+R!86%@@2VYO=VX@:7-S=64Z
M(&EF(&EM<&]R=&5D(%=31$P@*&)I;F174T1,*2!O<B!A;F]T:&5R(%=31$P@
M<V]U<F-E"B`@("`@("`@+R\@:7,@=7-E9"!T;R!A9&0@7W=S9&P@<W1R=6-T
M=7)E(&EN9F]R;6%T:6]N+"!T:&5N(&%D9$]B:F5C=%=31$P@:7,*("`@("`@
M("`O+R!U<V5D+"!T:&5R92!I<R!A(&AI9V@@<&]S<VEB:6QI='D@;V8@7W=S
M9&P@9&%T82!C;W)R=7!T:6]N.PH@("`@("`@("\O('1H97)E9F]R92!Y;W4@
M<VAO=6QD(&%V;VED('5S:6YG(%]?9&ES<&%T8VA?;6%P+U]?='EP961E9@H@
M("`@("`@("\O(&1E9FEN:71I;VYS($%.1"!O=&AE<B!74T1,(&1A=&$@<V]U
M<F-E<R!I;B!T:&4@<V%M92!S97)V:6-E+B!790H@("`@("`@("\O(&5X8VQU
M9&4@8VQA<W-E<R!T:&%T(&1O;B=T(&AA=F4@7U]T>7!E9&5F<R!T;R!A;&QO
M=R!E>'1E<FYA;"!74T1,"B`@("`@("`@+R\@9FEL97,@=&\@8F4@=7-E9"!W
M:71H(&-L87-S97,@=VET:"!N;R!I;G1E<FYA;"!T>7!E(&1E9FEN:71I;VYS
M"B`@("`@("`@+R\@*'1H92!T>7!E<R!A<F4@9&5F:6YE9"!I;B!T:&4@5U-$
M3"!F:6QE*2X@5VAE;B!A9&1/8FIE8W174T1,(&ES"B`@("`@("`@+R\@<F5F
M86-T;W)E9"!T;R!N;W0@8V%U<V4@8V]R<G5P=&EO;BP@=&AI<R!R97-T<FEC
M=&EO;B!C86X@8F4*("`@("`@("`O+R!R96QA>&5D+@H*("`@("`@("`O+R!)
M;B!S=6UM87)Y+"!I9B!Y;W4@861D(&%N(&]B:F5C="!W:71H(&)O=&@@82!D
M:7-P871C:"!M87`@86YD('1Y<&4*("`@("`@("`O+R!D969I;FET:6]N<RP@
M=&AE;B!P<F5V:6]U<R!74T1,(&9I;&4@;W!E<F%T:6]N(&%N9"!T>7!E(&1E
M9FEN:71I;VYS"B`@("`@("`@+R\@=VEL;"!B92!O=F5R=W)I='1E;BX*("`@
M("`@("!I9B`H:7-S970H)&]B:BT^7U]D:7-P871C:%]M87`I("8F(&ES<V5T
M*"1O8FHM/E]?='EP961E9BDI('L*("`@("`@("`@("`@)'1H:7,M/F%D9$]B
M:F5C=%=31$PH)&]B:BP@)&YA;65S<&%C92P@)'-E<G9I8V5?;F%M92P@)'-E
M<G9I8V5?9&5S8RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"B`@("`O*BH*("`@("`J($%D9',@82!M971H;V0@=&\@=&AE(&1I
M<W!A=&-H(&UA<"X*("`@("`J+PH@("`@9G5N8W1I;VX@861D5&]-87`H)&UE
M=&AO9&YA;64L("1I;BP@)&]U="P@)&YA;65S<&%C92`](&YU;&PL("1A;&EA
M<R`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"%F=6YC=&EO;E]E>&ES=',H
M)&UE=&AO9&YA;64I*2!["B`@("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P
M1F%U;'0H)T5R<F]R(&UA<'!I;F<@9G5N8W1I;VXG+"`G)RP@)R<L("=397)V
M97(G*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@)'1H:7,M/F1I<W!A=&-H7VUA<%LD;65T:&]D;F%M95U;)VEN)UT@
M/2`D:6X["B`@("`@("`@)'1H:7,M/F1I<W!A=&-H7VUA<%LD;65T:&]D;F%M
M95U;)V]U="==(#T@)&]U=#L*("`@("`@("`D=&AI<RT^9&ES<&%T8VA?;6%P
M6R1M971H;V1N86UE75LG86QI87,G72`]("1A;&EA<SL*("`@("`@("!I9B`H
M)&YA;65S<&%C92D@>PH@("`@("`@("`@("`D=&AI<RT^9&ES<&%T8VA?;6%P
M6R1M971H;V1N86UE75LG;F%M97-P86-E)UT@/2`D;F%M97-P86-E.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@9G5N8W1I
M;VX@<V5T0V%L;$AA;F1L97(H)&-A;&Q(86YD;&5R+"`D=F%L:61A=&EO;B`]
M('1R=64I"B`@("!["B`@("`@("`@)'1H:7,M/F-A;&Q(86YD;&5R(#T@)&-A
M;&Q(86YD;&5R.PH@("`@("`@("1T:&ES+3YC86QL5F%L:61A=&EO;B`]("1V
M86QI9&%T:6]N.PH@("`@?0H*("`@("\J*@H@("`@("H@0&1E<')E8V%T960@
M=7-E(&)I;F174T1,(&9R;VT@;F]W(&]N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&)I;F0H)'=S9&Q?=7)L*0H@("`@>PH@("`@("`@("1T:&ES+3YB:6YD5U-$
M3"@D=W-D;%]U<FPI.PH@("`@?0H*("`@("\J*@H@("`@("H@0'!A<F%M("!S
M=')I;F<@82!U<FP@=&\@82!74T1,(')E<V]U<F-E"B`@("`@*B!`<F5T=7)N
M('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@8FEN9%=31$PH)'=S9&Q?=7)L
M*0H@("`@>PH@("`@("`@("\J($EN<W1A;G1I871E(%=31$P@8VQA<W,N("HO
M"B`@("`@("`@)'1H:7,M/E]W<V1L(#TF(&YE=R!33T%07U=31$PH)'=S9&Q?
M=7)L*3L*("`@("`@("!I9B`H)'1H:7,M/E]W<V1L+3YF875L="D@>PH@("`@
M("`@("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"1T:&ES+3Y?=W-D;"T^
M9F%U;'0I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($!R971U
M<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1/8FIE8W174T1,*"8D
M=W-D;%]O8FHL("1T87)G971.86UE<W!A8V4L("1S97)V:6-E7VYA;64L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1S97)V:6-E7V1E<V,@/2`G)RD*
M("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?=W-D;"DI('L*("`@
M("`@("`@("`@)'1H:7,M/E]W<V1L(#TF(&YE=R!33T%07U=31$P["B`@("`@
M("`@?0H*("`@("`@("`D=&AI<RT^7W=S9&PM/G!A<G-E3V)J96-T*"1W<V1L
M7V]B:BP@)'1A<F=E=$YA;65S<&%C92P@)'-E<G9I8V5?;F%M92P@)'-E<G9I
M8V5?9&5S8RD["@H@("`@("`@(&EF("@D=&AI<RT^7W=S9&PM/F9A=6QT*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)'1H:7,M/E]W
M<V1L+3YF875L="D["B`@("`@("`@?0H@("`@?0I]"@``````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+U-/05`O5')A;G-P;W)T+G!H<```````````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#0U,S`@,3`U,34T,S,W,S$@,#(Q-S,U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B!4:&ES(&9I;&4@8V]N=&%I;G,@=&AE(&-O9&4@9F]R(&%N(&%B
M<W1R86-T('1R86YS<&]R="!L87EE<BX*("H*("H@4$A0('9E<G-I;VYS(#0@
M86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J
M96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L"B`J('1H
M870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,
M24-%3E-%+"!A;F0@:7,@879A:6QA8FQE(&%T"B`J('1H<F]U9V@@=&AE('=O
M<FQD+7=I9&4M=V5B(&%T(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?
M,#(N='AT+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@
M=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I=`H@
M*B!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N
M;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X*("H@;6%I;"!Y;W4@
M82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!796(@4V5R
M=FEC97,*("H@0'!A8VMA9V4@("`@4T]!4`H@*B!`875T:&]R("`@("!$:65T
M<FEC:"!!>6%L82`\9&EE=')I8VA`9V%N>#0N8V]M/@H@*B!`875T:&]R("`@
M("!3:&%N92!#87)A=F5O(#Q3:&%N94!#87)A=F5O+F-O;3X*("H@0&-O<'ER
M:6=H="`@,C`P,RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0@(%!(4"!,:6-E
M;G-E(#(N,#(*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P
M86-K86=E+U-/05`*("HO"@IR97%U:7)E7V]N8V4@)U-/05`O0F%S92YP:'`G
M.PH*+RHJ"B`J(%-/05`@5')A;G-P;W)T($QA>65R"B`J"B`J(%1H:7,@;&%Y
M97(@8V%N('5S92!D:69F97)E;G0@<')O=&]C;VQS(&1E<&5N9&%N="!O;B!T
M:&4@96YD<&]I;G0@=7)L('!R;W9I9&5D"B`J(&YO(&MN;W=L96=E(&]F('1H
M92!33T%0('!R;W1O8V]L(&ES(&%V86EL86)L92!A="!T:&ES(&QE=F5L"B`J
M(&YO(&MN;W=L96=E(&]F('1H92!T<F%N<W!O<G0@<')O=&]C;VQS(&ES(&%V
M86EL86)L92!A="!T:&ES(&QE=F5L"B`J"B`J($!A8V-E<W,@("!P=6)L:6,*
M("H@0'!A8VMA9V4@(%-/05`*("H@0&%U=&AO<B`@(%-H86YE($-A<F%V96\@
M/'-H86YE0'!H<"YN970^"B`J+PIC;&%S<R!33T%07U1R86YS<&]R=`I["B`@
M("!F=6YC=&EO;B`F9V5T5')A;G-P;W)T*"1U<FPL("1E;F-O9&EN9R`](%-/
M05!?1$5&055,5%]%3D-/1$E.1RD*("`@('L*("`@("`@("`D=7)L<&%R=',@
M/2!`<&%R<V5?=7)L*"1U<FPI.PH*("`@("`@("!I9B`H(21U<FQP87)T<ULG
M<V-H96UE)UTI('L*("`@("`@("`@("`@<F5T=7)N(%-/05!?0F%S95]/8FIE
M8W0Z.E]R86ES95-O87!&875L="@B26YV86QI9"!T<F%N<W!O<G0@55)).B`D
M=7)L(BD["B`@("`@("`@?0H*("`@("`@("!I9B`H<W1R8V%S96-M<"@D=7)L
M<&%R='-;)W-C:&5M92==+"`G;6%I;'1O)RD@/3T@,"D@>PH@("`@("`@("`@
M("`D=')A;G-P;W)T7W1Y<&4@/2`G4TU44"<["B`@("`@("`@?2!E;'-E:68@
M*'-T<F-A<V5C;7`H)'5R;'!A<G1S6R=S8VAE;64G72P@)VAT='!S)RD@/3T@
M,"D@>PH@("`@("`@("`@("`D=')A;G-P;W)T7W1Y<&4@/2`G2%144"<["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@:&%N9&QE(&]T:&5R('1R
M86YS<&]R="!T>7!E<R`J+PH@("`@("`@("`@("`D=')A;G-P;W)T7W1Y<&4@
M/2!S=')T;W5P<&5R*"1U<FQP87)T<ULG<V-H96UE)UTI.PH@("`@("`@('T*
M("`@("`@("`D=')A;G-P;W)T7VEN8VQU9&4@/2`G4T]!4"]4<F%N<W!O<G0O
M)R`N("1T<F%N<W!O<G1?='EP92`N("<N<&AP)SL*("`@("`@("`D<F5S(#T@
M0&EN8VQU9&5?;VYC92@D=')A;G-P;W)T7VEN8VQU9&4I.PH@("`@("`@(&EF
M("@A)')E<R`F)B`A:6Y?87)R87DH)'1R86YS<&]R=%]I;F-L=61E+"!G971?
M:6YC;'5D961?9FEL97,H*2DI('L*("`@("`@("`@("`@<F5T=7)N(%-/05!?
M0F%S95]/8FIE8W0Z.E]R86ES95-O87!&875L="@B3F\@5')A;G-P;W)T(&9O
M<B![)'5R;'!A<G1S6R=S8VAE;64G77TB*3L*("`@("`@("!]"B`@("`@("`@
M)'1R86YS<&]R=%]C;&%S<R`](")33T%07U1R86YS<&]R=%\D=')A;G-P;W)T
M7W1Y<&4B.PH@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"1T<F%N<W!O<G1?
M8VQA<W,I*2!["B`@("`@("`@("`@(')E='5R;B!33T%07T)A<V5?3V)J96-T
M.CI?<F%I<V53;V%P1F%U;'0H(DYO(%1R86YS<&]R="!C;&%S<R`D=')A;G-P
M;W)T7V-L87-S(BD["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D="`])B!N
M97<@)'1R86YS<&]R=%]C;&%S<R@D=7)L+"`D96YC;V1I;F<I.PH@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+U-/05`O5F%L=64N<&AP````````````````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,34Q-C`@,3`U,34T,S,W
M,S$@,#(Q,#$V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!4:&ES(&9I;&4@8V]N=&%I;G,@=&AE(&-O
M9&4@9F]R(&-O;G9E<G1I;F<@=F%L=65S(&)E='=E96X@4T]!4"!A;F0@4$A0
M+@H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4
M:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F
M('1H92!02%`@;&EC96YS92P*("H@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI
M<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R!A=F%I;&%B
M;&4@870*("H@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R
M92!U;F%B;&4@=&\@;V)T86EN(&ET"B`J('1H<F]U9V@@=&AE('=O<FQD+7=I
M9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T
M('-O('=E(&-A;@H@*B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J
M"B`J($!C871E9V]R>2`@(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G92`@("!3
M3T%0"B`J($!A=71H;W(@("`@($1I971R:6-H($%Y86QA(#QD:65T<FEC:$!G
M86YX-"YC;VT^($]R:6=I;F%L($%U=&AO<@H@*B!`875T:&]R("`@("!3:&%N
M92!#87)A=F5O(#Q3:&%N94!#87)A=F5O+F-O;3X@("!0;W)T('1O(%!%05(@
M86YD(&UO<F4*("H@0&%U=&AO<B`@("`@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^("`@36%I;G1E;F%N8V4*("H@0&%U=&AO<B`@("`@2F%N
M(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX@("`@("`@36%I;G1E;F%N8V4*
M("H@0&-O<'ER:6=H="`@,C`P,RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI
M8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0@
M(%!(4"!,:6-E;G-E(#(N,#(*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N
M<&AP+FYE="]P86-K86=E+U-/05`*("HO"@IR97%U:7)E7V]N8V4@)U-/05`O
M0F%S92YP:'`G.PH*+RHJ"B`J(%-/05`Z.E9A;'5E"B`J"B`J(%1H:7,@8VQA
M<W,@8V]N=F5R=',@=F%L=65S(&)E='=E96X@4$A0(&%N9"!33T%0+@H@*@H@
M*B!/<FEG:6YA;&QY(&)A<V5D(&]N(%-/05!X-"!B>2!$:65T<FEC:"!!>6%L
M80H@*B!H='1P.B\O9&EE=')I8V@N9V%N>#0N8V]M+W-O87!X-`H@*@H@*B!`
M86-C97-S('!U8FQI8PH@*B!`<&%C:V%G92!33T%0"B`J($!A=71H;W(@4VAA
M;F4@0V%R879E;R`\<VAA;F5`<&AP+FYE=#X@0V]N=F5R<VEO;B!T;R!014%2
M(&%N9"!U<&1A=&5S"B`J($!A=71H;W(@1&EE=')I8V@@07EA;&$@/&1I971R
M:6-H0&=A;G@T+F-O;3X@3W)I9VEN86P@075T:&]R"B`J+PIC;&%S<R!33T%0
M7U9A;'5E"GL*("`@("\J*@H@("`@("H*("`@("`J"B`@("`@*B!`=F%R("!S
M=')I;F<*("`@("`J+PH@("`@=F%R("1V86QU92`](&YU;&P["@H@("`@+RHJ
M"B`@("`@*@H@("`@("H@0'9A<B`@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D
M;F%M92`]("<G.PH*("`@("\J*@H@("`@("H*("`@("`J($!V87(@('-T<FEN
M9PH@("`@("HO"B`@("!V87(@)'1Y<&4@/2`G)SL*"B`@("`O*BH*("`@("`J
M($YA;65S<&%C90H@("`@("H*("`@("`J($!V87(@('-T<FEN9PH@("`@("HO
M"B`@("!V87(@)&YA;65S<&%C92`]("<G.PH@("`@=F%R("1T>7!E7VYA;65S
M<&%C92`]("<G.PH*("`@('9A<B`D871T<FEB=71E<R`](&%R<F%Y*"D["@H@
M("`@+RHJ"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1A<G)A>51Y<&4@/2`G)SL*"B`@("!V87(@)&]P=&EO;G,@/2!A<G)A
M>2@I.PH*("`@('9A<B`D;G%N.PH@("`@=F%R("1T<6X["@H@("`@+RHJ"B`@
M("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N86UE("`@("`@("!N86UE(&]F('1H92!S;V%P+79A;'5E('MN86UE<W!A
M8V5];F%M90H@("`@("H@0'!A<F%M(&UI>&5D("`D='EP92`@("`@("`@<V]A
M<"!V86QU92![;F%M97-P86-E?71Y<&4L(&EF(&YO="!S970@86X@875T;VUA
M=&EC"B`@("`@*B!`<&%R86T@;6EX960@("1V86QU92`@("`@("!V86QU92!T
M;R!S970*("`@("`J($!P87)A;2!A<G)A>2`@)&%T=')I8G5T97,@("AO<'1I
M;VYA;"D@071T<FEB=71E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@4T]!4%]6
M86QU92@D;F%M92`]("<G+"`D='EP92`](&9A;'-E+"`D=F%L=64@/2!N=6QL
M+"`D871T<FEB=71E<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@+R\@1&5T
M96-T('1Y<&4@:68@;F]T('!A<W-E9"X*("`@("`@("`D=&AI<RT^;G%N(#TF
M(&YE=R!13F%M92@D;F%M92D["B`@("`@("`@)'1H:7,M/FYA;64@/2`D=&AI
M<RT^;G%N+3YN86UE.PH@("`@("`@("1T:&ES+3YN86UE<W!A8V4@/2`D=&AI
M<RT^;G%N+3YN86UE<W!A8V4["B`@("`@("`@)'1H:7,M/G1Q;B`])B!N97<@
M44YA;64H)'1Y<&4I.PH@("`@("`@("1T:&ES+3YT>7!E(#T@)'1H:7,M/G1Q
M;BT^;F%M93L*("`@("`@("`D=&AI<RT^='EP95]P<F5F:7@@/2`D=&AI<RT^
M='%N+3YN<SL*("`@("`@("`D=&AI<RT^='EP95]N86UE<W!A8V4@/2`D=&AI
M<RT^='%N+3YN86UE<W!A8V4["B`@("`@("`@)'1H:7,M/G9A;'5E(#TF("1V
M86QU93L*("`@("`@("`D=&AI<RT^871T<FEB=71E<R`]("1A='1R:6)U=&5S
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5R:6%L:7IE+@H@("`@("H*("`@
M("`J($!P87)A;2!33T%07T)A<V4@)B1S97)I86QI>F5R("!!(%-/05!?0F%S
M92!I;G-T86YC92!O<B!S=6)C;&%S<R!T;R!S97)I86QI>F4@=VET:"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@6$U,(')E<')E<V5N=&%T:6]N
M(&]F("1T:&ES+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<V5R:6%L:7IE*"8D
M<V5R:6%L:7IE<BD*("`@('L*("`@("`@("!R971U<FX@)'-E<FEA;&EZ97(M
M/E]S97)I86QI>F5686QU92@D=&AI<RT^=F%L=64L("1T:&ES+3YN86UE+"`D
M=&AI<RT^='EP92P@)'1H:7,M/FYA;65S<&%C92P@)'1H:7,M/G1Y<&5?;F%M
M97-P86-E+"`D=&AI<RT^;W!T:6]N<RP@)'1H:7,M/F%T=')I8G5T97,L("1T
M:&ES+3YA<G)A>51Y<&4I.PH@("`@?0H*?0H*+RHJ"B`J(%-/05`Z.DAE861E
M<@H@*@H@*B!4:&ES(&-L87-S(&-O;G9E<G1S('9A;'5E<R!B971W965N(%!(
M4"!A;F0@4T]!4"X@270@:7,@82!S:6UP;&4*("H@=W)A<'!E<B!A<F]U;F0@
M4T]!4%]686QU92P@861D:6YG('-U<'!O<G0@9F]R(%-/05`@86-T;W(@86YD
M"B`J(&UU<W1U;F1E<G-T86YD('!A<F%M971E<G,N"B`J"B`J($]R:6=I;F%L
M;'D@8F%S960@;VX@4T]!4'@T(&)Y($1I971R:6-H($%Y86QA"B`J(&AT='`Z
M+R]D:65T<FEC:"YG86YX-"YC;VTO<V]A<'@T"B`J"B`J($!A8V-E<W,@<'5B
M;&EC"B`J($!P86-K86=E(%-/05`*("H@0&%U=&AO<B!3:&%N92!#87)A=F5O
M(#QS:&%N94!P:'`N;F5T/B!#;VYV97)S:6]N('1O(%!%05(@86YD('5P9&%T
M97,*("H@0&%U=&AO<B!$:65T<FEC:"!!>6%L82`\9&EE=')I8VA`9V%N>#0N
M8V]M/B!/<FEG:6YA;"!!=71H;W(*("HO"F-L87-S(%-/05!?2&5A9&5R(&5X
M=&5N9',@4T]!4%]686QU90I["B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&YA;64@("`@("`@("`@
M("!N86UE(&]F('1H92!S;V%P+79A;'5E('MN86UE<W!A8V5];F%M90H@("`@
M("H@0'!A<F%M(&UI>&5D("`@)'1Y<&4@("`@("`@("`@("!S;V%P('9A;'5E
M('MN86UE<W!A8V5]='EP92P@:68@;F]T('-E="!A;B!A=71O;6%T:6,*("`@
M("`J($!P87)A;2!M:7AE9"`@("1V86QU92`@("`@("`@("`@=F%L=64@=&\@
M<V5T"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;75S='5N9&5R<W1A;F0@(%IE
M<F\@;W(@;VYE+@H@("`@("H@0'!A<F%M(&UI>&5D("`@)&%T=')I8G5T97,@
M("`@("`H;W!T:6]N86PI($%T=')I8G5T97,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%-/05!?2&5A9&5R*"1N86UE(#T@)R<L("1T>7!E+"`D=F%L=64L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`D;75S='5N9&5R<W1A;F0@/2`P+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@)&%T=')I8G5T97,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@(&EF("@A:7-?87)R87DH)&%T=')I8G5T97,I*2![
M"B`@("`@("`@("`@("1A8W1O<B`]("1A='1R:6)U=&5S.PH@("`@("`@("`@
M("`D871T<FEB=71E<R`](&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("!P
M87)E;G0Z.E-/05!?5F%L=64H)&YA;64L("1T>7!E+"`D=F%L=64L("1A='1R
M:6)U=&5S*3L*"B`@("`@("`@:68@*&ES<V5T*"1A8W1O<BDI('L*("`@("`@
M("`@("`@)'1H:7,M/F%T=')I8G5T97-;)U-/05`M14Y6.F%C=&]R)UT@/2`D
M86-T;W(["B`@("`@("`@?2!E;'-E:68@*"%I<W-E="@D=&AI<RT^871T<FEB
M=71E<ULG4T]!4"U%3E8Z86-T;W(G72DI('L*("`@("`@("`@("`@)'1H:7,M
M/F%T=')I8G5T97-;)U-/05`M14Y6.F%C=&]R)UT@/2`G:'1T<#HO+W-C:&5M
M87,N>&UL<V]A<"YO<F<O<V]A<"]A8W1O<B]N97AT)SL*("`@("`@("!]"B`@
M("`@("`@)'1H:7,M/F%T=')I8G5T97-;)U-/05`M14Y6.FUU<W15;F1E<G-T
M86YD)UT@/2`H:6YT*21M=7-T=6YD97)S=&%N9#L*("`@('T*"GT*"B\J*@H@
M*B!33T%0.CI!='1A8VAM96YT"B`J('1H:7,@8VQA<W,@8V]N=F5R=',@=F%L
M=65S(&)E='=E96X@4$A0(&%N9"!33T%0"B`J(&ET(&AA;F1L97,@36EM92!A
M='1A8VAE;65N=',@<&5R(%<S0R!.;W1E(&]N(%-O87`@071T86-H96UE;G1S
M(&%T"B`J(&AT='`Z+R]W=W<N=S,N;W)G+U12+U-/05`M871T86-H;65N=',*
M("H*("H*("H@0&%C8V5S<R!P=6)L:6,*("H@0'!A8VMA9V4@4T]!4`H@*B!`
M875T:&]R(%-H86YE($-A<F%V96\@/'-H86YE0'!H<"YN970^($-O;G9E<G-I
M;VX@=&\@4$5!4B!A;F0@=7!D871E<PH@*B\*8VQA<W,@4T]!4%]!='1A8VAM
M96YT(&5X=&5N9',@4T]!4%]686QU90I["B`@("`O*BH*("`@("`J($-O;G-T
M<G5C=&]R"B`@("`@*@H@("`@("H@0'!A<F%M("`@('-T<FEN9R`@;F%M92!O
M9B!T:&4@<V]A<"UV86QU92`\=F%L=65?;F%M93X*("`@("`J($!P87)A;2`@
M("!M:7AE9"`@('-O87`@:&5A9&5R('9A;'5E"B`@("`@*B!`<&%R86T@("`@
M<W1R:6YG(&YA;65S<&%C90H@("`@("HO"B`@("!F=6YC=&EO;B!33T%07T%T
M=&%C:&UE;G0H)&YA;64@/2`G)RP@)'1Y<&4@/2`G87!P;&EC871I;VXO;V-T
M970M<W1R96%M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9FEL
M96YA;64L("1F:6QE(#T@;G5L;"D*("`@('L*("`@("`@("!G;&]B86P@)%-/
M05!?;W!T:6]N<SL*("`@("`@("!I9B`H(6ES<V5T*"133T%07V]P=&EO;G-;
M)TUI;64G72DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H)TUA:6Q?;6EM92!I<R!N;W0@:6YS=&%L;&5D+"!U;F%B;&4@=&\@<W5P
M<&]R="!33T%0($%T=&%C:&5M96YT<R<I.PH@("`@("`@('T*("`@("`@("!P
M87)E;G0Z.E-/05!?5F%L=64H)&YA;64L(&YU;&PL(&YU;&PI.PH*("`@("`@
M("`D9FEL961A=&$@/2`H)&9I;&4@/3T](&YU;&PI(#\@)'1H:7,M/E]F:6QE
M,G-T<B@D9FEL96YA;64I(#H@)&9I;&4["B`@("`@("`@)&9I;&5N86UE(#T@
M8F%S96YA;64H)&9I;&5N86UE*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D9FEL961A=&$I*2!["B`@("`@("`@("`@(')E='5R;B`D9FEL961A=&$[
M"B`@("`@("`@?0H*("`@("`@("`D8VED(#T@;60U*'5N:7%I9"AT:6UE*"DI
M*3L*"B`@("`@("`@)'1H:7,M/F%T=')I8G5T97-;)VAR968G72`]("=C:60Z
M)RXD8VED.PH*("`@("`@("`D=&AI<RT^;W!T:6]N<ULG871T86-H;65N="==
M(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V)O
M9'DG("`@("`]/B`D9FEL961A=&$L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)V1I<W!O<VET:6]N)R`@("`@/3X@)&9I;&5N86UE+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=C;VYT96YT7W1Y<&4G("`@
M/3X@)'1Y<&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V5N
M8V]D:6YG)R`]/B`G8F%S938T)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G8VED)R`]/B`D8VED"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M8V]N=&5N=',@;V8@=&AE(&=I=F5N(&9I;&4@;F%M92!A<R!S=')I;F<*("`@
M("`J($!P87)A;2!S=')I;F<@)&9I;&5?;F%M90H@("`@("H@0')E='5R;B!S
M=')I;F<*("`@("`J($!A8V-E<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T
M:6]N("9?9FEL93)S='(H)&9I;&5?;F%M92D*("`@('L*("`@("`@("!I9B`H
M(6ES7W)E861A8FQE*"1F:6QE7VYA;64I*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"=&:6QE(&ES(&YO="!R96%D86)L92`G("X@
M)&9I;&5?;F%M92D["B`@("`@("`@?0H@("`@("`@(&EF("@A)&9D(#T@9F]P
M96XH)&9I;&5?;F%M92P@)W)B)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)T-O=6QD(&YO="!O<&5N("<@+B`D9FEL95]N86UE
M*3L*("`@("`@("!]"B`@("`@("`@)&-O;G0@/2!F<F5A9"@D9F0L(&9I;&5S
M:7IE*"1F:6QE7VYA;64I*3L*("`@("`@("!F8VQO<V4H)&9D*3L*("`@("`@
M("!R971U<FX@)&-O;G0["B`@("!]"@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+U-/05`O5U-$3"YP:'``````````````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`R-#<R-C`@,3`U,34T,S,W,S$@,#(P-3(S`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B!4:&ES(&9I;&4@8V]N=&%I;G,@=&AE(&-O9&4@9F]R(&1E86QI;F<@
M=VET:"!74T1,(&%C8V5S<R!A;F0@<V5R=FEC97,N"B`J"B`J(%!(4"!V97)S
M:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@
M:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E
M+`H@*B!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE
M(&9I;&4@3$E#14Y312P@86YD(&ES(&%V86EL86)L92!A=`H@*B!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8B!A="!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\R7S`R+G1X="X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@82!C
M;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A
M:6X@:70*("H@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S
M96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N"B`J(&UA
M:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@
M5V5B(%-E<G9I8V5S"B`J($!P86-K86=E("`@(%-/05`*("H@0&%U=&AO<B`@
M("`@1&EE=')I8V@@07EA;&$@/&1I971R:6-H0&=A;G@T+F-O;3X@3W)I9VEN
M86P@075T:&]R"B`J($!A=71H;W(@("`@(%-H86YE($-A<F%V96\@/%-H86YE
M0$-A<F%V96\N8V]M/B`@(%!O<G0@=&\@4$5!4B!A;F0@;6]R90H@*B!`875T
M:&]R("`@("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX@("!-
M86EN=&5N86YC90H@*B!`875T:&]R("`@("!*86X@4V-H;F5I9&5R(#QJ86Y`
M:&]R9&4N;W)G/B`@("`@("!-86EN=&5N86YC90H@*B!`8V]P>7)I9VAT("`R
M,#`S+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="`@4$A0($QI8V5N<V4@,BXP
M,@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O
M4T]!4`H@*B\*"G)E<75I<F5?;VYC92`G4T]!4"]"87-E+G!H<"<["G)E<75I
M<F5?;VYC92`G4T]!4"]&875L="YP:'`G.PIR97%U:7)E7V]N8V4@)TA45%`O
M4F5Q=65S="YP:'`G.PH*9&5F:6YE*"=74T1,7T-!0TA%7TU!6%]!1T4G+"`T
M,S(P,"D["F1E9FEN92@G5U-$3%]#04-(15]54T4G+"`@("`@,"D[("\O('-E
M="!T;R!Z97)O('1O('1U<FX@;V9F(&-A8VAI;F<*"B\J*@H@*B!4:&ES(&-L
M87-S('!A<G-E<R!74T1,(&9I;&5S+"!A;F0@8V%N(&)E('5S960@8GD@4T]!
M4#HZ0VQI96YT('1O"B`J('!R;W!E<FQY(')E9VES=&5R('-O87`@=F%L=65S
M(&9O<B!S97)V:6-E<RX*("H*("H@3W)I9VEN86QL>2!B87-E9"!O;B!33T%0
M>#0@8GD@1&EE=')I8V@@07EA;&$*("H@:'1T<#HO+V1I971R:6-H+F=A;G@T
M+F-O;2]S;V%P>#0*("H*("H@5$]$3SH*("H@("!A9&0@=W-D;"!C86-H:6YG
M"B`J("`@<F5F86-T;W(@;F%M97-P86-E(&AA;F1L:6YG("@D;F%M97-P86-E
M+R1N<RD*("H@("!I;7!L96UE;G0@241,('1Y<&4@<WEN=&%X(&1E8VQA<F%T
M:6]N('-O('=E(&-A;B!G96YE<F%T92!74T1,"B`J"B`J($!A8V-E<W,@<'5B
M;&EC"B`J($!P86-K86=E(%-/05`*("H@0&%U=&AO<B!3:&%N92!#87)A=F5O
M(#QS:&%N94!P:'`N;F5T/B!#;VYV97)S:6]N('1O(%!%05(@86YD('5P9&%T
M97,*("H@0&%U=&AO<B!$:65T<FEC:"!!>6%L82`\9&EE=')I8VA`9V%N>#0N
M8V]M/B!/<FEG:6YA;"!!=71H;W(*("HO"F-L87-S(%-/05!?5U-$3"!E>'1E
M;F1S(%-/05!?0F%S90I["B`@("!V87(@)'1N<R`](&YU;&P["B`@("!V87(@
M)&1E9FEN:71I;VX@/2!A<G)A>2@I.PH@("`@=F%R("1N86UE<W!A8V5S(#T@
M87)R87DH*3L*("`@('9A<B`D;G,@/2!A<G)A>2@I.PH@("`@=F%R("1X<V0@
M/2!33T%07UA-3%]30TA%34%?5D524TE/3CL*("`@('9A<B`D8V]M<&QE>%1Y
M<&5S(#T@87)R87DH*3L*("`@('9A<B`D96QE;65N=',@/2!A<G)A>2@I.PH@
M("`@=F%R("1M97-S86=E<R`](&%R<F%Y*"D["B`@("!V87(@)'!O<G14>7!E
M<R`](&%R<F%Y*"D["B`@("!V87(@)&)I;F1I;F=S(#T@87)R87DH*3L*("`@
M('9A<B`D:6UP;W)T<R`](&%R<F%Y*"D["B`@("!V87(@)'-E<G9I8V5S(#T@
M87)R87DH*3L*("`@('9A<B`D<V5R=FEC92`]("<G.PH@("`@=F%R("1U<FD@
M/2`G)SL*("`@('9A<B`D9&]C<R`](&9A;'-E.PH*("`@("\J*@H@("`@("H@
M4')O>'D@<&%R86UE=&5R<PH@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1P<F]X>2`](&YU;&P["@H@("`@=F%R("1T<F%C92`]
M(#`["@H@("`@+RHJ"B`@("`@*B!5<V4@5U-$3"!C86-H90H@("`@("H*("`@
M("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)&-A8VAE57-E(#T@
M;G5L;#L*"B`@("`O*BH*("`@("`J($-A8VAE(&UA>"!L:69E=&EM92`H:6X@
M<V5C;VYD<RD*("`@("`J"B`@("`@*B!`=F%R(&EN=`H@("`@("HO"B`@("!V
M87(@)&-A8VAE36%X06=E(#T@;G5L;#L*"B`@("`O*BH*("`@("`J($-L87-S
M('1O('5S92!F;W(@5U-$3"!P87)S:6YG+B!#86X@8F4@;W9E<G)I9&1E;B!F
M;W(@<W!E8VEA;`H@("`@("H@8V%S97,L('-U8F-L87-S97,L(&5T8RX*("`@
M("`J($!V87(@<W1R:6YG("1W<V1L4&%R<V5R0VQA<W,*("`@("`J+PH@("`@
M=F%R("1W<V1L4&%R<V5R0VQA<W,@/2`G4T]!4%]74T1,7U!A<G-E<B<["@H@
M("`@+RHJ"B`@("`@*B!33T%07U=31$P@8V]N<W1R=6-T;W(N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`@)'=S9&Q?=7)I("`@("!54DP@=&\@5U-$
M3"!F:6QE+@H@("`@("H@0'!A<F%M(&%R<F%Y("`@)'!R;WAY("`@("`@("!#
M;VYT86EN<R!O<'1I;VYS(&9O<B!(5%107U)E<75E<W0@8VQA<W,@*'-E92!(
M5%10+U)E<75E<W0N<&AP*2X*("`@("`J($!P87)A;2!B;V]L96%N("1C86-H
M955S92`@("`@57-E(%=31$P@8V%C:&EN9RX@1&5F875L=',@=&\@9F%L<V4N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V%C:&5-87A!9V4@($-A8VAE(&UA
M>"!L:69E=&EM92`H:6X@<V5C;VYD<RDN"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D9&]C<R`@("`@("`@(%!A<G-E(&1O8W5M96YT871I;VX@:6X@=&AE(%=3
M1$P_($1E9F%U;'1S('1O(&9A;'-E+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(%-/05!?5U-$3"@D=W-D;%]U
M<FD@("`@/2!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`D<')O>'D@
M("`@("`@/2!A<G)A>2@I+`H@("`@("`@("`@("`@("`@("`@("`@("1C86-H
M955S92`@("`](%=31$Q?0T%#2$5?55-%+`H@("`@("`@("`@("`@("`@("`@
M("`@("1C86-H94UA>$%G92`](%=31$Q?0T%#2$5?34%87T%'12P*("`@("`@
M("`@("`@("`@("`@("`@("`D9&]C<R`@("`@("`@/2!F86QS92D*("`@('L*
M("`@("`@("!P87)E;G0Z.E-/05!?0F%S92@G5U-$3"<I.PH@("`@("`@("1T
M:&ES+3YU<FD@("`@("`@("`]("1W<V1L7W5R:3L*("`@("`@("`D=&AI<RT^
M<')O>'D@("`@("`@/2`D<')O>'D["B`@("`@("`@)'1H:7,M/F-A8VAE57-E
M("`@(#T@)&-A8VAE57-E.PH@("`@("`@("1T:&ES+3YC86-H94UA>$%G92`]
M("1C86-H94UA>$%G93L*("`@("`@("`D=&AI<RT^9&]C<R`@("`@("`@/2`D
M9&]C<SL*"B`@("`@("`@:68@*"1W<V1L7W5R:2D@>PH@("`@("`@("`@("`D
M=&AI<RT^<&%R<V554DPH)'=S9&Q?=7)I*3L*("`@("`@("`@("`@<F5S970H
M)'1H:7,M/G-E<G9I8V5S*3L*("`@("`@("`@("`@)'1H:7,M/G-E<G9I8V4@
M/2!K97DH)'1H:7,M/G-E<G9I8V5S*3L*("`@("`@("!]"B`@("!]"@H@("`@
M9G5N8W1I;VX@<V5T7W-E<G9I8V4H)'-E<G9I8V4I"B`@("!["B`@("`@("`@
M:68@*&%R<F%Y7VME>5]E>&ES=',H)'-E<G9I8V4L("1T:&ES+3YS97)V:6-E
M<RDI('L*("`@("`@("`@("`@)'1H:7,M/G-E<G9I8V4@/2`D<V5R=FEC93L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!`9&5P<F5C871E9"!U
M<V4@<&%R<V554DP@:6YS=&5A9`H@("`@("HO"B`@("!F=6YC=&EO;B!P87)S
M92@D=W-D;%]U<FDL("1P<F]X>2`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M)'1H:7,M/G!A<G-E55),*"1W<V1L7W5R:2P@)'!R;WAY*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($9I;&P@=&AE(%=31$P@87)R87D@=')E92!W:71H(&1A
M=&$@9G)O;2!A(%=31$P@9FEL90H@("`@("H*("`@("`J($!P87)A;2`@<W1R
M:6YG"B`@("`@*B!`<&%R86T@(&%R<F%Y("!P<F]X>2!R96QA=&5D('!A<F%M
M971E<G,*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO
M;B!P87)S95523"@D=W-D;%]U<FDL("1P<F]X>2`](&%R<F%Y*"DI"B`@("![
M"B`@("`@("`@)'!A<G-E<B`])B!N97<@)'1H:7,M/G=S9&Q087)S97)#;&%S
M<R@D=W-D;%]U<FDL("1T:&ES+"`D=&AI<RT^9&]C<RD["@H@("`@("`@(&EF
M("@D<&%R<V5R+3YF875L="D@>PH@("`@("`@("`@("`D=&AI<RT^7W)A:7-E
M4V]A<$9A=6QT*"1P87)S97(M/F9A=6QT*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!&:6QL('1H92!74T1,(&%R<F%Y('1R964@=VET:"!D
M871A(&9R;VT@;VYE(&]R(&UO<F4@4$A0(&-L87-S(&]B:F5C=',*("`@("`J
M"B`@("`@*B!`<&%R86T@(&UI>&5D("`D=W-D;%]O8FH@06X@;V)J96-T(&]R
M(&%R<F%Y(&]F(&]B:F5C=',@=&\@861D('1O('1H92!I;G1E<FYA;"!74T1,
M('1R964*("`@("`J($!P87)A;2`@<W1R:6YG("`D<V5R=FEC95]N86UE($YA
M;64@;V8@=&AE(%=31$P@/'-E<G9I8V4^"B`@("`@*B!`<&%R86T@('-T<FEN
M9R`@)'-E<G9I8V5?9&5S8R!/<'1I;VYA;"!D97-C<FEP=&EO;B!O9B!T:&4@
M5U-$3"`\<V5R=FEC93X*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@
M("!F=6YC=&EO;B!P87)S94]B:F5C="@F)'=S9&Q?;V)J+"`D=&%R9V5T3F%M
M97-P86-E+"`D<V5R=FEC95]N86UE+"`D<V5R=FEC95]D97-C(#T@)R<I"B`@
M("!["B`@("`@("`@)'!A<G-E<B`])B!N97<@4T]!4%]74T1,7T]B:F5C=%!A
M<G-E<B@D=W-D;%]O8FHL("1T:&ES+"`D=&%R9V5T3F%M97-P86-E+"`D<V5R
M=FEC95]N86UE+"`D<V5R=FEC95]D97-C*3L*"B`@("`@("`@(&EF("@D<&%R
M<V5R+3YF875L="D@>PH@("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&
M875L="@D<&%R<V5R+3YF875L="D["B`@("`@("`@('T*("`@('T*"B`@("!F
M=6YC=&EO;B!G971%;F1P;VEN="@D<&]R=$YA;64I"B`@("!["B`@("`@("`@
M<F5T=7)N("AI<W-E="@D=&AI<RT^<V5R=FEC97-;)'1H:7,M/G-E<G9I8V5=
M6R=P;W)T<R==6R1P;W)T3F%M95U;)V%D9')E<W,G75LG;&]C871I;VXG72DI
M"B`@("`@("`@("`@("`@("`_("1T:&ES+3YS97)V:6-E<ULD=&AI<RT^<V5R
M=FEC95U;)W!O<G1S)UU;)'!O<G1.86UE75LG861D<F5S<R==6R=L;V-A=&EO
M;B=="B`@("`@("`@("`@("`@("`Z("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H
M(FYO(&5N9'!O:6YT(&9O<B!P;W)T(&9O<B`D<&]R=$YA;64B+"`D=&AI<RT^
M=7)I*3L*("`@('T*"B`@("!F=6YC=&EO;B!?9V5T4&]R=$YA;64H)&]P97)A
M=&EO;BP@)'-E<G9I8V4I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3YS97)V:6-E<ULD<V5R=FEC95U;)W!O<G1S)UTI*2!["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3YS97)V:6-E<ULD<V5R=FEC95U;)W!O<G1S)UT@
M87,@)'!O<G0@/3X@)'!O<G1!='1R<RD@>PH@("`@("`@("`@("`@("`@)'1Y
M<&4@/2`D=&AI<RT^<V5R=FEC97-;)'-E<G9I8V5=6R=P;W)T<R==6R1P;W)T
M75LG='EP92==.PH@("`@("`@("`@("`@("`@:68@*"1T>7!E(#T]("=S;V%P
M)R`F)@H@("`@("`@("`@("`@("`@("`@(&ES<V5T*"1T:&ES+3YB:6YD:6YG
M<ULD<&]R=$%T=')S6R=B:6YD:6YG)UU=6R=O<&5R871I;VYS)UU;)&]P97)A
M=&EO;ETI*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1P;W)T.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@(')E='5R;B!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@9FEN9"!T
M:&4@;F%M92!O9B!T:&4@9FER<W0@<&]R="!T:&%T(&-O;G1A:6YS(&%N(&]P
M97)A=&EO;B!O9@H@("`@("H@;F%M92`D;W!E<F%T:6]N+B`@86QW87ES(')E
M='5R;G,@82!T:&4@<V]A<"!P;W)T3F%M92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T4&]R=$YA;64H)&]P97)A=&EO;BP@)'-E<G9I8V4@/2!N=6QL*0H@
M("`@>PH@("`@("`@(&EF("@A)'-E<G9I8V4I("1S97)V:6-E(#T@)'1H:7,M
M/G-E<G9I8V4["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YS97)V:6-E<ULD
M<V5R=FEC95U;)W!O<G1S)UTI*2!["B`@("`@("`@("`@("1P;W)T3F%M92`]
M("1T:&ES+3Y?9V5T4&]R=$YA;64H)&]P97)A=&EO;BP@)'-E<G9I8V4I.PH@
M("`@("`@("`@("!I9B`H)'!O<G1.86UE*2!R971U<FX@)'!O<G1.86UE.PH@
M("`@("`@('T*("`@("`@("`O+R!4<GD@86YY('-E<G9I8V4@:6X@=&AE(%=3
M1$PN"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/G-E<G9I8V5S(&%S("1S97)V
M:6-E3F%M92`]/B`D<V5R=FEC92D@>PH@("`@("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/G-E<G9I8V5S6R1S97)V:6-E3F%M95U;)W!O<G1S)UTI*2!["B`@
M("`@("`@("`@("`@("`D<&]R=$YA;64@/2`D=&AI<RT^7V=E=%!O<G1.86UE
M*"1O<&5R871I;VXL("1S97)V:6-E3F%M92D["B`@("`@("`@("`@("`@("!I
M9B`H)'!O<G1.86UE*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E
M<G9I8V4@/2`D<V5R=FEC94YA;64["B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N("1P;W)T3F%M93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&
M875L="@B;F\@;W!E<F%T:6]N("1O<&5R871I;VX@:6X@=W-D;"(L("1T:&ES
M+3YU<FDI.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$]P97)A=&EO;D1A=&$H
M)'!O<G1.86UE+"`D;W!E<F%T:6]N*0H@("`@>PH@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^<V5R=FEC97-;)'1H:7,M/G-E<G9I8V5=6R=P;W)T<R==6R1P
M;W)T3F%M95U;)V)I;F1I;F<G72D*("`@("`@("`@("`@)B8@)&)I;F1I;F<@
M/2`D=&AI<RT^<V5R=FEC97-;)'1H:7,M/G-E<G9I8V5=6R=P;W)T<R==6R1P
M;W)T3F%M95U;)V)I;F1I;F<G72D@>PH@("`@("`@("`@("`O+R!G970@;W!E
M<F%T:6]N(&1A=&$@9G)O;2!B:6YD:6YG"B`@("`@("`@("`@(&EF("AI<U]A
M<G)A>2@D=&AI<RT^8FEN9&EN9W-;)&)I;F1I;F==6R=O<&5R871I;VYS)UU;
M)&]P97)A=&EO;ETI*2!["B`@("`@("`@("`@("`@("`D;W!$871A(#T@)'1H
M:7,M/F)I;F1I;F=S6R1B:6YD:6YG75LG;W!E<F%T:6]N<R==6R1O<&5R871I
M;VY=.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("\O(&=E="!O<&5R871I
M;VX@9&%T82!F<F]M('!O<G1T>7!E"B`@("`@("`@("`@("1P;W)T5'EP92`]
M("1T:&ES+3YB:6YD:6YG<ULD8FEN9&EN9UU;)W1Y<&4G73L*("`@("`@("`@
M("`@:68@*"$D<&]R=%1Y<&4I('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")N;R!P;W)T('1Y<&4@9F]R(&)I;F1I
M;F<@)&)I;F1I;F<@:6X@=W-D;"`B("X@)'1H:7,M/G5R:2D["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3YP;W)T5'EP
M97-;)'!O<G14>7!E75LD;W!E<F%T:6]N72DI('L*("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^<&]R=%1Y<&5S6R1P;W)T5'EP95U;)&]P97)A
M=&EO;EU;)W!A<F%M971E<D]R9&5R)UTI*0H@("`@("`@("`@("`@("`@("`@
M("1O<$1A=&%;)W!A<F%M971E<D]R9&5R)UT@/2`D=&AI<RT^<&]R=%1Y<&5S
M6R1P;W)T5'EP95U;)&]P97)A=&EO;EU;)W!A<F%M971E<D]R9&5R)UT["B`@
M("`@("`@("`@("`@("`D;W!$871A6R=I;G!U="==(#T@87)R87E?;65R9V4H
M)&]P1&%T85LG:6YP=70G72P@)'1H:7,M/G!O<G14>7!E<ULD<&]R=%1Y<&5=
M6R1O<&5R871I;VY=6R=I;G!U="==*3L*("`@("`@("`@("`@("`@("1O<$1A
M=&%;)V]U='!U="==(#T@87)R87E?;65R9V4H)&]P1&%T85LG;W5T<'5T)UTL
M("1T:&ES+3YP;W)T5'EP97-;)'!O<G14>7!E75LD;W!E<F%T:6]N75LG;W5T
M<'5T)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A)&]P1&%T
M82D*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A
M=6QT*")N;R!O<&5R871I;VX@)&]P97)A=&EO;B!F;W(@<&]R="`D<&]R=$YA
M;64L(&EN('=S9&PB+"`D=&AI<RT^=7)I*3L*("`@("`@("`@("`@)&]P1&%T
M85LG<&%R86UE=&5R<R==(#T@9F%L<V4["B`@("`@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^8FEN9&EN9W-;)'1H:7,M/G-E<G9I8V5S6R1T:&ES+3YS97)V
M:6-E75LG<&]R=',G75LD<&]R=$YA;65=6R=B:6YD:6YG)UU=6R=O<&5R871I
M;VYS)UU;)&]P97)A=&EO;EU;)VEN<'5T)UU;)VYA;65S<&%C92==*2D*("`@
M("`@("`@("`@("`@("1O<$1A=&%;)VYA;65S<&%C92==(#T@)'1H:7,M/F)I
M;F1I;F=S6R1T:&ES+3YS97)V:6-E<ULD=&AI<RT^<V5R=FEC95U;)W!O<G1S
M)UU;)'!O<G1.86UE75LG8FEN9&EN9R==75LG;W!E<F%T:6]N<R==6R1O<&5R
M871I;VY=6R=I;G!U="==6R=N86UE<W!A8V4G73L*("`@("`@("`@("`@+R\@
M;65S<V%G92!D871A(&9R;VT@;65S<V%G97,*("`@("`@("`@("`@)&EN<'5T
M37-G(#T@)&]P1&%T85LG:6YP=70G75LG;65S<V%G92==.PH@("`@("`@("`@
M("!I9B`H:7-?87)R87DH)'1H:7,M/FUE<W-A9V5S6R1I;G!U=$US9UTI*2![
M"B`@("`@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^;65S<V%G97-;)&EN
M<'5T37-G72!A<R`D<&YA;64@/3X@)'!A='1R<RD@>PH@("`@("`@("`@("`@
M("`@("`@(&EF("@D;W!$871A6R=S='EL92==(#T]("=D;V-U;65N="<@)B8@
M)&]P1&%T85LG:6YP=70G75LG=7-E)UT@/3T@)VQI=&5R86PG"B`@("`@("`@
M("`@("`@("`@("`@("`@("8F("1P;F%M92`]/2`G<&%R86UE=&5R<R<I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&]P1&%T85LG<&%R86UE=&5R<R==
M(#T@=')U93L*("`@("`@("`@("`@("`@("`@("`@("`@)&]P1&%T85LG;F%M
M97-P86-E)UT@/2`D=&AI<RT^;F%M97-P86-E<ULD<&%T=')S6R=N86UE<W!A
M8V4G75T["B`@("`@("`@("`@("`@("`@("`@("`@("1E;"`]("1T:&ES+3YE
M;&5M96YT<ULD<&%T=')S6R=N86UE<W!A8V4G75U;)'!A='1R<ULG='EP92==
M73L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1E;%LG96QE
M;65N=',G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1E;%LG96QE;65N=',G72!A<R`D96QN86UE(#T^("1E;&%T=')S*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&]P1&%T85LG:6YP
M=70G75LG<&%R=',G75LD96QN86UE72`]("1E;&%T=')S.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&]P1&%T85LG:6YP=70G75LG<&%R=',G75LD<&YA;65=(#T@
M)'!A='1R<SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&]U='!U=$US9R`]("1O
M<$1A=&%;)V]U='!U="==6R=M97-S86=E)UT["B`@("`@("`@("`@(&EF("AI
M<U]A<G)A>2@D=&AI<RT^;65S<V%G97-;)&]U='!U=$US9UTI*2!["B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^;65S<V%G97-;)&]U='!U=$US
M9UT@87,@)'!N86UE(#T^("1P871T<G,I('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H)&]P1&%T85LG<W1Y;&4G72`]/2`G9&]C=6UE;G0G("8F("1O<$1A
M=&%;)V]U='!U="==6R=U<V4G72`]/2`G;&ET97)A;"<*("`@("`@("`@("`@
M("`@("`@("`@("`@)B8@)'!N86UE(#T]("=P87)A;65T97)S)RD@>PH*("`@
M("`@("`@("`@("`@("`@("`@("`@)&5L(#T@)'1H:7,M/F5L96UE;G1S6R1P
M871T<G-;)VYA;65S<&%C92==75LD<&%T=')S6R=T>7!E)UU=.PH@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&5L6R=E;&5M96YT<R==*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&5L6R=E
M;&5M96YT<R==(&%S("1E;&YA;64@/3X@)&5L871T<G,I('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D;W!$871A6R=O=71P=70G75LG<&%R
M=',G75LD96QN86UE72`]("1E;&%T=')S.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&]P1&%T85LG;W5T<'5T)UU;)W!A<G1S)UU;)'!N86UE72`]("1P871T<G,[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D;W!$871A.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&875L="@B;F\@
M8FEN9&EN9R!F;W(@<&]R="`D<&]R=$YA;64@:6X@=W-D;"(L("1T:&ES+3YU
M<FDI.PH@("`@?0H*("`@(&9U;F-T:6]N(&UA=&-H365T:&]D*"8D;W!E<F%T
M:6]N*0H@("`@>PH@("`@("`@("\O($]V97)L;V%D:6YG(&QO=V5R8V%S97,@
M9G5N8W1I;VX@;F%M97,@.B@*("`@("`@("!F;W)E86-H("@D=&AI<RT^<V5R
M=FEC97-;)'1H:7,M/G-E<G9I8V5=6R=P;W)T<R==(&%S("1P;W)T(#T^("1P
M;W)T071T<G,I('L*("`@("`@("`@("`@9F]R96%C:"`H87)R87E?:V5Y<R@D
M=&AI<RT^8FEN9&EN9W-;)'!O<G1!='1R<ULG8FEN9&EN9R==75LG;W!E<F%T
M:6]N<R==*2!A<R`D;W`I('L*("`@("`@("`@("`@("`@(&EF("AS=')C87-E
M8VUP*"1O<"P@)&]P97)A=&EO;BD@/3T@,"D@>PH@("`@("`@("`@("`@("`@
M("`@("1O<&5R871I;VX@/2`D;W`["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!G971$
M871A2&%N9&QE<@H@("`@("H*("`@("`J($=I=F5N(&$@9&%T871Y<&4L('=H
M870@9G5N8W1I;VX@:&%N9&QE<R!T:&4@<')O8V5S<VEN9S\*("`@("`J('1H
M:7,@:7,@=7-E9"!F;W(@9&]C+VQI=&5R86P@<F5Q=65S=',@=VAE<F4@=V4@
M<F5C96EV90H@("`@("H@82!D871A='EP92P@86YD('=E(&YE960@=&\@<&%S
M<R!I="!T;R!A(&UE=&AO9"!I;B!O=70*("`@("`J('-E<G9E<B!C;&%S<PH@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@9&%T871Y<&4*("`@("`J($!P
M87)A;2!S=')I;F<@;F%M97-P86-E"B`@("`@*B!`<F5T=7)N<R!S=')I;F<@
M;65T:&]D;F%M90H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T1&%T84AA;F1L97(H)&1A=&%T>7!E+"`D;F%M97-P86-E
M*0H@("`@>PH@("`@("`@("\O('-E92!I9B!W92!H879E(&%N(&5L96UE;G0@
M8GD@=&AI<R!N86UE"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YN86UE<W!A
M8V5S6R1N86UE<W!A8V5=*2D*("`@("`@("`@("`@)&YA;65S<&%C92`]("1T
M:&ES+3YN86UE<W!A8V5S6R1N86UE<W!A8V5=.PH@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^;G-;)&YA;65S<&%C95TI*2!["B`@("`@("`@("`@("1N<W`@
M/2`D=&AI<RT^;G-;)&YA;65S<&%C95T["B`@("`@("`@("`@("\O:68@*"%I
M<W-E="@D=&AI<RT^96QE;65N='-;)&YS<%TI*0H@("`@("`@("`@("`O+R`@
M("`D;G-P(#T@)'1H:7,M/FYA;65S<&%C97-;)&YS<%T["B`@("`@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^96QE;65N='-;)&YS<%U;)&1A=&%T>7!E72DI
M('L*("`@("`@("`@("`@("`@("1C:&5C:VUE<W-A9V5S(#T@87)R87DH*3L*
M("`@("`@("`@("`@("`@("\O(&9I;F0@=VAA="!M97-S86=E<R!U<V4@=&AI
M<R!D871A='EP90H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/FUE
M<W-A9V5S(&%S("1M97-S86=E;F%M92`]/B`D;65S<V%G92D@>PH@("`@("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1M97-S86=E(&%S("1P87)T;F%M92`]
M/B`D<&%R="D@>PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'!A<G1;
M)W1Y<&4G72`]/2`D9&%T871Y<&4I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1C:&5C:VUE<W-A9V5S6UT@/2`D;65S<V%G96YA;64["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("\O(&9I;F0@=&AE(&]P97)A=&EO;B!T
M:&%T('5S97,@=&AI<R!M97-S86=E"B`@("`@("`@("`@("`@("`D9&%T84AA
M;F1L97(@/2!N=6QL.PH@("`@("`@("`@("`@("`@9F]R96%C:"@D=&AI<RT^
M<&]R=%1Y<&5S(&%S("1P;W)T;F%M92`]/B`D<&]R='1Y<&4I('L*("`@("`@
M("`@("`@("`@("`@("!F;W)E86-H("@D<&]R='1Y<&4@87,@)&]P;F%M92`]
M/B`D;W!I;F9O*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1C:&5C:VUE<W-A9V5S(&%S("1M97-S86=E;F%M92D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"1O<&EN9F];)VEN<'5T)UU;)VUE<W-A
M9V4G72`]/2`D;65S<V%G96YA;64I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)&]P;F%M93L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!R971U<FX@;G5L;#L*("`@('T*"B`@("!F
M=6YC=&EO;B!G9713;V%P06-T:6]N*"1P;W)T3F%M92P@)&]P97)A=&EO;BD*
M("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/F)I;F1I;F=S6R1T:&ES
M+3YS97)V:6-E<ULD=&AI<RT^<V5R=FEC95U;)W!O<G1S)UU;)'!O<G1.86UE
M75LG8FEN9&EN9R==75LG;W!E<F%T:6]N<R==6R1O<&5R871I;VY=6R=S;V%P
M06-T:6]N)UTI("8F"B`@("`@("`@("`@("1S;V%P06-T:6]N(#T@)'1H:7,M
M/F)I;F1I;F=S6R1T:&ES+3YS97)V:6-E<ULD=&AI<RT^<V5R=FEC95U;)W!O
M<G1S)UU;)'!O<G1.86UE75LG8FEN9&EN9R==75LG;W!E<F%T:6]N<R==6R1O
M<&5R871I;VY=6R=S;V%P06-T:6]N)UTI('L*("`@("`@("`@("`@<F5T=7)N
M("1S;V%P06-T:6]N.PH@("`@("`@('T*("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("!]"@H@("`@9G5N8W1I;VX@9V5T3F%M97-P86-E*"1P;W)T3F%M92P@
M)&]P97)A=&EO;BD*("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/F)I
M;F1I;F=S6R1T:&ES+3YS97)V:6-E<ULD=&AI<RT^<V5R=FEC95U;)W!O<G1S
M)UU;)'!O<G1.86UE75LG8FEN9&EN9R==72D@)B8*("`@("`@("`@("`@:7-S
M970H)'1H:7,M/F)I;F1I;F=S6R1T:&ES+3YS97)V:6-E<ULD=&AI<RT^<V5R
M=FEC95U;)W!O<G1S)UU;)'!O<G1.86UE75LG8FEN9&EN9R==75LG;W!E<F%T
M:6]N<R==6R1O<&5R871I;VY=6R=I;G!U="==6R=N86UE<W!A8V4G72D@)B8*
M("`@("`@("`@("`@)&YA;65S<&%C92`]("1T:&ES+3YB:6YD:6YG<ULD=&AI
M<RT^<V5R=FEC97-;)'1H:7,M/G-E<G9I8V5=6R=P;W)T<R==6R1P;W)T3F%M
M95U;)V)I;F1I;F<G75U;)V]P97)A=&EO;G,G75LD;W!E<F%T:6]N75LG:6YP
M=70G75LG;F%M97-P86-E)UTI('L*("`@("`@("`@("`@<F5T=7)N("1N86UE
M<W!A8V4["B`@("`@("`@?0H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*
M"B`@("!F=6YC=&EO;B!G971.86UE<W!A8V5!='1R:6)U=&5.86UE*"1N86UE
M<W!A8V4I"B`@("!["B`@("`@("`@+RH@268@:70@9&]E<VXG="!E>&ES="!A
M="!F:7)S="P@9FQI<"!T:&4@87)R87D@86YD(&-H96-K"B`@("`@("`@("H@
M86=A:6XN("HO"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3YN<ULD;F%M97-P
M86-E72DI('L*("`@("`@("`@("`@)'1H:7,M/FYS(#T@87)R87E?9FQI<"@D
M=&AI<RT^;F%M97-P86-E<RD["B`@("`@("`@?0H@("`@("`@("\J($EF(&ET
M(&1O97-N)W0@97AI<W0@;F]W+"!A9&0@:70N("HO"B`@("`@("`@:68@*&5M
M<'1Y*"1T:&ES+3YN<ULD;F%M97-P86-E72DI('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YA9&1.86UE<W!A8V4H)&YA;65S<&%C92D["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)'1H:7,M/FYS6R1N86UE<W!A8V5=.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&%D9$YA;65S<&%C92@D;F%M97-P86-E*0H@("`@
M>PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/FYS6R1N86UE<W!A8V5=*2D@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/FYS6R1N86UE<W!A8V5=.PH@
M("`@("`@('T*"B`@("`@("`@)&X@/2!C;W5N="@D=&AI<RT^;G,I.PH@("`@
M("`@("1A='1R(#T@)VYS)R`N("1N.PH@("`@("`@("1T:&ES+3YN86UE<W!A
M8V5S6R=N<R<@+B`D;ET@/2`D;F%M97-P86-E.PH@("`@("`@("1T:&ES+3YN
M<ULD;F%M97-P86-E72`]("1A='1R.PH@("`@("`@(')E='5R;B`D871T<CL*
M("`@('T*"B`@("!F=6YC=&EO;B!?=F%L:61A=&53=')I;F<H)'-T<FEN9RD*
M("`@('L*("`@("`@("`O+R!86%@@=&AI<R!S:&]U;&0@8F4@9&]N92!S;V]N
M97(@;W(@;&%T97(*("`@("`@("`O+R!R971U<FX@=')U93L*("`@("`@("!R
M971U<FX@<')E9U]M871C:"@B+UY;7'=?.B-<+UTK)"\B+"`D<W1R:6YG*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!?861D07)G*"8D87)G<RP@)B1A<F=A<G)A
M>2P@)&%R9VYA;64I"B`@("!["B`@("`@("`@:68@*"1A<F=S*2!["B`@("`@
M("`@("`@("1A<F=S("X]("<L("<["B`@("`@("`@?0H@("`@("`@("1A<F=S
M("X](")<)"(@+B`D87)G;F%M93L*("`@("`@("!I9B`H(21T:&ES+3Y?=F%L
M:61A=&53=')I;F<H)&%R9VYA;64I*2!["B`@("`@("`@("`@(')E='5R;B!N
M=6QL.PH@("`@("`@('T*("`@("`@("!I9B`H)&%R9V%R<F%Y*2!["B`@("`@
M("`@("`@("1A<F=A<G)A>2`N/2`G+"`G.PH@("`@("`@('T*("`@("`@("`D
M87)G87)R87D@+CT@(B<D87)G;F%M92<@/3X@7"0B("X@)&%R9VYA;64["B`@
M("!]"@H@("`@9G5N8W1I;VX@7V5L96UE;G1!<F<H)B1A<F=S+"`F)&%R9V%R
M<F%Y+"`F)%]A<F=T>7!E+"`D7V%R9VYA;64I"B`@("!["B`@("`@("`@)&-O
M;6UE;G1S(#T@)R<["B`@("`@("`@)&5L(#T@)'1H:7,M/F5L96UE;G1S6R1?
M87)G='EP95LG;F%M97-P86-E)UU=6R1?87)G='EP95LG='EP92==73L*("`@
M("`@("`D=&YS(#T@:7-S970H)'1H:7,M/FYS6R1E;%LG;F%M97-P86-E)UU=
M*2`_("1T:&ES+3YN<ULD96Q;)VYA;65S<&%C92==72`Z("1?87)G='EP95LG
M;F%M97-P86-E)UT["@H@("`@("`@(&EF("@A96UP='DH)&5L6R=C;VUP;&5X
M)UTI('Q\("AI<W-E="@D96Q;)W1Y<&4G72D@)B8@:7-S970H)'1H:7,M/F-O
M;7!L97A4>7!E<ULD=&YS75LD96Q;)W1Y<&4G75TI*2D@>PH@("`@("`@("`@
M("`O+R!4:&4@96QE;65N="!I<R!A(&-O;7!L97@@='EP92X*("`@("`@("`@
M("`@)&-O;6UE;G1S("X]("(@("`@("`@("\O('LD7V%R9W1Y<&5;)W1Y<&4G
M77T@:7,@82!#;VUP;&5X5'EP92P@<F5F97(@=&\@=&AE(%=31$P@9F]R(&UO
M<F4@:6YF;RY<;B(["B`@("`@("`@("`@("1A='1R;F%M92`](")[)%]A<F=T
M>7!E6R=T>7!E)UU]7V%T='(B.PH@("`@("`@("`@("!I9B`H:7-S970H)&5L
M6R=T>7!E)UTI("8F(&ES<V5T*"1T:&ES+3YC;VUP;&5X5'EP97-;)'1N<UU;
M)&5L6R=T>7!E)UU=6R=A='1R:6)U=&4G72DI('L*("`@("`@("`@("`@("`@
M("1C;VUM96YT<R`N/2`B("`@("`@("`O+R![)%]A<F=T>7!E6R=T>7!E)UU]
M(&UA>2!R97%U:7)E(&%T=')I8G5T97,L(')E9F5R('1O('1H92!74T1,(&9O
M<B!M;W)E(&EN9F\N7&XB.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1C
M;VUM96YT<R`N/2`B("`@("`@("!<)'LD871T<FYA;65]6R=X;6QN<R==(#T@
M)WLD=&AI<RT^;F%M97-P86-E<ULD7V%R9W1Y<&5;)VYA;65S<&%C92==77TG
M.UQN(CL*("`@("`@("`@("`@)&-O;6UE;G1S("X]("(@("`@("`@(%PD>R1?
M87)G='EP95LG='EP92==?2`])B!N97<@4T]!4%]686QU92@G>R1?87)G='EP
M95LG='EP92==?2<L(&9A;'-E+"!<)'LD7V%R9W1Y<&5;)W1Y<&4G77TL(%PD
M)&%T=')N86UE*3M<;B(["B`@("`@("`@("`@("1T:&ES+3Y?861D07)G*"1A
M<F=S+"`D87)G87)R87DL("1?87)G='EP95LG='EP92==*3L*("`@("`@("`@
M("`@:68@*&ES<V5T*"1E;%LG='EP92==*2`F)B!I<W-E="@D=&AI<RT^8V]M
M<&QE>%1Y<&5S6R1T;G-=6R1E;%LG='EP92==75LG871T<FEB=71E)UTI*2![
M"B`@("`@("`@("`@("`@("!I9B`H)&%R9W,I('L*("`@("`@("`@("`@("`@
M("`@("`D87)G<R`N/2`G+"`G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@)&%R9W,@+CT@)R0G("X@)&%T=')N86UE.PH@("`@("`@("`@
M("!]"B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1E;%LG96QE;65N=',G72DI
M('L*("`@("`@("`@("`@9F]R96%C:"`H)&5L6R=E;&5M96YT<R==(&%S("1E
M;F%M92`]/B`D96QE;65N="D@>PH@("`@("`@("`@("`@("`@)&-O;6UE;G1S
M("X]("(@("`@("`@(%PD)&5N86UE(#TF(&YE=R!33T%07U9A;'5E*"=[>R1T
M:&ES+3YN86UE<W!A8V5S6R1E;&5M96YT6R=N86UE<W!A8V4G75U]?21E;F%M
M92<L("<B("X*("`@("`@("`@("`@("`@("`@("`H:7-S970H)&5L96UE;G1;
M)W1Y<&4G72D@/R`D96QE;65N=%LG='EP92==(#H@9F%L<V4I("X@(B<L(%PD
M)&5N86UE*3M<;B(["B`@("`@("`@("`@("`@("`D=&AI<RT^7V%D9$%R9R@D
M87)G<RP@)&%R9V%R<F%Y+"`D96YA;64I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&-O;6UE;G1S("X]("(@("`@("`@
M(%PD)%]A<F=N86UE(#TF(&YE=R!33T%07U9A;'5E*"=[>R1T:&ES+3YN86UE
M<W!A8V5S6R1T;G-=?7TD7V%R9VYA;64G+"`G>R1E;%LG='EP92==?2<L(%PD
M)%]A<F=N86UE*3M<;B(["B`@("`@("`@("`@("1T:&ES+3Y?861D07)G*"1A
M<F=S+"`D87)G87)R87DL("1?87)G;F%M92D["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)&-O;6UE;G1S.PH@("`@?0H*("`@(&9U;F-T:6]N(%]C;VUP
M;&5X5'EP94%R9R@F)&%R9W,L("8D87)G87)R87DL("8D7V%R9W1Y<&4L("1?
M87)G;F%M92D*("`@('L*("`@("`@("`D8V]M;65N=',@/2`G)SL*("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/F-O;7!L97A4>7!E<ULD7V%R9W1Y<&5;)VYA
M;65S<&%C92==75LD7V%R9W1Y<&5;)W1Y<&4G75TI*2!["B`@("`@("`@("`@
M("1C;VUM96YT<R`@/2`B("`@("`@("`O+R`D7V%R9VYA;64@:7,@82!#;VUP
M;&5X5'EP92![)%]A<F=T>7!E6R=T>7!E)UU]+%QN(CL*("`@("`@("`@("`@
M)&-O;6UE;G1S("X]("(@("`@("`@("\O(')E9F5R('1O('=S9&P@9F]R(&UO
M<F4@:6YF;UQN(CL*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YC;VUP
M;&5X5'EP97-;)%]A<F=T>7!E6R=N86UE<W!A8V4G75U;)%]A<F=T>7!E6R=T
M>7!E)UU=6R=A='1R:6)U=&4G72DI('L*("`@("`@("`@("`@("`@("1C;VUM
M96YT<R`N/2`B("`@("`@("`O+R`D7V%R9VYA;64@;6%Y(')E<75I<F4@871T
M<FEB=71E<RP@<F5F97(@=&\@=W-D;"!F;W(@;6]R92!I;F9O7&XB.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1W<F%P;F%M92`]("=[)R`N("1T:&ES
M+3YN86UE<W!A8V5S6R1?87)G='EP95LG;F%M97-P86-E)UU=+B=])R`N("1?
M87)G='EP95LG='EP92==.PH@("`@("`@("`@("`D8V]M;65N=',@+CT@(B`@
M("`@("`@7"0D7V%R9VYA;64@/28@;F5W(%-/05!?5F%L=64H)R1?87)G;F%M
M92<L("<D=W)A<&YA;64G+"!<)"1?87)G;F%M92D[7&XB.PH@("`@("`@('T*
M"B`@("`@("`@)'1H:7,M/E]A9&1!<F<H)&%R9W,L("1A<F=A<G)A>2P@)%]A
M<F=N86UE*3L*("`@("`@("!R971U<FX@)&-O;6UE;G1S.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1V5N97)A=&5S('-T=6(@8V]D92!F<F]M('1H92!74T1,
M('1H870@8V%N(&)E('-A=F5D('1O(&$@9FEL90H@("`@("H@;W(@979A;"=D
M(&EN=&\@97AI<W1E;F-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G96YE<F%T
M95!R;WAY0V]D92@D<&]R="`]("<G+"`D8VQA<W-N86UE/2<G*0H@("`@>PH@
M("`@("`@("1M=6QT:7!O<G0@/2!C;W5N="@D=&AI<RT^<V5R=FEC97-;)'1H
M:7,M/G-E<G9I8V5=6R=P;W)T<R==*2`^(#$["B`@("`@("`@:68@*"$D<&]R
M="D@>PH@("`@("`@("`@("!R97-E="@D=&AI<RT^<V5R=FEC97-;)'1H:7,M
M/G-E<G9I8V5=6R=P;W)T<R==*3L*("`@("`@("`@("`@)'!O<G0@/2!C=7)R
M96YT*"1T:&ES+3YS97)V:6-E<ULD=&AI<RT^<V5R=FEC95U;)W!O<G1S)UTI
M.PH@("`@("`@('T*("`@("`@("`O+R!86%@@8W5R<F5N=&QY(&1O(&YO="!S
M=7!P;W)T($A45%`@<&]R=',*("`@("`@("!I9B`H)'!O<G1;)W1Y<&4G72`A
M/2`G<V]A<"<I('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@
M?0H*("`@("`@("`O+R!86%@@8W5R<F5N=%!O<G0@:7,@0D%$"B`@("`@("`@
M)&-L:65N='5R;"`]("1P;W)T6R=A9&1R97-S)UU;)VQO8V%T:6]N)UT["B`@
M("`@("`@:68@*"$D8VQA<W-N86UE*2!["B`@("`@("`@("`@(&EF("@D;75L
M=&EP;W)T('Q\("1P;W)T*2!["B`@("`@("`@("`@("`@("`D8VQA<W-N86UE
M(#T@)U=E8E-E<G9I8V5?)R`N("1T:&ES+3YS97)V:6-E("X@)U\G("X@)'!O
M<G1;)VYA;64G73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1C;&%S<VYA;64@/2`G5V5B4V5R=FEC95\G("X@)'1H:7,M/G-E<G9I
M8V4["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&-L87-S;F%M92`]('!R
M96=?<F5P;&%C92@G+UL@+EPM7"A<*5TK+R<L("=?)RP@)&-L87-S;F%M92D[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H(21T:&ES+3Y?=F%L:61A=&53=')I
M;F<H)&-L87-S;F%M92DI('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@
M("`@("`@?0H*("`@("`@("!I9B`H:7-?87)R87DH)'1H:7,M/G!R;WAY*2`F
M)B!C;W5N="@D=&AI<RT^<')O>'DI*2!["B`@("`@("`@("`@("1C;&%S<R`]
M(")C;&%S<R`D8VQA<W-N86UE(&5X=&5N9',@4T]!4%]#;&EE;G1<;GM<;B(@
M+@H@("`@("`@("`@("`B("`@(&9U;F-T:6]N("1C;&%S<VYA;64H7"1P871H
M(#T@)R1C;&EE;G1U<FPG*5QN("`@('M<;B(@+@H@("`@("`@("`@("`B("`@
M("`@("!<)'1H:7,M/E-/05!?0VQI96YT*%PD<&%T:"P@,"P@,"Q<;B(@+@H@
M("`@("`@("`@("`G("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH
M)SL*"B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YP<F]X>2!A<R`D:V5Y
M(#T^("1V86PI('L*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D=F%L
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1C;&%S<R`N/2`B)R1K97DG(#T^
M(&%R<F%Y*"(["B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'9A;"!A
M<R`D:V5Y,B`]/B`D=F%L,BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M8VQA<W,@+CT@(B<D:V5Y,B<@/3X@)R1V86PR)RP@(CL*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&-L87-S("X]("<I)SL*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M)&-L87-S("X]("(G)&ME>2<@/3X@)R1V86PG+"`B.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1C;&%S<R`N/2`B*2D[
M7&X@("`@?5QN(CL*("`@("`@("`@("`@)&-L87-S(#T@<W1R7W)E<&QA8V4H
M)RP@*2DG+"`G*2DG+"`D8VQA<W,I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1C;&%S<R`](")C;&%S<R`D8VQA<W-N86UE(&5X=&5N9',@4T]!
M4%]#;&EE;G1<;GM<;B(@+@H@("`@("`@("`@("`B("`@(&9U;F-T:6]N("1C
M;&%S<VYA;64H7"1P871H(#T@)R1C;&EE;G1U<FPG*5QN("`@('M<;B(@+@H@
M("`@("`@("`@("`B("`@("`@("!<)'1H:7,M/E-/05!?0VQI96YT*%PD<&%T
M:"P@,"D[7&XB("X*("`@("`@("`@("`@(B`@("!]7&XB.PH@("`@("`@('T*
M"B`@("`@("`@+R\@9V5T('1H92!B:6YD:6YG+"!F<F]M('1H870@9V5T('1H
M92!P;W)T('1Y<&4*("`@("`@("`D<')I;6%R>4)I;F1I;F<@/2`D<&]R=%LG
M8FEN9&EN9R==.R`O+R1T:&ES+3YS97)V:6-E<ULD=&AI<RT^<V5R=FEC95U;
M)W!O<G1S)UU;)'!O<G1;)VYA;64G75U;(F)I;F1I;F<B73L*("`@("`@("`D
M<')I;6%R>4)I;F1I;F<@/2!P<F5G7W)E<&QA8V4H(B]>*"XJ.BDO(BP@)R<L
M("1P<FEM87)Y0FEN9&EN9RD["B`@("`@("`@)'!O<G14>7!E(#T@)'1H:7,M
M/F)I;F1I;F=S6R1P<FEM87)Y0FEN9&EN9UU;)W1Y<&4G73L*("`@("`@("`D
M<&]R=%1Y<&4@/2!P<F5G7W)E<&QA8V4H(B]>*"XJ.BDO(BP@)R<L("1P;W)T
M5'EP92D["B`@("`@("`@)'-T>6QE(#T@)'1H:7,M/F)I;F1I;F=S6R1P<FEM
M87)Y0FEN9&EN9UU;)W-T>6QE)UT["@H@("`@("`@("\O(%A86"!C=7)R96YT
M4&]R=%1Y<&4@:7,@0D%$"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/G!O<G14
M>7!E<ULD<&]R=%1Y<&5=(&%S("1O<&YA;64@/3X@)&]P97)A=&EO;BD@>PH@
M("`@("`@("`@("`D<V]A<&%C=&EO;B`](&ES<V5T*"1T:&ES+3YB:6YD:6YG
M<ULD<')I;6%R>4)I;F1I;F==6R=O<&5R871I;VYS)UU;)&]P;F%M95U;)W-O
M87!!8W1I;VXG72D@/PH@("`@("`@("`@("`@("`@)'1H:7,M/F)I;F1I;F=S
M6R1P<FEM87)Y0FEN9&EN9UU;)V]P97)A=&EO;G,G75LD;W!N86UE75LG<V]A
M<$%C=&EO;B==(#H*("`@("`@("`@("`@("`@(&YU;&P["B`@("`@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^8FEN9&EN9W-;)'!R:6UA<GE":6YD:6YG75LG
M;W!E<F%T:6]N<R==6R1O<&YA;65=6R=S='EL92==*2D@>PH@("`@("`@("`@
M("`@("`@)&]P<W1Y;&4@/2`D=&AI<RT^8FEN9&EN9W-;)'!R:6UA<GE":6YD
M:6YG75LG;W!E<F%T:6]N<R==6R1O<&YA;65=6R=S='EL92==.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&]P<W1Y;&4@/2`D<W1Y
M;&4["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'5S92`]("1T:&ES+3YB
M:6YD:6YG<ULD<')I;6%R>4)I;F1I;F==6R=O<&5R871I;VYS)UU;)&]P;F%M
M95U;)VEN<'5T)UU;)W5S92==.PH@("`@("`@("`@("!I9B`H)'5S92`]/2`G
M96YC;V1E9"<I('L*("`@("`@("`@("`@("`@("1N86UE<W!A8V4@/2`D=&AI
M<RT^8FEN9&EN9W-;)'!R:6UA<GE":6YD:6YG75LG;W!E<F%T:6]N<R==6R1O
M<&YA;65=6R=I;G!U="==6R=N86UE<W!A8V4G73L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1B:6YD:6YG5'EP92`]("1T:&ES+3YB
M:6YD:6YG<ULD<')I;6%R>4)I;F1I;F==6R=T>7!E)UT["B`@("`@("`@("`@
M("`@("`D;G,@/2`D=&AI<RT^<&]R=%1Y<&5S6R1B:6YD:6YG5'EP95U;)&]P
M;F%M95U;)VEN<'5T)UU;)VYA;65S<&%C92==.PH@("`@("`@("`@("`@("`@
M)&YA;65S<&%C92`]("1T:&ES+3YN86UE<W!A8V5S6R1N<UT["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("1A<F=S(#T@)R<["B`@("`@("`@("`@("1A
M<F=A<G)A>2`]("<G.PH@("`@("`@("`@("`D8V]M;65N=',@/2`G)SL*("`@
M("`@("`@("`@)'=R87!P97)S(#T@)R<["B`@("`@("`@("`@(&9O<F5A8V@@
M*"1O<&5R871I;VY;)VEN<'5T)UT@87,@)&%R9VYA;64@/3X@)&%R9W1Y<&4I
M('L*("`@("`@("`@("`@("`@(&EF("@D87)G;F%M92`]/2`G;65S<V%G92<I
M('L*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^;65S<V%G
M97-;)&%R9W1Y<&5=(&%S("1?87)G;F%M92`]/B`D7V%R9W1Y<&4I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"1O<'-T>6QE(#T]("=D;V-U;65N
M="<@)B8@)'5S92`]/2`G;&ET97)A;"<@)B8*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1?87)G='EP95LG;F%M92==(#T]("=P87)A;65T97)S)RD@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@5&AE('1Y<&4@;W(@
M96QE;65N="!R969E<F5D('1O(&ES('5S960*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("\O(&9O<B!P87)A;65T97)S+@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&5L871T<G,@/2!N=6QL.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&5L96UE;G0@/2`D7V%R9W1Y<&5;)V5L96UE;G0G73L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E;"`]("1T:&ES+3YE;&5M
M96YT<ULD7V%R9W1Y<&5;)VYA;65S<&%C92==75LD7V%R9W1Y<&5;)W1Y<&4G
M75T["@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1E;%LG8V]M
M<&QE>"==*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YA
M;65S<&%C92`]("1T:&ES+3YN86UE<W!A8V5S6R1?87)G='EP95LG;F%M97-P
M86-E)UU=.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(%A8
M6"!N965D('1O('=R87`@=&AE('!A<F%M971E<G,@:6X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`O+R!A('-O87!?=F%L=64N"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)&5L6R=E;&5M96YT<R==*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1E;%LG96QE;65N=',G
M72!A<R`D96QN86UE(#T^("1E;&%T=')S*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("\O($ES('1H92!E;&5M96YT(&$@8V]M<&QE
M>"!T>7!E/PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/F-O;7!L97A4>7!E<ULD96QA='1R<ULG;F%M97-P
M86-E)UU=6R1E;&YA;65=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&-O;6UE;G1S("X]("1T:&ES+3Y?8V]M<&QE>%1Y
M<&5!<F<H)&%R9W,L("1A<F=A<G)A>2P@)%]A<F=T>7!E+"`D7V%R9VYA;64I
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]A9&1!<F<H)&%R9W,L("1A<F=A<G)A>2P@)&5L;F%M92D["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&5L6R=C
M;VUP;&5X)UT@)B8@)&%R9V%R<F%Y*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'=R87!N86UE(#T@)WLG("X@)'1H:7,M/FYA;65S<&%C
M97-;)%]A<F=T>7!E6R=N86UE<W!A8V4G75TN)WTG("X@)&5L6R=N86UE)UT[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O;6UE;G1S("X]
M("(@("`@("`@(%PD>R1E;%LG;F%M92==?2`])B!N97<@4T]!4%]686QU92@G
M)'=R87!N86UE)RP@9F%L<V4L(%PD=B`](&%R<F%Y*"1A<F=A<G)A>2DI.UQN
M(CL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D87)G87)R87D@
M/2`B)WLD96Q;)VYA;64G77TG(#T^(%PD>R1E;%LG;F%M92==?2(["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)%]A<F=T>7!E6R=E;&5M96YT)UTI*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@16QE;65N="!A<F=U;65N="X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]M;65N=',@+CT@)'1H:7,M
M/E]E;&5M96YT07)G*"1A<F=S+"`D87)G87)R87DL("1?87)G='EP92P@)%]A
M<F=T>7!E6R=T>7!E)UTI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!#
M;VUP;&5X('1Y<&4@87)G=6UE;G0N"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&-O;6UE;G1S("X]("1T:&ES+3Y?8V]M<&QE>%1Y<&5!<F<H
M)&%R9W,L("1A<F=A<G)A>2P@)%]A<F=T>7!E+"`D7V%R9VYA;64I.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!686QI9&%T92!E;G1R
M:65S+@H*("`@("`@("`@("`@+R\@3W!E<F%T:6]N(&YA;65S(&%R92!F=6YC
M=&EO;B!N86UE<RP@<V\@=')Y('1O(&UA:V4@<W5R90H@("`@("`@("`@("`O
M+R!I="=S(&QE9V%L+B!4:&ES(&-O=6QD('!O=&5N=&EA;&QY(&-A=7-E(&-O
M;&QI<VEO;G,L"B`@("`@("`@("`@("\O(&)U="!L970G<R!T<GD@=&\@;6%K
M92!E=F5R>71H:6YG(&-A;&QA8FQE(&%N9"!S964@:&]W"B`@("`@("`@("`@
M("\O(&UA;GD@<')O8FQE;7,@=&AA="!C875S97,N"B`@("`@("`@("`@("1O
M<&YA;65?<&AP(#T@<')E9U]R97!L86-E*"<O6R`N7"U<*%PI72LO)RP@)U\G
M+"`D;W!N86UE*3L*("`@("`@("`@("`@:68@*"$D=&AI<RT^7W9A;&ED871E
M4W1R:6YG*"1O<&YA;65?<&AP*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(&YU;&P["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D87)G87)R
M87DI('L*("`@("`@("`@("`@("`@("1A<F=A<G)A>2`](")A<G)A>2@D87)G
M87)R87DI(CL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1A<F=A<G)A>2`]("=N=6QL)SL*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@)&-L87-S("X]("(@("`@9G5N8W1I;VX@)B1O<&YA;65?<&AP*"1A<F=S
M*5QN("`@('M<;B1C;VUM96YT<R1W<F%P<&5R<R(@+@H@("`@("`@("`@("`@
M("`@(B`@("`@("`@<F5T=7)N(%PD=&AI<RT^8V%L;"@G)&]P;F%M92<L7&XB
M("X*("`@("`@("`@("`@("`@("(@("`@("`@("`@("`@("`@("`@("`@("`@
M("!<)'8@/2`D87)G87)R87DL7&XB("X*("`@("`@("`@("`@("`@("(@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G;F%M97-P86-E)R`]/B`G
M)&YA;65S<&%C92<L7&XB("X*("`@("`@("`@("`@("`@("(@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G<V]A<&%C=&EO;B<@/3X@)R1S;V%P
M86-T:6]N)RQ<;B(@+@H@("`@("`@("`@("`@("`@(B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=S='EL92<@/3X@)R1O<'-T>6QE)RQ<;B(@
M+@H@("`@("`@("`@("`@("`@(B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=U<V4G(#T^("<D=7-E)R(@+@H@("`@("`@("`@("`@("`@*"1T
M:&ES+3YT<F%C93\B+%QN("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W1R86-E)R`]/B`Q(B`Z("<G*2`N("(I*3M<;B(@+@H@("`@("`@("`@
M("`@("`@(B`@("!]7&XB.PH@("`@("`@('T*"B`@("`@("`@)&-L87-S("X]
M(")]7&XB.PH@("`@("`@(')E='5R;B`D8VQA<W,["B`@("!]"@H@("`@9G5N
M8W1I;VX@9V5N97)A=&5!;&Q0<F]X:65S*"D*("`@('L*("`@("`@("`D<')O
M>'EC;V1E(#T@)R<["B`@("`@("`@9F]R96%C:"`H87)R87E?:V5Y<R@D=&AI
M<RT^<V5R=FEC97-;)'1H:7,M/G-E<G9I8V5=6R=P;W)T<R==*2!A<R`D:V5Y
M*2!["B`@("`@("`@("`@("1P;W)T(#TF("1T:&ES+3YS97)V:6-E<ULD=&AI
M<RT^<V5R=FEC95U;)W!O<G1S)UU;)&ME>5T["B`@("`@("`@("`@("1P<F]X
M>6-O9&4@+CT@)'1H:7,M/F=E;F5R871E4')O>'E#;V1E*"1P;W)T*3L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("1P<F]X>6-O9&4["B`@("!]"@H@("`@
M9G5N8W1I;VX@)F=E=%!R;WAY*"1P;W)T(#T@)R<L("1N86UE(#T@)R<I"B`@
M("!["B`@("`@("`@)&UU;'1I<&]R="`](&-O=6YT*"1T:&ES+3YS97)V:6-E
M<ULD=&AI<RT^<V5R=FEC95U;)W!O<G1S)UTI(#X@,3L*"B`@("`@("`@:68@
M*"$D<&]R="D@>PH@("`@("`@("`@("!R97-E="@D=&AI<RT^<V5R=FEC97-;
M)'1H:7,M/G-E<G9I8V5=6R=P;W)T<R==*3L*("`@("`@("`@("`@)'!O<G0@
M/2!C=7)R96YT*"1T:&ES+3YS97)V:6-E<ULD=&AI<RT^<V5R=FEC95U;)W!O
M<G1S)UTI.PH@("`@("`@('T*"B`@("`@("`@:68@*"1M=6QT:7!O<G0@?'P@
M)'!O<G0I('L*("`@("`@("`@("`@)&-L87-S;F%M92`]("=796)397)V:6-E
M7R<@+B`D=&AI<RT^<V5R=FEC92`N("=?)R`N("1P;W)T6R=N86UE)UT["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&-L87-S;F%M92`]("=796)3
M97)V:6-E7R<@+B`D=&AI<RT^<V5R=FEC93L*("`@("`@("!]"@H@("`@("`@
M(&EF("@D;F%M92D@>PH@("`@("`@("`@("`D8VQA<W-N86UE(#T@)&YA;64@
M+B`G7R<@+B`D8VQA<W-N86UE.PH@("`@("`@('T*"B`@("`@("`@)&-L87-S
M;F%M92`]('!R96=?<F5P;&%C92@G+UL@+EPM7"A<*5TK+R<L("=?)RP@)&-L
M87-S;F%M92D["B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)&-L87-S;F%M
M92DI('L*("`@("`@("`@("`@)'!R;WAY(#T@)'1H:7,M/F=E;F5R871E4')O
M>'E#;V1E*"1P;W)T+"`D8VQA<W-N86UE*3L*("`@("`@("`@("`@<F5Q=6ER
M95]O;F-E("=33T%0+T-L:65N="YP:'`G.PH@("`@("`@("`@("!E=F%L*"1P
M<F]X>2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@;F5W("1C;&%S<VYA
M;64["B`@("!]"@H@("`@9G5N8W1I;VX@)E]G971#;VUP;&5X5'EP949O<D5L
M96UE;G0H)&YA;64L("1N86UE<W!A8V4I"B`@("!["B`@("`@("`@)'0@/2!N
M=6QL.PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^;G-;)&YA;65S<&%C95TI
M("8F"B`@("`@("`@("`@(&ES<V5T*"1T:&ES+3YE;&5M96YT<ULD=&AI<RT^
M;G-;)&YA;65S<&%C95U=6R1N86UE75LG='EP92==*2D@>PH*("`@("`@("`@
M("`@)'1Y<&4@/2`D=&AI<RT^96QE;65N='-;)'1H:7,M/FYS6R1N86UE<W!A
M8V5=75LD;F%M95U;)W1Y<&4G73L*("`@("`@("`@("`@)&YS(#T@)'1H:7,M
M/F5L96UE;G1S6R1T:&ES+3YN<ULD;F%M97-P86-E75U;)&YA;65=6R=N86UE
M<W!A8V4G73L*"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^8V]M<&QE
M>%1Y<&5S6R1N<UU;)'1Y<&5=*2D@>PH@("`@("`@("`@("`@("`@)'0@/2`D
M=&AI<RT^8V]M<&QE>%1Y<&5S6R1N<UU;)'1Y<&5=.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=#L*("`@('T*"B`@("!F=6YC
M=&EO;B!G971#;VUP;&5X5'EP94YA;65&;W)%;&5M96YT*"1N86UE+"`D;F%M
M97-P86-E*0H@("`@>PH@("`@("`@("1T(#T@)'1H:7,M/E]G971#;VUP;&5X
M5'EP949O<D5L96UE;G0H)&YA;64L("1N86UE<W!A8V4I.PH@("`@("`@(&EF
M("@D="D@>PH@("`@("`@("`@("!R971U<FX@)'1;)VYA;64G73L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N(&YU;&P["B`@("!]"@H@("`@9G5N8W1I;VX@
M9V5T0V]M<&QE>%1Y<&5#:&EL9%1Y<&4H)&YS+"`D;F%M92P@)&-H:6QD7VYS
M+"`D8VAI;&1?;F%M92D*("`@('L*("`@("`@("`O+R!I<R!T:&4@='EP92!A
M;B!E;&5M96YT/PH@("`@("`@("1T(#T@)'1H:7,M/E]G971#;VUP;&5X5'EP
M949O<D5L96UE;G0H)&YA;64L("1N<RD["B`@("`@("`@:68@*"1T*2!["B`@
M("`@("`@("`@("\O(&YO+"!G970@:70@9G)O;2!C;VUP;&5X('1Y<&5S(&1I
M<F5C=&QY"B`@("`@("`@("`@(&EF("AI<W-E="@D=%LG96QE;65N=',G75LD
M8VAI;&1?;F%M95U;)W1Y<&4G72DI"B`@("`@("`@("`@("`@("!R971U<FX@
M)'1;)V5L96UE;G1S)UU;)&-H:6QD7VYA;65=6R=T>7!E)UT["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B!N=6QL.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E
M=%-C:&5M851Y<&4H)'1Y<&4L("1N86UE+"`D='EP95]N86UE<W!A8V4I"B`@
M("!["B`@("`@("`@+R\@<V5E(&EF(&ET)W,@82!C;VUP;&5X('1Y<&4@<V\@
M=V4@8V%N(&1E86P@<')O<&5R;'D@=VET:`H@("`@("`@("\O(%-/05!%3D,Z
M87)R87E4>7!E+@H@("`@("`@(&EF("@D;F%M92`F)B`D='EP92D@>PH@("`@
M("`@("`@("`O+R!86%@@5$]$3SH*("`@("`@("`@("`@+R\@;&]O:R!U<"!T
M:&4@;F%M92!I;B!T:&4@=W-D;"!A;F0@=F%L:61A=&4@=&AE('1Y<&4N"B`@
M("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YC;VUP;&5X5'EP97,@87,@)&YS
M(#T^("1T>7!E<RD@>PH@("`@("`@("`@("`@("`@:68@*&%R<F%Y7VME>5]E
M>&ES=',H)'1Y<&4L("1T>7!E<RDI('L*("`@("`@("`@("`@("`@("`@("!I
M9B`H87)R87E?:V5Y7V5X:7-T<R@G='EP92<L("1T>7!E<ULD='EP95TI*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@(&QI<W0H)&%R<F%Y='EP95]N<RP@
M)&%R<F%Y='EP92P@)&%R<F%Y7V1E<'1H*2`](&ES<V5T*"1T>7!E<ULD='EP
M95U;)V%R<F%Y5'EP92==*3\*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?9V5T1&5E<&5S=$%R<F%Y5'EP92@D='EP97-;)'1Y<&5=6R=N
M86UE<W!A8V4G72P@)'1Y<&5S6R1T>7!E75LG87)R87E4>7!E)UTI"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`Z(&%R<F%Y*"1T:&ES+3YN86UE<W!A
M8V5S6R1T>7!E<ULD='EP95U;)VYA;65S<&%C92==72P@;G5L;"P@,"D["B`@
M("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>2@D='EP97-;)'1Y
M<&5=6R=T>7!E)UTL("1A<G)A>71Y<&4L("1A<G)A>71Y<&5?;G,L("1A<G)A
M>5]D97!T:"D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"=A<G)A>51Y<&4G+"`D='EP
M97-;)'1Y<&5=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!L:7-T*"1A
M<G)A>71Y<&5?;G,L("1A<G)A>71Y<&4L("1A<G)A>5]D97!T:"D@/0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G971$965P97-T07)R
M87E4>7!E*"1T>7!E<ULD='EP95U;)VYA;65S<&%C92==+"`D='EP97-;)'1Y
M<&5=6R=A<G)A>51Y<&4G72D["B`@("`@("`@("`@("`@("`@("`@("`@(')E
M='5R;B!A<G)A>2@G07)R87DG+"`D87)R87ET>7!E+"`D87)R87ET>7!E7VYS
M+"`D87)R87E?9&5P=&@I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@G96QE;65N=',G
M+"`D='EP97-;)'1Y<&5=*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>5]K97E?97AI<W1S*"1N86UE+"`D='EP97-;)'1Y<&5=6R=E;&5M96YT
M<R==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D='EP92`]("1T>7!E
M<ULD='EP95U;)V5L96UE;G1S)UU;)W1Y<&4G73L*("`@("`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N(&%R<F%Y*"1T>7!E+"!N=6QL+"`D=&AI<RT^;F%M
M97-P86-E<ULD='EP97-;)'1Y<&5=6R=N86UE<W!A8V4G75TL(&YU;&PI.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H)'1Y<&4@)B8@)'1Y<&5?
M;F%M97-P86-E*2!["B`@("`@("`@("`@("1A<G)A>51Y<&4@/2!N=6QL.PH@
M("`@("`@("`@("`O+R!86%@@5$]$3SH*("`@("`@("`@("`@+R\@=&AI<R!C
M;V1E(&-U<G)E;G1L>2!H86YD;&5S(&]N;'D@;VYE('=A>2!O9B!E;F-O9&EN
M9R!A<G)A>2!T>7!E<R!I;B!W<V1L"B`@("`@("`@("`@("\O(&YE960@=&\@
M9&\@82!G96YE<F%L:7IE9"!F=6YC=&EO;B!T;R!F:6=U<F4@;W5T(&-O;7!L
M97@@='EP97,*("`@("`@("`@("`@)'`@/2`D=&AI<RT^;G-;)'1Y<&5?;F%M
M97-P86-E73L*("`@("`@("`@("`@:68@*"1P("8F"B`@("`@("`@("`@("`@
M("!A<G)A>5]K97E?97AI<W1S*"1P+"`D=&AI<RT^8V]M<&QE>%1Y<&5S*2`F
M)@H@("`@("`@("`@("`@("`@87)R87E?:V5Y7V5X:7-T<R@D='EP92P@)'1H
M:7,M/F-O;7!L97A4>7!E<ULD<%TI*2!["B`@("`@("`@("`@("`@("!I9B`H
M)&%R<F%Y5'EP92`]("1T:&ES+3YC;VUP;&5X5'EP97-;)'!=6R1T>7!E75LG
M87)R87E4>7!E)UTI('L*("`@("`@("`@("`@("`@("`@("`D='EP92`]("=!
M<G)A>2<["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)'1H:7,M/F-O;7!L
M97A4>7!E<ULD<%U;)'1Y<&5=6R=O<F1E<B==/3TG<V5Q=65N8V4G("8F"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@87)R87E?:V5Y7V5X:7-T<R@G96QE
M;65N=',G+"`D=&AI<RT^8V]M<&QE>%1Y<&5S6R1P75LD='EP95TI*2!["B`@
M("`@("`@("`@("`@("`@("`@<F5S970H)'1H:7,M/F-O;7!L97A4>7!E<ULD
M<%U;)'1Y<&5=6R=E;&5M96YT<R==*3L*("`@("`@("`@("`@("`@("`@("`O
M+R!A<W-U;64@86X@87)R87D*("`@("`@("`@("`@("`@("`@("!I9B`H8V]U
M;G0H)'1H:7,M/F-O;7!L97A4>7!E<ULD<%U;)'1Y<&5=6R=E;&5M96YT<R==
M*2`]/2`Q*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1A<F<@/2!C=7)R
M96YT*"1T:&ES+3YC;VUP;&5X5'EP97-;)'!=6R1T>7!E75LG96QE;65N=',G
M72D["B`@("`@("`@("`@("`@("`@("`@("`@("1A<G)A>51Y<&4@/2`D87)G
M6R=T>7!E)UT["B`@("`@("`@("`@("`@("`@("`@("`@("1T>7!E(#T@)T%R
M<F%Y)SL*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^8V]M<&QE>%1Y<&5S6R1P
M75LD='EP95U;)V5L96UE;G1S)UT@87,@)&5L96UE;G0I('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("@D96QE;65N=%LG;F%M92==(#T]("1T
M>7!E*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%R<F%Y
M5'EP92`]("1E;&5M96YT6R=T>7!E)UT["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1Y<&4@/2`D96QE;65N=%LG='EP92==.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`D='EP92`]("=3=')U8W0G.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y
M*"1T>7!E+"`D87)R87E4>7!E+"`D='EP95]N86UE<W!A8V4L(&YU;&PI.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!A<G)A>2AN
M=6QL+"!N=6QL+"!N=6QL+"!N=6QL*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E8W5R<V4@=&AR;W5G:"!T:&4@5U-$3"!S=')U8W1U<F4@;&]O:VEN9R!F
M;W(@=&AE(&EN;F5R;6]S=`H@("`@("H@87)R87D@='EP92!O9B!M=6QT:2UD
M:6UE;G-I;VYA;"!A<G)A>7,N"B`@("`@*@H@("`@("H@5&%K97,@82!N86UE
M<W!A8V4@<')E9FEX(&%N9"!A('1Y<&4L('=H:6-H(&-A;B!B92!I;B!T:&4@
M9F]R;0H@("`@("H@)W1Y<&4G(&]R("=T>7!E6UTG+"!A;F0@<F5T=7)N<R!T
M:&4@9G5L;"!N86UE<W!A8V4@55))+"!T:&4*("`@("`J('1Y<&4@;V8@=&AE
M(&UO<W0@9&5E<&QY(&YE<W1E9"!A<G)A>2!T>7!E(&9O=6YD+"!A;F0@=&AE
M(&YU;6)E<@H@("`@("H@;V8@;&5V96QS(&]F(&YE<W1I;F<N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<F5T=7)N(&UI>&5D(&%R
M<F%Y(&]R(&YO=&AI;F<*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$1E97!E
M<W1!<G)A>51Y<&4H)&YS4')E9FEX+"`D87)R87E4>7!E*0H@("`@>PH@("`@
M("`@('-T871I8R`D=')A:6P@/2!A<G)A>2@I.PH*("`@("`@("`D87)R87E4
M>7!E(#T@97)E9U]R97!L86-E*"=<6UQ=)"<L("<G+"`D87)R87E4>7!E*3L*
M"B`@("`@("`@+R\@4')O=&5C="!A9V%I;G-T(&-I<F-U;&%R(')E9F5R96YC
M97,*("`@("`@("`O+R!86%@@5V4@<F5A;&QY(&YE960@=&\@<F5M;W9E('1R
M86EL(&9R;VT@=&AI<R!A;'1O9V5T:&5R("AI="=S('9E<GD@:6YE9F9I8VEE
M;G0@86YD"B`@("`@("`@+R\@:6X@=&AE('=R;VYG('!L86-E(2D@86YD('!U
M="!C:7)C=6QA<B!R969E<F5N8V4@8VAE8VMI;F<@:6X@=VAE;B!T:&4@5U-$
M3"!I;F9O"B`@("`@("`@+R\@:7,@9V5N97)A=&5D(&EN('1H92!F:7)S="!P
M;&%C90H@("`@("`@(&EF("AA<G)A>5]S96%R8V@H)&YS4')E9FEX("X@)SHG
M("X@)&%R<F%Y5'EP92P@)'1R86EL*2D@>PH@("`@("`@("`@("!R971U<FX@
M87)R87DH;G5L;"P@;G5L;"P@+6-O=6YT*"1T<F%I;"DI.PH@("`@("`@('T*
M"B`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)&YS4')E9FEX+"`D=&AI
M<RT^8V]M<&QE>%1Y<&5S*2`F)@H@("`@("`@("`@("!A<G)A>5]K97E?97AI
M<W1S*"1A<G)A>51Y<&4L("1T:&ES+3YC;VUP;&5X5'EP97-;)&YS4')E9FEX
M72D@)B8*("`@("`@("`@("`@87)R87E?:V5Y7V5X:7-T<R@G87)R87E4>7!E
M)RP@)'1H:7,M/F-O;7!L97A4>7!E<ULD;G-0<F5F:7A=6R1A<G)A>51Y<&5=
M*2D@>PH@("`@("`@("`@("`D=')A:6Q;72`]("1N<U!R969I>"`N("<Z)R`N
M("1A<G)A>51Y<&4["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V=E
M=$1E97!E<W1!<G)A>51Y<&4H)'1H:7,M/F-O;7!L97A4>7!E<ULD;G-0<F5F
M:7A=6R1A<G)A>51Y<&5=6R=N86UE<W!A8V4G72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8V]M
M<&QE>%1Y<&5S6R1N<U!R969I>%U;)&%R<F%Y5'EP95U;)V%R<F%Y5'EP92==
M*3L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"1R97-U;'1;,%TL("1R97-U
M;'1;,5TL("1R97-U;'1;,ET@*R`Q*3L*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N(&%R<F%Y*"1T:&ES+3YN86UE<W!A8V5S6R1N<U!R969I>%TL("1A<G)A
M>51Y<&4L(#`I.PH@("`@?0H*?0H*8VQA<W,@4T]!4%]74T1,7T-A8VAE(&5X
M=&5N9',@4T]!4%]"87-E"GL*("`@("\O($-A8VAE('-E='1I;F=S"@H@("`@
M+RHJ"B`@("`@*B!5<V4@5U-$3"!C86-H90H@("`@("H*("`@("`J($!V87(@
M8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]C86-H955S92`](&YU;&P["@H@
M("`@+RHJ"B`@("`@*B!#86-H92!M87@@;&EF971I;64@*&EN('-E8V]N9',I
M"B`@("`@*@H@("`@("H@0'9A<B!I;G0*("`@("`J+PH@("`@=F%R("1?8V%C
M:&5-87A!9V4@/2!N=6QL.PH*("`@("\J*@H@("`@("H@4T]!4%]74T1,7T-A
M8VAE(&-O;G-T<G5C=&]R"B`@("`@*@H@("`@("H@0'!A<F%M("!B;V]L96%N
M('5S92!C86-H:6YG"B`@("`@*B!`<&%R86T@(&EN="`@("`@8V%C:&4@;6%X
M(&QI9F5T:6UE("AI;B!S96-O;F1S*0H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@4T]!4%]74T1,7T-A8VAE*"1C86-H955S
M92`](%=31$Q?0T%#2$5?55-%+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1C86-H94UA>$%G92`](%=31$Q?0T%#2$5?34%87T%'12D*("`@('L*
M("`@("`@("!P87)E;G0Z.E-/05!?0F%S92@G5U-$3$-!0TA%)RD["B`@("`@
M("`@)'1H:7,M/E]C86-H955S92`]("1C86-H955S93L*("`@("`@("`D=&AI
M<RT^7V-A8VAE36%X06=E(#T@)&-A8VAE36%X06=E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@7V-A8VAE1&ER"B`@("`@*B!R971U<FX@=&AE('!A=&@@=&\@
M=&AE(&-A8VAE+"!I9B!I="!D;V5S;B=T(&5X:7-T+"!M86ME(&ET"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]C86-H941I<B@I"B`@("!["B`@("`@("`@)&1I
M<B`](&=E=&5N=B@B5U-$3$-!0TA%(BD["B`@("`@("`@:68@*"$D9&ER*2`D
M9&ER(#T@(B`N+W=S9&QC86-H92(["B`@("`@("`@0&UK9&ER*"1D:7(L(#`W
M,#`I.PH@("`@("`@(')E='5R;B`D9&ER.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T<FEE=F5S(&$@9FEL92!F<F]M(&-A8VAE(&EF(&ET(&5X:7-T<RP@
M;W1H97)W:7-E(')E=')E:79E(&9R;VT@;F5T+`H@("`@("H@861D('1O(&-A
M8VAE+"!A;F0@<F5T=7)N(&9R;VT@8V%C:&4N"B`@("`@*@H@("`@("H@0'!A
M<F%M("!S=')I;F<@("!54DP@=&\@5U-$3`H@("`@("H@0'!A<F%M("!A<G)A
M>2`@("!P<F]X>2!P87)A;65T97)S"B`@("`@*B!`<&%R86T@(&EN="`@("`@
M(&5X<&5C=&5D($U$-2!O9B!74T1,(%523`H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J($!R971U<FX@<W1R:6YG("!D871A"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E="@D=W-D;%]F;F%M92P@)'!R;WAY7W!A<F%M<R`](&%R<F%Y
M*"DL("1C86-H92`](#`I"B`@("!["B`@("`@("`@)&-A8VAE;F%M92`]("1M
M9#5?=W-D;"`]("1F:6QE7V1A=&$@/2`G)SL*("`@("`@("!I9B`H)'1H:7,M
M/E]C86-H955S92D@>PH@("`@("`@("`@("`O+R!4<GD@=&\@<F5T<FEE=F4@
M5U-$3"!F<F]M(&-A8VAE"B`@("`@("`@("`@("1C86-H96YA;64@/2!33T%0
M7U=31$Q?0V%C:&4Z.E]C86-H941I<B@I("X@)R\G("X@;60U*"1W<V1L7V9N
M86UE*2X@)R`N=W-D;"<["B`@("`@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D
M8V%C:&5N86UE*2D@>PH@("`@("`@("`@("`@("`@)'=F(#T@9F]P96XH)&-A
M8VAE;F%M92P@)W)B)RD["B`@("`@("`@("`@("`@("!I9B`H)'=F*2!["B`@
M("`@("`@("`@("`@("`@("`@+R\@4F5A9&EN9R!C86-H960@9FEL90H@("`@
M("`@("`@("`@("`@("`@("1F:6QE7V1A=&$@/2!F<F5A9"@D=V8L(&9I;&5S
M:7IE*"1C86-H96YA;64I*3L*("`@("`@("`@("`@("`@("`@("`D;60U7W=S
M9&P@/2!M9#4H)&9I;&5?9&%T82D["B`@("`@("`@("`@("`@("`@("`@9F-L
M;W-E*"1W9BD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I
M9B`H)&-A8VAE*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1C86-H92`A
M/2`D;60U7W=S9&PI('L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)U=31$P@0VAE8VMS=6T@97)R;W(A
M)RP@)'=S9&Q?9FYA;64I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&9I(#T@
M<W1A="@D8V%C:&5N86UE*3L*("`@("`@("`@("`@("`@("`@("`D8V%C:&5?
M;71I;64@/2`D9FE;.%T["B`@("`@("`@("`@("`@("`@("`@+R]P<FEN="!C
M86-H95]M=&EM92P@=&EM92@I"B`@("`@("`@("`@("`@("`@("`@:68@*"1C
M86-H95]M=&EM92`K("1T:&ES+3Y?8V%C:&5-87A!9V4@/"!T:6UE*"DI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@+R\@97AP:7)E9`H@("`@("`@("`@
M("`@("`@("`@("`@("`D;60U7W=S9&P@/2`G)SL@+R\@<F5F971C:`H@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"$D;60U7W=S9&PI('L*("`@
M("`@("`@("`@+R\@3F]T(&-A8VAE9"!O<B!N;W0@=7-I;F<@8V%C:&4N(%)E
M=')I979E(%=31$P@9G)O;2!54DP*"B`@("`@("`@("`@("\O(&ES(&ET(&$@
M;&]C86P@9FEL93\*("`@("`@("`@("`@+R\@=&AI<R!S96-T:6]N('-H;W5L
M9"!B92!R97!L86-E(&)Y(&-U<FP@870@<V]M92!P;VEN=`H@("`@("`@("`@
M("!I9B`H(7!R96=?;6%T8V@H)R]>*&AT='!S/WQF:6QE*3I<+UPO+R<L("1W
M<V1L7V9N86UE*2D@>PH@("`@("`@("`@("`@("`@:68@*"%F:6QE7V5X:7-T
M<R@D=W-D;%]F;F%M92DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/E]R86ES95-O87!&875L="@B56YA8FQE('1O(')E860@;&]C86P@
M5U-$3"`D=W-D;%]F;F%M92(L("1W<V1L7V9N86UE*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V9I
M;&5?9V5T7V-O;G1E;G1S)RDI('L*("`@("`@("`@("`@("`@("`@("`D9FEL
M95]D871A(#T@9FEL95]G971?8V]N=&5N=',H)'=S9&Q?9FYA;64I.PH@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D9FEL
M95]D871A(#T@:6UP;&]D92@G)RQF:6QE*"1W<V1L7V9N86UE*2D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D=7)I(#T@97AP;&]D92@G/R<L("1W<V1L7V9N86UE*3L*("`@("`@
M("`@("`@("`@("1R<2`])B!N97<@2%144%]297%U97-T*"1U<FE;,%TL("1P
M<F]X>5]P87)A;7,I.PH@("`@("`@("`@("`@("`@+R\@=&AE('5S97(@86=E
M;G0@2%144%]297%U97-T('5S97,@9F]U;',@=&AI;F=S('5P"B`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)'5R:5LQ72DI('L*("`@("`@("`@("`@("`@
M("`@("`D<G$M/F%D9%)A=U%U97)Y4W1R:6YG*"1U<FE;,5TI.PH@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<')O>'E?
M<&%R86US6R=P<F]X>5]H;W-T)UTI("8F"B`@("`@("`@("`@("`@("`@("`@
M:7-S970H)'!R;WAY7W!A<F%M<ULG<')O>'E?<&]R="==*2`F)@H@("`@("`@
M("`@("`@("`@("`@(&ES<V5T*"1P<F]X>5]P87)A;7-;)W!R;WAY7W5S97(G
M72D@)B8*("`@("`@("`@("`@("`@("`@("!I<W-E="@D<')O>'E?<&%R86US
M6R=P<F]X>5]P87-S)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)')Q+3YS
M9710<F]X>2@D<')O>'E?<&%R86US6R=P<F]X>5]H;W-T)UTL("1P<F]X>5]P
M87)A;7-;)W!R;WAY7W!O<G0G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1P<F]X>5]P87)A;7-;)W!R;WAY7W5S97(G72P@)'!R;WAY
M7W!A<F%M<ULG<')O>'E?<&%S<R==*3L*("`@("`@("`@("`@("`@('T@96QS
M96EF("AI<W-E="@D<')O>'E?<&%R86US6R=P<F]X>5]H;W-T)UTI("8F"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@:7-S970H)'!R;WAY7W!A<F%M<ULG
M<')O>'E?<&]R="==*2D@>PH@("`@("`@("`@("`@("`@("`@("1R<2T^<V5T
M4')O>'DH)'!R;WAY7W!A<F%M<ULG<')O>'E?:&]S="==+"`D<')O>'E?<&%R
M86US6R=P<F]X>5]P;W)T)UTI.PH@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@("`@("1R97-U;'0@/2`D<G$M/G-E;F1297%U97-T*"D["B`@("`@
M("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT
M*")5;F%B;&4@=&\@<F5T<FEE=F4@5U-$3"`D=W-D;%]F;F%M92PB("X@)')Q
M+3YG971297-P;VYS94-O9&4H*2P@)'=S9&Q?9FYA;64I.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@)&9I;&5?9&%T82`]("1R<2T^9V5T
M4F5S<&]N<V5";V1Y*"D["B`@("`@("`@("`@("`@("!I9B`H(21F:6QE7V1A
M=&$I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES
M95-O87!&875L="@B56YA8FQE('1O(')E=')I979E(%=31$P@)'=S9&Q?9FYA
M;64L(&YO(&AT='`@8F]D>2(L("1W<V1L7V9N86UE*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&UD-5]W<V1L(#T@
M;60U*"1F:6QE7V1A=&$I.PH*("`@("`@("`@("`@:68@*"1T:&ES+3Y?8V%C
M:&55<V4I('L*("`@("`@("`@("`@("`@("1F<"`](&9O<&5N*"1C86-H96YA
M;64L(")W8B(I.PH@("`@("`@("`@("`@("`@9G=R:71E*"1F<"P@)&9I;&5?
M9&%T82D["B`@("`@("`@("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/E]C86-H955S92`F
M)B`D8V%C:&4@)B8@)&-A8VAE("$]("1M9#5?=W-D;"D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&875L="@B5U-$3"!#:&5C:W-U
M;2!E<G)O<B$B+"`D=W-D;%]F;F%M92D["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D9FEL95]D871A.PH@("`@?0H*?0H*8VQA<W,@4T]!4%]74T1,7U!A
M<G-E<B!E>'1E;F1S(%-/05!?0F%S90I["@H@("`@+RHJ"B`@("`@*B!$969I
M;F4@:6YT97)N86P@87)R87ES(&]F(&)I;F1I;F=S+"!P;W)T<RP@;W!E<F%T
M:6]N<RP*("`@("`J(&UE<W-A9V5S+"!E=&,N"B`@("`@*B\*("`@('9A<B`D
M8W5R<F5N=$UE<W-A9V4["B`@("!V87(@)&-U<G)E;G1/<&5R871I;VX["B`@
M("!V87(@)&-U<G)E;G10;W)T5'EP93L*("`@('9A<B`D8W5R<F5N=$)I;F1I
M;F<["B`@("!V87(@)&-U<G)E;G10;W)T.PH*("`@("\J*@H@("`@("H@4&%R
M<V5R('9A<G,N"B`@("`@*B\*("`@('9A<B`D8V%C:&4["@H@("`@=F%R("1T
M;G,@/2!N=6QL.PH@("`@=F%R("1S;V%P;G,@/2!A<G)A>2@G<V]A<"<I.PH@
M("`@=F%R("1U<FD@/2`G)SL*("`@('9A<B`D=W-D;"`](&YU;&P["@H@("`@
M=F%R("1S=&%T=7,@/2`G)SL*("`@('9A<B`D96QE;65N=%]S=&%C:R`](&%R
M<F%Y*"D["B`@("!V87(@)'!A<F5N=$5L96UE;G0@/2`G)SL*"B`@("!V87(@
M)'-C:&5M82`]("<G.PH@("`@=F%R("1S8VAE;6%3=&%T=7,@/2`G)SL*("`@
M('9A<B`D<V-H96UA7W-T86-K(#T@87)R87DH*3L*("`@('9A<B`D8W5R<F5N
M=$-O;7!L97A4>7!E.PH@("`@=F%R("1S8VAE;6%?96QE;65N=%]S=&%C:R`]
M(&%R<F%Y*"D["B`@("!V87(@)&-U<G)E;G1%;&5M96YT.PH*("`@("\J*@H@
M("`@("H@8V]N<W1R=6-T;W(*("`@("`J+PH@("`@9G5N8W1I;VX@4T]!4%]7
M4T1,7U!A<G-E<B@D=7)I+"`F)'=S9&PL("1D;V-S(#T@9F%L<V4I"B`@("![
M"B`@("`@("`@<&%R96YT.CI33T%07T)A<V4H)U=31$Q005)315(G*3L*("`@
M("`@("`D=&AI<RT^8V%C:&4@/28@;F5W(%-/05!?5U-$3%]#86-H92@D=W-D
M;"T^8V%C:&55<V4L("1W<V1L+3YC86-H94UA>$%G92D["B`@("`@("`@)'1H
M:7,M/G5R:2`]("1U<FD["B`@("`@("`@)'1H:7,M/G=S9&P@/2`F)'=S9&P[
M"B`@("`@("`@)'1H:7,M/F1O8W,@/2`D9&]C<SL*("`@("`@("`D=&AI<RT^
M<&%R<V4H)'5R:2D["B`@("!]"@H@("`@9G5N8W1I;VX@<&%R<V4H)'5R:2D*
M("`@('L*("`@("`@("`O+R!#:&5C:R!W:&5T:&5R(&-O;G1E;G0@:&%S(&)E
M96X@<F5A9"X*("`@("`@("`D9F0@/2`D=&AI<RT^8V%C:&4M/F=E="@D=7)I
M+"`D=&AI<RT^=W-D;"T^<')O>'DI.PH@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1F9"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53
M;V%P1F%U;'0H)&9D*3L*("`@("`@("!]"@H@("`@("`@("\O($-R96%T92!A
M;B!834P@<&%R<V5R+@H@("`@("`@("1P87)S97(@/2!X;6Q?<&%R<V5R7V-R
M96%T92@I.PH@("`@("`@('AM;%]P87)S97)?<V5T7V]P=&EO;B@D<&%R<V5R
M+"!834Q?3U!424].7T-!4T5?1D],1$E.1RP@,"D["B`@("`@("`@>&UL7W-E
M=%]O8FIE8W0H)'!A<G-E<BP@)'1H:7,I.PH@("`@("`@('AM;%]S971?96QE
M;65N=%]H86YD;&5R*"1P87)S97(L("=S=&%R=$5L96UE;G0G+"`G96YD16QE
M;65N="<I.PH@("`@("`@(&EF("@D=&AI<RT^9&]C<RD@>PH@("`@("`@("`@
M("!X;6Q?<V5T7V-H87)A8W1E<E]D871A7VAA;F1L97(H)'!A<G-E<BP@)V-H
M87)A8W1E<D1A=&$G*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A>&UL7W!A
M<G-E*"1P87)S97(L("1F9"P@=')U92DI('L*("`@("`@("`@("`@)&1E=&%I
M;"`]('-P<FEN=&8H)UA-3"!E<G)O<B!O;B!L:6YE("5D.B`E<R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('AM;%]G971?8W5R<F5N=%]L:6YE
M7VYU;6)E<B@D<&%R<V5R*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@>&UL7V5R<F]R7W-T<FEN9RAX;6Q?9V5T7V5R<F]R7V-O9&4H)'!A<G-E
M<BDI*3L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U
M;'0H(E5N86)L92!T;R!P87)S92!74T1,(&9I;&4@)'5R:5QN)&1E=&%I;"(I
M.PH@("`@("`@('T*("`@("`@("!X;6Q?<&%R<V5R7V9R964H)'!A<G-E<BD[
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!S
M=&%R="UE;&5M96YT(&AA;F1L97(*("`@("`J+PH@("`@9G5N8W1I;VX@<W1A
M<G1%;&5M96YT*"1P87)S97(L("1N86UE+"`D871T<G,I"B`@("!["B`@("`@
M("`@+R\@1V5T(&5L96UE;G0@<')E9FEX+@H@("`@("`@("1Q;F%M92`])B!N
M97<@44YA;64H)&YA;64I.PH@("`@("`@(&EF("@D<6YA;64M/FYS*2!["B`@
M("`@("`@("`@("1N<R`]("1Q;F%M92T^;G,["B`@("`@("`@("`@(&EF("@D
M;G,@)B8@*"@A)'1H:7,M/G1N<R`F)B!S=')C87-E8VUP*"1Q;F%M92T^;F%M
M92P@)V1E9FEN:71I;VYS)RD@/3T@,"D@?'P@)&YS(#T]("1T:&ES+3YT;G,I
M*2!["B`@("`@("`@("`@("`@("`D;F%M92`]("1Q;F%M92T^;F%M93L*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D=&AI<RT^8W5R<F5N=%1A
M9R`]("1Q;F%M92T^;F%M93L*("`@("`@("`D=&AI<RT^<&%R96YT16QE;65N
M="`]("<G.PH@("`@("`@("1S=&%C:U]S:7IE(#T@8V]U;G0H)'1H:7,M/F5L
M96UE;G1?<W1A8VLI.PH@("`@("`@(&EF("@D<W1A8VM?<VEZ92D@>PH@("`@
M("`@("`@("`D=&AI<RT^<&%R96YT16QE;65N="`]("1T:&ES+3YE;&5M96YT
M7W-T86-K6R1S=&%C:U]S:7IE("T@,5T["B`@("`@("`@?0H@("`@("`@("1T
M:&ES+3YE;&5M96YT7W-T86-K6UT@/2`D=&AI<RT^8W5R<F5N=%1A9SL*"B`@
M("`@("`@+R\@1FEN9"!S=&%T=7,L(')E9VES=&5R(&1A=&$N"B`@("`@("`@
M<W=I=&-H("@D=&AI<RT^<W1A='5S*2!["B`@("`@("`@8V%S92`G='EP97,G
M.@H@("`@("`@("`@("`O+R!S96-T(#(N,B!W<V1L.G1Y<&5S"B`@("`@("`@
M("`@("\O(&-H:6QD<F5N.B!X<V0Z<V-H96UA"B`@("`@("`@("`@("1P87)E
M;G1?=&%G(#T@)R<["B`@("`@("`@("`@("1S=&%C:U]S:7IE(#T@8V]U;G0H
M)'1H:7,M/G-C:&5M85]S=&%C:RD["B`@("`@("`@("`@(&EF("@D<W1A8VM?
M<VEZ92D@>PH@("`@("`@("`@("`@("`@)'!A<F5N=%]T86<@/2`D=&AI<RT^
M<V-H96UA7W-T86-K6R1S=&%C:U]S:7IE("T@,5T["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@('-W:71C:"`H)'%N86UE+3YN86UE*2!["B`@("`@("`@
M("`@(&-A<V4@)W-C:&5M82<Z"B`@("`@("`@("`@("`@("`O+R!.;R!P87)E
M;G0@<VAO=6QD(&)E(&EN('1H92!S=&%C:RX*("`@("`@("`@("`@("`@(&EF
M("@A)'!A<F5N=%]T86<@?'P@)'!A<F5N=%]T86<@/3T@)W1Y<&5S)RD@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"=T87)G
M971.86UE<W!A8V4G+"`D871T<G,I*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YS8VAE;6$@/2`D=&AI<RT^=W-D;"T^9V5T3F%M97-P86-E
M071T<FEB=71E3F%M92@D871T<G-;)W1A<F=E=$YA;65S<&%C92==*3L*("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^<V-H96UA(#T@)'1H:7,M/G=S9&PM/F=E=$YA;65S<&%C
M94%T=')I8G5T94YA;64H)'1H:7,M/G=S9&PM/G1N<RD["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YC
M;VUP;&5X5'EP97-;)'1H:7,M/G-C:&5M85T@/2!A<G)A>2@I.PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YE;&5M96YT<ULD=&AI<RT^<V-H
M96UA72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V-O;7!L97A4>7!E)SH*
M("`@("`@("`@("`@("`@(&EF("@D<&%R96YT7W1A9R`]/2`G<V-H96UA)RD@
M>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC=7)R96YT0V]M<&QE>%1Y
M<&4@/2`D871T<G-;)VYA;64G73L*("`@("`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1A='1R<ULG;F%M97-P86-E)UTI*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1A='1R<ULG;F%M97-P86-E)UT@/2`D=&AI<RT^<V-H96UA
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=6R1T:&ES
M+3YC=7)R96YT0V]M<&QE>%1Y<&5=(#T@)&%T=')S.PH@("`@("`@("`@("`@
M("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"=B87-E)RP@)&%T=')S*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D<6X@/28@;F5W(%%.86UE*"1A
M='1R<ULG8F%S92==*3L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/G=S9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R
M<F5N=$-O;7!L97A4>7!E75LG='EP92==(#T@)'%N+3YN86UE.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T
M:&ES+3YS8VAE;6%=6R1T:&ES+3YC=7)R96YT0V]M<&QE>%1Y<&5=6R=N86UE
M<W!A8V4G72`]("1Q;BT^;G,["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/F-O;7!L
M97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N=$-O;7!L97A4
M>7!E75LG='EP92==(#T@)U-T<G5C="<["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS8VAE;6%3=&%T=7,@/2`G
M8V]M<&QE>%1Y<&4G.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^96QE;65N='-;)'1H:7,M/G-C
M:&5M85U;)'1H:7,M/F-U<G)E;G1%;&5M96YT75LG8V]M<&QE>"==(#T@=')U
M93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@8V%S92`G96QE;65N="<Z"B`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)&%T=')S6R=T>7!E)UTI*2!["B`@("`@("`@("`@("`@("`@
M("`@)'%N(#TF(&YE=R!13F%M92@D871T<G-;)W1Y<&4G72D["B`@("`@("`@
M("`@("`@("`@("`@)&%T=')S6R=T>7!E)UT@/2`D<6XM/FYA;64["B`@("`@
M("`@("`@("`@("`@("`@:68@*"1Q;BT^;G,@)B8@87)R87E?:V5Y7V5X:7-T
M<R@D<6XM/FYS+"`D=&AI<RT^=W-D;"T^;F%M97-P86-E<RDI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&%T=')S6R=N86UE<W!A8V4G72`]("1Q;BT^
M;G,["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@("1P87)E;G1%;&5M96YT(#T@)R<["B`@("`@("`@
M("`@("`@("`D<W1A8VM?<VEZ92`](&-O=6YT*"1T:&ES+3YS8VAE;6%?96QE
M;65N=%]S=&%C:RD["B`@("`@("`@("`@("`@("!I9B`H)'-T86-K7W-I>F4@
M/B`P*2!["B`@("`@("`@("`@("`@("`@("`@)'!A<F5N=$5L96UE;G0@/2`D
M=&AI<RT^<V-H96UA7V5L96UE;G1?<W1A8VM;)'-T86-K7W-I>F4@+2`Q73L*
M("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)&%T=')S6R=R968G72DI('L*("`@("`@("`@("`@("`@("`@("`D<6X@/28@
M;F5W(%%.86UE*"1A='1R<ULG<F5F)UTI.PH@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YC=7)R96YT16QE;65N="`]("1Q;BT^;F%M93L*("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-U
M<G)E;G1%;&5M96YT(#T@)&%T=')S6R=N86UE)UT["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`D=&AI<RT^<V-H96UA7V5L96UE;G1?<W1A
M8VM;72`]("1T:&ES+3YC=7)R96YT16QE;65N=#L*("`@("`@("`@("`@("`@
M(&EF("@A:7-S970H)&%T=')S6R=N86UE<W!A8V4G72DI('L*("`@("`@("`@
M("`@("`@("`@("`D871T<G-;)VYA;65S<&%C92==(#T@)'1H:7,M/G-C:&5M
M83L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I9B`H)'!A
M<F5N=%]T86<@/3T@)W-C:&5M82<I('L*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^=W-D;"T^96QE;65N='-;)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U
M<G)E;G1%;&5M96YT72`]("1A='1R<SL*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^=W-D;"T^96QE;65N='-;)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U
M<G)E;G1%;&5M96YT75LG8V]M<&QE>"==(#T@9F%L<V4["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/G-C:&5M85-T871U<R`]("=E;&5M96YT)SL*("`@
M("`@("`@("`@("`@('T@96QS96EF("@D=&AI<RT^8W5R<F5N=$-O;7!L97A4
M>7!E*2!["B`@("`@("`@("`@("`@("`@("`@+R\@=V4G<F4@:6YS:61E(&$@
M8V]M<&QE>%1Y<&4*("`@("`@("`@("`@("`@("`@("!I9B`H*&ES<V5T*"1T
M:&ES+3YW<V1L+3YC;VUP;&5X5'EP97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M
M/F-U<G)E;G1#;VUP;&5X5'EP95U;)V]R9&5R)UTI("8F"B`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES
M+3YS8VAE;6%=6R1T:&ES+3YC=7)R96YT0V]M<&QE>%1Y<&5=6R=O<F1E<B==
M(#T]("=S97%U96YC92<I"B`@("`@("`@("`@("`@("`@("`@("`@("8F("1T
M:&ES+3YW<V1L+3YC;VUP;&5X5'EP97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M
M/F-U<G)E;G1#;VUP;&5X5'EP95U;)W1Y<&4G72`]/2`G07)R87DG*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YC;VUP;&5X5'EP
M97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U<G)E;G1#;VUP;&5X5'EP95U;
M)V%R<F%Y5'EP92==(#T@:7-S970H)&%T=')S6R=T>7!E)UTI(#\@)&%T=')S
M6R=T>7!E)UT@.B!N=6QL.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES
M+3YS8VAE;6%=6R1T:&ES+3YC=7)R96YT0V]M<&QE>%1Y<&5=6R=E;&5M96YT
M<R==6R1T:&ES+3YC=7)R96YT16QE;65N=%T@/2`D871T<G,["B`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW
M<V1L+3YE;&5M96YT<ULD=&AI<RT^<V-H96UA75LD<&%R96YT16QE;65N=%U;
M)V5L96UE;G1S)UU;)'1H:7,M/F-U<G)E;G1%;&5M96YT72`]("1A='1R<SL*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@8V%S92`G8V]M<&QE>$-O;G1E;G0G.@H@("`@("`@("`@("!C
M87-E("=S:6UP;&5#;VYT96YT)SH*("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@8V%S92`G97AT96YS:6]N)SH*("`@("`@("`@("`@8V%S
M92`G<F5S=')I8W1I;VXG.@H@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YS
M8VAE;6%3=&%T=7,@/3T@)V-O;7!L97A4>7!E)RD@>PH@("`@("`@("`@("`@
M("`@("`@(&EF("@A96UP='DH)&%T=')S6R=B87-E)UTI*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1Q;B`])B!N97<@44YA;64H)&%T=')S6R=B87-E
M)UTI.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^8V]M
M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=6R1T:&ES+3YC=7)R96YT0V]M<&QE
M>%1Y<&5=6R=T>7!E)UT@/2`D<6XM/FYA;64["@H@("`@("`@("`@("`@("`@
M("`@("`@("`O+R!4>7!E<R!T:&%T(&5X=&5N9"!F<F]M(&]T:&5R('1Y<&5S
M(&%R96XG=`H@("`@("`@("`@("`@("`@("`@("`@("`O+R`J;V8J('1H;W-E
M('1Y<&5S+B!2969L96-T('1H:7,@8GD@9&5N;W1I;F<*("`@("`@("`@("`@
M("`@("`@("`@("`@+R\@=VAI8V@@='EP92!T:&5Y(&5X=&5N9"X@22=M(&QE
M879I;F<@=&AE"B`@("`@("`@("`@("`@("`@("`@("`@("\O("=T>7!E)R!S
M971T:6YG(&AE<F4@<VEN8V4@22=M(&YO="!S=7)E('=H870*("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@<F5M;W9I;F<@:70@;6EG:'0@8G)E86L@870@
M=&AE(&UO;65N="X*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1Q;F%M
M92T^;F%M92`]/2`G97AT96YS:6]N)RD@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/G=S9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H
M96UA75LD=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E75LG97AT96YD<R==(#T@
M)'%N+3YN86UE.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/G=S9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI
M<RT^8W5R<F5N=$-O;7!L97A4>7!E75LG='EP92==(#T@)U-T<G5C="<["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=S97%U96YC92<Z
M"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/G-C:&5M85-T871U<R`]/2`G
M8V]M<&QE>%1Y<&4G*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S
M9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N
M=$-O;7!L97A4>7!E75LG;W)D97(G72`]("1Q;F%M92T^;F%M93L*("`@("`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YW<V1L+3YC;VUP;&5X
M5'EP97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U<G)E;G1#;VUP;&5X5'EP
M95U;)W1Y<&4G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/G=S9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R
M<F5N=$-O;7!L97A4>7!E75LG='EP92==(#T@)T%R<F%Y)SL*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V%L;"<Z"B`@("`@("`@("`@
M("`@("`D=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=
M6R1T:&ES+3YC=7)R96YT0V]M<&QE>%1Y<&5=6R=O<F1E<B==(#T@)'%N86UE
M+3YN86UE.PH@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^=W-D
M;"T^8V]M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=6R1T:&ES+3YC=7)R96YT
M0V]M<&QE>%1Y<&5=6R=T>7!E)UTI*2!["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/G=S9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI
M<RT^8W5R<F5N=$-O;7!L97A4>7!E75LG='EP92==(#T@)U-T<G5C="<["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@(&-A<V4@)V-H;VEC92<Z"B`@("`@("`@("`@("`@("`D=&AI<RT^
M=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=6R1T:&ES+3YC=7)R
M96YT0V]M<&QE>%1Y<&5=6R=O<F1E<B==(#T@)'%N86UE+3YN86UE.PH@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^=W-D;"T^8V]M<&QE>%1Y
M<&5S6R1T:&ES+3YS8VAE;6%=6R1T:&ES+3YC=7)R96YT0V]M<&QE>%1Y<&5=
M6R=T>7!E)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM
M/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N=$-O
M;7!L97A4>7!E75LG='EP92==(#T@)T%R<F%Y)SL*("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@(&-A<V4@)V%T=')I8G5T92<Z"B`@("`@("`@("`@
M("`@("!I9B`H)'1H:7,M/G-C:&5M85-T871U<R`]/2`G8V]M<&QE>%1Y<&4G
M*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A='1R<ULG;F%M
M92==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^
M8V]M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=6R1T:&ES+3YC=7)R96YT0V]M
M<&QE>%1Y<&5=6R=A='1R:6)U=&4G75LD871T<G-;)VYA;64G75T@/2`D871T
M<G,["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1A='1R<ULG<F5F)UTI*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<2`])B!N97<@44YA;64H)&%T=')S
M6R=R968G72D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H
M("@D871T<G,@87,@)&L@/3X@)'8I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H)&L@(3T@)W)E9B<@)B8@<W1R<W1R*"1K+"`D<2T^
M;F%M92DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'9Q(#TF(&YE=R!13F%M92@D=BD["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("@D<2T^;F%M92`]/2`G87)R87E4>7!E)RD@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/G=S9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R
M<F5N=$-O;7!L97A4>7!E75LD<2T^;F%M95T@/2`D=G$M/FYA;64N("1V<2T^
M87)R87E);F9O.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G=S9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA
M75LD=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E75LG='EP92==(#T@)T%R<F%Y
M)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YW<V1L+3YC;VUP;&5X5'EP97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M
M/F-U<G)E;G1#;VUP;&5X5'EP95U;)VYA;65S<&%C92==(#T@)'9Q+3YN<SL*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YW<V1L+3YC;VUP;&5X5'EP97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U
M<G)E;G1#;VUP;&5X5'EP95U;)'$M/FYA;65=(#T@)'9Q+3YN86UE.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3YS8VAE
M;6%?<W1A8VM;72`]("1Q;F%M92T^;F%M93L*("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@(&-A<V4@)VUE<W-A9V4G.@H@("`@("`@("`@("`O+R!S96-T
M(#(N,R!W<V1L.FUE<W-A9V4@8VAI;&0@=W-D;#IP87)T"B`@("`@("`@("`@
M('-W:71C:"`H)'%N86UE+3YN86UE*2!["B`@("`@("`@("`@(&-A<V4@)W!A
M<G0G.@H@("`@("`@("`@("`@("`@)'%N(#T@;G5L;#L*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D871T<G-;)W1Y<&4G72DI('L*("`@("`@("`@("`@
M("`@("`@("`D<6X@/28@;F5W(%%.86UE*"1A='1R<ULG='EP92==*3L*("`@
M("`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D871T<G-;)V5L96UE;G0G
M72DI('L*("`@("`@("`@("`@("`@("`@("`D<6X@/28@;F5W(%%.86UE*"1A
M='1R<ULG96QE;65N="==*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&EF("@D<6XI('L*("`@("`@("`@("`@("`@("`@("`D871T<G-;
M)W1Y<&4G72`]("1Q;BT^;F%M93L*("`@("`@("`@("`@("`@("`@("`D871T
M<G-;)VYA;65S<&%C92==(#T@)'%N+3YN<SL*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YM97-S86=E<ULD=&AI<RT^
M8W5R<F5N=$UE<W-A9V5=6R1A='1R<ULG;F%M92==72`]("1A='1R<SL*("`@
M("`@("`@("`@("`@("\O(&5R<F]R(&EN('=S9&P*"B`@("`@("`@("`@(&-A
M<V4@)V1O8W5M96YT871I;VXG.@H@("`@("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@
M)W!O<G14>7!E)SH*("`@("`@("`@("`@+R\@<V5C="`R+C0*("`@("`@("`@
M("`@<W=I=&-H("@D<6YA;64M/FYA;64I('L*("`@("`@("`@("`@8V%S92`G
M;W!E<F%T:6]N)SH*("`@("`@("`@("`@("`@("\O(&%T=')I8G5T97,Z(&YA
M;64*("`@("`@("`@("`@("`@("\O(&-H:6QD<F5N.B!W<V1L.FEN<'5T('=S
M9&PZ;W5T<'5T('=S9&PZ9F%U;'0*("`@("`@("`@("`@("`@("1T:&ES+3YC
M=7)R96YT3W!E<F%T:6]N(#T@)&%T=')S6R=N86UE)UT["B`@("`@("`@("`@
M("`@("`D=&AI<RT^=W-D;"T^<&]R=%1Y<&5S6R1T:&ES+3YC=7)R96YT4&]R
M=%1Y<&5=6R1T:&ES+3YC=7)R96YT3W!E<F%T:6]N72`]("1A='1R<SL*("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G:6YP=70G
M.@H@("`@("`@("`@("!C87-E("=O=71P=70G.@H@("`@("`@("`@("!C87-E
M("=F875L="<Z"B`@("`@("`@("`@("`@("`O+R!W<V1L.FEN<'5T('=S9&PZ
M;W5T<'5T('=S9&PZ9F%U;'0*("`@("`@("`@("`@("`@("\O(&%T=')I8G5T
M97,Z(&YA;64@;65S<V%G92!P87)A;65T97)/<F1E<BAO<'1I;VYA;"D*("`@
M("`@("`@("`@("`@(&EF("@D=&AI<RT^8W5R<F5N=$]P97)A=&EO;BD@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^=W-D;"T^<&]R
M=%1Y<&5S6R1T:&ES+3YC=7)R96YT4&]R=%1Y<&5=6R1T:&ES+3YC=7)R96YT
M3W!E<F%T:6]N75LD;F%M95TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YW<V1L+3YP;W)T5'EP97-;)'1H:7,M/F-U<G)E;G10;W)T5'EP
M95U;)'1H:7,M/F-U<G)E;G1/<&5R871I;VY=6R1N86UE72`](&%R<F%Y7VUE
M<F=E*"1T:&ES+3YW<V1L+3YP;W)T5'EP97-;)'1H:7,M/F-U<G)E;G10;W)T
M5'EP95U;)'1H:7,M/F-U<G)E;G1/<&5R871I;VY=6R1N86UE72P@)&%T=')S
M*3L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^=W-D;"T^<&]R=%1Y<&5S6R1T:&ES+3YC=7)R
M96YT4&]R=%1Y<&5=6R1T:&ES+3YC=7)R96YT3W!E<F%T:6]N75LD;F%M95T@
M/2`D871T<G,["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"=M97-S86=E)RP@)&%T=')S
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<6X@/28@;F5W(%%.86UE
M*"1A='1R<ULG;65S<V%G92==*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/G=S9&PM/G!O<G14>7!E<ULD=&AI<RT^8W5R<F5N=%!O<G14>7!E
M75LD=&AI<RT^8W5R<F5N=$]P97)A=&EO;EU;)&YA;65=6R=M97-S86=E)UT@
M/2`D<6XM/FYA;64["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW
M<V1L+3YP;W)T5'EP97-;)'1H:7,M/F-U<G)E;G10;W)T5'EP95U;)'1H:7,M
M/F-U<G)E;G1/<&5R871I;VY=6R1N86UE75LG;F%M97-P86-E)UT@/2`D<6XM
M/FYS.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G9&]C
M=6UE;G1A=&EO;B<Z"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G8FEN9&EN
M9R<Z"B`@("`@("`@("`@("1N<R`]("1Q;F%M92T^;G,@/R`D=&AI<RT^=W-D
M;"T^;F%M97-P86-E<ULD<6YA;64M/FYS72`Z(%-#2$5-05]74T1,.PH@("`@
M("`@("`@("!S=VET8V@@*"1N<RD@>PH@("`@("`@("`@("!C87-E(%-#2$5-
M05]33T%0.@H@("`@("`@("`@("`@("`@+R\@=&AI<R!D96%L<R!W:71H('=S
M9&P@<V5C=&EO;B`S('-O87`@8FEN9&EN9PH@("`@("`@("`@("`@("`@<W=I
M=&-H("@D<6YA;64M/FYA;64I('L*("`@("`@("`@("`@("`@(&-A<V4@)V)I
M;F1I;F<G.@H@("`@("`@("`@("`@("`@("`@("\O('-E8W0@,RXS"B`@("`@
M("`@("`@("`@("`@("`@+R\@<V]A<#IB:6YD:6YG+"!A='1R:6)U=&5S.B!T
M<F%N<W!O<G0H<F5Q=6ER960I+"!S='EL92AO<'1I;VYA;"P@9&5F875L="`]
M(&1O8W5M96YT*0H@("`@("`@("`@("`@("`@("`@("\O(&EF('-T>6QE(&ES
M(&UI<W-I;F<L(&ET(&ES(&%S<W5M960@=&\@8F4@)V1O8W5M96YT)PH@("`@
M("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&%T=')S6R=S='EL92==*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D871T<G-;)W-T>6QE)UT@/2`G
M9&]C=6UE;G0G.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^=W-D;"T^8FEN9&EN9W-;)'1H:7,M/F-U<G)E;G1"
M:6YD:6YG72`](&%R<F%Y7VUE<F=E*"1T:&ES+3YW<V1L+3YB:6YD:6YG<ULD
M=&AI<RT^8W5R<F5N=$)I;F1I;F==+"`D871T<G,I.PH@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)V]P97)A=&EO
M;B<Z"B`@("`@("`@("`@("`@("`@("`@+R\@<V5C="`S+C0*("`@("`@("`@
M("`@("`@("`@("`O+R!S;V%P.F]P97)A=&EO;BP@871T<FEB=71E<SH@<V]A
M<$%C=&EO;BAR97%U:7)E9"DL('-T>6QE*&]P=&EO;F%L+"!D969A=6QT(#T@
M<V]A<#IB:6YD:6YG.G-T>6QE*0H@("`@("`@("`@("`@("`@("`@(&EF("@A
M:7-S970H)&%T=')S6R=S='EL92==*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D871T<G-;)W-T>6QE)UT@/2`D=&AI<RT^=W-D;"T^8FEN9&EN9W-;
M)'1H:7,M/F-U<G)E;G1":6YD:6YG75LG<W1Y;&4G73L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3YW<V1L+3YB:6YD:6YG<ULD=&AI<RT^8W5R<F5N=$)I;F1I;F==6R=O<&5R
M871I;VYS)UU;)'1H:7,M/F-U<G)E;G1/<&5R871I;VY=*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^8FEN9&EN9W-;)'1H:7,M
M/F-U<G)E;G1":6YD:6YG75LG;W!E<F%T:6]N<R==6R1T:&ES+3YC=7)R96YT
M3W!E<F%T:6]N72`](&%R<F%Y7VUE<F=E*"1T:&ES+3YW<V1L+3YB:6YD:6YG
M<ULD=&AI<RT^8W5R<F5N=$)I;F1I;F==6R=O<&5R871I;VYS)UU;)'1H:7,M
M/F-U<G)E;G1/<&5R871I;VY=+"`D871T<G,I.PH@("`@("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW
M<V1L+3YB:6YD:6YG<ULD=&AI<RT^8W5R<F5N=$)I;F1I;F==6R=O<&5R871I
M;VYS)UU;)'1H:7,M/F-U<G)E;G1/<&5R871I;VY=(#T@)&%T=')S.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@("`@("!C87-E("=B;V1Y)SH*("`@("`@("`@("`@("`@
M("`@("`O+R!S96-T(#,N-0H@("`@("`@("`@("`@("`@("`@("\O('-O87`Z
M8F]D>2!A='1R:6)U=&5S.@H@("`@("`@("`@("`@("`@("`@("\O('!A<G0@
M+2!O<'1I;VYA;"X@(&QI<W1E9"!P87)T<R!M=7-T(&%P<&5A<B!I;B!B;V1Y
M+"!M:7-S:6YG(&UE86YS(&%L;"!P87)T<R!A<'!E87(@:6X@8F]D>0H@("`@
M("`@("`@("`@("`@("`@("\O('5S92`M(')E<75I<F5D+B!E;F-O9&5D?&QI
M=&5R86P*("`@("`@("`@("`@("`@("`@("`O+R!E;F-O9&EN9U-T>6QE("T@
M;W!T:6]N86PN("!S<&%C92!S97!E<F%T960@;&ES="!O9B!E;F-O9&EN9W,@
M*'5R:2=S*0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YB:6YD
M:6YG<ULD=&AI<RT^8W5R<F5N=$)I;F1I;F=="B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%LG;W!E<F%T:6]N<R==6R1T:&ES+3YC=7)R
M96YT3W!E<F%T:6]N75LD=&AI<RT^;W!3=&%T=7-=(#T@)&%T=')S.PH@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@
M)V9A=6QT)SH*("`@("`@("`@("`@("`@("`@("`O+R!S96-T(#,N-@H@("`@
M("`@("`@("`@("`@("`@("\O('-O87`Z9F%U;'0@871T<FEB=71E<SH@;F%M
M92!U<V4@(&5N8V]D:6YG4W1Y;&4@;F%M97-P86-E"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G=S9&PM/F)I;F1I;F=S6R1T:&ES+3YC=7)R96YT0FEN
M9&EN9UT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6R=O
M<&5R871I;VYS)UU;)'1H:7,M/F-U<G)E;G1/<&5R871I;VY=6R1T:&ES+3YO
M<%-T871U<UT@/2`D871T<G,["B`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("`@("`@8V%S92`G:&5A9&5R)SH*("`@("`@("`@("`@
M("`@("`@("`O+R!S96-T(#,N-PH@("`@("`@("`@("`@("`@("`@("\O('-O
M87`Z:&5A9&5R(&%T=')I8G5T97,Z(&UE<W-A9V4@<&%R="!U<V4@96YC;V1I
M;F=3='EL92!N86UE<W!A8V4*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M=W-D;"T^8FEN9&EN9W-;)'1H:7,M/F-U<G)E;G1":6YD:6YG70H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!;)V]P97)A=&EO;G,G75LD
M=&AI<RT^8W5R<F5N=$]P97)A=&EO;EU;)'1H:7,M/F]P4W1A='5S75LG:&5A
M9&5R<R==6UT@/2`D871T<G,["B`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("`@("`@8V%S92`G:&5A9&5R9F%U;'0G.@H@("`@("`@
M("`@("`@("`@("`@("\O('-E8W0@,RXW"B`@("`@("`@("`@("`@("`@("`@
M+R\@<V]A<#IH96%D97(@871T<FEB=71E<SH@;65S<V%G92!P87)T('5S92!E
M;F-O9&EN9U-T>6QE(&YA;65S<&%C90H@("`@("`@("`@("`@("`@("`@("1H
M96%D97(@/2!C;W5N="@D=&AI<RT^=W-D;"T^8FEN9&EN9W-;)'1H:7,M/F-U
M<G)E;G1":6YD:6YG70H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!;)V]P97)A=&EO;G,G75LD=&AI<RT^8W5R<F5N=$]P97)A=&EO;EU;
M)'1H:7,M/F]P4W1A='5S75LG:&5A9&5R<R==*2TQ.PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YW<V1L+3YB:6YD:6YG<ULD=&AI<RT^8W5R<F5N=$)I
M;F1I;F=="B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%LG
M;W!E<F%T:6]N<R==6R1T:&ES+3YC=7)R96YT3W!E<F%T:6]N75LD=&AI<RT^
M;W!3=&%T=7-=6R=H96%D97)S)UU;)&AE861E<EU;)V9A=6QT)UT@/2`D871T
M<G,["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@
M("`@8V%S92`G9&]C=6UE;G1A=&EO;B<Z"B`@("`@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@
M("`@("`@("`O+R!E<G)O<B$@(&YO="!A('9A;&ED(&5L96UE;G0@:6YS:61E
M(&)I;F1I;F<*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M8V%S92!30TA%34%?5U-$3#H*("`@("`@("`@("`@("`@("\O(%A86"!V97)I
M9GD@8V]R<F5C="!N86UE<W!A8V4*("`@("`@("`@("`@("`@("\O(&9O<B!N
M;W<L(&1E9F%U;'0@:7,@=&AE("=W<V1L)R!N86UE<W!A8V4*("`@("`@("`@
M("`@("`@("\O(&]T:&5R('!O<W-I8FQE(&YA;65S<&%C97,@:6YC;'5D92!S
M;71P+"!H='1P+"!E=&,N(&9O<B!A;'1E<FYA=&4@8FEN9&EN9W,*("`@("`@
M("`@("`@("`@('-W:71C:"`H)'%N86UE+3YN86UE*2!["B`@("`@("`@("`@
M("`@("!C87-E("=O<&5R871I;VXG.@H@("`@("`@("`@("`@("`@("`@("\O
M('-E8W0@,BXU"B`@("`@("`@("`@("`@("`@("`@+R\@=W-D;#IO<&5R871I
M;VX@871T<FEB=71E<SH@;F%M90H@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YC=7)R96YT3W!E<F%T:6]N(#T@)&%T=')S6R=N86UE)UT["B`@("`@("`@
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G;W5T
M<'5T)SH*("`@("`@("`@("`@("`@(&-A<V4@)VEN<'5T)SH*("`@("`@("`@
M("`@("`@(&-A<V4@)V9A=6QT)SH*("`@("`@("`@("`@("`@("`@("`O+R!S
M96-T(#(N-0H@("`@("`@("`@("`@("`@("`@("\O('=S9&PZ:6YP=70@871T
M<FEB=71E<SH@;F%M90H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YO<%-T
M871U<R`]("1Q;F%M92T^;F%M93L*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@("`@("!C87-E("=D;V-U;65N=&%T:6]N)SH*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!D969A
M=6QT.@H@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E
M(%-#2$5-05]74T1,7TA45%`Z"B`@("`@("`@("`@("`@("!S=VET8V@@*"1Q
M;F%M92T^;F%M92D@>PH@("`@("`@("`@("`@("`@8V%S92`G8FEN9&EN9R<Z
M"B`@("`@("`@("`@("`@("`@("`@+R\@<V5C="`T+C0*("`@("`@("`@("`@
M("`@("`@("`O+R!H='1P.F)I;F1I;F<@871T<FEB=71E<SH@=F5R8@H@("`@
M("`@("`@("`@("`@("`@("\O('!A<F5N=#H@=W-D;#IB:6YD:6YG"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/F)I;F1I;F=S6R1T:&ES+3YC
M=7)R96YT0FEN9&EN9UT@/2!A<G)A>5]M97)G92@D=&AI<RT^=W-D;"T^8FEN
M9&EN9W-;)'1H:7,M/F-U<G)E;G1":6YD:6YG72P@)&%T=')S*3L*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=O
M<&5R871I;VXG.@H@("`@("`@("`@("`@("`@("`@("\O('-E8W0@-"XU"B`@
M("`@("`@("`@("`@("`@("`@+R\@:'1T<#IO<&5R871I;VX@871T<FEB=71E
M<SH@;&]C871I;VX*("`@("`@("`@("`@("`@("`@("`O+R!P87)E;G0Z('=S
M9&PZ;W!E<F%T:6]N"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM
M/F)I;F1I;F=S6R1T:&ES+3YC=7)R96YT0FEN9&EN9UU;)V]P97)A=&EO;G,G
M70H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(%LD=&AI<RT^8W5R<F5N=$]P97)A=&EO;ET@/2`D871T
M<G,["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@
M("`@8V%S92`G=7)L16YC;V1E9"<Z"B`@("`@("`@("`@("`@("`@("`@+R\@
M<V5C="`T+C8*("`@("`@("`@("`@("`@("`@("`O+R!H='1P.G5R;$5N8V]D
M960@871T<FEB=71E<SH@;&]C871I;VX*("`@("`@("`@("`@("`@("`@("`O
M+R!P87)E;G0Z('=S9&PZ:6YP=70@=W-D;#IO=71P=70@971C+@H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YB:6YD:6YG<ULD=&AI<RT^8W5R
M<F5N=$)I;F1I;F==6R=O<&5R871I;VYS)UU;)'1H:7,M/F]P4W1A='5S70H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%LD=&AI<RT^8W5R<F5N=$]P97)A=&EO;EU;)W5R:2==(#T@
M)W5R;$5N8V]D960G.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@("`@(&-A<V4@)W5R;%)E<&QA8V5M96YT)SH*("`@("`@("`@
M("`@("`@("`@("`O+R!S96-T(#0N-PH@("`@("`@("`@("`@("`@("`@("\O
M(&AT='`Z=7)L4F5P;&%C96UE;G0@871T<FEB=71E<SH@;&]C871I;VX*("`@
M("`@("`@("`@("`@("`@("`O+R!P87)E;G0Z('=S9&PZ:6YP=70@=W-D;#IO
M=71P=70@971C+@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YB
M:6YD:6YG<ULD=&AI<RT^8W5R<F5N=$)I;F1I;F==6R=O<&5R871I;VYS)UU;
M)'1H:7,M/F]P4W1A='5S70H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%LD=&AI<RT^8W5R<F5N=$]P
M97)A=&EO;EU;)W5R:2==(#T@)W5R;%)E<&QA8V5M96YT)SL*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=D;V-U
M;65N=&%T:6]N)SH*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@("`@("\O(&5R
M<F]R"B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!C87-E(%-#2$5-05]-24U%.@H@("`@("`@("`@
M("`@("`@+R\@<V5C="`U"B`@("`@("`@("`@("`@("`O+R!A;&P@;6EM92!P
M87)T<R!A<F4@8VAI;&1R96X@;V8@=W-D;#II;G!U="P@=W-D;#IO=71P=70L
M(&5T8RX*("`@("`@("`@("`@("`@("\O('5N<W5P;W)T960@87,@;V8@>65T
M"B`@("`@("`@("`@("`@("!S=VET8V@@*"1Q;F%M92T^;F%M92D@>PH@("`@
M("`@("`@("`@("`@8V%S92`G8V]N=&5N="<Z"B`@("`@("`@("`@("`@("`@
M("`@+R\@<V5C="`U+C,@;6EM93IC;VYT96YT"B`@("`@("`@("`@("`@("`@
M("`@+R\@/&UI;64Z8V]N=&5N="!P87)T/2)N;71O:V5N(C\@='EP93TB<W1R
M:6YG(C\O/@H@("`@("`@("`@("`@("`@("`@("\O('!A<G0@871T<FEB=71E
M(&]N;'D@<F5Q=6ER960@:68@8V]N=&5N="!I<R!C:&EL9"!O9B!M=6QT:7!A
M<G0@<F5L871E9"P*("`@("`@("`@("`@("`@("`@("`O+R`@("`@("`@:70@
M8V]N=&%I;G,@=&AE(&YA;64@;V8@=&AE('!A<G0*("`@("`@("`@("`@("`@
M("`@("`O+R!T>7!E(&%T=')I8G5T92!C;VYT86EN<R!T:&4@;6EM92!T>7!E
M"B`@("`@("`@("`@("`@("!C87-E("=M=6QT:7!A<G1296QA=&5D)SH*("`@
M("`@("`@("`@("`@("`@("`O+R!S96-T(#4N-"!M:6UE.FUU;'1I<&%R=%)E
M;&%T960*("`@("`@("`@("`@("`@(&-A<V4@)W!A<G0G.@H@("`@("`@("`@
M("`@("`@8V%S92`G;6EM95AM;"<Z"B`@("`@("`@("`@("`@("`@("`@+R\@
M<V5C="`U+C8@;6EM93IM:6UE6&UL"B`@("`@("`@("`@("`@("`@("`@+R\@
M/&UI;64Z;6EM95AM;"!P87)T/2)N;71O:V5N(C\O/@H@("`@("`@("`@("`@
M("`@("`@("\O"B`@("`@("`@("`@("`@("!C87-E("=D;V-U;65N=&%T:6]N
M)SH*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@
M("!D969A=6QT.@H@("`@("`@("`@("`@("`@("`@("\O(&5R<F]R"B`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!C87-E(%-#2$5-05]$24U%.@H@("`@("`@("`@("`@("`@+R\@
M1$E-12!I<R!D969I;F5D(&EN.@H@("`@("`@("`@("`@("`@+R\@:'1T<#HO
M+V=O=&1O=&YE="YC;VTO=&5A;2]X;6Q?=W-S<&5C<R]D:6UE+U=31$PM17AT
M96YS:6]N+69O<BU$24U%+FAT;0H@("`@("`@("`@("`@("`@+R\@86QL($1)
M344@<&%R=',@87)E(&-H:6QD<F5N(&]F('=S9&PZ:6YP=70L('=S9&PZ;W5T
M<'5T+"!E=&,N"B`@("`@("`@("`@("`@("`O+R!U;G-U<&]R=&5D(&%S(&]F
M('EE=`H@("`@("`@("`@("`@("`@<W=I=&-H("@D<6YA;64M/FYA;64I('L*
M("`@("`@("`@("`@("`@(&-A<V4@)VUE<W-A9V4G.@H@("`@("`@("`@("`@
M("`@("`@("\O('-E8W0@-"XQ(&1I;64Z;65S<V%G90H@("`@("`@("`@("`@
M("`@("`@("\O(&%P<&5A<G,@:6X@8FEN9&EN9R!S96-T:6]N"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/G=S9&PM/F)I;F1I;F=S6R1T:&ES+3YC=7)R
M96YT0FEN9&EN9UU;)V1I;64G72`]("1A='1R<SL*("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!D969A=6QT.@H@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=S97)V
M:6-E)SH*("`@("`@("`@("`@)&YS(#T@)'%N86UE+3YN<R`_("1T:&ES+3YW
M<V1L+3YN86UE<W!A8V5S6R1Q;F%M92T^;G-=(#H@4T-(14U!7U=31$P["@H@
M("`@("`@("`@("!S=VET8V@@*"1Q;F%M92T^;F%M92D@>PH@("`@("`@("`@
M("!C87-E("=P;W)T)SH*("`@("`@("`@("`@("`@("\O('-E8W0@,BXV('=S
M9&PZ<&]R="!A='1R:6)U=&5S.B!N86UE(&)I;F1I;F<*("`@("`@("`@("`@
M("`@("1T:&ES+3YC=7)R96YT4&]R="`]("1A='1R<ULG;F%M92==.PH@("`@
M("`@("`@("`@("`@)'1H:7,M/G=S9&PM/G-E<G9I8V5S6R1T:&ES+3YC=7)R
M96YT4V5R=FEC95U;)W!O<G1S)UU;)'1H:7,M/F-U<G)E;G10;W)T72`]("1A
M='1R<SL*("`@("`@("`@("`@("`@("\O(%A86"!H86-K('1O(&1E86P@=VET
M:"!B:6YD:6YG(&YA;65S<&%C97,*("`@("`@("`@("`@("`@("1Q;B`])B!N
M97<@44YA;64H)&%T=')S6R=B:6YD:6YG)UTI.PH@("`@("`@("`@("`@("`@
M)'1H:7,M/G=S9&PM/G-E<G9I8V5S6R1T:&ES+3YC=7)R96YT4V5R=FEC95U;
M)W!O<G1S)UU;)'1H:7,M/F-U<G)E;G10;W)T75LG8FEN9&EN9R==(#T@)'%N
M+3YN86UE.PH@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/G-E<G9I8V5S
M6R1T:&ES+3YC=7)R96YT4V5R=FEC95U;)W!O<G1S)UU;)'1H:7,M/F-U<G)E
M;G10;W)T75LG;F%M97-P86-E)UT@/2`D<6XM/FYS.PH@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=A9&1R97-S)SH*("`@("`@
M("`@("`@("`@("1T:&ES+3YW<V1L+3YS97)V:6-E<ULD=&AI<RT^8W5R<F5N
M=%-E<G9I8V5=6R=P;W)T<R==6R1T:&ES+3YC=7)R96YT4&]R=%U;)V%D9')E
M<W,G72`]("1A='1R<SL*("`@("`@("`@("`@("`@("\O('=H870@5%E012!O
M9B!P;W)T(&ES(&ET/R`@4T]!4"!O<B!(5%10/PH@("`@("`@("`@("`@("`@
M)&YS(#T@)'%N86UE+3YN<R`_("1T:&ES+3YW<V1L+3YN86UE<W!A8V5S6R1Q
M;F%M92T^;G-=(#H@4T-(14U!7U=31$P["B`@("`@("`@("`@("`@("!S=VET
M8V@@*"1N<RD@>PH@("`@("`@("`@("`@("`@8V%S92!30TA%34%?5U-$3%](
M5%10.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YS97)V:6-E
M<ULD=&AI<RT^8W5R<F5N=%-E<G9I8V5=6R=P;W)T<R==6R1T:&ES+3YC=7)R
M96YT4&]R=%U;)W1Y<&4G73TG:'1T<"<["B`@("`@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92!30TA%34%?4T]!4#H*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^<V5R=FEC97-;)'1H:7,M
M/F-U<G)E;G1397)V:6-E75LG<&]R=',G75LD=&AI<RT^8W5R<F5N=%!O<G1=
M6R=T>7!E)UT])W-O87`G.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@
M+R\@4VAO=6QD;B=T(&AA<'!E;BP@=V4G;&P@87-S=6UE(%-/05`N"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/G-E<G9I8V5S6R1T:&ES+3YC
M=7)R96YT4V5R=FEC95U;)W!O<G1S)UU;)'1H:7,M/F-U<G)E;G10;W)T75LG
M='EP92==/2=S;V%P)SL*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V1O8W5M96YT871I;VXG
M.@H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!D969A=6QT
M.@H@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("\O(%1O<"!L979E;"!E;&5M96YT<R!F;W5N9"!U;F1E
M<B!W<V1L.F1E9FEN:71I;VYS+@H@("`@("`@('-W:71C:"`H)'%N86UE+3YN
M86UE*2!["B`@("`@("`@8V%S92`G:6UP;W)T)SH*("`@("`@("`@("`@+R\@
M<V5C="`R+C$N,2!W<V1L.FEM<&]R="!A='1R:6)U=&5S.B!N86UE<W!A8V4@
M;&]C871I;VX*("`@("`@("`@("`@:68@*"AI<W-E="@D871T<G-;)VQO8V%T
M:6]N)UTI('Q\(&ES<V5T*"1A='1R<ULG<V-H96UA3&]C871I;VXG72DI("8F
M"B`@("`@("`@("`@("`@("`A:7-S970H)'1H:7,M/G=S9&PM/FEM<&]R='-;
M)&%T=')S6R=N86UE<W!A8V4G75TI*2!["B`@("`@("`@("`@("`@("`D=7)I
M(#T@:7-S970H)&%T=')S6R=L;V-A=&EO;B==*2`_("1A='1R<ULG;&]C871I
M;VXG72`Z("1A='1R<ULG<V-H96UA3&]C871I;VXG73L*("`@("`@("`@("`@
M("`@("1L;V-A=&EO;B`]($!P87)S95]U<FPH)'5R:2D["B`@("`@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1L;V-A=&EO;ELG<V-H96UE)UTI*2!["B`@("`@
M("`@("`@("`@("`@("`@)&)A<V4@/2!`<&%R<V5?=7)L*"1T:&ES+3YU<FDI
M.PH@("`@("`@("`@("`@("`@("`@("1U<FD@/2`D=&AI<RT^;65R9V55<FPH
M)&)A<V4L("1U<FDI.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@("1T:&ES+3YW<V1L+3YI;7!O<G1S6R1A='1R<ULG;F%M97-P86-E)UU=
M(#T@)&%T=')S.PH@("`@("`@("`@("`@("`@)&EM<&]R=%]P87)S97)?8VQA
M<W,@/2!G971?8VQA<W,H)'1H:7,I.PH@("`@("`@("`@("`@("`@)&EM<&]R
M=%]P87)S97(@/28@;F5W("1I;7!O<G1?<&%R<V5R7V-L87-S*"1U<FDL("1T
M:&ES+3YW<V1L+"`D=&AI<RT^9&]C<RD["B`@("`@("`@("`@("`@("!I9B`H
M)&EM<&]R=%]P87)S97(M/F9A=6QT*2!["B`@("`@("`@("`@("`@("`@("`@
M=6YS970H)'1H:7,M/G=S9&PM/FEM<&]R='-;)&%T=')S6R=N86UE<W!A8V4G
M75TI.PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1T:&ES+3YC=7)R96YT26UP
M;W)T(#T@)&%T=')S6R=N86UE<W!A8V4G73L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`O+R!#;VYT:6YU92!O;B!T;R!T:&4@)W1Y<&5S)R!C87-E("T@
M;&%C:R!O9B!B<F5A:SL@:7,*("`@("`@("`@("`@+R\@:6YT96YT:6]N86PN
M"@H@("`@("`@(&-A<V4@)W1Y<&5S)SH*("`@("`@("`@("`@+R\@<V5C="`R
M+C(@=W-D;#IT>7!E<PH@("`@("`@("`@("`D=&AI<RT^<W1A='5S(#T@)W1Y
M<&5S)SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)W-C:&5M
M82<Z"B`@("`@("`@("`@("\O(%=E(&-A;B!H:70@=&AI<R!A="!T:&4@=&]P
M(&QE=F5L(&EF('=E)W9E(&)E96X@87-K960@=&\*("`@("`@("`@("`@+R\@
M:6UP;W)T(&%N(%A31"!F:6QE+@H@("`@("`@("`@("!I9B`H(65M<'1Y*"1A
M='1R<ULG=&%R9V5T3F%M97-P86-E)UTI*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^<V-H96UA(#T@)'1H:7,M/G=S9&PM/F=E=$YA;65S<&%C94%T=')I
M8G5T94YA;64H)&%T=')S6R=T87)G971.86UE<W!A8V4G72D["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V-H96UA(#T@
M)'1H:7,M/G=S9&PM/F=E=$YA;65S<&%C94%T=')I8G5T94YA;64H)'1H:7,M
M/G=S9&PM/G1N<RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M
M/G=S9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA72`](&%R<F%Y*"D[
M"B`@("`@("`@("`@("1T:&ES+3YW<V1L+3YE;&5M96YT<ULD=&AI<RT^<V-H
M96UA72`](&%R<F%Y*"D["B`@("`@("`@("`@("1T:&ES+3YS8VAE;6%?<W1A
M8VM;72`]("1Q;F%M92T^;F%M93L*("`@("`@("`@("`@)'1H:7,M/G-T871U
M<R`]("=T>7!E<R<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E
M("=M97-S86=E)SH*("`@("`@("`@("`@+R\@<V5C="`R+C,@=W-D;#IM97-S
M86=E(&%T=')I8G5T97,Z(&YA;64@8VAI;&1R96XZ=W-D;#IP87)T"B`@("`@
M("`@("`@("1T:&ES+3YS=&%T=7,@/2`G;65S<V%G92<["B`@("`@("`@("`@
M(&EF("AI<W-E="@D871T<G-;)VYA;64G72DI('L*("`@("`@("`@("`@("`@
M("1T:&ES+3YC=7)R96YT365S<V%G92`]("1A='1R<ULG;F%M92==.PH@("`@
M("`@("`@("`@("`@)'1H:7,M/G=S9&PM/FUE<W-A9V5S6R1T:&ES+3YC=7)R
M96YT365S<V%G95T@/2!A<G)A>2@I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("!C87-E("=P;W)T5'EP92<Z"B`@("`@("`@
M("`@("\O('-E8W0@,BXT('=S9&PZ<&]R=%1Y<&4*("`@("`@("`@("`@+R\@
M871T<FEB=71E<SH@;F%M90H@("`@("`@("`@("`O+R!C:&EL9')E;CH@=W-D
M;#IO<&5R871I;VX*("`@("`@("`@("`@)'1H:7,M/G-T871U<R`]("=P;W)T
M5'EP92<["B`@("`@("`@("`@("1T:&ES+3YC=7)R96YT4&]R=%1Y<&4@/2`D
M871T<G-;)VYA;64G73L*("`@("`@("`@("`@)'1H:7,M/G=S9&PM/G!O<G14
M>7!E<ULD=&AI<RT^8W5R<F5N=%!O<G14>7!E72`](&%R<F%Y*"D["B`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=B:6YD:6YG)SH*("`@("`@
M("`@("`@+R\@<V5C="`R+C4@=W-D;#IB:6YD:6YG(&%T=')I8G5T97,Z(&YA
M;64@='EP90H@("`@("`@("`@("`O+R!C:&EL9')E;CH@=W-D;#IO<&5R871I
M;VX@<V]A<#IB:6YD:6YG(&AT='`Z8FEN9&EN9PH@("`@("`@("`@("!I9B`H
M)'%N86UE+3YN<R`F)B`D<6YA;64M/FYS("$]("1T:&ES+3YT;G,I('L*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1T:&ES+3YS=&%T=7,@/2`G8FEN9&EN9R<["B`@("`@("`@("`@("1T:&ES
M+3YC=7)R96YT0FEN9&EN9R`]("1A='1R<ULG;F%M92==.PH@("`@("`@("`@
M("`D<6X@/28@;F5W(%%.86UE*"1A='1R<ULG='EP92==*3L*("`@("`@("`@
M("`@)'1H:7,M/G=S9&PM/F)I;F1I;F=S6R1T:&ES+3YC=7)R96YT0FEN9&EN
M9UU;)W1Y<&4G72`]("1Q;BT^;F%M93L*("`@("`@("`@("`@)'1H:7,M/G=S
M9&PM/F)I;F1I;F=S6R1T:&ES+3YC=7)R96YT0FEN9&EN9UU;)VYA;65S<&%C
M92==(#T@)'%N+3YN<SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@)W-E<G9I8V4G.@H@("`@("`@("`@("`O+R!S96-T(#(N-R!W<V1L.G-E
M<G9I8V4@871T<FEB=71E<SH@;F%M92!C:&EL9')E;CH@<&]R=',*("`@("`@
M("`@("`@)'1H:7,M/F-U<G)E;G1397)V:6-E(#T@)&%T=')S6R=N86UE)UT[
M"B`@("`@("`@("`@("1T:&ES+3YW<V1L+3YS97)V:6-E<ULD=&AI<RT^8W5R
M<F5N=%-E<G9I8V5=6R=P;W)T<R==(#T@87)R87DH*3L*("`@("`@("`@("`@
M)'1H:7,M/G-T871U<R`]("=S97)V:6-E)SL*("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@(&-A<V4@)V1E9FEN:71I;VYS)SH*("`@("`@("`@("`@+R\@
M<V5C(#(N,2!W<V1L.F1E9FEN:71I;VYS"B`@("`@("`@("`@("\O(&%T=')I
M8G5T97,Z(&YA;64@=&%R9V5T3F%M97-P86-E('AM;&YS.BH*("`@("`@("`@
M("`@+R\@8VAI;&1R96XZ('=S9&PZ:6UP;W)T('=S9&PZ='EP97,@=W-D;#IM
M97-S86=E('=S9&PZ<&]R=%1Y<&4@=W-D;#IB:6YD:6YG('=S9&PZ<V5R=FEC
M90H@("`@("`@("`@("`D=&AI<RT^=W-D;"T^9&5F:6YI=&EO;B`]("1A='1R
M<SL*("`@("`@("`@("`@9F]R96%C:"`H)&%T=')S(&%S("1K97D@/3X@)'9A
M;'5E*2!["B`@("`@("`@("`@("`@("!I9B`H<W1R<W1R*"1K97DL("=X;6QN
M<SHG*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("`D<6X@/28@
M;F5W(%%.86UE*"1K97DI.PH@("`@("`@("`@("`@("`@("`@("\O(%A86"!N
M965D('1O(')E9F%C=&]R(&YS(&AA;F1L:6YG+@H@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YW<V1L+3YN86UE<W!A8V5S6R1Q;BT^;F%M95T@/2`D=F%L
M=64["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/FYS6R1V86QU
M95T@/2`D<6XM/FYA;64["B`@("`@("`@("`@("`@("`@("`@:68@*"1K97D@
M/3T@)W1A<F=E=$YA;65S<&%C92<@?'P*("`@("`@("`@("`@("`@("`@("`@
M("`@<W1R8V%S96-M<"@D=F%L=64L4T]!4%]30TA%34$I(#T](#`I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-O87!N<UM=(#T@)'%N+3YN
M86UE.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("AI;E]A<G)A>2@D=F%L=64L("1T:&ES+3Y?6$U,
M4V-H96UA*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/G=S9&PM/GAS9"`]("1V86QU93L*("`@("`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!I9B`H:7-S970H)&YS*2`F)B`D;G,I
M('L*("`@("`@("`@("`@("`@("1N86UE<W!A8V4@/2`G>&UL;G,Z)R`N("1N
M<SL*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/G=S9&PM/F1E9FEN:71I
M;VY;)&YA;65S<&%C95TI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/E]R86ES95-O87!&875L="@B<&%R<V4@97)R;W(L(&YO(&YA;65S
M<&%C92!F;W(@)&YA;65S<&%C92(L("1T:&ES+3YU<FDI.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@)'1H:7,M/G1N<R`]("1N<SL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!E;F0M96QE;65N="!H86YD;&5R+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!E;F1%;&5M96YT*"1P87)S97(L("1N86UE*0H@("`@
M>PH@("`@("`@("1S=&%C:W-I>F4@/2!C;W5N="@D=&AI<RT^96QE;65N=%]S
M=&%C:RD["B`@("`@("`@:68@*"1S=&%C:W-I>F4I('L*("`@("`@("`@("`@
M:68@*"1T:&ES+3YE;&5M96YT7W-T86-K6R1S=&%C:W-I>F4@+2`Q72`]/2`G
M9&5F:6YI=&EO;G,G*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<W1A='5S
M(#T@)R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@87)R87E?<&]P*"1T
M:&ES+3YE;&5M96YT7W-T86-K*3L*("`@("`@("!]"@H@("`@("`@(&EF("AS
M=')I<W1R*"1N86UE+"`G<V-H96UA)RDI('L*("`@("`@("`@("`@87)R87E?
M<&]P*"1T:&ES+3YS8VAE;6%?<W1A8VLI.PH@("`@("`@("`@("`D=&AI<RT^
M<V-H96UA(#T@)R<["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/G-C
M:&5M82D@>PH@("`@("`@("`@("!A<G)A>5]P;W`H)'1H:7,M/G-C:&5M85]S
M=&%C:RD["B`@("`@("`@("`@(&EF("AC;W5N="@D=&AI<RT^<V-H96UA7W-T
M86-K*2`\/2`Q*2!["B`@("`@("`@("`@("`@("`O*B!#;W)R96-T('1H92!T
M>7!E(&9O<B!S97%U96YC97,@=VET:"!M=6QT:7!L90H@("`@("`@("`@("`@
M("`@("H@96QE;65N=',N("HO"B`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/F-U<G)E;G1#;VUP;&5X5'EP92D@)B8@:7-S970H)'1H:7,M/G=S
M9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N
M=$-O;7!L97A4>7!E75LG='EP92==*0H@("`@("`@("`@("`@("`@("`@("8F
M("1T:&ES+3YW<V1L+3YC;VUP;&5X5'EP97-;)'1H:7,M/G-C:&5M85U;)'1H
M:7,M/F-U<G)E;G1#;VUP;&5X5'EP95U;)W1Y<&4G72`]/2`G07)R87DG"B`@
M("`@("`@("`@("`@("`@("`@)B8@87)R87E?:V5Y7V5X:7-T<R@G96QE;65N
M=',G+"`D=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=
M6R1T:&ES+3YC=7)R96YT0V]M<&QE>%1Y<&5=*0H@("`@("`@("`@("`@("`@
M("`@("8F(&-O=6YT*"1T:&ES+3YW<V1L+3YC;VUP;&5X5'EP97-;)'1H:7,M
M/G-C:&5M85U;)'1H:7,M/F-U<G)E;G1#;VUP;&5X5'EP95U;)V5L96UE;G1S
M)UTI(#X@,2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D
M;"T^8V]M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=6R1T:&ES+3YC=7)R96YT
M0V]M<&QE>%1Y<&5=6R=T>7!E)UT@/2`G4W1R=6-T)SL*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H<W1R:7-T<B@D
M;F%M92P@)V-O;7!L97A4>7!E)RDI('L*("`@("`@("`@("`@("`@("1T:&ES
M+3YC=7)R96YT0V]M<&QE>%1Y<&4@/2`G)SL*("`@("`@("`@("`@("`@(&EF
M("AC;W5N="@D=&AI<RT^<V-H96UA7V5L96UE;G1?<W1A8VLI*2!["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/F-U<G)E;G1%;&5M96YT(#T@87)R87E?
M<&]P*"1T:&ES+3YS8VAE;6%?96QE;65N=%]S=&%C:RD["B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC=7)R
M96YT16QE;65N="`]("<G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!](&5L<V5I9B`H<W1R:7-T<B@D;F%M92P@)V5L96UE;G0G*2D@>PH@("`@
M("`@("`@("`@("`@:68@*&-O=6YT*"1T:&ES+3YS8VAE;6%?96QE;65N=%]S
M=&%C:RDI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8W5R<F5N=$5L
M96UE;G0@/2!A<G)A>5]P;W`H)'1H:7,M/G-C:&5M85]E;&5M96YT7W-T86-K
M*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/F-U<G)E;G1%;&5M96YT(#T@)R<["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!%;&5M96YT(&-O;G1E;G0@:&%N9&QE<BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@8VAA<F%C=&5R1&%T82@D<&%R<V5R+"`D9&%T82D*("`@('L*("`@
M("`@("`O+R!3=&]R92!T:&4@9&]C=6UE;G1A=&EO;B!I;B!T:&4@5U-$3"!F
M:6QE+@H@("`@("`@(&EF("@D=&AI<RT^8W5R<F5N=%1A9R`]/2`G9&]C=6UE
M;G1A=&EO;B<I('L*("`@("`@("`@("`@)&1A=&$@/2!T<FEM*'!R96=?<F5P
M;&%C92@G+UQS*R\G+"`G("<L("1D871A*2D["B`@("`@("`@("`@(&EF("@A
M<W1R;&5N*"1D871A*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!S=VET8V@@*"1T:&ES+3YS=&%T=7,I
M('L*("`@("`@("`@("`@8V%S92`G<V5R=FEC92<Z"B`@("`@("`@("`@("`@
M("`D<'1R(#TF("1T:&ES+3YW<V1L+3YS97)V:6-E<ULD=&AI<RT^8W5R<F5N
M=%-E<G9I8V5=.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("!C87-E("=P;W)T5'EP92<Z"B`@("`@("`@("`@("`@("`D<'1R(#TF("1T
M:&ES+3YW<V1L+3YP;W)T5'EP97-;)'1H:7,M/F-U<G)E;G10;W)T5'EP95U;
M)'1H:7,M/F-U<G)E;G1/<&5R871I;VY=.PH@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("!C87-E("=B:6YD:6YG)SH*("`@("`@("`@("`@
M("`@("1P='(@/28@)'1H:7,M/G=S9&PM/F)I;F1I;F=S6R1T:&ES+3YC=7)R
M96YT0FEN9&EN9UT["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&-A<V4@)VUE<W-A9V4G.@H@("`@("`@("`@("`@("`@)'!T<B`])B`D
M=&AI<RT^=W-D;"T^;65S<V%G97-;)'1H:7,M/F-U<G)E;G1-97-S86=E73L*
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G;W!E
M<F%T:6]N)SH*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M8V%S92`G='EP97,G.@H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3YC=7)R96YT0V]M<&QE>%1Y<&4I("8F"B`@("`@("`@("`@("`@("`@("`@
M:7-S970H)'1H:7,M/G=S9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA
M75LD=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E72DI('L*("`@("`@("`@("`@
M("`@("`@("!I9B`H)'1H:7,M/F-U<G)E;G1%;&5M96YT*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1P='(@/28@)'1H:7,M/G=S9&PM/F-O;7!L97A4
M>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E
M75LG96QE;65N=',G75LD=&AI<RT^8W5R<F5N=$5L96UE;G1=.PH@("`@("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1P='(@/28@)'1H:7,M/G=S9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H
M96UA75LD=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E73L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*&ES<V5T*"1P
M='(I*2!["B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1P=');)V1O8W5M
M96YT871I;VXG72DI('L*("`@("`@("`@("`@("`@("`@("`D<'1R6R=D;V-U
M;65N=&%T:6]N)UT@/2`G)SL*("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@)'!T<ELG9&]C=6UE;G1A=&EO;B==("X]("<@
M)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1P=');)V1O
M8W5M96YT871I;VXG72`N/2`D9&%T83L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J("1P87)S960@:7,@86X@87)R87D@
M<F5T=7)N960@8GD@<&%R<V5?=7)L*"DN"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(&UE<F=E57)L*"1P87)S
M960L("1P871H*0H@("`@>PH@("`@("`@(&EF("@A:7-?87)R87DH)'!A<G-E
M9"DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@)'5R:2`]("<G.PH@("`@("`@(&EF("@A96UP='DH)'!A<G-E9%LG
M<V-H96UE)UTI*2!["B`@("`@("`@("`@("1S97`@/2`H<W1R=&]L;W=E<B@D
M<&%R<V5D6R=S8VAE;64G72D@/3T@)VUA:6QT;R<@/R`G.B<@.B`G.B\O)RD[
M"B`@("`@("`@("`@("1U<FD@/2`D<&%R<V5D6R=S8VAE;64G72`N("1S97`[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)'!A<G-E9%LG<&%S<R==
M*2D@>PH@("`@("`@("`@("`D=7)I("X]("(D<&%R<V5D6W5S97)=.B1P87)S
M961;<&%S<UU`(CL*("`@("`@("!](&5L<V5I9B`H:7-S970H)'!A<G-E9%LG
M=7-E<B==*2D@>PH@("`@("`@("`@("`D=7)I("X]("(D<&%R<V5D6W5S97)=
M0"(["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)'!A<G-E9%LG:&]S
M="==*2D@>PH@("`@("`@("`@("`D=7)I("X]("1P87)S961;)VAO<W0G73L*
M("`@("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1P87)S961;)W!O<G0G72DI
M('L*("`@("`@("`@("`@)'5R:2`N/2`B.B1P87)S961;<&]R=%TB.PH@("`@
M("`@('T*("`@("`@("!I9B`H)'!A=&A;,%T@(3T@)R\G("8F(&ES<V5T*"1P
M87)S961;)W!A=&@G72DI('L*("`@("`@("`@("`@:68@*"1P87)S961;)W!A
M=&@G75MS=')L96XH)'!A<G-E9%LG<&%T:"==*2`M(#%=("$]("<O)RD@>PH@
M("`@("`@("`@("`@("`@)'!A=&@@/2!D:7)N86UE*"1P87)S961;)W!A=&@G
M72D@+B`G+R<@+B`D<&%T:#L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1P871H(#T@)'!A<G-E9%LG<&%T:"==("X@)'!A=&@["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)'!A=&@@/2`D=&AI<RT^7VYO<FUA
M;&EZ92@D<&%T:"D["B`@("`@("`@?0H@("`@("`@("1S97`@/2`D<&%T:%LP
M72`]/2`G+R<@/R`G)R`Z("<O)SL*("`@("`@("`D=7)I("X]("1S97`@+B`D
M<&%T:#L*"B`@("`@("`@<F5T=7)N("1U<FD["B`@("!]"@H@("`@9G5N8W1I
M;VX@7VYO<FUA;&EZ92@D<&%T:%]S='(I"B`@("!["B`@("`@("`@)'!W9"`]
M("<G.PH@("`@("`@("1S=')!<G(@/2!P<F5G7W-P;&ET*"<O*%PO*2\G+"`D
M<&%T:%]S='(L("TQ+"!04D5'7U-03$E47TY/7T5-4%19*3L*("`@("`@("`D
M<'=D07)R(#T@)R<["B`@("`@("`@)&H@/2`P.PH@("`@("`@(&9O<B`H)&D@
M/2`P.R`D:2`\(&-O=6YT*"1S=')!<G(I.R`D:2LK*2!["B`@("`@("`@("`@
M(&EF("@D<W1R07)R6R1I72`A/2`G("XN)RD@>PH@("`@("`@("`@("`@("`@
M:68@*"1S=')!<G);)&E=("$]("<@+B<I('L*("`@("`@("`@("`@("`@("`@
M("`D<'=D07)R6R1J72`]("1S=')!<G);)&E=.PH@("`@("`@("`@("`@("`@
M("`@("1J*RL["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("!A<G)A>5]P;W`H)'!W9$%R<BD["B`@("`@
M("`@("`@("`@("`D:BTM.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@("1P4W1R(#T@:6UP;&]D92@G+R<L("1P=V1!<G(I.PH@("`@("`@("1P
M=V0@/2`H<W1R;&5N*"1P4W1R*2`^(#`I(#\@*"<O)R`N("1P4W1R*2`Z("<O
M)SL*("`@("`@("!R971U<FX@)'!W9#L*("`@('T*"GT*"B\J*@H@*B!087)S
M97,@=&AE('1Y<&5S(&%N9"!M971H;V1S('5S960@:6X@=V5B('-E<G9I8V4@
M;V)J96-T<R!I;G1O('1H92!I;G1E<FYA;`H@*B!D871A('-T<G5C='5R97,@
M=7-E9"!B>2!33T%07U=31$PN"B`J"B`J($%S<W5M97,@=&AE(%-/05!?5U-$
M3"!C;&%S<R!I<R!U;G!O<'5L871E9"!T;R!S=&%R="!W:71H+@H@*@H@*B!`
M875T:&]R($-H<FES($-O92`\:6YF;T!I;G1E;&QI9V5N='-T<F5A;6EN9RYC
M;VT^"B`J+PIC;&%S<R!33T%07U=31$Q?3V)J96-T4&%R<V5R(&5X=&5N9',@
M4T]!4%]"87-E"GL*("`@("\J*@H@("`@("H@5&%R9V5T(&YA;65S<&%C92!F
M;W(@=&AE(%=31$P@9&]C=6UE;G0@=VEL;"!H879E('1H92!F;VQL;W=I;F<*
M("`@("`J('!R969I>"X*("`@("`J+PH@("`@=F%R("1T;G-0<F5F:7@@/2`G
M=&YS)SL*"B`@("`O*BH*("`@("`J(%)E9F5R96YC92!T;R!T:&4@4T]!4%]7
M4T1,(&]B:F5C="!T;R!P;W!U;&%T92X*("`@("`J+PH@("`@=F%R("1W<V1L
M(#T@;G5L;#L*"B`@("`O*BH@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!`
M<&%R86T@("1O8FIE8W1S(%)E9F5R96YC92!T;R!T:&4@;V)J96-T(&]R(&%R
M<F%Y(&]F(&]B:F5C=',@=&\@<&%R<V4*("`@("`J($!P87)A;2`@)'=S9&P@
M4F5F97)E;F-E('1O('1H92!33T%07U=31$P@;V)J96-T('1O('!O<'5L871E
M"B`@("`@*B!`<&%R86T@("1T87)G971.86UE<W!A8V4@5&AE('1A<F=E="!N
M86UE<W!A8V4@;V8@<V-H96UA('1Y<&5S(&5T8RX*("`@("`J($!P87)A;2`@
M)'-E<G9I8V5?;F%M92!.86UE(&]F('1H92!74T1,(#QS97)V:6-E/@H@("`@
M("H@0'!A<F%M("`D<V5R=FEC95]D97-C($]P=&EO;F%L(&1E<V-R:7!T:6]N
M(&]F('1H92!74T1,(#QS97)V:6-E/@H@("`@("HO"B`@("!F=6YC=&EO;B!3
M3T%07U=31$Q?3V)J96-T4&%R<V5R*"8D;V)J96-T<RP@)B1W<V1L+"`D=&%R
M9V5T3F%M97-P86-E+"`D<V5R=FEC95]N86UE+"`D<V5R=FEC95]D97-C(#T@
M)R<I"B`@("!["B`@("`@("`@<&%R96YT.CI33T%07T)A<V4H)U=31$Q/0DI%
M0U1005)315(G*3L*"B`@("`@("`@)'1H:7,M/G=S9&P@/2`F)'=S9&P["@H@
M("`@("`@("\O(%-E="!U<"!T:&4@4T]!4%]74T1,(&]B:F5C=`H@("`@("`@
M("1T:&ES+3Y?:6YI=&EA;&ES92@D<V5R=FEC95]N86UE*3L*"B`@("`@("`@
M+R\@4&%R<V4@96%C:"!W96(@<V5R=FEC92!O8FIE8W0*("`@("`@("`D=W-D
M;%]R968@/2`H:7-?87)R87DH)&]B:F5C=',I/R`D;V)J96-T<R`Z(&%R<F%Y
M*"8D;V)J96-T<RDI.PH*("`@("`@("!F;W)E86-H("@D=W-D;%]R968@87,@
M)')E9E]I=&5M*2!["B`@("`@("`@("`@(&EF("@A:7-?;V)J96-T*"1R969?
M:71E;2DI"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O
M87!&875L="@G26YV86QI9"!W96(@<V5R=FEC92!O8FIE8W0@<&%S<V5D('1O
M(&]B:F5C="!P87)S97(G+"`G=7)N.B<@+B!G971?8VQA<W,H)&]B:F5C="DI
M.PH*("`@("`@("`@("`@:68@*"1T:&ES+3Y?<&%R<V4H)')E9E]I=&5M+"`D
M=&%R9V5T3F%M97-P86-E+"`D<V5R=FEC95]N86UE*2`A/2!T<G5E*0H@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("`O+R!"=6EL
M9"!B:6YD:6YG<R!F<F]M(&%B<W1R86-T(&1A=&$N"B`@("`@("`@:68@*"1T
M:&ES+3YF875L="`]/2!N=6QL*2!["B`@("`@("`@("`@("1T:&ES+3Y?9V5N
M97)A=&5":6YD:6YG<T%N9%-E<G9I8V5S*"1T87)G971.86UE<W!A8V4L("1S
M97)V:6-E7VYA;64L("1S97)V:6-E7V1E<V,I.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($EN:71I86QI<V4@=&AE(%-/05!?5U-$3"!T<F5E
M("AD97-T<G5C=&EV92DN"B`@("`@*@H@("`@("H@268@=&AE(&]B:F5C="!H
M87,@86QR96%D>2!B965N(&EN:71I86QI<V5D+"!T:&4@;VYL>2!E9F9E8W0*
M("`@("`J('=I;&P@8F4@=&\@8VAA;F=E('1H92!T;G,@;F%M97-P86-E('1O
M('1H92!N97<@<V5R=FEC92!N86UE+@H@("`@("H*("`@("`J($!P87)A;2`@
M)'-E<G9I8V5?;F%M92!.86UE(&]F('1H92!74T1,(#QS97)V:6-E/@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]I;FET
M:6%L:7-E*"1S97)V:6-E7VYA;64I"B`@("!["B`@("`@("`@+R\@4V5T('5P
M('1H92!B87-I8R!N86UE<W!A8V5S('1H870@86QL(%=31$P@9&5F:6YI=&EO
M;G,@=7-E+@H@("`@("`@("1T:&ES+3YW<V1L+3YN86UE<W!A8V5S6R=W<V1L
M)UT@/2!30TA%34%?5U-$3#L@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("\O(%=31$P@;&%N9W5A9V4*("`@("`@("`D=&AI<RT^=W-D
M;"T^;F%M97-P86-E<ULG<V]A<"==(#T@4T-(14U!7U-/05`[("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!74T1,(%-/05`@8FEN
M9&EN9W,*("`@("`@("`D=&AI<RT^=W-D;"T^;F%M97-P86-E<ULD=&AI<RT^
M=&YS4')E9FEX72`]("=U<FXZ)R`N("1S97)V:6-E7VYA;64[("`@("`@("`@
M("`@("`@("`O+R!487)G970@;F%M97-P86-E"B`@("`@("`@)'1H:7,M/G=S
M9&PM/FYA;65S<&%C97-;)WAS9"==(#T@87)R87E?<V5A<F-H*"=X<V0G+"`D
M=&AI<RT^7VYA;65S<&%C97,I.R`@("`@("`@("`@+R\@6$U,(%-C:&5M80H@
M("`@("`@("1T:&ES+3YW<V1L+3YN86UE<W!A8V5S6R=33T%0+45.0R==(#T@
M87)R87E?<V5A<F-H*"=33T%0+45.0R<L("1T:&ES+3Y?;F%M97-P86-E<RD[
M("\O(%-/05`@='EP97,*"B`@("`@("`@+R\@6%A8(%)E9F%C=&]R("1N86UE
M<W!A8V4O)&YS(&9O<B!3:&%N92`Z+2D*("`@("`@("!U;G-E="@D=&AI<RT^
M=W-D;"T^;G-;)W5R;CHG("X@)'-E<G9I8V5?;F%M95TI.PH@("`@("`@("1T
M:&ES+3YW<V1L+3YN<R`K/2!A<G)A>5]F;&EP*"1T:&ES+3YW<V1L+3YN86UE
M<W!A8V5S*3L*"B`@("`@("`@+R\@26UP;W)T<R!A<F4@;F]T(&EM<&QE;65N
M=&5D(&EN(%=31$P@9V5N97)A=&EO;B!F<F]M(&-L87-S97,N"B`@("`@("`@
M+R\@*BHJ(#QW<V1L.FEM<&]R=#X@*BHJ"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!087)S97(@+2!T86ME<R!A('-I;F=L92!O8FIE8W0@=&\@861D('1O('1R
M964*("`@("`J("AN;VXM9&5S=')U8W1I=F4I+@H@("`@("H*("`@("`J($!P
M87)A;2`@)&]B:F5C="!2969E<F5N8V4@=&\@=&AE(&]B:F5C="!T;R!P87)S
M90H@("`@("H@0'!A<F%M("`D<V5R=FEC95]N86UE($YA;64@;V8@=&AE(%=3
M1$P@/'-E<G9I8V4^"B`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@
M("!F=6YC=&EO;B!?<&%R<V4H)B1O8FIE8W0L("1S8VAE;6%.86UE<W!A8V4L
M("1S97)V:6-E7VYA;64I"B`@("!["B`@("`@("`@+R\@0W)E871E(&YA;65S
M<&%C92!P<F5F:7@@9F]R('1H92!S8VAE;6$*("`@("`@("`O+R!86%@@;F]T
M('9E<GD@96QE9V%N="`Z+2@*"B`@("`@("`@;&ES="@D<V-H4')E9FEX+"`D
M9F]O*2`]("1T:&ES+3Y?9V5T5'EP94YS*"=[)R`N("1S8VAE;6%.86UE<W!A
M8V4N)WTG*3L*("`@("`@("!U;G-E="@D9F]O*3L*"B`@("`@("`@+R\@4&%R
M<V4@86QL('1H92!T>7!E<R!D969I;F5D(&)Y('1H92!O8FIE8W0@:6X@=VAA
M=&5V97(*("`@("`@("`O+R!S8VAE;6$@;&%N9W5A9V4@=V4@87)E('5S:6YG
M("AC=7)R96YT;'D@7U]T>7!E9&5F(&%R<F%Y<RD*("`@("`@("`O+R`J*BH@
M/'=S9&PZ='EP97,^("HJ*@H*("`@("`@("!F;W)E86-H("@D;V)J96-T+3Y?
M7W1Y<&5D968@87,@)'1Y<&5.86UE(#T^("1T>7!E5F%L=64I('L*("`@("`@
M("`@("`@+R\@1V5T+V-R96%T92!N86UE<W!A8V4@9&5F:6YI=&EO;@H*("`@
M("`@("`@("`@;&ES="@D;G-0<F5F:7@L("1T>7!E3F%M92D@/2`D=&AI<RT^
M7V=E=%1Y<&5.<R@D='EP94YA;64I.PH*("`@("`@("`@("`@+R\@0W)E871E
M('1Y<&4@9&5F:6YI=&EO;@H*("`@("`@("`@("`@)'1H:7,M/G=S9&PM/F-O
M;7!L97A4>7!E<ULD<V-H4')E9FEX75LD='EP94YA;65=(#T@87)R87DH)VYA
M;64G(#T^("1T>7!E3F%M92D["B`@("`@("`@("`@("1T:&ES5'EP92`])B`D
M=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1S8VA0<F5F:7A=6R1T>7!E3F%M
M95T["@H@("`@("`@("`@("`O+R!!8V-O<F1I;F<@=&\@1&UI=')I)W,@9&]C
M=6UE;G1A=&EO;BP@7U]T>7!E9&5F(&-O;65S(&EN('1W;PH@("`@("`@("`@
M("`O+R!F;&%V;W)S.@H@("`@("`@("`@("`O+R!!<G)A>2`](&%R<F%Y*&%R
M<F%Y*")I=&5M(B`]/B`B=F%L=64B*2D*("`@("`@("`@("`@+R\@4W1R=6-T
M(#T@87)R87DH(FET96TQ(B`]/B`B=F%L=64Q(BP@(FET96TR(B`]/B`B=F%L
M=64R(BP@+BXN*0H*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1T>7!E5F%L
M=64I*2!["B`@("`@("`@("`@("`@("!R97-E="@D='EP959A;'5E*3L*("`@
M("`@("`@("`@("`@(&EF("AI<U]A<G)A>2AC=7)R96YT*"1T>7!E5F%L=64I
M*2`F)B!C;W5N="@D='EP959A;'5E*2`]/2`Q"B`@("`@("`@("`@("`@("`@
M("`@)B8@8V]U;G0H8W5R<F5N="@D='EP959A;'5E*2D@/3T@,2D@>PH@("`@
M("`@("`@("`@("`@("`@("\O($ET)W,@86X@87)R87D*"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7-4>7!E6R=T>7!E)UT@/2`G07)R87DG.PH@("`@("`@
M("`@("`@("`@("`@(')E<V5T*&-U<G)E;G0H)'1Y<&5686QU92DI.PH@("`@
M("`@("`@("`@("`@("`@(&QI<W0H)&YS4')E9FEX+"`D='EP94YA;64I(#T@
M)'1H:7,M/E]G9714>7!E3G,H8W5R<F5N="AC=7)R96YT*"1T>7!E5F%L=64I
M*2D["B`@("`@("`@("`@("`@("`@("`@)'1H:7-4>7!E6R=N86UE<W!A8V4G
M72`]("1N<U!R969I>#L*("`@("`@("`@("`@("`@("`@("`D=&AI<U1Y<&5;
M)V%R<F%Y5'EP92==(#T@)'1Y<&5.86UE("X@)UM=)SL*("`@("`@("`@("`@
M("`@('T@96QS96EF("@A:7-?87)R87DH8W5R<F5N="@D='EP959A;'5E*2DI
M('L*("`@("`@("`@("`@("`@("`@("`O+R!)="=S(&$@<W1R=6-T"@H@("`@
M("`@("`@("`@("`@("`@("1T:&ES5'EP95LG='EP92==(#T@)U-T<G5C="<[
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7-4>7!E6R=O<F1E<B==(#T@)V%L
M;"<["B`@("`@("`@("`@("`@("`@("`@)'1H:7-4>7!E6R=N86UE<W!A8V4G
M72`]("1N<U!R969I>#L*("`@("`@("`@("`@("`@("`@("`D=&AI<U1Y<&5;
M)V5L96UE;G1S)UT@/2!A<G)A>2@I.PH*("`@("`@("`@("`@("`@("`@("!F
M;W)E86-H("@D='EP959A;'5E(&%S("1E;&5M96YT3F%M92`]/B`D96QE;65N
M=%1Y<&4I('L*("`@("`@("`@("`@("`@("`@("`@("`@;&ES="@D;G-0<F5F
M:7@L("1T>7!E3F%M92D@/2`D=&AI<RT^7V=E=%1Y<&5.<R@D96QE;65N=%1Y
M<&4I.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<U1Y<&5;)V5L96UE
M;G1S)UU;)&5L96UE;G1.86UE75LG;F%M92==(#T@)&5L96UE;G1.86UE.PH@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<U1Y<&5;)V5L96UE;G1S)UU;
M)&5L96UE;G1.86UE75LG='EP92==(#T@)'1Y<&5.86UE.PH@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<U1Y<&5;)V5L96UE;G1S)UU;)&5L96UE;G1.
M86UE75LG;F%M97-P86-E)UT@/2`D;G-0<F5F:7@["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`O+R!)="=S(&5R<F]N96]U<PH@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")4:&4@='EP92!D969I
M;FET:6]N(&9O<B`D;G-0<F5F:7@Z)'1Y<&5.86UE(&ES(&EN=F%L:60N(BP@
M)W5R;CHG("X@9V5T7V-L87-S*"1O8FIE8W0I*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("\O($ET
M)W,@97)R;VYE;W5S"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R
M86ES95-O87!&875L="@B5&AE('1Y<&4@9&5F:6YI=&EO;B!F;W(@)&YS4')E
M9FEX.B1T>7!E3F%M92!I<R!I;G9A;&ED+B(L("=U<FXZ)R`N(&=E=%]C;&%S
M<R@D;V)J96-T*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("\O($-R96%T92!A;B!E;7!T>2!E;&5M96YT(&%R<F%Y('=I=&@@=&AE('1A
M<F=E="!N86UE<W!A8V4*("`@("`@("`O+R!P<F5F:7@L('1O(&UA=&-H('1H
M92!R97-U;'1S(&]F(%=31$P@<&%R<VEN9RX*"B`@("`@("`@)'1H:7,M/G=S
M9&PM/F5L96UE;G1S6R1S8VA0<F5F:7A=(#T@87)R87DH*3L*"B`@("`@("`@
M+R\@4&]P=6QA=&4@=')E92!W:71H(&UE<W-A9V4@:6YF;W)M871I;VX*("`@
M("`@("`O+R`J*BH@/'=S9&PZ;65S<V%G93X@*BHJ"@H@("`@("`@(&9O<F5A
M8V@@*"1O8FIE8W0M/E]?9&ES<&%T8VA?;6%P(&%S("1O<&5R871I;VY.86UE
M(#T^("1M97-S86=E<RD@>PH@("`@("`@("`@("!F;W)E86-H("@D;65S<V%G
M97,@87,@)&UE<W-A9V54>7!E(#T^("1M97-S86=E4&%R=',I('L*("`@("`@
M("`@("`@("`@('5N<V5T*"1T:&ES365S<V%G92D["@H@("`@("`@("`@("`@
M("`@<W=I=&-H("@D;65S<V%G951Y<&4I('L*("`@("`@("`@("`@("`@(&-A
M<V4@)VEN)SH*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^;65S
M<V%G97-;)&]P97)A=&EO;DYA;64@+B`G4F5Q=65S="==(#T@87)R87DH*3L*
M("`@("`@("`@("`@("`@("`@("`D=&AI<TUE<W-A9V4@/28@)'1H:7,M/G=S
M9&PM/FUE<W-A9V5S6R1O<&5R871I;VY.86UE("X@)U)E<75E<W0G73L*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E
M("=O=70G.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YM97-S
M86=E<ULD;W!E<F%T:6]N3F%M92`N("=297-P;VYS92==(#T@87)R87DH*3L*
M("`@("`@("`@("`@("`@("`@("`D=&AI<TUE<W-A9V4@/28@)'1H:7,M/G=S
M9&PM/FUE<W-A9V5S6R1O<&5R871I;VY.86UE("X@)U)E<W!O;G-E)UT["B`@
M("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S
M92`G86QI87,G.@H@("`@("`@("`@("`@("`@("`@("\O($1O(&YO=&AI;F<*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!D
M969A=6QT.@H@("`@("`@("`@("`@("`@("`@("\O($5R<F]R(&-O;F1I=&EO
M;@H@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<TUE<W-A9V4I*2![
M"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&UE<W-A9V5087)T<R!A
M<R`D<&%R=$YA;64@/3X@)'!A<G14>7!E*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@(&QI<W0@*"1N<U!R969I>"P@)'1Y<&5.86UE*2`]("1T:&ES+3Y?
M9V5T5'EP94YS*"1P87)T5'EP92D["@H@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<TUE<W-A9V5;)'!A<G1.86UE72`](&%R<F%Y*`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)VYA;64G(#T^("1P87)T3F%M92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`]/B`D='EP94YA;64L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G;F%M97-P86-E)R`]/B`D;G-0
M<F5F:7@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`O+R!0;W!U;&%T92!T<F5E('=I=&@@<&]R
M=%1Y<&4@:6YF;W)M871I;VX*("`@("`@("`O+R!86%@@0W5R<F5N="!I;7!L
M96UE;G1A=&EO;B!O;FQY('-U<'!O<G1S(&]N92!P;W)T5'EP92!T:&%T"B`@
M("`@("`@+R\@96YC;VUP87-S97,@86QL(&]F('1H92!O<&5R871I;VYS(&%V
M86EL86)L92X*("`@("`@("`O+R`J*BH@/'=S9&PZ<&]R=%1Y<&4^("HJ*@H*
M("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YW<V1L+3YP;W)T5'EP97-;)'-E
M<G9I8V5?;F%M92`N("=0;W)T)UTI*2!["B`@("`@("`@("`@("1T:&ES+3YW
M<V1L+3YP;W)T5'EP97-;)'-E<G9I8V5?;F%M92`N("=0;W)T)UT@/2!A<G)A
M>2@I.PH@("`@("`@('T*("`@("`@("`D=&AI<U!O<G14>7!E(#TF("1T:&ES
M+3YW<V1L+3YP;W)T5'EP97-;)'-E<G9I8V5?;F%M92`N("=0;W)T)UT["@H@
M("`@("`@(&9O<F5A8V@@*"1O8FIE8W0M/E]?9&ES<&%T8VA?;6%P(&%S("1O
M<&5R871I;VY.86UE(#T^("1M97-S86=E<RD@>PH@("`@("`@("`@("`D=&AI
M<U!O<G14>7!E6R1O<&5R871I;VY.86UE72`](&%R<F%Y*"=N86UE)R`]/B`D
M;W!E<F%T:6]N3F%M92D["@H@("`@("`@("`@("!F;W)E86-H("@D;65S<V%G
M97,@87,@)&UE<W-A9V54>7!E(#T^("1M97-S86=E4&%R=',I('L*("`@("`@
M("`@("`@("`@('-W:71C:"`H)&UE<W-A9V54>7!E*2!["B`@("`@("`@("`@
M("`@("!C87-E("=I;B<Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7-0;W)T
M5'EP95LD;W!E<F%T:6]N3F%M95U;)VEN<'5T)UT@/2!A<G)A>2@*("`@("`@
M("`@("`@("`@("`@("`@("`@)VUE<W-A9V4G(#T^("1O<&5R871I;VY.86UE
M("X@)U)E<75E<W0G+`H@("`@("`@("`@("`@("`@("`@("`@("`G;F%M97-P
M86-E)R`]/B`D=&AI<RT^=&YS4')E9FEX*3L*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=O=70G.@H@("`@("`@
M("`@("`@("`@("`@("1T:&ES4&]R=%1Y<&5;)&]P97)A=&EO;DYA;65=6R=O
M=71P=70G72`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`G;65S
M<V%G92<@/3X@)&]P97)A=&EO;DYA;64@+B`G4F5S<&]N<V4G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`G;F%M97-P86-E)R`]/B`D=&AI<RT^=&YS4')E
M9FEX*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!486ME(&%L;"!T:&4@86)S
M=')A8W0@5U-$3"!D871A(&%N9"!B=6EL9"!C;VYC<F5T92!B:6YD:6YG<R!A
M;F0*("`@("`J('-E<G9I8V5S("AD97-T<G5C=&EV92DN"B`@("`@*@H@("`@
M("H@6%A8($-U<G)E;G0@:6UP;&5M96YT871I;VX@9&ES8V%R9',@)'-E<G9I
M8V5?9&5S8RX*("`@("`J"B`@("`@*B!`<&%R86T@("1S8VAE;6%.86UE<W!A
M8V4@3F%M97-P86-E(&9O<B!T>7!E<R!E=&,N"B`@("`@*B!`<&%R86T@("1S
M97)V:6-E7VYA;64@3F%M92!O9B!T:&4@5U-$3"`\<V5R=FEC93X*("`@("`J
M($!P87)A;2`@)'-E<G9I8V5?9&5S8R!/<'1I;VYA;"!D97-C<FEP=&EO;B!O
M9B!T:&4@5U-$3"`\<V5R=FEC93X*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("HO"B`@("!F=6YC=&EO;B!?9V5N97)A=&5":6YD:6YG<T%N9%-E<G9I
M8V5S*"1S8VAE;6%.86UE<W!A8V4L("1S97)V:6-E7VYA;64L("1S97)V:6-E
M7V1E<V,@/2`G)RD*("`@('L*("`@("`@("`O+R!0;W!U;&%T92!T<F5E('=I
M=&@@8FEN9&EN9W,@:6YF;W)M871I;VX*("`@("`@("`O+R!86%@@0W5R<F5N
M="!I;7!L96UE;G1A=&EO;B!O;FQY('-U<'!O<G1S(&]N92!B:6YD:6YG('1H
M870*("`@("`@("`O+R!M871C:&5S('1H92!S:6YG;&4@<&]R=%1Y<&4@86YD
M(&%L;"!O9B!I=',@;W!E<F%T:6]N<RX*("`@("`@("`O+R!86%@@27,@=&AI
M<R!T:&4@8V]R<F5C="!U<V4@;V8@)'-C:&5M84YA;65S<&%C92!H97)E/PH@
M("`@("`@("\O("HJ*B`\=W-D;#IB:6YD:6YG/B`J*BH*"B`@("`@("`@)'1H
M:7,M/G=S9&PM/F)I;F1I;F=S6R1S97)V:6-E7VYA;64@+B`G0FEN9&EN9R==
M(#T@87)R87DH"B`@("`@("`@("`@("`@("`G='EP92<@/3X@)'-E<G9I8V5?
M;F%M92`N("=0;W)T)RP*("`@("`@("`@("`@("`@("=N86UE<W!A8V4G(#T^
M("1T:&ES+3YT;G-0<F5F:7@L"B`@("`@("`@("`@("`@("`G<W1Y;&4G(#T^
M("=R<&,G+`H@("`@("`@("`@("`@("`@)W1R86YS<&]R="<@/3X@4T-(14U!
M7U-/05!?2%144"P*("`@("`@("`@("`@("`@("=O<&5R871I;VYS)R`]/B!A
M<G)A>2@I*3L*("`@("`@("`D=&AI<T)I;F1I;F<@/28@)'1H:7,M/G=S9&PM
M/F)I;F1I;F=S6R1S97)V:6-E7VYA;64@+B`G0FEN9&EN9R==.PH*("`@("`@
M("!F;W)E86-H("@D=&AI<RT^=W-D;"T^<&]R=%1Y<&5S6R1S97)V:6-E7VYA
M;64@+B`G4&]R="==(&%S("1O<&5R871I;VY.86UE(#T^("1O<&5R871I;VY$
M871A*2!["B`@("`@("`@("`@("1T:&ES0FEN9&EN9ULG;W!E<F%T:6]N<R==
M6R1O<&5R871I;VY.86UE72`](&%R<F%Y*`H@("`@("`@("`@("`@("`@)W-O
M87!!8W1I;VXG(#T^("1S8VAE;6%.86UE<W!A8V4@+B`G(R<@+B`D;W!E<F%T
M:6]N3F%M92P*("`@("`@("`@("`@("`@("=S='EL92<@/3X@)'1H:7-":6YD
M:6YG6R=S='EL92==*3L*"B`@("`@("`@("`@(&9O<F5A8V@@*&%R<F%Y*"=I
M;G!U="<L("=O=71P=70G*2!A<R`D;65S<V%G951Y<&4I"B`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)&]P97)A=&EO;D1A=&%;)&UE<W-A9V54>7!E72DI
M('L*("`@("`@("`@("`@("`@("`@("`D=&AI<T)I;F1I;F=;)V]P97)A=&EO
M;G,G75LD;W!E<F%T:6]N3F%M95U;)&UE<W-A9V54>7!E72`](&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5S92<@/3X@)V5N8V]D960G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYA;65S<&%C92<@/3X@
M)'-C:&5M84YA;65S<&%C92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=E;F-O9&EN9U-T>6QE)R`]/B!33T%07U-#2$5-05]%3D-/1$E.1RD["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!0;W!U;&%T
M92!T<F5E('=I=&@@<V5R=FEC92!I;F9O<FUA=&EO;@H@("`@("`@("\O(%A8
M6"!#=7)R96YT(&EM<&QE;65N=&%T:6]N('-U<'!O<G1S(&]N92!S97)V:6-E
M('=H:6-H(&=R;W5P<PH@("`@("`@("\O(&%L;"!O9B!T:&4@<&]R=',@=&]G
M971H97(L(&]N92!P;W)T('!E<B!B:6YD:6YG"B`@("`@("`@+R\@6%A8(%=H
M870@86)O=70@:'1T<',_"B`@("`@("`@+R\@*BHJ(#QW<V1L.G-E<G9I8V4^
M("HJ*@H*("`@("`@("`D=&AI<RT^=W-D;"T^<V5R=FEC97-;)'-E<G9I8V5?
M;F%M92`N("=397)V:6-E)UT@/2!A<G)A>2@G<&]R=',G(#T^(&%R<F%Y*"DI
M.PH@("`@("`@("1T:&ES4V5R=FEC92`])B`D=&AI<RT^=W-D;"T^<V5R=FEC
M97-;)'-E<G9I8V5?;F%M92`N("=397)V:6-E)UU;)W!O<G1S)UT["@H@("`@
M("`@(&9O<F5A8V@@*"1T:&ES+3YW<V1L+3YB:6YD:6YG<R!A<R`D8FEN9&EN
M9TYA;64@/3X@)&)I;F1I;F=$871A*2!["B`@("`@("`@("`@("1T:&ES4V5R
M=FEC95LD8FEN9&EN9T1A=&%;)W1Y<&4G75T@/2!A<G)A>2@*("`@("`@("`@
M("`@("`@("`@("`G;F%M92<@/3X@)&)I;F1I;F=$871A6R=T>7!E)UTL"B`@
M("`@("`@("`@("`@("`@("`@)V)I;F1I;F<G(#T^("1B:6YD:6YG3F%M92P*
M("`@("`@("`@("`@("`@("`@("`G;F%M97-P86-E)R`]/B`D=&AI<RT^=&YS
M4')E9FEX+`H@("`@("`@("`@("`@("`@("`@("=A9&1R97-S)R`]/B!A<G)A
M>2@G;&]C871I;VXG(#T^"B`@("`@("`@("`@("`@("`@("`@("`@("=H='1P
M.B\O)R`N("1?4T525D526R=315)615)?3D%-12==("X@)%]315)615);)U!(
M4%]314Q&)UT@+@H@("`@("`@("`@("`@("`@("`@("`@("`H:7-S970H)%]3
M15)615);)U%515)97U-44DE.1R==*2`_("<_)R`N("1?4T525D526R=15452
M65]35%))3D<G72`Z("<G*2DL"B`@("`@("`@("`@("`@("`@("`@)W1Y<&4G
M(#T^("=S;V%P)RD["B`@("`@("`@?0H*("`@("`@("`O+R!3970@<V5R=FEC
M90H@("`@("`@("1T:&ES+3YW<V1L+3YS971?<V5R=FEC92@D<V5R=FEC95]N
M86UE("X@)U-E<G9I8V4G*3L*("`@("`@("`D=&AI<RT^=W-D;"T^=7)I(#T@
M)'1H:7,M/G=S9&PM/FYA;65S<&%C97-;)'1H:7,M/G1N<U!R969I>%T["@H@
M("`@("`@("\O($-R96%T92!74T1,(&1E9FEN:71I;VX*("`@("`@("`O+R`J
M*BH@/'=S9&PZ9&5F:6YI=&EO;G,^("HJ*@H*("`@("`@("`D=&AI<RT^=W-D
M;"T^9&5F:6YI=&EO;B`](&%R<F%Y*`H@("`@("`@("`@("`@("`@)VYA;64G
M(#T^("1S97)V:6-E7VYA;64L"B`@("`@("`@("`@("`@("`G=&%R9V5T3F%M
M97-P86-E)R`]/B`D=&AI<RT^=W-D;"T^;F%M97-P86-E<ULD=&AI<RT^=&YS
M4')E9FEX72P*("`@("`@("`@("`@("`@("=X;6QN<R<@/3X@4T-(14U!7U=3
M1$PI.PH*("`@("`@("!F;W)E86-H("@D=&AI<RT^=W-D;"T^;F%M97-P86-E
M<R!A<R`D;G-0<F5F:7@@/3X@)&YA;65S<&%C92D@>PH@("`@("`@("`@("`D
M=&AI<RT^=W-D;"T^9&5F:6YI=&EO;ELG>&UL;G,Z)R`N("1N<U!R969I>%T@
M/2`D;F%M97-P86-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%1H:7,@9G5N8W1I;VX@:7,@861A<'1E9"!F<F]M($1M:71R:2!6)W,@:6UP
M;&5M96YT871I;VX@;V8*("`@("`J($1)4T-/+U=31$P@9V5N97)A=&EO;BX@
M270@<V5P87)A=&5S(&YA;65S<&%C92!F<F]M('1Y<&4@;F%M92!I;@H@("`@
M("H@82!?7W1Y<&5D968@:V5Y(&%N9"!C<F5A=&5S(&$@;F5W(&YA;65S<&%C
M92!E;G1R>2!I;B!T:&4@5U-$3`H@("`@("H@<W1R=6-T=7)E(&EF('1H92!N
M86UE<W!A8V4@:&%S(&YO="!B965N('5S960@8F5F;W)E+B!4:&4*("`@("`J
M(&YA;65S<&%C92!P<F5F:7@@86YD('1Y<&4@;F%M92!A<F4@<F5T=7)N960N
M($EF(&YO(&YA;65S<&%C92!I<PH@("`@("H@<W!E8VEF:65D+"!X<V0@:7,@
M87-S=6UE9"X*("`@("`J"B`@("`@*B!792!W:6QL(&YO="!N965D('1H:7,@
M9G5N8W1I;VX@86YY;6]R92!O;F-E(%]?='EP961E9B!I<PH@("`@("H@96QI
M;6EN871E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=%1Y<&5.<R@D='EP
M92D*("`@('L*("`@("`@("!P<F5G7VUA=&-H7V%L;"@B)UQ[*"XJ*5Q])W-M
M(BP@)'1Y<&4L("1M*3L*("`@("`@("!I9B`H:7-S970H)&U;,5U;,%TI("8F
M("1M6S%=6S!=("$]("<G*2!["B`@("`@("`@("`@(&EF("@A87)R87E?:V5Y
M7V5X:7-T<R@D;5LQ75LP72P@)'1H:7,M/G=S9&PM/FYS*2D@>PH@("`@("`@
M("`@("`@("`@)&YS7W!R968@/2`G;G,G("X@8V]U;G0H)'1H:7,M/G=S9&PM
M/FYA;65S<&%C97,I.PH@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/FYS
M6R1M6S%=6S!=72`]("1N<U]P<F5F.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/G=S9&PM/FYA;65S<&%C97-;)&YS7W!R969=(#T@)&U;,5U;,%T["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)'1Y<&5N<R`]("1T:&ES+3YW<V1L+3YN
M<ULD;5LQ75LP75T["B`@("`@("`@("`@("1T>7!E(#T@97)E9U]R97!L86-E
M*"1M6S!=6S!=+"`G)RP@)'1Y<&4I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1T>7!E;G,@/2`G>'-D)SL*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!A<G)A>2@D='EP96YS+"`D='EP92D["B`@("!]"@I]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4T]!
M4"]#;&EE;G0N<&AP````````````````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`V,3`W,2`Q,#4Q-30S,S<S,2`P,C$Q-C(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H
M:7,@9FEL92!C;VYT86EN<R!T:&4@8V]D92!F;W(@=&AE(%-/05`@8VQI96YT
M+@H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4
M:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F
M('1H92!02%`@;&EC96YS92P*("H@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI
M<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R!A=F%I;&%B
M;&4@870*("H@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R
M92!U;F%B;&4@=&\@;V)T86EN(&ET"B`J('1H<F]U9V@@=&AE('=O<FQD+7=I
M9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T
M('-O('=E(&-A;@H@*B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J
M"B`J($!C871E9V]R>2`@(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G92`@("!3
M3T%0"B`J($!A=71H;W(@("`@($1I971R:6-H($%Y86QA(#QD:65T<FEC:$!G
M86YX-"YC;VT^($]R:6=I;F%L($%U=&AO<@H@*B!`875T:&]R("`@("!3:&%N
M92!#87)A=F5O(#Q3:&%N94!#87)A=F5O+F-O;3X@("!0;W)T('1O(%!%05(@
M86YD(&UO<F4*("H@0&%U=&AO<B`@("`@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^("`@36%I;G1E;F%N8V4*("H@0&%U=&AO<B`@("`@2F%N
M(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX@("`@("`@36%I;G1E;F%N8V4*
M("H@0&-O<'ER:6=H="`@,C`P,RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI
M8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0@
M(%!(4"!,:6-E;G-E(#(N,#(*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N
M<&AP+FYE="]P86-K86=E+U-/05`*("HO"@IR97%U:7)E7V]N8V4@)U-/05`O
M5F%L=64N<&AP)SL*<F5Q=6ER95]O;F-E("=33T%0+T)A<V4N<&AP)SL*<F5Q
M=6ER95]O;F-E("=33T%0+U1R86YS<&]R="YP:'`G.PIR97%U:7)E7V]N8V4@
M)U-/05`O5U-$3"YP:'`G.PIR97%U:7)E7V]N8V4@)U-/05`O1F%U;'0N<&AP
M)SL*<F5Q=6ER95]O;F-E("=33T%0+U!A<G-E<BYP:'`G.PH*+R\@07)N875D
M.B!T:&4@9F]L;&]W:6YG(&-O9&4@=V%S('1A:V5N(&9R;VT@1&%T84]B:F5C
M="!A;F0@861A<'1E9"!T;R!S=6ET"@HO+R!T:&ES('=I;&P@8F4@:&]R<FEF
M:6-A;&QY('-L;W<A(2$A"B\O($Y/5$4Z($]V97)L;V%D(%-%1T9!54Q44R!/
M3B!02%`T("L@6F5N9"!/<'1I;6EZ97(*+R\@=&AE<V4@='=O(&%R92!"0R]&
M0R!H86YD;&5R<R!F;W(@8V%L;"!I;B!02%`T+S4*"FEF("@A8VQA<W-?97AI
M<W1S*"=33T%07T-L:65N=%]/=F5R;&]A9"<I*2!["B`@("!I9B`H<W5B<W1R
M*'!H<'9E<G-I;VXH*2P@,"P@,2D@/3T@-2D@>PH@("`@("`@(&-L87-S(%-/
M05!?0VQI96YT7T]V97)L;V%D(&5X=&5N9',@4T]!4%]"87-E('L*("`@("`@
M("`@("`@9G5N8W1I;VX@7U]C86QL*"1M971H;V0L("1A<F=S*0H@("`@("`@
M("`@("!["B`@("`@("`@("`@("`@("`D<F5T=7)N(#T@;G5L;#L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?8V%L;"@D;65T:&]D+"`D87)G<RP@)')E='5R
M;BD["B`@("`@("`@("`@("`@("!R971U<FX@)')E='5R;CL*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@('T@96QS92!["B`@("`@("`@:68@*"%F=6YC
M=&EO;E]E>&ES=',H)V-L;VYE)RDI('L*("`@("`@("`@("`@979A;"@G9G5N
M8W1I;VX@8VQO;F4H)'0I('L@<F5T=7)N("1T.R!])RD["B`@("`@("`@?0H@
M("`@("`@(&5V86PH)PH@("`@("`@("`@("!C;&%S<R!33T%07T-L:65N=%]/
M=F5R;&]A9"!E>'1E;F1S(%-/05!?0F%S92!["B`@("`@("`@("`@("`@("!F
M=6YC=&EO;B!?7V-A;&PH)&UE=&AO9"P@)&%R9W,L("8D<F5T=7)N*0H@("`@
M("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7V-A;&PH)&UE=&AO9"P@)&%R9W,L("1R971U<FXI.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!])RD["B`@("!]"GT*"B\J*@H@*B!33T%0
M($-L:65N="!#;&%S<PH@*@H@*B!4:&ES(&-L87-S(&ES('1H92!M86EN(&EN
M=&5R9F%C92!F;W(@;6%K:6YG('-O87`@<F5Q=65S=',N"B`J"B`J(&)A<VEC
M('5S86=E.CQC;V1E/@H@*B`@("1S;V%P8VQI96YT(#T@;F5W(%-/05!?0VQI
M96YT*"!S=')I;F<@<&%T:"!;("P@8F]O;&5A;B!W<V1L72`I.PH@*B`@(&5C
M:&\@)'-O87!C;&EE;G0M/F-A;&PH('-T<FEN9R!M971H;V1N86UE(%L@+"!A
M<G)A>2!P87)A;65T97)S72`I.PH@*B`\+V-O9&4^"B`J"B`J($]R:6=I;F%L
M;'D@8F%S960@;VX@4T]!4'@T(&)Y($1I971R:6-H($%Y86QA"B`J(&AT='`Z
M+R]D:65T<FEC:"YG86YX-"YC;VTO<V]A<'@T"B`J"B`J($!A8V-E<W,@("!P
M=6)L:6,*("H@0'!A8VMA9V4@(%-/05`*("H@0&%U=&AO<B`@(%-H86YE($-A
M<F%V96\@/'-H86YE0'!H<"YN970^($-O;G9E<G-I;VX@=&\@4$5!4B!A;F0@
M=7!D871E<PH@*B!`875T:&]R("`@4W1I9R!"86MK96X@/'-S8D!F87-T+FYO
M/B!#;VYV97)S:6]N('1O(%!%05(*("H@0&%U=&AO<B`@($1I971R:6-H($%Y
M86QA(#QD:65T<FEC:$!G86YX-"YC;VT^($]R:6=I;F%L($%U=&AO<@H@*B\*
M8VQA<W,@4T]!4%]#;&EE;G0@97AT96YD<R!33T%07T-L:65N=%]/=F5R;&]A
M9`I["B`@("`O*BH*("`@("`J($-O;6UU;FEC871I;VX@96YD<&]I;G0N"B`@
M("`@*@H@("`@("H@0W5R<F5N=&QY('1H92!F;VQL;W=I;F<@=')A;G-P;W)T
M(&9O<FUA=',@87)E('-U<'!O<G1E9#H*("`@("`J("`M($A45%`*("`@("`J
M("`M(%--5%`*("`@("`J"B`@("`@*B!%>&%M<&QE(&5N9'!O:6YT<SH*("`@
M("`J("`@:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]S;V%P+W-E<G9E<BYP:'`*
M("`@("`J("`@:'1T<',Z+R]W=W<N97AA;7!L92YC;VTO<V]A<"]S97)V97(N
M<&AP"B`@("`@*B`@(&UA:6QT;SIS;V%P0&5X86UP;&4N8V]M"B`@("`@*@H@
M("`@("H@0'-E92`@4T]!4%]#;&EE;G0H*0H@("`@("H@0'9A<B`D7V5N9'!O
M:6YT('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]E;F1P;VEN="`]("<G.PH*
M("`@("\J*@H@("`@("H@5&AE(%-/05`@4$]25"!N86UE('1H870@:7,@=7-E
M9"!B>2!T:&4@8VQI96YT+@H@("`@("H*("`@("`J($!V87(@)%]P;W)T3F%M
M92!S=')I;F<*("`@("`J+PH@("`@=F%R("1?<&]R=$YA;64@/2`G)SL*"B`@
M("`O*BH*("`@("`J($5N9'!O:6YT('1Y<&4@92YG+B`G=V1S;"<N"B`@("`@
M*@H@("`@("H@0'9A<B`D7U]E;F1P;VEN=%1Y<&4@<W1R:6YG"B`@("`@*B\*
M("`@('9A<B`D7U]E;F1P;VEN=%1Y<&4@/2`G)SL*"B`@("`O*BH*("`@("`J
M(%1H92!R96-E:79E9"!X;6PN"B`@("`@*@H@("`@("H@0'9A<B`D>&UL('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)'AM;#L*"B`@("`O*BH*("`@("`J(%1H
M92!O=71G;VEN9R!A;F0@:6YC;VUI;F<@9&%T82!S=')E86T@9F]R(&1E8G5G
M9VEN9RX*("`@("`J"B`@("`@*B!`=F%R("1W:7)E('-T<FEN9PH@("`@("HO
M"B`@("!V87(@)'=I<F4["B`@("!V87(@)%]?;&%S=%]R97%U97-T(#T@;G5L
M;#L*("`@('9A<B`D7U]L87-T7W)E<W!O;G-E(#T@;G5L;#L*"B`@("`O*BH*
M("`@("`J($]P=&EO;G,N"B`@("`@*@H@("`@("H@0'9A<B`D7U]O<'1I;VYS
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7U]O<'1I;VYS(#T@87)R87DH)W1R
M86-E)ST^,"D["@H@("`@+RHJ"B`@("`@*B!4:&4@8VAA<F%C=&5R(&5N8V]D
M:6YG('5S960@9F]R(%A-3"!P87)S97(L(&5T8RX*("`@("`J"B`@("`@*B!`
M=F%R("1?96YC;V1I;F<@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V5N8V]D
M:6YG(#T@4T]!4%]$149!54Q47T5.0T]$24Y'.PH*("`@("\J*@H@("`@("H@
M5&AE(&%R<F%Y(&]F(%-/05!?2&5A9&5R<R!T:&%T('=E(&%R92!S96YD:6YG
M+@H@("`@("H*("`@("`J($!V87(@)&AE861E<G-/=70@87)R87D*("`@("`J
M+PH@("`@=F%R("1H96%D97)S3W5T(#T@;G5L;#L*"B`@("`O*BH*("`@("`J
M(%1H92!H96%D97)S('=E(')E8VEE=F5D(&)A8VL@:6X@=&AE(')E<W!O;G-E
M+@H@("`@("H*("`@("`J($!V87(@)&AE861E<G-);B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)&AE861E<G-);B`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!/
M<'1I;VYS(&9O<B!T:&4@2%144%]297%U97-T(&-L87-S("AS964@2%144"]2
M97%U97-T+G!H<"DN"B`@("`@*@H@("`@("H@0'9A<B`D7U]P<F]X>5]P87)A
M;7,@87)R87D*("`@("`J+PH@("`@=F%R("1?7W!R;WAY7W!A<F%M<R`](&%R
M<F%Y*"D["@H@("`@=F%R("1?<V]A<%]T<F%N<W!O<G0@/2!N=6QL.PH*("`@
M("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1E;F1P;VEN
M="`@("`@06X@55),+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'=S9&P@("`@
M("`@(%=H971H97(@=&AE(&5N9'!O:6YT(&ES(&$@5U-$3"!F:6QE+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<&]R=$YA;64*("`@("`J($!P87)A;2!A<G)A
M>2`D<')O>'E?<&%R86US("!/<'1I;VYS(&9O<B!T:&4@2%144%]297%U97-T
M(&-L87-S("AS964*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!(5%10+U)E<75E<W0N<&AP*0H@("`@("HO"B`@("!F=6YC=&EO;B!33T%0
M7T-L:65N="@D96YD<&]I;G0L("1W<V1L(#T@9F%L<V4L("1P;W)T3F%M92`]
M(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'!R;WAY7W!A<F%M
M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<&%R96YT.CI33T%07T)A<V4H
M)T-L:65N="<I.PH*("`@("`@("`D=&AI<RT^7V5N9'!O:6YT(#T@)&5N9'!O
M:6YT.PH@("`@("`@("1T:&ES+3Y?<&]R=$YA;64@/2`D<&]R=$YA;64["B`@
M("`@("`@)'1H:7,M/E]?<')O>'E?<&%R86US(#T@)'!R;WAY7W!A<F%M<SL*
M"B`@("`@("`@+R\@5&AI<R!H86-K('-H;W5L9"!P97)H87!S(&)E(')E;6]V
M960@87,@:70@;6EG:'0@8V%U<V4@=6YE>'!E8W1E9`H@("`@("`@("\O(&)E
M:&%V:6]U<BX*("`@("`@("`D=W-D;"`]("1W<V1L"B`@("`@("`@("`@(#\@
M)'=S9&P*("`@("`@("`@("`@.B!S=')T;VQO=V5R*'-U8G-T<B@D96YD<&]I
M;G0L("TT*2D@/3T@)W=S9&PG.PH*("`@("`@("`O+R!M86ME('9A;'5E<PH@
M("`@("`@(&EF("@D=W-D;"D@>PH@("`@("`@("`@("`D=&AI<RT^7U]E;F1P
M;VEN=%1Y<&4@/2`G=W-D;"<["B`@("`@("`@("`@("\O(&EN<W1A;G1I871E
M('=S9&P@8VQA<W,*("`@("`@("`@("`@)'1H:7,M/E]W<V1L(#TF(&YE=R!3
M3T%07U=31$PH)'1H:7,M/E]E;F1P;VEN="P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]?<')O>'E?<&%R86US
M*3L*("`@("`@("`@("`@:68@*"1T:&ES+3Y?=W-D;"T^9F%U;'0I('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)'1H:7,M/E]W
M<V1L+3YF875L="D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@
M("`@9G5N8W1I;VX@7W)E<V5T*"D*("`@('L*("`@("`@("`D=&AI<RT^>&UL
M(#T@;G5L;#L*("`@("`@("`D=&AI<RT^=VER92`](&YU;&P["B`@("`@("`@
M)'1H:7,M/E]?;&%S=%]R97%U97-T(#T@;G5L;#L*("`@("`@("`D=&AI<RT^
M7U]L87-T7W)E<W!O;G-E(#T@;G5L;#L*("`@("`@("`D=&AI<RT^:&5A9&5R
M<TEN(#T@;G5L;#L*("`@("`@("`D=&AI<RT^:&5A9&5R<T]U="`](&YU;&P[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!C:&%R86-T97(@96YC
M;V1I;F<N"B`@("`@*@H@("`@("H@3&EM:71E9"!T;R`G551&+3@G+"`G55-?
M05-#24DG(&%N9"`G25-/+3@X-3DM,2<N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG(&5N8V]D:6YG
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@4T]!4%]&875L="!O;B!E
M<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T16YC;V1I;F<H)&5N8V]D
M:6YG*0H@("`@>PH@("`@("`@(&EF("AI;E]A<G)A>2@D96YC;V1I;F<L("1T
M:&ES+3Y?96YC;V1I;F=S*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V5N8V]D
M:6YG(#T@)&5N8V]D:6YG.PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=);G9A
M;&ED($5N8V]D:6YG)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@
M:&5A9&5R('1O('1H92!E;G9E;&]P92X*("`@("`J"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("H*("`@("`J($!P87)A;2!33T%07TAE861E<B`D<V]A
M<%]V86QU92`@02!33T%07TAE861E<B!O<B!A;B!A<G)A>2!W:71H('1H90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!E;&5M96YT
M<R`G;F%M92<L("=N86UE<W!A8V4G+`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G;75S='5N9&5R<W1A;F0G+"!A;F0@)V%C=&]R
M)R!T;R!S96YD"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&%S(&$@:&5A9&5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1(96%D
M97(H)B1S;V%P7W9A;'5E*0H@("`@>PH@("`@("`@("\O($%D9"!A(&YE=R!H
M96%D97(@=&\@=&AE(&UE<W-A9V4N"B`@("`@("`@:68@*&ES7V$H)'-O87!?
M=F%L=64L("=33T%07TAE861E<B<I*2!["B`@("`@("`@("`@("1T:&ES+3YH
M96%D97)S3W5T6UT@/28@)'-O87!?=F%L=64["B`@("`@("`@?2!E;'-E:68@
M*&ES7V%R<F%Y*"1S;V%P7W9A;'5E*2D@>PH@("`@("`@("`@("`O+R!N86UE
M+"!V86QU92P@;F%M97-P86-E+"!M=7-T=6YD97)S=&%N9"P@86-T;W(*("`@
M("`@("`@("`@)'1H:7,M/FAE861E<G-/=71;72`])B!N97<@4T]!4%](96%D
M97(H)'-O87!?=F%L=65;,%TL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&YU;&PL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S;V%P7W9A
M;'5E6S%=+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<V]A<%]V86QU95LR72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-O87!?=F%L
M=65;,UTI.SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^
M7W)A:7-E4V]A<$9A=6QT*"=);G9A;&ED('!A<F%M971E<B!P<F]V:61E9"!T
M;R!A9&1(96%D97(H*2X@($UU<W0@8F4@86X@87)R87D@;W(@82!33T%07TAE
M861E<BXG*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#86QL
M<R!A(&UE=&AO9"!O;B!T:&4@4T]!4"!E;F1P;VEN="X*("`@("`J"B`@("`@
M*B!4:&4@;F%M97-P86-E('!A<F%M971E<B!I<R!O=F5R;&]A9&5D('1O(&%C
M8V5P="!A;B!A<G)A>2!O9B!O<'1I;VYS"B`@("`@*B!T:&%T(&-A;B!C;VYT
M86EN(&1A=&$@;F5C97-S87)Y(&9O<B!V87)I;W5S('1R86YS<&]R=',@:68@
M:70@:7,@=7-E9"!A<PH@("`@("H@86X@87)R87DL(&ET($U!62!C;VYT86EN
M(&$@;F%M97-P86-E('9A;'5E(&%N9"!A('-O87!A8W1I;VX@=F%L=64N("!)
M9@H@("`@("H@:70@:7,@;W9E<FQO861E9"P@=&AE('-O87!A8W1I;VX@<&%R
M86UE=&5R(&ES(&EG;F]R960@86YD($U54U0@8F4*("`@("`J('!L86-E9"!I
M;B!T:&4@;W!T:6]N<R!A<G)A>2X@(%1H:7,@:7,@9&]N92!T;R!P<F]V:61E
M(&)A8VMW87)D<PH@("`@("H@8V]M<&%T:6)I;&ET>2!W:71H(&-U<G)E;G0@
M8VQI96YT<RP@8G5T(&UA>2!B92!R96UO=F5D(&EN('1H92!F=71U<F4N"B`@
M("`@*B!4:&4@8W5R<F5N=&QY('-U<'!O<G1E9"!V86QU97,@87)E.CQP<F4^
M"B`@("`@*B`@(&YA;65S<&%C90H@("`@("H@("!S;V%P86-T:6]N"B`@("`@
M*B`@('1I;65O=70@*$A45%`@<V]C:V5T('1I;65O=70I"B`@("`@*B`@('1R
M86YS9F5R+65N8V]D:6YG("A33510+"!#;VYT96YT+51R86YS9F5R+45N8V]D
M:6YG.B!H96%D97(I"B`@("`@*B`@(&9R;VT@*%--5%`L($9R;VTZ(&AE861E
M<BD*("`@("`J("`@<W5B:F5C="`H4TU44"P@4W5B:F5C=#H@:&5A9&5R*0H@
M("`@("H@("!H96%D97)S("A33510+"!H87-H(&]F(&5X=')A(%--5%`@:&5A
M9&5R<RD*("`@("`J(#PO<')E/@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;65T:&]D("`@("`@
M("`@("!4:&4@;65T:&]D('1O(&-A;&PN"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R`@("`@("`@("`@(%1H92!M971H;V0@<&%R86UE=&5R<RX*("`@
M("`J($!P87)A;2!S=')I;F=\87)R87D@)&YA;65S<&%C92`@3F%M97-P86-E
M(&]R(&AA<V@@=VET:"!O<'1I;VYS+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<V]A<$%C=&EO;@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!M
M971H;V0@<F5S=6QT(&]R(&$@4T]!4%]&875L="!O;B!E<G)O<BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@)F-A;&PH)&UE=&AO9"P@)B1P87)A;7,L("1N86UE
M<W!A8V4@/2!F86QS92P@)'-O87!!8W1I;VX@/2!F86QS92D*("`@('L*("`@
M("`@("`D=&AI<RT^:&5A9&5R<TEN(#T@;G5L;#L*("`@("`@("`D=&AI<RT^
M7U]L87-T7W)E<75E<W0@/2!N=6QL.PH@("`@("`@("1T:&ES+3Y?7VQA<W1?
M<F5S<&]N<V4@/2!N=6QL.PH@("`@("`@("1T:&ES+3YW:7)E(#T@;G5L;#L*
M("`@("`@("`D=&AI<RT^>&UL(#T@;G5L;#L*"B`@("`@("`@)'-O87!?9&%T
M82`])B`D=&AI<RT^7U]G96YE<F%T92@D;65T:&]D+"`D<&%R86US+"`D;F%M
M97-P86-E+"`D<V]A<$%C=&EO;BD["B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)'-O87!?9&%T82DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M<F%I<V53;V%P1F%U;'0H)'-O87!?9&%T82D["B`@("`@("`@?0H*("`@("`@
M("`O+R!?7V=E;F5R871E*"D@;6%Y(&AA=F4@8VAA;F=E9"!T:&4@96YD<&]I
M;G0@:68@=&AE(%=31$P@:&%S(&UO<F4*("`@("`@("`O+R!T:&%N(&]N92!S
M97)V:6-E+"!S;R!W92!N965D('1O('-E92!I9B!W92!N965D('1O(&=E;F5R
M871E(&$@;F5W"B`@("`@("`@+R\@=')A;G-P;W)T('1O(&AO;VL@=&\@82!D
M:69F97)E;G0@55))+B`@4VEN8V4@=&AE('1R86YS<&]R="!P<F]T;V-O;`H@
M("`@("`@("\O(&-A;B!A;'-O(&-H86YG92P@=V4@;F5E9"!T;R!G970@86X@
M96YT:7)E;'D@;F5W(&]B:F5C="X@(%1H:7,@8V]U;&0*("`@("`@("`O+R!P
M<F]B86)L>2!B92!O<'1I;6EZ960N"B`@("`@("`@:68@*"$D=&AI<RT^7W-O
M87!?=')A;G-P;W)T('Q\"B`@("`@("`@("`@("1T:&ES+3Y?96YD<&]I;G0@
M(3T@)'1H:7,M/E]S;V%P7W1R86YS<&]R="T^=7)L*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?<V]A<%]T<F%N<W!O<G0@/28@4T]!4%]4<F%N<W!O<G0Z.F=E
M=%1R86YS<&]R="@D=&AI<RT^7V5N9'!O:6YT*3L*("`@("`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)'1H:7,M/E]S;V%P7W1R86YS<&]R="DI('L*("`@
M("`@("`@("`@("`@("1F875L="`])B`D=&AI<RT^7W-O87!?=')A;G-P;W)T
M.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]S;V%P7W1R86YS<&]R="`](&YU
M;&P["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&
M875L="@D9F%U;'0I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@
M("1T:&ES+3Y?<V]A<%]T<F%N<W!O<G0M/F5N8V]D:6YG(#T@)'1H:7,M/E]E
M;F-O9&EN9SL*"B`@("`@("`@+R\@4V5N9"!T:&4@;65S<V%G92X*("`@("`@
M("`D=')A;G-P;W)T7V]P=&EO;G,@/2!A<G)A>5]M97)G95]R96-U<G-I=F4H
M)'1H:7,M/E]?<')O>'E?<&%R86US+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7U]O<'1I;VYS
M*3L*("`@("`@("`D=&AI<RT^>&UL(#TF("1T:&ES+3Y?<V]A<%]T<F%N<W!O
M<G0M/G-E;F0H)'-O87!?9&%T82P@)'1R86YS<&]R=%]O<'1I;VYS*3L*"B`@
M("`@("`@+R\@4V%V92!T:&4@=VER92!I;F9O<FUA=&EO;B!F;W(@9&5B=6=G
M:6YG+@H@("`@("`@(&EF("@D=&AI<RT^7U]O<'1I;VYS6R=T<F%C92==(#X@
M,"D@>PH@("`@("`@("`@("`D=&AI<RT^7U]L87-T7W)E<75E<W0@/28@)'1H
M:7,M/E]S;V%P7W1R86YS<&]R="T^;W5T9V]I;F=?<&%Y;&]A9#L*("`@("`@
M("`@("`@)'1H:7,M/E]?;&%S=%]R97-P;VYS92`])B`D=&AI<RT^7W-O87!?
M=')A;G-P;W)T+3YI;F-O;6EN9U]P87EL;V%D.PH@("`@("`@("`@("`D=&AI
M<RT^=VER92`])B`D=&AI<RT^7U]G971?=VER92@I.PH@("`@("`@('T*("`@
M("`@("!I9B`H)'1H:7,M/E]S;V%P7W1R86YS<&]R="T^9F%U;'0I('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)'1H:7,M
M/GAM;"D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7U]A='1A8VAM96YT
M<R`])B`D=&AI<RT^7W-O87!?=')A;G-P;W)T+3YA='1A8VAM96YT<SL*("`@
M("`@("`D=&AI<RT^7U]R97-U;'1?96YC;V1I;F<@/2`D=&AI<RT^7W-O87!?
M=')A;G-P;W)T+3YR97-U;'1?96YC;V1I;F<["@H@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7U]O<'1I;VYS6R=R97-U;'0G72D@)B8*("`@("`@("`@("`@
M)'1H:7,M/E]?;W!T:6]N<ULG<F5S=6QT)UT@(3T@)W!A<G-E)RD@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/GAM;#L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D=&AI<RT^7U]P87)S92@D=&AI<RT^>&UL+"`D=&AI<RT^7U]R
M97-U;'1?96YC;V1I;F<L("1T:&ES+3Y?7V%T=&%C:&UE;G1S*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%-E=',@86X@;W!T:6]N('1O('5S92!W:71H('1H
M92!T<F%N<W!O<G0@;&%Y97)S+@H@("`@("H*("`@("`J($9O<B!E>&%M<&QE
M.@H@("`@("H@/&-O9&4^"B`@("`@*B`D<V]A<&-L:65N="T^<V5T3W!T*"=C
M=7)L)RP@0U523$]05%]615)"3U-%+"`Q*0H@("`@("H@/"]C;V1E/@H@("`@
M("H@=&\@<&%S<R!A('-P96-I9FEC(&]P=&EO;B!T;R!C=7)L(&EF('5S:6YG
M(&%N(%-33"!C;VYN96-T:6]N+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V%T96=O<GD@($-A
M=&5G;W)Y('1O('=H:6-H('1H92!O<'1I;VX@87!P;&EE<R!O<B!O<'1I;VX*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!N86UE+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;W!T:6]N("`@($%N(&]P=&EO;B!N86UE(&EF("1C
M871E9V]R>2!I<R!A(&-A=&5G;W)Y(&YA;64L"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@86X@;W!T:6]N('9A;'5E(&EF("1C871E9V]R>2!I
M<R!A;B!O<'1I;VX@;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@)'9A;'5E
M("`@("!!;B!O<'1I;VX@=F%L=64@:68@)&-A=&5G;W)Y(&ES(&$@8V%T96=O
M<GD*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!N86UE+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S971/<'0H)&-A=&5G;W)Y+"`D;W!T:6]N+"`D
M=F%L=64@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-?;G5L;"@D=F%L
M=64I*2!["B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]?;W!T:6]N
M<ULD8V%T96=O<GE=*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]?;W!T
M:6]N<ULD8V%T96=O<GE=(#T@87)R87DH*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D=&AI<RT^7U]O<'1I;VYS6R1C871E9V]R>5U;)&]P=&EO;ET@
M/2`D=F%L=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M
M/E]?;W!T:6]N<ULD8V%T96=O<GE=(#T@)&]P=&EO;CL*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#86QL(&UE=&AO9"!S=7!P;W)T:6YG('1H
M92!O=F5R;&]A9"!E>'1E;G-I;VXN"B`@("`@*@H@("`@("H@268@=&AE(&]V
M97)L;V%D(&5X=&5N<VEO;B!I<R!L;V%D960L('EO=2!C86X@8V%L;"!T:&4@
M8VQI96YT(&-L87-S('=I=&@*("`@("`J(&$@<V]A<"!M971H;V0@;F%M93H*
M("`@("`J(#QC;V1E/@H@("`@("H@)'-O87`@/2!N97<@4T]!4%]#;&EE;G0H
M+BXN+BD["B`@("`@*B`D=F%L=64@/2`D<V]A<"T^9V5T4W1O8VM1=6]T92@G
M35-&5"<I.PH@("`@("H@/"]C;V1E/@H@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;65T:&]D("`@
M("`@("!4:&4@;65T:&]D('1O(&-A;&PN"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R`@("`@("`@(%1H92!M971H;V0@<&%R86UE=&5R<RX*("`@("`J
M($!P87)A;2!S=')I;F<@)')E='5R;E]V86QU92`@5VEL;"!G970@=&AE(&UE
M=&AO9"=S(')E='5R;B!V86QU90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A<W-I9VYE9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@($%L=V%Y<R!T<G5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V%L
M;"@D;65T:&]D+"`D<&%R86US+"`F)')E='5R;E]V86QU92D*("`@('L*("`@
M("`@("`O+R!/=F5R;&]A9&EN9R!L;W=E<F-A<V5S('1H92!M971H;V0@;F%M
M92P@=V4@;F5E9"!T;R!L;V]K(&EN=&\@=&AE"B`@("`@("`@+R\@=W-D;"!A
M;F0@=')Y('1O(&9I;F0@=&AE(&-O<G)E8W0@;65T:&]D(&YA;64@=&\@9V5T
M('1H92!C;W)R96-T"B`@("`@("`@+R\@8V%S92!F;W(@=&AE(&-A;&PN"B`@
M("`@("`@:68@*"1T:&ES+3Y?=W-D;"D@>PH@("`@("`@("`@("`D=&AI<RT^
M7W=S9&PM/FUA=&-H365T:&]D*"1M971H;V0I.PH@("`@("`@('T*"B`@("`@
M("`@)')E='5R;E]V86QU92`])B`D=&AI<RT^8V%L;"@D;65T:&]D+"`D<&%R
M86US*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@9G5N8W1I
M;VX@)E]?9V5T;&%S=')E<75E<W0H*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^7U]L87-T7W)E<75E<W0["B`@("!]"@H@("`@9G5N8W1I;VX@)E]?
M9V5T;&%S=')E<W!O;G-E*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/E]?;&%S=%]R97-P;VYS93L*("`@('T*"B`@("!F=6YC=&EO;B!?7W5S92@D
M=7-E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;)W5S92==(#T@
M)'5S93L*("`@('T*"B`@("!F=6YC=&EO;B!?7W-T>6QE*"1S='EL92D*("`@
M('L*("`@("`@("`D=&AI<RT^7U]O<'1I;VYS6R=S='EL92==(#T@)'-T>6QE
M.PH@("`@?0H*("`@(&9U;F-T:6]N(%]?=')A8V4H)&QE=F5L*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;)W1R86-E)UT@/2`D;&5V96P["B`@
M("!]"@H@("`@9G5N8W1I;VX@)E]?9V5N97)A=&4H)&UE=&AO9"P@)B1P87)A
M;7,L("1N86UE<W!A8V4@/2!F86QS92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("1S;V%P06-T:6]N(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1H:7,M
M/F9A=6QT(#T@;G5L;#L*("`@("`@("`D=&AI<RT^7U]O<'1I;VYS6R=I;G!U
M="==/2=P87)S92<["B`@("`@("`@)'1H:7,M/E]?;W!T:6]N<ULG<F5S=6QT
M)UT])W!A<G-E)SL*("`@("`@("`D=&AI<RT^7U]O<'1I;VYS6R=P87)A;65T
M97)S)UT@/2!F86QS93L*"B`@("`@("`@:68@*"1P87)A;7,@)B8@9V5T='EP
M92@D<&%R86US*2`A/2`G87)R87DG*2!["B`@("`@("`@("`@("1P87)A;7,@
M/2!A<G)A>2@D<&%R86US*3L*("`@("`@("!]"@H@("`@("`@(&EF("AG971T
M>7!E*"1N86UE<W!A8V4I(#T]("=A<G)A>2<I('L*("`@("`@("`@("`@9F]R
M96%C:"`H)&YA;65S<&%C92!A<R`D;W!T;F%M92`]/B`D;W!T*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7U]O<'1I;VYS6W-T<G1O;&]W97(H)&]P=&YA
M;64I72`]("1O<'0["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?7V]P=&EO;G-;)VYA;65S<&%C92==*2D@>PH@("`@("`@
M("`@("`@("`@)&YA;65S<&%C92`]("1T:&ES+3Y?7V]P=&EO;G-;)VYA;65S
M<&%C92==.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)&YA;65S<&%C92`](&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@+R\@5V4G;&P@<&QA8V4@)'-O87!!8W1I;VX@
M:6YT;R!O=7(@87)R87D@9F]R('5S86=E(&EN('1H90H@("`@("`@("`@("`O
M+R!T<F%N<W!O<G0N"B`@("`@("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;)W-O
M87!A8W1I;VXG72`]("1S;V%P06-T:6]N.PH@("`@("`@("`@("`D=&AI<RT^
M7U]O<'1I;VYS6R=N86UE<W!A8V4G72`]("1N86UE<W!A8V4["B`@("`@("`@
M?0H*("`@("`@("!I9B`H)'1H:7,M/E]?96YD<&]I;G14>7!E(#T]("=W<V1L
M)RD@>PH@("`@("`@("`@("`D=&AI<RT^7W-E=%-C:&5M859E<G-I;VXH)'1H
M:7,M/E]W<V1L+3YX<V0I.PH*("`@("`@("`@("`@+R\@1V5T('!O<G0@;F%M
M92X*("`@("`@("`@("`@:68@*"$D=&AI<RT^7W!O<G1.86UE*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!O<G1.86UE(#T@)'1H:7,M/E]W<V1L+3YG
M9710;W)T3F%M92@D;65T:&]D*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D=&AI<RT^7W!O<G1.86UE*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)'1H
M:7,M/E]P;W)T3F%M92D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O
M($=E="!E;F1P;VEN="X*("`@("`@("`@("`@)'1H:7,M/E]E;F1P;VEN="`]
M("1T:&ES+3Y?=W-D;"T^9V5T16YD<&]I;G0H)'1H:7,M/E]P;W)T3F%M92D[
M"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1T:&ES+3Y?96YD<&]I
M;G0I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O
M87!&875L="@D=&AI<RT^7V5N9'!O:6YT*3L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@+R\@1V5T(&]P97)A=&EO;B!D871A+@H@("`@("`@("`@("`D
M;W!$871A(#T@)'1H:7,M/E]W<V1L+3YG971/<&5R871I;VY$871A*"1T:&ES
M+3Y?<&]R=$YA;64L("1M971H;V0I.PH*("`@("`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)&]P1&%T82DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"1O<$1A=&$I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1N86UE<W!A8V4@/2`D;W!$871A6R=N86UE<W!A8V4G
M73L*("`@("`@("`@("`@)'1H:7,M/E]?;W!T:6]N<ULG<W1Y;&4G72`]("1O
M<$1A=&%;)W-T>6QE)UT["B`@("`@("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;
M)W5S92==(#T@)&]P1&%T85LG:6YP=70G75LG=7-E)UT["B`@("`@("`@("`@
M("1T:&ES+3Y?7V]P=&EO;G-;)W-O87!A8W1I;VXG72`]("1O<$1A=&%;)W-O
M87!!8W1I;VXG73L*"B`@("`@("`@("`@("\O(%-E="!I;G!U="!P87)A;65T
M97)S+@H@("`@("`@("`@("!I9B`H)'1H:7,M/E]?;W!T:6]N<ULG:6YP=70G
M72`]/2`G<&%R<V4G*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7U]O<'1I
M;VYS6R=P87)A;65T97)S)UT@/2`D;W!$871A6R=P87)A;65T97)S)UT["B`@
M("`@("`@("`@("`@("`D;G!A<F%M<R`](&%R<F%Y*"D["B`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)&]P1&%T85LG:6YP=70G75LG<&%R=',G72D@)B8*
M("`@("`@("`@("`@("`@("`@("!C;W5N="@D;W!$871A6R=I;G!U="==6R=P
M87)T<R==*2D@>PH@("`@("`@("`@("`@("`@("`@("1I(#T@,#L*("`@("`@
M("`@("`@("`@("`@("!F;W)E86-H("@D;W!$871A6R=I;G!U="==6R=P87)T
M<R==(&%S("1N86UE(#T^("1P87)T*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1X;6QN<R`]("<G.PH@("`@("`@("`@("`@("`@("`@("`@("`D871T
M<G,@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@("`@("`O+R!)<R!T
M:&4@;F%M92!A(&-O;7!L97@@='EP93\*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1P87)T6R=E;&5M96YT)UTI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D>&UL;G,@/2`D=&AI<RT^7W=S9&PM/FYA;65S
M<&%C97-;)'!A<G1;)VYA;65S<&%C92==73L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1P87)T(#T@)'1H:7,M/E]W<V1L+3YE;&5M96YT<ULD<&%R
M=%LG;F%M97-P86-E)UU=6R1P87)T6R=T>7!E)UU=.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&YA;64@/2`D<&%R=%LG;F%M92==.PH@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D<&%R86US6R1N86UE72D@?'P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?=W-D;"T^9V5T1&%T84AA;F1L97(H)&YA;64L
M("1P87)T6R=N86UE<W!A8V4G72DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1N<&%R86US6R1N86UE72`])B`D<&%R86US6R1N86UE73L*("`@
M("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("\O(%=E(&YO=R!F;W)C92!A;B!A<W-O8VEA=&EV92!A
M<G)A>2!F;W(*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O('!A<F%M
M971E<G,@:68@=7-I;F<@5U-$3"X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")4:&4@;F%M960@
M<&%R86UE=&5R("1N86UE(&ES(&YO="!I;B!T:&4@8V%L;"!P87)A;65T97)S
M+B(I.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("AG971T>7!E*"1N<&%R86US6R1N86UE72D@(3T@)V]B
M:F5C="<@?'P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("%I<U]A*"1N
M<&%R86US6R1N86UE72P@)U-/05!?5F%L=64G*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@5'EP92!I<R!L:6ME;'D@82!Q;F%M92P@<W!L
M:70@:70@87!A<G0L(&%N9"!G970*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("\O('1H92!T>7!E(&YA;65S<&%C92!F<F]M(%=31$PN"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<6YA;64@/28@;F5W(%%.86UE*"1P87)T
M6R=T>7!E)UTI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1Q
M;F%M92T^;G,I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M='EP95]N86UE<W!A8V4@/2`D=&AI<RT^7W=S9&PM/FYA;65S<&%C97-;)'%N
M86UE+3YN<UT["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V5I
M9B`H:7-S970H)'!A<G1;)VYA;65S<&%C92==*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T>7!E7VYA;65S<&%C92`]("1T:&ES+3Y?
M=W-D;"T^;F%M97-P86-E<ULD<&%R=%LG;F%M97-P86-E)UU=.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D='EP95]N86UE<W!A8V4@/2!N=6QL.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'%N86UE+3YN86UE<W!A8V4@/2`D='EP95]N86UE<W!A8V4[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D='EP92`]("1Q;F%M92T^
M;F%M93L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<6YA;64@/2`D
M;F%M93L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D>&UL;G,I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<'%N86UE(#T@
M)WLG("X@)'AM;&YS("X@)WTG("X@)&YA;64["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;G!A
M<F%M<ULD;F%M95T@/28@;F5W(%-/05!?5F%L=64H)'!Q;F%M92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<6YA;64M/F9Q;B@I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N
M<&%R86US6R1N86UE72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D871T<G,I.PH@("`@
M("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@+R\@5U-$3"!F:7AU<',@=&\@=&AE(%-/05`@=F%L=64N
M"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<&%R86US
M(#TF("1N<&%R86US.PH@("`@("`@("`@("`@("`@=6YS970H)&YP87)A;7,I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'1H:7,M/E]S97138VAE;6%697)S:6]N*%-/05!?6$U,7U-#2$5-05]615)3
M24].*3L*("`@("`@("!]"@H@("`@("`@("\O(%-E<FEA;&EZ92!T:&4@;65S
M<V%G92X*("`@("`@("`D=&AI<RT^7W-E8W1I;VXU(#T@*&ES<V5T*"1T:&ES
M+3Y?7V]P=&EO;G-;)W5S92==*2`F)@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]?;W!T:6]N<ULG=7-E)UT@/3T@)VQI=&5R86PG*3L*
M"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7U]O<'1I;VYS6R=S='EL92==
M*2!\?`H@("`@("`@("`@("`D=&AI<RT^7U]O<'1I;VYS6R=S='EL92==(#T]
M("=R<&,G*2!["B`@("`@("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;)W-T>6QE
M)UT@/2`G<G!C)SL*("`@("`@("`@("`@)'1H:7,M/F1O8W!A<F%M<R`]('1R
M=64["B`@("`@("`@("`@("1M<6YA;64@/28@;F5W(%%.86UE*"1M971H;V0L
M("1N86UE<W!A8V4I.PH@("`@("`@("`@("`D;65T:&]D5F%L=64@/28@;F5W
M(%-/05!?5F%L=64H)&UQ;F%M92T^9G%N*"DL("=3=')U8W0G+"`D<&%R86US
M*3L*("`@("`@("`@("`@)'-O87!?;7-G(#TF("1T:&ES+3Y?;6%K945N=F5L
M;W!E*"1M971H;V1686QU92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YH96%D97)S3W5T+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]E;F-O9&EN9RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?7V]P=&EO;G,I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(&EF("@A)'!A<F%M<RD@>PH@("`@("`@("`@("`@
M("`@)&UQ;F%M92`])B!N97<@44YA;64H)&UE=&AO9"P@)&YA;65S<&%C92D[
M"B`@("`@("`@("`@("`@("`D;7EN=6QL(#T@;G5L;#L*("`@("`@("`@("`@
M("`@("1P87)A;7,@/28@;F5W(%-/05!?5F%L=64H)&UQ;F%M92T^9G%N*"DL
M("=3=')U8W0G+"`D;7EN=6QL*3L*("`@("`@("`@("`@?2!E;'-E:68@*"1T
M:&ES+3Y?7V]P=&EO;G-;)VEN<'5T)UT@/3T@)W!A<G-E)RD@>PH@("`@("`@
M("`@("`@("`@:68@*&ES7V%R<F%Y*"1P87)A;7,I*2!["B`@("`@("`@("`@
M("`@("`@("`@)&YP87)A;7,@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@
M("`@("1K97ES(#T@87)R87E?:V5Y<R@D<&%R86US*3L*("`@("`@("`@("`@
M("`@("`@("!F;W)E86-H("@D:V5Y<R!A<R`D:RD@>PH@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H9V5T='EP92@D<&%R86US6R1K72D@(3T@)V]B:F5C
M="<I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N<&%R86US6UT@
M/28@;F5W(%-/05!?5F%L=64H)&LL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9A;'-E+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<&%R86US6R1K72D["B`@("`@("`@("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;G!A<F%M
M<UM=(#TF("1P87)A;7-;)&M=.PH@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1P
M87)A;7,@/28@)&YP87)A;7,["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!I9B`H)'1H:7,M/E]?;W!T:6]N<ULG<&%R86UE=&5R<R==*2![
M"B`@("`@("`@("`@("`@("`@("`@)&UQ;F%M92`])B!N97<@44YA;64H)&UE
M=&AO9"P@)&YA;65S<&%C92D["B`@("`@("`@("`@("`@("`@("`@)'!A<F%M
M<R`])B!N97<@4T]!4%]686QU92@D;7%N86UE+3YF<6XH*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=3=')U8W0G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'!A<F%M<RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)'-O87!?;7-G(#TF("1T:&ES+3Y?;6%K945N=F5L;W!E
M*"1P87)A;7,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^:&5A9&5R<T]U="P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?96YC;V1I
M;F<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7U]O<'1I;VYS*3L*("`@("`@("!]"B`@("`@("`@=6YS
M970H)'1H:7,M/FAE861E<G-/=70I.PH*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D<V]A<%]M<V<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7W)A:7-E4V]A<$9A=6QT*"1S;V%P7VUS9RD["B`@("`@("`@?0H*("`@("`@
M("`O+R!(86YD;&4@34E-12!O<B!$24U%(&5N8V]D:6YG+@H@("`@("`@("\O
M(%1/1$\Z($1)344@96YC;V1I;F<@<VAO=6QD(&UO=F4@=&\@=&AE('1R86YS
M<&]R="P@9&\@:70@:&5R92!F;W(*("`@("`@("`O+R!N;W<@86YD(&9O<B!E
M87-E(&]F(&=E='1I;F<@:70@9&]N92X*("`@("`@("!I9B`H8V]U;G0H)'1H
M:7,M/E]?871T86-H;65N=',I*2!["B`@("`@("`@("`@(&EF("@H:7-S970H
M)'1H:7,M/E]?;W!T:6]N<ULG871T86-H;65N=',G72D@)B8*("`@("`@("`@
M("`@("`@("`D=&AI<RT^7U]O<'1I;VYS6R=A='1A8VAM96YT<R==(#T]("=-
M:6UE)RD@?'P*("`@("`@("`@("`@("`@(&ES<V5T*"1T:&ES+3Y?7V]P=&EO
M;G-;)TUI;64G72DI('L*("`@("`@("`@("`@("`@("1S;V%P7VUS9R`])B`D
M=&AI<RT^7VUA:V5-:6UE365S<V%G92@D<V]A<%]M<V<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]E;F-O9&EN9RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`O+R!D969A=6QT(&ES(&1I;64*("`@("`@("`@("`@("`@("1S
M;V%P7VUS9R`])B`D=&AI<RT^7VUA:V5$24U%365S<V%G92@D<V]A<%]M<V<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]E;F-O9&EN9RD["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7U]O<'1I;VYS6R=H96%D97)S)UU;)T-O;G1E;G0M5'EP92==(#T@
M)V%P<&QI8V%T:6]N+V1I;64G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("A014%2.CII<T5R<F]R*"1S;V%P7VUS9RDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"1S;V%P7VUS9RD[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O($EN<W1A;G1I
M871E(&-L:65N="X*("`@("`@("!I9B`H:7-?87)R87DH)'-O87!?;7-G*2D@
M>PH@("`@("`@("`@("`D<V]A<%]D871A(#TF("1S;V%P7VUS9ULG8F]D>2==
M.PH@("`@("`@("`@("!I9B`H8V]U;G0H)'-O87!?;7-G6R=H96%D97)S)UTI
M*2!["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]?;W!T:6]N
M<ULG:&5A9&5R<R==*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M7V]P=&EO;G-;)VAE861E<G,G72`](&%R<F%Y7VUE<F=E*"1T:&ES+3Y?7V]P
M=&EO;G-;)VAE861E<G,G72P@)'-O87!?;7-G6R=H96%D97)S)UTI.PH@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7U]O<'1I;VYS6R=H96%D97)S)UT@/2`D<V]A<%]M<V=;)VAE861E<G,G
M73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1S;V%P7V1A=&$@/28@)'-O87!?;7-G.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1S;V%P7V1A=&$["B`@("!]"@H@
M("`@9G5N8W1I;VX@)E]?<&%R<V4H)B1R97-P;VYS92P@)&5N8V]D:6YG+"`F
M)&%T=&%C:&UE;G1S*0H@("`@>PH@("`@("`@("\O(%!A<G-E('1H92!R97-P
M;VYS92X*("`@("`@("`D<F5S<&]N<V4@/28@;F5W(%-/05!?4&%R<V5R*"1R
M97-P;VYS92P@)&5N8V]D:6YG+"`D871T86-H;65N=',I.PH@("`@("`@(&EF
M("@D<F5S<&]N<V4M/F9A=6QT*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7W)A:7-E4V]A<$9A=6QT*"1R97-P;VYS92T^9F%U;'0I.PH@("`@("`@
M('T*"B`@("`@("`@+R\@4F5T=7)N(&%R<F%Y(&]F('!A<F%M971E<G,N"B`@
M("`@("`@)')E='5R;B`])B`D<F5S<&]N<V4M/F=E=%)E<W!O;G-E*"D["B`@
M("`@("`@)&AE861E<G,@/28@)')E<W!O;G-E+3YG971(96%D97)S*"D["B`@
M("`@("`@:68@*"1H96%D97)S*2!["B`@("`@("`@("`@("1T:&ES+3YH96%D
M97)S26X@/28@)'1H:7,M/E]?9&5C;V1E4F5S<&]N<V4H)&AE861E<G,L(&9A
M;'-E*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^7U]D96-O
M9&5297-P;VYS92@D<F5T=7)N*3L*("`@('T*"B`@("!F=6YC=&EO;B`F7U]D
M96-O9&5297-P;VYS92@F)')E<W!O;G-E+"`D<VAI9G0@/2!T<G5E*0H@("`@
M>PH@("`@("`@(&EF("@A)')E<W!O;G-E*2!["B`@("`@("`@("`@(')E='5R
M;B!N=6QL.PH@("`@("`@('T*"B`@("`@("`@+R\@0VAE8VL@9F]R('9A;&ED
M(')E<W!O;G-E+@H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1R97-P;VYS
M92DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U
M;'0H)')E<W!O;G-E*3L*("`@("`@("!](&5L<V5I9B`H(6ES7V$H)')E<W!O
M;G-E+"`G<V]A<%]V86QU92<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7W)A:7-E4V]A<$9A=6QT*")$:61N)W0@9V5T(%-/05!?5F%L=64@;V)J
M96-T(&)A8VL@9G)O;2!C;&EE;G0B*3L*("`@("`@("!]"@H@("`@("`@("\O
M($1E8V]D92!T;R!N871I=F4@<&AP(&1A=&%T>7!E+@H@("`@("`@("1R971U
M<FY!<G)A>2`])B`D=&AI<RT^7V1E8V]D92@D<F5S<&]N<V4I.PH*("`@("`@
M("`O+R!&875L=#\*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5T=7)N
M07)R87DI*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A
M<$9A=6QT*"1R971U<FY!<G)A>2D["B`@("`@("`@?0H*("`@("`@("!I9B`H
M:7-?;V)J96-T*"1R971U<FY!<G)A>2D@)B8*("`@("`@("`@("`@<W1R8V%S
M96-M<"AG971?8VQA<W,H)')E='5R;D%R<F%Y*2P@)W-T9$-L87-S)RD@/3T@
M,"D@>PH@("`@("`@("`@("`D<F5T=7)N07)R87D@/2!G971?;V)J96-T7W9A
M<G,H)')E='5R;D%R<F%Y*3L*("`@("`@("!]"B`@("`@("`@:68@*&ES7V%R
M<F%Y*"1R971U<FY!<G)A>2DI('L*("`@("`@("`@("`@:68@*&ES<V5T*"1R
M971U<FY!<G)A>5LG9F%U;'1C;V1E)UTI('Q\"B`@("`@("`@("`@("`@("!I
M<W-E="@D<F5T=7)N07)R87E;)U-/05`M14Y6.F9A=6QT8V]D92==*2D@>PH@
M("`@("`@("`@("`@("`@)&9A=6QT8V]D92`]("1F875L='-T<FEN9R`]("1F
M875L=&1E=&%I;"`]("1F875L=&%C=&]R(#T@)R<["B`@("`@("`@("`@("`@
M("!F;W)E86-H("@D<F5T=7)N07)R87D@87,@)&L@/3X@)'8I('L*("`@("`@
M("`@("`@("`@("`@("!I9B`H<W1R:7-T<B@D:RP@)V9A=6QT8V]D92<I*2`D
M9F%U;'1C;V1E(#T@)'8["B`@("`@("`@("`@("`@("`@("`@:68@*'-T<FES
M='(H)&LL("=F875L='-T<FEN9R<I*2`D9F%U;'1S=')I;F<@/2`D=CL*("`@
M("`@("`@("`@("`@("`@("!I9B`H<W1R:7-T<B@D:RP@)V1E=&%I;"<I*2`D
M9F%U;'1D971A:6P@/2`D=CL*("`@("`@("`@("`@("`@("`@("!I9B`H<W1R
M:7-T<B@D:RP@)V9A=6QT86-T;W(G*2D@)&9A=6QT86-T;W(@/2`D=CL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7W)A:7-E4V]A<$9A=6QT*"1F875L='-T<FEN9RP@)&9A=6QT9&5T86EL+"`D
M9F%U;'1A8W1O<BP@)&9A=6QT8V]D92D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@+R\@4F5T=7)N(&%R<F%Y(&]F(')E='5R;B!V86QU97,N"B`@("`@
M("`@("`@(&EF("@D<VAI9G0@)B8@8V]U;G0H)')E='5R;D%R<F%Y*2`]/2`Q
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@87)R87E?<VAI9G0H)')E='5R
M;D%R<F%Y*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)')E
M='5R;D%R<F%Y.PH@("`@("`@('T*("`@("`@("!R971U<FX@)')E='5R;D%R
M<F%Y.PH@("`@?0H*("`@(&9U;F-T:6]N(%]?9V5T7W=I<F4H*0H@("`@>PH@
M("`@("`@(&EF("@D=&AI<RT^7U]O<'1I;VYS6R=T<F%C92==(#X@,"`F)@H@
M("`@("`@("`@("`H)'1H:7,M/E]?;&%S=%]R97%U97-T('Q\("1T:&ES+3Y?
M7VQA<W1?<F5S<&]N<V4I*2!["B`@("`@("`@("`@(')E='5R;B`B3U541T])
M3D<Z7&Y<;B(@+@H@("`@("`@("`@("`@("`@)'1H:7,M/E]?;&%S=%]R97%U
M97-T("X*("`@("`@("`@("`@("`@(")<;EQN24Y#3TU)3D=<;EQN(B`N"B`@
M("`@("`@("`@("`@("!P<F5G7W)E<&QA8V4H(B\^/"\B+"(^7')<;CPB+"`D
M=&AI<RT^7U]L87-T7W)E<W!O;G-E*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!N=6QL.PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O4T]!4"]"87-E+G!H<```````````````````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#$R,C$S,R`Q,#4Q-30S,S<S,2`P,C`V,3,`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J(%1H:7,@9FEL92!L;V%D<R!A;&P@<F5Q=6ER960@;&EB<F%R
M:65S+"!D969I;F5S(&-O;G-T86YT<R!U<V5D(&%C<F]S<R!T:&4*("H@4T]!
M4"!P86-K86=E+"!A;F0@9&5F:6YE<R!T:&4@8F%S92!C;&%S<V5S('1H870@
M;6]S="!O=&AE<B!C;&%S<V5S(&]F('1H:7,*("H@<&%C:V%G92!E>'1E;F0N
M"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H
M:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@
M=&AE(%!(4"!L:6-E;G-E+`H@*B!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES
M('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES(&%V86EL86)L
M92!A=`H@*B!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E
M('5N86)L92!T;R!O8G1A:6X@:70*("H@=&AR;W5G:"!T:&4@=V]R;&0M=VED
M92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@
M<V\@=V4@8V%N"B`J(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*
M("H@0&-A=&5G;W)Y("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E("`@(%-/
M05`*("H@0&%U=&AO<B`@("`@1&EE=')I8V@@07EA;&$@/&1I971R:6-H0&=A
M;G@T+F-O;3X@3W)I9VEN86P@075T:&]R"B`J($!A=71H;W(@("`@(%-H86YE
M($-A<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/B`@(%!O<G0@=&\@4$5!4B!A
M;F0@;6]R90H@*B!`875T:&]R("`@("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX@("!-86EN=&5N86YC90H@*B!`875T:&]R("`@("!*86X@
M4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/B`@("`@("!-86EN=&5N86YC90H@
M*B!`8V]P>7)I9VAT("`R,#`S+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC
M96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="`@
M4$A0($QI8V5N<V4@,BXP,@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP
M:'`N;F5T+W!A8VMA9V4O4T]!4`H@*B\*"B\J*@H@*B!33T%07T]"2D5#5%]3
M5%)50U0@;6%K97,@4$5!4CHZ4T]!4"!U<V4@;V)J96-T<R!F;W(@4T]!4"!S
M=')U8W1U<F5S(')A=&AE<@H@*B!T:&%N(&%R<F%Y<RX@(%1H:7,@:&%S(&)E
M96X@9&]N92!T;R!P<F]V:61E(&$@8VQO<V5R(&UA=&-H('1O('!H<"US;V%P
M+B`@268*("H@=&AE(&]L9"!B96AA=FEO=7(@:7,@;F5E9&5D+"!S970@=&\@
M9F%L<V4N("!4:&4@;VQD(&)E:&%V:6]U<B!I<PH@*B!D97!R96-A=&5D+@H@
M*@H@*B!`9VQO8F%L(&)O;VP@)$=,3T)!3%-;)U-/05!?3T)*14-47U-44E5#
M5"=="B`J+PHD1TQ/0D%,4ULG4T]!4%]/0DI%0U1?4U1254-4)UT@/2!T<G5E
M.PH*+RHJ"B`J(%-/05!?4D%77T-/3E9%4E0@;6%K97,@4$5!4CHZ4T]!4"!A
M='1E;7!T('1O(&1E=&5R;6EN92!W:&%T(%-/05`@='EP92!A(%!(4`H@*B!S
M=')I;F<@0T]53$0@8F4N("!4:&ES(&UA>2!R97-U;'0@:6X@<VQI9VAT;'D@
M8F5T=&5R(&EN=&5R;W!E<F%B:6QI='D@=VAE;@H@*B!Y;W4@87)E(&YO="!U
M<VEN9R!74T1,+"!A;F0@87)E(&)E:6YG(&QA>GD@86YD(&YO="!U<VEN9R!3
M3T%07U9A;'5E('1O"B`J(&1E9FEN92!T>7!E<R!F;W(@>6]U<B!V86QU97,N
M"B`J"B`J($!G;&]B86P@8F]O;"`D1TQ/0D%,4ULG4T]!4%]205=?0T].5D52
M5"=="B`J+PHD1TQ/0D%,4ULG4T]!4%]205=?0T].5D525"==(#T@9F%L<V4[
M"@IR97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*<F5Q=6ER95]O;F-E("=33T%0
M+U1Y<&4O9&%T951I;64N<&AP)SL*<F5Q=6ER95]O;F-E("=33T%0+U1Y<&4O
M:&5X0FEN87)Y+G!H<"<["@HO+R!O<'1I;VYA;"!F96%T=7)E<PHD1TQ/0D%,
M4ULG4T]!4%]O<'1I;VYS)UT@/2!A<G)A>2@I.PH*0&EN8VQU9&5?;VYC92`G
M36%I;"]M:6UE4&%R="YP:'`G.PI`:6YC;'5D95]O;F-E("=-86EL+VUI;65$
M96-O9&4N<&AP)SL*:68@*&-L87-S7V5X:7-T<R@G36%I;%]M:6UE4&%R="<I
M*2!["B`@("`D1TQ/0D%,4ULG4T]!4%]O<'1I;VYS)UU;)TUI;64G72`](#$[
M"B`@("!D969I;F4H)TU!24Q?34E-15!!4E1?0U),1B<L(")<<EQN(BD["GT*
M"D!I;F-L=61E7V]N8V4@)TYE="]$24U%+G!H<"<["FEF("AC;&%S<U]E>&ES
M=',H)TYE=%]$24U%7TUE<W-A9V4G*2D@>PH@("`@)$=,3T)!3%-;)U-/05!?
M;W!T:6]N<R==6R=$24U%)UT@/2`Q.PI]"@HO*BH*("H@16YA8FQE(&1E8G5G
M9VEN9R!I;F9O<FUA=&EO;C\*("H*("H@0&=L;V)A;"!B;V]L("1'3$]"04Q3
M6R=33T%07T1%0E5')UT*("H@0&YA;64@)%-/05!?1$5"54<*("HO"B1'3$]"
M04Q36R=33T%07T1%0E5')UT@/2!F86QS93L*"FEF("@A9G5N8W1I;VY?97AI
M<W1S*"=V97)S:6]N7V-O;7!A<F4G*2!\?`H@("`@=F5R<VEO;E]C;VUP87)E
M*'!H<'9E<G-I;VXH*2P@)S0N,2<L("<\)RDI('L*("`@(&1I92@B<F5Q=6ER
M97,@4$A0(#0N,2!O<B!H:6=H97)<;B(I.PI]"FEF("AV97)S:6]N7V-O;7!A
M<F4H<&AP=F5R<VEO;B@I+"`G-"XQ)RP@)SX])RD@)B8*("`@('9E<G-I;VY?
M8V]M<&%R92AP:'!V97)S:6]N*"DL("<T+C(G+"`G/"<I*2!["B`@("!D969I
M;F4H)T9,3T%4)RP@)V1O=6)L92<I.PI](&5L<V4@>PH@("`@9&5F:6YE*"=&
M3$]!5"<L("=F;&]A="<I.PI]"@II9B`H(61E9FEN960H)TE.1B<I*2!["B`@
M("!D969I;F4H)TE.1B<L(#$N.&4S,#<I.PI]"FEF("@A9&5F:6YE9"@G3D%.
M)RDI('L*("`@(&1E9FEN92@G3D%.)RP@,"XP*3L*?0H*9&5F:6YE*"=33T%0
M7TQ)0E)!4EE?5D524TE/3B<L("<P+C@N,%)#-"<I.PID969I;F4H)U-/05!?
M3$E"4D%265].04U%)RP@("`@)U!%05(M4T]!4"`P+C@N,%)#-"UD979E;"<I
M.PH*+R\@4V5T('-C:&5M82!V97)S:6]N+@ID969I;F4H)U-/05!?6$U,7U-#
M2$5-05]615)324].)RP@("=H='1P.B\O=W=W+G<S+F]R9R\R,#`Q+UA-3%-C
M:&5M82<I.PID969I;F4H)U-/05!?6$U,7U-#2$5-05])3E-404Y#12<L("=H
M='1P.B\O=W=W+G<S+F]R9R\R,#`Q+UA-3%-C:&5M82UI;G-T86YC92<I.PID
M969I;F4H)U-/05!?6$U,7U-#2$5-05\Q.3DY)RP@("`@("=H='1P.B\O=W=W
M+G<S+F]R9R\Q.3DY+UA-3%-C:&5M82<I.PID969I;F4H)U-/05!?4T-(14U!
M)RP@("`@("`@("`@("`@("=H='1P.B\O<V-H96UA<RYX;6QS;V%P+F]R9R]W
M<V1L+W-O87`O)RD["F1E9FEN92@G4T]!4%]30TA%34%?14Y#3T1)3D<G+"`@
M("`@)VAT='`Z+R]S8VAE;6%S+GAM;'-O87`N;W)G+W-O87`O96YC;V1I;F<O
M)RD["F1E9FEN92@G4T]!4%]%3E9%3$]0)RP@("`@("`@("`@("`@)VAT='`Z
M+R]S8VAE;6%S+GAM;'-O87`N;W)G+W-O87`O96YV96QO<&4O)RD["@ID969I
M;F4H)U-#2$5-05]$25-#3R<L("`@("`@("`@("`@("=H='1P.B\O<V-H96UA
M<RYX;6QS;V%P+F]R9R]D:7-C;R\G*3L*9&5F:6YE*"=30TA%34%?1$E30T]?
M4T-,)RP@("`@("`@("`G:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO<F<O9&ES
M8V\O<V-L+R<I.PH*9&5F:6YE*"=30TA%34%?4T]!4"<L("`@("`@("`@("`@
M("`G:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO<F<O=W-D;"]S;V%P+R<I.PID
M969I;F4H)U-#2$5-05]33T%07TA45%`G+"`@("`@("`@("=H='1P.B\O<V-H
M96UA<RYX;6QS;V%P+F]R9R]S;V%P+VAT='`G*3L*9&5F:6YE*"=30TA%34%?
M5U-$3%](5%10)RP@("`@("`@("`G:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO
M<F<O=W-D;"]H='1P+R<I.PID969I;F4H)U-#2$5-05]-24U%)RP@("`@("`@
M("`@("`@("=H='1P.B\O<V-H96UA<RYX;6QS;V%P+F]R9R]W<V1L+VUI;64O
M)RD["F1E9FEN92@G4T-(14U!7U=31$PG+"`@("`@("`@("`@("`@)VAT='`Z
M+R]S8VAE;6%S+GAM;'-O87`N;W)G+W=S9&PO)RD["F1E9FEN92@G4T-(14U!
M7T1)344G+"`@("`@("`@("`@("`@)VAT='`Z+R]S8VAE;6%S+GAM;'-O87`N
M;W)G+W=S+S(P,#(O,#0O9&EM92]W<V1L+R<I.PID969I;F4H)U-#2$5-05]#
M3TY414Y4)RP@("`@("`@("`@("=H='1P.B\O<V-H96UA<RYX;6QS;V%P+F]R
M9R]W<R\R,#`R+S`T+V-O;G1E;G0M='EP92\G*3L*9&5F:6YE*"=30TA%34%?
M4D5&)RP@("`@("`@("`@("`@("`G:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO
M<F<O=W,O,C`P,B\P-"]R969E<F5N8V4O)RD["@ID969I;F4H)U-/05!?1$5&
M055,5%]%3D-/1$E.1R<L("`G551&+3@G*3L*"FEF("@A9G5N8W1I;VY?97AI
M<W1S*"=I<U]A)RDI('L*("`@(&9U;F-T:6]N(&ES7V$H)B1O8FIE8W0L("1C
M;&%S<U]N86UE*0H@("`@>PH@("`@("`@(&EF("AS=')T;VQO=V5R*&=E=%]C
M;&%S<R@D;V)J96-T*2D@/3T@)&-L87-S7VYA;64I('L*("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@?0H@("`@("`@(')E='5R;B!I<U]S=6)C
M;&%S<U]O9B@D;V)J96-T+"`D8VQA<W-?;F%M92D["B`@("!]"GT*"FEF("@A
M8VQA<W-?97AI<W1S*"=S=&1#;&%S<R<I*2!["B`@("`O*B!02%`U(&1O97-N
M)W0@9&5F:6YE('1H:7,_("HO"B`@("!C;&%S<R!S=&1#;&%S<R!["B`@("`@
M("`@9G5N8W1I;VX@7U]C;VYS=')U8W1O<B@I('M]"B`@("!]"GT*"F-L87-S
M(%-/05!?0F%S95]/8FIE8W0@97AT96YD<R!014%2"GL*("`@("\J*@H@("`@
M("H@4W1O<F4@9&5B=6=G:6YG(&EN9F]R;6%T:6]N(&EN("1?9&5B=6=?9&%T
M83\*("`@("`J"B`@("`@*B!`<V5E("1D96)U9U]D871A+"!33T%07T)A<V4*
M("`@("`J($!V87(@8F]O;&5A;B`D7V1E8G5G7V9L86<*("`@("`J+PH@("`@
M=F%R("1?9&5B=6=?9FQA9R`](&9A;'-E.PH*("`@("\J*@H@("`@("H@4W1R
M:6YG(&-O;G1A:6YI;F<@9&5B=6=G:6YG(&EN9F]R;6%T:6]N(&EF("1?9&5B
M=6=?9FQA9R!I<R!T<G5E+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B!`<V5E("1D96)U9U]F;&%G+"!33T%07T)A<V4*("`@("`J($!V
M87(@<W1R:6YG("1?9&5B=6=?9&%T80H@("`@("HO"B`@("!V87(@)%]D96)U
M9U]D871A(#T@)R<["@H@("`@+RHJ"B`@("`@*B!3=7!P;W)T960@96YC;V1I
M;F=S+"!L:6UI=&5D(&)Y(%A-3"!E>'1E;G-I;VXN"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>2`D7V5N8V]D:6YG<PH@("`@("HO"B`@("!V87(@)%]E;F-O
M9&EN9W,@/2!A<G)A>2@G25-/+3@X-3DM,2<L("=54RU!4T-)22<L("=55$8M
M."<I.PH*("`@("\J*@H@("`@("H@1F%U;'0@8V]D92X*("`@("`J"B`@("`@
M*B!`=F%R('-T<FEN9R`D7VUY9F%U;'1C;V1E"B`@("`@*B\*("`@('9A<B`D
M7VUY9F%U;'1C;V1E(#T@)R<["@H@("`@+RHJ"B`@("`@*B!296-E;G0@4$5!
M4E]%<G)O<B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'9A<B!014%27T5R<F]R
M("1F875L=`H@("`@("HO"B`@("!V87(@)&9A=6QT(#T@;G5L;#L*"B`@("`O
M*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!S964@)&1E
M8G5G7V1A=&$L(%]D96)U9R@I"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9F%U;'1C;V1E("!%<G)O<B!C;V1E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!33T%07T)A<V5?3V)J96-T*"1F875L=&-O9&4@/2`G0VQI96YT)RD*("`@
M('L*("`@("`@("`D=&AI<RT^7VUY9F%U;'1C;V1E(#T@)&9A=6QT8V]D93L*
M("`@("`@("`D=&AI<RT^7V1E8G5G7V9L86<@/2`D1TQ/0D%,4ULG4T]!4%]$
M14)51R==.PH@("`@("`@('!A<F5N=#HZ4$5!4B@G4T]!4%]&875L="<I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F%I<V5S(&$@4T]!4"!E<G)O<BX*("`@
M("`J"B`@("`@*B!0;&5A<V4@<F5F97(@=&\@=&AE(%-/05`@9&5F:6YI=&EO
M;B!F;W(@86X@:6UP<F5S<VEO;B!O9B!W:&%T(&$@8V5R=&%I;@H@("`@("H@
M<&%R86UE=&5R('-T86YD<R!F;W(N"B`@("`@*@H@("`@("H@57-E("1D96)U
M9U]F;&%G('1O('-T;W)E(&5R<F]R<R!T;R!T:&4@;65M8F5R('9A<FEA8FQE
M("1D96)U9U]D871A"B`@("`@*@H@("`@("H@0'-E92`D9&5B=6=?9FQA9RP@
M)&1E8G5G7V1A=&$L(%-/05!?1F%U;'0*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG?&]B:F5C="`D<W1R("!%<G)O<B!M97-S86=E(&]R(&]B:F5C="X*
M("`@("`J($!P87)A;2!S=')I;F<@)&1E=&%I;"`@("`@($1E=&%I;&5D(&5R
M<F]R(&UE<W-A9V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1A8W1O<E5220H@
M("`@("H@0'!A<F%M(&UI>&5D("1C;V1E"B`@("`@*B!`<&%R86T@;6EX960@
M)&UO9&4*("`@("`J($!P87)A;2!M:7AE9"`D;W!T:6]N<PH@("`@("H@0'!A
M<F%M(&)O;VQE86X@)'-K:7!M<V<*("`@("`J+PH@("`@9G5N8W1I;VX@)E]R
M86ES95-O87!&875L="@D<W1R+"`D9&5T86EL(#T@)R<L("1A8W1O<E5222`]
M("<G+"`D8V]D92`](&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1M;V1E(#T@;G5L;"P@)&]P=&EO;G,@/2!N=6QL+"`D<VMI<&US9R`]
M(&9A;'-E*0H@("`@>PH@("`@("`@("\O(%!A<W,@=&AR;W5G:"!P<F5V:6]U
M<R!F875L=',N"B`@("`@("`@)&ES7VEN<W1A;F-E(#T@:7-S970H)'1H:7,I
M.PH@("`@("`@(&EF("AI<U]O8FIE8W0H)'-T<BDI('L*("`@("`@("`@("`@
M)&9A=6QT(#TF("1S='(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M:68@*"$D8V]D92D@>PH@("`@("`@("`@("`@("`@)&-O9&4@/2`D:7-?:6YS
M=&%N8V4@/R`D=&AI<RT^7VUY9F%U;'1C;V1E(#H@)T-L:65N="<["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)&9A=6QT(#TF(&YE=R!33T%07T9A=6QT
M*"1S='(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M8V]D92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1A
M8W1O<E5222P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1D971A:6PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D;6]D92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1O<'1I;VYS*3L*("`@("`@("!]"B`@("`@("`@:68@*"1I<U]I;G-T86YC
M92D@>PH@("`@("`@("`@("`D=&AI<RT^9F%U;'0@/28@)&9A=6QT.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1F875L=#L*("`@('T*"B`@("!F=6YC
M=&EO;B!?7VES9F%U;'0H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M9F%U;'0@(3T@;G5L;#L*("`@('T*"B`@("!F=6YC=&EO;B`F7U]G971F875L
M="@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YF875L=#L*("`@('T*
M"B`@("`O*BH*("`@("`J($%D9',@82!S=')I;F<@=&\@=&AE(&1E8G5G(&1A
M=&$N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<W1R:6YG("!$96)U
M9V=I;F<@;65S<V%G92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V1E8G5G*"1S
M=')I;F<I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?9&5B=6=?9FQA9RD@
M>PH@("`@("`@("`@("`D=&AI<RT^7V1E8G5G7V1A=&$@+CT@9V5T7V-L87-S
M*"1T:&ES*2`N("<Z("<@+@H@("`@("`@("`@("`@("`@<W1R7W)E<&QA8V4H
M)SXG+"`B/EQR7&XB+"`D<W1R:6YG*2`N(")<;B(["B`@("`@("`@?0H@("`@
M?0H*?0H*+RHJ"B`J($-O;6UO;B!B87-E(&-L87-S(&]F(&%L;"!33T%0(&-L
M87-S97,N"B`J"B`J($!A8V-E<W,@("!P=6)L:6,*("H@0'!A8VMA9V4@(%-/
M05`*("H@0&%U=&AO<B`@(%-H86YE($-A<F%V96\@/'-H86YE0'!H<"YN970^
M($-O;G9E<G-I;VX@=&\@4$5!4B!A;F0@=7!D871E<PH@*B\*8VQA<W,@4T]!
M4%]"87-E(&5X=&5N9',@4T]!4%]"87-E7T]B:F5C=`I["B`@("!V87(@)%]8
M34Q38VAE;6$@/2!A<G)A>2@G:'1T<#HO+W=W=RYW,RYO<F<O,C`P,2]834Q3
M8VAE;6$G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAT='`Z+R]W
M=W<N=S,N;W)G+S$Y.3DO6$U,4V-H96UA)RD["B`@("!V87(@)%]834Q38VAE
M;6%697)S:6]N(#T@)VAT='`Z+R]W=W<N=S,N;W)G+S(P,#$O6$U,4V-H96UA
M)SL*"B`@("`O+R!L;V%D('1Y<&5S(&EN=&\@='EP96UA<"!A<G)A>0H@("`@
M=F%R("1?='EP96UA<"`](&%R<F%Y*`H@("`@("`@("=H='1P.B\O=W=W+G<S
M+F]R9R\R,#`Q+UA-3%-C:&5M82<@/3X@87)R87DH"B`@("`@("`@("`@("=S
M=')I;F<G(#T^("=S=')I;F<G+`H@("`@("`@("`@("`G8F]O;&5A;B<@/3X@
M)V)O;VQE86XG+`H@("`@("`@("`@("`G9FQO870G(#T^($9,3T%4+`H@("`@
M("`@("`@("`G9&]U8FQE)R`]/B!&3$]!5"P*("`@("`@("`@("`@)V1E8VEM
M86PG(#T^($9,3T%4+`H@("`@("`@("`@("`G9'5R871I;VXG(#T^("=I;G1E
M9V5R)RP*("`@("`@("`@("`@)V1A=&54:6UE)R`]/B`G<W1R:6YG)RP*("`@
M("`@("`@("`@)W1I;64G(#T^("=S=')I;F<G+`H@("`@("`@("`@("`G9&%T
M92<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("=G665A<DUO;G1H)R`]/B`G
M:6YT96=E<B<L"B`@("`@("`@("`@("=G665A<B<@/3X@)VEN=&5G97(G+`H@
M("`@("`@("`@("`G9TUO;G1H1&%Y)R`]/B`G:6YT96=E<B<L"B`@("`@("`@
M("`@("=G1&%Y)R`]/B`G:6YT96=E<B<L"B`@("`@("`@("`@("=G36]N=&@G
M(#T^("=I;G1E9V5R)RP*("`@("`@("`@("`@)VAE>$)I;F%R>2<@/3X@)W-T
M<FEN9R<L"B`@("`@("`@("`@("=B87-E-C1":6YA<GDG(#T^("=S=')I;F<G
M+`H@("`@("`@("`@("`O+R!D97)I=F5D(&1A=&%T>7!E<PH@("`@("`@("`@
M("`G;F]R;6%L:7IE9%-T<FEN9R<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@
M("=T;VME;B<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("=L86YG=6%G92<@
M/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("=.351/2T5.)R`]/B`G<W1R:6YG
M)RP*("`@("`@("`@("`@)TY-5$]+14Y3)R`]/B`G<W1R:6YG)RP*("`@("`@
M("`@("`@)TYA;64G(#T^("=S=')I;F<G+`H@("`@("`@("`@("`G3D-.86UE
M)R`]/B`G<W1R:6YG)RP*("`@("`@("`@("`@)TE$)R`]/B`G<W1R:6YG)RP*
M("`@("`@("`@("`@)TE$4D5&)R`]/B`G<W1R:6YG)RP*("`@("`@("`@("`@
M)TE$4D5&4R<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("=%3E1)5%DG(#T^
M("=S=')I;F<G+`H@("`@("`@("`@("`G14Y4251)15,G(#T^("=S=')I;F<G
M+`H@("`@("`@("`@("`G:6YT96=E<B<@/3X@)VEN=&5G97(G+`H@("`@("`@
M("`@("`G;F]N4&]S:71I=F5);G1E9V5R)R`]/B`G:6YT96=E<B<L"B`@("`@
M("`@("`@("=N96=A=&EV94EN=&5G97(G(#T^("=I;G1E9V5R)RP*("`@("`@
M("`@("`@)VQO;F<G(#T^("=I;G1E9V5R)RP*("`@("`@("`@("`@)VEN="<@
M/3X@)VEN=&5G97(G+`H@("`@("`@("`@("`G<VAO<G0G(#T^("=I;G1E9V5R
M)RP*("`@("`@("`@("`@)V)Y=&4G(#T^("=S=')I;F<G+`H@("`@("`@("`@
M("`G;F]N3F5G871I=F5);G1E9V5R)R`]/B`G:6YT96=E<B<L"B`@("`@("`@
M("`@("=U;G-I9VYE9$QO;F<G(#T^("=I;G1E9V5R)RP*("`@("`@("`@("`@
M)W5N<VEG;F5D26YT)R`]/B`G:6YT96=E<B<L"B`@("`@("`@("`@("=U;G-I
M9VYE9%-H;W)T)R`]/B`G:6YT96=E<B<L"B`@("`@("`@("`@("=U;G-I9VYE
M9$)Y=&4G(#T^("=I;G1E9V5R)RP*("`@("`@("`@("`@)W!O<VET:79E26YT
M96=E<B<@(#T^("=I;G1E9V5R)RP*("`@("`@("`@("`@)V%N>51Y<&4G(#T^
M("=S=')I;F<G+`H@("`@("`@("`@("`G86YY55)))R`]/B`G<W1R:6YG)RP*
M("`@("`@("`@("`@)U%.86UE)R`]/B`G<W1R:6YG)PH@("`@("`@("DL"B`@
M("`@("`@)VAT='`Z+R]W=W<N=S,N;W)G+S$Y.3DO6$U,4V-H96UA)R`]/B!A
M<G)A>2@*("`@("`@("`@("`@)VDT)R`]/B`G:6YT96=E<B<L"B`@("`@("`@
M("`@("=I;G0G(#T^("=I;G1E9V5R)RP*("`@("`@("`@("`@)V)O;VQE86XG
M(#T^("=B;V]L96%N)RP*("`@("`@("`@("`@)W-T<FEN9R<@/3X@)W-T<FEN
M9R<L"B`@("`@("`@("`@("=D;W5B;&4G(#T^($9,3T%4+`H@("`@("`@("`@
M("`G9FQO870G(#T^($9,3T%4+`H@("`@("`@("`@("`G9&%T951I;64G(#T^
M("=S=')I;F<G+`H@("`@("`@("`@("`G=&EM94EN<W1A;G0G(#T^("=S=')I
M;F<G+`H@("`@("`@("`@("`G8F%S938T0FEN87)Y)R`]/B`G<W1R:6YG)RP*
M("`@("`@("`@("`@)V)A<V4V-"<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@
M("=U<BUT>7!E)R`]/B`G<W1R:6YG)PH@("`@("`@("DL"B`@("`@("`@)VAT
M='`Z+R]S8VAE;6%S+GAM;'-O87`N;W)G+W-O87`O96YC;V1I;F<O)R`]/B!A
M<G)A>2@*("`@("`@("`@("`@)V)A<V4V-"<@/3X@)W-T<FEN9R<L"B`@("`@
M("`@("`@("=A<G)A>2<@/3X@)V%R<F%Y)RP*("`@("`@("`@("`@)T%R<F%Y
M)R`]/B`G87)R87DG+`H@("`@("`@("`@("`G4W1R=6-T)R`]/B`G87)R87DG
M*0H@("`@*3L*"B`@("`O*BH*("`@("`J($1E9F%U;'0@8VQA<W,@;F%M92!T
M;R!U<V4@9F]R(&1E8V]D960@<F5S<&]N<V4@;V)J96-T<RX*("`@("`J"B`@
M("`@*B!`=F%R('-T<FEN9R`D7V1E9F%U;'1/8FIE8W1#;&%S<VYA;64*("`@
M("`J+PH@("`@=F%R("1?9&5F875L=$]B:F5C=$-L87-S;F%M92`]("=S=&1#
M;&%S<R<["@H@("`@+R\@3&]A9"!N86UE<W!A8V4@55))<R!I;G1O(&%N(&%R
M<F%Y(&]F(%5222`]/B!P<F5F:7@N"B`@("!V87(@)%]N86UE<W!A8V5S.PH@
M("`@=F%R("1?;F%M97-P86-E.PH*("`@('9A<B`D7WAM;$5N=&ET:65S(#T@
M87)R87DH)R8G(#T^("<F86UP.R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("<\)R`]/B`G)FQT.R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("<^)R`]/B`G)F=T.R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("(G(B`]/B`G)F%P;W,[)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)R(G(#T^("<F<75O=#LG*3L*"B`@("!V87(@)%]D;V-O;G9E
M<G-I;VX@/2!F86QS93L*"B`@("!V87(@)%]?871T86-H;65N=',@/2!A<G)A
M>2@I.PH*("`@('9A<B`D7W=S9&P@/2!N=6QL.PH*("`@("\J*@H@("`@("H@
M5')U92!I9B!W92!U<V4@<V5C=&EO;B`U(&5N8V]D:6YG+"!O<B!F86QS92!I
M9B!T:&ES(&ES(&QI=&5R86PN"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N
M("1?<V5C=&EO;C4*("`@("`J+PH@("`@=F%R("1?<V5C=&EO;C4@/2!T<G5E
M.PH*("`@("\O($AA;F1L92!T>7!E('1O(&-L87-S(&UA<'!I;F<N"B`@("!V
M87(@)%]A=71O7W1R86YS;&%T:6]N(#T@9F%L<V4["B`@("!V87(@)%]T>7!E
M7W1R86YS;&%T:6]N(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($-O;G-T
M<G5C=&]R+@H@("`@("H*("`@("`J($!S964@)&1E8G5G7V1A=&$L(%]D96)U
M9R@I"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F%U;'1C;V1E("!%
M<G)O<B!C;V1E+@H@("`@("HO"B`@("!F=6YC=&EO;B!33T%07T)A<V4H)&9A
M=6QT8V]D92`]("=#;&EE;G0G*0H@("`@>PH@("`@("`@('!A<F5N=#HZ4T]!
M4%]"87-E7T]B:F5C="@D9F%U;'1C;V1E*3L*("`@("`@("`D=&AI<RT^7W)E
M<V5T3F%M97-P86-E<R@I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R97-E=$YA
M;65S<&%C97,H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;F%M97-P86-E<R`]
M(&%R<F%Y*`H@("`@("`@("`@("`G:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO
M<F<O<V]A<"]E;G9E;&]P92\G(#T^("=33T%0+45.5B<L"B`@("`@("`@("`@
M("=H='1P.B\O=W=W+G<S+F]R9R\R,#`Q+UA-3%-C:&5M82<@/3X@)WAS9"<L
M"B`@("`@("`@("`@("=H='1P.B\O=W=W+G<S+F]R9R\R,#`Q+UA-3%-C:&5M
M82UI;G-T86YC92<@/3X@)WAS:2<L"B`@("`@("`@("`@("=H='1P.B\O<V-H
M96UA<RYX;6QS;V%P+F]R9R]S;V%P+V5N8V]D:6YG+R<@/3X@)U-/05`M14Y#
M)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!S8VAE;6$@=F5R
M<VEO;B!U<V5D(&EN('1H92!33T%0(&UE<W-A9V4N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<V5E("1?6$U,4V-H96UA"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V-H96UA5F5R<VEO;B`@5&AE('-C
M:&5M82!V97)S:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<V5T4V-H96UA
M5F5R<VEO;B@D<V-H96UA5F5R<VEO;BD*("`@('L*("`@("`@("!I9B`H(6EN
M7V%R<F%Y*"1S8VAE;6%697)S:6]N+"`D=&AI<RT^7UA-3%-C:&5M82DI('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(G5N
M<W5P;W)T960@6$U,4V-H96UA("1S8VAE;6%697)S:6]N(BD["B`@("`@("`@
M?0H@("`@("`@("1T:&ES+3Y?6$U,4V-H96UA5F5R<VEO;B`]("1S8VAE;6%6
M97)S:6]N.PH@("`@("`@("1T;7!.4R`](&%R<F%Y7V9L:7`H)'1H:7,M/E]N
M86UE<W!A8V5S*3L*("`@("`@("`D=&UP3E-;)WAS9"==(#T@)'1H:7,M/E]8
M34Q38VAE;6%697)S:6]N.PH@("`@("`@("1T;7!.4ULG>'-I)UT@/2`D=&AI
M<RT^7UA-3%-C:&5M859E<G-I;VX@+B`G+6EN<W1A;F-E)SL*("`@("`@("`D
M=&AI<RT^7VYA;65S<&%C97,@/2!A<G)A>5]F;&EP*"1T;7!.4RD["B`@("!]
M"@H@("`@9G5N8W1I;VX@7V=E=$YA;65S<&%C95!R969I>"@D;G,I"B`@("![
M"B`@("`@("`@:68@*"1T:&ES+3Y?;F%M97-P86-E("8F("1N<R`]/2`D=&AI
M<RT^7VYA;65S<&%C92D@>PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@
M("`@?0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VYA;65S<&%C97-;)&YS
M72DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?;F%M97-P86-E<ULD
M;G-=.PH@("`@("`@('T*("`@("`@("`D<')E9FEX(#T@)VYS)R`N(&-O=6YT
M*"1T:&ES+3Y?;F%M97-P86-E<RD["B`@("`@("`@)'1H:7,M/E]N86UE<W!A
M8V5S6R1N<UT@/2`D<')E9FEX.PH@("`@("`@(')E='5R;B`D<')E9FEX.PH@
M("`@?0H*("`@(&9U;F-T:6]N(%]G971.86UE<W!A8V5&;W)0<F5F:7@H)'!R
M969I>"D*("`@('L*("`@("`@("`D9FQI<'!E9"`](&%R<F%Y7V9L:7`H)'1H
M:7,M/E]N86UE<W!A8V5S*3L*("`@("`@("!I9B`H:7-S970H)&9L:7!P961;
M)'!R969I>%TI*2!["B`@("`@("`@("`@(')E='5R;B`D9FQI<'!E9%LD<')E
M9FEX73L*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&YU;&P["B`@("!]"@H@
M("`@9G5N8W1I;VX@7VES4V]A<%9A;'5E*"8D=F%L=64I"B`@("!["B`@("`@
M("`@<F5T=7)N(&ES7V$H)'9A;'5E+"`G4T]!4%]686QU92<I.PH@("`@?0H*
M("`@(&9U;F-T:6]N(%]S97)I86QI>F5686QU92@F)'9A;'5E+"`D;F%M92`]
M("<G+"`D='EP92`](&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1E;$YA;65S<&%C92`](&YU;&PL("1T>7!E3F%M97-P86-E(#T@;G5L
M;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;W!T:6]N<R`](&%R
M<F%Y*"DL("1A='1R:6)U=&5S(#T@87)R87DH*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D87)T>7!E(#T@)R<I"B`@("!["B`@("`@("`@)&YA
M;65S<&%C97,@/2!A<G)A>2@I.PH@("`@("`@("1A<G)A>51Y<&4@/2`D87)R
M87E?9&5P=&@@/2`D>&UL;W5T7W9A;'5E(#T@;G5L;#L*("`@("`@("`D='EP
M95!R969I>"`]("1E;%!R969I>"`]("1X;6QO=71?;V9F<V5T(#T@)'AM;&]U
M=%]A<G)A>51Y<&4@/2`G)SL*("`@("`@("`D>&UL;W5T7W1Y<&4@/2`D>&UL
M;G,@/2`D<'1Y<&4@/2`D87)R87E?='EP95]N<R`]("<G.PH*("`@("`@("!I
M9B`H(21N86UE('Q\(&ES7VYU;65R:6,H)&YA;64I*2!["B`@("`@("`@("`@
M("1N86UE(#T@)VET96TG.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES
M+3Y?=W-D;"D@>PH@("`@("`@("`@("!L:7-T*"1P='EP92P@)&%R<F%Y5'EP
M92P@)&%R<F%Y7W1Y<&5?;G,L("1A<G)A>5]D97!T:"D*("`@("`@("`@("`@
M("`@(#T@)'1H:7,M/E]W<V1L+3YG97138VAE;6%4>7!E*"1T>7!E+"`D;F%M
M92P@)'1Y<&5.86UE<W!A8V4I.PH@("`@("`@('T*"B`@("`@("`@:68@*"$D
M87)R87E4>7!E*2!["B`@("`@("`@("`@("1A<G)A>51Y<&4@/2`D87)T>7!E
M.PH@("`@("`@('T*("`@("`@("!I9B`H(21P='EP92D@>PH@("`@("`@("`@
M("`D<'1Y<&4@/2`D=&AI<RT^7V=E=%1Y<&4H)'9A;'5E*3L*("`@("`@("!]
M"B`@("`@("`@:68@*"$D='EP92D@>PH@("`@("`@("`@("`D='EP92`]("1P
M='EP93L*("`@("`@("!]"@H@("`@("`@(&EF("AS=')C87-E8VUP*"1P='EP
M92P@)U-T<G5C="<I(#T](#`@?'P*("`@("`@("`@("`@<W1R8V%S96-M<"@D
M='EP92P@)U-T<G5C="<I(#T](#`I('L*("`@("`@("`@("`@+R\@4W1R=6-T
M"B`@("`@("`@("`@("1V87)S(#T@;G5L;#L*("`@("`@("`@("`@:68@*&ES
M7V]B:F5C="@D=F%L=64I*2!["B`@("`@("`@("`@("`@("`D=F%R<R`](&=E
M=%]O8FIE8W1?=F%R<R@D=F%L=64I.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)'9A<G,@/2`F)'9A;'5E.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D=F%R<RDI('L*("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*&%R<F%Y7VME>7,H)'9A<G,I(&%S("1K*2!["B`@
M("`@("`@("`@("`@("`@("`@+R\@2&ED92!P<FEV871E('9A<G,N"B`@("`@
M("`@("`@("`@("`@("`@:68@*"1K6S!=(#T]("=?)RD@8V]N=&EN=64["B`@
M("`@("`@("`@("`@("`@("`@:68@*&ES7V]B:F5C="@D=F%R<ULD:UTI*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A*"1V87)S6R1K72P@
M)U-/05!?5F%L=64G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'AM;&]U=%]V86QU92`N/2`D=F%R<ULD:UTM/G-E<FEA;&EZ92@D=&AI<RD[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`O+R!86%@@9V5T('1H92!M96UB97)S(&%N9"!S
M97)I86QI>F4@=&AE;2!I;G-T96%D"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`O+R!C;VYV97)T:6YG('1O(&%N(&%R<F%Y(&ES(&UO<F4@;W9E<FAE
M860@=&AA;B!W90H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@<VAO
M=6QD(')E86QL>2!D;RX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1X
M;6QO=71?=F%L=64@+CT@)'1H:7,M/E]S97)I86QI>F5686QU92AG971?;V)J
M96-T7W9A<G,H)'9A<G-;)&M=*2P@)&LL(&9A;'-E+"`D=&AI<RT^7W-E8W1I
M;VXU(#\@;G5L;"`Z("1E;$YA;65S<&%C92D["B`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D>&UL;W5T7W9A;'5E("X]("1T:&ES+3Y?<V5R
M:6%L:7IE5F%L=64H)'9A<G-;)&M=+"`D:RP@9F%L<V4L("1T:&ES+3Y?<V5C
M=&EO;C4@/R!N=6QL(#H@)&5L3F%M97-P86-E*3L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!](&5L<V5I9B`H<W1R8V%S96-M<"@D<'1Y<&4L("=!<G)A>2<I(#T](#`@
M?'P*("`@("`@("`@("`@("`@("`@<W1R8V%S96-M<"@D='EP92P@)T%R<F%Y
M)RD@/3T@,"D@>PH@("`@("`@("`@("`O+R!!<G)A>2X*("`@("`@("`@("`@
M)'1Y<&5.86UE<W!A8V4@/2!33T%07U-#2$5-05]%3D-/1$E.1SL*("`@("`@
M("`@("`@)&]R:6=?='EP92`]("1T>7!E.PH@("`@("`@("`@("`D='EP92`]
M("=!<G)A>2<["B`@("`@("`@("`@("1N=6UT>7!E<R`](#`["B`@("`@("`@
M("`@("\O(%A86"!T:&ES('=I;&P@8F4@<VQO=R!O;B!L87)G97(@87)R87ES
M+B`@0F%S:6-A;&QY+"!I="!F;&%T=&5N<PH@("`@("`@("`@("`O+R!A<G)A
M>7,@=&\@86QL;W<@=7,@=&\@<V5R:6%L:7IE(&UU;'1I+61I;65N<VEO;F%L
M(&%R<F%Y<RX@(%=E"B`@("`@("`@("`@("\O(&]N;'D@9&\@=&AI<R!I9B!A
M<G)A>51Y<&4@:7,@<V5T+"!W:&EC:"!W:6QL('1Y<&EC86QL>2!O;FQY"B`@
M("`@("`@("`@("\O(&AA<'!E;B!I9B!W92!A<F4@=7-I;F<@5U-$3`H@("`@
M("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)V9L871T96XG72D@?'P*("`@
M("`@("`@("`@("`@("@D87)R87E4>7!E("8F"B`@("`@("`@("`@("`@("`@
M*'-T<F-H<B@D87)R87E4>7!E+"`G+"<I('Q\('-T<G-T<B@D87)R87E4>7!E
M+"`G75LG*2DI*2!["B`@("`@("`@("`@("`@("`D;G5M='EP97,@/2`D=&AI
M<RT^7VUU;'1I07)R87E4>7!E*"1V86QU92P@)&%R<F%Y5'EP92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&%R7W-I>F4L("1X;6QO=71?=F%L=64I.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`D87)R87E?='EP92`]("1A<G)A>5]T>7!E7W!R969I>"`]("<G
M.PH@("`@("`@("`@("!I9B`H)&YU;71Y<&5S("$](#$I('L*("`@("`@("`@
M("`@("`@("1A<G)A>51Y<&513F%M92`])B!N97<@44YA;64H)&%R<F%Y5'EP
M92D["B`@("`@("`@("`@("`@("`D87)R87E4>7!E(#T@)&%R<F%Y5'EP95%.
M86UE+3YN86UE.PH@("`@("`@("`@("`@("`@)&%R<F%Y7W1Y<&5S(#T@87)R
M87DH*3L*("`@("`@("`@("`@("`@("1A<G)A>5]V86P@/2!N=6QL.PH*("`@
M("`@("`@("`@("`@("\O(%-E<FEA;&EZ92!E86-H(&%R<F%Y(&5L96UE;G0N
M"B`@("`@("`@("`@("`@("`D87)?<VEZ92`](&-O=6YT*"1V86QU92D["B`@
M("`@("`@("`@("`@("!F;W)E86-H("@D=F%L=64@87,@)&%R<F%Y7W9A;"D@
M>PH@("`@("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7VES4V]A<%9A;'5E
M*"1A<G)A>5]V86PI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1A<G)A
M>5]T>7!E(#T@)&%R<F%Y7W9A;"T^='EP93L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&%R<F%Y7W1Y<&5S6R1A<G)A>5]T>7!E72`](#$["B`@("`@("`@
M("`@("`@("`@("`@("`@("1A<G)A>5]T>7!E7VYS(#T@)&%R<F%Y7W9A;"T^
M='EP95]N86UE<W!A8V4["B`@("`@("`@("`@("`@("`@("`@("`@("1X;6QO
M=71?=F%L=64@+CT@)'1H:7,M/E]S97)I86QI>F5686QU92@D87)R87E?=F%L
M+"`D87)R87E?=F%L+3YN86UE+"`D87)R87E?='EP92P@)&%R<F%Y7W1Y<&5?
M;G,I.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1A<G)A>5]T>7!E(#T@)'1H:7,M/E]G9714>7!E*"1A
M<G)A>5]V86PI.PH@("`@("`@("`@("`@("`@("`@("`@("`D87)R87E?='EP
M97-;)&%R<F%Y7W1Y<&5=(#T@,3L*("`@("`@("`@("`@("`@("`@("`@("`@
M)'AM;&]U=%]V86QU92`N/2`D=&AI<RT^7W-E<FEA;&EZ959A;'5E*"1A<G)A
M>5]V86PL("=I=&5M)RP@)&%R<F%Y7W1Y<&4L("1T:&ES+3Y?<V5C=&EO;C4@
M/R!N=6QL(#H@)&5L3F%M97-P86-E*3L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)'AM;&]U=%]O
M9F9S970@/2`G(%-/05`M14Y#.F]F9G-E=#TB6S!=(B<["B`@("`@("`@("`@
M("`@("!I9B`H(21A<G)A>51Y<&4I('L*("`@("`@("`@("`@("`@("`@("`D
M;G5M='EP97,@/2!C;W5N="@D87)R87E?='EP97,I.PH@("`@("`@("`@("`@
M("`@("`@(&EF("@D;G5M='EP97,@/3T@,2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D87)R87E4>7!E(#T@)&%R<F%Y7W1Y<&4["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("\O(%5S:6YG(&%N>51Y
M<&4@:7,@;6]R92!I;G1E<F]P97)A8FQE+@H@("`@("`@("`@("`@("`@("`@
M(&EF("@D87)R87E?='EP92`]/2`G4W1R=6-T)RD@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D87)R87E?='EP92`]("<G.PH@("`@("`@("`@("`@("`@
M("`@('T@96QS96EF("@D87)R87E?='EP92`]/2`G07)R87DG*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1A<G)A>51Y<&4@/2`G86YY5'EP92<["B`@
M("`@("`@("`@("`@("`@("`@("`@("1A<G)A>5]T>7!E7W!R969I>"`]("=X
M<V0G.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("@A)&%R<F%Y5'EP92D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&%R<F%Y5'EP92`]("1A<G)A>5]T>7!E.PH@("`@
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("@A)&%R<F%Y5'EP92!\?"`D;G5M='EP97,@/B`Q*2!["B`@("`@("`@("`@
M("`@("`O+R!3:&]U;&0@<F5F97)E;F-E('=H870@<V-H96UA('=E)W)E('5S
M:6YG+@H@("`@("`@("`@("`@("`@)&%R<F%Y5'EP92`]("=X<V0Z86YY5'EP
M92<["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!I9B`H
M)&%R<F%Y7W1Y<&5?;G,I('L*("`@("`@("`@("`@("`@("`@("`D87)R87E?
M='EP95]P<F5F:7@@/2`D=&AI<RT^7V=E=$YA;65S<&%C95!R969I>"@D87)R
M87E?='EP95]N<RD["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H:7-S970H
M)'1H:7,M/E]T>7!E;6%P6R1T:&ES+3Y?6$U,4V-H96UA5F5R<VEO;EU;)&%R
M<F%Y5'EP95TI*2!["B`@("`@("`@("`@("`@("`@("`@)&%R<F%Y7W1Y<&5?
M<')E9FEX(#T@)'1H:7,M/E]N86UE<W!A8V5S6R1T:&ES+3Y?6$U,4V-H96UA
M5F5R<VEO;ET["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I
M9B`H)&%R<F%Y7W1Y<&5?<')E9FEX*2!["B`@("`@("`@("`@("`@("`@("`@
M)&%R<F%Y5'EP92`]("1A<G)A>5]T>7!E7W!R969I>"`N("<Z)R`N("1A<G)A
M>51Y<&4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("1X;6QO=71?87)R87E4>7!E(#T@)R!33T%0+45.0SIA<G)A>51Y
M<&4](B<@+B`D87)R87E4>7!E.PH@("`@("`@("`@("!I9B`H)&%R<F%Y7V1E
M<'1H("$](&YU;&PI('L*("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D
M:2`\("1A<G)A>5]D97!T:#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@
M("1X;6QO=71?87)R87E4>7!E("X]("=;72<["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)'AM;&]U=%]A<G)A>51Y<&4@
M+CT@(ELD87)?<VEZ95U<(B(["B`@("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?
M:7-3;V%P5F%L=64H)'9A;'5E*2D@>PH@("`@("`@("`@("`D>&UL;W5T7W9A
M;'5E(#TF("1V86QU92T^<V5R:6%L:7IE*"1T:&ES*3L*("`@("`@("!](&5L
M<V5I9B`H)'1Y<&4@/3T@)W-T<FEN9R<I('L*("`@("`@("`@("`@)'AM;&]U
M=%]V86QU92`](&AT;6QS<&5C:6%L8VAA<G,H)'9A;'5E*3L*("`@("`@("!]
M(&5L<V5I9B`H)'1Y<&4@/3T@)W)A=W-T<FEN9R<I('L*("`@("`@("`@("`@
M)'AM;&]U=%]V86QU92`])B`D=F%L=64["B`@("`@("`@?2!E;'-E:68@*"1T
M>7!E(#T]("=B;V]L96%N)RD@>PH@("`@("`@("`@("`D>&UL;W5T7W9A;'5E
M(#T@)'9A;'5E(#\@)W1R=64G(#H@)V9A;'-E)SL*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D>&UL;W5T7W9A;'5E(#TF("1V86QU93L*("`@("`@
M("!]"@H@("`@("`@("\O($%D9"!N86UE<W!A8V5S+@H@("`@("`@(&EF("@D
M96Q.86UE<W!A8V4I('L*("`@("`@("`@("`@)&5L4')E9FEX(#T@)'1H:7,M
M/E]G971.86UE<W!A8V50<F5F:7@H)&5L3F%M97-P86-E*3L*("`@("`@("`@
M("`@:68@*"1E;%!R969I>"D@>PH@("`@("`@("`@("`@("`@)'AM;&]U=%]N
M86UE(#T@(B1E;%!R969I>#HD;F%M92(["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D>&UL;W5T7VYA;64@/2`D;F%M93L*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1X;6QO=71?
M;F%M92`]("1N86UE.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T>7!E3F%M
M97-P86-E*2!["B`@("`@("`@("`@("1T>7!E4')E9FEX(#T@)'1H:7,M/E]G
M971.86UE<W!A8V50<F5F:7@H)'1Y<&5.86UE<W!A8V4I.PH@("`@("`@("`@
M("!I9B`H)'1Y<&50<F5F:7@I('L*("`@("`@("`@("`@("`@("1X;6QO=71?
M='EP92`]("(D='EP95!R969I>#HD='EP92(["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D>&UL;W5T7W1Y<&4@/2`D='EP93L*("`@
M("`@("`@("`@?0H@("`@("`@('T@96QS96EF("@D='EP92`F)@H@("`@("`@
M("`@("`@("`@("!I<W-E="@D=&AI<RT^7W1Y<&5M87!;)'1H:7,M/E]834Q3
M8VAE;6%697)S:6]N75LD='EP95TI*2!["B`@("`@("`@("`@("1T>7!E4')E
M9FEX(#T@)'1H:7,M/E]N86UE<W!A8V5S6R1T:&ES+3Y?6$U,4V-H96UA5F5R
M<VEO;ET["B`@("`@("`@("`@(&EF("@D='EP95!R969I>"D@>PH@("`@("`@
M("`@("`@("`@)'AM;&]U=%]T>7!E(#T@(B1T>7!E4')E9FEX.B1T>7!E(CL*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1X;6QO=71?
M='EP92`]("1T>7!E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`O+R!(86YD;&4@861D:71I;VYA;"!A='1R:6)U=&5S+@H@("`@("`@("1X
M;6Q?871T<B`]("<G.PH@("`@("`@(&EF("AC;W5N="@D871T<FEB=71E<RDI
M('L*("`@("`@("`@("`@9F]R96%C:"`H)&%T=')I8G5T97,@87,@)&L@/3X@
M)'8I('L*("`@("`@("`@("`@("`@("1K<6X@/28@;F5W(%%.86UE*"1K*3L*
M("`@("`@("`@("`@("`@("1V<6X@/28@;F5W(%%.86UE*"1V*3L*("`@("`@
M("`@("`@("`@("1X;6Q?871T<B`N/2`G("<@+B`D:W%N+3YF<6XH*2`N("<]
M(B<@+B`D=G%N+3YF<6XH*2`N("<B)SL*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@+R\@4W1O<F4@=&AE(&%T=&%C:&UE;G0@9F]R(&UI;64@
M96YC;V1I;F<N"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=A='1A8VAM
M96YT)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?7V%T=&%C:&UE;G1S6UT@
M/2`D;W!T:6]N<ULG871T86-H;65N="==.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"1T:&ES+3Y?<V5C=&EO;C4I('L*("`@("`@("`@("`@:68@*"1X;6QO
M=71?='EP92D@>PH@("`@("`@("`@("`@("`@)'AM;&]U=%]T>7!E(#T@(B!X
M<VDZ='EP93U<(B1X;6QO=71?='EP95PB(CL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!I9B`H:7-?;G5L;"@D>&UL;W5T7W9A;'5E*2D@>PH@("`@("`@
M("`@("`@("`@)'AM;"`](")<<EQN/"1X;6QO=71?;F%M921X;6QO=71?='EP
M921X;6QN<R1X;6QO=71?87)R87E4>7!E(B`N"B`@("`@("`@("`@("`@("`@
M("`@(B1X;6Q?871T<B!X<VDZ;FEL/5PB=')U95PB+SXB.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'AM;"`](")<<EQN/"1X;6QO
M=71?;F%M921X;6QO=71?='EP921X;6QN<R1X;6QO=71?87)R87E4>7!E(B`N
M"B`@("`@("`@("`@("`@("`@("`@(B1X;6QO=71?;V9F<V5T)'AM;%]A='1R
M/B1X;6QO=71?=F%L=64\+R1X;6QO=71?;F%M93XB.PH@("`@("`@("`@("!]
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*&ES7VYU;&PH)'AM
M;&]U=%]V86QU92DI('L*("`@("`@("`@("`@("`@("1X;6P@/2`B7')<;CPD
M>&UL;W5T7VYA;64D>&UL;G,D>&UL7V%T='(O/B(["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D>&UL(#T@(EQR7&X\)'AM;&]U=%]N
M86UE)'AM;&YS)'AM;%]A='1R/B(@+@H@("`@("`@("`@("`@("`@("`@("1X
M;6QO=71?=F%L=64@+B`B/"\D>&UL;W5T7VYA;64^(CL*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1X;6P["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#;VYV97)T<R!A(%!(4"!T>7!E('1O(&$@4T]!4"!T>7!E
M+@H@("`@("H*("`@("`J($!A8V-E<W,@("!P<FEV871E"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=F%L=64@(%1H92!V86QU92!T;R!I;G-P96-T
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=F%L=64G<R!3
M3T%0('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G9714>7!E*"8D=F%L
M=64I"B`@("!["B`@("`@("`@9VQO8F%L("133T%07T]"2D5#5%]35%)50U0L
M("133T%07U)!5U]#3TY615)4.PH*("`@("`@("`D='EP92`](&=E='1Y<&4H
M)'9A;'5E*3L*("`@("`@("!S=VET8V@@*"1T>7!E*2!["B`@("`@("`@8V%S
M92`G;V)J96-T)SH*("`@("`@("`@("`@:68@*&ES7V$H)'9A;'5E+"`G<V]A
M<%]V86QU92<I*2!["B`@("`@("`@("`@("`@("`D='EP92`]("1V86QU92T^
M='EP93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T
M>7!E(#T@)U-T<G5C="<["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@(&-A<V4@)V%R<F%Y)SH*("`@("`@("`@("`@+R\@2&%S
M:&5S(&%R92!A;'=A>7,@:&%N9&QE9"!A<R!S=')U8W1S+@H@("`@("`@("`@
M("!I9B`H)'1H:7,M/E]I<TAA<V@H)'9A;'5E*2D@>PH@("`@("`@("`@("`@
M("`@)'1Y<&4@/2`G4W1R=6-T)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1A<E]S:7IE(#T@8V]U;G0H)'9A;'5E*3L*("`@("`@
M("`@("`@("`@(')E<V5T*"1V86QU92D["B`@("`@("`@("`@("`@("`D:V5Y
M,2`](&ME>2@D=F%L=64I.PH@("`@("`@("`@("`@("`@:68@*"1A<E]S:7IE
M(#X@,"`F)B!I<U]A*"1K97DQ+"`G4T]!4%]686QU92<I*2!["B`@("`@("`@
M("`@("`@("`@("`@+R\@1DE8344Z(&9O<B!N;VXM=W-D;"!S=')U8W1S('1H
M870@87)E(&%L;"!T:&4@<V%M92!T>7!E"B`@("`@("`@("`@("`@("`@("`@
M)&ME>3(@/2!K97DH)'9A;'5E*3L*("`@("`@("`@("`@("`@("`@("!I9B`H
M)&%R7W-I>F4@/B`Q("8F"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?:7-3;V%P5F%L=64H)&ME>3$I("8F"B`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?:7-3;V%P5F%L=64H)&ME>3(I("8F"B`@("`@("`@("`@
M("`@("`@("`@("`@("1K97DQ+3YN86UE("$]("1K97DR+3YN86UE*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("\O(%1H:7,@:7,@82!S=')U8W0L(&YO
M="!A;B!A<G)A>2X*("`@("`@("`@("`@("`@("`@("`@("`@)'1Y<&4@/2`G
M4W1R=6-T)SL*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D='EP92`]("=!<G)A>2<["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`D='EP92`]("=!<G)A>2<["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@)VEN=&5G97(G.@H@("`@("`@(&-A<V4@)VQO;F<G.@H@("`@("`@("`@
M("`D='EP92`]("=I;G0G.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M8V%S92`G8F]O;&5A;B<Z"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C
M87-E("=D;W5B;&4G.@H@("`@("`@("`@("`O+R!D;W5B;&4@:7,@9&5P<F5C
M871E9"!I;B!02%`@-"XR(&%N9"!L871E<BX*("`@("`@("`@("`@)'1Y<&4@
M/2`G9FQO870G.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G
M;G5L;"<Z"B`@("`@("`@("`@("1T>7!E(#T@)R<["B`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("!C87-E("=S=')I;F<G.@H@("`@("`@("`@("!I9B`H
M)%-/05!?4D%77T-/3E9%4E0I('L*("`@("`@("`@("`@("`@(&EF("AI<U]N
M=6UE<FEC*"1V86QU92DI('L*("`@("`@("`@("`@("`@("`@("!I9B`H<W1R
M<W1R*"1V86QU92P@)RXG*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M='EP92`]("=F;&]A="<["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)'1Y<&4@/2`G:6YT)SL*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@(&EF("A33T%07U1Y<&5?:&5X0FEN87)Y.CII<U]H
M97AB:6XH)'9A;'5E*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D='EP
M92`]("=H97A":6YA<GDG.PH@("`@("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7VES0F%S938T
M*"1V86QU92DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T>7!E
M(#T@)V)A<V4V-$)I;F%R>2<["B`@("`@("`@("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9'0@/28@;F5W
M(%-/05!?5'EP95]D871E5&EM92@D=F%L=64I.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"1D="T^=&]5;FEX=&EM92@I("$]("TQ*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1Y<&4@/2`G9&%T951I
M;64G.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!D969A=6QT.@H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D='EP93L*("`@('T*"B`@("!F=6YC=&EO;B!?
M;75L=&E!<G)A>51Y<&4H)B1V86QU92P@)B1T>7!E+"`F)'-I>F4L("8D>&UL
M*0H@("`@>PH@("`@("`@("1S>B`](&-O=6YT*"1V86QU92D["B`@("`@("`@
M:68@*&ES7V%R<F%Y*"1V86QU92DI('L*("`@("`@("`@("`@+R\@4V5E;7,@
M=V4@:&%V92!A(&UU;'1I(&1I;65N<VEO;F%L(&%R<F%Y+"!F:6=U<F4@:70@
M;W5T(&EF('=E"B`@("`@("`@("`@("\O(&1O+@H@("`@("`@("`@("`D8R`]
M(&-O=6YT*"1V86QU92D["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M("1C.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VUU;'1I07)R
M87E4>7!E*"1V86QU95LD:5TL("1T>7!E+"`D<VEZ92P@)'AM;"D["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@(&EF("@D<VEZ92D@>PH@("`@("`@("`@
M("`@("`@)'-I>F4@/2`D<WHN("<L)R`N("1S:7IE.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)'-I>F4@/2`D<WH["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@(')E='5R;B`Q.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(&EF("AI<U]O8FIE8W0H)'9A;'5E*2D@>PH@("`@("`@
M("`@("`@("`@)'1Y<&4@/2`D=F%L=64M/G1Y<&4["B`@("`@("`@("`@("`@
M("`D>&UL("X]("1V86QU92T^<V5R:6%L:7IE*"1T:&ES*3L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T>7!E(#T@)'1H:7,M/E]G
M9714>7!E*"1V86QU92D["B`@("`@("`@("`@("`@("`D>&UL("X]("1T:&ES
M+3Y?<V5R:6%L:7IE5F%L=64H)'9A;'5E+"`G:71E;2<L("1T>7!E*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D<VEZ92`](&YU;&P["@H@
M("`@("`@(')E='5R;B`Q.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!W:&5T:&5R(&$@<W1R:6YG(&ES(&)A<V4V-"!E;F-O9&5D(&1A=&$N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=F%L=64@(%1H92!S=')I;F<@
M=&\@8VAE8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E
M(&EF('1H92!S<&5C:69I960@=F%L=64@<V5E;7,@=&\@8F4@8F%S938T(&5N
M8V]D960N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]I<T)A<V4V-"@F)'9A;'5E
M*0H@("`@>PH@("`@("`@("1L(#T@<W1R;&5N*"1V86QU92D["B`@("`@("`@
M:68@*"1L*2!["B`@("`@("`@("`@(')E='5R;B`D=F%L=65;)&P@+2`Q72`]
M/2`G/2<@)B8*("`@("`@("`@("`@("`@('!R96=?;6%T8V@H)R];02U:82UZ
M/5PO7"M=*R\G+"`D=F%L=64I.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('=H971H97(@
M82!T>7!E(&ES(&$@8F%S938T('1Y<&4N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D='EP92`@02!T>7!E(&YA;64N"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!T>7!E(&YA;64@:7,@82!B87-E
M-C0@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@7VES0F%S938T5'EP92@D
M='EP92D*("`@('L*("`@("`@("!R971U<FX@)'1Y<&4@/3T@)V)A<V4V-"<@
M?'P@)'1Y<&4@/3T@)V)A<V4V-$)I;F%R>2<["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('=H971H97(@86X@87)R87D@:7,@82!H87-H+@H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D82`@06X@87)R87D@=&\@8VAE8VLN
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!S
M<&5C:69I960@87)R87D@:7,@82!H87-H+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?:7-(87-H*"8D82D*("`@('L*("`@("`@("`O+R!)(')E86QL>2!D:7-L
M:6ME(&AA=FEN9R!T;R!L;V]P('1H<F]U9V@@=&AI<R!I;B!02%`@8V]D92P@
M<F5A;&QY"B`@("`@("`@+R\@;&%R9V4@87)R87ES('=I;&P@8F4@<VQO=RX@
M(%=E(&YE960@82!#(&9U;F-T:6]N('1O(&1O('1H:7,N"B`@("`@("`@)&YA
M;65S(#T@87)R87DH*3L*("`@("`@("`D:70@/2`P.PH@("`@("`@(&9O<F5A
M8V@@*"1A(&%S("1K(#T^("1V*2!["B`@("`@("`@("`@("\O($-H96-K:6YG
M('1H92!T>7!E(&ES(&9A<W1E<B!T:&%N(')E9V5X<"X*("`@("`@("`@("`@
M)'0@/2!G971T>7!E*"1K*3L*("`@("`@("`@("`@:68@*"1T("$]("=I;G1E
M9V5R)RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@
M("`@('T@96QS96EF("@D=&AI<RT^7VES4V]A<%9A;'5E*"1V*2D@>PH@("`@
M("`@("`@("`@("`@)&YA;65S6R1V+3YN86UE72`](#$["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@+R\@268@<V]M96]N92!H87,@82!L87)G92!H87-H
M('1H97D@<VAO=6QD(')E86QL>2!B92!D969I;FEN9R!T:&4*("`@("`@("`@
M("`@+R\@='EP92X*("`@("`@("`@("`@:68@*"1I="LK(#X@,3`I('L*("`@
M("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@("`@("!R971U<FX@8V]U;G0H)&YA;65S*3XQ.PH@("`@?0H*
M("`@(&9U;F-T:6]N("9?=6Y?:'1M;&5N=&ET:65S*"1S=')I;F<I"B`@("![
M"B`@("`@("`@)'1R86YS7W1B;"`](&=E=%]H=&UL7W1R86YS;&%T:6]N7W1A
M8FQE*$A434Q?14Y4251)15,I.PH@("`@("`@("1T<F%N<U]T8FP@/2!A<G)A
M>5]F;&EP*"1T<F%N<U]T8FPI.PH@("`@("`@(')E='5R;B!S=')T<B@D<W1R
M:6YG+"`D=')A;G-?=&)L*3L*("`@('T*"B`@("!F=6YC=&EO;B`F7V1E8V]D
M92@F)'-O87!V86PI"B`@("!["B`@("`@("`@9VQO8F%L("133T%07T]"2D5#
M5%]35%)50U0["@H@("`@("`@(&EF("@A)'1H:7,M/E]I<U-O87!686QU92@D
M<V]A<'9A;"DI('L*("`@("`@("`@("`@<F5T=7)N("1S;V%P=F%L.PH@("`@
M("`@('T@96QS96EF("AI<U]A<G)A>2@D<V]A<'9A;"T^=F%L=64I*2!["B`@
M("`@("`@("`@(&EF("@D4T]!4%]/0DI%0U1?4U1254-4("8F("1S;V%P=F%L
M+3YT>7!E("$]("=!<G)A>2<I('L*("`@("`@("`@("`@("`@("1C;&%S<VYA
M;64@/2`D=&AI<RT^7V1E9F%U;'1/8FIE8W1#;&%S<VYA;64["B`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]T>7!E7W1R86YS;&%T:6]N6R1S
M;V%P=F%L+3YT<6XM/F9Q;B@I72DI('L*("`@("`@("`@("`@("`@("`@("`O
M+R!4:&ES('=I;&P@9F]R8V4@86X@97)R;W(@:6X@4$A0(&EF('1H92!C;&%S
M<R!D;V5S(&YO=`H@("`@("`@("`@("`@("`@("`@("\O(&5X:7-T+@H@("`@
M("`@("`@("`@("`@("`@("1C;&%S<VYA;64@/2`D=&AI<RT^7W1Y<&5?=')A
M;G-L871I;VY;)'-O87!V86PM/G1Q;BT^9G%N*"E=.PH@("`@("`@("`@("`@
M("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES+3Y?='EP95]T<F%N<VQA=&EO;ELD
M<V]A<'9A;"T^='EP95TI*2!["B`@("`@("`@("`@("`@("`@("`@+R\@5&AI
M<R!W:6QL(&9O<F-E(&%N(&5R<F]R(&EN(%!(4"!I9B!T:&4@8VQA<W,@9&]E
M<R!N;W0*("`@("`@("`@("`@("`@("`@("`O+R!E>&ES="X*("`@("`@("`@
M("`@("`@("`@("`D8VQA<W-N86UE(#T@)'1H:7,M/E]T>7!E7W1R86YS;&%T
M:6]N6R1S;V%P=F%L+3YT>7!E73L*("`@("`@("`@("`@("`@('T@96QS96EF
M("@D=&AI<RT^7V%U=&]?=')A;G-L871I;VXI('L*("`@("`@("`@("`@("`@
M("`@("!I9B`H8VQA<W-?97AI<W1S*"1S;V%P=F%L+3YT>7!E*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D8VQA<W-N86UE(#T@)'-O87!V86PM/G1Y
M<&4["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?=W-D
M;"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D="`]("1T:&ES+3Y?=W-D
M;"T^9V5T0V]M<&QE>%1Y<&5.86UE1F]R16QE;65N="@D<V]A<'9A;"T^;F%M
M92P@)'-O87!V86PM/FYA;65S<&%C92D["B`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@D="`F)B!C;&%S<U]E>&ES=',H)'0I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D8VQA<W-N86UE(#T@)'0["B`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`D<F5T=7)N(#TF(&YE=R`D8VQA
M<W-N86UE.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)')E='5R;B`](&%R<F%Y*"D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1C;W5N=&5R(#T@,3L*("`@("`@("`@("`@)&ES<W1R=6-T(#T@(2133T%0
M7T]"2D5#5%]35%)50U0@?'P@(6ES7V%R<F%Y*"1R971U<FXI.PH@("`@("`@
M("`@("!F;W)E86-H("@D<V]A<'9A;"T^=F%L=64@87,@)&ET96TI('L*("`@
M("`@("`@("`@("`@(&EF("AI<U]O8FIE8W0H)')E='5R;BDI('L*("`@("`@
M("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]W<V1L*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("\O($=E="!T:&ES(&-H:6QD)W,@5U-$3"!I;F9O<FUA
M=&EO;BX*("`@("`@("`@("`@("`@("`@("`@("`@+R\@+R1S;V%P=F%L+3YN
M<R\D<V]A<'9A;"T^='EP92\D:71E;2T^;G,O)&ET96TM/FYA;64*("`@("`@
M("`@("`@("`@("`@("`@("`@)&-H:6QD7W1Y<&4@/2`D=&AI<RT^7W=S9&PM
M/F=E=$-O;7!L97A4>7!E0VAI;&14>7!E*`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'-O87!V86PM/FYA;65S<&%C92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1S;V%P=F%L+3YN86UE+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&ET96TM/FYA;65S<&%C92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1I=&5M+3YN86UE*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"1C:&EL9%]T>7!E*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D:71E;2T^='EP92`]("1C:&EL9%]T>7!E.PH@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@(&EF("@A)&ES<W1R=6-T('Q\("1I=&5M+3YT>7!E(#T]
M("=!<G)A>2<I('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1R971U<FXM/GLD:71E;2T^;F%M97TI("8F"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!I<U]O8FIE8W0H)')E='5R;BT^>R1I=&5M+3YN86UE?2DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R971U<FXM/GLD:71E
M;2T^;F%M97T@/28@)'1H:7,M/E]D96-O9&4H)&ET96TI.PH@("`@("`@("`@
M("`@("`@("`@("`@("!](&5L<V5I9B`H:7-S970H)')E='5R;BT^>R1I=&5M
M+3YN86UE?2D@)B8*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&ES7V%R<F%Y*"1R971U<FXM/GLD:71E;2T^;F%M97TI*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<F5T=7)N+3Y[)&ET96TM/FYA;65]6UT@
M/28@)'1H:7,M/E]D96-O9&4H)&ET96TI.PH@("`@("`@("`@("`@("`@("`@
M("`@("!](&5L<V5I9B`H:7-?87)R87DH)')E='5R;BDI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1R971U<FY;72`])B`D=&AI<RT^7V1E8V]D
M92@D:71E;2D["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5T=7)N+3Y[)&ET96TM/FYA
M;65](#TF("1T:&ES+3Y?9&5C;V1E*"1I=&5M*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T@96QS96EF("AI<W-E
M="@D<F5T=7)N+3Y[)&ET96TM/FYA;65]*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D:7-S=')U8W0@/2!F86QS93L*("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*&-O=6YT*&=E=%]O8FIE8W1?=F%R<R@D<F5T=7)N*2D@/3T@
M,2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&0@/28@)'1H:7,M
M/E]D96-O9&4H)&ET96TI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)')E='5R;B`](&%R<F%Y*"1R971U<FXM/GLD:71E;2T^;F%M97TL("1D*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1D(#TF("1T:&ES+3Y?9&5C;V1E*"1I=&5M*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R971U<FXM/GLD:71E;2T^
M;F%M97T@/2!A<G)A>2@D<F5T=7)N+3Y[)&ET96TM/FYA;65]+"`D9"D["B`@
M("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<F5T=7)N+3Y[)&ET
M96TM/FYA;65](#TF("1T:&ES+3Y?9&5C;V1E*"1I=&5M*3L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@+R\@4V5T('1H92!A
M='1R:6)U=&5S(&%S(&UE;6)E<G,@:6X@=&AE(&-L87-S+@H@("`@("`@("`@
M("`@("`@("`@(&EF("AM971H;V1?97AI<W1S*"1R971U<FXL("=?7W-E=%]A
M='1R:6)U=&4G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H
M("@D<V]A<'9A;"T^871T<FEB=71E<R!A<R`D:V5Y(#T^("1V86QU92D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F-?87)R
M87DH87)R87DH)B1R971U<FXL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G7U]S971?871T<FEB=71E
M)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A<G)A>2@D:V5Y+"`D=F%L=64I*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@:68@*"1S;V%P=F%L
M+3YA<G)A>51Y<&4@)B8@)'1H:7,M/E]I<U-O87!686QU92@D:71E;2DI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?:7-"87-E-C14
M>7!E*"1I=&5M+3YT>7!E*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(21T:&ES+3Y?:7-"87-E-C14>7!E*"1S;V%P=F%L+3YA<G)A>51Y<&4I
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!$96-O9&4@=&AE
M('9A;'5E(&EF('=E)W)E(&QO<VEN9R!T:&4@8F%S938T"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`O+R!T>7!E(&EN9F]R;6%T:6]N+@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&ET96TM/G9A;'5E(#T@8F%S938T7V1E
M8V]D92@D:71E;2T^=F%L=64I.PH@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@("`@("1I=&5M+3YT>7!E(#T@)'-O87!V
M86PM/F%R<F%Y5'EP93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@:68@*"$D:7-S=')U8W0I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)')E='5R;EM=(#TF("1T:&ES+3Y?9&5C;V1E*"1I=&5M*3L*
M("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H:7-S970H)')E='5R;ELD
M:71E;2T^;F%M95TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1I<W-T
M<G5C="`](&9A;'-E.PH@("`@("`@("`@("`@("`@("`@("`@("`D9"`])B`D
M=&AI<RT^7V1E8V]D92@D:71E;2D["B`@("`@("`@("`@("`@("`@("`@("`@
M("1R971U<FX@/2!A<G)A>2@D<F5T=7)N6R1I=&5M+3YN86UE72P@)&0I.PH@
M("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1R971U<FY;)&ET96TM/FYA;65=(#TF("1T:&ES+3Y?9&5C;V1E
M*"1I=&5M*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(')E='5R;B`D<F5T=7)N
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"1S;V%P=F%L+3YT>7!E(#T]("=B
M;V]L96%N)RD@>PH@("`@("`@("`@("!I9B`H)'-O87!V86PM/G9A;'5E("$]
M("<P)R`F)@H@("`@("`@("`@("`@("`@<W1R8V%S96-M<"@D<V]A<'9A;"T^
M=F%L=64L("=F86QS92<I("$](#`I('L*("`@("`@("`@("`@("`@("1S;V%P
M=F%L+3YV86QU92`]('1R=64["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D<V]A<'9A;"T^=F%L=64@/2!F86QS93L*("`@("`@("`@
M("`@?0H@("`@("`@('T@96QS96EF("@D<V]A<'9A;"T^='EP92`F)@H@("`@
M("`@("`@("`@("`@("!I<W-E="@D=&AI<RT^7W1Y<&5M87!;4T]!4%]834Q?
M4T-(14U!7U9%4E-)3TY=6R1S;V%P=F%L+3YT>7!E72DI('L*("`@("`@("`@
M("`@+R\@268@=V4@8V%N+"!S970@=F%R:6%B;&4@='EP92X*("`@("`@("`@
M("`@<V5T='EP92@D<V]A<'9A;"T^=F%L=64L"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]T>7!E;6%P6U-/05!?6$U,7U-#2$5-05]615)324].75LD
M<V]A<'9A;"T^='EP95TI.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES
M+3Y?:7-"87-E-C14>7!E*"1S;V%P=F%L+3YT>7!E*2D@>PH@("`@("`@("`@
M("!R971U<FX@8F%S938T7V1E8V]D92@D<V]A<'9A;"T^=F%L=64I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D<V]A<'9A;"T^=F%L
M=64["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E<R!T
M:&4@4T]!4"!E;G9E;&]P92!W:71H('1H92!33T%0(&5N=F5L;W`@9&%T82X*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T*("`@("`J($!P87)A;2!A<G)A>2`D:&5A9&5R<PH@("`@("H@0'!A
M<F%M('-T<FEN9R`D96YC;V1I;F<*("`@("`J($!P87)A;2!A<G)A>2`D;W!T
M:6]N<PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9?;6%K945N=F5L;W!E*"8D;65T:&]D+"`F)&AE861E<G,L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D96YC;V1I;F<@/2!33T%0
M7T1%1D%53%1?14Y#3T1)3D<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D;W!T:6]N<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'-M<V<@/2`D
M:&5A9&5R7WAM;"`]("1N<U]S=')I;F<@/2`G)SL*"B`@("`@("`@:68@*"1H
M96%D97)S*2!["B`@("`@("`@("`@("1C(#T@8V]U;G0H)&AE861E<G,I.PH@
M("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D8SL@)&DK*RD@>PH@("`@
M("`@("`@("`@("`@)&AE861E<E]X;6P@+CT@)&AE861E<G-;)&E=+3YS97)I
M86QI>F4H)'1H:7,I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1H96%D
M97)?>&UL(#T@(CQ33T%0+45.5CI(96%D97(^7')<;B1H96%D97)?>&UL7')<
M;CPO4T]!4"U%3E8Z2&5A9&5R/EQR7&XB.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"%I<W-E="@D;W!T:6]N<ULG:6YP=70G72D@?'P@)&]P=&EO;G-;)VEN
M<'5T)UT@/3T@)W!A<G-E)RD@>PH@("`@("`@("`@("!I9B`H:7-?87)R87DH
M)&UE=&AO9"DI('L*("`@("`@("`@("`@("`@("1C(#T@8V]U;G0H)&UE=&AO
M9"D["B`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D8SL@)&DK
M*RD@>PH@("`@("`@("`@("`@("`@("`@("1S;7-G("X]("1M971H;V1;)&E=
M+3YS97)I86QI>F4H)'1H:7,I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'-M<V<@/28@)&UE=&AO
M9"T^<V5R:6%L:7IE*"1T:&ES*3L*("`@("`@("`@("`@?0H@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1S;7-G(#TF("1M971H;V0["B`@("`@("`@
M?0H@("`@("`@("1B;V1Y(#T@(CQ33T%0+45.5CI";V1Y/EQR7&XB("X@)'-M
M<V<@+B`B7')<;CPO4T]!4"U%3E8Z0F]D>3Y<<EQN(CL*"B`@("`@("`@9F]R
M96%C:"`H)'1H:7,M/E]N86UE<W!A8V5S(&%S("1K(#T^("1V*2!["B`@("`@
M("`@("`@("1N<U]S=')I;F<@+CT@(B!X;6QN<SHD=CU<(B1K7")<<EQN(CL*
M("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3Y?;F%M97-P86-E*2!["B`@
M("`@("`@("`@("1N<U]S=')I;F<@+CT@(B!X;6QN<SU<(GLD=&AI<RT^7VYA
M;65S<&%C97U<(EQR7&XB.PH@("`@("`@('T*"B`@("`@("`@+RH@268@)W5S
M92<@/3T@)VQI=&5R86PG+"!W92!D;R!N;W0@<'5T(&EN('1H92!E;F-O9&EN
M9U-T>6QE+B`@5&AI<R!I<PH@("`@("`@("`J(&1E;F]T960@8GD@)'1H:7,M
M/E]S96-T:6]N-2!B96EN9R!F86QS92X@("=U<V4G(&-A;B!B92!D969I;F5D
M(&%T(&$*("`@("`@("`@*B!M;W)E(&=R86YU;&%R(&QE=F5L('1H86X@=V4@
M87)E(&1E86QI;F<@=VET:"!H97)E+"!S;R!T:&ES(&1O97,@;F]T"B`@("`@
M("`@("H@=V]R:R!F;W(@86QL('-E<G9I8V5S+B`J+PH@("`@("`@("1X;6P@
M/2`B/#]X;6P@=F5R<VEO;CU<(C$N,%PB(&5N8V]D:6YG/5PB)&5N8V]D:6YG
M7"(_/EQR7&Y<<EQN(BX*("`@("`@("`@("`@(CQ33T%0+45.5CI%;G9E;&]P
M92`D;G-?<W1R:6YG(BX*("`@("`@("`@("`@*"1T:&ES+3Y?<V5C=&EO;C4@
M/R`G(%-/05`M14Y6.F5N8V]D:6YG4W1Y;&4](B<@+B!33T%07U-#2$5-05]%
M3D-/1$E.1R`N("<B)R`Z("<G*2X*("`@("`@("`@("`@(CY<<EQN(BX*("`@
M("`@("`@("`@(B1H96%D97)?>&UL)&)O9'D\+U-/05`M14Y6.D5N=F5L;W!E
M/EQR7&XB.PH*("`@("`@("!R971U<FX@)'AM;#L*("`@('T*"B`@("!F=6YC
M=&EO;B`F7VUA:V5-:6UE365S<V%G92@F)'AM;"P@)&5N8V]D:6YG(#T@4T]!
M4%]$149!54Q47T5.0T]$24Y'*0H@("`@>PH@("`@("`@(&=L;V)A;"`D4T]!
M4%]O<'1I;VYS.PH*("`@("`@("!I9B`H(6ES<V5T*"133T%07V]P=&EO;G-;
M)TUI;64G72DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53
M;V%P1F%U;'0H)TUI;64@:7,@;F]T(&EN<W1A;&QE9"<I.PH@("`@("`@('T*
M"B`@("`@("`@+R\@16YC;V1E(&%N>2!A='1A8VAM96YT<RX*("`@("`@("`O
M+R!3964@:'1T<#HO+W=W=RYW,RYO<F<O5%(O4T]!4"UA='1A8VAM96YT<PH@
M("`@("`@("\O($YO=R!W92!H879E('1O(&UI;64@96YC;V1E('1H92!M97-S
M86=E+@H@("`@("`@("1P87)A;7,@/2!A<G)A>2@G8V]N=&5N=%]T>7!E)R`]
M/B`G;75L=&EP87)T+W)E;&%T960[('1Y<&4]=&5X="]X;6PG*3L*("`@("`@
M("`D;7-G(#TF(&YE=R!-86EL7VUI;65087)T*"<G+"`D<&%R86US*3L*"B`@
M("`@("`@+R\@061D('1H92!X;6P@<&%R="X*("`@("`@("`D<&%R86US6R=C
M;VYT96YT7W1Y<&4G72`]("=T97AT+WAM;"<["B`@("`@("`@)'!A<F%M<ULG
M8VAA<G-E="==(#T@)&5N8V]D:6YG.PH@("`@("`@("1P87)A;7-;)V5N8V]D
M:6YG)UT@/2`G8F%S938T)SL*("`@("`@("`D;7-G+3YA9&13=6)087)T*"1X
M;6PL("1P87)A;7,I.PH*("`@("`@("`O+R!!9&0@=&AE(&%T=&%C:&5M96YT
M<PH@("`@("`@("1C(#T@8V]U;G0H)'1H:7,M/E]?871T86-H;65N=',I.PH@
M("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1C.R`D:2LK*2!["B`@("`@("`@
M("`@("1A='1A8VAM96YT(#TF("1T:&ES+3Y?7V%T=&%C:&UE;G1S6R1I73L*
M("`@("`@("`@("`@)&US9RT^861D4W5B4&%R="@D871T86-H;65N=%LG8F]D
M>2==+"`D871T86-H;65N="D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&US9RT^96YC;V1E*"D["B`@("!]"@H@("`@+R\@5$]$3SH@=&AI<R!N965D
M<R!T;R!B92!U<V5D(&9R;VT@=&AE(%1R86YS<&]R="!S>7-T96TN"B`@("!F
M=6YC=&EO;B`F7VUA:V5$24U%365S<V%G92@F)'AM;"D*("`@('L*("`@("`@
M("!G;&]B86P@)%-/05!?;W!T:6]N<SL*"B`@("`@("`@:68@*"%I<W-E="@D
M4T]!4%]O<'1I;VYS6R=$24U%)UTI*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=$24U%(&ES(&YO="!I;G-T86QL960G
M*3L*("`@("`@("!]"@H@("`@("`@("\O($5N8V]D92!A;GD@871T86-H;65N
M=',N"B`@("`@("`@+R\@4V5E(&AT='`Z+R]S96%R8V@N:65T9BYO<F<O:6YT
M97)N970M9')A9G1S+V1R869T+6YI96QS96XM9&EM92US;V%P+3`P+G1X=`H@
M("`@("`@("\O($YO=R!W92!H879E('1O($1)344@96YC;V1E('1H92!M97-S
M86=E"B`@("`@("`@)&1I;64@/28@;F5W($YE=%]$24U%7TUE<W-A9V4H*3L*
M("`@("`@("`D;7-G(#TF("1D:6UE+3YE;F-O9&5$871A*"1X;6PL(%-/05!?
M14Y614Q/4"P@;G5L;"P@3D547T1)345?5%E015]54DDI.PH*("`@("`@("`O
M+R!!9&0@=&AE(&%T=&%C:&UE;G1S+@H@("`@("`@("1C(#T@8V]U;G0H)'1H
M:7,M/E]?871T86-H;65N=',I.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M("1C.R`D:2LK*2!["B`@("`@("`@("`@("1A='1A8VAM96YT(#TF("1T:&ES
M+3Y?7V%T=&%C:&UE;G1S6R1I73L*("`@("`@("`@("`@)&US9R`N/2`D9&EM
M92T^96YC;V1E1&%T82@D871T86-H;65N=%LG8F]D>2==+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1A='1A8VAM96YT6R=C;VYT
M96YT7W1Y<&4G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D871T86-H;65N=%LG8VED)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@3D547T1)345?5%E015]-141)02D["B`@("`@
M("`@?0H@("`@("`@("1M<V<@+CT@)&1I;64M/F5N9$UE<W-A9V4H*3L*"B`@
M("`@("`@<F5T=7)N("1M<V<["B`@("!]"@H@("`@9G5N8W1I;VX@7V1E8V]D
M94UI;65-97-S86=E*"8D9&%T82P@)B1H96%D97)S+"`F)&%T=&%C:&UE;G1S
M*0H@("`@>PH@("`@("`@(&=L;V)A;"`D4T]!4%]O<'1I;VYS.PH*("`@("`@
M("!I9B`H(6ES<V5T*"133T%07V]P=&EO;G-;)TUI;64G72DI('L*("`@("`@
M("`@("`@)'1H:7,M/E]R86ES95-O87!&875L="@G36EM92!5;G-U<'!O<G1E
M9"P@:6YS=&%L;"!014%2.CI-86EL.CI-:6UE)RP@)R<L("<G+"`G4V5R=F5R
M)RD["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("1P
M87)A;7-;)VEN8VQU9&5?8F]D:65S)UT@/2!T<G5E.PH@("`@("`@("1P87)A
M;7-;)V1E8V]D95]B;V1I97,G72`@/2!T<G5E.PH@("`@("`@("1P87)A;7-;
M)V1E8V]D95]H96%D97)S)UT@/2!T<G5E.PH*("`@("`@("`O+R!,86UE('1H
M:6YG('1O(&AA=F4@=&\@9&\@9F]R(&1E8V]D:6YG+@H@("`@("`@("1D96-O
M9&5R(#TF(&YE=R!-86EL7VUI;65$96-O9&4H)&1A=&$I.PH@("`@("`@("1S
M=')U8W1U<F4@/2`D9&5C;V1E<BT^9&5C;V1E*"1P87)A;7,I.PH*("`@("`@
M("!I9B`H:7-S970H)'-T<G5C='5R92T^8F]D>2DI('L*("`@("`@("`@("`@
M)&1A=&$@/2`D<W1R=6-T=7)E+3YB;V1Y.PH@("`@("`@("`@("`D:&5A9&5R
M<R`]("1S=')U8W1U<F4M/FAE861E<G,["@H@("`@("`@("`@("!R971U<FX[
M"B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1S=')U8W1U<F4M/G!A<G1S*2D@
M>PH@("`@("`@("`@("`D9&%T82`]("1S=')U8W1U<F4M/G!A<G1S6S!=+3YB
M;V1Y.PH@("`@("`@("`@("`D:&5A9&5R<R`](&%R<F%Y7VUE<F=E*"1S=')U
M8W1U<F4M/FAE861E<G,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'-T<G5C='5R92T^<&%R='-;,%TM/FAE861E<G,I.PH@("`@("`@
M("`@("!I9B`H8V]U;G0H)'-T<G5C='5R92T^<&%R=',I(#X@,2D@>PH@("`@
M("`@("`@("`@("`@)&UI;65?<&%R=',@/2!A<G)A>5]S<&QI8V4H)'-T<G5C
M='5R92T^<&%R=',L,2D["B`@("`@("`@("`@("`@("`O+R!0<F5P87)E('1H
M92!P87)T<R!F;W(@=&AE(%-/05`@<&%R<V5R+@H*("`@("`@("`@("`@("`@
M("1C(#T@8V]U;G0H)&UI;65?<&%R=',I.PH@("`@("`@("`@("`@("`@9F]R
M("@D:2`](#`[("1I(#P@)&,[("1I*RLI('L*("`@("`@("`@("`@("`@("`@
M("`D<"`])B`D;6EM95]P87)T<ULD:5T["B`@("`@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1P+3YH96%D97)S6R=C;VYT96YT+6QO8V%T:6]N)UTI*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("\O(%1/1$\Z(&UO9&EF>2!L;V-A
M=&EO;B!P97(@4W=!(&YO=&4@<V5C=&EO;B`S"B`@("`@("`@("`@("`@("`@
M("`@("`@("\O(&AT='`Z+R]W=W<N=S,N;W)G+U12+U-/05`M871T86-H;65N
M=',*("`@("`@("`@("`@("`@("`@("`@("`@)&%T=&%C:&UE;G1S6R1P+3YH
M96%D97)S6R=C;VYT96YT+6QO8V%T:6]N)UU=(#T@)'`M/F)O9'D["B`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&-I9"`]("=C:60Z)R`N('-U8G-T<B@D<"T^:&5A9&5R<ULG8V]N=&5N
M="UI9"==+"`Q+"`M,BD["B`@("`@("`@("`@("`@("`@("`@("`@("1A='1A
M8VAM96YT<ULD8VED72`]("1P+3YB;V1Y.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]R86ES95-O
M87!&875L="@G36EM92!P87)S:6YG(&5R<F]R)RP@)R<L("<G+"`G4V5R=F5R
M)RD["B`@("!]"@H@("`@9G5N8W1I;VX@7V1E8V]D941)345-97-S86=E*"8D
M9&%T82P@)B1H96%D97)S+"`F)&%T=&%C:&UE;G1S*0H@("`@>PH@("`@("`@
M(&=L;V)A;"`D4T]!4%]O<'1I;VYS.PH*("`@("`@("!I9B`H(6ES<V5T*"13
M3T%07V]P=&EO;G-;)T1)344G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]R
M86ES95-O87!&875L="@G1$E-12!5;G-U<'!O<G1E9"P@:6YS=&%L;"!014%2
M.CI.970Z.D1)344G+"`G)RP@)R<L("=397)V97(G*3L*("`@("`@("`@("`@
M<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@+R\@5&AI<R!32$]53$0@8F4@
M;6]V960@=&\@=&AE('1R86YS<&]R="!L87EE<BP@92YG+B!02%`@:71S96QF
M('-H;W5L9`H@("`@("`@("\O(&AA;F1L92!P87)S:6YG($1)344@.RD*("`@
M("`@("`D9&EM92`])B!N97<@3F5T7T1)345?365S<V%G92@I.PH@("`@("`@
M("1E<G(@/2`D9&EM92T^9&5C;V1E1&%T82@D9&%T82D["B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&5R<BDI('L*("`@("`@("`@("`@)'1H:7,M/E]R
M86ES95-O87!&875L="@G1F%I;&5D('1O(&1E8V]D92!T:&4@1$E-12!M97-S
M86=E(2<L("<G+"`G)RP@)U-E<G9E<B<I.PH@("`@("`@("`@("!R971U<FX[
M"B`@("`@("`@?0H@("`@("`@(&EF("AS=')C87-E8VUP*"1D:6UE+3YP87)T
M<ULP75LG='EP92==+"!33T%07T5.5D5,3U`I("$](#`I('L*("`@("`@("`@
M("`@)'1H:7,M/E]R86ES95-O87!&875L="@G1$E-12!R96-O<F0@,2!I<R!N
M;W0@82!33T%0(&5N=F5L;W`A)RP@)R<L("<G+"`G4V5R=F5R)RD["B`@("`@
M("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("1D871A(#T@)&1I
M;64M/G!A<G1S6S!=6R=D871A)UT["B`@("`@("`@+R\@1F%K92!I="!F;W(@
M;F]W+@H@("`@("`@("1H96%D97)S6R=C;VYT96YT+71Y<&4G72`]("=T97AT
M+WAM;"<["B`@("`@("`@)&,@/2!C;W5N="@D9&EM92T^<&%R=',I.PH@("`@
M("`@(&9O<B`H)&D@/2`P.R`D:2`\("1C.R`D:2LK*2!["B`@("`@("`@("`@
M("1P87)T(#TF("1D:6UE+3YP87)T<ULD:5T["B`@("`@("`@("`@("\O(%=E
M(&YE960@=&\@:&%N9&QE(%5222=S(&)E='1E<BX*("`@("`@("`@("`@)&ED
M(#T@<W1R;F-M<"@D<&%R=%LG:60G72P@)V-I9#HG+"`T*0H@("`@("`@("`@
M("`@("`@/R`G8VED.B<@+B`D<&%R=%LG:60G70H@("`@("`@("`@("`@("`@
M.B`D<&%R=%LG:60G73L*("`@("`@("`@("`@)&%T=&%C:&UE;G1S6R1I9%T@
M/2`D<&%R=%LG9&%T82==.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO
M;B!?7W-E=%]T>7!E7W1R86YS;&%T:6]N*"1T>7!E+"`D8VQA<W,@/2!N=6QL
M*0H@("`@>PH@("`@("`@("1T<2`])B!N97<@44YA;64H)'1Y<&4I.PH@("`@
M("`@(&EF("@A)&-L87-S*2!["B`@("`@("`@("`@("1C;&%S<R`]("1T<2T^
M;F%M93L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]T>7!E7W1R86YS;&%T
M:6]N6R1T>7!E73TD8VQA<W,["B`@("!]"@I]"@HO*BH*("H@0VQA<W,@=7-E
M9"!T;R!H86YD;&4@44Y!344@=F%L=65S(&EN(%A-3"X*("H*("H@0&%C8V5S
M<R`@('!U8FQI8PH@*B!`<&%C:V%G92`@4T]!4`H@*B!`875T:&]R("`@4VAA
M;F4@0V%R879E;R`\<VAA;F5`<&AP+FYE=#X@0V]N=F5R<VEO;B!T;R!014%2
M(&%N9"!U<&1A=&5S"B`J+PIC;&%S<R!13F%M90I["B`@("!V87(@)&YA;64@
M/2`G)SL*("`@('9A<B`D;G,@/2`G)SL*("`@('9A<B`D;F%M97-P86-E/2<G
M.PH*("`@(&9U;F-T:6]N(%%.86UE*"1N86UE+"`D;F%M97-P86-E(#T@)R<I
M"B`@("!["B`@("`@("`@:68@*"1N86UE("8F("1N86UE6S!=(#T]("=[)RD@
M>PH@("`@("`@("`@("!P<F5G7VUA=&-H*"<O7'LH+BH_*5Q]*"XJ*2\G+"`D
M;F%M92P@)&TI.PH@("`@("`@("`@("`D=&AI<RT^;F%M92`]("1M6S)=.PH@
M("`@("`@("`@("`D=&AI<RT^;F%M97-P86-E(#T@)&U;,5T["B`@("`@("`@
M?2!E;'-E:68@*'-U8G-T<E]C;W5N="@D;F%M92P@)SHG*2`]/2`Q*2!["B`@
M("`@("`@("`@("1S(#T@97AP;&]D92@G.B<L("1N86UE*3L*("`@("`@("`@
M("`@)',@/2!A<G)A>5]R979E<G-E*"1S*3L*("`@("`@("`@("`@)'1H:7,M
M/FYA;64@/2`D<ULP73L*("`@("`@("`@("`@)'1H:7,M/FYS(#T@)'-;,5T[
M"B`@("`@("`@("`@("1T:&ES+3YN86UE<W!A8V4@/2`D;F%M97-P86-E.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YN86UE(#T@)&YA
M;64["B`@("`@("`@("`@("1T:&ES+3YN86UE<W!A8V4@/2`D;F%M97-P86-E
M.PH@("`@("`@('T*"B`@("`@("`@+R\@02!L:71T;&4@;6]R92!M86=I8R!T
M:&%N('-H;W5L9"!B92!I;B!A('%N86UE+@H@("`@("`@("1P(#T@<W1R<&]S
M*"1T:&ES+3YN86UE+"`G6R<I.PH@("`@("`@(&EF("@D<"D@>PH@("`@("`@
M("`@("`O+R!43T1/.B!.965D('1O(')E+65X86UI;F4@=&AI<R!L;V=I8R!L
M871E<BX*("`@("`@("`@("`@+R\@0VAO<"!O9F8@6UTN"B`@("`@("`@("`@
M("1T:&ES+3YA<G)A>5-I>F4@/2!E>'!L;V1E*"<L)RP@<W5B<W1R*"1T:&ES
M+3YN86UE+"`D<"`K(#$L("TD<"`M(#(I*3L*("`@("`@("`@("`@)'1H:7,M
M/F%R<F%Y26YF;R`]('-U8G-T<B@D=&AI<RT^;F%M92P@)'`I.PH@("`@("`@
M("`@("`D=&AI<RT^;F%M92`]('-U8G-T<B@D=&AI<RT^;F%M92P@,"P@)'`I
M.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!F<6XH*0H@("`@>PH@
M("`@("`@(&EF("@D=&AI<RT^;F%M97-P86-E*2!["B`@("`@("`@("`@(')E
M='5R;B`G>R<@+B`D=&AI<RT^;F%M97-P86-E("X@)WTG("X@)'1H:7,M/FYA
M;64["B`@("`@("`@?2!E;'-E:68@*"1T:&ES+3YN<RD@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/FYS("X@)SHG("X@)'1H:7,M/FYA;64["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^;F%M93L*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4T]!
M4"]$:7-C;RYP:'``````````````````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`S-C$T-"`Q,#4Q-30S,S<S,2`P,C$P,3``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H
M:7,@9FEL92!C;VYT86EN<R!T:&4@8V]D92!F;W(@=&AE($1)4T-/('-E<G9E
M<BP@<')O=FED:6YG($1)4T\@86YD(%=31$P*("H@<V5R=FEC97,N"B`J"B`J
M(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U
M<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(
M4"!L:6-E;G-E+`H@*B!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA
M9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES(&%V86EL86)L92!A=`H@
M*B!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\R7S`R+G1X="X@($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L
M92!T;R!O8G1A:6X@:70*("H@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L
M('!L96%S92!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@
M8V%N"B`J(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A
M=&5G;W)Y("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E("`@(%-/05`*("H@
M0&%U=&AO<B`@("`@1&UI=')I(%9I;F]G<F%D;W8@/&1I;6ET<FE`=FEN;V=R
M861O=BYD93X*("H@0&%U=&AO<B`@("`@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^"B`J($!A=71H;W(@("`@($IA;B!38VAN96ED97(@/&IA
M;D!H;W)D92YO<F<^"B`J($!C;W!Y<FEG:'0@(#(P,#,M,C`P-2!4:&4@4$A0
M($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S)?,#(N='AT("!02%`@3&EC96YS92`R+C`R"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]33T%0"B`J+PH*<F5Q=6ER
M95]O;F-E("=33T%0+T)A<V4N<&AP)SL*"F-L87-S(%-/05!?1$E30T]?4V5R
M=F5R(&5X=&5N9',@4T]!4%]"87-E7T]B:F5C="!["@H@("`@=F%R("1N86UE
M<W!A8V5S("`@("`](&%R<F%Y*%-#2$5-05]74T1,(#T^("=W<V1L)RP@4T-(
M14U!7U-/05`@/3X@)W-O87`G*3L*("`@('9A<B`D:6UP;W)T7VYS("`@("`@
M/2!A<G)A>2@I.PH@("`@=F%R("1W<V1L("`@("`@("`@("`]("<G.PH@("`@
M=F%R("1D:7-C;R`@("`@("`@("`]("<G.PH@("`@=F%R("1?=W-D;"`@("`@
M("`@("`](&%R<F%Y*"D["B`@("!V87(@)%]D:7-C;R`@("`@("`@(#T@87)R
M87DH*3L*("`@('9A<B`D7W-E<G9I8V5?;F%M92`@/2`G)SL*("`@('9A<B`D
M7W-E<G9I8V5?;G,@("`@/2`G)SL*("`@('9A<B`D7W-E<G9I8V5?9&5S8R`@
M/2`G)SL*("`@('9A<B`D7W!O<G1N86UE("`@("`@/2`G)SL*("`@('9A<B`D
M7V)I;F1I;F=N86UE("`@/2`G)SL*("`@('9A<B`D<V]A<%]S97)V97(@("`@
M/2!.54Q,.PH*"B`@("!F=6YC=&EO;B!33T%07T1)4T-/7U-E<G9E<B@D<V]A
M<%]S97)V97(L("1S97)V:6-E7VYA;64L("1S97)V:6-E7V1E<V,@/2`G)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I;7!O<G1?;G,@/2!N
M=6QL*0H@("`@>PH@("`@("`@('!A<F5N=#HZ4T]!4%]"87-E7T]B:F5C="@G
M4V5R=F5R)RD["@H@("`@("`@(&EF("@@(6ES7V]B:F5C="@D<V]A<%]S97)V
M97(I"B`@("`@("`@("`@('Q\("%G971?8VQA<W,H)'-O87!?<V5R=F5R*2`]
M/2`G<V]A<%]S97)V97(G*2!R971U<FX["@H@("`@("`@("1T:&ES+3Y?<V5R
M=FEC95]N86UE(#T@)'-E<G9I8V5?;F%M93L*("`@("`@("`D=&AI<RT^7W-E
M<G9I8V5?;G,@/2`B=7)N.B1S97)V:6-E7VYA;64B.PH@("`@("`@("1T:&ES
M+3Y?<V5R=FEC95]D97-C(#T@)'-E<G9I8V5?9&5S8SL*("`@("`@("`D=&AI
M<RT^:6UP;W)T7VYS(#T@:7-S970H)&EM<&]R=%]N<RD@/R`D:6UP;W)T7VYS
M(#H@)'1H:7,M/FEM<&]R=%]N<SL*("`@("`@("`D=&AI<RT^<V]A<%]S97)V
M97(@/2`D<V]A<%]S97)V97(["B`@("`@("`@)'1H:7,M/FAO<W0@/2!I<W-E
M="@D7U-%4E9%4ELG2%144%](3U-4)UTI(#\@)%]315)615);)TA45%!?2$]3
M5"==(#H@)VQO8V%L:&]S="<["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T1$E3
M0T\H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9V5N97)A=&5?1$E30T\H*3L*
M("`@("`@("!R971U<FX@)'1H:7,M/F1I<V-O.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&=E=%=31$PH*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9V5N97)A=&5?
M5U-$3"@I.PH@("`@("`@(')E='5R;B`D=&AI<RT^=W-D;#L*("`@('T*"B`@
M("!F=6YC=&EO;B!?9V5N97)A=&5?1$E30T\H*0H@("`@>PH@("`@("`@("\O
M($1)4T-/"B`@("`@("`@)'1H:7,M/E]D:7-C;ULG9&ES8V\Z9&ES8V]V97)Y
M)UU;)V%T='(G75LG>&UL;G,Z9&ES8V\G72`](%-#2$5-05]$25-#3SL*("`@
M("`@("`D=&AI<RT^7V1I<V-O6R=D:7-C;SID:7-C;W9E<GDG75LG871T<B==
M6R=X;6QN<SIS8VPG72`](%-#2$5-05]$25-#3U]30TP["B`@("`@("`@)'1H
M:7,M/E]D:7-C;ULG9&ES8V\Z9&ES8V]V97)Y)UU;)W-C;#IC;VYT<F%C=%)E
M9B==6R=A='1R)UU;)W)E9B==(#T*("`@("`@("`@("`@*&%R<F%Y7VME>5]E
M>&ES=',H)TA45%!3)RP@)%]315)615(I("8F("1?4T525D526R=(5%104R==
M(#T]("=O;B<I"B`@("`@("`@("`@(#\@)VAT='!S.B\O)R`N("1T:&ES+3YH
M;W-T("X@)%]315)615);)U!(4%]314Q&)UT@+B`G/W=S9&PG"B`@("`@("`@
M("`@(#H@)VAT='`Z+R\G("`N("1T:&ES+3YH;W-T("X@)%]315)615);)U!(
M4%]314Q&)UT@+B`G/W=S9&PG.PH*("`@("`@("`O+R!G96YE<F%T92!D:7-C
M;R!X;6P*("`@("`@("`D=&AI<RT^7V=E;F5R871E7T1)4T-/7UA-3"@D=&AI
M<RT^7V1I<V-O*3L*("`@('T*"B`@("!F=6YC=&EO;B!?9V5N97)A=&5?5U-$
M3"@I"B`@("!["B`@("`@("`@+R\@5U-$3`H@("`@("`@(&EF("AI<U]A<G)A
M>2@D=&AI<RT^<V]A<%]S97)V97(M/E]N86UE<W!A8V5S*2D@>PH@("`@("`@
M("`@("`O+R!N965D('1O(&=E=#H@='EP96YS+"!X<V0@)B!33T%0+45.0PH@
M("`@("`@("`@("`D9FQI<'!E9"`](&%R<F%Y7V9L:7`H)'1H:7,M/G-O87!?
M<V5R=F5R+3Y?;F%M97-P86-E<RD["B`@("`@("`@("`@("1T:&ES+3YN86UE
M<W!A8V5S6R1T:&ES+3Y?<V5R=FEC95]N<UT@/2`G=&YS)SL*("`@("`@("`@
M("`@)'1H:7,M/FYA;65S<&%C97-;)&9L:7!P961;)WAS9"==72`]("=X<V0G
M.PH@("`@("`@("`@("`D=&AI<RT^;F%M97-P86-E<ULD9FQI<'!E9%LG4T]!
M4"U%3D,G75T@/2`G4T]!4"U%3D,G.PH@("`@("`@('T*"B`@("`@("`@+R\@
M1$5&24Y)5$E/3E,*("`@("`@("`D=&AI<RT^7W=S9&Q;)V1E9FEN:71I;VYS
M)UU;)V%T='(G75LG;F%M92==(#T@)'1H:7,M/E]S97)V:6-E7VYA;64["B`@
M("`@("`@)'1H:7,M/E]W<V1L6R=D969I;FET:6]N<R==6R=A='1R)UU;)W1A
M<F=E=$YA;65S<&%C92==(#T@)'1H:7,M/E]S97)V:6-E7VYS.PH@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3YN86UE<W!A8V5S(&%S("1N<R`]/B`D<')E9FEX
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?=W-D;%LG9&5F:6YI=&EO;G,G75LG
M871T<B==6R=X;6QN<SHG("X@)'!R969I>%T@/2`D;G,["B`@("`@("`@?0H@
M("`@("`@("1T:&ES+3Y?=W-D;%LG9&5F:6YI=&EO;G,G75LG871T<B==6R=X
M;6QN<R==(#T@4T-(14U!7U=31$P["@H@("`@("`@("\O($EM<&]R="!N86UE
M<W!A8V5S+B!3965M<R!T;R!N;W0@=V]R:R!Y970Z('=S9&PN97AE(&9O;2`N
M3D54(&-A;B=T"B`@("`@("`@+R\@:&%N9&QE(&EM<&]R=&5D(&-O;7!L971E
M('=S9&PM9&5F:6YI=&EO;G,N"B`@("`@("`@:68@*&-O=6YT*"1T:&ES+3YI
M;7!O<G1?;G,I*2!["B`@("`@("`@("`@("1I(#T@,#L*("`@("`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/FEM<&]R=%]N<R!A<R`D7VYS(#T^("1?;&]C871I
M;VXI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?=W-D;%LG9&5F:6YI=&EO
M;G,G75LG:6UP;W)T)UU;)&E=6R=A='1R)UU;)VQO8V%T:6]N)UT@/2`D7VQO
M8V%T:6]N.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]W<V1L6R=D969I;FET
M:6]N<R==6R=I;7!O<G0G75LD:5U;)V%T='(G75LG;F%M97-P86-E)UT@/2`D
M7VYS.PH@("`@("`@("`@("`@("`@)&DK*SL*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@("`@("`D=&AI<RT^7W=S9&Q;)V1E9FEN:71I;VYS)UU;)W1Y
M<&5S)UU;)V%T='(G75LG>&UL;G,G73TG:'1T<#HO+W-C:&5M87,N>&UL<V]A
M<"YO<F<O=W-D;"\G.PH@("`@("`@("1T:&ES+3Y?=W-D;%LG9&5F:6YI=&EO
M;G,G75LG='EP97,G75LG<V-H96UA)UT]87)R87DH*3L*"B`@("`@("`@+R\@
M4&QA8V5H;VQD97(@9F]R(&UE<W-A9V5S"B`@("`@("`@)'1H:7,M/E]W<V1L
M6R=D969I;FET:6]N<R==6R=M97-S86=E)UT@/2!A<G)A>2@I.PH*("`@("`@
M("`O+R!03U)45%E012U.04U%"B`@("`@("`@)'1H:7,M/E]P;W)T;F%M92`]
M("1T:&ES+3Y?<V5R=FEC95]N86UE("X@)U!O<G0G.PH@("`@("`@("1T:&ES
M+3Y?=W-D;%LG9&5F:6YI=&EO;G,G75LG<&]R=%1Y<&4G75LG871T<B==6R=N
M86UE)UT@/2`D=&AI<RT^7W!O<G1N86UE.PH*("`@("`@("`O+R!"24Y$24Y'
M+4Y!344*("`@("`@("`D=&AI<RT^7V)I;F1I;F=N86UE(#T@)'1H:7,M/E]S
M97)V:6-E7VYA;64@+B`G0FEN9&EN9R<["B`@("`@("`@)'1H:7,M/E]W<V1L
M6R=D969I;FET:6]N<R==6R=B:6YD:6YG)UU;)V%T='(G75LG;F%M92==(#T@
M)'1H:7,M/E]B:6YD:6YG;F%M93L*("`@("`@("`D=&AI<RT^7W=S9&Q;)V1E
M9FEN:71I;VYS)UU;)V)I;F1I;F<G75LG871T<B==6R=T>7!E)UT@/2`G=&YS
M.B<@+B`D=&AI<RT^7W!O<G1N86UE.PH@("`@("`@("1T:&ES+3Y?=W-D;%LG
M9&5F:6YI=&EO;G,G75LG8FEN9&EN9R==6R=S;V%P.F)I;F1I;F<G75LG871T
M<B==6R=S='EL92==(#T@)W)P8R<["B`@("`@("`@)'1H:7,M/E]W<V1L6R=D
M969I;FET:6]N<R==6R=B:6YD:6YG)UU;)W-O87`Z8FEN9&EN9R==6R=A='1R
M)UU;)W1R86YS<&]R="==(#T@4T-(14U!7U-/05!?2%144#L*"B`@("`@("`@
M+R\@4T525DE#10H@("`@("`@("1T:&ES+3Y?=W-D;%LG9&5F:6YI=&EO;G,G
M75LG<V5R=FEC92==6R=A='1R)UU;)VYA;64G72`]("1T:&ES+3Y?<V5R=FEC
M95]N86UE("X@)U-E<G9I8V4G.PH@("`@("`@("1T:&ES+3Y?=W-D;%LG9&5F
M:6YI=&EO;G,G75LG<V5R=FEC92==6R=D;V-U;65N=&%T:6]N)UU;)V%T='(G
M72`]("<G.PH@("`@("`@("1T:&ES+3Y?=W-D;%LG9&5F:6YI=&EO;G,G75LG
M<V5R=FEC92==6R=D;V-U;65N=&%T:6]N)UT@/2!H=&UL96YT:71I97,H)'1H
M:7,M/E]S97)V:6-E7V1E<V,I.PH@("`@("`@("1T:&ES+3Y?=W-D;%LG9&5F
M:6YI=&EO;G,G75LG<V5R=FEC92==6R=P;W)T)UU;)V%T='(G75LG;F%M92==
M(#T@)'1H:7,M/E]P;W)T;F%M93L*("`@("`@("`D=&AI<RT^7W=S9&Q;)V1E
M9FEN:71I;VYS)UU;)W-E<G9I8V4G75LG<&]R="==6R=A='1R)UU;)V)I;F1I
M;F<G72`]("=T;G,Z)R`N("1T:&ES+3Y?8FEN9&EN9VYA;64["B`@("`@("`@
M)'1H:7,M/E]W<V1L6R=D969I;FET:6]N<R==6R=S97)V:6-E)UU;)W!O<G0G
M75LG<V]A<#IA9&1R97-S)UU;)V%T='(G75LG;&]C871I;VXG72`]"B`@("`@
M("`@("`@("AA<G)A>5]K97E?97AI<W1S*"=(5%104R<L("1?4T525D52*2`F
M)B`D7U-%4E9%4ELG2%144%,G72`]/2`G;VXG*0H@("`@("`@("`@("`_("=H
M='1P<SHO+R<@+B`D=&AI<RT^:&]S="`N("1?4T525D526R=02%!?4T5,1B==
M"B`@("`@("`@("`@(#H@)VAT='`Z+R\G("`N("1T:&ES+3YH;W-T("X@)%]3
M15)615);)U!(4%]314Q&)UT["@H@("`@("`@("\O"B`@("`@("`@)&1I<W!A
M=&-H7VME>7,@/2!A<G)A>5]K97ES*"1T:&ES+3YS;V%P7W-E<G9E<BT^9&ES
M<&%T8VA?;V)J96-T<RD["B`@("`@("`@)&1C(#T@8V]U;G0H)&1I<W!A=&-H
M7VME>7,I.PH@("`@("`@(&9O<B`H)&1I(#T@,#L@)&1I(#P@)&1C.R`D9&DK
M*RD@>PH@("`@("`@("`@("`D;F%M97-P86-E(#T@)&1I<W!A=&-H7VME>7-;
M)&1I73L*("`@("`@("`@("`@)&YA;65S<&%C95]O8FIE8W1S(#TF("1T:&ES
M+3YS;V%P7W-E<G9E<BT^9&ES<&%T8VA?;V)J96-T<ULD;F%M97-P86-E73L*
M("`@("`@("`@("`@)&]C(#T@8V]U;G0H)&YA;65S<&%C95]O8FIE8W1S*3L*
M("`@("`@("`@("`@9F]R("@D;VD@/2`P.R`D;VD@/"`D;V,[("1O:2LK*2![
M"B`@("`@("`@("`@("`@("`D;V)J96-T(#T@)&YA;65S<&%C95]O8FIE8W1S
M6R1O:5T["B`@("`@("`@("`@("`@("`O+R!T>7!E<R!D969I;FET:6]N<PH@
M("`@("`@("`@("`@("`@)'1H:7,M/F%D9%-C:&5M849R;VU-87`H)&]B:F5C
M="T^7U]T>7!E9&5F*3L*("`@("`@("`@("`@("`@("\O($U%4U-!1T53"B`@
M("`@("`@("`@("`@("`D=&AI<RT^861D365T:&]D<T9R;VU-87`H)&]B:F5C
M="T^7U]D:7-P871C:%]M87`L("1N86UE<W!A8V4L(&=E=%]C;&%S<R@D;V)J
M96-T*2D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*&ES
M<V5T*"1S97)V97(M/F1I<W!A=&-H7VUA<"DI('L*("`@("`@("`@("`@)'1H
M:7,M/F%D9$UE=&AO9'-&<F]M36%P*"1S97)V97(M/F1I<W!A=&-H7VUA<"P@
M)&YA;65S<&%C92D["B`@("`@("`@?0H*("`@("`@("`O+R!G96YE<F%T92!W
M<V1L"B`@("`@("`@)'1H:7,M/E]G96YE<F%T95]74T1,7UA-3"@I.PH@("`@
M?0H*("`@(&9U;F-T:6]N("9?9V5T4V-H96UA*"1N86UE<W!A8V4I"B`@("![
M"B`@("`@("`@+R\@4T-(14U!"B`@("`@("`@)&,@/2!C;W5N="@D=&AI<RT^
M7W=S9&Q;)V1E9FEN:71I;VYS)UU;)W1Y<&5S)UU;)W-C:&5M82==*3L*("`@
M("`@("!F;W(H)&D@/2`P.R`D:2`\("1C.R`D:2LK*2!["B`@("`@("`@("`@
M(&EF("@D=&AI<RT^7W=S9&Q;)V1E9FEN:71I;VYS)UU;)W1Y<&5S)UU;)W-C
M:&5M82==6R1I75LG871T<B==6R=T87)G971.86UE<W!A8V4G72`]/2`D;F%M
M97-P86-E*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]W<V1L
M6R=D969I;FET:6]N<R==6R=T>7!E<R==6R=S8VAE;6$G75LD:5T["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O(&1O;B=T(&AA=F4@=&AI
M<R!N86UE<W!A8V4*("`@("`@("`D<V-H96UA(#T@87)R87DH*3L*("`@("`@
M("`D<V-H96UA6R=A='1R)UT@/2!A<G)A>2@I.PH@("`@("`@("1S8VAE;6%;
M)V-O;7!L97A4>7!E)UT@/2!A<G)A>2@I.PH@("`@("`@("1S8VAE;6%;)V%T
M='(G75LG>&UL;G,G72`](&%R<F%Y7W-E87)C:"@G>'-D)RPD=&AI<RT^;F%M
M97-P86-E<RD["B`@("`@("`@)'-C:&5M85LG871T<B==6R=T87)G971.86UE
M<W!A8V4G72`]("1N86UE<W!A8V4["B`@("`@("`@)'1H:7,M/E]W<V1L6R=D
M969I;FET:6]N<R==6R=T>7!E<R==6R=S8VAE;6$G75M=(#TF("1S8VAE;6$[
M"@H@("`@("`@(')E='5R;B`D<V-H96UA.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&%D9%-C:&5M849R;VU-87`H)B1M87`I"B`@("!["B`@("`@("`@:68@*"$D
M;6%P*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@
M(&9O<F5A8V@@*"1M87`@87,@)%]T>7!E7VYA;64@/3X@)%]T>7!E7V1E9BD@
M>PH@("`@("`@("`@("!L:7-T*"1T>7!E;G,L)'1Y<&4I(#T@)'1H:7,M/E]G
M9714>7!E3G,H)%]T>7!E7VYA;64I.PH@("`@("`@("`@("!I9B`H)'1Y<&5N
M<R`]/2`G>'-D)RD@>PH@("`@("`@("`@("`@("`@+R\@8V%N;F]T(&%D9"!T
M;R!X<V0L(&QE=',@=7-E(&UE=&AO9%]N86UE<W!A8V4*("`@("`@("`@("`@
M("`@("1T>7!E;G,@/2`G=&YS)SL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D<V-H96UA(#TF("1T:&ES+3Y?9V5T4V-H96UA*&%R<F%Y7W-E87)C:"@D
M='EP96YS+"`D=&AI<RT^;F%M97-P86-E<RDI.PH@("`@("`@("`@("!I9B`H
M(21T:&ES+3Y?:69#;VUP;&5X5'EP945X:7-T<R@D<V-H96UA6R=C;VUP;&5X
M5'EP92==+"`D='EP92DI('L*("`@("`@("`@("`@("`@("1C='EP92`])B`D
M<V-H96UA6R=C;VUP;&5X5'EP92==6UT["B`@("`@("`@("`@("`@("`D8W1Y
M<&5;)V%T='(G75LG;F%M92==(#T@)'1Y<&4["B`@("`@("`@("`@("`@("!F
M;W)E86-H("@D7W1Y<&5?9&5F(&%S("1?=F%R;F%M92`]/B`D7W9A<G1Y<&4I
M('L*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES7VEN="@D7W9A<FYA;64I
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&QI<W0H)%]V87)T>7!E;G,L
M)%]V87)T>7!E*2`]("1T:&ES+3Y?9V5T5'EP94YS*"1?=F%R='EP92D["B`@
M("`@("`@("`@("`@("`@("`@("`@("1C='EP95LG86QL)UU;)V%T='(G72`]
M("<G.PH@("`@("`@("`@("`@("`@("`@("`@("`D96P@/28@)&-T>7!E6R=A
M;&PG75LG96QE;65N="==6UT["B`@("`@("`@("`@("`@("`@("`@("`@("1E
M;%LG871T<B==6R=N86UE)UT@/2`D7W9A<FYA;64["B`@("`@("`@("`@("`@
M("`@("`@("`@("1E;%LG871T<B==6R=T>7!E)UT@/2`D7W9A<G1Y<&5N<R`N
M("<Z)R`N("1?=F%R='EP93L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D8W1Y<&5;)V-O;7!L97A#;VYT
M96YT)UU;)V%T='(G72`]("<G.PH@("`@("`@("`@("`@("`@("`@("`@("`D
M8W1Y<&5;)V-O;7!L97A#;VYT96YT)UU;)W)E<W1R:6-T:6]N)UU;)V%T='(G
M75LG8F%S92==(#T@)U-/05`M14Y#.D%R<F%Y)SL*("`@("`@("`@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)%]V87)T>7!E(&%S("1A<G)A>5]V87(@/3X@
M)&%R<F%Y7W1Y<&4I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&QI
M<W0H)%]V87)T>7!E;G,L("1?=F%R='EP92D@/2`D=&AI<RT^7V=E=%1Y<&5.
M<R@D87)R87E?='EP92D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M8W1Y<&5;)V-O;7!L97A#;VYT96YT)UU;)W)E<W1R:6-T:6]N)UU;)V%T=')I
M8G5T92==6R=A='1R)UU;)W)E9B==(#T@)U-/05`M14Y#.F%R<F%Y5'EP92<[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8W1Y<&5;)V-O;7!L97A#
M;VYT96YT)UU;)W)E<W1R:6-T:6]N)UU;)V%T=')I8G5T92==6R=A='1R)UU;
M)W=S9&PZ87)R87E4>7!E)UT@/2`D7W9A<G1Y<&5N<R`N("<Z)R`N("1?=F%R
M='EP92`N("=;72<["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@861D365T:&]D<T9R
M;VU-87`H)B1M87`L("1N86UE<W!A8V4L("1C;&%S<VYA;64@/2!N=6QL*0H@
M("`@>PH@("`@("`@(&EF("@A)&UA<"D@>PH@("`@("`@("`@("!R971U<FX[
M"B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D;6%P(&%S("1M971H;V1?
M;F%M92`]/B`D;65T:&]D7W1Y<&5S*2!["B`@("`@("`@("`@(&EF("AA<G)A
M>5]K97E?97AI<W1S*"=N86UE<W!A8V4G+"`D;65T:&]D7W1Y<&5S*2D@>PH@
M("`@("`@("`@("`@("`@)&UE=&AO9%]N86UE<W!A8V4@/2`D;65T:&]D7W1Y
M<&5S6R=N86UE<W!A8V4G73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1M971H;V1?;F%M97-P86-E(#T@)&YA;65S<&%C93L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`O+R!)3E!55`H@("`@("`@("`@("!I
M9B`H:7-S970H)&UE=&AO9%]T>7!E<ULG:6XG72D@)B8@:7-?87)R87DH)&UE
M=&AO9%]T>7!E<ULG:6XG72DI('L*("`@("`@("`@("`@("`@("1I;G!U=%]M
M97-S86=E(#TF("1T:&ES+3Y?=W-D;%LG9&5F:6YI=&EO;G,G75LG;65S<V%G
M92==6UT["B`@("`@("`@("`@("`@("`D:6YP=71?;65S<V%G95LG871T<B==
M6R=N86UE)UT@/2`D;65T:&]D7VYA;64@+B`G4F5Q=65S="<["B`@("`@("`@
M("`@("`@("!F;W)E86-H("@D;65T:&]D7W1Y<&5S6R=I;B==(&%S("1N86UE
M(#T^("1T>7!E*2!["B`@("`@("`@("`@("`@("`@("`@;&ES="@D='EP96YS
M+"`D='EP92D@/2`D=&AI<RT^7V=E=%1Y<&5.<R@D='EP92D["B`@("`@("`@
M("`@("`@("`@("`@)'!A<G0@/28@)&EN<'5T7VUE<W-A9V5;)W!A<G0G75M=
M.PH@("`@("`@("`@("`@("`@("`@("1P87)T6R=A='1R)UU;)VYA;64G72`]
M("1N86UE.PH@("`@("`@("`@("`@("`@("`@("1P87)T6R=A='1R)UU;)W1Y
M<&4G72`]("1T>7!E;G,@+B`G.B<@+B`D='EP93L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@3U544%54"B`@("`@
M("`@("`@(&EF("AI<W-E="@D;65T:&]D7W1Y<&5S6R=O=70G72D@)B8@:7-?
M87)R87DH)&UE=&AO9%]T>7!E<ULG;W5T)UTI*2!["B`@("`@("`@("`@("`@
M("`D;W5T<'5T7VUE<W-A9V4@/28@)'1H:7,M/E]W<V1L6R=D969I;FET:6]N
M<R==6R=M97-S86=E)UU;73L*("`@("`@("`@("`@("`@("1O=71P=71?;65S
M<V%G95LG871T<B==6R=N86UE)UT@/2`D;65T:&]D7VYA;64@+B`G4F5S<&]N
M<V4G.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&UE=&AO9%]T>7!E<ULG
M;W5T)UT@87,@)&YA;64@/3X@)'1Y<&4I('L*("`@("`@("`@("`@("`@("`@
M("!L:7-T*"1T>7!E;G,L("1T>7!E*2`]("1T:&ES+3Y?9V5T5'EP94YS*"1T
M>7!E*3L*("`@("`@("`@("`@("`@("`@("`D<&%R="`])B`D;W5T<'5T7VUE
M<W-A9V5;)W!A<G0G75M=.PH@("`@("`@("`@("`@("`@("`@("1P87)T6R=A
M='1R)UU;)VYA;64G72`]("1N86UE.PH@("`@("`@("`@("`@("`@("`@("1P
M87)T6R=A='1R)UU;)W1Y<&4G72`]("1T>7!E;G,@+B`G.B<@+B`D='EP93L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M+R\@4$]25%194$53"B`@("`@("`@("`@("1O<&5R871I;VX@/28@)'1H:7,M
M/E]W<V1L6R=D969I;FET:6]N<R==6R=P;W)T5'EP92==6R=O<&5R871I;VXG
M75M=.PH@("`@("`@("`@("`D;W!E<F%T:6]N6R=A='1R)UU;)VYA;64G72`]
M("1M971H;V1?;F%M93L*"B`@("`@("`@("`@("\O($E.4%54"B`@("`@("`@
M("`@("1O<&5R871I;VY;)VEN<'5T)UU;)V%T='(G75LG;65S<V%G92==(#T@
M)W1N<SHG"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("1I;G!U=%]M
M97-S86=E6R=A='1R)UU;)VYA;64G73L*"B`@("`@("`@("`@("\O($]55%!5
M5`H@("`@("`@("`@("`D;W!E<F%T:6]N6R=O=71P=70G75LG871T<B==6R=M
M97-S86=E)UT@/2`G=&YS.B<*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("X@)&]U='!U=%]M97-S86=E6R=A='1R)UU;)VYA;64G73L*"B`@("`@("`@
M("`@("\O($))3D1)3D<*("`@("`@("`@("`@)&)I;F1I;F<@/28@)'1H:7,M
M/E]W<V1L6R=D969I;FET:6]N<R==6R=B:6YD:6YG)UU;)V]P97)A=&EO;B==
M6UT["B`@("`@("`@("`@("1B:6YD:6YG6R=A='1R)UU;)VYA;64G72`]("1M
M971H;V1?;F%M93L*("`@("`@("`@("`@)&%C=&EO;B`]("1M971H;V1?;F%M
M97-P86-E("X@)R,G("X@*"1C;&%S<VYA;64@/R`D8VQA<W-N86UE("X@)R,G
M(#H@)R<I("X@)&UE=&AO9%]N86UE.PH@("`@("`@("`@("`D8FEN9&EN9ULG
M<V]A<#IO<&5R871I;VXG75LG871T<B==6R=S;V%P06-T:6]N)UT@/2`D86-T
M:6]N.PH*("`@("`@("`@("`@+R\@24Y0550*("`@("`@("`@("`@)&)I;F1I
M;F=;)VEN<'5T)UU;)V%T='(G72`]("<G.PH@("`@("`@("`@("`D8FEN9&EN
M9ULG:6YP=70G75LG<V]A<#IB;V1Y)UU;)V%T='(G75LG=7-E)UT@/2`G96YC
M;V1E9"<["B`@("`@("`@("`@("1B:6YD:6YG6R=I;G!U="==6R=S;V%P.F)O
M9'DG75LG871T<B==6R=N86UE<W!A8V4G72`]("1M971H;V1?;F%M97-P86-E
M.PH@("`@("`@("`@("`D8FEN9&EN9ULG:6YP=70G75LG<V]A<#IB;V1Y)UU;
M)V%T='(G75LG96YC;V1I;F=3='EL92==(#T@4T]!4%]30TA%34%?14Y#3T1)
M3D<["@H@("`@("`@("`@("`O+R!/5510550*("`@("`@("`@("`@)&)I;F1I
M;F=;)V]U='!U="==6R=A='1R)UT@/2`G)SL*("`@("`@("`@("`@)&)I;F1I
M;F=;)V]U='!U="==6R=S;V%P.F)O9'DG75LG871T<B==6R=U<V4G72`]("=E
M;F-O9&5D)SL*("`@("`@("`@("`@)&)I;F1I;F=;)V]U='!U="==6R=S;V%P
M.F)O9'DG75LG871T<B==6R=N86UE<W!A8V4G72`]("1M971H;V1?;F%M97-P
M86-E.PH@("`@("`@("`@("`D8FEN9&EN9ULG;W5T<'5T)UU;)W-O87`Z8F]D
M>2==6R=A='1R)UU;)V5N8V]D:6YG4W1Y;&4G72`](%-/05!?4T-(14U!7T5.
M0T]$24Y'.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?9V5N97)A
M=&5?1$E30T]?6$U,*"1D:7-C;U]A<G)A>2D*("`@('L*("`@("`@("`D9&ES
M8V\@/2`G/#]X;6P@=F5R<VEO;CTB,2XP(C\^)SL*("`@("`@("!F;W)E86-H
M("@D9&ES8V]?87)R87D@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@
M("1D:7-C;R`N/2`D=&AI<RT^7V%R<F%Y5&].;V1E*"1K97DL)'9A;"D["B`@
M("`@("`@?0H@("`@("`@("1T:&ES+3YD:7-C;R`]("1D:7-C;SL*("`@('T*
M"B`@("!F=6YC=&EO;B!?9V5N97)A=&5?5U-$3%]834PH*0H@("`@>PH@("`@
M("`@("1W<V1L(#T@)SP_>&UL('9E<G-I;VX](C$N,"(_/B<["B`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/E]W<V1L(&%S("1K97D@/3X@)'9A;"D@>PH@("`@
M("`@("`@("`D=W-D;"`N/2`D=&AI<RT^7V%R<F%Y5&].;V1E*"1K97DL("1V
M86PI.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^=W-D;"`]("1W<V1L.PH@
M("`@?0H*("`@(&9U;F-T:6]N(%]A<G)A>51O3F]D92@D;F]D95]N86UE(#T@
M)R<L("1A<G)A>2D*("`@('L*("`@("`@("`D<F5T=7)N(#T@)R<["B`@("`@
M("`@:68@*&ES7V%R<F%Y*"1A<G)A>2DI('L*("`@("`@("`@("`@+R\@=V4@
M:&%V92!A(&YO9&4@:68@=&AE<F4G<R!K97D@)V%T='(G"B`@("`@("`@("`@
M(&EF("AA<G)A>5]K97E?97AI<W1S*"=A='1R)RPD87)R87DI*2!["B`@("`@
M("`@("`@("`@("`D<F5T=7)N("X]("(\)&YO9&5?;F%M92(["B`@("`@("`@
M("`@("`@("!I9B`H:7-?87)R87DH)&%R<F%Y6R=A='1R)UTI*2!["B`@("`@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)&%R<F%Y6R=A='1R)UT@87,@)&%T
M=')?;F%M92`]/B`D871T<E]V86QU92D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D<F5T=7)N("X]("(@)&%T=')?;F%M93U<(B1A='1R7W9A;'5E7"(B
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("`@("`O+R!U;G-E="`G871T<B<@86YD('!R;V-E960@;W1H
M97(@8VAI;&1S+BXN"B`@("`@("`@("`@("`@("!U;G-E="@D87)R87E;)V%T
M='(G72D["@H@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1A<G)A>2D@/B`P
M*2!["B`@("`@("`@("`@("`@("`@("`@)&D@/2`P.PH@("`@("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1A<G)A>2!A<R`D8VAI;&1?;F]D95]N86UE(#T^
M("1C:&EL9%]N;V1E7W9A;'5E*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1R971U<FX@+CT@)&D@/3T@,"`_("(^7&XB(#H@)R<["B`@("`@("`@("`@
M("`@("`@("`@("`@("1R971U<FX@+CT@)'1H:7,M/E]A<G)A>51O3F]D92@D
M8VAI;&1?;F]D95]N86UE+"1C:&EL9%]N;V1E7W9A;'5E*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&DK*SL*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@)')E='5R;B`N/2`B/"\D;F]D95]N86UE/EQN
M(CL*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@)')E='5R;B`N/2`B("\^7&XB.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+R\@=V4@:&%V92!N
M;R`G871T<B<@:V5Y(&EN(&%R<F%Y("T@<V\@:70G<R!L:7-T(&]F(&YO9&5S
M('=I=&@*("`@("`@("`@("`@("`@("\O('1H92!S86UE(&YA;64@+BXN"B`@
M("`@("`@("`@("`@("!F;W)E86-H("@D87)R87D@87,@)&-H:6QD7VYO9&5?
M;F%M92`]/B`D8VAI;&1?;F]D95]V86QU92D@>PH@("`@("`@("`@("`@("`@
M("`@("1R971U<FX@+CT@)'1H:7,M/E]A<G)A>51O3F]D92@D;F]D95]N86UE
M+"1C:&EL9%]N;V1E7W9A;'5E*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O("1A<G)A
M>2!I<R!N;W0@86X@87)R87D*("`@("`@("`@("`@:68@*"1A<G)A>2`A/2<G
M*2!["B`@("`@("`@("`@("`@("`O+R!A;F0@:71S(&YO="!E;7!T>0H@("`@
M("`@("`@("`@("`@)')E='5R;B`N/2`B/"1N;V1E7VYA;64^)&%R<F%Y/"\D
M;F]D95]N86UE/EQN(CL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("\O(&%N9"!I=',@96UP='DN+BX*("`@("`@("`@("`@("`@("1R
M971U<FX@+CT@(CPD;F]D95]N86UE("\^7&XB.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D<F5T=7)N.PH@("`@?0H*("`@(&9U
M;F-T:6]N(%]G9714>7!E3G,H)'1Y<&4I"B`@("!["B`@("`@("`@<')E9U]M
M871C:%]A;&PH(B=<>R@N*BE<?2=S;2(L("1T>7!E+"`D;2D["B`@("`@("`@
M:68@*&ES<V5T*"1M6S%=6S!=*2`F)B`D;5LQ75LP72`A/2`G)RD@>PH@("`@
M("`@("`@("!I9B`H(6%R<F%Y7VME>5]E>&ES=',H)&U;,5U;,%TL)'1H:7,M
M/FYA;65S<&%C97,I*2!["B`@("`@("`@("`@("`@("`D;G-?<')E9B`]("=N
M<R<@+B!C;W5N="@D=&AI<RT^;F%M97-P86-E<RD["B`@("`@("`@("`@("`@
M("`D=&AI<RT^;F%M97-P86-E<ULD;5LQ75LP75T@/2`D;G-?<')E9CL*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?=W-D;%LG9&5F:6YI=&EO;G,G75LG871T
M<B==6R=X;6QN<SHG("X@)&YS7W!R969=(#T@)&U;,5U;,%T["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)'1Y<&5N<R`]("1T:&ES+3YN86UE<W!A8V5S
M6R1M6S%=6S!=73L*("`@("`@("`@("`@)'1Y<&4@/2!E<F5G7W)E<&QA8V4H
M)&U;,%U;,%TL)R<L)'1Y<&4I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1T>7!E;G,@/2`G>'-D)SL*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M(&%R<F%Y*"1T>7!E;G,L)'1Y<&4I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]I
M9D-O;7!L97A4>7!E17AI<W1S*"1T>7!E<T%R<F%Y+"`D='EP95]N86UE*0H@
M("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D='EP97-!<G)A>2DI('L*("`@
M("`@("`@("`@9F]R96%C:"`H)'1Y<&5S07)R87D@87,@)&EN9&5X(#T^("1T
M>7!E7V1A=&$I('L*("`@("`@("`@("`@("`@(&EF("@D='EP97-!<G)A>5LD
M:6YD97A=6R=A='1R)UU;)VYA;64G72`]/2`D='EP95]N86UE*2!["B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@?0I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+U-/05`O1F%U;'0N<&AP````````````````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,3`P-3(@,3`U,34T,S,W,S$@,#(Q,#$P`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B!4:&ES(&9I;&4@8V]N=&%I;G,@=&AE(%-/05!?1F%U;'0@8VQA<W,L('5S
M960@9F]R(&%L;"!E<G)O<B!O8FIE8W1S(&EN('1H:7,*("H@<&%C:V%G92X*
M("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T
M:&4@4$A0(&QI8V5N<V4L"B`J('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@
M<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@879A:6QA8FQE
M(&%T"B`J('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@
M=6YA8FQE('1O(&]B=&%I;B!I=`H@*B!T:')O=6=H('1H92!W;W)L9"UW:61E
M+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S
M;R!W92!C86X*("H@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@
M*B!`8V%T96=O<GD@("!796(@4V5R=FEC97,*("H@0'!A8VMA9V4@("`@4T]!
M4`H@*B!`875T:&]R("`@("!$:65T<FEC:"!!>6%L82`\9&EE=')I8VA`9V%N
M>#0N8V]M/B!/<FEG:6YA;"!!=71H;W(*("H@0&%U=&AO<B`@("`@4VAA;F4@
M0V%R879E;R`\4VAA;F5`0V%R879E;RYC;VT^("`@4&]R="!T;R!014%2(&%N
M9"!M;W)E"B`J($!A=71H;W(@("`@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/B`@($UA:6YT96YA;F-E"B`J($!A=71H;W(@("`@($IA;B!3
M8VAN96ED97(@/&IA;D!H;W)D92YO<F<^("`@("`@($UA:6YT96YA;F-E"B`J
M($!C;W!Y<FEG:'0@(#(P,#,M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E
M;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT("!0
M2%`@3&EC96YS92`R+C`R"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H
M<"YN970O<&%C:V%G92]33T%0"B`J+PH*<F5Q=6ER95]O;F-E*"=014%2+G!H
M<"<I.PH*+RHJ"B`J(%-/05!?1F%U;'0*("H@4$5!4CHZ17)R;W(@=W)A<'!E
M<B!U<V5D('1O(&UA=&-H(%-/05`@1F%U;'1S('1O(%!%05(@17)R;W)S"B`J
M"B`J($!P86-K86=E("!33T%0"B`J($!A8V-E<W,@("!P=6)L:6,*("H@0&%U
M=&AO<B`@(%-H86YE($-A<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/B`@(%!O
M<G0@=&\@4$5!4B!A;F0@;6]R90H@*B!`875T:&]R("`@1&EE=')I8V@@07EA
M;&$@/&1I971R:6-H0&=A;G@T+F-O;3X@3W)I9VEN86P@075T:&]R"B`J+PIC
M;&%S<R!33T%07T9A=6QT(&5X=&5N9',@4$5!4E]%<G)O<@I["B`@("`*("`@
M("\J*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J(`H@("`@("H@0'!A<F%M
M("`@('-T<FEN9R`@;65S<V%G92!S=')I;F<@9F]R(&9A=6QT"B`@("`@*B!`
M<&%R86T@("`@;6EX960@("!T:&4@9F%U;'1C;V1E"B`@("`@*B!`<&%R86T@
M("`@;6EX960@("!S964@4$5!4CHZ15)23U(@"B`@("`@*B!`<&%R86T@("`@
M;6EX960@("!S964@4$5!4CHZ15)23U(@"B`@("`@*B!`<&%R86T@("`@87)R
M87D@("!T:&4@=7-E<FEN9F\@87)R87D@:7,@=7-E9"!T;R!P87-S(&EN('1H
M90H@("`@("H@("`@("`@("`@("`@("`@("`@4T]!4"!A8W1O<B!A;F0@9&5T
M86EL(&9O<B!T:&4@9F%U;'0*("`@("`J+PH@("`@9G5N8W1I;VX@4T]!4%]&
M875L="@D9F%U;'1S=')I;F<@/2`G=6YK;F]W;B!E<G)O<B<L("1F875L=&-O
M9&4@/2`G0VQI96YT)RP@)&9A=6QT86-T;W(]3E5,3"P@)&1E=&%I;#U.54Q,
M+"`D;6]D92`](&YU;&PL("1O<'1I;VYS(#T@;G5L;"D*("`@('L*("`@("`@
M("!P87)E;G0Z.E!%05)?17)R;W(H)&9A=6QT<W1R:6YG+"`D9F%U;'1C;V1E
M+"`D;6]D92P@)&]P=&EO;G,L("1D971A:6PI.PH@("`@("`@(&EF("@D9F%U
M;'1A8W1O<BD@)'1H:7,M/F5R<F]R7VUE<W-A9V5?<')E9FEX(#T@)&9A=6QT
M86-T;W(["B`@("!]"B`@("`*("`@("\J*@H@("`@("H@;65S<V%G90H@("`@
M("H*("`@("`J(')E='5R;G,@82!33T%07TUE<W-A9V4@8VQA<W,@=&AA="!C
M86X@8F4@<V5N="!A<R!A('-E<G9E<B!R97-P;VYS90H@("`@("H*("`@("`J
M($!R971U<FX@4T]!4%]-97-S86=E(`H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@;65S<V%G92@I"B`@("!["B`@("`@("`@
M)&US9R`])B!N97<@4T]!4%]"87-E*"D["B`@("`@("`@)'!A<F%M<R`](&%R
M<F%Y*"D["B`@("`@("`@)'!A<F%M<UM=(#TF(&YE=R!33T%07U9A;'5E*"=F
M875L=&-O9&4G+"`G44YA;64G+"`G4T]!4"U%3E8Z)RXD=&AI<RT^8V]D92D[
M"B`@("`@("`@)'!A<F%M<UM=(#TF(&YE=R!33T%07U9A;'5E*"=F875L='-T
M<FEN9R<L("=S=')I;F<G+"`D=&AI<RT^;65S<V%G92D["B`@("`@("`@)'!A
M<F%M<UM=(#TF(&YE=R!33T%07U9A;'5E*"=F875L=&%C=&]R)RP@)V%N>552
M22<L("1T:&ES+3YE<G)O<E]M97-S86=E7W!R969I>"D["B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3YB86-K=')A8V4I*2!["B`@("`@("`@("`@("1P87)A
M;7-;72`])B!N97<@4T]!4%]686QU92@G9&5T86EL)RP@)W-T<FEN9R<L("1T
M:&ES+3YB86-K=')A8V4I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1P87)A;7-;72`])B!N97<@4T]!4%]686QU92@G9&5T86EL)RP@)W-T<FEN
M9R<L("1T:&ES+3YU<V5R:6YF;RD["B`@("`@("`@?0H@("`@("`@(`H@("`@
M("`@("1M971H;V1686QU92`])B!N97<@4T]!4%]686QU92@G>R<N4T]!4%]%
M3E9%3$]0+B=]1F%U;'0G+"`G4W1R=6-T)RP@)'!A<F%M<RD["B`@("`@("`@
M)&AE861E<G,@/2!.54Q,.PH@("`@("`@(')E='5R;B`D;7-G+3Y?;6%K945N
M=F5L;W!E*"1M971H;V1686QU92P@)&AE861E<G,I.PH@("`@?0H@("`@"B`@
M("`O*BH*("`@("`J(&=E=$9A=6QT"B`@("`@*@H@("`@("H@<F5T=7)N<R!A
M('-I;7!L92!N871I=F4@<&AP(&%R<F%Y(&-O;G1A:6YI;F<@=&AE(&9A=6QT
M(&1A=&$*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y(`H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1F%U;'0H*0H@
M("`@>PH@("`@("`@(&=L;V)A;"`D4T]!4%]/0DI%0U1?4U1254-4.PH@("`@
M("`@(&EF("@D4T]!4%]/0DI%0U1?4U1254-4*2!["B`@("`@("`@("`@("1F
M875L="`])B!N97<@<W1D0VQA<W,H*3L*("`@("`@("`@("`@)&9A=6QT+3YF
M875L=&-O9&4@/2`D=&AI<RT^8V]D93L*("`@("`@("`@("`@)&9A=6QT+3YF
M875L='-T<FEN9R`]("1T:&ES+3YM97-S86=E.PH@("`@("`@("`@("`D9F%U
M;'0M/F9A=6QT86-T;W(@/2`D=&AI<RT^97)R;W)?;65S<V%G95]P<F5F:7@[
M"B`@("`@("`@("`@("1F875L="T^9&5T86EL(#T@)'1H:7,M/G5S97)I;F9O
M.PH@("`@("`@("`@("!R971U<FX@)&9A=6QT.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@87)R87DH"B`@("`@("`@("`@("`@("`G9F%U;'1C;V1E)R`]
M/B`D=&AI<RT^8V]D92P*("`@("`@("`@("`@("`@("=F875L='-T<FEN9R<@
M/3X@)'1H:7,M/FUE<W-A9V4L"B`@("`@("`@("`@("`@("`G9F%U;'1A8W1O
M<B<@/3X@)'1H:7,M/F5R<F]R7VUE<W-A9V5?<')E9FEX+`H@("`@("`@("`@
M("`@("`@)V1E=&%I;"<@/3X@)'1H:7,M/G5S97)I;F9O"B`@("`@("`@("`@
M("D["B`@("!]"B`@("`*("`@("\J*@H@("`@("H@9V5T06-T;W(*("`@("`J
M"B`@("`@*B!R971U<FYS('1H92!33T%0(&%C=&]R(&9O<B!T:&4@9F%U;'0*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%C=&]R*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/F5R<F]R7VUE<W-A9V5?<')E9FEX.PH@
M("`@?0H@("`@"B`@("`O*BH*("`@("`J(&=E=$1E=&%I;`H@("`@("H*("`@
M("`J(')E='5R;G,@=&AE(&9A=6QT(&1E=&%I;`H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG(`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T1&5T86EL*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/G5S97)I;F9O.PH@("`@?0H@("`@"GT*/SX`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4T]!4"]087)S
M97(N<&AP````````````````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`T-C`U,"`Q,#4Q-30S,S<S,2`P,C$R,#``(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J(%1H:7,@9FEL
M92!C;VYT86EN<R!T:&4@8V]D92!F;W(@=&AE(%-/05`@;65S<V%G92!P87)S
M97(N"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z
M(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@
M;V8@=&AE(%!(4"!L:6-E;G-E+`H@*B!T:&%T(&ES(&)U;F1L960@=VET:"!T
M:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES(&%V86EL
M86)L92!A=`H@*B!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!H='1P
M.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@
M87)E('5N86)L92!T;R!O8G1A:6X@:70*("H@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN
M970@<V\@=V4@8V%N"B`J(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*
M("H*("H@0&-A=&5G;W)Y("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E("`@
M(%-/05`*("H@0&%U=&AO<B`@("`@1&EE=')I8V@@07EA;&$@/&1I971R:6-H
M0&=A;G@T+F-O;3X@3W)I9VEN86P@075T:&]R"B`J($!A=71H;W(@("`@(%-H
M86YE($-A<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/B`@(%!O<G0@=&\@4$5!
M4B!A;F0@;6]R90H@*B!`875T:&]R("`@("!#:'5C:R!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX@("!-86EN=&5N86YC90H@*B!`875T:&]R("`@("!*
M86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/B`@("`@("!-86EN=&5N86YC
M90H@*B!`8V]P>7)I9VAT("`R,#`S+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`
M;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X
M="`@4$A0($QI8V5N<V4@,BXP,@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A
M<BYP:'`N;F5T+W!A8VMA9V4O4T]!4`H@*B\*"G)E<75I<F5?;VYC92`G4T]!
M4"]"87-E+G!H<"<["G)E<75I<F5?;VYC92`G4T]!4"]686QU92YP:'`G.PH*
M+RHJ"B`J(%-/05`@4&%R<V5R"B`J"B`J(%1H:7,@8VQA<W,@:7,@=7-E9"!B
M>2!33T%0.CI-97-S86=E(&%N9"!33T%0.CI397)V97(@=&\@<&%R<V4@<V]A
M<`H@*B!P86-K971S+B!/<FEG:6YA;&QY(&)A<V5D(&]N(%-/05!X-"!B>2!$
M:65T<FEC:"!!>6%L80H@*B!H='1P.B\O9&EE=')I8V@N9V%N>#0N8V]M+W-O
M87!X-`H@*@H@*B!`86-C97-S('!U8FQI8PH@*B!`<&%C:V%G92!33T%0"B`J
M($!A=71H;W(@4VAA;F4@0V%R879E;R`\<VAA;F5`<&AP+FYE=#X@0V]N=F5R
M<VEO;B!T;R!014%2(&%N9"!U<&1A=&5S"B`J($!A=71H;W(@1&EE=')I8V@@
M07EA;&$@/&1I971R:6-H0&=A;G@T+F-O;3X@3W)I9VEN86P@075T:&]R"B`J
M+PIC;&%S<R!33T%07U!A<G-E<B!E>'1E;F1S(%-/05!?0F%S90I["B`@("!V
M87(@)'-T871U<R`]("<G.PH@("`@=F%R("1P;W-I=&EO;B`](#`["B`@("!V
M87(@)'!O<U]S=&%T(#T@,#L*("`@('9A<B`D9&5P=&@@/2`P.PH@("`@=F%R
M("1D969A=6QT7VYA;65S<&%C92`]("<G.PH@("`@=F%R("1M97-S86=E(#T@
M87)R87DH*3L*("`@('9A<B`D9&5P=&A?87)R87D@/2!A<G)A>2@I.PH@("`@
M=F%R("1P<F5V:6]U<U]E;&5M96YT(#T@)R<["B`@("!V87(@)'-O87!R97-P
M;VYS92`](&YU;&P["B`@("!V87(@)'-O87!H96%D97)S(#T@;G5L;#L*("`@
M('9A<B`D<&%R96YT(#T@,#L*("`@('9A<B`D<F]O=%]S=')U8W1?;F%M92`]
M(&%R<F%Y*"D["B`@("!V87(@)&AE861E<E]S=')U8W1?;F%M92`](&%R<F%Y
M*"D["B`@("!V87(@)&-U<F5N=%]R;V]T7W-T<G5C=%]N86UE(#T@)R<["B`@
M("!V87(@)&5N=&ET:65S(#T@87)R87D@*"`G)B<@/3X@)R9A;7`[)RP@)SPG
M(#T^("<F;'0[)RP@)SXG(#T^("<F9W0[)RP@(B<B(#T^("<F87!O<SLG+"`G
M(B<@/3X@)R9Q=6]T.R<@*3L*("`@('9A<B`D<F]O=%]S=')U8W0@/2!A<G)A
M>2@I.PH@("`@=F%R("1H96%D97)?<W1R=6-T(#T@87)R87DH*3L*("`@('9A
M<B`D8W5R96YT7W)O;W1?<W1R=6-T(#T@,#L*("`@('9A<B`D<F5F97)E;F-E
M<R`](&%R<F%Y*"D["B`@("!V87(@)&YE961?<F5F97)E;F-E<R`](&%R<F%Y
M*"D["B`@("!V87(@)%A-3%-C:&5M859E<G-I;VX["B`@("!V87(@)&)O9'E$
M97!T:#L@+R\@=7-E9"!T;R!H86YD;&4@;F]N+7)O;W0@96QE;65N=',@8F5F
M;W)E(')O;W0@8F]D>2!E;&5M96YT"@H@("`@+RHJ"B`@("`@*B!33T%07U!A
M<G-E<B!C;VYS=')U8W1O<@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M>&UL(&-O;G1E;G0*("`@("`J($!P87)A;2!S=')I;F<@>&UL(&-H87)A8W1E
M<B!E;F-O9&EN9RP@9&5F875L=',@=&\@)U541BTX)PH@("`@("HO"B`@("!F
M=6YC=&EO;B!33T%07U!A<G-E<B@F)'AM;"P@)&5N8V]D:6YG(#T@4T]!4%]$
M149!54Q47T5.0T]$24Y'+"`D871T86-H;65N=',@/2!N=6QL*0H@("`@>PH@
M("`@("`@('!A<F5N=#HZ4T]!4%]"87-E*"=087)S97(G*3L*("`@("`@("`D
M=&AI<RT^7W-E=%-C:&5M859E<G-I;VXH4T]!4%]834Q?4T-(14U!7U9%4E-)
M3TXI.PH*("`@("`@("`D=&AI<RT^871T86-H;65N=',@/2`D871T86-H;65N
M=',["@H@("`@("`@("\O($-H96-K('1H92!X;6P@=&%G(&9O<B!E;F-O9&EN
M9RX*("`@("`@("!I9B`H<')E9U]M871C:"@G+SQ</WAM;%M>/ETK96YC;V1I
M;F=<<RH_/5QS*C\H7"<H6UY<)UTJ*5PG?"(H6UXB72HI(BE;7CY=*C];7#]=
M/B\G+"`D>&UL+"`D;2DI('L*("`@("`@("`@("`@)&5N8V]D:6YG(#T@<W1R
M=&]U<'!E<B@D;5LR72`_("1M6S)=(#H@)&U;,UTI.PH@("`@("`@('T*"B`@
M("`@("`@+R\@1&5T97)M:6YE<R!W:&5R92!I;B!T:&4@;65S<V%G92!W92!A
M<F4*("`@("`@("`O+R`H96YV96QO<&4L:&5A9&5R+&)O9'DL;65T:&]D*2X@
M0VAE8VL@=VAE=&AE<B!C;VYT96YT(&AA<PH@("`@("`@("\O(&)E96X@<F5A
M9"X*("`@("`@("!I9B`H(65M<'1Y*"1X;6PI*2!["B`@("`@("`@("`@("\O
M(%!R97!A<F4@=&AE('AM;"!P87)S97(N"B`@("`@("`@("`@("1P87)S97(@
M/2!X;6Q?<&%R<V5R7V-R96%T92@D96YC;V1I;F<I.PH@("`@("`@("`@("!X
M;6Q?<&%R<V5R7W-E=%]O<'1I;VXH)'!A<G-E<BP@6$U,7T]05$E/3E]#05-%
M7T9/3$1)3D<L(#`I.PH@("`@("`@("`@("!X;6Q?<V5T7V]B:F5C="@D<&%R
M<V5R+"`D=&AI<RD["B`@("`@("`@("`@('AM;%]S971?96QE;65N=%]H86YD
M;&5R*"1P87)S97(L("=S=&%R=$5L96UE;G0G+"`G96YD16QE;65N="<I.PH@
M("`@("`@("`@("!X;6Q?<V5T7V-H87)A8W1E<E]D871A7VAA;F1L97(H)'!A
M<G-E<BP@)V-H87)A8W1E<D1A=&$G*3L*"B`@("`@("`@("`@("\O(%-O;64@
M;&%M92!S;V%P(&EM<&QE;65N=&%T:6]N<R!A9&0@;G5L;"!B>71E<R!A="!T
M:&4*("`@("`@("`@("`@+R\@96YD(&]F('1H92!S;V%P('-T<F5A;2P@86YD
M(&5X<&%T(&-H;V%K<R!O;B!T:&%T+@H@("`@("`@("`@("!I9B`H)'AM;%MS
M=')L96XH)'AM;"D@+2`Q72`]/2`P*2!["B`@("`@("`@("`@("`@("`D>&UL
M(#T@=')I;2@D>&UL*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@
M4&%R<V4@=&AE(%A-3"!F:6QE+@H@("`@("`@("`@("!I9B`H(7AM;%]P87)S
M92@D<&%R<V5R+"`D>&UL+"!T<G5E*2D@>PH@("`@("`@("`@("`@("`@)&5R
M<B`]('-P<FEN=&8H)UA-3"!E<G)O<B!O;B!L:6YE("5D(&-O;"`E9"!B>71E
M("5D("5S)RP*("`@("`@("`@("`@("`@("`@("!X;6Q?9V5T7V-U<G)E;G1?
M;&EN95]N=6UB97(H)'!A<G-E<BDL"B`@("`@("`@("`@("`@("`@("`@>&UL
M7V=E=%]C=7)R96YT7V-O;'5M;E]N=6UB97(H)'!A<G-E<BDL"B`@("`@("`@
M("`@("`@("`@("`@>&UL7V=E=%]C=7)R96YT7V)Y=&5?:6YD97@H)'!A<G-E
M<BDL"B`@("`@("`@("`@("`@("`@("`@>&UL7V5R<F]R7W-T<FEN9RAX;6Q?
M9V5T7V5R<F]R7V-O9&4H)'!A<G-E<BDI*3L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<F%I<V53;V%P1F%U;'0H)&5R<BQH=&UL<W!E8VEA;&-H87)S*"1X
M;6PI*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!X;6Q?<&%R<V5R7V9R
M964H)'!A<G-E<BD["B`@("`@("`@?0H@("`@?0H*"B`@("`O*BH*("`@("`J
M(&1O;75L=&D*("`@("`J(')E8W5R<V4@=&\@8G5I;&0@82!M=6QT:2UD:6T@
M87)R87DL('5S960@8GD@8G5I;&1297-P;VYS90H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!D;VUU;'1I*"1D
M+"`F)&%R+"`F)'(L("8D=BP@)&%D/3`I"B`@("!["B`@("`@("`@:68@*"1D
M*2!["B`@("`@("`@("`@("1T:&ES+3YD;VUU;'1I*"1D+3$L("1A<BP@)');
M)&%R6R1A9%U=+"`D=BP@)&%D*S$I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1R(#T@)'8["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@8G5I;&1297-P;VYS90H@("`@("H@;&]O<"!T:')O=6=H(&US9RP@8G5I
M;&1I;F<@<F5S<&]N<V4@<W1R=6-T=7)E<PH@("`@("H*("`@("`J($!P87)A
M;2!I;G0@<&]S:71I;VX*("`@("`J($!R971U<FX@4T]!4%]686QU90H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N("9B=6EL
M9%)E<W!O;G-E*"1P;W,I"B`@("!["B`@("`@("`@)')E<W!O;G-E(#T@;G5L
M;#L*"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YM97-S86=E6R1P;W-=6R=C
M:&EL9')E;B==*2D@>PH@("`@("`@("`@("`D8VAI;&1R96X@/2!E>'!L;V1E
M*"=\)RP@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V-H:6QD<F5N)UTI.PH*("`@
M("`@("`@("`@9F]R96%C:"`H)&-H:6QD<F5N(&%S("1C(#T^("1C:&EL9%]P
M;W,I('L*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^;65S<V%G95LD8VAI
M;&1?<&]S75LG='EP92==("$](&YU;&PI('L*("`@("`@("`@("`@("`@("`@
M("`D<F5S<&]N<V5;72`])B`D=&AI<RT^8G5I;&1297-P;VYS92@D8VAI;&1?
M<&]S*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@G87)R87E3:7IE)RP@)'1H:7,M
M/FUE<W-A9V5;)'!O<UTI*2!["B`@("`@("`@("`@("`@("`D87)D97!T:"`]
M(&-O=6YT*"1T:&ES+3YM97-S86=E6R1P;W-=6R=A<G)A>5-I>F4G72D["B`@
M("`@("`@("`@("`@("!I9B`H)&%R9&5P=&@@/B`Q*2!["B`@("`@("`@("`@
M("`@("`@("`@)&%R(#T@87)R87E?<&%D*&%R<F%Y*"DL("1A<F1E<'1H+"`P
M*3L*("`@("`@("`@("`@("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@G
M87)R87E/9F9S970G+"`D=&AI<RT^;65S<V%G95LD<&]S72DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&%R9&5P=&@[
M("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1A<ELD:5T@
M*ST@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V%R<F%Y3V9F<V5T)UU;)&E=.PH@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@("1E;&,@/2!C;W5N="@D<F5S<&]N<V4I
M.PH@("`@("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1E;&,[
M("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@+R\@<F5C=7)S92!T
M;R!B=6EL9"!A(&UU;'1I+61I;65N<VEO;F%L(&%R<F%Y"B`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YD;VUU;'1I*"1A<F1E<'1H+"`D87(L("1N
M97=R97-P+"`D<F5S<&]N<V5;)&E=*3L*"B`@("`@("`@("`@("`@("`@("`@
M("`@("\O(&EN8W)E;65N="!O=7(@87)R87D@<&]I;G1E<G,*("`@("`@("`@
M("`@("`@("`@("`@("`@)&%D(#T@)&%R9&5P=&@@+2`Q.PH@("`@("`@("`@
M("`@("`@("`@("`@("`D87);)&%D72LK.PH@("`@("`@("`@("`@("`@("`@
M("`@("!W:&EL92`H)&%D(#X@,"`F)B`D87);)&%D72`^/2`D=&AI<RT^;65S
M<V%G95LD<&]S75LG87)R87E3:7IE)UU;)&%D72D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&%R6R1A9%T@/2`P.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&%D+2T["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D87);)&%D72LK.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1R97-P;VYS
M92`]("1N97=R97-P.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T
M*"1T:&ES+3YM97-S86=E6R1P;W-=6R=A<G)A>4]F9G-E="==*2`F)@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YM97-S86=E6R1P;W-=6R=A
M<G)A>4]F9G-E="==6S!=(#X@,"D@>PH@("`@("`@("`@("`@("`@("`@("\O
M(&-H96-K(&9O<B!P861D:6YG"B`@("`@("`@("`@("`@("`@("`@)'!A9"`]
M("1T:&ES+3YM97-S86=E6R1P;W-=6R=A<G)A>4]F9G-E="==6S!=("L@8V]U
M;G0H)')E<W!O;G-E*2`J("TQ.PH@("`@("`@("`@("`@("`@("`@("1R97-P
M;VYS92`](&%R<F%Y7W!A9"@D<F5S<&]N<V4L("1P860L(&YU;&PI.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`O+R!"=6EL9"!A='1R:6)U=&5S+@H@("`@("`@("1A='1R<R`](&%R<F%Y
M*"D["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V%T
M=')S)UT@87,@)&%T;B`]/B`D871V*2!["B`@("`@("`@("`@(&EF("@A<W1R
M<W1R*"1A=&XL("=X;6QN<R<I("8F"B`@("`@("`@("`@("`@("`A<W1R<&]S
M*"1A=&XL("<Z)RDI('L*("`@("`@("`@("`@("`@("1A='1R<ULD871N72`]
M("1A='8["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O($%D
M9"!C=7)R96YT(&YO9&4G<R!V86QU92X*("`@("`@("!I9B`H)')E<W!O;G-E
M*2!["B`@("`@("`@("`@("1N<6X@/28@;F5W(%%N86UE*"1T:&ES+3YM97-S
M86=E6R1P;W-=6R=N86UE)UTL("1T:&ES+3YM97-S86=E6R1P;W-=6R=N86UE
M<W!A8V4G72D["B`@("`@("`@("`@("1T<6X@/28@;F5W(%%N86UE*"1T:&ES
M+3YM97-S86=E6R1P;W-=6R=T>7!E)UTL("1T:&ES+3YM97-S86=E6R1P;W-=
M6R=T>7!E7VYA;65S<&%C92==*3L*("`@("`@("`@("`@)')E<W!O;G-E(#TF
M(&YE=R!33T%07U9A;'5E*"1N<6XM/F9Q;B@I+"`D='%N+3YF<6XH*2P@)')E
M<W!O;G-E+"`D871T<G,I.PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/FUE<W-A9V5;)'!O<UU;)V%R<F%Y5'EP92==*2D@>PH@("`@("`@("`@("`@
M("`@)')E<W!O;G-E+3YA<G)A>51Y<&4@/2`D=&AI<RT^;65S<V%G95LD<&]S
M75LG87)R87E4>7!E)UT["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D;G%N(#TF(&YE=R!1;F%M92@D=&AI<RT^;65S<V%G
M95LD<&]S75LG;F%M92==+"`D=&AI<RT^;65S<V%G95LD<&]S75LG;F%M97-P
M86-E)UTI.PH@("`@("`@("`@("`D='%N(#TF(&YE=R!1;F%M92@D=&AI<RT^
M;65S<V%G95LD<&]S75LG='EP92==+"`D=&AI<RT^;65S<V%G95LD<&]S75LG
M='EP95]N86UE<W!A8V4G72D["B`@("`@("`@("`@("1R97-P;VYS92`])B!N
M97<@4T]!4%]686QU92@D;G%N+3YF<6XH*2P@)'1Q;BT^9G%N*"DL("1T:&ES
M+3YM97-S86=E6R1P;W-=6R=C9&%T82==+"`D871T<G,I.PH@("`@("`@('T*
M"B`@("`@("`@+R\@:&%N9&QE(&AE861E<B!A='1R:6)U=&4@=&AA="!W92!N
M965D"B`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)V%C=&]R)RP@)'1H
M:7,M/FUE<W-A9V5;)'!O<UTI*2!["B`@("`@("`@("`@("1R97-P;VYS92T^
M86-T;W(@/2`D=&AI<RT^;65S<V%G95LD<&]S75LG86-T;W(G73L*("`@("`@
M("!]"B`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)VUU<W15;F1E<G-T
M86YD)RP@)'1H:7,M/FUE<W-A9V5;)'!O<UTI*2!["B`@("`@("`@("`@("1R
M97-P;VYS92T^;75S='5N9&5R<W1A;F0@/2`D=&AI<RT^;65S<V%G95LD<&]S
M75LG;75S=%5N9&5R<W1A;F0G73L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1R97-P;VYS93L*("`@('T*"B`@("`O*BH*("`@("`J('-T87)T16QE;65N
M=`H@("`@("H@<W1A<G0M96QE;65N="!H86YD;&5R('5S960@=VET:"!X;6P@
M<&%R<V5R"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-T87)T16QE;65N="@D<&%R<V5R+"`D;F%M92P@)&%T
M=')S*0H@("`@>PH@("`@("`@("\O('!O<VET:6]N(&EN(&$@=&]T86P@;G5M
M8F5R(&]F(&5L96UE;G1S+"!S=&%R=&EN9R!F<F]M(#`*("`@("`@("`O+R!U
M<&1A=&4@8VQA<W,@;&5V96P@<&]S"B`@("`@("`@)'!O<R`]("1T:&ES+3YP
M;W-I=&EO;BLK.PH*("`@("`@("`O+R!A;F0@<V5T(&UI;F4*("`@("`@("`D
M=&AI<RT^;65S<V%G95LD<&]S72`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M
M/FUE<W-A9V5;)'!O<UU;)W1Y<&4G72`]("<G.PH@("`@("`@("1T:&ES+3YM
M97-S86=E6R1P;W-=6R=T>7!E7VYA;65S<&%C92==(#T@)R<["B`@("`@("`@
M)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V-D871A)UT@/2`G)SL*("`@("`@("`D
M=&AI<RT^;65S<V%G95LD<&]S75LG<&]S)UT@/2`D<&]S.PH@("`@("`@("1T
M:&ES+3YM97-S86=E6R1P;W-=6R=I9"==(#T@)R<["@H@("`@("`@("\O('!A
M<F5N="]C:&EL9"]D97!T:"!D971E<FUI;F%T:6]N<PH*("`@("`@("`O+R!D
M97!T:"`](&AO=R!M86YY(&QE=F5L<R!R96UO=F5D(&9R;VT@<F]O=#\*("`@
M("`@("`O+R!S970@;6EN92!A<R!C=7)R96YT(&=L;V)A;"!D97!T:"!A;F0@
M:6YC<F5M96YT(&=L;V)A;"!D97!T:"!V86QU90H@("`@("`@("1T:&ES+3YM
M97-S86=E6R1P;W-=6R=D97!T:"==(#T@)'1H:7,M/F1E<'1H*RL["@H@("`@
M("`@("\O(&5L<V4@861D('-E;&8@87,@8VAI;&0@=&\@=VAO979E<B!T:&4@
M8W5R<F5N="!P87)E;G0@:7,*("`@("`@("!I9B`H)'!O<R`A/2`P*2!["B`@
M("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^;65S<V%G95LD=&AI<RT^<&%R
M96YT75LG8VAI;&1R96XG72DI"B`@("`@("`@("`@("`@("`D=&AI<RT^;65S
M<V%G95LD=&AI<RT^<&%R96YT75LG8VAI;&1R96XG72`N/2`B?"1P;W,B.PH@
M("`@("`@("`@("!E;'-E"B`@("`@("`@("`@("`@("`D=&AI<RT^;65S<V%G
M95LD=&AI<RT^<&%R96YT75LG8VAI;&1R96XG72`]("1P;W,["B`@("`@("`@
M?0H*("`@("`@("`O+R!S970@;7D@<&%R96YT"B`@("`@("`@)'1H:7,M/FUE
M<W-A9V5;)'!O<UU;)W!A<F5N="==(#T@)'1H:7,M/G!A<F5N=#L*"B`@("`@
M("`@+R\@<V5T('-E;&8@87,@8W5R<F5N="!V86QU92!F;W(@=&AI<R!D97!T
M:`H@("`@("`@("1T:&ES+3YD97!T:%]A<G)A>5LD=&AI<RT^9&5P=&A=(#T@
M)'!O<SL*("`@("`@("`O+R!S970@<V5L9B!A<R!C=7)R96YT('!A<F5N=`H@
M("`@("`@("1T:&ES+3YP87)E;G0@/2`D<&]S.PH@("`@("`@("1Q;F%M92`]
M)B!N97<@44YA;64H)&YA;64I.PH@("`@("`@("\O('-E="!S=&%T=7,*("`@
M("`@("!I9B`H<W1R8V%S96-M<"@G96YV96QO<&4G+"`D<6YA;64M/FYA;64I
M(#T](#`I('L*("`@("`@("`@("`@)'1H:7,M/G-T871U<R`]("=E;G9E;&]P
M92<["B`@("`@("`@?2!E;'-E:68@*'-T<F-A<V5C;7`H)VAE861E<B<L("1Q
M;F%M92T^;F%M92D@/3T@,"D@>PH@("`@("`@("`@("`D=&AI<RT^<W1A='5S
M(#T@)VAE861E<B<["B`@("`@("`@("`@("1T:&ES+3YH96%D97)?<W1R=6-T
M7VYA;65;72`]("1T:&ES+3YC=7)E;G1?<F]O=%]S=')U8W1?;F%M92`]("1Q
M;F%M92T^;F%M93L*("`@("`@("`@("`@)'1H:7,M/FAE861E<E]S=')U8W1;
M72`]("1T:&ES+3YC=7)E;G1?<F]O=%]S=')U8W0@/2`D<&]S.PH@("`@("`@
M("`@("`D=&AI<RT^;65S<V%G95LD<&]S75LG='EP92==(#T@)U-T<G5C="<[
M"B`@("`@("`@?2!E;'-E:68@*'-T<F-A<V5C;7`H)V)O9'DG+"`D<6YA;64M
M/FYA;64I(#T](#`I('L*("`@("`@("`@("`@)'1H:7,M/G-T871U<R`]("=B
M;V1Y)SL*("`@("`@("`@("`@)'1H:7,M/F)O9'E$97!T:"`]("1T:&ES+3YD
M97!T:#L*"B`@("`@("`@+R\@4V5T(&UE=&AO9`H@("`@("`@('T@96QS96EF
M("@D=&AI<RT^<W1A='5S(#T]("=B;V1Y)RD@>PH@("`@("`@("`@("`O+R!)
M<R!T:&ES(&5L96UE;G0@86QL;W=E9"!T;R!B92!A(')O;W0_"B`@("`@("`@
M("`@("\O(%A86"!T:&ES(&YE961S('1O(&)E(&]P=&EM:7IE9"P@=V4@;&]O
M<"!T:')O=6=H(&%T=')S('1W:6-E(&YO=RX*("`@("`@("`@("`@)&-A;E]R
M;V]T(#T@)'1H:7,M/F1E<'1H(#T]("1T:&ES+3YB;V1Y1&5P=&@@*R`Q.PH@
M("`@("`@("`@("!I9B`H)&-A;E]R;V]T*2!["B`@("`@("`@("`@("`@("!F
M;W)E86-H("@D871T<G,@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@
M("`@("`@("`@("!I9B`H<W1R:7-T<B@D:V5Y+"`G.G)O;W0G*2`F)B`A)'9A
M;'5E*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1C86Y?<F]O="`]($9!
M3%-%.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1C86Y?<F]O="D@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/G-T871U<R`]("=M971H;V0G.PH@("`@
M("`@("`@("`@("`@)'1H:7,M/G)O;W1?<W1R=6-T7VYA;65;72`]("1T:&ES
M+3YC=7)E;G1?<F]O=%]S=')U8W1?;F%M92`]("1Q;F%M92T^;F%M93L*("`@
M("`@("`@("`@("`@("1T:&ES+3YR;V]T7W-T<G5C=%M=(#T@)'1H:7,M/F-U
M<F5N=%]R;V]T7W-T<G5C="`]("1P;W,["B`@("`@("`@("`@("`@("`D=&AI
M<RT^;65S<V%G95LD<&]S75LG='EP92==(#T@)U-T<G5C="<["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("\O(%-E="!M>2!S=&%T=7,N"B`@
M("`@("`@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)W-T871U<R==(#T@)'1H:7,M
M/G-T871U<SL*"B`@("`@("`@+R\@4V5T(&YA;64N"B`@("`@("`@)'1H:7,M
M/FUE<W-A9V5;)'!O<UU;)VYA;64G72`](&AT;6QS<&5C:6%L8VAA<G,H)'%N
M86UE+3YN86UE*3L*"B`@("`@("`@+R\@4V5T(&%T=')I8G5T97,N"B`@("`@
M("`@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V%T=')S)UT@/2`D871T<G,["@H@
M("`@("`@("\O($QO;W`@=&AR;W5G:"!A='1R:6)U=&5S+"!L;V=G:6YG(&YS
M(&%N9"!T>7!E(&1E8VQA<F%T:6]N<RX*("`@("`@("!F;W)E86-H("@D871T
M<G,@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@+R\@268@;G,@
M9&5C;&%R871I;VYS+"!A9&0@=&\@8VQA<W,@;&5V96P@87)R87D@;V8@=F%L
M:60*("`@("`@("`@("`@+R\@;F%M97-P86-E<RX*("`@("`@("`@("`@)&MQ
M;B`])B!N97<@44YA;64H)&ME>2D["B`@("`@("`@("`@(&EF("@D:W%N+3YN
M<R`]/2`G>&UL;G,G*2!["B`@("`@("`@("`@("`@("`D<')E9FEX(#T@)&MQ
M;BT^;F%M93L*"B`@("`@("`@("`@("`@("!I9B`H:6Y?87)R87DH)'9A;'5E
M+"`D=&AI<RT^7UA-3%-C:&5M82DI('L*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W-E=%-C:&5M859E<G-I;VXH)'9A;'5E*3L*("`@("`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("`@("`D=&AI<RT^7VYA;65S<&%C97-;)'9A
M;'5E72`]("1P<F5F:7@["@H@("`@("`@("`@("`O+R!3970@;65T:&]D(&YA
M;65S<&%C92X*("`@("`@("`@("`@?2!E;'-E:68@*"1K97D@/3T@)WAM;&YS
M)RD@>PH@("`@("`@("`@("`@("`@)'%N86UE+3YN<R`]("1T:&ES+3Y?9V5T
M3F%M97-P86-E4')E9FEX*"1V86QU92D["B`@("`@("`@("`@("`@("`D<6YA
M;64M/FYA;65S<&%C92`]("1V86QU93L*("`@("`@("`@("`@?2!E;'-E:68@
M*"1K<6XM/FYA;64@/3T@)V%C=&]R)RD@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/FUE<W-A9V5;)'!O<UU;)V%C=&]R)UT@/2`D=F%L=64["B`@("`@("`@
M("`@('T@96QS96EF("@D:W%N+3YN86UE(#T]("=M=7-T56YD97)S=&%N9"<I
M('L*("`@("`@("`@("`@("`@("1T:&ES+3YM97-S86=E6R1P;W-=6R=M=7-T
M56YD97)S=&%N9"==(#T@)'9A;'5E.PH*("`@("`@("`@("`@+R\@268@:70G
M<R!A('1Y<&4@9&5C;&%R871I;VXL('-E="!T>7!E+@H@("`@("`@("`@("!]
M(&5L<V5I9B`H)&MQ;BT^;F%M92`]/2`G='EP92<I('L*("`@("`@("`@("`@
M("`@("1V<6X@/28@;F5W(%%.86UE*"1V86QU92D["B`@("`@("`@("`@("`@
M("`D=&AI<RT^;65S<V%G95LD<&]S75LG='EP92==(#T@)'9Q;BT^;F%M93L*
M("`@("`@("`@("`@("`@("1T:&ES+3YM97-S86=E6R1P;W-=6R=T>7!E7VYA
M;65S<&%C92==(#T@)'1H:7,M/E]G971.86UE<W!A8V5&;W)0<F5F:7@H)'9Q
M;BT^;G,I.PH@("`@("`@("`@("`@("`@+R\@4VAO=6QD(&1O('-O;65T:&EN
M9R!H97)E('=I=&@@=&AE(&YA;65S<&%C92!O9@H@("`@("`@("`@("`@("`@
M+R\@<W!E8VEF:65D('1Y<&4_"@H@("`@("`@("`@("!](&5L<V5I9B`H)&MQ
M;BT^;F%M92`]/2`G87)R87E4>7!E)RD@>PH@("`@("`@("`@("`@("`@)'9Q
M;B`])B!N97<@44YA;64H)'9A;'5E*3L*("`@("`@("`@("`@("`@("1T:&ES
M+3YM97-S86=E6R1P;W-=6R=T>7!E)UT@/2`G07)R87DG.PH@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1V<6XM/F%R<F%Y4VEZ92DI('L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^;65S<V%G95LD<&]S75LG87)R87E3:7IE)UT@
M/2`D=G%N+3YA<G)A>5-I>F4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`D=&AI<RT^;65S<V%G95LD<&]S75LG87)R87E4>7!E)UT@/2`D
M=G%N+3YN86UE.PH*("`@("`@("`@("`@?2!E;'-E:68@*"1K<6XM/FYA;64@
M/3T@)V]F9G-E="<I('L*("`@("`@("`@("`@("`@("1T:&ES+3YM97-S86=E
M6R1P;W-=6R=A<G)A>4]F9G-E="==(#T@<W!L:70H)RPG+"!S=6)S='(H)'9A
M;'5E+"`Q+"!S=')L96XH)'9A;'5E*2`M(#(I*3L*"B`@("`@("`@("`@('T@
M96QS96EF("@D:W%N+3YN86UE(#T]("=I9"<I('L*("`@("`@("`@("`@("`@
M("\O(%-A=F4@:60@=&\@<F5F97)E;F-E(&%R<F%Y+@H@("`@("`@("`@("`@
M("`@)'1H:7,M/G)E9F5R96YC97-;)'9A;'5E72`]("1P;W,["B`@("`@("`@
M("`@("`@("`D=&AI<RT^;65S<V%G95LD<&]S75LG:60G72`]("1V86QU93L*
M"B`@("`@("`@("`@('T@96QS96EF("@D:W%N+3YN86UE(#T]("=H<F5F)RD@
M>PH@("`@("`@("`@("`@("`@:68@*"1V86QU95LP72`]/2`G(R<I('L*("`@
M("`@("`@("`@("`@("`@("`D<F5F(#T@<W5B<W1R*"1V86QU92P@,2D["B`@
M("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YR969E<F5N8V5S
M6R1R969=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`O+R!C9&%T82P@
M='EP92P@:6YV86PN"B`@("`@("`@("`@("`@("`@("`@("`@("1R969?<&]S
M(#T@)'1H:7,M/G)E9F5R96YC97-;)')E9ET["B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YM97-S86=E6R1P;W-=6R=C:&EL9')E;B==(#T@)B1T
M:&ES+3YM97-S86=E6R1R969?<&]S75LG8VAI;&1R96XG73L*("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V-D871A)UT@
M/2`F)'1H:7,M/FUE<W-A9V5;)')E9E]P;W-=6R=C9&%T82==.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^;65S<V%G95LD<&]S75LG='EP92==
M(#T@)B1T:&ES+3YM97-S86=E6R1R969?<&]S75LG='EP92==.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^;65S<V%G95LD<&]S75LG87)R87E3
M:7IE)UT@/2`F)'1H:7,M/FUE<W-A9V5;)')E9E]P;W-=6R=A<G)A>5-I>F4G
M73L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FUE<W-A9V5;)'!O
M<UU;)V%R<F%Y5'EP92==(#T@)B1T:&ES+3YM97-S86=E6R1R969?<&]S75LG
M87)R87E4>7!E)UT["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`@("`@+R\@4F5V97)S92!R969E<F5N8V4L('-T
M;W)E(&EN("=N965D(')E9F5R96YC92<N"B`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@A:7-S970H)'1H:7,M/FYE961?<F5F97)E;F-E<ULD<F5F72DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YN965D7W)E
M9F5R96YC97-;)')E9ET@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YN965D7W)E
M9F5R96YC97-;)')E9EU;72`]("1P;W,["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES+3YA='1A
M8VAM96YT<ULD=F%L=65=*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YM97-S86=E6R1P;W-=6R=C9&%T82==(#T@)'1H:7,M/F%T=&%C:&UE;G1S
M6R1V86QU95T["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("`@("`@+R\@4V5E(&EF(&YA;65S<&%C92!I<R!D969I;F5D
M(&EN('1A9RX*("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@G>&UL;G,Z
M)R`N("1Q;F%M92T^;G,L("1A='1R<RDI('L*("`@("`@("`@("`@)&YA;65S
M<&%C92`]("1A='1R<ULG>&UL;G,Z)R`N("1Q;F%M92T^;G-=.PH@("`@("`@
M('T@96QS96EF("@D<6YA;64M/FYS("8F("$D<6YA;64M/FYA;65S<&%C92D@
M>PH@("`@("`@("`@("`D;F%M97-P86-E(#T@)'1H:7,M/E]G971.86UE<W!A
M8V5&;W)0<F5F:7@H)'%N86UE+3YN<RD["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@+R\@1V5T(&YA;65S<&%C92X*("`@("`@("`@("`@)&YA;65S
M<&%C92`]("1Q;F%M92T^;F%M97-P86-E(#\@)'%N86UE+3YN86UE<W!A8V4@
M.B`D=&AI<RT^9&5F875L=%]N86UE<W!A8V4["B`@("`@("`@?0H@("`@("`@
M("1T:&ES+3YM97-S86=E6R1P;W-=6R=N86UE<W!A8V4G72`]("1N86UE<W!A
M8V4["B`@("`@("`@)'1H:7,M/F1E9F%U;'1?;F%M97-P86-E(#T@)&YA;65S
M<&%C93L*("`@('T*"B`@("`O*BH*("`@("`J(&5N9$5L96UE;G0*("`@("`J
M(&5N9"UE;&5M96YT(&AA;F1L97(@=7-E9"!W:71H('AM;"!P87)S97(*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I
M;VX@96YD16QE;65N="@D<&%R<V5R+"`D;F%M92D*("`@('L*("`@("`@("`O
M+R!0;W-I=&EO;B!O9B!C=7)R96YT(&5L96UE;G0@:7,@97%U86P@=&\@=&AE
M(&QA<W0@=F%L=64@;&5F=`H@("`@("`@("\O(&EN(&1E<'1H7V%R<F%Y(&9O
M<B!M>2!D97!T:"X*("`@("`@("`D<&]S(#T@)'1H:7,M/F1E<'1H7V%R<F%Y
M6R1T:&ES+3YD97!T:%T["@H@("`@("`@("\O($)R:6YG(&1E<'1H(&1O=VX@
M82!N;W1C:"X*("`@("`@("`D=&AI<RT^9&5P=&@M+3L*("`@("`@("`D<6YA
M;64@/28@;F5W(%%.86UE*"1N86UE*3L*"B`@("`@("`@+R\@1V5T('1Y<&4@
M:68@;F]T(&5X<&QI8VET;'D@9&5C;&%R960@:6X@86X@>'-I.G1Y<&4@871T
M<FEB=71E+@H@("`@("`@("\O(%A86"!C:&5C:R!O;B!I;G1E9W)A=&EN9R!W
M<V1L('9A;&ED871I;VX@:&5R90H@("`@("`@(&EF("@D=&AI<RT^;65S<V%G
M95LD<&]S75LG='EP92==(#T]("<G*2!["B`@("`@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^;65S<V%G95LD<&]S75LG8VAI;&1R96XG72DI('L*("`@("`@
M("`@("`@("`@("\J('1H:7,@:7,@<VQO=RP@;F5E9"!T;R!L;V]K(&%T('-O
M;64@9F%S=&5R(&UE=&AO9`H@("`@("`@("`@("`@("`@)&-H:6QD<F5N(#T@
M97AP;&]D92@G?"<L("1T:&ES+3YM97-S86=E6R1P;W-=6R=C:&EL9')E;B==
M*3L*("`@("`@("`@("`@("`@(&EF("AC;W5N="@D8VAI;&1R96XI(#X@,B`F
M)@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YM97-S86=E6R1C:&EL9')E
M;ELQ75U;)VYA;64G72`]/2`D=&AI<RT^;65S<V%G95LD8VAI;&1R96Y;,EU=
M6R=N86UE)UTI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;65S<V%G
M95LD<&]S75LG='EP92==(#T@)T%R<F%Y)SL*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FUE<W-A9V5;)'!O
M<UU;)W1Y<&4G72`]("=3=')U8W0G.PH@("`@("`@("`@("`@("`@?2HO"B`@
M("`@("`@("`@("`@("`D=&AI<RT^;65S<V%G95LD<&]S75LG='EP92==(#T@
M)U-T<G5C="<["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D<&%R96YT(#T@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)W!A<F5N="==.PH@
M("`@("`@("`@("`@("`@:68@*"1T:&ES+3YM97-S86=E6R1P87)E;G1=6R=T
M>7!E)UT@/3T@)T%R<F%Y)R`F)@H@("`@("`@("`@("`@("`@("!A<G)A>5]K
M97E?97AI<W1S*"=A<G)A>51Y<&4G+"`D=&AI<RT^;65S<V%G95LD<&%R96YT
M72DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;65S<V%G95LD<&]S
M75LG='EP92==(#T@)'1H:7,M/FUE<W-A9V5;)'!A<F5N=%U;)V%R<F%Y5'EP
M92==.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^;65S<V%G95LD<&]S75LG='EP92==(#T@)W-T<FEN9R<[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("\O($EF('1A9R!W92!A<F4@8W5R<F5N=&QY(&-L;W-I;F<@:7,@
M=&AE(&UE=&AO9"!W<F%P<&5R+@H@("`@("`@(&EF("@D<&]S(#T]("1T:&ES
M+3YC=7)E;G1?<F]O=%]S=')U8W0I('L*("`@("`@("`@("`@)'1H:7,M/G-T
M871U<R`]("=B;V1Y)SL*("`@("`@("!](&5L<V5I9B`H)'%N86UE+3YN86UE
M(#T]("=";V1Y)R!\?"`D<6YA;64M/FYA;64@/3T@)TAE861E<B<I('L*("`@
M("`@("`@("`@)'1H:7,M/G-T871U<R`]("=E;G9E;&]P92<["B`@("`@("`@
M?0H*("`@("`@("`O+R!3970@<&%R96YT(&)A8VL@=&\@;7D@<&%R96YT+@H@
M("`@("`@("1T:&ES+3YP87)E;G0@/2`D=&AI<RT^;65S<V%G95LD<&]S75LG
M<&%R96YT)UT["@H@("`@("`@("\O($AA;F1L92!A;GD@<F5V97)S92!R969E
M<F5N8V5S(&YO=RX*("`@("`@("`D:61R968@/2`D=&AI<RT^;65S<V%G95LD
M<&]S75LG:60G73L*"B`@("`@("`@:68@*"1I9')E9B`A/2`G)R`F)B!A<G)A
M>5]K97E?97AI<W1S*"1I9')E9BP@)'1H:7,M/FYE961?<F5F97)E;F-E<RDI
M('L*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/FYE961?<F5F97)E;F-E
M<ULD:61R969=(&%S("1R969?<&]S*2!["B`@("`@("`@("`@("`@("`O+R!8
M6%@@:7,@=&AI<R!S='5F9B!T:&5R92!A;')E861Y/PH@("`@("`@("`@("`@
M("`@)'1H:7,M/FUE<W-A9V5;)')E9E]P;W-=6R=C:&EL9')E;B==(#T@)B1T
M:&ES+3YM97-S86=E6R1P;W-=6R=C:&EL9')E;B==.PH@("`@("`@("`@("`@
M("`@)'1H:7,M/FUE<W-A9V5;)')E9E]P;W-=6R=C9&%T82==(#T@)B1T:&ES
M+3YM97-S86=E6R1P;W-=6R=C9&%T82==.PH@("`@("`@("`@("`@("`@)'1H
M:7,M/FUE<W-A9V5;)')E9E]P;W-=6R=T>7!E)UT@/2`F)'1H:7,M/FUE<W-A
M9V5;)'!O<UU;)W1Y<&4G73L*("`@("`@("`@("`@("`@("1T:&ES+3YM97-S
M86=E6R1R969?<&]S75LG87)R87E3:7IE)UT@/2`F)'1H:7,M/FUE<W-A9V5;
M)'!O<UU;)V%R<F%Y4VEZ92==.PH@("`@("`@("`@("`@("`@)'1H:7,M/FUE
M<W-A9V5;)')E9E]P;W-=6R=A<G)A>51Y<&4G72`]("8D=&AI<RT^;65S<V%G
M95LD<&]S75LG87)R87E4>7!E)UT["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!C:&%R86-T97)$871A"B`@("`@*B!E
M;&5M96YT(&-O;G1E;G0@:&%N9&QE<B!U<V5D('=I=&@@>&UL('!A<G-E<@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC
M=&EO;B!C:&%R86-T97)$871A*"1P87)S97(L("1D871A*0H@("`@>PH@("`@
M("`@("1P;W,@/2`D=&AI<RT^9&5P=&A?87)R87E;)'1H:7,M/F1E<'1H73L*
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V-D871A
M)UTI*2!["B`@("`@("`@("`@("1T:&ES+3YM97-S86=E6R1P;W-=6R=C9&%T
M82==("X]("1D871A.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T
M:&ES+3YM97-S86=E6R1P;W-=6R=C9&%T82==(#T@)&1A=&$["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@9V5T4F5S<&]N<V4*("`@("`J"B`@
M("`@*B!R971U<FYS(&%N(&%R<F%Y(&]F(')E<W!O;G-E<PH@("`@("H@869T
M97(@<&%R<VEN9R!A('-O87`@;65S<V%G92P@=7-E('1H:7,@=&\@9V5T('1H
M92!R97-P;VYS90H@("`@("H*("`@("`J($!R971U<FX@("!A<G)A>0H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=%)E
M<W!O;G-E*"D*("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/G)O;W1?
M<W1R=6-T6S!=*2`F)@H@("`@("`@("`@("`D=&AI<RT^<F]O=%]S=')U8W1;
M,%TI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YB=6EL9%)E<W!O;G-E
M*"1T:&ES+3YR;V]T7W-T<G5C=%LP72D["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")C;W5L9&XG="!B=6EL9"!R
M97-P;VYS92(I.PH@("`@?0H*("`@("\J*@H@("`@("H@9V5T2&5A9&5R<PH@
M("`@("H*("`@("`J(')E='5R;G,@86X@87)R87D@;V8@:&5A9&5R(')E<W!O
M;G-E<PH@("`@("H@869T97(@<&%R<VEN9R!A('-O87`@;65S<V%G92P@=7-E
M('1H:7,@=&\@9V5T('1H92!R97-P;VYS90H@("`@("H*("`@("`J($!R971U
M<FX@("!A<G)A>0H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@)F=E=$AE861E<G,H*0H@("`@>PH@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^:&5A9&5R7W-T<G5C=%LP72D@)B8*("`@("`@("`@("`@)'1H
M:7,M/FAE861E<E]S=')U8W1;,%TI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YB=6EL9%)E<W!O;G-E*"1T:&ES+3YH96%D97)?<W1R=6-T6S!=*3L*
M("`@("`@("!]"@H@("`@("`@("\O(%=E(&1O;B=T(&9A=6QT(&EF('1H97)E
M(&%R92!N;R!H96%D97)S('1H870@8V%N(&)E(&AA;F1L960*("`@("`@("`O
M+R!B>2!T:&4@87!P(&EF(&YE8V5S<V%R>2X*("`@("`@("!R971U<FX@;G5L
M;#L*("`@('T*"B`@("`O*BH*("`@("`J(&1E8V]D945N=&ET:65S"B`@("`@
M*@H@("`@("H@<F5M;W9E<R!E;G1I=&EE<R!F<F]M('1E>'0*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG"B`@("`@*B!`<F5T=7)N("`@<W1R:6YG"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@9&5C
M;V1E16YT:71I97,H)'1E>'0I"B`@("!["B`@("`@("`@)'1R86YS7W1B;"`]
M(&%R<F%Y7V9L:7`H)'1H:7,M/F5N=&ET:65S*3L*("`@("`@("!R971U<FX@
M<W1R='(H)'1E>'0L("1T<F%N<U]T8FPI.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]$871E
M````````````````````````````````````````````````````````````
M`````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S,Q(#`Q-S(V,@`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+T1A=&4O2'5M86XN<&AP````````````````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3<T-C0@,3`U,34T,S,W,S$@,#(Q
M,3,V`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W
M:61T:#TT('-O9G1T86)S=&]P/30Z("HO"B\O"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`U($%L
M;&%N($ME;G0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R
M8V4@9FEL92!I<R!S=6)J96-T('1O('1H92!.97<@0E-$(&QI8V5N<V4L(%1H
M870@:7,@8G5N9&QE9"`@?`HO+R!\('=I=&@@=&AI<R!P86-K86=E(&EN('1H
M92!F:6QE($Q)0T5.4T4L(&%N9"!I<R!A=F%I;&%B;&4@=&AR;W5G:"`@("`@
M('P*+R\@?"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO
M+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@
M("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I
M=F4@82!C;W!Y(&]F('1H92!N97<@0E-$;&EC96YS92!A;F0@87)E('5N86)L
M92`@('P*+R\@?"!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED
M92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("!\"B\O('P@<&5A
M<BUD979`;&ES=',N<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y
M(&EM;65D:6%T96QY+B`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!!=71H;W(Z($%L;&%N($ME;G0@/&%L;&%N0&QO9&5S
M=&]N92YC;RYZ83X@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PH*+RHJ"B`J($-L87-S('1O(&-O
M;G9E<G0@9&%T92!S=')I;F=S(&)E='=E96X@1W)E9V]R:6%N(&%N9"!(=6UA
M;B!C86QE;F1A<B!F;W)M871S"B`J"B`J(%1H92!(=6UA;B!#86QE;F1A<B!F
M;W)M870@:&%S(&)E96X@<')O<&]S960@8GD@4V-O='0@1FQA;G-B=7)G(&%N
M9"!C86X@8F4*("H@97AP;&%I;F5D(&%S(&9O;&QO=W,Z"B`J("!4:&4@>65A
M<B!I<R!M861E('5P(&]F(#$S(&UO;G1H<PH@*B`@16%C:"!M;VYT:"!H87,@
M,C@@9&%Y<PH@*B`@0V]U;G1I;F<@;V8@;6]N=&AS('-T87)T<R!F<F]M(#`@
M*'IE<F\I('-O('1H92!M;VYT:',@=VEL;"!R=6X@9G)O;2`P('1O(#$R"B`J
M("!.97<@665A<G,@9&%Y("@P,"D@:7,@82!M;VYT:&QE<W,@9&%Y"B`J("!.
M;W1E.B!,96%P(%EE87)S(&%R92!N;W0@>65T(&%C8V]U;G1E9"!F;W(@:6X@
M=&AE($AU;6%N($-A;&5N9&%R('-Y<W1E;0H@*@H@*B!02%`@=F5R<VEO;G,@
M-"!A;F0@-0H@*@H@*B!`8V%T96=O<GD@("!$871E(&%N9"!4:6UE"B`J($!P
M86-K86=E("`@($1A=&4*("H@0&%U=&AO<B`@("`@06QL86X@2V5N="`\86QL
M86Y`;&]D97-T;VYE+F-O+GIA/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@
M06QL86X@2V5N=`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+F]P96YS;W5R
M8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@3F5W($)31"!,:6-E
M;G-E"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!(=6UA;BYP:'`L=B`Q+C4@
M,C`P-2\Q,2\Q-2`P,#HQ-CHT,"!P86IO>64@17AP("0*("H@0&QI;FL@("`@
M("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1A=&4*("H@0'-I;F-E
M("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C,*("HO"@HO
M*BH*("H@0VQA<W,@=&\@8V]N=F5R="!D871E('-T<FEN9W,@8F5T=V5E;B!'
M<F5G;W)I86X@86YD($AU;6%N(&-A;&5N9&%R(&9O<FUA=',*("H*("H@5&AE
M($AU;6%N($-A;&5N9&%R(&9O<FUA="!H87,@8F5E;B!P<F]P;W-E9"!B>2!3
M8V]T="!&;&%N<V)U<F<@86YD(&-A;B!B90H@*B!E>'!L86EN960@87,@9F]L
M;&]W<SH*("H@(%1H92!Y96%R(&ES(&UA9&4@=7`@;V8@,3,@;6]N=&AS"B`J
M("!%86-H(&UO;G1H(&AA<R`R."!D87ES"B`J("!#;W5N=&EN9R!O9B!M;VYT
M:',@<W1A<G1S(&9R;VT@,"`H>F5R;RD@<V\@=&AE(&UO;G1H<R!W:6QL(')U
M;B!F<F]M(#`@=&\@,3(*("H@($YE=R!996%R<R!D87D@*#`P*2!I<R!A(&UO
M;G1H;&5S<R!D87D*("H@($YO=&4Z($QE87`@665A<G,@87)E(&YO="!Y970@
M86-C;W5N=&5D(&9O<B!I;B!T:&4@2'5M86X@0V%L96YD87(@<WES=&5M"B`J
M"B`J($!A=71H;W(@("`@($%L;&%N($ME;G0@/&%L;&%N0&QO9&5S=&]N92YC
M;RYZ83X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U($%L;&%N($ME;G0*("H@
M0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E
M<R]B<V0M;&EC96YS92YP:'`@($YE=R!"4T0@3&EC96YS90H@*B!`=F5R<VEO
M;B`@("!296QE87-E.B`Q+C0N-@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A
M<BYP:'`N;F5T+W!A8VMA9V4O1&%T90H@*B!`<VEN8V4@("`@("!#;&%S<R!A
M=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C,*("HO"F-L87-S($1A=&5?2'5M
M86X*>PH@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&%S<V]C:6%T:79E(&%R
M<F%Y(&-O;G1A:6YI;F<@=&AE(&-O;G9E<G1E9"!D871E(&EN9F]R;6%T:6]N
M"B`@("`@*B!I;B`G2'5M86X@0V%L96YD87(G(&9O<FUA="X*("`@("`J"B`@
M("`@*B!`<&%R86T@:6YT(&1A>2!I;B!$1"!F;W)M870L(&1E9F%U;'0@8W5R
M<F5N="!L;V-A;"!D87D*("`@("`J($!P87)A;2!I;G0@;6]N=&@@:6X@34T@
M9F]R;6%T+"!D969A=6QT(&-U<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P
M87)A;2!I;G0@>65A<B!I;B!#0UE9(&9O<FUA="P@9&5F875L="!T;R!C=7)R
M96YT(&QO8V%L('EE87(*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("H*("`@("`J($!R971U<FX@87-S;V-I871I=F4@87)R87DH"B`@("`@
M*B`@("`@("`@("`@("`@(&AD;VTL("`@("`@("\O($AU;6%N($1A>2!/9B!-
M;VYT:"P@<W1A<G1I;F<@870@,0H@("`@("H@("`@("`@("`@("`@("!H9&]W
M+"`@("`@("`O+R!(=6UA;B!$87D@3V8@5V5E:RP@<W1A<G1I;F<@870@,0H@
M("`@("H@("`@("`@("`@("`@("!H=V]M+"`@("`@("`O+R!(=6UA;B!7965K
M(&]F($UO;G1H+"!S=&%R=&EN9R!A="`Q"B`@("`@*B`@("`@("`@("`@("`@
M(&AW;WDL("`@("`@("\O($AU;6%N(%=E96L@;V8@665A<BP@<W1A<G1I;F<@
M870@,0H@("`@("H@("`@("`@("`@("`@("!H;6]Y+"`@("`@("`O+R!(=6UA
M;B!-;VYT:"!O9B!996%R+"!S=&%R=&EN9R!A="`P"B`@("`@*B`@("`@("`@
M("`@("`@("D*("`@("`J"B`@("`@*B!)9B!T:&4@9&%Y(&ES($YE=R!996%R
M<R!$87DL('1H92!F=6YC=&EO;B!W:6QL(')E='5R;@H@("`@("H@(FAD;VTB
M(#T^("`P"B`@("`@*B`B:&1O=R(@/3X@(#`*("`@("`J(")H=V]M(B`]/B`@
M,`H@("`@("H@(FAW;WDB(#T^("`P"B`@("`@*B`B:&UO>2(@/3X@+3$*("`@
M("`J("!3:6YC92`P(&ES(&$@=F%L:60@;6]N=&@@;G5M8F5R('5N9&5R('1H
M92!(=6UA;B!#86QE;F1A<BP@22!H879E(&QE9G0*("`@("`J("!T:&4@;6]N
M=&@@87,@+3$@9F]R($YE=R!996%R<R!$87DN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=R96=O<FEA;E1O2'5M86XH)&1A>3TP+"`D;6]N=&@],"P@)'EE87(]
M,"D*("`@('L*("`@("`@("`O*@H@("`@("`@("`J($-H96-K('1O('-E92!I
M9B!A;GD@;V8@=&AE(&%R9W5M96YT<R!A<F4@96UP='D*("`@("`@("`@*B!)
M9B!T:&5Y(&%R92!T:&5N('!O<'5L871E('1H92`D9&%T96EN9F\@87)R87D*
M("`@("`@("`@*B!4:&5N(&-H96-K('1O('-E92!W:&EC:"!A<F=U;65N=',@
M87)E(&5M<'1Y(&%N9"!F:6QL"B`@("`@("`@("H@=&AO<V4@=VET:"!T:&4@
M8W5R<F5N="!D871E(&EN9F\*("`@("`@("`@*B\*("`@("`@("!I9B`H*&5M
M<'1Y*"1D87DI('Q\("AE;7!T>2@D;6]N=&@I*2!\?"!E;7!T>2@D>65A<BDI
M*2!["B`@("`@("`@("`@("1D871E:6YF;R`](&=E=&1A=&4H=&EM92@I*3L*
M("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1D87DI*2!["B`@("`@("`@
M("`@("1D87D@/2`D9&%T96EN9F];(FUD87DB73L*("`@("`@("!]"B`@("`@
M("`@:68@*&5M<'1Y*"1M;VYT:"DI('L*("`@("`@("`@("`@)&UO;G1H(#T@
M)&1A=&5I;F9O6R)M;VXB73L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y
M*"1Y96%R*2D@>PH@("`@("`@("`@("`D>65A<B`]("1D871E:6YF;ULB>65A
M<B)=.PH@("`@("`@('T*("`@("`@("`O*@H@("`@("`@("`J(%=E(&YE960@
M=&\@:VYO=R!H;W<@;6%N>2!D87ES(&EN=&\@=&AE('EE87(@=V4@87)E"B`@
M("`@("`@("HO"B`@("`@("`@)&1A=&5I;F9O(#T@9V5T9&%T92AM:W1I;64H
M,"P@,"P@,"P@)&UO;G1H+"`D9&%Y+"`D>65A<BDI.PH@("`@("`@("1D87EO
M9GEE87(@/2`D9&%T96EN9F];(GED87DB73L*("`@("`@("`O*@H@("`@("`@
M("`J($AU;6%N($-A;&5N9&%R('-T87)T<R!A="`P(&9O<B!M;VYT:',@86YD
M('1H92!F:7)S="!D87D@;V8@=&AE('EE87(*("`@("`@("`@*B!I<R!D97-I
M9VYA=&5D(#`P+"!S;R!W92!N965D('1O('-T87)T(&]U<B!D87D@;V8@=&AE
M('EE87(@870@,"!F;W(*("`@("`@("`@*B!T:&5S92!C86QC=6QA=&EO;G,N
M"B`@("`@("`@("H@06QS;RP@=&AE(&1A>2!O9B!T:&4@;6]N=&@@:7,@8V%L
M8W5L871E9"!W:71H(&$@;6]D=6QU<R!O9B`R."X*("`@("`@("`@*B!"96-A
M=7-E(&$@9&%Y(&ES(#(X(&1A>7,L('1H92!L87-T(&1A>2!O9B!T:&4@;6]N
M=&@@=V]U;&0@:&%V92!A"B`@("`@("`@("H@<F5M86EN9&5R(&]F(#`@86YD
M(&YO="`R."!A<R!I="!S:&]U;&0@8F4N("!$96-R96UE;G1I;F<@)&1A>6]F
M>65A<@H@("`@("`@("`J(&=E=',@87)O=6YD('1H:7,N"B`@("`@("`@("HO
M"B`@("`@("`@)&1A>6]F>65A<BTM.PH@("`@("`@("\J"B`@("`@("`@("H@
M,C@@9&%Y<R!I;B!A(&UO;G1H+BXN"B`@("`@("`@("HO"B`@("`@("`@)&AU
M;6%N36]N=&A/9EEE87(@/2!F;&]O<B@D9&%Y;V9Y96%R("\@,C@I.PH@("`@
M("`@("\J"B`@("`@("`@("H@268@=V4@87)E(&EN('1H92!F:7)S="!M;VYT
M:"!T:&5N('1H92!D87D@;V8@=&AE(&UO;G1H(&ES("1D87EO9GEE87(*("`@
M("`@("`@*B!E;'-E('=E(&YE960@=&\@9FEN9"!T:&4@;6]D=6QU<R!O9B`R
M."X*("`@("`@("`@*B\*("`@("`@("!I9B`H)&AU;6%N36]N=&A/9EEE87(@
M/3T@,"D@>PH@("`@("`@("`@("`D:'5M86Y$87E/9DUO;G1H(#T@)&1A>6]F
M>65A<CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D:'5M86Y$87E/
M9DUO;G1H(#T@*"1D87EO9GEE87(I("4@,C@["B`@("`@("`@?0H@("`@("`@
M("\J"B`@("`@("`@("H@1&%Y(&]F('1H92!W965K(&ES(&UO9'5L=7,@-PH@
M("`@("`@("`J+PH@("`@("`@("1H=6UA;D1A>4]F5V5E:R`]("1D87EO9GEE
M87(@)2`W.PH@("`@("`@("\J"B`@("`@("`@("H@5V4@8V%N(&YO=R!I;F-R
M96UE;G0@)&1A>6]F>65A<B!B86-K('1O(&ET)W,@8V]R<F5C="!V86QU92!F
M;W(*("`@("`@("`@*B!T:&4@<F5M86EN9&5R(&]F('1H92!C86QC=6QA=&EO
M;G,*("`@("`@("`@*B\*("`@("`@("`D9&%Y;V9Y96%R*RL["B`@("`@("`@
M+RH*("`@("`@("`@*B`D:'5M86Y$87E/9DUO;G1H(&YE961S('1O(&)E(&EN
M8W)E;65N=&5D(&YO=R`M(')E8V%L;"!T:&%T('=E(&9U9&=E9`H@("`@("`@
M("`J(&ET(&$@8FET(&)Y(&1E8W)E;65N=&EN9R`D9&%Y;V9Y96%R(&5A<FQI
M97(*("`@("`@("`@*B!386UE(&=O97,@9F]R("1H=6UA;D1A>4]F5V5E:PH@
M("`@("`@("`J+PH@("`@("`@("1H=6UA;D1A>4]F36]N=&@K*SL*("`@("`@
M("`D:'5M86Y$87E/9E=E96LK*SL*("`@("`@("`O*@H@("`@("`@("`J(%=E
M96L@;V8@=&AE(&UO;G1H(&ES(&1A>2!O9B!T:&4@;6]N=&@@9&EV:61E9"!B
M>2`W+"!R;W5N9&5D('5P"B`@("`@("`@("H@4V%M92!F;W(@=V5E:R!O9B!T
M:&4@>65A<BP@8G5T('5S92`D9&%Y;V9Y96%R(&EN<W1E860@)&AU;6%N1&%Y
M3V9-;VYT:`H@("`@("`@("`J+PH@("`@("`@("1H=6UA;E=E96M/9DUO;G1H
M(#T@8V5I;"@D:'5M86Y$87E/9DUO;G1H("\@-RD["B`@("`@("`@)&AU;6%N
M5V5E:T]F665A<B`](&-E:6PH)&1A>6]F>65A<B`O(#<I.PH@("`@("`@("\J
M"B`@("`@("`@("H@4F5T=7)N(&%N(&%S<V]C:6%T:79E(&%R<F%Y(&]F('1H
M92!V86QU97,*("`@("`@("`@*B\*("`@("`@("!R971U<FX@87)R87DH"B`@
M("`@("`@("`@("`@("`@("`@(")H9&]M(B`]/B`D:'5M86Y$87E/9DUO;G1H
M+`H@("`@("`@("`@("`@("`@("`@("`B:&1O=R(@/3X@)&AU;6%N1&%Y3V97
M965K+`H@("`@("`@("`@("`@("`@("`@("`B:'=O;2(@/3X@)&AU;6%N5V5E
M:T]F36]N=&@L"B`@("`@("`@("`@("`@("`@("`@(")H=V]Y(B`]/B`D:'5M
M86Y7965K3V9996%R+`H@("`@("`@("`@("`@("`@("`@("`B:&UO>2(@/3X@
M)&AU;6%N36]N=&A/9EEE87(@*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=6YI>"!T:6UE<W1A;7`@9F]R(&$@9VEV96X@2'5M86X@0V%L96YD
M87(@9&%T90H@("`@("H*("`@("`J($!P87)A;2!I;G0@9&%Y(&EN($1$(&9O
M<FUA=`H@("`@("H@0'!A<F%M(&EN="!M;VYT:"!I;B!-32!F;W)M870*("`@
M("`J($!P87)A;2!I;G0@>65A<B!I;B!#0UE9(&9O<FUA="P@9&5F875L="!T
M;R!C=7)R96YT(&QO8V%L('EE87(*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("H*("`@("`J($!R971U<FX@:6YT('5N:7@@=&EM97-T86UP
M(&]F(&1A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@2'5M86Y4;T=R96=O<FEA
M;B@D9&%Y+"`D;6]N=&@L("1Y96%R/3`I"B`@("!["B`@("`@("`@+RH*("`@
M("`@("`@*B!#:&5C:R!T;R!S964@:68@=&AE('EE87(@:&%S(&)E96X@<&%S
M<V5D('1H<F]U9V@N"B`@("`@("`@("H@268@;F]T(&=E="!C=7)R96YT('EE
M87(*("`@("`@("`@*B\*("`@("`@("!I9B`H96UP='DH)'EE87(I*2!["B`@
M("`@("`@("`@("1D871E:6YF;R`](&=E=&1A=&4H=&EM92@I*3L*("`@("`@
M("`@("`@)'EE87(@/2`D9&%T96EN9F];(GEE87(B73L*("`@("`@("!]"B`@
M("`@("`@+RH*("`@("`@("`@*B!792!N965D('1O(&=E="!T:&4@9&%Y(&]F
M('1H92!Y96%R('1H870@=V4@87)E(&-U<G)E;G1L>2!A="!S;R!T:&%T"B`@
M("`@("`@("H@=V4@8V%N('=O<FL@;W5T('1H92!'<F5G;W)I86X@36]N=&@@
M86YD(&1A>0H@("`@("`@("`J+PH@("`@("`@("1$87E/9EEE87(@/2`D;6]N
M=&@@*B`R.#L*("`@("`@("`D1&%Y3V9996%R("L]("1D87D["B`@("`@("`@
M+RH*("`@("`@("`@*B!(=6UA;B!#86QE;F1A<B!S=&%R=',@870@,"P@<V\@
M=V4@;F5E9"!T;R!I;F-R96UE;G0@)$1A>4]F665A<@H@("`@("`@("`J('1O
M('1A:V4@:6YT;R!A8V-O=6YT('1H92!D87D@,#`*("`@("`@("`@*B\*("`@
M("`@("`D1&%Y3V9996%R*RL["B`@("`@("`@+RH*("`@("`@("`@*B!T:&4@
M;6MT:6UE*"D@9G5N8W1I;VX@=VEL;"!C;W)R96-T;'D@8V%L8W5L871E('1H
M92!D871E(&9O<B!O=70@;V8*("`@("`@("`@*B!R86YG92!V86QU97,L('-O
M('!U='1I;F<@)$1A>4]F665A<B!I;G-T96%D(&]F('1H92!D87D@;V8@=&AE
M(&UO;G1H"B`@("`@("`@("H@=VEL;"!W;W)K(&9I;F4N"B`@("`@("`@("HO
M"B`@("`@("`@)$=R96=O<FEA;E1I;653=&%M<"`](&UK=&EM92@P+"`P+"`P
M+"`Q+"`D1&%Y3V9996%R+"`D>65A<BD["B`@("`@("`@<F5T=7)N("1'<F5G
M;W)I86Y4:6UE4W1A;7`["B`@("!]"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]$871E+U-P86XN<&AP
M````````````````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#<U
M-30Q(#$P-3$U-#,S-S,Q(#`R,#<V-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T
M86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PHO
M+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG
M:'0@*&,I(#$Y.3<M,C`P-2`@3&5A;F1R;R!,=6-A<F5L;&$L(%!I97)R92U!
M;&%I;B!*;WEE("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!T:&4@
M3F5W($)31"!L:6-E;G-E+"!4:&%T(&ES(&)U;F1L960@('P*+R\@?"!W:71H
M('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@879A
M:6QA8FQE('1H<F]U9V@@("`@("!\"B\O('P@=&AE('=O<FQD+7=I9&4M=V5B
M(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS
M97,O8G-D+6QI8V5N<V4N<&AP("`@("`@("`@("`@("`@("`@('P*+R\@?"!)
M9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@;F5W($)31&QI
M8V5N<V4@86YD(&%R92!U;F%B;&4@("!\"B\O('P@=&\@;V)T86EN(&ET('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@
M=&\@("`@("`@?`HO+R!\('!E87(M9&5V0&QI<W1S+G!H<"YN970@<V\@=V4@
M8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@('P*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R.B!"86)A
M($)U96AL97(@/&)A8F%`8F%B87HN8V]M/B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R!\("`@("`@("`@4&EE<G)E+4%L86EN($IO>64@
M/'!A:F]Y94!P:'`N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"@HO*BH*("H@1V5N97)I
M8R!T:6UE('-P86X@:&%N9&QI;F<@8VQA<W,@9F]R(%!%05(*("H*("H@4$A0
M('9E<G-I;VYS(#0@86YD(#4*("H*("H@0&-A=&5G;W)Y("`@1&%T92!A;F0@
M5&EM90H@*B!`<&%C:V%G92`@("!$871E"B`J($!A=71H;W(@("`@($QE86YD
M<F\@3'5C87)E;&QA(#QL;'5C87A`<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@
M4&EE<G)E+4%L86EN($IO>64@/'!A:F]Y94!P:'`N;F5T/@H@*B!`8V]P>7)I
M9VAT("`Q.3DW+3(P,#4@3&5A;F1R;R!,=6-A<F5L;&$L(%!I97)R92U!;&%I
M;B!*;WEE"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO
M<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!.97<@0E-$($QI8V5N<V4*
M("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%-P86XN<&AP+'8@,2XX(#(P,#4O
M,3$O,34@,#`Z,38Z-#`@<&%J;WEE($5X<"`D"B`J($!L:6YK("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$871E"B`J($!S:6YC92`@("`@
M($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT"B`J+PH*+RHJ"B`J
M($=E="!T:&4@1&%T92!C;&%S<PH@*B\*<F5Q=6ER95]O;F-E("=$871E+G!H
M<"<["@HO*BH*("H@1V5T('1H92!$871E7T-A;&,@8VQA<W,*("HO"G)E<75I
M<F5?;VYC92`G1&%T92]#86QC+G!H<"<["@HO*BH*("H@3F]N($YU;65R:6,@
M4V5P87)A=&5D(%9A;'5E<R`H3DY35BD@26YP=70@1F]R;6%T+@H@*@H@*B!)
M;G!U="!F;W)M870@9W5E<W-E9"!F<F]M('-O;65T:&EN9R!L:6ME('1H:7,Z
M"B`J(&1A>7,\<V5P/FAO=7)S/'-E<#YM:6YU=&5S/'-E<#YS96-O;F1S"B`J
M(%=H97)E(#QS97`^(&ES(&%N>2!Q=6%N=&ET>2!O9B!N;VX@;G5M97)I8R!C
M:&%R<RX@268@;F\@=F%L=65S(&%R90H@*B!G:79E;BP@=&EM92!S<&%N(&ES
M('-E="!T;R!Z97)O+"!I9B!O;F4@=F%L=64@:7,@9VEV96XL(&ET)W,@=7-E
M9"!F;W(*("H@:&]U<G,L(&EF('1W;R!V86QU97,@87)E(&=I=F5N(&ET)W,@
M=7-E9"!F;W(@:&]U<G,@86YD(&UI;G5T97,@86YD(&EF"B`J('1H<F5E('9A
M;'5E<R!A<F4@9VEV96XL(&ET)W,@=7-E9"!F;W(@:&]U<G,L(&UI;G5T97,@
M86YD('-E8V]N9',N/&)R/@H@*B!%>&%M<&QE<SH\8G(^"B`J("<G("`@("`@
M("`@("`@("`@("`@("T^(#`L(#`L(#`L(#`@*&1A>7,L(&AO=7)S+"!M:6YU
M=&5S+"!S96-O;F1S*3QB<CX*("H@)S$R)R`@("`@("`@("`@("`@("`@+3X@
M,"P@,3(L(#`L(#`*("H@)S$R+C,P)R`@("`@("`@("`@("`@+3X@,"P@,3(L
M(#,P+"`P/&)R/@H@*B`G,3(Z,S`Z,3@G("`@("`@("`@("`M/B`P+"`Q,BP@
M,S`L(#$X/&)R/@H@*B`G,RTQ,BTS,"TQ."<@("`@("`@("`M/B`S+"`Q,BP@
M,S`L(#$X/&)R/@H@*B`G,R!D87ES+"`Q,BTS,"TQ."<@("`M/B`S+"`Q,BP@
M,S`L(#$X/&)R/@H@*B`G,3(Z,S`@=VET:"`Q."!S96-S)R`M/B`P+"`Q,BP@
M,S`L(#$X/&)R/@H@*@H@*B!`8V]N<W0@:6YT"B`J+PID969I;F4H)T1!5$5?
M4U!!3E])3E!55%]&3U)-051?3DY35B<L(#$I.PH*+RHJ"B`J($1E9F%U;'0@
M=&EM92!F;W)M870@=VAE;B!C;VYV97)T:6YG('1O(&$@<W1R:6YG+@H@*@H@
M*B!`9VQO8F%L('-T<FEN9PH@*B\*)$=,3T)!3%-;)U]$051%7U-004Y?1D]2
M34%4)UT@(#T@)R5#)SL*"B\J*@H@*B!$969A=6QT('1I;64@9F]R;6%T('=H
M96X@8V]N=F5R=&EN9R!F<F]M(&$@<W1R:6YG+@H@*@H@*B!`9VQO8F%L(&UI
M>&5D"B`J+PHD1TQ/0D%,4ULG7T1!5$5?4U!!3E])3E!55%]&3U)-050G72`]
M($1!5$5?4U!!3E])3E!55%]&3U)-051?3DY35CL*"B\J*@H@*B!'96YE<FEC
M('1I;64@<W!A;B!H86YD;&EN9R!C;&%S<R!F;W(@4$5!4@H@*@H@*B!`875T
M:&]R("`@("!,96%N9')O($QU8V%R96QL82`\;&QU8V%X0'!H<"YN970^"B`J
M($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E
M;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D
M+6QI8V5N<V4N<&AP("!.97<@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@
M4F5L96%S93H@,2XT+C8*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP
M+FYE="]P86-K86=E+T1A=&4*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA
M8FQE('-I;F-E(%)E;&5A<V4@,2XT"B`J"B`J($!T;V1O("`@("`@($=E="!A
M;F0@<V5T(&1E9F%U;'0@;&]C86P@:6YP=70@86YD(&]U='!U="!F;W)M871S
M/PH@*B\*8VQA<W,@1&%T95]3<&%N('L*"B`@("`O*BH*("`@("`J($!V87(@
M:6YT"B`@("`@*B\*("`@('9A<B`D9&%Y.PH*("`@("\J*@H@("`@("H@0'9A
M<B!I;G0*("`@("`J+PH@("`@=F%R("1H;W5R.PH*("`@("\J*@H@("`@("H@
M0'9A<B!I;G0*("`@("`J+PH@("`@=F%R("1M:6YU=&4["@H@("`@+RHJ"B`@
M("`@*B!`=F%R(&EN=`H@("`@("HO"B`@("!V87(@)'-E8V]N9#L*"B`@("`O
M*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($-R96%T97,@
M=&AE('1I;64@<W!A;B!O8FIE8W0@8V%L;&EN9R!T:&4@<V5T*"D@;65T:&]D
M+@H@("`@("H*("`@("`J($!P87)A;2`@;6EX960@)'1I;64@("!4:6UE('-P
M86X@97AP<F5S<VEO;BX*("`@("`J($!P87)A;2`@;6EX960@)&9O<FUA="!&
M;W)M870@<W1R:6YG('1O('-E="!I="!F<F]M(&$@<W1R:6YG(&]R('1H90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@('-E8V]N9"!D871E('-E="!I
M="!F<F]M(&$@9&%T92!D:69F+@H@("`@("H*("`@("`J($!S964@("`@<V5T
M*"D*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N
M($1A=&5?4W!A;B@D=&EM92`](#`L("1F;W)M870@/2!N=6QL*0H@("`@>PH@
M("`@("`@("1T:&ES+3YS970H)'1I;64L("1F;W)M870I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5T('1H92!T:6UE('-P86X@=&\@82!N97<@=F%L=64@
M:6X@82`G<VUA<G0G('=A>2X*("`@("`J"B`@("`@*B!3971S('1H92!T:6UE
M('-P86X@9&5P96YD:6YG(&]N('1H92!A<F=U;65N="!T>7!E<RP@8V%L;&EN
M9PH@("`@("H@=&\@=&AE(&%P<')O<')I871E('-E=$9R;VU8>'@H*2!M971H
M;V0N"B`@("`@*@H@("`@("H@0'!A<F%M("!M:7AE9"`D=&EM92`@(%1I;64@
M<W!A;B!E>'!R97-S:6]N+@H@("`@("H@0'!A<F%M("!M:7AE9"`D9F]R;6%T
M($9O<FUA="!S=')I;F<@=&\@<V5T(&ET(&9R;VT@82!S=')I;F<@;W(@=&AE
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<V5C;VYD(&1A=&4@<V5T
M(&ET(&9R;VT@82!D871E(&1I9F8N"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L("!T<G5E(&]N('-U8V-E<W,N"B`@("`@*@H@("`@("H@0'-E92`@("!S
M971&<F]M3V)J96-T*"D*("`@("`J($!S964@("`@<V5T1G)O;4%R<F%Y*"D*
M("`@("`J($!S964@("`@<V5T1G)O;5-T<FEN9R@I"B`@("`@*B!`<V5E("`@
M('-E=$9R;VU396-O;F1S*"D*("`@("`J($!S964@("`@<V5T1G)O;41A=&5$
M:69F*"D*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T
M:6]N('-E="@D=&EM92`](#`L("1F;W)M870@/2!N=6QL*0H@("`@>PH@("`@
M("`@(&EF("AI<U]A*"1T:6UE+"`G9&%T95]S<&%N)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YC;W!Y*"1T:6UE*3L*("`@("`@("!](&5L<V5I
M9B`H:7-?82@D=&EM92P@)V1A=&4G*2!A;F0@:7-?82@D9F]R;6%T+"`G9&%T
M92<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<V5T1G)O;41A=&5$
M:69F*"1T:6UE+"`D9F]R;6%T*3L*("`@("`@("!](&5L<V5I9B`H:7-?87)R
M87DH)'1I;64I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<V5T1G)O
M;4%R<F%Y*"1T:6UE*3L*("`@("`@("!](&5L<V5I9B`H:7-?<W1R:6YG*"1T
M:6UE*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G-E=$9R;VU3=')I
M;F<H)'1I;64L("1F;W)M870I.PH@("`@("`@('T@96QS96EF("AI<U]I;G0H
M)'1I;64I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<V5T1G)O;5-E
M8V]N9',H)'1I;64I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<V5T1G)O;5-E8V]N9',H,"D["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@4V5T('1H92!T:6UE('-P86X@9G)O;2!A;B!A
M<G)A>2X*("`@("`J"B`@("`@*B!3970@=&AE('1I;64@<W!A;B!F<F]M(&%N
M(&%R<F%Y+B!!;GD@=F%L=64@8V%N(&)E(&$@9FQO870@*&)U="!I=`H@("`@
M("H@:&%S(&YO('-E;G-E(&EN('-E8V]N9',I+"!F;W(@97AA;7!L92!A<G)A
M>2@R,RXU+"`R,"P@,"D@:7,*("`@("`J(&EN=&5R<')E=&5D(&%S(#(S(&AO
M=7)S+"`N-2HV,"`K(#(P(#T@-3`@;6EN=71E<R!A;F0@,"!S96-O;F1S+@H@
M("`@("H*("`@("`J($!P87)A;2`@87)R87D@)'1I;64@271E;7,@87)E(&-O
M=6YT960@9G)O;2!R:6=H="!T;R!L969T+B!&:7)S=`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("!I=&5M(&ES(&9O<B!S96-O;F1S+"!S96-O;F0@9F]R
M(&UI;G5T97,L('1H:7)D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(&9O
M<B!H;W5R<R!A;F0@9F]U<G1H(&9O<B!D87ES+B!)9B!T:&5R92!A<F4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@;&5S<R!I=&5M<R!T:&%N(#0L('IE
M<F\@*#`I(&ES(&%S<W5M960@9F]R('1H90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("!A8G-E;G0@=F%L=65S+@H@("`@("H*("`@("`J($!R971U<FX@
M8F]O;"`@5')U92!O;B!S=6-C97-S+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$9R;VU!<G)A>2@D=&EM
M92D*("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1T:6UE*2D@>PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@("1T;7`Q
M(#T@;F5W($1A=&5?4W!A;CL*("`@("`@("!I9B`H(21T;7`Q+3YS971&<F]M
M4V5C;VYD<RA`87)R87E?<&]P*"1T:6UE*2DI('L*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("`D=&UP,B`](&YE=R!$871E
M7U-P86X["B`@("`@("`@:68@*"$D=&UP,BT^<V5T1G)O;4UI;G5T97,H0&%R
M<F%Y7W!O<"@D=&EM92DI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!]"B`@("`@("`@)'1M<#$M/F%D9"@D=&UP,BD["B`@("`@("`@
M:68@*"$D=&UP,BT^<V5T1G)O;4AO=7)S*$!A<G)A>5]P;W`H)'1I;64I*2D@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@
M("1T;7`Q+3YA9&0H)'1M<#(I.PH@("`@("`@(&EF("@A)'1M<#(M/G-E=$9R
M;VU$87ES*$!A<G)A>5]P;W`H)'1I;64I*2D@>PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@("1T;7`Q+3YA9&0H)'1M<#(I
M.PH@("`@("`@(')E='5R;B`D=&AI<RT^8V]P>2@D=&UP,2D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!3970@=&AE('1I;64@<W!A;B!F<F]M(&$@<W1R:6YG
M(&)A<V5D(&]N(&%N(&EN<'5T(&9O<FUA="X*("`@("`J"B`@("`@*B!3970@
M=&AE('1I;64@<W!A;B!F<F]M(&$@<W1R:6YG(&)A<V5D(&]N(&%N(&EN<'5T
M(&9O<FUA="X@5&AI<R!I<PH@("`@("H@<V]M92!L:6ME(&$@;6EX(&]F(&9O
M<FUA="@I(&UE=&AO9"!A;F0@<W-C86YF*"D@4$A0(&9U;F-T:6]N+B!4:&4*
M("`@("`J(&5R<F]R(&-H96-K:6YG(&%N9"!V86QI9&%T:6]N(&]F('1H:7,@
M9G5N8W1I;VX@:7,@=F5R>2!P<FEM:71I=F4L"B`@("`@*B!S;R!Y;W4@<VAO
M=6QD(&)E(&-A<F5F=6QL('=H96X@=7-I;F<@:70@=VET:"!U;FMN;W=N("1T
M:6UE('-T<FEN9W,N"B`@("`@*B!7:71H('1H:7,@;65T:&]D('EO=2!A<F4@
M87-S:6=N:6YG(&1A>2P@:&]U<BP@;6EN=71E(&%N9"!S96-O;F0*("`@("`J
M('9A;'5E<RP@86YD('1H92!L87-T('9A;'5E<R!A<F4@=7-E9"X@5&AI<R!M
M96%N<R!T:&%T(&EF('EO=2!U<V4*("`@("`J('-O;65T:&EN9R!L:6ME('-E
M=$9R;VU3=')I;F<H)S$P+"`R,"<L("<E2"P@)6@G*2!Y;W5R('1I;64@<W!A
M;@H@("`@("H@=V]U;&0@8F4@,C`@:&]U<G,@;&]N9RX@06QL=V%Y<R!R96UE
M;6)E<B!T:&%T('1H:7,@;65T:&]D('-E=`H@("`@("H@/&(^86QL/"]B/B!T
M:&4@=F%L=65S+"!S;R!I9B!Y;W4@:&%D(&$@)'1I;64@<W!A;B`S,"!M:6YU
M=&5S(&QO;F<*("`@("`J(&%N9"!Y;W4@;6%K92`D=&EM92T^<V5T1G)O;5-T
M<FEN9R@G,C`@:&]U<G,G+"`G)4@@:&]U<G,G*2P@)'1I;64*("`@("`J('-P
M86X@=V]U;&0@8F4@,C`@:&]U<G,@;&]N9R`H86YD(&YO="`R,"!H;W5R<R!A
M;F0@,S`@;6EN=71E<RDN"B`@("`@*B!);G!U="!F;W)M870@;W!T:6]N<SH\
M8G(^"B`@("`@*B`@/&-O9&4^)4,\+V-O9&4^($1A>7,@=VET:"!T:6UE+"!S
M86UE(&%S("(E1"P@)4@Z)4TZ)5,B+CQB<CX*("`@("`J("`\8V]D93XE9#PO
M8V]D93X@5&]T86P@9&%Y<R!A<R!A(&9L;V%T(&YU;6)E<@H@("`@("H@("`@
M("`@("`@("`@("`@("`H,B!D87ES+"`Q,B!H;W5R<R`](#(N-2!D87ES*2X\
M8G(^"B`@("`@*B`@/&-O9&4^)40\+V-O9&4^($1A>7,@87,@82!D96-I;6%L
M(&YU;6)E<BX\8G(^"B`@("`@*B`@/&-O9&4^)64\+V-O9&4^(%1O=&%L(&AO
M=7)S(&%S(&$@9FQO870@;G5M8F5R"B`@("`@*B`@("`@("`@("`@("`@("`@
M("@Q(&1A>2P@,B!H;W5R<RP@,S`@;6EN=71E<R`](#(V+C4@:&]U<G,I+CQB
M<CX*("`@("`J("`\8V]D93XE9CPO8V]D93X@5&]T86P@;6EN=71E<R!A<R!A
M(&9L;V%T(&YU;6)E<@H@("`@("H@("`@("`@("`@("`@("`@("`H,B!M:6YU
M=&5S+"`S,"!S96-O;F1S(#T@,BXU(&UI;G5T97,I+CQB<CX*("`@("`J("`\
M8V]D93XE9SPO8V]D93X@5&]T86P@<V5C;VYD<R!A<R!A(&1E8VEM86P@;G5M
M8F5R"B`@("`@*B`@("`@("`@("`@("`@("`@("@R(&UI;G5T97,L(#,P('-E
M8V]N9',@/2`Y,"!S96-O;F1S*2X\8G(^"B`@("`@*B`@/&-O9&4^)6@\+V-O
M9&4^($AO=7)S(&%S(&1E8VEM86P@;G5M8F5R+CQB<CX*("`@("`J("`\8V]D
M93XE2#PO8V]D93X@2&]U<G,@87,@9&5C:6UA;"!N=6UB97(@;&EM:71E9"!T
M;R`R(&1I9VET<RX\8G(^"B`@("`@*B`@/&-O9&4^)6T\+V-O9&4^($UI;G5T
M97,@87,@82!D96-I;6%L(&YU;6)E<BX\8G(^"B`@("`@*B`@/&-O9&4^)4T\
M+V-O9&4^($UI;G5T97,@87,@82!D96-I;6%L(&YU;6)E<B!L:6UI=&5D('1O
M(#(@9&EG:71S+CQB<CX*("`@("`J("`\8V]D93XE;CPO8V]D93X@3F5W;&EN
M92!C:&%R86-T97(@*%QN*2X\8G(^"B`@("`@*B`@/&-O9&4^)7`\+V-O9&4^
M($5I=&AE<B`G86TG(&]R("=P;2<@9&5P96YD:6YG(&]N('1H92!T:6UE+B!)
M9B`G<&TG"B`@("`@*B`@("`@("`@("`@("`@("`@(&ES(&1E=&5C=&5D(&ET
M(&%D9',@,3(@:&]U<G,@=&\@=&AE(')E<W5L=&EN9R!T:6UE"B`@("`@*B`@
M("`@("`@("`@("`@("`@('-P86X@*'=I=&AO=70@86YY(&-H96-K<RDN(%1H
M:7,@:7,@8V%S90H@("`@("H@("`@("`@("`@("`@("`@("!I;G-E;G-I=&EV
M92X\8G(^"B`@("`@*B`@/&-O9&4^)7(\+V-O9&4^(%1I;64@:6X@86TO<&T@
M;F]T871I;VXL('-A;64@87,@(B5(.B5-.B53("5P(BX\8G(^"B`@("`@*B`@
M/&-O9&4^)5(\+V-O9&4^(%1I;64@:6X@,C0M:&]U<B!N;W1A=&EO;BP@<V%M
M92!A<R`B)4@Z)4TB+CQB<CX*("`@("`J("`\8V]D93XE<SPO8V]D93X@4V5C
M;VYD<R!A<R!A(&1E8VEM86P@;G5M8F5R+CQB<CX*("`@("`J("`\8V]D93XE
M4SPO8V]D93X@4V5C;VYD<R!A<R!A(&1E8VEM86P@;G5M8F5R(&QI;6ET960@
M=&\@,B!D:6=I=',N/&)R/@H@("`@("H@(#QC;V1E/B5T/"]C;V1E/B!486(@
M8VAA<F%C=&5R("A<="DN/&)R/@H@("`@("H@(#QC;V1E/B54/"]C;V1E/B!#
M=7)R96YT('1I;64@97%U:79A;&5N="P@<V%M92!A<R`B)4@Z)4TZ)5,B+CQB
M<CX*("`@("`J("`\8V]D93XE)3PO8V]D93X@3&ET97)A;"`G)2<N/&)R/@H@
M("`@("H*("`@("`J($!P87)A;2`@<W1R:6YG("1T:6UE("`@4W1R:6YG(&9R
M;VT@=VAE<F4@=&\@9V5T('1H92!T:6UE('-P86X*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@:6YF;W)M871I;VXN"B`@("`@*B!`<&%R86T@('-T
M<FEN9R`D9F]R;6%T($9O<FUA="!S=')I;F<N"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L("`@5')U92!O;B!S=6-C97-S+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$9R;VU3=')I
M;F<H)'1I;64L("1F;W)M870@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI
M<U]N=6QL*"1F;W)M870I*2!["B`@("`@("`@("`@("1F;W)M870@/2`D1TQ/
M0D%,4ULG7T1!5$5?4U!!3E])3E!55%]&3U)-050G73L*("`@("`@("!]"B`@
M("`@("`@+R\@268@9F]R;6%T(&ES(&$@<W1R:6YG+"!I="!P87)S97,@=&AE
M('-T<FEN9R!F;W)M870N"B`@("`@("`@:68@*&ES7W-T<FEN9R@D9F]R;6%T
M*2D@>PH@("`@("`@("`@("`D<W1R(#T@)R<["B`@("`@("`@("`@("1V87)S
M(#T@87)R87DH*3L*("`@("`@("`@("`@)'!M(#T@)V%M)SL*("`@("`@("`@
M("`@)&1A>2`]("1H;W5R(#T@)&UI;G5T92`]("1S96-O;F0@/2`P.PH@("`@
M("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S=')L96XH)&9O<FUA="D[("1I
M*RLI('L*("`@("`@("`@("`@("`@("1C:&%R(#T@)&9O<FUA='LD:7T["B`@
M("`@("`@("`@("`@("!I9B`H)&-H87(@/3T@)R4G*2!["B`@("`@("`@("`@
M("`@("`@("`@)&YE>'1C:&%R(#T@)&9O<FUA='LK*R1I?3L*("`@("`@("`@
M("`@("`@("`@("!S=VET8V@@*"1N97AT8VAA<BD@>PH@("`@("`@("`@("`@
M("`@("`@("`@("!C87-E("=C)SH*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1S='(@+CT@)R5D+"`E9#HE9#HE9"<["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>5]P=7-H*`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1V87)S+"`G9&%Y)RP@)VAO=7(G+"`G;6EN=71E)RP@)W-E
M8V]N9"<I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)T,G.@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'-T<B`N/2`G)60L("4R9#HE,F0Z)3)D)SL*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W!U<V@H"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'9A<G,L("=D87DG+"`G:&]U<B<L
M("=M:6YU=&4G+"`G<V5C;VYD)RD["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G9"<Z
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<W1R("X]("<E9B<["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>5]P=7-H*"1V87)S+"`G
M9&%Y)RD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@("`@("`@("`@("`@8V%S92`G1"<Z"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<W1R("X]("<E9"<["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>5]P=7-H*"1V87)S+"`G9&%Y)RD["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@
M("`@("`@8V%S92`G92<Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<W1R("X]("<E9B<["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>5]P=7-H*"1V87)S+"`G:&]U<B<I.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)V8G
M.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-T<B`N/2`G)68G.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87E?<'5S:"@D=F%R<RP@
M)VUI;G5T92<I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)V<G.@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'-T<B`N/2`G)68G.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87E?<'5S:"@D=F%R<RP@)W-E8V]N9"<I.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("`@("`@("`@(&-A<V4@)V@G.@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'-T<B`N/2`G)60G.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87E?<'5S:"@D=F%R<RP@)VAO=7(G*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C
M87-E("=()SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S='(@+CT@
M)R4R9"<["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>5]P=7-H
M*"1V87)S+"`G:&]U<B<I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)VTG.@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'-T<B`N/2`G)60G.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87E?<'5S:"@D=F%R<RP@)VUI;G5T
M92<I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("`@("`@("`@(&-A<V4@)TTG.@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'-T<B`N/2`G)3)D)SL*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y7W!U<V@H)'9A<G,L("=M:6YU=&4G*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M("`@("`@("!C87-E("=N)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1S='(@+CT@(EQN(CL*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E("=P)SH*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1S='(@+CT@)R4R<R<["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>5]P=7-H*"1V87)S+"`G<&TG*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("`@("`@("`@("`@("!C87-E("=R)SH*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1S='(@+CT@)R4R9#HE,F0Z)3)D("4R<R<["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>5]P=7-H*`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1V87)S+"`G:&]U<B<L("=M:6YU=&4G+"`G<V5C
M;VYD)RP@)W!M)RD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G4B<Z"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<W1R("X]("<E,F0Z)3)D)SL*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W!U<V@H)'9A<G,L("=H;W5R
M)RP@)VUI;G5T92<I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)W,G.@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'-T<B`N/2`G)60G.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@87)R87E?<'5S:"@D=F%R<RP@)W-E8V]N9"<I
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@("`@("`@("`@("`@(&-A<V4@)U,G.@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'-T<B`N/2`G)3)D)SL*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y7W!U<V@H)'9A<G,L("=S96-O;F0G*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@
M("`@("!C87-E("=T)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S
M='(@+CT@(EQT(CL*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E("=4)SH*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1S='(@+CT@)R4R9#HE,F0Z)3)D)SL*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W!U<V@H)'9A<G,L("=H
M;W5R)RP@)VUI;G5T92<L("=S96-O;F0G*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E
M("<E)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S='(@+CT@(B4B
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@("`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<W1R("X]("1C:&%R("X@)&YE>'1C:&%R.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@)'-T<B`N/2`D8VAA<CL*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D=F%L<R`]('-S8V%N9B@D=&EM
M92P@)'-T<BD["B`@("`@("`@("`@(&9O<F5A8V@@*"1V86QS(&%S("1I(#T^
M("1V86PI('L*("`@("`@("`@("`@("`@(&EF("AI<U]N=6QL*"1V86PI*2![
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@)"1V87)S6R1I72`]("1V86P["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*'-T<F-A<V5C;7`H)'!M+"`G
M<&TG*2`]/2`P*2!["B`@("`@("`@("`@("`@("`D:&]U<B`K/2`Q,CL*("`@
M("`@("`@("`@?2!E;'-E:68@*'-T<F-A<V5C;7`H)'!M+"`G86TG*2`A/2`P
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)'1H:7,M/G-E=$9R;VU!<G)A>2AA<G)A>2@D9&%Y
M+"`D:&]U<BP@)&UI;G5T92P@)'-E8V]N9"DI.PH@("`@("`@("\O($EF(&9O
M<FUA="!I<R!A(&EN=&5G97(L(&ET('5S97,@82!P<F5D969I;F5D(&9O<FUA
M=`H@("`@("`@("\O(&1E=&5C=&EO;B!M971H;V0N"B`@("`@("`@?2!E;'-E
M:68@*&ES7VEN=&5G97(H)&9O<FUA="DI('L*("`@("`@("`@("`@<W=I=&-H
M("@D9F]R;6%T*2!["B`@("`@("`@("`@("`@("!C87-E($1!5$5?4U!!3E])
M3E!55%]&3U)-051?3DY35CH*("`@("`@("`@("`@("`@("`@("`D=&EM92`]
M('!R96=?<W!L:70H)R]<1"LO)RP@)'1I;64I.PH@("`@("`@("`@("`@("`@
M("`@('-W:71C:"`H8V]U;G0H)'1I;64I*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@(&-A<V4@,#H*("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<V5T1G)O;4%R<F%Y*`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*#`L(#`L(#`L(#`I*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@8V%S92`Q.@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YS971&<F]M07)R87DH"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@87)R87DH,"P@)'1I;65;,%TL(#`L(#`I*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`R.@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YS971&<F]M07)R87DH"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH,"P@)'1I;65;
M,%TL("1T:6UE6S%=+"`P*2D["B`@("`@("`@("`@("`@("`@("`@("`@(&-A
M<V4@,SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<V5T1G)O;4%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y*#`L("1T:6UE6S!=+"`D=&EM95LQ72P@)'1I;65;,ETI*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<V5T1G)O;4%R<F%Y*"1T
M:6UE*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!T:6UE
M('-P86X@9G)O;2!A('1O=&%L(&YU;6)E<B!O9B!S96-O;F1S+@H@("`@("H*
M("`@("`J($!P87)A;2`@:6YT("`D<V5C;VYD<R!4;W1A;"!N=6UB97(@;V8@
M<V5C;VYD<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@5')U92!O;B!S
M=6-C97-S+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-E=$9R;VU396-O;F1S*"1S96-O;F1S*0H@("`@>PH@
M("`@("`@(&EF("@D<V5C;VYD<R`\(#`I('L*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@('T*("`@("`@("`D<V5C("`](&EN='9A;"@D<V5C
M;VYD<RD["B`@("`@("`@)&UI;B`@/2!F;&]O<B@D<V5C("\@-C`I.PH@("`@
M("`@("1H;W5R(#T@9FQO;W(H)&UI;B`O(#8P*3L*("`@("`@("`D9&%Y("`]
M(&EN='9A;"AF;&]O<B@D:&]U<B`O(#(T*2D["B`@("`@("`@)'1H:7,M/G-E
M8V]N9"`]("1S96,@)2`V,#L*("`@("`@("`D=&AI<RT^;6EN=71E(#T@)&UI
M;B`E(#8P.PH@("`@("`@("1T:&ES+3YH;W5R("`@/2`D:&]U<B`E(#(T.PH@
M("`@("`@("1T:&ES+3YD87D@("`@/2`D9&%Y.PH@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!T:6UE('-P86X@
M9G)O;2!A('1O=&%L(&YU;6)E<B!O9B!M:6YU=&5S+@H@("`@("H*("`@("`J
M($!P87)A;2`@9FQO870@)&UI;G5T97,@5&]T86P@;G5M8F5R(&]F(&UI;G5T
M97,N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L("!4<G5E(&]N('-U8V-E
M<W,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@<V5T1G)O;4UI;G5T97,H)&UI;G5T97,I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3YS971&<F]M4V5C;VYD<RAR;W5N9"@D;6EN=71E
M<R`J(#8P*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE('1I;64@
M<W!A;B!F<F]M(&$@=&]T86P@;G5M8F5R(&]F(&AO=7)S+@H@("`@("H*("`@
M("`J($!P87)A;2`@9FQO870@)&AO=7)S(%1O=&%L(&YU;6)E<B!O9B!H;W5R
M<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@(%1R=64@;VX@<W5C8V5S
M<RX*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F
M=6YC=&EO;B!S971&<F]M2&]U<G,H)&AO=7)S*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^<V5T1G)O;5-E8V]N9',H<F]U;F0H)&AO=7)S("H@,S8P
M,"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!T:6UE('-P86X@
M9G)O;2!A('1O=&%L(&YU;6)E<B!O9B!D87ES+@H@("`@("H*("`@("`J($!P
M87)A;2`@9FQO870@)&1A>7,@5&]T86P@;G5M8F5R(&]F(&1A>7,N"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L("!4<G5E(&]N('-U8V-E<W,N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@
M<V5T1G)O;41A>7,H)&1A>7,I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3YS971&<F]M4V5C;VYD<RAR;W5N9"@D9&%Y<R`J(#@V-#`P*2D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!3970@=&AE('-P86X@9G)O;2!T:&4@96QA<'-E
M9"!T:6UE(&)E='=E96X@='=O(&1A=&5S+@H@("`@("H*("`@("`J(%-E="!T
M:&4@<W!A;B!F<F]M('1H92!E;&%P<V5D('1I;64@8F5T=V5E;B!T=V\@9&%T
M97,N(%1H92!T:6UE('-P86X*("`@("`J(&ES(&%L;'=A>7,@<&]S:71I=F4L
M('-O('1H92!D871E)W,@;W)D97(@:7,@;F]T(&EM<&]R=&%N="X*("`@("`J
M"B`@("`@*B!`<&%R86T@(&]B:F5C="!$871E("1D871E,2!&:7)S="!$871E
M+@H@("`@("H@0'!A<F%M("!O8FIE8W0@1&%T92`D9&%T93(@4V5C;VYD($1A
M=&4N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L("!4<G5E(&]N('-U8V-E
M<W,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@<V5T1G)O;41A=&5$:69F*"1D871E,2P@)&1A=&4R*0H@("`@
M>PH@("`@("`@(&EF("@A:7-?82@D9&%T93$L("=D871E)RD@;W(@(6ES7V$H
M)&1A=&4R+"`G9&%T92<I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!]"B`@("`@("`@)&1A=&4Q+3YT;U540R@I.PH@("`@("`@("1D
M871E,BT^=&]55$,H*3L*("`@("`@("!I9B`H)&1A=&4Q+3YA9G1E<B@D9&%T
M93(I*2!["B`@("`@("`@("`@(&QI<W0H)&1A=&4Q+"`D9&%T93(I(#T@87)R
M87DH)&1A=&4R+"`D9&%T93$I.PH@("`@("`@('T*("`@("`@("`D9&%Y<R`]
M($1A=&5?0V%L8SHZ9&%T941I9F8H"B`@("`@("`@("`@("1D871E,2T^9V5T
M1&%Y*"DL("1D871E,2T^9V5T36]N=&@H*2P@)&1A=&4Q+3YG971996%R*"DL
M"B`@("`@("`@("`@("1D871E,BT^9V5T1&%Y*"DL("1D871E,BT^9V5T36]N
M=&@H*2P@)&1A=&4R+3YG971996%R*"D*("`@("`@("`I.PH@("`@("`@("1H
M;W5R<R`]("1D871E,BT^9V5T2&]U<B@I("T@)&1A=&4Q+3YG971(;W5R*"D[
M"B`@("`@("`@)&UI;G,@(#T@)&1A=&4R+3YG971-:6YU=&4H*2`M("1D871E
M,2T^9V5T36EN=71E*"D["B`@("`@("`@)'-E8W,@(#T@)&1A=&4R+3YG9713
M96-O;F0H*2`M("1D871E,2T^9V5T4V5C;VYD*"D["B`@("`@("`@)'1H:7,M
M/G-E=$9R;VU396-O;F1S*`H@("`@("`@("`@("`D9&%Y<R`J(#@V-#`P("L@
M)&AO=7)S("H@,S8P,"`K("1M:6YS("H@-C`@*R`D<V5C<PH@("`@("`@("D[
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M970@=&AE('1I;64@<W!A;B!F<F]M(&%N;W1H97(@=&EM92!O8FIE8W0N"B`@
M("`@*@H@("`@("H@0'!A<F%M("!O8FIE8W0@1&%T95]3<&%N("1T:6UE(%-O
M=7)C92!T:6UE('-P86X@;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@
M8F]O;"`@(%1R=64@;VX@<W5C8V5S<RX*("`@("`J"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!C;W!Y*"1T:6UE*0H@("`@
M>PH@("`@("`@(&EF("AI<U]A*"1T:6UE+"`G9&%T95]S<&%N)RDI('L*("`@
M("`@("`@("`@)'1H:7,M/G-E8V]N9"`]("1T:6UE+3YS96-O;F0["B`@("`@
M("`@("`@("1T:&ES+3YM:6YU=&4@/2`D=&EM92T^;6EN=71E.PH@("`@("`@
M("`@("`D=&AI<RT^:&]U<B`@(#T@)'1I;64M/FAO=7(["B`@("`@("`@("`@
M("1T:&ES+3YD87D@("`@/2`D=&EM92T^9&%Y.PH@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@5&EM92!S
M<&%N('!R971T>2!P<FEN=&EN9R`H<VEM:6QA<B!T;R!$871E.CIF;W)M870H
M*2DN"B`@("`@*@H@("`@("H@1F]R;6%T<R!T:&4@=&EM92!S<&%N(&EN('1H
M92!G:79E;B!F;W)M870L('-I;6EL87(@=&\*("`@("`J('-T<F9T:6UE*"D@
M86YD($1A=&4Z.F9O<FUA="@I+CQB<CX*("`@("`J(#QB<CX*("`@("`J($9O
M<FUA='1I;F<@;W!T:6]N<SH\8G(^"B`@("`@*B`@/&-O9&4^)4,\+V-O9&4^
M($1A>7,@=VET:"!T:6UE+"!S86UE(&%S("(E1"P@)4@Z)4TZ)5,B+CQB<CX*
M("`@("`J("`\8V]D93XE9#PO8V]D93X@5&]T86P@9&%Y<R!A<R!A(&9L;V%T
M(&YU;6)E<@H@("`@("H@("`@("`@("`@("`@("`@("`H,B!D87ES+"`Q,B!H
M;W5R<R`](#(N-2!D87ES*2X\8G(^"B`@("`@*B`@/&-O9&4^)40\+V-O9&4^
M($1A>7,@87,@82!D96-I;6%L(&YU;6)E<BX\8G(^"B`@("`@*B`@/&-O9&4^
M)64\+V-O9&4^(%1O=&%L(&AO=7)S(&%S(&$@9FQO870@;G5M8F5R"B`@("`@
M*B`@("`@("`@("`@("`@("`@("@Q(&1A>2P@,B!H;W5R<RP@,S`@;6EN=71E
M<R`](#(V+C4@:&]U<G,I+CQB<CX*("`@("`J("`\8V]D93XE13PO8V]D93X@
M5&]T86P@:&]U<G,@87,@82!D96-I;6%L(&YU;6)E<@H@("`@("H@("`@("`@
M("`@("`@("`@("`H,2!D87DL(#(@:&]U<G,L(#0P(&UI;G5T97,@/2`R-B!H
M;W5R<RDN/&)R/@H@("`@("H@(#QC;V1E/B5F/"]C;V1E/B!4;W1A;"!M:6YU
M=&5S(&%S(&$@9FQO870@;G5M8F5R"B`@("`@*B`@("`@("`@("`@("`@("`@
M("@R(&UI;G5T97,L(#,P('-E8V]N9',@/2`R+C4@;6EN=71E<RDN/&)R/@H@
M("`@("H@(#QC;V1E/B5&/"]C;V1E/B!4;W1A;"!M:6YU=&5S(&%S(&$@9&5C
M:6UA;"!N=6UB97(*("`@("`J("`@("`@("`@("`@("`@("`@*#$@:&]U<BP@
M,B!M:6YU=&5S+"`T,"!S96-O;F1S(#T@-C(@;6EN=71E<RDN/&)R/@H@("`@
M("H@(#QC;V1E/B5G/"]C;V1E/B!4;W1A;"!S96-O;F1S(&%S(&$@9&5C:6UA
M;"!N=6UB97(*("`@("`J("`@("`@("`@("`@("`@("`@*#(@;6EN=71E<RP@
M,S`@<V5C;VYD<R`](#DP('-E8V]N9',I+CQB<CX*("`@("`J("`\8V]D93XE
M:#PO8V]D93X@2&]U<G,@87,@9&5C:6UA;"!N=6UB97(@*#`@=&\@,C,I+CQB
M<CX*("`@("`J("`\8V]D93XE2#PO8V]D93X@2&]U<G,@87,@9&5C:6UA;"!N
M=6UB97(@*#`P('1O(#(S*2X\8G(^"B`@("`@*B`@/&-O9&4^)6D\+V-O9&4^
M($AO=7)S(&%S(&1E8VEM86P@;G5M8F5R(&]N(#$R+6AO=7(@8VQO8VL*("`@
M("`J("`@("`@("`@("`@("`@("`@*#$@=&\@,3(I+CQB<CX*("`@("`J("`\
M8V]D93XE23PO8V]D93X@2&]U<G,@87,@9&5C:6UA;"!N=6UB97(@;VX@,3(M
M:&]U<B!C;&]C:PH@("`@("H@("`@("`@("`@("`@("`@("`H,#$@=&\@,3(I
M+CQB<CX*("`@("`J("`\8V]D93XE;3PO8V]D93X@36EN=71E<R!A<R!A(&1E
M8VEM86P@;G5M8F5R("@P('1O(#4Y*2X\8G(^"B`@("`@*B`@/&-O9&4^)4T\
M+V-O9&4^($UI;G5T97,@87,@82!D96-I;6%L(&YU;6)E<B`H,#`@=&\@-3DI
M+CQB<CX*("`@("`J("`\8V]D93XE;CPO8V]D93X@3F5W;&EN92!C:&%R86-T
M97(@*%QN*2X\8G(^"B`@("`@*B`@/&-O9&4^)7`\+V-O9&4^($5I=&AE<B`G
M86TG(&]R("=P;2<@9&5P96YD:6YG(&]N('1H92!T:6UE+CQB<CX*("`@("`J
M("`\8V]D93XE4#PO8V]D93X@16ET:&5R("=!32<@;W(@)U!-)R!D97!E;F1I
M;F<@;VX@=&AE('1I;64N/&)R/@H@("`@("H@(#QC;V1E/B5R/"]C;V1E/B!4
M:6UE(&EN(&%M+W!M(&YO=&%T:6]N+"!S86UE(&%S("(E23HE33HE4R`E<"(N
M/&)R/@H@("`@("H@(#QC;V1E/B52/"]C;V1E/B!4:6UE(&EN(#(T+6AO=7(@
M;F]T871I;VXL('-A;64@87,@(B5(.B5-(BX\8G(^"B`@("`@*B`@/&-O9&4^
M)7,\+V-O9&4^(%-E8V]N9',@87,@82!D96-I;6%L(&YU;6)E<B`H,"!T;R`U
M.2DN/&)R/@H@("`@("H@(#QC;V1E/B53/"]C;V1E/B!396-O;F1S(&%S(&$@
M9&5C:6UA;"!N=6UB97(@*#`P('1O(#4Y*2X\8G(^"B`@("`@*B`@/&-O9&4^
M)70\+V-O9&4^(%1A8B!C:&%R86-T97(@*%QT*2X\8G(^"B`@("`@*B`@/&-O
M9&4^)50\+V-O9&4^($-U<G)E;G0@=&EM92!E<75I=F%L96YT+"!S86UE(&%S
M("(E2#HE33HE4R(N/&)R/@H@("`@("H@(#QC;V1E/B4E/"]C;V1E/B!,:71E
M<F%L("<E)RX\8G(^"B`@("`@*@H@("`@("H@0'!A<F%M("!S=')I;F<@)&9O
M<FUA="!4:&4@9F]R;6%T('-T<FEN9R!F;W(@<F5T=7)N960@=&EM92!S<&%N
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG(%1H92!T:6UE('-P86X@
M:6X@<W!E8VEF:65D(&9O<FUA="X*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!F;W)M870H)&9O<FUA="`](&YU
M;&PI"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)&9O<FUA="DI('L*("`@
M("`@("`@("`@)&9O<FUA="`]("1'3$]"04Q36R=?1$%415]34$%.7T9/4DU!
M5"==.PH@("`@("`@('T*("`@("`@("`D;W5T<'5T(#T@)R<["B`@("`@("`@
M9F]R("@D:2`](#`[("1I(#P@<W1R;&5N*"1F;W)M870I.R`D:2LK*2!["B`@
M("`@("`@("`@("1C:&%R(#T@)&9O<FUA='LD:7T["B`@("`@("`@("`@(&EF
M("@D8VAA<B`]/2`G)2<I('L*("`@("`@("`@("`@("`@("1N97AT8VAA<B`]
M("1F;W)M871[*RLD:7T["B`@("`@("`@("`@("`@("!S=VET8V@@*"1N97AT
M8VAA<BD@>PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)T,G.@H@("`@("`@
M("`@("`@("`@("`@("`@("`D;W5T<'5T("X]('-P<FEN=&8H"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G)60L("4P,F0Z)3`R9#HE,#)D)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YD87DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^:&]U<BP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YM:6YU=&4L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^<V5C;VYD"B`@("`@("`@("`@("`@("`@
M("`@("`@("D["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@("`@(&-A<V4@)V0G.@H@("`@("`@("`@("`@("`@("`@
M("`@("`D;W5T<'5T("X]("1T:&ES+3YT;T1A>7,H*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@8V%S92`G
M1"<Z"B`@("`@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@)'1H:7,M
M/F1A>3L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@("`@("`@("`@8V%S92`G92<Z"B`@("`@("`@("`@("`@("`@("`@("`@
M("1O=71P=70@+CT@)'1H:7,M/G1O2&]U<G,H*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@8V%S92`G12<Z
M"B`@("`@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@9FQO;W(H)'1H
M:7,M/G1O2&]U<G,H*2D["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)V8G.@H@("`@("`@("`@("`@
M("`@("`@("`@("`D;W5T<'5T("X]("1T:&ES+3YT;TUI;G5T97,H*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@
M("`@8V%S92`G1B<Z"B`@("`@("`@("`@("`@("`@("`@("`@("1O=71P=70@
M+CT@9FQO;W(H)'1H:7,M/G1O36EN=71E<R@I*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@8V%S92`G9R<Z
M"B`@("`@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@)'1H:7,M/G1O
M4V5C;VYD<R@I.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@("`@("`@("!C87-E("=H)SH*("`@("`@("`@("`@("`@("`@
M("`@("`@)&]U='!U="`N/2`D=&AI<RT^:&]U<CL*("`@("`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@8V%S92`G2"<Z
M"B`@("`@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@<W!R:6YT9B@G
M)3`R9"<L("1T:&ES+3YH;W5R*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@("`@("`@("`@8V%S92`G:2<Z"B`@("`@("`@
M("`@("`@("`@("`@("`@("1H;W5R(#T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("@D=&AI<RT^:&]U<B`K(#$I(#X@,3(@/PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/FAO=7(@+2`Q,B`Z"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^:&]U<CL*("`@("`@("`@("`@("`@
M("`@("`@("`@)&]U='!U="`N/2`H)&AO=7(@/3T@,"D@/R`Q,B`Z("1H;W5R
M.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M("`@("`@("!C87-E("=))SH*("`@("`@("`@("`@("`@("`@("`@("`@)&AO
M=7(@/0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@*"1T:&ES+3YH;W5R
M("L@,2D@/B`Q,B`_"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^:&]U<B`M(#$R(#H*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YH;W5R.PH@("`@("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]
M('-P<FEN=&8H)R4P,F0G+"`D:&]U<CT],"`_(#$R(#H@)&AO=7(I.PH@("`@
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@
M("!C87-E("=M)SH*("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N
M/2`D=&AI<RT^;6EN=71E.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@("`@("`@("!C87-E("=-)SH*("`@("`@("`@("`@
M("`@("`@("`@("`@)&]U='!U="`N/2!S<')I;G1F*"<E,#)D)RPD=&AI<RT^
M;6EN=71E*3L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("`@("`@8V%S92`G;B<Z"B`@("`@("`@("`@("`@("`@("`@
M("`@("1O=71P=70@+CT@(EQN(CL*("`@("`@("`@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@("`@("`@("`@8V%S92`G<"<Z"B`@("`@("`@
M("`@("`@("`@("`@("`@("1O=71P=70@+CT@)'1H:7,M/FAO=7(@/CT@,3(@
M/R`G<&TG(#H@)V%M)SL*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@("`@("`@("`@8V%S92`G4"<Z"B`@("`@("`@("`@("`@
M("`@("`@("`@("1O=71P=70@+CT@)'1H:7,M/FAO=7(@/CT@,3(@/R`G4$TG
M(#H@)T%-)SL*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("`@("`@8V%S92`G<B<Z"B`@("`@("`@("`@("`@("`@("`@
M("`@("1H;W5R(#T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("@D=&AI
M<RT^:&]U<B`K(#$I(#X@,3(@/PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/FAO=7(@+2`Q,B`Z"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^:&]U<CL*("`@("`@("`@("`@("`@("`@("`@("`@)&]U
M='!U="`N/2!S<')I;G1F*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)R4P,F0Z)3`R9#HE,#)D("5S)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1H;W5R/3TP(#\@(#$R(#H@)&AO=7(L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^;6EN=71E+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/G-E8V]N9"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YH;W5R(#X](#$R(#\@)W!M)R`Z("=A;2<*("`@("`@
M("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@("`@("`@("`@8V%S92`G4B<Z"B`@("`@("`@
M("`@("`@("`@("`@("`@("1O=71P=70@+CT@<W!R:6YT9B@*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("<E,#)D.B4P,F0G+"`D=&AI<RT^:&]U<BP@
M)'1H:7,M/FUI;G5T90H@("`@("`@("`@("`@("`@("`@("`@("`I.PH@("`@
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@
M("!C87-E("=S)SH*("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N
M/2`D=&AI<RT^<V5C;VYD.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@("`@("`@("!C87-E("=3)SH*("`@("`@("`@("`@
M("`@("`@("`@("`@)&]U='!U="`N/2!S<')I;G1F*"<E,#)D)RP@)'1H:7,M
M/G-E8V]N9"D["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@("`@(&-A<V4@)W0G.@H@("`@("`@("`@("`@("`@("`@
M("`@("`D;W5T<'5T("X](")<="(["B`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)U0G.@H@("`@("`@
M("`@("`@("`@("`@("`@("`D;W5T<'5T("X]('-P<FEN=&8H"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G)3`R9#HE,#)D.B4P,F0G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FAO=7(L("1T:&ES+3YM:6YU
M=&4L("1T:&ES+3YS96-O;F0*("`@("`@("`@("`@("`@("`@("`@("`@*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("`@("`@8V%S92`G)2<Z"B`@("`@("`@("`@("`@("`@("`@("`@("1O=71P
M=70@+CT@(B4B.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@("`@
M("`@("`D;W5T<'5T("X]("1C:&%R("X@)&YE>'1C:&%R.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)&]U='!U="`N/2`D8VAA<CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M("`@("!R971U<FX@)&]U='!U=#L*("`@('T*"B`@("`O*BH*("`@("`J($-O
M;G9E<G0@=&EM92!S<&%N('1O('-E8V]N9',N"B`@("`@*@H@("`@("H@0')E
M='5R;B!I;G0@5&EM92!S<&%N(&%S(&%N(&EN=&5G97(@;G5M8F5R(&]F('-E
M8V]N9',N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@=&]396-O;F1S*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/F1A>2`J(#@V-#`P("L@)'1H:7,M/FAO=7(@*B`S-C`P("L*("`@
M("`@("`@("`@)'1H:7,M/FUI;G5T92`J(#8P("L@)'1H:7,M/G-E8V]N9#L*
M("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E<G0@=&EM92!S<&%N('1O(&UI
M;G5T97,N"B`@("`@*@H@("`@("H@0')E='5R;B!F;&]A="!4:6UE('-P86X@
M87,@82!D96-I;6%L(&YU;6)E<B!O9B!M:6YU=&5S+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('1O36EN=71E
M<R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YD87D@*B`Q-#0P("L@
M)'1H:7,M/FAO=7(@*B`V,"`K("1T:&ES+3YM:6YU=&4@*PH@("`@("`@("`@
M("`D=&AI<RT^<V5C;VYD("\@-C`["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M;VYV97)T('1I;64@<W!A;B!T;R!H;W5R<RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&9L;V%T(%1I;64@<W!A;B!A<R!A(&1E8VEM86P@;G5M8F5R(&]F(&AO
M=7)S+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@
M(&9U;F-T:6]N('1O2&]U<G,H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^9&%Y("H@,C0@*R`D=&AI<RT^:&]U<B`K("1T:&ES+3YM:6YU=&4@+R`V
M,"`K"B`@("`@("`@("`@("1T:&ES+3YS96-O;F0@+R`S-C`P.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0V]N=F5R="!T:6UE('-P86X@=&\@9&%Y<RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&9L;V%T(%1I;64@<W!A;B!A<R!A(&1E8VEM
M86P@;G5M8F5R(&]F(&1A>7,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J+PH@("`@9G5N8W1I;VX@=&]$87ES*"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/F1A>2`K("1T:&ES+3YH;W5R("\@,C0@*R`D=&AI
M<RT^;6EN=71E("\@,30T,"`K"B`@("`@("`@("`@("1T:&ES+3YS96-O;F0@
M+R`X-C0P,#L*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@82!T:6UE('-P
M86XN"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE8W0@1&%T95]3<&%N("1T
M:6UE(%1I;64@<W!A;B!T;R!A9&0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@861D*"1T:6UE*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^<V5T1G)O;5-E8V]N9',H"B`@("`@("`@
M("`@("1T:&ES+3YT;U-E8V]N9',H*2`K("1T:6UE+3YT;U-E8V]N9',H*0H@
M("`@("`@("D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3=6)T<F%C=',@82!T
M:6UE('-P86XN"B`@("`@*@H@("`@("H@4W5B=')A8W1S(&$@=&EM92!S<&%N
M+B!)9B!T:&4@=&EM92!S<&%N('1O('-U8G1R86-T(&ES(&QA<F=E<@H@("`@
M("H@=&AA;B!T:&4@;W)I9VEN86PL('1H92!R97-U;'0@:7,@>F5R;R`H=&AE
M<F4G<R!N;R!S96YS92!I;@H@("`@("H@;F5G871I=F4@=&EM92!S<&%N<RDN
M"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE8W0@1&%T95]3<&%N("1T:6UE
M(%1I;64@<W!A;B!T;R!S=6)T<F%C="X*("`@("`J"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!S=6)T<F%C="@D=&EM92D*
M("`@('L*("`@("`@("`D<W5B(#T@)'1H:7,M/G1O4V5C;VYD<R@I("T@)'1I
M;64M/G1O4V5C;VYD<R@I.PH@("`@("`@(&EF("@D<W5B(#P@,"D@>PH@("`@
M("`@("`@("`D=&AI<RT^<V5T1G)O;5-E8V]N9',H,"D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'1H:7,M/G-E=$9R;VU396-O;F1S*"1S=6(I
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%1E;&QS(&EF('1I
M;64@<W!A;B!I<R!E<75A;"!T;R`D=&EM92X*("`@("`J"B`@("`@*B!`<&%R
M86T@(&]B:F5C="!$871E7U-P86X@)'1I;64@5&EM92!S<&%N('1O(&-O;7!A
M<F4@=&\N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L("`@5')U92!I9B!T
M:&4@=&EM92!S<&%N<R!A<F4@97%U86PN"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@97%U86PH)'1I;64I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YT;U-E8V]N9',H*2`]/2`D=&EM
M92T^=&]396-O;F1S*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!496QL<R!I
M9B!T:&ES('1I;64@<W!A;B!I<R!G<F5A=&5R(&]R(&5Q=6%L('1H86X@)'1I
M;64N"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE8W0@1&%T95]3<&%N("1T
M:6UE(%1I;64@<W!A;B!T;R!C;VUP87)E('1O+@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;"`@(%1R=64@:68@=&AI<R!T:6UE('-P86X@:7,@9W)E871E
M<B!O<B!E<75A;"!T:&%N("1T:6UE+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=R96%T97)%<75A;"@D=&EM
M92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G1O4V5C;VYD<R@I(#X]
M("1T:6UE+3YT;U-E8V]N9',H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1E
M;&QS(&EF('1H:7,@=&EM92!S<&%N(&ES(&QO=V5R(&]R(&5Q=6%L('1H86X@
M)'1I;64N"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE8W0@1&%T95]3<&%N
M("1T:6UE(%1I;64@<W!A;B!T;R!C;VUP87)E('1O+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;"`@(%1R=64@:68@=&AI<R!T:6UE('-P86X@:7,@;&]W
M97(@;W(@97%U86P@=&AA;B`D=&EM92X*("`@("`J"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!L;W=E<D5Q=6%L*"1T:6UE
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^=&]396-O;F1S*"D@/#T@
M)'1I;64M/G1O4V5C;VYD<R@I.PH@("`@?0H*("`@("\J*@H@("`@("H@5&5L
M;',@:68@=&AI<R!T:6UE('-P86X@:7,@9W)E871E<B!T:&%N("1T:6UE+@H@
M("`@("H*("`@("`J($!P87)A;2`@;V)J96-T($1A=&5?4W!A;B`D=&EM92!4
M:6UE('-P86X@=&\@8V]M<&%R92!T;RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VP@("!4<G5E(&EF('1H:7,@=&EM92!S<&%N(&ES(&=R96%T97(@=&AA
M;B`D=&EM92X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!G<F5A=&5R*"1T:6UE*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^=&]396-O;F1S*"D@/B`D=&EM92T^=&]396-O;F1S*"D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!496QL<R!I9B!T:&ES('1I;64@<W!A
M;B!I<R!L;W=E<B!T:&%N("1T:6UE+@H@("`@("H*("`@("`J($!P87)A;2`@
M;V)J96-T($1A=&5?4W!A;B`D=&EM92!4:6UE('-P86X@=&\@8V]M<&%R92!T
M;RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@("!4<G5E(&EF('1H:7,@
M=&EM92!S<&%N(&ES(&QO=V5R('1H86X@)'1I;64N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@;&]W97(H)'1I
M;64I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YT;U-E8V]N9',H*2`\
M("1T:6UE+3YT;U-E8V]N9',H*3L*("`@('T*"B`@("`O*BH*("`@("`J($-O
M;7!A<F5S('1W;R!T:6UE('-P86YS+@H@("`@("H*("`@("`J($-O;7!A<F5S
M('1W;R!T:6UE('-P86YS+B!3=6ET86)L92!F;W(@=7-E(&EN('-O<G1I;F<@
M9G5N8W1I;VYS+@H@("`@("H*("`@("`J($!P87)A;2`@;V)J96-T($1A=&5?
M4W!A;B`D=&EM93$@5&AE(&9I<G-T('1I;64@<W!A;BX*("`@("`J($!P87)A
M;2`@;V)J96-T($1A=&5?4W!A;B`D=&EM93(@5&AE('-E8V]N9"!T:6UE('-P
M86XN"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@("`@,"!I9B!T:&4@=&EM
M92!S<&%N<R!A<F4@97%U86PL("TQ(&EF('1I;64Q(&ES(&QO=V5R"B`@("`@
M*B`@("`@("`@("`@("`@("!T:&%N('1I;64R+"`Q(&EF('1I;64Q(&ES(&=R
M96%T97(@=&AA;B!T:6UE,BX*("`@("`J"B`@("`@*B!`<W1A=&EC"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!C;VUP87)E
M*"1T:6UE,2P@)'1I;64R*0H@("`@>PH@("`@("`@(&EF("@D=&EM93$M/F5Q
M=6%L*"1T:6UE,BDI('L*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@
M?2!E;'-E:68@*"1T:6UE,2T^;&]W97(H)'1I;64R*2D@>PH@("`@("`@("`@
M("!R971U<FX@+3$["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N(#$["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@5&5L;',@
M:68@=&AE('1I;64@<W!A;B!I<R!E;7!T>2`H>F5R;R!L96YG=&@I+@H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;"!4<G5E(&ES(&ET)W,@96UP='DN"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&ES16UP='DH*0H@("`@>PH@("`@("`@(')E
M='5R;B`A)'1H:7,M/F1A>2`F)B`A)'1H:7,M/FAO=7(@)B8@(21T:&ES+3YM
M:6YU=&4@)B8@(21T:&ES+3YS96-O;F0["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!3970@=&AE(&1E9F%U;'0@:6YP=70@9F]R;6%T+@H@("`@("H*("`@("`J
M($!P87)A;2`@;6EX960@)&9O<FUA="!.97<@9&5F875L="!I;G!U="!F;W)M
M870N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!0<F5V:6]U<R!D969A
M=6QT(&EN<'5T(&9O<FUA="X*("`@("`J"B`@("`@*B!`<W1A=&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E=$1E9F%U;'1);G!U=$9O<FUA="@D9F]R;6%T
M*0H@("`@>PH@("`@("`@("1O;&0@/2`D1TQ/0D%,4ULG7T1!5$5?4U!!3E])
M3E!55%]&3U)-050G73L*("`@("`@("`D1TQ/0D%,4ULG7T1!5$5?4U!!3E])
M3E!55%]&3U)-050G72`]("1F;W)M870["B`@("`@("`@<F5T=7)N("1O;&0[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE(&1E9F%U;'0@:6YP=70@
M9F]R;6%T+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@1&5F875L="!I
M;G!U="!F;W)M870N"B`@("`@*@H@("`@("H@0'-T871I8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!G971$969A=6QT26YP=71&;W)M870H*0H@("`@>PH@("`@
M("`@(')E='5R;B`D1TQ/0D%,4ULG7T1!5$5?4U!!3E])3E!55%]&3U)-050G
M73L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@9&5F875L="!F;W)M
M870N"B`@("`@*@H@("`@("H@0'!A<F%M("!M:7AE9"`D9F]R;6%T($YE=R!D
M969A=6QT(&9O<FUA="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%!R
M979I;W5S(&1E9F%U;'0@9F]R;6%T+@H@("`@("H*("`@("`J($!S=&%T:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@<V5T1&5F875L=$9O<FUA="@D9F]R;6%T
M*0H@("`@>PH@("`@("`@("1O;&0@/2`D1TQ/0D%,4ULG7T1!5$5?4U!!3E]&
M3U)-050G73L*("`@("`@("`D1TQ/0D%,4ULG7T1!5$5?4U!!3E]&3U)-050G
M72`]("1F;W)M870["B`@("`@("`@<F5T=7)N("1O;&0["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!'970@=&AE(&1E9F%U;'0@9F]R;6%T+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@1&5F875L="!F;W)M870N"B`@("`@*@H@("`@
M("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!G971$969A=6QT1F]R
M;6%T*"D*("`@('L*("`@("`@("!R971U<FX@)$=,3T)!3%-;)U]$051%7U-0
M04Y?1D]234%4)UT["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@
M8V]P>2!O9B!T:&4@;V)J96-T("AW;W)K87)R;W5N9"!F;W(@4$A0-2!F;W)W
M87)D(&-O;7!A=&EB:6QI='DI+@H@("`@("H*("`@("`J($!R971U<FX@;V)J
M96-T($1A=&5?4W!A;B!#;W!Y(&]F('1H92!O8FIE8W0N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]?8VQO;F4H*2!["B`@("`@("`@)&,@/2!G971?8VQA<W,H
M)'1H:7,I.PH@("`@("`@("1S(#T@;F5W("1C.PH@("`@("`@("1S+3YD87D@
M("`@/2`D=&AI<RT^9&%Y.PH@("`@("`@("1S+3YH;W5R("`@/2`D=&AI<RT^
M:&]U<CL*("`@("`@("`D<RT^;6EN=71E(#T@)'1H:7,M/FUI;G5T93L*("`@
M("`@("`D<RT^<V5C;VYD(#T@)'1H:7,M/G-E8V]N9#L*("`@("`@("!R971U
M<FX@)',["B`@("!]"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]$871E+U1I;65:;VYE+G!H<```````
M````````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P-#8S,S<S(#$P-3$U
M-#,S-S,Q(#`R,38R-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O
M<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PHO+PHO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y
M.3<M,C`P-2!"86)A($)U96AL97(L(%!I97)R92U!;&%I;B!*;WEE("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!T:&4@3F5W($)31"!L
M:6-E;G-E+"!4:&%T(&ES(&)U;F1L960@('P*+R\@?"!W:71H('1H:7,@<&%C
M:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@879A:6QA8FQE('1H
M<F]U9V@@("`@("!\"B\O('P@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R!\(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D+6QI
M8V5N<V4N<&AP("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED
M(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@;F5W($)31&QI8V5N<V4@86YD
M(&%R92!U;F%B;&4@("!\"B\O('P@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE
M('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@
M?`HO+R!\('!E87(M9&5V0&QI<W1S+G!H<"YN970@<V\@=V4@8V%N(&UA:6P@
M>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R.B!"86)A($)U96AL97(@
M/&)A8F%`8F%B87HN8V]M/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R!\("`@("`@("`@4&EE<G)E+4%L86EN($IO>64@/'!A:F]Y94!P
M:'`N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"@HO*BH*("H@5&EM95IO;F4@<F5P<F5S
M96YT871I;VX@8VQA<W,L(&%L;VYG('=I=&@@=&EM92!Z;VYE(&EN9F]R;6%T
M:6]N(&1A=&$*("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@0&-A
M=&5G;W)Y("`@1&%T92!A;F0@5&EM90H@*B!`<&%C:V%G92`@("!$871E"B`J
M($!A=71H;W(@("`@($)A8F$@0G5E:&QE<B`\8F%B84!B86)A>BYC;VT^"B`J
M($!A=71H;W(@("`@(%!I97)R92U!;&%I;B!*;WEE(#QP86IO>65`<&AP+FYE
M=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U($)A8F$@0G5E:&QE<BP@4&EE
M<G)E+4%L86EN($IO>64*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYO<&5N
M<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($YE=R!"4T0@
M3&EC96YS90H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@5&EM95IO;F4N<&AP
M+'8@,2XQ,2`R,#`U+S$Q+S$U(#`P.C$V.C0P('!A:F]Y92!%>'`@)`H@*B!`
M;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1&%T90H@
M*B\*"B\J*@H@*B!4:6UE6F]N92!R97!R97-E;G1A=&EO;B!C;&%S<RP@86QO
M;F<@=VET:"!T:6UE('IO;F4@:6YF;W)M871I;VX@9&%T80H@*@H@*B!4:&4@
M9&5F875L="!T:6UE>F]N92!I<R!S970@9G)O;2!T:&4@9FER<W0@=F%L:60@
M=&EM97IO;F4@:60@9F]U;F0*("H@:6X@;VYE(&]F('1H92!F;VQL;W=I;F<@
M<&QA8V5S+"!I;B!T:&ES(&]R9&5R.@H@*B`@("L@9VQO8F%L("1?1$%415]4
M24U%6D].15]$149!54Q4"B`J("`@*R!S>7-T96T@96YV:7)O;FUE;G0@=F%R
M:6%B;&4@4$A07U1:"B`J("`@*R!S>7-T96T@96YV:7)O;FUE;G0@=F%R:6%B
M;&4@5%H*("H@("`K('1H92!R97-U;'0@;V8@9&%T92@G5"<I"B`J"B`J($EF
M(&YO('9A;&ED('1I;65Z;VYE(&ED(&ES(&9O=6YD+"!T:&4@9&5F875L="!T
M:6UE>F]N92!I<R!S970@=&\@)U540R<N"B`J(%EO=2!M87D@86QS;R!M86YU
M86QL>2!S970@=&AE(&1E9F%U;'0@=&EM97IO;F4@8GD@<&%S<VEN9R!A('9A
M;&ED(&ED('1O"B`J($1A=&5?5&EM95IO;F4Z.G-E=$1E9F%U;'0H*2X*("H*
M("H@5&AI<R!C;&%S<R!I;F-L=61E<R!T:6UE('IO;F4@9&%T82`H9G)O;2!Z
M;VYE:6YF;RD@:6X@=&AE(&9O<FT@;V8@80H@*B!G;&]B86P@87)R87DL("1?
M1$%415]424U%6D].15]$051!+@H@*@H@*B!`875T:&]R("`@("!"86)A($)U
M96AL97(@/&)A8F%`8F%B87HN8V]M/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P
M,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+F]P
M96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@3F5W($)3
M1"!,:6-E;G-E"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XV"B`J($!L
M:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$871E"B`J
M+PIC;&%S<R!$871E7U1I;65:;VYE"GL*("`@("\J*@H@("`@("H@5&EM92!:
M;VYE($E$(&]F('1H:7,@=&EM92!Z;VYE"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("HO"B`@("!V87(@)&ED.PH@("`@+RHJ"B`@("`@*B!,;VYG($YA;64@
M;V8@=&AI<R!T:6UE('IO;F4@*&EE($-E;G1R86P@4W1A;F1A<F0@5&EM92D*
M("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D;&]N9VYA;64[
M"B`@("`O*BH*("`@("`J(%-H;W)T($YA;64@;V8@=&AI<R!T:6UE('IO;F4@
M*&EE($-35"D*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D
M<VAO<G1N86UE.PH@("`@+RHJ"B`@("`@*B!T<G5E(&EF('1H:7,@=&EM92!Z
M;VYE(&]B<V5R=F5S(&1A>6QI9VAT('-A=FEN9W,@=&EM90H@("`@("H@0'9A
M<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D:&%S9'-T.PH@("`@+RHJ"B`@
M("`@*B!$4U0@3&]N9R!.86UE(&]F('1H:7,@=&EM92!Z;VYE"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)&1S=&QO;F=N86UE.PH@("`@
M+RHJ"B`@("`@*B!$4U0@4VAO<G0@3F%M92!O9B!T:&ES('1I;65Z;VYE"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)&1S='-H;W)T;F%M
M93L*("`@("\J*@H@("`@("H@;V9F<V5T+"!I;B!M:6QL:7-E8V]N9',L(&]F
M('1H:7,@=&EM97IO;F4*("`@("`J($!V87(@:6YT"B`@("`@*B\*("`@('9A
M<B`D;V9F<V5T.PH*("`@("\J*@H@("`@("H@4WES=&5M($1E9F%U;'0@5&EM
M92!:;VYE"B`@("`@*B!`=F%R(&]B:F5C="!$871E7U1I;65:;VYE"B`@("`@
M*B\*("`@('9A<B`D9&5F875L=#L*"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U
M8W1O<@H@("`@("H*("`@("`J($-R96%T97,@82!N97<@1&%T93HZ5&EM95IO
M;F4@;V)J96-T+"!R97!R97-E;G1I;F<@=&AE('1I;64@>F]N90H@("`@("H@
M<W!E8VEF:65D(&EN("1I9"X@($EF('1H92!S=7!P;&EE9"!)1"!I<R!I;G9A
M;&ED+"!T:&4@8W)E871E9`H@("`@("H@=&EM92!Z;VYE(&ES(%540RX*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M('-T<FEN
M9R`D:60@=&AE('1I;64@>F]N92!I9`H@("`@("H@0')E='5R;B!O8FIE8W0@
M1&%T95]4:6UE6F]N92!T:&4@;F5W($1A=&5?5&EM95IO;F4@;V)J96-T"B`@
M("`@*B\*("`@(&9U;F-T:6]N($1A=&5?5&EM95IO;F4H)&ED*0H@("`@>PH@
M("`@("`@(&=L;V)A;"`D7T1!5$5?5$E-15I/3D5?1$%403L*("`@("`@("!I
M9BA$871E7U1I;65:;VYE.CII<U9A;&ED240H)&ED*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^:60@/2`D:60["B`@("`@("`@("`@("1T:&ES+3YL;VYG;F%M
M92`]("1?1$%415]424U%6D].15]$051!6R1I9%U;)VQO;F=N86UE)UT["B`@
M("`@("`@("`@("1T:&ES+3YS:&]R=&YA;64@/2`D7T1!5$5?5$E-15I/3D5?
M1$%405LD:61=6R=S:&]R=&YA;64G73L*("`@("`@("`@("`@)'1H:7,M/F]F
M9G-E="`]("1?1$%415]424U%6D].15]$051!6R1I9%U;)V]F9G-E="==.PH@
M("`@("`@("`@("!I9B@D7T1!5$5?5$E-15I/3D5?1$%405LD:61=6R=H87-D
M<W0G72D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/FAA<V1S="`]('1R=64[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^9'-T;&]N9VYA;64@/2`D7T1!5$5?
M5$E-15I/3D5?1$%405LD:61=6R=D<W1L;VYG;F%M92==.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/F1S='-H;W)T;F%M92`]("1?1$%415]424U%6D].15]$
M051!6R1I9%U;)V1S='-H;W)T;F%M92==.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/FAA<V1S="`](&9A;'-E.PH@("`@
M("`@("`@("`@("`@)'1H:7,M/F1S=&QO;F=N86UE(#T@)'1H:7,M/FQO;F=N
M86UE.PH@("`@("`@("`@("`@("`@)'1H:7,M/F1S='-H;W)T;F%M92`]("1T
M:&ES+3YS:&]R=&YA;64["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D=&AI<RT^:60@/2`G551#)SL*("`@("`@("`@("`@
M)'1H:7,M/FQO;F=N86UE(#T@)%]$051%7U1)345:3TY%7T1!5$%;)'1H:7,M
M/FED75LG;&]N9VYA;64G73L*("`@("`@("`@("`@)'1H:7,M/G-H;W)T;F%M
M92`]("1?1$%415]424U%6D].15]$051!6R1T:&ES+3YI9%U;)W-H;W)T;F%M
M92==.PH@("`@("`@("`@("`D=&AI<RT^:&%S9'-T(#T@)%]$051%7U1)345:
M3TY%7T1!5$%;)'1H:7,M/FED75LG:&%S9'-T)UT["B`@("`@("`@("`@("1T
M:&ES+3YO9F9S970@/2`D7T1!5$5?5$E-15I/3D5?1$%405LD=&AI<RT^:61=
M6R=O9F9S970G73L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FX@82!4:6UE6F]N92!O8FIE8W0@<F5P<F5S96YT:6YG('1H92!S>7-T
M96T@9&5F875L="!T:6UE('IO;F4*("`@("`J"B`@("`@*B!2971U<FX@82!4
M:6UE6F]N92!O8FIE8W0@<F5P<F5S96YT:6YG('1H92!S>7-T96T@9&5F875L
M="!T:6UE('IO;F4L"B`@("`@*B!W:&EC:"!I<R!I;FET:6%L:7IE9"!D=7)I
M;F<@=&AE(&QO861I;F<@;V8@5&EM95IO;F4N<&AP+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N(&]B:F5C="!$871E7U1I
M;65:;VYE('1H92!D969A=6QT('1I;64@>F]N90H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971$969A=6QT*"D*("`@('L*("`@("`@("!G;&]B86P@)%]$051%
M7U1)345:3TY%7T1%1D%53%0["B`@("`@("`@<F5T=7)N(&YE=R!$871E7U1I
M;65:;VYE*"1?1$%415]424U%6D].15]$149!54Q4*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E=',@=&AE('-Y<W1E;2!D969A=6QT('1I;64@>F]N92!T
M;R!T:&4@=&EM92!Z;VYE(&EN("1I9`H@("`@("H*("`@("`J(%-E=',@=&AE
M('-Y<W1E;2!D969A=6QT('1I;64@>F]N92!T;R!T:&4@=&EM92!Z;VYE(&EN
M("1I9`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1I9"!T:&4@=&EM92!Z;VYE(&ED('1O('5S90H@("`@("HO
M"B`@("!F=6YC=&EO;B!S971$969A=6QT*"1I9"D*("`@('L*("`@("`@("!G
M;&]B86P@)%]$051%7U1)345:3TY%7T1%1D%53%0["B`@("`@("`@:68H1&%T
M95]4:6UE6F]N93HZ:7-686QI9$E$*"1I9"DI('L*("`@("`@("`@("`@)%]$
M051%7U1)345:3TY%7T1%1D%53%0@/2`D:60["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@5&5S=',@:68@9VEV96X@:60@:7,@<F5P<F5S96YT
M960@:6X@=&AE("1?1$%415]424U%6D].15]$051!('1I;64@>F]N92!D871A
M"B`@("`@*@H@("`@("H@5&5S=',@:68@9VEV96X@:60@:7,@<F5P<F5S96YT
M960@:6X@=&AE("1?1$%415]424U%6D].15]$051!('1I;64@>F]N92!D871A
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2!S
M=')I;F<@)&ED('1H92!I9"!T;R!T97-T"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@=')U92!I9B!T:&4@<W5P<&QI960@240@:7,@=F%L:60*("`@("`J+PH@
M("`@9G5N8W1I;VX@:7-686QI9$E$*"1I9"D*("`@('L*("`@("`@("!G;&]B
M86P@)%]$051%7U1)345:3TY%7T1!5$$["B`@("`@("`@:68H:7-S970H)%]$
M051%7U1)345:3TY%7T1!5$%;)&ED72DI('L*("`@("`@("`@("`@<F5T=7)N
M('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($ES('1H:7,@
M=&EM92!Z;VYE(&5Q=6%L('1O(&%N;W1H97(*("`@("`J"B`@("`@*B!497-T
M<R!T;R!S964@:68@=&AI<R!T:6UE('IO;F4@:7,@97%U86P@*&ED<R!M871C
M:"D*("`@("`J('1O(&$@9VEV96X@1&%T95]4:6UE6F]N92!O8FIE8W0N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2!O8FIE
M8W0@1&%T95]4:6UE6F]N92`D='H@=&AE('1I;65Z;VYE('1O('1E<W0*("`@
M("`J($!R971U<FX@8F]O;&5A;B!T<G5E(&EF('1H:7,@=&EM92!Z;VYE(&ES
M(&5Q=6%L('1O('1H92!S=7!P;&EE9"!T:6UE('IO;F4*("`@("`J+PH@("`@
M9G5N8W1I;VX@:7-%<75A;"@D='HI"B`@("!["B`@("`@("`@:68H<W1R8V%S
M96-M<"@D=&AI<RT^:60L("1T>BT^:60I(#T](#`I('L*("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($ES
M('1H:7,@=&EM92!Z;VYE(&5Q=6EV86QE;G0@=&\@86YO=&AE<@H@("`@("H*
M("`@("`J(%1E<W1S('1O('-E92!I9B!T:&ES('1I;64@>F]N92!I<R!E<75I
M=F%L96YT('1O"B`@("`@*B!A(&=I=F5N('1I;64@>F]N92!O8FIE8W0N("!%
M<75I=F%L96YC92!I;B!T:&ES(&-O;G1E>'0*("`@("`J(&ES(&1E9FEN960@
M8GD@=&AE('1W;R!T:6UE('IO;F5S(&AA=FEN9R!A;B!E<75A;"!R87<*("`@
M("`J(&]F9G-E="!A;F0@86X@97%U86P@<V5T=&EN9R!O9B`B:&%S9'-T(BX@
M(%1H:7,@:7,@;F]T('1R=64*("`@("`J(&5Q=6EV86QE;F-E+"!A<R!T:&4@
M='=O('1I;64@>F]N97,@;6%Y(&AA=F4@9&EF9F5R96YT(')U;&5S"B`@("`@
M*B!F;W(@=&AE(&]B<V5R=F%N8V4@;V8@1%-4+"!B=70@=&AI<R!I;7!L96UE
M;G1A=&EO;B!D;V5S(&YO=`H@("`@("H@:VYO=R!$4U0@<G5L97,N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2!O8FIE8W0@
M1&%T95]4:6UE6F]N92`D='H@=&AE('1I;65Z;VYE(&]B:F5C="!T;R!T97-T
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@=')U92!I9B!T:&ES('1I;64@>F]N
M92!I<R!E<75I=F%L96YT('1O('1H92!S=7!P;&EE9"!T:6UE('IO;F4*("`@
M("`J+PH@("`@9G5N8W1I;VX@:7-%<75I=F%L96YT*"1T>BD*("`@('L*("`@
M("`@("!I9B@D=&AI<RT^;V9F<V5T(#T]("1T>BT^;V9F<V5T("8F("1T:&ES
M+3YH87-D<W0@/3T@)'1Z+3YH87-D<W0I('L*("`@("`@("`@("`@<F5T=7)N
M('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=')U92!I9B!T:&ES('IO;F4@;V)S97)V97,@9&%Y;&EG:'0@<V%V:6YG<R!T
M:6UE"B`@("`@*@H@("`@("H@4F5T=7)N<R!T<G5E(&EF('1H:7,@>F]N92!O
M8G-E<G9E<R!D87EL:6=H="!S879I;F=S('1I;64*("`@("`J"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!B;V]L96%N('1R=64@:68@
M=&AI<R!T:6UE('IO;F4@:&%S($135`H@("`@("HO"B`@("!F=6YC=&EO;B!H
M87-$87EL:6=H=%1I;64H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M:&%S9'-T.PH@("`@?0H*("`@("\J*@H@("`@("H@27,@=&AE(&=I=F5N(&1A
M=&4O=&EM92!I;B!$4U0@9F]R('1H:7,@=&EM92!Z;VYE"B`@("`@*@H@("`@
M("H@071T96UP=',@=&\@9&5T97)M:6YE(&EF(&$@9VEV96X@1&%T92!O8FIE
M8W0@<F5P<F5S96YT<R!A(&1A=&4O=&EM90H@("`@("H@=&AA="!I<R!I;B!$
M4U0@9F]R('1H:7,@=&EM92!Z;VYE+B`@5T%23DE.1U,Z('1H:7,@8F%S:6-A
M;&QY(&%T=&5M<'1S('1O"B`@("`@*B`B=')I8VLB('1H92!S>7-T96T@:6YT
M;R!T96QL:6YG('5S(&EF('=E)W)E(&EN($135"!F;W(@82!G:79E;B!T:6UE
M('IO;F4N"B`@("`@*B!4:&ES('5S97,@<'5T96YV*"D@=VAI8V@@;6%Y(&YO
M="!W;W)K(&EN('-A9F4@;6]D92P@86YD(')E;&EE<R!O;B!U;FEX('1I;64*
M("`@("`J('=H:6-H(&ES(&]N;'D@=F%L:60@9F]R(&1A=&5S(&9R;VT@,3DW
M,"!T;R!^,C`S."X@(%1H:7,@<F5L:65S(&]N('1H90H@("`@("H@=6YD97)L
M>6EN9R!/4R!C86QL<RP@<V\@:70@;6%Y(&YO="!W;W)K(&]N(%=I;F1O=W,@
M;W(@;VX@82!S>7-T96T@=VAE<F4*("`@("`J('IO;F5I;F9O(&ES(&YO="!I
M;G-T86QL960@;W(@8V]N9FEG=7)E9"!P<F]P97)L>2X*("`@("`J"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M(&]B:F5C="!$871E("1D
M871E('1H92!D871E+W1I;64@=&\@=&5S=`H@("`@("H@0')E='5R;B!B;V]L
M96%N('1R=64@:68@=&AI<R!D871E(&ES(&EN($135"!F;W(@=&AI<R!T:6UE
M('IO;F4*("`@("`J+PH@("`@9G5N8W1I;VX@:6Y$87EL:6=H=%1I;64H)&1A
M=&4I"B`@("!["B`@("`@("`@)&5N=E]T>B`]("(B.PH@("`@("`@(&EF*&=E
M=&5N=B@B5%HB*2D@>PH@("`@("`@("`@("`D96YV7W1Z(#T@9V5T96YV*")4
M6B(I.PH@("`@("`@('T*("`@("`@("!P=71E;G8H(E1:/2(N)'1H:7,M/FED
M*3L*("`@("`@("`D;'1I;64@/2!L;V-A;'1I;64H)&1A=&4M/F=E=%1I;64H
M*2P@=')U92D["B`@("`@("`@<'5T96YV*")46CTB+B1E;G9?='HI.PH@("`@
M("`@(')E='5R;B`D;'1I;65;)W1M7VES9'-T)UT["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'970@=&AE($135"!O9F9S970@9F]R('1H:7,@=&EM92!Z;VYE
M"B`@("`@*@H@("`@("H@4F5T=7)N<R!T:&4@1%-4(&]F9G-E="!O9B!T:&ES
M('1I;64@>F]N92P@:6X@;6EL;&ES96-O;F1S+`H@("`@("H@:68@=&AE('IO
M;F4@;V)S97)V97,@1%-4+"!Z97)O(&]T:&5R=VES92X@($-U<G)E;G1L>2!T
M:&4*("`@("`J($135"!O9F9S970@:7,@:&%R9"UC;V1E9"!T;R!O;F4@:&]U
M<BX*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R
M;B!I;G0@=&AE($135"!O9F9S970L(&EN(&UI;&QI<V5C;VYD<R!O<B!Z97)O
M(&EF('1H92!Z;VYE(&1O97,@;F]T(&]B<V5R=F4@1%-4"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$135%-A=FEN9W,H*0H@("`@>PH@("`@("`@(&EF*"1T
M:&ES+3YH87-D<W0I('L*("`@("`@("`@("`@<F5T=7)N(#,V,#`P,#`["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@1V5T('1H92!$4U0M8V]R<F5C=&5D
M(&]F9G-E="!T;R!55$,@9F]R('1H92!G:79E;B!D871E"B`@("`@*@H@("`@
M("H@071T96UP=',@=&\@9V5T('1H92!O9F9S970@=&\@551#(&9O<B!A(&=I
M=F5N(&1A=&4O=&EM92P@=&%K:6YG(&EN=&\*("`@("`J(&%C8V]U;G0@9&%Y
M;&EG:'0@<V%V:6YG<R!T:6UE+"!I9B!T:&4@=&EM92!Z;VYE(&]B<V5R=F5S
M(&ET(&%N9"!I9@H@("`@("H@:70@:7,@:6X@969F96-T+B`@4&QE87-E('-E
M92!T:&4@5T%23DE.1U,@;VX@1&%T93HZ5&EM95IO;F4Z.FEN1&%Y;&EG:'14
M:6UE*"DN"B`@("`@*@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B!`<&%R86T@;V)J96-T($1A=&4@)&1A=&4@=&AE($1A=&4@=&\@=&5S
M=`H@("`@("H@0')E='5R;B!I;G0@=&AE(&-O<G)E8W1E9"!O9F9S970@=&\@
M551#(&EN(&UI;&QI<V5C;VYD<PH@("`@("HO"B`@("!F=6YC=&EO;B!G971/
M9F9S970H)&1A=&4I"B`@("!["B`@("`@("`@:68H)'1H:7,M/FEN1&%Y;&EG
M:'14:6UE*"1D871E*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F]F
M9G-E="`K("1T:&ES+3YG971$4U13879I;F=S*"D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YO9F9S970["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;&ES="!O9B!V
M86QI9"!T:6UE('IO;F4@:60@<W1R:6YG<PH@("`@("H*("`@("`J(%)E='5R
M;G,@=&AE(&QI<W0@;V8@=F%L:60@=&EM92!Z;VYE(&ED('-T<FEN9W,*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!M:7AE
M9"!A;B!A<G)A>2!O9B!S=')I;F=S('=I=&@@=&AE('9A;&ED('1I;64@>F]N
M92!)1',*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T079A:6QA8FQE241S*"D*
M("`@('L*("`@("`@("!G;&]B86P@)%]$051%7U1)345:3TY%7T1!5$$["B`@
M("`@("`@<F5T=7)N(&%R<F%Y7VME>7,H)%]$051%7U1)345:3TY%7T1!5$$I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@:60@9F]R('1H
M:7,@=&EM92!Z;VYE"B`@("`@*@H@("`@("H@4F5T=7)N<R!T:&4@=&EM92!Z
M;VYE(&ED("!F;W(@=&AI<R!T:6UE('IO;F4L(&DN92X@(D%M97)I8V$O0VAI
M8V%G;R(*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E
M='5R;B!S=')I;F<@=&AE(&ED"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$E$
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/FED.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;&]N9R!N86UE(&9O<B!T:&ES('1I
M;64@>F]N90H@("`@("H*("`@("`J(%)E='5R;G,@=&AE(&QO;F<@;F%M92!F
M;W(@=&AI<R!T:6UE('IO;F4L"B`@("`@*B!I+F4N(")#96YT<F%L(%-T86YD
M87)D(%1I;64B"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M($!R971U<FX@<W1R:6YG('1H92!L;VYG(&YA;64*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T3&]N9TYA;64H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^;&]N9VYA;64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!S:&]R="!N86UE(&9O<B!T:&ES('1I;64@>F]N90H@("`@("H*("`@("`J
M(%)E='5R;G,@=&AE('-H;W)T(&YA;64@9F]R('1H:7,@=&EM92!Z;VYE+"!I
M+F4N(")#4U0B"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M($!R971U<FX@<W1R:6YG('1H92!S:&]R="!N86UE"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%-H;W)T3F%M92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3YS:&]R=&YA;64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!$4U0@;&]N9R!N86UE(&9O<B!T:&ES('1I;64@>F]N90H@("`@("H*
M("`@("`J(%)E='5R;G,@=&AE($135"!L;VYG(&YA;64@9F]R('1H:7,@=&EM
M92!Z;VYE+"!I+F4N(")#96YT<F%L($1A>6QI9VAT(%1I;64B"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@<W1R:6YG('1H
M92!D87EL:6=H="!S879I;F=S('1I;64@;&]N9R!N86UE"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$135$QO;F=.86UE*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/F1S=&QO;F=N86UE.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!T:&4@1%-4('-H;W)T(&YA;64@9F]R('1H:7,@=&EM92!Z;VYE
M"B`@("`@*@H@("`@("H@4F5T=7)N<R!T:&4@1%-4('-H;W)T(&YA;64@9F]R
M('1H:7,@=&EM92!Z;VYE+"!I+F4N(")#1%0B"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@<W1R:6YG('1H92!D87EL:6=H
M="!S879I;F=S('1I;64@<VAO<G0@;F%M90H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971$4U13:&]R=$YA;64H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^9'-T<VAO<G1N86UE.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!T:&4@<F%W("AN;VXM1%-4+6-O<G)E8W1E9"D@;V9F<V5T(&9R;VT@551#
M+T=-5"!F;W(@=&AI<R!T:6UE('IO;F4*("`@("`J"B`@("`@*B!2971U<FYS
M('1H92!R87<@*&YO;BU$4U0M8V]R<F5C=&5D*2!O9F9S970@9G)O;2!55$,O
M1TU4(&9O<B!T:&ES('1I;64@>F]N90H@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B!`<F5T=7)N(&EN="!T:&4@;V9F<V5T+"!I;B!M:6QL
M:7-E8V]N9',*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4F%W3V9F<V5T*"D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F]F9G-E=#L*("`@('T*?0H*
M"B\O"B\O(%1I;64@6F]N92!$871A"B\O("!O9F9S970@:7,@:6X@;6EL:7-E
M8V]N9',*+R\*)$=,3T)!3%-;)U]$051%7U1)345:3TY%7T1!5$$G72`](&%R
M<F%Y*`H@("`@)T5T8R]'350K,3(G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^("TT,S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350M
M,3(Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350M,3(Z,#`G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G171C+T=-5"LQ,2<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,Y-C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T=-5"TQ,3HP,"<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T=-5"TQ,3HP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=-250G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M("TS.38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=797-T(%-A;6]A
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=74U0G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4&%C:69I8R]!<&EA)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,SDV,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G5V5S="!386UO82!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G5U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)U!A8VEF:6,O36ED=V%Y)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`M,SDV,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4V%M
M;V$@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U-3
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC
M+TYI=64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS.38P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=.:75E(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=.550G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G4&%C:69I8R]086=O7U!A9V\G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^("TS.38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=386UO82!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G4U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)U!A8VEF:6,O4V%M;V$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M("TS.38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=386UO82!3=&%N
M9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4U-4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U53+U-A;6]A)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,SDV,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G4V%M;V$@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)U-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=!;65R:6-A+T%D86LG(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^("TS-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=(
M87=A:6DM06QE=71I86X@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)TA!4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`G2&%W86EI+4%L975T:6%N($1A>6QI
M9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=(0414)R`I
M+`H@("`@)T%M97)I8V$O071K82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TAA=V%I
M:2U!;&5U=&EA;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G2$%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@
M("`G9'-T;&]N9VYA;64G(#T^("=(87=A:6DM06QE=71I86X@1&%Y;&EG:'0@
M5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TA!1%0G("DL"B`@
M("`G171C+T=-5"LQ,"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-5"TQ,#HP,"<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"TQ,#HP,"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=(4U0G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^("TS-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=(87=A:6D@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)TA35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=086-I9FEC+T9A:V%O9F\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^("TS-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=4;VME;&%U
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=42U0G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4&%C:69I8R](;VYO;'5L=2<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,V,#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)TAA=V%I:2!3=&%N9&%R9"!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G2%-4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)U!A8VEF:6,O2F]H;G-T;VXG(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^("TS-C`P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=(87=A:6D@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)TA35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=086-I9FEC+U)A<F]T;VYG82<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-O
M;VL@27,N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#2U0G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4&%C:69I8R]486AI
M=&DG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS-C`P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=486AI=&D@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)U1!2%0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G4WES=&5M5B](4U0Q,"<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@+3,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)TAA=V%I:2!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G2%-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U53
M+T%L975T:6%N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,S8P
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G2&%W86EI+4%L975T:6%N
M(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=(05-4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG
M;F%M92<@/3X@)TAA=V%I:2U!;&5U=&EA;B!$87EL:6=H="!4:6UE)RP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G2$%$5"<@*2P*("`@("=54R](87=A
M:6DG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS-C`P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=(87=A:6D@4W1A;F1A<F0@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TA35"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC+TUA<G%U97-A<R<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,T,C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)TUA<G%U97-A<R!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G34%25"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=!4U0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS,C0P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!;&%S:V$@4W1A;F1A<F0@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%+4U0G+`H@("`@("`@
M("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G
M06QA<VMA($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G
M(#T^("=!2T14)R`I+`H@("`@)T%M97)I8V$O06YC:&]R86=E)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,S(T,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G06QA<VMA(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=!2U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E
M+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T%L87-K82!$87EL:6=H="!4
M:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G04M$5"<@*2P*("`@
M("=!;65R:6-A+TIU;F5A=2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@+3,R-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%L87-K82!3
M=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G04M35"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^("=!;&%S:V$@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)T%+1%0G("DL"B`@("`G06UE<FEC82].;VUE)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,S(T,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G06QA<VMA(%-T86YD87)D(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=!2U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T
M<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T%L87-K82!$87EL:6=H
M="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G04M$5"<@*2P*
M("`@("=!;65R:6-A+UEA:W5T870G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^("TS,C0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!;&%S
M:V$@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%+
M4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO
M;F=N86UE)R`]/B`G06QA<VMA($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=!2T14)R`I+`H@("`@)T5T8R]'350K.2<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,R-#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T=-5"TP.3HP,"<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T=-5"TP.3HP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=086-I9FEC+T=A;6)I97(G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^("TS,C0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='
M86UB:65R(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='04U4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U-Y<W1E;58O65-4
M.2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,R-#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T=A;6)I97(@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T=!350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G4WES=&5M5B]94U0Y6414)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,S(T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G06QA<VMA(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=!2U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@
M("=D<W1L;VYG;F%M92<@/3X@)T%L87-K82!$87EL:6=H="!4:6UE)RP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G04M$5"<@*2P*("`@("=54R]!;&%S
M:V$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS,C0P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=!;&%S:V$@4W1A;F1A<F0@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%+4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G06QA<VMA
M($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=!
M2T14)R`I+`H@("`@)T%M97)I8V$O1&%W<V]N)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G4&%C:69I8R!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G4%-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@
M("=D<W1L;VYG;F%M92<@/3X@)U!A8VEF:6,@1&%Y;&EG:'0@5&EM92<L"B`@
M("`@("`@)V1S='-H;W)T;F%M92<@/3X@)U!$5"<@*2P*("`@("=!;65R:6-A
M+T5N<V5N861A)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C@X
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4&%C:69I8R!3=&%N9&%R
M9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4%-4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@
M)U!A8VEF:6,@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M
M92<@/3X@)U!$5"<@*2P*("`@("=!;65R:6-A+TQO<U]!;F=E;&5S)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C@X,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G4&%C:69I8R!3=&%N9&%R9"!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G4%-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T
M<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)U!A8VEF:6,@1&%Y;&EG
M:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)U!$5"<@*2P*
M("`@("=!;65R:6-A+U1I:G5A;F$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^("TR.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=086-I
M9FEC(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=0
M4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO
M;F=N86UE)R`]/B`G4&%C:69I8R!$87EL:6=H="!4:6UE)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G4$14)R`I+`H@("`@)T%M97)I8V$O5F%N8V]U
M=F5R)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C@X,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4&%C:69I8R!3=&%N9&%R9"!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4%-4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)U!A8VEF
M:6,@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@
M)U!$5"<@*2P*("`@("=!;65R:6-A+U=H:71E:&]R<V4G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^("TR.#@P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=086-I9FEC(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=04U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`G4&%C:69I8R!$87EL:6=H="!4:6UE
M)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G4$14)R`I+`H@("`@)T-A
M;F%D82]086-I9FEC)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M
M,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4&%C:69I8R!3=&%N
M9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4%-4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@)U!A8VEF:6,@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T
M;F%M92<@/3X@)U!$5"<@*2P*("`@("=#86YA9&$O675K;VXG(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TR.#@P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=086-I9FEC(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=04U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L
M"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G4&%C:69I8R!$87EL:6=H="!4
M:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G4$14)R`I+`H@("`@
M)T5T8R]'350K."<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(X
M.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-5"TP.#HP,"<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"TP.#HP,"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=-97AI8V\O0F%J84YO<G1E)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C@X,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G4&%C:69I8R!3=&%N9&%R9"!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G4%-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T
M<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)U!A8VEF:6,@1&%Y;&EG
M:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)U!$5"<@*2P*
M("`@("=04U0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR.#@P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=086-I9FEC(%-T86YD87)D
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=04U0G+`H@("`@("`@
M("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G
M4&%C:69I8R!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G4$14)R`I+`H@("`@)U!35#A01%0G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TR.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=086-I9FEC(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=04U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@
M)V1S=&QO;F=N86UE)R`]/B`G4&%C:69I8R!$87EL:6=H="!4:6UE)RP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G4$14)R`I+`H@("`@)U!A8VEF:6,O
M4&ET8V%I<FXG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR.#@P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=0:71C86ER;B!3=&%N9&%R
M9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4%-4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U-Y<W1E;58O4%-4."<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(X.#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)U!I=&-A:7)N(%-T86YD87)D(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=04U0G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G4WES=&5M5B]04U0X4$14)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`M,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G4&%C:69I8R!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G4%-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@
M("`@("=D<W1L;VYG;F%M92<@/3X@)U!A8VEF:6,@1&%Y;&EG:'0@5&EM92<L
M"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)U!$5"<@*2P*("`@("=54R]0
M86-I9FEC)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C@X,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4&%C:69I8R!3=&%N9&%R9"!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4%-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)U!A
M8VEF:6,@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)U!$5"<@*2P*("`@("=54R]086-I9FEC+4YE=R<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)U!A8VEF:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)U!35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@
M("`@("`G9'-T;&]N9VYA;64G(#T^("=086-I9FEC($1A>6QI9VAT(%1I;64G
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=01%0G("DL"B`@("`G06UE
M<FEC82]";VES92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(U
M,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUO=6YT86EN(%-T86YD
M87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=-4U0G+`H@("`@
M("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]
M/B`G36]U;G1A:6X@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T
M;F%M92<@/3X@)TU$5"<@*2P*("`@("=!;65R:6-A+T-A;6)R:61G95]"87DG
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR-3(P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=-;W5N=&%I;B!3=&%N9&%R9"!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G35-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TUO=6YT86EN
M($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=-
M1%0G("DL"B`@("`G06UE<FEC82]#:&EH=6%H=6$G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^("TR-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=-;W5N=&%I;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G35-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@
M("`@("=D<W1L;VYG;F%M92<@/3X@)TUO=6YT86EN($1A>6QI9VAT(%1I;64G
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=-1%0G("DL"B`@("`G06UE
M<FEC82]$87=S;VY?0W)E96LG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^("TR-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=-;W5N=&%I
M;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G35-4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O
M1&5N=F5R)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C4R,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G36]U;G1A:6X@4W1A;F1A<F0@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU35"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=-
M;W5N=&%I;B!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G3414)R`I+`H@("`@)T%M97)I8V$O161M;VYT;VXG(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TR-3(P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=-;W5N=&%I;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G35-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E
M+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TUO=6YT86EN($1A>6QI9VAT
M(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=-1%0G("DL"B`@
M("`G06UE<FEC82](97)M;W-I;&QO)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`M,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G36]U
M;G1A:6X@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)TU35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R
M:6-A+TEN=79I:R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(U
M,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUO=6YT86EN(%-T86YD
M87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=-4U0G+`H@("`@
M("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]
M/B`G36]U;G1A:6X@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T
M;F%M92<@/3X@)TU$5"<@*2P*("`@("=!;65R:6-A+TUA>F%T;&%N)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C4R,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G36]U;G1A:6X@4W1A;F1A<F0@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)TU35"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=-;W5N=&%I;B!$87EL
M:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G3414)R`I
M+`H@("`@)T%M97)I8V$O4&AO96YI>"<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUO
M=6YT86EN(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=-4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE
M<FEC82]3:&EP<F]C:R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUO=6YT86EN(%-T
M86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=-4U0G+`H@
M("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE
M)R`]/B`G36]U;G1A:6X@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)TU$5"<@*2P*("`@("=!;65R:6-A+UEE;&QO=VMN:69E
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C4R,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G36]U;G1A:6X@4W1A;F1A<F0@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU35"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=-;W5N=&%I
M;B!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G
M3414)R`I+`H@("`@)T-A;F%D82]-;W5N=&%I;B<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)TUO=6YT86EN(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=-4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@
M("`@)V1S=&QO;F=N86UE)R`]/B`G36]U;G1A:6X@1&%Y;&EG:'0@5&EM92<L
M"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TU$5"<@*2P*("`@("=%=&,O
M1TU4*S<G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR-3(P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350M,#<Z,#`G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("='350M,#<Z,#`G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G35-4)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`M,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G36]U
M;G1A:6X@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)TU35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T
M;&]N9VYA;64G(#T^("=-;W5N=&%I;B!$87EL:6=H="!4:6UE)RP*("`@("`@
M("`G9'-T<VAO<G1N86UE)R`]/B`G3414)R`I+`H@("`@)TU35#=-1%0G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR-3(P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=-;W5N=&%I;B!3=&%N9&%R9"!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G35-4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TUO=6YT86EN($1A
M>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=-1%0G
M("DL"B`@("`G365X:6-O+T)A:F%3=7(G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^("TR-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=-
M;W5N=&%I;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G35-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@)TUO=6YT86EN($1A>6QI9VAT(%1I;64G+`H@("`@
M("`@("=D<W1S:&]R=&YA;64G(#T^("=-1%0G("DL"B`@("`G3F%V86IO)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C4R,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G36]U;G1A:6X@4W1A;F1A<F0@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)TU35"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=-;W5N=&%I;B!$
M87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G3414
M)R`I+`H@("`@)U!.5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUO=6YT86EN(%-T
M86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=-4U0G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4WES=&5M5B]-4U0W
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C4R,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G36]U;G1A:6X@4W1A;F1A<F0@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU35"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=3>7-T96U6+TU35#=-1%0G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TR-3(P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=-;W5N=&%I;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G35-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E
M+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TUO=6YT86EN($1A>6QI9VAT
M(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=-1%0G("DL"B`@
M("`G55,O07)I>F]N82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUO=6YT86EN(%-T
M86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=-4U0G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G55,O36]U;G1A:6XG
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR-3(P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=-;W5N=&%I;B!3=&%N9&%R9"!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G35-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TUO=6YT86EN
M($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=-
M1%0G("DL"B`@("`G06UE<FEC82]"96QI>F4G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=#96YT<F%L(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M06UE<FEC82]#86YC=6XG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M("TR,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L(%-T
M86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@
M("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE
M)R`]/B`G0V5N=')A;"!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO
M<G1N86UE)R`]/B`G0T14)R`I+`H@("`@)T%M97)I8V$O0VAI8V%G;R<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(Q-C`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A;F1A<F0@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#96YT<F%L($1A>6QI
M9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#1%0G("DL
M"B`@("`G06UE<FEC82]#;W-T85]2:6-A)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`M,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M0V5N=')A;"!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M
M97)I8V$O16Q?4V%L=F%D;W(G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^("TR,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L
M(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]'
M=6%T96UA;&$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR,38P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L(%-T86YD87)D
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]-86YA9W5A)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!3=&%N9&%R9"!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)T%M97)I8V$O365N;VUI;F5E)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G0V5N=')A;"!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@1&%Y;&EG:'0@5&EM
M92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-$5"<@*2P*("`@("=!
M;65R:6-A+TUE<FED82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A
M;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("=#96YT<F%L($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=#1%0G("DL"B`@("`G06UE<FEC82]-97AI8V]?0VET>2<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(Q-C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A;F1A<F0@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+TUO;G1E<G)E>2<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@+3(Q-C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T-E;G1R86P@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#96YT<F%L($1A>6QI9VAT(%1I
M;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#1%0G("DL"B`@("`G
M06UE<FEC82].;W)T:%]$86MO=&$O0V5N=&5R)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G0V5N=')A;"!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@
M("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@1&%Y;&EG:'0@5&EM92<L"B`@
M("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-$5"<@*2P*("`@("=!;65R:6-A
M+U)A:6YY7U)I=F5R)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M
M,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!3=&%N
M9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@)T-E;G1R86P@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T
M;F%M92<@/3X@)T-$5"<@*2P*("`@("=!;65R:6-A+U)A;FMI;E]);FQE="<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(Q-C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N($1A
M>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%1%0G
M("DL"B`@("`G06UE<FEC82]296=I;F$G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#
M96YT<F%L(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE
M<FEC82]3=VEF=%]#=7)R96YT)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A
M;"!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O
M5&5G=6-I9V%L<&$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR
M,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L(%-T86YD
M87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]7:6YN:7!E
M9R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(Q-C`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A;F1A<F0@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#96YT<F%L
M($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#
M1%0G("DL"B`@("`G0U-4)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`M,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!3
M=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M
M92<@/3X@)T-E;G1R86P@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)T-$5"<@*2P*("`@("=#4U0V0T14)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G0V5N=')A;"!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@1&%Y;&EG:'0@5&EM
M92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-$5"<@*2P*("`@("=#
M86YA9&$O0V5N=')A;"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A
M;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("=#96YT<F%L($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=#1%0G("DL"B`@("`G0V%N861A+T5A<W0M4V%S:V%T8VAE
M=V%N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!3=&%N9&%R9"!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)T-A;F%D82]387-K871C:&5W86XG(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=#96YT<F%L(%-T86YD87)D(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G0VAI;&4O16%S=&5R27-L86YD)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G16%S=&5R($ES+B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G14%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@
M("`G9'-T;&]N9VYA;64G(#T^("=%87-T97(@27,N(%-U;6UE<B!4:6UE)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G14%34U0G("DL"B`@("`G171C
M+T=-5"LV)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4+3`V.C`P)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G1TU4+3`V.C`P)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)TUE>&EC;R]'96YE<F%L)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G0V5N=')A;"!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)U!A8VEF:6,O16%S=&5R)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`M,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S
M=&5R($ES+B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G14%35"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^("=%87-T97(@27,N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G14%34U0G("DL"B`@("`G4&%C:69I8R]'86QA<&%G
M;W,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR,38P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("='86QA<&%G;W,@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T=!3%0G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G4WES=&5M5B]#4U0V)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G0V5N=')A;"!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)U-Y<W1E;58O0U-4-D-$5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@+3(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@
M4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^("=#96YT<F%L($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S
M:&]R=&YA;64G(#T^("=#1%0G("DL"B`@("`G55,O0V5N=')A;"<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(Q-C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U
M92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#96YT<F%L($1A>6QI9VAT
M(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#1%0G("DL"B`@
M("`G06UE<FEC82]";V=O=&$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^("TQ.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#;VQO;6)I
M82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T]4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O0V%Y;6%N)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)T%M97)I8V$O1&5T<F]I="<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@
M("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N($1A>6QI9VAT(%1I;64G
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%1%0G("DL"B`@("`G06UE
M<FEC82]%:7)U;F5P92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%C<F4@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%#5"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+T9O<G1?5V%Y;F4G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD87)D(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G06UE<FEC82]'<F%N9%]4=7)K)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@
M("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@1&%Y;&EG:'0@5&EM92<L
M"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5$5"<@*2P*("`@("=!;65R
M:6-A+T=U87EA<75I;"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5C=6%D;W(@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5#5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+TAA=F%N82<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U
M92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#96YT<F%L($1A>6QI9VAT
M(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#1%0G("DL"B`@
M("`G06UE<FEC82]);F1I86YA+TEN9&EA;F%P;VQI<R<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=!;65R:6-A+TEN9&EA;F$O2VYO>"<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T5A<W1E<FX@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!
M;65R:6-A+TEN9&EA;F$O36%R96YG;R<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A
M<W1E<FX@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R
M:6-A+TEN9&EA;F$O5F5V87DG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^("TQ.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N
M(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82])
M;F1I86YA<&]L:7,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ
M.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD
M87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82])<6%L=6ET
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@
M1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5$
M5"<@*2P*("`@("=!;65R:6-A+TIA;6%I8V$G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=%87-T97)N(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M06UE<FEC82]+96YT=6-K>2],;W5I<W9I;&QE)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@
M("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@1&%Y;&EG:'0@5&EM92<L"B`@
M("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5$5"<@*2P*("`@("=!;65R:6-A
M+TME;G1U8VMY+TUO;G1I8V5L;&\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^("TQ.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T
M97)N(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%
M4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO
M;F=N86UE)R`]/B`G16%S=&5R;B!$87EL:6=H="!4:6UE)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G1414)R`I+`H@("`@)T%M97)I8V$O2VYO>%])
M3B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+TQI;6$G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=097)U(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=0
M150G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC
M82],;W5I<W9I;&QE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M
M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N
M9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@)T5A<W1E<FX@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T
M;F%M92<@/3X@)T5$5"<@*2P*("`@("=!;65R:6-A+TUO;G1R96%L)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T
M<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@1&%Y;&EG
M:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5$5"<@*2P*
M("`@("=!;65R:6-A+TYA<W-A=2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E
M<FX@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T53
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N
M9VYA;64G(#T^("=%87-T97)N($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=%1%0G("DL"B`@("`G06UE<FEC82].97=?66]R
M:R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N
M($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%
M1%0G("DL"B`@("`G06UE<FEC82].:7!I9V]N)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@
M("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@1&%Y;&EG:'0@5&EM92<L"B`@
M("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5$5"<@*2P*("`@("=!;65R:6-A
M+U!A;F%M82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+U!A;F=N:7)T=6YG
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@
M1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5$
M5"<@*2P*("`@("=!;65R:6-A+U!O<G0M874M4')I;F-E)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T%M97)I8V$O4&]R=&]?06-R92<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T%C<F4@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%#5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+U)I;U]"
M<F%N8V\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!8W)E(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=!0U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G06UE<FEC82]4:'5N9&5R7T)A>2<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@
M("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N($1A>6QI9VAT(%1I;64G
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%1%0G("DL"B`@("`G0G)A
M>FEL+T%C<F4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!8W)E(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=!0U0G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G0V%N861A+T5A<W1E<FXG(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=%87-T97)N(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@
M("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!$87EL:6=H="!4:6UE)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G1414)R`I+`H@("`@)T-U8F$G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L(%-T86YD87)D(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G
M(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!$
M87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T14
M)R`I+`H@("`@)T535"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@4W1A
M;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("=%87-T97)N($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=%1%0G("DL"B`@("`G15-4-45$5"<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@
M("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N($1A>6QI9VAT(%1I;64G
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%1%0G("DL"B`@("`G171C
M+T=-5"LU)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4+3`U.C`P)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G1TU4+3`U.C`P)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)TE%5"<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A
M<W1E<FX@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=*86UA
M:6-A)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)U-Y<W1E;58O15-4-2<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=3>7-T96U6+T535#5%1%0G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^("TQ.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%
M87-T97)N(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S
M=&QO;F=N86UE)R`]/B`G16%S=&5R;B!$87EL:6=H="!4:6UE)RP*("`@("`@
M("`G9'-T<VAO<G1N86UE)R`]/B`G1414)R`I+`H@("`@)U53+T5A<W0M26YD
M:6%N82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=54R]%87-T97)N)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@1&%Y;&EG:'0@5&EM
M92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5$5"<@*2P*("`@("=5
M4R]);F1I86YA+5-T87)K92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@
M4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=54R]-:6-H:6=A
M;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N
M($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%
M1%0G("DL"B`@("`G06UE<FEC82]!;F=U:6QL82<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T%T;&%N=&EC(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G06UE<FEC82]!;G1I9W5A)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G071L86YT
M:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%3
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A
M+T%R=6)A)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G071L86YT:6,@4W1A;F1A<F0@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%35"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+T%S=6YC:6]N)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G4&%R86=U87D@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)U!95"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=087)A9W5A>2!3=6UM97(@5&EM
M92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)U!94U0G("DL"B`@("`G
M06UE<FEC82]"87)B861O<R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%T;&%N=&EC
M(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4U0G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]"
M;V%?5FES=&$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!;6%Z;VX@4W1A;F1A<F0@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%-5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+T-A<F%C87,G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=696YE>G5E;&$@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)U9%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=!;65R:6-A+T-U:6%B82<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%M
M87IO;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M04U4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@)T%M87IO;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S
M='-H;W)T;F%M92<@/3X@)T%-4U0G("DL"B`@("`G06UE<FEC82]#=7)A8V%O
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G071L86YT:6,@4W1A;F1A<F0@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%35"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+T1O;6EN:6-A)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G071L86YT:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=!;65R:6-A+T=L86-E7T)A>2<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T%T;&%N=&EC(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@
M("`@)V1S=&QO;F=N86UE)R`]/B`G071L86YT:6,@1&%Y;&EG:'0@5&EM92<L
M"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T%$5"<@*2P*("`@("=!;65R
M:6-A+T=O;W-E7T)A>2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%T;&%N=&EC(%-T
M86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4U0G+`H@
M("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE
M)R`]/B`G071L86YT:6,@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)T%$5"<@*2P*("`@("=!;65R:6-A+T=R96YA9&$G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=!=&QA;G1I8R!3=&%N9&%R9"!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G05-4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)T%M97)I8V$O1W5A9&5L;W5P92<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T%T;&%N=&EC(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G06UE<FEC82]'=7EA;F$G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='
M=7EA;F$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=95"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+TAA;&EF
M87@G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=!=&QA;G1I8R!3=&%N9&%R9"!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G05-4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T%T;&%N
M=&EC($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=!1%0G("DL"B`@("`G06UE<FEC82],85]087HG(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=";VQI=FEA(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("="
M3U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC
M82]-86YA=7,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!;6%Z;VX@4W1A;F1A<F0@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%-5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+TUA<G1I;FEQ=64G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=!=&QA;G1I8R!3=&%N9&%R9"!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G05-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O36]N='-E<G)A="<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T%T;&%N=&EC(%-T86YD87)D(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G06UE<FEC82]0;W)T7V]F7U-P86EN)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G071L86YT:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=!;65R:6-A+U!O<G1O7U9E;&AO)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G06UA>F]N(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=!350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M06UE<FEC82]0=65R=&]?4FEC;R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%T;&%N
M=&EC(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!
M4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC
M82]386YT:6%G;R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T
M-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-H:6QE(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=#3%0G+`H@("`@("`@("=H87-D<W0G
M(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0VAI;&4@4W5M
M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#3%-4)R`I
M+`H@("`@)T%M97)I8V$O4V%N=&]?1&]M:6YG;R<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T%T;&%N=&EC(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G06UE<FEC82]3=%]+:71T<R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%T;&%N
M=&EC(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!
M4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC
M82]3=%],=6-I82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T
M-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%T;&%N=&EC(%-T86YD
M87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]3=%]4:&]M
M87,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=!=&QA;G1I8R!3=&%N9&%R9"!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G05-4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O4W1?5FEN8V5N="<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T%T;&%N=&EC(%-T86YD87)D(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G06UE<FEC82]4:'5L92<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T%T;&%N=&EC(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G06UE<FEC82]4;W)T;VQA)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G071L86YT
M:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%3
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A
M+U9I<F=I;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%T;&%N=&EC(%-T86YD87)D
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06YT87)C=&EC82]086QM97(G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=#:&EL92!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G0TQ4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-H:6QE(%-U;6UE<B!4:6UE)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0TQ35"<@*2P*("`@("=!=&QA
M;G1I8R]"97)M=61A)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M
M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G071L86YT:6,@4W1A
M;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%35"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("=!=&QA;G1I8R!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO
M<G1N86UE)R`]/B`G0414)R`I+`H@("`@)T%T;&%N=&EC+U-T86YL97DG(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=&86QK;&%N9"!)<RX@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T9+5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U
M92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=&86QK;&%N9"!)<RX@4W5M
M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=&2U-4)R`I
M+`H@("`@)T)R87II;"]797-T)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G06UA>F]N
M(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!350G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G0V%N861A+T%T
M;&%N=&EC)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G071L86YT:6,@4W1A;F1A<F0@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%35"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=!
M=&QA;G1I8R!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G0414)R`I+`H@("`@)T-H:6QE+T-O;G1I;F5N=&%L)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G0VAI;&4@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T-,5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^("=#:&EL92!3=6UM97(@5&EM92<L"B`@("`@("`@
M)V1S='-H;W)T;F%M92<@/3X@)T-,4U0G("DL"B`@("`G171C+T=-5"LT)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G1TU4+3`T.C`P)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G1TU4+3`T.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)U!25"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%T;&%N=&EC(%-T
M86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4U0G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4WES=&5M5B]!4U0T
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G071L86YT:6,@4W1A;F1A<F0@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%35"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=3>7-T96U6+T%35#1!1%0G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=!=&QA;G1I8R!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E
M+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T%T;&%N=&EC($1A>6QI9VAT
M(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=!1%0G("DL"B`@
M("`G06UE<FEC82]3=%]*;VAN<R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3$R-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TYE=V9O
M=6YD;&%N9"!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G3E-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@)TYE=V9O=6YD;&%N9"!$87EL:6=H="!4:6UE)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G3D14)R`I+`H@("`@)T-.5"<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$R-C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)TYE=V9O=6YD;&%N9"!3=&%N9&%R9"!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G3E-4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TYE=V9O
M=6YD;&%N9"!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G3D14)R`I+`H@("`@)T-A;F%D82].97=F;W5N9&QA;F0G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ,C8P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=.97=F;W5N9&QA;F0@4W1A;F1A<F0@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)TY35"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=.97=F;W5N9&QA
M;F0@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@
M)TY$5"<@*2P*("`@("=!1U0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^("TQ,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!<F=E;G1I
M;F4@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%25"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+T%R86=U86EN
M82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$P.#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T)R87II;"!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G0E)4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E
M+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T)R87II;"!3=6UM97(@5&EM
M92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T)24U0G("DL"B`@("`G
M06UE<FEC82]"96QE;2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T)R87II;"!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0E)4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O0G5E;F]S7T%I<F5S)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3`X,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G07)G96YT:6YE(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=!4E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G06UE<FEC82]#871A;6%R8V$G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TQ,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=!<F=E;G1I;F4@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%2
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A
M+T-A>65N;F4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ,#@P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=&<F5N8V@@1W5I86YA(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='1E0G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]#;W)D;V)A)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3`X,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G07)G96YT:6YE(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=!4E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G06UE<FEC82]&;W)T86QE>F$G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^("TQ,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("="
M<F%Z:6P@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T)25"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("="<F%Z:6P@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("="4E-4)R`I+`H@("`@)T%M97)I8V$O1V]D=&AA8B<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$P.#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)U=E<W1E<FX@1W)E96YL86YD(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=71U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G5V5S=&5R;B!'<F5E;FQA
M;F0@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=7
M1U-4)R`I+`H@("`@)T%M97)I8V$O2G5J=7DG(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TQ,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=!<F=E;G1I;F4@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%2
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A
M+TUA8V5I;R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$P.#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T)R87II;"!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G0E)4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T)R87II;"!3=6UM
M97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T)24U0G("DL
M"B`@("`G06UE<FEC82]-96YD;WIA)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`M,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G07)G
M96YT:6YE(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4E0G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]-:7%U
M96QO;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$P.#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U!I97)R92`F($UI<75E;&]N(%-T
M86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=035-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M
M92<@/3X@)U!I97)R92`F($UI<75E;&]N($1A>6QI9VAT(%1I;64G+`H@("`@
M("`@("=D<W1S:&]R=&YA;64G(#T^("=03414)R`I+`H@("`@)T%M97)I8V$O
M36]N=&5V:61E;R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$P
M.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U5R=6=U87D@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U595"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+U!A<F%M87)I8F\G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ,#@P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=3=7)I;F%M92!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G4U)4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)T%M97)I8V$O4F5C:69E)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0G)A>FEL
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("="4E0G+`H@("`@("`@
M("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G
M0G)A>FEL(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]
M/B`G0E)35"<@*2P*("`@("=!;65R:6-A+U)O<V%R:6\G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^("TQ,#@P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=!<F=E;G1I;F4@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T%25"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!
M;65R:6-A+U-A;U]0875L;R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@+3$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T)R87II;"!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0E)4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T)R
M87II;"!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@
M)T)24U0G("DL"B`@("`G0D54)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0G)A>FEL
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("="4E0G+`H@("`@("`@
M("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G
M0G)A>FEL(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]
M/B`G0E)35"<@*2P*("`@("="<F%Z:6PO16%S="<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T)R87II;"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0E)4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG
M;F%M92<@/3X@)T)R87II;"!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)T)24U0G("DL"B`@("`G171C+T=-5"LS)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3`X,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G1TU4+3`S.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G1TU4+3`S.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)T%M97)I8V$O3F]R;VYH82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1F5R;F%N
M9&\@9&4@3F]R;VYH82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M1DY4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%T;&%N
M=&EC+U-O=71H7T=E;W)G:6$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^("TW,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U-O=71H($=E
M;W)G:6$@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T=35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("="<F%Z
M:6PO1&5.;W)O;FAA)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M
M-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=&97)N86YD;R!D92!.
M;W)O;FAA(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=&3E0G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G171C+T=-5"LR)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M-S(P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("='350M,#(Z,#`G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("='350M,#(Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G06UE<FEC82]38V]R97-B>7-U;F0G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^("TS-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T5A<W1E<FX@1W)E96YL86YD(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=%1U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@
M("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!'<F5E;FQA;F0@4W5M;65R
M(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%1U-4)R`I+`H@
M("`@)T%T;&%N=&EC+T%Z;W)E<R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G07IO<F5S
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!6D]4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@
M)T%Z;W)E<R!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)T%:3U-4)R`I+`H@("`@)T%T;&%N=&EC+T-A<&5?5F5R9&4G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS-C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T-A<&4@5F5R9&4@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T-65"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=%=&,O1TU4*S$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M("TS-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-5"TP,3HP,"<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"TP,3HP,"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O06)I9&IA;B<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("='<F5E;G=I8V@@365A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G1TU4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)T%F<FEC82]!8V-R82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='<F5E;G=I8V@@365A;B!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82]"86UA:V\G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G1W)E96YW:6-H($UE86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T=-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=!9G)I8V$O0F%N:G5L)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=R965N=VEC:"!-96%N(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+T)I<W-A=2<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("='<F5E;G=I8V@@365A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G1TU4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T%F<FEC82]#87-A8FQA;F-A)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U=E<W1E<FX@175R;W!E
M86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U=%5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O0V]N86MR>2<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("='<F5E;G=I8V@@365A;B!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G1TU4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T%F<FEC82]$86MA<B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='<F5E;G=I8V@@365A
M;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82]%;%]!86EU;B<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=797-T97)N($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=7150G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G069R:6-A+T9R965T;W=N)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=R965N=VEC
M:"!-96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+TQO;64G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G1W)E96YW:6-H($UE86X@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T=-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=!9G)I8V$O36]N<F]V:6$G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1W)E96YW:6-H
M($UE86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O3F]U86MC
M:&]T="<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("='<F5E;G=I8V@@365A;B!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G1TU4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)T%F<FEC82]/=6%G861O=6=O=2<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='
M<F5E;G=I8V@@365A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M1TU4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC
M82]386]?5&]M92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("='<F5E;G=I8V@@365A;B!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82]4:6UB=6MT=2<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("='<F5E;G=I8V@@365A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G1TU4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M
M97)I8V$O1&%N;6%R:W-H879N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=R965N=VEC:"!-96%N
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G071L86YT:6,O0V%N87)Y)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)U=E<W1E<FX@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)U=%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=797-T97)N($5U<F]P96%N(%-U
M;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G5T535"<@
M*2P*("`@("=!=&QA;G1I8R]&865R;V4G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5V5S=&5R;B!%
M=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5T54)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M
M92<@/3X@)U=E<W1E<FX@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@
M("=D<W1S:&]R=&YA;64G(#T^("=715-4)R`I+`H@("`@)T%T;&%N=&EC+TUA
M9&5I<F$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G5V5S=&5R;B!%=7)O<&5A;B!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G5T54)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)U=E<W1E<FX@175R
M;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=715-4)R`I+`H@("`@)T%T;&%N=&EC+U)E>6MJ879I:R<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("='<F5E;G=I8V@@365A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G1TU4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%T
M;&%N=&EC+U-T7TAE;&5N82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='<F5E;G=I8V@@365A;B!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T5I<F4G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1W)E
M96YW:6-H($UE86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N
M9VYA;64G(#T^("=)<FES:"!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)TE35"<@*2P*("`@("=%=&,O1TU4)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T=-5"LP,#HP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"LP,#HP
M,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=%=&,O1TU4
M*S`G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G1TU4*S`P.C`P)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G1TU4*S`P.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T5T8R]'350M,"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350K,#`Z,#`G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("='350K,#`Z,#`G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G171C+T=-5#`G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4
M*S`P.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4*S`P.C`P)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T5T8R]'<F5E;G=I
M8V@G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G1W)E96YW:6-H($UE86X@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T=-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=%=&,O54-4)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-O;W)D:6YA=&5D(%5N
M:79E<G-A;"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G551#)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T5T8R]55$,G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G0V]O<F1I;F%T960@56YI=F5R<V%L(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=55$,G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G171C+U5N:79E<G-A;"<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#;V]R9&EN
M871E9"!5;FEV97)S86P@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)U540R<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=%=&,O
M6G5L=2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=#;V]R9&EN871E9"!5;FEV97)S86P@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U540R<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=%=7)O<&4O0F5L9F%S="<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("='<F5E;G=I8V@@365A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G1TU4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@)T)R:71I<V@@4W5M;65R(%1I;64G+`H@("`@("`@
M("=D<W1S:&]R=&YA;64G(#T^("="4U0G("DL"B`@("`G175R;W!E+T1U8FQI
M;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("='<F5E;G=I8V@@365A;B!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G1TU4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E
M+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TER:7-H(%-U;6UE<B!4:6UE
M)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G25-4)R`I+`H@("`@)T5U
M<F]P92],:7-B;VXG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5V5S=&5R;B!%=7)O<&5A;B!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5T54)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)U=E<W1E
M<FX@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("=715-4)R`I+`H@("`@)T5U<F]P92],;VYD;VXG(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G1W)E96YW:6-H($UE86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T=-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^("="<FET:7-H(%-U;6UE<B!4:6UE)RP*("`@("`@
M("`G9'-T<VAO<G1N86UE)R`]/B`G0E-4)R`I+`H@("`@)T=")R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T=R965N=VEC:"!-96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("='350G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@
M)V1S=&QO;F=N86UE)R`]/B`G0G)I=&ES:"!3=6UM97(@5&EM92<L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)T)35"<@*2P*("`@("='0BU%:7)E)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T=R965N=VEC:"!-96%N(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("='350G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0G)I=&ES:"!3=6UM97(@5&EM92<L
M"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T)35"<@*2P*("`@("='350G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G1W)E96YW:6-H($UE86X@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T=-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("='350P)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-5"LP,#HP,"<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T=-5"LP,#HP,"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("='<F5E;G=I8V@G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1W)E96YW
M:6-H($UE86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=)8V5L86YD)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T=R965N=VEC:"!-96%N(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("='350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G4&]R='5G86PG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5V5S=&5R;B!%=7)O<&5A;B!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5T54)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)U=E
M<W1E<FX@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=715-4)R`I+`H@("`@)U5#5"<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#;V]R
M9&EN871E9"!5;FEV97)S86P@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)U540R<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=5
M5$,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G0V]O<F1I;F%T960@56YI=F5R<V%L(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=55$,G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G56YI=F5R<V%L)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-O;W)D
M:6YA=&5D(%5N:79E<G-A;"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G551#)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U=%
M5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=797-T97)N($5U<F]P96%N(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=7150G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G5V5S=&5R;B!%=7)O<&5A
M;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)U=%
M4U0G("DL"B`@("`G6G5L=2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#;V]R9&EN871E9"!5;FEV
M97)S86P@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U540R<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O06QG:65R
M<R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=#150G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G069R:6-A+T)A;F=U:2<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=797-T97)N($%F<FEC86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)U=!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=!9G)I8V$O0G)A>GIA=FEL;&4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5V5S=&5R
M;B!!9G)I8V%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=7050G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+T-E
M=71A)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#96YT<F%L
M($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G0T535"<@*2P*("`@("=!9G)I8V$O1&]U86QA)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)U=E<W1E<FX@069R:6-A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G5T%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)T%F<FEC82]+:6YS:&%S82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=797-T97)N
M($%F<FEC86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U=!5"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O3&%G
M;W,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G5V5S=&5R;B!!9G)I8V%N(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=7050G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G069R:6-A+TQI8G)E=FEL;&4G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G5V5S=&5R;B!!9G)I8V%N(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=7050G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G069R:6-A+TQU86YD82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=797-T97)N
M($%F<FEC86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U=!5"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O36%L
M86)O)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)U=E<W1E<FX@069R:6-A;B!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G5T%4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82].9&IA;65N82<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=797-T97)N($%F<FEC86X@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)U=!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=!9G)I8V$O3FEA;65Y)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U=E<W1E<FX@
M069R:6-A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5T%4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82]0;W)T
M;RU.;W9O)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U=E<W1E<FX@069R:6-A;B!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5T%4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82]4=6YI<R<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=#96YT<F%L($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=#150G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G069R:6-A+U=I;F1H;V5K)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U=E<W1E
M<FX@069R:6-A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5T%4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG
M;F%M92<@/3X@)U=E<W1E<FX@069R:6-A;B!3=6UM97(@5&EM92<L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)U=!4U0G("DL"B`@("`G07)C=&EC+TQO
M;F=Y96%R8GEE;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#150G+`H@("`@("`@
M("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G
M0V5N=')A;"!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)T-%4U0G("DL"B`@("`G071L86YT:6,O2F%N7TUA>65N
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@1W)E96YL86YD(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=%1U0G+`H@("`@("`@("=H87-D<W0G
M(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!'
M<F5E;FQA;F0@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G
M(#T^("=%1U-4)R`I+`H@("`@)T-%5"<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT
M<F%L($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#
M150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO
M;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@
M("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-%4U0G("DL"B`@("`G0T535"<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^(")#96YT<F%L($5U<F]P96%N(%1I;64B+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=#150G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`B0V5N=')A;"!%=7)O
M<&5A;B!3=6UM97(@5&EM92(L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@
M)T-%4U0G("DL"B`@("`G14-4)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@
M175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^("=#96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@
M("`G9'-T<VAO<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=%=&,O1TU4+3$G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G1TU4*S`Q.C`P)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G1TU4*S`Q.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T5U<F]P92]!;7-T97)D86TG(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M0V5N=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@4W5M;65R(%1I;64G
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@)T5U
M<F]P92]!;F1O<G)A)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S
M-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E
M86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^
M("=#96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=%=7)O<&4O0F5L9W)A9&4G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@175R
M;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=#15-4)R`I+`H@("`@)T5U<F]P92]"97)L:6XG(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G0V5N=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@
M("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@4W5M;65R(%1I
M;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@
M)T5U<F]P92]"<F%T:7-L879A)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@
M175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^("=#96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@
M("`G9'-T<VAO<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=%=7)O<&4O0G)U
M<W-E;',G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T54)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R
M86P@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("=#15-4)R`I+`H@("`@)T5U<F]P92]"=61A<&5S="<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=#150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L
M"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!3
M=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-%4U0G
M("DL"B`@("`G175R;W!E+T-O<&5N:&%G96XG(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M0V5N=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@4W5M;65R(%1I;64G
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@)T5U
M<F]P92]':6)R86QT87(G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O
M<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T54)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@)T-E;G1R86P@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@)T5U<F]P92],:G5B;&IA
M;F$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T54)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@
M175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G
M(#T^("=#15-4)R`I+`H@("`@)T5U<F]P92],=7AE;6)O=7)G)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%-U
M;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T535"<@
M*2P*("`@("=%=7)O<&4O36%D<FED)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R
M86P@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N
M9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=%=7)O<&4O
M36%L=&$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T54)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R
M86P@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("=#15-4)R`I+`H@("`@)T5U<F]P92]-;VYA8V\G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@4W5M
M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I
M+`H@("`@)T5U<F]P92]/<VQO)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@
M175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^("=#96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@
M("`G9'-T<VAO<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=%=7)O<&4O4&%R
M:7,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T54)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@
M175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G
M(#T^("=#15-4)R`I+`H@("`@)T5U<F]P92]0<F%G=64G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@
M("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@4W5M;65R
M(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@
M("`@)T5U<F]P92]2;VUE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@175R
M;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("=#96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=%=7)O<&4O4V%N7TUA
M<FEN;R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#150G+`H@("`@("`@("=H87-D
M<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A
M;"!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M
M92<@/3X@)T-%4U0G("DL"B`@("`G175R;W!E+U-A<F%J979O)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%-U
M;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T535"<@
M*2P*("`@("=%=7)O<&4O4VMO<&IE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R
M86P@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N
M9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=%=7)O<&4O
M4W1O8VMH;VQM)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#
M96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO
M<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=%=7)O<&4O5&ER86YE)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U
M92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N
M(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T53
M5"<@*2P*("`@("=%=7)O<&4O5F%D=7HG(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N
M=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@4W5M;65R(%1I;64G+`H@
M("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@)T5U<F]P
M92]6871I8V%N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#
M96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO
M<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=%=7)O<&4O5FEE;FYA)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U
M92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N
M(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T53
M5"<@*2P*("`@("=%=7)O<&4O5V%R<V%W)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E
M;G1R86P@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T-%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T
M;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=%=7)O
M<&4O6F%G<F5B)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#
M96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO
M<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=%=7)O<&4O6G5R:6-H)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U
M92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N
M(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T53
M5"<@*2P*("`@("=-150G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G36ED9&QE($5U<F]P
M92!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G3454)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@
M)TUI9&1L92!%=7)O<&4@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=-15-4)R`I+`H@("`@)U!O;&%N9"<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=#96YT<F%L($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=#150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@
M("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!3=6UM97(@
M5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-%4U0G("DL"B`@
M("`G05)4)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5%5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T
M97)N($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N
M86UE)R`]/B`G14535"<@*2P*("`@("=!9G)I8V$O0FQA;G1Y<F4G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G0V5N=')A;"!!9G)I8V%N(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=#050G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G069R:6-A+T)U:G5M8G5R82<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#
M96YT<F%L($%F<FEC86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T-!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I
M8V$O0V%I<F\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1454)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A
M<W1E<FX@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=%15-4)R`I+`H@("`@)T%F<FEC82]'86)O<F]N92<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=#96YT<F%L($%F<FEC86X@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T-!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=!9G)I8V$O2&%R87)E)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E
M;G1R86P@069R:6-A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M0T%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC
M82]*;VAA;FYE<V)U<F<G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4V]U=&@@069R:6-A
M(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=305-4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82]+
M:6=A;&DG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!!9G)I8V%N(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#050G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+TQU8G5M8F%S:&DG(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G0V5N=')A;"!!9G)I8V%N(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=#050G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G069R:6-A+TQU<V%K82<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT
M<F%L($%F<FEC86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-!
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O
M36%P=71O)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@069R:6-A;B!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T%4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82]-87-E<G4G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G4V]U=&@@069R:6-A(%-T86YD87)D(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=305-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)T%F<FEC82]-8F%B86YE)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)U-O=71H($%F<FEC82!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G4T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=!9G)I8V$O5')I<&]L:2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N
M($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%150G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]!;6UA
M;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=%150G+`H@("`@("`@("=H87-D<W0G
M(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!%
M=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)T5%4U0G("DL"B`@("`G07-I82]"96ER=70G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G16%S=&5R;B!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G1454)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@
M("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@4W5M;65R(%1I
M;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%15-4)R`I+`H@("`@
M)T%S:6$O1&%M87-C=7,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O
M<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1454)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@)T5A<W1E<FX@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=%15-4)R`I+`H@("`@)T%S:6$O1V%Z82<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=%150G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A
M;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5%
M4U0G("DL"B`@("`G07-I82])<W1A;F)U;"<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%
M87-T97)N($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=%150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S
M=&QO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92<L
M"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5%4U0G("DL"B`@("`G07-I
M82]*97)U<V%L96TG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G27-R865L(%-T86YD87)D
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=)4U0G+`H@("`@("`@
M("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G
M27-R865L($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G
M(#T^("=)1%0G("DL"B`@("`G07-I82].:6-O<VEA)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T5A<W1E<FX@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T5%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@
M("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N(%-U;6UE<B!4
M:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G14535"<@*2P*("`@
M("=!<VEA+U1E;%]!=FEV)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TES<F%E;"!3=&%N
M9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G25-4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@)TES<F%E;"!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N
M86UE)R`]/B`G2414)R`I+`H@("`@)T-!5"<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#
M96YT<F%L($%F<FEC86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T-!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=%150G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G1454)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R
M;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=%15-4)R`I+`H@("`@)T5G>7!T)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E
M<FX@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5%
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N
M9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G14535"<@*2P*("`@("=%=&,O1TU4
M+3(G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G1TU4*S`R.C`P)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G1TU4*S`R.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)T5U<F]P92]!=&AE;G,G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M16%S=&5R;B!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G1454)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@4W5M;65R(%1I;64G
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%15-4)R`I+`H@("`@)T5U
M<F]P92]"=6-H87)E<W0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O
M<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1454)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@)T5A<W1E<FX@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=%15-4)R`I+`H@("`@)T5U<F]P92]#:&ES:6YA
M=2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=%150G+`H@("`@("`@("=H87-D<W0G
M(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!%
M=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)T5%4U0G("DL"B`@("`G175R;W!E+TAE;'-I;FMI)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T5A<W1E<FX@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T5%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@
M("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N(%-U;6UE
M<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G14535"<@*2P*
M("`@("=%=7)O<&4O27-T86YB=6PG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R
M;B!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1454
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG
M;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@
M("`@("=D<W1S:&]R=&YA;64G(#T^("=%15-4)R`I+`H@("`@)T5U<F]P92]+
M86QI;FEN9W)A9"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%150G+`H@("`@("`@
M("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G
M16%S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)T5%4U0G("DL"B`@("`G175R;W!E+TMI978G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G1454)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E
M+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@
M4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%15-4
M)R`I+`H@("`@)T5U<F]P92]-:6YS:R<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T
M97)N($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%
M150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO
M;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@
M("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5%4U0G("DL"B`@("`G175R;W!E
M+TYI8V]S:6$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1454)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A
M<W1E<FX@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=%15-4)R`I+`H@("`@)T5U<F]P92]2:6=A)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T5%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N(%-U
M;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G14535"<@
M*2P*("`@("=%=7)O<&4O4VEM9F5R;W!O;"<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%
M87-T97)N($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=%150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S
M=&QO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92<L
M"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5%4U0G("DL"B`@("`G175R
M;W!E+U-O9FEA)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5%5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%
M87-T97)N($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO
M<G1N86UE)R`]/B`G14535"<@*2P*("`@("=%=7)O<&4O5&%L;&EN;B<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=%150G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G175R;W!E+U1I<F%S<&]L)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T5A<W1E<FX@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T5%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N(%-U;6UE<B!4:6UE
M)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G14535"<@*2P*("`@("=%
M=7)O<&4O57IH9V]R;V0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O
M<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1454)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@)T5A<W1E<FX@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=%15-4)R`I+`H@("`@)T5U<F]P92]6:6QN:75S
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T5%5"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=%=7)O<&4O6F%P;W)O>FAY92<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=%87-T97)N($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=%150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!3=6UM
M97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5%4U0G("DL
M"B`@("`G27-R865L)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W
M,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TES<F%E;"!3=&%N9&%R
M9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G25-4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@
M)TES<F%E;"!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G2414)R`I+`H@("`@)TQI8GEA)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A
M<W1E<FX@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T5%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=4=7)K
M97DG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G1454)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@
M175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G
M(#T^("=%15-4)R`I+`H@("`@)T%F<FEC82]!9&1I<U]!8F%B82<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3`X,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G16%S=&5R;B!!9G)I8V%N(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=%050G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G069R:6-A+T%S;65R82<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S
M=&5R;B!!9G)I8V%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%
M050G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A
M+T1A<E]E<U]386QA86TG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@069R
M:6-A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G14%4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82]$:FEB;W5T
M:2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3`X,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!!9G)I8V%N(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=%050G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G069R:6-A+TMA;7!A;&$G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T5A<W1E<FX@069R:6-A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G14%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)T%F<FEC82]+:&%R=&]U;2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R
M;B!!9G)I8V%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%050G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+TUO
M9V%D:7-H=2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3`X,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!!9G)I8V%N(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%050G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+TYA:7)O8FDG(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$P.#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T5A<W1E<FX@069R:6-A;B!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G14%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T%N=&%R8W1I8V$O4WEO=V$G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)U-Y;W=A(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=364]4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O061E;B<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3`X,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G07)A8FEA(%-T86YD87)D(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G07-I82]"86=H9&%D)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`Q,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=!<F%B:6$@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^("=!<F%B:6$@1&%Y;&EG:'0@5&EM92<L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)T%$5"<@*2P*("`@("=!<VEA+T)A:')A
M:6XG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$P.#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T%R86)I82!3=&%N9&%R9"!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G05-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)T%S:6$O2W5W86ET)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`Q,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=!<F%B:6$@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=!<VEA+U%A=&%R)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q
M,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!<F%B:6$@4W1A;F1A
M<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%35"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+U)I>6%D:"<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3`X,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G07)A8FEA(%-T86YD87)D(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G14%4)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`Q,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N($%F
M<FEC86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5!5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=%=&,O1TU4+3,G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$P.#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T=-5"LP,SHP,"<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T=-5"LP,SHP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=%=7)O<&4O36]S8V]W)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`Q,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=-;W-C
M;W<@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU3
M2R<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N
M9VYA;64G(#T^("=-;W-C;W<@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S
M='-H;W)T;F%M92<@/3X@)TU31"<@*2P*("`@("=);F1I86XO06YT86YA;F%R
M:79O)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q,#@P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N($%F<FEC86X@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5!5"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=);F1I86XO0V]M;W)O)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`Q,#@P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=%87-T97)N($%F<FEC86X@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T5!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=);F1I86XO36%Y;W1T92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R
M;B!!9G)I8V%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%050G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G5RU352<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3`X,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G36]S8V]W(%-T86YD87)D(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=-4TLG+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G36]S8V]W($1A>6QI9VAT
M(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=-4T0G("DL"B`@
M("`G07-I82]2:7EA9&@X-R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,3$R,C0P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4*S`S.C`W
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4*S`S.C`W)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O4FEY861H.#@G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$Q,C(T,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T=-5"LP,SHP-R<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T=-5"LP,SHP-R<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=!<VEA+U)I>6%D:#@Y)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`Q,3(R-#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350K
M,#,Z,#<G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350K,#,Z,#<G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G36ED96%S="]2:7EA
M9&@X-R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3$R,C0P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4*S`S.C`W)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G1TU4*S`S.C`W)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)TUI9&5A<W0O4FEY861H.#@G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#$Q,C(T,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T=-5"LP,SHP-R<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-
M5"LP,SHP-R<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=-
M:61E87-T+U)I>6%D:#@Y)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`Q,3(R-#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350K,#,Z,#<G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350K,#,Z,#<G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]496AR86XG(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$R-C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)TER86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)TE25"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^("=)<F%N(%-U;65R(%1I;64G+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=)4E-4)R`I+`H@("`@)TER86XG(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#$R-C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)TER86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)TE25"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T
M;&]N9VYA;64G(#T^("=)<F%N(%-U;65R(%1I;64G+`H@("`@("`@("=D<W1S
M:&]R=&YA;64G(#T^("=)4E-4)R`I+`H@("`@)T%S:6$O07%T874G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$T-#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T%Q=&%U(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=!4514)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@
M("=D<W1L;VYG;F%M92<@/3X@)T%Q=&%U(%-U;6UE<B!4:6UE)RP*("`@("`@
M("`G9'-T<VAO<G1N86UE)R`]/B`G05%44U0G("DL"B`@("`G07-I82]"86MU
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q-#0P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=!>F5R8F%I:F%N(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=!6E0G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G07IE<F)A:6IA;B!3=6UM
M97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T%:4U0G("DL
M"B`@("`G07-I82]$=6)A:2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1W5L9B!3=&%N
M9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1U-4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O375S8V%T)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q-#0P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("='=6QF(%-T86YD87)D(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("='4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G07-I82]48FEL:7-I)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`Q-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='
M96]R9VEA(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='150G+`H@
M("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE
M)R`]/B`G1V5O<F=I82!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T
M;F%M92<@/3X@)T=%4U0G("DL"B`@("`G07-I82]997)E=F%N)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q-#0P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=!<FUE;FEA(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=!350G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@
M)V1S=&QO;F=N86UE)R`]/B`G07)M96YI82!3=6UM97(@5&EM92<L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)T%-4U0G("DL"B`@("`G171C+T=-5"TT
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q-#0P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("='350K,#0Z,#`G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("='350K,#0Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G175R;W!E+U-A;6%R82<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M4V%M87)A(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=304U4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M
M92<@/3X@)U-A;6%R82!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T
M;F%M92<@/3X@)U-!35-4)R`I+`H@("`@)TEN9&EA;B]-86AE)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q-#0P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=397EC:&5L;&5S(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=30U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G26YD:6%N+TUA=7)I=&EU<R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G36%U<FET
M:75S(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=-550G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G26YD:6%N+U)E=6YI;VXG
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$T-#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)U)E=6YI;VX@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)U)%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=.150G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$T
M-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%R;65N:6$@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%-5"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=!<FUE;FEA
M(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G04U3
M5"<@*2P*("`@("=!<VEA+TMA8G5L)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`Q-C(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!9F=H
M86YI<W1A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0494)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O07%T;V)E
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q.#`P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=!<71O8F4@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T%15%0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L
M"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G07%T;V)E(%-U;6UE<B!4:6UE
M)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G05%44U0G("DL"B`@("`G
M07-I82]!<VAG86)A="<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5'5R:VUE;FES=&%N
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=4350G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]!<VAK:&%B860G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$X,#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)U1U<FMM96YI<W1A;B!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G5$U4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T%S:6$O0FES:&ME:R<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G2VER
M9VEZ<W1A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G2T=4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M
M92<@/3X@)TMI<F=I>G-T86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S
M:&]R=&YA;64G(#T^("=+1U-4)R`I+`H@("`@)T%S:6$O1'5S:&%N8F4G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$X,#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)U1A:FEK:7-T86X@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)U1*5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=!<VEA+TMA<F%C:&DG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U!A:VES
M=&%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=02U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]386UA<FMA;F0G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$X,#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)U1U<FMM96YI<W1A;B!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G5$U4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)T%S:6$O5&%S:&ME;G0G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)U5Z8F5K:7-T86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U5:
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+UEE
M:V%T97)I;F)U<F<G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$X
M,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)UEE:V%T97)I;F)U<F<@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)UE%2U0G+`H@("`@("`@
M("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G
M665K871E<FEN8G5R9R!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T
M;F%M92<@/3X@)UE%2U-4)R`I+`H@("`@)T5T8R]'350M-2<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G1TU4*S`U.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M1TU4*S`U.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)TEN9&EA;B]+97)G=65L96XG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T9R96YC:"!3
M;W5T:&5R;B`F($%N=&%R8W1I8R!,86YD<R!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G5$94)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)TEN9&EA;B]-86QD:79E<R<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G36%L
M9&EV97,@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU65"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=03%0G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#$X,#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)U!A:VES=&%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=02U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M07-I82]#86QC=71T82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,3DX,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G26YD:6$@4W1A;F1A
M<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TE35"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=)4U0G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#$Y.#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)TEN9&EA(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=)4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G07-I82]+871M86YD=2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,C`W,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G3F5P86P@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TY05"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;G1A<F-T:6-A+TUA=W-O;B<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C$V,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G36%W<V]N(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=-05=4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)T%N=&%R8W1I8V$O5F]S=&]K)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`R,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=6;W-T
M;VL@=&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U9/4U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]!;&UA='DG(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(Q-C`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T%L;6$M071A(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=!3$U4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T%L;6$M071A(%-U;6UE<B!4:6UE
M)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G04Q-4U0G("DL"B`@("`G
M07-I82]#;VQO;6)O)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R
M,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=3<FD@3&%N:V$@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TQ+5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+T1A8V-A)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`R,38P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("="86YG;&%D97-H(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("="1%0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M07-I82]$:&%K82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C$V
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0F%N9VQA9&5S:"!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0D14)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O3F]V;W-I8FER<VLG(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(Q-C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)TYO=F]S:6)I<G-K(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=.3U94)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TYO=F]S:6)I<G-K(%-U;6UE<B!4
M:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G3D]64U0G("DL"B`@
M("`G07-I82]/;7-K)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R
M,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=/;7-K(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=/35-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T]M<VL@4W5M
M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=/35-35"<@
M*2P*("`@("=!<VEA+U1H:6UB=2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0FAU=&%N
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("="5%0G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]4:&EM<&AU)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R,38P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=":'5T86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T)45"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("="1%0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(Q-C`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T)A;F=L861E<V@@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T)$5"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=%=&,O1TU4+38G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T=-5"LP-CHP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"LP-CHP
M,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=);F1I86XO
M0VAA9V]S)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R,38P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=);F1I86X@3V-E86X@5&5R<FET
M;W)Y(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=)3U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]286YG;V]N)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R,S0P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=->6%N;6%R(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=-350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G26YD:6%N+T-O8V]S)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`R,S0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#;V-O<R!)
M<VQA;F1S(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#0U0G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06YT87)C=&EC82]$
M879I<R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C4R,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1&%V:7,@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T1!5E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G07-I82]"86YG:V]K)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`R-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=)
M;F1O8VAI;F$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TE#5"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+TAO=F0G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(U,C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)TAO=F0@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)TA/5E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G07-I82]*86MA<G1A)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`R-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=797-T($EN
M9&]N97-I82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5TE4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O2W)A<VYO
M>6%R<VLG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(U,C`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TMR87-N;WEA<G-K(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=+4D%4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TMR87-N;WEA
M<G-K(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G
M2U)!4U0G("DL"B`@("`G07-I82]0:&YO;5]096YH)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`R-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=);F1O8VAI;F$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)TE#5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA
M+U!O;G1I86YA:R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C4R
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5V5S="!);F1O;F5S:6$@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U=)5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+U-A:6=O;B<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C4R,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G26YD;V-H:6YA(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=)0U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G07-I82]6:65N=&EA;F4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TEN9&]C:&EN
M82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G24-4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T5T8R]'350M-R<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C4R,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G1TU4*S`W.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G1TU4*S`W.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)TEN9&EA;B]#:')I<W1M87,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-H<FES
M=&UA<R!)<VQA;F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-8
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=64U0G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(U,C`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)TEN9&]C:&EN82!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G24-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T%N=&%R8W1I8V$O0V%S97DG(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U=E
M<W1E<FX@4W1A;F1A<F0@5&EM92`H075S=')A;&EA*2<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)U=35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=!<VEA+T)R=6YE:2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0G)U;F5I
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("="3E0G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]#:&]N9W%I;F<G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T-H:6YA(%-T86YD87)D(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G07-I82]#:'5N9VMI;F<G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T-H:6YA(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I
M82](87)B:6XG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-H:6YA(%-T86YD87)D(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82](;VYG7TMO;F<G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)TAO;F<@2V]N9R!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G2$M4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)T%S:6$O27)K=71S:R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G27)K=71S:R!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G25)+5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=)
M<FMU='-K(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]
M/B`G25)+4U0G("DL"B`@("`G07-I82]+87-H9V%R)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=#:&EN82!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T%S:6$O2W5A;&%?3'5M<'5R)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=-86QA>7-I
M82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G35E4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O2W5C:&EN9R<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C@X,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G36%L87ES:6$@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)TU95"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=!<VEA+TUA8V%O)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#:&EN82!3=&%N
M9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O36%N:6QA)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=0:&EL:7!P:6YE<R!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G4$A4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T%S:6$O4VAA;F=H86DG(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-H
M:6YA(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#
M4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]3
M:6YG87!O<F4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U-I;F=A<&]R92!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G4T=4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)T%S:6$O5&%I<&5I)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=#:&EN82!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T%S:6$O56IU;F=?4&%N9&%N9R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A
M;"!);F1O;F5S:6$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-)
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+U5L
M86%N8F%A=&%R)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R.#@P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=5;&%A;F)A871A<B!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G54Q!5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+U5L86Y?0F%T;W(G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)U5L86%N8F%A=&%R(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=53$%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T%S:6$O57)U;7%I)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#:&EN82!3
M=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%U<W1R86QI82]0
M97)T:"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C@X,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5V5S=&5R;B!3=&%N9&%R9"!4:6UE
M("A!=7-T<F%L:6$I)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5U-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%U<W1R86QI82]7
M97-T)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=797-T97)N(%-T86YD87)D(%1I;64@
M*$%U<W1R86QI82DG+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=74U0G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G0U14)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=#:&EN82!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T5T8R]'350M."<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4*S`X.C`P
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4*S`X.C`P)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TAO;F=K;VYG)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=(;VYG($MO;F<@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)TA+5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=04D,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-H:6YA(%-T86YD87)D(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G4VEN9V%P;W)E)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=3:6YG87!O<F4@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)U-'5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA
M+T-H;VEB86QS86XG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,R
M-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-H;VEB86QS86X@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-(3U0G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]$:6QI)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`S,C0P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=%87-T(%1I;6]R(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=44%0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M07-I82]*87EA<'5R82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,S(T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S="!);F1O;F5S
M:6$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5)5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+U!Y;VYG>6%N9R<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S(T,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G2V]R96$@4W1A;F1A<F0@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)TM35"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=!<VEA+U-E;W5L)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`S,C0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=+
M;W)E82!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M2U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O
M5&]K>6\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,R-#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TIA<&%N(%-T86YD87)D(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=*4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]986MU='-K)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`S,C0P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=986MU='-K(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=904M4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@)UEA:W1S:R!3=6UM97(@5&EM92<L"B`@("`@("`@
M)V1S='-H;W)T;F%M92<@/3X@)UE!2U-4)R`I+`H@("`@)T5T8R]'350M.2<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S(T,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G1TU4*S`Y.C`P)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G1TU4*S`Y.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)TI35"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,S(T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G2F%P86X@4W1A;F1A
M<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TI35"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=*87!A;B<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,S(T,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G2F%P86X@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)TI35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=086-I9FEC+U!A;&%U)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`S,C0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=086QA=2!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4%=4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U)/2R<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,S(T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G2V]R96$@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)TM35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!
M0U0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,T,C`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A;F1A<F0@5&EM92`H
M3F]R=&AE<FX@5&5R<FET;W)Y*2<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!=7-T
M<F%L:6$O061E;&%I9&4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#,T,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A
M;F1A<F0@5&EM92`H4V]U=&@@075S=')A;&EA*2<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@
M("`@("`G9'-T;&]N9VYA;64G(#T^("=#96YT<F%L(%-U;6UE<B!4:6UE("A3
M;W5T:"!!=7-T<F%L:6$I)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G
M0U-4)R`I+`H@("`@)T%U<W1R86QI82]"<F]K96Y?2&EL;"<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,S0R,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G0V5N=')A;"!3=&%N9&%R9"!4:6UE("A3;W5T:"!!=7-T<F%L
M:6$O3F5W(%-O=71H(%=A;&5S*2<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T
M;&]N9VYA;64G(#T^("=#96YT<F%L(%-U;6UE<B!4:6UE("A3;W5T:"!!=7-T
M<F%L:6$O3F5W(%-O=71H(%=A;&5S*2<L"B`@("`@("`@)V1S='-H;W)T;F%M
M92<@/3X@)T-35"<@*2P*("`@("=!=7-T<F%L:6$O1&%R=VEN)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-#(P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=#96YT<F%L(%-T86YD87)D(%1I;64@*$YO<G1H97)N(%1E
M<G)I=&]R>2DG+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G075S=')A;&EA+TYO<G1H
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-#(P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L(%-T86YD87)D(%1I;64@*$YO
M<G1H97)N(%1E<G)I=&]R>2DG+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#
M4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G075S=')A
M;&EA+U-O=71H)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-#(P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L(%-T86YD87)D
M(%1I;64@*%-O=71H($%U<W1R86QI82DG+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@
M)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!3=6UM97(@5&EM92`H4V]U=&@@
M075S=')A;&EA*2<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-35"<@
M*2P*("`@("=!=7-T<F%L:6$O66%N8V]W:6YN82<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,S0R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G0V5N=')A;"!3=&%N9&%R9"!4:6UE("A3;W5T:"!!=7-T<F%L:6$O3F5W
M(%-O=71H(%=A;&5S*2<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^("=#96YT<F%L(%-U;6UE<B!4:6UE("A3;W5T:"!!=7-T<F%L:6$O
M3F5W(%-O=71H(%=A;&5S*2<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@
M)T-35"<@*2P*("`@("=!150G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@
M4W1A;F1A<F0@5&EM92`H3F5W(%-O=71H(%=A;&5S*2<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N(%-U;6UE<B!4:6UE
M("A.97<@4V]U=&@@5V%L97,I)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]
M/B`G15-4)R`I+`H@("`@)T%N=&%R8W1I8V$O1'5M;VYT1%5R=FEL;&4G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T1U;6]N="UD7"=5<G9I;&QE(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=$1%54)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)T%S:6$O4V%K:&%L:6XG(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)U-A:VAA;&EN(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=3
M04M4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@)U-A:VAA;&EN(%-U;6UE<B!4:6UE)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G4T%+4U0G("DL"B`@("`G07-I82]6;&%D:79O
M<W1O:R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5FQA9&EV;W-T;VL@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)U9,050G+`H@("`@("`@("=H87-D<W0G
M(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G5FQA9&EV;W-T
M;VL@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=6
M3$%35"<@*2P*("`@("=!=7-T<F%L:6$O04-4)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`S-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=%87-T97)N(%-T86YD87)D(%1I;64@*$YE=R!3;W5T:"!786QE<RDG+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G
M(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!3
M=6UM97(@5&EM92`H3F5W(%-O=71H(%=A;&5S*2<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)T535"<@*2P*("`@("=!=7-T<F%L:6$O0G)I<V)A;F4G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM92`H475E
M96YS;&%N9"DG+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G075S=')A;&EA+T-A;F)E
M<G)A)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD87)D(%1I;64@
M*$YE=R!3;W5T:"!786QE<RDG+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%
M4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO
M;F=N86UE)R`]/B`G16%S=&5R;B!3=6UM97(@5&EM92`H3F5W(%-O=71H(%=A
M;&5S*2<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T535"<@*2P*("`@
M("=!=7-T<F%L:6$O2&]B87)T)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`S-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N
M(%-T86YD87)D(%1I;64@*%1A<VUA;FEA*2<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@
M("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N(%-U;6UE<B!4:6UE("A487-M
M86YI82DG+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%4U0G("DL"B`@
M("`G075S=')A;&EA+TQI;F1E;6%N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`S-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T
M97)N(%-T86YD87)D(%1I;64@*%%U965N<VQA;F0I)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T%U<W1R86QI82]-96QB;W5R;F4G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T5A<W1E<FX@4W1A;F1A<F0@5&EM92`H5FEC=&]R:6$I)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E
M+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@4W5M;65R(%1I
M;64@*%9I8W1O<FEA*2<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T53
M5"<@*2P*("`@("=!=7-T<F%L:6$O3E-7)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`S-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%
M87-T97)N(%-T86YD87)D(%1I;64@*$YE=R!3;W5T:"!786QE<RDG+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!3=6UM
M97(@5&EM92`H3F5W(%-O=71H(%=A;&5S*2<L"B`@("`@("`@)V1S='-H;W)T
M;F%M92<@/3X@)T535"<@*2P*("`@("=!=7-T<F%L:6$O475E96YS;&%N9"<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE("A1=65E
M;G-L86YD*2<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!=7-T<F%L:6$O4WED;F5Y
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD87)D(%1I;64@*$YE
M=R!3;W5T:"!786QE<RDG+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`G16%S=&5R;B!3=6UM97(@5&EM92`H3F5W(%-O=71H(%=A;&5S
M*2<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T535"<@*2P*("`@("=!
M=7-T<F%L:6$O5&%S;6%N:6$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@
M4W1A;F1A<F0@5&EM92`H5&%S;6%N:6$I)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@
M("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@4W5M;65R(%1I;64@*%1A<VUA
M;FEA*2<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T535"<@*2P*("`@
M("=!=7-T<F%L:6$O5FEC=&]R:6$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E
M<FX@4W1A;F1A<F0@5&EM92`H5FEC=&]R:6$I)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@
M("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@4W5M;65R(%1I;64@*%9I
M8W1O<FEA*2<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T535"<@*2P*
M("`@("=%=&,O1TU4+3$P)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`S-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350K,3`Z,#`G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350K,3`Z,#`G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4&%C:69I8R]'=6%M)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=#:&%M;W)R;R!3=&%N9&%R9"!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G0VA35"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=086-I9FEC+U!O<G1?36]R97-B>2<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G4&%P=6$@3F5W($=U:6YE82!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G4$=4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)U!A8VEF:6,O4V%I<&%N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`S-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#:&%M
M;W)R;R!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M0VA35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I
M9FEC+U1R=6LG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U1R=6L@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)U12550G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G4&%C:69I8R]987`G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)UEA<"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G64%05"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!=7-T<F%L:6$O3$A)
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-S@P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=,;V%D($AO=V4@4W1A;F1A<F0@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TQ(4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G3&]A9"!(
M;W=E(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G
M3$A35"<@*2P*("`@("=!=7-T<F%L:6$O3&]R9%](;W=E)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`S-S@P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=,;V%D($AO=V4@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)TQ(4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L
M"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G3&]A9"!(;W=E(%-U;6UE<B!4
M:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G3$A35"<@*2P*("`@
M("=!<VEA+TUA9V%D86XG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#,Y-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUA9V%D86X@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU!1U0G+`H@("`@("`@("=H
M87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G36%G
M861A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@
M)TU!1U-4)R`I+`H@("`@)T5T8R]'350M,3$G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#,Y-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T=-5"LQ,3HP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"LQ,3HP
M,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC
M+T5F871E)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S.38P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=686YU871U(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=6550G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G4&%C:69I8R]'=6%D86QC86YA;"<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,SDV,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G4V]L;VUO;B!)<RX@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)U-"5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=086-I9FEC+TMO<W)A92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,SDV,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G2V]S<F%E(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=+3U-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!A8VEF:6,O3F]U;65A)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S.38P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=.97<@0V%L961O;FEA(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=.0U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G4&%C:69I8R]0;VYA<&4G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#,Y-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U!O
M;F%P92!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4$].5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=34U0G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#,Y-C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)U-O;&]M;VX@27,N(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=30E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G4&%C:69I8R].;W)F;VQK)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`T,30P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=.;W)F;VQK
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=.1E0G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06YT87)C=&EC82]-8TUU<F1O
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`T,S(P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=.97<@6F5A;&%N9"!3=&%N9&%R9"!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G3EI35"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=.97<@
M6F5A;&%N9"!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G3EI$5"<@*2P*("`@("=!;G1A<F-T:6-A+U-O=71H7U!O;&4G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0S,C`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)TYE=R!:96%L86YD(%-T86YD87)D(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=.6E-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TYE=R!:96%L
M86YD($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=.6D14)R`I+`H@("`@)T%S:6$O06YA9'ER)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`T,S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=!;F%D>7(@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%.050G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`G06YA9'ER(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO
M<G1N86UE)R`]/B`G04Y!4U0G("DL"B`@("`G07-I82]+86UC:&%T:V$G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0S,C`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)U!E=')O<&%V;&]V<VLM2V%M8VAA='-K:2!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4$545"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=0971R
M;W!A=FQO=G-K+4MA;6-H871S:VD@4W5M;65R(%1I;64G+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=015135"<@*2P*("`@("=%=&,O1TU4+3$R)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`T,S(P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("='350K,3(Z,#`G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("='350K,3(Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G2W=A:F%L96EN)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`T,S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=-87)S:&%L
M;"!)<VQA;F1S(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=-2%0G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G3E-4)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`T,S(P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=.97<@6F5A;&%N9"!3=&%N9&%R9"!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G3EI35"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=.97<@6F5A;&%N
M9"!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G
M3EI$5"<@*2P*("`@("=.6B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@-#,R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G3F5W(%IE86QA
M;F0@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TY:
M4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO
M;F=N86UE)R`]/B`G3F5W(%IE86QA;F0@1&%Y;&EG:'0@5&EM92<L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)TY:1%0G("DL"B`@("`G4&%C:69I8R]!
M=6-K;&%N9"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-#,R,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G3F5W(%IE86QA;F0@4W1A;F1A
M<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TY:4U0G+`H@("`@
M("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]
M/B`G3F5W(%IE86QA;F0@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)TY:1%0G("DL"B`@("`G4&%C:69I8R]&:6II)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`T,S(P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=&:6II(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=&2E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M4&%C:69I8R]&=6YA9G5T:2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@-#,R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5'5V86QU(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=45E0G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4&%C:69I8R]+=V%J86QE:6XG(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0S,C`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)TUA<G-H86QL($ES;&%N9',@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)TU(5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=086-I9FEC+TUA:G5R;R<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@-#,R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G36%R<VAA;&P@27-L86YD<R!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G34A4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)U!A8VEF:6,O3F%U<G4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#0S,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TYA=7)U(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=.4E0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G4&%C:69I8R]487)A=V$G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#0S,C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T=I;&)E<G0@27,N(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("='24Q4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)U!A8VEF:6,O5V%K92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@-#,R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5V%K92!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5T%+5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC+U=A;&QI<R<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@-#,R,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G5V%L;&ES("8@1G5T=6YA(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=71E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G3EHM0TA!5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@-#4Y,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0VAA=&AA;2!3
M=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0TA!4U0G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`G0VAA=&AA;2!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G0TA!1%0G("DL"B`@("`G4&%C:69I8R]#:&%T:&%M
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`T-3DP,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=#:&%T:&%M(%-T86YD87)D(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=#2$%35"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#:&%T:&%M
M($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#
M2$%$5"<@*2P*("`@("=%=&,O1TU4+3$S)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`T-C@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='
M350K,3,Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350K,3,Z,#`G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4&%C:69I8R]%
M;F1E<F)U<GDG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0V.#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U!H;V5N:7@@27,N(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=02$]4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)U!A8VEF:6,O5&]N9V%T87!U)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`T-C@P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=4;VYG82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G5$]4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T5T8R]'350M,30G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#4P
M-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-5"LQ-#HP,"<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"LQ-#HP,"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC+TMI<FET:6UA=&DG(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#4P-#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)TQI;F4@27,N(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=,24Y4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T=-5"TQ,CHP,"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@+30S,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-5"TQ,CHP
M,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"TQ,CHP,"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("='350M,3$Z,#`G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS.38P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("='350M,3$Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("='350M,3$Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G5V5S="!386UO82!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`M,SDV,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5V5S
M="!386UO82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5U-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U-A;6]A(%-T86YD
M87)D(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS.38P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=386UO82!3=&%N9&%R9"!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4U-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TYI=64@5&EM92<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@+3,Y-C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)TYI=64@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)TY55"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=(87=A
M:6DM06QE=71I86X@4W1A;F1A<F0@5&EM92<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@+3,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)TAA=V%I:2U!;&5U=&EA;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G2$%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=(87=A:6DM06QE=71I86X@1&%Y
M;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TA!1%0G
M("DL"B`@("`G1TU4+3$P.C`P)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4+3$P
M.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4+3$P.C`P)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TAA=V%I:2!3=&%N9&%R
M9"!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,S8P,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G2&%W86EI(%-T86YD87)D(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=(4U0G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G5&]K96QA=2!4:6UE)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,S8P,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G5&]K96QA=2!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G5$M4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T-O;VL@27,N(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M("TS-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#;V]K($ES+B!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0TM4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U1A:&ET:2!4:6UE)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,S8P,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G5&%H:71I(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=404A4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)TUA<G%U97-A<R!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`M,S0R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G36%R<75E<V%S
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=-05)4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%L87-K82!3=&%N9&%R9"!4
M:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,S(T,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G06QA<VMA(%-T86YD87)D(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!2U-4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T%L87-K
M82!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G
M04M$5"<@*2P*("`@("='350M,#DZ,#`G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^("TS,C0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='
M350M,#DZ,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350M,#DZ,#`G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G1V%M8FEE<B!4
M:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,S(T,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1V%M8FEE<B!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G1T%-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=086-I9FEC(%-T86YD87)D(%1I;64G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TR.#@P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=086-I9FEC(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=04U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L
M"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G4&%C:69I8R!$87EL:6=H="!4
M:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G4$14)R`I+`H@("`@
M)T=-5"TP.#HP,"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(X
M.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-5"TP.#HP,"<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"TP.#HP,"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=0:71C86ER;B!3=&%N9&%R9"!4:6UE
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C@X,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G4&ET8V%I<FX@4W1A;F1A<F0@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U!35"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=-;W5N=&%I;B!3=&%N9&%R9"!4:6UE)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C4R,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G36]U;G1A:6X@4W1A;F1A<F0@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)TU35"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=-;W5N=&%I;B!$
M87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G3414
M)R`I+`H@("`@)T=-5"TP-SHP,"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-5"TP
M-SHP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"TP-SHP,"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=#96YT<F%L(%-T86YD
M87)D(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L(%-T86YD87)D
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@
M("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G
M0V5N=')A;"!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G0T14)R`I+`H@("`@)T5A<W1E<FX@4W1A;F1A<F0@5&EM92<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N($1A>6QI
M9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%1%0G("DL
M"B`@("`G16%S=&5R($ES+B!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`M,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S
M=&5R($ES+B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G14%35"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^("=%87-T97(@27,N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G14%34U0G("DL"B`@("`G1TU4+3`V.C`P)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G1TU4+3`V.C`P)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G1TU4+3`V.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T=A;&%P86=O<R!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`M,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1V%L
M87!A9V]S(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='04Q4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T-O;&]M8FEA(%1I
M;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=#;VQO;6)I82!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G0T]4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)T%C<F4@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%C
M<F4@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%#5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=%8W5A9&]R(%1I;64G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=%8W5A9&]R(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=%0U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G4&5R=2!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4&5R=2!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4$54)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)T=-5"TP-3HP,"<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T=-5"TP-3HP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-
M5"TP-3HP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!
M=&QA;G1I8R!3=&%N9&%R9"!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G071L
M86YT:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T
M;&]N9VYA;64G(#T^("=!=&QA;G1I8R!$87EL:6=H="!4:6UE)RP*("`@("`@
M("`G9'-T<VAO<G1N86UE)R`]/B`G0414)R`I+`H@("`@)U!A<F%G=6%Y(%1I
M;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=087)A9W5A>2!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G4%E4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T
M<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)U!A<F%G=6%Y(%-U;6UE
M<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G4%E35"<@*2P*
M("`@("=!;6%Z;VX@4W1A;F1A<F0@5&EM92<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T%M87IO;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G04U4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U9E
M;F5Z=65L82!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M
M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5F5N97IU96QA(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=6150G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G1W5Y86YA(%1I;64G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("='=7EA;F$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T=95"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("="
M;VQI=FEA(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ
M-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=";VQI=FEA(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("="3U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G0VAI;&4@5&EM92<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T-H:6QE(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#
M3%0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO
M;F=N86UE)R`]/B`G0VAI;&4@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S
M:&]R=&YA;64G(#T^("=#3%-4)R`I+`H@("`@)T9A;&ML86YD($ES+B!4:6UE
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G1F%L:VQA;F0@27,N(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=&2U0G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G1F%L:VQA;F0@27,N
M(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G1DM3
M5"<@*2P*("`@("='350M,#0Z,#`G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350M
M,#0Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350M,#0Z,#`G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G3F5W9F]U;F1L86YD
M(%-T86YD87)D(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M("TQ,C8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=.97=F;W5N9&QA
M;F0@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TY3
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N
M9VYA;64G(#T^("=.97=F;W5N9&QA;F0@1&%Y;&EG:'0@5&EM92<L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)TY$5"<@*2P*("`@("=!<F=E;G1I;F4@
M5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$P.#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%R9V5N=&EN92!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G05)4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)T)R87II;"!4:6UE)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G0G)A>FEL(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("="4E0G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`G0G)A>FEL(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO
M<G1N86UE)R`]/B`G0E)35"<@*2P*("`@("=&<F5N8V@@1W5I86YA(%1I;64G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ,#@P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=&<F5N8V@@1W5I86YA(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("='1E0G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G5V5S=&5R;B!'<F5E;FQA;F0@5&EM92<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$P.#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)U=E<W1E<FX@1W)E96YL86YD(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=71U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G5V5S=&5R;B!'<F5E;FQA
M;F0@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=7
M1U-4)R`I+`H@("`@)U!I97)R92`F($UI<75E;&]N(%-T86YD87)D(%1I;64G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ,#@P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=0:65R<F4@)B!-:7%U96QO;B!3=&%N9&%R
M9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4$U35"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^
M("=0:65R<F4@)B!-:7%U96QO;B!$87EL:6=H="!4:6UE)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G4$U$5"<@*2P*("`@("=5<G5G=6%Y(%1I;64G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ,#@P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=5<G5G=6%Y(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=5650G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G4W5R:6YA;64@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U-U
M<FEN86UE(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=34E0G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G1TU4+3`S.C`P)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3`X,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G1TU4+3`S.C`P)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G1TU4+3`S.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T9E<FYA;F1O(&1E($YO<F]N:&$@5&EM92<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@+3<R,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G1F5R;F%N9&\@9&4@3F]R;VYH82!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G1DY4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)U-O=71H($=E;W)G:6$@4W1A;F1A<F0@5&EM92<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3<R,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G4V]U=&@@1V5O<F=I82!3=&%N9&%R9"!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G1U-4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)T=-5"TP,CHP,"<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@+3<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M1TU4+3`R.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4+3`R.C`P
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T5A<W1E<FX@
M1W)E96YL86YD(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!'<F5E
M;FQA;F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5'5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("=%87-T97)N($=R965N;&%N9"!3=6UM97(@5&EM92<L"B`@("`@("`@
M)V1S='-H;W)T;F%M92<@/3X@)T5'4U0G("DL"B`@("`G07IO<F5S(%1I;64G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS-C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T%Z;W)E<R!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G05I/5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=!>F]R97,@4W5M;65R(%1I;64G
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=!6D]35"<@*2P*("`@("=#
M87!E(%9E<F1E(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M("TS-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-A<&4@5F5R9&4@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-65"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("='350M,#$Z,#`G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TS-C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T=-5"TP,3HP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T=-5"TP,3HP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("='<F5E;G=I8V@@365A;B!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=R965N=VEC:"!-
M96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G5V5S=&5R;B!%=7)O<&5A
M;B!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)U=E<W1E<FX@175R;W!E86X@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)U=%5"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=797-T97)N($5U
M<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]
M/B`G5T535"<@*2P*("`@("='350K,#`Z,#`G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4*S`P
M.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4*S`P.C`P)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T-O;W)D:6YA=&5D(%5N
M:79E<G-A;"!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-O;W)D:6YA=&5D(%5N:79E<G-A
M;"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G551#)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T-E;G1R86P@175R;W!E86X@
M5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#150G+`H@("`@("`@("=H87-D
M<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A
M;"!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M
M92<@/3X@)T-%4U0G("DL"B`@("`G5V5S=&5R;B!!9G)I8V%N(%1I;64G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G5V5S=&5R;B!!9G)I8V%N(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=7050G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G5V5S=&5R;B!!9G)I8V%N
M(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G5T%3
M5"<@*2P*("`@("='350K,#$Z,#`G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4*S`Q
M.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4*S`Q.C`P)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TUI9&1L92!%=7)O<&4@
M5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=-:61D;&4@175R;W!E(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=-150G+`H@("`@("`@("=H87-D<W0G
M(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G36ED9&QE($5U
M<F]P92!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@
M)TU%4U0G("DL"B`@("`G16%S=&5R;B!%=7)O<&5A;B!4:6UE)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T5%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N(%-U
M;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G14535"<@
M*2P*("`@("=#96YT<F%L($%F<FEC86X@5&EM92<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=#96YT<F%L($%F<FEC86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T-!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=3
M;W5T:"!!9G)I8V$@4W1A;F1A<F0@5&EM92<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=3
M;W5T:"!!9G)I8V$@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)U-!4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G27-R865L(%-T86YD87)D(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G27-R
M865L(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=)
M4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO
M;F=N86UE)R`]/B`G27-R865L($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=)1%0G("DL"B`@("`G1TU4*S`R.C`P)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T=-5"LP,CHP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T=-5"LP,CHP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=%87-T97)N($%F<FEC86X@5&EM92<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M16%S=&5R;B!!9G)I8V%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=%050G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4WEO
M=V$@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3`X,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4WEO=V$@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)U-93U0G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G07)A8FEA(%-T86YD87)D(%1I;64G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#$P.#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T%R86)I82!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T=-5"LP,SHP,"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4*S`S.C`P
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4*S`S.C`P)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TUO<V-O=R!3=&%N9&%R9"!4
M:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q,#@P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=-;W-C;W<@4W1A;F1A<F0@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU32R<L"B`@("`@("`@)VAA<V1S
M="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=-;W-C;W<@
M1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TU3
M1"<@*2P*("`@("='350K,#,Z,#<G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#$Q,C(T,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-5"LP
M,SHP-R<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"LP,SHP-R<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=)<F%N(%1I;64G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$R-C`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)TER86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)TE25"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@
M("`G9'-T;&]N9VYA;64G(#T^("=)<F%N(%-U;65R(%1I;64G+`H@("`@("`@
M("=D<W1S:&]R=&YA;64G(#T^("=)4E-4)R`I+`H@("`@)T%Q=&%U(%1I;64G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$T-#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T%Q=&%U(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=!4514)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T%Q=&%U(%-U;6UE<B!4:6UE)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G05%44U0G("DL"B`@("`G07IE
M<F)A:6IA;B!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q
M-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!>F5R8F%I:F%N(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!6E0G+`H@("`@("`@("=H
M87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G07IE
M<F)A:6IA;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)T%:4U0G("DL"B`@("`G1W5L9B!3=&%N9&%R9"!4:6UE)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q-#0P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("='=6QF(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("='4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G1V5O<F=I82!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`Q-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='96]R9VEA
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='150G+`H@("`@("`@
M("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G
M1V5O<F=I82!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)T=%4U0G("DL"B`@("`G07)M96YI82!4:6UE)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`Q-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=!<FUE;FEA(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!
M350G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO
M;F=N86UE)R`]/B`G07)M96YI82!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S
M='-H;W)T;F%M92<@/3X@)T%-4U0G("DL"B`@("`G1TU4*S`T.C`P)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q-#0P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("='350K,#0Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("='350K,#0Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G4V%M87)A(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U-A;6%R82!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4T%-5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=3
M86UA<F$@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=304U35"<@*2P*("`@("=397EC:&5L;&5S(%1I;64G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)U-E>6-H96QL97,@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)U-#5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=-
M875R:71I=7,@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G36%U<FET:75S(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=-550G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4F5U;FEO;B!4:6UE)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q-#0P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=2975N:6]N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=2150G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M069G:&%N:7-T86X@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,38R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G069G:&%N:7-T
M86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%&5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<71O8F4@5&EM92<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3@P,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G07%T;V)E(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=!4514)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@
M("`@("=D<W1L;VYG;F%M92<@/3X@)T%Q=&]B92!3=6UM97(@5&EM92<L"B`@
M("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T%15%-4)R`I+`H@("`@)U1U<FMM
M96YI<W1A;B!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q
M.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=4=7)K;65N:7-T86X@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U1-5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=+:7)G:7IS=&%N(%1I;64G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$X,#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)TMI<F=I>G-T86X@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)TM'5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=+:7)G:7IS=&%N(%-U;6UE<B!4
M:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G2T=35"<@*2P*("`@
M("=486II:VES=&%N(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U1A:FEK:7-T
M86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U1*5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=086MI<W1A;B!4:6UE)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q.#`P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=086MI<W1A;B!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G4$M4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)U5Z8F5K:7-T86X@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G57IB
M96MI<W1A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G55I4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)UEE:V%T97)I;F)U
M<F<@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3@P,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G665K871E<FEN8G5R9R!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G645+5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=996MA
M=&5R:6YB=7)G(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G645+4U0G("DL"B`@("`G1TU4*S`U.C`P)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`Q.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("='350K,#4Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350K
M,#4Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G1G)E
M;F-H(%-O=71H97)N("8@06YT87)C=&EC($QA;F1S(%1I;64G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#$X,#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T9R96YC:"!3;W5T:&5R;B`F($%N=&%R8W1I8R!,86YD<R!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5$94)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TUA;&1I=F5S(%1I;64G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$X,#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)TUA;&1I=F5S(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=-5E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G26YD:6$@4W1A;F1A<F0@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@,3DX,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G26YD
M:6$@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TE3
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=.97!A;"!4
M:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R,#<P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=.97!A;"!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G3E!4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)TUA=W-O;B!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`R,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=-87=S
M;VX@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU!5U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G5F]S=&]K('1I;64G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(Q-C`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)U9O<W1O:R!T:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G5D]35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=!;&UA+4%T82!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`R,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!;&UA+4%T
M82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G04Q-5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^
M("=!;&UA+4%T82!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M
M92<@/3X@)T%,35-4)R`I+`H@("`@)U-R:2!,86YK82!4:6UE)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`R,38P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=3<FD@3&%N:V$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)TQ+5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("="86YG;&%D97-H(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T)A;F=L861E
M<V@@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T)$5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=.;W9O<VEB:7)S:R!4:6UE
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R,38P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=.;W9O<VEB:7)S:R!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G3D]65"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=.;W9O<VEB:7)S:R!3
M=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TY/5E-4
M)R`I+`H@("`@)T]M<VL@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G3VUS:R!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G3TU35"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=/
M;7-K(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G
M3TU34U0G("DL"B`@("`G0FAU=&%N(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T)H=71A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0E14)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T=-5"LP-CHP,"<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C$V,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G1TU4*S`V.C`P)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G1TU4*S`V.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)TEN9&EA;B!/8V5A;B!497)R:71O<GD@5&EM92<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C$V,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G26YD:6%N($]C96%N(%1E<G)I=&]R>2!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G24]4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)TUY86YM87(@5&EM92<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,C,T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G37EA;FUA<B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G34U4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T-O8V]S($ES
M;&%N9',@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C,T
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V]C;W,@27-L86YD<R!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T1A=FES(%1I;64G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#(U,C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T1A=FES(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=$0594)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TEN
M9&]C:&EN82!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R
M-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=);F1O8VAI;F$@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TE#5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=(;W9D(%1I;64G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)TAO=F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TA/
M5E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G5V5S="!)
M;F1O;F5S:6$@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5V5S="!);F1O;F5S
M:6$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U=)5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=+<F%S;F]Y87)S:R!4:6UE
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R-3(P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=+<F%S;F]Y87)S:R!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G2U)!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=+<F%S;F]Y87)S:R!3
M=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TM205-4
M)R`I+`H@("`@)T=-5"LP-SHP,"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4*S`W
M.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4*S`W.C`P)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T-H<FES=&UA<R!)<VQA
M;F0@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C4R,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0VAR:7-T;6%S($ES;&%N9"!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0UA4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U=E<W1E<FX@4W1A;F1A<F0@5&EM
M92`H075S=')A;&EA*2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5V5S=&5R;B!3=&%N
M9&%R9"!4:6UE("A!=7-T<F%L:6$I)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G5U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T)R
M=6YE:2!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R.#@P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("="<G5N96D@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T).5"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=#:&EN82!3=&%N9&%R9"!4:6UE)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=#:&EN82!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)TAO;F<@2V]N9R!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=(;VYG
M($MO;F<@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TA+5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=)<FMU='-K(%1I;64G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)TER:W5T<VL@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)TE22U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L
M"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G27)K=71S:R!3=6UM97(@5&EM
M92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TE22U-4)R`I+`H@("`@
M)TUA;&%Y<VEA(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUA;&%Y<VEA(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=-650G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4&AI;&EP<&EN97,@5&EM92<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C@X,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G4&AI;&EP<&EN97,@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)U!(5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=3:6YG87!O<F4@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4VEN
M9V%P;W)E(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=31U0G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G0V5N=')A;"!);F1O
M;F5S:6$@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C@X
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!);F1O;F5S
M:6$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-)5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=5;&%A;F)A871A<B!4:6UE
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=5;&%A;F)A871A<B!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G54Q!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("='350K,#@Z,#`G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-
M5"LP.#HP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"LP.#HP,"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=#:&]I8F%L<V%N
M(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,R-#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-H;VEB86QS86X@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T-(3U0G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G16%S="!4:6UO<B!4:6UE)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`S,C0P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=%87-T(%1I;6]R(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=44%0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M16%S="!);F1O;F5S:6$@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,S(T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S="!)
M;F1O;F5S:6$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5)5"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=+;W)E82!3=&%N
M9&%R9"!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S,C0P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=+;W)E82!3=&%N9&%R9"!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G2U-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TIA<&%N(%-T86YD87)D(%1I;64G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,R-#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)TIA<&%N(%-T86YD87)D(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=*4U0G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G66%K=71S:R!4:6UE)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`S,C0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=986MU='-K(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=904M4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG
M;F%M92<@/3X@)UEA:W1S:R!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)UE!2U-4)R`I+`H@("`@)T=-5"LP.3HP,"<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S(T,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G1TU4*S`Y.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G1TU4*S`Y.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)U!A;&%U(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#,R-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U!A;&%U(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=05U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G0V5N=')A;"!3=&%N9&%R9"!4:6UE("A.
M;W)T:&5R;B!497)R:71O<GDI)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`S-#(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L
M(%-T86YD87)D(%1I;64@*$YO<G1H97)N(%1E<G)I=&]R>2DG+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G0V5N=')A;"!3=&%N9&%R9"!4:6UE("A3;W5T:"!!=7-T
M<F%L:6$I)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-#(P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L(%-T86YD87)D(%1I
M;64@*%-O=71H($%U<W1R86QI82DG+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S
M=&QO;F=N86UE)R`]/B`G0V5N=')A;"!3=6UM97(@5&EM92`H4V]U=&@@075S
M=')A;&EA*2<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-35"<@*2P*
M("`@("=#96YT<F%L(%-T86YD87)D(%1I;64@*%-O=71H($%U<W1R86QI82].
M97<@4V]U=&@@5V%L97,I)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`S-#(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L(%-T
M86YD87)D(%1I;64@*%-O=71H($%U<W1R86QI82].97<@4V]U=&@@5V%L97,I
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R
M86P@4W5M;65R(%1I;64@*%-O=71H($%U<W1R86QI82].97<@4V]U=&@@5V%L
M97,I)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0U-4)R`I+`H@("`@
M)T5A<W1E<FX@4W1A;F1A<F0@5&EM92`H3F5W(%-O=71H(%=A;&5S*2<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE("A.97<@4V]U
M=&@@5V%L97,I)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@)T5A<W1E<FX@4W5M;65R(%1I;64@*$YE=R!3;W5T:"!786QE<RDG+`H@
M("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%4U0G("DL"B`@("`G1'5M;VYT
M+61<)U5R=FEL;&4@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1'5M;VYT+61<
M)U5R=FEL;&4@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T1$550G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4V%K:&%L:6X@
M5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4V%K:&%L:6X@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)U-!2U0G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G4V%K:&%L:6X@4W5M
M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=304M35"<@
M*2P*("`@("=6;&%D:79O<W1O:R!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`S-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=6
M;&%D:79O<W1O:R!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5DQ!
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N
M9VYA;64G(#T^("=6;&%D:79O<W1O:R!3=6UM97(@5&EM92<L"B`@("`@("`@
M)V1S='-H;W)T;F%M92<@/3X@)U9,05-4)R`I+`H@("`@)T5A<W1E<FX@4W1A
M;F1A<F0@5&EM92`H475E96YS;&%N9"DG(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A
M<W1E<FX@4W1A;F1A<F0@5&EM92`H475E96YS;&%N9"DG+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G16%S=&5R;B!3=&%N9&%R9"!4:6UE("A487-M86YI82DG(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM92`H5&%S;6%N
M:6$I)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A
M<W1E<FX@4W5M;65R(%1I;64@*%1A<VUA;FEA*2<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)T535"<@*2P*("`@("=%87-T97)N(%-T86YD87)D(%1I
M;64@*%9I8W1O<FEA*2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N
M9&%R9"!4:6UE("A6:6-T;W)I82DG+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S
M=&QO;F=N86UE)R`]/B`G16%S=&5R;B!3=6UM97(@5&EM92`H5FEC=&]R:6$I
M)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G15-4)R`I+`H@("`@)T=-
M5"LQ,#HP,"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4*S$P.C`P)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G1TU4*S$P.C`P)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)T-H86UO<G)O(%-T86YD87)D(%1I;64G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T-H86UO<G)O(%-T86YD87)D(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=#:%-4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)U!A<'5A($YE=R!'=6EN96$@5&EM92<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G4&%P=6$@3F5W($=U:6YE82!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G4$=4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)U1R=6L@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5')U:R!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5%)55"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=987`@5&EM92<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G66%P(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=9
M05!4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TQO860@
M2&]W92!3=&%N9&%R9"!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`S-S@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=,;V%D($AO
M=V4@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TQ(
M4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO
M;F=N86UE)R`]/B`G3&]A9"!(;W=E(%-U;6UE<B!4:6UE)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G3$A35"<@*2P*("`@("=-86=A9&%N(%1I;64G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,Y-C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)TUA9V%D86X@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)TU!1U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L
M"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G36%G861A;B!3=6UM97(@5&EM
M92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TU!1U-4)R`I+`H@("`@
M)T=-5"LQ,3HP,"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,SDV
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4*S$Q.C`P)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G1TU4*S$Q.C`P)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)U9A;G5A='4@5&EM92<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,SDV,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G5F%N=6%T=2!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G5E54)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U-O
M;&]M;VX@27,N(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#,Y-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U-O;&]M;VX@27,N
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=30E0G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G2V]S<F%E(%1I;64G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,Y-C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)TMO<W)A92!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G2T]35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=.97<@0V%L961O;FEA(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#,Y-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TYE=R!#
M86QE9&]N:6$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TY#5"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=0;VYA<&4@5&EM
M92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,SDV,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G4&]N87!E(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=03TY4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)TYO<F9O;&L@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@-#$T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G3F]R
M9F]L:R!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G3D94)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TYE=R!:96%L86YD(%-T
M86YD87)D(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0S
M,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TYE=R!:96%L86YD(%-T
M86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=.6E-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M
M92<@/3X@)TYE=R!:96%L86YD($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=.6D14)R`I+`H@("`@)T%N861Y<B!4:6UE)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`T,S(P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=!;F%D>7(@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T%.050G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`G06YA9'ER(%-U;6UE<B!4:6UE)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G04Y!4U0G("DL"B`@("`G4&5T
M<F]P879L;W9S:RU+86UC:&%T<VMI(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#0S,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)U!E=')O<&%V;&]V<VLM2V%M8VAA='-K:2!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G4$545"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=0971R;W!A=FQO=G-K+4MA;6-H
M871S:VD@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=015135"<@*2P*("`@("='350K,3(Z,#`G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#0S,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T=-5"LQ,CHP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"LQ,CHP
M,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=-87)S:&%L
M;"!)<VQA;F1S(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#0S,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUA<G-H86QL($ES
M;&%N9',@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU(5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=&:6II(%1I;64G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0S,C`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T9I:FD@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T9*5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=4=79A;'4@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M-#,R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5'5V86QU(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=45E0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G3F%U<G4@5&EM92<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@-#,R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G3F%U<G4@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TY2
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=':6QB97)T
M($ES+B!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`T,S(P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=':6QB97)T($ES+B!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TE,5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=786ME(%1I;64G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#0S,C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)U=A:V4@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U=!
M2U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G5V%L;&ES
M("8@1G5T=6YA(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#0S,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U=A;&QI<R`F($9U
M='5N82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5T94)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T-H871H86T@4W1A;F1A
M<F0@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-#4Y,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0VAA=&AA;2!3=&%N9&%R9"!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0TA!4U0G+`H@("`@("`@
M("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G
M0VAA=&AA;2!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G0TA!1%0G("DL"B`@("`G1TU4*S$S.C`P)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`T-C@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("='350K,3,Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350K
M,3,Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4&AO
M96YI>"!)<RX@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M-#8X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4&AO96YI>"!)<RX@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U!(3U0G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G5&]N9V$@5&EM92<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@-#8X,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G5&]N9V$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)U1/5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("='
M350K,30Z,#`G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#4P-#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-5"LQ-#HP,"<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T=-5"LQ-#HP,"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=,:6YE($ES+B!4:6UE)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`U,#0P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=,:6YE($ES+B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G3$E.5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P**3L*"B\O
M"B\O($EN:71I86QI>F4@9&5F875L="!T:6UE>F]N90HO+R`@1FER<W0@=')Y
M(%]$051%7U1)345:3TY%7T1%1D%53%0@9VQO8F%L+`HO+R`@=&AE;B!02%!?
M5%H@96YV:7)O;FUE;G0@=F%R+"!T:&5N(%1:(&5N=FER;VYM96YT('9A<@HO
M+PII9BAI<W-E="@D7T1!5$5?5$E-15I/3D5?1$5&055,5"D*("`@("8F($1A
M=&5?5&EM95IO;F4Z.FES5F%L:61)1"@D7T1!5$5?5$E-15I/3D5?1$5&055,
M5"D**2!["B`@("!$871E7U1I;65:;VYE.CIS971$969A=6QT*"1?1$%415]4
M24U%6D].15]$149!54Q4*3L*?2!E;'-E:68@*&=E=&5N=B@G4$A07U1:)RD@
M)B8@1&%T95]4:6UE6F]N93HZ:7-686QI9$E$*&=E=&5N=B@G4$A07U1:)RDI
M*2!["B`@("!$871E7U1I;65:;VYE.CIS971$969A=6QT*&=E=&5N=B@G4$A0
M7U1:)RDI.PI](&5L<V5I9B`H9V5T96YV*"=46B<I("8F($1A=&5?5&EM95IO
M;F4Z.FES5F%L:61)1"AG971E;G8H)U1:)RDI*2!["B`@("!$871E7U1I;65:
M;VYE.CIS971$969A=6QT*&=E=&5N=B@G5%HG*2D["GT@96QS96EF("A$871E
M7U1I;65:;VYE.CII<U9A;&ED240H9&%T92@G5"<I*2D@>PH@("`@1&%T95]4
M:6UE6F]N93HZ<V5T1&5F875L="AD871E*"=4)RDI.PI](&5L<V4@>PH@("`@
M1&%T95]4:6UE6F]N93HZ<V5T1&5F875L="@G551#)RD["GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]$871E+T-A;&,N<&AP````````````````````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,C`P,C4P(#$P-3$U-#,S-S,Q(#`R,#<Q
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED
M=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PHO+PHO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P-2!"86)A
M($)U96AL97(L(%!I97)R92U!;&%I;B!*;WEE("`@("`@("`@("`@("!\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E
M(&9I;&4@:7,@<W5B:F5C="!T;R!T:&4@3F5W($)31"!L:6-E;G-E+"!4:&%T
M(&ES(&)U;F1L960@('P*+R\@?"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@
M9FEL92!,24-%3E-%+"!A;F0@:7,@879A:6QA8FQE('1H<F]U9V@@("`@("!\
M"B\O('P@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W
M=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("`@
M("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E
M(&$@8V]P>2!O9B!T:&4@;F5W($)31&QI8V5N<V4@86YD(&%R92!U;F%B;&4@
M("!\"B\O('P@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M
M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@?`HO+R!\('!E87(M
M9&5V0&QI<W1S+G!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I
M;6UE9&EA=&5L>2X@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@075T:&]R.B!"86)A($)U96AL97(@/&)A8F%`8F%B87HN
M8V]M/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\("`@
M("`@("`@4&EE<G)E+4%L86EN($IO>64@/'!A:F]Y94!P:'`N;F5T/B`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"@HO*BH*("H@0V%L8W5L871E<RP@;6%N:7!U;&%T97,@86YD
M(')E=')I979E<R!D871E<PH@*@H@*B!)="!D;V5S(&YO="!R96QY(&]N(#,R
M+6)I="!S>7-T96T@=&EM92!S=&%M<',L('-O(&ET('=O<FMS(&1A=&5S"B`J
M(&)E9F]R92`Q.3<P(&%N9"!A9G1E<B`R,#,X+@H@*@H@*B!02%`@=F5R<VEO
M;G,@-"!A;F0@-0H@*@H@*B!`8V%T96=O<GD@("!$871E(&%N9"!4:6UE"B`J
M($!P86-K86=E("`@($1A=&4*("H@0&%U=&AO<B`@("`@36]N=&4@3VAR="`\
M;6]N=&5`:7-P:2YN970^"B`J($!A=71H;W(@("`@(%!I97)R92U!;&%I;B!*
M;WEE(#QP86IO>65`<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@1&%N:65L($-O
M;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DY
M+3(P,#4@($UO;G1E($]H<G0L(%!I97)R92U!;&%I;B!*;WEE+"!$86YI96P@
M0V]N=FES<V]R"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C
M92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!.97<@0E-$($QI8V5N
M<V4*("H@0'9E<G-I;VX@("`@0U93.B`D260Z($-A;&,N<&AP+'8@,2XS,R`R
M,#`U+S$Q+S$U(#`P.C$V.C,Y('!A:F]Y92!%>'`@)`H@*B!`;&EN:R`@("`@
M("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1&%T90H@*B!`<VEN8V4@
M("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N,@H@*B\*"FEF
M("@A9&5F:6YE9"@G1$%415]#04Q#7T)%1TE.7U=%14M$05DG*2D@>PH@("`@
M+RHJ"B`@("`@*B!$969I;F5S('=H870@9&%Y('-T87)T<R!T:&4@=V5E:PH@
M("`@("H*("`@("`J($UO;F1A>2`H,2D@:7,@=&AE(&EN=&5R;F%T:6]N86P@
M<W1A;F1A<F0N"B`@("`@*B!2961E9FEN92!T:&ES('1O(#`@:68@>6]U('=A
M;G0@=V5E:W,@=&\@8F5G:6X@;VX@4W5N9&%Y+@H@("`@("HO"B`@("!D969I
M;F4H)T1!5$5?0T%,0U]"14=)3E]7145+1$%9)RP@,2D["GT*"FEF("@A9&5F
M:6YE9"@G1$%415]#04Q#7T9/4DU!5"<I*2!["B`@("`O*BH*("`@("`J(%1H
M92!D969A=6QT('9A;'5E(&9O<B!E86-H(&UE=&AO9"=S("1F;W)M870@<&%R
M86UE=&5R"B`@("`@*@H@("`@("H@5&AE(&1E9F%U;'0@:7,@)R59)6TE9"<N
M("!4;R!O=F5R<FED92!T:&ES(&1E9F%U;'0L(&1E9FEN90H@("`@("H@=&AI
M<R!C;VYS=&%N="!B969O<F4@:6YC;'5D:6YG($-A;&,N<&AP+@H@("`@("H*
M("`@("`J($!S:6YC92!#;VYS=&%N="!A=F%I;&%B;&4@<VEN8V4@4F5L96%S
M92`Q+C4N,`H@("`@("HO"B`@("!D969I;F4H)T1!5$5?0T%,0U]&3U)-050G
M+"`G)5DE;25D)RD["GT*"B\J*@H@*B!#86QC=6QA=&5S+"!M86YI<'5L871E
M<R!A;F0@<F5T<FEE=F5S(&1A=&5S"B`J"B`J($ET(&1O97,@;F]T(')E;'D@
M;VX@,S(M8FET('-Y<W1E;2!T:6UE('-T86UP<RP@<V\@:70@=V]R:W,@9&%T
M97,*("H@8F5F;W)E(#$Y-S`@86YD(&%F=&5R(#(P,S@N"B`J"B`J($!A=71H
M;W(@("`@($UO;G1E($]H<G0@/&UO;G1E0&ES<&DN;F5T/@H@*B!`875T:&]R
M("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C
M;W!Y<FEG:'0@(#$Y.3DL(#(P,#(L(#(P,#,@:7-P:0H@*B!`;&EC96YS92`@
M("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E
M;G-E+G!H<"`@3F5W($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@(%)E;&5A
M<V4Z(#$N-"XV"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O
M<&%C:V%G92]$871E"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S
M:6YC92!296QE87-E(#$N,@H@*B\*8VQA<W,@1&%T95]#86QC"GL*("`@("\J
M*@H@("`@("H@1F]R;6%T<R!T:&4@9&%T92!I;B!T:&4@9VEV96X@9F]R;6%T
M+"!M=6-H(&QI:V4@<W1R9FUT*"D*("`@("`J"B`@("`@*B!4:&ES(&9U;F-T
M:6]N(&ES('5S960@=&\@86QL979I871E('1H92!P<F]B;&5M('=I=&@@,S(M
M8FET(&YU;6)E<G,@9F]R"B`@("`@*B!D871E<R!P<F4@,3DW,"!O<B!P;W-T
M(#(P,S@L(&%S('-T<F9M="@I(&AA<R!O;B!M;W-T('-Y<W1E;7,N"B`@("`@
M*B!-;W-T(&]F('1H92!F;W)M871T:6YG(&]P=&EO;G,@87)E(&-O;7!A=&EB
M;&4N"B`@("`@*@H@("`@("H@1F]R;6%T=&EN9R!O<'1I;VYS.@H@("`@("H@
M/'!R93X*("`@("`J("5A("`@86)B<F5V:6%T960@=V5E:V1A>2!N86UE("A3
M=6XL($UO;BP@5'5E*0H@("`@("H@)4$@("!F=6QL('=E96MD87D@;F%M92`H
M4W5N9&%Y+"!-;VYD87DL(%1U97-D87DI"B`@("`@*B`E8B`@(&%B8G)E=FEA
M=&5D(&UO;G1H(&YA;64@*$IA;BP@1F5B+"!-87(I"B`@("`@*B`E0B`@(&9U
M;&P@;6]N=&@@;F%M92`H2F%N=6%R>2P@1F5B<G5A<GDL($UA<F-H*0H@("`@
M("H@)60@("!D87D@;V8@;6]N=&@@*')A;F=E(#`P('1O(#,Q*0H@("`@("H@
M)64@("!D87D@;V8@;6]N=&@L('-I;F=L92!D:6=I="`H<F%N9V4@,"!T;R`S
M,2D*("`@("`J("5%("`@;G5M8F5R(&]F(&1A>7,@<VEN8V4@=6YS<&5C:69I
M960@97!O8V@@*&EN=&5G97(I"B`@("`@*B`@("`@("`@*"5%(&ES('5S969U
M;"!F;W(@<&%S<VEN9R!A(&1A=&4@:6X@82!54DP@87,*("`@("`J("`@("`@
M("!A;B!I;G1E9V5R('9A;'5E+B!4:&5N('-I;7!L>2!U<V4*("`@("`J("`@
M("`@("!D87ES5&]$871E*"D@=&\@8V]N=F5R="!B86-K('1O(&$@9&%T92XI
M"B`@("`@*B`E:B`@(&1A>2!O9B!Y96%R("AR86YG92`P,#$@=&\@,S8V*0H@
M("`@("H@)6T@("!M;VYT:"!A<R!D96-I;6%L(&YU;6)E<B`H<F%N9V4@,2!T
M;R`Q,BD*("`@("`J("5N("`@;F5W;&EN92!C:&%R86-T97(@*%QN*0H@("`@
M("H@)70@("!T86(@8VAA<F%C=&5R("A<="D*("`@("`J("5W("`@=V5E:V1A
M>2!A<R!D96-I;6%L("@P(#T@4W5N9&%Y*0H@("`@("H@)54@("!W965K(&YU
M;6)E<B!O9B!C=7)R96YT('EE87(L(&9I<G-T('-U;F1A>2!A<R!F:7)S="!W
M965K"B`@("`@*B`E>2`@('EE87(@87,@9&5C:6UA;"`H<F%N9V4@,#`@=&\@
M.3DI"B`@("`@*B`E62`@('EE87(@87,@9&5C:6UA;"!I;F-L=61I;F<@8V5N
M='5R>2`H<F%N9V4@,#`P,"!T;R`Y.3DY*0H@("`@("H@)24@("!L:71E<F%L
M("<E)PH@("`@("H@/"]P<F4^"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@
M("`D9&%Y("`@("!T:&4@9&%Y(&]F('1H92!M;VYT:`H@("`@("H@0'!A<F%M
M(&EN="`@("`D;6]N=&@@("!T:&4@;6]N=&@*("`@("`J($!P87)A;2!I;G0@
M("`@)'EE87(@("`@=&AE('EE87(N("!5<V4@=&AE(&-O;7!L971E('EE87(@
M:6YS=&5A9"!O9B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M(&%B8G)E=FEA=&5D('9E<G-I;VXN("!%+F<N('5S92`R,#`U+"!N;W0@,#4N
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!$;R!N;W0@861D(&QE
M861I;F<@,"=S(&9O<B!Y96%R<R!P<FEO<B!T;R`Q,#`P+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D9F]R;6%T("!T:&4@9F]R;6%T('-T<FEN9PH@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@9&%T92!I;B!T:&4@9&5S:7)E
M9"!F;W)M870*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@
M0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!D871E1F]R;6%T*"1D87DL
M("1M;VYT:"P@)'EE87(L("1F;W)M870I"B`@("!["B`@("`@("`@:68@*"%$
M871E7T-A;&,Z.FES5F%L:61$871E*"1D87DL("1M;VYT:"P@)'EE87(I*2![
M"B`@("`@("`@("`@("1Y96%R("`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)5DG
M*3L*("`@("`@("`@("`@)&UO;G1H(#T@1&%T95]#86QC.CID871E3F]W*"<E
M;2<I.PH@("`@("`@("`@("`D9&%Y("`@/2!$871E7T-A;&,Z.F1A=&5.;W<H
M)R5D)RD["B`@("`@("`@?0H*("`@("`@("`D;W5T<'5T(#T@)R<["@H@("`@
M("`@(&9O<B`H)'-T<G!O<R`](#`[("1S=')P;W,@/"!S=')L96XH)&9O<FUA
M="D[("1S=')P;W,K*RD@>PH@("`@("`@("`@("`D8VAA<B`]('-U8G-T<B@D
M9F]R;6%T+"`D<W1R<&]S+"`Q*3L*("`@("`@("`@("`@:68@*"1C:&%R(#T]
M("<E)RD@>PH@("`@("`@("`@("`@("`@)&YE>'1C:&%R(#T@<W5B<W1R*"1F
M;W)M870L("1S=')P;W,@*R`Q+"`Q*3L*("`@("`@("`@("`@("`@('-W:71C
M:"@D;F5X=&-H87(I('L*("`@("`@("`@("`@("`@("`@("!C87-E("=A)SH*
M("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2!$871E7T-A;&,Z
M.F=E=%=E96MD87E!8F)R;F%M92@D9&%Y+"`D;6]N=&@L("1Y96%R*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@
M("`@8V%S92`G02<Z"B`@("`@("`@("`@("`@("`@("`@("`@("1O=71P=70@
M+CT@1&%T95]#86QC.CIG9717965K9&%Y1G5L;&YA;64H)&1A>2P@)&UO;G1H
M+"`D>65A<BD["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@("`@(&-A<V4@)V(G.@H@("`@("`@("`@("`@("`@("`@
M("`@("`D;W5T<'5T("X]($1A=&5?0V%L8SHZ9V5T36]N=&A!8F)R;F%M92@D
M;6]N=&@I.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@("`@("`@("!C87-E("=")SH*("`@("`@("`@("`@("`@("`@("`@
M("`@)&]U='!U="`N/2!$871E7T-A;&,Z.F=E=$UO;G1H1G5L;&YA;64H)&UO
M;G1H*3L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@("`@("`@("`@8V%S92`G9"<Z"B`@("`@("`@("`@("`@("`@("`@("`@
M("1O=71P=70@+CT@<W!R:6YT9B@G)3`R9"<L("1D87DI.PH@("`@("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E
M("=E)SH*("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2`D9&%Y
M.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M("`@("`@("!C87-E("=%)SH*("`@("`@("`@("`@("`@("`@("`@("`@)&]U
M='!U="`N/2!$871E7T-A;&,Z.F1A=&54;T1A>7,H)&1A>2P@)&UO;G1H+"`D
M>65A<BD["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("`@("`@("`@(&-A<V4@)VHG.@H@("`@("`@("`@("`@("`@("`@("`@
M("`D;W5T<'5T("X]($1A=&5?0V%L8SHZ:G5L:6%N1&%T92@D9&%Y+"`D;6]N
M=&@L("1Y96%R*3L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@("`@("`@("`@8V%S92`G;2<Z"B`@("`@("`@("`@("`@("`@
M("`@("`@("1O=71P=70@+CT@<W!R:6YT9B@G)3`R9"<L("1M;VYT:"D["B`@
M("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M("`@(&-A<V4@)VXG.@H@("`@("`@("`@("`@("`@("`@("`@("`D;W5T<'5T
M("X](")<;B(["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@("`@(&-A<V4@)W0G.@H@("`@("`@("`@("`@("`@("`@
M("`@("`D;W5T<'5T("X](")<="(["B`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)W<G.@H@("`@("`@
M("`@("`@("`@("`@("`@("`D;W5T<'5T("X]($1A=&5?0V%L8SHZ9&%Y3V97
M965K*"1D87DL("1M;VYT:"P@)'EE87(I.PH@("`@("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E("=5)SH*("`@
M("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2!$871E7T-A;&,Z.G=E
M96M/9EEE87(H)&1A>2P@)&UO;G1H+"`D>65A<BD["B`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)WDG
M.@H@("`@("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]('-U8G-T<B@D
M>65A<BP@,BP@,BD["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@("`@(&-A<V4@)UDG.@H@("`@("`@("`@("`@("`@
M("`@("`@("`D;W5T<'5T("X]("1Y96%R.PH@("`@("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E("<E)SH*("`@
M("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2`G)2<["B`@("`@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&1E
M9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@)&-H
M87(N)&YE>'1C:&%R.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@)'-T<G!O<RLK.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)&]U='!U="`N/2`D8VAA<CL*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("!R971U<FX@)&]U='!U=#L*("`@('T*"B`@("`O*BH*("`@
M("`J(%1U<FYS(&$@='=O(&1I9VET('EE87(@:6YT;R!A(&9O=7(@9&EG:70@
M>65A<@H@("`@("H*("`@("`J($9R;VT@)S4Q('1O("<Y.2!I<R!I;B!T:&4@
M,3DP,"=S+"!O=&AE<G=I<V4@:70G<R!I;B!T:&4@,C`P,"=S+@H@("`@("H*
M("`@("`J($!P87)A;2!I;G0@("`@)'EE87(@("`@=&AE(#(@9&EG:70@>65A
M<@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@-"!D:6=I="!Y
M96%R"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T
M:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9&5F875L=$-E;G1U<GDH)'EE87(I
M"B`@("!["B`@("`@("`@:68@*'-T<FQE;B@D>65A<BD@/3T@,2D@>PH@("`@
M("`@("`@("`D>65A<B`]("<P)R`N("1Y96%R.PH@("`@("`@('T*("`@("`@
M("!I9B`H)'EE87(@/B`U,"D@>PH@("`@("`@("`@("!R971U<FX@)S$Y)R`N
M("1Y96%R.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`G
M,C`G("X@)'EE87(["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M0V]N=F5R=',@82!D871E('1O(&YU;6)E<B!O9B!D87ES('-I;F-E(&$@9&ES
M=&%N="!U;G-P96-I9FEE9"!E<&]C:`H@("`@("H*("`@("`J($!P87)A;2!I
M;G0@("`@)&1A>2`@("`@=&AE(&1A>2!O9B!T:&4@;6]N=&@*("`@("`J($!P
M87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO;G1H"B`@("`@*B!`<&%R86T@
M:6YT("`@("1Y96%R("`@('1H92!Y96%R+B`@57-E('1H92!C;VUP;&5T92!Y
M96%R(&EN<W1E860@;V8@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("!A8F)R979I871E9"!V97)S:6]N+B`@12YG+B!U<V4@,C`P-2P@;F]T
M(#`U+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@1&\@;F]T(&%D
M9"!L96%D:6YG(#`G<R!F;W(@>65A<G,@<')I;W(@=&\@,3`P,"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@('1H92!N=6UB97(@;V8@9&%Y<R!S
M:6YC92!T:&4@1&%T95]#86QC(&5P;V-H"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I;VX@
M9&%T951O1&%Y<R@D9&%Y+"`D;6]N=&@L("1Y96%R*0H@("`@>PH@("`@("`@
M("1C96YT=7)Y(#T@*&EN="ES=6)S='(H)'EE87(L(#`L(#(I.PH@("`@("`@
M("1Y96%R(#T@*&EN="ES=6)S='(H)'EE87(L(#(L(#(I.PH@("`@("`@(&EF
M("@D;6]N=&@@/B`R*2!["B`@("`@("`@("`@("1M;VYT:"`M/2`S.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1M;VYT:"`K/2`Y.PH@("`@("`@
M("`@("!I9B`H)'EE87(I('L*("`@("`@("`@("`@("`@("1Y96%R+2T["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D>65A<B`](#DY
M.PH@("`@("`@("`@("`@("`@)&-E;G1U<GD@+2T["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`H9FQO;W(H*#$T-C`Y-R`J("1C
M96YT=7)Y*2`O(#0@*2`K"B`@("`@("`@("`@("`@("!F;&]O<B@H,30V,2`J
M("1Y96%R*2`O(#0@*2`K"B`@("`@("`@("`@("`@("!F;&]O<B@H,34S("H@
M)&UO;G1H("L@,BD@+R`U("D@*PH@("`@("`@("`@("`@("`@)&1A>2`K(#$W
M,C$Q,3DI.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R=',@;G5M8F5R
M(&]F(&1A>7,@=&\@82!D:7-T86YT('5N<W!E8VEF:65D(&5P;V-H"B`@("`@
M*@H@("`@("H@0'!A<F%M(&EN="`@("`D9&%Y<R`@("!T:&4@;G5M8F5R(&]F
M(&1A>7,@<VEN8V4@=&AE($1A=&5?0V%L8R!E<&]C:`H@("`@("H@0'!A<F%M
M('-T<FEN9R`D9F]R;6%T("!T:&4@<W1R:6YG(&EN9&EC871I;F<@:&]W('1O
M(&9O<FUA="!T:&4@;W5T<'5T"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@('1H92!D871E(&EN('1H92!D97-I<F5D(&9O<FUA=`H@("`@("H*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&1A>7-4;T1A=&4H)&1A>7,L("1F;W)M870@/2!$051%7T-!
M3$-?1D]234%4*0H@("`@>PH@("`@("`@("1D87ES("`@+3T@,3<R,3$Q.3L*
M("`@("`@("`D8V5N='5R>2`](&9L;V]R*"@T("H@)&1A>7,@+2`Q*2`O(#$T
M-C`Y-RD["B`@("`@("`@)&1A>7,@("`@/2!F;&]O<B@T("H@)&1A>7,@+2`Q
M("T@,30V,#DW("H@)&-E;G1U<GDI.PH@("`@("`@("1D87D@("`@(#T@9FQO
M;W(H)&1A>7,@+R`T*3L*"B`@("`@("`@)'EE87(@("`@/2!F;&]O<B@H-"`J
M("1D87D@*R`@,RD@+R`Q-#8Q*3L*("`@("`@("`D9&%Y("`@("`](&9L;V]R
M*#0@*B`D9&%Y("L@(#,@+2`Q-#8Q("H@)'EE87(I.PH@("`@("`@("1D87D@
M("`@(#T@9FQO;W(H*"1D87D@*R`@-"D@+R`T*3L*"B`@("`@("`@)&UO;G1H
M("`@/2!F;&]O<B@H-2`J("1D87D@+2`S*2`O(#$U,RD["B`@("`@("`@)&1A
M>2`@("`@/2!F;&]O<B@U("H@)&1A>2`M(#,@+2`Q-3,@*B`D;6]N=&@I.PH@
M("`@("`@("1D87D@("`@(#T@9FQO;W(H*"1D87D@*R`@-2D@+R`@-2D["@H@
M("`@("`@(&EF("@D;6]N=&@@/"`Q,"D@>PH@("`@("`@("`@("`D;6]N=&@@
M*STS.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1M;VYT:"`M/3D[
M"B`@("`@("`@("`@(&EF("@D>65A<BLK(#T](#DY*2!["B`@("`@("`@("`@
M("`@("`D>65A<B`](#`["B`@("`@("`@("`@("`@("`D8V5N='5R>2LK.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D8V5N='5R>2`]('-P
M<FEN=&8H)R4P,F0G+"`D8V5N='5R>2D["B`@("`@("`@)'EE87(@("`@/2!S
M<')I;G1F*"<E,#)D)RP@)'EE87(I.PH@("`@("`@(')E='5R;B!$871E7T-A
M;&,Z.F1A=&5&;W)M870H)&1A>2P@)&UO;G1H+"`D8V5N='5R>2`N("1Y96%R
M+"`D9F]R;6%T*3L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E<G1S(&9R
M;VT@1W)E9V]R:6%N(%EE87(M36]N=&@M1&%Y('1O($E33R!996%R+5=E96M.
M=6UB97(M5V5E:T1A>0H@("`@("H*("`@("`J(%5S97,@25-/(#@V,#$@9&5F
M:6YI=&EO;G,N("!!;&=O<FET:&T@8GD@4FEC:R!-8T-A<G1Y+"`Q.3DY(&%T
M"B`@("`@*B!H='1P.B\O<&5R<V]N86PN96-U+F5D=2]M8V-A<G1Y<B])4T]W
M9$%,1RYT>'0@+@H@("`@("H@5')A;G-C<FEB960@=&\@4$A0(&)Y($IE<W5S
M($TN($-A<W1A9VYE='1O+@H@("`@("H*("`@("`J($!P87)A;2!I;G0@("`@
M)&1A>2`@("`@=&AE(&1A>2!O9B!T:&4@;6]N=&@*("`@("`J($!P87)A;2!I
M;G0@("`@)&UO;G1H("`@=&AE(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT("`@
M("1Y96%R("`@('1H92!Y96%R+B`@57-E('1H92!C;VUP;&5T92!Y96%R(&EN
M<W1E860@;V8@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!A
M8F)R979I871E9"!V97)S:6]N+B`@12YG+B!U<V4@,C`P-2P@;F]T(#`U+@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@1&\@;F]T(&%D9"!L96%D
M:6YG(#`G<R!F;W(@>65A<G,@<')I;W(@=&\@,3`P,"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@=&AE(&1A=&4@:6X@25-/(%EE87(M5V5E:TYU
M;6)E<BU7965K1&%Y(&9O<FUA=`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=R96=O
M<FEA;E1O25-/*"1D87DL("1M;VYT:"P@)'EE87(I('L*("`@("`@("`D;6YT
M:"`](&%R<F%Y("@P+"`S,2P@-3DL(#DP+"`Q,C`L(#$U,2P@,3@Q+"`R,3(L
M(#(T,RP@,C<S+"`S,#0L(#,S-"D["B`@("`@("`@)'E?:7-L96%P(#T@1&%T
M95]#86QC.CII<TQE87!996%R*"1Y96%R*3L*("`@("`@("`D>5\Q7VES;&5A
M<"`]($1A=&5?0V%L8SHZ:7-,96%P665A<B@D>65A<B`M(#$I.PH@("`@("`@
M("1D87E?;V9?>65A<E]N=6UB97(@/2`D9&%Y("L@)&UN=&A;)&UO;G1H("T@
M,5T["B`@("`@("`@:68@*"1Y7VES;&5A<"`F)B`D;6]N=&@@/B`R*2!["B`@
M("`@("`@("`@("1D87E?;V9?>65A<E]N=6UB97(K*SL*("`@("`@("!]"B`@
M("`@("`@+R\@9FEN9"!*86X@,2!W965K9&%Y("AM;VYD87D@/2`Q+"!S=6YD
M87D@/2`W*0H@("`@("`@("1Y>2`]("@D>65A<B`M(#$I("4@,3`P.PH@("`@
M("`@("1C(#T@*"1Y96%R("T@,2D@+2`D>7D["B`@("`@("`@)&<@/2`D>7D@
M*R!I;G1V86PH)'EY("\@-"D["B`@("`@("`@)&IA;C%?=V5E:V1A>2`](#$@
M*R!I;G1V86PH*"@H*"1C("\@,3`P*2`E(#0I("H@-2D@*R`D9RD@)2`W*3L*
M("`@("`@("`O+R!W965K9&%Y(&9O<B!Y96%R+6UO;G1H+61A>0H@("`@("`@
M("1H(#T@)&1A>5]O9E]Y96%R7VYU;6)E<B`K("@D:F%N,5]W965K9&%Y("T@
M,2D["B`@("`@("`@)'=E96MD87D@/2`Q("L@:6YT=F%L*"@D:"`M(#$I("4@
M-RD["B`@("`@("`@+R\@9FEN9"!I9B!9($T@1"!F86QL<R!I;B!996%R3G5M
M8F5R(%DM,2P@5V5E:TYU;6)E<B`U,B!O<@H@("`@("`@(&EF("@D9&%Y7V]F
M7WEE87)?;G5M8F5R(#P]("@X("T@)&IA;C%?=V5E:V1A>2D@)B8@)&IA;C%?
M=V5E:V1A>2`^(#0I>PH@("`@("`@("`@("`D>65A<FYU;6)E<B`]("1Y96%R
M("T@,3L*("`@("`@("`@("`@:68@*"1J86XQ7W=E96MD87D@/3T@-2!\?"`H
M)&IA;C%?=V5E:V1A>2`]/2`V("8F("1Y7S%?:7-L96%P*2D@>PH@("`@("`@
M("`@("`@("`@)'=E96MN=6UB97(@/2`U,SL*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1W965K;G5M8F5R(#T@-3(["B`@("`@("`@
M("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D>65A<FYU;6)E
M<B`]("1Y96%R.PH@("`@("`@('T*("`@("`@("`O+R!F:6YD(&EF(%D@32!$
M(&9A;&QS(&EN(%EE87).=6UB97(@62LQ+"!7965K3G5M8F5R(#$*("`@("`@
M("!I9B`H)'EE87)N=6UB97(@/3T@)'EE87(I('L*("`@("`@("`@("`@:68@
M*"1Y7VES;&5A<"D@>PH@("`@("`@("`@("`@("`@)&D@/2`S-C8["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D:2`](#,V-3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!I9B`H*"1I("T@)&1A>5]O9E]Y96%R
M7VYU;6)E<BD@/"`H-"`M("1W965K9&%Y*2D@>PH@("`@("`@("`@("`@("`@
M)'EE87)N=6UB97(K*SL*("`@("`@("`@("`@("`@("1W965K;G5M8F5R(#T@
M,3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`O+R!F:6YD(&EF
M(%D@32!$(&9A;&QS(&EN(%EE87).=6UB97(@62P@5V5E:TYU;6)E<B`Q('1H
M<F]U9V@@-3,*("`@("`@("!I9B`H)'EE87)N=6UB97(@/3T@)'EE87(I('L*
M("`@("`@("`@("`@)&H@/2`D9&%Y7V]F7WEE87)?;G5M8F5R("L@*#<@+2`D
M=V5E:V1A>2D@*R`H)&IA;C%?=V5E:V1A>2`M(#$I.PH@("`@("`@("`@("`D
M=V5E:VYU;6)E<B`](&EN='9A;"@D:B`O(#<I.PH@("`@("`@("`@("!I9B`H
M)&IA;C%?=V5E:V1A>2`^(#0I('L*("`@("`@("`@("`@("`@("1W965K;G5M
M8F5R+2T["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@+R\@<'5T
M(&ET(&%L;"!T;V=E=&AE<@H@("`@("`@(&EF("@D=V5E:VYU;6)E<B`\(#$P
M*2!["B`@("`@("`@("`@("1W965K;G5M8F5R(#T@)S`G+B1W965K;G5M8F5R
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'EE87)N=6UB97(@+B`G+2<@
M+B`D=V5E:VYU;6)E<B`N("<M)R`N("1W965K9&%Y.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1&5T97)M:6YE<R!J=6QI86X@9&%T92!O9B!T:&4@9VEV96X@
M<V5A<V]N"B`@("`@*@H@("`@("H@061A<'1E9"!F<F]M('!R979I;W5S('=O
M<FL@:6X@2F%V82!B>2!*86UE<R!-87)K($AA;6EL=&]N+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'-E87-O;B`@=&AE('-E87-O;B!T;R!G970@
M=&AE(&1A=&4@9F]R.B!615).04Q%455)3D]8+`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@4U5-34524T],4U1)0T4L($%55%5-3D%,15%524Y/
M6"P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&]R(%=)3E1%4E-/
M3%-424-%"B`@("`@*B!`<&%R86T@<W1R:6YG("1Y96%R("`@('1H92!Y96%R
M(&EN(&9O=7(@9&EG:70@9F]R;6%T+B`@375S="!B92!B971W965N"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`M,3`P,$)#(&%N9"`S,#`P040N
M"B`@("`@*@H@("`@("H@0')E='5R;B!F;&]A="`@=&AE(&IU;&EA;B!D871E
M('1H92!S96%S;VX@<W1A<G1S(&]N"B`@("`@*@H@("`@("H@0&%U=&AO<B!*
M86UE<R!-87)K($AA;6EL=&]N(#QM:&%M:6QT;VY`<7=E<W0N;F5T/@H@("`@
M("H@0&%U=&AO<B!2;V)E<G0@0G5T;&5R(#QR;V)`;6%X=V5L;&-R965K+F]R
M9SX*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&1A=&5396%S;VXH)'-E87-O;BP@)'EE87(@/2`P
M*2!["B`@("`@("`@:68@*"1Y96%R(#T]("<G*2!["B`@("`@("`@("`@("1Y
M96%R(#T@1&%T95]#86QC.CID871E3F]W*"<E62<I.PH@("`@("`@('T*("`@
M("`@("!I9B`H*"1Y96%R(#X]("TQ,#`P*2`F)B`H)'EE87(@/#T@,3`P,"DI
M('L*("`@("`@("`@("`@)'D@/2`D>65A<B`O(#$P,#`N,#L*("`@("`@("`@
M("`@<W=I=&-H("@D<V5A<V]N*2!["B`@("`@("`@("`@("`@("!C87-E("=6
M15).04Q%455)3D]8)SH*("`@("`@("`@("`@("`@("`@("`D:G5L:6%N9&%T
M92`]("@H*"@H*"@M,"XP,#`W,2`J("1Y*2`M(#`N,#`Q,3$I("H@)'DI("L@
M,"XP-C$S-"D@*B`D>2D@*R`S-C4R-#(N,3,W-"D@*B`D>2D@*R`Q-S(Q,3,Y
M+C(Y,3@Y.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("`@("`@8V%S92`G4U5-34524T],4U1)0T4G.@H@("`@("`@("`@("`@("`@
M("`@("1J=6QI86YD871E(#T@*"@H*"@H*#`N,#`P,C4@*B`D>2D@*R`P+C`P
M.3`W*2`J("1Y*2`M(#`N,#4S,C,I("H@)'DI("L@,S8U,C0Q+C<R-38R*2`J
M("1Y*2`K(#$W,C$R,S,N,C4T,#$["B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("!C87-E("=!551534Y!3$5154E.3U@G.@H@
M("`@("`@("`@("`@("`@("`@("1J=6QI86YD871E(#T@*"@H*"@H*#`N,#`P
M-S0@*B`D>2D@+2`P+C`P,CDW*2`J("1Y*2`M(#`N,3$V-S<I("H@)'DI("L@
M,S8U,C0R+C0Y-34X*2`J("1Y*2`K(#$W,C$S,C4N-S`T-34["B`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E("=724Y4
M15)33TQ35$E#12<Z"B`@("`@("`@("`@("`@("!D969A=6QT.@H@("`@("`@
M("`@("`@("`@("`@("1J=6QI86YD871E(#T@*"@H*"@H*"TP+C`P,#`V("H@
M)'DI("T@,"XP,#DS,RD@*B`D>2D@+2`P+C`P-S8Y*2`J("1Y*2`K(#,V-3(T
M,BXX.#(U-RD@*B`D>2D@*R`Q-S(Q-#$T+C,Y.3@W.PH@("`@("`@("`@("!]
M"B`@("`@("`@?2!E;'-E:68@*"@D>65A<B`^(#$P,#`I("8F("@D>65A<B`\
M/2`S,#`P*2D@>PH@("`@("`@("`@("`D>2`]("@D>65A<B`M(#(P,#`I("\@
M,3`P,#L*("`@("`@("`@("`@<W=I=&-H("@D<V5A<V]N*2!["B`@("`@("`@
M("`@("`@("!C87-E("=615).04Q%455)3D]8)SH*("`@("`@("`@("`@("`@
M("`@("`D:G5L:6%N9&%T92`]("@H*"@H*"@M,"XP,#`U-R`J("1Y*2`M(#`N
M,#`T,3$I("H@)'DI("L@,"XP-3$V.2D@*B`D>2D@*R`S-C4R-#(N,S<T,#0I
M("H@)'DI("L@,C0U,38R,RXX,#DX-#L*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@)U-534U%4E-/3%-424-%)SH*
M("`@("`@("`@("`@("`@("`@("`D:G5L:6%N9&%T92`]("@H*"@H*"@M,"XP
M,#`S("H@)'DI("L@,"XP,#@X."D@*B`D>2D@*R`P+C`P,S(U*2`J("1Y*2`K
M(#,V-3(T,2XV,C8P,RD@*B`D>2D@*R`R-#4Q-S$V+C4V-S8W.PH@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`G0554
M54U.04Q%455)3D]8)SH*("`@("`@("`@("`@("`@("`@("`D:G5L:6%N9&%T
M92`]("@H*"@H*"@P+C`P,#<X("H@)'DI("L@,"XP,#,S-RD@*B`D>2D@+2`P
M+C$Q-3<U*2`J("1Y*2`K(#,V-3(T,BXP,3<V-RD@*B`D>2D@*R`R-#4Q.#$P
M+C(Q-S$U.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("`@("`@8V%S92`G5TE.5$524T],4U1)0T4G.@H@("`@("`@("`@("`@("`@
M9&5F875L=#H*("`@("`@("`@("`@("`@("`@("`D:G5L:6%N9&%T92`]("@H
M*"@H*"@P+C`P,#,R("H@)'DI("T@,"XP,#@R,RD@*B`D>2D@+2`P+C`V,C(S
M*2`J("1Y*2`K(#,V-3(T,BXW-#`T.2D@*B`D>2D@*R`R-#4Q.3`P+C`U.34R
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D:G5L
M:6%N9&%T93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-U
M<G)E;G0@;&]C86P@9&%T90H@("`@("H*("`@("`J($Y/5$4Z(%1H:7,@9G5N
M8W1I;VX@<F5T<FEE=F5S('1H92!L;V-A;"!D871E('5S:6YG('-T<F9T:6UE
M*"DL"B`@("`@*B!W:&EC:"!M87D@;W(@;6%Y(&YO="!B92`S,BUB:70@<V%F
M92!O;B!Y;W5R('-Y<W1E;2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1F;W)M870@('1H92!S=')I;F<@:6YD:6-A=&EN9R!H;W<@=&\@9F]R;6%T
M('1H92!O=71P=70*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE
M(&-U<G)E;G0@9&%T92!I;B!T:&4@<W!E8VEF:65D(&9O<FUA=`H@("`@("H*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&1A=&5.;W<H)&9O<FUA="`]($1!5$5?0T%,0U]&3U)-
M050I"B`@("!["B`@("`@("`@<F5T=7)N('-T<F9T:6UE*"1F;W)M870L('1I
M;64H*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C=7)R
M96YT(&QO8V%L('EE87(@:6X@9F]R;6%T($-#65D*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@=&AE(&-U<G)E;G0@>65A<B!I;B!F;W5R(&1I9VET
M(&9O<FUA=`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`
M<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%EE87(H*0H@("`@>PH@
M("`@("`@(')E='5R;B!$871E7T-A;&,Z.F1A=&5.;W<H)R59)RD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C=7)R96YT(&QO8V%L(&UO
M;G1H(&EN(&9O<FUA="!-30H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!T:&4@8W5R<F5N="!M;VYT:"!I;B!T=V\@9&EG:70@9F]R;6%T"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T36]N=&@H*0H@("`@>PH@("`@("`@(')E='5R
M;B!$871E7T-A;&,Z.F1A=&5.;W<H)R5M)RD["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!C=7)R96YT(&QO8V%L(&1A>2!I;B!F;W)M870@
M1$0*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&-U<G)E;G0@
M9&%Y(&]F('1H92!M;VYT:"!I;B!T=V\@9&EG:70@9F]R;6%T"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T1&%Y*"D*("`@('L*("`@("`@("!R971U<FX@1&%T
M95]#86QC.CID871E3F]W*"<E9"<I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!N=6UB97(@;V8@9&%Y<R!S:6YC92`S,2!$96-E;6)E<B!O9B!Y
M96%R(&)E9F]R92!G:79E;B!D871E"B`@("`@*@H@("`@("H@0'!A<F%M(&EN
M="`@("`D9&%Y("`@("!T:&4@9&%Y(&]F('1H92!M;VYT:"P@9&5F875L="!I
M<R!C=7)R96YT(&QO8V%L(&1A>0H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N
M=&@@("!T:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT
M:`H@("`@("H@0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<B!I;B!F
M;W5R(&1I9VET(&9O<FUA="P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE
M87(*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&IU;&EA;B!D871E
M(&9O<B!T:&4@9&%T90H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&IU;&EA;D1A=&4H
M)&1A>2`](#`L("1M;VYT:"`](#`L("1Y96%R(#T@,"D*("`@('L*("`@("`@
M("!I9B`H96UP='DH)'EE87(I*2!["B`@("`@("`@("`@("1Y96%R(#T@1&%T
M95]#86QC.CID871E3F]W*"<E62<I.PH@("`@("`@('T*("`@("`@("!I9B`H
M96UP='DH)&UO;G1H*2D@>PH@("`@("`@("`@("`D;6]N=&@@/2!$871E7T-A
M;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T
M>2@D9&%Y*2D@>PH@("`@("`@("`@("`D9&%Y(#T@1&%T95]#86QC.CID871E
M3F]W*"<E9"<I.PH@("`@("`@('T*("`@("`@("`D9&%Y<R`](&%R<F%Y*#`L
M(#,Q+"`U.2P@.3`L(#$R,"P@,34Q+"`Q.#$L(#(Q,BP@,C0S+"`R-S,L(#,P
M-"P@,S,T*3L*("`@("`@("`D:G5L:6%N(#T@*"1D87ES6R1M;VYT:"`M(#%=
M("L@)&1A>2D["B`@("`@("`@:68@*"1M;VYT:"`^(#(@)B8@1&%T95]#86QC
M.CII<TQE87!996%R*"1Y96%R*2D@>PH@("`@("`@("`@("`D:G5L:6%N*RL[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D:G5L:6%N.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!T:&4@9G5L;"!W965K9&%Y(&YA;64@9F]R
M('1H92!G:79E;B!D871E"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D
M9&%Y("`@("!T:&4@9&%Y(&]F('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R
M96YT(&QO8V%L(&1A>0H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T
M:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@
M("H@0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I
M9VET(&9O<FUA="P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&9U;&P@;F%M92!O9B!T
M:&4@9&%Y(&]F('1H92!W965K"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5V5E
M:V1A>49U;&QN86UE*"1D87D@/2`P+"`D;6]N=&@@/2`P+"`D>65A<B`](#`I
M"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1Y96%R*2D@>PH@("`@("`@("`@
M("`D>65A<B`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)5DG*3L*("`@("`@("!]
M"B`@("`@("`@:68@*&5M<'1Y*"1M;VYT:"DI('L*("`@("`@("`@("`@)&UO
M;G1H(#T@1&%T95]#86QC.CID871E3F]W*"<E;2<I.PH@("`@("`@('T*("`@
M("`@("!I9B`H96UP='DH)&1A>2DI('L*("`@("`@("`@("`@)&1A>2`]($1A
M=&5?0V%L8SHZ9&%T94YO=R@G)60G*3L*("`@("`@("!]"B`@("`@("`@)'=E
M96MD87E?;F%M97,@/2!$871E7T-A;&,Z.F=E=%=E96M$87ES*"D["B`@("`@
M("`@)'=E96MD87D@/2!$871E7T-A;&,Z.F1A>4]F5V5E:R@D9&%Y+"`D;6]N
M=&@L("1Y96%R*3L*("`@("`@("!R971U<FX@)'=E96MD87E?;F%M97-;)'=E
M96MD87E=.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@86)B
M<F5V:6%T960@=V5E:V1A>2!N86UE(&9O<B!T:&4@9VEV96X@9&%T90H@("`@
M("H*("`@("`J($!P87)A;2!I;G0@("`@)&1A>2`@("`@=&AE(&1A>2!O9B!T
M:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!D87D*("`@("`J
M($!P87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO;G1H+"!D969A=6QT(&ES
M(&-U<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P87)A;2!I;G0@("`@)'EE
M87(@("`@=&AE('EE87(@:6X@9F]U<B!D:6=I="!F;W)M870L(&1E9F%U;'0@
M:7,@8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*B!`<&%R86T@:6YT("`@("1L
M96YG=&@@('1H92!L96YG=&@@;V8@86)B<F5V:6%T:6]N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@('1H92!A8F)R979I871E9"!N86UE(&]F('1H
M92!D87D@;V8@=&AE('=E96L*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("H@0'-T871I8PH@("`@("H@0'-E92!$871E7T-A;&,Z.F=E=%=E
M96MD87E&=6QL;F%M92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%=E96MD
M87E!8F)R;F%M92@D9&%Y(#T@,"P@)&UO;G1H(#T@,"P@)'EE87(@/2`P+"`D
M;&5N9W1H(#T@,RD*("`@('L*("`@("`@("!I9B`H96UP='DH)'EE87(I*2![
M"B`@("`@("`@("`@("1Y96%R(#T@1&%T95]#86QC.CID871E3F]W*"<E62<I
M.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&UO;G1H*2D@>PH@("`@
M("`@("`@("`D;6]N=&@@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5M)RD["B`@
M("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D9&%Y*2D@>PH@("`@("`@("`@
M("`D9&%Y(#T@1&%T95]#86QC.CID871E3F]W*"<E9"<I.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@<W5B<W1R*$1A=&5?0V%L8SHZ9V5T5V5E:V1A>49U
M;&QN86UE*"1D87DL("1M;VYT:"P@)'EE87(I+`H@("`@("`@("`@("`@("`@
M("`@("`@,"P@)&QE;F=T:"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS('1H92!F=6QL(&UO;G1H(&YA;64@9F]R('1H92!G:79E;B!M;VYT:`H@
M("`@("H*("`@("`J($!P87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO;G1H
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!F=6QL(&YA;64@
M;V8@=&AE(&UO;G1H"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T36]N=&A&=6QL
M;F%M92@D;6]N=&@I"B`@("!["B`@("`@("`@)&UO;G1H(#T@*&EN="DD;6]N
M=&@["B`@("`@("`@:68@*&5M<'1Y*"1M;VYT:"DI('L*("`@("`@("`@("`@
M)&UO;G1H(#T@*&EN="E$871E7T-A;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@
M("`@?0H@("`@("`@("1M;VYT:%]N86UE<R`]($1A=&5?0V%L8SHZ9V5T36]N
M=&A.86UE<R@I.PH@("`@("`@(')E='5R;B`D;6]N=&A?;F%M97-;)&UO;G1H
M73L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&%B8G)E=FEA
M=&5D(&UO;G1H(&YA;64@9F]R('1H92!G:79E;B!M;VYT:`H@("`@("H*("`@
M("`J($!P87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO;G1H"B`@("`@*B!`
M<&%R86T@:6YT("`@("1L96YG=&@@('1H92!L96YG=&@@;V8@86)B<F5V:6%T
M:6]N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!A8F)R979I
M871E9"!N86UE(&]F('1H92!M;VYT:`H@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@*B!`<V5E($1A=&5?0V%L8SHZ
M9V5T36]N=&A&=6QL;F%M90H@("`@("HO"B`@("!F=6YC=&EO;B!G971-;VYT
M:$%B8G)N86UE*"1M;VYT:"P@)&QE;F=T:"`](#,I"B`@("!["B`@("`@("`@
M)&UO;G1H(#T@*&EN="DD;6]N=&@["B`@("`@("`@:68@*&5M<'1Y*"1M;VYT
M:"DI('L*("`@("`@("`@("`@)&UO;G1H(#T@1&%T95]#86QC.CID871E3F]W
M*"<E;2<I.PH@("`@("`@('T*("`@("`@("!R971U<FX@<W5B<W1R*$1A=&5?
M0V%L8SHZ9V5T36]N=&A&=6QL;F%M92@D;6]N=&@I+"`P+"`D;&5N9W1H*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&YU;65R:6,@;6]N
M=&@@9G)O;2!T:&4@;6]N=&@@;F%M92!O<B!A;B!A8G)E=FEA=&EO;@H@("`@
M("H*("`@("`J($)O=&@@075G=7-T(&%N9"!!=6<@=V]U;&0@<F5T=7)N(#@N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;6]N=&@@('1H92!N86UE
M(&]F('1H92!M;VYT:"!T;R!E>&%M:6YE+@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("!#87-E(&EN<V5N<VET:79E+@H@("`@("H*("`@("`J($!R
M971U<FX@:6YT96=E<B`@=&AE(&UO;G1H)W,@;G5M8F5R"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T36]N=&A&<F]M1G5L;$YA;64H)&UO;G1H*0H@("`@>PH@
M("`@("`@("1M;VYT:"`]('-T<G1O;&]W97(H)&UO;G1H*3L*("`@("`@("`D
M;6]N=&AS(#T@1&%T95]#86QC.CIG971-;VYT:$YA;65S*"D["B`@("`@("`@
M=VAI;&4H;&ES="@D:60L("1N86UE*2`](&5A8V@H)&UO;G1H<RDI('L*("`@
M("`@("`@("`@:68@*&5R96<H)&UO;G1H+"!S=')T;VQO=V5R*"1N86UE*2DI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D:60["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N(#`["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS(&%N(&%R<F%Y(&]F(&UO;G1H(&YA;65S"B`@("`@*@H@
M("`@("H@57-E9"!T;R!T86ME(&%D=F%N=&%G92!O9B!T:&4@<V5T;&]C86QE
M(&9U;F-T:6]N('1O(')E='5R;@H@("`@("H@;&%N9W5A9V4@<W!E8VEF:6,@
M;6]N=&@@;F%M97,N"B`@("`@*@H@("`@("H@5$]$3SH@8V%C:&4@=F%L=65S
M('1O('-O;64@9VQO8F%L(&%R<F%Y('1O(&%V;VED('!R969O<FUA8V4*("`@
M("`J(&AI=',@=VAE;B!C86QL960@;6]R92!T:&%N(&]N8V4N"B`@("`@*@H@
M("`@("H@0')E='5R;G,@87)R87D@(&%N(&%R<F%Y(&]F(&UO;G1H(&YA;65S
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T36]N=&A.86UE<R@I"B`@("!["B`@
M("`@("`@9F]R("@D:2`](#$[("1I(#P@,3,[("1I*RLI('L*("`@("`@("`@
M("`@)&UO;G1H<ULD:5T@/2!S=')F=&EM92@G)4(G+"!M:W1I;64H,"P@,"P@
M,"P@)&DL(#$L(#(P,#$I*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1M
M;VYT:',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&%R<F%Y
M(&]F('=E96L@9&%Y<PH@("`@("H*("`@("`J(%5S960@=&\@=&%K92!A9'9A
M;G1A9V4@;V8@=&AE('-E=&QO8V%L92!F=6YC=&EO;B!T;PH@("`@("H@<F5T
M=7)N(&QA;F=U86=E('-P96-I9FEC('=E96L@9&%Y<RX*("`@("`J"B`@("`@
M*B!43T1/.B!C86-H92!V86QU97,@=&\@<V]M92!G;&]B86P@87)R87D@=&\@
M879O:60@<')E9F]R;6%C90H@("`@("H@:&ET<R!W:&5N(&-A;&QE9"!M;W)E
M('1H86X@;VYC92X*("`@("`J"B`@("`@*B!`<F5T=7)N<R!A<G)A>2`@86X@
M87)R87D@;V8@=V5E:R!D87D@;F%M97,*("`@("`J"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!G
M9717965K1&%Y<R@I"B`@("!["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@
M-SL@)&DK*RD@>PH@("`@("`@("`@("`D=V5E:V1A>7-;)&E=(#T@<W1R9G1I
M;64H)R5!)RP@;6MT:6UE*#`L(#`L(#`L(#$L("1I+"`R,#`Q*2D["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D=V5E:V1A>7,["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS(&1A>2!O9B!W965K(&9O<B!G:79E;B!D871E("@P
M(#T@4W5N9&%Y*0H@("`@("H*("`@("`J($!P87)A;2!I;G0@("`@)&1A>2`@
M("`@=&AE(&1A>2!O9B!T:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L
M;V-A;"!D87D*("`@("`J($!P87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO
M;G1H+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P
M87)A;2!I;G0@("`@)'EE87(@("`@=&AE('EE87(@:6X@9F]U<B!D:6=I="!F
M;W)M870L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*@H@
M("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB97(@;V8@=&AE(&1A>2!I;B!T
M:&4@=V5E:PH@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`
M<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&1A>4]F5V5E:R@D9&%Y(#T@
M,"P@)&UO;G1H(#T@,"P@)'EE87(@/2`P*0H@("`@>PH@("`@("`@(&EF("AE
M;7!T>2@D>65A<BDI('L*("`@("`@("`@("`@)'EE87(@/2!$871E7T-A;&,Z
M.F1A=&5.;W<H)R59)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D
M;6]N=&@I*2!["B`@("`@("`@("`@("1M;VYT:"`]($1A=&5?0V%L8SHZ9&%T
M94YO=R@G)6TG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1D87DI
M*2!["B`@("`@("`@("`@("1D87D@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5D
M)RD["B`@("`@("`@?0H@("`@("`@(&EF("@D;6]N=&@@/B`R*2!["B`@("`@
M("`@("`@("1M;VYT:"`M/2`R.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1M;VYT:"`K/2`Q,#L*("`@("`@("`@("`@)'EE87(M+3L*("`@("`@
M("!]"@H@("`@("`@("1D87D@/2`H9FQO;W(H*#$S("H@)&UO;G1H("T@,2D@
M+R`U*2`K"B`@("`@("`@("`@("`@("`D9&%Y("L@*"1Y96%R("4@,3`P*2`K
M"B`@("`@("`@("`@("`@("!F;&]O<B@H)'EE87(@)2`Q,#`I("\@-"D@*PH@
M("`@("`@("`@("`@("`@9FQO;W(H*"1Y96%R("\@,3`P*2`O(#0I("T@,B`J
M"B`@("`@("`@("`@("`@("!F;&]O<B@D>65A<B`O(#$P,"D@*R`W-RD["@H@
M("`@("`@("1W965K9&%Y7VYU;6)E<B`]("1D87D@+2`W("H@9FQO;W(H)&1A
M>2`O(#<I.PH@("`@("`@(')E='5R;B`D=V5E:V1A>5]N=6UB97(["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('=E96L@;V8@=&AE('EE87(L(&9I
M<G-T(%-U;F1A>2!I<R!F:7)S="!D87D@;V8@9FER<W0@=V5E:PH@("`@("H*
M("`@("`J($!P87)A;2!I;G0@("`@)&1A>2`@("`@=&AE(&1A>2!O9B!T:&4@
M;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!D87D*("`@("`J($!P
M87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO;G1H+"!D969A=6QT(&ES(&-U
M<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P87)A;2!I;G0@("`@)'EE87(@
M("`@=&AE('EE87(@:6X@9F]U<B!D:6=I="!F;W)M870L(&1E9F%U;'0@:7,@
M8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@
M('1H92!N=6UB97(@;V8@=&AE('=E96L@:6X@=&AE('EE87(*("`@("`J"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!W965K3V9996%R*"1D87D@/2`P+"`D;6]N=&@@/2`P+"`D
M>65A<B`](#`I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1Y96%R*2D@>PH@
M("`@("`@("`@("`D>65A<B`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)5DG*3L*
M("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1M;VYT:"DI('L*("`@("`@
M("`@("`@)&UO;G1H(#T@1&%T95]#86QC.CID871E3F]W*"<E;2<I.PH@("`@
M("`@('T*("`@("`@("!I9B`H96UP='DH)&1A>2DI('L*("`@("`@("`@("`@
M)&1A>2`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)60G*3L*("`@("`@("!]"B`@
M("`@("`@)&ES;R`@("`]($1A=&5?0V%L8SHZ9W)E9V]R:6%N5&])4T\H)&1A
M>2P@)&UO;G1H+"`D>65A<BD["B`@("`@("`@)'!A<G1S("`](&5X<&QO9&4H
M)RTG+"`D:7-O*3L*("`@("`@("`D=V5E:U]N=6UB97(@/2!I;G1V86PH)'!A
M<G1S6S%=*3L*("`@("`@("!R971U<FX@)'=E96M?;G5M8F5R.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!Q=6%R=&5R(&]F('1H92!Y96%R(&9O
M<B!G:79E;B!D871E"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D9&%Y
M("`@("!T:&4@9&%Y(&]F('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT
M(&QO8V%L(&1A>0H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T:&4@
M;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@("H@
M0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I9VET
M(&9O<FUA="P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!T:&4@<75A<G1E
M<B!I;B!T:&4@>65A<@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('%U87)T97)/9EEE
M87(H)&1A>2`](#`L("1M;VYT:"`](#`L("1Y96%R(#T@,"D*("`@('L*("`@
M("`@("!I9B`H96UP='DH)'EE87(I*2!["B`@("`@("`@("`@("1Y96%R(#T@
M1&%T95]#86QC.CID871E3F]W*"<E62<I.PH@("`@("`@('T*("`@("`@("!I
M9B`H96UP='DH)&UO;G1H*2D@>PH@("`@("`@("`@("`D;6]N=&@@/2!$871E
M7T-A;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE
M;7!T>2@D9&%Y*2D@>PH@("`@("`@("`@("`D9&%Y(#T@1&%T95]#86QC.CID
M871E3F]W*"<E9"<I.PH@("`@("`@('T*("`@("`@("`D>65A<E]Q=6%R=&5R
M(#T@:6YT=F%L*"@D;6]N=&@@+2`Q*2`O(#,@*R`Q*3L*("`@("`@("!R971U
M<FX@)'EE87)?<75A<G1E<CL*("`@('T*"B`@("`O*BH*("`@("`J($9I;F0@
M=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!G:79E;B!M;VYT:`H@("`@("H*
M("`@("`J($!P87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO;G1H+"!D969A
M=6QT(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P87)A;2!I;G0@
M("`@)'EE87(@("`@=&AE('EE87(@:6X@9F]U<B!D:6=I="!F;W)M870L(&1E
M9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*@H@("`@("H@0')E
M='5R;B!I;G0@('1H92!N=6UB97(@;V8@9&%Y<R!T:&4@;6]N=&@@:&%S"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@9&%Y<TEN36]N=&@H)&UO;G1H(#T@,"P@)'EE
M87(@/2`P*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D>65A<BDI('L*("`@
M("`@("`@("`@)'EE87(@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R59)RD["B`@
M("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D;6]N=&@I*2!["B`@("`@("`@
M("`@("1M;VYT:"`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)6TG*3L*("`@("`@
M("!]"@H@("`@("`@(&EF("@D>65A<B`]/2`Q-3@R("8F("1M;VYT:"`]/2`Q
M,"D@>PH@("`@("`@("`@("!R971U<FX@,C$[("`O+R!/8W1O8F5R(#$U.#(@
M;VYL>2!H860@,7-T+31T:"!A;F0@,35T:"TS,7-T"B`@("`@("`@?0H*("`@
M("`@("!I9B`H)&UO;G1H(#T](#(I('L*("`@("`@("`@("`@:68@*$1A=&5?
M0V%L8SHZ:7-,96%P665A<B@D>65A<BDI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`R.3L*("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("!R971U<FX@,C@["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V5I9B`H
M)&UO;G1H(#T](#0@;W(@)&UO;G1H(#T](#8@;W(@)&UO;G1H(#T](#D@;W(@
M)&UO;G1H(#T](#$Q*2!["B`@("`@("`@("`@(')E='5R;B`S,#L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@,S$["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;G5M8F5R(&]F(')O
M=W,@;VX@82!C86QE;F1A<B!M;VYT:`H@("`@("H*("`@("`J(%5S969U;"!F
M;W(@9&5T97)M:6YI;F<@=&AE(&YU;6)E<B!O9B!R;W=S('=H96X@9&ES<&QA
M>6EN9R!A('1Y<&EC86P*("`@("`J(&UO;G1H(&-A;&5N9&%R+@H@("`@("H*
M("`@("`J($!P87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO;G1H+"!D969A
M=6QT(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P87)A;2!I;G0@
M("`@)'EE87(@("`@=&AE('EE87(@:6X@9F]U<B!D:6=I="!F;W)M870L(&1E
M9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*@H@("`@("H@0')E
M='5R;B!I;G0@('1H92!N=6UB97(@;V8@=V5E:W,@=&AE(&UO;G1H(&AA<PH@
M("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@
M("`@*B\*("`@(&9U;F-T:6]N('=E96MS26Y-;VYT:"@D;6]N=&@@/2`P+"`D
M>65A<B`](#`I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1Y96%R*2D@>PH@
M("`@("`@("`@("`D>65A<B`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)5DG*3L*
M("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1M;VYT:"DI('L*("`@("`@
M("`@("`@)&UO;G1H(#T@1&%T95]#86QC.CID871E3F]W*"<E;2<I.PH@("`@
M("`@('T*("`@("`@("`D1D1/32`]($1A=&5?0V%L8SHZ9FER<W1/9DUO;G1H
M5V5E:V1A>2@D;6]N=&@L("1Y96%R*3L*("`@("`@("!I9B`H1$%415]#04Q#
M7T)%1TE.7U=%14M$05D]/3$@)B8@)$9$3TT]/3`I('L*("`@("`@("`@("`@
M)&9I<G-T7W=E96M?9&%Y<R`](#<@+2`D1D1/32`K($1!5$5?0T%,0U]"14=)
M3E]7145+1$%9.PH@("`@("`@("`@("`D=V5E:W,@/2`Q.PH@("`@("`@('T@
M96QS96EF("A$051%7T-!3$-?0D5'24Y?5T5%2T1!63T],"`F)B`D1D1/32`]
M/2`V*2!["B`@("`@("`@("`@("1F:7)S=%]W965K7V1A>7,@/2`W("T@)$9$
M3TT@*R!$051%7T-!3$-?0D5'24Y?5T5%2T1!63L*("`@("`@("`@("`@)'=E
M96MS(#T@,3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9FER<W1?
M=V5E:U]D87ES(#T@1$%415]#04Q#7T)%1TE.7U=%14M$05D@+2`D1D1/33L*
M("`@("`@("`@("`@)'=E96MS(#T@,#L*("`@("`@("!]"B`@("`@("`@)&9I
M<G-T7W=E96M?9&%Y<R`E/2`W.PH@("`@("`@(')E='5R;B!C96EL*"A$871E
M7T-A;&,Z.F1A>7-);DUO;G1H*"1M;VYT:"P@)'EE87(I"B`@("`@("`@("`@
M("`@("`@("`@("T@)&9I<G-T7W=E96M?9&%Y<RD@+R`W*2`K("1W965K<SL*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!A;B!A<G)A>2!W:71H(&1A
M>7,@:6X@=V5E:PH@("`@("H*("`@("`J($!P87)A;2!I;G0@("`@)&1A>2`@
M("`@=&AE(&1A>2!O9B!T:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L
M;V-A;"!D87D*("`@("`J($!P87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO
M;G1H+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P
M87)A;2!I;G0@("`@)'EE87(@("`@=&AE('EE87(@:6X@9F]U<B!D:6=I="!F
M;W)M870L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1F;W)M870@('1H92!S=')I;F<@:6YD:6-A=&EN9R!H
M;W<@=&\@9F]R;6%T('1H92!O=71P=70*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("1W965K6R1W965K9&%Y70H@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$-A;&5N9&%R5V5E:R@D9&%Y(#T@,"P@)&UO;G1H(#T@,"P@)'EE87(@/2`P
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F;W)M870@/2!$051%
M7T-!3$-?1D]234%4*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D>65A<BDI
M('L*("`@("`@("`@("`@)'EE87(@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R59
M)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D;6]N=&@I*2!["B`@
M("`@("`@("`@("1M;VYT:"`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)6TG*3L*
M("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1D87DI*2!["B`@("`@("`@
M("`@("1D87D@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5D)RD["B`@("`@("`@
M?0H*("`@("`@("`D=V5E:U]A<G)A>2`](&%R<F%Y*"D["@H@("`@("`@("\O
M(&1A=&4@9F]R('1H92!C;VQU;6X@;V8@=V5E:PH*("`@("`@("`D8W5R<E]D
M87D@/2!$871E7T-A;&,Z.F)E9VEN3V97965K*"1D87DL("1M;VYT:"P@)'EE
M87(L)R5%)RD["@H@("`@("`@(&9O<B`H)&-O=6YT97(@/2`P.R`D8V]U;G1E
M<B`\/2`V.R`D8V]U;G1E<BLK*2!["B`@("`@("`@("`@("1W965K7V%R<F%Y
M6R1C;W5N=&5R72`]($1A=&5?0V%L8SHZ9&%Y<U1O1&%T92@D8W5R<E]D87DL
M("1F;W)M870I.PH@("`@("`@("`@("`D8W5R<E]D87DK*SL*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1W965K7V%R<F%Y.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N(&$@<V5T(&]F(&%R<F%Y<R!T;R!C;VYS=')U8W0@82!C
M86QE;F1A<B!M;VYT:"!F;W(@=&AE(&=I=F5N(&1A=&4*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT("`@("1M;VYT:"`@('1H92!M;VYT:"P@9&5F875L="!I
M<R!C=7)R96YT(&QO8V%L(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1Y
M96%R("`@('1H92!Y96%R(&EN(&9O=7(@9&EG:70@9F]R;6%T+"!D969A=6QT
M(&ES(&-U<G)E;G0@;&]C86P@>65A<@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M9F]R;6%T("!T:&4@<W1R:6YG(&EN9&EC871I;F<@:&]W('1O(&9O<FUA="!T
M:&4@;W5T<'5T"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`D;6]N=&A;
M)')O=UU;)&-O;%T*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!G971#86QE;F1A<DUO
M;G1H*"1M;VYT:"`](#`L("1Y96%R(#T@,"P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&9O<FUA="`]($1!5$5?0T%,0U]&3U)-050I"B`@("![
M"B`@("`@("`@:68@*&5M<'1Y*"1Y96%R*2D@>PH@("`@("`@("`@("`D>65A
M<B`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)5DG*3L*("`@("`@("!]"B`@("`@
M("`@:68@*&5M<'1Y*"1M;VYT:"DI('L*("`@("`@("`@("`@)&UO;G1H(#T@
M1&%T95]#86QC.CID871E3F]W*"<E;2<I.PH@("`@("`@('T*"B`@("`@("`@
M)&UO;G1H7V%R<F%Y(#T@87)R87DH*3L*"B`@("`@("`@+R\@9&%T92!F;W(@
M=&AE(&9I<G-T(')O=RP@9FER<W0@8V]L=6UN(&]F(&-A;&5N9&%R(&UO;G1H
M"B`@("`@("`@:68@*$1!5$5?0T%,0U]"14=)3E]7145+1$%9(#T](#$I('L*
M("`@("`@("`@("`@:68@*$1A=&5?0V%L8SHZ9FER<W1/9DUO;G1H5V5E:V1A
M>2@D;6]N=&@L("1Y96%R*2`]/2`P*2!["B`@("`@("`@("`@("`@("`D8W5R
M<E]D87D@/2!$871E7T-A;&,Z.F1A=&54;T1A>7,H)S`Q)RP@)&UO;G1H+"`D
M>65A<BD@+2`V.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)&-U<G)?9&%Y(#T@1&%T95]#86QC.CID871E5&]$87ES*"<P,2<L("1M
M;VYT:"P@)'EE87(I"B`@("`@("`@("`@("`@("`@("`@+2!$871E7T-A;&,Z
M.F9I<G-T3V9-;VYT:%=E96MD87DH)&UO;G1H+"`D>65A<BD@*R`Q.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&-U<G)?
M9&%Y(#T@*$1A=&5?0V%L8SHZ9&%T951O1&%Y<R@G,#$G+"`D;6]N=&@L("1Y
M96%R*0H@("`@("`@("`@("`@("`@+2!$871E7T-A;&,Z.F9I<G-T3V9-;VYT
M:%=E96MD87DH)&UO;G1H+"`D>65A<BDI.PH@("`@("`@('T*"B`@("`@("`@
M+R\@;G5M8F5R(&]F(&1A>7,@:6X@=&AI<R!M;VYT:`H@("`@("`@("1D87ES
M26Y-;VYT:"`]($1A=&5?0V%L8SHZ9&%Y<TEN36]N=&@H)&UO;G1H+"`D>65A
M<BD["@H@("`@("`@("1W965K<TEN36]N=&@@/2!$871E7T-A;&,Z.G=E96MS
M26Y-;VYT:"@D;6]N=&@L("1Y96%R*3L*("`@("`@("!F;W(@*"1R;W=?8V]U
M;G1E<B`](#`[("1R;W=?8V]U;G1E<B`\("1W965K<TEN36]N=&@[("1R;W=?
M8V]U;G1E<BLK*2!["B`@("`@("`@("`@(&9O<B`H)&-O;'5M;E]C;W5N=&5R
M(#T@,#L@)&-O;'5M;E]C;W5N=&5R(#P](#8[("1C;VQU;6Y?8V]U;G1E<BLK
M*2!["B`@("`@("`@("`@("`@("`D;6]N=&A?87)R87E;)')O=U]C;W5N=&5R
M75LD8V]L=6UN7V-O=6YT97)=(#T*("`@("`@("`@("`@("`@("`@("`@("`@
M1&%T95]#86QC.CID87ES5&]$871E*"1C=7)R7V1A>2`L("1F;W)M870I.PH@
M("`@("`@("`@("`@("`@)&-U<G)?9&%Y*RL["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D;6]N=&A?87)R87D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FX@82!S970@;V8@87)R87ES('1O(&-O;G-T
M<G5C="!A(&-A;&5N9&%R('EE87(@9F]R('1H92!G:79E;B!D871E"B`@("`@
M*@H@("`@("H@0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<B!I;B!F
M;W5R(&1I9VET(&9O<FUA="P@9&5F875L="!C=7)R96YT(&QO8V%L('EE87(*
M("`@("`J($!P87)A;2!S=')I;F<@)&9O<FUA="`@=&AE('-T<FEN9R!I;F1I
M8V%T:6YG(&AO=R!T;R!F;W)M870@=&AE(&]U='!U=`H@("`@("H*("`@("`J
M($!R971U<FX@87)R87D@)'EE87);)&UO;G1H75LD<F]W75LD8V]L70H@("`@
M("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$-A;&5N9&%R665A<B@D>65A<B`](#`L("1F
M;W)M870@/2!$051%7T-!3$-?1D]234%4*0H@("`@>PH@("`@("`@(&EF("AE
M;7!T>2@D>65A<BDI('L*("`@("`@("`@("`@)'EE87(@/2!$871E7T-A;&,Z
M.F1A=&5.;W<H)R59)RD["B`@("`@("`@?0H*("`@("`@("`D>65A<E]A<G)A
M>2`](&%R<F%Y*"D["@H@("`@("`@(&9O<B`H)&-U<G)?;6]N=&@@/2`P.R`D
M8W5R<E]M;VYT:"`\/2`Q,3L@)&-U<G)?;6]N=&@K*RD@>PH@("`@("`@("`@
M("`D>65A<E]A<G)A>5LD8W5R<E]M;VYT:%T@/0H@("`@("`@("`@("`@("`@
M("`@($1A=&5?0V%L8SHZ9V5T0V%L96YD87)-;VYT:"@D8W5R<E]M;VYT:"`K
M(#$L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1Y96%R+"`D9F]R;6%T*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D>65A<E]A<G)A>3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@9&%T92!O9B!D87D@8F5F;W)E(&=I=F5N(&1A=&4*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT("`@("1D87D@("`@('1H92!D87D@;V8@=&AE(&UO;G1H
M+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@9&%Y"B`@("`@*B!`<&%R86T@
M:6YT("`@("1M;VYT:"`@('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT
M(&QO8V%L(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H
M92!Y96%R(&EN(&9O=7(@9&EG:70@9F]R;6%T+"!D969A=6QT(&ES(&-U<G)E
M;G0@;&]C86P@>65A<@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]R;6%T("!T
M:&4@<W1R:6YG(&EN9&EC871I;F<@:&]W('1O(&9O<FUA="!T:&4@;W5T<'5T
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!D871E(&EN('1H
M92!D97-I<F5D(&9O<FUA=`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('!R979$87DH
M)&1A>2`](#`L("1M;VYT:"`](#`L("1Y96%R(#T@,"P*("`@("`@("`@("`@
M("`@("`@("`@)&9O<FUA="`]($1!5$5?0T%,0U]&3U)-050I"B`@("!["B`@
M("`@("`@:68@*&5M<'1Y*"1Y96%R*2D@>PH@("`@("`@("`@("`D>65A<B`]
M($1A=&5?0V%L8SHZ9&%T94YO=R@G)5DG*3L*("`@("`@("!]"B`@("`@("`@
M:68@*&5M<'1Y*"1M;VYT:"DI('L*("`@("`@("`@("`@)&UO;G1H(#T@1&%T
M95]#86QC.CID871E3F]W*"<E;2<I.PH@("`@("`@('T*("`@("`@("!I9B`H
M96UP='DH)&1A>2DI('L*("`@("`@("`@("`@)&1A>2`]($1A=&5?0V%L8SHZ
M9&%T94YO=R@G)60G*3L*("`@("`@("!]"B`@("`@("`@)&1A>7,@/2!$871E
M7T-A;&,Z.F1A=&54;T1A>7,H)&1A>2P@)&UO;G1H+"`D>65A<BD["B`@("`@
M("`@<F5T=7)N($1A=&5?0V%L8SHZ9&%Y<U1O1&%T92@D9&%Y<R`M(#$L("1F
M;W)M870I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!D871E(&]F
M(&1A>2!A9G1E<B!G:79E;B!D871E"B`@("`@*@H@("`@("H@0'!A<F%M(&EN
M="`@("`D9&%Y("`@("!T:&4@9&%Y(&]F('1H92!M;VYT:"P@9&5F875L="!I
M<R!C=7)R96YT(&QO8V%L(&1A>0H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N
M=&@@("!T:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT
M:`H@("`@("H@0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<B!I;B!F
M;W5R(&1I9VET(&9O<FUA="P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE
M87(*("`@("`J($!P87)A;2!S=')I;F<@)&9O<FUA="`@=&AE('-T<FEN9R!I
M;F1I8V%T:6YG(&AO=R!T;R!F;W)M870@=&AE(&]U='!U=`H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!T:&4@9&%T92!I;B!T:&4@9&5S:7)E9"!F
M;W)M870*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T
M871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!N97AT1&%Y*"1D87D@/2`P+"`D
M;6]N=&@@/2`P+"`D>65A<B`](#`L"B`@("`@("`@("`@("`@("`@("`@("1F
M;W)M870@/2!$051%7T-!3$-?1D]234%4*0H@("`@>PH@("`@("`@(&EF("AE
M;7!T>2@D>65A<BDI('L*("`@("`@("`@("`@)'EE87(@/2!$871E7T-A;&,Z
M.F1A=&5.;W<H)R59)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D
M;6]N=&@I*2!["B`@("`@("`@("`@("1M;VYT:"`]($1A=&5?0V%L8SHZ9&%T
M94YO=R@G)6TG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1D87DI
M*2!["B`@("`@("`@("`@("1D87D@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5D
M)RD["B`@("`@("`@?0H@("`@("`@("1D87ES(#T@1&%T95]#86QC.CID871E
M5&]$87ES*"1D87DL("1M;VYT:"P@)'EE87(I.PH@("`@("`@(')E='5R;B!$
M871E7T-A;&,Z.F1A>7-4;T1A=&4H)&1A>7,@*R`Q+"`D9F]R;6%T*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@9&%T92!O9B!T:&4@<')E=FEO
M=7,@=V5E:V1A>2P@<VMI<'!I;F<@9G)O;2!-;VYD87D@=&\@1G)I9&%Y"B`@
M("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D9&%Y("`@("!T:&4@9&%Y(&]F
M('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&1A>0H@("`@
M("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T:&4@;6]N=&@L(&1E9F%U;'0@
M:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@("H@0'!A<F%M(&EN="`@("`D
M>65A<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I9VET(&9O<FUA="P@9&5F875L
M="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@("`J($!P87)A;2!S=')I;F<@
M)&9O<FUA="`@=&AE('-T<FEN9R!I;F1I8V%T:6YG(&AO=R!T;R!F;W)M870@
M=&AE(&]U='!U=`H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@
M9&%T92!I;B!T:&4@9&5S:7)E9"!F;W)M870*("`@("`J"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO
M;B!P<F5V5V5E:V1A>2@D9&%Y(#T@,"P@)&UO;G1H(#T@,"P@)'EE87(@/2`P
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@)&9O<FUA="`]($1!5$5?0T%,
M0U]&3U)-050I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1Y96%R*2D@>PH@
M("`@("`@("`@("`D>65A<B`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)5DG*3L*
M("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1M;VYT:"DI('L*("`@("`@
M("`@("`@)&UO;G1H(#T@1&%T95]#86QC.CID871E3F]W*"<E;2<I.PH@("`@
M("`@('T*("`@("`@("!I9B`H96UP='DH)&1A>2DI('L*("`@("`@("`@("`@
M)&1A>2`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)60G*3L*("`@("`@("!]"B`@
M("`@("`@)&1A>7,@/2!$871E7T-A;&,Z.F1A=&54;T1A>7,H)&1A>2P@)&UO
M;G1H+"`D>65A<BD["B`@("`@("`@:68@*$1A=&5?0V%L8SHZ9&%Y3V97965K
M*"1D87DL("1M;VYT:"P@)'EE87(I(#T](#$I('L*("`@("`@("`@("`@)&1A
M>7,@+3T@,SL*("`@("`@("!](&5L<V5I9B`H1&%T95]#86QC.CID87E/9E=E
M96LH)&1A>2P@)&UO;G1H+"`D>65A<BD@/3T@,"D@>PH@("`@("`@("`@("`D
M9&%Y<R`M/2`R.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1D87ES
M("T](#$["B`@("`@("`@?0H@("`@("`@(')E='5R;B!$871E7T-A;&,Z.F1A
M>7-4;T1A=&4H)&1A>7,L("1F;W)M870I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!D871E(&]F('1H92!N97AT('=E96MD87D@;V8@9VEV96X@
M9&%T92P@<VMI<'!I;F<@9G)O;0H@("`@("H@1G)I9&%Y('1O($UO;F1A>0H@
M("`@("H*("`@("`J($!P87)A;2!I;G0@("`@)&1A>2`@("`@=&AE(&1A>2!O
M9B!T:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!D87D*("`@
M("`J($!P87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO;G1H+"!D969A=6QT
M(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P87)A;2!I;G0@("`@
M)'EE87(@("`@=&AE('EE87(@:6X@9F]U<B!D:6=I="!F;W)M870L(&1E9F%U
M;'0@:7,@8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1F;W)M870@('1H92!S=')I;F<@:6YD:6-A=&EN9R!H;W<@=&\@9F]R;6%T
M('1H92!O=71P=70*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE
M(&1A=&4@:6X@=&AE(&1E<VER960@9F]R;6%T"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I
M;VX@;F5X=%=E96MD87DH)&1A>2`](#`L("1M;VYT:"`](#`L("1Y96%R(#T@
M,"P*("`@("`@("`@("`@("`@("`@("`@("`@("1F;W)M870@/2!$051%7T-!
M3$-?1D]234%4*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D>65A<BDI('L*
M("`@("`@("`@("`@)'EE87(@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R59)RD[
M"B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D;6]N=&@I*2!["B`@("`@
M("`@("`@("1M;VYT:"`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)6TG*3L*("`@
M("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1D87DI*2!["B`@("`@("`@("`@
M("1D87D@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5D)RD["B`@("`@("`@?0H@
M("`@("`@("1D87ES(#T@1&%T95]#86QC.CID871E5&]$87ES*"1D87DL("1M
M;VYT:"P@)'EE87(I.PH@("`@("`@(&EF("A$871E7T-A;&,Z.F1A>4]F5V5E
M:R@D9&%Y+"`D;6]N=&@L("1Y96%R*2`]/2`U*2!["B`@("`@("`@("`@("1D
M87ES("L](#,["B`@("`@("`@?2!E;'-E:68@*$1A=&5?0V%L8SHZ9&%Y3V97
M965K*"1D87DL("1M;VYT:"P@)'EE87(I(#T](#8I('L*("`@("`@("`@("`@
M)&1A>7,@*ST@,CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9&%Y
M<R`K/2`Q.PH@("`@("`@('T*("`@("`@("!R971U<FX@1&%T95]#86QC.CID
M87ES5&]$871E*"1D87ES+"`D9F]R;6%T*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@9&%T92!O9B!T:&4@<')E=FEO=7,@<W!E8VEF:6,@9&%Y
M(&]F('1H92!W965K"B`@("`@*B!F<F]M('1H92!G:79E;B!D871E"B`@("`@
M*@H@("`@("H@0'!A<F%M(&EN="!D87D@;V8@=V5E:RP@,#U3=6YD87D*("`@
M("`J($!P87)A;2!I;G0@("`@)&1A>2`@("`@=&AE(&1A>2!O9B!T:&4@;6]N
M=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!D87D*("`@("`J($!P87)A
M;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO;G1H+"!D969A=6QT(&ES(&-U<G)E
M;G0@;&]C86P@;6]N=&@*("`@("`J($!P87)A;2!I;G0@("`@)'EE87(@("`@
M=&AE('EE87(@:6X@9F]U<B!D:6=I="!F;W)M870L(&1E9F%U;'0@:7,@8W5R
M<F5N="!L;V-A;"!Y96%R"B`@("`@*B!`<&%R86T@8F]O;"`@("1O;D]R0F5F
M;W)E("!I9B!T<G5E(&%N9"!D87ES(&%R92!S86UE+"!R971U<FYS(&-U<G)E
M;G0@9&%Y"B`@("`@*B!`<&%R86T@<W1R:6YG("1F;W)M870@('1H92!S=')I
M;F<@:6YD:6-A=&EN9R!H;W<@=&\@9F]R;6%T('1H92!O=71P=70*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&1A=&4@:6X@=&AE(&1E<VER
M960@9F]R;6%T"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<')E=D1A>4]F5V5E:R@D
M9&]W+"`D9&%Y(#T@,"P@)&UO;G1H(#T@,"P@)'EE87(@/2`P+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9F]R;6%T(#T@1$%415]#04Q#7T9/4DU!
M5"P@)&]N3W)"969O<F4@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H96UP
M='DH)'EE87(I*2!["B`@("`@("`@("`@("1Y96%R(#T@1&%T95]#86QC.CID
M871E3F]W*"<E62<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&UO
M;G1H*2D@>PH@("`@("`@("`@("`D;6]N=&@@/2!$871E7T-A;&,Z.F1A=&5.
M;W<H)R5M)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D9&%Y*2D@
M>PH@("`@("`@("`@("`D9&%Y(#T@1&%T95]#86QC.CID871E3F]W*"<E9"<I
M.PH@("`@("`@('T*("`@("`@("`D9&%Y<R`]($1A=&5?0V%L8SHZ9&%T951O
M1&%Y<R@D9&%Y+"`D;6]N=&@L("1Y96%R*3L*("`@("`@("`D8W5R<E]W965K
M9&%Y(#T@1&%T95]#86QC.CID87E/9E=E96LH)&1A>2P@)&UO;G1H+"`D>65A
M<BD["B`@("`@("`@:68@*"1C=7)R7W=E96MD87D@/3T@)&1O=RD@>PH@("`@
M("`@("`@("!I9B`H(21O;D]R0F5F;W)E*2!["B`@("`@("`@("`@("`@("`D
M9&%Y<R`M/2`W.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E:68@*"1C
M=7)R7W=E96MD87D@/"`D9&]W*2!["B`@("`@("`@("`@("1D87ES("T](#<@
M+2`H)&1O=R`M("1C=7)R7W=E96MD87DI.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1D87ES("T]("1C=7)R7W=E96MD87D@+2`D9&]W.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@1&%T95]#86QC.CID87ES5&]$871E*"1D
M87ES+"`D9F]R;6%T*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M9&%T92!O9B!T:&4@;F5X="!S<&5C:69I8R!D87D@;V8@=&AE('=E96L*("`@
M("`J(&9R;VT@=&AE(&=I=F5N(&1A=&4*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT("`@("1D;W<@("`@('1H92!D87D@;V8@=&AE('=E96L@*#`@/2!3=6YD
M87DI"B`@("`@*B!`<&%R86T@:6YT("`@("1D87D@("`@('1H92!D87D@;V8@
M=&AE(&UO;G1H+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@9&%Y"B`@("`@
M*B!`<&%R86T@:6YT("`@("1M;VYT:"`@('1H92!M;VYT:"P@9&5F875L="!I
M<R!C=7)R96YT(&QO8V%L(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1Y
M96%R("`@('1H92!Y96%R(&EN(&9O=7(@9&EG:70@9F]R;6%T+"!D969A=6QT
M(&ES(&-U<G)E;G0@;&]C86P@>65A<@H@("`@("H@0'!A<F%M(&)O;VP@("`D
M;VY/<D%F=&5R("!I9B!T<G5E(&%N9"!D87ES(&%R92!S86UE+"!R971U<FYS
M(&-U<G)E;G0@9&%Y"B`@("`@*B!`<&%R86T@<W1R:6YG("1F;W)M870@('1H
M92!S=')I;F<@:6YD:6-A=&EN9R!H;W<@=&\@9F]R;6%T('1H92!O=71P=70*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&1A=&4@:6X@=&AE
M(&1E<VER960@9F]R;6%T"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I;VX@;F5X=$1A>4]F
M5V5E:R@D9&]W+"`D9&%Y(#T@,"P@)&UO;G1H(#T@,"P@)'EE87(@/2`P+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R;6%T(#T@1$%415]#04Q#
M7T9/4DU!5"P@)&]N3W)!9G1E<B`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF
M("AE;7!T>2@D>65A<BDI('L*("`@("`@("`@("`@)'EE87(@/2!$871E7T-A
M;&,Z.F1A=&5.;W<H)R59)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T
M>2@D;6]N=&@I*2!["B`@("`@("`@("`@("1M;VYT:"`]($1A=&5?0V%L8SHZ
M9&%T94YO=R@G)6TG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1D
M87DI*2!["B`@("`@("`@("`@("1D87D@/2!$871E7T-A;&,Z.F1A=&5.;W<H
M)R5D)RD["B`@("`@("`@?0H*("`@("`@("`D9&%Y<R`]($1A=&5?0V%L8SHZ
M9&%T951O1&%Y<R@D9&%Y+"`D;6]N=&@L("1Y96%R*3L*("`@("`@("`D8W5R
M<E]W965K9&%Y(#T@1&%T95]#86QC.CID87E/9E=E96LH)&1A>2P@)&UO;G1H
M+"`D>65A<BD["@H@("`@("`@(&EF("@D8W5R<E]W965K9&%Y(#T]("1D;W<I
M('L*("`@("`@("`@("`@:68@*"$D;VY/<D%F=&5R*2!["B`@("`@("`@("`@
M("`@("`D9&%Y<R`K/2`W.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E
M:68@*"1C=7)R7W=E96MD87D@/B`D9&]W*2!["B`@("`@("`@("`@("1D87ES
M("L](#<@+2`H)&-U<G)?=V5E:V1A>2`M("1D;W<I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1D87ES("L]("1D;W<@+2`D8W5R<E]W965K9&%Y
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N($1A=&5?0V%L8SHZ9&%Y<U1O
M1&%T92@D9&%Y<RP@)&9O<FUA="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS(&1A=&4@;V8@=&AE('!R979I;W5S('-P96-I9FEC(&1A>2!O9B!T
M:&4@=V5E:PH@("`@("H@;VX@;W(@8F5F;W)E('1H92!G:79E;B!D871E"B`@
M("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D9&]W("`@("!T:&4@9&%Y(&]F
M('1H92!W965K("@P(#T@4W5N9&%Y*0H@("`@("H@0'!A<F%M(&EN="`@("`D
M9&%Y("`@("!T:&4@9&%Y(&]F('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R
M96YT(&QO8V%L(&1A>0H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T
M:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@
M("H@0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I
M9VET(&9O<FUA="P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@
M("`J($!P87)A;2!S=')I;F<@)&9O<FUA="`@=&AE('-T<FEN9R!I;F1I8V%T
M:6YG(&AO=R!T;R!F;W)M870@=&AE(&]U='!U=`H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!T:&4@9&%T92!I;B!T:&4@9&5S:7)E9"!F;W)M870*
M("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@
M("`@("HO"B`@("!F=6YC=&EO;B!P<F5V1&%Y3V97965K3VY/<D)E9F]R92@D
M9&]W+"`D9&%Y(#T@,"P@)&UO;G1H(#T@,"P@)'EE87(@/2`P+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O<FUA="`]($1!5$5?
M0T%,0U]&3U)-050I"B`@("!["B`@("`@("`@<F5T=7)N($1A=&5?0V%L8SHZ
M<')E=D1A>4]F5V5E:R@D9&]W+"`D9&%Y+"`D;6]N=&@L("1Y96%R+"`D9F]R
M;6%T+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M=')U92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&1A=&4@;V8@
M=&AE(&YE>'0@<W!E8VEF:6,@9&%Y(&]F('1H92!W965K"B`@("`@*B!O;B!O
M<B!A9G1E<B!T:&4@9VEV96X@9&%T90H@("`@("H*("`@("`J($!P87)A;2!I
M;G0@("`@)&1O=R`@("`@=&AE(&1A>2!O9B!T:&4@=V5E:R`H,"`](%-U;F1A
M>2D*("`@("`J($!P87)A;2!I;G0@("`@)&1A>2`@("`@=&AE(&1A>2!O9B!T
M:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!D87D*("`@("`J
M($!P87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO;G1H+"!D969A=6QT(&ES
M(&-U<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P87)A;2!I;G0@("`@)'EE
M87(@("`@=&AE('EE87(@:6X@9F]U<B!D:6=I="!F;W)M870L(&1E9F%U;'0@
M:7,@8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*B!`<&%R86T@<W1R:6YG("1F
M;W)M870@('1H92!S=')I;F<@:6YD:6-A=&EN9R!H;W<@=&\@9F]R;6%T('1H
M92!O=71P=70*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&1A
M=&4@:6X@=&AE(&1E<VER960@9F]R;6%T"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I;VX@
M;F5X=$1A>4]F5V5E:T]N3W)!9G1E<B@D9&]W+"`D9&%Y(#T@,"P@)&UO;G1H
M(#T@,"P@)'EE87(@/2`P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9F]R;6%T(#T@1$%415]#04Q#7T9/4DU!5"D*("`@('L*("`@
M("`@("!R971U<FX@1&%T95]#86QC.CIN97AT1&%Y3V97965K*"1D;W<L("1D
M87DL("1M;VYT:"P@)'EE87(L("1F;W)M870L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!T<G5E*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($9I;F0@=&AE(&UO;G1H(&1A>2!O9B!T:&4@8F5G:6YN:6YG(&]F
M('=E96L@9F]R(&=I=F5N(&1A=&4L"B`@("`@*B!U<VEN9R!$051%7T-!3$-?
M0D5'24Y?5T5%2T1!60H@("`@("H*("`@("`J($-A;B!R971U<FX@=V5E:V1A
M>2!O9B!P<F5V(&UO;G1H+@H@("`@("H*("`@("`J($!P87)A;2!I;G0@("`@
M)&1A>2`@("`@=&AE(&1A>2!O9B!T:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R
M<F5N="!L;V-A;"!D87D*("`@("`J($!P87)A;2!I;G0@("`@)&UO;G1H("`@
M=&AE(&UO;G1H+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*("`@
M("`J($!P87)A;2!I;G0@("`@)'EE87(@("`@=&AE('EE87(@:6X@9F]U<B!D
M:6=I="!F;W)M870L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!Y96%R"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1F;W)M870@('1H92!S=')I;F<@:6YD:6-A
M=&EN9R!H;W<@=&\@9F]R;6%T('1H92!O=71P=70*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@=&AE(&1A=&4@:6X@=&AE(&1E<VER960@9F]R;6%T
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@8F5G:6Y/9E=E96LH)&1A>2`](#`L("1M
M;VYT:"`](#`L("1Y96%R(#T@,"P*("`@("`@("`@("`@("`@("`@("`@("`@
M("1F;W)M870@/2!$051%7T-!3$-?1D]234%4*0H@("`@>PH@("`@("`@(&EF
M("AE;7!T>2@D>65A<BDI('L*("`@("`@("`@("`@)'EE87(@/2!$871E7T-A
M;&,Z.F1A=&5.;W<H)R59)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T
M>2@D;6]N=&@I*2!["B`@("`@("`@("`@("1M;VYT:"`]($1A=&5?0V%L8SHZ
M9&%T94YO=R@G)6TG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1D
M87DI*2!["B`@("`@("`@("`@("1D87D@/2!$871E7T-A;&,Z.F1A=&5.;W<H
M)R5D)RD["B`@("`@("`@?0H@("`@("`@("1T:&ES7W=E96MD87D@/2!$871E
M7T-A;&,Z.F1A>4]F5V5E:R@D9&%Y+"`D;6]N=&@L("1Y96%R*3L*("`@("`@
M("`D:6YT97)V86P@/2`H-R`M($1!5$5?0T%,0U]"14=)3E]7145+1$%9("L@
M)'1H:7-?=V5E:V1A>2D@)2`W.PH@("`@("`@(')E='5R;B!$871E7T-A;&,Z
M.F1A>7-4;T1A=&4H1&%T95]#86QC.CID871E5&]$87ES*"1D87DL("1M;VYT
M:"P@)'EE87(I"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`M("1I;G1E<G9A;"P@)&9O<FUA="D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!&:6YD('1H92!M;VYT:"!D87D@;V8@=&AE(&5N9"!O9B!W965K(&9O<B!G
M:79E;B!D871E+`H@("`@("H@=7-I;F<@1$%415]#04Q#7T)%1TE.7U=%14M$
M05D*("`@("`J"B`@("`@*B!#86X@<F5T=7)N('=E96MD87D@;V8@9F]L;&]W
M:6YG(&UO;G1H+@H@("`@("H*("`@("`J($!P87)A;2!I;G0@("`@)&1A>2`@
M("`@=&AE(&1A>2!O9B!T:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L
M;V-A;"!D87D*("`@("`J($!P87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO
M;G1H+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P
M87)A;2!I;G0@("`@)'EE87(@("`@=&AE('EE87(@:6X@9F]U<B!D:6=I="!F
M;W)M870L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1F;W)M870@('1H92!S=')I;F<@:6YD:6-A=&EN9R!H
M;W<@=&\@9F]R;6%T('1H92!O=71P=70*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@=&AE(&1A=&4@:6X@=&AE(&1E<VER960@9F]R;6%T"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J
M+PH@("`@9G5N8W1I;VX@96YD3V97965K*"1D87D@/2`P+"`D;6]N=&@@/2`P
M+"`D>65A<B`](#`L"B`@("`@("`@("`@("`@("`@("`@("`@)&9O<FUA="`]
M($1!5$5?0T%,0U]&3U)-050I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1Y
M96%R*2D@>PH@("`@("`@("`@("`D>65A<B`]($1A=&5?0V%L8SHZ9&%T94YO
M=R@G)5DG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1M;VYT:"DI
M('L*("`@("`@("`@("`@)&UO;G1H(#T@1&%T95]#86QC.CID871E3F]W*"<E
M;2<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&1A>2DI('L*("`@
M("`@("`@("`@)&1A>2`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)60G*3L*("`@
M("`@("!]"B`@("`@("`@)'1H:7-?=V5E:V1A>2`]($1A=&5?0V%L8SHZ9&%Y
M3V97965K*"1D87DL("1M;VYT:"P@)'EE87(I.PH@("`@("`@("1I;G1E<G9A
M;"`]("@V("L@1$%415]#04Q#7T)%1TE.7U=%14M$05D@+2`D=&AI<U]W965K
M9&%Y*2`E(#<["B`@("`@("`@<F5T=7)N($1A=&5?0V%L8SHZ9&%Y<U1O1&%T
M92A$871E7T-A;&,Z.F1A=&54;T1A>7,H)&1A>2P@)&UO;G1H+"`D>65A<BD*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("L@)&EN=&5R
M=F%L+"`D9F]R;6%T*3L*("`@('T*"B`@("`O*BH*("`@("`J($9I;F0@=&AE
M(&UO;G1H(&1A>2!O9B!T:&4@8F5G:6YN:6YG(&]F('=E96L@8F5F;W)E(&=I
M=F5N(&1A=&4L"B`@("`@*B!U<VEN9R!$051%7T-!3$-?0D5'24Y?5T5%2T1!
M60H@("`@("H*("`@("`J($-A;B!R971U<FX@=V5E:V1A>2!O9B!P<F5V(&UO
M;G1H+@H@("`@("H*("`@("`J($!P87)A;2!I;G0@("`@)&1A>2`@("`@=&AE
M(&1A>2!O9B!T:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!D
M87D*("`@("`J($!P87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO;G1H+"!D
M969A=6QT(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P87)A;2!I
M;G0@("`@)'EE87(@("`@=&AE('EE87(@:6X@9F]U<B!D:6=I="!F;W)M870L
M(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1F;W)M870@('1H92!S=')I;F<@:6YD:6-A=&EN9R!H;W<@=&\@
M9F]R;6%T('1H92!O=71P=70*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@=&AE(&1A=&4@:6X@=&AE(&1E<VER960@9F]R;6%T"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@8F5G:6Y/9E!R9797965K*"1D87D@/2`P+"`D;6]N=&@@/2`P
M+"`D>65A<B`](#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O
M<FUA="`]($1!5$5?0T%,0U]&3U)-050I"B`@("!["B`@("`@("`@:68@*&5M
M<'1Y*"1Y96%R*2D@>PH@("`@("`@("`@("`D>65A<B`]($1A=&5?0V%L8SHZ
M9&%T94YO=R@G)5DG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1M
M;VYT:"DI('L*("`@("`@("`@("`@)&UO;G1H(#T@1&%T95]#86QC.CID871E
M3F]W*"<E;2<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&1A>2DI
M('L*("`@("`@("`@("`@)&1A>2`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)60G
M*3L*("`@("`@("!]"@H@("`@("`@("1D871E(#T@1&%T95]#86QC.CID87ES
M5&]$871E*$1A=&5?0V%L8SHZ9&%T951O1&%Y<R@D9&%Y+3<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1M;VYT:"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'EE87(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<E625M)60G*3L*"B`@
M("`@("`@)'!R979?=V5E:U]Y96%R("`]('-U8G-T<B@D9&%T92P@,"P@-"D[
M"B`@("`@("`@)'!R979?=V5E:U]M;VYT:"`]('-U8G-T<B@D9&%T92P@-"P@
M,BD["B`@("`@("`@)'!R979?=V5E:U]D87D@("`]('-U8G-T<B@D9&%T92P@
M-BP@,BD["@H@("`@("`@(')E='5R;B!$871E7T-A;&,Z.F)E9VEN3V97965K
M*"1P<F5V7W=E96M?9&%Y+"`D<')E=E]W965K7VUO;G1H+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<F5V7W=E96M?>65A<BP@
M)&9O<FUA="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&:6YD('1H92!M;VYT
M:"!D87D@;V8@=&AE(&)E9VEN;FEN9R!O9B!W965K(&%F=&5R(&=I=F5N(&1A
M=&4L"B`@("`@*B!U<VEN9R!$051%7T-!3$-?0D5'24Y?5T5%2T1!60H@("`@
M("H*("`@("`J($-A;B!R971U<FX@=V5E:V1A>2!O9B!P<F5V(&UO;G1H+@H@
M("`@("H*("`@("`J($!P87)A;2!I;G0@("`@)&1A>2`@("`@=&AE(&1A>2!O
M9B!T:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!D87D*("`@
M("`J($!P87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO;G1H+"!D969A=6QT
M(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P87)A;2!I;G0@("`@
M)'EE87(@("`@=&AE('EE87(@:6X@9F]U<B!D:6=I="!F;W)M870L(&1E9F%U
M;'0@:7,@8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1F;W)M870@('1H92!S=')I;F<@:6YD:6-A=&EN9R!H;W<@=&\@9F]R;6%T
M('1H92!O=71P=70*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE
M(&1A=&4@:6X@=&AE(&1E<VER960@9F]R;6%T"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I
M;VX@8F5G:6Y/9DYE>'17965K*"1D87D@/2`P+"`D;6]N=&@@/2`P+"`D>65A
M<B`](#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O<FUA="`]
M($1!5$5?0T%,0U]&3U)-050I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1Y
M96%R*2D@>PH@("`@("`@("`@("`D>65A<B`]($1A=&5?0V%L8SHZ9&%T94YO
M=R@G)5DG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1M;VYT:"DI
M('L*("`@("`@("`@("`@)&UO;G1H(#T@1&%T95]#86QC.CID871E3F]W*"<E
M;2<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&1A>2DI('L*("`@
M("`@("`@("`@)&1A>2`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)60G*3L*("`@
M("`@("!]"@H@("`@("`@("1D871E(#T@1&%T95]#86QC.CID87ES5&]$871E
M*$1A=&5?0V%L8SHZ9&%T951O1&%Y<R@D9&%Y("L@-RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&UO;G1H+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D>65A<BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)R59)6TE9"<I.PH*("`@("`@
M("`D;F5X=%]W965K7WEE87(@(#T@<W5B<W1R*"1D871E+"`P+"`T*3L*("`@
M("`@("`D;F5X=%]W965K7VUO;G1H(#T@<W5B<W1R*"1D871E+"`T+"`R*3L*
M("`@("`@("`D;F5X=%]W965K7V1A>2`@(#T@<W5B<W1R*"1D871E+"`V+"`R
M*3L*"B`@("`@("`@<F5T=7)N($1A=&5?0V%L8SHZ8F5G:6Y/9E=E96LH)&YE
M>'1?=V5E:U]D87DL("1N97AT7W=E96M?;6]N=&@L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&YE>'1?=V5E:U]Y96%R+"`D9F]R
M;6%T*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!D871E(&]F(&9I
M<G-T(&1A>2!O9B!M;VYT:"!O9B!G:79E;B!D871E"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN="`@("`D;6]N=&@@("!T:&4@;6]N=&@L(&1E9F%U;'0@:7,@
M8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@("H@0'!A<F%M(&EN="`@("`D>65A
M<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I9VET(&9O<FUA="P@9&5F875L="!I
M<R!C=7)R96YT(&QO8V%L('EE87(*("`@("`J($!P87)A;2!S=')I;F<@)&9O
M<FUA="`@=&AE('-T<FEN9R!I;F1I8V%T:6YG(&AO=R!T;R!F;W)M870@=&AE
M(&]U='!U=`H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@9&%T
M92!I;B!T:&4@9&5S:7)E9"!F;W)M870*("`@("`J"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@("H@0'-E92!$871E7T-A;&,Z
M.F)E9VEN3V9-;VYT:$)Y4W!A;B@I"B`@("`@*B!`9&5P<F5C871E9"!-971H
M;V0@9&5P<F5C871E9"!I;B!296QE87-E(#$N-2XP"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&)E9VEN3V9-;VYT:"@D;6]N=&@@/2`P+"`D>65A<B`](#`L("1F
M;W)M870@/2!$051%7T-!3$-?1D]234%4*0H@("`@>PH@("`@("`@(&EF("AE
M;7!T>2@D>65A<BDI('L*("`@("`@("`@("`@)'EE87(@/2!$871E7T-A;&,Z
M.F1A=&5.;W<H)R59)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D
M;6]N=&@I*2!["B`@("`@("`@("`@("1M;VYT:"`]($1A=&5?0V%L8SHZ9&%T
M94YO=R@G)6TG*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1A=&5?0V%L
M8SHZ9&%T949O<FUA="@G,#$G+"`D;6]N=&@L("1Y96%R+"`D9F]R;6%T*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@9&%T92!O9B!T:&4@9FER
M<W0@9&%Y(&]F('!R979I;W5S(&UO;G1H(&]F(&=I=F5N(&1A=&4*("`@("`J
M"B`@("`@*B!`<&%R86T@:6YT("`@("1D87D@("`@('1H92!D87D@;V8@=&AE
M(&UO;G1H+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@9&%Y"B`@("`@*B!`
M<&%R86T@:6YT("`@("1M;VYT:"`@('1H92!M;VYT:"P@9&5F875L="!I<R!C
M=7)R96YT(&QO8V%L(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R
M("`@('1H92!Y96%R(&EN(&9O=7(@9&EG:70@9F]R;6%T+"!D969A=6QT(&ES
M(&-U<G)E;G0@;&]C86P@>65A<@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]R
M;6%T("!T:&4@<W1R:6YG(&EN9&EC871I;F<@:&]W('1O(&9O<FUA="!T:&4@
M;W5T<'5T"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!D871E
M(&EN('1H92!D97-I<F5D(&9O<FUA=`H@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@*B!`<V5E($1A=&5?0V%L8SHZ
M8F5G:6Y/9DUO;G1H0GE3<&%N*"D*("`@("`J($!D97!R96-A=&5D($UE=&AO
M9"!D97!R96-A=&5D(&EN(%)E;&5A<V4@,2XU+C`*("`@("`J+PH@("`@9G5N
M8W1I;VX@8F5G:6Y/9E!R979-;VYT:"@D9&%Y(#T@,"P@)&UO;G1H(#T@,"P@
M)'EE87(@/2`P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R
M;6%T(#T@1$%415]#04Q#7T9/4DU!5"D*("`@('L*("`@("`@("!I9B`H96UP
M='DH)'EE87(I*2!["B`@("`@("`@("`@("1Y96%R(#T@1&%T95]#86QC.CID
M871E3F]W*"<E62<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&UO
M;G1H*2D@>PH@("`@("`@("`@("`D;6]N=&@@/2!$871E7T-A;&,Z.F1A=&5.
M;W<H)R5M)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D9&%Y*2D@
M>PH@("`@("`@("`@("`D9&%Y(#T@1&%T95]#86QC.CID871E3F]W*"<E9"<I
M.PH@("`@("`@('T*("`@("`@("!I9B`H)&UO;G1H(#X@,2D@>PH@("`@("`@
M("`@("`D;6]N=&@M+3L*("`@("`@("`@("`@)&1A>2`](#$["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)'EE87(M+3L*("`@("`@("`@("`@)&UO
M;G1H(#T@,3(["B`@("`@("`@("`@("1D87D@("`](#$["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B!$871E7T-A;&,Z.F1A=&5&;W)M870H)&1A>2P@)&UO
M;G1H+"`D>65A<BP@)&9O<FUA="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS(&1A=&4@;V8@=&AE(&QA<W0@9&%Y(&]F('!R979I;W5S(&UO;G1H
M(&9O<B!G:79E;B!D871E"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D
M9&%Y("`@("!T:&4@9&%Y(&]F('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R
M96YT(&QO8V%L(&1A>0H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T
M:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@
M("H@0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I
M9VET(&9O<FUA="P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@
M("`J($!P87)A;2!S=')I;F<@)&9O<FUA="`@=&AE('-T<FEN9R!I;F1I8V%T
M:6YG(&AO=R!T;R!F;W)M870@=&AE(&]U='!U=`H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!T:&4@9&%T92!I;B!T:&4@9&5S:7)E9"!F;W)M870*
M("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@
M("`@("H@0'-E92!$871E7T-A;&,Z.F5N9$]F36]N=&A">5-P86XH*0H@("`@
M("H@0&1E<')E8V%T960@365T:&]D(&1E<')E8V%T960@:6X@4F5L96%S92`Q
M+C4N,`H@("`@("HO"B`@("!F=6YC=&EO;B!E;F1/9E!R979-;VYT:"@D9&%Y
M(#T@,"P@)&UO;G1H(#T@,"P@)'EE87(@/2`P+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&9O<FUA="`]($1!5$5?0T%,0U]&3U)-050I"B`@("![
M"B`@("`@("`@:68@*&5M<'1Y*"1Y96%R*2D@>PH@("`@("`@("`@("`D>65A
M<B`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)5DG*3L*("`@("`@("!]"B`@("`@
M("`@:68@*&5M<'1Y*"1M;VYT:"DI('L*("`@("`@("`@("`@)&UO;G1H(#T@
M1&%T95]#86QC.CID871E3F]W*"<E;2<I.PH@("`@("`@('T*("`@("`@("!I
M9B`H96UP='DH)&1A>2DI('L*("`@("`@("`@("`@)&1A>2`]($1A=&5?0V%L
M8SHZ9&%T94YO=R@G)60G*3L*("`@("`@("!]"B`@("`@("`@:68@*"1M;VYT
M:"`^(#$I('L*("`@("`@("`@("`@)&UO;G1H+2T["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'EE87(M+3L*("`@("`@("`@("`@)&UO;G1H(#T@
M,3(["B`@("`@("`@?0H@("`@("`@("1D87D@/2!$871E7T-A;&,Z.F1A>7-)
M;DUO;G1H*"1M;VYT:"P@)'EE87(I.PH@("`@("`@(')E='5R;B!$871E7T-A
M;&,Z.F1A=&5&;W)M870H)&1A>2P@)&UO;G1H+"`D>65A<BP@)&9O<FUA="D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&1A=&4@;V8@8F5G:6X@
M;V8@;F5X="!M;VYT:"!O9B!G:79E;B!D871E"B`@("`@*@H@("`@("H@0'!A
M<F%M(&EN="`@("`D9&%Y("`@("!T:&4@9&%Y(&]F('1H92!M;VYT:"P@9&5F
M875L="!I<R!C=7)R96YT(&QO8V%L(&1A>0H@("`@("H@0'!A<F%M(&EN="`@
M("`D;6]N=&@@("!T:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A
M;"!M;VYT:`H@("`@("H@0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A
M<B!I;B!F;W5R(&1I9VET(&9O<FUA="P@9&5F875L="!I<R!C=7)R96YT(&QO
M8V%L('EE87(*("`@("`J($!P87)A;2!S=')I;F<@)&9O<FUA="`@=&AE('-T
M<FEN9R!I;F1I8V%T:6YG(&AO=R!T;R!F;W)M870@=&AE(&]U='!U=`H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@9&%T92!I;B!T:&4@9&5S
M:7)E9"!F;W)M870*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("H@0'-T871I8PH@("`@("H@0'-E92!$871E7T-A;&,Z.F)E9VEN3V9-;VYT
M:$)Y4W!A;B@I"B`@("`@*B!`9&5P<F5C871E9"!-971H;V0@9&5P<F5C871E
M9"!I;B!296QE87-E(#$N-2XP"B`@("`@*B\*("`@(&9U;F-T:6]N(&)E9VEN
M3V9.97AT36]N=&@H)&1A>2`](#`L("1M;VYT:"`](#`L("1Y96%R(#T@,"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O<FUA="`]($1!5$5?
M0T%,0U]&3U)-050I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1Y96%R*2D@
M>PH@("`@("`@("`@("`D>65A<B`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)5DG
M*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1M;VYT:"DI('L*("`@
M("`@("`@("`@)&UO;G1H(#T@1&%T95]#86QC.CID871E3F]W*"<E;2<I.PH@
M("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&1A>2DI('L*("`@("`@("`@
M("`@)&1A>2`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)60G*3L*("`@("`@("!]
M"B`@("`@("`@:68@*"1M;VYT:"`\(#$R*2!["B`@("`@("`@("`@("1M;VYT
M:"LK.PH@("`@("`@("`@("`D9&%Y(#T@,3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D>65A<BLK.PH@("`@("`@("`@("`D;6]N=&@@/2`Q.PH@
M("`@("`@("`@("`D9&%Y(#T@,3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M($1A=&5?0V%L8SHZ9&%T949O<FUA="@D9&%Y+"`D;6]N=&@L("1Y96%R+"`D
M9F]R;6%T*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@9&%T92!O
M9B!T:&4@;&%S="!D87D@;V8@;F5X="!M;VYT:"!O9B!G:79E;B!D871E"B`@
M("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D9&%Y("`@("!T:&4@9&%Y(&]F
M('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&1A>0H@("`@
M("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T:&4@;6]N=&@L(&1E9F%U;'0@
M:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@("H@0'!A<F%M(&EN="`@("`D
M>65A<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I9VET(&9O<FUA="P@9&5F875L
M="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@("`J($!P87)A;2!S=')I;F<@
M)&9O<FUA="`@=&AE('-T<FEN9R!I;F1I8V%T:6YG(&AO=R!T;R!F;W)M870@
M=&AE(&]U='!U=`H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@
M9&%T92!I;B!T:&4@9&5S:7)E9"!F;W)M870*("`@("`J"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@("H@0'-E92!$871E7T-A
M;&,Z.F5N9$]F36]N=&A">5-P86XH*0H@("`@("H@0&1E<')E8V%T960@365T
M:&]D(&1E<')E8V%T960@:6X@4F5L96%S92`Q+C4N,`H@("`@("HO"B`@("!F
M=6YC=&EO;B!E;F1/9DYE>'1-;VYT:"@D9&%Y(#T@,"P@)&UO;G1H(#T@,"P@
M)'EE87(@/2`P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O<FUA
M="`]($1!5$5?0T%,0U]&3U)-050I"B`@("!["B`@("`@("`@:68@*&5M<'1Y
M*"1Y96%R*2D@>PH@("`@("`@("`@("`D>65A<B`]($1A=&5?0V%L8SHZ9&%T
M94YO=R@G)5DG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1M;VYT
M:"DI('L*("`@("`@("`@("`@)&UO;G1H(#T@1&%T95]#86QC.CID871E3F]W
M*"<E;2<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&1A>2DI('L*
M("`@("`@("`@("`@)&1A>2`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)60G*3L*
M("`@("`@("!]"B`@("`@("`@:68@*"1M;VYT:"`\(#$R*2!["B`@("`@("`@
M("`@("1M;VYT:"LK.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1Y
M96%R*RL["B`@("`@("`@("`@("1M;VYT:"`](#$["B`@("`@("`@?0H@("`@
M("`@("1D87D@/2!$871E7T-A;&,Z.F1A>7-);DUO;G1H*"1M;VYT:"P@)'EE
M87(I.PH@("`@("`@(')E='5R;B!$871E7T-A;&,Z.F1A=&5&;W)M870H)&1A
M>2P@)&UO;G1H+"`D>65A<BP@)&9O<FUA="D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS(&1A=&4@;V8@=&AE(&9I<G-T(&1A>2!O9B!T:&4@;6]N
M=&@@:6X@=&AE(&YU;6)E<B!O9B!M;VYT:',*("`@("`J(&9R;VT@=&AE(&=I
M=F5N(&1A=&4*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("`@("1M;VYT:',@
M('1H92!N=6UB97(@;V8@;6]N=&AS(&9R;VT@=&AE(&1A=&4@<')O=FED960N
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!0;W-I=&EV92!N=6UB
M97)S(&=O(&EN=&\@=&AE(&9U='5R92X*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@($YE9V%T:79E(&YU;6)E<G,@9V\@:6YT;R!T:&4@<&%S="X*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(#`@:7,@=&AE(&UO;G1H
M('!R97-E;G1E9"!I;B`D;6]N=&@N"B`@("`@*B!`<&%R86T@<W1R:6YG("1M
M;VYT:"`@('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&UO
M;G1H"B`@("`@*B!`<&%R86T@<W1R:6YG("1Y96%R("`@('1H92!Y96%R(&EN
M(&9O=7(@9&EG:70@9F]R;6%T+"!D969A=6QT(&ES('1H90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1F;W)M870@('1H92!S=')I;F<@:6YD:6-A=&EN
M9R!H;W<@=&\@9F]R;6%T('1H92!O=71P=70*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@=&AE(&1A=&4@:6X@=&AE(&1E<VER960@9F]R;6%T"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@
M("`J($!S:6YC92`@365T:&]D(&%V86EL86)L92!S:6YC92!296QE87-E(#$N
M-2XP"B`@("`@*B\*("`@(&9U;F-T:6]N(&)E9VEN3V9-;VYT:$)Y4W!A;B@D
M;6]N=&AS(#T@,"P@)&UO;G1H(#T@,"P@)'EE87(@/2`P+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1F;W)M870@/2!$051%7T-!3$-?1D]2
M34%4*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D>65A<BDI('L*("`@("`@
M("`@("`@)'EE87(@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R59)RD["B`@("`@
M("`@?0H@("`@("`@(&EF("AE;7!T>2@D;6]N=&@I*2!["B`@("`@("`@("`@
M("1M;VYT:"`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)6TG*3L*("`@("`@("!]
M"B`@("`@("`@:68@*"1M;VYT:',@/B`P*2!["B`@("`@("`@("`@("\O(&9U
M='5R92!M;VYT:`H@("`@("`@("`@("`D=&UP7VUO(#T@)&UO;G1H("L@)&UO
M;G1H<SL*("`@("`@("`@("`@)&UO;G1H("`]("1T;7!?;6\@)2`Q,CL*("`@
M("`@("`@("`@:68@*"1M;VYT:"`]/2`P*2!["B`@("`@("`@("`@("`@("`D
M;6]N=&@@/2`Q,CL*("`@("`@("`@("`@("`@("1Y96%R(#T@)'EE87(@*R!F
M;&]O<B@H)'1M<%]M;R`M(#$I("\@,3(I.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)'EE87(@/2`D>65A<B`K(&9L;V]R*"1T;7!?
M;6\@+R`Q,BD["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`O+R!P87-T(&]R('!R97-E;G0@;6]N=&@*("`@("`@("`@("`@
M)'1M<%]M;R`]("1M;VYT:"`K("1M;VYT:',["B`@("`@("`@("`@(&EF("@D
M=&UP7VUO(#X@,"D@>PH@("`@("`@("`@("`@("`@+R\@<V%M92!Y96%R"B`@
M("`@("`@("`@("`@("`D;6]N=&@@/2`D=&UP7VUO.PH@("`@("`@("`@("!]
M(&5L<V5I9B`H)'1M<%]M;R`]/2`P*2!["B`@("`@("`@("`@("`@("`O+R!P
M<FEO<B!D96,*("`@("`@("`@("`@("`@("1M;VYT:"`](#$R.PH@("`@("`@
M("`@("`@("`@)'EE87(M+3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("\O('-O;64@=&EM92!I;B!A('!R:6]R('EE87(*("`@("`@
M("`@("`@("`@("1M;VYT:"`](#$R("L@*"1T;7!?;6\@)2`Q,BD["B`@("`@
M("`@("`@("`@("`D>65A<B`@/2`D>65A<B`K(&9L;V]R*"1T;7!?;6\@+R`Q
M,BD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1A
M=&5?0V%L8SHZ9&%T949O<FUA="@Q+"`D;6]N=&@L("1Y96%R+"`D9F]R;6%T
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@9&%T92!O9B!T:&4@
M;&%S="!D87D@;V8@=&AE(&UO;G1H(&EN('1H92!N=6UB97(@;V8@;6]N=&AS
M"B`@("`@*B!F<F]M('1H92!G:79E;B!D871E"B`@("`@*@H@("`@("H@0'!A
M<F%M(&EN="`@("`D;6]N=&AS("!T:&4@;G5M8F5R(&]F(&UO;G1H<R!F<F]M
M('1H92!D871E('!R;W9I9&5D+@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@4&]S:71I=F4@;G5M8F5R<R!G;R!I;G1O('1H92!F=71U<F4N"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!.96=A=&EV92!N=6UB97)S
M(&=O(&EN=&\@=&AE('!A<W0N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`P(&ES('1H92!M;VYT:"!P<F5S96YT960@:6X@)&UO;G1H+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;6]N=&@@("!T:&4@;6]N=&@L(&1E9F%U;'0@
M:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@("H@0'!A<F%M('-T<FEN9R`D
M>65A<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I9VET(&9O<FUA="P@9&5F875L
M="!I<R!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&-U<G)E
M;G0@;&]C86P@>65A<@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]R;6%T("!T
M:&4@<W1R:6YG(&EN9&EC871I;F<@:&]W('1O(&9O<FUA="!T:&4@;W5T<'5T
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!D871E(&EN('1H
M92!D97-I<F5D(&9O<FUA=`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B!`<W1A=&EC"B`@("`@*B!`<VEN8V4@($UE=&AO9"!A=F%I;&%B
M;&4@<VEN8V4@4F5L96%S92`Q+C4N,`H@("`@("HO"B`@("!F=6YC=&EO;B!E
M;F1/9DUO;G1H0GE3<&%N*"1M;VYT:',@/2`P+"`D;6]N=&@@/2`P+"`D>65A
M<B`](#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F;W)M870@
M/2!$051%7T-!3$-?1D]234%4*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D
M>65A<BDI('L*("`@("`@("`@("`@)'EE87(@/2!$871E7T-A;&,Z.F1A=&5.
M;W<H)R59)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D;6]N=&@I
M*2!["B`@("`@("`@("`@("1M;VYT:"`]($1A=&5?0V%L8SHZ9&%T94YO=R@G
M)6TG*3L*("`@("`@("!]"B`@("`@("`@:68@*"1M;VYT:',@/B`P*2!["B`@
M("`@("`@("`@("\O(&9U='5R92!M;VYT:`H@("`@("`@("`@("`D=&UP7VUO
M(#T@)&UO;G1H("L@)&UO;G1H<SL*("`@("`@("`@("`@)&UO;G1H("`]("1T
M;7!?;6\@)2`Q,CL*("`@("`@("`@("`@:68@*"1M;VYT:"`]/2`P*2!["B`@
M("`@("`@("`@("`@("`D;6]N=&@@/2`Q,CL*("`@("`@("`@("`@("`@("1Y
M96%R(#T@)'EE87(@*R!F;&]O<B@H)'1M<%]M;R`M(#$I("\@,3(I.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'EE87(@/2`D>65A
M<B`K(&9L;V]R*"1T;7!?;6\@+R`Q,BD["B`@("`@("`@("`@('T*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`O+R!P87-T(&]R('!R97-E;G0@;6]N
M=&@*("`@("`@("`@("`@)'1M<%]M;R`]("1M;VYT:"`K("1M;VYT:',["B`@
M("`@("`@("`@(&EF("@D=&UP7VUO(#X@,"D@>PH@("`@("`@("`@("`@("`@
M+R\@<V%M92!Y96%R"B`@("`@("`@("`@("`@("`D;6]N=&@@/2`D=&UP7VUO
M.PH@("`@("`@("`@("!](&5L<V5I9B`H)'1M<%]M;R`]/2`P*2!["B`@("`@
M("`@("`@("`@("`O+R!P<FEO<B!D96,*("`@("`@("`@("`@("`@("1M;VYT
M:"`](#$R.PH@("`@("`@("`@("`@("`@)'EE87(M+3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("\O('-O;64@=&EM92!I;B!A('!R
M:6]R('EE87(*("`@("`@("`@("`@("`@("1M;VYT:"`](#$R("L@*"1T;7!?
M;6\@)2`Q,BD["B`@("`@("`@("`@("`@("`D>65A<B`@/2`D>65A<B`K(&9L
M;V]R*"1T;7!?;6\@+R`Q,BD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N($1A=&5?0V%L8SHZ9&%T949O<FUA="A$871E7T-A;&,Z
M.F1A>7-);DUO;G1H*"1M;VYT:"P@)'EE87(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&UO;G1H+"`D>65A<BP@)&9O<FUA="D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!&:6YD('1H92!D87D@;V8@=&AE('=E
M96L@9F]R('1H92!F:7)S="!O9B!T:&4@;6]N=&@@;V8@9VEV96X@9&%T90H@
M("`@("H*("`@("`J($!P87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO;G1H
M+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P87)A
M;2!I;G0@("`@)'EE87(@("`@=&AE('EE87(@:6X@9F]U<B!D:6=I="!F;W)M
M870L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*@H@("`@
M("H@0')E='5R;B!I;G0@;G5M8F5R(&]F('=E96MD87D@9F]R('1H92!F:7)S
M="!D87DL(#`]4W5N9&%Y"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9FER<W1/9DUO
M;G1H5V5E:V1A>2@D;6]N=&@@/2`P+"`D>65A<B`](#`I"B`@("!["B`@("`@
M("`@:68@*&5M<'1Y*"1Y96%R*2D@>PH@("`@("`@("`@("`D>65A<B`]($1A
M=&5?0V%L8SHZ9&%T94YO=R@G)5DG*3L*("`@("`@("!]"B`@("`@("`@:68@
M*&5M<'1Y*"1M;VYT:"DI('L*("`@("`@("`@("`@)&UO;G1H(#T@1&%T95]#
M86QC.CID871E3F]W*"<E;2<I.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M1&%T95]#86QC.CID87E/9E=E96LH)S`Q)RP@)&UO;G1H+"`D>65A<BD["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#86QC=6QA=&5S('1H92!D871E(&]F('1H
M92!.=&@@=V5E:V1A>2!O9B!T:&4@;6]N=&@L"B`@("`@*B!S=6-H(&%S('1H
M92!S96-O;F0@4V%T=7)D87D@;V8@2F%N=6%R>2`R,#`P"B`@("`@*@H@("`@
M("H@0'!A<F%M(&EN="`@("`D=V5E:R`@("!T:&4@;G5M8F5R(&]F('1H92!W
M965K('1O(&=E=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@*#$@
M/2!F:7)S="P@971C+B`@06QS;R!C86X@8F4@)VQA<W0G+BD*("`@("`J($!P
M87)A;2!I;G0@("`@)&1O=R`@("`@=&AE(&1A>2!O9B!T:&4@=V5E:R`H,"`]
M(%-U;F1A>2D*("`@("`J($!P87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO
M;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H92!Y96%R+B`@
M57-E('1H92!C;VUP;&5T92!Y96%R(&EN<W1E860@;V8@=&AE"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!A8F)R979I871E9"!V97)S:6]N+B`@
M12YG+B!U<V4@,C`P-2P@;F]T(#`U+@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@1&\@;F]T(&%D9"!L96%D:6YG(#`G<R!F;W(@>65A<G,@<')I
M;W(@=&\@,3`P,"X*("`@("`J($!P87)A;2!S=')I;F<@)&9O<FUA="`@=&AE
M('-T<FEN9R!I;F1I8V%T:6YG(&AO=R!T;R!F;W)M870@=&AE(&]U='!U=`H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@9&%T92!I;B!T:&4@
M9&5S:7)E9"!F;W)M870*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!.5V5E:V1A>4]F
M36]N=&@H)'=E96LL("1D;W<L("1M;VYT:"P@)'EE87(L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&9O<FUA="`]($1!5$5?0T%,0U]&3U)-050I
M"B`@("!["B`@("`@("`@:68@*&ES7VYU;65R:6,H)'=E96LI*2!["B`@("`@
M("`@("`@("1$3U<Q9&%Y(#T@*"1W965K("T@,2D@*B`W("L@,3L*("`@("`@
M("`@("`@)$1/5S$@("`@/2!$871E7T-A;&,Z.F1A>4]F5V5E:R@D1$]7,61A
M>2P@)&UO;G1H+"`D>65A<BD["B`@("`@("`@("`@("1W9&%T92`@(#T@*"1W
M965K("T@,2D@*B`W("L@,2`K("@W("L@)&1O=R`M("1$3U<Q*2`E(#<["B`@
M("`@("`@("`@(&EF("@D=V1A=&4@/B!$871E7T-A;&,Z.F1A>7-);DUO;G1H
M*"1M;VYT:"P@)'EE87(I*2!["B`@("`@("`@("`@("`@("!R971U<FX@+3$[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@
M1&%T95]#86QC.CID871E1F]R;6%T*"1W9&%T92P@)&UO;G1H+"`D>65A<BP@
M)&9O<FUA="D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V5I9B`H)'=E
M96L@/3T@)VQA<W0G("8F("1D;W<@/"`W*2!["B`@("`@("`@("`@("1L87-T
M9&%Y(#T@1&%T95]#86QC.CID87ES26Y-;VYT:"@D;6]N=&@L("1Y96%R*3L*
M("`@("`@("`@("`@)&QA<W1D;W<@/2!$871E7T-A;&,Z.F1A>4]F5V5E:R@D
M;&%S=&1A>2P@)&UO;G1H+"`D>65A<BD["B`@("`@("`@("`@("1D:69F("`@
M(#T@)&1O=R`M("1L87-T9&]W.PH@("`@("`@("`@("!I9B`H)&1I9F8@/B`P
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@1&%T95]#86QC.CID871E1F]R
M;6%T*"1L87-T9&%Y("T@*#<@+2`D9&EF9BDL("1M;VYT:"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'EE87(L("1F
M;W)M870I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N($1A=&5?0V%L8SHZ9&%T949O<FUA="@D;&%S=&1A>2`K("1D:69F
M+"`D;6]N=&@L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1Y96%R+"`D9F]R;6%T*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`M,3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1R=64@9F]R('9A;&ED
M(&1A=&4L(&9A;'-E(&9O<B!I;G9A;&ED(&1A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@:6YT("`@("1D87D@("`@('1H92!D87D@;V8@=&AE(&UO;G1H"B`@
M("`@*B!`<&%R86T@:6YT("`@("1M;VYT:"`@('1H92!M;VYT:`H@("`@("H@
M0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<BX@(%5S92!T:&4@8V]M
M<&QE=&4@>65A<B!I;G-T96%D(&]F('1H90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@86)B<F5V:6%T960@=F5R<VEO;BX@($4N9RX@=7-E(#(P
M,#4L(&YO="`P-2X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@($1O
M(&YO="!A9&0@;&5A9&EN9R`P)W,@9F]R('EE87)S('!R:6]R('1O(#$P,#`N
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N
M8W1I;VX@:7-686QI9$1A=&4H)&1A>2P@)&UO;G1H+"`D>65A<BD*("`@('L*
M("`@("`@("!I9B`H)'EE87(@/"`P('Q\("1Y96%R(#X@.3DY.2D@>PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@(&EF("@A
M8VAE8VMD871E*"1M;VYT:"P@)&1A>2P@)'EE87(I*2!["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1R=64@9F]R(&$@;&5A
M<"!Y96%R+"!E;'-E(&9A;'-E"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@
M("`D>65A<B`@("!T:&4@>65A<BX@(%5S92!T:&4@8V]M<&QE=&4@>65A<B!I
M;G-T96%D(&]F('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M86)B<F5V:6%T960@=F5R<VEO;BX@($4N9RX@=7-E(#(P,#4L(&YO="`P-2X*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@($1O(&YO="!A9&0@;&5A
M9&EN9R`P)W,@9F]R('EE87)S('!R:6]R('1O(#$P,#`N"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I;VX@:7-,96%P
M665A<B@D>65A<B`](#`I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1Y96%R
M*2D@>PH@("`@("`@("`@("`D>65A<B`]($1A=&5?0V%L8SHZ9&%T94YO=R@G
M)5DG*3L*("`@("`@("!]"B`@("`@("`@:68@*'!R96=?;6%T8V@H)R]<1"\G
M+"`D>65A<BDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T*("`@("`@("!I9B`H)'EE87(@/"`Q,#`P*2!["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@:68@*"1Y96%R(#P@,34X
M,BD@>PH@("`@("`@("`@("`O+R!P<F4@1W)E9V]R:6\@6$E)22`M(#$U.#(*
M("`@("`@("`@("`@<F5T=7)N("@D>65A<B`E(#0@/3T@,"D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@+R\@<&]S="!'<F5G;W)I;R!824E)("T@
M,34X,@H@("`@("`@("`@("!R971U<FX@*"@D>65A<B`E(#0@/3T@,"D@)B8@
M*"1Y96%R("4@,3`P("$](#`I*2!\?"`H)'EE87(@)2`T,#`@/3T@,"D["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE<R!I9B!G
M:79E;B!D871E(&ES(&$@9G5T=7)E(&1A=&4@9G)O;2!N;W<*("`@("`J"B`@
M("`@*B!`<&%R86T@:6YT("`@("1D87D@("`@('1H92!D87D@;V8@=&AE(&UO
M;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1M;VYT:"`@('1H92!M;VYT:`H@
M("`@("H@0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<BX@(%5S92!T
M:&4@8V]M<&QE=&4@>65A<B!I;G-T96%D(&]F('1H90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@86)B<F5V:6%T960@=F5R<VEO;BX@($4N9RX@
M=7-E(#(P,#4L(&YO="`P-2X*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@($1O(&YO="!A9&0@;&5A9&EN9R`P)W,@9F]R('EE87)S('!R:6]R('1O
M(#$P,#`N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@:7-&=71U<F5$871E*"1D87DL("1M;VYT:"P@)'EE87(I
M"B`@("!["B`@("`@("`@)'1H:7-?>65A<B`@/2!$871E7T-A;&,Z.F1A=&5.
M;W<H)R59)RD["B`@("`@("`@)'1H:7-?;6]N=&@@/2!$871E7T-A;&,Z.F1A
M=&5.;W<H)R5M)RD["B`@("`@("`@)'1H:7-?9&%Y("`@/2!$871E7T-A;&,Z
M.F1A=&5.;W<H)R5D)RD["@H@("`@("`@(&EF("@D>65A<B`^("1T:&ES7WEE
M87(I('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E
M:68@*"1Y96%R(#T]("1T:&ES7WEE87(I('L*("`@("`@("`@("`@:68@*"1M
M;VYT:"`^("1T:&ES7VUO;G1H*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M=')U93L*("`@("`@("`@("`@?2!E;'-E:68@*"1M;VYT:"`]/2`D=&AI<U]M
M;VYT:"D@>PH@("`@("`@("`@("`@("`@:68@*"1D87D@/B`D=&AI<U]D87DI
M('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U
M<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S(&EF
M(&=I=F5N(&1A=&4@:7,@82!P87-T(&1A=&4@9G)O;2!N;W<*("`@("`J"B`@
M("`@*B!`<&%R86T@:6YT("`@("1D87D@("`@('1H92!D87D@;V8@=&AE(&UO
M;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1M;VYT:"`@('1H92!M;VYT:`H@
M("`@("H@0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<BX@(%5S92!T
M:&4@8V]M<&QE=&4@>65A<B!I;G-T96%D(&]F('1H90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@86)B<F5V:6%T960@=F5R<VEO;BX@($4N9RX@
M=7-E(#(P,#4L(&YO="`P-2X*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@($1O(&YO="!A9&0@;&5A9&EN9R`P)W,@9F]R('EE87)S('!R:6]R('1O
M(#$P,#`N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@:7-087-T1&%T92@D9&%Y+"`D;6]N=&@L("1Y96%R*0H@
M("`@>PH@("`@("`@("1T:&ES7WEE87(@(#T@1&%T95]#86QC.CID871E3F]W
M*"<E62<I.PH@("`@("`@("1T:&ES7VUO;G1H(#T@1&%T95]#86QC.CID871E
M3F]W*"<E;2<I.PH@("`@("`@("1T:&ES7V1A>2`@(#T@1&%T95]#86QC.CID
M871E3F]W*"<E9"<I.PH*("`@("`@("!I9B`H)'EE87(@/"`D=&AI<U]Y96%R
M*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS96EF
M("@D>65A<B`]/2`D=&AI<U]Y96%R*2!["B`@("`@("`@("`@(&EF("@D;6]N
M=&@@/"`D=&AI<U]M;VYT:"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N('1R
M=64["B`@("`@("`@("`@('T@96QS96EF("@D;6]N=&@@/3T@)'1H:7-?;6]N
M=&@I('L*("`@("`@("`@("`@("`@(&EF("@D9&%Y(#P@)'1H:7-?9&%Y*2![
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!N=6UB97(@
M;V8@9&%Y<R!B971W965N('1W;R!G:79E;B!D871E<PH@("`@("H*("`@("`J
M($!P87)A;2!I;G0@("`@)&1A>3$@("`@=&AE(&1A>2!O9B!T:&4@;6]N=&@*
M("`@("`J($!P87)A;2!I;G0@("`@)&UO;G1H,2`@=&AE(&UO;G1H"B`@("`@
M*B!`<&%R86T@:6YT("`@("1Y96%R,2`@('1H92!Y96%R+B`@57-E('1H92!C
M;VUP;&5T92!Y96%R(&EN<W1E860@;V8@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("!A8F)R979I871E9"!V97)S:6]N+B`@12YG+B!U<V4@
M,C`P-2P@;F]T(#`U+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M1&\@;F]T(&%D9"!L96%D:6YG(#`G<R!F;W(@>65A<G,@<')I;W(@=&\@,3`P
M,"X*("`@("`J($!P87)A;2!I;G0@("`@)&1A>3(@("`@=&AE(&1A>2!O9B!T
M:&4@;6]N=&@*("`@("`J($!P87)A;2!I;G0@("`@)&UO;G1H,B`@=&AE(&UO
M;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R,B`@('1H92!Y96%R+B`@
M57-E('1H92!C;VUP;&5T92!Y96%R(&EN<W1E860@;V8@=&AE"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!A8F)R979I871E9"!V97)S:6]N+B`@
M12YG+B!U<V4@,C`P-2P@;F]T(#`U+@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@1&\@;F]T(&%D9"!L96%D:6YG(#`G<R!F;W(@>65A<G,@<')I
M;W(@=&\@,3`P,"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&%B
M<V]L=71E(&YU;6)E<B!O9B!D87ES(&)E='=E96X@=&AE('1W;R!D871E<RX*
M("`@("`J("`@("`@("`@("`@("`@268@86X@97)R;W(@;V-C=7)S+"`M,2!I
M<R!R971U<FYE9"X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!D871E1&EF9B@D9&%Y
M,2P@)&UO;G1H,2P@)'EE87(Q+"`D9&%Y,BP@)&UO;G1H,BP@)'EE87(R*0H@
M("`@>PH@("`@("`@(&EF("@A1&%T95]#86QC.CII<U9A;&ED1&%T92@D9&%Y
M,2P@)&UO;G1H,2P@)'EE87(Q*2D@>PH@("`@("`@("`@("!R971U<FX@+3$[
M"B`@("`@("`@?0H@("`@("`@(&EF("@A1&%T95]#86QC.CII<U9A;&ED1&%T
M92@D9&%Y,BP@)&UO;G1H,BP@)'EE87(R*2D@>PH@("`@("`@("`@("!R971U
M<FX@+3$["B`@("`@("`@?0H@("`@("`@(')E='5R;B!A8G,H1&%T95]#86QC
M.CID871E5&]$87ES*"1D87DQ+"`D;6]N=&@Q+"`D>65A<C$I"B`@("`@("`@
M("`@("`@("`@("`M($1A=&5?0V%L8SHZ9&%T951O1&%Y<R@D9&%Y,BP@)&UO
M;G1H,BP@)'EE87(R*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VUP87)E
M<R!T=V\@9&%T97,*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("`@("1D87DQ
M("`@('1H92!D87D@;V8@=&AE(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT("`@
M("1M;VYT:#$@('1H92!M;VYT:`H@("`@("H@0'!A<F%M(&EN="`@("`D>65A
M<C$@("!T:&4@>65A<BX@(%5S92!T:&4@8V]M<&QE=&4@>65A<B!I;G-T96%D
M(&]F('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@86)B<F5V
M:6%T960@=F5R<VEO;BX@($4N9RX@=7-E(#(P,#4L(&YO="`P-2X*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@($1O(&YO="!A9&0@;&5A9&EN9R`P
M)W,@9F]R('EE87)S('!R:6]R('1O(#$P,#`N"B`@("`@*B!`<&%R86T@:6YT
M("`@("1D87DR("`@('1H92!D87D@;V8@=&AE(&UO;G1H"B`@("`@*B!`<&%R
M86T@:6YT("`@("1M;VYT:#(@('1H92!M;VYT:`H@("`@("H@0'!A<F%M(&EN
M="`@("`D>65A<C(@("!T:&4@>65A<BX@(%5S92!T:&4@8V]M<&QE=&4@>65A
M<B!I;G-T96%D(&]F('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@86)B<F5V:6%T960@=F5R<VEO;BX@($4N9RX@=7-E(#(P,#4L(&YO="`P
M-2X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@($1O(&YO="!A9&0@
M;&5A9&EN9R`P)W,@9F]R('EE87)S('!R:6]R('1O(#$P,#`N"B`@("`@*@H@
M("`@("H@0')E='5R;B!I;G0@(#`@:68@=&AE(&1A=&5S(&%R92!E<75A;"X@
M,2!I9B!D871E(#$@:7,@;&%T97(L("TQ(&EF"B`@("`@*B`@("`@("`@("`@
M("`@(&1A=&4@,2!I<R!E87)L:65R+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O
M;7!A<F5$871E<R@D9&%Y,2P@)&UO;G1H,2P@)'EE87(Q+"`D9&%Y,BP@)&UO
M;G1H,BP@)'EE87(R*0H@("`@>PH@("`@("`@("1N9&%Y<S$@/2!$871E7T-A
M;&,Z.F1A=&54;T1A>7,H)&1A>3$L("1M;VYT:#$L("1Y96%R,2D["B`@("`@
M("`@)&YD87ES,B`]($1A=&5?0V%L8SHZ9&%T951O1&%Y<R@D9&%Y,BP@)&UO
M;G1H,BP@)'EE87(R*3L*("`@("`@("!I9B`H)&YD87ES,2`]/2`D;F1A>7,R
M*2!["B`@("`@("`@("`@(')E='5R;B`P.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@*"1N9&%Y<S$@/B`D;F1A>7,R*2`_(#$@.B`M,3L*("`@('T*?0H*
M/SX*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+U!(4%5N:70`````````````````````````````
M````````````````````````````````````````````````````````,#`P
M-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S$@
M,#$W-C<T`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$A056YI="]'54D`
M````````````````````````````````````````````````````````````
M```````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,#`P,"`Q,#4Q-30S,S<S,2`P,C`S,C``(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]02%!5;FET+T=522](5$U,+G!H<```````````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#(Q,C$W(#$P-3$U-#,S-S,Q(#`R,38U-P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S
M;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J(%!(4"!697)S:6]N(#0*("H*("H@
M0V]P>7)I9VAT("AC*2`R,#`R+3(P,#4L(%-E8F%S=&EA;B!"97)G;6%N;B`\
M<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/BX*("H@06QL(')I9VAT<R!R97-E
M<G9E9"X*("H*("H@4F5D:7-T<FEB=71I;VX@86YD('5S92!I;B!S;W5R8V4@
M86YD(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T"B`J(&UO9&EF:6-A
M=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F;VQL;W=I
M;F<@8V]N9&ET:6]N<PH@*B!A<F4@;65T.@H@*@H@*B`@("H@4F5D:7-T<FEB
M=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C
M;W!Y<FEG:'0*("H@("`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO
M;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX*("H@"B`J("`@*B!2
M961I<W1R:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@
M=&AE(&%B;W9E(&-O<'ER:6=H=`H@*B`@("`@;F]T:6-E+"!T:&ES(&QI<W0@
M;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN
M"B`J("`@("!T:&4@9&]C=6UE;G1A=&EO;B!A;F0O;W(@;W1H97(@;6%T97)I
M86QS('!R;W9I9&5D('=I=&@@=&AE"B`J("`@("!D:7-T<FEB=71I;VXN"B`J
M"B`J("`@*B!.96ET:&5R('1H92!N86UE(&]F(%-E8F%S=&EA;B!"97)G;6%N
M;B!N;W(@=&AE(&YA;65S(&]F(&AI<PH@*B`@("`@8V]N=')I8G5T;W)S(&UA
M>2!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92!P<F]D=6-T<R!D97)I
M=F5D"B`J("`@("!F<F]M('1H:7,@<V]F='=A<F4@=VET:&]U="!S<&5C:69I
M8R!P<FEO<B!W<FET=&5N('!E<FUI<W-I;VXN"B`J"B`J(%1(25,@4T]&5%=!
M4D4@25,@4%)/5DE$140@0ED@5$A%($-/4%E224=(5"!(3TQ$15)3($%.1"!#
M3TY44DE"551/4E,*("H@(D%3($E3(B!!3D0@04Y9($584%)%4U,@3U(@24U0
M3$E%1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.3U0*("H@3$E-251%
M1"!43RP@5$A%($E-4$Q)140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)
M5%D@04Y$($9)5$Y%4U,*("H@1D]2($$@4$%25$E#54Q!4B!055)03U-%($%2
M12!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4*("H@0T]065))
M1TA4($]73D52($]2($-/3E1224)55$]24R!"12!,24%"3$4@1D]2($%.62!$
M25)%0U0L($E.1$E214-4+`H@*B!)3D-)1$5.5$%,+"!34$5#24%,+"!%6$5-
M4$Q!4EDL($]2($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'+`H@
M*B!"550@3D]4($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&(%-50E-42515
M5$4@1T]/1%,@3U(@4T525DE#15,["B`J($Q/4U,@3T8@55-%+"!$051!+"!/
M4B!04D]&2513.R!/4B!"55-)3D534R!)3E1%4E)54%1)3TXI($A/5T5615(*
M("H@0T%54T5$($%.1"!/3B!!3ED@5$A%3U)9($]&($Q)04))3$E462P@5TA%
M5$A%4B!)3B!#3TY44D%#5"P@4U1224,*("H@3$E!0DE,2519+"!/4B!43U)4
M("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I($%225-)3D<@
M24X*("H@04Y9(%=!62!/550@3T8@5$A%(%5312!/1B!42$E3(%-/1E1705)%
M+"!%5D5.($E&($%$5DE3140@3T8@5$A%"B`J(%!/4U-)0DE,2519($]&(%-5
M0T@@1$%-04=%+@H@*@H@*B!`8V%T96=O<GD@("!497-T:6YG"B`J($!P86-K
M86=E("`@(%!(4%5N:70*("H@0&%U=&AO<B`@("`@5V]L9G)A;2!+<FEE<VEN
M9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*("H@0&-O<'ER:6=H="`@,C`P,BTR
M,#`U(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN
M+F1E/@H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G
M+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E
M<G-I;VX@("`@0U93.B`D260Z($A434PN<&AP+'8@,2XQ.2`R,#`U+S$Q+S$P
M(#`Y.C0W.C$U('-E8F%S=&EA;B!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P
M.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$A056YI=`H@*B!`<VEN8V4@("`@
M("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N,"XP"B`J+PH*+RHJ
M"B`J($A434P@1U5)+@H@*@H@*B!`8V%T96=O<GD@("!497-T:6YG"B`J($!P
M86-K86=E("`@(%!(4%5N:70*("H@0&%U=&AO<B`@("`@5V]L9G)A;2!+<FEE
M<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*("H@0&-O<'ER:6=H="`@,C`P
M,BTR,#`U(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M
M86YN+F1E/@H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N
M;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@
M0'9E<G-I;VX@("`@4F5L96%S93H@,2XS+C(*("H@0&QI;FL@("`@("`@:'1T
M<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!(4%5N:70*("H@0'-I;F-E("`@
M("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XP+C`*("HO"F-L
M87-S(%!(4%5N:71?1U5)7TA434P*>PH@("`@=F%R("1?<W5I=&5S(#T@87)R
M87DH*3L*"B`@("`O*BH*("`@("H@=&AE(&-U<G)E;G0@:6UP;&5M96YT871I
M;VX@;V8@4$A056YI="!I<R!D97-I9VYE9`H@("`@*B!T:&ES('=A>2!T:&%T
M(&%D9&EN9R!A('-U:71E('1O(&%N;W1H97(@<W5I=&4@;VYL>0H@("`@*B!G
M<F%B<R!A;&P@=&AE('1E<W1S(&%N9"!A9&1S('1H96T@=&\@=&AE('-U:71E
M+"!S;R!Y;W4*("`@("H@:&%V92!N;R!C:&%N8V4@=&\@9FEN9"!O=70@=VAI
M8V@@=&5S="!G;V5S('=I=&@@=VAI8V@@<W5I=&4*("`@("H@=&AE<F5F;W)E
M('EO=2!C86X@<VEM<&QY('!A<W,@86X@87)R87D@;V8@<W5I=&5S('1O('1H
M:7,@8V]N<W1R=6-T;W(@:&5R90H@("`@*@H@("`@*B!`<&%R86T@(&%R<F%Y
M("`@5&AE('-U:71E<R!T;R!B92!T97-T960N($EF(&YO="!G:79E;BP@=&AE
M;B!Y;W4@;6EG:'0*("`@("H@("`@("`@("`@("`@("`@(&)E('5S:6YG('1H
M92!3971U<$1E8V]R871O<BP@=VAI8V@@9&5T96-T<R!T:&5M(&%U=&]M871I
M8V%L;'D*("`@("H@("`@("`@("`@("`@("`@('=H96X@8V%L;&EN9R!G9713
M=6ET97-&<F]M1&ER*"D*("`@("HO"B`@("!F=6YC=&EO;B!02%!5;FET7T=5
M25](5$U,*"1S=6ET97,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("@A
M:7-?87)R87DH)'-U:71E<RDI('L*("`@("`@("`@("`@)'1H:7,M/E]S=6ET
M97,@/2!A<G)A>2@D<W5I=&5S*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D=&AI<RT^7W-U:71E<R`]("1S=6ET97,["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@*B!!9&0@<W5I=&5S('1O('1H92!'54D*("`@("H*
M("`@("H@0'!A<F%M("!O8FIE8W0@('1H:7,@<VAO=6QD(&)E(&%N(&EN<W1A
M;F-E(&]F(%!(4%5N:71?5&5S=%-U:71E"B`@("`J+PH@("`@9G5N8W1I;VX@
M861D4W5I=&5S*"1S=6ET97,I"B`@("!["B`@("`@("`@)'1H:7,M/E]S=6ET
M97,@/2!A<G)A>5]M97)G92@D=&AI<RT^7W-U:71E<RPD<W5I=&5S*3L*("`@
M('T*"B`@("`O*BH*("`@("H@=&AI<R!P<FEN=',@=&AE($A434P@8V]D92!S
M=')A:6=H="!O=70*("`@("H*("`@("HO"B`@("!F=6YC=&EO;B!S:&]W*"D*
M("`@('L*("`@("`@("`D<F5Q=65S="`@("`]("1?4D5154535#L*("`@("`@
M("`D<VAO=U!A<W-E9"`]($9!3%-%.PH@("`@("`@("1S=6)M:71T960@(#T@
M0"1R97%U97-T6R=S=6)M:71T960G73L*"B`@("`@("`@:68@*"1S=6)M:71T
M960I('L*("`@("`@("`@("`@)'-H;W=087-S960@/2!`)')E<75E<W1;)W-H
M;W=/2R==(#\@5%)512`Z($9!3%-%.PH@("`@("`@('T*"B`@("`@("`@)'-U
M:71E4F5S=6QT<R`](&%R<F%Y*"D["@H@("`@("`@(&9O<F5A8V@@*"1T:&ES
M+3Y?<W5I=&5S(&%S("1A4W5I=&4I('L*("`@("`@("`@("`@)&%3=6ET95)E
M<W5L="`](&%R<F%Y*"D["@H@("`@("`@("`@("`O+R!R96UO=F4@=&AE(&9I
M<G-T(&1I<F5C=&]R>2=S(&YA;64@9G)O;2!T:&4@=&5S="US=6ET92!N86UE
M+"!S:6YC92!I=`H@("`@("`@("`@("`O+R!M;W-T;'D@:7,@<V]M971H:6YG
M(&QI:V4@)W1E<W1S)R!O<B!A;&EK90H@("`@("`@("`@("`D<F5M;W9A8FQE
M4')E9FEX(#T@97AP;&]D92@G7R<L)&%3=6ET92T^9V5T3F%M92@I*3L*("`@
M("`@("`@("`@)&%3=6ET95)E<W5L=%LG;F%M92==(#T@<W1R7W)E<&QA8V4H
M)')E;6]V86)L95!R969I>%LP72XG7R<L("<G+"`D85-U:71E+3YG971.86UE
M*"DI.PH*("`@("`@("`@("`@:68@*"1S=6)M:71T960@)B8@:7-S970H)')E
M<75E<W1;)&%3=6ET95)E<W5L=%LG;F%M92==72DI('L*("`@("`@("`@("`@
M("`@("1R97-U;'0@/2!02%!5;FET.CIR=6XH)&%3=6ET92D["@H@("`@("`@
M("`@("`@("`@)&%3=6ET95)E<W5L=%LG8V]U;G1S)UU;)W)U;B==(#T@)')E
M<W5L="T^<G5N0V]U;G0H*3L*("`@("`@("`@("`@("`@("1A4W5I=&5297-U
M;'1;)V-O=6YT<R==6R=E<G)O<B==(#T@)')E<W5L="T^97)R;W)#;W5N="@I
M.PH@("`@("`@("`@("`@("`@)&%3=6ET95)E<W5L=%LG8V]U;G1S)UU;)V9A
M:6QU<F4G72`]("1R97-U;'0M/F9A:6QU<F5#;W5N="@I.PH*("`@("`@("`@
M("`@("`@("1A4W5I=&5297-U;'1;)W)E<W5L=',G72`]("1T:&ES+3Y?<')E
M<&%R95)E<W5L="@D<F5S=6QT+"1S:&]W4&%S<V5D*3L*"B`@("`@("`@("`@
M("`@("`D<&5R(#T@,3`P+R1R97-U;'0M/G)U;D-O=6YT*"D["B`@("`@("`@
M("`@("`@("`D9F%I;&5D(#T@*"1P97(J)')E<W5L="T^97)R;W)#;W5N="@I
M*2LH)'!E<BHD<F5S=6QT+3YF86EL=7)E0V]U;G0H*2D["B`@("`@("`@("`@
M("`@("`D85-U:71E4F5S=6QT6R=P97)C96YT)UT@/2!R;W5N9"@Q,#`M)&9A
M:6QE9"PR*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1A4W5I=&5297-U;'1;)V%D9$EN9F\G72`]("=.3U0@15A%0U54140G.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`D<W5I=&5297-U;'1S6UT@/2`D
M85-U:71E4F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@)&9I;F%L6R=N86UE
M)UT@/2`G3U9%4D%,3"!215-53%0G.PH@("`@("`@("1F:6YA;%LG8V]U;G1S
M)UT@/2!A<G)A>2@I.PH@("`@("`@("1F:6YA;%LG<&5R8V5N="==(#T@,#L*
M("`@("`@("`D;G5M17AE8W5T961497-T<R`](#`["@H@("`@("`@(&9O<F5A
M8V@@*"1S=6ET95)E<W5L=',@87,@)&%3=6ET95)E<W5L="D@>PH@("`@("`@
M("`@("!I9B`H<VEZ96]F*$`D85-U:71E4F5S=6QT6R=C;W5N=',G72DI('L*
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1A4W5I=&5297-U;'1;)V-O=6YT
M<R==(&%S("1K97D]/B1A0V]U;G0I('L*("`@("`@("`@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1F:6YA;%LG8V]U;G1S)UU;)&ME>5TI*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1F:6YA;%LG8V]U;G1S)UU;)&ME>5T@/2`P.PH@
M("`@("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@)&9I
M;F%L6R=C;W5N=',G75LD:V5Y72`K/2`D84-O=6YT.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S
M970H)&9I;F%L6R=C;W5N=',G75LG<G5N)UTI*2!["B`@("`@("`@("`@("1P
M97(@/2`Q,#`O)&9I;F%L6R=C;W5N=',G75LG<G5N)UT["B`@("`@("`@("`@
M("1F86EL960@/2`H)'!E<BHD9FEN86Q;)V-O=6YT<R==6R=E<G)O<B==*2LH
M)'!E<BHD9FEN86Q;)V-O=6YT<R==6R=F86EL=7)E)UTI.PH@("`@("`@("`@
M("`D9FEN86Q;)W!E<F-E;G0G72`](')O=6YD*#$P,"TD9F%I;&5D+#(I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1F:6YA;%LG<&5R8V5N="==
M(#T@,#L*("`@("`@("!]"@H@("`@("`@(&%R<F%Y7W5N<VAI9G0H)'-U:71E
M4F5S=6QT<RPD9FEN86PI.PH*("`@("`@("!I;F-L=61E("=02%!5;FET+T=5
M22](5$U,+G1P;"<["B`@("!]"@H@("`@9G5N8W1I;VX@7W!R97!A<F5297-U
M;'0H)')E<W5L="PD<VAO=U!A<W-E9"D*("`@('L*("`@("`@("`D<F5T(#T@
M87)R87DH*3L*("`@("`@("`D9F%I;'5R97,@/2`D<F5S=6QT+3YF86EL=7)E
M<R@I.PH*("`@("`@("!F;W)E86-H*"1F86EL=7)E<R!A<R`D849A:6QU<F4I
M('L*("`@("`@("`@("`@)')E=%LG9F%I;'5R97,G75M=(#T@)'1H:7,M/E]P
M<F5P87)E1F%I;'5R92@D849A:6QU<F4I.PH@("`@("`@('T*"B`@("`@("`@
M)&5R<F]R<R`]("1R97-U;'0M/F5R<F]R<R@I.PH*("`@("`@("!F;W)E86-H
M*"1E<G)O<G,@87,@)&%%<G)O<BD@>PH@("`@("`@("`@("`D<F5T6R=E<G)O
M<G,G75M=(#T@)'1H:7,M/E]P<F5P87)E17)R;W)S*"1A17)R;W(I.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"1S:&]W4&%S<V5D*2!["B`@("`@("`@("`@
M("1P87-S960@/2`D<F5S=6QT+3YP87-S961497-T<R@I.PH*("`@("`@("`@
M("`@9F]R96%C:"@D<&%S<V5D(&%S("1A4&%S<V5D*2!["B`@("`@("`@("`@
M("`@("`D<F5T6R=P87-S960G75M=(#T@)'1H:7,M/E]P<F5P87)E4&%S<V5D
M5&5S=',H)&%087-S960I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)')E=#L*("`@('T*"B`@("!F=6YC=&EO;B!?<')E<&%R
M949A:6QU<F4H)&9A:6QU<F4I"B`@("!["B`@("`@("`@)'1E<W0@/2`D9F%I
M;'5R92T^9F%I;&5D5&5S="@I.PH@("`@("`@("1R971;)W1E<W1.86UE)UT@
M/2`D=&5S="T^9V5T3F%M92@I.PH@("`@("`@("1E>&-E<'1I;VX@/2`D9F%I
M;'5R92T^=&AR;W=N17AC97!T:6]N*"D["@H@("`@("`@("\O(&$@<V5R:6%L
M:7IE9"!S=')I;F<@<W1A<G1S('=I=&@@82`G8VAA<F%C=&5R.F1E8VEM86PZ
M>R<*("`@("`@("`O+R!I9B!S;R!W92!T<GD@=&\@=6YS97)I86QI>F4@:70*
M("`@("`@("`O+R!T:&ES('!I96-E(&]F('1H92!R96=U;&%R(&5X<')E<W-I
M;VX@:7,@9F]R(&1E=&5C=&EN9R!A('-E<FEA;&EZ960*("`@("`@("`O+R!T
M>7!E(&QI:V4@)V$Z,SHG(&9O<B!A;B!A<G)A>2!W:71H('1H<F5E(&5L96UE
M;G0@;W(@86X@;V)J96-T(&DN92X@)T\Z,3(Z(F-L87-S(CHS)PH@("`@("`@
M("1S97)I86QI>F5D(#T@)RA<=SI<9"LZ*#\Z(EM>(ETK(CI<9"LZ*3]<>RXJ
M7'TI)SL*"B`@("`@("`@+R\@4W!A8V5S(&UI9VAT(&UA:V4@82!D:69F+"!S
M;R!W92!S:&%L;"!S:&]W('1H96T@<')O<&5R;'D@*'-I;F-E(&$*("`@("`@
M("`O+R!U<V5R(&%G96YT(&EG;F]R97,@=&AE;2DN"B`@("`@("`@:68@*'!R
M96=?;6%T8V@H)R]>*"XJ*65X<&5C=&5D("<@+B`D<V5R:6%L:7IE9"`N("<L
M(&%C='5A;"`G("X@)'-E<FEA;&EZ960@+B`G)"]S52<L("1E>&-E<'1I;VXL
M("1M871C:&5S*2D@>PH@("`@("`@("`@("!O8E]S=&%R="@I.PH@("`@("`@
M("`@("!P<FEN=%]R*'5N<V5R:6%L:7IE*"1M871C:&5S6S)=*2D["B`@("`@
M("`@("`@("1R971;)V5X<&5C=&5D)UT@/2!H=&UL<W!E8VEA;&-H87)S*"1M
M871C:&5S6S%=*2`N("(\<')E/B(@+B!H=&UL<W!E8VEA;&-H87)S*')T<FEM
M*&]B7V=E=%]C;VYT96YT<R@I*2D@+B`B/"]P<F4^(CL*("`@("`@("`@("`@
M+R\@26UP<F]V960@8V]M<&%T:6)I;&ET>2P@;V)?8VQE86XH*2!W;W5L9"!B
M92!02%`@/CT@-"XR+C`@;VYL>2X*("`@("`@("`@("`@;V)?96YD7V-L96%N
M*"D["@H@("`@("`@("`@("!O8E]S=&%R="@I.PH@("`@("`@("`@("!P<FEN
M=%]R*'5N<V5R:6%L:7IE*"1M871C:&5S6S-=*2D["B`@("`@("`@("`@("1R
M971;)V%C='5A;"==(#T@:'1M;'-P96-I86QC:&%R<R@D;6%T8VAE<ULQ72D@
M+B`B/'!R93XB("X@:'1M;'-P96-I86QC:&%R<RAR=')I;2AO8E]G971?8V]N
M=&5N=',H*2DI("X@(CPO<')E/B(["B`@("`@("`@("`@(&]B7V5N9%]C;&5A
M;B@I.PH@("`@("`@('T*"B`@("`@("`@96QS92!I9B`H<')E9U]M871C:"@G
M+UXH+BHI97AP96-T960@*"XJ*2P@86-T=6%L("@N*BDD+W-5)RP@)&5X8V5P
M=&EO;BP@)&UA=&-H97,I*2!["B`@("`@("`@("`@("1R971;)V5X<&5C=&5D
M)UT@/2!N;#)B<BAS=')?<F5P;&%C92@B("(L("(F;F)S<#LB+"!H=&UL<W!E
M8VEA;&-H87)S*"1M871C:&5S6S%=("X@)&UA=&-H97-;,ETI*2D["B`@("`@
M("`@("`@("1R971;)V%C='5A;"==(#T@;FPR8G(H<W1R7W)E<&QA8V4H(B`B
M+"`B)FYB<W`[(BP@:'1M;'-P96-I86QC:&%R<R@D;6%T8VAE<ULQ72`N("1M
M871C:&5S6S-=*2DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R
M971;)VUE<W-A9V4G72`](&YL,F)R*'-T<E]R97!L86-E*"(@(BP@(B9N8G-P
M.R(L(&AT;6QS<&5C:6%L8VAA<G,H)&5X8V5P=&EO;BDI*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D<F5T.PH@("`@?0H*("`@(&9U;F-T:6]N(%]P
M<F5P87)E4&%S<V5D5&5S=',H)'!A<W-E9"D*("`@('L*("`@("`@("`D<F5T
M6R=T97-T3F%M92==(#T@)'!A<W-E9"T^9V5T3F%M92@I.PH@("`@("`@(')E
M='5R;B`D<F5T.PH@("`@?0H*("`@(&9U;F-T:6]N(%]P<F5P87)E17)R;W(H
M)&5R<F]R*0H@("`@>PH@("`@("`@("1R971;)W1E<W1.86UE)UT@/2`D97)R
M;W(M/F=E=$YA;64H*3L*("`@("`@("`D<F5T6R=M97-S86=E)UT@/2`D97)R
M;W(M/G1O4W1R:6YG*"D["B`@("`@("`@<F5T=7)N("1R970["B`@("!]"GT*
M"B\J"B`J($QO8V%L('9A<FEA8FQE<SH*("H@=&%B+7=I9'1H.B`T"B`J(&,M
M8F%S:6,M;V9F<V5T.B`T"B`J(&,M:&%N9VEN9RUC;VUM96YT+65N9&5R+7`Z
M(&YI;`H@*B!%;F0Z"B`J+PH_/@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+U!(4%5N:70O1U5)+TA434PN='!L````````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,34P,C,@,3`U,34T,S,W,S$@,#(Q
M-C8U`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#QH=&UL/@H@("`@/&AE860^"B`@("`@("`@/%-464Q%('1Y<&4](G1E>'0O
M8W-S(CX*"B`@("`@("`@("`@(&)O9'DL('1D('L*("`@("`@("`@("`@("`@
M(&)A8VMG<F]U;F0M8V]L;W(Z(&QI9VAT9W)E>3L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@=&%B;&4N;W5T;&EN92P@;W5T;&EN949A:6QU<F4@>PH@
M("`@("`@("`@("`@("`@8F%C:V=R;W5N9"UC;VQO<CH@8FQA8VL["B`@("`@
M("`@("`@("`@("!B;W)D97(M=VED=&@Z(#%P>#L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@=&0@>PH@("`@("`@("`@("`@("`@<&%D9&EN9SH@,G!X
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!T:"!["B`@("`@("`@("`@
M("`@("!T97AT+6%L:6=N.B!L969T.PH@("`@("`@("`@("`@("`@8V]L;W(Z
M('=H:71E.PH@("`@("`@("`@("`@("`@8F%C:V=R;W5N9"UC;VQO<CH@8FQA
M8VL["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("YS=6-C97-S('L*("`@
M("`@("`@("`@("`@(&)A8VMG<F]U;F0M8V]L;W(Z(&QI9VAT9W)E96X["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("YF86EL=7)E('L*("`@("`@("`@
M("`@("`@(&)A8VMG<F]U;F0M8V]L;W(Z(&]R86YG93L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`N:6YF;R!["B`@("`@("`@("`@("`@("!P861D:6YG
M.B`R<'@["B`@("`@("`@("`@("`@("!C;VQO<CH@;W)A;F=E.PH@("`@("`@
M("`@("!]"@H@("`@("`@(#PO4U193$4^"B`@("`\+VAE860^"B`@("`\8F]D
M>3X*("`@("`@("`\9F]R;2!A8W1I;VX](CP_<&AP(&5C:&\@)%]315)615);
M)U!(4%]314Q&)UT@/SXB(&UE=&AO9#TB<&]S="(@;F%M93TB;W!T:6]N<T9O
M<FTB/@H@("`@("`@("`@("`\=&%B;&4@86QI9VX](F-E;G1E<B(@8VQA<W,]
M(F]U=&QI;F4B('=I9'1H/2(W,"4B/@H@("`@("`@("`@("`@("`@/'1R/@H@
M("`@("`@("`@("`@("`@("`@(#QT:"!C;VQS<&%N/2(Q,"(^"B`@("`@("`@
M("`@("`@("`@("`@("`@($]P=&EO;G,*("`@("`@("`@("`@("`@("`@("`\
M+W1H/@H@("`@("`@("`@("`@("`@/"]T<CX*("`@("`@("`@("`@("`@(#QT
M<CX*("`@("`@("`@("`@("`@("`@("`\=&0@8V]L<W!A;CTB,3`B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\:6YP=70@='EP93TB8VAE8VMB;W@B(&]N
M0VQI8VL](G5N0VAE8VM!;&PH*2(@;F%M93TB86QL0VAE8VME9"(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("AU;BEC:&5C:R!A;&P*("`@("`@("`@("`@
M("`@("`@("`@("`@)FYB<W`[("9N8G-P.PH@("`@("`@("`@("`@("`@("`@
M("`@("!S:&]W($]+(#QI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB<VAO
M=T]+(B`\/W!H<"!E8VAO($`D<F5Q=65S=%LG<VAO=T]+)UT_)V-H96-K960G
M.B<G/SX^"B`@("`@("`@("`@("`@("`@("`@("`@("9N8G-P.R`F;F)S<#L*
M("`@("`@("`@("`@("`@("`@("`@("`@/&EN<'5T('1Y<&4](G-U8FUI="(@
M;F%M93TB<W5B;6ET=&5D(B!V86QU93TB<G5N('1E<W1S(CX*("`@("`@("`@
M("`@("`@("`@("`\+W1D/@H@("`@("`@("`@("`@("`@/"]T<CX*"B`@("`@
M("`@("`@("`@("`\/W!H<"!F;W)E86-H*"1S=6ET95)E<W5L=',@87,@)&%2
M97-U;'0I.B`_/@H@("`@("`@("`@("`@("`@("`@(#QT<CX*("`@("`@("`@
M("`@("`@("`@("`@("`@/'1H(&-O;'-P86X](C$P(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB
M/#]P:'`@96-H;R`D85)E<W5L=%LG;F%M92==(#\^(B`\/W!H<"!E8VAO($`D
M<F5Q=65S=%LD85)E<W5L=%LG;F%M92==73\G8VAE8VME9"<Z)R<@/SX^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\/W!H<"!E8VAO("1A4F5S=6QT
M6R=N86UE)UT@/SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("9N8G-P
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@/#]P:'`@:68@*&ES<V5T
M*"1A4F5S=6QT6R=A9&1);F9O)UTI*3H@/SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\9F]N="!C;&%S<STB:6YF;R(^/#]P:'`@96-H;R!`
M)&%297-U;'1;)V%D9$EN9F\G72`_/CPO9F]N=#X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#P_<&AP(&5N9&EF(#\^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#PO=&@^"B`@("`@("`@("`@("`@("`@("`@/"]T<CX*"B`@("`@
M("`@("`@("`@("`@("`@/#]P:'`@:68H0"1A4F5S=6QT6R=P97)C96YT)UTI
M.B`_/@H@("`@("`@("`@("`@("`@("`@("`@("`\='(^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\=&0@8V]L<W!A;CTB,3`B(&YO=W)A<#TB;F]W
M<F%P(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\=&%B;&4@
M<W1Y;&4](G=I9'1H.C$P,"4[('!A9&1I;F<Z,G!X.R(@8V5L;'-P86-I;F<]
M(C`B(&-E;&QS<&%N/2(P(B!C96QL<&%D9&EN9STB,"(^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QT<CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QT9"!W:61T:#TB/#]P:'`@96-H
M;R`D85)E<W5L=%LG<&5R8V5N="==(#\^)2(@8VQA<W,](G-U8V-E<W,B(&%L
M:6=N/2)C96YT97(B('-T>6QE/2)P861D:6YG.C`[(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\/W!H<"!E8VAO("1A
M4F5S=6QT6R=P97)C96YT)UT_)&%297-U;'1;)W!E<F-E;G0G72XG)2<Z)R<@
M/SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO
M=&0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M=&0@=VED=&@](CP_<&AP(&5C:&\@,3`P+21A4F5S=6QT6R=P97)C96YT)UT@
M/SXE(B!C;&%S<STB9F%I;'5R92(@86QI9VX](F-E;G1E<B(@<W1Y;&4](G!A
M9&1I;F<Z,#LB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#P_<&AP(&5C:&\@*#$P,"TD85)E<W5L=%LG<&5R8V5N="==
M*3\H,3`P+21A4F5S=6QT6R=P97)C96YT)UTN)R4G*3HG)R`_/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]T9#X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]T<CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\+W1A8FQE/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]T9#X*("`@("`@("`@("`@("`@("`@("`@("`@
M/"]T<CX*("`@("`@("`@("`@("`@("`@("`\/W!H<"!E;F1I9B`_/@H*("`@
M("`@("`@("`@("`@("`@("`\/W!H<"!I9BA`)&%297-U;'1;)V-O=6YT<R==
M*3H@/SX*("`@("`@("`@("`@("`@("`@("`@("`@/'1R/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'1D(&-O;'-P86X](C$P(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\/W!H<"!F;W)E86-H*"1A4F5S=6QT
M6R=C;W5N=',G72!A<R`D84-O=6YT/3XD=F%L=64I.B`_/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\/W!H<"!E8VAO("1A0V]U;G0@
M/SYS(#T@/#]P:'`@96-H;R`D=F%L=64@/SX@)FYB<W`[("9N8G-P.R`F;F)S
M<#L@)FYB<W`["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/#]P
M:'`@96YD9F]R96%C:"`_/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]T9#X*("`@("`@("`@("`@("`@("`@("`@("`@/"]T<CX*("`@("`@("`@
M("`@("`@("`@("`\/W!H<"!E;F1I9B`_/@H*("`@("`@("`@("`@("`@("`@
M("`\/W!H<"!I9BAI<W-E="@D85)E<W5L=%LG<F5S=6QT<R==6R=F86EL=7)E
M<R==*2`F)B!S:7IE;V8H)&%297-U;'1;)W)E<W5L=',G75LG9F%I;'5R97,G
M72DI"B`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@H)&%297-U;'1;
M)W)E<W5L=',G75LG9F%I;'5R97,G72!A<R`D849A:6QU<F4I.B`_/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\='(^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\=&0@8VQA<W,](F9A:6QU<F4B/CP_<&AP(&5C:&\@)&%&86EL
M=7)E6R=T97-T3F%M92==(#\^/"]T9#X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QT9"!C;&%S<STB9F%I;'5R92(^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/#]P:'`@:68H:7-S970H)&%&86EL=7)E6R=M97-S
M86=E)UTI("8F("1A1F%I;'5R95LG;65S<V%G92==*3H@/SX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/#]P:'`@96-H;R`D849A:6QU
M<F5;)VUE<W-A9V4G72`_/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#P_<&AP(&5L<V4Z(#\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QT86)L92!C;&%S<STB;W5T;&EN949A:6QU<F4B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'1R/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QT9#YE
M>'!E8W1E9#PO=&0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'1D/CP_<&AP(&5C:&\@)&%&86EL=7)E6R=E>'!E8W1E
M9"==(#\^/"]T9#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#PO='(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\='(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'1D/F%C='5A;#PO=&0^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'1D/CP_<&AP(&5C:&\@)&%&
M86EL=7)E6R=A8W1U86PG72`_/CPO=&0^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+W1R/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\+W1A8FQE/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#P_<&AP(&5N9&EF(#\^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\+W1D/@H@("`@("`@("`@("`@("`@("`@("`@("`\+W1R
M/@H@("`@("`@("`@("`@("`@("`@(#P_<&AP(&5N9&9O<F5A8V@@/SX*"B`@
M("`@("`@("`@("`@("`@("`@/#]P:'`@:68H:7-S970H)&%297-U;'1;)W)E
M<W5L=',G75LG97)R;W)S)UTI("8F('-I>F5O9B@D85)E<W5L=%LG<F5S=6QT
M<R==6R=E<G)O<G,G72DI"B`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A
M8V@H)&%297-U;'1;)W)E<W5L=',G75LG97)R;W)S)UT@87,@)&%%<G)O<BDZ
M(#\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QT<CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QT9"!C;&%S<STB9F%I;'5R92(^/#]P:'`@96-H
M;R`D845R<F]R6R=T97-T3F%M92==(#\^/"]T9#X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QT9"!C;&%S<STB9F%I;'5R92(^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/#]P:'`@96-H;R`D845R<F]R6R=M97-S
M86=E)UT@/SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO=&0^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#PO='(^"B`@("`@("`@("`@("`@("`@
M("`@/#]P:'`@96YD9F]R96%C:"`_/@H*("`@("`@("`@("`@("`@("`@("`\
M/W!H<"!I9BAI<W-E="@D85)E<W5L=%LG<F5S=6QT<R==6R=P87-S960G72D@
M)B8@<VEZ96]F*"1A4F5S=6QT6R=R97-U;'1S)UU;)W!A<W-E9"==*2D*("`@
M("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"@D85)E<W5L=%LG<F5S=6QT
M<R==6R=P87-S960G72!A<R`D85!A<W-E9"DZ(#\^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#QT<CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QT
M9"!C;&%S<STB<W5C8V5S<R(^/#]P:'`@96-H;R`D85!A<W-E9%LG=&5S=$YA
M;64G72`_/CPO=&0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\=&0@
M8VQA<W,](G-U8V-E<W,B/CQB/D]+/"]B/CPO=&0^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#PO='(^"B`@("`@("`@("`@("`@("`@("`@/#]P:'`@96YD
M9F]R96%C:"`_/@H*("`@("`@("`@("`@("`@(#P_<&AP(&5N9&9O<F5A8V@@
M/SX*("`@("`@("`@("`@/"]T86)L93X*("`@("`@("`\+V9O<FT^"@H@("`@
M("`@(#QS8W)I<'0^"B`@("`@("`@("`@('9A<B!A;&Q3=6ET94YA;65S(#T@
M;F5W($%R<F%Y*"D["B`@("`@("`@("`@(#P_<&AP(&9O<F5A8V@H)'-U:71E
M4F5S=6QT<R!A<R`D85)E<W5L="DZ(#\^"B`@("`@("`@("`@("`@("!A;&Q3
M=6ET94YA;65S6V%L;%-U:71E3F%M97,N;&5N9W1H72`]("(\/W!H<"!E8VAO
M("1A4F5S=6QT6R=N86UE)UT@/SXB.PH@("`@("`@("`@("`\/W!H<"!E;F1F
M;W)E86-H(#\^"B`@("`@("`@("`@(&9U;F-T:6]N('5N0VAE8VM!;&PH*0H@
M("`@("`@("`@("!["B`@("`@("`@("`@("`@("!?8VAE8VME9"`](&1O8W5M
M96YT+F]P=&EO;G-&;W)M+F%L;$-H96-K960N8VAE8VME9#L*("`@("`@("`@
M("`@("`@(&9O<B`H:3TP.VD\86QL4W5I=&5.86UE<RYL96YG=&@[:2LK*2![
M"B`@("`@("`@("`@("`@("`@("`@9&]C=6UE;G0N;W!T:6]N<T9O<FU;86QL
M4W5I=&5.86UE<UMI75TN8VAE8VME9"`](%]C:&5C:V5D.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@/"]S8W)I<'0^"@H@("`@
M/"]B;V1Y/@H\+VAT;6P^"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!(
M4%5N:70O1U5)+U-E='5P1&5C;W)A=&]R+G!H<```````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,38U-C$@,3`U,34T,S,W,S$@,#(T,#8T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J('9I;3H@
M<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S
M=&]P/30Z("HO"@HO*BH*("H@4$A0(%9E<G-I;VX@-`H@*@H@*B!#;W!Y<FEG
M:'0@*&,I(#(P,#(M,C`P-2P@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A
M<W1I86XM8F5R9VUA;FXN9&4^+@H@*B!!;&P@<FEG:'1S(')E<V5R=F5D+@H@
M*@H@*B!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN
M87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70*("H@;6]D:69I8V%T:6]N+"!A
M<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO=VEN9R!C;VYD
M:71I;VYS"B`J(&%R92!M970Z"B`J"B`J("`@*B!2961I<W1R:6)U=&EO;G,@
M;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H
M=`H@*B`@("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@
M=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R+@H@*B`*("H@("`J(%)E9&ES=')I
M8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C92!T:&4@86)O
M=F4@8V]P>7)I9VAT"B`J("`@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD
M:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@:6X*("H@("`@
M('1H92!D;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O
M=FED960@=VET:"!T:&4*("H@("`@(&1I<W1R:6)U=&EO;BX*("H*("H@("`J
M($YE:71H97(@=&AE(&YA;64@;V8@4V5B87-T:6%N($)E<F=M86YN(&YO<B!T
M:&4@;F%M97,@;V8@:&ES"B`J("`@("!C;VYT<FEB=71O<G,@;6%Y(&)E('5S
M960@=&\@96YD;W)S92!O<B!P<F]M;W1E('!R;V1U8W1S(&1E<FEV960*("H@
M("`@(&9R;VT@=&AI<R!S;V9T=V%R92!W:71H;W5T('-P96-I9FEC('!R:6]R
M('=R:71T96X@<&5R;6ES<VEO;BX*("H*("H@5$A)4R!33T945T%212!)4R!0
M4D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@04Y$($-/3E1224)5
M5$]24PH@*B`B05,@25,B($%.1"!!3ED@15A04D534R!/4B!)35!,245$(%=!
M4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5`H@*B!,24U)5$5$(%1/+"!4
M2$4@24U03$E%1"!705)204Y42453($]&($U%4D-(04Y404))3$E462!!3D0@
M1DE43D534PH@*B!&3U(@02!005)424-53$%2(%!54E!/4T4@05)%($1)4T-,
M04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(10H@*B!#3U!94DE'2%0@3U=.
M15(@3U(@0T].5%))0E543U)3($)%($Q)04),12!&3U(@04Y9($1)4D5#5"P@
M24Y$25)%0U0L"B`J($E.0TE$14Y404PL(%-014-)04PL($5814U03$%262P@
M3U(@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,541)3D<L"B`J($)55"!.
M3U0@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8@4U5"4U1)5%5412!'3T]$
M4R!/4B!315)624-%4SL*("H@3$]34R!/1B!54T4L($1!5$$L($]2(%!23T9)
M5%,[($]2($)54TE.15-3($E.5$524E505$E/3BD@2$]7159%4@H@*B!#0553
M140@04Y$($].($%.62!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52($E.
M($-/3E1204-4+"!35%))0PH@*B!,24%"24Q)5%DL($]2(%1/4E0@*$E.0TQ5
M1$E.1R!.14=,24=%3D-%($]2($]42$525TE312D@05))4TE.1R!)3@H@*B!!
M3ED@5T%9($]55"!/1B!42$4@55-%($]&(%1(25,@4T]&5%=!4D4L($5614X@
M248@041625-%1"!/1B!42$4*("H@4$]34TE"24Q)5%D@3T8@4U5#2"!$04U!
M1T4N"B`J"B`J($!C871E9V]R>2`@(%1E<W1I;F<*("H@0'!A8VMA9V4@("`@
M4$A056YI=`H@*B!`875T:&]R("`@("!7;VQF<F%M($MR:65S:6YG(#QW;VQF
M<F%M0&MR:65S:6YG+F1E/@H@*B!`8V]P>7)I9VAT("`R,#`R+3(P,#4@4V5B
M87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^"B`J
M($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS
M97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@
M("!#5E,Z("1)9#H@4V5T=7!$96-O<F%T;W(N<&AP+'8@,2XQ-2`R,#`U+S$Q
M+S$P(#`Y.C0W.C$U('-E8F%S=&EA;B!%>'`@)`H@*B!`;&EN:R`@("`@("!H
M='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$A056YI=`H@*B!`<VEN8V4@
M("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N,"XP"B`J+PH*
M+RHJ"B`J(%1H:7,@9&5C;W)A=&]R(&%C='5A;&QY(&IU<W0@861D<R!T:&4@
M9G5N8W1I;VYA;&ET>2!T;R!R96%D('1H90H@*B!T97-T+7-U:71E(&-L87-S
M97,@9G)O;2!A(&=I=F5N(&1I<F5C=&]R>2!A;F0@:6YS=&%N8VEA=&4@=&AE
M;0H@*B!A=71O;6%T:6-A;&QY+"!U<V4@:70@87,@9VEV96X@:6X@=&AE(&5X
M86UP;&4@8F5L;W<N"B`J"B`J(#QC;V1E/@H@*B`\/W!H<`H@*B`D9W5I(#T@
M;F5W(%!(4%5N:71?1U5)7U-E='5P1&5C;W)A=&]R*&YE=R!02%!5;FET7T=5
M25](5$U,*"DI.PH@*B`D9W5I+3YG9713=6ET97-&<F]M1&ER*"<O<&%T:"]T
M;R]D:7(O=&5S=',G+"<N*EPN<&AP)"<L87)R87DH)VEN9&5X+G!H<"<L)W-Q
M;"YP:'`G*2D["B`J("1G=6DM/G-H;W<H*3L*("H@/SX*("H@/"]C;V1E/@H@
M*@H@*B!4:&4@97AA;7!L92!C86QL<R!T:&ES(&-L87-S(&%N9"!T96QL<R!I
M="!T;SH*("H*("H@("`M(&9I;F0@86QL(&9I;&4@=6YD97(@=&AE(&1I<F5C
M=&]R>2`O<&%T:"]T;R]D:7(O=&5S=',*("H@("`M(&9O<B!F:6QE<RP@=VAI
M8V@@96YD('=I=&@@)RYP:'`G("AT:&ES(&ES(&$@<&EE8V4@;V8@82!R96=E
M>'`L('1H870G<R!W:'D@=&AE("X@:7,@97-C87!E9"D*("H@("`M(&%N9"!T
M;R!E>&-L=61E('1H92!F:6QE<R`G:6YD97@N<&AP)R!A;F0@)W-Q;"YP:'`G
M"B`J("`@+2!A;F0@:6YC;'5D92!A;&P@=&AE(&9I;&5S('1H870@87)E(&QE
M9G0@:6X@=&AE('1E<W1S+@H@*@H@*B!':79E;B!T:&%T('1H92!P871H("AT
M:&4@9FER<W0@<&%R86UE=&5R*2!E;F1S('=I=&@@)W1E<W1S)R!I="!W:6QL
M(&)E(&%S<W5M960*("H@=&AA="!T:&4@8VQA<W-E<R!A<F4@;F%M960@=&5S
M='-?*B!W:&5R92`J(&ES('1H92!D:7)E8W1O<GD@<&QU<R!T:&4@9FEL96YA
M;64L"B`J(&%C8V]R9&EN9R!T;R!014%2('-T86YD87)D<RX*("H*("H@4V\@
M=&AA=#H*("H*("H@("`M("=T97-T364N<&AP)R!I;B!T:&4@9&ER("=T97-T
M<R<@8FEL;"!B92!A<W-U;65D('1O(&-O;G1A:6X@82!C;&%S<R!T97-T<U]T
M97-T364*("H@("`M("<O;6]R971E<W1S+V%497-T+G!H<"<@<VAO=6QD(&-O
M;G1A:6X@82!C;&%S<R`G=&5S='-?;6]R971E<W1S7V%497-T)PH@*@H@*B!`
M8V%T96=O<GD@("!497-T:6YG"B`J($!P86-K86=E("`@(%!(4%5N:70*("H@
M0&%U=&AO<B`@("`@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN
M9RYD93X*("H@0&-O<'ER:6=H="`@,C`P,BTR,#`U(%-E8F%S=&EA;B!"97)G
M;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/@H@*B!`;&EC96YS92`@
M("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E
M;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@4F5L96%S93H@
M,2XS+C(*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K
M86=E+U!(4%5N:70*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I
M;F-E(%)E;&5A<V4@,2XP+C`*("HO"F-L87-S(%!(4%5N:71?1U5)7U-E='5P
M1&5C;W)A=&]R"GL*("`@("\J*@H@("`@*@H@("`@*@H@("`@*B\*("`@(&9U
M;F-T:6]N(%!(4%5N:71?1U5)7U-E='5P1&5C;W)A=&]R*"8D9W5I*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?9W5I(#T@)B1G=6D["B`@("!]"@H@("`@+RHJ
M"B`@("`J("`@:G5S="!F;W)W87)D:6YG('1H92!A8W1I;VX@=&\@=&AE(&1E
M8V]R871E9"!C;&%S<RX*("`@("H*("`@("HO"B`@("!F=6YC=&EO;B!S:&]W
M*"1S:&]W4&%S<V5D/512544I"B`@("!["B`@("`@("`@)'1H:7,M/E]G=6DM
M/G-H;W<H)'-H;W=087-S960I.PH@("`@?0H*("`@("\J*@H@("`@*B!3971U
M<"!T97-T('-U:71E<R!T:&%T(&-A;B!B92!F;W5N9"!I;B!T:&4@9VEV96X@
M9&ER96-T;W)Y"B`@("`J(%5S:6YG('1H92!S96-O;F0@<&%R86UE=&5R('EO
M=2!C86X@86QS;R!C:&]O<V4@82!S=6)S971S(&]F('1H92!F:6QE<R!F;W5N
M9`H@("`@*B!I;B!T:&4@9VEV96X@9&ER96-T;W)Y+B!)+F4N(&]N;'D@86QL
M('1H92!F:6QE<R!T:&%T(&-O;G1A:6X@)U]5;FET5&5S=%\G+`H@("`@*B!I
M;B!O<F1E<B!T;R!D;R!T:&ES('-I;7!L>2!C86QL(&ET(&QI:V4@=&AI<SH*
M("`@("H@/&-O9&4^9V5T4W5I=&5S1G)O;41I<B@D9&ER+"<N*E]5;FET5&5S
M=%\N*B<I/"]C;V1E/BX*("`@("H@5&AE<F4@>6]U(&-A;B!A;')E861Y('-E
M92!T:&%T('1H92!P871T97)N(&ES(&)U:6QT(&9O<B!T:&4@=7-E('=I=&AI
M;B!A(')E9W5L87(@97AP<F5S<VEO;BX*("`@("H*("`@("H@0'!A<F%M("!S
M=')I;F<@('1H92!D:7)E8W1O<GD@=VAE<F4@=&\@<V5A<F-H(&9O<B!T97-T
M+7-U:71E(&9I;&5S"B`@("`J($!P87)A;2`@<W1R:6YG("!T:&4@<&%T=&5R
M;B`H82!R96=E>'`I(&)Y('=H:6-H('1O(&9I;F0@=&AE(&9I;&5S"B`@("`J
M($!P87)A;2`@87)R87D@("!A;B!A<G)A>2!O9B!F:6QE(&YA;65S('1H870@
M<VAA;&P@8F4@97AC;'5D960*("`@("HO"B`@("!F=6YC=&EO;B!G9713=6ET
M97-&<F]M1&ER*"1D:7(L("1F:6QE;F%M95!A='1E<FX@/2`G)RP@)&5X8VQU
M9&4@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("@D9&ER>W-T<FQE;B@D
M9&ER*2TQ?2`]/2!$25)%0U1/4EE?4T5005)!5$]2*2!["B`@("`@("`@("`@
M("1D:7(@/2!S=6)S='(H)&1I<BP@,"P@+3$I.PH@("`@("`@('T*"B`@("`@
M("`@)&9I;&5S(#T@)'1H:7,M/E]G971&:6QE<RAR96%L<&%T:"@D9&ER*2P@
M)&9I;&5N86UE4&%T=&5R;BP@)&5X8VQU9&4L(')E86QP871H*"1D:7(@+B`G
M+RXN)RDI.PH@("`@("`@(&%S;W)T*"1F:6QE<RD["@H@("`@("`@(&9O<F5A
M8V@@*"1F:6QE<R!A<R`D8VQA<W-.86UE(#T^("1A1FEL92D@>PH@("`@("`@
M("`@("!I;F-L=61E7V]N8V4H)&%&:6QE*3L*"B`@("`@("`@("`@(&EF("AC
M;&%S<U]E>&ES=',H)&-L87-S3F%M92DI('L*("`@("`@("`@("`@("`@("1S
M=6ET97-;72`])B!N97<@4$A056YI=%]497-T4W5I=&4H)&-L87-S3F%M92D[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!T<FEG9V5R
M7V5R<F]R*"(D8VQA<W-.86UE(&-O=6QD(&YO="!B92!F;W5N9"!I;B`D9&ER
M)&%&:6QE(2(I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D
M=&AI<RT^7V=U:2T^861D4W5I=&5S*"1S=6ET97,I.PH@("`@?0H*("`@("\J
M*@H@("`@*B!4:&ES(&UE=&AO9"!S96%R8VAE<R!R96-U<G-I=F5L>2!T:')O
M=6=H('1H92!D:7)E8W1O<FEE<PH@("`@*B!T;R!F:6YD(&%L;"!T:&4@9FEL
M97,@=&AA="!S:&%L;"!B92!A9&1E9"!T;R!T:&4@8F4@=FES:6)L92X*("`@
M("H*("`@("H@0'!A<F%M("!S=')I;F<@('1H92!P871H('=H97)E(&9I;F0@
M=&AE(&9I;&5S"B`@("`J($!P87)A;2`@<W)T:6YG("!T:&4@<W1R:6YG('!A
M='1E<FX@8GD@=VAI8V@@=&\@9FEN9"!T:&4@9FEL97,*("`@("H@0'!A<F%M
M("!S=')I;F<@('1H92!F:6QE(&YA;65S('1O(&)E(&5X8VQU9&5D"B`@("`J
M($!P87)A;2`@<W1R:6YG("!T:&4@<F]O="!D:7)E8W1O<GDL('=H:6-H('-E
M<G9E<R!A<R!T:&4@<')E9FEX('1O('1H92!F=6QL>2!Q=6%L:69I960@9FEL
M96YA;64*("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`J+PH@("`@9G5N8W1I
M;VX@7V=E=$9I;&5S*"1D:7(L("1F:6QE;F%M95!A='1E<FXL("1E>&-L=61E
M+"`D<F]O=$1I<BD*("`@('L*("`@("`@("`D9FEL97,@/2!A<G)A>2@I.PH*
M("`@("`@("!I9B`H)&1P(#T@;W!E;F1I<B@D9&ER*2D@>PH@("`@("`@("`@
M("!W:&EL92`H1D%,4T4@(3T]("@D9FEL92`](')E861D:7(H)&1P*2DI('L*
M("`@("`@("`@("`@("`@("1F:6QE;F%M92`]("1D:7(@+B!$25)%0U1/4EE?
M4T5005)!5$]2("X@)&9I;&4["B`@("`@("`@("`@("`@("`D;6%T8V@@("`@
M/2!44E5%.PH*("`@("`@("`@("`@("`@(&EF("@D9FEL96YA;650871T97)N
M("8F("%P<F5G7VUA=&-H*")^)&9I;&5N86UE4&%T=&5R;GXB+"`D9FEL92DI
M('L*("`@("`@("`@("`@("`@("`@("`D;6%T8V@@/2!&04Q313L*("`@("`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I9B`H<VEZ96]F*"1E>&-L
M=61E*2D@>PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1E>&-L=61E
M(&%S("1A17AC;'5D92D@>PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M<W1R<&]S*"1F:6QE+"`D845X8VQU9&4I("$]/2!&04Q312D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&UA=&-H(#T@1D%,4T4["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("!I9B`H:7-?9FEL92@D9FEL96YA;64I("8F
M("1M871C:"D@>PH@("`@("`@("`@("`@("`@("`@("1T;7`@/2!S=')?<F5P
M;&%C92@D<F]O=$1I<BP@)R<L("1F:6QE;F%M92D["@H@("`@("`@("`@("`@
M("`@("`@(&EF("AS=')P;W,H)'1M<"P@1$E214-43U)97U-%4$%2051/4BD@
M/3T](#`I('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1M<"`]('-U8G-T
M<B@D=&UP+"`Q*3L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`@("`@("`@(&EF("AS=')P;W,H)'1M<"P@)R\G*2`]/3T@,"D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D=&UP(#T@<W5B<W1R*"1T;7`L(#$I.PH@
M("`@("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@)&-L
M87-S3F%M92`]('-T<E]R97!L86-E*$1)4D5#5$]265]315!!4D%43U(L("=?
M)RP@)'1M<"D["B`@("`@("`@("`@("`@("`@("`@)&-L87-S3F%M92`](&)A
M<V5N86UE*"1C;&%S<TYA;64L("<N<&AP)RD["@H@("`@("`@("`@("`@("`@
M("`@("1F:6QE<ULD8VQA<W-.86UE72`]("1F:6QE;F%M93L*("`@("`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("`@("!I9B`H)&9I;&4@(3T@)RXG("8F
M("1F:6QE("$]("<N+B<@)B8@:7-?9&ER*"1F:6QE;F%M92DI('L*("`@("`@
M("`@("`@("`@("`@("`D9FEL97,@/2!A<G)A>5]M97)G92@D9FEL97,L("1T
M:&ES+3Y?9V5T1FEL97,H)&9I;&5N86UE+"`D9FEL96YA;650871T97)N+"`D
M97AC;'5D92P@)')O;W1$:7(I*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@8VQO<V5D:7(H)&1P*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D9FEL97,["B`@("!]"GT*"B\J"B`J($QO8V%L
M('9A<FEA8FQE<SH*("H@=&%B+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T
M.B`T"B`J(&,M:&%N9VEN9RUC;VUM96YT+65N9&5R+7`Z(&YI;`H@*B!%;F0Z
M"B`J+PH_/@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M4$A056YI="]'54DO1W1K+G!H<```````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`U-#,R-R`Q,#4Q-30S,S<S,2`P,C$V-3``(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RH@=FEM
M.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A
M8G-T;W`]-#H@*B\*"B\J*@H@*B!02%`@5F5R<VEO;B`T"B`J"B`J($-O<'ER
M:6=H="`H8RD@,C`P,BTR,#`U+"!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E
M8F%S=&EA;BUB97)G;6%N;BYD93XN"B`J($%L;"!R:6=H=',@<F5S97)V960N
M"B`J"B`J(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B
M:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U=`H@*B!M;V1I9FEC871I;VXL
M(&%R92!P97)M:71T960@<')O=FED960@=&AA="!T:&4@9F]L;&]W:6YG(&-O
M;F1I=&EO;G,*("H@87)E(&UE=#H*("H*("H@("`J(%)E9&ES=')I8G5T:6]N
M<R!O9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I
M9VAT"B`J("`@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N
M9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N"B`J(`H@*B`@("H@4F5D:7-T
M<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A
M8F]V92!C;W!Y<FEG:'0*("H@("`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O
M;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;@H@*B`@
M("`@=&AE(&1O8W5M96YT871I;VX@86YD+V]R(&]T:&5R(&UA=&5R:6%L<R!P
M<F]V:61E9"!W:71H('1H90H@*B`@("`@9&ES=')I8G5T:6]N+@H@*@H@*B`@
M("H@3F5I=&AE<B!T:&4@;F%M92!O9B!396)A<W1I86X@0F5R9VUA;FX@;F]R
M('1H92!N86UE<R!O9B!H:7,*("H@("`@(&-O;G1R:6)U=&]R<R!M87D@8F4@
M=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O9'5C=',@9&5R:79E9`H@
M*B`@("`@9G)O;2!T:&ES('-O9G1W87)E('=I=&AO=70@<W!E8VEF:6,@<')I
M;W(@=W)I='1E;B!P97)M:7-S:6]N+@H@*@H@*B!42$E3(%-/1E1705)%($E3
M(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$524R!!3D0@0T].5%))
M0E543U)3"B`J(")!4R!)4R(@04Y$($%.62!%6%!215-3($]2($E-4$Q)140@
M5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4"B`J($Q)34E4140@5$\L
M(%1(12!)35!,245$(%=!4E)!3E1)15,@3T8@34520TA!3E1!0DE,2519($%.
M1"!&251.15-3"B`J($9/4B!!(%!!4E1)0U5,05(@4%524$]312!!4D4@1$E3
M0TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%"B`J($-/4%E224=(5"!/
M5TY%4B!/4B!#3TY44DE"551/4E,@0D4@3$E!0DQ%($9/4B!!3ED@1$E214-4
M+"!)3D1)4D5#5"P*("H@24Y#241%3E1!3"P@4U!%0TE!3"P@15A%35!,05)9
M+"!/4B!#3TY315%514Y424%,($1!34%'15,@*$E.0TQ51$E.1RP*("H@0E54
M($Y/5"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1B!354)35$E4551%($=/
M3T13($]2(%-%4E9)0T53.PH@*B!,3U-3($]&(%5312P@1$%402P@3U(@4%)/
M1DE44SL@3U(@0E5324Y%4U,@24Y415)255!424].*2!(3U=%5D52"B`J($-!
M55-%1"!!3D0@3TX@04Y9(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(15(@
M24X@0T].5%)!0U0L(%-44DE#"B`J($Q)04))3$E462P@3U(@5$]25"`H24Y#
M3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!4DE324Y'($E."B`J
M($%.62!705D@3U54($]&(%1(12!54T4@3T8@5$A)4R!33T945T%212P@159%
M3B!)1B!!1%9)4T5$($]&(%1(10H@*B!03U-324))3$E462!/1B!354-(($1!
M34%'12X*("H*("H@0&-A=&5G;W)Y("`@5&5S=&EN9PH@*B!`<&%C:V%G92`@
M("!02%!5;FET"B`J($!A=71H;W(@("`@(%-C;W1T($UA='1O8VMS(#QS8V]T
M=$!C<FES<V-O='0N8V]M/@H@*B!`8V]P>7)I9VAT("`R,#`R+3(P,#4@4V5B
M87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^"B`J
M($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS
M97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@
M("!#5E,Z("1)9#H@1W1K+G!H<"QV(#$N-B`R,#`U+S$Q+S$P(#`Y.C0W.C$U
M('-E8F%S=&EA;B!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP
M:'`N;F5T+W!A8VMA9V4O4$A056YI=`H@*B!`<VEN8V4@("`@("!&:6QE(&%V
M86EL86)L92!S:6YC92!296QE87-E(#$N,BXP"B`J+PH*:68@*"%F=6YC=&EO
M;E]E>&ES=',H)VES7V$G*2D@>PH@("`@<F5Q=6ER95]O;F-E("=02%`O0V]M
M<&%T+T9U;F-T:6]N+VES7V$N<&AP)SL*?0H*+RHJ"B`J($=42R!'54D@:6YT
M97)F86-E(&9O<B!02%!5;FET+@H@*@H@*B!4:&ES(&-L87-S(&ES(&$@4$A0
M('!O<G0@;V8@:G5N:70N87=T=6DN=&5S=')U;FYE<BX@1&]C=6UE;G1A=&EO
M;@H@*B!F;W(@:G5N:70N87=T=6DN=&5S=')U;FYE<B!C86X@8F4@9F]U;F0@
M870*("H@:'1T<#HO+VIU;FET+G-O=7)C969O<F=E+FYE=`H@*@H@*B!$=64@
M=&\@=&AE(&QI;6ET871I;VYS(&]F(%!(4#0@86YD(%!(4"U'=&LL('1H:7,@
M8VQA<W,@8V%N(&YO=`H@*B!D=7!L:6-A=&4@86QL(&]F('1H92!F=6YC=&EO
M;F%L:71Y(&]F('1H92!*56YI="!'54DN(%-O;64@;V8@=&AE"B`J('1H:6YG
M<R!T:&ES(&-L87-S(&-A;FYO="!D;R!I;F-L=61E.@H@*B`M(%)E;&]A9&EN
M9R!T:&4@8VQA<W,@9F]R(&5A8V@@<G5N"B`J("T@4W1O<'!I;F<@=&AE('1E
M<W0@:6X@<')O9W)E<W,*("H*("H@5&\@=7-E('-I;7!L>2!I;G1A;G1I871E
M('1H92!C;&%S<R!A;F0@8V%L;"!M86EN*"D*("H@)&=T:R`])B!N97<@4$A0
M56YI=%]'54E?1W1K.PH@*B`D9W1K+3YM86EN*"D["B`J"B`J($]N8V4@=&AE
M('=I;F1O=R!H87,@9FEN:7-H960@;&]A9&EN9RP@>6]U(&-A;B!E;G1E<B!T
M:&4@;F%M92!O9@H@*B!A(&-L87-S('1H870@:&%S(&)E96X@;&]A9&5D("AI
M;F-L=61E+W)E<75I<F4@<V]M92!W:&5R92!I;B!Y;W5R"B`J(&-O9&4L(&]R
M('EO=2!C86X@<&%S<R!T:&4@;F%M92!O9B!T:&4@9FEL92!C;VYT86EN:6YG
M('1H92!C;&%S<RX*("H*("H@66]U(&-A;B!A;'-O(&QO860@8VQA<W-E<R!U
M<VEN9R!T:&4@4V5T=7!$96-O<F%T;W(@8VQA<W,N"B`J(')E<75I<F5?;VYC
M92`G4$A056YI="]'54DO4V5T=7!$96-O<F%T;W(N<&AP)SL*("H@<F5Q=6ER
M95]O;F-E("=02%!5;FET+T=522]'=&LN<&AP)SL*("H@)&=U:2`](&YE=R!0
M2%!5;FET7T=525]3971U<$1E8V]R871O<BAN97<@4$A056YI=%]'54E?1W1K
M*"DI.PH@*B`D9W5I+3YG9713=6ET97-&<F]M1&ER*"<O<&%T:"]T;R]T97-T
M)RPG+BI<+G!H<"0G+&%R<F%Y*"=I;F1E>"YP:'`G+"=S<6PN<&AP)RDI.PH@
M*B`D9W5I+3YS:&]W*"D["B`J"B`J"B`J($!C871E9V]R>2`@(%1E<W1I;F<*
M("H@0'!A8VMA9V4@("`@4$A056YI=`H@*B!`875T:&]R("`@("!38V]T="!-
M871T;V-K<R`\<V-O='1`8W)I<W-C;W1T+F-O;3X*("H@0&-O<'ER:6=H="`@
M,C`P,BTR,#`U(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E
M<F=M86YN+F1E/@H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+F]P96YS;W5R
M8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*
M("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XS+C(*("H@0&QI;FL@("`@("`@
M:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!(4%5N:70*("H@0'-I;F-E
M("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XR+C`*("H@
M0'1O9&\@("`@("`@06QL;W<@9FEL92!D<F]P+B`H1W1K7T9I;&5$<F]P*0H@
M*B\*8VQA<W,@4$A056YI=%]'54E?1W1K('L*"B`@("`O*BH*("`@("`J(%1H
M92!M86EN(&=T:R!W:6YD;W<*("`@("`J($!V87(@;V)J96-T"B`@("`@*B\*
M("`@('9A<B`D9W5I.PH@("`@+RHJ"B`@("`@*B!4:&4@=&5X="!E;G1R>2!T
M:&%T(&-O;G1A:6YS('1H92!N86UE(&]F('1H90H@("`@("H@9FEL92!T:&%T
M(&AO;&1S('1H92!T97-T*',I+W-U:71E*',I+@H@("`@("H@0'9A<B!O8FIE
M8W0*("`@("`J+PH@("`@=F%R("1S=6ET949I96QD.PH@("`@+RHJ"B`@("`@
M*B!4:&4@;&%B96P@=&AA="!S:&]W<R!T:&4@;G5M8F5R(&]F('1E<W1S('1H
M870*("`@("`J('=E<F4@<G5N+@H@("`@("H@0'9A<B!O8FIE8W0*("`@("`J
M+PH@("`@=F%R("1N=6UB97)/9E)U;G,["B`@("`O*BH*("`@("`J(%1H92!L
M86)E;"!T:&%T('-H;W=S('1H92!N=6UB97(@;V8@97)R;W)S('1H870*("`@
M("`J('=E<F4@96YC;W5N=&5R960N"B`@("`@*B!`=F%R(&]B:F5C=`H@("`@
M("HO"B`@("!V87(@)&YU;6)E<D]F17)R;W)S.PH@("`@+RHJ"B`@("`@*B!4
M:&4@;&%B96P@=&AA="!S:&]W<R!T:&4@;G5M8F5R(&]F(&9A:6QU<F5S"B`@
M("`@*B!T:&%T('=E<F4@96YC;W5N=&5R960N"B`@("`@*B!`=F%R(&]B:F5C
M=`H@("`@("HO"B`@("!V87(@)&YU;6)E<D]F1F%I;'5R97,["B`@("`O*BH*
M("`@("`J(%1H92!L86)E;"!F;W(@<F5P;W)T:6YG('5S97(@;65S<V%G97,N
M"B`@("`@*B!`=F%R(&]B:F5C=`H@("`@("HO"B`@("!V87(@)'-T871U<TQI
M;F4["B`@("`O*BH*("`@("`J(%1H92!T97AT(&%R96$@9F]R(')E<&]R=&EN
M9R!M97-S86=E<R!F<F]M('-U8V-E<W-F=6P*("`@("`J('1E<W0@<G5N<RX@
M*&YO="!N96-E<W-A<FEL>2!S=6-C97-S9G5L('1E<W1S*0H@("`@("H@0'9A
M<B!O8FIE8W0*("`@("`J+PH@("`@=F%R("1R97!O<G1!<F5A.PH@("`@+RHJ
M"B`@("`@*B!4:&4@=&5X="!A<F5A(&9O<B!R97!O<G1I;F<@97)R;W)S(&5N
M8V]U;G1E<F5D('=H96X*("`@("`J(')U;FYI;F<@=&5S=',N"B`@("`@*B!`
M=F%R(&]B:F5C=`H@("`@("HO"B`@("!V87(@)&1U;7!!<F5A.PH@("`@+RHJ
M"B`@("`@*B!4:&4@<')O9W)E<W,@8F%R(&EN9&EC871O<BX@4VAO=W,@=&AE
M('!E<F-E;G1A9V4@;V8*("`@("`J('!A<W-E9"!T97-T<RX*("`@("`J($!V
M87(@;V)J96-T"B`@("`@*B\*("`@('9A<B`D<')O9W)E<W,["B`@("`O*BH*
M("`@("`J($$@8VAE8VMB;W@@9F]R('1H92!U<V5R('1O(&EN9&EC871E('=H
M971H97(@;W(@;F]T('1H97D*("`@("`J('=O=6QD(&QI:V4@=&\@<V5E(')E
M<W5L=',@9G)O;2!A;&P@=&5S=',@;W(@:G5S="!F86EL=7)E<RX*("`@("`J
M($!O8FIE8W0*("`@("`J+PH@("`@=F%R("1S:&]W4&%S<V5D.PH*("`@("\J
M*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@5&AE(&-O;G-T
M<G5C=&]R(&-H96-K<R!F;W(@=&AE(&=T:R!E>'1E;G-I;VX@86YD(&QO861S
M(&ET"B`@("`@*B!I9B!N965D960N(%1H96X@:70@8W)E871E<R!T:&4@1U5)
M+B!4:&4@1U5)(&ES(&YO="!S:&]W;@H@("`@("H@;F]R(&ES('1H92!M86EN
M(&=T:R!L;V]P('-T87)T960@=6YT:6P@;6%I;B@I(&ES(&-A;&QE9"X*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M("!N;VYE
M"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@4$A0
M56YI=%]'54E?1W1K*"D*("`@('L*("`@("`@("`O+R!#:&5C:R!F;W(@<&AP
M+6=T:R!E>'1E;G-I;VXN"B`@("`@("`@:68@*"%E>'1E;G-I;VY?;&]A9&5D
M*"=G=&LG*2D@>PH@("`@("`@("`@("!D;"@@)W!H<%]G=&LN)R`N(%!(4%]3
M2$Q)0E]3549&25@I.PH@("`@("`@('T*"B`@("`@("`@+R\@0W)E871E('1H
M92!I;G1E<F9A8V4@8G5T(&1O;B=T('-T87)T('1H92!L;V]P"B`@("`@("`@
M)'1H:7,M/E]C<F5A=&5522@I.PH@("`@?0H@("`@+RHJ"B`@("`@*B!3=&%R
M="!T:&4@;6%I;B!G=&L@;&]O<"X*("`@("`J"B`@("`@*B!M86EN*"D@9FER
M<W0@<V5T<R!T:&4@9&5F875L="!S=&%T92!O9B!T:&4@<VAO=U!A<W-E9`H@
M("`@("H@8VAE8VL@8F]X+B!.97AT(&%L;"!W:61G971S('1H870@87)E('!A
M<G0@;V8@=&AE($=520H@("`@("H@87)E('-H;W=N+B!&:6YA;&QY('1H92!M
M86EN(&=T:R!L;V]P(&ES('-T87)T960N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J($!P87)A;2`@8F]O;&5A;B`D<VAO=U!A<W-E9`H@
M("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N(&UA:6XH
M)'-H;W=087-S960@/2!T<G5E*0H@("`@>PH@("`@("`@("1T:&ES+3YS:&]W
M4&%S<V5D+3YS971?86-T:79E*"1S:&]W4&%S<V5D*3L*("`@("`@("`D=&AI
M<RT^9W5I+3YS:&]W7V%L;"@I.PH*("`@("`@("!G=&LZ.FUA:6XH*3L*("`@
M('T*("`@("\J*@H@("`@("H@0W)E871E('1H92!U<V5R(&EN=&5R9F%C92X*
M("`@("`J"B`@("`@*B!4:&4@=7-E<B!I;G1E<F9A8V4@:7,@<')E='1Y('-I
M;7!L92X@270@8V]N<VES=',@;V8@80H@("`@("H@;65N=2P@=&5X="!E;G1R
M>2P@<G5N(&)U='1O;BP@<V]M92!L86)E;',L(&$@<')O9W)E<W,*("`@("`J
M(&EN9&EC871O<BP@86YD(&$@8V]U<&QE(&]F(&%R96%S(&9O<B!N;W1I9FEC
M871I;VX@;V8*("`@("`J(&%N>2!M97-S86=E<RX*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J($!P87)A;2`@;F]N90H@("`@("H@0')E
M='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C<F5A=&5522@I"B`@
M("!["B`@("`@("`@+R\@0W)E871E(&$@=VEN9&]W+@H@("`@("`@("1W:6YD
M;W<@/28@;F5W($=T:U=I;F1O=SL*("`@("`@("`D=VEN9&]W+3YS971?=&ET
M;&4H)U!(4%5N:70@1W1K)RD["B`@("`@("`@)'=I;F1O=RT^<V5T7W5S:7IE
M*#0P,"P@+3$I.PH*("`@("`@("`O+R!#<F5A=&4@=&AE(&UA:6X@8F]X+@H@
M("`@("`@("1M86EN0F]X(#TF(&YE=R!'=&M60F]X.PH@("`@("`@("1W:6YD
M;W<M/F%D9"@D;6%I;D)O>"D["@H@("`@("`@("\O(%-T87)T('=I=&@@=&AE
M(&UE;G4N"B`@("`@("`@)&UA:6Y";W@M/G!A8VM?<W1A<G0H)'1H:7,M/E]C
M<F5A=&5-96YU*"DI.PH*("`@("`@("`O+R!4:&5N(&%D9"!T:&4@<W5I=&4@
M9FEE;&0@96YT<GDN"B`@("`@("`@)&UA:6Y";W@M/G!A8VM?<W1A<G0H)'1H
M:7,M/E]C<F5A=&53=6ET945N=')Y*"DI.PH*("`@("`@("`O+R!4:&5N(&%D
M9"!T:&4@<F5P;W)T(&QA8F5L<RX*("`@("`@("`D;6%I;D)O>"T^<&%C:U]S
M=&%R="@D=&AI<RT^7V-R96%T95)E<&]R=$QA8F5L<R@I*3L*"B`@("`@("`@
M+R\@3F5X="!A9&0@=&AE('!R;V=R97-S(&)A<BX*("`@("`@("`D;6%I;D)O
M>"T^<&%C:U]S=&%R="@D=&AI<RT^7V-R96%T95!R;V=R97-S0F%R*"DI.PH*
M("`@("`@("`O+R!4:&5N(&%D9"!T:&4@<F5P;W)T(&%R96$@86YD('1H92!D
M=6UP(&%R96$N"B`@("`@("`@)&UA:6Y";W@M/G!A8VM?<W1A<G0H)'1H:7,M
M/E]C<F5A=&5297!O<G1!<F5A<R@I*3L*"B`@("`@("`@+R\@1FEN:7-H(&]F
M9B!W:71H('1H92!S=&%T=7,@;&EN92X*("`@("`@("`D;6%I;D)O>"T^<&%C
M:U]S=&%R="@D=&AI<RT^7V-R96%T95-T871U<TQI;F4H*2D["@H@("`@("`@
M("\O($-O;FYE8W0@=&AE(&1E<W1R;WD@<VEG;F%L+@H@("`@("`@("1W:6YD
M;W<M/F-O;FYE8W1?;V)J96-T*"=D97-T<F]Y)RP@87)R87DH)V=T:R<L("=M
M86EN7W%U:70G*2D["@H@("`@("`@("\O($%S<VEG;B!T:&4@;65M8F5R+@H@
M("`@("`@("1T:&ES+3YG=6D@/28@)'=I;F1O=SL*("`@('T*("`@("\J*@H@
M("`@("H@0W)E871E('1H92!M96YU+@H@("`@("H*("`@("`J(%1H92!M96YU
M(&ES('9E<GD@<VEM<&QE+B!)="!A;B!E>&ET(&UE;G4@:71E;2P@=VAI8V@@
M97AI=',*("`@("`J('1H92!A<'!L:6-A=&EO;BP@86YD(&%N(&%B;W5T(&UE
M;G4@:71E;2P@=VAI8V@@<VAO=W,@<V]M90H@("`@("H@8F%S:6,@:6YF;W)M
M871I;VX@86)O=70@=&AE(&%P<&QI8V%T:6]N(&ET<V5L9BX*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!P87)A;2`@;F]N90H@("`@
M("H@0')E='5R;B`F;V)J96-T(%1H92!'=&M-96YU0F%R"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9?8W)E871E365N=2@I"B`@("!["B`@("`@("`@+R\@0W)E
M871E('1H92!M96YU(&)A<BX*("`@("`@("`D;65N=4)A<B`])B!N97<@1W1K
M365N=4)A<CL*"B`@("`@("`@+R\@0W)E871E('1H92!M86EN("AO;FQY*2!M
M96YU(&ET96TN"B`@("`@("`@)'!H<$AE861E<B`])B!N97<@1W1K365N=4ET
M96TH)U!(4%5N:70G*3L*"B`@("`@("`@+R\@061D('1H92!M96YU(&ET96T@
M=&\@=&AE(&UE;G4@8F%R+@H@("`@("`@("1M96YU0F%R+3YA<'!E;F0H)'!H
M<$AE861E<BD["@H@("`@("`@("\O($-R96%T92!T:&4@4$A056YI="!M96YU
M+@H@("`@("`@("1P:'!-96YU(#TF(&YE=R!'=&M-96YU.PH*("`@("`@("`O
M+R!!9&0@=&AE(&UE;G4@:71E;7,*("`@("`@("`D86)O=70@/28@;F5W($=T
M:TUE;G5)=&5M*"=!8F]U="XN+B<I.PH@("`@("`@("1A8F]U="T^8V]N;F5C
M="@G86-T:79A=&4G+"!A<G)A>2@F)'1H:7,L("=A8F]U="<I*3L*("`@("`@
M("`D<&AP365N=2T^87!P96YD*"1A8F]U="D["@H@("`@("`@("1E>&ET(#TF
M(&YE=R!'=&M-96YU271E;2@G17AI="<I.PH@("`@("`@("1E>&ET+3YC;VYN
M96-T7V]B:F5C="@G86-T:79A=&4G+"!A<G)A>2@G9W1K)RP@)VUA:6Y?<75I
M="<I*3L*("`@("`@("`D<&AP365N=2T^87!P96YD*"1E>&ET*3L*"B`@("`@
M("`@+R\@0V]M<&QE=&4@=&AE(&UE;G4N"B`@("`@("`@)'!H<$AE861E<BT^
M<V5T7W-U8FUE;G4H)'!H<$UE;G4I.PH*("`@("`@("!R971U<FX@)&UE;G5"
M87(["B`@("!]"B`@("`O*BH*("`@("`J($-R96%T92!T:&4@<W5I=&4@96YT
M<GD@86YD(')E;&%T960@=VED9V5T<RX*("`@("`J"B`@("`@*B!4:&4@<W5I
M=&4@96YT<GD@:&%S('-O;64@<W5P<&]R=&EN9R!C;VUP;VYE;G1S('-U8V@@
M87,@80H@("`@("H@;&%B96PL('1H92!S:&]W('!A<W-E9"!C:&5C:R!B;W@@
M86YD('1H92!R=6X@8G5T=&]N+B!!;&P*("`@("`J(&]F('1H97-E(&ET96US
M(&%R92!P86-K960@:6YT;R!T=V\@;F5S=&5D(&)O>&5S+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'!A<F%M("!N;VYE"B`@("`@
M*B!`<F5T=7)N("9O8FIE8W0@02!B;W@@=&AA="!C;VYT86EN<R!A;&P@;V8@
M=&AE('-U:71E(&5N=')Y('!I96-E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M)E]C<F5A=&53=6ET945N=')Y*"D*("`@('L*("`@("`@("`O+R!#<F5A=&4@
M=&AE(&]U=&5R;6]S="!B;W@N"B`@("`@("`@)&]U=&5R0F]X("`@("`@("`@
M/28@;F5W($=T:U9";W@["@H@("`@("`@("\O($-R96%T92!T:&4@<W5I=&4@
M;&%B96PL(&)O>"P@86YD(&9I96QD+@H@("`@("`@("1S=6ET94QA8F5L("`@
M("`@(#TF(&YE=R!'=&M,86)E;"@G5&5S="!C;&%S<R!N86UE.B<I.PH@("`@
M("`@("1S=6ET94)O>"`@("`@("`@(#TF(&YE=R!'=&M(0F]X.PH@("`@("`@
M("1T:&ES+3YS=6ET949I96QD(#TF(&YE=R!'=&M%;G1R>3L*("`@("`@("`D
M=&AI<RT^<W5I=&5&:65L9"T^<V5T7W1E>'0H)'-U:71E3F%M92`A/2!.54Q,
M(#\@)'-U:71E3F%M92`Z("<G*3L*"B`@("`@("`@+R\@0W)E871E('1H92!B
M=71T;VX@=&AE('5S97(@=VEL;"!U<V4@=&\@<W1A<G0@=&AE('1E<W0N"B`@
M("`@("`@)')U;D)U='1O;B`])B!N97<@1W1K0G5T=&]N*"=2=6XG*3L*("`@
M("`@("`D<G5N0G5T=&]N+3YC;VYN96-T7V]B:F5C="@G8VQI8VME9"<L(&%R
M<F%Y*"8D=&AI<RP@)W)U;B<I*3L*"B`@("`@("`@+R\@0W)E871E('1H92!C
M:&5C:R!B;W@@=&AA="!L971S('1H92!U<V5R('-H;W<@;VYL>2!F86EL=7)E
M<RX*("`@("`@("`D=&AI<RT^<VAO=U!A<W-E9"`])B!N97<@1W1K0VAE8VM"
M=71T;VXH)U-H;W<@<&%S<V5D('1E<W1S)RD["@H@("`@("`@("\O($%D9"!T
M:&4@8V]M<&]N96YT<R!T;R!T:&5I<B!R97-P96-T:79E(&)O>&5S+@H@("`@
M("`@("1S=6ET94QA8F5L+3YS971?86QI9VYM96YT*#`L(#`I.PH@("`@("`@
M("1O=71E<D)O>"T^<&%C:U]S=&%R="@D<W5I=&5,86)E;"D["B`@("`@("`@
M)&]U=&5R0F]X+3YP86-K7W-T87)T*"1S=6ET94)O>"D["B`@("`@("`@)&]U
M=&5R0F]X+3YP86-K7W-T87)T*"1T:&ES+3YS:&]W4&%S<V5D*3L*"B`@("`@
M("`@)'-U:71E0F]X+3YP86-K7W-T87)T*"1T:&ES+3YS=6ET949I96QD*3L*
M("`@("`@("`D<W5I=&5";W@M/G!A8VM?<W1A<G0H)')U;D)U='1O;BD["@H@
M("`@("`@(')E='5R;B`D;W5T97)";W@["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#<F5A=&4@=&AE(&QA8F5L<R!T:&%T('1E;&P@=&AE('5S97(@=VAA="!H
M87,@:&%P<&5N960N"B`@("`@*@H@("`@("H@5&AE<F4@87)E('1H<F5E(&QA
M8F5L<RP@;VYE(&5A8V@@9F]R('1O=&%L(')U;G,L(&5R<F]R<R!A;F0*("`@
M("`J(&9A:6QU<F5S+B!4:&5R92!I<R!A;'-O(&]N92!L86)E;"!F;W(@96%C
M:"!O9B!T:&5S92!T:&%T"B`@("`@*B!D97-C<FEB97,@=VAA="!T:&4@;&%B
M96P@:7,N($ET(&-O=6QD(&)E(&1O;F4@=VET:"!O;F4@;&%B96P*("`@("`J
M(&EN<W1E860@;V8@='=O(&)U="!T:&%T('=O=6QD(&UA:V4@=7!D871E<R!M
M=6-H(&AA<F1E<BX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J($!P87)A;2`@;F]N90H@("`@("H@0')E='5R;B`F;V)J96-T($$@8F]X
M(&-O;G1A:6YI;F<@=&AE(&QA8F5L<RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M)E]C<F5A=&5297!O<G1,86)E;',H*0H@("`@>PH@("`@("`@("\O($-R96%T
M92!A(&)O>"!T;R!H;VQD(&5V97)Y=&AI;F<N"B`@("`@("`@)&QA8F5L0F]X
M("`@("`@("`@/28@;F5W($=T:TA";W@["@H@("`@("`@("\O($-R96%T92!T
M:&4@;F]N+75P9&%T960@;&%B96QS+@H@("`@("`@("1N=6UB97)/9E)U;G,@
M("`@(#TF(&YE=R!'=&M,86)E;"@G4G5N<SHG*3L*("`@("`@("`D;G5M8F5R
M3V9%<G)O<G,@("`])B!N97<@1W1K3&%B96PH)T5R<F]R<SHG*3L*("`@("`@
M("`D;G5M8F5R3V9&86EL=7)E<R`])B!N97<@1W1K3&%B96PH)T9A:6QU<F5S
M.B<I.PH*("`@("`@("`O+R!#<F5A=&4@=&AE(&QA8F5L<R!T:&%T('=I;&P@
M8F4@=7!D871E9"X*("`@("`@("`O+R!4:&5S92!A<F4@87-S<VEG;F5D('1O
M(&UE;6)E<G,@=&\@;6%K92!I="!E87-I97(@=&\*("`@("`@("`O+R!S970@
M=&AE:7(@=F%L=65S(&QA=&5R+@H@("`@("`@("1T:&ES+3YN=6UB97)/9E)U
M;G,@("`@(#TF(&YE=R!'=&M,86)E;"@P*3L*("`@("`@("`D=&AI<RT^;G5M
M8F5R3V9%<G)O<G,@("`])B!N97<@1W1K3&%B96PH,"D["B`@("`@("`@)'1H
M:7,M/FYU;6)E<D]F1F%I;'5R97,@/28@;F5W($=T:TQA8F5L*#`I.PH*("`@
M("`@("`O+R!086-K(&5V97)Y=&AI;F<@:6XN"B`@("`@("`@)&QA8F5L0F]X
M+3YP86-K7W-T87)T*"1N=6UB97)/9E)U;G,I.PH@("`@("`@("1L86)E;$)O
M>"T^<&%C:U]S=&%R="@D=&AI<RT^;G5M8F5R3V92=6YS*3L*("`@("`@("`D
M;&%B96Q";W@M/G!A8VM?<W1A<G0H)&YU;6)E<D]F17)R;W)S*3L*("`@("`@
M("`D;&%B96Q";W@M/G!A8VM?<W1A<G0H)'1H:7,M/FYU;6)E<D]F17)R;W)S
M*3L*("`@("`@("`D;&%B96Q";W@M/G!A8VM?<W1A<G0H)&YU;6)E<D]F1F%I
M;'5R97,I.PH@("`@("`@("1L86)E;$)O>"T^<&%C:U]S=&%R="@D=&AI<RT^
M;G5M8F5R3V9&86EL=7)E<RD["@H@("`@("`@(')E='5R;B`D;&%B96Q";W@[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@=&AE('-U8V-E<W,O9F%I
M;'5R92!I;F1I8V%T;W(N"B`@("`@*@H@("`@("H@02!'=&M0<F]G<F5S<T)A
M<B!I<R!U<V5D('1O('9I<W5A;&QY(&EN9&EC871E(&AO=R!M86YY"B`@("`@
M*B!T97-T<R!W97)E('-U8V-E<W-F=6P@8V]M<&%R960@=&\@:&]W(&UA;GD@
M=V5R92!N;W0N(%1H90H@("`@("H@<')O9W)E<W,@8F%R('-H;W=S('1H92!P
M97)C96YT86=E(&]F('-U8V-E<W,@86YD('=I;&P*("`@("`J(&-H86YG92!F
M<F]M(&=R965N('1O(')E9"!I9B!T:&5R92!A<F4@86YY(&9A:6QU<F5S+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'!A<F%M("!N
M;VYE"B`@("`@*B!`<F5T=7)N("9O8FIE8W0@5&AE('!R;V=R97-S(&)A<@H@
M("`@("HO"B`@("!F=6YC=&EO;B`F7V-R96%T95!R;V=R97-S0F%R*"D*("`@
M('L*("`@("`@("`O+R!#<F5A=&4@=&AE('!R;V=R97-S(&)A<BX*("`@("`@
M("`D=&AI<RT^<')O9W)E<W,@/28@;F5W($=T:U!R;V=R97-S0F%R*&YE=R!'
M=&M!9&IU<W1M96YT*#`L(#`L(#$L("XQ+"`Q+"`P*2D["@H@("`@("`@("\O
M(%-E="!T:&4@<')O9W)E<W,@8F%R('1O('!R:6YT('1H92!P97)C96YT86=E
M+@H@("`@("`@("1T:&ES+3YP<F]G<F5S<RT^<V5T7W-H;W=?=&5X="AT<G5E
M*3L*"B`@("`@("`@<F5T=7)N("1T:&ES+3YP<F]G<F5S<SL*("`@('T*"B`@
M("`O*BH*("`@("`J($-R96%T92!T:&4@<F5P;W)T('1E>'0@87)E87,N"B`@
M("`@*@H@("`@("H@5&AE(')E<&]R="!A<F5A(&-O;G-I<W1S(&]F(&]N92!T
M97AT(&%R96$@9F]R(&9A:6QU<F5S+"!O;F4*("`@("`J('1E>'0@87)E82!F
M;W(@97)R;W)S(&%N9"!O;F4@;&%B96P@9F]R(&ED96YT:69I8V%T:6]N('!U
M<G!O<V5S+@H@("`@("H@06QL('1H<F5E('=I9&=E=',@87)E('!A8VME9"!I
M;G1O(&$@8F]X+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H@0'!A<F%M("!N;VYE"B`@("`@*B!`<F5T=7)N("9O8FIE8W0@5&AE(&)O
M>"!C;VYT86EN:6YG('1H92!R97!O<G0@87)E87,N"B`@("`@*B\*("`@(&9U
M;F-T:6]N("9?8W)E871E4F5P;W)T07)E87,H*0H@("`@>PH@("`@("`@("\O
M($-R96%T92!T:&4@8V]N=&%I;FEN9R!B;W@N"B`@("`@("`@)')E<&]R=$)O
M>"`])B!N97<@1W1K5D)O>#L*"B`@("`@("`@+R\@0W)E871E('1H92!I9&5N
M=&EF:6-A=&EO;B!L86)E;`H@("`@("`@("1R97!O<G1,86)E;"`])B!N97<@
M1W1K3&%B96PH)T5R<F]R<R!A;F0@1F%I;'5R97,Z)RD["B`@("`@("`@)')E
M<&]R=$QA8F5L+3YS971?86QI9VYM96YT*#`L(#`I.PH*("`@("`@("`O+R!#
M<F5A=&4@=&AE('-C<F]L;&5D('=I;F1O=W,@9F]R('1H92!T97AT(&%R96%S
M+@H@("`@("`@("1R97!O<G138W)O;&P@/28@;F5W($=T:U-C<F]L;&5D5VEN
M9&]W.PH@("`@("`@("1D=6UP4V-R;VQL("`@/28@;F5W($=T:U-C<F]L;&5D
M5VEN9&]W.PH*("`@("`@("`O+R!-86ME('1H92!S8W)O;&P@87)E87,@8FEG
M(&5N;W5G:"X*("`@("`@("`D<F5P;W)T4V-R;VQL+3YS971?=7-I>F4H+3$L
M(#$U,"D["B`@("`@("`@)&1U;7!38W)O;&PM/G-E=%]U<VEZ92@M,2P@,34P
M*3L*"B`@("`@("`@+R\@3VYL>2!S:&]W('1H92!V97)T:6-A;"!S8W)O;&P@
M8F%R('=H96X@;F5E9&5D+@H@("`@("`@("\O($YE=F5R('-H;W<@=&AE(&AO
M<FEZ;VYT86P@<V-R;VQL(&)A<BX*("`@("`@("`D<F5P;W)T4V-R;VQL+3YS
M971?<&]L:6-Y*$=42U]03TQ)0UE?3D5615(L($=42U]03TQ)0UE?05543TU!
M5$E#*3L*("`@("`@("`D9'5M<%-C<F]L;"T^<V5T7W!O;&EC>2A'5$M?4$],
M24-97TY%5D52+"!'5$M?4$],24-97T%55$]-051)0RD["@H@("`@("`@("\O
M($-R96%T92!T:&4@=&5X="!A<F5A<RX*("`@("`@("`D=&AI<RT^<F5P;W)T
M07)E82`])B!N97<@1W1K5&5X=#L*("`@("`@("`D=&AI<RT^9'5M<$%R96$@
M/28@;F5W($=T:U1E>'0["@H@("`@("`@("\O($1O;B=T(&QE="!W;W)D<R!G
M970@8G)O:V5N+@H@("`@("`@("1T:&ES+3YR97!O<G1!<F5A+3YS971?=V]R
M9%]W<F%P*'1R=64I.PH@("`@("`@("1T:&ES+3YD=6UP07)E82T^<V5T7W=O
M<F1?=W)A<"AT<G5E*3L*"B`@("`@("`@+R\@4&%C:R!E=F5R>71H:6YG(&EN
M+@H@("`@("`@("1R97!O<G1";W@M/G!A8VM?<W1A<G0H)')E<&]R=$QA8F5L
M*3L*("`@("`@("`D<F5P;W)T4V-R;VQL+3YA9&0H)'1H:7,M/G)E<&]R=$%R
M96$I.PH@("`@("`@("1R97!O<G1";W@M/G!A8VM?<W1A<G0H)')E<&]R=%-C
M<F]L;"D["B`@("`@("`@)&1U;7!38W)O;&PM/F%D9"@D=&AI<RT^9'5M<$%R
M96$I.PH@("`@("`@("1R97!O<G1";W@M/G!A8VM?<W1A<G0H)&1U;7!38W)O
M;&PI.PH*("`@("`@("!R971U<FX@)')E<&]R=$)O>#L*("`@('T*"B`@("`O
M*BH*("`@("`J($-R96%T92!A('-T871U<R!L86)E;"X*("`@("`J"B`@("`@
M*B!!('-T871U<R!L:6YE(&%T('1H92!B;W1T;VT@;V8@=&AE(&%P<&QI8V%T
M:6]N(&ES('5S960*("`@("`J('1O(&YO=&EF>2!T:&4@=7-E<B!O9B!N;VXM
M=&5S="!R96QA=&5D(&UE<W-A9V5S('-U8V@@87,*("`@("`J(&9A:6QU<F5S
M(&QO861I;F<@82!T97-T('-U:71E+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H@0'!A<F%M("!N;VYE"B`@("`@*B!`<F5T=7)N("9O
M8FIE8W0@5&AE('-T871U<R!L86)E;"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M)E]C<F5A=&53=&%T=7-,:6YE*"D*("`@('L*("`@("`@("`O+R!#<F5A=&4@
M=&AE('-T871U<R!L86)E;"X*("`@("`@("`D=&AI<RT^<W1A='5S3&EN92`]
M)B!N97<@1W1K3&%B96PH)R<I.PH@("`@("`@("1T:&ES+3YS=&%T=7-,:6YE
M+3YS971?86QI9VYM96YT*#`L(#`I.PH*("`@("`@("!R971U<FX@)'1H:7,M
M/G-T871U<TQI;F4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3:&]W(&$@<&]P
M=7`@=VET:"!I;F9O<FUA=&EO;B!A8F]U="!T:&4@87!P;&EC871I;VXN"B`@
M("`@*@H@("`@("H@5&AE('!O<'5P('-H;W5L9"!S:&]W(&EN9F]R;6%T:6]N
M(&%B;W5T('1H92!V97)S:6]N+`H@("`@("H@=&AE(&%U=&AO<BP@=&AE(&QI
M8V5N<V4L('=H97)E('1O(&=E="!T:&4@;&%T97-T"B`@("`@*B!V97)S:6]N
M(&%N9"!A('-H;W)T(&1E<V-R:7!T:6]N+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@(&YO;F4*("`@("`J($!R971U<FX@
M=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@
M("`@+R\@0W)E871E('1H92!N97<@=VEN9&]W+@H@("`@("`@("1A8F]U="`]
M)B!N97<@1W1K5VEN9&]W.PH@("`@("`@("1A8F]U="T^<V5T7W1I=&QE*"=!
M8F]U="!02%!5;FET($=522!'=&LG*3L*("`@("`@("`D86)O=70M/G-E=%]U
M<VEZ92@R-3`L("TQ*3L*"B`@("`@("`@+R\@4'5T('1W;R!V8F]X97,@:6X@
M=&AE(&AB;W@N"B`@("`@("`@)'9";W@@/28@;F5W($=T:U9";W@["B`@("`@
M("`@)&%B;W5T+3YA9&0H)'9";W@I.PH*("`@("`@("`O+R!#<F5A=&4@=&AE
M(&QA8F5L<RX*("`@("`@("`D=F5R<VEO;B`@("`@/28@;F5W($=T:TQA8F5L
M*"(@5F5R<VEO;CH@,2XP(BD["B`@("`@("`@)&QI8V5N<V4@("`@(#TF(&YE
M=R!'=&M,86)E;"@B($QI8V5N<V4Z(%!(4"!,:6-E;G-E('8S+C`B*3L*("`@
M("`@("`D=VAE<F4@("`@("`@/28@;F5W($=T:TQA8F5L*"(@1&]W;FQO860@
M9G)O;3H@:'1T<#HO+W!E87(N<&AP+FYE="]02%!5;FET+R(I.PH@("`@("`@
M("1U;FET075T:"`@("`])B!N97<@1W1K3&%B96PH(B!02%!5;FET($%U=&AO
M<CH@4V5B87-T:6%N($)E<F=M86XB*3L*("`@("`@("`D9W1K075T:"`@("`@
M/28@;F5W($=T:TQA8F5L*"(@1W1K($=522!!=71H;W(Z(%-C;W1T($UA='1O
M8VMS(BD["@H@("`@("`@("\O($%L:6=N(&5V97)Y=&AI;F<@=&\@=&AE(&QE
M9G0*("`@("`@("`D=VAE<F4M/G-E=%]A;&EG;FUE;G0H,"P@+C4I.PH@("`@
M("`@("1V97)S:6]N+3YS971?86QI9VYM96YT*#`L("XU*3L*("`@("`@("`D
M;&EC96YS92T^<V5T7V%L:6=N;65N="@P+"`N-2D["B`@("`@("`@)&=T:T%U
M=&@M/G-E=%]A;&EG;FUE;G0H,"P@+C4I.PH@("`@("`@("1U;FET075T:"T^
M<V5T7V%L:6=N;65N="@P+"`N-2D["@H@("`@("`@("\O(%!A8VL@979E<GET
M:&EN9R!I;G1O('1H92!V0F]X.PH@("`@("`@("1V0F]X+3YP86-K7W-T87)T
M*"1V97)S:6]N*3L*("`@("`@("`D=D)O>"T^<&%C:U]S=&%R="@D;&EC96YS
M92D["B`@("`@("`@)'9";W@M/G!A8VM?<W1A<G0H)'=H97)E*3L*("`@("`@
M("`D=D)O>"T^<&%C:U]S=&%R="@D=6YI=$%U=&@I.PH@("`@("`@("1V0F]X
M+3YP86-K7W-T87)T*"1G=&M!=71H*3L*"B`@("`@("`@+R\@0V]N;F5C="!T
M:&4@9&5S=')O>2!S:6=N86PN"B`@("`@("`@)&%B;W5T+3YC;VYN96-T*"=D
M97-T<F]Y)RP@87)R87DH)V=T:R<L("=T<G5E)RDI.PH*("`@("`@("`O+R!3
M:&]W('1H92!G;V]D<RX*("`@("`@("`D86)O=70M/G-H;W=?86QL*"D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!,;V%D('1H92!T97-T('-U:71E+@H@("`@
M("H*("`@("`J(%1H:7,@;65T:&]D('1R:65S('1O(&QO860@=&5S="!S=6ET
M92!B87-E9"!O;B!T:&4@=7-E<@H@("`@("H@:6YF;RX@268@=&AE('5S97(@
M<&%S<V5S('1H92!N86UE(&]F(&$@=&5S=',@<W5I=&4L(&ET"B`@("`@*B!I
M<R!I;G-T86YT:6%T960@86YD(&$@;F5W(&]B:F5C="!I<R!R971U<FYE9"X@
M268@=&AE"B`@("`@*B!U<V5R('!A<W-E<R!A(&9I;&4@=&AA="!C;VYT86EN
M<R!A('1E<W0@<W5I=&4L('1H92!C;&%S<PH@("`@("H@:7,@:6YS=&%N=&EA
M=&5D(&%N9"!A(&YE=R!O8FIE8W0@:7,@<F5T=7)N960N($EF('1H92!U<V5R
M"B`@("`@*B!P87-S97,@82!F:6QE('1H870@8V]N=&%I;G,@82!T97-T(&-A
M<V4L('1H92!T97-T(&-A<V4@:7,*("`@("`J('!A<W-E9"!T;R!A(&YE=R!T
M97-T('-U:71E(&%N9"!T:&4@;F5W('-U:71E(&]B:F5C="!I<PH@("`@("H@
M<F5T=7)N960N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M($!P87)A;2`@<W1R:6YG("!4:&4@9FEL92!T:&%T(&-O;G1A:6YS(&$@=&5S
M="!C87-E+W-U:71E(&]R('1H92!C;&%S<VYA;64N"B`@("`@*B!`<F5T=7)N
M("9O8FIE8W0@5&AE(&YE=R!T97-T('-U:71E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B`F;&]A9%1E<W0H)B1F:6QE*0H@("`@>PH@("`@("`@("\O($-H96-K
M('1O('-E92!I9B!A(&-L87-S(&YA;64@=V%S(&=I=F5N+@H@("`@("`@(&EF
M("AI<U]A*"1F:6QE+"`G4$A056YI=%]497-T4W5I=&4G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)&9I;&4["B`@("`@("`@?2!E;'-E:68@*&-L87-S7V5X
M:7-T<R@D9FEL92DI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=02%!5
M;FET+U1E<W13=6ET92YP:'`G.PH@("`@("`@("`@("!R971U<FX@;F5W(%!(
M4%5N:71?5&5S=%-U:71E*"1F:6QE*3L*("`@("`@("!]"@H@("`@("`@("\O
M($-H96-K('1H870@=&AE(&9I;&4@97AI<W1S+@H@("`@("`@(&EF("@A0&ES
M7W)E861A8FQE*"1F:6QE*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W-H;W=3
M=&%T=7,H)T-A;FYO="!F:6YD(&9I;&4Z("<@+B`D9FEL92D["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?
M<VAO=U-T871U<R@G3&]A9&EN9R!T97-T('-U:71E+BXN)RD["@H@("`@("`@
M("\O($EN<W1A;G1I871E('1H92!C;&%S<RX*("`@("`@("`O+R!)9B!T:&4@
M<&%T:"!I<R`O<&%T:"]T;R]T97-T+U1E<W1#;&%S<RYP:'`*("`@("`@("`O
M+R!T:&4@8VQA<W,@;F%M92!S:&]U;&0@8F4@=&5S=%]497-T0VQA<W,*("`@
M("`@("!R97%U:7)E7V]N8V4@)&9I;&4["B`@("`@("`@)&-L87-S3F%M92`]
M('-T<E]R97!L86-E*$1)4D5#5$]265]315!!4D%43U(L("=?)RP@)&9I;&4I
M.PH@("`@("`@("1C;&%S<TYA;64@/2!S=6)S='(H)&-L87-S3F%M92P@,"P@
M<W1R<&]S*"1C;&%S<TYA;64L("<N)RDI.PH*("`@("`@("!R97%U:7)E7V]N
M8V4@)U!(4%5N:70O5&5S=%-U:71E+G!H<"<["B`@("`@("`@<F5T=7)N(&YE
M=R!02%!5;FET7U1E<W13=6ET92@D8VQA<W-.86UE*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)U;B!T:&4@=&5S="!S=6ET92X*("`@("`J"B`@("`@*B!4
M:&ES(&UE=&AO9"!R=6YS('1H92!T97-T('-U:71E(&%N9"!U<&1A=&5S('1H
M92!M97-S86=E<PH@("`@("H@9F]R('1H92!U<V5R+B!7:&5N(&9I;FES:&5D
M(&ET(&-H86YG97,@=&AE('-T871U<R!L:6YE"B`@("`@*B!T;R`G5&5S="!#
M;VUP;&5T92<*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@
M0'!A<F%M("!N;VYE"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@
M9G5N8W1I;VX@<G5N5&5S="@I"B`@("!["B`@("`@("`@+R\@3F]T:69Y('1H
M92!U<V5R('1H870@=&AE('1E<W0@:7,@<G5N;FEN9RX*("`@("`@("`D=&AI
M<RT^7W-H;W=3=&%T=7,H)U)U;FYI;F<@5&5S="XN+B<I.PH*("`@("`@("`O
M+R!2=6X@=&AE('1E<W0N"B`@("`@("`@)')E<W5L="`](%!(4%5N:70Z.G)U
M;B@D=&AI<RT^<W5I=&4I.PH*("`@("`@("`O+R!5<&1A=&4@=&AE(&QA8F5L
M<RX*("`@("`@("`D=&AI<RT^7W-E=$QA8F5L5F%L=64H)'1H:7,M/FYU;6)E
M<D]F4G5N<RP@("`@("1R97-U;'0M/G)U;D-O=6YT*"DI.PH@("`@("`@("1T
M:&ES+3Y?<V5T3&%B96Q686QU92@D=&AI<RT^;G5M8F5R3V9%<G)O<G,L("`@
M)')E<W5L="T^97)R;W)#;W5N="@I*3L*("`@("`@("`D=&AI<RT^7W-E=$QA
M8F5L5F%L=64H)'1H:7,M/FYU;6)E<D]F1F%I;'5R97,L("1R97-U;'0M/F9A
M:6QU<F5#;W5N="@I*3L*"B`@("`@("`@+R\@57!D871E('1H92!P<F]G<F5S
M<R!B87(N"B`@("`@("`@)'1H:7,M/E]U<&1A=&50<F]G<F5S<R@D<F5S=6QT
M+3YR=6Y#;W5N="@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)')E<W5L="T^97)R;W)#;W5N="@I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)')E<W5L="T^9F%I;'5R94-O=6YT*"D*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("D["@H@("`@("`@("\O(%-H;W<@=&AE(&5R
M<F]R<RX*("`@("`@("`D=&AI<RT^7W-H;W=&86EL=7)E<R@D<F5S=6QT+3YE
M<G)O<G,H*2P@)'1H:7,M/F1U;7!!<F5A*3L*"B`@("`@("`@+R\@4VAO=R!T
M:&4@;65S<V%G97,@9G)O;2!T:&4@=&5S=',N"B`@("`@("`@:68@*"1T:&ES
M+3YS:&]W4&%S<V5D+3YG971?86-T:79E*"DI('L*("`@("`@("`@("`@+R\@
M4VAO=R!F86EL=7)E<R!A;F0@<W5C8V5S<RX*("`@("`@("`@("`@)'1H:7,M
M/E]S:&]W06QL*"1R97-U;'0L("1T:&ES+3YR97!O<G1!<F5A*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`O+R!3:&]W(&]N;'D@9F%I;'5R97,N
M"B`@("`@("`@("`@("1T:&ES+3Y?<VAO=T9A:6QU<F5S*"1R97-U;'0M/F9A
M:6QU<F5S*"DL("1T:&ES+3YR97!O<G1!<F5A*3L*("`@("`@("!]"@H@("`@
M("`@("\O(%5P9&%T92!T:&4@<W1A='5S(&UE<W-A9V4N"B`@("`@("`@)'1H
M:7,M/E]S:&]W4W1A='5S*"=497-T(&-O;7!L971E)RD["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!3970@=&AE('1E>'0@;V8@82!L86)E;"X*("`@("`J"B`@
M("`@*B!#:&%N9V4@=&AE('1E>'0@;V8@82!G:79E;B!L86)E;"X*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!P87)A;2`@=VED9V5T
M("`F)&QA8F5L(%1H92!L86)E;"!W:&]S92!V86QU92!I<R!T;R!B92!C:&%N
M9V5D+@H@("`@("H@0'!A<F%M("!S=')I;F<@("1V86QU92`@5&AE(&YE=R!T
M97AT(&]F('1H92!L86)E;"X*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO
M"B`@("!F=6YC=&EO;B!?<V5T3&%B96Q686QU92@F)&QA8F5L+"`D=F%L=64I
M"B`@("!["B`@("`@("`@)&QA8F5L+3YS971?=&5X="@D=F%L=64I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@5&AE(&UA:6X@=V]R:R!O9B!T:&4@87!P;&EC
M871I;VXN"B`@("`@*@H@("`@("H@3&]A9"!T:&4@=&5S="!S=6ET92!A;F0@
M=&AE;B!E>&5C=71E('1H92!T97-T<RX*("`@("`J"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("H@0'!A<F%M("!N;VYE"B`@("`@*B!`<F5T=7)N('9O
M:60*("`@("`J+PH@("`@9G5N8W1I;VX@<G5N*"D*("`@('L*("`@("`@("`O
M+R!,;V%D('1H92!T97-T('-U:71E+@H@("`@("`@("1T:&ES+3YS=6ET92`]
M)B`D=&AI<RT^;&]A9%1E<W0H)'1H:7,M/G-U:71E1FEE;&0M/F=E=%]T97AT
M*"DI.PH*("`@("`@("`O+R!#:&5C:R!T;R!M86ME('-U<F4@=&AE('-U:71E
M('=A<R!L;V%D960@<')O<&5R;'DN"B`@("`@("`@:68@*"%I<U]O8FIE8W0H
M)'1H:7,M/G-U:71E*2D@>PH@("`@("`@("`@("`O+R!286ES92!A;B!E<G)O
M<BX*("`@("`@("`@("`@)'1H:7,M/E]S:&]W4W1A='5S*"=#;W5L9"!N;W0@
M;&]A9"!T97-T('-U:71E+B<I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H*("`@("`@("`O+R!2=6X@=&AE('1E<W1S+@H@("`@("`@
M("1T:&ES+3YR=6Y497-T*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!5<&1A
M=&4@=&AE('-T871U<R!M97-S86=E+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H@0'!A<F%M("!S=')I;F<@("1S=&%T=7,@5&AE(&YE
M=R!M97-S86=E+@H@("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]S:&]W4W1A='5S*"1S=&%T=7,I"B`@("!["B`@("`@("`@)'1H
M:7,M/G-T871U<TQI;F4M/G-E=%]T97AT*"1S=&%T=7,I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@06QI87,@9F]R(&UA:6XH*0H@("`@("H*("`@("`J($!S
M964@;6%I;@H@("`@("HO"B`@("!F=6YC=&EO;B!S:&]W*"1S:&]W4&%S<V5D
M(#T@=')U92D*("`@('L*("`@("`@("`D=&AI<RT^;6%I;B@D<VAO=U!A<W-E
M9"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@82!S=6ET92!T;R!T:&4@
M=&5S=',N"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@:7,@<F5Q=6ER92!B
M>2!3971U<$1E8V]R871O<BX@270@861D<R!A"B`@("`@*B!S=6ET92!T;R!T
M:&4@=&AE(&-U<G)E;G0@<V5T(&]F('-U:71E<RX*("`@("`J"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M("!O8FIE8W0@)'1E<W13=6ET
M92!4:&4@<W5I=&4@=&\@861D+@H@("`@("H@0')E='5R;B!V;VED"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&%D9%-U:71E<R@D=&5S=%-U:71E*0H@("`@>PH@
M("`@("`@(&EF("@A:7-?87)R87DH)'1E<W13=6ET92DI('L*("`@("`@("`@
M("`@<V5T='EP92@D=&5S=%-U:71E+"`G87)R87DG*3L*("`@("`@("!]"@H@
M("`@("`@(&9O<F5A8V@@*"1T97-T4W5I=&4@87,@)'-U:71E*2!["@H@("`@
M("`@("`@("!I9B`H:7-?82@D=&AI<RT^<W5I=&4L("=02%!5;FET7U1E<W13
M=6ET92<I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<W5I=&4M/F%D9%1E
M<W13=6ET92@D<W5I=&4M/F=E=$YA;64H*2D["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D=&AI<RT^<W5I=&4@/28@)'1H:7,M/FQO
M861497-T*"1S=6ET92D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O
M(%-E="!T:&4@<W5I=&4@9FEE;&0N"B`@("`@("`@("`@("1T97AT(#T@)'1H
M:7,M/G-U:71E1FEE;&0M/F=E=%]T97AT*"D["B`@("`@("`@("`@(&EF("AE
M;7!T>2@D=&5X="DI('L*("`@("`@("`@("`@("`@("1T:&ES+3YS=6ET949I
M96QD+3YS971?=&5X="@D=&AI<RT^<W5I=&4M/F=E=$YA;64H*2D["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3:&]W
M(&%L;"!T97-T(&UE<W-A9V5S+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H@0'!A<F%M("!O8FIE8W0@(%1H92!497-T4F5S=6QT(&9R
M;VT@=&AE('1E<W0@<W5I=&4N"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J
M+PH@("`@9G5N8W1I;VX@7W-H;W=!;&PH)B1R97-U;'0I"B`@("!["B`@("`@
M("`@+R\@0VQE87(@=&AE(&%R96$@9FER<W0N"B`@("`@("`@)'1H:7,M/G)E
M<&]R=$%R96$M/F1E;&5T95]T97AT*#`L("TQ*3L*("`@("`@("`D=&AI<RT^
M<F5P;W)T07)E82T^:6YS97)T7W1E>'0H)')E<W5L="T^=&]3=')I;F<H*2P@
M,"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3:&]W(&9A:6QU<F4O97)R;W(@
M;65S<V%G97,@:6X@=&AE(&=I=F5N('1E>'0@87)E82X*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J($!P87)A;2`@;V)J96-T("`F)')E
M<W5L=',@5&AE(')E<W5L=',@;V8@=&AE('1E<W0N"B`@("`@*B!`<&%R86T@
M('=I9&=E="`@)B1A<F5A("`@(%1H92!A<F5A('1O('-H;W<@=&AE(')E<W5L
M=',@:6XN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S:&]W1F%I;'5R97,H)B1R
M97-U;'1S+"`F)&%R96$I"B`@("!["B`@("`@("`@)&%R96$M/F1E;&5T95]T
M97AT*#`L("TQ*3L*("`@("`@("!F;W)E86-H("AA<G)A>5]R979E<G-E*"1R
M97-U;'1S+"!T<G5E*2!A<R`D<F5S=6QT*2!["B`@("`@("`@("`@("1A<F5A
M+3YI;G-E<G1?=&5X="@D<F5S=6QT+3YT;U-T<FEN9R@I+"`P*3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!5<&1A=&4@=&AE('!R;V=R97-S
M(&EN9&EC871O<BX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J($!P87)A;2`@:6YT96=E<B`D<G5N<PH@("`@("H@0'!A<F%M("!I;G1E
M9V5R("1E<G)O<G,*("`@("`J($!P87)A;2`@:6YT96=E<B`D9F%I;'5R97,*
M("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!?=7!D
M871E4')O9W)E<W,H)')U;G,L("1E<G)O<G,L("1F86EL=7)E<RD*("`@('L*
M("`@("`@("`D<&5R8V5N=&%G92`](#$@+2`H*"1E<G)O<G,@*R`D9F%I;'5R
M97,I("\@)')U;G,I.PH@("`@("`@("1T:&ES+3YP<F]G<F5S<RT^<V5T7W!E
M<F-E;G1A9V4H)'!E<F-E;G1A9V4I.PH@("`@?0I]"@HO*@H@*B!,;V-A;"!V
M87)I86)L97,Z"B`J('1A8BUW:61T:#H@-`H@*B!C+6)A<VEC+6]F9G-E=#H@
M-`H@*B!C+6AA;F=I;F<M8V]M;65N="UE;F1E<BUP.B!N:6P*("H@16YD.@H@
M*B\*/SX*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]02%!5;FET+U)E<&5A=&5D5&5S="YP:'``````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$P-C(R(#$P-3$U-#,S-S,Q
M(#`R,S`U-@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H
M:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J(%!(4"!697)S
M:6]N(#0*("H*("H@0V]P>7)I9VAT("AC*2`R,#`R+3(P,#4L(%-E8F%S=&EA
M;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/BX*("H@06QL
M(')I9VAT<R!R97-E<G9E9"X*("H*("H@4F5D:7-T<FEB=71I;VX@86YD('5S
M92!I;B!S;W5R8V4@86YD(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T
M"B`J(&UO9&EF:6-A=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T
M('1H92!F;VQL;W=I;F<@8V]N9&ET:6]N<PH@*B!A<F4@;65T.@H@*@H@*B`@
M("H@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN
M('1H92!A8F]V92!C;W!Y<FEG:'0*("H@("`@(&YO=&EC92P@=&AI<R!L:7-T
M(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX*
M("H@"B`J("`@*B!2961I<W1R:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S
M="!R97!R;V1U8V4@=&AE(&%B;W9E(&-O<'ER:6=H=`H@*B`@("`@;F]T:6-E
M+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D
M:7-C;&%I;65R(&EN"B`J("`@("!T:&4@9&]C=6UE;G1A=&EO;B!A;F0O;W(@
M;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE"B`J("`@("!D:7-T
M<FEB=71I;VXN"B`J"B`J("`@*B!.96ET:&5R('1H92!N86UE(&]F(%-E8F%S
M=&EA;B!"97)G;6%N;B!N;W(@=&AE(&YA;65S(&]F(&AI<PH@*B`@("`@8V]N
M=')I8G5T;W)S(&UA>2!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92!P
M<F]D=6-T<R!D97)I=F5D"B`J("`@("!F<F]M('1H:7,@<V]F='=A<F4@=VET
M:&]U="!S<&5C:69I8R!P<FEO<B!W<FET=&5N('!E<FUI<W-I;VXN"B`J"B`J
M(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($-/4%E224=(5"!(
M3TQ$15)3($%.1"!#3TY44DE"551/4E,*("H@(D%3($E3(B!!3D0@04Y9($58
M4%)%4U,@3U(@24U03$E%1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.
M3U0*("H@3$E-251%1"!43RP@5$A%($E-4$Q)140@5T%24D%.5$E%4R!/1B!-
M15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,*("H@1D]2($$@4$%25$E#54Q!
M4B!055)03U-%($%212!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!4
M2$4*("H@0T]065))1TA4($]73D52($]2($-/3E1224)55$]24R!"12!,24%"
M3$4@1D]2($%.62!$25)%0U0L($E.1$E214-4+`H@*B!)3D-)1$5.5$%,+"!3
M4$5#24%,+"!%6$5-4$Q!4EDL($]2($-/3E-%455%3E1)04P@1$%-04=%4R`H
M24Y#3%5$24Y'+`H@*B!"550@3D]4($Q)34E4140@5$\L(%!23T-54D5-14Y4
M($]&(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,["B`J($Q/4U,@3T8@
M55-%+"!$051!+"!/4B!04D]&2513.R!/4B!"55-)3D534R!)3E1%4E)54%1)
M3TXI($A/5T5615(*("H@0T%54T5$($%.1"!/3B!!3ED@5$A%3U)9($]&($Q)
M04))3$E462P@5TA%5$A%4B!)3B!#3TY44D%#5"P@4U1224,*("H@3$E!0DE,
M2519+"!/4B!43U)4("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)
M4T4I($%225-)3D<@24X*("H@04Y9(%=!62!/550@3T8@5$A%(%5312!/1B!4
M2$E3(%-/1E1705)%+"!%5D5.($E&($%$5DE3140@3T8@5$A%"B`J(%!/4U-)
M0DE,2519($]&(%-50T@@1$%-04=%+@H@*@H@*B!`8V%T96=O<GD@("!497-T
M:6YG"B`J($!P86-K86=E("`@(%!(4%5N:70*("H@0&%U=&AO<B`@("`@4V5B
M87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^"B`J
M($!C;W!Y<FEG:'0@(#(P,#(M,C`P-2!396)A<W1I86X@0F5R9VUA;FX@/'-B
M0'-E8F%S=&EA;BUB97)G;6%N;BYD93X*("H@0&QI8V5N<V4@("`@:'1T<#HO
M+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@
M($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!297!E871E
M9%1E<W0N<&AP+'8@,2XQ,R`R,#`U+S$Q+S$P(#`Y.C0W.C$T('-E8F%S=&EA
M;B!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A
M8VMA9V4O4$A056YI=`H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S
M:6YC92!296QE87-E(#$N,"XP"B`J+PH*<F5Q=6ER95]O;F-E("=02%!5;FET
M+U1E<W1$96-O<F%T;W(N<&AP)SL*"B\J*@H@*B!!($1E8V]R871O<B!T:&%T
M(')U;G,@82!T97-T(')E<&5A=&5D;'DN"B`J"B`J($AE<F4@:7,@86X@97AA
M;7!L93H*("H*("H@/&-O9&4^"B`J(#P_<&AP"B`J(')E<75I<F5?;VYC92`G
M4$A056YI="YP:'`G.PH@*B!R97%U:7)E7V]N8V4@)U!(4%5N:70O4F5P96%T
M961497-T+G!H<"<["B`J"B`J(&-L87-S($UA=&A497-T(&5X=&5N9',@4$A0
M56YI=%]497-T0V%S92!["B`J("`@("!V87(@)&9686QU93$["B`J("`@("!V
M87(@)&9686QU93(["B`J"B`J("`@("!F=6YC=&EO;B!-871H5&5S="@D;F%M
M92D@>PH@*B`@("`@("`@("1T:&ES+3Y02%!5;FET7U1E<W1#87-E*"1N86UE
M*3L*("H@("`@('T*("H*("H@("`@(&9U;F-T:6]N('-E=%5P*"D@>PH@*B`@
M("`@("`@("1T:&ES+3YF5F%L=64Q(#T@,CL*("H@("`@("`@("`D=&AI<RT^
M9E9A;'5E,B`](#,["B`J("`@("!]"B`J"B`J("`@("!F=6YC=&EO;B!T97-T
M061D*"D@>PH@*B`@("`@("`@("1T:&ES+3YA<W-E<G14<G5E*"1T:&ES+3YF
M5F%L=64Q("L@)'1H:7,M/F9686QU93(@/3T@-2D["B`J("`@("!]"B`J('T*
M("H*("H@)'-U:71E(#T@;F5W(%!(4%5N:71?5&5S=%-U:71E.PH@*@H@*B`D
M<W5I=&4M/F%D9%1E<W0H"B`J("`@;F5W(%!(4%5N:71?4F5P96%T961497-T
M*`H@*B`@("`@;F5W($UA=&A497-T*"=T97-T061D)RDL"B`J("`@("`Q,`H@
M*B`@("D*("H@*3L*("H*("H@)')E<W5L="`](%!(4%5N:70Z.G)U;B@D<W5I
M=&4I.PH@*B!P<FEN="`D<F5S=6QT+3YT;U-T<FEN9R@I.PH@*B`_/@H@*B`\
M+V-O9&4^"B`J"B`J($!C871E9V]R>2`@(%1E<W1I;F<*("H@0'!A8VMA9V4@
M("`@4$A056YI=`H@*B!`875T:&]R("`@("!396)A<W1I86X@0F5R9VUA;FX@
M/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X*("H@0&-O<'ER:6=H="`@,C`P
M,BTR,#`U(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M
M86YN+F1E/@H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N
M;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@
M0'9E<G-I;VX@("`@4F5L96%S93H@,2XS+C(*("H@0&QI;FL@("`@("`@:'1T
M<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!(4%5N:70*("H@0'-I;F-E("`@
M("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XP+C`*("HO"F-L
M87-S(%!(4%5N:71?4F5P96%T961497-T(&5X=&5N9',@4$A056YI=%]497-T
M1&5C;W)A=&]R('L*("`@("\J*@H@("`@("H@0'9A<B`@("!I;G1E9V5R"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?=&EM97-2
M97!E870@/2`Q.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@
M*@H@("`@("H@0'!A<F%M("!O8FIE8W0*("`@("`J($!P87)A;2`@:6YT96=E
M<@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@
M4$A056YI=%]297!E871E9%1E<W0H)B1T97-T+"`D=&EM97-297!E870@/2`Q
M*2!["B`@("`@("`@)'1H:7,M/E!(4%5N:71?5&5S=$1E8V]R871O<B@D=&5S
M="D["B`@("`@("`@)'1H:7,M/E]T:6UE<U)E<&5A="`]("1T:6UE<U)E<&5A
M=#L*("`@('T*"B`@("`O*BH*("`@("`J($-O=6YT<R!T:&4@;G5M8F5R(&]F
M('1E<W0@8V%S97,@=&AA=`H@("`@("H@=VEL;"!B92!R=6X@8GD@=&AI<R!T
M97-T+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@8V]U;G1497-T0V%S
M97,H*2!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=&EM97-297!E870@*B`D
M=&AI<RT^7W1E<W0M/F-O=6YT5&5S=$-A<V5S*"D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2=6YS('1H92!D96-O<F%T960@=&5S="!A;F0@8V]L;&5C=',@
M=&AE"B`@("`@*B!R97-U;'0@:6X@82!497-T4F5S=6QT+@H@("`@("H*("`@
M("`J($!P87)A;2`@;V)J96-T"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("H@0&%B<W1R86-T"B`@("`@*B\*("`@(&9U;F-T:6]N(')U;B@F)')E<W5L
M="D@>PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1T:&ES+3Y?=&EM97-2
M97!E870[("1I*RLI('L*("`@("`@("`@("`@)'1H:7,M/E]T97-T+3YR=6XH
M)')E<W5L="D["B`@("`@("`@?0H@("`@?0I]"@HO*@H@*B!,;V-A;"!V87)I
M86)L97,Z"B`J('1A8BUW:61T:#H@-`H@*B!C+6)A<VEC+6]F9G-E=#H@-`H@
M*B!C+6AA;F=I;F<M8V]M;65N="UE;F1E<BUP.B!N:6P*("H@16YD.@H@*B\*
M/SX*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+U!(4%5N:70O4VME;&5T;VXN<&AP````````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,S0R,#4@,3`U,34T,S,W,S$@,#(R,C4T`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT
M('-O9G1T86)S=&]P/30Z("HO"@HO*BH*("H@4$A0(%9E<G-I;VX@-`H@*@H@
M*B!#;W!Y<FEG:'0@*&,I(#(P,#(M,C`P-2P@4V5B87-T:6%N($)E<F=M86YN
M(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^+@H@*B!!;&P@<FEG:'1S(')E
M<V5R=F5D+@H@*@H@*B!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C
M92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70*("H@;6]D:69I
M8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO
M=VEN9R!C;VYD:71I;VYS"B`J(&%R92!M970Z"B`J"B`J("`@*B!2961I<W1R
M:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E
M(&-O<'ER:6=H=`H@*B`@("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET
M:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R+@H@*B`*("H@("`J
M(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C
M92!T:&4@86)O=F4@8V]P>7)I9VAT"B`J("`@("!N;W1I8V4L('1H:7,@;&ES
M="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@
M:6X*("H@("`@('1H92!D;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE<B!M871E
M<FEA;',@<')O=FED960@=VET:"!T:&4*("H@("`@(&1I<W1R:6)U=&EO;BX*
M("H*("H@("`J($YE:71H97(@=&AE(&YA;64@;V8@4V5B87-T:6%N($)E<F=M
M86YN(&YO<B!T:&4@;F%M97,@;V8@:&ES"B`J("`@("!C;VYT<FEB=71O<G,@
M;6%Y(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E('!R;V1U8W1S(&1E
M<FEV960*("H@("`@(&9R;VT@=&AI<R!S;V9T=V%R92!W:71H;W5T('-P96-I
M9FEC('!R:6]R('=R:71T96X@<&5R;6ES<VEO;BX*("H*("H@5$A)4R!33T94
M5T%212!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@04Y$
M($-/3E1224)55$]24PH@*B`B05,@25,B($%.1"!!3ED@15A04D534R!/4B!)
M35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5`H@*B!,24U)
M5$5$(%1/+"!42$4@24U03$E%1"!705)204Y42453($]&($U%4D-(04Y404))
M3$E462!!3D0@1DE43D534PH@*B!&3U(@02!005)424-53$%2(%!54E!/4T4@
M05)%($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(10H@*B!#3U!9
M4DE'2%0@3U=.15(@3U(@0T].5%))0E543U)3($)%($Q)04),12!&3U(@04Y9
M($1)4D5#5"P@24Y$25)%0U0L"B`J($E.0TE$14Y404PL(%-014-)04PL($58
M14U03$%262P@3U(@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,541)3D<L
M"B`J($)55"!.3U0@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8@4U5"4U1)
M5%5412!'3T]$4R!/4B!315)624-%4SL*("H@3$]34R!/1B!54T4L($1!5$$L
M($]2(%!23T9)5%,[($]2($)54TE.15-3($E.5$524E505$E/3BD@2$]7159%
M4@H@*B!#0553140@04Y$($].($%.62!42$5/4ED@3T8@3$E!0DE,2519+"!7
M2$542$52($E.($-/3E1204-4+"!35%))0PH@*B!,24%"24Q)5%DL($]2(%1/
M4E0@*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]42$525TE312D@05))4TE.
M1R!)3@H@*B!!3ED@5T%9($]55"!/1B!42$4@55-%($]&(%1(25,@4T]&5%=!
M4D4L($5614X@248@041625-%1"!/1B!42$4*("H@4$]34TE"24Q)5%D@3T8@
M4U5#2"!$04U!1T4N"B`J"B`J($!C871E9V]R>2`@(%1E<W1I;F<*("H@0'!A
M8VMA9V4@("`@4$A056YI=`H@*B!`875T:&]R("`@("!38V]T="!-871T;V-K
M<R`\<V-O='1`8W)I<W-C;W1T+F-O;3X*("H@0&-O<'ER:6=H="`@,C`P,BTR
M,#`U(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN
M+F1E/@H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G
M+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E
M<G-I;VX@("`@0U93.B`D260Z(%-K96QE=&]N+G!H<"QV(#$N."`R,#`U+S$Q
M+S$P(#`Y.C0W.C$T('-E8F%S=&EA;B!%>'`@)`H@*B!`;&EN:R`@("`@("!H
M='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$A056YI=`H@*B!`<VEN8V4@
M("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N,2XP"B`J+PH*
M+RHJ"B`J($-L87-S(&9O<B!C<F5A=&EN9R!A(%!(4%5N:71?5&5S=$-A<V4@
M<VME;&5T;VX@9FEL92X*("H*("H@5&AI<R!C;&%S<R!W:6QL('1A:V4@82!C
M;&%S<VYA;64@87,@82!P87)A;65T97(@;VX@8V]N<W1R=6-T:6]N(&%N9"!W
M:6QL"B`J(&-R96%T92!A(%!(4"!F:6QE('1H870@8V]N=&%I;G,@=&AE('-K
M96QE=&]N(&]F(&$@4$A056YI=%]497-T0V%S90H@*B!S=6)C;&%S<RX@5&AE
M('1E<W0@8V%S92!W:6QL(&-O;G1A:6X@82!T97-T(&9O<F5A8V@@;65T:&]D
M(&]F('1H92!C;&%S<RX*("H@365T:&]D<R!O9B!T:&4@<&%R96YT(&-L87-S
M('=I;&PL(&)Y(&1E9F%U;'0L(&)E(&5X8VQU9&5D(&9R;VT@=&AE('1E<W0*
M("H@8VQA<W,N(%!A<W-I;F<@86YD(&]P=&EO;F%L(&-O;G-T<G5C=&EO;B!P
M87)A;65T97(@=VEL;"!I;F-L=61E('1H96TN"B`J"B`J($5X86UP;&4*("H*
M("H@("`\/W!H<`H@*B`@(')E<75I<F5?;VYC92`G4$A056YI="]3:V5L971O
M;BYP:'`G.PH@*B`@("1P<R`](&YE=R!02%!5;FET7U-K96QE=&]N*"=02%!5
M;FET7U-K96QE=&]N)RP@)U!(4%5N:70O4VME;&5T;VXN<&AP)RD["B`J"B`J
M("`@+R\@1V5N97)A=&4@=&AE('1E<W0@8VQA<W,N"B`J("`@+R\@1&5F875L
M="!S971T:6YG<R!W:6QL(&YO="!I;F-L=61E(&%N>2!P87)E;G0@8VQA<W,@
M;65T:&]D<RP@8G5T"B`J("`@+R\@=VEL;"!I;F-L=61E('!R:79A=&4@;65T
M:&]D<RX*("H@("`D<',M/F-R96%T951E<W1#;&%S<R@I.PH@*@H@*B`@("\O
M(%=R:71E('1H92!N97<@=&5S="!C;&%S<R!T;R!F:6QE+@H@*B`@("\O($)Y
M(&1E9F%U;'0L(&-O9&4@=&\@<G5N('1H92!T97-T('=I;&P@8F4@:6YC;'5D
M960N"B`J("`@)'!S+3YW<FET951E<W1#;&%S<R@I.PH@*B`@(#\^"B`J"B`J
M($YO=R!O<&5N('1H92!S:V5L971O;B!C;&%S<R!A;F0@9FEL;"!I;B!T:&4@
M9&5T86EL<RX*("H@268@>6]U(')U;B!T:&4@=&5S="!A<R!I<RP@86QL('1E
M<W1S('=I;&P@9F%I;"!A;F0*("H@>6]U('=I;&P@<V5E('!L96YT>2!O9B!U
M;F1E9FEN960@8V]N<W1A;G0@97)R;W)S+@H@*@H@*B!`8V%T96=O<GD@("!4
M97-T:6YG"B`J($!P86-K86=E("`@(%!(4%5N:70*("H@0&%U=&AO<B`@("`@
M4V-O='0@36%T=&]C:W,@/'-C;W1T0&-R:7-S8V]T="YC;VT^"B`J($!C;W!Y
M<FEG:'0@(#(P,#(M,C`P-2!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S
M=&EA;BUB97)G;6%N;BYD93X*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYO
M<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($)31"!,
M:6-E;G-E"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N,RXR"B`J($!L:6YK
M("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]02%!5;FET"B`J
M($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#$N
M,2XP"B`J+PIC;&%S<R!02%!5;FET7U-K96QE=&]N('L*("`@("\J*@H@("`@
M("H@4&%T:"!T;R!T:&4@8VQA<W,@9FEL92!T;R!C<F5A=&4@82!S:V5L971O
M;B!F;W(N"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)&-L
M87-S4&%T:#L*"B`@("`O*BH*("`@("`J(%1H92!N86UE(&]F('1H92!C;&%S
M<PH@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1C;&%S<TYA
M;64["@H@("`@+RHJ"B`@("`@*B!0871H('1O('1H92!C;VYF:6=U<F%T:6]N
M(&9I;&4@;F5E9&5D(&)Y(&-L87-S('1O('1E<W0N"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)&-O;F9I9T9I;&4["@H@("`@+RHJ"B`@
M("`@*B!7:&5T:&5R(&]R(&YO="!T;R!I;F-L=61E('1H92!M971H;V1S(&]F
M('1H92!P87)E;G0@8VQA<W,@=VAE;B!T97-T:6YG+@H@("`@("H@0'9A<B!B
M;V]L96%N"B`@("`@*B\*("`@('9A<B`D:6YC;'5D95!A<F5N=',["@H@("`@
M+RHJ"B`@("`@*B!7:&5T:&5R(&]R(&YO="!T;R!T97-T('!R:79A=&4@;65T
M:&]D<RX*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)&EN
M8VQU9&50<FEV871E.PH*("`@("\J*@H@("`@("H@5&AE('1E<W0@8VQA<W,@
M=&AA="!W:6QL(&)E(&-R96%T960N"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)'1E<W1#;&%S<SL*"B`@("`O*BH*("`@("`J($-O;G-T
M<G5C=&]R+B!3971S('1H92!C;&%S<R!M96UB97)S(&%N9"!C:&5C:R!T:&%T
M('1H92!C;&%S<PH@("`@("H@=&\@=&5S="!I<R!A8V-E<W-I8FQE+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@('-T<FEN
M9R`@)&-L87-S3F%M90H@("`@("H@0'!A<F%M("!S=')I;F<@("1C;&%S<U!A
M=&@*("`@("`J($!P87)A;2`@8F]O;&5A;B`D:6YC;'5D95!A<F5N=',@5VAE
M=&5R('1O(&EN8VQU9&4@=&AE('!A<F5N="=S(&UE=&AO9',@:6X@=&AE('1E
M<W0N"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@
M4$A056YI=%]3:V5L971O;B@D8VQA<W-.86UE+"`D8VQA<W-0871H+"`D:6YC
M;'5D95!A<F5N=',@/2!&04Q312P@)&EN8VQU9&50<FEV871E(#T@5%)512D@
M>PH@("`@("`@("\O(%-E="!U<"!T:&4@;65M8F5R<RX*("`@("`@("!I9B`H
M0&ES7W)E861A8FQE*"1C;&%S<U!A=&@I*2!["B`@("`@("`@("`@("1T:&ES
M+3YC;&%S<TYA;64@/2`D8VQA<W-.86UE.PH@("`@("`@("`@("`D=&AI<RT^
M8VQA<W-0871H(#T@)&-L87-S4&%T:#L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=&AI<RT^7VAA;F1L945R<F]R<R@D8VQA<W-0871H("X@)R!I
M<R!N;W0@<F5A9&%B;&4N($-A;FYO="!C<F5A=&4@=&5S="!C;&%S<RXG*3L*
M("`@("`@("!]"@H@("`@("`@("\O($1O('=E('=A;G0@=&\@:6YC;'5D92!P
M87)E;G0@;65T:&]D<S\*("`@("`@("`D=&AI<RT^:6YC;'5D95!A<F5N=',@
M/2`D:6YC;'5D95!A<F5N=',["@H@("`@("`@("\O($1O('=E('=A;G0@=&\@
M86QL;W<@<')I=F%T92!M971H;V1S/PH@("`@("`@("1T:&ES+3YI;F-L=61E
M4')I=F%T92`]("1I;F-L=61E4')I=F%T93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%1H92!C;&%S<R!T;R!T97-T(&UA>2!R97%U:7)E(&$@<W!E8VEA;"!C
M;VYF:6<@9FEL92!B969O<F4@:70@8V%N(&)E"B`@("`@*B!I;G-T86YT:6%T
M960N(%1H:7,@;65T:&]D(&QE=',@>6]U('-E="!T:&%T(&9I;&4N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2`@<W1R:6YG
M("1C;VYF:6=0871H"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@
M9G5N8W1I;VX@<V5T0V]N9FEG1FEL92@D8V]N9FEG1FEL92D@>PH@("`@("`@
M("\O($-H96-K('1H870@=&AE(&9I;&4@:7,@<F5A9&%B;&4*("`@("`@("!I
M9B`H0&ES7W)E861A8FQE*"1C;VYF:6=&:6QE*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^8V]N9FEG1FEL92`]("1C;VYF:6=&:6QE.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1T:&ES+3Y?:&%N9&QE17)R;W)S*"1C;VYF:6=&
M:6QE("X@)R!I<R!N;W0@<F5A9&%B;&4N($-A;FYO="!C<F5A=&4@=&5S="!C
M;&%S<RXG*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A
M=&4@=&AE(&-O9&4@=&AA="!W:6QL(&)E('1H92!S:V5L971O;B!O9B!T:&4@
M=&5S="!C87-E+@H@("`@("H*("`@("`J(%1H92!T97-T(&-A<V4@;75S="!H
M879E(&$@8VQS<R!D969I;FET:6]N+"!O;F4@=F%R+"!A(&-O;G-T<G5C=&]R
M"B`@("`@*B!S9715<"P@=&5A<D1O=VXL(&%N9"!M971H;V1S+B!/<'1I;VYA
M;&QY(&%N9"!B>2!D969A=6QT('1H92!C;V1E"B`@("`@*B!T;R!R=6X@=&AE
M('1E<W0@:7,@861D960@=VAE;B!T:&4@8VQA<W,@:7,@=W)I='1E;B!T;R!F
M:6QE+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R
M86T@(&YO;F4*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC
M=&EO;B!C<F5A=&5497-T0VQA<W,H*2!["B`@("`@("`@+R\@26YS=&%N=&EA
M=&4@=&AE(&]B:F5C="X*("`@("`@("!I9B`H:7-S970H)'1H:7,M/F-O;F9I
M9T9I;&4I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`D=&AI<RT^8V]N
M9FEG1FEL93L*("`@("`@("!]"@H@("`@("`@(')E<75I<F5?;VYC92`D=&AI
M<RT^8VQA<W-0871H.PH*("`@("`@("`O+R!'970@=&AE(&UE=&AO9',N"B`@
M("`@("`@)&-L87-S365T:&]D<R`](&=E=%]C;&%S<U]M971H;V1S*"1T:&ES
M+3YC;&%S<TYA;64I.PH*("`@("`@("`O+R!296UO=F4@=&AE('!A<F5N="!M
M971H;V1S(&EF(&YE961E9"X*("`@("`@("!I9B`H(21T:&ES+3YI;F-L=61E
M4&%R96YT<RD@>PH@("`@("`@("`@("`D<&%R96YT365T:&]D<R`](&=E=%]C
M;&%S<U]M971H;V1S*&=E=%]P87)E;G1?8VQA<W,H)'1H:7,M/F-L87-S3F%M
M92DI.PH*("`@("`@("`@("`@:68@*&-O=6YT*"1P87)E;G1-971H;V1S*2D@
M>PH@("`@("`@("`@("`@("`@)&-L87-S365T:&]D<R`](&%R<F%Y7V1I9F8H
M)&-L87-S365T:&]D<RP@)'!A<F5N=$UE=&AO9',I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`O+R!#<F5A=&4@=&AE(&-L87-S(&1E9FEN
M:71I;VXL(&-O;G-T<G5C=&]R+"!S9715<"!A;F0@=&5A<D1O=VXN"B`@("`@
M("`@)'1H:7,M/E]C<F5A=&5$969I;FET:6]N*"D["B`@("`@("`@)'1H:7,M
M/E]C<F5A=&5#;VYS=')U8W1O<B@I.PH@("`@("`@("1T:&ES+3Y?8W)E871E
M4V5T57!496%R1&]W;B@I.PH*("`@("`@("!I9B`H8V]U;G0H)&-L87-S365T
M:&]D<RDI('L*("`@("`@("`@("`@+R\@1F]R96%C:"!M971H;V0@8W)E871E
M(&$@=&5S="!C87-E+@H@("`@("`@("`@("!F;W)E86-H("@D8VQA<W--971H
M;V1S(&%S("1M971H;V0I('L*("`@("`@("`@("`@("`@("\O(%5N;&5S<R!I
M="!I<R!T:&4@8V]N<W1R=6-T;W(N"B`@("`@("`@("`@("`@("!I9B`H<W1R
M8V%S96-M<"@D=&AI<RT^8VQA<W-.86UE+"`D;65T:&]D*2`A/3T@,"D@>PH@
M("`@("`@("`@("`@("`@("`O+R!#:&5C:R!F;W(@<')I=F%T92!M971H;V1S
M+@H@("`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3YI;F-L=61E4')I=F%T
M92`F)B!S=')P;W,H)&UE=&AO9"P@)U\G*2`]/3T@,"D@>PH@("`@("`@("`@
M("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-R96%T94UE=&AO
M9"@D;65T:&]D*3L*("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!&:6YI
M<R!O9F8@=&AE(&-L87-S+@H@("`@("`@("1T:&ES+3Y?9FEN:7-H0VQA<W,H
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T92!T:&4@8VQA<W,@9&5F
M:6YI=&EO;BX*("`@("`J"B`@("`@*B!4:&4@9&5F:6YI=&EO;B!C;VYS:7-T
M(&]F(&$@:&5A9&5R(&-O;6UE;G0L(')E<75I<F4@<W1A=&UE;G0*("`@("`J
M(&9O<B!G971T:6YG('1H92!02%!5;FET(&9I;&4L('1H92!A8W1U86P@8VQA
M<W,@9&5F:6YI=&EO;BP*("`@("`J(&%N9"!T:&4@9&5F:6YI=&EO;B!O9B!T
M:&4@8VQA<W,@;65M8F5R('9A<FEA8FQE+@H@("`@("H*("`@("`J($%L;"!O
M9B!T:&4@8V]D92!N965D960@9F]R('1H92!N97<@8VQA<W,@:7,@<W1O<F5D
M(&EN('1H90H@("`@("H@=&5S=$-L87-S(&UE;6)E<BX*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J($!P87)A;2`@;F]N90H@("`@("H@
M0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C<F5A=&5$969I
M;FET:6]N*"D@>PH@("`@("`@("\O($-R96%T92!H96%D97(@8V]M;65N="X*
M("`@("`@("`D=&AI<RT^=&5S=$-L87-S(#T*("`@("`@("`@("(O*BI<;B(@
M+@H@("`@("`@("`@(B`J(%!(4%5N:70@=&5S="!C87-E(&9O<B`B("X@)'1H
M:7,M/F-L87-S3F%M92`N(")<;B(@+@H@("`@("`@("`@(B`J(%QN(B`N"B`@
M("`@("`@("`B("H@5&AE(&UE=&AO9"!S:V5L971O;G,@8F5L;W<@;F5E9"!T
M;R!B92!F:6QL960@:6X@=VET:"!<;B(@+@H@("`@("`@("`@(B`J(')E86P@
M9&%T82!S;R!T:&%T('1H92!T97-T<R!W:6QL(')U;B!C;W)R96-T;'DN(%)E
M<&QA8V4@7&XB("X*("`@("`@("`@("(@*B!A;&P@15A014-4141?5D%,(&%N
M9"!005)!32!S=')I;F=S('=I=&@@<F5A;"!D871A+B!<;B(@+@H@("`@("`@
M("`@(B`J(%QN(B`N"B`@("`@("`@("`B("H@0W)E871E9"!W:71H(%!(4%5N
M:71?4VME;&5T;VX@;VX@(B`N(&1A=&4H)UDM;2UD)RD@+B`B7&XB("X*("`@
M("`@("`@("(@*B]<;B(["@H@("`@("`@("\O($%D9"!T:&4@<F5Q=6ER92!S
M=&%T96UE;G1S+@H@("`@("`@("1T:&ES+3YT97-T0VQA<W,@+CT@(G)E<75I
M<F5?;VYC92`G4$A056YI="YP:'`G.UQN(CL*"B`@("`@("`@+R\@061D('1H
M92!C;&%S<R!D969I;FET:6]N(&%N9"!V87)I86)L92!D969I;FET:6]N+@H@
M("`@("`@("1T:&ES+3YT97-T0VQA<W,@+CT*("`@("`@("`@(")C;&%S<R`B
M("X@)'1H:7,M/F-L87-S3F%M92`N(")497-T(&5X=&5N9',@4$A056YI=%]4
M97-T0V%S92![7&Y<;B(@+@H@("`@("`@("`@(B`@("!V87(@7"0B("X@)'1H
M:7,M/F-L87-S3F%M92`N("([7&Y<;B(["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#<F5A=&4@=&AE(&-L87-S(&-O;G-T<G5C=&]R+B`H4$A0-"!S='EL92D*
M("`@("`J"B`@("`@*B!4:&4@8V]N<W1R=6-T;W(@<VEM<&QY(&-A;&QS('1H
M92!02%!5;FET7U1E<W1#87-E(&UE=&AO9"X*("`@("`J(%1H:7,@8V]D92!I
M<R!T86ME;B!F<F]M('1H92!02%!5;FET(&1O8W5M96YT871I;VXN"B`@("`@
M*@H@("`@("H@06QL(&]F('1H92!C;V1E(&YE961E9"!F;W(@=&AE(&YE=R!C
M;&%S<R!I<R!S=&]R960@:6X@=&AE"B`@("`@*B!T97-T0VQA<W,@;65M8F5R
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'!A<F%M
M("!N;VYE"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V-R96%T94-O;G-T<G5C=&]R*"D@>PH@("`@("`@("\O($-R96%T92!T
M:&4@=&5S="!C;&%S<R!C;VYS=')U8W1O<BX*("`@("`@("`D=&AI<RT^=&5S
M=$-L87-S+CT*("`@("`@("`@("(@("`@9G5N8W1I;VX@(B`N("1T:&ES+3YC
M;&%S<TYA;64@+B`B5&5S="A<)&YA;64I7&XB("X*("`@("`@("`@("(@("`@
M>UQN(B`N"B`@("`@("`@("`B("`@("`@("!<)'1H:7,M/E!(4%5N:71?5&5S
M=$-A<V4H7"1N86UE*3M<;B(@+@H@("`@("`@("`@(B`@("!]7&Y<;B(["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@<V5T57`@86YD('1E87)$;W=N
M(&UE=&AO9',N"B`@("`@*@H@("`@("H@5&AE('-E=%5P(&UE=&AO9"!C<F5A
M=&5S('1H92!I;G-T86YC92!O9B!T:&4@;V)J96-T('1O('1E<W0N"B`@("`@
M*B!4:&4@=&5A<D1O=VX@;65T:&]D(')E;&5A<V5S('1H92!I;G-T86YC92X*
M("`@("`J(%1H:7,@8V]D92!I<R!T86ME;B!F<F]M('1H92!02%!5;FET(&1O
M8W5M96YT871I;VXN"B`@("`@*@H@("`@("H@06QL(&]F('1H92!C;V1E(&YE
M961E9"!F;W(@=&AE(&YE=R!C;&%S<R!I<R!S=&]R960@:6X@=&AE"B`@("`@
M*B!T97-T0VQA<W,@;65M8F5R+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H@0'!A<F%M("!N;VYE"B`@("`@*B!`<F5T=7)N('9O:60*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V-R96%T95-E=%5P5&5A<D1O=VXH*2![
M"B`@("`@("`@+R\@0W)E871E('1H92!S9715<"!M971H;V0N"B`@("`@("`@
M)'1H:7,M/G1E<W1#;&%S<R`N/0H@("`@("`@("`@(B`@("!F=6YC=&EO;B!S
M9715<"@I7&XB("X*("`@("`@("`@("(@("`@>UQN(CL*"B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3YC;VYF:6=&:6QE*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^=&5S=$-L87-S("X]"B`@("`@("`@("`@("(@("`@("`@(')E<75I<F5?
M;VYC92`G(B`N("1T:&ES+3YC;VYF:6=&:6QE("X@(B<[7&XB.PH@("`@("`@
M('T*"B`@("`@("`@)'1H:7,M/G1E<W1#;&%S<R`N/0H@("`@("`@("`@(B`@
M("`@("`@<F5Q=6ER95]O;F-E("<B("X@)'1H:7,M/F-L87-S4&%T:"`N("(G
M.UQN(B`N"B`@("`@("`@("`B("`@("`@("!<)'1H:7,M/B(@+B`D=&AI<RT^
M8VQA<W-.86UE("X@(B`])B!N97<@(B`N("1T:&ES+3YC;&%S<TYA;64@+B`B
M*%!!4D%-*3M<;B(@+@H@("`@("`@("`@(B`@("!]7&Y<;B(["@H@("`@("`@
M("\O($-R96%T92!T:&4@=&5A<D1O=VX@;65T:&]D+@H@("`@("`@("1T:&ES
M+3YT97-T0VQA<W,@+CT*("`@("`@("`@("(@("`@9G5N8W1I;VX@=&5A<D1O
M=VXH*5QN(B`N"B`@("`@("`@("`B("`@('M<;B(@+@H@("`@("`@("`@(B`@
M("`@("`@=6YS970H7"1T:&ES+3XB("X@)'1H:7,M/F-L87-S3F%M92`N("(I
M.UQN(B`N"B`@("`@("`@("`B("`@('U<;EQN(CL*("`@('T*"B`@("`O*BH*
M("`@("`J($-R96%T92!A(&)A<VEC('-K96QE=&]N(&9O<B!T97-T(&UE=&AO
M9',N"B`@("`@*@H@("`@("H@5&AI<R!C;V1E(&ES('1A:V5N(&9R;VT@=&AE
M(%!(4%5N:70@9&]C=6UE;G1A=&EO;BX*("`@("`J"B`@("`@*B!!;&P@;V8@
M=&AE(&-O9&4@;F5E9&5D(&9O<B!T:&4@;F5W(&-L87-S(&ES('-T;W)E9"!I
M;B!T:&4*("`@("`J('1E<W1#;&%S<R!M96UB97(N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@(&YO;F4*("`@("`J($!R
M971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!?8W)E871E365T:&]D
M*"1M971H;V1.86UE*2!["B`@("`@("`@+R\@0W)E871E(&$@=&5S="!M971H
M;V0N"B`@("`@("`@)'1H:7,M/G1E<W1#;&%S<R`N/0H@("`@("`@("`@(B`@
M("!F=6YC=&EO;B!T97-T(B`N("1M971H;V1.86UE("X@(B@I7&XB("X*("`@
M("`@("`@("(@("`@>UQN(B`N"B`@("`@("`@("`B("`@("`@("!<)')E<W5L
M="`@(#T@7"1T:&ES+3XB("X@)'1H:7,M/F-L87-S3F%M92`N("(M/B(@+B`D
M;65T:&]D3F%M92`N("(H4$%204TI.UQN(B`N"B`@("`@("`@("`B("`@("`@
M("!<)&5X<&5C=&5D(#T@15A014-4141?5D%,.UQN(B`N"B`@("`@("`@("`B
M("`@("`@("!<)'1H:7,M/F%S<V5R=$5Q=6%L<RA<)&5X<&5C=&5D+"!<)')E
M<W5L="D[7&XB("X*("`@("`@("`@("(@("`@?5QN7&XB.PH@("`@?0H*("`@
M("\J*@H@("`@("H@061D('1H92!C;&]S:6YG(&)R86-E(&YE961E9"!F;W(@
M82!P<F]P97(@8VQA<W,@9&5F:6YI=&EO;BX*("`@("`J"B`@("`@*B!!;&P@
M;V8@=&AE(&-O9&4@;F5E9&5D(&9O<B!T:&4@;F5W(&-L87-S(&ES('-T;W)E
M9"!I;B!T:&4*("`@("`J('1E<W1#;&%S<R!M96UB97(N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@(&YO;F4*("`@("`J
M($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!?9FEN:7-H0VQA
M<W,H*2!["B`@("`@("`@+R\@0VQO<V4@;V9F('1H92!C;&%S<RX*("`@("`@
M("`D=&AI<RT^=&5S=$-L87-S+CT@(GU<;B(["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#<F5A=&4@=&AE(&-O9&4@=&AA="!W:6QL(&%C='5A;&QY(')U;B!T
M:&4@=&5S="X*("`@("`J"B`@("`@*B!4:&ES(&-O9&4@:7,@861D960@8GD@
M9&5F875L="!S;R!T:&%T('1H92!T97-T(&-A;B!B92!R=6X*("`@("`J(&IU
M<W0@8GD@<G5N;FEN9R!T:&4@9FEL92X@5&\@:&%V92!I="!N;W0@861D960@
M<&%S<R!F86QS90H@("`@("H@87,@=&AE('-E8V]N9"!P87)A;65T97(@=&\@
M=&AE('=R:71E5&5S=$-L87-S(&UE=&AO9"X*("`@("`J(%1H:7,@8V]D92!I
M<R!T86ME;B!F<F]M('1H92!02%!5;FET(&1O8W5M96YT871I;VXN"B`@("`@
M*@H@("`@("H@06QL(&]F('1H92!C;V1E(&YE961E9"!F;W(@=&AE(&YE=R!C
M;&%S<R!I<R!S=&]R960@:6X@=&AE"B`@("`@*B!T97-T0VQA<W,@;65M8F5R
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'!A<F%M
M("!N;VYE"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V-R96%T951E<W0H*2!["B`@("`@("`@+R\@0W)E871E(&$@8V%L;"!T
M;R!T:&4@=&5S="X*("`@("`@("`D=&5S="`]"B`@("`@("`@("`B+R\@4G5N
M;FEN9R!T:&4@=&5S="Y<;B(@+@H@("`@("`@("`@(EPD<W5I=&4@(#T@;F5W
M(%!(4%5N:71?5&5S=%-U:71E*"<B("X@)'1H:7,M/F-L87-S3F%M92`N(")4
M97-T)RD[7&XB("X*("`@("`@("`@(")<)')E<W5L="`](%!(4%5N:70Z.G)U
M;BA<)'-U:71E*3M<;B(@+@H@("`@("`@("`@(F5C:&\@7"1R97-U;'0M/G1O
M4W1R:6YG*"D[7&XB.PH*("`@("`@("!R971U<FX@)'1E<W0["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!7<FET92!T:&4@=&5S="!C;&%S<R!T;R!F:6QE+@H@
M("`@("H*("`@("`J(%1H:7,@=VEL;"!W<FET92!T:&4@=&5S="!C;&%S<R!C
M<F5A=&5D('5S:6YG('1H92!C<F5A=&5497-T0VQA<W,*("`@("`J(&UE=&AO
M9"!T;R!A(&9I;&4@8V%L;&5D(#QC;&%S<TYA;64^5&5S="YP:'`N($)Y(&1E
M9F%U;'0@=&AE(&9I;&4*("`@("`J(&ES('=R:71T96X@=&\@=&AE(&-U<G)E
M;G0@9&ER96-T;W)Y(&%N9"!W:6QL(&AA=F4@8V]D92!T;R!R=6X*("`@("`J
M('1H92!T97-T(&%P<&5N9&5D('1O('1H92!B;W1T;VT@;V8@=&AE(&9I;&4N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2`@
M<W1R:6YG("`D9&5S=&EN871I;VX@5&AE(&1I<F5C=&]R>2!T;R!W<FET92!T
M:&4@9FEL92!T;RX*("`@("`J($!P87)A;2`@8F]O;&5A;B`D861D5&5S="`@
M("`@5VAE=&5R('1O(&%D9"!T:&4@=&5S="!R=6YN:6YG(&-O9&4N"B`@("`@
M*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@=W)I=&5497-T
M0VQA<W,H)&1E<W1I;F%T:6]N(#T@)RXO)RP@)&%D9%1E<W0@/2!44E5%*2![
M"B`@("`@("`@+R\@0VAE8VL@9F]R('-O;65T:&EN9R!T;R!W<FET92!T;R!F
M:6QE+@H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/G1E<W1#;&%S<RDI('L*
M("`@("`@("`@("`@)'1H:7,M/E]H86YD;&5%<G)O<G,H)TYO=&EN9R!T;R!W
M<FET92XG+"!02%!54U]705).24Y'*3L*("`@("`@("`@("`@<F5T=7)N.PH@
M("`@("`@('T*"B`@("`@("`@+R\@3W!E;B!T:&4@9&5S=&EN871I;VX@9FEL
M92X*("`@("`@("`D9G`@/2!F;W!E;B@D9&5S=&EN871I;VX@+B`D=&AI<RT^
M8VQA<W-.86UE("X@)U1E<W0N<&AP)RP@)W<G*3L*("`@("`@("!F=W)I=&4H
M)&9P+"`B/#]P:'!<;B(I.PH*("`@("`@("`O+R!7<FET92!T:&4@=&5S="!C
M;&%S<RX*("`@("`@("!F=W)I=&4H)&9P+"`D=&AI<RT^=&5S=$-L87-S*3L*
M"B`@("`@("`@+R\@061D('1H92!C86QL('1O('1E<W0@=&AE(&-L87-S(&EN
M('1H92!F:6QE(&EF('=E('=E<F4@87-K960@=&\N"B`@("`@("`@:68@*"1A
M9&1497-T*2!["B`@("`@("`@("`@(&9W<FET92@D9G`L("1T:&ES+3Y?8W)E
M871E5&5S="@I*3L*("`@("`@("!]"@H@("`@("`@("\O($-L;W-E('1H92!F
M:6QE+@H@("`@("`@(&9W<FET92@D9G`L("(_/EQN(BD["B`@("`@("`@9F-L
M;W-E*"1F<"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%<G)O<B!H86YD;&5R
M+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D('-H;W5L9"!B92!R97=R:71T
M96X@=&\@=7-E('1H92!P<F5F97)E9"!E<G)O<@H@("`@("H@:&%N9&QI;F<@
M;65T:&]D+B`H4$5!4E]%<G)O<E-T86-K*0H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H@0'!A<F%M("!S=')I;F<@("1M97-S86=E(%1H
M92!E<G)O<B!M97-S86=E+@H@("`@("H@0'!A<F%M("!I;G1E9V5R("1T>7!E
M("`@($%N(&EN9&EC871I;VX@;V8@=&AE('-E=F5R:71Y(&]F('1H92!E<G)O
M<BX*("`@("`J($!R971U<FX@=F]I9"`@("`@("`@("`@("!#;V1E(&UA>2!C
M875S92!02%`@=&\@97AI="X*("`@("`J+PH@("`@9G5N8W1I;VX@7VAA;F1L
M945R<F]R<R@D;65S<V%G92P@)'1Y<&4@/2!%7U5315)?15)23U(I('L*("`@
M("`@("`O+R!&;W(@;F]W(&IU<W0@96-H;R!T:&4@;65S<V%G92X*("`@("`@
M("!E8VAO("1M97-S86=E.PH*("`@("`@("`O+R!#:&5C:R!T;R!S964@:68@
M=V4@<VAO=6QD('%U:70N"B`@("`@("`@:68@*"1T>7!E(#T]($5?55-%4E]%
M4E)/4BD@>PH@("`@("`@("`@("!E>&ET.PH@("`@("`@('T*("`@('T*?0H*
M+RH*("H@3&]C86P@=F%R:6%B;&5S.@H@*B!T86(M=VED=&@Z(#0*("H@8RUB
M87-I8RUO9F9S970Z(#0*("H@8RUH86YG:6YG+6-O;6UE;G0M96YD97(M<#H@
M;FEL"B`J($5N9#H*("HO"C\^"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+U!(4%5N:70O5&5S=$-A<V4N<&AP````
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,38S,3(@,3`U,34T
M,S,W,S$@,#(R,C`R`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P
M/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO"@HO*BH*("H@4$A0
M(%9E<G-I;VX@-`H@*@H@*B!#;W!Y<FEG:'0@*&,I(#(P,#(M,C`P-2P@4V5B
M87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^+@H@
M*B!!;&P@<FEG:'1S(')E<V5R=F5D+@H@*@H@*B!2961I<W1R:6)U=&EO;B!A
M;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I
M=&AO=70*("H@;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D
M('1H870@=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS"B`J(&%R92!M970Z"B`J
M"B`J("`@*B!2961I<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R
M971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H=`H@*B`@("`@;F]T:6-E+"!T:&ES
M(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I
M;65R+@H@*B`*("H@("`J(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R
M;2!M=7-T(')E<')O9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT"B`J("`@("!N
M;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W
M:6YG(&1I<V-L86EM97(@:6X*("H@("`@('1H92!D;V-U;65N=&%T:6]N(&%N
M9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@=VET:"!T:&4*("H@("`@
M(&1I<W1R:6)U=&EO;BX*("H*("H@("`J($YE:71H97(@=&AE(&YA;64@;V8@
M4V5B87-T:6%N($)E<F=M86YN(&YO<B!T:&4@;F%M97,@;V8@:&ES"B`J("`@
M("!C;VYT<FEB=71O<G,@;6%Y(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M
M;W1E('!R;V1U8W1S(&1E<FEV960*("H@("`@(&9R;VT@=&AI<R!S;V9T=V%R
M92!W:71H;W5T('-P96-I9FEC('!R:6]R('=R:71T96X@<&5R;6ES<VEO;BX*
M("H*("H@5$A)4R!33T945T%212!)4R!04D]6241%1"!"62!42$4@0T]065))
M1TA4($A/3$1%4E,@04Y$($-/3E1224)55$]24PH@*B`B05,@25,B($%.1"!!
M3ED@15A04D534R!/4B!)35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@
M0E54($Y/5`H@*B!,24U)5$5$(%1/+"!42$4@24U03$E%1"!705)204Y42453
M($]&($U%4D-(04Y404))3$E462!!3D0@1DE43D534PH@*B!&3U(@02!005)4
M24-53$%2(%!54E!/4T4@05)%($1)4T-,04E-140N($E.($Y/($5614Y4(%-(
M04Q,(%1(10H@*B!#3U!94DE'2%0@3U=.15(@3U(@0T].5%))0E543U)3($)%
M($Q)04),12!&3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L"B`J($E.0TE$14Y4
M04PL(%-014-)04PL($5814U03$%262P@3U(@0T].4T51545.5$E!3"!$04U!
M1T53("A)3D-,541)3D<L"B`J($)55"!.3U0@3$E-251%1"!43RP@4%)/0U52
M14U%3E0@3T8@4U5"4U1)5%5412!'3T]$4R!/4B!315)624-%4SL*("H@3$]3
M4R!/1B!54T4L($1!5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3($E.5$52
M4E505$E/3BD@2$]7159%4@H@*B!#0553140@04Y$($].($%.62!42$5/4ED@
M3T8@3$E!0DE,2519+"!72$542$52($E.($-/3E1204-4+"!35%))0PH@*B!,
M24%"24Q)5%DL($]2(%1/4E0@*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]4
M2$525TE312D@05))4TE.1R!)3@H@*B!!3ED@5T%9($]55"!/1B!42$4@55-%
M($]&(%1(25,@4T]&5%=!4D4L($5614X@248@041625-%1"!/1B!42$4*("H@
M4$]34TE"24Q)5%D@3T8@4U5#2"!$04U!1T4N"B`J"B`J($!C871E9V]R>2`@
M(%1E<W1I;F<*("H@0'!A8VMA9V4@("`@4$A056YI=`H@*B!`875T:&]R("`@
M("!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD
M93X*("H@0&-O<'ER:6=H="`@,C`P,BTR,#`U(%-E8F%S=&EA;B!"97)G;6%N
M;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/@H@*B!`;&EC96YS92`@("!H
M='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E
M+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%1E
M<W1#87-E+G!H<"QV(#$N,C$@,C`P-2\Q,2\Q,"`P.3HT-SHQ-"!S96)A<W1I
M86X@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P
M86-K86=E+U!(4%5N:70*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@
M<VEN8V4@4F5L96%S92`Q+C`N,`H@*B\*"G)E<75I<F5?;VYC92`G4$A056YI
M="]!<W-E<G0N<&AP)SL*<F5Q=6ER95]O;F-E("=02%!5;FET+U1E<W1297-U
M;'0N<&AP)SL*"B\J*@H@*B!!(%1E<W1#87-E(&1E9FEN97,@=&AE(&9I>'1U
M<F4@=&\@<G5N(&UU;'1I<&QE('1E<W1S+@H@*@H@*B!4;R!D969I;F4@82!4
M97-T0V%S90H@*@H@*B`@(#$I($EM<&QE;65N="!A('-U8F-L87-S(&]F(%!(
M4%5N:71?5&5S=$-A<V4N"B`J("`@,BD@1&5F:6YE(&EN<W1A;F-E('9A<FEA
M8FQE<R!T:&%T('-T;W)E('1H92!S=&%T92!O9B!T:&4@9FEX='5R92X*("H@
M("`S*2!);FET:6%L:7IE('1H92!F:7AT=7)E('-T871E(&)Y(&]V97)R:61I
M;F<@<V5T57`H*2X*("H@("`T*2!#;&5A;BUU<"!A9G1E<B!A('1E<W0@8GD@
M;W9E<G)I9&EN9R!T96%R1&]W;B@I+@H@*@H@*B!%86-H('1E<W0@<G5N<R!I
M;B!I=',@;W=N(&9I>'1U<F4@<V\@=&AE<F4@8V%N(&)E(&YO('-I9&4@969F
M96-T<PH@*B!A;6]N9R!T97-T(')U;G,N"B`J"B`J($AE<F4@:7,@86X@97AA
M;7!L93H*("H*("H@/&-O9&4^"B`J(#P_<&AP"B`J(&-L87-S($UA=&A497-T
M(&5X=&5N9',@4$A056YI=%]497-T0V%S92!["B`J("`@("!V87(@)&9686QU
M93$["B`J("`@("!V87(@)&9686QU93(["B`J"B`J("`@("!F=6YC=&EO;B!-
M871H5&5S="@D;F%M92D@>PH@*B`@("`@("`@("1T:&ES+3Y02%!5;FET7U1E
M<W1#87-E*"1N86UE*3L*("H@("`@('T*("H*("H@("`@(&9U;F-T:6]N('-E
M=%5P*"D@>PH@*B`@("`@("`@("1T:&ES+3YF5F%L=64Q(#T@,CL*("H@("`@
M("`@("`D=&AI<RT^9E9A;'5E,B`](#,["B`J("`@("!]"B`J('T*("H@/SX*
M("H@/"]C;V1E/@H@*@H@*B!&;W(@96%C:"!T97-T(&EM<&QE;65N="!A(&UE
M=&AO9"!W:&EC:"!I;G1E<F%C=',@=VET:"!T:&4@9FEX='5R92X*("H@5F5R
M:69Y('1H92!E>'!E8W1E9"!R97-U;'1S('=I=&@@87-S97)T:6]N<R!S<&5C
M:69I960@8GD@8V%L;&EN9PH@*B!A<W-E<G0@=VET:"!A(&)O;VQE86XN"B`J
M"B`J(#QC;V1E/@H@*B`\/W!H<`H@*B!F=6YC=&EO;B!T97-T4&%S<R@I('L*
M("H@("`@("1T:&ES+3YA<W-E<G14<G5E*"1T:&ES+3YF5F%L=64Q("L@)'1H
M:7,M/F9686QU93(@/3T@-2D["B`J('T*("H@/SX*("H@/"]C;V1E/@H@*@H@
M*B!`8V%T96=O<GD@("!497-T:6YG"B`J($!P86-K86=E("`@(%!(4%5N:70*
M("H@0&%U=&AO<B`@("`@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I
M86XM8F5R9VUA;FXN9&4^"B`J($!C;W!Y<FEG:'0@(#(P,#(M,C`P-2!396)A
M<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X*("H@
M0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E
M<R]B<V0M;&EC96YS92YP:'`@($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@
M(%)E;&5A<V4Z(#$N,RXR"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H
M<"YN970O<&%C:V%G92]02%!5;FET"B`J($!S:6YC92`@("`@($-L87-S(&%V
M86EL86)L92!S:6YC92!296QE87-E(#$N,"XP"B`J+PIC;&%S<R!02%!5;FET
M7U1E<W1#87-E(&5X=&5N9',@4$A056YI=%]!<W-E<G0@>PH@("`@+RHJ"B`@
M("`@*B!`=F%R("`@(&)O;VQE86X*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("HO"B`@("!V87(@)%]F86EL960@/2!&04Q313L*"B`@("`O*BH*("`@
M("`J(%1H92!N86UE(&]F('1H92!T97-T(&-A<V4N"B`@("`@*@H@("`@("H@
M0'9A<B`@("!S=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO
M"B`@("!V87(@)%]N86UE(#T@)R<["@H@("`@+RHJ"B`@("`@*B!02%!5;FET
M7U1E<W1297-U;'0@;V)J96-T"B`@("`@*@H@("`@("H@0'9A<B`@("!O8FIE
M8W0*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]R
M97-U;'0["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@=&5S="!C87-E
M('=I=&@@=&AE(&=I=F5N(&YA;64N"B`@("`@*@H@("`@("H@0'!A<F%M("!S
M=')I;F<*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%!(4%5N:71?5&5S=$-A<V4H)&YA;64@/2!&04Q312D@>PH@("`@("`@
M(&EF("@D;F%M92`A/3T@1D%,4T4I('L*("`@("`@("`@("`@)'1H:7,M/G-E
M=$YA;64H)&YA;64I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($-O=6YT<R!T:&4@;G5M8F5R(&]F('1E<W0@8V%S97,@97AE8W5T960@8GD@
M<G5N*%1E<W1297-U;'0@<F5S=6QT*2X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&EN=&5G97(*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&-O=6YT5&5S=$-A<V5S*"D@>PH@("`@("`@(')E='5R;B`Q.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@;F%M92!O9B!A(%1E<W1#
M87-E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!G971.86UE*"D@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7VYA;64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2=6YS('1H92!T97-T(&-A<V4@86YD(&-O;&QE8W1S('1H92!R97-U
M;'1S(&EN(&$@9VEV96X@5&5S=%)E<W5L="!O8FIE8W0N"B`@("`@*@H@("`@
M("H@0'!A<F%M("!O8FIE8W0*("`@("`J($!R971U<FX@;V)J96-T"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!R=6XH)B1R
M97-U;'0I('L*("`@("`@("`D=&AI<RT^7W)E<W5L="`]("8D<F5S=6QT.PH@
M("`@("`@("1T:&ES+3Y?<F5S=6QT+3YR=6XH)'1H:7,I.PH*("`@("`@("!R
M971U<FX@)'1H:7,M/E]R97-U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M=6YS('1H92!B87)E('1E<W0@<V5Q=65N8V4N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<G5N0F%R92@I('L*
M("`@("`@("`D=&AI<RT^<V5T57`H*3L*("`@("`@("`D=&AI<RT^<G5N5&5S
M="@I.PH@("`@("`@("1T:&ES+3YT96%R1&]W;B@I.PH@("`@("`@("1T:&ES
M+3YP87-S*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!/=F5R<FED92!T;R!R
M=6X@=&AE('1E<W0@86YD(&%S<V5R="!I=',@<W1A=&4N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J+PH@("`@9G5N8W1I;VX@<G5N
M5&5S="@I('L*("`@("`@("!C86QL7W5S97)?9G5N8R@*("`@("`@("`@(&%R
M<F%Y*`H@("`@("`@("`@("`F)'1H:7,L"B`@("`@("`@("`@("1T:&ES+3Y?
M;F%M90H@("`@("`@("`@*0H@("`@("`@("D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3971S('1H92!N86UE(&]F(&$@5&5S=$-A<V4N"B`@("`@*@H@("`@
M("H@0'!A<F%M("!S=')I;F<*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E=$YA;64H)&YA;64I('L*("`@("`@("`D=&AI
M<RT^7VYA;64@/2`D;F%M93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@82!S=')I;F<@<F5P<F5S96YT871I;VX@;V8@=&AE('1E<W0@8V%S92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9PH@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@=&]3=')I;F<H*2!["B`@("`@
M("`@<F5T=7)N("<G.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E<R!A
M(&1E9F%U;'0@5&5S=%)E<W5L="!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E
M='5R;B!O8FIE8W0*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B\*
M("`@(&9U;F-T:6]N("9C<F5A=&5297-U;'0H*2!["B`@("`@("`@<F5T=7)N
M(&YE=R!02%!5;FET7U1E<W1297-U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!&86EL<R!A('1E<W0@=VET:"!T:&4@9VEV96X@;65S<V%G92X*("`@("`J
M"B`@("`@*B!`<&%R86T@('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<F]T96-T
M960*("`@("`J+PH@("`@9G5N8W1I;VX@9F%I;"@D;65S<V%G92`]("<G*2![
M"B`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G9&5B=6=?8F%C:W1R86-E
M)RDI('L*("`@("`@("`@("`@)'1R86-E(#T@9&5B=6=?8F%C:W1R86-E*"D[
M"@H@("`@("`@("`@("!I9B`H:7-S970H)'1R86-E6R<Q)UU;)V9I;&4G72DI
M('L*("`@("`@("`@("`@("`@("1M97-S86=E(#T@<W!R:6YT9B@*("`@("`@
M("`@("`@("`@("`@(B5S(&EN("5S.B5S(BP*"B`@("`@("`@("`@("`@("`@
M("1M97-S86=E+`H@("`@("`@("`@("`@("`@("`D=')A8V5;)S$G75LG9FEL
M92==+`H@("`@("`@("`@("`@("`@("`D=')A8V5;)S$G75LG;&EN92=="B`@
M("`@("`@("`@("`@("`I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("`D=&AI<RT^7W)E<W5L="T^861D1F%I;'5R92@D=&AI<RP@)&UE<W-A
M9V4I.PH@("`@("`@("1T:&ES+3Y?9F%I;&5D(#T@5%)513L*("`@('T*"B`@
M("`O*BH*("`@("`J(%!A<W-E<R!A('1E<W0N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<F]T96-T960*("`@("`J+PH@("`@9G5N8W1I;VX@<&%S<R@I('L*
M("`@("`@("!I9B`H(21T:&ES+3Y?9F%I;&5D*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?<F5S=6QT+3YA9&1087-S961497-T*"1T:&ES*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('5P('1H92!F:7AT=7)E+"!F
M;W(@97AA;7!L92P@;W!E;B!A(&YE='=O<FL@8V]N;F5C=&EO;BX*("`@("`J
M(%1H:7,@;65T:&]D(&ES(&-A;&QE9"!B969O<F4@82!T97-T(&ES(&5X96-U
M=&5D+@H@("`@("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B!`
M86)S=')A8W0*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T57`H*2![("\J(&%B
M<W1R86-T("HO('T*"B`@("`O*BH*("`@("`J(%1E87)S(&1O=VX@=&AE(&9I
M>'1U<F4L(&9O<B!E>&%M<&QE+"!C;&]S92!A(&YE='=O<FL@8V]N;F5C=&EO
M;BX*("`@("`J(%1H:7,@;65T:&]D(&ES(&-A;&QE9"!A9G1E<B!A('1E<W0@
M:7,@97AE8W5T960N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*
M("`@("`J($!A8G-T<F%C=`H@("`@("HO"B`@("!F=6YC=&EO;B!T96%R1&]W
M;B@I('L@+RH@86)S=')A8W0@*B\@?0I]"@HO*@H@*B!,;V-A;"!V87)I86)L
M97,Z"B`J('1A8BUW:61T:#H@-`H@*B!C+6)A<VEC+6]F9G-E=#H@-`H@*B!C
M+6AA;F=I;F<M8V]M;65N="UE;F1E<BUP.B!N:6P*("H@16YD.@H@*B\*/SX*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$A056YI="]497-T1&5C;W)A=&]R
M+G!H<```````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,#8V-B`Q,#4Q
M-30S,S<S,2`P,C,R-3<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T
M;W`]-"!S:&EF='=I9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*"B\J*@H@*B!0
M2%`@5F5R<VEO;B`T"B`J"B`J($-O<'ER:6=H="`H8RD@,C`P,BTR,#`U+"!3
M96)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93XN
M"B`J($%L;"!R:6=H=',@<F5S97)V960N"B`J"B`J(%)E9&ES=')I8G5T:6]N
M(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@
M=VET:&]U=`H@*B!M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@<')O=FED
M960@=&AA="!T:&4@9F]L;&]W:6YG(&-O;F1I=&EO;G,*("H@87)E(&UE=#H*
M("H*("H@("`J(%)E9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D92!M=7-T
M(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I9VAT"B`J("`@("!N;W1I8V4L('1H
M:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L
M86EM97(N"B`J(`H@*B`@("H@4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F
M;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0*("H@("`@
M(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL
M;W=I;F<@9&ES8VQA:6UE<B!I;@H@*B`@("`@=&AE(&1O8W5M96YT871I;VX@
M86YD+V]R(&]T:&5R(&UA=&5R:6%L<R!P<F]V:61E9"!W:71H('1H90H@*B`@
M("`@9&ES=')I8G5T:6]N+@H@*@H@*B`@("H@3F5I=&AE<B!T:&4@;F%M92!O
M9B!396)A<W1I86X@0F5R9VUA;FX@;F]R('1H92!N86UE<R!O9B!H:7,*("H@
M("`@(&-O;G1R:6)U=&]R<R!M87D@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R
M;VUO=&4@<')O9'5C=',@9&5R:79E9`H@*B`@("`@9G)O;2!T:&ES('-O9G1W
M87)E('=I=&AO=70@<W!E8VEF:6,@<')I;W(@=W)I='1E;B!P97)M:7-S:6]N
M+@H@*@H@*B!42$E3(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#3U!9
M4DE'2%0@2$],1$524R!!3D0@0T].5%))0E543U)3"B`J(")!4R!)4R(@04Y$
M($%.62!%6%!215-3($]2($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$24Y'
M+"!"550@3D]4"B`J($Q)34E4140@5$\L(%1(12!)35!,245$(%=!4E)!3E1)
M15,@3T8@34520TA!3E1!0DE,2519($%.1"!&251.15-3"B`J($9/4B!!(%!!
M4E1)0U5,05(@4%524$]312!!4D4@1$E30TQ!24U%1"X@24X@3D\@159%3E0@
M4TA!3$P@5$A%"B`J($-/4%E224=(5"!/5TY%4B!/4B!#3TY44DE"551/4E,@
M0D4@3$E!0DQ%($9/4B!!3ED@1$E214-4+"!)3D1)4D5#5"P*("H@24Y#241%
M3E1!3"P@4U!%0TE!3"P@15A%35!,05)9+"!/4B!#3TY315%514Y424%,($1!
M34%'15,@*$E.0TQ51$E.1RP*("H@0E54($Y/5"!,24U)5$5$(%1/+"!04D]#
M55)%345.5"!/1B!354)35$E4551%($=/3T13($]2(%-%4E9)0T53.PH@*B!,
M3U-3($]&(%5312P@1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,@24Y4
M15)255!424].*2!(3U=%5D52"B`J($-!55-%1"!!3D0@3TX@04Y9(%1(14]2
M62!/1B!,24%"24Q)5%DL(%=(151(15(@24X@0T].5%)!0U0L(%-44DE#"B`J
M($Q)04))3$E462P@3U(@5$]25"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@
M3U1(15)725-%*2!!4DE324Y'($E."B`J($%.62!705D@3U54($]&(%1(12!5
M4T4@3T8@5$A)4R!33T945T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(10H@
M*B!03U-324))3$E462!/1B!354-(($1!34%'12X*("H*("H@0&-A=&5G;W)Y
M("`@5&5S=&EN9PH@*B!`<&%C:V%G92`@("!02%!5;FET"B`J($!A=71H;W(@
M("`@(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN
M+F1E/@H@*B!`8V]P>7)I9VAT("`R,#`R+3(P,#4@4V5B87-T:6%N($)E<F=M
M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^"B`J($!L:6-E;G-E("`@
M(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N
M<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@
M5&5S=$1E8V]R871O<BYP:'`L=B`Q+C$W(#(P,#4O,3$O,3`@,#DZ-#<Z,30@
M<V5B87-T:6%N($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H
M<"YN970O<&%C:V%G92]02%!5;FET"B`J($!S:6YC92`@("`@($9I;&4@879A
M:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XP+C`*("HO"@IR97%U:7)E7V]N8V4@
M)U!(4%5N:70O5&5S=$-A<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=02%!5;FET
M+U1E<W13=6ET92YP:'`G.PH*:68@*"%F=6YC=&EO;E]E>&ES=',H)VES7V$G
M*2D@>PH@("`@<F5Q=6ER95]O;F-E("=02%`O0V]M<&%T+T9U;F-T:6]N+VES
M7V$N<&AP)SL*?0H*+RHJ"B`J($$@1&5C;W)A=&]R(&9O<B!497-T<RX*("H*
M("H@57-E(%1E<W1$96-O<F%T;W(@87,@=&AE(&)A<V4@8VQA<W,@9F]R(&1E
M9FEN:6YG(&YE=PH@*B!T97-T(&1E8V]R871O<G,N(%1E<W0@9&5C;W)A=&]R
M('-U8F-L87-S97,@8V%N(&)E(&EN=')O9'5C960*("H@=&\@861D(&)E:&%V
M:6]U<B!B969O<F4@;W(@869T97(@82!T97-T(&ES(')U;BX*("H*("H@0&-A
M=&5G;W)Y("`@5&5S=&EN9PH@*B!`<&%C:V%G92`@("!02%!5;FET"B`J($!A
M=71H;W(@("`@(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E
M<F=M86YN+F1E/@H@*B!`8V]P>7)I9VAT("`R,#`R+3(P,#4@4V5B87-T:6%N
M($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^"B`J($!L:6-E
M;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D
M+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@("!296QE
M87-E.B`Q+C,N,@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T
M+W!A8VMA9V4O4$A056YI=`H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B
M;&4@<VEN8V4@4F5L96%S92`Q+C`N,`H@*B\*8VQA<W,@4$A056YI=%]497-T
M1&5C;W)A=&]R('L*("`@("\J*@H@("`@("H@5&AE(%1E<W0@=&\@8F4@9&5C
M;W)A=&5D+@H@("`@("H*("`@("`J($!V87(@("`@;V)J96-T"B`@("`@*B!`
M86-C97-S('!R;W1E8W1E9`H@("`@("HO"B`@("!V87(@)%]T97-T(#T@3E5,
M3#L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J
M($!P87)A;2`@;V)J96-T"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!02%!5;FET7U1E<W1$96-O<F%T;W(H)B1T97-T*2![
M"B`@("`@("`@:68@*&ES7V]B:F5C="@D=&5S="D@)B8*("`@("`@("`@("`@
M*&ES7V$H)'1E<W0L("=02%!5;FET7U1E<W1#87-E)RD@?'P*("`@("`@("`@
M("`@(&ES7V$H)'1E<W0L("=02%!5;FET7U1E<W13=6ET92<I*2D@>PH*("`@
M("`@("`@("`@)'1H:7,M/E]T97-T(#T@)B1T97-T.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J(%)U;G,@=&AE('1E<W0@86YD(&-O;&QE8W1S
M('1H90H@("`@("H@<F5S=6QT(&EN(&$@5&5S=%)E<W5L="X*("`@("`J"B`@
M("`@*B!`<&%R86T@(&]B:F5C=`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@8F%S:6-2=6XH)B1R97-U;'0I('L*("`@("`@
M("`D=&AI<RT^7W1E<W0M/G)U;B@D<F5S=6QT*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($-O=6YT<R!T:&4@;G5M8F5R(&]F('1E<W0@8V%S97,@=&AA=`H@
M("`@("H@=VEL;"!B92!R=6X@8GD@=&AI<R!T97-T+@H@("`@("H*("`@("`J
M($!R971U<FX@:6YT96=E<@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M+PH@("`@9G5N8W1I;VX@8V]U;G1497-T0V%S97,H*2!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?=&5S="T^8V]U;G1497-T0V%S97,H*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@=&AE('1E<W0@=&\@8F4@<G5N+@H@("`@
M("H*("`@("`J($!R971U<FX@;V)J96-T"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T5&5S="@I('L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]T97-T.PH@("`@?0H*("`@("\J*@H@("`@("H@4G5N
M<R!T:&4@9&5C;W)A=&5D('1E<W0@86YD(&-O;&QE8W1S('1H90H@("`@("H@
M<F5S=6QT(&EN(&$@5&5S=%)E<W5L="X*("`@("`J"B`@("`@*B!`<&%R86T@
M(&]B:F5C=`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!A8G-T<F%C
M=`H@("`@("HO"B`@("!F=6YC=&EO;B!R=6XH)B1R97-U;'0I('L@+RH@86)S
M=')A8W0@*B\@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A('-T<FEN9R!R
M97!R97-E;G1A=&EO;B!O9B!T:&4@=&5S="X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9PH@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@=&]3=')I;F<H*2!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M=&5S="T^=&]3=')I;F<H*3L*("`@('T*?0H*+RH*("H@3&]C86P@=F%R:6%B
M;&5S.@H@*B!T86(M=VED=&@Z(#0*("H@8RUB87-I8RUO9F9S970Z(#0*("H@
M8RUH86YG:6YG+6-O;6UE;G0M96YD97(M<#H@;FEL"B`J($5N9#H*("HO"C\^
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]02%!5;FET+U1E<W1&86EL=7)E+G!H<```````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`W-C,R(#$P-3$U-#,S-S,Q(#`R
M,C<R,P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T
M=VED=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J(%!(4"!697)S:6]N
M(#0*("H*("H@0V]P>7)I9VAT("AC*2`R,#`R+3(P,#4L(%-E8F%S=&EA;B!"
M97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/BX*("H@06QL(')I
M9VAT<R!R97-E<G9E9"X*("H*("H@4F5D:7-T<FEB=71I;VX@86YD('5S92!I
M;B!S;W5R8V4@86YD(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T"B`J
M(&UO9&EF:6-A=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H
M92!F;VQL;W=I;F<@8V]N9&ET:6]N<PH@*B!A<F4@;65T.@H@*@H@*B`@("H@
M4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H
M92!A8F]V92!C;W!Y<FEG:'0*("H@("`@(&YO=&EC92P@=&AI<R!L:7-T(&]F
M(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX*("H@
M"B`J("`@*B!2961I<W1R:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R
M97!R;V1U8V4@=&AE(&%B;W9E(&-O<'ER:6=H=`H@*B`@("`@;F]T:6-E+"!T
M:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C
M;&%I;65R(&EN"B`J("`@("!T:&4@9&]C=6UE;G1A=&EO;B!A;F0O;W(@;W1H
M97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE"B`J("`@("!D:7-T<FEB
M=71I;VXN"B`J"B`J("`@*B!.96ET:&5R('1H92!N86UE(&]F(%-E8F%S=&EA
M;B!"97)G;6%N;B!N;W(@=&AE(&YA;65S(&]F(&AI<PH@*B`@("`@8V]N=')I
M8G5T;W)S(&UA>2!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92!P<F]D
M=6-T<R!D97)I=F5D"B`J("`@("!F<F]M('1H:7,@<V]F='=A<F4@=VET:&]U
M="!S<&5C:69I8R!P<FEO<B!W<FET=&5N('!E<FUI<W-I;VXN"B`J"B`J(%1(
M25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($-/4%E224=(5"!(3TQ$
M15)3($%.1"!#3TY44DE"551/4E,*("H@(D%3($E3(B!!3D0@04Y9($584%)%
M4U,@3U(@24U03$E%1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.3U0*
M("H@3$E-251%1"!43RP@5$A%($E-4$Q)140@5T%24D%.5$E%4R!/1B!-15)#
M2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,*("H@1D]2($$@4$%25$E#54Q!4B!0
M55)03U-%($%212!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4*
M("H@0T]065))1TA4($]73D52($]2($-/3E1224)55$]24R!"12!,24%"3$4@
M1D]2($%.62!$25)%0U0L($E.1$E214-4+`H@*B!)3D-)1$5.5$%,+"!34$5#
M24%,+"!%6$5-4$Q!4EDL($]2($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#
M3%5$24Y'+`H@*B!"550@3D]4($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&
M(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,["B`J($Q/4U,@3T8@55-%
M+"!$051!+"!/4B!04D]&2513.R!/4B!"55-)3D534R!)3E1%4E)54%1)3TXI
M($A/5T5615(*("H@0T%54T5$($%.1"!/3B!!3ED@5$A%3U)9($]&($Q)04))
M3$E462P@5TA%5$A%4B!)3B!#3TY44D%#5"P@4U1224,*("H@3$E!0DE,2519
M+"!/4B!43U)4("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I
M($%225-)3D<@24X*("H@04Y9(%=!62!/550@3T8@5$A%(%5312!/1B!42$E3
M(%-/1E1705)%+"!%5D5.($E&($%$5DE3140@3T8@5$A%"B`J(%!/4U-)0DE,
M2519($]&(%-50T@@1$%-04=%+@H@*@H@*B!`8V%T96=O<GD@("!497-T:6YG
M"B`J($!P86-K86=E("`@(%!(4%5N:70*("H@0&%U=&AO<B`@("`@4V5B87-T
M:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^"B`J($!C
M;W!Y<FEG:'0@(#(P,#(M,C`P-2!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E
M8F%S=&EA;BUB97)G;6%N;BYD93X*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W
M=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($)3
M1"!,:6-E;G-E"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!497-T1F%I;'5R
M92YP:'`L=B`Q+C$S(#(P,#4O,3$O,3`@,#DZ-#<Z,30@<V5B87-T:6%N($5X
M<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G
M92]02%!5;FET"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E
M(%)E;&5A<V4@,2XP+C`*("HO"@HO*BH*("H@02!497-T1F%I;'5R92!C;VQL
M96-T<R!A(&9A:6QE9"!T97-T('1O9V5T:&5R('=I=&@@=&AE(&-A=6=H="!E
M>&-E<'1I;VXN"B`J"B`J($!C871E9V]R>2`@(%1E<W1I;F<*("H@0'!A8VMA
M9V4@("`@4$A056YI=`H@*B!`875T:&]R("`@("!396)A<W1I86X@0F5R9VUA
M;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X*("H@0&-O<'ER:6=H="`@
M,C`P,BTR,#`U(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E
M<F=M86YN+F1E/@H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+F]P96YS;W5R
M8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*
M("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XS+C(*("H@0&QI;FL@("`@("`@
M:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!(4%5N:70*("H@0'-I;F-E
M("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XP+C`*("HO
M"F-L87-S(%!(4%5N:71?5&5S=$9A:6QU<F4@>PH@("`@+RHJ"B`@("`@*B!`
M=F%R("`@(&]B:F5C=`H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@('9A<B`D7V9A:6QE9%1E<W0["@H@("`@+RHJ"B`@("`@*B!`=F%R("`@
M('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A
M<B`D7W1H<F]W;D5X8V5P=&EO;CL*"B`@("`O*BH*("`@("`J($-O;G-T<G5C
M=',@82!497-T1F%I;'5R92!W:71H('1H92!G:79E;B!T97-T(&%N9"!E>&-E
M<'1I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE8W0*("`@("`J($!P
M87)A;2`@<W1R:6YG"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!02%!5;FET7U1E<W1&86EL=7)E*"8D9F%I;&5D5&5S="P@
M)B1T:')O=VY%>&-E<'1I;VXI('L*("`@("`@("`D=&AI<RT^7V9A:6QE9%1E
M<W0@("`@("`]("8D9F%I;&5D5&5S=#L*("`@("`@("`D=&AI<RT^7W1H<F]W
M;D5X8V5P=&EO;B`]("8D=&AR;W=N17AC97!T:6]N.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1V5T<R!T:&4@9F%I;&5D('1E<W0N"B`@("`@*@H@("`@("H@
M0')E='5R;B!O8FIE8W0*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N("9F86EL961497-T*"D@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^7V9A:6QE9%1E<W0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'971S
M('1H92!T:')O=VX@97AC97!T:6]N+@H@("`@("H*("`@("`J($!R971U<FX@
M;V)J96-T"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC
M=&EO;B`F=&AR;W=N17AC97!T:6]N*"D@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^7W1H<F]W;D5X8V5P=&EO;CL*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@82!S:&]R="!D97-C<FEP=&EO;B!O9B!T:&4@9F%I;'5R92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9PH@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J+PH@("`@9G5N8W1I;VX@=&]3=')I;F<H*2!["B`@("`@("`@
M<F5T=7)N('-P<FEN=&8H"B`@("`@("`@("`B5&5S=$-A<V4@)7,M/B5S*"D@
M9F%I;&5D.B`E<UQN(BP*"B`@("`@("`@("!G971?8VQA<W,H)'1H:7,M/E]F
M86EL961497-T*2P*("`@("`@("`@("1T:&ES+3Y?9F%I;&5D5&5S="T^9V5T
M3F%M92@I+`H@("`@("`@("`@)'1H:7,M/E]T:')O=VY%>&-E<'1I;VX*("`@
M("`@("`I.PH@("`@?0I]"@HO*@H@*B!,;V-A;"!V87)I86)L97,Z"B`J('1A
M8BUW:61T:#H@-`H@*B!C+6)A<VEC+6]F9G-E=#H@-`H@*B!C+6AA;F=I;F<M
M8V]M;65N="UE;F1E<BUP.B!N:6P*("H@16YD.@H@*B\*/SX*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]02%!5;FET+U1E<W1,
M:7-T96YE<BYP:'``````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$Q
M,#8U(#$P-3$U-#,S-S,Q(#`R,S$Q-``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T
M86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PH*
M+RHJ"B`J(%!(4"!697)S:6]N(#0*("H*("H@0V]P>7)I9VAT("AC*2`R,#`R
M+3(P,#4L(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M
M86YN+F1E/BX*("H@06QL(')I9VAT<R!R97-E<G9E9"X*("H*("H@4F5D:7-T
M<FEB=71I;VX@86YD('5S92!I;B!S;W5R8V4@86YD(&)I;F%R>2!F;W)M<RP@
M=VET:"!O<B!W:71H;W5T"B`J(&UO9&EF:6-A=&EO;BP@87)E('!E<FUI='1E
M9"!P<F]V:61E9"!T:&%T('1H92!F;VQL;W=I;F<@8V]N9&ET:6]N<PH@*B!A
M<F4@;65T.@H@*@H@*B`@("H@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C
M;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0*("H@("`@(&YO
M=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I
M;F<@9&ES8VQA:6UE<BX*("H@"B`J("`@*B!2961I<W1R:6)U=&EO;G,@:6X@
M8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B;W9E(&-O<'ER:6=H
M=`H@*B`@("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@
M=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN"B`J("`@("!T:&4@9&]C=6UE
M;G1A=&EO;B!A;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@
M=&AE"B`J("`@("!D:7-T<FEB=71I;VXN"B`J"B`J("`@*B!.96ET:&5R('1H
M92!N86UE(&]F(%-E8F%S=&EA;B!"97)G;6%N;B!N;W(@=&AE(&YA;65S(&]F
M(&AI<PH@*B`@("`@8V]N=')I8G5T;W)S(&UA>2!B92!U<V5D('1O(&5N9&]R
M<V4@;W(@<')O;6]T92!P<F]D=6-T<R!D97)I=F5D"B`J("`@("!F<F]M('1H
M:7,@<V]F='=A<F4@=VET:&]U="!S<&5C:69I8R!P<FEO<B!W<FET=&5N('!E
M<FUI<W-I;VXN"B`J"B`J(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@
M5$A%($-/4%E224=(5"!(3TQ$15)3($%.1"!#3TY44DE"551/4E,*("H@(D%3
M($E3(B!!3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!705)204Y42453+"!)
M3D-,541)3D<L($)55"!.3U0*("H@3$E-251%1"!43RP@5$A%($E-4$Q)140@
M5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,*("H@
M1D]2($$@4$%25$E#54Q!4B!055)03U-%($%212!$25-#3$%)345$+B!)3B!.
M3R!%5D5.5"!32$%,3"!42$4*("H@0T]065))1TA4($]73D52($]2($-/3E12
M24)55$]24R!"12!,24%"3$4@1D]2($%.62!$25)%0U0L($E.1$E214-4+`H@
M*B!)3D-)1$5.5$%,+"!34$5#24%,+"!%6$5-4$Q!4EDL($]2($-/3E-%455%
M3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'+`H@*B!"550@3D]4($Q)34E4140@
M5$\L(%!23T-54D5-14Y4($]&(%-50E-425155$4@1T]/1%,@3U(@4T525DE#
M15,["B`J($Q/4U,@3T8@55-%+"!$051!+"!/4B!04D]&2513.R!/4B!"55-)
M3D534R!)3E1%4E)54%1)3TXI($A/5T5615(*("H@0T%54T5$($%.1"!/3B!!
M3ED@5$A%3U)9($]&($Q)04))3$E462P@5TA%5$A%4B!)3B!#3TY44D%#5"P@
M4U1224,*("H@3$E!0DE,2519+"!/4B!43U)4("A)3D-,541)3D<@3D5'3$E'
M14Y#12!/4B!/5$A%4E=)4T4I($%225-)3D<@24X*("H@04Y9(%=!62!/550@
M3T8@5$A%(%5312!/1B!42$E3(%-/1E1705)%+"!%5D5.($E&($%$5DE3140@
M3T8@5$A%"B`J(%!/4U-)0DE,2519($]&(%-50T@@1$%-04=%+@H@*@H@*B!`
M8V%T96=O<GD@("!497-T:6YG"B`J($!P86-K86=E("`@(%!(4%5N:70*("H@
M0&%U=&AO<B`@("`@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM
M8F5R9VUA;FXN9&4^"B`J($!C;W!Y<FEG:'0@(#(P,#(M,C`P-2!396)A<W1I
M86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X*("H@0&QI
M8V5N<V4@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B
M<V0M;&EC96YS92YP:'`@($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@($-6
M4SH@)$ED.B!497-T3&ES=&5N97(N<&AP+'8@,2XQ,B`R,#`U+S$Q+S$P(#`Y
M.C0W.C$U('-E8F%S=&EA;B!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$A056YI=`H@*B!`<VEN8V4@("`@("!&
M:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N,"XP"B`J+PH*+RHJ"B`J
M($$@3&ES=&5N97(@9F]R('1E<W0@<')O9W)E<W,N"B`J"B`J($AE<F4@:7,@
M86X@97AA;7!L93H*("H*("H@/&-O9&4^"B`J(#P_<&AP"B`J(')E<75I<F5?
M;VYC92`G4$A056YI="YP:'`G.PH@*B!R97%U:7)E7V]N8V4@)U!(4%5N:70O
M5&5S=$QI<W1E;F5R+G!H<"<["B`J"B`J(&-L87-S($UA=&A497-T(&5X=&5N
M9',@4$A056YI=%]497-T0V%S92!["B`J("`@("!V87(@)&9686QU93$["B`J
M("`@("!V87(@)&9686QU93(["B`J"B`J("`@("!F=6YC=&EO;B!-871H5&5S
M="@D;F%M92D@>PH@*B`@("`@("`@("1T:&ES+3Y02%!5;FET7U1E<W1#87-E
M*"1N86UE*3L*("H@("`@('T*("H*("H@("`@(&9U;F-T:6]N('-E=%5P*"D@
M>PH@*B`@("`@("`@("1T:&ES+3YF5F%L=64Q(#T@,CL*("H@("`@("`@("`D
M=&AI<RT^9E9A;'5E,B`](#,["B`J("`@("!]"B`J"B`J("`@("!F=6YC=&EO
M;B!T97-T061D*"D@>PH@*B`@("`@("`@("1T:&ES+3YA<W-E<G14<G5E*"1T
M:&ES+3YF5F%L=64Q("L@)'1H:7,M/F9686QU93(@/3T@-"D["B`J("`@("!]
M"B`J('T*("H*("H@8VQA<W,@37E,:7-T96YE<B!E>'1E;F1S(%!(4%5N:71?
M5&5S=$QI<W1E;F5R('L*("H@("`@(&9U;F-T:6]N(&%D9$5R<F]R*"8D=&5S
M="P@)B1T*2!["B`J("`@("`@("`@<')I;G0@(DUY3&ES=&5N97(Z.F%D9$5R
M<F]R*"D@8V%L;&5D+EQN(CL*("H@("`@('T*("H*("H@("`@(&9U;F-T:6]N
M(&%D9$9A:6QU<F4H)B1T97-T+"`F)'0I('L*("H@("`@("`@("!P<FEN="`B
M37E,:7-T96YE<CHZ861D1F%I;'5R92@I(&-A;&QE9"Y<;B(["B`J("`@("!]
M"B`J"B`J("`@("!F=6YC=&EO;B!E;F1497-T*"8D=&5S="D@>PH@*B`@("`@
M("`@('!R:6YT(")->4QI<W1E;F5R.CIE;F1497-T*"D@8V%L;&5D+EQN(CL*
M("H@("`@('T*("H*("H@("`@(&9U;F-T:6]N('-T87)T5&5S="@F)'1E<W0I
M('L*("H@("`@("`@("!P<FEN="`B37E,:7-T96YE<CHZ<W1A<G1497-T*"D@
M8V%L;&5D+EQN(CL*("H@("`@('T*("H@?0H@*@H@*B`D<W5I=&4@/2!N97<@
M4$A056YI=%]497-T4W5I=&4["B`J("1S=6ET92T^861D5&5S="AN97<@36%T
M:%1E<W0H)W1E<W1!9&0G*2D["B`J"B`J("1R97-U;'0@/2!N97<@4$A056YI
M=%]497-T4F5S=6QT.PH@*B`D<F5S=6QT+3YA9&1,:7-T96YE<BAN97<@37E,
M:7-T96YE<BD["B`J"B`J("1S=6ET92T^<G5N*"1R97-U;'0I.PH@*B!P<FEN
M="`D<F5S=6QT+3YT;U-T<FEN9R@I.PH@*B`_/@H@*B`\+V-O9&4^"B`J"B`J
M($!C871E9V]R>2`@(%1E<W1I;F<*("H@0'!A8VMA9V4@("`@4$A056YI=`H@
M*B!`875T:&]R("`@("!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA
M;BUB97)G;6%N;BYD93X*("H@0&-O<'ER:6=H="`@,C`P,BTR,#`U(%-E8F%S
M=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/@H@*B!`
M;&EC96YS92`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S
M+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@
M4F5L96%S93H@,2XS+C(*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP
M+FYE="]P86-K86=E+U!(4%5N:70*("H@0'-I;F-E("`@("`@0VQA<W,@879A
M:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XP+C`*("HO"F-L87-S(%!(4%5N:71?
M5&5S=$QI<W1E;F5R('L*("`@("\J*@H@("`@("H@06X@97)R;W(@;V-C=7)R
M960N"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE8W0*("`@("`J($!P87)A
M;2`@;V)J96-T"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0&%B<W1R
M86-T"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$5R<F]R*"8D=&5S="P@)B1T
M*2![("\J86)S=')A8W0@*B\@?0H*("`@("\J*@H@("`@("H@02!F86EL=7)E
M(&]C8W5R<F5D+@H@("`@("H*("`@("`J($!P87)A;2`@;V)J96-T"B`@("`@
M*B!`<&%R86T@(&]B:F5C=`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M($!A8G-T<F%C=`H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1&86EL=7)E*"8D
M=&5S="P@)B1T*2![("\J86)S=')A8W0@*B\@?0H*("`@("\J*@H@("`@("H@
M02!T97-T(&5N9&5D+@H@("`@("H*("`@("`J($!P87)A;2`@;V)J96-T"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0&%B<W1R86-T"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&5N9%1E<W0H)B1T97-T*2![("\J86)S=')A8W0@*B\@
M?0H*("`@("\J*@H@("`@("H@02!T97-T('-T87)T960N"B`@("`@*@H@("`@
M("H@0'!A<F%M("!O8FIE8W0*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B!`86)S=')A8W0*("`@("`J+PH@("`@9G5N8W1I;VX@<W1A<G1497-T*"8D
M=&5S="D@>R`O*F%B<W1R86-T("HO('T*?0H*+RH*("H@3&]C86P@=F%R:6%B
M;&5S.@H@*B!T86(M=VED=&@Z(#0*("H@8RUB87-I8RUO9F9S970Z(#0*("H@
M8RUH86YG:6YG+6-O;6UE;G0M96YD97(M<#H@;FEL"B`J($5N9#H*("HO"C\^
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$A056YI
M="]497-T4F5S=6QT+G!H<```````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`R,#4R,"`Q,#4Q-30S,S<S,2`P,C(V,#$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RH@=FEM.B!S970@
M97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A8G-T;W`]
M-#H@*B\*"B\J*@H@*B!02%`@5F5R<VEO;B`T"B`J"B`J($-O<'ER:6=H="`H
M8RD@,C`P,BTR,#`U+"!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA
M;BUB97)G;6%N;BYD93XN"B`J($%L;"!R:6=H=',@<F5S97)V960N"B`J"B`J
M(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B:6YA<GD@
M9F]R;7,L('=I=&@@;W(@=VET:&]U=`H@*B!M;V1I9FEC871I;VXL(&%R92!P
M97)M:71T960@<')O=FED960@=&AA="!T:&4@9F]L;&]W:6YG(&-O;F1I=&EO
M;G,*("H@87)E(&UE=#H*("H*("H@("`J(%)E9&ES=')I8G5T:6]N<R!O9B!S
M;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I9VAT"B`J
M("`@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@
M9F]L;&]W:6YG(&1I<V-L86EM97(N"B`J(`H@*B`@("H@4F5D:7-T<FEB=71I
M;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C
M;W!Y<FEG:'0*("H@("`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO
M;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;@H@*B`@("`@=&AE
M(&1O8W5M96YT871I;VX@86YD+V]R(&]T:&5R(&UA=&5R:6%L<R!P<F]V:61E
M9"!W:71H('1H90H@*B`@("`@9&ES=')I8G5T:6]N+@H@*@H@*B`@("H@3F5I
M=&AE<B!T:&4@;F%M92!O9B!396)A<W1I86X@0F5R9VUA;FX@;F]R('1H92!N
M86UE<R!O9B!H:7,*("H@("`@(&-O;G1R:6)U=&]R<R!M87D@8F4@=7-E9"!T
M;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O9'5C=',@9&5R:79E9`H@*B`@("`@
M9G)O;2!T:&ES('-O9G1W87)E('=I=&AO=70@<W!E8VEF:6,@<')I;W(@=W)I
M='1E;B!P97)M:7-S:6]N+@H@*@H@*B!42$E3(%-/1E1705)%($E3(%!23U9)
M1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$524R!!3D0@0T].5%))0E543U)3
M"B`J(")!4R!)4R(@04Y$($%.62!%6%!215-3($]2($E-4$Q)140@5T%24D%.
M5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4"B`J($Q)34E4140@5$\L(%1(12!)
M35!,245$(%=!4E)!3E1)15,@3T8@34520TA!3E1!0DE,2519($%.1"!&251.
M15-3"B`J($9/4B!!(%!!4E1)0U5,05(@4%524$]312!!4D4@1$E30TQ!24U%
M1"X@24X@3D\@159%3E0@4TA!3$P@5$A%"B`J($-/4%E224=(5"!/5TY%4B!/
M4B!#3TY44DE"551/4E,@0D4@3$E!0DQ%($9/4B!!3ED@1$E214-4+"!)3D1)
M4D5#5"P*("H@24Y#241%3E1!3"P@4U!%0TE!3"P@15A%35!,05)9+"!/4B!#
M3TY315%514Y424%,($1!34%'15,@*$E.0TQ51$E.1RP*("H@0E54($Y/5"!,
M24U)5$5$(%1/+"!04D]#55)%345.5"!/1B!354)35$E4551%($=/3T13($]2
M(%-%4E9)0T53.PH@*B!,3U-3($]&(%5312P@1$%402P@3U(@4%)/1DE44SL@
M3U(@0E5324Y%4U,@24Y415)255!424].*2!(3U=%5D52"B`J($-!55-%1"!!
M3D0@3TX@04Y9(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(15(@24X@0T].
M5%)!0U0L(%-44DE#"B`J($Q)04))3$E462P@3U(@5$]25"`H24Y#3%5$24Y'
M($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!4DE324Y'($E."B`J($%.62!7
M05D@3U54($]&(%1(12!54T4@3T8@5$A)4R!33T945T%212P@159%3B!)1B!!
M1%9)4T5$($]&(%1(10H@*B!03U-324))3$E462!/1B!354-(($1!34%'12X*
M("H*("H@0&-A=&5G;W)Y("`@5&5S=&EN9PH@*B!`<&%C:V%G92`@("!02%!5
M;FET"B`J($!A=71H;W(@("`@(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B
M87-T:6%N+6)E<F=M86YN+F1E/@H@*B!`8V]P>7)I9VAT("`R,#`R+3(P,#4@
M4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^
M"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC
M96YS97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO
M;B`@("!#5E,Z("1)9#H@5&5S=%)E<W5L="YP:'`L=B`Q+C$X(#(P,#4O,3$O
M,3`@,#DZ-#<Z,34@<V5B87-T:6%N($5X<"`D"B`J($!L:6YK("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]02%!5;FET"B`J($!S:6YC92`@
M("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XP+C`*("HO"@IR
M97%U:7)E7V]N8V4@)U!(4%5N:70O5&5S=$9A:6QU<F4N<&AP)SL*<F5Q=6ER
M95]O;F-E("=02%!5;FET+U1E<W1,:7-T96YE<BYP:'`G.PH*:68@*"%F=6YC
M=&EO;E]E>&ES=',H)VES7V$G*2D@>PH@("`@<F5Q=6ER95]O;F-E("=02%`O
M0V]M<&%T+T9U;F-T:6]N+VES7V$N<&AP)SL*?0H*+RHJ"B`J($$@5&5S=%)E
M<W5L="!C;VQL96-T<R!T:&4@<F5S=6QT<R!O9B!E>&5C=71I;F<@82!T97-T
M(&-A<V4N"B`J"B`J($!C871E9V]R>2`@(%1E<W1I;F<*("H@0'!A8VMA9V4@
M("`@4$A056YI=`H@*B!`875T:&]R("`@("!396)A<W1I86X@0F5R9VUA;FX@
M/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X*("H@0&-O<'ER:6=H="`@,C`P
M,BTR,#`U(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M
M86YN+F1E/@H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N
M;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@
M0'9E<G-I;VX@("`@4F5L96%S93H@,2XS+C(*("H@0&QI;FL@("`@("`@:'1T
M<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!(4%5N:70*("H@0'-I;F-E("`@
M("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XP+C`*("HO"F-L
M87-S(%!(4%5N:71?5&5S=%)E<W5L="!["B`@("`O*BH*("`@("`J($!V87(@
M("`@87)R87D*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B\*("`@
M('9A<B`D7V5R<F]R<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!`=F%R
M("`@(&%R<F%Y"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@("HO"B`@
M("!V87(@)%]F86EL=7)E<R`](&%R<F%Y*"D["@H@("`@("\J*@H@("`@("H@
M0'9A<B`@("!A<G)A>0H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J
M+PH@("`@=F%R("1?;&ES=&5N97)S(#T@87)R87DH*3L*"B`@("`O*BH*("`@
M("`J($!V87(@("`@87)R87D*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@
M("`@*B\*("`@('9A<B`D7W!A<W-E9%1E<W1S(#T@87)R87DH*3L*"B`@("`O
M*BH*("`@("`J($!V87(@("`@:6YT96=E<@H@("`@("H@0&%C8V5S<R!P<F]T
M96-T960*("`@("`J+PH@("`@=F%R("1?<G5N5&5S=',@/2`P.PH*("`@("\J
M*@H@("`@("H@0'9A<B`@("!B;V]L96%N"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@=F%R("1?<W1O<"`]($9!3%-%.PH*("`@("\J*@H@
M("`@("H@061D<R!A;B!E<G)O<B!T;R!T:&4@;&ES="!O9B!E<G)O<G,N"B`@
M("`@*B!4:&4@<&%S<V5D(&EN(&5X8V5P=&EO;B!C875S960@=&AE(&5R<F]R
M+@H@("`@("H*("`@("`J($!P87)A;2`@;V)J96-T"B`@("`@*B!`<&%R86T@
M(&]B:F5C=`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N
M8W1I;VX@861D17)R;W(H)B1T97-T+"`F)'0I('L*("`@("`@("`D=&AI<RT^
M7V5R<F]R<UM=(#T@;F5W(%!(4%5N:71?5&5S=$9A:6QU<F4H)'1E<W0L("1T
M*3L*"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F*"1T:&ES+3Y?
M;&ES=&5N97)S*3L@)&DK*RD@>PH@("`@("`@("`@("`D=&AI<RT^7VQI<W1E
M;F5R<ULD:5TM/F%D9$5R<F]R*"1T97-T+"`D="D["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@061D<R!A(&9A:6QU<F4@=&\@=&AE(&QI<W0@
M;V8@9F%I;'5R97,N"B`@("`@*B!4:&4@<&%S<V5D(&EN(&5X8V5P=&EO;B!C
M875S960@=&AE(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE
M8W0*("`@("`J($!P87)A;2`@;V)J96-T"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!A9&1&86EL=7)E*"8D=&5S="P@)B1T
M*2!["B`@("`@("`@)'1H:7,M/E]F86EL=7)E<UM=(#T@;F5W(%!(4%5N:71?
M5&5S=$9A:6QU<F4H)'1E<W0L("1T*3L*"B`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P@<VEZ96]F*"1T:&ES+3Y?;&ES=&5N97)S*3L@)&DK*RD@>PH@("`@
M("`@("`@("`D=&AI<RT^7VQI<W1E;F5R<ULD:5TM/F%D9$9A:6QU<F4H)'1E
M<W0L("1T*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296=I
M<W1E<G,@82!497-T3&ES=&5N97(N"B`@("`@*@H@("`@("H@0'!A<F%M("!O
M8FIE8W0*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%D9$QI<W1E;F5R*"8D;&ES=&5N97(I('L*("`@("`@("!I9B`H:7-?
M;V)J96-T*"1L:7-T96YE<BD@)B8*("`@("`@("`@("`@:7-?82@D;&ES=&5N
M97(L("=02%!5;FET7U1E<W1,:7-T96YE<B<I*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?;&ES=&5N97)S6UT@/2`F)&QI<W1E;F5R.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($%D9',@82!P87-S960@=&5S="!T;R!T:&4@
M;&ES="!O9B!P87-S960@=&5S=',N"B`@("`@*@H@("`@("H@0'!A<F%M("!O
M8FIE8W0*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%D9%!A<W-E9%1E<W0H)B1T97-T*2!["B`@("`@("`@)'1H:7,M/E]P
M87-S961497-T<UM=(#T@)B1T97-T.PH@("`@?0H*("`@("\J*@H@("`@("H@
M26YF;W)M<R!T:&4@<F5S=6QT('1H870@82!T97-T('=A<R!C;VUP;&5T960N
M"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE8W0*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N9%1E<W0H)B1T97-T*2![
M"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F*"1T:&ES+3Y?;&ES
M=&5N97)S*3L@)&DK*RD@>PH@("`@("`@("`@("`D=&AI<RT^7VQI<W1E;F5R
M<ULD:5TM/F5N9%1E<W0H)'1E<W0I.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($=E=',@=&AE(&YU;6)E<B!O9B!D971E8W1E9"!E<G)O<G,N
M"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!E<G)O<D-O=6YT*"D@>PH@
M("`@("`@(')E='5R;B!S:7IE;V8H)'1H:7,M/E]E<G)O<G,I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!%;G5M97)A=&EO;B!F;W(@=&AE
M(&5R<F]R<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B`F97)R;W)S*"D@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V5R<F]R<SL*("`@('T*"B`@("`O
M*BH*("`@("`J($=E=',@=&AE(&YU;6)E<B!O9B!D971E8W1E9"!F86EL=7)E
M<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&9A:6QU<F5#;W5N="@I
M('L*("`@("`@("!R971U<FX@<VEZ96]F*"1T:&ES+3Y?9F%I;'5R97,I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!%;G5M97)A=&EO;B!F
M;W(@=&AE(&9A:6QU<F5S+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N("9F
M86EL=7)E<R@I('L*("`@("`@("!R971U<FX@)'1H:7,M/E]F86EL=7)E<SL*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86X@16YU;65R871I;VX@
M9F]R('1H92!P87-S960@=&5S=',N"B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>0H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I
M;VX@)G!A<W-E9%1E<W1S*"D@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W!A
M<W-E9%1E<W1S.PH@("`@?0H*("`@("\J*@H@("`@("H@56YR96=I<W1E<G,@
M82!497-T3&ES=&5N97(N"B`@("`@*B!4:&ES(')E<75I<F5S('1H92!:96YD
M($5N9VEN92`R("AT;R!W;W)K('!R;W!E<FQY*2X*("`@("`J"B`@("`@*B!`
M<&%R86T@(&]B:F5C=`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@<F5M;W9E3&ES=&5N97(H)B1L:7-T96YE<BD@>PH@("`@
M("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D=&AI<RT^7VQI<W1E;F5R
M<RD[("1I*RLI('L*("`@("`@("`@("`@:68@*"1T:&ES+3Y?;&ES=&5N97)S
M6R1I72`]/3T@)&QI<W1E;F5R*2!["B`@("`@("`@("`@("`@("!U;G-E="@D
M=&AI<RT^7VQI<W1E;F5R<ULD:5TI.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@4G5N<R!A(%1E<W1#87-E+@H@("`@
M("H*("`@("`J($!P87)A;2`@;V)J96-T"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!R=6XH)B1T97-T*2!["B`@("`@("`@
M)'1H:7,M/G-T87)T5&5S="@D=&5S="D["B`@("`@("`@)'1H:7,M/E]R=6Y4
M97-T<RLK.PH@("`@("`@("1T97-T+3YR=6Y"87)E*"D["B`@("`@("`@)'1H
M:7,M/F5N9%1E<W0H)'1E<W0I.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T
M<R!T:&4@;G5M8F5R(&]F(')U;B!T97-T<RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&EN=&5G97(*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@
M(&9U;F-T:6]N(')U;D-O=6YT*"D@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M7W)U;E1E<W1S.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS('=H971H
M97(@=&AE('1E<W0@<G5N('-H;W5L9"!S=&]P+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('-H;W5L9%-T;W`H
M*2!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<W1O<#L*("`@('T*"B`@("`O
M*BH*("`@("`J($EN9F]R;7,@=&AE(')E<W5L="!T:&%T(&$@=&5S="!W:6QL
M(&)E('-T87)T960N"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE8W0*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('-T87)T
M5&5S="@F)'1E<W0I('L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE
M;V8H)'1H:7,M/E]L:7-T96YE<G,I.R`D:2LK*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?;&ES=&5N97)S6R1I72T^<W1A<G1497-T*"1T97-T*3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!-87)K<R!T:&%T('1H92!T97-T
M(')U;B!S:&]U;&0@<W1O<"X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!S=&]P*"D@>PH@("`@("`@("1T:&ES
M+3Y?<W1O<"`](%12544["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M(&$@2%1-3"!R97!R97-E;G1A=&EO;B!O9B!T:&4@=&5S="!R97-U;'0N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('1O2%1-3"@I('L*("`@("`@("!R
M971U<FX@)SQP<F4^)R`N(&AT;6QS<&5C:6%L8VAA<G,H)'1H:7,M/G1O4W1R
M:6YG*"DI("X@)SPO<')E/B<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS(&$@=&5X="!R97!R97-E;G1A=&EO;B!O9B!T:&4@=&5S="!R97-U;'0N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('1O4W1R:6YG*"D@>PH@("`@
M("`@("1R97-U;'0@/2`G)SL*"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]P
M87-S961497-T<R!A<R`D<&%S<V5D5&5S="D@>PH@("`@("`@("`@("`D<F5S
M=6QT("X]('-P<FEN=&8H"B`@("`@("`@("`@("`@(E1E<W1#87-E("5S+3XE
M<R@I('!A<W-E9%QN(BP*"B`@("`@("`@("`@("`@9V5T7V-L87-S*"1P87-S
M961497-T*2P*("`@("`@("`@("`@("`D<&%S<V5D5&5S="T^9V5T3F%M92@I
M"B`@("`@("`@("`@("D["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D
M=&AI<RT^7V9A:6QU<F5S(&%S("1F86EL961497-T*2!["B`@("`@("`@("`@
M("1R97-U;'0@+CT@)&9A:6QE9%1E<W0M/G1O4W1R:6YG*"D["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=VAE=&AE<B!T:&4@96YT:7)E('1E<W0@=V%S('-U8V-E
M<W-F=6P@;W(@;F]T+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@=V%S
M4W5C8V5S<V9U;"@I('L*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]E<G)O
M<G,I("8F(&5M<'1Y*"1T:&ES+3Y?9F%I;'5R97,I*2!["B`@("`@("`@("`@
M(')E='5R;B!44E5%.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B!&04Q313L*("`@("`@("!]"B`@("!]"GT*"B\J"B`J($QO8V%L('9A
M<FEA8FQE<SH*("H@=&%B+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T
M"B`J(&,M:&%N9VEN9RUC;VUM96YT+65N9&5R+7`Z(&YI;`H@*B!%;F0Z"B`J
M+PH_/@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$A056YI="]497-T4W5I
M=&4N<&AP````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q-3(V
M-"`Q,#4Q-30S,S<S,2`P,C(T,C4`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B
M('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*"B\J
M*@H@*B!02%`@5F5R<VEO;B`T"B`J"B`J($-O<'ER:6=H="`H8RD@,C`P,BTR
M,#`U+"!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N
M;BYD93XN"B`J($%L;"!R:6=H=',@<F5S97)V960N"B`J"B`J(%)E9&ES=')I
M8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I
M=&@@;W(@=VET:&]U=`H@*B!M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@
M<')O=FED960@=&AA="!T:&4@9F]L;&]W:6YG(&-O;F1I=&EO;G,*("H@87)E
M(&UE=#H*("H*("H@("`J(%)E9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D
M92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I9VAT"B`J("`@("!N;W1I
M8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG
M(&1I<V-L86EM97(N"B`J(`H@*B`@("H@4F5D:7-T<FEB=71I;VYS(&EN(&)I
M;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0*
M("H@("`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H
M92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;@H@*B`@("`@=&AE(&1O8W5M96YT
M871I;VX@86YD+V]R(&]T:&5R(&UA=&5R:6%L<R!P<F]V:61E9"!W:71H('1H
M90H@*B`@("`@9&ES=')I8G5T:6]N+@H@*@H@*B`@("H@3F5I=&AE<B!T:&4@
M;F%M92!O9B!396)A<W1I86X@0F5R9VUA;FX@;F]R('1H92!N86UE<R!O9B!H
M:7,*("H@("`@(&-O;G1R:6)U=&]R<R!M87D@8F4@=7-E9"!T;R!E;F1O<G-E
M(&]R('!R;VUO=&4@<')O9'5C=',@9&5R:79E9`H@*B`@("`@9G)O;2!T:&ES
M('-O9G1W87)E('=I=&AO=70@<W!E8VEF:6,@<')I;W(@=W)I='1E;B!P97)M
M:7-S:6]N+@H@*@H@*B!42$E3(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(
M12!#3U!94DE'2%0@2$],1$524R!!3D0@0T].5%))0E543U)3"B`J(")!4R!)
M4R(@04Y$($%.62!%6%!215-3($]2($E-4$Q)140@5T%24D%.5$E%4RP@24Y#
M3%5$24Y'+"!"550@3D]4"B`J($Q)34E4140@5$\L(%1(12!)35!,245$(%=!
M4E)!3E1)15,@3T8@34520TA!3E1!0DE,2519($%.1"!&251.15-3"B`J($9/
M4B!!(%!!4E1)0U5,05(@4%524$]312!!4D4@1$E30TQ!24U%1"X@24X@3D\@
M159%3E0@4TA!3$P@5$A%"B`J($-/4%E224=(5"!/5TY%4B!/4B!#3TY44DE"
M551/4E,@0D4@3$E!0DQ%($9/4B!!3ED@1$E214-4+"!)3D1)4D5#5"P*("H@
M24Y#241%3E1!3"P@4U!%0TE!3"P@15A%35!,05)9+"!/4B!#3TY315%514Y4
M24%,($1!34%'15,@*$E.0TQ51$E.1RP*("H@0E54($Y/5"!,24U)5$5$(%1/
M+"!04D]#55)%345.5"!/1B!354)35$E4551%($=/3T13($]2(%-%4E9)0T53
M.PH@*B!,3U-3($]&(%5312P@1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%
M4U,@24Y415)255!424].*2!(3U=%5D52"B`J($-!55-%1"!!3D0@3TX@04Y9
M(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(15(@24X@0T].5%)!0U0L(%-4
M4DE#"B`J($Q)04))3$E462P@3U(@5$]25"`H24Y#3%5$24Y'($Y%1TQ)1T5.
M0T4@3U(@3U1(15)725-%*2!!4DE324Y'($E."B`J($%.62!705D@3U54($]&
M(%1(12!54T4@3T8@5$A)4R!33T945T%212P@159%3B!)1B!!1%9)4T5$($]&
M(%1(10H@*B!03U-324))3$E462!/1B!354-(($1!34%'12X*("H*("H@0&-A
M=&5G;W)Y("`@5&5S=&EN9PH@*B!`<&%C:V%G92`@("!02%!5;FET"B`J($!A
M=71H;W(@("`@(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E
M<F=M86YN+F1E/@H@*B!`8V]P>7)I9VAT("`R,#`R+3(P,#4@4V5B87-T:6%N
M($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^"B`J($!L:6-E
M;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D
M+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@("!#5E,Z
M("1)9#H@5&5S=%-U:71E+G!H<"QV(#$N,3<@,C`P-2\Q,2\Q,"`P.3HT-SHQ
M-2!S96)A<W1I86X@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N
M<&AP+FYE="]P86-K86=E+U!(4%5N:70*("H@0'-I;F-E("`@("`@1FEL92!A
M=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C`N,`H@*B\*"G)E<75I<F5?;VYC
M92`G4$A056YI="]497-T0V%S92YP:'`G.PH*+RHJ"B`J($$@5&5S=%-U:71E
M(&ES(&$@0V]M<&]S:71E(&]F(%1E<W1S+B!)="!R=6YS(&$@8V]L;&5C=&EO
M;B!O9B!T97-T(&-A<V5S+@H@*@H@*B!(97)E(&ES(&%N(&5X86UP;&4@=7-I
M;F<@=&AE(&1Y;F%M:6,@=&5S="!D969I;FET:6]N+@H@*@H@*B`\8V]D93X*
M("H@/#]P:'`*("H@)'-U:71E(#T@;F5W(%!(4%5N:71?5&5S=%-U:71E*"D[
M"B`J("1S=6ET92T^861D5&5S="AN97<@36%T:%1E<W0H)W1E<W1087-S)RDI
M.PH@*B`_/@H@*B`\+V-O9&4^"B`J"B`J($%L=&5R;F%T:79E;'DL(&$@5&5S
M=%-U:71E(&-A;B!E>'1R86-T('1H92!T97-T<R!T;R!B92!R=6X@875T;VUA
M=&EC86QL>2X*("H@5&\@9&\@<V\@>6]U('!A<W,@=&AE(&-L87-S;F%M92!O
M9B!Y;W5R(%1E<W1#87-E(&-L87-S('1O('1H92!497-T4W5I=&4*("H@8V]N
M<W1R=6-T;W(N"B`J"B`J(#QC;V1E/@H@*B`\/W!H<`H@*B`D<W5I=&4@/2!N
M97<@5&5S=%-U:71E*"=C;&%S<VYA;64G*3L*("H@/SX*("H@/"]C;V1E/@H@
M*@H@*B!4:&ES(&-O;G-T<G5C=&]R(&-R96%T97,@82!S=6ET92!W:71H(&%L
M;"!T:&4@;65T:&]D<R!S=&%R=&EN9R!W:71H"B`J(")T97-T(B!T:&%T('1A
M:V4@;F\@87)G=6UE;G1S+@H@*@H@*B!`8V%T96=O<GD@("!497-T:6YG"B`J
M($!P86-K86=E("`@(%!(4%5N:70*("H@0&%U=&AO<B`@("`@4V5B87-T:6%N
M($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^"B`J($!C;W!Y
M<FEG:'0@(#(P,#(M,C`P-2!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S
M=&EA;BUB97)G;6%N;BYD93X*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYO
M<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($)31"!,
M:6-E;G-E"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N,RXR"B`J($!L:6YK
M("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]02%!5;FET"B`J
M($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#$N
M,"XP"B`J+PIC;&%S<R!02%!5;FET7U1E<W13=6ET92!["B`@("`O*BH*("`@
M("`J(%1H92!N86UE(&]F('1H92!T97-T('-U:71E+@H@("`@("H*("`@("`J
M($!V87(@("`@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M+PH@("`@=F%R("1?;F%M92`]("<G.PH*("`@("\J*@H@("`@("H@5&AE('1E
M<W1S(&EN('1H92!T97-T('-U:71E+@H@("`@("H*("`@("`J($!V87(@("`@
M87)R87D*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@
M)%]T97-T<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S
M(&$@5&5S=%-U:71E+@H@("`@("H*("`@("`J($!P87)A;2`@;6EX960*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(%!(4%5N
M:71?5&5S=%-U:71E*"1T97-T(#T@1D%,4T4I('L*("`@("`@("!I9B`H)'1E
M<W0@(3T]($9!3%-%*2!["B`@("`@("`@("`@("1T:&ES+3YS971.86UE*"1T
M97-T*3L*("`@("`@("`@("`@)'1H:7,M/F%D9%1E<W13=6ET92@D=&5S="D[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@061D<R!A('1E<W0@
M=&\@=&AE('-U:71E+@H@("`@("H*("`@("`J($!P87)A;2`@;V)J96-T"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!A9&14
M97-T*"8D=&5S="D@>PH@("`@("`@("1T:&ES+3Y?=&5S='-;72`]("8D=&5S
M=#L*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@=&AE('1E<W1S(&9R;VT@
M=&AE(&=I=F5N(&-L87-S('1O('1H92!S=6ET92X*("`@("`J"B`@("`@*B!`
M<&%R86T@('-T<FEN9PH@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@861D5&5S=%-U:71E*"1T97-T0VQA<W,I('L*("`@("`@
M("!I9B`H8VQA<W-?97AI<W1S*"1T97-T0VQA<W,I*2!["B`@("`@("`@("`@
M("1M971H;V1S("`@("`@(#T@9V5T7V-L87-S7VUE=&AO9',H)'1E<W1#;&%S
M<RD["B`@("`@("`@("`@("1P87)E;G1#;&%S<V5S(#T@87)R87DH<W1R=&]L
M;W=E<B@D=&5S=$-L87-S*2D["B`@("`@("`@("`@("1P87)E;G1#;&%S<R`@
M(#T@)'1E<W1#;&%S<SL*"B`@("`@("`@("`@('=H:6QE*&ES7W-T<FEN9R@D
M<&%R96YT0VQA<W,@/2!G971?<&%R96YT7V-L87-S*"1P87)E;G1#;&%S<RDI
M*2!["B`@("`@("`@("`@("`@("`D<&%R96YT0VQA<W-E<UM=(#T@)'!A<F5N
M=$-L87-S.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!F;W)E86-H("@D
M;65T:&]D<R!A<R`D;65T:&]D*2!["B`@("`@("`@("`@("`@("!I9B`H<W5B
M<W1R*"1M971H;V0L(#`L(#0I(#T]("=T97-T)R`F)@H@("`@("`@("`@("`@
M("`@("`@("%I;E]A<G)A>2@D;65T:&]D+"`D<&%R96YT0VQA<W-E<RDI('L*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^861D5&5S="AN97<@)'1E<W1#
M;&%S<R@D;65T:&]D*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;W5N=',@=&AE
M(&YU;6)E<B!O9B!T97-T(&-A<V5S('1H870@=VEL;"!B92!R=6X@8GD@=&AI
M<R!T97-T+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@8V]U;G1497-T
M0V%S97,H*2!["B`@("`@("`@)&-O=6YT(#T@,#L*"B`@("`@("`@9F]R96%C
M:"`H)'1H:7,M/E]T97-T<R!A<R`D=&5S="D@>PH@("`@("`@("`@("`D8V]U
M;G0@*ST@)'1E<W0M/F-O=6YT5&5S=$-A<V5S*"D["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)&-O=6YT.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@;F%M92!O9B!T:&4@<W5I=&4N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$YA;64H*2!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M;F%M93L*("`@('T*"B`@("`O*BH*("`@("`J(%)U;G,@=&AE('1E<W1S(&%N
M9"!C;VQL96-T<R!T:&5I<B!R97-U;'0@:6X@82!497-T4F5S=6QT+@H@("`@
M("H*("`@("`J($!P87)A;2`@;V)J96-T"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!R=6XH)B1R97-U;'0I('L*("`@("`@
M("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'1H:7,M/E]T97-T<RD@)B8@
M(21R97-U;'0M/G-H;W5L9%-T;W`H*3L@)&DK*RD@>PH@("`@("`@("`@("`D
M=&AI<RT^7W1E<W1S6R1I72T^<G5N*"1R97-U;'0I.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J(%)U;G,@82!T97-T+@H@("`@("H*("`@("`J
M($!P87)A;2`@;V)J96-T"B`@("`@*B!`<&%R86T@(&]B:F5C=`H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<G5N5&5S="@F
M)'1E<W0L("8D<F5S=6QT*2!["B`@("`@("`@)'1E<W0M/G)U;B@D<F5S=6QT
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE(&YA;64@;V8@=&AE
M('-U:71E+@H@("`@("H*("`@("`J($!P87)A;2`@<W1R:6YG"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!S971.86UE*"1N
M86UE*2!["B`@("`@("`@)'1H:7,M/E]N86UE(#T@)&YA;64["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!T97-T(&%T('1H92!G:79E;B!I
M;F1E>"X*("`@("`J"B`@("`@*B!`<&%R86T@(&EN=&5G97(*("`@("`J($!R
M971U<FX@;V)J96-T"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@
M("!F=6YC=&EO;B`F=&5S=$%T*"1I;F1E>"D@>PH@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7W1E<W1S6R1I;F1E>%TI*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7W1E<W1S6R1I;F1E>%T["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<F5T=7)N($9!3%-%.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE(&YU;6)E<B!O9B!T97-T<R!I;B!T:&ES
M('-U:71E+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@=&5S=$-O=6YT
M*"D@>PH@("`@("`@(')E='5R;B!S:7IE;V8H)'1H:7,M/E]T97-T<RD["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!T97-T<R!A<R!A;B!E
M;G5M97)A=&EO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B`F=&5S=',H
M*2!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=&5S=',["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS(&$@<W1R:6YG(')E<')E<V5N=&%T:6]N(&]F
M('1H92!T97-T('-U:71E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!T
M;U-T<FEN9R@I('L*("`@("`@("!R971U<FX@)R<["B`@("!]"GT*"B\J"B`J
M($QO8V%L('9A<FEA8FQE<SH*("H@=&%B+7=I9'1H.B`T"B`J(&,M8F%S:6,M
M;V9F<V5T.B`T"B`J(&,M:&%N9VEN9RUC;VUM96YT+65N9&5R+7`Z(&YI;`H@
M*B!%;F0Z"B`J+PH_/@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O4$A056YI="]!<W-E<G0N<&AP````````````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R-S(S-"`Q,#4Q-30S,S<S,2`P
M,C$W,S4`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF
M='=I9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*"B\J*@H@*B!02%`@5F5R<VEO
M;B`T"B`J"B`J($-O<'ER:6=H="`H8RD@,C`P,BTR,#`U+"!396)A<W1I86X@
M0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93XN"B`J($%L;"!R
M:6=H=',@<F5S97)V960N"B`J"B`J(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@
M:6X@<V]U<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U=`H@
M*B!M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@<')O=FED960@=&AA="!T
M:&4@9F]L;&]W:6YG(&-O;F1I=&EO;G,*("H@87)E(&UE=#H*("H*("H@("`J
M(%)E9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T
M:&4@86)O=F4@8V]P>7)I9VAT"B`J("`@("!N;W1I8V4L('1H:7,@;&ES="!O
M9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N"B`J
M(`H@*B`@("H@4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@
M<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0*("H@("`@(&YO=&EC92P@
M=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES
M8VQA:6UE<B!I;@H@*B`@("`@=&AE(&1O8W5M96YT871I;VX@86YD+V]R(&]T
M:&5R(&UA=&5R:6%L<R!P<F]V:61E9"!W:71H('1H90H@*B`@("`@9&ES=')I
M8G5T:6]N+@H@*@H@*B`@("H@3F5I=&AE<B!T:&4@;F%M92!O9B!396)A<W1I
M86X@0F5R9VUA;FX@;F]R('1H92!N86UE<R!O9B!H:7,*("H@("`@(&-O;G1R
M:6)U=&]R<R!M87D@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O
M9'5C=',@9&5R:79E9`H@*B`@("`@9G)O;2!T:&ES('-O9G1W87)E('=I=&AO
M=70@<W!E8VEF:6,@<')I;W(@=W)I='1E;B!P97)M:7-S:6]N+@H@*@H@*B!4
M2$E3(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],
M1$524R!!3D0@0T].5%))0E543U)3"B`J(")!4R!)4R(@04Y$($%.62!%6%!2
M15-3($]2($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4
M"B`J($Q)34E4140@5$\L(%1(12!)35!,245$(%=!4E)!3E1)15,@3T8@3452
M0TA!3E1!0DE,2519($%.1"!&251.15-3"B`J($9/4B!!(%!!4E1)0U5,05(@
M4%524$]312!!4D4@1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%
M"B`J($-/4%E224=(5"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4@3$E!0DQ%
M($9/4B!!3ED@1$E214-4+"!)3D1)4D5#5"P*("H@24Y#241%3E1!3"P@4U!%
M0TE!3"P@15A%35!,05)9+"!/4B!#3TY315%514Y424%,($1!34%'15,@*$E.
M0TQ51$E.1RP*("H@0E54($Y/5"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/
M1B!354)35$E4551%($=/3T13($]2(%-%4E9)0T53.PH@*B!,3U-3($]&(%53
M12P@1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,@24Y415)255!424].
M*2!(3U=%5D52"B`J($-!55-%1"!!3D0@3TX@04Y9(%1(14]262!/1B!,24%"
M24Q)5%DL(%=(151(15(@24X@0T].5%)!0U0L(%-44DE#"B`J($Q)04))3$E4
M62P@3U(@5$]25"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%
M*2!!4DE324Y'($E."B`J($%.62!705D@3U54($]&(%1(12!54T4@3T8@5$A)
M4R!33T945T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(10H@*B!03U-324))
M3$E462!/1B!354-(($1!34%'12X*("H*("H@0&-A=&5G;W)Y("`@5&5S=&EN
M9PH@*B!`<&%C:V%G92`@("!02%!5;FET"B`J($!A=71H;W(@("`@(%-E8F%S
M=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/@H@*B!`
M8V]P>7)I9VAT("`R,#`R+3(P,#4@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S
M96)A<W1I86XM8F5R9VUA;FXN9&4^"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W
M=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!"
M4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@07-S97)T+G!H
M<"QV(#$N,CD@,C`P-2\Q,2\Q,"`P.3HT-SHQ-"!S96)A<W1I86X@17AP("0*
M("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!(
M4%5N:70*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L
M96%S92`Q+C`N,`H@*B\*"B\J*@H@*B!!('-E="!O9B!A<W-E<G0@;65T:&]D
M<RX*("H*("H@0&-A=&5G;W)Y("`@5&5S=&EN9PH@*B!`<&%C:V%G92`@("!0
M2%!5;FET"B`J($!A=71H;W(@("`@(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`
M<V5B87-T:6%N+6)E<F=M86YN+F1E/@H@*B!`8V]P>7)I9VAT("`R,#`R+3(P
M,#4@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN
M9&4^"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O
M;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R
M<VEO;B`@("!296QE87-E.B`Q+C,N,@H@*B!`;&EN:R`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$A056YI=`H@*B!`<VEN8V4@("`@("!#
M;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C`N,`H@*B\*8VQA<W,@
M4$A056YI=%]!<W-E<G0@>PH@("`@+RHJ"B`@("`@*B!`=F%R("`@(&)O;VQE
M86X*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]L
M;V]S96QY5'EP960@/2!&04Q313L*"B`@("`O*BH*("`@("`J($%S<V5R=',@
M=&AA="!A(&AA>7-T86-K(&-O;G1A:6YS(&$@;F5E9&QE+@H@("`@("H*("`@
M("`J($!P87)A;2`@;6EX960*("`@("`J($!P87)A;2`@;6EX960*("`@("`J
M($!P87)A;2`@<W1R:6YG"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@
M0'-I;F-E("!-971H;V0@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XQ+C`*
M("`@("`J+PH@("`@9G5N8W1I;VX@87-S97)T0V]N=&%I;G,H)&YE961L92P@
M)&AA>7-T86-K+"`D;65S<V%G92`]("<G*2!["B`@("`@("`@:68@*&ES7W-T
M<FEN9R@D;F5E9&QE*2`F)B!I<U]S=')I;F<H)&AA>7-T86-K*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^87-S97)T5')U92AS=')P;W,H)&AA>7-T86-K+"`D
M;F5E9&QE*2`A/3T@1D%,4T4L("1M97-S86=E*3L*("`@("`@("!]"@H@("`@
M("`@(&5L<V4@:68@*&ES7V%R<F%Y*"1H87ES=&%C:RD@)B8@(6ES7V]B:F5C
M="@D;F5E9&QE*2D@>PH@("`@("`@("`@("`D=&AI<RT^87-S97)T5')U92AI
M;E]A<G)A>2@D;F5E9&QE+"`D:&%Y<W1A8VLI+"`D;65S<V%G92D["B`@("`@
M("`@?0H*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/F9A:6PH
M)U5N<W5P<&]R=&5D('!A<F%M971E<B!P87-S960@=&\@87-S97)T0V]N=&%I
M;G,H*2XG*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!<W-E
M<G1S('1H870@82!H87ES=&%C:R!D;V5S(&YO="!C;VYT86EN(&$@;F5E9&QE
M+@H@("`@("H*("`@("`J($!P87)A;2`@;6EX960*("`@("`J($!P87)A;2`@
M;6EX960*("`@("`J($!P87)A;2`@<W1R:6YG"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("H@0'-I;F-E("!-971H;V0@879A:6QA8FQE('-I;F-E(%)E
M;&5A<V4@,2XQ+C`*("`@("`J+PH@("`@9G5N8W1I;VX@87-S97)T3F]T0V]N
M=&%I;G,H)&YE961L92P@)&AA>7-T86-K+"`D;65S<V%G92`]("<G*2!["B`@
M("`@("`@:68@*&ES7W-T<FEN9R@D;F5E9&QE*2`F)B!I<U]S=')I;F<H)&AA
M>7-T86-K*2D@>PH@("`@("`@("`@("`D=&AI<RT^87-S97)T1F%L<V4H<W1R
M<&]S*"1H87ES=&%C:RP@)&YE961L92D@(3T]($9!3%-%+"`D;65S<V%G92D[
M"B`@("`@("`@?0H*("`@("`@("!E;'-E(&EF("AI<U]A<G)A>2@D:&%Y<W1A
M8VLI("8F("%I<U]O8FIE8W0H)&YE961L92DI('L*("`@("`@("`@("`@)'1H
M:7,M/F%S<V5R=$9A;'-E*&EN7V%R<F%Y*"1N965D;&4L("1H87ES=&%C:RDL
M("1M97-S86=E*3L*("`@("`@("!]"@H@("`@("`@(&5L<V4@>PH@("`@("`@
M("`@("`D=&AI<RT^9F%I;"@G56YS=7!P;W)T960@<&%R86UE=&5R('!A<W-E
M9"!T;R!A<W-E<G1.;W1#;VYT86EN<R@I+B<I.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($%S<V5R=',@=&AA="!T=V\@=F%R:6%B;&5S(&%R
M92!E<75A;"X*("`@("`J"B`@("`@*B!`<&%R86T@(&UI>&5D"B`@("`@*B!`
M<&%R86T@(&UI>&5D"B`@("`@*B!`<&%R86T@('-T<FEN9PH@("`@("H@0'!A
M<F%M("!M:7AE9`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@87-S97)T17%U86QS*"1E>'!E8W1E9"P@)&%C='5A;"P@)&UE
M<W-A9V4@/2`G)RP@)&1E;'1A(#T@,"D@>PH@("`@("`@(&EF("@H:7-?87)R
M87DH)&%C='5A;"D@("8F(&ES7V%R<F%Y*"1E>'!E8W1E9"DI('Q\"B`@("`@
M("`@("`@("AI<U]O8FIE8W0H)&%C='5A;"D@)B8@:7-?;V)J96-T*"1E>'!E
M8W1E9"DI*2!["B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D86-T=6%L*2`F
M)B!I<U]A<G)A>2@D97AP96-T960I*2!["B`@("`@("`@("`@("`@("!K<V]R
M="@D86-T=6%L*3L*("`@("`@("`@("`@("`@(&MS;W)T*"1E>'!E8W1E9"D[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D=&AI<RT^7VQO;W-E
M;'E4>7!E9"D@>PH@("`@("`@("`@("`@("`@)&%C='5A;"`@(#T@)'1H:7,M
M/E]C;VYV97)T5&]3=')I;F<H)&%C='5A;"D["B`@("`@("`@("`@("`@("`D
M97AP96-T960@/2`D=&AI<RT^7V-O;G9E<G14;U-T<FEN9R@D97AP96-T960I
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D86-T=6%L("`@/2!S97)I
M86QI>F4H)&%C='5A;"D["B`@("`@("`@("`@("1E>'!E8W1E9"`]('-E<FEA
M;&EZ92@D97AP96-T960I.PH*("`@("`@("`@("`@)&UE<W-A9V4@/2!S<')I
M;G1F*`H@("`@("`@("`@("`@("<E<V5X<&5C=&5D("5S+"!A8W1U86P@)7,G
M+`H*("`@("`@("`@("`@("`A96UP='DH)&UE<W-A9V4I(#\@)&UE<W-A9V4@
M+B`G("<@.B`G)RP*("`@("`@("`@("`@("`D97AP96-T960L"B`@("`@("`@
M("`@("`@)&%C='5A;`H@("`@("`@("`@("`I.PH*("`@("`@("`@("`@:68@
M*"1A8W1U86P@(3T]("1E>'!E8W1E9"D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YF86EL*"1M97-S86=E*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@96QS96EF("AI<U]N=6UE<FEC*"1A8W1U86PI("8F
M(&ES7VYU;65R:6,H)&5X<&5C=&5D*2D@>PH@("`@("`@("`@("`D;65S<V%G
M92`]('-P<FEN=&8H"B`@("`@("`@("`@("`@)R5S97AP96-T960@)7,E<RP@
M86-T=6%L("5S)RP*"B`@("`@("`@("`@("`@(65M<'1Y*"1M97-S86=E*2`_
M("1M97-S86=E("X@)R`G(#H@)R<L"B`@("`@("`@("`@("`@)&5X<&5C=&5D
M+`H@("`@("`@("`@("`@("@D9&5L=&$@(3T@,"D@/R`H)RLO+2`G("X@)&1E
M;'1A*2`Z("<G+`H@("`@("`@("`@("`@("1A8W1U86P*("`@("`@("`@("`@
M*3L*"B`@("`@("`@("`@(&EF("@A*"1A8W1U86P@/CT@*"1E>'!E8W1E9"`M
M("1D96QT82D@)B8@)&%C='5A;"`\/2`H)&5X<&5C=&5D("L@)&1E;'1A*2DI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9F%I;"@D;65S<V%G
M92D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&5L<V4@>PH@
M("`@("`@("`@("`D;65S<V%G92`]('-P<FEN=&8H"B`@("`@("`@("`@("`@
M)R5S97AP96-T960@)7,L(&%C='5A;"`E<R<L"@H@("`@("`@("`@("`@("%E
M;7!T>2@D;65S<V%G92D@/R`D;65S<V%G92`N("<@)R`Z("<G+`H@("`@("`@
M("`@("`@("1E>'!E8W1E9"P*("`@("`@("`@("`@("`D86-T=6%L"B`@("`@
M("`@("`@("D["@H@("`@("`@("`@("!I9B`H)&%C='5A;"`A/3T@)&5X<&5C
M=&5D*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/F9A:6PH)&UE
M<W-A9V4I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@07-S97)T<R!T:&%T('1W;R!V87)I86)L97,@<F5F97)E;F-E
M('1H92!S86UE(&]B:F5C="X*("`@("`J(%1H:7,@<F5Q=6ER97,@=&AE(%IE
M;F0@16YG:6YE(#(@=&\@=V]R:RX*("`@("`J"B`@("`@*B!`<&%R86T@(&]B
M:F5C=`H@("`@("H@0'!A<F%M("!O8FIE8W0*("`@("`J($!P87)A;2`@<W1R
M:6YG"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0&1E<')E8V%T960*
M("`@("`J+PH@("`@9G5N8W1I;VX@87-S97)T4V%M92@D97AP96-T960L("1A
M8W1U86PL("1M97-S86=E(#T@)R<I('L*("`@("`@("!I9B`H(79E<G-I;VY?
M8V]M<&%R92AP:'!V97)S:6]N*"DL("<U+C`N,"<L("<^/2<I*2!["B`@("`@
M("`@("`@("1T:&ES+3YF86EL*"=A<W-E<G1386UE*"D@;VYL>2!W;W)K<R!W
M:71H(%!(4"`^/2`U+C`N,"XG*3L*("`@("`@("!]"@H@("`@("`@(&EF("@H
M:7-?;V)J96-T*"1E>'!E8W1E9"D@?'P@:7-?;G5L;"@D97AP96-T960I*2`F
M)@H@("`@("`@("`@("`H:7-?;V)J96-T*"1A8W1U86PI("`@?'P@:7-?;G5L
M;"@D86-T=6%L*2DI('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!S<')I;G1F
M*`H@("`@("`@("`@("`@("<E<V5X<&5C=&5D('1W;R!V87)I86)L97,@=&\@
M<F5F97)E;F-E('1H92!S86UE(&]B:F5C="<L"@H@("`@("`@("`@("`@("%E
M;7!T>2@D;65S<V%G92D@/R`D;65S<V%G92`N("<@)R`Z("<G"B`@("`@("`@
M("`@("D["@H@("`@("`@("`@("!I9B`H)&5X<&5C=&5D("$]/2`D86-T=6%L
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/F9A:6PH)&UE<W-A
M9V4I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'1H:7,M/F9A:6PH)U5N<W5P<&]R=&5D('!A<F%M971E<B!P87-S960@
M=&\@87-S97)T4V%M92@I+B<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($%S<V5R=',@=&AA="!T=V\@=F%R:6%B;&5S(&1O(&YO="!R969E
M<F5N8V4@=&AE('-A;64@;V)J96-T+@H@("`@("H@5&AI<R!R97%U:7)E<R!T
M:&4@6F5N9"!%;F=I;F4@,B!T;R!W;W)K+@H@("`@("H*("`@("`J($!P87)A
M;2`@;V)J96-T"B`@("`@*B!`<&%R86T@(&]B:F5C=`H@("`@("H@0'!A<F%M
M("!S=')I;F<*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`9&5P<F5C
M871E9`H@("`@("HO"B`@("!F=6YC=&EO;B!A<W-E<G1.;W1386UE*"1E>'!E
M8W1E9"P@)&%C='5A;"P@)&UE<W-A9V4@/2`G)RD@>PH@("`@("`@(&EF("@A
M=F5R<VEO;E]C;VUP87)E*'!H<'9E<G-I;VXH*2P@)S4N,"XP)RP@)SX])RDI
M('L*("`@("`@("`@("`@)'1H:7,M/F9A:6PH)V%S<V5R=$YO=%-A;64H*2!O
M;FQY('=O<FMS('=I=&@@4$A0(#X](#4N,"XP+B<I.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"AI<U]O8FIE8W0H)&5X<&5C=&5D*2!\?"!I<U]N=6QL*"1E
M>'!E8W1E9"DI("8F"B`@("`@("`@("`@("AI<U]O8FIE8W0H)&%C='5A;"D@
M("!\?"!I<U]N=6QL*"1A8W1U86PI*2D@>PH@("`@("`@("`@("`D;65S<V%G
M92`]('-P<FEN=&8H"B`@("`@("`@("`@("`@)R5S97AP96-T960@='=O('9A
M<FEA8FQE<R!T;R!R969E<F5N8V4@9&EF9F5R96YT(&]B:F5C=',G+`H*("`@
M("`@("`@("`@("`A96UP='DH)&UE<W-A9V4I(#\@)&UE<W-A9V4@+B`G("<@
M.B`G)PH@("`@("`@("`@("`I.PH*("`@("`@("`@("`@:68@*"1E>'!E8W1E
M9"`]/3T@)&%C='5A;"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YF86EL*"1M97-S86=E*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1T:&ES+3YF86EL*"=5;G-U<'!O<G1E9"!P87)A
M;65T97(@<&%S<V5D('1O(&%S<V5R=$YO=%-A;64H*2XG*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!<W-E<G1S('1H870@82!V87)I86)L
M92!I<R!N;W0@3E5,3"X*("`@("`J"B`@("`@*B!`<&%R86T@(&UI>&5D"B`@
M("`@*B!`<&%R86T@('-T<FEN9PH@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@87-S97)T3F]T3G5L;"@D86-T=6%L+"`D;65S
M<V%G92`]("<G*2!["B`@("`@("`@)&UE<W-A9V4@/2!S<')I;G1F*`H@("`@
M("`@("`@)R5S97AP96-T960@3D]4($Y53$PL(&%C='5A;"!.54Q,)RP*"B`@
M("`@("`@("`A96UP='DH)&UE<W-A9V4I(#\@)&UE<W-A9V4@+B`G("<@.B`G
M)PH@("`@("`@("D["@H@("`@("`@(&EF("AI<U]N=6QL*"1A8W1U86PI*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9F%I;"@D;65S<V%G92D["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@07-S97)T<R!T:&%T(&$@
M=F%R:6%B;&4@:7,@3E5,3"X*("`@("`J"B`@("`@*B!`<&%R86T@(&UI>&5D
M"B`@("`@*B!`<&%R86T@('-T<FEN9PH@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@87-S97)T3G5L;"@D86-T=6%L+"`D;65S
M<V%G92`]("<G*2!["B`@("`@("`@)&UE<W-A9V4@/2!S<')I;G1F*`H@("`@
M("`@("`@)R5S97AP96-T960@3E5,3"P@86-T=6%L($Y/5"!.54Q,)RP*"B`@
M("`@("`@("`A96UP='DH)&UE<W-A9V4I(#\@)&UE<W-A9V4@+B`G("<@.B`G
M)PH@("`@("`@("D["@H@("`@("`@(&EF("@A:7-?;G5L;"@D86-T=6%L*2D@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F9A:6PH)&UE<W-A9V4I.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%S<V5R=',@=&AA="!A
M(&-O;F1I=&EO;B!I<R!T<G5E+@H@("`@("H*("`@("`J($!P87)A;2`@8F]O
M;&5A;@H@("`@("H@0'!A<F%M("!S=')I;F<*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&%S<V5R=%1R=64H)&-O;F1I=&EO
M;BP@)&UE<W-A9V4@/2`G)RD@>PH@("`@("`@("1M97-S86=E(#T@<W!R:6YT
M9B@*("`@("`@("`@("<E<V5X<&5C=&5D(%12544L(&%C='5A;"!&04Q312<L
M"@H@("`@("`@("`@(65M<'1Y*"1M97-S86=E*2`_("1M97-S86=E("X@)R`G
M(#H@)R<*("`@("`@("`I.PH*("`@("`@("!I9B`H(21C;VYD:71I;VXI('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YF86EL*"1M97-S86=E*3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!<W-E<G1S('1H870@82!C
M;VYD:71I;VX@:7,@9F%L<V4N"B`@("`@*@H@("`@("H@0'!A<F%M("!B;V]L
M96%N"B`@("`@*B!`<&%R86T@('-T<FEN9PH@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J+PH@("`@9G5N8W1I;VX@87-S97)T1F%L<V4H)&-O;F1I=&EO
M;BP@)&UE<W-A9V4@/2`G)RD@>PH@("`@("`@("1M97-S86=E(#T@<W!R:6YT
M9B@*("`@("`@("`@("<E<V5X<&5C=&5D($9!3%-%+"!A8W1U86P@5%)512<L
M"@H@("`@("`@("`@(65M<'1Y*"1M97-S86=E*2`_("1M97-S86=E("X@)R`G
M(#H@)R<*("`@("`@("`I.PH*("`@("`@("!I9B`H)&-O;F1I=&EO;BD@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/F9A:6PH)&UE<W-A9V4I.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%S<V5R=',@=&AA="!A('-T
M<FEN9R!M871C:&5S(&$@9VEV96X@<F5G=6QA<B!E>'!R97-S:6]N+@H@("`@
M("H*("`@("`J($!P87)A;2`@<W1R:6YG"B`@("`@*B!`<&%R86T@('-T<FEN
M9PH@("`@("H@0'!A<F%M("!S=')I;F<*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&%S<V5R=%)E9T5X<"@D<&%T=&5R;BP@
M)'-T<FEN9RP@)&UE<W-A9V4@/2`G)RD@>PH@("`@("`@("1M97-S86=E(#T@
M<W!R:6YT9B@*("`@("`@("`@("<E<R(E<R(@9&]E<R!N;W0@;6%T8V@@<&%T
M=&5R;B`B)7,B)RP*"B`@("`@("`@("`A96UP='DH)&UE<W-A9V4I(#\@)&UE
M<W-A9V4@+B`G("<@.B`G)RP*("`@("`@("`@("1S=')I;F<L"B`@("`@("`@
M("`D<&%T=&5R;@H@("`@("`@("D["@H@("`@("`@(&EF("@A<')E9U]M871C
M:"@D<&%T=&5R;BP@)'-T<FEN9RDI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YF86EL*"1M97-S86=E*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!!<W-E<G1S('1H870@82!S=')I;F<@9&]E<R!N;W0@;6%T8V@@
M82!G:79E;B!R96=U;&%R(&5X<')E<W-I;VXN"B`@("`@*@H@("`@("H@0'!A
M<F%M("!S=')I;F<*("`@("`J($!P87)A;2`@<W1R:6YG"B`@("`@*B!`<&%R
M86T@('-T<FEN9PH@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S:6YC
M92`@365T:&]D(&%V86EL86)L92!S:6YC92!296QE87-E(#$N,2XP"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&%S<V5R=$YO=%)E9T5X<"@D<&%T=&5R;BP@)'-T
M<FEN9RP@)&UE<W-A9V4@/2`G)RD@>PH@("`@("`@("1M97-S86=E(#T@<W!R
M:6YT9B@*("`@("`@("`@("<E<R(E<R(@;6%T8VAE<R!P871T97)N("(E<R(G
M+`H*("`@("`@("`@("%E;7!T>2@D;65S<V%G92D@/R`D;65S<V%G92`N("<@
M)R`Z("<G+`H@("`@("`@("`@)'-T<FEN9RP*("`@("`@("`@("1P871T97)N
M"B`@("`@("`@*3L*"B`@("`@("`@:68@*'!R96=?;6%T8V@H)'!A='1E<FXL
M("1S=')I;F<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9F%I;"@D
M;65S<V%G92D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@07-S
M97)T<R!T:&%T(&$@=F%R:6%B;&4@:7,@;V8@82!G:79E;B!T>7!E+@H@("`@
M("H*("`@("`J($!P87)A;2`@<W1R:6YG("`@("`@("`@("1E>'!E8W1E9`H@
M("`@("H@0'!A<F%M("!M:7AE9"`@("`@("`@("`@)&%C='5A;`H@("`@("H@
M0'!A<F%M("!O<'1I;VYA;"!S=')I;F<@)&UE<W-A9V4*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&%S<V5R=%1Y<&4H)&5X
M<&5C=&5D+"`D86-T=6%L+"`D;65S<V%G92`]("<G*2!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3YA<W-E<G1%<75A;',H"B`@("`@("`@("`D97AP96-T960L
M"B`@("`@("`@("!G971T>7!E*"1A8W1U86PI+`H@("`@("`@("`@)&UE<W-A
M9V4*("`@("`@("`I.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R=',@
M82!V86QU92!T;R!A('-T<FEN9RX*("`@("`J"B`@("`@*B!`<&%R86T@(&UI
M>&5D("`@)'9A;'5E"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V-O;G9E<G14;U-T<FEN9R@D=F%L=64I('L*("`@("`@
M("!F;W)E86-H("@D=F%L=64@87,@)&L@/3X@)'8I('L*("`@("`@("`@("`@
M:68@*&ES7V%R<F%Y*"1V*2D@>PH@("`@("`@("`@("`@("`@)'9A;'5E6R1K
M72`]("1T:&ES+3Y?8V]N=F5R=%1O4W1R:6YG*"1V86QU95LD:UTI.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<V5T='EP92@D=F%L
M=65;)&M=+"`G<W1R:6YG)RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D=F%L=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!`
M<&%R86T@(&)O;VQE86X@)&QO;W-E;'E4>7!E9`H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T3&]O<V5L>51Y<&5D*"1L
M;V]S96QY5'EP960I('L*("`@("`@("!I9B`H:7-?8F]O;"@D;&]O<V5L>51Y
M<&5D*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VQO;W-E;'E4>7!E9"`]("1L
M;V]S96QY5'EP960["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M1F%I;',@82!T97-T('=I=&@@=&AE(&=I=F5N(&UE<W-A9V4N"B`@("`@*@H@
M("`@("H@0'!A<F%M("!S=')I;F<*("`@("`J($!A8V-E<W,@<')O=&5C=&5D
M"B`@("`@*B!`86)S=')A8W0*("`@("`J+PH@("`@9G5N8W1I;VX@9F%I;"@D
M;65S<V%G92`]("<G*2![("\J(&%B<W1R86-T("HO('T*?0H*+RH*("H@3&]C
M86P@=F%R:6%B;&5S.@H@*B!T86(M=VED=&@Z(#0*("H@8RUB87-I8RUO9F9S
M970Z(#0*("H@8RUH86YG:6YG+6-O;6UE;G0M96YD97(M<#H@;FEL"B`J($5N
M9#H*("HO"C\^"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]&:6QE````````
M````````````````````````````````````````````````````````````
M`````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P,#`P(#$P-3$U-#,S-S,Q(#`Q-S(V-``@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+T9I;&4O0U-6+G!H<```````````````````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P-#`V,#`@,3`U,34T,S,W,S$@,#(P-3`W`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT
M('-O9G1T86)S=&]P/30Z("HO"@HO*BH*("H@1FEL93HZ0U-6"B`J"B`J(%!(
M4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E
M(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI
M8V5N<V4*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E
M:79E(&$@8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B
M;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E
M;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y
M;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("`@1FEL
M90H@*B!`<&%C:V%G92`@("`@1FEL90H@*B!`875T:&]R("`@("`@5&]M87,@
M5BY6+D-O>"`\8V]X0&ED96-N970N8V]M/@H@*B!`875T:&]R("`@("`@2&5L
M9VD@WF]R;6%R(#QD=69U>D!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`@,C`P
M-"TR,#`U(%1H92!!=71H;W)S"B`J($!L:6-E;G-E("`@("!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@
M0'9E<G-I;VX@("`@($-64SH@)$ED.B!#4U8N<&AP+'8@,2XR-"`R,#`U+S`X
M+S`Y(#`X.C$V.C`R(&1U9G5Z($5X<"`D"B`J($!L:6YK("`@("`@("!H='1P
M.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1FEL90H@*B\*"G)E<75I<F5?;VYC
M92`G4$5!4BYP:'`G.PIR97%U:7)E7V]N8V4@)T9I;&4N<&AP)SL*"B\J*@HJ
M($9I;&4@8VQA<W,@9F]R(&AA;F1L:6YG($-35B!F:6QE<R`H0V]M;6$@4V5P
M87)A=&5D(%9A;'5E<RDL(&$@8V]M;6]N(&9O<FUA=`HJ(&9O<B!E>&-H86YG
M:6YG(&1A=&$N"BH**B!43T1/.@HJ("`M(%5S86=E(&5X86UP;&4@86YD($1O
M8PHJ("`M(%5S92!G9710;VEN=&5R*"D@:6X@9&ES8V]V97)&;W)M870**B`@
M+2!!9&0@82!L:6YE(&-O=6YT97(@9F]R(&)E:6YG(&%B;&4@=&\@;W5T<'5T
M(&)E='1E<B!E<G)O<B!R97!O<G1S"BH@("T@4W1O<F4@=&AE(&QA<W0@97)R
M;W(@:6X@1TQ/0D%,4R!A;F0@861D($9I;&5?0U-6.CIG971,87-T17)R;W(H
M*0HJ"BH@5VES:#H**B`@+2!/=&AE<B!M971H;V1S(&QI:V4@<F5A9$%L;"@I
M+"!W<FET94%L;"@I+"!N=6U&:65L9',H*2P@;G5M4F]W<R@I"BH@("T@5')Y
M('1O(&1E=&5C="!I9B!A($-35B!H87,@:&5A9&5R(&]R(&YO="!I;B!D:7-C
M;W9E<D9O<FUA="@I"BH**B!+;F]W;B!"=6=S.@HJ("AT:&5Y(&AA<R!B965N
M(&%N86QY>F5D(&)U="!F;W(@=&AE(&UO;65N="!T:&4@:6UP86-T(&EN('1H
M92!S<&5E9"!F;W(**B`@<')O<&5R;'D@:&%N9&QE('1H:7,@=6YC;VUM;VX@
M8V%S97,@:7,@=&]O(&AI9V@@86YD('=O;B=T(&)E('-U<'!O<G1E9"D**B`@
M+2!!(&9I96QD('=H:6-H(&ES(&-O;7!O<V5D(&]N;'D@8GD@82!S:6YG;&4@
M<75O=&5D('-E<&%R871O<B`H:64@+3X@.R([(CLI"BH@("`@:7,@;F]T(&AA
M;F1L960@<')O<&5R;'D**B`@+2!7:&5N('1H97)E(&ES(&5X86-T;'D@;VYE
M(&9I96QD(&UI;G5S('1H86X@=&AE(&5X<&5C=&5D(&YU;6)E<B!A;F0@=&AE
M<F4**B`@("!I<R!A(&9I96QD('=I=&@@82!S97!A<F%T;W(@:6YS:61E+"!T
M:&4@<&%R<V5R('=I;&P@=&AR;W<@=&AE(")W<F]N9R!C;W5N="(@97)R;W(*
M*@HJ($!A=71H;W(@5&]M87,@5BY6+D-O>"`\8V]X0&ED96-N970N8V]M/@HJ
M($!A=71H;W(@("`@("!(96QG:2#>;W)M87(@/&1U9G5Z0'!H<"YN970^"BH@
M0'!A8VMA9V4@1FEL90HJ+PIC;&%S<R!&:6QE7T-35@I["B`@("`O*BH*("`@
M("H@5&AI<R!R86ES945R<F]R(&UE=&AO9"!W;W)K<R!I;B!A(&1I9F9E<F5N
M="!W87DN($ET('=I;&P@86QW87ES(')E='5R;@H@("`@*B!F86QS92`H86X@
M97)R;W(@;V-C=7)R960I(&)U="!I="!W:6QL(&-A;&P@4$5!4CHZ<F%I<V5%
M<G)O<B@I(&)E9F]R90H@("`@*B!I="X@268@;F\@9&5F875L="!014%2(&=L
M;V)A;"!H86YD;&5R(&ES('-E="P@=VEL;"!T<FEG9V5R(&%N(&5R<F]R+@H@
M("`@*@H@("`@*B!`<&%R86T@<W1R:6YG("1E<G)O<B!4:&4@97)R;W(@;65S
M<V%G90H@("`@*B!`<F5T=7)N(&)O;VP@86QW87ES(&9A;'-E"B`@("`J+PH@
M("`@9G5N8W1I;VX@<F%I<V5%<G)O<B@D97)R;W(I"B`@("!["B`@("`@("`@
M+R\@268@82!D969A=6QT(%!%05(@17)R;W(@:&%N9&QE<B!I<R!N;W0@<V5T
M('1R:6=G97(@=&AE(&5R<F]R"B`@("`@("`@+R\@6%A8($%D9"!A(%!%05(Z
M.FES4V5T2&%N9&QE<B@I(&UE=&AO9#\*("`@("`@("!I9B`H)$=,3T)!3%-;
M)U]014%27V1E9F%U;'1?97)R;W)?;6]D92==(#T](%!%05)?15)23U)?4D54
M55).*2!["B`@("`@("`@("`@(%!%05(Z.G)A:7-E17)R;W(H)&5R<F]R+"!N
M=6QL+"!014%27T524D]27U1224='15(L($5?55-%4E]705).24Y'*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!014%2.CIR86ES945R<F]R*"1E
M<G)O<BD["B`@("`@("`@?0H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*
M"B`@("`O*BH*("`@("H@0VAE8VMS('1H92!C;VYF:6=U<F%T:6]N(&=I=F5N
M(&)Y('1H92!U<V5R"B`@("`J"B`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M*B!`<&%R86T@<W1R:6YG("8D97)R;W(@5&AE(&5R<F]R('=I;&P@8F4@=W)I
M='1E;B!H97)E(&EF(&%N>0H@("`@*B!`<&%R86T@87)R87D@("8D8V]N9B`@
M5&AE(&-O;F9I9W5R871I;VX@87-S;V,@87)R87D*("`@("H@0')E='5R;B!S
M=')I;F<@97)R;W(@("`@4F5T=7)N<R!A(&5R<F]R(&UE<W-A9V4*("`@("HO
M"B`@("!F=6YC=&EO;B!?8V]N9B@F)&5R<F]R+"`F)&-O;F8I"B`@("!["B`@
M("`@("`@+R\@8VAE8VL@8V]N9@H@("`@("`@(&EF("@A:7-?87)R87DH)&-O
M;F8I*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W(@/2`G26YV86QI9"!C
M;VYF:6=U<F%T:6]N)SL*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-S970H
M)&-O;F9;)V9I96QD<R==*2!\?"`A:7-?;G5M97)I8R@D8V]N9ELG9FEE;&1S
M)UTI*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W(@/2`G5&AE(&YU;6)E
M<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC("AT:&4@(F9I96QD<R(@:V5Y
M*2<["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)&-O;F9;)W-E<"==
M*2D@>PH@("`@("`@("`@("!I9B`H<W1R;&5N*"1C;VYF6R=S97`G72D@(3T@
M,2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1E<G)O<B`]("=397!A<F%T
M;W(@8V%N(&]N;'D@8F4@;VYE(&-H87(G.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E:68@*"1C;VYF6R=F:65L9',G72`^(#$I('L*("`@("`@("`@
M("`@<F5T=7)N("1E<G)O<B`]("=-:7-S:6YG('-E<&%R871O<B`H=&AE(")S
M97`B(&ME>2DG.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1C;VYF
M6R=Q=6]T92==*2D@>PH@("`@("`@("`@("!I9B`H<W1R;&5N*"1C;VYF6R=Q
M=6]T92==*2`A/2`Q*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&5R<F]R
M(#T@)U1H92!Q=6]T92!C:&%R(&UU<W0@8F4@;VYE(&-H87(@*'1H92`B<75O
M=&4B(&ME>2DG.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&-O;F9;)W%U;W1E)UT@/2!N=6QL.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"%I<W-E="@D8V]N9ELG8W)L9B==*2D@>PH@("`@("`@("`@
M("`D8V]N9ELG8W)L9B==(#T@(EQN(CL*("`@("`@("!]"@H@("`@("`@(&EF
M("@A:7-S970H)&-O;F9;)V5O;#)U;FEX)UTI*2!["B`@("`@("`@("`@("1C
M;VYF6R=E;VPR=6YI>"==(#T@=')U93L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`J(%)E='5R;B!O<B!C<F5A=&4@=&AE(&9I;&4@9&5S8W)I<'1O
M<B!A<W-O8VEA=&5D('=I=&@@82!F:6QE"B`@("`J"B`@("`J($!P87)A;2!S
M=')I;F<@)&9I;&4@5&AE(&YA;64@;V8@=&AE(&9I;&4*("`@("H@0'!A<F%M
M(&%R<F%Y("`F)&-O;F8@5&AE(&-O;F9I9W5R871I;VX*("`@("H@0'!A<F%M
M('-T<FEN9R`D;6]D92!4:&4@;W!E;B!N;V1E("AE>#H@1DE,15]-3T1%7U)%
M040@;W(@1DE,15]-3T1%7U=2251%*0H@("`@*B!`<&%R86T@8F]O;&5A;B`D
M<F5S970@:68@<&%S<V5D(&%S('1R=64@86YD(')E<V]U<F-E(&9O<B!T:&4@
M9FEL92!E>&ES=',*("`@("H@("`@("`@("`@("`@("`@("`@("`@('1H86X@
M=&AE(&9I;&4@<&]I;G1E<B!W:6QL(&)E(&UO=F5D('1O('1H92!B96=I;FYI
M;F<*("`@("H*("`@("H@0')E='5R;B!M:7AE9"!!(&9I;&4@<F5S;W5R8V4@
M;W(@9F%L<V4*("`@("HO"B`@("!F=6YC=&EO;B!G9710;VEN=&5R*"1F:6QE
M+"`F)&-O;F8L("1M;V1E(#T@1DE,15]-3T1%7U)%040L("1R97-E="`](&9A
M;'-E*0H@("`@>PH@("`@("`@('-T871I8R`D<F5S;W5R8V5S("`](&%R<F%Y
M*"D["B`@("`@("`@<W1A=&EC("1C;VYF:6<["B`@("`@("`@:68@*&ES<V5T
M*"1R97-O=7)C97-;)&9I;&5=*2D@>PH@("`@("`@("`@("`D8V]N9B`]("1C
M;VYF:6<["B`@("`@("`@("`@(&EF("@D<F5S970I('L*("`@("`@("`@("`@
M("`@(&9S965K*"1R97-O=7)C97-;)&9I;&5=+"`P*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!R971U<FX@)')E<V]U<F-E<ULD9FEL95T["B`@("`@
M("`@?0H@("`@("`@($9I;&5?0U-6.CI?8V]N9B@D97)R;W(L("1C;VYF*3L*
M("`@("`@("!I9B`H)&5R<F]R*2!["B`@("`@("`@("`@(')E='5R;B!&:6QE
M7T-35CHZ<F%I<V5%<G)O<B@D97)R;W(I.PH@("`@("`@('T*("`@("`@("`D
M8V]N9FEG(#T@)&-O;F8["B`@("`@("`@4$5!4CHZ<'5S:$5R<F]R2&%N9&QI
M;F<H4$5!4E]%4E)/4E]215154DXI.PH@("`@("`@("1F<"`]("9&:6QE.CI?
M9V5T1FEL95!O:6YT97(H)&9I;&4L("1M;V1E*3L*("`@("`@("!014%2.CIP
M;W!%<G)O<DAA;F1L:6YG*"D["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)&9P*2D@>PH@("`@("`@("`@("!R971U<FX@1FEL95]#4U8Z.G)A:7-E17)R
M;W(H)&9P*3L*("`@("`@("!]"B`@("`@("`@)')E<V]U<F-E<ULD9FEL95T@
M/2`D9G`["@H@("`@("`@(&EF("@D;6]D92`]/2!&24Q%7TU/1$5?4D5!1"`F
M)B`A96UP='DH)&-O;F9;)VAE861E<B==*2D@>PH@("`@("`@("`@("!I9B`H
M(49I;&5?0U-6.CIR96%D*"1F:6QE+"`D8V]N9BDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M("`@("!R971U<FX@)&9P.PH@("`@?0H*("`@("\J*@H@("`@*B!5;G%U;W1E
M(&1A=&$*("`@("H*("`@("H@0'!A<F%M('-T<FEN9R`D9FEE;&0@5&AE(&1A
M=&$@=&\@=6YQ=6]T90H@("`@*B!`<&%R86T@<W1R:6YG("1Q=6]T92!4:&4@
M<75O=&4@8VAA<@H@("`@*B!`<F5T=7)N('-T<FEN9R!T:&4@=6YQ=6]T960@
M9&%T80H@("`@*B\*("`@(&9U;F-T:6]N('5N<75O=&4H)&9I96QD+"`D<75O
M=&4I"B`@("!["B`@("`@("`@+R\@5')I;2!F:7)S="!T:&4@<W1R:6YG+@H@
M("`@("`@("1F:65L9"`]('1R:6TH)&9I96QD*3L*("`@("`@("`D<75O=&4@
M/2!T<FEM*"1Q=6]T92D["@H@("`@("`@("\O($EN8V%S92!N=6QL(&9I96QD
M<R`H9F]R;3H@.SLI"B`@("`@("`@:68@*"%S=')L96XH)&9I96QD*2D@>PH@
M("`@("`@("`@("!R971U<FX@)&9I96QD.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"1Q=6]T92`F)B`D9FEE;&1[,'T@/3T@)'%U;W1E("8F("1F:65L9'MS
M=')L96XH)&9I96QD*2TQ?2`]/2`D<75O=&4I('L*("`@("`@("`@("`@<F5T
M=7)N('-U8G-T<B@D9FEE;&0L(#$L("TQ*3L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("1F:65L9#L*("`@('T*"B`@("`O*BH*("`@("H@4F5A9',@82!R
M;W<@;V8@9&%T82!A<R!A;B!A<G)A>2!F<F]M(&$@0U-6(&9I;&4N($ET)W,@
M86)L92!T;PH@("`@*B!R96%D(&UE;6\@9FEE;&1S('=I=&@@;75L=&EL:6YE
M(&1A=&$N"B`@("`J"B`@("`J($!P87)A;2!S=')I;F<@)&9I;&4@("!4:&4@
M9FEL96YA;64@=VAE<F4@=&\@=W)I=&4@=&AE(&1A=&$*("`@("H@0'!A<F%M
M(&%R<F%Y("`F)&-O;F8@("!4:&4@8V]N9FEG=7)A=&EO;B!O9B!T:&4@9&5S
M="!#4U8*("`@("H*("`@("H@0')E='5R;B!M:7AE9"!!<G)A>2!W:71H('1H
M92!D871A(')E860@;W(@9F%L<V4@;VX@97)R;W(O;F\@;6]R92!D871A"B`@
M("`J+PH@("`@9G5N8W1I;VX@<F5A9%%U;W1E9"@D9FEL92P@)B1C;VYF*0H@
M("`@>PH@("`@("`@(&EF("@A)&9P(#T@1FEL95]#4U8Z.F=E=%!O:6YT97(H
M)&9I;&4L("1C;VYF+"!&24Q%7TU/1$5?4D5!1"DI('L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@)&)U9F8@/2`D8R`]
M("<G.PH@("`@("`@("1R970@(#T@87)R87DH*3L*("`@("`@("`D:2`](#$[
M"B`@("`@("`@)&EN7W%U;W1E(#T@9F%L<V4["B`@("`@("`@)'%U;W1E(#T@
M)&-O;F9;)W%U;W1E)UT["B`@("`@("`@)&8@/2`D8V]N9ELG9FEE;&1S)UT[
M"B`@("`@("`@)&5O;#)U;FEX(#T@)&-O;F9;)V5O;#)U;FEX)UT["B`@("`@
M("`@=VAI;&4@*"@D8V@@/2!F9V5T8R@D9G`I*2`A/3T@9F%L<V4I('L*("`@
M("`@("`@("`@)'!R978@/2`D8SL*("`@("`@("`@("`@)&,@/2`D8V@["B`@
M("`@("`@("`@("\O($-O;6UO;B!C87-E"B`@("`@("`@("`@(&EF("@D8R`A
M/2`D<75O=&4@)B8@)&,@(3T@)&-O;F9;)W-E<"==("8F("1C("$](")<;B(@
M)B8@)&,@(3T@(EQR(BD@>PH@("`@("`@("`@("`@("`@)&)U9F8@+CT@)&,[
M"B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@+R\@4W1A<G0@<75O=&4N"B`@("`@("`@("`@(&EF("@D<75O
M=&4@)B8@)&,@/3T@)'%U;W1E("8F"B`@("`@("`@("`@("`@("`H)'!R978@
M/3T@)&-O;F9;)W-E<"==('Q\("1P<F5V(#T](")<;B(@?'P@)'!R978@/3T]
M(&YU;&P@?'P*("`@("`@("`@("`@("`@("`D<')E=B`]/2`B7'(B('Q\("1P
M<F5V(#T]("<G*2D*("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@)&EN
M7W%U;W1E(#T@=')U93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@
M*"1I;E]Q=6]T92D@>PH@("`@("`@("`@("`@("`@+R\@5VAE;B!E;F1S('%U
M;W1E"B`@("`@("`@("`@("`@("!I9B`H)&,@/3T@)&-O;F9;)W-E<"==("8F
M("1P<F5V(#T]("1C;VYF6R=Q=6]T92==*2!["B`@("`@("`@("`@("`@("`@
M("`@)&EN7W%U;W1E(#T@9F%L<V4["B`@("`@("`@("`@("`@("!](&5L<V5I
M9B`H)&,@/3T@(EQN(B!\?"`D8R`]/2`B7'(B*2!["B`@("`@("`@("`@("`@
M("`@("`@)'-U8B`]("@D<')E=B`]/2`B7'(B*2`_(#(@.B`Q.PH@("`@("`@
M("`@("`@("`@("`@(&EF("@H<W1R;&5N*"1B=69F*2`^/2`D<W5B*2`F)@H@
M("`@("`@("`@("`@("`@("`@("`@("`H)&)U9F9[<W1R;&5N*"1B=69F*2`M
M("1S=6)](#T]("1Q=6]T92DI"B`@("`@("`@("`@("`@("`@("`@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D:6Y?<75O=&4@/2!F86QS93L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@(&EF("@A)&EN7W%U;W1E("8F("@D8R`]/2`D8V]N
M9ELG<V5P)UT@?'P@)&,@/3T@(EQN(B!\?"`D8R`]/2`B7'(B*2`F)B`D<')E
M=B`A/2`G)RD@>PH@("`@("`@("`@("`@("`@+R\@36]R92!F:65L9',@=&AA
M;B!E>'!E8W1E9`H@("`@("`@("`@("`@("`@:68@*"@D8R`]/2`D8V]N9ELG
M<V5P)UTI("8F("@H8V]U;G0H)')E="D@*R`Q*2`]/2`D9BDI('L*("`@("`@
M("`@("`@("`@("`@("`O+R!3965K('1H92!P;VEN=&5R(&EN=&\@;&EN96)R
M96%K(&-H87)A8W1E<BX*("`@("`@("`@("`@("`@("`@("!W:&EL92`H=')U
M92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D8R`](&9G971C*"1F<"D[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("`H)&,@/3T@(EQN(B!\?"`D
M8R`]/2`B7'(B*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("`@("`@("`@+R\@26YS97)T(&QA<W0@9FEE
M;&0@=F%L=64N"B`@("`@("`@("`@("`@("`@("`@)')E=%M=(#T@1FEL95]#
M4U8Z.G5N<75O=&4H)&)U9F8L("1Q=6]T92D["B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1R970["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`@("`@+R\@3&5S<R!F:65L9',@=&AA;B!E>'!E8W1E9`H@("`@("`@("`@
M("`@("`@:68@*"@D8R`]/2`B7&XB('Q\("1C(#T](")<<B(I("8F("@D:2`A
M/2`D9BDI('L*("`@("`@("`@("`@("`@("`@("`O+R!);G-E<G0@;&%S="!F
M:65L9"!V86QU92X*("`@("`@("`@("`@("`@("`@("`D<F5T6UT@/2!&:6QE
M7T-35CHZ=6YQ=6]T92@D8G5F9BP@)'%U;W1E*3L*"B`@("`@("`@("`@("`@
M("`@("`@+R\@4&%I<B!T:&4@87)R87D@96QE;65N=',@=&\@9FEE;&1S(&-O
M=6YT+@H@("`@("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>5]M97)G92@D
M<F5T+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>5]F:6QL*&-O=6YT*"1R970I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@*"1F("T@,2D@+2`H8V]U;G0H
M)')E="D@+2`Q*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("<G*0H@("`@("`@("`@("`@("`@("`@("D["B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*"1P<F5V(#T]
M(")<<B(I('L*("`@("`@("`@("`@("`@("`@("`D8G5F9B`]('-U8G-T<B@D
M8G5F9BP@,"P@+3$I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@("\O($-O;G9E<G0@14],(&-H87)A8W1E<B!T;R!5;FEX($5/3"`H3$8I
M+@H@("`@("`@("`@("`@("`@:68@*"1E;VPR=6YI>"D@>PH@("`@("`@("`@
M("`@("`@("`@("1B=69F(#T@<')E9U]R97!L86-E*"<O*%QR7&Y\7'(I)"\G
M+"`B7&XB+"`D8G5F9BD["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`@("`@)')E=%M=(#T@1FEL95]#4U8Z.G5N<75O=&4H)&)U9F8L("1Q=6]T
M92D["B`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)')E="D@/3T@)&8I('L*
M("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E=#L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("1B=69F(#T@)R<["B`@("`@("`@("`@
M("`@("`D:2LK.PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)&)U9F8@+CT@)&,["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`A9F5O9B@D9G`I(#\@)')E="`Z(&9A;'-E.PH@("`@?0H*
M("`@("\J*@H@("`@*B!296%D<R!A(")R;W<B(&9R;VT@82!#4U8@9FEL92!A
M;F0@<F5T=7)N(&ET(&%S(&%N(&%R<F%Y"B`@("`J"B`@("`J($!P87)A;2!S
M=')I;F<@)&9I;&4@5&AE($-35B!F:6QE"B`@("`J($!P87)A;2!A<G)A>2`@
M)B1C;VYF(%1H92!C;VYF:6=U<F%T:6]N(&]F('1H92!D97-T($-35@H@("`@
M*@H@("`@*B!`<F5T=7)N(&UI>&5D($%R<F%Y(&]R(&9A;'-E"B`@("`J+PH@
M("`@9G5N8W1I;VX@<F5A9"@D9FEL92P@)B1C;VYF*0H@("`@>PH@("`@("`@
M(&EF("@A)&9P(#T@1FEL95]#4U8Z.F=E=%!O:6YT97(H)&9I;&4L("1C;VYF
M+"!&24Q%7TU/1$5?4D5!1"DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*("`@("`@("`O+R!4:&4@<VEZ92!I<R!L:6UI=&5D('1O
M(#1+"B`@("`@("`@:68@*"$D;&EN92`@(#T@9F=E=',H)&9P+"`T,#DV*2D@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@
M("`D9FEE;&1S(#T@)&-O;F9;)V9I96QD<R==(#T](#$@/R!A<G)A>2@D;&EN
M92D@.B!E>'!L;V1E*"1C;VYF6R=S97`G72P@)&QI;F4I.PH*("`@("`@("!I
M9B`H)&-O;F9;)W%U;W1E)UTI('L*("`@("`@("`@("`@)&QA<W0@/28@)&9I
M96QD<UMC;W5N="@D9FEE;&1S*2`M(#%=.PH@("`@("`@("`@("`O+R!&86QL
M8F%C:R!T;R!R96%D('1H92!L:6YE('=I=&@@<F5A9%%U;W1E9"!W:&5N(&=U
M97-S"B`@("`@("`@("`@("\O('1H870@=&AE('-I;7!L92!E>'!L;V1E('=O
M;B=T('=O<FL@<FEG:'0*("`@("`@("`@("`@:68@*"@D;&%S='MS=')L96XH
M)&QA<W0I("T@,7T@/3T@(EQN(@H@("`@("`@("`@("`@("`@)B8@)&QA<W1[
M,'T@/3T@)&-O;F9;)W%U;W1E)UT*("`@("`@("`@("`@("`@("8F("1L87-T
M>W-T<FQE;BAR=')I;2@D;&%S="DI("T@,7T@(3T@)&-O;F9;)W%U;W1E)UTI
M"B`@("`@("`@("`@("`@("!\?`H@("`@("`@("`@("`@("`@*&-O=6YT*"1F
M:65L9',I("$]("1C;VYF6R=F:65L9',G72D*("`@("`@("`@("`@("`@("\O
M(%A86"!P97)H87!S('1H97)E(&ES(&$@<V5P87)A=&]R(&EN<VED92!A('%U
M;W1E9"!F:65L9`H@("`@("`@("`@("`@("`@+R]P<F5G7VUA=&-H*")\>R1C
M;VYF6R=Q=6]T92==?2XJ>R1C;VYF6R=S97`G77TN*GLD8V]N9ELG<75O=&4G
M77U\52(L("1L:6YE*0H@("`@("`@("`@("`@("`@*0H@("`@("`@("`@("![
M"B`@("`@("`@("`@("`@("!F<V5E:R@D9G`L("TQ("H@<W1R;&5N*"1L:6YE
M*2P@4T5%2U]#55(I.PH@("`@("`@("`@("`@("`@<F5T=7)N($9I;&5?0U-6
M.CIR96%D475O=&5D*"1F:6QE+"`D8V]N9BD["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D;&%S="`](')T<FEM*"1L87-T*3L*("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1F:65L9',@87,@)&L@/3X@)'8I('L*
M("`@("`@("`@("`@("`@("`@("`D9FEE;&1S6R1K72`]($9I;&5?0U-6.CIU
M;G%U;W1E*"1V+"`D8V]N9ELG<75O=&4G72D["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("AC;W5N="@D
M9FEE;&1S*2`A/2`D8V]N9ELG9FEE;&1S)UTI('L*("`@("`@("`@("`@1FEL
M95]#4U8Z.G)A:7-E17)R;W(H(E)E860@=W)O;F<@9FEE;&1S(&YU;6)E<B!C
M;W5N=#H@)R(N(&-O=6YT*"1F:65L9',I("X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("(G(&5X<&5C=&5D("(N)&-O;F9;)V9I96QD<R==
M*3L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B`D9FEE;&1S.PH@("`@?0H*("`@("\J*@H@("`@*B!);G1E<FYA
M;"!U<V4@;VYL>2P@=VEL;"!B92!R96UO=F5D(&EN('1H92!F=71U<F4*("`@
M("H*("`@("H@0'!A<F%M('-T<FEN9R`D<W1R(%1H92!S=')I;F<@=&\@9&5B
M=6<*("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`J+PH@("`@9G5N8W1I;VX@
M7V1B9T)U9F8H)'-T<BD*("`@('L*("`@("`@("!I9B`H<W1R<&]S*"1S='(L
M(")<<B(I("$]/2!F86QS92D@>PH@("`@("`@("`@("`D<W1R(#T@<W1R7W)E
M<&QA8V4H(EQR(BP@(E]R7R(L("1S='(I.PH@("`@("`@('T*("`@("`@("!I
M9B`H<W1R<&]S*"1S='(L(")<;B(I("$]/2!F86QS92D@>PH@("`@("`@("`@
M("`D<W1R(#T@<W1R7W)E<&QA8V4H(EQN(BP@(E]N7R(L("1S='(I.PH@("`@
M("`@('T*("`@("`@("!I9B`H<W1R<&]S*"1S='(L(")<="(I("$]/2!F86QS
M92D@>PH@("`@("`@("`@("`D<W1R(#T@<W1R7W)E<&QA8V4H(EQT(BP@(E]T
M7R(L("1S='(I.PH@("`@("`@('T*("`@("`@("!E8VAO(")B=69F.B`H)'-T
M<BE<;B(["B`@("!]"@H@("`@+RHJ"B`@("`J(%=R:71E<R!A('-T<G5C("AA
M<G)A>2D@:6X@82!F:6QE(&%S($-35@H@("`@*@H@("`@*B!`<&%R86T@<W1R
M:6YG("1F:6QE("`@5&AE(&9I;&5N86UE('=H97)E('1O('=R:71E('1H92!D
M871A"B`@("`J($!P87)A;2!A<G)A>2`@)&9I96QD<R!/<F1E<F5D(&%R<F%Y
M('=I=&@@=&AE(&1A=&$*("`@("H@0'!A<F%M(&%R<F%Y("`F)&-O;F8@("!4
M:&4@8V]N9FEG=7)A=&EO;B!O9B!T:&4@9&5S="!#4U8*("`@("H*("`@("H@
M0')E='5R;B!B;V]L(%1R=64@;VX@<W5C8V5S<R!F86QS92!O=&AE<G=I<V4*
M("`@("HO"B`@("!F=6YC=&EO;B!W<FET92@D9FEL92P@)&9I96QD<RP@)B1C
M;VYF*0H@("`@>PH@("`@("`@(&EF("@A)&9P(#T@1FEL95]#4U8Z.F=E=%!O
M:6YT97(H)&9I;&4L("1C;VYF+"!&24Q%7TU/1$5?5U))5$4I*2!["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@:68@*&-O
M=6YT*"1F:65L9',I("$]("1C;VYF6R=F:65L9',G72D@>PH@("`@("`@("`@
M("!&:6QE7T-35CHZ<F%I<V5%<G)O<B@B5W)O;F<@9FEE;&1S(&YU;6)E<B!C
M;W5N=#H@)R(N(&-O=6YT*"1F:65L9',I("X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("(G(&5X<&5C=&5D("(N)&-O;F9;)V9I96QD<R==
M*3L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H@("`@("`@
M("1W<FET92`]("<G.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT
M*"1F:65L9',I.R`D:2LK*2!["B`@("`@("`@("`@(&EF("@A:7-?;G5M97)I
M8R@D9FEE;&1S6R1I72D@)B8@)&-O;F9;)W%U;W1E)UTI('L*("`@("`@("`@
M("`@("`@("1W<FET92`N/2`D8V]N9ELG<75O=&4G72`N("1F:65L9'-;)&E=
M("X@)&-O;F9;)W%U;W1E)UT["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D=W)I=&4@+CT@)&9I96QD<ULD:5T["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@:68@*"1I(#P@*&-O=6YT*"1F:65L9',I("T@,2DI
M('L*("`@("`@("`@("`@("`@("1W<FET92`N/2`D8V]N9ELG<V5P)UT["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=W)I=&4@+CT@
M)&-O;F9;)V-R;&8G73L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!I9B`H(69W<FET92@D9G`L("1W<FET92DI('L*("`@("`@("`@("`@<F5T
M=7)N($9I;&5?0U-6.CIR86ES945R<F]R*"=#86X@;F]T('=R:71E('1O(&9I
M;&4G*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@+RHJ"B`@("`J($1I<V-O=F5R('1H92!F;W)M870@;V8@82!#4U8@9FEL
M92`H=&AE(&YU;6)E<B!O9B!F:65L9',L('1H92!S97!A<F%T;W(*("`@("H@
M86YD(&EF(&ET('%U;W1E('-T<FEN9R!F:65L9',I"B`@("`J"B`@("`J($!P
M87)A;2!S=')I;F<@=&AE($-35B!F:6QE(&YA;64*("`@("H@0'!A<F%M(&%R
M<F%Y(&5X=')A('-E<&%R871O<G,@=&AA="!S:&]U;&0@8F4@8VAE8VME9"!F
M;W(N"B`@("`J($!R971U<FX@;6EX960@07-S;V,@87)R87D@;W(@9F%L<V4*
M("`@("HO"B`@("!F=6YC=&EO;B!D:7-C;W9E<D9O<FUA="@D9FEL92P@)&5X
M=')A4V5P<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"$D9G`@/2!`
M9F]P96XH)&9I;&4L("=R)RDI('L*("`@("`@("`@("`@<F5T=7)N($9I;&5?
M0U-6.CIR86ES945R<F]R*")#;W5L9"!N;W0@;W!E;B!F:6QE.B`D9FEL92(I
M.PH@("`@("`@('T*("`@("`@("`D<V5P<R`](&%R<F%Y*")<="(L("<[)RP@
M)SHG+"`G+"<I.PH@("`@("`@("1S97!S(#T@87)R87E?;65R9V4H)'-E<',L
M("1E>'1R85-E<',I.PH@("`@("`@("1M871C:&5S(#T@87)R87DH*3L*"B`@
M("`@("`@+R\@4V5T(&%U=&\@9&5T96-T(&QI;F4@96YD:6YG(&9O<B!-86,@
M14],('-U<'!O<G0@:68@/"!02%`@-"XS+C`N"B`@("`@("`@)'!H<'9E<B`]
M('9E<G-I;VY?8V]M<&%R92@G-"XS+C`G+"!P:'!V97)S:6]N*"DL("<\)RD[
M"B`@("`@("`@:68@*"1P:'!V97(I('L*("`@("`@("`@("`@)&]L9&EN:2`]
M(&EN:5]G970H)V%U=&]?9&5T96-T7VQI;F5?96YD:6YG<R<I.PH@("`@("`@
M("`@("!I;FE?<V5T*"=A=71O7V1E=&5C=%]L:6YE7V5N9&EN9W,G+"`G,2<I
M.PH@("`@("`@('T*"B`@("`@("`@+R\@5&%K92!T:&4@9FER<W0@,3`@;&EN
M97,@86YD('-T;W)E('1H92!N=6UB97(@;V8@;V-U<G)E;F-E<PH@("`@("`@
M("\O(&9O<B!E86-H('-E<&%R871O<B!I;B!E86-H(&QI;F4*"B`@("`@("`@
M)&QI;F5S(#T@9FEL92@D9FEL92D["B`@("`@("`@:68@*&-O=6YT*"1L:6YE
M<RD@/B`Q,"D@>PH@("`@("`@("`@("`D;&EN97,@/2!A<G)A>5]S;&EC92@D
M;&EN97,L(#`L(#$P*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D<&AP=F5R
M*2!["B`@("`@("`@("`@(&EN:5]S970H)V%U=&]?9&5T96-T7VQI;F5?96YD
M:6YG<R<L("1O;&1I;FDI.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H
M)&QI;F5S(&%S("1L:6YE*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1S97!S
M(&%S("1S97`I('L*("`@("`@("`@("`@("`@("1M871C:&5S6R1S97!=6UT@
M/2!S=6)S=')?8V]U;G0H)&QI;F4L("1S97`I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`D9FEN86P@/2!A<G)A>2@I.PH@("`@("`@("\O
M($=R;W5P('1H92!R97-U;'1S(&)Y(&%M;W5N="!O9B!E<75A;"!O8W5R<F5N
M8V5S"B`@("`@("`@9F]R96%C:"`H)&UA=&-H97,@87,@)'-E<"`]/B`D<F5S
M*2!["B`@("`@("`@("`@("1T:6UE<R`](&%R<F%Y*"D["B`@("`@("`@("`@
M("1T:6UE<ULP72`](#`["B`@("`@("`@("`@(&9O<F5A8V@@*"1R97,@87,@
M)&L@/3X@)&YU;2D@>PH@("`@("`@("`@("`@("`@:68@*"1N=6T@/B`P*2![
M"B`@("`@("`@("`@("`@("`@("`@)'1I;65S6R1N=6U=(#T@*&ES<V5T*"1T
M:6UE<ULD;G5M72DI(#\@)'1I;65S6R1N=6U=("L@,2`Z(#$["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@87)S;W)T*"1T
M:6UE<RD["@H@("`@("`@("`@("`O+R!5<V4@;6%X(&9I96QD<R!C;W5N="X*
M("`@("`@("`@("`@)&9I96QD<ULD<V5P72`](&UA>"AA<G)A>5]F;&EP*"1T
M:6UE<RDI.PH@("`@("`@("`@("`D86UO=6YT6R1S97!=(#T@)'1I;65S6VME
M>2@D=&EM97,I73L*("`@("`@("!]"@H@("`@("`@(&%R<V]R="@D86UO=6YT
M*3L*("`@("`@("`D<V5P("`@(#T@:V5Y*"1A;6]U;G0I.PH*("`@("`@("`D
M8V]N9ELG9FEE;&1S)UT@/2`D9FEE;&1S6R1S97!=("L@,3L*("`@("`@("`D
M8V]N9ELG<V5P)UT@("`@/2`D<V5P.PH*("`@("`@("`O+R!497-T(&EF('1H
M97)E(&%R92!F:65L9',@=VET:"!Q=6]T97,@87)R;W5N9"!I;B!T:&4@9FER
M<W0@-2!L:6YE<PH@("`@("`@("1Q=6]T97,@/2`G(EPG)SL*("`@("`@("`D
M<75O=&4@(#T@;G5L;#L*("`@("`@("!I9B`H8V]U;G0H)&QI;F5S*2`^(#4I
M('L*("`@("`@("`@("`@)&QI;F5S(#T@87)R87E?<VQI8V4H)&QI;F5S+"`P
M+"`U*3L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1L:6YE<R!A<R`D
M;&EN92D@>PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@B?"1S97`H6R1Q
M=6]T97-=*2XJ*%LD<75O=&5S72DD<V5P?%4B+"`D;&EN92P@)&UA=&-H*2D@
M>PH@("`@("`@("`@("`@("`@:68@*"1M871C:%LQ72`]/2`D;6%T8VA;,ETI
M('L*("`@("`@("`@("`@("`@("`@("`D<75O=&4@/2`D;6%T8VA;,5T["B`@
M("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H(GQ>*%LD
M<75O=&5S72DN*BA;)'%U;W1E<UTI)'-E<'LP+#%]?"(L("1L:6YE+"`D;6%T
M8V@I"B`@("`@("`@("`@("`@("!\?"!P<F5G7VUA=&-H*")\*%LD<75O=&5S
M72DN*BA;)'%U;W1E<UTI)'-E<%QS)'Q5<R(L("1L:6YE+"`D;6%T8V@I*0H@
M("`@("`@("`@("!["B`@("`@("`@("`@("`@("!I9B`H)&UA=&-H6S%=(#T]
M("1M871C:%LR72D@>PH@("`@("`@("`@("`@("`@("`@("1Q=6]T92`]("1M
M871C:%LQ73L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D8V]N
M9ELG<75O=&4G72`]("1Q=6]T93L*("`@("`@("!F8VQO<V4H)&9P*3L*("`@
M("`@("`O+R!86%@@5VAA="!A8F]U="!T<GEI;F<@=&\@9&ES8V]V97(@=&AE
M(")H96%D97(B/PH@("`@("`@(')E='5R;B`D8V]N9CL*("`@('T*"B`@("`O
M*BH*("`@("`J($9R;VYT('1O(&-A;&P@9V5T4&]I;G1E<B!A;F0@;6]V:6YG
M('1H92!R97-O=7)C92!T;R!T:&4*("`@("`J(&)E9VEN;FEN9R!O9B!T:&4@
M9FEL90H@("`@("H@4F5S970@:70@:68@>6]U(&QI:V4N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D9FEL92!4:&4@;F%M92!O9B!T:&4@9FEL90H@
M("`@("H@0'!A<F%M(&%R<F%Y("`F)&-O;F8@5&AE(&-O;F9I9W5R871I;VX*
M("`@("`J($!P87)A;2!S=')I;F<@)&UO9&4@5&AE(&]P96X@;F]D92`H97@Z
M($9)3$5?34]$15]214%$(&]R($9)3$5?34]$15]74DE412D*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@=')U92!O;B!S=6-C97-S(&9A;'-E(&]N
M(&9A:6QU<F4*("`@("`J+PH@("`@9G5N8W1I;VX@<F5S9710;VEN=&5R*"1F
M:6QE+"`F)&-O;F8L("1M;V1E*0H@("`@>PH@("`@("`@(&EF("@A1FEL95]#
M4U8Z.F=E=%!O:6YT97(H)&9I;&4L("1C;VYF+"`D;6]D92P@=')U92DI('L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N('1R=64["B`@("!]"GT*/SX`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M1FEL92]5=&EL+G!H<```````````````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`S,34T,R`Q,#4Q-30S,S<S,2`P,C`W-S<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RH@=FEM
M.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A
M8G-T;W`]-#H@*B\*"B\J*@H@*B!&:6QE.CI5=&EL"B`J(`H@*B!02%`@=F5R
M<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE
M(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E
M"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M
M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@H@*B!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A
M(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O
M(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90H@*B!S96YD(&$@
M;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@
M8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@($9I;&4*("H@
M0'!A8VMA9V4@("`@($9I;&4*("H@0&%U=&AO<B`@("`@($UI8VAA96P@5V%L
M;&YE<B`\;6EK94!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`@,C`P-"TR,#`U
M($UI8VAA96P@5V%L;&YE<@H@*B!`;&EC96YS92`@("`@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V
M97)S:6]N("`@("!#5E,Z("1)9#H@571I;"YP:'`L=B`Q+C(Q(#(P,#4O,#@O
M,#D@,#<Z-3(Z,3,@;6EK92!%>'`@)`H@*B!`;&EN:R`@("`@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]P86-K86=E+T9I;&4*("HO"@HO*BHC0"L*("H@4V]R
M=&EN9R!#;VYS=&%N=',*("HO"F1E9FEN92@G1DE,15]33U)47TY/3D4G+"`@
M("`P*3L*9&5F:6YE*"=&24Q%7U-/4E1?4D5615)312<L(#$I.PID969I;F4H
M)T9)3$5?4T]25%].04U%)RP@("`@,BD["F1E9FEN92@G1DE,15]33U)47U-)
M6D4G+"`@("`T*3L*9&5F:6YE*"=&24Q%7U-/4E1?1$%412<L("`@(#@I.PID
M969I;F4H)T9)3$5?4T]25%]204Y$3TTG+"`@,38I.PHO*BHC0"TJ+PH*+RHJ
M(T`K"B`J($QI<W1I;F<@0V]N<W1A;G1S"B`J+PID969I;F4H)T9)3$5?3$E3
M5%]&24Q%4R<L("`@,2D["F1E9FEN92@G1DE,15],25-47T1)4E,G+"`@("`R
M*3L*9&5F:6YE*"=&24Q%7TQ)4U1?1$]44R<L("`@(#0I.PID969I;F4H)T9)
M3$5?3$E35%]!3$PG+"`@("`@1DE,15],25-47T9)3$53('P@1DE,15],25-4
M7T1)4E,@?"!&24Q%7TQ)4U1?1$]44RD["B\J*B-`+2HO"@HO*BH*("H@0&EG
M;F]R90H@*B\*9&5F:6YE*"=&24Q%7U=)3C,R)RP@9&5F:6YE9"@G3U-?5TE.
M1$]74R<I(#\@3U-?5TE.1$]74R`Z("%S=')N8V%S96-M<"A02%!?3U,L("=W
M:6XG+"`S*2D["@HO*BH@"B`J($9I;&5?571I;`H@*@H@*B!&:6QE(&%N9"!D
M:7)E8W1O<GD@=71I;&ET>2!F=6YC=&EO;G,N"B`J(`H@*B!`86-C97-S("!P
M=6)L:6,*("H@0'-T871I8PH@*B\*8VQA<W,@1FEL95]5=&EL"GL*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!A('-T<FEN9R!P871H(&)U:6QT(&9R;VT@=&AE
M(&%R<F%Y("1P871H4&%R=',N(%=H97)E(&$@:F]I;B`*("`@("`J(&]C8W5R
M<R!M=6QT:7!L92!S97!A<F%T;W)S(&%R92!R96UO=F5D+B!*;VEN<R!U<VEN
M9R!T:&4@;W!T:6]N86P@"B`@("`@*B!S97!A<F%T;W(L(&1E9F%U;'1I;F<@
M=&\@=&AE(%!(4"!$25)%0U1/4EE?4T5005)!5$]2(&-O;G-T86YT+@H@("`@
M("H@"B`@("`@*B!`<W1A=&EC"B`@("`@*B!`86-C97-S("!P=6)L:6,@"B`@
M("`@*B!`<&%R86T@("!A<G)A>2`@("1P87)T<R!!<G)A>2!C;VYT86EN:6YG
M('1H92!P87)T<R!T;R!B92!J;VEN960*("`@("`J($!P87)A;2`@('-T<FEN
M9R`@)'-E<&%R871O<B!4:&4@9&ER96-T;W)Y('-E<&5R871O<@H@("`@("HO
M"B`@("!F=6YC=&EO;B!B=6EL9%!A=&@H)'!A<G1S+"`D<V5P87)A=&]R(#T@
M1$E214-43U)97U-%4$%2051/4BD*("`@('L*("`@("`@("`D<7,@/2`G+UXG
M+B!P<F5G7W%U;W1E*"1S97!A<F%T;W(L("<O)RD@+B<K)"\G.PH@("`@("`@
M(&9O<B`H)&D@/2`P+"`D8R`](&-O=6YT*"1P87)T<RD[("1I(#P@)&,[("1I
M*RLI('L*("`@("`@("`@("`@:68@*"%S=')L96XH)'!A<G1S6R1I72D@?'P@
M<')E9U]M871C:"@D<7,L("1P87)T<ULD:5TI*2!["B`@("`@("`@("`@("`@
M("!U;G-E="@D<&%R='-;)&E=*3L*("`@("`@("`@("`@?2!E;'-E:68@*#`@
M/3T@)&DI('L*("`@("`@("`@("`@("`@("1P87)T<ULD:5T@/2!R=')I;2@D
M<&%R='-;)&E=+"`D<V5P87)A=&]R*3L*("`@("`@("`@("`@?2!E;'-E:68@
M*"1C("T@,2`]/2`D:2D@>PH@("`@("`@("`@("`@("`@)'!A<G1S6R1I72`]
M(&QT<FEM*"1P87)T<ULD:5TL("1S97!A<F%T;W(I.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)'!A<G1S6R1I72`]('1R:6TH)'!A
M<G1S6R1I72P@)'-E<&%R871O<BD["B`@("`@("`@("`@('T@"B`@("`@("`@
M?2`*("`@("`@("!R971U<FX@:6UP;&]D92@D<V5P87)A=&]R+"`D<&%R=',I
M.PH@("`@?2`*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!P871H('=I=&AO
M=70@;&5A9&EN9R`O(&]R($,Z7"X@268@=&AI<R!I<R!N;W0*("`@("`J('!R
M97-E;G0@=&AE('!A=&@@:7,@<F5T=7)N960@87,@:7,N"B`@("`@*B`*("`@
M("`J($!S=&%T:6,*("`@("`J($!A8V-E<W,@('!U8FQI8R`*("`@("`J($!P
M87)A;2`@('-T<FEN9R`@)'!A=&@@5&AE('!A=&@@=&\@8F4@<')O8V5S<V5D
M"B`@("`@*B!`<F5T=7)N("!S=')I;F<@(%1H92!P<F]C97-S960@<&%T:"!O
M<B!T:&4@<&%T:"!A<R!I<PH@("`@("HO"B`@("!F=6YC=&EO;B!S:VEP4F]O
M="@D<&%T:"D*("`@('L*("`@("`@("!I9B`H1FEL95]5=&EL.CII<T%B<V]L
M=71E*"1P871H*2D@>PH@("`@("`@("`@("!I9B`H1DE,15]724XS,BD@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N('-U8G-T<B@D<&%T:"P@)'!A=&A[,WT@
M/3T@)UQ<)R`_(#0@.B`S*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R
M971U<FX@;'1R:6TH)'!A=&@L("<O)RD["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D<&%T:#L*("`@('T@"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!T96UP(&1I<F5C=&]R>2!A8V-O<F1I;F<@=&\@96ET:&5R('1H92!435`L
M(%1-4$1)4BP@;W(@"B`@("`@*B!414U0(&5N=B!V87)I86)L97,N($EF('1H
M97-E(&%R92!N;W0@<V5T(&ET('=I;&P@86QS;R!C:&5C:R!F;W(@=&AE(`H@
M("`@("H@97AI<W1E;F-E(&]F("]T;7`L("5724Y$25(E7'1E;7`*("`@("`J
M(`H@("`@("H@0'-T871I8PH@("`@("H@0&%C8V5S<R`@<'5B;&EC(`H@("`@
M("H@0')E='5R;B`@<W1R:6YG("!4:&4@<WES=&5M('1M<"!D:7)E8W1O<GD*
M("`@("`J+PH@("`@9G5N8W1I;VX@=&UP1&ER*"D*("`@('L*("`@("`@("!I
M9B`H1DE,15]724XS,BD@>PH@("`@("`@("`@("!I9B`H:7-S970H)%]%3E9;
M)U1%35`G72DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D7T5.5ELG5$5-
M4"==.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AI<W-E="@D7T5.
M5ELG5$U0)UTI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)%]%3E9;)U1-
M4"==.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AI<W-E="@D7T5.
M5ELG=VEN9&ER)UTI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)%]%3E9;
M)W=I;F1I<B==("X@)UQ<=&5M<"<["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*&ES<V5T*"1?14Y66R=3>7-T96U2;V]T)UTI*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)%]%3E9;)U-Y<W1E;5)O;W0G72`N("=<7'1E;7`G
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AI<W-E="@D7U-%4E9%
M4ELG5$5-4"==*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1?4T525D52
M6R=414U0)UT["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES<V5T
M*"1?4T525D526R=435`G72DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M7U-%4E9%4ELG5$U0)UT["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@
M*&ES<V5T*"1?4T525D526R=W:6YD:7(G72DI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D7U-%4E9%4ELG=VEN9&ER)UT@+B`G7%QT96UP)SL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!I9B`H:7-S970H)%]315)615);)U-Y<W1E
M;5)O;W0G72DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D7U-%4E9%4ELG
M4WES=&5M4F]O="==("X@)UQ<=&5M<"<["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@<F5T=7)N("=<=&5M<"<["B`@("`@("`@?0H@("`@("`@(&EF("AI
M<W-E="@D7T5.5ELG5$U01$E2)UTI*2!["B`@("`@("`@("`@(')E='5R;B`D
M7T5.5ELG5$U01$E2)UT["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D
M7U-%4E9%4ELG5$U01$E2)UTI*2!["B`@("`@("`@("`@(')E='5R;B`D7U-%
M4E9%4ELG5$U01$E2)UT["B`@("`@("`@?0H@("`@("`@(')E='5R;B`G+W1M
M<"<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@=&5M<&]R87)Y
M(&9I;&5N86UE('5S:6YG('1E;7!N86TH*2!A;F0@1FEL93HZ=&UP1&ER*"DN
M"B`@("`@*B`*("`@("`J($!S=&%T:6,*("`@("`J($!A8V-E<W,@('!U8FQI
M8R`*("`@("`J($!P87)A;2`@('-T<FEN9R`@)&1I<FYA;64@3W!T:6]N86P@
M9&ER96-T;W)Y(&YA;64@9F]R('1H92!T;7`@9FEL90H@("`@("H@0')E='5R
M;B`@<W1R:6YG("!&:6QE;F%M92!A;F0@<&%T:"!O9B!T:&4@=&UP(&9I;&4*
M("`@("`J+PH@("`@9G5N8W1I;VX@=&UP1FEL92@D9&ER;F%M92`](&YU;&PI
M"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D9&ER;F%M92DI('L*("`@("`@
M("`@("`@)&1I<FYA;64@/2!&:6QE7U5T:6PZ.G1M<$1I<B@I.PH@("`@("`@
M('T@"B`@("`@("`@<F5T=7)N('1E;7!N86TH)&1I<FYA;64L("=T96UP+B<I
M.PH@("`@?2`*"B`@("`O*BH*("`@("`J(%)E='5R;G,@8F]O;&5A;B!B87-E
M9"!O;B!W:&5T:&5R(&=I=F5N('!A=&@@:7,@86)S;VQU=&4@;W(@;F]T+@H@
M("`@("H@"B`@("`@*B!`<W1A=&EC"B`@("`@*B!`86-C97-S("!P=6)L:6,@
M"B`@("`@*B!`<&%R86T@("!S=')I;F<@("1P871H($=I=F5N('!A=&@*("`@
M("`J($!R971U<FX@(&)O;VQE86X@5')U92!I9B!T:&4@<&%T:"!I<R!A8G-O
M;'5T92P@9F%L<V4@:68@:70@:7,@;F]T"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&ES06)S;VQU=&4H)'!A=&@I"B`@("!["B`@("`@("`@:68@*'!R96=?;6%T
M8V@H)R\H/SI<+WQ<7%PI7"Y<+B@_/5PO?"0I+R<L("1P871H*2D@>PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?2`*("`@("`@("!I9B`H
M1DE,15]724XS,BD@>PH@("`@("`@("`@("!R971U<FX@<')E9U]M871C:"@G
M+UY;82UZ02U:73HH7%Q<?%PO*2\G+"`D<&%T:"D["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`H)'!A=&A[,'T@/3T@)R\G*2!\?"`H)'!A=&A[,'T@/3T@
M)WXG*3L*("`@('T@"@H@("`@+RHJ"B`@("`@*B!'970@<&%T:"!R96QA=&EV
M92!T;R!A;F]T:&5R('!A=&@*("`@("`J"B`@("`@*B!`<W1A=&EC"B`@("`@
M*B!`86-C97-S("!P=6)L:6,*("`@("`J($!R971U<FX@('-T<FEN9PH@("`@
M("H@0'!A<F%M("`@<W1R:6YG("`D<&%T:`H@("`@("H@0'!A<F%M("`@<W1R
M:6YG("`D<F]O=`H@("`@("H@0'!A<F%M("`@<W1R:6YG("`D<V5P87)A=&]R
M"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;&%T:79E4&%T:"@D<&%T:"P@)')O
M;W0L("1S97!A<F%T;W(@/2!$25)%0U1/4EE?4T5005)!5$]2*0H@("`@>PH@
M("`@("`@("1P871H(#T@1FEL95]5=&EL.CIR96%L<&%T:"@D<&%T:"P@)'-E
M<&%R871O<BD["B`@("`@("`@)')O;W0@/2!&:6QE7U5T:6PZ.G)E86QP871H
M*"1R;V]T+"`D<V5P87)A=&]R*3L*("`@("`@("`D9&ER<R`](&5X<&QO9&4H
M)'-E<&%R871O<BP@)'!A=&@I.PH@("`@("`@("1C;VUP(#T@97AP;&]D92@D
M<V5P87)A=&]R+"`D<F]O="D["B`@("`@("`@"B`@("`@("`@:68@*$9)3$5?
M5TE.,S(I('L*("`@("`@("`@("`@:68@*'-T<F-A<V5C;7`H)&1I<G-;,%TL
M("1C;VUP6S!=*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1P871H.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@('5N<V5T*"1D:7)S6S!=+"`D8V]M
M<%LP72D["B`@("`@("`@?0H@("`@("`@(`H@("`@("`@(&9O<F5A8V@@*"1C
M;VUP(&%S("1I(#T^("1P87)T*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D
M9&ER<ULD:5TI("8F("1P87)T(#T]("1D:7)S6R1I72D@>PH@("`@("`@("`@
M("`@("`@=6YS970H)&1I<G-;)&E=+"`D8V]M<%LD:5TI.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@(`H@("`@("`@(')E='5R;B!S=')?<F5P
M96%T*"<N+B<@+B`D<V5P87)A=&]R+"!C;W5N="@D8V]M<"DI("X@:6UP;&]D
M92@D<V5P87)A=&]R+"`D9&ER<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'
M970@<F5A;"!P871H("AW;W)K<R!W:71H(&YO;BUE>&ES=&%N="!P871H<RD*
M("`@("`J"B`@("`@*B!`<W1A=&EC"B`@("`@*B!`86-C97-S("!P=6)L:6,*
M("`@("`J($!R971U<FX@('-T<FEN9PH@("`@("H@0'!A<F%M("`@<W1R:6YG
M("`D<&%T:`H@("`@("H@0'!A<F%M("`@<W1R:6YG("`D<V5P87)A=&]R"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')E86Q0871H*"1P871H+"`D<V5P87)A=&]R
M(#T@1$E214-43U)97U-%4$%2051/4BD*("`@('L*("`@("`@("!I9B`H(7-T
M<FQE;B@D<&%T:"DI('L*("`@("`@("`@("`@<F5T=7)N("1S97!A<F%T;W([
M"B`@("`@("`@?0H@("`@("`@(`H@("`@("`@("1D<FEV92`]("<G.PH@("`@
M("`@(&EF("A&24Q%7U=)3C,R*2!["B`@("`@("`@("`@("1P871H(#T@<')E
M9U]R97!L86-E*"<O6UQ<7%Q<+UTO)RP@)'-E<&%R871O<BP@)'!A=&@I.PH@
M("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+RA;82UZ02U:75PZ*2@N*BDO
M)RP@)'!A=&@L("1M871C:&5S*2D@>PH@("`@("`@("`@("`@("`@)&1R:79E
M(#T@)&UA=&-H97-;,5T["B`@("`@("`@("`@("`@("`D<&%T:"`@/2`D;6%T
M8VAE<ULR73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1C=V0@("`](&=E=&-W9"@I.PH@("`@("`@("`@("`@("`@)&1R:79E(#T@
M<W5B<W1R*"1C=V0L(#`L(#(I.PH@("`@("`@("`@("`@("`@:68@*"1P871H
M>S!]("$]/2`D<V5P87)A=&]R>S!]*2!["B`@("`@("`@("`@("`@("`@("`@
M)'!A=&@@(#T@<W5B<W1R*"1C=V0L(#,I("X@)'-E<&%R871O<B`N("1P871H
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E
M;'-E:68@*"1P871H>S!]("$]/2`D<V5P87)A=&]R*2!["B`@("`@("`@("`@
M("1P871H(#T@9V5T8W=D*"D@+B`D<V5P87)A=&]R("X@)'!A=&@["B`@("`@
M("`@?0H@("`@("`@(`H@("`@("`@("1D:7)3=&%C:R`](&%R<F%Y*"D["B`@
M("`@("`@9F]R96%C:"`H97AP;&]D92@D<V5P87)A=&]R+"`D<&%T:"D@87,@
M)&1I<BD@>PH@("`@("`@("`@("!I9B`H<W1R;&5N*"1D:7(I("8F("1D:7(@
M(3T]("<N)RD@>PH@("`@("`@("`@("`@("`@:68@*"1D:7(@/3T@)RXN)RD@
M>PH@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W!O<"@D9&ER4W1A8VLI.PH@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D
M9&ER4W1A8VM;72`]("1D:7(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@<F5T=7)N("1D<FEV
M92`N("1S97!A<F%T;W(@+B!I;7!L;V1E*"1S97!A<F%T;W(L("1D:7)3=&%C
M:RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:R!W:&5T:&5R('!A=&@@
M:7,@:6X@<F]O="!P871H"B`@("`@*@H@("`@("H@0'-T871I8PH@("`@("H@
M0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<F5T=7)N("!B;V]L"B`@("`@*B!`
M<&%R86T@("!S=')I;F<@("1P871H"B`@("`@*B!`<&%R86T@("!S=')I;F<@
M("1R;V]T"B`@("`@*B\*("`@(&9U;F-T:6]N('!A=&A);E)O;W0H)'!A=&@L
M("1R;V]T*0H@("`@>PH@("`@("`@('-T871I8R`D<F5A;%!A=&AS(#T@87)R
M87DH*3L*("`@("`@("`*("`@("`@("!I9B`H(6ES<V5T*"1R96%L4&%T:'-;
M)')O;W1=*2D@>PH@("`@("`@("`@("`D<F5A;%!A=&AS6R1R;V]T72`]($9I
M;&5?571I;#HZ<F5A;%!A=&@H)')O;W0I.PH@("`@("`@('T*("`@("`@("`*
M("`@("`@("!R971U<FX@9F%L<V4@(3T]('-T<G-T<BA&:6QE7U5T:6PZ.G)E
M86Q0871H*"1P871H*2P@)')E86Q0871H<ULD<F]O=%TI.PH@("`@?0H*("`@
M("\J*@H@("`@("H@3&ES="!$:7)E8W1O<GD*("`@("`J(`H@("`@("H@5&AE
M(&9I;F%L(&%R9W5M96YT+"`D8V(L(&ES(&$@8V%L;&)A8VL@=&AA="!E:71H
M97(@979A;'5A=&5S('1O('1R=64@;W(*("`@("`J(&9A;'-E(&%N9"!P97)F
M;W)M<R!A(&9I;'1E<B!O<&5R871I;VXL(&]R(&ET(&-A;B!A;'-O(&UO9&EF
M>2!T:&4@"B`@("`@*B!D:7)E8W1O<GDO9FEL92!N86UE<R!R971U<FYE9"X@
M(%1O(&%C:&EE=F4@=&AE(&QA='1E<B!E9F9E8W0@=7-E(&%S(`H@("`@("H@
M9F]L;&]W<SH*("`@("`J(`H@("`@("H@/&-O9&4^"B`@("`@*B`\/W!H<`H@
M("`@("H@9G5N8W1I;VX@=6,H)B1F:6QE;F%M92D@>PH@("`@("H@("`@("1F
M:6QE;F%M92`]('-T<G1O=7!P97(H)&9I;&5N86UE*3L*("`@("`J("`@("!R
M971U<FX@=')U93L*("`@("`J('T*("`@("`J("1E;G1R:65S(#T@1FEL95]5
M=&EL.CIL:7-T1&ER*"<N)RP@1DE,15],25-47T%,3"P@1DE,15]33U)47TY/
M3D4L("=U8R<I.PH@("`@("H@9F]R96%C:"`H)&5N=')I97,@87,@)&4I('L*
M("`@("`J("`@("!E8VAO("1E+3YN86UE+"`B7&XB.PH@("`@("H@?0H@("`@
M("H@/SX*("`@("`J(#PO8V]D93X*("`@("`J(`H@("`@("H@0'-T871I8PH@
M("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<F5T=7)N("!A<G)A>0H@
M("`@("H@0'!A<F%M("`@<W1R:6YG("`D<&%T:`H@("`@("H@0'!A<F%M("`@
M:6YT("`@("`D;&ES=`H@("`@("H@0'!A<F%M("`@:6YT("`@("`D<V]R=`H@
M("`@("H@0'!A<F%M("`@;6EX960@("`D8V(*("`@("`J+PH@("`@9G5N8W1I
M;VX@;&ES=$1I<B@D<&%T:"P@)&QI<W0@/2!&24Q%7TQ)4U1?04Q,+"`D<V]R
M="`]($9)3$5?4T]25%].3TY%+"`D8V(@/2!N=6QL*0H@("`@>PH@("`@("`@
M(&EF("@A<W1R;&5N*"1P871H*2!\?"`A:7-?9&ER*"1P871H*2D@>PH@("`@
M("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("`@("`@"B`@("`@
M("`@)&5N=')I97,@/2!A<G)A>2@I.PH@("`@("`@(&9O<B`H)&1I<B`](&1I
M<B@D<&%T:"D[(&9A;'-E("$]/2`D96YT<GD@/2`D9&ER+3YR96%D*"D[("D@
M>PH@("`@("`@("`@("!I9B`H)&QI<W0@)B!&24Q%7TQ)4U1?1$]44R!\?"`D
M96YT<GE[,'T@(3T]("<N)RD@>PH@("`@("`@("`@("`@("`@)&ES4F5F(#T@
M*"1E;G1R>2`]/3T@)RXG('Q\("1E;G1R>2`]/3T@)RXN)RD["B`@("`@("`@
M("`@("`@("`D:7-$:7(@/2`D:7-2968@?'P@:7-?9&ER*"1P871H("XG+R<N
M("1E;G1R>2D["B`@("`@("`@("`@("`@("!I9B`H("`@("@H(21I<T1I<B`F
M)B`D;&ES="`F($9)3$5?3$E35%]&24Q%4RD@("!\?`H@("`@("`@("`@("`@
M("`@("`@("`@("`@*"1I<T1I<B`@)B8@)&QI<W0@)B!&24Q%7TQ)4U1?1$E2
M4RDI("`@)B8*("`@("`@("`@("`@("`@("`@("`@("`@*"%I<U]C86QL86)L
M92@D8V(I('Q\(`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V%L;%]U
M<V5R7V9U;F-?87)R87DH)&-B+"!A<G)A>2@F)&5N=')Y*2DI*2!["B`@("`@
M("`@("`@("`@("`@("`@)&5N=')I97-;72`]("AO8FIE8W0I(&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("`@("`G;F%M92<@(#T^("1E;G1R>2P*("`@
M("`@("`@("`@("`@("`@("`@("`@)W-I>F4G("`]/B`D:7-$:7(@/R!N=6QL
M(#H@9FEL97-I>F4H)'!A=&@@+B<O)RX@)&5N=')Y*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@)V1A=&4G("`]/B!F:6QE;71I;64H)'!A=&@@+B<O)RX@
M)&5N=')Y*2P*("`@("`@("`@("`@("`@("`@("`I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1D:7(M/F-L
M;W-E*"D["B`@("`@("`@"B`@("`@("`@:68@*"1S;W)T*2!["B`@("`@("`@
M("`@("1E;G1R:65S(#T@1FEL95]5=&EL.CIS;W)T1FEL97,H)&5N=')I97,L
M("1S;W)T*3L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@<F5T=7)N("1E
M;G1R:65S.PH@("`@?0H@("`@"B`@("`O*BH*("`@("`J(%-O<G0@1FEL97,*
M("`@("`J(`H@("`@("H@0'-T871I8PH@("`@("H@0&%C8V5S<R`@<'5B;&EC
M"B`@("`@*B!`<F5T=7)N("!A<G)A>0H@("`@("H@0'!A<F%M("`@87)R87D@
M("`D9FEL97,*("`@("`J($!P87)A;2`@(&EN="`@("`@)'-O<G0*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V]R=$9I;&5S*"1F:6QE<RP@)'-O<G0I"B`@("![
M"B`@("`@("`@:68@*"$D9FEL97,I('L*("`@("`@("`@("`@<F5T=7)N(&%R
M<F%Y*"D["B`@("`@("`@?0H@("`@("`@(`H@("`@("`@(&EF("@A)'-O<G0I
M('L*("`@("`@("`@("`@<F5T=7)N("1F:6QE<SL*("`@("`@("!]"B`@("`@
M("`@"B`@("`@("`@:68@*"1S;W)T(#T]/2`Q*2!["B`@("`@("`@("`@(')E
M='5R;B!A<G)A>5]R979E<G-E*"1F:6QE<RD["B`@("`@("`@?0H@("`@("`@
M(`H@("`@("`@(&EF("@D<V]R="`F($9)3$5?4T]25%]204Y$3TTI('L*("`@
M("`@("`@("`@<VAU9F9L92@D9FEL97,I.PH@("`@("`@("`@("!R971U<FX@
M)&9I;&5S.PH@("`@("`@('T*("`@("`@("`*("`@("`@("`D;F%M97,@/2!A
M<G)A>2@I.PH@("`@("`@("1S:7IE<R`](&%R<F%Y*"D["B`@("`@("`@)&1A
M=&5S(#T@87)R87DH*3L*("`@(`H@("`@("`@(&EF("@D<V]R="`F($9)3$5?
M4T]25%].04U%*2!["B`@("`@("`@("`@("1R(#T@)B1N86UE<SL*("`@("`@
M("!](&5L<V5I9B`H)'-O<G0@)B!&24Q%7U-/4E1?1$%412D@>PH@("`@("`@
M("`@("`D<B`]("8D9&%T97,["B`@("`@("`@?2!E;'-E:68@*"1S;W)T("8@
M1DE,15]33U)47U-)6D4I('L*("`@("`@("`@("`@)'(@/2`F)'-I>F5S.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(&%S;W)T*"1F:6QE<RP@4T]2
M5%]214=53$%2*3L*("`@("`@("`@("`@<F5T=7)N("1F:6QE<SL*("`@("`@
M("!]"B`@("`@("`@"B`@("`@("`@)'-O<G1&;&%G<R`](&%R<F%Y*`H@("`@
M("`@("`@("!&24Q%7U-/4E1?3D%-12`]/B!33U)47U-44DE.1RP@"B`@("`@
M("`@("`@($9)3$5?4T]25%]$051%(#T^(%-/4E1?3E5-15))0RP@"B`@("`@
M("`@("`@($9)3$5?4T]25%]325I%(#T^(%-/4E1?3E5-15))0RP*("`@("`@
M("`I.PH@("`@("`@(`H@("`@("`@(&9O<F5A8V@@*"1F:6QE<R!A<R`D9FEL
M92D@>PH@("`@("`@("`@("`D;F%M97-;72`]("1F:6QE+3YN86UE.PH@("`@
M("`@("`@("`D<VEZ97-;72`]("1F:6QE+3YS:7IE.PH@("`@("`@("`@("`D
M9&%T97-;72`]("1F:6QE+3YD871E.PH@("`@("`@('T*("`@("`@("`*("`@
M("`@("!I9B`H)'-O<G0@)B!&24Q%7U-/4E1?4D5615)312D@>PH@("`@("`@
M("`@("!A<G-O<G0H)'(L("1S;W)T1FQA9W-;)'-O<G0@)B!^,5TI.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(&%S;W)T*"1R+"`D<V]R=$9L86=S
M6R1S;W)T72D["B`@("`@("`@?0H@("`@"B`@("`@("`@)')E<W5L="`](&%R
M<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)'(@87,@)&D@/3X@)&8I('L*("`@
M("`@("`@("`@)')E<W5L=%M=(#T@)&9I;&5S6R1I73L*("`@("`@("!]"B`@
M("`*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*("`@(`H@("`@+RHJ
M"B`@("`@*B!3=VET8V@@1FEL92!%>'1E;G-I;VX*("`@("`J(`H@("`@("H@
M0'-T871I8PH@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<F5T=7)N
M("!S=')I;F=\87)R87D*("`@("`J($!P87)A;2`@('-T<FEN9WQA<G)A>2`@
M("`D9FEL96YA;64*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`D
M=&\@;F5W(&9I;&4@97AT96YS:6]N"B`@("`@*B!`<&%R86T@("!S=')I;F<@
M("`@("`@("`@)&9R;VT@8VAA;F=E(&]N;'D@9FEL97,@=VET:"!T:&ES(&5X
M=&5N<VEO;@H@("`@("H@0'!A<F%M("`@8F]O;"`@("`@("`@("`@("1R979E
M<G-E(&-H86YG92!O;FQY(&9I;&5S(&YO="!H879I;F<@)&9R;VT@97AT96YS
M:6]N"B`@("`@*B\*("`@(&9U;F-T:6]N('-W:71C:$5X="@D9FEL96YA;64L
M("1T;RP@)&9R;VT@/2!N=6QL+"`D<F5V97)S92`](&9A;'-E*0H@("`@>PH@
M("`@("`@(&EF("AI<U]A<G)A>2@D9FEL96YA;64I*2!["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1F:6QE;F%M92!A<R`D:V5Y(#T^("1F:6QE*2!["B`@("`@
M("`@("`@("`@("`D9FEL96YA;65;)&ME>5T@/2!&:6QE7U5T:6PZ.G-W:71C
M:$5X="@D9FEL92P@)'1O+"`D9G)O;2D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@<F5T=7)N("1F:6QE;F%M93L*("`@("`@("!]"B`@("`@("`@"B`@
M("`@("`@:68@*"1L96X@/2!S=')L96XH)&9R;VTI*2!["B`@("`@("`@("`@
M("1E>'0@/2!S=6)S='(H)&9I;&5N86UE+"`M)&QE;B`M(#$I.PH@("`@("`@
M("`@("`D8V9N(#T@1DE,15]724XS,B`_("=S=')C87-E8VUP)R`Z("=S=')C
M;7`G.PH@("`@("`@("`@("!I9B`H(21R979E<G-E(#T]("1C9FXH)&5X="P@
M)RXG+B`D9G)O;2DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D9FEL96YA
M;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N('-U8G-T<B@D
M9FEL96YA;64L(#`L("TD;&5N("T@,2D@+B<N)RX@)'1O.PH@("`@("`@('T*
M("`@("`@("`*("`@("`@("!I9B`H)'!O<R`]('-T<G!O<R@D9FEL96YA;64L
M("<N)RDI('L*("`@("`@("`@("`@<F5T=7)N('-U8G-T<B@D9FEL96YA;64L
M(#`L("1P;W,I("XG+B<N("1T;SL*("`@("`@("!]"B`@("`@("`@"B`@("`@
M("`@<F5T=7)N("1F:6QE;F%M92`N)RXG+B`D=&\["B`@("!]"B`@("`*?0H*
M/SX*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O4$5!4@``````````````````````````````````````````
M```````````````````````````````````````````````P,#`W-34@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<S,B`P,3<Q,S4`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+T1O=VYL;V%D97(`````
M````````````````````````````````````````````````````````````
M`````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P
M-3$U-#,S-S,Q(#`R,3(S,@`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%
M05(O1&]W;FQO861E<B]086-K86=E+G!H<```````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`R,30Q-C4@,3`U,34T,S,W,S$@,#(S,S8V`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP#0HO*BH-"B`J
M(%!%05)?1&]W;FQO861E<E]086-K86=E#0H@*@T*("H@4$A0('9E<G-I;VYS
M(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES
M('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@
M*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@
M8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O
M(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A
M(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A
M(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*
M("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V
M97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V
M(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E
M<G-I;VX@("`@0U93.B`D260Z(%!A8VMA9V4N<&AP+'8@,2XY,2`R,#`V+S`Q
M+S(S(#$Y.C`U.C4R(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T
M<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@
M($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0HO
M*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!P87)A;65T97(@:6YI=&EA;&EZ871I
M;VX@9F%I;',@8F5C875S92!N;R!R96QE87-E<PT*("H@97AI<W0@=VET:&EN
M('!R969E<G)E9%]S=&%T92P@8G5T(')E;&5A<V5S(&1O(&5X:7-T#0H@*B\-
M"F1E9FEN92@G4$5!4E]$3U=.3$]!1$527U!!0TM!1T5?4U1!5$4G+"`M,3`P
M,RD[#0HO*BH-"B`J($-O;W)D:6YA=&5S(&1O=VYL;V%D('!A<F%M971E<G,@
M86YD(&UA;F%G97,@=&AE:7(@9&5P96YD96YC:65S#0H@*B!P<FEO<B!T;R!D
M;W=N;&]A9&EN9R!T:&5M+@T*("H-"B`J($EN<'5T(&-A;B!C;VUE(&9R;VT@
M=&AR964@<V]U<F-E<SH-"B`J#0H@*B`M(&QO8V%L(&9I;&5S("AA<F-H:79E
M<R!O<B!P86-K86=E+GAM;"D-"B`J("T@<F5M;W1E(&9I;&5S("AD;W=N;&]A
M9&%B;&4@=7)L<RD-"B`J("T@86)S=')A8W0@<&%C:V%G92!N86UE<PT*("H-
M"B`J(%1H92!F:7)S="!T=V\@96QE;65N=',@87)E(&AA;F1L960@8VQE86YL
M>2!B>2!014%27U!A8VMA9V5&:6QE+"!B=70@=&AE('1H:7)D(')E<75I<F5S
M#0H@*B!A8V-E<W-I;F<@<&5A<G=E8B=S('AM;"UR<&,@:6YT97)F86-E('1O
M(&1E=&5R;6EN92!N96-E<W-A<GD@9&5P96YD96YC:65S+"!A;F0@=&AE#0H@
M*B!F;W)M870@<F5T=7)N960@;V8@9&5P96YD96YC:65S(&ES('-L:6=H=&QY
M(&1I9F9E<F5N="!F<F]M('1H870@=7-E9"!I;B!P86-K86=E+GAM;"X-"B`J
M#0H@*B!4:&ES(&-L87-S(&AI9&5S('1H92!D:69F97)E;F-E<R!B971W965N
M('1H97-E(&5L96UE;G1S+"!A;F0@;6%K97,@875T;VUA=&EC#0H@*B!D97!E
M;F1E;F-Y(')E<V]L=71I;VX@82!P:65C92!O9B!C86ME+B`@270@86QS;R!M
M86YA9V5S(&-O;F9L:6-T<R!W:&5N#0H@*B!T=V\@8VQA<W-E<R!D97!E;F0@
M;VX@:6YC;VUP871I8FQE(&1E<&5N9&5N8VEE<RP@;W(@9&EF9F5R:6YG('9E
M<G-I;VYS(&]F('1H92!S86UE#0H@*B!P86-K86=E(&1E<&5N9&5N8WDN("!)
M;B!A9&1I=&EO;BP@9&]W;FQO860@=VEL;"!N;W0@8F4@871T96UP=&5D(&EF
M('1H92!P:'`@=F5R<VEO;B!I<PT*("H@;F]T('-U<'!O<G1E9"P@4$5!4B!I
M;G-T86QL97(@=F5R<VEO;B!I<R!N;W0@<W5P<&]R=&5D+"!O<B!N;VXM4$5#
M3"!E>'1E;G-I;VYS(&%R92!N;W0-"B`J(&EN<W1A;&QE9"X-"B`J($!C871E
M9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@
M("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG
M:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS
M92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN
M:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@
M0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT
M+C!A,0T*("HO#0IC;&%S<R!014%27T1O=VYL;V%D97)?4&%C:V%G90T*>PT*
M("`@("\J*@T*("`@("`J($!V87(@4$5!4E]$;W=N;&]A9&5R#0H@("`@("HO
M#0H@("`@=F%R("1?9&]W;FQO861E<CL-"B`@("`O*BH-"B`@("`@*B!`=F%R
M(%!%05)?0V]N9FEG#0H@("`@("HO#0H@("`@=F%R("1?8V]N9FEG.PT*("`@
M("\J*@T*("`@("`J($!V87(@4$5!4E]296=I<W1R>0T*("`@("`J+PT*("`@
M('9A<B`D7W)E9VES=')Y.PT*("`@("\J*@T*("`@("`J(%5S960@=&\@:6UP
M;&5M96YT('!A8VMA9VEN9W)O;W0@<')O<&5R;'D-"B`@("`@*B!`=F%R(%!%
M05)?4F5G:7-T<GD-"B`@("`@*B\-"B`@("!V87(@)%]I;G-T86QL4F5G:7-T
M<GD[#0H@("`@+RHJ#0H@("`@("H@0'9A<B!014%27U!A8VMA9V5&:6QE7W8Q
M?%!%05)?4&%C:V%G949I;&5\=C(-"B`@("`@*B\-"B`@("!V87(@)%]P86-K
M86=E9FEL93L-"B`@("`O*BH-"B`@("`@*B!`=F%R(&%R<F%Y#0H@("`@("HO
M#0H@("`@=F%R("1?<&%R<V5D;F%M93L-"B`@("`O*BH-"B`@("`@*B!`=F%R
M(&%R<F%Y#0H@("`@("HO#0H@("`@=F%R("1?9&]W;FQO86154DP[#0H@("`@
M+RHJ#0H@("`@("H@0'9A<B!A<G)A>0T*("`@("`J+PT*("`@('9A<B`D7V1O
M=VYL;V%D1&5P<R`](&%R<F%Y*"D[#0H@("`@+RHJ#0H@("`@("H@0'9A<B!B
M;V]L96%N#0H@("`@("HO#0H@("`@=F%R("1?=F%L:60@/2!F86QS93L-"B`@
M("`O*BH-"B`@("`@*B!`=F%R(&)O;VQE86X-"B`@("`@*B\-"B`@("!V87(@
M)%]A;F%L>7IE9"`](&9A;'-E.PT*("`@("\J*@T*("`@("`J(&EF('1H:7,@
M;W(@82!P87)E;G0@<&%C:V%G92!W87,@:6YV;VME9"!W:71H(%!A8VMA9V4M
M<W1A=&4L('1H:7,@:7,@<V5T('1O('1H90T*("`@("`J('-T871E('9A<FEA
M8FQE+@T*("`@("`J#0H@("`@("H@5&AI<R!A;&QO=W,@=&5M<&]R87)Y(')E
M87-S:6=N;65N="!O9B!P<F5F97)R961?<W1A=&4@9F]R(&$@<&%R96YT('!A
M8VMA9V4@86YD(&%L;"!O9@T*("`@("`J(&ET<R!D97!E;F1E;F-I97,N#0H@
M("`@("H@0'9A<B!S=')I;F=\9F%L<V4-"B`@("`@*B\-"B`@("!V87(@)%]E
M>'!L:6-I=%-T871E(#T@9F%L<V4[#0H@("`@+RHJ#0H@("`@("H@268@=&AI
M<R!P86-K86=E(&ES(&EN=F]K960@=VET:"!086-K86=E(V=R;W5P+"!T:&ES
M('9A<FEA8FQE('=I;&P@8F4@=')U90T*("`@("`J+PT*("`@('9A<B`D7V5X
M<&QI8VET1W)O=7`@/2!F86QS93L-"B`@("`O*BH-"B`@("`@*B!086-K86=E
M('1Y<&4@;&]C86Q\=7)L?'AM;')P8PT*("`@("`J($!V87(@<W1R:6YG#0H@
M("`@("HO#0H@("`@=F%R("1?='EP93L-"B`@("`O*BH-"B`@("`@*B!#;VYT
M96YT<R!O9B!P86-K86=E+GAM;"P@:68@9&]W;FQO861E9"!F<F]M(&$@<F5M
M;W1E(&-H86YN96P-"B`@("`@*B!`=F%R('-T<FEN9WQF86QS90T*("`@("`J
M($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D7W)A=W!A8VMA
M9V5F:6QE.PT*("`@("\J*@T*("`@("`J($!V87(@8F]O;&5A;@T*("`@("`J
M($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D7W9A;&ED871E
M9"`](&9A;'-E.PT*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(%!%05)?1&]W
M;FQO861E<@T*("`@("`J+PT*("`@(&9U;F-T:6]N(%!%05)?1&]W;FQO861E
M<E]086-K86=E*"8D9&]W;FQO861E<BD-"B`@("![#0H@("`@("`@("1T:&ES
M+3Y?9&]W;FQO861E<B`]("8D9&]W;FQO861E<CL-"B`@("`@("`@)'1H:7,M
M/E]C;VYF:6<@/2`F)'1H:7,M/E]D;W=N;&]A9&5R+3YC;VYF:6<[#0H@("`@
M("`@("1T:&ES+3Y?<F5G:7-T<GD@/2`F)'1H:7,M/E]C;VYF:6<M/F=E=%)E
M9VES=')Y*"D[#0H@("`@("`@("1O<'1I;VYS(#T@)&1O=VYL;V%D97(M/F=E
M=$]P=&EO;G,H*3L-"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=P86-K
M86=I;F=R;V]T)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7V-O;F9I9RT^
M<V5T26YS=&%L;%)O;W0H)&]P=&EO;G-;)W!A8VMA9VEN9W)O;W0G72D[#0H@
M("`@("`@("`@("`D=&AI<RT^7VEN<W1A;&Q296=I<W1R>2`]("8D=&AI<RT^
M7V-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-"B`@("`@("`@("`@("1T:&ES+3Y?
M8V]N9FEG+3YS971);G-T86QL4F]O="AF86QS92D[#0H@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`D=&AI<RT^7VEN<W1A;&Q296=I<W1R>2`]("8D
M=&AI<RT^7W)E9VES=')Y.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?
M=F%L:60@/2`D=&AI<RT^7V%N86QY>F5D(#T@9F%L<V4[#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@4&%R<V4@=&AE(&EN<'5T(&%N9"!D971E<FUI;F4@
M=VAE=&AE<B!T:&ES(&ES(&$@;&]C86P@9FEL92P@82!R96UO=&4@=7)I+"!O
M<B!A;@T*("`@("`J(&%B<W1R86-T('!A8VMA9V4@;F%M92X-"B`@("`@*@T*
M("`@("`J(%1H:7,@:7,@=&AE(&AE87)T(&]F('1H92!014%27T1O=VYL;V%D
M97)?4&%C:V%G92@I+"!A;F0@:7,@=7-E9"!I;@T*("`@("`J('M`;&EN:R!0
M14%27T1O=VYL;V%D97(Z.F1O=VYL;V%D*"E]#0H@("`@("H@0'!A<F%M('-T
M<FEN9PT*("`@("`J($!R971U<FX@8F]O;'Q014%27T5R<F]R#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@:6YI=&EA;&EZ92@D<&%R86TI#0H@("`@>PT*("`@
M("`@("`D;W)I9T5R<B`]("1T:&ES+3Y?9G)O;49I;&4H)'!A<F%M*3L-"B`@
M("`@("`@:68@*"$D=&AI<RT^7W9A;&ED*2![#0H@("`@("`@("`@("`D;W!T
M:6]N<R`]("1T:&ES+3Y?9&]W;FQO861E<BT^9V5T3W!T:6]N<R@I.PT*("`@
M("`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=O9F9L:6YE)UTI*2![#0H@
M("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&]R:6=%<G(I*2![
M#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;)W-O
M9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&]W
M;FQO861E<BT^;&]G*#`L("1O<FEG17)R+3YG971-97-S86=E*"DI.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=#86YN;W0@9&]W
M;FQO860@;F]N+6QO8V%L('!A8VMA9V4@(B<@+B`D<&%R86T@+B`G(B<I.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&5R<B`]("1T:&ES+3Y?9G)O
M;55R;"@D<&%R86TI.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)&5R<BD@?'P@(21T:&ES+3Y?=F%L:60I('L-"B`@("`@("`@("`@("`@("!I
M9B`H)'1H:7,M/E]T>7!E(#T]("=U<FPG*2![#0H@("`@("`@("`@("`@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1E<G(I*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A9&5R
M+3YL;V<H,"P@)&5R<BT^9V5T365S<V%G92@I*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B26YV86QI9"!O
M<B!M:7-S:6YG(')E;6]T92!P86-K86=E(&9I;&4B*3L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@)&5R<B`]("1T:&ES+3Y?9G)O;5-T
M<FEN9R@D<&%R86TI.PT*("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1E<G(I('Q\("$D=&AI<RT^7W9A;&ED*2![#0H@("`@("`@("`@("`@
M("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G(I("8F#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("1E<G(M/F=E=$-O9&4H*2`]/2!014%27T1/5TY,
M3T%$15)?4$%#2T%'15]35$%412D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.R`O+R!I;G-T<G5C="!T:&4@9&]W;FQO861E<B!T
M;R!S:6QE;G1L>2!S:VEP#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?='EP92D@)B8@)'1H
M:7,M/E]T>7!E(#T]("=L;V-A;"<@)B8-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@4$5!4CHZ:7-%<G)O<B@D;W)I9T5R<BDI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D;W)I9T5R<BT^9V5T57-E<DEN
M9F\H*2DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H
M("@D;W)I9T5R<BT^9V5T57-E<DEN9F\H*2!A<R`D97)R*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D97)R*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5R<B`]
M("1E<G);)VUE<W-A9V4G73L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1O=VYL;V%D97(M/FQO9R@P
M+"`D97)R*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7V1O=VYL;V%D97(M/FQO9R@P+"`D;W)I9T5R<BT^
M9V5T365S<V%G92@I*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D<&%R86TI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M(#T@)'1H:7,M
M/E]R96=I<W1R>2T^<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9R@D<&%R86TL
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1R=64I.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(D-A;FYO="!I;FET:6%L:7IE("<D<&%R86TG+"!I;G9A
M;&ED(&]R(&UI<W-I;F<@<&%C:V%G92!F:6QE(BD[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&5R<BDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7V1O=VYL;V%D97(M/FQO9R@P+"`D97)R+3YG971-
M97-S86=E*"DI.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A
M<G)A>2@D<&%R86TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D<&%R
M86T@/2`D=&AI<RT^7W)E9VES=')Y+3YP87)S961086-K86=E3F%M951O4W1R
M:6YG*"1P87)A;2P@=')U92D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H#0H@
M("`@("`@("`@("`@("`@("`@("`@("`B0V%N;F]T(&EN:71I86QI>F4@)R1P
M87)A;2<L(&EN=F%L:60@;W(@;6ES<VEN9R!P86-K86=E(&9I;&4B*3L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M4F5T<FEE=F4@86YY(&YO;BUL;V-A;"!P86-K86=E<PT*("`@("`J($!R971U
M<FX@4$5!4E]086-K86=E1FEL95]V,7Q014%27U!A8VMA9V5&:6QE7W8R?%!%
M05)?17)R;W(-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F9&]W;FQO860H*0T*
M("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G969I;&4I
M*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E9FEL93L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]D;W=N;&]A
M9%523%LG=7)L)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7VES=F%L:60@
M/2!F86QS93L-"B`@("`@("`@("`@("1I;F9O(#T@)'1H:7,M/F=E=%!A<G-E
M9%!A8VMA9V4H*3L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1I;F9O(&%S("1I
M(#T^("1P*2![#0H@("`@("`@("`@("`@("`@)&EN9F];)&E=(#T@<W1R=&]L
M;W=E<B@D<"D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D97)R(#T@
M)'1H:7,M/E]F<F]M57)L*"1T:&ES+3Y?9&]W;FQO86154DQ;)W5R;"==+`T*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA
M9V5.86UE5&]3=')I;F<H)'1H:7,M/E]P87)S961N86UE+"!T<G5E*2D[#0H@
M("`@("`@("`@("`D;F5W:6YF;R`]("1T:&ES+3YG971087)S961086-K86=E
M*"D[#0H@("`@("`@("`@("!F;W)E86-H("@D;F5W:6YF;R!A<R`D:2`]/B`D
M<"D@>PT*("`@("`@("`@("`@("`@("1N97=I;F9O6R1I72`]('-T<G1O;&]W
M97(H)'`I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1I;F9O
M("$]("1N97=I;F9O*2![#0H@("`@("`@("`@("`@("`@9&\@>PT*("`@("`@
M("`@("`@("`@("`@("!I9B`H)&EN9F];)W!A8VMA9V4G72`]/2`G<&5C;"YP
M:'`N;F5T)R`F)B`D;F5W:6YF;ULG<&%C:V%G92==(#T]("=P96%R+G!H<"YN
M970G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D:6YF;ULG<&%C:V%G
M92==(#T@)W!E87(N<&AP+FYE="<[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H)&EN9F\@/3T@)&YE=VEN9F\I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!S:VEP('1H92!C:&%N;F5L(&-H96-K(&EF(&$@<&5C
M;"!P86-K86=E('-A>7,@:70G<R!A(%!%05(@<&%C:V%G90T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=#4DE424-!3"!%4E)/
M4CH@5V4@87)E("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]R96=I<W1R>2T^<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9R@D:6YF;RD@
M+B`G+"!B=70@=&AE(&9I;&4@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`G9&]W;FQO861E9"!C;&%I;7,@=&\@8F4@)R`N#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W)E9VES=')Y+3YP87)S961086-K86=E3F%M
M951O4W1R:6YG*"1T:&ES+3YG971087)S961086-K86=E*"DI*3L-"B`@("`@
M("`@("`@("`@("!]('=H:6QE("AF86QS92D[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R*2!\?"`A)'1H:7,M
M/E]V86QI9"D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D97)R.PT*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?='EP92`]
M("=L;V-A;"<[#0H@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5F:6QE
M.PT*("`@('T-"@T*("`@(&9U;F-T:6]N("9G971086-K86=E1FEL92@I#0H@
M("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E9FEL93L-"B`@
M("!]#0H-"B`@("!F=6YC=&EO;B`F9V5T1&]W;FQO861E<B@I#0H@("`@>PT*
M("`@("`@("!R971U<FX@)'1H:7,M/E]D;W=N;&]A9&5R.PT*("`@('T-"@T*
M("`@(&9U;F-T:6]N(&=E=%1Y<&4H*2`-"B`@("![#0H@("`@("`@(')E='5R
M;B`D=&AI<RT^7W1Y<&4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@3&EK
M92![0&QI;FL@:6YI=&EA;&EZ92@I?2P@8G5T(&]P97)A=&5S(&]N(&$@9&5P
M96YD96YC>0T*("`@("`J+PT*("`@(&9U;F-T:6]N(&9R;VU$97!54DPH)&1E
M<"D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?9&]W;FQO86154DP@/2`D9&5P
M.PT*("`@("`@("!I9B`H:7-S970H)&1E<%LG=7)I)UTI*2![#0H@("`@("`@
M("`@("`D;W!T:6]N<R`]("1T:&ES+3Y?9&]W;FQO861E<BT^9V5T3W!T:6]N
M<R@I.PT*("`@("`@("`@("`@:68@*"%E>'1E;G-I;VY?;&]A9&5D*")Z;&EB
M(BD@?'P@:7-S970H)&]P=&EO;G-;)VYO8V]M<')E<W,G72DI('L-"B`@("`@
M("`@("`@("`@("`D97AT(#T@)RYT87(G.PT*("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`D97AT(#T@)RYT9WHG.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@4$5!4CHZ<'5S:$5R<F]R2&%N9&QI;F<H4$5!
M4E]%4E)/4E]215154DXI.PT*("`@("`@("`@("`@)&5R<B`]("1T:&ES+3Y?
M9G)O;55R;"@D9&5P6R=U<FDG72`N("1E>'0I.PT*("`@("`@("`@("`@4$5!
M4CHZ<&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)&5R<BDI('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?9&]W;FQO861E<BT^;&]G*#`L("1E<G(M/F=E=$UE<W-A9V4H*2D[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"=);G9A;&ED('5R:2!D97!E;F1E;F-Y("(G("X@
M)&1E<%LG=7)I)UT@+B`D97AT("X@)R(L("<@+@T*("`@("`@("`@("`@("`@
M("`@("`G8V%N;F]T(&1O=VYL;V%D)RD[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`D=&AI<RT^7W!A<G-E9&YA;64@
M/0T*("`@("`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@
M("`G<&%C:V%G92<@/3X@)&1E<%LG:6YF;R==+3YG971086-K86=E*"DL#0H@
M("`@("`@("`@("`@("`@("`@("=C:&%N;F5L)R`]/B`D9&5P6R=I;F9O)UTM
M/F=E=$-H86YN96PH*2P-"B`@("`@("`@("`@("`@("`@("`@)W9E<G-I;VXG
M(#T^("1D97!;)W9E<G-I;VXG70T*("`@("`@("`@("`@("`@("D[#0H@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1D97!;)VYO9&5F875L="==*2D@>PT*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%R<V5D;F%M95LG9W)O=7`G72`]("=D
M969A=6QT)SL@+R\@9&]W;FQO860@=&AE(&1E9F%U;'0@9&5P96YD96YC>2!G
M<F]U<`T*("`@("`@("`@("`@("`@("1T:&ES+3Y?97AP;&EC:71'<F]U<"`]
M(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'1H:7,M/E]R
M87=P86-K86=E9FEL92`]("1D97!;)W)A=R==.PT*("`@("`@("!]#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@9&5T96-T1&5P96YD96YC:65S*"1P87)A;7,I
M#0H@("`@>PT*("`@("`@("`D;W!T:6]N<R`]("1T:&ES+3Y?9&]W;FQO861E
M<BT^9V5T3W!T:6]N<R@I.PT*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;
M)V1O=VYL;V%D;VYL>2==*2D@>PT*("`@("`@("`@("`@<F5T=7)N.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG;V9F;&EN92==
M*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A9&5R+3YL;V<H,RP@
M)U-K:7!P:6YG(&1E<&5N9&5N8WD@9&]W;FQO860@8VAE8VLL("TM;V9F;&EN
M92!S<&5C:69I960G*3L-"B`@("`@("`@("`@(')E='5R;CL-"B`@("`@("`@
M?0T*("`@("`@("`D<&YA;64@/2`D=&AI<RT^9V5T4&%R<V5D4&%C:V%G92@I
M.PT*("`@("`@("!I9B`H(21P;F%M92D@>PT*("`@("`@("`@("`@<F5T=7)N
M.PT*("`@("`@("!]#0H@("`@("`@("1D97!S(#T@)'1H:7,M/F=E=$1E<',H
M*3L-"B`@("`@("`@:68@*"$D9&5P<RD@>PT*("`@("`@("`@("`@<F5T=7)N
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&5P<ULG<F5Q=6ER
M960G72DI('L@+R\@<&%C:V%G92YX;6P@,BXP#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]D971E8W0R*"1D97!S+"`D<&YA;64L("1O<'1I;VYS+"`D
M<&%R86US*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7V1E=&5C=#$H)&1E<',L("1P;F%M92P@)&]P=&EO;G,L("1P
M87)A;7,I.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T
M5F%L:61A=&5D*"D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?=F%L:61A=&5D
M(#T@=')U93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!A;')E861Y5F%L:61A
M=&5D*"D-"B`@("![#0H@("`@("`@(')E='5R;B`D=&AI<RT^7W9A;&ED871E
M9#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!296UO=F4@<&%C:V%G97,@
M=&\@8F4@9&]W;FQO861E9"!T:&%T(&%R92!A;')E861Y(&EN<W1A;&QE9`T*
M("`@("`J($!P87)A;2!A<G)A>2!O9B!014%27T1O=VYL;V%D97)?4&%C:V%G
M92!O8FIE8W1S#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T
M:6]N(')E;6]V94EN<W1A;&QE9"@F)'!A<F%M<RD-"B`@("![#0H@("`@("`@
M(&EF("@A:7-S970H)'!A<F%M<ULP72DI('L-"B`@("`@("`@("`@(')E='5R
M;CL-"B`@("`@("`@?0T*("`@("`@("`D;W!T:6]N<R`]("1P87)A;7-;,%TM
M/E]D;W=N;&]A9&5R+3YG971/<'1I;VYS*"D[#0H@("`@("`@(&EF("@A:7-S
M970H)&]P=&EO;G-;)V1O=VYL;V%D;VYL>2==*2D@>PT*("`@("`@("`@("`@
M9F]R96%C:"`H)'!A<F%M<R!A<R`D:2`]/B`D<&%R86TI('L-"B`@("`@("`@
M("`@("`@("`O+R!R96UO=F4@<V5L9B!I9B!A;')E861Y(&EN<W1A;&QE9"!W
M:71H('1H:7,@=F5R<VEO;@T*("`@("`@("`@("`@("`@("\O('1H:7,@9&]E
M<R!N;W0@;F5E9"!A;GD@<&5C;"!M86=I8R`M('=E(&]N;'D@<F5M;W9E(&5X
M86-T(&UA=&-H97,-"B`@("`@("`@("`@("`@("!I9B`H)'!A<F%M+3Y?:6YS
M=&%L;%)E9VES=')Y+3YP86-K86=E17AI<W1S*"1P87)A;2T^9V5T4&%C:V%G
M92@I+"`D<&%R86TM/F=E=$-H86YN96PH*2DI('L-"B`@("`@("`@("`@("`@
M("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92@D<&%R86TM/E]I;G-T86QL4F5G
M:7-T<GDM/G!A8VMA9V5);F9O*"1P87)A;2T^9V5T4&%C:V%G92@I+"`G=F5R
M<VEO;B<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("1P87)A;2T^9V5T
M0VAA;FYE;"@I*2P@)'!A<F%M+3YG971697)S:6]N*"DL("<]/2<I*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=F
M;W)C92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O
M(#T@)'!A<F%M+3YG971087)S961086-K86=E*"D[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@=6YS970H)&EN9F];)W9E<G-I;VXG72D[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)&EN9F];)W-T871E)UTI
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&]P
M=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'!A<F%M+3Y?9&]W;FQO861E<BT^;&]G*#$L("=3:VEP<&EN9R!P
M86-K86=E("(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1P87)A;2T^9V5T4VAO<G1.86UE*"D@+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)R(L(&%L<F5A9'D@:6YS=&%L;&5D(&%S
M('9E<G-I;VX@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<&%R86TM/E]I;G-T86QL4F5G:7-T<GDM/G!A8VMA9V5);F9O*"1P
M87)A;2T^9V5T4&%C:V%G92@I+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=V97)S:6]N)RP@)'!A<F%M+3YG971#:&%N;F5L
M*"DI*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<ULD:5T@/2!F86QS93L-"B`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E:68@*"%I<W-E="@D;W!T:6]N<ULG9F]R8V4G72D@)B8@(6ES<V5T
M*"1O<'1I;VYS6R=U<&=R861E)UTI("8F#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("%I<W-E="@D;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)&EN9F\@/2`D<&%R86TM/F=E=%!A<G-E9%!A8VMA
M9V4H*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("1P87)A;2T^7V1O=VYL
M;V%D97(M/FQO9R@Q+"`G4VMI<'!I;F<@<&%C:V%G92`B)R`N#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'!A<F%M+3YG9713:&]R=$YA;64H*2`N
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R(L(&%L<F5A9'D@:6YS
M=&%L;&5D(&%S('9E<G-I;VX@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'!A<F%M+3Y?:6YS=&%L;%)E9VES=')Y+3YP86-K86=E26YF;R@D
M<&%R86TM/F=E=%!A8VMA9V4H*2P@)W9E<G-I;VXG+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<&%R86TM/F=E=$-H86YN96PH*2DI.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<ULD:5T@/2!F86QS93L-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!014%27T1O=VYL;V%D
M97)?4&%C:V%G93HZ<F5M;W9E1'5P;&EC871E<R@D<&%R86US*3L-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!?9&5T96-T,B@D9&5P<RP@)'!N86UE+"`D;W!T
M:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@("1T:&ES+3Y?9&]W;FQO
M861$97!S(#T@87)R87DH*3L-"B`@("`@("`@)&=R;W5P;F]T9F]U;F0@/2!F
M86QS93L-"B`@("`@("`@9F]R96%C:"`H87)R87DH)W!A8VMA9V4G+"`G<W5B
M<&%C:V%G92<I(&%S("1P86-K86=E='EP92D@>PT*("`@("`@("`@("`@+R\@
M9V5T(')E<75I<F5D(&1E<&5N9&5N8WD@9W)O=7`-"B`@("`@("`@("`@(&EF
M("AI<W-E="@D9&5P<ULG<F5Q=6ER960G75LD<&%C:V%G971Y<&5=*2D@>PT*
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P<ULG<F5Q=6ER960G75LD
M<&%C:V%G971Y<&5=6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("!F;W)E
M86-H("@D9&5P<ULG<F5Q=6ER960G75LD<&%C:V%G971Y<&5=(&%S("1D97`I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=C
M;VYF;&EC=',G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!S:VEP(&%N>2!P86-K86=E('1H870@=&AI<R!P86-K86=E(&-O;F9L:6-T
M<R!W:71H#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[
M#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D<F5T(#T@)'1H:7,M/E]D971E8W0R1&5P*"1D97`L("1P;F%M
M92P@)W)E<75I<F5D)RP@)'!A<F%M<RD[#0H@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-?87)R87DH)')E="DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7V1O=VYL;V%D1&5P<UM=(#T@)')E=#L-"B`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M("`@("1D97`@/2`D9&5P<ULG<F5Q=6ER960G75LD<&%C:V%G971Y<&5=.PT*
M("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1D97!;)V-O;F9L:6-T
M<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@+R\@<VMI<"!A;GD@
M<&%C:V%G92!T:&%T('1H:7,@<&%C:V%G92!C;VYF;&EC=',@=VET:`T*("`@
M("`@("`@("`@("`@("`@("`@("`@)')E="`]("1T:&ES+3Y?9&5T96-T,D1E
M<"@D9&5P+"`D<&YA;64L("=R97%U:7)E9"<L("1P87)A;7,I.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1R970I*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A9$1E<'-;
M72`]("1R970[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`O+R!G970@;W!T:6]N86P@9&5P96YD96YC>2!G
M<F]U<"P@:68@86YY#0H@("`@("`@("`@("!I9B`H:7-S970H)&1E<'-;)V]P
M=&EO;F%L)UU;)'!A8VMA9V5T>7!E72DI('L-"B`@("`@("`@("`@("`@("`D
M<VMI<&YA;65S(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1D97!S6R=O<'1I;VYA;"==6R1P86-K86=E='EP95U;,%TI*2![#0H@
M("`@("`@("`@("`@("`@("`@("1D97!S6R=O<'1I;VYA;"==6R1P86-K86=E
M='EP95T@/2!A<G)A>2@D9&5P<ULG;W!T:6]N86PG75LD<&%C:V%G971Y<&5=
M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)&1E<'-;)V]P=&EO;F%L)UU;)'!A8VMA9V5T>7!E72!A<R`D9&5P*2![
M#0H@("`@("`@("`@("`@("`@("`@("1S:VEP(#T@9F%L<V4[#0H@("`@("`@
M("`@("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;)V%L;&1E<',G72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1D97!;)W!A8VMA9V4G72`]
M("1D97!;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A
M:7-S970H)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7V1O=VYL;V%D97(M/FQO9R@S+"`G3F]T:6-E
M.B!P86-K86=E("(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H
M)'1H:7,M/F=E=%!A<G-E9%!A8VMA9V4H*2P-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('1R=64I("X@)R(@;W!T:6]N86P@9&5P96YD
M96YC>2`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H87)R
M87DH)W!A8VMA9V4G(#T^#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9&5P6R=N86UE)UTL("=C:&%N;F5L)R`]/B`G<&5A<BYP:'`N
M;F5T)RDL('1R=64I("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)R(@=VEL;"!N;W0@8F4@875T;VUA=&EC86QL>2!D;W=N;&]A9&5D)RD[
M#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D<VMI<&YA;65S6UT@/2`D=&AI<RT^7W)E9VES=')Y+3YP87)S
M961086-K86=E3F%M951O4W1R:6YG*"1D97`L('1R=64I.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)'-K:7`@/2!T<G5E.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@=6YS970H)&1E<%LG<&%C:V%G92==*3L-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H(2@D<F5T(#T@
M)'1H:7,M/E]D971E8W0R1&5P*"1D97`L("1P;F%M92P@)V]P=&EO;F%L)RP@
M)'!A<F%M<RDI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D9&5P6R=P
M86-K86=E)UT@/2`D9&5P6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H0"1S:VEP;F%M97-;8V]U;G0H)'-K:7!N86UE<RD@+2`Q72`]
M/0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R96=I
M<W1R>2T^<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9R@D9&5P+"!T<G5E*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W!O<"@D<VMI
M<&YA;65S*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H(21S:VEP
M("8F(&ES7V%R<F%Y*"1R970I*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V1O=VYL;V%D1&5P<UM=(#T@)')E=#L-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!I9B`H8V]U;G0H)'-K:7!N86UE<RDI('L-"B`@("`@("`@("`@("`@("`@
M("`@:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A9&5R+3YL;V<H,2P@)T1I
M9"!N;W0@9&]W;FQO860@;W!T:6]N86P@9&5P96YD96YC:65S.B`G("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I;7!L;V1E*"<L("<L("1S:VEP
M;F%M97,I("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G+"!U<V4@
M+2UA;&QD97!S('1O(&1O=VYL;V%D(&%U=&]M871I8V%L;'DG*3L-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("\O(&=E="!R97%U97-T960@9&5P96YD96YC
M>2!G<F]U<"P@:68@86YY#0H@("`@("`@("`@("`D9W)O=7!N86UE(#T@)'1H
M:7,M/F=E=$=R;W5P*"D[#0H@("`@("`@("`@("`D97AP;&EC:70@/2`D=&AI
M<RT^7V5X<&QI8VET1W)O=7`[#0H@("`@("`@("`@("!I9B`H(21G<F]U<&YA
M;64I('L-"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/F-A;D1E9F%U;'0H
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`D9W)O=7!N86UE(#T@)V1E9F%U
M;'0G.R`O+R!T<GD@=&AE(&1E9F%U;'0@9&5P96YD96YC>2!G<F]U<`T*("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&EF("@D9W)O=7!N;W1F;W5N9"D@>PT*("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@
M*&ES<V5T*"1D97!S6R=G<F]U<"==*2D@>PT*("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D9&5P<ULG9W)O=7`G75LG871T<FEB<R==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("!I9B`H<W1R=&]L;W=E<B@D9&5P<ULG9W)O=7`G75LG
M871T<FEB<R==6R=N86UE)UTI(#T]('-T<G1O;&]W97(H)&=R;W5P;F%M92DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1G<F]U<"`]("1D97!S6R=G
M<F]U<"==.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&5X<&QI
M8VET*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O
M<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]D;W=N;&]A9&5R+3YL;V<H,"P@)U=A<FYI;F<Z('!A8VMA
M9V4@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W)E9VES=')Y+3YP87)S961086-K86=E3F%M951O4W1R:6YG*"1P;F%M
M92P@=')U92D@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M(B!H87,@;F\@9&5P96YD96YC>2`G("X@)V=R;W5P(&YA;65D("(G("X@)&=R
M;W5P;F%M92`N("<B)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D9W)O=7!N;W1F;W5N9"`]('1R=64[
M#0H@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@("`@("1F;W5N9"`](&9A;'-E.PT*("`@("`@("`@("`@
M("`@("`@("!F;W)E86-H("@D9&5P<ULG9W)O=7`G72!A<R`D9W)O=7`I('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AS=')T;VQO=V5R*"1G<F]U
M<%LG871T<FEB<R==6R=N86UE)UTI(#T]('-T<G1O;&]W97(H)&=R;W5P;F%M
M92DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]U;F0@/2!T
M<G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@(&EF("@A)&9O=6YD*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H)&5X<&QI8VET*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V1O=VYL;V%D97(M/FQO9R@P+"`G5V%R;FEN9SH@<&%C:V%G92`B)R`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)E
M9VES=')Y+3YP87)S961086-K86=E3F%M951O4W1R:6YG*"1P;F%M92P@=')U
M92D@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R(@
M:&%S(&YO(&1E<&5N9&5N8WD@)R`N("=G<F]U<"!N86UE9"`B)R`N("1G<F]U
M<&YA;64@+B`G(B<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1G<F]U<&YO=&9O=6YD(#T@=')U93L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M:68@*&ES<V5T*"1G<F]U<"DI('L-"B`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&=R;W5P6R1P86-K86=E='EP95TI*2![#0H@("`@("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D9W)O=7!;)'!A8VMA9V5T>7!E75LP72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1G<F]U<%LD<&%C:V%G
M971Y<&5=(&%S("1D97`I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<F5T(#T@)'1H:7,M/E]D971E8W0R1&5P*"1D97`L("1P;F%M92P@)V1E
M<&5N9&5N8WD@9W)O=7`@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9W)O=7!;)V%T=')I8G,G75LG;F%M92==("X@)R(G+"`D<&%R
M86US*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-?87)R
M87DH)')E="DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]D;W=N;&]A9$1E<'-;72`]("1R970[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)')E="`]("1T:&ES+3Y?9&5T96-T,D1E<"@D9W)O=7!;)'!A
M8VMA9V5T>7!E72P@)'!N86UE+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=D97!E;F1E;F-Y(&=R;W5P("(G("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D9W)O=7!;)V%T=')I8G,G75LG;F%M92==("X@)R(G+"`D
M<&%R86US*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A
M>2@D<F5T*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?9&]W;FQO861$97!S6UT@/2`D<F5T.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*#0H@("`@
M9G5N8W1I;VX@7V1E=&5C=#)$97`H)&1E<"P@)'!N86UE+"`D9W)O=7`L("1P
M87)A;7,I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)&1E<%LG8V]N9FQI
M8W1S)UTI*2![#0H@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@
M?0T*("`@("`@("`D;W!T:6]N<R`]("1T:&ES+3Y?9&]W;FQO861E<BT^9V5T
M3W!T:6]N<R@I.PT*("`@("`@("!I9B`H:7-S970H)&1E<%LG=7)I)UTI*2![
M#0H@("`@("`@("`@("!R971U<FX@87)R87DH)W5R:2<@/3X@)&1E<%LG=7)I
M)UTL("=D97`G(#T^("1D97`I.SL-"B`@("`@("`@?0T*("`@("`@("`D=&5S
M=&1E<"`]("1D97`[#0H@("`@("`@("1T97-T9&5P6R=P86-K86=E)UT@/2`D
M9&5P6R=N86UE)UT[#0H@("`@("`@(&EF("A014%27T1O=VYL;V%D97)?4&%C
M:V%G93HZ=VEL;$1O=VYL;V%D*"1T97-T9&5P+"`D<&%R86US*2D@>PT*("`@
M("`@("`@("`@)&1E<%LG<&%C:V%G92==(#T@)&1E<%LG;F%M92==.PT*("`@
M("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==*2D@>PT*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?9&]W;FQO861E<BT^;&]G*#(L("1T:&ES
M+3YG9713:&]R=$YA;64H*2`N("<Z(%-K:7!P:6YG("<@+B`D9W)O=7`@+@T*
M("`@("`@("`@("`@("`@("`@("`G(&1E<&5N9&5N8WD@(B<@+@T*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W)E9VES=')Y+3YP87)S961086-K86=E
M3F%M951O4W1R:6YG*"1D97`L('1R=64I("X-"B`@("`@("`@("`@("`@("`@
M("`@)R(L('=I;&P@8F4@:6YS=&%L;&5D)RD[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@
M)&]P=&EO;G,@/2`D=&AI<RT^7V1O=VYL;V%D97(M/F=E=$]P=&EO;G,H*3L-
M"B`@("`@("`@4$5!4CHZ<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]2
M15154DXI.PT*("`@("`@("!I9B`H)'1H:7,M/E]E>'!L:6-I=%-T871E*2![
M#0H@("`@("`@("`@("`D<&YA;65;)W-T871E)UT@/2`D=&AI<RT^7V5X<&QI
M8VET4W1A=&4[#0H@("`@("`@('T-"B`@("`@("`@)'5R;"`]#0H@("`@("`@
M("`@("`D=&AI<RT^7V1O=VYL;V%D97(M/E]G971$97!086-K86=E1&]W;FQO
M8615<FPH)&1E<"P@)'!N86UE*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)'5R;"DI('L-"B`@("`@("`@("`@(%!%05(Z.G!O<$5R<F]R2&%N9&QI
M;F<H*3L-"B`@("`@("`@("`@(')E='5R;B`D=7)L.PT*("`@("`@("!]#0H@
M("`@("`@("1D97!;)W!A8VMA9V4G72`]("1D97!;)VYA;64G73L-"B`@("`@
M("`@)')E="`]("1T:&ES+3Y?86YA;'EZ941O=VYL;V%D55),*"1U<FPL("=D
M97!E;F1E;F-Y)RP@)&1E<"P@)'!A<F%M<RP@)&=R;W5P(#T]("=O<'1I;VYA
M;"<@)B8-"B`@("`@("`@("`@("%I<W-E="@D;W!T:6]N<ULG86QL9&5P<R==
M*2D[#0H@("`@("`@(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)')E="DI('L-"B`@("`@("`@("`@(&EF
M("@A:7-S970H)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^7V1O=VYL;V%D97(M/FQO9R@P+"`D<F5T+3YG971-97-S86=E
M*"DI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@+R\@8VAE8VL@=&\@
M<V5E(&EF(&$@9&5P(&ES(&%L<F5A9'D@:6YS=&%L;&5D(&%N9"!I<R!T:&4@
M<V%M92!O<B!N97=E<@T*("`@("`@("`@("`@:68@*"%I<W-E="@D9&5P6R=M
M:6XG72D@)B8@(6ES<V5T*"1D97!;)VUA>"==*2`F)B`A:7-S970H)&1E<%LG
M<F5C;VUM96YD960G72DI('L-"B`@("`@("`@("`@("`@("`D;W!E<B`]("=H
M87,G.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D
M;W!E<B`]("=G="<[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`O+R!D
M;R!N;W0@=')Y('1O(&UO=F4@=&AI<R!B969O<F4@9V5T1&5P4&%C:V%G941O
M=VYL;V%D55),#0H@("`@("`@("`@("`O+R!W92!C86XG="!D971E<FUI;F4@
M=VAE=&AE<B!U<&=R861E(&ES(&YE8V5S<V%R>2!U;G1I;"!W92!K;F]W('=H
M870-"B`@("`@("`@("`@("\O('9E<G-I;VX@=V]U;&0@8F4@9&]W;FQO861E
M9`T*("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG9F]R8V4G72D@
M)B8@)'1H:7,M/FES26YS=&%L;&5D*"1R970L("1O<&5R*2D@>PT*("`@("`@
M("`@("`@("`@("1V97)S:6]N(#T@)'1H:7,M/E]I;G-T86QL4F5G:7-T<GDM
M/G!A8VMA9V5);F9O*"1D97!;)VYA;64G72P@)W9E<G-I;VXG+`T*("`@("`@
M("`@("`@("`@("`@("`D9&5P6R=C:&%N;F5L)UTI.PT*("`@("`@("`@("`@
M("`@("1D97!;)W!A8VMA9V4G72`]("1D97!;)VYA;64G73L-"B`@("`@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?9&]W;FQO861E<BT^;&]G*#,L("1T
M:&ES+3YG9713:&]R=$YA;64H*2`N("<Z(%-K:7!P:6YG("<@+B`D9W)O=7`@
M+@T*("`@("`@("`@("`@("`@("`@("`@("`@)R!D97!E;F1E;F-Y("(G("X-
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1R>2T^<&%R<V5D
M4&%C:V%G94YA;654;U-T<FEN9R@D9&5P+"!T<G5E*2`N#0H@("`@("`@("`@
M("`@("`@("`@("`@("`G(B!V97)S:6]N("<@+B`D=7)L6R=V97)S:6]N)UT@
M+B`G+"!A;')E861Y(&EN<W1A;&QE9"!A<R!V97)S:6]N("<@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@)'9E<G-I;VXI.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!;)VYO9&5F
M875L="==*2D@>PT*("`@("`@("`@("`@)')E=%LG;F]D969A=6QT)UT@/2!T
M<G5E.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-
M"@T*("`@(&9U;F-T:6]N(%]D971E8W0Q*"1D97!S+"`D<&YA;64L("1O<'1I
M;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]D;W=N;&]A
M9$1E<',@/2!A<G)A>2@I.PT*("`@("`@("`D<VMI<&YA;65S(#T@87)R87DH
M*3L-"B`@("`@("`@9F]R96%C:"`H)&1E<',@87,@)&1E<"D@>PT*("`@("`@
M("`@("`@)&YO9&]W;FQO860@/2!F86QS93L-"B`@("`@("`@("`@(&EF("@D
M9&5P6R=T>7!E)UT@/3T@)W!K9R<I('L-"B`@("`@("`@("`@("`@("`D9&5P
M6R=C:&%N;F5L)UT@/2`G<&5A<BYP:'`N;F5T)SL-"B`@("`@("`@("`@("`@
M("`D9&5P6R=P86-K86=E)UT@/2`D9&5P6R=N86UE)UT[#0H@("`@("`@("`@
M("`@("`@<W=I=&-H("@D9&5P6R=R96PG72D@>PT*("`@("`@("`@("`@("`@
M("`@("!C87-E("=N;W0G(#H-"B`@("`@("`@("`@("`@("`@("`@("`@(&-O
M;G1I;G5E(#([#0H@("`@("`@("`@("`@("`@("`@(&-A<V4@)V=E)R`Z#0H@
M("`@("`@("`@("`@("`@("`@(&-A<V4@)V5Q)R`Z#0H@("`@("`@("`@("`@
M("`@("`@(&-A<V4@)V=T)R`Z#0H@("`@("`@("`@("`@("`@("`@(&-A<V4@
M)VAA<R<@.@T*("`@("`@("`@("`@("`@("`@("`@("`@)&=R;W5P(#T@*"%I
M<W-E="@D9&5P6R=O<'1I;VYA;"==*2!\?"`D9&5P6R=O<'1I;VYA;"==(#T]
M("=N;R<I(#\-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5Q=6ER
M960G(#H-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;W!T:6]N86PG
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*%!%05)?1&]W;FQO861E
M<E]086-K86=E.CIW:6QL1&]W;FQO860H)&1E<"P@)'!A<F%M<RDI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1O=VYL;V%D97(M
M/FQO9R@R+"`D=&AI<RT^9V5T4VAO<G1.86UE*"D@+B`G.B!3:VEP<&EN9R`G
M("X@)&=R;W5P#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@
M)R!D97!E;F1E;F-Y("(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]R96=I<W1R>2T^<&%R<V5D4&%C:V%G94YA;654;U-T
M<FEN9R@D9&5P+"!T<G5E*2`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("<B+"!W:6QL(&)E(&EN<W1A;&QE9"<I.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&-O;G1I;G5E(#([#0H@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`D9F%K961P(#T@
M;F5W(%!%05)?4&%C:V%G949I;&5?=C$[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D9F%K961P+3YS971086-K86=E*"1D97!;)VYA;64G72D[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`O+R!S:VEP(&EN=&5R;F5T(&-H96-K(&EF
M('=E(&%R92!N;W0@=7!G<F%D:6YG("AB=6<@(S4X,3`I#0H@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=U<&=R861E)UTI
M("8F("1T:&ES+3YI<TEN<W1A;&QE9"@-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1F86ME9'`L("1D97!;)W)E;"==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&]W;FQO861E<BT^;&]G*#(L
M("1T:&ES+3YG9713:&]R=$YA;64H*2`N("<Z(%-K:7!P:6YG("<@+B`D9W)O
M=7`-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G(&1E<&5N
M9&5N8WD@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W)E9VES=')Y+3YP87)S961086-K86=E3F%M951O4W1R:6YG*"1D
M97`L('1R=64I("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)R(L(&ES(&%L<F5A9'D@:6YS=&%L;&5D)RD[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8V]N=&EN=64@,CL-"B`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@4$5!
M4CHZ<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@
M("`@("`@("`@("`@(&EF("@D=&AI<RT^7V5X<&QI8VET4W1A=&4I('L-"B`@
M("`@("`@("`@("`@("`@("`@)'!N86UE6R=S=&%T92==(#T@)'1H:7,M/E]E
M>'!L:6-I=%-T871E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`D=7)L(#T-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N
M;&]A9&5R+3Y?9V5T1&5P4&%C:V%G941O=VYL;V%D57)L*"1D97`L("1P;F%M
M92D[#0H@("`@("`@("`@("`@("`@)&-H86X@/2`G<&5A<BYP:'`N;F5T)SL-
M"B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D=7)L*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`O+R!C:&5C:R!T;R!S964@:68@=&AI<R!I
M<R!A('!E8VP@<&%C:V%G92!T:&%T(&AA<R!J=6UP960-"B`@("`@("`@("`@
M("`@("`@("`@+R\@9G)O;2!P96%R+G!H<"YN970@=&\@<&5C;"YP:'`N;F5T
M(&-H86YN96P-"B`@("`@("`@("`@("`@("`@("`@:68@*"%C;&%S<U]E>&ES
M=',H)U!%05)?1&5P96YD96YC>3(G*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@<F5Q=6ER95]O;F-E("=014%2+T1E<&5N9&5N8WDR+G!H<"<[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)&YE
M=V1E<"`](%!%05)?1&5P96YD96YC>3(Z.FYO<FUA;&EZ941E<"@D9&5P*3L-
M"B`@("`@("`@("`@("`@("`@("`@)&YE=V1E<"`]("1N97=D97!;,%T[#0H@
M("`@("`@("`@("`@("`@("`@("1N97=D97!;)V-H86YN96PG72`]("=P96-L
M+G!H<"YN970G.PT*("`@("`@("`@("`@("`@("`@("`D8VAA;B`]("=P96-L
M+G!H<"YN970G.PT*("`@("`@("`@("`@("`@("`@("`D=7)L(#T-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&]W;FQO861E<BT^7V=E=$1E
M<%!A8VMA9V5$;W=N;&]A9%5R;"@D;F5W9&5P+"`D<&YA;64I.PT*("`@("`@
M("`@("`@("`@("`@("`D;V)J(#T@)B1T:&ES+3Y?:6YS=&%L;%)E9VES=')Y
M+3YG971086-K86=E*"1D97!;)VYA;64G72D[#0H@("`@("`@("`@("`@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1U<FPI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("!014%2.CIP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H)&]B:B`A/3T@;G5L;"`F)B`D=&AI<RT^
M:7-);G-T86QL960H)&]B:BP@)&1E<%LG<F5L)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&=R;W5P(#T@*"%I<W-E="@D9&5P6R=O<'1I
M;VYA;"==*2!\?"`D9&5P6R=O<'1I;VYA;"==(#T]("=N;R<I(#\-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E<75I<F5D)R`Z#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=O<'1I;VYA;"<[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&1E<%LG<&%C:V%G92==(#T@)&1E
M<%LG;F%M92==.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A
M:7-S970H)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A9&5R+3YL;V<H,RP@)'1H
M:7,M/F=E=%-H;W)T3F%M92@I("X-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("<Z(%-K:7!P:6YG("<@+B`D9W)O=7`@+B`G(&1E<&5N
M9&5N8WD@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]R96=I<W1R>2T^<&%R<V5D4&%C:V%G94YA;654;U-T<FEN
M9R@D9&5P+"!T<G5E*2`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G(BP@86QR96%D>2!I;G-T86QL960@87,@=F5R<VEO;B`G("X@
M)&]B:BT^9V5T5F5R<VEO;B@I*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*$`D<VMI
M<&YA;65S6V-O=6YT*"1S:VEP;F%M97,I("T@,5T@/3T-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)E9VES=')Y+3YP87)S
M961086-K86=E3F%M951O4W1R:6YG*"1D97`L('1R=64I*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W!O<"@D<VMI<&YA;65S
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D9&5P6R=O<'1I;VYA;"==*2`F)B`D9&5P6R=O<'1I;VYA
M;"==(#T]("=Y97,G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9&]W;FQO861E<BT^;&]G*#(L("1T:&ES+3YG9713:&]R
M=$YA;64H*2`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G.B!3:VEP<&EN9R`G("X@)&=R;W5P#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`N("<@9&5P96YD96YC>2`B)R`N#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)E9VES=')Y
M+3YP87)S961086-K86=E3F%M951O4W1R:6YG*"1D97`L('1R=64I("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<B+"!N;R!R96QE
M87-E<R!E>&ES="<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)'5R;#L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@4$5!4CHZ<&]P17)R
M;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&]P
M=&EO;G-;)V%L;&1E<',G72DI('L-"B`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1D97!;)V]P=&EO;F%L)UTI("8F("1D97!;)V]P=&EO;F%L)UT@
M/3T@)WEE<R<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7V1O=VYL;V%D97(M/FQO9R@S+"`G3F]T:6-E.B!P
M86-K86=E("(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/F=E=%-H;W)T3F%M92@I("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)R(@;W!T:6]N86P@9&5P96YD96YC>2`B)R`N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5G:7-T<GDM
M/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@G8VAA;FYE;"<@/3X@)&-H86XL
M("=P86-K86=E)R`]/@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&1E<%LG;F%M92==*2P@=')U92D@+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G(B!W:6QL(&YO="!B92!A=71O;6%T:6-A;&QY
M(&1O=VYL;V%D960G*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1S:VEP;F%M97-;72`]("1T:&ES+3Y?
M<F5G:7-T<GDM/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=C:&%N;F5L)R`]/B`D
M8VAA;BP@)W!A8VMA9V4G(#T^#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1D97!;)VYA;64G72DL('1R=64I.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)&YO9&]W;FQO860@/2!T<G5E.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)&]P=&EO;G-;)V%L;&1E<',G72D@)B8@(6ES<V5T*"1O<'1I
M;VYS6R=O;FQY<F5Q9&5P<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1D97!;)V]P=&EO;F%L)UTI('Q\("1D97!;)V]P=&EO;F%L
M)UT@/3T@)VYO)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I
M<W-E="@D;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?9&]W;FQO861E<BT^;&]G*#,L("=.;W1I8V4Z
M('!A8VMA9V4@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^9V5T4VAO<G1.86UE*"D@+@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G(B!R97%U:7)E9"!D97!E;F1E;F-Y("(G("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1R
M>2T^<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9R@-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=C:&%N;F5L)R`]/B`D8VAA
M;BP@)W!A8VMA9V4G(#T^#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9&5P6R=N86UE)UTI+"!T<G5E*2`N#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("<B('=I;&P@;F]T(&)E(&%U=&]M871I8V%L
M;'D@9&]W;FQO861E9"<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@)'-K:7!N86UE<UM=(#T@)'1H:7,M
M/E]R96=I<W1R>2T^<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9R@-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V-H86YN96PG(#T^
M("1C:&%N+"`G<&%C:V%G92<@/3X-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&1E<%LG;F%M92==*2P@=')U92D[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D;F]D;W=N;&]A9"`]('1R=64[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M+R\@8VAE8VL@=&\@<V5E(&EF(&$@9&5P(&ES(&%L<F5A9'D@:6YS=&%L;&5D
M#0H@("`@("`@("`@("`@("`@+R\@9&\@;F]T('1R>2!T;R!M;W9E('1H:7,@
M8F5F;W)E(&=E=$1E<%!A8VMA9V5$;W=N;&]A9%523`T*("`@("`@("`@("`@
M("`@("\O('=E(&-A;B=T(&1E=&5R;6EN92!W:&5T:&5R('5P9W)A9&4@:7,@
M;F5C97-S87)Y('5N=&EL('=E(&MN;W<@=VAA=`T*("`@("`@("`@("`@("`@
M("\O('9E<G-I;VX@=V]U;&0@8F4@9&]W;FQO861E9`T*("`@("`@("`@("`@
M("`@(&EF("@A:7-S970H)&]P=&EO;G-;)V9O<F-E)UTI("8F("1T:&ES+3YI
M<TEN<W1A;&QE9"@-"B`@("`@("`@("`@("`@("`@("`@("`@("1U<FPL("1D
M97!;)W)E;"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D9W)O=7`@/2`H
M(6ES<V5T*"1D97!;)V]P=&EO;F%L)UTI('Q\("1D97!;)V]P=&EO;F%L)UT@
M/3T@)VYO)RD@/PT*("`@("`@("`@("`@("`@("`@("`@("`@)W)E<75I<F5D
M)R`Z#0H@("`@("`@("`@("`@("`@("`@("`@("`G;W!T:6]N86PG.PT*("`@
M("`@("`@("`@("`@("`@("`D9&5P6R=P86-K86=E)UT@/2`D9&5P6R=N86UE
M)UT[#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D;F5W9&5P*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'9E<G-I;VX@/2`D=&AI<RT^
M7VEN<W1A;&Q296=I<W1R>2T^<&%C:V%G94EN9F\H)&YE=V1E<%LG;F%M92==
M+"`G=F5R<VEO;B<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YE
M=V1E<%LG8VAA;FYE;"==*3L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1V97)S:6]N(#T@)'1H:7,M
M/E]I;G-T86QL4F5G:7-T<GDM/G!A8VMA9V5);F9O*"1D97!;)VYA;64G72P@
M)W9E<G-I;VXG*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`D9&5P6R=V97)S:6]N)UT@/2`D=7)L6R=V97)S:6]N)UT[
M#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;)W-O
M9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&]W
M;FQO861E<BT^;&]G*#,L("1T:&ES+3YG9713:&]R=$YA;64H*2`N("<Z(%-K
M:7!P:6YG("<@+B`D9W)O=7`@+@T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("<@9&5P96YD96YC>2`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]R96=I<W1R>2T^<&%R<V5D4&%C:V%G94YA;654;U-T
M<FEN9R@D9&5P+"!T<G5E*2`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)R(L(&%L<F5A9'D@:6YS=&%L;&5D(&%S('9E<G-I;VX@)R`N("1V97)S
M:6]N*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("!I9B`H0"1S:VEP;F%M97-;8V]U;G0H)'-K:7!N86UE<RD@+2`Q72`]
M/0T*("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)E9VES=')Y
M+3YP87)S961086-K86=E3F%M951O4W1R:6YG*"1D97`L('1R=64I*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>5]P;W`H)'-K:7!N86UE<RD[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(&EF("@D;F]D;W=N;&]A9"D@>PT*("`@("`@("`@("`@("`@("`@("!C;VYT
M:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@4$5!
M4CHZ<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D;F5W9&5P*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`D9&5P(#T@)&YE=V1E<#L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@)&1E<%LG<&%C:V%G92==(#T@)&1E<%LG;F%M
M92==.PT*("`@("`@("`@("`@("`@("1R970@/2`D=&AI<RT^7V%N86QY>F5$
M;W=N;&]A9%523"@D=7)L+"`G9&5P96YD96YC>2<L("1D97`L("1P87)A;7,L
M#0H@("`@("`@("`@("`@("`@("`@(&ES<V5T*"1D97!;)V]P=&EO;F%L)UTI
M("8F("1D97!;)V]P=&EO;F%L)UT@/3T@)WEE<R<@)B8-"B`@("`@("`@("`@
M("`@("`@("`@(6ES<V5T*"1O<'1I;VYS6R=A;&QD97!S)UTI*3L-"B`@("`@
M("`@("`@("`@("!014%2.CIP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@
M("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E="DI('L-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A9&5R+3YL
M;V<H,"P@)')E="T^9V5T365S<V%G92@I*3L-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A9$1E
M<'-;72`]("1R970[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@:68@*&-O=6YT*"1S:VEP;F%M97,I*2![#0H@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@
M)'1H:7,M/E]D;W=N;&]A9&5R+3YL;V<H,2P@)T1I9"!N;W0@9&]W;FQO860@
M9&5P96YD96YC:65S.B`G("X-"B`@("`@("`@("`@("`@("`@("`@:6UP;&]D
M92@G+"`G+"`D<VMI<&YA;65S*2`N#0H@("`@("`@("`@("`@("`@("`@("<L
M('5S92`M+6%L;&1E<',@;W(@+2UO;FQY<F5Q9&5P<R!T;R!D;W=N;&]A9"!A
M=71O;6%T:6-A;&QY)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("!]#0H-"B`@("!F=6YC=&EO;B!S971$;W=N;&]A9%523"@D<&MG*0T*("`@
M('L-"B`@("`@("`@)'1H:7,M/E]D;W=N;&]A9%523"`]("1P:V<[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@4V5T('1H92!P86-K86=E+GAM;"!O8FIE
M8W0@9F]R('1H:7,@9&]W;FQO861E9"!P86-K86=E#0H@("`@("H-"B`@("`@
M*B!`<&%R86T@4$5!4E]086-K86=E1FEL95]V,7Q014%27U!A8VMA9V5&:6QE
M7W8R("1P:V<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S971086-K86=E1FEL
M92@F)'!K9RD-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G969I;&4@
M/2`F)'!K9SL-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G9713:&]R=$YA;64H
M*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F5G:7-T<GDM/G!A
M<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H87)R87DH)V-H86YN96PG(#T^("1T
M:&ES+3YG971#:&%N;F5L*"DL#0H@("`@("`@("`@("`G<&%C:V%G92<@/3X@
M)'1H:7,M/F=E=%!A8VMA9V4H*2DL('1R=64I.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N(&=E=%!A<G-E9%!A8VMA9V4H*0T*("`@('L@("`-"B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G969I;&4I('Q\(&ES<V5T*"1T:&ES
M+3Y?<&%R<V5D;F%M92DI('L-"B`@("`@("`@("`@(')E='5R;B!A<G)A>2@G
M8VAA;FYE;"<@/3X@)'1H:7,M/F=E=$-H86YN96PH*2P-"B`@("`@("`@("`@
M("`@("`G<&%C:V%G92<@/3X@)'1H:7,M/F=E=%!A8VMA9V4H*2P-"B`@("`@
M("`@("`@("`@("`G=F5R<VEO;B<@/3X@)'1H:7,M/F=E=%9E<G-I;VXH*2D[
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*
M("`@(&9U;F-T:6]N(&=E=$1O=VYL;V%D55),*"D-"B`@("![#0H@("`@("`@
M(')E='5R;B`D=&AI<RT^7V1O=VYL;V%D55),.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N(&-A;D1E9F%U;'0H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?9&]W;FQO86154DPI*2![#0H@("`@("`@("`@("!I9B`H:7-S
M970H)'1H:7,M/E]D;W=N;&]A9%523%LG;F]D969A=6QT)UTI*2![#0H@("`@
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N(&=E=%!A8VMA9V4H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?<&%C:V%G969I;&4I*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/E]P86-K86=E9FEL92T^9V5T4&%C:V%G92@I.PT*("`@("`@("!]
M(&5L<V5I9B`H:7-S970H)'1H:7,M/E]D;W=N;&]A9%523%LG:6YF;R==*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&]W;FQO86154DQ;)VEN
M9F\G72T^9V5T4&%C:V%G92@I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C%\4$5!4E]0
M86-K86=E1FEL95]V,@T*("`@("`J+PT*("`@(&9U;F-T:6]N(&ES4W5B<&%C
M:V%G92@F)'!F*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M<&%C:V%G969I;&4I*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P
M86-K86=E9FEL92T^:7-3=6)P86-K86=E*"1P9BD[#0H@("`@("`@('T@96QS
M96EF("AI<W-E="@D=&AI<RT^7V1O=VYL;V%D55),6R=I;F9O)UTI*2![#0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]D;W=N;&]A9%523%LG:6YF;R==
M+3YI<U-U8G!A8VMA9V4H)'!F*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@('T-"@T*("`@
M(&9U;F-T:6]N(&=E=%!A8VMA9V54>7!E*"D-"B`@("![#0H@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7W!A8VMA9V5F:6QE*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?<&%C:V%G969I;&4M/F=E=%!A8VMA9V54>7!E*"D[
M#0H@("`@("`@('T@96QS96EF("AI<W-E="@D=&AI<RT^7V1O=VYL;V%D55),
M6R=I;F9O)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]D;W=N
M;&]A9%523%LG:6YF;R==+3YG971086-K86=E5'EP92@I.PT*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]
M#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@:7-"=6YD;&4H*0T*("`@('L-"B`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G969I;&4I*2![#0H@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E9FEL92T^9V5T4&%C:V%G
M951Y<&4H*2`]/2`G8G5N9&QE)SL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@('T-"@T*("`@
M(&9U;F-T:6]N(&=E=%!A8VMA9V58;6Q697)S:6]N*"D-"B`@("![#0H@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5F:6QE*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G969I;&4M/F=E=%!A8VMA9V5X
M;6Q697)S:6]N*"D[#0H@("`@("`@('T@96QS96EF("AI<W-E="@D=&AI<RT^
M7V1O=VYL;V%D55),6R=I;F9O)UTI*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/E]D;W=N;&]A9%523%LG:6YF;R==+3YG971086-K86=E>&UL5F5R
M<VEO;B@I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@<F5T=7)N
M("<Q+C`G.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T
M0VAA;FYE;"@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P
M86-K86=E9FEL92DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A
M8VMA9V5F:6QE+3YG971#:&%N;F5L*"D[#0H@("`@("`@('T@96QS96EF("AI
M<W-E="@D=&AI<RT^7V1O=VYL;V%D55),6R=I;F9O)UTI*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]D;W=N;&]A9%523%LG:6YF;R==+3YG971#
M:&%N;F5L*"D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G
M97154DDH*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C
M:V%G969I;&4I*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K
M86=E9FEL92T^9V5T55))*"D[#0H@("`@("`@('T@96QS96EF("AI<W-E="@D
M=&AI<RT^7V1O=VYL;V%D55),6R=I;F9O)UTI*2![#0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]D;W=N;&]A9%523%LG:6YF;R==+3YG97154DDH*3L-
M"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("`@("`@?0T*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=%9E<G-I;VXH
M*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G969I
M;&4I*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E9FEL
M92T^9V5T5F5R<VEO;B@I.PT*("`@("`@("!](&5L<V5I9B`H:7-S970H)'1H
M:7,M/E]D;W=N;&]A9%523%LG=F5R<VEO;B==*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?9&]W;FQO86154DQ;)W9E<G-I;VXG73L-"B`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@?0T*("`@('T-"@T*("`@(&9U;F-T:6]N(&ES0V]M<&%T:6)L92@D<&8I
M#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E9FEL
M92DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5F:6QE
M+3YI<T-O;7!A=&EB;&4H)'!F*3L-"B`@("`@("`@?2!E;'-E:68@*&ES<V5T
M*"1T:&ES+3Y?9&]W;FQO86154DQ;)VEN9F\G72DI('L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7V1O=VYL;V%D55),6R=I;F9O)UTM/FES0V]M<&%T
M:6)L92@D<&8I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!S
M971'<F]U<"@D9W)O=7`I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W!A<G-E
M9&YA;65;)V=R;W5P)UT@/2`D9W)O=7`[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@9V5T1W)O=7`H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?<&%R<V5D;F%M95LG9W)O=7`G72DI('L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7W!A<G-E9&YA;65;)V=R;W5P)UT[#0H@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("!R971U<FX@)R<[#0H@("`@("`@('T-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!I<T5X=&5N<VEO;B@D;F%M92D-"B`@("![#0H@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5F:6QE*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G969I;&4M/FES17AT96YS
M:6]N*"1N86UE*3L-"B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES+3Y?
M9&]W;FQO86154DQ;)VEN9F\G72DI('L-"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7V1O=VYL;V%D55),6R=I;F9O)UTM/F=E=%!R;W9I9&5S17AT96YS
M:6]N*"D@/3T@)&YA;64[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!G971$97!S*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^7W!A8VMA9V5F:6QE*2D@>PT*("`@("`@("`@("`@:68@*"1T:&ES+3Y?
M<&%C:V%G969I;&4M/F=E=%!A8VMA9V5X;6Q697)S:6]N*"D@/3T@)S(N,"<I
M('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E9FEL
M92T^9V5T1&5P<RAT<G5E*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G969I;&4M/F=E=$1E
M<',H*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E:68@*&ES<V5T
M*"1T:&ES+3Y?9&]W;FQO86154DQ;)VEN9F\G72DI('L-"B`@("`@("`@("`@
M(&EF("@D=&AI<RT^7V1O=VYL;V%D55),6R=I;F9O)UTM/F=E=%!A8VMA9V5X
M;6Q697)S:6]N*"D@/3T@)S(N,"<I('L-"B`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]D;W=N;&]A9%523%LG:6YF;R==+3YG971$97!S*'1R=64I
M.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]D;W=N;&]A9%523%LG:6YF;R==+3YG971$97!S*"D[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!R
M971U<FX@87)R87DH*3L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*
M("`@("`J($!P87)A;2!A<G)A>2!087)S960@87)R87D@9G)O;2![0&QI;FL@
M4$5!4E]296=I<W1R>3HZ<&%R<V5086-K86=E3F%M92@I?2!O<B!A(&1E<&5N
M9&5N8WD-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(')E='5R;F5D(&9R
M;VT@9V5T1&5P1&]W;FQO86154DPH*0T*("`@("`J+PT*("`@(&9U;F-T:6]N
M(&ES17%U86PH)'!A<F%M*0T*("`@('L-"B`@("`@("`@:68@*&ES7V]B:F5C
M="@D<&%R86TI*2![#0H@("`@("`@("`@("`D8VAA;FYE;"`]("1P87)A;2T^
M9V5T0VAA;FYE;"@I.PT*("`@("`@("`@("`@)'!A8VMA9V4@/2`D<&%R86TM
M/F=E=%!A8VMA9V4H*3L-"B`@("`@("`@("`@(&EF("@D<&%R86TM/F=E=%52
M22@I*2![#0H@("`@("`@("`@("`@("`@)'!A<F%M(#T@87)R87DH#0H@("`@
M("`@("`@("`@("`@("`@("=C:&%N;F5L)R`]/B`D<&%R86TM/F=E=$-H86YN
M96PH*2P-"B`@("`@("`@("`@("`@("`@("`@)W!A8VMA9V4G(#T^("1P87)A
M;2T^9V5T4&%C:V%G92@I+`T*("`@("`@("`@("`@("`@("`@("`G=F5R<VEO
M;B<@/3X@)'!A<F%M+3YG971697)S:6]N*"DL#0H@("`@("`@("`@("`@("`@
M("`@("=U<FDG(#T^("1P87)A;2T^9V5T55))*"DL#0H@("`@("`@("`@("`@
M("`@*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M)'!A<F%M(#T@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=C:&%N;F5L
M)R`]/B`D<&%R86TM/F=E=$-H86YN96PH*2P-"B`@("`@("`@("`@("`@("`@
M("`@)W!A8VMA9V4G(#T^("1P87)A;2T^9V5T4&%C:V%G92@I+`T*("`@("`@
M("`@("`@("`@("`@("`G=F5R<VEO;B<@/3X@)'!A<F%M+3YG971697)S:6]N
M*"DL#0H@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D<&%R86U;)W5R
M:2==*2D@>PT*("`@("`@("`@("`@("`@("1P87)A;5LG8VAA;FYE;"==(#T@
M)U]?=7)I)SL-"B`@("`@("`@("`@("`@("`D<&%R86U;)W!A8VMA9V4G72`]
M("1P87)A;5LG9&5P)UU;)VYA;64G73L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("1P86-K86=E(#T@:7-S970H)'!A<F%M6R=P86-K86=E)UTI(#\@
M)'!A<F%M6R=P86-K86=E)UT@.@T*("`@("`@("`@("`@("`@("1P87)A;5LG
M:6YF;R==+3YG971086-K86=E*"D[#0H@("`@("`@("`@("`D8VAA;FYE;"`]
M(&ES<V5T*"1P87)A;5LG8VAA;FYE;"==*2`_("1P87)A;5LG8VAA;FYE;"==
M(#H-"B`@("`@("`@("`@("`@("`D<&%R86U;)VEN9F\G72T^9V5T0VAA;FYE
M;"@I.PT*("`@("`@("`@("`@:68@*&ES<V5T*"1P87)A;5LG<F5L)UTI*2![
M#0H@("`@("`@("`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?1&5P
M96YD96YC>3(G*2D@>PT*("`@("`@("`@("`@("`@("`@("!R97%U:7)E7V]N
M8V4@)U!%05(O1&5P96YD96YC>3(N<&AP)SL-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@)&YE=V1E<"`](%!%05)?1&5P96YD96YC>3(Z
M.FYO<FUA;&EZ941E<"@D<&%R86TI.PT*("`@("`@("`@("`@("`@("1N97=D
M97`@/2`D;F5W9&5P6S!=.PT*("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T
M*"1P87)A;5LG;6EN)UTI*2![#0H@("`@("`@("`@("`@("`@)&YE=V1E<"`]
M("1P87)A;3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H:7-S970H)&YE=V1E<"DI('L-"B`@("`@("`@("`@(&EF("@A:7-S970H
M)&YE=V1E<%LG;6EN)UTI*2![#0H@("`@("`@("`@("`@("`@)&YE=V1E<%LG
M;6EN)UT@/2`G,"<[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1N97=D97!;)VUA>"==*2D@>PT*("`@("`@("`@("`@("`@("1N
M97=D97!;)VUA>"==(#T@)S$P,#`P,#`P,#`P,#`P,#`P,#`P,"<[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`O+R!U<V4@;6%G:6,@=&\@<W5P<&]R
M="!P96-L('!A8VMA9V5S('-U9&1E;FQY(&IU;7!I;F<@=&\@=&AE('!E8VP@
M8VAA;FYE;`T*("`@("`@("`@("`@+R\@=V4@;F5E9"!T;R!S=7!P;W)T(&)O
M=&@@9&5P96YD96YC>2!P;W-S:6)I;&ET:65S#0H@("`@("`@("`@("!I9B`H
M)&-H86YN96P@/3T@)W!E87(N<&AP+FYE="<@)B8@)'1H:7,M/F=E=$-H86YN
M96PH*2`]/2`G<&5C;"YP:'`N;F5T)RD@>PT*("`@("`@("`@("`@("`@(&EF
M("@D<&%C:V%G92`]/2`D=&AI<RT^9V5T4&%C:V%G92@I*2![#0H@("`@("`@
M("`@("`@("`@("`@("1C:&%N;F5L(#T@)W!E8VPN<&AP+FYE="<[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@
M*"1C:&%N;F5L(#T]("=P96-L+G!H<"YN970G("8F("1T:&ES+3YG971#:&%N
M;F5L*"D@/3T@)W!E87(N<&AP+FYE="<I('L-"B`@("`@("`@("`@("`@("!I
M9B`H)'!A8VMA9V4@/3T@)'1H:7,M/F=E=%!A8VMA9V4H*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`D8VAA;FYE;"`]("=P96%R+G!H<"YN970G.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E
M='5R;B`H<W1R=&]L;W=E<B@D<&%C:V%G92D@/3T@<W1R=&]L;W=E<B@D=&AI
M<RT^9V5T4&%C:V%G92@I*2`F)@T*("`@("`@("`@("`@("`@("1C:&%N;F5L
M(#T]("1T:&ES+3YG971#:&%N;F5L*"D@)B8-"B`@("`@("`@("`@("`@("!V
M97)S:6]N7V-O;7!A<F4H)&YE=V1E<%LG;6EN)UTL("1T:&ES+3YG971697)S
M:6]N*"DL("<\/2<I("8F#0H@("`@("`@("`@("`@("`@=F5R<VEO;E]C;VUP
M87)E*"1N97=D97!;)VUA>"==+"`D=&AI<RT^9V5T5F5R<VEO;B@I+"`G/CTG
M*2D[#0H@("`@("`@('T-"B`@("`@("`@+R\@=7-E(&UA9VEC('1O('-U<'!O
M<G0@<&5C;"!P86-K86=E<R!S=61D96YL>2!J=6UP:6YG('1O('1H92!P96-L
M(&-H86YN96P-"B`@("`@("`@:68@*"1C:&%N;F5L(#T]("=P96-L+G!H<"YN
M970G("8F("1T:&ES+3YG971#:&%N;F5L*"D@/3T@)W!E87(N<&AP+FYE="<I
M('L-"B`@("`@("`@("`@(&EF("AS=')T;VQO=V5R*"1P86-K86=E*2`]/2!S
M=')T;VQO=V5R*"1T:&ES+3YG971086-K86=E*"DI*2![#0H@("`@("`@("`@
M("`@("`@)&-H86YN96P@/2`G<&5A<BYP:'`N;F5T)SL-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)'!A<F%M6R=V97)S
M:6]N)UTI*2![#0H@("`@("`@("`@("!R971U<FX@*'-T<G1O;&]W97(H)'!A
M8VMA9V4I(#T]('-T<G1O;&]W97(H)'1H:7,M/F=E=%!A8VMA9V4H*2D@)B8-
M"B`@("`@("`@("`@("`@("`D8VAA;FYE;"`]/2`D=&AI<RT^9V5T0VAA;FYE
M;"@I("8F#0H@("`@("`@("`@("`@("`@)'!A<F%M6R=V97)S:6]N)UT@/3T@
M)'1H:7,M/F=E=%9E<G-I;VXH*2D[#0H@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("!R971U<FX@<W1R=&]L;W=E<B@D<&%C:V%G92D@/3T@<W1R=&]L
M;W=E<B@D=&AI<RT^9V5T4&%C:V%G92@I*2`F)@T*("`@("`@("`@("`@("`@
M("1C:&%N;F5L(#T]("1T:&ES+3YG971#:&%N;F5L*"D[#0H@("`@("`@('T-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!I<TEN<W1A;&QE9"@D9&5P+"`D;W!E
M<B`]("<]/2<I#0H@("`@>PT*("`@("`@("!I9B`H(21D97`I('L-"B`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M)&]P97(@(3T@)V=E)R`F)B`D;W!E<B`A/2`G9W0G("8F("1O<&5R("$]("=H
M87,G("8F("1O<&5R("$]("<]/2<I('L-"B`@("`@("`@("`@(')E='5R;B!F
M86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-?;V)J96-T*"1D97`I
M*2![#0H@("`@("`@("`@("`D<&%C:V%G92`]("1D97`M/F=E=%!A8VMA9V4H
M*3L-"B`@("`@("`@("`@("1C:&%N;F5L(#T@)&1E<"T^9V5T0VAA;FYE;"@I
M.PT*("`@("`@("`@("`@:68@*"1D97`M/F=E=%5222@I*2![#0H@("`@("`@
M("`@("`@("`@)&1E<"`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G
M=7)I)R`]/B`D9&5P+3YG97154DDH*2P-"B`@("`@("`@("`@("`@("`@("`@
M)W9E<G-I;VXG(#T^("1D97`M/F=E=%9E<G-I;VXH*2P-"B`@("`@("`@("`@
M("`@("`I.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`D9&5P(#T@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=V97)S:6]N
M)R`]/B`D9&5P+3YG971697)S:6]N*"DL#0H@("`@("`@("`@("`@("`@*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M(&EF("AI<W-E="@D9&5P6R=U<FDG72DI('L-"B`@("`@("`@("`@("`@("`D
M8VAA;FYE;"`]("=?7W5R:2<[#0H@("`@("`@("`@("`@("`@)'!A8VMA9V4@
M/2`D9&5P6R=D97`G75LG;F%M92==.PT*("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`D8VAA;FYE;"`]("1D97!;)VEN9F\G72T^9V5T
M0VAA;FYE;"@I.PT*("`@("`@("`@("`@("`@("1P86-K86=E(#T@)&1E<%LG
M:6YF;R==+3YG971086-K86=E*"D[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@)&]P=&EO;G,@/2`D=&AI<RT^7V1O=VYL;V%D97(M/F=E
M=$]P=&EO;G,H*3L-"B`@("`@("`@)'1E<W0@/2`D=&AI<RT^7VEN<W1A;&Q2
M96=I<W1R>2T^<&%C:V%G945X:7-T<R@D<&%C:V%G92P@)&-H86YN96PI.PT*
M("`@("`@("!I9B`H(21T97-T("8F("1C:&%N;F5L(#T]("=P96-L+G!H<"YN
M970G*2![#0H@("`@("`@("`@("`O+R!D;R!M86=I8R!T;R!A;&QO=R!U<&=R
M861I;F<@9G)O;2!O;&0@<&5C;"!P86-K86=E<R!T;R!N97<@;VYE<PT*("`@
M("`@("`@("`@)'1E<W0@/2`D=&AI<RT^7VEN<W1A;&Q296=I<W1R>2T^<&%C
M:V%G945X:7-T<R@D<&%C:V%G92P@)W!E87(N<&AP+FYE="<I.PT*("`@("`@
M("`@("`@)&-H86YN96P@/2`G<&5A<BYP:'`N;F5T)SL-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H)'1E<W0I('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D
M9&5P6R=U<FDG72DI('L-"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]I
M;G-T86QL4F5G:7-T<GDM/G!A8VMA9V5);F9O*"1P86-K86=E+"`G=7)I)RP@
M)U]?=7)I)RD@/3T@)&1E<%LG=7)I)UTI('L-"B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=U<&=R861E
M)UTI*2![#0H@("`@("`@("`@("`@("`@:68@*"1O<&5R(#T]("=H87,G*2![
M#0H@("`@("`@("`@("`@("`@("`@(&EF("AV97)S:6]N7V-O;7!A<F4H)'1H
M:7,M/E]I;G-T86QL4F5G:7-T<GDM/G!A8VMA9V5);F9O*`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<&%C:V%G92P@)W9E<G-I;VXG+"`D8VAA;FYE
M;"DL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("1D97!;)W9E<G-I;VXG
M72P@)SX])RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!T
M<G5E.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92@D=&AI<RT^7VEN<W1A;&Q2
M96=I<W1R>2T^<&%C:V%G94EN9F\H#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("1P86-K86=E+"`G=F5R<VEO;B<L("1C:&%N;F5L*2P-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&1E<%LG=F5R<VEO;B==+"`G/CTG*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@87)R
M87D-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<F5M
M;W9E1'5P;&EC871E<R@F)'!A<F%M<RD-"B`@("![#0H@("`@("`@("1P;F%M
M97,@/2!A<G)A>2@I.PT*("`@("`@("!F;W)E86-H("@D<&%R86US(&%S("1I
M(#T^("1P87)A;2D@>PT*("`@("`@("`@("`@:68@*"$D<&%R86TI('L-"B`@
M("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&EF("@D<&%R86TM/F=E=%!A8VMA9V4H*2D@>PT*("`@("`@("`@
M("`@("`@("1P;F%M97-;)&E=(#T@)'!A<F%M+3YG971#:&%N;F5L*"D@+B`G
M+R<@+@T*("`@("`@("`@("`@("`@("`@("`D<&%R86TM/F=E=%!A8VMA9V4H
M*2`N("<M)R`N("1P87)A;2T^9V5T5F5R<VEO;B@I("X@)R,G("X@)'!A<F%M
M+3YG971'<F]U<"@I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@("1P;F%M97,@/2!A<G)A>5]U;FEQ=64H)'!N86UE<RD[#0H@("`@("`@
M("1U;G-E="`](&%R<F%Y7V1I9F8H87)R87E?:V5Y<R@D<&%R86US*2P@87)R
M87E?:V5Y<R@D<&YA;65S*2D[#0H@("`@("`@("1T97-T<"`](&%R<F%Y7V9L
M:7`H)'!N86UE<RD[#0H@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)&D@
M/3X@)'!A<F%M*2![#0H@("`@("`@("`@("!I9B`H(21P87)A;2D@>PT*("`@
M("`@("`@("`@("`@("1U;G-E=%M=(#T@)&D[#0H@("`@("`@("`@("`@("`@
M8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(6ES
M7V$H)'!A<F%M+"`G4$5!4E]$;W=N;&]A9&5R7U!A8VMA9V4G*2D@>PT*("`@
M("`@("`@("`@("`@("1U;G-E=%M=(#T@)&D[#0H@("`@("`@("`@("`@("`@
M8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1T97-T<%LD<&%R86TM/F=E=$-H86YN96PH*2`N("<O)R`N("1P87)A
M;2T^9V5T4&%C:V%G92@I("X@)RTG("X-"B`@("`@("`@("`@("`@("`@("1P
M87)A;2T^9V5T5F5R<VEO;B@I("X@)R,G("X@)'!A<F%M+3YG971'<F]U<"@I
M72DI('L-"B`@("`@("`@("`@("`@("`D=6YS971;72`]("1I.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&9O<F5A8V@@*"1U;G-E="!A
M<R`D:2D@>PT*("`@("`@("`@("`@=6YS970H)'!A<F%M<ULD:5TI.PT*("`@
M("`@("!]#0H@("`@("`@("1R970@/2!A<G)A>2@I.PT*("`@("`@("!F;W)E
M86-H("@D<&%R86US(&%S("1I(#T^("1P87)A;2D@>PT*("`@("`@("`@("`@
M)')E=%M=(#T@)B1P87)A;7-;)&E=.PT*("`@("`@("!]#0H@("`@("`@("1P
M87)A;7,@/2!A<G)A>2@I.PT*("`@("`@("!F;W)E86-H("@D<F5T(&%S("1I
M(#T^("1P87)A;2D@>PT*("`@("`@("`@("`@)'!A<F%M<UM=(#T@)B1R971;
M)&E=.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@97AP;&EC
M:713=&%T92@I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/E]E>'!L
M:6-I=%-T871E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E=$5X<&QI8VET
M4W1A=&4H)',I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7V5X<&QI8VET4W1A
M=&4@/2`D<SL-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<W1A=&EC#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@;65R9V5$97!E;F1E;F-I97,H)B1P87)A
M;7,I#0H@("`@>PT*("`@("`@("`D;F5W<&%R86US(#T@87)R87DH*3L-"B`@
M("`@("`@)&)U;F1L97,@/2!A<G)A>2@I.PT*("`@("`@("!F;W)E86-H("@D
M<&%R86US(&%S("1I(#T^("1P87)A;2D@>PT*("`@("`@("`@("`@:68@*"$D
M<&%R86TM/FES0G5N9&QE*"DI('L-"B`@("`@("`@("`@("`@("!C;VYT:6YU
M93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1B=6YD;&5S6UT@/2`D
M:3L-"B`@("`@("`@("`@("1P9B`]("8D<&%R86TM/F=E=%!A8VMA9V5&:6QE
M*"D[#0H@("`@("`@("`@("`D;F5W9&5P<R`](&%R<F%Y*"D[#0H@("`@("`@
M("`@("`D8V]N=&5N=',@/2`D<&8M/F=E=$)U;F1L961086-K86=E<R@I.PT*
M("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D8V]N=&5N=',I*2![#0H@("`@
M("`@("`@("`@("`@)&-O;G1E;G1S(#T@87)R87DH)&-O;G1E;G1S*3L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@*"1C;VYT96YT<R!A
M<R`D9FEL92D@>PT*("`@("`@("`@("`@("`@("1F:6QE8V]N=&5N=',@/2`D
M<&8M/F=E=$9I;&5#;VYT96YT<R@D9FEL92D[#0H@("`@("`@("`@("`@("`@
M)&1L(#T@)B1P87)A;2T^9V5T1&]W;FQO861E<B@I.PT*("`@("`@("`@("`@
M("`@("1O<'1I;VYS(#T@)&1L+3YG971/<'1I;VYS*"D[#0H@("`@("`@("`@
M("`@("`@)&9P(#T@0&9O<&5N*"1D;"T^9V5T1&]W;FQO861$:7(H*2`N($1)
M4D5#5$]265]315!!4D%43U(@+B`D9FEL92P@)W=B)RD[#0H@("`@("`@("`@
M("`@("`@:68@*"$D9G`I('L-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN
M=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&9W<FET
M92@D9G`L("1F:6QE8V]N=&5N=',L('-T<FQE;B@D9FEL96-O;G1E;G1S*2D[
M#0H@("`@("`@("`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@("`@("`@
M("`@:68@*"1S(#T@)'!A<F%M<ULD:5TM/F5X<&QI8VET4W1A=&4H*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`D;V)J+3YS971%>'!L:6-I=%-T871E*"1S
M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&]B:B`]
M("9N97<@4$5!4E]$;W=N;&]A9&5R7U!A8VMA9V4H)'!A<F%M<ULD:5TM/F=E
M=$1O=VYL;V%D97(H*2D[#0H@("`@("`@("`@("`@("`@4$5!4CHZ<'5S:$5R
M<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`@("`@
M("`@("1E(#T@)&]B:BT^7V9R;VU&:6QE*"1A(#T@)&1L+3YG971$;W=N;&]A
M9$1I<B@I("X@1$E214-43U)97U-%4$%2051/4B`N("1F:6QE*3L-"B`@("`@
M("`@("`@("`@("!014%2.CIP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@
M("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&4I*2![#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1D;"T^;&]G*#`L("1E+3YG971-97-S
M86=E*"DI.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`D:B`]("8D;V)J.PT*("`@("`@("`@("`@("`@(&EF("@A4$5!
M4E]$;W=N;&]A9&5R7U!A8VMA9V4Z.G=I;&Q$;W=N;&]A9"@D:BP-"B`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>5]M97)G92@D<&%R86US+"`D;F5W<&%R
M86US*2D@)B8@(21P87)A;2T^:7-);G-T86QL960H)&HI*2![#0H@("`@("`@
M("`@("`@("`@("`@("1N97=P87)A;7-;72`]("8D:CL-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@9F]R
M96%C:"`H)&)U;F1L97,@87,@)&DI('L-"B`@("`@("`@("`@('5N<V5T*"1P
M87)A;7-;)&E=*3L@+R\@<F5M;W9E(&)U;F1L97,@+2!O;FQY('1H96ER(&-O
M;G1E;G1S(&UA='1E<B!F;W(@:6YS=&%L;&%T:6]N#0H@("`@("`@('T-"B`@
M("`@("`@4$5!4E]$;W=N;&]A9&5R7U!A8VMA9V4Z.G)E;6]V941U<&QI8V%T
M97,H)'!A<F%M<RD[("\O('-T<FEP(&%N>2!U;G-E="!I;F1I8V5S#0H@("`@
M("`@(&EF("AC;W5N="@D;F5W<&%R86US*2D@>R`O+R!A9&0@:6X@8G5N9&QE
M9"!P86-K86=E<R!F;W(@:6YS=&%L;`T*("`@("`@("`@("`@9F]R96%C:"`H
M)&YE=W!A<F%M<R!A<R`D:2`]/B`D=6YU<V5D*2![#0H@("`@("`@("`@("`@
M("`@)'!A<F%M<UM=(#T@)B1N97=P87)A;7-;)&E=.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@)&YE=W!A<F%M<R`](&%R<F%Y*"D[#0H@("`@("`@
M('T-"B`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D:2`]/B`D<&%R86TI
M('L-"B`@("`@("`@("`@("1N97=D97!S(#T@87)R87DH*3L-"B`@("`@("`@
M("`@(&9O<F5A8V@@*"1P87)A;2T^7V1O=VYL;V%D1&5P<R!A<R`D9&5P*2![
M#0H@("`@("`@("`@("`@("`@:68@*"%014%27T1O=VYL;V%D97)?4&%C:V%G
M93HZ=VEL;$1O=VYL;V%D*"1D97`L#0H@("`@("`@("`@("`@("`@("`@("`@
M87)R87E?;65R9V4H)'!A<F%M<RP@)&YE=W!A<F%M<RDI("8F("$D<&%R86TM
M/FES26YS=&%L;&5D*"1D97`I*2![#0H@("`@("`@("`@("`@("`@("`@("1N
M97=D97!S6UT@/2`D9&5P.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@("`@("\O(&1E=&5C="!V97)S:6]N:6YG(&-O;F9L
M:6-T<R!H97)E#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@+R\@8V]N=F5R="!T:&4@9&5P96YD96YC:65S(&EN=&\@
M4$5!4E]$;W=N;&]A9&5R7U!A8VMA9V4@;V)J96-T<R!F;W(@=&AE(&YE>'0@
M=&EM90T*("`@("`@("`@("`@+R\@87)O=6YD#0H@("`@("`@("`@("`D<&%R
M86US6R1I72T^7V1O=VYL;V%D1&5P<R`](&%R<F%Y*"D[#0H@("`@("`@("`@
M("!F;W)E86-H("@D;F5W9&5P<R!A<R`D9&5P*2![#0H@("`@("`@("`@("`@
M("`@)&]B:B`]("9N97<@4$5!4E]$;W=N;&]A9&5R7U!A8VMA9V4H)'!A<F%M
M<ULD:5TM/F=E=$1O=VYL;V%D97(H*2D[#0H@("`@("`@("`@("`@("`@:68@
M*"1S(#T@)'!A<F%M<ULD:5TM/F5X<&QI8VET4W1A=&4H*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`D;V)J+3YS971%>'!L:6-I=%-T871E*"1S*3L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@4$5!4CHZ<'5S:$5R
M<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`@("`@
M("`@("1E(#T@)&]B:BT^9G)O;41E<%523"@D9&5P*3L-"B`@("`@("`@("`@
M("`@("!014%2.CIP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)&4I*2![#0H@("`@("`@("`@("`@("`@
M("`@(&EF("@A:7-S970H)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1O8FHM/E]D;W=N;&]A9&5R+3YL;V<H,"P@)&4M
M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("1E(#T@)&]B:BT^9&5T96-T1&5P96YD96YC:65S
M*"1P87)A;7,I.PT*("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1E*2D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I
M;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D;V)J
M+3Y?9&]W;FQO861E<BT^;&]G*#`L("1E+3YG971-97-S86=E*"DI.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("1J(#T@)B1O8FH[#0H@("`@("`@("`@("`@("`@)&YE=W!A
M<F%M<UM=(#T@)B1J.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@(&EF("AC;W5N="@D;F5W<&%R86US*2D@>PT*("`@("`@("`@("`@9F]R
M96%C:"`H)&YE=W!A<F%M<R!A<R`D:2`]/B`D=6YU<V5D*2![#0H@("`@("`@
M("`@("`@("`@)'!A<F%M<UM=(#T@)B1N97=P87)A;7-;)&E=.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-
M"B`@("!]#0H-"@T*("`@("\J*@T*("`@("`J($!S=&%T:6,-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!W:6QL1&]W;FQO860H)'!A<F%M+"`D<&%R86US*0T*
M("`@('L-"B`@("`@("`@:68@*"%I<U]A<G)A>2@D<&%R86US*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&9O
M<F5A8V@@*"1P87)A;7,@87,@)&]B:BD@>PT*("`@("`@("`@("`@:68@*"1O
M8FHM/FES17%U86PH)'!A<F%M*2D@>PT*("`@("`@("`@("`@("`@(')E='5R
M;B!T<G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!&;W(@<VEM
M<&QE<B!U;FET+71E<W1I;F<-"B`@("`@*B!`<&%R86T@4$5!4E]#;VYF:6<-
M"B`@("`@*B!`<&%R86T@:6YT#0H@("`@("H@0'!A<F%M('-T<FEN9PT*("`@
M("`J+PT*("`@(&9U;F-T:6]N("9G971086-K86=E9FEL94]B:F5C="@F)&,L
M("1D+"`D="`](&9A;'-E*0T*("`@('L-"B`@("`@("`@)&$@/2`F;F5W(%!%
M05)?4&%C:V%G949I;&4H)&,L("1D+"`D="D[#0H@("`@("`@(')E='5R;B`D
M83L-"B`@("!]#0H-"@T*("`@("\J*@T*("`@("`J(%1H:7,@=VEL;"!R971R
M:65V92!F<F]M(&$@;&]C86P@9FEL92!I9B!P;W-S:6)L92P@86YD('!A<G-E
M(&]U=`T*("`@("`J(&$@9W)O=7`@;F%M92!A<R!W96QL+B`@5&AE(&]R:6=I
M;F%L('!A<F%M971E<B!W:6QL(&)E(&UO9&EF:65D('1O(')E9FQE8W0@=&AI
M<RX-"B`@("`@*B!`<&%R86T@<W1R:6YG?&%R<F%Y(&-A;B!B92!A('!A<G-E
M9"!P86-K86=E(&YA;64@87,@=V5L;`T*("`@("`J($!A8V-E<W,@<')I=F%T
M90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]F<F]M1FEL92@F)'!A<F%M*0T*
M("`@('L-"B`@("`@("`@:68@*&ES7W-T<FEN9R@D<&%R86TI("8F("%`:7-?
M9FEL92@D<&%R86TI*2![#0H@("`@("`@("`@("`D=&5S="`](&5X<&QO9&4H
M)R,G+"`D<&%R86TI.PT*("`@("`@("`@("`@)&=R;W5P(#T@87)R87E?<&]P
M*"1T97-T*3L-"B`@("`@("`@("`@(&EF("A`:7-?9FEL92AI;7!L;V1E*"<C
M)RP@)'1E<W0I*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3YS971'<F]U
M<"@D9W)O=7`I.PT*("`@("`@("`@("`@("`@("1P87)A;2`](&EM<&QO9&4H
M)R,G+"`D=&5S="D[#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]E>'!L:6-I
M=$=R;W5P(#T@=')U93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H0&ES7V9I;&4H)'!A<F%M*2D@>PT*("`@("`@("`@("`@)'1H
M:7,M/E]T>7!E(#T@)VQO8V%L)SL-"B`@("`@("`@("`@("1O<'1I;VYS(#T@
M)'1H:7,M/E]D;W=N;&]A9&5R+3YG971/<'1I;VYS*"D[#0H@("`@("`@("`@
M("!I9B`H:7-S970H)&]P=&EO;G-;)V1O=VYL;V%D;VYL>2==*2D@>PT*("`@
M("`@("`@("`@("`@("1P:V<@/2`F)'1H:7,M/F=E=%!A8VMA9V5F:6QE3V)J
M96-T*"1T:&ES+3Y?8V]N9FEG+`T*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7V1O=VYL;V%D97(M/E]D96)U9RD[#0H@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("1P:V<@/2`F)'1H:7,M/F=E=%!A8VMA9V5F
M:6QE3V)J96-T*"1T:&ES+3Y?8V]N9FEG+`T*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V1O=VYL;V%D97(M/E]D96)U9RP@)'1H:7,M/E]D;W=N;&]A
M9&5R+3YG971$;W=N;&]A9$1I<B@I*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(%!%05(Z.G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D54
M55).*3L-"B`@("`@("`@("`@("1P9B`]("8D<&MG+3YF<F]M06YY1FEL92@D
M<&%R86TL(%!%05)?5D%,241!5$5?24Y35$%,3$E.1RD[#0H@("`@("`@("`@
M("!014%2.CIP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D<&8I*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M
M/E]V86QI9"`](&9A;'-E.PT*("`@("`@("`@("`@("`@(')E='5R;B`D<&8[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5F
M:6QE(#T@)B1P9CL-"B`@("`@("`@("`@(&EF("@A)'1H:7,M/F=E=$=R;W5P
M*"DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1W)O=7`H)V1E9F%U
M;'0G*3L@+R\@:6YS=&%L;"!T:&4@9&5F875L="!D97!E;F1E;F-Y(&=R;W5P
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]V
M86QI9"`]('1R=64[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?=F%L:60@/2!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?9G)O
M;55R;"@D<&%R86TL("1S879E<&%R86T@/2`G)RD-"B`@("![#0H@("`@("`@
M(&EF("@A:7-?87)R87DH)'!A<F%M*2`F)@T*("`@("`@("`@("`@("`H<')E
M9U]M871C:"@G(UXH:'1T<'QF='`I.B\O(R<L("1P87)A;2DI*2![#0H@("`@
M("`@("`@("`D;W!T:6]N<R`]("1T:&ES+3Y?9&]W;FQO861E<BT^9V5T3W!T
M:6]N<R@I.PT*("`@("`@("`@("`@)'1H:7,M/E]T>7!E(#T@)W5R;"<[#0H@
M("`@("`@("`@("`D8V%L;&)A8VL@/2`D=&AI<RT^7V1O=VYL;V%D97(M/G5I
M(#\-"B`@("`@("`@("`@("`@("!A<G)A>2@F)'1H:7,M/E]D;W=N;&]A9&5R
M+"`G7V1O=VYL;V%D0V%L;&)A8VLG*2`Z(&YU;&P[#0H@("`@("`@("`@("`D
M=&AI<RT^7V1O=VYL;V%D97(M/G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)2
M3U)?4D5455).*3L-"B`@("`@("`@("`@("1F:6QE(#T@)'1H:7,M/E]D;W=N
M;&]A9&5R+3YD;W=N;&]A9$AT='`H)'!A<F%M+"`D=&AI<RT^7V1O=VYL;V%D
M97(M/G5I+`T*("`@("`@("`@("`@("`@("1T:&ES+3Y?9&]W;FQO861E<BT^
M9V5T1&]W;FQO861$:7(H*2P@)&-A;&QB86-K*3L-"B`@("`@("`@("`@("1T
M:&ES+3Y?9&]W;FQO861E<BT^<&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)&9I;&4I*2![#0H@("`@("`@("`@
M("`@("`@:68@*"%E;7!T>2@D<V%V97!A<F%M*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`D<V%V97!A<F%M(#T@(BP@8V%N;F]T(&1O=VYL;V%D(%PB)'-A
M=F5P87)A;5PB(CL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@)&5R<B`](%!%05(Z.G)A:7-E17)R;W(H)T-O=6QD(&YO="!D;W=N;&]A
M9"!F<F]M("(G("X@)'!A<F%M("X-"B`@("`@("`@("`@("`@("`@("`@)R(G
M("X@)'-A=F5P87)A;2D[#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M97)R.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1T:&ES+3Y?
M<F%W<&%C:V%G969I;&4I('L-"B`@("`@("`@("`@("`@("!R97%U:7)E7V]N
M8V4@)T%R8VAI=F4O5&%R+G!H<"<[#0H@("`@("`@("`@("`@("`@)'1A<B`]
M("9N97<@07)C:&EV95]487(H)&9I;&4I.PT*("`@("`@("`@("`@("`@("1P
M86-K86=E>&UL(#T@)'1A<BT^97AT<F%C=$EN4W1R:6YG*"=P86-K86=E,BYX
M;6PG*3L-"B`@("`@("`@("`@("`@("!I9B`H(21P86-K86=E>&UL*2![#0H@
M("`@("`@("`@("`@("`@("`@("1P86-K86=E>&UL(#T@)'1A<BT^97AT<F%C
M=$EN4W1R:6YG*"=P86-K86=E+GAM;"<I.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!I9B`H<W1R7W)E<&QA8V4H87)R87DH(EQN(BP@
M(EQR(BDL(&%R<F%Y*"<G+"<G*2P@)'!A8VMA9V5X;6PI("$]#0H@("`@("`@
M("`@("`@("`@("`@("`@<W1R7W)E<&QA8V4H87)R87DH(EQN(BP@(EQR(BDL
M(&%R<F%Y*"<G+"<G*2P@)'1H:7,M/E]R87=P86-K86=E9FEL92DI('L-"B`@
M("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YG971#:&%N;F5L*"D@/3T@
M)W!E87(N<&AP+FYE="<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("\O
M(&)E(&UO<F4@;&%X(&9O<B!T:&4@97AI<W1I;F<@4$5!4B!P86-K86=E<R!T
M:&%T(&AA=F4@;F]T+6]K#0H@("`@("`@("`@("`@("`@("`@("`@("`O+R!C
M:&%R86-T97)S(&EN('1H96ER('!A8VMA9V4N>&UL#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7V1O=VYL;V%D97(M/FQO9R@P+"`G0U))5$E#
M04P@5T%23DE.1SH@5&AE("(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^9V5T4&%C:V%G92@I("X@)R(@<&%C:V%G92!H87,@:6YV
M86QI9"!C:&%R86-T97)S(&EN(&ET<R`G("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G<&%C:V%G92YX;6PN("!4:&4@;F5X="!V97)S:6]N(&]F
M(%!%05(@;6%Y(&YO="!B92!A8FQE('1O(&EN<W1A;&P@)R`N#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W1H:7,@<&%C:V%G92!F;W(@<V5C=7)I
M='D@<F5A<V]N<RX@(%!L96%S92!O<&5N(&$@8G5G(')E<&]R="!A="`G("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:'1T<#HO+W!E87(N<&AP
M+FYE="]P86-K86=E+R<@+B`D=&AI<RT^9V5T4&%C:V%G92@I("X@)R]B=6=S
M)RD[#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G0U))5$E#
M04P@15)23U(Z('!A8VMA9V4N>&UL(&1O=VYL;V%D960@9&]E<R`G("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G;F]T(&UA=&-H('9A;'5E(')E
M='5R;F5D(&9R;VT@>&UL+7)P8R<I.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@+R\@=VAE=RP@9&]W;FQO860@=V]R:V5D(0T*("`@("`@("`@("`@:68@
M*&ES<V5T*"1O<'1I;VYS6R=D;W=N;&]A9&]N;'DG72DI('L-"B`@("`@("`@
M("`@("`@("`D<&MG(#T@)B1T:&ES+3YG971086-K86=E9FEL94]B:F5C="@D
M=&AI<RT^7V-O;F9I9RP@)'1H:7,M/E]D;W=N;&]A9&5R+3YD96)U9RD[#0H@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1P:V<@/2`F
M)'1H:7,M/F=E=%!A8VMA9V5F:6QE3V)J96-T*"1T:&ES+3Y?8V]N9FEG+"`D
M=&AI<RT^7V1O=VYL;V%D97(M/F1E8G5G+`T*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V1O=VYL;V%D97(M/F=E=$1O=VYL;V%D1&ER*"DI.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@4$5!4CHZ<'5S:$5R<F]R2&%N9&QI
M;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`@("`@)'!F(#T@)B1P
M:V<M/F9R;VU!;GE&:6QE*"1F:6QE+"!014%27U9!3$E$051%7TE.4U1!3$Q)
M3D<I.PT*("`@("`@("`@("`@4$5!4CHZ<&]P17)R;W)(86YD;&EN9R@I.PT*
M("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'!F*2D@>PT*("`@("`@
M("`@("`@("`@(&EF("AI<U]A<G)A>2@D<&8M/F=E=%5S97));F9O*"DI*2![
M#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1P9BT^9V5T57-E<DEN
M9F\H*2!A<R`D97)R*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M:7-?87)R87DH)&5R<BDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D97)R(#T@)&5R<ELG;65S<V%G92==.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9&]W;FQO861E<BT^;&]G*#`L(")686QI9&%T:6]N($5R
M<F]R.B`D97)R(BD[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7V1O=VYL;V%D97(M/FQO9R@P+"`D
M<&8M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("1E<G(@/2!014%2.CIR86ES945R<F]R*"=$;W=N;&]A9"!O
M9B`B)R`N("@D<V%V97!A<F%M(#\@)'-A=F5P87)A;2`Z#0H@("`@("`@("`@
M("`@("`@("`@("1P87)A;2D@+B`G(B!S=6-C965D960L(&)U="!I="!I<R!N
M;W0@82!V86QI9"!P86-K86=E(&%R8VAI=F4G*3L-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^7W9A;&ED(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@<F5T
M=7)N("1E<G([#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D=&AI<RT^
M7W!A8VMA9V5F:6QE(#T@)B1P9CL-"B`@("`@("`@("`@("1T:&ES+3YS971'
M<F]U<"@G9&5F875L="<I.R`O+R!I;G-T86QL('1H92!D969A=6QT(&1E<&5N
M9&5N8WD@9W)O=7`-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W9A;&ED
M(#T@=')U93L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'1H:7,M/E]V
M86QI9"`](&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J#0H@("`@
M("H@0'!A<F%M('-T<FEN9WQA<G)A>2!P87-S(&EN(&%N(&%R<F%Y(&]F(&9O
M<FUA=`T*("`@("`J("`@("`@("`@("`@("`@("`@("`@87)R87DH#0H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@)W!A8VMA9V4G(#T^("=P;F%M92<L
M#0H@("`@("H@("`@("`@("`@("`@("`@("`@("!;)V-H86YN96PG(#T^("=C
M:&%N;F%M92<L70T*("`@("`J("`@("`@("`@("`@("`@("`@("`@6R=V97)S
M:6]N)R`]/B`G=F5R<VEO;B<L70T*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@6R=S=&%T92<@/3X@)W-T871E)RQ=*0T*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@;W(@82!S=')I;F<@;V8@9F]R;6%T(%MC:&%N;F%M92]=<&YA
M;65;+79E<G-I;VY\+7-T871E70T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]F
M<F]M4W1R:6YG*"1P87)A;2D-"B`@("![#0H@("`@("`@("1O<'1I;VYS(#T@
M)'1H:7,M/E]D;W=N;&]A9&5R+3YG971/<'1I;VYS*"D[#0H@("`@("`@(%!%
M05(Z.G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@
M("`@("`@)'!N86UE(#T@)'1H:7,M/E]R96=I<W1R>2T^<&%R<V5086-K86=E
M3F%M92@D<&%R86TL#0H@("`@("`@("`@("`D=&AI<RT^7V-O;F9I9RT^9V5T
M*"=D969A=6QT7V-H86YN96PG*2D[#0H@("`@("`@(%!%05(Z.G!O<$5R<F]R
M2&%N9&QI;F<H*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'!N86UE
M*2D@>PT*("`@("`@("`@("`@:68@*"1P;F%M92T^9V5T0V]D92@I(#T]("=I
M;G9A;&ED)RD@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L:60@/2!F
M86QS93L-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!I9B`H)'!N86UE+3YG971#;V1E*"D@/3T@
M)V-H86YN96PG*2![#0H@("`@("`@("`@("`@("`@)'!A<G-E9"`]("1P;F%M
M92T^9V5T57-E<DEN9F\H*3L-"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M
M/E]D;W=N;&]A9&5R+3YD:7-C;W9E<B@D<&%R<V5D6R=C:&%N;F5L)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7V-O;F9I9RT^9V5T
M*"=A=71O7V1I<V-O=F5R)RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(%!%05(Z.G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1P;F%M92`]("1T:&ES+3Y?<F5G
M:7-T<GDM/G!A<G-E4&%C:V%G94YA;64H)'!A<F%M+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]N9FEG+3YG970H)V1E9F%U;'1?
M8VAA;FYE;"<I*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(%!%05(Z.G!O
M<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO
M;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7V1O=VYL;V%D97(M/FQO9R@P+"`G0VAA;FYE;"`B)R`N("1P87)S
M961;)V-H86YN96PG72`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("<B(&ES(&YO="!I;FET:6%L:7IE9"P@=7-E("<@+@T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G(G!E87(@8VAA;FYE;"UD:7-C;W9E
M<B`G("X@)'!A<G-E9%LG8VAA;FYE;"==("X@)R(@=&\@:6YI=&EA;&EZ92<@
M+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;W(@<&5A<B!C
M;VYF:6<M<V5T(&%U=&]?9&ES8V]V97(@,2<I.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1P
M;F%M92DI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T
M:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]D;W=N;&]A9&5R+3YL;V<H,"P@)'!N86UE+3YG971-97-S86=E*"DI
M.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M(&EF("AI<U]A<G)A>2@D<&%R86TI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D<&%R86T@/2`D=&AI<RT^7W)E9VES=')Y+3YP87)S961086-K86=E
M3F%M951O4W1R:6YG*"1P87)A;2D[#0H@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@)&5R<B`](%!%05(Z.G)A:7-E17)R;W(H
M)VEN=F%L:60@<&%C:V%G92!N86UE+W!A8VMA9V4@9FEL92`B)R`N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D<&%R86T@+B`G(B<I.PT*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W9A;&ED(#T@9F%L<V4[#0H@("`@("`@("`@
M("`@("`@("`@(')E='5R;B`D97)R.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7V1O=VYL;V%D97(M/FQO9R@P+"`D<&YA;64M/F=E=$UE<W-A9V4H
M*2D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1E<G(@
M/2!014%2.CIR86ES945R<F]R*"=I;G9A;&ED('!A8VMA9V4@;F%M92]P86-K
M86=E(&9I;&4@(B<@+@T*("`@("`@("`@("`@("`@("`@("`D<&%R86T@+B`G
M(B<I.PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L:60@/2!F86QS93L-
M"B`@("`@("`@("`@("`@("!R971U<FX@)&5R<CL-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?='EP92DI
M('L-"B`@("`@("`@("`@("1T:&ES+3Y?='EP92`]("=X;6QR<&,G.PT*("`@
M("`@("!]#0H@("`@("`@("1T:&ES+3Y?<&%R<V5D;F%M92`]("1P;F%M93L-
M"B`@("`@("`@:68@*&ES<V5T*"1P;F%M95LG<W1A=&4G72DI('L-"B`@("`@
M("`@("`@("1T:&ES+3Y?97AP;&EC:713=&%T92`]("1P;F%M95LG<W1A=&4G
M73L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1T:&ES+3Y?97AP
M;&EC:713=&%T92`](&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI
M<W-E="@D<&YA;65;)V=R;W5P)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^
M7V5X<&QI8VET1W)O=7`@/2!T<G5E.PT*("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@)'1H:7,M/E]E>'!L:6-I=$=R;W5P(#T@9F%L<V4[#0H@("`@
M("`@('T-"B`@("`@("`@)&EN9F\@/2`D=&AI<RT^7V1O=VYL;V%D97(M/E]G
M971086-K86=E1&]W;FQO8615<FPH)'!N86UE*3L-"B`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)&EN9F\I*2![#0H@("`@("`@("`@("!I9B`H)'!N86UE
M6R=C:&%N;F5L)UT@/3T@)W!E87(N<&AP+FYE="<I('L-"B`@("`@("`@("`@
M("`@("`O+R!T<GD@<&5C;`T*("`@("`@("`@("`@("`@("1P;F%M95LG8VAA
M;FYE;"==(#T@)W!E8VPN<&AP+FYE="<[#0H@("`@("`@("`@("`@("`@:68@
M*"1T97-T(#T@)'1H:7,M/E]D;W=N;&]A9&5R+3Y?9V5T4&%C:V%G941O=VYL
M;V%D57)L*"1P;F%M92DI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%0
M14%2.CII<T5R<F]R*"1T97-T*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)&EN9F\@/2!014%2.CIR86ES945R<F]R*"1I;F9O+3YG971-97-S86=E
M*"D@+B`G("T@<&%C:V%G92`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W)E9VES=')Y+3YP87)S961086-K86=E3F%M951O4W1R
M:6YG*"1P;F%M92P@=')U92D@+@T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("<@8V%N(&)E(&EN<W1A;&QE9"!W:71H(")P96-L(&EN<W1A;&P@)R`N
M("1P;F%M95LG<&%C:V%G92==("X-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G(B<I.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)'!N86UE6R=C:&%N;F5L)UT@/2`G<&5A
M<BYP:'`N;F5T)SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1P;F%M95LG
M8VAA;FYE;"==(#T@)W!E87(N<&AP+FYE="<[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N("1I;F9O.PT*
M("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?<F%W<&%C:V%G969I;&4@/2`D
M:6YF;ULG<F%W)UT[#0H@("`@("`@("1R970@/2`D=&AI<RT^7V%N86QY>F5$
M;W=N;&]A9%523"@D:6YF;RP@)'!A<F%M+"`D<&YA;64I.PT*("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D<F5T*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M("1R970[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1R970I('L-"B`@("`@
M("`@("`@("1T:&ES+3Y?9&]W;FQO86154DP@/2`D<F5T.PT*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?=F%L:60@/2`H8F]O;"D@)')E=#L-"B`@("`@
M("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!A<G)A>2!O
M=71P=70@;V8@<&%C:V%G92YG971$;W=N;&]A9%523`T*("`@("`J($!P87)A
M;2!S=')I;F=\87)R87E\;V)J96-T(&EN9F]R;6%T:6]N(&9O<B!D971E8W1I
M;F<@<&%C:V%G97,@=&\@8F4@9&]W;FQO861E9"P@86YD#0H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@9F]R(&5R<F]R<PT*("`@("`J($!P
M87)A;2!A<G)A>2!N86UE(&EN9F]R;6%T:6]N(&]F('1H92!P86-K86=E#0H@
M("`@("H@0'!A<F%M(&%R<F%Y?&YU;&P@<&%C:V%G97,@=&\@8F4@9&]W;FQO
M861E9`T*("`@("`J($!P87)A;2!B;V]L(&ES('1H:7,@86X@;W!T:6]N86P@
M9&5P96YD96YC>3\-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!?86YA;'EZ941O=VYL;V%D55),*"1I;F9O+"`D<&%R
M86TL("1P;F%M92P@)'!A<F%M<R`](&YU;&PL("1O<'1I;VYA;"`](&9A;'-E
M*0T*("`@('L-"B`@("`@("`@:68@*"%I<U]S=')I;F<H)'!A<F%M*2`F)B!0
M14%27T1O=VYL;V%D97)?4&%C:V%G93HZ=VEL;$1O=VYL;V%D*"1P87)A;2P@
M)'!A<F%M<RDI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H(21I;F9O*2![#0H@("`@("`@("`@("!I9B`H
M(6ES7W-T<FEN9R@D<&%R86TI*2![#0H@("`@("`@("`@("`@("`@)'-A=F5P
M87)A;2`]("(L(&-A;FYO="!D;W=N;&]A9"!<(B1P87)A;5PB(CL-"B`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)'-A=F5P87)A;2`]
M("<G.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@+R\@;F\@<F5L96%S
M97,@97AI<W0-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"=.;R!R96QE87-E<R!F;W(@<&%C:V%G92`B)R`N#0H@("`@("`@("`@("`@
M("`@)'1H:7,M/E]R96=I<W1R>2T^<&%R<V5D4&%C:V%G94YA;654;U-T<FEN
M9R@D<&YA;64L('1R=64I("X@)R(@97AI<W0G("X@)'-A=F5P87)A;2D[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*'-T<G1O;&]W97(H)&EN9F];)VEN9F\G
M72T^9V5T0VAA;FYE;"@I*2`A/2!S=')T;VQO=V5R*"1P;F%M95LG8VAA;FYE
M;"==*2D@>PT*("`@("`@("`@("`@)&5R<B`](&9A;'-E.PT*("`@("`@("`@
M("`@:68@*"1P;F%M95LG8VAA;FYE;"==(#T]("=P96-L+G!H<"YN970G*2![
M#0H@("`@("`@("`@("`@("`@:68@*"1I;F9O6R=I;F9O)UTM/F=E=$-H86YN
M96PH*2`A/2`G<&5A<BYP:'`N;F5T)RD@>PT*("`@("`@("`@("`@("`@("`@
M("`D97)R(#T@=')U93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!](&5L<V5I9B`H)&EN9F];)VEN9F\G72T^9V5T0VAA;FYE;"@I(#T]("=P
M96-L+G!H<"YN970G*2![#0H@("`@("`@("`@("`@("`@:68@*"1P;F%M95LG
M8VAA;FYE;"==("$]("=P96%R+G!H<"YN970G*2![#0H@("`@("`@("`@("`@
M("`@("`@("1E<G(@/2!T<G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)&5R<B`]('1R=64[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)&5R<BD@>PT*("`@
M("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=314-54DE4
M62!%4E)/4CH@<&%C:V%G92!I;B!C:&%N;F5L("(G("X@)'!N86UE6R=C:&%N
M;F5L)UT@+@T*("`@("`@("`@("`@("`@("`@("`G(B!R971R:65V960@86YO
M=&AE<B!C:&%N;F5L7"=S(&YA;64@9F]R(&1O=VYL;V%D(2`H(B<@+@T*("`@
M("`@("`@("`@("`@("`@("`D:6YF;ULG:6YF;R==+3YG971#:&%N;F5L*"D@
M+B`G(BDG*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H(6ES<V5T*"1I;F9O6R=U<FPG72DI('L-"B`@("`@("`@("`@("1I;G-T
M96%D(#T@("<L('=I;&P@:6YS=&5A9"!D;W=N;&]A9"!V97)S:6]N("<@+B`D
M:6YF;ULG=F5R<VEO;B==("X-"B`@("`@("`@("`@("`@("`@("`@("`@("<L
M('-T86)I;&ET>2`B)R`N("1I;F9O6R=I;F9O)UTM/F=E=%-T871E*"D@+B`G
M(B<[#0H@("`@("`@("`@("`O+R!R96QE87-E<R!E>&ES="P@8G5T('=E(&9A
M:6QE9"!T;R!G970@86YY#0H@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/E]D;W=N;&]A9&5R+3Y?;W!T:6]N<ULG9F]R8V4G72DI('L-"B`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)'!N86UE6R=V97)S:6]N)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("1V<R`]("<L('9E<G-I;VX@(B<@+B`D<&YA;65;
M)W9E<G-I;VXG72`N("<B)SL-"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H
M:7-S970H)'!N86UE6R=S=&%T92==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`D=G,@/2`G+"!S=&%B:6QI='D@(B<@+B`D<&YA;65;)W-T871E)UT@+B`G
M(B<[#0H@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1P87)A;2`]/2`G9&5P
M96YD96YC>2<I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%C;&%S<U]E
M>&ES=',H)U!%05)?0V]M;6]N)RDI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@(')E<75I<F5?;VYC92`G4$5!4B]#;VUM;VXN<&AP)SL-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H(6EN7V%R
M<F%Y*"1I;F9O6R=I;F9O)UTM/F=E=%-T871E*"DL#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@(%!%05)?0V]M;6]N.CIB971T97)3=&%T97,H)'1H:7,M
M/E]C;VYF:6<M/F=E="@G<')E9F5R<F5D7W-T871E)RDL('1R=64I*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1O<'1I;VYA;"D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("\O(&1O;B=T('-P:70@;W5T(&-O
M;F9U<VEN9R!E<G)O<B!M97-S86=E#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?9&]W;FQO861E<BT^7V=E=%!A8VMA9V5$
M;W=N;&]A9%5R;"@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH)W!A8VMA9V4G(#T^("1P;F%M95LG<&%C:V%G92==+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8VAA;FYE;"<@/3X@
M)'!N86UE6R=C:&%N;F5L)UTL#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=V97)S:6]N)R`]/B`D:6YF;ULG=F5R<VEO;B==*2D[
M#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D=G,@/2`G('=I=&AI;B!P<F5F97)R960@<W1A=&4@(B<@+B`D
M=&AI<RT^7V-O;F9I9RT^9V5T*"=P<F5F97)R961?<W1A=&4G*2`N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)R(G.PT*("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%C
M;&%S<U]E>&ES=',H)U!%05)?1&5P96YD96YC>3(G*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]$97!E;F1E
M;F-Y,BYP:'`G.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"1O<'1I;VYA;"D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("\O(&1O;B=T('-P:70@;W5T(&-O;F9U<VEN
M9R!E<G)O<B!M97-S86=E#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?9&]W;FQO861E<BT^7V=E=%!A8VMA9V5$;W=N;&]A
M9%5R;"@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH
M)W!A8VMA9V4G(#T^("1P;F%M95LG<&%C:V%G92==+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G8VAA;FYE;"<@/3X@)'!N86UE
M6R=C:&%N;F5L)UTL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=V97)S:6]N)R`]/B`D:6YF;ULG=F5R<VEO;B==*2D[#0H@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D=G,@/2!014%27T1E<&5N9&5N8WDR.CI?9V5T17AT<F%3=')I;F<H)'!N
M86UE*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("1I;G-T96%D(#T@)R<[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`D=G,@/2`G('=I=&AI;B!P<F5F
M97)R960@<W1A=&4@(B<@+B`D=&AI<RT^7V-O;F9I9RT^9V5T*`T*("`@("`@
M("`@("`@("`@("`@("`@("`@)W!R969E<G)E9%]S=&%T92<I("X@)R(G.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?9&]W;FQO861E<BT^;&]G*#$L("=705).24Y'.B!F86EL960@=&\@
M9&]W;FQO860@)R`N("1P;F%M95LG8VAA;FYE;"==("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("<O)R`N("1P;F%M95LG<&%C:V%G92==("X@)'9S("X@
M)&EN<W1E860I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`O+R!D;W=N;&]A9"!T:&4@;&%T97-T(')E;&5A<V4-"B`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]D;W=N;&]A9&5R+3Y?9V5T4&%C:V%G941O
M=VYL;V%D57)L*`T*("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<&%C:V%G
M92<@/3X@)'!N86UE6R=P86-K86=E)UTL#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("=C:&%N;F5L)R`]/B`D<&YA;65;)V-H86YN96PG72P-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W9E<G-I;VXG(#T^("1I;F9O6R=V97)S
M:6]N)UTI*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@+R\@8V]N<W1R=6-T(&AE;'!F=6P@97)R;W(@;65S<V%G90T*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D<&YA;65;)W9E<G-I;VXG72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@)'9S(#T@)RP@=F5R<VEO;B`B)R`N("1P;F%M
M95LG=F5R<VEO;B==("X@)R(G.PT*("`@("`@("`@("`@("`@('T@96QS96EF
M("AI<W-E="@D<&YA;65;)W-T871E)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("1V<R`]("<L('-T86)I;&ET>2`B)R`N("1P;F%M95LG<W1A=&4G72`N
M("<B)SL-"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)'!A<F%M(#T]("=D
M97!E;F1E;F-Y)RD@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6-L87-S
M7V5X:7-T<R@G4$5!4E]#;VUM;VXG*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@<F5Q=6ER95]O;F-E("=014%2+T-O;6UO;BYP:'`G.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:6Y?
M87)R87DH)&EN9F];)VEN9F\G72T^9V5T4W1A=&4H*2P-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@4$5!4E]#;VUM;VXZ.F)E='1E<E-T871E<R@D=&AI
M<RT^7V-O;F9I9RT^9V5T*"=P<F5F97)R961?<W1A=&4G*2P@=')U92DI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&]P=&EO;F%L*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@9&]N)W0@<W!I="!O=70@
M8V]N9G5S:6YG(&5R<F]R(&UE<W-A9V4L(&%N9"!D;VXG="!D:64@;VX-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!O<'1I;VYA;"!D97`@9F%I
M;'5R92$-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]D;W=N;&]A9&5R+3Y?9V5T4&%C:V%G941O=VYL;V%D57)L*`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<&%C:V%G92<@
M/3X@)'!N86UE6R=P86-K86=E)UTL#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=C:&%N;F5L)R`]/B`D<&YA;65;)V-H86YN96PG
M72P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W9E
M<G-I;VXG(#T^("1I;F9O6R=V97)S:6]N)UTI*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("1V<R`]("<@
M=VET:&EN('!R969E<G)E9"!S=&%T92`B)R`N("1T:&ES+3Y?8V]N9FEG+3YG
M970H)W!R969E<G)E9%]S=&%T92<I("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G(B<[#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!
M4E]$97!E;F1E;F-Y,B<I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<F5Q=6ER95]O;F-E("=014%2+T1E<&5N9&5N8WDR+G!H<"<[#0H@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H)&]P=&EO;F%L*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+R\@9&]N)W0@<W!I="!O=70@8V]N9G5S:6YG(&5R<F]R(&UE<W-A9V4L
M(&%N9"!D;VXG="!D:64@;VX-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`O+R!O<'1I;VYA;"!D97`@9F%I;'5R92$-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]D;W=N;&]A9&5R+3Y?9V5T4&%C
M:V%G941O=VYL;V%D57)L*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@G<&%C:V%G92<@/3X@)'!N86UE6R=P86-K86=E)UTL#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=C:&%N;F5L
M)R`]/B`D<&YA;65;)V-H86YN96PG72P-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W9E<G-I;VXG(#T^("1I;F9O6R=V97)S:6]N
M)UTI*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1V<R`](%!%05)?1&5P96YD96YC>3(Z.E]G971%>'1R
M85-T<FEN9R@D<&YA;64I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)'9S
M(#T@)R!W:71H:6X@<')E9F5R<F5D('-T871E("(G("X@)'1H:7,M/E]D;W=N
M;&]A9&5R+3YC;VYF:6<M/F=E="@-"B`@("`@("`@("`@("`@("`@("`@("`@
M("=P<F5F97)R961?<W1A=&4G*2`N("<B)SL-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@)&]P=&EO;G,@/2`D=&AI<RT^7V1O=VYL;V%D
M97(M/F=E=$]P=&EO;G,H*3L-"B`@("`@("`@("`@("`@("`O+R!T:&ES(&ES
M(&]N;'D@<V5T(&)Y('1H92`B9&]W;FQO860M86QL(B!C;VUM86YD#0H@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=I9VYO<F5P<F5F97)R
M961?<W1A=&4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)&5R<B`](%!%
M05(Z.G)A:7-E17)R;W(H#0H@("`@("`@("`@("`@("`@("`@("`@("`G1F%I
M;&5D('1O(&1O=VYL;V%D("<@+B`D=&AI<RT^7W)E9VES=')Y+3YP87)S9610
M86-K86=E3F%M951O4W1R:6YG*`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y*"=C:&%N;F5L)R`]/B`D<&YA;65;)V-H86YN96PG72P@)W!A
M8VMA9V4G(#T^("1P;F%M95LG<&%C:V%G92==*2P-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@=')U92D-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`N("1V<R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`G+"!L871E
M<W0@<F5L96%S92!I<R!V97)S:6]N("<@+B`D:6YF;ULG=F5R<VEO;B==("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("<L('-T86)I;&ET>2`B)R`N("1I
M;F9O6R=I;F9O)UTM/F=E=%-T871E*"D@+B`G(BP@=7-E("(G("X-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A
M8VMA9V5.86UE5&]3=')I;F<H#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH)V-H86YN96PG(#T^("1P;F%M95LG8VAA;FYE;"==+"`G<&%C
M:V%G92<@/3X@)'!N86UE6R=P86-K86=E)UTL#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W9E<G-I;VXG(#T^("1I;F9O6R=V97)S:6]N)UTI*2`N
M("<B('1O(&EN<W1A;&PG+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%!%05)?1$]73DQ/041%4E]004-+04=%7U-4051%*3L-"B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("1E<G([#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("1E<G(@/2!014%2.CIR86ES945R<F]R*`T*("`@("`@
M("`@("`@("`@("`@("`G1F%I;&5D('1O(&1O=VYL;V%D("<@+B`D=&AI<RT^
M7W)E9VES=')Y+3YP87)S961086-K86=E3F%M951O4W1R:6YG*`T*("`@("`@
M("`@("`@("`@("`@("`@("`@87)R87DH)V-H86YN96PG(#T^("1P;F%M95LG
M8VAA;FYE;"==+"`G<&%C:V%G92<@/3X@)'!N86UE6R=P86-K86=E)UTI+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('1R=64I#0H@("`@("`@("`@
M("`@("`@("`@("`N("1V<R`N#0H@("`@("`@("`@("`@("`@("`@("<L(&QA
M=&5S="!R96QE87-E(&ES('9E<G-I;VX@)R`N("1I;F9O6R=V97)S:6]N)UT@
M+@T*("`@("`@("`@("`@("`@("`@("`G+"!S=&%B:6QI='D@(B<@+B`D:6YF
M;ULG:6YF;R==+3YG9713=&%T92@I("X@)R(L('5S92`B)R`N#0H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA9V5.
M86UE5&]3=')I;F<H#0H@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G
M8VAA;FYE;"<@/3X@)'!N86UE6R=C:&%N;F5L)UTL("=P86-K86=E)R`]/B`D
M<&YA;65;)W!A8VMA9V4G72P-"B`@("`@("`@("`@("`@("`@("`@("`@("=V
M97)S:6]N)R`]/B`D:6YF;ULG=F5R<VEO;B==*2D@+B`G(B!T;R!I;G-T86QL
M)RD[#0H@("`@("`@("`@("`@("`@<F5T=7)N("1E<G([#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1I;F9O.PT*("`@('T-
M"GT-"C\^#0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]487-K````````````
M````````````````````````````````````````````````````````````
M```````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q
M,#4Q-30S,S<S,2`P,C`P,S8`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]0
M14%2+U1A<VLO56YI>&5O;```````````````````````````````````````
M`````````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S,Q(#`R,30V,0`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+U!%05(O5&%S:R]5;FEX96]L+W)W+G!H<```````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,S-C<@,3`U,34T,S,W,S$@
M,#(R-S$R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP#0HO*BH-"B`J(#QT87-K<SIU;FEX96]L/B`M(')E860O=W)I
M=&4@=F5R<VEO;@T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*
M("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E
M<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I
M;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO
M=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N
M='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H
M92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR
M;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N
M<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@
M(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP
M+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P
M#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S
M7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@
M)$ED.B!R=RYP:'`L=B`Q+C0@,C`P-B\P,2\P-B`P-#HT-SHS-R!C96QL;V<@
M17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC
M92!296QE87-E(#$N-"XP83$P#0H@*B\-"B\J*@T*("H@0F%S92!C;&%S<PT*
M("HO#0IR97%U:7)E7V]N8V4@)U!%05(O5&%S:R]5;FEX96]L+G!H<"<[#0HO
M*BH-"B`J($%B<W1R86-T<R!T:&4@=6YI>&5O;"!T87-K('AM;"X-"B`J($!C
M871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H
M;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y
M<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@
M("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC
M96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`
M;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*
M("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@
M,2XT+C!A,3`-"B`J+PT*8VQA<W,@4$5!4E]487-K7U5N:7AE;VQ?<G<@97AT
M96YD<R!014%27U1A<VM?56YI>&5O;`T*>PT*("`@(&9U;F-T:6]N(%!%05)?
M5&%S:U]5;FEX96]L7W)W*"8D<&MG+"`F)&-O;F9I9RP@)B1L;V=G97(L("1F
M:6QE6&UL*0T*("`@('L-"B`@("`@("`@<&%R96YT.CI014%27U1A<VM?0V]M
M;6]N*"1C;VYF:6<L("1L;V=G97(L(%!%05)?5$%32U]004-+04=%*3L-"B`@
M("`@("`@)'1H:7,M/E]C;VYT96YT<R`]("1F:6QE6&UL.PT*("`@("`@("`D
M=&AI<RT^7W!K9R`]("8D<&MG.PT*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]
M(&%R<F%Y*"D[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@=F%L:61A=&4H*0T*
M("`@('L-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@9V5T3F%M92@I#0H@("`@>PT*("`@("`@("!R971U<FX@)W5N:7AE
M;VPG.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=%AM;"@I#0H@("`@>PT*
M("`@("`@("!R971U<FX@)R<[#0H@("`@?0T*?0T*/SX`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]014%2+U1A<VLO5VEN9&]W<V5O;```````````````````
M`````````````````````````````````````````````````#`P,#<U-2``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S,Q(#`R,C$W
M,``@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O5&%S:R]7:6YD;W=S
M96]L+W)W+G!H<```````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,T,30@
M,3`U,34T,S,W,S$@,#(S-#$R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP#0HO*BH-"B`J(#QT87-K<SIW:6YD;W=S
M96]L/B`M(')E860O=W)I=&4@=F5R<VEO;@T*("H-"B`J(%!(4"!V97)S:6]N
M<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I
M<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*
M("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A
M(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T
M;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@
M82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@
M82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-
M"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A
M=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P
M-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V
M97)S:6]N("`@($-64SH@)$ED.B!R=RYP:'`L=B`Q+C0@,C`P-B\P,2\P-B`P
M-#HT-SHS-R!C96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P
M96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE
M(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP83$P#0H@*B\-"B\J*@T*
M("H@0F%S92!C;&%S<PT*("HO#0IR97%U:7)E7V]N8V4@)U!%05(O5&%S:R]7
M:6YD;W=S96]L+G!H<"<[#0HO*BH-"B`J($%B<W1R86-T<R!T:&4@=VEN9&]W
M<V5O;"!T87-K('AM;"X-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K
M86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL
M;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0
M($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@
M(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP
M:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A
M:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,3`-"B`J+PT*8VQA<W,@4$5!
M4E]487-K7U=I;F1O=W-E;VQ?<G<@97AT96YD<R!014%27U1A<VM?5VEN9&]W
M<V5O;`T*>PT*("`@(&9U;F-T:6]N(%!%05)?5&%S:U]7:6YD;W=S96]L7W)W
M*"8D<&MG+"`F)&-O;F9I9RP@)B1L;V=G97(L("1F:6QE6&UL*0T*("`@('L-
M"B`@("`@("`@<&%R96YT.CI014%27U1A<VM?0V]M;6]N*"1C;VYF:6<L("1L
M;V=G97(L(%!%05)?5$%32U]004-+04=%*3L-"B`@("`@("`@)'1H:7,M/E]C
M;VYT96YT<R`]("1F:6QE6&UL.PT*("`@("`@("`D=&AI<RT^7W!K9R`]("8D
M<&MG.PT*("`@("`@("`D=&AI<RT^7W!A<F%M<R`](&%R<F%Y*"D[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@=F%L:61A=&4H*0T*("`@('L-"B`@("`@("`@
M<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T3F%M92@I
M#0H@("`@>PT*("`@("`@("!R971U<FX@)W=I;F1O=W-E;VPG.PT*("`@('T-
M"@T*("`@(&9U;F-T:6]N(&=E=%AM;"@I#0H@("`@>PT*("`@("`@("!R971U
M<FX@)R<[#0H@("`@?0T*?0T*/SX`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+U1A<VLO4F5P;&%C90``````
M````````````````````````````````````````````````````````````
M`````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U
M-#,S-S,Q(#`R,30Q,0`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O
M5&%S:R]297!L86-E+W)W+G!H<```````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#,W-30@,3`U,34T,S,W,S$@,#(R-C0R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP#0HO*BH-"B`J(#QT
M87-K<SIR97!L86-E/B`M(')E860O=W)I=&4@=F5R<VEO;@T*("H-"B`J(%!(
M4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R
M8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@
M;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@
M<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E
M('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-
M"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@
M;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R
M>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@
M($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@
M(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P
M.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S
M+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!R=RYP:'`L=B`Q+C,@,C`P
M-B\P,2\P-B`P-#HT-SHS-R!C96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@
M("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP83$P#0H@
M*B\-"B\J*@T*("H@0F%S92!C;&%S<PT*("HO#0IR97%U:7)E7V]N8V4@)U!%
M05(O5&%S:R]297!L86-E+G!H<"<[#0HO*BH-"B`J($%B<W1R86-T<R!T:&4@
M<F5P;&%C92!T87-K('AM;"X-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P
M86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC
M96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@
M4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N
M("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A
M<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@
M879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,3`-"B`J+PT*8VQA<W,@
M4$5!4E]487-K7U)E<&QA8V5?<G<@97AT96YD<R!014%27U1A<VM?4F5P;&%C
M90T*>PT*("`@(&9U;F-T:6]N(%!%05)?5&%S:U]297!L86-E7W)W*"8D<&MG
M+"`F)&-O;F9I9RP@)B1L;V=G97(L("1F:6QE6&UL*0T*("`@('L-"B`@("`@
M("`@<&%R96YT.CI014%27U1A<VM?0V]M;6]N*"1C;VYF:6<L("1L;V=G97(L
M(%!%05)?5$%32U]004-+04=%*3L-"B`@("`@("`@)'1H:7,M/E]C;VYT96YT
M<R`]("1F:6QE6&UL.PT*("`@("`@("`D=&AI<RT^7W!K9R`]("8D<&MG.PT*
M("`@("`@("`D=&AI<RT^7W!A<F%M<R`](&%R<F%Y*"D[#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@=F%L:61A=&4H*0T*("`@('L-"B`@("`@("`@<F5T=7)N
M("1T:&ES+3YV86QI9&%T95AM;"@D=&AI<RT^7W!K9RP@)'1H:7,M/E]P87)A
M;7,L("1T:&ES+3YC;VYF:6<L("1T:&ES+3Y?8V]N=&5N=',I.PT*("`@('T-
M"@T*("`@(&9U;F-T:6]N('-E=$EN9F\H)&9R;VTL("1T;RP@)'1Y<&4I#0H@
M("`@>PT*("`@("`@("`D=&AI<RT^7W!A<F%M<R`](&%R<F%Y*"=A='1R:6)S
M)R`]/B!A<G)A>2@G9G)O;2<@/3X@)&9R;VTL("=T;R<@/3X@)'1O+"`G='EP
M92<@/3X@)'1Y<&4I*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971.86UE
M*"D-"B`@("![#0H@("`@("`@(')E='5R;B`G<F5P;&%C92<[#0H@("`@?0T*
M#0H@("`@9G5N8W1I;VX@9V5T6&UL*"D-"B`@("![#0H@("`@("`@(')E='5R
M;B`D=&AI<RT^7W!A<F%M<SL-"B`@("!]#0I]#0H_/@``````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+U1A<VLO
M4&]S=&EN<W1A;&QS8W)I<'0`````````````````````````````````````
M`````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P,#`P(#$P-3$U-#,S-S,Q(#`R,S4W-P`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+U!%05(O5&%S:R]0;W-T:6YS=&%L;'-C<FEP="]R=RYP:'``````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,30S-34@,3`U,34T,S,W,S$@,#(U,#(W`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M#0HO*BH-"B`J(#QT87-K<SIP;W-T:6YS=&%L;'-C<FEP=#X@+2!R96%D+W=R
M:71E('9E<G-I;VX-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-
M"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V
M97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A
M:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL
M;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T
M:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H
M<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E
M;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA
M=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@
M("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H
M<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U
M<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z
M("1)9#H@<G<N<&AP+'8@,2XQ,2`R,#`V+S`Q+S`V(#`T.C0W.C,W(&-E;&QO
M9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P
M86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I
M;F-E(%)E;&5A<V4@,2XT+C!A,3`-"B`J+PT*+RHJ#0H@*B!"87-E(&-L87-S
M#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!4B]487-K+U!O<W1I;G-T86QL<V-R
M:7!T+G!H<"<[#0HO*BH-"B`J($%B<W1R86-T<R!T:&4@<&]S=&EN<W1A;&QS
M8W)I<'0@9FEL92!T87-K('AM;"X-"B`J($!C871E9V]R>2`@('!E87(-"B`J
M($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R
M(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4
M:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S
M:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA
M<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,3`-"B`J+PT*8VQA
M<W,@4$5!4E]487-K7U!O<W1I;G-T86QL<V-R:7!T7W)W(&5X=&5N9',@4$5!
M4E]487-K7U!O<W1I;G-T86QL<V-R:7!T#0I[#0H@("`@+RHJ#0H@("`@("H@
M<&%R96YT('!A8VMA9V4@9FEL92!O8FIE8W0-"B`@("`@*@T*("`@("`J($!V
M87(@4$5!4E]086-K86=E1FEL95]V,E]R=PT*("`@("`J+PT*("`@('9A<B`D
M7W!K9SL-"B`@("`O*BH-"B`@("`@*B!%;G1E<B!D97-C<FEP=&EO;B!H97)E
M+BXN#0H@("`@("H-"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E1FEL95]V
M,E]R=R`D<&MG#0H@("`@("H@0'!A<F%M(%!%05)?0V]N9FEG("1C;VYF:6<-
M"B`@("`@*B!`<&%R86T@4$5!4E]&<F]N=&5N9"`D;&]G9V5R#0H@("`@("H@
M0'!A<F%M(&%R<F%Y("1F:6QE6&UL#0H@("`@("H@0')E='5R;B!014%27U1A
M<VM?4&]S=&EN<W1A;&QS8W)I<'1?<G<-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!014%27U1A<VM?4&]S=&EN<W1A;&QS8W)I<'1?<G<H)B1P:V<L("8D8V]N
M9FEG+"`F)&QO9V=E<BP@)&9I;&58;6PI#0H@("`@>PT*("`@("`@("!P87)E
M;G0Z.E!%05)?5&%S:U]#;VUM;VXH)&-O;F9I9RP@)&QO9V=E<BP@4$5!4E]4
M05-+7U!!0TM!1T4I.PT*("`@("`@("`D=&AI<RT^7V-O;G1E;G1S(#T@)&9I
M;&58;6P[#0H@("`@("`@("1T:&ES+3Y?<&MG(#T@)B1P:V<[#0H@("`@("`@
M("1T:&ES+3Y?<&%R86US(#T@87)R87DH*3L-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!V86QI9&%T92@I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M
M/G9A;&ED871E6&UL*"1T:&ES+3Y?<&MG+"`D=&AI<RT^7W!A<F%M<RP@)'1H
M:7,M/F-O;F9I9RP@)'1H:7,M/E]C;VYT96YT<RD[#0H@("`@?0T*#0H@("`@
M9G5N8W1I;VX@9V5T3F%M92@I#0H@("`@>PT*("`@("`@("!R971U<FX@)W!O
M<W1I;G-T86QL<V-R:7!T)SL-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!A
M9&0@82!S:6UP;&4@/'!A<F%M9W)O=7`^('1O('1H92!P;W-T+6EN<W1A;&P@
M<V-R:7!T#0H@("`@("H-"B`@("`@*B!/<F1E<B!I<R!S:6=N:69I8V%N="P@
M<V\@8V%L;"!T:&ES(&UE=&AO9"!I;B!T:&4@<V%M90T*("`@("`J('-E<75E
M;F-E('1H92!U<V5R<R!S:&]U;&0@<V5E('1H92!P87)A;6=R;W5P<RX@(%1H
M92`D<&%R86US#0H@("`@("H@<&%R86UE=&5R('-H;W5L9"!E:71H97(@8F4@
M=&AE(')E<W5L="!O9B!A(&-A;&P@=&\@>T!L:6YK(&=E=%!A<F%M*"E]#0H@
M("`@("H@;W(@86X@87)R87D@;V8@8V%L;',@=&\@9V5T4&%R86TH*2X-"B`@
M("`@*B`-"B`@("`@*B!5<V4@>T!L:6YK(&%D9$-O;F1I=&EO;E1Y<&5'<F]U
M<"@I?2!T;R!A9&0@82`\<&%R86UG<F]U<#X@8V]N=&%I;FEN9PT*("`@("`J
M(&$@/&-O;F1I=&EO;G1Y<&4^('1A9PT*("`@("`J($!P87)A;2!S=')I;F<@
M)&ED(#QP87)A;6=R;W5P/B!I9"!A<R!S965N(&)Y('1H92!S8W)I<'0-"B`@
M("`@*B!`<&%R86T@87)R87E\9F%L<V4@)'!A<F%M<R!A<G)A>2!O9B!G9710
M87)A;2@I(&-A;&QS+"!O<B!F86QS92!F;W(@;F\@<&%R86US#0H@("`@("H@
M0'!A<F%M('-T<FEN9WQF86QS92`D:6YS=')U8W1I;VYS#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@861D4&%R86U'<F]U<"@D:60L("1P87)A;7,@/2!F86QS
M92P@)&EN<W1R=6-T:6]N<R`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@
M*"1P87)A;7,@)B8@:7-S970H)'!A<F%M<ULP72D@)B8@(6ES<V5T*"1P87)A
M;7-;,5TI*2![#0H@("`@("`@("`@("`D<&%R86US(#T@)'!A<F%M<ULP73L-
M"B`@("`@("`@?0T*("`@("`@("`D<W1U9F8@/0T*("`@("`@("`@("`@87)R
M87DH#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]P:V<M/F=E=%1A<VMS3G,H
M*2`N("<Z:60G(#T^("1I9"P-"B`@("`@("`@("`@("D[#0H@("`@("`@(&EF
M("@D:6YS=')U8W1I;VYS*2![#0H@("`@("`@("`@("`D<W1U9F9;)'1H:7,M
M/E]P:V<M/F=E=%1A<VMS3G,H*2`N("<Z:6YS=')U8W1I;VYS)UT@/2`D:6YS
M=')U8W1I;VYS.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D<&%R86US*2![
M#0H@("`@("`@("`@("`D<W1U9F9;)'1H:7,M/E]P:V<M/F=E=%1A<VMS3G,H
M*2`N("<Z<&%R86TG72`]("1P87)A;7,[#0H@("`@("`@('T-"B`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)'1H:7,M/E]P:V<M/F=E=%1A<VMS3G,H*2`N("<Z
M<&%R86UG<F]U<"==6UT@/2`D<W1U9F8[#0H@("`@?0T*#0H@("`@+RHJ#0H@
M("`@("H@861D(&$@8V]M<&QE>"`\<&%R86UG<F]U<#X@=&\@=&AE('!O<W0M
M:6YS=&%L;"!S8W)I<'0@=VET:"!C;VYD:71I;VYS#0H@("`@("H-"B`@("`@
M*B!4:&ES(&EN<V5R=',@82`\<&%R86UG<F]U<#X@=VET:`T*("`@("`J#0H@
M("`@("H@3W)D97(@:7,@<VEG;FEF:6-A;G0L('-O(&-A;&P@=&AI<R!M971H
M;V0@:6X@=&AE('-A;64-"B`@("`@*B!S97%U96YC92!T:&4@=7-E<G,@<VAO
M=6QD('-E92!T:&4@<&%R86UG<F]U<',N("!4:&4@)'!A<F%M<PT*("`@("`J
M('!A<F%M971E<B!S:&]U;&0@96ET:&5R(&)E('1H92!R97-U;'0@;V8@82!C
M86QL('1O('M`;&EN:R!G971087)A;2@I?0T*("`@("`J(&]R(&%N(&%R<F%Y
M(&]F(&-A;&QS('1O(&=E=%!A<F%M*"DN#0H@("`@("H@#0H@("`@("H@57-E
M('M`;&EN:R!A9&1087)A;4=R;W5P*"E]('1O(&%D9"!A('-I;7!L92`\<&%R
M86UG<F]U<#X-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@)&ED(#QP
M87)A;6=R;W5P/B!I9"!A<R!S965N(&)Y('1H92!S8W)I<'0-"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1O;&1G<F]U<"`\<&%R86UG<F]U<#X@:60@;V8@=&AE
M('-E8W1I;VX@<F5F97)E;F-E9"!B>0T*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@(#QC;VYD:71I;VYT>7!E/@T*("`@("`J($!P87)A;2!S=')I
M;F<@)'!A<F%M(&YA;64@;V8@=&AE(#QP87)A;3X@9G)O;2!T:&4@;VQD97(@
M<V5C=&EO;B!R969E<F5N8V5D#0H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@8GD@/&-O;G1I=&EO;G1Y<&4^#0H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=F%L=64@=F%L=64@=&\@;6%T8V@@;V8@=&AE('!A<F%M971E<@T*("`@("`J
M($!P87)A;2!S=')I;F<@)&-O;F1I=&EO;G1Y<&4@;VYE(&]F("<])RP@)R$]
M)RP@)W!R96=?;6%T8V@G#0H@("`@("H@0'!A<F%M(&%R<F%Y?&9A;'-E("1P
M87)A;7,@87)R87D@;V8@9V5T4&%R86TH*2!C86QL<RP@;W(@9F%L<V4@9F]R
M(&YO('!A<F%M<PT*("`@("`J($!P87)A;2!S=')I;F=\9F%L<V4@)&EN<W1R
M=6-T:6]N<PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&%D9$-O;F1I=&EO;E1Y
M<&5'<F]U<"@D:60L("1O;&1G<F]U<"P@)'!A<F%M+"`D=F%L=64L("1C;VYD
M:71I;VYT>7!E(#T@)STG+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<&%R86US(#T@9F%L<V4L("1I;G-T<G5C=&EO;G,@/2!F86QS
M92D-"B`@("![#0H@("`@("`@(&EF("@D<&%R86US("8F(&ES<V5T*"1P87)A
M;7-;,%TI("8F("%I<W-E="@D<&%R86US6S%=*2D@>PT*("`@("`@("`@("`@
M)'!A<F%M<R`]("1P87)A;7-;,%T[#0H@("`@("`@('T-"B`@("`@("`@)'-T
M=69F(#T-"B`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&MG+3YG971487-K<TYS*"D@+B`G.FED)R`]/B`D:60L#0H@("`@
M("`@("`@("`I.PT*("`@("`@("!I9B`H)&EN<W1R=6-T:6]N<RD@>PT*("`@
M("`@("`@("`@)'-T=69F6R1T:&ES+3Y?<&MG+3YG971487-K<TYS*"D@+B`G
M.FEN<W1R=6-T:6]N<R==(#T@)&EN<W1R=6-T:6]N<SL-"B`@("`@("`@?0T*
M("`@("`@("`D<W1U9F9;)'1H:7,M/E]P:V<M/F=E=%1A<VMS3G,H*2`N("<Z
M;F%M92==(#T@)&]L9&=R;W5P("X@)SHZ)R`N("1P87)A;3L-"B`@("`@("`@
M)'-T=69F6R1T:&ES+3Y?<&MG+3YG971487-K<TYS*"D@+B`G.F-O;F1I=&EO
M;G1Y<&4G72`]("1C;VYD:71I;VYT>7!E.PT*("`@("`@("`D<W1U9F9;)'1H
M:7,M/E]P:V<M/F=E=%1A<VMS3G,H*2`N("<Z=F%L=64G72`]("1V86QU93L-
M"B`@("`@("`@:68@*"1P87)A;7,I('L-"B`@("`@("`@("`@("1S='5F9ELD
M=&AI<RT^7W!K9RT^9V5T5&%S:W-.<R@I("X@)SIP87)A;2==(#T@)'!A<F%M
M<SL-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7W!A<F%M<ULD=&AI<RT^
M7W!K9RT^9V5T5&%S:W-.<R@I("X@)SIP87)A;6=R;W5P)UU;72`]("1S='5F
M9CL-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G9718;6PH*0T*("`@('L-"B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?<&%R86US.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("`J(%5S92!T;R!S970@=7`@82!P87)A;2!T86<@9F]R('5S92!I
M;B!C<F5A=&EN9R!A('!A<F%M9W)O=7`-"B`@("`@*B!`<W1A=&EC#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@9V5T4&%R86TH)&YA;64L("1P<F]M<'0L("1T
M>7!E(#T@)W-T<FEN9R<L("1D969A=6QT(#T@;G5L;"D-"B`@("![#0H@("`@
M("`@(&EF("@D9&5F875L="`A/3T@;G5L;"D@>PT*("`@("`@("`@("`@<F5T
M=7)N(`T*("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P:V<M/F=E=%1A<VMS3G,H*2`N("<Z;F%M92<@/3X@)&YA;64L#0H@
M("`@("`@("`@("`@("`@)'1H:7,M/E]P:V<M/F=E=%1A<VMS3G,H*2`N("<Z
M<')O;7!T)R`]/B`D<')O;7!T+`T*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&MG+3YG971487-K<TYS*"D@+B`G.G1Y<&4G(#T^("1T>7!E+`T*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&MG+3YG971487-K<TYS*"D@+B`G.F1E9F%U
M;'0G(#T^("1D969A=6QT#0H@("`@("`@("`@("`I.PT*("`@("`@("!]#0H@
M("`@("`@(')E='5R;@T*("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P:V<M/F=E=%1A<VMS3G,H*2`N("<Z;F%M92<@/3X@
M)&YA;64L#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]P:V<M/F=E=%1A<VMS
M3G,H*2`N("<Z<')O;7!T)R`]/B`D<')O;7!T+`T*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<&MG+3YG971487-K<TYS*"D@+B`G.G1Y<&4G(#T^("1T>7!E
M+`T*("`@("`@("`@("`@*3L-"B`@("!]#0I]#0H_/@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+U1A<VLO0V]M;6]N+G!H<```````
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$U,#$Q(#$P-3$U-#,S
M-S,Q(#`R,C`U-``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`T*+RHJ#0H@*B!014%27U1A<VM?0V]M;6]N+"!B87-E
M(&-L87-S(&9O<B!I;G-T86QL97(@=&%S:W,-"B`J#0H@*B!02%`@=F5R<VEO
M;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@
M:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-
M"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M
M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@
M82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@
M=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD
M(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U
M(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R
M#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E
M879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P
M,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`
M=F5R<VEO;B`@("!#5E,Z("1)9#H@0V]M;6]N+G!H<"QV(#$N,34@,C`P-B\P
M,2\P-B`P-#HT-SHS-R!C96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@
M("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*
M+RHJ(T`K#0H@*B!%<G)O<B!C;V1E<R!F;W(@=&%S:R!V86QI9&%T:6]N(')O
M=71I;F5S#0H@*B\-"F1E9FEN92@G4$5!4E]405-+7T524D]27TY/05144DE"
M4R<L(#$I.PT*9&5F:6YE*"=014%27U1!4TM?15)23U)?34E34TE.1U]!5%12
M24(G+"`R*3L-"F1E9FEN92@G4$5!4E]405-+7T524D]27U=23TY'7T%45%))
M0E]604Q512<L(#,I.PT*9&5F:6YE*"=014%27U1!4TM?15)23U)?24Y604Q)
M1"<L(#0I.PT*+RHJ(T`M*B\-"F1E9FEN92@G4$5!4E]405-+7U!!0TM!1T4G
M+"`Q*3L-"F1E9FEN92@G4$5!4E]405-+7TE.4U1!3$PG+"`R*3L-"F1E9FEN
M92@G4$5!4E]405-+7U!!0TM!1T5!3D1)3E-404Q,)RP@,RD[#0HO*BH-"B`J
M($$@=&%S:R!I<R!A;B!O<&5R871I;VX@=&AA="!M86YI<'5L871E<R!T:&4@
M8V]N=&5N=',@;V8@82!F:6QE+@T*("H-"B`J(%-I;7!L92!T87-K<R!O<&5R
M871E(&]N(#$@9FEL92X@($UU;'1I<&QE('1A<VMS(&%R92!E>&5C=71E9"!A
M9G1E<B!A;&P@9FEL97,@:&%V92!B965N#0H@*B!P<F]C97-S960@86YD(&EN
M<W1A;&QE9"P@86YD(&%R92!D97-I9VYE9"!T;R!O<&5R871E(&]N(&%L;"!F
M:6QE<R!C;VYT86EN:6YG('1H92!T87-K+@T*("H@5&AE(%!O<W0M:6YS=&%L
M;"!S8W)I<'0@=&%S:R!S:6UP;'D@=&%K97,@861V86YT86=E(&]F('1H92!F
M86-T('1H870@:70@=VEL;"!B92!R=6X-"B`J(&%F=&5R(&EN<W1A;&QA=&EO
M;BP@<F5P;&%C92!I<R!A('-I;7!L92!T87-K+@T*("H-"B`J($-O;6)I;FEN
M9R!T87-K<R!I<R!P;W-S:6)L92P@8G5T(&]R9&5R:6YG(&ES('-I9VYI9FEC
M86YT+@T*("H-"B`J(#QF:6QE(&YA;64](G1E<W0N<&AP(B!R;VQE/2)P:'`B
M/@T*("H@(#QT87-K<SIR97!L86-E(&9R;VT](D!D871A+61I<D`B('1O/2)D
M871A7V1I<B(@='EP93TB<&5A<BUC;VYF:6<B+SX-"B`J("`\=&%S:W,Z<&]S
M=&EN<W1A;&QS8W)I<'0O/@T*("H@/"]F:6QE/@T*("H-"B`J(%1H:7,@=VEL
M;"!F:7)S="!R97!L86-E(&%N>2!I;G-T86YC92!O9B!`9&%T82UD:7)`(&EN
M('1H92!T97-T+G!H<"!F:6QE#0H@*B!W:71H('1H92!P871H('1O('1H92!C
M=7)R96YT(&1A=&$@9&ER96-T;W)Y+B`@5&AE;BP@:70@=VEL;"!I;F-L=61E
M('1H90T*("H@=&5S="YP:'`@9FEL92!A;F0@<G5N('1H92!S8W)I<'0@:70@
M8V]N=&%I;G,@=&\@8V]N9FEG=7)E('1H92!P86-K86=E('!O<W0M:6YS=&%L
M;&%T:6]N+@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@
M4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N
M;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-
M"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?
M,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S
M93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O
M<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@
M<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B!`86)S=')A8W0-"B`J+PT*8VQA
M<W,@4$5!4E]487-K7T-O;6UO;@T*>PT*("`@("\J*@T*("`@("`J(%9A;&ED
M('1Y<&5S(&9O<B!T:&ES('9E<G-I;VX@87)E("=S:6UP;&4G(&%N9"`G;75L
M=&EP;&4G#0H@("`@("H-"B`@("`@*B`M('-I;7!L92!T87-K<R!O<&5R871E
M(&]N('1H92!C;VYT96YT<R!O9B!A(&9I;&4@86YD('=R:71E(&]U="!C:&%N
M9V5S('1O(&1I<VL-"B`@("`@*B`M(&UU;'1I<&QE('1A<VMS(&]P97)A=&4@
M;VX@=&AE(&-O;G1E;G1S(&]F(&UA;GD@9FEL97,@86YD('=R:71E(&]U="!T
M:&4-"B`@("`@*B`@(&-H86YG97,@9&ER96-T;'D@=&\@9&ES:PT*("`@("`J
M#0H@("`@("H@0VAI;&0@=&%S:R!C;&%S<V5S(&UU<W0@;W9E<G)I9&4@=&AI
M<R!P<F]P97)T>2X-"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`T*("`@("`J
M+PT*("`@('9A<B`D='EP92`]("=S:6UP;&4G.PT*("`@("\J*@T*("`@("`J
M($1E=&5R;6EN97,@=VAI8V@@:6YS=&%L;"!P:&%S92!T:&ES('1A<VL@:7,@
M97AE8W5T960@=6YD97(-"B`@("`@*B\-"B`@("!V87(@)'!H87-E(#T@4$5!
M4E]405-+7TE.4U1!3$P[#0H@("`@+RHJ#0H@("`@("H@0&%C8V5S<R!P<F]T
M96-T960-"B`@("`@*B\-"B`@("!V87(@)&-O;F9I9SL-"B`@("`O*BH-"B`@
M("`@*B!`86-C97-S('!R;W1E8W1E9`T*("`@("`J+PT*("`@('9A<B`D<F5G
M:7-T<GD[#0H@("`@+RHJ#0H@("`@("H@0&%C8V5S<R!P<F]T96-T960-"B`@
M("`@*B\-"B`@("!V87(@)&QO9V=E<CL-"B`@("`O*BH-"B`@("`@*B!`86-C
M97-S('!R;W1E8W1E9`T*("`@("`J+PT*("`@('9A<B`D:6YS=&%L;'!H87-E
M.PT*("`@("\J*@T*("`@("`J($!P87)A;2!014%27T-O;F9I9PT*("`@("`J
M($!P87)A;2!014%27T-O;6UO;@T*("`@("`J+PT*("`@(&9U;F-T:6]N(%!%
M05)?5&%S:U]#;VUM;VXH)B1C;VYF:6<L("8D;&]G9V5R+"`D<&AA<V4I#0H@
M("`@>PT*("`@("`@("`D=&AI<RT^8V]N9FEG(#T@)B1C;VYF:6<[#0H@("`@
M("`@("1T:&ES+3YR96=I<W1R>2`]("8D8V]N9FEG+3YG971296=I<W1R>2@I
M.PT*("`@("`@("`D=&AI<RT^;&]G9V5R(#T@)B1L;V=G97([#0H@("`@("`@
M("1T:&ES+3YI;G-T86QL<&AA<V4@/2`D<&AA<V4[#0H@("`@("`@(&EF("@D
M=&AI<RT^='EP92`]/2`G;75L=&EP;&4G*2![#0H@("`@("`@("`@("`D1TQ/
M0D%,4ULG7U!%05)?5$%32U]03U-424Y35$%.0T53)UU;9V5T7V-L87-S*"1T
M:&ES*5U;72`]("8D=&AI<SL-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J
M*@T*("`@("`J(%9A;&ED871E('1H92!B87-I8R!C;VYT96YT<R!O9B!A('1A
M<VL@=&%G+@T*("`@("`J($!P87)A;2!014%27U!A8VMA9V5&:6QE7W8R#0H@
M("`@("H@0'!A<F%M(&%R<F%Y#0H@("`@("H@0'!A<F%M(%!%05)?0V]N9FEG
M#0H@("`@("H@0'!A<F%M(&%R<F%Y('1H92!E;G1I<F4@<&%R<V5D(#QF:6QE
M/B!T86<-"B`@("`@*B!`<F5T=7)N('1R=65\87)R87D@3VX@97)R;W(L(')E
M='5R;B!A;B!A<G)A>2!I;B!F;W)M870Z#0H@("`@("H@("`@87)R87DH4$5!
M4E]405-+7T524D]27S\_/ULL('!A<F%M,5U;+"!P87)A;3)=6RP@+BXN72D-
M"B`@("`@*@T*("`@("`J("`@($9O<B!014%27U1!4TM?15)23U)?34E34TE.
M1U]!5%1224(L('!A<W,@=&AE(&%T=')I8G5T92!N86UE(&EN#0H@("`@("H@
M("`@1F]R(%!%05)?5$%32U]%4E)/4E]74D].1U]!5%1224)?5D%,544L('!A
M<W,@=&AE(&%T=')I8G5T92!N86UE(&%N9"!A;B!A<G)A>0T*("`@("`J("`@
M(&]F(&QE9V%L('9A;'5E<R!I;@T*("`@("`J($!S=&%T:6,-"B`@("`@*B!`
M86)S=')A8W0-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!V86QI9%AM;"@D<&MG
M+"`D>&UL+"`F)&-O;F9I9RP@)&9I;&58;6PI#0H@("`@>PT*("`@('T-"@T*
M("`@("\J*@T*("`@("`J($EN:71I86QI>F4@82!T87-K(&EN<W1A;F-E('=I
M=&@@=&AE('!A<F%M971E<G,-"B`@("`@*B!`<&%R86T@87)R87D@<F%W+"!P
M87)S960@>&UL#0H@("`@("H@0'!A<F%M(&%R<F%Y(&%T=')I8G5T97,@9G)O
M;2!T:&4@/&9I;&4^('1A9R!C;VYT86EN:6YG('1H:7,@=&%S:PT*("`@("`J
M($!P87)A;2!S=')I;F=\;G5L;"!L87-T(&EN<W1A;&QE9"!V97)S:6]N(&]F
M('1H:7,@<&%C:V%G90T*("`@("`J($!A8G-T<F%C=`T*("`@("`J+PT*("`@
M(&9U;F-T:6]N(&EN:70H)'AM;"P@)&9I;&5!='1R:6)U=&5S+"`D;&%S=%9E
M<G-I;VXI#0H@("`@>PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($)E9VEN
M(&$@=&%S:R!P<F]C97-S:6YG('-E<W-I;VXN("!!;&P@;75L=&EP;&4@=&%S
M:W,@=VEL;"!B92!P<F]C97-S960@869T97(@96%C:"!F:6QE#0H@("`@("H@
M:&%S(&)E96X@<W5C8V5S<V9U;&QY(&EN<W1A;&QE9"P@86QL('-I;7!L92!T
M87-K<R!S:&]U;&0@<&5R9F]R;2!T:&5I<B!T87-K(&AE<F4@86YD#0H@("`@
M("H@<F5T=7)N(&%N>2!E<G)O<G,@=7-I;F<@=&AE(&-U<W1O;2!T:')O=T5R
M<F]R*"D@;65T:&]D('1O(&%L;&]W(&9O<G=A<F0@8V]M<&%T:6)I;&ET>0T*
M("`@("`J#0H@("`@("H@5&AI<R!M971H;V0@35535"!.3U0@=W)I=&4@;W5T
M(&%N>2!C:&%N9V5S('1O(&1I<VL-"B`@("`@*B!`<&%R86T@4$5!4E]086-K
M86=E1FEL95]V,@T*("`@("`J($!P87)A;2!S=')I;F<@9FEL92!C;VYT96YT
M<PT*("`@("`J($!P87)A;2!S=')I;F<@=&AE(&5V96YT=6%L(&9I;F%L(&9I
M;&4@;&]C871I;VX@*&EN9F]R;6%T:6]N86P@;VYL>2D-"B`@("`@*B!`<F5T
M=7)N('-T<FEN9WQF86QS97Q014%27T5R<F]R(&9A;'-E('1O('-K:7`@=&AI
M<R!F:6QE+"!014%27T5R<F]R('1O(&9A:6P-"B`@("`@*B`@("`@("`@("AU
M<V4@)'1H:7,M/G1H<F]W17)R;W(I+"!O=&AE<G=I<V4@<F5T=7)N('1H92!N
M97<@8V]N=&5N=',-"B`@("`@*B!`86)S=')A8W0-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!S=&%R=%-E<W-I;VXH)'!K9RP@)&-O;G1E;G1S+"`D9&5S="D-
M"B`@("![#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@5&AI<R!M971H;V0@
M:7,@=7-E9"!T;R!P<F]C97-S(&5A8V@@;V8@=&AE('1A<VMS(&9O<B!A('!A
M<G1I8W5L87(@;75L=&EP;&4@8VQA<W,-"B`@("`@*B!T>7!E+B`@4VEM<&QE
M('1A<VMS(&YE960@;F]T(&EM<&QE;65N="!T:&ES(&UE=&AO9"X-"B`@("`@
M*B!`<&%R86T@87)R87D@86X@87)R87D@;V8@=&%S:W,-"B`@("`@*B!`86-C
M97-S('!R;W1E8W1E9`T*("`@("`J($!S=&%T:6,-"B`@("`@*B!`86)S=')A
M8W0-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!R=6XH)'1A<VMS*0T*("`@('L-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<W1A=&EC#0H@("`@("H@0&9I
M;F%L#0H@("`@("HO#0H@("`@9G5N8W1I;VX@:&%S4&]S=&EN<W1A;&Q487-K
M<R@I#0H@("`@>PT*("`@("`@("!R971U<FX@:7-S970H)$=,3T)!3%-;)U]0
M14%27U1!4TM?4$]35$E.4U1!3D-%4R==*3L-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`@*B!`<W1A=&EC#0H@("`@("H@0&9I;F%L#0H@("`@("HO#0H@("`@
M(&9U;F-T:6]N(')U;E!O<W1I;G-T86QL5&%S:W,H*0T*("`@("![#0H@("`@
M("`@("!F;W)E86-H("@D1TQ/0D%,4ULG7U!%05)?5$%32U]03U-424Y35$%.
M0T53)UT@87,@)&-L87-S(#T^("1T87-K<RD@>PT*("`@("`@("`@("`@("1E
M<G(@/2!C86QL7W5S97)?9G5N8RAA<G)A>2@D8VQA<W,L("=R=6XG*2P-"B`@
M("`@("`@("`@("`@("`@("1'3$]"04Q36R=?4$5!4E]405-+7U!/4U1)3E-4
M04Y#15,G75LD8VQA<W-=*3L-"B`@("`@("`@("`@("!I9B`H)&5R<BD@>PT*
M("`@("`@("`@("`@("`@("!R971U<FX@4$5!4E]487-K7T-O;6UO;CHZ=&AR
M;W=%<G)O<B@D97)R*3L-"B`@("`@("`@("`@("!]#0H@("`@("`@("!]#0H@
M("`@("`@("!U;G-E="@D1TQ/0D%,4ULG7U!%05)?5$%32U]03U-424Y35$%.
M0T53)UTI.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($1E=&5R;6EN97,@
M=VAE=&AE<B!A(')O;&4@:7,@82!S8W)I<'0-"B`@("`@*B!`<F5T=7)N(&)O
M;VP-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!I<U-C<FEP="@I#0H@("`@>PT*
M("`@("`@("!R971U<FX@)'1H:7,M/G1Y<&4@/3T@)W-C<FEP="<[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@=&AR;W=%<G)O<B@D;7-G+"`D8V]D92`]("TQ
M*0T*("`@('L-"B`@("`@("`@:6YC;'5D95]O;F-E("=014%2+G!H<"<[#0H@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"1M<V<L("1C;V1E*3L-
M"B`@("!]#0I]#0H_/@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]014%2+U1A<VLO4&]S=&EN<W1A;&QS8W)I<'0N<&AP````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#,U,S<R(#$P-3$U-#,S-S,Q(#`R-#0P,0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`T*
M+RHJ#0H@*B`\=&%S:W,Z<&]S=&EN<W1A;&QS8W)I<'0^#0H@*@T*("H@4$A0
M('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C
M92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L
M:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L
M9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R
M96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@
M=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*
M("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M
M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y
M("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@
M1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@
M,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N
M,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%!O<W1I;G-T86QL<V-R:7!T
M+G!H<"QV(#$N,3@@,C`P-B\P,B\P."`P,3HR,3HT-R!C96QL;V<@17AP("0-
M"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]0
M14%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE
M87-E(#$N-"XP83$-"B`J+PT*+RHJ#0H@*B!"87-E(&-L87-S#0H@*B\-"G)E
M<75I<F5?;VYC92`G4$5!4B]487-K+T-O;6UO;BYP:'`G.PT*+RHJ#0H@*B!)
M;7!L96UE;G1S('1H92!P;W-T:6YS=&%L;'-C<FEP="!F:6QE('1A<VLN#0H@
M*@T*("H@3F]T92!T:&%T('!O<W0M:6YS=&%L;"!S8W)I<'1S(&%R92!H86YD
M;&5D('-E<&%R871E;'D@9G)O;2!I;G-T86QL871I;VXL(&)Y('1H90T*("H@
M(G!E87(@<G5N+7-C<FEP=',B(&-O;6UA;F0-"B`J($!C871E9V]R>2`@('!E
M87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@
M0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M
M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J
M($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H
M='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@
M("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO
M#0IC;&%S<R!014%27U1A<VM?4&]S=&EN<W1A;&QS8W)I<'0@97AT96YD<R!0
M14%27U1A<VM?0V]M;6]N#0I[#0H@("`@=F%R("1T>7!E(#T@)W-C<FEP="<[
M#0H@("`@=F%R("1?8VQA<W,[#0H@("`@=F%R("1?<&%R86US.PT*("`@('9A
M<B`D7V]B:CL-"B`@("`O*BH-"B`@("`@*@T*("`@("`J($!V87(@4$5!4E]0
M86-K86=E1FEL95]V,@T*("`@("`J+PT*("`@('9A<B`D7W!K9SL-"B`@("!V
M87(@)%]C;VYT96YT<SL-"B`@("!V87(@)'!H87-E(#T@4$5!4E]405-+7TE.
M4U1!3$P[#0H-"B`@("`O*BH-"B`@("`@*B!686QI9&%T92!T:&4@<F%W('AM
M;"!A="!P87)S:6YG+71I;64N#0H@("`@("H-"B`@("`@*B!4:&ES(&%L<V\@
M871T96UP=',@=&\@=F%L:61A=&4@=&AE('-C<FEP="!T;R!M86ME('-U<F4@
M:70@;65E=',@=&AE(&-R:71E<FEA#0H@("`@("H@9F]R(&$@<&]S="UI;G-T
M86QL('-C<FEP=`T*("`@("`J($!P87)A;2!014%27U!A8VMA9V5&:6QE7W8R
M#0H@("`@("H@0'!A<F%M(&%R<F%Y(%1H92!834P@8V]N=&5N=',@;V8@=&AE
M(#QP;W-T:6YS=&%L;'-C<FEP=#X@=&%G#0H@("`@("H@0'!A<F%M(%!%05)?
M0V]N9FEG#0H@("`@("H@0'!A<F%M(&%R<F%Y('1H92!E;G1I<F4@<&%R<V5D
M(#QF:6QE/B!T86<-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@=F%L:61A=&58;6PH)'!K9RP@)'AM;"P@)B1C;VYF:6<L("1F:6QE
M6&UL*0T*("`@('L-"B`@("`@("`@:68@*"1F:6QE6&UL6R=R;VQE)UT@(3T@
M)W!H<"<I('L-"B`@("`@("`@("`@(')E='5R;B!A<G)A>2A014%27U1!4TM?
M15)23U)?24Y604Q)1"P@)U!O<W0M:6YS=&%L;"!S8W)I<'0@(B<@+@T*("`@
M("`@("`@("`@)&9I;&58;6Q;)VYA;64G72`N("<B(&UU<W0@8F4@<F]L93TB
M<&AP(B<I.PT*("`@("`@("!]#0H@("`@("`@(%!%05(Z.G!U<VA%<G)O<DAA
M;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@)&9I;&4@/2`D
M<&MG+3YG971&:6QE0V]N=&5N=',H)&9I;&58;6Q;)VYA;64G72D[#0H@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1F:6QE*2D@>PT*("`@("`@("`@("`@
M4$5!4CHZ<&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@<F5T=7)N
M(&%R<F%Y*%!%05)?5$%32U]%4E)/4E])3E9!3$E$+"`G4&]S="UI;G-T86QL
M('-C<FEP="`B)R`N#0H@("`@("`@("`@("`@("`@)&9I;&58;6Q;)VYA;64G
M72`N("<B(&ES(&YO="!V86QI9#H@)R`N#0H@("`@("`@("`@("`@("`@)&9I
M;&4M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@('T@96QS96EF("@D9FEL92`]
M/3T@;G5L;"D@>PT*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*%!%05)?5$%3
M2U]%4E)/4E])3E9!3$E$+"`G4&]S="UI;G-T86QL('-C<FEP="`B)R`N#0H@
M("`@("`@("`@("`@("`@)&9I;&58;6Q;)VYA;64G72`N("<B(&-O=6QD(&YO
M="!B92!R971R:65V960@9F]R('!R;V-E<W-I;F<A)RD[#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`D86YA;'ES:7,@/2`D<&MG+3YA;F%L>7IE
M4V]U<F-E0V]D92@D9FEL92P@=')U92D[#0H@("`@("`@("`@("!I9B`H(21A
M;F%L>7-I<RD@>PT*("`@("`@("`@("`@("`@(%!%05(Z.G!O<$5R<F]R2&%N
M9&QI;F<H*3L-"B`@("`@("`@("`@("`@("`D=V%R;FEN9W,@/2`G)SL-"B`@
M("`@("`@("`@("`@("!F;W)E86-H("@D<&MG+3YG971686QI9&%T:6]N5V%R
M;FEN9W,H*2!A<R`D=V%R;BD@>PT*("`@("`@("`@("`@("`@("`@("`D=V%R
M;FEN9W,@+CT@)'=A<FY;)VUE<W-A9V4G72`N(")<;B([#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>2A014%27U1!
M4TM?15)23U)?24Y604Q)1"P@)T%N86QY<VES(&]F('!O<W0M:6YS=&%L;"!S
M8W)I<'0@(B<@+@T*("`@("`@("`@("`@("`@("`@("`D9FEL95AM;%LG;F%M
M92==("X@)R(@9F%I;&5D.B`G("X@)'=A<FYI;F=S*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(&EF("AC;W5N="@D86YA;'ES:7-;)V1E8VQA<F5D
M7V-L87-S97,G72D@(3T@,2D@>PT*("`@("`@("`@("`@("`@(%!%05(Z.G!O
M<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@("`@("!R971U<FX@87)R
M87DH4$5!4E]405-+7T524D]27TE.5D%,240L("=0;W-T+6EN<W1A;&P@<V-R
M:7!T("(G("X-"B`@("`@("`@("`@("`@("`@("`@)&9I;&58;6Q;)VYA;64G
M72`N("<B(&UU<W0@9&5C;&%R92!E>&%C=&QY(#$@8VQA<W,G*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("1C;&%S<R`]("1A;F%L>7-I<ULG9&5C
M;&%R961?8VQA<W-E<R==6S!=.PT*("`@("`@("`@("`@:68@*"1C;&%S<R`A
M/2!S=')?<F5P;&%C92AA<G)A>2@G+R<L("<N<&AP)RDL(&%R<F%Y*"=?)RP@
M)R<I+`T*("`@("`@("`@("`@("`@("`@)&9I;&58;6Q;)VYA;64G72D@+B`G
M7W!O<W1I;G-T86QL)RD@>PT*("`@("`@("`@("`@("`@(%!%05(Z.G!O<$5R
M<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@("`@("!R971U<FX@87)R87DH
M4$5!4E]405-+7T524D]27TE.5D%,240L("=0;W-T+6EN<W1A;&P@<V-R:7!T
M("(G("X-"B`@("`@("`@("`@("`@("`@("`@)&9I;&58;6Q;)VYA;64G72`N
M("<B(&-L87-S("(G("X@)&-L87-S("X@)R(@;75S="!B92!N86UE9"`B)R`N
M#0H@("`@("`@("`@("`@("`@("`@('-T<E]R97!L86-E*&%R<F%Y*"<O)RP@
M)RYP:'`G*2P@87)R87DH)U\G+"`G)RDL#0H@("`@("`@("`@("`@("`@("`@
M("1F:6QE6&UL6R=N86UE)UTI("X@)U]P;W-T:6YS=&%L;"(G*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&EF("@A:7-S970H)&%N86QY<VES6R=D
M96-L87)E9%]M971H;V1S)UU;)&-L87-S72DI('L-"B`@("`@("`@("`@("`@
M("!014%2.CIP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("`@("`@
M<F5T=7)N(&%R<F%Y*%!%05)?5$%32U]%4E)/4E])3E9!3$E$+"`G4&]S="UI
M;G-T86QL('-C<FEP="`B)R`N#0H@("`@("`@("`@("`@("`@("`@("1F:6QE
M6&UL6R=N86UE)UT@+B`G(B!M=7-T(&1E8VQA<F4@;65T:&]D<R!I;FET*"D@
M86YD(')U;B@I)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D;65T
M:&]D<R`](&%R<F%Y*"=I;FET)R`]/B`P+"`G<G5N)R`]/B`Q*3L-"B`@("`@
M("`@("`@(&9O<F5A8V@@*"1A;F%L>7-I<ULG9&5C;&%R961?;65T:&]D<R==
M6R1C;&%S<UT@87,@)&UE=&AO9"D@>PT*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D;65T:&]D<ULD;65T:&]D72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@=6YS970H)&UE=&AO9'-;)&UE=&AO9%TI.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AC;W5N="@D;65T
M:&]D<RDI('L-"B`@("`@("`@("`@("`@("!014%2.CIP;W!%<G)O<DAA;F1L
M:6YG*"D[#0H@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*%!%05)?5$%3
M2U]%4E)/4E])3E9!3$E$+"`G4&]S="UI;G-T86QL('-C<FEP="`B)R`N#0H@
M("`@("`@("`@("`@("`@("`@("1F:6QE6&UL6R=N86UE)UT@+B`G(B!M=7-T
M(&1E8VQA<F4@;65T:&]D<R!I;FET*"D@86YD(')U;B@I)RD[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@4$5!4CHZ<&]P17)R;W)(86YD
M;&EN9R@I.PT*("`@("`@("`D9&5F:6YE9'!A<F%M<R`](&%R<F%Y*"D[#0H@
M("`@("`@("1T87-K<TYA;65S<&%C92`]("1P:V<M/F=E=%1A<VMS3G,H*2`N
M("<Z)SL-"B`@("`@("`@:68@*"%I<W-E="@D>&UL6R1T87-K<TYA;65S<&%C
M92`N("=P87)A;6=R;W5P)UTI("8F(&ES<V5T*"1X;6Q;)W!A<F%M9W)O=7`G
M72DI('L-"B`@("`@("`@("`@("\O(&EN(&]R9&5R('1O('-U<'!O<G0@=&AE
M(&]L9&5R(&)E=&%S+"!W:&EC:"!D:60@;F]T(&5X<&5C="!I;G1E<FYA;"!T
M86=S#0H@("`@("`@("`@("`O+R!T;R!A;'-O('5S92!T:&4@;F%M97-P86-E
M#0H@("`@("`@("`@("`D=&%S:W-.86UE<W!A8V4@/2`G)SL-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H:7-S970H)'AM;%LD=&%S:W-.86UE<W!A8V4@+B`G
M<&%R86UG<F]U<"==*2D@>PT*("`@("`@("`@("`@)'!A<F%M<R`]("1X;6Q;
M)'1A<VMS3F%M97-P86-E("X@)W!A<F%M9W)O=7`G73L-"B`@("`@("`@("`@
M(&EF("@A:7-?87)R87DH)'!A<F%M<RD@?'P@(6ES<V5T*"1P87)A;7-;,%TI
M*2![#0H@("`@("`@("`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"1P87)A;7,I
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H)'!A<F%M
M<R!A<R`D<&%R86TI('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1P
M87)A;5LD=&%S:W-.86UE<W!A8V4@+B`G:60G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N(&%R<F%Y*%!%05)?5$%32U]%4E)/4E])3E9!3$E$
M+"`G4&]S="UI;G-T86QL('-C<FEP="`B)R`N#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D9FEL95AM;%LG;F%M92==("X@)R(@/'!A<F%M9W)O=7`^(&UU
M<W0@:&%V92`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("=A;B`G("X@
M)'1A<VMS3F%M97-P86-E("X@)VED/B!T86<G*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P87)A;5LD=&%S:W-.
M86UE<W!A8V4@+B`G;F%M92==*2D@>PT*("`@("`@("`@("`@("`@("`@("!I
M9B`H(6EN7V%R<F%Y*"1P87)A;5LD=&%S:W-.86UE<W!A8V4@+B`G;F%M92==
M+"`D9&5F:6YE9'!A<F%M<RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;B!A<G)A>2A014%27U1!4TM?15)23U)?24Y604Q)1"P@)U!O<W0M
M:6YS=&%L;"!S8W)I<'0@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1F:6QE6&UL6R=N86UE)UT@+B`G(B`G("X@)'1A<VMS3F%M97-P86-E
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<&%R86UG<F]U<#X@
M:60@(B<@+B`D<&%R86U;)'1A<VMS3F%M97-P86-E("X@)VED)UT@+@T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("<B('!A<F%M971E<B`B)R`N("1P
M87)A;5LD=&%S:W-.86UE<W!A8V4@+B`G;F%M92==("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G(B!H87,@;F]T(&)E96X@<')E=FEO=7-L>2!D
M969I;F5D)RD[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D<&%R86U;)'1A<VMS3F%M97-P86-E("X@
M)V-O;F1I=&EO;G1Y<&4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;B!A<G)A>2A014%27U1!4TM?15)23U)?24Y604Q)1"P@)U!O<W0M
M:6YS=&%L;"!S8W)I<'0@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1F:6QE6&UL6R=N86UE)UT@+B`G(B`G("X@)'1A<VMS3F%M97-P86-E
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<&%R86UG<F]U<#X@
M:60@(B<@+B`D<&%R86U;)'1A<VMS3F%M97-P86-E("X@)VED)UT@+@T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("<B(&UU<W0@:&%V92!A("<@+B`D
M=&%S:W-.86UE<W!A8V4@+B`-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G8V]N9&ET:6]N='EP93X@=&%G(&-O;G1A:6YI;F<@96ET:&5R("(](BP@
M)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R(A/2(L(&]R(")P
M<F5G7VUA=&-H(B<I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@(&EF("@A:6Y?87)R87DH)'!A<F%M6R1T87-K<TYA;65S
M<&%C92`N("=C;VYD:71I;VYT>7!E)UTL#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"<])RP@)R$])RP@)W!R96=?;6%T8V@G*2DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>2A014%27U1!4TM?
M15)23U)?24Y604Q)1"P@)U!O<W0M:6YS=&%L;"!S8W)I<'0@(B<@+@T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1F:6QE6&UL6R=N86UE)UT@+B`G
M(B`G("X@)'1A<VMS3F%M97-P86-E("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G<&%R86UG<F]U<#X@:60@(B<@+B`D<&%R86U;)'1A<VMS3F%M
M97-P86-E("X@)VED)UT@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("<B(&UU<W0@:&%V92!A("<@+B`D=&%S:W-.86UE<W!A8V4@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=C;VYD:71I;VYT>7!E/B!T86<@8V]N
M=&%I;FEN9R!E:71H97(@(CTB+"`G("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G(B$](BP@;W(@(G!R96=?;6%T8V@B)RD[#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M<&%R86U;)'1A<VMS3F%M97-P86-E("X@)W9A;'5E)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("!R971U<FX@87)R87DH4$5!4E]405-+7T524D]2
M7TE.5D%,240L("=0;W-T+6EN<W1A;&P@<V-R:7!T("(G("X-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9FEL95AM;%LG;F%M92==("X@)R(@)R`N
M("1T87-K<TYA;65S<&%C92`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W!A<F%M9W)O=7`^(&ED("(G("X@)'!A<F%M6R1T87-K<TYA;65S<&%C
M92`N("=I9"==("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G(B!M
M=7-T(&AA=F4@82`G("X@)'1A<VMS3F%M97-P86-E("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G=F%L=64^('1A9R!C;VYT86EN:6YG(&5X<&5C
M=&5D('!A<F%M971E<B!V86QU92<I.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D<&%R86U;)'1A<VMS3F%M97-P86-E("X@)VEN<W1R=6-T:6]N<R==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES7W-T<FEN9R@D<&%R86U;
M)'1A<VMS3F%M97-P86-E("X@)VEN<W1R=6-T:6]N<R==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*%!%05)?5$%32U]%4E)/
M4E])3E9!3$E$+"`G4&]S="UI;G-T86QL('-C<FEP="`B)R`N#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&9I;&58;6Q;)VYA;64G72`N("<B("<@
M+B`D=&%S:W-.86UE<W!A8V4@+@T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=P87)A;6=R;W5P/B!I9"`B)R`N("1P87)A;5LD=&%S:W-.86UE<W!A
M8V4@+B`G:60G72`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R(@
M)R`N("1T87-K<TYA;65S<&%C92`N("=I;G-T<G5C=&EO;G,^(&UU<W0@8F4@
M<VEM<&QE('1E>'0G*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1P87)A
M;5LD=&%S:W-.86UE<W!A8V4@+B`G<&%R86TG72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@8V]N=&EN=64[("\O(#QP87)A;3X@:7,@;F\@;&]N9V5R(')E
M<75I<F5D#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1S
M=6)P87)A;7,@/2`D<&%R86U;)'1A<VMS3F%M97-P86-E("X@)W!A<F%M)UT[
M#0H@("`@("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D<W5B<&%R86US*2!\
M?"`A:7-S970H)'-U8G!A<F%M<ULP72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@)'-U8G!A<F%M<R`](&%R<F%Y*"1S=6)P87)A;7,I.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D<W5B<&%R86US
M(&%S("1S=6)P87)A;2D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1S=6)P87)A;5LD=&%S:W-.86UE<W!A8V4@+B`G;F%M92==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*%!%05)?5$%3
M2U]%4E)/4E])3E9!3$E$+"`G4&]S="UI;G-T86QL('-C<FEP="`B)R`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9I;&58;6Q;)VYA;64G72`N
M("<B('!A<F%M971E<B!F;W(@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1A<VMS3F%M97-P86-E("X@)W!A<F%M9W)O=7`^(&ED("(G("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86U;)'1A<VMS3F%M
M97-P86-E("X@)VED)UT@+B`G(B!M=7-T(&AA=F4@)R`N#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V$@)R`N("1T87-K<TYA;65S<&%C92`N("=N
M86UE/B!T86<G*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H)R];82UZ02U:,"TY72LO)RP-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@)'-U8G!A<F%M6R1T87-K<TYA
M;65S<&%C92`N("=N86UE)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("!R971U<FX@87)R87DH4$5!4E]405-+7T524D]27TE.5D%,240L("=0;W-T
M+6EN<W1A;&P@<V-R:7!T("(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D9FEL95AM;%LG;F%M92==("X@)R(@<&%R86UE=&5R("(G("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<W5B<&%R86U;)'1A<VMS3F%M
M97-P86-E("X@)VYA;64G72`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)R(@9F]R("<@+B`D=&%S:W-.86UE<W!A8V4@+B`G<&%R86UG<F]U<#X@
M:60@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P87)A;5LD
M=&%S:W-.86UE<W!A8V4@+B`G:60G72`N#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)R(@:7,@;F]T(&$@=F%L:60@;F%M92X@($UU<W0@8V]N=&%I
M;B!O;FQY(&%L<&AA;G5M97)I8R!C:&%R86-T97)S)RD[#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M<W5B<&%R86U;)'1A<VMS3F%M97-P86-E("X@)W!R;VUP="==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*%!%05)?5$%32U]%
M4E)/4E])3E9!3$E$+"`G4&]S="UI;G-T86QL('-C<FEP="`B)R`N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&9I;&58;6Q;)VYA;64G72`N("<B
M('!A<F%M971E<B`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'-U8G!A<F%M6R1T87-K<TYA;65S<&%C92`N("=N86UE)UT@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("<B(&9O<B`G("X@)'1A<VMS3F%M97-P
M86-E("X@)W!A<F%M9W)O=7`^(&ED("(G("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<&%R86U;)'1A<VMS3F%M97-P86-E("X@)VED)UT@+@T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("<B(&UU<W0@:&%V92!A("<@
M+B`D=&%S:W-.86UE<W!A8V4@+B`G<')O;7!T/B!T86<G*3L-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1S=6)P87)A;5LD=&%S:W-.86UE<W!A8V4@+B`G='EP92==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*%!%05)?5$%32U]%
M4E)/4E])3E9!3$E$+"`G4&]S="UI;G-T86QL('-C<FEP="`B)R`N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&9I;&58;6Q;)VYA;64G72`N("<B
M('!A<F%M971E<B`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'-U8G!A<F%M6R1T87-K<TYA;65S<&%C92`N("=N86UE)UT@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("<B(&9O<B`G("X@)'1A<VMS3F%M97-P
M86-E("X@)W!A<F%M9W)O=7`^(&ED("(G("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<&%R86U;)'1A<VMS3F%M97-P86-E("X@)VED)UT@+@T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("<B(&UU<W0@:&%V92!A("<@
M+B`D=&%S:W-.86UE<W!A8V4@+B`G='EP93X@=&%G)RD[#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)&1E9FEN961P87)A
M;7-;72`]("1P87)A;5LD=&%S:W-.86UE<W!A8V4@+B`G:60G72`N("<Z.B<@
M+@T*("`@("`@("`@("`@("`@("`@("`D<W5B<&%R86U;)'1A<VMS3F%M97-P
M86-E("X@)VYA;64G73L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*
M#0H@("`@+RHJ#0H@("`@("H@26YI=&EA;&EZ92!A('1A<VL@:6YS=&%N8V4@
M=VET:"!T:&4@<&%R86UE=&5R<PT*("`@("`J($!P87)A;2!A<G)A>2!R87<L
M('!A<G-E9"!X;6P-"B`@("`@*B!`<&%R86T@87)R87D@871T<FEB=71E<R!F
M<F]M('1H92`\9FEL93X@=&%G(&-O;G1A:6YI;F<@=&AI<R!T87-K#0H@("`@
M("H@0'!A<F%M('-T<FEN9WQN=6QL(&QA<W0@:6YS=&%L;&5D('9E<G-I;VX@
M;V8@=&AI<R!P86-K86=E+"!I9B!A;GD@*'5S969U;"!F;W(@=7!G<F%D97,I
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@:6YI="@D>&UL+"`D9FEL96%T=')I
M8G,L("1L87-T=F5R<VEO;BD-"B`@("![#0H@("`@("`@("1T:&ES+3Y?8VQA
M<W,@/2!S=')?<F5P;&%C92@G+R<L("=?)RP@)&9I;&5A='1R:6)S6R=N86UE
M)UTI.PT*("`@("`@("`D=&AI<RT^7V9I;&5N86UE(#T@)&9I;&5A='1R:6)S
M6R=N86UE)UT[#0H@("`@("`@("1T:&ES+3Y?8VQA<W,@/2!S=')?<F5P;&%C
M92`H)RYP:'`G+"`G)RP@)'1H:7,M/E]C;&%S<RD@+B`G7W!O<W1I;G-T86QL
M)SL-"B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D>&UL.PT*("`@("`@("`D
M=&AI<RT^7VQA<W1V97)S:6]N(#T@)&QA<W1V97)S:6]N.PT*("`@('T-"@T*
M("`@("\J*@T*("`@("`J(%-T<FEP('1H92!T87-K<SH@;F%M97-P86-E(&9R
M;VT@:6YT97)N86P@<&%R86US#0H@("`@("H-"B`@("`@*B!`86-C97-S('!R
M:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?<W1R:7!.86UE<W!A8V4H
M)'!A<F%M<R`](&YU;&PI#0H@("`@>PT*("`@("`@("!I9B`H)'!A<F%M<R`]
M/3T@;G5L;"D@>PT*("`@("`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"D[#0H@
M("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1T:&ES+3Y?<&%R86US*2D@>PT*
M("`@("`@("`@("`@("`@(')E='5R;CL-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<&%R86US(&%S("1I(#T^("1P87)A
M;2D@>PT*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D<&%R86TI*2![
M#0H@("`@("`@("`@("`@("`@("`@("1P87)A;2`]("1T:&ES+3Y?<W1R:7!.
M86UE<W!A8V4H)'!A<F%M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@)'!A<F%M<UMS=')?<F5P;&%C92@D=&AI<RT^7W!K9RT^9V5T
M5&%S:W-.<R@I("X@)SHG+"`G)RP@)&DI72`]("1P87)A;3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL-
M"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1N97=P87)A;7,@/2!A
M<G)A>2@I.PT*("`@("`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D:2`]
M/B`D<&%R86TI('L-"B`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)'!A
M<F%M*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<&%R86T@/2`D=&AI<RT^
M7W-T<FEP3F%M97-P86-E*"1P87)A;2D[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("1N97=P87)A;7-;<W1R7W)E<&QA8V4H)'1H:7,M
M/E]P:V<M/F=E=%1A<VMS3G,H*2`N("<Z)RP@)R<L("1I*5T@/2`D<&%R86T[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@)&YE=W!A<F%M
M<SL-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@("`J(%5N;&EK
M92!O=&AE<B!T87-K<RP@=&AE(&EN<W1A;&QE9"!F:6QE(&YA;64@:7,@<&%S
M<V5D(&EN(&EN<W1E860@;V8@=&AE(&9I;&4@8V]N=&5N=',L#0H@("`@("H@
M8F5C875S92!T:&ES('1A<VL@:7,@:&%N9&QE9"!P;W-T+6EN<W1A;&QA=&EO
M;@T*("`@("`J($!P87)A;2!014%27U!A8VMA9V5&:6QE7W8Q?%!%05)?4&%C
M:V%G949I;&5?=C(-"B`@("`@*B!`<&%R86T@<W1R:6YG(&9I;&4@;F%M90T*
M("`@("`J($!R971U<FX@8F]O;'Q014%27T5R<F]R(&9A;'-E('1O('-K:7`@
M=&AI<R!F:6QE+"!014%27T5R<F]R('1O(&9A:6P-"B`@("`@*B`@("`@("`@
M("AU<V4@)'1H:7,M/G1H<F]W17)R;W(I#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@<W1A<G1397-S:6]N*"1P:V<L("1C;VYT96YT<RD-"B`@("![#0H@("`@
M("`@(&EF("@D=&AI<RT^:6YS=&%L;'!H87-E("$](%!%05)?5$%32U])3E-4
M04Q,*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-
M"B`@("`@("`@+R\@<F5M;W9E('1H92!T87-K<SH@;F%M97-P86-E(&EF('!R
M97-E;G0-"B`@("`@("`@)'1H:7,M/E]P:V<@/2`D<&MG.PT*("`@("`@("`D
M=&AI<RT^7W-T<FEP3F%M97-P86-E*"D[#0H@("`@("`@("1T:&ES+3YL;V=G
M97(M/FQO9R@P+"`G26YC;'5D:6YG(&5X=&5R;F%L('!O<W0M:6YS=&%L;&%T
M:6]N('-C<FEP="`B)R`N#0H@("`@("`@("`@("`D8V]N=&5N=',@+B`G(B`M
M(&%N>2!E<G)O<G,@87)E(&EN('1H:7,@<V-R:7!T)RD[#0H@("`@("`@(&EN
M8VQU9&5?;VYC92`D8V]N=&5N=',[#0H@("`@("`@(&EF("AC;&%S<U]E>&ES
M=',H)'1H:7,M/E]C;&%S<RDI('L-"B`@("`@("`@("`@("1T:&ES+3YL;V=G
M97(M/FQO9R@P+"`G26YC;'5S:6]N('-U8V-E961E9"<I.PT*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YT:')O=T5R<F]R
M*"=I;FET(&]F('!O<W0M:6YS=&%L;"!S8W)I<'0@8VQA<W,@(B<@+B`D=&AI
M<RT^7V-L87-S#0H@("`@("`@("`@("`@("`@+B`G(B!F86EL960G*3L-"B`@
M("`@("`@?0T*("`@("`@("`D=&AI<RT^7V]B:B`](&YE=R`D=&AI<RT^7V-L
M87-S.PT*("`@("`@("`D=&AI<RT^;&]G9V5R+3YL;V<H,2P@)W)U;FYI;F<@
M<&]S="UI;G-T86QL('-C<FEP="`B)R`N("1T:&ES+3Y?8VQA<W,@+B`G+3YI
M;FET*"DB)RD[#0H@("`@("`@(%!%05(Z.G!U<VA%<G)O<DAA;F1L:6YG*%!%
M05)?15)23U)?4D5455).*3L-"B`@("`@("`@)')E<R`]("1T:&ES+3Y?;V)J
M+3YI;FET*"1T:&ES+3YC;VYF:6<L("1P:V<L("1T:&ES+3Y?;&%S='9E<G-I
M;VXI.PT*("`@("`@("!014%2.CIP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@
M("`@(&EF("@D<F5S*2![#0H@("`@("`@("`@("`D=&AI<RT^;&]G9V5R+3YL
M;V<H,"P@)VEN:70@<W5C8V5E9&5D)RD[#0H@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G1H<F]W17)R;W(H)VEN:70@;V8@
M<&]S="UI;G-T86QL('-C<FEP="`B)R`N("1T:&ES+3Y?8VQA<W,@+@T*("`@
M("`@("`@("`@("`@("<M/FEN:70H*2(@9F%I;&5D)RD[#0H@("`@("`@('T-
M"B`@("`@("`@)'1H:7,M/E]C;VYT96YT<R`]("1C;VYT96YT<SL-"B`@("`@
M("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@3F\@
M;&]N9V5R('5S960-"B`@("`@*B!`<V5E(%!%05)?4&%C:V%G949I;&5?=C(Z
M.G)U;E!O<W1I;G-T86QL4V-R:7!T<R@I#0H@("`@("H@0'!A<F%M(&%R<F%Y
M(&%N(&%R<F%Y(&]F('1A<VMS#0H@("`@("H@0'!A<F%M('-T<FEN9R!I;G-T
M86QL(&]R('5P9W)A9&4-"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`T*("`@
M("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!R=6XH*0T*("`@
M('L-"B`@("!]#0I]#0H_/@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O5&%S
M:R]297!L86-E+G!H<```````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,38R-38@,3`U,34T,S,W,S$@,#(R,C$S`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP#0HO*BH-"B`J(#QT87-K
M<SIR97!L86-E/@T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*
M("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E
M<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I
M;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO
M=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N
M='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H
M92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR
M;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N
M<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@
M(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP
M+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P
M#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S
M7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@
M)$ED.B!297!L86-E+G!H<"QV(#$N,34@,C`P-B\P,R\P,B`Q.#HQ-#HQ,R!C
M96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN
M970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L
M92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*+RHJ#0H@*B!"87-E(&-L
M87-S#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!4B]487-K+T-O;6UO;BYP:'`G
M.PT*+RHJ#0H@*B!);7!L96UE;G1S('1H92!R97!L86-E(&9I;&4@=&%S:RX-
M"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J
M($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J
M($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC
M96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!0
M2%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY
M#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O
M4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E
M;&5A<V4@,2XT+C!A,0T*("HO#0IC;&%S<R!014%27U1A<VM?4F5P;&%C92!E
M>'1E;F1S(%!%05)?5&%S:U]#;VUM;VX-"GL-"B`@("!V87(@)'1Y<&4@/2`G
M<VEM<&QE)SL-"B`@("!V87(@)'!H87-E(#T@4$5!4E]405-+7U!!0TM!1T5!
M3D1)3E-404Q,.PT*("`@('9A<B`D7W)E<&QA8V5M96YT<SL-"@T*("`@("\J
M*@T*("`@("`J(%9A;&ED871E('1H92!R87<@>&UL(&%T('!A<G-I;F<M=&EM
M92X-"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E1FEL95]V,@T*("`@("`J
M($!P87)A;2!A<G)A>2!R87<L('!A<G-E9"!X;6P-"B`@("`@*B!`<&%R86T@
M4$5!4E]#;VYF:6<-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@=F%L:61A=&58;6PH)'!K9RP@)'AM;"P@)B1C;VYF:6<L("1F:6QE
M6&UL*0T*("`@('L-"B`@("`@("`@:68@*"%I<W-E="@D>&UL6R=A='1R:6)S
M)UTI*2![#0H@("`@("`@("`@("!R971U<FX@87)R87DH4$5!4E]405-+7T52
M4D]27TY/05144DE"4RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<W-E
M="@D>&UL6R=A='1R:6)S)UU;)W1Y<&4G72DI('L-"B`@("`@("`@("`@(')E
M='5R;B!A<G)A>2A014%27U1!4TM?15)23U)?34E34TE.1U]!5%1224(L("=T
M>7!E)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<W-E="@D>&UL6R=A
M='1R:6)S)UU;)W1O)UTI*2![#0H@("`@("`@("`@("!R971U<FX@87)R87DH
M4$5!4E]405-+7T524D]27TU)4U-)3D=?05144DE"+"`G=&\G*3L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H(6ES<V5T*"1X;6Q;)V%T=')I8G,G75LG9G)O
M;2==*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*%!%05)?5$%32U]%
M4E)/4E]-25-324Y'7T%45%))0BP@)V9R;VTG*3L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H)'AM;%LG871T<FEB<R==6R=T>7!E)UT@/3T@)W!E87(M8V]N
M9FEG)RD@>PT*("`@("`@("`@("`@:68@*"%I;E]A<G)A>2@D>&UL6R=A='1R
M:6)S)UU;)W1O)UTL("1C;VYF:6<M/F=E=$ME>7,H*2DI('L-"B`@("`@("`@
M("`@("`@("!R971U<FX@87)R87DH4$5!4E]405-+7T524D]27U=23TY'7T%4
M5%))0E]604Q512P@)W1O)RP@)'AM;%LG871T<FEB<R==6R=T;R==+`T*("`@
M("`@("`@("`@("`@("`@("`D8V]N9FEG+3YG971+97ES*"DI.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!](&5L<V5I9B`H)'AM;%LG871T<FEB<R==6R=T
M>7!E)UT@/3T@)W!H<"UC;VYS="<I('L-"B`@("`@("`@("`@(&EF("AD969I
M;F5D*"1X;6Q;)V%T=')I8G,G75LG=&\G72DI('L-"B`@("`@("`@("`@("`@
M("!R971U<FX@=')U93L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@<F5T=7)N(&%R<F%Y*%!%05)?5$%32U]%4E)/4E]74D].1U]!
M5%1224)?5D%,544L("=T;R<L("1X;6Q;)V%T=')I8G,G75LG=&\G72P-"B`@
M("`@("`@("`@("`@("`@("`@87)R87DH)W9A;&ED(%!(4"!C;VYS=&%N="<I
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E:68@*"1X;6Q;)V%T
M=')I8G,G75LG='EP92==(#T]("=P86-K86=E+6EN9F\G*2![#0H@("`@("`@
M("`@("!I9B`H:6Y?87)R87DH)'AM;%LG871T<FEB<R==6R=T;R==+`T*("`@
M("`@("`@("`@("`@(&%R<F%Y*"=N86UE)RP@)W-U;6UA<GDG+"`G8VAA;FYE
M;"<L("=N;W1E<R<L("=E>'1E;F1S)RP@)V1E<V-R:7!T:6]N)RP-"B`@("`@
M("`@("`@("`@("`@("`@)W)E;&5A<V5?;F]T97,G+"`G;&EC96YS92<L("=R
M96QE87-E+6QI8V5N<V4G+"`G;&EC96YS92UU<FDG+`T*("`@("`@("`@("`@
M("`@("`@("`G=F5R<VEO;B<L("=A<&DM=F5R<VEO;B<L("=S=&%T92<L("=A
M<&DM<W1A=&4G+"`G<F5L96%S95]D871E)RP-"B`@("`@("`@("`@("`@("`@
M("`@)V1A=&4G+"`G=&EM92<I*2D@>PT*("`@("`@("`@("`@("`@(')E='5R
M;B!T<G5E.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("!R971U<FX@87)R87DH4$5!4E]405-+7T524D]27U=23TY'7T%45%))0E]6
M04Q512P@)W1O)RP@)'AM;%LG871T<FEB<R==6R=T;R==+`T*("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@G;F%M92<L("=S=6UM87)Y)RP@)V-H86YN96PG
M+"`G;F]T97,G+"`G97AT96YD<R<L("=D97-C<FEP=&EO;B<L#0H@("`@("`@
M("`@("`@("`@("`@("=R96QE87-E7VYO=&5S)RP@)VQI8V5N<V4G+"`G<F5L
M96%S92UL:6-E;G-E)RP@)VQI8V5N<V4M=7)I)RP-"B`@("`@("`@("`@("`@
M("`@("`@)W9E<G-I;VXG+"`G87!I+79E<G-I;VXG+"`G<W1A=&4G+"`G87!I
M+7-T871E)RP@)W)E;&5A<V5?9&%T92<L#0H@("`@("`@("`@("`@("`@("`@
M("=D871E)RP@)W1I;64G*2D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("!R971U<FX@87)R87DH4$5!4E]405-+7T52
M4D]27U=23TY'7T%45%))0E]604Q512P@)W1Y<&4G+"`D>&UL6R=A='1R:6)S
M)UU;)W1Y<&4G72P-"B`@("`@("`@("`@("`@("!A<G)A>2@G<&5A<BUC;VYF
M:6<G+"`G<&%C:V%G92UI;F9O)RP@)W!H<"UC;VYS="<I*3L-"B`@("`@("`@
M?0T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!);FET:6%L:7IE(&$@=&%S:R!I;G-T86YC92!W:71H('1H92!P87)A
M;65T97)S#0H@("`@("H@0'!A<F%M(&%R<F%Y(')A=RP@<&%R<V5D('AM;`T*
M("`@("`J($!P87)A;2!U;G5S960-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!I
M;FET*"1X;6PL("1A='1R:6)S*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]R
M97!L86-E;65N=',@/2!I<W-E="@D>&UL6R=A='1R:6)S)UTI(#\@87)R87DH
M)'AM;"D@.B`D>&UL.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($1O(&$@
M<&%C:V%G92YX;6P@,2XP(')E<&QA8V5M96YT+"!W:71H(&%D9&ET:6]N86P@
M<&%C:V%G92UI;F9O(&9I96QD<R!A=F%I;&%B;&4-"B`@("`@*@T*("`@("`J
M(%-E92!V86QI9&%T95AM;"@I('-O=7)C92!F;W(@=&AE(&-O;7!L971E(&QI
M<W0@;V8@86QL;W=E9"!F:65L9',-"B`@("`@*B!`<&%R86T@4$5!4E]086-K
M86=E1FEL95]V,7Q014%27U!A8VMA9V5&:6QE7W8R#0H@("`@("H@0'!A<F%M
M('-T<FEN9R!F:6QE(&-O;G1E;G1S#0H@("`@("H@0'!A<F%M('-T<FEN9R!T
M:&4@979E;G1U86P@9FEN86P@9FEL92!L;V-A=&EO;B`H:6YF;W)M871I;VYA
M;"!O;FQY*0T*("`@("`J($!R971U<FX@<W1R:6YG?&9A;'-E?%!%05)?17)R
M;W(@9F%L<V4@=&\@<VMI<"!T:&ES(&9I;&4L(%!%05)?17)R;W(@=&\@9F%I
M;`T*("`@("`J("`@("`@("`@*'5S92`D=&AI<RT^=&AR;W=%<G)O<BDL(&]T
M:&5R=VES92!R971U<FX@=&AE(&YE=R!C;VYT96YT<PT*("`@("`J+PT*("`@
M(&9U;F-T:6]N('-T87)T4V5S<VEO;B@D<&MG+"`D8V]N=&5N=',L("1D97-T
M*0T*("`@('L-"B`@("`@("`@)'-U8G-T7V9R;VT@/2`D<W5B<W1?=&\@/2!A
M<G)A>2@I.PT*("`@("`@("!F;W)E86-H("@D=&AI<RT^7W)E<&QA8V5M96YT
M<R!A<R`D82D@>PT*("`@("`@("`@("`@)&$@/2`D85LG871T<FEB<R==.PT*
M("`@("`@("`@("`@)'1O(#T@)R<[#0H@("`@("`@("`@("!I9B`H)&%;)W1Y
M<&4G72`]/2`G<&5A<BUC;VYF:6<G*2![#0H@("`@("`@("`@("`@("`@:68@
M*"1T:&ES+3YI;G-T86QL<&AA<V4@/3T@4$5!4E]405-+7U!!0TM!1T4I('L-
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H)&%;)W1O)UT@/3T@)VUA
M<W1E<E]S97)V97(G*2![#0H@("`@("`@("`@("`@("`@("`@("1C:&%N(#T@
M)'1H:7,M/G)E9VES=')Y+3YG971#:&%N;F5L*"1P:V<M/F=E=$-H86YN96PH
M*2D[#0H@("`@("`@("`@("`@("`@("`@(&EF("@A4$5!4CHZ:7-%<G)O<B@D
M8VAA;BDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T;R`]("1C:&%N
M+3YG971397)V97(H*3L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V=G97(M/FQO9R@P
M+"`B)&1E<W0Z(&EN=F%L:60@<&5A<BUC;VYF:6<@<F5P;&%C96UE;G0Z("1A
M6W1O72(I.PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YC;VYF:6<M
M/FES1&5F:6YE9$QA>65R*"=F='`G*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@+R\@=')Y('1H92!R96UO=&4@8V]N9FEG(&9I;&4@9FER<W0-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1T;R`]("1T:&ES+3YC;VYF:6<M/F=E
M="@D85LG=&\G72P@)V9T<"<L("1P:V<M/F=E=$-H86YN96PH*2D[#0H@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-?;G5L;"@D=&\I*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@+R\@=&AE;B!D969A=6QT('1O(&QO
M8V%L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1O(#T@)'1H:7,M
M/F-O;F9I9RT^9V5T*"1A6R=T;R==+"!N=6QL+"`D<&MG+3YG971#:&%N;F5L
M*"DI.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1O
M(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"1A6R=T;R==+"!N=6QL+"`D<&MG+3YG
M971#:&%N;F5L*"DI.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<U]N=6QL*"1T;RDI
M('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9V=E<BT^;&]G*#`L
M("(D9&5S=#H@:6YV86QI9"!P96%R+6-O;F9I9R!R97!L86-E;65N=#H@)&%;
M=&]=(BD[#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!](&5L<V5I9B`H)&%;)W1Y
M<&4G72`]/2`G<&AP+6-O;G-T)RD@>PT*("`@("`@("`@("`@("`@(&EF("@D
M=&AI<RT^:6YS=&%L;'!H87-E(#T](%!%05)?5$%32U]004-+04=%*2![#0H@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&1E9FEN960H)&%;)W1O)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("1T;R`](&-O;G-T86YT*"1A6R=T
M;R==*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^;&]G9V5R+3YL;V<H,"P@(B1D97-T.B!I;G9A;&ED
M('!H<"UC;VYS="!R97!L86-E;65N=#H@)&%;=&]=(BD[#0H@("`@("`@("`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(&EF("@D="`]
M("1P:V<M/G!A8VMA9V5);F9O*"1A6R=T;R==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`D=&\@/2`D=#L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G9V5R+3YL;V<H,"P@(B1D
M97-T.B!I;G9A;&ED('!A8VMA9V4M:6YF;R!R97!L86-E;65N=#H@)&%;=&]=
M(BD[#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H
M(6ES7VYU;&PH)'1O*2D@>PT*("`@("`@("`@("`@("`@("1S=6)S=%]F<F]M
M6UT@/2`D85LG9G)O;2==.PT*("`@("`@("`@("`@("`@("1S=6)S=%]T;UM=
M(#T@)'1O.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1T
M:&ES+3YL;V=G97(M/FQO9R@S+"`B9&]I;F<@(B`N('-I>F5O9B@D<W5B<W1?
M9G)O;2D@+@T*("`@("`@("`@("`@(B!S=6)S=&ET=71I;VXH<RD@9F]R("1D
M97-T(BD[#0H@("`@("`@(&EF("AS:7IE;V8H)'-U8G-T7V9R;VTI*2![#0H@
M("`@("`@("`@("`D8V]N=&5N=',@/2!S=')?<F5P;&%C92@D<W5B<W1?9G)O
M;2P@)'-U8G-T7W1O+"`D8V]N=&5N=',I.PT*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B`D8V]N=&5N=',[#0H@("`@?0T*?0T*/SX`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]4
M87-K+U5N:7AE;VPN<&AP````````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P-3(R,2`Q,#4Q-30S,S<S,2`P,C(R-3$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`-"B\J*@T*("H@/'1A
M<VMS.G5N:7AE;VP^#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J
M#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@
M=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V
M86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L
M;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?
M,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@
M=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T
M:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC
M96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I
M871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@
M("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P
M:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O
M=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93
M.B`D260Z(%5N:7AE;VPN<&AP+'8@,2XX(#(P,#8O,#$O,#8@,#0Z-#<Z,S<@
M8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N
M;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B
M;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"B\J*@T*("H@0F%S92!C
M;&%S<PT*("HO#0IR97%U:7)E7V]N8V4@)U!%05(O5&%S:R]#;VUM;VXN<&AP
M)SL-"B\J*@T*("H@26UP;&5M96YT<R!T:&4@=6YI>"!L:6YE(&5N9&EN9W,@
M9FEL92!T87-K+@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@
M("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P
M:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O
M=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L
M96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN
M970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B
M;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"F-L87-S(%!%05)?5&%S
M:U]5;FEX96]L(&5X=&5N9',@4$5!4E]487-K7T-O;6UO;@T*>PT*("`@('9A
M<B`D='EP92`]("=S:6UP;&4G.PT*("`@('9A<B`D<&AA<V4@/2!014%27U1!
M4TM?4$%#2T%'13L-"B`@("!V87(@)%]R97!L86-E;65N=',[#0H-"B`@("`O
M*BH-"B`@("`@*B!686QI9&%T92!T:&4@<F%W('AM;"!A="!P87)S:6YG+71I
M;64N#0H@("`@("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C(-"B`@("`@
M*B!`<&%R86T@87)R87D@<F%W+"!P87)S960@>&UL#0H@("`@("H@0'!A<F%M
M(%!%05)?0V]N9FEG#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U
M;F-T:6]N('9A;&ED871E6&UL*"1P:V<L("1X;6PL("8D8V]N9FEG+"`D9FEL
M95AM;"D-"B`@("![#0H@("`@("`@(&EF("@D>&UL("$]("<G*2![#0H@("`@
M("`@("`@("!R971U<FX@87)R87DH4$5!4E]405-+7T524D]27TE.5D%,240L
M("=N;R!A='1R:6)U=&5S(&%L;&]W960G*3L-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!);FET
M:6%L:7IE(&$@=&%S:R!I;G-T86YC92!W:71H('1H92!P87)A;65T97)S#0H@
M("`@("H@0'!A<F%M(&%R<F%Y(')A=RP@<&%R<V5D('AM;`T*("`@("`J($!P
M87)A;2!U;G5S960-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!I;FET*"1X;6PL
M("1A='1R:6)S*0T*("`@('L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!2
M97!L86-E(&%L;"!L:6YE(&5N9&EN9W,@=VET:"!L:6YE(&5N9&EN9W,@8W5S
M=&]M:7IE9"!F;W(@=&AE(&-U<G)E;G0@3U,-"B`@("`@*@T*("`@("`J(%-E
M92!V86QI9&%T95AM;"@I('-O=7)C92!F;W(@=&AE(&-O;7!L971E(&QI<W0@
M;V8@86QL;W=E9"!F:65L9',-"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E
M1FEL95]V,7Q014%27U!A8VMA9V5&:6QE7W8R#0H@("`@("H@0'!A<F%M('-T
M<FEN9R!F:6QE(&-O;G1E;G1S#0H@("`@("H@0'!A<F%M('-T<FEN9R!T:&4@
M979E;G1U86P@9FEN86P@9FEL92!L;V-A=&EO;B`H:6YF;W)M871I;VYA;"!O
M;FQY*0T*("`@("`J($!R971U<FX@<W1R:6YG?&9A;'-E?%!%05)?17)R;W(@
M9F%L<V4@=&\@<VMI<"!T:&ES(&9I;&4L(%!%05)?17)R;W(@=&\@9F%I;`T*
M("`@("`J("`@("`@("`@*'5S92`D=&AI<RT^=&AR;W=%<G)O<BDL(&]T:&5R
M=VES92!R971U<FX@=&AE(&YE=R!C;VYT96YT<PT*("`@("`J+PT*("`@(&9U
M;F-T:6]N('-T87)T4V5S<VEO;B@D<&MG+"`D8V]N=&5N=',L("1D97-T*0T*
M("`@('L-"B`@("`@("`@)'1H:7,M/FQO9V=E<BT^;&]G*#,L(")R97!L86-I
M;F<@86QL(&QI;F4@96YD:6YG<R!W:71H(%Q<;B!I;B`D9&5S="(I.PT*("`@
M("`@("!R971U<FX@<')E9U]R97!L86-E*"(O7')<;GQ<;EQR?%QR?%QN+R(L
M(")<;B(L("1C;VYT96YT<RD[#0H@("`@?0T*?0T*/SX`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+U1A<VLO5VEN9&]W<V5O;"YP
M:'``````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`U,C$U(#$P-3$U
M-#,S-S,Q(#`R,C<V,P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`T*+RHJ#0H@*B`\=&%S:W,Z=VEN9&]W<V5O;#X-
M"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z
M(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O
M9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U
M9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*
M("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO
M=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N
M<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E
M8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@
M<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@
M*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`
M875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`
M8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N
M<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0
M($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@5VEN9&]W
M<V5O;"YP:'`L=B`Q+C<@,C`P-B\P,2\P-B`P-#HT-SHS-R!C96QL;V<@17AP
M("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G
M92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!2
M96QE87-E(#$N-"XP83$-"B`J+PT*+RHJ#0H@*B!"87-E(&-L87-S#0H@*B\-
M"G)E<75I<F5?;VYC92`G4$5!4B]487-K+T-O;6UO;BYP:'`G.PT*+RHJ#0H@
M*B!);7!L96UE;G1S('1H92!W:6YD;W=S(&QI;F4@96YD<VEN9W,@9FEL92!T
M87-K+@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!
M4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T
M/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J
M($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT
M>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@
M,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN
M8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"F-L87-S(%!%05)?5&%S:U]7:6YD
M;W=S96]L(&5X=&5N9',@4$5!4E]487-K7T-O;6UO;@T*>PT*("`@('9A<B`D
M='EP92`]("=S:6UP;&4G.PT*("`@('9A<B`D<&AA<V4@/2!014%27U1!4TM?
M4$%#2T%'13L-"B`@("!V87(@)%]R97!L86-E;65N=',[#0H-"B`@("`O*BH-
M"B`@("`@*B!686QI9&%T92!T:&4@<F%W('AM;"!A="!P87)S:6YG+71I;64N
M#0H@("`@("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C(-"B`@("`@*B!`
M<&%R86T@87)R87D@<F%W+"!P87)S960@>&UL#0H@("`@("H@0'!A<F%M(%!%
M05)?0V]N9FEG#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T
M:6]N('9A;&ED871E6&UL*"1P:V<L("1X;6PL("8D8V]N9FEG+"`D9FEL95AM
M;"D-"B`@("![#0H@("`@("`@(&EF("@D>&UL("$]("<G*2![#0H@("`@("`@
M("`@("!R971U<FX@87)R87DH4$5!4E]405-+7T524D]27TE.5D%,240L("=N
M;R!A='1R:6)U=&5S(&%L;&]W960G*3L-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!);FET:6%L
M:7IE(&$@=&%S:R!I;G-T86YC92!W:71H('1H92!P87)A;65T97)S#0H@("`@
M("H@0'!A<F%M(&%R<F%Y(')A=RP@<&%R<V5D('AM;`T*("`@("`J($!P87)A
M;2!U;G5S960-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!I;FET*"1X;6PL("1A
M='1R:6)S*0T*("`@('L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!297!L
M86-E(&%L;"!L:6YE(&5N9&EN9W,@=VET:"!W:6YD;W=S(&QI;F4@96YD:6YG
M<PT*("`@("`J#0H@("`@("H@4V5E('9A;&ED871E6&UL*"D@<V]U<F-E(&9O
M<B!T:&4@8V]M<&QE=&4@;&ES="!O9B!A;&QO=V5D(&9I96QD<PT*("`@("`J
M($!P87)A;2!014%27U!A8VMA9V5&:6QE7W8Q?%!%05)?4&%C:V%G949I;&5?
M=C(-"B`@("`@*B!`<&%R86T@<W1R:6YG(&9I;&4@8V]N=&5N=',-"B`@("`@
M*B!`<&%R86T@<W1R:6YG('1H92!E=F5N='5A;"!F:6YA;"!F:6QE(&QO8V%T
M:6]N("AI;F9O<FUA=&EO;F%L(&]N;'DI#0H@("`@("H@0')E='5R;B!S=')I
M;F=\9F%L<V5\4$5!4E]%<G)O<B!F86QS92!T;R!S:VEP('1H:7,@9FEL92P@
M4$5!4E]%<G)O<B!T;R!F86EL#0H@("`@("H@("`@("`@("`H=7-E("1T:&ES
M+3YT:')O=T5R<F]R*2P@;W1H97)W:7-E(')E='5R;B!T:&4@;F5W(&-O;G1E
M;G1S#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<W1A<G1397-S:6]N*"1P:V<L
M("1C;VYT96YT<RP@)&1E<W0I#0H@("`@>PT*("`@("`@("`D=&AI<RT^;&]G
M9V5R+3YL;V<H,RP@(G)E<&QA8VEN9R!A;&P@;&EN92!E;F1I;F=S('=I=&@@
M7%QR7%QN(&EN("1D97-T(BD[#0H@("`@("`@(')E='5R;B!P<F5G7W)E<&QA
M8V4H(B]<<EQN?%QN7')\7')\7&XO(BP@(EQR7&XB+"`D8V]N=&5N=',I.PT*
M("`@('T-"GT-"C\^````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+U!%05(O5F%L:61A=&]R````````````````````````````````
M````````````````````````````````````````````,#`P-S4U(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S$@,#(Q,#8Q`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]686QI9&%T;W(O4$5#3"YP
M:'``````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-#$T,R`Q,#4Q
M-30S,S<S,2`P,C(S-S8`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`-"B\J*@T*("H@0VAA;FYE;"!686QI9&%T;W(@
M9F]R('1H92!P96-L+G!H<"YN970@8VAA;FYE;`T*("H-"B`J(%!(4"`T(&%N
M9"!02%`@-0T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E
M("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`
M<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R
M;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-6
M4SH@)$ED.B!014-,+G!H<"QV(#$N-R`R,#`V+S`R+S`S(#`R.C`R.C(R(&-E
M;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE
M="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE
M('-I;F-E(%)E;&5A<V4@,2XT+C!A-0T*("HO#0HO*BH-"B`J(%1H:7,@:7,@
M=&AE('!A<F5N="!C;&%S<R!F;W(@86QL('9A;&ED871O<G,-"B`J+PT*<F5Q
M=6ER95]O;F-E("=014%2+U9A;&ED871E+G!H<"<[#0HO*BH-"B`J($-H86YN
M96P@5F%L:61A=&]R(&9O<B!T:&4@<&5C;"YP:'`N;F5T(&-H86YN96P-"B`J
M($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A
M=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C
M;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS
M92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@
M3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@
M*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!
M4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A
M<V4@,2XT+C!A-0T*("HO#0IC;&%S<R!014%27U9A;&ED871O<E]014-,(&5X
M=&5N9',@4$5!4E]686QI9&%T90T*>PT*("`@(&9U;F-T:6]N('9A;&ED871E
M5F5R<VEO;B@I#0H@("`@>PT*("`@("`@("!I9B`H)'1H:7,M/E]S=&%T92`]
M/2!014%27U9!3$E$051%7U!!0TM!1TE.1RD@>PT*("`@("`@("`@("`@)'9E
M<G-I;VX@/2`D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=%9E<G-I;VXH*3L-"B`@
M("`@("`@("`@("1V97)S:6]N8V]M<&]N96YT<R`](&5X<&QO9&4H)RXG+"`D
M=F5R<VEO;BD[#0H@("`@("`@("`@("`D;&%S="`](&%R<F%Y7W!O<"@D=F5R
M<VEO;F-O;7!O;F5N=',I.PT*("`@("`@("`@("`@:68@*'-U8G-T<B@D;&%S
M="P@,2P@,BD@/3T@)W)C)RD@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M861D1F%I;'5R92@G=F5R<VEO;B<L("=296QE87-E($-A;F1I9&%T92!V97)S
M:6]N<R!M=7-T(&AA=F4@)R`N#0H@("`@("`@("`@("`@("`@)W5P<&5R+6-A
M<V4@4D,L(&YO="!L;W=E<BUC87-E(')C)RD[#0H@("`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('9A;&ED
M871E4&%C:V%G94YA;64H*0T*("`@('L-"B`@("`@("`@)')E="`]('!A<F5N
M=#HZ=F%L:61A=&5086-K86=E3F%M92@I.PT*("`@("`@("!I9B`H)'1H:7,M
M/E]P86-K86=E>&UL+3YG971086-K86=E5'EP92@I(#T]("=E>'1S<F,G*2![
M#0H@("`@("`@("`@("!I9B`H<W1R=&]L;W=E<B@D=&AI<RT^7W!A8VMA9V5X
M;6PM/F=E=%!A8VMA9V4H*2D@(3T-"B`@("`@("`@("`@("`@("`@('-T<G1O
M;&]W97(H)'1H:7,M/E]P86-K86=E>&UL+3YG9710<F]V:61E<T5X=&5N<VEO
M;B@I*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?861D5V%R;FEN9R@G
M<')O=FED97-E>'1E;G-I;VXG+"`G<&%C:V%G92!N86UE("(G("X-"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E>&UL+3YG971086-K86=E
M*"D@+B`G(B!I<R!D:69F97)E;G0@9G)O;2!E>'1E;G-I;VX@;F%M92`B)R`N
M#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G97AM;"T^9V5T
M4')O=FED97-%>'1E;G-I;VXH*2`N("<B)RD[#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*?0T*/SX`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM
M86YD````````````````````````````````````````````````````````
M```````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#`P,"`Q,#4Q-30S,S<S,2`P,C`U,3(`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]014%2+T-O;6UA;F0O4&%C:V%G92YP:'`N;W)I9P``````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,3,W,#4Q(#$P-3$U-#,S-S,Q(#`R,S8P,P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`T*+RHJ#0H@*B!014%27T-O;6UA;F1?4&%C:V%G92`H<&%C:V%G92P@<&%C
M:V%G92UV86QI9&%T92P@8W9S9&EF9BP@8W9S=&%G+"!P86-K86=E+61E<&5N
M9&5N8VEE<RP-"B`J('-I9VXL(&UA:V5R<&TL(&-O;G9E<G0@8V]M;6%N9',I
M#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%
M.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@
M;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O
M=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-
M"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y
M;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E
M;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W
M96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T
M('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*
M("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@
M0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U
M=&AO<B`@("`@36%R=&EN($IA;G-E;B`\;6I`<&AP+FYE=#X-"B`J($!A=71H
M;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y
M<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@
M("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC
M96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!086-K86=E+G!H
M<"QV(#$N,3$Y(#(P,#8O,#,O,#(@,3@Z,30Z,3,@8V5L;&]G($5X<"`D#0H@
M*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!
M4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S
M92`P+C$-"B`J+PT*#0HO*BH-"B`J(&)A<V4@8VQA<W,-"B`J+PT*<F5Q=6ER
M95]O;F-E("=014%2+T-O;6UA;F0O0V]M;6]N+G!H<"<[#0H-"B\J*@T*("H@
M4$5!4B!C;VUM86YD<R!F;W(@;&]G:6XO;&]G;W5T#0H@*@T*("H@0&-A=&5G
M;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@
M("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@
M36%R=&EN($IA;G-E;B`\;6I`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@($=R
M96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y
M.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-
M"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@
M("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E
M("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,"XQ#0H@*B\-
M"@T*8VQA<W,@4$5!4E]#;VUM86YD7U!A8VMA9V4@97AT96YD<R!014%27T-O
M;6UA;F1?0V]M;6]N#0I[#0H@("`@+R\@>WM[('!R;W!E<G1I97,-"@T*("`@
M('9A<B`D8V]M;6%N9',@/2!A<G)A>2@-"B`@("`@("`@)W!A8VMA9V4G(#T^
M(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("="=6EL9"!086-K
M86=E)RP-"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O4&%C:V%G92<L
M#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=P)RP-"B`@("`@("`@("`@
M("=O<'1I;VYS)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`G;F]C;VUP
M<F5S<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P
M="<@/3X@)UHG+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G1&\@
M;F]T(&=Z:7`@=&AE('!A8VMA9V4@9FEL92<-"B`@("`@("`@("`@("`@("`@
M("`@*2P-"B`@("`@("`@("`@("`@("`G<VAO=VYA;64G(#T^(&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=N)RP-"B`@("`@
M("`@("`@("`@("`@("`@)V1O8R<@/3X@)U!R:6YT('1H92!N86UE(&]F('1H
M92!P86-K86=E9"!F:6QE+B<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@
M("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("=D;V,G(#T^("=;9&5S
M8V9I;&5=(%MD97-C9FEL93)=#0I#<F5A=&5S(&$@4$5!4B!P86-K86=E(&9R
M;VT@:71S(&1E<V-R:7!T:6]N(&9I;&4@*'5S=6%L;'D@8V%L;&5D#0IP86-K
M86=E+GAM;"DN("!)9B!A('-E8V]N9"!P86-K86=E9FEL92!I<R!P87-S960@
M:6XL('1H96X-"G1H92!P86-K86=E<B!W:6QL(&-H96-K('1O(&UA:V4@<W5R
M92!T:&%T(&]N92!I<R!A('!A8VMA9V4N>&UL#0IV97)S:6]N(#$N,"P@86YD
M('1H92!O=&AE<B!I<R!A('!A8VMA9V4N>&UL('9E<G-I;VX@,BXP+B`@5&AE
M#0IP86-K86=E+GAM;"!V97)S:6]N(#$N,"!W:6QL(&)E('-A=F5D(&%S(")P
M86-K86=E+GAM;"(@:6X@=&AE(&%R8VAI=F4L#0IA;F0@=&AE(&]T:&5R(&%S
M(")P86-K86=E,BYX;6PB(&EN('1H92!A<F-H:79E(@T*)PT*("`@("`@("`@
M("`@*2P-"B`@("`@("`@)W!A8VMA9V4M=F%L:61A=&4G(#T^(&%R<F%Y*`T*
M("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=686QI9&%T92!086-K86=E($-O
M;G-I<W1E;F-Y)RP-"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O4&%C
M:V%G959A;&ED871E)RP-"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)W!V
M)RP-"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@I+`T*("`@("`@
M("`@("`@)V1O8R<@/3X@)PT*)RP-"B`@("`@("`@("`@("DL#0H@("`@("`@
M("=C=G-D:69F)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]
M/B`G4G5N(&$@(F-V<R!D:69F(B!F;W(@86QL(&9I;&5S(&EN(&$@<&%C:V%G
M92<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;T-V<T1I9F8G+`T*
M("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G8V0G+`T*("`@("`@("`@("`@
M)V]P=&EO;G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=Q=6EE="<@
M/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@
M)W$G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G0F4@<75I970G
M+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=R
M96%L;'EQ=6EE="<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S
M:&]R=&]P="<@/3X@)U$G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]
M/B`G0F4@<F5A;&QY('%U:65T)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-
M"B`@("`@("`@("`@("`@("`G9&%T92<@/3X@87)R87DH#0H@("`@("`@("`@
M("`@("`@("`@("=S:&]R=&]P="<@/3X@)T0G+`T*("`@("`@("`@("`@("`@
M("`@("`G9&]C)R`]/B`G1&EF9B!A9V%I;G-T(')E=FES:6]N(&]F($1!5$4G
M+`T*("`@("`@("`@("`@("`@("`@("`G87)G)R`]/B`G1$%412<L#0H@("`@
M("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@)W)E;&5A<V4G
M(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^
M("=2)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)T1I9F8@86=A
M:6YS="!T86<@9F]R('!A8VMA9V4@<F5L96%S92!214PG+`T*("`@("`@("`@
M("`@("`@("`@("`G87)G)R`]/B`G4D5,)RP-"B`@("`@("`@("`@("`@("`@
M("`@*2P-"B`@("`@("`@("`@("`@("`G<F5V:7-I;VXG(#T^(&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=R)RP-"B`@("`@
M("`@("`@("`@("`@("`@)V1O8R<@/3X@)T1I9F8@86=A:6YS="!R979I<VEO
M;B!2158G+`T*("`@("`@("`@("`@("`@("`@("`G87)G)R`]/B`G4D56)RP-
M"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G8V]N
M=&5X="<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P
M="<@/3X@)V,G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G1V5N
M97)A=&4@8V]N=&5X="!D:69F)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-
M"B`@("`@("`@("`@("`@("`G=6YI9FEE9"<@/3X@87)R87DH#0H@("`@("`@
M("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)W4G+`T*("`@("`@("`@("`@
M("`@("`@("`G9&]C)R`]/B`G1V5N97)A=&4@=6YI9FEE9"!D:69F)RP-"B`@
M("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G:6=N;W)E
M+6-A<V4G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O
M<'0G(#T^("=I)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)TEG
M;F]R92!C87-E+"!C;VYS:61E<B!U<'!E<BT@86YD(&QO=V5R+6-A<V4@;&5T
M=&5R<R!E<75I=F%L96YT)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@
M("`@("`@("`@("`@("`G:6=N;W)E+7=H:71E<W!A8V4G(#T^(&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=B)RP-"B`@("`@
M("`@("`@("`@("`@("`@)V1O8R<@/3X@)TEG;F]R92!C:&%N9V5S(&EN(&%M
M;W5N="!O9B!W:&ET92!S<&%C92<L#0H@("`@("`@("`@("`@("`@("`@("DL
M#0H@("`@("`@("`@("`@("`@)VEG;F]R92UB;&%N:RUL:6YE<R<@/3X@87)R
M87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)T(G+`T*
M("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G26=N;W)E(&-H86YG97,@
M=&AA="!I;G-E<G0@;W(@9&5L971E(&)L86YK(&QI;F5S)RP-"B`@("`@("`@
M("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G8G)I968G(#T^(&%R
M<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G4F5P;W)T(&]N
M;'D@=VAE=&AE<B!T:&4@9FEL97,@9&EF9F5R+"!N;R!D971A:6QS)RP-"B`@
M("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G9')Y+7)U
M;B<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@
M/3X@)VXG+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G1&]N7"=T
M(&1O(&%N>71H:6YG+"!J=7-T('!R971E;F0G+`T*("`@("`@("`@("`@("`@
M("`@("`I+`T*("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`G9&]C
M)R`]/B`G/'!A8VMA9V4N>&UL/@T*0V]M<&%R97,@86QL('1H92!F:6QE<R!I
M;B!A('!A8VMA9V4N("!7:71H;W5T(&%N>2!O<'1I;VYS+"!T:&ES#0IC;VUM
M86YD('=I;&P@8V]M<&%R92!T:&4@8W5R<F5N="!C;V1E('=I=&@@=&AE(&QA
M<W0@8VAE8VME9"UI;B!C;V1E+@T*57-I;F<@=&AE("UR(&]R("U2(&]P=&EO
M;B!Y;W4@;6%Y(&-O;7!A<F4@=&AE(&-U<G)E;G0@8V]D92!W:71H('1H870-
M"F]F(&$@<W!E8VEF:6,@<F5L96%S92X-"B<L#0H@("`@("`@("`@("`I+`T*
M("`@("`@("`G8W9S=&%G)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM
M87)Y)R`]/B`G4V5T($-64R!296QE87-E(%1A9R<L#0H@("`@("`@("`@("`G
M9G5N8W1I;VXG(#T^("=D;T-V<U1A9R<L#0H@("`@("`@("`@("`G<VAO<G1C
M=70G(#T^("=C="<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH
M#0H@("`@("`@("`@("`@("`@)W%U:65T)R`]/B!A<G)A>2@-"B`@("`@("`@
M("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G<2<L#0H@("`@("`@("`@("`@
M("`@("`@("=D;V,G(#T^("="92!Q=6EE="<L#0H@("`@("`@("`@("`@("`@
M("`@("DL#0H@("`@("`@("`@("`@("`@)W)E86QL>7%U:65T)R`]/B!A<G)A
M>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G42<L#0H@
M("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("="92!R96%L;'D@<75I970G
M+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=S
M;&ED92<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P
M="<@/3X@)T8G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G36]V
M92`H<VQI9&4I('1A9R!I9B!I="!E>&ES=',G+`T*("`@("`@("`@("`@("`@
M("`@("`I+`T*("`@("`@("`@("`@("`@("=D96QE=&4G(#T^(&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=D)RP-"B`@("`@
M("`@("`@("`@("`@("`@)V1O8R<@/3X@)U)E;6]V92!T86<G+`T*("`@("`@
M("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=D<GDM<G5N)R`]
M/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G
M;B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=$;VY<)W0@9&\@
M86YY=&AI;F<L(&IU<W0@<')E=&5N9"<L#0H@("`@("`@("`@("`@("`@("`@
M("DL#0H@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("=D;V,G(#T^
M("<\<&%C:V%G92YX;6P^(%MF:6QE<RXN+ET-"E-E=',@82!#5E,@=&%G(&]N
M(&%L;"!F:6QE<R!I;B!A('!A8VMA9V4N("!5<V4@=&AI<R!C;VUM86YD(&%F
M=&5R('EO=2!H879E#0IP86-K86=E9"!A(&1I<W1R:6)U=&EO;B!T87)B86QL
M('=I=&@@=&AE(")P86-K86=E(B!C;VUM86YD('1O('1A9R!W:&%T#0IR979I
M<VEO;G,@;V8@=VAA="!F:6QE<R!W97)E(&EN('1H870@<F5L96%S92X@($EF
M(&YE960@=&\@9FEX('-O;65T:&EN9PT*869T97(@<G5N;FEN9R!C=G-T86<@
M;VYC92P@8G5T(&)E9F]R92!T:&4@=&%R8F%L;"!I<R!R96QE87-E9"!T;R!T
M:&4@<'5B;&EC+`T*=7-E('1H92`B<VQI9&4B(&]P=&EO;B!T;R!M;W9E('1H
M92!R96QE87-E('1A9RX-"@T*=&\@:6YC;'5D92!F:6QE<R`H<W5C:"!A<R!A
M('-E8V]N9"!P86-K86=E+GAM;"P@;W(@=&5S=',@;F]T(&EN8VQU9&5D(&EN
M('1H90T*<F5L96%S92DL('!A<W,@=&AE;2!A<R!A9&1I=&EO;F%L('!A<F%M
M971E<G,N#0HG+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@)W!A8VMA9V4M
M9&5P96YD96YC:65S)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y
M)R`]/B`G4VAO=R!P86-K86=E(&1E<&5N9&5N8VEE<R<L#0H@("`@("`@("`@
M("`G9G5N8W1I;VXG(#T^("=D;U!A8VMA9V5$97!E;F1E;F-I97,G+`T*("`@
M("`@("`@("`@)W-H;W)T8W5T)R`]/B`G<&0G+`T*("`@("`@("`@("`@)V]P
M=&EO;G,G(#T^(&%R<F%Y*"DL#0H@("`@("`@("`@("`G9&]C)R`]/B`G#0I,
M:7-T(&%L;"!D97!E;F-I97,@=&AE('!A8VMA9V4@:&%S+B<-"B`@("`@("`@
M("`@("DL#0H@("`@("`@("=S:6=N)R`]/B!A<G)A>2@-"B`@("`@("`@("`@
M("=S=6UM87)Y)R`]/B`G4VEG;B!A('!A8VMA9V4@9&ES=')I8G5T:6]N(&9I
M;&4G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]3:6=N)RP-"B`@
M("`@("`@("`@("=S:&]R=&-U="<@/3X@)W-I)RP-"B`@("`@("`@("`@("=O
M<'1I;VYS)R`]/B!A<G)A>2@I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)SQP
M86-K86=E+69I;&4^#0I3:6=N<R!A('!A8VMA9V4@9&ES=')I8G5T:6]N("@N
M=&%R(&]R("YT9WHI(&9I;&4@=VET:"!';G501RXG+`T*("`@("`@("`@("`@
M*2P-"B`@("`@("`@)VUA:V5R<&TG(#T^(&%R<F%Y*`T*("`@("`@("`@("`@
M)W-U;6UA<GDG(#T^("="=6EL9',@86X@4E!-('-P96,@9FEL92!F<F]M(&$@
M4$5!4B!P86-K86=E)RP-"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O
M36%K95)032<L#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=R<&TG+`T*
M("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@
M("`@("=S<&5C+71E;7!L871E)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`@("`@)W-H;W)T;W!T)R`]/B`G="<L#0H@("`@("`@("`@("`@("`@("`@
M("=A<F<G(#T^("=&24Q%)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@
M/3X@)U5S92!&24Q%(&%S(%)032!S<&5C(&9I;&4@=&5M<&QA=&4G#0H@("`@
M("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@)W)P;2UP:V=N
M86UE)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T
M)R`]/B`G<"<L#0H@("`@("`@("`@("`@("`@("`@("=A<F<G(#T^("=&3U)-
M050G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G57-E($9/4DU!
M5"!A<R!F;W)M870@<W1R:6YG(&9O<B!24$T@<&%C:V%G92!N86UE+"`E<R!I
M<R!R97!L86-E9`T*8GD@=&AE(%!%05(@<&%C:V%G92!N86UE+"!D969A=6QT
M<R!T;R`B4$5!4CHZ)7,B+B<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@
M("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("=D;V,G(#T^("<\<&%C
M:V%G92UF:6QE/@T*#0I#<F5A=&5S(&%N(%)032`N<W!E8R!F:6QE(&9O<B!W
M<F%P<&EN9R!A(%!%05(@<&%C:V%G92!I;G-I9&4@86X@4E!-#0IP86-K86=E
M+B`@26YT96YD960@=&\@8F4@=7-E9"!F<F]M('1H92!34$5#4R!D:7)E8W1O
M<GDL('=I=&@@=&AE(%!%05(-"G!A8VMA9V4@=&%R8F%L;"!I;B!T:&4@4T]5
M4D-%4R!D:7)E8W1O<GDZ#0H-"B0@<&5A<B!M86ME<G!M("XN+U-/55)#15,O
M3F5T7U-O8VME="TQ+C`N=&=Z#0I7<F]T92!24$T@<W!E8R!F:6QE(%!%05(Z
M.DYE=%]'96\M,2XP+G-P96,-"B0@<G!M("UB8B!014%2.CI.971?4V]C:V5T
M+3$N,"YS<&5C#0HN+BX-"E=R;W1E.B`O=7-R+W-R8R]R961H870O4E!-4R]I
M,S@V+U!%05(Z.DYE=%]3;V-K970M,2XP+3$N:3,X-BYR<&T-"B<L#0H@("`@
M("`@("`@("`I+`T*("`@("`@("`G8V]N=F5R="<@/3X@87)R87DH#0H@("`@
M("`@("`@("`G<W5M;6%R>2<@/3X@)T-O;G9E<G0@82!P86-K86=E+GAM;"`Q
M+C`@=&\@<&%C:V%G92YX;6P@,BXP(&9O<FUA="<L#0H@("`@("`@("`@("`G
M9G5N8W1I;VXG(#T^("=D;T-O;G9E<G0G+`T*("`@("`@("`@("`@)W-H;W)T
M8W5T)R`]/B`G8S(G+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y
M*`T*("`@("`@("`@("`@("`@("=F;&%T)R`]/B!A<G)A>2@-"B`@("`@("`@
M("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G9B<L#0H@("`@("`@("`@("`@
M("`@("`@("=D;V,G(#T^("=D;R!N;W0@8F5A=71I9GD@=&AE(&9I;&5L:7-T
M+B<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@
M*2P-"B`@("`@("`@("`@("=D;V,G(#T^("=;9&5S8V9I;&5=(%MD97-C9FEL
M93)=#0I#;VYV97)T<R!A('!A8VMA9V4N>&UL(&EN(#$N,"!F;W)M870@:6YT
M;R!A('!A8VMA9V4N>&UL#0II;B`R+C`@9F]R;6%T+B`@5&AE(&YE=R!F:6QE
M('=I;&P@8F4@;F%M960@<&%C:V%G93(N>&UL(&)Y(&1E9F%U;'0L#0IA;F0@
M<&%C:V%G92YX;6P@=VEL;"!B92!U<V5D(&%S('1H92!O;&0@9FEL92!B>2!D
M969A=6QT+@T*5&AI<R!I<R!N;W0@=&AE(&UO<W0@:6YT96QL:6=E;G0@8V]N
M=F5R<VEO;BP@86YD('-H;W5L9"!O;FQY(&)E#0IU<V5D(&9O<B!A=71O;6%T
M960@8V]N=F5R<VEO;B!O<B!L96%R;FEN9R!T:&4@9F]R;6%T+@T*)PT*("`@
M("`@("`@("`@*2P-"B`@("`@("`@*3L-"@T*("`@('9A<B`D;W5T<'5T.PT*
M#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R#0H-"B`@("`O
M*BH-"B`@("`@*B!014%27T-O;6UA;F1?4&%C:V%G92!C;VYS=')U8W1O<BX-
M"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@4$5!4E]#;VUM86YD7U!A8VMA9V4H)B1U:2P@)B1C;VYF:6<I
M#0H@("`@>PT*("`@("`@("!P87)E;G0Z.E!%05)?0V]M;6%N9%]#;VUM;VXH
M)'5I+"`D8V]N9FEG*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*("`@("\O
M('M[>R!?9&ES<&QA>59A;&ED871I;VY297-U;'1S*"D-"@T*("`@(&9U;F-T
M:6]N(%]D:7-P;&%Y5F%L:61A=&EO;E)E<W5L=',H)&5R<BP@)'=A<FXL("1S
M=')I8W0@/2!F86QS92D-"B`@("![#0H@("`@("`@(&9O<F5A8V@@*"1E<G(@
M87,@)&4I('L-"B`@("`@("`@("`@("1T:&ES+3YO=71P=70@+CT@(D5R<F]R
M.B`D95QN(CL-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D=V%R;B!A
M<R`D=RD@>PT*("`@("`@("`@("`@)'1H:7,M/F]U='!U="`N/2`B5V%R;FEN
M9SH@)'=<;B([#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/F]U='!U="`N
M/2!S<')I;G1F*"=686QI9&%T:6]N.B`E9"!E<G)O<BAS*2P@)60@=V%R;FEN
M9RAS*2<N(EQN(BP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('-I>F5O9B@D97)R*2P@<VEZ96]F*"1W87)N*2D[#0H@("`@("`@
M(&EF("@D<W1R:6-T("8F('-I>F5O9B@D97)R*2`^(#`I('L-"B`@("`@("`@
M("`@("1T:&ES+3YO=71P=70@+CT@(D9I>"!T:&5S92!E<G)O<G,@86YD('1R
M>2!A9V%I;BXB.PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]
M?0T*("`@(&9U;F-T:6]N("9G971086-K86=E<B@I#0H@("`@>PT*("`@("`@
M("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]086-K86=E<B<I*2![#0H@("`@
M("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O4&%C:V%G97(N<&AP)SL-"B`@
M("`@("`@?0T*("`@("`@("`D82`]("9N97<@4$5!4E]086-K86=E<CL-"B`@
M("`@("`@<F5T=7)N("1A.PT*("`@('T-"@T*("`@(&9U;F-T:6]N("9G9710
M86-K86=E1FEL92@D8V]N9FEG+"`D9&5B=6<@/2!F86QS92P@)'1M<&1I<B`]
M(&YU;&PI#0H@("`@>PT*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!
M4E]#;VUM;VXG*2D@>PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2
M+T-O;6UO;BYP:'`G.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A8VQA<W-?
M97AI<W1S*"=014%2+U!A8VMA9V5&:6QE+G!H<"<I*2![#0H@("`@("`@("`@
M("!R97%U:7)E7V]N8V4@)U!%05(O4&%C:V%G949I;&4N<&AP)SL-"B`@("`@
M("`@?0T*("`@("`@("`D82`]("9N97<@4$5!4E]086-K86=E1FEL92@D8V]N
M9FEG+"`D9&5B=6<L("1T;7!D:7(I.PT*("`@("`@("`D8V]M;6]N(#T@;F5W
M(%!%05)?0V]M;6]N.PT*("`@("`@("`D8V]M;6]N+3YU:2`]("1T:&ES+3YU
M:3L-"B`@("`@("`@)&$M/G-E=$QO9V=E<B@D8V]M;6]N*3L-"B`@("`@("`@
M<F5T=7)N("1A.PT*("`@('T-"B`@("`O+R![>WL@9&]086-K86=E*"D-"@T*
M("`@(&9U;F-T:6]N(&1O4&%C:V%G92@D8V]M;6%N9"P@)&]P=&EO;G,L("1P
M87)A;7,I#0H@("`@>PT*("`@("`@("`D=&AI<RT^;W5T<'5T(#T@)R<[#0H@
M("`@("`@("1P:V=I;F9O9FEL92`](&ES<V5T*"1P87)A;7-;,%TI(#\@)'!A
M<F%M<ULP72`Z("=P86-K86=E+GAM;"<[#0H@("`@("`@("1P:V<R(#T@:7-S
M970H)'!A<F%M<ULQ72D@/R`D<&%R86US6S%=(#H@;G5L;#L-"B`@("`@("`@
M:68@*"$D<&MG,B`F)B`A:7-S970H)'!A<F%M<ULP72DI('L-"B`@("`@("`@
M("`@(&EF("AF:6QE7V5X:7-T<R@G<&%C:V%G93(N>&UL)RDI('L-"B`@("`@
M("`@("`@("`@("`D<&MG,B`]("=P86-K86=E,BYX;6PG.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@("1P86-K86=E<B`]("8D=&AI<RT^
M9V5T4&%C:V%G97(H*3L-"B`@("`@("`@)&-O;7!R97-S(#T@96UP='DH)&]P
M=&EO;G-;)VYO8V]M<')E<W,G72D@/R!T<G5E(#H@9F%L<V4[#0H@("`@("`@
M("1R97-U;'0@/2`D<&%C:V%G97(M/G!A8VMA9V4H)'!K9VEN9F]F:6QE+"`D
M8V]M<')E<W,L("1P:V<R*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)')E<W5L="DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@D<F5S=6QT*3L-"B`@("`@("`@?0T*("`@("`@("`O+R!$;VXG="!W
M86YT(&]U='!U="P@;VYL>2!T:&4@<&%C:V%G92!F:6QE(&YA;64@:G5S="!C
M<F5A=&5D#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG<VAO=VYA;64G
M72DI('L-"B`@("`@("`@("`@("1T:&ES+3YO=71P=70@/2`D<F5S=6QT.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("@D=&AI<RT^;W5T<'5T*2![#0H@("`@
M("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)'1H:7,M/F]U='!U="P@
M)&-O;6UA;F0I.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*
M("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!D;U!A8VMA9V5686QI
M9&%T92@I#0H-"B`@("!F=6YC=&EO;B!D;U!A8VMA9V5686QI9&%T92@D8V]M
M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I#0H@("`@>PT*("`@("`@("`D=&AI
M<RT^;W5T<'5T(#T@)R<[#0H@("`@("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@
M/"`Q*2![#0H@("`@("`@("`@("`D<&%R86US6S!=(#T@(G!A8VMA9V4N>&UL
M(CL-"B`@("`@("`@?0T*("`@("`@("`D;V)J(#T@)B1T:&ES+3YG971086-K
M86=E1FEL92@D=&AI<RT^8V]N9FEG+"`D=&AI<RT^7V1E8G5G*3L-"B`@("`@
M("`@)&]B:BT^<F%W4F5T=7)N*"D[#0H@("`@("`@(%!%05(Z.G-T871I8U!U
M<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@
M)&EN9F\@/2`D;V)J+3YF<F]M5&=Z1FEL92@D<&%R86US6S!=+"!014%27U9!
M3$E$051%7TY/4DU!3"D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1I
M;F9O*2D@>PT*("`@("`@("`@("`@)&EN9F\@/2`D;V)J+3YF<F]M4&%C:V%G
M949I;&4H)'!A<F%M<ULP72P@4$5!4E]604Q)1$%415].3U)-04PI.PT*("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&%R8VAI=F4@/2`D:6YF;RT^
M9V5T07)C:&EV949I;&4H*3L-"B`@("`@("`@("`@("1T87(@/2`F;F5W($%R
M8VAI=F5?5&%R*"1A<F-H:79E*3L-"B`@("`@("`@("`@("1T87(M/F5X=')A
M8W0H9&ER;F%M92@D:6YF;RT^9V5T4&%C:V%G949I;&4H*2DI.PT*("`@("`@
M("`@("`@)&EN9F\M/G-E=%!A8VMA9V5&:6QE*&1I<FYA;64H)&EN9F\M/F=E
M=%!A8VMA9V5&:6QE*"DI("X@1$E214-43U)97U-%4$%2051/4B`N#0H@("`@
M("`@("`@("`@("`@)&EN9F\M/F=E=%!A8VMA9V4H*2`N("<M)R`N("1I;F9O
M+3YG971697)S:6]N*"D@+B!$25)%0U1/4EE?4T5005)!5$]2("X-"B`@("`@
M("`@("`@("`@("!B87-E;F%M92@D:6YF;RT^9V5T4&%C:V%G949I;&4H*2DI
M.PT*("`@("`@("!]#0H@("`@("`@(%!%05(Z.G-T871I8U!O<$5R<F]R2&%N
M9&QI;F<H*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&EN9F\I*2![
M#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&EN9F\I
M.PT*("`@("`@("!]#0H@("`@("`@("1V86QI9"`](&9A;'-E.PT*("`@("`@
M("!I9B`H)&EN9F\M/F=E=%!A8VMA9V5X;6Q697)S:6]N*"D@/3T@)S(N,"<I
M('L-"B`@("`@("`@("`@(&EF("@D=F%L:60@/2`D:6YF;RT^=F%L:61A=&4H
M4$5!4E]604Q)1$%415].3U)-04PI*2![#0H@("`@("`@("`@("`@("`@)&EN
M9F\M/F9L871T96Y&:6QE3&ES="@I.PT*("`@("`@("`@("`@("`@("1V86QI
M9"`]("1I;F9O+3YV86QI9&%T92A014%27U9!3$E$051%7U!!0TM!1TE.1RD[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`D=F%L:60@/2`D:6YF;RT^=F%L:61A=&4H4$5!4E]604Q)1$%415]004-+
M04=)3D<I.PT*("`@("`@("!]#0H@("`@("`@("1E<G(@/2!A<G)A>2@I.PT*
M("`@("`@("`D=V%R;B`](&%R<F%Y*"D[#0H@("`@("`@(&EF("@A)'9A;&ED
M*2![#0H@("`@("`@("`@("!F;W)E86-H("@D:6YF;RT^9V5T5F%L:61A=&EO
M;E=A<FYI;F=S*"D@87,@)&5R<F]R*2![#0H@("`@("`@("`@("`@("`@:68@
M*"1E<G)O<ELG;&5V96PG72`]/2`G=V%R;FEN9R<I('L-"B`@("`@("`@("`@
M("`@("`@("`@)'=A<FY;72`]("1E<G)O<ELG;65S<V%G92==.PT*("`@("`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1E<G);
M72`]("1E<G)O<ELG;65S<V%G92==.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7V1I<W!L
M87E686QI9&%T:6]N4F5S=6QT<R@D97)R+"`D=V%R;BD[#0H@("`@("`@("1T
M:&ES+3YU:2T^;W5T<'5T1&%T82@D=&AI<RT^;W5T<'5T+"`D8V]M;6%N9"D[
M#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*
M("`@("\O('M[>R!D;T-V<U1A9R@I#0H-"B`@("!F=6YC=&EO;B!D;T-V<U1A
M9R@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I#0H@("`@>PT*("`@("`@
M("`D=&AI<RT^;W5T<'5T(#T@)R<[#0H@("`@("`@("1?8VUD(#T@)&-O;6UA
M;F0[#0H@("`@("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@/"`Q*2![#0H@("`@
M("`@("`@("`D:&5L<"`]("1T:&ES+3YG971(96QP*"1C;VUM86YD*3L-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B)&-O;6UA;F0Z
M(&UI<W-I;F<@<&%R86UE=&5R.B`D:&5L<%LP72(I.PT*("`@("`@("!]#0H@
M("`@("`@("1O8FH@/2`F)'1H:7,M/F=E=%!A8VMA9V5&:6QE*"1T:&ES+3YC
M;VYF:6<L("1T:&ES+3Y?9&5B=6<I.PT*("`@("`@("`D:6YF;R`]("1O8FHM
M/F9R;VU!;GE&:6QE*"1P87)A;7-;,%TL(%!%05)?5D%,241!5$5?3D]234%,
M*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&EN9F\I*2![#0H@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&EN9F\I.PT*("`@
M("`@("!]#0H@("`@("`@("1E<G(@/2`D=V%R;B`](&%R<F%Y*"D[#0H@("`@
M("`@(&EF("@A)&EN9F\M/G9A;&ED871E*"DI('L-"B`@("`@("`@("`@(&9O
M<F5A8V@@*"1I;F9O+3YG971686QI9&%T:6]N5V%R;FEN9W,H*2!A<R`D97)R
M;W(I('L-"B`@("`@("`@("`@("`@("!I9B`H)&5R<F]R6R=L979E;"==(#T]
M("=W87)N:6YG)RD@>PT*("`@("`@("`@("`@("`@("`@("`D=V%R;EM=(#T@
M)&5R<F]R6R=M97-S86=E)UT[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`@("`@)&5R<EM=(#T@)&5R<F]R6R=M97-S86=E
M)UT[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@(&EF("@A)'1H:7,M/E]D:7-P;&%Y5F%L:61A=&EO;E)E
M<W5L=',H)&5R<BP@)'=A<FXL('1R=64I*2![#0H@("`@("`@("`@("`D=&AI
M<RT^=6DM/F]U='!U=$1A=&$H)'1H:7,M/F]U='!U="P@)&-O;6UA;F0I.PT*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=#5E,@=&%G
M(&9A:6QE9"<I.PT*("`@("`@("!]#0H@("`@("`@("1V97)S:6]N(#T@)&EN
M9F\M/F=E=%9E<G-I;VXH*3L-"B`@("`@("`@)&-V<W9E<G-I;VX@/2!P<F5G
M7W)E<&QA8V4H)R];7F$M>C`M.5TO:2<L("=?)RP@)'9E<G-I;VXI.PT*("`@
M("`@("`D8W9S=&%G(#T@(E)%3$5!4T5?)&-V<W9E<G-I;VXB.PT*("`@("`@
M("`D9FEL97,@/2!A<G)A>5]K97ES*"1I;F9O+3YG971&:6QE;&ES="@I*3L-
M"B`@("`@("`@)&-O;6UA;F0@/2`B8W9S(CL-"B`@("`@("`@:68@*&ES<V5T
M*"1O<'1I;VYS6R=Q=6EE="==*2D@>PT*("`@("`@("`@("`@)&-O;6UA;F0@
M+CT@)R`M<2<[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1O<'1I
M;VYS6R=R96%L;'EQ=6EE="==*2D@>PT*("`@("`@("`@("`@)&-O;6UA;F0@
M+CT@)R`M42<[#0H@("`@("`@('T-"B`@("`@("`@)&-O;6UA;F0@+CT@)R!T
M86<G.PT*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W-L:61E)UTI*2![
M#0H@("`@("`@("`@("`D8V]M;6%N9"`N/2`G("U&)SL-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)V1E;&5T92==*2D@>PT*("`@
M("`@("`@("`@)&-O;6UA;F0@+CT@)R`M9"<[#0H@("`@("`@('T-"B`@("`@
M("`@)&-O;6UA;F0@+CT@)R`G("X@)&-V<W1A9R`N("<@)R`N(&5S8V%P97-H
M96QL87)G*"1P87)A;7-;,%TI.PT*("`@("`@("!A<G)A>5]S:&EF="@D<&%R
M86US*3L-"B`@("`@("`@:68@*&-O=6YT*"1P87)A;7,I*2![#0H@("`@("`@
M("`@("`O+R!A9&0@:6X@861D:71I;VYA;"!F:6QE<R!T;R!B92!T86=G960-
M"B`@("`@("`@("`@("1F:6QE<R`](&%R<F%Y7VUE<F=E*"1F:6QE<RP@)'!A
M<F%M<RD[#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H)&9I;&5S(&%S
M("1F:6QE*2![#0H@("`@("`@("`@("`D8V]M;6%N9"`N/2`G("<@+B!E<V-A
M<&5S:&5L;&%R9R@D9FEL92D[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1T
M:&ES+3YC;VYF:6<M/F=E="@G=F5R8F]S92<I(#X@,2D@>PT*("`@("`@("`@
M("`@)'1H:7,M/F]U='!U="`N/2`B*R`D8V]M;6%N9%QN(CL-"B`@("`@("`@
M?0T*("`@("`@("`D=&AI<RT^;W5T<'5T("X]("(K("1C;VUM86YD7&XB.PT*
M("`@("`@("!I9B`H96UP='DH)&]P=&EO;G-;)V1R>2UR=6XG72DI('L-"B`@
M("`@("`@("`@("1F<"`]('!O<&5N*"1C;VUM86YD+"`B<B(I.PT*("`@("`@
M("`@("`@=VAI;&4@*"1L:6YE(#T@9F=E=',H)&9P+"`Q,#(T*2D@>PT*("`@
M("`@("`@("`@("`@("1T:&ES+3YO=71P=70@+CT@<G1R:6TH)&QI;F4I+B)<
M;B([#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!P8VQO<V4H)&9P*3L-
M"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)'1H
M:7,M/F]U='!U="P@)%]C;60I.PT*("`@("`@("!R971U<FX@=')U93L-"B`@
M("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9&]#=G-$:69F*"D-"@T*
M("`@(&9U;F-T:6]N(&1O0W9S1&EF9B@D8V]M;6%N9"P@)&]P=&EO;G,L("1P
M87)A;7,I#0H@("`@>PT*("`@("`@("`D=&AI<RT^;W5T<'5T(#T@)R<[#0H@
M("`@("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@/"`Q*2![#0H@("`@("`@("`@
M("`D:&5L<"`]("1T:&ES+3YG971(96QP*"1C;VUM86YD*3L-"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B)&-O;6UA;F0Z(&UI<W-I
M;F<@<&%R86UE=&5R.B`D:&5L<%LP72(I.PT*("`@("`@("!]#0H@("`@("`@
M("1O8FH@/2`F)'1H:7,M/F=E=%!A8VMA9V5&:6QE*"1T:&ES+3YC;VYF:6<L
M("1T:&ES+3Y?9&5B=6<I.PT*("`@("`@("`D:6YF;R`]("1O8FHM/F9R;VU!
M;GE&:6QE*"1P87)A;7-;,%TL(%!%05)?5D%,241!5$5?3D]234%,*3L-"B`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)&EN9F\I*2![#0H@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&EN9F\I.PT*("`@("`@("!]
M#0H@("`@("`@("1E<G(@/2`D=V%R;B`](&%R<F%Y*"D[#0H@("`@("`@(&EF
M("@A)&EN9F\M/G9A;&ED871E*"DI('L-"B`@("`@("`@("`@(&9O<F5A8V@@
M*"1I;F9O+3YG971686QI9&%T:6]N5V%R;FEN9W,H*2!A<R`D97)R;W(I('L-
M"B`@("`@("`@("`@("`@("!I9B`H)&5R<F]R6R=L979E;"==(#T]("=W87)N
M:6YG)RD@>PT*("`@("`@("`@("`@("`@("`@("`D=V%R;EM=(#T@)&5R<F]R
M6R=M97-S86=E)UT[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`@("`@)&5R<EM=(#T@)&5R<F]R6R=M97-S86=E)UT[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@(&EF("@A)'1H:7,M/E]D:7-P;&%Y5F%L:61A=&EO;E)E<W5L=',H
M)&5R<BP@)'=A<FXL('1R=64I*2![#0H@("`@("`@("`@("`D=&AI<RT^=6DM
M/F]U='!U=$1A=&$H)'1H:7,M/F]U='!U="P@)&-O;6UA;F0I.PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=#5E,@9&EF9B!F86EL
M960G*3L-"B`@("`@("`@?0T*("`@("`@("`D:6YF;S$@/2`D:6YF;RT^9V5T
M1FEL96QI<W0H*3L-"B`@("`@("`@)&9I;&5S(#T@)&EN9F\Q.PT*("`@("`@
M("`D8VUD(#T@(F-V<R([#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG
M<75I970G72DI('L-"B`@("`@("`@("`@("1C;60@+CT@)R`M<2<[#0H@("`@
M("`@("`@("!U;G-E="@D;W!T:6]N<ULG<75I970G72D[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=R96%L;'EQ=6EE="==*2D@
M>PT*("`@("`@("`@("`@)&-M9"`N/2`G("U1)SL-"B`@("`@("`@("`@('5N
M<V5T*"1O<'1I;VYS6R=R96%L;'EQ=6EE="==*3L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W)E;&5A<V4G72DI('L-"B`@("`@
M("`@("`@("1C=G-V97)S:6]N(#T@<')E9U]R97!L86-E*"<O6UYA+7HP+3E=
M+VDG+"`G7R<L("1O<'1I;VYS6R=R96QE87-E)UTI.PT*("`@("`@("`@("`@
M)&-V<W1A9R`](")214Q%05-%7R1C=G-V97)S:6]N(CL-"B`@("`@("`@("`@
M("1O<'1I;VYS6R=R979I<VEO;B==(#T@)&-V<W1A9SL-"B`@("`@("`@("`@
M('5N<V5T*"1O<'1I;VYS6R=R96QE87-E)UTI.PT*("`@("`@("!]#0H@("`@
M("`@("1E>&5C=71E(#T@=')U93L-"B`@("`@("`@:68@*&ES<V5T*"1O<'1I
M;VYS6R=D<GDM<G5N)UTI*2![#0H@("`@("`@("`@("`D97AE8W5T92`](&9A
M;'-E.PT*("`@("`@("`@("`@=6YS970H)&]P=&EO;G-;)V1R>2UR=6XG72D[
M#0H@("`@("`@('T-"B`@("`@("`@)&-M9"`N/2`G(&1I9F8G.PT*("`@("`@
M("`O+R!T:&4@<F5S="!O9B!T:&4@;W!T:6]N<R!A<F4@<&%S<V5D(')I9VAT
M(&]N('1O(")C=G,@9&EF9B(-"B`@("`@("`@9F]R96%C:"`H)&]P=&EO;G,@
M87,@)&]P=&EO;B`]/B`D;W!T87)G*2![#0H@("`@("`@("`@("`D87)G(#T@
M0"1T:&ES+3YC;VUM86YD<ULD8V]M;6%N9%U;)V]P=&EO;G,G75LD;W!T:6]N
M75LG87)G)UT[#0H@("`@("`@("`@("`D<VAO<G0@/2!`)'1H:7,M/F-O;6UA
M;F1S6R1C;VUM86YD75LG;W!T:6]N<R==6R1O<'1I;VY=6R=S:&]R=&]P="==
M.PT*("`@("`@("`@("`@)&-M9"`N/2`D<VAO<G0@/R`B("TD<VAO<G0B(#H@
M(B`M+21O<'1I;VXB.PT*("`@("`@("`@("`@:68@*"1A<F<@)B8@)&]P=&%R
M9RD@>PT*("`@("`@("`@("`@("`@("1C;60@+CT@*"1S:&]R="`_("<G(#H@
M)STG*2`N(&5S8V%P97-H96QL87)G*"1O<'1A<F<I.PT*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@(&9O<F5A8V@@*"1F:6QE<R!A<R`D9FEL
M92D@>PT*("`@("`@("`@("`@)&-M9"`N/2`G("<@+B!E<V-A<&5S:&5L;&%R
M9R@D9FEL95LG;F%M92==*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'1H
M:7,M/F-O;F9I9RT^9V5T*"=V97)B;W-E)RD@/B`Q*2![#0H@("`@("`@("`@
M("`D=&AI<RT^;W5T<'5T("X]("(K("1C;61<;B([#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"1E>&5C=71E*2![#0H@("`@("`@("`@("`D9G`@/2!P;W!E
M;B@D8VUD+"`B<B(I.PT*("`@("`@("`@("`@=VAI;&4@*"1L:6YE(#T@9F=E
M=',H)&9P+"`Q,#(T*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3YO=71P
M=70@+CT@<G1R:6TH)&QI;F4I+B)<;B([#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!P8VQO<V4H)&9P*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI
M<RT^=6DM/F]U='!U=$1A=&$H)'1H:7,M/F]U='!U="P@)&-O;6UA;F0I.PT*
M("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@
M("`O+R![>WL@9&]086-K86=E1&5P96YD96YC:65S*"D-"@T*("`@(&9U;F-T
M:6]N(&1O4&%C:V%G941E<&5N9&5N8VEE<R@D8V]M;6%N9"P@)&]P=&EO;G,L
M("1P87)A;7,I#0H@("`@>PT*("`@("`@("`O+R`D<&%R86US6S!=("T^('1H
M92!014%2('!A8VMA9V4@=&\@;&ES="!I=',@:6YF;W)M871I;VX-"B`@("`@
M("`@:68@*'-I>F5O9B@D<&%R86US*2`A/2`Q*2![#0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F)A9"!P87)A;65T97(H<RDL('1R
M>2!<(FAE;'`@)&-O;6UA;F1<(B(I.PT*("`@("`@("!]#0H@("`@("`@("1O
M8FH@/2`F)'1H:7,M/F=E=%!A8VMA9V5&:6QE*"1T:&ES+3YC;VYF:6<L("1T
M:&ES+3Y?9&5B=6<I.PT*("`@("`@("`D:6YF;R`]("1O8FHM/F9R;VU!;GE&
M:6QE*"1P87)A;7-;,%TL(%!%05)?5D%,241!5$5?3D]234%,*3L-"B`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)&EN9F\I*2![#0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&EN9F\I.PT*("`@("`@("!]#0H@
M("`@("`@("1D97!S(#T@)&EN9F\M/F=E=$1E<',H*3L-"B`@("`@("`@:68@
M*&ES7V%R<F%Y*"1D97!S*2D@>PT*("`@("`@("`@("`@:68@*"1I;F9O+3YG
M971086-K86=E>&UL5F5R<VEO;B@I(#T]("<Q+C`G*2![#0H@("`@("`@("`@
M("`@("`@)&1A=&$@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)V-A
M<'1I;VXG(#T^("=$97!E;F1E;F-I97,@9F]R('!E87(O)R`N("1I;F9O+3YG
M971086-K86=E*"DL#0H@("`@("`@("`@("`@("`@("`@("=B;W)D97(G(#T^
M('1R=64L#0H@("`@("`@("`@("`@("`@("`@("=H96%D;&EN92<@/3X@87)R
M87DH(E)E<75I<F5D/R(L(")4>7!E(BP@(DYA;64B+"`B4F5L871I;VXB+"`B
M5F5R<VEO;B(I+`T*("`@("`@("`@("`@("`@("`@("`I.PT*#0H@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)&1E<',@87,@)&0I('L-"B`@("`@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1D6R=O<'1I;VYA;"==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"1D6R=O<'1I;VYA;"==(#T]("=Y97,G
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E<2`]("=.;R<[
M#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1R97$@/2`G665S)SL-"B`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1R97$@/2`G665S)SL-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)'1H:7,M/E]D97!S7W)E;%]T<F%N<ULD9%LG<F5L)UU=*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)')E;"`]("1T:&ES+3Y?9&5P<U]R96Q?
M=')A;G-;)&1;)W)E;"==73L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1R96P@/2`D9%LG<F5L)UT[
M#0H@("`@("`@("`@("`@("`@("`@('T-"@T*("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]D97!S7W1Y<&5?=')A;G-;)&1;)W1Y<&4G
M75TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D='EP92`]('5C9FER
M<W0H)'1H:7,M/E]D97!S7W1Y<&5?=')A;G-;)&1;)W1Y<&4G75TI.PT*("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1Y<&4@/2`D9%LG='EP92==.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D6R=N86UE
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D;F%M92`]("1D6R=N
M86UE)UT[#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D;F%M92`]("<G.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D6R=V
M97)S:6]N)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=F5R<VEO
M;B`]("1D6R=V97)S:6]N)UT[#0H@("`@("`@("`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=F5R<VEO;B`]("<G.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H-"B`@("`@("`@("`@("`@("`@("`@
M)&1A=&%;)V1A=&$G75M=(#T@87)R87DH)')E<2P@)'1Y<&4L("1N86UE+"`D
M<F5L+"`D=F5R<VEO;BD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@?2!E;'-E('L@+R\@<&%C:V%G92YX;6P@,BXP(&1E<&5N9&5N8VEE<R!D
M:7-P;&%Y#0H@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+T1E
M<&5N9&5N8WDR+G!H<"<[#0H@("`@("`@("`@("`@("`@)&1E<',@/2`D:6YF
M;RT^9V5T1&5P96YD96YC:65S*"D[#0H@("`@("`@("`@("`@("`@)')E9R`]
M("8D=&AI<RT^8V]N9FEG+3YG971296=I<W1R>2@I.PT*("`@("`@("`@("`@
M("`@(&EF("AI<U]A<G)A>2@D9&5P<RDI('L-"B`@("`@("`@("`@("`@("`@
M("`@)&0@/2!N97<@4$5!4E]$97!E;F1E;F-Y,B@D=&AI<RT^8V]N9FEG+"!A
M<G)A>2@I+"`G)RD[#0H@("`@("`@("`@("`@("`@("`@("1D871A(#T@87)R
M87DH#0H@("`@("`@("`@("`@("`@("`@("`@("`G8V%P=&EO;B<@/3X@)T1E
M<&5N9&5N8VEE<R!F;W(@)R`N("1I;F9O+3YG971086-K86=E*"DL#0H@("`@
M("`@("`@("`@("`@("`@("`@("`G8F]R9&5R)R`]/B!T<G5E+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@)VAE861L:6YE)R`]/B!A<G)A>2@B4F5Q=6ER
M960_(BP@(E1Y<&4B+"`B3F%M92(L("=697)S:6]N:6YG)RP@)T=R;W5P)RDL
M#0H@("`@("`@("`@("`@("`@("`@("`@("`I.PT*("`@("`@("`@("`@("`@
M("`@("!F;W)E86-H("@D9&5P<R!A<R`D='EP92`]/B`D<W5B9"D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)')E<2`]("@D='EP92`]/2`G<F5Q=6ER
M960G*2`_("=997,G(#H@)TYO)SL-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@D='EP92`]/2`G9W)O=7`G*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&=R;W5P(#T@)'-U8F1;)V%T=')I8G,G75LG;F%M92==.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9W)O=7`@/2`G)SL-"B`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)'-U8F1;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'-U8F0@/2!A<G)A>2@D<W5B9"D[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D<W5B9"!A
M<R`D9W)O=7!A*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R
M96%C:"`H)&=R;W5P82!A<R`D9&5P='EP92`]/B`D9&5P:6YF;RD@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&1E<'1Y<&4@/3T@
M)V%T=')I8G,G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&1E
M<'1Y<&4@/3T@)W!E87)I;G-T86QL97(G*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9&5P='EP92`]("=P96%R($EN<W1A;&QE
M<B<[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D9&5P:6YF
M;ULP72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1D97!I;F9O(#T@87)R87DH)&1E<&EN9F\I.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1D97!I;F9O(&%S("1I;F8I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N86UE(#T@)R<[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&EN
M9ELG8VAA;FYE;"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1A;&EA<R`]("1R96<M/F-H86YN96Q!;&EA<R@D:6YF
M6R=C:&%N;F5L)UTI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@A)&%L:6%S*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1A;&EA<R`]("<H8VAA;FYE;#\I
M("<@+B1I;F9;)V-H86YN96PG73L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&YA;64@/2`D86QI87,@+B`G+R<[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&EN9ELG;F%M92==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1N86UE("X]("1I;F9;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D:6YF6R=P871T97)N
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&YA;64@+CT@)&EN9ELG<&%T=&5R;B==.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D;F%M92`N/2`G)SL-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D:6YF6R=U<FDG
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D;F%M92`N/2`G(%LG("X@)&EN9ELG=7)I)UT@+B`@)UTG.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I;F9;)V-O;F9L
M:6-T<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1V97(@/2`G8V]N9FQI8W1S)SL-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'9E<B`]("1D+3Y?9V5T17AT<F%3
M=')I;F<H)&EN9BD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M9&%T85LG9&%T82==6UT@/2!A<G)A>2@D<F5Q+"!U8V9I<G-T*"1D97!T>7!E
M*2P@)&YA;64L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'9E<BP@)&=R;W5P*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"@T*("`@("`@
M("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"1D871A+"`D8V]M;6%N9"D[
M#0H@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@?0T*#0H@("`@
M("`@("\O($9A;&QB86-K#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T
M82@B5&AI<R!P86-K86=E(&1O97,@;F]T(&AA=F4@86YY(&1E<&5N9&5N8VEE
M<RXB+"`D8V]M;6%N9"D[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@
M>WM[(&1O4VEG;B@I#0H-"B`@("!F=6YC=&EO;B!D;U-I9VXH)&-O;6UA;F0L
M("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@<F5Q=6ER95]O
M;F-E("=3>7-T96TN<&AP)SL-"B`@("`@("`@<F5Q=6ER95]O;F-E("=!<F-H
M:79E+U1A<BYP:'`G.PT*("`@("`@("`O+R!S:&]U;&0@;6]V92!M;W-T(&]F
M('1H:7,@8V]D92!I;G1O(%!%05)?4&%C:V%G97(-"B`@("`@("`@+R\@<V\@
M:70G;&P@8F4@96%S>2!T;R!I;7!L96UE;G0@(G!E87(@<&%C:V%G92`M+7-I
M9VXB#0H@("`@("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@(3T@,2D@>PT*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")B860@<&%R86UE
M=&5R*',I+"!T<GD@7")H96QP("1C;VUM86YD7"(B*3L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1P87)A;7-;,%TI*2![#0H@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F9I;&4@9&]E<R!N
M;W0@97AI<W0Z("1P87)A;7-;,%TB*3L-"B`@("`@("`@?0T*("`@("`@("`D
M;V)J(#T@)'1H:7,M/F=E=%!A8VMA9V5&:6QE*"1T:&ES+3YC;VYF:6<L("1T
M:&ES+3Y?9&5B=6<I.PT*("`@("`@("`D:6YF;R`]("1O8FHM/F9R;VU49WI&
M:6QE*"1P87)A;7-;,%TL(%!%05)?5D%,241!5$5?3D]234%,*3L-"B`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)&EN9F\I*2![#0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&EN9F\I.PT*("`@("`@("!]#0H@
M("`@("`@("1T87(@/2!N97<@07)C:&EV95]487(H)'!A<F%M<ULP72D[#0H@
M("`@("`@("1T;7!D:7(@/2!3>7-T96TZ.FUK=&5M<"@G+60@<&5A<G-I9VXG
M*3L-"B`@("`@("`@:68@*"$D=&%R+3YE>'1R86-T3&ES="@G<&%C:V%G93(N
M>&UL('!A8VMA9V4N<VEG)RP@)'1M<&1I<BDI('L-"B`@("`@("`@("`@(&EF
M("@A)'1A<BT^97AT<F%C=$QI<W0H)W!A8VMA9V4N>&UL('!A8VMA9V4N<VEG
M)RP@)'1M<&1I<BDI('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H(F9A:6QE9"!T;R!E>'1R86-T('1A<B!F:6QE(BD[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&9I;&5?97AI
M<W1S*"(D=&UP9&ER+W!A8VMA9V4N<VEG(BDI('L-"B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B<&%C:V%G92!A;')E861Y('-I9VYE
M9"(I.PT*("`@("`@("!]#0H@("`@("`@("1P86-K86=E>&UL(#T@)W!A8VMA
M9V4N>&UL)SL-"B`@("`@("`@:68@*&9I;&5?97AI<W1S*"(D=&UP9&ER+W!A
M8VMA9V4R+GAM;"(I*2![#0H@("`@("`@("`@("`D<&%C:V%G97AM;"`]("=P
M86-K86=E,BYX;6PG.PT*("`@("`@("!]#0H@("`@("`@($!U;FQI;FLH(B1T
M;7!D:7(O<&%C:V%G92YS:6<B*3L-"B`@("`@("`@)&EN<'5T(#T@)'1H:7,M
M/G5I+3YU<V5R1&EA;&]G*"1C;VUM86YD+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)T=N=5!'(%!A<W-P:')A<V4G
M*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*"=P87-S=V]R9"<I*3L-"B`@("`@("`@)&=P9R`]('!O<&5N*")G<&<@
M+2UB871C:"`M+7!A<W-P:')A<V4M9F0@,"`M+6%R;6]R("TM9&5T86-H+7-I
M9VX@+2UO=71P=70@)'1M<&1I<B]P86-K86=E+G-I9R`D=&UP9&ER+R1P86-K
M86=E>&UL(#(^+V1E=B]N=6QL(BP@(G<B*3L-"B`@("`@("`@:68@*"$D9W!G
M*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F=P
M9R!C;VUM86YD(&9A:6QE9"(I.PT*("`@("`@("!]#0H@("`@("`@(&9W<FET
M92@D9W!G+"`B)&EN<'5T6S!=7&XB*3L-"B`@("`@("`@:68@*'!C;&]S92@D
M9W!G*2!\?"`A9FEL95]E>&ES=',H(B1T;7!D:7(O<&%C:V%G92YS:6<B*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")G<&<@
M<VEG;B!F86EL960B*3L-"B`@("`@("`@?0T*("`@("`@("`D=&%R+3YA9&1-
M;V1I9GDH(B1T;7!D:7(O<&%C:V%G92YS:6<B+"`G)RP@)'1M<&1I<BD[#0H@
M("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*#0H@
M("`@+RHJ#0H@("`@("H@1F]R('5N:70@=&5S=&EN9R!P=7)P;W-E<PT*("`@
M("`J+PT*("`@(&9U;F-T:6]N("9G971);G-T86QL97(H)B1U:2D-"B`@("![
M#0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27TEN<W1A;&QE<B<I
M*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O26YS=&%L;&5R
M+G!H<"<[#0H@("`@("`@('T-"B`@("`@("`@)&$@/2`F;F5W(%!%05)?26YS
M=&%L;&5R*"1U:2D[#0H@("`@("`@(')E='5R;B`D83L-"B`@("!]#0H@("`@
M#0H@("`@+RHJ#0H@("`@("H@1F]R('5N:70@=&5S=&EN9R!P=7)P;W-E<PT*
M("`@("`J+PT*("`@(&9U;F-T:6]N("9G971#;VUM86YD4&%C:V%G:6YG*"8D
M=6DL("8D8V]N9FEG*0T*("`@('L-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES
M=',H)U!%05)?0V]M;6%N9%]086-K86=I;F<G*2D@>PT*("`@("`@("`@("`@
M0&EN8VQU9&5?;VYC92`G4$5!4B]#;VUM86YD+U!A8VMA9VEN9RYP:'`G.PT*
M("`@("`@("!]#0H@("`@("`@(`T*("`@("`@("!I9B`H8VQA<W-?97AI<W1S
M*"=014%27T-O;6UA;F1?4&%C:V%G:6YG)RDI('L-"B`@("`@("`@("`@("1A
M(#T@)FYE=R!014%27T-O;6UA;F1?4&%C:V%G:6YG*"1U:2P@)&-O;F9I9RD[
M#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D82`](&YU;&P[#0H@
M("`@("`@('T-"B`@("`@("`@<F5T=7)N("1A.PT*("`@('T-"@T*("`@("\O
M('M[>R!D;TUA:V524$TH*0T*#0H@("`@9G5N8W1I;VX@9&]-86ME4E!-*"1C
M;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@(')E
M<75I<F5?;VYC92`G4WES=&5M+G!H<"<[#0H@("`@("`@(')E<75I<F5?;VYC
M92`G07)C:&EV92]487(N<&AP)SL-"@T*("`@("`@("`O+R!#:&5C:R!T;R!S
M964@:68@4$5!4E]#;VUM86YD7U!A8VMA9VEN9R!I<R!I;G-T86QL960L(&%N
M9`T*("`@("`@("`O+R!T<F%N<W!A<F5N=&QY('-W:71C:"!T;R!U<V4@=&AE
M(")M86ME+7)P;2US<&5C(B!C;VUM86YD(&9R;VT@:70-"B`@("`@("`@+R\@
M:6YS=&5A9"P@:68@:70@9&]E<RX@3W1H97)W:7-E+"!C;VYT:6YU92!T;R!U
M<V4@=&AE(&]L9"!V97)S:6]N#0H@("`@("`@("\O(&]F(")M86ME<G!M(B!S
M=7!P;&EE9"!W:71H('1H:7,@<&%C:V%G92`H4$5!4BDN#0H@("`@("`@("1P
M86-K86=I;F=?8VUD(#T@)'1H:7,M/F=E=$-O;6UA;F1086-K86=I;F<H)'1H
M:7,M/G5I+"`D=&AI<RT^8V]N9FEG*3L-"B`@("`@("`@:68@*"1P86-K86=I
M;F=?8VUD("$]/2!N=6QL*2![#0H@("`@("`@("`@("`D=&AI<RT^=6DM/F]U
M='!U=$1A=&$H)U!%05)?0V]M;6%N9%]086-K86=I;F<@:7,@:6YS=&%L;&5D
M.R!U<VEN9R`G+@T*("`@("`@("`@("`@("`@("=N97=E<B`B;6%K92UR<&TM
M<W!E8R(@8V]M;6%N9"!I;G-T96%D)RD[#0H@("`@("`@("`@("!R971U<FX@
M)'!A8VMA9VEN9U]C;60M/G)U;B@G;6%K92UR<&TM<W!E8R<L("1O<'1I;VYS
M+"`D<&%R86US*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1T
M:&ES+3YU:2T^;W5T<'5T1&%T82@G5T%23DE.1SH@(G!E87(@;6%K97)P;2(@
M:7,@;F]W(&1E<')E8V%T960[(&%N("<N#0H@("`@("`@("`@("`@("=I;7!R
M;W9E9"!V97)S:6]N(&ES(&%V86EL86)L92!V:6$@(G!E87(@;6%K92UR<&TM
M<W!E8R(L('=H:6-H("<N#0H@("`@("`@("`@("`@("=I<R!A=F%I;&%B;&4@
M8GD@:6YS=&%L;&EN9R!014%27T-O;6UA;F1?4&%C:V%G:6YG)RD[#0H@("`@
M("`@('T-"B`@("`@("`@#0H@("`@("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@
M(3T@,2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*")B860@<&%R86UE=&5R*',I+"!T<GD@7")H96QP("1C;VUM86YD7"(B*3L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1P87)A;7-;
M,%TI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M(F9I;&4@9&]E<R!N;W0@97AI<W0Z("1P87)A;7-;,%TB*3L-"B`@("`@("`@
M?0T*("`@("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y
M*"D[#0H@("`@("`@("1P:V<@/2`F)'1H:7,M/F=E=%!A8VMA9V5&:6QE*"1T
M:&ES+3YC;VYF:6<L("1T:&ES+3Y?9&5B=6<I.PT*("`@("`@("`D<&8@/2`F
M)'!K9RT^9G)O;4%N>49I;&4H)'!A<F%M<ULP72P@4$5!4E]604Q)1$%415].
M3U)-04PI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<&8I*2![#0H@
M("`@("`@("`@("`D=2`]("1P9BT^9V5T57-E<FEN9F\H*3L-"B`@("`@("`@
M("`@(&EF("AI<U]A<G)A>2@D=2DI('L-"B`@("`@("`@("`@("`@("!F;W)E
M86-H("@D=2!A<R`D97)R*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("AI
M<U]A<G)A>2@D97)R*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&5R
M<B`]("1E<G);)VUE<W-A9V4G73L-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)&5R
M<BD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"(D<&%R86US6S!=(&ES
M(&YO="!A('9A;&ED('!A8VMA9V4B*3L-"B`@("`@("`@?0T*("`@("`@("`D
M=&UP9&ER(#T@4WES=&5M.CIM:W1E;7`H87)R87DH)RUD)RP@)W!E87(R<G!M
M)RDI.PT*("`@("`@("`D:6YS=')O;W0@/2!3>7-T96TZ.FUK=&5M<"AA<G)A
M>2@G+60G+"`G<&5A<C)R<&TG*2D[#0H@("`@("`@("1T;7`@/2`D=&AI<RT^
M8V]N9FEG+3YG970H)W9E<F)O<V4G*3L-"B`@("`@("`@)'1H:7,M/F-O;F9I
M9RT^<V5T*"=V97)B;W-E)RP@,"D[#0H@("`@("`@("1I;G-T86QL97(@/2`D
M=&AI<RT^9V5T26YS=&%L;&5R*"1T:&ES+3YU:2D[#0H@("`@("`@(')E<75I
M<F5?;VYC92`G4$5!4B]$;W=N;&]A9&5R+U!A8VMA9V4N<&AP)SL-"B`@("`@
M("`@)'!A8VL@/2!N97<@4$5!4E]$;W=N;&]A9&5R7U!A8VMA9V4H)&EN<W1A
M;&QE<BD[#0H@("`@("`@("1P86-K+3YS971086-K86=E1FEL92@D<&8I.PT*
M("`@("`@("`D<&%R86US6S!=(#T@)B1P86-K.PT*("`@("`@("`D:6YS=&%L
M;&5R+3YS971/<'1I;VYS*&%R<F%Y*"=I;G-T86QL<F]O="<@/3X@)&EN<W1R
M;V]T+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)VYO9&5P<R<@/3X@=')U92P@)W-O9G0G(#T^('1R=64I*3L-"B`@("`@
M("`@)&EN<W1A;&QE<BT^<V5T1&]W;FQO861E9%!A8VMA9V5S*"1P87)A;7,I
M.PT*("`@("`@("`D:6YF;R`]("1I;G-T86QL97(M/FEN<W1A;&PH)'!A<F%M
M<ULP72P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*"=I;G-T86QL<F]O="<@/3X@)&EN<W1R;V]T+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYO9&5P<R<@/3X@=')U
M92P@)W-O9G0G(#T^('1R=64I*3L-"B`@("`@("`@)'!K9V1I<B`]("1P9BT^
M9V5T4&%C:V%G92@I("X@)RTG("X@)'!F+3YG971697)S:6]N*"D[#0H@("`@
M("`@("1I;F9O6R=R<&U?>&UL7V1I<B==(#T@)R]V87(O;&EB+W!E87(G.PT*
M("`@("`@("`D=&AI<RT^8V]N9FEG+3YS970H)W9E<F)O<V4G+"`D=&UP*3L-
M"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=S<&5C+71E;7!L871E)UTI
M*2![#0H@("`@("`@("`@("`D<W!E8U]T96UP;&%T92`]("1O<'1I;VYS6R=S
M<&5C+71E;7!L871E)UT[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`D<W!E8U]T96UP;&%T92`]("<O:&]M92]L=6-E<B]W;W)K+W!E87(O<VAA
M<F4O<&AP+V1A=&$O4$5!4B]T96UP;&%T92YS<&5C)SL-"B`@("`@("`@?0T*
M("`@("`@("`D:6YF;ULG<&]S<VEB;&5?8VAA;FYE;"==(#T@)R<[#0H@("`@
M("`@("1I;F9O6R=E>'1R85]C;VYF:6<G72`]("<G.PT*("`@("`@("!I9B`H
M:7-S970H)&]P=&EO;G-;)W)P;2UP:V=N86UE)UTI*2![#0H@("`@("`@("`@
M("`D<G!M7W!K9VYA;65?9F]R;6%T(#T@)&]P=&EO;G-;)W)P;2UP:V=N86UE
M)UT[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!I9B`H)'!F+3YG
M971#:&%N;F5L*"D@/3T@)W!E87(N<&AP+FYE="<@?'P@)'!F+3YG971#:&%N
M;F5L*"D@/3T@)W!E8VPN<&AP+FYE="<I('L-"B`@("`@("`@("`@("`@("`D
M86QI87,@/2`G4$5!4B<[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("1C:&%N(#T@)B1R96<M/F=E=$-H86YN96PH)'!F+3YG971#
M:&%N;F5L*"DI.PT*("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1C:&%N*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H)&-H86XI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`D86QI87,@/2`D8VAA;BT^9V5T06QI87,H*3L-"B`@("`@
M("`@("`@("`@("`D86QI87,@/2!S=')T;W5P<&5R*"1A;&EA<RD[#0H@("`@
M("`@("`@("`@("`@)&EN9F];)W!O<W-I8FQE7V-H86YN96PG72`]("1P9BT^
M9V5T0VAA;FYE;"@I("X@)R\G.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@)')P;5]P:V=N86UE7V9O<FUA="`]("1A;&EA<R`N("<Z.B5S)SL-"B`@
M("`@("`@?0T*#0H@("`@("`@("1I;F9O6R=E>'1R85]H96%D97)S)UT@/2`G
M)SL-"B`@("`@("`@)&EN9F];)V1O8U]F:6QE<R==(#T@)R<[#0H@("`@("`@
M("1I;F9O6R=F:6QE<R==(#T@)R<[#0H@("`@("`@("1I;F9O6R=P86-K86=E
M,GAM;"==(#T@)R<[#0H@("`@("`@("1I;F9O6R=R<&U?<&%C:V%G92==(#T@
M<W!R:6YT9B@D<G!M7W!K9VYA;65?9F]R;6%T+"`D<&8M/F=E=%!A8VMA9V4H
M*2D[#0H@("`@("`@("1S<F-F:6QE<R`](#`[#0H@("`@("`@(&9O<F5A8V@@
M*"1I;F9O6R=F:6QE;&ES="==(&%S("1N86UE(#T^("1A='1R*2![#0H@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1A='1R6R=R;VQE)UTI*2![#0H@("`@("`@
M("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`D;F%M92`]('!R96=?<F5P;&%C92@G(5LO.EQ<7%Q=(2<L("<O)RP@)&YA
M;64I.PT*("`@("`@("`@("`@:68@*"1A='1R6R=R;VQE)UT@/3T@)V1O8R<I
M('L-"B`@("`@("`@("`@("`@("`D:6YF;ULG9&]C7V9I;&5S)UT@+CT@(B`D
M;F%M92([#0H@("`@("`@("`@("`O+R!-87`@<F]L92!T;R!T:&4@<G!M('9A
M<G,-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)&-?
M<')E9FEX(#T@)R5[7VQI8F1I<GTO<&AP+W!E87(G.PT*("`@("`@("`@("`@
M("`@('-W:71C:"`H)&%T=');)W)O;&4G72D@>PT*("`@("`@("`@("`@("`@
M("`@("!C87-E("=P:'`G.@T*("`@("`@("`@("`@("`@("`@("`@("`@)'!R
M969I>"`]("1C7W!R969I>#L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[
M#0H@("`@("`@("`@("`@("`@("`@(&-A<V4@)V5X="<Z#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D<')E9FEX(#T@)R5[7VQI8F1I<GTO<&AP)SL-"B`@
M("`@("`@("`@("`@("`@("`@8G)E86L[("\O(%A86"!G;V]D('!L86-E/PT*
M("`@("`@("`@("`@("`@("`@("!C87-E("=S<F,G.@T*("`@("`@("`@("`@
M("`@("`@("`@("`@)'-R8V9I;&5S*RL[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D<')E9FEX(#T@)R5[7VEN8VQU9&5D:7)]+W!H<"<[#0H@("`@("`@
M("`@("`@("`@("`@(&)R96%K.R`O+R!86%@@9V]O9"!P;&%C93\-"B`@("`@
M("`@("`@("`@("`@("`@8V%S92`G=&5S="<Z#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D<')E9FEX(#T@(B1C7W!R969I>"]T97-T<R\B("X@)'!F+3YG
M971086-K86=E*"D[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@
M("`@("`@("`@("`@("`@("!C87-E("=D871A)SH-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1P<F5F:7@@/2`B)&-?<')E9FEX+V1A=&$O(B`N("1P9BT^
M9V5T4&%C:V%G92@I.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@
M("`@("`@("`@("`@("`@("`@8V%S92`G<V-R:7!T)SH-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1P<F5F:7@@/2`G)7M?8FEN9&ER?2<[#0H@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@("`@("!D969A
M=6QT.B`O+R!N;VXM<W1A;F1A<F0@<F]L97,-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1P<F5F:7@@/2`B)&-?<')E9FEX+R1A='1R6W)O;&5=+R(@+B`D
M<&8M/F=E=%!A8VMA9V4H*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("1I
M;F9O6R=E>'1R85]C;VYF:6<G72`N/0T*("`@("`@("`@("`@("`@("`@("`@
M("`@(EQN("`@("`@("`M9"![)&%T=');<F]L95U]7V1I<CTD8U]P<F5F:7@O
M>R1A='1R6W)O;&5=?2!<7"([#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^=6DM/F]U='!U=$1A=&$H)U=!4DY)3D<Z(')O;&4@(B<@+B`D871T
M<ELG<F]L92==("X@)R(@=7-E9"P@)R`N#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)V%N9"!W:6QL(&)E(&EN<W1A;&QE9"!I;B`B)R`N("1C7W!R
M969I>"`N("<O)R`N("1A='1R6R=R;VQE)UT@+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("<O)R`N("1P9BT^9V5T4&%C:V%G92@I("X-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G("T@:&%N9"UE9&ET('1H92!F:6YA
M;"`N<W!E8R!I9B!T:&ES(&ES('=R;VYG)RP@)&-O;6UA;F0I.PT*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@)&YA;64@/2!S=')?<F5P;&%C92@G7%PG+"`G+R<L("1N
M86UE*3L-"B`@("`@("`@("`@("`@("`D:6YF;ULG9FEL97,G72`N/2`B)'!R
M969I>"\D;F%M95QN(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H)'-R8V9I;&5S(#X@,"D@>PT*("`@("`@("`@("`@<F5Q=6ER
M95]O;F-E("=/4R]'=65S<RYP:'`G.PT*("`@("`@("`@("`@)&]S(#T@;F5W
M($]37T=U97-S.PT*("`@("`@("`@("`@)&%R8V@@/2`D;W,M/F=E=$-P=2@I
M.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&%R8V@@/2`G;F]A
M<F-H)SL-"B`@("`@("`@?0T*("`@("`@("`D8V9G(#T@87)R87DH)VUA<W1E
M<E]S97)V97(G+"`G<&AP7V1I<B<L("=E>'1?9&ER)RP@)V1O8U]D:7(G+`T*
M("`@("`@("`@("`@("`@("`@("`@)V)I;E]D:7(G+"`G9&%T85]D:7(G+"`G
M=&5S=%]D:7(G*3L-"B`@("`@("`@9F]R96%C:"`H)&-F9R!A<R`D:RD@>PT*
M("`@("`@("`@("`@:68@*"1K(#T]("=M87-T97)?<V5R=F5R)RD@>PT*("`@
M("`@("`@("`@("`@("1C:&%N(#T@)')E9RT^9V5T0VAA;FYE;"@D<&8M/F=E
M=$-H86YN96PH*2D[#0H@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&-H86XI*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@D8VAA;BD[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("1I;F9O6R1K72`]("1C:&%N+3YG971397)V97(H*3L-
M"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("1I;F9O6R1K72`]("1T:&ES+3YC;VYF:6<M/F=E="@D:RD[
M#0H@("`@("`@('T-"B`@("`@("`@)&EN9F];)V%R8V@G72`]("1A<F-H.PT*
M("`@("`@("`D9G`@/2!`9F]P96XH)'-P96-?=&5M<&QA=&4L(")R(BD[#0H@
M("`@("`@(&EF("@A)&9P*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H(F-O=6QD(&YO="!O<&5N(%)032!S<&5C(&9I;&4@=&5M
M<&QA=&4@)'-P96-?=&5M<&QA=&4Z("1P:'!?97)R;W)M<V<B*3L-"B`@("`@
M("`@?0T*("`@("`@("`D:6YF;ULG<&%C:V%G92==(#T@)'!F+3YG971086-K
M86=E*"D[#0H@("`@("`@("1I;F9O6R=V97)S:6]N)UT@/2`D<&8M/F=E=%9E
M<G-I;VXH*3L-"B`@("`@("`@)&EN9F];)W)E;&5A<V5?;&EC96YS92==(#T@
M)'!F+3YG971,:6-E;G-E*"D[#0H@("`@("`@(&EF("@D<&8M/F=E=$1E<',H
M*2D@>PT*("`@("`@("`@("`@:68@*"1P9BT^9V5T4&%C:V%G97AM;%9E<G-I
M;VXH*2`]/2`G,2XP)RD@>PT*("`@("`@("`@("`@("`@("1R97%U:7)E<R`]
M("1C;VYF;&EC=',@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1P9BT^9V5T1&5P<R@I(&%S("1D97`I('L-"B`@("`@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1D97!;)V]P=&EO;F%L)UTI("8F("1D97!;)V]P
M=&EO;F%L)UT@/3T@)WEE<R<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@D9&5P6R=T>7!E)UT@(3T@)W!K9R<I('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=C
M:&%N;F5L)UTI("8F("1D97!;)V-H86YN96PG72`A/2`G<&5A<BYP:'`N;F5T
M)R`F)@T*("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P6R=C:&%N;F5L
M)UT@(3T@)W!E8VPN<&AP+FYE="<I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1C:&%N(#T@)B1R96<M/F=E=$-H86YN96PH)&1E<%LG8VAA;FYE;"==
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1C:&%N*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@D8VAA;BD[#0H@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`D<&%C:V%G92`]
M('-T<G1O=7!P97(H)&-H86XM/F=E=$%L:6%S*"DI("X@)SHZ)R`N("1D97!;
M)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1P86-K86=E(#T@)U!%05(Z.B<@+B`D9&5P
M6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@)'1R86YS(#T@87)R87DH#0H@("`@("`@("`@("`@("`@("`@
M("`@("`G/B<@/3X@)SXG+`T*("`@("`@("`@("`@("`@("`@("`@("`@)SPG
M(#T^("<\)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("<^/2<@/3X@)SX]
M)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("<\/2<@/3X@)SP])RP-"B`@
M("`@("`@("`@("`@("`@("`@("`@("<])R`]/B`G/2<L#0H@("`@("`@("`@
M("`@("`@("`@("`@("`G9W0G(#T^("<^)RP-"B`@("`@("`@("`@("`@("`@
M("`@("`@("=L="<@/3X@)SPG+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M)V=E)R`]/B`G/CTG+`T*("`@("`@("`@("`@("`@("`@("`@("`@)VQE)R`]
M/B`G/#TG+`T*("`@("`@("`@("`@("`@("`@("`@("`@)V5Q)R`]/B`G/2<L
M#0H@("`@("`@("`@("`@("`@("`@("D[#0H@("`@("`@("`@("`@("`@("`@
M(&EF("@D9&5P6R=R96PG72`]/2`G:&%S)RD@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)')E<75I<F5S6UT@/2`D<&%C:V%G93L-"B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E:68@*"1D97!;)W)E;"==(#T]("=N;W0G*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D8V]N9FQI8W1S6UT@/2`D<&%C:V%G
M93L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1D97!;)W)E;"==
M(#T]("=N92<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1C;VYF;&EC
M='-;72`]("1P86-K86=E("X@)R`]("<@+B`D9&5P6R=V97)S:6]N)UT[#0H@
M("`@("`@("`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D=')A;G-;)&1E
M<%LG<F5L)UU=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)')E<75I
M<F5S6UT@/2`D<&%C:V%G92`N("<@)R`N("1T<F%N<ULD9&5P6R=R96PG75T@
M+B`G("<@+B`D9&5P6R=V97)S:6]N)UT[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&-O
M=6YT*"1R97%U:7)E<RDI('L-"B`@("`@("`@("`@("`@("`@("`@)&EN9F];
M)V5X=')A7VAE861E<G,G72`N/2`G4F5Q=6ER97,Z("<@+B!I;7!L;V1E*"<L
M("<L("1R97%U:7)E<RD@+B`B7&XB.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!I9B`H8V]U;G0H)&-O;F9L:6-T<RDI('L-"B`@("`@
M("`@("`@("`@("`@("`@)&EN9F];)V5X=')A7VAE861E<G,G72`N/2`G0V]N
M9FQI8W1S.B`G("X@:6UP;&]D92@G+"`G+"`D8V]N9FQI8W1S*2`N(")<;B([
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`D:6YF;ULG<&%C:V%G93)X;6PG72`]("<R)SL@+R\@
M=&5L;"!T:&4@<W!E8R!T;R!U<V4@<&%C:V%G93(N>&UL#0H@("`@("`@("`@
M("`@("`@)')E<75I<F5S(#T@)&-O;F9L:6-T<R`](&%R<F%Y*"D[#0H@("`@
M("`@("`@("`@("`@)&1E<',@/2`D<&8M/F=E=$1E<',H=')U92D[#0H@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1D97!S6R=R97%U:7)E9"==6R=P86-K
M86=E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&1E
M<'-;)W)E<75I<F5D)UU;)W!A8VMA9V4G75LP72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1D97!S6R=R97%U:7)E9"==6R=P86-K86=E)UT@/2!A
M<G)A>2@D9&5P<ULG<F5Q=6ER960G75LG<&%C:V%G92==*3L-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D
M9&5P<ULG<F5Q=6ER960G75LG<&%C:V%G92==(&%S("1D97`I('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("@D9&5P6R=C:&%N;F5L)UT@(3T@)W!E
M87(N<&AP+FYE="<@)B8@("1D97!;)V-H86YN96PG72`A/2`G<&5C;"YP:'`N
M;F5T)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C:&%N(#T@
M)B1R96<M/F=E=$-H86YN96PH)&1E<%LG8VAA;FYE;"==*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8VAA;BDI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*"1C:&%N*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A8VMA
M9V4@/2!S=')T;W5P<&5R*"1C:&%N+3YG971!;&EA<R@I*2`N("<Z.B<@+B`D
M9&5P6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E(#T@)U!%
M05(Z.B<@+B`D9&5P6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG
M8V]N9FQI8W1S)UTI("8F("AI<W-E="@D9&5P6R=M:6XG72D@?'P-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&ES<V5T*"1D97!;)VUA>"==*2DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P<F%N9V4@/2!A
M<G)A>2@I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D9&5P6R=M:6XG72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&1E<')A;F=E6UT@/2!A<G)A>2@D9&5P6R=M:6XG72PG/CTG*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)VUA>"==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P<F%N9V5;72`](&%R
M<F%Y*"1D97!;)VUA>"==+"`G/#TG*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1D97!;)V5X8VQU9&4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D9&5P6R=E>&-L=61E)UTI('Q\
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("%I<W-E
M="@D9&5P6R=E>&-L=61E)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9&5P6R=E>&-L=61E)UT@/2!A<G)A>2@D9&5P
M6R=E>&-L=61E)UTI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AC;W5N
M="@D9&5P<F%N9V4I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D97AC;"`]("1D97!;)V5X8VQU9&4G73L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("\O(&-H86YG92`^/2!T;R`^(&EF
M(&5X8VQU9&EN9R!T:&4@;6EN('9E<G-I;VX-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("\O(&-H86YG92`\/2!T;R`\(&EF(&5X8VQU
M9&EN9R!T:&4@;6%X('9E<G-I;VX-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&9O<B@D:2`](#`[("1I(#P@8V]U;G0H)&5X8VPI.R`D
M:2LK*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1D97!R86YG95LP72D@)B8-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D97AC;%LD:5T@/3T@
M)&1E<')A;F=E6S!=6S!=*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1D97!R86YG95LP75LQ72`]("<\)SL-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS
M970H)&1E<%LG97AC;'5D92==6R1I72D[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P<F%N9V5;,5TI("8F
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&5X8VQ;)&E=(#T]("1D97!R86YG95LQ75LP72D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P<F%N9V5;
M,5U;,5T@/2`G/B<[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('5N<V5T*"1D97!;)V5X8VQU9&4G75LD:5TI.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H8V]U;G0H)&1E<%LG97AC;'5D92==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E<%LG97AC;'5D
M92==(#T@87)R87E?=F%L=65S*"1D97!;)V5X8VQU9&4G72D[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F5W9&5P<F%N9V4@/2!A
M<G)A>2@I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+R\@<F5M;W9E(&5X8VQU9&5S('1H870@87)E(&]U='-I9&4@=&AE(&5X:7-T
M:6YG(')A;F=E#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D9&5P6R=E>&-L=61E)UTI.R`D
M:2LK*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"1D97!;)V5X8VQU9&4G75LD:5T@/"`D9&5P6R=M:6XG72!\?`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1D97!;)V5X8VQU9&4G75LD:5T@/B`D9&5P6R=M87@G72D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D
M9&5P6R=E>&-L=61E)UU;)&E=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D9&5P6R=E>&-L=61E)UT@/2!A<G)A>5]V86QU97,H)&1E<%LG97AC
M;'5D92==*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('5S;W)T*"1D97!;)V5X8VQU9&4G72P@)W9E<G-I;VY?8V]M<&%R92<I.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@=&%K92!T
M:&4@<F5M86EN:6YG(&5X8VQU9&5S(&%N9`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@<W!L:70@=&AE(&1E<&5N9&5N8WD@:6YT
M;R!S=6(M<F%N9V5S#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D;&%S=&UI;B`]("1D97!R86YG95LP73L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT
M*"1D97!;)V5X8VQU9&4G72D@+2`Q.R`D:2LK*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YE=V1E<')A;F=E6UT@/2`G
M*"<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<&%C:V%G92`N("(@>R1L87-T;6EN6S%=?2![)&QA<W1M:6Y;,%U]
M(&%N9"`B("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!A8VMA9V4@+B`G(#P@)R`N("1D97!;)V5X8VQU9&4G75LD
M:5T@+B`G*2<[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&QA<W1M:6X@/2!A<G)A>2@D9&5P6R=E>&-L=61E)UU;)&E=+"`G
M/B<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1D97!;)VUA>"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1N97=D97!R86YG95M=(#T@)R@G("X@)'!A8VMA9V4@
M+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`B('LD;&%S=&UI;ELQ77T@>R1L87-T;6EN6S!=?2!A;F0@(B`N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P86-K
M86=E("X@)R`\("<@+B`D9&5P6R=M87@G72`N("<I)SL-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1C;VYF;&EC='-;72`](&EM<&QO9&4H)R!O
M<B`G+"`D9&5P<F%N9V4I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&-O;F9L:6-T<UM=(#T@)'!A8VMA9V4@+@T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("(@>R1D97!R86YG95LP75LQ
M77T@>R1D97!R86YG95LP75LP77TB("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`H:7-S970H)&1E<')A;F=E6S%=*2`_(`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("(@86YD
M("1P86-K86=E('LD9&5P<F%N9V5;,5U;,5U]('LD9&5P<F%N9V5;,5U;,%U]
M(@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M)R<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D9&5P6R=M
M:6XG72D@)B8@(6ES<V5T*"1D97!;)VUA>"==*2`F)@T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(6ES<V5T*"1D97!;)V5X8VQU9&4G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG
M8V]N9FQI8W1S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1C;VYF;&EC='-;72`]("1P86-K86=E.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1R97%U:7)E<UM=(#T@)'!A8VMA9V4[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&1E<%LG;6EN)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1R97%U:7)E<UM=(#T@)'!A8VMA9V4@+B`G(#X]("<@+B`D9&5P
M6R=M:6XG73L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)VUA>"==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5Q=6ER
M97-;72`]("1P86-K86=E("X@)R`\/2`G("X@)&1E<%LG;6%X)UT[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E>"`]("1D97!;)V5X8VQU
M9&4G73L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I
M<U]A<G)A>2@D97@I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D97@@/2!A<G)A>2@D97@I.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1E>"!A<R`D=F5R*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D8V]N9FQI8W1S6UT@/2`D<&%C:V%G92`N
M("<@/2`G("X@)'9E<CL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)T%R8VAI=F4O5&%R+G!H
M<"<[#0H@("`@("`@("`@("`@("`@("`@("1T87(@/2!N97<@07)C:&EV95]4
M87(H)'!F+3YG971!<F-H:79E1FEL92@I*3L-"B`@("`@("`@("`@("`@("`@
M("`@)'1A<BT^<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI
M.PT*("`@("`@("`@("`@("`@("`@("`D82`]("1T87(M/F5X=')A8W1);E-T
M<FEN9R@G<&%C:V%G93(N>&UL)RD[#0H@("`@("`@("`@("`@("`@("`@("1T
M87(M/G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*"1A(#T]/2!N=6QL('Q\(%!%05(Z.FES17)R;W(H)&$I*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D:6YF;ULG<&%C:V%G93)X;6PG72`]("<G
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@+R\@=&AI<R!D;V5S;B=T(&AA
M=F4@82!P86-K86=E+GAM;"!V97)S:6]N(#$N,`T*("`@("`@("`@("`@("`@
M("`@("`@("`@)')E<75I<F5S6UT@/2`G4$5!4CHZ4$5!4B`^/2`G("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P<ULG<F5Q=6ER960G75LG
M<&5A<FEN<W1A;&QE<B==6R=M:6XG73L-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)')E<75I<F5S*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F];)V5X=')A7VAE861E
M<G,G72`N/2`G4F5Q=6ER97,Z("<@+B!I;7!L;V1E*"<L("<L("1R97%U:7)E
M<RD@+B`B7&XB.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@(&EF("AC;W5N="@D8V]N9FQI8W1S*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)&EN9F];)V5X=')A7VAE861E<G,G72`N/2`G0V]N
M9FQI8W1S.B`G("X@:6UP;&]D92@G+"`G+"`D8V]N9FQI8W1S*2`N(")<;B([
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"@T*("`@("`@("`O+R!R96UO=F4@
M=&AE('1R86EL:6YG(&YE=VQI;F4-"B`@("`@("`@)&EN9F];)V5X=')A7VAE
M861E<G,G72`]('1R:6TH)&EN9F];)V5X=')A7VAE861E<G,G72D[#0H@("`@
M("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V9I;&5?9V5T7V-O;G1E;G1S)RDI
M('L-"B`@("`@("`@("`@(&9C;&]S92@D9G`I.PT*("`@("`@("`@("`@)'-P
M96-?8V]N=&5N=',@/2!P<F5G7W)E<&QA8V4H)R]`*%MA+7HP+3E?+5TK*4`O
M92<L("<D:6YF;ULB7#$B72<L#0H@("`@("`@("`@("`@("`@9FEL95]G971?
M8V]N=&5N=',H)'-P96-?=&5M<&QA=&4I*3L-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("1S<&5C7V-O;G1E;G1S(#T@<')E9U]R97!L86-E*"<O
M0"A;82UZ,"TY7RU=*RE`+V4G+"`G)&EN9F];(EPQ(ETG+`T*("`@("`@("`@
M("`@("`@(&9R96%D*"1F<"P@9FEL97-I>F4H)'-P96-?=&5M<&QA=&4I*2D[
M#0H@("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@?0T*("`@("`@
M("`D<W!E8U]F:6QE(#T@(B1I;F9O6W)P;5]P86-K86=E72TD:6YF;UMV97)S
M:6]N72YS<&5C(CL-"B`@("`@("`@)'=P(#T@9F]P96XH)'-P96-?9FEL92P@
M(G=B(BD[#0H@("`@("`@(&EF("@A)'=P*2![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H(F-O=6QD(&YO="!W<FET92!24$T@<W!E
M8R!F:6QE("1S<&5C7V9I;&4Z("1P:'!?97)R;W)M<V<B*3L-"B`@("`@("`@
M?0T*("`@("`@("!F=W)I=&4H)'=P+"`D<W!E8U]C;VYT96YT<RD[#0H@("`@
M("`@(&9C;&]S92@D=W`I.PT*("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A
M=&$H(E=R;W1E(%)032!S<&5C(&9I;&4@)'-P96-?9FEL92(L("1C;VUM86YD
M*3L-"@T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!D;T-O;G9E<G0H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*
M("`@('L-"B`@("`@("`@)'!A8VMA9V5X;6P@/2!I<W-E="@D<&%R86US6S!=
M*2`_("1P87)A;7-;,%T@.B`G<&%C:V%G92YX;6PG.PT*("`@("`@("`D;F5W
M<&%C:V%G97AM;"`](&ES<V5T*"1P87)A;7-;,5TI(#\@)'!A<F%M<ULQ72`Z
M(&1I<FYA;64H)'!A8VMA9V5X;6PI("X-"B`@("`@("`@("`@($1)4D5#5$]2
M65]315!!4D%43U(@+B`G<&%C:V%G93(N>&UL)SL-"B`@("`@("`@)'!K9R`]
M("8D=&AI<RT^9V5T4&%C:V%G949I;&4H)'1H:7,M/F-O;F9I9RP@)'1H:7,M
M/E]D96)U9RD[#0H@("`@("`@(%!%05(Z.G-T871I8U!U<VA%<G)O<DAA;F1L
M:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@)'!F(#T@)'!K9RT^
M9G)O;5!A8VMA9V5&:6QE*"1P86-K86=E>&UL+"!014%27U9!3$E$051%7TY/
M4DU!3"D[#0H@("`@("`@(%!%05(Z.G-T871I8U!O<$5R<F]R2&%N9&QI;F<H
M*3L-"B`@("`@("`@:68@*"%014%2.CII<T5R<F]R*"1P9BDI('L-"B`@("`@
M("`@("`@(&EF("AI<U]A*"1P9BP@)U!%05)?4&%C:V%G949I;&5?=C(G*2D@
M>PT*("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D<&%C
M:V%G97AM;"`N("<@:7,@86QR96%D>2!A('!A8VMA9V4N>&UL('9E<G-I;VX@
M,BXP)RD[#0H@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`D9V5N(#T@)B1P9BT^9V5T1&5F875L=$=E
M;F5R871O<B@I.PT*("`@("`@("`@("`@)&YE=W!F(#T@)B1G96XM/G1O5C(H
M*3L-"B`@("`@("`@("`@("1N97=P9BT^<V5T4&%C:V%G969I;&4H)&YE=W!A
M8VMA9V5X;6PI.PT*("`@("`@("`@("`@)&=E;B`]("8D;F5W<&8M/F=E=$1E
M9F%U;'1'96YE<F%T;W(H*3L-"B`@("`@("`@("`@(%!%05(Z.G-T871I8U!U
M<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@
M("`@("1S=&%T92`]("AI<W-E="@D;W!T:6]N<ULG9FQA="==*2`_(%!%05)?
M5D%,241!5$5?4$%#2T%'24Y'(#H@4$5!4E]604Q)1$%415].3U)-04PI.PT*
M("`@("`@("`@("`@)'-A=F5D(#T@)&=E;BT^=&]086-K86=E1FEL92AD:7)N
M86UE*"1N97=P86-K86=E>&UL*2P@)'-T871E+`T*("`@("`@("`@("`@("`@
M(&)A<V5N86UE*"1N97=P86-K86=E>&UL*2D[#0H@("`@("`@("`@("!014%2
M.CIS=&%T:6-0;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D<V%V960I*2![#0H@("`@("`@("`@("`@("`@:68@
M*&ES7V%R<F%Y*"1S879E9"T^9V5T57-E<DEN9F\H*2DI('L-"B`@("`@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)'-A=F5D+3YG9715<V5R26YF;R@I(&%S
M("1W87)N:6YG*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M=6DM/F]U='!U=$1A=&$H)'=A<FYI;F=;)VUE<W-A9V4G72D[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"1S879E9"T^9V5T365S<V%G
M92@I*3L-"B`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G5W)O
M=&4@;F5W('9E<G-I;VX@,BXP('!A8VMA9V4N>&UL('1O("(G("X@)'-A=F5D
M("X@)R(G*3L-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1P9BT^9V5T57-E
M<DEN9F\H*2DI('L-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D<&8M/F=E
M=%5S97));F9O*"D@87,@)'=A<FYI;F<I('L-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G5I+3YO=71P=71$871A*"1W87)N:6YG6R=M97-S86=E)UTI
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D<&8I.PT*("`@("`@("!]
M#0H@("`@?0T*#0H@("`@+R\@?7U]#0I]#0H-"C\^#0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O0V]M
M;6%N9"]"=6EL9"YX;6P`````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`T,34@,3`U,34T,S,W,S$@,#(R,S4R`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#QC;VUM86YD<R!V97)S:6]N/2(Q
M+C`B/@T*(#QB=6EL9#X-"B`@/'-U;6UA<GD^0G5I;&0@86X@17AT96YS:6]N
M($9R;VT@0R!3;W5R8V4\+W-U;6UA<GD^#0H@(#QF=6YC=&EO;CYD;T)U:6QD
M/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T/F(\+W-H;W)T8W5T/@T*("`\;W!T
M:6]N<R`O/@T*("`\9&]C/EMP86-K86=E+GAM;%T-"D)U:6QD<R!O;F4@;W(@
M;6]R92!E>'1E;G-I;VYS(&-O;G1A:6YE9"!I;B!A('!A8VMA9V4N/"]D;V,^
M#0H@/"]B=6EL9#X-"CPO8V]M;6%N9',^````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O0G5I;&0N
M<&AP````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`U-C`P(#$P
M-3$U-#,S-S,Q(#`R,C,T,@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`T*+RHJ#0H@*B!014%27T-O;6UA;F1?075T
M:"`H8G5I;&0@8V]M;6%N9"D-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@
M-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C
M="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@
M:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H
M92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F
M#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN
M(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T
M;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I
M;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C
M:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B
M0'!H<"YN970^#0H@*B!`875T:&]R("`@("!4;VUA<R!6+E8N0V]X(#QC;WA`
M:61E8VYE="YC;VT^#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L
M;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(
M4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@
M("!#5E,Z("1)9#H@0G5I;&0N<&AP+'8@,2XQ,R`R,#`V+S`Q+S`V(#`T.C0W
M.C,V(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N
M<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A
M:6QA8FQE('-I;F-E(%)E;&5A<V4@,"XQ#0H@*B\-"@T*+RHJ#0H@*B!B87-E
M(&-L87-S#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!4B]#;VUM86YD+T-O;6UO
M;BYP:'`G.PT*#0HO*BH-"B`J(%!%05(@8V]M;6%N9',@9F]R(&)U:6QD:6YG
M(&5X=&5N<VEO;G,N#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A
M8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S
M8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@5&]M87,@5BY6+D-O>"`\8V]X
M0&ED96-N970N8V]M/@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E
M;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!0
M2%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L
M:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@
M("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R
M+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A
M=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J+PT*8VQA<W,@4$5!4E]#
M;VUM86YD7T)U:6QD(&5X=&5N9',@4$5!4E]#;VUM86YD7T-O;6UO;@T*>PT*
M("`@("\O('M[>R!P<F]P97)T:65S#0H-"B`@("!V87(@)&-O;6UA;F1S(#T@
M87)R87DH#0H@("`@("`@("=B=6EL9"<@/3X@87)R87DH#0H@("`@("`@("`@
M("`G<W5M;6%R>2<@/3X@)T)U:6QD(&%N($5X=&5N<VEO;B!&<F]M($,@4V]U
M<F-E)RP-"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O0G5I;&0G+`T*
M("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G8B<L#0H@("`@("`@("`@("`G
M;W!T:6]N<R<@/3X@87)R87DH*2P-"B`@("`@("`@("`@("=D;V,G(#T^("=;
M<&%C:V%G92YX;6Q=#0I"=6EL9',@;VYE(&]R(&UO<F4@97AT96YS:6]N<R!C
M;VYT86EN960@:6X@82!P86-K86=E+B<-"B`@("`@("`@("`@("DL#0H@("`@
M("`@("D[#0H-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!C;VYS=')U8W1O
M<@T*#0H@("`@+RHJ#0H@("`@("H@4$5!4E]#;VUM86YD7T)U:6QD(&-O;G-T
M<G5C=&]R+@T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!014%27T-O;6UA;F1?0G5I;&0H)B1U:2P@)B1C
M;VYF:6<I#0H@("`@>PT*("`@("`@("!P87)E;G0Z.E!%05)?0V]M;6%N9%]#
M;VUM;VXH)'5I+"`D8V]N9FEG*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*
M("`@("\O('M[>R!D;T)U:6QD*"D-"@T*("`@(&9U;F-T:6]N(&1O0G5I;&0H
M)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@
M<F5Q=6ER95]O;F-E("=014%2+T)U:6QD97(N<&AP)SL-"B`@("`@("`@:68@
M*'-I>F5O9B@D<&%R86US*2`\(#$I('L-"B`@("`@("`@("`@("1P87)A;7-;
M,%T@/2`G<&%C:V%G92YX;6PG.PT*("`@("`@("!]#0H@("`@("`@("1B=6EL
M9&5R(#T@)FYE=R!014%27T)U:6QD97(H)'1H:7,M/G5I*3L-"B`@("`@("`@
M)'1H:7,M/F1E8G5G(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=V97)B;W-E)RD[
M#0H@("`@("`@("1E<G(@/2`D8G5I;&1E<BT^8G5I;&0H)'!A<F%M<ULP72P@
M87)R87DH)B1T:&ES+"`G8G5I;&1#86QL8F%C:R<I*3L-"B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&5R<BDI('L-"B`@("`@("`@("`@(')E='5R;B`D
M97)R.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-
M"@T*("`@("\O('U]?0T*("`@("\O('M[>R!B=6EL9$-A;&QB86-K*"D-"@T*
M("`@(&9U;F-T:6]N(&)U:6QD0V%L;&)A8VLH)'=H870L("1D871A*0T*("`@
M('L-"B`@("`@("`@:68@*"@D=VAA="`]/2`G8VUD;W5T<'5T)R`F)B`D=&AI
M<RT^9&5B=6<@/B`Q*2!\?`T*("`@("`@("`@("`@*"1W:&%T(#T]("=O=71P
M=70G("8F("1T:&ES+3YD96)U9R`^(#`I*2![#0H@("`@("`@("`@("`D=&AI
M<RT^=6DM/F]U='!U=$1A=&$H<G1R:6TH)&1A=&$I+"`G8G5I;&0G*3L-"B`@
M("`@("`@?0T*("`@('T-"@T*("`@("\O('U]?0T*?0T*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+U!%05(O0V]M;6%N9"]#:&%N;F5L<RYX;6P`````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#4R-S$@,3`U,34T,S,W,S$@,#(S,#4S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#QC
M;VUM86YD<R!V97)S:6]N/2(Q+C`B/@T*(#QL:7-T+6-H86YN96QS/@T*("`\
M<W5M;6%R>3Y,:7-T($%V86EL86)L92!#:&%N;F5L<SPO<W5M;6%R>3X-"B`@
M/&9U;F-T:6]N/F1O3&ES=#PO9G5N8W1I;VX^#0H@(#QS:&]R=&-U=#YL8SPO
M<VAO<G1C=70^#0H@(#QO<'1I;VYS("\^#0H@(#QD;V,^#0I,:7-T(&%L;"!A
M=F%I;&%B;&4@8VAA;FYE;',@9F]R(&EN<W1A;&QA=&EO;BX-"CPO9&]C/@T*
M(#PO;&ES="UC:&%N;F5L<SX-"B`\=7!D871E+6-H86YN96QS/@T*("`\<W5M
M;6%R>3Y5<&1A=&4@=&AE($-H86YN96P@3&ES=#PO<W5M;6%R>3X-"B`@/&9U
M;F-T:6]N/F1O57!D871E06QL/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T/G5C
M/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,@+SX-"B`@/&1O8SX-"DQI<W0@86QL
M(&EN<W1A;&QE9"!P86-K86=E<R!I;B!A;&P@8VAA;FYE;',N#0H\+V1O8SX-
M"B`\+W5P9&%T92UC:&%N;F5L<SX-"B`\8VAA;FYE;"UD96QE=&4^#0H@(#QS
M=6UM87)Y/E)E;6]V92!A($-H86YN96P@1G)O;2!T:&4@3&ES=#PO<W5M;6%R
M>3X-"B`@/&9U;F-T:6]N/F1O1&5L971E/"]F=6YC=&EO;CX-"B`@/'-H;W)T
M8W5T/F-D93PO<VAO<G1C=70^#0H@(#QO<'1I;VYS("\^#0H@(#QD;V,^)FQT
M.V-H86YN96P@;F%M929G=#L-"D1E;&5T92!A(&-H86YN96P@9G)O;2!T:&4@
M<F5G:7-T<GDN("!9;W4@;6%Y(&YO=`T*<F5M;W9E(&%N>2!C:&%N;F5L('1H
M870@:&%S(&EN<W1A;&QE9"!P86-K86=E<RX-"CPO9&]C/@T*(#PO8VAA;FYE
M;"UD96QE=&4^#0H@/&-H86YN96PM861D/@T*("`\<W5M;6%R>3Y!9&0@82!#
M:&%N;F5L/"]S=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]!9&0\+V9U;F-T:6]N
M/@T*("`\<VAO<G1C=70^8V$\+W-H;W)T8W5T/@T*("`\;W!T:6]N<R`O/@T*
M("`\9&]C/B9L=#MC:&%N;F5L+GAM;"9G=#L-"D%D9"!A('!R:79A=&4@8VAA
M;FYE;"!T;R!T:&4@8VAA;FYE;"!L:7-T+B`@3F]T92!T:&%T(&%L;`T*<'5B
M;&EC(&-H86YN96QS('-H;W5L9"!B92!S>6YC960@=7-I;F<@)G%U;W0[=7!D
M871E+6-H86YN96QS)G%U;W0[+@T*4&%R86UE=&5R(&UA>2!B92!E:71H97(@
M82!L;V-A;"!F:6QE(&]R(')E;6]T92!54DP@=&\@80T*8VAA;FYE;"YX;6PN
M#0H\+V1O8SX-"B`\+V-H86YN96PM861D/@T*(#QC:&%N;F5L+75P9&%T93X-
M"B`@/'-U;6UA<GD^57!D871E(&%N($5X:7-T:6YG($-H86YN96P\+W-U;6UA
M<GD^#0H@(#QF=6YC=&EO;CYD;U5P9&%T93PO9G5N8W1I;VX^#0H@(#QS:&]R
M=&-U=#YC=3PO<VAO<G1C=70^#0H@(#QO<'1I;VYS/@T*("`@/&9O<F-E/@T*
M("`@(#QS:&]R=&]P=#YF/"]S:&]R=&]P=#X-"B`@("`\9&]C/G=I;&P@9F]R
M8V4@9&]W;FQO860@;V8@;F5W(&-H86YN96PN>&UL(&EF(&%N(&5X:7-T:6YG
M(&-H86YN96P@;F%M92!I<R!U<V5D/"]D;V,^#0H@("`\+V9O<F-E/@T*("`@
M/&-H86YN96P^#0H@("`@/'-H;W)T;W!T/F,\+W-H;W)T;W!T/@T*("`@(#QA
M<F<^0TA!3DY%3#PO87)G/@T*("`@(#QD;V,^=VEL;"!F;W)C92!D;W=N;&]A
M9"!O9B!N97<@8VAA;FYE;"YX;6P@:68@86X@97AI<W1I;F<@8VAA;FYE;"!N
M86UE(&ES('5S960\+V1O8SX-"B`@(#PO8VAA;FYE;#X-"B`@/"]O<'1I;VYS
M/@T*("`\9&]C/ELF;'0[8VAA;FYE;"YX;6PF9W0[?"9L=#MC:&%N;F5L(&YA
M;64F9W0[70T*57!D871E(&$@8VAA;FYE;"!I;B!T:&4@8VAA;FYE;"!L:7-T
M(&1I<F5C=&QY+B`@3F]T92!T:&%T(&%L;`T*<'5B;&EC(&-H86YN96QS(&-A
M;B!B92!S>6YC960@=7-I;F<@)G%U;W0[=7!D871E+6-H86YN96QS)G%U;W0[
M+@T*4&%R86UE=&5R(&UA>2!B92!A(&QO8V%L(&]R(')E;6]T92!C:&%N;F5L
M+GAM;"P@;W(@=&AE(&YA;64@;V8-"F%N(&5X:7-T:6YG(&-H86YN96PN#0H\
M+V1O8SX-"B`\+V-H86YN96PM=7!D871E/@T*(#QC:&%N;F5L+6EN9F\^#0H@
M(#QS=6UM87)Y/E)E=')I979E($EN9F]R;6%T:6]N(&]N(&$@0VAA;FYE;#PO
M<W5M;6%R>3X-"B`@/&9U;F-T:6]N/F1O26YF;SPO9G5N8W1I;VX^#0H@(#QS
M:&]R=&-U=#YC:3PO<VAO<G1C=70^#0H@(#QO<'1I;VYS("\^#0H@(#QD;V,^
M)FQT.W!A8VMA9V4F9W0[#0I,:7-T('1H92!F:6QE<R!I;B!A;B!I;G-T86QL
M960@<&%C:V%G92X-"CPO9&]C/@T*(#PO8VAA;FYE;"UI;F9O/@T*(#QC:&%N
M;F5L+6%L:6%S/@T*("`\<W5M;6%R>3Y3<&5C:69Y(&%N(&%L:6%S('1O(&$@
M8VAA;FYE;"!N86UE/"]S=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]!;&EA<SPO
M9G5N8W1I;VX^#0H@(#QS:&]R=&-U=#YC:&$\+W-H;W)T8W5T/@T*("`\;W!T
M:6]N<R`O/@T*("`\9&]C/B9L=#MC:&%N;F5L)F=T.R`F;'0[86QI87,F9W0[
M#0I3<&5C:69Y(&$@<W!E8VEF:6,@86QI87,@=&\@=7-E(&9O<B!A(&-H86YN
M96P@;F%M92X-"E1H92!A;&EA<R!M87D@;F]T(&)E(&%N(&5X:7-T:6YG(&-H
M86YN96P@;F%M92!O<@T*86QI87,N#0H\+V1O8SX-"B`\+V-H86YN96PM86QI
M87,^#0H@/&-H86YN96PM9&ES8V]V97(^#0H@(#QS=6UM87)Y/DEN:71I86QI
M>F4@82!#:&%N;F5L(&9R;VT@:71S('-E<G9E<CPO<W5M;6%R>3X-"B`@/&9U
M;F-T:6]N/F1O1&ES8V]V97(\+V9U;F-T:6]N/@T*("`\<VAO<G1C=70^9&D\
M+W-H;W)T8W5T/@T*("`\;W!T:6]N<R`O/@T*("`\9&]C/B9L=#MP86-K86=E
M)F=T.PT*3&ES="!T:&4@9FEL97,@:6X@86X@:6YS=&%L;&5D('!A8VMA9V4N
M#0H\+V1O8SX-"B`\+V-H86YN96PM9&ES8V]V97(^#0H\+V-O;6UA;F1S/@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]#
M;VUM86YD+T-H86YN96QS+G!H<```````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#$P,30R,B`Q,#4Q-30S,S<S,2`P,C,P,S4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`-"B\O("\J('9I;3H@
M<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT.B`J+PT*+RHJ
M#0H@*B!014%27T-O;6UA;F1?0VAA;FYE;',@*&QI<W0M8VAA;FYE;',L('5P
M9&%T92UC:&%N;F5L<RP@8VAA;FYE;"UD96QE=&4L(&-H86YN96PM861D+`T*
M("H@8VAA;FYE;"UU<&1A=&4L(&-H86YN96PM:6YF;RP@8VAA;FYE;"UA;&EA
M<RP@8VAA;FYE;"UD:7-C;W9E<B!C;VUM86YD<RD-"B`J#0H@*B!02%`@=F5R
M<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I
M;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N
M<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I
M9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I
M=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B
M;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S
M96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@
M>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P
M96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!3=&EG
M($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R("`@("!'<F5G($)E
M879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P
M,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`
M=F5R<VEO;B`@("!#5E,Z("1)9#H@0VAA;FYE;',N<&AP+'8@,2XT-"`R,#`V
M+S`S+S`R(#$X.C$T.C$S(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@
M:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@
M("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO
M#0H-"B\J*@T*("H@8F%S92!C;&%S<PT*("HO#0IR97%U:7)E7V]N8V4@)U!%
M05(O0V]M;6%N9"]#;VUM;VXN<&AP)SL-"@T*+RHJ#0H@*B!014%2(&-O;6UA
M;F1S(&9O<B!M86YA9VEN9R!C:&%N;F5L<RX-"B`J#0H@*B!`8V%T96=O<GD@
M("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'
M<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q
M.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP
M#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@
M("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC
M92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP83$-
M"B`J+PT*8VQA<W,@4$5!4E]#;VUM86YD7T-H86YN96QS(&5X=&5N9',@4$5!
M4E]#;VUM86YD7T-O;6UO;@T*>PT*("`@("\O('M[>R!P<F]P97)T:65S#0H-
M"B`@("!V87(@)&-O;6UA;F1S(#T@87)R87DH#0H@("`@("`@("=L:7-T+6-H
M86YN96QS)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G
M3&ES="!!=F%I;&%B;&4@0VAA;FYE;',G+`T*("`@("`@("`@("`@)V9U;F-T
M:6]N)R`]/B`G9&],:7-T)RP-"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@
M)VQC)RP-"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@I+`T*("`@
M("`@("`@("`@)V1O8R<@/3X@)PT*3&ES="!A;&P@879A:6QA8FQE(&-H86YN
M96QS(&9O<B!I;G-T86QL871I;VXN#0HG+`T*("`@("`@("`@("`@*2P-"B`@
M("`@("`@)W5P9&%T92UC:&%N;F5L<R<@/3X@87)R87DH#0H@("`@("`@("`@
M("`G<W5M;6%R>2<@/3X@)U5P9&%T92!T:&4@0VAA;FYE;"!,:7-T)RP-"B`@
M("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O57!D871E06QL)RP-"B`@("`@
M("`@("`@("=S:&]R=&-U="<@/3X@)W5C)RP-"B`@("`@("`@("`@("=O<'1I
M;VYS)R`]/B!A<G)A>2@I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)PT*3&ES
M="!A;&P@:6YS=&%L;&5D('!A8VMA9V5S(&EN(&%L;"!C:&%N;F5L<RX-"B<-
M"B`@("`@("`@("`@("DL#0H@("`@("`@("=C:&%N;F5L+61E;&5T92<@/3X@
M87)R87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)U)E;6]V92!A($-H
M86YN96P@1G)O;2!T:&4@3&ES="<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG
M(#T^("=D;T1E;&5T92<L#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=C
M9&4G+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*"DL#0H@("`@
M("`@("`@("`G9&]C)R`]/B`G/&-H86YN96P@;F%M93X-"D1E;&5T92!A(&-H
M86YN96P@9G)O;2!T:&4@<F5G:7-T<GDN("!9;W4@;6%Y(&YO=`T*<F5M;W9E
M(&%N>2!C:&%N;F5L('1H870@:&%S(&EN<W1A;&QE9"!P86-K86=E<RX-"B<-
M"B`@("`@("`@("`@("DL#0H@("`@("`@("=C:&%N;F5L+6%D9"<@/3X@87)R
M87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)T%D9"!A($-H86YN96PG
M+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]!9&0G+`T*("`@("`@
M("`@("`@)W-H;W)T8W5T)R`]/B`G8V$G+`T*("`@("`@("`@("`@)V]P=&EO
M;G,G(#T^(&%R<F%Y*"DL#0H@("`@("`@("`@("`G9&]C)R`]/B`G/&-H86YN
M96PN>&UL/@T*061D(&$@<')I=F%T92!C:&%N;F5L('1O('1H92!C:&%N;F5L
M(&QI<W0N("!.;W1E('1H870@86QL#0IP=6)L:6,@8VAA;FYE;',@<VAO=6QD
M(&)E('-Y;F-E9"!U<VEN9R`B=7!D871E+6-H86YN96QS(BX-"E!A<F%M971E
M<B!M87D@8F4@96ET:&5R(&$@;&]C86P@9FEL92!O<B!R96UO=&4@55),('1O
M(&$-"F-H86YN96PN>&UL+@T*)PT*("`@("`@("`@("`@*2P-"B`@("`@("`@
M)V-H86YN96PM=7!D871E)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM
M87)Y)R`]/B`G57!D871E(&%N($5X:7-T:6YG($-H86YN96PG+`T*("`@("`@
M("`@("`@)V9U;F-T:6]N)R`]/B`G9&]5<&1A=&4G+`T*("`@("`@("`@("`@
M)W-H;W)T8W5T)R`]/B`G8W4G+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^
M(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=F;W)C92<@/3X@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)V8G+`T*("`@("`@
M("`@("`@("`@("`@("`G9&]C)R`]/B`G=VEL;"!F;W)C92!D;W=N;&]A9"!O
M9B!N97<@8VAA;FYE;"YX;6P@:68@86X@97AI<W1I;F<@8VAA;FYE;"!N86UE
M(&ES('5S960G+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@
M("`@("`@("=C:&%N;F5L)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@
M("`@)W-H;W)T;W!T)R`]/B`G8R<L#0H@("`@("`@("`@("`@("`@("`@("=A
M<F<G(#T^("=#2$%.3D5,)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@
M/3X@)W=I;&P@9F]R8V4@9&]W;FQO860@;V8@;F5W(&-H86YN96PN>&UL(&EF
M(&%N(&5X:7-T:6YG(&-H86YN96P@;F%M92!I<R!U<V5D)RP-"B`@("`@("`@
M("`@("`@("`@("`@*2P-"BDL#0H@("`@("`@("`@("`G9&]C)R`]/B`G6SQC
M:&%N;F5L+GAM;#Y\/&-H86YN96P@;F%M93Y=#0I5<&1A=&4@82!C:&%N;F5L
M(&EN('1H92!C:&%N;F5L(&QI<W0@9&ER96-T;'DN("!.;W1E('1H870@86QL
M#0IP=6)L:6,@8VAA;FYE;',@8V%N(&)E('-Y;F-E9"!U<VEN9R`B=7!D871E
M+6-H86YN96QS(BX-"E!A<F%M971E<B!M87D@8F4@82!L;V-A;"!O<B!R96UO
M=&4@8VAA;FYE;"YX;6PL(&]R('1H92!N86UE(&]F#0IA;B!E>&ES=&EN9R!C
M:&%N;F5L+@T*)PT*("`@("`@("`@("`@*2P-"B`@("`@("`@)V-H86YN96PM
M:6YF;R<@/3X@87)R87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)U)E
M=')I979E($EN9F]R;6%T:6]N(&]N(&$@0VAA;FYE;"<L#0H@("`@("`@("`@
M("`G9G5N8W1I;VXG(#T^("=D;TEN9F\G+`T*("`@("`@("`@("`@)W-H;W)T
M8W5T)R`]/B`G8VDG+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y
M*"DL#0H@("`@("`@("`@("`G9&]C)R`]/B`G/'!A8VMA9V4^#0I,:7-T('1H
M92!F:6QE<R!I;B!A;B!I;G-T86QL960@<&%C:V%G92X-"B<-"B`@("`@("`@
M("`@("DL#0H@("`@("`@("=C:&%N;F5L+6%L:6%S)R`]/B!A<G)A>2@-"B`@
M("`@("`@("`@("=S=6UM87)Y)R`]/B`G4W!E8VEF>2!A;B!A;&EA<R!T;R!A
M(&-H86YN96P@;F%M92<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D
M;T%L:6%S)RP-"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)V-H82<L#0H@
M("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH*2P-"B`@("`@("`@("`@
M("=D;V,G(#T^("<\8VAA;FYE;#X@/&%L:6%S/@T*4W!E8VEF>2!A('-P96-I
M9FEC(&%L:6%S('1O('5S92!F;W(@82!C:&%N;F5L(&YA;64N#0I4:&4@86QI
M87,@;6%Y(&YO="!B92!A;B!E>&ES=&EN9R!C:&%N;F5L(&YA;64@;W(-"F%L
M:6%S+@T*)PT*("`@("`@("`@("`@*2P-"B`@("`@("`@)V-H86YN96PM9&ES
M8V]V97(G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=)
M;FET:6%L:7IE(&$@0VAA;FYE;"!F<F]M(&ET<R!S97)V97(G+`T*("`@("`@
M("`@("`@)V9U;F-T:6]N)R`]/B`G9&]$:7-C;W9E<B<L#0H@("`@("`@("`@
M("`G<VAO<G1C=70G(#T^("=D:2<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@
M/3X@87)R87DH*2P-"B`@("`@("`@("`@("=D;V,G(#T^("<\<&%C:V%G93X-
M"DQI<W0@=&AE(&9I;&5S(&EN(&%N(&EN<W1A;&QE9"!P86-K86=E+@T*)PT*
M("`@("`@("`@("`@*2P-"B`@("`@("`@*3L-"@T*("`@("\O('U]?0T*("`@
M("\O('M[>R!C;VYS=')U8W1O<@T*#0H@("`@+RHJ#0H@("`@("H@4$5!4E]#
M;VUM86YD7U)E9VES=')Y(&-O;G-T<G5C=&]R+@T*("`@("`J#0H@("`@("H@
M0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!014%27T-O
M;6UA;F1?0VAA;FYE;',H)B1U:2P@)B1C;VYF:6<I#0H@("`@>PT*("`@("`@
M("!P87)E;G0Z.E!%05)?0V]M;6%N9%]#;VUM;VXH)'5I+"`D8V]N9FEG*3L-
M"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!D;TQI<W0H*0T*
M("`@(`T*("`@(&9U;F-T:6]N(%]S;W)T0VAA;FYE;',H)&$L("1B*0T*("`@
M('L-"B`@("`@("`@<F5T=7)N('-T<FYA=&-A<V5C;7`H)&$M/F=E=$YA;64H
M*2P@)&(M/F=E=$YA;64H*2D[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9&],
M:7-T*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@
M("`@("1R96<@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-"B`@
M("`@("`@)')E9VES=&5R960@/2`D<F5G+3YG971#:&%N;F5L<R@I.PT*("`@
M("`@("!U<V]R="@D<F5G:7-T97)E9"P@87)R87DH)B1T:&ES+"`G7W-O<G1C
M:&%N;F5L<R<I*3L-"B`@("`@("`@)&D@/2`D:B`](#`[#0H@("`@("`@("1D
M871A(#T@87)R87DH#0H@("`@("`@("`@("`G8V%P=&EO;B<@/3X@)U)E9VES
M=&5R960@0VAA;FYE;',Z)RP-"B`@("`@("`@("`@("=B;W)D97(G(#T^('1R
M=64L#0H@("`@("`@("`@("`G:&5A9&QI;F4G(#T^(&%R<F%Y*"=#:&%N;F5L
M)RP@)U-U;6UA<GDG*0T*("`@("`@("`@("`@*3L-"B`@("`@("`@9F]R96%C
M:"`H)')E9VES=&5R960@87,@)&-H86YN96PI('L-"B`@("`@("`@("`@("1D
M871A6R=D871A)UU;72`](&%R<F%Y*"1C:&%N;F5L+3YG971.86UE*"DL#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C:&%N;F5L
M+3YG9713=6UM87)Y*"DI.PT*("`@("`@("!]#0H@("`@("`@(&EF("AC;W5N
M="@D<F5G:7-T97)E9"D]/3`I('L-"B`@("`@("`@("`@("1D871A(#T@)RAN
M;R!R96=I<W1E<F5D(&-H86YN96QS*2<[#0H@("`@("`@('T-"B`@("`@("`@
M)'1H:7,M/G5I+3YO=71P=71$871A*"1D871A+"`D8V]M;6%N9"D[#0H@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@('T-"B`@("`-"B`@("!F=6YC=&EO;B!D
M;U5P9&%T94%L;"@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I#0H@("`@
M>PT*("`@("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y
M*"D[#0H@("`@("`@("1S879E8VAA;FYE;"`]("1T:&ES+3YC;VYF:6<M/F=E
M="@G9&5F875L=%]C:&%N;F5L)RD[#0H@("`@("`@(&EF("AI<W-E="@D;W!T
M:6]N<ULG8VAA;FYE;"==*2D@>PT*("`@("`@("`@("`@:68@*"$D<F5G+3YC
M:&%N;F5L17AI<W1S*"1O<'1I;VYS6R=C:&%N;F5L)UTI*2![#0H@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=5;FMN;W=N(&-H
M86YN96P@(B<@+B`D;W!T:6]N<ULG8VAA;FYE;"==("X@)R(G*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("1T:&ES+3YC;VYF:6<M/G-E="@G9&5F
M875L=%]C:&%N;F5L)RP@)&]P=&EO;G-;)V-H86YN96PG72D[#0H@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`D=&AI<RT^8V]N9FEG+3YS970H)V1E
M9F%U;'1?8VAA;FYE;"<L("=P96%R+G!H<"YN970G*3L-"B`@("`@("`@?0T*
M("`@("`@("`D<F5M;W1E(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E;6]T92@I
M.PT*("`@("`@("`D8VAA;FYE;',@/2`D<F5M;W1E+3YC86QL*"=C:&%N;F5L
M+FQI<W1!;&PG*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&-H86YN
M96QS*2D@>PT*("`@("`@("`@("`@)'1H:7,M/F-O;F9I9RT^<V5T*"=D969A
M=6QT7V-H86YN96PG+"`D<V%V96-H86YN96PI.PT*("`@("`@("`@("`@<F5T
M=7)N("1C:&%N;F5L<SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES7V%R
M<F%Y*"1C:&%N;F5L<RD@?'P@:7-S970H)&-H86YN96QS6R=F875L=$-O9&4G
M72DI('L-"B`@("`@("`@("`@("1T:&ES+3YC;VYF:6<M/G-E="@G9&5F875L
M=%]C:&%N;F5L)RP@)'-A=F5C:&%N;F5L*3L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@B26YC;W)R96-T(&-H86YN96P@;&ES=&EN
M9R!R971U<FYE9"!F<F]M(&-H86YN96P@)R1C:&%N)R(I.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("@A8V]U;G0H)&-H86YN96QS*2D@>PT*("`@("`@("`@
M("`@)&1A=&$@/2`G;F\@=7!D871E<R!A=F%I;&%B;&4G.PT*("`@("`@("!]
M#0H@("`@("`@("1D;"`]("8D=&AI<RT^9V5T1&]W;FQO861E<B@I.PT*("`@
M("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4WES=&5M)RDI('L-"B`@("`@("`@
M("`@(')E<75I<F5?;VYC92`G4WES=&5M+G!H<"<[#0H@("`@("`@('T-"B`@
M("`@("`@)'1M<&1I<B`](%-Y<W1E;3HZ;6MT96UP*&%R<F%Y*"<M9"<I*3L-
M"B`@("`@("`@9F]R96%C:"`H)&-H86YN96QS(&%S("1C:&%N;F5L*2![#0H@
M("`@("`@("`@("`D8VAA;FYE;"`]("1C:&%N;F5L6S!=.PT*("`@("`@("`@
M("`@)'-A=F4@/2`D8VAA;FYE;#L-"B`@("`@("`@("`@(&EF("@D<F5G+3YC
M:&%N;F5L17AI<W1S*"1C:&%N;F5L+"!T<G5E*2D@>PT*("`@("`@("`@("`@
M("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@B57!D871I;F<@8VAA;FYE;"!<
M(B1C:&%N;F5L7"(B+"`D8V]M;6%N9"D[#0H@("`@("`@("`@("`@("`@)'1E
M<W0@/2`D<F5G+3YG971#:&%N;F5L*"1C:&%N;F5L+"!T<G5E*3L-"B`@("`@
M("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D=&5S="DI('L-"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*")#:&%N;F5L
M("<D8VAA;FYE;"<@:7,@8V]R<G5P="!I;B!R96=I<W1R>2$B+"`D8V]M;6%N
M9"D[#0H@("`@("`@("`@("`@("`@("`@("1L87-T;6]D:69I960@/2!F86QS
M93L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("`@("`D;&%S=&UO9&EF:65D(#T@)'1E<W0M/FQA<W1-;V1I9FEE9"@I.PT*
M("`@("`@("`@("`@("`@("`@("`-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@4$5!4CHZ<W1A=&EC4'5S:$5R<F]R2&%N9&QI;F<H4$5!
M4E]%4E)/4E]215154DXI.PT*("`@("`@("`@("`@("`@("1C;VYT96YT<R`]
M("1D;"T^9&]W;FQO861(='1P*"=H='1P.B\O)R`N("1T97-T+3YG971.86UE
M*"D@+B`G+V-H86YN96PN>&UL)RP-"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G5I+"`D=&UP9&ER+"!N=6QL+"`D;&%S=&UO9&EF:65D*3L-"B`@("`@
M("`@("`@("`@("!014%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L:6YG*"D[#0H@
M("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&-O;G1E;G1S*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H
M)T524D]2.B!#86YN;W0@<F5T<FEE=F4@8VAA;FYE;"YX;6P@9F]R(&-H86YN
M96P@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)'1E<W0M/F=E=$YA
M;64H*2`N("<B)RP@)&-O;6UA;F0I.PT*("`@("`@("`@("`@("`@("`@("!C
M;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M:68@*"$D8V]N=&5N=',I('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/G5I+3YO=71P=71$871A*")#:&%N;F5L(%PB)&-H86YN96Q<(B!I<R!U<"UT
M;RUD871E(BP@)&-O;6UA;F0I.PT*("`@("`@("`@("`@("`@("`@("!C;VYT
M:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@;&ES
M="@D8V]N=&5N=',L("1L87-T;6]D:69I960I(#T@)&-O;G1E;G1S.PT*("`@
M("`@("`@("`@("`@("1I;F9O(#T@:6UP;&]D92@G)RP@9FEL92@D8V]N=&5N
M=',I*3L-"B`@("`@("`@("`@("`@("!I9B`H(21I;F9O*2![#0H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@B0VAA;FYE;"!<
M(B1C:&%N;F5L7"(@:7,@=7`M=&\M9&%T92(L("1C;VUM86YD*3L-"B`@("`@
M("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27T-H86YN
M96Q&:6QE)RDI('L-"B`@("`@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E
M("=014%2+T-H86YN96Q&:6QE+G!H<"<[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("1C:&%N;F5L:6YF;R`](&YE=R!014%27T-H86YN
M96Q&:6QE.PT*("`@("`@("`@("`@("`@("1C:&%N;F5L:6YF;RT^9G)O;5AM
M;%-T<FEN9R@D:6YF;RD[#0H@("`@("`@("`@("`@("`@:68@*"1C:&%N;F5L
M:6YF;RT^9V5T17)R;W)S*"DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G5I+3YO=71P=71$871A*")$;W=N;&]A9&5D(&-H86YN96P@9&%T82!F
M<F]M(&-H86YN96P@7"(D8VAA;FYE;%PB("(@+B`-"B`@("`@("`@("`@("`@
M("`@("`@("`@("=I<R!C;W)R=7!T+"!S:VEP<&EN9R<L("1C;VUM86YD*3L-
M"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("1C:&%N;F5L(#T@)&-H86YN96QI;F9O
M.PT*("`@("`@("`@("`@("`@(&EF("@D8VAA;FYE;"T^9V5T3F%M92@I("$]
M("1S879E*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T
M<'5T1&%T82@G15)23U(Z(%-E8W5R:71Y(')I<VL@+2!D;W=N;&]A9&5D(&-H
M86YN96P@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`G9&5F:6YI=&EO
M;B!F:6QE(&9O<B!C:&%N;F5L("(G#0H@("`@("`@("`@("`@("`@("`@("`@
M("`N("1C:&%N;F5L+3YG971.86UE*"D@+B`G(&9R;VT@8VAA;FYE;"`B)R`N
M("1S879E("X-"B`@("`@("`@("`@("`@("`@("`@("`@("<B+B`@5&\@=7-E
M(&%N>7=A>2P@=7-E(&-H86YN96PM=7!D871E)RP@)&-O;6UA;F0I.PT*("`@
M("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@)')E9RT^=7!D871E0VAA;FYE;"@D8VAA;FYE
M;"P@)&QA<W1M;V1I9FEE9"D[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@(&EF("@D<F5G+3YI<T%L:6%S*"1C:&%N;F5L*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`D=&5M<"`]("8D<F5G+3YG971#:&%N;F5L
M*"1C:&%N;F5L*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)'1E;7`I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H)'1E;7`I.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1T96UP+3YS971!;&EA<R@D
M=&5M<"T^9V5T3F%M92@I+"!T<G5E*3L@+R\@<V5T('1H92!A;&EA<R!T;R!T
M:&4@8VAA;FYE;"!N86UE#0H@("`@("`@("`@("`@("`@("`@(&EF("@D<F5G
M+3YC:&%N;F5L17AI<W1S*"1T96UP+3YG971.86UE*"DI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)T524D]2
M.B!E>&ES=&EN9R!C:&%N;F5L("(G("X@)'1E;7`M/F=E=$YA;64H*2`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)R(@:7,@86QI87-E9"!T;R`B
M)R`N("1C:&%N;F5L("X@)R(@86QR96%D>2!A;F0@8V%N;F]T(&)E("<@+@T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R92UA;&EA<V5D('1O("(G
M("X@)'1E;7`M/F=E=$YA;64H*2`N("<B(&)E8V%U<V4@82!C:&%N;F5L('=I
M=&@@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1H870@;F%M
M92!O<B!A;&EA<R!A;')E861Y(&5X:7-T<R$@(%!L96%S92!R92UA;&EA<R!A
M;F0@=')Y("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A9V%I
M;BXG+"`D8V]M;6%N9"D[#0H@("`@("`@("`@("`@("`@("`@("`@("!C;VYT
M:6YU93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H(D%D
M9&EN9R!N97<@8VAA;FYE;"!<(B1C:&%N;F5L7"(B+"`D8V]M;6%N9"D[#0H@
M("`@("`@("`@("`@("`@4$5!4CHZ<W1A=&EC4'5S:$5R<F]R2&%N9&QI;F<H
M4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`@("`@("`@("1C;VYT96YT
M<R`]("1D;"T^9&]W;FQO861(='1P*"=H='1P.B\O)R`N("1C:&%N;F5L("X@
M)R]C:&%N;F5L+GAM;"<L#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU
M:2P@)'1M<&1I<BP@;G5L;"P@9F%L<V4I.PT*("`@("`@("`@("`@("`@(%!%
M05(Z.G-T871I8U!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D8V]N=&5N=',I*2![#0H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G15)23U(Z($-A;FYO
M="!R971R:65V92!C:&%N;F5L+GAM;"!F;W(@8VAA;FYE;"`B)R`N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D8VAA;FYE;"`N("<B)RP@)&-O;6UA;F0I
M.PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@;&ES="@D8V]N=&5N=',L("1L87-T
M;6]D:69I960I(#T@)&-O;G1E;G1S.PT*("`@("`@("`@("`@("`@("1I;F9O
M(#T@:6UP;&]D92@G)RP@9FEL92@D8V]N=&5N=',I*3L-"B`@("`@("`@("`@
M("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]#:&%N;F5L1FEL92<I*2![
M#0H@("`@("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]#:&%N
M;F5L1FEL92YP:'`G.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`D8VAA;FYE;&EN9F\@/2!N97<@4$5!4E]#:&%N;F5L9FEL93L-"B`@
M("`@("`@("`@("`@("`D8VAA;FYE;&EN9F\M/F9R;VU8;6Q3=')I;F<H)&EN
M9F\I.PT*("`@("`@("`@("`@("`@(&EF("@D8VAA;FYE;&EN9F\M/F=E=$5R
M<F]R<R@I*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T
M<'5T1&%T82@B1&]W;FQO861E9"!C:&%N;F5L(&1A=&$@9G)O;2!C:&%N;F5L
M(%PB)&-H86YN96Q<(B(@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)R!I
M<R!C;W)R=7!T+"!S:VEP<&EN9R<L("1C;VUM86YD*3L-"B`@("`@("`@("`@
M("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("1C:&%N;F5L(#T@)&-H86YN96QI;F9O.PT*("`@("`@("`@
M("`@("`@(&EF("@D8VAA;FYE;"T^9V5T3F%M92@I("$]("1S879E*2![#0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G15)2
M3U(Z(%-E8W5R:71Y(')I<VL@+2!D;W=N;&]A9&5D(&-H86YN96P@)R`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`G9&5F:6YI=&EO;B!F:6QE(&9O<B!C
M:&%N;F5L("(G#0H@("`@("`@("`@("`@("`@("`@("`@("`N("1C:&%N;F5L
M+3YG971.86UE*"D@+B`G(B!F<F]M(&-H86YN96P@(B<@+B`D<V%V92`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`G(BX@(%1O('5S92!A;GEW87DL('5S
M92!C:&%N;F5L+75P9&%T92<L("1C;VUM86YD*3L-"B`@("`@("`@("`@("`@
M("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("1R96<M/F%D9$-H86YN96PH)&-H86YN96PL("1L87-T;6]D:69I
M960I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1T:&ES
M+3YC;VYF:6<M/G-E="@G9&5F875L=%]C:&%N;F5L)RP@)'-A=F5C:&%N;F5L
M*3L-"B`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"=U<&1A=&4M8VAA
M;FYE;',@8V]M<&QE=&4G+"`D8V]M;6%N9"D[#0H@("`@("`@(')E='5R;B!T
M<G5E.PT*("`@('T-"B`@("`-"B`@("!F=6YC=&EO;B!D;TEN9F\H)&-O;6UA
M;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@:68@*'-I
M>F5O9B@D<&%R86US*2`A/2`Q*2![#0H@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H(DYO(&-H86YN96P@<W!E8VEF:65D(BD[#0H@("`@
M("`@('T-"B`@("`@("`@)')E9R`]("8D=&AI<RT^8V]N9FEG+3YG971296=I
M<W1R>2@I.PT*("`@("`@("`D8VAA;FYE;"`]('-T<G1O;&]W97(H)'!A<F%M
M<ULP72D[#0H@("`@("`@(&EF("@D<F5G+3YC:&%N;F5L17AI<W1S*"1C:&%N
M;F5L*2D@>PT*("`@("`@("`@("`@)&-H86X@/2`D<F5G+3YG971#:&%N;F5L
M*"1C:&%N;F5L*3L-"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1C
M:&%N*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@D8VAA;BD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("!I9B`H<W1R<&]S*"1C:&%N;F5L+"`G.B\O)RDI('L-
M"B`@("`@("`@("`@("`@("`D9&]W;FQO861E<B`]("8D=&AI<RT^9V5T1&]W
M;FQO861E<B@I.PT*("`@("`@("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S
M*"=3>7-T96TG*2D@>PT*("`@("`@("`@("`@("`@("`@("!R97%U:7)E7V]N
M8V4@)U-Y<W1E;2YP:'`G.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`D=&UP9&ER(#T@4WES=&5M.CIM:W1E;7`H87)R87DH)RUD)RDI
M.PT*("`@("`@("`@("`@("`@(%!%05(Z.G-T871I8U!U<VA%<G)O<DAA;F1L
M:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@("`@("`@("`D;&]C
M(#T@)&1O=VYL;V%D97(M/F1O=VYL;V%D2'1T<"@D8VAA;FYE;"P@)'1H:7,M
M/G5I+"`D=&UP9&ER*3L-"B`@("`@("`@("`@("`@("!014%2.CIS=&%T:6-0
M;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)&QO8RDI('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*"=#86YN;W0@;W!E;B`B)R`N("1C:&%N;F5L
M("X@)R(G*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@("`D8V]N=&5N=',@/2!I;7!L;V1E*"<G+"!F:6QE*"1L;V,I
M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("1F<"`]($!F;W!E;B@D<&%R86US6S!=+"`G<B<I
M.PT*("`@("`@("`@("`@("`@(&EF("@A)&9P*2![#0H@("`@("`@("`@("`@
M("`@("`@(&EF("A`9FEL95]E>&ES=',H)'!A<F%M<ULP72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G
M0V%N;F]T(&]P96X@(B<@+B`D<&%R86US6S!=("X@)R(G*3L-"B`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G56YK;F]W;B!C:&%N;F5L("(G
M("X@)&-H86YN96P@+B`G(B<I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1C;VYT96YT<R`]
M("<G.PT*("`@("`@("`@("`@("`@('=H:6QE("@A9F5O9B@D9G`I*2![#0H@
M("`@("`@("`@("`@("`@("`@("1C;VYT96YT<R`N/2!F<F5A9"@D9G`L(#$P
M,C0I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!F8VQO
M<V4H)&9P*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A8VQA
M<W-?97AI<W1S*"=014%27T-H86YN96Q&:6QE)RDI('L-"B`@("`@("`@("`@
M("`@("!R97%U:7)E7V]N8V4@)U!%05(O0VAA;FYE;$9I;&4N<&AP)SL-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("1C:&%N(#T@;F5W(%!%05)?0VAA
M;FYE;$9I;&4[#0H@("`@("`@("`@("`D8VAA;BT^9G)O;5AM;%-T<FEN9R@D
M8V]N=&5N=',I.PT*("`@("`@("`@("`@)&-H86XM/G9A;&ED871E*"D[#0H@
M("`@("`@("`@("!I9B`H)&5R<G,@/2`D8VAA;BT^9V5T17)R;W)S*'1R=64I
M*2![#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&5R<G,@87,@)&5R<BD@
M>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H
M)&5R<ELG;&5V96PG72`N("<Z("<@+B`D97)R6R=M97-S86=E)UTI.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H)T-H86YN96P@9FEL92`B)R`N("1P87)A;7-;,%T@+B`G
M(B!I<R!N;W0@=F%L:60G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H)&-H86XI('L-"B`@("`@("`@("`@("1C:&%N;F5L(#T@
M)&-H86XM/F=E=$YA;64H*3L-"B`@("`@("`@("`@("1C87!T:6]N(#T@)T-H
M86YN96P@)R`N("1C:&%N;F5L("X@)R!);F9O<FUA=&EO;CHG.PT*("`@("`@
M("`@("`@)&1A=&$Q(#T@87)R87DH#0H@("`@("`@("`@("`@("`@)V-A<'1I
M;VXG(#T^("1C87!T:6]N+`T*("`@("`@("`@("`@("`@("=B;W)D97(G(#T^
M('1R=64I.PT*("`@("`@("`@("`@)&1A=&$Q6R=D871A)UU;)W-E<G9E<B==
M(#T@87)R87DH)TYA;64@86YD(%-E<G9E<B<L("1C:&%N+3YG971.86UE*"DI
M.PT*("`@("`@("`@("`@:68@*"1C:&%N+3YG971!;&EA<R@I("$]("1C:&%N
M+3YG971.86UE*"DI('L-"B`@("`@("`@("`@("`@("`D9&%T83%;)V1A=&$G
M75LG86QI87,G72`](&%R<F%Y*"=!;&EA<R<L("1C:&%N+3YG971!;&EA<R@I
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1D871A,5LG9&%T82==
M6R=S=6UM87)Y)UT@/2!A<G)A>2@G4W5M;6%R>2<L("1C:&%N+3YG9713=6UM
M87)Y*"DI.PT*("`@("`@("`@("`@)'9A;&ED871E(#T@)&-H86XM/F=E=%9A
M;&ED871I;VY086-K86=E*"D[#0H@("`@("`@("`@("`D9&%T83%;)V1A=&$G
M75LG=G!A8VMA9V4G72`](&%R<F%Y*"=686QI9&%T:6]N(%!A8VMA9V4@3F%M
M92<L("1V86QI9&%T95LG7V-O;G1E;G0G72D[#0H@("`@("`@("`@("`D9&%T
M83%;)V1A=&$G75LG=G!A8VMA9V5V97)S:6]N)UT@/0T*("`@("`@("`@("`@
M("`@(&%R<F%Y*"=686QI9&%T:6]N(%!A8VMA9V4@5F5R<VEO;B<L("1V86QI
M9&%T95LG871T<FEB<R==6R=V97)S:6]N)UTI.PT*("`@("`@("`@("`@)&0@
M/2!A<G)A>2@I.PT*("`@("`@("`@("`@)&1;)VUA:6XG72`]("1D871A,3L-
M"@T*("`@("`@("`@("`@)&1A=&%;)V1A=&$G72`](&%R<F%Y*"D[#0H@("`@
M("`@("`@("`D9&%T85LG8V%P=&EO;B==(#T@)U-E<G9E<B!#87!A8FEL:71I
M97,G.PT*("`@("`@("`@("`@)&1A=&%;)VAE861L:6YE)UT@/2!A<G)A>2@G
M5'EP92<L("=697)S:6]N+U)%4U0@='EP92<L("=&=6YC=&EO;B!.86UE+U)%
M4U0@8F%S92<I.PT*("`@("`@("`@("`@)&-A<&%B:6QI=&EE<R`]("1C:&%N
M+3YG971&=6YC=&EO;G,H)WAM;')P8R<I.PT*("`@("`@("`@("`@)'-O87!S
M(#T@)&-H86XM/F=E=$9U;F-T:6]N<R@G<V]A<"<I.PT*("`@("`@("`@("`@
M:68@*"1C87!A8FEL:71I97,@?'P@)'-O87!S('Q\("1C:&%N+3YS=7!P;W)T
M<U)%4U0H*2D@>PT*("`@("`@("`@("`@("`@(&EF("@D8V%P86)I;&ET:65S
M*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&-A<&%B:6QI
M=&EE<ULP72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1C87!A8FEL
M:71I97,@/2!A<G)A>2@D8V%P86)I;&ET:65S*3L-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D8V%P86)I
M;&ET:65S(&%S("1P<F]T;V-O;"D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)&1A=&%;)V1A=&$G75M=(#T@87)R87DH)WAM;')P8R<L("1P<F]T;V-O
M;%LG871T<FEB<R==6R=V97)S:6]N)UTL#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!R;W1O8V]L6R=?8V]N=&5N="==*3L-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!I9B`H)'-O87!S*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)'-O87!S6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'-O
M87!S(#T@87)R87DH)'-O87!S*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D<V]A<',@87,@)'!R;W1O
M8V]L*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D9&%T85LG9&%T82==
M6UT@/2!A<G)A>2@G<V]A<"<L("1P<F]T;V-O;%LG871T<FEB<R==6R=V97)S
M:6]N)UTL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!R;W1O8V]L
M6R=?8V]N=&5N="==*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H)&-H86XM/G-U<'!O
M<G1S4D535"@I*2![#0H@("`@("`@("`@("`@("`@("`@("1F=6YC<R`]("1C
M:&%N+3YG971&=6YC=&EO;G,H)W)E<W0G*3L-"B`@("`@("`@("`@("`@("`@
M("`@:68@*"%I<W-E="@D9G5N8W-;,%TI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D9G5N8W,@/2!A<G)A>2@D9G5N8W,I.PT*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1F=6YC
M<R!A<R`D<')O=&]C;VPI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1D
M871A6R=D871A)UU;72`](&%R<F%Y*"=R97-T)RP@)'!R;W1O8V]L6R=A='1R
M:6)S)UU;)W1Y<&4G72P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<')O=&]C;VQ;)U]C;VYT96YT)UTI.R`-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@)&1A=&%;)V1A=&$G75M=(#T@87)R87DH)TYO('-U
M<'!O<G1E9"!P<F]T;V-O;',G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("1D6R=P<F]T;V-O;',G72`]("1D871A.PT*("`@("`@("`@("`@)&1A
M=&%;)V1A=&$G72`](&%R<F%Y*"D[#0H@("`@("`@("`@("`D;6ER<F]R<R`]
M("1C:&%N+3YG971-:7)R;W)S*"D[#0H@("`@("`@("`@("!I9B`H)&UI<G)O
M<G,I('L-"B`@("`@("`@("`@("`@("`D9&%T85LG8V%P=&EO;B==(#T@)T-H
M86YN96P@)R`N("1C:&%N;F5L("X@)R!-:7)R;W)S.B<[#0H@("`@("`@("`@
M("`@("`@=6YS970H)&1A=&%;)VAE861L:6YE)UTI.PT*("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1M:7)R;W)S(&%S("1M:7)R;W(I('L-"B`@("`@("`@
M("`@("`@("`@("`@)&1A=&%;)V1A=&$G75M=(#T@87)R87DH)&UI<G)O<ELG
M871T<FEB<R==6R=H;W-T)UTI.PT*("`@("`@("`@("`@("`@("`@("`D9%LG
M;6ER<F]R<R==(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1M:7)R;W)S(&%S("1M:7)R;W(I('L-"B`@
M("`@("`@("`@("`@("`@("`@)&1A=&%;)V1A=&$G72`](&%R<F%Y*"D[#0H@
M("`@("`@("`@("`@("`@("`@("1D871A6R=C87!T:6]N)UT@/2`G36ER<F]R
M("<@+B`D;6ER<F]R6R=A='1R:6)S)UU;)VAO<W0G72`N("<@0V%P86)I;&ET
M:65S)SL-"B`@("`@("`@("`@("`@("`@("`@)&1A=&%;)VAE861L:6YE)UT@
M/2!A<G)A>2@G5'EP92<L("=697)S:6]N+U)%4U0@='EP92<L("=&=6YC=&EO
M;B!.86UE+U)%4U0@8F%S92<I.PT*("`@("`@("`@("`@("`@("`@("`D8V%P
M86)I;&ET:65S(#T@)&-H86XM/F=E=$9U;F-T:6]N<R@G>&UL<G!C)RP@)&UI
M<G)O<ELG871T<FEB<R==6R=H;W-T)UTI.PT*("`@("`@("`@("`@("`@("`@
M("`D<V]A<',@/2`D8VAA;BT^9V5T1G5N8W1I;VYS*"=S;V%P)RP@)&UI<G)O
M<ELG871T<FEB<R==6R=H;W-T)UTI.PT*("`@("`@("`@("`@("`@("`@("!I
M9B`H)&-A<&%B:6QI=&EE<R!\?"`D<V]A<',@?'P@)&-H86XM/G-U<'!O<G1S
M4D535"@D;6ER<F]R6R=A='1R:6)S)UU;)VAO<W0G72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@D8V%P86)I;&ET:65S*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D8V%P86)I;&ET:65S
M6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V%P
M86)I;&ET:65S(#T@87)R87DH)&-A<&%B:6QI=&EE<RD[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1C87!A8FEL:71I97,@87,@)'!R;W1O8V]L*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D871A6R=D871A)UU;
M72`](&%R<F%Y*"=X;6QR<&,G+"`D<')O=&]C;VQ;)V%T=')I8G,G75LG=F5R
M<VEO;B==+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!R;W1O8V]L6R=?8V]N=&5N="==*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H)'-O87!S*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*"%I<W-E="@D<V]A<'-;,%TI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S;V%P<R`](&%R<F%Y*"1S
M;V%P<RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1S;V%P<R!A<R`D<')O
M=&]C;VPI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A
M=&%;)V1A=&$G75M=(#T@87)R87DH)W-O87`G+"`D<')O=&]C;VQ;)V%T=')I
M8G,G75LG=F5R<VEO;B==+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!R;W1O8V]L6R=?8V]N=&5N="==*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&-H86XM/G-U<'!O<G1S
M4D535"@D;6ER<F]R6R=A='1R:6)S)UU;)VAO<W0G72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9G5N8W,@/2`D8VAA;BT^9V5T1G5N8W1I
M;VYS*"=R97-T)RP@)&UI<G)O<ELG871T<FEB<R==6R=H;W-T)UTI.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&9U;F-S6S!=
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9G5N8W,@
M/2!A<G)A>2@D9G5N8W,I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D9G5N
M8W,@87,@)'!R;W1O8V]L*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1D871A6R=D871A)UU;72`](&%R<F%Y*"=R97-T)RP@)'!R;W1O
M8V]L6R=A='1R:6)S)UU;)W1Y<&4G72P-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P<F]T;V-O;%LG7V-O;G1E;G0G72D[(`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1D871A6R=D871A)UU;72`](&%R<F%Y*"=.
M;R!S=7!P;W)T960@<')O=&]C;VQS)RD[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@)&1;)VUI<G)O<G!R;W1O8V]L<R==
M(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"1D+"`G8VAA;FYE
M;"UI;F9O)RD[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H)U-E<FEO=7,@97)R;W(Z($-H86YN96P@
M(B<@+B`D<&%R86US6S!=("X-"B`@("`@("`@("`@("`@("`G(B!H87,@82!C
M;W)R=7!T960@<F5G:7-T<GD@96YT<GDG*3L-"B`@("`@("`@?0T*("`@('T-
M"@T*("`@("\O('U]?0T*("`@(`T*("`@(&9U;F-T:6]N(&1O1&5L971E*"1C
M;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@(&EF
M("AS:7IE;V8H)'!A<F%M<RD@(3T@,2D@>PT*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*"=C:&%N;F5L+61E;&5T93H@;F\@8VAA;FYE
M;"!S<&5C:69I960G*3L-"B`@("`@("`@?0T*("`@("`@("`D<F5G(#T@)B1T
M:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@(&EF("@A)')E
M9RT^8VAA;FYE;$5X:7-T<R@D<&%R86US6S!=*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=C:&%N;F5L+61E;&5T93H@8VAA
M;FYE;"`B)R`N("1P87)A;7-;,%T@+B`G(B!D;V5S(&YO="!E>&ES="<I.PT*
M("`@("`@("!]#0H@("`@("`@("1C:&%N;F5L(#T@)')E9RT^8VAA;FYE;$YA
M;64H)'!A<F%M<ULP72D[#0H@("`@("`@(&EF("@D8VAA;FYE;"`]/2`G<&5A
M<BYP:'`N;F5T)RD@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*"=#86YN;W0@9&5L971E('1H92!P96%R+G!H<"YN970@8VAA;FYE
M;"<I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D8VAA;FYE;"`]/2`G<&5C
M;"YP:'`N;F5T)RD@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*"=#86YN;W0@9&5L971E('1H92!P96-L+G!H<"YN970@8VAA;FYE
M;"<I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D8VAA;FYE;"`]/2`G7U]U
M<FDG*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M)T-A;FYO="!D96QE=&4@=&AE(%]?=7)I('!S975D;RUC:&%N;F5L)RD[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<B`]("1R
M96<M/FQI<W1086-K86=E<R@D8VAA;FYE;"DI*2![#0H@("`@("`@("`@("!R
M971U<FX@)&5R<CL-"B`@("`@("`@?0T*("`@("`@("!I9B`H8V]U;G0H)&5R
M<BDI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G
M0VAA;FYE;"`B)R`N("1C:&%N;F5L("X-"B`@("`@("`@("`@("`@("`G(B!H
M87,@:6YS=&%L;&5D('!A8VMA9V5S+"!C86YN;W0@9&5L971E)RD[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"$D<F5G+3YD96QE=&5#:&%N;F5L*"1C:&%N
M;F5L*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*"=#:&%N;F5L("(G("X@)&-H86YN96P@+B`G(B!D96QE=&EO;B!F86EL960G
M*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1T:&ES+3YC;VYF
M:6<M/F1E;&5T94-H86YN96PH)&-H86YN96PI.PT*("`@("`@("`@("`@)'1H
M:7,M/G5I+3YO=71P=71$871A*"=#:&%N;F5L("(G("X@)&-H86YN96P@+B`G
M(B!D96QE=&5D)RP@)&-O;6UA;F0I.PT*("`@("`@("!]#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@9&]!9&0H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US
M*0T*("`@('L-"B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US*2`A/2`Q*2![
M#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)V-H86YN
M96PM861D.B!N;R!C:&%N;F5L(&9I;&4@<W!E8VEF:65D)RD[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*'-T<G!O<R@D<&%R86US6S!=+"`G.B\O)RDI('L-
M"B`@("`@("`@("`@("1D;W=N;&]A9&5R(#T@)B1T:&ES+3YG971$;W=N;&]A
M9&5R*"D[#0H@("`@("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4WES=&5M
M)RDI('L-"B`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U-Y<W1E;2YP
M:'`G.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'1M<&1I<B`](%-Y
M<W1E;3HZ;6MT96UP*&%R<F%Y*"<M9"<I*3L-"B`@("`@("`@("`@(%!%05(Z
M.G-T871I8U!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-
M"B`@("`@("`@("`@("1L;V,@/2`D9&]W;FQO861E<BT^9&]W;FQO861(='1P
M*"1P87)A;7-;,%TL("1T:&ES+3YU:2P@)'1M<&1I<BP@;G5L;"P@9F%L<V4I
M.PT*("`@("`@("`@("`@4$5!4CHZ<W1A=&EC4&]P17)R;W)(86YD;&EN9R@I
M.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&QO8RDI('L-"B`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)V-H86YN
M96PM861D.B!#86YN;W0@;W!E;B`B)R`N("1P87)A;7-;,%T@+B`G(B<I.PT*
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!L:7-T*"1L
M;V,L("1L87-T;6]D:69I960I(#T@)&QO8SL-"B`@("`@("`@("`@("`@("`D
M8V]N=&5N=',@/2!I;7!L;V1E*"<G+"!F:6QE*"1L;V,I*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1L87-T;6]D
M:69I960@/2!F86QS93L-"B`@("`@("`@("`@("1F<"`]($!F;W!E;B@D<&%R
M86US6S!=+"`G<B<I.PT*("`@("`@("`@("`@:68@*"$D9G`I('L-"B`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)V-H86YN96PM
M861D.B!C86YN;W0@;W!E;B`B)R`N("1P87)A;7-;,%T@+B`G(B<I.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@)&-O;G1E;G1S(#T@)R<[#0H@("`@
M("`@("`@("!W:&EL92`H(69E;V8H)&9P*2D@>PT*("`@("`@("`@("`@("`@
M("1C;VYT96YT<R`N/2!F<F5A9"@D9G`L(#$P,C0I.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?0VAA;FYE;$9I;&4G*2D@>PT*
M("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+T-H86YN96Q&:6QE+G!H
M<"<[#0H@("`@("`@('T-"B`@("`@("`@)&-H86YN96P@/2!N97<@4$5!4E]#
M:&%N;F5L1FEL93L-"B`@("`@("`@4$5!4CHZ<W1A=&EC4'5S:$5R<F]R2&%N
M9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`D<F5S=6QT(#T@
M)&-H86YN96PM/F9R;VU8;6Q3=')I;F<H)&-O;G1E;G1S*3L-"B`@("`@("`@
M4$5!4CHZ<W1A=&EC4&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("!I9B`H
M(21R97-U;'0I('L-"B`@("`@("`@("`@("1E>&ET(#T@9F%L<V4[#0H@("`@
M("`@("`@("!I9B`H8V]U;G0H)&5R<F]R<R`]("1C:&%N;F5L+3YG971%<G)O
M<G,H=')U92DI*2![#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&5R<F]R
M<R!A<R`D97)R;W(I('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G5I
M+3YO=71P=71$871A*'5C9FER<W0H)&5R<F]R6R=L979E;"==("X@)SH@)R`N
M("1E<G)O<ELG;65S<V%G92==*2D[#0H@("`@("`@("`@("`@("`@("`@(&EF
M("@A)&5X:70I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1E>&ET(#T@
M)&5R<F]R6R=L979E;"==(#T]("=E<G)O<B<@/R!T<G5E(#H@9F%L<V4[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@:68@*"1E>&ET*2![#0H@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G8VAA;FYE;"UA9&0Z(&EN=F%L
M:60@8VAA;FYE;"YX;6P@9FEL92<I.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D<F5G(#T@)B1T:&ES
M+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@(&EF("@D<F5G+3YC
M:&%N;F5L17AI<W1S*"1C:&%N;F5L+3YG971.86UE*"DI*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)V-H86YN96PM861D.B!#
M:&%N;F5L("(G("X@)&-H86YN96PM/F=E=$YA;64H*2`N#0H@("`@("`@("`@
M("`@("`@)R(@97AI<W1S+"!U<V4@8VAA;FYE;"UU<&1A=&4@=&\@=7!D871E
M(&5N=')Y)RD[#0H@("`@("`@('T-"B`@("`@("`@)')E="`]("1R96<M/F%D
M9$-H86YN96PH)&-H86YN96PL("1L87-T;6]D:69I960I.PT*("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D<F5T*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M("1R970[#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D<F5T*2![#0H@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)V-H86YN96PM861D
M.B!A9&1I;F<@0VAA;FYE;"`B)R`N("1C:&%N;F5L+3YG971.86UE*"D@+@T*
M("`@("`@("`@("`@("`@("<B('1O(')E9VES=')Y(&9A:6QE9"<I.PT*("`@
M("`@("!]#0H@("`@("`@("1T:&ES+3YC;VYF:6<M/G-E=$-H86YN96QS*"1R
M96<M/FQI<W1#:&%N;F5L<R@I*3L-"B`@("`@("`@)'1H:7,M/F-O;F9I9RT^
M=W)I=&5#;VYF:6=&:6QE*"D[#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T
M1&%T82@G061D:6YG($-H86YN96P@(B<@+B`D8VAA;FYE;"T^9V5T3F%M92@I
M("X@)R(@<W5C8V5E9&5D)RP@)&-O;6UA;F0I.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N(&1O57!D871E*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-
M"B`@("![#0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=3>7-T96TG*2D@
M>PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=3>7-T96TN<&AP)SL-"B`@
M("`@("`@?0T*("`@("`@("`D=&UP9&ER(#T@4WES=&5M.CIM:W1E;7`H87)R
M87DH)RUD)RDI.PT*("`@("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E
M=%)E9VES=')Y*"D[#0H@("`@("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@(3T@
M,2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*").
M;R!C:&%N;F5L(&9I;&4@<W!E8VEF:65D(BD[#0H@("`@("`@('T-"B`@("`@
M("`@)&QA<W1M;V1I9FEE9"`](&9A;'-E.PT*("`@("`@("!I9B`H*"%F:6QE
M7V5X:7-T<R@D<&%R86US6S!=*2!\?"!I<U]D:7(H)'!A<F%M<ULP72DI#0H@
M("`@("`@("`@("`@("8F("1R96<M/F-H86YN96Q%>&ES=',H<W1R=&]L;W=E
M<B@D<&%R86US6S!=*2DI('L-"B`@("`@("`@("`@("1C(#T@)')E9RT^9V5T
M0VAA;FYE;"AS=')T;VQO=V5R*"1P87)A;7-;,%TI*3L-"B`@("`@("`@("`@
M(&EF("A014%2.CII<T5R<F]R*"1C*2D@>PT*("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D8RD[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)U)E=')I979I;F<@
M8VAA;FYE;"YX;6P@9G)O;2!R96UO=&4@<V5R=F5R)RD[#0H@("`@("`@("`@
M("`D9&P@/2`F)'1H:7,M/F=E=$1O=VYL;V%D97(H87)R87DH*2D[#0H@("`@
M("`@("`@("`O+R!I9B!F;W)C92!I<R!S<&5C:69I960L('5S92!A('1I;65S
M=&%M<"!O9B`B,2(@=&\@9F]R8V4@<F5T<FEE=F%L#0H@("`@("`@("`@("`D
M;&%S=&UO9&EF:65D(#T@:7-S970H)&]P=&EO;G-;)V9O<F-E)UTI(#\@9F%L
M<V4@.B`D8RT^;&%S=$UO9&EF:65D*"D[#0H@("`@("`@("`@("!014%2.CIS
M=&%T:6-0=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@
M("`@("`@("`@("`D8V]N=&5N=',@/2`D9&PM/F1O=VYL;V%D2'1T<"@G:'1T
M<#HO+R<@+B`D8RT^9V5T3F%M92@I("X@)R]C:&%N;F5L+GAM;"<L#0H@("`@
M("`@("`@("`@("`@)'1H:7,M/G5I+"`D=&UP9&ER+"!N=6QL+"`D;&%S=&UO
M9&EF:65D*3L-"B`@("`@("`@("`@(%!%05(Z.G-T871I8U!O<$5R<F]R2&%N
M9&QI;F<H*3L-"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1C;VYT
M96YT<RDI('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H)T-A;FYO="!R971R:65V92!C:&%N;F5L+GAM;"!F;W(@8VAA;FYE
M;"`B)R`N#0H@("`@("`@("`@("`@("`@("`@("1C+3YG971.86UE*"D@+B`G
M(B<I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@;&ES="@D8V]N=&5N
M=',L("1L87-T;6]D:69I960I(#T@)&-O;G1E;G1S.PT*("`@("`@("`@("`@
M:68@*"$D8V]N=&5N=',I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^=6DM
M/F]U='!U=$1A=&$H(D-H86YN96P@)'!A<F%M<ULP72!C:&%N;F5L+GAM;"!I
M<R!U<"!T;R!D871E(BD[#0H@("`@("`@("`@("`@("`@<F5T=7)N.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@)&-O;G1E;G1S(#T@:6UP;&]D92@G
M)RP@9FEL92@D8V]N=&5N=',I*3L-"B`@("`@("`@("`@(&EF("@A8VQA<W-?
M97AI<W1S*"=014%27T-H86YN96Q&:6QE)RDI('L-"B`@("`@("`@("`@("`@
M("!R97%U:7)E7V]N8V4@)U!%05(O0VAA;FYE;$9I;&4N<&AP)SL-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("1C:&%N;F5L(#T@;F5W(%!%05)?0VAA
M;FYE;$9I;&4[#0H@("`@("`@("`@("`D8VAA;FYE;"T^9G)O;5AM;%-T<FEN
M9R@D8V]N=&5N=',I.PT*("`@("`@("`@("`@:68@*"$D8VAA;FYE;"T^9V5T
M17)R;W)S*"DI('L-"B`@("`@("`@("`@("`@("`O+R!S96-U<FET>2!C:&5C
M:SH@:7,@=&AE(&1O=VYL;V%D960@9FEL92!F;W(@=&AE(&-H86YN96P@=V4@
M9V]T(&ET(&9R;VT_#0H@("`@("`@("`@("`@("`@:68@*'-T<G1O;&]W97(H
M)&-H86YN96PM/F=E=$YA;64H*2D@(3T@<W1R=&]L;W=E<B@D8RT^9V5T3F%M
M92@I*2D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&]P=&EO
M;G-;)V9O<F-E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^=6DM/FQO9R@P+"`G5T%23DE.1SH@9&]W;FQO861E9"!C:&%N;F5L(&1E
M9FEN:71I;VX@9FEL92<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("<@9F]R(&-H86YN96P@(B<@+B`D8VAA;FYE;"T^9V5T3F%M92@I("X@)R(@
M9G)O;2!C:&%N;F5L("(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!S=')T;VQO=V5R*"1C+3YG971.86UE*"DI("X@)R(G*3L-"B`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G15)23U(Z(&1O=VYL;V%D960@
M8VAA;FYE;"!D969I;FET:6]N(&9I;&4G("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G(&9O<B!C:&%N;F5L("(G("X@)&-H86YN96PM/F=E=$YA
M;64H*2`N("<B(&9R;VT@8VAA;FYE;"`B)R`N#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<W1R=&]L;W=E<B@D8RT^9V5T3F%M92@I*2`N("<B)RD[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!I
M9B`H<W1R<&]S*"1P87)A;7-;,%TL("<Z+R\G*2D@>PT*("`@("`@("`@("`@
M("`@("1D;"`]("8D=&AI<RT^9V5T1&]W;FQO861E<B@I.PT*("`@("`@("`@
M("`@("`@(%!%05(Z.G-T871I8U!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)2
M3U)?4D5455).*3L-"B`@("`@("`@("`@("`@("`D;&]C(#T@)&1L+3YD;W=N
M;&]A9$AT='`H)'!A<F%M<ULP72P-"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G5I+"`D=&UP9&ER+"!N=6QL+"`D;&%S=&UO9&EF:65D*3L-"B`@("`@
M("`@("`@("`@("!014%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L:6YG*"D[#0H@
M("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&QO8RDI('L-"B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")#
M86YN;W0@;W!E;B`B("X@)'!A<F%M<ULP72D[#0H@("`@("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@;&ES="@D;&]C+"`D;&%S
M=&UO9&EF:65D*2`]("1L;V,[#0H@("`@("`@("`@("`@("`@("`@("1C;VYT
M96YT<R`](&EM<&QO9&4H)R<L(&9I;&4H)&QO8RDI.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M)&9P(#T@0&9O<&5N*"1P87)A;7-;,%TL("=R)RD[#0H@("`@("`@("`@("`@
M("`@:68@*"$D9G`I('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*")#86YN;W0@;W!E;B`B("X@)'!A<F%M<ULP72D[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1C;VYT96YT
M<R`]("<G.PT*("`@("`@("`@("`@("`@('=H:6QE("@A9F5O9B@D9G`I*2![
M#0H@("`@("`@("`@("`@("`@("`@("1C;VYT96YT<R`N/2!F<F5A9"@D9G`L
M(#$P,C0I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!F
M8VQO<V4H)&9P*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A
M8VQA<W-?97AI<W1S*"=014%27T-H86YN96Q&:6QE)RDI('L-"B`@("`@("`@
M("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O0VAA;FYE;$9I;&4N<&AP)SL-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1C:&%N;F5L(#T@;F5W(%!%
M05)?0VAA;FYE;$9I;&4[#0H@("`@("`@("`@("`D8VAA;FYE;"T^9G)O;5AM
M;%-T<FEN9R@D8V]N=&5N=',I.PT*("`@("`@("!]#0H@("`@("`@("1E>&ET
M(#T@9F%L<V4[#0H@("`@("`@(&EF("AC;W5N="@D97)R;W)S(#T@)&-H86YN
M96PM/F=E=$5R<F]R<RAT<G5E*2DI('L-"B`@("`@("`@("`@(&9O<F5A8V@@
M*"1E<G)O<G,@87,@)&5R<F]R*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M
M/G5I+3YO=71P=71$871A*'5C9FER<W0H)&5R<F]R6R=L979E;"==("X@)SH@
M)R`N("1E<G)O<ELG;65S<V%G92==*2D[#0H@("`@("`@("`@("`@("`@:68@
M*"$D97AI="D@>PT*("`@("`@("`@("`@("`@("`@("`D97AI="`]("1E<G)O
M<ELG;&5V96PG72`]/2`G97)R;W(G(#\@=')U92`Z(&9A;'-E.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D
M97AI="D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@G26YV86QI9"!C:&%N;F5L+GAM;"!F:6QE)RD[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D<F5G+3YC:&%N;F5L17AI
M<W1S*"1C:&%N;F5L+3YG971.86UE*"DI*2![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H)T5R<F]R.B!#:&%N;F5L("(G("X@)&-H
M86YN96PM/F=E=$YA;64H*2`N#0H@("`@("`@("`@("`@("`@)R(@9&]E<R!N
M;W0@97AI<W0L('5S92!C:&%N;F5L+6%D9"!T;R!A9&0@86X@96YT<GDG*3L-
M"B`@("`@("`@?0T*("`@("`@("`D<F5T(#T@)')E9RT^=7!D871E0VAA;FYE
M;"@D8VAA;FYE;"P@)&QA<W1M;V1I9FEE9"D[#0H@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1R970I*2![#0H@("`@("`@("`@("!R971U<FX@)')E=#L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H(21R970I('L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G57!D871I;F<@0VAA;FYE;"`B
M)R`N("1C:&%N;F5L+3YG971.86UE*"D@+@T*("`@("`@("`@("`@("`@("<B
M(&EN(')E9VES=')Y(&9A:6QE9"<I.PT*("`@("`@("!]#0H@("`@("`@("1T
M:&ES+3YC;VYF:6<M/G-E=$-H86YN96QS*"1R96<M/FQI<W1#:&%N;F5L<R@I
M*3L-"B`@("`@("`@)'1H:7,M/F-O;F9I9RT^=W)I=&5#;VYF:6=&:6QE*"D[
M#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G57!D871E(&]F($-H
M86YN96P@(B<@+B`D8VAA;FYE;"T^9V5T3F%M92@I("X@)R(@<W5C8V5E9&5D
M)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@)F=E=$1O=VYL;V%D97(H*0T*
M("`@('L-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?1&]W;FQO
M861E<B<I*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O1&]W
M;FQO861E<BYP:'`G.PT*("`@("`@("!]#0H@("`@("`@("1A(#T@;F5W(%!%
M05)?1&]W;FQO861E<B@D=&AI<RT^=6DL(&%R<F%Y*"DL("1T:&ES+3YC;VYF
M:6<I.PT*("`@("`@("!R971U<FX@)&$[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@9&]!;&EA<R@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I#0H@("`@
M>PT*("`@("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y
M*"D[#0H@("`@("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@/3T@,2D@>PT*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=.;R!C:&%N;F5L
M(&%L:6%S('-P96-I9FEE9"<I.PT*("`@("`@("!]#0H@("`@("`@(&EF("AS
M:7IE;V8H)'!A<F%M<RD@(3T@,BD@>PT*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*`T*("`@("`@("`@("`@("`@("=);G9A;&ED(&9O
M<FUA="P@8V]R<F5C="!I<SH@8VAA;FYE;"UA;&EA<R!C:&%N;F5L(&%L:6%S
M)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D<F5G+3YC:&%N;F5L17AI
M<W1S*"1P87)A;7-;,%TL('1R=64I*2![#0H@("`@("`@("`@("!I9B`H)')E
M9RT^:7-!;&EA<R@D<&%R86US6S!=*2D@>PT*("`@("`@("`@("`@("`@("1E
M>'1R82`]("<@*'5S92`B8VAA;FYE;"UA;&EA<R`G("X@)')E9RT^8VAA;FYE
M;$YA;64H)'!A<F%M<ULP72D@+B`G("<@+@T*("`@("`@("`@("`@("`@("`@
M("!S=')T;VQO=V5R*"1P87)A;7-;,5TI("X@)R(I)SL-"B`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@)&5X=')A(#T@)R<[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H)R(G("X@)'!A<F%M<ULP72`N("<B(&ES(&YO="!A('9A;&ED(&-H86YN
M96PG("X@)&5X=')A*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)')E9RT^
M:7-!;&EA<R@D<&%R86US6S%=*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*"=#:&%N;F5L("(G("X@)')E9RT^8VAA;FYE;$YA
M;64H)'!A<F%M<ULQ72D@+B`G(B!I<R`G("X-"B`@("`@("`@("`@("`@("`G
M86QR96%D>2!A;&EA<V5D('1O("(G("X@<W1R=&]L;W=E<B@D<&%R86US6S%=
M*2`N("<B+"!C86YN;W0@<F4M86QI87,G*3L-"B`@("`@("`@?0T*("`@("`@
M("`D8VAA;B`]("8D<F5G+3YG971#:&%N;F5L*"1P87)A;7-;,%TI.PT*("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8VAA;BDI('L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G0V]R<G5P="!R96=I<W1R>3\@
M($5R<F]R(')E=')I979I;F<@8VAA;FYE;"`B)R`N("1P87)A;7-;,%T@+@T*
M("`@("`@("`@("`@("`@("<B(&EN9F]R;6%T:6]N("@G("X@)&-H86XM/F=E
M=$UE<W-A9V4H*2`N("<I)RD[#0H@("`@("`@('T-"B`@("`@("`@+R\@;6%K
M92!I="!A(&QO8V%L(&%L:6%S#0H@("`@("`@(&EF("@A)&-H86XM/G-E=$%L
M:6%S*'-T<G1O;&]W97(H)'!A<F%M<ULQ72DL('1R=64I*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)T%L:6%S("(G("X@<W1R
M=&]L;W=E<B@D<&%R86US6S%=*2`N#0H@("`@("`@("`@("`@("`@)R(@:7,@
M;F]T(&$@=F%L:60@8VAA;FYE;"!A;&EA<R<I.PT*("`@("`@("!]#0H@("`@
M("`@("1R96<M/G5P9&%T94-H86YN96PH)&-H86XI.PT*("`@("`@("`D=&AI
M<RT^=6DM/F]U='!U=$1A=&$H)T-H86YN96P@(B<@+B`D8VAA;BT^9V5T3F%M
M92@I("X@)R(@86QI87-E9"!S=6-C97-S9G5L;'D@=&\@(B<@+@T*("`@("`@
M("`@("`@<W1R=&]L;W=E<B@D<&%R86US6S%=*2`N("<B)RD[#0H@("`@?0T*
M#0H@("`@9G5N8W1I;VX@9&]$:7-C;W9E<B@D8V]M;6%N9"P@)&]P=&EO;G,L
M("1P87)A;7,I#0H@("`@>PT*("`@("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF
M:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@(&EF("AS:7IE;V8H)'!A<F%M
M<RD@(3T@,2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*").;R!C:&%N;F5L('-E<G9E<B!S<&5C:69I960B*3L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H)')E9RT^8VAA;FYE;$5X:7-T<R@D<&%R86US6S!=
M*2D@>PT*("`@("`@("`@("`@:68@*"1R96<M/FES06QI87,H)'!A<F%M<ULP
M72DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H(D$@8VAA;FYE;"!A;&EA<R!N86UE9"!<(B1P87)A;7-;,%U<(B`B("X-
M"B`@("`@("`@("`@("`@("`@("`@)V%L<F5A9'D@97AI<W1S+"!A;&EA<VEN
M9R!C:&%N;F5L("(G("X@)')E9RT^8VAA;FYE;$YA;64H)'!A<F%M<ULP72D-
M"B`@("`@("`@("`@("`@("`@("`@+B`G(B<I.PT*("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H(D-H86YN96P@7"(D<&%R86US6S!=7"(@:7,@86QR96%D>2!I;FET:6%L
M:7IE9"(I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1T
M:&ES+3YP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@
M("`@("`@("1E<G(@/2`D=&AI<RT^9&]!9&0H)&-O;6UA;F0L("1O<'1I;VYS
M+"!A<G)A>2@G:'1T<#HO+R<@+B`D<&%R86US6S!=("X@)R]C:&%N;F5L+GAM
M;"<I*3L-"B`@("`@("`@)'1H:7,M/G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<BDI('L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B1&ES8V]V97)Y(&]F(&-H86YN
M96P@7"(D<&%R86US6S!=7"(@9F%I;&5D("@B("X-"B`@("`@("`@("`@("`@
M("`D97)R+3YG971-97-S86=E*"D@+B`G*2<I.PT*("`@("`@("!]#0H@("`@
M("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@B1&ES8V]V97)Y(&]F(&-H86YN
M96P@7"(D<&%R86US6S!=7"(@<W5C8V5E9&5D(BP@)&-O;6UA;F0I.PT*("`@
M('T-"GT-"C\^#0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]014%2+T-O;6UA;F0O0V]M;6]N+G!H<```````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#(Q,#<S(#$P-3$U-#,S-S,Q(#`R,C4S-0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`T*+RHJ#0H@*B!014%27T-O;6UA;F1?0V]M;6]N(&)A<V4@8VQA<W,-"B`J
M#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H
M:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T
M:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D
M:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@
M86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@
M<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@
M=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`
M8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T
M:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R
M("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I
M9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N
M<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@0V]M;6]N+G!H<"QV
M(#$N,S(@,C`P-B\P,R\P,B`Q-CHS.3HQ-"!P86IO>64@17AP("0-"B`J($!L
M:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@
M*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#`N
M,0T*("HO#0H-"B\J*@T*("H@8F%S92!C;&%S<PT*("HO#0IR97%U:7)E7V]N
M8V4@)U!%05(N<&AP)SL-"@T*+RHJ#0H@*B!014%2(&-O;6UA;F1S(&)A<V4@
M8VQA<W,-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@
M("!014%2#0H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN
M970^#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN
M970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*
M("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E
M.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P
M86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S
M:6YC92!296QE87-E(#`N,0T*("HO#0IC;&%S<R!014%27T-O;6UA;F1?0V]M
M;6]N(&5X=&5N9',@4$5!4@T*>PT*("`@("\O('M[>R!P<F]P97)T:65S#0H-
M"B`@("`O*BH-"B`@("`@*B!014%27T-O;F9I9R!O8FIE8W0@=7-E9"!T;R!P
M87-S('5S97(@<WES=&5M(&%N9"!C;VYF:6=U<F%T:6]N#0H@("`@("H@;VX@
M=VAE;B!E>&5C=71I;F<@8V]M;6%N9',-"B`@("`@*@T*("`@("`J($!V87(@
M4$5!4E]#;VYF:6<-"B`@("`@*B\-"B`@("!V87(@)&-O;F9I9SL-"B`@("`O
M*BH-"B`@("`@*B!`=F%R(%!%05)?4F5G:7-T<GD-"B`@("`@*B!`86-C97-S
M('!R;W1E8W1E9`T*("`@("`J+PT*("`@('9A<B`D7W)E9VES=')Y.PT*#0H@
M("`@+RHJ#0H@("`@("H@57-E<B!);G1E<F9A8V4@;V)J96-T+"!F;W(@86QL
M(&EN=&5R86-T:6]N('=I=&@@=&AE('5S97(N#0H@("`@("H@0'9A<B!O8FIE
M8W0-"B`@("`@*B\-"B`@("!V87(@)'5I.PT*#0H@("`@=F%R("1?9&5P<U]R
M96Q?=')A;G,@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=L="<@/3X@)SPG+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)VQE)R`]/B`G/#TG+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V5Q)R`]/B`G/2<L#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G;F4G(#T^("<A/2<L#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G9W0G(#T^("<^)RP-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=G92<@/3X@)SX])RP-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=H87,G(#T^("<]/2<-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("D[#0H-"B`@("!V87(@)%]D97!S
M7W1Y<&5?=')A;G,@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G<&MG)R`]/B`G<&%C:V%G92<L#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V5X=&5N<VEO;B<@/3X@)V5X=&5N<VEO
M;B<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!H<"<@
M/3X@)U!(4"<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W!R;V<G(#T^("=E>'1E<FYA;"!P<F]G<F%M)RP-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G;&1L:6(G(#T^("=E>'1E<FYA;"!L:6)R
M87)Y(&9O<B!L:6YK:6YG)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G<G1L:6(G(#T^("=E>'1E<FYA;"!R=6YT:6UE(&QI8G)A<GDG
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=O<R<@/3X@
M)V]P97)A=&EN9R!S>7-T96TG+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=W96)S<G8G(#T^("=W96(@<V5R=F5R)RP-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G<V%P:2<@/3X@)U-!4$D@8F%C
M:V5N9"<-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I.PT*
M#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R#0H-"B`@("`O
M*BH-"B`@("`@*B!014%27T-O;6UA;F1?0V]M;6]N(&-O;G-T<G5C=&]R+@T*
M("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!014%27T-O;6UA;F1?0V]M;6]N*"8D=6DL("8D8V]N9FEG*0T*
M("`@('L-"B`@("`@("`@<&%R96YT.CI014%2*"D[#0H@("`@("`@("1T:&ES
M+3YC;VYF:6<@/2`F)&-O;F9I9SL-"B`@("`@("`@)'1H:7,M/G5I(#T@)B1U
M:3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!G971#;VUM
M86YD<R@I#0H-"B`@("`O*BH-"B`@("`@*B!2971U<FX@82!L:7-T(&]F(&%L
M;"!T:&4@8V]M;6%N9',@9&5F:6YE9"!B>2!T:&ES(&-L87-S+@T*("`@("`J
M($!R971U<FX@87)R87D@;&ES="!O9B!C;VUM86YD<PT*("`@("`J($!A8V-E
M<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T0V]M;6%N9',H
M*0T*("`@('L-"B`@("`@("`@)')E="`](&%R<F%Y*"D[#0H@("`@("`@(&9O
M<F5A8V@@*&%R<F%Y7VME>7,H)'1H:7,M/F-O;6UA;F1S*2!A<R`D8V]M;6%N
M9"D@>PT*("`@("`@("`@("`@)')E=%LD8V]M;6%N9%T@/2`D=&AI<RT^8V]M
M;6%N9'-;)&-O;6UA;F1=6R=S=6UM87)Y)UT[#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@
M>WM[(&=E=%-H;W)T8W5T<R@I#0H-"B`@("`O*BH-"B`@("`@*B!2971U<FX@
M82!L:7-T(&]F(&%L;"!T:&4@8V]M;6%N9"!S:&]R=&-U=',@9&5F:6YE9"!B
M>2!T:&ES(&-L87-S+@T*("`@("`J($!R971U<FX@87)R87D@<VAO<G1C=70@
M/3X@8V]M;6%N9`T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@9V5T4VAO<G1C=71S*"D-"B`@("![#0H@("`@("`@("1R
M970@/2!A<G)A>2@I.PT*("`@("`@("!F;W)E86-H("AA<G)A>5]K97ES*"1T
M:&ES+3YC;VUM86YD<RD@87,@)&-O;6UA;F0I('L-"B`@("`@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^8V]M;6%N9'-;)&-O;6UA;F1=6R=S:&]R=&-U="==
M*2D@>PT*("`@("`@("`@("`@("`@("1R971;)'1H:7,M/F-O;6UA;F1S6R1C
M;VUM86YD75LG<VAO<G1C=70G75T@/2`D8V]M;6%N9#L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-
M"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T3W!T:6]N<R@I#0H-"B`@("!F
M=6YC=&EO;B!G971/<'1I;VYS*"1C;VUM86YD*0T*("`@('L-"B`@("`@("`@
M)'-H;W)T8W5T<R`]("1T:&ES+3YG9713:&]R=&-U=',H*3L-"B`@("`@("`@
M:68@*&ES<V5T*"1S:&]R=&-U='-;)&-O;6UA;F1=*2D@>PT*("`@("`@("`@
M("`@)&-O;6UA;F0@/2`D<VAO<G1C=71S6R1C;VUM86YD73L-"B`@("`@("`@
M?0T*("`@("`@("!R971U<FX@0"1T:&ES+3YC;VUM86YD<ULD8V]M;6%N9%U;
M)V]P=&EO;G,G73L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@
M9V5T1V5T;W!T07)G<R@I#0H-"B`@("!F=6YC=&EO;B!G971'971O<'1!<F=S
M*"1C;VUM86YD+"`F)'-H;W)T7V%R9W,L("8D;&]N9U]A<F=S*0T*("`@('L-
M"B`@("`@("`@)'-H;W)T7V%R9W,@/2`B(CL-"B`@("`@("`@)&QO;F=?87)G
M<R`](&%R<F%Y*"D[#0H@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^8V]M;6%N
M9'-;)&-O;6UA;F1=*2!\?"!E;7!T>2@D=&AI<RT^8V]M;6%N9'-;)&-O;6UA
M;F1=6R=O<'1I;VYS)UTI*2![#0H@("`@("`@("`@("!R971U<FX[#0H@("`@
M("`@('T-"B`@("`@("`@<F5S970H)'1H:7,M/F-O;6UA;F1S6R1C;VUM86YD
M75LG;W!T:6]N<R==*3L-"B`@("`@("`@=VAI;&4@*&QI<W0H)&]P=&EO;BP@
M)&EN9F\I(#T@96%C:"@D=&AI<RT^8V]M;6%N9'-;)&-O;6UA;F1=6R=O<'1I
M;VYS)UTI*2![#0H@("`@("`@("`@("`D;&%R9R`]("1S87)G(#T@)R<[#0H@
M("`@("`@("`@("!I9B`H:7-S970H)&EN9F];)V%R9R==*2D@>PT*("`@("`@
M("`@("`@("`@(&EF("@D:6YF;ULG87)G)UU[,'T@/3T@)R@G*2![#0H@("`@
M("`@("`@("`@("`@("`@("1L87)G(#T@)ST])SL-"B`@("`@("`@("`@("`@
M("`@("`@)'-A<F<@/2`G.CHG.PT*("`@("`@("`@("`@("`@("`@("`D87)G
M(#T@<W5B<W1R*"1I;F9O6R=A<F<G72P@,2P@+3$I.PT*("`@("`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1L87)G(#T@)STG
M.PT*("`@("`@("`@("`@("`@("`@("`D<V%R9R`]("<Z)SL-"B`@("`@("`@
M("`@("`@("`@("`@)&%R9R`]("1I;F9O6R=A<F<G73L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S970H
M)&EN9F];)W-H;W)T;W!T)UTI*2![#0H@("`@("`@("`@("`@("`@)'-H;W)T
M7V%R9W,@+CT@)&EN9F];)W-H;W)T;W!T)UT@+B`D<V%R9SL-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("1L;VYG7V%R9W-;72`]("1O<'1I;VX@+B`D
M;&%R9SL-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O
M('M[>R!G971(96QP*"D-"B`@("`O*BH-"B`@("`J(%)E='5R;G,@=&AE(&AE
M;'`@;65S<V%G92!F;W(@=&AE(&=I=F5N(&-O;6UA;F0-"B`@("`J#0H@("`@
M*B!`<&%R86T@<W1R:6YG("1C;VUM86YD(%1H92!C;VUM86YD#0H@("`@*B!`
M<F5T=7)N(&UI>&5D($$@9F%I;"!S=')I;F<@:68@=&AE(&-O;6UA;F0@9&]E
M<R!N;W0@:&%V92!H96QP(&]R#0H@("`@*B`@("`@("`@("`@("`@(&$@='=O
M(&5L96UE;G1S(&%R<F%Y(&-O;G1A:6YI;F<@6S!=/3YH96QP('-T<FEN9RP-
M"B`@("`J("`@("`@("`@("`@("`@6S%=/3X@:&5L<"!S=')I;F<@9F]R('1H
M92!A8V-E<'1E9"!C;60@87)G<PT*("`@("HO#0H@("`@9G5N8W1I;VX@9V5T
M2&5L<"@D8V]M;6%N9"D-"B`@("![#0H@("`@("`@("1C;VYF:6<@/2`F4$5!
M4E]#;VYF:6<Z.G-I;F=L971O;B@I.PT*("`@("`@("`D:&5L<"`]($`D=&AI
M<RT^8V]M;6%N9'-;)&-O;6UA;F1=6R=D;V,G73L-"B`@("`@("`@:68@*&5M
M<'1Y*"1H96QP*2D@>PT*("`@("`@("`@("`@+R\@6%A8("AC;W@I($9A;&QB
M86-K('1O('-U;6UA<GD@:68@=&AE<F4@:7,@;F\@9&]C("AS:&]W(&)O=&@_
M*0T*("`@("`@("`@("`@:68@*"$D:&5L<"`]($`D=&AI<RT^8V]M;6%N9'-;
M)&-O;6UA;F1=6R=S=6UM87)Y)UTI('L-"B`@("`@("`@("`@("`@("!R971U
M<FX@(DYO(&AE;'`@9F]R(&-O;6UA;F0@7"(D8V]M;6%N9%PB(CL-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H<')E9U]M871C:%]A
M;&PH)R][8V]N9FEG7',K*%M>7'U=*RE]+V4G+"`D:&5L<"P@)&UA=&-H97,I
M*2![#0H@("`@("`@("`@("!F;W)E86-H*"1M871C:&5S6S!=(&%S("1K(#T^
M("1V*2![#0H@("`@("`@("`@("`@("`@)&AE;'`@/2!P<F5G7W)E<&QA8V4H
M(B\D=B\B+"`D8V]N9FEG+3YG970H)&UA=&-H97-;,5U;)&M=*2P@)&AE;'`I
M.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B!A
M<G)A>2@D:&5L<"P@)'1H:7,M/F=E=$AE;'!!<F=S*"1C;VUM86YD*2D[#0H@
M("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&=E=$AE;'!!<F=S*"D-
M"B`@("`O*BH-"B`@("`J(%)E='5R;G,@=&AE(&AE;'`@9F]R('1H92!A8V-E
M<'1E9"!A<F=U;65N=',@;V8@82!C;VUM86YD#0H@("`@*@T*("`@("H@0'!A
M<F%M("!S=')I;F<@)&-O;6UA;F0-"B`@("`J($!R971U<FX@<W1R:6YG(%1H
M92!H96QP('-T<FEN9PT*("`@("HO#0H@("`@9G5N8W1I;VX@9V5T2&5L<$%R
M9W,H)&-O;6UA;F0I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/F-O;6UA;F1S6R1C;VUM86YD75LG;W!T:6]N<R==*2`F)@T*("`@("`@("`@
M("`@8V]U;G0H)'1H:7,M/F-O;6UA;F1S6R1C;VUM86YD75LG;W!T:6]N<R==
M*2D-"B`@("`@("`@>PT*("`@("`@("`@("`@)&AE;'`@/2`B3W!T:6]N<SI<
M;B([#0H@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^8V]M;6%N9'-;)&-O
M;6UA;F1=6R=O<'1I;VYS)UT@87,@)&L@/3X@)'8I('L-"B`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)'9;)V%R9R==*2D@>PT*("`@("`@("`@("`@("`@
M("`@("!I9B`H)'9;)V%R9R==>S!](#T]("<H)RD@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)&%R9R`]('-U8G-T<B@D=ELG87)G)UTL(#$L("TQ*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1S87!P(#T@(B!;)&%R9UTB.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)&QA<'`@/2`B6STD87)G72([#0H@
M("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D<V%P<"`]("(@)'9;87)G72([#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D;&%P<"`]("(])'9;87)G72([#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("`@("`D<V%P<"`]("1L87!P(#T@(B([#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=ELG<VAO<G1O<'0G72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@)',@/2`D=ELG<VAO<G1O<'0G73L-
M"B`@("`@("`@("`@("`@("`@("`@0"1H96QP("X]("(@("TD<R1S87!P+"`M
M+21K)&QA<'!<;B([#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`@("`@0"1H96QP("X]("(@("TM)&LD;&%P<%QN(CL-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'`@/2`B("`@("`@
M("`B.PT*("`@("`@("`@("`@("`@("1D;V,@/2!R=')I;2AS=')?<F5P;&%C
M92@B7&XB+"`B7&XD<"(L("1V6R=D;V,G72DI.PT*("`@("`@("`@("`@("`@
M("1H96QP("X]("(@("`@("`@("1D;V-<;B([#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!R971U<FX@)&AE;'`[#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N(&YU;&P[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[
M(')U;B@I#0H-"B`@("!F=6YC=&EO;B!R=6XH)&-O;6UA;F0L("1O<'1I;VYS
M+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3YC
M;VUM86YD<ULD8V]M;6%N9%U;)V9U;F-T:6]N)UTI*2![#0H@("`@("`@("`@
M("`O+R!L;V]K(&9O<B!S:&]R=&-U=',-"B`@("`@("`@("`@(&9O<F5A8V@@
M*&%R<F%Y7VME>7,H)'1H:7,M/F-O;6UA;F1S*2!A<R`D8VUD*2![#0H@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YC;VUM86YD<ULD8VUD75LG
M<VAO<G1C=70G72D@)B8@)'1H:7,M/F-O;6UA;F1S6R1C;61=6R=S:&]R=&-U
M="==(#T]("1C;VUM86YD*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("AE
M;7!T>2@D=&AI<RT^8V]M;6%N9'-;)&-M9%U;)V9U;F-T:6]N)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H(G5N:VYO=VX@8V]M;6%N9"!@)&-O;6UA;F0G(BD[#0H@("`@("`@("`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M9G5N8R`]("1T:&ES+3YC;VUM86YD<ULD8VUD75LG9G5N8W1I;VXG73L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D8V]M
M;6%N9"`]("1C;60[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("1F=6YC(#T@)'1H:7,M/F-O;6UA;F1S6R1C;VUM
M86YD75LG9G5N8W1I;VXG73L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M)'1H:7,M/B1F=6YC*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD[#0H@
M("`@?0T*#0H@("`@+R\@?7U]#0I]#0H-"C\^#0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]#;VYF:6<N>&UL````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#8V,C$@,3`U,34T,S,W,S$@
M,#(R-3(U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#QC;VUM86YD<R!V97)S:6]N/2(Q+C`B/@T*(#QC;VYF:6<M<VAO=SX-
M"B`@/'-U;6UA<GD^4VAO=R!!;&P@4V5T=&EN9W,\+W-U;6UA<GD^#0H@(#QF
M=6YC=&EO;CYD;T-O;F9I9U-H;W<\+V9U;F-T:6]N/@T*("`\<VAO<G1C=70^
M8W-H/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,^#0H@("`\8VAA;FYE;#X-"B`@
M("`\<VAO<G1O<'0^8SPO<VAO<G1O<'0^#0H@("`@/&1O8SYS:&]W(&-O;F9I
M9W5R871I;VX@=F%R:6%B;&5S(&9O<B!A;F]T:&5R(&-H86YN96P\+V1O8SX-
M"B`@("`\87)G/D-(04X\+V%R9SX-"B`@(#PO8VAA;FYE;#X-"B`@/"]O<'1I
M;VYS/@T*("`\9&]C/EML87EE<ET-"D1I<W!L87ES(&%L;"!C;VYF:6=U<F%T
M:6]N('9A;'5E<RX@($%N(&]P=&EO;F%L(&%R9W5M96YT#0IM87D@8F4@=7-E
M9"!T;R!T96QL('=H:6-H(&-O;F9I9W5R871I;VX@;&%Y97(@=&\@9&ES<&QA
M>2X@(%9A;&ED#0IC;VYF:6=U<F%T:6]N(&QA>65R<R!A<F4@)G%U;W0[=7-E
M<B9Q=6]T.RP@)G%U;W0[<WES=&5M)G%U;W0[(&%N9"`F<75O=#MD969A=6QT
M)G%U;W0[+B!4;R!D:7-P;&%Y#0IC;VYF:6=U<F%T:6]N<R!F;W(@9&EF9F5R
M96YT(&-H86YN96QS+"!S970@=&AE(&1E9F%U;'1?8VAA;FYE;`T*8V]N9FEG
M=7)A=&EO;B!V87)I86)L92!A;F0@<G5N(&-O;F9I9RUS:&]W(&%G86EN+@T*
M/"]D;V,^#0H@/"]C;VYF:6<M<VAO=SX-"B`\8V]N9FEG+6=E=#X-"B`@/'-U
M;6UA<GD^4VAO=R!/;F4@4V5T=&EN9SPO<W5M;6%R>3X-"B`@/&9U;F-T:6]N
M/F1O0V]N9FEG1V5T/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T/F-G/"]S:&]R
M=&-U=#X-"B`@/&]P=&EO;G,^#0H@("`\8VAA;FYE;#X-"B`@("`\<VAO<G1O
M<'0^8SPO<VAO<G1O<'0^#0H@("`@/&1O8SYS:&]W(&-O;F9I9W5R871I;VX@
M=F%R:6%B;&5S(&9O<B!A;F]T:&5R(&-H86YN96P\+V1O8SX-"B`@("`\87)G
M/D-(04X\+V%R9SX-"B`@(#PO8VAA;FYE;#X-"B`@/"]O<'1I;VYS/@T*("`\
M9&]C/B9L=#MP87)A;65T97(F9W0[(%ML87EE<ET-"D1I<W!L87ES('1H92!V
M86QU92!O9B!O;F4@8V]N9FEG=7)A=&EO;B!P87)A;65T97(N("!4:&4-"F9I
M<G-T(&%R9W5M96YT(&ES('1H92!N86UE(&]F('1H92!P87)A;65T97(L(&%N
M(&]P=&EO;F%L('-E8V]N9"!A<F=U;65N=`T*;6%Y(&)E('5S960@=&\@=&5L
M;"!W:&EC:"!C;VYF:6=U<F%T:6]N(&QA>65R('1O(&QO;VL@:6XN("!686QI
M9"!C;VYF:6=U<F%T:6]N#0IL87EE<G,@87)E("9Q=6]T.W5S97(F<75O=#LL
M("9Q=6]T.W-Y<W1E;29Q=6]T.R!A;F0@)G%U;W0[9&5F875L="9Q=6]T.RX@
M($EF(&YO(&QA>65R(&ES('-P96-I9FEE9"P@82!V86QU90T*=VEL;"!B92!P
M:6-K960@9G)O;2!T:&4@9FER<W0@;&%Y97(@=&AA="!D969I;F5S('1H92!P
M87)A;65T97(L(&EN('1H92!O<F1E<@T*:G5S="!S<&5C:69I960N("!4:&4@
M8V]N9FEG=7)A=&EO;B!V86QU92!W:6QL(&)E(')E=')I979E9"!F;W(@=&AE
M(&-H86YN96P-"G-P96-I9FEE9"!B>2!T:&4@9&5F875L=%]C:&%N;F5L(&-O
M;F9I9W5R871I;VX@=F%R:6%B;&4N#0H\+V1O8SX-"B`\+V-O;F9I9RUG970^
M#0H@/&-O;F9I9RUS970^#0H@(#QS=6UM87)Y/D-H86YG92!3971T:6YG/"]S
M=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]#;VYF:6=3970\+V9U;F-T:6]N/@T*
M("`\<VAO<G1C=70^8W,\+W-H;W)T8W5T/@T*("`\;W!T:6]N<SX-"B`@(#QC
M:&%N;F5L/@T*("`@(#QS:&]R=&]P=#YC/"]S:&]R=&]P=#X-"B`@("`\9&]C
M/G-H;W<@8V]N9FEG=7)A=&EO;B!V87)I86)L97,@9F]R(&%N;W1H97(@8VAA
M;FYE;#PO9&]C/@T*("`@(#QA<F<^0TA!3CPO87)G/@T*("`@/"]C:&%N;F5L
M/@T*("`\+V]P=&EO;G,^#0H@(#QD;V,^)FQT.W!A<F%M971E<B9G=#L@)FQT
M.W9A;'5E)F=T.R!;;&%Y97)=#0I3971S('1H92!V86QU92!O9B!O;F4@8V]N
M9FEG=7)A=&EO;B!P87)A;65T97(N("!4:&4@9FER<W0@87)G=6UE;G0@:7,-
M"G1H92!N86UE(&]F('1H92!P87)A;65T97(L('1H92!S96-O;F0@87)G=6UE
M;G0@:7,@=&AE(&YE=R!V86QU92X@(%-O;64-"G!A<F%M971E<G,@87)E('-U
M8FIE8W0@=&\@=F%L:61A=&EO;BP@86YD('1H92!C;VUM86YD('=I;&P@9F%I
M;"!W:71H#0IA;B!E<G)O<B!M97-S86=E(&EF('1H92!N97<@=F%L=64@9&]E
M<R!N;W0@;6%K92!S96YS92X@($%N(&]P=&EO;F%L#0IT:&ER9"!A<F=U;65N
M="!M87D@8F4@=7-E9"!T;R!S<&5C:69Y(&EN('=H:6-H(&QA>65R('1O('-E
M="!T:&4-"F-O;F9I9W5R871I;VX@<&%R86UE=&5R+B`@5&AE(&1E9F%U;'0@
M;&%Y97(@:7,@)G%U;W0[=7-E<B9Q=6]T.RX@(%1H90T*8V]N9FEG=7)A=&EO
M;B!V86QU92!W:6QL(&)E('-E="!F;W(@=&AE(&-U<G)E;G0@8VAA;FYE;"P@
M=VAI8V@-"FES(&-O;G1R;VQL960@8GD@=&AE(&1E9F%U;'1?8VAA;FYE;"!C
M;VYF:6=U<F%T:6]N('9A<FEA8FQE+@T*/"]D;V,^#0H@/"]C;VYF:6<M<V5T
M/@T*(#QC;VYF:6<M:&5L<#X-"B`@/'-U;6UA<GD^4VAO=R!);F9O<FUA=&EO
M;B!!8F]U="!3971T:6YG/"]S=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]#;VYF
M:6=(96QP/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T/F-H/"]S:&]R=&-U=#X-
M"B`@/&]P=&EO;G,@+SX-"B`@/&1O8SY;<&%R86UE=&5R70T*1&ES<&QA>7,@
M:&5L<"!F;W(@82!C;VYF:6=U<F%T:6]N('!A<F%M971E<BX@(%=I=&AO=70@
M87)G=6UE;G1S(&ET#0ID:7-P;&%Y<R!H96QP(&9O<B!A;&P@8V]N9FEG=7)A
M=&EO;B!P87)A;65T97)S+@T*/"]D;V,^#0H@/"]C;VYF:6<M:&5L<#X-"B`\
M8V]N9FEG+6-R96%T93X-"B`@/'-U;6UA<GD^0W)E871E(&$@1&5F875L="!C
M;VYF:6=U<F%T:6]N(&9I;&4\+W-U;6UA<GD^#0H@(#QF=6YC=&EO;CYD;T-O
M;F9I9T-R96%T93PO9G5N8W1I;VX^#0H@(#QS:&]R=&-U=#YC;V,\+W-H;W)T
M8W5T/@T*("`\;W!T:6]N<SX-"B`@(#QW:6YD;W=S/@T*("`@(#QS:&]R=&]P
M=#YW/"]S:&]R=&]P=#X-"B`@("`\9&]C/F-R96%T92!A(&-O;F9I9R!F:6QE
M(&9O<B!A('=I;F1O=W,@:6YS=&%L;#PO9&]C/@T*("`@/"]W:6YD;W=S/@T*
M("`\+V]P=&EO;G,^#0H@(#QD;V,^)FQT.W)O;W0@<&%T:"9G=#L@)FQT.V9I
M;&5N86UE)F=T.PT*0W)E871E(&$@9&5F875L="!C;VYF:6=U<F%T:6]N(&9I
M;&4@=VET:"!A;&P@9&ER96-T;W)Y(&-O;F9I9W5R871I;VX-"G9A<FEA8FQE
M<R!S970@=&\@<W5B9&ER96-T;W)I97,@;V8@)FQT.W)O;W0@<&%T:"9G=#LL
M(&%N9"!S879E(&ET(&%S("9L=#MF:6QE;F%M929G=#LN#0I4:&ES(&ES('5S
M969U;"!E<W!E8VEA;&QY(&9O<B!C<F5A=&EN9R!A(&-O;F9I9W5R871I;VX@
M9FEL92!F;W(@82!R96UO=&4-"E!%05(@:6YS=&%L;&%T:6]N("AU<VEN9R!T
M:&4@+2UR96UO=&5C;VYF:6<@;W!T:6]N(&]F(&EN<W1A;&PL('5P9W)A9&4L
M#0IA;F0@=6YI;G-T86QL*2X-"CPO9&]C/@T*(#PO8V]N9FEG+6-R96%T93X-
M"CPO8V]M;6%N9',^````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O0V]N9FEG+G!H<```````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#,V,S(W(#$P-3$U-#,S-S,Q
M(#`R,C4R,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`T*+RHJ#0H@*B!014%27T-O;6UA;F1?0V]N9FEG("AC;VYF
M:6<M<VAO=RP@8V]N9FEG+6=E="P@8V]N9FEG+7-E="P@8V]N9FEG+6AE;'`L
M(&-O;F9I9RUC<F5A=&4@8V]M;6%N9',I#0H@*@T*("H@4$A0('9E<G-I;VYS
M(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES
M('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@
M*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@
M8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O
M(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A
M(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A
M(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*
M("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK
M96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@
M/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H
M92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I
M;VX@("`@0U93.B`D260Z($-O;F9I9RYP:'`L=B`Q+C4Q(#(P,#8O,#,O,#(@
M,3,Z,S(Z,S@@<&%J;WEE($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL
M92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J+PT*#0HO*BH-"B`J
M(&)A<V4@8VQA<W,-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2+T-O;6UA;F0O
M0V]M;6]N+G!H<"<[#0H-"B\J*@T*("H@4$5!4B!C;VUM86YD<R!F;W(@;6%N
M86=I;F<@8V]N9FEG=7)A=&EO;B!D871A+@T*("H-"B`J($!C871E9V]R>2`@
M('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@(%-T
M:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@($=R96<@
M0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M
M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J
M($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H
M='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@
M("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,"XQ#0H@*B\-"F-L
M87-S(%!%05)?0V]M;6%N9%]#;VYF:6<@97AT96YD<R!014%27T-O;6UA;F1?
M0V]M;6]N#0I[#0H@("`@+R\@>WM[('!R;W!E<G1I97,-"@T*("`@('9A<B`D
M8V]M;6%N9',@/2!A<G)A>2@-"B`@("`@("`@)V-O;F9I9RUS:&]W)R`]/B!A
M<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G4VAO=R!!;&P@4V5T
M=&EN9W,G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]#;VYF:6=3
M:&]W)RP-"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)V-S:"<L#0H@("`@
M("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@
M)V-H86YN96PG(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO
M<G1O<'0G(#T^("=C)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@
M)W-H;W<@8V]N9FEG=7)A=&EO;B!V87)I86)L97,@9F]R(&%N;W1H97(@8VAA
M;FYE;"<L#0H@("`@("`@("`@("`@("`@("`@("=A<F<G(#T^("=#2$%.)RP-
M"B`@("`@("`@("`@("`@("`@("`@*2P-"BDL#0H@("`@("`@("`@("`G9&]C
M)R`]/B`G6VQA>65R70T*1&ES<&QA>7,@86QL(&-O;F9I9W5R871I;VX@=F%L
M=65S+B`@06X@;W!T:6]N86P@87)G=6UE;G0-"FUA>2!B92!U<V5D('1O('1E
M;&P@=VAI8V@@8V]N9FEG=7)A=&EO;B!L87EE<B!T;R!D:7-P;&%Y+B`@5F%L
M:60-"F-O;F9I9W5R871I;VX@;&%Y97)S(&%R92`B=7-E<B(L(")S>7-T96TB
M(&%N9"`B9&5F875L="(N(%1O(&1I<W!L87D-"F-O;F9I9W5R871I;VYS(&9O
M<B!D:69F97)E;G0@8VAA;FYE;',L('-E="!T:&4@9&5F875L=%]C:&%N;F5L
M#0IC;VYF:6=U<F%T:6]N('9A<FEA8FQE(&%N9"!R=6X@8V]N9FEG+7-H;W<@
M86=A:6XN#0HG+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@)V-O;F9I9RUG
M970G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=3:&]W
M($]N92!3971T:6YG)RP-"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O
M0V]N9FEG1V5T)RP-"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)V-G)RP-
M"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@-"B`@("`@("`@("`@
M("`@("`G8VAA;FYE;"<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@
M("=S:&]R=&]P="<@/3X@)V,G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C
M)R`]/B`G<VAO=R!C;VYF:6=U<F%T:6]N('9A<FEA8FQE<R!F;W(@86YO=&AE
M<B!C:&%N;F5L)RP-"B`@("`@("`@("`@("`@("`@("`@)V%R9R<@/3X@)T-(
M04XG+`T*("`@("`@("`@("`@("`@("`@("`I+`T**2P-"B`@("`@("`@("`@
M("=D;V,G(#T^("<\<&%R86UE=&5R/B!;;&%Y97)=#0I$:7-P;&%Y<R!T:&4@
M=F%L=64@;V8@;VYE(&-O;F9I9W5R871I;VX@<&%R86UE=&5R+B`@5&AE#0IF
M:7)S="!A<F=U;65N="!I<R!T:&4@;F%M92!O9B!T:&4@<&%R86UE=&5R+"!A
M;B!O<'1I;VYA;"!S96-O;F0@87)G=6UE;G0-"FUA>2!B92!U<V5D('1O('1E
M;&P@=VAI8V@@8V]N9FEG=7)A=&EO;B!L87EE<B!T;R!L;V]K(&EN+B`@5F%L
M:60@8V]N9FEG=7)A=&EO;@T*;&%Y97)S(&%R92`B=7-E<B(L(")S>7-T96TB
M(&%N9"`B9&5F875L="(N("!)9B!N;R!L87EE<B!I<R!S<&5C:69I960L(&$@
M=F%L=64-"G=I;&P@8F4@<&EC:V5D(&9R;VT@=&AE(&9I<G-T(&QA>65R('1H
M870@9&5F:6YE<R!T:&4@<&%R86UE=&5R+"!I;B!T:&4@;W)D97(-"FIU<W0@
M<W!E8VEF:65D+B`@5&AE(&-O;F9I9W5R871I;VX@=F%L=64@=VEL;"!B92!R
M971R:65V960@9F]R('1H92!C:&%N;F5L#0IS<&5C:69I960@8GD@=&AE(&1E
M9F%U;'1?8VAA;FYE;"!C;VYF:6=U<F%T:6]N('9A<FEA8FQE+@T*)RP-"B`@
M("`@("`@("`@("DL#0H@("`@("`@("=C;VYF:6<M<V5T)R`]/B!A<G)A>2@-
M"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G0VAA;F=E(%-E='1I;F<G+`T*
M("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]#;VYF:6=3970G+`T*("`@
M("`@("`@("`@)W-H;W)T8W5T)R`]/B`G8W,G+`T*("`@("`@("`@("`@)V]P
M=&EO;G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=C:&%N;F5L)R`]
M/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G
M8R<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=S:&]W(&-O;F9I
M9W5R871I;VX@=F%R:6%B;&5S(&9O<B!A;F]T:&5R(&-H86YN96PG+`T*("`@
M("`@("`@("`@("`@("`@("`G87)G)R`]/B`G0TA!3B<L#0H@("`@("`@("`@
M("`@("`@("`@("DL#0HI+`T*("`@("`@("`@("`@)V1O8R<@/3X@)SQP87)A
M;65T97(^(#QV86QU93X@6VQA>65R70T*4V5T<R!T:&4@=F%L=64@;V8@;VYE
M(&-O;F9I9W5R871I;VX@<&%R86UE=&5R+B`@5&AE(&9I<G-T(&%R9W5M96YT
M(&ES#0IT:&4@;F%M92!O9B!T:&4@<&%R86UE=&5R+"!T:&4@<V5C;VYD(&%R
M9W5M96YT(&ES('1H92!N97<@=F%L=64N("!3;VUE#0IP87)A;65T97)S(&%R
M92!S=6)J96-T('1O('9A;&ED871I;VXL(&%N9"!T:&4@8V]M;6%N9"!W:6QL
M(&9A:6P@=VET:`T*86X@97)R;W(@;65S<V%G92!I9B!T:&4@;F5W('9A;'5E
M(&1O97,@;F]T(&UA:V4@<V5N<V4N("!!;B!O<'1I;VYA;`T*=&AI<F0@87)G
M=6UE;G0@;6%Y(&)E('5S960@=&\@<W!E8VEF>2!I;B!W:&EC:"!L87EE<B!T
M;R!S970@=&AE#0IC;VYF:6=U<F%T:6]N('!A<F%M971E<BX@(%1H92!D969A
M=6QT(&QA>65R(&ES(")U<V5R(BX@(%1H90T*8V]N9FEG=7)A=&EO;B!V86QU
M92!W:6QL(&)E('-E="!F;W(@=&AE(&-U<G)E;G0@8VAA;FYE;"P@=VAI8V@-
M"FES(&-O;G1R;VQL960@8GD@=&AE(&1E9F%U;'1?8VAA;FYE;"!C;VYF:6=U
M<F%T:6]N('9A<FEA8FQE+@T*)RP-"B`@("`@("`@("`@("DL#0H@("`@("`@
M("=C;VYF:6<M:&5L<"<@/3X@87)R87DH#0H@("`@("`@("`@("`G<W5M;6%R
M>2<@/3X@)U-H;W<@26YF;W)M871I;VX@06)O=70@4V5T=&EN9R<L#0H@("`@
M("`@("`@("`G9G5N8W1I;VXG(#T^("=D;T-O;F9I9TAE;'`G+`T*("`@("`@
M("`@("`@)W-H;W)T8W5T)R`]/B`G8V@G+`T*("`@("`@("`@("`@)V]P=&EO
M;G,G(#T^(&%R<F%Y*"DL#0H@("`@("`@("`@("`G9&]C)R`]/B`G6W!A<F%M
M971E<ET-"D1I<W!L87ES(&AE;'`@9F]R(&$@8V]N9FEG=7)A=&EO;B!P87)A
M;65T97(N("!7:71H;W5T(&%R9W5M96YT<R!I=`T*9&ES<&QA>7,@:&5L<"!F
M;W(@86QL(&-O;F9I9W5R871I;VX@<&%R86UE=&5R<RX-"B<L#0H@("`@("`@
M("`@("DL#0H@("`@("`@("=C;VYF:6<M8W)E871E)R`]/B!A<G)A>2@-"B`@
M("`@("`@("`@("=S=6UM87)Y)R`]/B`G0W)E871E(&$@1&5F875L="!C;VYF
M:6=U<F%T:6]N(&9I;&4G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G
M9&]#;VYF:6=#<F5A=&4G+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G
M8V]C)RP-"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@-"B`@("`@
M("`@("`@("`@("`G=VEN9&]W<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@
M("`@("`@("=S:&]R=&]P="<@/3X@)W<G+`T*("`@("`@("`@("`@("`@("`@
M("`G9&]C)R`]/B`G8W)E871E(&$@8V]N9FEG(&9I;&4@9F]R(&$@=VEN9&]W
M<R!I;G-T86QL)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@
M("`@("DL#0H@("`@("`@("`@("`G9&]C)R`]/B`G/')O;W0@<&%T:#X@/&9I
M;&5N86UE/@T*0W)E871E(&$@9&5F875L="!C;VYF:6=U<F%T:6]N(&9I;&4@
M=VET:"!A;&P@9&ER96-T;W)Y(&-O;F9I9W5R871I;VX-"G9A<FEA8FQE<R!S
M970@=&\@<W5B9&ER96-T;W)I97,@;V8@/')O;W0@<&%T:#XL(&%N9"!S879E
M(&ET(&%S(#QF:6QE;F%M93XN#0I4:&ES(&ES('5S969U;"!E<W!E8VEA;&QY
M(&9O<B!C<F5A=&EN9R!A(&-O;F9I9W5R871I;VX@9FEL92!F;W(@82!R96UO
M=&4-"E!%05(@:6YS=&%L;&%T:6]N("AU<VEN9R!T:&4@+2UR96UO=&5C;VYF
M:6<@;W!T:6]N(&]F(&EN<W1A;&PL('5P9W)A9&4L#0IA;F0@=6YI;G-T86QL
M*2X-"B<L#0H@("`@("`@("`@("`I+`T*("`@("`@("`I.PT*#0H@("`@+R\@
M?7U]#0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R#0H-"B`@("`O*BH-"B`@("`@
M*B!014%27T-O;6UA;F1?0V]N9FEG(&-O;G-T<G5C=&]R+@T*("`@("`J#0H@
M("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!0
M14%27T-O;6UA;F1?0V]N9FEG*"8D=6DL("8D8V]N9FEG*0T*("`@('L-"B`@
M("`@("`@<&%R96YT.CI014%27T-O;6UA;F1?0V]M;6]N*"1U:2P@)&-O;F9I
M9RD[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@9&]#;VYF
M:6=3:&]W*"D-"@T*("`@(&9U;F-T:6]N(&1O0V]N9FEG4VAO=R@D8V]M;6%N
M9"P@)&]P=&EO;G,L("1P87)A;7,I#0H@("`@>PT*("`@("`@("!I9B`H:7-?
M87)R87DH)'!A<F%M<RDI('L-"B`@("`@("`@("`@("1L87EE<B`](&ES<V5T
M*"1P87)A;7-;,%TI(#\@)'!A<F%M<ULP72`Z($Y53$P[#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`D;&%Y97(@/2!.54Q,.PT*("`@("`@("!]
M#0H-"B`@("`@("`@+R\@)'!A<F%M<ULP72`M/B!T:&4@;&%Y97(-"B`@("`@
M("`@:68@*"1E<G)O<B`]("1T:&ES+3Y?8VAE8VM,87EE<B@D;&%Y97(I*2![
M#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F-O;F9I
M9RUS:&]W.B1E<G)O<B(I.PT*("`@("`@("!]#0H@("`@("`@("1K97ES(#T@
M)'1H:7,M/F-O;F9I9RT^9V5T2V5Y<R@I.PT*("`@("`@("!S;W)T*"1K97ES
M*3L-"B`@("`@("`@)&-H86YN96P@/2!I<W-E="@D;W!T:6]N<ULG8VAA;FYE
M;"==*2`_("1O<'1I;VYS6R=C:&%N;F5L)UT@.@T*("`@("`@("`@("`@)'1H
M:7,M/F-O;F9I9RT^9V5T*"=D969A=6QT7V-H86YN96PG*3L-"B`@("`@("`@
M)')E9R`]("8D=&AI<RT^8V]N9FEG+3YG971296=I<W1R>2@I.PT*("`@("`@
M("!I9B`H(21R96<M/F-H86YN96Q%>&ES=',H)&-H86YN96PI*2![#0H@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-H86YN96P@(B<@
M+B`D8VAA;FYE;"`N("<B(&1O97,@;F]T(&5X:7-T)RD[#0H@("`@("`@('T-
M"B`@("`@("`@)&1A=&$@/2!A<G)A>2@G8V%P=&EO;B<@/3X@)T-O;F9I9W5R
M871I;VX@*&-H86YN96P@)R`N("1C:&%N;F5L("X@)RDZ)RD[#0H@("`@("`@
M(&9O<F5A8V@@*"1K97ES(&%S("1K97DI('L-"B`@("`@("`@("`@("1T>7!E
M(#T@)'1H:7,M/F-O;F9I9RT^9V5T5'EP92@D:V5Y*3L-"B`@("`@("`@("`@
M("1V86QU92`]("1T:&ES+3YC;VYF:6<M/F=E="@D:V5Y+"`D;&%Y97(L("1C
M:&%N;F5L*3L-"B`@("`@("`@("`@(&EF("@D='EP92`]/2`G<&%S<W=O<F0G
M("8F("1V86QU92D@>PT*("`@("`@("`@("`@("`@("1V86QU92`]("<J*BHJ
M*BHJ*B<[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)'9A;'5E
M(#T]/2!F86QS92D@>PT*("`@("`@("`@("`@("`@("1V86QU92`]("=F86QS
M92<[#0H@("`@("`@("`@("!](&5L<V5I9B`H)'9A;'5E(#T]/2!T<G5E*2![
M#0H@("`@("`@("`@("`@("`@)'9A;'5E(#T@)W1R=64G.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@)&1A=&%;)V1A=&$G75LD=&AI<RT^8V]N9FEG
M+3YG971'<F]U<"@D:V5Y*5U;72`](&%R<F%Y*"1T:&ES+3YC;VYF:6<M/F=E
M=%!R;VUP="@D:V5Y*2`L("1K97DL("1V86QU92D[#0H@("`@("`@('T-"B`@
M("`@("`@9F]R96%C:"`H)'1H:7,M/F-O;F9I9RT^9V5T3&%Y97)S*"D@87,@
M)&QA>65R*2![#0H@("`@("`@("`@("`D9&%T85LG9&%T82==6R=#;VYF:6<@
M1FEL97,G75M=(#T@87)R87DH=6-F:7)S="@D;&%Y97(I("X@)R!#;VYF:6=U
M<F%T:6]N($9I;&4G+"`G1FEL96YA;64G("P@)'1H:7,M/F-O;F9I9RT^9V5T
M0V]N9D9I;&4H)&QA>65R*2D[#0H@("`@("`@('T-"@T*("`@("`@("`D=&AI
M<RT^=6DM/F]U='!U=$1A=&$H)&1A=&$L("1C;VUM86YD*3L-"B`@("`@("`@
M<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[
M(&1O0V]N9FEG1V5T*"D-"@T*("`@(&9U;F-T:6]N(&1O0V]N9FEG1V5T*"1C
M;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@(&EF
M("@A:7-?87)R87DH)'!A<F%M<RDI('L-"B`@("`@("`@("`@("1A<F=S7V-N
M="`](#`[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D87)G<U]C
M;G0@(#T@8V]U;G0H)'!A<F%M<RD[#0H@("`@("`@('T-"@T*("`@("`@("!S
M=VET8V@@*"1A<F=S7V-N="D@>PT*("`@("`@("`@("`@8V%S92`Q.@T*("`@
M("`@("`@("`@("`@("1C;VYF:6=?:V5Y(#T@)'!A<F%M<ULP73L-"B`@("`@
M("`@("`@("`@("`D;&%Y97(@/2!.54Q,.PT*("`@("`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@8V%S92`R.@T*("`@("`@("`@("`@("`@("1C
M;VYF:6=?:V5Y(#T@)'!A<F%M<ULP73L-"B`@("`@("`@("`@("`@("`D;&%Y
M97(@/2`D<&%R86US6S%=.PT*("`@("`@("`@("`@("`@(&EF("@D97)R;W(@
M/2`D=&AI<RT^7V-H96-K3&%Y97(H)&QA>65R*2D@>PT*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F-O;F9I9RUG970Z
M)&5R<F]R(BD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(&)R96%K.PT*("`@("`@("`@("`@8V%S92`P.@T*("`@("`@("`@("`@9&5F
M875L=#H-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H(F-O;F9I9RUG970@97AP96-T<R`Q(&]R(#(@<&%R86UE=&5R<R(I.PT*
M("`@("`@("!]#0H-"B`@("`@("`@)&-H86YN96P@/2!I<W-E="@D;W!T:6]N
M<ULG8VAA;FYE;"==*2`_("1O<'1I;VYS6R=C:&%N;F5L)UT@.B`D=&AI<RT^
M8V]N9FEG+3YG970H)V1E9F%U;'1?8VAA;FYE;"<I.PT*("`@("`@("`D<F5G
M(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H-"B`@("`@("`@
M:68@*"$D<F5G+3YC:&%N;F5L17AI<W1S*"1C:&%N;F5L*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=#:&%N;F5L("(G("X@
M)&-H86YN96P@+B`G(B!D;V5S(&YO="!E>&ES="<I.PT*("`@("`@("!]#0H-
M"B`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"1T:&ES+3YC;VYF:6<M
M/F=E="@D8V]N9FEG7VME>2P@)&QA>65R+"`D8VAA;FYE;"DL("1C;VUM86YD
M*3L-"@T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O+R!]
M?7T-"B`@("`O+R![>WL@9&]#;VYF:6=3970H*0T*#0H@("`@9G5N8W1I;VX@
M9&]#;VYF:6=3970H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@
M('L-"B`@("`@("`@+R\@)'!A<F%M6S!=("T^(&$@<&%R86UE=&5R('1O('-E
M=`T*("`@("`@("`O+R`D<&%R86U;,5T@+3X@=&AE('9A;'5E(&9O<B!T:&4@
M<&%R86UE=&5R#0H@("`@("`@("\O("1P87)A;5LR72`M/B!T:&4@;&%Y97(-
M"B`@("`@("`@)&9A:6QM<V<@/2`G)SL-"B`@("`@("`@:68@*'-I>F5O9B@D
M<&%R86US*2`\(#(@?'P@<VEZ96]F*"1P87)A;7,I(#X@,RD@>PT*("`@("`@
M("`@("`@)&9A:6QM<V<@+CT@(F-O;F9I9RUS970@97AP96-T<R`R(&]R(#,@
M<&%R86UE=&5R<R([#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@D9F%I;&US9RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1E<G)O
M<B`]("1T:&ES+3Y?8VAE8VM,87EE<BA`)'!A<F%M<ULR72DI('L-"B`@("`@
M("`@("`@("1F86EL;7-G("X]("1E<G)O<CL-"B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*")C;VYF:6<M<V5T.B1F86EL;7-G(BD[#0H@
M("`@("`@('T-"B`@("`@("`@)&-H86YN96P@/2!I<W-E="@D;W!T:6]N<ULG
M8VAA;FYE;"==*2`_("1O<'1I;VYS6R=C:&%N;F5L)UT@.@T*("`@("`@("`@
M("`@)'1H:7,M/F-O;F9I9RT^9V5T*"=D969A=6QT7V-H86YN96PG*3L-"B`@
M("`@("`@)')E9R`]("8D=&AI<RT^8V]N9FEG+3YG971296=I<W1R>2@I.PT*
M("`@("`@("!I9B`H(21R96<M/F-H86YN96Q%>&ES=',H)&-H86YN96PI*2![
M#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-H86YN
M96P@(B<@+B`D8VAA;FYE;"`N("<B(&1O97,@;F]T(&5X:7-T)RD[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"1P87)A;7-;,%T@/3T@)V1E9F%U;'1?8VAA
M;FYE;"<I('L-"B`@("`@("`@("`@(&EF("@A)')E9RT^8VAA;FYE;$5X:7-T
M<R@D<&%R86US6S%=*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@G0VAA;FYE;"`B)R`N("1P87)A;7-;,5T@+B`G(B!D
M;V5S(&YO="!E>&ES="<I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@(&EF("AC;W5N="@D<&%R86US*2`]/2`R*2![#0H@("`@("`@("`@
M("!A<G)A>5]P=7-H*"1P87)A;7,L("=U<V5R)RD[#0H@("`@("`@("`@("`D
M;&%Y97(@/2`G=7-E<B<[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`D;&%Y97(@/2`D<&%R86US6S)=.PT*("`@("`@("!]#0H@("`@("`@(&%R
M<F%Y7W!U<V@H)'!A<F%M<RP@)&-H86YN96PI.PT*("`@("`@("!I9B`H(6-A
M;&Q?=7-E<E]F=6YC7V%R<F%Y*&%R<F%Y*"8D=&AI<RT^8V]N9FEG+"`G<V5T
M)RDL("1P87)A;7,I*0T*("`@("`@("![#0H@("`@("`@("`@("!A<G)A>5]P
M;W`H)'!A<F%M<RD[#0H@("`@("`@("`@("`D9F%I;&US9R`](")C;VYF:6<M
M<V5T("@B("X@:6UP;&]D92@B+"`B+"`D<&%R86US*2`N("(I(&9A:6QE9"P@
M8VAA;FYE;"`D8VAA;FYE;"([#0H@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`D=&AI<RT^8V]N9FEG+3YS=&]R92@D;&%Y97(I.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("@D9F%I;&US9RD@>PT*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*"1F86EL;7-G*3L-"B`@("`@("`@?0T*("`@
M("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)V-O;F9I9RUS970@<W5C8V5E
M9&5D)RP@)&-O;6UA;F0I.PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]
M#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9&]#;VYF:6=(96QP*"D-"@T*
M("`@(&9U;F-T:6]N(&1O0V]N9FEG2&5L<"@D8V]M;6%N9"P@)&]P=&EO;G,L
M("1P87)A;7,I#0H@("`@>PT*("`@("`@("!I9B`H96UP='DH)'!A<F%M<RDI
M('L-"B`@("`@("`@("`@("1P87)A;7,@/2`D=&AI<RT^8V]N9FEG+3YG971+
M97ES*"D[#0H@("`@("`@('T-"B`@("`@("`@)&1A=&%;)V-A<'1I;VXG72`@
M/2`B0V]N9FEG(&AE;'`B("X@*"AC;W5N="@D<&%R86US*2`]/2`Q*2`_("(@
M9F]R("1P87)A;7-;,%TB(#H@)R<I.PT*("`@("`@("`D9&%T85LG:&5A9&QI
M;F4G72`](&%R<F%Y*"=.86UE)RP@)U1Y<&4G+"`G1&5S8W)I<'1I;VXG*3L-
M"B`@("`@("`@)&1A=&%;)V)O<F1E<B==("`@/2!T<G5E.PT*("`@("`@("!F
M;W)E86-H("@D<&%R86US(&%S("1N86UE*2![#0H@("`@("`@("`@("`D='EP
M92`]("1T:&ES+3YC;VYF:6<M/F=E=%1Y<&4H)&YA;64I.PT*("`@("`@("`@
M("`@)&1O8W,@/2`D=&AI<RT^8V]N9FEG+3YG971$;V-S*"1N86UE*3L-"B`@
M("`@("`@("`@(&EF("@D='EP92`]/2`G<V5T)RD@>PT*("`@("`@("`@("`@
M("`@("1D;V-S(#T@<G1R:6TH)&1O8W,I("X@(EQN5F%L:60@<V5T.B`B("X-
M"B`@("`@("`@("`@("`@("`@("`@:6UP;&]D92@G("<L("1T:&ES+3YC;VYF
M:6<M/F=E=%-E=%9A;'5E<R@D;F%M92DI.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@)&1A=&%;)V1A=&$G75M=(#T@87)R87DH)&YA;64L("1T>7!E
M+"`D9&]C<RD[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/G5I+3YO=71P
M=71$871A*"1D871A+"`D8V]M;6%N9"D[#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0H@("`@+R\@>WM[(&1O0V]N9FEG0W)E871E*"D-"@T*("`@(&9U;F-T:6]N
M(&1O0V]N9FEG0W)E871E*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-
M"B`@("![#0H@("`@("`@(&EF("AC;W5N="@D<&%R86US*2`A/2`R*2![#0H@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G8V]N9FEG+6-R
M96%T93H@;75S="!H879E(#(@<&%R86UE=&5R<RP@<F]O="!P871H(&%N9"`G
M("X-"B`@("`@("`@("`@("`@("`G9FEL96YA;64@=&\@<V%V92!A<R<I.PT*
M("`@("`@("!]#0H@("`@("`@("1R;V]T(#T@)'!A<F%M<ULP73L-"B`@("`@
M("`@+R\@0VQE86X@=7`@=&AE($1)4D5#5$]265]315!!4D%43U(@;65S<PT*
M("`@("`@("`D9',R(#T@1$E214-43U)97U-%4$%2051/4B`N($1)4D5#5$]2
M65]315!!4D%43U([#0H@("`@("`@("1R;V]T(#T@<')E9U]R97!L86-E*&%R
M<F%Y*"<A7%Q<7"LA)RP@)R$O*R$G+"`B(21D<S(K(2(I+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@G+R<L("<O)RP@)R\G*2P-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<F]O="D[#0H@("`@("`@(&EF
M("@D<F]O='LP?2`A/2`G+R<I('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D
M;W!T:6]N<ULG=VEN9&]W<R==*2D@>PT*("`@("`@("`@("`@("`@(&EF("@A
M<')E9U]M871C:"@G+UY;02U:82UZ73HO)RP@)')O;W0I*2![#0H@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=2;V]T(&1I
M<F5C=&]R>2!M=7-T(&)E(&%N(&%B<V]L=71E('!A=&@@8F5G:6YN:6YG("<@
M+@T*("`@("`@("`@("`@("`@("`@("`@("`@)W=I=&@@(EQ<(B!O<B`B0SI<
M7"(L('=A<SH@(B<@+B`D<F]O="`N("<B)RD[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4F]O="!D:7)E8W1O<GD@;75S="!B92!A
M;B!A8G-O;'5T92!P871H(&)E9VEN;FEN9R`G("X-"B`@("`@("`@("`@("`@
M("`@("`@)W=I=&@@(B\B+"!W87,Z("(G("X@)')O;W0@+B`G(B<I.PT*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1W:6YD;W=S(#T@:7-S
M970H)&]P=&EO;G-;)W=I;F1O=W,G72D[#0H@("`@("`@(&EF("@D=VEN9&]W
M<RD@>PT*("`@("`@("`@("`@)')O;W0@/2!S=')?<F5P;&%C92@G+R<L("=<
M7"<L("1R;V]T*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(69I;&5?97AI
M<W1S*"1P87)A;7-;,5TI*2![#0H@("`@("`@("`@("!I9B`H(4!T;W5C:"@D
M<&%R86US6S%=*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"=#;W5L9"!N;W0@8W)E871E("(G("X@)'!A<F%M<ULQ72`N
M("<B)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)'!A
M<F%M<ULQ72`](')E86QP871H*"1P87)A;7-;,5TI.PT*("`@("`@("`D8V]N
M9FEG(#T@)FYE=R!014%27T-O;F9I9R@D<&%R86US6S%=+"`G(VYO(W-Y<W1E
M;2-C;VYF:6<C)RP@9F%L<V4L(&9A;'-E*3L-"B`@("`@("`@:68@*"1R;V]T
M>W-T<FQE;B@D<F]O="D@+2`Q?2`]/2`G+R<I('L-"B`@("`@("`@("`@("1R
M;V]T(#T@<W5B<W1R*"1R;V]T+"`P+"!S=')L96XH)')O;W0I("T@,2D[#0H@
M("`@("`@('T-"B`@("`@("`@)&-O;F9I9RT^;F]296=I<W1R>2@I.PT*("`@
M("`@("`D8V]N9FEG+3YS970H)W!H<%]D:7(G+"`D=VEN9&]W<R`_("(D<F]O
M=%Q<<&5A<EQ<<&AP(B`Z("(D<F]O="]P96%R+W!H<"(L("=U<V5R)RD[#0H@
M("`@("`@("1C;VYF:6<M/G-E="@G9&%T85]D:7(G+"`D=VEN9&]W<R`_("(D
M<F]O=%Q<<&5A<EQ<9&%T82(@.B`B)')O;W0O<&5A<B]D871A(BD[#0H@("`@
M("`@("1C;VYF:6<M/G-E="@G97AT7V1I<B<L("1W:6YD;W=S(#\@(B1R;V]T
M7%QP96%R7%QE>'0B(#H@(B1R;V]T+W!E87(O97AT(BD[#0H@("`@("`@("1C
M;VYF:6<M/G-E="@G9&]C7V1I<B<L("1W:6YD;W=S(#\@(B1R;V]T7%QP96%R
M7%QD;V-S(B`Z("(D<F]O="]P96%R+V1O8W,B*3L-"B`@("`@("`@)&-O;F9I
M9RT^<V5T*"=T97-T7V1I<B<L("1W:6YD;W=S(#\@(B1R;V]T7%QP96%R7%QT
M97-T<R(@.B`B)')O;W0O<&5A<B]T97-T<R(I.PT*("`@("`@("`D8V]N9FEG
M+3YS970H)V-A8VAE7V1I<B<L("1W:6YD;W=S(#\@(B1R;V]T7%QP96%R7%QC
M86-H92(@.B`B)')O;W0O<&5A<B]C86-H92(I.PT*("`@("`@("`D8V]N9FEG
M+3YS970H)V)I;E]D:7(G+"`D=VEN9&]W<R`_("(D<F]O=%Q<<&5A<B(@.B`B
M)')O;W0O<&5A<B(I.PT*("`@("`@("`D8V]N9FEG+3YW<FET94-O;F9I9T9I
M;&4H*3L-"B`@("`@("`@)'1H:7,M/E]S:&]W0V]N9FEG*"1C;VYF:6<I.PT*
M("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)U-U8V-E<W-F=6QL>2!C
M<F5A=&5D(&1E9F%U;'0@8V]N9FEG=7)A=&EO;B!F:6QE("(G("X@)'!A<F%M
M<ULQ72`N("<B)RP-"B`@("`@("`@("`@("1C;VUM86YD*3L-"B`@("!]#0H-
M"B`@("`O+R!]?7T-"@T*("`@(&9U;F-T:6]N(%]S:&]W0V]N9FEG*"8D8V]N
M9FEG*0T*("`@('L-"B`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"=U<V5R)RD[
M#0H@("`@("`@("1K97ES(#T@)&-O;F9I9RT^9V5T2V5Y<R@I.PT*("`@("`@
M("!S;W)T*"1K97ES*3L-"B`@("`@("`@)&-H86YN96P@/2`G<&5A<BYP:'`N
M;F5T)SL-"B`@("`@("`@)&1A=&$@/2!A<G)A>2@G8V%P=&EO;B<@/3X@)T-O
M;F9I9W5R871I;VX@*&-H86YN96P@)R`N("1C:&%N;F5L("X@)RDZ)RD[#0H@
M("`@("`@(&9O<F5A8V@@*"1K97ES(&%S("1K97DI('L-"B`@("`@("`@("`@
M("1T>7!E(#T@)&-O;F9I9RT^9V5T5'EP92@D:V5Y*3L-"B`@("`@("`@("`@
M("1V86QU92`]("1C;VYF:6<M/F=E="@D:V5Y+"`G=7-E<B<L("1C:&%N;F5L
M*3L-"B`@("`@("`@("`@(&EF("@D='EP92`]/2`G<&%S<W=O<F0G("8F("1V
M86QU92D@>PT*("`@("`@("`@("`@("`@("1V86QU92`]("<J*BHJ*BHJ*B<[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)'9A;'5E(#T]/2!F
M86QS92D@>PT*("`@("`@("`@("`@("`@("1V86QU92`]("=F86QS92<[#0H@
M("`@("`@("`@("!](&5L<V5I9B`H)'9A;'5E(#T]/2!T<G5E*2![#0H@("`@
M("`@("`@("`@("`@)'9A;'5E(#T@)W1R=64G.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@)&1A=&%;)V1A=&$G75LD8V]N9FEG+3YG971'<F]U<"@D
M:V5Y*5U;72`]#0H@("`@("`@("`@("`@("`@87)R87DH)&-O;F9I9RT^9V5T
M4')O;7!T*"1K97DI("P@)&ME>2P@)'9A;'5E*3L-"B`@("`@("`@?0T*("`@
M("`@("!F;W)E86-H("@D8V]N9FEG+3YG971,87EE<G,H*2!A<R`D;&%Y97(I
M('L-"B`@("`@("`@("`@("1D871A6R=D871A)UU;)T-O;F9I9R!&:6QE<R==
M6UT@/0T*("`@("`@("`@("`@("`@(&%R<F%Y*'5C9FER<W0H)&QA>65R*2`N
M("<@0V]N9FEG=7)A=&EO;B!&:6QE)RP@)T9I;&5N86UE)R`L#0H@("`@("`@
M("`@("`@("`@("`@("1C;VYF:6<M/F=E=$-O;F9&:6QE*"1L87EE<BDI.PT*
M("`@("`@("!]#0H-"B`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"1D
M871A+"`G8V]N9FEG+7-H;W<G*3L-"B`@("`@("`@<F5T=7)N('1R=64[#0H@
M("`@?0T*("`@("\O('M[>R!?8VAE8VM,87EE<B@I#0H-"B`@("`O*BH-"B`@
M("`@*B!#:&5C:W,@:68@82!L87EE<B!I<R!D969I;F5D(&]R(&YO=`T*("`@
M("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`D;&%Y97(@5&AE(&QA>65R('1O
M('-E87)C:"!F;W(-"B`@("`@*B!`<F5T=7)N(&UI>&5D($9A;'-E(&]N(&YO
M(&5R<F]R(&]R('1H92!E<G)O<B!M97-S86=E#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@7V-H96-K3&%Y97(H)&QA>65R(#T@;G5L;"D-"B`@("![#0H@("`@
M("`@(&EF("@A96UP='DH)&QA>65R*2`F)B`D;&%Y97(@(3T@)V1E9F%U;'0G
M*2![#0H@("`@("`@("`@("`D;&%Y97)S(#T@)'1H:7,M/F-O;F9I9RT^9V5T
M3&%Y97)S*"D[#0H@("`@("`@("`@("!I9B`H(6EN7V%R<F%Y*"1L87EE<BP@
M)&QA>65R<RDI('L-"B`@("`@("`@("`@("`@("!R971U<FX@(B!O;FQY('1H
M92!L87EE<G,Z(%PB(B`N(&EM<&QO9&4H)R(@;W(@(B<L("1L87EE<G,I("X@
M(EPB(&%R92!S=7!P;W)T960B.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("`O+R!]?7T-
M"GT-"@T*/SX-"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+TEN<W1A;&PN>&UL
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q-S8P-"`Q,#4Q-30S
M,S<S,2`P,C(W,S$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/&-O;6UA;F1S('9E<G-I;VX](C$N,"(^#0H@/&EN<W1A;&P^
M#0H@(#QS=6UM87)Y/DEN<W1A;&P@4&%C:V%G93PO<W5M;6%R>3X-"B`@/&9U
M;F-T:6]N/F1O26YS=&%L;#PO9G5N8W1I;VX^#0H@(#QS:&]R=&-U=#YI/"]S
M:&]R=&-U=#X-"B`@/&]P=&EO;G,^#0H@("`\9F]R8V4^#0H@("`@/'-H;W)T
M;W!T/F8\+W-H;W)T;W!T/@T*("`@(#QD;V,^=VEL;"!O=F5R=W)I=&4@;F5W
M97(@:6YS=&%L;&5D('!A8VMA9V5S/"]D;V,^#0H@("`\+V9O<F-E/@T*("`@
M/&QO;W-E/@T*("`@(#QS:&]R=&]P=#YL/"]S:&]R=&]P=#X-"B`@("`\9&]C
M/F1O(&YO="!C:&5C:R!F;W(@<F5C;VUM96YD960@9&5P96YD96YC>2!V97)S
M:6]N/"]D;V,^#0H@("`\+VQO;W-E/@T*("`@/&YO9&5P<SX-"B`@("`\<VAO
M<G1O<'0^;CPO<VAO<G1O<'0^#0H@("`@/&1O8SYI9VYO<F4@9&5P96YD96YC
M:65S+"!I;G-T86QL(&%N>7=A>3PO9&]C/@T*("`@/"]N;V1E<',^#0H@("`\
M<F5G:7-T97(M;VYL>3X-"B`@("`\<VAO<G1O<'0^<CPO<VAO<G1O<'0^#0H@
M("`@/&1O8SYD;R!N;W0@:6YS=&%L;"!F:6QE<RP@;VYL>2!R96=I<W1E<B!T
M:&4@<&%C:V%G92!A<R!I;G-T86QL960\+V1O8SX-"B`@(#PO<F5G:7-T97(M
M;VYL>3X-"B`@(#QS;V9T/@T*("`@(#QS:&]R=&]P=#YS/"]S:&]R=&]P=#X-
M"B`@("`\9&]C/G-O9G0@:6YS=&%L;"P@9F%I;"!S:6QE;G1L>2P@;W(@=7!G
M<F%D92!I9B!A;')E861Y(&EN<W1A;&QE9#PO9&]C/@T*("`@/"]S;V9T/@T*
M("`@/&YO8G5I;&0^#0H@("`@/'-H;W)T;W!T/D(\+W-H;W)T;W!T/@T*("`@
M(#QD;V,^9&]N)F%P;W,[="!B=6EL9"!#(&5X=&5N<VEO;G,\+V1O8SX-"B`@
M(#PO;F]B=6EL9#X-"B`@(#QN;V-O;7!R97-S/@T*("`@(#QS:&]R=&]P=#Y:
M/"]S:&]R=&]P=#X-"B`@("`\9&]C/G)E<75E<W0@=6YC;VUP<F5S<V5D(&9I
M;&5S('=H96X@9&]W;FQO861I;F<\+V1O8SX-"B`@(#PO;F]C;VUP<F5S<SX-
M"B`@(#QI;G-T86QL<F]O=#X-"B`@("`\<VAO<G1O<'0^4CPO<VAO<G1O<'0^
M#0H@("`@/&%R9SY$25(\+V%R9SX-"B`@("`\9&]C/G)O;W0@9&ER96-T;W)Y
M('5S960@=VAE;B!I;G-T86QL:6YG(&9I;&5S("AA;&$@4$A0)F%P;W,[<R!)
M3E-404Q,7U)/3U0I/"]D;V,^#0H@("`\+VEN<W1A;&QR;V]T/@T*("`@/&EG
M;F]R92UE<G)O<G,^#0H@("`@/&1O8SYF;W)C92!I;G-T86QL(&5V96X@:68@
M=&AE<F4@=V5R92!E<G)O<G,\+V1O8SX-"B`@(#PO:6=N;W)E+65R<F]R<SX-
M"B`@(#QA;&QD97!S/@T*("`@(#QS:&]R=&]P=#YA/"]S:&]R=&]P=#X-"B`@
M("`\9&]C/FEN<W1A;&P@86QL(')E<75I<F5D(&%N9"!O<'1I;VYA;"!D97!E
M;F1E;F-I97,\+V1O8SX-"B`@(#PO86QL9&5P<SX-"B`@(#QO;FQY<F5Q9&5P
M<SX-"B`@("`\<VAO<G1O<'0^;SPO<VAO<G1O<'0^#0H@("`@/&1O8SYI;G-T
M86QL(&%L;"!R97%U:7)E9"!D97!E;F1E;F-I97,\+V1O8SX-"B`@(#PO;VYL
M>7)E<61E<',^#0H@("`\;V9F;&EN93X-"B`@("`\<VAO<G1O<'0^3SPO<VAO
M<G1O<'0^#0H@("`@/&1O8SYD;R!N;W0@871T96UP="!T;R!D;W=N;&]A9"!A
M;GD@=7)L<R!O<B!C;VYT86-T(&-H86YN96QS/"]D;V,^#0H@("`\+V]F9FQI
M;F4^#0H@("`\<')E=&5N9#X-"B`@("`\<VAO<G1O<'0^<#PO<VAO<G1O<'0^
M#0H@("`@/&1O8SY/;FQY(&QI<W0@=&AE('!A8VMA9V5S('1H870@=V]U;&0@
M8F4@9&]W;FQO861E9#PO9&]C/@T*("`@/"]P<F5T96YD/@T*("`\+V]P=&EO
M;G,^#0H@(#QD;V,^6V-H86YN96PO729L=#MP86-K86=E)F=T.R`N+BX-"DEN
M<W1A;&QS(&]N92!O<B!M;W)E(%!%05(@<&%C:V%G97,N("!9;W4@8V%N('-P
M96-I9GD@82!P86-K86=E('1O#0II;G-T86QL(&EN(&9O=7(@=V%Y<SH-"@T*
M)G%U;W0[4&%C:V%G92TQ+C`N=&=Z)G%U;W0[(#H@:6YS=&%L;',@9G)O;2!A
M(&QO8V%L(&9I;&4-"@T*)G%U;W0[:'1T<#HO+V5X86UP;&4N8V]M+U!A8VMA
M9V4M,2XP+G1G>B9Q=6]T.R`Z(&EN<W1A;&QS(&9R;VT-"F%N>7=H97)E(&]N
M('1H92!N970N#0H-"B9Q=6]T.W!A8VMA9V4N>&UL)G%U;W0[(#H@:6YS=&%L
M;',@=&AE('!A8VMA9V4@9&5S8W)I8F5D(&EN#0IP86-K86=E+GAM;"X@(%5S
M969U;"!F;W(@=&5S=&EN9RP@;W(@9F]R('=R87!P:6YG(&$@4$5!4B!P86-K
M86=E(&EN#0IA;F]T:&5R('!A8VMA9V4@;6%N86=E<B!S=6-H(&%S(%)032X-
M"@T*)G%U;W0[4&%C:V%G95LM=F5R<VEO;B]S=&%T95U;+G1A<ETF<75O=#L@
M.B!Q=65R:65S('EO=7(@9&5F875L="!C:&%N;F5L)F%P;W,[<R!S97)V97(-
M"BA[8V]N9FEG(&UA<W1E<E]S97)V97)]*2!A;F0@9&]W;FQO861S('1H92!N
M97=E<W0@<&%C:V%G92!W:71H#0IT:&4@<')E9F5R<F5D('%U86QI='DO<W1A
M=&4@*'MC;VYF:6<@<')E9F5R<F5D7W-T871E?2DN#0H-"E1O(')E=')I979E
M(%!A8VMA9V4@=F5R<VEO;B`Q+C$L('5S92`F<75O=#M086-K86=E+3$N,2PF
M<75O=#L@=&\@<F5T<FEE=F4-"E!A8VMA9V4@<W1A=&4@8F5T82P@=7-E("9Q
M=6]T.U!A8VMA9V4M8F5T82XF<75O=#L@(%1O(')E=')I979E(&%N('5N8V]M
M<')E<W-E9`T*9FEL92P@87!P96YD("YT87(@*&UA:V4@<W5R92!T:&5R92!I
M<R!N;R!F:6QE(&)Y('1H92!S86UE(&YA;64@9FER<W0I#0H-"E1O(&1O=VYL
M;V%D(&$@<&%C:V%G92!F<F]M(&%N;W1H97(@8VAA;FYE;"P@<')E9FEX('=I
M=&@@=&AE(&-H86YN96P@;F%M92!L:6ME#0HF<75O=#MC:&%N;F5L+U!A8VMA
M9V4F<75O=#L-"@T*36]R92!T:&%N(&]N92!P86-K86=E(&UA>2!B92!S<&5C
M:69I960@870@;VYC92X@($ET(&ES(&]K('1O(&UI>"!T:&5S90T*9F]U<B!W
M87ES(&]F('-P96-I9GEI;F<@<&%C:V%G97,N#0H\+V1O8SX-"B`\+VEN<W1A
M;&P^#0H@/'5P9W)A9&4^#0H@(#QS=6UM87)Y/E5P9W)A9&4@4&%C:V%G93PO
M<W5M;6%R>3X-"B`@/&9U;F-T:6]N/F1O26YS=&%L;#PO9G5N8W1I;VX^#0H@
M(#QS:&]R=&-U=#YU<#PO<VAO<G1C=70^#0H@(#QO<'1I;VYS/@T*("`@/&9O
M<F-E/@T*("`@(#QS:&]R=&]P=#YF/"]S:&]R=&]P=#X-"B`@("`\9&]C/F]V
M97)W<FET92!N97=E<B!I;G-T86QL960@<&%C:V%G97,\+V1O8SX-"B`@(#PO
M9F]R8V4^#0H@("`\;&]O<V4^#0H@("`@/'-H;W)T;W!T/FP\+W-H;W)T;W!T
M/@T*("`@(#QD;V,^9&\@;F]T(&-H96-K(&9O<B!R96-O;6UE;F1E9"!D97!E
M;F1E;F-Y('9E<G-I;VX\+V1O8SX-"B`@(#PO;&]O<V4^#0H@("`\;F]D97!S
M/@T*("`@(#QS:&]R=&]P=#YN/"]S:&]R=&]P=#X-"B`@("`\9&]C/FEG;F]R
M92!D97!E;F1E;F-I97,L('5P9W)A9&4@86YY=V%Y/"]D;V,^#0H@("`\+VYO
M9&5P<SX-"B`@(#QR96=I<W1E<BUO;FQY/@T*("`@(#QS:&]R=&]P=#YR/"]S
M:&]R=&]P=#X-"B`@("`\9&]C/F1O(&YO="!I;G-T86QL(&9I;&5S+"!O;FQY
M(')E9VES=&5R('1H92!P86-K86=E(&%S('5P9W)A9&5D/"]D;V,^#0H@("`\
M+W)E9VES=&5R+6]N;'D^#0H@("`\;F]B=6EL9#X-"B`@("`\<VAO<G1O<'0^
M0CPO<VAO<G1O<'0^#0H@("`@/&1O8SYD;VXF87!O<SMT(&)U:6QD($,@97AT
M96YS:6]N<SPO9&]C/@T*("`@/"]N;V)U:6QD/@T*("`@/&YO8V]M<')E<W,^
M#0H@("`@/'-H;W)T;W!T/EH\+W-H;W)T;W!T/@T*("`@(#QD;V,^<F5Q=65S
M="!U;F-O;7!R97-S960@9FEL97,@=VAE;B!D;W=N;&]A9&EN9SPO9&]C/@T*
M("`@/"]N;V-O;7!R97-S/@T*("`@/&EN<W1A;&QR;V]T/@T*("`@(#QS:&]R
M=&]P=#Y2/"]S:&]R=&]P=#X-"B`@("`\87)G/D1)4CPO87)G/@T*("`@(#QD
M;V,^<F]O="!D:7)E8W1O<GD@=7-E9"!W:&5N(&EN<W1A;&QI;F<@9FEL97,@
M*&%L82!02%`F87!O<SMS($E.4U1!3$Q?4D]/5"D\+V1O8SX-"B`@(#PO:6YS
M=&%L;')O;W0^#0H@("`\:6=N;W)E+65R<F]R<SX-"B`@("`\9&]C/F9O<F-E
M(&EN<W1A;&P@979E;B!I9B!T:&5R92!W97)E(&5R<F]R<SPO9&]C/@T*("`@
M/"]I9VYO<F4M97)R;W)S/@T*("`@/&%L;&1E<',^#0H@("`@/'-H;W)T;W!T
M/F$\+W-H;W)T;W!T/@T*("`@(#QD;V,^:6YS=&%L;"!A;&P@<F5Q=6ER960@
M86YD(&]P=&EO;F%L(&1E<&5N9&5N8VEE<SPO9&]C/@T*("`@/"]A;&QD97!S
M/@T*("`@/&]N;'ER97%D97!S/@T*("`@(#QS:&]R=&]P=#YO/"]S:&]R=&]P
M=#X-"B`@("`\9&]C/FEN<W1A;&P@86QL(')E<75I<F5D(&1E<&5N9&5N8VEE
M<SPO9&]C/@T*("`@/"]O;FQY<F5Q9&5P<SX-"B`@(#QO9F9L:6YE/@T*("`@
M(#QS:&]R=&]P=#Y//"]S:&]R=&]P=#X-"B`@("`\9&]C/F1O(&YO="!A='1E
M;7!T('1O(&1O=VYL;V%D(&%N>2!U<FQS(&]R(&-O;G1A8W0@8VAA;FYE;',\
M+V1O8SX-"B`@(#PO;V9F;&EN93X-"B`@(#QP<F5T96YD/@T*("`@(#QS:&]R
M=&]P=#YP/"]S:&]R=&]P=#X-"B`@("`\9&]C/D]N;'D@;&ES="!T:&4@<&%C
M:V%G97,@=&AA="!W;W5L9"!B92!D;W=N;&]A9&5D/"]D;V,^#0H@("`\+W!R
M971E;F0^#0H@(#PO;W!T:6]N<SX-"B`@/&1O8SXF;'0[<&%C:V%G929G=#L@
M+BXN#0I5<&=R861E<R!O;F4@;W(@;6]R92!014%2('!A8VMA9V5S+B`@4V5E
M(&1O8W5M96YT871I;VX@9F]R('1H90T*)G%U;W0[:6YS=&%L;"9Q=6]T.R!C
M;VUM86YD(&9O<B!W87ES('1O('-P96-I9GD@82!P86-K86=E+@T*#0I7:&5N
M('5P9W)A9&EN9RP@>6]U<B!P86-K86=E('=I;&P@8F4@=7!D871E9"!I9B!T
M:&4@<')O=FED960@;F5W#0IP86-K86=E(&AA<R!A(&AI9VAE<B!V97)S:6]N
M(&YU;6)E<B`H=7-E('1H92`M9B!O<'1I;VX@:68@>6]U(&YE960@=&\-"G5P
M9W)A9&4@86YY=V%Y*2X-"@T*36]R92!T:&%N(&]N92!P86-K86=E(&UA>2!B
M92!S<&5C:69I960@870@;VYC92X-"CPO9&]C/@T*(#PO=7!G<F%D93X-"B`\
M=7!G<F%D92UA;&P^#0H@(#QS=6UM87)Y/E5P9W)A9&4@06QL(%!A8VMA9V5S
M/"]S=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]);G-T86QL/"]F=6YC=&EO;CX-
M"B`@/'-H;W)T8W5T/G5A/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,^#0H@("`\
M;F]D97!S/@T*("`@(#QS:&]R=&]P=#YN/"]S:&]R=&]P=#X-"B`@("`\9&]C
M/FEG;F]R92!D97!E;F1E;F-I97,L('5P9W)A9&4@86YY=V%Y/"]D;V,^#0H@
M("`\+VYO9&5P<SX-"B`@(#QR96=I<W1E<BUO;FQY/@T*("`@(#QS:&]R=&]P
M=#YR/"]S:&]R=&]P=#X-"B`@("`\9&]C/F1O(&YO="!I;G-T86QL(&9I;&5S
M+"!O;FQY(')E9VES=&5R('1H92!P86-K86=E(&%S('5P9W)A9&5D/"]D;V,^
M#0H@("`\+W)E9VES=&5R+6]N;'D^#0H@("`\;F]B=6EL9#X-"B`@("`\<VAO
M<G1O<'0^0CPO<VAO<G1O<'0^#0H@("`@/&1O8SYD;VXF87!O<SMT(&)U:6QD
M($,@97AT96YS:6]N<SPO9&]C/@T*("`@/"]N;V)U:6QD/@T*("`@/&YO8V]M
M<')E<W,^#0H@("`@/'-H;W)T;W!T/EH\+W-H;W)T;W!T/@T*("`@(#QD;V,^
M<F5Q=65S="!U;F-O;7!R97-S960@9FEL97,@=VAE;B!D;W=N;&]A9&EN9SPO
M9&]C/@T*("`@/"]N;V-O;7!R97-S/@T*("`@/&EN<W1A;&QR;V]T/@T*("`@
M(#QS:&]R=&]P=#Y2/"]S:&]R=&]P=#X-"B`@("`\87)G/D1)4CPO87)G/@T*
M("`@(#QD;V,^<F]O="!D:7)E8W1O<GD@=7-E9"!W:&5N(&EN<W1A;&QI;F<@
M9FEL97,@*&%L82!02%`F87!O<SMS($E.4U1!3$Q?4D]/5"D\+V1O8SX-"B`@
M(#PO:6YS=&%L;')O;W0^#0H@("`\:6=N;W)E+65R<F]R<SX-"B`@("`\9&]C
M/F9O<F-E(&EN<W1A;&P@979E;B!I9B!T:&5R92!W97)E(&5R<F]R<SPO9&]C
M/@T*("`@/"]I9VYO<F4M97)R;W)S/@T*("`@/&QO;W-E/@T*("`@(#QD;V,^
M9&\@;F]T(&-H96-K(&9O<B!R96-O;6UE;F1E9"!D97!E;F1E;F-Y('9E<G-I
M;VX\+V1O8SX-"B`@(#PO;&]O<V4^#0H@(#PO;W!T:6]N<SX-"B`@/&1O8SX-
M"E5P9W)A9&5S(&%L;"!P86-K86=E<R!T:&%T(&AA=F4@82!N97=E<B!R96QE
M87-E(&%V86EL86)L92X@(%5P9W)A9&5S(&%R90T*9&]N92!O;FQY(&EF('1H
M97)E(&ES(&$@<F5L96%S92!A=F%I;&%B;&4@;V8@=&AE('-T871E('-P96-I
M9FEE9"!I;@T*)G%U;W0[<')E9F5R<F5D7W-T871E)G%U;W0[("AC=7)R96YT
M;'D@>V-O;F9I9R!P<F5F97)R961?<W1A=&5]*2P@;W(@82!S=&%T92!C;VYS
M:61E<F5D#0IM;W)E('-T86)L92X-"CPO9&]C/@T*(#PO=7!G<F%D92UA;&P^
M#0H@/'5N:6YS=&%L;#X-"B`@/'-U;6UA<GD^56XM:6YS=&%L;"!086-K86=E
M/"]S=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]5;FEN<W1A;&P\+V9U;F-T:6]N
M/@T*("`\<VAO<G1C=70^=6X\+W-H;W)T8W5T/@T*("`\;W!T:6]N<SX-"B`@
M(#QN;V1E<',^#0H@("`@/'-H;W)T;W!T/FX\+W-H;W)T;W!T/@T*("`@(#QD
M;V,^:6=N;W)E(&1E<&5N9&5N8VEE<RP@=6YI;G-T86QL(&%N>7=A>3PO9&]C
M/@T*("`@/"]N;V1E<',^#0H@("`\<F5G:7-T97(M;VYL>3X-"B`@("`\<VAO
M<G1O<'0^<CPO<VAO<G1O<'0^#0H@("`@/&1O8SYD;R!N;W0@<F5M;W9E(&9I
M;&5S+"!O;FQY(')E9VES=&5R('1H92!P86-K86=E<R!A<R!N;W0@:6YS=&%L
M;&5D/"]D;V,^#0H@("`\+W)E9VES=&5R+6]N;'D^#0H@("`\:6YS=&%L;')O
M;W0^#0H@("`@/'-H;W)T;W!T/E(\+W-H;W)T;W!T/@T*("`@(#QA<F<^1$E2
M/"]A<F<^#0H@("`@/&1O8SYR;V]T(&1I<F5C=&]R>2!U<V5D('=H96X@:6YS
M=&%L;&EN9R!F:6QE<R`H86QA(%!(4"9A<&]S.W,@24Y35$%,3%]23T]4*3PO
M9&]C/@T*("`@/"]I;G-T86QL<F]O=#X-"B`@(#QI9VYO<F4M97)R;W)S/@T*
M("`@(#QD;V,^9F]R8V4@:6YS=&%L;"!E=F5N(&EF('1H97)E('=E<F4@97)R
M;W)S/"]D;V,^#0H@("`\+VEG;F]R92UE<G)O<G,^#0H@("`\;V9F;&EN93X-
M"B`@("`\<VAO<G1O<'0^3SPO<VAO<G1O<'0^#0H@("`@/&1O8SYD;R!N;W0@
M871T96UP="!T;R!U;FEN<W1A;&P@<F5M;W1E;'D\+V1O8SX-"B`@(#PO;V9F
M;&EN93X-"B`@/"]O<'1I;VYS/@T*("`\9&]C/EMC:&%N;F5L+UTF;'0[<&%C
M:V%G929G=#L@+BXN#0I5;FEN<W1A;&QS(&]N92!O<B!M;W)E(%!%05(@<&%C
M:V%G97,N("!-;W)E('1H86X@;VYE('!A8VMA9V4@;6%Y(&)E#0IS<&5C:69I
M960@870@;VYC92X@(%!R969I>"!W:71H(&-H86YN96P@;F%M92!T;R!U;FEN
M<W1A;&P@9G)O;2!A#0IC:&%N;F5L(&YO="!I;B!Y;W5R(&1E9F%U;'0@8VAA
M;FYE;"`H>V-O;F9I9R!D969A=6QT7V-H86YN96Q]*0T*/"]D;V,^#0H@/"]U
M;FEN<W1A;&P^#0H@/&)U;F1L93X-"B`@/'-U;6UA<GD^56YP86-K<R!A(%!E
M8VP@4&%C:V%G93PO<W5M;6%R>3X-"B`@/&9U;F-T:6]N/F1O0G5N9&QE/"]F
M=6YC=&EO;CX-"B`@/'-H;W)T8W5T/F)U;CPO<VAO<G1C=70^#0H@(#QO<'1I
M;VYS/@T*("`@/&1E<W1I;F%T:6]N/@T*("`@(#QS:&]R=&]P=#YD/"]S:&]R
M=&]P=#X-"B`@("`\87)G/D1)4CPO87)G/@T*("`@(#QD;V,^3W!T:6]N86P@
M9&5S=&EN871I;VX@9&ER96-T;W)Y(&9O<B!U;G!A8VMI;F<@*&1E9F%U;'1S
M('1O(&-U<G)E;G0@<&%T:"!O<B`F<75O=#ME>'0F<75O=#L@:68@97AI<W1S
M*3PO9&]C/@T*("`@/"]D97-T:6YA=&EO;CX-"B`@(#QF;W)C93X-"B`@("`\
M<VAO<G1O<'0^9CPO<VAO<G1O<'0^#0H@("`@/&1O8SY&;W)C92!T:&4@=6YP
M86-K:6YG(&5V96X@:68@=&AE<F4@=V5R92!E<G)O<G,@:6X@=&AE('!A8VMA
M9V4\+V1O8SX-"B`@(#PO9F]R8V4^#0H@(#PO;W!T:6]N<SX-"B`@/&1O8SXF
M;'0[<&%C:V%G929G=#L-"E5N<&%C:W,@82!096-L(%!A8VMA9V4@:6YT;R!T
M:&4@<V5L96-T960@;&]C871I;VXN($ET('=I;&P@9&]W;FQO860@=&AE#0IP
M86-K86=E(&EF(&YE961E9"X-"CPO9&]C/@T*(#PO8G5N9&QE/@T*(#QR=6XM
M<V-R:7!T<SX-"B`@/'-U;6UA<GD^4G5N(%!O<W0M26YS=&%L;"!38W)I<'1S
M(&)U;F1L960@=VET:"!A('!A8VMA9V4\+W-U;6UA<GD^#0H@(#QF=6YC=&EO
M;CYD;U)U;E-C<FEP=',\+V9U;F-T:6]N/@T*("`\<VAO<G1C=70^<G,\+W-H
M;W)T8W5T/@T*("`\;W!T:6]N<R`O/@T*("`\9&]C/B9L=#MP86-K86=E)F=T
M.PT*4G5N('!O<W0M:6YS=&%L;&%T:6]N('-C<FEP=',@:6X@<&%C:V%G92`F
M;'0[<&%C:V%G929G=#LL(&EF(&%N>2!E>&ES="X-"CPO9&]C/@T*(#PO<G5N
M+7-C<FEP=',^#0H\+V-O;6UA;F1S/@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O
M0V]M;6%N9"]);G-T86QL+G!H<```````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`Q,#$Q-#4@,3`U,34T,S,W,S$@,#(R-S$R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP#0HO*BH-"B`J(%!%
M05)?0V]M;6%N9%]);G-T86QL("AI;G-T86QL+"!U<&=R861E+"!U<&=R861E
M+6%L;"P@=6YI;G-T86QL+"!B=6YD;&4L(')U;BUS8W)I<'1S(&-O;6UA;F1S
M*0T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y3
M13H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP
M(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ
M#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@
M>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC
M96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@
M=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE
M="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-
M"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J
M($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X-"B`J($!A
M=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C
M;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS
M92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@
M3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!);G-T86QL
M+G!H<"QV(#$N,3$U(#(P,#8O,#,O,#(@,3@Z,30Z,3,@8V5L;&]G($5X<"`D
M#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O
M4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L
M96%S92`P+C$-"B`J+PT*#0HO*BH-"B`J(&)A<V4@8VQA<W,-"B`J+PT*<F5Q
M=6ER95]O;F-E("=014%2+T-O;6UA;F0O0V]M;6]N+G!H<"<[#0H-"B\J*@T*
M("H@4$5!4B!C;VUM86YD<R!F;W(@:6YS=&%L;&%T:6]N(&]R(&1E:6YS=&%L
M;&%T:6]N+W5P9W)A9&EN9R!O9@T*("H@<&%C:V%G97,N#0H@*@T*("H@0&-A
M=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO
M<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@
M("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H
M="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT
M='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E
M(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK
M("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`
M<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-
M"B`J+PT*8VQA<W,@4$5!4E]#;VUM86YD7TEN<W1A;&P@97AT96YD<R!014%2
M7T-O;6UA;F1?0V]M;6]N#0I[#0H@("`@+R\@>WM[('!R;W!E<G1I97,-"@T*
M("`@('9A<B`D8V]M;6%N9',@/2!A<G)A>2@-"B`@("`@("`@)VEN<W1A;&PG
M(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=);G-T86QL
M(%!A8VMA9V4G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]);G-T
M86QL)RP-"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)VDG+`T*("`@("`@
M("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=F
M;W)C92<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P
M="<@/3X@)V8G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G=VEL
M;"!O=F5R=W)I=&4@;F5W97(@:6YS=&%L;&5D('!A8VMA9V5S)RP-"B`@("`@
M("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G;&]O<V4G(#T^
M(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=L
M)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)V1O(&YO="!C:&5C
M:R!F;W(@<F5C;VUM96YD960@9&5P96YD96YC>2!V97)S:6]N)RP-"B`@("`@
M("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G;F]D97!S)R`]
M/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G
M;B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=I9VYO<F4@9&5P
M96YD96YC:65S+"!I;G-T86QL(&%N>7=A>2<L#0H@("`@("`@("`@("`@("`@
M("`@("DL#0H@("`@("`@("`@("`@("`@)W)E9VES=&5R+6]N;'DG(#T^(&%R
M<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=R)RP-
M"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)V1O(&YO="!I;G-T86QL
M(&9I;&5S+"!O;FQY(')E9VES=&5R('1H92!P86-K86=E(&%S(&EN<W1A;&QE
M9"<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@
M)W-O9G0G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O
M<'0G(#T^("=S)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)W-O
M9G0@:6YS=&%L;"P@9F%I;"!S:6QE;G1L>2P@;W(@=7!G<F%D92!I9B!A;')E
M861Y(&EN<W1A;&QE9"<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@
M("`@("`@("`@("`@)VYO8G5I;&0G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@
M("`@("`@("`G<VAO<G1O<'0G(#T^("=")RP-"B`@("`@("`@("`@("`@("`@
M("`@)V1O8R<@/3X@)V1O;EPG="!B=6EL9"!#(&5X=&5N<VEO;G,G+`T*("`@
M("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=N;V-O;7!R
M97-S)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T
M)R`]/B`G6B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=R97%U
M97-T('5N8V]M<')E<W-E9"!F:6QE<R!W:&5N(&1O=VYL;V%D:6YG)RP-"B`@
M("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G:6YS=&%L
M;')O;W0G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O
M<'0G(#T^("=2)RP-"B`@("`@("`@("`@("`@("`@("`@)V%R9R<@/3X@)T1)
M4B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=R;V]T(&1I<F5C
M=&]R>2!U<V5D('=H96X@:6YS=&%L;&EN9R!F:6QE<R`H86QA(%!(4%PG<R!)
M3E-404Q,7U)/3U0I+"!U<V4@<&%C:V%G:6YG<F]O="!F;W(@4E!-)RP-"B`@
M("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G<&%C:V%G
M:6YG<F]O="<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R
M=&]P="<@/3X@)U`G+`T*("`@("`@("`@("`@("`@("`@("`G87)G)R`]/B`G
M1$E2)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)W)O;W0@9&ER
M96-T;W)Y('5S960@=VAE;B!P86-K86=I;F<@9FEL97,L(&QI:V4@4E!-('!A
M8VMA9VEN9R<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@
M("`@("`@)VEG;F]R92UE<G)O<G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@
M("`@("`@("`G9&]C)R`]/B`G9F]R8V4@:6YS=&%L;"!E=F5N(&EF('1H97)E
M('=E<F4@97)R;W)S)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@
M("`@("`@("`@("`G86QL9&5P<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@
M("`@("`@("=S:&]R=&]P="<@/3X@)V$G+`T*("`@("`@("`@("`@("`@("`@
M("`G9&]C)R`]/B`G:6YS=&%L;"!A;&P@<F5Q=6ER960@86YD(&]P=&EO;F%L
M(&1E<&5N9&5N8VEE<R<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@
M("`@("`@("`@("`@)V]N;'ER97%D97!S)R`]/B!A<G)A>2@-"B`@("`@("`@
M("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G;R<L#0H@("`@("`@("`@("`@
M("`@("`@("=D;V,G(#T^("=I;G-T86QL(&%L;"!R97%U:7)E9"!D97!E;F1E
M;F-I97,G+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@
M("`@("=O9F9L:6YE)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@
M)W-H;W)T;W!T)R`]/B`G3R<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G
M(#T^("=D;R!N;W0@871T96UP="!T;R!D;W=N;&]A9"!A;GD@=7)L<R!O<B!C
M;VYT86-T(&-H86YN96QS)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@
M("`@("`@("`@("`@("`G<')E=&5N9"<@/3X@87)R87DH#0H@("`@("`@("`@
M("`@("`@("`@("=S:&]R=&]P="<@/3X@)W`G+`T*("`@("`@("`@("`@("`@
M("`@("`G9&]C)R`]/B`G3VYL>2!L:7-T('1H92!P86-K86=E<R!T:&%T('=O
M=6QD(&)E(&1O=VYL;V%D960G+`T*("`@("`@("`@("`@("`@("`@("`I+`T*
M("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`G9&]C)R`]/B`G6V-H
M86YN96PO73QP86-K86=E/B`N+BX-"DEN<W1A;&QS(&]N92!O<B!M;W)E(%!%
M05(@<&%C:V%G97,N("!9;W4@8V%N('-P96-I9GD@82!P86-K86=E('1O#0II
M;G-T86QL(&EN(&9O=7(@=V%Y<SH-"@T*(E!A8VMA9V4M,2XP+G1G>B(@.B!I
M;G-T86QL<R!F<F]M(&$@;&]C86P@9FEL90T*#0HB:'1T<#HO+V5X86UP;&4N
M8V]M+U!A8VMA9V4M,2XP+G1G>B(@.B!I;G-T86QL<R!F<F]M#0IA;GEW:&5R
M92!O;B!T:&4@;F5T+@T*#0HB<&%C:V%G92YX;6PB(#H@:6YS=&%L;',@=&AE
M('!A8VMA9V4@9&5S8W)I8F5D(&EN#0IP86-K86=E+GAM;"X@(%5S969U;"!F
M;W(@=&5S=&EN9RP@;W(@9F]R('=R87!P:6YG(&$@4$5!4B!P86-K86=E(&EN
M#0IA;F]T:&5R('!A8VMA9V4@;6%N86=E<B!S=6-H(&%S(%)032X-"@T*(E!A
M8VMA9V5;+79E<G-I;VXO<W1A=&5=6RYT87)=(B`Z('%U97)I97,@>6]U<B!D
M969A=6QT(&-H86YN96Q<)W,@<V5R=F5R#0HH>V-O;F9I9R!M87-T97)?<V5R
M=F5R?2D@86YD(&1O=VYL;V%D<R!T:&4@;F5W97-T('!A8VMA9V4@=VET:`T*
M=&AE('!R969E<G)E9"!Q=6%L:71Y+W-T871E("A[8V]N9FEG('!R969E<G)E
M9%]S=&%T97TI+@T*#0I4;R!R971R:65V92!086-K86=E('9E<G-I;VX@,2XQ
M+"!U<V4@(E!A8VMA9V4M,2XQ+"(@=&\@<F5T<FEE=F4-"E!A8VMA9V4@<W1A
M=&4@8F5T82P@=7-E(")086-K86=E+6)E=&$N(B`@5&\@<F5T<FEE=F4@86X@
M=6YC;VUP<F5S<V5D#0IF:6QE+"!A<'!E;F0@+G1A<B`H;6%K92!S=7)E('1H
M97)E(&ES(&YO(&9I;&4@8GD@=&AE('-A;64@;F%M92!F:7)S="D-"@T*5&\@
M9&]W;FQO860@82!P86-K86=E(&9R;VT@86YO=&AE<B!C:&%N;F5L+"!P<F5F
M:7@@=VET:"!T:&4@8VAA;FYE;"!N86UE(&QI:V4-"B)C:&%N;F5L+U!A8VMA
M9V4B#0H-"DUO<F4@=&AA;B!O;F4@<&%C:V%G92!M87D@8F4@<W!E8VEF:65D
M(&%T(&]N8V4N("!)="!I<R!O:R!T;R!M:7@@=&AE<V4-"F9O=7(@=V%Y<R!O
M9B!S<&5C:69Y:6YG('!A8VMA9V5S+@T*)RDL#0H@("`@("`@("=U<&=R861E
M)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G57!G<F%D
M92!086-K86=E)RP-"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O26YS
M=&%L;"<L#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=U<"<L#0H@("`@
M("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@
M)V9O<F-E)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T
M;W!T)R`]/B`G9B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=O
M=F5R=W)I=&4@;F5W97(@:6YS=&%L;&5D('!A8VMA9V5S)RP-"B`@("`@("`@
M("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G;&]O<V4G(#T^(&%R
M<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=L)RP-
M"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)V1O(&YO="!C:&5C:R!F
M;W(@<F5C;VUM96YD960@9&5P96YD96YC>2!V97)S:6]N)RP-"B`@("`@("`@
M("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G;F]D97!S)R`]/B!A
M<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G;B<L
M#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=I9VYO<F4@9&5P96YD
M96YC:65S+"!U<&=R861E(&%N>7=A>2<L#0H@("`@("`@("`@("`@("`@("`@
M("DL#0H@("`@("`@("`@("`@("`@)W)E9VES=&5R+6]N;'DG(#T^(&%R<F%Y
M*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=R)RP-"B`@
M("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)V1O(&YO="!I;G-T86QL(&9I
M;&5S+"!O;FQY(')E9VES=&5R('1H92!P86-K86=E(&%S('5P9W)A9&5D)RP-
M"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G;F]B
M=6EL9"<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P
M="<@/3X@)T(G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G9&]N
M7"=T(&)U:6QD($,@97AT96YS:6]N<R<L#0H@("`@("`@("`@("`@("`@("`@
M("DL#0H@("`@("`@("`@("`@("`@)VYO8V]M<')E<W,G(#T^(&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=:)RP-"B`@("`@
M("`@("`@("`@("`@("`@)V1O8R<@/3X@)W)E<75E<W0@=6YC;VUP<F5S<V5D
M(&9I;&5S('=H96X@9&]W;FQO861I;F<G+`T*("`@("`@("`@("`@("`@("`@
M("`I+`T*("`@("`@("`@("`@("`@("=I;G-T86QL<F]O="<@/3X@87)R87DH
M#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)U(G+`T*("`@
M("`@("`@("`@("`@("`@("`G87)G)R`]/B`G1$E2)RP-"B`@("`@("`@("`@
M("`@("`@("`@)V1O8R<@/3X@)W)O;W0@9&ER96-T;W)Y('5S960@=VAE;B!I
M;G-T86QL:6YG(&9I;&5S("AA;&$@4$A07"=S($E.4U1!3$Q?4D]/5"DL('5S
M92!P86-K86=I;F=R;V]T(&9O<B!24$TG+`T*("`@("`@("`@("`@("`@("`@
M("`I+`T*("`@("`@("`@("`@("`@("=P86-K86=I;F=R;V]T)R`]/B!A<G)A
M>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G4"<L#0H@
M("`@("`@("`@("`@("`@("`@("=A<F<G(#T^("=$25(G+`T*("`@("`@("`@
M("`@("`@("`@("`G9&]C)R`]/B`G<F]O="!D:7)E8W1O<GD@=7-E9"!W:&5N
M('!A8VMA9VEN9R!F:6QE<RP@;&EK92!24$T@<&%C:V%G:6YG)RP-"B`@("`@
M("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G:6=N;W)E+65R
M<F]R<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^
M("=F;W)C92!I;G-T86QL(&5V96X@:68@=&AE<F4@=V5R92!E<G)O<G,G+`T*
M("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=A;&QD
M97!S)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T
M)R`]/B`G82<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=I;G-T
M86QL(&%L;"!R97%U:7)E9"!A;F0@;W!T:6]N86P@9&5P96YD96YC:65S)RP-
M"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G;VYL
M>7)E<61E<',G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO
M<G1O<'0G(#T^("=O)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@
M)VEN<W1A;&P@86QL(')E<75I<F5D(&1E<&5N9&5N8VEE<R<L#0H@("`@("`@
M("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@)V]F9FQI;F4G(#T^
M(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=/
M)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)V1O(&YO="!A='1E
M;7!T('1O(&1O=VYL;V%D(&%N>2!U<FQS(&]R(&-O;G1A8W0@8VAA;FYE;',G
M+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=P
M<F5T96YD)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T
M;W!T)R`]/B`G<"<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=/
M;FQY(&QI<W0@=&AE('!A8VMA9V5S('1H870@=V]U;&0@8F4@9&]W;FQO861E
M9"<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@
M*2P-"B`@("`@("`@("`@("=D;V,G(#T^("<\<&%C:V%G93X@+BXN#0I5<&=R
M861E<R!O;F4@;W(@;6]R92!014%2('!A8VMA9V5S+B`@4V5E(&1O8W5M96YT
M871I;VX@9F]R('1H90T*(FEN<W1A;&PB(&-O;6UA;F0@9F]R('=A>7,@=&\@
M<W!E8VEF>2!A('!A8VMA9V4N#0H-"E=H96X@=7!G<F%D:6YG+"!Y;W5R('!A
M8VMA9V4@=VEL;"!B92!U<&1A=&5D(&EF('1H92!P<F]V:61E9"!N97<-"G!A
M8VMA9V4@:&%S(&$@:&EG:&5R('9E<G-I;VX@;G5M8F5R("AU<V4@=&AE("UF
M(&]P=&EO;B!I9B!Y;W4@;F5E9"!T;PT*=7!G<F%D92!A;GEW87DI+@T*#0I-
M;W)E('1H86X@;VYE('!A8VMA9V4@;6%Y(&)E('-P96-I9FEE9"!A="!O;F-E
M+@T*)RDL#0H@("`@("`@("=U<&=R861E+6%L;"<@/3X@87)R87DH#0H@("`@
M("`@("`@("`G<W5M;6%R>2<@/3X@)U5P9W)A9&4@06QL(%!A8VMA9V5S)RP-
M"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O26YS=&%L;"<L#0H@("`@
M("`@("`@("`G<VAO<G1C=70G(#T^("=U82<L#0H@("`@("`@("`@("`G;W!T
M:6]N<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@)VYO9&5P<R<@/3X@
M87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)VXG
M+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G:6=N;W)E(&1E<&5N
M9&5N8VEE<RP@=7!G<F%D92!A;GEW87DG+`T*("`@("`@("`@("`@("`@("`@
M("`I+`T*("`@("`@("`@("`@("`@("=R96=I<W1E<BUO;FQY)R`]/B!A<G)A
M>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G<B<L#0H@
M("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=D;R!N;W0@:6YS=&%L;"!F
M:6QE<RP@;VYL>2!R96=I<W1E<B!T:&4@<&%C:V%G92!A<R!U<&=R861E9"<L
M#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@)VYO
M8G5I;&0G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O
M<'0G(#T^("=")RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)V1O
M;EPG="!B=6EL9"!#(&5X=&5N<VEO;G,G+`T*("`@("`@("`@("`@("`@("`@
M("`I+`T*("`@("`@("`@("`@("`@("=N;V-O;7!R97-S)R`]/B!A<G)A>2@-
M"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G6B<L#0H@("`@
M("`@("`@("`@("`@("`@("=D;V,G(#T^("=R97%U97-T('5N8V]M<')E<W-E
M9"!F:6QE<R!W:&5N(&1O=VYL;V%D:6YG)RP-"B`@("`@("`@("`@("`@("`@
M("`@*2P-"B`@("`@("`@("`@("`@("`G:6YS=&%L;')O;W0G(#T^(&%R<F%Y
M*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=2)RP-"B`@
M("`@("`@("`@("`@("`@("`@)V%R9R<@/3X@)T1)4B<L#0H@("`@("`@("`@
M("`@("`@("`@("=D;V,G(#T^("=R;V]T(&1I<F5C=&]R>2!U<V5D('=H96X@
M:6YS=&%L;&EN9R!F:6QE<R`H86QA(%!(4%PG<R!)3E-404Q,7U)/3U0I+"!U
M<V4@<&%C:V%G:6YG<F]O="!F;W(@4E!-)RP-"B`@("`@("`@("`@("`@("`@
M("`@*2P-"B`@("`@("`@("`@("`@("`G:6=N;W)E+65R<F]R<R<@/3X@87)R
M87DH#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=F;W)C92!I;G-T
M86QL(&5V96X@:68@=&AE<F4@=V5R92!E<G)O<G,G+`T*("`@("`@("`@("`@
M("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=L;V]S92<@/3X@87)R87DH
M#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=D;R!N;W0@8VAE8VL@
M9F]R(')E8V]M;65N9&5D(&1E<&5N9&5N8WD@=F5R<VEO;B<L#0H@("`@("`@
M("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@
M("`@("=D;V,G(#T^("<-"E5P9W)A9&5S(&%L;"!P86-K86=E<R!T:&%T(&AA
M=F4@82!N97=E<B!R96QE87-E(&%V86EL86)L92X@(%5P9W)A9&5S(&%R90T*
M9&]N92!O;FQY(&EF('1H97)E(&ES(&$@<F5L96%S92!A=F%I;&%B;&4@;V8@
M=&AE('-T871E('-P96-I9FEE9"!I;@T*(G!R969E<G)E9%]S=&%T92(@*&-U
M<G)E;G1L>2![8V]N9FEG('!R969E<G)E9%]S=&%T97TI+"!O<B!A('-T871E
M(&-O;G-I9&5R960-"FUO<F4@<W1A8FQE+@T*)RDL#0H@("`@("`@("=U;FEN
M<W1A;&PG(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=5
M;BUI;G-T86QL(%!A8VMA9V4G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]
M/B`G9&]5;FEN<W1A;&PG+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G
M=6XG+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*`T*("`@("`@
M("`@("`@("`@("=N;V1E<',G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@
M("`@("`G<VAO<G1O<'0G(#T^("=N)RP-"B`@("`@("`@("`@("`@("`@("`@
M)V1O8R<@/3X@)VEG;F]R92!D97!E;F1E;F-I97,L('5N:6YS=&%L;"!A;GEW
M87DG+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@
M("=R96=I<W1E<BUO;FQY)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@
M("`@)W-H;W)T;W!T)R`]/B`G<B<L#0H@("`@("`@("`@("`@("`@("`@("=D
M;V,G(#T^("=D;R!N;W0@<F5M;W9E(&9I;&5S+"!O;FQY(')E9VES=&5R('1H
M92!P86-K86=E<R!A<R!N;W0@:6YS=&%L;&5D)RP-"B`@("`@("`@("`@("`@
M("`@("`@*2P-"B`@("`@("`@("`@("`@("`G:6YS=&%L;')O;W0G(#T^(&%R
M<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=2)RP-
M"B`@("`@("`@("`@("`@("`@("`@)V%R9R<@/3X@)T1)4B<L#0H@("`@("`@
M("`@("`@("`@("`@("=D;V,G(#T^("=R;V]T(&1I<F5C=&]R>2!U<V5D('=H
M96X@:6YS=&%L;&EN9R!F:6QE<R`H86QA(%!(4%PG<R!)3E-404Q,7U)/3U0I
M)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G
M:6=N;W)E+65R<F]R<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@
M("=D;V,G(#T^("=F;W)C92!I;G-T86QL(&5V96X@:68@=&AE<F4@=V5R92!E
M<G)O<G,G+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@
M("`@("=O9F9L:6YE)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@
M)W-H;W)T;W!T)R`]/B`G3R<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G
M(#T^("=D;R!N;W0@871T96UP="!T;R!U;FEN<W1A;&P@<F5M;W1E;'DG+`T*
M("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("DL#0H@
M("`@("`@("`@("`G9&]C)R`]/B`G6V-H86YN96PO73QP86-K86=E/B`N+BX-
M"E5N:6YS=&%L;',@;VYE(&]R(&UO<F4@4$5!4B!P86-K86=E<RX@($UO<F4@
M=&AA;B!O;F4@<&%C:V%G92!M87D@8F4-"G-P96-I9FEE9"!A="!O;F-E+B`@
M4')E9FEX('=I=&@@8VAA;FYE;"!N86UE('1O('5N:6YS=&%L;"!F<F]M(&$-
M"F-H86YN96P@;F]T(&EN('EO=7(@9&5F875L="!C:&%N;F5L("A[8V]N9FEG
M(&1E9F%U;'1?8VAA;FYE;'TI#0HG*2P-"B`@("`@("`@)V)U;F1L92<@/3X@
M87)R87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)U5N<&%C:W,@82!0
M96-L(%!A8VMA9V4G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]"
M=6YD;&4G+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G8G5N)RP-"B`@
M("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`G9&5S=&EN871I;VXG(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@
M("=S:&]R=&]P="<@/3X@)V0G+`T*("`@("`@("`@("`@("`@("`@("`G87)G
M)R`]/B`G1$E2)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)T]P
M=&EO;F%L(&1E<W1I;F%T:6]N(&1I<F5C=&]R>2!F;W(@=6YP86-K:6YG("AD
M969A=6QT<R!T;R!C=7)R96YT('!A=&@@;W(@(F5X="(@:68@97AI<W1S*2<L
M#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@)V9O
M<F-E)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T
M)R`]/B`G9B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=&;W)C
M92!T:&4@=6YP86-K:6YG(&5V96X@:68@=&AE<F4@=V5R92!E<G)O<G,@:6X@
M=&AE('!A8VMA9V4G+`T*("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@
M("`I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)SQP86-K86=E/@T*56YP86-K
M<R!A(%!E8VP@4&%C:V%G92!I;G1O('1H92!S96QE8W1E9"!L;V-A=&EO;BX@
M270@=VEL;"!D;W=N;&]A9"!T:&4-"G!A8VMA9V4@:68@;F5E9&5D+@T*)RDL
M#0H@("`@("`@("=R=6XM<V-R:7!T<R<@/3X@87)R87DH#0H@("`@("`@("`@
M("`G<W5M;6%R>2<@/3X@)U)U;B!0;W-T+4EN<W1A;&P@4V-R:7!T<R!B=6YD
M;&5D('=I=&@@82!P86-K86=E)RP-"B`@("`@("`@("`@("=F=6YC=&EO;B<@
M/3X@)V1O4G5N4V-R:7!T<R<L#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^
M("=R<R<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH#0H@("`@
M("`@("`@("`I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)SQP86-K86=E/@T*
M4G5N('!O<W0M:6YS=&%L;&%T:6]N('-C<FEP=',@:6X@<&%C:V%G92`\<&%C
M:V%G93XL(&EF(&%N>2!E>&ES="X-"B<I+`T*("`@("D[#0H-"B`@("`O+R!]
M?7T-"B`@("`O+R![>WL@8V]N<W1R=6-T;W(-"@T*("`@("\J*@T*("`@("`J
M(%!%05)?0V]M;6%N9%]);G-T86QL(&-O;G-T<G5C=&]R+@T*("`@("`J#0H@
M("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!0
M14%27T-O;6UA;F1?26YS=&%L;"@F)'5I+"`F)&-O;F9I9RD-"B`@("![#0H@
M("`@("`@('!A<F5N=#HZ4$5!4E]#;VUM86YD7T-O;6UO;B@D=6DL("1C;VYF
M:6<I.PT*("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@+RHJ#0H@("`@("H@
M1F]R('5N:70@=&5S=&EN9R!P=7)P;W-E<PT*("`@("`J+PT*("`@(&9U;F-T
M:6]N("9G971$;W=N;&]A9&5R*"8D=6DL("1O<'1I;VYS+"`F)&-O;F9I9RD-
M"B`@("![#0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27T1O=VYL
M;V%D97(G*2D@>PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+T1O
M=VYL;V%D97(N<&AP)SL-"B`@("`@("`@?0T*("`@("`@("`D82`]("9N97<@
M4$5!4E]$;W=N;&]A9&5R*"1U:2P@)&]P=&EO;G,L("1C;VYF:6<I.PT*("`@
M("`@("!R971U<FX@)&$[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@1F]R
M('5N:70@=&5S=&EN9R!P=7)P;W-E<PT*("`@("`J+PT*("`@(&9U;F-T:6]N
M("9G971);G-T86QL97(H)B1U:2D-"B`@("![#0H@("`@("`@(&EF("@A8VQA
M<W-?97AI<W1S*"=014%27TEN<W1A;&QE<B<I*2![#0H@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)U!%05(O26YS=&%L;&5R+G!H<"<[#0H@("`@("`@('T-
M"B`@("`@("`@)&$@/2`F;F5W(%!%05)?26YS=&%L;&5R*"1U:2D[#0H@("`@
M("`@(')E='5R;B`D83L-"B`@("!]#0H-"B`@("`O+R![>WL@9&]);G-T86QL
M*"D-"@T*("`@(&9U;F-T:6]N(&1O26YS=&%L;"@D8V]M;6%N9"P@)&]P=&EO
M;G,L("1P87)A;7,I#0H@("`@>PT*("`@("`@("!I9B`H96UP='DH)'1H:7,M
M/FEN<W1A;&QE<BDI('L-"B`@("`@("`@("`@("1T:&ES+3YI;G-T86QL97(@
M/2`F)'1H:7,M/F=E=$EN<W1A;&QE<B@D=&AI<RT^=6DI.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("@D8V]M;6%N9"`]/2`G=7!G<F%D92<I('L-"B`@("`@
M("`@("`@("1O<'1I;VYS6R=U<&=R861E)UT@/2!T<G5E.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG:6YS=&%L;')O;W0G72D@
M)B8@:7-S970H)&]P=&EO;G-;)W!A8VMA9VEN9W)O;W0G72DI('L-"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G15)23U(Z(&-A;FYO
M="!U<V4@8F]T:"`M+6EN<W1A;&QR;V]T(&%N9"`M+7!A8VMA9VEN9W)O;W0G
M*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W!A
M8VMA9VEN9W)O;W0G72D@)B8@)'1H:7,M/F-O;F9I9RT^9V5T*"=V97)B;W-E
M)RD@/B`R*2![#0H@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H
M)W5S:6YG('!A8VMA9V4@<F]O=#H@)R`N("1O<'1I;VYS6R=P86-K86=I;F=R
M;V]T)UTI.PT*("`@("`@("!]#0H@("`@("`@("1R96<@/2`F)'1H:7,M/F-O
M;F9I9RT^9V5T4F5G:7-T<GDH*3L-"B`@("`@("`@:68@*"1C;VUM86YD(#T]
M("=U<&=R861E+6%L;"<I('L-"B`@("`@("`@("`@("1O<'1I;VYS6R=U<&=R
M861E)UT@/2!T<G5E.PT*("`@("`@("`@("`@)')E9R`]("8D=&AI<RT^8V]N
M9FEG+3YG971296=I<W1R>2@I.PT*("`@("`@("`@("`@)'-A=F5C:&%N;F5L
M(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=D969A=6QT7V-H86YN96PG*3L-"B`@
M("`@("`@("`@("1P87)A;7,@/2!A<G)A>2@I.PT*("`@("`@("`@("`@9F]R
M96%C:"`H)')E9RT^;&ES=$-H86YN96QS*"D@87,@)&-H86YN96PI('L-"B`@
M("`@("`@("`@("`@("!I9B`H)&-H86YN96P@/3T@)U]?=7)I)RD@>PT*("`@
M("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/F-O;F9I9RT^<V5T*"=D969A=6QT
M7V-H86YN96PG+"`D8VAA;FYE;"D[#0H@("`@("`@("`@("`@("`@)&-H86X@
M/2`F)')E9RT^9V5T0VAA;FYE;"@D8VAA;FYE;"D[#0H@("`@("`@("`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)&-H86XI*2![#0H@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D8VAA;BD[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D8VAA;BT^<W5P
M<&]R='-215-4*"1T:&ES+3YC;VYF:6<M/F=E="@G<')E9F5R<F5D7VUI<G)O
M<B<I*2`F)@T*("`@("`@("`@("`@("`@("`@("`@("1B87-E(#T@)&-H86XM
M/F=E=$)A<V554DPH)U)%4U0Q+C`G+"`D=&AI<RT^8V]N9FEG+3YG970H)W!R
M969E<G)E9%]M:7)R;W(G*2DI('L-"B`@("`@("`@("`@("`@("`@("`@)&1O
M<F5S="`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@('5N<V5T*"1R96UO
M=&4I.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@("`@("1D;W)E<W0@/2!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@
M)')E;6]T92`]("8D=&AI<RT^8V]N9FEG+3YG971296UO=&4H)'1H:7,M/F-O
M;F9I9RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1S
M=&%T92`]("1T:&ES+3YC;VYF:6<M/F=E="@G<')E9F5R<F5D7W-T871E)RD[
M#0H@("`@("`@("`@("`@("`@)&EN<W1A;&QE9"`](&%R<F%Y7V9L:7`H)')E
M9RT^;&ES=%!A8VMA9V5S*"1C:&%N;F5L*2D[#0H@("`@("`@("`@("`@("`@
M4$5!4CHZ<W1A=&EC4'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]21515
M4DXI.PT*("`@("`@("`@("`@("`@(&EF("@D9&]R97-T*2![#0H@("`@("`@
M("`@("`@("`@("`@("1R97-T(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)%4U0H
M)S$N,"<L(&%R<F%Y*"DI.PT*("`@("`@("`@("`@("`@("`@("`D;&%T97-T
M(#T@)')E<W0M/FQI<W1,871E<W15<&=R861E<R@D8F%S92P@)'-T871E+"`D
M:6YS=&%L;&5D+"`D8VAA;FYE;"P@)')E9RD[#0H@("`@("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1S=&%T
M92D@?'P@)'-T871E(#T]("=A;GDG*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D;&%T97-T(#T@)')E;6]T92T^8V%L;"@B<&%C:V%G92YL:7-T3&%T
M97-T4F5L96%S97,B*3L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1L871E<W0@/2`D<F5M;W1E+3YC
M86QL*")P86-K86=E+FQI<W1,871E<W1296QE87-E<R(L("1S=&%T92D[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@4$5!4CHZ<W1A=&EC4&]P17)R;W)(86YD;&EN9R@I.PT*
M("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1L871E<W0I('Q\
M("%I<U]A<G)A>2@D;&%T97-T*2D@>PT*("`@("`@("`@("`@("`@("`@("!C
M;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)&QA=&5S="!A<R`D<&%C:V%G92`]/B`D:6YF;RD@>PT*("`@
M("`@("`@("`@("`@("`@("`D<&%C:V%G92`]('-T<G1O;&]W97(H)'!A8VMA
M9V4I.PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86QL
M961;)'!A8VMA9V5=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M<VMI<"!P86-K86=E<R!W92!D;VXG="!H879E(&EN<W1A;&QE9`T*("`@("`@
M("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@)&EN<W1?=F5R<VEO;B`]("1R
M96<M/G!A8VMA9V5);F9O*"1P86-K86=E+"`G=F5R<VEO;B<L("1C:&%N;F5L
M*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92@B
M)&EN9F];=F5R<VEO;ETB+"`B)&EN<W1?=F5R<VEO;B(L(")L92(I*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`O+R!I;G-T86QL960@=F5R<VEO;B!I
M<R!U<"UT;RUD871E#0H@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU
M93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`D<&%R86US6UT@/2`D<F5G+3YP87)S961086-K86=E3F%M951O4W1R:6YG
M*&%R<F%Y*"=P86-K86=E)R`]/B`D<&%C:V%G92P-"B`@("`@("`@("`@("`@
M("`@("`@("`@("=C:&%N;F5L)R`]/B`D8VAA;FYE;"DI.PT*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H87)R87DH)V1A=&$G
M(#T^(")7:6QL('5P9W)A9&4@)'!A8VMA9V4B*2P@)&-O;6UA;F0I.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1T
M:&ES+3YC;VYF:6<M/G-E="@G9&5F875L=%]C:&%N;F5L)RP@)'-A=F5C:&%N
M;F5L*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^9&]W;FQO861E<B`]
M("8D=&AI<RT^9V5T1&]W;FQO861E<B@D=&AI<RT^=6DL("1O<'1I;VYS+"`D
M=&AI<RT^8V]N9FEG*3L-"B`@("`@("`@)&5R<F]R<R`](&%R<F%Y*"D[#0H@
M("`@("`@("1D;W=N;&]A9&5D(#T@87)R87DH*3L-"B`@("`@("`@)&1O=VYL
M;V%D960@/2`F)'1H:7,M/F1O=VYL;V%D97(M/F1O=VYL;V%D*"1P87)A;7,I
M.PT*("`@("`@("`D97)R;W)S(#T@)'1H:7,M/F1O=VYL;V%D97(M/F=E=$5R
M<F]R37-G<R@I.PT*("`@("`@("!I9B`H8V]U;G0H)&5R<F]R<RDI('L-"B`@
M("`@("`@("`@(&9O<F5A8V@@*"1E<G)O<G,@87,@)&5R<F]R*2![#0H@("`@
M("`@("`@("`@("`@)&5R<ELG9&%T82==6UT@/2!A<G)A>2@D97)R;W(I.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&5R<ELG:&5A9&QI;F4G72`]
M("=);G-T86QL($5R<F]R<R<[#0H@("`@("`@("`@("`D=&AI<RT^=6DM/F]U
M='!U=$1A=&$H)&5R<BD[#0H@("`@("`@("`@("!I9B`H(6-O=6YT*"1D;W=N
M;&]A9&5D*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@B)&-O;6UA;F0@9F%I;&5D(BD[#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("`@("`@)&1A=&$@/2!A<G)A>2@-"B`@("`@("`@("`@
M("=H96%D;&EN92<@/3X@)U!A8VMA9V5S('1H870@=V]U;&0@8F4@26YS=&%L
M;&5D)PT*("`@("`@("`I.PT*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;
M)W!R971E;F0G72DI('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1D;W=N;&]A
M9&5D(&%S("1P86-K86=E*2![#0H@("`@("`@("`@("`@("`@)&1A=&%;)V1A
M=&$G75M=(#T@87)R87DH)')E9RT^<&%R<V5D4&%C:V%G94YA;654;U-T<FEN
M9R@D<&%C:V%G92T^9V5T4&%R<V5D4&%C:V%G92@I*2D[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)&1A=&$L
M("=P<F5T96YD)RD[#0H@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@
M("`@?0T*("`@("`@("`D=&AI<RT^:6YS=&%L;&5R+3YS971/<'1I;VYS*"1O
M<'1I;VYS*3L-"B`@("`@("`@)'1H:7,M/FEN<W1A;&QE<BT^<V]R=%!A8VMA
M9V5S1F]R26YS=&%L;"@D9&]W;FQO861E9"D[#0H@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1E<G(@/2`D=&AI<RT^:6YS=&%L;&5R+3YS971$;W=N;&]A
M9&5D4&%C:V%G97,H)&1O=VYL;V%D960I*2D@>PT*("`@("`@("`@("`@)'1H
M:7,M/G)A:7-E17)R;W(H)&5R<BT^9V5T365S<V%G92@I*3L-"B`@("`@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@("`@("`@("1E>'1R86EN
M9F\@/2!A<G)A>2@I.PT*("`@("`@("!F;W)E86-H("@D9&]W;FQO861E9"!A
M<R`D<&%R86TI('L-"B`@("`@("`@("`@(%!%05(Z.G-T871I8U!U<VA%<G)O
M<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@("`@("1I
M;F9O(#T@)'1H:7,M/FEN<W1A;&QE<BT^:6YS=&%L;"@D<&%R86TL("1O<'1I
M;VYS*3L-"B`@("`@("`@("`@(%!%05(Z.G-T871I8U!O<$5R<F]R2&%N9&QI
M;F<H*3L-"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1I;F9O*2D@
M>PT*("`@("`@("`@("`@("`@("1O;&1I;F9O(#T@)&EN9F\[#0H@("`@("`@
M("`@("`@("`@)'!K9R`]("8D<&%R86TM/F=E=%!A8VMA9V5&:6QE*"D[#0H@
M("`@("`@("`@("`@("`@:68@*"1I;F9O+3YG971#;V1E*"D@(3T@4$5!4E])
M3E-404Q,15)?3D]"24Y!4EDI('L-"B`@("`@("`@("`@("`@("`@("`@:68@
M*"$H)&EN9F\@/2`D<&MG+3YI;G-T86QL0FEN87)Y*"1T:&ES+3YI;G-T86QL
M97(I*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G5I+3YO
M=71P=71$871A*"=%4E)/4CH@)R`N)&]L9&EN9F\M/F=E=$UE<W-A9V4H*2D[
M#0H@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`O+R!W92!J=7-T
M(&EN<W1A;&QE9"!A(&1I9F9E<F5N="!P86-K86=E('1H86X@<F5Q=65S=&5D
M+`T*("`@("`@("`@("`@("`@("`@("`O+R!L970G<R!C:&%N9V4@=&AE('!A
M<F%M(&%N9"!I;F9O('-O('1H870@=&AE(')E<W0@;V8@=&AI<R!W;W)K<PT*
M("`@("`@("`@("`@("`@("`@("`D<&%R86T@/2`D:6YF;ULP73L-"B`@("`@
M("`@("`@("`@("`@("`@)&EN9F\@/2`D:6YF;ULQ73L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-?87)R
M87DH)&EN9F\I*2![#0H@("`@("`@("`@("`@("`@:68@*"1P87)A;2T^9V5T
M4&%C:V%G951Y<&4H*2`]/2`G97AT<W)C)R!\?`T*("`@("`@("`@("`@("`@
M("`@("`@("1P87)A;2T^9V5T4&%C:V%G951Y<&4H*2`]/2`G97AT8FEN)RD@
M>PT*("`@("`@("`@("`@("`@("`@("`D<&MG(#T@)B1P87)A;2T^9V5T4&%C
M:V%G949I;&4H*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1I;G-T8FEN
M(#T@)'!K9RT^9V5T26YS=&%L;&5D0FEN87)Y*"DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1I;G-T<&MG(#T@)B1R96<M/F=E=%!A8VMA9V4H)&EN
M<W1B:6XL("1P:V<M/F=E=$-H86YN96PH*2D[#0H@("`@("`@("`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`D:6YS='!K
M9R`]("8D<F5G+3YG971086-K86=E*"1P:V<M/F=E=%!A8VMA9V4H*2P@)'!K
M9RT^9V5T0VAA;FYE;"@I*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("!F;W)E86-H("@D:6YS='!K9RT^9V5T1FEL96QI
M<W0H*2!A<R`D;F%M92`]/B`D871T<RD@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)'!I;F9O(#T@<&%T:&EN9F\H)&%T='-;)VEN<W1A;&QE9%]A<R==
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'!I;F9O
M6R=E>'1E;G-I;VXG72D@?'P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EN7V%R<F%Y*"1P:6YF;ULG97AT96YS:6]N)UTL(&%R<F%Y*"=C)RP@
M)V@G*2DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU
M93L@+R\@;6%K92!S=7)E('=E(&1O;B=T(&UA=&-H('!H<%]B;&%H+F@-"B`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@H<W1R<&]S*"1P:6YF;ULG8F%S96YA;64G72P@)W!H<%\G*2`]
M/3T@,"`F)@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!I;F9O
M6R=E>'1E;G-I;VXG72`]/2`G9&QL)RD@?'P-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("\O(&UO<W0@=6YI8V5S#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<&EN9F];)V5X=&5N<VEO;B==(#T]("=S;R<@?'P-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(&AP+75X#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<&EN9F];)V5X=&5N<VEO;B==
M(#T]("=S;"<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D97AT
M<F%I;F9O6UT@/2`G66]U('-H;W5L9"!A9&0@(F5X=&5N<VEO;CTG("X@)'!I
M;F9O6R=B87-E;F%M92==#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("X@)R(@=&\@<&AP+FEN:2<[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@:68@*"1T:&ES+3YC;VYF:6<M/F=E="@G=F5R8F]S92<I(#X@
M,"D@>PT*("`@("`@("`@("`@("`@("`@("`D8VAA;FYE;"`]("1P87)A;2T^
M9V5T0VAA;FYE;"@I.PT*("`@("`@("`@("`@("`@("`@("`D;&%B96P@/2`D
M<F5G+3YP87)S961086-K86=E3F%M951O4W1R:6YG*`T*("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V-H86YN96PG(#T^("1C:&%N;F5L+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=P86-K86=E)R`]/B`D<&%R86TM/F=E=%!A8VMA9V4H*2P-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=F5R<VEO;B<@/3X@)'!A
M<F%M+3YG971697)S:6]N*"DL#0H@("`@("`@("`@("`@("`@("`@("`@("`I
M*3L-"B`@("`@("`@("`@("`@("`@("`@)&]U="`](&%R<F%Y*"=D871A)R`]
M/B`B)&-O;6UA;F0@;VLZ("1L86)E;"(I.PT*("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)&EN9F];)W)E;&5A<V5?=V%R;FEN9W,G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1O=71;)W)E;&5A<V5?=V%R;FEN9W,G
M72`]("1I;F9O6R=R96QE87-E7W=A<FYI;F=S)UT[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P
M=71$871A*"1O=70L("1C;VUM86YD*3L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*"%I<W-E="@D;W!T:6]N<ULG<F5G:7-T97(M;VYL>2==*2`F)B`A:7-S
M970H)&]P=&EO;G-;)V]F9FQI;F4G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@D=&AI<RT^8V]N9FEG+3YI<T1E9FEN961,87EE<B@G9G1P
M)RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!014%2.CIS=&%T
M:6-0=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F\@/2`D=&AI<RT^:6YS=&%L
M;&5R+3YF='!);G-T86QL*"1P87)A;2D[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@4$5!4CHZ<W1A=&EC4&]P17)R;W)(86YD;&EN9R@I.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1I
M;F9O*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^=6DM/F]U='!U=$1A=&$H)&EN9F\M/F=E=$UE<W-A9V4H*2D[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T
M1&%T82@B<F5M;W1E(&EN<W1A;&P@9F%I;&5D.B`D;&%B96PB*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H(G)E
M;6]T92!I;G-T86QL(&]K.B`D;&%B96PB*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@)&1E<',@/2`D<&%R86TM/F=E=$1E<',H*3L-"B`@("`@("`@
M("`@("`@("!I9B`H)&1E<',I('L-"B`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1D97!S6R=G<F]U<"==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)&=R;W5P<R`]("1D97!S6R=G<F]U<"==.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D9W)O=7!S6S!=*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1G<F]U<',@/2!A<G)A>2@D9W)O=7!S
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1G<F]U<',@87,@)&=R;W5P*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1G<F]U<%LG871T<FEB<R==
M6R=N86UE)UT@/3T@)V1E9F%U;'0G*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("\O(&1E9F%U;'0@9W)O=7`@:7,@86QW87ES(&EN<W1A
M;&QE9"P@=6YL97-S('1H92!U<V5R#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("\O(&5X<&QI8VET;'D@8VAO;W-E<R!T;R!I;G-T86QL(&%N
M;W1H97(@9W)O=7`-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T
M82@D<&%R86TM/F=E=%!A8VMA9V4H*2`N("<Z($]P=&EO;F%L(&9E871U<F4@
M)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1G<F]U<%LG
M871T<FEB<R==6R=N86UE)UT@+B`G(&%V86EL86)L92`H)R`N#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1G<F]U<%LG871T<FEB<R==6R=H
M:6YT)UT@+B`G*2<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`@("`@)&5X=')A:6YF;UM=(#T@)U1O(&EN<W1A
M;&P@=7-E(")P96%R(&EN<W1A;&P@)R`N#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)')E9RT^<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9R@-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W!A8VMA9V4G
M(#T^("1P87)A;2T^9V5T4&%C:V%G92@I+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G8VAA;FYE;"<@/3X@)'!A<F%M+3YG971#
M:&%N;F5L*"DI+"!T<G5E*2`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)R-F96%T=7)E;F%M92(G.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D;W!T:6]N<ULG:6YS=&%L;')O;W0G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@)')E9R`]("8D=&AI<RT^8V]N9FEG+3YG971296=I<W1R>2@I
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D<&MG(#T@
M)B1R96<M/F=E=%!A8VMA9V4H)'!A<F%M+3YG971086-K86=E*"DL("1P87)A
M;2T^9V5T0VAA;FYE;"@I*3L-"B`@("`@("`@("`@("`@("`O+R`D<&MG(&UA
M>2!B92!.54Q,(&EF(&EN<W1A;&P@:7,@82`G9F%K92<@:6YS=&%L;"!V:6$@
M+2UP86-K86=I;F=R;V]T#0H@("`@("`@("`@("`@("`@:68@*&ES7V]B:F5C
M="@D<&MG*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<&MG+3YS971#;VYF
M:6<H)'1H:7,M/F-O;F9I9RD[#0H@("`@("`@("`@("`@("`@("`@(&EF("@D
M;&ES="`]("1P:V<M/FQI<W10;W-T:6YS=&%L;%-C<FEP=',H*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)'!N(#T@)')E9RT^<&%R<V5D4&%C:V%G
M94YA;654;U-T<FEN9RAA<G)A>2@G8VAA;FYE;"<@/3X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P87)A;2T^9V5T0VAA;FYE;"@I+"`G<&%C:V%G
M92<@/3X@)'!A<F%M+3YG971086-K86=E*"DI+"!T<G5E*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1E>'1R86EN9F];72`]("1P;B`N("<@:&%S('!O
M<W0M:6YS=&%L;"!S8W)I<'1S.B<[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!F;W)E86-H("@D;&ES="!A<R`D9FEL92D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1E>'1R86EN9F];72`]("1F:6QE.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@)&5X
M=')A:6YF;UM=(#T@)U5S92`B<&5A<B!R=6XM<V-R:7!T<R`G("X@)'!N("X@
M)R(@=&\@<G5N)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("1E>'1R86EN
M9F];72`]("=$3R!.3U0@4E5.(%-#4DE05%,@1E)/32!53E1255-4140@4T]5
M4D-%4R<[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B)&-O;6UA;F0@9F%I;&5D(BD[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&-O=6YT*"1E
M>'1R86EN9F\I*2![#0H@("`@("`@("`@("!F;W)E86-H("@D97AT<F%I;F9O
M(&%S("1I;F9O*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P
M=71$871A*"1I;F9O*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O
M+R![>WL@9&]5;FEN<W1A;&PH*0T*#0H@("`@9G5N8W1I;VX@9&]5;FEN<W1A
M;&PH)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@
M("`@:68@*&5M<'1Y*"1T:&ES+3YI;G-T86QL97(I*2![#0H@("`@("`@("`@
M("`D=&AI<RT^:6YS=&%L;&5R(#T@)B1T:&ES+3YG971);G-T86QL97(H)'1H
M:7,M/G5I*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&]P=&EO
M;G-;)W)E;6]T96-O;F9I9R==*2D@>PT*("`@("`@("`@("`@)&4@/2`D=&AI
M<RT^8V]N9FEG+3YR96%D1E100V]N9FEG1FEL92@D;W!T:6]N<ULG<F5M;W1E
M8V]N9FEG)UTI.PT*("`@("`@("`@("`@:68@*"%014%2.CII<T5R<F]R*"1E
M*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3YI;G-T86QL97(M/G-E=$-O
M;F9I9R@D=&AI<RT^8V]N9FEG*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H<VEZ96]F*"1P87)A;7,I(#P@,2D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")0;&5A<V4@<W5P<&QY
M('1H92!P86-K86=E*',I('EO=2!W86YT('1O('5N:6YS=&%L;"(I.PT*("`@
M("`@("!]#0H@("`@("`@("1R96<@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G
M:7-T<GDH*3L-"B`@("`@("`@)&YE=W!A<F%M<R`](&%R<F%Y*"D[#0H@("`@
M("`@("1B861P87)A;7,@/2!A<G)A>2@I.PT*("`@("`@("!F;W)E86-H("@D
M<&%R86US(&%S("1P:V<I('L-"B`@("`@("`@("`@("1C:&%N;F5L(#T@)'1H
M:7,M/F-O;F9I9RT^9V5T*"=D969A=6QT7V-H86YN96PG*3L-"B`@("`@("`@
M("`@(%!%05(Z.G-T871I8U!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?
M4D5455).*3L-"B`@("`@("`@("`@("1P87)S960@/2`D<F5G+3YP87)S95!A
M8VMA9V5.86UE*"1P:V<L("1C:&%N;F5L*3L-"B`@("`@("`@("`@(%!%05(Z
M.G-T871I8U!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@(&EF("@A
M)'!A<G-E9"!\?"!014%2.CII<T5R<F]R*"1P87)S960I*2![#0H@("`@("`@
M("`@("`@("`@)&)A9'!A<F%M<UM=(#T@)'!K9SL-"B`@("`@("`@("`@("`@
M("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1P86-K
M86=E(#T@)'!A<G-E9%LG<&%C:V%G92==.PT*("`@("`@("`@("`@)&-H86YN
M96P@/2`D<&%R<V5D6R=C:&%N;F5L)UT[#0H@("`@("`@("`@("`D:6YF;R`]
M("8D<F5G+3YG971086-K86=E*"1P86-K86=E+"`D8VAA;FYE;"D[#0H@("`@
M("`@("`@("!I9B`H)&EN9F\@/3T](&YU;&P@)B8-"B`@("`@("`@("`@("`@
M("`@*"1C:&%N;F5L(#T]("=P96%R+G!H<"YN970G('Q\("1C:&%N;F5L(#T]
M("=P96-L+G!H<"YN970G*2D@>PT*("`@("`@("`@("`@("`@("\O(&UA:V4@
M<W5R92!T:&ES(&ES;B=T(&$@<&%C:V%G92!T:&%T(&AA<R!F;&EP<&5D(&9R
M;VT@<&5A<B!T;R!P96-L(&)U=`T*("`@("`@("`@("`@("`@("\O('5S960@
M82!P86-K86=E+GAM;"`Q+C`-"B`@("`@("`@("`@("`@("`D=&5S=&,@/2`H
M)&-H86YN96P@/3T@)W!E87(N<&AP+FYE="<I(#\@)W!E8VPN<&AP+FYE="<@
M.B`G<&5A<BYP:'`N;F5T)SL-"B`@("`@("`@("`@("`@("`D:6YF;R`]("8D
M<F5G+3YG971086-K86=E*"1P86-K86=E+"`D=&5S=&,I.PT*("`@("`@("`@
M("`@("`@(&EF("@D:6YF;R`A/3T@;G5L;"D@>PT*("`@("`@("`@("`@("`@
M("`@("`D8VAA;FYE;"`]("1T97-T8SL-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)&EN9F\@/3T](&YU;&PI
M('L-"B`@("`@("`@("`@("`@("`D8F%D<&%R86US6UT@/2`D<&MG.PT*("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D;F5W<&%R86US
M6UT@/2`F)&EN9F\[#0H@("`@("`@("`@("`@("`@+R\@8VAE8VL@9F]R(&)I
M;F%R>2!P86-K86=E<R`H=&AI<R!I<R!A;B!A;&EA<R!F;W(@=&AO<V4@<&%C
M:V%G97,@:68@<V\I#0H@("`@("`@("`@("`@("`@:68@*"1I;G-T86QL961B
M:6YA<GD@/2`D:6YF;RT^9V5T26YS=&%L;&5D0FEN87)Y*"DI('L-"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/G5I+3YL;V<H)V%D9&EN9R!B:6YA<GD@
M<&%C:V%G92`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("1R96<M/G!A
M<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H87)R87DH)V-H86YN96PG(#T^("1C
M:&%N;F5L+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P86-K86=E
M)R`]/B`D:6YS=&%L;&5D8FEN87)Y*2P@=')U92DI.PT*("`@("`@("`@("`@
M("`@("`@("`D;F5W<&%R86US6UT@/2`F)')E9RT^9V5T4&%C:V%G92@D:6YS
M=&%L;&5D8FEN87)Y+"`D8VAA;FYE;"D[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("\O(&%D9"!T:&4@8V]N=&5N=',@;V8@82!D97!E
M;F1E;F-Y(&=R;W5P('1O('1H92!L:7-T(&]F(&EN<W1A;&QE9"!P86-K86=E
M<PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<&%R<V5D6R=G<F]U<"==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`D9W)O=7`@/2`D:6YF;RT^9V5T
M1&5P96YD96YC>4=R;W5P*"1P87)S961;)V=R;W5P)UTI.PT*("`@("`@("`@
M("`@("`@("`@("!I9B`H)&=R;W5P*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D:6YS=&%L;&5D(#T@)B1R96<M/F=E=$EN<W1A;&QE9$=R;W5P*"1G
M<F]U<"D[#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&EN<W1A;&QE
M9"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1I
M;G-T86QL960@87,@)&D@/3X@)'`I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&YE=W!A<F%M<UM=(#T@)B1I;G-T86QL961;)&E=.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D
M97)R(#T@)'1H:7,M/FEN<W1A;&QE<BT^<V]R=%!A8VMA9V5S1F]R56YI;G-T
M86QL*"1N97=P87)A;7,I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M97)R*2D@>PT*("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"1E
M<G(M/F=E=$UE<W-A9V4H*2P@)&-O;6UA;F0I.PT*("`@("`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@)'!A<F%M<R`]("1N97=P
M87)A;7,[#0H@("`@("`@("\O('1W:7-T('1H:7,@=&\@=7-E(&ET('1O(&-H
M96-K(&]N('=H971H97(@9&5P96YD96YT('!A8VMA9V5S(&%R92!A;'-O(&)E
M:6YG('5N:6YS=&%L;&5D#0H@("`@("`@("\O(&9O<B!C:7)C=6QA<B!D97!E
M;F1E;F-I97,@;&EK92!S=6)P86-K86=E<PT*("`@("`@("`D=&AI<RT^:6YS
M=&%L;&5R+3YS9715;FEN<W1A;&Q086-K86=E<R@D;F5W<&%R86US*3L-"B`@
M("`@("`@)'!A<F%M<R`](&%R<F%Y7VUE<F=E*"1P87)A;7,L("1B861P87)A
M;7,I.PT*("`@("`@("!F;W)E86-H("@D<&%R86US(&%S("1P:V<I('L-"B`@
M("`@("`@("`@("1T:&ES+3YI;G-T86QL97(M/G!U<VA%<G)O<DAA;F1L:6YG
M*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@("`@(&EF("@D97)R(#T@
M)'1H:7,M/FEN<W1A;&QE<BT^=6YI;G-T86QL*"1P:V<L("1O<'1I;VYS*2D@
M>PT*("`@("`@("`@("`@("`@("1T:&ES+3YI;G-T86QL97(M/G!O<$5R<F]R
M2&%N9&QI;F<H*3L-"B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D97)R*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=6DM/F]U
M='!U=$1A=&$H)&5R<BT^9V5T365S<V%G92@I+"`D8V]M;6%N9"D[#0H@("`@
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`D<V%V97!K9R`]("1P:V<[#0H@("`@("`@("`@
M("`@("`@:68@*"1T:&ES+3YC;VYF:6<M/F=E="@G=F5R8F]S92<I(#X@,"D@
M>PT*("`@("`@("`@("`@("`@("`@("!I9B`H:7-?;V)J96-T*"1P:V<I*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D<&MG(#T@)')E9RT^<&%R<V5D
M4&%C:V%G94YA;654;U-T<FEN9R@D<&MG*3L-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A
M=&$H(G5N:6YS=&%L;"!O:SH@)'!K9R(L("1C;VUM86YD*3L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N
M<ULG;V9F;&EN92==*2`F)B!I<U]O8FIE8W0H)'-A=F5P:V<I("8F#0H@("`@
M("`@("`@("`@("`@("`@("`@9&5F:6YE9"@G4$5!4E]214U/5$5)3E-404Q,
M7T]+)RDI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YC;VYF
M:6<M/FES1&5F:6YE9$QA>65R*"=F='`G*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/FEN<W1A;&QE<BT^<'5S:$5R<F]R2&%N9&QI;F<H
M4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M)&EN9F\@/2`D=&AI<RT^:6YS=&%L;&5R+3YF='!5;FEN<W1A;&PH)'-A=F5P
M:V<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FEN<W1A;&QE
M<BT^<&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)&EN9F\I*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"1I;F9O+3YG
M971-97-S86=E*"DI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YU:2T^;W5T<'5T1&%T82@B<F5M;W1E('5N:6YS=&%L;"!F86EL960Z
M("1P:V<B*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$
M871A*")R96UO=&4@=6YI;G-T86QL(&]K.B`D<&MG(BD[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("1T:&ES+3YI;G-T86QL97(M/G!O<$5R<F]R2&%N9&QI;F<H*3L-
M"B`@("`@("`@("`@("`@("!I9B`H:7-?;V)J96-T*"1P:V<I*2![#0H@("`@
M("`@("`@("`@("`@("`@("1P:V<@/2`D<F5G+3YP87)S961086-K86=E3F%M
M951O4W1R:6YG*"1P:V<I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(G5N:6YS=&%L;"!F
M86EL960Z("1P:V<B*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*#0H@
M("`@+R\@?7U]#0H@("`@+R\@>WM[(&1O0G5N9&QE*"D-"B`@("`O*@T*("`@
M("AC;W@I($ET(&IU<W0@9&]W;FQO861S(&%N9"!U;G1A<G,@=&AE('!A8VMA
M9V4L(&1O97,@;F]T(&1O#0H@("`@("`@("`@("!A;GD@8VAE8VL@=&AA="!T
M:&4@4$5!4E]);G-T86QL97(Z.E]I;G-T86QL1FEL92@I(&1O97,N#0H@("`@
M*B\-"@T*("`@(&9U;F-T:6]N(&1O0G5N9&QE*"1C;VUM86YD+"`D;W!T:6]N
M<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@("1D;W=N;&]A9&5R(#T@)B1T
M:&ES+3YG971$;W=N;&]A9&5R*"1T:&ES+3YU:2P@87)R87DH)V9O<F-E)R`]
M/B!T<G5E+"`G;F]D97!S)R`]/B!T<G5E+`T*("`@("`@("`@("`@)W-O9G0G
M(#T^('1R=64I+"`D=&AI<RT^8V]N9FEG*3L-"B`@("`@("`@)')E9R`]("8D
M=&AI<RT^8V]N9FEG+3YG971296=I<W1R>2@I.PT*("`@("`@("!I9B`H<VEZ
M96]F*"1P87)A;7,I(#P@,2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*")0;&5A<V4@<W5P<&QY('1H92!P86-K86=E('EO=2!W
M86YT('1O(&)U;F1L92(I.PT*("`@("`@("!]#0H-"B`@("`@("`@:68@*&ES
M<V5T*"1O<'1I;VYS6R=D97-T:6YA=&EO;B==*2D@>PT*("`@("`@("`@("`@
M:68@*"%I<U]D:7(H)&]P=&EO;G-;)V1E<W1I;F%T:6]N)UTI*2![#0H@("`@
M("`@("`@("`@("`@4WES=&5M.CIM:V1I<B@G+7`@)R`N("1O<'1I;VYS6R=D
M97-T:6YA=&EO;B==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1D
M97-T(#T@<F5A;'!A=&@H)&]P=&EO;G-;)V1E<W1I;F%T:6]N)UTI.PT*("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'!W9"`](&=E=&-W9"@I.PT*
M("`@("`@("`@("`@:68@*&ES7V1I<B@D<'=D("X@1$E214-43U)97U-%4$%2
M051/4B`N("=E>'0G*2D@>PT*("`@("`@("`@("`@("`@("1D97-T(#T@)'!W
M9"`N($1)4D5#5$]265]315!!4D%43U(@+B`G97AT)SL-"B`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@)&1E<W0@/2`D<'=D.PT*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1D;W=N;&]A9&5R+3YS
M971$;W=N;&]A9$1I<B@D9&5S="D[#0H@("`@("`@("1R97-U;'0@/2`F)&1O
M=VYL;V%D97(M/F1O=VYL;V%D*&%R<F%Y*"1P87)A;7-;,%TI*3L-"B`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)')E<W5L="DI('L-"B`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PT*("`@("`@("!]#0H@("`@("`@("1P:V=F:6QE
M(#T@)B1R97-U;'1;,%TM/F=E=%!A8VMA9V5&:6QE*"D[#0H@("`@("`@("1P
M:V=N86UE(#T@)'!K9V9I;&4M/F=E=$YA;64H*3L-"B`@("`@("`@)'!K9W9E
M<G-I;VX@/2`D<&MG9FEL92T^9V5T5F5R<VEO;B@I.PT*#0H@("`@("`@("\O
M(%5N<&%C:VEN9R`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM#0H@("`@("`@("1D97-T("X]($1)4D5#5$]265]3
M15!!4D%43U(@+B`D<&MG;F%M93L-"B`@("`@("`@)&]R:6<@/2`D<&MG;F%M
M92`N("<M)R`N("1P:V=V97)S:6]N.PT*#0H@("`@("`@("1T87(@/2`F;F5W
M($%R8VAI=F5?5&%R*"1P:V=F:6QE+3YG971!<F-H:79E1FEL92@I*3L-"B`@
M("`@("`@:68@*"%`)'1A<BT^97AT<F%C=$UO9&EF>2@D9&5S="P@)&]R:6<I
M*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)W5N
M86)L92!T;R!U;G!A8VL@)R`N("1P:V=F:6QE+3YG971!<F-H:79E1FEL92@I
M*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H
M(E!A8VMA9V4@<F5A9'D@870@)R1D97-T)R(I.PT*("`@("\O('U]?0T*("`@
M('T-"@T*("`@("\O('U]?0T*#0H@("`@9G5N8W1I;VX@9&]2=6Y38W)I<'1S
M*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@
M(&EF("@A:7-S970H)'!A<F%M<ULP72DI('L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@G<G5N+7-C<FEP=',@97AP96-T<R`Q('!A
M<F%M971E<CH@82!P86-K86=E(&YA;64G*3L-"B`@("`@("`@?0T*("`@("`@
M("`D<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@
M("`@(%!%05(Z.G-T871I8U!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?
M4D5455).*3L-"B`@("`@("`@)'!A<G-E9"`]("1R96<M/G!A<G-E4&%C:V%G
M94YA;64H)'!A<F%M<ULP72P@)'1H:7,M/F-O;F9I9RT^9V5T*"=D969A=6QT
M7V-H86YN96PG*2D[#0H@("`@("`@(%!%05(Z.G-T871I8U!O<$5R<F]R2&%N
M9&QI;F<H*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'!A<G-E9"DI
M('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D<&%R
M<V5D*3L-"B`@("`@("`@?0T*("`@("`@("`D<&%C:V%G92`]("8D<F5G+3YG
M971086-K86=E*"1P87)S961;)W!A8VMA9V4G72P@)'!A<G-E9%LG8VAA;FYE
M;"==*3L-"B`@("`@("`@:68@*&ES7V]B:F5C="@D<&%C:V%G92DI('L-"B`@
M("`@("`@("`@("1P86-K86=E+3YS971#;VYF:6<H)'1H:7,M/F-O;F9I9RD[
M#0H@("`@("`@("`@("`D<&%C:V%G92T^<G5N4&]S=&EN<W1A;&Q38W)I<'1S
M*"D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H)T-O=6QD(&YO="!R971R:65V92!P86-K86=E("(G
M("X@)'!A<F%M<ULP72`N("<B(&9R;VT@<F5G:7-T<GDG*3L-"B`@("`@("`@
M?0T*("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)TEN<W1A;&P@<V-R
M:7!T<R!C;VUP;&5T92<L("1C;VUM86YD*3L-"B`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@?0T*?0T*/SX-"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O4$5!4B]#;VUM86YD+U!A8VMA9V4N>&UL````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`Q,S4P,R`Q,#4Q-30S,S<S,2`P,C(V-3``
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/&-O
M;6UA;F1S('9E<G-I;VX](C$N,"(^#0H@/'!A8VMA9V4^#0H@(#QS=6UM87)Y
M/D)U:6QD(%!A8VMA9V4\+W-U;6UA<GD^#0H@(#QF=6YC=&EO;CYD;U!A8VMA
M9V4\+V9U;F-T:6]N/@T*("`\<VAO<G1C=70^<#PO<VAO<G1C=70^#0H@(#QO
M<'1I;VYS/@T*("`@/&YO8V]M<')E<W,^#0H@("`@/'-H;W)T;W!T/EH\+W-H
M;W)T;W!T/@T*("`@(#QD;V,^1&\@;F]T(&=Z:7`@=&AE('!A8VMA9V4@9FEL
M93PO9&]C/@T*("`@/"]N;V-O;7!R97-S/@T*("`@/'-H;W=N86UE/@T*("`@
M(#QS:&]R=&]P=#YN/"]S:&]R=&]P=#X-"B`@("`\9&]C/E!R:6YT('1H92!N
M86UE(&]F('1H92!P86-K86=E9"!F:6QE+CPO9&]C/@T*("`@/"]S:&]W;F%M
M93X-"B`@/"]O<'1I;VYS/@T*("`\9&]C/EMD97-C9FEL95T@6V1E<V-F:6QE
M,ET-"D-R96%T97,@82!014%2('!A8VMA9V4@9G)O;2!I=',@9&5S8W)I<'1I
M;VX@9FEL92`H=7-U86QL>2!C86QL960-"G!A8VMA9V4N>&UL*2X@($EF(&$@
M<V5C;VYD('!A8VMA9V5F:6QE(&ES('!A<W-E9"!I;BP@=&AE;@T*=&AE('!A
M8VMA9V5R('=I;&P@8VAE8VL@=&\@;6%K92!S=7)E('1H870@;VYE(&ES(&$@
M<&%C:V%G92YX;6P-"G9E<G-I;VX@,2XP+"!A;F0@=&AE(&]T:&5R(&ES(&$@
M<&%C:V%G92YX;6P@=F5R<VEO;B`R+C`N("!4:&4-"G!A8VMA9V4N>&UL('9E
M<G-I;VX@,2XP('=I;&P@8F4@<V%V960@87,@)G%U;W0[<&%C:V%G92YX;6PF
M<75O=#L@:6X@=&AE(&%R8VAI=F4L#0IA;F0@=&AE(&]T:&5R(&%S("9Q=6]T
M.W!A8VMA9V4R+GAM;"9Q=6]T.R!I;B!T:&4@87)C:&EV929Q=6]T.PT*/"]D
M;V,^#0H@/"]P86-K86=E/@T*(#QP86-K86=E+79A;&ED871E/@T*("`\<W5M
M;6%R>3Y686QI9&%T92!086-K86=E($-O;G-I<W1E;F-Y/"]S=6UM87)Y/@T*
M("`\9G5N8W1I;VX^9&]086-K86=E5F%L:61A=&4\+V9U;F-T:6]N/@T*("`\
M<VAO<G1C=70^<'8\+W-H;W)T8W5T/@T*("`\;W!T:6]N<R`O/@T*("`\9&]C
M/@T*/"]D;V,^#0H@/"]P86-K86=E+79A;&ED871E/@T*(#QC=G-D:69F/@T*
M("`\<W5M;6%R>3Y2=6X@82`F<75O=#MC=G,@9&EF9B9Q=6]T.R!F;W(@86QL
M(&9I;&5S(&EN(&$@<&%C:V%G93PO<W5M;6%R>3X-"B`@/&9U;F-T:6]N/F1O
M0W9S1&EF9CPO9G5N8W1I;VX^#0H@(#QS:&]R=&-U=#YC9#PO<VAO<G1C=70^
M#0H@(#QO<'1I;VYS/@T*("`@/'%U:65T/@T*("`@(#QS:&]R=&]P=#YQ/"]S
M:&]R=&]P=#X-"B`@("`\9&]C/D)E('%U:65T/"]D;V,^#0H@("`\+W%U:65T
M/@T*("`@/')E86QL>7%U:65T/@T*("`@(#QS:&]R=&]P=#Y1/"]S:&]R=&]P
M=#X-"B`@("`\9&]C/D)E(')E86QL>2!Q=6EE=#PO9&]C/@T*("`@/"]R96%L
M;'EQ=6EE=#X-"B`@(#QD871E/@T*("`@(#QS:&]R=&]P=#Y$/"]S:&]R=&]P
M=#X-"B`@("`\9&]C/D1I9F8@86=A:6YS="!R979I<VEO;B!O9B!$051%/"]D
M;V,^#0H@("`@/&%R9SY$051%/"]A<F<^#0H@("`\+V1A=&4^#0H@("`\<F5L
M96%S93X-"B`@("`\<VAO<G1O<'0^4CPO<VAO<G1O<'0^#0H@("`@/&1O8SY$
M:69F(&%G86EN<W0@=&%G(&9O<B!P86-K86=E(')E;&5A<V4@4D5,/"]D;V,^
M#0H@("`@/&%R9SY214P\+V%R9SX-"B`@(#PO<F5L96%S93X-"B`@(#QR979I
M<VEO;CX-"B`@("`\<VAO<G1O<'0^<CPO<VAO<G1O<'0^#0H@("`@/&1O8SY$
M:69F(&%G86EN<W0@<F5V:7-I;VX@4D56/"]D;V,^#0H@("`@/&%R9SY2158\
M+V%R9SX-"B`@(#PO<F5V:7-I;VX^#0H@("`\8V]N=&5X=#X-"B`@("`\<VAO
M<G1O<'0^8SPO<VAO<G1O<'0^#0H@("`@/&1O8SY'96YE<F%T92!C;VYT97AT
M(&1I9F8\+V1O8SX-"B`@(#PO8V]N=&5X=#X-"B`@(#QU;FEF:65D/@T*("`@
M(#QS:&]R=&]P=#YU/"]S:&]R=&]P=#X-"B`@("`\9&]C/D=E;F5R871E('5N
M:69I960@9&EF9CPO9&]C/@T*("`@/"]U;FEF:65D/@T*("`@/&EG;F]R92UC
M87-E/@T*("`@(#QS:&]R=&]P=#YI/"]S:&]R=&]P=#X-"B`@("`\9&]C/DEG
M;F]R92!C87-E+"!C;VYS:61E<B!U<'!E<BT@86YD(&QO=V5R+6-A<V4@;&5T
M=&5R<R!E<75I=F%L96YT/"]D;V,^#0H@("`\+VEG;F]R92UC87-E/@T*("`@
M/&EG;F]R92UW:&ET97-P86-E/@T*("`@(#QS:&]R=&]P=#YB/"]S:&]R=&]P
M=#X-"B`@("`\9&]C/DEG;F]R92!C:&%N9V5S(&EN(&%M;W5N="!O9B!W:&ET
M92!S<&%C93PO9&]C/@T*("`@/"]I9VYO<F4M=VAI=&5S<&%C93X-"B`@(#QI
M9VYO<F4M8FQA;FLM;&EN97,^#0H@("`@/'-H;W)T;W!T/D(\+W-H;W)T;W!T
M/@T*("`@(#QD;V,^26=N;W)E(&-H86YG97,@=&AA="!I;G-E<G0@;W(@9&5L
M971E(&)L86YK(&QI;F5S/"]D;V,^#0H@("`\+VEG;F]R92UB;&%N:RUL:6YE
M<SX-"B`@(#QB<FEE9CX-"B`@("`\9&]C/E)E<&]R="!O;FQY('=H971H97(@
M=&AE(&9I;&5S(&1I9F9E<BP@;F\@9&5T86EL<SPO9&]C/@T*("`@/"]B<FEE
M9CX-"B`@(#QD<GDM<G5N/@T*("`@(#QS:&]R=&]P=#YN/"]S:&]R=&]P=#X-
M"B`@("`\9&]C/D1O;B9A<&]S.W0@9&\@86YY=&AI;F<L(&IU<W0@<')E=&5N
M9#PO9&]C/@T*("`@/"]D<GDM<G5N/@T*("`\+V]P=&EO;G,^#0H@(#QD;V,^
M)FQT.W!A8VMA9V4N>&UL)F=T.PT*0V]M<&%R97,@86QL('1H92!F:6QE<R!I
M;B!A('!A8VMA9V4N("!7:71H;W5T(&%N>2!O<'1I;VYS+"!T:&ES#0IC;VUM
M86YD('=I;&P@8V]M<&%R92!T:&4@8W5R<F5N="!C;V1E('=I=&@@=&AE(&QA
M<W0@8VAE8VME9"UI;B!C;V1E+@T*57-I;F<@=&AE("UR(&]R("U2(&]P=&EO
M;B!Y;W4@;6%Y(&-O;7!A<F4@=&AE(&-U<G)E;G0@8V]D92!W:71H('1H870-
M"F]F(&$@<W!E8VEF:6,@<F5L96%S92X-"CPO9&]C/@T*(#PO8W9S9&EF9CX-
M"B`\8W9S=&%G/@T*("`\<W5M;6%R>3Y3970@0U93(%)E;&5A<V4@5&%G/"]S
M=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]#=G-486<\+V9U;F-T:6]N/@T*("`\
M<VAO<G1C=70^8W0\+W-H;W)T8W5T/@T*("`\;W!T:6]N<SX-"B`@(#QQ=6EE
M=#X-"B`@("`\<VAO<G1O<'0^<3PO<VAO<G1O<'0^#0H@("`@/&1O8SY"92!Q
M=6EE=#PO9&]C/@T*("`@/"]Q=6EE=#X-"B`@(#QR96%L;'EQ=6EE=#X-"B`@
M("`\<VAO<G1O<'0^43PO<VAO<G1O<'0^#0H@("`@/&1O8SY"92!R96%L;'D@
M<75I970\+V1O8SX-"B`@(#PO<F5A;&QY<75I970^#0H@("`\<VQI9&4^#0H@
M("`@/'-H;W)T;W!T/D8\+W-H;W)T;W!T/@T*("`@(#QD;V,^36]V92`H<VQI
M9&4I('1A9R!I9B!I="!E>&ES=',\+V1O8SX-"B`@(#PO<VQI9&4^#0H@("`\
M9&5L971E/@T*("`@(#QS:&]R=&]P=#YD/"]S:&]R=&]P=#X-"B`@("`\9&]C
M/E)E;6]V92!T86<\+V1O8SX-"B`@(#PO9&5L971E/@T*("`@/&1R>2UR=6X^
M#0H@("`@/'-H;W)T;W!T/FX\+W-H;W)T;W!T/@T*("`@(#QD;V,^1&]N)F%P
M;W,[="!D;R!A;GET:&EN9RP@:G5S="!P<F5T96YD/"]D;V,^#0H@("`\+V1R
M>2UR=6X^#0H@(#PO;W!T:6]N<SX-"B`@/&1O8SXF;'0[<&%C:V%G92YX;6PF
M9W0[#0I3971S(&$@0U93('1A9R!O;B!A;&P@9FEL97,@:6X@82!P86-K86=E
M+B`@57-E('1H:7,@8V]M;6%N9"!A9G1E<B!Y;W4@:&%V90T*<&%C:V%G960@
M82!D:7-T<FEB=71I;VX@=&%R8F%L;"!W:71H('1H92`F<75O=#MP86-K86=E
M)G%U;W0[(&-O;6UA;F0@=&\@=&%G('=H870-"G)E=FES:6]N<R!O9B!W:&%T
M(&9I;&5S('=E<F4@:6X@=&AA="!R96QE87-E+B`@268@;F5E9"!T;R!F:7@@
M<V]M971H:6YG#0IA9G1E<B!R=6YN:6YG(&-V<W1A9R!O;F-E+"!B=70@8F5F
M;W)E('1H92!T87)B86QL(&ES(')E;&5A<V5D('1O('1H92!P=6)L:6,L#0IU
M<V4@=&AE("9Q=6]T.W-L:61E)G%U;W0[(&]P=&EO;B!T;R!M;W9E('1H92!R
M96QE87-E('1A9RX-"CPO9&]C/@T*(#PO8W9S=&%G/@T*(#QP86-K86=E+61E
M<&5N9&5N8VEE<SX-"B`@/'-U;6UA<GD^4VAO=R!P86-K86=E(&1E<&5N9&5N
M8VEE<SPO<W5M;6%R>3X-"B`@/&9U;F-T:6]N/F1O4&%C:V%G941E<&5N9&5N
M8VEE<SPO9G5N8W1I;VX^#0H@(#QS:&]R=&-U=#YP9#PO<VAO<G1C=70^#0H@
M(#QO<'1I;VYS("\^#0H@(#QD;V,^#0I,:7-T(&%L;"!D97!E;F-I97,@=&AE
M('!A8VMA9V4@:&%S+CPO9&]C/@T*(#PO<&%C:V%G92UD97!E;F1E;F-I97,^
M#0H@/'-I9VX^#0H@(#QS=6UM87)Y/E-I9VX@82!P86-K86=E(&1I<W1R:6)U
M=&EO;B!F:6QE/"]S=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]3:6=N/"]F=6YC
M=&EO;CX-"B`@/'-H;W)T8W5T/G-I/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,@
M+SX-"B`@/&1O8SXF;'0[<&%C:V%G92UF:6QE)F=T.PT*4VEG;G,@82!P86-K
M86=E(&1I<W1R:6)U=&EO;B`H+G1A<B!O<B`N=&=Z*2!F:6QE('=I=&@@1VYU
M4$<N/"]D;V,^#0H@/"]S:6=N/@T*(#QM86ME<G!M/@T*("`\<W5M;6%R>3Y"
M=6EL9',@86X@4E!-('-P96,@9FEL92!F<F]M(&$@4$5!4B!P86-K86=E/"]S
M=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]-86ME4E!-/"]F=6YC=&EO;CX-"B`@
M/'-H;W)T8W5T/G)P;3PO<VAO<G1C=70^#0H@(#QO<'1I;VYS/@T*("`@/'-P
M96,M=&5M<&QA=&4^#0H@("`@/'-H;W)T;W!T/G0\+W-H;W)T;W!T/@T*("`@
M(#QA<F<^1DE,13PO87)G/@T*("`@(#QD;V,^57-E($9)3$4@87,@4E!-('-P
M96,@9FEL92!T96UP;&%T93PO9&]C/@T*("`@/"]S<&5C+71E;7!L871E/@T*
M("`@/')P;2UP:V=N86UE/@T*("`@(#QS:&]R=&]P=#YP/"]S:&]R=&]P=#X-
M"B`@("`\87)G/D9/4DU!5#PO87)G/@T*("`@(#QD;V,^57-E($9/4DU!5"!A
M<R!F;W)M870@<W1R:6YG(&9O<B!24$T@<&%C:V%G92!N86UE+"`E<R!I<R!R
M97!L86-E9`T*8GD@=&AE(%!%05(@<&%C:V%G92!N86UE+"!D969A=6QT<R!T
M;R`F<75O=#M014%2.CHE<R9Q=6]T.RX\+V1O8SX-"B`@(#PO<G!M+7!K9VYA
M;64^#0H@(#PO;W!T:6]N<SX-"B`@/&1O8SXF;'0[<&%C:V%G92UF:6QE)F=T
M.PT*#0I#<F5A=&5S(&%N(%)032`N<W!E8R!F:6QE(&9O<B!W<F%P<&EN9R!A
M(%!%05(@<&%C:V%G92!I;G-I9&4@86X@4E!-#0IP86-K86=E+B`@26YT96YD
M960@=&\@8F4@=7-E9"!F<F]M('1H92!34$5#4R!D:7)E8W1O<GDL('=I=&@@
M=&AE(%!%05(-"G!A8VMA9V4@=&%R8F%L;"!I;B!T:&4@4T]54D-%4R!D:7)E
M8W1O<GDZ#0H-"B0@<&5A<B!M86ME<G!M("XN+U-/55)#15,O3F5T7U-O8VME
M="TQ+C`N=&=Z#0I7<F]T92!24$T@<W!E8R!F:6QE(%!%05(Z.DYE=%]'96\M
M,2XP+G-P96,-"B0@<G!M("UB8B!014%2.CI.971?4V]C:V5T+3$N,"YS<&5C
M#0HN+BX-"E=R;W1E.B`O=7-R+W-R8R]R961H870O4E!-4R]I,S@V+U!%05(Z
M.DYE=%]3;V-K970M,2XP+3$N:3,X-BYR<&T-"CPO9&]C/@T*(#PO;6%K97)P
M;3X-"B`\8V]N=F5R=#X-"B`@/'-U;6UA<GD^0V]N=F5R="!A('!A8VMA9V4N
M>&UL(#$N,"!T;R!P86-K86=E+GAM;"`R+C`@9F]R;6%T/"]S=6UM87)Y/@T*
M("`\9G5N8W1I;VX^9&]#;VYV97)T/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T
M/F,R/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,^#0H@("`\9FQA=#X-"B`@("`\
M<VAO<G1O<'0^9CPO<VAO<G1O<'0^#0H@("`@/&1O8SYD;R!N;W0@8F5A=71I
M9GD@=&AE(&9I;&5L:7-T+CPO9&]C/@T*("`@/"]F;&%T/@T*("`\+V]P=&EO
M;G,^#0H@(#QD;V,^6V1E<V-F:6QE72!;9&5S8V9I;&4R70T*0V]N=F5R=',@
M82!P86-K86=E+GAM;"!I;B`Q+C`@9F]R;6%T(&EN=&\@82!P86-K86=E+GAM
M;`T*:6X@,BXP(&9O<FUA="X@(%1H92!N97<@9FEL92!W:6QL(&)E(&YA;65D
M('!A8VMA9V4R+GAM;"!B>2!D969A=6QT+`T*86YD('!A8VMA9V4N>&UL('=I
M;&P@8F4@=7-E9"!A<R!T:&4@;VQD(&9I;&4@8GD@9&5F875L="X-"E1H:7,@
M:7,@;F]T('1H92!M;W-T(&EN=&5L;&EG96YT(&-O;G9E<G-I;VXL(&%N9"!S
M:&]U;&0@;VYL>2!B90T*=7-E9"!F;W(@875T;VUA=&5D(&-O;G9E<G-I;VX@
M;W(@;&5A<FYI;F<@=&AE(&9O<FUA="X-"CPO9&]C/@T*(#PO8V]N=F5R=#X-
M"CPO8V]M;6%N9',^````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]014%2+T-O;6UA;F0O4&%C:V%G92YP:'``````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,3,W,#0W(#$P-3$U-#,S-S,Q(#`R,C8U,0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`T*
M+RHJ#0H@*B!014%27T-O;6UA;F1?4&%C:V%G92`H<&%C:V%G92P@<&%C:V%G
M92UV86QI9&%T92P@8W9S9&EF9BP@8W9S=&%G+"!P86-K86=E+61E<&5N9&5N
M8VEE<RP-"B`J('-I9VXL(&UA:V5R<&TL(&-O;G9E<G0@8V]M;6%N9',I#0H@
M*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4
M:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@
M=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@
M9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E
M(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L
M('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O
M('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@
M0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U
M=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO
M<B`@("`@36%R=&EN($IA;G-E;B`\;6I`<&AP+FYE=#X-"B`J($!A=71H;W(@
M("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG
M:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS
M92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!086-K86=E+G!H<"QV
M(#$N,3$Y(#(P,#8O,#,O,#(@,3@Z,30Z,3,@8V5L;&]G($5X<"`D#0H@*B!`
M;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*
M("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P
M+C$-"B`J+PT*#0HO*BH-"B`J(&)A<V4@8VQA<W,-"B`J+PT*<F5Q=6ER95]O
M;F-E("=014%2+T-O;6UA;F0O0V]M;6]N+G!H<"<[#0H-"B\J*@T*("H@4$5!
M4B!C;VUM86YD<R!F;W(@;&]G:6XO;&]G;W5T#0H@*@T*("H@0&-A=&5G;W)Y
M("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@
M4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@36%R
M=&EN($IA;G-E;B`\;6I`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@($=R96<@
M0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M
M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J
M($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H
M='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@
M("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,"XQ#0H@*B\-"@T*
M8VQA<W,@4$5!4E]#;VUM86YD7U!A8VMA9V4@97AT96YD<R!014%27T-O;6UA
M;F1?0V]M;6]N#0I[#0H@("`@+R\@>WM[('!R;W!E<G1I97,-"@T*("`@('9A
M<B`D8V]M;6%N9',@/2!A<G)A>2@-"B`@("`@("`@)W!A8VMA9V4G(#T^(&%R
M<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("="=6EL9"!086-K86=E
M)RP-"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O4&%C:V%G92<L#0H@
M("`@("`@("`@("`G<VAO<G1C=70G(#T^("=P)RP-"B`@("`@("`@("`@("=O
M<'1I;VYS)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`G;F]C;VUP<F5S
M<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@
M/3X@)UHG+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G1&\@;F]T
M(&=Z:7`@=&AE('!A8VMA9V4@9FEL92<-"B`@("`@("`@("`@("`@("`@("`@
M*2P-"B`@("`@("`@("`@("`@("`G<VAO=VYA;64G(#T^(&%R<F%Y*`T*("`@
M("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=N)RP-"B`@("`@("`@
M("`@("`@("`@("`@)V1O8R<@/3X@)U!R:6YT('1H92!N86UE(&]F('1H92!P
M86-K86=E9"!F:6QE+B<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@
M("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("=D;V,G(#T^("=;9&5S8V9I
M;&5=(%MD97-C9FEL93)=#0I#<F5A=&5S(&$@4$5!4B!P86-K86=E(&9R;VT@
M:71S(&1E<V-R:7!T:6]N(&9I;&4@*'5S=6%L;'D@8V%L;&5D#0IP86-K86=E
M+GAM;"DN("!)9B!A('-E8V]N9"!P86-K86=E9FEL92!I<R!P87-S960@:6XL
M('1H96X-"G1H92!P86-K86=E<B!W:6QL(&-H96-K('1O(&UA:V4@<W5R92!T
M:&%T(&]N92!I<R!A('!A8VMA9V4N>&UL#0IV97)S:6]N(#$N,"P@86YD('1H
M92!O=&AE<B!I<R!A('!A8VMA9V4N>&UL('9E<G-I;VX@,BXP+B`@5&AE#0IP
M86-K86=E+GAM;"!V97)S:6]N(#$N,"!W:6QL(&)E('-A=F5D(&%S(")P86-K
M86=E+GAM;"(@:6X@=&AE(&%R8VAI=F4L#0IA;F0@=&AE(&]T:&5R(&%S(")P
M86-K86=E,BYX;6PB(&EN('1H92!A<F-H:79E(@T*)PT*("`@("`@("`@("`@
M*2P-"B`@("`@("`@)W!A8VMA9V4M=F%L:61A=&4G(#T^(&%R<F%Y*`T*("`@
M("`@("`@("`@)W-U;6UA<GDG(#T^("=686QI9&%T92!086-K86=E($-O;G-I
M<W1E;F-Y)RP-"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O4&%C:V%G
M959A;&ED871E)RP-"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)W!V)RP-
M"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@I+`T*("`@("`@("`@
M("`@)V1O8R<@/3X@)PT*)RP-"B`@("`@("`@("`@("DL#0H@("`@("`@("=C
M=G-D:69F)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G
M4G5N(&$@(F-V<R!D:69F(B!F;W(@86QL(&9I;&5S(&EN(&$@<&%C:V%G92<L
M#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;T-V<T1I9F8G+`T*("`@
M("`@("`@("`@)W-H;W)T8W5T)R`]/B`G8V0G+`T*("`@("`@("`@("`@)V]P
M=&EO;G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=Q=6EE="<@/3X@
M87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)W$G
M+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G0F4@<75I970G+`T*
M("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=R96%L
M;'EQ=6EE="<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R
M=&]P="<@/3X@)U$G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G
M0F4@<F5A;&QY('%U:65T)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@
M("`@("`@("`@("`@("`G9&%T92<@/3X@87)R87DH#0H@("`@("`@("`@("`@
M("`@("`@("=S:&]R=&]P="<@/3X@)T0G+`T*("`@("`@("`@("`@("`@("`@
M("`G9&]C)R`]/B`G1&EF9B!A9V%I;G-T(')E=FES:6]N(&]F($1!5$4G+`T*
M("`@("`@("`@("`@("`@("`@("`G87)G)R`]/B`G1$%412<L#0H@("`@("`@
M("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@)W)E;&5A<V4G(#T^
M(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=2
M)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)T1I9F8@86=A:6YS
M="!T86<@9F]R('!A8VMA9V4@<F5L96%S92!214PG+`T*("`@("`@("`@("`@
M("`@("`@("`G87)G)R`]/B`G4D5,)RP-"B`@("`@("`@("`@("`@("`@("`@
M*2P-"B`@("`@("`@("`@("`@("`G<F5V:7-I;VXG(#T^(&%R<F%Y*`T*("`@
M("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=R)RP-"B`@("`@("`@
M("`@("`@("`@("`@)V1O8R<@/3X@)T1I9F8@86=A:6YS="!R979I<VEO;B!2
M158G+`T*("`@("`@("`@("`@("`@("`@("`G87)G)R`]/B`G4D56)RP-"B`@
M("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G8V]N=&5X
M="<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@
M/3X@)V,G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G1V5N97)A
M=&4@8V]N=&5X="!D:69F)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@
M("`@("`@("`@("`@("`G=6YI9FEE9"<@/3X@87)R87DH#0H@("`@("`@("`@
M("`@("`@("`@("=S:&]R=&]P="<@/3X@)W4G+`T*("`@("`@("`@("`@("`@
M("`@("`G9&]C)R`]/B`G1V5N97)A=&4@=6YI9FEE9"!D:69F)RP-"B`@("`@
M("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G:6=N;W)E+6-A
M<V4G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G
M(#T^("=I)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)TEG;F]R
M92!C87-E+"!C;VYS:61E<B!U<'!E<BT@86YD(&QO=V5R+6-A<V4@;&5T=&5R
M<R!E<75I=F%L96YT)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@
M("`@("`@("`@("`G:6=N;W)E+7=H:71E<W!A8V4G(#T^(&%R<F%Y*`T*("`@
M("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=B)RP-"B`@("`@("`@
M("`@("`@("`@("`@)V1O8R<@/3X@)TEG;F]R92!C:&%N9V5S(&EN(&%M;W5N
M="!O9B!W:&ET92!S<&%C92<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@
M("`@("`@("`@("`@("`@)VEG;F]R92UB;&%N:RUL:6YE<R<@/3X@87)R87DH
M#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)T(G+`T*("`@
M("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G26=N;W)E(&-H86YG97,@=&AA
M="!I;G-E<G0@;W(@9&5L971E(&)L86YK(&QI;F5S)RP-"B`@("`@("`@("`@
M("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G8G)I968G(#T^(&%R<F%Y
M*`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G4F5P;W)T(&]N;'D@
M=VAE=&AE<B!T:&4@9FEL97,@9&EF9F5R+"!N;R!D971A:6QS)RP-"B`@("`@
M("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G9')Y+7)U;B<@
M/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@
M)VXG+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G1&]N7"=T(&1O
M(&%N>71H:6YG+"!J=7-T('!R971E;F0G+`T*("`@("`@("`@("`@("`@("`@
M("`I+`T*("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`G9&]C)R`]
M/B`G/'!A8VMA9V4N>&UL/@T*0V]M<&%R97,@86QL('1H92!F:6QE<R!I;B!A
M('!A8VMA9V4N("!7:71H;W5T(&%N>2!O<'1I;VYS+"!T:&ES#0IC;VUM86YD
M('=I;&P@8V]M<&%R92!T:&4@8W5R<F5N="!C;V1E('=I=&@@=&AE(&QA<W0@
M8VAE8VME9"UI;B!C;V1E+@T*57-I;F<@=&AE("UR(&]R("U2(&]P=&EO;B!Y
M;W4@;6%Y(&-O;7!A<F4@=&AE(&-U<G)E;G0@8V]D92!W:71H('1H870-"F]F
M(&$@<W!E8VEF:6,@<F5L96%S92X-"B<L#0H@("`@("`@("`@("`I+`T*("`@
M("`@("`G8W9S=&%G)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y
M)R`]/B`G4V5T($-64R!296QE87-E(%1A9R<L#0H@("`@("`@("`@("`G9G5N
M8W1I;VXG(#T^("=D;T-V<U1A9R<L#0H@("`@("`@("`@("`G<VAO<G1C=70G
M(#T^("=C="<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH#0H@
M("`@("`@("`@("`@("`@)W%U:65T)R`]/B!A<G)A>2@-"B`@("`@("`@("`@
M("`@("`@("`@)W-H;W)T;W!T)R`]/B`G<2<L#0H@("`@("`@("`@("`@("`@
M("`@("=D;V,G(#T^("="92!Q=6EE="<L#0H@("`@("`@("`@("`@("`@("`@
M("DL#0H@("`@("`@("`@("`@("`@)W)E86QL>7%U:65T)R`]/B!A<G)A>2@-
M"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G42<L#0H@("`@
M("`@("`@("`@("`@("`@("=D;V,G(#T^("="92!R96%L;'D@<75I970G+`T*
M("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=S;&ED
M92<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@
M/3X@)T8G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G36]V92`H
M<VQI9&4I('1A9R!I9B!I="!E>&ES=',G+`T*("`@("`@("`@("`@("`@("`@
M("`I+`T*("`@("`@("`@("`@("`@("=D96QE=&4G(#T^(&%R<F%Y*`T*("`@
M("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=D)RP-"B`@("`@("`@
M("`@("`@("`@("`@)V1O8R<@/3X@)U)E;6]V92!T86<G+`T*("`@("`@("`@
M("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=D<GDM<G5N)R`]/B!A
M<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G;B<L
M#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=$;VY<)W0@9&\@86YY
M=&AI;F<L(&IU<W0@<')E=&5N9"<L#0H@("`@("`@("`@("`@("`@("`@("DL
M#0H@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("=D;V,G(#T^("<\
M<&%C:V%G92YX;6P^(%MF:6QE<RXN+ET-"E-E=',@82!#5E,@=&%G(&]N(&%L
M;"!F:6QE<R!I;B!A('!A8VMA9V4N("!5<V4@=&AI<R!C;VUM86YD(&%F=&5R
M('EO=2!H879E#0IP86-K86=E9"!A(&1I<W1R:6)U=&EO;B!T87)B86QL('=I
M=&@@=&AE(")P86-K86=E(B!C;VUM86YD('1O('1A9R!W:&%T#0IR979I<VEO
M;G,@;V8@=VAA="!F:6QE<R!W97)E(&EN('1H870@<F5L96%S92X@($EF(&YE
M960@=&\@9FEX('-O;65T:&EN9PT*869T97(@<G5N;FEN9R!C=G-T86<@;VYC
M92P@8G5T(&)E9F]R92!T:&4@=&%R8F%L;"!I<R!R96QE87-E9"!T;R!T:&4@
M<'5B;&EC+`T*=7-E('1H92`B<VQI9&4B(&]P=&EO;B!T;R!M;W9E('1H92!R
M96QE87-E('1A9RX-"@T*=&\@:6YC;'5D92!F:6QE<R`H<W5C:"!A<R!A('-E
M8V]N9"!P86-K86=E+GAM;"P@;W(@=&5S=',@;F]T(&EN8VQU9&5D(&EN('1H
M90T*<F5L96%S92DL('!A<W,@=&AE;2!A<R!A9&1I=&EO;F%L('!A<F%M971E
M<G,N#0HG+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@)W!A8VMA9V4M9&5P
M96YD96YC:65S)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]
M/B`G4VAO=R!P86-K86=E(&1E<&5N9&5N8VEE<R<L#0H@("`@("`@("`@("`G
M9G5N8W1I;VXG(#T^("=D;U!A8VMA9V5$97!E;F1E;F-I97,G+`T*("`@("`@
M("`@("`@)W-H;W)T8W5T)R`]/B`G<&0G+`T*("`@("`@("`@("`@)V]P=&EO
M;G,G(#T^(&%R<F%Y*"DL#0H@("`@("`@("`@("`G9&]C)R`]/B`G#0I,:7-T
M(&%L;"!D97!E;F-I97,@=&AE('!A8VMA9V4@:&%S+B<-"B`@("`@("`@("`@
M("DL#0H@("`@("`@("=S:6=N)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S
M=6UM87)Y)R`]/B`G4VEG;B!A('!A8VMA9V4@9&ES=')I8G5T:6]N(&9I;&4G
M+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]3:6=N)RP-"B`@("`@
M("`@("`@("=S:&]R=&-U="<@/3X@)W-I)RP-"B`@("`@("`@("`@("=O<'1I
M;VYS)R`]/B!A<G)A>2@I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)SQP86-K
M86=E+69I;&4^#0I3:6=N<R!A('!A8VMA9V4@9&ES=')I8G5T:6]N("@N=&%R
M(&]R("YT9WHI(&9I;&4@=VET:"!';G501RXG+`T*("`@("`@("`@("`@*2P-
M"B`@("`@("`@)VUA:V5R<&TG(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U
M;6UA<GDG(#T^("="=6EL9',@86X@4E!-('-P96,@9FEL92!F<F]M(&$@4$5!
M4B!P86-K86=E)RP-"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O36%K
M95)032<L#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=R<&TG+`T*("`@
M("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@
M("=S<&5C+71E;7!L871E)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@
M("`@)W-H;W)T;W!T)R`]/B`G="<L#0H@("`@("`@("`@("`@("`@("`@("=A
M<F<G(#T^("=&24Q%)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@
M)U5S92!&24Q%(&%S(%)032!S<&5C(&9I;&4@=&5M<&QA=&4G#0H@("`@("`@
M("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@)W)P;2UP:V=N86UE
M)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]
M/B`G<"<L#0H@("`@("`@("`@("`@("`@("`@("=A<F<G(#T^("=&3U)-050G
M+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G57-E($9/4DU!5"!A
M<R!F;W)M870@<W1R:6YG(&9O<B!24$T@<&%C:V%G92!N86UE+"`E<R!I<R!R
M97!L86-E9`T*8GD@=&AE(%!%05(@<&%C:V%G92!N86UE+"!D969A=6QT<R!T
M;R`B4$5!4CHZ)7,B+B<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@
M("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("=D;V,G(#T^("<\<&%C:V%G
M92UF:6QE/@T*#0I#<F5A=&5S(&%N(%)032`N<W!E8R!F:6QE(&9O<B!W<F%P
M<&EN9R!A(%!%05(@<&%C:V%G92!I;G-I9&4@86X@4E!-#0IP86-K86=E+B`@
M26YT96YD960@=&\@8F4@=7-E9"!F<F]M('1H92!34$5#4R!D:7)E8W1O<GDL
M('=I=&@@=&AE(%!%05(-"G!A8VMA9V4@=&%R8F%L;"!I;B!T:&4@4T]54D-%
M4R!D:7)E8W1O<GDZ#0H-"B0@<&5A<B!M86ME<G!M("XN+U-/55)#15,O3F5T
M7U-O8VME="TQ+C`N=&=Z#0I7<F]T92!24$T@<W!E8R!F:6QE(%!%05(Z.DYE
M=%]'96\M,2XP+G-P96,-"B0@<G!M("UB8B!014%2.CI.971?4V]C:V5T+3$N
M,"YS<&5C#0HN+BX-"E=R;W1E.B`O=7-R+W-R8R]R961H870O4E!-4R]I,S@V
M+U!%05(Z.DYE=%]3;V-K970M,2XP+3$N:3,X-BYR<&T-"B<L#0H@("`@("`@
M("`@("`I+`T*("`@("`@("`G8V]N=F5R="<@/3X@87)R87DH#0H@("`@("`@
M("`@("`G<W5M;6%R>2<@/3X@)T-O;G9E<G0@82!P86-K86=E+GAM;"`Q+C`@
M=&\@<&%C:V%G92YX;6P@,BXP(&9O<FUA="<L#0H@("`@("`@("`@("`G9G5N
M8W1I;VXG(#T^("=D;T-O;G9E<G0G+`T*("`@("`@("`@("`@)W-H;W)T8W5T
M)R`]/B`G8S(G+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("=F;&%T)R`]/B!A<G)A>2@-"B`@("`@("`@("`@
M("`@("`@("`@)W-H;W)T;W!T)R`]/B`G9B<L#0H@("`@("`@("`@("`@("`@
M("`@("=D;V,G(#T^("=D;R!N;W0@8F5A=71I9GD@=&AE(&9I;&5L:7-T+B<L
M#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@*2P-
M"B`@("`@("`@("`@("=D;V,G(#T^("=;9&5S8V9I;&5=(%MD97-C9FEL93)=
M#0I#;VYV97)T<R!A('!A8VMA9V4N>&UL(&EN(#$N,"!F;W)M870@:6YT;R!A
M('!A8VMA9V4N>&UL#0II;B`R+C`@9F]R;6%T+B`@5&AE(&YE=R!F:6QE('=I
M;&P@8F4@;F%M960@<&%C:V%G93(N>&UL(&)Y(&1E9F%U;'0L#0IA;F0@<&%C
M:V%G92YX;6P@=VEL;"!B92!U<V5D(&%S('1H92!O;&0@9FEL92!B>2!D969A
M=6QT+@T*5&AI<R!I<R!N;W0@=&AE(&UO<W0@:6YT96QL:6=E;G0@8V]N=F5R
M<VEO;BP@86YD('-H;W5L9"!O;FQY(&)E#0IU<V5D(&9O<B!A=71O;6%T960@
M8V]N=F5R<VEO;B!O<B!L96%R;FEN9R!T:&4@9F]R;6%T+@T*)PT*("`@("`@
M("`@("`@*2P-"B`@("`@("`@*3L-"@T*("`@('9A<B`D;W5T<'5T.PT*#0H@
M("`@+R\@?7U]#0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R#0H-"B`@("`O*BH-
M"B`@("`@*B!014%27T-O;6UA;F1?4&%C:V%G92!C;VYS=')U8W1O<BX-"B`@
M("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@4$5!4E]#;VUM86YD7U!A8VMA9V4H)B1U:2P@)B1C;VYF:6<I#0H@
M("`@>PT*("`@("`@("!P87)E;G0Z.E!%05)?0V]M;6%N9%]#;VUM;VXH)'5I
M+"`D8V]N9FEG*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*("`@("\O('M[
M>R!?9&ES<&QA>59A;&ED871I;VY297-U;'1S*"D-"@T*("`@(&9U;F-T:6]N
M(%]D:7-P;&%Y5F%L:61A=&EO;E)E<W5L=',H)&5R<BP@)'=A<FXL("1S=')I
M8W0@/2!F86QS92D-"B`@("![#0H@("`@("`@(&9O<F5A8V@@*"1E<G(@87,@
M)&4I('L-"B`@("`@("`@("`@("1T:&ES+3YO=71P=70@+CT@(D5R<F]R.B`D
M95QN(CL-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D=V%R;B!A<R`D
M=RD@>PT*("`@("`@("`@("`@)'1H:7,M/F]U='!U="`N/2`B5V%R;FEN9SH@
M)'=<;B([#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/F]U='!U="`N/2!S
M<')I;G1F*"=686QI9&%T:6]N.B`E9"!E<G)O<BAS*2P@)60@=V%R;FEN9RAS
M*2<N(EQN(BP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('-I>F5O9B@D97)R*2P@<VEZ96]F*"1W87)N*2D[#0H@("`@("`@(&EF
M("@D<W1R:6-T("8F('-I>F5O9B@D97)R*2`^(#`I('L-"B`@("`@("`@("`@
M("1T:&ES+3YO=71P=70@+CT@(D9I>"!T:&5S92!E<G)O<G,@86YD('1R>2!A
M9V%I;BXB.PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*
M("`@(&9U;F-T:6]N("9G971086-K86=E<B@I#0H@("`@>PT*("`@("`@("!I
M9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]086-K86=E<B<I*2![#0H@("`@("`@
M("`@("!R97%U:7)E7V]N8V4@)U!%05(O4&%C:V%G97(N<&AP)SL-"B`@("`@
M("`@?0T*("`@("`@("`D82`]("9N97<@4$5!4E]086-K86=E<CL-"B`@("`@
M("`@<F5T=7)N("1A.PT*("`@('T-"@T*("`@(&9U;F-T:6]N("9G971086-K
M86=E1FEL92@D8V]N9FEG+"`D9&5B=6<@/2!F86QS92P@)'1M<&1I<B`](&YU
M;&PI#0H@("`@>PT*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]#
M;VUM;VXG*2D@>PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+T-O
M;6UO;BYP:'`G.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A8VQA<W-?97AI
M<W1S*"=014%2+U!A8VMA9V5&:6QE+G!H<"<I*2![#0H@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)U!%05(O4&%C:V%G949I;&4N<&AP)SL-"B`@("`@("`@
M?0T*("`@("`@("`D82`]("9N97<@4$5!4E]086-K86=E1FEL92@D8V]N9FEG
M+"`D9&5B=6<L("1T;7!D:7(I.PT*("`@("`@("`D8V]M;6]N(#T@;F5W(%!%
M05)?0V]M;6]N.PT*("`@("`@("`D8V]M;6]N+3YU:2`]("1T:&ES+3YU:3L-
M"B`@("`@("`@)&$M/G-E=$QO9V=E<B@D8V]M;6]N*3L-"B`@("`@("`@<F5T
M=7)N("1A.PT*("`@('T-"B`@("`O+R![>WL@9&]086-K86=E*"D-"@T*("`@
M(&9U;F-T:6]N(&1O4&%C:V%G92@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A
M;7,I#0H@("`@>PT*("`@("`@("`D=&AI<RT^;W5T<'5T(#T@)R<[#0H@("`@
M("`@("1P:V=I;F9O9FEL92`](&ES<V5T*"1P87)A;7-;,%TI(#\@)'!A<F%M
M<ULP72`Z("=P86-K86=E+GAM;"<[#0H@("`@("`@("1P:V<R(#T@:7-S970H
M)'!A<F%M<ULQ72D@/R`D<&%R86US6S%=(#H@;G5L;#L-"B`@("`@("`@:68@
M*"$D<&MG,B`F)B`A:7-S970H)'!A<F%M<ULP72DI('L-"B`@("`@("`@("`@
M(&EF("AF:6QE7V5X:7-T<R@G<&%C:V%G93(N>&UL)RDI('L-"B`@("`@("`@
M("`@("`@("`D<&MG,B`]("=P86-K86=E,BYX;6PG.PT*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@("1P86-K86=E<B`]("8D=&AI<RT^9V5T
M4&%C:V%G97(H*3L-"B`@("`@("`@)&-O;7!R97-S(#T@96UP='DH)&]P=&EO
M;G-;)VYO8V]M<')E<W,G72D@/R!T<G5E(#H@9F%L<V4[#0H@("`@("`@("1R
M97-U;'0@/2`D<&%C:V%G97(M/G!A8VMA9V4H)'!K9VEN9F]F:6QE+"`D8V]M
M<')E<W,L("1P:V<R*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E
M<W5L="DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@D<F5S=6QT*3L-"B`@("`@("`@?0T*("`@("`@("`O+R!$;VXG="!W86YT
M(&]U='!U="P@;VYL>2!T:&4@<&%C:V%G92!F:6QE(&YA;64@:G5S="!C<F5A
M=&5D#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG<VAO=VYA;64G72DI
M('L-"B`@("`@("`@("`@("1T:&ES+3YO=71P=70@/2`D<F5S=6QT.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("@D=&AI<RT^;W5T<'5T*2![#0H@("`@("`@
M("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)'1H:7,M/F]U='!U="P@)&-O
M;6UA;F0I.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@
M('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!D;U!A8VMA9V5686QI9&%T
M92@I#0H-"B`@("!F=6YC=&EO;B!D;U!A8VMA9V5686QI9&%T92@D8V]M;6%N
M9"P@)&]P=&EO;G,L("1P87)A;7,I#0H@("`@>PT*("`@("`@("`D=&AI<RT^
M;W5T<'5T(#T@)R<[#0H@("`@("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@/"`Q
M*2![#0H@("`@("`@("`@("`D<&%R86US6S!=(#T@(G!A8VMA9V4N>&UL(CL-
M"B`@("`@("`@?0T*("`@("`@("`D;V)J(#T@)B1T:&ES+3YG971086-K86=E
M1FEL92@D=&AI<RT^8V]N9FEG+"`D=&AI<RT^7V1E8G5G*3L-"B`@("`@("`@
M)&]B:BT^<F%W4F5T=7)N*"D[#0H@("`@("`@(%!%05(Z.G-T871I8U!U<VA%
M<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@)&EN
M9F\@/2`D;V)J+3YF<F]M5&=Z1FEL92@D<&%R86US6S!=+"!014%27U9!3$E$
M051%7TY/4DU!3"D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1I;F9O
M*2D@>PT*("`@("`@("`@("`@)&EN9F\@/2`D;V)J+3YF<F]M4&%C:V%G949I
M;&4H)'!A<F%M<ULP72P@4$5!4E]604Q)1$%415].3U)-04PI.PT*("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@)&%R8VAI=F4@/2`D:6YF;RT^9V5T
M07)C:&EV949I;&4H*3L-"B`@("`@("`@("`@("1T87(@/2`F;F5W($%R8VAI
M=F5?5&%R*"1A<F-H:79E*3L-"B`@("`@("`@("`@("1T87(M/F5X=')A8W0H
M9&ER;F%M92@D:6YF;RT^9V5T4&%C:V%G949I;&4H*2DI.PT*("`@("`@("`@
M("`@)&EN9F\M/G-E=%!A8VMA9V5&:6QE*&1I<FYA;64H)&EN9F\M/F=E=%!A
M8VMA9V5&:6QE*"DI("X@1$E214-43U)97U-%4$%2051/4B`N#0H@("`@("`@
M("`@("`@("`@)&EN9F\M/F=E=%!A8VMA9V4H*2`N("<M)R`N("1I;F9O+3YG
M971697)S:6]N*"D@+B!$25)%0U1/4EE?4T5005)!5$]2("X-"B`@("`@("`@
M("`@("`@("!B87-E;F%M92@D:6YF;RT^9V5T4&%C:V%G949I;&4H*2DI.PT*
M("`@("`@("!]#0H@("`@("`@(%!%05(Z.G-T871I8U!O<$5R<F]R2&%N9&QI
M;F<H*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&EN9F\I*2![#0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&EN9F\I.PT*
M("`@("`@("!]#0H@("`@("`@("1V86QI9"`](&9A;'-E.PT*("`@("`@("!I
M9B`H)&EN9F\M/F=E=%!A8VMA9V5X;6Q697)S:6]N*"D@/3T@)S(N,"<I('L-
M"B`@("`@("`@("`@(&EF("@D=F%L:60@/2`D:6YF;RT^=F%L:61A=&4H4$5!
M4E]604Q)1$%415].3U)-04PI*2![#0H@("`@("`@("`@("`@("`@)&EN9F\M
M/F9L871T96Y&:6QE3&ES="@I.PT*("`@("`@("`@("`@("`@("1V86QI9"`]
M("1I;F9O+3YV86QI9&%T92A014%27U9!3$E$051%7U!!0TM!1TE.1RD[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D
M=F%L:60@/2`D:6YF;RT^=F%L:61A=&4H4$5!4E]604Q)1$%415]004-+04=)
M3D<I.PT*("`@("`@("!]#0H@("`@("`@("1E<G(@/2!A<G)A>2@I.PT*("`@
M("`@("`D=V%R;B`](&%R<F%Y*"D[#0H@("`@("`@(&EF("@A)'9A;&ED*2![
M#0H@("`@("`@("`@("!F;W)E86-H("@D:6YF;RT^9V5T5F%L:61A=&EO;E=A
M<FYI;F=S*"D@87,@)&5R<F]R*2![#0H@("`@("`@("`@("`@("`@:68@*"1E
M<G)O<ELG;&5V96PG72`]/2`G=V%R;FEN9R<I('L-"B`@("`@("`@("`@("`@
M("`@("`@)'=A<FY;72`]("1E<G)O<ELG;65S<V%G92==.PT*("`@("`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1E<G);72`]
M("1E<G)O<ELG;65S<V%G92==.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7V1I<W!L87E6
M86QI9&%T:6]N4F5S=6QT<R@D97)R+"`D=V%R;BD[#0H@("`@("`@("1T:&ES
M+3YU:2T^;W5T<'5T1&%T82@D=&AI<RT^;W5T<'5T+"`D8V]M;6%N9"D[#0H@
M("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@
M("\O('M[>R!D;T-V<U1A9R@I#0H-"B`@("!F=6YC=&EO;B!D;T-V<U1A9R@D
M8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I#0H@("`@>PT*("`@("`@("`D
M=&AI<RT^;W5T<'5T(#T@)R<[#0H@("`@("`@("1?8VUD(#T@)&-O;6UA;F0[
M#0H@("`@("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@/"`Q*2![#0H@("`@("`@
M("`@("`D:&5L<"`]("1T:&ES+3YG971(96QP*"1C;VUM86YD*3L-"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B)&-O;6UA;F0Z(&UI
M<W-I;F<@<&%R86UE=&5R.B`D:&5L<%LP72(I.PT*("`@("`@("!]#0H@("`@
M("`@("1O8FH@/2`F)'1H:7,M/F=E=%!A8VMA9V5&:6QE*"1T:&ES+3YC;VYF
M:6<L("1T:&ES+3Y?9&5B=6<I.PT*("`@("`@("`D:6YF;R`]("1O8FHM/F9R
M;VU!;GE&:6QE*"1P87)A;7-;,%TL(%!%05)?5D%,241!5$5?3D]234%,*3L-
M"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&EN9F\I*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&EN9F\I.PT*("`@("`@
M("!]#0H@("`@("`@("1E<G(@/2`D=V%R;B`](&%R<F%Y*"D[#0H@("`@("`@
M(&EF("@A)&EN9F\M/G9A;&ED871E*"DI('L-"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1I;F9O+3YG971686QI9&%T:6]N5V%R;FEN9W,H*2!A<R`D97)R;W(I
M('L-"B`@("`@("`@("`@("`@("!I9B`H)&5R<F]R6R=L979E;"==(#T]("=W
M87)N:6YG)RD@>PT*("`@("`@("`@("`@("`@("`@("`D=V%R;EM=(#T@)&5R
M<F]R6R=M97-S86=E)UT[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`@("`@)&5R<EM=(#T@)&5R<F]R6R=M97-S86=E)UT[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(&EF("@A)'1H:7,M/E]D:7-P;&%Y5F%L:61A=&EO;E)E<W5L
M=',H)&5R<BP@)'=A<FXL('1R=64I*2![#0H@("`@("`@("`@("`D=&AI<RT^
M=6DM/F]U='!U=$1A=&$H)'1H:7,M/F]U='!U="P@)&-O;6UA;F0I.PT*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=#5E,@=&%G(&9A
M:6QE9"<I.PT*("`@("`@("!]#0H@("`@("`@("1V97)S:6]N(#T@)&EN9F\M
M/F=E=%9E<G-I;VXH*3L-"B`@("`@("`@)&-V<W9E<G-I;VX@/2!P<F5G7W)E
M<&QA8V4H)R];7F$M>C`M.5TO:2<L("=?)RP@)'9E<G-I;VXI.PT*("`@("`@
M("`D8W9S=&%G(#T@(E)%3$5!4T5?)&-V<W9E<G-I;VXB.PT*("`@("`@("`D
M9FEL97,@/2!A<G)A>5]K97ES*"1I;F9O+3YG971&:6QE;&ES="@I*3L-"B`@
M("`@("`@)&-O;6UA;F0@/2`B8W9S(CL-"B`@("`@("`@:68@*&ES<V5T*"1O
M<'1I;VYS6R=Q=6EE="==*2D@>PT*("`@("`@("`@("`@)&-O;6UA;F0@+CT@
M)R`M<2<[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS
M6R=R96%L;'EQ=6EE="==*2D@>PT*("`@("`@("`@("`@)&-O;6UA;F0@+CT@
M)R`M42<[#0H@("`@("`@('T-"B`@("`@("`@)&-O;6UA;F0@+CT@)R!T86<G
M.PT*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W-L:61E)UTI*2![#0H@
M("`@("`@("`@("`D8V]M;6%N9"`N/2`G("U&)SL-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H:7-S970H)&]P=&EO;G-;)V1E;&5T92==*2D@>PT*("`@("`@
M("`@("`@)&-O;6UA;F0@+CT@)R`M9"<[#0H@("`@("`@('T-"B`@("`@("`@
M)&-O;6UA;F0@+CT@)R`G("X@)&-V<W1A9R`N("<@)R`N(&5S8V%P97-H96QL
M87)G*"1P87)A;7-;,%TI.PT*("`@("`@("!A<G)A>5]S:&EF="@D<&%R86US
M*3L-"B`@("`@("`@:68@*&-O=6YT*"1P87)A;7,I*2![#0H@("`@("`@("`@
M("`O+R!A9&0@:6X@861D:71I;VYA;"!F:6QE<R!T;R!B92!T86=G960-"B`@
M("`@("`@("`@("1F:6QE<R`](&%R<F%Y7VUE<F=E*"1F:6QE<RP@)'!A<F%M
M<RD[#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H)&9I;&5S(&%S("1F
M:6QE*2![#0H@("`@("`@("`@("`D8V]M;6%N9"`N/2`G("<@+B!E<V-A<&5S
M:&5L;&%R9R@D9FEL92D[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1T:&ES
M+3YC;VYF:6<M/F=E="@G=F5R8F]S92<I(#X@,2D@>PT*("`@("`@("`@("`@
M)'1H:7,M/F]U='!U="`N/2`B*R`D8V]M;6%N9%QN(CL-"B`@("`@("`@?0T*
M("`@("`@("`D=&AI<RT^;W5T<'5T("X]("(K("1C;VUM86YD7&XB.PT*("`@
M("`@("!I9B`H96UP='DH)&]P=&EO;G-;)V1R>2UR=6XG72DI('L-"B`@("`@
M("`@("`@("1F<"`]('!O<&5N*"1C;VUM86YD+"`B<B(I.PT*("`@("`@("`@
M("`@=VAI;&4@*"1L:6YE(#T@9F=E=',H)&9P+"`Q,#(T*2D@>PT*("`@("`@
M("`@("`@("`@("1T:&ES+3YO=71P=70@+CT@<G1R:6TH)&QI;F4I+B)<;B([
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!P8VQO<V4H)&9P*3L-"B`@
M("`@("`@?0T*("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)'1H:7,M
M/F]U='!U="P@)%]C;60I.PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]
M#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9&]#=G-$:69F*"D-"@T*("`@
M(&9U;F-T:6]N(&1O0W9S1&EF9B@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A
M;7,I#0H@("`@>PT*("`@("`@("`D=&AI<RT^;W5T<'5T(#T@)R<[#0H@("`@
M("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@/"`Q*2![#0H@("`@("`@("`@("`D
M:&5L<"`]("1T:&ES+3YG971(96QP*"1C;VUM86YD*3L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B)&-O;6UA;F0Z(&UI<W-I;F<@
M<&%R86UE=&5R.B`D:&5L<%LP72(I.PT*("`@("`@("!]#0H@("`@("`@("1O
M8FH@/2`F)'1H:7,M/F=E=%!A8VMA9V5&:6QE*"1T:&ES+3YC;VYF:6<L("1T
M:&ES+3Y?9&5B=6<I.PT*("`@("`@("`D:6YF;R`]("1O8FHM/F9R;VU!;GE&
M:6QE*"1P87)A;7-;,%TL(%!%05)?5D%,241!5$5?3D]234%,*3L-"B`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)&EN9F\I*2![#0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&EN9F\I.PT*("`@("`@("!]#0H@
M("`@("`@("1E<G(@/2`D=V%R;B`](&%R<F%Y*"D[#0H@("`@("`@(&EF("@A
M)&EN9F\M/G9A;&ED871E*"DI('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1I
M;F9O+3YG971686QI9&%T:6]N5V%R;FEN9W,H*2!A<R`D97)R;W(I('L-"B`@
M("`@("`@("`@("`@("!I9B`H)&5R<F]R6R=L979E;"==(#T]("=W87)N:6YG
M)RD@>PT*("`@("`@("`@("`@("`@("`@("`D=V%R;EM=(#T@)&5R<F]R6R=M
M97-S86=E)UT[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@)&5R<EM=(#T@)&5R<F]R6R=M97-S86=E)UT[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@(&EF("@A)'1H:7,M/E]D:7-P;&%Y5F%L:61A=&EO;E)E<W5L=',H)&5R
M<BP@)'=A<FXL('1R=64I*2![#0H@("`@("`@("`@("`D=&AI<RT^=6DM/F]U
M='!U=$1A=&$H)'1H:7,M/F]U='!U="P@)&-O;6UA;F0I.PT*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=#5E,@9&EF9B!F86EL960G
M*3L-"B`@("`@("`@?0T*("`@("`@("`D:6YF;S$@/2`D:6YF;RT^9V5T1FEL
M96QI<W0H*3L-"B`@("`@("`@)&9I;&5S(#T@)&EN9F\Q.PT*("`@("`@("`D
M8VUD(#T@(F-V<R([#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG<75I
M970G72DI('L-"B`@("`@("`@("`@("1C;60@+CT@)R`M<2<[#0H@("`@("`@
M("`@("!U;G-E="@D;W!T:6]N<ULG<75I970G72D[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=R96%L;'EQ=6EE="==*2D@>PT*
M("`@("`@("`@("`@)&-M9"`N/2`G("U1)SL-"B`@("`@("`@("`@('5N<V5T
M*"1O<'1I;VYS6R=R96%L;'EQ=6EE="==*3L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H:7-S970H)&]P=&EO;G-;)W)E;&5A<V4G72DI('L-"B`@("`@("`@
M("`@("1C=G-V97)S:6]N(#T@<')E9U]R97!L86-E*"<O6UYA+7HP+3E=+VDG
M+"`G7R<L("1O<'1I;VYS6R=R96QE87-E)UTI.PT*("`@("`@("`@("`@)&-V
M<W1A9R`](")214Q%05-%7R1C=G-V97)S:6]N(CL-"B`@("`@("`@("`@("1O
M<'1I;VYS6R=R979I<VEO;B==(#T@)&-V<W1A9SL-"B`@("`@("`@("`@('5N
M<V5T*"1O<'1I;VYS6R=R96QE87-E)UTI.PT*("`@("`@("!]#0H@("`@("`@
M("1E>&5C=71E(#T@=')U93L-"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS
M6R=D<GDM<G5N)UTI*2![#0H@("`@("`@("`@("`D97AE8W5T92`](&9A;'-E
M.PT*("`@("`@("`@("`@=6YS970H)&]P=&EO;G-;)V1R>2UR=6XG72D[#0H@
M("`@("`@('T-"B`@("`@("`@)&-M9"`N/2`G(&1I9F8G.PT*("`@("`@("`O
M+R!T:&4@<F5S="!O9B!T:&4@;W!T:6]N<R!A<F4@<&%S<V5D(')I9VAT(&]N
M('1O(")C=G,@9&EF9B(-"B`@("`@("`@9F]R96%C:"`H)&]P=&EO;G,@87,@
M)&]P=&EO;B`]/B`D;W!T87)G*2![#0H@("`@("`@("`@("`D87)G(#T@0"1T
M:&ES+3YC;VUM86YD<ULD8V]M;6%N9%U;)V]P=&EO;G,G75LD;W!T:6]N75LG
M87)G)UT[#0H@("`@("`@("`@("`D<VAO<G0@/2!`)'1H:7,M/F-O;6UA;F1S
M6R1C;VUM86YD75LG;W!T:6]N<R==6R1O<'1I;VY=6R=S:&]R=&]P="==.PT*
M("`@("`@("`@("`@)&-M9"`N/2`D<VAO<G0@/R`B("TD<VAO<G0B(#H@(B`M
M+21O<'1I;VXB.PT*("`@("`@("`@("`@:68@*"1A<F<@)B8@)&]P=&%R9RD@
M>PT*("`@("`@("`@("`@("`@("1C;60@+CT@*"1S:&]R="`_("<G(#H@)STG
M*2`N(&5S8V%P97-H96QL87)G*"1O<'1A<F<I.PT*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@(&9O<F5A8V@@*"1F:6QE<R!A<R`D9FEL92D@
M>PT*("`@("`@("`@("`@)&-M9"`N/2`G("<@+B!E<V-A<&5S:&5L;&%R9R@D
M9FEL95LG;F%M92==*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'1H:7,M
M/F-O;F9I9RT^9V5T*"=V97)B;W-E)RD@/B`Q*2![#0H@("`@("`@("`@("`D
M=&AI<RT^;W5T<'5T("X]("(K("1C;61<;B([#0H@("`@("`@('T-"B`@("`@
M("`@:68@*"1E>&5C=71E*2![#0H@("`@("`@("`@("`D9G`@/2!P;W!E;B@D
M8VUD+"`B<B(I.PT*("`@("`@("`@("`@=VAI;&4@*"1L:6YE(#T@9F=E=',H
M)&9P+"`Q,#(T*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3YO=71P=70@
M+CT@<G1R:6TH)&QI;F4I+B)<;B([#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!P8VQO<V4H)&9P*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^
M=6DM/F]U='!U=$1A=&$H)'1H:7,M/F]U='!U="P@)&-O;6UA;F0I.PT*("`@
M("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O
M+R![>WL@9&]086-K86=E1&5P96YD96YC:65S*"D-"@T*("`@(&9U;F-T:6]N
M(&1O4&%C:V%G941E<&5N9&5N8VEE<R@D8V]M;6%N9"P@)&]P=&EO;G,L("1P
M87)A;7,I#0H@("`@>PT*("`@("`@("`O+R`D<&%R86US6S!=("T^('1H92!0
M14%2('!A8VMA9V4@=&\@;&ES="!I=',@:6YF;W)M871I;VX-"B`@("`@("`@
M:68@*'-I>F5O9B@D<&%R86US*2`A/2`Q*2![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H(F)A9"!P87)A;65T97(H<RDL('1R>2!<
M(FAE;'`@)&-O;6UA;F1<(B(I.PT*("`@("`@("!]#0H@("`@("`@("1O8FH@
M/2`F)'1H:7,M/F=E=%!A8VMA9V5&:6QE*"1T:&ES+3YC;VYF:6<L("1T:&ES
M+3Y?9&5B=6<I.PT*("`@("`@("`D:6YF;R`]("1O8FHM/F9R;VU!;GE&:6QE
M*"1P87)A;7-;,%TL(%!%05)?5D%,241!5$5?3D]234%,*3L-"B`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)&EN9F\I*2![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H)&EN9F\I.PT*("`@("`@("!]#0H@("`@
M("`@("1D97!S(#T@)&EN9F\M/F=E=$1E<',H*3L-"B`@("`@("`@:68@*&ES
M7V%R<F%Y*"1D97!S*2D@>PT*("`@("`@("`@("`@:68@*"1I;F9O+3YG9710
M86-K86=E>&UL5F5R<VEO;B@I(#T]("<Q+C`G*2![#0H@("`@("`@("`@("`@
M("`@)&1A=&$@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)V-A<'1I
M;VXG(#T^("=$97!E;F1E;F-I97,@9F]R('!E87(O)R`N("1I;F9O+3YG9710
M86-K86=E*"DL#0H@("`@("`@("`@("`@("`@("`@("=B;W)D97(G(#T^('1R
M=64L#0H@("`@("`@("`@("`@("`@("`@("=H96%D;&EN92<@/3X@87)R87DH
M(E)E<75I<F5D/R(L(")4>7!E(BP@(DYA;64B+"`B4F5L871I;VXB+"`B5F5R
M<VEO;B(I+`T*("`@("`@("`@("`@("`@("`@("`I.PT*#0H@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)&1E<',@87,@)&0I('L-"B`@("`@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1D6R=O<'1I;VYA;"==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*"1D6R=O<'1I;VYA;"==(#T]("=Y97,G*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E<2`]("=.;R<[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1R97$@/2`G665S)SL-"B`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1R97$@/2`G665S)SL-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]D97!S7W)E;%]T<F%N<ULD9%LG<F5L)UU=*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)')E;"`]("1T:&ES+3Y?9&5P<U]R96Q?=')A
M;G-;)&1;)W)E;"==73L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1R96P@/2`D9%LG<F5L)UT[#0H@
M("`@("`@("`@("`@("`@("`@('T-"@T*("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/E]D97!S7W1Y<&5?=')A;G-;)&1;)W1Y<&4G75TI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D='EP92`]('5C9FER<W0H
M)'1H:7,M/E]D97!S7W1Y<&5?=')A;G-;)&1;)W1Y<&4G75TI.PT*("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)'1Y<&4@/2`D9%LG='EP92==.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D6R=N86UE)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D;F%M92`]("1D6R=N86UE
M)UT[#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D;F%M92`]("<G.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D6R=V97)S
M:6]N)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=F5R<VEO;B`]
M("1D6R=V97)S:6]N)UT[#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D=F5R<VEO;B`]("<G.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H-"B`@("`@("`@("`@("`@("`@("`@)&1A
M=&%;)V1A=&$G75M=(#T@87)R87DH)')E<2P@)'1Y<&4L("1N86UE+"`D<F5L
M+"`D=F5R<VEO;BD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M?2!E;'-E('L@+R\@<&%C:V%G92YX;6P@,BXP(&1E<&5N9&5N8VEE<R!D:7-P
M;&%Y#0H@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+T1E<&5N
M9&5N8WDR+G!H<"<[#0H@("`@("`@("`@("`@("`@)&1E<',@/2`D:6YF;RT^
M9V5T1&5P96YD96YC:65S*"D[#0H@("`@("`@("`@("`@("`@)')E9R`]("8D
M=&AI<RT^8V]N9FEG+3YG971296=I<W1R>2@I.PT*("`@("`@("`@("`@("`@
M(&EF("AI<U]A<G)A>2@D9&5P<RDI('L-"B`@("`@("`@("`@("`@("`@("`@
M)&0@/2!N97<@4$5!4E]$97!E;F1E;F-Y,B@D=&AI<RT^8V]N9FEG+"!A<G)A
M>2@I+"`G)RD[#0H@("`@("`@("`@("`@("`@("`@("1D871A(#T@87)R87DH
M#0H@("`@("`@("`@("`@("`@("`@("`@("`G8V%P=&EO;B<@/3X@)T1E<&5N
M9&5N8VEE<R!F;W(@)R`N("1I;F9O+3YG971086-K86=E*"DL#0H@("`@("`@
M("`@("`@("`@("`@("`@("`G8F]R9&5R)R`]/B!T<G5E+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@)VAE861L:6YE)R`]/B!A<G)A>2@B4F5Q=6ER960_
M(BP@(E1Y<&4B+"`B3F%M92(L("=697)S:6]N:6YG)RP@)T=R;W5P)RDL#0H@
M("`@("`@("`@("`@("`@("`@("`@("`I.PT*("`@("`@("`@("`@("`@("`@
M("!F;W)E86-H("@D9&5P<R!A<R`D='EP92`]/B`D<W5B9"D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)')E<2`]("@D='EP92`]/2`G<F5Q=6ER960G
M*2`_("=997,G(#H@)TYO)SL-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@D='EP92`]/2`G9W)O=7`G*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&=R;W5P(#T@)'-U8F1;)V%T=')I8G,G75LG;F%M92==.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9W)O=7`@/2`G)SL-"B`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H
M)'-U8F1;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-U
M8F0@/2!A<G)A>2@D<W5B9"D[#0H@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D<W5B9"!A<R`D
M9W)O=7!A*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)&=R;W5P82!A<R`D9&5P='EP92`]/B`D9&5P:6YF;RD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&1E<'1Y<&4@/3T@)V%T
M=')I8G,G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&1E<'1Y
M<&4@/3T@)W!E87)I;G-T86QL97(G*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9&5P='EP92`]("=P96%R($EN<W1A;&QE<B<[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D9&5P:6YF;ULP
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D
M97!I;F9O(#T@87)R87DH)&1E<&EN9F\I.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1D97!I;F9O(&%S("1I;F8I('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1N86UE(#T@)R<[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&EN9ELG
M8VAA;FYE;"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1A;&EA<R`]("1R96<M/F-H86YN96Q!;&EA<R@D:6YF6R=C
M:&%N;F5L)UTI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@A)&%L:6%S*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1A;&EA<R`]("<H8VAA;FYE;#\I("<@
M+B1I;F9;)V-H86YN96PG73L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&YA;64@/2`D86QI87,@+B`G+R<[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&EN9ELG;F%M92==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N
M86UE("X]("1I;F9;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D:6YF6R=P871T97)N)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&YA;64@+CT@)&EN9ELG<&%T=&5R;B==.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D;F%M92`N/2`G)SL-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D:6YF6R=U<FDG72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M;F%M92`N/2`G(%LG("X@)&EN9ELG=7)I)UT@+B`@)UTG.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I;F9;)V-O;F9L:6-T
M<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1V97(@/2`G8V]N9FQI8W1S)SL-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'9E<B`]("1D+3Y?9V5T17AT<F%3=')I
M;F<H)&EN9BD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&%T
M85LG9&%T82==6UT@/2!A<G)A>2@D<F5Q+"!U8V9I<G-T*"1D97!T>7!E*2P@
M)&YA;64L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'9E<BP@)&=R;W5P*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"@T*("`@("`@("`@
M("`@)'1H:7,M/G5I+3YO=71P=71$871A*"1D871A+"`D8V]M;6%N9"D[#0H@
M("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@?0T*#0H@("`@("`@
M("\O($9A;&QB86-K#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@B
M5&AI<R!P86-K86=E(&1O97,@;F]T(&AA=F4@86YY(&1E<&5N9&5N8VEE<RXB
M+"`D8V]M;6%N9"D[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[
M(&1O4VEG;B@I#0H-"B`@("!F=6YC=&EO;B!D;U-I9VXH)&-O;6UA;F0L("1O
M<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@<F5Q=6ER95]O;F-E
M("=3>7-T96TN<&AP)SL-"B`@("`@("`@<F5Q=6ER95]O;F-E("=!<F-H:79E
M+U1A<BYP:'`G.PT*("`@("`@("`O+R!S:&]U;&0@;6]V92!M;W-T(&]F('1H
M:7,@8V]D92!I;G1O(%!%05)?4&%C:V%G97(-"B`@("`@("`@+R\@<V\@:70G
M;&P@8F4@96%S>2!T;R!I;7!L96UE;G0@(G!E87(@<&%C:V%G92`M+7-I9VXB
M#0H@("`@("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@(3T@,2D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")B860@<&%R86UE=&5R
M*',I+"!T<GD@7")H96QP("1C;VUM86YD7"(B*3L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H(69I;&5?97AI<W1S*"1P87)A;7-;,%TI*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F9I;&4@9&]E<R!N;W0@
M97AI<W0Z("1P87)A;7-;,%TB*3L-"B`@("`@("`@?0T*("`@("`@("`D;V)J
M(#T@)'1H:7,M/F=E=%!A8VMA9V5&:6QE*"1T:&ES+3YC;VYF:6<L("1T:&ES
M+3Y?9&5B=6<I.PT*("`@("`@("`D:6YF;R`]("1O8FHM/F9R;VU49WI&:6QE
M*"1P87)A;7-;,%TL(%!%05)?5D%,241!5$5?3D]234%,*3L-"B`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)&EN9F\I*2![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H)&EN9F\I.PT*("`@("`@("!]#0H@("`@
M("`@("1T87(@/2!N97<@07)C:&EV95]487(H)'!A<F%M<ULP72D[#0H@("`@
M("`@("1T;7!D:7(@/2!3>7-T96TZ.FUK=&5M<"@G+60@<&5A<G-I9VXG*3L-
M"B`@("`@("`@:68@*"$D=&%R+3YE>'1R86-T3&ES="@G<&%C:V%G93(N>&UL
M('!A8VMA9V4N<VEG)RP@)'1M<&1I<BDI('L-"B`@("`@("`@("`@(&EF("@A
M)'1A<BT^97AT<F%C=$QI<W0H)W!A8VMA9V4N>&UL('!A8VMA9V4N<VEG)RP@
M)'1M<&1I<BDI('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H(F9A:6QE9"!T;R!E>'1R86-T('1A<B!F:6QE(BD[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&9I;&5?97AI<W1S
M*"(D=&UP9&ER+W!A8VMA9V4N<VEG(BDI('L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@B<&%C:V%G92!A;')E861Y('-I9VYE9"(I
M.PT*("`@("`@("!]#0H@("`@("`@("1P86-K86=E>&UL(#T@)W!A8VMA9V4N
M>&UL)SL-"B`@("`@("`@:68@*&9I;&5?97AI<W1S*"(D=&UP9&ER+W!A8VMA
M9V4R+GAM;"(I*2![#0H@("`@("`@("`@("`D<&%C:V%G97AM;"`]("=P86-K
M86=E,BYX;6PG.PT*("`@("`@("!]#0H@("`@("`@($!U;FQI;FLH(B1T;7!D
M:7(O<&%C:V%G92YS:6<B*3L-"B`@("`@("`@)&EN<'5T(#T@)'1H:7,M/G5I
M+3YU<V5R1&EA;&]G*"1C;VUM86YD+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@87)R87DH)T=N=5!'(%!A<W-P:')A<V4G*2P-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"=P87-S=V]R9"<I*3L-"B`@("`@("`@)&=P9R`]('!O<&5N*")G<&<@+2UB
M871C:"`M+7!A<W-P:')A<V4M9F0@,"`M+6%R;6]R("TM9&5T86-H+7-I9VX@
M+2UO=71P=70@)'1M<&1I<B]P86-K86=E+G-I9R`D=&UP9&ER+R1P86-K86=E
M>&UL(#(^+V1E=B]N=6QL(BP@(G<B*3L-"B`@("`@("`@:68@*"$D9W!G*2![
M#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F=P9R!C
M;VUM86YD(&9A:6QE9"(I.PT*("`@("`@("!]#0H@("`@("`@(&9W<FET92@D
M9W!G+"`B)&EN<'5T6S!=7&XB*3L-"B`@("`@("`@:68@*'!C;&]S92@D9W!G
M*2!\?"`A9FEL95]E>&ES=',H(B1T;7!D:7(O<&%C:V%G92YS:6<B*2D@>PT*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")G<&<@<VEG
M;B!F86EL960B*3L-"B`@("`@("`@?0T*("`@("`@("`D=&%R+3YA9&1-;V1I
M9GDH(B1T;7!D:7(O<&%C:V%G92YS:6<B+"`G)RP@)'1M<&1I<BD[#0H@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@
M+RHJ#0H@("`@("H@1F]R('5N:70@=&5S=&EN9R!P=7)P;W-E<PT*("`@("`J
M+PT*("`@(&9U;F-T:6]N("9G971);G-T86QL97(H)B1U:2D-"B`@("![#0H@
M("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27TEN<W1A;&QE<B<I*2![
M#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O26YS=&%L;&5R+G!H
M<"<[#0H@("`@("`@('T-"B`@("`@("`@)&$@/2`F;F5W(%!%05)?26YS=&%L
M;&5R*"1U:2D[#0H@("`@("`@(')E='5R;B`D83L-"B`@("!]#0H@("`@#0H@
M("`@+RHJ#0H@("`@("H@1F]R('5N:70@=&5S=&EN9R!P=7)P;W-E<PT*("`@
M("`J+PT*("`@(&9U;F-T:6]N("9G971#;VUM86YD4&%C:V%G:6YG*"8D=6DL
M("8D8V]N9FEG*0T*("`@('L-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H
M)U!%05)?0V]M;6%N9%]086-K86=I;F<G*2D@>PT*("`@("`@("`@("`@0&EN
M8VQU9&5?;VYC92`G4$5!4B]#;VUM86YD+U!A8VMA9VEN9RYP:'`G.PT*("`@
M("`@("!]#0H@("`@("`@(`T*("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"=0
M14%27T-O;6UA;F1?4&%C:V%G:6YG)RDI('L-"B`@("`@("`@("`@("1A(#T@
M)FYE=R!014%27T-O;6UA;F1?4&%C:V%G:6YG*"1U:2P@)&-O;F9I9RD[#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D82`](&YU;&P[#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N("1A.PT*("`@('T-"@T*("`@("\O('M[
M>R!D;TUA:V524$TH*0T*#0H@("`@9G5N8W1I;VX@9&]-86ME4E!-*"1C;VUM
M86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@(')E<75I
M<F5?;VYC92`G4WES=&5M+G!H<"<[#0H@("`@("`@(')E<75I<F5?;VYC92`G
M07)C:&EV92]487(N<&AP)SL-"@T*("`@("`@("`O+R!#:&5C:R!T;R!S964@
M:68@4$5!4E]#;VUM86YD7U!A8VMA9VEN9R!I<R!I;G-T86QL960L(&%N9`T*
M("`@("`@("`O+R!T<F%N<W!A<F5N=&QY('-W:71C:"!T;R!U<V4@=&AE(")M
M86ME+7)P;2US<&5C(B!C;VUM86YD(&9R;VT@:70-"B`@("`@("`@+R\@:6YS
M=&5A9"P@:68@:70@9&]E<RX@3W1H97)W:7-E+"!C;VYT:6YU92!T;R!U<V4@
M=&AE(&]L9"!V97)S:6]N#0H@("`@("`@("\O(&]F(")M86ME<G!M(B!S=7!P
M;&EE9"!W:71H('1H:7,@<&%C:V%G92`H4$5!4BDN#0H@("`@("`@("1P86-K
M86=I;F=?8VUD(#T@)'1H:7,M/F=E=$-O;6UA;F1086-K86=I;F<H)'1H:7,M
M/G5I+"`D=&AI<RT^8V]N9FEG*3L-"B`@("`@("`@:68@*"1P86-K86=I;F=?
M8VUD("$]/2!N=6QL*2![#0H@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U
M=$1A=&$H)U!%05)?0V]M;6%N9%]086-K86=I;F<@:7,@:6YS=&%L;&5D.R!U
M<VEN9R`G+@T*("`@("`@("`@("`@("`@("=N97=E<B`B;6%K92UR<&TM<W!E
M8R(@8V]M;6%N9"!I;G-T96%D)RD[#0H@("`@("`@("`@("!R971U<FX@)'!A
M8VMA9VEN9U]C;60M/G)U;B@G;6%K92UR<&TM<W!E8R<L("1O<'1I;VYS+"`D
M<&%R86US*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1T:&ES
M+3YU:2T^;W5T<'5T1&%T82@G5T%23DE.1SH@(G!E87(@;6%K97)P;2(@:7,@
M;F]W(&1E<')E8V%T960[(&%N("<N#0H@("`@("`@("`@("`@("=I;7!R;W9E
M9"!V97)S:6]N(&ES(&%V86EL86)L92!V:6$@(G!E87(@;6%K92UR<&TM<W!E
M8R(L('=H:6-H("<N#0H@("`@("`@("`@("`@("=I<R!A=F%I;&%B;&4@8GD@
M:6YS=&%L;&EN9R!014%27T-O;6UA;F1?4&%C:V%G:6YG)RD[#0H@("`@("`@
M('T-"B`@("`@("`@#0H@("`@("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@(3T@
M,2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")B
M860@<&%R86UE=&5R*',I+"!T<GD@7")H96QP("1C;VUM86YD7"(B*3L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1P87)A;7-;,%TI
M*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F9I
M;&4@9&]E<R!N;W0@97AI<W0Z("1P87)A;7-;,%TB*3L-"B`@("`@("`@?0T*
M("`@("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[
M#0H@("`@("`@("1P:V<@/2`F)'1H:7,M/F=E=%!A8VMA9V5&:6QE*"1T:&ES
M+3YC;VYF:6<L("1T:&ES+3Y?9&5B=6<I.PT*("`@("`@("`D<&8@/2`F)'!K
M9RT^9G)O;4%N>49I;&4H)'!A<F%M<ULP72P@4$5!4E]604Q)1$%415].3U)-
M04PI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<&8I*2![#0H@("`@
M("`@("`@("`D=2`]("1P9BT^9V5T57-E<FEN9F\H*3L-"B`@("`@("`@("`@
M(&EF("AI<U]A<G)A>2@D=2DI('L-"B`@("`@("`@("`@("`@("!F;W)E86-H
M("@D=2!A<R`D97)R*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A
M<G)A>2@D97)R*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&5R<B`]
M("1E<G);)VUE<W-A9V4G73L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)&5R<BD[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"(D<&%R86US6S!=(&ES(&YO
M="!A('9A;&ED('!A8VMA9V4B*3L-"B`@("`@("`@?0T*("`@("`@("`D=&UP
M9&ER(#T@4WES=&5M.CIM:W1E;7`H87)R87DH)RUD)RP@)W!E87(R<G!M)RDI
M.PT*("`@("`@("`D:6YS=')O;W0@/2!3>7-T96TZ.FUK=&5M<"AA<G)A>2@G
M+60G+"`G<&5A<C)R<&TG*2D[#0H@("`@("`@("1T;7`@/2`D=&AI<RT^8V]N
M9FEG+3YG970H)W9E<F)O<V4G*3L-"B`@("`@("`@)'1H:7,M/F-O;F9I9RT^
M<V5T*"=V97)B;W-E)RP@,"D[#0H@("`@("`@("1I;G-T86QL97(@/2`D=&AI
M<RT^9V5T26YS=&%L;&5R*"1T:&ES+3YU:2D[#0H@("`@("`@(')E<75I<F5?
M;VYC92`G4$5!4B]$;W=N;&]A9&5R+U!A8VMA9V4N<&AP)SL-"B`@("`@("`@
M)'!A8VL@/2!N97<@4$5!4E]$;W=N;&]A9&5R7U!A8VMA9V4H)&EN<W1A;&QE
M<BD[#0H@("`@("`@("1P86-K+3YS971086-K86=E1FEL92@D<&8I.PT*("`@
M("`@("`D<&%R86US6S!=(#T@)B1P86-K.PT*("`@("`@("`D:6YS=&%L;&5R
M+3YS971/<'1I;VYS*&%R<F%Y*"=I;G-T86QL<F]O="<@/3X@)&EN<W1R;V]T
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)VYO9&5P<R<@/3X@=')U92P@)W-O9G0G(#T^('1R=64I*3L-"B`@("`@("`@
M)&EN<W1A;&QE<BT^<V5T1&]W;FQO861E9%!A8VMA9V5S*"1P87)A;7,I.PT*
M("`@("`@("`D:6YF;R`]("1I;G-T86QL97(M/FEN<W1A;&PH)'!A<F%M<ULP
M72P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"=I;G-T86QL<F]O="<@/3X@)&EN<W1R;V]T+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYO9&5P<R<@/3X@=')U92P@
M)W-O9G0G(#T^('1R=64I*3L-"B`@("`@("`@)'!K9V1I<B`]("1P9BT^9V5T
M4&%C:V%G92@I("X@)RTG("X@)'!F+3YG971697)S:6]N*"D[#0H@("`@("`@
M("1I;F9O6R=R<&U?>&UL7V1I<B==(#T@)R]V87(O;&EB+W!E87(G.PT*("`@
M("`@("`D=&AI<RT^8V]N9FEG+3YS970H)W9E<F)O<V4G+"`D=&UP*3L-"B`@
M("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=S<&5C+71E;7!L871E)UTI*2![
M#0H@("`@("`@("`@("`D<W!E8U]T96UP;&%T92`]("1O<'1I;VYS6R=S<&5C
M+71E;7!L871E)UT[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D
M<W!E8U]T96UP;&%T92`]("<O=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]D871A+U!%05(O=&5M<&QA=&4N<W!E8R<[#0H@("`@("`@('T-"B`@("`@
M("`@)&EN9F];)W!O<W-I8FQE7V-H86YN96PG72`]("<G.PT*("`@("`@("`D
M:6YF;ULG97AT<F%?8V]N9FEG)UT@/2`G)SL-"B`@("`@("`@:68@*&ES<V5T
M*"1O<'1I;VYS6R=R<&TM<&MG;F%M92==*2D@>PT*("`@("`@("`@("`@)')P
M;5]P:V=N86UE7V9O<FUA="`]("1O<'1I;VYS6R=R<&TM<&MG;F%M92==.PT*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@:68@*"1P9BT^9V5T0VAA
M;FYE;"@I(#T]("=P96%R+G!H<"YN970G('Q\("1P9BT^9V5T0VAA;FYE;"@I
M(#T]("=P96-L+G!H<"YN970G*2![#0H@("`@("`@("`@("`@("`@)&%L:6%S
M(#T@)U!%05(G.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`D8VAA;B`]("8D<F5G+3YG971#:&%N;F5L*"1P9BT^9V5T0VAA;FYE
M;"@I*3L-"B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8VAA
M;BDI('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*"1C:&%N*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@)&%L:6%S(#T@)&-H86XM/F=E=$%L:6%S*"D[#0H@("`@("`@("`@
M("`@("`@)&%L:6%S(#T@<W1R=&]U<'!E<B@D86QI87,I.PT*("`@("`@("`@
M("`@("`@("1I;F9O6R=P;W-S:6)L95]C:&%N;F5L)UT@/2`D<&8M/F=E=$-H
M86YN96PH*2`N("<O)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1R
M<&U?<&MG;F%M95]F;W)M870@/2`D86QI87,@+B`G.CHE<R<[#0H@("`@("`@
M('T-"@T*("`@("`@("`D:6YF;ULG97AT<F%?:&5A9&5R<R==(#T@)R<[#0H@
M("`@("`@("1I;F9O6R=D;V-?9FEL97,G72`]("<G.PT*("`@("`@("`D:6YF
M;ULG9FEL97,G72`]("<G.PT*("`@("`@("`D:6YF;ULG<&%C:V%G93)X;6PG
M72`]("<G.PT*("`@("`@("`D:6YF;ULG<G!M7W!A8VMA9V4G72`]('-P<FEN
M=&8H)')P;5]P:V=N86UE7V9O<FUA="P@)'!F+3YG971086-K86=E*"DI.PT*
M("`@("`@("`D<W)C9FEL97,@/2`P.PT*("`@("`@("!F;W)E86-H("@D:6YF
M;ULG9FEL96QI<W0G72!A<R`D;F%M92`]/B`D871T<BD@>PT*("`@("`@("`@
M("`@:68@*"%I<W-E="@D871T<ELG<F]L92==*2D@>PT*("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&YA
M;64@/2!P<F5G7W)E<&QA8V4H)R%;+SI<7%Q<72$G+"`G+R<L("1N86UE*3L-
M"B`@("`@("`@("`@(&EF("@D871T<ELG<F]L92==(#T]("=D;V,G*2![#0H@
M("`@("`@("`@("`@("`@)&EN9F];)V1O8U]F:6QE<R==("X]("(@)&YA;64B
M.PT*("`@("`@("`@("`@+R\@36%P(')O;&4@=&\@=&AE(')P;2!V87)S#0H@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1C7W!R969I
M>"`]("<E>U]L:6)D:7)]+W!H<"]P96%R)SL-"B`@("`@("`@("`@("`@("!S
M=VET8V@@*"1A='1R6R=R;VQE)UTI('L-"B`@("`@("`@("`@("`@("`@("`@
M8V%S92`G<&AP)SH-"B`@("`@("`@("`@("`@("`@("`@("`@("1P<F5F:7@@
M/2`D8U]P<F5F:7@[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@
M("`@("`@("`@("`@("`@("!C87-E("=E>'0G.@T*("`@("`@("`@("`@("`@
M("`@("`@("`@)'!R969I>"`]("<E>U]L:6)D:7)]+W!H<"<[#0H@("`@("`@
M("`@("`@("`@("`@(&)R96%K.R`O+R!86%@@9V]O9"!P;&%C93\-"B`@("`@
M("`@("`@("`@("`@("`@8V%S92`G<W)C)SH-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1S<F-F:6QE<RLK.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M)'!R969I>"`]("<E>U]I;F-L=61E9&ER?2]P:'`G.PT*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL@+R\@6%A8(&=O;V0@<&QA8V4_#0H@("`@("`@("`@
M("`@("`@("`@(&-A<V4@)W1E<W0G.@T*("`@("`@("`@("`@("`@("`@("`@
M("`@)'!R969I>"`]("(D8U]P<F5F:7@O=&5S=',O(B`N("1P9BT^9V5T4&%C
M:V%G92@I.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M("`@("`@("`@("`@8V%S92`G9&%T82<Z#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D<')E9FEX(#T@(B1C7W!R969I>"]D871A+R(@+B`D<&8M/F=E=%!A
M8VMA9V4H*3L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@
M("`@("`@("`@("`@(&-A<V4@)W-C<FEP="<Z#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D<')E9FEX(#T@)R5[7V)I;F1I<GTG.PT*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@9&5F875L=#H@
M+R\@;F]N+7-T86YD87)D(')O;&5S#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D<')E9FEX(#T@(B1C7W!R969I>"\D871T<EMR;VQE72\B("X@)'!F+3YG
M971086-K86=E*"D[#0H@("`@("`@("`@("`@("`@("`@("`@("`D:6YF;ULG
M97AT<F%?8V]N9FEG)UT@+CT-"B`@("`@("`@("`@("`@("`@("`@("`@(")<
M;B`@("`@("`@+60@>R1A='1R6W)O;&5=?5]D:7(])&-?<')E9FEX+WLD871T
M<EMR;VQE77T@7%PB.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/G5I+3YO=71P=71$871A*"=705).24Y'.B!R;VQE("(G("X@)&%T=');)W)O
M;&4G72`N("<B('5S960L("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=A;F0@=VEL;"!B92!I;G-T86QL960@:6X@(B<@+B`D8U]P<F5F:7@@
M+B`G+R<@+B`D871T<ELG<F]L92==("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G+R<@+B`D<&8M/F=E=%!A8VMA9V4H*2`N#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)R`M(&AA;F0M961I="!T:&4@9FEN86P@+G-P
M96,@:68@=&AI<R!I<R!W<F]N9R<L("1C;VUM86YD*3L-"B`@("`@("`@("`@
M("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("1N86UE(#T@<W1R7W)E<&QA8V4H)UQ<)RP@)R\G+"`D;F%M92D[
M#0H@("`@("`@("`@("`@("`@)&EN9F];)V9I;&5S)UT@+CT@(B1P<F5F:7@O
M)&YA;65<;B([#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M:68@*"1S<F-F:6QE<R`^(#`I('L-"B`@("`@("`@("`@(')E<75I<F5?;VYC
M92`G3U,O1W5E<W,N<&AP)SL-"B`@("`@("`@("`@("1O<R`](&YE=R!/4U]'
M=65S<SL-"B`@("`@("`@("`@("1A<F-H(#T@)&]S+3YG971#<'4H*3L-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1A<F-H(#T@)VYO87)C:"<[
M#0H@("`@("`@('T-"B`@("`@("`@)&-F9R`](&%R<F%Y*"=M87-T97)?<V5R
M=F5R)RP@)W!H<%]D:7(G+"`G97AT7V1I<B<L("=D;V-?9&ER)RP-"B`@("`@
M("`@("`@("`@("`@("`@("=B:6Y?9&ER)RP@)V1A=&%?9&ER)RP@)W1E<W1?
M9&ER)RD[#0H@("`@("`@(&9O<F5A8V@@*"1C9F<@87,@)&LI('L-"B`@("`@
M("`@("`@(&EF("@D:R`]/2`G;6%S=&5R7W-E<G9E<B<I('L-"B`@("`@("`@
M("`@("`@("`D8VAA;B`]("1R96<M/F=E=$-H86YN96PH)'!F+3YG971#:&%N
M;F5L*"DI.PT*("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1C
M:&%N*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H)&-H86XI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`D:6YF;ULD:UT@/2`D8VAA;BT^9V5T4V5R=F5R*"D[#0H@("`@
M("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`D:6YF;ULD:UT@/2`D=&AI<RT^8V]N9FEG+3YG970H)&LI.PT*("`@
M("`@("!]#0H@("`@("`@("1I;F9O6R=A<F-H)UT@/2`D87)C:#L-"B`@("`@
M("`@)&9P(#T@0&9O<&5N*"1S<&5C7W1E;7!L871E+"`B<B(I.PT*("`@("`@
M("!I9B`H(21F<"D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*")C;W5L9"!N;W0@;W!E;B!24$T@<W!E8R!F:6QE('1E;7!L871E
M("1S<&5C7W1E;7!L871E.B`D<&AP7V5R<F]R;7-G(BD[#0H@("`@("`@('T-
M"B`@("`@("`@)&EN9F];)W!A8VMA9V4G72`]("1P9BT^9V5T4&%C:V%G92@I
M.PT*("`@("`@("`D:6YF;ULG=F5R<VEO;B==(#T@)'!F+3YG971697)S:6]N
M*"D[#0H@("`@("`@("1I;F9O6R=R96QE87-E7VQI8V5N<V4G72`]("1P9BT^
M9V5T3&EC96YS92@I.PT*("`@("`@("!I9B`H)'!F+3YG971$97!S*"DI('L-
M"B`@("`@("`@("`@(&EF("@D<&8M/F=E=%!A8VMA9V5X;6Q697)S:6]N*"D@
M/3T@)S$N,"<I('L-"B`@("`@("`@("`@("`@("`D<F5Q=6ER97,@/2`D8V]N
M9FQI8W1S(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D
M<&8M/F=E=$1E<',H*2!A<R`D9&5P*2![#0H@("`@("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D9&5P6R=O<'1I;VYA;"==*2`F)B`D9&5P6R=O<'1I;VYA
M;"==(#T]("=Y97,G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!C;VYT
M:6YU93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("!I9B`H)&1E<%LG='EP92==("$]("=P:V<G*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG8VAA;FYE
M;"==*2`F)B`D9&5P6R=C:&%N;F5L)UT@(3T@)W!E87(N<&AP+FYE="<@)B8-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E<%LG8VAA;FYE;"==("$]
M("=P96-L+G!H<"YN970G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M8VAA;B`]("8D<F5G+3YG971#:&%N;F5L*"1D97!;)V-H86YN96PG72D[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8VAA
M;BDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H)&-H86XI.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@)'!A8VMA9V4@/2!S=')T
M;W5P<&5R*"1C:&%N+3YG971!;&EA<R@I*2`N("<Z.B<@+B`D9&5P6R=N86UE
M)UT[#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D<&%C:V%G92`]("=014%2.CHG("X@)&1E<%LG;F%M
M92==.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("1T<F%N<R`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@
M)SXG(#T^("<^)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("<\)R`]/B`G
M/"<L#0H@("`@("`@("`@("`@("`@("`@("`@("`G/CTG(#T^("<^/2<L#0H@
M("`@("`@("`@("`@("`@("`@("`@("`G/#TG(#T^("<\/2<L#0H@("`@("`@
M("`@("`@("`@("`@("`@("`G/2<@/3X@)STG+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@)V=T)R`]/B`G/B<L#0H@("`@("`@("`@("`@("`@("`@("`@
M("`G;'0G(#T^("<\)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("=G92<@
M/3X@)SX])RP-"B`@("`@("`@("`@("`@("`@("`@("`@("=L92<@/3X@)SP]
M)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("=E<2<@/3X@)STG+`T*("`@
M("`@("`@("`@("`@("`@("`I.PT*("`@("`@("`@("`@("`@("`@("!I9B`H
M)&1E<%LG<F5L)UT@/3T@)VAA<R<I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1R97%U:7)E<UM=(#T@)'!A8VMA9V4[#0H@("`@("`@("`@("`@("`@
M("`@('T@96QS96EF("@D9&5P6R=R96PG72`]/2`G;F]T)RD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)&-O;F9L:6-T<UM=(#T@)'!A8VMA9V4[#0H@
M("`@("`@("`@("`@("`@("`@('T@96QS96EF("@D9&5P6R=R96PG72`]/2`G
M;F4G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D8V]N9FQI8W1S6UT@
M/2`D<&%C:V%G92`N("<@/2`G("X@)&1E<%LG=F5R<VEO;B==.PT*("`@("`@
M("`@("`@("`@("`@("!](&5L<V5I9B`H:7-S970H)'1R86YS6R1D97!;)W)E
M;"==72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1R97%U:7)E<UM=
M(#T@)'!A8VMA9V4@+B`G("<@+B`D=')A;G-;)&1E<%LG<F5L)UU=("X@)R`G
M("X@)&1E<%LG=F5R<VEO;B==.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AC;W5N="@D
M<F5Q=6ER97,I*2![#0H@("`@("`@("`@("`@("`@("`@("1I;F9O6R=E>'1R
M85]H96%D97)S)UT@+CT@)U)E<75I<F5S.B`G("X@:6UP;&]D92@G+"`G+"`D
M<F5Q=6ER97,I("X@(EQN(CL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@:68@*&-O=6YT*"1C;VYF;&EC=',I*2![#0H@("`@("`@("`@
M("`@("`@("`@("1I;F9O6R=E>'1R85]H96%D97)S)UT@+CT@)T-O;F9L:6-T
M<SH@)R`N(&EM<&QO9&4H)RP@)RP@)&-O;F9L:6-T<RD@+B`B7&XB.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@)&EN9F];)W!A8VMA9V4R>&UL)UT@/2`G,B<[("\O('1E;&P@
M=&AE('-P96,@=&\@=7-E('!A8VMA9V4R+GAM;`T*("`@("`@("`@("`@("`@
M("1R97%U:7)E<R`]("1C;VYF;&EC=',@/2!A<G)A>2@I.PT*("`@("`@("`@
M("`@("`@("1D97!S(#T@)'!F+3YG971$97!S*'1R=64I.PT*("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D9&5P<ULG<F5Q=6ER960G75LG<&%C:V%G92==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1D97!S6R=R
M97%U:7)E9"==6R=P86-K86=E)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D9&5P<ULG<F5Q=6ER960G75LG<&%C:V%G92==(#T@87)R87DH
M)&1E<'-;)W)E<75I<F5D)UU;)W!A8VMA9V4G72D[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&1E<'-;
M)W)E<75I<F5D)UU;)W!A8VMA9V4G72!A<R`D9&5P*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H)&1E<%LG8VAA;FYE;"==("$]("=P96%R+G!H
M<"YN970G("8F("`D9&5P6R=C:&%N;F5L)UT@(3T@)W!E8VPN<&AP+FYE="<I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8VAA;B`]("8D<F5G
M+3YG971#:&%N;F5L*"1D97!;)V-H86YN96PG72D[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&-H86XI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@D8VAA;BD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E(#T@
M<W1R=&]U<'!E<B@D8VAA;BT^9V5T06QI87,H*2D@+B`G.CHG("X@)&1E<%LG
M;F%M92==.PT*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%C:V%G92`]("=014%2.CHG
M("X@)&1E<%LG;F%M92==.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)V-O;F9L
M:6-T<R==*2`F)B`H:7-S970H)&1E<%LG;6EN)UTI('Q\#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I<W-E="@D9&5P6R=M87@G72DI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E<')A;F=E(#T@87)R87DH
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E
M<%LG;6EN)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1D97!R86YG95M=(#T@87)R87DH)&1E<%LG;6EN)UTL)SX])RD[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=M87@G72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&1E<')A;F=E6UT@/2!A<G)A>2@D
M9&5P6R=M87@G72P@)SP])RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M9&5P6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@A:7-?87)R87DH)&1E<%LG97AC;'5D92==*2!\?`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`A:7-S970H)&1E
M<%LG97AC;'5D92==6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&1E<%LG97AC;'5D92==(#T@87)R87DH)&1E<%LG97AC
M;'5D92==*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)&1E
M<')A;F=E*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&5X8VP@/2`D9&5P6R=E>&-L=61E)UT[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`O+R!C:&%N9V4@/CT@=&\@/B!I9B!E>&-L
M=61I;F<@=&AE(&UI;B!V97)S:6]N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!C:&%N9V4@/#T@=&\@/"!I9B!E>&-L=61I;F<@
M=&AE(&UA>"!V97)S:6]N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!F;W(H)&D@/2`P.R`D:2`\(&-O=6YT*"1E>&-L*3L@)&DK*RD@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D9&5P<F%N9V5;,%TI("8F#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5X8VQ;)&E=(#T]("1D97!R
M86YG95LP75LP72D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9&5P<F%N9V5;,%U;,5T@/2`G/"<[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1D
M97!;)V5X8VQU9&4G75LD:5TI.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<')A;F=E6S%=*2`F)@T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E
M>&-L6R1I72`]/2`D9&5P<F%N9V5;,5U;,%TI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E<')A;F=E6S%=6S%=
M(#T@)SXG.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!U;G-E="@D9&5P6R=E>&-L=61E)UU;)&E=*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*&-O=6YT*"1D97!;)V5X8VQU9&4G72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D97!;)V5X8VQU9&4G72`]
M(&%R<F%Y7W9A;'5E<R@D9&5P6R=E>&-L=61E)UTI.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&YE=V1E<')A;F=E(#T@87)R87DH
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(')E
M;6]V92!E>&-L=61E<R!T:&%T(&%R92!O=71S:61E('1H92!E>&ES=&EN9R!R
M86YG90T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R
M("@D:2`](#`[("1I(#P@8V]U;G0H)&1E<%LG97AC;'5D92==*3L@)&DK*RD@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@D9&5P6R=E>&-L=61E)UU;)&E=(#P@)&1E<%LG;6EN)UT@?'P-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P
M6R=E>&-L=61E)UU;)&E=(#X@)&1E<%LG;6%X)UTI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)&1E<%LG
M97AC;'5D92==6R1I72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&1E<%LG97AC;'5D92==(#T@87)R87E?=F%L=65S*"1D97!;)V5X8VQU9&4G
M72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!U<V]R
M="@D9&5P6R=E>&-L=61E)UTL("=V97)S:6]N7V-O;7!A<F4G*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O('1A:V4@=&AE(')E
M;6%I;FEN9R!E>&-L=61E<R!A;F0-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("\O('-P;&ET('1H92!D97!E;F1E;F-Y(&EN=&\@<W5B
M+7)A;F=E<PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&QA<W1M:6X@/2`D9&5P<F%N9V5;,%T[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D9&5P
M6R=E>&-L=61E)UTI("T@,3L@)&DK*RD@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1N97=D97!R86YG95M=(#T@)R@G("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!A8VMA9V4@+B`B('LD;&%S=&UI;ELQ77T@>R1L87-T;6EN6S!=?2!A;F0@
M(B`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1P86-K86=E("X@)R`\("<@+B`D9&5P6R=E>&-L=61E)UU;)&E=("X@
M)RDG.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1L87-T;6EN(#T@87)R87DH)&1E<%LG97AC;'5D92==6R1I72P@)SXG*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P
M6R=M87@G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D;F5W9&5P<F%N9V5;72`]("<H)R`N("1P86-K86=E("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(B![
M)&QA<W1M:6Y;,5U]('LD;&%S=&UI;ELP77T@86YD("(@+@T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%C:V%G92`N
M("<@/"`G("X@)&1E<%LG;6%X)UT@+B`G*2<[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D8V]N9FQI8W1S6UT@/2!I;7!L;V1E*"<@;W(@)RP@
M)&1E<')A;F=E*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1C;VYF;&EC='-;72`]("1P86-K86=E("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`B('LD9&5P<F%N9V5;,%U;,5U]('LD
M9&5P<F%N9V5;,%U;,%U](B`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@*&ES<V5T*"1D97!R86YG95LQ72D@/R`-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B(&%N9"`D<&%C
M:V%G92![)&1E<')A;F=E6S%=6S%=?2![)&1E<')A;F=E6S%=6S!=?2(-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("<G*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&1E<%LG;6EN)UTI
M("8F("%I<W-E="@D9&5P6R=M87@G72D@)B8-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("%I<W-E="@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)V-O;F9L
M:6-T<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M8V]N9FQI8W1S6UT@/2`D<&%C:V%G93L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<F5Q=6ER97-;72`]("1P86-K86=E.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D
M97!;)VUI;B==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<F5Q=6ER97-;72`]("1P86-K86=E("X@)R`^/2`G("X@)&1E<%LG;6EN
M)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=M87@G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E<75I<F5S6UT@
M/2`D<&%C:V%G92`N("<@/#T@)R`N("1D97!;)VUA>"==.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)&1E<%LG97AC;'5D92==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D97@@/2`D9&5P6R=E>&-L=61E)UT[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?87)R
M87DH)&5X*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&5X(#T@87)R87DH)&5X*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F
M;W)E86-H("@D97@@87,@)'9E<BD@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&-O;F9L:6-T<UM=(#T@)'!A8VMA9V4@+B`G(#T@
M)R`N("1V97([#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=!<F-H:79E+U1A<BYP:'`G.PT*
M("`@("`@("`@("`@("`@("`@("`D=&%R(#T@;F5W($%R8VAI=F5?5&%R*"1P
M9BT^9V5T07)C:&EV949I;&4H*2D[#0H@("`@("`@("`@("`@("`@("`@("1T
M87(M/G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@
M("`@("`@("`@("`@("`@("`@)&$@/2`D=&%R+3YE>'1R86-T26Y3=')I;F<H
M)W!A8VMA9V4R+GAM;"<I.PT*("`@("`@("`@("`@("`@("`@("`D=&%R+3YP
M;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("`@("`@("`@(&EF("@D
M82`]/3T@;G5L;"!\?"!014%2.CII<T5R<F]R*"1A*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)&EN9F];)W!A8VMA9V4R>&UL)UT@/2`G)SL-"B`@
M("`@("`@("`@("`@("`@("`@("`@("\O('1H:7,@9&]E<VXG="!H879E(&$@
M<&%C:V%G92YX;6P@=F5R<VEO;B`Q+C`-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1R97%U:7)E<UM=(#T@)U!%05(Z.E!%05(@/CT@)R`N#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&1E<'-;)W)E<75I<F5D)UU;)W!E87)I
M;G-T86QL97(G75LG;6EN)UT[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1R97%U:7)E<RDI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R=E>'1R85]H96%D97)S)UT@
M+CT@)U)E<75I<F5S.B`G("X@:6UP;&]D92@G+"`G+"`D<F5Q=6ER97,I("X@
M(EQN(CL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("!I9B`H8V]U;G0H)&-O;F9L:6-T<RDI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1I;F9O6R=E>'1R85]H96%D97)S)UT@+CT@)T-O;F9L:6-T
M<SH@)R`N(&EM<&QO9&4H)RP@)RP@)&-O;F9L:6-T<RD@+B`B7&XB.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H-"B`@("`@("`@+R\@<F5M;W9E('1H92!T
M<F%I;&EN9R!N97=L:6YE#0H@("`@("`@("1I;F9O6R=E>'1R85]H96%D97)S
M)UT@/2!T<FEM*"1I;F9O6R=E>'1R85]H96%D97)S)UTI.PT*("`@("`@("!I
M9B`H9G5N8W1I;VY?97AI<W1S*"=F:6QE7V=E=%]C;VYT96YT<R<I*2![#0H@
M("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@("`@("1S<&5C7V-O
M;G1E;G1S(#T@<')E9U]R97!L86-E*"<O0"A;82UZ,"TY7RU=*RE`+V4G+"`G
M)&EN9F];(EPQ(ETG+`T*("`@("`@("`@("`@("`@(&9I;&5?9V5T7V-O;G1E
M;G1S*"1S<&5C7W1E;7!L871E*2D[#0H@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`D<W!E8U]C;VYT96YT<R`]('!R96=?<F5P;&%C92@G+T`H6V$M
M>C`M.5\M72LI0"]E)RP@)R1I;F9O6R)<,2)=)RP-"B`@("`@("`@("`@("`@
M("!F<F5A9"@D9G`L(&9I;&5S:7IE*"1S<&5C7W1E;7!L871E*2DI.PT*("`@
M("`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@('T-"B`@("`@("`@)'-P
M96-?9FEL92`]("(D:6YF;UMR<&U?<&%C:V%G95TM)&EN9F];=F5R<VEO;ETN
M<W!E8R([#0H@("`@("`@("1W<"`](&9O<&5N*"1S<&5C7V9I;&4L(")W8B(I
M.PT*("`@("`@("!I9B`H(21W<"D@>PT*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*")C;W5L9"!N;W0@=W)I=&4@4E!-('-P96,@9FEL
M92`D<W!E8U]F:6QE.B`D<&AP7V5R<F]R;7-G(BD[#0H@("`@("`@('T-"B`@
M("`@("`@9G=R:71E*"1W<"P@)'-P96-?8V]N=&5N=',I.PT*("`@("`@("!F
M8VQO<V4H)'=P*3L-"B`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*")7
M<F]T92!24$T@<W!E8R!F:6QE("1S<&5C7V9I;&4B+"`D8V]M;6%N9"D[#0H-
M"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M9&]#;VYV97)T*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![
M#0H@("`@("`@("1P86-K86=E>&UL(#T@:7-S970H)'!A<F%M<ULP72D@/R`D
M<&%R86US6S!=(#H@)W!A8VMA9V4N>&UL)SL-"B`@("`@("`@)&YE=W!A8VMA
M9V5X;6P@/2!I<W-E="@D<&%R86US6S%=*2`_("1P87)A;7-;,5T@.B!D:7)N
M86UE*"1P86-K86=E>&UL*2`N#0H@("`@("`@("`@("!$25)%0U1/4EE?4T50
M05)!5$]2("X@)W!A8VMA9V4R+GAM;"<[#0H@("`@("`@("1P:V<@/2`F)'1H
M:7,M/F=E=%!A8VMA9V5&:6QE*"1T:&ES+3YC;VYF:6<L("1T:&ES+3Y?9&5B
M=6<I.PT*("`@("`@("!014%2.CIS=&%T:6-0=7-H17)R;W)(86YD;&EN9RA0
M14%27T524D]27U)%5%523BD[#0H@("`@("`@("1P9B`]("1P:V<M/F9R;VU0
M86-K86=E1FEL92@D<&%C:V%G97AM;"P@4$5!4E]604Q)1$%415].3U)-04PI
M.PT*("`@("`@("!014%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L:6YG*"D[#0H@
M("`@("`@(&EF("@A4$5!4CHZ:7-%<G)O<B@D<&8I*2![#0H@("`@("`@("`@
M("!I9B`H:7-?82@D<&8L("=014%27U!A8VMA9V5&:6QE7W8R)RDI('L-"B`@
M("`@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)'!A8VMA9V5X
M;6P@+B`G(&ES(&%L<F5A9'D@82!P86-K86=E+GAM;"!V97)S:6]N(#(N,"<I
M.PT*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@)&=E;B`]("8D<&8M/F=E=$1E9F%U;'1'96YE<F%T
M;W(H*3L-"B`@("`@("`@("`@("1N97=P9B`]("8D9V5N+3YT;U8R*"D[#0H@
M("`@("`@("`@("`D;F5W<&8M/G-E=%!A8VMA9V5F:6QE*"1N97=P86-K86=E
M>&UL*3L-"B`@("`@("`@("`@("1G96X@/2`F)&YE=W!F+3YG971$969A=6QT
M1V5N97)A=&]R*"D[#0H@("`@("`@("`@("!014%2.CIS=&%T:6-0=7-H17)R
M;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@("`@("`D
M<W1A=&4@/2`H:7-S970H)&]P=&EO;G-;)V9L870G72D@/R!014%27U9!3$E$
M051%7U!!0TM!1TE.1R`Z(%!%05)?5D%,241!5$5?3D]234%,*3L-"B`@("`@
M("`@("`@("1S879E9"`]("1G96XM/G1O4&%C:V%G949I;&4H9&ER;F%M92@D
M;F5W<&%C:V%G97AM;"DL("1S=&%T92P-"B`@("`@("`@("`@("`@("!B87-E
M;F%M92@D;F5W<&%C:V%G97AM;"DI.PT*("`@("`@("`@("`@4$5!4CHZ<W1A
M=&EC4&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)'-A=F5D*2D@>PT*("`@("`@("`@("`@("`@(&EF("AI<U]A
M<G)A>2@D<V%V960M/F=E=%5S97));F9O*"DI*2![#0H@("`@("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1S879E9"T^9V5T57-E<DEN9F\H*2!A<R`D=V%R
M;FEN9RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G5I+3YO
M=71P=71$871A*"1W87)N:6YG6R=M97-S86=E)UTI.PT*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D<V%V960M/F=E=$UE<W-A9V4H*2D[
M#0H@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)U=R;W1E(&YE
M=R!V97)S:6]N(#(N,"!P86-K86=E+GAM;"!T;R`B)R`N("1S879E9"`N("<B
M)RD[#0H@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D<&8M/F=E=%5S97));F9O
M*"DI*2![#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!F+3YG9715<V5R
M26YF;R@I(&%S("1W87)N:6YG*2![#0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YU:2T^;W5T<'5T1&%T82@D=V%R;FEN9ULG;65S<V%G92==*3L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)'!F*3L-"B`@("`@("`@?0T*("`@
M('T-"@T*("`@("\O('U]?0T*?0T*#0H_/@T*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N
M9"]0:6-K;&4N>&UL````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#(W-C,@,3`U,34T,S,W,S$@,#(R-3,R`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#QC;VUM86YD<R!V97)S:6]N/2(Q+C`B
M/@T*(#QP:6-K;&4^#0H@(#QS=6UM87)Y/D)U:6QD(%!%0TP@4&%C:V%G93PO
M<W5M;6%R>3X-"B`@/&9U;F-T:6]N/F1O4&%C:V%G93PO9G5N8W1I;VX^#0H@
M(#QS:&]R=&-U=#YP:3PO<VAO<G1C=70^#0H@(#QO<'1I;VYS/@T*("`@/&YO
M8V]M<')E<W,^#0H@("`@/'-H;W)T;W!T/EH\+W-H;W)T;W!T/@T*("`@(#QD
M;V,^1&\@;F]T(&=Z:7`@=&AE('!A8VMA9V4@9FEL93PO9&]C/@T*("`@/"]N
M;V-O;7!R97-S/@T*("`@/'-H;W=N86UE/@T*("`@(#QS:&]R=&]P=#YN/"]S
M:&]R=&]P=#X-"B`@("`\9&]C/E!R:6YT('1H92!N86UE(&]F('1H92!P86-K
M86=E9"!F:6QE+CPO9&]C/@T*("`@/"]S:&]W;F%M93X-"B`@/"]O<'1I;VYS
M/@T*("`\9&]C/EMD97-C9FEL95T@6V1E<V-F:6QE,ET-"D-R96%T97,@82!0
M14-,('!A8VMA9V4@9G)O;2!I=',@9&5S8W)I<'1I;VX@9FEL92`H=7-U86QL
M>2!C86QL960-"G!A8VMA9V4N>&UL*2X@($EF(&$@<V5C;VYD('!A8VMA9V5F
M:6QE(&ES('!A<W-E9"!I;BP@=&AE;@T*=&AE('!A8VMA9V5R('=I;&P@8VAE
M8VL@=&\@;6%K92!S=7)E('1H870@;VYE(&ES(&$@<&%C:V%G92YX;6P-"G9E
M<G-I;VX@,2XP+"!A;F0@=&AE(&]T:&5R(&ES(&$@<&%C:V%G92YX;6P@=F5R
M<VEO;B`R+C`N("!4:&4-"G!A8VMA9V4N>&UL('9E<G-I;VX@,2XP('=I;&P@
M8F4@<V%V960@87,@)G%U;W0[<&%C:V%G92YX;6PF<75O=#L@:6X@=&AE(&%R
M8VAI=F4L#0IA;F0@=&AE(&]T:&5R(&%S("9Q=6]T.W!A8VMA9V4R+GAM;"9Q
M=6]T.R!I;B!T:&4@87)C:&EV929Q=6]T.PT*#0I)9B!N;R!S96-O;F0@9FEL
M92!I<R!P87-S960@:6XL(&%N9"!;9&5S8V9I;&5=(&ES(&$@<&%C:V%G92YX
M;6P@,BXP+`T*86X@875T;VUA=&EC(&-O;G9E<G-I;VX@=VEL;"!B92!M861E
M('1O(&$@<&%C:V%G92YX;6P@,2XP+B`@3F]T92!T:&%T#0IO;FQY('-I;7!L
M92!P86-K86=E+GAM;"`R+C`@=VEL;"!B92!C;VYV97)T960N("!P86-K86=E
M+GAM;"`R+C`@=VET:#H-"@T*("T@9&5P96YD96YC>2!T>7!E<R!O=&AE<B!T
M:&%N(')E<75I<F5D+V]P=&EO;F%L(%!%0TP@<&%C:V%G92]E>'0O<&AP+W!E
M87)I;G-T86QL97(-"B`M(&UO<F4@=&AA;B!O;F4@97AT<W)C<F5L96%S90T*
M("T@97AT8FEN<F5L96%S92P@<&AP<F5L96%S92P@;W(@8G5N9&QE(')E;&5A
M<V4@='EP90T*("T@9&5P96YD96YC>2!G<F]U<',-"B`M(&EG;F]R92!T86=S
M(&EN(')E;&5A<V4@9FEL96QI<W0-"B`M('1A<VMS(&]T:&5R('1H86X@<F5P
M;&%C90T*("T@8W5S=&]M(')O;&5S#0H-"G=I;&P@8V%U<V4@<&EC:VQE('1O
M(&9A:6PL(&%N9"!O=71P=70@86X@97)R;W(@;65S<V%G92X@($EF('EO=7(@
M<&%C:V%G93(N>&UL#0IU<V5S(&%N>2!O9B!T:&5S92!F96%T=7)E<RP@>6]U
M(&%R92!B97-T(&]F9B!U<VEN9R!014%27U!A8VMA9V5&:6QE36%N86=E<B!T
M;PT*9V5N97)A=&4@8F]T:"!P86-K86=E+GAM;"X\+V1O8SX-"B`\+W!I8VML
M93X-"CPO8V]M;6%N9',^`````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+U!I8VML92YP:'``````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`T,#`V,B`Q,#4Q-30S,S<S,2`P,C(U
M,3,`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`-"B\J*@T*("H@4$5!4E]#;VUM86YD7U!I8VML92`H<&EC:VQE(&-O
M;6UA;F0I#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,
M24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO
M;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L
M92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG
M(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N
M("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(
M4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H
M('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P
M:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN
M#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!
M4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T
M/@T*("H@0&-O<'ER:6=H="`@,C`P-2TR,#`V(%1H92!02%`@1W)O=7`-"B`J
M($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT
M>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z
M(%!I8VML92YP:'`L=B`Q+C4@,C`P-B\P,2\P-B`P-#HT-SHS-B!C96QL;V<@
M17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC
M92!296QE87-E(#$N-"XQ#0H@*B\-"@T*+RHJ#0H@*B!B87-E(&-L87-S#0H@
M*B\-"G)E<75I<F5?;VYC92`G4$5!4B]#;VUM86YD+T-O;6UO;BYP:'`G.PT*
M#0HO*BH-"B`J(%!%05(@8V]M;6%N9',@9F]R(&QO9VEN+VQO9V]U=`T*("H-
M"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J
M($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J
M($!C;W!Y<FEG:'0@(#(P,#4M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC
M96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!0
M2%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY
M#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O
M4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E
M;&5A<V4@,2XT+C$-"B`J+PT*#0IC;&%S<R!014%27T-O;6UA;F1?4&EC:VQE
M(&5X=&5N9',@4$5!4E]#;VUM86YD7T-O;6UO;@T*>PT*("`@('9A<B`D8V]M
M;6%N9',@/2!A<G)A>2@-"B`@("`@("`@)W!I8VML92<@/3X@87)R87DH#0H@
M("`@("`@("`@("`G<W5M;6%R>2<@/3X@)T)U:6QD(%!%0TP@4&%C:V%G92<L
M#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;U!A8VMA9V4G+`T*("`@
M("`@("`@("`@)W-H;W)T8W5T)R`]/B`G<&DG+`T*("`@("`@("`@("`@)V]P
M=&EO;G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=N;V-O;7!R97-S
M)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]
M/B`G6B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=$;R!N;W0@
M9WII<"!T:&4@<&%C:V%G92!F:6QE)PT*("`@("`@("`@("`@("`@("`@("`I
M+`T*("`@("`@("`@("`@("`@("=S:&]W;F%M92<@/3X@87)R87DH#0H@("`@
M("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)VXG+`T*("`@("`@("`@
M("`@("`@("`@("`G9&]C)R`]/B`G4')I;G0@=&AE(&YA;64@;V8@=&AE('!A
M8VMA9V5D(&9I;&4N)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@
M("`@("`@("`@("`I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)UMD97-C9FEL
M95T-"D-R96%T97,@82!014-,('!A8VMA9V4@9G)O;2!I=',@<&%C:V%G93(N
M>&UL(&9I;&4N#0H-"D%N(&%U=&]M871I8R!C;VYV97)S:6]N('=I;&P@8F4@
M;6%D92!T;R!A('!A8VMA9V4N>&UL(#$N,"!A;F0@=W)I='1E;B!O=70@=&\-
M"F1I<VL@:6X@=&AE(&-U<G)E;G0@9&ER96-T;W)Y(&%S(")P86-K86=E+GAM
M;"(N("!.;W1E('1H870-"F]N;'D@<VEM<&QE('!A8VMA9V4N>&UL(#(N,"!W
M:6QL(&)E(&-O;G9E<G1E9"X@('!A8VMA9V4N>&UL(#(N,"!W:71H.@T*#0H@
M+2!D97!E;F1E;F-Y('1Y<&5S(&]T:&5R('1H86X@<F5Q=6ER960O;W!T:6]N
M86P@4$5#3"!P86-K86=E+V5X="]P:'`O<&5A<FEN<W1A;&QE<@T*("T@;6]R
M92!T:&%N(&]N92!E>'1S<F-R96QE87-E#0H@+2!E>'1B:6YR96QE87-E+"!P
M:'!R96QE87-E+"!O<B!B=6YD;&4@<F5L96%S92!T>7!E#0H@+2!D97!E;F1E
M;F-Y(&=R;W5P<PT*("T@:6=N;W)E('1A9W,@:6X@<F5L96%S92!F:6QE;&ES
M=`T*("T@=&%S:W,@;W1H97(@=&AA;B!R97!L86-E#0H@+2!C=7-T;VT@<F]L
M97,-"@T*=VEL;"!C875S92!P:6-K;&4@=&\@9F%I;"P@86YD(&]U='!U="!A
M;B!E<G)O<B!M97-S86=E+B`@268@>6]U<B!P86-K86=E,BYX;6P-"G5S97,@
M86YY(&]F('1H97-E(&9E871U<F5S+"!Y;W4@87)E(&)E<W0@;V9F('5S:6YG
M(%!%05)?4&%C:V%G949I;&5-86YA9V5R('1O#0IG96YE<F%T92!B;W1H('!A
M8VMA9V4N>&UL+@T*)PT*("`@("`@("`@("`@*2P-"B`@("`@("`@*3L-"@T*
M("`@("\J*@T*("`@("`J(%!%05)?0V]M;6%N9%]086-K86=E(&-O;G-T<G5C
M=&]R+@T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!014%27T-O;6UA;F1?4&EC:VQE*"8D=6DL("8D8V]N
M9FEG*0T*("`@('L-"B`@("`@("`@<&%R96YT.CI014%27T-O;6UA;F1?0V]M
M;6]N*"1U:2P@)&-O;F9I9RD[#0H@("`@?0T*#0H-"B`@("`O*BH-"B`@("`@
M*B!&;W(@=6YI="UT97-T:6YG(&5A<V4-"B`@("`@*@T*("`@("`J($!R971U
M<FX@4$5!4E]086-K86=E<@T*("`@("`J+PT*("`@(&9U;F-T:6]N("9G9710
M86-K86=E<B@I#0H@("`@>PT*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G
M4$5!4E]086-K86=E<B<I*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M)U!%05(O4&%C:V%G97(N<&AP)SL-"B`@("`@("`@?0T*("`@("`@("`D82`]
M("9N97<@4$5!4E]086-K86=E<CL-"B`@("`@("`@<F5T=7)N("1A.PT*("`@
M('T-"@T*("`@("\J*@T*("`@("`J($9O<B!U;FET+71E<W1I;F<@96%S90T*
M("`@("`J#0H@("`@("H@0'!A<F%M(%!%05)?0V]N9FEG("1C;VYF:6<-"B`@
M("`@*B!`<&%R86T@8F]O;"`D9&5B=6<-"B`@("`@*B!`<&%R86T@<W1R:6YG
M?&YU;&P@)'1M<&1I<@T*("`@("`J($!R971U<FX@4$5!4E]086-K86=E1FEL
M90T*("`@("`J+PT*("`@(&9U;F-T:6]N("9G971086-K86=E1FEL92@D8V]N
M9FEG+"`D9&5B=6<@/2!F86QS92P@)'1M<&1I<B`](&YU;&PI#0H@("`@>PT*
M("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]#;VUM;VXG*2D@>PT*
M("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+T-O;6UO;BYP:'`G.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%2+U!A
M8VMA9V5&:6QE+G!H<"<I*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M)U!%05(O4&%C:V%G949I;&4N<&AP)SL-"B`@("`@("`@?0T*("`@("`@("`D
M82`]("9N97<@4$5!4E]086-K86=E1FEL92@D8V]N9FEG+"`D9&5B=6<L("1T
M;7!D:7(I.PT*("`@("`@("`D8V]M;6]N(#T@;F5W(%!%05)?0V]M;6]N.PT*
M("`@("`@("`D8V]M;6]N+3YU:2`]("1T:&ES+3YU:3L-"B`@("`@("`@)&$M
M/G-E=$QO9V=E<B@D8V]M;6]N*3L-"B`@("`@("`@<F5T=7)N("1A.PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N(&1O4&%C:V%G92@D8V]M;6%N9"P@)&]P=&EO
M;G,L("1P87)A;7,I#0H@("`@>PT*("`@("`@("`D=&AI<RT^;W5T<'5T(#T@
M)R<[#0H@("`@("`@("1P:V=I;F9O9FEL92`](&ES<V5T*"1P87)A;7-;,%TI
M(#\@)'!A<F%M<ULP72`Z("=P86-K86=E,BYX;6PG.PT*("`@("`@("`D<&%C
M:V%G97(@/2`F)'1H:7,M/F=E=%!A8VMA9V5R*"D[#0H@("`@("`@(&EF("A0
M14%2.CII<T5R<F]R*"1E<G(@/2`D=&AI<RT^7V-O;G9E<G1086-K86=E*"1P
M:V=I;F9O9FEL92DI*2![#0H@("`@("`@("`@("!R971U<FX@)&5R<CL-"B`@
M("`@("`@?0T*("`@("`@("`D8V]M<')E<W,@/2!E;7!T>2@D;W!T:6]N<ULG
M;F]C;VUP<F5S<R==*2`_('1R=64@.B!F86QS93L-"B`@("`@("`@)')E<W5L
M="`]("1P86-K86=E<BT^<&%C:V%G92@D<&MG:6YF;V9I;&4L("1C;VUP<F5S
M<RP@)W!A8VMA9V4N>&UL)RD[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1R97-U;'0I*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H)')E<W5L="D[#0H@("`@("`@('T-"B`@("`@("`@+R\@1&]N)W0@
M=V%N="!O=71P=70L(&]N;'D@=&AE('!A8VMA9V4@9FEL92!N86UE(&IU<W0@
M8W)E871E9`T*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W-H;W=N86UE
M)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)')E
M<W5L="P@)&-O;6UA;F0I.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!T
M<G5E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]C;VYV97)T4&%C:V%G92@D
M<&%C:V%G97AM;"D-"B`@("![#0H@("`@("`@("1P:V<@/2`F)'1H:7,M/F=E
M=%!A8VMA9V5&:6QE*"1T:&ES+3YC;VYF:6<I.PT*("`@("`@("`D<&8R(#T@
M)B1P:V<M/F9R;VU086-K86=E1FEL92@D<&%C:V%G97AM;"P@4$5!4E]604Q)
M1$%415].3U)-04PI.PT*("`@("`@("!I9B`H(6ES7V$H)'!F,BP@)U!%05)?
M4&%C:V%G949I;&5?=C(G*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*"=#86YN;W0@<')O8V5S<R`B)R`N#0H@("`@("`@("`@
M("`@("`@)'!A8VMA9V5X;6P@+B`G(BP@:7,@;F]T(&$@<&%C:V%G92YX;6P@
M,BXP)RD[#0H@("`@("`@('T-"B`@("`@("`@<F5Q=6ER95]O;F-E("=014%2
M+U!A8VMA9V5&:6QE+W8Q+G!H<"<[#0H@("`@("`@("1P9B`](&YE=R!014%2
M7U!A8VMA9V5&:6QE7W8Q.PT*("`@("`@("`D<&8M/G-E=$-O;F9I9R@D=&AI
M<RT^8V]N9FEG*3L-"B`@("`@("`@:68@*&ES7V%R<F%Y*"1P9C(M/F=E=%!A
M8VMA9V54>7!E*"D@(3T@)V5X='-R8R<I*2![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-A;FYO="!S869E;'D@8V]N=F5R="`B
M)R`N("1P86-K86=E>&UL("X-"B`@("`@("`@("`@("<B+"!I<R!N;W0@86X@
M97AT96YS:6]N('-O=7)C92!P86-K86=E+B`@57-I;F<@82!014%27U!A8VMA
M9V5&:6QE36%N86=E<BUB87-E9"`G("X-"B`@("`@("`@("`@("=S8W)I<'0@
M:7,@86X@;W!T:6]N)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES7V%R
M<F%Y*"1P9C(M/F=E=%5S97-2;VQE*"DI*2![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-A;FYO="!S869E;'D@8V]N=F5R="`B
M)R`N("1P86-K86=E>&UL("X-"B`@("`@("`@("`@("<B+"!C;VYT86EN<R!C
M=7-T;VT@<F]L97,N("!5<VEN9R!A(%!%05)?4&%C:V%G949I;&5-86YA9V5R
M+6)A<V5D('-C<FEP="!O<B`G("X-"B`@("`@("`@("`@("=T:&4@8V]N=F5R
M="!C;VUM86YD(&ES(&%N(&]P=&EO;B<I.PT*("`@("`@("!]#0H@("`@("`@
M(&EF("AI<U]A<G)A>2@D<&8R+3YG9715<V5S5&%S:R@I*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=#86YN;W0@<V%F96QY
M(&-O;G9E<G0@(B<@+B`D<&%C:V%G97AM;"`N#0H@("`@("`@("`@("`G(BP@
M8V]N=&%I;G,@8W5S=&]M('1A<VMS+B`@57-I;F<@82!014%27U!A8VMA9V5&
M:6QE36%N86=E<BUB87-E9"!S8W)I<'0@;W(@)R`N#0H@("`@("`@("`@("`G
M=&AE(&-O;G9E<G0@8V]M;6%N9"!I<R!A;B!O<'1I;VXG*3L-"B`@("`@("`@
M?0T*("`@("`@("`D9&5P<R`]("1P9C(M/F=E=$1E<&5N9&5N8VEE<R@I.PT*
M("`@("`@("!I9B`H:7-S970H)&1E<'-;)V=R;W5P)UTI*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-A;FYO="!S869E;'D@
M8V]N=F5R="`B)R`N("1P86-K86=E>&UL("X-"B`@("`@("`@("`@("<B+"!C
M;VYT86EN<R!D97!E;F1E;F-Y(&=R;W5P<RX@(%5S:6YG(&$@4$5!4E]086-K
M86=E1FEL94UA;F%G97(M8F%S960@<V-R:7!T("<@+@T*("`@("`@("`@("`@
M)V]R('1H92!C;VYV97)T(&-O;6UA;F0@:7,@86X@;W!T:6]N)RD[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!S6R=R97%U:7)E9"==6R=S
M=6)P86-K86=E)UTI('Q\#0H@("`@("`@("`@("`@(&ES<V5T*"1D97!S6R=O
M<'1I;VYA;"==6R=S=6)P86-K86=E)UTI*2![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-A;FYO="!S869E;'D@8V]N=F5R="`B
M)R`N("1P86-K86=E>&UL("X-"B`@("`@("`@("`@("<B+"!C;VYT86EN<R!S
M=6)P86-K86=E(&1E<&5N9&5N8VEE<RX@(%5S:6YG(&$@4$5!4E]086-K86=E
M1FEL94UA;F%G97(M8F%S960@("<N#0H@("`@("`@("`@("`G<V-R:7!T(&ES
M(&%N(&]P=&EO;B<I.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D
M9&5P<ULG<F5Q=6ER960G75LG;W,G72DI('L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@G0V%N;F]T('-A9F5L>2!C;VYV97)T("(G
M("X@)'!A8VMA9V5X;6P@+@T*("`@("`@("`@("`@)R(L(&-O;G1A:6YS(&]S
M(&1E<&5N9&5N8VEE<RX@(%5S:6YG(&$@4$5!4E]086-K86=E1FEL94UA;F%G
M97(M8F%S960@("<N#0H@("`@("`@("`@("`G<V-R:7!T(&ES(&%N(&]P=&EO
M;B<I.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&5P<ULG<F5Q
M=6ER960G75LG87)C:"==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*"=#86YN;W0@<V%F96QY(&-O;G9E<G0@(B<@+B`D<&%C
M:V%G97AM;"`N#0H@("`@("`@("`@("`G(BP@8V]N=&%I;G,@87)C:"!D97!E
M;F1E;F-I97,N("!5<VEN9R!A(%!%05)?4&%C:V%G949I;&5-86YA9V5R+6)A
M<V5D("`G+@T*("`@("`@("`@("`@)W-C<FEP="!I<R!A;B!O<'1I;VXG*3L-
M"B`@("`@("`@?0T*("`@("`@("`D<&8M/G-E=%!A8VMA9V4H)'!F,BT^9V5T
M4&%C:V%G92@I*3L-"B`@("`@("`@)'!F+3YS9713=6UM87)Y*"1P9C(M/F=E
M=%-U;6UA<GDH*2D[#0H@("`@("`@("1P9BT^<V5T1&5S8W)I<'1I;VXH)'!F
M,BT^9V5T1&5S8W)I<'1I;VXH*2D[#0H@("`@("`@(&9O<F5A8V@@*"1P9C(M
M/F=E=$UA:6YT86EN97)S*"D@87,@)&UA:6YT86EN97(I('L-"B`@("`@("`@
M("`@("1P9BT^861D36%I;G1A:6YE<B@D;6%I;G1A:6YE<ELG<F]L92==+"`D
M;6%I;G1A:6YE<ELG:&%N9&QE)UTL#0H@("`@("`@("`@("`@("`@)&UA:6YT
M86EN97);)VYA;64G72P@)&UA:6YT86EN97);)V5M86EL)UTI.PT*("`@("`@
M("!]#0H@("`@("`@("1P9BT^<V5T5F5R<VEO;B@D<&8R+3YG971697)S:6]N
M*"DI.PT*("`@("`@("`D<&8M/G-E=$1A=&4H)'!F,BT^9V5T1&%T92@I*3L-
M"B`@("`@("`@)'!F+3YS971,:6-E;G-E*"1P9C(M/F=E=$QI8V5N<V4H*2D[
M#0H@("`@("`@("1P9BT^<V5T4W1A=&4H)'!F,BT^9V5T4W1A=&4H*2D[#0H@
M("`@("`@("1P9BT^<V5T3F]T97,H)'!F,BT^9V5T3F]T97,H*2D[#0H@("`@
M("`@("1P9BT^861D4&AP1&5P*"1D97!S6R=R97%U:7)E9"==6R=P:'`G75LG
M;6EN)UTL("=G92<I.PT*("`@("`@("!I9B`H:7-S970H)&1E<'-;)W)E<75I
M<F5D)UU;)W!H<"==6R=M87@G72DI('L-"B`@("`@("`@("`@("1P9BT^861D
M4&AP1&5P*"1D97!S6R=R97%U:7)E9"==6R=P:'`G75LG;6%X)UTL("=L92<I
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&5P<ULG<F5Q=6ER
M960G75LG<&%C:V%G92==*2D@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D
M9&5P<ULG<F5Q=6ER960G75LG<&%C:V%G92==6S!=*2D@>PT*("`@("`@("`@
M("`@("`@("1D97!S6R=R97%U:7)E9"==6R=P86-K86=E)UT@/2!A<G)A>2@D
M9&5P<ULG<F5Q=6ER960G75LG<&%C:V%G92==*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1D97!S6R=R97%U:7)E9"==6R=P86-K
M86=E)UT@87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H
M)&1E<%LG8VAA;FYE;"==*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-A;FYO="!S869E;'D@8V]N=F5R="`B
M)R`N("1P86-K86=E>&UL("X@)R(G("X-"B`@("`@("`@("`@("`@("`@("`@
M)R!C;VYT86EN<R!U<FDM8F%S960@9&5P96YD96YC>2!O;B!A('!A8VMA9V4N
M("!5<VEN9R!A("<@+@T*("`@("`@("`@("`@("`@("`@("`G4$5!4E]086-K
M86=E1FEL94UA;F%G97(M8F%S960@<V-R:7!T(&ES(&%N(&]P=&EO;B<I.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H)&1E<%LG
M8VAA;FYE;"==("$]("=P96%R+G!H<"YN970G("8F("1D97!;)V-H86YN96PG
M72`A/2`G<&5C;"YP:'`N;F5T)RD@>PT*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-A;FYO="!S869E;'D@8V]N=F5R
M="`B)R`N("1P86-K86=E>&UL("X@)R(G("X-"B`@("`@("`@("`@("`@("`@
M("`@)R!C;VYT86EN<R!D97!E;F1E;F-Y(&]N(&$@;F]N+7-T86YD87)D(&-H
M86YN96P@<&%C:V%G92X@(%5S:6YG(&$@)R`N#0H@("`@("`@("`@("`@("`@
M("`@("=014%27U!A8VMA9V5&:6QE36%N86=E<BUB87-E9"!S8W)I<'0@:7,@
M86X@;W!T:6]N)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D9&5P6R=C;VYF;&EC=',G72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=#86YN;W0@
M<V%F96QY(&-O;G9E<G0@(B<@+B`D<&%C:V%G97AM;"`N("<B)R`N#0H@("`@
M("`@("`@("`@("`@("`@("<@8V]N=&%I;G,@8V]N9FQI8W1S(&1E<&5N9&5N
M8WDN("!5<VEN9R!A("<@+@T*("`@("`@("`@("`@("`@("`@("`G4$5!4E]0
M86-K86=E1FEL94UA;F%G97(M8F%S960@<V-R:7!T(&ES(&%N(&]P=&EO;B<I
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&1E<%LG97AC;'5D92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^=6DM/F]U='!U=$1A=&$H)U=!4DY)3D<Z(&5X8VQU9&4@=&%G<R!A
M<F4@:6=N;W)E9"!I;B!C;VYV97)S:6]N)RD[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=M:6XG72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@)'!F+3YA9&1086-K86=E1&5P*"1D97!;
M)VYA;64G72P@)&1E<%LG;6EN)UTL("=G92<I.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG;6%X)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("1P9BT^861D4&%C:V%G941E<"@D9&5P
M6R=N86UE)UTL("1D97!;)VUA>"==+"`G;&4G*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES
M<V5T*"1D97!S6R=R97%U:7)E9"==6R=E>'1E;G-I;VXG72DI('L-"B`@("`@
M("`@("`@(&EF("@A:7-S970H)&1E<'-;)W)E<75I<F5D)UU;)V5X=&5N<VEO
M;B==6S!=*2D@>PT*("`@("`@("`@("`@("`@("1D97!S6R=R97%U:7)E9"==
M6R=E>'1E;G-I;VXG72`](&%R<F%Y*"1D97!S6R=R97%U:7)E9"==6R=E>'1E
M;G-I;VXG72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F;W)E86-H
M("@D9&5P<ULG<F5Q=6ER960G75LG97AT96YS:6]N)UT@87,@)&1E<"D@>PT*
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=C;VYF;&EC=',G72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*"=#86YN;W0@<V%F96QY(&-O;G9E<G0@(B<@+B`D<&%C:V%G97AM;"`N
M("<B)R`N#0H@("`@("`@("`@("`@("`@("`@("<@8V]N=&%I;G,@8V]N9FQI
M8W1S(&1E<&5N9&5N8WDN("!5<VEN9R!A("<@+@T*("`@("`@("`@("`@("`@
M("`@("`G4$5!4E]086-K86=E1FEL94UA;F%G97(M8F%S960@<V-R:7!T(&ES
M(&%N(&]P=&EO;B<I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)&1E<%LG97AC;'5D92==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)U=!4DY)3D<Z(&5X
M8VQU9&4@=&%G<R!A<F4@:6=N;W)E9"!I;B!C;VYV97)S:6]N)RD[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P
M6R=M:6XG72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'!F+3YA9&1%>'1E
M;G-I;VY$97`H)&1E<%LG;F%M92==+"`D9&5P6R=M:6XG72P@)V=E)RD[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M9&5P6R=M87@G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'!F+3YA9&1%
M>'1E;G-I;VY$97`H)&1E<%LG;F%M92==+"`D9&5P6R=M87@G72P@)VQE)RD[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(&EF("AI<W-E="@D9&5P<ULG;W!T:6]N86PG75LG<&%C:V%G
M92==*2D@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D9&5P<ULG;W!T:6]N
M86PG75LG<&%C:V%G92==6S!=*2D@>PT*("`@("`@("`@("`@("`@("1D97!S
M6R=O<'1I;VYA;"==6R=P86-K86=E)UT@/2!A<G)A>2@D9&5P<ULG;W!T:6]N
M86PG75LG<&%C:V%G92==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&9O<F5A8V@@*"1D97!S6R=O<'1I;VYA;"==6R=P86-K86=E)UT@87,@)&1E
M<"D@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&1E<%LG8VAA;FYE
M;"==*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H)T-A;FYO="!S869E;'D@8V]N=F5R="`B)R`N("1P86-K86=E
M>&UL("X@)R(G("X-"B`@("`@("`@("`@("`@("`@("`@)R!C;VYT86EN<R!U
M<FDM8F%S960@9&5P96YD96YC>2!O;B!A('!A8VMA9V4N("!5<VEN9R!A("<@
M+@T*("`@("`@("`@("`@("`@("`@("`G4$5!4E]086-K86=E1FEL94UA;F%G
M97(M8F%S960@<V-R:7!T(&ES(&%N(&]P=&EO;B<I.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!I9B`H)&1E<%LG8VAA;FYE;"==("$]
M("=P96%R+G!H<"YN970G("8F("1D97!;)V-H86YN96PG72`A/2`G<&5C;"YP
M:'`N;F5T)RD@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H)T-A;FYO="!S869E;'D@8V]N=F5R="`B)R`N("1P86-K
M86=E>&UL("X@)R(G("X-"B`@("`@("`@("`@("`@("`@("`@)R!C;VYT86EN
M<R!D97!E;F1E;F-Y(&]N(&$@;F]N+7-T86YD87)D(&-H86YN96P@<&%C:V%G
M92X@(%5S:6YG(&$@)R`N#0H@("`@("`@("`@("`@("`@("`@("=014%27U!A
M8VMA9V5&:6QE36%N86=E<BUB87-E9"!S8W)I<'0@:7,@86X@;W!T:6]N)RD[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YU:2T^;W5T<'5T1&%T82@G5T%23DE.1SH@97AC;'5D92!T86=S(&%R
M92!I9VYO<F5D(&EN(&-O;G9E<G-I;VXG*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)VUI;B==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`D<&8M/F%D9%!A8VMA9V5$97`H)&1E<%LG
M;F%M92==+"`D9&5P6R=M:6XG72P@)V=E)RP@)WEE<R<I.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG;6%X
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1P9BT^861D4&%C:V%G941E
M<"@D9&5P6R=N86UE)UTL("1D97!;)VUA>"==+"`G;&4G+"`G>65S)RD[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@(&EF("AI<W-E="@D9&5P<ULG;W!T:6]N86PG75LG97AT96YS:6]N
M)UTI*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1D97!S6R=O<'1I;VYA
M;"==6R=E>'1E;G-I;VXG75LP72DI('L-"B`@("`@("`@("`@("`@("`D9&5P
M<ULG;W!T:6]N86PG75LG97AT96YS:6]N)UT@/2!A<G)A>2@D9&5P<ULG;W!T
M:6]N86PG75LG97AT96YS:6]N)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@9F]R96%C:"`H)&1E<'-;)V]P=&EO;F%L)UU;)V5X=&5N<VEO;B==
M(&%S("1D97`I('L-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG
M97AC;'5D92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=6DM
M/F]U='!U=$1A=&$H)U=!4DY)3D<Z(&5X8VQU9&4@=&%G<R!A<F4@:6=N;W)E
M9"!I;B!C;VYV97)S:6]N)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=M:6XG72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@)'!F+3YA9&1%>'1E;G-I;VY$97`H)&1E<%LG;F%M92==
M+"`D9&5P6R=M:6XG72P@)V=E)RP@)WEE<R<I.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG;6%X)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("1P9BT^861D17AT96YS:6]N1&5P*"1D
M97!;)VYA;64G72P@)&1E<%LG;6%X)UTL("=L92<L("=Y97,G*3L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@)&-O;G1E;G1S(#T@)'!F,BT^9V5T0V]N=&5N=',H*3L-"B`@("`@("`@
M)')E;&5A<V4@/2`D<&8R+3YG971296QE87-E<R@I.PT*("`@("`@("!I9B`H
M:7-S970H)')E;&5A<V5S6S!=*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*"=#86YN;W0@<V%F96QY('!R;V-E<W,@(B<@+B`D
M<&%C:V%G97AM;"`N("<B(&-O;G1A:6YS("<@#0H@("`@("`@("`@("`N("=M
M=6QT:7!L92!E>'1S<F-R96QE87-E('1A9W,N("!5<VEN9R!A(%!%05)?4&%C
M:V%G949I;&5-86YA9V5R+6)A<V5D('-C<FEP="`G("X-"B`@("`@("`@("`@
M("=O<B!T:&4@8V]N=F5R="!C;VUM86YD(&ES(&%N(&]P=&EO;B<I.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("@D8V]N9FEG;W!T:6]N<R`]("1P9C(M/F=E
M=$-O;F9I9W5R94]P=&EO;G,H*2D@>PT*("`@("`@("`@("`@9F]R96%C:"`H
M)&-O;F9I9V]P=&EO;G,@87,@)&]P=&EO;BD@>PT*("`@("`@("`@("`@("`@
M("1P9BT^861D0V]N9FEG=7)E3W!T:6]N*"1O<'1I;VY;)VYA;64G72P@)&]P
M=&EO;ELG<')O;7!T)UTL#0H@("`@("`@("`@("`@("`@("`@(&ES<V5T*"1O
M<'1I;VY;)V1E9F%U;'0G72D@/R`D;W!T:6]N6R=D969A=6QT)UT@.B!F86QS
M92D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES
M<V5T*"1R96QE87-E6R=F:6QE;&ES="==6R=I9VYO<F4G72DI('L-"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G0V%N;F]T('-A9F5L
M>2!P<F]C97-S("(G("X@)'!A8VMA9V5X;6P@+B`G(B!C;VYT86EN<R`G(`T*
M("`@("`@("`@("`@+B`G:6=N;W)E('1A9W,N("!5<VEN9R!A(%!%05)?4&%C
M:V%G949I;&5-86YA9V5R+6)A<V5D('-C<FEP="!O<B!T:&4@8V]N=F5R="<@
M+@T*("`@("`@("`@("`@)R!C;VUM86YD(&ES(&%N(&]P=&EO;B<I.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D<F5L96%S95LG9FEL96QI<W0G
M75LG:6YS=&%L;"==*2`F)@T*("`@("`@("`@("`@("`A:7-S970H)')E;&5A
M<V5;)V9I;&5L:7-T)UU;)VEN<W1A;&PG75LP72DI('L-"B`@("`@("`@("`@
M("1R96QE87-E6R=F:6QE;&ES="==6R=I;G-T86QL)UT@/2!A<G)A>2@D<F5L
M96%S95LG9FEL96QI<W0G75LG:6YS=&%L;"==*3L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H:7-S970H)&-O;G1E;G1S6R=D:7(G75LG871T<FEB<R==6R=B
M87-E:6YS=&%L;&1I<B==*2D@>PT*("`@("`@("`@("`@)&)A<V5I;G-T86QL
M9&ER(#T@)&-O;G1E;G1S6R=D:7(G75LG871T<FEB<R==6R=B87-E:6YS=&%L
M;&1I<B==.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&)A<V5I
M;G-T86QL9&ER(#T@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I
M<W-E="@D8V]N=&5N='-;)V1I<B==6R=F:6QE)UU;,%TI*2![#0H@("`@("`@
M("`@("`D8V]N=&5N='-;)V1I<B==6R=F:6QE)UT@/2!A<G)A>2@D8V]N=&5N
M='-;)V1I<B==6R=F:6QE)UTI.PT*("`@("`@("!]#0H@("`@("`@(&9O<F5A
M8V@@*"1C;VYT96YT<ULG9&ER)UU;)V9I;&4G72!A<R`D9FEL92D@>PT*("`@
M("`@("`@("`@:68@*"1B87-E:6YS=&%L;&1I<B`F)B`A:7-S970H)&9I;&5;
M)V%T=')I8G,G75LG8F%S96EN<W1A;&QD:7(G72DI('L-"B`@("`@("`@("`@
M("`@("`D9FEL95LG871T<FEB<R==6R=B87-E:6YS=&%L;&1I<B==(#T@)&)A
M<V5I;G-T86QL9&ER.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'!R
M;V-E<W-&:6QE(#T@)&9I;&4[#0H@("`@("`@("`@("!U;G-E="@D<')O8V5S
M<T9I;&5;)V%T=')I8G,G72D[#0H@("`@("`@("`@("!I9B`H8V]U;G0H)'!R
M;V-E<W-&:6QE*2D@>PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1P<F]C
M97-S1FEL92!A<R`D;F%M92`]/B`D=&%S:RD@>PT*("`@("`@("`@("`@("`@
M("`@("!I9B`H)&YA;64@(3T@)'!F,BT^9V5T5&%S:W-.<R@I("X@)SIR97!L
M86-E)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*"=#86YN;W0@<V%F96QY('!R;V-E<W,@(B<@+B`D<&%C
M:V%G97AM;"`N#0H@("`@("`@("`@("`@("`@("`@("`@("`G(B!C;VYT86EN
M<R!T87-K<R!O=&AE<B!T:&%N(')E<&QA8V4N("!5<VEN9R!A("<@+@T*("`@
M("`@("`@("`@("`@("`@("`@("`@)U!%05)?4&%C:V%G949I;&5-86YA9V5R
M+6)A<V5D('-C<FEP="!I<R!A;B!O<'1I;VXN)RD[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)&9I;&5;)V%T=')I8G,G
M75LG<F5P;&%C92==6UT@/2`D=&%S:SL-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(6EN7V%R<F%Y*"1F:6QE
M6R=A='1R:6)S)UU;)W)O;&4G72P@4$5!4E]#;VUM;VXZ.F=E=$9I;&52;VQE
M<R@I*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@G0V%N;F]T('-A9F5L>2!C;VYV97)T("(G("X@)'!A8VMA9V5X;6P@
M+@T*("`@("`@("`@("`@("`@("<B+"!C;VYT86EN<R!C=7-T;VT@<F]L97,N
M("!5<VEN9R!A(%!%05)?4&%C:V%G949I;&5-86YA9V5R+6)A<V5D('-C<FEP
M="`G("X-"B`@("`@("`@("`@("`@("`G;W(@=&AE(&-O;G9E<G0@8V]M;6%N
M9"!I<R!A;B!O<'1I;VXG*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&EF("AI<W-E="@D<F5L96%S95LG9FEL96QI<W0G75LG:6YS=&%L;"==*2D@
M>PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1R96QE87-E6R=F:6QE;&ES
M="==6R=I;G-T86QL)UT@87,@)&EN<W1A;&QA<RD@>PT*("`@("`@("`@("`@
M("`@("`@("!I9B`H)&EN<W1A;&QA<ULG871T<FEB<R==6R=N86UE)UT@/3T@
M)&9I;&5;)V%T=')I8G,G75LG;F%M92==*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D9FEL95LG871T<FEB<R==6R=I;G-T86QL+6%S)UT@/2`D:6YS
M=&%L;&%S6R=A='1R:6)S)UU;)V%S)UT[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`D<&8M/F%D9$9I;&4H)R\G+"`D9FEL95LG871T<FEB<R==6R=N86UE
M)UTL("1F:6QE6R=A='1R:6)S)UTI.PT*("`@("`@("!]#0H@("`@("`@(&EF
M("@D<&8R+3YG971#:&%N9V5,;V<H*2D@>PT*("`@("`@("`@("`@)'1H:7,M
M/G5I+3YO=71P=71$871A*"=705).24Y'.B!C:&%N9V5L;V<@:7,@;F]T('1R
M86YS;&%T960@=&\@<&%C:V%G92YX;6P@)R`N#0H@("`@("`@("`@("`@("`@
M)S$N,"P@=7-E(%!%05)?4&%C:V%G949I;&5-86YA9V5R+6)A<V5D('-C<FEP
M="!I9B!Y;W4@;F5E9"!C:&%N9V5L;V<M)R`N#0H@("`@("`@("`@("`@("`@
M)W1R86YS;&%T:6]N(&9O<B!P86-K86=E+GAM;"`Q+C`G*3L-"B`@("`@("`@
M?0T*("`@("`@("`D9V5N(#T@)B1P9BT^9V5T1&5F875L=$=E;F5R871O<B@I
M.PT*("`@("`@("`D9V5N+3YT;U!A8VMA9V5&:6QE*"<N)RD[#0H@("`@?0T*
M?0T*#0H_/@T*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]014%2+T-O;6UA;F0O4F5G:7-T<GDN>&UL````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`S,C8U(#$P-3$U-#,S-S,Q(#`R,S$S,0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\8V]M;6%N
M9',@=F5R<VEO;CTB,2XP(CX-"B`\;&ES=#X-"B`@/'-U;6UA<GD^3&ES="!)
M;G-T86QL960@4&%C:V%G97,@26X@5&AE($1E9F%U;'0@0VAA;FYE;#PO<W5M
M;6%R>3X-"B`@/&9U;F-T:6]N/F1O3&ES=#PO9G5N8W1I;VX^#0H@(#QS:&]R
M=&-U=#YL/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,^#0H@("`\8VAA;FYE;#X-
M"B`@("`\<VAO<G1O<'0^8SPO<VAO<G1O<'0^#0H@("`@/&1O8SYL:7-T(&EN
M<W1A;&QE9"!P86-K86=E<R!F<F]M('1H:7,@8VAA;FYE;#PO9&]C/@T*("`@
M(#QA<F<^0TA!3CPO87)G/@T*("`@/"]C:&%N;F5L/@T*("`@/&%L;&-H86YN
M96QS/@T*("`@(#QS:&]R=&]P=#YA/"]S:&]R=&]P=#X-"B`@("`\9&]C/FQI
M<W0@:6YS=&%L;&5D('!A8VMA9V5S(&9R;VT@86QL(&-H86YN96QS/"]D;V,^
M#0H@("`\+V%L;&-H86YN96QS/@T*("`\+V]P=&EO;G,^#0H@(#QD;V,^)FQT
M.W!A8VMA9V4F9W0[#0I)9B!I;G9O:V5D('=I=&AO=70@<&%R86UE=&5R<RP@
M=&AI<R!C;VUM86YD(&QI<W1S('1H92!014%2('!A8VMA9V5S#0II;G-T86QL
M960@:6X@>6]U<B!P:'!?9&ER("A[8V]N9FEG('!H<%]D:7)]*2X@(%=I=&@@
M82!P87)A;65T97(L(&ET#0IL:7-T<R!T:&4@9FEL97,@:6X@82!P86-K86=E
M+@T*/"]D;V,^#0H@/"]L:7-T/@T*(#QL:7-T+69I;&5S/@T*("`\<W5M;6%R
M>3Y,:7-T($9I;&5S($EN($EN<W1A;&QE9"!086-K86=E/"]S=6UM87)Y/@T*
M("`\9G5N8W1I;VX^9&]&:6QE3&ES=#PO9G5N8W1I;VX^#0H@(#QS:&]R=&-U
M=#YF;#PO<VAO<G1C=70^#0H@(#QO<'1I;VYS("\^#0H@(#QD;V,^)FQT.W!A
M8VMA9V4F9W0[#0I,:7-T('1H92!F:6QE<R!I;B!A;B!I;G-T86QL960@<&%C
M:V%G92X-"CPO9&]C/@T*(#PO;&ES="UF:6QE<SX-"B`\<VAE;&PM=&5S=#X-
M"B`@/'-U;6UA<GD^4VAE;&P@4V-R:7!T(%1E<W0\+W-U;6UA<GD^#0H@(#QF
M=6YC=&EO;CYD;U-H96QL5&5S=#PO9G5N8W1I;VX^#0H@(#QS:&]R=&-U=#YS
M=#PO<VAO<G1C=70^#0H@(#QO<'1I;VYS("\^#0H@(#QD;V,^)FQT.W!A8VMA
M9V4F9W0[(%M;<F5L871I;VY=('9E<G-I;VY=#0I497-T<R!I9B!A('!A8VMA
M9V4@:7,@:6YS=&%L;&5D(&EN('1H92!S>7-T96TN(%=I;&P@97AI="@Q*2!I
M9B!I="!I<R!N;W0N#0H@("`F;'0[<F5L871I;VXF9W0[("`@5&AE('9E<G-I
M;VX@8V]M<&%R:7-O;B!O<&5R871O<BX@3VYE(&]F.@T*("`@("`@("`@("`@
M("`@("9L=#LL(&QT+"`F;'0[/2P@;&4L("9G=#LL(&=T+"`F9W0[/2P@9V4L
M(#T]+"`]+"!E<2P@(3TL("9L=#LF9W0[+"!N90T*("`@)FQT.W9E<G-I;VXF
M9W0[("`@(%1H92!V97)S:6]N('1O(&-O;7!A<F4@=VET:`T*/"]D;V,^#0H@
M/"]S:&5L;"UT97-T/@T*(#QI;F9O/@T*("`\<W5M;6%R>3Y$:7-P;&%Y(&EN
M9F]R;6%T:6]N(&%B;W5T(&$@<&%C:V%G93PO<W5M;6%R>3X-"B`@/&9U;F-T
M:6]N/F1O26YF;SPO9G5N8W1I;VX^#0H@(#QS:&]R=&-U=#YI;CPO<VAO<G1C
M=70^#0H@(#QO<'1I;VYS("\^#0H@(#QD;V,^)FQT.W!A8VMA9V4F9W0[#0I$
M:7-P;&%Y<R!I;F9O<FUA=&EO;B!A8F]U="!A('!A8VMA9V4N(%1H92!P86-K
M86=E(&%R9W5M96YT(&UA>2!B92!A#0IL;V-A;"!P86-K86=E(&9I;&4L(&%N
M(%523"!T;R!A('!A8VMA9V4@9FEL92P@;W(@=&AE(&YA;64@;V8@86X-"FEN
M<W1A;&QE9"!P86-K86=E+CPO9&]C/@T*(#PO:6YF;SX-"CPO8V]M;6%N9',^
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M4$5!4B]#;VUM86YD+U)E9VES=')Y+G!H<```````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#$R-S0U-2`Q,#4Q-30S,S<S,2`P,C,Q,S``(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`-"B\J*@T*
M("H@4$5!4E]#;VUM86YD7U)E9VES=')Y("AL:7-T+"!L:7-T+69I;&5S+"!S
M:&5L;"UT97-T+"!I;F9O(&-O;6UA;F1S*0T*("H-"B`J(%!(4"!V97)S:6]N
M<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I
M<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*
M("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A
M(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T
M;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@
M82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@
M82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-
M"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@(%-T:6<@0F%K
M:V5N(#QS<V)`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R
M(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4
M:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S
M:6]N("`@($-64SH@)$ED.B!296=I<W1R>2YP:'`L=B`Q+C<P(#(P,#8O,#$O
M,#8@,#0Z-#<Z,S8@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P
M.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@
M1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J+PT*#0HO*BH-
M"B`J(&)A<V4@8VQA<W,-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2+T-O;6UA
M;F0O0V]M;6]N+G!H<"<[#0H-"B\J*@T*("H@4$5!4B!C;VUM86YD<R!F;W(@
M<F5G:7-T<GD@;6%N:7!U;&%T:6]N#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A
M<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@4W1I9R!"
M86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V
M97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V
M(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E
M<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z
M+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#
M;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J+PT*8VQA<W,@
M4$5!4E]#;VUM86YD7U)E9VES=')Y(&5X=&5N9',@4$5!4E]#;VUM86YD7T-O
M;6UO;@T*>PT*("`@("\O('M[>R!P<F]P97)T:65S#0H-"B`@("!V87(@)&-O
M;6UA;F1S(#T@87)R87DH#0H@("`@("`@("=L:7-T)R`]/B!A<G)A>2@-"B`@
M("`@("`@("`@("=S=6UM87)Y)R`]/B`G3&ES="!);G-T86QL960@4&%C:V%G
M97,@26X@5&AE($1E9F%U;'0@0VAA;FYE;"<L#0H@("`@("`@("`@("`G9G5N
M8W1I;VXG(#T^("=D;TQI<W0G+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]
M/B`G;"<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH#0H@("`@
M("`@("`@("`@("`@)V-H86YN96PG(#T^(&%R<F%Y*`T*("`@("`@("`@("`@
M("`@("`@("`G<VAO<G1O<'0G(#T^("=C)RP-"B`@("`@("`@("`@("`@("`@
M("`@)V1O8R<@/3X@)VQI<W0@:6YS=&%L;&5D('!A8VMA9V5S(&9R;VT@=&AI
M<R!C:&%N;F5L)RP-"B`@("`@("`@("`@("`@("`@("`@)V%R9R<@/3X@)T-(
M04XG+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@
M("=A;&QC:&%N;F5L<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@
M("=S:&]R=&]P="<@/3X@)V$G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C
M)R`]/B`G;&ES="!I;G-T86QL960@<&%C:V%G97,@9G)O;2!A;&P@8VAA;FYE
M;',G+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@
M("DL#0H@("`@("`@("`@("`G9&]C)R`]/B`G/'!A8VMA9V4^#0I)9B!I;G9O
M:V5D('=I=&AO=70@<&%R86UE=&5R<RP@=&AI<R!C;VUM86YD(&QI<W1S('1H
M92!014%2('!A8VMA9V5S#0II;G-T86QL960@:6X@>6]U<B!P:'!?9&ER("A[
M8V]N9FEG('!H<%]D:7)]*2X@(%=I=&@@82!P87)A;65T97(L(&ET#0IL:7-T
M<R!T:&4@9FEL97,@:6X@82!P86-K86=E+@T*)RP-"B`@("`@("`@("`@("DL
M#0H@("`@("`@("=L:7-T+69I;&5S)R`]/B!A<G)A>2@-"B`@("`@("`@("`@
M("=S=6UM87)Y)R`]/B`G3&ES="!&:6QE<R!);B!);G-T86QL960@4&%C:V%G
M92<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;T9I;&5,:7-T)RP-
M"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)V9L)RP-"B`@("`@("`@("`@
M("=O<'1I;VYS)R`]/B!A<G)A>2@I+`T*("`@("`@("`@("`@)V1O8R<@/3X@
M)SQP86-K86=E/@T*3&ES="!T:&4@9FEL97,@:6X@86X@:6YS=&%L;&5D('!A
M8VMA9V4N#0HG#0H@("`@("`@("`@("`I+`T*("`@("`@("`G<VAE;&PM=&5S
M="<@/3X@87)R87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)U-H96QL
M(%-C<FEP="!497-T)RP-"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O
M4VAE;&Q497-T)RP-"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)W-T)RP-
M"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@I+`T*("`@("`@("`@
M("`@)V1O8R<@/3X@)SQP86-K86=E/B!;6W)E;&%T:6]N72!V97)S:6]N70T*
M5&5S=',@:68@82!P86-K86=E(&ES(&EN<W1A;&QE9"!I;B!T:&4@<WES=&5M
M+B!7:6QL(&5X:70H,2D@:68@:70@:7,@;F]T+@T*("`@/')E;&%T:6]N/B`@
M(%1H92!V97)S:6]N(&-O;7!A<FES;VX@;W!E<F%T;W(N($]N92!O9CH-"B`@
M("`@("`@("`@("`@("`\+"!L="P@/#TL(&QE+"`^+"!G="P@/CTL(&=E+"`]
M/2P@/2P@97$L("$]+"`\/BP@;F4-"B`@(#QV97)S:6]N/B`@("!4:&4@=F5R
M<VEO;B!T;R!C;VUP87)E('=I=&@-"B<I+`T*("`@("`@("`G:6YF;R<@/3X@
M87)R87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@(#T^("=$:7-P;&%Y(&EN
M9F]R;6%T:6]N(&%B;W5T(&$@<&%C:V%G92<L#0H@("`@("`@("`@("`G9G5N
M8W1I;VXG(#T^("=D;TEN9F\G+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]
M/B`G:6XG+`T*("`@("`@("`@("`@)V]P=&EO;G,G("`]/B!A<G)A>2@I+`T*
M("`@("`@("`@("`@)V1O8R<@("`@("`]/B`G/'!A8VMA9V4^#0I$:7-P;&%Y
M<R!I;F9O<FUA=&EO;B!A8F]U="!A('!A8VMA9V4N(%1H92!P86-K86=E(&%R
M9W5M96YT(&UA>2!B92!A#0IL;V-A;"!P86-K86=E(&9I;&4L(&%N(%523"!T
M;R!A('!A8VMA9V4@9FEL92P@;W(@=&AE(&YA;64@;V8@86X-"FEN<W1A;&QE
M9"!P86-K86=E+B<-"B`@("`@("`@("`@("D-"B`@("`@("`@*3L-"@T*("`@
M("\O('U]?0T*("`@("\O('M[>R!C;VYS=')U8W1O<@T*#0H@("`@+RHJ#0H@
M("`@("H@4$5!4E]#;VUM86YD7U)E9VES=')Y(&-O;G-T<G5C=&]R+@T*("`@
M("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!014%27T-O;6UA;F1?4F5G:7-T<GDH)B1U:2P@)B1C;VYF:6<I#0H@
M("`@>PT*("`@("`@("!P87)E;G0Z.E!%05)?0V]M;6%N9%]#;VUM;VXH)'5I
M+"`D8V]N9FEG*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*("`@("\O('M[
M>R!D;TQI<W0H*0T*#0H@("`@9G5N8W1I;VX@7W-O<G1I;F9O*"1A+"`D8BD-
M"B`@("![#0H@("`@("`@("1A<&%C:V%G92`](&ES<V5T*"1A6R=P86-K86=E
M)UTI(#\@)&%;)W!A8VMA9V4G72`Z("1A6R=N86UE)UT[#0H@("`@("`@("1B
M<&%C:V%G92`](&ES<V5T*"1B6R=P86-K86=E)UTI(#\@)&);)W!A8VMA9V4G
M72`Z("1B6R=N86UE)UT[#0H@("`@("`@(')E='5R;B!S=')C;7`H)&%P86-K
M86=E+"`D8G!A8VMA9V4I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&1O3&ES
M="@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I#0H@("`@>PT*("`@("`@
M("!I9B`H:7-S970H)&]P=&EO;G-;)V%L;&-H86YN96QS)UTI*2![#0H@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/F1O3&ES=$%L;"@D8V]M;6%N9"P@87)R
M87DH*2P@)'!A<F%M<RD[#0H@("`@("`@('T-"B`@("`@("`@)')E9R`]("8D
M=&AI<RT^8V]N9FEG+3YG971296=I<W1R>2@I.PT*("`@("`@("!I9B`H8V]U
M;G0H)'!A<F%M<RD@/3T@,2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YD;T9I;&5,:7-T*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=C:&%N;F5L
M)UTI*2![#0H@("`@("`@("`@("!I9B`H)')E9RT^8VAA;FYE;$5X:7-T<R@D
M;W!T:6]N<ULG8VAA;FYE;"==*2D@>PT*("`@("`@("`@("`@("`@("1C:&%N
M;F5L(#T@)')E9RT^8VAA;FYE;$YA;64H)&]P=&EO;G-;)V-H86YN96PG72D[
M#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@G0VAA;FYE;"`B)R`N("1O<'1I;VYS6R=C
M:&%N;F5L)UT@+B<B(&1O97,@;F]T(&5X:7-T)RD[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D8VAA;FYE;"`]("1T
M:&ES+3YC;VYF:6<M/F=E="@G9&5F875L=%]C:&%N;F5L)RD[#0H@("`@("`@
M('T-"B`@("`@("`@)&EN<W1A;&QE9"`]("1R96<M/G!A8VMA9V5);F9O*&YU
M;&PL(&YU;&PL("1C:&%N;F5L*3L-"B`@("`@("`@=7-O<G0H)&EN<W1A;&QE
M9"P@87)R87DH)B1T:&ES+"`G7W-O<G1I;F9O)RDI.PT*("`@("`@("`D:2`]
M("1J(#T@,#L-"B`@("`@("`@)&1A=&$@/2!A<G)A>2@-"B`@("`@("`@("`@
M("=C87!T:6]N)R`]/B`G26YS=&%L;&5D('!A8VMA9V5S+"!C:&%N;F5L("<@
M+@T*("`@("`@("`@("`@("`@("1C:&%N;F5L("X@)SHG+`T*("`@("`@("`@
M("`@)V)O<F1E<B<@/3X@=')U92P-"B`@("`@("`@("`@("=H96%D;&EN92<@
M/3X@87)R87DH)U!A8VMA9V4G+"`G5F5R<VEO;B<L("=3=&%T92<I#0H@("`@
M("`@("`@("`I.PT*("`@("`@("!F;W)E86-H("@D:6YS=&%L;&5D(&%S("1P
M86-K86=E*2![#0H@("`@("`@("`@("`D<&]B:B`]("1R96<M/F=E=%!A8VMA
M9V4H:7-S970H)'!A8VMA9V5;)W!A8VMA9V4G72D@/PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E6R=P86-K86=E
M)UT@.B`D<&%C:V%G95LG;F%M92==+"`D8VAA;FYE;"D[#0H@("`@("`@("`@
M("`D9&%T85LG9&%T82==6UT@/2!A<G)A>2@D<&]B:BT^9V5T4&%C:V%G92@I
M+"`D<&]B:BT^9V5T5F5R<VEO;B@I+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'!O8FHM/F=E=%-T871E*"D@/R`D<&]B:BT^9V5T
M4W1A=&4H*2`Z(&YU;&PI.PT*("`@("`@("!]#0H@("`@("`@(&EF("AC;W5N
M="@D:6YS=&%L;&5D*3T],"D@>PT*("`@("`@("`@("`@)&1A=&$@/2`G*&YO
M('!A8VMA9V5S(&EN<W1A;&QE9"!F<F]M(&-H86YN96P@)R`N("1C:&%N;F5L
M("X@)RDG.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T
M1&%T82@D9&%T82P@)&-O;6UA;F0I.PT*("`@("`@("!R971U<FX@=')U93L-
M"B`@("!]#0H@("`@#0H@("`@9G5N8W1I;VX@9&],:7-T06QL*"1C;VUM86YD
M+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@("1R96<@/2`F
M)'1H:7,M/F-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-"B`@("`@("`@)&EN<W1A
M;&QE9"`]("1R96<M/G!A8VMA9V5);F9O*&YU;&PL(&YU;&PL(&YU;&PI.PT*
M("`@("`@("!F;W)E86-H("@D:6YS=&%L;&5D(&%S("1C:&%N;F5L(#T^("1P
M86-K86=E<RD@>PT*("`@("`@("`@("`@=7-O<G0H)'!A8VMA9V5S+"!A<G)A
M>2@D=&AI<RP@)U]S;W)T:6YF;R<I*3L-"B`@("`@("`@("`@("1I(#T@)&H@
M/2`P.PT*("`@("`@("`@("`@)&1A=&$@/2!A<G)A>2@-"B`@("`@("`@("`@
M("`@("`G8V%P=&EO;B<@/3X@)TEN<W1A;&QE9"!P86-K86=E<RP@8VAA;FYE
M;"`G("X@)&-H86YN96P@+B`G.B<L#0H@("`@("`@("`@("`@("`@)V)O<F1E
M<B<@/3X@=')U92P-"B`@("`@("`@("`@("`@("`G:&5A9&QI;F4G(#T^(&%R
M<F%Y*"=086-K86=E)RP@)U9E<G-I;VXG+"`G4W1A=&4G*0T*("`@("`@("`@
M("`@("`@("D[#0H@("`@("`@("`@("!F;W)E86-H("@D<&%C:V%G97,@87,@
M)'!A8VMA9V4I('L-"B`@("`@("`@("`@("`@("`D<&]B:B`]("1R96<M/F=E
M=%!A8VMA9V4H:7-S970H)'!A8VMA9V5;)W!A8VMA9V4G72D@/PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%C:V%G
M95LG<&%C:V%G92==(#H@)'!A8VMA9V5;)VYA;64G72P@)&-H86YN96PI.PT*
M("`@("`@("`@("`@("`@("1D871A6R=D871A)UU;72`](&%R<F%Y*"1P;V)J
M+3YG971086-K86=E*"DL("1P;V)J+3YG971697)S:6]N*"DL#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O8FHM/F=E=%-T
M871E*"D@/R`D<&]B:BT^9V5T4W1A=&4H*2`Z(&YU;&PI.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@:68@*&-O=6YT*"1P86-K86=E<RD]/3`I('L-
M"B`@("`@("`@("`@("`@("`D9&%T82`](&%R<F%Y*`T*("`@("`@("`@("`@
M("`@("`@("`G8V%P=&EO;B<@/3X@)TEN<W1A;&QE9"!P86-K86=E<RP@8VAA
M;FYE;"`G("X@)&-H86YN96P@+B`G.B<L#0H@("`@("`@("`@("`@("`@("`@
M("=B;W)D97(G(#T^('1R=64L#0H@("`@("`@("`@("`@("`@("`@("=D871A
M)R`]/B!A<G)A>2AA<G)A>2@G*&YO('!A8VMA9V5S(&EN<W1A;&QE9"DG*2DL
M#0H@("`@("`@("`@("`@("`@("`@("D[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)&1A=&$L("1C;VUM86YD
M*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H@
M("`@#0H@("`@9G5N8W1I;VX@9&]&:6QE3&ES="@D8V]M;6%N9"P@)&]P=&EO
M;G,L("1P87)A;7,I#0H@("`@>PT*("`@("`@("!I9B`H8V]U;G0H)'!A<F%M
M<RD@(3T@,2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*"=L:7-T+69I;&5S(&5X<&5C=',@,2!P87)A;65T97(G*3L-"B`@("`@
M("`@?0T*("`@("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES
M=')Y*"D[#0H@("`@("`@(&EF("@A:7-?9&ER*"1P87)A;7-;,%TI("8F("AF
M:6QE7V5X:7-T<R@D<&%R86US6S!=*2!\?"`D9G`@/2!`9F]P96XH)'!A<F%M
M<ULP72P-"B`@("`@("`@("`@("`@)W(G*2DI('L-"B`@("`@("`@("`@($!F
M8VQO<V4H)&9P*3L-"B`@("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=0
M14%27U!A8VMA9V5&:6QE)RDI('L-"B`@("`@("`@("`@("`@("!R97%U:7)E
M7V]N8V4@)U!%05(O4&%C:V%G949I;&4N<&AP)SL-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("1P:V<@/2`F;F5W(%!%05)?4&%C:V%G949I;&4H)'1H
M:7,M/F-O;F9I9RP@)'1H:7,M/E]D96)U9RD[#0H@("`@("`@("`@("!014%2
M.CIS=&%T:6-0=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[
M#0H@("`@("`@("`@("`D:6YF;R`]("8D<&MG+3YF<F]M06YY1FEL92@D<&%R
M86US6S!=+"!014%27U9!3$E$051%7TY/4DU!3"D[#0H@("`@("`@("`@("!0
M14%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("`D
M:&5A9&EN9W,@/2!A<G)A>2@G4&%C:V%G92!&:6QE)RP@)TEN<W1A;&P@4&%T
M:"<I.PT*("`@("`@("`@("`@)&EN<W1A;&QE9"`](&9A;'-E.PT*("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@4$5!4CHZ<W1A=&EC4'5S:$5R<F]R
M2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`@("`@)'!A
M<G-E9"`]("1R96<M/G!A<G-E4&%C:V%G94YA;64H)'!A<F%M<ULP72P@)'1H
M:7,M/F-O;F9I9RT^9V5T*"=D969A=6QT7V-H86YN96PG*2D[#0H@("`@("`@
M("`@("!014%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<&%R<V5D*2D@>PT*("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D<&%R<V5D*3L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("1I;F9O(#T@)B1R96<M/F=E=%!A
M8VMA9V4H)'!A<G-E9%LG<&%C:V%G92==+"`D<&%R<V5D6R=C:&%N;F5L)UTI
M.PT*("`@("`@("`@("`@)&AE861I;F=S(#T@87)R87DH)U1Y<&4G+"`G26YS
M=&%L;"!0871H)RD[#0H@("`@("`@("`@("`D:6YS=&%L;&5D(#T@=')U93L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI
M('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D:6YF
M;RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1I;F9O(#T]/2!N=6QL*2![
M#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F`D<&%R
M86US6S!=)R!N;W0@:6YS=&%L;&5D(BD[#0H@("`@("`@('T-"B`@("`@("`@
M)&QI<W0@/2`H)&EN9F\M/F=E=%!A8VMA9V5X;6Q697)S:6]N*"D@/3T@)S$N
M,"<@?'P@)&EN<W1A;&QE9"D@/PT*("`@("`@("`@("`@)&EN9F\M/F=E=$9I
M;&5L:7-T*"D@.B`D:6YF;RT^9V5T0V]N=&5N=',H*3L-"B`@("`@("`@:68@
M*"1I;G-T86QL960I('L-"B`@("`@("`@("`@("1C87!T:6]N(#T@)TEN<W1A
M;&QE9"!&:6QE<R!&;W(@)R`N("1P87)A;7-;,%T[#0H@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`D8V%P=&EO;B`]("=#;VYT96YT<R!O9B`G("X@
M8F%S96YA;64H)'!A<F%M<ULP72D[#0H@("`@("`@('T-"B`@("`@("`@)&1A
M=&$@/2!A<G)A>2@-"B`@("`@("`@("`@("=C87!T:6]N)R`]/B`D8V%P=&EO
M;BP-"B`@("`@("`@("`@("=B;W)D97(G(#T^('1R=64L#0H@("`@("`@("`@
M("`G:&5A9&QI;F4G(#T^("1H96%D:6YG<RD[#0H@("`@("`@(&EF("@D:6YF
M;RT^9V5T4&%C:V%G97AM;%9E<G-I;VXH*2`]/2`G,2XP)R!\?"`D:6YS=&%L
M;&5D*2![#0H@("`@("`@("`@("!F;W)E86-H("@D;&ES="!A<R`D9FEL92`]
M/B`D871T*2![#0H@("`@("`@("`@("`@("`@:68@*"1I;G-T86QL960I('L-
M"B`@("`@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1A='1;)VEN<W1A;&QE
M9%]A<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M)&1A=&%;)V1A=&$G75M=(#T@87)R87DH)&%T=%LG<F]L92==+"`D871T6R=I
M;G-T86QL961?87,G72D[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A='1;)V)A<V5I;G-T86QL
M9&ER)UTI("8F("%I;E]A<G)A>2@D871T6R=R;VQE)UTL#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"=T97-T)RP@)V1A=&$G+"`G9&]C)RDI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D9&5S="`]("1A='1;)V)A
M<V5I;G-T86QL9&ER)UT@+B!$25)%0U1/4EE?4T5005)!5$]2("X-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9FEL93L-"B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1D97-T
M(#T@)&9I;&4[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@<W=I=&-H("@D871T6R=R;VQE)UTI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@(&-A<V4@)W1E<W0G.@T*("`@("`@("`@("`@("`@("`@
M("`@("`@8V%S92`G9&%T82<Z#0H@("`@("`@("`@("`@("`@("`@("`@("!C
M87-E("=D;V,G.@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R;VQE
M(#T@)&%T=%LG<F]L92==.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@D<F]L92`]/2`G=&5S="<I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)')O;&4@+CT@)W,G.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5S
M="`]("1T:&ES+3YC;VYF:6<M/F=E="@D<F]L92`N("=?9&ER)RD@+B!$25)%
M0U1/4EE?4T5005)!5$]2("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&EN9F\M/F=E=%!A8VMA9V4H*2`N($1)4D5#5$]265]315!!4D%4
M3U(@+B`D9&5S=#L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL-"B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)W!H<"<Z#0H@("`@
M("`@("`@("`@("`@("`@("`@("!D969A=6QT.@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1D97-T(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=P:'!?
M9&ER)RD@+B!$25)%0U1/4EE?4T5005)!5$]2("X-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&1E<W0[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@)&1S,B`]($1)4D5#5$]265]315!!
M4D%43U(@+B!$25)%0U1/4EE?4T5005)!5$]2.PT*("`@("`@("`@("`@("`@
M("`@("`D9&5S="`]('!R96=?<F5P;&%C92AA<G)A>2@G(5Q<7%PK(2<L("<A
M+R$G+"`B(21D<S(K(2(I+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*$1)4D5#5$]265]315!!
M4D%43U(L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@1$E214-43U)97U-%4$%2051/4BP-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!$25)%0U1/4EE?4T5005)!5$]2*2P-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5S
M="D[#0H@("`@("`@("`@("`@("`@("`@("1F:6QE(#T@<')E9U]R97!L86-E
M*"<A+RLA)RP@)R\G+"`D9FEL92D[#0H@("`@("`@("`@("`@("`@("`@("1D
M871A6R=D871A)UU;72`](&%R<F%Y*"1F:6QE+"`D9&5S="D[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>R`O
M+R!P86-K86=E+GAM;"`R+C`L(&YO="!I;G-T86QL960-"B`@("`@("`@("`@
M(&EF("@A:7-S970H)&QI<W1;)V1I<B==6R=F:6QE)UU;,%TI*2![#0H@("`@
M("`@("`@("`@("`@)&QI<W1;)V1I<B==6R=F:6QE)UT@/2!A<G)A>2@D;&ES
M=%LG9&ER)UU;)V9I;&4G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!F;W)E86-H("@D;&ES=%LG9&ER)UU;)V9I;&4G72!A<R`D871T*2![#0H@
M("`@("`@("`@("`@("`@)&%T="`]("1A='1;)V%T=')I8G,G73L-"B`@("`@
M("`@("`@("`@("`D9FEL92`]("1A='1;)VYA;64G73L-"B`@("`@("`@("`@
M("`@("`D<F]L92`]("9014%27TEN<W1A;&QE<E]2;VQE.CIF86-T;W)Y*"1I
M;F9O+"`D871T6R=R;VQE)UTL("1T:&ES+3YC;VYF:6<I.PT*("`@("`@("`@
M("`@("`@("1R;VQE+3YS971U<"@D=&AI<RP@)&EN9F\L("1A='0L("1F:6QE
M*3L-"B`@("`@("`@("`@("`@("!I9B`H(21R;VQE+3YI<TEN<W1A;&QA8FQE
M*"DI('L-"B`@("`@("`@("`@("`@("`@("`@)&1E<W0@/2`G*&YO="!I;G-T
M86QL86)L92DG.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@("`@("1D97-T(#T@)')O;&4M/G!R;V-E<W-);G-T86QL871I
M;VXH)&EN9F\L("1A='0L("1F:6QE+"`G)RD[#0H@("`@("`@("`@("`@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1D97-T*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)&1E<W0@/2`G*%5N:VYO=VX@<F]L92`B)R`N("1A='1;
M)W)O;&4G72`N("<I)SL-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&QI<W0H+"P@)&1E<W0I(#T@)&1E
M<W0[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@)&1A=&%;)V1A=&$G75M=(#T@87)R87DH)&9I
M;&4L("1D97-T*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)&1A=&$L("1C;VUM86YD*3L-"B`@
M("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@
M+R\@>WM[(&1O4VAE;&Q497-T*"D-"@T*("`@(&9U;F-T:6]N(&1O4VAE;&Q4
M97-T*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@
M("`@("1T:&ES+3YP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%52
M3BD[#0H@("`@("`@("1R96<@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G:7-T
M<GDH*3L-"B`@("`@("`@)&EN9F\@/2`D<F5G+3YP87)S95!A8VMA9V5.86UE
M*"1P87)A;7-;,%TL("1T:&ES+3YC;VYF:6<M/F=E="@G9&5F875L=%]C:&%N
M;F5L)RDI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-
M"B`@("`@("`@("`@(&5X:70H,2D[("\O(&EN=F%L:60@<&%C:V%G92!N86UE
M#0H@("`@("`@('T-"B`@("`@("`@)'!A8VMA9V4@/2`D:6YF;ULG<&%C:V%G
M92==.PT*("`@("`@("`D8VAA;FYE;"`]("1I;F9O6R=C:&%N;F5L)UT[#0H@
M("`@("`@("\O(")P96%R('-H96QL+71E<W0@1F]O(@T*("`@("`@("!I9B`H
M(21R96<M/G!A8VMA9V5%>&ES=',H)'!A8VMA9V4L("1C:&%N;F5L*2D@>PT*
M("`@("`@("`@("`@:68@*"1C:&%N;F5L(#T]("=P96-L+G!H<"YN970G*2![
M#0H@("`@("`@("`@("`@("`@:68@*"1R96<M/G!A8VMA9V5%>&ES=',H)'!A
M8VMA9V4L("=P96%R+G!H<"YN970G*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`D8VAA;FYE;"`]("=P96%R+G!H<"YN970G.R`O+R!M86=I8V%L;'D@8VAA
M;F=E(&-H86YN96QS(&9O<B!E>'1E;G-I;VYS#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AS:7IE
M;V8H)'!A<F%M<RD@/3T@,2D@>PT*("`@("`@("`@("`@:68@*"$D<F5G+3YP
M86-K86=E17AI<W1S*"1P86-K86=E+"`D8VAA;FYE;"DI('L-"B`@("`@("`@
M("`@("`@("!E>&ET*#$I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M+R\@(G!E87(@<VAE;&PM=&5S="!&;V\@,2XP(@T*("`@("`@("!](&5L<V5I
M9B`H<VEZ96]F*"1P87)A;7,I(#T](#(I('L-"B`@("`@("`@("`@("1V(#T@
M)')E9RT^<&%C:V%G94EN9F\H)'!A8VMA9V4L("=V97)S:6]N)RP@)&-H86YN
M96PI.PT*("`@("`@("`@("`@:68@*"$D=B!\?"`A=F5R<VEO;E]C;VUP87)E
M*"(D=B(L(")[)'!A<F%M<ULQ77TB+"`B9V4B*2D@>PT*("`@("`@("`@("`@
M("`@(&5X:70H,2D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`O+R`B
M<&5A<B!S:&5L;"UT97-T($9O;R!G92`Q+C`B#0H@("`@("`@('T@96QS96EF
M("AS:7IE;V8H)'!A<F%M<RD@/3T@,RD@>PT*("`@("`@("`@("`@)'8@/2`D
M<F5G+3YP86-K86=E26YF;R@D<&%C:V%G92P@)W9E<G-I;VXG+"`D8VAA;FYE
M;"D[#0H@("`@("`@("`@("!I9B`H(21V('Q\("%V97)S:6]N7V-O;7!A<F4H
M(B1V(BP@(GLD<&%R86US6S)=?2(L("1P87)A;7-;,5TI*2![#0H@("`@("`@
M("`@("`@("`@97AI="@Q*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("1T:&ES+3YP;W!%<G)O<DAA;F1L:6YG*"D[
M#0H@("`@("`@("`@("`D=&AI<RT^<F%I<V5%<G)O<B@B)&-O;6UA;F0Z(&5X
M<&5C=',@,2!T;R`S('!A<F%M971E<G,B*3L-"B`@("`@("`@("`@(&5X:70H
M,2D[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![
M>WL@9&]);F9O#0H-"B`@("!F=6YC=&EO;B!D;TEN9F\H)&-O;6UA;F0L("1O
M<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@:68@*&-O=6YT*"1P
M87)A;7,I("$](#$I('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@G<&5A<B!I;F9O(&5X<&5C=',@,2!P87)A;65T97(G*3L-"B`@
M("`@("`@?0T*("`@("`@("`D:6YF;R`](&9A;'-E.PT*("`@("`@("`D<F5G
M(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@(&EF
M("@H0&ES7V9I;&4H)'!A<F%M<ULP72D@)B8@(6ES7V1I<B@D<&%R86US6S!=
M*2D@?'P@)&9P(#T@0&9O<&5N*"1P87)A;7-;,%TL("=R)RDI('L-"B`@("`@
M("`@("`@($!F8VQO<V4H)&9P*3L-"B`@("`@("`@("`@(&EF("@A8VQA<W-?
M97AI<W1S*"=014%27U!A8VMA9V5&:6QE)RDI('L-"B`@("`@("`@("`@("`@
M("!R97%U:7)E7V]N8V4@)U!%05(O4&%C:V%G949I;&4N<&AP)SL-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("1P:V<@/2`F;F5W(%!%05)?4&%C:V%G
M949I;&4H)'1H:7,M/F-O;F9I9RP@)'1H:7,M/E]D96)U9RD[#0H@("`@("`@
M("`@("!014%2.CIS=&%T:6-0=7-H17)R;W)(86YD;&EN9RA014%27T524D]2
M7U)%5%523BD[#0H@("`@("`@("`@("`D;V)J(#T@)B1P:V<M/F9R;VU!;GE&
M:6QE*"1P87)A;7-;,%TL(%!%05)?5D%,241!5$5?3D]234%,*3L-"B`@("`@
M("`@("`@(%!%05(Z.G-T871I8U!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@
M("`@("`@(&EF("A014%2.CII<T5R<F]R*"1O8FHI*2![#0H@("`@("`@("`@
M("`@("`@)'5I;F9O(#T@)&]B:BT^9V5T57-E<DEN9F\H*3L-"B`@("`@("`@
M("`@("`@("!I9B`H:7-?87)R87DH)'5I;F9O*2D@>PT*("`@("`@("`@("`@
M("`@("`@("!F;W)E86-H("@D=6EN9F\@87,@)&UE<W-A9V4I('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D;65S<V%G92DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;65S<V%G92`]("1M97-S
M86=E6R=M97-S86=E)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H
M)&UE<W-A9V4I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@D;V)J*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D
M;V)J+3YG971086-K86=E>&UL5F5R<VEO;B@I(#T]("<Q+C`G*2![#0H@("`@
M("`@("`@("`@("`@)&EN9F\@/2`D;V)J+3YT;T%R<F%Y*"D[#0H@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7V1O26YF;S(H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US+"`D;V)J+"!F
M86QS92D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`D<&%R<V5D(#T@)')E9RT^<&%R<V5086-K86=E3F%M92@D<&%R
M86US6S!=+"`D=&AI<RT^8V]N9FEG+3YG970H)V1E9F%U;'1?8VAA;FYE;"<I
M*3L-"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1P87)S960I*2![
M#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1P
M87)S960I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'!A8VMA9V4@
M/2`D<&%R<V5D6R=P86-K86=E)UT[#0H@("`@("`@("`@("`D8VAA;FYE;"`]
M("1P87)S961;)V-H86YN96PG73L-"B`@("`@("`@("`@("1I;F9O(#T@)')E
M9RT^<&%C:V%G94EN9F\H)'!A8VMA9V4L(&YU;&PL("1C:&%N;F5L*3L-"B`@
M("`@("`@("`@(&EF("AI<W-E="@D:6YF;ULG;VQD)UTI*2![#0H@("`@("`@
M("`@("`@("`@)&]B:B`]("1R96<M/F=E=%!A8VMA9V4H)'!A8VMA9V4L("1C
M:&%N;F5L*3L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]D;TEN
M9F\R*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RP@)&]B:BP@=')U92D[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)&EN9F\I*2![#0H@("`@("`@("`@("!R971U<FX@)&EN9F\[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*&5M<'1Y*"1I;F9O*2D@>PT*("`@
M("`@("`@("`@)'1H:7,M/G)A:7-E17)R;W(H(DYO(&EN9F]R;6%T:6]N(&9O
M=6YD(&9O<B!@)'!A<F%M<ULP72<B*3L-"B`@("`@("`@("`@(')E='5R;CL-
M"B`@("`@("`@?0T*("`@("`@("!U;G-E="@D:6YF;ULG9FEL96QI<W0G72D[
M#0H@("`@("`@('5N<V5T*"1I;F9O6R=D:7)T<F5E)UTI.PT*("`@("`@("!U
M;G-E="@D:6YF;ULG8VAA;F=E;&]G)UTI.PT*("`@("`@("!I9B`H:7-S970H
M)&EN9F];)WAS9'9E<G-I;VXG72DI('L-"B`@("`@("`@("`@("1I;F9O6R=P
M86-K86=E+GAM;"!V97)S:6]N)UT@/2`D:6YF;ULG>'-D=F5R<VEO;B==.PT*
M("`@("`@("`@("`@=6YS970H)&EN9F];)WAS9'9E<G-I;VXG72D[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1I;F9O6R=P86-K86=E<G9E<G-I
M;VXG72DI('L-"B`@("`@("`@("`@("1I;F9O6R=P86-K86=E9"!W:71H(%!%
M05(@=F5R<VEO;B==(#T@)&EN9F];)W!A8VMA9V5R=F5R<VEO;B==.PT*("`@
M("`@("`@("`@=6YS970H)&EN9F];)W!A8VMA9V5R=F5R<VEO;B==*3L-"B`@
M("`@("`@?0T*("`@("`@("`D:V5Y<R`](&%R<F%Y7VME>7,H)&EN9F\I.PT*
M("`@("`@("`D;&]N9W1E>'0@/2!A<G)A>2@G9&5S8W)I<'1I;VXG+"`G<W5M
M;6%R>2<I.PT*("`@("`@("!F;W)E86-H("@D:V5Y<R!A<R`D:V5Y*2![#0H@
M("`@("`@("`@("!I9B`H:7-?87)R87DH)&EN9F];)&ME>5TI*2![#0H@("`@
M("`@("`@("`@("`@<W=I=&-H("@D:V5Y*2![#0H@("`@("`@("`@("`@("`@
M("`@(&-A<V4@)VUA:6YT86EN97)S)SH@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)&D@/2`P.PT*("`@("`@("`@("`@("`@("`@("`@("`@)&US='(@
M/2`G)SL-"B`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1I;F9O
M6R1K97E=(&%S("1M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"1I*RL@/B`P*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1M<W1R("X](")<;B([#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1M<W1R("X]("1M
M6R=N86UE)UT@+B`B(#PB.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D;5LG96UA:6PG72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&US='(@+CT@)&U;)V5M86EL)UT[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&US='(@+CT@)&U;)VAA;F1L92==("X@)T!P
M:'`N;F5T)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&US='(@+CT@(CX@*"1M6W)O;&5=
M*2([#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D:6YF;ULD:V5Y72`]("1M<W1R.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@8V%S92`G<F5L96%S95]D97!S)SH@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)&D@/2`P.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)&1S='(@/2`G)SL-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1I;F9O6R1K97E=(&%S("1D*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?9&5P<U]R96Q?=')A
M;G-;)&1;)W)E;"==72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)')E;"`]("1T:&ES+3Y?9&5P<U]R96Q?=')A;G-;)&1;)W)E;"==
M73L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5L(#T@)&1;)W)E;"==
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]D97!S7W1Y<&5?
M=')A;G-;)&1;)W1Y<&4G75TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T>7!E(#T@=6-F:7)S="@D=&AI<RT^7V1E<'-?='EP95]T
M<F%N<ULD9%LG='EP92==72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1Y<&4@/2`D9%LG='EP92==.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)&1;)VYA;64G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&YA;64@/2`D9%LG;F%M92==("X@)R`G.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1N86UE(#T@)R<[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D9%LG=F5R<VEO;B==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=F5R<VEO;B`]("1D6R=V97)S:6]N)UT@+B`G("<[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'9E<G-I;VX@/2`G)SL-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1D6R=O<'1I;VYA;"==*2`F)B`D9%LG;W!T:6]N
M86PG72`]/2`G>65S)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D;W!T:6]N86P@/2`G("AO<'1I;VYA;"DG.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1O<'1I;VYA;"`]("<G.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M9'-T<B`N/2`B)'1Y<&4@)&YA;64D<F5L("1V97)S:6]N)&]P=&EO;F%L7&XB
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("`@("`@)&EN9F];)&ME>5T@/2`D9'-T<CL-"B`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@(&-A<V4@)W!R;W9I9&5S)R`Z('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1D96)U9R`]("1T:&ES+3YC;VYF:6<M/F=E="@G
M=F5R8F]S92<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1D96)U
M9R`\(#(I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<'-T<B`]
M("=#;&%S<V5S.B`G.PT*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<'-T<B`]("<G.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@)&D@/2`P.PT*("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)&EN9F];)&ME>5T@87,@)'`I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H)&1E8G5G(#P@,B`F)B`D<%LG='EP92==("$](")C;&%S
M<R(I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN
M=64[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("\O($]N;'D@<')I;G0@8VQA<W-E<R!W:&5N
M('9E<F)O<VET>2!M;V1E(&ES(#P@,@T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@D9&5B=6<@/"`R*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("@D:2LK(#X@,"D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'!S='(@+CT@(BP@(CL-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<'-T<B`N/2`D<%LG;F%M92==.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@D:2LK(#X@,"D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'!S='(@+CT@(EQN(CL-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<'-T<B`N/2!U8V9I<G-T*"1P6R=T>7!E)UTI
M("X@(B`B("X@)'!;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1P6R=E>'!L:6-I="==*2`F)B`D<%LG97AP
M;&EC:70G72`]/2`Q*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<'-T<B`N/2`B("AE>'!L:6-I="DB.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@)&EN9F];)&ME>5T@/2`D<'-T<CL-"B`@("`@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@(&-A<V4@)V-O;F9I9W5R95]O<'1I;VYS
M)R`Z('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1I;F9O
M6R1K97E=(&%S("1I(#T^("1P*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&EN9F];)&ME>5U;)&E=(#T@87)R87E?;6%P*&YU;&PL(&%R<F%Y
M7VME>7,H)'`I+"!A<G)A>5]V86QU97,H)'`I*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D:6YF;ULD:V5Y75LD:5T@/2!A<G)A>5]M87`H8W)E
M871E7V9U;F-T:6]N*"<D82<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=R971U<FX@:F]I;B@B(#T@(BPD82D[)RDL("1I;F9O6R1K97E=
M6R1I72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F];)&ME
M>5U;)&E=(#T@:6UP;&]D92@G+"`G+"`D:6YF;ULD:V5Y75LD:5TI.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@)&EN9F];)&ME>5T@/2!I;7!L;V1E*")<;B(L("1I;F9O6R1K97E=*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&1E9F%U;'0Z('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R1K97E=(#T@:6UP;&]D92@B
M+"`B+"`D:6YF;ULD:V5Y72D[#0H@("`@("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D:V5Y(#T]("=?
M;&%S=&UO9&EF:65D)RD@>PT*("`@("`@("`@("`@("`@("1H9&%T92`](&1A
M=&4H)UDM;2UD)RP@)&EN9F];)&ME>5TI.PT*("`@("`@("`@("`@("`@('5N
M<V5T*"1I;F9O6R1K97E=*3L-"B`@("`@("`@("`@("`@("`D:6YF;ULG3&%S
M="!-;V1I9FEE9"==(#T@)&AD871E.PT*("`@("`@("`@("`@?2!E;'-E:68@
M*"1K97D@/3T@)U]L87-T=F5R<VEO;B<I('L-"B`@("`@("`@("`@("`@("`D
M:6YF;ULG3&%S="!);G-T86QL960@5F5R<VEO;B==(#T@)&EN9F];)&ME>5T@
M/R`D:6YF;ULD:V5Y72`Z("<M($YO;F4@+2<[#0H@("`@("`@("`@("`@("`@
M=6YS970H)&EN9F];)&ME>5TI.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`D:6YF;ULD:V5Y72`]('1R:6TH)&EN9F];)&ME>5TI
M.PT*("`@("`@("`@("`@("`@(&EF("AI;E]A<G)A>2@D:V5Y+"`D;&]N9W1E
M>'0I*2![#0H@("`@("`@("`@("`@("`@("`@("1I;F9O6R1K97E=(#T@<')E
M9U]R97!L86-E*"<O("`K+R<L("<@)RP@)&EN9F];)&ME>5TI.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("`D8V%P=&EO;B`]("=!8F]U="`G("X@)&EN9F];)W!A8VMA9V4G72`N("<M
M)R`N("1I;F9O6R=V97)S:6]N)UT[#0H@("`@("`@("1D871A(#T@87)R87DH
M#0H@("`@("`@("`@("`G8V%P=&EO;B<@/3X@)&-A<'1I;VXL#0H@("`@("`@
M("`@("`G8F]R9&5R)R`]/B!T<G5E*3L-"B`@("`@("`@9F]R96%C:"`H)&EN
M9F\@87,@)&ME>2`]/B`D=F%L=64I('L-"B`@("`@("`@("`@("1K97D@/2!U
M8W=O<F1S*'1R:6TH<W1R7W)E<&QA8V4H)U\G+"`G("<L("1K97DI*2D[#0H@
M("`@("`@("`@("`D9&%T85LG9&%T82==6UT@/2!A<G)A>2@D:V5Y+"`D=F%L
M=64I.PT*("`@("`@("!]#0H@("`@("`@("1D871A6R=R87<G72`]("1I;F9O
M.PT*#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D9&%T82P@)W!A
M8VMA9V4M:6YF;R<I.PT*("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@+RHJ
M#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@7V1O26YF;S(H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US+"`F)&]B
M:BP@)&EN<W1A;&QE9"D-"B`@("![#0H@("`@("`@("1R96<@/2`F)'1H:7,M
M/F-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-"B`@("`@("`@)&-A<'1I;VX@/2`G
M06)O=70@)R`N("1O8FHM/F=E=$-H86YN96PH*2`N("<O)R`N)&]B:BT^9V5T
M4&%C:V%G92@I("X@)RTG("X-"B`@("`@("`@("`@("1O8FHM/F=E=%9E<G-I
M;VXH*3L-"B`@("`@("`@)&1A=&$@/2!A<G)A>2@-"B`@("`@("`@("`@("=C
M87!T:6]N)R`]/B`D8V%P=&EO;BP-"B`@("`@("`@("`@("=B;W)D97(G(#T^
M('1R=64I.PT*("`@("`@("!S=VET8V@@*"1O8FHM/F=E=%!A8VMA9V54>7!E
M*"DI('L-"B`@("`@("`@("`@(&-A<V4@)W!H<"<@.@T*("`@("`@("`@("`@
M("`@("1R96QE87-E(#T@)U!%05(M<W1Y;&4@4$A0+6)A<V5D(%!A8VMA9V4G
M.PT*("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=E>'1S
M<F,G(#H-"B`@("`@("`@("`@("`@("`D<F5L96%S92`]("=014-,+7-T>6QE
M(%!(4"!E>'1E;G-I;VX@*'-O=7)C92!C;V1E*2<[#0H@("`@("`@("`@("!B
M<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)V5X=&)I;B<@.@T*("`@("`@("`@
M("`@("`@("1R96QE87-E(#T@)U!%0TPM<W1Y;&4@4$A0(&5X=&5N<VEO;B`H
M8FEN87)Y*2<[#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A
M<V4@)V)U;F1L92<@.@T*("`@("`@("`@("`@("`@("1R96QE87-E(#T@)U!A
M8VMA9V4@8G5N9&QE("AC;VQL96-T:6]N(&]F('!A8VMA9V5S*2<[#0H@("`@
M("`@("`@("!B<F5A:SL-"B`@("`@("`@?0T*("`@("`@("`D97AT96YD<R`]
M("1O8FHM/F=E=$5X=&5N9',H*3L-"B`@("`@("`@)&5X=&5N9',@/2`D97AT
M96YD<R`_#0H@("`@("`@("`@("`D;V)J+3YG971086-K86=E*"D@+B`G("AE
M>'1E;F1S("<@+B`D97AT96YD<R`N("<I)R`Z("1O8FHM/F=E=%!A8VMA9V4H
M*3L-"B`@("`@("`@:68@*"1S<F,@/2`D;V)J+3YG9713;W5R8V5086-K86=E
M*"DI('L-"B`@("`@("`@("`@("1E>'1E;F1S("X]("<@*'-O=7)C92!P86-K
M86=E("<@+B`D<W)C6R=C:&%N;F5L)UT@+B`G+R<@+B`D<W)C6R=P86-K86=E
M)UT@+B`G*2<[#0H@("`@("`@('T-"B`@("`@("`@)&EN9F\@/2!A<G)A>2@-
M"B`@("`@("`@("`@("=296QE87-E(%1Y<&4G(#T^("1R96QE87-E+`T*("`@
M("`@("`@("`@)TYA;64G(#T^("1E>'1E;F1S+`T*("`@("`@("`@("`@)T-H
M86YN96PG(#T^("1O8FHM/F=E=$-H86YN96PH*2P-"B`@("`@("`@("`@("=3
M=6UM87)Y)R`]/B!P<F5G7W)E<&QA8V4H)R\@("LO)RP@)R`G+"`D;V)J+3YG
M9713=6UM87)Y*"DI+`T*("`@("`@("`@("`@)T1E<V-R:7!T:6]N)R`]/B!P
M<F5G7W)E<&QA8V4H)R\@("LO)RP@)R`G+"`D;V)J+3YG971$97-C<FEP=&EO
M;B@I*2P-"B`@("`@("`@("`@("D[#0H@("`@("`@("1I;F9O6R=-86EN=&%I
M;F5R<R==(#T@)R<[#0H@("`@("`@(&9O<F5A8V@@*&%R<F%Y*"=L96%D)RP@
M)V1E=F5L;W!E<B<L("=C;VYT<FEB=71O<B<L("=H96QP97(G*2!A<R`D<F]L
M92D@>PT*("`@("`@("`@("`@)&QE861S(#T@)&]B:BT^>R)G971[)')O;&5]
M<R)]*"D[#0H@("`@("`@("`@("!I9B`H(21L96%D<RD@>PT*("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M:68@*&ES<V5T*"1L96%D<ULG86-T:79E)UTI*2![#0H@("`@("`@("`@("`@
M("`@)&QE861S(#T@87)R87DH)&QE861S*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&9O<F5A8V@@*"1L96%D<R!A<R`D;&5A9"D@>PT*("`@("`@
M("`@("`@("`@(&EF("@A96UP='DH)&EN9F];)TUA:6YT86EN97)S)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("1I;F9O6R=-86EN=&%I;F5R<R==("X]
M(")<;B([#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1I
M;F9O6R=-86EN=&%I;F5R<R==("X]("1L96%D6R=N86UE)UT@+B`G(#PG.PT*
M("`@("`@("`@("`@("`@("1I;F9O6R=-86EN=&%I;F5R<R==("X]("1L96%D
M6R=E;6%I;"==("X@(CX@*"1R;VQE*2([#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@)&EN9F];)U)E;&5A<V4@1&%T92==(#T@)&]B:BT^
M9V5T1&%T92@I.PT*("`@("`@("!I9B`H)'1I;64@/2`D;V)J+3YG9714:6UE
M*"DI('L-"B`@("`@("`@("`@("1I;F9O6R=296QE87-E($1A=&4G72`N/2`G
M("<@+B`D=&EM93L-"B`@("`@("`@?0T*("`@("`@("`D:6YF;ULG4F5L96%S
M92!697)S:6]N)UT@/2`D;V)J+3YG971697)S:6]N*"D@+B`G("@G("X@)&]B
M:BT^9V5T4W1A=&4H*2`N("<I)SL-"B`@("`@("`@)&EN9F];)T%022!697)S
M:6]N)UT@/2`D;V)J+3YG971697)S:6]N*"=A<&DG*2`N("<@*"<@+B`D;V)J
M+3YG9713=&%T92@G87!I)RD@+B`G*2<[#0H@("`@("`@("1I;F9O6R=,:6-E
M;G-E)UT@/2`D;V)J+3YG971,:6-E;G-E*"D[#0H@("`@("`@("1U<FD@/2`D
M;V)J+3YG971,:6-E;G-E3&]C871I;VXH*3L-"B`@("`@("`@:68@*"1U<FDI
M('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D=7)I6R=U<FDG72DI('L-"B`@
M("`@("`@("`@("`@("`D:6YF;ULG3&EC96YS92==("X]("<@*"<@+B`D=7)I
M6R=U<FDG72`N("<I)SL-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@)&5X=')A(#T@)&]B:BT^9V5T26YS=&%L;&5D3&]C871I;VXH
M)&EN9F];)V9I;&5S;W5R8V4G72D[#0H@("`@("`@("`@("`@("`@:68@*"1E
M>'1R82D@>PT*("`@("`@("`@("`@("`@("`@("`D:6YF;ULG3&EC96YS92==
M("X]("<@*"<@+B`D=7)I6R=F:6QE<V]U<F-E)UT@+B`G*2<[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M("1I;F9O6R=296QE87-E($YO=&5S)UT@/2`D;V)J+3YG971.;W1E<R@I.PT*
M("`@("`@("!I9B`H)&-O;7!A="`]("1O8FHM/F=E=$-O;7!A=&EB;&4H*2D@
M>PT*("`@("`@("`@("`@)&EN9F];)T-O;7!A=&EB;&4@=VET:"==(#T@)R<[
M#0H@("`@("`@("`@("!F;W)E86-H("@D8V]M<&%T(&%S("1P86-K86=E*2![
M#0H@("`@("`@("`@("`@("`@)&EN9F];)T-O;7!A=&EB;&4@=VET:"==("X]
M("1P86-K86=E6R=C:&%N;F5L)UT@+B`G+R<@+B`D<&%C:V%G95LG<&%C:V%G
M92==("X-"B`@("`@("`@("`@("`@("`@("`@(EQN5F5R<VEO;G,@/CT@(B`N
M("1P86-K86=E6R=M:6XG72`N("<L(#P]("<@+B`D<&%C:V%G95LG;6%X)UT[
M#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P86-K86=E6R=E>&-L=61E
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D<&%C
M:V%G95LG97AC;'5D92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M)'!A8VMA9V5;)V5X8VQU9&4G72`](&EM<&QO9&4H)RP@)RP@)'!A8VMA9V5;
M)V5X8VQU9&4G72D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D:6YF;ULG3F]T($-O;7!A=&EB;&4@
M=VET:"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F];)TYO
M="!#;VUP871I8FQE('=I=&@G72`]("<G.PT*("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F];)TYO
M="!#;VUP871I8FQE('=I=&@G72`N/2`B7&XB.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1I;F9O6R=.;W0@0V]M<&%T
M:6)L92!W:71H)UT@+CT@)'!A8VMA9V5;)V-H86YN96PG72`N("<O)R`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D<&%C:V%G95LG<&%C:V%G92==("X@
M(EQN5F5R<VEO;G,@(B`N("1P86-K86=E6R=E>&-L=61E)UT[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M("1U<V5S<F]L92`]("1O8FHM/F=E=%5S97-R;VQE*"D[#0H@("`@("`@(&EF
M("@D=7-E<W)O;&4I('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)'5S97-R
M;VQE6S!=*2D@>PT*("`@("`@("`@("`@("`@("1U<V5S<F]L92`](&%R<F%Y
M*"1U<V5S<F]L92D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F;W)E
M86-H("@D=7-E<W)O;&4@87,@)')O;&5D871A*2![#0H@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1I;F9O6R=5<V5S($-U<W1O;2!2;VQE<R==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`D:6YF;ULG57-E<R!#=7-T;VT@4F]L97,G
M72`N/2`B7&XB.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@("`@("1I;F9O6R=5<V5S($-U<W1O;2!2;VQE<R==(#T@)R<[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D<F]L961A=&%;)W!A8VMA9V4G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@)')O;&5P86-K86=E(#T@)')E9RT^<&%R<V5D4&%C:V%G94YA;654;U-T
M<FEN9R@D<F]L961A=&$L('1R=64I.PT*("`@("`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@("`@("1R;VQE<&%C:V%G92`]("1R;VQE
M9&%T85LG=7)I)UT[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("1I;F9O6R=5<V5S($-U<W1O;2!2;VQE<R==("X]("1R;VQE9&%T85LG
M<F]L92==("X@)R`H)R`N("1R;VQE<&%C:V%G92`N("<I)SL-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("`D=7-E<W1A<VL@/2`D;V)J+3YG
M9715<V5S=&%S:R@I.PT*("`@("`@("!I9B`H)'5S97-T87-K*2![#0H@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1U<V5S=&%S:ULP72DI('L-"B`@("`@("`@
M("`@("`@("`D=7-E<W1A<VL@/2!A<G)A>2@D=7-E<W1A<VLI.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H)'5S97-T87-K(&%S("1T
M87-K9&%T82D@>PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D:6YF;ULG
M57-E<R!#=7-T;VT@5&%S:W,G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M)&EN9F];)U5S97,@0W5S=&]M(%1A<VMS)UT@+CT@(EQN(CL-"B`@("`@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D:6YF;ULG
M57-E<R!#=7-T;VT@5&%S:W,G72`]("<G.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1A<VMD871A6R=P86-K86=E
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1T87-K<&%C:V%G92`]("1R
M96<M/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H)'1A<VMD871A+"!T<G5E
M*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("`@("`D=&%S:W!A8VMA9V4@/2`D=&%S:V1A=&%;)W5R:2==.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D:6YF;ULG57-E<R!#=7-T
M;VT@5&%S:W,G72`N/2`D=&%S:V1A=&%;)W1A<VLG72`N("<@*"<@+B`D=&%S
M:W!A8VMA9V4@+B`G*2<[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@)&1E<',@/2`D;V)J+3YG971$97!E;F1E;F-I97,H*3L-"B`@("`@
M("`@)&EN9F];)U)E<75I<F5D($1E<&5N9&5N8VEE<R==(#T@)U!(4"!V97)S
M:6]N("<@+B`D9&5P<ULG<F5Q=6ER960G75LG<&AP)UU;)VUI;B==.PT*("`@
M("`@("!I9B`H:7-S970H)&1E<'-;)W)E<75I<F5D)UU;)W!H<"==6R=M87@G
M72DI('L-"B`@("`@("`@("`@("1I;F9O6R=297%U:7)E9"!$97!E;F1E;F-I
M97,G72`N/2`G+2<@+B`D9&5P<ULG<F5Q=6ER960G75LG<&AP)UU;)VUA>"==
M("X@(EQN(CL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1I;F9O
M6R=297%U:7)E9"!$97!E;F1E;F-I97,G72`N/2`B7&XB.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("AI<W-E="@D9&5P<ULG<F5Q=6ER960G75LG<&AP)UU;
M)V5X8VQU9&4G72DI('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)&EN9F];
M)TYO="!#;VUP871I8FQE('=I=&@G72DI('L-"B`@("`@("`@("`@("`@("`D
M:6YF;ULG3F]T($-O;7!A=&EB;&4@=VET:"==(#T@)R<[#0H@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1I;F9O6R=.;W0@0V]M<&%T
M:6)L92!W:71H)UT@+CT@(EQN(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(&EF("AI<U]A<G)A>2@D9&5P<ULG<F5Q=6ER960G75LG<&AP)UU;)V5X
M8VQU9&4G72DI('L-"B`@("`@("`@("`@("`@("`D9&5P<ULG<F5Q=6ER960G
M75LG<&AP)UU;)V5X8VQU9&4G72`]#0H@("`@("`@("`@("`@("`@("`@(&EM
M<&QO9&4H)RP@)RP@)&1E<'-;)W)E<75I<F5D)UU;)W!H<"==6R=E>&-L=61E
M)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&EN9F];)TYO="!#
M;VUP871I8FQE('=I=&@G72`N/2`B4$A0('9E<G-I;VYS7&X@("(@+@T*("`@
M("`@("`@("`@("`@("1D97!S6R=R97%U:7)E9"==6R=P:'`G75LG97AC;'5D
M92==.PT*("`@("`@("!]#0H@("`@("`@("1I;F9O6R=297%U:7)E9"!$97!E
M;F1E;F-I97,G72`N/2`G4$5!4B!I;G-T86QL97(@=F5R<VEO;B<[#0H@("`@
M("`@(&EF("AI<W-E="@D9&5P<ULG<F5Q=6ER960G75LG<&5A<FEN<W1A;&QE
M<B==6R=M87@G72DI('L-"B`@("`@("`@("`@("1I;F9O6R=297%U:7)E9"!$
M97!E;F1E;F-I97,G72`N/2`G<R`G("X-"B`@("`@("`@("`@("`@("`D9&5P
M<ULG<F5Q=6ER960G75LG<&5A<FEN<W1A;&QE<B==6R=M:6XG72`N("<M)R`N
M#0H@("`@("`@("`@("`@("`@)&1E<'-;)W)E<75I<F5D)UU;)W!E87)I;G-T
M86QL97(G75LG;6%X)UT[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`D:6YF;ULG4F5Q=6ER960@1&5P96YD96YC:65S)UT@+CT@)R`G("X-"B`@
M("`@("`@("`@("`@("`D9&5P<ULG<F5Q=6ER960G75LG<&5A<FEN<W1A;&QE
M<B==6R=M:6XG72`N("<@;W(@;F5W97(G.PT*("`@("`@("!]#0H@("`@("`@
M(&EF("AI<W-E="@D9&5P<ULG<F5Q=6ER960G75LG<&5A<FEN<W1A;&QE<B==
M6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1I;F9O
M6R=.;W0@0V]M<&%T:6)L92!W:71H)UTI*2![#0H@("`@("`@("`@("`@("`@
M)&EN9F];)TYO="!#;VUP871I8FQE('=I=&@G72`]("<G.PT*("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D:6YF;ULG3F]T($-O;7!A
M=&EB;&4@=VET:"==("X](")<;B([#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!I9B`H:7-?87)R87DH)&1E<'-;)W)E<75I<F5D)UU;)W!E87)I;G-T
M86QL97(G75LG97AC;'5D92==*2D@>PT*("`@("`@("`@("`@("`@("1D97!S
M6R=R97%U:7)E9"==6R=P96%R:6YS=&%L;&5R)UU;)V5X8VQU9&4G72`]#0H@
M("`@("`@("`@("`@("`@("`@(&EM<&QO9&4H)RP@)RP@)&1E<'-;)W)E<75I
M<F5D)UU;)W!E87)I;G-T86QL97(G75LG97AC;'5D92==*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("1I;F9O6R=.;W0@0V]M<&%T:6)L92!W:71H
M)UT@+CT@(E!%05(@:6YS=&%L;&5R7&X@(%9E<G-I;VYS("(@+@T*("`@("`@
M("`@("`@("`@("1D97!S6R=R97%U:7)E9"==6R=P96%R:6YS=&%L;&5R)UU;
M)V5X8VQU9&4G73L-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("AA<G)A
M>2@G4&%C:V%G92<L("=%>'1E;G-I;VXG*2!A<R`D='EP92D@>PT*("`@("`@
M("`@("`@)&EN9&5X(#T@<W1R=&]L;W=E<B@D='EP92D[#0H@("`@("`@("`@
M("!I9B`H:7-S970H)&1E<'-;)W)E<75I<F5D)UU;)&EN9&5X72DI('L-"B`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<'-;)W)E<75I<F5D)UU;)&EN
M9&5X75LG;F%M92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D9&5P<ULG
M<F5Q=6ER960G75LD:6YD97A=(#T@87)R87DH)&1E<'-;)W)E<75I<F5D)UU;
M)&EN9&5X72D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1D97!S6R=R97%U:7)E9"==6R1I;F1E>%T@87,@)'!A8VMA
M9V4I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P86-K86=E
M6R=C;VYF;&EC=',G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1I
M;F9O:6YD97@@/2`G3F]T($-O;7!A=&EB;&4@=VET:"<[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1I;F9O6R=.;W0@0V]M<&%T:6)L
M92!W:71H)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN
M9F];)TYO="!#;VUP871I8FQE('=I=&@G72`]("<G.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D:6YF;ULG3F]T($-O;7!A=&EB;&4@=VET:"==("X](")<;B([#0H@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`D:6YF;VEN9&5X
M(#T@)U)E<75I<F5D($1E<&5N9&5N8VEE<R<[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D:6YF;ULD:6YF;VEN9&5X72`N/2`B7&XB.PT*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@D:6YD97@@
M/3T@)V5X=&5N<VEO;B<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1N
M86UE(#T@)'!A8VMA9V5;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M<&%C:V%G95LG8VAA;FYE;"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1N86UE(#T@)'!A8VMA9V5;)V-H86YN96PG72`N("<O)R`N("1P
M86-K86=E6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N86UE(#T@)U]?
M=7)I+R<@+B`D<&%C:V%G95LG;F%M92==("X@)R`H<W1A=&EC(%5222DG.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("1I;F9O6R1I;F9O:6YD97A=("X]
M("(D='EP92`D;F%M92([#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D<&%C:V%G95LG=7)I)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D:6YF;ULD:6YF;VEN9&5X72`N/2`B7&X@($1O=VYL;V%D(%5223H@)'!A
M8VMA9V5;=7)I72([#0H@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU
M93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)'!A8VMA9V5;)VUA>"==*2`F)B!I<W-E="@D<&%C:V%G
M95LG;6EN)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D:6YF;ULD
M:6YF;VEN9&5X72`N/2`B(%QN("!697)S:6]N<R`B("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<&%C:V%G95LG;6EN)UT@+B`G+2<@+B`D<&%C
M:V%G95LG;6%X)UT[#0H@("`@("`@("`@("`@("`@("`@('T@96QS96EF("AI
M<W-E="@D<&%C:V%G95LG;6EN)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D:6YF;ULD:6YF;VEN9&5X72`N/2`B(%QN("!697)S:6]N("(@+@T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E6R=M:6XG72`N
M("<@;W(@;F5W97(G.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H
M:7-S970H)'!A8VMA9V5;)VUA>"==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)&EN9F];)&EN9F]I;F1E>%T@+CT@(B!<;B`@5F5R<VEO;B`B("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%C:V%G95LG;6%X)UT@
M+B`G(&]R(&]L9&5R)SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)'!A8VMA9V5;)W)E8V]M;65N9&5D
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D:6YF;ULD:6YF;VEN
M9&5X72`N/2`B7&X@(%)E8V]M;65N9&5D('9E<G-I;VXZ("1P86-K86=E6W)E
M8V]M;65N9&5D72([#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1P86-K86=E6R=E>&-L=61E)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1I;F9O6R=.
M;W0@0V]M<&%T:6)L92!W:71H)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&EN9F];)TYO="!#;VUP871I8FQE('=I=&@G72`]("<G.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D:6YF;ULG3F]T($-O;7!A=&EB;&4@=VET:"==
M("X](")<;B([#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)'!A8VMA9V5;)V5X8VQU
M9&4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%C:V%G
M95LG97AC;'5D92==(#T@:6UP;&]D92@G+"`G+"`D<&%C:V%G95LG97AC;'5D
M92==*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1P86-K86=E6R=P86-K86=E)UT@/2`D<&%C:V%G95LG
M;F%M92==.R`O+R!F;W(@<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9PT*("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<&%C:V%G95LG8V]N
M9FQI8W1S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN
M9F];)TYO="!#;VUP871I8FQE('=I=&@G72`N/2`G/3X@97AC97!T("<[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("1I;F9O6R=.;W0@0V]M<&%T:6)L92!W:71H)UT@+CT@)U!A8VMA9V4@
M)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E9RT^<&%R<V5D
M4&%C:V%G94YA;654;U-T<FEN9R@D<&%C:V%G92P@=')U92D[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D:6YF;ULG3F]T($-O;7!A=&EB;&4@=VET:"==
M("X](")<;B`@5F5R<VEO;G,@(B`N("1P86-K86=E6R=E>&-L=61E)UT[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!S
M6R=R97%U:7)E9"==6R=O<R==*2D@>PT*("`@("`@("`@("`@:68@*&ES<V5T
M*"1D97!S6R=R97%U:7)E9"==6R=O<R==6R=N86UE)UTI*2![#0H@("`@("`@
M("`@("`@("`@)&1E<%LG<F5Q=6ER960G75LG;W,G75LG;F%M92==(#T@87)R
M87DH)&1E<%LG<F5Q=6ER960G75LG;W,G75LG;F%M92==*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@*"1D97!;)W)E<75I<F5D)UU;
M)V]S)UT@87,@)&]S*2![#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1O
M<ULG8V]N9FQI8W1S)UTI("8F("1O<ULG8V]N9FQI8W1S)UT@/3T@)WEE<R<I
M('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D:6YF;ULG3F]T
M($-O;7!A=&EB;&4@=VET:"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)&EN9F];)TYO="!#;VUP871I8FQE('=I=&@G72`]("<G.PT*("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)&EN9F];)TYO="!#;VUP871I8FQE('=I=&@G72`N/2`B7&XB.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1I;F9O
M6R=.;W0@0V]M<&%T:6)L92!W:71H)UT@+CT@(B1O<UMN86UE72!/<&5R871I
M;F<@4WES=&5M(CL-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("`D:6YF;ULG4F5Q=6ER960@1&5P96YD96YC:65S)UT@
M+CT@(EQN(CL-"B`@("`@("`@("`@("`@("`@("`@)&EN9F];)U)E<75I<F5D
M($1E<&5N9&5N8VEE<R==("X]("(D;W-;;F%M95T@3W!E<F%T:6YG(%-Y<W1E
M;2([#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@(&EF("AI<W-E="@D9&5P<ULG<F5Q=6ER960G75LG87)C
M:"==*2D@>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1D97!S6R=R97%U:7)E
M9"==6R=A<F-H)UU;)W!A='1E<FXG72DI('L-"B`@("`@("`@("`@("`@("`D
M9&5P6R=R97%U:7)E9"==6R=A<F-H)UU;)W!A='1E<FXG72`](&%R<F%Y*"1D
M97!;)W)E<75I<F5D)UU;)V]S)UU;)W!A='1E<FXG72D[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!F;W)E86-H("@D9&5P6R=R97%U:7)E9"==6R=A
M<F-H)UT@87,@)&]S*2![#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1O
M<ULG8V]N9FQI8W1S)UTI("8F("1O<ULG8V]N9FQI8W1S)UT@/3T@)WEE<R<I
M('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D:6YF;ULG3F]T
M($-O;7!A=&EB;&4@=VET:"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)&EN9F];)TYO="!#;VUP871I8FQE('=I=&@G72`]("<G.PT*("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)&EN9F];)TYO="!#;VUP871I8FQE('=I=&@G72`N/2`B7&XB.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1I;F9O
M6R=.;W0@0V]M<&%T:6)L92!W:71H)UT@+CT@(D]3+T%R8V@@;6%T8VAI;F<@
M<&%T=&5R;B`G+R1O<UMP871T97)N72\G(CL-"B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D:6YF;ULG4F5Q=6ER960@
M1&5P96YD96YC:65S)UT@+CT@(EQN(CL-"B`@("`@("`@("`@("`@("`@("`@
M)&EN9F];)U)E<75I<F5D($1E<&5N9&5N8VEE<R==("X](")/4R]!<F-H(&UA
M=&-H:6YG('!A='1E<FX@)R\D;W-;<&%T=&5R;ETO)R([#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF
M("AI<W-E="@D9&5P<ULG;W!T:6]N86PG72DI('L-"B`@("`@("`@("`@(&9O
M<F5A8V@@*&%R<F%Y*"=086-K86=E)RP@)T5X=&5N<VEO;B<I(&%S("1T>7!E
M*2![#0H@("`@("`@("`@("`@("`@)&EN9&5X(#T@<W1R=&]L;W=E<B@D='EP
M92D[#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!S6R=O<'1I;VYA
M;"==6R1I;F1E>%TI*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D9&5P<ULG;W!T:6]N86PG75LD:6YD97A=6R=N86UE)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D9&5P<ULG;W!T:6]N86PG75LD:6YD97A=
M(#T@87)R87DH)&1E<'-;)V]P=&EO;F%L)UU;)&EN9&5X72D[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)&1E<'-;)V]P=&EO;F%L)UU;)&EN9&5X72!A<R`D<&%C:V%G92D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P86-K86=E6R=C;VYF
M;&EC=',G72D@)B8@)'!A8VMA9V5;)V-O;F9L:6-T<R==(#T]("=Y97,G*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F]I;F1E>"`]("=.
M;W0@0V]M<&%T:6)L92!W:71H)SL-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1I;F9O6R=.;W0@0V]M<&%T:6)L92!W:71H)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R=.
M;W0@0V]M<&%T:6)L92!W:71H)UT@/2`G)SL-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D:6YF;ULG3F]T($-O;7!A=&EB;&4@=VET:"==("X](")<;B([
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D:6YF;VEN9&5X(#T@)T]P=&EO;F%L($1E<&5N9&5N8VEE<R<[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D:6YF;ULG
M3W!T:6]N86P@1&5P96YD96YC:65S)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1I;F9O6R=/<'1I;VYA;"!$97!E;F1E;F-I97,G
M72`]("<G.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R=/<'1I
M;VYA;"!$97!E;F1E;F-I97,G72`N/2`B7&XB.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@D:6YD97@@/3T@)V5X=&5N<VEO
M;B<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F%M92`]("1P
M86-K86=E6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M<&%C:V%G95LG8VAA;FYE;"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D;F%M92`]("1P86-K86=E6R=C:&%N;F5L)UT@+B`G+R<@
M+B`D<&%C:V%G95LG;F%M92==.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1N86UE(#T@)U]?=7)I+R<@+B`D<&%C:V%G95LG;F%M92==("X@)R`H<W1A
M=&EC(%5222DG.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1I;F9O6R1I;F9O:6YD97A=("X]("(D='EP92`D;F%M92([#0H@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A8VMA9V5;)W5R:2==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R1I;F9O
M:6YD97A=("X](")<;B`@1&]W;FQO860@55)).B`D<&%C:V%G95MU<FE=(CL-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@D:6YF;VEN9&5X(#T]("=.;W0@0V]M<&%T:6)L92!W:71H)RD@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(&-O;F9L:6-T<R!I<R!O
M;FQY('5S960@=&\@<V%Y('1H870@86QL('9E<G-I;VYS(&-O;F9L:6-T#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)'!A8VMA9V5;)VUA>"==*2`F)B!I<W-E="@D<&%C:V%G95LG
M;6EN)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F];
M)&EN9F]I;F1E>%T@+CT@(B!<;B`@5F5R<VEO;G,@(B`N#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E6R=M:6XG72`N("<M)R`N
M("1P86-K86=E6R=M87@G73L-"B`@("`@("`@("`@("`@("`@("`@("`@('T@
M96QS96EF("AI<W-E="@D<&%C:V%G95LG;6EN)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&EN9F];)&EN9F]I;F1E>%T@+CT@(B!<;B`@
M5F5R<VEO;B`B("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!A8VMA9V5;)VUI;B==("X@)R!O<B!N97=E<B<[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!](&5L<V5I9B`H:7-S970H)'!A8VMA9V5;)VUA>"==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R1I;F9O:6YD
M97A=("X]("(@7&X@(%9E<G-I;VX@(B`N#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1P86-K86=E6R=M:6XG72`N("<@;W(@;VQD97(G.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1P86-K86=E6R=R96-O;6UE;F1E9"==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R1I;F9O:6YD97A=
M("X](")<;B`@4F5C;VUM96YD960@=F5R<VEO;CH@)'!A8VMA9V5;<F5C;VUM
M96YD961=(CL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<&%C:V%G95LG97AC;'5D92==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H
M)&EN9F];)TYO="!#;VUP871I8FQE('=I=&@G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&EN9F];)TYO="!#;VUP871I8FQE('=I
M=&@G72`]("<G.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R=.
M;W0@0V]M<&%T:6)L92!W:71H)UT@+CT@(EQN(CL-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*&ES7V%R<F%Y*"1P86-K86=E6R=E>&-L=61E)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E6R=E>&-L=61E)UT@
M/2!I;7!L;V1E*"<L("<L("1P86-K86=E6R=E>&-L=61E)UTI.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D:6YF;ULG3F]T($-O;7!A=&EB;&4@=VET:"==("X](")086-K
M86=E("1P86-K86=E7&X@(%9E<G-I;VYS("(@+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<&%C:V%G95LG97AC;'5D92==.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@(&EF("AI<W-E="@D9&5P<ULG9W)O=7`G72DI('L-"B`@("`@("`@
M("`@(&EF("@A:7-S970H)&1E<'-;)V=R;W5P)UU;,%TI*2![#0H@("`@("`@
M("`@("`@("`@)&1E<'-;)V=R;W5P)UT@/2!A<G)A>2@D9&5P<ULG9W)O=7`G
M72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F;W)E86-H("@D9&5P
M<ULG9W)O=7`G72!A<R`D9W)O=7`I('L-"B`@("`@("`@("`@("`@("`D:6YF
M;ULG1&5P96YD96YC>2!'<F]U<"`G("X@)&=R;W5P6R=A='1R:6)S)UU;)VYA
M;64G75T@/2`D9W)O=7!;)V%T=')I8G,G75LG:&EN="==.PT*("`@("`@("`@
M("`@("`@("1G<F]U<&EN9&5X(#T@)&=R;W5P6R=A='1R:6)S)UU;)VYA;64G
M72`N("<@0V]N=&5N=',G.PT*("`@("`@("`@("`@("`@("1I;F9O6R1G<F]U
M<&EN9&5X72`]("<G.PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*&%R<F%Y
M*"=086-K86=E)RP@)T5X=&5N<VEO;B<I(&%S("1T>7!E*2![#0H@("`@("`@
M("`@("`@("`@("`@("1I;F1E>"`]('-T<G1O;&]W97(H)'1Y<&4I.PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&=R;W5P6R1I;F1E>%TI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&=R;W5P6R1I
M;F1E>%U;)VYA;64G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9W)O=7!;)&EN9&5X72`](&%R<F%Y*"1G<F]U<%LD:6YD97A=*3L-"B`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1G<F]U<%LD:6YD97A=(&%S("1P86-K86=E*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D:6YF;ULD
M9W)O=7!I;F1E>%TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1I;F9O6R1G<F]U<&EN9&5X72`N/2`B7&XB.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H)&EN9&5X(#T]("=E>'1E;G-I;VXG*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1N86UE(#T@)'!A8VMA9V5;)VYA;64G73L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A8VMA9V5;
M)V-H86YN96PG72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1N86UE(#T@)'!A8VMA9V5;)V-H86YN96PG72`N("<O)R`N("1P
M86-K86=E6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D;F%M92`]("=?7W5R:2\G("X@)'!A8VMA9V5;)VYA;64G72`N("<@
M*'-T871I8R!54DDI)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A8VMA9V5;)W5R:2==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)'!A8VMA9V5;)V-O;F9L:6-T<R==*2`F)B`D<&%C:V%G95LG8V]N9FQI
M8W1S)UT@/3T@)WEE<R<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1I;F9O6R1G<F]U<&EN9&5X72`N/2`B3F]T($-O;7!A=&EB
M;&4@=VET:"`D='EP92`D;F%M92([#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D:6YF;ULD9W)O=7!I;F1E>%T@+CT@(B1T>7!E("1N86UE
M(CL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D:6YF;ULD9W)O=7!I;F1E>%T@
M+CT@(EQN("!$;W=N;&]A9"!54DDZ("1P86-K86=E6W5R:5TB.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1P86-K86=E6R=C;VYF;&EC=',G72D@)B8@)'!A
M8VMA9V5;)V-O;F9L:6-T<R==(#T]("=Y97,G*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1I;F9O6R1G<F]U<&EN9&5X72`N/2`B3F]T
M($-O;7!A=&EB;&4@=VET:"`D='EP92`D;F%M92([#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M:6YF;ULD9W)O=7!I;F1E>%T@+CT@(B1T>7!E("1N86UE(CL-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A8VMA9V5;)VUA>"==
M*2`F)B!I<W-E="@D<&%C:V%G95LG;6EN)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1I;F9O6R1G<F]U<&EN9&5X72`N/2`B(%QN
M("!697)S:6]N<R`B("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1P86-K86=E6R=M:6XG72`N("<M)R`N("1P86-K86=E6R=M87@G
M73L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H:7-S
M970H)'!A8VMA9V5;)VUI;B==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D:6YF;ULD9W)O=7!I;F1E>%T@+CT@(B!<;B`@5F5R<VEO
M;B`B("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P
M86-K86=E6R=M:6XG72`N("<@;W(@;F5W97(G.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D<&%C:V%G95LG;6%X)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R1G
M<F]U<&EN9&5X72`N/2`B(%QN("!697)S:6]N("(@+@T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'!A8VMA9V5;)VUI;B==("X@)R!O
M<B!O;&1E<B<[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<&%C:V%G95LG
M<F5C;VUM96YD960G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&EN9F];)&=R;W5P:6YD97A=("X](")<;B`@4F5C;VUM96YD960@
M=F5R<VEO;CH@)'!A8VMA9V5;<F5C;VUM96YD961=(CL-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1P86-K86=E6R=E>&-L=61E)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&EN9F];)TYO
M="!#;VUP871I8FQE('=I=&@G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1I;F9O6R=.;W0@0V]M<&%T:6)L92!W:71H)UT@
M/2`G)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O
M6R1G<F]U<&EN9&5X72`N/2`B3F]T($-O;7!A=&EB;&4@=VET:%QN(CL-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)'!A8VMA9V5;)V5X
M8VQU9&4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1P86-K86=E6R=E>&-L=61E)UT@/2!I;7!L;V1E*"<L("<L("1P86-K
M86=E6R=E>&-L=61E)UTI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O
M6R1G<F]U<&EN9&5X72`N/2`B("!086-K86=E("1P86-K86=E7&X@(%9E<G-I
M;VYS("(@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!A8VMA9V5;)V5X8VQU9&4G73L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"1O8FHM/F=E=%!A8VMA9V54>7!E
M*"D@/3T@)V)U;F1L92<I('L-"B`@("`@("`@("`@("1I;F9O6R="=6YD;&5D
M(%!A8VMA9V5S)UT@/2`G)SL-"B`@("`@("`@("`@(&9O<F5A8V@@*"1O8FHM
M/F=E=$)U;F1L961086-K86=E<R@I(&%S("1P86-K86=E*2![#0H@("`@("`@
M("`@("`@("`@:68@*"%E;7!T>2@D:6YF;ULG0G5N9&QE9"!086-K86=E<R==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`D:6YF;ULG0G5N9&QE9"!086-K
M86=E<R==("X](")<;B([#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D<&%C:V%G95LG=7)I)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("1I;F9O6R="=6YD;&5D(%!A8VMA9V5S)UT@+CT@)U]?
M=7)I+R<@+B`D<&%C:V%G95LG;F%M92==.PT*("`@("`@("`@("`@("`@("`@
M("`D:6YF;ULG0G5N9&QE9"!086-K86=E<R==("X](")<;B`@*%5223H@)'!A
M8VMA9V5;=7)I72([#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`@("`@)&EN9F];)T)U;F1L960@4&%C:V%G97,G72`N/2`D
M<&%C:V%G95LG8VAA;FYE;"==("X@)R\G("X@)'!A8VMA9V5;)VYA;64G73L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("`@("`@)&EN9F];)W!A8VMA9V4N>&UL('9E<G-I;VXG72`]("<R+C`G
M.PT*("`@("`@("!I9B`H)&EN<W1A;&QE9"D@>PT*("`@("`@("`@("`@:68@
M*"1O8FHM/F=E=$QA<W1-;V1I9FEE9"@I*2![#0H@("`@("`@("`@("`@("`@
M)&EN9F];)TQA<W0@36]D:69I960G72`](&1A=&4H)UDM;2UD($@Z:2<L("1O
M8FHM/F=E=$QA<W1-;V1I9FEE9"@I*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("1V(#T@)&]B:BT^9V5T3&%S=$EN<W1A;&QE9%9E<G-I;VXH*3L-
M"B`@("`@("`@("`@("1I;F9O6R=,87-T($EN<W1A;&QE9"!697)S:6]N)UT@
M/2`D=B`_("1V(#H@)RT@3F]N92`M)SL-"B`@("`@("`@?0T*("`@("`@("!F
M;W)E86-H("@D:6YF;R!A<R`D:V5Y(#T^("1V86QU92D@>PT*("`@("`@("`@
M("`@)&1A=&%;)V1A=&$G75M=(#T@87)R87DH)&ME>2P@)'9A;'5E*3L-"B`@
M("`@("`@?0T*("`@("`@("`D9&%T85LG<F%W)UT@/2`D;V)J+3YG971!<G)A
M>2@I.R`O+R!N;R!V86QI9&%T:6]N(&YE961E9`T*#0H@("`@("`@("1T:&ES
M+3YU:2T^;W5T<'5T1&%T82@D9&%T82P@)W!A8VMA9V4M:6YF;R<I.PT*("`@
M('T-"GT-"@T*/SX-"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]296UO
M=&4N>&UL````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#4U,C`@
M,3`U,34T,S,W,S$@,#(R-34P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#QC;VUM86YD<R!V97)S:6]N/2(Q+C`B/@T*(#QR
M96UO=&4M:6YF;SX-"B`@/'-U;6UA<GD^26YF;W)M871I;VX@06)O=70@4F5M
M;W1E(%!A8VMA9V5S/"]S=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]296UO=&5)
M;F9O/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T/G)I/"]S:&]R=&-U=#X-"B`@
M/&]P=&EO;G,@+SX-"B`@/&1O8SXF;'0[<&%C:V%G929G=#L-"D=E="!D971A
M:6QS(&]N(&$@<&%C:V%G92!F<F]M('1H92!S97)V97(N/"]D;V,^#0H@/"]R
M96UO=&4M:6YF;SX-"B`\;&ES="UU<&=R861E<SX-"B`@/'-U;6UA<GD^3&ES
M="!!=F%I;&%B;&4@57!G<F%D97,\+W-U;6UA<GD^#0H@(#QF=6YC=&EO;CYD
M;TQI<W15<&=R861E<SPO9G5N8W1I;VX^#0H@(#QS:&]R=&-U=#YL=3PO<VAO
M<G1C=70^#0H@(#QO<'1I;VYS("\^#0H@(#QD;V,^6W!R969E<G)E9%]S=&%T
M95T-"DQI<W0@<F5L96%S97,@;VX@=&AE('-E<G9E<B!O9B!P86-K86=E<R!Y
M;W4@:&%V92!I;G-T86QL960@=VAE<F4-"F$@;F5W97(@=F5R<VEO;B!I<R!A
M=F%I;&%B;&4@=VET:"!T:&4@<V%M92!R96QE87-E('-T871E("AS=&%B;&4@
M971C+BD-"F]R('1H92!S=&%T92!P87-S960@87,@=&AE('-E8V]N9"!P87)A
M;65T97(N/"]D;V,^#0H@/"]L:7-T+75P9W)A9&5S/@T*(#QR96UO=&4M;&ES
M=#X-"B`@/'-U;6UA<GD^3&ES="!296UO=&4@4&%C:V%G97,\+W-U;6UA<GD^
M#0H@(#QF=6YC=&EO;CYD;U)E;6]T94QI<W0\+V9U;F-T:6]N/@T*("`\<VAO
M<G1C=70^<FP\+W-H;W)T8W5T/@T*("`\;W!T:6]N<SX-"B`@(#QC:&%N;F5L
M/@T*("`@(#QS:&]R=&]P=#YC/"]S:&]R=&]P=#X-"B`@("`\9&]C/G-P96-I
M9GD@82!C:&%N;F5L(&]T:&5R('1H86X@=&AE(&1E9F%U;'0@8VAA;FYE;#PO
M9&]C/@T*("`@(#QA<F<^0TA!3CPO87)G/@T*("`@/"]C:&%N;F5L/@T*("`\
M+V]P=&EO;G,^#0H@(#QD;V,^#0I,:7-T<R!T:&4@<&%C:V%G97,@879A:6QA
M8FQE(&]N('1H92!C;VYF:6=U<F5D('-E<G9E<B!A;&]N9R!W:71H('1H90T*
M;&%T97-T('-T86)L92!R96QE87-E(&]F(&5A8V@@<&%C:V%G92X\+V1O8SX-
M"B`\+W)E;6]T92UL:7-T/@T*(#QS96%R8V@^#0H@(#QS=6UM87)Y/E-E87)C
M:"!R96UO=&4@<&%C:V%G92!D871A8F%S93PO<W5M;6%R>3X-"B`@/&9U;F-T
M:6]N/F1O4V5A<F-H/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T/G-P/"]S:&]R
M=&-U=#X-"B`@/&]P=&EO;G,^#0H@("`\8VAA;FYE;#X-"B`@("`\<VAO<G1O
M<'0^8SPO<VAO<G1O<'0^#0H@("`@/&1O8SYS<&5C:69Y(&$@8VAA;FYE;"!O
M=&AE<B!T:&%N('1H92!D969A=6QT(&-H86YN96P\+V1O8SX-"B`@("`\87)G
M/D-(04X\+V%R9SX-"B`@(#PO8VAA;FYE;#X-"B`@/"]O<'1I;VYS/@T*("`\
M9&]C/EMP86-K86=E;F%M95T@6W!A8VMA9V5I;F9O70T*3&ES=',@86QL('!A
M8VMA9V5S('=H:6-H(&UA=&-H('1H92!S96%R8V@@<&%R86UE=&5R<RX@(%1H
M92!F:7)S=`T*<&%R86UE=&5R(&ES(&$@9G)A9VUE;G0@;V8@82!P86-K86=E
M;F%M92X@(%1H92!D969A=6QT(&-H86YN96P-"G=I;&P@8F4@=7-E9"!U;FQE
M<W,@97AP;&EC:71L>2!O=F5R<FED9&5N+B`@5&AE('-E8V]N9"!P87)A;65T
M97(-"G=I;&P@8F4@=7-E9"!T;R!M871C:"!A;GD@<&]R=&EO;B!O9B!T:&4@
M<W5M;6%R>2]D97-C<FEP=&EO;CPO9&]C/@T*(#PO<V5A<F-H/@T*(#QL:7-T
M+6%L;#X-"B`@/'-U;6UA<GD^3&ES="!!;&P@4&%C:V%G97,\+W-U;6UA<GD^
M#0H@(#QF=6YC=&EO;CYD;TQI<W1!;&P\+V9U;F-T:6]N/@T*("`\<VAO<G1C
M=70^;&$\+W-H;W)T8W5T/@T*("`\;W!T:6]N<SX-"B`@(#QC:&%N;F5L/@T*
M("`@(#QS:&]R=&]P=#YC/"]S:&]R=&]P=#X-"B`@("`\9&]C/G-P96-I9GD@
M82!C:&%N;F5L(&]T:&5R('1H86X@=&AE(&1E9F%U;'0@8VAA;FYE;#PO9&]C
M/@T*("`@(#QA<F<^0TA!3CPO87)G/@T*("`@/"]C:&%N;F5L/@T*("`\+V]P
M=&EO;G,^#0H@(#QD;V,^#0I,:7-T<R!T:&4@<&%C:V%G97,@879A:6QA8FQE
M(&]N('1H92!C;VYF:6=U<F5D('-E<G9E<B!A;&]N9R!W:71H('1H90T*;&%T
M97-T('-T86)L92!R96QE87-E(&]F(&5A8V@@<&%C:V%G92X\+V1O8SX-"B`\
M+VQI<W0M86QL/@T*(#QD;W=N;&]A9#X-"B`@/'-U;6UA<GD^1&]W;FQO860@
M4&%C:V%G93PO<W5M;6%R>3X-"B`@/&9U;F-T:6]N/F1O1&]W;FQO860\+V9U
M;F-T:6]N/@T*("`\<VAO<G1C=70^9#PO<VAO<G1C=70^#0H@(#QO<'1I;VYS
M/@T*("`@/&YO8V]M<')E<W,^#0H@("`@/'-H;W)T;W!T/EH\+W-H;W)T;W!T
M/@T*("`@(#QD;V,^9&]W;FQO860@86X@=6YC;VUP<F5S<V5D("@N=&%R*2!F
M:6QE/"]D;V,^#0H@("`\+VYO8V]M<')E<W,^#0H@(#PO;W!T:6]N<SX-"B`@
M/&1O8SXF;'0[<&%C:V%G929G=#LN+BX-"D1O=VYL;V%D('!A8VMA9V4@=&%R
M8F%L;',N("!4:&4@9FEL97,@=VEL;"!B92!N86UE9"!A<R!S=6=G97-T960@
M8GD@=&AE#0IS97)V97(L(&9O<B!E>&%M<&QE(&EF('EO=2!D;W=N;&]A9"!T
M:&4@1$(@<&%C:V%G92!A;F0@=&AE(&QA=&5S="!S=&%B;&4-"G9E<G-I;VX@
M;V8@1$(@:7,@,2XV+C4L('1H92!D;W=N;&]A9&5D(&9I;&4@=VEL;"!B92!$
M0BTQ+C8N-2YT9WHN/"]D;V,^#0H@/"]D;W=N;&]A9#X-"B`\8VQE87(M8V%C
M:&4^#0H@(#QS=6UM87)Y/D-L96%R(%=E8B!397)V:6-E<R!#86-H93PO<W5M
M;6%R>3X-"B`@/&9U;F-T:6]N/F1O0VQE87)#86-H93PO9G5N8W1I;VX^#0H@
M(#QS:&]R=&-U=#YC8SPO<VAO<G1C=70^#0H@(#QO<'1I;VYS("\^#0H@(#QD
M;V,^#0I#;&5A<B!T:&4@6$U,+5)00R]215-4(&-A8VAE+B`@4V5E(&%L<V\@
M=&AE(&-A8VAE7W1T;"!C;VYF:6=U<F%T:6]N#0IP87)A;65T97(N#0H\+V1O
M8SX-"B`\+V-L96%R+6-A8VAE/@T*/"]C;VUM86YD<SX`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+U)E;6]T92YP:'``````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`V,S<R,R`Q,#4Q-30S,S<S,2`P,C(U
M-3``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`-"B\J*@T*("H@4$5!4E]#;VUM86YD7U)E;6]T92`H<F5M;W1E+6EN
M9F\L(&QI<W0M=7!G<F%D97,L(')E;6]T92UL:7-T+"!S96%R8V@L(&QI<W0M
M86QL+"!D;W=N;&]A9"P-"B`J(&-L96%R+6-A8VAE(&-O;6UA;F1S*0T*("H-
M"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H
M92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I
M9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A
M;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P
M;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W
M92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C
M871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H
M;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X-"B`J($!A=71H;W(@
M("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG
M:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS
M92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!296UO=&4N<&AP+'8@
M,2XY,"XR+C(@,C`P-B\P,R\R,R`P-3HT-3HQ-R!C96QL;V<@17AP("0-"B`J
M($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2
M#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E
M(#`N,0T*("HO#0H-"B\J*@T*("H@8F%S92!C;&%S<PT*("HO#0IR97%U:7)E
M7V]N8V4@)U!%05(O0V]M;6%N9"]#;VUM;VXN<&AP)SL-"G)E<75I<F5?;VYC
M92`G4$5!4B]215-4+G!H<"<[#0H-"B\J*@T*("H@4$5!4B!C;VUM86YD<R!F
M;W(@<F5M;W1E('-E<G9E<B!Q=65R>6EN9PT*("H-"B`J($!C871E9V]R>2`@
M('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@(%-T
M:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@($=R96<@
M0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M
M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J
M($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H
M='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@
M("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,"XQ#0H@*B\-"F-L
M87-S(%!%05)?0V]M;6%N9%]296UO=&4@97AT96YD<R!014%27T-O;6UA;F1?
M0V]M;6]N#0I[#0H@("`@+R\@>WM[(&-O;6UA;F0@9&5F:6YI=&EO;G,-"@T*
M("`@('9A<B`D8V]M;6%N9',@/2!A<G)A>2@-"B`@("`@("`@)W)E;6]T92UI
M;F9O)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G26YF
M;W)M871I;VX@06)O=70@4F5M;W1E(%!A8VMA9V5S)RP-"B`@("`@("`@("`@
M("=F=6YC=&EO;B<@/3X@)V1O4F5M;W1E26YF;R<L#0H@("`@("`@("`@("`G
M<VAO<G1C=70G(#T^("=R:2<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@
M87)R87DH*2P-"B`@("`@("`@("`@("=D;V,G(#T^("<\<&%C:V%G93X-"D=E
M="!D971A:6QS(&]N(&$@<&%C:V%G92!F<F]M('1H92!S97)V97(N)RP-"B`@
M("`@("`@("`@("DL#0H@("`@("`@("=L:7-T+75P9W)A9&5S)R`]/B!A<G)A
M>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G3&ES="!!=F%I;&%B;&4@
M57!G<F%D97,G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&],:7-T
M57!G<F%D97,G+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G;'4G+`T*
M("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*"DL#0H@("`@("`@("`@
M("`G9&]C)R`]/B`G6W!R969E<G)E9%]S=&%T95T-"DQI<W0@<F5L96%S97,@
M;VX@=&AE('-E<G9E<B!O9B!P86-K86=E<R!Y;W4@:&%V92!I;G-T86QL960@
M=VAE<F4-"F$@;F5W97(@=F5R<VEO;B!I<R!A=F%I;&%B;&4@=VET:"!T:&4@
M<V%M92!R96QE87-E('-T871E("AS=&%B;&4@971C+BD-"F]R('1H92!S=&%T
M92!P87-S960@87,@=&AE('-E8V]N9"!P87)A;65T97(N)PT*("`@("`@("`@
M("`@*2P-"B`@("`@("`@)W)E;6]T92UL:7-T)R`]/B!A<G)A>2@-"B`@("`@
M("`@("`@("=S=6UM87)Y)R`]/B`G3&ES="!296UO=&4@4&%C:V%G97,G+`T*
M("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]296UO=&5,:7-T)RP-"B`@
M("`@("`@("`@("=S:&]R=&-U="<@/3X@)W)L)RP-"B`@("`@("`@("`@("=O
M<'1I;VYS)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`G8VAA;FYE;"<@
M/3X-"B`@("`@("`@("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@("`@
M("`@("`@("=S:&]R=&]P="<@/3X@)V,G+`T*("`@("`@("`@("`@("`@("`@
M("`G9&]C)R`]/B`G<W!E8VEF>2!A(&-H86YN96P@;W1H97(@=&AA;B!T:&4@
M9&5F875L="!C:&%N;F5L)RP-"B`@("`@("`@("`@("`@("`@("`@)V%R9R<@
M/3X@)T-(04XG+`T*("`@("`@("`@("`@("`@("`@("`I#0H@("`@("`@("`@
M("`@("`@*2P-"B`@("`@("`@("`@("=D;V,G(#T^("<-"DQI<W1S('1H92!P
M86-K86=E<R!A=F%I;&%B;&4@;VX@=&AE(&-O;F9I9W5R960@<V5R=F5R(&%L
M;VYG('=I=&@@=&AE#0IL871E<W0@<W1A8FQE(')E;&5A<V4@;V8@96%C:"!P
M86-K86=E+B<L#0H@("`@("`@("`@("`I+`T*("`@("`@("`G<V5A<F-H)R`]
M/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G4V5A<F-H(')E
M;6]T92!P86-K86=E(&1A=&%B87-E)RP-"B`@("`@("`@("`@("=F=6YC=&EO
M;B<@/3X@)V1O4V5A<F-H)RP-"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@
M)W-P)RP-"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@-"B`@("`@
M("`@("`@("`@("`G8VAA;FYE;"<@/3X-"B`@("`@("`@("`@("`@("`@("`@
M87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)V,G
M+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G<W!E8VEF>2!A(&-H
M86YN96P@;W1H97(@=&AA;B!T:&4@9&5F875L="!C:&%N;F5L)RP-"B`@("`@
M("`@("`@("`@("`@("`@)V%R9R<@/3X@)T-(04XG+`T*("`@("`@("`@("`@
M("`@("`@("`I#0H@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("=D
M;V,G(#T^("=;<&%C:V%G96YA;65=(%MP86-K86=E:6YF;UT-"DQI<W1S(&%L
M;"!P86-K86=E<R!W:&EC:"!M871C:"!T:&4@<V5A<F-H('!A<F%M971E<G,N
M("!4:&4@9FER<W0-"G!A<F%M971E<B!I<R!A(&9R86=M96YT(&]F(&$@<&%C
M:V%G96YA;64N("!4:&4@9&5F875L="!C:&%N;F5L#0IW:6QL(&)E('5S960@
M=6YL97-S(&5X<&QI8VET;'D@;W9E<G)I9&1E;BX@(%1H92!S96-O;F0@<&%R
M86UE=&5R#0IW:6QL(&)E('5S960@=&\@;6%T8V@@86YY('!O<G1I;VX@;V8@
M=&AE('-U;6UA<GDO9&5S8W)I<'1I;VXG+`T*("`@("`@("`@("`@*2P-"B`@
M("`@("`@)VQI<W0M86QL)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM
M87)Y)R`]/B`G3&ES="!!;&P@4&%C:V%G97,G+`T*("`@("`@("`@("`@)V9U
M;F-T:6]N)R`]/B`G9&],:7-T06QL)RP-"B`@("`@("`@("`@("=S:&]R=&-U
M="<@/3X@)VQA)RP-"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@-
M"B`@("`@("`@("`@("`@("`G8VAA;FYE;"<@/3X-"B`@("`@("`@("`@("`@
M("`@("`@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@
M/3X@)V,G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G<W!E8VEF
M>2!A(&-H86YN96P@;W1H97(@=&AA;B!T:&4@9&5F875L="!C:&%N;F5L)RP-
M"B`@("`@("`@("`@("`@("`@("`@)V%R9R<@/3X@)T-(04XG+`T*("`@("`@
M("`@("`@("`@("`@("`I#0H@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@
M("`@("=D;V,G(#T^("<-"DQI<W1S('1H92!P86-K86=E<R!A=F%I;&%B;&4@
M;VX@=&AE(&-O;F9I9W5R960@<V5R=F5R(&%L;VYG('=I=&@@=&AE#0IL871E
M<W0@<W1A8FQE(')E;&5A<V4@;V8@96%C:"!P86-K86=E+B<L#0H@("`@("`@
M("`@("`I+`T*("`@("`@("`G9&]W;FQO860G(#T^(&%R<F%Y*`T*("`@("`@
M("`@("`@)W-U;6UA<GDG(#T^("=$;W=N;&]A9"!086-K86=E)RP-"B`@("`@
M("`@("`@("=F=6YC=&EO;B<@/3X@)V1O1&]W;FQO860G+`T*("`@("`@("`@
M("`@)W-H;W)T8W5T)R`]/B`G9"<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@
M/3X@87)R87DH#0H@("`@("`@("`@("`@("`@)VYO8V]M<')E<W,G(#T^(&%R
M<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=:)RP-
M"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)V1O=VYL;V%D(&%N('5N
M8V]M<')E<W-E9"`H+G1A<BD@9FEL92<L#0H@("`@("`@("`@("`@("`@("`@
M("DL#0H@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("=D;V,G(#T^
M("<\<&%C:V%G93XN+BX-"D1O=VYL;V%D('!A8VMA9V4@=&%R8F%L;',N("!4
M:&4@9FEL97,@=VEL;"!B92!N86UE9"!A<R!S=6=G97-T960@8GD@=&AE#0IS
M97)V97(L(&9O<B!E>&%M<&QE(&EF('EO=2!D;W=N;&]A9"!T:&4@1$(@<&%C
M:V%G92!A;F0@=&AE(&QA=&5S="!S=&%B;&4-"G9E<G-I;VX@;V8@1$(@:7,@
M,2XV+C4L('1H92!D;W=N;&]A9&5D(&9I;&4@=VEL;"!B92!$0BTQ+C8N-2YT
M9WHN)RP-"B`@("`@("`@("`@("DL#0H@("`@("`@("=C;&5A<BUC86-H92<@
M/3X@87)R87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)T-L96%R(%=E
M8B!397)V:6-E<R!#86-H92<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^
M("=D;T-L96%R0V%C:&4G+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G
M8V,G+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*"DL#0H@("`@
M("`@("`@("`G9&]C)R`]/B`G#0I#;&5A<B!T:&4@6$U,+5)00R]215-4(&-A
M8VAE+B`@4V5E(&%L<V\@=&AE(&-A8VAE7W1T;"!C;VYF:6=U<F%T:6]N#0IP
M87)A;65T97(N#0HG+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@*3L-"@T*
M("`@("\O('U]?0T*("`@("\O('M[>R!C;VYS=')U8W1O<@T*#0H@("`@+RHJ
M#0H@("`@("H@4$5!4E]#;VUM86YD7U)E;6]T92!C;VYS=')U8W1O<BX-"B`@
M("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@4$5!4E]#;VUM86YD7U)E;6]T92@F)'5I+"`F)&-O;F9I9RD-"B`@
M("![#0H@("`@("`@('!A<F5N=#HZ4$5!4E]#;VUM86YD7T-O;6UO;B@D=6DL
M("1C;VYF:6<I.PT*("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@9G5N8W1I
M;VX@7V-H96-K0VAA;FYE;$9O<E-T871U<R@D8VAA;FYE;"P@)&-H86XI#0H@
M("`@>PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8VAA;BDI('L-"B`@
M("`@("`@("`@("1T:&ES+3YR86ES945R<F]R*"1C:&%N*3L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H(6ES7V$H)&-H86XL("=014%27T-H86YN96Q&:6QE
M)RDI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G
M26YT97)N86P@8V]R<G5P=&EO;B!E<G)O<CH@:6YV86QI9"!C:&%N;F5L("(G
M("X-"B`@("`@("`@("`@("`@("`D8VAA;FYE;"`N("<B)RD[#0H@("`@("`@
M('T-"B`@("`@("`@)')E<W0@/2!N97<@4$5!4E]215-4*"1T:&ES+3YC;VYF
M:6<I.PT*("`@("`@("!014%2.CIS=&%T:6-0=7-H17)R;W)(86YD;&EN9RA0
M14%27T524D]27U)%5%523BD[#0H@("`@("`@("1A(#T@)')E<W0M/F1O=VYL
M;V%D2'1T<"@G:'1T<#HO+R<@+B`D8VAA;FYE;"`N#0H@("`@("`@("`@("`G
M+V-H86YN96PN>&UL)RP@)&-H86XM/FQA<W1-;V1I9FEE9"@I*3L-"B`@("`@
M("`@4$5!4CHZ<W1A=&EC4&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("!I
M9B`H(5!%05(Z.FES17)R;W(H)&$I("8F("1A*2![#0H@("`@("`@("`@("`D
M=&AI<RT^=6DM/F]U='!U=$1A=&$H)U=!4DY)3D<Z(&-H86YN96P@(B<@+B`D
M8VAA;FYE;"`N("<B(&AA<R`G("X-"B`@("`@("`@("`@("`@("`G=7!D871E
M9"!I=',@<')O=&]C;VQS+"!U<V4@(F-H86YN96PM=7!D871E("<@+B`D8VAA
M;FYE;"`N#0H@("`@("`@("`@("`@("`@)R(@=&\@=7!D871E)RD[#0H@("`@
M("`@('T-"B`@("!]#0H-"B`@("`O+R![>WL@9&]296UO=&5);F9O*"D-"@T*
M("`@(&9U;F-T:6]N(&1O4F5M;W1E26YF;R@D8V]M;6%N9"P@)&]P=&EO;G,L
M("1P87)A;7,I#0H@("`@>PT*("`@("`@("!I9B`H<VEZ96]F*"1P87)A;7,I
M("$](#$I('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@B)&-O;6UA;F0@97AP96-T<R!O;F4@<&%R86TZ('1H92!R96UO=&4@<&%C
M:V%G92!N86UE(BD[#0H@("`@("`@('T-"B`@("`@("`@)'-A=F5C:&%N;F5L
M(#T@)&-H86YN96P@/2`D=&AI<RT^8V]N9FEG+3YG970H)V1E9F%U;'1?8VAA
M;FYE;"<I.PT*("`@("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E
M9VES=')Y*"D[#0H@("`@("`@("1P86-K86=E(#T@)'!A<F%M<ULP73L-"B`@
M("`@("`@)'!A<G-E9"`]("1R96<M/G!A<G-E4&%C:V%G94YA;64H)'!A8VMA
M9V4L("1C:&%N;F5L*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'!A
M<G-E9"DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@G26YV86QI9"!P86-K86=E(&YA;64@(B<@+B`D<&%C:V%G92`N("<B)RD[
M#0H@("`@("`@('T-"B`@("`@("`@#0H@("`@("`@("1C:&%N;F5L(#T@)'!A
M<G-E9%LG8VAA;FYE;"==.PT*("`@("`@("`D=&AI<RT^8V]N9FEG+3YS970H
M)V1E9F%U;'1?8VAA;FYE;"<L("1C:&%N;F5L*3L-"B`@("`@("`@)&-H86X@
M/2`D<F5G+3YG971#:&%N;F5L*"1C:&%N;F5L*3L-"B`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)&4@/2`D=&AI<RT^7V-H96-K0VAA;FYE;$9O<E-T871U
M<R@D8VAA;FYE;"P@)&-H86XI*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1E
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D8VAA;BT^<W5P<&]R='-215-4
M*"1T:&ES+3YC;VYF:6<M/F=E="@G<')E9F5R<F5D7VUI<G)O<B<I*2`F)@T*
M("`@("`@("`@("`@("`D8F%S92`]("1C:&%N+3YG971"87-E55),*"=215-4
M,2XP)RP@)'1H:7,M/F-O;F9I9RT^9V5T*"=P<F5F97)R961?;6ER<F]R)RDI
M*2![#0H@("`@("`@("`@("`D<F5S="`]("8D=&AI<RT^8V]N9FEG+3YG9712
M15-4*"<Q+C`G+"!A<G)A>2@I*3L-"B`@("`@("`@("`@("1I;F9O(#T@)')E
M<W0M/G!A8VMA9V5);F9O*"1B87-E+"`D<&%R<V5D6R=P86-K86=E)UTI.PT*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'(@/2`F)'1H:7,M/F-O
M;F9I9RT^9V5T4F5M;W1E*"D[#0H@("`@("`@("`@("`D:6YF;R`]("1R+3YC
M86QL*"=P86-K86=E+FEN9F\G+"`D<&%R<V5D6R=P86-K86=E)UTI.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1I;F9O*2D@>PT*
M("`@("`@("`@("`@)'1H:7,M/F-O;F9I9RT^<V5T*"=D969A=6QT7V-H86YN
M96PG+"`D<V%V96-H86YN96PI.PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*"1I;F9O*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M(6ES<V5T*"1I;F9O6R=N86UE)UTI*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H)TYO(')E;6]T92!P86-K86=E("(G("X@)'!A
M8VMA9V4@+B`G(B!W87,@9F]U;F0G*3L-"B`@("`@("`@?0T*#0H@("`@("`@
M("1I;G-T86QL960@/2`D<F5G+3YP86-K86=E26YF;R@D:6YF;ULG;F%M92==
M+"!N=6QL+"`D8VAA;FYE;"D[#0H@("`@("`@("1I;F9O6R=I;G-T86QL960G
M72`]("1I;G-T86QL961;)W9E<G-I;VXG72`_("1I;G-T86QL961;)W9E<G-I
M;VXG72`Z("<M(&YO("TG.PT*("`@("`@("!I9B`H:7-?87)R87DH)&EN9F];
M)VEN<W1A;&QE9"==*2D@>PT*("`@("`@("`@("`@)&EN9F];)VEN<W1A;&QE
M9"==(#T@)&EN9F];)VEN<W1A;&QE9"==6R=R96QE87-E)UT[#0H@("`@("`@
M('T-"@T*("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)&EN9F\L("1C
M;VUM86YD*3L-"B`@("`@("`@)'1H:7,M/F-O;F9I9RT^<V5T*"=D969A=6QT
M7V-H86YN96PG+"`D<V%V96-H86YN96PI.PT*#0H@("`@("`@(')E='5R;B!T
M<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!D;U)E;6]T
M94QI<W0H*0T*#0H@("`@9G5N8W1I;VX@9&]296UO=&5,:7-T*"1C;VUM86YD
M+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@("1S879E8VAA
M;FYE;"`]("1C:&%N;F5L(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=D969A=6QT
M7V-H86YN96PG*3L-"B`@("`@("`@)')E9R`]("8D=&AI<RT^8V]N9FEG+3YG
M971296=I<W1R>2@I.PT*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)V-H
M86YN96PG72DI('L-"B`@("`@("`@("`@("1C:&%N;F5L(#T@)&]P=&EO;G-;
M)V-H86YN96PG73L-"B`@("`@("`@("`@(&EF("@D<F5G+3YC:&%N;F5L17AI
M<W1S*"1C:&%N;F5L*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3YC;VYF
M:6<M/G-E="@G9&5F875L=%]C:&%N;F5L)RP@)&-H86YN96PI.PT*("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H)T-H86YN96P@(B<@+B`D8VAA;FYE;"`N("<B(&1O97,@
M;F]T(&5X:7-T)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@)&-H86X@/2`D<F5G+3YG971#:&%N;F5L*"1C:&%N;F5L*3L-"B`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)&4@/2`D=&AI<RT^7V-H96-K0VAA;FYE
M;$9O<E-T871U<R@D8VAA;FYE;"P@)&-H86XI*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N("1E.PT*("`@("`@("!]#0H@("`@("`@("1L:7-T7V]P=&EO;G,@
M/2!F86QS93L-"B`@("`@("`@:68@*"1T:&ES+3YC;VYF:6<M/F=E="@G<')E
M9F5R<F5D7W-T871E)RD@/3T@)W-T86)L92<I('L-"B`@("`@("`@("`@("1L
M:7-T7V]P=&EO;G,@/2!T<G5E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D
M8VAA;BT^<W5P<&]R='-215-4*"1T:&ES+3YC;VYF:6<M/F=E="@G<')E9F5R
M<F5D7VUI<G)O<B<I*2`F)@T*("`@("`@("`@("`@("`D8F%S92`]("1C:&%N
M+3YG971"87-E55),*"=215-4,2XQ)RP@)'1H:7,M/F-O;F9I9RT^9V5T*"=P
M<F5F97)R961?;6ER<F]R)RDI*2![#0H@("`@("`@("`@("`O+R!U<V4@9F%S
M=&5R(&QI<W0M86QL(&EF(&%V86EL86)L90T*("`@("`@("`@("`@)')E<W0@
M/2`F)'1H:7,M/F-O;F9I9RT^9V5T4D535"@G,2XQ)RP@87)R87DH*2D[#0H@
M("`@("`@("`@("`D879A:6QA8FQE(#T@)')E<W0M/FQI<W1!;&PH)&)A<V4L
M("1L:7-T7V]P=&EO;G,I.PT*("`@("`@("!](&5L<V5I9B`H)&-H86XM/G-U
M<'!O<G1S4D535"@D=&AI<RT^8V]N9FEG+3YG970H)W!R969E<G)E9%]M:7)R
M;W(G*2D@)B8-"B`@("`@("`@("`@("`@)&)A<V4@/2`D8VAA;BT^9V5T0F%S
M95523"@G4D535#$N,"<L("1T:&ES+3YC;VYF:6<M/F=E="@G<')E9F5R<F5D
M7VUI<G)O<B<I*2D@>PT*("`@("`@("`@("`@)')E<W0@/2`F)'1H:7,M/F-O
M;F9I9RT^9V5T4D535"@G,2XP)RP@87)R87DH*2D[#0H@("`@("`@("`@("`D
M879A:6QA8FQE(#T@)')E<W0M/FQI<W1!;&PH)&)A<V4L("1L:7-T7V]P=&EO
M;G,I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'(@/2`F)'1H
M:7,M/F-O;F9I9RT^9V5T4F5M;W1E*"D[#0H@("`@("`@("`@("!I9B`H)&-H
M86YN96P@/3T@)W!E87(N<&AP+FYE="<I('L-"B`@("`@("`@("`@("`@("`O
M+R!H86-K(&)E8V%U<V4@;V8@<&]O<B!P96%R=V5B(&1E<VEG;@T*("`@("`@
M("`@("`@("`@("1A=F%I;&%B;&4@/2`D<BT^8V%L;"@G<&%C:V%G92YL:7-T
M06QL)RP@=')U92P@)&QI<W1?;W!T:6]N<RP@9F%L<V4I.PT*("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D879A:6QA8FQE(#T@)'(M
M/F-A;&PH)W!A8VMA9V4N;&ES=$%L;"<L('1R=64L("1L:7-T7V]P=&EO;G,I
M.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1A=F%I;&%B;&4I*2![#0H@("`@("`@("`@("`D=&AI<RT^
M8V]N9FEG+3YS970H)V1E9F%U;'1?8VAA;FYE;"<L("1S879E8VAA;FYE;"D[
M#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&%V86EL
M86)L92D[#0H@("`@("`@('T-"B`@("`@("`@)&D@/2`D:B`](#`[#0H@("`@
M("`@("1D871A(#T@87)R87DH#0H@("`@("`@("`@("`G8V%P=&EO;B<@/3X@
M)T-H86YN96P@)R`N("1C:&%N;F5L("X@)R!!=F%I;&%B;&4@<&%C:V%G97,Z
M)RP-"B`@("`@("`@("`@("=B;W)D97(G(#T^('1R=64L#0H@("`@("`@("`@
M("`G:&5A9&QI;F4G(#T^(&%R<F%Y*"=086-K86=E)RP@)U9E<G-I;VXG*2P-
M"B`@("`@("`@("`@("D[#0H@("`@("`@(&EF("AC;W5N="@D879A:6QA8FQE
M*3T],"D@>PT*("`@("`@("`@("`@)&1A=&$@/2`G*&YO('!A8VMA9V5S(&%V
M86EL86)L92!Y970I)SL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M(&9O<F5A8V@@*"1A=F%I;&%B;&4@87,@)&YA;64@/3X@)&EN9F\I('L-"B`@
M("`@("`@("`@("`@("`D9&%T85LG9&%T82==6UT@/2!A<G)A>2@D;F%M92P@
M*&ES<V5T*"1I;F9O6R=S=&%B;&4G72D@)B8@)&EN9F];)W-T86)L92==*0T*
M("`@("`@("`@("`@("`@("`@("`_("1I;F9O6R=S=&%B;&4G72`Z("<M;B]A
M+2<I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1T:&ES
M+3YU:2T^;W5T<'5T1&%T82@D9&%T82P@)&-O;6UA;F0I.PT*("`@("`@("`D
M=&AI<RT^8V]N9FEG+3YS970H)V1E9F%U;'1?8VAA;FYE;"<L("1S879E8VAA
M;FYE;"D[#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O
M('U]?0T*("`@("\O('M[>R!D;TQI<W1!;&PH*0T*#0H@("`@9G5N8W1I;VX@
M9&],:7-T06QL*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![
M#0H@("`@("`@("1S879E8VAA;FYE;"`]("1C:&%N;F5L(#T@)'1H:7,M/F-O
M;F9I9RT^9V5T*"=D969A=6QT7V-H86YN96PG*3L-"B`@("`@("`@)')E9R`]
M("8D=&AI<RT^8V]N9FEG+3YG971296=I<W1R>2@I.PT*("`@("`@("!I9B`H
M:7-S970H)&]P=&EO;G-;)V-H86YN96PG72DI('L-"B`@("`@("`@("`@("1C
M:&%N;F5L(#T@)&]P=&EO;G-;)V-H86YN96PG73L-"B`@("`@("`@("`@(&EF
M("@D<F5G+3YC:&%N;F5L17AI<W1S*"1C:&%N;F5L*2D@>PT*("`@("`@("`@
M("`@("`@("1T:&ES+3YC;VYF:6<M/G-E="@G9&5F875L=%]C:&%N;F5L)RP@
M)&-H86YN96PI.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D-H86YN96P@7"(D8VAA
M;FYE;%PB(&1O97,@;F]T(&5X:7-T(BD[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@)&QI<W1?;W!T:6]N<R`](&9A;'-E.PT*("`@("`@
M("!I9B`H)'1H:7,M/F-O;F9I9RT^9V5T*"=P<F5F97)R961?<W1A=&4G*2`]
M/2`G<W1A8FQE)RD@>PT*("`@("`@("`@("`@)&QI<W1?;W!T:6]N<R`]('1R
M=64[#0H@("`@("`@('T-"B`@("`@("`@)&-H86X@/2`D<F5G+3YG971#:&%N
M;F5L*"1C:&%N;F5L*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&4@
M/2`D=&AI<RT^7V-H96-K0VAA;FYE;$9O<E-T871U<R@D8VAA;FYE;"P@)&-H
M86XI*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1E.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@D8VAA;BT^<W5P<&]R='-215-4*"1T:&ES+3YC;VYF:6<M
M/F=E="@G<')E9F5R<F5D7VUI<G)O<B<I*2`F)@T*("`@("`@("`@("`@("`D
M8F%S92`]("1C:&%N+3YG971"87-E55),*"=215-4,2XQ)RP@)'1H:7,M/F-O
M;F9I9RT^9V5T*"=P<F5F97)R961?;6ER<F]R)RDI*2![#0H@("`@("`@("`@
M("`O+R!U<V4@9F%S=&5R(&QI<W0M86QL(&EF(&%V86EL86)L90T*("`@("`@
M("`@("`@)')E<W0@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4D535"@G,2XQ)RP@
M87)R87DH*2D[#0H@("`@("`@("`@("`D879A:6QA8FQE(#T@)')E<W0M/FQI
M<W1!;&PH)&)A<V4L("1L:7-T7V]P=&EO;G,L(&9A;'-E*3L-"B`@("`@("`@
M?2!E;'-E:68@*"1C:&%N+3YS=7!P;W)T<U)%4U0H)'1H:7,M/F-O;F9I9RT^
M9V5T*"=P<F5F97)R961?;6ER<F]R)RDI("8F#0H@("`@("`@("`@("`@("1B
M87-E(#T@)&-H86XM/F=E=$)A<V554DPH)U)%4U0Q+C`G+"`D=&AI<RT^8V]N
M9FEG+3YG970H)W!R969E<G)E9%]M:7)R;W(G*2DI('L-"B`@("`@("`@("`@
M("1R97-T(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)%4U0H)S$N,"<L(&%R<F%Y
M*"DI.PT*("`@("`@("`@("`@)&%V86EL86)L92`]("1R97-T+3YL:7-T06QL
M*"1B87-E+"`D;&ES=%]O<'1I;VYS+"!F86QS92D[#0H@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`D<B`]("8D=&AI<RT^8V]N9FEG+3YG971296UO
M=&4H*3L-"B`@("`@("`@("`@(&EF("@D8VAA;FYE;"`]/2`G<&5A<BYP:'`N
M;F5T)RD@>PT*("`@("`@("`@("`@("`@("\O(&AA8VL@8F5C875S92!O9B!P
M;V]R('!E87)W96(@9&5S:6=N#0H@("`@("`@("`@("`@("`@)&%V86EL86)L
M92`]("1R+3YC86QL*"=P86-K86=E+FQI<W1!;&PG+"!T<G5E+"`D;&ES=%]O
M<'1I;VYS+"!F86QS92D[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("1A=F%I;&%B;&4@/2`D<BT^8V%L;"@G<&%C:V%G92YL:7-T
M06QL)RP@=')U92P@)&QI<W1?;W!T:6]N<RD[#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&%V86EL86)L
M92DI('L-"B`@("`@("`@("`@("1T:&ES+3YC;VYF:6<M/G-E="@G9&5F875L
M=%]C:&%N;F5L)RP@)'-A=F5C:&%N;F5L*3L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@G5&AE('!A8VMA9V4@;&ES="!C;W5L9"!N
M;W0@8F4@9F5T8VAE9"!F<F]M('1H92!R96UO=&4@<V5R=F5R+B!0;&5A<V4@
M=')Y(&%G86EN+B`H1&5B=6<@:6YF;SH@(B<@+B`D879A:6QA8FQE+3YG971-
M97-S86=E*"D@+B`G(BDG*3L-"B`@("`@("`@?0T*("`@("`@("`D9&%T82`]
M(&%R<F%Y*`T*("`@("`@("`@("`@)V-A<'1I;VXG(#T^("=!;&P@<&%C:V%G
M97,Z)RP-"B`@("`@("`@("`@("=B;W)D97(G(#T^('1R=64L#0H@("`@("`@
M("`@("`G:&5A9&QI;F4G(#T^(&%R<F%Y*"=086-K86=E)RP@)TQA=&5S="<L
M("=,;V-A;"<I+`T*("`@("`@("`@("`@*3L-"B`@("`@("`@)&QO8V%L7W!K
M9W,@/2`D<F5G+3YL:7-T4&%C:V%G97,H)&-H86YN96PI.PT*#0H@("`@("`@
M(&9O<F5A8V@@*"1A=F%I;&%B;&4@87,@)&YA;64@/3X@)&EN9F\I('L-"B`@
M("`@("`@("`@("1I;G-T86QL960@/2`D<F5G+3YP86-K86=E26YF;R@D;F%M
M92P@;G5L;"P@)&-H86YN96PI.PT*("`@("`@("`@("`@:68@*&ES7V%R<F%Y
M*"1I;G-T86QL961;)W9E<G-I;VXG72DI('L-"B`@("`@("`@("`@("`@("`D
M:6YS=&%L;&5D6R=V97)S:6]N)UT@/2`D:6YS=&%L;&5D6R=V97)S:6]N)UU;
M)W)E;&5A<V4G73L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1D97-C
M(#T@)&EN9F];)W-U;6UA<GDG73L-"B`@("`@("`@("`@(&EF("AI<W-E="@D
M<&%R86US6R1N86UE72DI('L-"B`@("`@("`@("`@("`@("`D9&5S8R`N/2`B
M7&Y<;B(N)&EN9F];)V1E<V-R:7!T:6]N)UT[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)VUO9&4G72DI#0H@("`@
M("`@("`@("![#0H@("`@("`@("`@("`@("`@:68@*"1O<'1I;VYS6R=M;V1E
M)UT@/3T@)VEN<W1A;&QE9"<@)B8@(6ES<V5T*"1I;G-T86QL961;)W9E<G-I
M;VXG72DI('L-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D;W!T:6]N<ULG
M;6]D92==(#T]("=N;W1I;G-T86QL960G("8F(&ES<V5T*"1I;G-T86QL961;
M)W9E<G-I;VXG72DI('L-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D;W!T
M:6]N<ULG;6]D92==(#T]("=U<&=R861E<R<-"B`@("`@("`@("`@("`@("`@
M("`@("`F)B`H(6ES<V5T*"1I;G-T86QL961;)W9E<G-I;VXG72D@?'P@=F5R
M<VEO;E]C;VUP87)E*"1I;G-T86QL961;)W9E<G-I;VXG72P-"B`@("`@("`@
M("`@("`@("`@("`@("`D:6YF;ULG<W1A8FQE)UTL("<^/2<I*2D@>PT*("`@
M("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<&]S(#T@87)R87E?<V5A
M<F-H*'-T<G1O;&]W97(H)&YA;64I+"`D;&]C86Q?<&MG<RD[#0H@("`@("`@
M("`@("!I9B`H)'!O<R`A/3T@9F%L<V4I('L-"B`@("`@("`@("`@("`@("!U
M;G-E="@D;&]C86Q?<&MG<ULD<&]S72D[#0H@("`@("`@("`@("!]#0H-"B`@
M("`@("`@("`@(&EF("AI<W-E="@D:6YF;ULG<W1A8FQE)UTI("8F("$D:6YF
M;ULG<W1A8FQE)UTI('L-"B`@("`@("`@("`@("`@("`D:6YF;ULG<W1A8FQE
M)UT@/2!N=6QL.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&1A=&%;
M)V1A=&$G75LD:6YF;ULG8V%T96=O<GDG75U;72`](&%R<F%Y*`T*("`@("`@
M("`@("`@("`@("1R96<M/F-H86YN96Q!;&EA<R@D8VAA;FYE;"D@+B`G+R<@
M+B`D;F%M92P-"B`@("`@("`@("`@("`@("!`)&EN9F];)W-T86)L92==+`T*
M("`@("`@("`@("`@("`@($`D:6YS=&%L;&5D6R=V97)S:6]N)UTL#0H@("`@
M("`@("`@("`@("`@0"1D97-C+`T*("`@("`@("`@("`@("`@($`D:6YF;ULG
M9&5P<R==+`T*("`@("`@("`@("`@("`@("D[#0H@("`@("`@('T-"@T*("`@
M("`@("!I9B`H:7-S970H)&]P=&EO;G-;)VUO9&4G72D@)B8@:6Y?87)R87DH
M)&]P=&EO;G-;)VUO9&4G72P@87)R87DH)VYO=&EN<W1A;&QE9"<L("=U<&=R
M861E<R<I*2D@>PT*("`@("`@("`@("`@)'1H:7,M/F-O;F9I9RT^<V5T*"=D
M969A=6QT7V-H86YN96PG+"`D<V%V96-H86YN96PI.PT*("`@("`@("`@("`@
M)'1H:7,M/G5I+3YO=71P=71$871A*"1D871A+"`D8V]M;6%N9"D[#0H@("`@
M("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@?0T*("`@("`@("!F;W)E
M86-H("@D;&]C86Q?<&MG<R!A<R`D;F%M92D@>PT*("`@("`@("`@("`@)&EN
M9F\@/2`F)')E9RT^9V5T4&%C:V%G92@D;F%M92P@)&-H86YN96PI.PT*("`@
M("`@("`@("`@)&1A=&%;)V1A=&$G75LG3&]C86PG75M=(#T@87)R87DH#0H@
M("`@("`@("`@("`@("`@)')E9RT^8VAA;FYE;$%L:6%S*"1C:&%N;F5L*2`N
M("<O)R`N("1I;F9O+3YG971086-K86=E*"DL#0H@("`@("`@("`@("`@("`@
M)R<L#0H@("`@("`@("`@("`@("`@)&EN9F\M/F=E=%9E<G-I;VXH*2P-"B`@
M("`@("`@("`@("`@("`D:6YF;RT^9V5T4W5M;6%R>2@I+`T*("`@("`@("`@
M("`@("`@("1I;F9O+3YG971$97!S*"D-"B`@("`@("`@("`@("`@("`I.PT*
M("`@("`@("!]#0H-"B`@("`@("`@)'1H:7,M/F-O;F9I9RT^<V5T*"=D969A
M=6QT7V-H86YN96PG+"`D<V%V96-H86YN96PI.PT*("`@("`@("`D=&AI<RT^
M=6DM/F]U='!U=$1A=&$H)&1A=&$L("1C;VUM86YD*3L-"B`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&1O
M4V5A<F-H*"D-"@T*("`@(&9U;F-T:6]N(&1O4V5A<F-H*"1C;VUM86YD+"`D
M;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@(&EF("@H(6ES<V5T
M*"1P87)A;7-;,%TI('Q\(&5M<'1Y*"1P87)A;7-;,%TI*0T*("`@("`@("`@
M("`@)B8@*"%I<W-E="@D<&%R86US6S%=*2!\?"!E;7!T>2@D<&%R86US6S%=
M*2DI#0H@("`@("`@('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@G;F\@=F%L:60@<V5A<F-H('-T<FEN9R!S=7!P;&EE9"<I.PT*
M("`@("`@("!].PT*#0H@("`@("`@("1S879E8VAA;FYE;"`]("1C:&%N;F5L
M(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=D969A=6QT7V-H86YN96PG*3L-"B`@
M("`@("`@)')E9R`]("8D=&AI<RT^8V]N9FEG+3YG971296=I<W1R>2@I.PT*
M("`@("`@("`D<&%C:V%G92`]("1P87)A;7-;,%T[#0H@("`@("`@("1S=6UM
M87)Y(#T@:7-S970H)'!A<F%M<ULQ72D@/R`D<&%R86US6S%=(#H@9F%L<V4[
M#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG8VAA;FYE;"==*2D@>PT*
M("`@("`@("`@("`@)')E9R`]("8D=&AI<RT^8V]N9FEG+3YG971296=I<W1R
M>2@I.PT*("`@("`@("`@("`@)&-H86YN96P@/2`D;W!T:6]N<ULG8VAA;FYE
M;"==.PT*("`@("`@("`@("`@:68@*"1R96<M/F-H86YN96Q%>&ES=',H)&-H
M86YN96PI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/F-O;F9I9RT^<V5T
M*"=D969A=6QT7V-H86YN96PG+"`D8VAA;FYE;"D[#0H@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@G0VAA;FYE;"`B)R`N("1C:&%N;F5L("X@)R(@9&]E<R!N;W0@97AI
M<W0G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D8VAA
M;B`]("1R96<M/F=E=$-H86YN96PH)&-H86YN96PI.PT*("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D92`]("1T:&ES+3Y?8VAE8VM#:&%N;F5L1F]R4W1A
M='5S*"1C:&%N;F5L+"`D8VAA;BDI*2![#0H@("`@("`@("`@("!R971U<FX@
M)&4[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1C:&%N+3YS=7!P;W)T<U)%
M4U0H)'1H:7,M/F-O;F9I9RT^9V5T*"=P<F5F97)R961?;6ER<F]R)RDI("8F
M#0H@("`@("`@("`@("`@("1B87-E(#T@)&-H86XM/F=E=$)A<V554DPH)U)%
M4U0Q+C`G+"`D=&AI<RT^8V]N9FEG+3YG970H)W!R969E<G)E9%]M:7)R;W(G
M*2DI('L-"B`@("`@("`@("`@("1R97-T(#T@)B1T:&ES+3YC;VYF:6<M/F=E
M=%)%4U0H)S$N,"<L(&%R<F%Y*"DI.PT*("`@("`@("`@("`@)&%V86EL86)L
M92`]("1R97-T+3YL:7-T06QL*"1B87-E+"!F86QS92P@9F%L<V4L("1P86-K
M86=E+"`D<W5M;6%R>2D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`D<B`]("8D=&AI<RT^8V]N9FEG+3YG971296UO=&4H*3L-"B`@("`@("`@
M("`@("1A=F%I;&%B;&4@/2`D<BT^8V%L;"@G<&%C:V%G92YS96%R8V@G+"`D
M<&%C:V%G92P@)'-U;6UA<GDL('1R=64L(`T*("`@("`@("`@("`@("`@("1T
M:&ES+3YC;VYF:6<M/F=E="@G<')E9F5R<F5D7W-T871E)RD@/3T@)W-T86)L
M92<L('1R=64I.PT*("`@("`@("!]#0H@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1A=F%I;&%B;&4I*2![#0H@("`@("`@("`@("`D=&AI<RT^8V]N9FEG
M+3YS970H)V1E9F%U;'1?8VAA;FYE;"<L("1S879E8VAA;FYE;"D[#0H@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&%V86EL86)L92D[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D879A:6QA8FQE*2![#0H@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)VYO('!A8VMA9V5S
M(&9O=6YD('1H870@;6%T8V@@<&%T=&5R;B`B)R`N("1P86-K86=E("X@)R(G
M*3L-"B`@("`@("`@?0T*("`@("`@("`D9&%T82`](&%R<F%Y*`T*("`@("`@
M("`@("`@)V-A<'1I;VXG(#T^("=-871C:&5D('!A8VMA9V5S+"!C:&%N;F5L
M("<@+B`D8VAA;FYE;"`N("<Z)RP-"B`@("`@("`@("`@("=B;W)D97(G(#T^
M('1R=64L#0H@("`@("`@("`@("`G:&5A9&QI;F4G(#T^(&%R<F%Y*"=086-K
M86=E)RP@)U-T86)L92\H3&%T97-T*2<L("=,;V-A;"<I+`T*("`@("`@("`@
M("`@*3L-"@T*("`@("`@("!F;W)E86-H("@D879A:6QA8FQE(&%S("1N86UE
M(#T^("1I;F9O*2![#0H@("`@("`@("`@("`D:6YS=&%L;&5D(#T@)')E9RT^
M<&%C:V%G94EN9F\H)&YA;64L(&YU;&PL("1C:&%N;F5L*3L-"B`@("`@("`@
M("`@("1D97-C(#T@)&EN9F];)W-U;6UA<GDG73L-"B`@("`@("`@("`@(&EF
M("AI<W-E="@D<&%R86US6R1N86UE72DI#0H@("`@("`@("`@("`@("`@)&1E
M<V,@+CT@(EQN7&XB+B1I;F9O6R=D97-C<FEP=&EO;B==.PT*#0H@("`@("`@
M("`@("`D=6YS=&%B;&4@/2`G)SL-"B`@("`@("`@("`@(&EF("@D:6YF;ULG
M=6YS=&%B;&4G72D@>PT*("`@("`@("`@("`@("`@("1U;G-T86)L92`]("<O
M*"<@+B`D:6YF;ULG=6YS=&%B;&4G72`N("<@)R`N("1I;F9O6R=S=&%T92==
M("X@)RDG.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"%I<W-E
M="@D:6YF;ULG<W1A8FQE)UTI('Q\("$D:6YF;ULG<W1A8FQE)UTI('L-"B`@
M("`@("`@("`@("`@("`D:6YF;ULG<W1A8FQE)UT@/2`G;F]N92<[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`D=F5R<VEO;B`](&ES7V%R<F%Y*"1I
M;G-T86QL961;)W9E<G-I;VXG72D@/R`D:6YS=&%L;&5D6R=V97)S:6]N)UU;
M)W)E;&5A<V4G72`Z#0H@("`@("`@("`@("`@("`@)&EN<W1A;&QE9%LG=F5R
M<VEO;B==.PT*("`@("`@("`@("`@)&1A=&%;)V1A=&$G75LD:6YF;ULG8V%T
M96=O<GDG75U;72`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("1N86UE+`T*
M("`@("`@("`@("`@("`@("1I;F9O6R=S=&%B;&4G72`N("1U;G-T86)L92P-
M"B`@("`@("`@("`@("`@("`D=F5R<VEO;BP-"B`@("`@("`@("`@("`@("`D
M9&5S8RP-"B`@("`@("`@("`@("`@("`I.PT*("`@("`@("!]#0H@("`@("`@
M("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D9&%T82P@)&-O;6UA;F0I.PT*("`@
M("`@("`D=&AI<RT^8V]N9FEG+3YS970H)V1E9F%U;'1?8VAA;FYE;"<L("1C
M:&%N;F5L*3L-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@
M+R\@?7U]#0H@("`@9G5N8W1I;VX@)F=E=$1O=VYL;V%D97(H)&]P=&EO;G,I
M#0H@("`@>PT*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]$;W=N
M;&]A9&5R)RDI('L-"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]$
M;W=N;&]A9&5R+G!H<"<[#0H@("`@("`@('T-"B`@("`@("`@)&$@/2`F;F5W
M(%!%05)?1&]W;FQO861E<B@D=&AI<RT^=6DL("1O<'1I;VYS+"`D=&AI<RT^
M8V]N9FEG*3L-"B`@("`@("`@<F5T=7)N("1A.PT*("`@('T-"B`@("`O+R![
M>WL@9&]$;W=N;&]A9"@I#0H-"B`@("!F=6YC=&EO;B!D;T1O=VYL;V%D*"1C
M;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@("\O
M(&UA:V4@8V5R=&%I;B!T:&%T(&1E<&5N9&5N8VEE<R!A<F4@:6=N;W)E9`T*
M("`@("`@("`D;W!T:6]N<ULG9&]W;FQO861O;FQY)UT@/2`Q.PT*("`@("`@
M("`O+R!E;&EM:6YA=&4@97)R;W(@;65S<V%G97,@9F]R('!R969E<G)E9%]S
M=&%T92UR96QA=&5D(&5R<F]R<PT*("`@("`@("`D;W!T:6]N<ULG:6=N;W)E
M<')E9F5R<F5D7W-T871E)UT@/2`Q.PT*("`@("`@("`D9&]W;FQO861E<B`]
M("8D=&AI<RT^9V5T1&]W;FQO861E<B@D;W!T:6]N<RD[#0H@("`@("`@("1D
M;W=N;&]A9&5R+3YS971$;W=N;&]A9$1I<BAG971C=V0H*2D[#0H@("`@("`@
M("1E<G)O<G,@/2!A<G)A>2@I.PT*("`@("`@("`D9&]W;FQO861E9"`](&%R
M<F%Y*"D[#0H@("`@("`@("1E<G(@/2`D9&]W;FQO861E<BT^9&]W;FQO860H
M)'!A<F%M<RD[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G(I*2![
M#0H@("`@("`@("`@("!R971U<FX@)&5R<CL-"B`@("`@("`@?0T*("`@("`@
M("`D97)R;W)S(#T@)&1O=VYL;V%D97(M/F=E=$5R<F]R37-G<R@I.PT*("`@
M("`@("!I9B`H8V]U;G0H)&5R<F]R<RDI('L-"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1E<G)O<G,@87,@)&5R<F]R*2![#0H@("`@("`@("`@("`@("`@)'1H
M:7,M/G5I+3YO=71P=71$871A*"1E<G)O<BD[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(B1C;VUM86YD
M(&9A:6QE9"(I.PT*("`@("`@("!]#0H@("`@("`@("1D;W=N;&]A9&5D(#T@
M)&1O=VYL;V%D97(M/F=E=$1O=VYL;V%D961086-K86=E<R@I.PT*("`@("`@
M("!F;W)E86-H("@D9&]W;FQO861E9"!A<R`D<&MG*2![#0H@("`@("`@("`@
M("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H(D9I;&4@)'!K9UMF:6QE72!D;W=N
M;&]A9&5D(BP@)&-O;6UA;F0I.PT*("`@("`@("!]#0H@("`@("`@(')E='5R
M;B!T<G5E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&1O=VYL;V%D0V%L;&)A
M8VLH)&US9RP@)'!A<F%M<R`](&YU;&PI#0H@("`@>PT*("`@("`@("!I9B`H
M)&US9R`]/2`G9&]N92<I('L-"B`@("`@("`@("`@("1T:&ES+3YB>71E<U]D
M;W=N;&]A9&5D(#T@)'!A<F%M<SL-"B`@("`@("`@?0T*("`@('T-"@T*("`@
M("\O('U]?0T*("`@("\O('M[>R!D;TQI<W15<&=R861E<R@I#0H-"B`@("!F
M=6YC=&EO;B!D;TQI<W15<&=R861E<R@D8V]M;6%N9"P@)&]P=&EO;G,L("1P
M87)A;7,I#0H@("`@>PT*("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O0V]M
M;6]N+G!H<"<[#0H@("`@("`@(&EF("AI<W-E="@D<&%R86US6S!=*2`F)B`A
M4$5!4E]#;VUM;VXZ.F)E='1E<E-T871E<R@D<&%R86US6S!=*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1P87)A;7-;,%T@
M+B`G(&ES(&YO="!A('9A;&ED('-T871E("AS=&%B;&4O8F5T82]A;'!H82]D
M979E;"]E=&,N*2!T<GD@(G!E87(@:&5L<"!L:7-T+75P9W)A9&5S(B<I.PT*
M("`@("`@("!]#0H@("`@("`@("1S879E8VAA;FYE;"`]("1C:&%N;F5L(#T@
M)'1H:7,M/F-O;F9I9RT^9V5T*"=D969A=6QT7V-H86YN96PG*3L-"B`@("`@
M("`@)')E9R`]("8D=&AI<RT^8V]N9FEG+3YG971296=I<W1R>2@I.PT*("`@
M("`@("!F;W)E86-H("@D<F5G+3YL:7-T0VAA;FYE;',H*2!A<R`D8VAA;FYE
M;"D@>PT*("`@("`@("`@("`@)&EN<W0@/2!A<G)A>5]F;&EP*"1R96<M/FQI
M<W1086-K86=E<R@D8VAA;FYE;"DI.PT*("`@("`@("`@("`@:68@*"%C;W5N
M="@D:6YS="DI('L-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&EF("@D8VAA;FYE;"`]/2`G7U]U<FDG
M*2![#0H@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`D=&AI<RT^8V]N9FEG+3YS970H)V1E9F%U;'1?8VAA
M;FYE;"<L("1C:&%N;F5L*3L-"B`@("`@("`@("`@(&EF("AE;7!T>2@D<&%R
M86US6S!=*2D@>PT*("`@("`@("`@("`@("`@("1S=&%T92`]("1T:&ES+3YC
M;VYF:6<M/F=E="@G<')E9F5R<F5D7W-T871E)RD[#0H@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("1S=&%T92`]("1P87)A;7-;,%T[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D8V%P=&EO;B`]("1C:&%N
M;F5L("X@)R!!=F%I;&%B;&4@57!G<F%D97,G.PT*("`@("`@("`@("`@)&-H
M86X@/2`D<F5G+3YG971#:&%N;F5L*"1C:&%N;F5L*3L-"B`@("`@("`@("`@
M(&EF("A014%2.CII<T5R<F]R*"1E(#T@)'1H:7,M/E]C:&5C:T-H86YN96Q&
M;W)3=&%T=7,H)&-H86YN96PL("1C:&%N*2DI('L-"B`@("`@("`@("`@("`@
M("!R971U<FX@)&4[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H
M)&-H86XM/G-U<'!O<G1S4D535"@D=&AI<RT^8V]N9FEG+3YG970H)W!R969E
M<G)E9%]M:7)R;W(G*2D@)B8-"B`@("`@("`@("`@("`@("`@("1B87-E(#T@
M)&-H86XM/F=E=$)A<V554DPH)U)%4U0Q+C`G+"`D=&AI<RT^8V]N9FEG+3YG
M970H)W!R969E<G)E9%]M:7)R;W(G*2DI('L-"B`@("`@("`@("`@("`@("`D
M<F5S="`]("8D=&AI<RT^8V]N9FEG+3YG971215-4*"<Q+C`G+"!A<G)A>2@I
M*3L-"B`@("`@("`@("`@("`@("!I9B`H96UP='DH)'-T871E*2!\?"`D<W1A
M=&4@/3T@)V%N>2<I('L-"B`@("`@("`@("`@("`@("`@("`@)'-T871E(#T@
M9F%L<V4[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@)&-A<'1I;VX@+CT@)R`H)R`N(&EM<&QO9&4H)RP@)RP@4$5!
M4E]#;VUM;VXZ.F)E='1E<E-T871E<R@D<W1A=&4L('1R=64I*2`N("<I)SL-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@4$5!4CHZ<W1A
M=&EC4'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@
M("`@("`@("`@("`@("1L871E<W0@/2`D<F5S="T^;&ES=$QA=&5S=%5P9W)A
M9&5S*"1B87-E+"`D<W1A=&4L("1I;G-T+"`D8VAA;FYE;"P@)')E9RD[#0H@
M("`@("`@("`@("`@("`@4$5!4CHZ<W1A=&EC4&]P17)R;W)(86YD;&EN9R@I
M.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D<F5M
M;W1E(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E;6]T92@I.PT*("`@("`@("`@
M("`@("`@("1R96UO=&4M/G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?
M4D5455).*3L-"B`@("`@("`@("`@("`@("!I9B`H96UP='DH)'-T871E*2!\
M?"`D<W1A=&4@/3T@)V%N>2<I('L-"B`@("`@("`@("`@("`@("`@("`@)&QA
M=&5S="`]("1R96UO=&4M/F-A;&PH(G!A8VMA9V4N;&ES=$QA=&5S=%)E;&5A
M<V5S(BD[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@)&QA=&5S="`]("1R96UO=&4M/F-A;&PH(G!A8VMA9V4N;&ES
M=$QA=&5S=%)E;&5A<V5S(BP@)'-T871E*3L-"B`@("`@("`@("`@("`@("`@
M("`@)&-A<'1I;VX@+CT@)R`H)R`N(&EM<&QO9&4H)RP@)RP@4$5!4E]#;VUM
M;VXZ.F)E='1E<E-T871E<R@D<W1A=&4L('1R=64I*2`N("<I)SL-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)')E;6]T92T^<&]P17)R
M;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&QA=&5S="DI('L-"B`@("`@("`@("`@("`@("`D
M=&AI<RT^=6DM/F]U='!U=$1A=&$H)&QA=&5S="T^9V5T365S<V%G92@I*3L-
M"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("1C87!T:6]N("X]("<Z)SL-"B`@("`@("`@("`@(&EF("A0
M14%2.CII<T5R<F]R*"1L871E<W0I*2![#0H@("`@("`@("`@("`@("`@)'1H
M:7,M/F-O;F9I9RT^<V5T*"=D969A=6QT7V-H86YN96PG+"`D<V%V96-H86YN
M96PI.PT*("`@("`@("`@("`@("`@(')E='5R;B`D;&%T97-T.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@)&1A=&$@/2!A<G)A>2@-"B`@("`@("`@
M("`@("`@("`G8V%P=&EO;B<@/3X@)&-A<'1I;VXL#0H@("`@("`@("`@("`@
M("`@)V)O<F1E<B<@/3X@,2P-"B`@("`@("`@("`@("`@("`G:&5A9&QI;F4G
M(#T^(&%R<F%Y*"=#:&%N;F5L)RP@)U!A8VMA9V4G+"`G3&]C86PG+"`G4F5M
M;W1E)RP@)U-I>F4G*2P-"B`@("`@("`@("`@("`@("`I.PT*("`@("`@("`@
M("`@9F]R96%C:"`H*&%R<F%Y*21L871E<W0@87,@)'!K9R`]/B`D:6YF;RD@
M>PT*("`@("`@("`@("`@("`@("1P86-K86=E(#T@<W1R=&]L;W=E<B@D<&MG
M*3L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1I;G-T6R1P86-K86=E
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@+R\@<VMI<"!P86-K86=E<R!W
M92!D;VXG="!H879E(&EN<W1A;&QE9`T*("`@("`@("`@("`@("`@("`@("!C
M;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M97AT<F%C="@D:6YF;RD[#0H@("`@("`@("`@("`@("`@)&EN<W1?=F5R<VEO
M;B`]("1R96<M/G!A8VMA9V5);F9O*"1P86-K86=E+"`G=F5R<VEO;B<L("1C
M:&%N;F5L*3L-"B`@("`@("`@("`@("`@("`D:6YS=%]S=&%T92`@(#T@)')E
M9RT^<&%C:V%G94EN9F\H)'!A8VMA9V4L("=R96QE87-E7W-T871E)RP@)&-H
M86YN96PI.PT*("`@("`@("`@("`@("`@(&EF("AV97)S:6]N7V-O;7!A<F4H
M(B1V97)S:6]N(BP@(B1I;G-T7W9E<G-I;VXB+"`B;&4B*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`O+R!I;G-T86QL960@=F5R<VEO;B!I<R!U<"UT;RUD
M871E#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H)&9I;&5S:7IE(#X](#(P
M-#@P*2![#0H@("`@("`@("`@("`@("`@("`@("1F:6QE<VEZ92`K/2`Q,#(T
M("T@*"1F:6QE<VEZ92`E(#$P,C0I.PT*("`@("`@("`@("`@("`@("`@("`D
M9G,@/2!S<')I;G1F*"(E9&M"(BP@)&9I;&5S:7IE("\@,3`R-"D[#0H@("`@
M("`@("`@("`@("`@?2!E;'-E:68@*"1F:6QE<VEZ92`^(#`I('L-"B`@("`@
M("`@("`@("`@("`@("`@)&9I;&5S:7IE("L](#$P,R`M("@D9FEL97-I>F4@
M)2`Q,#,I.PT*("`@("`@("`@("`@("`@("`@("`D9G,@/2!S<')I;G1F*"(E
M+C%F:T(B+"`D9FEL97-I>F4@+R`Q,#(T+C`I.PT*("`@("`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1F<R`]("(@("TB.R`O
M+R!86%@@8V5N=&5R(&EN<W1E860-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@)&1A=&%;)V1A=&$G75M=(#T@87)R87DH)&-H86YN96PL
M("1P:V<L("(D:6YS=%]V97)S:6]N("@D:6YS=%]S=&%T92DB+"`B)'9E<G-I
M;VX@*"1S=&%T92DB+"`D9G,I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@:68@*&5M<'1Y*"1D871A6R=D871A)UTI*2![#0H@("`@("`@("`@("`@
M("`@)'1H:7,M/G5I+3YO=71P=71$871A*"=#:&%N;F5L("<@+B`D8VAA;FYE
M;"`N("<Z($YO('5P9W)A9&5S(&%V86EL86)L92<I.PT*("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A
M=&$H)&1A=&$L("1C;VUM86YD*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("`D=&AI<RT^8V]N9FEG+3YS970H)V1E9F%U;'1?8VAA;FYE
M;"<L("1S879E8VAA;FYE;"D[#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@
M('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!D;T-L96%R0V%C:&4H*0T*
M#0H@("`@9G5N8W1I;VX@9&]#;&5A<D-A8VAE*"1C;VUM86YD+"`D;W!T:6]N
M<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@("1C86-H95]D:7(@/2`D=&AI
M<RT^8V]N9FEG+3YG970H)V-A8VAE7V1I<B<I.PT*("`@("`@("`D=F5R8F]S
M92`]("1T:&ES+3YC;VYF:6<M/F=E="@G=F5R8F]S92<I.PT*("`@("`@("`D
M;W5T<'5T(#T@)R<[#0H@("`@("`@(&EF("@A*"1D<"`]($!O<&5N9&ER*"1C
M86-H95]D:7(I*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*")O<&5N9&ER*"1C86-H95]D:7(I(&9A:6QE9#H@)'!H<%]E<G)O
M<FUS9R(I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D=F5R8F]S92`^/2`Q
M*2![#0H@("`@("`@("`@("`D;W5T<'5T("X](")R96%D:6YG(&1I<F5C=&]R
M>2`D8V%C:&5?9&ER7&XB.PT*("`@("`@("!]#0H@("`@("`@("1N=6T@/2`P
M.PT*("`@("`@("!W:&EL92`H)&5N="`](')E861D:7(H)&1P*2D@>PT*("`@
M("`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>>&UL<G!C7V-A8VAE7UMA+7HP
M+3E=>S,R?20O)RP@)&5N="D@?'P-"B`@("`@("`@("`@("`@("`@('!R96=?
M;6%T8V@H)R]R97-T+F-A8VAE*&9I;&5\:60I)"\G+"`D96YT*2D@>PT*("`@
M("`@("`@("`@("`@("1P871H(#T@)&-A8VAE7V1I<B`N($1)4D5#5$]265]3
M15!!4D%43U(@+B`D96YT.PT*("`@("`@("`@("`@("`@("1O:R`]($!U;FQI
M;FLH)'!A=&@I.PT*("`@("`@("`@("`@("`@(&EF("@D;VLI('L-"B`@("`@
M("`@("`@("`@("`@("`@:68@*"1V97)B;W-E(#X](#(I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1O=71P=70@+CT@(F1E;&5T960@)'!A=&A<;B([
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M)&YU;2LK.PT*("`@("`@("`@("`@("`@('T@96QS96EF("@D=F5R8F]S92`^
M/2`Q*2![#0H@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@(F9A:6QE
M9"!T;R!D96QE=&4@)'!A=&A<;B([#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&-L;W-E9&ER*"1D<"D[
M#0H@("`@("`@(&EF("@D=F5R8F]S92`^/2`Q*2![#0H@("`@("`@("`@("`D
M;W5T<'5T("X]("(D;G5M(&-A8VAE(&5N=')I97,@8VQE87)E9%QN(CL-"B`@
M("`@("`@?0T*("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H<G1R:6TH
M)&]U='!U="DL("1C;VUM86YD*3L-"B`@("`@("`@<F5T=7)N("1N=6T[#0H@
M("`@?0T*#0H@("`@+R\@?7U]#0I]#0H-"C\^#0H`````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]-:7)R;W(N>&UL````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$Q-S(@,3`U,34T,S,W,S$@,#(R
M-38V`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#QC;VUM86YD<R!V97)S:6]N/2(Q+C`B/@T*(#QD;W=N;&]A9"UA;&P^#0H@
M(#QS=6UM87)Y/D1O=VYL;V%D<R!E86-H(&%V86EL86)L92!P86-K86=E(&9R
M;VT@=&AE(&1E9F%U;'0@8VAA;FYE;#PO<W5M;6%R>3X-"B`@/&9U;F-T:6]N
M/F1O1&]W;FQO861!;&P\+V9U;F-T:6]N/@T*("`\<VAO<G1C=70^9&$\+W-H
M;W)T8W5T/@T*("`\;W!T:6]N<SX-"B`@(#QC:&%N;F5L/@T*("`@(#QS:&]R
M=&]P=#YC/"]S:&]R=&]P=#X-"B`@("`\9&]C/G-P96-I9GD@82!C:&%N;F5L
M(&]T:&5R('1H86X@=&AE(&1E9F%U;'0@8VAA;FYE;#PO9&]C/@T*("`@(#QA
M<F<^0TA!3CPO87)G/@T*("`@/"]C:&%N;F5L/@T*("`\+V]P=&EO;G,^#0H@
M(#QD;V,^#0I297%U97-T<R!A(&QI<W0@;V8@879A:6QA8FQE('!A8VMA9V5S
M(&9R;VT@=&AE(&1E9F%U;'0@8VAA;FYE;"`H>V-O;F9I9R!D969A=6QT7V-H
M86YN96Q]*0T*86YD(&1O=VYL;V%D<R!T:&5M('1O(&-U<G)E;G0@=V]R:VEN
M9R!D:7)E8W1O<GDN("!.;W1E.B!O;FQY#0IP86-K86=E<R!W:71H:6X@<')E
M9F5R<F5D7W-T871E("A[8V]N9FEG('!R969E<G)E9%]S=&%T97TI('=I;&P@
M8F4@9&]W;FQO861E9#PO9&]C/@T*(#PO9&]W;FQO860M86QL/@T*/"]C;VUM
M86YD<SX`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]-:7)R;W(N<&AP````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3(T-3(@,3`U,34T,S,W
M,S$@,#(R-38P`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP#0HO*BH-"B`J(%!%05)?0V]M;6%N9%]-:7)R;W(@*&1O
M=VYL;V%D+6%L;"!C;VUM86YD*0T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N
M9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J
M96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA
M="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@
M=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@
M;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A
M:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E
M('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y
M(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P
M86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($%L97AA;F1E<B!-97)Z
M(#QA;&5X;65R>D!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V
M(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E
M<G-I;VX@("`@0U93.B`D260Z($UI<G)O<BYP:'`L=B`Q+C$X(#(P,#8O,#,O
M,#(@,3@Z,30Z,3,@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P
M.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@
M1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C(N,`T*("HO#0H-"B\J
M*@T*("H@8F%S92!C;&%S<PT*("HO#0IR97%U:7)E7V]N8V4@)U!%05(O0V]M
M;6%N9"]#;VUM;VXN<&AP)SL-"@T*+RHJ#0H@*B!014%2(&-O;6UA;F1S(&9O
M<B!P<F]V:61I;F<@9FEL92!M:7)R;W)S#0H@*@T*("H@0&-A=&5G;W)Y("`@
M<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@06QE
M>&%N9&5R($UE<GH@/&%L97AM97)Z0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT
M("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@
M,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@
M("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S
M:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#$N,BXP
M#0H@*B\-"F-L87-S(%!%05)?0V]M;6%N9%]-:7)R;W(@97AT96YD<R!014%2
M7T-O;6UA;F1?0V]M;6]N#0I[#0H@("`@+R\@>WM[('!R;W!E<G1I97,-"@T*
M("`@('9A<B`D8V]M;6%N9',@/2!A<G)A>2@-"B`@("`@("`@)V1O=VYL;V%D
M+6%L;"<@/3X@87)R87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)T1O
M=VYL;V%D<R!E86-H(&%V86EL86)L92!P86-K86=E(&9R;VT@=&AE(&1E9F%U
M;'0@8VAA;FYE;"<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;T1O
M=VYL;V%D06QL)RP-"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)V1A)RP-
M"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@-"B`@("`@("`@("`@
M("`@("`G8VAA;FYE;"<@/3X-"B`@("`@("`@("`@("`@("`@("`@87)R87DH
M#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)V,G+`T*("`@
M("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G<W!E8VEF>2!A(&-H86YN96P@
M;W1H97(@=&AA;B!T:&4@9&5F875L="!C:&%N;F5L)RP-"B`@("`@("`@("`@
M("`@("`@("`@)V%R9R<@/3X@)T-(04XG+`T*("`@("`@("`@("`@("`@("`@
M("`I+`T*("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`G9&]C)R`]
M/B`G#0I297%U97-T<R!A(&QI<W0@;V8@879A:6QA8FQE('!A8VMA9V5S(&9R
M;VT@=&AE(&1E9F%U;'0@8VAA;FYE;"`H>V-O;F9I9R!D969A=6QT7V-H86YN
M96Q]*0T*86YD(&1O=VYL;V%D<R!T:&5M('1O(&-U<G)E;G0@=V]R:VEN9R!D
M:7)E8W1O<GDN("!.;W1E.B!O;FQY#0IP86-K86=E<R!W:71H:6X@<')E9F5R
M<F5D7W-T871E("A[8V]N9FEG('!R969E<G)E9%]S=&%T97TI('=I;&P@8F4@
M9&]W;FQO861E9"<-"B`@("`@("`@("`@("DL#0H@("`@("`@("D[#0H-"B`@
M("`O+R!]?7T-"@T*("`@("\O('M[>R!C;VYS=')U8W1O<@T*#0H@("`@+RHJ
M#0H@("`@("H@4$5!4E]#;VUM86YD7TUI<G)O<B!C;VYS=')U8W1O<BX-"B`@
M("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H@0'!A<F%M(&]B
M:F5C="!014%27T9R;VYT96YD(&$@<F5F97)E;F-E('1O(&%N(&9R;VYT96YD
M#0H@("`@("H@0'!A<F%M(&]B:F5C="!014%27T-O;F9I9R!A(')E9F5R96YC
M92!T;R!T:&4@8V]N9FEG=7)A=&EO;B!D871A#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@4$5!4E]#;VUM86YD7TUI<G)O<B@F)'5I+"`F)&-O;F9I9RD-"B`@
M("![#0H@("`@("`@('!A<F5N=#HZ4$5!4E]#;VUM86YD7T-O;6UO;B@D=6DL
M("1C;VYF:6<I.PT*("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@+RHJ#0H@
M("`@("H@1F]R('5N:70M=&5S=&EN9PT*("`@("`J+PT*("`@(&9U;F-T:6]N
M("9F86-T;W)Y*"1A*0T*("`@('L-"B`@("`@("`@)&$@/2`F4$5!4E]#;VUM
M86YD.CIF86-T;W)Y*"1A+"`D=&AI<RT^8V]N9FEG*3L-"B`@("`@("`@<F5T
M=7)N("1A.PT*("`@('T-"@T*("`@("\O('M[>R!D;T1O=VYL;V%D06QL*"D-
M"B`@("`O*BH-"B`@("`J(')E=')I979E<R!A(&QI<W0@;V8@879A:6)L92!0
M86-K86=E<R!F<F]M(&UA<W1E<B!S97)V97(-"B`@("`J(&%N9"!D;W=N;&]A
M9',@=&AE;0T*("`@("H-"B`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@*B!`
M<&%R86T@<W1R:6YG("1C;VUM86YD('1H92!C;VUM86YD#0H@("`@*B!`<&%R
M86T@87)R87D@)&]P=&EO;G,@=&AE(&-O;6UA;F0@;W!T:6]N<R!B969O<F4@
M=&AE(&-O;6UA;F0-"B`@("`J($!P87)A;2!A<G)A>2`D<&%R86US('1H92!S
M='5F9B!A9G1E<B!T:&4@8V]M;6%N9"!N86UE#0H@("`@*B!`<F5T=7)N(&)O
M;VP@=')U92!I9B!S=6-C97-F=6P-"B`@("`J($!T:')O=R!014%27T5R<F]R
M(`T*("`@("HO#0H@("`@9G5N8W1I;VX@9&]$;W=N;&]A9$%L;"@D8V]M;6%N
M9"P@)&]P=&EO;G,L("1P87)A;7,I#0H@("`@>PT*("`@("`@("`D<V%V96-H
M86YN96P@/2`D=&AI<RT^8V]N9FEG+3YG970H)V1E9F%U;'1?8VAA;FYE;"<I
M.PT*("`@("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y
M*"D[#0H@("`@("`@("1C:&%N;F5L(#T@:7-S970H)&]P=&EO;G-;)V-H86YN
M96PG72D@/R`D;W!T:6]N<ULG8VAA;FYE;"==(#H-"B`@("`@("`@("`@("1T
M:&ES+3YC;VYF:6<M/F=E="@G9&5F875L=%]C:&%N;F5L)RD[#0H@("`@("`@
M(&EF("@A)')E9RT^8VAA;FYE;$5X:7-T<R@D8VAA;FYE;"DI('L-"B`@("`@
M("`@("`@("1T:&ES+3YC;VYF:6<M/G-E="@G9&5F875L=%]C:&%N;F5L)RP@
M)'-A=F5C:&%N;F5L*3L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@G0VAA;FYE;"`B)R`N("1C:&%N;F5L("X@)R(@9&]E<R!N;W0@
M97AI<W0G*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^8V]N9FEG+3YS
M970H)V1E9F%U;'1?8VAA;FYE;"<L("1C:&%N;F5L*3L-"B`@("`@("`@)'1H
M:7,M/G5I+3YO=71P=71$871A*"=5<VEN9R!#:&%N;F5L("<@+B`D=&AI<RT^
M8V]N9FEG+3YG970H)V1E9F%U;'1?8VAA;FYE;"<I*3L-"B`@("`@("`@)&-H
M86X@/2`D<F5G+3YG971#:&%N;F5L*"1C:&%N;F5L*3L-"B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&-H86XI*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H)&-H86XI.PT*("`@("`@("!]#0H@("`@("`@
M(&EF("@D8VAA;BT^<W5P<&]R='-215-4*"1T:&ES+3YC;VYF:6<M/F=E="@G
M<')E9F5R<F5D7VUI<G)O<B<I*2`F)@T*("`@("`@("`@("`@("`D8F%S92`]
M("1C:&%N+3YG971"87-E55),*"=215-4,2XP)RP@)'1H:7,M/F-O;F9I9RT^
M9V5T*"=P<F5F97)R961?;6ER<F]R)RDI*2![#0H@("`@("`@("`@("`D<F5S
M="`]("8D=&AI<RT^8V]N9FEG+3YG971215-4*"<Q+C`G+"!A<G)A>2@I*3L-
M"B`@("`@("`@("`@("1R96UO=&5);F9O(#T@87)R87E?9FQI<"@D<F5S="T^
M;&ES=%!A8VMA9V5S*"1B87-E*2D[#0H@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`D<F5M;W1E(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E;6]T92@I
M.PT*("`@("`@("`@("`@)'-T86)L92`]("@D=&AI<RT^8V]N9FEG+3YG970H
M)W!R969E<G)E9%]S=&%T92<I(#T]("=S=&%B;&4G*3L-"B`@("`@("`@("`@
M("1R96UO=&5);F9O(#T@)')E;6]T92T^8V%L;"@B<&%C:V%G92YL:7-T06QL
M(BP@=')U92P@)'-T86)L92P@9F%L<V4I.PT*("`@("`@("!]#0H@("`@("`@
M(&EF("A014%2.CII<T5R<F]R*"1R96UO=&5);F9O*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N("1R96UO=&5);F9O.PT*("`@("`@("!]#0H@("`@("`@("1C
M;60@/2`F)'1H:7,M/F9A8W1O<GDH(F1O=VYL;V%D(BD[#0H@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1C;60I*2![#0H@("`@("`@("`@("!R971U<FX@
M)&-M9#L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A
M=&$H)U5S:6YG(%!R969E<G)E9"!3=&%T92!O9B`G("X-"B`@("`@("`@("`@
M("1T:&ES+3YC;VYF:6<M/F=E="@G<')E9F5R<F5D7W-T871E)RDI.PT*("`@
M("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)T=A=&AE<FEN9R!R96QE87-E
M(&EN9F]R;6%T:6]N+"!P;&5A<V4@=V%I="XN+B<I.PT*("`@("`@("`O*BH-
M"B`@("`@("`@("H@17)R;W(@:&%N9&QI;F<@;F]T(&YE8V5S<V%R>2P@8F5C
M875S92!A;')E861Y(&1O;F4@8GD@#0H@("`@("`@("`J('1H92!D;W=N;&]A
M9"!C;VUM86YD#0H@("`@("`@("`J+PT*("`@("`@("!014%2.CIS=&%T:6-0
M=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@
M("1E<G(@/2`D8VUD+3YR=6XH)V1O=VYL;V%D)RP@87)R87DH)V1O=VYL;V%D
M;VYL>2<@/3X@=')U92DL(&%R<F%Y7VME>7,H)')E;6]T94EN9F\I*3L-"B`@
M("`@("`@4$5!4CHZ<W1A=&EC4&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@
M("`D=&AI<RT^8V]N9FEG+3YS970H)V1E9F%U;'1?8VAA;FYE;"<L("1S879E
M8VAA;FYE;"D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G(I*2![
M#0H@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)&5R<BT^9V5T
M365S<V%G92@I*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@=')U93L-
M"B`@("!]#0H-"B`@("`O+R!]?7T-"GT-"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%
M05(O0V]M;6%N9"]497-T+GAM;```````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#(S,C(@,3`U,34T,S,W,S$@,#(R,C,Q`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#QC;VUM86YD<R!V97)S
M:6]N/2(Q+C`B/@T*(#QR=6XM=&5S=',^#0H@(#QS=6UM87)Y/E)U;B!296=R
M97-S:6]N(%1E<W1S/"]S=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]2=6Y497-T
M<SPO9G5N8W1I;VX^#0H@(#QS:&]R=&-U=#YR=#PO<VAO<G1C=70^#0H@(#QO
M<'1I;VYS/@T*("`@/')E8W5R/@T*("`@(#QS:&]R=&]P=#YR/"]S:&]R=&]P
M=#X-"B`@("`\9&]C/E)U;B!T97-T<R!I;B!C:&EL9"!D:7)E8W1O<FEE<RP@
M<F5C=7)S:79E;'DN("`T(&1I<G,@9&5E<"!M87AI;75M/"]D;V,^#0H@("`\
M+W)E8W5R/@T*("`@/&EN:3X-"B`@("`\<VAO<G1O<'0^:3PO<VAO<G1O<'0^
M#0H@("`@/&1O8SYA8W1U86P@<W1R:6YG(&]F('-E='1I;F=S('1O('!A<W,@
M=&\@<&AP(&EN(&9O<FUA="`F<75O=#L@+60@<V5T=&EN9SUB;&%H)G%U;W0[
M/"]D;V,^#0H@("`@/&%R9SY3151424Y'4SPO87)G/@T*("`@/"]I;FD^#0H@
M("`\<F5A;'1I;65L;V<^#0H@("`@/'-H;W)T;W!T/FP\+W-H;W)T;W!T/@T*
M("`@(#QD;V,^3&]G('1E<W0@<G5N<R]R97-U;'1S(&%S('1H97D@87)E(')U
M;CPO9&]C/@T*("`@/"]R96%L=&EM96QO9SX-"B`@(#QQ=6EE=#X-"B`@("`\
M<VAO<G1O<'0^<3PO<VAO<G1O<'0^#0H@("`@/&1O8SY/;FQY(&1I<W!L87D@
M9&5T86EL(&9O<B!F86EL960@=&5S=',\+V1O8SX-"B`@(#PO<75I970^#0H@
M("`\<VEM<&QE/@T*("`@(#QS:&]R=&]P=#YS/"]S:&]R=&]P=#X-"B`@("`\
M9&]C/D1I<W!L87D@<VEM<&QE(&]U='!U="!F;W(@86QL('1E<W1S/"]D;V,^
M#0H@("`\+W-I;7!L93X-"B`@(#QP86-K86=E/@T*("`@(#QS:&]R=&]P=#YP
M/"]S:&]R=&]P=#X-"B`@("`\9&]C/E1R96%T('!A<F%M971E<G,@87,@:6YS
M=&%L;&5D('!A8VMA9V5S(&9R;VT@=VAI8V@@=&\@<G5N('1E<W1S/"]D;V,^
M#0H@("`\+W!A8VMA9V4^#0H@("`\<&AP=6YI=#X-"B`@("`\<VAO<G1O<'0^
M=3PO<VAO<G1O<'0^#0H@("`@/&1O8SY396%R8V@@<&%R86UE=&5R<R!F;W(@
M06QL5&5S=',N<&AP+"!A;F0@=7-E('1H870@=&\@<G5N('!H<'5N:70M8F%S
M960@=&5S=',\+V1O8SX-"B`@(#PO<&AP=6YI=#X-"B`@/"]O<'1I;VYS/@T*
M("`\9&]C/EMT97-T9FEL97QD:7(@+BXN70T*4G5N(')E9W)E<W-I;VX@=&5S
M=',@=VET:"!02%`F87!O<SMS(')E9W)E<W-I;VX@=&5S=&EN9R!S8W)I<'0@
M*')U;BUT97-T<RYP:'`I+CPO9&]C/@T*(#PO<G5N+71E<W1S/@T*/"]C;VUM
M86YD<SX`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+U1E<W0N<&AP````
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R,S<R,"`Q,#4Q-30S
M,S<S,2`P,C(R,C4`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`-"B\J*@T*("H@4$5!4E]#;VUM86YD7U1E<W0@*')U
M;BUT97-T<RD-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J
M($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S
M:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA
M8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I
M;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@
M4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U
M9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E
M0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L
M>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!0
M14%2#0H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^
M#0H@*B!`875T:&]R("`@("!-87)T:6X@2F%N<V5N(#QM:D!P:'`N;F5T/@T*
M("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*
M("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L
M:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@
M(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%1E
M<W0N<&AP+'8@,2XY(#(P,#8O,#(O,#,@,C(Z,C@Z,#@@8V5L;&]G($5X<"`D
M#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O
M4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L
M96%S92`P+C$-"B`J+PT*#0HO*BH-"B`J(&)A<V4@8VQA<W,-"B`J+PT*<F5Q
M=6ER95]O;F-E("=014%2+T-O;6UA;F0O0V]M;6]N+G!H<"<[#0H-"B\J*@T*
M("H@4$5!4B!C;VUM86YD<R!F;W(@;&]G:6XO;&]G;W5T#0H@*@T*("H@0&-A
M=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO
M<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@
M("`@36%R=&EN($IA;G-E;B`\;6I`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@
M($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@
M(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P
M.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S
M+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@
M("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I
M;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,"XQ#0H@
M*B\-"@T*8VQA<W,@4$5!4E]#;VUM86YD7U1E<W0@97AT96YD<R!014%27T-O
M;6UA;F1?0V]M;6]N#0I[#0H@("`@+R\@>WM[('!R;W!E<G1I97,-"@T*("`@
M('9A<B`D8V]M;6%N9',@/2!A<G)A>2@-"B`@("`@("`@)W)U;BUT97-T<R<@
M/3X@87)R87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)U)U;B!296=R
M97-S:6]N(%1E<W1S)RP-"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O
M4G5N5&5S=',G+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G<G0G+`T*
M("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@
M("`@("=R96-U<B<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S
M:&]R=&]P="<@/3X@)W(G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]
M/B`G4G5N('1E<W1S(&EN(&-H:6QD(&1I<F5C=&]R:65S+"!R96-U<G-I=F5L
M>2X@(#0@9&ER<R!D965P(&UA>&EM=6TG+`T*("`@("`@("`@("`@("`@("DL
M#0H@("`@("`@("`@("`@("`@)VEN:2<@/3X@87)R87DH#0H@("`@("`@("`@
M("`@("`@("`@("=S:&]R=&]P="<@/3X@)VDG+`T*("`@("`@("`@("`@("`@
M("`@("`G9&]C)R`]/B`G86-T=6%L('-T<FEN9R!O9B!S971T:6YG<R!T;R!P
M87-S('1O('!H<"!I;B!F;W)M870@(B`M9"!S971T:6YG/6)L86@B)RP-"B`@
M("`@("`@("`@("`@("`@("`@)V%R9R<@/3X@)U-%5%1)3D=3)PT*("`@("`@
M("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@)W)E86QT:6UE;&]G)R`]
M/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G
M;"<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=,;V<@=&5S="!R
M=6YS+W)E<W5L=',@87,@=&AE>2!A<F4@<G5N)RP-"B`@("`@("`@("`@("`@
M("`I+`T*("`@("`@("`@("`@("`@("=Q=6EE="<@/3X@87)R87DH#0H@("`@
M("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)W$G+`T*("`@("`@("`@
M("`@("`@("`@("`G9&]C)R`]/B`G3VYL>2!D:7-P;&%Y(&1E=&%I;"!F;W(@
M9F%I;&5D('1E<W1S)RP-"B`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@
M("`@("`@("=S:6UP;&4G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@
M("`G<VAO<G1O<'0G(#T^("=S)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O
M8R<@/3X@)T1I<W!L87D@<VEM<&QE(&]U='!U="!F;W(@86QL('1E<W1S)RP-
M"B`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=P86-K86=E
M)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]
M/B`G<"<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=4<F5A="!P
M87)A;65T97)S(&%S(&EN<W1A;&QE9"!P86-K86=E<R!F<F]M('=H:6-H('1O
M(')U;B!T97-T<R<L#0H@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@
M("`@("`G<&AP=6YI="<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@
M("=S:&]R=&]P="<@/3X@)W4G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C
M)R`]/B`G4V5A<F-H('!A<F%M971E<G,@9F]R($%L;%1E<W1S+G!H<"P@86YD
M('5S92!T:&%T('1O(')U;B!P:'!U;FET+6)A<V5D('1E<W1S)RP-"B`@("`@
M("`@("`@("`@("`I+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("=D
M;V,G(#T^("=;=&5S=&9I;&5\9&ER("XN+ET-"E)U;B!R96=R97-S:6]N('1E
M<W1S('=I=&@@4$A07"=S(')E9W)E<W-I;VX@=&5S=&EN9R!S8W)I<'0@*')U
M;BUT97-T<RYP:'`I+B<L#0H@("`@("`@("`@("`I+`T*("`@("`@("`I.PT*
M#0H@("`@=F%R("1O=71P=70[#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@
M8V]N<W1R=6-T;W(-"@T*("`@("\J*@T*("`@("`J(%!%05)?0V]M;6%N9%]4
M97-T(&-O;G-T<G5C=&]R+@T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L
M:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!014%27T-O;6UA;F1?5&5S="@F
M)'5I+"`F)&-O;F9I9RD-"B`@("![#0H@("`@("`@('!A<F5N=#HZ4$5!4E]#
M;VUM86YD7T-O;6UO;B@D=6DL("1C;VYF:6<I.PT*("`@('T-"@T*("`@("\O
M('U]?0T*("`@("\O('M[>R!D;U)U;E1E<W1S*"D-"@T*("`@(&9U;F-T:6]N
M(&1O4G5N5&5S=',H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@
M('L-"B`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+T-O;6UO;BYP:'`G.PT*
M("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O4G5N5&5S="YP:'`G.PT*("`@
M("`@("!R97%U:7)E7V]N8V4@)U-Y<W1E;2YP:'`G.PT*("`@("`@("`D;&]G
M(#T@;F5W(%!%05)?0V]M;6]N.PT*("`@("`@("`D;&]G+3YU:2`]("8D=&AI
M<RT^=6D[("\O('-L:6=H=&QY(&AA8VMY+"!B=70@:70@=VEL;"!W;W)K#0H@
M("`@("`@("1R=6X@/2!N97<@4$5!4E]2=6Y497-T*"1L;V<L("1O<'1I;VYS
M*3L-"B`@("`@("`@)'1E<W1S(#T@87)R87DH*3L-"B`@("`@("`@:68@*&ES
M<V5T*"1O<'1I;VYS6R=R96-U<B==*2D@>PT*("`@("`@("`@("`@)&1E<'1H
M(#T@-#L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1D97!T:"`]
M(#$[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%C;W5N="@D<&%R86US*2D@
M>PT*("`@("`@("`@("`@)'!A<F%M<UM=(#T@)RXG.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG<&%C:V%G92==*2D@>PT*("`@
M("`@("`@("`@)&]L9'!A<F%M<R`]("1P87)A;7,[#0H@("`@("`@("`@("`D
M<&%R86US(#T@87)R87DH*3L-"B`@("`@("`@("`@("1R96<@/2`F)'1H:7,M
M/F-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-"B`@("`@("`@("`@(&9O<F5A8V@@
M*"1O;&1P87)A;7,@87,@)'!A<F%M*2![#0H@("`@("`@("`@("`@("`@)'!N
M86UE(#T@)')E9RT^<&%R<V5086-K86=E3F%M92@D<&%R86TL("1T:&ES+3YC
M;VYF:6<M/F=E="@G9&5F875L=%]C:&%N;F5L)RDI.PT*("`@("`@("`@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1P;F%M92DI('L-"B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1P;F%M92D[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1P86-K86=E(#T@
M)B1R96<M/F=E=%!A8VMA9V4H)'!N86UE6R=P86-K86=E)UTL("1P;F%M95LG
M8VAA;FYE;"==*3L-"B`@("`@("`@("`@("`@("!I9B`H(21P86-K86=E*2![
M#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"=5;FMN;W=N('!A8VMA9V4@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@
M("`@)')E9RT^<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9R@D<&YA;64I("X@
M)R(G*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&9I
M;&5L:7-T(#T@)'!A8VMA9V4M/F=E=$9I;&5L:7-T*"D[#0H@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)&9I;&5L:7-T(&%S("1N86UE(#T^("1A='1S*2![
M#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D871T<ULG<F]L92==
M*2`F)B`D871T<ULG<F]L92==("$]("=T97-T)RD@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=P:'!U
M;FET)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(7!R96=?
M;6%T8V@H)R]!;&Q497-T<UPN<&AP)"]I)RP@)&YA;64I*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H)R]<+G!H
M<'0D+R<L("1N86UE*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1P87)A;7-;
M72`]("1A='1S6R=I;G-T86QL961?87,G73L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H
M)'!A<F%M<R!A<R`D<"D@>PT*("`@("`@("`@("`@:68@*&ES7V1I<B@D<"DI
M('L-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W!H<'5N
M:70G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)&1I<B`](%-Y<W1E;3HZ
M9FEN9"AA<G)A>2@D<"P@)RUT>7!E)RP@)V8G+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)RUM87AD97!T:"<L
M("1D97!T:"P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("<M;F%M92<L("=!;&Q497-T<RYP:'`G*2D[#0H@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)&1I
M<B`](%-Y<W1E;3HZ9FEN9"AA<G)A>2@D<"P@)RUT>7!E)RP@)V8G+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)RUM87AD97!T:"<L("1D97!T:"P-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("<M;F%M92<L("<J+G!H<'0G*2D[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1T97-T<R`]
M(&%R<F%Y7VUE<F=E*"1T97-T<RP@)&1I<BD[#0H@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG<&AP
M=6YI="==*2D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(7!R96=?;6%T
M8V@H)R]!;&Q497-T<UPN<&AP)"]I)RP@)'`I*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`D=&5S='-;72`]("1P.PT*("`@("`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A0&9I
M;&5?97AI<W1S*"1P*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"%P<F5G7VUA=&-H*"<O7"YP:'!T)"\G+"`D<"DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<"`N/2`G+G!H<'0G.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@)&1I<B`]
M(%-Y<W1E;3HZ9FEN9"AA<G)A>2AD:7)N86UE*"1P*2P@)RUT>7!E)RP@)V8G
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("<M;6%X9&5P=&@G+"`D9&5P=&@L#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)RUN86UE
M)RP@)'`I*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T97-T<R`](&%R
M<F%Y7VUE<F=E*"1T97-T<RP@)&1I<BD[#0H@("`@("`@("`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&5S='-;72`]
M("1P.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1I;FE?<V5T
M=&EN9W,@/2`G)SL-"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=I;FDG
M72DI('L-"B`@("`@("`@("`@("1I;FE?<V5T=&EN9W,@+CT@)&]P=&EO;G-;
M)VEN:2==.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D7T5.5ELG
M5$535%]02%!?24Y#3%5$15]0051()UTI*2![#0H@("`@("`@("`@("`D:6YI
M7W-E='1I;F=S("X]("(@+60@:6YC;'5D95]P871H/7LD7T5.5ELG5$535%]0
M2%!?24Y#3%5$15]0051()UU](CL-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M)&EN:5]S971T:6YG<RD@>PT*("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P
M=71$871A*"=5<VEN9R!)3DD@<V5T=&EN9W,Z("(G("X@)&EN:5]S971T:6YG
M<R`N("<B)RD[#0H@("`@("`@('T-"B`@("`@("`@)'-K:7!P960@/2`D<&%S
M<V5D(#T@)&9A:6QE9"`](&%R<F%Y*"D[#0H@("`@("`@("1T:&ES+3YU:2T^
M;W5T<'5T1&%T82@G4G5N;FEN9R`G("X@8V]U;G0H)'1E<W1S*2`N("<@=&5S
M=',G+"`D8V]M;6%N9"D[#0H@("`@("`@("1S=&%R="`]('1I;64H*3L-"B`@
M("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=R96%L=&EM96QO9R==*2D@>PT*
M("`@("`@("`@("`@0'5N;&EN:R@G<G5N+71E<W1S+FQO9R<I.PT*("`@("`@
M("!]#0H@("`@("`@(&9O<F5A8V@@*"1T97-T<R!A<R`D="D@>PT*("`@("`@
M("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=R96%L=&EM96QO9R==*2D@>PT*
M("`@("`@("`@("`@("`@("1F<"`]($!F;W!E;B@G<G5N+71E<W1S+FQO9R<L
M("=A)RD[#0H@("`@("`@("`@("`@("`@:68@*"1F<"D@>PT*("`@("`@("`@
M("`@("`@("`@("!F=W)I=&4H)&9P+"`B4G5N;FEN9R!T97-T("1T+BXN(BD[
M#0H@("`@("`@("`@("`@("`@("`@(&9C;&]S92@D9G`I.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(%!%05(Z.G-T
M871I8U!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@
M("`@("`@("`@("1R97-U;'0@/2`D<G5N+3YR=6XH)'0L("1I;FE?<V5T=&EN
M9W,I.PT*("`@("`@("`@("`@4$5!4CHZ<W1A=&EC4&]P17)R;W)(86YD;&EN
M9R@I.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<W5L="DI
M('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^=6DM/FQO9R@P+"`D<F5S=6QT
M+3YG971-97-S86=E*"DI.PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS
M6R=R96%L=&EM96QO9R==*2D@>PT*("`@("`@("`@("`@("`@("1F<"`]($!F
M;W!E;B@G<G5N+71E<W1S+FQO9R<L("=A)RD[#0H@("`@("`@("`@("`@("`@
M:68@*"1F<"D@>PT*("`@("`@("`@("`@("`@("`@("!F=W)I=&4H)&9P+"`B
M)')E<W5L=%QN(BD[#0H@("`@("`@("`@("`@("`@("`@(&9C;&]S92@D9G`I
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(&EF("@D<F5S=6QT(#T]("=&04E,140G*2![#0H@("`@("`@("`@("`)
M)&9A:6QE9%M=(#T@)'0[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I
M9B`H)')E<W5L="`]/2`G4$%34T5$)RD@>PT*("`@("`@("`@("`@"21P87-S
M961;72`]("1T.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1R
M97-U;'0@/3T@)U-+25!0140G*2![#0H@("`@("`@("`@("`))'-K:7!P961;
M72`]("1T.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1T
M;W1A;"`](&1A=&4H)VDZ<R<L('1I;64H*2`M("1S=&%R="D[#0H@("`@("`@
M(&EF("AC;W5N="@D9F%I;&5D*2D@>PT*("`@("`@("`@("`@)&]U='!U="`]
M(")43U1!3"!424U%.B`D=&]T86Q<;B([#0H@("`@("`@("`@("`D;W5T<'5T
M("X](&-O=6YT*"1P87-S960I("X@(B!005-3140@5$535%-<;B([#0H@("`@
M("`@("`@("`D;W5T<'5T("X](&-O=6YT*"1S:VEP<&5D*2`N("(@4TM)4%!%
M1"!415-44UQN(CL-"B`@("`)"21O=71P=70@+CT@8V]U;G0H)&9A:6QE9"D@
M+B`B($9!24Q%1"!415-44SI<;B([#0H@("`@("`@(`EF;W)E86-H("@D9F%I
M;&5D(&%S("1F86EL=7)E*2![#0H@("`@("`@(`D))&]U='!U="`N/2`D9F%I
M;'5R92`N(")<;B([#0H@("`@("`@(`E]#0H@("`@("`@("`@("!I9B`H:7-S
M970H)&]P=&EO;G-;)W)E86QT:6UE;&]G)UTI*2![#0H@("`@("`@("`@("`@
M("`@)&9P(#T@0&9O<&5N*"=R=6XM=&5S=',N;&]G)RP@)V$G*3L-"B`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)&9P(#T@0&9O<&5N
M*"=R=6XM=&5S=',N;&]G)RP@)W<G*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&EF("@D9G`I('L-"B`@("`@("`@("`@("`@("!F=W)I=&4H)&9P
M+"`D;W5T<'5T+"!S=')L96XH)&]U='!U="DI.PT*("`@("`@("`@("`@("`@
M(&9C;&]S92@D9G`I.PT*("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T
M<'5T1&%T82@G=W)O=&4@;&]G('1O("(G("X@<F5A;'!A=&@H)W)U;BUT97-T
M<RYL;V<G*2`N("<B)RP@)&-O;6UA;F0I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!](&5L<V5I9B`H0&9I;&5?97AI<W1S*"=R=6XM=&5S=',N;&]G)RD@
M)B8@(4!I<U]D:7(H)W)U;BUT97-T<RYL;V<G*2D@>PT*("`@("`@("`@("`@
M0'5N;&EN:R@G<G5N+71E<W1S+FQO9R<I.PT*("`@("`@("!]#0H@("`@("`@
M("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G5$]404P@5$E-13H@)R`N("1T;W1A
M;"D[#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82AC;W5N="@D<&%S
M<V5D*2`N("<@4$%34T5$(%1%4U13)RP@)&-O;6UA;F0I.PT*("`@("`@("`D
M=&AI<RT^=6DM/F]U='!U=$1A=&$H8V]U;G0H)'-K:7!P960I("X@)R!32TE0
M4$5$(%1%4U13)RP@)&-O;6UA;F0I.PT*("`@("`@("!I9B`H8V]U;G0H)&9A
M:6QE9"DI('L-"B`@("`)"21T:&ES+3YU:2T^;W5T<'5T1&%T82AC;W5N="@D
M9F%I;&5D*2`N("<@1D%)3$5$(%1%4U13.B<L("1C;VUM86YD*3L-"B`@("`@
M("`@"69O<F5A8V@@*"1F86EL960@87,@)&9A:6QU<F4I('L-"B`@("`@("`@
M"0DD=&AI<RT^=6DM/F]U='!U=$1A=&$H)&9A:6QU<F4L("1C;VUM86YD*3L-
M"B`@("`@("`@"7T-"B`@("`@("`@?0T*#0H@("`@("`@(')E='5R;B!T<G5E
M.PT*("`@('T-"B`@("`O+R!]?7T-"GT-"@T*/SX-"@``````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+T%U=&@N>&UL````````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,38U,"`Q,#4Q-30S,S<S
M,2`P,C(R,38`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/&-O;6UA;F1S('9E<G-I;VX](C$N,"(^#0H@/&QO9VEN/@T*("`\
M<W5M;6%R>3Y#;VYN96-T<R!A;F0@875T:&5N=&EC871E<R!T;R!R96UO=&4@
M<V5R=F5R/"]S=6UM87)Y/@T*("`\<VAO<G1C=70^;&D\+W-H;W)T8W5T/@T*
M("`\9G5N8W1I;VX^9&],;V=I;CPO9G5N8W1I;VX^#0H@(#QO<'1I;VYS("\^
M#0H@(#QD;V,^#0I,;V<@:6X@=&\@=&AE(')E;6]T92!S97)V97(N("!4;R!U
M<V4@<F5M;W1E(&9U;F-T:6]N<R!I;B!T:&4@:6YS=&%L;&5R#0IT:&%T(')E
M<75I<F4@86YY(&MI;F0@;V8@<')I=FEL96=E<RP@>6]U(&YE960@=&\@;&]G
M(&EN(&9I<G-T+B`@5&AE#0IU<V5R;F%M92!A;F0@<&%S<W=O<F0@>6]U(&5N
M=&5R(&AE<F4@=VEL;"!B92!S=&]R960@:6X@>6]U<B!P97(M=7-E<@T*4$5!
M4B!C;VYF:6=U<F%T:6]N("A^+RYP96%R<F,@;VX@56YI>"UL:6ME('-Y<W1E
M;7,I+B`@069T97(@;&]G9VEN9PT*:6XL('EO=7(@=7-E<FYA;64@86YD('!A
M<W-W;W)D('=I;&P@8F4@<V5N="!A;&]N9R!I;B!S=6)S97%U96YT#0IO<&5R
M871I;VYS(&]N('1H92!R96UO=&4@<V5R=F5R+CPO9&]C/@T*(#PO;&]G:6X^
M#0H@/&QO9V]U=#X-"B`@/'-U;6UA<GD^3&]G<R!O=70@9G)O;2!T:&4@<F5M
M;W1E('-E<G9E<CPO<W5M;6%R>3X-"B`@/'-H;W)T8W5T/FQO/"]S:&]R=&-U
M=#X-"B`@/&9U;F-T:6]N/F1O3&]G;W5T/"]F=6YC=&EO;CX-"B`@/&]P=&EO
M;G,@+SX-"B`@/&1O8SX-"DQO9W,@;W5T(&9R;VT@=&AE(')E;6]T92!S97)V
M97(N("!4:&ES(&-O;6UA;F0@9&]E<R!N;W0@86-T=6%L;'D-"F-O;FYE8W0@
M=&\@=&AE(')E;6]T92!S97)V97(L(&ET(&]N;'D@9&5L971E<R!T:&4@<W1O
M<F5D('5S97)N86UE(&%N9`T*<&%S<W=O<F0@9G)O;2!Y;W5R('5S97(@8V]N
M9FEG=7)A=&EO;BX\+V1O8SX-"B`\+VQO9V]U=#X-"CPO8V]M;6%N9',^````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+T%U=&@N<&AP
M````````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,S`U,"`Q,#4Q
M-30S,S<S,2`P,C(R,#(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`-"B\J*@T*("H@4$5!4E]#;VUM86YD7T%U=&@@
M*&QO9VEN+"!L;V=O=70@8V]M;6%N9',I#0H@*@T*("H@4$A0('9E<G-I;VYS
M(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES
M('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@
M*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@
M8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O
M(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A
M(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A
M(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*
M("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK
M96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@
M/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H
M92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I
M;VX@("`@0U93.B`D260Z($%U=&@N<&AP+'8@,2XR,R`R,#`V+S`S+S`R(#$X
M.C$T.C$S(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E
M87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@
M879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,"XQ#0H@*B\-"@T*+RHJ#0H@*B!B
M87-E(&-L87-S#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!4B]#;VUM86YD+T-O
M;6UO;BYP:'`G.PT*<F5Q=6ER95]O;F-E("=014%2+T-O;F9I9RYP:'`G.PT*
M#0HO*BH-"B`J(%!%05(@8V]M;6%N9',@9F]R(&QO9VEN+VQO9V]U=`T*("H-
M"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J
M($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X-"B`J($!A
M=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C
M;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS
M92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@
M3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@
M*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!
M4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A
M<V4@,"XQ#0H@*B\-"F-L87-S(%!%05)?0V]M;6%N9%]!=71H(&5X=&5N9',@
M4$5!4E]#;VUM86YD7T-O;6UO;@T*>PT*("`@("\O('M[>R!P<F]P97)T:65S
M#0H-"B`@("!V87(@)&-O;6UA;F1S(#T@87)R87DH#0H@("`@("`@("=L;V=I
M;B<@/3X@87)R87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)T-O;FYE
M8W1S(&%N9"!A=71H96YT:6-A=&5S('1O(')E;6]T92!S97)V97(G+`T*("`@
M("`@("`@("`@)W-H;W)T8W5T)R`]/B`G;&DG+`T*("`@("`@("`@("`@)V9U
M;F-T:6]N)R`]/B`G9&],;V=I;B<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@
M/3X@87)R87DH*2P-"B`@("`@("`@("`@("=D;V,G(#T^("<-"DQO9R!I;B!T
M;R!T:&4@<F5M;W1E('-E<G9E<BX@(%1O('5S92!R96UO=&4@9G5N8W1I;VYS
M(&EN('1H92!I;G-T86QL97(-"G1H870@<F5Q=6ER92!A;GD@:VEN9"!O9B!P
M<FEV:6QE9V5S+"!Y;W4@;F5E9"!T;R!L;V<@:6X@9FER<W0N("!4:&4-"G5S
M97)N86UE(&%N9"!P87-S=V]R9"!Y;W4@96YT97(@:&5R92!W:6QL(&)E('-T
M;W)E9"!I;B!Y;W5R('!E<BUU<V5R#0I014%2(&-O;F9I9W5R871I;VX@*'XO
M+G!E87)R8R!O;B!5;FEX+6QI:V4@<WES=&5M<RDN("!!9G1E<B!L;V=G:6YG
M#0II;BP@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0@=VEL;"!B92!S96YT
M(&%L;VYG(&EN('-U8G-E<75E;G0-"F]P97)A=&EO;G,@;VX@=&AE(')E;6]T
M92!S97)V97(N)RP-"B`@("`@("`@("`@("DL#0H@("`@("`@("=L;V=O=70G
M(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=,;V=S(&]U
M="!F<F]M('1H92!R96UO=&4@<V5R=F5R)RP-"B`@("`@("`@("`@("=S:&]R
M=&-U="<@/3X@)VQO)RP-"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O
M3&]G;W5T)RP-"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@I+`T*
M("`@("`@("`@("`@)V1O8R<@/3X@)PT*3&]G<R!O=70@9G)O;2!T:&4@<F5M
M;W1E('-E<G9E<BX@(%1H:7,@8V]M;6%N9"!D;V5S(&YO="!A8W1U86QL>0T*
M8V]N;F5C="!T;R!T:&4@<F5M;W1E('-E<G9E<BP@:70@;VYL>2!D96QE=&5S
M('1H92!S=&]R960@=7-E<FYA;64@86YD#0IP87-S=V]R9"!F<F]M('EO=7(@
M=7-E<B!C;VYF:6=U<F%T:6]N+B<L#0H@("`@("`@("`@("`I#0H-"B`@("`@
M("`@*3L-"@T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R
M#0H-"B`@("`O*BH-"B`@("`@*B!014%27T-O;6UA;F1?075T:"!C;VYS=')U
M8W1O<BX-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@4$5!4E]#;VUM86YD7T%U=&@H)B1U:2P@)B1C;VYF
M:6<I#0H@("`@>PT*("`@("`@("!P87)E;G0Z.E!%05)?0V]M;6%N9%]#;VUM
M;VXH)'5I+"`D8V]N9FEG*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*("`@
M("\O('M[>R!D;TQO9VEN*"D-"@T*("`@("\J*@T*("`@("`J($5X96-U=&4@
M=&AE("=L;V=I;B<@8V]M;6%N9"X-"B`@("`@*@T*("`@("`J($!P87)A;2!S
M=')I;F<@)&-O;6UA;F0@8V]M;6%N9"!N86UE#0H@("`@("H-"B`@("`@*B!`
M<&%R86T@87)R87D@)&]P=&EO;G,@;W!T:6]N7VYA;64@/3X@=F%L=64-"B`@
M("`@*@T*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US(&QI<W0@;V8@861D
M:71I;VYA;"!P87)A;65T97)S#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&)O
M;VP@5%)512!O;B!S=6-C97-S(&]R#0H@("`@("H@82!014%2(&5R<F]R(&]N
M(&9A:6QU<F4-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@9&],;V=I;B@D8V]M;6%N9"P@)&]P=&EO;G,L
M("1P87)A;7,I#0H@("`@>PT*("`@("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF
M:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@("1C:&%N;F5L(#T@)'1H:7,M
M/F-O;F9I9RT^9V5T*"=D969A=6QT7V-H86YN96PG*3L-"B`@("`@("`@)&-H
M86X@/2`D<F5G+3YG971#:&%N;F5L*"1C:&%N;F5L*3L-"B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&-H86XI*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H)&-H86XI.PT*("`@("`@("!]#0H@("`@("`@
M("1S97)V97(@/2`D=&AI<RT^8V]N9FEG+3YG970H)W!R969E<G)E9%]M:7)R
M;W(G*3L-"B`@("`@("`@)')E;6]T92`]("8D=&AI<RT^8V]N9FEG+3YG9712
M96UO=&4H*3L-"B`@("`@("`@)'5S97)N86UE(#T@)'1H:7,M/F-O;F9I9RT^
M9V5T*"=U<V5R;F%M92<I.PT*("`@("`@("!I9B`H96UP='DH)'5S97)N86UE
M*2D@>PT*("`@("`@("`@("`@)'5S97)N86UE(#T@0"1?14Y66R=54T52)UT[
M#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"),
M;V=G:6YG(&EN('1O("1S97)V97(N(BP@)&-O;6UA;F0I.PT*("`@("`@("`-
M"B`@("`@("`@;&ES="@D=7-E<FYA;64L("1P87-S=V]R9"D@/2`D=&AI<RT^
M=6DM/G5S97)$:6%L;V<H#0H@("`@("`@("`@("`D8V]M;6%N9"P-"B`@("`@
M("`@("`@(&%R<F%Y*"=5<V5R;F%M92<L("=087-S=V]R9"<I+`T*("`@("`@
M("`@("`@87)R87DH)W1E>'0G+"`@("`@)W!A<W-W;W)D)RDL#0H@("`@("`@
M("`@("!A<G)A>2@D=7-E<FYA;64L("`G)RD-"B`@("`@("`@("`@("D[#0H@
M("`@("`@("1U<V5R;F%M92`]('1R:6TH)'5S97)N86UE*3L-"B`@("`@("`@
M)'!A<W-W;W)D(#T@=')I;2@D<&%S<W=O<F0I.PT*("`@("`@("`-"B`@("`@
M("`@)'1H:7,M/F-O;F9I9RT^<V5T*"=U<V5R;F%M92<L("1U<V5R;F%M92D[
M#0H@("`@("`@("1T:&ES+3YC;VYF:6<M/G-E="@G<&%S<W=O<F0G+"`D<&%S
M<W=O<F0I.PT*#0H@("`@("`@(&EF("@D8VAA;BT^<W5P<&]R='-215-4*"DI
M('L-"B`@("`@("`@("`@("1O:R`]('1R=64[#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`D<F5M;W1E+3YE>'!E8W1%<G)O<B@T,#$I.PT*("`@
M("`@("`@("`@)&]K(#T@)')E;6]T92T^8V%L;"@G;&]G:6YT97-T)RD[#0H@
M("`@("`@("`@("`D<F5M;W1E+3YP;W!%>'!E8W0H*3L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H)&]K(#T]/2!T<G5E*2![#0H@("`@("`@("`@("`D=&AI
M<RT^=6DM/F]U='!U=$1A=&$H(DQO9V=E9"!I;BXB+"`D8V]M;6%N9"D[#0H@
M("`@("`@("`@("`D=&AI<RT^8V]N9FEG+3YS=&]R92@I.PT*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*"),;V=I;B!F86EL960A(BD[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N
M('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&1O3&]G
M;W5T*"D-"@T*("`@("\J*@T*("`@("`J($5X96-U=&4@=&AE("=L;V=O=70G
M(&-O;6UA;F0N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VUM
M86YD(&-O;6UA;F0@;F%M90T*("`@("`J#0H@("`@("H@0'!A<F%M(&%R<F%Y
M("1O<'1I;VYS(&]P=&EO;E]N86UE(#T^('9A;'5E#0H@("`@("H-"B`@("`@
M*B!`<&%R86T@87)R87D@)'!A<F%M<R!L:7-T(&]F(&%D9&ET:6]N86P@<&%R
M86UE=&5R<PT*("`@("`J#0H@("`@("H@0')E='5R;B!B;V]L(%12544@;VX@
M<W5C8V5S<R!O<@T*("`@("`J(&$@4$5!4B!E<G)O<B!O;B!F86EL=7)E#0H@
M("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U
M;F-T:6]N(&1O3&]G;W5T*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-
M"B`@("![#0H@("`@("`@("1R96<@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G
M:7-T<GDH*3L-"B`@("`@("`@)&-H86YN96P@/2`D=&AI<RT^8V]N9FEG+3YG
M970H)V1E9F%U;'1?8VAA;FYE;"<I.PT*("`@("`@("`D8VAA;B`]("1R96<M
M/F=E=$-H86YN96PH)&-H86YN96PI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D8VAA;BDI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@D8VAA;BD[#0H@("`@("`@('T-"B`@("`@("`@)'-E<G9E<B`]
M("1T:&ES+3YC;VYF:6<M/F=E="@G<')E9F5R<F5D7VUI<G)O<B<I.PT*("`@
M("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H(DQO9V=I;F<@;W5T(&9R;VT@
M)'-E<G9E<BXB+"`D8V]M;6%N9"D[#0H@("`@("`@("1T:&ES+3YC;VYF:6<M
M/G)E;6]V92@G=7-E<FYA;64G*3L-"B`@("`@("`@)'1H:7,M/F-O;F9I9RT^
M<F5M;W9E*"=P87-S=V]R9"<I.PT*("`@("`@("`D=&AI<RT^8V]N9FEG+3YS
M=&]R92@I.PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O
M+R!]?7T-"GT-"@T*/SX`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+U)%4U0`````````````````````
M````````````````````````````````````````````````````````````
M`#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S
M-S,Q(#`Q-S<Q,0`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O4D53
M5"\Q,2YP:'``````````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,3<T-C8@,3`U,34T,S,W,S$@,#(P-S0P`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP#0HO*BH-"B`J(%!%05)?
M4D535%\Q,2`M(&EM<&QE;65N="!F87-T97(@;&ES="UA;&PO<F5M;W1E+6QI
M<W0@8V]M;6%N9`T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*
M("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E
M<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I
M;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO
M=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N
M='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H
M92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR
M;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N
M<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@
M(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP
M+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P
M#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S
M7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@
M)$ED.B`Q,2YP:'`L=B`Q+C0@,C`P-B\P,2\P-B`P-#HT-SHS-R!C96QL;V<@
M17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC
M92!296QE87-E(#$N-"XS#0H@*B\-"@T*+RHJ#0H@*B!&;W(@9&]W;FQO861I
M;F<@4D535"!X;6PO='AT(&9I;&5S#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!
M4B]215-4+G!H<"<[#0H-"B\J*@T*("H@26UP;&5M96YT(%)%4U0@,2XQ#0H@
M*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*
M("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*
M("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L
M:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@
M(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT
M+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G
M92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@
M4F5L96%S92`Q+C0N,PT*("HO#0IC;&%S<R!014%27U)%4U1?,3$-"GL-"B`@
M("`O*BH-"B`@("`@*B!`=F%R(%!%05)?4D535`T*("`@("`J+PT*("`@('9A
M<B`D7W)E<W0[#0H-"B`@("!F=6YC=&EO;B!014%27U)%4U1?,3$H)&-O;F9I
M9RP@)&]P=&EO;G,@/2!A<G)A>2@I*0T*("`@('L-"B`@("`@("`@)'1H:7,M
M/E]R97-T(#T@)FYE=R!014%27U)%4U0H)&-O;F9I9RP@)&]P=&EO;G,I.PT*
M("`@('T-"@T*("`@(&9U;F-T:6]N(&QI<W1!;&PH)&)A<V4L("1D;W-T86)L
M92P@)&)A<VEC(#T@=')U92D-"B`@("![#0H@("`@("`@("1C871E9V]R>6QI
M<W0@/2`D=&AI<RT^7W)E<W0M/G)E=')I979E1&%T82@D8F%S92`N("=C+V-A
M=&5G;W)I97,N>&UL)RD[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1C
M871E9V]R>6QI<W0I*2![#0H@("`@("`@("`@("!R971U<FX@)&-A=&5G;W)Y
M;&ES=#L-"B`@("`@("`@?0T*("`@("`@("`D<F5T(#T@87)R87DH*3L-"B`@
M("`@("`@:68@*"%I<U]A<G)A>2@D8V%T96=O<GEL:7-T6R=C)UTI*2![#0H@
M("`@("`@("`@("`D8V%T96=O<GEL:7-T6R=C)UT@/2!A<G)A>2@D8V%T96=O
M<GEL:7-T6R=C)UTI.PT*("`@("`@("!]#0H@("`@("`@(%!%05(Z.G!U<VA%
M<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@9F]R
M96%C:"`H)&-A=&5G;W)Y;&ES=%LG8R==(&%S("1P<F]G<F5S<R`]/B`D8V%T
M96=O<GDI('L-"B`@("`@("`@("`@("1C871E9V]R>2`]("1C871E9V]R>5LG
M7V-O;G1E;G0G73L-"B`@("`@("`@("`@("1P86-K86=E<VEN9F\@/2`D=&AI
M<RT^7W)E<W0M/G)E=')I979E1&%T82@D8F%S92`N#0H@("`@("`@("`@("`@
M("`@)V,O)R`N('5R;&5N8V]D92@D8V%T96=O<GDI("X@)R]P86-K86=E<VEN
M9F\N>&UL)RD[#0H@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<&%C
M:V%G97-I;F9O*2D@>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D<&%C:V%G
M97-I;F9O*2!\?"`A:7-S970H)'!A8VMA9V5S:6YF;ULG<&DG72DI('L-"B`@
M("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&EF("@A:7-?87)R87DH)'!A8VMA9V5S:6YF;ULG<&DG72D@?'P@
M(6ES<V5T*"1P86-K86=E<VEN9F];)W!I)UU;,%TI*2![#0H@("`@("`@("`@
M("`@("`@)'!A8VMA9V5S:6YF;ULG<&DG72`](&%R<F%Y*"1P86-K86=E<VEN
M9F];)W!I)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C
M:"`H)'!A8VMA9V5S:6YF;ULG<&DG72!A<R`D<&%C:V%G96EN9F\I('L-"B`@
M("`@("`@("`@("`@("`D:6YF;R`]("1P86-K86=E:6YF;ULG<"==.PT*("`@
M("`@("`@("`@("`@("1P86-K86=E(#T@)&EN9F];)VXG73L-"B`@("`@("`@
M("`@("`@("`D<F5L96%S97,@/2!I<W-E="@D<&%C:V%G96EN9F];)V$G72D@
M/R`D<&%C:V%G96EN9F];)V$G72`Z(&9A;'-E.PT*("`@("`@("`@("`@("`@
M('5N<V5T*"1L871E<W0I.PT*("`@("`@("`@("`@("`@('5N<V5T*"1U;G-T
M86)L92D[#0H@("`@("`@("`@("`@("`@=6YS970H)'-T86)L92D[#0H@("`@
M("`@("`@("`@("`@=6YS970H)'-T871E*3L-"B`@("`@("`@("`@("`@("!I
M9B`H)')E;&5A<V5S*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)')E;&5A<V5S6R=R)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D<F5L96%S97-;)W(G72`](&%R<F%Y*"1R96QE87-E<ULG<B==*3L-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!F
M;W)E86-H("@D<F5L96%S97-;)W(G72!A<R`D<F5L96%S92D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;&%T97-T*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D9&]S=&%B;&4@)B8@)')E
M;&5A<V5;)W,G72`]/2`G<W1A8FQE)RD@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D;&%T97-T(#T@)')E;&5A<V5;)W8G73L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-T871E(#T@)W-T86)L92<[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@A)&1O<W1A8FQE*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1L871E<W0@/2`D<F5L96%S95LG=B==
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<W1A=&4@/2`D
M<F5L96%S95LG<R==.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)'-T86)L92D@)B8@)')E;&5A<V5;)W,G72`]
M/2`G<W1A8FQE)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S
M=&%B;&4@/2`D<F5L96%S95LG=B==.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)'5N<W1A8FQE*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=6YS=&%B;&4@/2`D<W1A8FQE.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H
M)'5N<W1A8FQE*2`F)B`D<F5L96%S95LG<R==("$]("=S=&%B;&4G*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&QA=&5S="`]("1U;G-T86)L
M92`]("1R96QE87-E6R=V)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'-T871E(#T@)')E;&5A<V5;)W,G73L-"B`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M;&%T97-T*2`F)B`A:7-S970H)'-T871E*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1S=&%T92`]("1R96QE87-E6R=S)UT[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)&QA=&5S="D@)B8@:7-S970H)'-T86)L92D@)B8@:7-S970H
M)'5N<W1A8FQE*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(&EF("@D8F%S:6,I('L@+R\@<F5M;W1E+6QI<W0@8V]M;6%N9`T*("`@("`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1L871E<W0I*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D;&%T97-T(#T@9F%L<V4[#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)')E=%LD<&%C:V%G
M95T@/2!A<G)A>2@G<W1A8FQE)R`]/B`D;&%T97-T*3L-"B`@("`@("`@("`@
M("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("\O(&QI<W0M86QL(&-O;6UA;F0-"B`@("`@("`@("`@("`@
M("`D9&5P<R`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D=6YS=&%B;&4I*2![#0H@("`@("`@("`@("`@("`@("`@("1U;G-T86)L
M92`](&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("`D<W1A=&4@/2`G<W1A
M8FQE)SL-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1S=&%B;&4I
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D;&%T97-T(#T@)'5N<W1A
M8FQE(#T@)'-T86)L93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1L871E
M<W0@/2`D=6YS=&%B;&4[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)&QA=&5S="DI('L-"B`@("`@("`@("`@("`@
M("`@("`@)&QA=&5S="`](&9A;'-E.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!I9B`H)&QA=&5S="D@>PT*("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)'!A8VMA9V5I;F9O6R=D97!S)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1P86-K86=E:6YF
M;ULG9&5P<R==*2!\?`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(6ES<V5T*"1P86-K86=E:6YF;ULG9&5P<R==6S!=*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1P86-K86=E:6YF;ULG9&5P<R==(#T@87)R
M87DH)'!A8VMA9V5I;F9O6R=D97!S)UTI.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("1D(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1P86-K86=E:6YF;ULG9&5P<R==(&%S("1D97`I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@D9&5P6R=V)UT@/3T@)&QA=&5S="D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D(#T@=6YS97)I86QI>F4H
M)&1E<%LG9"==*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H)&0I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9%LG<F5Q
M=6ER960G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M(6-L87-S7V5X:7-T<R@G4$5!4E]086-K86=E1FEL95]V,B<I*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!
M4B]086-K86=E1FEL92]V,BYP:'`G.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1P9BDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!F(#T@;F5W(%!%05)?4&%C:V%G949I;&5?=C([#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1P9BT^<V5T1&5P<R@D9"D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1D97!S(#T@)'!F+3YG971$97!S*"D[#0H@("`@("`@("`@("`@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T9&5P<R`]("1D.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1D97!S(&%S("1D97`I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&1E<%LG='EP
M92==("$]/2`G<&MG)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E<'-;72`]("1D97`[
M#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D<W1A8FQE*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<W1A
M8FQE(#T@)RUN+V$M)SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@)&EN9F\@/2!A<G)A>2@G<W1A8FQE)R`]/B`D;&%T97-T+"`G<W5M
M;6%R>2<@/3X@)&EN9F];)W,G72P-"B`@("`@("`@("`@("`@("`@("`@)V1E
M<V-R:7!T:6]N)R`]/@T*("`@("`@("`@("`@("`@("`@("`D:6YF;ULG9"==
M+"`G9&5P<R<@/3X@)&1E<',L("=C871E9V]R>2<@/3X@)&EN9F];)V-A)UU;
M)U]C;VYT96YT)UTL#0H@("`@("`@("`@("`@("`@("`@("=U;G-T86)L92<@
M/3X@)'5N<W1A8FQE+"`G<W1A=&4G(#T^("1S=&%T92D[#0H@("`@("`@("`@
M("`@("`@)')E=%LD<&%C:V%G95T@/2`D:6YF;SL-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("!014%2.CIP;W!%<G)O<DAA;F1L:6YG*"D[
M#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*("`@("\J*@T*("`@
M("`J(%)E='5R;B!A;B!A<G)A>2!C;VYT86EN:6YG(&%L;"!O9B!T:&4@<W1A
M=&5S('1H870@87)E(&UO<F4@<W1A8FQE('1H86X-"B`@("`@*B!O<B!E<75A
M;"!T;R!T:&4@<&%S<V5D(&EN('-T871E#0H@("`@("H-"B`@("`@*B!`<&%R
M86T@<W1R:6YG(%)E;&5A<V4@<W1A=&4-"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B!$971E<FUI;F5S('=H971H97(@=&\@:6YC;'5D92`D<W1A=&4@:6X@=&AE
M(&QI<W0-"B`@("`@*B!`<F5T=7)N(&9A;'-E?&%R<F%Y($9A;'-E(&EF("1S
M=&%T92!I<R!N;W0@82!V86QI9"!R96QE87-E('-T871E#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@8F5T=&5R4W1A=&5S*"1S=&%T92P@)&EN8VQU9&4@/2!F
M86QS92D-"B`@("![#0H@("`@("`@('-T871I8R`D<W1A=&5S(#T@87)R87DH
M)W-N87!S:&]T)RP@)V1E=F5L)RP@)V%L<&AA)RP@)V)E=&$G+"`G<W1A8FQE
M)RD[#0H@("`@("`@("1I(#T@87)R87E?<V5A<F-H*"1S=&%T92P@)'-T871E
M<RD[#0H@("`@("`@(&EF("@D:2`]/3T@9F%L<V4I('L-"B`@("`@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&EN8VQU
M9&4I('L-"B`@("`@("`@("`@("1I+2T[#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N(&%R<F%Y7W-L:6-E*"1S=&%T97,L("1I("L@,2D[#0H@("`@?0T*
M?0T*/SX`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]014%2+U)%4U0O,3`N<&AP````````````````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#8Q,S`R(#$P-3$U-#,S-S,Q(#`R,#<R
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`T*+RHJ#0H@*B!014%27U)%4U1?,3`-"B`J#0H@*B!02%`@=F5R<VEO
M;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@
M:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-
M"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M
M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@
M82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@
M=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD
M(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U
M(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R
M#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E
M879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P
M,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`
M=F5R<VEO;B`@("!#5E,Z("1)9#H@,3`N<&AP+'8@,2XT,"`R,#`V+S`Q+S`V
M(#`T.C0W.C,W(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I
M;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,3(-"B`J+PT*#0HO
M*BH-"B`J($9O<B!D;W=N;&]A9&EN9R!215-4('AM;"]T>'0@9FEL97,-"B`J
M+PT*<F5Q=6ER95]O;F-E("=014%2+U)%4U0N<&AP)SL-"@T*+RHJ#0H@*B!)
M;7!L96UE;G0@4D535"`Q+C`-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@
M*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E
M<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@
M5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R
M<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L
M87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP83$R#0H@*B\-"F-L
M87-S(%!%05)?4D535%\Q,`T*>PT*("`@("\J*@T*("`@("`J($!V87(@4$5!
M4E]215-4#0H@("`@("HO#0H@("`@=F%R("1?<F5S=#L-"B`@("!F=6YC=&EO
M;B!014%27U)%4U1?,3`H)&-O;F9I9RP@)&]P=&EO;G,@/2!A<G)A>2@I*0T*
M("`@('L-"B`@("`@("`@)'1H:7,M/E]R97-T(#T@)FYE=R!014%27U)%4U0H
M)&-O;F9I9RP@)&]P=&EO;G,I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E
M=$1O=VYL;V%D55),*"1B87-E+"`D<&%C:V%G96EN9F\L("1P<F5F<W1A=&4L
M("1I;G-T86QL960I#0H@("`@>PT*("`@("`@("`D8VAA;FYE;"`]("1P86-K
M86=E:6YF;ULG8VAA;FYE;"==.PT*("`@("`@("`D<&%C:V%G92`]("1P86-K
M86=E:6YF;ULG<&%C:V%G92==.PT*("`@("`@("`D<W1A=&5S(#T@)'1H:7,M
M/F)E='1E<E-T871E<R@D<')E9G-T871E+"!T<G5E*3L-"B`@("`@("`@:68@
M*"$D<W1A=&5S*2![#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@G(B<@+B`D<')E9G-T871E("X@)R(@:7,@;F]T(&$@=F%L:60@<W1A
M=&4G*3L-"B`@("`@("`@?0T*("`@("`@("`D<W1A=&4@/2`D=F5R<VEO;B`]
M(&YU;&P[#0H@("`@("`@(&EF("AI<W-E="@D<&%C:V%G96EN9F];)W-T871E
M)UTI*2![#0H@("`@("`@("`@("`D<W1A=&4@/2`D<&%C:V%G96EN9F];)W-T
M871E)UT[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1P86-K86=E
M:6YF;ULG=F5R<VEO;B==*2D@>PT*("`@("`@("`@("`@)'9E<G-I;VX@/2`D
M<&%C:V%G96EN9F];)W9E<G-I;VXG73L-"B`@("`@("`@?0T*("`@("`@("`D
M:6YF;R`]("1T:&ES+3Y?<F5S="T^<F5T<FEE=F5$871A*"1B87-E("X@)W(O
M)R`N('-T<G1O;&]W97(H)'!A8VMA9V4I("X@)R]A;&QR96QE87-E<RYX;6PG
M*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&EN9F\I*2![#0H@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G3F\@<F5L96%S97,@
M879A:6QA8FQE(&9O<B!P86-K86=E("(G("X-"B`@("`@("`@("`@("`@("`D
M8VAA;FYE;"`N("<O)R`N("1P86-K86=E("X@)R(G*3L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H(6ES<V5T*"1I;F9O6R=R)UTI*2![#0H@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)&9O=6YD(#T@
M9F%L<V4[#0H@("`@("`@("1R96QE87-E(#T@9F%L<V4[#0H@("`@("`@(&EF
M("@A:7-?87)R87DH)&EN9F];)W(G72D@?'P@(6ES<V5T*"1I;F9O6R=R)UU;
M,%TI*2![#0H@("`@("`@("`@("`D:6YF;ULG<B==(#T@87)R87DH)&EN9F];
M)W(G72D[#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H)&EN9F];)W(G
M72!A<R`D<F5L96%S92D@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI
M<RT^7W)E<W0M/E]O<'1I;VYS6R=F;W)C92==*2`F)B`H)&EN<W1A;&QE9"`F
M)@T*("`@("`@("`@("`@("`@("`@=F5R<VEO;E]C;VUP87)E*"1R96QE87-E
M6R=V)UTL("1I;G-T86QL960L("<\)RDI*2![#0H@("`@("`@("`@("`@("`@
M8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S
M970H)'-T871E*2D@>PT*("`@("`@("`@("`@("`@(&EF("@D<F5L96%S95LG
M<R==(#T]("1S=&%T92D@>PT*("`@("`@("`@("`@("`@("`@("`D9F]U;F0@
M/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!](&5L<V5I9B`H:7-S970H)'9E<G-I
M;VXI*2![#0H@("`@("`@("`@("`@("`@:68@*"1R96QE87-E6R=V)UT@/3T@
M)'9E<G-I;VXI('L-"B`@("`@("`@("`@("`@("`@("`@)&9O=6YD(#T@=')U
M93L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!I
M9B`H:6Y?87)R87DH)')E;&5A<V5;)W,G72P@)'-T871E<RDI('L-"B`@("`@
M("`@("`@("`@("`@("`@)&9O=6YD(#T@=')U93L-"B`@("`@("`@("`@("`@
M("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D=&AI<RT^7W)E='5R;D1O
M=VYL;V%D55),*"1B87-E+"`D<&%C:V%G92P@)')E;&5A<V4L("1I;F9O+"`D
M9F]U;F0I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$1E<$1O=VYL;V%D
M55),*"1B87-E+"`D>'-D=F5R<VEO;BP@)&1E<&5N9&5N8WDL("1D97!P86-K
M86=E+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<F5F<W1A
M=&4@/2`G<W1A8FQE)RP@)&EN<W1A;&QE9"`](&9A;'-E*0T*("`@('L-"B`@
M("`@("`@)&-H86YN96P@/2`D9&5P96YD96YC>5LG8VAA;FYE;"==.PT*("`@
M("`@("`D<&%C:V%G92`]("1D97!E;F1E;F-Y6R=N86UE)UT[#0H@("`@("`@
M("1S=&%T97,@/2`D=&AI<RT^8F5T=&5R4W1A=&5S*"1P<F5F<W1A=&4L('1R
M=64I.PT*("`@("`@("!I9B`H(21S=&%T97,I('L-"B`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*"<B)R`N("1P<F5F<W1A=&4@+B`G(B!I
M<R!N;W0@82!V86QI9"!S=&%T92<I.PT*("`@("`@("!]#0H@("`@("`@("1S
M=&%T92`]("1V97)S:6]N(#T@;G5L;#L-"B`@("`@("`@:68@*&ES<V5T*"1P
M86-K86=E:6YF;ULG<W1A=&4G72DI('L-"B`@("`@("`@("`@("1S=&%T92`]
M("1P86-K86=E:6YF;ULG<W1A=&4G73L-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H:7-S970H)'!A8VMA9V5I;F9O6R=V97)S:6]N)UTI*2![#0H@("`@("`@
M("`@("`D=F5R<VEO;B`]("1P86-K86=E:6YF;ULG=F5R<VEO;B==.PT*("`@
M("`@("!]#0H@("`@("`@("1I;F9O(#T@)'1H:7,M/E]R97-T+3YR971R:65V
M941A=&$H)&)A<V4@+B`G<B\G("X@<W1R=&]L;W=E<B@D<&%C:V%G92D@+B`G
M+V%L;')E;&5A<V5S+GAM;"<I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D:6YF;RDI('L-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*"=086-K86=E("(G("X@)&1E<'!A8VMA9V5;)V-H86YN96PG72`N("<O
M)R`N("1D97!P86-K86=E6R=P86-K86=E)UT-"B`@("`@("`@("`@("`@("`N
M("<B(&1E<&5N9&5N8WD@(B<@+B`D8VAA;FYE;"`N("<O)R`N("1P86-K86=E
M("X@)R(@:&%S(&YO(')E;&5A<V5S)RD[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*"%I<U]A<G)A>2@D:6YF;RD@?'P@(6ES<V5T*"1I;F9O6R=R)UTI*2![
M#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@
M("`@)&5X8VQU9&4@/2!A<G)A>2@I.PT*("`@("`@("`D;6EN(#T@)&UA>"`]
M("1R96-O;6UE;F1E9"`](&9A;'-E.PT*("`@("`@("!I9B`H)'AS9'9E<G-I
M;VX@/3T@)S$N,"<I('L-"B`@("`@("`@("`@("1P:6YF;ULG<&%C:V%G92==
M(#T@)&1E<&5N9&5N8WE;)VYA;64G73L-"B`@("`@("`@("`@("1P:6YF;ULG
M8VAA;FYE;"==(#T@)W!E87(N<&AP+FYE="<[("\O('1H:7,@:7,@86QW87ES
M('1R=64@+2!D;VXG="!C:&%N9V4@=&AI<PT*("`@("`@("`@("`@<W=I=&-H
M("@D9&5P96YD96YC>5LG<F5L)UTI('L-"B`@("`@("`@("`@("`@("!C87-E
M("=G92<@.@T*("`@("`@("`@("`@("`@("`@("`D;6EN(#T@)&1E<&5N9&5N
M8WE;)W9E<G-I;VXG73L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@
M("`@("`@("`@("!C87-E("=G="<@.@T*("`@("`@("`@("`@("`@("`@("`D
M;6EN(#T@)&1E<&5N9&5N8WE;)W9E<G-I;VXG73L-"B`@("`@("`@("`@("`@
M("`@("`@)&5X8VQU9&4@/2!A<G)A>2@D9&5P96YD96YC>5LG=F5R<VEO;B==
M*3L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!C
M87-E("=E<2<@.@T*("`@("`@("`@("`@("`@("`@("`D<F5C;VUM96YD960@
M/2`D9&5P96YD96YC>5LG=F5R<VEO;B==.PT*("`@("`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@("`@(&-A<V4@)VQT)R`Z#0H@("`@("`@("`@
M("`@("`@("`@("1M87@@/2`D9&5P96YD96YC>5LG=F5R<VEO;B==.PT*("`@
M("`@("`@("`@("`@("`@("`D97AC;'5D92`](&%R<F%Y*"1D97!E;F1E;F-Y
M6R=V97)S:6]N)UTI.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@
M("`@("`@("`@(&-A<V4@)VQE)R`Z#0H@("`@("`@("`@("`@("`@("`@("1M
M87@@/2`D9&5P96YD96YC>5LG=F5R<VEO;B==.PT*("`@("`@("`@("`@("`@
M(&)R96%K.PT*("`@("`@("`@("`@("`@(&-A<V4@)VYE)R`Z#0H@("`@("`@
M("`@("`@("`@("`@("1E>&-L=61E(#T@87)R87DH)&1E<&5N9&5N8WE;)W9E
M<G-I;VXG72D[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D<&EN9F];)W!A
M8VMA9V4G72`]("1D97!E;F1E;F-Y6R=N86UE)UT[#0H@("`@("`@("`@("`D
M;6EN(#T@:7-S970H)&1E<&5N9&5N8WE;)VUI;B==*2`_("1D97!E;F1E;F-Y
M6R=M:6XG72`Z(&9A;'-E.PT*("`@("`@("`@("`@)&UA>"`](&ES<V5T*"1D
M97!E;F1E;F-Y6R=M87@G72D@/R`D9&5P96YD96YC>5LG;6%X)UT@.B!F86QS
M93L-"B`@("`@("`@("`@("1R96-O;6UE;F1E9"`](&ES<V5T*"1D97!E;F1E
M;F-Y6R=R96-O;6UE;F1E9"==*2`_#0H@("`@("`@("`@("`@("`@)&1E<&5N
M9&5N8WE;)W)E8V]M;65N9&5D)UT@.B!F86QS93L-"B`@("`@("`@("`@(&EF
M("AI<W-E="@D9&5P96YD96YC>5LG97AC;'5D92==*2D@>PT*("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)&1E<&5N9&5N8WE;)V5X8VQU9&4G75LP72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@)&5X8VQU9&4@/2!A<G)A>2@D9&5P
M96YD96YC>5LG97AC;'5D92==*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)&9O=6YD(#T@9F%L<V4[
M#0H@("`@("`@("1R96QE87-E(#T@9F%L<V4[#0H@("`@("`@(&EF("@A:7-?
M87)R87DH)&EN9F];)W(G72D@?'P@(6ES<V5T*"1I;F9O6R=R)UU;,%TI*2![
M#0H@("`@("`@("`@("`D:6YF;ULG<B==(#T@87)R87DH)&EN9F];)W(G72D[
M#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H)&EN9F];)W(G72!A<R`D
M<F5L96%S92D@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W)E
M<W0M/E]O<'1I;VYS6R=F;W)C92==*2`F)B`H)&EN<W1A;&QE9"`F)@T*("`@
M("`@("`@("`@("`@("`@=F5R<VEO;E]C;VUP87)E*"1R96QE87-E6R=V)UTL
M("1I;G-T86QL960L("<\)RDI*2![#0H@("`@("`@("`@("`@("`@8V]N=&EN
M=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:6Y?87)R87DH
M)')E;&5A<V5;)W8G72P@)&5X8VQU9&4I*2![("\O('-K:7`@97AC;'5D960@
M=F5R<VEO;G,-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("\O(&%L;&]W(&YE=V5R(')E;&5A<V5S('1O
M('-A>2`B22=M($]+('=I=&@@=&AE(&1E<&5N9&5N="!P86-K86=E(@T*("`@
M("`@("`@("`@:68@*"1X<V1V97)S:6]N(#T]("<R+C`G("8F(&ES<V5T*"1R
M96QE87-E6R=C;R==*2D@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-?87)R
M87DH)')E;&5A<V5;)V-O)UTI('Q\("%I<W-E="@D<F5L96%S95LG8V\G75LP
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@)')E;&5A<V5;)V-O)UT@/2!A
M<G)A>2@D<F5L96%S95LG8V\G72D[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1R96QE87-E6R=C;R==(&%S("1E;G1R
M>2D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&5N=')Y6R=X
M)UTI("8F("%I<U]A<G)A>2@D96YT<GE;)W@G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1E;G1R>5LG>"==(#T@87)R87DH)&5N=')Y6R=X)UTI
M.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H(6ES<V5T*"1E;G1R
M>5LG>"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&5N=')Y6R=X
M)UT@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@(&EF("@D96YT<GE;)V,G72`]/2`D9&5P<&%C:V%G95LG
M8VAA;FYE;"==("8F#0H@("`@("`@("`@("`@("`@("`@("`@("`@('-T<G1O
M;&]W97(H)&5N=')Y6R=P)UTI(#T]('-T<G1O;&]W97(H)&1E<'!A8VMA9V5;
M)W!A8VMA9V4G72D@)B8-"B`@("`@("`@("`@("`@("`@("`@("`@("`@=F5R
M<VEO;E]C;VUP87)E*"1D97!P86-K86=E6R=V97)S:6]N)UTL("1E;G1R>5LG
M;6EN)UTL("<^/2<I("8F#0H@("`@("`@("`@("`@("`@("`@("`@("`@('9E
M<G-I;VY?8V]M<&%R92@D9&5P<&%C:V%G95LG=F5R<VEO;B==+"`D96YT<GE;
M)VUA>"==+"`G/#TG*2`F)@T*("`@("`@("`@("`@("`@("`@("`@("`@("`A
M:6Y?87)R87DH)')E;&5A<V5;)W8G72P@)&5N=')Y6R=X)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D<F5C;VUM96YD960@/2`D<F5L96%S95LG
M=B==.PT*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!I9B`H)')E8V]M;65N9&5D*2![#0H@("`@("`@
M("`@("`@("`@:68@*"1R96QE87-E6R=V)UT@(3T@)')E8V]M;65N9&5D*2![
M("\O(&EF('=E('=A;G0@82!S<&5C:69I8PT*("`@("`@("`@("`@("`@("`@
M("`O+R!V97)S:6]N+"!T:&5N('-K:7`@86QL(&]T:&5R<PT*("`@("`@("`@
M("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6EN7V%R<F%Y*"1R96QE87-E
M6R=S)UTL("1S=&%T97,I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!T:&4@<W1A8FEL:71Y(&ES('1O;R!L;W<L(&)U="!W92!M=7-T(')E='5R
M;B!T:&4-"B`@("`@("`@("`@("`@("`@("`@("`@("\O(')E8V]M;65N9&5D
M('9E<G-I;VX@:68@<&]S<VEB;&4-"B`@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7W)E='5R;D1O=VYL;V%D55),*"1B87-E+"`D<&%C
M:V%G92P@)')E;&5A<V4L("1I;F9O+"!T<G5E*3L-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&EF("@D;6EN("8F('9E<G-I;VY?8V]M<&%R92@D<F5L96%S
M95LG=B==+"`D;6EN+"`G;'0G*2D@>R`O+R!S:VEP('1O;R!O;&0@=F5R<VEO
M;G,-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(&EF("@D;6%X("8F('9E<G-I;VY?8V]M<&%R92@D<F5L
M96%S95LG=B==+"`D;6%X+"`G9W0G*2D@>R`O+R!S:VEP('1O;R!N97<@=F5R
M<VEO;G,-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(&EF("@D:6YS=&%L;&5D("8F('9E<G-I;VY?8V]M
M<&%R92@D<F5L96%S95LG=B==+"`D:6YS=&%L;&5D+"`G/"<I*2![#0H@("`@
M("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!I9B`H:6Y?87)R87DH)')E;&5A<V5;)W,G72P@)'-T871E<RDI('L@
M+R\@:68@:6X@=&AE('!R969E<G)E9"!S=&%T92XN+@T*("`@("`@("`@("`@
M("`@("1F;W5N9"`]('1R=64[("\O("XN+B!T:&5N('5S92!I=`T*("`@("`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@(')E='5R;B`D=&AI<RT^7W)E='5R;D1O=VYL;V%D55),*"1B87-E
M+"`D<&%C:V%G92P@)')E;&5A<V4L("1I;F9O+"`D9F]U;F0I.PT*("`@('T-
M"@T*("`@(&9U;F-T:6]N(%]R971U<FY$;W=N;&]A9%523"@D8F%S92P@)'!A
M8VMA9V4L("1R96QE87-E+"`D:6YF;RP@)&9O=6YD*0T*("`@('L-"B`@("`@
M("`@:68@*"$D9F]U;F0I('L-"B`@("`@("`@("`@("1R96QE87-E(#T@)&EN
M9F];)W(G75LP73L-"B`@("`@("`@?0T*("`@("`@("`D<F5L96%S96EN9F\@
M/2`D=&AI<RT^7W)E<W0M/G)E=')I979E0V%C:&5&:7)S="@D8F%S92`N("=R
M+R<@+B!S=')T;VQO=V5R*"1P86-K86=E*2`N("<O)R`N(`T*("`@("`@("`@
M("`@)')E;&5A<V5;)W8G72`N("<N>&UL)RD[#0H@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1R96QE87-E:6YF;RDI('L-"B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"=086-K86=E("(G("X@)'!A8VMA9V4@+B`G
M(B!697)S:6]N("(G("X@)')E;&5A<V5;)W8G72`N#0H@("`@("`@("`@("`@
M("`@)R(@9&]E<R!N;W0@:&%V92!215-4('AM;"!A=F%I;&%B;&4G*3L-"B`@
M("`@("`@?0T*("`@("`@("`D<&%C:V%G97AM;"`]("1T:&ES+3Y?<F5S="T^
M<F5T<FEE=F5#86-H949I<G-T*"1B87-E("X@)W(O)R`N('-T<G1O;&]W97(H
M)'!A8VMA9V4I("X@)R\G("X-"B`@("`@("`@("`@("=D97!S+B<@+B`D<F5L
M96%S95LG=B==("X@)RYT>'0G+"!F86QS92P@=')U92D[#0H@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1P86-K86=E>&UL*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U!A8VMA9V4@(B<@+B`D<&%C:V%G
M92`N("<B(%9E<G-I;VX@(B<@+B`D<F5L96%S95LG=B==("X-"B`@("`@("`@
M("`@("`@("`G(B!D;V5S(&YO="!H879E(%)%4U0@9&5P96YD96YC>2!I;F9O
M<FUA=&EO;B!A=F%I;&%B;&4G*3L-"B`@("`@("`@?0T*("`@("`@("`D<&%C
M:V%G97AM;"`]('5N<V5R:6%L:7IE*"1P86-K86=E>&UL*3L-"B`@("`@("`@
M:68@*"$D<&%C:V%G97AM;"D@>PT*("`@("`@("`@("`@)'!A8VMA9V5X;6P@
M/2!A<G)A>2@I.PT*("`@("`@("!]#0H@("`@("`@("1A;&QI;F9O(#T@)'1H
M:7,M/E]R97-T+3YR971R:65V941A=&$H)&)A<V4@+B`G<B\G("X@<W1R=&]L
M;W=E<B@D<&%C:V%G92D@+@T*("`@("`@("`@("`@)R]A;&QR96QE87-E<RYX
M;6PG*3L-"B`@("`@("`@:68@*"%I<U]A<G)A>2@D86QL:6YF;ULG<B==*2!\
M?"`A:7-S970H)&%L;&EN9F];)W(G75LP72DI('L-"B`@("`@("`@("`@("1A
M;&QI;F9O6R=R)UT@/2!A<G)A>2@D86QL:6YF;ULG<B==*3L-"B`@("`@("`@
M?0T*("`@("`@("`D8V]M<&%T:6)L92`](&9A;'-E.PT*("`@("`@("!F;W)E
M86-H("@D86QL:6YF;ULG<B==(&%S("1R96QE87-E*2![#0H@("`@("`@("`@
M("!I9B`H)')E;&5A<V5;)W8G72`A/2`D<F5L96%S96EN9F];)W8G72D@>PT*
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@:68@*"%I<W-E="@D<F5L96%S95LG8V\G72DI('L-"B`@("`@
M("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("1C;VUP871I8FQE(#T@87)R87DH*3L-"B`@("`@("`@("`@(&EF("@A:7-?
M87)R87DH)')E;&5A<V5;)V-O)UTI('Q\("%I<W-E="@D<F5L96%S95LG8V\G
M75LP72DI('L-"B`@("`@("`@("`@("`@("`D<F5L96%S95LG8V\G72`](&%R
M<F%Y*"1R96QE87-E6R=C;R==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(&9O<F5A8V@@*"1R96QE87-E6R=C;R==(&%S("1E;G1R>2D@>PT*("`@
M("`@("`@("`@("`@("1C;VUP(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@
M("`D8V]M<%LG;F%M92==(#T@)&5N=')Y6R=P)UT[#0H@("`@("`@("`@("`@
M("`@)&-O;7!;)V-H86YN96PG72`]("1E;G1R>5LG8R==.PT*("`@("`@("`@
M("`@("`@("1C;VUP6R=M:6XG72`]("1E;G1R>5LG;6EN)UT[#0H@("`@("`@
M("`@("`@("`@)&-O;7!;)VUA>"==(#T@)&5N=')Y6R=M87@G73L-"B`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&5N=')Y6R=X)UTI("8F("%I<U]A<G)A
M>2@D96YT<GE;)W@G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)&-O;7!;
M)V5X8VQU9&4G72`]("1E;G1R>5LG>"==.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`D8V]M<&%T:6)L95M=(#T@)&-O;7`[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!I9B`H8V]U;G0H)&-O;7!A=&EB;&4I
M(#T](#$I('L-"B`@("`@("`@("`@("`@("`D8V]M<&%T:6)L92`]("1C;VUP
M871I8FQE6S!=.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@8G)E86L[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"1F;W5N9"D@>PT*("`@("`@("`@
M("`@<F5T=7)N(`T*("`@("`@("`@("`@("`@(&%R<F%Y*"=V97)S:6]N)R`]
M/B`D<F5L96%S96EN9F];)W8G72P-"B`@("`@("`@("`@("`@("`@("`@("`G
M:6YF;R<@/3X@)'!A8VMA9V5X;6PL#0H@("`@("`@("`@("`@("`@("`@("`@
M)W!A8VMA9V4G(#T^("1R96QE87-E:6YF;ULG<"==6R=?8V]N=&5N="==+`T*
M("`@("`@("`@("`@("`@("`@("`@("=S=&%B:6QI='DG(#T^("1R96QE87-E
M:6YF;ULG<W0G72P-"B`@("`@("`@("`@("`@("`@("`@("`G=7)L)R`]/B`D
M<F5L96%S96EN9F];)V<G72P-"B`@("`@("`@("`@("`@("`@("`@("`G8V]M
M<&%T:6)L92<@/3X@)&-O;7!A=&EB;&4I.PT*("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@<F5T=7)N#0H@("`@("`@("`@("`@("`@87)R87DH)W9E
M<G-I;VXG(#T^("1R96QE87-E:6YF;ULG=B==+`T*("`@("`@("`@("`@("`@
M("`@("`@("=P86-K86=E)R`]/B`D<F5L96%S96EN9F];)W`G75LG7V-O;G1E
M;G0G72P-"B`@("`@("`@("`@("`@("`@("`@("`G<W1A8FEL:71Y)R`]/B`D
M<F5L96%S96EN9F];)W-T)UTL#0H@("`@("`@("`@("`@("`@("`@("`@)VEN
M9F\G(#T^("1P86-K86=E>&UL+`T*("`@("`@("`@("`@("`@("`@("`@("=C
M;VUP871I8FQE)R`]/B`D8V]M<&%T:6)L92D[#0H@("`@("`@('T-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!L:7-T4&%C:V%G97,H)&)A<V4I#0H@("`@>PT*
M("`@("`@("`D<&%C:V%G96QI<W0@/2`D=&AI<RT^7W)E<W0M/G)E=')I979E
M1&%T82@D8F%S92`N("=P+W!A8VMA9V5S+GAM;"<I.PT*("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D<&%C:V%G96QI<W0I*2![#0H@("`@("`@("`@("!R
M971U<FX@)'!A8VMA9V5L:7-T.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A
M:7-?87)R87DH)'!A8VMA9V5L:7-T*2!\?"`A:7-S970H)'!A8VMA9V5L:7-T
M6R=P)UTI*2![#0H@("`@("`@("`@("!R971U<FX@87)R87DH*3L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1P86-K86=E;&ES=%LG<"==
M*2D@>PT*("`@("`@("`@("`@)'!A8VMA9V5L:7-T6R=P)UT@/2!A<G)A>2@D
M<&%C:V%G96QI<W1;)W`G72D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N
M("1P86-K86=E;&ES=%LG<"==.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&QI
M<W1!;&PH)&)A<V4L("1D;W-T86)L92P@)&)A<VEC(#T@=')U92P@)'-E87)C
M:'!A8VMA9V4@/2!F86QS92P@)'-E87)C:'-U;6UA<GD@/2!F86QS92D-"B`@
M("![#0H@("`@("`@("1P86-K86=E;&ES="`]("1T:&ES+3Y?<F5S="T^<F5T
M<FEE=F5$871A*"1B87-E("X@)W`O<&%C:V%G97,N>&UL)RD[#0H@("`@("`@
M(&EF("A014%2.CII<T5R<F]R*"1P86-K86=E;&ES="DI('L-"B`@("`@("`@
M("`@(')E='5R;B`D<&%C:V%G96QI<W0[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*"1T:&ES+3Y?<F5S="T^8V]N9FEG+3YG970H)W9E<F)O<V4G*2`^(#`I
M('L-"B`@("`@("`@("`@("1U:2`]("9014%27T9R;VYT96YD.CIS:6YG;&5T
M;VXH*3L-"B`@("`@("`@("`@("1U:2T^;&]G*"=2971R:65V:6YG(&1A=&$N
M+BXP)2<L(&9A;'-E*3L-"B`@("`@("`@?0T*("`@("`@("`D<F5T(#T@87)R
M87DH*3L-"B`@("`@("`@:68@*"%I<U]A<G)A>2@D<&%C:V%G96QI<W0I('Q\
M("%I<W-E="@D<&%C:V%G96QI<W1;)W`G72DI('L-"B`@("`@("`@("`@(')E
M='5R;B`D<F5T.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-?87)R87DH
M)'!A8VMA9V5L:7-T6R=P)UTI*2![#0H@("`@("`@("`@("`D<&%C:V%G96QI
M<W1;)W`G72`](&%R<F%Y*"1P86-K86=E;&ES=%LG<"==*3L-"B`@("`@("`@
M?0T*("`@("`@("!014%2.CIP=7-H17)R;W)(86YD;&EN9RA014%27T524D]2
M7U)%5%523BD[#0H@("`@("`@("1N97AT(#T@+C$[#0H@("`@("`@(&9O<F5A
M8V@@*"1P86-K86=E;&ES=%LG<"==(&%S("1P<F]G<F5S<R`]/B`D<&%C:V%G
M92D@>PT*("`@("`@("`@("`@:68@*"1T:&ES+3Y?<F5S="T^8V]N9FEG+3YG
M970H)W9E<F)O<V4G*2`^(#`I('L-"B`@("`@("`@("`@("`@("!I9B`H)'!R
M;V=R97-S("\@8V]U;G0H)'!A8VMA9V5L:7-T6R=P)UTI(#X]("1N97AT*2![
M#0H@("`@("`@("`@("`@("`@("`@(&EF("@D;F5X="`]/2`N-2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)'5I+3YL;V<H)S4P)2<L(&9A;'-E*3L-
M"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1U:2T^;&]G*"<N)RP@9F%L<V4I.PT*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1N97AT("L]("XQ.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&EF("@D8F%S:6,I('L@+R\@<F5M;W1E+6QI<W0@8V]M;6%N9`T*("`@("`@
M("`@("`@("`@(&EF("@D9&]S=&%B;&4I('L-"B`@("`@("`@("`@("`@("`@
M("`@)&QA=&5S="`]("1T:&ES+3Y?<F5S="T^<F5T<FEE=F5$871A*"1B87-E
M("X@)W(O)R`N('-T<G1O;&]W97(H)'!A8VMA9V4I("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("<O<W1A8FQE+G1X="<I.PT*("`@("`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1L871E<W0@/2`D=&AI
M<RT^7W)E<W0M/G)E=')I979E1&%T82@D8F%S92`N("=R+R<@+B!S=')T;VQO
M=V5R*"1P86-K86=E*2`N#0H@("`@("`@("`@("`@("`@("`@("`@("`G+VQA
M=&5S="YT>'0G*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)&QA=&5S="DI('L-"B`@("`@("`@("`@
M("`@("`@("`@)&QA=&5S="`](&9A;'-E.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`D:6YF;R`](&%R<F%Y*"=S=&%B;&4G(#T^("1L
M871E<W0I.PT*("`@("`@("`@("`@?2!E;'-E('L@+R\@;&ES="UA;&P@8V]M
M;6%N9`T*("`@("`@("`@("`@("`@("1I;F8@/2`D=&AI<RT^7W)E<W0M/G)E
M=')I979E1&%T82@D8F%S92`N("=P+R<@+B!S=')T;VQO=V5R*"1P86-K86=E
M*2`N("<O:6YF;RYX;6PG*3L-"B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D:6YF*2D@>PT*("`@("`@("`@("`@("`@("`@("!014%2.CIP
M;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D:6YF.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I
M9B`H)'-E87)C:'!A8VMA9V4I('L-"B`@("`@("`@("`@("`@("`@("`@)&9O
M=6YD(#T@*"%E;7!T>2@D<V5A<F-H<&%C:V%G92D@)B8@<W1R:7-T<B@D<&%C
M:V%G92P@)'-E87)C:'!A8VMA9V4I("$]/2!F86QS92D[#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@A)&9O=6YD("8F("$H:7-S970H)'-E87)C:'-U;6UA
M<GDI("8F("%E;7!T>2@D<V5A<F-H<W5M;6%R>2D-"B`@("`@("`@("`@("`@
M("`@("`@("`@("8F("AS=')I<W1R*"1I;F9;)W,G72P@)'-E87)C:'-U;6UA
M<GDI("$]/2!F86QS90T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('Q\
M('-T<FES='(H)&EN9ELG9"==+"`D<V5A<F-H<W5M;6%R>2D@(3T](&9A;'-E
M*2DI#0H@("`@("`@("`@("`@("`@("`@('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("!].PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D<F5L96%S97,@/2`D
M=&AI<RT^7W)E<W0M/G)E=')I979E1&%T82@D8F%S92`N("=R+R<@+B!S=')T
M;VQO=V5R*"1P86-K86=E*2`N#0H@("`@("`@("`@("`@("`@("`@("<O86QL
M<F5L96%S97,N>&UL)RD[#0H@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)')E;&5A<V5S*2D@>PT*("`@("`@("`@("`@("`@("`@("!C;VYT
M:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D<F5L96%S97-;)W(G75LP72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@)')E;&5A<V5S6R=R)UT@/2!A<G)A>2@D<F5L96%S97-;)W(G72D[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('5N<V5T*"1L
M871E<W0I.PT*("`@("`@("`@("`@("`@('5N<V5T*"1U;G-T86)L92D[#0H@
M("`@("`@("`@("`@("`@=6YS970H)'-T86)L92D[#0H@("`@("`@("`@("`@
M("`@=6YS970H)'-T871E*3L-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D
M<F5L96%S97-;)W(G72!A<R`D<F5L96%S92D@>PT*("`@("`@("`@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1L871E<W0I*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H)&1O<W1A8FQE("8F("1R96QE87-E6R=S)UT@/3T@)W-T
M86)L92<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;&%T97-T
M(#T@)')E;&5A<V5;)W8G73L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<W1A=&4@/2`G<W1A8FQE)SL-"B`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A)&1O<W1A8FQE*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&QA=&5S="`]("1R96QE
M87-E6R=V)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-T871E
M(#T@)')E;&5A<V5;)W,G73L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1S=&%B;&4I("8F("1R96QE87-E6R=S)UT@/3T@)W-T86)L
M92<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1S=&%B;&4@/2`D<F5L
M96%S95LG=B==.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D=6YS=&%B;&4I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'5N<W1A8FQE(#T@)'-T86)L93L-"B`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1U;G-T86)L92D@)B8@)')E;&5A<V5;)W,G72`A/2`G
M<W1A8FQE)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&QA=&5S="`]
M("1U;G-T86)L92`]("1R96QE87-E6R=V)UT[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D<W1A=&4@/2`D<F5L96%S95LG<R==.PT*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D;&%T
M97-T*2`F)B`A:7-S970H)'-T871E*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)'-T871E(#T@)')E;&5A<V5;)W,G73L-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&QA=&5S
M="D@)B8@:7-S970H)'-T86)L92D@)B8@:7-S970H)'5N<W1A8FQE*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M)&1E<',@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H
M)'5N<W1A8FQE*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=6YS=&%B;&4@
M/2!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@)'-T871E(#T@)W-T86)L
M92<[#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<W1A8FQE*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&QA=&5S="`]("1U;G-T86)L
M92`]("1S=&%B;&4[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D;&%T97-T
M(#T@)'5N<W1A8FQE.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1L871E<W0I*2![#0H@("`@("`@("`@("`@("`@
M("`@("1L871E<W0@/2!F86QS93L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@:68@*"1L871E<W0I('L-"B`@("`@("`@("`@("`@("`@
M("`@)&0@/2`D=&AI<RT^7W)E<W0M/G)E=')I979E0V%C:&5&:7)S="@D8F%S
M92`N("=R+R<@+B!S=')T;VQO=V5R*"1P86-K86=E*2`N("<O9&5P<RXG("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1L871E<W0@+B`G+G1X="<I.PT*
M("`@("`@("`@("`@("`@("`@("!I9B`H(5!%05(Z.FES17)R;W(H)&0I*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D9"`]('5N<V5R:6%L:7IE*"1D
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D9"D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9%LG<F5Q=6ER960G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%C
M;&%S<U]E>&ES=',H)U!%05)?4&%C:V%G949I;&5?=C(G*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=0
M14%2+U!A8VMA9V5&:6QE+W8R+G!H<"<[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"%I<W-E="@D<&8I*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<&8@/2!N97<@4$5!4E]086-K86=E1FEL95]V,CL-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<&8M/G-E=$1E<',H)&0I.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&1E<',@/2`D<&8M/F=E
M=$1E<',H*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&1E<',@/2`D
M9#L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1D97!S(&%S("1D97`I('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1D97!;)W1Y
M<&4G72`A/3T@)W!K9R<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D
M97!S6UT@/2`D9&5P.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1S=&%B;&4I*2![#0H@("`@("`@("`@("`@("`@("`@("1S=&%B
M;&4@/2`G+6XO82TG.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!I9B`H(21S96%R8VAP86-K86=E*2![#0H@("`@("`@("`@("`@("`@
M("`@("1I;F9O(#T@87)R87DH)W-T86)L92<@/3X@)&QA=&5S="P@)W-U;6UA
M<GDG(#T^("1I;F9;)W,G72P@)V1E<V-R:7!T:6]N)R`]/@T*("`@("`@("`@
M("`@("`@("`@("`@("`@)&EN9ELG9"==+"`G9&5P<R<@/3X@)&1E<',L("=C
M871E9V]R>2<@/3X@)&EN9ELG8V$G75LG7V-O;G1E;G0G72P-"B`@("`@("`@
M("`@("`@("`@("`@("`@("=U;G-T86)L92<@/3X@)'5N<W1A8FQE+"`G<W1A
M=&4G(#T^("1S=&%T92D[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`@("`@)&EN9F\@/2!A<G)A>2@G<W1A8FQE)R`]/B`D
M<W1A8FQE+"`G<W5M;6%R>2<@/3X@)&EN9ELG<R==+"`G9&5S8W)I<'1I;VXG
M(#T^#0H@("`@("`@("`@("`@("`@("`@("`@("`D:6YF6R=D)UTL("=D97!S
M)R`]/B`D9&5P<RP@)V-A=&5G;W)Y)R`]/B`D:6YF6R=C82==6R=?8V]N=&5N
M="==+`T*("`@("`@("`@("`@("`@("`@("`@("`@)W5N<W1A8FQE)R`]/B`D
M=6YS=&%B;&4L("=S=&%T92<@/3X@)'-T871E*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<F5T6R1P86-K86=E
M72`]("1I;F9O.PT*("`@("`@("!]#0H@("`@("`@(%!%05(Z.G!O<$5R<F]R
M2&%N9&QI;F<H*3L-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@;&ES=$QA=&5S=%5P9W)A9&5S*"1B87-E+"`D<W1A=&4L
M("1I;G-T86QL960L("1C:&%N;F5L+"`F)')E9RD-"B`@("![#0H@("`@("`@
M("1P86-K86=E;&ES="`]("1T:&ES+3Y?<F5S="T^<F5T<FEE=F5$871A*"1B
M87-E("X@)W`O<&%C:V%G97,N>&UL)RD[#0H@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1P86-K86=E;&ES="DI('L-"B`@("`@("`@("`@(')E='5R;B`D
M<&%C:V%G96QI<W0[#0H@("`@("`@('T-"B`@("`@("`@)')E="`](&%R<F%Y
M*"D[#0H@("`@("`@(&EF("@A:7-?87)R87DH)'!A8VMA9V5L:7-T*2!\?"`A
M:7-S970H)'!A8VMA9V5L:7-T6R=P)UTI*2![#0H@("`@("`@("`@("!R971U
M<FX@)')E=#L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1P
M86-K86=E;&ES=%LG<"==*2D@>PT*("`@("`@("`@("`@)'!A8VMA9V5L:7-T
M6R=P)UT@/2!A<G)A>2@D<&%C:V%G96QI<W1;)W`G72D[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"1S=&%T92D@>PT*("`@("`@("`@("`@)'-T871E<R`]
M("1T:&ES+3YB971T97)3=&%T97,H)'-T871E+"!T<G5E*3L-"B`@("`@("`@
M?0T*("`@("`@("!F;W)E86-H("@D<&%C:V%G96QI<W1;)W`G72!A<R`D<&%C
M:V%G92D@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D:6YS=&%L;&5D6W-T
M<G1O;&]W97(H)'!A8VMA9V4I72DI('L-"B`@("`@("`@("`@("`@("!C;VYT
M:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1I;G-T7W9E<G-I
M;VX@/2`D<F5G+3YP86-K86=E26YF;R@D<&%C:V%G92P@)W9E<G-I;VXG+"`D
M8VAA;FYE;"D[#0H@("`@("`@("`@("!014%2.CIP=7-H17)R;W)(86YD;&EN
M9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@("`@("`D:6YF;R`]("1T
M:&ES+3Y?<F5S="T^<F5T<FEE=F5$871A*"1B87-E("X@)W(O)R`N('-T<G1O
M;&]W97(H)'!A8VMA9V4I("X-"B`@("`@("`@("`@("`@("`G+V%L;')E;&5A
M<V5S+GAM;"<I.PT*("`@("`@("`@("`@4$5!4CHZ<&]P17)R;W)(86YD;&EN
M9R@I.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&EN9F\I*2![
M#0H@("`@("`@("`@("`@("`@8V]N=&EN=64[("\O(&YO(')E;6]T92!R96QE
M87-E<PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"%I<W-E="@D
M:6YF;ULG<B==*2D@>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@)&9O=6YD(#T@9F%L<V4[#0H@("`@
M("`@("`@("`D<F5L96%S92`](&9A;'-E.PT*("`@("`@("`@("`@:68@*"%I
M<U]A<G)A>2@D:6YF;ULG<B==*2!\?"`A:7-S970H)&EN9F];)W(G75LP72DI
M('L-"B`@("`@("`@("`@("`@("`D:6YF;ULG<B==(#T@87)R87DH)&EN9F];
M)W(G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F;W)E86-H("@D
M:6YF;ULG<B==(&%S("1R96QE87-E*2![#0H@("`@("`@("`@("`@("`@:68@
M*"1I;G-T7W9E<G-I;VX@)B8@=F5R<VEO;E]C;VUP87)E*"1R96QE87-E6R=V
M)UTL("1I;G-T7W9E<G-I;VXL("<\/2<I*2![#0H@("`@("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!I9B`H)'-T871E*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("AI
M;E]A<G)A>2@D<F5L96%S95LG<R==+"`D<W1A=&5S*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)&9O=6YD(#T@=')U93L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)&9O
M=6YD(#T@=')U93L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@
M*"$D9F]U;F0I('L-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("1R96QI;F9O(#T@)'1H:7,M/E]R97-T
M+3YR971R:65V94-A8VAE1FER<W0H)&)A<V4@+B`G<B\G("X@<W1R=&]L;W=E
M<B@D<&%C:V%G92D@+B`G+R<@+B`-"B`@("`@("`@("`@("`@("`D<F5L96%S
M95LG=B==("X@)RYX;6PG*3L-"B`@("`@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1R96QI;F9O*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D<F5L
M:6YF;SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1R971;)'!A8VMA
M9V5=(#T@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=V97)S:6]N)R`]
M/B`D<F5L96%S95LG=B==+`T*("`@("`@("`@("`@("`@("`@("`G<W1A=&4G
M(#T^("1R96QE87-E6R=S)UTL#0H@("`@("`@("`@("`@("`@("`@("=F:6QE
M<VEZ92<@/3X@)')E;&EN9F];)V8G72P-"B`@("`@("`@("`@("`@("`I.PT*
M("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*("`@
M(&9U;F-T:6]N('!A8VMA9V5);F9O*"1B87-E+"`D<&%C:V%G92D-"B`@("![
M#0H@("`@("`@(%!%05(Z.G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?
M4D5455).*3L-"B`@("`@("`@)'!I;F9O(#T@)'1H:7,M/E]R97-T+3YR971R
M:65V941A=&$H)&)A<V4@+B`G<"\G("X@<W1R=&]L;W=E<B@D<&%C:V%G92D@
M+B`G+VEN9F\N>&UL)RD[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1P
M:6YF;RDI('L-"B`@("`@("`@("`@(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H
M*3L-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=5;FMN
M;W=N('!A8VMA9V4Z("(G("X@)'!A8VMA9V4@+B`G(B`H1&5B=6<Z("<@+@T*
M("`@("`@("`@("`@("`@("1P:6YF;RT^9V5T365S<V%G92@I("X@)RDG*3L-
M"B`@("`@("`@?0T*("`@("`@("`D<F5L96%S97,@/2!A<G)A>2@I.PT*("`@
M("`@("`D86QL<F5L96%S97,@/2`D=&AI<RT^7W)E<W0M/G)E=')I979E1&%T
M82@D8F%S92`N("=R+R<@+B!S=')T;VQO=V5R*"1P86-K86=E*2`N#0H@("`@
M("`@("`@("`G+V%L;')E;&5A<V5S+GAM;"<I.PT*("`@("`@("!I9B`H(5!%
M05(Z.FES17)R;W(H)&%L;')E;&5A<V5S*2D@>PT*("`@("`@("`@("`@:68@
M*"%C;&%S<U]E>&ES=',H)U!%05)?4&%C:V%G949I;&5?=C(G*2D@>PT*("`@
M("`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]086-K86=E1FEL92]V
M,BYP:'`G.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"%I<U]A
M<G)A>2@D86QL<F5L96%S97-;)W(G72DI('L-"B`@("`@("`@("`@("`@("`D
M86QL<F5L96%S97-;)W(G72`](&%R<F%Y*"1A;&QR96QE87-E<ULG<B==*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1P9B`](&YE=R!014%27U!A
M8VMA9V5&:6QE7W8R.PT*("`@("`@("`@("`@9F]R96%C:"`H)&%L;')E;&5A
M<V5S6R=R)UT@87,@)')E;&5A<V4I('L-"B`@("`@("`@("`@("`@("`D9',@
M/2`D=&AI<RT^7W)E<W0M/G)E=')I979E0V%C:&5&:7)S="@D8F%S92`N("=R
M+R<@+B!S=')T;VQO=V5R*"1P86-K86=E*2`N("<O9&5P<RXG("X-"B`@("`@
M("`@("`@("`@("`@("`@)')E;&5A<V5;)W8G72`N("<N='AT)RD[#0H@("`@
M("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&1S*2D@>PT*("`@("`@
M("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;&%T97-T*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`D;&%T97-T(#T@)')E;&5A<V5;)W8G73L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'!F+3YS971$97!S*'5N
M<V5R:6%L:7IE*"1D<RDI.PT*("`@("`@("`@("`@("`@("1D<R`]("1P9BT^
M9V5T1&5P<R@I.PT*("`@("`@("`@("`@("`@("1I;F9O(#T@)'1H:7,M/E]R
M97-T+3YR971R:65V94-A8VAE1FER<W0H)&)A<V4@+B`G<B\G("X@<W1R=&]L
M;W=E<B@D<&%C:V%G92D-"B`@("`@("`@("`@("`@("`@("`@+B`G+R<@+B`D
M<F5L96%S95LG=B==("X@)RYX;6PG*3L-"B`@("`@("`@("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-"B`@("`@("`@("`@("`@("`@("`@
M8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("1R96QE87-E<ULD<F5L96%S95LG=B==72`](&%R<F%Y*`T*("`@("`@("`@
M("`@("`@("`@("`G9&]N96)Y)R`]/B`D:6YF;ULG;2==+`T*("`@("`@("`@
M("`@("`@("`@("`G;&EC96YS92<@/3X@)&EN9F];)VPG72P-"B`@("`@("`@
M("`@("`@("`@("`@)W-U;6UA<GDG(#T^("1I;F9O6R=S)UTL#0H@("`@("`@
M("`@("`@("`@("`@("=D97-C<FEP=&EO;B<@/3X@)&EN9F];)V0G72P-"B`@
M("`@("`@("`@("`@("`@("`@)W)E;&5A<V5D871E)R`]/B`D:6YF;ULG9&$G
M72P-"B`@("`@("`@("`@("`@("`@("`@)W)E;&5A<V5N;W1E<R<@/3X@)&EN
M9F];)VXG72P-"B`@("`@("`@("`@("`@("`@("`@)W-T871E)R`]/B`D<F5L
M96%S95LG<R==+`T*("`@("`@("`@("`@("`@("`@("`G9&5P<R<@/3X@)&1S
M(#\@)&1S(#H@87)R87DH*2P-"B`@("`@("`@("`@("`@("`I.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&QA=&5S
M="`]("<G.PT*("`@("`@("!]#0H@("`@("`@(%!%05(Z.G!O<$5R<F]R2&%N
M9&QI;F<H*3L-"B`@("`@("`@<F5T=7)N(&%R<F%Y*`T*("`@("`@("`@("`@
M)VYA;64G(#T^("1P:6YF;ULG;B==+`T*("`@("`@("`@("`@)V-H86YN96PG
M(#T^("1P:6YF;ULG8R==+`T*("`@("`@("`@("`@)V-A=&5G;W)Y)R`]/B`D
M<&EN9F];)V-A)UU;)U]C;VYT96YT)UTL#0H@("`@("`@("`@("`G<W1A8FQE
M)R`]/B`D;&%T97-T+`T*("`@("`@("`@("`@)VQI8V5N<V4G(#T^("1P:6YF
M;ULG;"==+`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("1P:6YF;ULG<R==
M+`T*("`@("`@("`@("`@)V1E<V-R:7!T:6]N)R`]/B`D<&EN9F];)V0G72P-
M"B`@("`@("`@("`@("=R96QE87-E<R<@/3X@)')E;&5A<V5S+`T*("`@("`@
M("`@("`@*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!2971U<FX@86X@
M87)R87D@8V]N=&%I;FEN9R!A;&P@;V8@=&AE('-T871E<R!T:&%T(&%R92!M
M;W)E('-T86)L92!T:&%N#0H@("`@("H@;W(@97%U86P@=&\@=&AE('!A<W-E
M9"!I;B!S=&%T90T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R!296QE
M87-E('-T871E#0H@("`@("H@0'!A<F%M(&)O;VQE86X@1&5T97)M:6YE<R!W
M:&5T:&5R('1O(&EN8VQU9&4@)'-T871E(&EN('1H92!L:7-T#0H@("`@("H@
M0')E='5R;B!F86QS97QA<G)A>2!&86QS92!I9B`D<W1A=&4@:7,@;F]T(&$@
M=F%L:60@<F5L96%S92!S=&%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(&)E
M='1E<E-T871E<R@D<W1A=&4L("1I;F-L=61E(#T@9F%L<V4I#0H@("`@>PT*
M("`@("`@("!S=&%T:6,@)'-T871E<R`](&%R<F%Y*"=S;F%P<VAO="<L("=D
M979E;"<L("=A;'!H82<L("=B971A)RP@)W-T86)L92<I.PT*("`@("`@("`D
M:2`](&%R<F%Y7W-E87)C:"@D<W1A=&4L("1S=&%T97,I.PT*("`@("`@("!I
M9B`H)&D@/3T](&9A;'-E*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"1I;F-L=61E*2![#0H@("`@("`@
M("`@("`D:2TM.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!A<G)A>5]S
M;&EC92@D<W1A=&5S+"`D:2`K(#$I.PT*("`@('T-"GT-"C\^````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+T9R;VYT96YD````````````
M````````````````````````````````````````````````````````````
M`````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U
M-#,S-S,Q(#`R,#<Q,P`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O
M1G)O;G1E;F0O0TQ)+G!H<```````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P-C0T,#4@,3`U,34T,S,W,S$@,#(R,3(S`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP#0HO*BH-"B`J(%!%
M05)?1G)O;G1E;F1?0TQ)#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-
M"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@
M=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES
M(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@
M9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*
M("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I
M="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@
M;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM
M961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA
M9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P
M:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P
M:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O
M=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93
M.B`D260Z($-,22YP:'`L=B`Q+C4Y(#(P,#8O,#,O,#(@,3,Z,38Z,3D@<&%J
M;WEE($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T
M+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@
M<VEN8V4@4F5L96%S92`P+C$-"B`J+PT*+RHJ#0H@*B!B87-E(&-L87-S#0H@
M*B\-"G)E<75I<F5?;VYC92`G4$5!4B]&<F]N=&5N9"YP:'`G.PT*#0HO*BH-
M"B`J($-O;6UA;F0M;&EN92!&<F]N=&5N9"!F;W(@=&AE(%!%05(@26YS=&%L
M;&5R#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2
M#0H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@
M*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@
M*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI
M8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@
M4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N
M.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E
M+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!2
M96QE87-E(#`N,0T*("HO#0IC;&%S<R!014%27T9R;VYT96YD7T-,22!E>'1E
M;F1S(%!%05)?1G)O;G1E;F0-"GL-"B`@("`O+R![>WL@<')O<&5R=&EE<PT*
M#0H@("`@+RHJ#0H@("`@("H@5VAA="!T>7!E(&]F('5S97(@:6YT97)F86-E
M('1H:7,@9G)O;G1E;F0@:7,@9F]R+@T*("`@("`J($!V87(@<W1R:6YG#0H@
M("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!V87(@)'1Y<&4@
M/2`G0TQ))SL-"B`@("!V87(@)&QP(#T@)R<[("\O(&QI;F4@<')E9FEX#0H-
M"B`@("!V87(@)'!A<F%M<R`](&%R<F%Y*"D[#0H@("`@=F%R("1T97)M(#T@
M87)R87DH#0H@("`@("`@("=B;VQD)R`]/B`G)RP-"B`@("`@("`@)VYO<FUA
M;"<@/3X@)R<L#0H@("`@("`@("D[#0H-"B`@("`O+R!]?7T-"@T*("`@("\O
M('M[>R!C;VYS=')U8W1O<@T*#0H@("`@9G5N8W1I;VX@4$5!4E]&<F]N=&5N
M9%]#3$DH*0T*("`@('L-"B`@("`@("`@<&%R96YT.CI014%2*"D[#0H@("`@
M("`@("1T97)M(#T@9V5T96YV*"=415)-)RD[("\O*&-O>"D@)%]%3E8@:7,@
M96UP='D@9F]R(&UE(&EN(#0N,2XQ#0H@("`@("`@(&EF("AF=6YC=&EO;E]E
M>&ES=',H)W!O<VEX7VES871T>2<I("8F("%P;W-I>%]I<V%T='DH,2DI('L-
M"B`@("`@("`@("`@("\O(&]U='!U="!I<R!B96EN9R!R961I<F5C=&5D('1O
M(&$@9FEL92!O<B!T:')O=6=H(&$@<&EP90T*("`@("`@("!](&5L<V5I9B`H
M)'1E<FTI('L-"B`@("`@("`@("`@("\O(%A86"!C86X@=7-E(&YC=7)S97,@
M97AT96YS:6]N(&AE<F4L(&EF(&%V86EL86)L90T*("`@("`@("`@("`@:68@
M*'!R96=?;6%T8V@H)R]>*'AT97)M?'9T,C(P?&QI;G5X*2\G+"`D=&5R;2DI
M('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^=&5R;5LG8F]L9"==(#T@<W!R
M:6YT9B@B)6,E8R5C)6,B+"`R-RP@.3$L(#0Y+"`Q,#DI.PT*("`@("`@("`@
M("`@("`@("1T:&ES+3YT97)M6R=N;W)M86PG73US<')I;G1F*"(E8R5C)6,B
M+"`R-RP@.3$L(#$P.2D[#0H@("`@("`@("`@("!](&5L<V5I9B`H<')E9U]M
M871C:"@G+UYV=#$P,"\G+"`D=&5R;2DI('L-"B`@("`@("`@("`@("`@("`D
M=&AI<RT^=&5R;5LG8F]L9"==(#T@<W!R:6YT9B@B)6,E8R5C)6,E8R5C(BP@
M,C<L(#DQ+"`T.2P@,3`Y+"`P+"`P*3L-"B`@("`@("`@("`@("`@("`D=&AI
M<RT^=&5R;5LG;F]R;6%L)UT]<W!R:6YT9B@B)6,E8R5C)6,E8R(L(#(W+"`Y
M,2P@,3`Y+"`P+"`P*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E
M:68@*$]37U=)3D1/5U,I('L-"B`@("`@("`@("`@("\O(%A86"!A9&0@04Y3
M22!C;V1E<R!H97)E#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O+R!]?7T-
M"@T*("`@("\O('M[>R!D:7-P;&%Y3&EN92AT97AT*0T*#0H@("`@9G5N8W1I
M;VX@9&ES<&QA>4QI;F4H)'1E>'0I#0H@("`@>PT*("`@("`@("!T<FEG9V5R
M7V5R<F]R*")014%27T9R;VYT96YD7T-,23HZ9&ES<&QA>4QI;F4@9&5P<F5C
M871E9"(L($5?55-%4E]%4E)/4BD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M7V1I<W!L87E,:6YE*"1T97AT*0T*("`@('L-"B`@("`@("`@<')I;G0@(B1T
M:&ES+3YL<"1T97AT7&XB.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O
M('M[>R!D:7-P;&%Y*'1E>'0I#0H-"B`@("!F=6YC=&EO;B!D:7-P;&%Y*"1T
M97AT*0T*("`@('L-"B`@("`@("`@=')I9V=E<E]E<G)O<B@B4$5!4E]&<F]N
M=&5N9%]#3$DZ.F1I<W!L87D@9&5P<F5C871E9"(L($5?55-%4E]%4E)/4BD[
M#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7V1I<W!L87DH)'1E>'0I#0H@("`@
M>PT*("`@("`@("!P<FEN="`D=&5X=#L-"B`@("!]#0H-"B`@("`O+R!]?7T-
M"B`@("`O+R![>WL@9&ES<&QA>45R<F]R*&5O8FHI#0H-"B`@("`O*BH-"B`@
M("`@*B!`<&%R86T@;V)J96-T(%!%05)?17)R;W(@;V)J96-T#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@9&ES<&QA>45R<F]R*"1E;V)J*0T*("`@('L-"B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?9&ES<&QA>4QI;F4H)&5O8FHM/F=E=$UE
M<W-A9V4H*2D[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&1I
M<W!L87E&871A;$5R<F]R*&5O8FHI#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R
M86T@;V)J96-T(%!%05)?17)R;W(@;V)J96-T#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@9&ES<&QA>49A=&%L17)R;W(H)&5O8FHI#0H@("`@>PT*("`@("`@
M("`D=&AI<RT^9&ES<&QA>45R<F]R*"1E;V)J*3L-"B`@("`@("`@:68@*&-L
M87-S7V5X:7-T<R@G4$5!4E]#;VYF:6<G*2D@>PT*("`@("`@("`@("`@)&-O
M;F9I9R`]("9014%27T-O;F9I9SHZ<VEN9VQE=&]N*"D[#0H@("`@("`@("`@
M("!I9B`H)&-O;F9I9RT^9V5T*"=V97)B;W-E)RD@/B`U*2![#0H@("`@("`@
M("`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G9&5B=6=?<')I;G1?8F%C
M:W1R86-E)RDI('L-"B`@("`@("`@("`@("`@("`@("`@9&5B=6=?<')I;G1?
M8F%C:W1R86-E*"D[#0H@("`@("`@("`@("`@("`@?2!E;'-E:68@*&9U;F-T
M:6]N7V5X:7-T<R@G9&5B=6=?8F%C:W1R86-E)RDI('L-"B`@("`@("`@("`@
M("`@("`@("`@)'1R86-E(#T@9&5B=6=?8F%C:W1R86-E*"D[#0H@("`@("`@
M("`@("`@("`@("`@("1R86ES960@/2!F86QS93L-"B`@("`@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)'1R86-E(&%S("1I(#T^("1F<F%M92D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"$D<F%I<V5D*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1F<F%M95LG8VQA<W,G
M72D@)B8@<W1R=&]L;W=E<B@D9G)A;65;)V-L87-S)UTI(#T]#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!E87(G("8F('-T<G1O;&]W
M97(H)&9R86UE6R=F=6YC=&EO;B==*2`]/2`G<F%I<V5E<G)O<B<I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')A:7-E9"`]('1R=64[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@0"1T:&ES+3Y?9&ES<&QA
M>4QI;F4H(B,D:3H@)&9R86UE6V-L87-S721F<F%M95MT>7!E721F<F%M95MF
M=6YC=&EO;ET@)&9R86UE6VQI;F5=(BD[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@97AI="@Q*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@
M("`O+R![>WL@9&ES<&QA>4AE861I;F<H=&ET;&4I#0H-"B`@("!F=6YC=&EO
M;B!D:7-P;&%Y2&5A9&EN9R@D=&ET;&4I#0H@("`@>PT*("`@("`@("!T<FEG
M9V5R7V5R<F]R*")014%27T9R;VYT96YD7T-,23HZ9&ES<&QA>4AE861I;F<@
M9&5P<F5C871E9"(L($5?55-%4E]%4E)/4BD[#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@7V1I<W!L87E(96%D:6YG*"1T:71L92D-"B`@("![#0H@("`@("`@
M('!R:6YT("1T:&ES+3YL<"XD=&AI<RT^8F]L9"@D=&ET;&4I+B)<;B([#0H@
M("`@("`@('!R:6YT("1T:&ES+3YL<"YS=')?<F5P96%T*"(](BP@<W1R;&5N
M*"1T:71L92DI+B)<;B([#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-"B`@("`O
M*BH-"B`@("`@*B!);G-T<G5C="!T:&4@<G5N26YS=&%L;%-C<FEP="!M971H
M;V0@=&\@<VMI<"!A('!A<F%M9W)O=7`@=&AA="!M871C:&5S('1H90T*("`@
M("`J(&ED('9A;'5E('!A<W-E9"!I;BX-"B`@("`@*@T*("`@("`J(%1H:7,@
M;65T:&]D(&ES('5S969U;"!F;W(@9'EN86UI8V%L;'D@8V]N9FEG=7)I;F<@
M=VAI8V@@<V5C=&EO;G,@;V8@82!P;W-T+6EN<W1A;&P@<V-R:7!T#0H@("`@
M("H@=VEL;"!B92!R=6X@8F%S960@;VX@=&AE('5S97(G<R!S971U<"P@=VAI
M8V@@:7,@=F5R>2!U<V5F=6P@9F]R(&UA:VEN9R!F;&5X:6)L90T*("`@("`J
M('!O<W0M:6YS=&%L;"!S8W)I<'1S('=I=&AO=70@;&]S:6YG('1H92!C<F]S
M<RU&<F]N=&5N9"!A8FEL:71Y('1O(')E=')I979E('5S97(@:6YP=70-"B`@
M("`@*B!`<&%R86T@<W1R:6YG#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<VMI
M<%!A<F%M9W)O=7`H)&ED*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S:VEP
M4V5C=&EO;G-;)&ED72`]('1R=64[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M<G5N4&]S=&EN<W1A;&Q38W)I<'1S*"8D<V-R:7!T<RD-"B`@("![#0H@("`@
M("`@(&9O<F5A8V@@*"1S8W)I<'1S(&%S("1I(#T^("1S8W)I<'0I('L-"B`@
M("`@("`@("`@("1T:&ES+3YR=6Y);G-T86QL4V-R:7!T*"1S8W)I<'1S6R1I
M72T^7W!A<F%M<RP@)'-C<FEP='-;)&E=+3Y?;V)J*3L-"B`@("`@("`@?0T*
M("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!A<G)A>2`D>&UL(&-O
M;G1E;G1S(&]F('!O<W1I;G-T86QL<V-R:7!T('1A9PT*("`@("`J($!P87)A
M;2!O8FIE8W0@)'-C<FEP="!P;W-T+6EN<W1A;&QA=&EO;B!S8W)I<'0-"B`@
M("`@*B!`<&%R86T@<W1R:6YG(&EN<W1A;&Q\=7!G<F%D90T*("`@("`J+PT*
M("`@(&9U;F-T:6]N(')U;DEN<W1A;&Q38W)I<'0H)'AM;"P@)B1S8W)I<'0I
M#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-K:7!396-T:6]N<R`](&%R<F%Y
M*"D[#0H@("`@("`@(&EF("@A:7-?87)R87DH)'AM;"D@?'P@(6ES<V5T*"1X
M;6Q;)W!A<F%M9W)O=7`G72DI('L-"B`@("`@("`@("`@("1S8W)I<'0M/G)U
M;BAA<G)A>2@I+"`G7V1E9F%U;'0G*3L-"B`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("1C;VUP;&5T9610:&%S97,@/2!A<G)A>2@I.PT*("`@("`@
M("`@("`@:68@*"%I<W-E="@D>&UL6R=P87)A;6=R;W5P)UU;,%TI*2![#0H@
M("`@("`@("`@("`@("`@)'AM;%LG<&%R86UG<F]U<"==(#T@87)R87DH)'AM
M;%LG<&%R86UG<F]U<"==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&9O<F5A8V@@*"1X;6Q;)W!A<F%M9W)O=7`G72!A<R`D9W)O=7`I('L-"B`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]S:VEP4V5C=&EO;G-;
M)&=R;W5P6R=I9"==72DI('L-"B`@("`@("`@("`@("`@("`@("`@+R\@=&AE
M('!O<W0M:6YS=&%L;"!S8W)I<'0@8VAO<V4@=&\@<VMI<"!T:&ES('-E8W1I
M;VX@9'EN86UI8V%L;'D-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D9W)O=7!;)VYA;64G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'!A
M<F%M;F%M92`](&5X<&QO9&4H)SHZ)RP@)&=R;W5P6R=N86UE)UTI.PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H)&QA<W1G<F]U<%LG:60G72`A/2`D<&%R
M86UN86UE6S!=*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU
M93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`D9W)O=7!;)VYA;64G72`]("1P87)A;6YA;65;,5T[#0H@("`@("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D86YS=V5R<RDI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D86YS=V5R<ULD9W)O=7!;)VYA;64G
M75TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W=I=&-H("@D
M9W)O=7!;)V-O;F1I=&EO;G1Y<&4G72D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!C87-E("<])R`Z#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H)&%N<W=E<G-;)&=R;W5P6R=N86UE)UU=
M("$]("1G<F]U<%LG=F%L=64G72D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E(#([#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!C87-E("<A/2<@.@T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"1A;G-W97)S6R1G<F]U<%LG;F%M92==72`]/2`D
M9W)O=7!;)W9A;'5E)UTI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!C;VYT:6YU92`R.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@8V%S92`G<')E9U]M871C:"<@.@T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*"%`<')E9U]M871C:"@G+R<@+B`D9W)O=7!;
M)W9A;'5E)UT@+B`G+R<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D86YS=V5R<ULD9W)O=7!;)VYA;64G75TI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN
M=64@,CL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&1E9F%U;'0@.@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1L87-T9W)O=7`@
M/2`D9W)O=7`[#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1G<F]U<%LG
M:6YS=')U8W1I;VYS)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?9&ES<&QA>2@D9W)O=7!;)VEN<W1R=6-T:6]N<R==*3L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D9W)O=7!;
M)W!A<F%M)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("1G<F]U<%LG
M<&%R86TG72`](&%R<F%Y*"1G<F]U<%LG<&%R86TG72D[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9W)O=7!;)W!A
M<F%M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("AM971H;V1?97AI
M<W1S*"1S8W)I<'0L("=P;W-T4')O8V5S<U!R;VUP=',G*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)'!R;VUP=',@/2`D<V-R:7!T+3YP;W-T4')O
M8V5S<U!R;VUP=',H)&=R;W5P6R=P87)A;2==+"`D9W)O=7!;)VED)UTI.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D<')O;7!T
M<RD@?'P@8V]U;G0H)'!R;VUP=',I("$](&-O=6YT*"1G<F]U<%LG<&%R86TG
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;W5T
M<'5T1&%T82@G<&]S=&EN<W1A;&PG+"`G17)R;W(Z('!O<W0M:6YS=&%L;"!S
M8W)I<'0@9&ED(&YO="`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W)E='5R;B!P<F]P97(@<&]S="UP<F]C97-S960@<')O;7!T<R<I
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<F]M<'1S(#T@)&=R
M;W5P6R=P87)A;2==.PT*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D<')O
M;7!T<R!A<R`D:2`]/B`D=F%R*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@A:7-?87)R87DH)'9A<BD@?'P@(6ES<V5T*"1V87);
M)W!R;VUP="==*2!\?`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`A:7-S970H)'9A<ELG;F%M92==*2!\?`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`H)'9A<ELG;F%M92==("$]("1G
M<F]U<%LG<&%R86TG75LD:5U;)VYA;64G72D@?'P-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@*"1V87);)W1Y<&4G72`A/2`D9W)O
M=7!;)W!A<F%M)UU;)&E=6R=T>7!E)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;W5T<'5T1&%T82@G<&]S=&EN
M<W1A;&PG+"`G17)R;W(Z('!O<W0M:6YS=&%L;"!S8W)I<'0@)R`N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VUO9&EF:65D
M('1H92!V87)I86)L97,@;W(@<')O;7!T<RP@<V5V97)E('-E8W5R:71Y(')I
M<VLN("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=7:6QL(&EN<W1E860@=7-E('1H92!D969A=6QT<R!F<F]M('1H92!P
M86-K86=E+GAM;"<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'!R;VUP=',@/2`D9W)O=7!;)W!A<F%M)UT[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D86YS=V5R<R`]("1T:&ES+3YC;VYF:7)M1&EA
M;&]G*"1P<F]M<'1S*3L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1A;G-W97)S(#T@)'1H:7,M/F-O
M;F9I<FU$:6%L;V<H)&=R;W5P6R=P87)A;2==*3L-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I
M9B`H*&ES<V5T*"1A;G-W97)S*2`F)B`D86YS=V5R<RD@?'P@(6ES<V5T*"1G
M<F]U<%LG<&%R86TG72DI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I
M<W-E="@D86YS=V5R<RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1A
M;G-W97)S(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("!A<G)A>5]U;G-H:69T*"1C;VUP;&5T9610:&%S
M97,L("1G<F]U<%LG:60G72D[#0H@("`@("`@("`@("`@("`@("`@(&EF("@A
M)'-C<FEP="T^<G5N*"1A;G-W97)S+"`D9W)O=7!;)VED)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D<V-R:7!T+3YR=6XH)&-O;7!L971E9%!H
M87-E<RP@)U]U;F1O3VY%<G)O<B<I.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)'-C<FEP="T^
M<G5N*"1C;VUP;&5T9610:&%S97,L("=?=6YD;T]N17)R;W(G*3L-"B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@
M("`J($%S:R!F;W(@=7-E<B!I;G!U="P@8V]N9FER;2!T:&4@86YS=V5R<R!A
M;F0@8V]N=&EN=64@=6YT:6P@=&AE('5S97(@:7,@<V%T:7-F:65D#0H@("`@
M("H@0'!A<F%M(&%R<F%Y(&%N(&%R<F%Y(&]F(&%R<F%Y<RP@9F]R;6%T(&%R
M<F%Y*"=N86UE)R`]/B`G<&%R86UN86UE)RP@)W!R;VUP="<@/3X-"B`@("`@
M*B`@("`@("`@("`@("`@)W1E>'0@=&\@9&ES<&QA>2<L("=T>7!E)R`]/B`G
M<W1R:6YG)ULL(&1E9F%U;'0@/3X@)V1E9F%U;'0@=F%L=64G72D-"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y#0H@("`@("HO#0H@("`@9G5N8W1I;VX@8V]N9FER
M;41I86QO9R@D<&%R86US*0T*("`@('L-"B`@("`@("`@)&%N<W=E<G,@/2!A
M<G)A>2@I.PT*("`@("`@("`D<')O;7!T<R`]("1T>7!E<R`](&%R<F%Y*"D[
M#0H@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)'!A<F%M*2![#0H@("`@
M("`@("`@("`D<')O;7!T<ULD<&%R86U;)VYA;64G75T@/2`D<&%R86U;)W!R
M;VUP="==.PT*("`@("`@("`@("`@)'1Y<&5S6R1P87)A;5LG;F%M92==72`]
M("1P87)A;5LG='EP92==.PT*("`@("`@("`@("`@:68@*&ES<V5T*"1P87)A
M;5LG9&5F875L="==*2D@>PT*("`@("`@("`@("`@("`@("1A;G-W97)S6R1P
M87)A;5LG;F%M92==72`]("1P87)A;5LG9&5F875L="==.PT*("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D86YS=V5R<ULD<&%R86U;
M)VYA;64G75T@/2`G)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!D;R![#0H@("`@("`@("`@("`D;VL@/2!A<G)A>2@G>65S;F\G(#T^
M("=N;R<I.PT*("`@("`@("`@("`@9&\@>PT*("`@("`@("`@("`@("`@("1A
M;G-W97)S(#T@)'1H:7,M/G5S97)$:6%L;V<H)R<L("1P<F]M<'1S+"`D='EP
M97,L("1A;G-W97)S*3L-"B`@("`@("`@("`@('T@=VAI;&4@*&-O=6YT*&%R
M<F%Y7V9I;'1E<B@D86YS=V5R<RDI("$](&-O=6YT*"1P<F]M<'1S*2D[#0H@
M("`@("`@("`@("`D=&AI<RT^;W5T<'5T1&%T82@G66]U<B!C:&]I8V5S.B<I
M.PT*("`@("`@("`@("`@9F]R96%C:"`H)'!R;VUP=',@87,@)&YA;64@/3X@
M)'!R;VUP="D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3YO=71P=71$871A
M*"1P<F]M<'0@+B`G.B`G("X@)&%N<W=E<G-;)&YA;65=*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("1O:R`]("1T:&ES+3YU<V5R1&EA;&]G*"<G
M+`T*("`@("`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@
M("`G>65S;F\G(#T^("=4:&5S92!#:&]I8V5S($]+/R`H=7-E(")A8F]R="(@
M=&\@:&%L="DG#0H@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@
M("!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)WEE<VYO)R`]/B`G<W1R
M:6YG)RP-"B`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@(&%R
M<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G>65S;F\G(#T^("=Y97,G#0H@
M("`@("`@("`@("`@("`@*0T*("`@("`@("`@("`@*3L-"B`@("`@("`@("`@
M(&EF("@D;VM;)WEE<VYO)UT@/3T@)V%B;W)T)RD@>PT*("`@("`@("`@("`@
M("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!W
M:&EL92`H)&]K6R=Y97-N;R==("$]("=Y97,G*3L-"B`@("`@("`@<F5T=7)N
M("1A;G-W97)S.PT*("`@('T-"B`@("`O+R![>WL@=7-E<D1I86QO9RAP<F]M
M<'0L(%MT>7!E72P@6V1E9F%U;'1=*0T*#0H@("`@9G5N8W1I;VX@=7-E<D1I
M86QO9R@D8V]M;6%N9"P@)'!R;VUP=',L("1T>7!E<R`](&%R<F%Y*"DL("1D
M969A=6QT<R`](&%R<F%Y*"DI#0H@("`@>PT*("`@("`@("`D<F5S=6QT(#T@
M87)R87DH*3L-"B`@("`@("`@:68@*&ES7V%R<F%Y*"1P<F]M<'1S*2D@>PT*
M("`@("`@("`@("`@+R\@<&AP(#4N,"XP(&EN97AP;&EC86)L>2!B<F5A:W,@
M0D,@=VET:"!T:&ES(&)E:&%V:6]R#0H@("`@("`@("`@("`O+R!N;W<@<F5A
M9&EN9R!F<F]M(%-41$E.(&ES('1H92!I;G1E;F1E9"!S>6YT87@-"B`@("`@
M("`@("`@(&EF("AV97)S:6]N7V-O;7!A<F4H<&AP=F5R<VEO;B@I+"`G-2XP
M+C`G+"`G/"<I*2![#0H@("`@("`@("`@("`@("`@)&9P(#T@9F]P96XH(G!H
M<#HO+W-T9&EN(BP@(G(B*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&9O<F5A8V@@*"1P<F]M<'1S(&%S("1K97D@/3X@)'!R;VUP="D@>PT*("`@
M("`@("`@("`@("`@("1T>7!E(#T@)'1Y<&5S6R1K97E=.PT*("`@("`@("`@
M("`@("`@("1D969A=6QT(#T@0"1D969A=6QT<ULD:V5Y73L-"B`@("`@("`@
M("`@("`@("!I9B`H)'1Y<&4@/3T@)W!A<W-W;W)D)RD@>PT*("`@("`@("`@
M("`@("`@("`@("!S>7-T96TH)W-T='D@+65C:&\G*3L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@<')I;G0@(B1T:&ES+3YL<"1P<F]M
M<'0@(CL-"B`@("`@("`@("`@("`@("!I9B`H)&1E9F%U;'0I('L-"B`@("`@
M("`@("`@("`@("`@("`@<')I;G0@(ELD9&5F875L=%T@(CL-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@<')I;G0@(CH@(CL-"B`@("`@
M("`@("`@("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*'!H<'9E<G-I;VXH*2P@
M)S4N,"XP)RP@)SPG*2D@>PT*("`@("`@("`@("`@("`@("`@("`D;&EN92`]
M(&9G971S*"1F<"P@,C`T."D[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`@("`@:68@*"%D969I;F5D*"=35$1)3B<I*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("!D969I;F4H)U-41$E.)RP@9F]P
M96XH)W!H<#HO+W-T9&EN)RP@)W(G*2D[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@)&QI;F4@/2!F9V5T<RA35$1)3BP@
M,C`T."D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF
M("@D='EP92`]/2`G<&%S<W=O<F0G*2![#0H@("`@("`@("`@("`@("`@("`@
M('-Y<W1E;2@G<W1T>2!E8VAO)RD[#0H@("`@("`@("`@("`@("`@("`@('!R
M:6YT(")<;B([#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(&EF("@D9&5F875L="`F)B!T<FEM*"1L:6YE*2`]/2`B(BD@>PT*("`@("`@
M("`@("`@("`@("`@("`D<F5S=6QT6R1K97E=(#T@)&1E9F%U;'0[#0H@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)')E
M<W5L=%LD:V5Y72`]('1R:6TH)&QI;F4I.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AV97)S:6]N7V-O;7!A
M<F4H<&AP=F5R<VEO;B@I+"`G-2XP+C`G+"`G/"<I*2![#0H@("`@("`@("`@
M("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("`@("`@<F5T=7)N("1R97-U;'0[#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0H@("`@+R\@>WM[('5S97)#;VYF:7)M*'!R;VUP="P@6V1E9F%U;'1=*0T*
M#0H@("`@9G5N8W1I;VX@=7-E<D-O;F9I<FTH)'!R;VUP="P@)&1E9F%U;'0@
M/2`G>65S)RD-"B`@("![#0H@("`@("`@('1R:6=G97)?97)R;W(H(E!%05)?
M1G)O;G1E;F1?0TQ).CIU<V5R0V]N9FER;2!N;W0@>65T(&-O;G9E<G1E9"(L
M($5?55-%4E]%4E)/4BD[#0H@("`@("`@('-T871I8R`D<&]S:71I=F5S(#T@
M87)R87DH)WDG+"`G>65S)RP@)V]N)RP@)S$G*3L-"B`@("`@("`@<W1A=&EC
M("1N96=A=&EV97,@/2!A<G)A>2@G;B<L("=N;R<L("=O9F8G+"`G,"<I.PT*
M("`@("`@("!P<FEN="`B)'1H:7,M/FQP)'!R;VUP="!;)&1E9F%U;'1=(#H@
M(CL-"B`@("`@("`@)&9P(#T@9F]P96XH(G!H<#HO+W-T9&EN(BP@(G(B*3L-
M"B`@("`@("`@)&QI;F4@/2!F9V5T<R@D9G`L(#(P-#@I.PT*("`@("`@("!F
M8VQO<V4H)&9P*3L-"B`@("`@("`@)&%N<W=E<B`]('-T<G1O;&]W97(H=')I
M;2@D;&EN92DI.PT*("`@("`@("!I9B`H96UP='DH)&%N<W=E<BDI('L-"B`@
M("`@("`@("`@("1A;G-W97(@/2`D9&5F875L=#L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H:6Y?87)R87DH)&%N<W=E<BP@)'!O<VET:79E<RDI('L-"B`@
M("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@("`@("`@(&EF
M("AI;E]A<G)A>2@D86YS=V5R+"`D;F5G871I=F5S*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI;E]A
M<G)A>2@D9&5F875L="P@)'!O<VET:79E<RDI('L-"B`@("`@("`@("`@(')E
M='5R;B!T<G5E.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@<W1A<G1486)L92A;
M<&%R86US72D-"@T*("`@(&9U;F-T:6]N('-T87)T5&%B;&4H)'!A<F%M<R`]
M(&%R<F%Y*"DI#0H@("`@>PT*("`@("`@("!T<FEG9V5R7V5R<F]R*")014%2
M7T9R;VYT96YD7T-,23HZ<W1A<G1486)L92!D97!R96-A=&5D(BP@15]54T52
M7T524D]2*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?<W1A<G1486)L92@D
M<&%R86US(#T@87)R87DH*2D-"B`@("![#0H@("`@("`@("1P87)A;7-;)W1A
M8FQE7V1A=&$G72`](&%R<F%Y*"D[#0H@("`@("`@("1P87)A;7-;)W=I9&5S
M="==(#T@87)R87DH*3L@("\O(&EN9&5X960@8GD@8V]L=6UN#0H@("`@("`@
M("1P87)A;7-;)VAI9VAE<W0G72`](&%R<F%Y*"D[("\O(&EN9&5X960@8GD@
M<F]W#0H@("`@("`@("1P87)A;7-;)VYC;VQS)UT@/2`P.PT*("`@("`@("`D
M=&AI<RT^<&%R86US(#T@)'!A<F%M<SL-"B`@("!]#0H-"B`@("`O+R!]?7T-
M"B`@("`O+R![>WL@=&%B;&52;W<H8V]L=6UN<RP@6W)O=W!A<F%M<UTL(%MC
M;VQP87)A;7-=*0T*#0H@("`@9G5N8W1I;VX@=&%B;&52;W<H)&-O;'5M;G,L
M("1R;W=P87)A;7,@/2!A<G)A>2@I+"`D8V]L<&%R86US(#T@87)R87DH*2D-
M"B`@("![#0H@("`@("`@('1R:6=G97)?97)R;W(H(E!%05)?1G)O;G1E;F1?
M0TQ).CIT86)L95)O=R!D97!R96-A=&5D(BP@15]54T527T524D]2*3L-"B`@
M("!]#0H-"B`@("!F=6YC=&EO;B!?=&%B;&52;W<H)&-O;'5M;G,L("1R;W=P
M87)A;7,@/2!A<G)A>2@I+"`D8V]L<&%R86US(#T@87)R87DH*2D-"B`@("![
M#0H@("`@("`@("1H:6=H97-T(#T@,3L-"B`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P@<VEZ96]F*"1C;VQU;6YS*3L@)&DK*RD@>PT*("`@("`@("`@("`@
M)&-O;"`]("8D8V]L=6UN<ULD:5T[#0H@("`@("`@("`@("!I9B`H:7-S970H
M)&-O;'!A<F%M<ULD:5TI("8F("%E;7!T>2@D8V]L<&%R86US6R1I75LG=W)A
M<"==*2D@>PT*("`@("`@("`@("`@("`@("1C;VP@/2!W;W)D=W)A<"@D8V]L
M+"`D8V]L<&%R86US6R1I75LG=W)A<"==+"`B7&XB+"`P*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(&EF("AS=')P;W,H)&-O;"P@(EQN(BD@(3T]
M(&9A;'-E*2![#0H@("`@("`@("`@("`@("`@)&UU;'1I;&EN92`](&5X<&QO
M9&4H(EQN(BP@)&-O;"D[#0H@("`@("`@("`@("`@("`@)'<@/2`P.PT*("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1M=6QT:6QI;F4@87,@)&X@/3X@)&QI
M;F4I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*'-T<FQE;B@D;&EN92D@
M/B`D=RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'<@/2!S=')L96XH
M)&QI;F4I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("1L:6YE<R`]('-I>F5O9B@D;75L=&EL
M:6YE*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M)'<@/2!S=')L96XH)&-O;"D[#0H@("`@("`@("`@("!]#0H-"B`@("`@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^<&%R86US6R=W:61E<W0G75LD:5TI*2![
M#0H@("`@("`@("`@("`@("`@:68@*"1W(#X@)'1H:7,M/G!A<F%M<ULG=VED
M97-T)UU;)&E=*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YP87)A
M;7-;)W=I9&5S="==6R1I72`]("1W.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)'1H:7,M/G!A
M<F%M<ULG=VED97-T)UU;)&E=(#T@)'<[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`D=&UP(#T@8V]U;G1?8VAA<G,H)&-O;'5M;G-;)&E=+"`Q*3L-
M"B`@("`@("`@("`@("\O(&AA;F1L92!U;FEX+"!M86,@86YD('=I;F1O=W,@
M9F]R;6%T<PT*("`@("`@("`@("`@)&QI;F5S(#T@*&ES<V5T*"1T;7!;,3!=
M*2`_("1T;7!;,3!=(#H@*&ES<V5T*"1T;7!;,3-=*2`_("1T;7!;,3-=(#H@
M,"DI("L@,3L-"B`@("`@("`@("`@(&EF("@D;&EN97,@/B`D:&EG:&5S="D@
M>PT*("`@("`@("`@("`@("`@("1H:6=H97-T(#T@)&QI;F5S.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AS:7IE;V8H)&-O;'5M
M;G,I(#X@)'1H:7,M/G!A<F%M<ULG;F-O;',G72D@>PT*("`@("`@("`@("`@
M)'1H:7,M/G!A<F%M<ULG;F-O;',G72`]('-I>F5O9B@D8V]L=6UN<RD[#0H@
M("`@("`@('T-"B`@("`@("`@)&YE=U]R;W<@/2!A<G)A>2@-"B`@("`@("`@
M("`@("=D871A)R`]/B`D8V]L=6UN<RP-"B`@("`@("`@("`@("=H96EG:'0G
M(#T^("1H:6=H97-T+`T*("`@("`@("`@("`@)W)O=W!A<F%M<R<@/3X@)')O
M=W!A<F%M<RP-"B`@("`@("`@("`@("=C;VQP87)A;7,G(#T^("1C;VQP87)A
M;7,L#0H@("`@("`@("`@("`I.PT*("`@("`@("`D=&AI<RT^<&%R86US6R=T
M86)L95]D871A)UU;72`]("1N97=?<F]W.PT*("`@('T-"@T*("`@("\O('U]
M?0T*("`@("\O('M[>R!E;F1486)L92@I#0H-"B`@("!F=6YC=&EO;B!E;F14
M86)L92@I#0H@("`@>PT*("`@("`@("!T<FEG9V5R7V5R<F]R*")014%27T9R
M;VYT96YD7T-,23HZ96YD5&%B;&4@9&5P<F5C871E9"(L($5?55-%4E]%4E)/
M4BD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7V5N9%1A8FQE*"D-"B`@("![
M#0H@("`@("`@(&5X=')A8W0H)'1H:7,M/G!A<F%M<RD[#0H@("`@("`@(&EF
M("@A96UP='DH)&-A<'1I;VXI*2![#0H@("`@("`@("`@("`D=&AI<RT^7V1I
M<W!L87E(96%D:6YG*"1C87!T:6]N*3L-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H8V]U;G0H)'1A8FQE7V1A=&$I(#T](#`I('L-"B`@("`@("`@("`@(')E
M='5R;CL-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES<V5T*"1W:61T:"DI
M('L-"B`@("`@("`@("`@("1W:61T:"`]("1W:61E<W0[#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D;F-O;',[
M("1I*RLI('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1W:61T:%LD
M:5TI*2![#0H@("`@("`@("`@("`@("`@("`@("1W:61T:%LD:5T@/2`D=VED
M97-T6R1I73L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("`@("`@)&)O<F1E<B`](&9A;'-E.PT*("`@("`@("!I
M9B`H96UP='DH)&)O<F1E<BDI('L-"B`@("`@("`@("`@("1C96QL<W1A<G0@
M/2`G)SL-"B`@("`@("`@("`@("1C96QL96YD(#T@)R`G.PT*("`@("`@("`@
M("`@)')O=V5N9"`]("<G.PT*("`@("`@("`@("`@)'!A9')O=V5N9"`](&9A
M;'-E.PT*("`@("`@("`@("`@)&)O<F1E<FQI;F4@/2`G)SL-"B`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("1C96QL<W1A<G0@/2`G?"`G.PT*("`@
M("`@("`@("`@)&-E;&QE;F0@/2`G("<[#0H@("`@("`@("`@("`D<F]W96YD
M(#T@)WPG.PT*("`@("`@("`@("`@)'!A9')O=V5N9"`]('1R=64[#0H@("`@
M("`@("`@("`D8F]R9&5R;&EN92`]("<K)SL-"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1W:61T:"!A<R`D=RD@>PT*("`@("`@("`@("`@("`@("1B;W)D97)L
M:6YE("X]('-T<E]R97!E870H)RTG+"`D=R`K('-T<FQE;B@D8V5L;'-T87)T
M*2`K('-T<FQE;B@D8V5L;&5N9"D@+2`Q*3L-"B`@("`@("`@("`@("`@("`D
M8F]R9&5R;&EN92`N/2`G*R<[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"1B;W)D97)L:6YE*2![#0H@("`@("`@("`@("`D=&AI
M<RT^7V1I<W!L87E,:6YE*"1B;W)D97)L:6YE*3L-"B`@("`@("`@?0T*("`@
M("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'1A8FQE7V1A=&$I.R`D
M:2LK*2![#0H@("`@("`@("`@("!E>'1R86-T*"1T86)L95]D871A6R1I72D[
M#0H@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1R;W=P87)A;7,I*2![#0H@
M("`@("`@("`@("`@("`@)')O=W!A<F%M<R`](&%R<F%Y*"D[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1C;VQP87)A;7,I
M*2![#0H@("`@("`@("`@("`@("`@)&-O;'!A<F%M<R`](&%R<F%Y*"D[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`D<F]W;&EN97,@/2!A<G)A>2@I
M.PT*("`@("`@("`@("`@:68@*"1H96EG:'0@/B`Q*2![#0H@("`@("`@("`@
M("`@("`@9F]R("@D8R`](#`[("1C(#P@<VEZ96]F*"1D871A*3L@)&,K*RD@
M>PT*("`@("`@("`@("`@("`@("`@("`D<F]W;&EN97-;)&-=(#T@<')E9U]S
M<&QI="@G+RA<<C]<;GQ<<BDO)RP@)&1A=&%;)&-=*3L-"B`@("`@("`@("`@
M("`@("`@("`@:68@*'-I>F5O9B@D<F]W;&EN97-;)&-=*2`\("1H96EG:'0I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1R;W=L:6YE<ULD8UT@/2!A
M<G)A>5]P860H)')O=VQI;F5S6R1C72P@)&AE:6=H="P@)R<I.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!F;W(@*"1C(#T@,#L@)&,@
M/"!S:7IE;V8H)&1A=&$I.R`D8RLK*2![#0H@("`@("`@("`@("`@("`@("`@
M("1R;W=L:6YE<ULD8UT@/2!A<G)A>2@D9&%T85LD8UTI.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O<B`H)'(@
M/2`P.R`D<B`\("1H96EG:'0[("1R*RLI('L-"B`@("`@("`@("`@("`@("`D
M<F]W=&5X="`]("<G.PT*("`@("`@("`@("`@("`@(&9O<B`H)&,@/2`P.R`D
M8R`\('-I>F5O9B@D9&%T82D[("1C*RLI('L-"B`@("`@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1C;VQP87)A;7-;)&-=*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)&%T=')I8G,@/2!A<G)A>5]M97)G92@D<F]W<&%R86US
M+"`D8V]L<&%R86US*3L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1A='1R:6)S(#T@)')O=W!A<F%M
M<SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`D=R`](&ES<V5T*"1W:61T:%LD8UTI(#\@)'=I9'1H6R1C72`Z(#`[#0H@
M("`@("`@("`@("`@("`@("`@("\O)&-E;&P@/2`D9&%T85LD8UT[#0H@("`@
M("`@("`@("`@("`@("`@("1C96QL(#T@)')O=VQI;F5S6R1C75LD<ET[#0H@
M("`@("`@("`@("`@("`@("`@("1L(#T@<W1R;&5N*"1C96QL*3L-"B`@("`@
M("`@("`@("`@("`@("`@:68@*"1L(#X@)'<I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1C96QL(#T@<W5B<W1R*"1C96QL+"`P+"`D=RD[#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1A='1R:6)S6R=B;VQD)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D8V5L;"`]("1T:&ES+3YB;VQD*"1C96QL*3L-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H)&P@/"`D=RD@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@+R\@;F]T('5S:6YG('-T<E]P
M860@:&5R92!B96-A=7-E('=E(&UA>0T*("`@("`@("`@("`@("`@("`@("`@
M("`@+R\@861D(&)O;&0@97-C87!E(&-H87)A8W1E<G,@=&\@)&-E;&P-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1C96QL("X]('-T<E]R97!E870H)R`G
M+"`D=R`M("1L*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*#0H@("`@("`@
M("`@("`@("`@("`@("1R;W=T97AT("X]("1C96QL<W1A<G0@+B`D8V5L;"`N
M("1C96QL96YD.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!I9B`H(21B;W)D97(I('L-"B`@("`@("`@("`@("`@("`@("`@)')O=W1E
M>'0@/2!R=')I;2@D<F]W=&5X="D[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("1R;W=T97AT("X]("1R;W=E;F0[#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]D:7-P;&%Y3&EN92@D<F]W=&5X="D[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"1B;W)D97)L:6YE*2![
M#0H@("`@("`@("`@("`D=&AI<RT^7V1I<W!L87E,:6YE*"1B;W)D97)L:6YE
M*3L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[
M>R!O=71P=71$871A*"D-"@T*("`@(&9U;F-T:6]N(&]U='!U=$1A=&$H)&1A
M=&$L("1C;VUM86YD(#T@)U]D969A=6QT)RD-"B`@("![#0H@("`@("`@('-W
M:71C:"`H)&-O;6UA;F0I('L-"B`@("`@("`@("`@(&-A<V4@)V-H86YN96PM
M:6YF;R<Z#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&1A=&$@87,@)'1Y
M<&4@/3X@)'-E8W1I;VXI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1T
M>7!E(#T]("=M86EN)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'-E
M8W1I;VY;)V1A=&$G72`](&%R<F%Y7W9A;'5E<R@D<V5C=&EO;ELG9&%T82==
M*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^;W5T<'5T1&%T82@D<V5C=&EO;BD[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S
M92`G:6YS=&%L;"<Z#0H@("`@("`@("`@("!C87-E("=U<&=R861E)SH-"B`@
M("`@("`@("`@(&-A<V4@)W5P9W)A9&4M86QL)SH-"B`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)&1A=&%;)W)E;&5A<V5?=V%R;FEN9W,G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D:7-P;&%Y3&EN92@G)RD[#0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<W1A<G1486)L92AA<G)A>2@-
M"B`@("`@("`@("`@("`@("`@("`@("`@("=B;W)D97(G(#T^(&9A;'-E+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@)V-A<'1I;VXG(#T^("=296QE87-E
M(%=A<FYI;F=S)PT*("`@("`@("`@("`@("`@("`@("`@("`@*2D[#0H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?=&%B;&52;W<H87)R87DH)&1A=&%;
M)W)E;&5A<V5?=V%R;FEN9W,G72DL(&YU;&PL(&%R<F%Y*#$@/3X@87)R87DH
M)W=R87`G(#T^(#4U*2DI.PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V5N9%1A8FQE*"D[#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&ES
M<&QA>4QI;F4H)R<I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`D=&AI<RT^7V1I<W!L87E,:6YE*"1D871A6R=D871A)UTI.PT*("`@
M("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G<V5A<F-H
M)SH-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W-T87)T5&%B;&4H)&1A=&$I
M.PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&%T85LG:&5A9&QI;F4G
M72D@)B8@:7-?87)R87DH)&1A=&%;)VAE861L:6YE)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?=&%B;&52;W<H)&1A=&%;)VAE861L:6YE
M)UTL(&%R<F%Y*"=B;VQD)R`]/B!T<G5E*2P@87)R87DH,2`]/B!A<G)A>2@G
M=W)A<"<@/3X@-34I*2D[#0H@("`@("`@("`@("`@("`@?0T*#0H@("`@("`@
M("`@("`@("`@9F]R96%C:"@D9&%T85LG9&%T82==(&%S("1C871E9V]R>2D@
M>PT*("`@("`@("`@("`@("`@("`@("!F;W)E86-H*"1C871E9V]R>2!A<R`D
M<&MG*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W1A8FQE
M4F]W*"1P:V<L(&YU;&PL(&%R<F%Y*#$@/3X@87)R87DH)W=R87`G(#T^(#4U
M*2DI.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M?3L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V5N9%1A8FQE*"D[#0H@("`@
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=L:7-T+6%L
M;"<Z#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]S=&%R=%1A8FQE*"1D871A
M*3L-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1A=&%;)VAE861L:6YE
M)UTI("8F(&ES7V%R<F%Y*"1D871A6R=H96%D;&EN92==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W1A8FQE4F]W*"1D871A6R=H96%D;&EN
M92==+"!A<G)A>2@G8F]L9"<@/3X@=')U92DL(&%R<F%Y*#$@/3X@87)R87DH
M)W=R87`G(#T^(#4U*2DI.PT*("`@("`@("`@("`@("`@('T-"@T*("`@("`@
M("`@("`@("`@(&9O<F5A8V@H)&1A=&%;)V1A=&$G72!A<R`D8V%T96=O<GDI
M('L-"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"@D8V%T96=O<GD@87,@
M)'!K9RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)'!K9ULT
M72D[#0H@("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D<&MG6S5=*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=&%B;&52;W<H)'!K
M9RP@;G5L;"P@87)R87DH,2`]/B!A<G)A>2@G=W)A<"<@/3X@-34I*2D[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!].PT*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?96YD5&%B;&4H*3L-"B`@("`@("`@("`@
M("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)V-O;F9I9RUS:&]W)SH-
M"B`@("`@("`@("`@("`@("`D9&%T85LG8F]R9&5R)UT@/2!F86QS93L-"B`@
M("`@("`@("`@("`@("`D;W!T<R`](&%R<F%Y*#`@/3X@87)R87DH)W=R87`G
M(#T^(#,P*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#$@/3X@
M87)R87DH)W=R87`G(#T^(#(P*2P-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#(@/3X@87)R87DH)W=R87`G(#T^(#,U*2D[#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]S=&%R=%1A8FQE*"1D871A*3L-"B`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)&1A=&%;)VAE861L:6YE)UTI("8F(&ES7V%R<F%Y
M*"1D871A6R=H96%D;&EN92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W1A8FQE4F]W*"1D871A6R=H96%D;&EN92==+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=B;VQD)R`]/B!T
M<G5E*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M;W!T<RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&9O
M<F5A8V@H)&1A=&%;)V1A=&$G72!A<R`D9W)O=7`I('L-"B`@("`@("`@("`@
M("`@("`@("`@9F]R96%C:"@D9W)O=7`@87,@)'9A;'5E*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H)'9A;'5E6S)=(#T]("<G*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E6S)=(#T@(CQN;W0@<V5T
M/B([#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W1A8FQE4F]W*"1V86QU92P@;G5L;"P@)&]P
M=',I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("1T:&ES+3Y?96YD5&%B;&4H*3L-"B`@("`@
M("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)W)E;6]T92UI
M;F9O)SH-"B`@("`@("`@("`@("`@("`D9&%T82`](&%R<F%Y*`T*("`@("`@
M("`@("`@("`@("`@("`G8V%P=&EO;B<@/3X@)U!A8VMA9V4@9&5T86EL<SHG
M+`T*("`@("`@("`@("`@("`@("`@("`G8F]R9&5R)R`]/B!F86QS92P-"B`@
M("`@("`@("`@("`@("`@("`@)V1A=&$G(#T^(&%R<F%Y*`T*("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87DH(DQA=&5S="(L("`@("1D871A6R=S=&%B
M;&4G72DL#0H@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@B26YS=&%L
M;&5D(BP@)&1A=&%;)VEN<W1A;&QE9"==*2P-"B`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*")086-K86=E(BP@("`D9&%T85LG;F%M92==*2P-"B`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"),:6-E;G-E(BP@("`D9&%T
M85LG;&EC96YS92==*2P-"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*")#871E9V]R>2(L("`D9&%T85LG8V%T96=O<GDG72DL#0H@("`@("`@("`@
M("`@("`@("`@("`@("!A<G)A>2@B4W5M;6%R>2(L("`@)&1A=&%;)W-U;6UA
M<GDG72DL#0H@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@B1&5S8W)I
M<'1I;VXB+"`D9&%T85LG9&5S8W)I<'1I;VXG72DL#0H@("`@("`@("`@("`@
M("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("`@("`I.PT*("`@("`@
M("`@("`@9&5F875L=#H@>PT*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A
M>2@D9&%T82DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S=&%R
M=%1A8FQE*"1D871A*3L-"B`@("`@("`@("`@("`@("`@("`@)&-O=6YT(#T@
M8V]U;G0H)&1A=&%;)V1A=&$G75LP72D[#0H@("`@("`@("`@("`@("`@("`@
M(&EF("@D8V]U;G0@/3T@,BD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M)&]P=',@/2!A<G)A>2@P(#T^(&%R<F%Y*"=W<F%P)R`]/B`R-2DL#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#$@/3X@87)R87DH
M)W=R87`G(#T^(#0X*0T*("`@("`@("`@("`@("`@("`@("`@("`@*3L-"B`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1C;W5N="`]/2`S*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D;W!T<R`](&%R<F%Y*#`@/3X@87)R
M87DH)W=R87`G(#T^(#,P*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@,2`]/B!A<G)A>2@G=W)A<"<@/3X@,C`I+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`R(#T^(&%R<F%Y*"=W
M<F%P)R`]/B`S-2D-"B`@("`@("`@("`@("`@("`@("`@("`@("D[#0H@("`@
M("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D;W!T<R`](&YU;&P[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D871A6R=H96%D;&EN92==
M*2`F)B!I<U]A<G)A>2@D9&%T85LG:&5A9&QI;F4G72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?=&%B;&52;W<H)&1A=&%;)VAE861L
M:6YE)UTL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y*"=B;VQD)R`]/B!T<G5E*2P-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&]P=',I.PT*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@H)&1A=&%;
M)V1A=&$G72!A<R`D<F]W*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W1A8FQE4F]W*"1R;W<L(&YU;&PL("1O<'1S*3L-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V5N
M9%1A8FQE*"D[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]D:7-P;&%Y3&EN92@D9&%T82D[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&QO9RAT97AT*0T*#0H-"B`@
M("!F=6YC=&EO;B!L;V<H)'1E>'0L("1A<'!E;F1?8W)L9B`]('1R=64I#0H@
M("`@>PT*("`@("`@("!I9B`H)&%P<&5N9%]C<FQF*2![#0H@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]D:7-P;&%Y3&EN92@D=&5X="D[#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&ES<&QA>2@D=&5X="D[#0H@
M("`@?0T*#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@8F]L9"@D=&5X="D-
M"@T*("`@(&9U;F-T:6]N(&)O;&0H)'1E>'0I#0H@("`@>PT*("`@("`@("!I
M9B`H96UP='DH)'1H:7,M/G1E<FU;)V)O;&0G72DI('L-"B`@("`@("`@("`@
M(')E='5R;B!S=')T;W5P<&5R*"1T97AT*3L-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@)'1H:7,M/G1E<FU;)V)O;&0G72`N("1T97AT("X@)'1H:7,M
M/G1E<FU;)VYO<FUA;"==.PT*("`@('T-"@T*("`@("\O('U]?0T*?0T*#0H_
M/@T*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+U!%05(O26YS=&%L;&5R````````````````````````
M````````````````````````````````````````````````````,#`P-S4U
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S(@,#(Q
M,#<R`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]);G-T86QL97(O
M4F]L90``````````````````````````````````````````````````````
M```````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P
M,"`Q,#4Q-30S,S<S,2`P,C$W-S(`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]014%2+TEN<W1A;&QE<B]2;VQE+T-O;6UO;BYP:'``````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#$U,C0T(#$P-3$U-#,S-S,Q(#`R-#`R,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`T*+RHJ
M#0H@*B!"87-E(&-L87-S(&9O<B!A;&P@:6YS=&%L;&%T:6]N(')O;&5S+@T*
M("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@
M5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F
M('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G
M:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@
M*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U
M(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS
M92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B
M+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S
M;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J
M($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A
M=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C
M;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS
M92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@
M3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!#;VUM;VXN
M<&AP+'8@,2XQ,"`R,#`V+S`Q+S`V(#`T.C0W.C,W(&-E;&QO9R!%>'`@)`T*
M("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%
M05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A
M<V4@,2XT+C!A,0T*("HO#0HO*BH-"B`J($)A<V4@8VQA<W,@9F]R(&%L;"!I
M;G-T86QL871I;VX@<F]L97,N#0H@*@T*("H@5&AI<R!C;&%S<R!A;&QO=W,@
M97AT96YS:6)I;&ET>2!O9B!F:6QE(')O;&5S+B`@4&%C:V%G97,@=VET:"!C
M;VUP;&5X#0H@*B!C=7-T;VUI>F%T:6]N(&-A;B!N;W<@<')O=FED92!C=7-T
M;VT@9FEL92!R;VQE<R!A;&]N9R!W:71H('1H92!P;W-S:6)I;&ET>2!O9@T*
M("H@861D:6YG(&-O;F9I9W5R871I;VX@=F%L=65S('1O(&UA=&-H+@T*("H@
M0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U
M=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O
M<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J
M($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2
M#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S
M92`Q+C0N,&$Q#0H@*B\-"F-L87-S(%!%05)?26YS=&%L;&5R7U)O;&5?0V]M
M;6]N#0I[#0H@("`@+RHJ#0H@("`@("H@0'9A<B!014%27T-O;F9I9PT*("`@
M("`J($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@("`@=F%R("1C;VYF
M:6<[#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@4$5!4E]#;VYF:6<-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!014%27TEN<W1A;&QE<E]2;VQE7T-O;6UO
M;B@F)&-O;F9I9RD-"B`@("![#0H@("`@("`@("1T:&ES+3YC;VYF:6<@/2`D
M8V]N9FEG.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%)E=')I979E(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@86)O=70@82!F:6QE(')O;&4@9G)O
M;2!I=',@6$U,(&EN9F\-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@
M)')O;&4@4F]L92!#;&%S<VYA;64L(&%S(&EN(")014%27TEN<W1A;&QE<E]2
M;VQE7T1A=&$B#0H@("`@("H@0')E='5R;B!A<G)A>0T*("`@("`J+PT*("`@
M(&9U;F-T:6]N(&=E=$EN9F\H)')O;&4I#0H@("`@>PT*("`@("`@("!I9B`H
M96UP='DH)$=,3T)!3%-;)U]014%27TE.4U1!3$Q%4E]23TQ%4R==6R1R;VQE
M72DI('L-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=5
M;FMN;W=N(%)O;&4@8VQA<W,Z("(G("X@)')O;&4@+B`G(B<I.PT*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG7U!%05)?24Y35$%,3$52
M7U)/3$53)UU;)')O;&5=.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%1H
M:7,@:7,@8V%L;&5D(&9O<B!E86-H(&9I;&4@=&\@<V5T('5P('1H92!D:7)E
M8W1O<FEE<R!A;F0@9FEL97,-"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E
M1FEL95]V,7Q014%27U!A8VMA9V5&:6QE7W8R#0H@("`@("H@0'!A<F%M(&%R
M<F%Y(&%T=')I8G5T97,@9G)O;2!T:&4@/&9I;&4^('1A9PT*("`@("`J($!P
M87)A;2!S=')I;F<@9FEL92!N86UE#0H@("`@("H@0')E='5R;B!A<G)A>2!A
M;B!A<G)A>2!C;VYS:7-T:6YG(&]F.@T*("`@("`J#0H@("`@("H@("`@,2!T
M:&4@;W)I9VEN86PL('!R92UB87-E:6YS=&%L;&1I<B!I;G-T86QL871I;VX@
M9&ER96-T;W)Y#0H@("`@("H@("`@,B!T:&4@9FEN86P@:6YS=&%L;&%T:6]N
M(&1I<F5C=&]R>0T*("`@("`J("`@(#,@=&AE(&9U;&P@<&%T:"!T;R!T:&4@
M9FEN86P@;&]C871I;VX@;V8@=&AE(&9I;&4-"B`@("`@*B`@("`T('1H92!L
M;V-A=&EO;B!O9B!T:&4@<')E+6EN<W1A;&QA=&EO;B!F:6QE#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@<')O8V5S<TEN<W1A;&QA=&EO;B@D<&MG+"`D871T
M<RP@)&9I;&4L("1T;7!?<&%T:"P@)&QA>65R(#T@;G5L;"D-"B`@("![#0H@
M("`@("`@("1R;VQE26YF;R`](%!%05)?26YS=&%L;&5R7U)O;&5?0V]M;6]N
M.CIG971);F9O*"=014%27TEN<W1A;&QE<E]2;VQE7R<@+B`-"B`@("`@("`@
M("`@('5C9FER<W0H<W1R7W)E<&QA8V4H)W!E87)?:6YS=&%L;&5R7W)O;&5?
M)RP@)R<L('-T<G1O;&]W97(H9V5T7V-L87-S*"1T:&ES*2DI*2D[#0H@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1R;VQE26YF;RDI('L-"B`@("`@("`@
M("`@(')E='5R;B`D<F]L94EN9F\[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*"$D<F]L94EN9F];)VQO8V%T:6]N8V]N9FEG)UTI('L-"B`@("`@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)')O;&5)
M;F9O6R=H;VYO<G-B87-E:6YS=&%L;"==*2![#0H@("`@("`@("`@("`D9&5S
M=%]D:7(@/2`D<V%V95]D97-T9&ER(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"1R
M;VQE26YF;ULG;&]C871I;VYC;VYF:6<G72P@)&QA>65R+`T*("`@("`@("`@
M("`@("`@("1P:V<M/F=E=$-H86YN96PH*2D[#0H@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1A='1S6R=B87-E:6YS=&%L;&1I<B==*2D@>PT*("`@("`@("`@
M("`@("`@("1D97-T7V1I<B`N/2!$25)%0U1/4EE?4T5005)!5$]2("X@)&%T
M='-;)V)A<V5I;G-T86QL9&ER)UT[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T@96QS96EF("@D<F]L94EN9F];)W5N=7-U86QB87-E:6YS=&%L;"==*2![
M#0H@("`@("`@("`@("`D9&5S=%]D:7(@/2`D<V%V95]D97-T9&ER(#T@)'1H
M:7,M/F-O;F9I9RT^9V5T*"1R;VQE26YF;ULG;&]C871I;VYC;VYF:6<G72P-
M"B`@("`@("`@("`@("`@("`@("`@;G5L;"P@)'!K9RT^9V5T0VAA;FYE;"@I
M*2`N($1)4D5#5$]265]315!!4D%43U(@+B`D<&MG+3YG971086-K86=E*"D[
M#0H@("`@("`@("`@("!I9B`H(65M<'1Y*"1A='1S6R=B87-E:6YS=&%L;&1I
M<B==*2D@>PT*("`@("`@("`@("`@("`@("1D97-T7V1I<B`N/2!$25)%0U1/
M4EE?4T5005)!5$]2("X@)&%T='-;)V)A<V5I;G-T86QL9&ER)UT[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D9&5S
M=%]D:7(@/2`D<V%V95]D97-T9&ER(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"1R
M;VQE26YF;ULG;&]C871I;VYC;VYF:6<G72P-"B`@("`@("`@("`@("`@("`@
M("`@;G5L;"P@)'!K9RT^9V5T0VAA;FYE;"@I*2`N($1)4D5#5$]265]315!!
M4D%43U(@+B`D<&MG+3YG971086-K86=E*"D[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*&1I<FYA;64H)&9I;&4I("$]("<N)R`F)B!E;7!T>2@D871T<ULG
M:6YS=&%L;"UA<R==*2D@>PT*("`@("`@("`@("`@)&1E<W1?9&ER("X]($1)
M4D5#5$]265]315!!4D%43U(@+B!D:7)N86UE*"1F:6QE*3L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H96UP='DH)&%T='-;)VEN<W1A;&PM87,G72DI('L-
M"B`@("`@("`@("`@("1D97-T7V9I;&4@/2`D9&5S=%]D:7(@+B!$25)%0U1/
M4EE?4T5005)!5$]2("X@8F%S96YA;64H)&9I;&4I.PT*("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@)&1E<W1?9FEL92`]("1D97-T7V1I<B`N($1)
M4D5#5$]265]315!!4D%43U(@+B`D871T<ULG:6YS=&%L;"UA<R==.PT*("`@
M("`@("!]#0H@("`@("`@("1O<FEG7V9I;&4@/2`D=&UP7W!A=&@@+B!$25)%
M0U1/4EE?4T5005)!5$]2("X@)&9I;&4[#0H-"B`@("`@("`@+R\@0VQE86X@
M=7`@=&AE($1)4D5#5$]265]315!!4D%43U(@;65S<PT*("`@("`@("`D9',R
M(#T@1$E214-43U)97U-%4$%2051/4B`N($1)4D5#5$]265]315!!4D%43U([
M#0H@("`@("`@(`T*("`@("`@("!L:7-T*"1D97-T7V1I<BP@)&1E<W1?9FEL
M92P@)&]R:6=?9FEL92D@/2!P<F5G7W)E<&QA8V4H87)R87DH)R%<7%Q<*R$G
M+"`G(2\A)RP@(B$D9',R*R$B*2P-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2A$25)%0U1/4EE?
M4T5005)!5$]2+"!$25)%0U1/4EE?4T5005)!5$]2+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M($1)4D5#5$]265]315!!4D%43U(I+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1D97-T7V1I
M<BP@)&1E<W1?9FEL92P@)&]R:6=?9FEL92DI.PT*("`@("`@("!R971U<FX@
M87)R87DH)'-A=F5?9&5S=&1I<BP@)&1E<W1?9&ER+"`D9&5S=%]F:6QE+"`D
M;W)I9U]F:6QE*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE
M(&YA;64@;V8@=&AE(&-O;F9I9W5R871I;VX@=F%R:6%B;&4@=&AA="!S<&5C
M:69I97,@=&AE(&QO8V%T:6]N(&]F('1H:7,@9FEL90T*("`@("`J($!R971U
M<FX@<W1R:6YG?&9A;'-E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T3&]C
M871I;VY#;VYF:6<H*0T*("`@('L-"B`@("`@("`@)')O;&5);F9O(#T@4$5!
M4E]);G-T86QL97)?4F]L95]#;VUM;VXZ.F=E=$EN9F\H)U!%05)?26YS=&%L
M;&5R7U)O;&5?)R`N(`T*("`@("`@("`@("`@=6-F:7)S="AS=')?<F5P;&%C
M92@G<&5A<E]I;G-T86QL97)?<F]L95\G+"`G)RP@<W1R=&]L;W=E<BAG971?
M8VQA<W,H)'1H:7,I*2DI*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)')O;&5);F9O*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1R;VQE26YF;SL-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)')O;&5);F9O6R=L;V-A=&EO
M;F-O;F9I9R==.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($1O(&%N>2!U
M;G5S=6%L('-E='5P(&AE<F4-"B`@("`@*B!`<&%R86T@4$5!4E]);G-T86QL
M97(-"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E1FEL95]V,@T*("`@("`J
M($!P87)A;2!A<G)A>2!F:6QE(&%T=')I8G5T97,-"B`@("`@*B!`<&%R86T@
M<W1R:6YG(&9I;&4@;F%M90T*("`@("`J+PT*("`@(&9U;F-T:6]N('-E='5P
M*"8D:6YS=&%L;&5R+"`D<&MG+"`D871T<RP@)&9I;&4I#0H@("`@>PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N(&ES17AE8W5T86)L92@I#0H@("`@>PT*("`@
M("`@("`D<F]L94EN9F\@/2!014%27TEN<W1A;&QE<E]2;VQE7T-O;6UO;CHZ
M9V5T26YF;R@G4$5!4E]);G-T86QL97)?4F]L95\G("X@#0H@("`@("`@("`@
M("!U8V9I<G-T*'-T<E]R97!L86-E*"=P96%R7VEN<W1A;&QE<E]R;VQE7R<L
M("<G+"!S=')T;VQO=V5R*&=E=%]C;&%S<R@D=&AI<RDI*2DI.PT*("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F]L94EN9F\I*2![#0H@("`@("`@("`@
M("!R971U<FX@)')O;&5);F9O.PT*("`@("`@("!]#0H@("`@("`@(')E='5R
M;B`D<F]L94EN9F];)V5X96-U=&%B;&4G73L-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!I<TEN<W1A;&QA8FQE*"D-"B`@("![#0H@("`@("`@("1R;VQE26YF
M;R`](%!%05)?26YS=&%L;&5R7U)O;&5?0V]M;6]N.CIG971);F9O*"=014%2
M7TEN<W1A;&QE<E]2;VQE7R<@+B`-"B`@("`@("`@("`@('5C9FER<W0H<W1R
M7W)E<&QA8V4H)W!E87)?:6YS=&%L;&5R7W)O;&5?)RP@)R<L('-T<G1O;&]W
M97(H9V5T7V-L87-S*"1T:&ES*2DI*2D[#0H@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1R;VQE26YF;RDI('L-"B`@("`@("`@("`@(')E='5R;B`D<F]L
M94EN9F\[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1R;VQE26YF;ULG
M:6YS=&%L;&%B;&4G73L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!I<T5X=&5N
M<VEO;B@I#0H@("`@>PT*("`@("`@("`D<F]L94EN9F\@/2!014%27TEN<W1A
M;&QE<E]2;VQE7T-O;6UO;CHZ9V5T26YF;R@G4$5!4E]);G-T86QL97)?4F]L
M95\G("X@#0H@("`@("`@("`@("!U8V9I<G-T*'-T<E]R97!L86-E*"=P96%R
M7VEN<W1A;&QE<E]R;VQE7R<L("<G+"!S=')T;VQO=V5R*&=E=%]C;&%S<R@D
M=&AI<RDI*2DI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F]L94EN
M9F\I*2![#0H@("`@("`@("`@("!R971U<FX@)')O;&5);F9O.PT*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B`D<F]L94EN9F];)W!H<&5X=&5N<VEO;B==
M.PT*("`@('T-"GT-"C\^````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+TEN<W1A;&QE
M<B]2;VQE+T1A=&$N<&AP````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R
M,S(Q(#$P-3$U-#,S-S,Q(#`R,S0S,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`T*+RHJ#0H@*B!014%27TEN<W1A
M;&QE<E]2;VQE7T1A=&$-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*
M("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T
M;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@
M879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F
M;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@
M*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET
M('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L
M:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE
M9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G
M92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G
M0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'
M<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#
M5E,Z("1)9#H@1&%T82YP:'`L=B`Q+C8@,C`P-B\P,2\P-B`P-#HT-SHS-R!C
M96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN
M970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L
M92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*#0HO*BH-"B`J($!C871E
M9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@
M("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG
M:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS
M92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN
M:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@
M0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT
M+C!A,0T*("HO#0IC;&%S<R!014%27TEN<W1A;&QE<E]2;VQE7T1A=&$@97AT
M96YD<R!014%27TEN<W1A;&QE<E]2;VQE7T-O;6UO;B![?0T*/SX`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+U!%05(O26YS=&%L;&5R+U)O;&4O1&]C+GAM;```````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`U,3,@,3`U,34T,S,W,S$@,#(S,C<W
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#QR
M;VQE('9E<G-I;VX](C$N,"(^#0H@/')E;&5A<V5T>7!E<SYP:'`\+W)E;&5A
M<V5T>7!E<SX-"B`\<F5L96%S971Y<&5S/F5X='-R8SPO<F5L96%S971Y<&5S
M/@T*(#QR96QE87-E='EP97,^97AT8FEN/"]R96QE87-E='EP97,^#0H@/&EN
M<W1A;&QA8FQE/C$\+VEN<W1A;&QA8FQE/@T*(#QL;V-A=&EO;F-O;F9I9SYD
M;V-?9&ER/"]L;V-A=&EO;F-O;F9I9SX-"B`\:&]N;W)S8F%S96EN<W1A;&P@
M+SX-"B`\=6YU<W5A;&)A<V5I;G-T86QL("\^#0H@/'!H<&9I;&4@+SX-"B`\
M97AE8W5T86)L92`O/@T*(#QP:'!E>'1E;G-I;VX@+SX-"B`\8V]N9FEG7W9A
M<G,@+SX-"CPO<F]L93X`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]0
M14%2+TEN<W1A;&QE<B]2;VQE+T1O8RYP:'``````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`R,S$V(#$P-3$U-#,S-S,Q(#`R,S(W,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`T*+RHJ#0H@
M*B!014%27TEN<W1A;&QE<E]2;VQE7T1O8PT*("H-"B`J(%!(4"!V97)S:6]N
M<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I
M<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*
M("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A
M(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T
M;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@
M82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@
M82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-
M"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A
M=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P
M-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V
M97)S:6]N("`@($-64SH@)$ED.B!$;V,N<&AP+'8@,2XV(#(P,#8O,#$O,#8@
M,#0Z-#<Z,S<@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL
M92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"@T*+RHJ
M#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@
M*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@
M*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI
M8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@
M4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N
M.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E
M+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!2
M96QE87-E(#$N-"XP83$-"B`J+PT*8VQA<W,@4$5!4E]);G-T86QL97)?4F]L
M95]$;V,@97AT96YD<R!014%27TEN<W1A;&QE<E]2;VQE7T-O;6UO;B![?0T*
M/SX`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O26YS=&%L;&5R+U)O;&4O17AT
M+GAM;```````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`T-#,@,3`U,34T
M,S,W,S$@,#(S,S,T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#QR;VQE('9E<G-I;VX](C$N,"(^#0H@/')E;&5A<V5T>7!E
M<SYE>'1B:6X\+W)E;&5A<V5T>7!E<SX-"B`\:6YS=&%L;&%B;&4^,3PO:6YS
M=&%L;&%B;&4^#0H@/&QO8V%T:6]N8V]N9FEG/F5X=%]D:7(\+VQO8V%T:6]N
M8V]N9FEG/@T*(#QH;VYO<G-B87-E:6YS=&%L;#XQ/"]H;VYO<G-B87-E:6YS
M=&%L;#X-"B`\=6YU<W5A;&)A<V5I;G-T86QL("\^#0H@/'!H<&9I;&4@+SX-
M"B`\97AE8W5T86)L92`O/@T*(#QP:'!E>'1E;G-I;VX^,3PO<&AP97AT96YS
M:6]N/@T*(#QC;VYF:6=?=F%R<R`O/@T*/"]R;VQE/@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]014%2+TEN<W1A;&QE<B]2;VQE+T5X="YP:'``````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,S$V(#$P-3$U-#,S-S,Q(#`R,S,R
M-``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`T*+RHJ#0H@*B!014%27TEN<W1A;&QE<E]2;VQE7T5X=`T*("H-"B`J
M(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S
M;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!0
M2%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@
M=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P
M.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N
M;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@
M87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A
M<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C
M86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E
M9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@
M("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG
M:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS
M92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!%>'0N<&AP+'8@,2XV
M(#(P,#8O,#$O,#8@,#0Z-#<Z,S<@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@
M("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I
M;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q
M#0H@*B\-"@T*+RHJ#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G
M92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G
M0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'
M<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!2
M96QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP
M+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL
M86)L92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*8VQA<W,@4$5!4E])
M;G-T86QL97)?4F]L95]%>'0@97AT96YD<R!014%27TEN<W1A;&QE<E]2;VQE
M7T-O;6UO;B![?0T*/SX`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O26YS=&%L
M;&5R+U)O;&4O4&AP+GAM;```````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#`U-#<@,3`U,34T,S,W,S$@,#(S,S,P`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#QR;VQE('9E<G-I;VX](C$N,"(^#0H@
M/')E;&5A<V5T>7!E<SYP:'`\+W)E;&5A<V5T>7!E<SX-"B`\<F5L96%S971Y
M<&5S/F5X='-R8SPO<F5L96%S971Y<&5S/@T*(#QR96QE87-E='EP97,^97AT
M8FEN/"]R96QE87-E='EP97,^#0H@/&EN<W1A;&QA8FQE/C$\+VEN<W1A;&QA
M8FQE/@T*(#QL;V-A=&EO;F-O;F9I9SYP:'!?9&ER/"]L;V-A=&EO;F-O;F9I
M9SX-"B`\:&]N;W)S8F%S96EN<W1A;&P^,3PO:&]N;W)S8F%S96EN<W1A;&P^
M#0H@/'5N=7-U86QB87-E:6YS=&%L;"`O/@T*(#QP:'!F:6QE/C$\+W!H<&9I
M;&4^#0H@/&5X96-U=&%B;&4@+SX-"B`\<&AP97AT96YS:6]N("\^#0H@/&-O
M;F9I9U]V87)S("\^#0H\+W)O;&4^````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+TEN<W1A;&QE<B]2;VQE+U!H
M<"YP:'``````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,S$V(#$P-3$U
M-#,S-S,Q(#`R,S,Q,P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`T*+RHJ#0H@*B!014%27TEN<W1A;&QE<E]2;VQE
M7U!H<`T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#
M14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@
M,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@
M=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!5
M4DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@
M268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@
M3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T
M:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP
M+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*
M("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-
M"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-
M"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`
M;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT
M("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!0
M:'`N<&AP+'8@,2XW(#(P,#8O,#$O,#8@,#0Z-#<Z,S<@8V5L;&]G($5X<"`D
M#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O
M4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L
M96%S92`Q+C0N,&$Q#0H@*B\-"@T*+RHJ#0H@*B!`8V%T96=O<GD@("!P96%R
M#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E
M879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P
M,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`
M=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T
M<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@
M($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*
M8VQA<W,@4$5!4E]);G-T86QL97)?4F]L95]0:'`@97AT96YD<R!014%27TEN
M<W1A;&QE<E]2;VQE7T-O;6UO;B![?0T*/SX`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+U!%05(O26YS=&%L;&5R+U)O;&4O4V-R:7!T+GAM;```````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#`U-3(@,3`U,34T,S,W,S$@,#(T,#0Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#QR;VQE('9E<G-I
M;VX](C$N,"(^#0H@/')E;&5A<V5T>7!E<SYP:'`\+W)E;&5A<V5T>7!E<SX-
M"B`\<F5L96%S971Y<&5S/F5X='-R8SPO<F5L96%S971Y<&5S/@T*(#QR96QE
M87-E='EP97,^97AT8FEN/"]R96QE87-E='EP97,^#0H@/&EN<W1A;&QA8FQE
M/C$\+VEN<W1A;&QA8FQE/@T*(#QL;V-A=&EO;F-O;F9I9SYB:6Y?9&ER/"]L
M;V-A=&EO;F-O;F9I9SX-"B`\:&]N;W)S8F%S96EN<W1A;&P^,3PO:&]N;W)S
M8F%S96EN<W1A;&P^#0H@/'5N=7-U86QB87-E:6YS=&%L;"`O/@T*(#QP:'!F
M:6QE("\^#0H@/&5X96-U=&%B;&4^,3PO97AE8W5T86)L93X-"B`\<&AP97AT
M96YS:6]N("\^#0H@/&-O;F9I9U]V87)S("\^#0H\+W)O;&4^````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+TEN<W1A
M;&QE<B]2;VQE+U-C<FEP="YP:'``````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`R,S(W(#$P-3$U-#,S-S,Q(#`R-#`S,@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`T*+RHJ#0H@*B!014%27TEN
M<W1A;&QE<E]2;VQE7U-C<FEP=`T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N
M9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J
M96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA
M="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@
M=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@
M;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A
M:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E
M('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y
M(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P
M86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC
M96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@
M4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N
M("`@($-64SH@)$ED.B!38W)I<'0N<&AP+'8@,2XV(#(P,#8O,#$O,#8@,#0Z
M-#<Z,S<@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A
M<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A
M=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"@T*+RHJ#0H@
M*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`
M875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`
M8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N
M<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0
M($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.0T*
M("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%
M05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE
M87-E(#$N-"XP83$-"B`J+PT*8VQA<W,@4$5!4E]);G-T86QL97)?4F]L95]3
M8W)I<'0@97AT96YD<R!014%27TEN<W1A;&QE<E]2;VQE7T-O;6UO;B![?0T*
M/SX`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+U!%05(O26YS=&%L;&5R+U)O;&4O4W)C+GAM;```````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`S,S<@,3`U,34T,S,W,S$@,#(S
M,S(U`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#QR;VQE('9E<G-I;VX](C$N,"(^#0H@/')E;&5A<V5T>7!E<SYE>'1S<F,\
M+W)E;&5A<V5T>7!E<SX-"B`\:6YS=&%L;&%B;&4@+SX-"B`\;&]C871I;VYC
M;VYF:6<@+SX-"B`\:&]N;W)S8F%S96EN<W1A;&P@+SX-"B`\=6YU<W5A;&)A
M<V5I;G-T86QL("\^#0H@/'!H<&9I;&4@+SX-"B`\97AE8W5T86)L92`O/@T*
M(#QP:'!E>'1E;G-I;VX@+SX-"B`\8V]N9FEG7W9A<G,@+SX-"CPO<F]L93X`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]014%2+TEN<W1A;&QE<B]2;VQE+U-R8RYP:'``````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`R-#<Q(#$P-3$U-#,S-S,Q(#`R,S,Q-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`T*+RHJ
M#0H@*B!014%27TEN<W1A;&QE<E]2;VQE7U-R8PT*("H-"B`J(%!(4"!V97)S
M:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL
M92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS
M90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED
M92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV
M92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L
M92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E
M;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y
M;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E
M87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@
M0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M
M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J
M($!V97)S:6]N("`@($-64SH@)$ED.B!3<F,N<&AP+'8@,2XV(#(P,#8O,#$O
M,#8@,#0Z-#<Z,S<@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P
M.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@
M1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"@T*
M+RHJ#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2
M#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^
M#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@
M0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q
M+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K
M86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC
M92!296QE87-E(#$N-"XP83$-"B`J+PT*8VQA<W,@4$5!4E]);G-T86QL97)?
M4F]L95]3<F,@97AT96YD<R!014%27TEN<W1A;&QE<E]2;VQE7T-O;6UO;@T*
M>PT*("`@(&9U;F-T:6]N('-E='5P*"8D:6YS=&%L;&5R+"`D<&MG+"`D871T
M<RP@)&9I;&4I#0H@("`@>PT*("`@("`@("`D:6YS=&%L;&5R+3YS;W5R8V5?
M9FEL97,K*SL-"B`@("!]#0I]#0H_/@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O26YS=&%L;&5R+U)O;&4O
M5&5S="YX;6P`````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`U,30@,3`U
M,34T,S,W,S$@,#(S-3$R`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#QR;VQE('9E<G-I;VX](C$N,"(^#0H@/')E;&5A<V5T
M>7!E<SYP:'`\+W)E;&5A<V5T>7!E<SX-"B`\<F5L96%S971Y<&5S/F5X='-R
M8SPO<F5L96%S971Y<&5S/@T*(#QR96QE87-E='EP97,^97AT8FEN/"]R96QE
M87-E='EP97,^#0H@/&EN<W1A;&QA8FQE/C$\+VEN<W1A;&QA8FQE/@T*(#QL
M;V-A=&EO;F-O;F9I9SYT97-T7V1I<CPO;&]C871I;VYC;VYF:6<^#0H@/&AO
M;F]R<V)A<V5I;G-T86QL("\^#0H@/'5N=7-U86QB87-E:6YS=&%L;"`O/@T*
M(#QP:'!F:6QE("\^#0H@/&5X96-U=&%B;&4@+SX-"B`\<&AP97AT96YS:6]N
M("\^#0H@/&-O;F9I9U]V87)S("\^#0H\+W)O;&4^````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]014%2+TEN<W1A;&QE<B]2;VQE+U1E<W0N<&AP````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,S(Q(#$P-3$U-#,S-S,Q(#`R
M,S0W-P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`T*+RHJ#0H@*B!014%27TEN<W1A;&QE<E]2;VQE7U1E<W0-"B`J
M#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H
M:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T
M:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D
M:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@
M86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@
M<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@
M=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`
M8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T
M:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P
M>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@
M("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI
M8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@5&5S="YP:'`L
M=B`Q+C8@,C`P-B\P,2\P-B`P-#HT-SHS-R!C96QL;V<@17AP("0-"B`J($!L
M:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@
M*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N
M-"XP83$-"B`J+PT*#0HO*BH-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P
M86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC
M96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@
M4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N
M("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A
M<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@
M879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0IC;&%S<R!0
M14%27TEN<W1A;&QE<E]2;VQE7U1E<W0@97AT96YD<R!014%27TEN<W1A;&QE
M<E]2;VQE7T-O;6UO;B![?0T*/SX`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O26YS
M=&%L;&5R+U)O;&4O1&%T82YX;6P`````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`U,30@,3`U,34T,S,W,S$@,#(S-#0T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#QR;VQE('9E<G-I;VX](C$N,"(^
M#0H@/')E;&5A<V5T>7!E<SYP:'`\+W)E;&5A<V5T>7!E<SX-"B`\<F5L96%S
M971Y<&5S/F5X='-R8SPO<F5L96%S971Y<&5S/@T*(#QR96QE87-E='EP97,^
M97AT8FEN/"]R96QE87-E='EP97,^#0H@/&EN<W1A;&QA8FQE/C$\+VEN<W1A
M;&QA8FQE/@T*(#QL;V-A=&EO;F-O;F9I9SYD871A7V1I<CPO;&]C871I;VYC
M;VYF:6<^#0H@/&AO;F]R<V)A<V5I;G-T86QL("\^#0H@/'5N=7-U86QB87-E
M:6YS=&%L;"`O/@T*(#QP:'!F:6QE("\^#0H@/&5X96-U=&%B;&4@+SX-"B`\
M<&AP97AT96YS:6]N("\^#0H@/&-O;F9I9U]V87)S("\^#0H\+W)O;&4^````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+TEN<W1A;&QE<B]2;VQE
M+G!H<```````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#(P,C,R(#$P
M-3$U-#,S-S,R(#`R,C4V,@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`T*+RHJ#0H@*B!014%27TEN<W1A;&QE<E]2
M;VQE#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%
M3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S
M+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%52
M23H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)
M9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,
M:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H
M92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N
M;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@
M*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*
M("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*
M("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L
M:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@
M(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%)O
M;&4N<&AP+'8@,2XQ,R`R,#`V+S`Q+S`V(#`T.C0W.C,V(&-E;&QO9R!%>'`@
M)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E
M+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E
M;&5A<V4@,2XT+C!A,0T*("HO#0H-"B\J*@T*("H@8F%S92!C;&%S<R!F;W(@
M:6YS=&%L;&5R(')O;&5S#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!4B]);G-T
M86QL97(O4F]L92]#;VUM;VXN<&AP)SL-"G)E<75I<F5?;VYC92`G4$5!4B]8
M34Q087)S97(N<&AP)SL-"B\O)$=,3T)!3%-;)U]014%27TE.4U1!3$Q%4E]2
M3TQ%4R==(#T@87)R87DH*3L-"B\J*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*
M("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V
M97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V
M(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E
M<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z
M+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#
M;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"F-L
M87-S(%!%05)?26YS=&%L;&5R7U)O;&4-"GL-"B`@("`O*BH-"B`@("`@*B!3
M970@=7`@86YY(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!V87)I86)L97,@
M=&AA="!F:6QE(')O;&5S(')E<75I<F4-"B`@("`@*@T*("`@("`J($YE=F5R
M(&-A;&P@=&AI<R!D:7)E8W1L>2P@:70@:7,@8V%L;&5D(&)Y('1H92!014%2
M7T-O;F9I9R!C;VYS=')U8W1O<@T*("`@("`J($!P87)A;2!014%27T-O;F9I
M9PT*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J($!S=&%T:6,-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!I;FET:6%L:7IE0V]N9FEG*"8D8V]N9FEG
M*0T*("`@('L-"B`@("`@("`@:68@*"%I<W-E="@D1TQ/0D%,4ULG7U!%05)?
M24Y35$%,3$527U)/3$53)UTI*2![#0H@("`@("`@("`@("!014%27TEN<W1A
M;&QE<E]2;VQE.CIR96=I<W1E<E)O;&5S*"D[#0H@("`@("`@('T-"B`@("`@
M("`@9F]R96%C:"`H)$=,3T)!3%-;)U]014%27TE.4U1!3$Q%4E]23TQ%4R==
M(&%S("1C;&%S<R`]/B`D:6YF;RD@>PT*("`@("`@("`@("`@:68@*"$D:6YF
M;ULG8V]N9FEG7W9A<G,G72D@>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&-O;F9I9RT^7V%D9$-O
M;F9I9U9A<G,H)&EN9F];)V-O;F9I9U]V87)S)UTI.PT*("`@("`@("!]#0H@
M("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(%!%05)?4&%C:V%G949I
M;&5?=C(-"B`@("`@*B!`<&%R86T@<W1R:6YG(')O;&4@;F%M90T*("`@("`J
M($!P87)A;2!014%27T-O;F9I9PT*("`@("`J($!R971U<FX@4$5!4E]);G-T
M86QL97)?4F]L95]#;VUM;VX-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@)F9A8W1O<GDH)'!K9RP@)')O;&4L("8D8V]N9FEG*0T*
M("`@('L-"B`@("`@("`@:68@*"%I<W-E="@D1TQ/0D%,4ULG7U!%05)?24Y3
M5$%,3$527U)/3$53)UTI*2![#0H@("`@("`@("`@("!014%27TEN<W1A;&QE
M<E]2;VQE.CIR96=I<W1E<E)O;&5S*"D[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*"%I;E]A<G)A>2@D<F]L92P@4$5!4E]);G-T86QL97)?4F]L93HZ9V5T
M5F%L:612;VQE<R@D<&MG+3YG971086-K86=E5'EP92@I*2DI('L-"B`@("`@
M("`@("`@("1A(#T@9F%L<V4[#0H@("`@("`@("`@("!R971U<FX@)&$[#0H@
M("`@("`@('T-"B`@("`@("`@)&$@/2`G4$5!4E]);G-T86QL97)?4F]L95\G
M("X@=6-F:7)S="@D<F]L92D[#0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S
M*"1A*2D@>PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E('-T<E]R97!L86-E
M*"=?)RP@)R\G+"`D82D@+B`G+G!H<"<[#0H@("`@("`@('T-"B`@("`@("`@
M)&(@/2!N97<@)&$H)&-O;F9I9RD[#0H@("`@("`@(')E='5R;B`D8CL-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`@*B!'970@82!L:7-T(&]F(&9I;&4@<F]L
M97,@=&AA="!A<F4@=F%L:60@9F]R('1H92!P87)T:6-U;&%R(')E;&5A<V4@
M='EP92X-"B`@("`@*@T*("`@("`J($9O<B!I;G-T86YC92P@<W)C(&9I;&5S
M('-E<G9E(&YO('!U<G!O<V4@:6X@<F5G=6QA<B!P:'`@<F5L96%S97,N("!P
M:'`@9FEL97,-"B`@("`@*B!S97)V92!N;R!P=7)P;W-E(&EN(&5X='-R8R!O
M<B!E>'1B:6X@<F5L96%S97,-"B`@("`@*B!`<&%R86T@<W1R:6YG#0H@("`@
M("H@0'!A<F%M(&)O;VP@8VQE87(@8V%C:&4-"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E
M=%9A;&ED4F]L97,H)')E;&5A<V4L("1C;&5A<B`](&9A;'-E*0T*("`@('L-
M"B`@("`@("`@:68@*"%I<W-E="@D1TQ/0D%,4ULG7U!%05)?24Y35$%,3$52
M7U)/3$53)UTI*2![#0H@("`@("`@("`@("!014%27TEN<W1A;&QE<E]2;VQE
M.CIR96=I<W1E<E)O;&5S*"D[#0H@("`@("`@('T-"B`@("`@("`@<W1A=&EC
M("1R970@/2!A<G)A>2@I.PT*("`@("`@("!I9B`H)&-L96%R*2![#0H@("`@
M("`@("`@("`D<F5T(#T@87)R87DH*3L-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H:7-S970H)')E=%LD<F5L96%S95TI*2![#0H@("`@("`@("`@("!R971U
M<FX@)')E=%LD<F5L96%S95T[#0H@("`@("`@('T-"B`@("`@("`@)')E=%LD
M<F5L96%S95T@/2!A<G)A>2@I.PT*("`@("`@("!F;W)E86-H("@D1TQ/0D%,
M4ULG7U!%05)?24Y35$%,3$527U)/3$53)UT@87,@)')O;&4@/3X@)&]K<F5L
M96%S97,I('L-"B`@("`@("`@("`@(&EF("AI;E]A<G)A>2@D<F5L96%S92P@
M)&]K<F5L96%S97-;)W)E;&5A<V5T>7!E<R==*2D@>PT*("`@("`@("`@("`@
M("`@("1R971;)')E;&5A<V5=6UT@/2!S=')T;VQO=V5R*'-T<E]R97!L86-E
M*"=014%27TEN<W1A;&QE<E]2;VQE7R<L("<G+"`D<F]L92DI.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<F5T6R1R96QE
M87-E73L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!'970@82!L:7-T(&]F
M(')O;&5S('1H870@<F5Q=6ER92!T:&5I<B!F:6QE<R!T;R!B92!I;G-T86QL
M960-"B`@("`@*@T*("`@("`J($UO<W0@<F]L97,@;75S="!B92!I;G-T86QL
M960L(&)U="!S<F,@86YD('!A8VMA9V4@<F]L97,L(&9O<B!I;G-T86YC90T*
M("`@("`J(&%R92!P<V5U9&\M<F]L97,N("!S<F,@9FEL97,@87)E(&-O;7!I
M;&5D(&EN=&\@82!N97<@97AT96YS:6]N+B`@4&%C:V%G90T*("`@("`J(')O
M;&5S(&%R92!A8W1U86QL>2!F=6QL>2!B=6YD;&5D(')E;&5A<V5S(&]F(&$@
M<&%C:V%G90T*("`@("`J($!P87)A;2!B;V]L(&-L96%R(&-A8VAE#0H@("`@
M("H@0')E='5R;B!A<G)A>0T*("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!G971);G-T86QL86)L95)O;&5S*"1C;&5A<B`](&9A;'-E
M*0T*("`@('L-"B`@("`@("`@:68@*"%I<W-E="@D1TQ/0D%,4ULG7U!%05)?
M24Y35$%,3$527U)/3$53)UTI*2![#0H@("`@("`@("`@("!014%27TEN<W1A
M;&QE<E]2;VQE.CIR96=I<W1E<E)O;&5S*"D[#0H@("`@("`@('T-"B`@("`@
M("`@<W1A=&EC("1R970[#0H@("`@("`@(&EF("@D8VQE87(I('L-"B`@("`@
M("`@("`@('5N<V5T*"1R970I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A
M:7-S970H)')E="DI('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1'3$]"04Q3
M6R=?4$5!4E])3E-404Q,15)?4D],15,G72!A<R`D<F]L92`]/B`D;VMR96QE
M87-E<RD@>PT*("`@("`@("`@("`@("`@(&EF("@D;VMR96QE87-E<ULG:6YS
M=&%L;&%B;&4G72D@>PT*("`@("`@("`@("`@("`@("`@("`D<F5T6UT@/2!S
M=')T;VQO=V5R*'-T<E]R97!L86-E*"=014%27TEN<W1A;&QE<E]2;VQE7R<L
M("<G+"`D<F]L92DI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-
M"B`@("`O*BH-"B`@("`@*B!2971U<FX@86X@87)R87D@;V8@<F]L97,@=&AA
M="!A<F4@869F96-T960@8GD@=&AE(&)A<V5I;G-T86QL9&ER(&%T=')I8G5T
M90T*("`@("`J#0H@("`@("H@36]S="!R;VQE<R!I9VYO<F4@=&AI<R!A='1R
M:6)U=&4L(&%N9"!I;G-T96%D(&EN<W1A;&P@9&ER96-T;'D@:6YT;SH-"B`@
M("`@*B!086-K86=E3F%M92]F:6QE<&%T:`T*("`@("`J('-O(&$@=&5S=',@
M9FEL92!T97-T<R]F:6QE+G!H<'0@:7,@:6YS=&%L;&5D(&EN=&\@4&%C:V%G
M94YA;64O=&5S=',O9FEL97!A=&@N<&AP#0H@("`@("H@0'!A<F%M(&)O;VP@
M8VQE87(@8V%C:&4-"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@("`@("H@0'-T
M871I8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$)A<V5I;G-T86QL4F]L
M97,H)&-L96%R(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H(6ES<V5T
M*"1'3$]"04Q36R=?4$5!4E])3E-404Q,15)?4D],15,G72DI('L-"B`@("`@
M("`@("`@(%!%05)?26YS=&%L;&5R7U)O;&4Z.G)E9VES=&5R4F]L97,H*3L-
M"B`@("`@("`@?0T*("`@("`@("!S=&%T:6,@)')E=#L-"B`@("`@("`@:68@
M*"1C;&5A<BD@>PT*("`@("`@("`@("`@=6YS970H)')E="D[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"%I<W-E="@D<F5T*2D@>PT*("`@("`@("`@("`@
M9F]R96%C:"`H)$=,3T)!3%-;)U]014%27TE.4U1!3$Q%4E]23TQ%4R==(&%S
M("1R;VQE(#T^("1O:W)E;&5A<V5S*2![#0H@("`@("`@("`@("`@("`@:68@
M*"1O:W)E;&5A<V5S6R=H;VYO<G-B87-E:6YS=&%L;"==*2![#0H@("`@("`@
M("`@("`@("`@("`@("1R971;72`]('-T<G1O;&]W97(H<W1R7W)E<&QA8V4H
M)U!%05)?26YS=&%L;&5R7U)O;&5?)RP@)R<L("1R;VQE*2D[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B`D<F5T.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%)E='5R
M;B!A;B!A<G)A>2!O9B!F:6QE(')O;&5S('1H870@<VAO=6QD(&)E(&%N86QY
M>F5D(&9O<B!02%`@8V]N=&5N="!A="!P86-K86=E('1I;64L#0H@("`@("H@
M;&EK92!T:&4@(G!H<"(@<F]L92X-"B`@("`@*B!`<&%R86T@8F]O;"!C;&5A
M<B!C86-H90T*("`@("`J($!R971U<FX@87)R87D-"B`@("`@*B!`<W1A=&EC
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T4&AP4F]L97,H)&-L96%R(#T@
M9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H(6ES<V5T*"1'3$]"04Q36R=?
M4$5!4E])3E-404Q,15)?4D],15,G72DI('L-"B`@("`@("`@("`@(%!%05)?
M26YS=&%L;&5R7U)O;&4Z.G)E9VES=&5R4F]L97,H*3L-"B`@("`@("`@?0T*
M("`@("`@("!S=&%T:6,@)')E=#L-"B`@("`@("`@:68@*"1C;&5A<BD@>PT*
M("`@("`@("`@("`@=6YS970H)')E="D[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*"%I<W-E="@D<F5T*2D@>PT*("`@("`@("`@("`@9F]R96%C:"`H)$=,
M3T)!3%-;)U]014%27TE.4U1!3$Q%4E]23TQ%4R==(&%S("1R;VQE(#T^("1O
M:W)E;&5A<V5S*2![#0H@("`@("`@("`@("`@("`@:68@*"1O:W)E;&5A<V5S
M6R=P:'!F:6QE)UTI('L-"B`@("`@("`@("`@("`@("`@("`@)')E=%M=(#T@
M<W1R=&]L;W=E<BAS=')?<F5P;&%C92@G4$5!4E]);G-T86QL97)?4F]L95\G
M+"`G)RP@)')O;&4I*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*
M#0H@("`@+RHJ#0H@("`@("H@4V-A;B!T:')O=6=H('1H92!#;VUM86YD(&1I
M<F5C=&]R>2!L;V]K:6YG(&9O<B!C;&%S<V5S#0H@("`@("H@86YD('-E92!W
M:&%T(&-O;6UA;F1S('1H97D@:6UP;&5M96YT+@T*("`@("`J($!P87)A;2!S
M=')I;F<@=VAI8V@@9&ER96-T;W)Y('1O(&QO;VL@9F]R(&-L87-S97,L(&1E
M9F%U;'1S('1O#0H@("`@("H@("`@("`@("`@("`@("!T:&4@26YS=&%L;&5R
M+U)O;&5S('-U8F1I<F5C=&]R>2!O9@T*("`@("`J("`@("`@("`@("`@("`@
M=&AE(&1I<F5C=&]R>2!F<F]M('=H97)E('1H:7,@9FEL92`H7U]&24Q%7U\I
M(&ES#0H@("`@("H@("`@("`@("`@("`@("!I;F-L=61E9"X-"B`@("`@*@T*
M("`@("`J($!R971U<FX@8F]O;"!44E5%(&]N('-U8V-E<W,L(&$@4$5!4B!E
M<G)O<B!O;B!F86EL=7)E#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@
M*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<F5G:7-T97)2;VQE
M<R@D9&ER(#T@;G5L;"D-"B`@("![#0H@("`@("`@("1P87)S97(@/2!N97<@
M4$5!4E]834Q087)S97([#0H@("`@("`@(&EF("@D9&ER(#T]/2!N=6QL*2![
M#0H@("`@("`@("`@("`D9&ER(#T@9&ER;F%M92A?7T9)3$5?7RD@+B`G+U)O
M;&4G.PT*("`@("`@("!]#0H@("`@("`@("1D<"`]($!O<&5N9&ER*"1D:7(I
M.PT*("`@("`@("!I9B`H96UP='DH)&1P*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H(G)E9VES=&5R4F]L97,Z(&]P96YD:7(H
M)&1I<BD@9F%I;&5D(BD[#0H@("`@("`@('T-"B`@("`@("`@=VAI;&4@*"1E
M;G1R>2`](')E861D:7(H)&1P*2D@>PT*("`@("`@("`@("`@:68@*"1E;G1R
M>7LP?2`]/2`G+B<@?'P@<W5B<W1R*"1E;G1R>2P@+30I("$]("<N>&UL)RD@
M>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@)&-L87-S(#T@(E!%05)?26YS=&%L;&5R7U)O;&5?(BYS
M=6)S='(H)&5N=')Y+"`P+"`M-"D[#0H@("`@("`@("`@("`O+R!,:7-T(&]F
M(')O;&5S#0H@("`@("`@("`@("!I9B`H96UP='DH)$=,3T)!3%-;)U]014%2
M7TE.4U1!3$Q%4E]23TQ%4R==6R1C;&%S<UTI*2![#0H@("`@("`@("`@("`@
M("`@)&9I;&4@/2`B)&1I<B\D96YT<GDB.PT*("`@("`@("`@("`@("`@("1P
M87)S97(M/G!A<G-E*&9I;&5?9V5T7V-O;G1E;G1S*"1F:6QE*2D[#0H@("`@
M("`@("`@("`@("`@)&1A=&$@/2`D<&%R<V5R+3YG971$871A*"D[#0H@("`@
M("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D9&%T85LG<F5L96%S971Y<&5S
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1D871A6R=R96QE87-E='EP
M97,G72`](&%R<F%Y*"1D871A6R=R96QE87-E='EP97,G72D[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1'3$]"04Q36R=?4$5!4E])
M3E-404Q,15)?4D],15,G75LD8VQA<W-=(#T@)&1A=&$[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@0&-L;W-E9&ER*"1D<"D[#0H@("`@
M("`@(&MS;W)T*"1'3$]"04Q36R=?4$5!4E])3E-404Q,15)?4D],15,G72D[
M#0H@("`@("`@(%!%05)?26YS=&%L;&5R7U)O;&4Z.F=E=$)A<V5I;G-T86QL
M4F]L97,H=')U92D[#0H@("`@("`@(%!%05)?26YS=&%L;&5R7U)O;&4Z.F=E
M=$EN<W1A;&QA8FQE4F]L97,H=')U92D[#0H@("`@("`@(%!%05)?26YS=&%L
M;&5R7U)O;&4Z.F=E=%!H<%)O;&5S*'1R=64I.PT*("`@("`@("!014%27TEN
M<W1A;&QE<E]2;VQE.CIG971686QI9%)O;&5S*"<J*BHJ)RP@=')U92D[#0H@
M("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"GT-"C\^#0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]014%2+U!A8VMA9V5&:6QE````````````````
M`````````````````````````````````````````````````````````#`P
M,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S,R
M(#`R,3(W,``@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O4&%C:V%G
M949I;&4O1V5N97)A=&]R````````````````````````````````````````
M````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#`P,#`@,3`U,34T,S,W,S(@,#(S,C$V`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O4$5!4B]086-K86=E1FEL92]'96YE<F%T;W(O=C(N<&AP````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#$W,C`P,"`Q,#4Q-30S,S<S,B`P,C0S,S4`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`-
M"B\J*@T*("H@<&%C:V%G92YX;6P@9V5N97)A=&EO;B!C;&%S<RP@<&%C:V%G
M92YX;6P@=F5R<VEO;B`R+C`-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@
M-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C
M="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@
M:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H
M92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F
M#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN
M(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T
M;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I
M;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C
M:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L
M;&]G0'!H<"YN970^#0H@*B!`875T:&]R("`@("!3=&5P:&%N(%-C:&UI9'0@
M*&]R:6=I;F%L(%A-3%]397)I86QI>F5R(&-O9&4I#0H@*B!`8V]P>7)I9VAT
M("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@
M,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@=C(N<&AP+'8@,2XS-"`R
M,#`V+S`S+S`R(#(P.C4P.C4Y(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@
M("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC
M92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*
M("HO#0HO*BH-"B`J(&9I;&4O9&ER(&UA;FEP=6QA=&EO;B!R;W5T:6YE<PT*
M("HO#0IR97%U:7)E7V]N8V4@)U-Y<W1E;2YP:'`G.PT*+RHJ#0H@*B!4:&ES
M(&-L87-S(&-O;G9E<G1S(&$@4$5!4E]086-K86=E1FEL95]V,B!O8FIE8W0@
M:6YT;R!A;GD@;W5T<'5T(&9O<FUA="X-"B`J#0H@*B!3=7!P;W)T960@;W5T
M<'5T(&9O<FUA=',@:6YC;'5D92!A<G)A>2P@6$U,('-T<FEN9R`H=7-I;F<@
M4RX@4V-H;6ED="=S#0H@*B!834Q?4V5R:6%L:7IE<BP@<VQI9VAT;'D@8W5S
M=&]M:7IE9"D-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@
M(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP
M+FYE=#X-"B`J($!A=71H;W(@("`@(%-T97!H86X@4V-H;6ED="`H;W)I9VEN
M86P@6$U,7U-E<FEA;&EZ97(@8V]D92D-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M
M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J
M($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H
M='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@
M("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO
M#0IC;&%S<R!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,@T*>PT*("`@
M+RHJ#0H@("`@*B!D969A=6QT(&]P=&EO;G,@9F]R('1H92!S97)I86QI>F%T
M:6]N#0H@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`J($!V87(@87)R87D@
M)%]D969A=6QT3W!T:6]N<PT*("`@("HO#0H@("`@=F%R("1?9&5F875L=$]P
M=&EO;G,@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`G:6YD
M96YT)R`@("`@("`@("`@("`]/B`G("<L("`@("`@("`@("`@("`@("`@("`O
M+R!S=')I;F<@=7-E9"!F;W(@:6YD96YT871I;VX-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`G;&EN96)R96%K)R`@("`@("`@("`]/B`B7&XB+"`@("`@
M("`@("`@("`@("`@("\O('-T<FEN9R!U<V5D(&9O<B!N97=L:6YE<PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("=T>7!E2&EN=',G("`@("`@("`@(#T^
M(&9A;'-E+"`@("`@("`@("`@("`@("`@+R\@875T;VUA=&EC86QL>2!A9&0@
M='EP92!H:6X@871T<FEB=71E<PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("=A9&1$96-L)R`@("`@("`@("`@(#T^('1R=64L("`@("`@("`@("`@("`@
M("`O+R!A9&0@86X@6$U,(&1E8VQA<F%T:6]N#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@)V1E9F%U;'1486=.86UE)R`@("`@/3X@)UA-3%]397)I86QI
M>F5R7U1A9R<L("`O+R!T86<@=7-E9"!F;W(@:6YD97AE9"!A<G)A>7,@;W(@
M:6YV86QI9"!N86UE<PT*("`@("`@("`@("`@("`@("`@("`@("`@("=C;&%S
M<T%S5&%G3F%M92<@("`@(#T^(&9A;'-E+"`@("`@("`@("`@("`@("`@+R\@
M=7-E(&-L87-S;F%M92!F;W(@;V)J96-T<R!I;B!I;F1E>&5D(&%R<F%Y<PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("=K97E!='1R:6)U=&4G("`@("`@
M(#T^("=?;W)I9VEN86Q+97DG+"`@("`@("`@+R\@871T<FEB=71E('=H97)E
M(&]R:6=I;F%L(&ME>2!I<R!S=&]R960-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`G='EP94%T=')I8G5T92<@("`@("`]/B`G7W1Y<&4G+"`@("`@("`@
M("`@("`@("\O(&%T=')I8G5T92!F;W(@='EP92`H;VYL>2!I9B!T>7!E2&EN
M=',@/3X@=')U92D-"B`@("`@("`@("`@("`@("`@("`@("`@("`G8VQA<W-!
M='1R:6)U=&4G("`@("`]/B`G7V-L87-S)RP@("`@("`@("`@("`@("\O(&%T
M=')I8G5T92!F;W(@8VQA<W,@;V8@;V)J96-T<R`H;VYL>2!I9B!T>7!E2&EN
M=',@/3X@=')U92D-"B`@("`@("`@("`@("`@("`@("`@("`@("`G<V-A;&%R
M07-!='1R:6)U=&5S)R`]/B!F86QS92P@("`@("`@("`@("`@("`@("\O('-C
M86QA<B!V86QU97,@*'-T<FEN9W,L(&EN=',L+BXI('=I;&P@8F4@<V5R:6%L
M:7IE9"!A<R!A='1R:6)U=&4-"B`@("`@("`@("`@("`@("`@("`@("`@("`G
M<')E<&5N9$%T=')I8G5T97,G("`]/B`G)RP@("`@("`@("`@("`@("`@("`@
M("\O('!R97!E;F0@<W1R:6YG(&9O<B!A='1R:6)U=&5S#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@)VEN9&5N=$%T=')I8G5T97,G("`@/3X@9F%L<V4L
M("`@("`@("`@("`@("`@("`O+R!I;F1E;G0@=&AE(&%T=')I8G5T97,L(&EF
M('-E="!T;R`G7V%U=&\G+"!I="!W:6QL(&EN9&5N="!A='1R:6)U=&5S('-O
M('1H97D@86QL('-T87)T(&%T('1H92!S86UE(&-O;'5M;@T*("`@("`@("`@
M("`@("`@("`@("`@("`@("=M;V1E)R`@("`@("`@("`@("`@(#T^("=S:6UP
M;&5X;6PG+"`@("`@("`@("`@("`O+R!U<V4@)W-I;7!L97AM;"<@=&\@=7-E
M('!A<F5N="!N86UE(&%S('1A9VYA;64@:68@=')A;G-F;W)M:6YG(&%N(&EN
M9&5X960@87)R87D-"B`@("`@("`@("`@("`@("`@("`@("`@("`G861D1&]C
M='EP92<@("`@("`@("`]/B!F86QS92P@("`@("`@("`@("`@("`@("\O(&%D
M9"!A(&1O8W1Y<&4@9&5C;&%R871I;VX-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`G9&]C='EP92<@("`@("`@("`@("`]/B!N=6QL+"`@("`@("`@("`@
M("`@("`@("\O('-U<'!L>2!A('-T<FEN9R!O<B!A;B!A<G)A>2!W:71H(&ED
M(&%N9"!U<FD@*'M`<V5E(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R
M7U!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL.CIG971$
M;V-T>7!E1&5C;&%R871I;VXH*7T-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`G<F]O=$YA;64G("`@("`@("`@("`]/B`G<&%C:V%G92<L("`@("`@("`@
M("`@("`@("`@+R\@;F%M92!O9B!T:&4@<F]O="!T86<-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`G<F]O=$%T=')I8G5T97,G("`@("`]/B!A<G)A>2@-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W9E<G-I;VXG(#T^("<R
M+C`G+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G>&UL;G,G(#T^
M("=H='1P.B\O<&5A<BYP:'`N;F5T+V1T9"]P86-K86=E+3(N,"<L#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=X;6QN<SIT87-K<R<@/3X@)VAT
M='`Z+R]P96%R+G!H<"YN970O9'1D+W1A<VMS+3$N,"<L#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=X;6QN<SIX<VDG(#T^("=H='1P.B\O=W=W
M+G<S+F]R9R\R,#`Q+UA-3%-C:&5M82UI;G-T86YC92<L#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=X<VDZ<V-H96UA3&]C871I;VXG(#T^("=H
M='1P.B\O<&5A<BYP:'`N;F5T+V1T9"]T87-K<RTQ+C`-"FAT='`Z+R]P96%R
M+G!H<"YN970O9'1D+W1A<VMS+3$N,"YX<V0-"FAT='`Z+R]P96%R+G!H<"YN
M970O9'1D+W!A8VMA9V4M,BXP#0IH='1P.B\O<&5A<BYP:'`N;F5T+V1T9"]P
M86-K86=E+3(N,"YX<V0G+`T*("`@("`@("`@("`@("`@("`@("`@("`@("DL
M("`@("`@("`@("`@("`@+R\@871T<FEB=71E<R!O9B!T:&4@<F]O="!T86<-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`G871T<FEB=71E<T%R<F%Y)R`@
M("`]/B`G871T<FEB<R<L("`@("`@("`@("`@("`@("`@+R\@86QL('9A;'5E
M<R!I;B!T:&ES(&ME>2!W:6QL(&)E('1R96%T960@87,@871T<FEB=71E<PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("=C;VYT96YT3F%M92<@("`@("`@
M(#T^("=?8V]N=&5N="<L("`@("`@("`@("`@("`@("`@("\O('1H:7,@=F%L
M=64@=VEL;"!B92!U<V5D(&1I<F5C=&QY(&%S(&-O;G1E;G0L(&EN<W1E860@
M;V8@8W)E871I;F<@82!N97<@=&%G+"!M87D@;VYL>2!B92!U<V5D(&EN(&-O
M;FIU8W1I;VX@=VET:"!A='1R:6)U=&5S07)R87D-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`G8F5A=71I9GE&:6QE;&ES="<@("`]/B!F86QS92P-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`G96YC;V1I;F<G(#T^("=55$8M."<L
M#0H@("`@("`@("`@("`@("`@("`@("`@("`I.PT*#0H@("`O*BH-"B`@("`J
M(&]P=&EO;G,@9F]R('1H92!S97)I86QI>F%T:6]N#0H@("`@*B!`86-C97-S
M('!R:79A=&4-"B`@("`J($!V87(@87)R87D@)&]P=&EO;G,-"B`@("`J+PT*
M("`@('9A<B`D;W!T:6]N<R`](&%R<F%Y*"D[#0H-"B`@("\J*@T*("`@("H@
M8W5R<F5N="!T86<@9&5P=&@-"B`@("`J($!V87(@:6YT96=E<B`D7W1A9T1E
M<'1H#0H@("`@*B\-"B`@("!V87(@)%]T86=$97!T:"`](#`[#0H-"B`@("\J
M*@T*("`@("H@<V5R:6QI86QI>F5D(')E<')E<V5N=&%T:6]N(&]F('1H92!D
M871A#0H@("`@*B!`=F%R('-T<FEN9R`D7W-E<FEA;&EZ961$871A#0H@("`@
M*B\-"B`@("!V87(@)%]S97)I86QI>F5D1&%T82`](&YU;&P[#0H@("`@+RHJ
M#0H@("`@("H@0'9A<B!014%27U!A8VMA9V5&:6QE7W8R#0H@("`@("HO#0H@
M("`@=F%R("1?<&%C:V%G969I;&4[#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M
M(%!%05)?4&%C:V%G949I;&5?=C(-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!0
M14%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,B@F)'!A8VMA9V5F:6QE*0T*
M("`@('L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E9FEL92`]("8D<&%C:V%G
M969I;&4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0')E='5R;B!S=')I
M;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971086-K86=E<E9E<G-I;VXH
M*0T*("`@('L-"B`@("`@("`@<F5T=7)N("<Q+C0N.2<[#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@0'!A<F%M(%!%05)?4&%C:V%G97(-"B`@("`@*B!`
M<&%R86T@8F]O;"!G96YE<F%T92!A("YT9WH@;W(@82`N=&%R#0H@("`@("H@
M0'!A<F%M('-T<FEN9WQN=6QL('1E;7!O<F%R>2!D:7)E8W1O<GD@=&\@<&%C
M:V%G92!I;@T*("`@("`J+PT*("`@(&9U;F-T:6]N('1O5&=Z*"8D<&%C:V%G
M97(L("1C;VUP<F5S<R`]('1R=64L("1W:&5R92`](&YU;&PI#0H@("`@>PT*
M("`@("`@("`D82`](&YU;&P[#0H@("`@("`@(')E='5R;B`D=&AI<RT^=&]4
M9WHR*"1P86-K86=E<BP@)&$L("1C;VUP<F5S<RP@)'=H97)E*3L-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!086-K86=E('5P(&)O=&@@82!P86-K86=E
M+GAM;"!A;F0@<&%C:V%G93(N>&UL(&9O<B!T:&4@<V%M92!R96QE87-E#0H@
M("`@("H@0'!A<F%M(%!%05)?4&%C:V%G97(-"B`@("`@*B!`<&%R86T@4$5!
M4E]086-K86=E1FEL95]V,0T*("`@("`J($!P87)A;2!B;V]L(&=E;F5R871E
M(&$@+G1G>B!O<B!A("YT87(-"B`@("`@*B!`<&%R86T@<W1R:6YG?&YU;&P@
M=&5M<&]R87)Y(&1I<F5C=&]R>2!T;R!P86-K86=E(&EN#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@=&]49WHR*"8D<&%C:V%G97(L("8D<&8Q+"`D8V]M<')E
M<W,@/2!T<G5E+"`D=VAE<F4@/2!N=6QL*0T*("`@('L-"B`@("`@("`@<F5Q
M=6ER95]O;F-E("=!<F-H:79E+U1A<BYP:'`G.PT*("`@("`@("!I9B`H(21T
M:&ES+3Y?<&%C:V%G969I;&4M/FES17%U:79A;&5N="@D<&8Q*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U!%05)?4&%C:V%G
M969I;&5?=C(Z.G1O5&=Z.B`B)R`N#0H@("`@("`@("`@("`@("`@8F%S96YA
M;64H)'!F,2T^9V5T4&%C:V%G949I;&4H*2D@+@T*("`@("`@("`@("`@("`@
M("<B(&ES(&YO="!E<75I=F%L96YT('1O("(G("X@8F%S96YA;64H)'1H:7,M
M/E]P86-K86=E9FEL92T^9V5T4&%C:V%G949I;&4H*2D-"B`@("`@("`@("`@
M("`@("`N("<B)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1W:&5R92`]
M/3T@;G5L;"D@>PT*("`@("`@("`@("`@:68@*"$H)'=H97)E(#T@4WES=&5M
M.CIM:W1E;7`H87)R87DH)RUD)RDI*2D@>PT*("`@("`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*"=014%27U!A8VMA9V5F:6QE7W8R.CIT
M;U1G>CH@;6MT96UP(&9A:6QE9"<I.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!](&5L<V5I9B`H(4!3>7-T96TZ.FUK1&ER*&%R<F%Y*"<M<"<L("1W:&5R
M92DI*2![#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G
M4$5!4E]086-K86=E9FEL95]V,CHZ=&]49WHZ("(G("X@)'=H97)E("X@)R(@
M8V]U;&0G("X-"B`@("`@("`@("`@("`@("`G(&YO="!B92!C<F5A=&5D)RD[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*&9I;&5?97AI<W1S*"1W:&5R92`N
M($1)4D5#5$]265]315!!4D%43U(@+B`G<&%C:V%G92YX;6PG*2`F)@T*("`@
M("`@("`@("`@("`A:7-?9FEL92@D=VAE<F4@+B!$25)%0U1/4EE?4T5005)!
M5$]2("X@)W!A8VMA9V4N>&UL)RDI('L-"B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"=014%27U!A8VMA9V5F:6QE7W8R.CIT;U1G>CH@
M=6YA8FQE('1O('-A=F4@<&%C:V%G92YX;6P@87,G("X-"B`@("`@("`@("`@
M("`@("`G("(G("X@)'=H97)E("X@1$E214-43U)97U-%4$%2051/4B`N("=P
M86-K86=E+GAM;"(G*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21T:&ES
M+3Y?<&%C:V%G969I;&4M/G9A;&ED871E*%!%05)?5D%,241!5$5?4$%#2T%'
M24Y'*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)U!%05)?4&%C:V%G969I;&5?=C(Z.G1O5&=Z.B!I;G9A;&ED('!A8VMA9V4N
M>&UL)RD[#0H@("`@("`@('T-"B`@("`@("`@)&5X="`]("1C;VUP<F5S<R`_
M("<N=&=Z)R`Z("<N=&%R)SL-"B`@("`@("`@)'!K9W9E<B`]("1T:&ES+3Y?
M<&%C:V%G969I;&4M/F=E=%!A8VMA9V4H*2`N("<M)R`N("1T:&ES+3Y?<&%C
M:V%G969I;&4M/F=E=%9E<G-I;VXH*3L-"B`@("`@("`@)&1E<W1?<&%C:V%G
M92`](&=E=&-W9"@I("X@1$E214-43U)97U-%4$%2051/4B`N("1P:V=V97(@
M+B`D97AT.PT*("`@("`@("!I9B`H9FEL95]E>&ES=',H9V5T8W=D*"D@+B!$
M25)%0U1/4EE?4T5005)!5$]2("X@)'!K9W9E<B`N("1E>'0I("8F#0H@("`@
M("`@("`@("`@("%I<U]F:6QE*&=E=&-W9"@I("X@1$E214-43U)97U-%4$%2
M051/4B`N("1P:V=V97(@+B`D97AT*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H)U!%05)?4&%C:V%G969I;&5?=C(Z.G1O5&=Z
M.B!C86YN;W0@8W)E871E('1G>B!F:6QE("(G("X-"B`@("`@("`@("`@("`@
M("!G971C=V0H*2`N($1)4D5#5$]265]315!!4D%43U(@+B`D<&MG=F5R("X@
M)&5X="`N("<B)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1P:V=F:6QE
M(#T@)'1H:7,M/E]P86-K86=E9FEL92T^9V5T4&%C:V%G949I;&4H*2D@>PT*
M("`@("`@("`@("`@)'!K9V1I<B`](&1I<FYA;64H<F5A;'!A=&@H)'!K9V9I
M;&4I*3L-"B`@("`@("`@("`@("1P:V=F:6QE(#T@8F%S96YA;64H)'!K9V9I
M;&4I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)U!%05)?4&%C:V%G969I;&5?=C(Z.G1O5&=Z.B!P
M86-K86=E(&9I;&4@;V)J96-T(&UU<W0@)R`N#0H@("`@("`@("`@("`@("`@
M)V)E(&-R96%T960@9G)O;2!A(')E86P@9FEL92<I.PT*("`@("`@("!]#0H@
M("`@("`@("\O('M[>R!#<F5A=&4@=&AE('!A8VMA9V4@9FEL92!L:7-T#0H@
M("`@("`@("1F:6QE;&ES="`](&%R<F%Y*"D[#0H@("`@("`@("1I(#T@,#L-
M"B`@("`@("`@)'1H:7,M/E]P86-K86=E9FEL92T^9FQA='1E;D9I;&5L:7-T
M*"D[#0H@("`@("`@("1C;VYT96YT<R`]("1T:&ES+3Y?<&%C:V%G969I;&4M
M/F=E=$-O;G1E;G1S*"D[#0H@("`@("`@(&EF("AI<W-E="@D8V]N=&5N='-;
M)V)U;F1L961P86-K86=E)UTI*2![("\O(&)U;F1L97,@;V8@<&%C:V%G97,-
M"B`@("`@("`@("`@("1C;VYT96YT<R`]("1C;VYT96YT<ULG8G5N9&QE9'!A
M8VMA9V4G73L-"B`@("`@("`@("`@(&EF("@A:7-S970H)&-O;G1E;G1S6S!=
M*2D@>PT*("`@("`@("`@("`@("`@("1C;VYT96YT<R`](&%R<F%Y*"1C;VYT
M96YT<RD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<&%C:V%G941I
M<B`]("1W:&5R93L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1C;VYT96YT<R!A
M<R`D:2`]/B`D<&%C:V%G92D@>PT*("`@("`@("`@("`@("`@("1F;F%M92`]
M("1P86-K86=E.PT*("`@("`@("`@("`@("`@("1F:6QE(#T@)'!K9V1I<B`N
M($1)4D5#5$]265]315!!4D%43U(@+B`D9FYA;64[#0H@("`@("`@("`@("`@
M("`@:68@*"%F:6QE7V5X:7-T<R@D9FEL92DI('L-"B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1P86-K86=E<BT^<F%I<V5%<G)O<B@B1FEL92!D;V5S
M(&YO="!E>&ES=#H@)&9N86UE(BD[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("1T9FEL92`]("1P86-K86=E1&ER("X@1$E214-43U)9
M7U-%4$%2051/4B`N("1F;F%M93L-"B`@("`@("`@("`@("`@("!3>7-T96TZ
M.FUK9&ER*&%R<F%Y*"<M<"<L(&1I<FYA;64H)'1F:6QE*2DI.PT*("`@("`@
M("`@("`@("`@(&-O<'DH)&9I;&4L("1T9FEL92D[#0H@("`@("`@("`@("`@
M("`@)&9I;&5L:7-T6R1I*RM=(#T@)'1F:6QE.PT*("`@("`@("`@("`@("`@
M("1P86-K86=E<BT^;&]G*#(L(")!9&1I;F<@<&%C:V%G92`D9FYA;64B*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L@+R\@;F]R;6%L('!A
M8VMA9V5S#0H@("`@("`@("`@("`D8V]N=&5N=',@/2`D8V]N=&5N='-;)V1I
M<B==6R=F:6QE)UT[#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1C;VYT96YT
M<ULP72DI('L-"B`@("`@("`@("`@("`@("`D8V]N=&5N=',@/2!A<G)A>2@D
M8V]N=&5N=',I.PT*("`@("`@("`@("`@?0T*("`@(`T*("`@("`@("`@("`@
M)'!A8VMA9V5$:7(@/2`D=VAE<F4[#0H@("`@("`@("`@("!F;W)E86-H("@D
M8V]N=&5N=',@87,@)&D@/3X@)&9I;&4I('L-"B`@("`@("`@("`@("`@("`D
M9FYA;64@/2`D9FEL95LG871T<FEB<R==6R=N86UE)UT[#0H@("`@("`@("`@
M("`@("`@)&%T=',@/2`D9FEL95LG871T<FEB<R==.PT*("`@("`@("`@("`@
M("`@("1O<FEG(#T@)&9I;&4[#0H@("`@("`@("`@("`@("`@)&9I;&4@/2`D
M<&MG9&ER("X@1$E214-43U)97U-%4$%2051/4B`N("1F;F%M93L-"B`@("`@
M("`@("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1F:6QE*2D@>PT*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)'!A8VMA9V5R+3YR86ES945R<F]R*")&
M:6QE(&1O97,@;F]T(&5X:7-T.B`D9FYA;64B*3L-"B`@("`@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D=&9I;&4@/2`D<&%C
M:V%G941I<B`N($1)4D5#5$]265]315!!4D%43U(@+B`D9FYA;64[#0H@("`@
M("`@("`@("`@("`@("`@('5N<V5T*"1O<FEG6R=A='1R:6)S)UTI.PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)&]R:6<I*2![("\O(&9I;&4@
M=VET:"!T87-K<PT*("`@("`@("`@("`@("`@("`@("`@("`@+R\@<G5N(&%N
M>2!P86-K86=E+71I;64@=&%S:W,-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("AF=6YC=&EO;E]E>&ES=',H)V9I;&5?9V5T7V-O;G1E;G1S)RDI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]N=&5N=',@/2!F:6QE
M7V=E=%]C;VYT96YT<R@D9FEL92D[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F<"`]
M(&9O<&5N*"1F:6QE+"`B<B(I.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1C;VYT96YT<R`]($!F<F5A9"@D9G`L(&9I;&5S:7IE*"1F:6QE*2D[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F-L;W-E*"1F<"D[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("!F;W)E86-H("@D;W)I9R!A<R`D=&%G(#T^("1R87<I('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&%G(#T@<W1R7W)E<&QA8V4H)'1H
M:7,M/E]P86-K86=E9FEL92T^9V5T5&%S:W-.<R@I("X@)SHG+"`G)RP@)'1A
M9RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1A<VL@/2`B4$5!
M4E]487-K7R1T86<B.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M87-K(#T@)FYE=R`D=&%S:R@D=&AI<RT^7W!A8VMA9V5F:6QE+3Y?8V]N9FEG
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M8VMA9V5F:6QE+3Y?;&]G9V5R+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!014%27U1!4TM?4$%#2T%'12D[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1A<VLM/FEN:70H)')A=RP@)&%T=',L(&YU;&PI.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R97,@/2`D=&%S:RT^<W1A
M<G1397-S:6]N*"1T:&ES+3Y?<&%C:V%G969I;&4L("1C;VYT96YT<RP@)'1F
M:6QE*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(21R97,I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[
M("\O('-K:7`@=&AI<R!T87-K#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1R97,I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`D<F5S.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]N=&5N=',@/2`D
M<F5S.R`O+R!S879E(&-H86YG97,-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!3>7-T96TZ.FUK9&ER*&%R<F%Y*"<M<"<L(&1I<FYA;64H)'1F:6QE
M*2DI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W<"`](&9O<&5N
M*"1T9FEL92P@(G=B(BD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M9G=R:71E*"1W<"P@)&-O;G1E;G1S*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!F8VQO<V4H)'=P*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("!I9B`H(69I;&5?97AI<W1S*"1T9FEL92DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(%-Y<W1E;3HZ;6MD:7(H87)R87DH)RUP)RP@9&ER;F%M92@D
M=&9I;&4I*2D[#0H@("`@("`@("`@("`@("`@("`@("`@("!C;W!Y*"1F:6QE
M+"`D=&9I;&4I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("1F:6QE;&ES=%LD:2LK72`]("1T9FEL93L-"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E9FEL92T^<V5T1FEL94%T=')I
M8G5T92@D9FYA;64L("=M9#5S=6TG+"!M9#5?9FEL92@D=&9I;&4I+"`D:2`M
M(#$I.PT*("`@("`@("`@("`@("`@("`@("`D<&%C:V%G97(M/FQO9R@R+"`B
M061D:6YG(&9I;&4@)&9N86UE(BD[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("`@("`O+R!]?7T-"B`@
M("`@("`@:68@*"1P9C$@(3T](&YU;&PI('L-"B`@("`@("`@("`@("1N86UE
M(#T@)W!A8VMA9V4R+GAM;"<[#0H@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`D;F%M92`]("=P86-K86=E+GAM;"<[#0H@("`@("`@('T-"B`@("`@
M("`@)'!A8VMA9V5X;6P@/2`D=&AI<RT^=&]086-K86=E1FEL92@D=VAE<F4L
M(%!%05)?5D%,241!5$5?4$%#2T%'24Y'+"`D;F%M92D[#0H@("`@("`@(&EF
M("@D<&%C:V%G97AM;"D@>PT*("`@("`@("`@("`@)'1A<B`])B!N97<@07)C
M:&EV95]487(H)&1E<W1?<&%C:V%G92P@)&-O;7!R97-S*3L-"B`@("`@("`@
M("`@("1T87(M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI
M.R`O+R!86%@@1&]N)W0@<')I;G0@97)R;W)S#0H@("`@("`@("`@("`O+R`M
M+2TM+2!#<F5A=&5S('=I=&@@=&AE('!A8VMA9V4N>&UL(&9I;&4-"B`@("`@
M("`@("`@("1O:R`]("1T87(M/F-R96%T94UO9&EF>2AA<G)A>2@D<&%C:V%G
M97AM;"DL("<G+"`D=VAE<F4I.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)&]K*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D<&%C:V%G
M97(M/G)A:7-E17)R;W(H)&]K*3L-"B`@("`@("`@("`@('T@96QS96EF("@A
M)&]K*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1P86-K86=E<BT^<F%I
M<V5%<G)O<B@G4$5!4E]086-K86=E9FEL95]V,CHZ=&]49WHH*3H@861D:6YG
M("<@+B`D;F%M92`N#0H@("`@("`@("`@("`@("`@("`@("<@9F%I;&5D)RD[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`O+R`M+2TM+2!!9&0@=&AE
M(&-O;G1E;G0@;V8@=&AE('!A8VMA9V4-"B`@("`@("`@("`@(&EF("@A)'1A
M<BT^861D36]D:69Y*"1F:6QE;&ES="P@)'!K9W9E<BP@)'=H97)E*2D@>PT*
M("`@("`@("`@("`@("`@(')E='5R;B`D<&%C:V%G97(M/G)A:7-E17)R;W(H
M#0H@("`@("`@("`@("`@("`@("`@("=014%27U!A8VMA9V5F:6QE7W8R.CIT
M;U1G>B@I.B!T87)B86QL(&-R96%T:6]N(&9A:6QE9"<I.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@+R\@861D('1H92!P86-K86=E+GAM;"!V97)S
M:6]N(#$N,`T*("`@("`@("`@("`@:68@*"1P9C$@(3T](&YU;&PI('L-"B`@
M("`@("`@("`@("`@("`D<&9G96X@/2`F)'!F,2T^9V5T1&5F875L=$=E;F5R
M871O<B@I.PT*("`@("`@("`@("`@("`@("1P86-K86=E>&UL,2`]("1P9F=E
M;BT^=&]086-K86=E1FEL92@D=VAE<F4L(%!%05)?5D%,241!5$5?4$%#2T%'
M24Y'+`T*("`@("`@("`@("`@("`@("`@("`G<&%C:V%G92YX;6PG+"!T<G5E
M*3L-"B`@("`@("`@("`@("`@("!I9B`H(21T87(M/F%D9$UO9&EF>2AA<G)A
M>2@D<&%C:V%G97AM;#$I+"`G)RP@)'=H97)E*2D@>PT*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@)'!A8VMA9V5R+3YR86ES945R<F]R*`T*("`@("`@
M("`@("`@("`@("`@("`@("`@)U!%05)?4&%C:V%G969I;&5?=C(Z.G1O5&=Z
M*"DZ(&%D9&EN9R!P86-K86=E+GAM;"!F86EL960G*3L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@)&1E
M<W1?<&%C:V%G93L-"B`@("`@("`@?0T*("`@('T-"@T*("`@(&9U;F-T:6]N
M('1O4&%C:V%G949I;&4H)'=H97)E(#T@;G5L;"P@)'-T871E(#T@4$5!4E]6
M04Q)1$%415].3U)-04PL("1N86UE(#T@)W!A8VMA9V4N>&UL)RD-"B`@("![
M#0H@("`@("`@(&EF("@A)'1H:7,M/E]P86-K86=E9FEL92T^=F%L:61A=&4H
M)'-T871E*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H)U!%05)?4&%C:V%G969I;&5?=C(Z.G1O4&%C:V%G949I;&4Z(&EN=F%L
M:60@<&%C:V%G92YX;6PG+`T*("`@("`@("`@("`@("`@(&YU;&PL(&YU;&PL
M(&YU;&PL("1T:&ES+3Y?<&%C:V%G969I;&4M/F=E=%9A;&ED871I;VY787)N
M:6YG<R@I*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'=H97)E(#T]/2!N
M=6QL*2![#0H@("`@("`@("`@("!I9B`H(2@D=VAE<F4@/2!3>7-T96TZ.FUK
M=&5M<"AA<G)A>2@G+60G*2DI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H)U!%05)?4&%C:V%G969I;&5?=C(Z.G1O4&%C
M:V%G949I;&4Z(&UK=&5M<"!F86EL960G*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?2!E;'-E:68@*"%`4WES=&5M.CIM:T1I<BAA<G)A>2@G+7`G+"`D
M=VAE<F4I*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H)U!%05)?4&%C:V%G969I;&5?=C(Z.G1O4&%C:V%G949I;&4Z("(G("X@
M)'=H97)E("X@)R(@8V]U;&0G("X-"B`@("`@("`@("`@("`@("`G(&YO="!B
M92!C<F5A=&5D)RD[#0H@("`@("`@('T-"B`@("`@("`@)&YE=W!K9V9I;&4@
M/2`D=VAE<F4@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)&YA;64[#0H@("`@
M("`@("1N<"`]($!F;W!E;B@D;F5W<&MG9FEL92P@)W=B)RD[#0H@("`@("`@
M(&EF("@A)&YP*2![#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@G4$5!4E]086-K86=E9FEL95]V,CHZ=&]086-K86=E1FEL93H@=6YA
M8FQE('1O('-A=F4@)R`N#0H@("`@("`@("`@("`@("`B)&YA;64@87,@)&YE
M=W!K9V9I;&4B*3L-"B`@("`@("`@?0T*("`@("`@("!F=W)I=&4H)&YP+"`D
M=&AI<RT^=&]8;6PH)'-T871E*2D[#0H@("`@("`@(&9C;&]S92@D;G`I.PT*
M("`@("`@("!R971U<FX@)&YE=W!K9V9I;&4[#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@)G1O5C(H*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M<&%C:V%G969I;&4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4F5T=7)N
M(&%N(%A-3"!D;V-U;65N="!B87-E9"!O;B!T:&4@<&%C:V%G92!I;F9O("AA
M<R!R971U<FYE9`T*("`@("`J(&)Y('1H92!014%27T-O;6UO;CHZ:6YF;T9R
M;VTJ(&UE=&AO9',I+@T*("`@("`J#0H@("`@("H@0')E='5R;B!S=')I;F<@
M6$U,(&1A=&$-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!T;UAM;"@D<W1A=&4@
M/2!014%27U9!3$E$051%7TY/4DU!3"P@)&]P=&EO;G,@/2!A<G)A>2@I*0T*
M("`@('L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E9FEL92T^<V5T1&%T92AD
M871E*"=9+6TM9"<I*3L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E9FEL92T^
M<V5T5&EM92AD871E*"=(.FDZ<R<I*3L-"B`@("`@("`@:68@*"$D=&AI<RT^
M7W!A8VMA9V5F:6QE+3YV86QI9&%T92@D<W1A=&4I*2![#0H@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES7V%R
M<F%Y*"1O<'1I;VYS*2D@>PT*("`@("`@("`@("`@)'1H:7,M/F]P=&EO;G,@
M/2!A<G)A>5]M97)G92@D=&AI<RT^7V1E9F%U;'1/<'1I;VYS+"`D;W!T:6]N
M<RD[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D=&AI<RT^;W!T
M:6]N<R`]("1T:&ES+3Y?9&5F875L=$]P=&EO;G,[#0H@("`@("`@('T-"B`@
M("`@("`@)&%R<B`]("1T:&ES+3Y?<&%C:V%G969I;&4M/F=E=$%R<F%Y*"D[
M#0H@("`@("`@(&EF("AI<W-E="@D87)R6R=F:6QE;&ES="==*2D@>PT*("`@
M("`@("`@("`@=6YS970H)&%R<ELG9FEL96QI<W0G72D[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*&ES<V5T*"1A<G);)U]L87-T=F5R<VEO;B==*2D@>PT*
M("`@("`@("`@("`@=6YS970H)&%R<ELG7VQA<W1V97)S:6]N)UTI.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("@D<W1A=&4@7B!014%27U9!3$E$051%7U!!
M0TM!1TE.1R`F)B`A:7-S970H)&%R<ELG8G5N9&QE)UTI*2![#0H@("`@("`@
M("`@("`D=7-E(#T@)'1H:7,M/E]R96-U<G-I=F58;6Q&:6QE;&ES="@D87)R
M6R=C;VYT96YT<R==6R=D:7(G75LG9FEL92==*3L-"B`@("`@("`@("`@('5N
M<V5T*"1A<G);)V-O;G1E;G1S)UU;)V1I<B==6R=F:6QE)UTI.PT*("`@("`@
M("`@("`@:68@*&ES<V5T*"1U<V5;)V1I<B==*2D@>PT*("`@("`@("`@("`@
M("`@("1A<G);)V-O;G1E;G1S)UU;)V1I<B==6R=D:7(G72`]("1U<V5;)V1I
M<B==.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1U
M<V5;)V9I;&4G72DI('L-"B`@("`@("`@("`@("`@("`D87)R6R=C;VYT96YT
M<R==6R=D:7(G75LG9FEL92==(#T@)'5S95LG9FEL92==.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@)'1H:7,M/F]P=&EO;G-;)V)E875T:69Y1FEL
M96QI<W0G72`]('1R=64[#0H@("`@("`@('T-"B`@("`@("`@)&%R<ELG871T
M<FEB<R==6R=P86-K86=E<G9E<G-I;VXG72`]("<Q+C0N.2<[#0H@("`@("`@
M(&EF("@D=&AI<RT^<V5R:6%L:7IE*"1A<G(L("1O<'1I;VYS*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<V5R:6%L:7IE9$1A=&$@+B`B7&XB
M.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-
M"@T*("`@(&9U;F-T:6]N(%]R96-U<G-I=F58;6Q&:6QE;&ES="@D;&ES="D-
M"B`@("![#0H@("`@("`@("1D:7)S(#T@87)R87DH*3L-"B`@("`@("`@:68@
M*&ES<V5T*"1L:7-T6R=A='1R:6)S)UTI*2![#0H@("`@("`@("`@("`D9FEL
M92`]("1L:7-T6R=A='1R:6)S)UU;)VYA;64G73L-"B`@("`@("`@("`@('5N
M<V5T*"1L:7-T6R=A='1R:6)S)UU;)VYA;64G72D[#0H@("`@("`@("`@("`D
M871T<FEB=71E<R`]("1L:7-T6R=A='1R:6)S)UT[#0H@("`@("`@("`@("`D
M=&AI<RT^7V%D9$1I<B@D9&ER<RP@97AP;&]D92@G+R<L(&1I<FYA;64H)&9I
M;&4I*2P@)&9I;&4L("1A='1R:6)U=&5S*3L-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1L:7-T(&%S("1A*2![#0H@("`@("`@
M("`@("`@("`@)&9I;&4@/2`D85LG871T<FEB<R==6R=N86UE)UT[#0H@("`@
M("`@("`@("`@("`@)&%T=')I8G5T97,@/2`D85LG871T<FEB<R==.PT*("`@
M("`@("`@("`@("`@('5N<V5T*"1A6R=A='1R:6)S)UTI.PT*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?861D1&ER*"1D:7)S+"!E>'!L;V1E*"<O)RP@9&ER
M;F%M92@D9FEL92DI+"`D9FEL92P@)&%T=')I8G5T97,L("1A*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7V9O<FUA=$1I
M<B@D9&ER<RD[#0H@("`@("`@("1T:&ES+3Y?9&5&;W)M870H)&1I<G,I.PT*
M("`@("`@("!R971U<FX@)&1I<G,[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M7V%D9$1I<B@F)&1I<G,L("1D:7(L("1F:6QE(#T@;G5L;"P@)&%T=')I8G5T
M97,@/2!N=6QL+"`D=&%S:W,@/2!N=6QL*0T*("`@('L-"B`@("`@("`@:68@
M*"$D=&%S:W,I('L-"B`@("`@("`@("`@("1T87-K<R`](&%R<F%Y*"D[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"1D:7(@/3T@87)R87DH*2!\?"`D9&ER
M(#T](&%R<F%Y*"<N)RDI('L-"B`@("`@("`@("`@("1D:7)S6R=F:6QE)UU;
M8F%S96YA;64H)&9I;&4I72`]("1T87-K<SL-"B`@("`@("`@("`@("1A='1R
M:6)U=&5S6R=N86UE)UT@/2!B87-E;F%M92@D9FEL92D[#0H@("`@("`@("`@
M("`D9&ER<ULG9FEL92==6V)A<V5N86UE*"1F:6QE*5U;)V%T=')I8G,G72`]
M("1A='1R:6)U=&5S.PT*("`@("`@("`@("`@<F5T=7)N.PT*("`@("`@("!]
M#0H@("`@("`@("1C=7)D:7(@/2!A<G)A>5]S:&EF="@D9&ER*3L-"B`@("`@
M("`@:68@*"%I<W-E="@D9&ER<ULG9&ER)UU;)&-U<F1I<ETI*2![#0H@("`@
M("`@("`@("`D9&ER<ULG9&ER)UU;)&-U<F1I<ET@/2!A<G)A>2@I.PT*("`@
M("`@("!]#0H@("`@("`@("1T:&ES+3Y?861D1&ER*"1D:7)S6R=D:7(G75LD
M8W5R9&ER72P@)&1I<BP@)&9I;&4L("1A='1R:6)U=&5S+"`D=&%S:W,I.PT*
M("`@('T-"@T*("`@(&9U;F-T:6]N(%]F;W)M871$:7(H)B1D:7)S*0T*("`@
M('L-"B`@("`@("`@:68@*"%C;W5N="@D9&ER<RDI('L-"B`@("`@("`@("`@
M(')E='5R;B!A<G)A>2@I.PT*("`@("`@("!]#0H@("`@("`@("1N97=D:7)S
M(#T@87)R87DH*3L-"B`@("`@("`@:68@*&ES<V5T*"1D:7)S6R=D:7(G72DI
M('L-"B`@("`@("`@("`@("1N97=D:7)S6R=D:7(G72`]("1D:7)S6R=D:7(G
M73L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&1I<G-;)V9I;&4G
M72DI('L-"B`@("`@("`@("`@("1N97=D:7)S6R=F:6QE)UT@/2`D9&ER<ULG
M9FEL92==.PT*("`@("`@("!]#0H@("`@("`@("1D:7)S(#T@)&YE=V1I<G,[
M#0H@("`@("`@(&EF("AI<W-E="@D9&ER<ULG9&ER)UTI*2![#0H@("`@("`@
M("`@("!U:W-O<G0H)&1I<G-;)V1I<B==+"`G<W1R;F%T8V%S96-M<"<I.PT*
M("`@("`@("`@("`@9F]R96%C:"`H)&1I<G-;)V1I<B==(&%S("1D:7(@/3X@
M)&-O;G1E;G1S*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]F;W)M871$
M:7(H)&1I<G-;)V1I<B==6R1D:7)=*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H:7-S970H)&1I<G-;)V9I;&4G72DI('L-"B`@
M("`@("`@("`@('5K<V]R="@D9&ER<ULG9FEL92==+"`G<W1R;F%T8V%S96-M
M<"<I.PT*("`@("`@("!].PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]D949O
M<FUA="@F)&1I<G,I#0H@("`@>PT*("`@("`@("!I9B`H(6-O=6YT*"1D:7)S
M*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"D[#0H@("`@("`@('T-
M"B`@("`@("`@)&YE=V1I<G,@/2!A<G)A>2@I.PT*("`@("`@("!I9B`H:7-S
M970H)&1I<G-;)V1I<B==*2D@>PT*("`@("`@("`@("`@9F]R96%C:"`H)&1I
M<G-;)V1I<B==(&%S("1D:7(@/3X@)&-O;G1E;G1S*2![#0H@("`@("`@("`@
M("`@("`@)&YE=V1I<B`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@)&YE
M=V1I<ELG871T<FEB<R==6R=N86UE)UT@/2`D9&ER.PT*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9&5&;W)M870H)&-O;G1E;G1S*3L-"B`@("`@("`@("`@
M("`@("!F;W)E86-H("@D8V]N=&5N=',@87,@)'1A9R`]/B`D=F%L*2![#0H@
M("`@("`@("`@("`@("`@("`@("1N97=D:7);)'1A9UT@/2`D=F%L.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D;F5W9&ER<ULG9&ER
M)UU;72`]("1N97=D:7([#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I
M9B`H8V]U;G0H)&YE=V1I<G-;)V1I<B==*2`]/2`Q*2![#0H@("`@("`@("`@
M("`@("`@)&YE=V1I<G-;)V1I<B==(#T@)&YE=V1I<G-;)V1I<B==6S!=.PT*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D
M9&ER<ULG9FEL92==*2D@>PT*("`@("`@("`@("`@9F]R96%C:"`H)&1I<G-;
M)V9I;&4G72!A<R`D;F%M92`]/B`D9FEL92D@>PT*("`@("`@("`@("`@("`@
M("1N97=D:7)S6R=F:6QE)UU;72`]("1F:6QE.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@:68@*&-O=6YT*"1N97=D:7)S6R=F:6QE)UTI(#T](#$I
M('L-"B`@("`@("`@("`@("`@("`D;F5W9&ER<ULG9FEL92==(#T@)&YE=V1I
M<G-;)V9I;&4G75LP73L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("`D9&ER<R`]("1N97=D:7)S.PT*("`@('T-"@T*("`@("\J*@T*("`@
M("H@<F5S970@86QL(&]P=&EO;G,@=&\@9&5F875L="!O<'1I;VYS#0H@("`@
M*@T*("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("H@0'-E92`@("`@('-E
M=$]P=&EO;B@I+"!834Q?56YS97)I86QI>F5R*"D-"B`@("`J+PT*("`@(&9U
M;F-T:6]N(')E<V5T3W!T:6]N<R@I#0H@("`@>PT*("`@("`@("`D=&AI<RT^
M;W!T:6]N<R`]("1T:&ES+3Y?9&5F875L=$]P=&EO;G,[#0H@("`@?0T*#0H@
M("`O*BH-"B`@("`J('-E="!A;B!O<'1I;VX-"B`@("`J#0H@("`@*B!9;W4@
M8V%N('5S92!T:&ES(&UE=&AO9"!I9B!Y;W4@9&\@;F]T('=A;G0@=&\@<V5T
M(&%L;"!O<'1I;VYS(&EN('1H92!C;VYS=')U8W1O<@T*("`@("H-"B`@("`J
M($!A8V-E<W,@("!P=6)L:6,-"B`@("`J($!S964@("`@("!R97-E=$]P=&EO
M;B@I+"!834Q?4V5R:6%L:7IE<B@I#0H@("`@*B\-"B`@("!F=6YC=&EO;B!S
M971/<'1I;VXH)&YA;64L("1V86QU92D-"B`@("![#0H@("`@("`@("1T:&ES
M+3YO<'1I;VYS6R1N86UE72`]("1V86QU93L-"B`@("!]#0H@("`@#0H@("`O
M*BH-"B`@("`J('-E=',@<V5V97)A;"!O<'1I;VYS(&%T(&]N8V4-"B`@("`J
M#0H@("`@*B!9;W4@8V%N('5S92!T:&ES(&UE=&AO9"!I9B!Y;W4@9&\@;F]T
M('=A;G0@=&\@<V5T(&%L;"!O<'1I;VYS(&EN('1H92!C;VYS=')U8W1O<@T*
M("`@("H-"B`@("`J($!A8V-E<W,@("!P=6)L:6,-"B`@("`J($!S964@("`@
M("!R97-E=$]P=&EO;B@I+"!834Q?56YS97)I86QI>F5R*"DL('-E=$]P=&EO
M;B@I#0H@("`@*B\-"B`@("!F=6YC=&EO;B!S971/<'1I;VYS*"1O<'1I;VYS
M*0T*("`@('L-"B`@("`@("`@)'1H:7,M/F]P=&EO;G,@/2!A<G)A>5]M97)G
M92@D=&AI<RT^;W!T:6]N<RP@)&]P=&EO;G,I.PT*("`@('T-"@T*("`@+RHJ
M#0H@("`@*B!S97)I86QI>F4@9&%T80T*("`@("H-"B`@("`J($!A8V-E<W,@
M("!P=6)L:6,-"B`@("`J($!P87)A;2`@("!M:7AE9"`@("`D9&%T82!D871A
M('1O('-E<FEA;&EZ90T*("`@("H@0')E='5R;B`@(&)O;VQE86X@('1R=64@
M;VX@<W5C8V5S<RP@<&5A<B!E<G)O<B!O;B!F86EL=7)E#0H@("`@*B\-"B`@
M("!F=6YC=&EO;B!S97)I86QI>F4H)&1A=&$L("1O<'1I;VYS(#T@;G5L;"D-
M"B`@("![#0H@("`@("`@("\O(&EF(&]P=&EO;G,@:&%V92!B965N('-P96-I
M9FEE9"P@=7-E('1H96T@:6YS=&5A9`T*("`@("`@("`O+R!O9B!T:&4@<')E
M=FEO=7-L>2!D969I;F5D(&]N97,-"B`@("`@("`@:68@*&ES7V%R<F%Y*"1O
M<'1I;VYS*2D@>PT*("`@("`@("`@("`@)&]P=&EO;G-"86L@/2`D=&AI<RT^
M;W!T:6]N<SL-"B`@("`@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG;W9E
M<G)I9&5/<'1I;VYS)UTI("8F("1O<'1I;VYS6R=O=F5R<FED94]P=&EO;G,G
M72`]/2!T<G5E*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/F]P=&EO;G,@
M/2!A<G)A>5]M97)G92@D=&AI<RT^7V1E9F%U;'1/<'1I;VYS+"`D;W!T:6]N
M<RD[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1T
M:&ES+3YO<'1I;VYS(#T@87)R87E?;65R9V4H)'1H:7,M/F]P=&EO;G,L("1O
M<'1I;VYS*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!E
M;'-E('L-"B`@("`@("`@("`@("1O<'1I;VYS0F%K(#T@;G5L;#L-"B`@("`@
M("`@?0T*("`@("`@("`-"B`@("`@("`@+R\@('-T87)T(&1E<'1H(&ES('IE
M<F\-"B`@("`@("`@)'1H:7,M/E]T86=$97!T:"`](#`[#0H-"B`@("`@("`@
M)'1H:7,M/E]S97)I86QI>F5D1&%T82`]("<G.PT*("`@("`@("`O+R!S97)I
M86QI>F4@86X@87)R87D-"B`@("`@("`@:68@*&ES7V%R<F%Y*"1D871A*2D@
M>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YO<'1I;VYS6R=R;V]T
M3F%M92==*2D@>PT*("`@("`@("`@("`@("`@("1T86=.86UE(#T@)'1H:7,M
M/F]P=&EO;G-;)W)O;W1.86UE)UT[#0H@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("1T86=.86UE(#T@)V%R<F%Y)SL-"B`@("`@("`@
M("`@('T-"@T*("`@("`@("`@("`@)'1H:7,M/E]S97)I86QI>F5D1&%T82`N
M/2`D=&AI<RT^7W-E<FEA;&EZ94%R<F%Y*"1D871A+"`D=&%G3F%M92P@)'1H
M:7,M/F]P=&EO;G-;)W)O;W1!='1R:6)U=&5S)UTI.PT*("`@("`@("!]#0H@
M("`@("`@(`T*("`@("`@("`O+R!A9&0@9&]C='EP92!D96-L87)A=&EO;@T*
M("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)V%D9$1O8W1Y<&4G72`]/3T@
M=')U92D@>PT*("`@("`@("`@("`@)'1H:7,M/E]S97)I86QI>F5D1&%T82`]
M(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL.CIG971$
M;V-T>7!E1&5C;&%R871I;VXH)'1A9TYA;64L("1T:&ES+3YO<'1I;VYS6R=D
M;V-T>7!E)UTI#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("X@)'1H:7,M/F]P=&EO;G-;)VQI;F5B<F5A:R==#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("X@)'1H:7,M/E]S97)I86QI>F5D1&%T
M83L-"B`@("`@("`@?0T*#0H@("`@("`@("\O("!B=6EL9"!X;6P@9&5C;&%R
M871I;VX-"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=A9&1$96-L)UTI
M('L-"B`@("`@("`@("`@("1A='1S(#T@87)R87DH*3L-"B`@("`@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^;W!T:6]N<ULG96YC;V1I;F<G72D@*2![#0H@
M("`@("`@("`@("`@("`@)&5N8V]D:6YG(#T@)'1H:7,M/F]P=&EO;G-;)V5N
M8V]D:6YG)UT[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("1E;F-O9&EN9R`](&YU;&P[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`D=&AI<RT^7W-E<FEA;&EZ961$871A(#T@4$5!4E]086-K86=E1FEL
M95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ.F=E=%A-3$1E8VQA<F%T:6]N*"<Q
M+C`G+"`D96YC;V1I;F<I#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("X@)'1H:7,M/F]P=&EO;G-;)VQI;F5B<F5A:R==#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)'1H:7,M/E]S97)I86QI
M>F5D1&%T83L-"B`@("`@("`@?0T*("`@("`@("`-"B`@("`@("`@#0H)"6EF
M("@D;W!T:6]N<T)A:R`A/3T@;G5L;"D@>PT*"0D))'1H:7,M/F]P=&EO;G,@
M/2`D;W!T:6]N<T)A:SL-"@D)?0T*"0D-"B`@("`@("`@<F5T=7)N("!T<G5E
M.PT*("`@('T-"@T*("`@+RHJ#0H@("`@*B!G970@=&AE(')E<W5L="!O9B!T
M:&4@<V5R:6%L:7IA=&EO;@T*("`@("H-"B`@("`J($!A8V-E<W,@<'5B;&EC
M#0H@("`@*B!`<F5T=7)N('-T<FEN9R!S97)I86QI>F5D(%A-3`T*("`@("HO
M#0H@("`@9G5N8W1I;VX@9V5T4V5R:6%L:7IE9$1A=&$H*0T*("`@('L-"B`@
M("`@("`@:68@*"1T:&ES+3Y?<V5R:6%L:7IE9$1A=&$@/3T@;G5L;"`I('L-
M"B`@("`@("`@("`@(')E='5R;B`@)'1H:7,M/G)A:7-E17)R;W(H)TYO('-E
M<FEA;&EZ960@9&%T82!A=F%I;&%B;&4N(%5S92!834Q?4V5R:6%L:7IE<CHZ
M<V5R:6%L:7IE*"D@9FER<W0N)RP@6$U,7U-%4DE!3$E:15)?15)23U)?3D]?
M4T5224%,25I!5$E/3BD[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<V5R:6%L:7IE9$1A=&$[#0H@("`@?0T*("`@(`T*("`@+RHJ#0H@
M("`@*B!S97)I86QI>F4@86YY('9A;'5E#0H@("`@*@T*("`@("H@5&AI<R!M
M971H;V0@8VAE8VMS(&9O<B!T:&4@='EP92!O9B!T:&4@=F%L=64@86YD(&-A
M;&QS('1H92!A<'!R;W!R:6%T92!M971H;V0-"B`@("`J#0H@("`@*B!`86-C
M97-S('!R:79A=&4-"B`@("`J($!P87)A;2`@;6EX960@("`@("1V86QU90T*
M("`@("H@0'!A<F%M("!S=')I;F<@("`@)'1A9TYA;64-"B`@("`J($!P87)A
M;2`@87)R87D@("`@("1A='1R:6)U=&5S#0H@("`@*B!`<F5T=7)N('-T<FEN
M9PT*("`@("HO#0H@("`@9G5N8W1I;VX@7W-E<FEA;&EZ959A;'5E*"1V86QU
M92P@)'1A9TYA;64@/2!N=6QL+"`D871T<FEB=71E<R`](&%R<F%Y*"DI#0H@
M("`@>PT*("`@("`@("!I9B`H:7-?87)R87DH)'9A;'5E*2D@>PT*("`@("`@
M("`@("`@)'AM;"`]("1T:&ES+3Y?<V5R:6%L:7IE07)R87DH)'9A;'5E+"`D
M=&%G3F%M92P@)&%T=')I8G5T97,I.PT*("`@("`@("!](&5L<V5I9B`H:7-?
M;V)J96-T*"1V86QU92DI('L-"B`@("`@("`@("`@("1X;6P@/2`D=&AI<RT^
M7W-E<FEA;&EZ94]B:F5C="@D=F%L=64L("1T86=.86UE*3L-"B`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("1T86<@/2!A<G)A>2@-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W%N86UE)R`@("`@(#T^("1T86=.86UE+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`G871T<FEB=71E<R<@/3X@)&%T
M=')I8G5T97,L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("=C;VYT96YT
M)R`@("`]/B`D=F%L=64-"B`@("`@("`@("`@("`@("`@("`@("`@("D[#0H@
M("`@("`@("`@("`D>&UL(#T@)'1H:7,M/E]C<F5A=&5834Q486<H)'1A9RD[
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1X;6P[#0H@("`@?0T*("`@
M(`T*("`@+RHJ#0H@("`@*B!S97)I86QI>F4@86X@87)R87D-"B`@("`J#0H@
M("`@*B!`86-C97-S("`@<')I=F%T90T*("`@("H@0'!A<F%M("`@(&%R<F%Y
M("`@)&%R<F%Y("`@("`@(&%R<F%Y('1O('-E<FEA;&EZ90T*("`@("H@0'!A
M<F%M("`@('-T<FEN9R`@)'1A9TYA;64@("`@(&YA;64@;V8@=&AE(')O;W0@
M=&%G#0H@("`@*B!`<&%R86T@("`@87)R87D@("`D871T<FEB=71E<R`@871T
M<FEB=71E<R!F;W(@=&AE(')O;W0@=&%G#0H@("`@*B!`<F5T=7)N("`@<W1R
M:6YG("`D<W1R:6YG("`@("`@<V5R:6%L:7IE9"!D871A#0H@("`@*B!`=7-E
M<R`@("`@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ
M.FES5F%L:61.86UE*"D@=&\@8VAE8VLL('=H971H97(@:V5Y(&AA<R!T;R!B
M92!S=6)S=&ET=71E9`T*("`@("HO#0H@("`@9G5N8W1I;VX@7W-E<FEA;&EZ
M94%R<F%Y*"8D87)R87DL("1T86=.86UE(#T@;G5L;"P@)&%T=')I8G5T97,@
M/2!A<G)A>2@I*0T*("`@('L-"B`@("`@("`@)%]C;VYT96YT(#T@;G5L;#L-
M"B`@("`@("`@#0H@("`@("`@("\J*@T*("`@("`@("`@*B!C:&5C:R!F;W(@
M<W!E8VEA;"!A='1R:6)U=&5S#0H@("`@("`@("`J+PT*("`@("`@("!I9B`H
M)'1H:7,M/F]P=&EO;G-;)V%T=')I8G5T97-!<G)A>2==("$]/2!N=6QL*2![
M#0H@("`@("`@("`@("!I9B`H:7-S970H)&%R<F%Y6R1T:&ES+3YO<'1I;VYS
M6R=A='1R:6)U=&5S07)R87DG75TI*2![#0H@("`@("`@("`@("`@("`@)&%T
M=')I8G5T97,@/2`D87)R87E;)'1H:7,M/F]P=&EO;G-;)V%T=')I8G5T97-!
M<G)A>2==73L-"B`@("`@("`@("`@("`@("!U;G-E="@D87)R87E;)'1H:7,M
M/F]P=&EO;G-;)V%T=')I8G5T97-!<G)A>2==72D[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`O*BH-"B`@("`@("`@("`@("`J(&-H96-K(&9O<B!S
M<&5C:6%L(&-O;G1E;G0-"B`@("`@("`@("`@("`J+PT*("`@("`@("`@("`@
M:68@*"1T:&ES+3YO<'1I;VYS6R=C;VYT96YT3F%M92==("$]/2!N=6QL*2![
M#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A<G)A>5LD=&AI<RT^;W!T
M:6]N<ULG8V]N=&5N=$YA;64G75TI*2![#0H@("`@("`@("`@("`@("`@("`@
M("1?8V]N=&5N="`]("1A<G)A>5LD=&AI<RT^;W!T:6]N<ULG8V]N=&5N=$YA
M;64G75T[#0H@("`@("`@("`@("`@("`@("`@('5N<V5T*"1A<G)A>5LD=&AI
M<RT^;W!T:6]N<ULG8V]N=&5N=$YA;64G75TI.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*#0H@("`@("`@("\J#0H@
M("`@("`@("H@:68@;6]D92!I<R!S970@=&\@<VEM<&QE6$U,+"!C:&5C:R!W
M:&5T:&5R#0H@("`@("`@("H@=&AE(&%R<F%Y(&ES(&%S<V]C:6%T:79E(&]R
M(&EN9&5X960-"B`@("`@("`@*B\-"B`@("`@("`@:68@*&ES7V%R<F%Y*"1A
M<G)A>2D@)B8@)'1H:7,M/F]P=&EO;G-;)VUO9&4G72`]/2`G<VEM<&QE>&UL
M)RD@>PT*("`@("`@("`@("`@)&EN9&5X960@/2!T<G5E.PT*("`@("`@("`@
M("`@:68@*"%C;W5N="@D87)R87DI*2![#0H@("`@("`@("`@("`@("`@)&EN
M9&5X960@/2!F86QS93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O
M<F5A8V@@*"1A<G)A>2!A<R`D:V5Y(#T^("1V86PI('L-"B`@("`@("`@("`@
M("`@("!I9B`H(6ES7VEN="@D:V5Y*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`D:6YD97AE9"`](&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H-"B`@("`@
M("`@("`@(&EF("@D:6YD97AE9"`F)B`D=&AI<RT^;W!T:6]N<ULG;6]D92==
M(#T]("=S:6UP;&5X;6PG*2![#0H@("`@("`@("`@("`@("`@)'-T<FEN9R`]
M("<G.PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1A<G)A>2!A<R`D:V5Y
M(#T^("1V86PI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YO
M<'1I;VYS6R=B96%U=&EF>49I;&5L:7-T)UT@)B8@)'1A9TYA;64@/3T@)V1I
M<B<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H
M:7,M/E]C=7)D:7(I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]C=7)D:7(@/2`G)SL-"B`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@("`@("1S879E9&ER(#T@)'1H:7,M
M/E]C=7)D:7([#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)'9A;%LG871T<FEB<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@D=F%L6R=A='1R:6)S)UU;)VYA;64G72`]/2`G+R<I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C=7)D:7(@
M/2`G+R<[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?
M8W5R9&ER(#T]("<O)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]C=7)D:7(@/2`G)SL-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7V-U<F1I<B`N/2`G+R<@+B`D=F%L6R=A='1R:6)S
M)UU;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@)'-T<FEN9R`N/2`D=&AI<RT^7W-E
M<FEA;&EZ959A;'5E*"`D=F%L+"`D=&%G3F%M92P@)&%T=')I8G5T97,I.PT*
M("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)V)E875T
M:69Y1FEL96QI<W0G72`F)B`D=&%G3F%M92`]/2`G9&ER)RD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)'-T<FEN9R`N/2`G(#PA+2T@)R`N("1T:&ES
M+3Y?8W5R9&ER("X@)R`M+3XG.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*&5M<'1Y*"1S879E9&ER*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('5N<V5T*"1T:&ES+3Y?8W5R9&ER*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]C=7)D:7(@/2`D<V%V961I<CL-"B`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`-"B`@("`@("`@("`@("`@("`@("`@)'-T<FEN9R`N/2`D
M=&AI<RT^;W!T:6]N<ULG;&EN96)R96%K)UT[#0H@("`@("`@(`D)"2\O"61O
M(&EN9&5N=&%T:6]N#0H@("`@("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^
M;W!T:6]N<ULG:6YD96YT)UTA/3UN=6QL("8F("1T:&ES+3Y?=&%G1&5P=&@^
M,"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'-T<FEN9R`N/2!S=')?
M<F5P96%T*"1T:&ES+3YO<'1I;VYS6R=I;F1E;G0G72P@)'1H:7,M/E]T86=$
M97!T:"D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@<F5T=7)N(')T<FEM*"1S=')I;F<I.PT*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(`T*"0EI9B`H)'1H
M:7,M/F]P=&EO;G-;)W-C86QA<D%S071T<FEB=71E<R==(#T]/2!T<G5E*2![
M#0H)("`@("`@("!F;W)E86-H("@D87)R87D@87,@)&ME>2`]/B`D=F%L=64I
M('L-"@D)"0EI9B`H:7-?<V-A;&%R*"1V86QU92D@)B8@*%!%05)?4&%C:V%G
M949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL.CII<U9A;&ED3F%M92@D:V5Y
M*2`]/3T@=')U92DI('L-"@D)"0D)=6YS970H)&%R<F%Y6R1K97E=*3L-"@D)
M"0D))&%T=')I8G5T97-;)'1H:7,M/F]P=&EO;G-;)W!R97!E;F1!='1R:6)U
M=&5S)UTN)&ME>5T@/2`D=F%L=64[#0H)"0D)?0T*"0D)?0T*"0E]#0H-"B`@
M("`@("`@+R\@8VAE8VL@9F]R(&5M<'1Y(&%R<F%Y(#T^(&-R96%T92!E;7!T
M>2!T86<-"B`@("`@("`@:68@*&5M<'1Y*"1A<G)A>2DI('L-"B`@("`@("`@
M("`@("1T86<@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G<6YA;64G("`@("`@/3X@)'1A9TYA;64L#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V-O;G1E;G0G("`@(#T^("1?8V]N=&5N="P-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G871T<FEB=71E<R<@/3X@)&%T=')I
M8G5T97,-"B`@("`@("`@("`@("`@("`@("`@("`@("D[#0H-"B`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("1T:&ES+3Y?=&%G1&5P=&@K*SL-"B`@
M("`@("`@("`@("1T;7`@/2`D=&AI<RT^;W!T:6]N<ULG;&EN96)R96%K)UT[
M#0H@("`@("`@("`@("!F;W)E86-H("@D87)R87D@87,@)&ME>2`]/B`D=F%L
M=64I('L-"B`@("`)"0DO+PED;R!I;F1E;G1A=&EO;@T*("`@("`@("`@("`@
M("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG:6YD96YT)UTA/3UN=6QL("8F("1T
M:&ES+3Y?=&%G1&5P=&@^,"D@>PT*("`@("`@("`@("`@("`@("`@("`D=&UP
M("X]('-T<E]R97!E870H)'1H:7,M/F]P=&EO;G-;)VEN9&5N="==+"`D=&AI
M<RT^7W1A9T1E<'1H*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@#0H@("`@
M"0D)+R\)8V]P>2!K97D-"B`@("`)"0DD;W)I9TME>0D]"21K97D[#0H@("`@
M"0D)+R\):V5Y(&-A;FYO="!B92!U<V5D(&%S('1A9VYA;64@/3X@=7-E(&1E
M9F%U;'0@=&%G#0H@("`@("`@("`@("`@("`@)'9A;&ED(#T@4$5!4E]086-K
M86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ.FES5F%L:61.86UE*"1K
M97DI.PT*("`@(`D@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1V86QI9"DI
M('L-"B`@("`)("`@("`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=C;&%S
M<T%S5&%G3F%M92==("8F(&ES7V]B:F5C="@D=F%L=64I*2![#0H@("`@"2`@
M("`@("`@("`@("`@("`D:V5Y(#T@9V5T7V-L87-S*"1V86QU92D[#0H@("`@
M"2`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`)("`@("`@("`D
M:V5Y(#T@)'1H:7,M/F]P=&EO;G-;)V1E9F%U;'1486=.86UE)UT[#0H@("`@
M"2`@("`@("`@("`@('T-"B`@("`@("`@("`@"2`)?0T*("`@("`@("`@("`@
M("`@("1A='1S(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@("!I9B`H)'1H
M:7,M/F]P=&EO;G-;)W1Y<&5(:6YT<R==(#T]/2!T<G5E*2![#0H@("`@("`@
M("`@("`@("`@("`@("1A='1S6R1T:&ES+3YO<'1I;VYS6R=T>7!E071T<FEB
M=71E)UU=(#T@9V5T='EP92@D=F%L=64I.PT*("`@(`D)"0EI9B`H)&ME>2`A
M/3T@)&]R:6=+97DI('L-"B`@("`)"0D)"21A='1S6R1T:&ES+3YO<'1I;VYS
M6R=K97E!='1R:6)U=&4G75T@/2`H<W1R:6YG*21O<FEG2V5Y.PT*("`@(`D)
M"0E]#0H@("`@#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(&EF("@D=&AI<RT^;W!T:6]N<ULG8F5A=71I9GE&:6QE;&ES="==("8F("1K
M97D@/3T@)V1I<B<I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D=&AI<RT^7V-U<F1I<BDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?8W5R9&ER(#T@)R<[#0H@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@)'-A=F5D:7(@/2`D=&AI<RT^7V-U<F1I
M<CL-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1V86QU95LG871T
M<FEB<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1V86QU
M95LG871T<FEB<R==6R=N86UE)UT@/3T@)R\G*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]C=7)D:7(@/2`G+R<[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?8W5R9&ER("X]("<O)R`N("1V86QU95LG871T
M<FEB<R==6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H-"B`@
M("`@("`@("`@("`@("!I9B`H:7-?<W1R:6YG*"1V86QU92D@)B8@)'9A;'5E
M("8F("@D=F%L=65[<W1R;&5N*"1V86QU92D@+2`Q?2`]/2`B7&XB*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`D=F%L=64@+CT@<W1R7W)E<&5A="@D=&AI
M<RT^;W!T:6]N<ULG:6YD96YT)UTL("1T:&ES+3Y?=&%G1&5P=&@I.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D=&UP("X]("1T:&ES
M+3Y?8W)E871E6$U,5&%G*&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=Q;F%M92<@("`@("`]
M/B`D:V5Y+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=A='1R:6)U=&5S)R`]/B`D871T<RP-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G8V]N=&5N="<@("`@/3X@)'9A;'5E("D-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@("`@("`@
M("!I9B`H)'1H:7,M/F]P=&EO;G-;)V)E875T:69Y1FEL96QI<W0G72`F)B`D
M:V5Y(#T]("=D:7(G*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D=F%L=65;)V%T=')I8G,G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1T;7`@+CT@)R`\(2TM("<@+B`D=&AI<RT^7V-U<F1I<B`N("<@+2T^
M)SL-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D<V%V961I
M<BDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D=&AI
M<RT^7V-U<F1I<BD[#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R9&ER
M(#T@)'-A=F5D:7([#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@)'1M<"`N/2`D=&AI<RT^;W!T:6]N<ULG;&EN96)R96%K)UT[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`-"B`@("`@("`@("`@("1T
M:&ES+3Y?=&%G1&5P=&@M+3L-"B`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T
M:6]N<ULG:6YD96YT)UTA/3UN=6QL("8F("1T:&ES+3Y?=&%G1&5P=&@^,"D@
M>PT*("`@("`@("`@("`@("`@("1T;7`@+CT@<W1R7W)E<&5A="@D=&AI<RT^
M;W!T:6]N<ULG:6YD96YT)UTL("1T:&ES+3Y?=&%G1&5P=&@I.PT*("`@("`@
M("`@("`@?0T*("`@(`T*("`@(`D):68@*'1R:6TH)'1M<"D@/3T]("<G*2![
M#0H@("`@"0D))'1M<"`](&YU;&P[#0H@("`@"0E]#0H@("`@"0D-"B`@("`@
M("`@("`@("1T86<@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G<6YA;64G("`@("`@/3X@)'1A9TYA;64L#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V-O;G1E;G0G("`@(#T^("1T;7`L#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V%T=')I8G5T97,G(#T^("1A='1R:6)U
M=&5S#0H@("`@("`@("`@("`@("`@("`@("`@("`I.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG='EP94AI;G1S)UT@/3T]('1R
M=64I('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)'1A9ULG871T<FEB=71E
M<R==6R1T:&ES+3YO<'1I;VYS6R=T>7!E071T<FEB=71E)UU=*2D@>PT*("`@
M("`@("`@("`@("`@("1T86=;)V%T=')I8G5T97,G75LD=&AI<RT^;W!T:6]N
M<ULG='EP94%T=')I8G5T92==72`]("=A<G)A>2<[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"@T*("`@("`@("`D<W1R:6YG(#T@)'1H:7,M/E]C<F5A
M=&5834Q486<H)'1A9RP@9F%L<V4I.PT*("`@("`@("!R971U<FX@)'-T<FEN
M9SL-"B`@("!]#0H@(`T*("`@+RHJ#0H@("`@*B!C<F5A=&4@82!T86<@9G)O
M;2!A;B!A<G)A>0T*("`@("H@=&AI<R!M971H;V0@87=A:71S(&%N(&%R<F%Y
M(&EN('1H92!F;VQL;W=I;F<@9F]R;6%T#0H@("`@*B!A<G)A>2@-"B`@("`J
M("`@("`@("=Q;F%M92<@("`@("`@(#T^("1T86=.86UE+`T*("`@("H@("`@
M("`@)V%T=')I8G5T97,G("`@/3X@87)R87DH*2P-"B`@("`J("`@("`@("=C
M;VYT96YT)R`@("`@(#T^("1C;VYT96YT+"`@("`@("\O(&]P=&EO;F%L#0H@
M("`@*B`@("`@("`G;F%M97-P86-E)R`@("`]/B`D;F%M97-P86-E("`@("`O
M+R!O<'1I;VYA;`T*("`@("H@("`@("`@)VYA;65S<&%C955R:2<@/3X@)&YA
M;65S<&%C955R:2`@+R\@;W!T:6]N86P-"B`@("`J("`@*0T*("`@("H-"B`@
M("`J($!A8V-E<W,@("!P<FEV871E#0H@("`@*B!`<&%R86T@("`@87)R87D@
M("`D=&%G('1A9R!D969I;FET:6]N#0H@("`@*B!`<&%R86T@("`@8F]O;&5A
M;B`D<F5P;&%C945N=&ET:65S('=H971H97(@=&\@<F5P;&%C92!834P@96YT
M:71I97,@:6X@8V]N=&5N="!O<B!N;W0-"B`@("`J($!R971U<FX@("!S=')I
M;F<@("1S=')I;F<@6$U,('1A9PT*("`@("HO#0H@("`@9G5N8W1I;VX@7V-R
M96%T95A-3%1A9R@@)'1A9RP@)')E<&QA8V5%;G1I=&EE<R`]('1R=64@*0T*
M("`@('L-"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=I;F1E;G1!='1R
M:6)U=&5S)UT@(3T](&9A;'-E*2![#0H@("`@("`@("`@("`D;75L=&EL:6YE
M(#T@=')U93L-"B`@("`@("`@("`@("1I;F1E;G0@("`@/2!S=')?<F5P96%T
M*"1T:&ES+3YO<'1I;VYS6R=I;F1E;G0G72P@)'1H:7,M/E]T86=$97!T:"D[
M#0H-"B`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG:6YD96YT071T
M<FEB=71E<R==(#T]("=?875T;R<I('L-"B`@("`@("`@("`@("`@("`D:6YD
M96YT("X]('-T<E]R97!E870H)R`G+"`H<W1R;&5N*"1T86=;)W%N86UE)UTI
M*S(I*3L-"@T*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`D:6YD96YT("X]("1T:&ES+3YO<'1I;VYS6R=I;F1E;G1!='1R:6)U=&5S
M)UT[#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`D;75L=&EL:6YE(#T@9F%L<V4[#0H@("`@("`@("`@("`D:6YD96YT
M("`@(#T@9F%L<V4[#0H@("`@("`@('T-"B`@("`-"B`@("`@("`@:68@*&ES
M7V%R<F%Y*"1T86=;)V-O;G1E;G0G72DI('L-"B`@("`@("`@("`@(&EF("AE
M;7!T>2@D=&%G6R=C;VYT96YT)UTI*2![#0H@("`@("`@("`@("`@("`@)'1A
M9ULG8V]N=&5N="==(#T@("`G)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?2!E;'-E:68H:7-?<V-A;&%R*"1T86=;)V-O;G1E;G0G72D@)B8@*'-T<FEN
M9RDD=&%G6R=C;VYT96YT)UT@/3T@)R<I('L-"B`@("`@("`@("`@("1T86=;
M)V-O;G1E;G0G72`]("`@)R<[#0H@("`@("`@('T-"B`@("`-"B`@("`@("`@
M:68@*&ES7W-C86QA<B@D=&%G6R=C;VYT96YT)UTI('Q\(&ES7VYU;&PH)'1A
M9ULG8V]N=&5N="==*2D@>PT*("`@("`@("`@("`@:68@*"1T:&ES+3YO<'1I
M;VYS6R=E;F-O9&EN9R==(#T]("=55$8M."<@)B8-"B`@("`@("`@("`@("`@
M("`@('9E<G-I;VY?8V]M<&%R92AP:'!V97)S:6]N*"DL("<U+C`N,"<L("=L
M="<I*2![#0H@("`@("`@("`@("`@("`@)&5N8V]D:6YG(#T@4$5!4E]086-K
M86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6Q?14Y4251)15-?551&.%]8
M34P[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1E
M;F-O9&EN9R`](%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5
M=&EL7T5.5$E424537UA-3#L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("1T86<@/2!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I
M;#HZ8W)E871E5&%G1G)O;4%R<F%Y*"1T86<L("1R97!L86-E16YT:71I97,L
M("1M=6QT:6QI;F4L("1I;F1E;G0L("1T:&ES+3YO<'1I;VYS6R=L:6YE8G)E
M86LG72P@)&5N8V]D:6YG*3L-"B`@("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y
M*"1T86=;)V-O;G1E;G0G72DI('L-"B`@("`@("`@("`@("1T86<@("`@/2`@
M("1T:&ES+3Y?<V5R:6%L:7IE07)R87DH)'1A9ULG8V]N=&5N="==+"`D=&%G
M6R=Q;F%M92==+"`D=&%G6R=A='1R:6)U=&5S)UTI.PT*("`@("`@("!](&5L
M<V5I9B`H:7-?;V)J96-T*"1T86=;)V-O;G1E;G0G72DI('L-"B`@("`@("`@
M("`@("1T86<@("`@/2`@("1T:&ES+3Y?<V5R:6%L:7IE3V)J96-T*"1T86=;
M)V-O;G1E;G0G72P@)'1A9ULG<6YA;64G72P@)'1A9ULG871T<FEB=71E<R==
M*3L-"B`@("`@("`@?2!E;'-E:68@*&ES7W)E<V]U<F-E*"1T86=;)V-O;G1E
M;G0G72DI('L-"B`@("`@("`@("`@('-E='1Y<&4H)'1A9ULG8V]N=&5N="==
M+"`G<W1R:6YG)RD[#0H@("`@("`@("`@("`D=&%G("`@(#T@("!014%27U!A
M8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;#HZ8W)E871E5&%G1G)O
M;4%R<F%Y*"1T86<L("1R97!L86-E16YT:71I97,I.PT*("`@("`@("!]#0H@
M("`@("`@(')E='5R;B`@)'1A9SL-"B`@("!]#0I]#0H-"B\O('=E;&PL(&ET
M)W,@;VYE('=A>2!T;R!D;R!T:&EN9W,@=VET:&]U="!E>'1R82!D97!S("XN
M+@T*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H
M/30Z("HO#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@
M4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK#0HO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`R(%1H
M92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!4:&ES('-O
M=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`@;V8@=&AE(%!(
M4"!L:6-E;G-E+"`@("`@("!\#0HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H
M('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@
M("`@('P-"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I
M9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N
M86)L92!T;R`@('P-"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`T*
M+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P
M>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@075T:&]R<SH@4W1E<&AA;B!38VAM
M:61T(#QS8VAS=$!P:'`M=&]O;',N;F5T/B`@("`@("`@("`@("`@("`@("`@
M("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+PT*+R\@
M("`@)$ED.B!V,BYP:'`L=B`Q+C,T(#(P,#8O,#,O,#(@,C`Z-3`Z-3D@8V5L
M;&]G($5X<"`D#0H-"B\J*@T*("H@97)R;W(@8V]D92!F;W(@:6YV86QI9"!C
M:&%R<R!I;B!834P@;F%M90T*("HO#0ID969I;F4H(E!%05)?4&%C:V%G949I
M;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL7T524D]27TE.5D%,241?0TA!4E,B
M+"`U,2D[#0H-"B\J*@T*("H@97)R;W(@8V]D92!F;W(@:6YV86QI9"!C:&%R
M<R!I;B!834P@;F%M90T*("HO#0ID969I;F4H(E!%05)?4&%C:V%G949I;&5?
M1V5N97)A=&]R7W8R7UA-3%]5=&EL7T524D]27TE.5D%,241?4U1!4E0B+"`U
M,BD[#0H-"B\J*@T*("H@97)R;W(@8V]D92!F;W(@;F]N+7-C86QA<B!T86<@
M8V]N=&5N=`T*("HO#0ID969I;F4H(E!%05)?4&%C:V%G949I;&5?1V5N97)A
M=&]R7W8R7UA-3%]5=&EL7T524D]27TY/3E]30T%,05)?0T].5$5.5"(L(#8P
M*3L-"B`@("`-"B\J*@T*("H@97)R;W(@8V]D92!F;W(@;6ES<VEN9R!T86<@
M;F%M90T*("HO#0ID969I;F4H(E!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R
M7W8R7UA-3%]5=&EL7T524D]27TY/7U1!1U].04U%(BP@-C$I.PT*("`@(`T*
M+RHJ#0H@*B!R97!L86-E(%A-3"!E;G1I=&EE<PT*("HO#0ID969I;F4H(E!%
M05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL7U)%4$Q!0T5?
M14Y4251)15,B+"`Q*3L-"@T*+RHJ#0H@*B!E;6)E9&0@8V]N=&5N="!I;B!A
M($-$871A(%-E8W1I;VX-"B`J+PT*9&5F:6YE*")014%27U!A8VMA9V5&:6QE
M7T=E;F5R871O<E]V,E]834Q?571I;%]#1$%405]314-424].(BP@,BD[#0H-
M"B\J*@T*("H@9&\@;F]T(')E<&QA8V4@96YT:71I=&5S#0H@*B\-"F1E9FEN
M92@B4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6Q?14Y4
M251)15-?3D].12(L(#`I.PT*#0HO*BH-"B`J(')E<&QA8V4@86QL(%A-3"!E
M;G1I=&ET97,-"B`J(%1H:7,@<V5T=&EN9R!W:6QL(')E<&QA8V4@/"P@/BP@
M(BP@)R!A;F0@)@T*("HO#0ID969I;F4H(E!%05)?4&%C:V%G949I;&5?1V5N
M97)A=&]R7W8R7UA-3%]5=&EL7T5.5$E424537UA-3"(L(#$I.PT*#0HO*BH-
M"B`J(')E<&QA8V4@;VYL>2!R97%U:7)E9"!834P@96YT:71I=&5S#0H@*B!4
M:&ES('-E='1I;F<@=VEL;"!R97!L86-E(#PL("(@86YD("8-"B`J+PT*9&5F
M:6YE*")014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;%]%
M3E1)5$E%4U]834Q?4D5154E2140B+"`R*3L-"@T*+RHJ#0H@*B!R97!L86-E
M($A434P@96YT:71I=&5S#0H@*B!`;&EN:R`@("!H='1P.B\O=W=W+G!H<"YN
M970O:'1M;&5N=&ET:65S#0H@*B\-"F1E9FEN92@B4$5!4E]086-K86=E1FEL
M95]'96YE<F%T;W)?=C)?6$U,7U5T:6Q?14Y4251)15-?2%1-3"(L(#,I.PT*
M#0HO*BH-"B`J(')E<&QA8V4@86QL(%A-3"!E;G1I=&ET97,L(&%N9"!E;F-O
M9&4@9G)O;2!)4T\M.#@U.2TQ('1O(%541BTX#0H@*B!4:&ES('-E='1I;F<@
M=VEL;"!R97!L86-E(#PL(#XL("(L("<@86YD("8-"B`J+PT*9&5F:6YE*")0
M14%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;%]%3E1)5$E%
M4U]55$8X7UA-3"(L(#0I.PT*#0HO*BH-"B`J('5T:6QI='D@8VQA<W,@9F]R
M('=O<FMI;F<@=VET:"!834P@9&]C=6UE;G1S#0H@*B`-"B`J(&-U<W1O;6EZ
M960@=F5R<VEO;B!O9B!834Q?571I;"`P+C8N,`T*("H-"B`J($!C871E9V]R
M>2!834P-"B`J($!P86-K86=E("!014%2#0H@*B!`=F5R<VEO;B`@,"XV+C`-
M"B`J($!A=71H;W(@("!3=&5P:&%N(%-C:&UI9'0@/'-C:'-T0'!H<"YN970^
M#0H@*B!`875T:&]R("`@1W)E9V]R>2!"96%V97(@/&-E;&QO9T!P:'`N;F5T
M/@T*("HO#0IC;&%S<R!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]8
M34Q?571I;"![#0H-"B`@("\J*@T*("`@("H@<F5T=7)N($%022!V97)S:6]N
M#0H@("`@*@T*("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("H@0'-T871I
M8PT*("`@("H@0')E='5R;B`@('-T<FEN9R`@)'9E<G-I;VX@05!)('9E<G-I
M;VX-"B`@("`J+PT*("`@(&9U;F-T:6]N(&%P:59E<G-I;VXH*0T*("`@('L-
M"B`@("`@("`@<F5T=7)N("(P+C8B.PT*("`@('T-"@T*("`@+RHJ#0H@("`@
M*B!R97!L86-E(%A-3"!E;G1I=&EE<PT*("`@("H-"B`@("`J(%=I=&@@=&AE
M(&]P=&EO;F%L('-E8V]N9"!P87)A;65T97(L('EO=2!M87D@<V5L96-T+"!W
M:&EC:`T*("`@("H@96YT:71I97,@<VAO=6QD(&)E(')E<&QA8V5D+@T*("`@
M("H-"B`@("`J(#QC;V1E/@T*("`@("H@<F5Q=6ER95]O;F-E("=834PO571I
M;"YP:'`G.PT*("`@("H@#0H@("`@*B`O+R!R97!L86-E(%A-3"!E;G1I=&5S
M.@T*("`@("H@)'-T<FEN9R`](%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R
M7W8R7UA-3%]5=&EL.CIR97!L86-E16YT:71I97,H(E1H:7,@<W1R:6YG(&-O
M;G1A:6YS(#P@)B`^+B(I.PT*("`@("H@/"]C;V1E/@T*("`@("H-"B`@("`J
M($!A8V-E<W,@("!P=6)L:6,-"B`@("`J($!S=&%T:6,-"B`@("`J($!P87)A
M;2`@("!S=')I;F<@('-T<FEN9R!W:&5R92!834P@<W!E8VEA;"!C:&%R<R!S
M:&]U;&0@8F4@<F5P;&%C960-"B`@("`J($!P87)A;2`@("!I;G1E9V5R('-E
M='1I;F<@9F]R(&5N=&ET:65S(&EN(&%T=')I8G5T92!V86QU97,@*&]N92!O
M9B!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;%]%3E1)
M5$E%4U]834PL(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5
M=&EL7T5.5$E424537UA-3%]215%525)%1"P@4$5!4E]086-K86=E1FEL95]'
M96YE<F%T;W)?=C)?6$U,7U5T:6Q?14Y4251)15-?2%1-3"D-"B`@("`J($!R
M971U<FX@("!S=')I;F<@('-T<FEN9R!W:71H(')E<&QA8V5D(&-H87)S#0H@
M("`@*B\-"B`@("!F=6YC=&EO;B!R97!L86-E16YT:71I97,H)'-T<FEN9RP@
M)')E<&QA8V5%;G1I=&EE<R`](%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R
M7W8R7UA-3%]5=&EL7T5.5$E424537UA-3"D-"B`@("![#0H@("`@("`@('-W
M:71C:"`H)')E<&QA8V5%;G1I=&EE<RD@>PT*("`@("`@("`@("`@8V%S92!0
M14%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;%]%3E1)5$E%
M4U]55$8X7UA-3#H-"B`@("`@("`@("`@("`@("!R971U<FX@<W1R='(H=71F
M.%]E;F-O9&4H)'-T<FEN9RDL87)R87DH#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G)B<@(#T^("<F86UP.R<L#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G/B<@(#T^
M("<F9W0[)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("<\)R`@/3X@)R9L=#LG+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)R(G("`]/B`G)G%U;W0[)RP-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=<)R<@/3X@
M)R9A<&]S.R<@*2D[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@
M("`@("!C87-E(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5
M=&EL7T5.5$E424537UA-3#H-"B`@("`@("`@("`@("`@("!R971U<FX@<W1R
M='(H)'-T<FEN9RQA<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("<F)R`@/3X@)R9A;7`[)RP-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<^)R`@/3X@)R9G=#LG
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)SPG("`]/B`G)FQT.R<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G(B<@(#T^("<F<75O=#LG+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)UPG)R`]/B`G)F%P;W,[
M)R`I*3L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A
M<V4@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6Q?14Y4
M251)15-?6$U,7U)%455)4D5$.@T*("`@("`@("`@("`@("`@(')E='5R;B!S
M=')T<B@D<W1R:6YG+&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)R8G("`]/B`G)F%M<#LG+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)SPG("`]/B`G)FQT
M.R<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G(B<@(#T^("<F<75O=#LG("DI.PT*("`@("`@("`@("`@("`@(&)R96%K
M.PT*("`@("`@("`@("`@8V%S92!014%27U!A8VMA9V5&:6QE7T=E;F5R871O
M<E]V,E]834Q?571I;%]%3E1)5$E%4U](5$U,.@T*("`@("`@("`@("`@("`@
M(')E='5R;B!H=&UL<W!E8VEA;&-H87)S*"1S=')I;F<I.PT*("`@("`@("`@
M("`@("`@(&)R96%K.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<W1R
M:6YG.PT*("`@('T-"@T*("`@+RHJ#0H@("`@*B!B=6EL9"!A;B!X;6P@9&5C
M;&%R871I;VX-"B`@("`J#0H@("`@*B`\8V]D93X-"B`@("`J(')E<75I<F5?
M;VYC92`G6$U,+U5T:6PN<&AP)SL-"B`@("`J(`T*("`@("H@+R\@9V5T(&%N
M(%A-3"!D96-L87)A=&EO;CH-"B`@("`J("1X;6Q$96-L(#T@4$5!4E]086-K
M86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ.F=E=%A-3$1E8VQA<F%T
M:6]N*"(Q+C`B+"`B551&+3@B+"!T<G5E*3L-"B`@("`J(#PO8V]D93X-"B`@
M("`J#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B!`<W1A=&EC#0H@
M("`@*B!`<&%R86T@("`@<W1R:6YG("`D=F5R<VEO;B`@("`@>&UL('9E<G-I
M;VX-"B`@("`J($!P87)A;2`@("!S=')I;F<@("1E;F-O9&EN9R`@("!C:&%R
M86-T97(@96YC;V1I;F<-"B`@("`J($!P87)A;2`@("!B;V]L96%N("1S=&%N
M9$%L;VYE("!D;V-U;65N="!I<R!S=&%N9&%L;VYE("AO<B!N;W0I#0H@("`@
M*B!`<F5T=7)N("`@<W1R:6YG("`D9&5C;"!X;6P@9&5C;&%R871I;VX-"B`@
M("`J($!U<V5S("`@("!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]8
M34Q?571I;#HZ871T<FEB=71E<U1O4W1R:6YG*"D@=&\@<V5R:6%L:7IE('1H
M92!A='1R:6)U=&5S(&]F('1H92!834P@9&5C;&%R871I;VX-"B`@("`J+PT*
M("`@(&9U;F-T:6]N(&=E=%A-3$1E8VQA<F%T:6]N*"1V97)S:6]N(#T@(C$N
M,"(L("1E;F-O9&EN9R`](&YU;&PL("1S=&%N9&%L;VYE(#T@;G5L;"D-"B`@
M("![#0H@("`@("`@("1A='1R:6)U=&5S(#T@87)R87DH#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(G9E<G-I;VXB(#T^("1V97)S:6]N+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@+R\@861D(&5N
M8V]D:6YG#0H@("`@("`@(&EF("@D96YC;V1I;F<@(3T](&YU;&PI('L-"B`@
M("`@("`@("`@("1A='1R:6)U=&5S6R)E;F-O9&EN9R)=(#T@)&5N8V]D:6YG
M.PT*("`@("`@("!]#0H@("`@("`@("\O(&%D9"!S=&%N9&%L;VYE+"!I9B!S
M<&5C:69I960-"B`@("`@("`@:68@*"1S=&%N9&%L;VYE("$]/2!N=6QL*2![
M#0H@("`@("`@("`@("`D871T<FEB=71E<ULB<W1A;F1A;&]N92)=(#T@)'-T
M86YD86QO;F4@/R`B>65S(B`Z(")N;R([#0H@("`@("`@('T-"B`@("`@("`@
M#0H@("`@("`@(')E='5R;B!S<')I;G1F*"(\/WAM;"5S/SXB+"!014%27U!A
M8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;#HZ871T<FEB=71E<U1O
M4W1R:6YG*"1A='1R:6)U=&5S+"!F86QS92DI.PT*("`@('T-"@T*("`@+RHJ
M#0H@("`@*B!B=6EL9"!A(&1O8W5M96YT('1Y<&4@9&5C;&%R871I;VX-"B`@
M("`J#0H@("`@*B`\8V]D93X-"B`@("`J(')E<75I<F5?;VYC92`G6$U,+U5T
M:6PN<&AP)SL-"B`@("`J(`T*("`@("H@+R\@9V5T(&$@9&]C='EP92!D96-L
M87)A=&EO;CH-"B`@("`J("1X;6Q$96-L(#T@4$5!4E]086-K86=E1FEL95]'
M96YE<F%T;W)?=C)?6$U,7U5T:6PZ.F=E=$1O8U1Y<&5$96-L87)A=&EO;B@B
M<F]O=%1A9R(L(FUY1&]C5'EP92YD=&0B*3L-"B`@("`J(#PO8V]D93X-"B`@
M("`J#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B!`<W1A=&EC#0H@
M("`@*B!`<&%R86T@("`@<W1R:6YG("`D<F]O="`@("`@("`@(&YA;64@;V8@
M=&AE(')O;W0@=&%G#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D=7)I("`@
M("`@("`@('5R:2!O9B!T:&4@9&]C='EP92!D969I;FET:6]N("AO<B!A<G)A
M>2!W:71H('5R:2!A;F0@<'5B;&EC(&ED*0T*("`@("H@0'!A<F%M("`@('-T
M<FEN9R`@)&EN=&5R;F%L1'1D("!I;G1E<FYA;"!D=&0@96YT<FEE<R`@(`T*
M("`@("H@0')E='5R;B`@('-T<FEN9R`@)&1E8VP@("`@("`@("!D;V-T>7!E
M(&1E8VQA<F%T:6]N#0H@("`@*B!`<VEN8V4@("`@,"XR#0H@("`@*B\-"B`@
M("!F=6YC=&EO;B!G971$;V-4>7!E1&5C;&%R871I;VXH)')O;W0L("1U<FD@
M/2!N=6QL+"`D:6YT97)N86Q$=&0@/2!N=6QL*0T*("`@('L-"B`@("`@("`@
M:68@*&ES7V%R<F%Y*"1U<FDI*2![#0H@("`@("`@("`@("`D<F5F(#T@<W!R
M:6YT9B@@)R!054),24,@(B5S(B`B)7,B)RP@)'5R:5LB:60B72P@)'5R:5LB
M=7)I(ET@*3L-"B`@("`@("`@?2!E;'-E:68@*"%E;7!T>2@D=7)I*2D@>PT*
M("`@("`@("`@("`@)')E9B`]('-P<FEN=&8H("<@4UE35$5-("(E<R(G+"`D
M=7)I("D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D<F5F(#T@
M(B([#0H@("`@("`@('T-"@T*("`@("`@("!I9B`H96UP='DH)&EN=&5R;F%L
M1'1D*2D@>PT*("`@("`@("`@("`@<F5T=7)N('-P<FEN=&8H(CPA1$]#5%E0
M12`E<R5S/B(L("1R;V]T+"`D<F5F*3L-"B`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@(')E='5R;B!S<')I;G1F*"(\(41/0U194$4@)7,E<R!;7&XE
M<UQN73XB+"`D<F]O="P@)')E9BP@)&EN=&5R;F%L1'1D*3L-"B`@("`@("`@
M?0T*("`@('T-"@T*("`@+RHJ#0H@("`@*B!C<F5A=&4@<W1R:6YG(')E<')E
M<V5N=&%T:6]N(&]F(&%N(&%T=')I8G5T92!L:7-T#0H@("`@*@T*("`@("H@
M/&-O9&4^#0H@("`@*B!R97%U:7)E7V]N8V4@)UA-3"]5=&EL+G!H<"<[#0H@
M("`@*B`-"B`@("`J("\O(&)U:6QD(&%N(&%T=')I8G5T92!S=')I;F<-"B`@
M("`J("1A='0@/2!A<G)A>2@-"B`@("`J("`@("`@("`@("`@("`B9F]O(B`@
M(#T^("`B8F%R(BP-"B`@("`J("`@("`@("`@("`@("`B87)G:"(@(#T^("`B
M=&]M871O(@T*("`@("H@("`@("`@("`@("`I.PT*("`@("H-"B`@("`J("1A
M='1,:7-T(#T@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T
M:6PZ.F%T=')I8G5T97-4;U-T<FEN9R@D871T*3L@("`@#0H@("`@*B`\+V-O
M9&4^#0H@("`@*@T*("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("H@0'-T
M871I8PT*("`@("H@0'!A<F%M("`@(&%R<F%Y("`@("`@("`@)&%T=')I8G5T
M97,@("`@("`@(&%T=')I8G5T92!A<G)A>0T*("`@("H@0'!A<F%M("`@(&)O
M;VQE86Y\87)R87D@)'-O<G0@("`@("`@("`@("`@('-O<G0@871T<FEB=71E
M(&QI<W0@86QP:&%B971I8V%L;'DL(&UA>2!A;'-O(&)E(&%N(&%S<V]C(&%R
M<F%Y(&-O;G1A:6YI;F<@=&AE(&ME>7,@)W-O<G0G+"`G;75L=&EL:6YE)RP@
M)VEN9&5N="<L("=L:6YE8G)E86LG(&%N9"`G96YT:71I97,G#0H@("`@*B!`
M<&%R86T@("`@8F]O;&5A;B`@("`@("`D;75L=&EL:6YE("`@("`@("`@=7-E
M(&QI;F5B<F5A:W,L(&EF(&UO<F4@=&AA;B!O;F4@871T<FEB=71E(&ES(&=I
M=F5N#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`@("`@("`D:6YD96YT("`@
M("`@("`@("`@<W1R:6YG('5S960@9F]R(&EN9&5N=&%T:6]N(&]F(&UU;'1I
M;&EN92!A='1R:6)U=&5S#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`@("`@
M("`D;&EN96)R96%K("`@("`@("`@<W1R:6YG('5S960@9F]R(&QI;F5B<F5A
M:W,@;V8@;75L=&EL:6YE(&%T=')I8G5T97,-"B`@("`J($!P87)A;2`@("!I
M;G1E9V5R("`@("`@("1E;G1I=&EE<R`@("`@("`@("!S971T:6YG(&9O<B!E
M;G1I=&EE<R!I;B!A='1R:6)U=&4@=F%L=65S("AO;F4@;V8@4$5!4E]086-K
M86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6Q?14Y4251)15-?3D].12P@
M4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6Q?14Y4251)
M15-?6$U,+"!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I
M;%]%3E1)5$E%4U]834Q?4D5154E2140L(%!%05)?4&%C:V%G949I;&5?1V5N
M97)A=&]R7W8R7UA-3%]5=&EL7T5.5$E424537TA434PI#0H@("`@*B!`<F5T
M=7)N("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R:6YG
M(')E<')E<V5N=&%T:6]N(&]F('1H92!A='1R:6)U=&5S#0H@("`@*B!`=7-E
M<R`@("`@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ
M.G)E<&QA8V5%;G1I=&EE<R@I('1O(')E<&QA8V4@6$U,(&5N=&ET:65S(&EN
M(&%T=')I8G5T92!V86QU97,-"B`@("`J($!T;V1O("`@("!A;&QO=R!S;W)T
M(&%L<V\@=&\@8F4@86X@;W!T:6]N<R!A<G)A>0T*("`@("HO#0H@("`@9G5N
M8W1I;VX@871T<FEB=71E<U1O4W1R:6YG*"1A='1R:6)U=&5S+"`D<V]R="`]
M('1R=64L("1M=6QT:6QI;F4@/2!F86QS92P@)&EN9&5N="`]("<@("`@)RP@
M)&QI;F5B<F5A:R`](")<;B(L("1E;G1I=&EE<R`](%!%05)?4&%C:V%G949I
M;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL7T5.5$E424537UA-3"D-"B`@("![
M#0H@("`@("`@("\J*@T*("`@("`@("`@*B!S96-O;F0@<&%R86UE=&5R(&UA
M>2!B92!A;B!A<G)A>0T*("`@("`@("`@*B\-"B`@("`@("`@:68@*&ES7V%R
M<F%Y*"1S;W)T*2D@>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1S;W)T6R=M
M=6QT:6QI;F4G72DI('L-"B`@("`@("`@("`@("`@("`D;75L=&EL:6YE(#T@
M)'-O<G1;)VUU;'1I;&EN92==.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@:68@*&ES<V5T*"1S;W)T6R=I;F1E;G0G72DI('L-"B`@("`@("`@("`@
M("`@("`D:6YD96YT(#T@)'-O<G1;)VEN9&5N="==.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1S;W)T6R=L:6YE8G)E86LG72DI
M('L-"B`@("`@("`@("`@("`@("`D;75L=&EL:6YE(#T@)'-O<G1;)VQI;F5B
M<F5A:R==.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T
M*"1S;W)T6R=E;G1I=&EE<R==*2D@>PT*("`@("`@("`@("`@("`@("1E;G1I
M=&EE<R`]("1S;W)T6R=E;G1I=&EE<R==.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@:68@*&ES<V5T*"1S;W)T6R=S;W)T)UTI*2![#0H@("`@("`@
M("`@("`@("`@)'-O<G0@/2`D<V]R=%LG<V]R="==.PT*("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D<V]R="`]('1R=64[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)'-T<FEN9R`]("<G.PT*
M("`@("`@("!I9B`H:7-?87)R87DH)&%T=')I8G5T97,I("8F("%E;7!T>2@D
M871T<FEB=71E<RDI('L-"B`@("`@("`@("`@(&EF("@D<V]R="D@>PT*("`@
M("`@("`@("`@("`@(&MS;W)T*"1A='1R:6)U=&5S*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(&EF*"`A)&UU;'1I;&EN92!\?"!C;W5N="@D871T
M<FEB=71E<RD@/3T@,2D@>PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1A
M='1R:6)U=&5S(&%S("1K97D@/3X@)'9A;'5E*2![#0H@("`@("`@("`@("`@
M("`@("`@(&EF("@D96YT:71I97,@(3T@4$5!4E]086-K86=E1FEL95]'96YE
M<F%T;W)?=C)?6$U,7U5T:6Q?14Y4251)15-?3D].12D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)'9A;'5E(#T@4$5!4E]086-K86=E1FEL95]'96YE
M<F%T;W)?=C)?6$U,7U5T:6PZ.G)E<&QA8V5%;G1I=&EE<R@D=F%L=64L("1E
M;G1I=&EE<RD[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@)'-T<FEN9R`N/2`G("<N)&ME>2XG/2(G+B1V86QU92XG(B<[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`D9FER<W0@/2!T<G5E.PT*("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1A='1R:6)U=&5S(&%S("1K97D@/3X@)'9A;'5E*2![#0H@
M("`@("`@("`@("`@("`@("`@(&EF("@D96YT:71I97,@(3T@4$5!4E]086-K
M86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6Q?14Y4251)15-?3D].12D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@4$5!4E]086-K
M86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ.G)E<&QA8V5%;G1I=&EE
M<R@D=F%L=64L("1E;G1I=&EE<RD[#0H@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@:68@*"1F:7)S="D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)'-T<FEN9R`N/2`B("(N)&ME>2XG/2(G+B1V86QU
M92XG(B<[#0H@("`@("`@("`@("`@("`@("`@("`@("`D9FER<W0@/2!F86QS
M93L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1S=')I;F<@+CT@)&QI;F5B<F5A:RXD:6YD96YT+B1K
M97DN)STB)RXD=F%L=64N)R(G.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@(')E='5R;B`D<W1R:6YG.PT*("`@('T-"@T*("`@+RHJ#0H@("`@
M*B!C<F5A=&4@82!T86<-"B`@("`J#0H@("`@*B!4:&ES(&UE=&AO9"!W:6QL
M(&-A;&P@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ
M.F-R96%T951A9T9R;VU!<G)A>2@I+"!W:&EC:`T*("`@("H@:7,@;6]R92!F
M;&5X:6)L92X-"B`@("`J#0H@("`@*B`\8V]D93X-"B`@("`J(')E<75I<F5?
M;VYC92`G6$U,+U5T:6PN<&AP)SL-"B`@("`J(`T*("`@("H@+R\@8W)E871E
M(&%N(%A-3"!T86<Z#0H@("`@*B`D=&%G(#T@4$5!4E]086-K86=E1FEL95]'
M96YE<F%T;W)?=C)?6$U,7U5T:6PZ.F-R96%T951A9R@B;7E.<SIM>51A9R(L
M(&%R<F%Y*")F;V\B(#T^(")B87(B*2P@(E1H:7,@:7,@:6YS:61E('1H92!T
M86<B+"`B:'1T<#HO+W=W=RYW,V,N;W)G+VUY3G,C(BD[#0H@("`@*B`\+V-O
M9&4^#0H@("`@*@T*("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("H@0'-T
M871I8PT*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)'%N86UE("`@("`@("`@
M("`@('%U86QI9FEE9"!T86=N86UE("AI;F-L=61I;F<@;F%M97-P86-E*0T*
M("`@("H@0'!A<F%M("`@(&%R<F%Y("`@)&%T=')I8G5T97,@("`@("`@(&%R
M<F%Y(&-O;G1A:6YG(&%T=')I8G5T97,-"B`@("`J($!P87)A;2`@("!M:7AE
M9"`@("1C;VYT96YT#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D;F%M97-P
M86-E57)I("`@("`@55))(&]F('1H92!N86UE<W!A8V4-"B`@("`J($!P87)A
M;2`@("!I;G1E9V5R("1R97!L86-E16YT:71I97,@("!W:&5T:&5R('1O(')E
M<&QA8V4@6$U,('-P96-I86P@8VAA<G,@:6X@8V]N=&5N="P@96UB961D(&ET
M(&EN(&$@0T1A=&$@<V5C=&EO;B!O<B!N;VYE(&]F(&)O=&@-"B`@("`J($!P
M87)A;2`@("!B;V]L96%N("1M=6QT:6QI;F4@("`@("`@("!W:&5T:&5R('1O
M(&-R96%T92!A(&UU;'1I;&EN92!T86<@=VAE<F4@96%C:"!A='1R:6)U=&4@
M9V5T<R!W<FET=&5N('1O(&$@<VEN9VQE(&QI;F4-"B`@("`J($!P87)A;2`@
M("!S=')I;F<@("1I;F1E;G0@("`@("`@("`@("!S=')I;F<@=7-E9"!T;R!I
M;F1E;G0@871T<FEB=71E<R`H7V%U=&\@:6YD96YT<R!A='1R:6)U=&5S('-O
M('1H97D@<W1A<G0@870@=&AE('-A;64@8V]L=6UN*0T*("`@("H@0'!A<F%M
M("`@('-T<FEN9R`@)&QI;F5B<F5A:R`@("`@("`@('-T<FEN9R!U<V5D(&9O
M<B!L:6YE8G)E86MS#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D96YC;V1I
M;F<@("`@("`@("`@96YC;V1I;F<@=&AA="!S:&]U;&0@8F4@=7-E9"!T;R!T
M<F%N<VQA=&4@8V]N=&5N=`T*("`@("H@0')E='5R;B`@('-T<FEN9R`@)'-T
M<FEN9R`@("`@("`@("`@(%A-3"!T86<-"B`@("`J($!S964@("`@("!014%2
M7U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;#HZ8W)E871E5&%G
M1G)O;4%R<F%Y*"D-"B`@("`J($!U<V5S("`@("!014%27U!A8VMA9V5&:6QE
M7T=E;F5R871O<E]V,E]834Q?571I;#HZ8W)E871E5&%G1G)O;4%R<F%Y*"D@
M=&\@8W)E871E('1H92!T86<-"B`@("`J+PT*("`@(&9U;F-T:6]N(&-R96%T
M951A9R@D<6YA;64L("1A='1R:6)U=&5S(#T@87)R87DH*2P@)&-O;G1E;G0@
M/2!N=6QL+"`D;F%M97-P86-E57)I(#T@;G5L;"P@)')E<&QA8V5%;G1I=&EE
M<R`](%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL7U)%
M4$Q!0T5?14Y4251)15,L("1M=6QT:6QI;F4@/2!F86QS92P@)&EN9&5N="`]
M(")?875T;R(L("1L:6YE8G)E86L@/2`B7&XB+"`D96YC;V1I;F<@/2!014%2
M7U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;%]%3E1)5$E%4U]8
M34PI#0H@("`@>PT*("`@("`@("`D=&%G(#T@87)R87DH#0H@("`@("`@("`@
M("`@("`@("`@("`B<6YA;64B("`@("`@/3X@)'%N86UE+`T*("`@("`@("`@
M("`@("`@("`@("`@(F%T=')I8G5T97,B(#T^("1A='1R:6)U=&5S#0H@("`@
M("`@("`@("`@("`@("`@("D[#0H-"B`@("`@("`@+R\@861D('1A9R!C;VYT
M96YT#0H@("`@("`@(&EF("@D8V]N=&5N="`A/3T@;G5L;"D@>PT*("`@("`@
M("`@("`@)'1A9ULB8V]N=&5N=")=(#T@)&-O;G1E;G0[#0H@("`@("`@('T-
M"B`@("`@("`@#0H@("`@("`@("\O(&%D9"!N86UE<W!A8V4@57)I#0H@("`@
M("`@(&EF("@D;F%M97-P86-E57)I("$]/2!N=6QL*2![#0H@("`@("`@("`@
M("`D=&%G6R)N86UE<W!A8V55<FDB72`]("1N86UE<W!A8V55<FD[#0H@("`@
M("`@('T-"@T*("`@("`@("!R971U<FX@4$5!4E]086-K86=E1FEL95]'96YE
M<F%T;W)?=C)?6$U,7U5T:6PZ.F-R96%T951A9T9R;VU!<G)A>2@D=&%G+"`D
M<F5P;&%C945N=&ET:65S+"`D;75L=&EL:6YE+"`D:6YD96YT+"`D;&EN96)R
M96%K+"`D96YC;V1I;F<I.PT*("`@('T-"@T*("`@+RHJ#0H@("`@*B!C<F5A
M=&4@82!T86<@9G)O;2!A;B!A<G)A>0T*("`@("H@=&AI<R!M971H;V0@87=A
M:71S(&%N(&%R<F%Y(&EN('1H92!F;VQL;W=I;F<@9F]R;6%T#0H@("`@*B`\
M<')E/@T*("`@("H@87)R87DH#0H@("`@*B`@(G%N86UE(B`@("`@("`@/3X@
M)'%N86UE("`@("`@("`@+R\@<75A;&EF:65D(&YA;64@;V8@=&AE('1A9PT*
M("`@("H@(")N86UE<W!A8V4B("`@(#T^("1N86UE<W!A8V4@("`@("\O(&YA
M;65S<&%C92!P<F5F:7@@*&]P=&EO;F%L+"!I9B!Q;F%M92!I<R!S<&5C:69I
M960@;W(@;F\@;F%M97-P86-E*0T*("`@("H@(")L;V-A;'!A<G0B("`@(#T^
M("1L;V-A;'!A<G0L("`@("\O(&QO8V%L('!A<G0@;V8@=&AE('1A9VYA;64@
M*&]P=&EO;F%L+"!I9B!Q;F%M92!I<R!S<&5C:69I960I#0H@("`@*B`@(F%T
M=')I8G5T97,B("`@/3X@87)R87DH*2P@("`@("`@+R\@87)R87D@8V]N=&%I
M;FEN9R!A;&P@871T<FEB=71E<R`H;W!T:6]N86PI#0H@("`@*B`@(F-O;G1E
M;G0B("`@("`@/3X@)&-O;G1E;G0L("`@("`@+R\@=&%G(&-O;G1E;G0@*&]P
M=&EO;F%L*0T*("`@("H@(")N86UE<W!A8V55<FDB(#T^("1N86UE<W!A8V55
M<FD@("\O(&YA;65S<&%C955R:2!F;W(@=&AE(&=I=F5N(&YA;65S<&%C92`H
M;W!T:6]N86PI#0H@("`@*B`@("D-"B`@("`J(#PO<')E/@T*("`@("H-"B`@
M("`J(#QC;V1E/@T*("`@("H@<F5Q=6ER95]O;F-E("=834PO571I;"YP:'`G
M.PT*("`@("H@#0H@("`@*B`D=&%G(#T@87)R87DH#0H@("`@*B`@("`@("`@
M("`@(G%N86UE(B`@("`@("`@/3X@(F9O;SIB87(B+`T*("`@("H@("`@("`@
M("`@(")N86UE<W!A8V55<FDB(#T^(")H='1P.B\O9F]O+F-O;2(L#0H@("`@
M*B`@("`@("`@("`@(F%T=')I8G5T97,B("`@/3X@87)R87DH(")K97DB(#T^
M(")V86QU92(L(")A<F=H(B`]/B`B9G)U:70F=F5G971A8FQE(B`I+`T*("`@
M("H@("`@("`@("`@(")C;VYT96YT(B`@("`@(#T^(")))VT@:6YS:61E('1H
M92!T86<B+`T*("`@("H@("`@("`@("`@("`I.PT*("`@("H@+R\@8W)E871I
M;F<@82!T86<@=VET:"!Q=6%L:69I960@;F%M92!A;F0@;F%M97-P86-E57)I
M#0H@("`@*B`D<W1R:6YG(#T@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?
M=C)?6$U,7U5T:6PZ.F-R96%T951A9T9R;VU!<G)A>2@D=&%G*3L-"B`@("`J
M(#PO8V]D93X-"B`@("`J#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@
M*B!`<W1A=&EC#0H@("`@*B!`<&%R86T@("`@87)R87D@("`D=&%G("`@("`@
M("`@("`@("`@=&%G(&1E9FEN:71I;VX-"B`@("`J($!P87)A;2`@("!I;G1E
M9V5R("1R97!L86-E16YT:71I97,@("!W:&5T:&5R('1O(')E<&QA8V4@6$U,
M('-P96-I86P@8VAA<G,@:6X@8V]N=&5N="P@96UB961D(&ET(&EN(&$@0T1A
M=&$@<V5C=&EO;B!O<B!N;VYE(&]F(&)O=&@-"B`@("`J($!P87)A;2`@("!B
M;V]L96%N("1M=6QT:6QI;F4@("`@("`@("!W:&5T:&5R('1O(&-R96%T92!A
M(&UU;'1I;&EN92!T86<@=VAE<F4@96%C:"!A='1R:6)U=&4@9V5T<R!W<FET
M=&5N('1O(&$@<VEN9VQE(&QI;F4-"B`@("`J($!P87)A;2`@("!S=')I;F<@
M("1I;F1E;G0@("`@("`@("`@("!S=')I;F<@=7-E9"!T;R!I;F1E;G0@871T
M<FEB=71E<R`H7V%U=&\@:6YD96YT<R!A='1R:6)U=&5S('-O('1H97D@<W1A
M<G0@870@=&AE('-A;64@8V]L=6UN*0T*("`@("H@0'!A<F%M("`@('-T<FEN
M9R`@)&QI;F5B<F5A:R`@("`@("`@('-T<FEN9R!U<V5D(&9O<B!L:6YE8G)E
M86MS#0H@("`@*B!`<F5T=7)N("`@<W1R:6YG("`D<W1R:6YG("`@("`@("`@
M("`@6$U,('1A9PT*("`@("H@0'-E92`@("`@(%!%05)?4&%C:V%G949I;&5?
M1V5N97)A=&]R7W8R7UA-3%]5=&EL.CIC<F5A=&5486<H*0T*("`@("H@0'5S
M97,@("`@(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL
M.CIA='1R:6)U=&5S5&]3=')I;F<H*2!T;R!S97)I86QI>F4@=&AE(&%T=')I
M8G5T97,@;V8@=&AE('1A9PT*("`@("H@0'5S97,@("`@(%!%05)?4&%C:V%G
M949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL.CIS<&QI=%%U86QI9FEE9$YA
M;64H*2!T;R!G970@;&]C86P@<&%R="!A;F0@;F%M97-P86-E(&]F(&$@<75A
M;&EF:65D(&YA;64-"B`@("`J+PT*("`@(&9U;F-T:6]N(&-R96%T951A9T9R
M;VU!<G)A>2@D=&%G+"`D<F5P;&%C945N=&ET:65S(#T@4$5!4E]086-K86=E
M1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6Q?4D503$%#15]%3E1)5$E%4RP@
M)&UU;'1I;&EN92`](&9A;'-E+"`D:6YD96YT(#T@(E]A=71O(BP@)&QI;F5B
M<F5A:R`](")<;B(L("1E;F-O9&EN9R`](%!%05)?4&%C:V%G949I;&5?1V5N
M97)A=&]R7W8R7UA-3%]5=&EL7T5.5$E424537UA-3"D-"B`@("![#0H@("`@
M("`@(&EF("AI<W-E="@D=&%G6R)C;VYT96YT(ETI("8F("%I<U]S8V%L87(H
M)'1A9ULB8V]N=&5N=")=*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05)?
M4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL.CIR86ES945R<F]R
M*"`B4W5P<&QI960@;F]N+7-C86QA<B!V86QU92!A<R!T86<@8V]N=&5N="(L
M(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL7T524D]2
M7TY/3E]30T%,05)?0T].5$5.5"`I.PT*("`@("`@("!]#0H-"B`@("`@("`@
M:68@*"%I<W-E="@D=&%G6R=Q;F%M92==*2`F)B`A:7-S970H)'1A9ULG;&]C
M86Q087)T)UTI*2![#0H@("`@("`@("`@("!R971U<FX@4$5!4E]086-K86=E
M1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ.G)A:7-E17)R;W(H("=9;W4@
M;75S="!E:71H97(@<W5P<&QY(&$@<75A;&EF:65D(&YA;64@*'%N86UE*2!O
M<B!L;V-A;"!T86<@;F%M92`H;&]C86Q087)T*2XG+"!014%27U!A8VMA9V5&
M:6QE7T=E;F5R871O<E]V,E]834Q?571I;%]%4E)/4E].3U]404=?3D%-12`I
M.PT*("`@("`@("!]#0H-"B`@("`@("`@+R\@:68@;F\@871T<FEB=71E<R!H
M878@8F5E;B!S970L('5S92!E;7!T>2!A='1R:6)U=&5S#0H@("`@("`@(&EF
M("@A:7-S970H)'1A9ULB871T<FEB=71E<R)=*2!\?"`A:7-?87)R87DH)'1A
M9ULB871T<FEB=71E<R)=*2D@>PT*("`@("`@("`@("`@)'1A9ULB871T<FEB
M=71E<R)=(#T@87)R87DH*3L-"B`@("`@("`@?0T*("`@("`@("`-"B`@("`@
M("`@+R\@<75A;&EF:65D(&YA;64@:7,@;F]T(&=I=F5N#0H@("`@("`@(&EF
M("@A:7-S970H)'1A9ULB<6YA;64B72DI('L-"B`@("`@("`@("`@("\O(&-H
M96-K(&9O<B!N86UE<W!A8V4-"B`@("`@("`@("`@(&EF("AI<W-E="@D=&%G
M6R)N86UE<W!A8V4B72D@)B8@(65M<'1Y*"1T86=;(FYA;65S<&%C92)=*2D@
M>PT*("`@("`@("`@("`@("`@("1T86=;(G%N86UE(ET@/2`D=&%G6R)N86UE
M<W!A8V4B72XB.B(N)'1A9ULB;&]C86Q087)T(ET[#0H@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("1T86=;(G%N86UE(ET@/2`D=&%G
M6R)L;V-A;%!A<G0B73L-"B`@("`@("`@("`@('T-"B`@("`@("`@+R\@;F%M
M97-P86-E(%5222!I<R!S970L(&)U="!N;R!N86UE<W!A8V4-"B`@("`@("`@
M?2!E;'-E:68@*&ES<V5T*"1T86=;(FYA;65S<&%C955R:2)=*2`F)B`A:7-S
M970H)'1A9ULB;F%M97-P86-E(ETI*2![#0H@("`@("`@("`@("`D<&%R=',@
M/2!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;#HZ<W!L
M:711=6%L:69I961.86UE*"1T86=;(G%N86UE(ETI.PT*("`@("`@("`@("`@
M)'1A9ULB;&]C86Q087)T(ET@/2`D<&%R='-;(FQO8V%L4&%R=")=.PT*("`@
M("`@("`@("`@:68@*&ES<V5T*"1P87)T<ULB;F%M97-P86-E(ETI*2![#0H@
M("`@("`@("`@("`@("`@)'1A9ULB;F%M97-P86-E(ET@/2`D<&%R='-;(FYA
M;65S<&%C92)=.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H-"B`@("`@
M("`@:68@*&ES<V5T*"1T86=;(FYA;65S<&%C955R:2)=*2`F)B`A96UP='DH
M)'1A9ULB;F%M97-P86-E57)I(ETI*2![#0H@("`@("`@("`@("`O+R!I<R!A
M(&YA;65S<&%C92!G:79E;@T*("`@("`@("`@("`@:68@*&ES<V5T*"1T86=;
M(FYA;65S<&%C92)=*2`F)B`A96UP='DH)'1A9ULB;F%M97-P86-E(ETI*2![
M#0H@("`@("`@("`@("`@("`@)'1A9ULB871T<FEB=71E<R)=6R)X;6QN<SHB
M+B1T86=;(FYA;65S<&%C92)=72`]("1T86=;(FYA;65S<&%C955R:2)=.PT*
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`O+R!D969I
M;F4@=&AI<R!5<FD@87,@=&AE(&1E9F%U;'0@;F%M97-P86-E#0H@("`@("`@
M("`@("`@("`@)'1A9ULB871T<FEB=71E<R)=6R)X;6QN<R)=(#T@)'1A9ULB
M;F%M97-P86-E57)I(ET[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"@T*
M("`@("`@("`O+R!C:&5C:R!F;W(@;75L=&EL:6YE(&%T=')I8G5T97,-"B`@
M("`@("`@:68@*"1M=6QT:6QI;F4@/3T]('1R=64I('L-"B`@("`@("`@("`@
M(&EF("@D:6YD96YT(#T]/2`B7V%U=&\B*2![#0H@("`@("`@("`@("`@("`@
M)&EN9&5N="`]('-T<E]R97!E870H(B`B+"`H<W1R;&5N*"1T86=;(G%N86UE
M(ETI*S(I*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`-
M"B`@("`@("`@+R\@8W)E871E(&%T=')I8G5T92!L:7-T#0H@("`@("`@("1A
M='1,:7-T("`@(#T@("!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]8
M34Q?571I;#HZ871T<FEB=71E<U1O4W1R:6YG*"1T86=;(F%T=')I8G5T97,B
M72P@=')U92P@)&UU;'1I;&EN92P@)&EN9&5N="P@)&QI;F5B<F5A:R`I.PT*
M("`@("`@("!I9B`H(6ES<V5T*"1T86=;(F-O;G1E;G0B72D@?'P@*'-T<FEN
M9RDD=&%G6R)C;VYT96YT(ET@/3T@)R<I('L-"B`@("`@("`@("`@("1T86<@
M("`@/2`@('-P<FEN=&8H(CPE<R5S("\^(BP@)'1A9ULB<6YA;64B72P@)&%T
M=$QI<W0I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@:68@*"1R
M97!L86-E16YT:71I97,@/3T@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?
M=C)?6$U,7U5T:6Q?4D503$%#15]%3E1)5$E%4RD@>PT*("`@("`@("`@("`@
M("`@("1T86=;(F-O;G1E;G0B72`](%!%05)?4&%C:V%G949I;&5?1V5N97)A
M=&]R7W8R7UA-3%]5=&EL.CIR97!L86-E16YT:71I97,H)'1A9ULB8V]N=&5N
M=")=+"`D96YC;V1I;F<I.PT*("`@("`@("`@("`@?2!E;'-E:68@*"1R97!L
M86-E16YT:71I97,@/3T@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?
M6$U,7U5T:6Q?0T1!5$%?4T5#5$E/3BD@>PT*("`@("`@("`@("`@("`@("1T
M86=;(F-O;G1E;G0B72`](%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R
M7UA-3%]5=&EL.CIC<F5A=&5#1&%T85-E8W1I;VXH)'1A9ULB8V]N=&5N=")=
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1T86<@("`@/2`@('-P
M<FEN=&8H(CPE<R5S/B5S/"\E<SXB+"`D=&%G6R)Q;F%M92)=+"`D871T3&ES
M="P@)'1A9ULB8V]N=&5N=")=+"`D=&%G6R)Q;F%M92)=("D[#0H@("`@("`@
M('T@("`@("`@(`T*("`@("`@("!R971U<FX@("1T86<[#0H@("`@?0T*#0H@
M("`O*BH-"B`@("`J(&-R96%T92!A('-T87)T(&5L96UE;G0-"B`@("`J#0H@
M("`@*B`\8V]D93X-"B`@("`J(')E<75I<F5?;VYC92`G6$U,+U5T:6PN<&AP
M)SL-"B`@("`J(`T*("`@("H@+R\@8W)E871E(&%N(%A-3"!S=&%R="!E;&5M
M96YT.@T*("`@("H@)'1A9R`](%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R
M7W8R7UA-3%]5=&EL.CIC<F5A=&53=&%R=$5L96UE;G0H(FUY3G,Z;7E486<B
M+"!A<G)A>2@B9F]O(B`]/B`B8F%R(BD@+")H='1P.B\O=W=W+G<S8RYO<F<O
M;7E.<R,B*3L-"B`@("`J(#PO8V]D93X-"B`@("`J#0H@("`@*B!`86-C97-S
M("`@<'5B;&EC#0H@("`@*B!`<W1A=&EC#0H@("`@*B!`<&%R86T@("`@<W1R
M:6YG("`D<6YA;64@("`@("`@("`@("`@<75A;&EF:65D('1A9VYA;64@*&EN
M8VQU9&EN9R!N86UE<W!A8V4I#0H@("`@*B!`<&%R86T@("`@87)R87D@("`D
M871T<FEB=71E<R`@("`@("`@87)R87D@8V]N=&%I;F<@871T<FEB=71E<PT*
M("`@("H@0'!A<F%M("`@('-T<FEN9R`@)&YA;65S<&%C955R:2`@("`@(%52
M22!O9B!T:&4@;F%M97-P86-E#0H@("`@*B!`<&%R86T@("`@8F]O;&5A;B`D
M;75L=&EL:6YE("`@("`@("`@=VAE=&AE<B!T;R!C<F5A=&4@82!M=6QT:6QI
M;F4@=&%G('=H97)E(&5A8V@@871T<FEB=71E(&=E=',@=W)I='1E;B!T;R!A
M('-I;F=L92!L:6YE#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D:6YD96YT
M("`@("`@("`@("`@<W1R:6YG('5S960@=&\@:6YD96YT(&%T=')I8G5T97,@
M*%]A=71O(&EN9&5N=',@871T<FEB=71E<R!S;R!T:&5Y('-T87)T(&%T('1H
M92!S86UE(&-O;'5M;BD-"B`@("`J($!P87)A;2`@("!S=')I;F<@("1L:6YE
M8G)E86L@("`@("`@("!S=')I;F<@=7-E9"!F;W(@;&EN96)R96%K<PT*("`@
M("H@0')E='5R;B`@('-T<FEN9R`@)'-T<FEN9R`@("`@("`@("`@(%A-3"!S
M=&%R="!E;&5M96YT#0H@("`@*B!`<V5E("`@("`@4$5!4E]086-K86=E1FEL
M95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ.F-R96%T945N9$5L96UE;G0H*2P@
M4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ.F-R96%T
M951A9R@I#0H@("`@*B\-"B`@("!F=6YC=&EO;B!C<F5A=&53=&%R=$5L96UE
M;G0H)'%N86UE+"`D871T<FEB=71E<R`](&%R<F%Y*"DL("1N86UE<W!A8V55
M<FD@/2!N=6QL+"`D;75L=&EL:6YE(#T@9F%L<V4L("1I;F1E;G0@/2`G7V%U
M=&\G+"`D;&EN96)R96%K(#T@(EQN(BD-"B`@("![#0H@("`@("`@("\O(&EF
M(&YO(&%T=')I8G5T97,@:&%V(&)E96X@<V5T+"!U<V4@96UP='D@871T<FEB
M=71E<PT*("`@("`@("!I9B`H(6ES<V5T*"1A='1R:6)U=&5S*2!\?"`A:7-?
M87)R87DH)&%T=')I8G5T97,I*2![#0H@("`@("`@("`@("`D871T<FEB=71E
M<R`](&%R<F%Y*"D[#0H@("`@("`@('T-"B`@("`@("`@#0H@("`@("`@(&EF
M("@D;F%M97-P86-E57)I("$](&YU;&PI('L-"B`@("`@("`@("`@("1P87)T
M<R`](%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL.CIS
M<&QI=%%U86QI9FEE9$YA;64H)'%N86UE*3L-"B`@("`@("`@?0T*#0H@("`@
M("`@("\O(&-H96-K(&9O<B!M=6QT:6QI;F4@871T<FEB=71E<PT*("`@("`@
M("!I9B`H)&UU;'1I;&EN92`]/3T@=')U92D@>PT*("`@("`@("`@("`@:68@
M*"1I;F1E;G0@/3T](")?875T;R(I('L-"B`@("`@("`@("`@("`@("`D:6YD
M96YT(#T@<W1R7W)E<&5A="@B("(L("AS=')L96XH)'%N86UE*2LR*2D[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"@T*("`@("`@("!I9B`H)&YA;65S
M<&%C955R:2`A/2!N=6QL*2![#0H@("`@("`@("`@("`O+R!I<R!A(&YA;65S
M<&%C92!G:79E;@T*("`@("`@("`@("`@:68@*&ES<V5T*"1P87)T<ULB;F%M
M97-P86-E(ETI("8F("%E;7!T>2@D<&%R='-;(FYA;65S<&%C92)=*2D@>PT*
M("`@("`@("`@("`@("`@("1A='1R:6)U=&5S6R)X;6QN<SHB+B1P87)T<ULB
M;F%M97-P86-E(EU=(#T@)&YA;65S<&%C955R:3L-"B`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@+R\@9&5F:6YE('1H:7,@57)I(&%S
M('1H92!D969A=6QT(&YA;65S<&%C90T*("`@("`@("`@("`@("`@("1A='1R
M:6)U=&5S6R)X;6QN<R)=(#T@)&YA;65S<&%C955R:3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*#0H@("`@("`@("\O(&-R96%T92!A='1R:6)U=&4@
M;&ES=`T*("`@("`@("`D871T3&ES="`@("`]("`@4$5!4E]086-K86=E1FEL
M95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ.F%T=')I8G5T97-4;U-T<FEN9R@D
M871T<FEB=71E<RP@=')U92P@)&UU;'1I;&EN92P@)&EN9&5N="P@)&QI;F5B
M<F5A:RD[#0H@("`@("`@("1E;&5M96YT("`@(#T@("!S<')I;G1F*"(\)7,E
M<SXB+"`D<6YA;64L("1A='1,:7-T*3L-"B`@("`@("`@<F5T=7)N("`D96QE
M;65N=#L-"B`@("!]#0H-"B`@("\J*@T*("`@("H@8W)E871E(&%N(&5N9"!E
M;&5M96YT#0H@("`@*@T*("`@("H@/&-O9&4^#0H@("`@*B!R97%U:7)E7V]N
M8V4@)UA-3"]5=&EL+G!H<"<[#0H@("`@*B`-"B`@("`J("\O(&-R96%T92!A
M;B!834P@<W1A<G0@96QE;65N=#H-"B`@("`J("1T86<@/2!014%27U!A8VMA
M9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;#HZ8W)E871E16YD16QE;65N
M="@B;7E.<SIM>51A9R(I.PT*("`@("H@/"]C;V1E/@T*("`@("H-"B`@("`J
M($!A8V-E<W,@("!P=6)L:6,-"B`@("`J($!S=&%T:6,-"B`@("`J($!P87)A
M;2`@("!S=')I;F<@("1Q;F%M92`@("`@("`@("`@("!Q=6%L:69I960@=&%G
M;F%M92`H:6YC;'5D:6YG(&YA;65S<&%C92D-"B`@("`J($!R971U<FX@("!S
M=')I;F<@("1S=')I;F<@("`@("`@("`@("!834P@96YD(&5L96UE;G0-"B`@
M("`J($!S964@("`@("!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]8
M34Q?571I;#HZ8W)E871E4W1A<G1%;&5M96YT*"DL(%!%05)?4&%C:V%G949I
M;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL.CIC<F5A=&5486<H*0T*("`@("HO
M#0H@("`@9G5N8W1I;VX@8W)E871E16YD16QE;65N="@D<6YA;64I#0H@("`@
M>PT*("`@("`@("`D96QE;65N="`@("`]("`@<W!R:6YT9B@B/"\E<SXB+"`D
M<6YA;64I.PT*("`@("`@("!R971U<FX@("1E;&5M96YT.PT*("`@('T-"B`@
M("`-"B`@("\J*@T*("`@("H@8W)E871E(&%N(%A-3"!C;VUM96YT#0H@("`@
M*@T*("`@("H@/&-O9&4^#0H@("`@*B!R97%U:7)E7V]N8V4@)UA-3"]5=&EL
M+G!H<"<[#0H@("`@*B`-"B`@("`J("\O(&-R96%T92!A;B!834P@<W1A<G0@
M96QE;65N=#H-"B`@("`J("1T86<@/2!014%27U!A8VMA9V5&:6QE7T=E;F5R
M871O<E]V,E]834Q?571I;#HZ8W)E871E0V]M;65N="@B22!A;2!A(&-O;6UE
M;G0B*3L-"B`@("`J(#PO8V]D93X-"B`@("`J#0H@("`@*B!`86-C97-S("`@
M<'5B;&EC#0H@("`@*B!`<W1A=&EC#0H@("`@*B!`<&%R86T@("`@<W1R:6YG
M("`D8V]N=&5N="`@("`@("`@("`@8V]N=&5N="!O9B!T:&4@8V]M;65N=`T*
M("`@("H@0')E='5R;B`@('-T<FEN9R`@)&-O;6UE;G0@("`@("`@("`@(%A-
M3"!C;VUM96YT#0H@("`@*B\-"B`@("!F=6YC=&EO;B!C<F5A=&5#;VUM96YT
M*"1C;VYT96YT*0T*("`@('L-"B`@("`@("`@)&-O;6UE;G0@("`@/2`@('-P
M<FEN=&8H(CPA+2T@)7,@+2T^(BP@)&-O;G1E;G0I.PT*("`@("`@("!R971U
M<FX@("1C;VUM96YT.PT*("`@('T-"B`@("`-"B`@("\J*@T*("`@("H@8W)E
M871E(&$@0T1A=&$@<V5C=&EO;@T*("`@("H-"B`@("`J(#QC;V1E/@T*("`@
M("H@<F5Q=6ER95]O;F-E("=834PO571I;"YP:'`G.PT*("`@("H@#0H@("`@
M*B`O+R!C<F5A=&4@82!#1&%T82!S96-T:6]N#0H@("`@*B`D=&%G(#T@4$5!
M4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ.F-R96%T94-$
M871A4V5C=&EO;B@B22!A;2!C;VYT96YT+B(I.PT*("`@("H@/"]C;V1E/@T*
M("`@("H-"B`@("`J($!A8V-E<W,@("!P=6)L:6,-"B`@("`J($!S=&%T:6,-
M"B`@("`J($!P87)A;2`@("!S=')I;F<@("1D871A("`@("`@("`@("`@("!D
M871A(&]F('1H92!#1&%T82!S96-T:6]N#0H@("`@*B!`<F5T=7)N("`@<W1R
M:6YG("`D<W1R:6YG("`@("`@("`@("`@0T1A=&$@<V5C=&EO;B!W:71H(&-O
M;G1E;G0-"B`@("`J+PT*("`@(&9U;F-T:6]N(&-R96%T94-$871A4V5C=&EO
M;B@D9&%T82D-"B`@("![#0H@("`@("`@(')E='5R;B`@<W!R:6YT9B@B/"%;
M0T1!5$%;)7-=73XB+"`D9&%T82D[#0H@("`@?0T*#0H@("`O*BH-"B`@("`J
M('-P;&ET('%U86QI9FEE9"!N86UE(&%N9"!R971U<FX@;F%M97-P86-E(&%N
M9"!L;V-A;"!P87)T#0H@("`@*@T*("`@("H@/&-O9&4^#0H@("`@*B!R97%U
M:7)E7V]N8V4@)UA-3"]5=&EL+G!H<"<[#0H@("`@*B`-"B`@("`J("\O('-P
M;&ET('%U86QI9FEE9"!T86<-"B`@("`J("1P87)T<R`](%!%05)?4&%C:V%G
M949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL.CIS<&QI=%%U86QI9FEE9$YA
M;64H(GAS;'0Z<W1Y;&5S:&5E="(I.PT*("`@("H@/"]C;V1E/@T*("`@("H@
M=&AE(')E='5R;F5D(&%R<F%Y('=I;&P@8V]N=&%I;B!T=V\@96QE;65N=',Z
M#0H@("`@*B`\<')E/@T*("`@("H@87)R87DH#0H@("`@*B`@("`@("`B;F%M
M97-P86-E(B`]/B`B>'-L="(L#0H@("`@*B`@("`@("`B;&]C86Q087)T(B`]
M/B`B<W1Y;&5S:&5E="(-"B`@("`J("`@("`@*3L-"B`@("`J(#PO<')E/@T*
M("`@("H-"B`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@*B!`<W1A=&EC#0H@
M("`@*B!`<&%R86T@('-T<FEN9R`@("`D<6YA;64@("`@("!Q=6%L:69I960@
M=&%G(&YA;64-"B`@("`J($!P87)A;2`@<W1R:6YG("`@("1D969A=6QT3G,@
M(&1E9F%U;'0@;F%M97-P86-E("AO<'1I;VYA;"D-"B`@("`J($!R971U<FX@
M87)R87D@("`@("1P87)T<R`@("`@(&%R<F%Y(&-O;G1A:6YI;F<@;F%M97-P
M86-E(&%N9"!L;V-A;"!P87)T#0H@("`@*B\-"B`@("!F=6YC=&EO;B!S<&QI
M=%%U86QI9FEE9$YA;64H)'%N86UE+"`D9&5F875L=$YS(#T@;G5L;"D-"B`@
M("![#0H@("`@("`@(&EF("AS=')S='(H)'%N86UE+"`G.B<I*2![#0H@("`@
M("`@("`@("`D=&UP(#T@97AP;&]D92@B.B(L("1Q;F%M92D[#0H@("`@("`@
M("`@("!R971U<FX@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M(")N86UE<W!A8V4B(#T^("1T;7!;,%TL#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@(")L;V-A;%!A<G0B(#T^("1T;7!;,5T-"B`@("`@("`@("`@("`@
M("`@("`@("`@("D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&%R<F%Y
M*`T*("`@("`@("`@("`@("`@("`@("`@(")N86UE<W!A8V4B(#T^("1D969A
M=6QT3G,L#0H@("`@("`@("`@("`@("`@("`@("`@(FQO8V%L4&%R="(@/3X@
M)'%N86UE#0H@("`@("`@("`@("`@("`@("`@("D[#0H@("`@?0T*#0H@("`O
M*BH-"B`@("`J(&-H96-K+"!W:&5T:&5R('-T<FEN9R!I<R!V86QI9"!834P@
M;F%M90T*("`@("H-"B`@("`J(#QP/EA-3"!N86UE<R!A<F4@=7-E9"!F;W(@
M=&%G;F%M92P@871T<FEB=71E(&YA;65S(&%N9"!V87)I;W5S#0H@("`@*B!O
M=&AE<BP@;&5S<V5R(&MN;W=N(&5N=&ET:65S+CPO<#X-"B`@("`J(#QP/D%N
M(%A-3"!N86UE(&UA>2!O;FQY(&-O;G-I<W0@;V8@86QP:&%N=6UE<FEC(&-H
M87)A8W1E<G,L#0H@("`@*B!D87-H97,L('5N9&5S8V]R97,@86YD('!E<FEO
M9',L(&%N9"!H87,@=&\@<W1A<G0@=VET:"!A(&QE='1E<@T*("`@("H@;W(@
M86X@=6YD97)S8V]R92X-"B`@("`J(#PO<#X-"B`@("`J#0H@("`@*B`\8V]D
M93X-"B`@("`J(')E<75I<F5?;VYC92`G6$U,+U5T:6PN<&AP)SL-"B`@("`J
M(`T*("`@("H@+R\@=F5R:69Y('1A9R!N86UE#0H@("`@*B`D<F5S=6QT(#T@
M4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ.FES5F%L
M:61.86UE*")I;G9A;&ED5&%G/R(I.PT*("`@("H@:68@*%!%05)?4&%C:V%G
M949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL.CII<T5R<F]R*"1R97-U;'0I
M*2![#0H@("`@*B`@("!P<FEN="`B26YV86QI9"!834P@;F%M93H@(B`N("1R
M97-U;'0M/F=E=$UE<W-A9V4H*3L-"B`@("`J('T-"B`@("`J(#PO8V]D93X-
M"B`@("`J#0H@("`@*B!`86-C97-S("!P=6)L:6,-"B`@("`J($!S=&%T:6,-
M"B`@("`J($!P87)A;2`@('-T<FEN9R`@)'-T<FEN9R!S=')I;F<@=&AA="!S
M:&]U;&0@8F4@8VAE8VME9`T*("`@("H@0')E='5R;B`@;6EX960@("`D=F%L
M:60@('1R=64L(&EF('-T<FEN9R!I<R!A('9A;&ED(%A-3"!N86UE+"!014%2
M(&5R<F]R(&]T:&5R=VES90T*("`@("H@0'1O9&\@("`@<W5P<&]R="!F;W(@
M;W1H97(@8VAA<G-E=',-"B`@("`J+PT*("`@(&9U;F-T:6]N(&ES5F%L:61.
M86UE*"1S=')I;F<I#0H@("`@>PT*("`@("`@("`O+R!C:&5C:R!F;W(@:6YV
M86QI9"!C:&%R<PT*("`@("`@("!I9B`H(7!R96=?;6%T8V@H(B]>6ULZ86QN
M=6TZ75]<+2Y=)"\B+"`D<W1R:6YG>S!]*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL.CIR
M86ES945R<F]R*"`B6$U,(&YA;65S(&UA>2!O;FQY('-T87)T('=I=&@@;&5T
M=&5R(&]R('5N9&5R<V-O<F4B+"!014%27U!A8VMA9V5&:6QE7T=E;F5R871O
M<E]V,E]834Q?571I;%]%4E)/4E])3E9!3$E$7U-405)4("D[#0H@("`@("`@
M('T-"B`@("`@("`@#0H@("`@("`@("\O(&-H96-K(&9O<B!I;G9A;&ED(&-H
M87)S#0H@("`@("`@(&EF("@A<')E9U]M871C:"@B+UXH6V$M>D$M6E]=*%MA
M+7I!+5HP+3E?7"U<+ETJ*3\Z*3];82UZ02U:7UTH6V$M>D$M6C`M.5]<+5PN
M72LI/R0O(BP@)'-T<FEN9RDI('L-"B`@("`@("`@("`@(')E='5R;B!014%2
M7U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;#HZ<F%I<V5%<G)O
M<B@@(EA-3"!N86UE<R!M87D@;VYL>2!C;VYT86EN(&%L<&AA;G5M97)I8R!C
M:&%R<RP@<&5R:6]D+"!H>7!H96XL(&-O;&]N(&%N9"!U;F1E<G-C;W)E<R(L
M(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL7T524D]2
M7TE.5D%,241?0TA!4E,@*3L-"B`@("`@("`@('T-"B`@("`@("`@+R\@6$U,
M(&YA;64@:7,@=F%L:60-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*
M#0H@("`O*BH-"B`@("`J(')E<&QA8V5M96YT(&9O<B!014%27U!A8VMA9V5&
M:6QE7T=E;F5R871O<E]V,E]834Q?571I;#HZ<F%I<V5%<G)O<@T*("`@("H-
M"B`@("`J($%V;VED<R!T:&4@;F5C97-S:71Y('1O(&%L=V%Y<R!R97%U:7)E
M#0H@("`@*B!014%2+G!H<`T*("`@("H-"B`@("`J($!A8V-E<W,@("!P=6)L
M:6,-"B`@("`J($!P87)A;2`@("!S=')I;F<@("`@("!E<G)O<B!M97-S86=E
M#0H@("`@*B!`<&%R86T@("`@:6YT96=E<B`@("`@97)R;W(@8V]D90T*("`@
M("H@0')E='5R;B`@(&]B:F5C="!014%27T5R<F]R#0H@("`@*B\-"B`@("!F
M=6YC=&EO;B!R86ES945R<F]R*"1M<V<L("1C;V1E*0T*("`@('L-"B`@("`@
M("`@<F5Q=6ER95]O;F-E("=014%2+G!H<"<[#0H@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"1M<V<L("1C;V1E*3L-"B`@("!]#0I]#0H_/G5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]086-K86=E1FEL92]'
M96YE<F%T;W(O=C$N<&AP````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#$T-3$S,"`Q
M,#4Q-30S,S<S,B`P,C0S-#``(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`-"B\J*@T*("H@<&%C:V%G92YX;6P@9V5N
M97)A=&EO;B!C;&%S<RP@<&%C:V%G92YX;6P@=F5R<VEO;B`Q+C`-"B`J#0H@
M*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@
M<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@
M4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE
M('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@
M;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD
M(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE
M87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@
M8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T
M96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R
M("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I
M9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N
M<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@=C$N<&AP+'8@,2XW
M,"`R,#`V+S`Q+S`V(#`T.C0W.C,W(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@
M("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S
M:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A
M,0T*("HO#0HO*BH-"B`J(&YE961E9"!F;W(@4$5!4E]604Q)1$%415\J(&-O
M;G-T86YT<PT*("HO#0IR97%U:7)E7V]N8V4@)U!%05(O5F%L:61A=&4N<&AP
M)SL-"G)E<75I<F5?;VYC92`G4WES=&5M+G!H<"<[#0IR97%U:7)E7V]N8V4@
M)U!%05(O4&%C:V%G949I;&4O=C(N<&AP)SL-"B\J*@T*("H@5&AI<R!C;&%S
M<R!C;VYV97)T<R!A(%!%05)?4&%C:V%G949I;&5?=C$@;V)J96-T(&EN=&\@
M86YY(&]U='!U="!F;W)M870N#0H@*@T*("H@4W5P<&]R=&5D(&]U='!U="!F
M;W)M871S(&EN8VQU9&4@87)R87DL(%A-3"!S=')I;F<L(&%N9"!A(%!%05)?
M4&%C:V%G949I;&5?=C(-"B`J(&]B:F5C="P@9F]R(&-O;G9E<G1I;F<@<&%C
M:V%G92YX;6P@,2XP(&EN=&\@<&%C:V%G92YX;6P@,BXP('=I=&@@;F\@<W=E
M870N#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2
M#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^
M#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@
M0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q
M+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K
M86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC
M92!296QE87-E(#$N-"XP83$-"B`J+PT*8VQA<W,@4$5!4E]086-K86=E1FEL
M95]'96YE<F%T;W)?=C$-"GL-"B`@("`O*BH-"B`@("`@*B!`=F%R(%!%05)?
M4&%C:V%G949I;&5?=C$-"B`@("`@*B\-"B`@("!V87(@)%]P86-K86=E9FEL
M93L-"B`@("!F=6YC=&EO;B!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V
M,2@F)'!A8VMA9V5F:6QE*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]P86-K
M86=E9FEL92`]("8D<&%C:V%G969I;&4[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@9V5T4&%C:V%G97)697)S:6]N*"D-"B`@("![#0H@("`@("`@(')E='5R
M;B`G,2XT+CDG.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!0
M14%27U!A8VMA9V5R#0H@("`@("H@0'!A<F%M(&)O;VP@:68@=')U92P@82`N
M=&=Z(&ES('=R:71T96XL(&]T:&5R=VES92!A("YT87(@:7,@=W)I='1E;@T*
M("`@("`J($!P87)A;2!S=')I;F=\;G5L;"!D:7)E8W1O<GD@:6X@=VAI8V@@
M=&\@<V%V92!T:&4@+G1G>@T*("`@("`J($!R971U<FX@<W1R:6YG?%!%05)?
M17)R;W(@;&]C871I;VX@;V8@<&%C:V%G92!O<B!E<G)O<B!O8FIE8W0-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!T;U1G>B@F)'!A8VMA9V5R+"`D8V]M<')E
M<W,@/2!T<G5E+"`D=VAE<F4@/2!N=6QL*0T*("`@('L-"B`@("`@("`@<F5Q
M=6ER95]O;F-E("=!<F-H:79E+U1A<BYP:'`G.PT*("`@("`@("!I9B`H)'=H
M97)E(#T]/2!N=6QL*2![#0H@("`@("`@("`@("!I9B`H(2@D=VAE<F4@/2!3
M>7-T96TZ.FUK=&5M<"AA<G)A>2@G+60G*2DI*2![#0H@("`@("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U!%05)?4&%C:V%G969I;&5?
M=C$Z.G1O5&=Z.B!M:W1E;7`@9F%I;&5D)RD[#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T@96QS96EF("@A0%-Y<W1E;3HZ;6M$:7(H87)R87DH)RUP)RP@
M)'=H97)E*2DI('L-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*"=014%27U!A8VMA9V5F:6QE7W8Q.CIT;U1G>CH@(B<@+B`D=VAE<F4@
M+B`G(B!C;W5L9"<@+@T*("`@("`@("`@("`@("`@("<@;F]T(&)E(&-R96%T
M960G*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H9FEL95]E>&ES=',H)'=H
M97)E("X@1$E214-43U)97U-%4$%2051/4B`N("=P86-K86=E+GAM;"<I("8F
M#0H@("`@("`@("`@("`@("%I<U]F:6QE*"1W:&5R92`N($1)4D5#5$]265]3
M15!!4D%43U(@+B`G<&%C:V%G92YX;6PG*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H)U!%05)?4&%C:V%G969I;&5?=C$Z.G1O
M5&=Z.B!U;F%B;&4@=&\@<V%V92!P86-K86=E+GAM;"!A<R<@+@T*("`@("`@
M("`@("`@("`@("<@(B<@+B`D=VAE<F4@+B!$25)%0U1/4EE?4T5005)!5$]2
M("X@)W!A8VMA9V4N>&UL(B<I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A
M)'1H:7,M/E]P86-K86=E9FEL92T^=F%L:61A=&4H4$5!4E]604Q)1$%415]0
M04-+04=)3D<I*2![#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@G4$5!4E]086-K86=E9FEL95]V,3HZ=&]49WHZ(&EN=F%L:60@<&%C
M:V%G92!F:6QE)RD[#0H@("`@("`@('T-"B`@("`@("`@)'!K9VEN9F\@/2`D
M=&AI<RT^7W!A8VMA9V5F:6QE+3YG971!<G)A>2@I.PT*("`@("`@("`D97AT
M(#T@)&-O;7!R97-S(#\@)RYT9WHG(#H@)RYT87(G.PT*("`@("`@("`D<&MG
M=F5R(#T@)'!K9VEN9F];)W!A8VMA9V4G72`N("<M)R`N("1P:V=I;F9O6R=V
M97)S:6]N)UT[#0H@("`@("`@("1D97-T7W!A8VMA9V4@/2!G971C=V0H*2`N
M($1)4D5#5$]265]315!!4D%43U(@+B`D<&MG=F5R("X@)&5X=#L-"B`@("`@
M("`@:68@*&9I;&5?97AI<W1S*&=E=&-W9"@I("X@1$E214-43U)97U-%4$%2
M051/4B`N("1P:V=V97(@+B`D97AT*2`F)@T*("`@("`@("`@("`@("`A:7-?
M9FEL92AG971C=V0H*2`N($1)4D5#5$]265]315!!4D%43U(@+B`D<&MG=F5R
M("X@)&5X="DI('L-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*"=014%27U!A8VMA9V5F:6QE7W8Q.CIT;U1G>CH@8V%N;F]T(&-R96%T
M92!T9WH@9FEL92`B)R`N#0H@("`@("`@("`@("`@("`@9V5T8W=D*"D@+B!$
M25)%0U1/4EE?4T5005)!5$]2("X@)'!K9W9E<B`N("1E>'0@+B`G(B<I.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("@D<&MG9FEL92`]("1T:&ES+3Y?<&%C
M:V%G969I;&4M/F=E=%!A8VMA9V5&:6QE*"DI('L-"B`@("`@("`@("`@("1P
M:V=D:7(@/2!D:7)N86UE*')E86QP871H*"1P:V=F:6QE*2D[#0H@("`@("`@
M("`@("`D<&MG9FEL92`](&)A<V5N86UE*"1P:V=F:6QE*3L-"B`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"=014%27U!A8VMA9V5F:6QE7W8Q.CIT;U1G>CH@<&%C:V%G92!F:6QE(&]B
M:F5C="!M=7-T("<@+@T*("`@("`@("`@("`@("`@("=B92!C<F5A=&5D(&9R
M;VT@82!R96%L(&9I;&4G*3L-"B`@("`@("`@?0T*("`@("`@("`O+R![>WL@
M0W)E871E('1H92!P86-K86=E(&9I;&4@;&ES=`T*("`@("`@("`D9FEL96QI
M<W0@/2!A<G)A>2@I.PT*("`@("`@("`D:2`](#`[#0H-"B`@("`@("`@9F]R
M96%C:"`H)'1H:7,M/E]P86-K86=E9FEL92T^9V5T1FEL96QI<W0H*2!A<R`D
M9FYA;64@/3X@)&%T=',I('L-"B`@("`@("`@("`@("1F:6QE(#T@)'!K9V1I
M<B`N($1)4D5#5$]265]315!!4D%43U(@+B`D9FYA;64[#0H@("`@("`@("`@
M("!I9B`H(69I;&5?97AI<W1S*"1F:6QE*2D@>PT*("`@("`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*")&:6QE(&1O97,@;F]T(&5X:7-T
M.B`D9FYA;64B*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@)&9I;&5L:7-T6R1I*RM=(#T@)&9I;&4[#0H@("`@("`@("`@("`@
M("`@:68@*"%I<W-E="@D871T<ULG;60U<W5M)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&%C:V%G969I;&4M/G-E=$9I;&5!='1R:6)U
M=&4H)&9N86UE+"`G;60U<W5M)RP@;60U7V9I;&4H)&9I;&4I*3L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'!A8VMA9V5R+3YL;V<H
M,BP@(D%D9&EN9R!F:6QE("1F;F%M92(I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@("\O('U]?0T*("`@("`@("`D<&%C:V%G97AM;"`]
M("1T:&ES+3YT;U!A8VMA9V5&:6QE*"1W:&5R92P@4$5!4E]604Q)1$%415]0
M04-+04=)3D<L("=P86-K86=E+GAM;"<L('1R=64I.PT*("`@("`@("!I9B`H
M)'!A8VMA9V5X;6PI('L-"B`@("`@("`@("`@("1T87(@/28@;F5W($%R8VAI
M=F5?5&%R*"1D97-T7W!A8VMA9V4L("1C;VUP<F5S<RD[#0H@("`@("`@("`@
M("`D=&%R+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L@
M+R\@6%A8($1O;B=T('!R:6YT(&5R<F]R<PT*("`@("`@("`@("`@+R\@+2TM
M+2T@0W)E871E<R!W:71H('1H92!P86-K86=E+GAM;"!F:6QE#0H@("`@("`@
M("`@("`D;VL@/2`D=&%R+3YC<F5A=&5-;V1I9GDH87)R87DH)'!A8VMA9V5X
M;6PI+"`G)RP@)'=H97)E*3L-"B`@("`@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1O:RDI('L-"B`@("`@("`@("`@("`@("!R971U<FX@)&]K.PT*("`@
M("`@("`@("`@?2!E;'-E:68@*"$D;VLI('L-"B`@("`@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4$5!4E]086-K86=E9FEL95]V,3HZ
M=&]49WHZ('1A<F)A;&P@8W)E871I;VX@9F%I;&5D)RD[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`O+R`M+2TM+2!!9&0@=&AE(&-O;G1E;G0@;V8@
M=&AE('!A8VMA9V4-"B`@("`@("`@("`@(&EF("@A)'1A<BT^861D36]D:69Y
M*"1F:6QE;&ES="P@)'!K9W9E<BP@)'!K9V1I<BDI('L-"B`@("`@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4$5!4E]086-K86=E9FEL
M95]V,3HZ=&]49WHZ('1A<F)A;&P@8W)E871I;VX@9F%I;&5D)RD[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@)&1E<W1?<&%C:V%G93L-
M"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S
M=')I;F=\;G5L;"!D:7)E8W1O<GD@=&\@<&QA8V4@=&AE('!A8VMA9V4N>&UL
M(&EN+"!O<B!N=6QL(&9O<B!A('1E;7!O<F%R>2!D:7(-"B`@("`@*B!`<&%R
M86T@:6YT(&]N92!O9B!T:&4@4$5!4E]604Q)1$%415\J(&-O;G-T86YT<PT*
M("`@("`J($!P87)A;2!S=')I;F<@;F%M92!O9B!T:&4@9V5N97)A=&5D(&9I
M;&4-"B`@("`@*B!`<&%R86T@8F]O;"!I9B!T<G5E+"!T:&5N(&YO(&%N86QY
M<VES('=I;&P@8F4@<&5R9F]R;65D(&]N(')O;&4](G!H<"(@9FEL97,-"B`@
M("`@*B!`<F5T=7)N('-T<FEN9WQ014%27T5R<F]R('!A=&@@=&\@=&AE(&-R
M96%T960@9FEL92!O;B!S=6-C97-S#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M=&]086-K86=E1FEL92@D=VAE<F4@/2!N=6QL+"`D<W1A=&4@/2!014%27U9!
M3$E$051%7TY/4DU!3"P@)&YA;64@/2`G<&%C:V%G92YX;6PG+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&YO9FEL96-H96-K:6YG(#T@9F%L<V4I
M#0H@("`@>PT*("`@("`@("!I9B`H(21T:&ES+3Y?<&%C:V%G969I;&4M/G9A
M;&ED871E*"1S=&%T92P@)&YO9FEL96-H96-K:6YG*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U!%05)?4&%C:V%G969I;&5?
M=C$Z.G1O4&%C:V%G949I;&4Z(&EN=F%L:60@<&%C:V%G92YX;6PG+`T*("`@
M("`@("`@("`@("`@(&YU;&PL(&YU;&PL(&YU;&PL("1T:&ES+3Y?<&%C:V%G
M969I;&4M/F=E=%9A;&ED871I;VY787)N:6YG<R@I*3L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H)'=H97)E(#T]/2!N=6QL*2![#0H@("`@("`@("`@("!I
M9B`H(2@D=VAE<F4@/2!3>7-T96TZ.FUK=&5M<"AA<G)A>2@G+60G*2DI*2![
M#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U!%
M05)?4&%C:V%G969I;&5?=C$Z.G1O4&%C:V%G949I;&4Z(&UK=&5M<"!F86EL
M960G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E:68@*"%`4WES
M=&5M.CIM:T1I<BAA<G)A>2@G+7`G+"`D=VAE<F4I*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U!%05)?4&%C:V%G969I;&5?
M=C$Z.G1O4&%C:V%G949I;&4Z("(G("X@)'=H97)E("X@)R(@8V]U;&0G("X-
M"B`@("`@("`@("`@("`@("`G(&YO="!B92!C<F5A=&5D)RD[#0H@("`@("`@
M('T-"B`@("`@("`@)&YE=W!K9V9I;&4@/2`D=VAE<F4@+B!$25)%0U1/4EE?
M4T5005)!5$]2("X@)&YA;64[#0H@("`@("`@("1N<"`]($!F;W!E;B@D;F5W
M<&MG9FEL92P@)W=B)RD[#0H@("`@("`@(&EF("@A)&YP*2![#0H@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4$5!4E]086-K86=E9FEL
M95]V,3HZ=&]086-K86=E1FEL93H@=6YA8FQE('1O('-A=F4@)R`N#0H@("`@
M("`@("`@("`@("`B)&YA;64@87,@)&YE=W!K9V9I;&4B*3L-"B`@("`@("`@
M?0T*("`@("`@("!F=W)I=&4H)&YP+"`D=&AI<RT^=&]8;6PH)'-T871E+"!T
M<G5E*2D[#0H@("`@("`@(&9C;&]S92@D;G`I.PT*("`@("`@("!R971U<FX@
M)&YE=W!K9V9I;&4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@9FEX(&)O
M=&@@6$U,(&5N8V]D:6YG('1O(&)E(%541C@L(&%N9"!R97!L86-E('-T86YD
M87)D(%A-3"!E;G1I=&EE<R`\(#X@(B`F("<-"B`@("`@*@T*("`@("`J($!P
M87)A;2!S=')I;F<@)'-T<FEN9PT*("`@("`J($!R971U<FX@<W1R:6YG#0H@
M("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M7V9I>%AM;$5N8V]D:6YG*"1S=')I;F<I#0H@("`@>PT*("`@("`@("!I9B`H
M=F5R<VEO;E]C;VUP87)E*'!H<'9E<G-I;VXH*2P@)S4N,"XP)RP@)VQT)RDI
M('L-"B`@("`@("`@("`@("1S=')I;F<@/2!U=&8X7V5N8V]D92@D<W1R:6YG
M*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@<W1R='(H)'-T<FEN9RP@
M87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G)B<@(#T^("<F86UP.R<L#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G/B<@(#T^("<F9W0[)RP-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<\)R`@/3X@)R9L
M=#LG+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)R(G("`]/B`G)G%U;W0[)RP-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=<)R<@/3X@)R9A<&]S.R<@*2D[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@4F5T=7)N(&%N(%A-3"!D;V-U;65N="!B
M87-E9"!O;B!T:&4@<&%C:V%G92!I;F9O("AA<R!R971U<FYE9`T*("`@("`J
M(&)Y('1H92!014%27T-O;6UO;CHZ:6YF;T9R;VTJ(&UE=&AO9',I+@T*("`@
M("`J#0H@("`@("H@0')E='5R;B!S=')I;F<@6$U,(&1A=&$-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!T;UAM;"@D<W1A=&4@/2!014%27U9!3$E$051%7TY/
M4DU!3"P@)&YO9FEL979A;&ED871I;VX@/2!F86QS92D-"B`@("![#0H@("`@
M("`@("1T:&ES+3Y?<&%C:V%G969I;&4M/G-E=$1A=&4H9&%T92@G62UM+60G
M*2D[#0H@("`@("`@(&EF("@A)'1H:7,M/E]P86-K86=E9FEL92T^=F%L:61A
M=&4H)'-T871E+"`D;F]F:6QE=F%L:61A=&EO;BDI('L-"B`@("`@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D<&MG:6YF;R`]
M("1T:&ES+3Y?<&%C:V%G969I;&4M/F=E=$%R<F%Y*"D[#0H@("`@("`@('-T
M871I8R`D;6%I;G1?;6%P(#T@87)R87DH#0H@("`@("`@("`@("`B:&%N9&QE
M(B`]/B`B=7-E<B(L#0H@("`@("`@("`@("`B;F%M92(@/3X@(FYA;64B+`T*
M("`@("`@("`@("`@(F5M86EL(B`]/B`B96UA:6PB+`T*("`@("`@("`@("`@
M(G)O;&4B(#T^(")R;VQE(BP-"B`@("`@("`@("`@("D[#0H@("`@("`@("1R
M970@/2`B/#]X;6P@=F5R<VEO;CU<(C$N,%PB(&5N8V]D:6YG/5PB551&+3A<
M(B`_/EQN(CL-"B`@("`@("`@)')E="`N/2`B/"%$3T-465!%('!A8VMA9V4@
M4UE35$5-(%PB:'1T<#HO+W!E87(N<&AP+FYE="]D=&0O<&%C:V%G92TQ+C!<
M(CY<;B([#0H@("`@("`@("1R970@+CT@(CQP86-K86=E('9E<G-I;VX]7"(Q
M+C!<(B!P86-K86=E<G9E<G-I;VX]7"(Q+C0N.5PB/EQN(B`N#0HB(#QN86UE
M/B1P:V=I;F9O6W!A8VMA9V5=/"]N86UE/B([#0H@("`@("`@(&EF("AI<W-E
M="@D<&MG:6YF;ULG97AT96YD<R==*2D@>PT*("`@("`@("`@("`@)')E="`N
M/2`B7&X\97AT96YD<SXD<&MG:6YF;UME>'1E;F1S73PO97AT96YD<SXB.PT*
M("`@("`@("!]#0H@("`@("`@("1R970@+CT-"B`B7&X@/'-U;6UA<GD^(BXD
M=&AI<RT^7V9I>%AM;$5N8V]D:6YG*"1P:V=I;F9O6R=S=6UM87)Y)UTI+B(\
M+W-U;6UA<GD^7&XB("X-"B(@/&1E<V-R:7!T:6]N/B(N=')I;2@D=&AI<RT^
M7V9I>%AM;$5N8V]D:6YG*"1P:V=I;F9O6R=D97-C<FEP=&EO;B==*2DN(EQN
M(#PO9&5S8W)I<'1I;VX^7&XB("X-"B(@/&UA:6YT86EN97)S/EQN(CL-"B`@
M("`@("`@9F]R96%C:"`H)'!K9VEN9F];)VUA:6YT86EN97)S)UT@87,@)&UA
M:6YT*2![#0H@("`@("`@("`@("`D<F5T("X]("(@(#QM86EN=&%I;F5R/EQN
M(CL-"B`@("`@("`@("`@(&9O<F5A8V@@*"1M86EN=%]M87`@87,@)&ED>"`]
M/B`D96QM*2![#0H@("`@("`@("`@("`@("`@)')E="`N/2`B("`@/"1E;&T^
M(CL-"B`@("`@("`@("`@("`@("`D<F5T("X]("1T:&ES+3Y?9FEX6&UL16YC
M;V1I;F<H)&UA:6YT6R1I9'A=*3L-"B`@("`@("`@("`@("`@("`D<F5T("X]
M("(\+R1E;&T^7&XB.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)')E
M="`N/2`B("`\+VUA:6YT86EN97(^7&XB.PT*("`@("`@("!]#0H@("`@("`@
M("1R970@+CT@(B`@/"]M86EN=&%I;F5R<SY<;B([#0H@("`@("`@("1R970@
M+CT@)'1H:7,M/E]M86ME4F5L96%S95AM;"@D<&MG:6YF;RP@9F%L<V4L("1S
M=&%T92D[#0H@("`@("`@(&EF("AI<W-E="@D<&MG:6YF;ULG8VAA;F=E;&]G
M)UTI("8F(&-O=6YT*"1P:V=I;F9O6R=C:&%N9V5L;V<G72D@/B`P*2![#0H@
M("`@("`@("`@("`D<F5T("X]("(@/&-H86YG96QO9SY<;B([#0H@("`@("`@
M("`@("!F;W)E86-H("@D<&MG:6YF;ULG8VAA;F=E;&]G)UT@87,@)&]L9')E
M;&5A<V4I('L-"B`@("`@("`@("`@("`@("`D<F5T("X]("1T:&ES+3Y?;6%K
M95)E;&5A<V58;6PH)&]L9')E;&5A<V4L('1R=64I.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@)')E="`N/2`B(#PO8VAA;F=E;&]G/EQN(CL-"B`@
M("`@("`@?0T*("`@("`@("`D<F5T("X]("(\+W!A8VMA9V4^7&XB.PT*("`@
M("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O
M+R![>WL@7VUA:V5296QE87-E6&UL*"D-"@T*("`@("\J*@T*("`@("`J($=E
M;F5R871E('!A<G0@;V8@86X@6$U,(&1E<V-R:7!T:6]N('=I=&@@<F5L96%S
M92!I;F9O<FUA=&EO;BX-"B`@("`@*@T*("`@("`J($!P87)A;2!A<G)A>2`@
M)'!K9VEN9F\@("`@87)R87D@=VET:"!R96QE87-E(&EN9F]R;6%T:6]N#0H@
M("`@("H@0'!A<F%M(&)O;VP@("`D8VAA;F=E;&]G("!W:&5T:&5R('1H92!R
M97-U;'0@=VEL;"!B92!I;B!A(&-H86YG96QO9R!E;&5M96YT#0H@("`@("H-
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R!834P@9&%T80T*("`@("`J#0H@("`@
M("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7VUA
M:V5296QE87-E6&UL*"1P:V=I;F9O+"`D8VAA;F=E;&]G(#T@9F%L<V4L("1S
M=&%T92`](%!%05)?5D%,241!5$5?3D]234%,*0T*("`@('L-"B`@("`@("`@
M+R\@6%A8(%%53U1%($5.5$E42453($E.(%!#1$%402P@3U(@14U"140@24X@
M0T1!5$$@0DQ/0TM3(2$-"B`@("`@("`@)&EN9&5N="`]("1C:&%N9V5L;V<@
M/R`B("`B(#H@(B([#0H@("`@("`@("1R970@/2`B)&EN9&5N="`\<F5L96%S
M93Y<;B([#0H@("`@("`@(&EF("@A96UP='DH)'!K9VEN9F];)W9E<G-I;VXG
M72DI('L-"B`@("`@("`@("`@("1R970@+CT@(B1I;F1E;G0@(#QV97)S:6]N
M/B1P:V=I;F9O6W9E<G-I;VY=/"]V97)S:6]N/EQN(CL-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H(65M<'1Y*"1P:V=I;F9O6R=R96QE87-E7V1A=&4G72DI
M('L-"B`@("`@("`@("`@("1R970@+CT@(B1I;F1E;G0@(#QD871E/B1P:V=I
M;F9O6W)E;&5A<V5?9&%T95T\+V1A=&4^7&XB.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("@A96UP='DH)'!K9VEN9F];)W)E;&5A<V5?;&EC96YS92==*2D@
M>PT*("`@("`@("`@("`@)')E="`N/2`B)&EN9&5N="`@/&QI8V5N<V4^)'!K
M9VEN9F];<F5L96%S95]L:6-E;G-E73PO;&EC96YS93Y<;B([#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"%E;7!T>2@D<&MG:6YF;ULG<F5L96%S95]S=&%T
M92==*2D@>PT*("`@("`@("`@("`@)')E="`N/2`B)&EN9&5N="`@/'-T871E
M/B1P:V=I;F9O6W)E;&5A<V5?<W1A=&5=/"]S=&%T93Y<;B([#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"%E;7!T>2@D<&MG:6YF;ULG<F5L96%S95]N;W1E
M<R==*2D@>PT*("`@("`@("`@("`@)')E="`N/2`B)&EN9&5N="`@/&YO=&5S
M/B(N=')I;2@D=&AI<RT^7V9I>%AM;$5N8V]D:6YG*"1P:V=I;F9O6R=R96QE
M87-E7VYO=&5S)UTI*0T*("`@("`@("`@("`@+B)<;B1I;F1E;G0@(#PO;F]T
M97,^7&XB.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A96UP='DH)'!K9VEN
M9F];)W)E;&5A<V5?=V%R;FEN9W,G72DI('L-"B`@("`@("`@("`@("1R970@
M+CT@(B1I;F1E;G0@(#QW87)N:6YG<SXB+B1T:&ES+3Y?9FEX6&UL16YC;V1I
M;F<H)'!K9VEN9F];)W)E;&5A<V5?=V%R;FEN9W,G72DN(CPO=V%R;FEN9W,^
M7&XB.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D<&MG:6YF;ULG
M<F5L96%S95]D97!S)UTI("8F('-I>F5O9B@D<&MG:6YF;ULG<F5L96%S95]D
M97!S)UTI(#X@,"D@>PT*("`@("`@("`@("`@)')E="`N/2`B)&EN9&5N="`@
M/&1E<',^7&XB.PT*("`@("`@("`@("`@9F]R96%C:"`H)'!K9VEN9F];)W)E
M;&5A<V5?9&5P<R==(&%S("1D97`I('L-"B`@("`@("`@("`@("`@("`D<F5T
M("X]("(D:6YD96YT("`@/&1E<"!T>7!E/5PB)&1E<%MT>7!E75PB(')E;#U<
M(B1D97!;<F5L75PB(CL-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E
M<%LG=F5R<VEO;B==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<F5T("X]
M("(@=F5R<VEO;CU<(B1D97!;=F5R<VEO;EU<(B([#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=O<'1I;VYA
M;"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<F5T("X]("(@;W!T:6]N
M86P]7"(D9&5P6V]P=&EO;F%L75PB(CL-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)VYA;64G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@)')E="`N/2`B/B1D97!;;F%M95T\+V1E<#Y<
M;B([#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@)')E="`N/2`B+SY<;B([#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@)')E="`N/2`B)&EN9&5N="`@/"]D
M97!S/EQN(CL-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)'!K9VEN
M9F];)V-O;F9I9W5R95]O<'1I;VYS)UTI*2![#0H@("`@("`@("`@("`D<F5T
M("X]("(D:6YD96YT("`\8V]N9FEG=7)E;W!T:6]N<SY<;B([#0H@("`@("`@
M("`@("!F;W)E86-H("@D<&MG:6YF;ULG8V]N9FEG=7)E7V]P=&EO;G,G72!A
M<R`D8RD@>PT*("`@("`@("`@("`@("`@("1R970@+CT@(B1I;F1E;G0@("`\
M8V]N9FEG=7)E;W!T:6]N(&YA;64]7"(B+@T*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V9I>%AM;$5N8V]D:6YG*"1C6R=N86UE)UTI("X@(EPB(CL-
M"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&-;)V1E9F%U;'0G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@)')E="`N/2`B(&1E9F%U;'0]7"(B("X@
M)'1H:7,M/E]F:7A8;6Q%;F-O9&EN9R@D8ULG9&5F875L="==*2`N(")<(B([
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1R970@+CT@
M(B!P<F]M<'0]7"(B("X@)'1H:7,M/E]F:7A8;6Q%;F-O9&EN9R@D8ULG<')O
M;7!T)UTI("X@(EPB(CL-"B`@("`@("`@("`@("`@("`D<F5T("X]("(O/EQN
M(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1R970@+CT@(B1I;F1E
M;G0@(#PO8V]N9FEG=7)E;W!T:6]N<SY<;B([#0H@("`@("`@('T-"B`@("`@
M("`@:68@*&ES<V5T*"1P:V=I;F9O6R=P<F]V:61E<R==*2D@>PT*("`@("`@
M("`@("`@9F]R96%C:"`H)'!K9VEN9F];)W!R;W9I9&5S)UT@87,@)&ME>2`]
M/B`D=VAA="D@>PT*("`@("`@("`@("`@("`@("1R970@+CT@(B1I;F1E;G0@
M(#QP<F]V:61E<R!T>7!E/5PB)'=H871;='EP95U<(B`B.PT*("`@("`@("`@
M("`@("`@("1R970@+CT@(FYA;64]7"(D=VAA=%MN86UE75PB("([#0H@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1W:&%T6R=E>'1E;F1S)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("1R970@+CT@(F5X=&5N9',]7"(D=VAA=%ME
M>'1E;F1S75PB("([#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("1R970@+CT@(B\^7&XB.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(&EF("AI<W-E="@D<&MG:6YF;ULG9FEL96QI<W0G72DI('L-
M"B`@("`@("`@("`@("1R970@+CT@(B1I;F1E;G0@(#QF:6QE;&ES=#Y<;B([
M#0H@("`@("`@("`@("!I9B`H)'-T871E(%X@4$5!4E]604Q)1$%415]004-+
M04=)3D<I('L-"B`@("`@("`@("`@("`@("`D<F5T("X]("1T:&ES+3YR96-U
M<G-I=F58;6Q&:6QE;&ES="@D<&MG:6YF;ULG9FEL96QI<W0G72D[#0H@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1P
M:V=I;F9O6R=F:6QE;&ES="==(&%S("1F:6QE(#T^("1F82D@>PT*("`@("`@
M("`@("`@("`@("`@("!`)')E="`N/2`B)&EN9&5N="`@(#QF:6QE(')O;&4]
M7"(D9F%;<F]L95U<(B([#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D9F%;)V)A<V5I;G-T86QL9&ER)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D<F5T("X]("<@8F%S96EN<W1A;&QD:7(](B<@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9FEX6&UL16YC;V1I;F<H
M)&9A6R=B87-E:6YS=&%L;&1I<B==*2`N("<B)SL-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&9A6R=M
M9#5S=6TG72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1R970@+CT@
M(B!M9#5S=6T]7"(D9F%;;60U<W5M75PB(CL-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&9A6R=P;&%T
M9F]R;2==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)')E="`N/2`B
M('!L871F;W)M/5PB)&9A6W!L871F;W)M75PB(CL-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1F85LG
M:6YS=&%L;"UA<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)')E
M="`N/2`G(&EN<W1A;&PM87,](B<@+@T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?9FEX6&UL16YC;V1I;F<H)&9A6R=I;G-T86QL+6%S
M)UTI("X@)R(G.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("1R970@+CT@)R!N86UE/2(G("X@)'1H:7,M/E]F:7A8;6Q%
M;F-O9&EN9R@D9FEL92D@+B`G(B<[#0H@("`@("`@("`@("`@("`@("`@(&EF
M("AE;7!T>2@D9F%;)W)E<&QA8V5M96YT<R==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)')E="`N/2`B+SY<;B([#0H@("`@("`@("`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`D<F5T("X]
M("(^7&XB.PT*("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&9A
M6R=R97!L86-E;65N=',G72!A<R`D<BD@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1R970@+CT@(B1I;F1E;G0@("`@/')E<&QA8V4B.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1R(&%S("1K(#T^
M("1V*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R970@
M+CT@(B`D:SU<(B(@+B`D=&AI<RT^7V9I>%AM;$5N8V]D:6YG*"1V*2`N)R(G
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<F5T("X]("(O/EQN(CL-"B`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@($`D<F5T
M("X]("(D:6YD96YT("`@/"]F:6QE/EQN(CL-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("1R970@+CT@(B1I;F1E;G0@(#PO9FEL96QI<W0^7&XB.PT*("`@
M("`@("!]#0H@("`@("`@("1R970@+CT@(B1I;F1E;G0@/"]R96QE87-E/EQN
M(CL-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@+RHJ#0H@
M("`@("H@0'!A<F%M(&%R<F%Y#0H@("`@("H@0&%C8V5S<R!P<F]T96-T960-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!R96-U<G-I=F58;6Q&:6QE;&ES="@D
M;&ES="D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?9&ER<R`](&%R<F%Y*"D[
M#0H@("`@("`@(&9O<F5A8V@@*"1L:7-T(&%S("1F:6QE(#T^("1A='1R:6)U
M=&5S*2![#0H@("`@("`@("`@("`D=&AI<RT^7V%D9$1I<B@D=&AI<RT^7V1I
M<G,L(&5X<&QO9&4H)R\G+"!D:7)N86UE*"1F:6QE*2DL("1F:6QE+"`D871T
M<FEB=71E<RD[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M9F]R;6%T1&ER*"1T:&ES+3Y?9&ER<RD[#0H@("`@?0T*#0H@("`@+RHJ#0H@
M("`@("H@0'!A<F%M(&%R<F%Y#0H@("`@("H@0'!A<F%M(&%R<F%Y#0H@("`@
M("H@0'!A<F%M('-T<FEN9WQN=6QL#0H@("`@("H@0'!A<F%M(&%R<F%Y?&YU
M;&P-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!?861D1&ER*"8D9&ER<RP@)&1I<BP@)&9I;&4@/2!N=6QL+"`D871T
M<FEB=71E<R`](&YU;&PI#0H@("`@>PT*("`@("`@("!I9B`H)&1I<B`]/2!A
M<G)A>2@I('Q\("1D:7(@/3T@87)R87DH)RXG*2D@>PT*("`@("`@("`@("`@
M)&1I<G-;)V9I;&5S)UU;8F%S96YA;64H)&9I;&4I72`]("1A='1R:6)U=&5S
M.PT*("`@("`@("`@("`@<F5T=7)N.PT*("`@("`@("!]#0H@("`@("`@("1C
M=7)D:7(@/2!A<G)A>5]S:&EF="@D9&ER*3L-"B`@("`@("`@:68@*"%I<W-E
M="@D9&ER<ULG9&ER<R==6R1C=7)D:7)=*2D@>PT*("`@("`@("`@("`@)&1I
M<G-;)V1I<G,G75LD8W5R9&ER72`](&%R<F%Y*"D[#0H@("`@("`@('T-"B`@
M("`@("`@)'1H:7,M/E]A9&1$:7(H)&1I<G-;)V1I<G,G75LD8W5R9&ER72P@
M)&1I<BP@)&9I;&4L("1A='1R:6)U=&5S*3L-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`@*B!`<&%R86T@87)R87D-"B`@("`@*B!`<&%R86T@<W1R:6YG#0H@
M("`@("H@0'!A<F%M('-T<FEN9PT*("`@("`J($!A8V-E<W,@<')I=F%T90T*
M("`@("`J+PT*("`@(&9U;F-T:6]N(%]F;W)M871$:7(H)&1I<G,L("1I;F1E
M;G0@/2`G)RP@)&-U<F1I<B`]("<G*0T*("`@('L-"B`@("`@("`@)')E="`]
M("<G.PT*("`@("`@("!I9B`H(6-O=6YT*"1D:7)S*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N("<G.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D
M9&ER<ULG9&ER<R==*2D@>PT*("`@("`@("`@("`@=6MS;W)T*"1D:7)S6R=D
M:7)S)UTL("=S=')N871C87-E8VUP)RD[#0H@("`@("`@("`@("!F;W)E86-H
M("@D9&ER<ULG9&ER<R==(&%S("1D:7(@/3X@)&-O;G1E;G1S*2![#0H@("`@
M("`@("`@("`@("`@)'5S961I<B`]("(D8W5R9&ER+R1D:7(B.PT*("`@("`@
M("`@("`@("`@("1R970@+CT@(B1I;F1E;G0@("`\9&ER(&YA;64]7"(D9&ER
M7"(^7&XB.PT*("`@("`@("`@("`@("`@("1R970@+CT@)'1H:7,M/E]F;W)M
M871$:7(H)&-O;G1E;G1S+"`B)&EN9&5N="`B+"`D=7-E9&ER*3L-"B`@("`@
M("`@("`@("`@("`D<F5T("X]("(D:6YD96YT("`@/"]D:7(^(#PA+2T@)'5S
M961I<B`M+3Y<;B([#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@:68@*&ES<V5T*"1D:7)S6R=F:6QE<R==*2D@>PT*("`@("`@("`@("`@
M=6MS;W)T*"1D:7)S6R=F:6QE<R==+"`G<W1R;F%T8V%S96-M<"<I.PT*("`@
M("`@("`@("`@9F]R96%C:"`H)&1I<G-;)V9I;&5S)UT@87,@)&9I;&4@/3X@
M)&%T=')I8G,I('L-"B`@("`@("`@("`@("`@("`D<F5T("X]("1T:&ES+3Y?
M9F]R;6%T1FEL92@D9FEL92P@)&%T=')I8G,L("1I;F1E;G0I.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@
M('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@*B!`
M<&%R86T@87)R87D-"B`@("`@*B!`<&%R86T@<W1R:6YG#0H@("`@("H@0&%C
M8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7V9O<FUA=$9I
M;&4H)&9I;&4L("1A='1R:6)U=&5S+"`D:6YD96YT*0T*("`@('L-"B`@("`@
M("`@)')E="`]("(D:6YD96YT("`@/&9I;&4@<F]L93U<(B1A='1R:6)U=&5S
M6W)O;&5=7"(B.PT*("`@("`@("!I9B`H:7-S970H)&%T=')I8G5T97-;)V)A
M<V5I;G-T86QL9&ER)UTI*2![#0H@("`@("`@("`@("`D<F5T("X]("<@8F%S
M96EN<W1A;&QD:7(](B<@+@T*("`@("`@("`@("`@("`@("1T:&ES+3Y?9FEX
M6&UL16YC;V1I;F<H)&%T=')I8G5T97-;)V)A<V5I;G-T86QL9&ER)UTI("X@
M)R(G.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D871T<FEB=71E
M<ULG;60U<W5M)UTI*2![#0H@("`@("`@("`@("`D<F5T("X]("(@;60U<W5M
M/5PB)&%T=')I8G5T97-;;60U<W5M75PB(CL-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H:7-S970H)&%T=')I8G5T97-;)W!L871F;W)M)UTI*2![#0H@("`@
M("`@("`@("`D<F5T("X]("(@<&QA=&9O<FT]7"(D871T<FEB=71E<UMP;&%T
M9F]R;5U<(B([#0H@("`@("`@('T-"B`@("`@("`@:68@*"%E;7!T>2@D871T
M<FEB=71E<ULG:6YS=&%L;"UA<R==*2D@>PT*("`@("`@("`@("`@)')E="`N
M/2`G(&EN<W1A;&PM87,](B<@+@T*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M9FEX6&UL16YC;V1I;F<H)&%T=')I8G5T97-;)VEN<W1A;&PM87,G72D@+B`G
M(B<[#0H@("`@("`@('T-"B`@("`@("`@)')E="`N/2`G(&YA;64](B<@+B`D
M=&AI<RT^7V9I>%AM;$5N8V]D:6YG*"1F:6QE*2`N("<B)SL-"B`@("`@("`@
M:68@*&5M<'1Y*"1A='1R:6)U=&5S6R=R97!L86-E;65N=',G72DI('L-"B`@
M("`@("`@("`@("1R970@+CT@(B\^7&XB.PT*("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@)')E="`N/2`B/EQN(CL-"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1A='1R:6)U=&5S6R=R97!L86-E;65N=',G72!A<R`D<BD@>PT*("`@
M("`@("`@("`@("`@("1R970@+CT@(B1I;F1E;G0@("`@/')E<&QA8V4B.PT*
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1R(&%S("1K(#T^("1V*2![#0H@
M("`@("`@("`@("`@("`@("`@("1R970@+CT@(B`D:SU<(B(@+B`D=&AI<RT^
M7V9I>%AM;$5N8V]D:6YG*"1V*2`N)R(G.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`D<F5T("X]("(O/EQN(CL-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("1R970@+CT@(B1I;F1E;G0@("`\+V9I;&4^7&XB
M.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*
M("`@("\O('M[>R!?=6Y);F1E;G0H*0T*#0H@("`@+RHJ#0H@("`@("H@56YI
M;F1E;G0@9VEV96X@<W1R:6YG("@_*0T*("`@("`J#0H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<W1R(%1H92!S=')I;F<@=&AA="!H87,@=&\@8F4@=6YI;F1E
M;G1E9"X-"B`@("`@*B!`<F5T=7)N('-T<FEN9PT*("`@("`J($!A8V-E<W,@
M<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]U;DEN9&5N="@D<W1R
M*0T*("`@('L-"B`@("`@("`@+R\@<F5M;W9E(&QE861I;F<@;F5W;&EN97,-
M"B`@("`@("`@)'-T<B`]('!R96=?<F5P;&%C92@G+UY;7')<;ETK+R<L("<G
M+"`D<W1R*3L-"B`@("`@("`@+R\@9FEN9"!W:&ET97-P86-E(&%T('1H92!B
M96=I;FYI;F<@;V8@=&AE(&9I<G-T(&QI;F4-"B`@("`@("`@)&EN9&5N=%]L
M96X@/2!S=')S<&XH)'-T<BP@(B!<="(I.PT*("`@("`@("`D:6YD96YT(#T@
M<W5B<W1R*"1S='(L(#`L("1I;F1E;G1?;&5N*3L-"B`@("`@("`@)&1A=&$@
M/2`G)SL-"B`@("`@("`@+R\@<F5M;W9E('1H92!S86UE(&%M;W5N="!O9B!W
M:&ET97-P86-E(&9R;VT@9F]L;&]W:6YG(&QI;F5S#0H@("`@("`@(&9O<F5A
M8V@@*&5X<&QO9&4H(EQN(BP@)'-T<BD@87,@)&QI;F4I('L-"B`@("`@("`@
M("`@(&EF("AS=6)S='(H)&QI;F4L(#`L("1I;F1E;G1?;&5N*2`]/2`D:6YD
M96YT*2![#0H@("`@("`@("`@("`@("`@)&1A=&$@+CT@<W5B<W1R*"1L:6YE
M+"`D:6YD96YT7VQE;BD@+B`B7&XB.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B`D9&%T83L-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M9&5P96YD96YC:65S5&]6,B@I#0H@("`@>PT*("`@("`@("`D87)R(#T@87)R
M87DH*3L-"B`@("`@("`@)'1H:7,M/E]C;VYV97)T1&5P96YD96YC:65S,E\P
M*"1A<G(I.PT*("`@("`@("!R971U<FX@)&%R<ELG9&5P96YD96YC:65S)UT[
M#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0V]N=F5R="!A('!A8VMA9V4N
M>&UL('9E<G-I;VX@,2XP(&EN=&\@=F5R<VEO;B`R+C`-"B`@("`@*@T*("`@
M("`J($YO=&4@=&AA="!T:&ES(&1O97,@82!B87-I8R!C;VYV97)S:6]N+"!T
M;R!A;&QO=R!M;W)E(&%D=F%N8V5D#0H@("`@("H@9F5A='5R97,@;&EK92!B
M=6YD;&5S(&%N9"!M=6QT:7!L92!R96QE87-E<PT*("`@("`J($!P87)A;2!S
M=')I;F<@=&AE(&-L87-S;F%M92!T;R!I;G-T86YT:6%T92!A;F0@<F5T=7)N
M+B`@5&AI<R!M=7-T(&)E#0H@("`@("H@("`@("`@("`@("`@("!014%27U!A
M8VMA9V5&:6QE7W8R(&]R(&$@9&5S8V5N9&%N=`T*("`@("`J($!P87)A;2!B
M;V]L96%N(&EF('1R=64L(&]N;'D@=F%L:60L(&1E=&5R;6EN:7-T:6,@<&%C
M:V%G92YX;6P@,2XP(&%S(&1E9FEN960@8GD@=&AE#0H@("`@("H@("`@("`@
M("`@("`@("`@<W1R:6-T97-T('!A<F%M971E<G,@=VEL;"!B92!C;VYV97)T
M960-"B`@("`@*B!`<F5T=7)N(%!%05)?4&%C:V%G949I;&5?=C)\4$5!4E]%
M<G)O<@T*("`@("`J+PT*("`@(&9U;F-T:6]N("9T;U8R*"1C;&%S<R`]("=0
M14%27U!A8VMA9V5&:6QE7W8R)RP@)'-T<FEC="`](&9A;'-E*0T*("`@('L-
M"B`@("`@("`@:68@*"1S=')I8W0I('L-"B`@("`@("`@("`@(&EF("@A)'1H
M:7,M/E]P86-K86=E9FEL92T^=F%L:61A=&4H*2D@>PT*("`@("`@("`@("`@
M("`@("1A(#T@4$5!4CHZ<F%I<V5%<G)O<B@G:6YV86QI9"!P86-K86=E+GAM
M;"!V97)S:6]N(#$N,"!C86YN;W0@8F4@8V]N=F5R=&5D)R`N#0H@("`@("`@
M("`@("`@("`@("`@("<@=&\@=F5R<VEO;B`R+C`G+"!N=6QL+"!N=6QL+"!N
M=6QL+`T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5F:6QE
M+3YG971686QI9&%T:6]N5V%R;FEN9W,H=')U92DI.PT*("`@("`@("`@("`@
M("`@(')E='5R;B`D83L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("`D87)R(#T@87)R87DH#0H@("`@("`@("`@("`G871T<FEB<R<@/3X@
M87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=V97)S:6]N
M)R`]/B`G,BXP)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)WAM
M;&YS)R`]/B`G:'1T<#HO+W!E87(N<&AP+FYE="]D=&0O<&%C:V%G92TR+C`G
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G>&UL;G,Z=&%S:W,G
M(#T^("=H='1P.B\O<&5A<BYP:'`N;F5T+V1T9"]T87-K<RTQ+C`G+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G>&UL;G,Z>'-I)R`]/B`G:'1T
M<#HO+W=W=RYW,RYO<F<O,C`P,2]834Q38VAE;6$M:6YS=&%N8V4G+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G>'-I.G-C:&5M84QO8V%T:6]N
M)R`]/B`B:'1T<#HO+W!E87(N<&AP+FYE="]D=&0O=&%S:W,M,2XP7&XB("X-
M"B)H='1P.B\O<&5A<BYP:'`N;F5T+V1T9"]T87-K<RTQ+C`N>'-D7&XB("X-
M"B)H='1P.B\O<&5A<BYP:'`N;F5T+V1T9"]P86-K86=E+3(N,%QN(B`N#0HG
M:'1T<#HO+W!E87(N<&AP+FYE="]D=&0O<&%C:V%G92TR+C`N>'-D)RP-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@)VYA;64G
M(#T^("1T:&ES+3Y?<&%C:V%G969I;&4M/F=E=%!A8VMA9V4H*2P-"B`@("`@
M("`@("`@("=C:&%N;F5L)R`]/B`G<&5A<BYP:'`N;F5T)RP-"B`@("`@("`@
M*3L-"B`@("`@("`@)&%R<ELG<W5M;6%R>2==(#T@)'1H:7,M/E]P86-K86=E
M9FEL92T^9V5T4W5M;6%R>2@I.PT*("`@("`@("`D87)R6R=D97-C<FEP=&EO
M;B==(#T@)'1H:7,M/E]P86-K86=E9FEL92T^9V5T1&5S8W)I<'1I;VXH*3L-
M"B`@("`@("`@)&UA:6YT86EN97)S(#T@)'1H:7,M/E]P86-K86=E9FEL92T^
M9V5T36%I;G1A:6YE<G,H*3L-"B`@("`@("`@9F]R96%C:"`H)&UA:6YT86EN
M97)S(&%S("1M86EN=&%I;F5R*2![#0H@("`@("`@("`@("!I9B`H)&UA:6YT
M86EN97);)W)O;&4G72`A/2`G;&5A9"<I('L-"B`@("`@("`@("`@("`@("!C
M;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1N97<@/2!A
M<G)A>2@-"B`@("`@("`@("`@("`@("`G;F%M92<@/3X@)&UA:6YT86EN97);
M)VYA;64G72P-"B`@("`@("`@("`@("`@("`G=7-E<B<@/3X@)&UA:6YT86EN
M97);)VAA;F1L92==+`T*("`@("`@("`@("`@("`@("=E;6%I;"<@/3X@)&UA
M:6YT86EN97);)V5M86EL)UTL#0H@("`@("`@("`@("`@("`@)V%C=&EV92<@
M/3X@)WEE<R<L#0H@("`@("`@("`@("`I.PT*("`@("`@("`@("`@)&%R<ELG
M;&5A9"==6UT@/2`D;F5W.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S
M970H)&%R<ELG;&5A9"==*2D@>R`O+R!S;VUE('!E;W!L92XN+B!Y;W4@:VYO
M=S\-"B`@("`@("`@("`@("1A<G);)VQE860G72`](&%R<F%Y*`T*("`@("`@
M("`@("`@("`@("=N86UE)R`]/B`G=6YK;F]W;B<L#0H@("`@("`@("`@("`@
M("`@)W5S97(G(#T^("=U;FMN;W=N)RP-"B`@("`@("`@("`@("`@("`G96UA
M:6PG(#T^("=N;VQE861M86EN=&%I;F5R0&5X86UP;&4N8V]M)RP-"B`@("`@
M("`@("`@("`@("`G86-T:79E)R`]/B`G;F\G+`T*("`@("`@("`@("`@*3L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H8V]U;G0H)&%R<ELG;&5A9"==*2`]
M/2`Q*2![#0H@("`@("`@("`@("`D87)R6R=L96%D)UT@/2`D87)R6R=L96%D
M)UU;,%T[#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H)&UA:6YT86EN
M97)S(&%S("1M86EN=&%I;F5R*2![#0H@("`@("`@("`@("!I9B`H)&UA:6YT
M86EN97);)W)O;&4G72`]/2`G;&5A9"<I('L-"B`@("`@("`@("`@("`@("!C
M;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1N97<@/2!A
M<G)A>2@-"B`@("`@("`@("`@("`@("`G;F%M92<@/3X@)&UA:6YT86EN97);
M)VYA;64G72P-"B`@("`@("`@("`@("`@("`G=7-E<B<@/3X@)&UA:6YT86EN
M97);)VAA;F1L92==+`T*("`@("`@("`@("`@("`@("=E;6%I;"<@/3X@)&UA
M:6YT86EN97);)V5M86EL)UTL#0H@("`@("`@("`@("`@("`@)V%C=&EV92<@
M/3X@)WEE<R<L#0H@("`@("`@("`@("`I.PT*("`@("`@("`@("`@)&%R<ELD
M;6%I;G1A:6YE<ELG<F]L92==75M=(#T@)&YE=SL-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H:7-S970H)&%R<ELG9&5V96QO<&5R)UTI("8F(&-O=6YT*"1A
M<G);)V1E=F5L;W!E<B==*2`]/2`Q*2![#0H@("`@("`@("`@("`D87)R6R=D
M979E;&]P97(G72`]("1A<G);)V1E=F5L;W!E<B==6S!=.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("AI<W-E="@D87)R6R=C;VYT<FEB=71O<B==*2`F)B!C
M;W5N="@D87)R6R=C;VYT<FEB=71O<B==*2`]/2`Q*2![#0H@("`@("`@("`@
M("`D87)R6R=C;VYT<FEB=71O<B==(#T@)&%R<ELG8V]N=')I8G5T;W(G75LP
M73L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&%R<ELG:&5L<&5R
M)UTI("8F(&-O=6YT*"1A<G);)VAE;'!E<B==*2`]/2`Q*2![#0H@("`@("`@
M("`@("`D87)R6R=H96QP97(G72`]("1A<G);)VAE;'!E<B==6S!=.PT*("`@
M("`@("!]#0H@("`@("`@("1A<G);)V1A=&4G72`]("1T:&ES+3Y?<&%C:V%G
M969I;&4M/F=E=$1A=&4H*3L-"B`@("`@("`@)&%R<ELG=F5R<VEO;B==(#T-
M"B`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=R96QE87-E
M)R`]/B`D=&AI<RT^7W!A8VMA9V5F:6QE+3YG971697)S:6]N*"DL#0H@("`@
M("`@("`@("`@("`@)V%P:2<@/3X@)'1H:7,M/E]P86-K86=E9FEL92T^9V5T
M5F5R<VEO;B@I+`T*("`@("`@("`@("`@*3L-"B`@("`@("`@)&%R<ELG<W1A
M8FEL:71Y)UT@/0T*("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@("`@
M("`@)W)E;&5A<V4G(#T^("1T:&ES+3Y?<&%C:V%G969I;&4M/F=E=%-T871E
M*"DL#0H@("`@("`@("`@("`@("`@)V%P:2<@/3X@)'1H:7,M/E]P86-K86=E
M9FEL92T^9V5T4W1A=&4H*2P-"B`@("`@("`@("`@("D[#0H@("`@("`@("1L
M:6-E;G-E;6%P(#T-"B`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@
M("`@("=P:'`G(#T^("=H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92<L#0H@
M("`@("`@("`@("`@("`@)W!H<"!L:6-E;G-E)R`]/B`G:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4G+`T*("`@("`@("`@("`@("`@("=L9W!L)R`]/B`G
M:'1T<#HO+W=W=RYG;G4N;W)G+V-O<'EL969T+VQE<W-E<BYH=&UL)RP-"B`@
M("`@("`@("`@("`@("`G8G-D)R`]/B`G:'1T<#HO+W=W=RYO<&5N<V]U<F-E
M+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`G+`T*("`@("`@("`@("`@
M("`@("=B<V0@<W1Y;&4G(#T^("=H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G
M+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"<L#0H@("`@("`@("`@("`@("`@
M)V)S9"US='EL92<@/3X@)VAT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC
M96YS97,O8G-D+6QI8V5N<V4N<&AP)RP-"B`@("`@("`@("`@("`@("`G;6ET
M)R`]/B`G:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]M:70M
M;&EC96YS92YP:'`G+`T*("`@("`@("`@("`@("`@("=G<&PG(#T^("=H='1P
M.B\O=W=W+F=N=2YO<F<O8V]P>6QE9G0O9W!L+FAT;6PG+`T*("`@("`@("`@
M("`@("`@("=A<&%C:&4G(#T^("=H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G
M+VQI8V5N<V5S+V%P86-H93(N,"YP:'`G#0H@("`@("`@("`@("`I.PT*("`@
M("`@("!I9B`H:7-S970H)&QI8V5N<V5M87!;<W1R=&]L;W=E<B@D=&AI<RT^
M7W!A8VMA9V5F:6QE+3YG971,:6-E;G-E*"DI72DI('L-"B`@("`@("`@("`@
M("1A<G);)VQI8V5N<V4G72`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("=A
M='1R:6)S)R`]/B!A<G)A>2@G=7)I)R`]/@T*("`@("`@("`@("`@("`@("`@
M("`D;&EC96YS96UA<%MS=')T;VQO=V5R*"1T:&ES+3Y?<&%C:V%G969I;&4M
M/F=E=$QI8V5N<V4H*2E=*2P-"B`@("`@("`@("`@("`@("`G7V-O;G1E;G0G
M(#T^("1T:&ES+3Y?<&%C:V%G969I;&4M/F=E=$QI8V5N<V4H*0T*("`@("`@
M("`@("`@("`@("D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`O
M+R!D;VXG="!U<V4@8F]G=7,@=7)I#0H@("`@("`@("`@("`D87)R6R=L:6-E
M;G-E)UT@/2`D=&AI<RT^7W!A8VMA9V5F:6QE+3YG971,:6-E;G-E*"D[#0H@
M("`@("`@('T-"B`@("`@("`@)&%R<ELG;F]T97,G72`]("1T:&ES+3Y?<&%C
M:V%G969I;&4M/F=E=$YO=&5S*"D[#0H@("`@("`@("1T96UP(#T@87)R87DH
M*3L-"B`@("`@("`@)&%R<ELG8V]N=&5N=',G72`]("1T:&ES+3Y?8V]N=F5R
M=$9I;&5L:7-T,E\P*"1T96UP*3L-"B`@("`@("`@)'1H:7,M/E]C;VYV97)T
M1&5P96YD96YC:65S,E\P*"1A<G(I.PT*("`@("`@("`D<F5L96%S92`]("@D
M=&AI<RT^7W!A8VMA9V5F:6QE+3YG971#;VYF:6=U<F5/<'1I;VYS*"D@?'P@
M)'1H:7,M/E]I<T5X=&5N<VEO;BD@/PT*("`@("`@("`@("`@)V5X='-R8W)E
M;&5A<V4G(#H@)W!H<')E;&5A<V4G.PT*("`@("`@("!I9B`H)')E;&5A<V4@
M/3T@)V5X='-R8W)E;&5A<V4G*2![#0H@("`@("`@("`@("`D87)R6R=C:&%N
M;F5L)UT@/2`G<&5C;"YP:'`N;F5T)SL-"B`@("`@("`@("`@("1A<G);)W!R
M;W9I9&5S97AT96YS:6]N)UT@/2`D87)R6R=N86UE)UT[("\O(&%S<W5M<'1I
M;VX-"B`@("`@("`@?0T*("`@("`@("`D87)R6R1R96QE87-E72`](&%R<F%Y
M*"D[#0H@("`@("`@(&EF("@D=&AI<RT^7W!A8VMA9V5F:6QE+3YG971#;VYF
M:6=U<F5/<'1I;VYS*"DI('L-"B`@("`@("`@("`@("1A<G);)')E;&5A<V5=
M6R=C;VYF:6=U<F5O<'1I;VXG72`]("1T:&ES+3Y?<&%C:V%G969I;&4M/F=E
M=$-O;F9I9W5R94]P=&EO;G,H*3L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1A
M<G);)')E;&5A<V5=6R=C;VYF:6=U<F5O<'1I;VXG72!A<R`D:2`]/B`D;W!T
M*2![#0H@("`@("`@("`@("`@("`@)&%R<ELD<F5L96%S95U;)V-O;F9I9W5R
M96]P=&EO;B==6R1I72`](&%R<F%Y*"=A='1R:6)S)R`]/B`D;W!T*3L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AC;W5N="@D87)R6R1R96QE
M87-E75LG8V]N9FEG=7)E;W!T:6]N)UTI(#T](#$I('L-"B`@("`@("`@("`@
M("`@("`D87)R6R1R96QE87-E75LG8V]N9FEG=7)E;W!T:6]N)UT@/2`D87)R
M6R1R96QE87-E75LG8V]N9FEG=7)E;W!T:6]N)UU;,%T[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]C;VYV97)T4F5L96%S
M93)?,"@D87)R6R1R96QE87-E72P@)'1E;7`I.PT*("`@("`@("!I9B`H)')E
M;&5A<V4@/3T@)V5X='-R8W)E;&5A<V4G("8F(&-O=6YT*"1A<G);)')E;&5A
M<V5=*2`^(#$I('L-"B`@("`@("`@("`@("\O(&UU;'1I<&QE(&5X='-R8W)E
M;&5A<V4@=&%G<R!A9&1E9"!I;B!014%2(#$N-"XQ#0H@("`@("`@("`@("`D
M87)R6R=D97!E;F1E;F-I97,G75LG<F5Q=6ER960G75LG<&5A<FEN<W1A;&QE
M<B==6R=M:6XG72`]("<Q+C0N,2<[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*"1C;"`]("1T:&ES+3Y?<&%C:V%G969I;&4M/F=E=$-H86YG96QO9R@I*2![
M#0H@("`@("`@("`@("!F;W)E86-H("@D8VP@87,@)')E;&5A<V4I('L-"B`@
M("`@("`@("`@("`@("`D<F5L(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@
M("`D<F5L6R=V97)S:6]N)UT@/0T*("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("=R96QE87-E)R`]/B`D<F5L
M96%S95LG=F5R<VEO;B==+`T*("`@("`@("`@("`@("`@("`@("`@("`@)V%P
M:2<@/3X@)')E;&5A<V5;)W9E<G-I;VXG72P-"B`@("`@("`@("`@("`@("`@
M("`@*3L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1R96QE87-E6R=R
M96QE87-E7W-T871E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1R96QE
M87-E6R=R96QE87-E7W-T871E)UT@/2`G<W1A8FQE)SL-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@)')E;%LG<W1A8FEL:71Y)UT@/0T*
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`@
M("`@("`@("=R96QE87-E)R`]/B`D<F5L96%S95LG<F5L96%S95]S=&%T92==
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@)V%P:2<@/3X@)')E;&5A<V5;
M)W)E;&5A<V5?<W1A=&4G72P-"B`@("`@("`@("`@("`@("`@("`@*3L-"B`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)')E;&5A<V5;)W)E;&5A<V5?9&%T
M92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<F5L6R=D871E)UT@/2`D
M<F5L96%S95LG<F5L96%S95]D871E)UT[#0H@("`@("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)')E;%LG9&%T92==(#T@9&%T
M92@G62UM+60G*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1R96QE87-E6R=R96QE87-E7VQI8V5N<V4G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1L:6-E;G-E;6%P6W-T
M<G1O;&]W97(H)')E;&5A<V5;)W)E;&5A<V5?;&EC96YS92==*5TI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D=7)I(#T@)&QI8V5N<V5M87!;<W1R
M=&]L;W=E<B@D<F5L96%S95LG<F5L96%S95]L:6-E;G-E)UTI73L-"B`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1U<FD@/2`G:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2<[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)')E;%LG;&EC
M96YS92==(#T@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V%T=')I8G,G(#T^(&%R<F%Y*"=U<FDG(#T^("1U<FDI+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=?8V]N=&5N="<@/3X@)')E;&5A<V5;)W)E
M;&5A<V5?;&EC96YS92==#0H@("`@("`@("`@("`@("`@("`@("`@("`I.PT*
M("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@
M("1R96Q;)VQI8V5N<V4G72`]("1A<G);)VQI8V5N<V4G73L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D<F5L96%S
M95LG<F5L96%S95]N;W1E<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D
M<F5L96%S95LG<F5L96%S95]N;W1E<R==(#T@)VYO(')E;&5A<V4@;F]T97,G
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D<F5L6R=N
M;W1E<R==(#T@)')E;&5A<V5;)W)E;&5A<V5?;F]T97,G73L-"B`@("`@("`@
M("`@("`@("`D87)R6R=C:&%N9V5L;V<G75LG<F5L96%S92==6UT@/2`D<F5L
M.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1R970@/2!N
M97<@)&-L87-S.PT*("`@("`@("`D<F5T+3YS971#;VYF:6<H)'1H:7,M/E]P
M86-K86=E9FEL92T^7V-O;F9I9RD[#0H@("`@("`@("1R970M/G-E=$QO9V=E
M<B@D=&AI<RT^7W!A8VMA9V5F:6QE+3Y?;&]G9V5R*3L-"B`@("`@("`@)')E
M="T^9G)O;4%R<F%Y*"1A<G(I.PT*("`@("`@("!R971U<FX@)')E=#L-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@87)R87D-"B`@("`@*B!`
M<&%R86T@8F]O;`T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*
M("`@(&9U;F-T:6]N(%]C;VYV97)T1&5P96YD96YC:65S,E\P*"8D<F5L96%S
M92P@)&EN=&5R;F%L(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D<&5A<F1E
M<"`](&%R<F%Y*"=P96%R:6YS=&%L;&5R)R`]/@T*("`@("`@("`@("`@87)R
M87DH)VUI;B<@/3X@)S$N-"XP8C$G*2D[("\O('1H:7,@:7,@82!L;W0@<V%F
M97(-"B`@("`@("`@)')E<75I<F5D(#T@)&]P=&EO;F%L(#T@87)R87DH*3L-
M"B`@("`@("`@)')E;&5A<V5;)V1E<&5N9&5N8VEE<R==(#T@87)R87DH*3L-
M"B`@("`@("`@:68@*"1T:&ES+3Y?<&%C:V%G969I;&4M/FAA<T1E<',H*2D@
M>PT*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]P86-K86=E9FEL92T^
M9V5T1&5P<R@I(&%S("1D97`I('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1D97!;)V]P=&EO;F%L)UTI('Q\("1D97!;)V]P=&EO;F%L)UT@/3T@
M)VYO)RD@>PT*("`@("`@("`@("`@("`@("`@("`D<F5Q=6ER961;72`]("1D
M97`[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@)&]P=&EO;F%L6UT@/2`D9&5P.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@*&%R<F%Y*"=R
M97%U:7)E9"<L("=O<'1I;VYA;"<I(&%S("1A<G(I('L-"B`@("`@("`@("`@
M("`@("`D9&5P<R`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)"1A<G(@87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@("`@("`O+R!O
M<F=A;FEZ92!D97!S(&)Y(&1E<&5N9&5N8WD@='EP92!A;F0@;F%M90T*("`@
M("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1D97!S6R1D97!;)W1Y<&4G
M75TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D9&5P<ULD9&5P6R=T
M>7!E)UU=(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG;F%M92==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)&1E<'-;)&1E<%LG='EP92==75LD
M9&5P6R=N86UE)UU=6UT@/2`D9&5P.PT*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&1E<'-;)&1E<%LG
M='EP92==75M=(#T@)&1E<#L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!D;R![#0H@("`@("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P<ULG<&AP)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D<&AP(#T@87)R87DH*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("AC;W5N="@D9&5P<ULG<&AP)UTI(#X@,2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P:'`@/2`D=&AI<RT^
M7W!R;V-E<W-0:'!$97!S*"1D97!S6R=P:'`G72D[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@A:7-S970H)&1E<'-;)W!H<"==6S!=*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!L:7-T*"1K97DL("1B;&%H*2`](&5A
M8V@@*"1D97!S6R=P:'`G72D[("\O('-T=7!I9"!B=6=G>2!V97)S:6]N<PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P<ULG<&AP)UT@
M/2!A<G)A>2@D8FQA:%LP72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P:'`@/2`D=&AI
M<RT^7W!R;V-E<W-$97`H)&1E<'-;)W!H<"==6S!=*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H(21P:'`I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8G)E86L[("\O('!O;W(@;6%N<R!T:')O=PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("1R96QE87-E
M6R=D97!E;F1E;F-I97,G75LD87)R75LG<&AP)UT@/2`D<&AP.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?2!W:&EL92`H9F%L
M<V4I.PT*("`@("`@("`@("`@("`@(&1O('L-"B`@("`@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1D97!S6R=P:V<G72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1P:V<@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)'!K9R`]("1T:&ES+3Y?<')O8V5S<TUU;'1I<&QE1&5P<TYA;64H
M)&1E<'-;)W!K9R==*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A
M)'!K9RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.R`O
M+R!P;V]R(&UA;G,@=&AR;W<-"B`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1R96QE87-E6R=D97!E;F1E;F-I
M97,G75LD87)R75LG<&%C:V%G92==(#T@)'!K9SL-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@('T@=VAI;&4@*&9A;'-E*3L-"B`@
M("`@("`@("`@("`@("!D;R![#0H@("`@("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D9&5P<ULG97AT)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D<&MG(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("1P
M:V<@/2`D=&AI<RT^7W!R;V-E<W--=6QT:7!L941E<'-.86UE*"1D97!S6R=E
M>'0G72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`D<F5L96%S95LG9&5P
M96YD96YC:65S)UU;)&%R<EU;)V5X=&5N<VEO;B==(#T@)'!K9SL-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T@=VAI;&4@*&9A
M;'-E*3L-"B`@("`@("`@("`@("`@("`O+R!S:VEP('-A<&D@+2!I="=S(&YO
M="!S=7!P;W)T960@<V\@;F]B;V1Y('=I;&P@:&%V92!U<V5D(&ET#0H@("`@
M("`@("`@("`@("`@+R\@<VMI<"!O<R`M(&ET)W,@;F]T('-U<'!O<G1E9"!I
M;B`Q+C`-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M:7-S970H)')E;&5A<V5;)V1E<&5N9&5N8VEE<R==6R=R97%U:7)E9"==*2D@
M>PT*("`@("`@("`@("`@)')E;&5A<V5;)V1E<&5N9&5N8VEE<R==6R=R97%U
M:7)E9"==(#T-"B`@("`@("`@("`@("`@("!A<G)A>5]M97)G92@D<&5A<F1E
M<"P@)')E;&5A<V5;)V1E<&5N9&5N8VEE<R==6R=R97%U:7)E9"==*3L-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1R96QE87-E6R=D97!E;F1E
M;F-I97,G75LG<F5Q=6ER960G72`]("1P96%R9&5P.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@A:7-S970H)')E;&5A<V5;)V1E<&5N9&5N8VEE<R==6R=R
M97%U:7)E9"==6R=P:'`G72DI('L-"B`@("`@("`@("`@("1R96QE87-E6R=D
M97!E;F1E;F-I97,G75LG<F5Q=6ER960G75LG<&AP)UT@/0T*("`@("`@("`@
M("`@("`@(&%R<F%Y*"=M:6XG(#T^("<T+C`N,"<I.PT*("`@("`@("!]#0H@
M("`@("`@("1O<F1E<B`](&%R<F%Y*"D[#0H@("`@("`@("1B97=M(#T@)')E
M;&5A<V5;)V1E<&5N9&5N8VEE<R==6R=R97%U:7)E9"==.PT*("`@("`@("`D
M;W)D97);)W!H<"==(#T@)&)E=VU;)W!H<"==.PT*("`@("`@("`D;W)D97);
M)W!E87)I;G-T86QL97(G72`]("1B97=M6R=P96%R:6YS=&%L;&5R)UT[#0H@
M("`@("`@(&ES<V5T*"1B97=M6R=P86-K86=E)UTI(#\@)&]R9&5R6R=P86-K
M86=E)UT@/2`D8F5W;5LG<&%C:V%G92==(#HP.PT*("`@("`@("!I<W-E="@D
M8F5W;5LG97AT96YS:6]N)UTI(#\@)&]R9&5R6R=E>'1E;G-I;VXG72`]("1B
M97=M6R=E>'1E;G-I;VXG72`Z,#L-"B`@("`@("`@)')E;&5A<V5;)V1E<&5N
M9&5N8VEE<R==6R=R97%U:7)E9"==(#T@)&]R9&5R.PT*("`@('T-"@T*("`@
M("\J*@T*("`@("`J($!P87)A;2!A<G)A>0T*("`@("`J($!A8V-E<W,@<')I
M=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]C;VYV97)T1FEL96QI<W0R
M7S`H)B1P86-K86=E*0T*("`@('L-"B`@("`@("`@)')E="`](&%R<F%Y*"=D
M:7(G(#T^#0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@
M("`@("`@("`@("`@("`@)V%T=')I8G,G(#T^(&%R<F%Y*"=N86UE)R`]/B`G
M+R<I+`T*("`@("`@("`@("`@("`@("`@("`@("`@)V9I;&4G(#T^(&%R<F%Y
M*"D-"B`@("`@("`@("`@("`@("`@("`@("`@("D-"B`@("`@("`@("`@("`@
M("`@("`@*3L-"B`@("`@("`@)'!A8VMA9V5;)W!L871F;W)M)UT@/0T*("`@
M("`@("`D<&%C:V%G95LG:6YS=&%L;"UA<R==(#T@87)R87DH*3L-"B`@("`@
M("`@)'1H:7,M/E]I<T5X=&5N<VEO;B`](&9A;'-E.PT*("`@("`@("!F;W)E
M86-H("@D=&AI<RT^7W!A8VMA9V5F:6QE+3YG971&:6QE;&ES="@I(&%S("1N
M86UE(#T^("1F:6QE*2![#0H@("`@("`@("`@("`D9FEL95LG;F%M92==(#T@
M)&YA;64[#0H@("`@("`@("`@("!I9B`H:7-S970H)&9I;&5;)W)O;&4G72D@
M)B8@)&9I;&5;)W)O;&4G72`]/2`G<W)C)RD@>PT*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?:7-%>'1E;G-I;VX@/2!T<G5E.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@:68@*&ES<V5T*"1F:6QE6R=R97!L86-E;65N=',G72DI
M('L-"B`@("`@("`@("`@("`@("`D<F5P;"`]("1F:6QE6R=R97!L86-E;65N
M=',G73L-"B`@("`@("`@("`@("`@("!U;G-E="@D9FEL95LG<F5P;&%C96UE
M;G1S)UTI.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("!U;G-E="@D<F5P;"D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I
M9B`H:7-S970H)&9I;&5;)VEN<W1A;&PM87,G72DI('L-"B`@("`@("`@("`@
M("`@("`D<&%C:V%G95LG:6YS=&%L;"UA<R==6R1N86UE72`]("1F:6QE6R=I
M;G-T86QL+6%S)UT[#0H@("`@("`@("`@("`@("`@=6YS970H)&9I;&5;)VEN
M<W1A;&PM87,G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H
M:7-S970H)&9I;&5;)W!L871F;W)M)UTI*2![#0H@("`@("`@("`@("`@("`@
M)'!A8VMA9V5;)W!L871F;W)M)UU;)&YA;65=(#T@)&9I;&5;)W!L871F;W)M
M)UT[#0H@("`@("`@("`@("`@("`@=6YS970H)&9I;&5;)W!L871F;W)M)UTI
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&9I;&4@/2!A<G)A>2@G
M871T<FEB<R<@/3X@)&9I;&4I.PT*("`@("`@("`@("`@:68@*&ES<V5T*"1R
M97!L*2D@>PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1R97!L(&%S("1R
M97!L86-E("D@>PT*("`@("`@("`@("`@("`@("`@("`D9FEL95LG=&%S:W,Z
M<F5P;&%C92==6UT@/2!A<G)A>2@G871T<FEB<R<@/3X@)')E<&QA8V4I.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H8V]U;G0H
M)')E<&PI(#T](#$I('L-"B`@("`@("`@("`@("`@("`@("`@)&9I;&5;)W1A
M<VMS.G)E<&QA8V4G72`]("1F:6QE6R=T87-K<SIR97!L86-E)UU;,%T[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M)')E=%LG9&ER)UU;)V9I;&4G75M=(#T@)&9I;&4[#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M4&]S="UP<F]C97-S('-P96-I86P@9FEL97,@=VET:"!I;G-T86QL+6%S+W!L
M871F;W)M(&%T=')I8G5T97,@86YD#0H@("`@("H@;6%K92!T:&4@<F5L96%S
M92!T86<N#0H@("`@("H@#0H@("`@("H@5&AI<R!C;VUP;&5X(&UE=&AO9"!F
M;VQL;W=S('1H:7,@=V]R:RUF;&]W('1O(&-R96%T92!T:&4@<F5L96%S92!T
M86=S.@T*("`@("`J(`T*("`@("`J(#QP<F4^#0H@("`@("H@+2!I9B!A;GD@
M:6YS=&%L;"UA<R]P;&%T9F]R;2!E>&ES="P@8W)E871E(&$@9V5N97)I8R!R
M96QE87-E(&%N9"!F:6QL(&ET('=I=&@-"B`@("`@*B`@(&\@/&EN<W1A;&P@
M87,]+BX^('1A9W,@9F]R(#QF:6QE(&YA;64]+BXN(&EN<W1A;&PM87,]+BXN
M/@T*("`@("`J("`@;R`\:6YS=&%L;"!A<STN+CX@=&%G<R!F;W(@/&9I;&4@
M;F%M93TN+BX@<&QA=&9O<FT](2XN+B!I;G-T86QL+6%S/2XN/@T*("`@("`J
M("`@;R`\:6=N;W)E/B!T86=S(&9O<B`\9FEL92!N86UE/2XN+B!P;&%T9F]R
M;3TN+BX^#0H@("`@("H@("!O(#QI9VYO<F4^('1A9W,@9F]R(#QF:6QE(&YA
M;64]+BXN('!L871F;W)M/2XN+B!I;G-T86QL+6%S/2XN/@T*("`@("`J("T@
M8W)E871E(&$@<F5L96%S92!F;W(@96%C:"!P;&%T9F]R;2!E;F-O=6YT97)E
M9"!A;F0@9FEL;"!W:71H#0H@("`@("H@("!O(#QI;G-T86QL(&%S+BX^('1A
M9W,@9F]R(#QF:6QE(&YA;64]+BXN(&EN<W1A;&PM87,]+BXN/@T*("`@("`J
M("`@;R`\:6YS=&%L;"!A<RXN/B!T86=S(&9O<B`\9FEL92!N86UE/2XN+B!P
M;&%T9F]R;3UT:&ES('!L871F;W)M(&EN<W1A;&PM87,]+BX^#0H@("`@("H@
M("!O(#QI;G-T86QL(&%S+BX^('1A9W,@9F]R(#QF:6QE(&YA;64]+BXN('!L
M871F;W)M/2%O=&AE<B!P;&%T9F]R;2!I;G-T86QL+6%S/2XN/@T*("`@("`J
M("`@;R`\:6=N;W)E/B!T86=S(&9O<B`\9FEL92!N86UE/2XN+B!P;&%T9F]R
M;3TA=&AI<R!P;&%T9F]R;3X-"B`@("`@*B`@(&\@/&EG;F]R93X@=&%G<R!F
M;W(@/&9I;&4@;F%M93TN+BX@<&QA=&9O<FT];W1H97(@<&QA=&9O<FT^#0H@
M("`@("H@("!O(#QI9VYO<F4^('1A9W,@9F]R(#QF:6QE(&YA;64]+BXN('!L
M871F;W)M/6]T:&5R('!L871F;W)M(&EN<W1A;&PM87,]+BX^#0H@("`@("H@
M("!O(#QI9VYO<F4^('1A9W,@9F]R(#QF:6QE(&YA;64]+BXN('!L871F;W)M
M/2%T:&ES('!L871F;W)M(&EN<W1A;&PM87,]+BX^#0H@("`@("H@/"]P<F4^
M#0H@("`@("H@#0H@("`@("H@270@9&]E<R!T:&ES(&)Y(&%C8V5S<VEN9R!T
M:&4@)'!A8VMA9V4@<&%R86UE=&5R+"!W:&EC:"!C;VYT86EN<R!A;B!A<G)A
M>2!W:71H#0H@("`@("H@:6YD:6-E<SH-"B`@("`@*B`-"B`@("`@*B`@+2!P
M;&%T9F]R;3H@;6%P<&EN9R!O9B!F:6QE(#T^($]3('1H92!F:6QE('-H;W5L
M9"!B92!I;G-T86QL960@;VX-"B`@("`@*B`@+2!I;G-T86QL+6%S.B!M87!P
M:6YG(&]F(&9I;&4@/3X@:6YS=&%L;&5D(&YA;64-"B`@("`@*B`@+2!O<VUA
M<#H@;6%P<&EN9R!O9B!/4R`]/B!L:7-T(&]F(&9I;&5S('1H870@<VAO=6QD
M(&)E(&EN<W1A;&QE9`T*("`@("`J("`@(&]N('1H870@3U,-"B`@("`@*B`@
M+2!N;W1O<VUA<#H@;6%P<&EN9R!O9B!/4R`]/B!L:7-T(&]F(&9I;&5S('1H
M870@<VAO=6QD(&YO="!B90T*("`@("`J("`@(&EN<W1A;&QE9"!O;B!T:&%T
M($]3#0H@("`@("H-"B`@("`@*B!`<&%R86T@87)R87D-"B`@("`@*B!`<&%R
M86T@87)R87D-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!?8V]N=F5R=%)E;&5A<V4R7S`H)B1R96QE87-E+"`D<&%C
M:V%G92D-"B`@("![#0H@("`@("`@("\O+2!I9B!A;GD@:6YS=&%L;"UA<R]P
M;&%T9F]R;2!E>&ES="P@8W)E871E(&$@9V5N97)I8R!R96QE87-E(&%N9"!F
M:6QL(&ET('=I=&@@#0H@("`@("`@(&EF("AC;W5N="@D<&%C:V%G95LG<&QA
M=&9O<FTG72D@?'P@8V]U;G0H)'!A8VMA9V5;)VEN<W1A;&PM87,G72DI('L-
M"B`@("`@("`@("`@("1G96YE<FEC(#T@87)R87DH*3L-"B`@("`@("`@("`@
M("1G96YE<FEC26=N;W)E(#T@87)R87DH*3L-"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1P86-K86=E6R=I;G-T86QL+6%S)UT@87,@)&9I;&4@/3X@)&%S*2![
M#0H@("`@("`@("`@("`@("`@+R]O(#QI;G-T86QL(&%S/2XN/B!T86=S(&9O
M<B`\9FEL92!N86UE/2XN+B!I;G-T86QL+6%S/2XN+CX-"B`@("`@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1P86-K86=E6R=P;&%T9F]R;2==6R1F:6QE72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@)&=E;F5R:6-;72`]("1F:6QE.PT*
M("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@+R]O(#QI;G-T86QL(&%S/2XN/B!T86=S
M(&9O<B`\9FEL92!N86UE/2XN+B!P;&%T9F]R;3TA+BXN(&EN<W1A;&PM87,]
M+BX^#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P86-K86=E6R=P;&%T
M9F]R;2==6R1F:6QE72D@)B8-"B`@("`@("`@("`@("`@("`@("`@("`D<&%C
M:V%G95LG<&QA=&9O<FTG75LD9FEL95U[,'T@/3T@)R$G*2![#0H@("`@("`@
M("`@("`@("`@("`@("1G96YE<FEC6UT@/2`D9FEL93L-"B`@("`@("`@("`@
M("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("\O;R`\:6=N;W)E/B!T86=S(&9O<B`\9FEL92!N86UE/2XN
M+B!P;&%T9F]R;3TN+BX@:6YS=&%L;"UA<STN+CX-"B`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)'!A8VMA9V5;)W!L871F;W)M)UU;)&9I;&5=*2`F)@T*
M("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E6R=P;&%T9F]R;2==6R1F
M:6QE77LP?2`A/2`G(2<I('L-"B`@("`@("`@("`@("`@("`@("`@)&=E;F5R
M:6-)9VYO<F5;72`]("1F:6QE.PT*("`@("`@("`@("`@("`@("`@("!C;VYT
M:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!F;W)E86-H("@D<&%C:V%G95LG<&QA=&9O<FTG72!A<R`D9FEL
M92`]/B`D<&QA=&9O<FTI('L-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)'!A8VMA9V5;)VEN<W1A;&PM87,G75LD9FEL95TI*2![#0H@("`@("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!I9B`H)'!L871F;W)M>S!]("$]("<A)RD@>PT*("`@("`@
M("`@("`@("`@("`@("`O+V\@/&EG;F]R93X@=&%G<R!F;W(@/&9I;&4@;F%M
M93TN+BX@<&QA=&9O<FT]+BXN/@T*("`@("`@("`@("`@("`@("`@("`D9V5N
M97)I8TEG;F]R95M=(#T@)&9I;&4[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&-O=6YT*"1P86-K86=E6R=P
M;&%T9F]R;2==*2D@>PT*("`@("`@("`@("`@("`@("1O<V5S(#T@)&YO='!L
M871F;W)M(#T@)'!L871F;W)M(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@
M("!F;W)E86-H("@D<&%C:V%G95LG<&QA=&9O<FTG72!A<R`D9FEL92`]/B`D
M;W,I('L-"B`@("`@("`@("`@("`@("`@("`@+R\@9V5T(&$@;&ES="!O9B!O
M<V5S#0H@("`@("`@("`@("`@("`@("`@(&EF("@D;W-[,'T@/3T@)R$G*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&]S97-;<W5B
M<W1R*"1O<RP@,2E=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@)&]S97-;<W5B<W1R*"1O<RP@,2E=(#T@8V]U
M;G0H)&]S97,I.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1O<V5S6R1O<UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D;W-E<ULD;W-=(#T@8V]U;G0H)&]S97,I.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("\O
M+2!C<F5A=&4@82!R96QE87-E(&9O<B!E86-H('!L871F;W)M(&5N8V]U;G1E
M<F5D(&%N9"!F:6QL('=I=&@-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D
M;W-E<R!A<R`D;W,@/3X@)')E;&5A<V5.=6TI('L-"B`@("`@("`@("`@("`@
M("`@("`@)')E;&5A<V5;)')E;&5A<V5.=6U=6R=I;G-T86QL8V]N9&ET:6]N
M<R==6R=O<R==6R=N86UE)UT@/2`D;W,[#0H@("`@("`@("`@("`@("`@("`@
M("1R96QE87-E6R1R96QE87-E3G5M75LG9FEL96QI<W0G72`](&%R<F%Y*"=I
M;G-T86QL)R`]/B!A<G)A>2@I+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M)VEG;F]R92<@/3X@87)R87DH*2D[#0H@("`@("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*"1P86-K86=E6R=I;G-T86QL+6%S)UT@87,@)&9I;&4@/3X@)&%S
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`O+V\@/&EN<W1A;&P@87,]
M+BX^('1A9W,@9F]R(#QF:6QE(&YA;64]+BXN(&EN<W1A;&PM87,]+BXN/@T*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D<&%C:V%G95LG
M<&QA=&9O<FTG75LD9FEL95TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)')E;&5A<V5;)')E;&5A<V5.=6U=6R=F:6QE;&ES="==6R=I;G-T
M86QL)UU;72`]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%T
M=')I8G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=N86UE)R`]/B`D9FEL92P-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G87,G(#T^("1A<RP-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("D[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@("`@("`O+V\@/&EN<W1A;&P@87,N+CX@
M=&%G<R!F;W(-"B`@("`@("`@("`@("`@("`@("`@("`@("\O("`\9FEL92!N
M86UE/2XN+B!P;&%T9F]R;3UT:&ES('!L871F;W)M(&EN<W1A;&PM87,]+BX^
M#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A8VMA9V5;
M)W!L871F;W)M)UU;)&9I;&5=*2`F)@T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!A8VMA9V5;)W!L871F;W)M)UU;)&9I;&5=(#T]("1O<RD@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R96QE87-E6R1R96QE
M87-E3G5M75LG9FEL96QI<W0G75LG:6YS=&%L;"==6UT@/0T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=A='1R:6)S)R`]/B!A<G)A>2@-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;F%M92<@
M/3X@)&9I;&4L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)V%S)R`]/B`D87,L#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@+R]O(#QI;G-T86QL(&%S+BX^('1A9W,@9F]R#0H@("`@("`@("`@
M("`@("`@("`@("`@("`O+R`@/&9I;&4@;F%M93TN+BX@<&QA=&9O<FT](6]T
M:&5R('!L871F;W)M(&EN<W1A;&PM87,]+BX^#0H@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)'!A8VMA9V5;)W!L871F;W)M)UU;)&9I;&5=
M*2`F)@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A8VMA9V5;
M)W!L871F;W)M)UU;)&9I;&5=("$]("(A)&]S(B`F)@T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'!A8VMA9V5;)W!L871F;W)M)UU;)&9I;&5=
M>S!](#T]("<A)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R
M96QE87-E6R1R96QE87-E3G5M75LG9FEL96QI<W0G75LG:6YS=&%L;"==6UT@
M/0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A='1R:6)S)R`]
M/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G;F%M92<@/3X@)&9I;&4L#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V%S)R`]/B`D87,L#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@+R]O(#QI9VYO<F4^('1A9W,@9F]R#0H@("`@
M("`@("`@("`@("`@("`@("`@("`O+R`@/&9I;&4@;F%M93TN+BX@<&QA=&9O
M<FT](71H:7,@<&QA=&9O<FT@:6YS=&%L;"UA<STN+CX-"B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D<&%C:V%G95LG<&QA=&9O<FTG75LD
M9FEL95TI("8F#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%C
M:V%G95LG<&QA=&9O<FTG75LD9FEL95T@/3T@(B$D;W,B*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)')E;&5A<V5;)')E;&5A<V5.=6U=6R=F
M:6QE;&ES="==6R=I9VYO<F4G75M=(#T-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G871T<FEB<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^("1F:6QE+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("\O;R`\:6=N;W)E/B!T
M86=S(&9O<@T*("`@("`@("`@("`@("`@("`@("`@("`@+R\@(#QF:6QE(&YA
M;64]+BXN('!L871F;W)M/6]T:&5R('!L871F;W)M(&EN<W1A;&PM87,]+BX^
M#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A8VMA9V5;
M)W!L871F;W)M)UU;)&9I;&5=*2`F)@T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!A8VMA9V5;)W!L871F;W)M)UU;)&9I;&5=>S!]("$]("<A
M)R`F)@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A8VMA9V5;
M)W!L871F;W)M)UU;)&9I;&5=("$]("1O<RD@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1R96QE87-E6R1R96QE87-E3G5M75LG9FEL96QI<W0G
M75LG:6=N;W)E)UU;72`]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V%T=')I8G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B`D9FEL92P-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("D[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@9F]R
M96%C:"`H)'!A8VMA9V5;)W!L871F;W)M)UT@87,@)&9I;&4@/3X@)'!L871F
M;W)M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A
M8VMA9V5;)VEN<W1A;&PM87,G75LD9FEL95TI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`O+V\@/&EG;F]R93X@
M=&%G<R!F;W(@/&9I;&4@;F%M93TN+BX@<&QA=&9O<FT](71H:7,@<&QA=&9O
M<FT^#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'!L871F;W)M(#T]
M("(A)&]S(BD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R96QE
M87-E6R1R96QE87-E3G5M75LG9FEL96QI<W0G75LG:6=N;W)E)UU;72`]#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%T=')I8G,G(#T^(&%R
M<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=N86UE)R`]/B`D9FEL92P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("`O+V\@/&EG;F]R93X@=&%G<R!F;W(@/&9I;&4@;F%M93TN+BX@<&QA
M=&9O<FT];W1H97(@<&QA=&9O<FT^#0H@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H)'!L871F;W)M>S!]("$]("<A)R`F)B`D<&QA=&9O<FT@(3T@)&]S
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E;&5A<V5;)')E
M;&5A<V5.=6U=6R=F:6QE;&ES="==6R=I9VYO<F4G75M=(#T-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G871T<FEB<R<@/3X@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYA;64G
M(#T^("1F:6QE+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L-"B`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("!I9B`H(6-O=6YT*"1R96QE87-E6R1R
M96QE87-E3G5M75LG9FEL96QI<W0G75LG:6YS=&%L;"==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@=6YS970H)')E;&5A<V5;)')E;&5A<V5.=6U=
M6R=F:6QE;&ES="==6R=I;G-T86QL)UTI.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@A8V]U;G0H)')E;&5A<V5;
M)')E;&5A<V5.=6U=6R=F:6QE;&ES="==6R=I9VYO<F4G72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@('5N<V5T*"1R96QE87-E6R1R96QE87-E3G5M
M75LG9FEL96QI<W0G75LG:6=N;W)E)UTI.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AC
M;W5N="@D9V5N97)I8RD@?'P@8V]U;G0H)&=E;F5R:6-)9VYO<F4I*2![#0H@
M("`@("`@("`@("`@("`@("`@("1R96QE87-E6V-O=6YT*"1O<V5S*5T@/2!A
M<G)A>2@I.PT*("`@("`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)&=E;F5R
M:6,I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D9V5N
M97)I8R!A<R`D9FEL92D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D<&%C:V%G95LG:6YS=&%L;"UA<R==6R1F:6QE72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN<W1A;&QA<R`]
M("1P86-K86=E6R=I;G-T86QL+6%S)UU;)&9I;&5=.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1I;G-T86QL87,@/2`D9FEL93L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)')E;&5A<V5;8V]U;G0H)&]S97,I75LG9FEL96QI<W0G75LG:6YS=&%L
M;"==6UT@/0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A='1R
M:6)S)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G;F%M92<@/3X@)&9I;&4L#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)V%S)R`]/B`D:6YS=&%L;&%S+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*0T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`I.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@(&EF("AC;W5N="@D9V5N97)I8TEG;F]R92DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1G96YE<FEC26=N;W)E(&%S
M("1F:6QE*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E;&5A
M<V5;8V]U;G0H)&]S97,I75LG9FEL96QI<W0G75LG:6=N;W)E)UU;72`]#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%T=')I8G,G(#T^(&%R
M<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=N86UE)R`]/B`D9FEL92P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("D-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`O
M+R!C;&5A;G5P#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)')E;&5A<V4@
M87,@)&D@/3X@)')E;"D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)')E;%LG9FEL96QI<W0G75LG:6YS=&%L;"==*2`F)@T*("`@("`@("`@
M("`@("`@("`@("`@("`@("!C;W5N="@D<F5L6R=F:6QE;&ES="==6R=I;G-T
M86QL)UTI(#T](#$I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1R96QE
M87-E6R1I75LG9FEL96QI<W0G75LG:6YS=&%L;"==(#T-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<F5L96%S95LD:5U;)V9I;&5L:7-T)UU;)VEN
M<W1A;&PG75LP73L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)')E;%LG9FEL96QI<W0G75LG:6=N;W)E
M)UTI("8F#0H@("`@("`@("`@("`@("`@("`@("`@("`@(&-O=6YT*"1R96Q;
M)V9I;&5L:7-T)UU;)VEG;F]R92==*2`]/2`Q*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D<F5L96%S95LD:5U;)V9I;&5L:7-T)UU;)VEG;F]R92==
M(#T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5L96%S95LD:5U;
M)V9I;&5L:7-T)UU;)VEG;F]R92==6S!=.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AC
M;W5N="@D<F5L96%S92D@/3T@,2D@>PT*("`@("`@("`@("`@("`@("`@("`D
M<F5L96%S92`]("1R96QE87-E6S!=.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@+R\@;F\@<&QA
M=&9O<FT@871T<RP@8G5T('-O;64@:6YS=&%L;"UA<R!A='1S#0H@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)'!A8VMA9V5;)VEN<W1A;&PM87,G72!A<R`D
M9FEL92`]/B`D=F%L=64I('L-"B`@("`@("`@("`@("`@("`@("`@)')E;&5A
M<V5;)V9I;&5L:7-T)UU;)VEN<W1A;&PG75M=(#T-"B`@("`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=A='1R:6)S)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)VYA;64G(#T^("1F:6QE+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G87,G(#T^("1V86QU90T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("D-"B`@("`@("`@("`@("`@("`@("`@("`@("D[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AC;W5N="@D
M<F5L96%S95LG9FEL96QI<W0G75LG:6YS=&%L;"==*2`]/2`Q*2![#0H@("`@
M("`@("`@("`@("`@("`@("1R96QE87-E6R=F:6QE;&ES="==6R=I;G-T86QL
M)UT@/2`D<F5L96%S95LG9FEL96QI<W0G75LG:6YS=&%L;"==6S!=.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!A<G)A>0T*("`@("`J($!R
M971U<FX@87)R87D-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!?<')O8V5S<T1E<"@D9&5P*0T*("`@('L-"B`@("`@
M("`@:68@*"1D97!;)W1Y<&4G72`]/2`G<&AP)RD@>PT*("`@("`@("`@("`@
M:68@*"1D97!;)W)E;"==(#T]("=H87,G*2![#0H@("`@("`@("`@("`@("`@
M+R\@8V]M92!O;B`M(&5V97)Y;VYE(&AA<R!P:'`A#0H@("`@("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@("1P:'`@/2!A<G)A>2@I.PT*("`@("`@("!I9B`H)&1E<%LG='EP
M92==("$]("=P:'`G*2![#0H@("`@("`@("`@("`D<&AP6R=N86UE)UT@/2`D
M9&5P6R=N86UE)UT[#0H@("`@("`@("`@("!I9B`H)&1E<%LG='EP92==(#T]
M("=P:V<G*2![#0H@("`@("`@("`@("`@("`@)'!H<%LG8VAA;FYE;"==(#T@
M)W!E87(N<&AP+FYE="<[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@<W=I=&-H("@D9&5P6R=R96PG72D@>PT*("`@("`@("`@("`@8V%S
M92`G9W0G(#H-"B`@("`@("`@("`@("`@("`D<&AP6R=M:6XG72`]("1D97!;
M)W9E<G-I;VXG73L-"B`@("`@("`@("`@("`@("`D<&AP6R=E>&-L=61E)UT@
M/2`D9&5P6R=V97)S:6]N)UT[#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@
M("`@("`@(&-A<V4@)V=E)R`Z#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D9&5P6R=V97)S:6]N)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(&EF
M("@D9&5P6R=T>7!E)UT@/3T@)W!H<"<I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D9&5P6R=N86UE)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&1E<%LG=F5R<VEO;B==(#T@)&1E<%LG;F%M
M92==.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("1P:'!;)VUI;B==(#T@)&1E<%LG=F5R<VEO;B==.PT*("`@("`@("`@("`@
M8G)E86L[#0H@("`@("`@("`@("!C87-E("=L="<@.@T*("`@("`@("`@("`@
M("`@("1P:'!;)VUA>"==(#T@)&1E<%LG=F5R<VEO;B==.PT*("`@("`@("`@
M("`@("`@("1P:'!;)V5X8VQU9&4G72`]("1D97!;)W9E<G-I;VXG73L-"B`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G;&4G(#H-"B`@
M("`@("`@("`@("`@("`D<&AP6R=M87@G72`]("1D97!;)W9E<G-I;VXG73L-
M"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G97$G(#H-
M"B`@("`@("`@("`@("`@("`D<&AP6R=M:6XG72`]("1D97!;)W9E<G-I;VXG
M73L-"B`@("`@("`@("`@("`@("`D<&AP6R=M87@G72`]("1D97!;)W9E<G-I
M;VXG73L-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G
M;F4G(#H-"B`@("`@("`@("`@("`@("`D<&AP6R=E>&-L=61E)UT@/2`D9&5P
M6R=V97)S:6]N)UT[#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@
M(&-A<V4@)VYO="<@.@T*("`@("`@("`@("`@("`@("1P:'!;)V-O;F9L:6-T
M<R==(#T@)WEE<R<[#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@?0T*
M("`@("`@("!R971U<FX@)'!H<#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!`<&%R86T@87)R87D-"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@7W!R;V-E<W-0:'!$97!S*"1D97!S*0T*("`@('L-
M"B`@("`@("`@)'1E<W0@/2!A<G)A>2@I.PT*("`@("`@("!F;W)E86-H("@D
M9&5P<R!A<R`D9&5P*2![#0H@("`@("`@("`@("`D=&5S=%M=(#T@)'1H:7,M
M/E]P<F]C97-S1&5P*"1D97`I.PT*("`@("`@("!]#0H@("`@("`@("1M:6X@
M/2!A<G)A>2@I.PT*("`@("`@("`D;6%X(#T@87)R87DH*3L-"B`@("`@("`@
M9F]R96%C:"`H)'1E<W0@87,@)&1E<"D@>PT*("`@("`@("`@("`@:68@*"$D
M9&5P*2![#0H@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG;6EN)UTI*2![#0H@
M("`@("`@("`@("`@("`@)&UI;ELD9&5P6R=M:6XG75T@/2!C;W5N="@D;6EN
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D9&5P
M6R=M87@G72DI('L-"B`@("`@("`@("`@("`@("`D;6%X6R1D97!;)VUA>"==
M72`](&-O=6YT*"1M87@I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@(&EF("AC;W5N="@D;6EN*2`^(#`I('L-"B`@("`@("`@("`@('5K
M<V]R="@D;6EN+"`G=F5R<VEO;E]C;VUP87)E)RD[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*&-O=6YT*"1M87@I(#X@,"D@>PT*("`@("`@("`@("`@=6MS
M;W)T*"1M87@L("=V97)S:6]N7V-O;7!A<F4G*3L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H8V]U;G0H)&UI;BDI('L-"B`@("`@("`@("`@("\O(&=E="!T
M:&4@:&EG:&5S="!M:6YI;75M#0H@("`@("`@("`@("`D;6EN(#T@87)R87E?
M<&]P*"1A(#T@87)R87E?9FQI<"@D;6EN*2D[#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`D;6EN(#T@9F%L<V4[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*&-O=6YT*"1M87@I*2![#0H@("`@("`@("`@("`O+R!G970@=&AE
M(&QO=V5S="!M87AI;75M#0H@("`@("`@("`@("`D;6%X(#T@87)R87E?<VAI
M9G0H)&$@/2!A<G)A>5]F;&EP*"1M87@I*3L-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("1M87@@/2!F86QS93L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H)&UI;BD@>PT*("`@("`@("`@("`@)'!H<%LG;6EN)UT@/2`D;6EN
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D;6%X*2![#0H@("`@("`@("`@
M("`D<&AP6R=M87@G72`]("1M87@[#0H@("`@("`@('T-"B`@("`@("`@)&5X
M8VQU9&4@/2!A<G)A>2@I.PT*("`@("`@("!F;W)E86-H("@D=&5S="!A<R`D
M9&5P*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1D97!;)V5X8VQU9&4G
M72DI('L-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("1E>&-L=61E6UT@/2`D9&5P6R=E>&-L=61E)UT[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*&-O=6YT*"1E>&-L=61E*2D@>PT*
M("`@("`@("`@("`@)'!H<%LG97AC;'5D92==(#T@)&5X8VQU9&4[#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N("1P:'`[#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@("H@<')O8V5S<R!M=6QT:7!L92!D97!E;F1E;F-I97,@=&AA="!H
M879E(&$@;F%M92P@;&EK92!P86-K86=E(&1E<',-"B`@("`@*B!`<&%R86T@
M87)R87D-"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@("`@("H@0&%C8V5S<R!P
M<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7W!R;V-E<W--=6QT:7!L
M941E<'-.86UE*"1D97!S*0T*("`@('L-"B`@("`@("`@)'1E<W1S(#T@87)R
M87DH*3L-"B`@("`@("`@9F]R96%C:"`H)&1E<',@87,@)&YA;64@/3X@)&1E
M<"D@>PT*("`@("`@("`@("`@9F]R96%C:"`H)&1E<"!A<R`D9"D@>PT*("`@
M("`@("`@("`@("`@("1T97-T<ULD;F%M95U;72`]("1T:&ES+3Y?<')O8V5S
M<T1E<"@D9"D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M9F]R96%C:"`H)'1E<W1S(&%S("1N86UE(#T^("1T97-T*2![#0H@("`@("`@
M("`@("`D<&AP(#T@87)R87DH*3L-"B`@("`@("`@("`@("1M:6X@/2!A<G)A
M>2@I.PT*("`@("`@("`@("`@)&UA>"`](&%R<F%Y*"D[#0H@("`@("`@("`@
M("`D<&AP6R=N86UE)UT@/2`D;F%M93L-"B`@("`@("`@("`@(&9O<F5A8V@@
M*"1T97-T(&%S("1D97`I('L-"B`@("`@("`@("`@("`@("!I9B`H(21D97`I
M('L-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=C:&%N
M;F5L)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1P:'!;)V-H86YN96PG
M72`]("=P96%R+G!H<"YN970G.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG8V]N9FQI8W1S)UTI("8F("1D
M97!;)V-O;F9L:6-T<R==(#T]("=Y97,G*2![#0H@("`@("`@("`@("`@("`@
M("`@("1P:'!;)V-O;F9L:6-T<R==(#T@)WEE<R<[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=M:6XG72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@)&UI;ELD9&5P6R=M:6XG75T@/2!C
M;W5N="@D;6EN*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1D97!;)VUA>"==*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`D;6%X6R1D97!;)VUA>"==72`](&-O=6YT*"1M87@I.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AC
M;W5N="@D;6EN*2`^(#`I('L-"B`@("`@("`@("`@("`@("!U:W-O<G0H)&UI
M;BP@)W9E<G-I;VY?8V]M<&%R92<I.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@:68@*&-O=6YT*"1M87@I(#X@,"D@>PT*("`@("`@("`@("`@("`@
M('5K<V]R="@D;6%X+"`G=F5R<VEO;E]C;VUP87)E)RD[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!I9B`H8V]U;G0H)&UI;BDI('L-"B`@("`@("`@
M("`@("`@("`O+R!G970@=&AE(&AI9VAE<W0@;6EN:6UU;0T*("`@("`@("`@
M("`@("`@("1M:6X@/2!A<G)A>5]P;W`H)&$@/2!A<G)A>5]F;&EP*"1M:6XI
M*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)&UI
M;B`](&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&-O
M=6YT*"1M87@I*2![#0H@("`@("`@("`@("`@("`@+R\@9V5T('1H92!L;W=E
M<W0@;6%X:6UU;0T*("`@("`@("`@("`@("`@("1M87@@/2!A<G)A>5]S:&EF
M="@D82`](&%R<F%Y7V9L:7`H)&UA>"DI.PT*("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`D;6%X(#T@9F%L<V4[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!I9B`H)&UI;BD@>PT*("`@("`@("`@("`@("`@
M("1P:'!;)VUI;B==(#T@)&UI;CL-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(&EF("@D;6%X*2![#0H@("`@("`@("`@("`@("`@)'!H<%LG;6%X)UT@
M/2`D;6%X.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&5X8VQU9&4@
M/2!A<G)A>2@I.PT*("`@("`@("`@("`@9F]R96%C:"`H)'1E<W0@87,@)&1E
M<"D@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&1E<%LG97AC;'5D
M92==*2D@>PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&5X8VQU9&5;72`]("1D
M97!;)V5X8VQU9&4G73L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF
M("AC;W5N="@D97AC;'5D92DI('L-"B`@("`@("`@("`@("`@("`D<&AP6R=E
M>&-L=61E)UT@/2`D97AC;'5D93L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("1R971;72`]("1P:'`[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N
M("1R970[#0H@("`@?0T*?0T*/SX`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+U!A8VMA9V5&:6QE+U!A<G-E
M<@``````````````````````````````````````````````````````````
M`````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U
M-#,S-S,R(#`R,C4R-``@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O
M4&%C:V%G949I;&4O4&%R<V5R+W8R+G!H<```````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#8W-S`@,3`U,34T,S,W,S(@,#(S-C4U`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP#0HO*BH-"B`J('!A
M8VMA9V4N>&UL('!A<G-I;F<@8VQA<W,L('!A8VMA9V4N>&UL('9E<G-I;VX@
M,BXP#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%
M3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S
M+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%52
M23H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)
M9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,
M:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H
M92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N
M;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@
M*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*
M("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*
M("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L
M:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@
M(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z('8R
M+G!H<"QV(#$N,3D@,C`P-B\P,2\R,R`Q-SHS.3HU,B!C96QL;V<@17AP("0-
M"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]0
M14%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE
M87-E(#$N-"XP83$-"B`J+PT*+RHJ#0H@*B!B87-E('AM;"!P87)S97(@8VQA
M<W,-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2+UA-3%!A<G-E<BYP:'`G.PT*
M<F5Q=6ER95]O;F-E("=014%2+U!A8VMA9V5&:6QE+W8R+G!H<"<[#0HO*BH-
M"B`J(%!A<G-E<B!F;W(@<&%C:V%G92YX;6P@=F5R<VEO;B`R+C`-"B`J($!C
M871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H
M;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y
M<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@
M("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC
M96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z($!014%2+59%4D`-
M"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]0
M14%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L
M96%S92`Q+C0N,&$Q#0H@*B\-"F-L87-S(%!%05)?4&%C:V%G949I;&5?4&%R
M<V5R7W8R(&5X=&5N9',@4$5!4E]834Q087)S97(-"GL-"B`@("!V87(@)%]C
M;VYF:6<[#0H@("`@=F%R("1?;&]G9V5R.PT*("`@('9A<B`D7W)E9VES=')Y
M.PT*#0H@("`@9G5N8W1I;VX@<V5T0V]N9FEG*"8D8RD-"B`@("![#0H@("`@
M("`@("1T:&ES+3Y?8V]N9FEG(#T@)B1C.PT*("`@("`@("`D=&AI<RT^7W)E
M9VES=')Y(#T@)B1C+3YG971296=I<W1R>2@I.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N('-E=$QO9V=E<B@F)&PI#0H@("`@>PT*("`@("`@("`D=&AI<RT^
M7VQO9V=E<B`]("8D;#L-"B`@("!]#0H@("`@+RHJ#0H@("`@("H@56YI;F1E
M;G0@9VEV96X@<W1R:6YG#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1S='(@5&AE('-T<FEN9R!T:&%T(&AA<R!T;R!B92!U;FEN9&5N=&5D+@T*
M("`@("`J($!R971U<FX@<W1R:6YG#0H@("`@("H@0&%C8V5S<R!P<FEV871E
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7W5N26YD96YT*"1S='(I#0H@("`@
M>PT*("`@("`@("`O+R!R96UO=F4@;&5A9&EN9R!N97=L:6YE<PT*("`@("`@
M("`D<W1R(#T@<')E9U]R97!L86-E*"<O7EM<<EQN72LO)RP@)R<L("1S='(I
M.PT*("`@("`@("`O+R!F:6YD('=H:71E<W!A8V4@870@=&AE(&)E9VEN;FEN
M9R!O9B!T:&4@9FER<W0@;&EN90T*("`@("`@("`D:6YD96YT7VQE;B`]('-T
M<G-P;B@D<W1R+"`B(%QT(BD[#0H@("`@("`@("1I;F1E;G0@/2!S=6)S='(H
M)'-T<BP@,"P@)&EN9&5N=%]L96XI.PT*("`@("`@("`D9&%T82`]("<G.PT*
M("`@("`@("`O+R!R96UO=F4@=&AE('-A;64@86UO=6YT(&]F('=H:71E<W!A
M8V4@9G)O;2!F;VQL;W=I;F<@;&EN97,-"B`@("`@("`@9F]R96%C:"`H97AP
M;&]D92@B7&XB+"`D<W1R*2!A<R`D;&EN92D@>PT*("`@("`@("`@("`@:68@
M*'-U8G-T<B@D;&EN92P@,"P@)&EN9&5N=%]L96XI(#T]("1I;F1E;G0I('L-
M"B`@("`@("`@("`@("`@("`D9&%T82`N/2!S=6)S='(H)&QI;F4L("1I;F1E
M;G1?;&5N*2`N(")<;B([#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N("1D871A.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J
M('!O<W0M<')O8V5S<R!D871A#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1D871A#0H@("`@("H@0'!A<F%M('-T<FEN9R`D96QE;65N="!E;&5M
M96YT(&YA;64-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!P;W-T4')O8V5S<R@D
M9&%T82P@)&5L96UE;G0I#0H@("`@>PT*("`@("`@("!I9B`H)&5L96UE;G0@
M/3T@)VYO=&5S)RD@>PT*("`@("`@("`@("`@<F5T=7)N('1R:6TH)'1H:7,M
M/E]U;DEN9&5N="@D9&%T82DI.PT*("`@("`@("!]#0H@("`@("`@(')E='5R
M;B!T<FEM*"1D871A*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R
M86T@<W1R:6YG#0H@("`@("H@0'!A<F%M('-T<FEN9R!F:6QE(&YA;64@;V8@
M=&AE('!A8VMA9V4N>&UL#0H@("`@("H@0'!A<F%M('-T<FEN9WQF86QS92!N
M86UE(&]F('1H92!A<F-H:79E('1H:7,@<&%C:V%G92YX;6P@8V%M92!F<F]M
M+"!I9B!A;GD-"B`@("`@*B!`<&%R86T@<W1R:6YG(&-L87-S(&YA;64@=&\@
M:6YS=&%N=&EA=&4@86YD(')E='5R;BX@(%1H:7,@;75S="!B92!014%27U!A
M8VMA9V5&:6QE7W8R(&]R#0H@("`@("H@("`@("`@("`@("`@("!A('-U8F-L
M87-S#0H@("`@("H@0')E='5R;B!014%27U!A8VMA9V5&:6QE7W8R#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@)G!A<G-E*"1D871A+"`D9FEL92P@)&%R8VAI
M=F4@/2!F86QS92P@)&-L87-S(#T@)U!%05)?4&%C:V%G949I;&5?=C(G*0T*
M("`@('L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<B`]('!A<F5N
M=#HZ<&%R<V4H)&1A=&$L("1F:6QE*2DI('L-"B`@("`@("`@("`@(')E='5R
M;B`D97)R.PT*("`@("`@("!]#0H@("`@("`@("1R970@/2!N97<@)&-L87-S
M.PT*("`@("`@("`D<F5T+3YS971#;VYF:6<H)'1H:7,M/E]C;VYF:6<I.PT*
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]L;V=G97(I*2![#0H@("`@("`@
M("`@("`D<F5T+3YS971,;V=G97(H)'1H:7,M/E]L;V=G97(I.PT*("`@("`@
M("!]#0H@("`@("`@("1R970M/F9R;VU!<G)A>2@D=&AI<RT^7W5N<V5R:6%L
M:7IE9$1A=&$I.PT*("`@("`@("`D<F5T+3YS971086-K86=E9FEL92@D9FEL
M92P@)&%R8VAI=F4I.PT*("`@("`@("!R971U<FX@)')E=#L-"B`@("!]#0I]
M#0H_/@``````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2
M+U!A8VMA9V5&:6QE+U!A<G-E<B]V,2YP:'``````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#0Q-3<P(#$P-3$U-#,S-S,R(#`R,S8U,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`T*+RHJ#0H@*B!P
M86-K86=E+GAM;"!P87)S:6YG(&-L87-S+"!P86-K86=E+GAM;"!V97)S:6]N
M(#$N,`T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#
M14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@
M,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@
M=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!5
M4DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@
M268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@
M3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T
M:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP
M+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*
M("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-
M"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-
M"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`
M;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT
M("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!V
M,2YP:'`L=B`Q+C(Q(#(P,#8O,#$O,#8@,#0Z-#<Z,S<@8V5L;&]G($5X<"`D
M#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O
M4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L
M96%S92`Q+C0N,&$Q#0H@*B\-"B\J*@T*("H@<&%C:V%G92YX;6P@86)S=')A
M8W1I;VX@8VQA<W,-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2+U!A8VMA9V5&
M:6QE+W8Q+G!H<"<[#0HO*BH-"B`J(%!A<G-E<B!F;W(@<&%C:V%G92YX;6P@
M=F5R<VEO;B`Q+C`-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E
M("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`
M<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R
M;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E
M;&5A<V4Z($!014%2+59%4D`-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R
M+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A
M=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"F-L87-S(%!%
M05)?4&%C:V%G949I;&5?4&%R<V5R7W8Q#0I[#0H@("`@=F%R("1?<F5G:7-T
M<GD[#0H@("`@=F%R("1?8V]N9FEG.PT*("`@('9A<B`D7VQO9V=E<CL-"B`@
M("`O*BH-"B`@("`@*B!"0R!H86-K('1O(&%L;&]W(%!%05)?0V]M;6]N.CII
M;F9O1G)O;5-T<FEN9R@I('1O('-O<G0@;V8-"B`@("`@*B!W;W)K('=I=&@@
M=&AE('9E<G-I;VX@,BXP(&9O<FUA="`M('1H97)E)W,@;F\@9FEL96QI<W0@
M=&AO=6=H#0H@("`@("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C(-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!F<F]M5C(H)'!A8VMA9V5F:6QE*0T*("`@
M('L-"B`@("`@("`@)&EN9F\@/2`D<&%C:V%G969I;&4M/F=E=$%R<F%Y*'1R
M=64I.PT*("`@("`@("`D<F5T(#T@;F5W(%!%05)?4&%C:V%G949I;&5?=C$[
M#0H@("`@("`@("1R970M/F9R;VU!<G)A>2@D:6YF;ULG;VQD)UTI.PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N('-E=$-O;F9I9R@F)&,I#0H@("`@>PT*("`@
M("`@("`D=&AI<RT^7V-O;F9I9R`]("8D8SL-"B`@("`@("`@)'1H:7,M/E]R
M96=I<W1R>2`]("8D8RT^9V5T4F5G:7-T<GDH*3L-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!S971,;V=G97(H)B1L*0T*("`@('L-"B`@("`@("`@)'1H:7,M
M/E]L;V=G97(@/2`F)&P[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A
M<F%M('-T<FEN9R!C;VYT96YT<R!O9B!P86-K86=E+GAM;"!F:6QE+"!V97)S
M:6]N(#$N,`T*("`@("`J($!R971U<FX@8F]O;"!S=6-C97-S(&]F('!A<G-I
M;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!P87)S92@D9&%T82P@)&9I;&4L
M("1A<F-H:79E(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H(65X=&5N
M<VEO;E]L;V%D960H)WAM;"<I*2![#0H@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@G0V%N;F]T(&-R96%T92!X;6P@<&%R<V5R(&9O<B!P
M87)S:6YG('!A8VMA9V4N>&UL+"!N;R!X;6P@97AT96YS:6]N)RD[#0H@("`@
M("`@('T-"B`@("`@("`@)'AP(#T@0'AM;%]P87)S97)?8W)E871E*"D[#0H@
M("`@("`@(&EF("@A)'AP*2![#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@G0V%N;F]T(&-R96%T92!X;6P@<&%R<V5R(&9O<B!P87)S
M:6YG('!A8VMA9V4N>&UL)RD[#0H@("`@("`@('T-"B`@("`@("`@>&UL7W-E
M=%]O8FIE8W0H)'AP+"`D=&AI<RD[#0H@("`@("`@('AM;%]S971?96QE;65N
M=%]H86YD;&5R*"1X<"P@)U]E;&5M96YT7W-T87)T7S%?,"<L("=?96QE;65N
M=%]E;F1?,5\P)RD[#0H@("`@("`@('AM;%]S971?8VAA<F%C=&5R7V1A=&%?
M:&%N9&QE<B@D>'`L("=?<&MG:6YF;U]C9&%T85\Q7S`G*3L-"B`@("`@("`@
M>&UL7W!A<G-E<E]S971?;W!T:6]N*"1X<"P@6$U,7T]05$E/3E]#05-%7T9/
M3$1)3D<L(&9A;'-E*3L-"@T*("`@("`@("`D=&AI<RT^96QE;65N=%]S=&%C
M:R`](&%R<F%Y*"D[#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2!A
M<G)A>2@G<')O=FED97,G(#T^(&%R<F%Y*"DI.PT*("`@("`@("`D=&AI<RT^
M8W5R<F5N=%]E;&5M96YT(#T@9F%L<V4[#0H@("`@("`@('5N<V5T*"1T:&ES
M+3YD:7)?:6YS=&%L;"D[#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];
M)V9I;&5L:7-T)UT@/2!A<G)A>2@I.PT*("`@("`@("`D=&AI<RT^9FEL96QI
M<W0@/28@)'1H:7,M/E]P86-K86=E26YF;ULG9FEL96QI<W0G73L-"B`@("`@
M("`@)'1H:7,M/F1I<E]N86UE<R`](&%R<F%Y*"D[#0H@("`@("`@("1T:&ES
M+3YI;E]C:&%N9V5L;V<@/2!F86QS93L-"B`@("`@("`@)'1H:7,M/F1?:2`]
M(#`[#0H@("`@("`@("1T:&ES+3YC9&%T82`]("<G.PT*("`@("`@("`D=&AI
M<RT^7VES5F%L:60@/2!T<G5E.PT*#0H@("`@("`@(&EF("@A>&UL7W!A<G-E
M*"1X<"P@)&1A=&$L(#$I*2![#0H@("`@("`@("`@("`D8V]D92`]('AM;%]G
M971?97)R;W)?8V]D92@D>'`I.PT*("`@("`@("`@("`@)&QI;F4@/2!X;6Q?
M9V5T7V-U<G)E;G1?;&EN95]N=6UB97(H)'AP*3L-"B`@("`@("`@("`@('AM
M;%]P87)S97)?9G)E92@D>'`I.PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H<W!R:6YT9B@B6$U,(&5R<F]R.B`E<R!A="!L:6YE("5D
M(BP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1S='(@/2!X;6Q?97)R
M;W)?<W1R:6YG*"1C;V1E*2P@)&QI;F4I+"`R*3L-"B`@("`@("`@?0T*#0H@
M("`@("`@('AM;%]P87)S97)?9G)E92@D>'`I.PT*#0H@("`@("`@("1P9B`]
M(&YE=R!014%27U!A8VMA9V5&:6QE7W8Q.PT*("`@("`@("`D<&8M/G-E=$-O
M;F9I9R@D=&AI<RT^7V-O;F9I9RD[#0H@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^7VQO9V=E<BDI('L-"B`@("`@("`@("`@("1P9BT^<V5T3&]G9V5R*"1T
M:&ES+3Y?;&]G9V5R*3L-"B`@("`@("`@?0T*("`@("`@("`D<&8M/G-E=%!A
M8VMA9V5F:6QE*"1F:6QE+"`D87)C:&EV92D[#0H@("`@("`@("1P9BT^9G)O
M;4%R<F%Y*"1T:&ES+3Y?<&%C:V%G94EN9F\I.PT*("`@("`@("!R971U<FX@
M)'!F.PT*("`@('T-"B`@("`O+R![>WL@7W5N26YD96YT*"D-"@T*("`@("\J
M*@T*("`@("`J(%5N:6YD96YT(&=I=F5N('-T<FEN9PT*("`@("`J#0H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<W1R(%1H92!S=')I;F<@=&AA="!H87,@=&\@
M8F4@=6YI;F1E;G1E9"X-"B`@("`@*B!`<F5T=7)N('-T<FEN9PT*("`@("`J
M($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]U;DEN
M9&5N="@D<W1R*0T*("`@('L-"B`@("`@("`@+R\@<F5M;W9E(&QE861I;F<@
M;F5W;&EN97,-"B`@("`@("`@)'-T<B`]('!R96=?<F5P;&%C92@G+UY;7')<
M;ETK+R<L("<G+"`D<W1R*3L-"B`@("`@("`@+R\@9FEN9"!W:&ET97-P86-E
M(&%T('1H92!B96=I;FYI;F<@;V8@=&AE(&9I<G-T(&QI;F4-"B`@("`@("`@
M)&EN9&5N=%]L96X@/2!S=')S<&XH)'-T<BP@(B!<="(I.PT*("`@("`@("`D
M:6YD96YT(#T@<W5B<W1R*"1S='(L(#`L("1I;F1E;G1?;&5N*3L-"B`@("`@
M("`@)&1A=&$@/2`G)SL-"B`@("`@("`@+R\@<F5M;W9E('1H92!S86UE(&%M
M;W5N="!O9B!W:&ET97-P86-E(&9R;VT@9F]L;&]W:6YG(&QI;F5S#0H@("`@
M("`@(&9O<F5A8V@@*&5X<&QO9&4H(EQN(BP@)'-T<BD@87,@)&QI;F4I('L-
M"B`@("`@("`@("`@(&EF("AS=6)S='(H)&QI;F4L(#`L("1I;F1E;G1?;&5N
M*2`]/2`D:6YD96YT*2![#0H@("`@("`@("`@("`@("`@)&1A=&$@+CT@<W5B
M<W1R*"1L:6YE+"`D:6YD96YT7VQE;BD@+B`B7&XB.PT*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D9&%T83L-"B`@("!]#0H-
M"B`@("`O+R!3=7!P;W)T(&9O<B!P86-K86=E($141"!V,2XP.@T*("`@("\O
M('M[>R!?96QE;65N=%]S=&%R=%\Q7S`H*0T*#0H@("`@+RHJ#0H@("`@("H@
M6$U,('!A<G-E<B!C86QL8F%C:R!F;W(@96YD:6YG(&5L96UE;G1S+B`@57-E
M9"!F;W(@=F5R<VEO;B`Q+C`-"B`@("`@*B!P86-K86=E<RX-"B`@("`@*@T*
M("`@("`J($!P87)A;2!R97-O=7)C92`@)'AP("`@(%A-3"!P87)S97(@<F5S
M;W5R8V4-"B`@("`@*B!`<&%R86T@<W1R:6YG("`@("1N86UE("!N86UE(&]F
M(&5N9&EN9R!E;&5M96YT#0H@("`@("H-"B`@("`@*B!`<F5T=7)N('9O:60-
M"B`@("`@*@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@
M(&9U;F-T:6]N(%]E;&5M96YT7W-T87)T7S%?,"@D>'`L("1N86UE+"`D871T
M<FEB<RD-"B`@("![#0H@("`@("`@(&%R<F%Y7W!U<V@H)'1H:7,M/F5L96UE
M;G1?<W1A8VLL("1N86UE*3L-"B`@("`@("`@)'1H:7,M/F-U<G)E;G1?96QE
M;65N="`]("1N86UE.PT*("`@("`@("`D<W!O<R`]('-I>F5O9B@D=&AI<RT^
M96QE;65N=%]S=&%C:RD@+2`R.PT*("`@("`@("`D=&AI<RT^<')E=E]E;&5M
M96YT(#T@*"1S<&]S(#X](#`I(#\@)'1H:7,M/F5L96UE;G1?<W1A8VM;)'-P
M;W-=(#H@)R<[#0H@("`@("`@("1T:&ES+3YC=7)R96YT7V%T=')I8G5T97,@
M/2`D871T<FEB<SL-"B`@("`@("`@)'1H:7,M/F-D871A(#T@)R<[#0H@("`@
M("`@('-W:71C:"`H)&YA;64I('L-"B`@("`@("`@("`@(&-A<V4@)V1I<B<Z
M#0H@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YI;E]C:&%N9V5L;V<I('L-
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"=N86UE
M)RP@)&%T=')I8G,I("8F("1A='1R:6)S6R=N86UE)UT@(3T@)R\G*2![#0H@
M("`@("`@("`@("`@("`@("`@("1A='1R:6)S6R=N86UE)UT@/2!P<F5G7W)E
M<&QA8V4H87)R87DH)R%<7%Q<*R$G+"`G(2\K(2<I+"!A<G)A>2@G+R<L("<O
M)RDL#0H@("`@("`@("`@("`@("`@("`@("`@("`D871T<FEB<ULG;F%M92==
M*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*'-T<G)P;W,H)&%T=')I8G-;
M)VYA;64G72P@)R\G*2`]/2!S=')L96XH)&%T=')I8G-;)VYA;64G72D@+2`Q
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D871T<FEB<ULG;F%M92==
M(#T@<W5B<W1R*"1A='1R:6)S6R=N86UE)UTL(#`L#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@<W1R;&5N*"1A='1R:6)S6R=N86UE)UTI("T@,2D[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M:68@*'-T<G!O<R@D871T<FEB<ULG;F%M92==+"`G+R<I(#T]/2`P*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D871T<FEB<ULG;F%M92==(#T@<W5B
M<W1R*"1A='1R:6)S6R=N86UE)UTL(#$I.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YD:7)?;F%M97-;72`]
M("1A='1R:6)S6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D871T<FEB<ULG8F%S96EN<W1A;&QD:7(G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F1I<E]I;G-T86QL
M(#T@)&%T=')I8G-;)V)A<V5I;G-T86QL9&ER)UT[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D871T<FEB<ULG<F]L
M92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9&ER7W)O;&4@
M/2`D871T<FEB<ULG<F]L92==.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)V9I;&4G.@T*
M("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^:6Y?8VAA;F=E;&]G*2![#0H@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&%T=')I8G-;)VYA;64G72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@)'!A=&@@/2`G)SL-"B`@("`@("`@
M("`@("`@("`@("`@:68@*&-O=6YT*"1T:&ES+3YD:7)?;F%M97,I*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^9&ER7VYA
M;65S(&%S("1D:7(I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<&%T:"`N/2`D9&ER("X@)R\G.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("1P871H("X]('!R96=?<F5P;&%C92AA<G)A>2@G(5Q<7%PK(2<L("<A+RLA
M)RDL(&%R<F%Y*"<O)RP@)R\G*2P-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1A='1R:6)S6R=N86UE)UTI.PT*("`@("`@("`@("`@("`@("`@("!U;G-E
M="@D871T<FEB<ULG;F%M92==*3L-"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/F-U<G)E;G1?<&%T:"`]("1P871H.PT*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^9FEL96QI<W1;)'!A=&A=(#T@)&%T=')I8G,[#0H@("`@("`@
M("`@("`@("`@("`@("\O(%-E="!T:&4@8F%S96EN<W1A;&QD:7(@;VYL>2!I
M9B!T:&4@9FEL92!D;VXG="!H879E('1H:7,@871T<FEB#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/F9I;&5L:7-T6R1P871H75LG
M8F%S96EN<W1A;&QD:7(G72D@)B8-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&ES<V5T*"1T:&ES+3YD:7)?:6YS=&%L;"DI#0H@("`@("`@("`@("`@("`@
M("`@('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YF:6QE;&ES
M=%LD<&%T:%U;)V)A<V5I;G-T86QL9&ER)UT@/2`D=&AI<RT^9&ER7VEN<W1A
M;&P[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@+R\@4V5T('1H92!2;VQE#0H@("`@("`@("`@("`@("`@("`@(&EF("@A
M:7-S970H)'1H:7,M/F9I;&5L:7-T6R1P871H75LG<F]L92==*2`F)B!I<W-E
M="@D=&AI<RT^9&ER7W)O;&4I*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^9FEL96QI<W1;)'!A=&A=6R=R;VQE)UT@/2`D=&AI<RT^9&ER
M7W)O;&4[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E
M("=R97!L86-E)SH-"B`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3YI;E]C
M:&%N9V5L;V<I('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F9I;&5L
M:7-T6R1T:&ES+3YC=7)R96YT7W!A=&A=6R=R97!L86-E;65N=',G75M=(#T@
M)&%T=')I8G,[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G;6%I;G1A:6YE<G,G.@T*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)VUA:6YT86EN97)S
M)UT@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@("1T:&ES+3YM7VD@/2`P
M.R`O+R!M86EN=&%I;F5R<R!A<G)A>2!I;F1E>`T*("`@("`@("`@("`@("`@
M(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G;6%I;G1A:6YE<B<Z#0H@("`@
M("`@("`@("`@("`@+R\@8V]M<&%T:6)I;&ET>2!C:&5C:PT*("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG;6%I;G1A
M:6YE<G,G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K
M86=E26YF;ULG;6%I;G1A:6YE<G,G72`](&%R<F%Y*"D[#0H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YM7VD@/2`P.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=M86EN=&%I
M;F5R<R==6R1T:&ES+3YM7VE=(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^8W5R<F5N=%]M86EN=&%I;F5R(#TF("1T:&ES+3Y?<&%C:V%G
M94EN9F];)VUA:6YT86EN97)S)UU;)'1H:7,M/FU?:5T[#0H@("`@("`@("`@
M("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=C:&%N9V5L;V<G.@T*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V-H86YG96QO
M9R==(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@("`D=&AI<RT^8U]I(#T@
M,#L@+R\@8VAA;F=E;&]G(&%R<F%Y(&EN9&5X#0H@("`@("`@("`@("`@("`@
M)'1H:7,M/FEN7V-H86YG96QO9R`]('1R=64[#0H@("`@("`@("`@("`@("`@
M8G)E86L[#0H@("`@("`@("`@("!C87-E("=R96QE87-E)SH-"B`@("`@("`@
M("`@("`@("!I9B`H)'1H:7,M/FEN7V-H86YG96QO9RD@>PT*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=C:&%N9V5L;V<G75LD
M=&AI<RT^8U]I72`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YC=7)R96YT7W)E;&5A<V4@/2`F)'1H:7,M/E]P86-K86=E26YF;ULG
M8VAA;F=E;&]G)UU;)'1H:7,M/F-?:5T[#0H@("`@("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-U<G)E;G1?<F5L
M96%S92`]("8D=&AI<RT^7W!A8VMA9V5);F9O.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@
M)V1E<',G.@T*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/FEN7V-H86YG
M96QO9RD@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=R96QE87-E7V1E<',G72`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S
M92`G9&5P)SH-"B`@("`@("`@("`@("`@("`O+R!D97!E;F1E;F-I97,@87)R
M87D@:6YD97@-"B`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3YI;E]C:&%N
M9V5L;V<I('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F1?:2LK.PT*
M("`@("`@("`@("`@("`@("`@("!I<W-E="@D871T<FEB<ULG='EP92==*2`_
M("@D871T<FEB<ULG='EP92==(#T@<W1R=&]L;W=E<B@D871T<FEB<ULG='EP
M92==*2D@.B!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M86-K86=E26YF;ULG<F5L96%S95]D97!S)UU;)'1H:7,M/F1?:5T@/2`D871T
M<FEB<SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@8G)E
M86L[#0H@("`@("`@("`@("!C87-E("=C;VYF:6=U<F5O<'1I;VYS)SH-"B`@
M("`@("`@("`@("`@("!I9B`H(21T:&ES+3YI;E]C:&%N9V5L;V<I('L-"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG8V]N9FEG
M=7)E7V]P=&EO;G,G72`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G8V]N
M9FEG=7)E;W!T:6]N)SH-"B`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3YI
M;E]C:&%N9V5L;V<I('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M86-K86=E26YF;ULG8V]N9FEG=7)E7V]P=&EO;G,G75M=(#T@)&%T=')I8G,[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&)R96%K.PT*
M("`@("`@("`@("`@8V%S92`G<')O=FED97,G.@T*("`@("`@("`@("`@("`@
M(&EF("AE;7!T>2@D871T<FEB<ULG='EP92==*2!\?"!E;7!T>2@D871T<FEB
M<ULG;F%M92==*2D@>PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&%T=')I8G-;)V5X
M<&QI8VET)UT@/2!T<G5E.PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C
M:V%G94EN9F];)W!R;W9I9&5S)UU;(B1A='1R:6)S6W1Y<&5=.R1A='1R:6)S
M6VYA;65=(ET@/2`D871T<FEB<SL-"B`@("`@("`@("`@("`@("!B<F5A:SL-
M"B`@("`@("`@("`@(&-A<V4@)W!A8VMA9V4G(#H-"B`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)&%T=')I8G-;)W9E<G-I;VXG72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG>'-D=F5R<VEO;B==
M(#T@=')I;2@D871T<FEB<ULG=F5R<VEO;B==*3L-"B`@("`@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA
M9V5);F9O6R=X<V1V97)S:6]N)UT@/2`G,2XP)SL-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A='1R:6)S6R=P86-K
M86=E<G9E<G-I;VXG72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]P86-K86=E26YF;ULG<&%C:V%G97)V97)S:6]N)UT@/2`D871T<FEB<ULG
M<&%C:V%G97)V97)S:6]N)UT[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+R\@
M?7U]#0H@("`@+R\@>WM[(%]E;&5M96YT7V5N9%\Q7S`H*0T*#0H@("`@+RHJ
M#0H@("`@("H@6$U,('!A<G-E<B!C86QL8F%C:R!F;W(@96YD:6YG(&5L96UE
M;G1S+B`@57-E9"!F;W(@=F5R<VEO;B`Q+C`-"B`@("`@*B!P86-K86=E<RX-
M"B`@("`@*@T*("`@("`J($!P87)A;2!R97-O=7)C92`@)'AP("`@(%A-3"!P
M87)S97(@<F5S;W5R8V4-"B`@("`@*B!`<&%R86T@<W1R:6YG("`@("1N86UE
M("!N86UE(&]F(&5N9&EN9R!E;&5M96YT#0H@("`@("H-"B`@("`@*B!`<F5T
M=7)N('9O:60-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@
M("`J+PT*("`@(&9U;F-T:6]N(%]E;&5M96YT7V5N9%\Q7S`H)'AP+"`D;F%M
M92D-"B`@("![#0H@("`@("`@("1D871A(#T@=')I;2@D=&AI<RT^8V1A=&$I
M.PT*("`@("`@("!S=VET8V@@*"1N86UE*2![#0H@("`@("`@("`@("!C87-E
M("=N86UE)SH-"B`@("`@("`@("`@("`@("!S=VET8V@@*"1T:&ES+3YP<F5V
M7V5L96UE;G0I('L-"B`@("`@("`@("`@("`@("`@("`@8V%S92`G<&%C:V%G
M92<Z#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=P86-K86=E)UT@/2`D9&%T83L-"B`@("`@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PT*("`@("`@("`@("`@("`@("`@("!C87-E("=M86EN=&%I
M;F5R)SH-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC=7)R96YT
M7VUA:6YT86EN97);)VYA;64G72`]("1D871A.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G97AT96YD<R<@.@T*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V5X=&5N9',G
M72`]("1D871A.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@
M("`@8V%S92`G<W5M;6%R>2<Z#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M86-K86=E26YF;ULG<W5M;6%R>2==(#T@)&1A=&$[#0H@("`@("`@("`@("`@
M("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=D97-C<FEP=&EO;B<Z#0H@
M("`@("`@("`@("`@("`@)&1A=&$@/2`D=&AI<RT^7W5N26YD96YT*"1T:&ES
M+3YC9&%T82D[#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF
M;ULG9&5S8W)I<'1I;VXG72`]("1D871A.PT*("`@("`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@8V%S92`G=7-E<B<Z#0H@("`@("`@("`@("`@
M("`@)'1H:7,M/F-U<G)E;G1?;6%I;G1A:6YE<ELG:&%N9&QE)UT@/2`D9&%T
M83L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@
M)V5M86EL)SH-"B`@("`@("`@("`@("`@("`D=&AI<RT^8W5R<F5N=%]M86EN
M=&%I;F5R6R=E;6%I;"==(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@8G)E
M86L[#0H@("`@("`@("`@("!C87-E("=R;VQE)SH-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^8W5R<F5N=%]M86EN=&%I;F5R6R=R;VQE)UT@/2`D9&%T83L-
M"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)W9E
M<G-I;VXG.@T*("`@("`@("`@("`@("`@("\O)&1A=&$@/2!E<F5G7W)E<&QA
M8V4@*"=;7F$M>D$M6C`M.2Y?7"U=)RP@)U\G+"`D9&%T82D[#0H@("`@("`@
M("`@("`@("`@:68@*"1T:&ES+3YI;E]C:&%N9V5L;V<I('L-"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/F-U<G)E;G1?<F5L96%S95LG=F5R<VEO;B==
M(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG=F5R<VEO;B==(#T@
M)&1A=&$[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@8V%S92`G9&%T92<Z#0H@("`@("`@("`@("`@
M("`@:68@*"1T:&ES+3YI;E]C:&%N9V5L;V<I('L-"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/F-U<G)E;G1?<F5L96%S95LG<F5L96%S95]D871E)UT@
M/2`D9&%T83L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=R96QE87-E7V1A=&4G
M72`]("1D871A.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)VYO=&5S)SH-"B`@("`@("`@
M("`@("`@("`O+R!T<GD@=&\@(F1E+6EN9&5N="(@<F5L96%S92!N;W1E<R!I
M;B!C87-E('-O;65O;F4-"B`@("`@("`@("`@("`@("`O+R!H87,@8F5E;B!O
M=F5R+6EN9&5N=&EN9R!T:&5I<B!X;6P@.RTI#0H@("`@("`@("`@("`@("`@
M)&1A=&$@/2`D=&AI<RT^7W5N26YD96YT*"1T:&ES+3YC9&%T82D[#0H@("`@
M("`@("`@("`@("`@:68@*"1T:&ES+3YI;E]C:&%N9V5L;V<I('L-"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/F-U<G)E;G1?<F5L96%S95LG<F5L96%S
M95]N;W1E<R==(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG<F5L
M96%S95]N;W1E<R==(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G=V%R;FEN
M9W,G.@T*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^:6Y?8VAA;F=E;&]G
M*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC=7)R96YT7W)E;&5A
M<V5;)W)E;&5A<V5?=V%R;FEN9W,G72`]("1D871A.PT*("`@("`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C
M:V%G94EN9F];)W)E;&5A<V5?=V%R;FEN9W,G72`]("1D871A.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M("`@(&-A<V4@)W-T871E)SH-"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M
M/FEN7V-H86YG96QO9RD@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M8W5R<F5N=%]R96QE87-E6R=R96QE87-E7W-T871E)UT@/2`D9&%T83L-"B`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!A8VMA9V5);F9O6R=R96QE87-E7W-T871E)UT@/2`D9&%T83L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@
M("`@("`@("`@("!C87-E("=L:6-E;G-E)SH-"B`@("`@("`@("`@("`@("!I
M9B`H)'1H:7,M/FEN7V-H86YG96QO9RD@>PT*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^8W5R<F5N=%]R96QE87-E6R=R96QE87-E7VQI8V5N<V4G72`]
M("1D871A.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)W)E;&5A<V5?;&EC96YS
M92==(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G9&5P)SH-"B`@("`@("`@
M("`@("`@("!I9B`H)&1A=&$@)B8@(21T:&ES+3YI;E]C:&%N9V5L;V<I('L-
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG<F5L
M96%S95]D97!S)UU;)'1H:7,M/F1?:5U;)VYA;64G72`]("1D871A.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@
M("`@("`@(&-A<V4@)V1I<B<Z#0H@("`@("`@("`@("`@("`@:68@*"1T:&ES
M+3YI;E]C:&%N9V5L;V<I('L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&%R<F%Y7W!O
M<"@D=&AI<RT^9&ER7VYA;65S*3L-"B`@("`@("`@("`@("`@("!B<F5A:SL-
M"B`@("`@("`@("`@(&-A<V4@)V9I;&4G.@T*("`@("`@("`@("`@("`@(&EF
M("@D=&AI<RT^:6Y?8VAA;F=E;&]G*2![#0H@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I
M9B`H)&1A=&$I('L-"B`@("`@("`@("`@("`@("`@("`@)'!A=&@@/2`G)SL-
M"B`@("`@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1T:&ES+3YD:7)?;F%M
M97,I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D=&AI
M<RT^9&ER7VYA;65S(&%S("1D:7(I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<&%T:"`N/2`D9&ER("X@)R\G.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("1P871H("X]("1D871A.PT*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^9FEL96QI<W1;)'!A=&A=(#T@)'1H:7,M/F-U<G)E;G1?871T
M<FEB=71E<SL-"B`@("`@("`@("`@("`@("`@("`@+R\@4V5T('1H92!B87-E
M:6YS=&%L;&1I<B!O;FQY(&EF('1H92!F:6QE(&1O;B=T(&AA=F4@=&AI<R!A
M='1R:6(-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^
M9FEL96QI<W1;)'!A=&A=6R=B87-E:6YS=&%L;&1I<B==*2`F)@T*("`@("`@
M("`@("`@("`@("`@("`@("`@:7-S970H)'1H:7,M/F1I<E]I;G-T86QL*2D-
M"B`@("`@("`@("`@("`@("`@("`@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/F9I;&5L:7-T6R1P871H75LG8F%S96EN<W1A;&QD:7(G72`]
M("1T:&ES+3YD:7)?:6YS=&%L;#L-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`O+R!3970@=&AE(%)O;&4-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^9FEL96QI<W1;)'!A=&A=
M6R=R;VQE)UTI("8F(&ES<V5T*"1T:&ES+3YD:7)?<F]L92DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YF:6QE;&ES=%LD<&%T:%U;)W)O
M;&4G72`]("1T:&ES+3YD:7)?<F]L93L-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!B<F5A:SL-
M"B`@("`@("`@("`@(&-A<V4@)VUA:6YT86EN97(G.@T*("`@("`@("`@("`@
M("`@(&EF("AE;7!T>2@D=&AI<RT^7W!A8VMA9V5);F9O6R=M86EN=&%I;F5R
M<R==6R1T:&ES+3YM7VE=6R=R;VQE)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)VUA:6YT86EN97)S)UU;)'1H:7,M
M/FU?:5U;)W)O;&4G72`]("=L96%D)SL-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@)'1H:7,M/FU?:2LK.PT*("`@("`@("`@("`@("`@
M(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G<F5L96%S92<Z#0H@("`@("`@
M("`@("`@("`@:68@*"1T:&ES+3YI;E]C:&%N9V5L;V<I('L-"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/F-?:2LK.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)V-H
M86YG96QO9R<Z#0H@("`@("`@("`@("`@("`@)'1H:7,M/FEN7V-H86YG96QO
M9R`](&9A;'-E.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("!]
M#0H@("`@("`@(&%R<F%Y7W!O<"@D=&AI<RT^96QE;65N=%]S=&%C:RD[#0H@
M("`@("`@("1S<&]S(#T@<VEZ96]F*"1T:&ES+3YE;&5M96YT7W-T86-K*2`M
M(#$[#0H@("`@("`@("1T:&ES+3YC=7)R96YT7V5L96UE;G0@/2`H)'-P;W,@
M/B`P*2`_("1T:&ES+3YE;&5M96YT7W-T86-K6R1S<&]S72`Z("<G.PT*("`@
M("`@("`D=&AI<RT^8V1A=&$@/2`G)SL-"B`@("!]#0H-"B`@("`O+R!]?7T-
M"B`@("`O+R![>WL@7W!K9VEN9F]?8V1A=&%?,5\P*"D-"@T*("`@("\J*@T*
M("`@("`J(%A-3"!P87)S97(@8V%L;&)A8VL@9F]R(&-H87)A8W1E<B!D871A
M+B`@57-E9"!F;W(@=F5R<VEO;B`Q+C`-"B`@("`@*B!P86-K86=E<RX-"B`@
M("`@*@T*("`@("`J($!P87)A;2!R97-O=7)C92`@)'AP("`@(%A-3"!P87)S
M97(@<F5S;W5R8V4-"B`@("`@*B!`<&%R86T@<W1R:6YG("`@("1N86UE("!C
M:&%R86-T97(@9&%T80T*("`@("`J#0H@("`@("H@0')E='5R;B!V;VED#0H@
M("`@("H-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!?<&MG:6YF;U]C9&%T85\Q7S`H)'AP+"`D9&%T82D-"B`@("![
M#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^8V1A=&$I*2![#0H@("`@("`@
M("`@("`D=&AI<RT^8V1A=&$@+CT@)&1A=&$[#0H@("`@("`@('T-"B`@("!]
M#0H-"B`@("`O+R!]?7T-"GT-"C\^````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O4$5!4B]086-K86=E1FEL92]V,@``````````````````````````
M```````````````````````````````````````````P,#`W-34@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<S,B`P,C$V,3<`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+U!A8VMA9V5&:6QE+W8R+W)W
M+G!H<```````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,38W-#$T(#$P-3$U
M-#,S-S,R(#`R,S`U-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`T*+RHJ#0H@*B!014%27U!A8VMA9V5&:6QE7W8R
M+"!P86-K86=E+GAM;"!V97)S:6]N(#(N,"P@<F5A9"]W<FET92!V97)S:6]N
M#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%
M.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@
M;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O
M=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-
M"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y
M;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E
M;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W
M96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T
M('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*
M("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@
M0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@
M0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E
M;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(
M4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(')W+G!H
M<"QV(#$N,34@,C`P-B\P,2\R."`Q-SHS-3HQ,2!C96QL;V<@17AP("0-"B`J
M($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2
M#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E
M(#$N-"XP83@-"B`J+PT*+RHJ#0H@*B!&;W(@8F%S92!C;&%S<PT*("HO#0IR
M97%U:7)E7V]N8V4@)U!%05(O4&%C:V%G949I;&4O=C(N<&AP)SL-"B\J*@T*
M("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@
M0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@
M0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E
M;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(
M4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-
M"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]0
M14%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L
M96%S92`Q+C0N,&$X#0H@*B\-"F-L87-S(%!%05)?4&%C:V%G949I;&5?=C)?
M<G<@97AT96YD<R!014%27U!A8VMA9V5&:6QE7W8R#0I[#0H@("`@+RHJ#0H@
M("`@("H@0'!A<F%M('-T<FEN9R!%>'1E;G-I;VX@;F%M90T*("`@("`J($!R
M971U<FX@8F]O;"!S=6-C97-S(&]F(&]P97)A=&EO;@T*("`@("`J+PT*("`@
M(&9U;F-T:6]N('-E=%!R;W9I9&5S17AT96YS:6]N*"1E>'1E;G-I;VXI#0H@
M("`@>PT*("`@("`@("!I9B`H:6Y?87)R87DH)'1H:7,M/F=E=%!A8VMA9V54
M>7!E*"DL(&%R<F%Y*"=E>'1S<F,G+"`G97AT8FEN)RDI*2![#0H@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W!R;W9I9&5S
M97AT96YS:6]N)UTI*2![#0H@("`@("`@("`@("`@("`@+R\@96YS=7)E('1H
M870@=&AE(&-H86YN96P@=&%G(&ES('-E="!U<"!I;B!T:&4@<FEG:'0@;&]C
M871I;VX-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O(#T@
M)'1H:7,M/E]I;G-E<G1"969O<F4H)'1H:7,M/E]P86-K86=E26YF;RP-"B`@
M("`@("`@("`@("`@("`@("`@87)R87DH)W5S97-R;VQE)RP@)W5S97-T87-K
M)RP@)W-R8W!A8VMA9V4G+"`G<W)C=7)I)RP@)W!H<')E;&5A<V4G+`T*("`@
M("`@("`@("`@("`@("`@("`G97AT<W)C<F5L96%S92<L("=E>'1B:6YR96QE
M87-E)RP@)V)U;F1L92<L("=C:&%N9V5L;V<G*2P-"B`@("`@("`@("`@("`@
M("`@("`@)&5X=&5N<VEO;BP@)W!R;W9I9&5S97AT96YS:6]N)RD[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=P
M<F]V:61E<V5X=&5N<VEO;B==(#T@)&5X=&5N<VEO;CL-"B`@("`@("`@("`@
M(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS
M93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!S971086-K86=E*"1P86-K86=E
M*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=A='1R:6)S)UTI
M*2![#0H@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O(#T@87)R87E?
M;65R9V4H87)R87DH)V%T=')I8G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W9E<G-I;VXG(#T^("<R+C`G+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)WAM;&YS)R`]/B`G:'1T
M<#HO+W!E87(N<&AP+FYE="]D=&0O<&%C:V%G92TR+C`G+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)WAM;&YS.G1A<VMS)R`]/B`G:'1T
M<#HO+W!E87(N<&AP+FYE="]D=&0O=&%S:W,M,2XP)RP-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=X;6QN<SIX<VDG(#T^("=H='1P.B\O
M=W=W+G<S+F]R9R\R,#`Q+UA-3%-C:&5M82UI;G-T86YC92<L#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G>'-I.G-C:&5M84QO8V%T:6]N
M)R`]/B`G:'1T<#HO+W!E87(N<&AP+FYE="]D=&0O=&%S:W,M,2XP#0H@("`@
M:'1T<#HO+W!E87(N<&AP+FYE="]D=&0O=&%S:W,M,2XP+GAS9`T*("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O9'1D+W!A8VMA9V4M,BXP#0H@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]D=&0O<&%C:V%G92TR+C`N>'-D)RP-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@*2DL("1T:&ES+3Y?<&%C:V%G94EN9F\I
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K
M86=E26YF;ULG;F%M92==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?<&%C:V%G94EN9F\@/2!A<G)A>5]M97)G92AA<G)A>2@G;F%M92<@/3X@
M)'!A8VMA9V4I+`T*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN
M9F\I.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];
M)VYA;64G72`]("1P86-K86=E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E
M=%5R:2@D=7)I*0T*("`@('L-"B`@("`@("`@=6YS970H)'1H:7,M/E]P86-K
M86=E26YF;ULG8VAA;FYE;"==*3L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED
M(#T@,#L-"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O
M6R=U<FDG72DI('L-"B`@("`@("`@("`@("\O(&5N<W5R92!T:&%T('1H92!U
M<FD@=&%G(&ES('-E="!U<"!I;B!T:&4@<FEG:'0@;&]C871I;VX-"B`@("`@
M("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D=&AI<RT^7VEN<V5R=$)E
M9F]R92@D=&AI<RT^7W!A8VMA9V5);F9O+"`-"B`@("`@("`@("`@("`@("!A
M<G)A>2@G97AT96YD<R<L("=S=6UM87)Y)RP@)V1E<V-R:7!T:6]N)RP@)VQE
M860G+`T*("`@("`@("`@("`@("`@("=D979E;&]P97(G+"`G8V]N=')I8G5T
M;W(G+"`G:&5L<&5R)RP@)V1A=&4G+"`G=&EM92<L("=V97)S:6]N)RP-"B`@
M("`@("`@("`@("`@("`G<W1A8FEL:71Y)RP@)VQI8V5N<V4G+"`G;F]T97,G
M+"`G8V]N=&5N=',G+"`G8V]M<&%T:6)L92<L#0H@("`@("`@("`@("`@("`@
M)V1E<&5N9&5N8VEE<R<L("=P<F]V:61E<V5X=&5N<VEO;B<L("=U<V5S<F]L
M92<L("=U<V5S=&%S:R<L("=S<F-P86-K86=E)RP@)W-R8W5R:2<L#0H@("`@
M("`@("`@("`@("`@)W!H<')E;&5A<V4G+"`G97AT<W)C<F5L96%S92<L#0H@
M("`@("`@("`@("`@("`@)V5X=&)I;G)E;&5A<V4G+"`G8G5N9&QE)RP@)V-H
M86YG96QO9R<I+"`D=7)I+"`G=7)I)RD[#0H@("`@("`@('T-"B`@("`@("`@
M)'1H:7,M/E]P86-K86=E26YF;ULG=7)I)UT@/2`D=7)I.PT*("`@('T-"@T*
M("`@(&9U;F-T:6]N('-E=$-H86YN96PH)&-H86YN96PI#0H@("`@>PT*("`@
M("`@("!U;G-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=U<FDG72D[#0H@("`@
M("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@(&EF("@A:7-S970H
M)'1H:7,M/E]P86-K86=E26YF;ULG8VAA;FYE;"==*2D@>PT*("`@("`@("`@
M("`@+R\@96YS=7)E('1H870@=&AE(&-H86YN96P@=&%G(&ES('-E="!U<"!I
M;B!T:&4@<FEG:'0@;&]C871I;VX-"B`@("`@("`@("`@("1T:&ES+3Y?<&%C
M:V%G94EN9F\@/2`D=&AI<RT^7VEN<V5R=$)E9F]R92@D=&AI<RT^7W!A8VMA
M9V5);F9O+`T*("`@("`@("`@("`@("`@(&%R<F%Y*"=E>'1E;F1S)RP@)W-U
M;6UA<GDG+"`G9&5S8W)I<'1I;VXG+"`G;&5A9"<L#0H@("`@("`@("`@("`@
M("`@)V1E=F5L;W!E<B<L("=C;VYT<FEB=71O<B<L("=H96QP97(G+"`G9&%T
M92<L("=T:6UE)RP@)W9E<G-I;VXG+`T*("`@("`@("`@("`@("`@("=S=&%B
M:6QI='DG+"`G;&EC96YS92<L("=N;W1E<R<L("=C;VYT96YT<R<L("=C;VUP
M871I8FQE)RP-"B`@("`@("`@("`@("`@("`G9&5P96YD96YC:65S)RP@)W!R
M;W9I9&5S97AT96YS:6]N)RP@)W5S97-R;VQE)RP@)W5S97-T87-K)RP@)W-R
M8W!A8VMA9V4G+"`G<W)C=7)I)RP-"B`@("`@("`@("`@("`@("`G<&AP<F5L
M96%S92<L("=E>'1S<F-R96QE87-E)RP-"B`@("`@("`@("`@("`@("`G97AT
M8FEN<F5L96%S92<L("=B=6YD;&4G+"`G8VAA;F=E;&]G)RDL("1C:&%N;F5L
M+"`G8VAA;FYE;"<I.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?<&%C
M:V%G94EN9F];)V-H86YN96PG72`]("1C:&%N;F5L.PT*("`@('T-"@T*("`@
M(&9U;F-T:6]N('-E=$5X=&5N9',H)&5X=&5N9',I#0H@("`@>PT*("`@("`@
M("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?<&%C:V%G94EN9F];)V5X=&5N9',G72DI('L-"B`@("`@("`@("`@
M("\O(&5N<W5R92!T:&%T('1H92!E>'1E;F1S('1A9R!I<R!S970@=7`@:6X@
M=&AE(')I9VAT(&QO8V%T:6]N#0H@("`@("`@("`@("`D=&AI<RT^7W!A8VMA
M9V5);F9O(#T@)'1H:7,M/E]I;G-E<G1"969O<F4H)'1H:7,M/E]P86-K86=E
M26YF;RP-"B`@("`@("`@("`@("`@("!A<G)A>2@G<W5M;6%R>2<L("=D97-C
M<FEP=&EO;B<L("=L96%D)RP-"B`@("`@("`@("`@("`@("`G9&5V96QO<&5R
M)RP@)V-O;G1R:6)U=&]R)RP@)VAE;'!E<B<L("=D871E)RP@)W1I;64G+"`G
M=F5R<VEO;B<L#0H@("`@("`@("`@("`@("`@)W-T86)I;&ET>2<L("=L:6-E
M;G-E)RP@)VYO=&5S)RP@)V-O;G1E;G1S)RP@)V-O;7!A=&EB;&4G+`T*("`@
M("`@("`@("`@("`@("=D97!E;F1E;F-I97,G+"`G<')O=FED97-E>'1E;G-I
M;VXG+"`G=7-E<W)O;&4G+"`G=7-E<W1A<VLG+"`G<W)C<&%C:V%G92<L("=S
M<F-U<FDG+`T*("`@("`@("`@("`@("`@("=P:'!R96QE87-E)RP@)V5X='-R
M8W)E;&5A<V4G+`T*("`@("`@("`@("`@("`@("=E>'1B:6YR96QE87-E)RP@
M)V)U;F1L92<L("=C:&%N9V5L;V<G*2P@)&5X=&5N9',L("=E>'1E;F1S)RD[
M#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG97AT
M96YD<R==(#T@)&5X=&5N9',[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T
M4W5M;6%R>2@D<W5M;6%R>2D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?:7-6
M86QI9"`](#`[#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E
M26YF;ULG<W5M;6%R>2==*2D@>PT*("`@("`@("`@("`@+R\@96YS=7)E('1H
M870@=&AE('-U;6UA<GD@=&%G(&ES('-E="!U<"!I;B!T:&4@<FEG:'0@;&]C
M871I;VX-"B`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D=&AI
M<RT^7VEN<V5R=$)E9F]R92@D=&AI<RT^7W!A8VMA9V5);F9O+`T*("`@("`@
M("`@("`@("`@(&%R<F%Y*"=D97-C<FEP=&EO;B<L("=L96%D)RP-"B`@("`@
M("`@("`@("`@("`G9&5V96QO<&5R)RP@)V-O;G1R:6)U=&]R)RP@)VAE;'!E
M<B<L("=D871E)RP@)W1I;64G+"`G=F5R<VEO;B<L#0H@("`@("`@("`@("`@
M("`@)W-T86)I;&ET>2<L("=L:6-E;G-E)RP@)VYO=&5S)RP@)V-O;G1E;G1S
M)RP@)V-O;7!A=&EB;&4G+`T*("`@("`@("`@("`@("`@("=D97!E;F1E;F-I
M97,G+"`G<')O=FED97-E>'1E;G-I;VXG+"`G=7-E<W)O;&4G+"`G=7-E<W1A
M<VLG+"`G<W)C<&%C:V%G92<L("=S<F-U<FDG+`T*("`@("`@("`@("`@("`@
M("=P:'!R96QE87-E)RP@)V5X='-R8W)E;&5A<V4G+`T*("`@("`@("`@("`@
M("`@("=E>'1B:6YR96QE87-E)RP@)V)U;F1L92<L("=C:&%N9V5L;V<G*2P@
M)'-U;6UA<GDL("=S=6UM87)Y)RD[#0H@("`@("`@('T-"B`@("`@("`@)'1H
M:7,M/E]P86-K86=E26YF;ULG<W5M;6%R>2==(#T@)'-U;6UA<GD[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@<V5T1&5S8W)I<'1I;VXH)&1E<V,I#0H@("`@
M>PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@("`@("!I9B`H
M(6ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<V-R:7!T:6]N)UTI*2![
M#0H@("`@("`@("`@("`O+R!E;G-U<F4@=&AA="!T:&4@9&5S8W)I<'1I;VX@
M=&%G(&ES('-E="!U<"!I;B!T:&4@<FEG:'0@;&]C871I;VX-"B`@("`@("`@
M("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D=&AI<RT^7VEN<V5R=$)E9F]R
M92@D=&AI<RT^7W!A8VMA9V5);F9O+`T*("`@("`@("`@("`@("`@(&%R<F%Y
M*"=L96%D)RP-"B`@("`@("`@("`@("`@("`G9&5V96QO<&5R)RP@)V-O;G1R
M:6)U=&]R)RP@)VAE;'!E<B<L("=D871E)RP@)W1I;64G+"`G=F5R<VEO;B<L
M#0H@("`@("`@("`@("`@("`@)W-T86)I;&ET>2<L("=L:6-E;G-E)RP@)VYO
M=&5S)RP@)V-O;G1E;G1S)RP@)V-O;7!A=&EB;&4G+`T*("`@("`@("`@("`@
M("`@("=D97!E;F1E;F-I97,G+"`G<')O=FED97-E>'1E;G-I;VXG+"`G=7-E
M<W)O;&4G+"`G=7-E<W1A<VLG+"`G<W)C<&%C:V%G92<L("=S<F-U<FDG+`T*
M("`@("`@("`@("`@("`@("=P:'!R96QE87-E)RP@)V5X='-R8W)E;&5A<V4G
M+`T*("`@("`@("`@("`@("`@("=E>'1B:6YR96QE87-E)RP@)V)U;F1L92<L
M("=C:&%N9V5L;V<G*2P@)&1E<V,L("=D97-C<FEP=&EO;B<I.PT*("`@("`@
M("!]#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<V-R:7!T:6]N
M)UT@/2`D9&5S8SL-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!!9&1S(&$@
M;F5W(&UA:6YT86EN97(@+2!N;R!C:&5C:VEN9R!O9B!D=7!L:6-A=&5S(&ES
M('!E<F9O<FUE9"P@=7-E#0H@("`@("H@=7!D871E;6%I;G1A:6YE<B!F;W(@
M=&AA="!P=7)P;W-E+@T*("`@("`J+PT*("`@(&9U;F-T:6]N(&%D9$UA:6YT
M86EN97(H)')O;&4L("1H86YD;&4L("1N86UE+"`D96UA:6PL("1A8W1I=F4@
M/2`G>65S)RD-"B`@("![#0H@("`@("`@(&EF("@A:6Y?87)R87DH)')O;&4L
M(&%R<F%Y*"=L96%D)RP@)V1E=F5L;W!E<B<L("=C;VYT<FEB=71O<B<L("=H
M96QP97(G*2DI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULD
M<F]L95TI*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%C
M:V%G94EN9F];)')O;&5=6S!=*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%C:V%G94EN9F];)')O;&5=(#T@87)R87DH)'1H:7,M/E]P86-K86=E
M26YF;ULD<F]L95TI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'1H
M:7,M/E]P86-K86=E26YF;ULD<F]L95U;72`]#0H@("`@("`@("`@("`@("`@
M87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B`D;F%M92P-
M"B`@("`@("`@("`@("`@("`@("`@)W5S97(G(#T^("1H86YD;&4L#0H@("`@
M("`@("`@("`@("`@("`@("=E;6%I;"<@/3X@)&5M86EL+`T*("`@("`@("`@
M("`@("`@("`@("`G86-T:79E)R`]/B`D86-T:79E+`T*("`@("`@("`@("`@
M("`@("D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D=&5S=&%R
M<B`](&%R<F%Y*"=L96%D)RP-"B`@("`@("`@("`@("`@("`@("`@)V1E=F5L
M;W!E<B<L("=C;VYT<FEB=71O<B<L("=H96QP97(G+"`G9&%T92<L("=T:6UE
M)RP@)W9E<G-I;VXG+`T*("`@("`@("`@("`@("`@("`@("`G<W1A8FEL:71Y
M)RP@)VQI8V5N<V4G+"`G;F]T97,G+"`G8V]N=&5N=',G+"`G8V]M<&%T:6)L
M92<L#0H@("`@("`@("`@("`@("`@("`@("=D97!E;F1E;F-I97,G+"`G<')O
M=FED97-E>'1E;G-I;VXG+"`G=7-E<W)O;&4G+"`G=7-E<W1A<VLG+`T*("`@
M("`@("`@("`@("`@("`@("`G<W)C<&%C:V%G92<L("=S<F-U<FDG+"`G<&AP
M<F5L96%S92<L("=E>'1S<F-R96QE87-E)RP-"B`@("`@("`@("`@("`@("`@
M("`@)V5X=&)I;G)E;&5A<V4G+"`G8G5N9&QE)RP@)V-H86YG96QO9R<I.PT*
M("`@("`@("`@("`@9F]R96%C:"`H87)R87DH)VQE860G+"`G9&5V96QO<&5R
M)RP@)V-O;G1R:6)U=&]R)RP@)VAE;'!E<B<I(&%S("1T97-T<F]L92D@>PT*
M("`@("`@("`@("`@("`@(&%R<F%Y7W-H:69T*"1T97-T87)R*3L-"B`@("`@
M("`@("`@("`@("!I9B`H)')O;&4@/3T@)'1E<W1R;VQE*2![#0H@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K
M86=E26YF;ULD<F]L95TI*2![#0H@("`@("`@("`@("`@("`@+R\@96YS=7)E
M('1H870@=&AE(&5X=&5N9',@=&%G(&ES('-E="!U<"!I;B!T:&4@<FEG:'0@
M;&]C871I;VX-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O
M(#T@)'1H:7,M/E]I;G-E<G1"969O<F4H)'1H:7,M/E]P86-K86=E26YF;RP@
M)'1E<W1A<G(L#0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"DL("1R;VQE
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G
M94EN9F];)')O;&5=(#T-"B`@("`@("`@("`@("`@("!A<G)A>2@-"B`@("`@
M("`@("`@("`@("`@("`@)VYA;64G(#T^("1N86UE+`T*("`@("`@("`@("`@
M("`@("`@("`G=7-E<B<@/3X@)&AA;F1L92P-"B`@("`@("`@("`@("`@("`@
M("`@)V5M86EL)R`]/B`D96UA:6PL#0H@("`@("`@("`@("`@("`@("`@("=A
M8W1I=F4G(#T^("1A8W1I=F4L#0H@("`@("`@("`@("`@("`@*3L-"B`@("`@
M("`@?0T*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@('T-"@T*
M("`@(&9U;F-T:6]N('5P9&%T94UA:6YT86EN97(H)&YE=W)O;&4L("1H86YD
M;&4L("1N86UE+"`D96UA:6PL("1A8W1I=F4@/2`G>65S)RD-"B`@("![#0H@
M("`@("`@("1F;W5N9"`](&9A;'-E.PT*("`@("`@("!F;W)E86-H("AA<G)A
M>2@G;&5A9"<L("=D979E;&]P97(G+"`G8V]N=')I8G5T;W(G+"`G:&5L<&5R
M)RD@87,@)')O;&4I('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/E]P86-K86=E26YF;ULD<F]L95TI*2![#0H@("`@("`@("`@("`@("`@8V]N
M=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D:6YF;R`]("1T
M:&ES+3Y?<&%C:V%G94EN9F];)')O;&5=.PT*("`@("`@("`@("`@:68@*"%I
M<W-E="@D:6YF;ULP72DI('L-"B`@("`@("`@("`@("`@("!I9B`H)&EN9F];
M)W5S97(G72`]/2`D:&%N9&QE*2![#0H@("`@("`@("`@("`@("`@("`@("1F
M;W5N9"`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O
M<F5A8V@@*"1I;F9O(&%S("1I(#T^("1M86EN=&%I;F5R*2![#0H@("`@("`@
M("`@("`@("`@:68@*"1M86EN=&%I;F5R6R=U<V5R)UT@/3T@)&AA;F1L92D@
M>PT*("`@("`@("`@("`@("`@("`@("`D9F]U;F0@/2`D:3L-"B`@("`@("`@
M("`@("`@("`@("`@8G)E86L@,CL-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"1F;W5N9"`]/3T@
M9F%L<V4I('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^861D36%I;G1A
M:6YE<B@D;F5W<F]L92P@)&AA;F1L92P@)&YA;64L("1E;6%I;"P@)&%C=&EV
M92D[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1F;W5N9"`A/3T@9F%L<V4I
M('L-"B`@("`@("`@("`@(&EF("@D9F]U;F0@/3T]('1R=64I('L-"B`@("`@
M("`@("`@("`@("!U;G-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R1R;VQE72D[
M#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@('5N<V5T
M*"1T:&ES+3Y?<&%C:V%G94EN9F];)')O;&5=6R1F;W5N9%TI.PT*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)')O;&5=(#T@87)R87E?
M=F%L=65S*"1T:&ES+3Y?<&%C:V%G94EN9F];)')O;&5=*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^861D36%I;G1A:6YE
M<B@D;F5W<F]L92P@)&AA;F1L92P@)&YA;64L("1E;6%I;"P@)&%C=&EV92D[
M#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@?0T*#0H@("`@
M9G5N8W1I;VX@9&5L971E36%I;G1A:6YE<B@D:&%N9&QE*0T*("`@('L-"B`@
M("`@("`@)&9O=6YD(#T@9F%L<V4[#0H@("`@("`@(&9O<F5A8V@@*&%R<F%Y
M*"=L96%D)RP@)V1E=F5L;W!E<B<L("=C;VYT<FEB=71O<B<L("=H96QP97(G
M*2!A<R`D<F]L92D@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^
M7W!A8VMA9V5);F9O6R1R;VQE72DI('L-"B`@("`@("`@("`@("`@("!C;VYT
M:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A:7-S970H
M)'1H:7,M/E]P86-K86=E26YF;ULD<F]L95U;,%TI*2![#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULD<F]L95T@/2!A<G)A>2@D=&AI
M<RT^7W!A8VMA9V5);F9O6R1R;VQE72D[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!F;W)E86-H("@D=&AI<RT^7W!A8VMA9V5);F9O6R1R;VQE72!A
M<R`D:2`]/B`D;6%I;G1A:6YE<BD@>PT*("`@("`@("`@("`@("`@(&EF("@D
M;6%I;G1A:6YE<ELG=7-E<B==(#T]("1H86YD;&4I('L-"B`@("`@("`@("`@
M("`@("`@("`@)&9O=6YD(#T@)&D[#0H@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&EF("@D9F]U;F0@(3T](&9A;'-E*2![#0H@("`@("`@("`@("`@
M("`@=6YS970H)'1H:7,M/E]P86-K86=E26YF;ULD<F]L95U;)&9O=6YD72D[
M#0H@("`@("`@("`@("`@("`@:68@*"%C;W5N="@D=&AI<RT^7W!A8VMA9V5)
M;F9O6R1R;VQE72D@)B8@)')O;&4@/3T@)VQE860G*2![#0H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@(&EF("@A8V]U;G0H)'1H:7,M/E]P86-K
M86=E26YF;ULD<F]L95TI*2![#0H@("`@("`@("`@("`@("`@("`@('5N<V5T
M*"1T:&ES+3Y?<&%C:V%G94EN9F];)')O;&5=*3L-"B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)')O;&5=(#T-"B`@("`@
M("`@("`@("`@("`@("`@87)R87E?=F%L=65S*"1T:&ES+3Y?<&%C:V%G94EN
M9F];)')O;&5=*3L-"B`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)'1H:7,M
M/E]P86-K86=E26YF;ULD<F]L95TI(#T](#$I('L-"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULD<F]L95T@/2`D=&AI<RT^7W!A
M8VMA9V5);F9O6R1R;VQE75LP73L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/E]P86-K86=E26YF;ULD<F]L95TI
M(#T](#$I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O
M6R1R;VQE72`]("1T:&ES+3Y?<&%C:V%G94EN9F];)')O;&5=6S!=.PT*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!S971296QE87-E5F5R<VEO;B@D=F5R
M<VEO;BD-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA
M9V5);F9O6R=V97)S:6]N)UTI("8F#0H@("`@("`@("`@("`@(&ES<V5T*"1T
M:&ES+3Y?<&%C:V%G94EN9F];)W9E<G-I;VXG75LG<F5L96%S92==*2D@>PT*
M("`@("`@("`@("`@=6YS970H)'1H:7,M/E]P86-K86=E26YF;ULG=F5R<VEO
M;B==6R=R96QE87-E)UTI.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?
M<&%C:V%G94EN9F\@/2`D=&AI<RT^7VUE<F=E5&%G*"1T:&ES+3Y?<&%C:V%G
M94EN9F\L("1V97)S:6]N+"!A<G)A>2@-"B`@("`@("`@("`@("=V97)S:6]N
M)R`]/B!A<G)A>2@G<W1A8FEL:71Y)RP@)VQI8V5N<V4G+"`G;F]T97,G+"`G
M8V]N=&5N=',G+"`G8V]M<&%T:6)L92<L#0H@("`@("`@("`@("`@("`@)V1E
M<&5N9&5N8VEE<R<L("=P<F]V:61E<V5X=&5N<VEO;B<L("=U<V5S<F]L92<L
M("=U<V5S=&%S:R<L("=S<F-P86-K86=E)RP@)W-R8W5R:2<L#0H@("`@("`@
M("`@("`@("`@)W!H<')E;&5A<V4G+"`G97AT<W)C<F5L96%S92<L#0H@("`@
M("`@("`@("`@("`@)V5X=&)I;G)E;&5A<V4G+"`G8G5N9&QE)RP@)V-H86YG
M96QO9R<I+`T*("`@("`@("`@("`@)W)E;&5A<V4G(#T^(&%R<F%Y*"=A<&DG
M*2DI.PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@('T-"@T*
M("`@(&9U;F-T:6]N('-E=$%0259E<G-I;VXH)'9E<G-I;VXI#0H@("`@>PT*
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG=F5R<VEO
M;B==*2`F)@T*("`@("`@("`@("`@("!I<W-E="@D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=V97)S:6]N)UU;)V%P:2==*2D@>PT*("`@("`@("`@("`@=6YS970H
M)'1H:7,M/E]P86-K86=E26YF;ULG=F5R<VEO;B==6R=A<&DG72D[#0H@("`@
M("`@('T-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;R`]("1T:&ES+3Y?
M;65R9V5486<H)'1H:7,M/E]P86-K86=E26YF;RP@)'9E<G-I;VXL(&%R<F%Y
M*`T*("`@("`@("`@("`@)W9E<G-I;VXG(#T^(&%R<F%Y*"=S=&%B:6QI='DG
M+"`G;&EC96YS92<L("=N;W1E<R<L("=C;VYT96YT<R<L("=C;VUP871I8FQE
M)RP-"B`@("`@("`@("`@("`@("`G9&5P96YD96YC:65S)RP@)W!R;W9I9&5S
M97AT96YS:6]N)RP@)W5S97-R;VQE)RP@)W5S97-T87-K)RP@)W-R8W!A8VMA
M9V4G+"`G<W)C=7)I)RP-"B`@("`@("`@("`@("`@("`G<&AP<F5L96%S92<L
M("=E>'1S<F-R96QE87-E)RP-"B`@("`@("`@("`@("`@("`G97AT8FEN<F5L
M96%S92<L("=B=6YD;&4G+"`G8VAA;F=E;&]G)RDL#0H@("`@("`@("`@("`G
M87!I)R`]/B!A<G)A>2@I*2D[#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`]
M(#`[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@<VYA<'-H;W1\9&5V96Q\
M86QP:&%\8F5T87QS=&%B;&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S9712
M96QE87-E4W1A8FEL:71Y*"1S=&%T92D-"B`@("![#0H@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=S=&%B:6QI='DG72D@)B8-"B`@
M("`@("`@("`@("`@:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG<W1A8FEL
M:71Y)UU;)W)E;&5A<V4G72DI('L-"B`@("`@("`@("`@('5N<V5T*"1T:&ES
M+3Y?<&%C:V%G94EN9F];)W-T86)I;&ET>2==6R=R96QE87-E)UTI.PT*("`@
M("`@("!]#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D=&AI<RT^
M7VUE<F=E5&%G*"1T:&ES+3Y?<&%C:V%G94EN9F\L("1S=&%T92P@87)R87DH
M#0H@("`@("`@("`@("`G<W1A8FEL:71Y)R`]/B!A<G)A>2@G;&EC96YS92<L
M("=N;W1E<R<L("=C;VYT96YT<R<L("=C;VUP871I8FQE)RP-"B`@("`@("`@
M("`@("`@("`G9&5P96YD96YC:65S)RP@)W!R;W9I9&5S97AT96YS:6]N)RP@
M)W5S97-R;VQE)RP@)W5S97-T87-K)RP@)W-R8W!A8VMA9V4G+"`G<W)C=7)I
M)RP-"B`@("`@("`@("`@("`@("`G<&AP<F5L96%S92<L("=E>'1S<F-R96QE
M87-E)RP-"B`@("`@("`@("`@("`@("`G97AT8FEN<F5L96%S92<L("=B=6YD
M;&4G+"`G8VAA;F=E;&]G)RDL#0H@("`@("`@("`@("`G<F5L96%S92<@/3X@
M87)R87DH)V%P:2<I*2D[#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[
M#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(&1E=F5L?&%L<&AA
M?&)E=&%\<W1A8FQE#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T05!)4W1A
M8FEL:71Y*"1S=&%T92D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^7W!A8VMA9V5);F9O6R=S=&%B:6QI='DG72D@)B8-"B`@("`@("`@("`@
M("`@:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG<W1A8FEL:71Y)UU;)V%P
M:2==*2D@>PT*("`@("`@("`@("`@=6YS970H)'1H:7,M/E]P86-K86=E26YF
M;ULG<W1A8FEL:71Y)UU;)V%P:2==*3L-"B`@("`@("`@?0T*("`@("`@("`D
M=&AI<RT^7W!A8VMA9V5);F9O(#T@)'1H:7,M/E]M97)G951A9R@D=&AI<RT^
M7W!A8VMA9V5);F9O+"`D<W1A=&4L(&%R<F%Y*`T*("`@("`@("`@("`@)W-T
M86)I;&ET>2<@/3X@87)R87DH)VQI8V5N<V4G+"`G;F]T97,G+"`G8V]N=&5N
M=',G+"`G8V]M<&%T:6)L92<L#0H@("`@("`@("`@("`@("`@)V1E<&5N9&5N
M8VEE<R<L("=P<F]V:61E<V5X=&5N<VEO;B<L("=U<V5S<F]L92<L("=U<V5S
M=&%S:R<L("=S<F-P86-K86=E)RP@)W-R8W5R:2<L#0H@("`@("`@("`@("`@
M("`@)W!H<')E;&5A<V4G+"`G97AT<W)C<F5L96%S92<L#0H@("`@("`@("`@
M("`@("`@)V5X=&)I;G)E;&5A<V4G+"`G8G5N9&QE)RP@)V-H86YG96QO9R<I
M+`T*("`@("`@("`@("`@)V%P:2<@/3X@87)R87DH*2DI.PT*("`@("`@("`D
M=&AI<RT^7VES5F%L:60@/2`P.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E
M=$QI8V5N<V4H)&QI8V5N<V4L("1U<FD@/2!F86QS92P@)&9I;&5S;W5R8V4@
M/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P
M86-K86=E26YF;ULG;&EC96YS92==*2D@>PT*("`@("`@("`@("`@+R\@96YS
M=7)E('1H870@=&AE(&QI8V5N<V4@=&%G(&ES('-E="!U<"!I;B!T:&4@<FEG
M:'0@;&]C871I;VX-"B`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@
M/2`D=&AI<RT^7VEN<V5R=$)E9F]R92@D=&AI<RT^7W!A8VMA9V5);F9O+`T*
M("`@("`@("`@("`@("`@(&%R<F%Y*"=N;W1E<R<L("=C;VYT96YT<R<L("=C
M;VUP871I8FQE)RP-"B`@("`@("`@("`@("`@("`G9&5P96YD96YC:65S)RP@
M)W!R;W9I9&5S97AT96YS:6]N)RP@)W5S97-R;VQE)RP@)W5S97-T87-K)RP@
M)W-R8W!A8VMA9V4G+"`G<W)C=7)I)RP-"B`@("`@("`@("`@("`@("`G<&AP
M<F5L96%S92<L("=E>'1S<F-R96QE87-E)RP-"B`@("`@("`@("`@("`@("`G
M97AT8FEN<F5L96%S92<L("=B=6YD;&4G+"`G8VAA;F=E;&]G)RDL(#`L("=L
M:6-E;G-E)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1U<FD@?'P@)&9I
M;&5S;W5R8V4I('L-"B`@("`@("`@("`@("1A='1R:6)S(#T@87)R87DH*3L-
M"B`@("`@("`@("`@(&EF("@D=7)I*2![#0H@("`@("`@("`@("`@("`@)&%T
M=')I8G-;)W5R:2==(#T@)'5R:3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("1U<FD@/2!T<G5E.R`O+R!F;W(@=&5S="!B96QO=PT*("`@("`@("`@
M("`@:68@*"1F:6QE<V]U<F-E*2![#0H@("`@("`@("`@("`@("`@)&%T=')I
M8G-;)V9I;&5S;W5R8V4G72`]("1F:6QE<V]U<F-E.PT*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@("1L:6-E;G-E(#T@)'5R:2`_(&%R<F%Y
M*"=A='1R:6)S)R`]/B`D871T<FEB<RP@)U]C;VYT96YT)R`]/B`D;&EC96YS
M92D@.B`D;&EC96YS93L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG
M;&EC96YS92==(#T@)&QI8V5N<V4[#0H@("`@("`@("1T:&ES+3Y?:7-686QI
M9"`](#`[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T3F]T97,H)&YO=&5S
M*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=N;W1E<R==*2D@
M>PT*("`@("`@("`@("`@+R\@96YS=7)E('1H870@=&AE(&YO=&5S('1A9R!I
M<R!S970@=7`@:6X@=&AE(')I9VAT(&QO8V%T:6]N#0H@("`@("`@("`@("`D
M=&AI<RT^7W!A8VMA9V5);F9O(#T@)'1H:7,M/E]I;G-E<G1"969O<F4H)'1H
M:7,M/E]P86-K86=E26YF;RP-"B`@("`@("`@("`@("`@("!A<G)A>2@G8V]N
M=&5N=',G+"`G8V]M<&%T:6)L92<L#0H@("`@("`@("`@("`@("`@)V1E<&5N
M9&5N8VEE<R<L("=P<F]V:61E<V5X=&5N<VEO;B<L("=U<V5S<F]L92<L("=U
M<V5S=&%S:R<L("=S<F-P86-K86=E)RP@)W-R8W5R:2<L#0H@("`@("`@("`@
M("`@("`@)W!H<')E;&5A<V4G+"`G97AT<W)C<F5L96%S92<L#0H@("`@("`@
M("`@("`@("`@)V5X=&)I;G)E;&5A<V4G+"`G8G5N9&QE)RP@)V-H86YG96QO
M9R<I+"`D;F]T97,L("=N;W1E<R<I.PT*("`@("`@("!]#0H@("`@("`@("1T
M:&ES+3Y?<&%C:V%G94EN9F];)VYO=&5S)UT@/2`D;F]T97,[#0H@("`@?0T*
M#0H@("`@+RHJ#0H@("`@("H@5&AI<R!I<R!O;FQY('5S960@870@:6YS=&%L
M;"UT:6UE+"!A9G1E<B!A;&P@<V5R:6%L:7IA=&EO;@T*("`@("`J(&ES(&]V
M97(N#0H@("`@("H@0'!A<F%M('-T<FEN9R!F:6QE(&YA;64-"B`@("`@*B!`
M<&%R86T@<W1R:6YG(&EN<W1A;&QE9"!P871H#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@<V5T26YS=&%L;&5D07,H)&9I;&4L("1P871H*0T*("`@('L-"B`@
M("`@("`@:68@*"1P871H*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]P86-K86=E26YF;ULG9FEL96QI<W0G75LD9FEL95U;)VEN<W1A;&QE9%]A
M<R==(#T@)'!A=&@[#0H@("`@("`@('T-"B`@("`@("`@=6YS970H)'1H:7,M
M/E]P86-K86=E26YF;ULG9FEL96QI<W0G75LD9FEL95U;)VEN<W1A;&QE9%]A
M<R==*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!4:&ES(&ES(&]N;'D@
M=7-E9"!A="!I;G-T86QL+71I;64L(&%F=&5R(&%L;"!S97)I86QI>F%T:6]N
M#0H@("`@("H@:7,@;W9E<BX-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!I;G-T
M86QL961&:6QE*"1F:6QE+"`D871T<RD-"B`@("![#0H@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=F:6QE;&ES="==6R1F:6QE72DI
M('L-"B`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V9I;&5L:7-T
M)UU;)&9I;&5=(#T-"B`@("`@("`@("`@("`@("!A<G)A>5]M97)G92@D=&AI
M<RT^7W!A8VMA9V5);F9O6R=F:6QE;&ES="==6R1F:6QE72P@)&%T='-;)V%T
M=')I8G,G72D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D=&AI
M<RT^7W!A8VMA9V5);F9O6R=F:6QE;&ES="==6R1F:6QE72`]("1A='1S6R=A
M='1R:6)S)UT[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!297-E="!T:&4@;&ES=&EN9R!O9B!P86-K86=E(&-O;G1E;G1S#0H@("`@
M("H@0'!A<F%M('-T<FEN9R!B87-E(&EN<W1A;&QA=&EO;B!D:7(@9F]R('1H
M92!W:&]L92!P86-K86=E+"!I9B!A;GD-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!C;&5A<D-O;G1E;G1S*"1B87-E:6YS=&%L;"`](&9A;'-E*0T*("`@('L-
M"B`@("`@("`@)'1H:7,M/E]F:6QE<U9A;&ED(#T@9F%L<V4[#0H@("`@("`@
M("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@(&EF("@A:7-S970H)'1H
M:7,M/E]P86-K86=E26YF;ULG8V]N=&5N=',G72DI('L-"B`@("`@("`@("`@
M("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D=&AI<RT^7VEN<V5R=$)E9F]R92@D
M=&AI<RT^7W!A8VMA9V5);F9O+`T*("`@("`@("`@("`@("`@(&%R<F%Y*"=C
M;VUP871I8FQE)RP-"B`@("`@("`@("`@("`@("`@("`@)V1E<&5N9&5N8VEE
M<R<L("=P<F]V:61E<V5X=&5N<VEO;B<L("=U<V5S<F]L92<L("=U<V5S=&%S
M:R<L#0H@("`@("`@("`@("`@("`@("`@("=S<F-P86-K86=E)RP@)W-R8W5R
M:2<L("=P:'!R96QE87-E)RP@)V5X='-R8W)E;&5A<V4G+`T*("`@("`@("`@
M("`@("`@("`@("`G97AT8FEN<F5L96%S92<L("=B=6YD;&4G+"`G8VAA;F=E
M;&]G)RDL(&%R<F%Y*"DL("=C;VYT96YT<R<I.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("@D=&AI<RT^9V5T4&%C:V%G951Y<&4H*2`A/2`G8G5N9&QE)RD@
M>PT*("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=&5N=',G
M72`](`T*("`@("`@("`@("`@("`@(&%R<F%Y*"=D:7(G(#T^(&%R<F%Y*"=A
M='1R:6)S)R`]/B!A<G)A>2@G;F%M92<@/3X@)R\G*2DI.PT*("`@("`@("`@
M("`@:68@*"1B87-E:6YS=&%L;"D@>PT*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S)UU;)V1I<B==6R=A='1R:6)S)UU;
M)V)A<V5I;G-T86QL9&ER)UT@/2`D8F%S96EN<W1A;&P[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R
M86T@<W1R:6YG(')E;&%T:79E('!A=&@@;V8@=&AE(&)U;F1L960@<&%C:V%G
M92X-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!A9&1"=6YD;&5D4&%C:V%G92@D
M<&%T:"D-"B`@("![#0H@("`@("`@(&EF("@D=&AI<RT^9V5T4&%C:V%G951Y
M<&4H*2`A/2`G8G5N9&QE)RD@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?9FEL97-686QI9"`](&9A
M;'-E.PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@("`@("`D
M=&AI<RT^7W!A8VMA9V5);F9O(#T@)'1H:7,M/E]M97)G951A9R@D=&AI<RT^
M7W!A8VMA9V5);F9O+"`D<&%T:"P@87)R87DH#0H@("`@("`@("`@("`@("`@
M)V-O;G1E;G1S)R`]/B!A<G)A>2@G8V]M<&%T:6)L92<L("=D97!E;F1E;F-I
M97,G+"`G<')O=FED97-E>'1E;G-I;VXG+`T*("`@("`@("`@("`@("`@("=U
M<V5S<F]L92<L("=U<V5S=&%S:R<L("=S<F-P86-K86=E)RP@)W-R8W5R:2<L
M("=P:'!R96QE87-E)RP-"B`@("`@("`@("`@("`@("`G97AT<W)C<F5L96%S
M92<L("=E>'1B:6YR96QE87-E)RP@)V)U;F1L92<L("=C:&%N9V5L;V<G*2P-
M"B`@("`@("`@("`@("`@("`G8G5N9&QE9'!A8VMA9V4G(#T^(&%R<F%Y*"DI
M*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W1R:6YG(&9I
M;&4@;F%M90T*("`@("`J($!P87)A;2!014%27U1A<VM?0V]M;6]N(&$@<F5A
M9"]W<FET92!T87-K#0H@("`@("HO#0H@("`@9G5N8W1I;VX@861D5&%S:U1O
M1FEL92@D9FEL96YA;64L("1T87-K*0T*("`@('L-"B`@("`@("`@:68@*"%M
M971H;V1?97AI<W1S*"1T87-K+"`G9V5T6&UL)RDI('L-"B`@("`@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6UE=&AO
M9%]E>&ES=',H)'1A<VLL("=G971.86UE)RDI('L-"B`@("`@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6UE=&AO9%]E
M>&ES=',H)'1A<VLL("=V86QI9&%T92<I*2![#0H@("`@("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D=&%S:RT^=F%L
M:61A=&4H*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG
M8V]N=&5N=',G75LG9&ER)UU;)V9I;&4G72DI('L-"B`@("`@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^9V5T5&%S
M:W-.<R@I.R`O+R!D:7-C;W9E<B!T:&4@=&%S:W,@;F%M97-P86-E(&EF(&YO
M="!D;VYE(&%L<F5A9'D-"B`@("`@("`@)&9I;&5S(#T@)'1H:7,M/E]P86-K
M86=E26YF;ULG8V]N=&5N=',G75LG9&ER)UU;)V9I;&4G73L-"B`@("`@("`@
M:68@*"%I<W-E="@D9FEL97-;,%TI*2![#0H@("`@("`@("`@("`D9FEL97,@
M/2!A<G)A>2@D9FEL97,I.PT*("`@("`@("`@("`@)&EN9"`](&9A;'-E.PT*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&EN9"`]('1R=64[#0H@
M("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H)&9I;&5S(&%S("1I(#T^("1F
M:6QE*2![#0H@("`@("`@("`@("!I9B`H:7-S970H)&9I;&5;)V%T=')I8G,G
M72DI('L-"B`@("`@("`@("`@("`@("!I9B`H)&9I;&5;)V%T=')I8G,G75LG
M;F%M92==(#T]("1F:6QE;F%M92D@>PT*("`@("`@("`@("`@("`@("`@("!I
M9B`H)&EN9"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'0@/2!I<W-E
M="@D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT96YT<R==6R=D:7(G75LG9FEL
M92==6R1I70T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6R=A='1R
M:6)S)UU;)'1H:7,M/E]T87-K<TYS("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("<Z)R`N("1T87-K+3YG971.86UE*"E=*2`_#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=C
M;VYT96YT<R==6R=D:7(G75LG9FEL92==6R1I70T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@6R=A='1R:6)S)UU;)'1H:7,M/E]T87-K<TYS("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<Z)R`N("1T87-K+3YG
M971.86UE*"E=(#H@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H)'0@)B8@(6ES<V5T*"1T6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S)UU;)V1I
M<B==6R=F:6QE)UU;)&E=#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(%LD=&AI<RT^7W1A<VMS3G,@+B`G.B<@+B`D=&%S:RT^9V5T3F%M92@I
M72`](&%R<F%Y*"1T*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V-O
M;G1E;G1S)UU;)V1I<B==6R=F:6QE)UU;)&E=6R1T:&ES+3Y?=&%S:W-.<R`N
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)SHG("X@)'1A<VLM/F=E
M=$YA;64H*5U;72`]("1T87-K+3YG9718;6PH*3L-"B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T(#T@
M:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=&5N=',G75LG9&ER)UU;
M)V9I;&4G70T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6R=A='1R
M:6)S)UU;)'1H:7,M/E]T87-K<TYS("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("<Z)R`N("1T87-K+3YG971.86UE*"E=*2`_("1T:&ES+3Y?
M<&%C:V%G94EN9F];)V-O;G1E;G1S)UU;)V1I<B==6R=F:6QE)UT-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%LG871T<FEB<R==6R1T:&ES+3Y?
M=&%S:W-.<R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G.B<@
M+B`D=&%S:RT^9V5T3F%M92@I72`Z(&9A;'-E.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"1T("8F("%I<W-E="@D=%LP72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT
M96YT<R==6R=D:7(G75LG9FEL92==#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%LD=&AI<RT^7W1A<VMS3G,@+B`G.B<@+B`D=&%S:RT^9V5T
M3F%M92@I72`](&%R<F%Y*"1T*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN
M9F];)V-O;G1E;G1S)UU;)V1I<B==6R=F:6QE)UU;)'1H:7,M/E]T87-K<TYS
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G.B<@+B`D=&%S:RT^
M9V5T3F%M92@I75M=(#T@)'1A<VLM/F=E=%AM;"@I.PT*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@0'!A<F%M('-T<FEN9R!P871H('1O('1H92!F:6QE#0H@("`@("H@0'!A
M<F%M('-T<FEN9R!F:6QE;F%M90T*("`@("`J($!P87)A;2!A<G)A>2!E>'1R
M82!A='1R:6)U=&5S#0H@("`@("HO#0H@("`@9G5N8W1I;VX@861D1FEL92@D
M9&ER+"`D9FEL92P@)&%T=')S*0T*("`@('L-"B`@("`@("`@:68@*"1T:&ES
M+3YG971086-K86=E5'EP92@I(#T]("=B=6YD;&4G*2![#0H@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]F
M:6QE<U9A;&ED(#T@9F%L<V4[#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`]
M(#`[#0H@("`@("`@("1D:7(@/2!P<F5G7W)E<&QA8V4H87)R87DH)R%<7%Q<
M*R$G+"`G(2\K(2<I+"!A<G)A>2@G+R<L("<O)RDL("1D:7(I.PT*("`@("`@
M("!I9B`H)&1I<B`]/2`G+R<@?'P@)&1I<B`]/2`G)RD@>PT*("`@("`@("`@
M("`@)&1I<B`]("<G.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M)&1I<B`N/2`G+R<[#0H@("`@("`@('T-"B`@("`@("`@)&%T=')S6R=N86UE
M)UT@/2`D9&ER("X@)&9I;&4[#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/E]P86-K86=E26YF;ULG8V]N=&5N=',G72DI('L-"B`@("`@("`@("`@("\O
M(&5N<W5R92!T:&%T('1H92!C;VYT96YT<R!T86<@:7,@<V5T('5P#0H@("`@
M("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O(#T@)'1H:7,M/E]I;G-E<G1"
M969O<F4H)'1H:7,M/E]P86-K86=E26YF;RP-"B`@("`@("`@("`@("`@("!A
M<G)A>2@G8V]M<&%T:6)L92<L("=D97!E;F1E;F-I97,G+"`G<')O=FED97-E
M>'1E;G-I;VXG+"`G=7-E<W)O;&4G+"`G=7-E<W1A<VLG+`T*("`@("`@("`@
M("`@("`@("=S<F-P86-K86=E)RP@)W-R8W5R:2<L("=P:'!R96QE87-E)RP@
M)V5X='-R8W)E;&5A<V4G+`T*("`@("`@("`@("`@("`@("=E>'1B:6YR96QE
M87-E)RP@)V)U;F1L92<L("=C:&%N9V5L;V<G*2P@87)R87DH*2P@)V-O;G1E
M;G1S)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M<&%C:V%G94EN9F];)V-O;G1E;G1S)UU;)V1I<B==6R=F:6QE)UTI*2![#0H@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-O
M;G1E;G1S)UU;)V1I<B==6R=F:6QE)UU;,%TI*2![#0H@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=&5N=',G75LG9&ER)UU;)V9I
M;&4G72`]#0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1T:&ES+3Y?<&%C
M:V%G94EN9F];)V-O;G1E;G1S)UU;)V1I<B==6R=F:6QE)UTI.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG8V]N
M=&5N=',G75LG9&ER)UU;)V9I;&4G75M=6R=A='1R:6)S)UT@/2`D871T<G,[
M#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D=&AI<RT^7W!A8VMA
M9V5);F9O6R=C;VYT96YT<R==6R=D:7(G75LG9FEL92==6R=A='1R:6)S)UT@
M/2`D871T<G,[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!`<&%R86T@<W1R:6YG($1E<&5N9&5N="!P86-K86=E(&YA;64-"B`@("`@
M*B!`<&%R86T@<W1R:6YG($1E<&5N9&5N="!P86-K86=E)W,@8VAA;FYE;"!N
M86UE#0H@("`@("H@0'!A<F%M('-T<FEN9R!M:6YI;75M('9E<G-I;VX@;V8@
M<W!E8VEF:65D('!A8VMA9V4@=&AA="!T:&ES(')E;&5A<V4@:7,@9W5A<F%N
M=&5E9"!T;R!B90T*("`@("`J("`@("`@("`@("`@("`@8V]M<&%T:6)L92!W
M:71H#0H@("`@("H@0'!A<F%M('-T<FEN9R!M87AI;75M('9E<G-I;VX@;V8@
M<W!E8VEF:65D('!A8VMA9V4@=&AA="!T:&ES(')E;&5A<V4@:7,@9W5A<F%N
M=&5E9"!T;R!B90T*("`@("`J("`@("`@("`@("`@("`@8V]M<&%T:6)L92!W
M:71H#0H@("`@("H@0'!A<F%M('-T<FEN9R!V97)S:6]N<R!O9B!S<&5C:69I
M960@<&%C:V%G92!T:&%T('1H:7,@<F5L96%S92!I<R!N;W0@8V]M<&%T:6)L
M92!W:71H#0H@("`@("HO#0H@("`@9G5N8W1I;VX@861D0V]M<&%T:6)L95!A
M8VMA9V4H)&YA;64L("1C:&%N;F5L+"`D;6EN+"`D;6%X+"`D97AC;'5D92`]
M(&9A;'-E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-
M"B`@("`@("`@)'-E="`](&%R<F%Y*`T*("`@("`@("`@("`@)VYA;64G(#T^
M("1N86UE+`T*("`@("`@("`@("`@)V-H86YN96PG(#T^("1C:&%N;F5L+`T*
M("`@("`@("`@("`@)VUI;B<@/3X@)&UI;BP-"B`@("`@("`@("`@("=M87@G
M(#T^("1M87@L#0H@("`@("`@("D[#0H@("`@("`@(&EF("@D97AC;'5D92D@
M>PT*("`@("`@("`@("`@)'-E=%LG97AC;'5D92==(#T@)&5X8VQU9&4[#0H@
M("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@
M("`@)'1H:7,M/E]P86-K86=E26YF;R`]("1T:&ES+3Y?;65R9V5486<H)'1H
M:7,M/E]P86-K86=E26YF;RP@)'-E="P@87)R87DH#0H@("`@("`@("`@("`@
M("`@)V-O;7!A=&EB;&4G(#T^(&%R<F%Y*"=D97!E;F1E;F-I97,G+"`G<')O
M=FED97-E>'1E;G-I;VXG+"`G=7-E<W)O;&4G+"`G=7-E<W1A<VLG+`T*("`@
M("`@("`@("`@("`@("`@("`G<W)C<&%C:V%G92<L("=S<F-U<FDG+"`G<&AP
M<F5L96%S92<L("=E>'1S<F-R96QE87-E)RP@)V5X=&)I;G)E;&5A<V4G+`T*
M("`@("`@("`@("`@("`@("`@("`G8G5N9&QE)RP@)V-H86YG96QO9R<I#0H@
M("`@("`@("`@("`I*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!296UO
M=F5S('1H92`\=7-E<W)O;&4^('1A9R!E;G1I<F5L>0T*("`@("`J+PT*("`@
M(&9U;F-T:6]N(')E<V5T57-E<W)O;&4H*0T*("`@('L-"B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W5S97-R;VQE)UTI*2![#0H@
M("`@("`@("`@("!U;G-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=U<V5S<F]L
M92==*3L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P
M87)A;2!S=')I;F<-"B`@("`@*B!`<&%R86T@<W1R:6YG('!A8VMA9V4@;F%M
M92!O<B!U<FD-"B`@("`@*B!`<&%R86T@<W1R:6YG(&-H86YN96P@;F%M92!I
M9B!N;VXM=7)I#0H@("`@("HO#0H@("`@9G5N8W1I;VX@861D57-E<W)O;&4H
M)')O;&4L("1P86-K86=E3W)5<FDL("1C:&%N;F5L(#T@9F%L<V4I('L-"B`@
M("`@("`@)'-E="`](&%R<F%Y*"=R;VQE)R`]/B`D<F]L92D[#0H@("`@("`@
M(&EF("@D8VAA;FYE;"D@>PT*("`@("`@("`@("`@)'-E=%LG<&%C:V%G92==
M(#T@)'!A8VMA9V5/<E5R:3L-"B`@("`@("`@("`@("1S971;)V-H86YN96PG
M72`]("1C:&%N;F5L.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M)'-E=%LG=7)I)UT@/2`D<&%C:V%G94]R57)I.PT*("`@("`@("!]#0H@("`@
M("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@("1T:&ES+3Y?<&%C
M:V%G94EN9F\@/2`D=&AI<RT^7VUE<F=E5&%G*"1T:&ES+3Y?<&%C:V%G94EN
M9F\L("1S970L(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=U<V5S<F]L92<@
M/3X@87)R87DH)W5S97-T87-K)RP@)W-R8W!A8VMA9V4G+"`G<W)C=7)I)RP-
M"B`@("`@("`@("`@("`@("`@("`@)W!H<')E;&5A<V4G+"`G97AT<W)C<F5L
M96%S92<L("=E>'1B:6YR96QE87-E)RP@)V)U;F1L92<L("=C:&%N9V5L;V<G
M*0T*("`@("`@("`@("`@*2D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M4F5M;W9E<R!T:&4@/'5S97-T87-K/B!T86<@96YT:7)E;'D-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!R97-E=%5S97-T87-K*"D-"B`@("![#0H@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=U<V5S=&%S:R==*2D@
M>PT*("`@("`@("`@("`@=6YS970H)'1H:7,M/E]P86-K86=E26YF;ULG=7-E
M<W1A<VLG72D[#0H@("`@("`@('T-"B`@("!]#0H-"@T*("`@("\J*@T*("`@
M("`J($!P87)A;2!S=')I;F<-"B`@("`@*B!`<&%R86T@<W1R:6YG('!A8VMA
M9V4@;F%M92!O<B!U<FD-"B`@("`@*B!`<&%R86T@<W1R:6YG(&-H86YN96P@
M;F%M92!I9B!N;VXM=7)I#0H@("`@("HO#0H@("`@9G5N8W1I;VX@861D57-E
M<W1A<VLH)'1A<VLL("1P86-K86=E3W)5<FDL("1C:&%N;F5L(#T@9F%L<V4I
M('L-"B`@("`@("`@)'-E="`](&%R<F%Y*"=T87-K)R`]/B`D=&%S:RD[#0H@
M("`@("`@(&EF("@D8VAA;FYE;"D@>PT*("`@("`@("`@("`@)'-E=%LG<&%C
M:V%G92==(#T@)'!A8VMA9V5/<E5R:3L-"B`@("`@("`@("`@("1S971;)V-H
M86YN96PG72`]("1C:&%N;F5L.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@)'-E=%LG=7)I)UT@/2`D<&%C:V%G94]R57)I.PT*("`@("`@("!]
M#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@("1T:&ES
M+3Y?<&%C:V%G94EN9F\@/2`D=&AI<RT^7VUE<F=E5&%G*"1T:&ES+3Y?<&%C
M:V%G94EN9F\L("1S970L(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=U<V5S
M=&%S:R<@/3X@87)R87DH)W-R8W!A8VMA9V4G+"`G<W)C=7)I)RP-"B`@("`@
M("`@("`@("`@("`@("`@)W!H<')E;&5A<V4G+"`G97AT<W)C<F5L96%S92<L
M("=E>'1B:6YR96QE87-E)RP@)V)U;F1L92<L("=C:&%N9V5L;V<G*0T*("`@
M("`@("`@("`@*2D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4F5M;W9E
M(&%L;"!C;VUP871I8FQE('1A9W,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!C
M;&5A<D-O;7!A=&EB;&4H*0T*("`@('L-"B`@("`@("`@=6YS970H)'1H:7,M
M/E]P86-K86=E26YF;ULG8V]M<&%T:6)L92==*3L-"B`@("!]#0H-"B`@("`O
M*BH-"B`@("`@*B!297-E="!D97!E;F1E;F-I97,@<')I;W(@=&\@861D:6YG
M(&YE=R!O;F5S#0H@("`@("HO#0H@("`@9G5N8W1I;VX@8VQE87)$97!S*"D-
M"B`@("![#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF
M;ULG9&5P96YD96YC:65S)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W!A
M8VMA9V5);F9O(#T@)'1H:7,M/E]M97)G951A9R@D=&AI<RT^7W!A8VMA9V5)
M;F9O+"!A<G)A>2@I+`T*("`@("`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@
M("`@("`@("`@("`@("`G9&5P96YD96YC:65S)R`]/B!A<G)A>2@G<')O=FED
M97-E>'1E;G-I;VXG+"`G=7-E<W)O;&4G+"`G=7-E<W1A<VLG+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@)W-R8W!A8VMA9V4G+"`G<W)C=7)I)RP@)W!H
M<')E;&5A<V4G+"`G97AT<W)C<F5L96%S92<L("=E>'1B:6YR96QE87-E)RP-
M"B`@("`@("`@("`@("`@("`@("`@("`@("=B=6YD;&4G+"`G8VAA;F=E;&]G
M)RDI*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O
M6R=D97!E;F1E;F-I97,G72`](&%R<F%Y*"D[#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@("H@0'!A<F%M('-T<FEN9R!M:6YI;75M(%!(4"!V97)S:6]N(&%L
M;&]W960-"B`@("`@*B!`<&%R86T@<W1R:6YG(&UA>&EM=6T@4$A0('9E<G-I
M;VX@86QL;W=E9`T*("`@("`J($!P87)A;2!A<G)A>2`D97AC;'5D92!I;F-O
M;7!A=&EB;&4@4$A0('9E<G-I;VYS#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M<V5T4&AP1&5P*"1M:6XL("1M87@@/2!F86QS92P@)&5X8VQU9&4@/2!F86QS
M92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@
M("`@("1D97`@/0T*("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@("`@
M("`@)VUI;B<@/3X@)&UI;BP-"B`@("`@("`@("`@("D[#0H@("`@("`@(&EF
M("@D;6%X*2![#0H@("`@("`@("`@("`D9&5P6R=M87@G72`]("1M87@[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"1E>&-L=61E*2![#0H@("`@("`@("`@
M("!I9B`H8V]U;G0H)&5X8VQU9&4I(#T](#$I('L-"B`@("`@("`@("`@("`@
M("`D97AC;'5D92`]("1E>&-L=61E6S!=.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@)&1E<%LG97AC;'5D92==(#T@)&5X8VQU9&4[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1E
M<&5N9&5N8VEE<R==6R=R97%U:7)E9"==6R=P:'`G72DI('L-"B`@("`@("`@
M("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G=V%R;FEN
M9R<L(&%R<F%Y*"=D97`G(#T^#0H@("`@("`@("`@("`D=&AI<RT^7W!A8VMA
M9V5);F9O6R=D97!E;F1E;F-I97,G75LG<F5Q=6ER960G75LG<&AP)UTI+`T*
M("`@("`@("`@("`@("`@("=W87)N:6YG.B!02%`@9&5P96YD96YC>2!A;')E
M861Y(&5X:7-T<RP@;W9E<G=R:71I;F<G*3L-"B`@("`@("`@("`@('5N<V5T
M*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<&5N9&5N8VEE<R==6R=R97%U:7)E
M9"==6R=P:'`G72D[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]P86-K
M86=E26YF;R`]("1T:&ES+3Y?;65R9V5486<H)'1H:7,M/E]P86-K86=E26YF
M;RP@)&1E<"P-"B`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@("`@
M("=D97!E;F1E;F-I97,G(#T^(&%R<F%Y*"=P<F]V:61E<V5X=&5N<VEO;B<L
M("=U<V5S<F]L92<L("=U<V5S=&%S:R<L#0H@("`@("`@("`@("`@("`@("`@
M("=S<F-P86-K86=E)RP@)W-R8W5R:2<L("=P:'!R96QE87-E)RP@)V5X='-R
M8W)E;&5A<V4G+"`G97AT8FEN<F5L96%S92<L#0H@("`@("`@("`@("`@("`@
M("`@("=B=6YD;&4G+"`G8VAA;F=E;&]G)RDL#0H@("`@("`@("`@("`@("`@
M)W)E<75I<F5D)R`]/B!A<G)A>2@G;W!T:6]N86PG+"`G9W)O=7`G*2P-"B`@
M("`@("`@("`@("`@("`G<&AP)R`]/B!A<G)A>2@G<&5A<FEN<W1A;&QE<B<L
M("=P86-K86=E)RP@)W-U8G!A8VMA9V4G+"`G97AT96YS:6]N)RP@)V]S)RP@
M)V%R8V@G*0T*("`@("`@("`@("`@*2D[#0H@("`@("`@(')E='5R;B!T<G5E
M.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S=')I;F<@;6EN
M:6UU;2!A;&QO=V5D(%!%05(@:6YS=&%L;&5R('9E<G-I;VX-"B`@("`@*B!`
M<&%R86T@<W1R:6YG(&UA>&EM=6T@86QL;W=E9"!014%2(&EN<W1A;&QE<B!V
M97)S:6]N#0H@("`@("H@0'!A<F%M('-T<FEN9R!R96-O;6UE;F1E9"!014%2
M(&EN<W1A;&QE<B!V97)S:6]N#0H@("`@("H@0'!A<F%M(&%R<F%Y(&EN8V]M
M<&%T:6)L92!V97)S:6]N(&]F('1H92!014%2(&EN<W1A;&QE<@T*("`@("`J
M+PT*("`@(&9U;F-T:6]N('-E=%!E87)I;G-T86QL97)$97`H)&UI;BP@)&UA
M>"`](&9A;'-E+"`D<F5C;VUM96YD960@/2!F86QS92P@)&5X8VQU9&4@/2!F
M86QS92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@
M("`@("`@("1D97`@/0T*("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@
M("`@("`@)VUI;B<@/3X@)&UI;BP-"B`@("`@("`@("`@("D[#0H@("`@("`@
M(&EF("@D;6%X*2![#0H@("`@("`@("`@("`D9&5P6R=M87@G72`]("1M87@[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"1R96-O;6UE;F1E9"D@>PT*("`@
M("`@("`@("`@)&1E<%LG<F5C;VUM96YD960G72`]("1R96-O;6UE;F1E9#L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H)&5X8VQU9&4I('L-"B`@("`@("`@
M("`@(&EF("AC;W5N="@D97AC;'5D92D@/3T@,2D@>PT*("`@("`@("`@("`@
M("`@("1E>&-L=61E(#T@)&5X8VQU9&5;,%T[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`D9&5P6R=E>&-L=61E)UT@/2`D97AC;'5D93L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG
M9&5P96YD96YC:65S)UU;)W)E<75I<F5D)UU;)W!E87)I;G-T86QL97(G72DI
M('L-"B`@("`@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/
M3E]?+"`G=V%R;FEN9R<L(&%R<F%Y*"=D97`G(#T^#0H@("`@("`@("`@("`D
M=&AI<RT^7W!A8VMA9V5);F9O6R=D97!E;F1E;F-I97,G75LG<F5Q=6ER960G
M75LG<&5A<FEN<W1A;&QE<B==*2P-"B`@("`@("`@("`@("`@("`G=V%R;FEN
M9SH@4$5!4B!);G-T86QL97(@9&5P96YD96YC>2!A;')E861Y(&5X:7-T<RP@
M;W9E<G=R:71I;F<G*3L-"B`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?<&%C
M:V%G94EN9F];)V1E<&5N9&5N8VEE<R==6R=R97%U:7)E9"==6R=P96%R:6YS
M=&%L;&5R)UTI.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G
M94EN9F\@/2`D=&AI<RT^7VUE<F=E5&%G*"1T:&ES+3Y?<&%C:V%G94EN9F\L
M("1D97`L#0H@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`G
M9&5P96YD96YC:65S)R`]/B!A<G)A>2@G<')O=FED97-E>'1E;G-I;VXG+"`G
M=7-E<W)O;&4G+"`G=7-E<W1A<VLG+`T*("`@("`@("`@("`@("`@("`@("`G
M<W)C<&%C:V%G92<L("=S<F-U<FDG+"`G<&AP<F5L96%S92<L("=E>'1S<F-R
M96QE87-E)RP@)V5X=&)I;G)E;&5A<V4G+`T*("`@("`@("`@("`@("`@("`@
M("`G8G5N9&QE)RP@)V-H86YG96QO9R<I+`T*("`@("`@("`@("`@("`@("=R
M97%U:7)E9"<@/3X@87)R87DH)V]P=&EO;F%L)RP@)V=R;W5P)RDL#0H@("`@
M("`@("`@("`@("`@)W!E87)I;G-T86QL97(G(#T^(&%R<F%Y*"=P86-K86=E
M)RP@)W-U8G!A8VMA9V4G+"`G97AT96YS:6]N)RP@)V]S)RP@)V%R8V@G*0T*
M("`@("`@("`@("`@*2D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@36%R
M:R!A('!A8VMA9V4@87,@8V]N9FQI8W1I;F<@=VET:"!T:&ES('!A8VMA9V4-
M"B`@("`@*B!`<&%R86T@<W1R:6YG('!A8VMA9V4@;F%M90T*("`@("`J($!P
M87)A;2!S=')I;F<@<&%C:V%G92!C:&%N;F5L#0H@("`@("H@0'!A<F%M('-T
M<FEN9R!E>'1E;G-I;VX@=&AI<R!P86-K86=E('!R;W9I9&5S+"!I9B!A;GD-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!A9&1#;VYF;&EC=&EN9U!A8VMA9V5$
M97!7:71H0VAA;FYE;"@D;F%M92P@)&-H86YN96PL("1P<F]V:61E<V5X=&5N
M<VEO;B`](&9A;'-E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED
M(#T@,#L-"B`@("`@("`@)&1E<"`]#0H@("`@("`@("`@("!A<G)A>2@-"B`@
M("`@("`@("`@("`@("`G;F%M92<@/3X@)&YA;64L#0H@("`@("`@("`@("`@
M("`@)V-H86YN96PG(#T^("1C:&%N;F5L+`T*("`@("`@("`@("`@("`@("=C
M;VYF;&EC=',G(#T^("<G+`T*("`@("`@("`@("`@*3L-"B`@("`@("`@:68@
M*"1P<F]V:61E<V5X=&5N<VEO;BD@>PT*("`@("`@("`@("`@)&1E<%LG<')O
M=FED97-E>'1E;G-I;VXG72`]("1P<F]V:61E<V5X=&5N<VEO;CL-"B`@("`@
M("`@?0T*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O(#T@)'1H:7,M/E]M
M97)G951A9R@D=&AI<RT^7W!A8VMA9V5);F9O+"`D9&5P+`T*("`@("`@("`@
M("`@87)R87DH#0H@("`@("`@("`@("`@("`@)V1E<&5N9&5N8VEE<R<@/3X@
M87)R87DH)W!R;W9I9&5S97AT96YS:6]N)RP@)W5S97-R;VQE)RP@)W5S97-T
M87-K)RP-"B`@("`@("`@("`@("`@("`@("`@)W-R8W!A8VMA9V4G+"`G<W)C
M=7)I)RP@)W!H<')E;&5A<V4G+"`G97AT<W)C<F5L96%S92<L("=E>'1B:6YR
M96QE87-E)RP-"B`@("`@("`@("`@("`@("`@("`@)V)U;F1L92<L("=C:&%N
M9V5L;V<G*2P-"B`@("`@("`@("`@("`@("`G<F5Q=6ER960G(#T^(&%R<F%Y
M*"=O<'1I;VYA;"<L("=G<F]U<"<I+`T*("`@("`@("`@("`@("`@("=P86-K
M86=E)R`]/B!A<G)A>2@G<W5B<&%C:V%G92<L("=E>'1E;G-I;VXG+"`G;W,G
M+"`G87)C:"<I#0H@("`@("`@("`@("`I*3L-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`@*B!-87)K(&$@<&%C:V%G92!A<R!C;VYF;&EC=&EN9R!W:71H('1H
M:7,@<&%C:V%G90T*("`@("`J($!P87)A;2!S=')I;F<@<&%C:V%G92!N86UE
M#0H@("`@("H@0'!A<F%M('-T<FEN9R!P86-K86=E(&-H86YN96P-"B`@("`@
M*B!`<&%R86T@<W1R:6YG(&5X=&5N<VEO;B!T:&ES('!A8VMA9V4@<')O=FED
M97,L(&EF(&%N>0T*("`@("`J+PT*("`@(&9U;F-T:6]N(&%D9$-O;F9L:6-T
M:6YG4&%C:V%G941E<%=I=&A5<FDH)&YA;64L("1U<FDL("1P<F]V:61E<V5X
M=&5N<VEO;B`](&9A;'-E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]I<U9A
M;&ED(#T@,#L-"B`@("`@("`@)&1E<"`]#0H@("`@("`@("`@("!A<G)A>2@-
M"B`@("`@("`@("`@("`@("`G;F%M92<@/3X@)&YA;64L#0H@("`@("`@("`@
M("`@("`@)W5R:2<@/3X@)'5R:2P-"B`@("`@("`@("`@("`@("`G8V]N9FQI
M8W1S)R`]/B`G)RP-"B`@("`@("`@("`@("D[#0H@("`@("`@(&EF("@D<')O
M=FED97-E>'1E;G-I;VXI('L-"B`@("`@("`@("`@("1D97!;)W!R;W9I9&5S
M97AT96YS:6]N)UT@/2`D<')O=FED97-E>'1E;G-I;VX[#0H@("`@("`@('T-
M"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;R`]("1T:&ES+3Y?;65R9V54
M86<H)'1H:7,M/E]P86-K86=E26YF;RP@)&1E<"P-"B`@("`@("`@("`@(&%R
M<F%Y*`T*("`@("`@("`@("`@("`@("=D97!E;F1E;F-I97,G(#T^(&%R<F%Y
M*"=P<F]V:61E<V5X=&5N<VEO;B<L("=U<V5S<F]L92<L("=U<V5S=&%S:R<L
M#0H@("`@("`@("`@("`@("`@("`@("=S<F-P86-K86=E)RP@)W-R8W5R:2<L
M("=P:'!R96QE87-E)RP@)V5X='-R8W)E;&5A<V4G+"`G97AT8FEN<F5L96%S
M92<L#0H@("`@("`@("`@("`@("`@("`@("=B=6YD;&4G+"`G8VAA;F=E;&]G
M)RDL#0H@("`@("`@("`@("`@("`@)W)E<75I<F5D)R`]/B!A<G)A>2@G;W!T
M:6]N86PG+"`G9W)O=7`G*2P-"B`@("`@("`@("`@("`@("`G<&%C:V%G92<@
M/3X@87)R87DH)W-U8G!A8VMA9V4G+"`G97AT96YS:6]N)RP@)V]S)RP@)V%R
M8V@G*0T*("`@("`@("`@("`@*2D[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M861D1&5P96YD96YC>4=R;W5P*"1N86UE+"`D:&EN="D-"B`@("![#0H@("`@
M("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@("1T:&ES+3Y?<&%C
M:V%G94EN9F\@/2`D=&AI<RT^7VUE<F=E5&%G*"1T:&ES+3Y?<&%C:V%G94EN
M9F\L#0H@("`@("`@("`@("!A<G)A>2@G871T<FEB<R<@/3X@87)R87DH)VYA
M;64G(#T^("1N86UE+"`G:&EN="<@/3X@)&AI;G0I*2P-"B`@("`@("`@("`@
M(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=D97!E;F1E;F-I97,G(#T^(&%R
M<F%Y*"=P<F]V:61E<V5X=&5N<VEO;B<L("=U<V5S<F]L92<L("=U<V5S=&%S
M:R<L#0H@("`@("`@("`@("`@("`@("`@("=S<F-P86-K86=E)RP@)W-R8W5R
M:2<L("=P:'!R96QE87-E)RP@)V5X='-R8W)E;&5A<V4G+"`G97AT8FEN<F5L
M96%S92<L#0H@("`@("`@("`@("`@("`@("`@("=B=6YD;&4G+"`G8VAA;F=E
M;&]G)RDL#0H@("`@("`@("`@("`@("`@)V=R;W5P)R`]/B!A<G)A>2@I+`T*
M("`@("`@("`@("`@*2D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A
M<F%M('-T<FEN9R!P86-K86=E(&YA;64-"B`@("`@*B!`<&%R86T@<W1R:6YG
M?&9A;'-E(&-H86YN96P@;F%M92P@9F%L<V4@:68@=&AI<R!I<R!A('5R:0T*
M("`@("`J($!P87)A;2!S=')I;F=\9F%L<V4@=7)I(&YA;64L(&9A;'-E(&EF
M('1H:7,@:7,@82!C:&%N;F5L#0H@("`@("H@0'!A<F%M('-T<FEN9WQF86QS
M92!M:6YI;75M('9E<G-I;VX@<F5Q=6ER960-"B`@("`@*B!`<&%R86T@<W1R
M:6YG?&9A;'-E(&UA>&EM=6T@=F5R<VEO;B!A;&QO=V5D#0H@("`@("H@0'!A
M<F%M('-T<FEN9WQF86QS92!R96-O;6UE;F1E9"!I;G-T86QL871I;VX@=F5R
M<VEO;@T*("`@("`J($!P87)A;2!A<G)A>7QF86QS92!V97)S:6]N<R!T;R!E
M>&-L=61E(&9R;VT@:6YS=&%L;&%T:6]N#0H@("`@("H@0'!A<F%M('-T<FEN
M9R!E>'1E;G-I;VX@=&AI<R!P86-K86=E('!R;W9I9&5S+"!I9B!A;GD-"B`@
M("`@*B!`<&%R86T@8F]O;"!I9B!T<G5E+"!T96QL<R!T:&4@:6YS=&%L;&5R
M('1O(&EG;F]R92!T:&4@9&5F875L="!O<'1I;VYA;"!D97!E;F1E;F-Y(&=R
M;W5P#0H@("`@("H@("`@("`@("`@("`@=VAE;B!I;G-T86QL:6YG('1H:7,@
M<&%C:V%G90T*("`@("`J($!R971U<FX@87)R87D-"B`@("`@*B!`86-C97-S
M('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?8V]N<W1R=6-T1&5P
M*"1N86UE+"`D8VAA;FYE;"P@)'5R:2P@)&UI;BP@)&UA>"P@)')E8V]M;65N
M9&5D+"`D97AC;'5D92P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1P
M<F]V:61E<V5X=&5N<VEO;B`](&9A;'-E+"`D;F]D969A=6QT(#T@9F%L<V4I
M#0H@("`@>PT*("`@("`@("`D9&5P(#T-"B`@("`@("`@("`@(&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("=N86UE)R`]/B`D;F%M92P-"B`@("`@("`@("`@
M("D[#0H@("`@("`@(&EF("@D8VAA;FYE;"D@>PT*("`@("`@("`@("`@)&1E
M<%LG8VAA;FYE;"==(#T@)&-H86YN96P[#0H@("`@("`@('T@96QS96EF("@D
M=7)I*2![#0H@("`@("`@("`@("`D9&5P6R=U<FDG72`]("1U<FD[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"1M:6XI('L-"B`@("`@("`@("`@("1D97!;
M)VUI;B==(#T@)&UI;CL-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&UA>"D@
M>PT*("`@("`@("`@("`@)&1E<%LG;6%X)UT@/2`D;6%X.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("@D<F5C;VUM96YD960I('L-"B`@("`@("`@("`@("1D
M97!;)W)E8V]M;65N9&5D)UT@/2`D<F5C;VUM96YD960[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"1E>&-L=61E*2![#0H@("`@("`@("`@("!I9B`H:7-?
M87)R87DH)&5X8VQU9&4I("8F(&-O=6YT*"1E>&-L=61E*2`]/2`Q*2![#0H@
M("`@("`@("`@("`@("`@)&5X8VQU9&4@/2`D97AC;'5D95LP73L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("1D97!;)V5X8VQU9&4G72`]("1E>&-L
M=61E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D;F]D969A=6QT*2![#0H@
M("`@("`@("`@("`D9&5P6R=N;V1E9F%U;'0G72`]("<G.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("@D<')O=FED97-E>'1E;G-I;VXI('L-"B`@("`@("`@
M("`@("1D97!;)W!R;W9I9&5S97AT96YS:6]N)UT@/2`D<')O=FED97-E>'1E
M;G-I;VX[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1D97`[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('!A8VMA9V5\<W5B<&%C:V%G
M90T*("`@("`J($!P87)A;2!S=')I;F<@9W)O=7`@;F%M90T*("`@("`J($!P
M87)A;2!S=')I;F<@<&%C:V%G92!N86UE#0H@("`@("H@0'!A<F%M('-T<FEN
M9R!P86-K86=E(&-H86YN96P-"B`@("`@*B!`<&%R86T@<W1R:6YG(&UI;FEM
M=6T@=F5R<VEO;@T*("`@("`J($!P87)A;2!S=')I;F<@;6%X:6UU;2!V97)S
M:6]N#0H@("`@("H@0'!A<F%M('-T<FEN9R!R96-O;6UE;F1E9"!V97)S:6]N
M#0H@("`@("H@0'!A<F%M(&%R<F%Y?&9A;'-E(&]P=&EO;F%L(&5X8VQU9&5D
M('9E<G-I;VYS#0H@("`@("H@0'!A<F%M('-T<FEN9R!E>'1E;G-I;VX@=&AI
M<R!P86-K86=E('!R;W9I9&5S+"!I9B!A;GD-"B`@("`@*B!`<&%R86T@8F]O
M;"!I9B!T<G5E+"!T96QL<R!T:&4@:6YS=&%L;&5R('1O(&EG;F]R92!T:&4@
M9&5F875L="!O<'1I;VYA;"!D97!E;F1E;F-Y(&=R;W5P#0H@("`@("H@("`@
M("`@("`@("`@=VAE;B!I;G-T86QL:6YG('1H:7,@<&%C:V%G90T*("`@("`J
M($!R971U<FX@8F]O;"!F86QS92!I9B!T:&4@9&5P96YD96YC>2!G<F]U<"!H
M87,@;F]T(&)E96X@:6YI=&EA;&EZ960@=VET:`T*("`@("`J("`@("`@("`@
M("`@("![0&QI;FL@861D1&5P96YD96YC>4=R;W5P*"E]+"!O<B!A('-U8G!A
M8VMA9V4@:7,@861D960@=VET:`T*("`@("`J("`@("`@("`@("`@("!A('!R
M;W9I9&5S97AT96YS:6]N#0H@("`@("HO#0H@("`@9G5N8W1I;VX@861D1W)O
M=7!086-K86=E1&5P5VET:$-H86YN96PH)'1Y<&4L("1G<F]U<&YA;64L("1N
M86UE+"`D8VAA;FYE;"P@)&UI;B`](&9A;'-E+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D;6%X(#T@9F%L<V4L("1R96-O;6UE
M;F1E9"`](&9A;'-E+"`D97AC;'5D92`](&9A;'-E+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<')O=FED97-E>'1E;G-I;VX@
M/2!F86QS92P@)&YO9&5F875L="`](&9A;'-E*0T*("`@('L-"B`@("`@("`@
M:68@*"1T>7!E(#T]("=S=6)P86-K86=E)R`F)B`D<')O=FED97-E>'1E;G-I
M;VXI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L@+R\@<W5B<&%C:V%G
M97,@;75S="!B92!P:'`@<&%C:V%G97,-"B`@("`@("`@?0T*("`@("`@("`D
M9&5P(#T@)'1H:7,M/E]C;VYS=')U8W1$97`H)&YA;64L("1C:&%N;F5L+"!F
M86QS92P@)&UI;BP@)&UA>"P@)')E8V]M;65N9&5D+"`D97AC;'5D92P-"B`@
M("`@("`@("`@("1P<F]V:61E<V5X=&5N<VEO;BP@)&YO9&5F875L="D[#0H@
M("`@("`@(')E='5R;B`D=&AI<RT^7V%D9$=R;W5P1&5P96YD96YC>2@D='EP
M92P@)&1E<"P@)&=R;W5P;F%M92D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@0'!A<F%M('!A8VMA9V5\<W5B<&%C:V%G90T*("`@("`J($!P87)A;2!S
M=')I;F<@9W)O=7`@;F%M90T*("`@("`J($!P87)A;2!S=')I;F<@<&%C:V%G
M92!N86UE#0H@("`@("H@0'!A<F%M('-T<FEN9R!P86-K86=E('5R:0T*("`@
M("`J($!P87)A;2!S=')I;F<@97AT96YS:6]N('1H:7,@<&%C:V%G92!P<F]V
M:61E<RP@:68@86YY#0H@("`@("H@0'!A<F%M(&)O;VP@:68@=')U92P@=&5L
M;',@=&AE(&EN<W1A;&QE<B!T;R!I9VYO<F4@=&AE(&1E9F%U;'0@;W!T:6]N
M86P@9&5P96YD96YC>2!G<F]U<`T*("`@("`J("`@("`@("`@("`@('=H96X@
M:6YS=&%L;&EN9R!T:&ES('!A8VMA9V4-"B`@("`@*B!`<F5T=7)N(&)O;VP@
M9F%L<V4@:68@=&AE(&1E<&5N9&5N8WD@9W)O=7`@:&%S(&YO="!B965N(&EN
M:71I86QI>F5D('=I=&@-"B`@("`@*B`@("`@("`@("`@("`@>T!L:6YK(&%D
M9$1E<&5N9&5N8WE'<F]U<"@I?0T*("`@("`J+PT*("`@(&9U;F-T:6]N(&%D
M9$=R;W5P4&%C:V%G941E<%=I=&A54DDH)'1Y<&4L("1G<F]U<&YA;64L("1N
M86UE+"`D=7)I+"`D<')O=FED97-E>'1E;G-I;VX@/2!F86QS92P-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N;V1E9F%U;'0@
M/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@D='EP92`]/2`G<W5B<&%C
M:V%G92<@)B8@)'!R;W9I9&5S97AT96YS:6]N*2![#0H@("`@("`@("`@("!R
M971U<FX@9F%L<V4[("\O('-U8G!A8VMA9V5S(&UU<W0@8F4@<&AP('!A8VMA
M9V5S#0H@("`@("`@('T-"B`@("`@("`@)&1E<"`]("1T:&ES+3Y?8V]N<W1R
M=6-T1&5P*"1N86UE+"!F86QS92P@)'5R:2P@9F%L<V4L(&9A;'-E+"!F86QS
M92P@9F%L<V4L#0H@("`@("`@("`@("`D<')O=FED97-E>'1E;G-I;VXL("1N
M;V1E9F%U;'0I.PT*("`@("`@("!R971U<FX@)'1H:7,M/E]A9&1'<F]U<$1E
M<&5N9&5N8WDH)'1Y<&4L("1D97`L("1G<F]U<&YA;64I.PT*("`@('T-"@T*
M("`@("\J*@T*("`@("`J($!P87)A;2!S=')I;F<@9W)O=7`@;F%M92`H;75S
M="!B92!P<F4M97AI<W1I;F<I#0H@("`@("H@0'!A<F%M('-T<FEN9R!E>'1E
M;G-I;VX@;F%M90T*("`@("`J($!P87)A;2!S=')I;F<@;6EN:6UU;2!V97)S
M:6]N(&%L;&]W960-"B`@("`@*B!`<&%R86T@<W1R:6YG(&UA>&EM=6T@=F5R
M<VEO;B!A;&QO=V5D#0H@("`@("H@0'!A<F%M('-T<FEN9R!R96-O;6UE;F1E
M9"!V97)S:6]N#0H@("`@("H@0'!A<F%M(&%R<F%Y(&EN8V]M<&%T:6)L92!V
M97)S:6]N<PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&%D9$=R;W5P17AT96YS
M:6]N1&5P*"1G<F]U<&YA;64L("1N86UE+"`D;6EN(#T@9F%L<V4L("1M87@@
M/2!F86QS92P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)')E8V]M;65N9&5D(#T@9F%L<V4L("1E>&-L=61E(#T@9F%L<V4I
M#0H@("`@>PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@("`@
M("`D9&5P(#T@)'1H:7,M/E]C;VYS=')U8W1$97`H)&YA;64L(&9A;'-E+"!F
M86QS92P@)&UI;BP@)&UA>"P@)')E8V]M;65N9&5D+"`D97AC;'5D92D[#0H@
M("`@("`@(')E='5R;B`D=&AI<RT^7V%D9$=R;W5P1&5P96YD96YC>2@G97AT
M96YS:6]N)RP@)&1E<"P@)&=R;W5P;F%M92D[#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@("H@0'!A<F%M('!A8VMA9V5\<W5B<&%C:V%G97QE>'1E;G-I;VX-
M"B`@("`@*B!`<&%R86T@87)R87D@9&5P96YD96YC>2!C;VYT96YT<PT*("`@
M("`J($!P87)A;2!S=')I;F<@;F%M92!O9B!T:&4@9&5P96YD96YC>2!G<F]U
M<"!T;R!A9&0@=&AI<R!T;PT*("`@("`J($!R971U<FX@8F]O;&5A;@T*("`@
M("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]A
M9&1'<F]U<$1E<&5N9&5N8WDH)'1Y<&4L("1D97`L("1G<F]U<&YA;64I#0H@
M("`@>PT*("`@("`@("`D87)R(#T@87)R87DH)W-U8G!A8VMA9V4G+"`G97AT
M96YS:6]N)RD[#0H@("`@("`@(&EF("@D='EP92`A/2`G<&%C:V%G92<I('L-
M"B`@("`@("`@("`@(&%R<F%Y7W-H:69T*"1A<G(I.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@D='EP92`]/2`G97AT96YS:6]N)RD@>PT*("`@("`@("`@
M("`@87)R87E?<VAI9G0H)&%R<BD[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=D97!E;F1E;F-I97,G75LG
M9W)O=7`G72DI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P
M86-K86=E26YF;ULG9&5P96YD96YC:65S)UU;)V=R;W5P)UU;,%TI*2![#0H@
M("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<&5N
M9&5N8VEE<R==6R=G<F]U<"==6R=A='1R:6)S)UU;)VYA;64G72`]/2`D9W)O
M=7!N86UE*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G
M94EN9F];)V1E<&5N9&5N8VEE<R==6R=G<F]U<"==(#T@)'1H:7,M/E]M97)G
M951A9R@-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G
M94EN9F];)V1E<&5N9&5N8VEE<R==6R=G<F]U<"==+"`D9&5P+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1Y<&4@/3X@)&%R<@T*("`@("`@("`@("`@("`@("`@("`@
M("`@*2D[#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:7-686QI9"`]
M(#`[#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<&%C:V%G
M94EN9F];)V1E<&5N9&5N8VEE<R==6R=G<F]U<"==(&%S("1I(#T^("1G<F]U
M<"D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H)&=R;W5P6R=A='1R:6)S
M)UU;)VYA;64G72`]/2`D9W)O=7!N86UE*2![#0H@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<&5N9&5N8VEE<R==6R=G<F]U
M<"==6R1I72`]("1T:&ES+3Y?;65R9V5486<H#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=D97!E;F1E;F-I97,G75LG
M9W)O=7`G75LD:5TL("1D97`L#0H@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D='EP92`]/B`D
M87)R#0H@("`@("`@("`@("`@("`@("`@("`@("`I*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("!]#0H-
M"B`@("`O*BH-"B`@("`@*B!`<&%R86T@;W!T:6]N86Q\<F5Q=6ER960-"B`@
M("`@*B!`<&%R86T@<W1R:6YG('!A8VMA9V4@;F%M90T*("`@("`J($!P87)A
M;2!S=')I;F<@<&%C:V%G92!C:&%N;F5L#0H@("`@("H@0'!A<F%M('-T<FEN
M9R!M:6YI;75M('9E<G-I;VX-"B`@("`@*B!`<&%R86T@<W1R:6YG(&UA>&EM
M=6T@=F5R<VEO;@T*("`@("`J($!P87)A;2!S=')I;F<@<F5C;VUM96YD960@
M=F5R<VEO;@T*("`@("`J($!P87)A;2!S=')I;F<@97AT96YS:6]N('1H:7,@
M<&%C:V%G92!P<F]V:61E<RP@:68@86YY#0H@("`@("H@0'!A<F%M(&)O;VP@
M:68@=')U92P@=&5L;',@=&AE(&EN<W1A;&QE<B!T;R!I9VYO<F4@=&AE(&1E
M9F%U;'0@;W!T:6]N86P@9&5P96YD96YC>2!G<F]U<`T*("`@("`J("`@("`@
M("`@("`@('=H96X@:6YS=&%L;&EN9R!T:&ES('!A8VMA9V4-"B`@("`@*B!`
M<&%R86T@87)R87E\9F%L<V4@;W!T:6]N86P@97AC;'5D960@=F5R<VEO;G,-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!A9&1086-K86=E1&5P5VET:$-H86YN
M96PH)'1Y<&4L("1N86UE+"`D8VAA;FYE;"P@)&UI;B`](&9A;'-E+"`D;6%X
M(#T@9F%L<V4L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1R96-O;6UE;F1E9"`](&9A;'-E+"`D97AC;'5D92`](&9A;'-E+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<')O=FED
M97-E>'1E;G-I;VX@/2!F86QS92P@)&YO9&5F875L="`](&9A;'-E*0T*("`@
M('L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@)&%R
M<B`](&%R<F%Y*"=O<'1I;VYA;"<L("=G<F]U<"<I.PT*("`@("`@("!I9B`H
M)'1Y<&4@(3T@)W)E<75I<F5D)RD@>PT*("`@("`@("`@("`@87)R87E?<VAI
M9G0H)&%R<BD[#0H@("`@("`@('T-"B`@("`@("`@)&1E<"`]("1T:&ES+3Y?
M8V]N<W1R=6-T1&5P*"1N86UE+"`D8VAA;FYE;"P@9F%L<V4L("1M:6XL("1M
M87@L("1R96-O;6UE;F1E9"P@)&5X8VQU9&4L#0H@("`@("`@("`@("`D<')O
M=FED97-E>'1E;G-I;VXL("1N;V1E9F%U;'0I.PT*("`@("`@("`D=&AI<RT^
M7W!A8VMA9V5);F9O(#T@)'1H:7,M/E]M97)G951A9R@D=&AI<RT^7W!A8VMA
M9V5);F9O+"`D9&5P+`T*("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@
M("`@("`@)V1E<&5N9&5N8VEE<R<@/3X@87)R87DH)W!R;W9I9&5S97AT96YS
M:6]N)RP@)W5S97-R;VQE)RP@)W5S97-T87-K)RP-"B`@("`@("`@("`@("`@
M("`@("`@)W-R8W!A8VMA9V4G+"`G<W)C=7)I)RP@)W!H<')E;&5A<V4G+"`G
M97AT<W)C<F5L96%S92<L("=E>'1B:6YR96QE87-E)RP-"B`@("`@("`@("`@
M("`@("`@("`@)V)U;F1L92<L("=C:&%N9V5L;V<G*2P-"B`@("`@("`@("`@
M("`@("`D='EP92`]/B`D87)R+`T*("`@("`@("`@("`@("`@("=P86-K86=E
M)R`]/B!A<G)A>2@G<W5B<&%C:V%G92<L("=E>'1E;G-I;VXG+"`G;W,G+"`G
M87)C:"<I#0H@("`@("`@("`@("`I*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!`<&%R86T@;W!T:6]N86Q\<F5Q=6ER960-"B`@("`@*B!`<&%R86T@
M<W1R:6YG(&YA;64@;V8@=&AE('!A8VMA9V4-"B`@("`@*B!`<&%R86T@<W1R
M:6YG('5R:2!O9B!T:&4@<&%C:V%G90T*("`@("`J($!P87)A;2!S=')I;F<@
M97AT96YS:6]N('1H:7,@<&%C:V%G92!P<F]V:61E<RP@:68@86YY#0H@("`@
M("H@0'!A<F%M(&)O;VP@:68@=')U92P@=&5L;',@=&AE(&EN<W1A;&QE<B!T
M;R!I9VYO<F4@=&AE(&1E9F%U;'0@;W!T:6]N86P@9&5P96YD96YC>2!G<F]U
M<`T*("`@("`J("`@("`@("`@("`@('=H96X@:6YS=&%L;&EN9R!T:&ES('!A
M8VMA9V4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!A9&1086-K86=E1&5P5VET
M:%5R:2@D='EP92P@)&YA;64L("1U<FDL("1P<F]V:61E<V5X=&5N<VEO;B`]
M(&9A;'-E+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N
M;V1E9F%U;'0@/2!F86QS92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?:7-6
M86QI9"`](#`[#0H@("`@("`@("1A<G(@/2!A<G)A>2@G;W!T:6]N86PG+"`G
M9W)O=7`G*3L-"B`@("`@("`@:68@*"1T>7!E("$]("=R97%U:7)E9"<I('L-
M"B`@("`@("`@("`@(&%R<F%Y7W-H:69T*"1A<G(I.PT*("`@("`@("!]#0H@
M("`@("`@("1D97`@/2`D=&AI<RT^7V-O;G-T<G5C=$1E<"@D;F%M92P@9F%L
M<V4L("1U<FDL(&9A;'-E+"!F86QS92P@9F%L<V4L(&9A;'-E+`T*("`@("`@
M("`@("`@)'!R;W9I9&5S97AT96YS:6]N+"`D;F]D969A=6QT*3L-"B`@("`@
M("`@)'1H:7,M/E]P86-K86=E26YF;R`]("1T:&ES+3Y?;65R9V5486<H)'1H
M:7,M/E]P86-K86=E26YF;RP@)&1E<"P-"B`@("`@("`@("`@(&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("=D97!E;F1E;F-I97,G(#T^(&%R<F%Y*"=P<F]V
M:61E<V5X=&5N<VEO;B<L("=U<V5S<F]L92<L("=U<V5S=&%S:R<L#0H@("`@
M("`@("`@("`@("`@("`@("=S<F-P86-K86=E)RP@)W-R8W5R:2<L("=P:'!R
M96QE87-E)RP@)V5X='-R8W)E;&5A<V4G+"`G97AT8FEN<F5L96%S92<L#0H@
M("`@("`@("`@("`@("`@("`@("=B=6YD;&4G+"`G8VAA;F=E;&]G)RDL#0H@
M("`@("`@("`@("`@("`@)'1Y<&4@/3X@)&%R<BP-"B`@("`@("`@("`@("`@
M("`G<&%C:V%G92<@/3X@87)R87DH)W-U8G!A8VMA9V4G+"`G97AT96YS:6]N
M)RP@)V]S)RP@)V%R8V@G*0T*("`@("`@("`@("`@*2D[#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@0'!A<F%M(&]P=&EO;F%L?')E<75I<F5D(&]P=&EO
M;F%L+"!R97%U:7)E9`T*("`@("`J($!P87)A;2!S=')I;F<@<&%C:V%G92!N
M86UE#0H@("`@("H@0'!A<F%M('-T<FEN9R!P86-K86=E(&-H86YN96P-"B`@
M("`@*B!`<&%R86T@<W1R:6YG(&UI;FEM=6T@=F5R<VEO;@T*("`@("`J($!P
M87)A;2!S=')I;F<@;6%X:6UU;2!V97)S:6]N#0H@("`@("H@0'!A<F%M('-T
M<FEN9R!R96-O;6UE;F1E9"!V97)S:6]N#0H@("`@("H@0'!A<F%M(&%R<F%Y
M(&EN8V]M<&%T:6)L92!V97)S:6]N<PT*("`@("`J($!P87)A;2!B;V]L(&EF
M('1R=64L('1E;&QS('1H92!I;G-T86QL97(@=&\@:6=N;W)E('1H92!D969A
M=6QT(&]P=&EO;F%L(&1E<&5N9&5N8WD@9W)O=7`-"B`@("`@*B`@("`@("`@
M("`@("!W:&5N(&EN<W1A;&QI;F<@=&AI<R!P86-K86=E#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@861D4W5B<&%C:V%G941E<%=I=&A#:&%N;F5L*"1T>7!E
M+"`D;F%M92P@)&-H86YN96PL("1M:6X@/2!F86QS92P@)&UA>"`](&9A;'-E
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<F5C;VUM96YD960@/2!F86QS92P@)&5X8VQU9&4@/2!F86QS92P-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YO9&5F875L
M="`](&9A;'-E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@
M,#L-"B`@("`@("`@)&%R<B`](&%R<F%Y*"=O<'1I;VYA;"<L("=G<F]U<"<I
M.PT*("`@("`@("!I9B`H)'1Y<&4@(3T@)W)E<75I<F5D)RD@>PT*("`@("`@
M("`@("`@87)R87E?<VAI9G0H)&%R<BD[#0H@("`@("`@('T-"B`@("`@("`@
M)&1E<"`]("1T:&ES+3Y?8V]N<W1R=6-T1&5P*"1N86UE+"`D8VAA;FYE;"P@
M9F%L<V4L("1M:6XL("1M87@L("1R96-O;6UE;F1E9"P@)&5X8VQU9&4L#0H@
M("`@("`@("`@("`D;F]D969A=6QT*3L-"B`@("`@("`@)'1H:7,M/E]P86-K
M86=E26YF;R`]("1T:&ES+3Y?;65R9V5486<H)'1H:7,M/E]P86-K86=E26YF
M;RP@)&1E<"P-"B`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@("`@
M("=D97!E;F1E;F-I97,G(#T^(&%R<F%Y*"=P<F]V:61E<V5X=&5N<VEO;B<L
M("=U<V5S<F]L92<L("=U<V5S=&%S:R<L#0H@("`@("`@("`@("`@("`@("`@
M("=S<F-P86-K86=E)RP@)W-R8W5R:2<L("=P:'!R96QE87-E)RP@)V5X='-R
M8W)E;&5A<V4G+"`G97AT8FEN<F5L96%S92<L#0H@("`@("`@("`@("`@("`@
M("`@("=B=6YD;&4G+"`G8VAA;F=E;&]G)RDL#0H@("`@("`@("`@("`@("`@
M)'1Y<&4@/3X@)&%R<BP-"B`@("`@("`@("`@("`@("`G<W5B<&%C:V%G92<@
M/3X@87)R87DH)V5X=&5N<VEO;B<L("=O<R<L("=A<F-H)RD-"B`@("`@("`@
M("`@("DI.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!O<'1I
M;VYA;'QR97%U:7)E9"!O<'1I;VYA;"P@<F5Q=6ER960-"B`@("`@*B!`<&%R
M86T@<W1R:6YG('!A8VMA9V4@;F%M90T*("`@("`J($!P87)A;2!S=')I;F<@
M<&%C:V%G92!U<FD@9F]R(&1O=VYL;V%D#0H@("`@("H@0'!A<F%M(&)O;VP@
M:68@=')U92P@=&5L;',@=&AE(&EN<W1A;&QE<B!T;R!I9VYO<F4@=&AE(&1E
M9F%U;'0@;W!T:6]N86P@9&5P96YD96YC>2!G<F]U<`T*("`@("`J("`@("`@
M("`@("`@('=H96X@:6YS=&%L;&EN9R!T:&ES('!A8VMA9V4-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!A9&13=6)P86-K86=E1&5P5VET:%5R:2@D='EP92P@
M)&YA;64L("1U<FDL("1N;V1E9F%U;'0@/2!F86QS92D-"B`@("![#0H@("`@
M("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@("1A<G(@/2!A<G)A
M>2@G;W!T:6]N86PG+"`G9W)O=7`G*3L-"B`@("`@("`@:68@*"1T>7!E("$]
M("=R97%U:7)E9"<I('L-"B`@("`@("`@("`@(&%R<F%Y7W-H:69T*"1A<G(I
M.PT*("`@("`@("!]#0H@("`@("`@("1D97`@/2`D=&AI<RT^7V-O;G-T<G5C
M=$1E<"@D;F%M92P@9F%L<V4L("1U<FDL(&9A;'-E+"!F86QS92P@9F%L<V4L
M(&9A;'-E+"`D;F]D969A=6QT*3L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E
M26YF;R`]("1T:&ES+3Y?;65R9V5486<H)'1H:7,M/E]P86-K86=E26YF;RP@
M)&1E<"P-"B`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=D
M97!E;F1E;F-I97,G(#T^(&%R<F%Y*"=P<F]V:61E<V5X=&5N<VEO;B<L("=U
M<V5S<F]L92<L("=U<V5S=&%S:R<L#0H@("`@("`@("`@("`@("`@("`@("=S
M<F-P86-K86=E)RP@)W-R8W5R:2<L("=P:'!R96QE87-E)RP@)V5X='-R8W)E
M;&5A<V4G+"`G97AT8FEN<F5L96%S92<L#0H@("`@("`@("`@("`@("`@("`@
M("=B=6YD;&4G+"`G8VAA;F=E;&]G)RDL#0H@("`@("`@("`@("`@("`@)'1Y
M<&4@/3X@)&%R<BP-"B`@("`@("`@("`@("`@("`G<W5B<&%C:V%G92<@/3X@
M87)R87DH)V5X=&5N<VEO;B<L("=O<R<L("=A<F-H)RD-"B`@("`@("`@("`@
M("DI.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!O<'1I;VYA
M;'QR97%U:7)E9"!O<'1I;VYA;"P@<F5Q=6ER960-"B`@("`@*B!`<&%R86T@
M<W1R:6YG(&5X=&5N<VEO;B!N86UE#0H@("`@("H@0'!A<F%M('-T<FEN9R!M
M:6YI;75M('9E<G-I;VX-"B`@("`@*B!`<&%R86T@<W1R:6YG(&UA>&EM=6T@
M=F5R<VEO;@T*("`@("`J($!P87)A;2!S=')I;F<@<F5C;VUM96YD960@=F5R
M<VEO;@T*("`@("`J($!P87)A;2!A<G)A>2!I;F-O;7!A=&EB;&4@=F5R<VEO
M;G,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!A9&1%>'1E;G-I;VY$97`H)'1Y
M<&4L("1N86UE+"`D;6EN(#T@9F%L<V4L("1M87@@/2!F86QS92P@)')E8V]M
M;65N9&5D(#T@9F%L<V4L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1E>&-L=61E(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7VES
M5F%L:60@/2`P.PT*("`@("`@("`D87)R(#T@87)R87DH)V]P=&EO;F%L)RP@
M)V=R;W5P)RD[#0H@("`@("`@(&EF("@D='EP92`A/2`G<F5Q=6ER960G*2![
M#0H@("`@("`@("`@("!A<G)A>5]S:&EF="@D87)R*3L-"B`@("`@("`@?0T*
M("`@("`@("`D9&5P(#T@)'1H:7,M/E]C;VYS=')U8W1$97`H)&YA;64L(&9A
M;'-E+"!F86QS92P@)&UI;BP@)&UA>"P@)')E8V]M;65N9&5D+"`D97AC;'5D
M92D[#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D=&AI<RT^7VUE
M<F=E5&%G*"1T:&ES+3Y?<&%C:V%G94EN9F\L("1D97`L#0H@("`@("`@("`@
M("!A<G)A>2@-"B`@("`@("`@("`@("`@("`G9&5P96YD96YC:65S)R`]/B!A
M<G)A>2@G<')O=FED97-E>'1E;G-I;VXG+"`G=7-E<W)O;&4G+"`G=7-E<W1A
M<VLG+`T*("`@("`@("`@("`@("`@("`@("`G<W)C<&%C:V%G92<L("=S<F-U
M<FDG+"`G<&AP<F5L96%S92<L("=E>'1S<F-R96QE87-E)RP@)V5X=&)I;G)E
M;&5A<V4G+`T*("`@("`@("`@("`@("`@("`@("`G8G5N9&QE)RP@)V-H86YG
M96QO9R<I+`T*("`@("`@("`@("`@("`@("1T>7!E(#T^("1A<G(L#0H@("`@
M("`@("`@("`@("`@)V5X=&5N<VEO;B<@/3X@87)R87DH)V]S)RP@)V%R8V@G
M*0T*("`@("`@("`@("`@*2D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M0'!A<F%M('-T<FEN9R!/<&5R871I;F<@<WES=&5M(&YA;64-"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B!T<G5E(&EF('1H:7,@<&%C:V%G92!C86YN;W0@8F4@
M:6YS=&%L;&5D(&]N('1H:7,@3U,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!A
M9&1/<T1E<"@D;F%M92P@)&-O;F9L:6-T<R`](&9A;'-E*0T*("`@('L-"B`@
M("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@)&1E<"`](&%R
M<F%Y*"=N86UE)R`]/B`D;F%M92D[#0H@("`@("`@(&EF("@D8V]N9FQI8W1S
M*2![#0H@("`@("`@("`@("`D9&5P6R=C;VYF;&EC=',G72`]("<G.PT*("`@
M("`@("!]#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D=&AI<RT^
M7VUE<F=E5&%G*"1T:&ES+3Y?<&%C:V%G94EN9F\L("1D97`L#0H@("`@("`@
M("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`G9&5P96YD96YC:65S)R`]
M/B!A<G)A>2@G<')O=FED97-E>'1E;G-I;VXG+"`G=7-E<W)O;&4G+"`G=7-E
M<W1A<VLG+`T*("`@("`@("`@("`@("`@("`@("`G<W)C<&%C:V%G92<L("=S
M<F-U<FDG+"`G<&AP<F5L96%S92<L("=E>'1S<F-R96QE87-E)RP@)V5X=&)I
M;G)E;&5A<V4G+`T*("`@("`@("`@("`@("`@("`@("`G8G5N9&QE)RP@)V-H
M86YG96QO9R<I+`T*("`@("`@("`@("`@("`@("=R97%U:7)E9"<@/3X@87)R
M87DH)V]P=&EO;F%L)RP@)V=R;W5P)RDL#0H@("`@("`@("`@("`@("`@)V]S
M)R`]/B!A<G)A>2@G87)C:"<I#0H@("`@("`@("`@("`I*3L-"B`@("!]#0H-
M"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W1R:6YG($%R8VAI=&5C='5R92!M
M871C:&EN9R!P871T97)N#0H@("`@("H@0'!A<F%M(&)O;VQE86X@=')U92!I
M9B!T:&ES('!A8VMA9V4@8V%N;F]T(&)E(&EN<W1A;&QE9"!O;B!T:&ES(&%R
M8VAI=&5C='5R90T*("`@("`J+PT*("`@(&9U;F-T:6]N(&%D9$%R8VA$97`H
M)'!A='1E<FXL("1C;VYF;&EC=',@/2!F86QS92D-"B`@("![#0H@("`@("`@
M("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@("1D97`@/2!A<G)A>2@G
M<&%T=&5R;B<@/3X@)'!A='1E<FXI.PT*("`@("`@("!I9B`H)&-O;F9L:6-T
M<RD@>PT*("`@("`@("`@("`@)&1E<%LG8V]N9FQI8W1S)UT@/2`G)SL-"B`@
M("`@("`@?0T*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O(#T@)'1H:7,M
M/E]M97)G951A9R@D=&AI<RT^7W!A8VMA9V5);F9O+"`D9&5P+`T*("`@("`@
M("`@("`@87)R87DH#0H@("`@("`@("`@("`@("`@)V1E<&5N9&5N8VEE<R<@
M/3X@87)R87DH)W!R;W9I9&5S97AT96YS:6]N)RP@)W5S97-R;VQE)RP@)W5S
M97-T87-K)RP-"B`@("`@("`@("`@("`@("`@("`@)W-R8W!A8VMA9V4G+"`G
M<W)C=7)I)RP@)W!H<')E;&5A<V4G+"`G97AT<W)C<F5L96%S92<L("=E>'1B
M:6YR96QE87-E)RP-"B`@("`@("`@("`@("`@("`@("`@)V)U;F1L92<L("=C
M:&%N9V5L;V<G*2P-"B`@("`@("`@("`@("`@("`G<F5Q=6ER960G(#T^(&%R
M<F%Y*"=O<'1I;VYA;"<L("=G<F]U<"<I+`T*("`@("`@("`@("`@("`@("=A
M<F-H)R`]/B!A<G)A>2@I#0H@("`@("`@("`@("`I*3L-"B`@("!]#0H-"B`@
M("`O*BH-"B`@("`@*B!3970@=&AE(&MI;F0@;V8@<&%C:V%G92P@86YD(&5R
M87-E(&%L;"!R96QE87-E('1A9W,-"B`@("`@*@T*("`@("`J("T@82!P:'`@
M<&%C:V%G92!I<R!A(%!%05(M<W1Y;&4@<&%C:V%G90T*("`@("`J("T@86X@
M97AT8FEN('!A8VMA9V4@:7,@82!014-,+7-T>6QE(&5X=&5N<VEO;B!B:6YA
M<GD-"B`@("`@*B`M(&%N(&5X='-R8R!P86-K86=E(&ES(&$@4$5#3"US='EL
M92!S;W5R8V4@9F]R(&$@8FEN87)Y#0H@("`@("H@+2!A(&)U;F1L92!P86-K
M86=E(&ES(&$@8V]L;&5C=&EO;B!O9B!O=&AE<B!P<F4M<&%C:V%G960@<&%C
M:V%G97,-"B`@("`@*B!`<&%R86T@<&AP?&5X=&)I;GQE>'1S<F-\8G5N9&QE
M#0H@("`@("H@0')E='5R;B!B;V]L('-U8V-E<W,-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!S971086-K86=E5'EP92@D='EP92D-"B`@("![#0H@("`@("`@
M("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@(&EF("@A:6Y?87)R87DH
M)'1Y<&4L(&%R<F%Y*"=P:'`G+"`G97AT8FEN)RP@)V5X='-R8R<L("=B=6YD
M;&4G*2DI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H)'1Y<&4@(3T@)V)U;F1L92<I('L-"B`@("`@("`@
M("`@("1T>7!E("X]("=R96QE87-E)SL-"B`@("`@("`@?0T*("`@("`@("!F
M;W)E86-H("AA<G)A>2@G<&AP<F5L96%S92<L("=E>'1B:6YR96QE87-E)RP@
M)V5X='-R8W)E;&5A<V4G+"`G8G5N9&QE)RD@87,@)'1E<W0I('L-"B`@("`@
M("`@("`@('5N<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)'1E<W1=*3L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN
M9F];)'1Y<&5=*2D@>PT*("`@("`@("`@("`@+R\@96YS=7)E('1H870@=&AE
M(')E;&5A<V4@=&%G(&ES('-E="!U<`T*("`@("`@("`@("`@)'1H:7,M/E]P
M86-K86=E26YF;R`]("1T:&ES+3Y?:6YS97)T0F5F;W)E*"1T:&ES+3Y?<&%C
M:V%G94EN9F\L(&%R<F%Y*"=C:&%N9V5L;V<G*2P-"B`@("`@("`@("`@("`@
M("!A<G)A>2@I+"`D='EP92D[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M
M/E]P86-K86=E26YF;ULD='EP95T@/2!A<G)A>2@I.PT*("`@("`@("!R971U
M<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<F5T=7)N(&)O
M;VP@=')U92!I9B!P86-K86=E('1Y<&4@:7,@<V5T('5P#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@861D4F5L96%S92@I#0H@("`@>PT*("`@("`@("!I9B`H
M)'1Y<&4@/2`D=&AI<RT^9V5T4&%C:V%G951Y<&4H*2D@>PT*("`@("`@("`@
M("`@:68@*"1T>7!E("$]("=B=6YD;&4G*2![#0H@("`@("`@("`@("`@("`@
M)'1Y<&4@+CT@)W)E;&5A<V4G.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@)'1H:7,M/E]P86-K86=E26YF;R`]("1T:&ES+3Y?;65R9V5486<H)'1H
M:7,M/E]P86-K86=E26YF;RP@87)R87DH*2P-"B`@("`@("`@("`@("`@("!A
M<G)A>2@D='EP92`]/B!A<G)A>2@G8VAA;F=E;&]G)RDI*3L-"B`@("`@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F
M86QS93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE(&-U<G)E
M;G0@<F5L96%S92!T86<@:6X@;W)D97(@=&\@861D('1O(&ET#0H@("`@("H@
M0'!A<F%M(&)O;VP@<F5T=7)N<R!O;FQY(')E;&5A<V5S('1H870@:&%V92!I
M;G-T86QL8V]N9&ET:6]N(&EF('1R=64-"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M?&YU;&P-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F7V=E=$-U<G)E;G1296QE
M87-E*"1S=')I8W0@/2!T<G5E*0T*("`@('L-"B`@("`@("`@:68@*"1P(#T@
M)'1H:7,M/F=E=%!A8VMA9V54>7!E*"DI('L-"B`@("`@("`@("`@(&EF("@D
M<W1R:6-T*2![#0H@("`@("`@("`@("`@("`@:68@*"1P(#T]("=E>'1S<F,G
M*2![#0H@("`@("`@("`@("`@("`@("`@("1A(#T@;G5L;#L-"B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1A.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D<"`A/2`G8G5N9&QE)RD@
M>PT*("`@("`@("`@("`@("`@("1P("X]("=R96QE87-E)SL-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5)
M;F9O6R1P75LP72DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]P86-K86=E26YF;ULD<%U;8V]U;G0H)'1H:7,M/E]P86-K86=E26YF;ULD
M<%TI("T@,5T[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R1P73L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1A(#T@;G5L
M;#L-"B`@("`@("`@("`@(')E='5R;B`D83L-"B`@("`@("`@?0T*("`@('T-
M"@T*("`@("\J*@T*("`@("`J($%D9"!A(&9I;&4@=&\@=&AE(&-U<G)E;G0@
M<F5L96%S92!T:&%T('-H;W5L9"!B92!I;G-T86QL960@=6YD97(@82!D:69F
M97)E;G0@;F%M90T*("`@("`J($!P87)A;2!S=')I;F<@/&-O;G1E;G1S/B!P
M871H('1O(&9I;&4-"B`@("`@*B!`<&%R86T@<W1R:6YG(&YA;64@=&AE(&9I
M;&4@<VAO=6QD(&)E(&EN<W1A;&QE9"!A<PT*("`@("`J+PT*("`@(&9U;F-T
M:6]N(&%D9$EN<W1A;&Q!<R@D<&%T:"P@)&%S*0T*("`@('L-"B`@("`@("`@
M)'(@/2`F)'1H:7,M/E]G971#=7)R96YT4F5L96%S92@I.PT*("`@("`@("!I
M9B`H)'(@/3T](&YU;&PI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@
M("`@("`D<B`]("1T:&ES+3Y?;65R9V5486<H)'(L(&%R<F%Y*"=A='1R:6)S
M)R`]/B!A<G)A>2@G;F%M92<@/3X@)'!A=&@L("=A<R<@/3X@)&%S*2DL#0H@
M("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`G9FEL96QI<W0G
M(#T^(&%R<F%Y*"DL#0H@("`@("`@("`@("`@("`@)VEN<W1A;&PG(#T^(&%R
M<F%Y*"=I9VYO<F4G*0T*("`@("`@("`@("`@*2D[#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@061D(&$@9FEL92!T;R!T:&4@8W5R<F5N="!R96QE87-E
M('1H870@<VAO=6QD(&)E(&EG;F]R960-"B`@("`@*B!`<&%R86T@<W1R:6YG
M(#QC;VYT96YT<SX@<&%T:"!T;R!F:6QE#0H@("`@("H@0')E='5R;B!B;V]L
M('-U8V-E<W,@;V8@;W!E<F%T:6]N#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M861D26=N;W)E*"1P871H*0T*("`@('L-"B`@("`@("`@)'(@/2`F)'1H:7,M
M/E]G971#=7)R96YT4F5L96%S92@I.PT*("`@("`@("!I9B`H)'(@/3T](&YU
M;&PI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*
M("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@("`@("`D<B`]("1T
M:&ES+3Y?;65R9V5486<H)'(L(&%R<F%Y*"=A='1R:6)S)R`]/B!A<G)A>2@G
M;F%M92<@/3X@)'!A=&@I*2P-"B`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@
M("`@("`@("`@("=F:6QE;&ES="<@/3X@87)R87DH*2P-"B`@("`@("`@("`@
M("`@("`G:6=N;W)E)R`]/B!A<G)A>2@I#0H@("`@("`@("`@("`I*3L-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`@*B!!9&0@86X@97AT96YS:6]N(&)I;F%R
M>2!P86-K86=E(&9O<B!T:&ES(&5X=&5N<VEO;B!S;W5R8V4@8V]D92!R96QE
M87-E#0H@("`@("H-"B`@("`@*B!.;W1E('1H870@=&AE('!A8VMA9V4@;75S
M="!B92!F<F]M('1H92!S86UE(&-H86YN96P@87,@=&AE(&5X=&5N<VEO;B!S
M;W5R8V4@<&%C:V%G90T*("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!A9&1":6YA<GEP86-K86=E*"1P86-K86=E*0T*("`@
M('L-"B`@("`@("`@:68@*"1T:&ES+3YG971086-K86=E5'EP92@I("$]("=E
M>'1S<F,G*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@
M('T-"B`@("`@("`@)'(@/2`F)'1H:7,M/E]G971#=7)R96YT4F5L96%S92AF
M86QS92D[#0H@("`@("`@(&EF("@D<B`]/3T@;G5L;"D@>PT*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?
M:7-686QI9"`](#`[#0H@("`@("`@("1R(#T@)'1H:7,M/E]M97)G951A9R@D
M<BP@)'!A8VMA9V4L#0H@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@
M("`@("`G8FEN87)Y<&%C:V%G92<@/3X@87)R87DH)V9I;&5L:7-T)RDL#0H@
M("`@("`@("`@("`I*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!!9&0@
M82!C;VYF:6=U<F5O<'1I;VX@=&\@86X@97AT96YS:6]N('-O=7)C92!P86-K
M86=E#0H@("`@("H@0'!A<F%M('-T<FEN9PT*("`@("`J($!P87)A;2!S=')I
M;F<-"B`@("`@*B!`<&%R86T@<W1R:6YG#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@861D0V]N9FEG=7)E3W!T:6]N*"1N86UE+"`D<')O;7!T+"`D9&5F875L
M="`](&YU;&PI#0H@("`@>PT*("`@("`@("!I9B`H)'1H:7,M/F=E=%!A8VMA
M9V54>7!E*"D@(3T@)V5X='-R8R<I('L-"B`@("`@("`@("`@(')E='5R;B!F
M86QS93L-"B`@("`@("`@?0T*("`@("`@("`D<B`]("8D=&AI<RT^7V=E=$-U
M<G)E;G1296QE87-E*&9A;'-E*3L-"B`@("`@("`@:68@*"1R(#T]/2!N=6QL
M*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@
M("`@("`@)&]P="`](&%R<F%Y*"=A='1R:6)S)R`]/B!A<G)A>2@G;F%M92<@
M/3X@)&YA;64L("=P<F]M<'0G(#T^("1P<F]M<'0I*3L-"B`@("`@("`@:68@
M*"1D969A=6QT("$]/2!N=6QL*2![#0H@("`@("`@("`@("`D;W!T6R=D969A
M=6QT)UT@/2`D9&5F875L=#L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^
M7VES5F%L:60@/2`P.PT*("`@("`@("`D<B`]("1T:&ES+3Y?;65R9V5486<H
M)'(L("1O<'0L#0H@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`G8V]N9FEG=7)E;W!T:6]N)R`]/B!A<G)A>2@G8FEN87)Y<&%C:V%G92<L
M("=F:6QE;&ES="<I+`T*("`@("`@("`@("`@*2D[#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@4V5T(&%N(&EN<W1A;&QA=&EO;B!C;VYD:71I;VX@8F%S
M960@;VX@<&AP('9E<G-I;VX@9F]R('1H92!C=7)R96YT(')E;&5A<V4@<V5T
M#0H@("`@("H@0'!A<F%M('-T<FEN9R!M:6YI;75M('9E<G-I;VX-"B`@("`@
M*B!`<&%R86T@<W1R:6YG(&UA>&EM=6T@=F5R<VEO;@T*("`@("`J($!P87)A
M;2!F86QS97QA<G)A>2!I;F-O;7!A=&EB;&4@=F5R<VEO;G,@;V8@4$A0#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@<V5T4&AP26YS=&%L;$-O;F1I=&EO;B@D
M;6EN+"`D;6%X+"`D97AC;'5D92`](&9A;'-E*0T*("`@('L-"B`@("`@("`@
M)'(@/2`F)'1H:7,M/E]G971#=7)R96YT4F5L96%S92@I.PT*("`@("`@("!I
M9B`H)'(@/3T](&YU;&PI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@
M("`@("!I9B`H:7-S970H)');)VEN<W1A;&QC;VYD:71I;VYS)UU;)W!H<"==
M*2D@>PT*("`@("`@("`@("`@=6YS970H)');)VEN<W1A;&QC;VYD:71I;VYS
M)UU;)W!H<"==*3L-"B`@("`@("`@?0T*("`@("`@("`D9&5P(#T@87)R87DH
M)VUI;B<@/3X@)&UI;BP@)VUA>"<@/3X@)&UA>"D[#0H@("`@("`@(&EF("@D
M97AC;'5D92D@>PT*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1E>&-L=61E
M*2`F)B!C;W5N="@D97AC;'5D92D@/3T@,2D@>PT*("`@("`@("`@("`@("`@
M("1E>&-L=61E(#T@)&5X8VQU9&5;,%T[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`D9&5P6R=E>&-L=61E)UT@/2`D97AC;'5D93L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H)'1H:7,M/F=E=%!A8VMA9V54>7!E*"D@/3T@)V5X
M='-R8R<I('L-"B`@("`@("`@("`@("1R(#T@)'1H:7,M/E]M97)G951A9R@D
M<BP@)&1E<"P-"B`@("`@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@
M("`@("`@("`@)VEN<W1A;&QC;VYD:71I;VYS)R`]/B!A<G)A>2@G8V]N9FEG
M=7)E;W!T:6]N)RP@)V)I;F%R>7!A8VMA9V4G+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@)V9I;&5L:7-T)RDL#0H@("`@("`@("`@("`@("`@("`@("=P
M:'`G(#T^(&%R<F%Y*"=E>'1E;G-I;VXG+"`G;W,G+"`G87)C:"<I#0H@("`@
M("`@("`@("`@("`@*2D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`D<B`]("1T:&ES+3Y?;65R9V5486<H)'(L("1D97`L#0H@("`@("`@("`@
M("`@("`@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=I;G-T86QL8V]N
M9&ET:6]N<R<@/3X@87)R87DH)V9I;&5L:7-T)RDL#0H@("`@("`@("`@("`@
M("`@("`@("=P:'`G(#T^(&%R<F%Y*"=E>'1E;G-I;VXG+"`G;W,G+"`G87)C
M:"<I#0H@("`@("`@("`@("`@("`@*2D[#0H@("`@("`@('T-"B`@("!]#0H-
M"B`@("`O*BH-"B`@("`@*B!`<&%R86T@;W!T:6]N86Q\<F5Q=6ER960@;W!T
M:6]N86PL(')E<75I<F5D#0H@("`@("H@0'!A<F%M('-T<FEN9R!E>'1E;G-I
M;VX@;F%M90T*("`@("`J($!P87)A;2!S=')I;F<@;6EN:6UU;2!V97)S:6]N
M#0H@("`@("H@0'!A<F%M('-T<FEN9R!M87AI;75M('9E<G-I;VX-"B`@("`@
M*B!`<&%R86T@<W1R:6YG(')E8V]M;65N9&5D('9E<G-I;VX-"B`@("`@*B!`
M<&%R86T@87)R87D@:6YC;VUP871I8FQE('9E<G-I;VYS#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@861D17AT96YS:6]N26YS=&%L;$-O;F1I=&EO;B@D;F%M
M92P@)&UI;B`](&9A;'-E+"`D;6%X(#T@9F%L<V4L("1R96-O;6UE;F1E9"`]
M(&9A;'-E+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&5X8VQU9&4@/2!F86QS92D-"B`@("![#0H@("`@("`@("1R(#T@
M)B1T:&ES+3Y?9V5T0W5R<F5N=%)E;&5A<V4H*3L-"B`@("`@("`@:68@*"1R
M(#T]/2!N=6QL*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M("`@('T-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@
M)&1E<"`]("1T:&ES+3Y?8V]N<W1R=6-T1&5P*"1N86UE+"!F86QS92P@9F%L
M<V4L("1M:6XL("1M87@L("1R96-O;6UE;F1E9"P@)&5X8VQU9&4I.PT*("`@
M("`@("!I9B`H)'1H:7,M/F=E=%!A8VMA9V54>7!E*"D@/3T@)V5X='-R8R<I
M('L-"B`@("`@("`@("`@("1R(#T@)'1H:7,M/E]M97)G951A9R@D<BP@)&1E
M<"P-"B`@("`@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`@
M("`@)VEN<W1A;&QC;VYD:71I;VYS)R`]/B!A<G)A>2@G8V]N9FEG=7)E;W!T
M:6]N)RP@)V)I;F%R>7!A8VMA9V4G+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@)V9I;&5L:7-T)RDL#0H@("`@("`@("`@("`@("`@("`@("=E>'1E;G-I
M;VXG(#T^(&%R<F%Y*"=O<R<L("=A<F-H)RD-"B`@("`@("`@("`@("`@("`I
M*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1R(#T@)'1H:7,M
M/E]M97)G951A9R@D<BP@)&1E<"P-"B`@("`@("`@("`@("`@("!A<G)A>2@-
M"B`@("`@("`@("`@("`@("`@("`@)VEN<W1A;&QC;VYD:71I;VYS)R`]/B!A
M<G)A>2@G9FEL96QI<W0G*2P-"B`@("`@("`@("`@("`@("`@("`@)V5X=&5N
M<VEO;B<@/3X@87)R87DH)V]S)RP@)V%R8V@G*0T*("`@("`@("`@("`@("`@
M("DI.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4V5T
M(&%N(&EN<W1A;&QA=&EO;B!C;VYD:71I;VX@8F%S960@;VX@;W!E<F%T:6YG
M('-Y<W1E;2!F;W(@=&AE(&-U<G)E;G0@<F5L96%S92!S970-"B`@("`@*B!`
M<&%R86T@<W1R:6YG($]3(&YA;64-"B`@("`@*B!`<&%R86T@8F]O;"!W:&5T
M:&5R('1H:7,@3U,@:7,@:6YC;VUP871I8FQE('=I=&@@=&AE(&-U<G)E;G0@
M<F5L96%S90T*("`@("`J+PT*("`@(&9U;F-T:6]N('-E=$]S26YS=&%L;$-O
M;F1I=&EO;B@D;F%M92P@)&-O;F9L:6-T<R`](&9A;'-E*0T*("`@('L-"B`@
M("`@("`@)'(@/2`F)'1H:7,M/E]G971#=7)R96YT4F5L96%S92@I.PT*("`@
M("`@("!I9B`H)'(@/3T](&YU;&PI('L-"B`@("`@("`@("`@(')E='5R;B!F
M86QS93L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P
M.PT*("`@("`@("!I9B`H:7-S970H)');)VEN<W1A;&QC;VYD:71I;VYS)UU;
M)V]S)UTI*2![#0H@("`@("`@("`@("!U;G-E="@D<ELG:6YS=&%L;&-O;F1I
M=&EO;G,G75LG;W,G72D[#0H@("`@("`@('T-"B`@("`@("`@)&1E<"`](&%R
M<F%Y*"=N86UE)R`]/B`D;F%M92D[#0H@("`@("`@(&EF("@D8V]N9FQI8W1S
M*2![#0H@("`@("`@("`@("`D9&5P6R=C;VYF;&EC=',G72`]("<G.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("@D=&AI<RT^9V5T4&%C:V%G951Y<&4H*2`]
M/2`G97AT<W)C)RD@>PT*("`@("`@("`@("`@)'(@/2`D=&AI<RT^7VUE<F=E
M5&%G*"1R+"`D9&5P+`T*("`@("`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@
M("`@("`@("`@("`@("`G:6YS=&%L;&-O;F1I=&EO;G,G(#T^(&%R<F%Y*"=C
M;VYF:6=U<F5O<'1I;VXG+"`G8FEN87)Y<&%C:V%G92<L#0H@("`@("`@("`@
M("`@("`@("`@("`@("`G9FEL96QI<W0G*2P-"B`@("`@("`@("`@("`@("`@
M("`@)V]S)R`]/B!A<G)A>2@G87)C:"<I#0H@("`@("`@("`@("`@("`@*2D[
M#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D<B`]("1T:&ES+3Y?
M;65R9V5486<H)'(L("1D97`L#0H@("`@("`@("`@("`@("`@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`@("=I;G-T86QL8V]N9&ET:6]N<R<@/3X@87)R
M87DH)V9I;&5L:7-T)RDL#0H@("`@("`@("`@("`@("`@("`@("=O<R<@/3X@
M87)R87DH)V%R8V@G*0T*("`@("`@("`@("`@("`@("DI.PT*("`@("`@("!]
M#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4V5T(&%N(&EN<W1A;&QA=&EO
M;B!C;VYD:71I;VX@8F%S960@;VX@87)C:&ET96-T=7)E(&9O<B!T:&4@8W5R
M<F5N="!R96QE87-E('-E=`T*("`@("`J($!P87)A;2!S=')I;F<@87)C:&ET
M96-T=7)E('!A='1E<FX-"B`@("`@*B!`<&%R86T@8F]O;"!W:&5T:&5R('1H
M:7,@87)C:"!I<R!I;F-O;7!A=&EB;&4@=VET:"!T:&4@8W5R<F5N="!R96QE
M87-E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T07)C:$EN<W1A;&Q#;VYD
M:71I;VXH)'!A='1E<FXL("1C;VYF;&EC=',@/2!F86QS92D-"B`@("![#0H@
M("`@("`@("1R(#T@)B1T:&ES+3Y?9V5T0W5R<F5N=%)E;&5A<V4H*3L-"B`@
M("`@("`@:68@*"1R(#T]/2!N=6QL*2![#0H@("`@("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@
M,#L-"B`@("`@("`@:68@*&ES<V5T*"1R6R=I;G-T86QL8V]N9&ET:6]N<R==
M6R=A<F-H)UTI*2![#0H@("`@("`@("`@("!U;G-E="@D<ELG:6YS=&%L;&-O
M;F1I=&EO;G,G75LG87)C:"==*3L-"B`@("`@("`@?0T*("`@("`@("`D9&5P
M(#T@87)R87DH)W!A='1E<FXG(#T^("1P871T97)N*3L-"B`@("`@("`@:68@
M*"1C;VYF;&EC=',I('L-"B`@("`@("`@("`@("1D97!;)V-O;F9L:6-T<R==
M(#T@)R<[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1T:&ES+3YG971086-K
M86=E5'EP92@I(#T]("=E>'1S<F,G*2![#0H@("`@("`@("`@("`D<B`]("1T
M:&ES+3Y?;65R9V5486<H)'(L("1D97`L#0H@("`@("`@("`@("`@("`@87)R
M87DH#0H@("`@("`@("`@("`@("`@("`@("=I;G-T86QL8V]N9&ET:6]N<R<@
M/3X@87)R87DH)V-O;F9I9W5R96]P=&EO;B<L("=B:6YA<GEP86-K86=E)RP-
M"B`@("`@("`@("`@("`@("`@("`@("`@("=F:6QE;&ES="<I+`T*("`@("`@
M("`@("`@("`@("`@("`G87)C:"<@/3X@87)R87DH*0T*("`@("`@("`@("`@
M("`@("DI.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'(@/2`D
M=&AI<RT^7VUE<F=E5&%G*"1R+"`D9&5P+`T*("`@("`@("`@("`@("`@(&%R
M<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G:6YS=&%L;&-O;F1I=&EO;G,G
M(#T^(&%R<F%Y*"=F:6QE;&ES="<I+`T*("`@("`@("`@("`@("`@("`@("`G
M87)C:"<@/3X@87)R87DH*0T*("`@("`@("`@("`@("`@("DI.PT*("`@("`@
M("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@1F]R(&5X=&5N<VEO;B!B
M:6YA<GD@<F5L96%S97,L('1H:7,@:7,@=7-E9"!T;R!S<&5C:69Y(&5I=&AE
M<B!T:&4-"B`@("`@*B!S=&%T:6,@55))('1O(&$@<V]U<F-E('!A8VMA9V4L
M(&]R('1H92!P86-K86=E(&YA;64@86YD(&-H86YN96P@;V8@=&AE(&5X='-R
M8PT*("`@("`J('!A8VMA9V4@:70@:7,@8F%S960@;VXN#0H@("`@("H@0'!A
M<F%M('-T<FEN9R!086-K86=E(&YA;64L(&]R(&9U;&P@55))('1O('-O=7)C
M92!P86-K86=E("AE>'1S<F,@='EP92D-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!S9713;W5R8V5086-K86=E*"1P86-K86=E3W)5<FDI#0H@("`@>PT*("`@
M("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]P86-K86=E26YF;ULG8VAA;FYE;"==*2D@>PT*("`@("`@("`@
M("`@)'1H:7,M/E]P86-K86=E26YF;R`]("1T:&ES+3Y?:6YS97)T0F5F;W)E
M*"1T:&ES+3Y?<&%C:V%G94EN9F\L(&%R<F%Y*"=P:'!R96QE87-E)RP-"B`@
M("`@("`@("`@("`@("`G97AT<W)C<F5L96%S92<L("=E>'1B:6YR96QE87-E
M)RP@)V)U;F1L92<L("=C:&%N9V5L;V<G*2P-"B`@("`@("`@("`@("`@("`D
M<&%C:V%G94]R57)I+"`G<W)C<&%C:V%G92<I.PT*("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;R`]("1T:&ES+3Y?
M:6YS97)T0F5F;W)E*"1T:&ES+3Y?<&%C:V%G94EN9F\L(&%R<F%Y*"=P:'!R
M96QE87-E)RP-"B`@("`@("`@("`@("`@("`G97AT<W)C<F5L96%S92<L("=E
M>'1B:6YR96QE87-E)RP@)V)U;F1L92<L("=C:&%N9V5L;V<G*2P@)'!A8VMA
M9V5/<E5R:2P@)W-R8W5R:2<I.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@1V5N97)A=&4@82!V86QI9"!C:&%N9V4@;&]G(&5N=')Y
M(&9R;VT@=&AE(&-U<G)E;G0@<&%C:V%G92YX;6P-"B`@("`@*B!`<&%R86T@
M<W1R:6YG?&9A;'-E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5N97)A=&5#
M:&%N9V5,;V=%;G1R>2@D;F]T97,@/2!F86QS92D-"B`@("![#0H@("`@("`@
M(')E='5R;B!A<G)A>2@-"B`@("`@("`@("`@("=V97)S:6]N)R`]/B`-"B`@
M("`@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W)E
M;&5A<V4G(#T^("1T:&ES+3YG971697)S:6]N*"=R96QE87-E)RDL#0H@("`@
M("`@("`@("`@("`@("`@("=A<&DG(#T^("1T:&ES+3YG971697)S:6]N*"=A
M<&DG*2P-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("=S
M=&%B:6QI='DG(#T^#0H@("`@("`@("`@("`@("`@)'1H:7,M/F=E=%-T86)I
M;&ET>2@I+`T*("`@("`@("`@("`@)V1A=&4G(#T^("1T:&ES+3YG971$871E
M*"DL#0H@("`@("`@("`@("`G;&EC96YS92<@/3X@)'1H:7,M/F=E=$QI8V5N
M<V4H=')U92DL#0H@("`@("`@("`@("`G;F]T97,G(#T^("1N;W1E<R`_("1N
M;W1E<R`Z("1T:&ES+3YG971.;W1E<R@I#0H@("`@("`@("`@("`I.PT*("`@
M('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S=')I;F<@<F5L96%S92!V
M97)S:6]N('1O('-E="!C:&%N9V4@;&]G(&YO=&5S(&9O<@T*("`@("`J($!P
M87)A;2!A<G)A>2!O=71P=70@;V8@>T!L:6YK(&=E;F5R871E0VAA;F=E3&]G
M16YT<GDH*7T-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S971#:&%N9V5L;V=%
M;G1R>2@D<F5L96%S979E<G-I;VXL("1C;VYT96YT<RD-"B`@("![#0H@("`@
M("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG8VAA;F=E;&]G
M)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=C:&%N
M9V5L;V<G75LG<F5L96%S92==(#T@)&-O;G1E;G1S.PT*("`@("`@("`@("`@
M<F5T=7)N.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/E]P86-K86=E26YF;ULG8VAA;F=E;&]G)UU;)W)E;&5A<V4G75LP72DI('L-
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^7W!A8VMA9V5);F9O6R=C:&%N9V5L
M;V<G75LG<F5L96%S92==6R=V97)S:6]N)UU;)W)E;&5A<V4G72`]/2`D<F5L
M96%S979E<G-I;VXI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA
M9V5);F9O6R=C:&%N9V5L;V<G75LG<F5L96%S92==(#T@87)R87DH#0H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V-H86YG96QO
M9R==6R=R96QE87-E)UTI.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=C:&%N9V5L;V<G75LG
M<F5L96%S92==(#T@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%C:V%G94EN9F];)V-H86YG96QO9R==6R=R96QE87-E)UTI.PT*("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=C:&%N
M9V5L;V<G75LG<F5L96%S92==6UT@/2`D8V]N=&5N=',[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C:"@D=&AI<RT^7W!A8VMA
M9V5);F9O6R=C:&%N9V5L;V<G75LG<F5L96%S92==(&%S("1I;F1E>"`]/B`D
M8VAA;F=E;&]G*2![#0H@("`@("`@("`@("!I9B`H:7-S970H)&-H86YG96QO
M9ULG=F5R<VEO;B==*2`F)@T*("`@("`@("`@("`@("`@("`@<W1R;F%T8V%S
M96-M<"@D8VAA;F=E;&]G6R=V97)S:6]N)UU;)W)E;&5A<V4G72P@)')E;&5A
M<V5V97)S:6]N*2`]/2`P*2![#0H@("`@("`@("`@("`@("`@)&-U<FQO9R`]
M("1I;F1E>#L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H:7-S970H)&-U<FQO9RDI('L-"B`@("`@("`@("`@("1T:&ES+3Y?<&%C
M:V%G94EN9F];)V-H86YG96QO9R==6R=R96QE87-E)UU;)&-U<FQO9UT@/2`D
M8V]N=&5N=',[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D=&AI
M<RT^7W!A8VMA9V5);F9O6R=C:&%N9V5L;V<G75LG<F5L96%S92==6UT@/2`D
M8V]N=&5N=',[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!296UO=F4@=&AE(&-H86YG96QO9R!E;G1I<F5L>0T*("`@("`J+PT*("`@
M(&9U;F-T:6]N(&-L96%R0VAA;F=E3&]G*"D-"B`@("![#0H@("`@("`@('5N
M<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-H86YG96QO9R==*3L-"B`@("!]
M#0I]#0H_/@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+U!%05(O4&%C:V%G949I;&4O=C(O5F%L:61A=&]R+G!H<```
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`R,S8U-C<@,3`U,34T,S,W,S(@,#(T,S4W
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP#0HO+PT*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\
M(%!(4"!697)S:6]N(#4@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PT*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P-"!4
M:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@5&AI<R!S
M;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!0
M2%`@;&EC96YS92P@("`@("`@?`T*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET
M:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@
M("`@("!\#0HO+R!\(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E
M+7=E8B!A="!T:&4@9F]L;&]W:6YG('5R;#H@("`@("`@("`@('P-"B\O('P@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"!)9B!Y;W4@9&ED(&YO
M="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U
M;F%B;&4@=&\@("!\#0HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L
M9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P-
M"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O
M<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\($%U=&AO<CH@1W)E9R!"96%V97(@
M/&-E;&QO9T!P:'`N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P-"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+PT*+R\@)$ED.B!686QI9&%T
M;W(N<&AP+'8@,2XX-B`R,#`V+S`S+S`R(#$X.C$T.C$S(&-E;&QO9R!%>'`@
M)`T*+RHJ#0H@*B!0<FEV871E('9A;&ED871I;VX@8VQA<W,@=7-E9"!B>2!0
M14%27U!A8VMA9V5&:6QE7W8R("T@9&\@;F]T('5S92!D:7)E8W1L>2P@:71S
M#0H@*B!S;VQE('!U<G!O<V4@:7,@=&\@<W!L:70@=7`@=&AE(%!%05(O4&%C
M:V%G949I;&4O=C(N<&AP(&9I;&4@=&\@;6%K92!I="!S;6%L;&5R#0H@*B!`
M875T:&]R($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!A8V-E
M<W,@<')I=F%T90T*("HO#0IC;&%S<R!014%27U!A8VMA9V5&:6QE7W8R7U9A
M;&ED871O<@T*>PT*("`@("\J*@T*("`@("`J($!V87(@87)R87D-"B`@("`@
M*B\-"B`@("!V87(@)%]P86-K86=E26YF;SL-"B`@("`O*BH-"B`@("`@*B!`
M=F%R(%!%05)?4&%C:V%G949I;&5?=C(-"B`@("`@*B\-"B`@("!V87(@)%]P
M9CL-"B`@("`O*BH-"B`@("`@*B!`=F%R(%!%05)?17)R;W)3=&%C:PT*("`@
M("`J+PT*("`@('9A<B`D7W-T86-K.PT*("`@("\J*@T*("`@("`J($!V87(@
M:6YT#0H@("`@("HO#0H@("`@=F%R("1?:7-686QI9"`](#`[#0H@("`@+RHJ
M#0H@("`@("H@0'9A<B!I;G0-"B`@("`@*B\-"B`@("!V87(@)%]F:6QE<U9A
M;&ED(#T@,#L-"B`@("`O*BH-"B`@("`@*B!`=F%R(&EN=`T*("`@("`J+PT*
M("`@('9A<B`D7V-U<E-T871E(#T@,#L-"B`@("`O*BH-"B`@("`@*B!`<&%R
M86T@4$5!4E]086-K86=E1FEL95]V,@T*("`@("`J($!P87)A;2!I;G0-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!V86QI9&%T92@F)'!F+"`D<W1A=&4@/2!0
M14%27U9!3$E$051%7TY/4DU!3"D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?
M<&8@/2`F)'!F.PT*("`@("`@("`D=&AI<RT^7V-U<E-T871E(#T@)'-T871E
M.PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O(#T@)'1H:7,M/E]P9BT^
M9V5T07)R87DH*3L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@)'1H:7,M
M/E]P9BT^7VES5F%L:60[#0H@("`@("`@("1T:&ES+3Y?9FEL97-686QI9"`]
M("1T:&ES+3Y?<&8M/E]F:6QE<U9A;&ED.PT*("`@("`@("`D=&AI<RT^7W-T
M86-K(#T@)B1P9BT^7W-T86-K.PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YG
M971%<G)O<G,H=')U92D[#0H@("`@("`@(&EF("@H)'1H:7,M/E]I<U9A;&ED
M("8@)'-T871E*2`]/2`D<W1A=&4I('L-"B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P
M86-K86=E26YF;RD@?'P@(6ES7V%R<F%Y*"1T:&ES+3Y?<&%C:V%G94EN9F\I
M*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=A='1R:6)S
M)UU;)W9E<G-I;VXG72D@?'P-"B`@("`@("`@("`@("`@)'1H:7,M/E]P86-K
M86=E26YF;ULG871T<FEB<R==6R=V97)S:6]N)UT@(3T@)S(N,"<I('L-"B`@
M("`@("`@("`@("1T:&ES+3Y?;F]086-K86=E5F5R<VEO;B@I.PT*("`@("`@
M("!]#0H@("`@("`@("1S=')U8W1U<F4@/0T*("`@("`@("!A<G)A>2@-"B`@
M("`@("`@("`@("=N86UE)RP-"B`@("`@("`@("`@("=C:&%N;F5L?'5R:2<L
M#0H@("`@("`@("`@("`G*F5X=&5N9',G+"`O+R!C86XG="!B92!M=6QT:7!L
M92P@8G5T('1H:7,@=V]R:W,@9FEN90T*("`@("`@("`@("`@)W-U;6UA<GDG
M+`T*("`@("`@("`@("`@)V1E<V-R:7!T:6]N)RP-"B`@("`@("`@("`@("<K
M;&5A9"<L("\O('1H97-E(&%L;"!N965D(&-O;G1E;G0@8VAE8VMS#0H@("`@
M("`@("`@("`G*F1E=F5L;W!E<B<L#0H@("`@("`@("`@("`G*F-O;G1R:6)U
M=&]R)RP-"B`@("`@("`@("`@("<J:&5L<&5R)RP-"B`@("`@("`@("`@("=D
M871E)RP-"B`@("`@("`@("`@("<J=&EM92<L#0H@("`@("`@("`@("`G=F5R
M<VEO;B<L#0H@("`@("`@("`@("`G<W1A8FEL:71Y)RP-"B`@("`@("`@("`@
M("=L:6-E;G-E+3X_=7)I+3X_9FEL97-O=7)C92<L#0H@("`@("`@("`@("`G
M;F]T97,G+`T*("`@("`@("`@("`@)V-O;G1E;G1S)RP@+R]S<&5C:6%L('9A
M;&ED871I;VX@;F5E9&5D#0H@("`@("`@("`@("`G*F-O;7!A=&EB;&4G+`T*
M("`@("`@("`@("`@)V1E<&5N9&5N8VEE<R<L("\O<W!E8VEA;"!V86QI9&%T
M:6]N(&YE961E9`T*("`@("`@("`@("`@)RIU<V5S<F]L92<L#0H@("`@("`@
M("`@("`G*G5S97-T87-K)RP@+R\@<F5S97)V92!T:&5S92!F;W(@,2XT+C!A
M,2!T;R!I;7!L96UE;G0-"B`@("`@("`@("`@("`@("`@("`@("`@("`O+R!T
M:&ES('=I;&P@86QL;W<@82!P86-K86=E+GAM;"!T;R!G<F%C969U;&QY('-A
M>2!I=`T*("`@("`@("`@("`@("`@("`@("`@("`@("\O(&YE961S(&$@8V5R
M=&%I;B!P86-K86=E(&EN<W1A;&QE9"!I;B!O<F1E<B!T;R!I;7!L96UE;G0@
M82!R;VQE(&]R('1A<VL-"B`@("`@("`@("`@("<J<')O=FED97-E>'1E;G-I
M;VXG+`T*("`@("`@("`@("`@)RIS<F-P86-K86=E?"IS<F-U<FDG+`T*("`@
M("`@("`@("`@)RMP:'!R96QE87-E?"ME>'1S<F-R96QE87-E?"ME>'1B:6YR
M96QE87-E?&)U;F1L92<L("\O<W!E8VEA;"!V86QI9&%T:6]N(&YE961E9`T*
M("`@("`@("`@("`@)RIC:&%N9V5L;V<G+`T*("`@("`@("`I.PT*("`@("`@
M("`D=&5S="`]("1T:&ES+3Y?<&%C:V%G94EN9F\[#0H@("`@("`@("\O(&EG
M;F]R92!P;W-T+6EN<W1A;&QA=&EO;B!A<G)A>2!F:65L9',-"B`@("`@("`@
M:68@*&%R<F%Y7VME>5]E>&ES=',H)V9I;&5L:7-T)RP@)'1E<W0I*2![#0H@
M("`@("`@("`@("!U;G-E="@D=&5S=%LG9FEL96QI<W0G72D[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)U]L87-T;6]D:69I
M960G+"`D=&5S="DI('L-"B`@("`@("`@("`@('5N<V5T*"1T97-T6R=?;&%S
M=&UO9&EF:65D)UTI.PT*("`@("`@("!]#0H@("`@("`@(&EF("AA<G)A>5]K
M97E?97AI<W1S*"<C8FEN87)Y<&%C:V%G92<L("1T97-T*2D@>PT*("`@("`@
M("`@("`@=6YS970H)'1E<W1;)R-B:6YA<GEP86-K86=E)UTI.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"=O;&0G+"`D=&5S
M="DI('L-"B`@("`@("`@("`@('5N<V5T*"1T97-T6R=O;&0G72D[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)U]L87-T=F5R
M<VEO;B<L("1T97-T*2D@>PT*("`@("`@("`@("`@=6YS970H)'1E<W1;)U]L
M87-T=F5R<VEO;B==*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21T:&ES
M+3Y?<W1U<&ED4V-H96UA5F%L:61A=&4H)'-T<G5C='5R92P-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T97-T+"`G/'!A
M8VMA9V4^)RDI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]P86-K86=E26YF;ULG
M;F%M92==*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]T86=#86YN;W1"945M
M<'1Y*"=N86UE)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1T
M:&ES+3Y?<&%C:V%G94EN9F];)W5R:2==*2D@>PT*("`@("`@("`@("`@)'1E
M<W0@/2`G=7)I)SL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1T
M97-T(#T@)V-H86YN96PG.PT*("`@("`@("!]#0H@("`@("`@(&EF("AE;7!T
M>2@D=&AI<RT^7W!A8VMA9V5);F9O6R1T97-T72DI('L-"B`@("`@("`@("`@
M("1T:&ES+3Y?=&%G0V%N;F]T0F5%;7!T>2@D=&5S="D[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3Y?<&%C:V%G94EN9F];)VQI
M8V5N<V4G72D@)B8-"B`@("`@("`@("`@("`@*"%I<W-E="@D=&AI<RT^7W!A
M8VMA9V5);F9O6R=L:6-E;G-E)UU;)U]C;VYT96YT)UTI('Q\#0H@("`@("`@
M("`@("`@(&5M<'1Y*"1T:&ES+3Y?<&%C:V%G94EN9F];)VQI8V5N<V4G75LG
M7V-O;G1E;G0G72DI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W1A9T-A;FYO
M=$)E16UP='DH)VQI8V5N<V4G*3L-"B`@("`@("`@?2!E;'-E:68@*&5M<'1Y
M*"1T:&ES+3Y?<&%C:V%G94EN9F];)VQI8V5N<V4G72DI('L-"B`@("`@("`@
M("`@("1T:&ES+3Y?=&%G0V%N;F]T0F5%;7!T>2@G;&EC96YS92<I.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W!A8VMA9V5);F9O
M6R=S=6UM87)Y)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W1A9T-A;FYO
M=$)E16UP='DH)W-U;6UA<GDG*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M96UP='DH)'1H:7,M/E]P86-K86=E26YF;ULG9&5S8W)I<'1I;VXG72DI('L-
M"B`@("`@("`@("`@("1T:&ES+3Y?=&%G0V%N;F]T0F5%;7!T>2@G9&5S8W)I
M<'1I;VXG*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H96UP='DH)'1H:7,M
M/E]P86-K86=E26YF;ULG9&%T92==*2D@>PT*("`@("`@("`@("`@)'1H:7,M
M/E]T86=#86YN;W1"945M<'1Y*"=D871E)RD[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%C:V%G94EN9F];)VYO=&5S)UTI*2![
M#0H@("`@("`@("`@("`D=&AI<RT^7W1A9T-A;FYO=$)E16UP='DH)VYO=&5S
M)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C
M:V%G94EN9F];)W1I;64G72D@)B8@96UP='DH)'1H:7,M/E]P86-K86=E26YF
M;ULG=&EM92==*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]T86=#86YN;W1"
M945M<'1Y*"=T:6UE)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<&5N9&5N8VEE<R==*2D@>PT*("`@
M("`@("`@("`@)'1H:7,M/E]V86QI9&%T941E<&5N9&5N8VEE<R@I.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O
M6R=C;VUP871I8FQE)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W9A;&ED
M871E0V]M<&%T:6)L92@I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]P86-K86=E26YF;ULG8G5N9&QE)UTI*2![#0H@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S
M)UU;)V1I<B==*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?9FEL96QI
M<W1-=7-T0V]N=&%I;D1I<B@G8V]N=&5N=',G*3L-"B`@("`@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=&5N=',G75LG9FEL
M92==*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?9FEL96QI<W1#86YN
M;W1#;VYT86EN1FEL92@G8V]N=&5N=',G*3L-"B`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@)'1H:7,M/E]V86QI9&%T94UA:6YT86EN97)S*"D[#0H@("`@("`@("1T
M:&ES+3Y?=F%L:61A=&53=&%B:6QI='E697)S:6]N*"D[#0H@("`@("`@("1F
M86EL(#T@9F%L<V4[#0H@("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"=U
M<V5S<F]L92<L("1T:&ES+3Y?<&%C:V%G94EN9F\I*2![#0H@("`@("`@("`@
M("`D<F]L97,@/2`D=&AI<RT^7W!A8VMA9V5);F9O6R=U<V5S<F]L92==.PT*
M("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D<F]L97,I('Q\("%I<W-E="@D
M<F]L97-;,%TI*2![#0H@("`@("`@("`@("`@("`@)')O;&5S(#T@87)R87DH
M)')O;&5S*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@
M*"1R;VQE<R!A<R`D<F]L92D@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)')O;&5;)W)O;&4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]U<V5S<F]L971A<VM-=7-T2&%V95)O;&5487-K*"=U<V5S<F]L92<L
M("=R;VQE)RD[#0H@("`@("`@("`@("`@("`@("`@("1F86EL(#T@=')U93L-
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1R;VQE6R=C:&%N;F5L)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1R;VQE6R=U<FDG72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W5S97-R;VQE=&%S
M:TUU<W1(879E0VAA;FYE;$]R57)I*"1R;VQE6R=R;VQE)UTL("=U<V5S<F]L
M92<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F86EL(#T@=')U
M93L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E:68@*"%I<W-E="@D<F]L95LG<&%C:V%G92==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]U<V5S<F]L971A<VM-
M=7-T2&%V95!A8VMA9V4H)')O;&5;)W)O;&4G72P@)W5S97-R;VQE)RD[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D9F%I;"`]('1R=64[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H
M)W5S97-T87-K)RP@)'1H:7,M/E]P86-K86=E26YF;RDI('L-"B`@("`@("`@
M("`@("1R;VQE<R`]("1T:&ES+3Y?<&%C:V%G94EN9F];)W5S97-T87-K)UT[
M#0H@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1R;VQE<RD@?'P@(6ES<V5T
M*"1R;VQE<ULP72DI('L-"B`@("`@("`@("`@("`@("`D<F]L97,@/2!A<G)A
M>2@D<F]L97,I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C
M:"`H)')O;&5S(&%S("1R;VQE*2![#0H@("`@("`@("`@("`@("`@:68@*"%I
M<W-E="@D<F]L95LG=&%S:R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W5S97-R;VQE=&%S:TUU<W1(879E4F]L951A<VLH)W5S97-T87-K
M)RP@)W1A<VLG*3L-"B`@("`@("`@("`@("`@("`@("`@)&9A:6P@/2!T<G5E
M.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M("`@(&EF("@A:7-S970H)')O;&5;)V-H86YN96PG72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@A:7-S970H)')O;&5;)W5R:2==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=7-E<W)O;&5T
M87-K375S=$AA=F5#:&%N;F5L3W)5<FDH)')O;&5;)W1A<VLG72P@)W5S97-T
M87-K)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9A:6P@/2!T
M<G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("!](&5L<V5I9B`H(6ES<V5T*"1R;VQE6R=P86-K86=E)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W5S97-R;VQE=&%S
M:TUU<W1(879E4&%C:V%G92@D<F]L95LG=&%S:R==+"`G=7-E<W1A<VLG*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1F86EL(#T@=')U93L-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&9A:6PI('L-"B`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D=&AI
M<RT^7W9A;&ED871E1FEL96QI<W0H*3L-"B`@("`@("`@)'1H:7,M/E]V86QI
M9&%T95)E;&5A<V4H*3L-"B`@("`@("`@:68@*"$D=&AI<RT^7W-T86-K+3YH
M87-%<G)O<G,H*2D@>PT*("`@("`@("`@("`@)&-H86X@/2`D=&AI<RT^7W!F
M+3Y?<F5G:7-T<GDM/F=E=$-H86YN96PH)'1H:7,M/E]P9BT^9V5T0VAA;FYE
M;"@I+"!T<G5E*3L-"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1C
M:&%N*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?=6YK;F]W;D-H86YN
M96PH)'1H:7,M/E]P9BT^9V5T0VAA;FYE;"@I*3L-"B`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@)'9A;'!A8VL@/2`D8VAA;BT^9V5T
M5F%L:61A=&EO;E!A8VMA9V4H*3L-"B`@("`@("`@("`@("`@("`O+R!F;W(@
M8VAA;FYE;"!V86QI9&%T;W(@<&%C:V%G97,L(&%L=V%Y<R!U<V4@=&AE(&1E
M9F%U;'0@4$5!4B!V86QI9&%T;W(N#0H@("`@("`@("`@("`@("`@+R\@;W1H
M97)W:7-E+"!T:&5Y(&-A;B=T(&)E(&EN<W1A;&QE9"!O<B!P86-K86=E9`T*
M("`@("`@("`@("`@("`@("1V86QI9&%T;W(@/2`D8VAA;BT^9V5T5F%L:61A
M=&EO;D]B:F5C="@D=&AI<RT^7W!F+3YG971086-K86=E*"DI.PT*("`@("`@
M("`@("`@("`@(&EF("@A)'9A;&ED871O<BD@>PT*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R
M)RP-"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y7VUE<F=E*`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=C:&%N;F5L)R`]/B`D
M8VAA;BT^9V5T3F%M92@I+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=P86-K86=E)R`]/B`D=&AI<RT^7W!F+3YG971086-K86=E*"DI
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'!A8VL-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@)W!A8VMA9V4@(B5C:&%N;F5L)2\E<&%C:V%G924B(&-A;FYO
M="!B92!P<F]P97)L>2!V86QI9&%T960@=VET:&]U="`G("X-"B`@("`@("`@
M("`@("`@("`@("`@("`@("=V86QI9&%T:6]N('!A8VMA9V4@(B5C:&%N;F5L
M)2\E;F%M924M)79E<G-I;VXE(B<I.PT*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@)'9A;&ED871O<BT^<V5T4&%C:V%G949I;&4H
M)'1H:7,M/E]P9BD[#0H@("`@("`@("`@("`@("`@)'9A;&ED871O<BT^=F%L
M:61A=&4H)'-T871E*3L-"B`@("`@("`@("`@("`@("`D9F%I;'5R97,@/2`D
M=F%L:61A=&]R+3YG971&86EL=7)E<R@I.PT*("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*"1F86EL=7)E<ULG97)R;W)S)UT@87,@)&5R<F]R*2![#0H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/
M3E]?+"`G97)R;W(G+"`D97)R;W(L#0H@("`@("`@("`@("`@("`@("`@("`@
M("`G0VAA;FYE;"!V86QI9&%T;W(@97)R;W(Z(&9I96QD("(E9FEE;&0E(B`M
M("5R96%S;VXE)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1F86EL=7)E<ULG=V%R;FEN9W,G72!A<R`D=V%R;FEN
M9RD@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H
M*%]?1E5.0U1)3TY?7RP@)W=A<FYI;F<G+"`D=V%R;FEN9RP-"B`@("`@("`@
M("`@("`@("`@("`@("`@("=#:&%N;F5L('9A;&ED871O<B!W87)N:6YG.B!F
M:65L9"`B)69I96QD)2(@+2`E<F5A<V]N)2<I.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^
M7W!F+3Y?:7-686QI9"`]("1T:&ES+3Y?:7-686QI9"`]("$D=&AI<RT^7W-T
M86-K+3YH87-%<G)O<G,H)V5R<F]R)RD[#0H@("`@("`@(&EF("@D=&AI<RT^
M7VES5F%L:60@)B8@)'-T871E(#T](%!%05)?5D%,241!5$5?4$%#2T%'24Y'
M("8F("$D=&AI<RT^7V9I;&5S5F%L:60I('L-"B`@("`@("`@("`@(&EF("@D
M=&AI<RT^7W!F+3YG971086-K86=E5'EP92@I(#T]("=B=6YD;&4G*2![#0H@
M("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?86YA;'EZ94)U;F1L961086-K
M86=E<R@I*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9FEL97-6
M86QI9"`]("1T:&ES+3Y?<&8M/E]F:6QE<U9A;&ED(#T@=')U93L-"B`@("`@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!F+3Y?:7-686QI9"`]("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("!I9B`H(21T:&ES+3Y?86YA;'EZ95!H<$9I;&5S*"DI('L-"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P9BT^7VES5F%L:60@/2`D=&AI
M<RT^7VES5F%L:60@/2`P.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9FEL97-686QI9"`]("1T:&ES
M+3Y?<&8M/E]F:6QE<U9A;&ED(#T@=')U93L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"1T:&ES
M+3Y?:7-686QI9"D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&8M
M/E]I<U9A;&ED(#T@)'1H:7,M/E]I<U9A;&ED(#T@)'-T871E.PT*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B`D=&AI<RT^7W!F+3Y?:7-686QI9"`]("1T
M:&ES+3Y?:7-686QI9"`](#`[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7W-T
M=7!I9%-C:&5M859A;&ED871E*"1S=')U8W1U<F4L("1X;6PL("1R;V]T*0T*
M("`@('L-"B`@("`@("`@:68@*"%I<U]A<G)A>2@D>&UL*2D@>PT*("`@("`@
M("`@("`@)'AM;"`](&%R<F%Y*"D[#0H@("`@("`@('T-"B`@("`@("`@)&ME
M>7,@/2!A<G)A>5]K97ES*"1X;6PI.PT*("`@("`@("!R97-E="@D:V5Y<RD[
M#0H@("`@("`@("1K97D@/2!C=7)R96YT*"1K97ES*3L-"B`@("`@("`@=VAI
M;&4@*"1K97D@/3T@)V%T=')I8G,G('Q\("1K97D@/3T@)U]C;VYT96YT<R<I
M('L-"B`@("`@("`@("`@("1K97D@/2!N97AT*"1K97ES*3L-"B`@("`@("`@
M?0T*("`@("`@("`D=6YF;W5N9'1A9W,@/2`D;W!T:6]N86QT86=S(#T@87)R
M87DH*3L-"B`@("`@("`@)')E="`]('1R=64[#0H@("`@("`@("1M:7-M871C
M:"`](&9A;'-E.PT*("`@("`@("!F;W)E86-H("@D<W1R=6-T=7)E(&%S("1S
M=')U8RD@>PT*("`@("`@("`@("`@:68@*"1K97DI('L-"B`@("`@("`@("`@
M("`@("`D=&%G(#T@)'AM;%LD:V5Y73L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("1T97-T(#T@)'1H:7,M/E]P<F]C97-S4W1R=6-T=7)E*"1S=')U
M8RD[#0H@("`@("`@("`@("!I9B`H:7-S970H)'1E<W1;)V-H;VEC97,G72DI
M('L-"B`@("`@("`@("`@("`@("`D;&]O<V4@/2!T<G5E.PT*("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1T97-T6R=C:&]I8V5S)UT@87,@)&-H;VEC92D@
M>PT*("`@("`@("`@("`@("`@("`@("!I9B`H)&ME>2`]/2`D8VAO:6-E6R=T
M86<G72D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&ME>2`](&YE>'0H
M)&ME>7,I.PT*("`@("`@("`@("`@("`@("`@("`@("`@=VAI;&4@*"1K97D@
M/3T@)V%T=')I8G,G('Q\("1K97D@/3T@)U]C;VYT96YT<R<I('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D:V5Y(#T@;F5X="@D:V5Y<RD[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D=6YF;W5N9'1A9W,@/2`D;W!T:6]N86QT86=S(#T@87)R87DH*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1M:7-M871C:"`](&9A;'-E.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1K97D@)B8@)&ME>2`A/2`D
M8VAO:6-E6R=T86<G72`F)B!I<W-E="@D8VAO:6-E6R=M=6QT:7!L92==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1U;F9O=6YD=&%G<UM=
M(#T@)&-H;VEC95LG=&%G)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&]P=&EO;F%L=&%G<UM=(#T@)&-H;VEC95LG=&%G)UT[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"1K97DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&UI<VUA=&-H(#T@=')U93L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`D<F5T("8]("1T:&ES
M+3Y?<')O8V5S<T%T=')I8G,H)&-H;VEC92P@)'1A9RP@)')O;W0I.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64@,CL-"B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1U
M;F9O=6YD=&%G<UM=(#T@)&-H;VEC95LG=&%G)UT[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D;6ES;6%T8V@@/2!T<G5E.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&-H;VEC
M95LG;75L=&EP;&4G72D@?'P@)&-H;VEC95LG;75L=&EP;&4G72`A/2`G*B<I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1L;V]S92`](&9A;'-E.PT*
M("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)&]P=&EO;F%L=&%G<UM=(#T@)&-H;VEC95LG=&%G)UT[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@:68@*"$D;&]O<V4I('L-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]I;G9A;&ED5&%G3W)D97(H)'5N9F]U;F1T86=S+"`D:V5Y
M+"`D<F]O="D[#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@(&EF("@D:V5Y("$]("1T97-T6R=T86<G72D@>PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1E<W1;)VUU;'1I<&QE)UTI
M("8F("1T97-T6R=M=6QT:7!L92==("$]("<J)RD@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)'5N9F]U;F1T86=S6UT@/2`D=&5S=%LG=&%G)UT[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VEN=F%L:61486=/<F1E
M<B@D=6YF;W5N9'1A9W,L("1K97DL("1R;V]T*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D:V5Y*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&UI<VUA=&-H(#T@=')U
M93L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1U;F9O=6YD=&%G<UM=(#T@)'1E<W1;)W1A9R==.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)&]P=&EO;F%L=&%G<UM=(#T@)'1E<W1;
M)W1A9R==.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)'1E<W1;)VUU;'1I<&QE)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VEN=F%L:61486=/<F1E<B@D
M=6YF;W5N9'1A9W,L("1K97DL("1R;V]T*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D=6YF;W5N9'1A9W,@
M/2`D;W!T:6]N86QT86=S(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@("`@
M("`@)&UI<VUA=&-H(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("1K97D@/2!N97AT*"1K97ES*3L-"B`@("`@("`@("`@
M("`@("!W:&EL92`H)&ME>2`]/2`G871T<FEB<R<@?'P@)&ME>2`]/2`G7V-O
M;G1E;G1S)RD@>PT*("`@("`@("`@("`@("`@("`@("`D:V5Y(#T@;F5X="@D
M:V5Y<RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF
M("@D:V5Y("8F("1K97D@(3T@)'1E<W1;)W1A9R==("8F(&ES<V5T*"1T97-T
M6R=M=6QT:7!L92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=6YF;W5N
M9'1A9W-;72`]("1T97-T6R=T86<G73L-"B`@("`@("`@("`@("`@("`@("`@
M)&]P=&EO;F%L=&%G<UM=(#T@)'1E<W1;)W1A9R==.PT*("`@("`@("`@("`@
M("`@("`@("`D;6ES;6%T8V@@/2!T<G5E.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`D<F5T("8]("1T:&ES+3Y?<')O8V5S<T%T=')I
M8G,H)'1E<W0L("1T86<L("1R;V]T*3L-"B`@("`@("`@("`@("`@("!C;VYT
M:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M(21M:7-M871C:"`F)B!C;W5N="@D;W!T:6]N86QT86=S*2D@>PT*("`@("`@
M("`@("`@+R\@9&]N)W0@97)R;W(@;W5T(&]N(&%N>2!O<'1I;VYA;"!T86=S
M#0H@("`@("`@("`@("`D=6YF;W5N9'1A9W,@/2!A<G)A>5]D:69F*"1U;F9O
M=6YD=&%G<RP@)&]P=&EO;F%L=&%G<RD[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&-O=6YT*"1U;F9O=6YD=&%G<RDI('L-"B`@("`@("`@("`@("1T:&ES
M+3Y?:6YV86QI9%1A9T]R9&5R*"1U;F9O=6YD=&%G<RP@)&ME>2P@)')O;W0I
M.PT*("`@("`@("!](&5L<V5I9B`H)&ME>2D@>PT*("`@("`@("`@("`@+R\@
M=6YK;F]W;B!T86=S#0H@("`@("`@("`@("`D=&AI<RT^7VEN=F%L:61486=/
M<F1E<B@G*FYO('1A9W,@86QL;W=E9"!H97)E*B<L("1K97DL("1R;V]T*3L-
M"B`@("`@("`@("`@('=H:6QE("@D:V5Y(#T@;F5X="@D:V5Y<RDI('L-"B`@
M("`@("`@("`@("`@("`D=&AI<RT^7VEN=F%L:61486=/<F1E<B@G*FYO('1A
M9W,@86QL;W=E9"!H97)E*B<L("1K97DL("1R;V]T*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-
M"B`@("!F=6YC=&EO;B!?<')O8V5S<T%T=')I8G,H)&-H;VEC92P@)'1A9RP@
M)&-O;G1E>'0I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)&-H;VEC95LG
M871T<FEB<R==*2D@>PT*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D=&%G
M*2D@>PT*("`@("`@("`@("`@("`@("1T86<@/2!A<G)A>2@D=&%G*3L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("1T86=S(#T@)'1A9SL-"B`@("`@
M("`@("`@(&EF("@A:7-S970H)'1A9W-;,%TI*2![#0H@("`@("`@("`@("`@
M("`@)'1A9W,@/2!A<G)A>2@D=&%G<RD[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`D<F5T(#T@=')U93L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1T
M86=S(&%S("1I(#T^("1T86<I('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES
M7V%R<F%Y*"1T86<I('Q\("%I<W-E="@D=&%G6R=A='1R:6)S)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1C:&]I8V5;)V%T=')I8G,G
M72!A<R`D871T<FEB*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M)&%T=')I8GLP?2`A/2`G/R<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<F5T("8]("1T:&ES+3Y?=&%G2&%S3F]!='1R:6)S*"1C:&]I8V5;
M)W1A9R==+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]N
M=&5X="D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64@
M,CL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!F
M;W)E86-H("@D8VAO:6-E6R=A='1R:6)S)UT@87,@)&%T=')I8BD@>PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H)&%T=')I8GLP?2`A/2`G/R<I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1A9ULG871T<FEB
M<R==6R1A='1R:6)=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1R970@)CT@)'1H:7,M/E]T86=-:7-S:6YG071T<FEB=71E*"1C:&]I8V5;
M)W1A9R==+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D871T
M<FEB+"`D8V]N=&5X="D[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@)')E=#L-"B`@("`@("`@
M?0T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!?<')O8V5S<U-T<G5C='5R92@D:V5Y*0T*("`@('L-"B`@("`@("`@)')E
M="`](&%R<F%Y*"D[#0H@("`@("`@(&EF("AC;W5N="@D<&EE8V5S(#T@97AP
M;&]D92@G?"<L("1K97DI*2`^(#$I('L-"B`@("`@("`@("`@(&9O<F5A8V@@
M*"1P:65C97,@87,@)'!I96-E*2![#0H@("`@("`@("`@("`@("`@)')E=%LG
M8VAO:6-E<R==6UT@/2`D=&AI<RT^7W!R;V-E<W-3=')U8W1U<F4H)'!I96-E
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B`D<F5T.PT*
M("`@("`@("!]#0H@("`@("`@("1M=6QT:2`]("1K97E[,'T[#0H@("`@("`@
M(&EF("@D;75L=&D@/3T@)RLG('Q\("1M=6QT:2`]/2`G*B<I('L-"B`@("`@
M("`@("`@("1R971;)VUU;'1I<&QE)UT@/2`D:V5Y>S!].PT*("`@("`@("`@
M("`@)&ME>2`]('-U8G-T<B@D:V5Y+"`Q*3L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H8V]U;G0H)&%T=')S(#T@97AP;&]D92@G+3XG+"`D:V5Y*2D@/B`Q
M*2![#0H@("`@("`@("`@("`D<F5T6R=T86<G72`](&%R<F%Y7W-H:69T*"1A
M='1R<RD[#0H@("`@("`@("`@("`D<F5T6R=A='1R:6)S)UT@/2`D871T<G,[
M#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D<F5T6R=T86<G72`]
M("1K97D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@7W9A;&ED871E4W1A8FEL:71Y5F5R<VEO;B@I
M#0H@("`@>PT*("`@("`@("`D<W1R=6-T=7)E(#T@87)R87DH)W)E;&5A<V4G
M+"`G87!I)RD[#0H@("`@("`@("1A(#T@)'1H:7,M/E]S='5P:6138VAE;6%6
M86QI9&%T92@D<W1R=6-T=7)E+"`D=&AI<RT^7W!A8VMA9V5);F9O6R=V97)S
M:6]N)UTL("<\=F5R<VEO;CXG*3L-"B`@("`@("`@)&$@)CT@)'1H:7,M/E]S
M='5P:6138VAE;6%686QI9&%T92@D<W1R=6-T=7)E+"`D=&AI<RT^7W!A8VMA
M9V5);F9O6R=S=&%B:6QI='DG72P@)SQS=&%B:6QI='D^)RD[#0H@("`@("`@
M(&EF("@D82D@>PT*("`@("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"<O7EQD
M*R@_.EPN7&0K*2HH/SI;82UZ02U:72M<9"HI/R0O)RP-"B`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)W9E<G-I;VXG75LG<F5L96%S
M92==*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YV86QI9%9E<G-I
M;VXH)W)E;&5A<V4G+"`D=&AI<RT^7W!A8VMA9V5);F9O6R=V97)S:6]N)UU;
M)W)E;&5A<V4G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H
M(7!R96=?;6%T8V@H)R]>7&0K*#\Z7"Y<9"LI*B@_.EMA+7I!+5I=*UQD*BD_
M)"\G+`T*("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG
M=F5R<VEO;B==6R=A<&DG72DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^
M7VEN=F%L:61697)S:6]N*"=A<&DG+"`D=&AI<RT^7W!A8VMA9V5);F9O6R=V
M97)S:6]N)UU;)V%P:2==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&EF("@A:6Y?87)R87DH)'1H:7,M/E]P86-K86=E26YF;ULG<W1A8FEL:71Y
M)UU;)W)E;&5A<V4G72P-"B`@("`@("`@("`@("`@("`@(&%R<F%Y*"=S;F%P
M<VAO="<L("=D979E;"<L("=A;'!H82<L("=B971A)RP@)W-T86)L92<I*2D@
M>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YV86QI9%-T871E*"=R96QE
M87-E)RP@)'1H:7,M/E]P86-K86=E:6YF;ULG<W1A8FEL:71Y)UU;)W)E;&5A
M<V4G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(6EN7V%R
M<F%Y*"1T:&ES+3Y?<&%C:V%G94EN9F];)W-T86)I;&ET>2==6R=A<&DG72P-
M"B`@("`@("`@("`@("`@("`@(&%R<F%Y*"=D979E;"<L("=A;'!H82<L("=B
M971A)RP@)W-T86)L92<I*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M:6YV86QI9%-T871E*"=A<&DG+"`D=&AI<RT^7W!A8VMA9V5I;F9O6R=S=&%B
M:6QI='DG75LG87!I)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@7W9A;&ED871E36%I;G1A:6YE<G,H*0T*
M("`@('L-"B`@("`@("`@)'-T<G5C='5R92`]#0H@("`@("`@("`@("!A<G)A
M>2@-"B`@("`@("`@("`@("`@("`G;F%M92<L#0H@("`@("`@("`@("`@("`@
M)W5S97(G+`T*("`@("`@("`@("`@("`@("=E;6%I;"<L#0H@("`@("`@("`@
M("`@("`@)V%C=&EV92<L#0H@("`@("`@("`@("`I.PT*("`@("`@("!F;W)E
M86-H("AA<G)A>2@G;&5A9"<L("=D979E;&]P97(G+"`G8V]N=')I8G5T;W(G
M+"`G:&5L<&5R)RD@87,@)'1Y<&4I('L-"B`@("`@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]P86-K86=E26YF;ULD='EP95TI*2![#0H@("`@("`@("`@
M("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULD='EP95U;,%TI*2![#0H@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]P86-K86=E26YF;ULD
M='EP95T@87,@)&QE860I('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]S='5P:6138VAE;6%686QI9&%T92@D<W1R=6-T=7)E+"`D;&5A9"P@)SPG
M("X@)'1Y<&4@+B`G/B<I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]S='5P:613
M8VAE;6%686QI9&%T92@D<W1R=6-T=7)E+"`D=&AI<RT^7W!A8VMA9V5);F9O
M6R1T>7!E72P-"B`@("`@("`@("`@("`@("`@("`@)SPG("X@)'1Y<&4@+B`G
M/B<I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*#0H@("`@
M9G5N8W1I;VX@7W9A;&ED871E4&AP1&5P*"1D97`L("1I;G-T86QL8V]N9&ET
M:6]N(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D<W1R=6-T=7)E(#T@87)R
M87DH#0H@("`@("`@("`@("`G;6EN)RP-"B`@("`@("`@("`@("<J;6%X)RP-
M"B`@("`@("`@("`@("<J97AC;'5D92<L#0H@("`@("`@("D[#0H@("`@("`@
M("1T>7!E(#T@)&EN<W1A;&QC;VYD:71I;VX@/R`G/&EN<W1A;&QC;VYD:71I
M;VX^/'!H<#XG(#H@)SQD97!E;F1E;F-I97,^/')E<75I<F5D/CQP:'`^)SL-
M"B`@("`@("`@)'1H:7,M/E]S='5P:6138VAE;6%686QI9&%T92@D<W1R=6-T
M=7)E+"`D9&5P+"`D='EP92D[#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=M
M:6XG72DI('L-"B`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@G+UY<9"LH
M/SI<+EQD*RDJ*#\Z6V$M>D$M6ETK7&0J*3\H/SHM6V$M>D$M6C`M.5TK*3\D
M+R<L#0H@("`@("`@("`@("`@("`@("`D9&5P6R=M:6XG72DI('L-"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7VEN=F%L:61697)S:6]N*"1T>7!E("X@)SQM
M:6X^)RP@)&1E<%LG;6EN)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=M87@G72DI('L-"B`@("`@("`@
M("`@(&EF("@A<')E9U]M871C:"@G+UY<9"LH/SI<+EQD*RDJ*#\Z6V$M>D$M
M6ETK7&0J*3\H/SHM6V$M>D$M6C`M.5TK*3\D+R<L#0H@("`@("`@("`@("`@
M("`@("`D9&5P6R=M87@G72DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^
M7VEN=F%L:61697)S:6]N*"1T>7!E("X@)SQM87@^)RP@)&1E<%LG;6%X)UTI
M.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@7W9A;&ED871E4&5A<FEN<W1A;&QE<D1E<"@D9&5P*0T*("`@('L-
M"B`@("`@("`@)'-T<G5C='5R92`](&%R<F%Y*`T*("`@("`@("`@("`@)VUI
M;B<L#0H@("`@("`@("`@("`G*FUA>"<L#0H@("`@("`@("`@("`G*G)E8V]M
M;65N9&5D)RP-"B`@("`@("`@("`@("<J97AC;'5D92<L#0H@("`@("`@("D[
M#0H@("`@("`@("1T:&ES+3Y?<W1U<&ED4V-H96UA5F%L:61A=&4H)'-T<G5C
M='5R92P@)&1E<"P@)SQD97!E;F1E;F-I97,^/')E<75I<F5D/CQP96%R:6YS
M=&%L;&5R/B<I.PT*("`@("`@("!I9B`H:7-S970H)&1E<%LG;6EN)UTI*2![
M#0H@("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H)R]>7&0K*#\Z7"Y<9"LI
M*B@_.EMA+7I!+5I=*UQD*BD_)"\G+`T*("`@("`@("`@("`@("`@("`@)&1E
M<%LG;6EN)UTI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]I;G9A;&ED
M5F5R<VEO;B@G/&1E<&5N9&5N8VEE<SX\<F5Q=6ER960^/'!E87)I;G-T86QL
M97(^/&UI;CXG+`T*("`@("`@("`@("`@("`@("`@("`D9&5P6R=M:6XG72D[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T
M*"1D97!;)VUA>"==*2D@>PT*("`@("`@("`@("`@:68@*"%P<F5G7VUA=&-H
M*"<O7EQD*R@_.EPN7&0K*2HH/SI;82UZ02U:72M<9"HI/R0O)RP-"B`@("`@
M("`@("`@("`@("`@("1D97!;)VUA>"==*2D@>PT*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?:6YV86QI9%9E<G-I;VXH)SQD97!E;F1E;F-I97,^/')E<75I
M<F5D/CQP96%R:6YS=&%L;&5R/CQM87@^)RP-"B`@("`@("`@("`@("`@("`@
M("`@)&1E<%LG;6%X)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@(&EF("AI<W-E="@D9&5P6R=R96-O;6UE;F1E9"==*2D@>PT*("`@
M("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"<O7EQD*R@_.EPN7&0K*2HH/SI;
M82UZ02U:72M<9"HI/R0O)RP-"B`@("`@("`@("`@("`@("`@("1D97!;)W)E
M8V]M;65N9&5D)UTI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]I;G9A
M;&ED5F5R<VEO;B@G/&1E<&5N9&5N8VEE<SX\<F5Q=6ER960^/'!E87)I;G-T
M86QL97(^/')E8V]M;65N9&5D/B<L#0H@("`@("`@("`@("`@("`@("`@("1D
M97!;)W)E8V]M;65N9&5D)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@
M("`@("`@("!I9B`H(6ES7V%R<F%Y*"1D97!;)V5X8VQU9&4G72DI('L-"B`@
M("`@("`@("`@("`@("`D9&5P6R=E>&-L=61E)UT@/2!A<G)A>2@D9&5P6R=E
M>&-L=61E)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C
M:"`H)&1E<%LG97AC;'5D92==(&%S("1E>&-L=61E*2![#0H@("`@("`@("`@
M("`@("`@:68@*"%P<F5G7VUA=&-H*"<O7EQD*R@_.EPN7&0K*2HH/SI;82UZ
M02U:72M<9"HI/R0O)RP-"B`@("`@("`@("`@("`@("`@("`@("`D97AC;'5D
M92DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I;G9A;&ED5F5R
M<VEO;B@G/&1E<&5N9&5N8VEE<SX\<F5Q=6ER960^/'!E87)I;G-T86QL97(^
M/&5X8VQU9&4^)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("1E>&-L=61E
M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?=F%L:61A=&5086-K86=E1&5P
M*"1D97`L("1G<F]U<"P@)'1Y<&4@/2`G/'!A8VMA9V4^)RD-"B`@("![#0H@
M("`@("`@(&EF("AI<W-E="@D9&5P6R=U<FDG72DI('L-"B`@("`@("`@("`@
M(&EF("AI<W-E="@D9&5P6R=C;VYF;&EC=',G72DI('L-"B`@("`@("`@("`@
M("`@("`D<W1R=6-T=7)E(#T@87)R87DH#0H@("`@("`@("`@("`@("`@("`@
M("=N86UE)RP-"B`@("`@("`@("`@("`@("`@("`@)W5R:2<L#0H@("`@("`@
M("`@("`@("`@("`@("=C;VYF;&EC=',G+`T*("`@("`@("`@("`@("`@("`@
M("`G*G!R;W9I9&5S97AT96YS:6]N)RP-"B`@("`@("`@("`@("`@("`I.PT*
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D<W1R=6-T
M=7)E(#T@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=N86UE)RP-"B`@
M("`@("`@("`@("`@("`@("`@)W5R:2<L#0H@("`@("`@("`@("`@("`@("`@
M("<J<')O=FED97-E>'1E;G-I;VXG+`T*("`@("`@("`@("`@("`@("D[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!I
M9B`H:7-S970H)&1E<%LG8V]N9FQI8W1S)UTI*2![#0H@("`@("`@("`@("`@
M("`@)'-T<G5C='5R92`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G
M;F%M92<L#0H@("`@("`@("`@("`@("`@("`@("=C:&%N;F5L)RP-"B`@("`@
M("`@("`@("`@("`@("`@)RIM:6XG+`T*("`@("`@("`@("`@("`@("`@("`G
M*FUA>"<L#0H@("`@("`@("`@("`@("`@("`@("<J97AC;'5D92<L#0H@("`@
M("`@("`@("`@("`@("`@("=C;VYF;&EC=',G+`T*("`@("`@("`@("`@("`@
M("`@("`G*G!R;W9I9&5S97AT96YS:6]N)RP-"B`@("`@("`@("`@("`@("`I
M.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D<W1R
M=6-T=7)E(#T@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=N86UE)RP-
M"B`@("`@("`@("`@("`@("`@("`@)V-H86YN96PG+`T*("`@("`@("`@("`@
M("`@("`@("`G*FUI;B<L#0H@("`@("`@("`@("`@("`@("`@("<J;6%X)RP-
M"B`@("`@("`@("`@("`@("`@("`@)RIR96-O;6UE;F1E9"<L#0H@("`@("`@
M("`@("`@("`@("`@("<J97AC;'5D92<L#0H@("`@("`@("`@("`@("`@("`@
M("<J;F]D969A=6QT)RP-"B`@("`@("`@("`@("`@("`@("`@)RIP<F]V:61E
M<V5X=&5N<VEO;B<L#0H@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&1E<%LG;F%M92==
M*2D@>PT*("`@("`@("`@("`@)'1Y<&4@+CT@)SQN86UE/B<@+B`D9&5P6R=N
M86UE)UT@+B`G/"]N86UE/B<[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M
M/E]S='5P:6138VAE;6%686QI9&%T92@D<W1R=6-T=7)E+"`D9&5P+"`G/&1E
M<&5N9&5N8VEE<SXG("X@)&=R;W5P("X@)'1Y<&4I.PT*("`@("`@("!I9B`H
M:7-S970H)&1E<%LG=7)I)UTI("8F("AI<W-E="@D9&5P6R=M:6XG72D@?'P@
M:7-S970H)&1E<%LG;6%X)UTI('Q\#0H@("`@("`@("`@("`@(&ES<V5T*"1D
M97!;)W)E8V]M;65N9&5D)UTI('Q\(&ES<V5T*"1D97!;)V5X8VQU9&4G72DI
M*2![#0H@("`@("`@("`@("`D=&AI<RT^7W5R:41E<'-#86YN;W1(879E5F5R
M<VEO;FEN9R@G/&1E<&5N9&5N8VEE<SXG("X@)&=R;W5P("X@)'1Y<&4I.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=C:&%N;F5L)UTI
M("8F('-T<G1O;&]W97(H)&1E<%LG8VAA;FYE;"==*2`]/2`G7U]U<FDG*2![
M#0H@("`@("`@("`@("`D=&AI<RT^7T1E<&-H86YN96Q#86YN;W1"955R:2@G
M/&1E<&5N9&5N8VEE<SXG("X@)&=R;W5P("X@)'1Y<&4I.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=M:6XG72DI('L-"B`@("`@("`@
M("`@(&EF("@A<')E9U]M871C:"@G+UY<9"LH/SI<+EQD*RDJ*#\Z6V$M>D$M
M6ETK7&0J*3\D+R<L#0H@("`@("`@("`@("`@("`@("`D9&5P6R=M:6XG72DI
M('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7VEN=F%L:61697)S:6]N*"<\
M9&5P96YD96YC:65S/B<@+B`D9W)O=7`@+B`D='EP92`N("<\;6EN/B<L("1D
M97!;)VUI;B==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H:7-S970H)&1E<%LG;6%X)UTI*2![#0H@("`@("`@("`@("!I9B`H
M(7!R96=?;6%T8V@H)R]>7&0K*#\Z7"Y<9"LI*B@_.EMA+7I!+5I=*UQD*BD_
M)"\G+`T*("`@("`@("`@("`@("`@("`@)&1E<%LG;6%X)UTI*2![#0H@("`@
M("`@("`@("`@("`@)'1H:7,M/E]I;G9A;&ED5F5R<VEO;B@G/&1E<&5N9&5N
M8VEE<SXG("X@)&=R;W5P("X@)'1Y<&4@+B`G/&UA>#XG+"`D9&5P6R=M87@G
M72D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES
M<V5T*"1D97!;)W)E8V]M;65N9&5D)UTI*2![#0H@("`@("`@("`@("!I9B`H
M(7!R96=?;6%T8V@H)R]>7&0K*#\Z7"Y<9"LI*B@_.EMA+7I!+5I=*UQD*BD_
M)"\G+`T*("`@("`@("`@("`@("`@("`@)&1E<%LG<F5C;VUM96YD960G72DI
M('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7VEN=F%L:61697)S:6]N*"<\
M9&5P96YD96YC:65S/B<@+B`D9W)O=7`@+B`D='EP92`N("<\<F5C;VUM96YD
M960^)RP-"B`@("`@("`@("`@("`@("`@("`@)&1E<%LG<F5C;VUM96YD960G
M72D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES
M<V5T*"1D97!;)V5X8VQU9&4G72DI('L-"B`@("`@("`@("`@(&EF("@A:7-?
M87)R87DH)&1E<%LG97AC;'5D92==*2D@>PT*("`@("`@("`@("`@("`@("1D
M97!;)V5X8VQU9&4G72`](&%R<F%Y*"1D97!;)V5X8VQU9&4G72D[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!F;W)E86-H("@D9&5P6R=E>&-L=61E
M)UT@87,@)&5X8VQU9&4I('L-"B`@("`@("`@("`@("`@("!I9B`H(7!R96=?
M;6%T8V@H)R]>7&0K*#\Z7"Y<9"LI*B@_.EMA+7I!+5I=*UQD*BD_)"\G+`T*
M("`@("`@("`@("`@("`@("`@("`@("1E>&-L=61E*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7VEN=F%L:61697)S:6]N*"<\9&5P96YD96YC
M:65S/B<@+B`D9W)O=7`@+B`D='EP92`N("<\97AC;'5D93XG+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@)&5X8VQU9&4I.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@('T-"@T*("`@(&9U
M;F-T:6]N(%]V86QI9&%T95-U8G!A8VMA9V5$97`H)&1E<"P@)&=R;W5P*0T*
M("`@('L-"B`@("`@("`@)'1H:7,M/E]V86QI9&%T95!A8VMA9V5$97`H)&1E
M<"P@)&=R;W5P+"`G/'-U8G!A8VMA9V4^)RD[#0H@("`@("`@(&EF("AI<W-E
M="@D9&5P6R=P<F]V:61E<V5X=&5N<VEO;B==*2D@>PT*("`@("`@("`@("`@
M)'1H:7,M/E]S=6)P86-K86=E0V%N;F]T4')O=FED945X=&5N<VEO;BA`)&1E
M<%LG;F%M92==*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&1E
M<%LG8V]N9FQI8W1S)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W-U8G!A
M8VMA9V5S0V%N;F]T0V]N9FQI8W0H0"1D97!;)VYA;64G72D[#0H@("`@("`@
M('T-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?=F%L:61A=&5%>'1E;G-I;VY$
M97`H)&1E<"P@)&=R;W5P(#T@9F%L<V4L("1I;G-T86QL8V]N9&ET:6]N(#T@
M9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)&1E<%LG8V]N9FQI
M8W1S)UTI*2![#0H@("`@("`@("`@("`D<W1R=6-T=7)E(#T@87)R87DH#0H@
M("`@("`@("`@("`@("`@)VYA;64G+`T*("`@("`@("`@("`@("`@("<J;6EN
M)RP-"B`@("`@("`@("`@("`@("`G*FUA>"<L#0H@("`@("`@("`@("`@("`@
M)RIE>&-L=61E)RP-"B`@("`@("`@("`@("`@("`G8V]N9FQI8W1S)RP-"B`@
M("`@("`@("`@("D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D
M<W1R=6-T=7)E(#T@87)R87DH#0H@("`@("`@("`@("`@("`@)VYA;64G+`T*
M("`@("`@("`@("`@("`@("<J;6EN)RP-"B`@("`@("`@("`@("`@("`G*FUA
M>"<L#0H@("`@("`@("`@("`@("`@)RIR96-O;6UE;F1E9"<L#0H@("`@("`@
M("`@("`@("`@)RIE>&-L=61E)RP-"B`@("`@("`@("`@("D[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"1I;G-T86QL8V]N9&ET:6]N*2![#0H@("`@("`@
M("`@("`D='EP92`]("<\:6YS=&%L;&-O;F1I=&EO;CX\97AT96YS:6]N/B<[
M#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D='EP92`]("<\9&5P
M96YD96YC:65S/B<@+B`D9W)O=7`@+B`G/&5X=&5N<VEO;CXG.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=N86UE)UTI*2![#0H@("`@
M("`@("`@("`D='EP92`N/2`G/&YA;64^)R`N("1D97!;)VYA;64G72`N("<\
M+VYA;64^)SL-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7W-T=7!I9%-C
M:&5M859A;&ED871E*"1S=')U8W1U<F4L("1D97`L("1T>7!E*3L-"B`@("`@
M("`@:68@*&ES<V5T*"1D97!;)VUI;B==*2D@>PT*("`@("`@("`@("`@:68@
M*"%P<F5G7VUA=&-H*"<O7EQD*R@_.EPN7&0K*2HH/SI;82UZ02U:72M<9"HI
M/R0O)RP-"B`@("`@("`@("`@("`@("`@("1D97!;)VUI;B==*2D@>PT*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?:6YV86QI9%9E<G-I;VXH<W5B<W1R*"1T
M>7!E+"`Q*2`N("<\;6EN)RP@)&1E<%LG;6EN)UTI.PT*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=M87@G72DI
M('L-"B`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@G+UY<9"LH/SI<+EQD
M*RDJ*#\Z6V$M>D$M6ETK7&0J*3\D+R<L#0H@("`@("`@("`@("`@("`@("`D
M9&5P6R=M87@G72DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7VEN=F%L
M:61697)S:6]N*'-U8G-T<B@D='EP92P@,2D@+B`G/&UA>"<L("1D97!;)VUA
M>"==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M:7-S970H)&1E<%LG<F5C;VUM96YD960G72DI('L-"B`@("`@("`@("`@(&EF
M("@A<')E9U]M871C:"@G+UY<9"LH/SI<+EQD*RDJ*#\Z6V$M>D$M6ETK7&0J
M*3\D+R<L#0H@("`@("`@("`@("`@("`@("`D9&5P6R=R96-O;6UE;F1E9"==
M*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YV86QI9%9E<G-I;VXH
M<W5B<W1R*"1T>7!E+"`Q*2`N("<\<F5C;VUM96YD960G+"`D9&5P6R=R96-O
M;6UE;F1E9"==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H:7-S970H)&1E<%LG97AC;'5D92==*2D@>PT*("`@("`@("`@("`@
M:68@*"%I<U]A<G)A>2@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@
M("`@("`@)&1E<%LG97AC;'5D92==(#T@87)R87DH)&1E<%LG97AC;'5D92==
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@*"1D97!;
M)V5X8VQU9&4G72!A<R`D97AC;'5D92D@>PT*("`@("`@("`@("`@("`@(&EF
M("@A<')E9U]M871C:"@G+UY<9"LH/SI<+EQD*RDJ*#\Z6V$M>D$M6ETK7&0J
M*3\D+R<L#0H@("`@("`@("`@("`@("`@("`@("`@)&5X8VQU9&4I*2![#0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YV86QI9%9E<G-I;VXH<W5B
M<W1R*"1T>7!E+"`Q*2`N("<\97AC;'5D92<L("1E>&-L=61E*3L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!?=F%L:61A=&5/<T1E<"@D9&5P+"`D:6YS=&%L
M;&-O;F1I=&EO;B`](&9A;'-E*0T*("`@('L-"B`@("`@("`@)'-T<G5C='5R
M92`](&%R<F%Y*`T*("`@("`@("`@("`@)VYA;64G+`T*("`@("`@("`@("`@
M)RIC;VYF;&EC=',G+`T*("`@("`@("`I.PT*("`@("`@("`D='EP92`]("1I
M;G-T86QL8V]N9&ET:6]N(#\@)SQI;G-T86QL8V]N9&ET:6]N/CQO<SXG(#H@
M)SQD97!E;F1E;F-I97,^/')E<75I<F5D/CQO<SXG.PT*("`@("`@("!I9B`H
M)'1H:7,M/E]S='5P:6138VAE;6%686QI9&%T92@D<W1R=6-T=7)E+"`D9&5P
M+"`D='EP92DI('L-"B`@("`@("`@("`@(&EF("@D9&5P6R=N86UE)UT@/3T@
M)RHG*2![#0H@("`@("`@("`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H
M)V-O;F9L:6-T<R<L("1D97`I*2![#0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?8V%N;F]T0V]N9FQI8W17:71H06QL3W,H)'1Y<&4I.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@('T-
M"@T*("`@(&9U;F-T:6]N(%]V86QI9&%T94%R8VA$97`H)&1E<"P@)&EN<W1A
M;&QC;VYD:71I;VX@/2!F86QS92D-"B`@("![#0H@("`@("`@("1S=')U8W1U
M<F4@/2!A<G)A>2@-"B`@("`@("`@("`@("=P871T97)N)RP-"B`@("`@("`@
M("`@("<J8V]N9FQI8W1S)RP-"B`@("`@("`@*3L-"B`@("`@("`@)'1Y<&4@
M/2`D:6YS=&%L;&-O;F1I=&EO;B`_("<\:6YS=&%L;&-O;F1I=&EO;CX\87)C
M:#XG(#H@)SQD97!E;F1E;F-I97,^/')E<75I<F5D/CQA<F-H/B<[#0H@("`@
M("`@("1T:&ES+3Y?<W1U<&ED4V-H96UA5F%L:61A=&4H)'-T<G5C='5R92P@
M)&1E<"P@)'1Y<&4I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]V86QI9&%T
M94EN<W1A;&Q#;VYD:71I;VYS*"1C;VYD+"`D<F5L96%S92D-"B`@("![#0H@
M("`@("`@("1S=')U8W1U<F4@/2!A<G)A>2@-"B`@("`@("`@("`@("<J<&AP
M)RP-"B`@("`@("`@("`@("<J97AT96YS:6]N)RP-"B`@("`@("`@("`@("<J
M;W,G+`T*("`@("`@("`@("`@)RIA<F-H)RP-"B`@("`@("`@*3L-"B`@("`@
M("`@:68@*"$D=&AI<RT^7W-T=7!I9%-C:&5M859A;&ED871E*"1S=')U8W1U
M<F4L#0H@("`@("`@("`@("`@("1C;VYD+"`D<F5L96%S92DI('L-"B`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!F;W)E
M86-H("AA<G)A>2@G<&AP)RP@)V5X=&5N<VEO;B<L("=O<R<L("=A<F-H)RD@
M87,@)'1Y<&4I('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D8V]N9%LD='EP
M95TI*2![#0H@("`@("`@("`@("`@("`@)&ET97(@/2`D8V]N9%LD='EP95T[
M#0H@("`@("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D:71E<BD@?'P@(6ES
M<V5T*"1I=&5R6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`D:71E<B`]
M(&%R<F%Y*"1I=&5R*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)&ET97(@87,@)'!A8VMA9V4I('L-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"1T>7!E(#T]("=E>'1E;G-I;VXG*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^>R)?=F%L:61A=&5[)'1Y<&5]
M1&5P(GTH)'!A8VMA9V4L(&9A;'-E+"!T<G5E*3L-"B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y[(E]V86QI9&%T97LD='EP97U$97`B?2@D<&%C:V%G92P@=')U92D[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?
M=F%L:61A=&5$97!E;F1E;F-I97,H*0T*("`@('L-"B`@("`@("`@)'-T<G5C
M='5R92`](&%R<F%Y*`T*("`@("`@("`@("`@)W)E<75I<F5D)RP-"B`@("`@
M("`@("`@("<J;W!T:6]N86PG+`T*("`@("`@("`@("`@)RIG<F]U<"T^;F%M
M92T^:&EN="<-"B`@("`@("`@*3L-"B`@("`@("`@:68@*"$D=&AI<RT^7W-T
M=7!I9%-C:&5M859A;&ED871E*"1S=')U8W1U<F4L#0H@("`@("`@("`@("`@
M("1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<&5N9&5N8VEE<R==+"`G/&1E<&5N
M9&5N8VEE<SXG*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M("`@("!]#0H@("`@("`@(&9O<F5A8V@@*&%R<F%Y*"=R97%U:7)E9"<L("=O
M<'1I;VYA;"<I(&%S("1S:6UP;&5D97`I('L-"B`@("`@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=D97!E;F1E;F-I97,G75LD<VEM
M<&QE9&5P72DI('L-"B`@("`@("`@("`@("`@("!I9B`H)'-I;7!L961E<"`]
M/2`G;W!T:6]N86PG*2![#0H@("`@("`@("`@("`@("`@("`@("1S=')U8W1U
M<F4@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("<J<&%C:V%G
M92<L#0H@("`@("`@("`@("`@("`@("`@("`@("`G*G-U8G!A8VMA9V4G+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@)RIE>'1E;G-I;VXG+`T*("`@("`@
M("`@("`@("`@("`@("`I.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@("`@("1S=')U8W1U<F4@/2!A<G)A>2@-"B`@("`@
M("`@("`@("`@("`@("`@("`@("=P:'`G+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@)W!E87)I;G-T86QL97(G+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@)RIP86-K86=E)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("<J<W5B
M<&%C:V%G92<L#0H@("`@("`@("`@("`@("`@("`@("`@("`G*F5X=&5N<VEO
M;B<L#0H@("`@("`@("`@("`@("`@("`@("`@("`G*F]S)RP-"B`@("`@("`@
M("`@("`@("`@("`@("`@("<J87)C:"<L#0H@("`@("`@("`@("`@("`@("`@
M("D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D
M=&AI<RT^7W-T=7!I9%-C:&5M859A;&ED871E*"1S=')U8W1U<F4L#0H@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG9&5P96YD
M96YC:65S)UU;)'-I;7!L961E<%TL#0H@("`@("`@("`@("`@("`@("`@("`@
M(CQD97!E;F1E;F-I97,^/"1S:6UP;&5D97`^(BDI('L-"B`@("`@("`@("`@
M("`@("`@("`@9F]R96%C:"`H87)R87DH)W!A8VMA9V4G+"`G<W5B<&%C:V%G
M92<L("=E>'1E;G-I;VXG*2!A<R`D='EP92D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<&5N
M9&5N8VEE<R==6R1S:6UP;&5D97!=6R1T>7!E72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D:71E<B`]("1T:&ES+3Y?<&%C:V%G94EN9F];
M)V1E<&5N9&5N8VEE<R==6R1S:6UP;&5D97!=6R1T>7!E73L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1I=&5R6S!=*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:71E<B`](&%R<F%Y
M*"1I=&5R*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&ET97(@87,@)'!A
M8VMA9V4I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"1T>7!E("$]("=E>'1E;G-I;VXG*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A8VMA9V5;)W5R:2==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D<&%C:V%G95LG8VAA;FYE;"==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7U5R;$]R
M0VAA;FYE;"@D='EP92P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1P86-K86=E6R=N86UE)UTI.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M<&%C:V%G95LG8VAA;FYE;"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7TYO0VAA;FYE;"@D='EP
M92P@)'!A8VMA9V5;)VYA;64G72D[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y[
M(E]V86QI9&%T97LD='EP97U$97`B?2@D<&%C:V%G92P@(CPD<VEM<&QE9&5P
M/B(I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("!I9B`H)'-I;7!L961E<"`]/2`G;W!T:6]N86PG
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!F;W)E86-H
M("AA<G)A>2@G<&AP)RP@)W!E87)I;G-T86QL97(G+"`G;W,G+"`G87)C:"<I
M(&%S("1T>7!E*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)'1H:7,M/E]P86-K86=E26YF;ULG9&5P96YD96YC:65S)UU;)'-I;7!L
M961E<%U;)'1Y<&5=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1I=&5R(#T@)'1H:7,M/E]P86-K86=E26YF;ULG9&5P96YD96YC:65S)UU;
M)'-I;7!L961E<%U;)'1Y<&5=.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@A:7-S970H)&ET97);,%TI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1I=&5R(#T@87)R87DH)&ET97(I.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!F;W)E86-H("@D:71E<B!A<R`D<&%C:V%G92D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^>R)?=F%L:61A=&5[
M)'1Y<&5]1&5P(GTH)'!A8VMA9V4I.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K
M86=E26YF;ULG9&5P96YD96YC:65S)UU;)V=R;W5P)UTI*2![#0H@("`@("`@
M("`@("`D9W)O=7!S(#T@)'1H:7,M/E]P86-K86=E26YF;ULG9&5P96YD96YC
M:65S)UU;)V=R;W5P)UT[#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1G<F]U
M<'-;,%TI*2![#0H@("`@("`@("`@("`@("`@)&=R;W5P<R`](&%R<F%Y*"1G
M<F]U<',I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'-T<G5C='5R
M92`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("<J<&%C:V%G92<L#0H@("`@
M("`@("`@("`@("`@)RIS=6)P86-K86=E)RP-"B`@("`@("`@("`@("`@("`G
M*F5X=&5N<VEO;B<L#0H@("`@("`@("`@("`I.PT*("`@("`@("`@("`@9F]R
M96%C:"`H)&=R;W5P<R!A<R`D9W)O=7`I('L-"B`@("`@("`@("`@("`@("!I
M9B`H)'1H:7,M/E]S='5P:6138VAE;6%686QI9&%T92@D<W1R=6-T=7)E+"`D
M9W)O=7`L("<\9W)O=7`^)RDI('L-"B`@("`@("`@("`@("`@("`@("`@:68@
M*"%014%27U9A;&ED871E.CIV86QI9$=R;W5P3F%M92@D9W)O=7!;)V%T=')I
M8G,G75LG;F%M92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]I;G9A;&ED1&5P1W)O=7!.86UE*"1G<F]U<%LG871T<FEB<R==6R=N
M86UE)UTI.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*&%R<F%Y*"=P86-K86=E)RP@)W-U8G!A8VMA9V4G
M+"`G97AT96YS:6]N)RD@87,@)'1Y<&4I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D9W)O=7!;)'1Y<&5=*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1I=&5R(#T@)&=R;W5P6R1T>7!E73L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1I=&5R6S!=
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:71E<B`]
M(&%R<F%Y*"1I=&5R*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&ET97(@
M87,@)'!A8VMA9V4I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"1T>7!E("$]("=E>'1E;G-I;VXG*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A8VMA9V5;)W5R
M:2==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D<&%C:V%G95LG8VAA;FYE;"==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7U5R;$]R0VAA;FYE;$=R;W5P*"1T>7!E+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A8VMA9V5;)VYA;64G
M72P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1G<F]U<%LG;F%M92==*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'!A8VMA9V5;)V-H86YN
M96PG72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E].;T-H86YN96Q'<F]U<"@D='EP92P-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P
M86-K86=E6R=N86UE)UTL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9W)O=7!;)VYA;64G72D[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y[(E]V86QI9&%T97LD='EP97U$97`B?2@D<&%C:V%G
M92P@)SQG<F]U<"!N86UE/2(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1G<F]U<%LG871T<FEB<R==6R=N86UE)UT@+B`G(CXG
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!?=F%L:61A=&5#;VUP871I8FQE*"D-"B`@("![
M#0H@("`@("`@("1C;VUP870@/2`D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VUP
M871I8FQE)UT[#0H@("`@("`@(&EF("@A:7-S970H)&-O;7!A=%LP72DI('L-
M"B`@("`@("`@("`@("1C;VUP870@/2!A<G)A>2@D8V]M<&%T*3L-"B`@("`@
M("`@?0T*("`@("`@("`D<F5Q=6ER960@/2!A<G)A>2@G;F%M92<L("=C:&%N
M;F5L)RP@)VUI;B<L("=M87@G+"`G*F5X8VQU9&4G*3L-"B`@("`@("`@9F]R
M96%C:"`H)&-O;7!A="!A<R`D<&%C:V%G92D@>PT*("`@("`@("`@("`@)'1Y
M<&4@/2`G/&-O;7!A=&EB;&4^)SL-"B`@("`@("`@("`@(&EF("AI<U]A<G)A
M>2@D<&%C:V%G92D@)B8@87)R87E?:V5Y7V5X:7-T<R@G;F%M92<L("1P86-K
M86=E*2D@>PT*("`@("`@("`@("`@("`@("1T>7!E("X]("<\;F%M93XG("X@
M)'!A8VMA9V5;)VYA;64G72`N("<\+VYA;64^)SL-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("1T:&ES+3Y?<W1U<&ED4V-H96UA5F%L:61A=&4H)')E
M<75I<F5D+"`D<&%C:V%G92P@)'1Y<&4I.PT*("`@("`@("`@("`@:68@*&ES
M7V%R<F%Y*"1P86-K86=E*2`F)B!A<G)A>5]K97E?97AI<W1S*"=M:6XG+"`D
M<&%C:V%G92DI('L-"B`@("`@("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H
M)R]>7&0K*#\Z7"Y<9"LI*B@_.EMA+7I!+5I=*UQD*BD_)"\G+`T*("`@("`@
M("`@("`@("`@("`@("`@("1P86-K86=E6R=M:6XG72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]I;G9A;&ED5F5R<VEO;BAS=6)S='(H)'1Y
M<&4L(#$I("X@)SQM:6XG+"`D<&%C:V%G95LG;6EN)UTI.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<U]A
M<G)A>2@D<&%C:V%G92D@)B8@87)R87E?:V5Y7V5X:7-T<R@G;6%X)RP@)'!A
M8VMA9V4I*2![#0H@("`@("`@("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"<O
M7EQD*R@_.EPN7&0K*2HH/SI;82UZ02U:72M<9"HI/R0O)RP-"B`@("`@("`@
M("`@("`@("`@("`@("`D<&%C:V%G95LG;6%X)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?:6YV86QI9%9E<G-I;VXH<W5B<W1R*"1T>7!E
M+"`Q*2`N("<\;6%X)RP@)'!A8VMA9V5;)VUA>"==*3L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-?87)R
M87DH)'!A8VMA9V4I("8F(&%R<F%Y7VME>5]E>&ES=',H)V5X8VQU9&4G+"`D
M<&%C:V%G92DI('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1P
M86-K86=E6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1P
M86-K86=E6R=E>&-L=61E)UT@/2!A<G)A>2@D<&%C:V%G95LG97AC;'5D92==
M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)'!A8VMA9V5;)V5X8VQU9&4G72!A<R`D97AC;'5D92D@>PT*("`@("`@
M("`@("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H)R]>7&0K*#\Z7"Y<9"LI
M*B@_.EMA+7I!+5I=*UQD*BD_)"\G+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`D97AC;'5D92DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?:6YV86QI9%9E<G-I;VXH<W5B<W1R*"1T>7!E+"`Q*2`N("<\97AC
M;'5D92<L("1E>&-L=61E*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M('T-"@T*("`@(&9U;F-T:6]N(%]V86QI9&%T94)U;F1L92@D;&ES="D-"B`@
M("![#0H@("`@("`@(&EF("@A:7-?87)R87DH)&QI<W0I('Q\("%I<W-E="@D
M;&ES=%LG8G5N9&QE9'!A8VMA9V4G72DI('L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7TYO0G5N9&QE9%!A8VMA9V5S*"D[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"%I<U]A<G)A>2@D;&ES=%LG8G5N9&QE9'!A8VMA9V4G72D@
M?'P@(6ES<V5T*"1L:7-T6R=B=6YD;&5D<&%C:V%G92==6S!=*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?071,96%S=#)"=6YD;&5D4&%C:V%G
M97,H*3L-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D;&ES=%LG8G5N
M9&QE9'!A8VMA9V4G72!A<R`D<&%C:V%G92D@>PT*("`@("`@("`@("`@:68@
M*"%I<U]S=')I;F<H)'!A8VMA9V4I*2![#0H@("`@("`@("`@("`@("`@)'1H
M:7,M/E]B=6YD;&5D4&%C:V%G97--=7-T0F5&:6QE;F%M92@I.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7W9A
M;&ED871E1FEL96QI<W0H)&QI<W0@/2!F86QS92P@)&%L;&]W:6=N;W)E(#T@
M9F%L<V4L("1D:7)S(#T@)R<I#0H@("`@>PT*("`@("`@("`D:7-C;VYT96YT
M<R`](&9A;'-E.PT*("`@("`@("!I9B`H(21L:7-T*2![#0H@("`@("`@("`@
M("`D:7-C;VYT96YT<R`]('1R=64[#0H@("`@("`@("`@("`D;&ES="`]("1T
M:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S)UT[#0H@("`@("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG8G5N9&QE)UTI*2![#0H@
M("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?=F%L:61A=&5"=6YD;&4H
M)&QI<W0I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF
M("@D86QL;W=I9VYO<F4I('L-"B`@("`@("`@("`@("1S=')U8R`](&%R<F%Y
M*`T*("`@("`@("`@("`@("`@("<J:6YS=&%L;"T^;F%M92T^87,G+`T*("`@
M("`@("`@("`@("`@("<J:6=N;W)E+3YN86UE)PT*("`@("`@("`@("`@*3L-
M"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1S=')U8R`](&%R<F%Y
M*`T*("`@("`@("`@("`@("`@("<J9&ER+3YN86UE+3X_8F%S96EN<W1A;&QD
M:7(G+`T*("`@("`@("`@("`@("`@("<J9FEL92T^;F%M92T^<F]L92T^/V)A
M<V5I;G-T86QL9&ER+3X_;60U<W5M)PT*("`@("`@("`@("`@*3L-"B`@("`@
M("`@("`@(&EF("AI<W-E="@D;&ES=%LG9&ER)UTI("8F(&ES<V5T*"1L:7-T
M6R=F:6QE)UTI*2![#0H@("`@("`@("`@("`@("`@+R\@<W1A=F4@;V9F('9A
M;&ED871I;VX@97)R;W)S('=I=&AO=70@<F5Q=6ER:6YG(&$@<V5T(&]R9&5R
M+@T*("`@("`@("`@("`@("`@("1?;VQD(#T@)&QI<W0[#0H@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1L:7-T6R=A='1R:6)S)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("1L:7-T(#T@87)R87DH)V%T=')I8G,G(#T^("1?;VQD
M6R=A='1R:6)S)UTI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`D;&ES=%LG9&ER)UT@/2`D7V]L9%LG9&ER)UT[#0H@("`@("`@("`@
M("`@("`@)&QI<W1;)V9I;&4G72`]("1?;VQD6R=F:6QE)UT[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<W-E="@D;&ES=%LG
M871T<FEB<R==*2!\?"`A:7-S970H)&QI<W1;)V%T=')I8G,G75LG;F%M92==
M*2D@>PT*("`@("`@("`@("`@)'5N:VYO=VX@/2`D86QL;W=I9VYO<F4@/R`G
M/&9I;&5L:7-T/B<@.B`G/&1I<B!N86UE/2(J=6YK;F]W;BHB/B<[#0H@("`@
M("`@("`@("`D9&ER;F%M92`]("1I<V-O;G1E;G1S(#\@)SQC;VYT96YT<SXG
M(#H@)'5N:VYO=VX[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D
M9&ER;F%M92`]("<\9&ER(&YA;64](B<@+B`D;&ES=%LG871T<FEB<R==6R=N
M86UE)UT@+B`G(CXG.PT*("`@("`@("!]#0H@("`@("`@("1R97,@/2`D=&AI
M<RT^7W-T=7!I9%-C:&5M859A;&ED871E*"1S=')U8RP@)&QI<W0L("1D:7)N
M86UE*3L-"B`@("`@("`@:68@*"1A;&QO=VEG;F]R92`F)B`D<F5S*2![#0H@
M("`@("`@("`@("`D=&AI<RT^7W!F+3YG971&:6QE;&ES="@I.PT*("`@("`@
M("`@("`@)&9C;VYT96YT<R`]("1T:&ES+3Y?<&8M/F=E=$-O;G1E;G1S*"D[
M#0H@("`@("`@("`@("`D9FEL96QI<W0@/2!A<G)A>2@I.PT*("`@("`@("`@
M("`@:68@*"%I<W-E="@D9F-O;G1E;G1S6R=D:7(G75LG9FEL92==6S!=*2D@
M>PT*("`@("`@("`@("`@("`@("1F8V]N=&5N='-;)V1I<B==6R=F:6QE)UT@
M/2!A<G)A>2@D9F-O;G1E;G1S6R=D:7(G75LG9FEL92==*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@*"1F8V]N=&5N='-;)V1I<B==
M6R=F:6QE)UT@87,@)&9I;&4I('L-"B`@("`@("`@("`@("`@("`D9FEL96QI
M<W1;)&9I;&5;)V%T=')I8G,G75LG;F%M92==72`]('1R=64[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)&QI<W1;)VEN<W1A;&PG
M72DI('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1L:7-T6R=I;G-T
M86QL)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("1L:7-T6R=I;G-T
M86QL)UT@/2!A<G)A>2@D;&ES=%LG:6YS=&%L;"==*3L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&QI<W1;)VEN<W1A
M;&PG72!A<R`D9FEL92D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1F:6QE;&ES=%LD9FEL95LG871T<FEB<R==6R=N86UE)UU=*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]N;W1);D-O;G1E;G1S
M*"1F:6QE6R=A='1R:6)S)UU;)VYA;64G72P@)VEN<W1A;&PG*3L-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D;&ES=%LG:6=N;W)E)UTI
M*2![#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;&ES=%LG:6=N;W)E
M)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("1L:7-T6R=I9VYO<F4G
M72`](&%R<F%Y*"1L:7-T6R=I9VYO<F4G72D[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1L:7-T6R=I9VYO<F4G72!A
M<R`D9FEL92D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1F
M:6QE;&ES=%LD9FEL95LG871T<FEB<R==6R=N86UE)UU=*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]N;W1);D-O;G1E;G1S*"1F:6QE
M6R=A='1R:6)S)UU;)VYA;64G72P@)VEG;F]R92<I.PT*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@(&EF("@A)&%L;&]W:6=N;W)E("8F(&ES<V5T
M*"1L:7-T6R=F:6QE)UTI*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1L
M:7-T6R=F:6QE)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@+R\@<VEN9VQE
M(&9I;&4-"B`@("`@("`@("`@("`@("`D;&ES=%LG9FEL92==(#T@87)R87DH
M)&QI<W1;)V9I;&4G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F
M;W)E86-H("@D;&ES=%LG9FEL92==(&%S("1I(#T^("1F:6QE*0T*("`@("`@
M("`@("`@>PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9FEL95LG871T
M<FEB<R==*2`F)B!I<W-E="@D9FEL95LG871T<FEB<R==6R=N86UE)UTI("8F
M#0H@("`@("`@("`@("`@("`@("`@("`@)&9I;&5;)V%T=')I8G,G75LG;F%M
M92==>S!](#T]("<N)R`F)@T*("`@("`@("`@("`@("`@("`@("`@("`@)&9I
M;&5;)V%T=')I8G,G75LG;F%M92==>S%](#T]("<O)RD@>PT*("`@("`@("`@
M("`@("`@("`@("`O+R!N86UE(&ES('-O;65T:&EN9R!L:6ME("(N+V1O8R]W
M:&%T979E<BYT>'0B#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YV
M86QI9$9I;&5.86UE*"1F:6QE6R=A='1R:6)S)UU;)VYA;64G72D[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9FEL
M95LG871T<FEB<R==*2`F)B!I<W-E="@D9FEL95LG871T<FEB<R==6R=R;VQE
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/E]V86QI
M9&%T95)O;&4H)&9I;&5;)V%T=')I8G,G75LG<F]L92==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN
M9F];)W5S97-R;VQE)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)')O;&5S(#T@)'1H:7,M/E]P86-K86=E26YF;ULG=7-E<W)O;&4G73L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1R;VQE
M<ULP72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')O
M;&5S(#T@87)R87DH)')O;&5S*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)')O;&5S(&%S("1R;VQE*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@D<F]L95LG<F]L92==(#T@)&9I;&5;)V%T=')I8G,G75LG
M<F]L92==*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D;7-G(#T@)U1H:7,@<&%C:V%G92!C;VYT86EN<R!R;VQE("(E<F]L924B
M(&%N9"!R97%U:7)E<R`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G<&%C:V%G92`B)7!A8VMA9V4E(B!T;R!B92!U<V5D
M)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D<F]L95LG=7)I)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"=R;VQE)R`]/B`D
M<F]L95LG<F]L92==+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G<&%C:V%G92<@/3X@)')O;&5;)W5R:2==*3L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M
M<R`](&%R<F%Y*"=R;VQE)R`]/B`D<F]L95LG<F]L92==+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<&%C:V%G92<@
M/3X@)'1H:7,M/E]P9BT^7W)E9VES=')Y+3X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@<&%R<V5D4&%C:V%G94YA;654
M;U-T<FEN9RAA<G)A>2@G<&%C:V%G92<@/3X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R;VQE6R=P86-K86=E
M)UTL("=C:&%N;F5L)R`]/B`D<F]L95LG8VAA;FYE;"==*2P-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1R=64I
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<W1A
M8VLM/G!U<V@H)U]M=7-T26YS=&%L;%)O;&4G+"`G97)R;W(G+"`D<&%R86US
M+"`D;7-G*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M:6YV86QI9$9I;&52;VQE*"1F:6QE6R=A='1R:6)S)UU;)VYA;64G72P-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9&ER;F%M92P@)&9I;&5;)V%T
M=')I8G,G75LG<F]L92==*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1F
M:6QE6R=A='1R:6)S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D<V%V
M92`]("1F:6QE6R=A='1R:6)S)UT[#0H@("`@("`@("`@("`@("`@:68@*"1D
M:7)S*2![#0H@("`@("`@("`@("`@("`@("`@("1S879E6R=N86UE)UT@/2`D
M9&ER<R`N("<O)R`N("1S879E6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@('5N<V5T*"1F:6QE6R=A='1R:6)S)UTI.PT*
M("`@("`@("`@("`@("`@(&EF("AC;W5N="@D9FEL92D@)B8@)'1H:7,M/E]C
M=7)3=&%T92`A/2!014%27U9!3$E$051%7T1/5TY,3T%$24Y'*2![("\O(&AA
M<R!T87-K<PT*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D9FEL92!A
M<R`D=&%S:R`]/B`D=F%L=64I('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@D=&%G0VQA<W,@/2`D=&AI<RT^7W!F+3YG971487-K*"1T87-K*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?87)R87DH
M)'9A;'5E*2!\?"`A:7-S970H)'9A;'5E6S!=*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2!A<G)A>2@D=F%L=64I.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!F;W)E86-H("@D=F%L=64@87,@)'8I('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E="`](&-A;&Q?=7-E<E]F
M=6YC*&%R<F%Y*"1T86=#;&%S<RP@)W9A;&ED871E6&UL)RDL#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!F+"`D=BP@
M)'1H:7,M/E]P9BT^7V-O;F9I9RP@)'-A=F4I.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)')E="DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YV86QI
M9%1A<VLH)'1A<VLL("1R970L($`D<V%V95LG;F%M92==*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?<&%C:V%G94EN9F];)W5S97-T87-K)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1R;VQE<R`]("1T:&ES+3Y?<&%C:V%G94EN
M9F];)W5S97-T87-K)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@A:7-S970H)')O;&5S6S!=*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)')O;&5S(#T@87)R87DH)')O;&5S*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D<F]L97,@87,@)')O
M;&4I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@D<F]L95LG=&%S:R==(#T@)'1A<VLI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D;7-G(#T@)U1H:7,@<&%C:V%G92!C
M;VYT86EN<R!T87-K("(E=&%S:R4B(&%N9"!R97%U:7)E<R`G("X-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!A8VMA
M9V4@(B5P86-K86=E)2(@=&\@8F4@=7-E9"<[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1R;VQE6R=U<FDG
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'!A<F%M<R`](&%R<F%Y*"=T87-K)R`]/B`D<F]L95LG=&%S:R==
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W!A8VMA9V4G(#T^("1R;VQE6R=U<FDG72D[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M
M<R`](&%R<F%Y*"=T87-K)R`]/B`D<F]L95LG=&%S:R==+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!A8VMA
M9V4G(#T^("1T:&ES+3Y?<&8M/E]R96=I<W1R>2T^#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!P87)S961086-K
M86=E3F%M951O4W1R:6YG*&%R<F%Y*"=P86-K86=E)R`]/@T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R
M;VQE6R=P86-K86=E)UTL("=C:&%N;F5L)R`]/B`D<F]L95LG8VAA;FYE;"==
M*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!T<G5E*2D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H)U]M=7-T26YS=&%L
M;%1A<VLG+"`G97)R;W(G+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<&%R86US+"`D;7-G*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W5N:VYO
M=VY487-K*"1T87-K+"`D<V%V95LG;F%M92==*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H:7-S970H)&QI<W1;)VEG;F]R92==*2D@>PT*("`@("`@("`@("`@:68@
M*"$D86QL;W=I9VYO<F4I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7VEG
M;F]R94YO=$%L;&]W960H)VEG;F]R92<I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D;&ES=%LG:6YS=&%L;"==*2D@
M>PT*("`@("`@("`@("`@:68@*"$D86QL;W=I9VYO<F4I('L-"B`@("`@("`@
M("`@("`@("`D=&AI<RT^7VEG;F]R94YO=$%L;&]W960H)VEN<W1A;&PG*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H
M)&QI<W1;)V9I;&4G72DI('L-"B`@("`@("`@("`@(&EF("@D86QL;W=I9VYO
M<F4I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V9I;&5.;W1!;&QO=V5D
M*"=F:6QE)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&ES<V5T*"1L:7-T6R=D:7(G72DI('L-"B`@("`@("`@("`@(&EF("@D
M86QL;W=I9VYO<F4I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V9I;&5.
M;W1!;&QO=V5D*"=D:7(G*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D;&ES=%LG9&ER)UU;,%TI*2![#0H@
M("`@("`@("`@("`@("`@("`@("1L:7-T6R=D:7(G72`](&%R<F%Y*"1L:7-T
M6R=D:7(G72D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1L:7-T6R=D:7(G72!A<R`D9&ER*2![#0H@("`@("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D9&ER6R=A='1R:6)S)UTI("8F(&ES<V5T
M*"1D:7);)V%T=')I8G,G75LG;F%M92==*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"1D:7);)V%T=')I8G,G75LG;F%M92==(#T]("<O)R!\
M?`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(6ES<V5T*"1T:&ES
M+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S)UU;)V1I<B==6R=D:7(G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!A;'=A>7,@=7-E(&YO
M=&AI;F<@:68@=&AE(&9I;&5L:7-T(&AA<R!A;')E861Y(&)E96X@9FQA='1E
M;F5D#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YE=V1I<G,@/2`G
M)SL-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF("@D9&ER<R`]
M/2`G)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N97=D:7)S
M(#T@)&1I<ELG871T<FEB<R==6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1N97=D:7)S(#T@)&1I<G,@+B`G+R<@+B`D9&ER6R=A='1R:6)S)UU;)VYA
M;64G73L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1N
M97=D:7)S(#T@)&1I<G,[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T949I;&5L:7-T*"1D:7(L
M("1A;&QO=VEG;F]R92P@)&YE=V1I<G,I.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@('T-"@T*("`@(&9U;F-T
M:6]N(%]V86QI9&%T95)E;&5A<V4H*0T*("`@('L-"B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W!H<')E;&5A<V4G72DI('L-"B`@
M("`@("`@("`@("1R96QE87-E(#T@)W!H<')E;&5A<V4G.PT*("`@("`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W!R;W9I9&5S97AT
M96YS:6]N)UTI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]C86YN;W10
M<F]V:61E17AT96YS:6]N*"1R96QE87-E*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=S<F-P
M86-K86=E)UTI('Q\(&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W-R8W5R
M:2==*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?8V%N;F]T2&%V95-R
M8W!A8VMA9V4H)')E;&5A<V4I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@)')E;&5A<V5S(#T@)'1H:7,M/E]P86-K86=E26YF;ULG<&AP<F5L96%S
M92==.PT*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D<F5L96%S97,I*2![
M#0H@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1R96QE87-E<ULP72DI('L-"B`@
M("`@("`@("`@("`@("`D<F5L96%S97,@/2!A<G)A>2@D<F5L96%S97,I.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H)')E;&5A<V5S
M(&%S("1R96PI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W-T=7!I9%-C
M:&5M859A;&ED871E*&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G*FEN
M<W1A;&QC;VYD:71I;VYS)RP-"B`@("`@("`@("`@("`@("`@("`@)RIF:6QE
M;&ES="<L#0H@("`@("`@("`@("`@("`@*2P@)')E;"P@)SQP:'!R96QE87-E
M/B<I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=E>'1S<F-R96QE87-E)UTI*2![
M#0H@("`@("`@("`@("`D<F5L96%S92`]("=E>'1S<F-R96QE87-E)SL-"B`@
M("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG<')O
M=FED97-E>'1E;G-I;VXG72DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^
M7VUU<W10<F]V:61E17AT96YS:6]N*"1R96QE87-E*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O
M6R=S<F-P86-K86=E)UTI('Q\(&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];
M)W-R8W5R:2==*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?8V%N;F]T
M2&%V95-R8W!A8VMA9V4H)')E;&5A<V4I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@)')E;&5A<V5S(#T@)'1H:7,M/E]P86-K86=E26YF;ULG97AT
M<W)C<F5L96%S92==.PT*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D<F5L
M96%S97,I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1R96QE87-E<ULP
M72DI('L-"B`@("`@("`@("`@("`@("`D<F5L96%S97,@/2!A<G)A>2@D<F5L
M96%S97,I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H
M)')E;&5A<V5S(&%S("1R96PI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^
M7W-T=7!I9%-C:&5M859A;&ED871E*&%R<F%Y*`T*("`@("`@("`@("`@("`@
M("`@("`G*FEN<W1A;&QC;VYD:71I;VYS)RP-"B`@("`@("`@("`@("`@("`@
M("`@)RIC;VYF:6=U<F5O<'1I;VXM/FYA;64M/G!R;VUP="T^/V1E9F%U;'0G
M+`T*("`@("`@("`@("`@("`@("`@("`G*F)I;F%R>7!A8VMA9V4G+`T*("`@
M("`@("`@("`@("`@("`@("`G*F9I;&5L:7-T)RP-"B`@("`@("`@("`@("`@
M("`I+"`D<F5L+"`G/&5X='-R8W)E;&5A<V4^)RD[#0H@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1R96Q;)V)I;F%R>7!A8VMA9V4G72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D<F5L6R=B:6YA<GEP86-K
M86=E)UTI('Q\("%I<W-E="@D<F5L6R=B:6YA<GEP86-K86=E)UU;,%TI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D<F5L6R=B:6YA<GEP86-K86=E
M)UT@/2!A<G)A>2@D<F5L6R=B:6YA<GEP86-K86=E)UTI.PT*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1R
M96Q;)V)I;F%R>7!A8VMA9V4G72!A<R`D8FEN*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H(6ES7W-T<FEN9R@D8FEN*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8FEN87)Y4&%C:V%G94UU<W1"
M95!A8VMA9V5N86UE*"D[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?<&%C:V%G94EN9F];)V5X=&)I;G)E;&5A<V4G72DI('L-"B`@("`@("`@
M("`@("1R96QE87-E(#T@)V5X=&)I;G)E;&5A<V4G.PT*("`@("`@("`@("`@
M:68@*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=P<F]V:61E<V5X=&5N
M<VEO;B==*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?;75S=%!R;W9I
M9&5%>'1E;G-I;VXH)')E;&5A<V4I.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-H86YN96PG
M72D@)B8-"B`@("`@("`@("`@("`@("`@("%I<W-E="@D=&AI<RT^7W!A8VMA
M9V5);F9O6R=S<F-P86-K86=E)UTI*2![#0H@("`@("`@("`@("`@("`@)'1H
M:7,M/E]M=7-T4W)C4&%C:V%G92@D<F5L96%S92D[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG
M=7)I)UTI("8F("%I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=S<F-U<FDG
M72DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7VUU<W13<F-U<FDH)')E
M;&5A<V4I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)')E;&5A<V5S
M(#T@)'1H:7,M/E]P86-K86=E26YF;ULG97AT8FEN<F5L96%S92==.PT*("`@
M("`@("`@("`@:68@*"%I<U]A<G)A>2@D<F5L96%S97,I*2![#0H@("`@("`@
M("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1R96QE87-E<ULP72DI('L-"B`@("`@("`@("`@
M("`@("`D<F5L96%S97,@/2!A<G)A>2@D<F5L96%S97,I.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H)')E;&5A<V5S(&%S("1R96PI
M('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W-T=7!I9%-C:&5M859A;&ED
M871E*&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G*FEN<W1A;&QC;VYD
M:71I;VYS)RP-"B`@("`@("`@("`@("`@("`@("`@)RIF:6QE;&ES="<L#0H@
M("`@("`@("`@("`@("`@*2P@)')E;"P@)SQE>'1B:6YR96QE87-E/B<I.PT*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7W!A8VMA9V5);F9O6R=B=6YD;&4G72DI('L-"B`@("`@("`@("`@
M("1R96QE87-E(#T@)V)U;F1L92<[#0H@("`@("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]P86-K86=E26YF;ULG<')O=FED97-E>'1E;G-I;VXG72DI('L-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7V-A;FYO=%!R;W9I9&5%>'1E;G-I
M;VXH)')E;&5A<V4I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W-R8W!A8VMA9V4G72D@?'P@
M:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG<W)C=7)I)UTI*2![#0H@("`@
M("`@("`@("`@("`@)'1H:7,M/E]C86YN;W1(879E4W)C<&%C:V%G92@D<F5L
M96%S92D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<F5L96%S97,@
M/2`D=&AI<RT^7W!A8VMA9V5);F9O6R=B=6YD;&4G73L-"B`@("`@("`@("`@
M(&EF("@A:7-?87)R87DH)')E;&5A<V5S*2!\?"`A:7-S970H)')E;&5A<V5S
M6S!=*2D@>PT*("`@("`@("`@("`@("`@("1R96QE87-E<R`](&%R<F%Y*"1R
M96QE87-E<RD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F;W)E86-H
M("@D<F5L96%S97,@87,@)')E;"D@>PT*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<W1U<&ED4V-H96UA5F%L:61A=&4H87)R87DH#0H@("`@("`@("`@("`@
M("`@("`@("<J:6YS=&%L;&-O;F1I=&EO;G,G+`T*("`@("`@("`@("`@("`@
M("`@("`G*F9I;&5L:7-T)RP-"B`@("`@("`@("`@("`@("`I+"`D<F5L+"`G
M/&)U;F1L93XG*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("!F;W)E86-H("@D<F5L96%S97,@87,@)')E;"D@>PT*("`@("`@("`@("`@
M:68@*&ES7V%R<F%Y*"1R96PI("8F(&%R<F%Y7VME>5]E>&ES=',H)VEN<W1A
M;&QC;VYD:71I;VYS)RP@)')E;"DI('L-"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7W9A;&ED871E26YS=&%L;$-O;F1I=&EO;G,H)')E;%LG:6YS=&%L;&-O
M;F1I=&EO;G,G72P-"B`@("`@("`@("`@("`@("`@("`@(CPD<F5L96%S93X\
M:6YS=&%L;&-O;F1I=&EO;G,^(BD[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!I9B`H:7-?87)R87DH)')E;"D@)B8@87)R87E?:V5Y7V5X:7-T<R@G
M9FEL96QI<W0G+"`D<F5L*2D@>PT*("`@("`@("`@("`@("`@(&EF("@D<F5L
M6R=F:6QE;&ES="==*2![#0H@("`@("`@("`@("`@("`@("`@(`T*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E1FEL96QI<W0H)')E;%LG
M9FEL96QI<W0G72P@=')U92D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M5&AI<R!I<R!H97)E('1O(&%L;&]W(')O;&4@97AT96YS:6]N('1H<F]U9V@@
M<&QU9VEN<PT*("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!?=F%L:61A=&52;VQE*"1R;VQE*0T*("`@('L-"B`@("`@("`@
M<F5T=7)N(&EN7V%R<F%Y*"1R;VQE+"!014%27TEN<W1A;&QE<E]2;VQE.CIG
M971686QI9%)O;&5S*"1T:&ES+3Y?<&8M/F=E=%!A8VMA9V54>7!E*"DI*3L-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?:6YV86QI9%1A9T]R9&5R*"1O:W1A
M9W,L("1A8W1U86PL("1R;V]T*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S
M=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L#0H@("`@("`@("`@
M("!A<G)A>2@G;VMT86=S)R`]/B`D;VMT86=S+"`G86-T=6%L)R`]/B`D86-T
M=6%L+"`G<F]O="<@/3X@)')O;W0I+`T*("`@("`@("`@("`@)TEN=F%L:60@
M=&%G(&]R9&5R(&EN("5R;V]T)2P@9F]U;F0@/"5A8W1U86PE/B!E>'!E8W1E
M9"!O;F4@;V8@(B5O:W1A9W,E(B<I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N
M(%]I9VYO<F5.;W1!;&QO=V5D*"1T>7!E*0T*("`@('L-"B`@("`@("`@)'1H
M:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y
M*"=T>7!E)R`]/B`D='EP92DL#0H@("`@("`@("`@("`G/"5T>7!E)3X@:7,@
M;F]T(&%L;&]W960@:6YS:61E(&=L;V)A;"`\8V]N=&5N=',^+"!O;FQY(&EN
M<VED92`G("X-"B`@("`@("`@("`@("<\<&AP<F5L96%S93XO/&5X=&)I;G)E
M;&5A<V4^+"!U<V4@/&1I<CX@86YD(#QF:6QE/B!O;FQY)RD[#0H@("`@?0T*
M#0H@("`@9G5N8W1I;VX@7V9I;&5.;W1!;&QO=V5D*"1T>7!E*0T*("`@('L-
M"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E
M<G)O<B<L(&%R<F%Y*"=T>7!E)R`]/B`D='EP92DL#0H@("`@("`@("`@("`G
M/"5T>7!E)3X@:7,@;F]T(&%L;&]W960@:6YS:61E(')E;&5A<V4@/&9I;&5L
M:7-T/BP@;VYL>2!I;G-I9&4@)R`N#0H@("`@("`@("`@("`G/&-O;G1E;G1S
M/BP@=7-E(#QI9VYO<F4^(&%N9"`\:6YS=&%L;#X@;VYL>2<I.PT*("`@('T-
M"@T*("`@(&9U;F-T:6]N(%]T86=-:7-S:6YG071T<FEB=71E*"1T86<L("1A
M='1R+"`D8V]N=&5X="D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM
M/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@G=&%G)R`]/B`D
M=&%G+`T*("`@("`@("`@("`@)V%T=')I8G5T92<@/3X@)&%T='(L("=C;VYT
M97AT)R`]/B`D8V]N=&5X="DL#0H@("`@("`@("`@("`G=&%G(#PE=&%G)3X@
M:6X@8V]N=&5X="`B)6-O;G1E>'0E(B!H87,@;F\@871T<FEB=71E("(E871T
M<FEB=71E)2(G*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?=&%G2&%S3F]!
M='1R:6)S*"1T86<L("1C;VYT97AT*0T*("`@('L-"B`@("`@("`@)'1H:7,M
M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=T
M86<G(#T^("1T86<L#0H@("`@("`@("`@("`G8V]N=&5X="<@/3X@)&-O;G1E
M>'0I+`T*("`@("`@("`@("`@)W1A9R`\)71A9R4^(&AA<R!N;R!A='1R:6)U
M=&5S(&EN(&-O;G1E>'0@(B5C;VYT97AT)2(G*3L-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!?:6YV86QI9$EN=&5R;F%L4W1R=6-T=7)E*"D-"B`@("![#0H@
M("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97AC
M97!T:6]N)RP@87)R87DH*2P-"B`@("`@("`@("`@("=I;G1E<FYA;"!A<G)A
M>2!W87,@;F]T(&=E;F5R871E9"!B>2!C;VUP871I8FQE('!A<G-E<BP@;W(@
M97AT<F5M92!P87)S97(@97)R;W(L(&-A;FYO="!C;VYT:6YU92<I.PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N(%]I;G9A;&ED1FEL95)O;&4H)&9I;&4L("1D
M:7(L("1R;VQE*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S
M:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*`T*("`@("`@("`@("`@
M)V9I;&4G(#T^("1F:6QE+"`G9&ER)R`]/B`D9&ER+"`G<F]L92<@/3X@)')O
M;&4L#0H@("`@("`@("`@("`G<F]L97,G(#T^(%!%05)?26YS=&%L;&5R7U)O
M;&4Z.F=E=%9A;&ED4F]L97,H)'1H:7,M/E]P9BT^9V5T4&%C:V%G951Y<&4H
M*2DI+`T*("`@("`@("`@("`@)T9I;&4@(B5F:6QE)2(@:6X@9&ER96-T;W)Y
M("(E9&ER)2(@:&%S(&EN=F%L:60@<F]L92`B)7)O;&4E(BP@<VAO=6QD(&)E
M(&]N92!O9B`E<F]L97,E)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7VEN
M=F%L:61&:6QE3F%M92@D9FEL92P@)&1I<BD-"B`@("![#0H@("`@("`@("1T
M:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A
M>2@-"B`@("`@("`@("`@("=F:6QE)R`]/B`D9FEL92DL#0H@("`@("`@("`@
M("`G1FEL92`B)69I;&4E(B!C86YN;W0@8F5G:6X@=VET:"`B+B(G*3L-"B`@
M("!]#0H-"B`@("!F=6YC=&EO;B!?9FEL96QI<W1#86YN;W1#;VYT86EN1FEL
M92@D9FEL96QI<W0I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP
M=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)W1A9R<@/3X@)&9I
M;&5L:7-T*2P-"B`@("`@("`@("`@("<\)71A9R4^(&-A;B!O;FQY(&-O;G1A
M:6X@/&1I<CXL(&-O;G1A:6YS(#QF:6QE/BX@(%5S92`G("X-"B`@("`@("`@
M("`@("<\9&ER(&YA;64](B\B/B!A<R!T:&4@9FER<W0@9&ER(&5L96UE;G0G
M*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?9FEL96QI<W1-=7-T0V]N=&%I
M;D1I<B@D9FEL96QI<W0I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K
M+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)W1A9R<@/3X@
M)&9I;&5L:7-T*2P-"B`@("`@("`@("`@("<\)71A9R4^(&UU<W0@8V]N=&%I
M;B`\9&ER/BX@(%5S92`\9&ER(&YA;64](B\B/B!A<R!T:&4@)R`N#0H@("`@
M("`@("`@("`G9FER<W0@9&ER(&5L96UE;G0G*3L-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!?=&%G0V%N;F]T0F5%;7!T>2@D=&%G*0T*("`@('L-"B`@("`@
M("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L
M(&%R<F%Y*"=T86<G(#T^("1T86<I+`T*("`@("`@("`@("`@)SPE=&%G)3X@
M8V%N;F]T(&)E(&5M<'1Y("@\)71A9R4O/BDG*3L-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!?57)L3W)#:&%N;F5L*"1T>7!E+"`D;F%M92D-"B`@("![#0H@
M("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R
M;W(G+"!A<G)A>2@G='EP92<@/3X@)'1Y<&4L#0H@("`@("`@("`@("`G;F%M
M92<@/3X@)&YA;64I+`T*("`@("`@("`@("`@)U)E<75I<F5D(&1E<&5N9&5N
M8WD@/"5T>7!E)3X@(B5N86UE)2(@8V%N(&AA=F4@96ET:&5R('5R;"!/4B`G
M("X-"B`@("`@("`@("`@("=C:&%N;F5L(&%T=')I8G5T97,L(&%N9"!N;W0@
M8F]T:"<I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%].;T-H86YN96PH)'1Y
M<&4L("1N86UE*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S
M:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=T>7!E)R`]/B`D='EP
M92P-"B`@("`@("`@("`@("=N86UE)R`]/B`D;F%M92DL#0H@("`@("`@("`@
M("`G4F5Q=6ER960@9&5P96YD96YC>2`\)71Y<&4E/B`B)6YA;64E(B!M=7-T
M(&AA=F4@96ET:&5R('5R;"!/4B`G("X-"B`@("`@("`@("`@("=C:&%N;F5L
M(&%T=')I8G5T97,G*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?57)L3W)#
M:&%N;F5L1W)O=7`H)'1Y<&4L("1N86UE+"`D9W)O=7`I#0H@("`@>PT*("`@
M("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R
M)RP@87)R87DH)W1Y<&4G(#T^("1T>7!E+`T*("`@("`@("`@("`@)VYA;64G
M(#T^("1N86UE+"`G9W)O=7`G(#T^("1G<F]U<"DL#0H@("`@("`@("`@("`G
M1W)O=7`@(B5G<F]U<"4B(&1E<&5N9&5N8WD@/"5T>7!E)3X@(B5N86UE)2(@
M8V%N(&AA=F4@96ET:&5R('5R;"!/4B`G("X-"B`@("`@("`@("`@("=C:&%N
M;F5L(&%T=')I8G5T97,L(&%N9"!N;W0@8F]T:"<I.PT*("`@('T-"@T*("`@
M(&9U;F-T:6]N(%].;T-H86YN96Q'<F]U<"@D='EP92P@)&YA;64L("1G<F]U
M<"D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#
M5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@G='EP92<@/3X@)'1Y<&4L#0H@("`@
M("`@("`@("`G;F%M92<@/3X@)&YA;64L("=G<F]U<"<@/3X@)&=R;W5P*2P-
M"B`@("`@("`@("`@("='<F]U<"`B)6=R;W5P)2(@9&5P96YD96YC>2`\)71Y
M<&4E/B`B)6YA;64E(B!M=7-T(&AA=F4@96ET:&5R('5R;"!/4B`G("X-"B`@
M("`@("`@("`@("=C:&%N;F5L(&%T=')I8G5T97,G*3L-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!?=6YK;F]W;D-H86YN96PH)&-H86YN96PI#0H@("`@>PT*
M("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R
M<F]R)RP@87)R87DH)V-H86YN96PG(#T^("1C:&%N;F5L*2P-"B`@("`@("`@
M("`@("=5;FMN;W=N(&-H86YN96P@(B5C:&%N;F5L)2(G*3L-"B`@("!]#0H-
M"B`@("!F=6YC=&EO;B!?;F]086-K86=E5F5R<VEO;B@I#0H@("`@>PT*("`@
M("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R
M)RP@87)R87DH*2P-"B`@("`@("`@("`@("=P86-K86=E+GAM;"`\<&%C:V%G
M93X@=&%G(&AA<R!N;R!V97)S:6]N(&%T=')I8G5T92P@;W(@=F5R<VEO;B!I
M<R!N;W0@,BXP)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7TYO0G5N9&QE
M9%!A8VMA9V5S*"D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U
M<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@I+`T*("`@("`@("`@
M("`@)TYO(#QB=6YD;&5D<&%C:V%G93X@=&%G('=A<R!F;W5N9"!I;B`\8V]N
M=&5N=',^+"!R97%U:7)E9"!F;W(@8G5N9&QE('!A8VMA9V5S)RD[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@7T%T3&5A<W0R0G5N9&QE9%!A8VMA9V5S*"D-
M"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/
M3E]?+"`G97)R;W(G+"!A<G)A>2@I+`T*("`@("`@("`@("`@)T%T(&QE87-T
M(#(@<&%C:V%G97,@;75S="!B92!B=6YD;&5D(&EN(&$@8G5N9&QE('!A8VMA
M9V4G*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?0VAA;FYE;$]R57)I*"1N
M86UE*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T95
M3D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=N86UE)R`]/B`D;F%M92DL#0H@
M("`@("`@("`@("`G0G5N9&QE9"!P86-K86=E("(E;F%M924B(&-A;B!H879E
M(&5I=&AE<B!A('5R:2!O<B!A(&-H86YN96PL(&YO="!B;W1H)RD[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@7VYO0VAI;&1486<H)&-H:6QD+"`D=&%G*0T*
M("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].
M7U\L("=E<G)O<B<L(&%R<F%Y*"=C:&EL9"<@/3X@)&-H:6QD+"`G=&%G)R`]
M/B`D=&%G*2P-"B`@("`@("`@("`@("=486<@/"5T86<E/B!I<R!M:7-S:6YG
M(&-H:6QD('1A9R`\)6-H:6QD)3XG*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!?:6YV86QI9%9E<G-I;VXH)'1Y<&4L("1V86QU92D-"B`@("![#0H@("`@
M("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G
M+"!A<G)A>2@G='EP92<@/3X@)'1Y<&4L("=V86QU92<@/3X@)'9A;'5E*2P-
M"B`@("`@("`@("`@("=697)S:6]N('1Y<&4@/"5T>7!E)3X@:7,@;F]T(&$@
M=F%L:60@=F5R<VEO;B`H)79A;'5E)2DG*3L-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!?:6YV86QI9%-T871E*"1T>7!E+"`D=F%L=64I#0H@("`@>PT*("`@
M("`@("`D<W1A=&5S(#T@87)R87DH)W-T86)L92<L("=B971A)RP@)V%L<&AA
M)RP@)V1E=F5L)RD[#0H@("`@("`@(&EF("@D='EP92`A/2`G87!I)RD@>PT*
M("`@("`@("`@("`@)'-T871E<UM=(#T@)W-N87!S:&]T)SL-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H<W1R=&]L;W=E<B@D=F%L=64I(#T]("=R8R<I('L-
M"B`@("`@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?
M+"`G97)R;W(G+`T*("`@("`@("`@("`@("`@(&%R<F%Y*"=V97)S:6]N)R`]
M/B`D=&AI<RT^7W!A8VMA9V5);F9O6R=V97)S:6]N)UU;)W)E;&5A<V4G72DL
M#0H@("`@("`@("`@("`@("`@)U)#(&ES(&YO="!A('-T871E+"!I="!I<R!A
M('9E<G-I;VX@<&]S=&9I>"P@=')Y("5V97)S:6]N)5)#,2P@<W1A8FEL:71Y
M(&)E=&$G*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7W-T86-K+3YP
M=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)W1Y<&4G(#T^("1T
M>7!E+"`G=F%L=64G(#T^("1V86QU92P-"B`@("`@("`@("`@("=T>7!E<R<@
M/3X@)'-T871E<RDL#0H@("`@("`@("`@("`G4W1A8FEL:71Y('1Y<&4@/"5T
M>7!E)3X@:7,@;F]T(&$@=F%L:60@<W1A8FEL:71Y("@E=F%L=64E*2P@;75S
M="!B92!O;F4@;V8@)R`N#0H@("`@("`@("`@("`G)71Y<&5S)2<I.PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N(%]I;G9A;&ED5&%S:R@D=&%S:RP@)')E="P@
M)&9I;&4I#0H@("`@>PT*("`@("`@("!S=VET8V@@*"1R971;,%TI('L-"B`@
M("`@("`@("`@(&-A<V4@4$5!4E]405-+7T524D]27TU)4U-)3D=?05144DE"
M(#H-"B`@("`@("`@("`@("`@("`D:6YF;R`](&%R<F%Y*"=A='1R:6(G(#T^
M("1R971;,5TL("=T87-K)R`]/B`D=&%S:RP@)V9I;&4G(#T^("1F:6QE*3L-
M"B`@("`@("`@("`@("`@("`D;7-G(#T@)W1A<VL@/"5T87-K)3X@:7,@;6ES
M<VEN9R!A='1R:6)U=&4@(B5A='1R:6(E(B!I;B!F:6QE("5F:6QE)2<[#0H@
M("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@4$5!4E]405-+
M7T524D]27TY/05144DE"4R`Z#0H@("`@("`@("`@("`@("`@)&EN9F\@/2!A
M<G)A>2@G=&%S:R<@/3X@)'1A<VLL("=F:6QE)R`]/B`D9FEL92D[#0H@("`@
M("`@("`@("`@("`@)&US9R`]("=T87-K(#PE=&%S:R4^(&AA<R!N;R!A='1R
M:6)U=&5S(&EN(&9I;&4@)69I;&4E)SL-"B`@("`@("`@("`@(&)R96%K.PT*
M("`@("`@("`@("`@8V%S92!014%27U1!4TM?15)23U)?5U)/3D=?05144DE"
M7U9!3%5%(#H-"B`@("`@("`@("`@("`@("`D:6YF;R`](&%R<F%Y*"=A='1R
M:6(G(#T^("1R971;,5TL("=V86QU97,G(#T^("1R971;,UTL#0H@("`@("`@
M("`@("`@("`@("`@("=W87,G(#T^("1R971;,ETL("=T87-K)R`]/B`D=&%S
M:RP@)V9I;&4G(#T^("1F:6QE*3L-"B`@("`@("`@("`@("`@("`D;7-G(#T@
M)W1A<VL@/"5T87-K)3X@871T<FEB=71E("(E871T<FEB)2(@:&%S('1H92!W
M<F]N9R!V86QU92`B)7=A<R4B("<N#0H@("`@("`@("`@("`@("`@("`@("=I
M;B!F:6QE("5F:6QE)2P@97AP96-T:6YG(&]N92!O9B`B)79A;'5E<R4B)SL-
M"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92!014%27U1!
M4TM?15)23U)?24Y604Q)1"`Z#0H@("`@("`@("`@("`@("`@)&EN9F\@/2!A
M<G)A>2@G<F5A<V]N)R`]/B`D<F5T6S%=+"`G=&%S:R<@/3X@)'1A<VLL("=F
M:6QE)R`]/B`D9FEL92D[#0H@("`@("`@("`@("`@("`@)&US9R`]("=T87-K
M(#PE=&%S:R4^(&EN(&9I;&4@)69I;&4E(&ES(&EN=F%L:60@8F5C875S92!O
M9B`B)7)E87-O;B4B)SL-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("!]
M#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G
M97)R;W(G+"`D:6YF;RP@)&US9RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M7W5N:VYO=VY487-K*"1T87-K+"`D9FEL92D-"B`@("![#0H@("`@("`@("1T
M:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A
M>2@G=&%S:R<@/3X@)'1A<VLL("=F:6QE)R`]/B`D9FEL92DL#0H@("`@("`@
M("`@("`G56YK;F]W;B!T87-K("(E=&%S:R4B('!A<W-E9"!I;B!F:6QE(#QF
M:6QE(&YA;64](B5F:6QE)2(^)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M7W-U8G!A8VMA9V5#86YN;W10<F]V:61E17AT96YS:6]N*"1N86UE*0T*("`@
M('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L
M("=E<G)O<B<L(&%R<F%Y*"=N86UE)R`]/B`D;F%M92DL#0H@("`@("`@("`@
M("`G4W5B<&%C:V%G92!D97!E;F1E;F-Y("(E;F%M924B(&-A;FYO="!U<V4@
M/'!R;W9I9&5S97AT96YS:6]N/BP@)R`N#0H@("`@("`@("`@("`G;VYL>2!P
M86-K86=E(&1E<&5N9&5N8VEE<R!C86X@=7-E('1H:7,@=&%G)RD[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@7W-U8G!A8VMA9V5S0V%N;F]T0V]N9FQI8W0H
M)&YA;64I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?
M1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)VYA;64G(#T^("1N86UE*2P-
M"B`@("`@("`@("`@("=3=6)P86-K86=E(&1E<&5N9&5N8WD@(B5N86UE)2(@
M8V%N;F]T('5S92`\8V]N9FQI8W1S+SXL("<@+@T*("`@("`@("`@("`@)V]N
M;'D@<&%C:V%G92!D97!E;F1E;F-I97,@8V%N('5S92!T:&ES('1A9R<I.PT*
M("`@('T-"@T*("`@(&9U;F-T:6]N(%]C86YN;W10<F]V:61E17AT96YS:6]N
M*"1R96QE87-E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S
M:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=R96QE87-E)R`]/B`D
M<F5L96%S92DL#0H@("`@("`@("`@("`G/"5R96QE87-E)3X@<&%C:V%G97,@
M8V%N;F]T('5S92`\<')O=FED97-E>'1E;G-I;VX^+"!O;FQY(&5X=&)I;G)E
M;&5A<V4@86YD(&5X='-R8W)E;&5A<V4@8V%N('!R;W9I9&4@82!02%`@97AT
M96YS:6]N)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7VUU<W10<F]V:61E
M17AT96YS:6]N*"1R96QE87-E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S
M=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=R96QE
M87-E)R`]/B`D<F5L96%S92DL#0H@("`@("`@("`@("`G/"5R96QE87-E)3X@
M<&%C:V%G97,@;75S="!U<V4@/'!R;W9I9&5S97AT96YS:6]N/B!T;R!I;F1I
M8V%T92!W:&EC:"!02%`@97AT96YS:6]N(&ES('!R;W9I9&5D)RD[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@7V-A;FYO=$AA=F53<F-P86-K86=E*"1R96QE
M87-E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T95
M3D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=R96QE87-E)R`]/B`D<F5L96%S
M92DL#0H@("`@("`@("`@("`G/"5R96QE87-E)3X@<&%C:V%G97,@8V%N;F]T
M('-P96-I9GD@82!S;W5R8V4@8V]D92!P86-K86=E+"!O;FQY(&5X=&5N<VEO
M;B!B:6YA<FEE<R!M87D@=7-E('1H92`\<W)C<&%C:V%G93X@=&%G)RD[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@7VUU<W13<F-086-K86=E*"1R96QE87-E
M*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-4
M24].7U\L("=E<G)O<B<L(&%R<F%Y*"=R96QE87-E)R`]/B`D<F5L96%S92DL
M#0H@("`@("`@("`@("`G/&5X=&)I;G)E;&5A<V4^('!A8VMA9V5S(&UU<W0@
M<W!E8VEF>2!A('-O=7)C92!C;V1E('!A8VMA9V4@=VET:"`\<W)C<&%C:V%G
M93XG*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?;75S=%-R8W5R:2@D<F5L
M96%S92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&
M54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@G<F5L96%S92<@/3X@)')E;&5A
M<V4I+`T*("`@("`@("`@("`@)SQE>'1B:6YR96QE87-E/B!P86-K86=E<R!M
M=7-T('-P96-I9GD@82!S;W5R8V4@8V]D92!P86-K86=E('=I=&@@/'-R8W5R
M:3XG*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?=7)I1&5P<T-A;FYO=$AA
M=F5697)S:6]N:6YG*"1T>7!E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S
M=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=T>7!E
M)R`]/B`D='EP92DL#0H@("`@("`@("`@("`G)71Y<&4E.B!D97!E;F1E;F-I
M97,@=VET:"!A(#QU<FD^('1A9R!C86YN;W0@:&%V92!A;GD@=F5R<VEO;FEN
M9R!I;F9O<FUA=&EO;B<I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]C;VYF
M;&EC=&EN9T1E<'-#86YN;W1(879E5F5R<VEO;FEN9R@D='EP92D-"B`@("![
M#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G
M97)R;W(G+"!A<G)A>2@G='EP92<@/3X@)'1Y<&4I+`T*("`@("`@("`@("`@
M)R5T>7!E)3H@8V]N9FQI8W1I;F<@9&5P96YD96YC:65S(&-A;FYO="!H879E
M('9E<G-I;VYI;F<@:6YF;RP@=7-E(#QE>&-L=61E/B!T;R`G("X-"B`@("`@
M("`@("`@("=E>&-L=61E('-P96-I9FEC('9E<G-I;VYS(&]F(&$@9&5P96YD
M96YC>2<I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]$97!C:&%N;F5L0V%N
M;F]T0F55<FDH)'1Y<&4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K
M+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)W1Y<&4G(#T^
M("1T>7!E*2P-"B`@("`@("`@("`@("<E='EP924Z(&-H86YN96P@8V%N;F]T
M(&)E(%]?=7)I+"!T:&ES(&ES(&$@<'-E=61O+6-H86YN96P@<F5S97)V960@
M9F]R('5R:2`G("X-"B`@("`@("`@("`@("=D97!E;F1E;F-I97,@;VYL>2<I
M.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]B=6YD;&5D4&%C:V%G97--=7-T
M0F5&:6QE;F%M92@I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP
M=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH*2P-"B`@("`@("`@
M("`@("<\8G5N9&QE9'!A8VMA9V4^('1A9W,@;75S="!C;VYT86EN(&]N;'D@
M=&AE(&9I;&5N86UE(&]F(&$@<&%C:V%G92!R96QE87-E("<@+@T*("`@("`@
M("`@("`@)VEN('1H92!B=6YD;&4G*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!?8FEN87)Y4&%C:V%G94UU<W1"95!A8VMA9V5N86UE*"D-"B`@("![#0H@
M("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R
M;W(G+"!A<G)A>2@I+`T*("`@("`@("`@("`@)SQB:6YA<GEP86-K86=E/B!T
M86=S(&UU<W0@8V]N=&%I;B!T:&4@;F%M92!O9B!A('!A8VMA9V4@=&AA="!I
M<R`G("X-"B`@("`@("`@("`@("=A(&-O;7!I;&5D('9E<G-I;VX@;V8@=&AI
M<R!E>'1S<F,@<&%C:V%G92<I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]F
M:6QE3F]T1F]U;F0H)&9I;&4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T
M86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)V9I;&4G
M(#T^("1F:6QE*2P-"B`@("`@("`@("`@("=&:6QE("(E9FEL924B(&EN('!A
M8VMA9V4N>&UL(&1O97,@;F]T(&5X:7-T)RD[#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@7VYO=$EN0V]N=&5N=',H)&9I;&4L("1T86<I#0H@("`@>PT*("`@
M("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R
M)RP@87)R87DH)V9I;&4G(#T^("1F:6QE+"`G=&%G)R`]/B`D=&%G*2P-"B`@
M("`@("`@("`@("<\)71A9R4@;F%M93TB)69I;&4E(CX@:7,@:6YV86QI9"P@
M9FEL92!I<R!N;W0@:6X@/&-O;G1E;G1S/B<I.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N(%]C86YN;W1686QI9&%T94YO4&%T:%-E="@I#0H@("`@>PT*("`@
M("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R
M)RP@87)R87DH*2P-"B`@("`@("`@("`@("=#86YN;W0@=F%L:61A=&4@9FEL
M97,L(&YO('!A=&@@=&\@<&%C:V%G92!F:6QE(&ES('-E="`H=7-E('-E=%!A
M8VMA9V5&:6QE*"DI)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7W5S97-R
M;VQE=&%S:TUU<W1(879E0VAA;FYE;$]R57)I*"1R;VQE+"`D=&%G*0T*("`@
M('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L
M("=E<G)O<B<L(&%R<F%Y*"=R;VQE)R`]/B`D<F]L92P@)W1A9R<@/3X@)'1A
M9RDL#0H@("`@("`@("`@("`G/"5T86<E/B!M=7-T(&-O;G1A:6X@96ET:&5R
M(#QU<FD^+"!O<B`\8VAA;FYE;#X@86YD(#QP86-K86=E/B<I.PT*("`@('T-
M"@T*("`@(&9U;F-T:6]N(%]U<V5S<F]L971A<VM-=7-T2&%V95!A8VMA9V4H
M)')O;&4L("1T86<I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP
M=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)W)O;&4G(#T^("1R
M;VQE+"`G=&%G)R`]/B`D=&%G*2P-"B`@("`@("`@("`@("<\)71A9R4^(&UU
M<W0@8V]N=&%I;B`\<&%C:V%G93XG*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!?=7-E<W)O;&5T87-K375S=$AA=F52;VQE5&%S:R@D=&%G+"`D='EP92D-
M"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/
M3E]?+"`G97)R;W(G+"!A<G)A>2@G=&%G)R`]/B`D=&%G+"`G='EP92<@/3X@
M)'1Y<&4I+`T*("`@("`@("`@("`@)SPE=&%G)3X@;75S="!C;VYT86EN(#PE
M='EP924^(&1E9FEN:6YG('1H92`E='EP924@=&\@8F4@=7-E9"<I.PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N(%]C86YN;W1#;VYF;&EC=%=I=&A!;&Q/<R@D
M='EP92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&
M54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@G=&%G)R`]/B`D=&%G*2P-"B`@
M("`@("`@("`@("<E=&%G)2!C86YN;W0@8V]N9FQI8W0@=VET:"!A;&P@3U-E
M<R<I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]I;G9A;&ED1&5P1W)O=7!.
M86UE*"1N86UE*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S
M:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=G<F]U<"<@/3X@)&YA
M;64I+`T*("`@("`@("`@("`@)TEN=F%L:60@9&5P96YD96YC>2!G<F]U<"!N
M86UE("(E;F%M924B)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7V%N86QY
M>F5"=6YD;&5D4&%C:V%G97,H*0T*("`@('L-"B`@("`@("`@:68@*"$D=&AI
M<RT^7VES5F%L:60I('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H(21T:&ES+3Y?<&8M/F=E=%!A8VMA9V54
M>7!E*"D@/3T@)V)U;F1L92<I('L-"B`@("`@("`@("`@(')E='5R;B!F86QS
M93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&8M
M/E]P86-K86=E1FEL92DI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("`@("`@?0T*("`@("`@("`D9&ER7W!R969I>"`](&1I<FYA;64H)'1H
M:7,M/E]P9BT^7W!A8VMA9V5&:6QE*3L-"B`@("`@("`@)&QO9R`](&ES<V5T
M*"1T:&ES+3Y?<&8M/E]L;V=G97(I(#\@87)R87DH)B1T:&ES+3Y?<&8M/E]L
M;V=G97(L("=L;V<G*2`Z#0H@("`@("`@("`@("!A<G)A>2@G4$5!4E]#;VUM
M;VXG+"`G;&]G)RD[#0H@("`@("`@("1I;F9O(#T@)'1H:7,M/E]P9BT^9V5T
M0V]N=&5N=',H*3L-"B`@("`@("`@)&EN9F\@/2`D:6YF;ULG8G5N9&QE9'!A
M8VMA9V4G73L-"B`@("`@("`@:68@*"%I<U]A<G)A>2@D:6YF;RDI('L-"B`@
M("`@("`@("`@("1I;F9O(#T@87)R87DH)&EN9F\I.PT*("`@("`@("!]#0H@
M("`@("`@("1P:V<@/2`F;F5W(%!%05)?4&%C:V%G949I;&4H)'1H:7,M/E]P
M9BT^7V-O;F9I9RD[#0H@("`@("`@(&9O<F5A8V@@*"1I;F9O(&%S("1P86-K
M86=E*2![#0H@("`@("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1D:7)?<')E
M9FEX("X@1$E214-43U)97U-%4$%2051/4B`N("1P86-K86=E*2D@>PT*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?9FEL94YO=$9O=6YD*"1D:7)?<')E9FEX
M("X@1$E214-43U)97U-%4$%2051/4B`N("1P86-K86=E*3L-"B`@("`@("`@
M("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@8V%L;%]U
M<V5R7V9U;F-?87)R87DH)&QO9RP@87)R87DH,2P@(D%N86QY>FEN9R!B=6YD
M;&5D('!A8VMA9V4@)'!A8VMA9V4B*2D[#0H@("`@("`@("`@("!014%2.CIP
M=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@
M("`@("`D<F5T(#T@)'!K9RT^9G)O;4%N>49I;&4H)&1I<E]P<F5F:7@@+B!$
M25)%0U1/4EE?4T5005)!5$]2("X@)'!A8VMA9V4L#0H@("`@("`@("`@("`@
M("`@4$5!4E]604Q)1$%415].3U)-04PI.PT*("`@("`@("`@("`@4$5!4CHZ
M<&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)')E="DI('L-"B`@("`@("`@("`@("`@("!C86QL7W5S97)?9G5N
M8U]A<G)A>2@D;&]G+"!A<G)A>2@P+"`B15)23U(Z('!A8VMA9V4@)'!A8VMA
M9V4@:7,@;F]T(&$@=F%L:60@(B`N#0H@("`@("`@("`@("`@("`@("`@("=P
M86-K86=E)RDI.PT*("`@("`@("`@("`@("`@("1I;F8@/2`D<F5T+3YG9715
M<V5R26YF;R@I.PT*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D:6YF
M*2D@>PT*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D:6YF(&%S("1E
M<G(I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&-A;&Q?=7-E<E]F=6YC
M7V%R<F%Y*"1L;V<L(&%R<F%Y*#$L("1E<G);)VUE<W-A9V4G72DI.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!?86YA;'EZ95!H<$9I;&5S*"D-"B`@("![#0H@("`@("`@(&EF("@A
M)'1H:7,M/E]I<U9A;&ED*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!F+3Y?
M<&%C:V%G949I;&4I*2![#0H@("`@("`@("`@("`D=&AI<RT^7V-A;FYO=%9A
M;&ED871E3F]0871H4V5T*"D[#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@("`@('T-"B`@("`@("`@)&1I<E]P<F5F:7@@/2!D:7)N86UE*"1T
M:&ES+3Y?<&8M/E]P86-K86=E1FEL92D[#0H@("`@("`@("1C;VUM;VX@/2!N
M97<@4$5!4E]#;VUM;VX[#0H@("`@("`@("1L;V<@/2!I<W-E="@D=&AI<RT^
M7W!F+3Y?;&]G9V5R*2`_(&%R<F%Y*"8D=&AI<RT^7W!F+3Y?;&]G9V5R+"`G
M;&]G)RD@.@T*("`@("`@("`@("`@87)R87DH)B1C;VUM;VXL("=L;V<G*3L-
M"B`@("`@("`@)&EN9F\@/2`D=&AI<RT^7W!F+3YG971#;VYT96YT<R@I.PT*
M("`@("`@("`D:6YF;R`]("1I;F9O6R=D:7(G75LG9FEL92==.PT*("`@("`@
M("!I9B`H:7-S970H)&EN9F];)V%T=')I8G,G72DI('L-"B`@("`@("`@("`@
M("1I;F9O(#T@87)R87DH)&EN9F\I.PT*("`@("`@("!]#0H@("`@("`@("1P
M<F]V:61E<R`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*"1I;F9O(&%S
M("1F82D@>PT*("`@("`@("`@("`@)&9A(#T@)&9A6R=A='1R:6)S)UT[#0H@
M("`@("`@("`@("`D9FEL92`]("1F85LG;F%M92==.PT*("`@("`@("`@("`@
M:68@*"%F:6QE7V5X:7-T<R@D9&ER7W!R969I>"`N($1)4D5#5$]265]315!!
M4D%43U(@+B`D9FEL92DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V9I
M;&5.;W1&;W5N9"@D9&ER7W!R969I>"`N($1)4D5#5$]265]315!!4D%43U(@
M+B`D9FEL92D[#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@
M,#L-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(&EF("AI;E]A<G)A>2@D9F%;)W)O;&4G72P@4$5!4E])
M;G-T86QL97)?4F]L93HZ9V5T4&AP4F]L97,H*2D@)B8@)&1I<E]P<F5F:7@I
M('L-"B`@("`@("`@("`@("`@("!C86QL7W5S97)?9G5N8U]A<G)A>2@D;&]G
M+"!A<G)A>2@Q+"`B06YA;'EZ:6YG("1F:6QE(BDI.PT*("`@("`@("`@("`@
M("`@("1S<F-I;F9O(#T@)'1H:7,M/F%N86QY>F53;W5R8V5#;V1E*"1D:7)?
M<')E9FEX("X@1$E214-43U)97U-%4$%2051/4B`N("1F:6QE*3L-"B`@("`@
M("`@("`@("`@("!I9B`H)'-R8VEN9F\I('L-"B`@("`@("`@("`@("`@("`@
M("`@)'!R;W9I9&5S(#T@87)R87E?;65R9V4H)'!R;W9I9&5S+"`D=&AI<RT^
M7V)U:6QD4')O=FED97-!<G)A>2@D<W)C:6YF;RDI.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D=&AI
M<RT^7W!A8VMA9V5.86UE(#T@)'!N(#T@)'1H:7,M/E]P9BT^9V5T4&%C:V%G
M92@I.PT*("`@("`@("`D<&YL(#T@<W1R;&5N*"1P;BD[#0H@("`@("`@(&9O
M<F5A8V@@*"1P<F]V:61E<R!A<R`D:V5Y(#T^("1W:&%T*2![#0H@("`@("`@
M("`@("!I9B`H:7-S970H)'=H871;)V5X<&QI8VET)UTI('Q\("$D=VAA="D@
M>PT*("`@("`@("`@("`@("`@("\O('-K:7`@8V]N9F]R;6%N8V4@8VAE8VMS
M(&EF('1H92!P<F]V:61E<R!E;G1R>2!I<PT*("`@("`@("`@("`@("`@("\O
M('-P96-I9FEE9"!I;B!T:&4@<&%C:V%G92YX;6P@9FEL90T*("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M97AT<F%C="@D=VAA="D[#0H@("`@("`@("`@("!I9B`H)'1Y<&4@/3T@)V-L
M87-S)RD@>PT*("`@("`@("`@("`@("`@(&EF("@A<W1R;F-A<V5C;7`H)&YA
M;64L("1P;BP@)'!N;"DI('L-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN
M=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G=V%R;FEN9R<L#0H@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"=F:6QE)R`]/B`D9FEL92P@)W1Y<&4G
M(#T^("1T>7!E+"`G;F%M92<@/3X@)&YA;64L("=P86-K86=E)R`]/B`D<&XI
M+`T*("`@("`@("`@("`@("`@("`@("`G:6X@)69I;&4E.B`E='EP924@(B5N
M86UE)2(@;F]T('!R969I>&5D('=I=&@@<&%C:V%G92!N86UE("(E<&%C:V%G
M924B)RD[#0H@("`@("`@("`@("!](&5L<V5I9B`H)'1Y<&4@/3T@)V9U;F-T
M:6]N)RD@>PT*("`@("`@("`@("`@("`@(&EF("AS=')S='(H)&YA;64L("<Z
M.B<I('Q\("%S=')N8V%S96-M<"@D;F%M92P@)'!N+"`D<&YL*2D@>PT*("`@
M("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-4
M24].7U\L("=W87)N:6YG)RP-"B`@("`@("`@("`@("`@("`@("`@87)R87DH
M)V9I;&4G(#T^("1F:6QE+"`G='EP92<@/3X@)'1Y<&4L("=N86UE)R`]/B`D
M;F%M92P@)W!A8VMA9V4G(#T^("1P;BDL#0H@("`@("`@("`@("`@("`@("`@
M("=I;B`E9FEL924Z("5T>7!E)2`B)6YA;64E(B!N;W0@<')E9FEX960@=VET
M:"!P86-K86=E(&YA;64@(B5P86-K86=E)2(G*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'1H:7,M/E]I<U9A;&ED.PT*
M("`@('T-"@T*("`@("\J*@T*("`@("`J($%N86QY>F4@=&AE('-O=7)C92!C
M;V1E(&]F('1H92!G:79E;B!02%`@9FEL90T*("`@("`J#0H@("`@("H@0'!A
M<F%M("!S=')I;F<@1FEL96YA;64@;V8@=&AE(%!(4"!F:6QE#0H@("`@("H@
M0'!A<F%M("!B;V]L96%N('=H971H97(@=&\@86YA;'EZ92`D9FEL92!A<R!T
M:&4@9FEL92!C;VYT96YT<PT*("`@("`J($!R971U<FX@;6EX960-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!A;F%L>7IE4V]U<F-E0V]D92@D9FEL92P@)'-T
M<FEN9R`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*"%F=6YC=&EO;E]E
M>&ES=',H(G1O:V5N7V=E=%]A;&PB*2D@>PT*("`@("`@("`@("`@)'1H:7,M
M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=F
M:6QE)R`]/B`D9FEL92DL#0H@("`@("`@("`@("`@("`@)U!A<G-E<B!E<G)O
M<CH@=&]K96Y?9V5T7V%L;"@I(&9U;F-T:6]N(&UU<W0@97AI<W0@=&\@86YA
M;'EZ92!S;W5R8V4@8V]D92<I.PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A9&5F:6YE9"@G5%]$3T-?0T]-
M345.5"<I*2![#0H@("`@("`@("`@("!D969I;F4H)U1?1$]#7T-/34U%3E0G
M+"!47T-/34U%3E0I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A9&5F:6YE
M9"@G5%])3E1%4D9!0T4G*2D@>PT*("`@("`@("`@("`@9&5F:6YE*"=47TE.
M5$521D%#12<L("TQ*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(61E9FEN
M960H)U1?24U03$5-14Y44R<I*2![#0H@("`@("`@("`@("!D969I;F4H)U1?
M24U03$5-14Y44R<L("TQ*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'-T
M<FEN9RD@>PT*("`@("`@("`@("`@)&-O;G1E;G1S(#T@)&9I;&4[#0H@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("!I9B`H(21F<"`]($!F;W!E;B@D
M9FEL92P@(G(B*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES
M=',H)V9I;&5?9V5T7V-O;G1E;G1S)RDI('L-"B`@("`@("`@("`@("`@("!F
M8VQO<V4H)&9P*3L-"B`@("`@("`@("`@("`@("`D8V]N=&5N=',@/2!F:6QE
M7V=E=%]C;VYT96YT<R@D9FEL92D[#0H@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("1C;VYT96YT<R`]($!F<F5A9"@D9G`L(&9I;&5S
M:7IE*"1F:6QE*2D[#0H@("`@("`@("`@("`@("`@9F-L;W-E*"1F<"D[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)'1O:V5N<R`]('1O
M:V5N7V=E=%]A;&PH)&-O;G1E;G1S*3L-"B\J#0H@("`@("`@(&9O<B`H)&D@
M/2`P.R`D:2`\('-I>F5O9B@D=&]K96YS*3L@)&DK*RD@>PT*("`@("`@("`@
M("`@0&QI<W0H)'1O:V5N+"`D9&%T82D@/2`D=&]K96YS6R1I73L-"B`@("`@
M("`@("`@(&EF("AI<U]S=')I;F<H)'1O:V5N*2D@>PT*("`@("`@("`@("`@
M("`@('9A<E]D=6UP*"1T;VME;BD[#0H@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@('!R:6YT('1O:V5N7VYA;64H)'1O:V5N*2`N("<@
M)SL-"B`@("`@("`@("`@("`@("!V87)?9'5M<"AR=')I;2@D9&%T82DI.PT*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0HJ+PT*("`@("`@("`D;&]O:U]F
M;W(@/2`P.PT*("`@("`@("`D<&%R96Y?;&5V96P@/2`P.PT*("`@("`@("`D
M8G)A8VME=%]L979E;"`](#`[#0H@("`@("`@("1B<F%C95]L979E;"`](#`[
M#0H@("`@("`@("1L87-T<&AP9&]C(#T@)R<[#0H@("`@("`@("1C=7)R96YT
M7V-L87-S(#T@)R<[#0H@("`@("`@("1C=7)R96YT7VEN=&5R9F%C92`]("<G
M.PT*("`@("`@("`D8W5R<F5N=%]C;&%S<U]L979E;"`]("TQ.PT*("`@("`@
M("`D8W5R<F5N=%]F=6YC=&EO;B`]("<G.PT*("`@("`@("`D8W5R<F5N=%]F
M=6YC=&EO;E]L979E;"`]("TQ.PT*("`@("`@("`D9&5C;&%R961?8VQA<W-E
M<R`](&%R<F%Y*"D[#0H@("`@("`@("1D96-L87)E9%]I;G1E<F9A8V5S(#T@
M87)R87DH*3L-"B`@("`@("`@)&1E8VQA<F5D7V9U;F-T:6]N<R`](&%R<F%Y
M*"D[#0H@("`@("`@("1D96-L87)E9%]M971H;V1S(#T@87)R87DH*3L-"B`@
M("`@("`@)'5S961?8VQA<W-E<R`](&%R<F%Y*"D[#0H@("`@("`@("1U<V5D
M7V9U;F-T:6]N<R`](&%R<F%Y*"D[#0H@("`@("`@("1E>'1E;F1S(#T@87)R
M87DH*3L-"B`@("`@("`@)&EM<&QE;65N=',@/2!A<G)A>2@I.PT*("`@("`@
M("`D;F]D97!S(#T@87)R87DH*3L-"B`@("`@("`@)&EN<75O=&4@/2!F86QS
M93L-"B`@("`@("`@)&EN=&5R9F%C92`](&9A;'-E.PT*("`@("`@("!F;W(@
M*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'1O:V5N<RD[("1I*RLI('L-"B`@("`@
M("`@("`@(&EF("AI<U]A<G)A>2@D=&]K96YS6R1I72DI('L-"B`@("`@("`@
M("`@("`@("!L:7-T*"1T;VME;BP@)&1A=&$I(#T@)'1O:V5N<ULD:5T[#0H@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1T;VME;B`]
M("1T;VME;G-;)&E=.PT*("`@("`@("`@("`@("`@("1D871A(#T@)R<[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)&EN<75O=&4I('L-"B`@
M("`@("`@("`@("`@("!I9B`H)'1O:V5N("$]("<B)R`F)B`D=&]K96X@(3T@
M5%]%3D1?2$52141/0RD@>PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU
M93L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("`@("`D:6YQ=6]T92`](&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("!C
M;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!S=VET8V@@*"1T;VME;BD@>PT*("`@("`@("`@("`@("`@
M(&-A<V4@5%]72$E415-004-%(#H-"B`@("`@("`@("`@("`@("`@("`@8V]N
M=&EN=64[#0H@("`@("`@("`@("`@("`@8V%S92`G.R<Z#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@D:6YT97)F86-E*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D8W5R<F5N=%]F=6YC=&EO;B`]("<G.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)&-U<G)E;G1?9G5N8W1I;VY?;&5V96P@/2`M,3L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL-"B`@("`@("`@("`@("`@("!C87-E("<B)SH-"B`@("`@("`@("`@("`@
M("!C87-E(%1?4U1!4E1?2$52141/0SH-"B`@("`@("`@("`@("`@("`@("`@
M)&EN<75O=&4@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-
M"B`@("`@("`@("`@("`@("!C87-E(%1?0U523%E?3U!%3CH-"B`@("`@("`@
M("`@("`@("!C87-E(%1?1$],3$%27T]014Y?0U523%E?0E)!0T53.@T*("`@
M("`@("`@("`@("`@(&-A<V4@)WLG.B`D8G)A8V5?;&5V96PK*SL@8V]N=&EN
M=64@,CL-"B`@("`@("`@("`@("`@("!C87-E("=])SH-"B`@("`@("`@("`@
M("`@("`@("`@)&)R86-E7VQE=F5L+2T[#0H@("`@("`@("`@("`@("`@("`@
M(&EF("@D8W5R<F5N=%]C;&%S<U]L979E;"`]/2`D8G)A8V5?;&5V96PI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1C=7)R96YT7V-L87-S(#T@)R<[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=%]C;&%S<U]L979E
M;"`]("TQ.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@(&EF("@D8W5R<F5N=%]F=6YC=&EO;E]L979E;"`]/2`D8G)A8V5?
M;&5V96PI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1C=7)R96YT7V9U
M;F-T:6]N(#T@)R<[#0H@("`@("`@("`@("`@("`@("`@("`@("`D8W5R<F5N
M=%]F=6YC=&EO;E]L979E;"`]("TQ.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E(#([#0H@("`@("`@("`@
M("`@("`@8V%S92`G6R<Z("1B<F%C:V5T7VQE=F5L*RL[(&-O;G1I;G5E(#([
M#0H@("`@("`@("`@("`@("`@8V%S92`G72<Z("1B<F%C:V5T7VQE=F5L+2T[
M(&-O;G1I;G5E(#([#0H@("`@("`@("`@("`@("`@8V%S92`G*"<Z("1P87)E
M;E]L979E;"LK.R`@(&-O;G1I;G5E(#([#0H@("`@("`@("`@("`@("`@8V%S
M92`G*2<Z("1P87)E;E]L979E;"TM.R`@(&-O;G1I;G5E(#([#0H@("`@("`@
M("`@("`@("`@8V%S92!47TE.5$521D%#13H-"B`@("`@("`@("`@("`@("`@
M("`@)&EN=&5R9F%C92`]('1R=64[#0H@("`@("`@("`@("`@("`@8V%S92!4
M7T-,05-3.@T*("`@("`@("`@("`@("`@("`@("!I9B`H*"1C=7)R96YT7V-L
M87-S7VQE=F5L("$]("TQ*2!\?"`H)&-U<G)E;G1?9G5N8W1I;VY?;&5V96P@
M(3T@+3$I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-T
M86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)V9I;&4G
M(#T^("1F:6QE*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("=087)S97(@
M97)R;W(Z(&EN=F%L:60@4$A0(&9O=6YD(&EN(&9I;&4@(B5F:6QE)2(G*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&-A<V4@5%]&54Y#
M5$E/3CH-"B`@("`@("`@("`@("`@("!C87-E(%1?3D57.@T*("`@("`@("`@
M("`@("`@(&-A<V4@5%]%6%1%3D13.@T*("`@("`@("`@("`@("`@(&-A<V4@
M5%])35!,14U%3E13.@T*("`@("`@("`@("`@("`@("`@("`D;&]O:U]F;W(@
M/2`D=&]K96X[#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E(#([#0H@
M("`@("`@("`@("`@("`@8V%S92!47U-44DE.1SH-"B`@("`@("`@("`@("`@
M("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92AZ96YD7W9E<G-I;VXH*2P@)S(N
M,"<L("<\)RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI;E]A
M<G)A>2AS=')T;VQO=V5R*"1D871A*2P-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A<G)A>2@G<'5B;&EC)RP@)W!R:79A=&4G+"`G<')O=&5C=&5D
M)RP@)V%B<W1R86-T)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G:6YT97)F86-E)RP@)VEM<&QE;65N=',G+"`G=&AR;W<G*2`-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.
M0U1)3TY?7RP@)W=A<FYI;F<G+"!A<G)A>2@-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V9I;&4G(#T^("1F:6QE*2P-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)T5R<F]R+"!02%`U('1O:V5N(&5N8V]U
M;G1E<F5D(&EN("5F:6QE)2PG("X-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)R!A;F%L>7-I<R!S:&]U;&0@8F4@:6X@4$A0-2<I.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@(&EF("@D;&]O:U]F;W(@/3T@5%]#3$%3
M4RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E;G1?8VQA<W,@
M/2`D9&%T83L-"B`@("`@("`@("`@("`@("`@("`@("`@("1C=7)R96YT7V-L
M87-S7VQE=F5L(#T@)&)R86-E7VQE=F5L.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)&1E8VQA<F5D7V-L87-S97-;72`]("1C=7)R96YT7V-L87-S.PT*
M("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&QO;VM?9F]R(#T](%1?
M24Y415)&04-%*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D8W5R<F5N
M=%]I;G1E<F9A8V4@/2`D9&%T83L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1C=7)R96YT7V-L87-S7VQE=F5L(#T@)&)R86-E7VQE=F5L.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)&1E8VQA<F5D7VEN=&5R9F%C97-;72`]("1C
M=7)R96YT7VEN=&5R9F%C93L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M:68@*"1L;V]K7V9O<B`]/2!47TE-4$Q%345.5%,I('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1I;7!L96UE;G1S6R1C=7)R96YT7V-L87-S72`]("1D
M871A.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&QO;VM?9F]R
M(#T](%1?15A414Y$4RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&5X
M=&5N9'-;)&-U<G)E;G1?8VQA<W-=(#T@)&1A=&$[#0H@("`@("`@("`@("`@
M("`@("`@('T@96QS96EF("@D;&]O:U]F;W(@/3T@5%]&54Y#5$E/3BD@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1C=7)R96YT7V-L87-S*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E;G1?9G5N8W1I
M;VX@/2`B)&-U<G)E;G1?8VQA<W,Z.B1D871A(CL-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9&5C;&%R961?;65T:&]D<ULD8W5R<F5N=%]C;&%S
M<UU;72`]("1D871A.PT*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M:68@*"1C=7)R96YT7VEN=&5R9F%C92D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1C=7)R96YT7V9U;F-T:6]N(#T@(B1C=7)R96YT7VEN=&5R
M9F%C93HZ)&1A=&$B.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D
M96-L87)E9%]M971H;V1S6R1C=7)R96YT7VEN=&5R9F%C95U;72`]("1D871A
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=%]F=6YC=&EO;B`]("1D871A
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D96-L87)E9%]F=6YC
M=&EO;G-;72`]("1C=7)R96YT7V9U;F-T:6]N.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E;G1?
M9G5N8W1I;VY?;&5V96P@/2`D8G)A8V5?;&5V96P[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D;2`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@("`@
M('T@96QS96EF("@D;&]O:U]F;W(@/3T@5%].15<I('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1U<V5D7V-L87-S97-;)&1A=&%=(#T@=')U93L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D;&]O
M:U]F;W(@/2`P.PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU92`R.PT*
M("`@("`@("`@("`@("`@(&-A<V4@5%]605))04),13H-"B`@("`@("`@("`@
M("`@("`@("`@)&QO;VM?9F]R(#T@,#L-"B`@("`@("`@("`@("`@("`@("`@
M8V]N=&EN=64@,CL-"B`@("`@("`@("`@("`@("!C87-E(%1?1$]#7T-/34U%
M3E0Z#0H@("`@("`@("`@("`@("`@8V%S92!47T-/34U%3E0Z#0H@("`@("`@
M("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<A7B]<*EPJ7',A)RP@)&1A
M=&$I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D;&%S='!H<&1O8R`]
M("1D871A.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T
M8VA?86QL*"<O0&YO9&5P7',K*%Q3*RDO)RP@)&QA<W1P:'!D;V,L("1M*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N;V1E<',@/2!A<G)A
M>5]M97)G92@D;F]D97!S+"`D;5LQ72D[#0H@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@8V]N=&EN=64@,CL-"B`@("`@("`@("`@("`@("!C87-E(%1?1$]5
M0DQ%7T-/3$]..@T*("`@("`@("`@("`@("`@("`@("!I9B`H(2@D=&]K96YS
M6R1I("T@,5U;,%T@/3T@5%]72$E415-004-%('Q\("1T;VME;G-;)&D@+2`Q
M75LP72`]/2!47U-44DE.1RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G=V%R;FEN9R<L
M(&%R<F%Y*"=F:6QE)R`]/B`D9FEL92DL#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)U!A<G-E<B!E<G)O<CH@:6YV86QI9"!02%`@9F]U;F0@:6X@
M9FEL92`B)69I;&4E(B<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("1C;&%S<R`]("1T;VME;G-;)&D@+2`Q75LQ73L-"B`@("`@
M("`@("`@("`@("`@("`@:68@*'-T<G1O;&]W97(H)&-L87-S*2`A/2`G<&%R
M96YT)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'5S961?8VQA<W-E
M<ULD8VQA<W-=(#T@=')U93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("!C;VYT:6YU92`R.PT*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@(')E='5R;B!A<G)A>2@-"B`@("`@("`@("`@
M(")S;W5R8V5?9FEL92(@/3X@)&9I;&4L#0H@("`@("`@("`@("`B9&5C;&%R
M961?8VQA<W-E<R(@/3X@)&1E8VQA<F5D7V-L87-S97,L#0H@("`@("`@("`@
M("`B9&5C;&%R961?:6YT97)F86-E<R(@/3X@)&1E8VQA<F5D7VEN=&5R9F%C
M97,L#0H@("`@("`@("`@("`B9&5C;&%R961?;65T:&]D<R(@/3X@)&1E8VQA
M<F5D7VUE=&AO9',L#0H@("`@("`@("`@("`B9&5C;&%R961?9G5N8W1I;VYS
M(B`]/B`D9&5C;&%R961?9G5N8W1I;VYS+`T*("`@("`@("`@("`@(G5S961?
M8VQA<W-E<R(@/3X@87)R87E?9&EF9BAA<G)A>5]K97ES*"1U<V5D7V-L87-S
M97,I+"`D;F]D97!S*2P-"B`@("`@("`@("`@(")I;FAE<FET86YC92(@/3X@
M)&5X=&5N9',L#0H@("`@("`@("`@("`B:6UP;&5M96YT<R(@/3X@)&EM<&QE
M;65N=',L#0H@("`@("`@("`@("`I.PT*("`@('T-"@T*("`@("\J*@T*("`@
M("`J($)U:6QD(&$@(G!R;W9I9&5S(B!A<G)A>2!F<F]M(&1A=&$@<F5T=7)N
M960@8GD-"B`@("`@*B!A;F%L>7IE4V]U<F-E0V]D92@I+B`@5&AE(&9O<FUA
M="!O9B!T:&4@8G5I;'0@87)R87D@:7,@;&EK90T*("`@("`J('1H:7,Z#0H@
M("`@("H-"B`@("`@*B`@87)R87DH#0H@("`@("H@("`@)V-L87-S.TUY0VQA
M<W,G(#T^("=A<G)A>2@G='EP92<@/3X@)V-L87-S)RP@)VYA;64G(#T^("=-
M>4-L87-S)RDL#0H@("`@("H@("`@+BXN#0H@("`@("H@("D-"B`@("`@*@T*
M("`@("`J#0H@("`@("H@0'!A<F%M(&%R<F%Y("1S<F-I;F9O(&%R<F%Y('=I
M=&@@:6YF;W)M871I;VX@86)O=70@82!S;W5R8V4@9FEL90T*("`@("`J(&%S
M(')E='5R;F5D(&)Y('1H92!A;F%L>7IE4V]U<F-E0V]D92@I(&UE=&AO9"X-
M"B`@("`@*@T*("`@("`J($!R971U<FX@=F]I9`T*("`@("`J#0H@("`@("H@
M0&%C8V5S<R!P<FEV871E#0H@("`@("H-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!?8G5I;&10<F]V:61E<T%R<F%Y*"1S<F-I;F9O*0T*("`@('L-"B`@("`@
M("`@:68@*"$D=&AI<RT^7VES5F%L:60I('L-"B`@("`@("`@("`@(')E='5R
M;B!A<G)A>2@I.PT*("`@("`@("!]#0H@("`@("`@("1P<F]V:61E<W)E="`]
M(&%R<F%Y*"D[#0H@("`@("`@("1F:6QE(#T@8F%S96YA;64H)'-R8VEN9F];
M)W-O=7)C95]F:6QE)UTI.PT*("`@("`@("`D<&X@/2`D=&AI<RT^7W!F+3YG
M971086-K86=E*"D[#0H@("`@("`@("1P;FP@/2!S=')L96XH)'!N*3L-"B`@
M("`@("`@9F]R96%C:"`H)'-R8VEN9F];)V1E8VQA<F5D7V-L87-S97,G72!A
M<R`D8VQA<W,I('L-"B`@("`@("`@("`@("1K97D@/2`B8VQA<W,[)&-L87-S
M(CL-"B`@("`@("`@("`@(&EF("AI<W-E="@D<')O=FED97-R971;)&ME>5TI
M*2![#0H@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`D<')O=FED97-R971;)&ME>5T@/0T*("`@("`@("`@
M("`@("`@(&%R<F%Y*"=F:6QE)ST^("1F:6QE+"`G='EP92<@/3X@)V-L87-S
M)RP@)VYA;64G(#T^("1C;&%S<RD[#0H@("`@("`@("`@("!I9B`H:7-S970H
M)'-R8VEN9F];)VEN:&5R:71A;F-E)UU;)&-L87-S72DI('L-"B`@("`@("`@
M("`@("`@("`D<')O=FED97-R971;)&ME>5U;)V5X=&5N9',G72`]#0H@("`@
M("`@("`@("`@("`@("`@("1S<F-I;F9O6R=I;FAE<FET86YC92==6R1C;&%S
M<UT[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C
M:"`H)'-R8VEN9F];)V1E8VQA<F5D7VUE=&AO9',G72!A<R`D8VQA<W,@/3X@
M)&UE=&AO9',I('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1M971H;V1S(&%S
M("1M971H;V0I('L-"B`@("`@("`@("`@("`@("`D9G5N8W1I;VX@/2`B)&-L
M87-S.CHD;65T:&]D(CL-"B`@("`@("`@("`@("`@("`D:V5Y(#T@(F9U;F-T
M:6]N.R1F=6YC=&EO;B([#0H@("`@("`@("`@("`@("`@:68@*"1M971H;V1[
M,'T@/3T@)U\G('Q\("%S=')C87-E8VUP*"1M971H;V0L("1C;&%S<RD@?'P-
M"B`@("`@("`@("`@("`@("`@("`@:7-S970H)'!R;W9I9&5S<F5T6R1K97E=
M*2D@>PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'!R;W9I9&5S<F5T6R1K97E=
M(#T-"B`@("`@("`@("`@("`@("`@("`@87)R87DH)V9I;&4G/3X@)&9I;&4L
M("=T>7!E)R`]/B`G9G5N8W1I;VXG+"`G;F%M92<@/3X@)&9U;F-T:6]N*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*#0H@("`@("`@(&9O<F5A8V@@
M*"1S<F-I;F9O6R=D96-L87)E9%]F=6YC=&EO;G,G72!A<R`D9G5N8W1I;VXI
M('L-"B`@("`@("`@("`@("1K97D@/2`B9G5N8W1I;VX[)&9U;F-T:6]N(CL-
M"B`@("`@("`@("`@(&EF("@D9G5N8W1I;VY[,'T@/3T@)U\G('Q\(&ES<V5T
M*"1P<F]V:61E<W)E=%LD:V5Y72DI('L-"B`@("`@("`@("`@("`@("!C;VYT
M:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A<W1R<W1R
M*"1F=6YC=&EO;BP@)SHZ)RD@)B8@<W1R;F-A<V5C;7`H)&9U;F-T:6]N+"`D
M<&XL("1P;FPI*2![#0H@("`@("`@("`@("`@("`@)'=A<FYI;F=S6UT@/2`B
M:6XQ("(@+B`D9FEL92`N("(Z(&9U;F-T:6]N(%PB)&9U;F-T:6]N7"(@;F]T
M('!R969I>&5D('=I=&@@<&%C:V%G92!N86UE(%PB)'!N7"(B.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@)'!R;W9I9&5S<F5T6R1K97E=(#T-"B`@
M("`@("`@("`@("`@("!A<G)A>2@G9FEL92<]/B`D9FEL92P@)W1Y<&4G(#T^
M("=F=6YC=&EO;B<L("=N86UE)R`]/B`D9G5N8W1I;VXI.PT*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B`D<')O=FED97-R970[#0H@("`@?0T*?0T*/SX`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]086-K86=E1FEL
M92]V,BYP:'``````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#(Q,3,P
M-"`Q,#4Q-30S,S<S,B`P,C(T,3``(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`-"B\J*@T*("H@4$5!4E]086-K86=E
M1FEL95]V,BP@<&%C:V%G92YX;6P@=F5R<VEO;B`R+C`-"B`J#0H@*B!02%`@
M=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E
M(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI
M8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E
M8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U
M;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@
M*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA
M:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@
M("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'
M<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q
M.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP
M#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@=C(N<&AP+'8@,2XQ,CDN,BXQ
M(#(P,#8O,#,O,C,@,#0Z,#<Z-3$@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@
M("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I
M;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q
M#0H@*B\-"B\J*@T*("H@1F]R(&5R<F]R(&AA;F1L:6YG#0H@*B\-"G)E<75I
M<F5?;VYC92`G4$5!4B]%<G)O<E-T86-K+G!H<"<[#0HO*BH-"B`J($!C871E
M9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@
M("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG
M:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS
M92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN
M:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@
M0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT
M+C!A,0T*("HO#0IC;&%S<R!014%27U!A8VMA9V5&:6QE7W8R#0I[#0H-"B`@
M("`O*BH-"B`@("`@*B!087)S960@<&%C:V%G92!I;F9O<FUA=&EO;@T*("`@
M("`J($!V87(@87)R87D-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@
M*B\-"B`@("!V87(@)%]P86-K86=E26YF;R`](&%R<F%Y*"D[#0H-"B`@("`O
M*BH-"B`@("`@*B!P871H('1O('!A8VMA9V4@+G1G>B!O<B!F86QS92!I9B!T
M:&ES(&ES(&$@;&]C86PO97AT<F%C=&5D('!A8VMA9V4N>&UL#0H@("`@("H@
M0'9A<B!S=')I;F=\9F%L<V4-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@
M("`@*B\-"B`@("!V87(@)%]A<F-H:79E1FEL93L-"@T*("`@("\J*@T*("`@
M("`J('!A=&@@=&\@<&%C:V%G92`N>&UL(&]R(&9A;'-E(&EF('1H:7,@:7,@
M86X@86)S=')A8W0@<&%R<V5D+69R;VTM<W1R:6YG('AM;`T*("`@("`J($!V
M87(@<W1R:6YG?&9A;'-E#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@
M("HO#0H@("`@=F%R("1?<&%C:V%G949I;&4[#0H-"B`@("`O*BH-"B`@("`@
M*B!4:&ES(&ES('5S960@8GD@9FEL92!A;F%L>7-I<R!R;W5T:6YE<R!T;R!L
M;V<@<')O9W)E<W,@:6YF;W)M871I;VX-"B`@("`@*B!`=F%R(%!%05)?0V]M
M;6]N#0H@("`@("H@0&%C8V5S<R!P<F]T96-T960-"B`@("`@*B\-"B`@("!V
M87(@)%]L;V=G97([#0H-"B`@("`O*BH-"B`@("`@*B!4:&ES(&ES('-E="!T
M;R!T:&4@:&EG:&5S="!V86QI9&%T:6]N(&QE=F5L('1H870@:&%S(&)E96X@
M=F%L:61A=&5D#0H@("`@("H-"B`@("`@*B!)9B!T:&4@<&%C:V%G92YX;6P@
M:7,@:6YV86QI9"!O<B!U;FMN;W=N+"!T:&ES(&ES('-E="!T;R`P+B`@268-
M"B`@("`@*B!N;W)M86P@=F%L:61A=&EO;B!H87,@;V-C=7)R960L('1H:7,@
M:7,@<V5T('1O(%!%05)?5D%,241!5$5?3D]234%,+B`@268-"B`@("`@*B!D
M;W=N;&]A9&EN9R]I;G-T86QL871I;VX@=F%L:61A=&EO;B!H87,@;V-C=7)R
M960@:70@:7,@<V5T('1O(%!%05)?5D%,241!5$5?1$]73DQ/041)3D<-"B`@
M("`@*B!O<B!)3E-404Q,24Y'+"!A;F0@<V\@;VX@=7`@=&\@4$5!4E]604Q)
M1$%415]004-+04=)3D<N("!4:&ES(&%L;&]W<R!V86QI9&%T:6]N#0H@("`@
M("H@(F-A8VAI;F<B('1O(&]C8W5R+"!W:&EC:"!I<R!P87)T:6-U;&%R;'D@
M:6UP;W)T86YT(&9O<B!P86-K86=E('9A;&ED871I;VXL('-O#0H@("`@("H@
M=&AA="!02%`@9FEL97,@87)E(&YO="!V86QI9&%T960@='=I8V4-"B`@("`@
M*B!`=F%R(&EN=`T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*
M("`@('9A<B`D7VES5F%L:60@/2`P.PT*#0H@("`@+RHJ#0H@("`@("H@5')U
M92!I9B!T:&4@9FEL96QI<W0@:&%S(&)E96X@=F%L:61A=&5D#0H@("`@("H@
M0'!A<F%M(&)O;VP-"B`@("`@*B\-"B`@("!V87(@)%]F:6QE<U9A;&ED(#T@
M9F%L<V4[#0H-"B`@("`O*BH-"B`@("`@*B!`=F%R(%!%05)?4F5G:7-T<GD-
M"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`T*("`@("`J+PT*("`@('9A<B`D
M7W)E9VES=')Y.PT*#0H@("`@+RHJ#0H@("`@("H@0'9A<B!014%27T-O;F9I
M9PT*("`@("`J($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@("`@=F%R
M("1?8V]N9FEG.PT*#0H@("`@+RHJ#0H@("`@("H@3W!T:6]N86P@1&5P96YD
M96YC>2!G<F]U<"!R97%U97-T960@9F]R(&EN<W1A;&QA=&EO;@T*("`@("`J
M($!V87(@<W1R:6YG#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO
M#0H@("`@=F%R("1?<F5Q=65S=&5D1W)O=7`@/2!F86QS93L-"@T*("`@("\J
M*@T*("`@("`J($!V87(@4$5!4E]%<G)O<E-T86-K#0H@("`@("H@0&%C8V5S
M<R!P<F]T96-T960-"B`@("`@*B\-"B`@("!V87(@)%]S=&%C:SL-"@T*("`@
M("\J*@T*("`@("`J($YA;65S<&%C92!P<F5F:7@@=7-E9"!F;W(@=&%S:W,@
M:6X@=&AI<R!P86-K86=E+GAM;"`M('5S92!T87-K<SH@=VAE;F5V97(@<&]S
M<VEB;&4-"B`@("`@*B\-"B`@("!V87(@)%]T87-K<TYS.PT*#0H@("`@+RHJ
M#0H@("`@("H@1&5T97)M:6YE<R!W:&5T:&5R('1H:7,@<&%C:V%G969I;&4@
M=V%S(&EN:71I86QI>F5D(&]N;'D@=VET:"!P87)T:6%L('!A8VMA9V4@:6YF
M;PT*("`@("`J#0H@("`@("H@268@=&AI<R!P86-K86=E(&9I;&4@=V%S(&-O
M;G-T<G5C=&5D('9I82!P87)S:6YG(%)%4U0L(&ET('=I;&P@;VYL>2!C;VYT
M86EN#0H@("`@("H-"B`@("`@*B`M('!A8VMA9V4@;F%M90T*("`@("`J("T@
M8VAA;FYE;"!N86UE#0H@("`@("H@+2!D97!E;F1E;F-I97,@#0H@("`@("H@
M0'9A<B!B;V]L96%N#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO
M#0H@("`@=F%R("1?:6YC;VUP;&5T92`]('1R=64[#0H-"B`@("`O*BH-"B`@
M("`@*B!`=F%R(%!%05)?4&%C:V%G949I;&5?=C)?5F%L:61A=&]R#0H@("`@
M("HO#0H@("`@=F%R("1?=C)686QI9&%T;W([#0H-"B`@("`O*BH-"B`@("`@
M*B!4:&4@8V]N<W1R=6-T;W(@;65R96QY('-E=',@=7`@=&AE('!R:79A=&4@
M97)R;W(@<W1A8VL-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!014%27U!A8VMA
M9V5&:6QE7W8R*"D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VL@/2!N
M97<@4$5!4E]%<G)O<E-T86-K*"=014%27U!A8VMA9V5&:6QE7W8R)RP@9F%L
M<V4L(&YU;&PI.PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2!F86QS93L-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!4;R!M86ME('5N:70M=&5S=&EN
M9R!E87-I97(-"B`@("`@*B!`<&%R86T@4$5!4E]&<F]N=&5N9%\J#0H@("`@
M("H@0'!A<F%M(&%R<F%Y(&]P=&EO;G,-"B`@("`@*B!`<&%R86T@4$5!4E]#
M;VYF:6<-"B`@("`@*B!`<F5T=7)N(%!%05)?1&]W;FQO861E<@T*("`@("`J
M($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)F=E
M=%!%05)$;W=N;&]A9&5R*"8D:2P@)&\L("8D8RD-"B`@("![#0H@("`@("`@
M("1Z(#T@)FYE=R!014%27T1O=VYL;V%D97(H)&DL("1O+"`D8RD[#0H@("`@
M("`@(')E='5R;B`D>CL-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!4;R!M
M86ME('5N:70M=&5S=&EN9R!E87-I97(-"B`@("`@*B!`<&%R86T@4$5!4E]#
M;VYF:6<-"B`@("`@*B!`<&%R86T@87)R87D@;W!T:6]N<PT*("`@("`J($!P
M87)A;2!A<G)A>2!P86-K86=E(&YA;64@87,@<F5T=7)N960@9G)O;2![0&QI
M;FL@4$5!4E]296=I<W1R>3HZ<&%R<V5086-K86=E3F%M92@I?0T*("`@("`J
M($!P87)A;2!I;G0@4$5!4E]604Q)1$%415\J(&-O;G-T86YT#0H@("`@("H@
M0')E='5R;B!014%27T1E<&5N9&5N8WDR#0H@("`@("H@0&%C8V5S<R!P<F]T
M96-T960-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F9V5T4$5!4D1E<&5N9&5N
M8WDR*"8D8RP@)&\L("1P+"`D<R`](%!%05)?5D%,241!5$5?24Y35$%,3$E.
M1RD-"B`@("![#0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27T1E
M<&5N9&5N8WDR)RDI('L-"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!
M4B]$97!E;F1E;F-Y,BYP:'`G.PT*("`@("`@("!]#0H@("`@("`@("1Z(#T@
M)FYE=R!014%27T1E<&5N9&5N8WDR*"1C+"`D;RP@)'`L("1S*3L-"B`@("`@
M("`@<F5T=7)N("1Z.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$EN<W1A
M;&QE9$)I;F%R>2@I#0H@("`@>PT*("`@("`@("!R971U<FX@:7-S970H)'1H
M:7,M/E]P86-K86=E26YF;ULG(V)I;F%R>7!A8VMA9V4G72D@/R`D=&AI<RT^
M7W!A8VMA9V5);F9O6R<C8FEN87)Y<&%C:V%G92==(#H-"B`@("`@("`@("`@
M(&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($EN<W1A;&QA=&EO
M;B!O9B!S;W5R8V4@<&%C:V%G92!H87,@9F%I;&5D+"!A='1E;7!T('1O(&1O
M=VYL;V%D(&%N9"!I;G-T86QL('1H90T*("`@("`J(&)I;F%R>2!V97)S:6]N
M(&]F('1H:7,@<&%C:V%G92X-"B`@("`@*B!`<&%R86T@4$5!4E]);G-T86QL
M97(-"B`@("`@*B!`<F5T=7)N(&%R<F%Y?&9A;'-E#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@:6YS=&%L;$)I;F%R>2@F)&EN<W1A;&QE<BD-"B`@("![#0H@
M("`@("`@(&EF("@A3U-?5TE.1$]74RD@>PT*("`@("`@("`@("`@)&$@/2!F
M86QS93L-"B`@("`@("`@("`@(')E='5R;B`D83L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H)'1H:7,M/F=E=%!A8VMA9V54>7!E*"D@/3T@)V5X='-R8R<I
M('L-"B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)&EN<W1A;&QE<BT^9V5T
M26YS=&%L;%!A8VMA9V5S*"DI*2![#0H@("`@("`@("`@("`@("`@)&$@/2!F
M86QS93L-"B`@("`@("`@("`@("`@("!R971U<FX@)&$[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!F;W)E86-H("@D:6YS=&%L;&5R+3YG971);G-T
M86QL4&%C:V%G97,H*2!A<R`D<"D@>PT*("`@("`@("`@("`@("`@(&EF("@D
M<"T^:7-%>'1E;G-I;VXH)'1H:7,M/E]P86-K86=E26YF;ULG<')O=FED97-E
M>'1E;G-I;VXG72DI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1P+3YG
M971086-K86=E5'EP92@I("$]("=E>'1S<F,G*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D82`](&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1A.R`O+R!T:&4@=7-E<B!P<F]B86)L>2!D;W=N;&]A9&5D
M(&ET('-E<&%R871E;'D-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=E>'1S<F-R96QE87-E)UU;)V)I
M;F%R>7!A8VMA9V4G72DI('L-"B`@("`@("`@("`@("`@("`D:6YS=&%L;&5R
M+3YL;V<H,"P@)T%T=&5M<'1I;F<@=&\@9&]W;FQO860@8FEN87)Y('9E<G-I
M;VX@;V8@97AT96YS:6]N("(G("X-"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P86-K86=E26YF;ULG<')O=FED97-E>'1E;G-I;VXG72`N("<B)RD[
M#0H@("`@("`@("`@("`@("`@)'!A<F%M<R`]("1T:&ES+3Y?<&%C:V%G94EN
M9F];)V5X='-R8W)E;&5A<V4G75LG8FEN87)Y<&%C:V%G92==.PT*("`@("`@
M("`@("`@("`@(&EF("@A:7-?87)R87DH)'!A<F%M<RD@?'P@(6ES<V5T*"1P
M87)A;7-;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("1P87)A;7,@/2!A
M<G)A>2@D<&%R86US*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-H86YN96PG
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A
M<R`D:2`]/B`D<&%R86TI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1P
M87)A;7-;)&E=(#T@87)R87DH)V-H86YN96PG(#T^("1T:&ES+3Y?<&%C:V%G
M94EN9F];)V-H86YN96PG72P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G<&%C:V%G92<@/3X@)'!A<F%M+"`G=F5R<VEO;B<@/3X@)'1H:7,M/F=E
M=%9E<G-I;VXH*2D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&1L(#T@)B1T:&ES+3YG9710
M14%21&]W;FQO861E<B@D:6YS=&%L;&5R+3YU:2P@)&EN<W1A;&QE<BT^9V5T
M3W!T:6]N<R@I+`T*("`@("`@("`@("`@("`@("`@("`D:6YS=&%L;&5R+3YC
M;VYF:6<I.PT*("`@("`@("`@("`@("`@("1V97)B;W-E(#T@)&1L+3YC;VYF
M:6<M/F=E="@G=F5R8F]S92<I.PT*("`@("`@("`@("`@("`@("1D;"T^8V]N
M9FEG+3YS970H)W9E<F)O<V4G+"`M,2D[#0H@("`@("`@("`@("`@("`@9F]R
M96%C:"`H)'!A<F%M<R!A<R`D<&%R86TI('L-"B`@("`@("`@("`@("`@("`@
M("`@4$5!4CHZ<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI
M.PT*("`@("`@("`@("`@("`@("`@("`D<F5T(#T@)&1L+3YD;W=N;&]A9"AA
M<G)A>2@D<&%R86TI*3L-"B`@("`@("`@("`@("`@("`@("`@4$5!4CHZ<&]P
M17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@("`@("`@("!I9B`H:7-?
M87)R87DH)')E="D@)B8@8V]U;G0H)')E="DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1D;"T^8V]N9FEG+3YS
M970H)W9E<F)O<V4G+"`D=F5R8F]S92D[#0H@("`@("`@("`@("`@("`@:68@
M*&ES7V%R<F%Y*"1R970I*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("AC
M;W5N="@D<F5T*2`]/2`Q*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M<&8@/2`D<F5T6S!=+3YG971086-K86=E1FEL92@I.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@4$5!4CHZ<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/
M4E]215154DXI.PT*("`@("`@("`@("`@("`@("`@("`@("`@)&5R<B`]("1I
M;G-T86QL97(M/FEN<W1A;&PH)')E=%LP72D[#0H@("`@("`@("`@("`@("`@
M("`@("`@("!014%2.CIP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)&5R<BDI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R<C8FEN
M87)Y<&%C:V%G92==(#T@)')E=%LP72T^9V5T4&%C:V%G92@I.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("\O(")I;G-T86QL(B!S96QF+"!S;R!A
M;&P@9&5P96YD96YC:65S('=I;&P@=V]R:R!T<F%N<W!A<F5N=&QY#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1R>2T^861D
M4&%C:V%G93(H)'1H:7,I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1I;G-T86QL97(M/FQO9R@P+"`G1&]W;FQO860@86YD(&EN<W1A;&P@;V8@
M8FEN87)Y(&5X=&5N<VEO;B`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA9V5.86UE
M5&]3=')I;F<H#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@G8VAA;FYE;"<@/3X@)'!F+3YG971#:&%N;F5L*"DL#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<&%C:V%G
M92<@/3X@)'!F+3YG971086-K86=E*"DI+"!T<G5E*2`N("<B('-U8V-E<W-F
M=6PG*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D82`](&%R<F%Y
M*"1R971;,%TL("1E<G(I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D83L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1I;G-T86QL97(M/FQO9R@P+"`G1&]W;FQO
M860@86YD(&EN<W1A;&P@;V8@8FEN87)Y(&5X=&5N<VEO;B`B)R`N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1R>2T^<&%R
M<V5D4&%C:V%G94YA;654;U-T<FEN9R@-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"=C:&%N;F5L)R`]/B`D<&8M/F=E=$-H
M86YN96PH*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=P86-K86=E)R`]/B`D<&8M/F=E=%!A8VMA9V4H*2DL('1R=64I
M("X@)R(@9F%I;&5D)RD[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@)&$@/2!F86QS93L-"B`@("`@("`@<F5T=7)N("1A.PT*("`@('T-"@T*
M("`@("\J*@T*("`@("`J($!R971U<FX@<W1R:6YG?&9A;'-E($5X=&5N<VEO
M;B!N86UE#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T4')O=FED97-%>'1E
M;G-I;VXH*0T*("`@('L-"B`@("`@("`@:68@*&EN7V%R<F%Y*"1T:&ES+3YG
M971086-K86=E5'EP92@I+"!A<G)A>2@G97AT<W)C)RP@)V5X=&)I;B<I*2D@
M>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];
M)W!R;W9I9&5S97AT96YS:6]N)UTI*2![#0H@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];)W!R;W9I9&5S97AT96YS:6]N)UT[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S=')I;F<@
M17AT96YS:6]N(&YA;64-"B`@("`@*B!`<F5T=7)N(&)O;VP-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!I<T5X=&5N<VEO;B@D97AT96YS:6]N*0T*("`@('L-
M"B`@("`@("`@:68@*&EN7V%R<F%Y*"1T:&ES+3YG971086-K86=E5'EP92@I
M+"!A<G)A>2@G97AT<W)C)RP@)V5X=&)I;B<I*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];)W!R;W9I9&5S97AT96YS:6]N
M)UT@/3T@)&5X=&5N<VEO;CL-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@5&5S=',@=VAE=&AE
M<B!E=F5R>2!P87)T(&]F('1H92!P86-K86=E+GAM;"`Q+C`@:7,@<F5P<F5S
M96YT960@:6X-"B`@("`@*B!T:&ES('!A8VMA9V4N>&UL(#(N,`T*("`@("`J
M($!P87)A;2!014%27U!A8VMA9V5&:6QE7W8Q#0H@("`@("H@0')E='5R;B!B
M;V]L#0H@("`@("HO#0H@("`@9G5N8W1I;VX@:7-%<75I=F%L96YT*"1P9C$I
M#0H@("`@>PT*("`@("`@("!I9B`H(21P9C$I('L-"B`@("`@("`@("`@(')E
M='5R;B!T<G5E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D=&AI<RT^9V5T
M4&%C:V%G951Y<&4H*2`]/2`G8G5N9&QE)RD@>PT*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM
M/F=E=$5R<F]R<RAT<G5E*3L-"B`@("`@("`@:68@*"$D<&8Q+3YV86QI9&%T
M92A014%27U9!3$E$051%7TY/4DU!3"DI('L-"B`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D<&%S<R`]('1R=64[#0H@
M("`@("`@(&EF("@D<&8Q+3YG971086-K86=E*"D@(3T@)'1H:7,M/F=E=%!A
M8VMA9V4H*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]D:69F97)E;G1086-K
M86=E*"1P9C$M/F=E=%!A8VMA9V4H*2D[#0H@("`@("`@("`@("`D<&%S<R`]
M(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D<&8Q+3YG971697)S
M:6]N*"D@(3T@)'1H:7,M/F=E=%9E<G-I;VXH*2D@>PT*("`@("`@("`@("`@
M)'1H:7,M/E]D:69F97)E;G1697)S:6]N*"1P9C$M/F=E=%9E<G-I;VXH*2D[
M#0H@("`@("`@("`@("`D<&%S<R`](&9A;'-E.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("AT<FEM*"1P9C$M/F=E=%-U;6UA<GDH*2D@(3T@)'1H:7,M/F=E
M=%-U;6UA<GDH*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]D:69F97)E;G13
M=6UM87)Y*"1P9C$M/F=E=%-U;6UA<GDH*2D[#0H@("`@("`@("`@("`D<&%S
M<R`](&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("AP<F5G7W)E<&QA
M8V4H)R]<<RLO)RP@)R<L("1P9C$M/F=E=$1E<V-R:7!T:6]N*"DI("$]#0H@
M("`@("`@("`@("`@('!R96=?<F5P;&%C92@G+UQS*R\G+"`G)RP@)'1H:7,M
M/F=E=$1E<V-R:7!T:6]N*"DI*2![#0H@("`@("`@("`@("`D=&AI<RT^7V1I
M9F9E<F5N=$1E<V-R:7!T:6]N*"1P9C$M/F=E=$1E<V-R:7!T:6]N*"DI.PT*
M("`@("`@("`@("`@)'!A<W,@/2!F86QS93L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H)'!F,2T^9V5T4W1A=&4H*2`A/2`D=&AI<RT^9V5T4W1A=&4H*2D@
M>PT*("`@("`@("`@("`@)'1H:7,M/E]D:69F97)E;G13=&%T92@D<&8Q+3YG
M9713=&%T92@I*3L-"B`@("`@("`@("`@("1P87-S(#T@9F%L<V4[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"%S=')S='(H<')E9U]R97!L86-E*"<O7',K
M+R<L("<G+"`D=&AI<RT^9V5T3F]T97,H*2DL#0H@("`@("`@("`@("`@('!R
M96=?<F5P;&%C92@G+UQS*R\G+"`G)RP@)'!F,2T^9V5T3F]T97,H*2DI*2![
M#0H@("`@("`@("`@("`D=&AI<RT^7V1I9F9E<F5N=$YO=&5S*"1P9C$M/F=E
M=$YO=&5S*"DI.PT*("`@("`@("`@("`@)'!A<W,@/2!F86QS93L-"B`@("`@
M("`@?0T*("`@("`@("`D;7EM86EN=&%I;F5R<R`]("1T:&ES+3YG971-86EN
M=&%I;F5R<R@I.PT*("`@("`@("`D>6]U<FUA:6YT86EN97)S(#T@)'!F,2T^
M9V5T36%I;G1A:6YE<G,H*3L-"B`@("`@("`@9F]R("@D:3$@/2`P.R`D:3$@
M/"!C;W5N="@D>6]U<FUA:6YT86EN97)S*3L@)&DQ*RLI('L-"B`@("`@("`@
M("`@("1R97-E="`](&9A;'-E.PT*("`@("`@("`@("`@9F]R("@D:3(@/2`P
M.R`D:3(@/"!C;W5N="@D;7EM86EN=&%I;F5R<RD[("1I,BLK*2![#0H@("`@
M("`@("`@("`@("`@:68@*"1M>6UA:6YT86EN97)S6R1I,EU;)VAA;F1L92==
M(#T]("1Y;W5R;6%I;G1A:6YE<G-;)&DQ75LG:&%N9&QE)UTI('L-"B`@("`@
M("`@("`@("`@("`@("`@:68@*"1M>6UA:6YT86EN97)S6R1I,EU;)W)O;&4G
M72`A/2`D>6]U<FUA:6YT86EN97)S6R1I,5U;)W)O;&4G72D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D:69F97)E;G12;VQE*"1M>6UA
M:6YT86EN97)S6R1I,EU;)VAA;F1L92==+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1Y;W5R;6%I;G1A:6YE<G-;)&DQ75LG<F]L92==+"`D;7EM
M86EN=&%I;F5R<ULD:3)=6R=R;VQE)UTI.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)'!A<W,@/2!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("!I9B`H)&UY;6%I;G1A:6YE<G-;)&DR75LG
M96UA:6PG72`A/2`D>6]U<FUA:6YT86EN97)S6R1I,5U;)V5M86EL)UTI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&EF9F5R96YT16UA
M:6PH)&UY;6%I;G1A:6YE<G-;)&DR75LG:&%N9&QE)UTL#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'EO=7)M86EN=&%I;F5R<ULD:3%=6R=E;6%I
M;"==+"`D;7EM86EN=&%I;F5R<ULD:3)=6R=E;6%I;"==*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1P87-S(#T@9F%L<V4[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"1M>6UA:6YT86EN
M97)S6R1I,EU;)VYA;64G72`A/2`D>6]U<FUA:6YT86EN97)S6R1I,5U;)VYA
M;64G72D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D:69F
M97)E;G1.86UE*"1M>6UA:6YT86EN97)S6R1I,EU;)VAA;F1L92==+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1Y;W5R;6%I;G1A:6YE<G-;)&DQ
M75LG;F%M92==+"`D;7EM86EN=&%I;F5R<ULD:3)=6R=N86UE)UTI.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)'!A<W,@/2!F86QS93L-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!U;G-E="@D;7EM
M86EN=&%I;F5R<ULD:3)=*3L-"B`@("`@("`@("`@("`@("`@("`@)&UY;6%I
M;G1A:6YE<G,@/2!A<G)A>5]V86QU97,H)&UY;6%I;G1A:6YE<G,I.PT*("`@
M("`@("`@("`@("`@("`@("!U;G-E="@D>6]U<FUA:6YT86EN97)S6R1I,5TI
M.PT*("`@("`@("`@("`@("`@("`@("`D>6]U<FUA:6YT86EN97)S(#T@87)R
M87E?=F%L=65S*"1Y;W5R;6%I;G1A:6YE<G,I.PT*("`@("`@("`@("`@("`@
M("`@("`D<F5S970@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!I9B`H)')E<V5T*2![#0H@("`@("`@("`@("`@("`@)&DQ(#T@+3$[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]U
M;FUA=&-H961-86EN=&%I;F5R<R@D;7EM86EN=&%I;F5R<RP@)'EO=7)M86EN
M=&%I;F5R<RD[#0H@("`@("`@("1F:6QE;&ES="`]("1T:&ES+3YG971&:6QE
M;&ES="@I.PT*("`@("`@("!F;W)E86-H("@D<&8Q+3YG971&:6QE;&ES="@I
M(&%S("1F:6QE(#T^("1A='1S*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1F:6QE;&ES=%LD9FEL95TI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M
M/E]M:7-S:6YG1FEL92@D9FEL92D[#0H@("`@("`@("`@("`@("`@)'!A<W,@
M/2!F86QS93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@)'!A<W,[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7V1I9F9E<F5N
M=%!A8VMA9V4H)'!A8VMA9V4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T
M86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)W!A8VMA
M9V4G(#T^("1P86-K86=E+`T*("`@("`@("`@("`@)W-E;&8G(#T^("1T:&ES
M+3YG971086-K86=E*"DI+`T*("`@("`@("`@("`@)W!A8VMA9V4N>&UL(#$N
M,"!P86-K86=E("(E<&%C:V%G924B(&1O97,@;F]T(&UA=&-H("(E<V5L9B4B
M)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7V1I9F9E<F5N=%9E<G-I;VXH
M)'9E<G-I;VXI#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H
M*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)W9E<G-I;VXG(#T^("1V
M97)S:6]N+`T*("`@("`@("`@("`@)W-E;&8G(#T^("1T:&ES+3YG971697)S
M:6]N*"DI+`T*("`@("`@("`@("`@)W!A8VMA9V4N>&UL(#$N,"!V97)S:6]N
M("(E=F5R<VEO;B4B(&1O97,@;F]T(&UA=&-H("(E<V5L9B4B)RD[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@7V1I9F9E<F5N=%-T871E*"1S=&%T92D-"B`@
M("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?
M+"`G97)R;W(G+"!A<G)A>2@G<W1A=&4G(#T^("1S=&%T92P-"B`@("`@("`@
M("`@("=S96QF)R`]/B`D=&AI<RT^9V5T4W1A=&4H*2DL#0H@("`@("`@("`@
M("`G<&%C:V%G92YX;6P@,2XP('-T871E("(E<W1A=&4E(B!D;V5S(&YO="!M
M871C:"`B)7-E;&8E(B<I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]D:69F
M97)E;G12;VQE*"1H86YD;&4L("1R;VQE+"`D<V5L9G)O;&4I#0H@("`@>PT*
M("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R
M<F]R)RP@87)R87DH)VAA;F1L92<@/3X@)&AA;F1L92P-"B`@("`@("`@("`@
M("=R;VQE)R`]/B`D<F]L92P@)W-E;&8G(#T^("1S96QF<F]L92DL#0H@("`@
M("`@("`@("`G<&%C:V%G92YX;6P@,2XP(&UA:6YT86EN97(@(B5H86YD;&4E
M(B!R;VQE("(E<F]L924B(&1O97,@;F]T(&UA=&-H("(E<V5L9B4B)RD[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@7V1I9F9E<F5N=$5M86EL*"1H86YD;&4L
M("1E;6%I;"P@)'-E;&9E;6%I;"D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?
M<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@G:&%N
M9&QE)R`]/B`D:&%N9&QE+`T*("`@("`@("`@("`@)V5M86EL)R`]/B`D96UA
M:6PL("=S96QF)R`]/B`D<V5L9F5M86EL*2P-"B`@("`@("`@("`@("=P86-K
M86=E+GAM;"`Q+C`@;6%I;G1A:6YE<B`B)6AA;F1L924B(&5M86EL("(E96UA
M:6PE(B!D;V5S(&YO="!M871C:"`B)7-E;&8E(B<I.PT*("`@('T-"@T*("`@
M(&9U;F-T:6]N(%]D:69F97)E;G1.86UE*"1H86YD;&4L("1N86UE+"`D<V5L
M9FYA;64I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?
M1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)VAA;F1L92<@/3X@)&AA;F1L
M92P-"B`@("`@("`@("`@("=N86UE)R`]/B`D;F%M92P@)W-E;&8G(#T^("1S
M96QF;F%M92DL#0H@("`@("`@("`@("`G<&%C:V%G92YX;6P@,2XP(&UA:6YT
M86EN97(@(B5H86YD;&4E(B!N86UE("(E;F%M924B(&1O97,@;F]T(&UA=&-H
M("(E<V5L9B4B)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7W5N;6%T8VAE
M9$UA:6YT86EN97)S*"1M>2P@)'EO=7)S*0T*("`@('L-"B`@("`@("`@:68@
M*"1M>2D@>PT*("`@("`@("`@("`@87)R87E?=V%L:R@D;7DL(&-R96%T95]F
M=6YC=&EO;B@G)B1I+"`D:R<L("<D:2`]("1I6R)H86YD;&4B73LG*2D[#0H@
M("`@("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@
M)V5R<F]R)RP@87)R87DH)VAA;F1L97,G(#T^("1M>2DL#0H@("`@("`@("`@
M("`@("`@)W!A8VMA9V4N>&UL(#(N,"!H87,@=6YM871C:&5D(&5X=')A(&UA
M:6YT86EN97)S("(E:&%N9&QE<R4B)RD[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*"1Y;W5R<RD@>PT*("`@("`@("`@("`@87)R87E?=V%L:R@D>6]U<G,L
M(&-R96%T95]F=6YC=&EO;B@G)B1I+"`D:R<L("<D:2`]("1I6R)H86YD;&4B
M73LG*2D[#0H@("`@("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.
M0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)VAA;F1L97,G(#T^("1Y;W5R<RDL
M#0H@("`@("`@("`@("`@("`@)W!A8VMA9V4N>&UL(#$N,"!H87,@=6YM871C
M:&5D(&5X=')A(&UA:6YT86EN97)S("(E:&%N9&QE<R4B)RD[#0H@("`@("`@
M('T-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?9&EF9F5R96YT3F]T97,H)&YO
M=&5S*0T*("`@('L-"B`@("`@("`@)'1R=6YC;F]T97,@/2!S=')L96XH)&YO
M=&5S*2`\(#(U(#\@)&YO=&5S(#H@<W5B<W1R*"1N;W1E<RP@,"P@,C0I("X@
M)RXN+B<[#0H@("`@("`@("1T<G5N8VUY;F]T97,@/2!S=')L96XH)'1H:7,M
M/F=E=$YO=&5S*"DI(#P@,C4@/R`D=&AI<RT^9V5T3F]T97,H*2`Z#0H@("`@
M("`@("`@("!S=6)S='(H)'1H:7,M/F=E=$YO=&5S*"DL(#`L(#(T*2`N("<N
M+BXG.PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?
M7RP@)V5R<F]R)RP@87)R87DH)VYO=&5S)R`]/B`D=')U;F-N;W1E<RP-"B`@
M("`@("`@("`@("=S96QF)R`]/B`D=')U;F-M>6YO=&5S*2P-"B`@("`@("`@
M("`@("=P86-K86=E+GAM;"`Q+C`@<F5L96%S92!N;W1E<R`B)6YO=&5S)2(@
M9&\@;F]T(&UA=&-H("(E<V5L9B4B)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@7V1I9F9E<F5N=%-U;6UA<GDH)'-U;6UA<GDI#0H@("`@>PT*("`@("`@
M("`D=')U;F-S=6UM87)Y(#T@<W1R;&5N*"1S=6UM87)Y*2`\(#(U(#\@)'-U
M;6UA<GD@.B!S=6)S='(H)'-U;6UA<GDL(#`L(#(T*2`N("<N+BXG.PT*("`@
M("`@("`D=')U;F-M>7-U;6UA<GD@/2!S=')L96XH)'1H:7,M/F=E='-U;6UA
M<GDH*2D@/"`R-2`_("1T:&ES+3YG9713=6UM87)Y*"D@.@T*("`@("`@("`@
M("`@<W5B<W1R*"1T:&ES+3YG971S=6UM87)Y*"DL(#`L(#(T*2`N("<N+BXG
M.PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@
M)V5R<F]R)RP@87)R87DH)W-U;6UA<GDG(#T^("1T<G5N8W-U;6UA<GDL#0H@
M("`@("`@("`@("`G<V5L9B<@/3X@)'1R=6YC;7ES=6UM87)Y*2P-"B`@("`@
M("`@("`@("=P86-K86=E+GAM;"`Q+C`@<W5M;6%R>2`B)7-U;6UA<GDE(B!D
M;V5S(&YO="!M871C:"`B)7-E;&8E(B<I.PT*("`@('T-"@T*("`@(&9U;F-T
M:6]N(%]D:69F97)E;G1$97-C<FEP=&EO;B@D9&5S8W)I<'1I;VXI#0H@("`@
M>PT*("`@("`@("`D=')U;F-D97-C<FEP=&EO;B`]('1R:6TH<W1R;&5N*"1D
M97-C<FEP=&EO;BD@/"`R-2`_("1D97-C<FEP=&EO;B`Z('-U8G-T<B@D9&5S
M8W)I<'1I;VXL(#`L(#(T*2`N("<N+BXG*3L-"B`@("`@("`@)'1R=6YC;7ED
M97-C<FEP=&EO;B`]('1R:6TH<W1R;&5N*"1T:&ES+3YG971$97-C<FEP=&EO
M;B@I*2`\(#(U(#\@)'1H:7,M/F=E=$1E<V-R:7!T:6]N*"D@.@T*("`@("`@
M("`@("`@<W5B<W1R*"1T:&ES+3YG971D97-C<FEP=&EO;B@I+"`P+"`R-"D@
M+B`G+BXN)RD[#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#
M5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@G9&5S8W)I<'1I;VXG(#T^("1T<G5N
M8V1E<V-R:7!T:6]N+`T*("`@("`@("`@("`@)W-E;&8G(#T^("1T<G5N8VUY
M9&5S8W)I<'1I;VXI+`T*("`@("`@("`@("`@)W!A8VMA9V4N>&UL(#$N,"!D
M97-C<FEP=&EO;B`B)61E<V-R:7!T:6]N)2(@9&]E<R!N;W0@;6%T8V@@(B5S
M96QF)2(G*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?;6ES<VEN9T9I;&4H
M)&9I;&4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?
M1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)V9I;&4G(#T^("1F:6QE*2P-
M"B`@("`@("`@("`@("=P86-K86=E+GAM;"`Q+C`@9FEL92`B)69I;&4E(B!I
M<R!N;W0@<')E<V5N="!I;B`\8V]N=&5N=',^)RD[#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@5T%23DE.1R`M(&1O(&YO="!U<V4@=&AI<R!F=6YC=&EO
M;B!U;FQE<W,@>6]U(&MN;W<@=VAA="!Y;W4G<F4@9&]I;F<-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!S971287=3=&%T92@D<W1A=&4I#0H@("`@>PT*("`@
M("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=S=&%B:6QI='DG75LG<F5L96%S
M92==(#T@)'-T871E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%=!4DY)
M3D<@+2!D;R!N;W0@=7-E('1H:7,@9G5N8W1I;VX@=6YL97-S('EO=2!K;F]W
M('=H870@>6]U)W)E(&1O:6YG#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T
M4F%W0V]M<&%T:6)L92@D8V]M<&%T:6)L92D-"B`@("![#0H@("`@("`@("1T
M:&ES+3Y?<&%C:V%G94EN9F];)V-O;7!A=&EB;&4G72`]("1C;VUP871I8FQE
M.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%=!4DY)3D<@+2!D;R!N;W0@
M=7-E('1H:7,@9G5N8W1I;VX@=6YL97-S('EO=2!K;F]W('=H870@>6]U)W)E
M(&1O:6YG#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T4F%W4&%C:V%G92@D
M<&%C:V%G92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];
M)VYA;64G72`]("1P86-K86=E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J
M(%=!4DY)3D<@+2!D;R!N;W0@=7-E('1H:7,@9G5N8W1I;VX@=6YL97-S('EO
M=2!K;F]W('=H870@>6]U)W)E(&1O:6YG#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@<V5T4F%W0VAA;FYE;"@D8VAA;FYE;"D-"B`@("![#0H@("`@("`@("1T
M:&ES+3Y?<&%C:V%G94EN9F];)V-H86YN96PG72`]("1C:&%N;F5L.PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N('-E=%)E<75E<W1E9$=R;W5P*"1G<F]U<"D-
M"B`@("![#0H@("`@("`@("1T:&ES+3Y?<F5Q=65S=&5D1W)O=7`@/2`D9W)O
M=7`[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T4F5Q=65S=&5D1W)O=7`H
M*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<F5Q=65S=&5D
M1W)O=7`I*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R97%U97-T
M961'<F]U<#L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@?0T*#0H@("`@+RHJ#0H@("`@("H@1F]R('-A=FEN9R!I;B!T:&4@<F5G
M:7-T<GDN#0H@("`@("H-"B`@("`@*B!3970@=&AE(&QA<W0@=F5R<VEO;B!T
M:&%T('=A<R!I;G-T86QL960-"B`@("`@*B!`<&%R86T@<W1R:6YG#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@<V5T3&%S=$EN<W1A;&QE9%9E<G-I;VXH)'9E
M<G-I;VXI#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=?
M;&%S='9E<G-I;VXG72`]("1V97)S:6]N.PT*("`@('T-"@T*("`@("\J*@T*
M("`@("`J($!R971U<FX@<W1R:6YG?&9A;'-E#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@9V5T3&%S=$EN<W1A;&QE9%9E<G-I;VXH*0T*("`@('L-"B`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)U]L87-T=F5R<VEO
M;B==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN
M9F];)U]L87-T=F5R<VEO;B==.PT*("`@("`@("!]#0H@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!$971E<FUI;F5S
M('=H971H97(@=&AI<R!P86-K86=E+GAM;"!H87,@<&]S="UI;G-T86QL('-C
M<FEP=',@;W(@;F]T#0H@("`@("H@0')E='5R;B!A<G)A>7QF86QS90T*("`@
M("`J+PT*("`@(&9U;F-T:6]N(&QI<W10;W-T:6YS=&%L;%-C<FEP=',H*0T*
M("`@('L-"B`@("`@("`@)&9I;&5L:7-T(#T@)'1H:7,M/F=E=$9I;&5L:7-T
M*"D[#0H@("`@("`@("1C;VYT96YT<R`]("1T:&ES+3YG971#;VYT96YT<R@I
M.PT*("`@("`@("`D8V]N=&5N=',@/2`D8V]N=&5N='-;)V1I<B==6R=F:6QE
M)UT[#0H@("`@("`@(&EF("@A:7-?87)R87DH)&-O;G1E;G1S*2!\?"`A:7-S
M970H)&-O;G1E;G1S6S!=*2D@>PT*("`@("`@("`@("`@)&-O;G1E;G1S(#T@
M87)R87DH)&-O;G1E;G1S*3L-"B`@("`@("`@?0T*("`@("`@("`D=&%S:V9I
M;&5S(#T@87)R87DH*3L-"B`@("`@("`@9F]R96%C:"`H)&-O;G1E;G1S(&%S
M("1F:6QE*2![#0H@("`@("`@("`@("`D871T<R`]("1F:6QE6R=A='1R:6)S
M)UT[#0H@("`@("`@("`@("!U;G-E="@D9FEL95LG871T<FEB<R==*3L-"B`@
M("`@("`@("`@(&EF("AC;W5N="@D9FEL92DI('L-"B`@("`@("`@("`@("`@
M("`D=&%S:V9I;&5S6R1A='1S6R=N86UE)UU=(#T@)&9I;&4[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)&-O;6UO;B`](&YE=R!014%2
M7T-O;6UO;CL-"B`@("`@("`@)&-O;6UO;BT^9&5B=6<@/2`D=&AI<RT^7V-O
M;F9I9RT^9V5T*"=V97)B;W-E)RD[#0H@("`@("`@("1T:&ES+3Y?<V-R:7!T
M<R`](&%R<F%Y*"D[#0H@("`@("`@("1R970@/2!A<G)A>2@I.PT*("`@("`@
M("!F;W)E86-H("@D=&%S:V9I;&5S(&%S("1N86UE(#T^("1T87-K<RD@>PT*
M("`@("`@("`@("`@:68@*"%I<W-E="@D9FEL96QI<W1;)&YA;65=*2D@>PT*
M("`@("`@("`@("`@("`@("\O(&EG;F]R960@9FEL97,@=VEL;"!N;W0@8F4@
M:6X@=&AE(&9I;&5L:7-T#0H@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`D871T<R`]("1F:6QE;&ES=%LD
M;F%M95T[#0H@("`@("`@("`@("!F;W)E86-H("@D=&%S:W,@87,@)'1A9R`]
M/B`D<F%W*2![#0H@("`@("`@("`@("`@("`@)'1A<VL@/2`D=&AI<RT^9V5T
M5&%S:R@D=&%G*3L-"B`@("`@("`@("`@("`@("`D=&%S:R`]("9N97<@)'1A
M<VLH)'1H:7,M/E]C;VYF:6<L("1C;VUM;VXL(%!%05)?5$%32U])3E-404Q,
M*3L-"B`@("`@("`@("`@("`@("!I9B`H)'1A<VLM/FES4V-R:7!T*"DI('L-
M"B`@("`@("`@("`@("`@("`@("`@)')E=%M=(#T@)&9I;&5L:7-T6R1N86UE
M75LG:6YS=&%L;&5D7V%S)UT[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AC;W5N="@D<F5T*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N("1R970[#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($EN
M:71I86QI>F4@<&]S="UI;G-T86QL('-C<FEP=',@9F]R(')U;FYI;F<-"B`@
M("`@*@T*("`@("`J(%1H:7,@;65T:&]D(&-A;B!B92!U<V5D('1O(&1E=&5C
M="!P;W-T+6EN<W1A;&P@<V-R:7!T<RP@87,@=&AE(')E='5R;B!V86QU90T*
M("`@("`J(&EN9&EC871E<R!W:&5T:&5R(&%N>2!E>&ES=`T*("`@("`J($!R
M971U<FX@8F]O;`T*("`@("`J+PT*("`@(&9U;F-T:6]N(&EN:710;W-T:6YS
M=&%L;%-C<FEP=',H*0T*("`@('L-"B`@("`@("`@)&9I;&5L:7-T(#T@)'1H
M:7,M/F=E=$9I;&5L:7-T*"D[#0H@("`@("`@("1C;VYT96YT<R`]("1T:&ES
M+3YG971#;VYT96YT<R@I.PT*("`@("`@("`D8V]N=&5N=',@/2`D8V]N=&5N
M='-;)V1I<B==6R=F:6QE)UT[#0H@("`@("`@(&EF("@A:7-?87)R87DH)&-O
M;G1E;G1S*2!\?"`A:7-S970H)&-O;G1E;G1S6S!=*2D@>PT*("`@("`@("`@
M("`@)&-O;G1E;G1S(#T@87)R87DH)&-O;G1E;G1S*3L-"B`@("`@("`@?0T*
M("`@("`@("`D=&%S:V9I;&5S(#T@87)R87DH*3L-"B`@("`@("`@9F]R96%C
M:"`H)&-O;G1E;G1S(&%S("1F:6QE*2![#0H@("`@("`@("`@("`D871T<R`]
M("1F:6QE6R=A='1R:6)S)UT[#0H@("`@("`@("`@("!U;G-E="@D9FEL95LG
M871T<FEB<R==*3L-"B`@("`@("`@("`@(&EF("AC;W5N="@D9FEL92DI('L-
M"B`@("`@("`@("`@("`@("`D=&%S:V9I;&5S6R1A='1S6R=N86UE)UU=(#T@
M)&9I;&4[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)&-O
M;6UO;B`](&YE=R!014%27T-O;6UO;CL-"B`@("`@("`@)&-O;6UO;BT^9&5B
M=6<@/2`D=&AI<RT^7V-O;F9I9RT^9V5T*"=V97)B;W-E)RD[#0H@("`@("`@
M("1T:&ES+3Y?<V-R:7!T<R`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@
M*"1T87-K9FEL97,@87,@)&YA;64@/3X@)'1A<VMS*2![#0H@("`@("`@("`@
M("`D871T<R`]("1F:6QE;&ES=%LD;F%M95T[#0H@("`@("`@("`@("!F;W)E
M86-H("@D=&%S:W,@87,@)'1A9R`]/B`D<F%W*2![#0H@("`@("`@("`@("`@
M("`@)'1A<VMN86UE(#T@)'1H:7,M/F=E=%1A<VLH)'1A9RD[#0H@("`@("`@
M("`@("`@("`@)'1A<VL@/2`F;F5W("1T87-K;F%M92@D=&AI<RT^7V-O;F9I
M9RP@)&-O;6UO;BP@4$5!4E]405-+7TE.4U1!3$PI.PT*("`@("`@("`@("`@
M("`@(&EF("@A)'1A<VLM/FES4V-R:7!T*"DI('L-"B`@("`@("`@("`@("`@
M("`@("`@8V]N=&EN=64[("\O('-C<FEP=',@87)E(&]N;'D@:&%N9&QE9"!A
M9G1E<B!I;G-T86QL871I;VX-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@)&QA<W1V97)S:6]N(#T@:7-S970H)'1H:7,M/E]P86-K86=E
M26YF;ULG7VQA<W1V97)S:6]N)UTI(#\-"B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P86-K86=E26YF;ULG7VQA<W1V97)S:6]N)UT@.B!N=6QL.PT*
M("`@("`@("`@("`@("`@("1T87-K+3YI;FET*"1R87<L("1A='1S+"`D;&%S
M='9E<G-I;VXI.PT*("`@("`@("`@("`@("`@("1R97,@/2`D=&%S:RT^<W1A
M<G1397-S:6]N*"1T:&ES+"`D871T<ULG:6YS=&%L;&5D7V%S)UTI.PT*("`@
M("`@("`@("`@("`@(&EF("@A)')E<RD@>PT*("`@("`@("`@("`@("`@("`@
M("!C;VYT:6YU93L@+R\@<VMI<"!T:&ES(&9I;&4-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<RDI
M('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R97,[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1A<W-I9VX@/2`F)'1A<VL[
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]S8W)I<'1S6UT@/2`F)&%S<VEG
M;CL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H8V]U
M;G0H)'1H:7,M/E]S8W)I<'1S*2D@>PT*("`@("`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-
M"@T*("`@(&9U;F-T:6]N(')U;E!O<W1I;G-T86QL4V-R:7!T<R@I#0H@("`@
M>PT*("`@("`@("!I9B`H)'1H:7,M/FEN:710;W-T:6YS=&%L;%-C<FEP=',H
M*2D@>PT*("`@("`@("`@("`@)'5I(#T@)E!%05)?1G)O;G1E;F0Z.G-I;F=L
M971O;B@I.PT*("`@("`@("`@("`@:68@*"1U:2D@>PT*("`@("`@("`@("`@
M("`@("1U:2T^<G5N4&]S=&EN<W1A;&Q38W)I<'1S*"1T:&ES+3Y?<V-R:7!T
M<RP@)'1H:7,I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*
M#0H-"B`@("`O*BH-"B`@("`@*B!#;VYV97)T(&$@<F5C=7)S:79E('-E="!O
M9B`\9&ER/B!A;F0@/&9I;&4^('1A9W,@:6YT;R!A('-I;F=L92`\9&ER/B!T
M86<@=VET:`T*("`@("`J(#QF:6QE/B!T86=S+@T*("`@("`J+PT*("`@(&9U
M;F-T:6]N(&9L871T96Y&:6QE;&ES="@I#0H@("`@>PT*("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG8G5N9&QE)UTI*2![#0H@("`@
M("`@("`@("!R971U<FX[#0H@("`@("`@('T-"B`@("`@("`@)&9I;&5L:7-T
M(#T@87)R87DH*3L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G
M94EN9F];)V-O;G1E;G1S)UU;)V1I<B==6R=D:7(G72DI('L-"B`@("`@("`@
M("`@("1T:&ES+3Y?9V5T1FQA='1E;F5D1FEL96QI<W0H)&9I;&5L:7-T+"`D
M=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT96YT<R==6R=D:7(G72D[#0H@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1F:6QE;&ES=%LQ72DI('L-"B`@("`@("`@
M("`@("`@("`D9FEL96QI<W0@/2`D9FEL96QI<W1;,%T[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT96YT
M<R==6R=D:7(G75LG9FEL92==(#T@)&9I;&5L:7-T.PT*("`@("`@("`@("`@
M=6YS970H)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=&5N=',G75LG9&ER)UU;
M)V1I<B==*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("\O(&5L
M<V4@86QR96%D>2!F;&%T=&5N960@8G5T(&-H96-K(&9O<B!B87-E:6YS=&%L
M;&1I<B!P<F]P86=A=&EO;@T*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S)UU;)V1I<B==6R=A='1R:6)S)UU;
M)V)A<V5I;G-T86QL9&ER)UTI*2![#0H@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S)UU;)V1I<B==6R=F
M:6QE)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T
M:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S)UU;)V1I<B==6R=F:6QE)UT@
M87,@)&D@/3X@)&9I;&4I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D9FEL95LG871T<FEB<R==6R=B87-E:6YS=&%L;&1I<B==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=&5N=',G75LG9&ER)UU;)V9I
M;&4G75LD:5U;)V%T=')I8G,G75LG8F%S96EN<W1A;&QD:7(G70T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#T@)'1H:7,M/E]P86-K86=E26YF;ULG
M8V]N=&5N=',G75LG9&ER)UU;)V%T=')I8G,G75LG8F%S96EN<W1A;&QD:7(G
M73L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/E]P86-K86=E26YF;ULG8V]N=&5N=',G75LG9&ER)UU;)V9I;&4G75LG871T
M<FEB<R==6R=B87-E:6YS=&%L;&1I<B==*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT96YT<R==6R=D:7(G
M75LG9FEL92==6R=A='1R:6)S)UU;)V)A<V5I;G-T86QL9&ER)UT-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`]("1T:&ES+3Y?<&%C:V%G94EN9F];
M)V-O;G1E;G1S)UU;)V1I<B==6R=A='1R:6)S)UU;)V)A<V5I;G-T86QL9&ER
M)UT[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`@*B!`<&%R86T@87)R87D@=&AE(&9I;F%L(&9L871T96YE9"!F:6QE
M(&QI<W0-"B`@("`@*B!`<&%R86T@87)R87D@=&AE(&-U<G)E;G0@9&ER96-T
M;W)Y(&)E:6YG('!R;V-E<W-E9`T*("`@("`J($!P87)A;2!S=')I;F=\9F%L
M<V4@86YY(')E8W5R<VEV96QY(&EN:&5R:71E9"!B865I;G-T86QL9&ER(&%T
M=')I8G5T90T*("`@("`J($!P87)A;2!S=')I;F<@<')I=F%T92!R96-U<G-I
M;VX@=F%R:6%B;&4-"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@("`@("H@0&%C
M8V5S<R!P<F]T96-T960-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?9V5T1FQA
M='1E;F5D1FEL96QI<W0H)B1F:6QE<RP@)&1I<BP@)&)A<V5I;G-T86QL(#T@
M9F%L<V4L("1P871H(#T@)R<I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H
M)&1I<ELG871T<FEB<R==*2`F)B!I<W-E="@D9&ER6R=A='1R:6)S)UU;)V)A
M<V5I;G-T86QL9&ER)UTI*2![#0H@("`@("`@("`@("`D8F%S96EN<W1A;&P@
M/2`D9&ER6R=A='1R:6)S)UU;)V)A<V5I;G-T86QL9&ER)UT[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&ES<V5T*"1D:7);)V1I<B==*2D@>PT*("`@("`@
M("`@("`@:68@*"%I<W-E="@D9&ER6R=D:7(G75LP72DI('L-"B`@("`@("`@
M("`@("`@("`D9&ER6R=D:7(G72`](&%R<F%Y*"1D:7);)V1I<B==*3L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@*"1D:7);)V1I<B==
M(&%S("1S=6)D:7(I('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1S
M=6)D:7);)V%T=')I8G,G72D@?'P@(6ES<V5T*"1S=6)D:7);)V%T=')I8G,G
M75LG;F%M92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D;F%M92`]("<J
M=6YK;F]W;BHG.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@("`@("1N86UE(#T@)'-U8F1I<ELG871T<FEB<R==6R=N86UE
M)UT[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1N97=P
M871H(#T@96UP='DH)'!A=&@I(#\@)&YA;64@.@T*("`@("`@("`@("`@("`@
M("`@("`D<&%T:"`N("<O)R`N("1N86UE.PT*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?9V5T1FQA='1E;F5D1FEL96QI<W0H)&9I;&5S+"`D<W5B9&ER+`T*
M("`@("`@("`@("`@("`@("`@("`D8F%S96EN<W1A;&PL("1N97=P871H*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H
M)&1I<ELG9FEL92==*2D@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D9&ER
M6R=F:6QE)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@)&1I<ELG9FEL92==
M(#T@87)R87DH)&1I<ELG9FEL92==*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&9O<F5A8V@@*"1D:7);)V9I;&4G72!A<R`D9FEL92D@>PT*("`@
M("`@("`@("`@("`@("1A='1R<R`]("1F:6QE6R=A='1R:6)S)UT[#0H@("`@
M("`@("`@("`@("`@)&YA;64@/2`D871T<G-;)VYA;64G73L-"B`@("`@("`@
M("`@("`@("!I9B`H)&)A<V5I;G-T86QL("8F("%I<W-E="@D871T<G-;)V)A
M<V5I;G-T86QL9&ER)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1A='1R
M<ULG8F%S96EN<W1A;&QD:7(G72`]("1B87-E:6YS=&%L;#L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&%T=')S6R=N86UE)UT@/2!E
M;7!T>2@D<&%T:"D@/R`D;F%M92`Z("1P871H("X@)R\G("X@)&YA;64[#0H@
M("`@("`@("`@("`@("`@)&%T=')S6R=N86UE)UT@/2!P<F5G7W)E<&QA8V4H
M87)R87DH)R%<7%Q<*R$G+"`G(2\K(2<I+"!A<G)A>2@G+R<L("<O)RDL#0H@
M("`@("`@("`@("`@("`@("`@("1A='1R<ULG;F%M92==*3L-"B`@("`@("`@
M("`@("`@("`D9FEL95LG871T<FEB<R==(#T@)&%T=')S.PT*("`@("`@("`@
M("`@("`@("1F:6QE<UM=(#T@)&9I;&4[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!S971#;VYF:6<H)B1C;VYF
M:6<I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7V-O;F9I9R`]("8D8V]N9FEG
M.PT*("`@("`@("`D=&AI<RT^7W)E9VES=')Y(#T@)B1C;VYF:6<M/F=E=%)E
M9VES=')Y*"D[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T3&]G9V5R*"8D
M;&]G9V5R*0T*("`@('L-"B`@("`@("`@:68@*"%I<U]O8FIE8W0H)&QO9V=E
M<BD@?'P@(6UE=&AO9%]E>&ES=',H)&QO9V=E<BP@)VQO9R<I*2![#0H@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G3&]G9V5R(&UU<W0@
M8F4@8V]M<&%T:6)L92!W:71H(%!%05)?0V]M;6]N.CIL;V<G*3L-"B`@("`@
M("`@?0T*("`@("`@("`D=&AI<RT^7VQO9V=E<B`]("8D;&]G9V5R.PT*("`@
M('T-"@T*("`@("\J*@T*("`@("`J(%=!4DY)3D<@+2!D;R!N;W0@=7-E('1H
M:7,@9G5N8W1I;VX@9&ER96-T;'D@=6YL97-S('EO=2!K;F]W('=H870@>6]U
M)W)E(&1O:6YG#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T1&5P<R@D9&5P
M<RD-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<&5N
M9&5N8VEE<R==(#T@)&1E<',[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T
M4&%C:V%G969I;&4H)&9I;&4L("1A<F-H:79E(#T@9F%L<V4I#0H@("`@>PT*
M("`@("`@("`D=&AI<RT^7W!A8VMA9V5&:6QE(#T@)&9I;&4[#0H@("`@("`@
M("1T:&ES+3Y?87)C:&EV949I;&4@/2`D87)C:&EV92`_("1A<F-H:79E(#H@
M)&9I;&4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@5W)A<'!E<B!T;R![
M0&QI;FL@4$5!4E]%<G)O<E-T86-K.CIG971%<G)O<G,H*7T-"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B!D971E<FUI;F5S('=H971H97(@=&\@<'5R9V4@=&AE
M(&5R<F]R('-T86-K(&%F=&5R(')E=')I979I;F<-"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T5F%L:61A=&EO;E=A
M<FYI;F=S*"1P=7)G92`]('1R=64I#0H@("`@>PT*("`@("`@("!R971U<FX@
M)'1H:7,M/E]S=&%C:RT^9V5T17)R;W)S*"1P=7)G92D[#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@9V5T4&%C:V%G949I;&4H*0T*("`@('L-"B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?<&%C:V%G949I;&4[#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@9V5T07)C:&EV949I;&4H*0T*("`@('L-"B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?87)C:&EV949I;&4[#0H@("`@?0T*#0H-"B`@("`O*BH-"B`@
M("`@*B!$:7)E8W1L>2!S970@=&AE(&%R<F%Y('1H870@9&5F:6YE<R!T:&ES
M('!A8VMA9V5F:6QE#0H@("`@("H-"B`@("`@*B!705).24Y'.B!N;R!V86QI
M9&%T:6]N+B`@5&AI<R!S:&]U;&0@;VYL>2!B92!P97)F;W)M960@8GD@:6YT
M97)N86P@;65T:&]D<PT*("`@("`J(&EN<VED92!014%2(&]R(&)Y(&EN<'5T
M=&EN9R!A;B!A<G)A>2!S879E9"!F<F]M(&%N(&5X:7-T:6YG(%!%05)?4&%C
M:V%G949I;&5?=C(-"B`@("`@*B!`<&%R86T@87)R87D-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!F<F]M07)R87DH)'!I;F9O*0T*("`@('L-"B`@("`@("`@
M=6YS970H)'!I;F9O6R=O;&0G72D[#0H@("`@("`@('5N<V5T*"1P:6YF;ULG
M>'-D=F5R<VEO;B==*3L-"B`@("`@("`@)'1H:7,M/E]I;F-O;7!L971E(#T@
M9F%L<V4[#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D<&EN9F\[
M#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@:7-);F-O;7!L971E*"D-"B`@("![
M#0H@("`@("`@(')E='5R;B`D=&AI<RT^7VEN8V]M<&QE=&4[#0H@("`@?0T*
M#0H@("`@+RHJ#0H@("`@("H@0')E='5R;B!A<G)A>0T*("`@("`J+PT*("`@
M(&9U;F-T:6]N('1O07)R87DH)&9O<G)E9R`](&9A;'-E*0T*("`@('L-"B`@
M("`@("`@:68@*"$D=&AI<RT^=F%L:61A=&4H4$5!4E]604Q)1$%415].3U)-
M04PI*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YG971!<G)A>2@D9F]R<F5G*3L-"B`@
M("!]#0H-"B`@("!F=6YC=&EO;B!G971!<G)A>2@D9F]R4F5G(#T@9F%L<V4I
M#0H@("`@>PT*("`@("`@("!I9B`H)&9O<E)E9RD@>PT*("`@("`@("`@("`@
M)&%R<B`]("1T:&ES+3Y?<&%C:V%G94EN9F\[#0H@("`@("`@("`@("`D87)R
M6R=O;&0G72`](&%R<F%Y*"D[#0H@("`@("`@("`@("`D87)R6R=O;&0G75LG
M=F5R<VEO;B==(#T@)'1H:7,M/F=E=%9E<G-I;VXH*3L-"B`@("`@("`@("`@
M("1A<G);)V]L9"==6R=R96QE87-E7V1A=&4G72`]("1T:&ES+3YG971$871E
M*"D[#0H@("`@("`@("`@("`D87)R6R=O;&0G75LG<F5L96%S95]S=&%T92==
M(#T@)'1H:7,M/F=E=%-T871E*"D[#0H@("`@("`@("`@("`D87)R6R=O;&0G
M75LG<F5L96%S95]L:6-E;G-E)UT@/2`D=&AI<RT^9V5T3&EC96YS92@I.PT*
M("`@("`@("`@("`@)&%R<ELG;VQD)UU;)W)E;&5A<V5?;F]T97,G72`]("1T
M:&ES+3YG971.;W1E<R@I.PT*("`@("`@("`@("`@)&%R<ELG;VQD)UU;)W)E
M;&5A<V5?9&5P<R==(#T@)'1H:7,M/F=E=$1E<',H*3L-"B`@("`@("`@("`@
M("1A<G);)V]L9"==6R=M86EN=&%I;F5R<R==(#T@)'1H:7,M/F=E=$UA:6YT
M86EN97)S*"D[#0H@("`@("`@("`@("`D87)R6R=X<V1V97)S:6]N)UT@/2`G
M,BXP)SL-"B`@("`@("`@("`@(')E='5R;B`D87)R.PT*("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@)&EN9F\@/2`D=&AI<RT^7W!A8VMA9V5);F9O
M.PT*("`@("`@("`@("`@=6YS970H)&EN9F];)V1I<G1R964G72D[#0H@("`@
M("`@("`@("!I9B`H:7-S970H)&EN9F];)U]L87-T=F5R<VEO;B==*2D@>PT*
M("`@("`@("`@("`@("`@('5N<V5T*"1I;F9O6R=?;&%S='9E<G-I;VXG72D[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)&EN9F];
M)R-B:6YA<GEP86-K86=E)UTI*2![#0H@("`@("`@("`@("`@("`@=6YS970H
M)&EN9F];)R-B:6YA<GEP86-K86=E)UTI.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@<F5T=7)N("1I;F9O.PT*("`@("`@("!]#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@<&%C:V%G94EN9F\H)&9I96QD*0T*("`@('L-"B`@("`@
M("`@)&%R<B`]("1T:&ES+3YG971!<G)A>2AT<G5E*3L-"B`@("`@("`@:68@
M*"1F:65L9"`]/2`G<W1A=&4G*2![#0H@("`@("`@("`@("!R971U<FX@)&%R
M<ELG<W1A8FEL:71Y)UU;)W)E;&5A<V4G73L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H)&9I96QD(#T]("=A<&DM=F5R<VEO;B<I('L-"B`@("`@("`@("`@
M(')E='5R;B`D87)R6R=V97)S:6]N)UU;)V%P:2==.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@D9FEE;&0@/3T@)V%P:2US=&%T92<I('L-"B`@("`@("`@
M("`@(')E='5R;B`D87)R6R=S=&%B:6QI='DG75LG87!I)UT[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&ES<V5T*"1A<G);)V]L9"==6R1F:65L9%TI*2![
M#0H@("`@("`@("`@("!I9B`H(6ES7W-T<FEN9R@D87)R6R=O;&0G75LD9FEE
M;&1=*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B!N=6QL.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N("1A<G);)V]L9"==6R1F:65L
M9%T[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1A<G);)&9I96QD
M72DI('L-"B`@("`@("`@("`@(&EF("@A:7-?<W1R:6YG*"1A<G);)&9I96QD
M72DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@;G5L;#L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(')E='5R;B`D87)R6R1F:65L9%T[#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N(&YU;&P[#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@9V5T3F%M92@I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M
M/F=E=%!A8VMA9V4H*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971086-K
M86=E*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA
M9V5);F9O6R=N86UE)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]P86-K86=E26YF;ULG;F%M92==.PT*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971#:&%N;F5L
M*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=U<FDG72DI('L-"B`@("`@("`@("`@(')E='5R;B`G7U]U<FDG.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=C:&%N;F5L)UTI*2![#0H@("`@("`@("`@("!R971U<FX@<W1R=&]L
M;W=E<B@D=&AI<RT^7W!A8VMA9V5);F9O6R=C:&%N;F5L)UTI.PT*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!G9715<FDH*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?<&%C:V%G94EN9F];)W5R:2==*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?<&%C:V%G94EN9F];)W5R:2==.PT*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971%
M>'1E;F1S*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A
M8VMA9V5);F9O6R=E>'1E;F1S)UTI*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/E]P86-K86=E26YF;ULG97AT96YD<R==.PT*("`@("`@("!]#0H@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G
M9713=6UM87)Y*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M7W!A8VMA9V5);F9O6R=S=6UM87)Y)UTI*2![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]P86-K86=E26YF;ULG<W5M;6%R>2==.PT*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!G971$97-C<FEP=&EO;B@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]P86-K86=E26YF;ULG9&5S8W)I<'1I;VXG72DI('L-"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=D97-C<FEP=&EO
M;B==.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!G971-86EN=&%I;F5R<R@D<F%W(#T@9F%L<V4I
M#0H@("`@>PT*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN
M9F];)VQE860G72DI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H)')A=RD@>PT*("`@("`@("`@("`@)')E
M="`](&%R<F%Y*"=L96%D)R`]/B`D=&AI<RT^7W!A8VMA9V5);F9O6R=L96%D
M)UTI.PT*("`@("`@("`@("`@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];
M)V1E=F5L;W!E<B==*2D@/PT*("`@("`@("`@("`@("`@("1R971;)V1E=F5L
M;W!E<B==(#T@)'1H:7,M/E]P86-K86=E26YF;ULG9&5V96QO<&5R)UT@.FYU
M;&P[#0H@("`@("`@("`@("`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG
M8V]N=')I8G5T;W(G72DI(#\-"B`@("`@("`@("`@("`@("`D<F5T6R=C;VYT
M<FEB=71O<B==(#T@)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=')I8G5T;W(G
M72`Z;G5L;#L-"B`@("`@("`@("`@("AI<W-E="@D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=H96QP97(G72DI(#\-"B`@("`@("`@("`@("`@("`D<F5T6R=H96QP
M97(G72`]("1T:&ES+3Y?<&%C:V%G94EN9F];)VAE;'!E<B==(#IN=6QL.PT*
M("`@("`@("`@("`@<F5T=7)N("1R970[#0H@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`D<F5T(#T@87)R87DH*3L-"B`@("`@("`@("`@("1L96%D
M<R`](&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)VQE860G75LP72D@/R`D
M=&AI<RT^7W!A8VMA9V5);F9O6R=L96%D)UT@.@T*("`@("`@("`@("`@("`@
M(&%R<F%Y*"1T:&ES+3Y?<&%C:V%G94EN9F];)VQE860G72D[#0H@("`@("`@
M("`@("!F;W)E86-H("@D;&5A9',@87,@)&QE860I('L-"B`@("`@("`@("`@
M("`@("`D<R`]("1L96%D.PT*("`@("`@("`@("`@("`@("1S6R=H86YD;&4G
M72`]("1S6R=U<V5R)UT[#0H@("`@("`@("`@("`@("`@=6YS970H)'-;)W5S
M97(G72D[#0H@("`@("`@("`@("`@("`@)'-;)W)O;&4G72`]("=L96%D)SL-
M"B`@("`@("`@("`@("`@("`D<F5T6UT@/2`D<SL-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=D
M979E;&]P97(G72DI('L-"B`@("`@("`@("`@("`@("`D;&5A9',@/2!I<W-E
M="@D=&AI<RT^7W!A8VMA9V5);F9O6R=D979E;&]P97(G75LP72D@/PT*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=D979E;&]P
M97(G72`Z#0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1T:&ES+3Y?<&%C
M:V%G94EN9F];)V1E=F5L;W!E<B==*3L-"B`@("`@("`@("`@("`@("!F;W)E
M86-H("@D;&5A9',@87,@)&UA:6YT86EN97(I('L-"B`@("`@("`@("`@("`@
M("`@("`@)',@/2`D;6%I;G1A:6YE<CL-"B`@("`@("`@("`@("`@("`@("`@
M)'-;)VAA;F1L92==(#T@)'-;)W5S97(G73L-"B`@("`@("`@("`@("`@("`@
M("`@=6YS970H)'-;)W5S97(G72D[#0H@("`@("`@("`@("`@("`@("`@("1S
M6R=R;VQE)UT@/2`G9&5V96QO<&5R)SL-"B`@("`@("`@("`@("`@("`@("`@
M)')E=%M=(#T@)',[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];
M)V-O;G1R:6)U=&]R)UTI*2![#0H@("`@("`@("`@("`@("`@)&QE861S(#T@
M:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=')I8G5T;W(G75LP72D@
M/PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=C
M;VYT<FEB=71O<B==(#H-"B`@("`@("`@("`@("`@("`@("`@87)R87DH)'1H
M:7,M/E]P86-K86=E26YF;ULG8V]N=')I8G5T;W(G72D[#0H@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)&QE861S(&%S("1M86EN=&%I;F5R*2![#0H@("`@
M("`@("`@("`@("`@("`@("1S(#T@)&UA:6YT86EN97([#0H@("`@("`@("`@
M("`@("`@("`@("1S6R=H86YD;&4G72`]("1S6R=U<V5R)UT[#0H@("`@("`@
M("`@("`@("`@("`@('5N<V5T*"1S6R=U<V5R)UTI.PT*("`@("`@("`@("`@
M("`@("`@("`D<ULG<F]L92==(#T@)V-O;G1R:6)U=&]R)SL-"B`@("`@("`@
M("`@("`@("`@("`@)')E=%M=(#T@)',[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M<&%C:V%G94EN9F];)VAE;'!E<B==*2D@>PT*("`@("`@("`@("`@("`@("1L
M96%D<R`](&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)VAE;'!E<B==6S!=
M*2`_#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];
M)VAE;'!E<B==(#H-"B`@("`@("`@("`@("`@("`@("`@87)R87DH)'1H:7,M
M/E]P86-K86=E26YF;ULG:&5L<&5R)UTI.PT*("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*"1L96%D<R!A<R`D;6%I;G1A:6YE<BD@>PT*("`@("`@("`@("`@
M("`@("`@("`D<R`]("1M86EN=&%I;F5R.PT*("`@("`@("`@("`@("`@("`@
M("`D<ULG:&%N9&QE)UT@/2`D<ULG=7-E<B==.PT*("`@("`@("`@("`@("`@
M("`@("!U;G-E="@D<ULG=7-E<B==*3L-"B`@("`@("`@("`@("`@("`@("`@
M)'-;)W)O;&4G72`]("=H96QP97(G.PT*("`@("`@("`@("`@("`@("`@("`D
M<F5T6UT@/2`D<SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!R971U<FX@)')E=#L-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T3&5A
M9',H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G
M94EN9F];)VQE860G72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7W!A8VMA9V5);F9O6R=L96%D)UT[#0H@("`@("`@('T-"B`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$1E=F5L;W!E
M<G,H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G
M94EN9F];)V1E=F5L;W!E<B==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<&%C:V%G94EN9F];)V1E=F5L;W!E<B==.PT*("`@("`@("!]#0H@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G
M971#;VYT<FEB=71O<G,H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T
M:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1R:6)U=&]R)UTI*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=')I8G5T;W(G
M73L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*
M#0H@("`@9G5N8W1I;VX@9V5T2&5L<&5R<R@I#0H@("`@>PT*("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG:&5L<&5R)UTI*2![#0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULG:&5L<&5R
M)UT[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-
M"@T*("`@(&9U;F-T:6]N('-E=$1A=&4H)&1A=&4I#0H@("`@>PT*("`@("`@
M("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1A=&4G72DI('L-
M"B`@("`@("`@("`@("\O(&5N<W5R92!T:&%T('1H92!E>'1E;F1S('1A9R!I
M<R!S970@=7`@:6X@=&AE(')I9VAT(&QO8V%T:6]N#0H@("`@("`@("`@("`D
M=&AI<RT^7W!A8VMA9V5);F9O(#T@)'1H:7,M/E]I;G-E<G1"969O<F4H)'1H
M:7,M/E]P86-K86=E26YF;RP-"B`@("`@("`@("`@("`@("!A<G)A>2@G=&EM
M92<L("=V97)S:6]N)RP-"B`@("`@("`@("`@("`@("`@("`@)W-T86)I;&ET
M>2<L("=L:6-E;G-E)RP@)VYO=&5S)RP@)V-O;G1E;G1S)RP@)V-O;7!A=&EB
M;&4G+`T*("`@("`@("`@("`@("`@("`@("`G9&5P96YD96YC:65S)RP@)W!R
M;W9I9&5S97AT96YS:6]N)RP@)W-R8W!A8VMA9V4G+"`G<W)C=7)I)RP-"B`@
M("`@("`@("`@("`@("`@("`@)W!H<')E;&5A<V4G+"`G97AT<W)C<F5L96%S
M92<L#0H@("`@("`@("`@("`@("`@("`@("=E>'1B:6YR96QE87-E)RP@)V)U
M;F1L92<L("=C:&%N9V5L;V<G*2P@87)R87DH*2P@)V1A=&4G*3L-"B`@("`@
M("`@?0T*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=D871E)UT@/2`D
M9&%T93L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("!]#0H-
M"B`@("!F=6YC=&EO;B!S9714:6UE*"1T:6UE*0T*("`@('L-"B`@("`@("`@
M)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@:68@*"%I<W-E="@D=&AI
M<RT^7W!A8VMA9V5);F9O6R=T:6UE)UTI*2![#0H@("`@("`@("`@("`O+R!E
M;G-U<F4@=&AA="!T:&4@=&EM92!T86<@:7,@<V5T('5P(&EN('1H92!R:6=H
M="!L;V-A=&EO;@T*("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;R`]
M("1T:&ES+3Y?:6YS97)T0F5F;W)E*"1T:&ES+3Y?<&%C:V%G94EN9F\L#0H@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=V97)S:6]N)RP-"B`@("`@("`@
M("`@("`@("`@("`@)W-T86)I;&ET>2<L("=L:6-E;G-E)RP@)VYO=&5S)RP@
M)V-O;G1E;G1S)RP@)V-O;7!A=&EB;&4G+`T*("`@("`@("`@("`@("`@("`@
M("`G9&5P96YD96YC:65S)RP@)W!R;W9I9&5S97AT96YS:6]N)RP@)W-R8W!A
M8VMA9V4G+"`G<W)C=7)I)RP-"B`@("`@("`@("`@("`@("`@("`@)W!H<')E
M;&5A<V4G+"`G97AT<W)C<F5L96%S92<L#0H@("`@("`@("`@("`@("`@("`@
M("=E>'1B:6YR96QE87-E)RP@)V)U;F1L92<L("=C:&%N9V5L;V<G*2P@)'1I
M;64L("=T:6UE)RD[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]P86-K
M86=E26YF;ULG=&EM92==(#T@)'1I;64[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@9V5T1&%T92@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/E]P86-K86=E26YF;ULG9&%T92==*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?<&%C:V%G94EN9F];)V1A=&4G73L-"B`@("`@("`@?0T*("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T
M5&EM92@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K
M86=E26YF;ULG=&EM92==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?<&%C:V%G94EN9F];)W1I;64G73L-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M
M('!A8VMA9V5\87!I('9E<G-I;VX@8V%T96=O<GD@=&\@<F5T=7)N#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@9V5T5F5R<VEO;B@D:V5Y(#T@)W)E;&5A<V4G
M*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN
M9F];)W9E<G-I;VXG75LD:V5Y72DI('L-"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7W!A8VMA9V5);F9O6R=V97)S:6]N)UU;)&ME>5T[#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T
M:6]N(&=E=%-T86)I;&ET>2@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]P86-K86=E26YF;ULG<W1A8FEL:71Y)UTI*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULG<W1A8FEL:71Y)UT[
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*
M("`@(&9U;F-T:6]N(&=E=%-T871E*"1K97D@/2`G<F5L96%S92<I#0H@("`@
M>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG<W1A
M8FEL:71Y)UU;)&ME>5TI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]P86-K86=E26YF;ULG<W1A8FEL:71Y)UU;)&ME>5T[#0H@("`@("`@('T-
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N
M(&=E=$QI8V5N<V4H)')A=R`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)VQI8V5N<V4G72DI('L-"B`@
M("`@("`@("`@(&EF("@D<F%W*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?<&%C:V%G94EN9F];)VQI8V5N<V4G73L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=L:6-E;G-E)UTI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<&%C:V%G94EN9F];)VQI8V5N<V4G75LG7V-O;G1E;G0G73L-"B`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<&%C:V%G94EN9F];)VQI8V5N<V4G73L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@9V5T3&EC96YS94QO8V%T:6]N*"D-"B`@("![#0H@("`@
M("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG;&EC96YS92==
M*2!\?"`A:7-?87)R87DH)'1H:7,M/E]P86-K86=E26YF;ULG;&EC96YS92==
M*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@
M("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=L:6-E;G-E)UU;
M)V%T=')I8G,G73L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971.;W1E<R@I
M#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF
M;ULG;F]T97,G72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A
M8VMA9V5);F9O6R=N;W1E<R==.PT*("`@("`@("!]#0H@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!2971U<FX@=&AE
M(#QU<V5S<F]L93X@=&%G(&-O;G1E;G1S+"!I9B!A;GD-"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y?&9A;'-E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T57-E
M<W)O;&4H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C
M:V%G94EN9F];)W5S97-R;VQE)UTI*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/E]P86-K86=E26YF;ULG=7-E<W)O;&4G73L-"B`@("`@("`@?0T*
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@4F5T=7)N('1H92`\=7-E<W1A<VL^('1A9R!C;VYT96YT<RP@:68@86YY
M#0H@("`@("H@0')E='5R;B!A<G)A>7QF86QS90T*("`@("`J+PT*("`@(&9U
M;F-T:6]N(&=E=%5S97-T87-K*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7W!A8VMA9V5);F9O6R=U<V5S=&%S:R==*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];)W5S97-T87-K)UT[
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*
M("`@("\J*@T*("`@("`J(%1H:7,@<VAO=6QD(&]N;'D@8F4@=7-E9"!T;R!R
M971R:65V92!F:6QE;F%M97,@86YD(&EN<W1A;&P@871T<FEB=71E<PT*("`@
M("`J+PT*("`@(&9U;F-T:6]N(&=E=$9I;&5L:7-T*"1P<F5S97)V92`](&9A
M;'-E*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G
M94EN9F];)V9I;&5L:7-T)UTI("8F("$D<')E<V5R=F4I('L-"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=F:6QE;&ES="==.PT*
M("`@("`@("!]#0H@("`@("`@("1T:&ES+3YF;&%T=&5N1FEL96QI<W0H*3L-
M"B`@("`@("`@:68@*"1C;VYT96YT<R`]("1T:&ES+3YG971#;VYT96YT<R@I
M*2![#0H@("`@("`@("`@("`D<F5T(#T@87)R87DH*3L-"B`@("`@("`@("`@
M(&EF("@A:7-S970H)&-O;G1E;G1S6R=D:7(G75LG9FEL92==6S!=*2D@>PT*
M("`@("`@("`@("`@("`@("1C;VYT96YT<ULG9&ER)UU;)V9I;&4G72`](&%R
M<F%Y*"1C;VYT96YT<ULG9&ER)UU;)V9I;&4G72D[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!F;W)E86-H("@D8V]N=&5N='-;)V1I<B==6R=F:6QE
M)UT@87,@)&9I;&4I('L-"B`@("`@("`@("`@("`@("`D;F%M92`]("1F:6QE
M6R=A='1R:6)S)UU;)VYA;64G73L-"B`@("`@("`@("`@("`@("!I9B`H(21P
M<F5S97)V92D@>PT*("`@("`@("`@("`@("`@("`@("`D9FEL92`]("1F:6QE
M6R=A='1R:6)S)UT[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("1R971;)&YA;65=(#T@)&9I;&4[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!I9B`H(21P<F5S97)V92D@>PT*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%C:V%G94EN9F];)V9I;&5L:7-T)UT@/2`D<F5T.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N("1R970[#0H@("`@("`@('T-
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@
M("`J(%)E='5R;B!C;VYF:6=U<F4@;W!T:6]N<R!A<G)A>2P@:68@86YY#0H@
M("`@("H-"B`@("`@*B!`<F5T=7)N(&%R<F%Y?&9A;'-E#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@9V5T0V]N9FEG=7)E3W!T:6]N<R@I#0H@("`@>PT*("`@
M("`@("!I9B`H)'1H:7,M/F=E=%!A8VMA9V54>7!E*"D@(3T@)V5X='-R8R<I
M('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@
M("`@("`D<F5L96%S97,@/2`D=&AI<RT^9V5T4F5L96%S97,H*3L-"B`@("`@
M("`@:68@*&ES<V5T*"1R96QE87-E<ULP72DI('L-"B`@("`@("`@("`@("1R
M96QE87-E<R`]("1R96QE87-E6S!=.PT*("`@("`@("!]#0H@("`@("`@(&EF
M("AI<W-E="@D<F5L96%S97-;)V-O;F9I9W5R96]P=&EO;B==*2D@>PT*("`@
M("`@("`@("`@:68@*"%I<W-E="@D<F5L96%S97-;)V-O;F9I9W5R96]P=&EO
M;B==6S!=*2D@>PT*("`@("`@("`@("`@("`@("1R96QE87-E<ULG8V]N9FEG
M=7)E;W!T:6]N)UT@/2!A<G)A>2@D<F5L96%S97-;)V-O;F9I9W5R96]P=&EO
M;B==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O<B`H)&D@/2`P
M.R`D:2`\(&-O=6YT*"1R96QE87-E<ULG8V]N9FEG=7)E;W!T:6]N)UTI.R`D
M:2LK*2![#0H@("`@("`@("`@("`@("`@)')E;&5A<V5S6R=C;VYF:6=U<F5O
M<'1I;VXG75LD:5T@/2`D<F5L96%S97-;)V-O;F9I9W5R96]P=&EO;B==6R1I
M75LG871T<FEB<R==.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T
M=7)N("1R96QE87-E<ULG8V]N9FEG=7)E;W!T:6]N)UT[#0H@("`@("`@('T-
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@
M("`J(%1H:7,@:7,@;VYL>2!U<V5D(&%T(&EN<W1A;&PM=&EM92P@869T97(@
M86QL('-E<FEA;&EZ871I;VX-"B`@("`@*B!I<R!O=F5R+@T*("`@("`J+PT*
M("`@(&9U;F-T:6]N(')E<V5T1FEL96QI<W0H*0T*("`@('L-"B`@("`@("`@
M)'1H:7,M/E]P86-K86=E26YF;ULG9FEL96QI<W0G72`](&%R<F%Y*"D[#0H@
M("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4F5T<FEE=F4@82!L:7-T(&]F(&9I
M;&5S('1H870@<VAO=6QD(&)E(&EN<W1A;&QE9"!O;B!T:&ES(&-O;7!U=&5R
M#0H@("`@("H@0')E='5R;B!A<G)A>0T*("`@("`J+PT*("`@(&9U;F-T:6]N
M(&=E=$EN<W1A;&QA=&EO;D9I;&5L:7-T*"1F;W)F:6QE8VAE8VL@/2!F86QS
M92D-"B`@("![#0H@("`@("`@("1C;VYT96YT<R`]("1T:&ES+3YG971&:6QE
M;&ES="AT<G5E*3L-"B`@("`@("`@:68@*&ES<V5T*"1C;VYT96YT<ULG9&ER
M)UU;)V%T=')I8G,G75LG8F%S96EN<W1A;&QD:7(G72DI('L-"B`@("`@("`@
M("`@("1B87-E(#T@)&-O;G1E;G1S6R=D:7(G75LG871T<FEB<R==6R=B87-E
M:6YS=&%L;&1I<B==.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7W!A8VMA9V5);F9O6R=B=6YD;&4G72DI('L-"B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*`T*("`@("`@("`@("`@("`@("=%
M>&-E<'1I;VXZ(&)U;F1L97,@<VAO=6QD(&)E(&AA;F1L960@:6X@9&]W;FQO
M860@8V]D92!O;FQY)RD[#0H@("`@("`@('T-"B`@("`@("`@)')E;&5A<V4@
M/2`D=&AI<RT^9V5T4F5L96%S97,H*3L-"B`@("`@("`@:68@*"1R96QE87-E
M*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1R96QE87-E6S!=*2D@>PT*
M("`@("`@("`@("`@("`@(&EF("@A:7-S970H)')E;&5A<V5;)VEN<W1A;&QC
M;VYD:71I;VYS)UTI("8F("%I<W-E="@D<F5L96%S95LG9FEL96QI<W0G72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1F;W)F:6QE8VAE8VLI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9V5T1FEL
M96QI<W0H*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@)&-O;G1E;G1S.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`D<F5L96%S92`](&%R<F%Y*"1R96QE87-E*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1D97!C:&5C:V5R(#T@)B1T
M:&ES+3YG971014%21&5P96YD96YC>3(H)'1H:7,M/E]C;VYF:6<L(&%R<F%Y
M*"DL#0H@("`@("`@("`@("`@("`@87)R87DH)V-H86YN96PG(#T^("1T:&ES
M+3YG971#:&%N;F5L*"DL("=P86-K86=E)R`]/B`D=&AI<RT^9V5T4&%C:V%G
M92@I*2P-"B`@("`@("`@("`@("`@("!014%27U9!3$E$051%7TE.4U1!3$Q)
M3D<I.PT*("`@("`@("`@("`@9F]R96%C:"`H)')E;&5A<V4@87,@)&EN<W1A
M;F-E*2![#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I;G-T86YC95LG
M:6YS=&%L;&-O;F1I=&EO;G,G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M)&EN<W1A;&QC;VYD:71I;VYS(#T@)&EN<W1A;F-E6R=I;G-T86QL8V]N9&ET
M:6]N<R==.PT*("`@("`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)&EN
M<W1A;&QC;VYD:71I;VYS*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M4$5!4CHZ<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&EN<W1A;&QC;VYD
M:71I;VYS(&%S("1T>7!E(#T^("1C;VYD:71I;VYS*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D8V]N9&ET:6]N<ULP72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O;F1I=&EO
M;G,@/2!A<G)A>2@D8V]N9&ET:6]N<RD[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1C;VYD:71I;VYS(&%S("1C;VYD:71I;VXI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)')E="`]("1D97!C:&5C:V5R+3Y[(G9A
M;&ED871E>R1T>7!E?41E<&5N9&5N8WDB?2@D8V]N9&ET:6]N*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)')E="DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E(#,[("\O('-K:7`@=&AI<R!R
M96QE87-E#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!014%2.CIP;W!%
M<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@+R\@=&AI<R!I<R!T:&4@
M<F5L96%S92!T;R!U<V4-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&EN
M<W1A;F-E6R=F:6QE;&ES="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`O
M+R!I9VYO<F4@9FEL97,-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1I;G-T86YC95LG9FEL96QI<W0G75LG:6=N;W)E)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D:6=N;W)E(#T@:7-S970H)&EN<W1A;F-E6R=F
M:6QE;&ES="==6R=I9VYO<F4G75LP72D@/PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1I;G-T86YC95LG9FEL96QI<W0G75LG:6=N;W)E)UT@.@T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1I;G-T86YC95LG
M9FEL96QI<W0G75LG:6=N;W)E)UTI.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)&EG;F]R92!A<R`D:6<I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!U;G-E="`H)&-O;G1E;G1S6R1I9ULG871T<FEB<R==
M6R=N86UE)UU=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`O+R!I;G-T
M86QL(&9I;&5S(&%S('1H:7,@;F%M90T*("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)&EN<W1A;F-E6R=F:6QE;&ES="==6R=I;G-T86QL)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D:6YS=&%L;&%S(#T@:7-S970H
M)&EN<W1A;F-E6R=F:6QE;&ES="==6R=I;G-T86QL)UU;,%TI(#\-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D:6YS=&%N8V5;)V9I;&5L:7-T)UU;
M)VEN<W1A;&PG72`Z#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)&EN<W1A;F-E6R=F:6QE;&ES="==6R=I;G-T86QL)UTI.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&EN<W1A;&QA<R!A<R`D87,I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]N=&5N='-;)&%S
M6R=A='1R:6)S)UU;)VYA;64G75U;)V%T=')I8G,G75LG:6YS=&%L;"UA<R==
M(#T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%S6R=A='1R
M:6)S)UU;)V%S)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@:68@*"1F;W)F:6QE8VAE8VLI('L-"B`@("`@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)&-O;G1E;G1S(&%S("1F:6QE(#T^("1A='1R<RD@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&-O;G1E;G1S6R1F:6QE72`]
M("1A='1R<ULG871T<FEB<R==.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(')E='5R;B`D8V]N
M=&5N=',[#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![("\O('-I
M;7!L92!R96QE87-E("T@;F\@:6YS=&%L;&-O;F1I=&EO;G,@;W(@:6YS=&%L
M;"UA<PT*("`@("`@("`@("`@:68@*"1F;W)F:6QE8VAE8VLI('L-"B`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/F=E=$9I;&5L:7-T*"D[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@)&-O;G1E;G1S.PT*("`@
M("`@("!]#0H@("`@("`@("\O(&YO(')E;&5A<V5S(&UA=&-H960-"B`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TYO(')E;&5A<V5S(&EN('!A
M8VMA9V4N>&UL(&UA=&-H960@=&AE(&5X:7-T:6YG(&]P97)A=&EN9R`G("X-
M"B`@("`@("`@("`@("=S>7-T96TL(&5X=&5N<VEO;G,@:6YS=&%L;&5D+"!O
M<B!A<F-H:71E8W1U<F4L(&-A;FYO="!I;G-T86QL)RD[#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@5&AI<R!I<R!O;FQY('5S960@870@:6YS=&%L;"UT
M:6UE+"!A9G1E<B!A;&P@<V5R:6%L:7IA=&EO;@T*("`@("`J(&ES(&]V97(N
M#0H@("`@("H@0'!A<F%M('-T<FEN9R!F:6QE(&YA;64-"B`@("`@*B!`<&%R
M86T@<W1R:6YG(&EN<W1A;&QE9"!P871H#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@<V5T26YS=&%L;&5D07,H)&9I;&4L("1P871H*0T*("`@('L-"B`@("`@
M("`@:68@*"1P871H*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P
M86-K86=E26YF;ULG9FEL96QI<W0G75LD9FEL95U;)VEN<W1A;&QE9%]A<R==
M(#T@)'!A=&@[#0H@("`@("`@('T-"B`@("`@("`@=6YS970H)'1H:7,M/E]P
M86-K86=E26YF;ULG9FEL96QI<W0G75LD9FEL95U;)VEN<W1A;&QE9%]A<R==
M*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971);G-T86QL961,;V-A=&EO
M;B@D9FEL92D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A
M8VMA9V5);F9O6R=F:6QE;&ES="==6R1F:6QE75LG:6YS=&%L;&5D7V%S)UTI
M*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULG
M9FEL96QI<W0G75LD9FEL95U;)VEN<W1A;&QE9%]A<R==.PT*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!4:&ES(&ES(&]N;'D@=7-E9"!A="!I;G-T86QL+71I;64L(&%F=&5R
M(&%L;"!S97)I86QI>F%T:6]N#0H@("`@("H@:7,@;W9E<BX-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!I;G-T86QL961&:6QE*"1F:6QE+"`D871T<RD-"B`@
M("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=F
M:6QE;&ES="==6R1F:6QE72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?<&%C
M:V%G94EN9F];)V9I;&5L:7-T)UU;)&9I;&5=(#T-"B`@("`@("`@("`@("`@
M("!A<G)A>5]M97)G92@D=&AI<RT^7W!A8VMA9V5);F9O6R=F:6QE;&ES="==
M6R1F:6QE72P@)&%T='-;)V%T=')I8G,G72D[#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=F:6QE;&ES="==
M6R1F:6QE72`]("1A='1S6R=A='1R:6)S)UT[#0H@("`@("`@('T-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!2971R:65V92!T:&4@8V]N=&5N=',@=&%G
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T0V]N=&5N=',H*0T*("`@('L-
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1E
M;G1S)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E
M26YF;ULG8V]N=&5N=',G73L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN
M9R!F=6QL('!A=&@@=&\@9FEL90T*("`@("`J($!P87)A;2!S=')I;F<@871T
M<FEB=71E(&YA;64-"B`@("`@*B!`<&%R86T@<W1R:6YG(&%T=')I8G5T92!V
M86QU90T*("`@("`J($!P87)A;2!I;G0@<FES:WD@8G5T(&9A<W0@+2!U<V4@
M=&AI<R!T;R!C:&]O<V4@82!F:6QE(&)A<V5D(&]N(&ET<R!P;W-I=&EO;B!I
M;B!T:&4@;&ES=`T*("`@("`J("`@("`@("`@("`@;V8@9FEL97,N("!);F1E
M>"!I<R!Z97)O+6)A<V5D(&QI:V4@4$A0(&%R<F%Y<RX-"B`@("`@*B!`<F5T
M=7)N(&)O;VP@<W5C8V5S<R!O9B!O<&5R871I;VX-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!S971&:6QE071T<FEB=71E*"1F:6QE;F%M92P@)&%T='(L("1V
M86QU92P@)&EN9&5X(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^
M7VES5F%L:60@/2`P.PT*("`@("`@("!I9B`H:6Y?87)R87DH)&%T='(L(&%R
M<F%Y*"=R;VQE)RP@)VYA;64G+"`G8F%S96EN<W1A;&QD:7(G*2DI('L-"B`@
M("`@("`@("`@("1T:&ES+3Y?9FEL97-686QI9"`](&9A;'-E.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("@D:6YD97@@(3T](&9A;'-E("8F#0H@("`@("`@
M("`@("`@(&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S)UU;
M)V1I<B==6R=F:6QE)UU;)&EN9&5X75LG871T<FEB<R==*2D@>PT*("`@("`@
M("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=&5N=',G75LG9&ER)UU;
M)V9I;&4G75LD:6YD97A=6R=A='1R:6)S)UU;)&%T=')=(#T@)'9A;'5E.PT*
M("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT96YT<R==6R=D
M:7(G75LG9FEL92==*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@("`@("!]#0H@("`@("`@("1F:6QE<R`]("1T:&ES+3Y?<&%C:V%G94EN
M9F];)V-O;G1E;G1S)UU;)V1I<B==6R=F:6QE)UT[#0H@("`@("`@(&EF("@A
M:7-S970H)&9I;&5S6S!=*2D@>PT*("`@("`@("`@("`@)&9I;&5S(#T@87)R
M87DH)&9I;&5S*3L-"B`@("`@("`@("`@("1I;F0@/2!F86QS93L-"B`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("1I;F0@/2!T<G5E.PT*("`@("`@
M("!]#0H@("`@("`@(&9O<F5A8V@@*"1F:6QE<R!A<R`D:2`]/B`D9FEL92D@
M>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1F:6QE6R=A='1R:6)S)UTI*2![
M#0H@("`@("`@("`@("`@("`@:68@*"1F:6QE6R=A='1R:6)S)UU;)VYA;64G
M72`]/2`D9FEL96YA;64I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1I
M;F0I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G
M94EN9F];)V-O;G1E;G1S)UU;)V1I<B==6R=F:6QE)UU;)&E=6R=A='1R:6)S
M)UU;)&%T=')=(#T@)'9A;'5E.PT*("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E
M26YF;ULG8V]N=&5N=',G75LG9&ER)UU;)V9I;&4G75LG871T<FEB<R==6R1A
M='1R72`]("1V86QU93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E=$1I<G1R964H)'!A=&@I
M#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=D:7)T<F5E
M)UU;)'!A=&A=(#T@=')U93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971$
M:7)T<F5E*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A
M8VMA9V5);F9O6R=D:7)T<F5E)UTI("8F(&-O=6YT*"1T:&ES+3Y?<&%C:V%G
M94EN9F];)V1I<G1R964G72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7W!A8VMA9V5);F9O6R=D:7)T<F5E)UT[#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(')E<V5T
M1&ER=')E92@I#0H@("`@>PT*("`@("`@("!U;G-E="@D=&AI<RT^7W!A8VMA
M9V5);F9O6R=D:7)T<F5E)UTI.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J
M($1E=&5R;6EN97,@=VAE=&AE<B!T:&ES('!A8VMA9V4@8VQA:6US(&ET(&ES
M(&-O;7!A=&EB;&4@=VET:"!T:&4@=F5R<VEO;B!O9@T*("`@("`J('1H92!P
M86-K86=E('1H870@:&%S(&$@<F5C;VUM96YD960@=F5R<VEO;B!D97!E;F1E
M;F-Y#0H@("`@("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C)\4$5!4E]0
M86-K86=E1FEL95]V,7Q014%27T1O=VYL;V%D97)?4&%C:V%G90T*("`@("`J
M($!R971U<FX@8F]O;&5A;@T*("`@("`J+PT*("`@(&9U;F-T:6]N(&ES0V]M
M<&%T:6)L92@D<&8I#0H@("`@>PT*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3Y?<&%C:V%G94EN9F];)V-O;7!A=&EB;&4G72DI('L-"B`@("`@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-H86YN96PG72DI('L-"B`@("`@("`@
M("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D;64@/2`D
M<&8M/F=E=%9E<G-I;VXH*3L-"B`@("`@("`@)&-O;7!A=&EB;&4@/2`D=&AI
M<RT^7W!A8VMA9V5);F9O6R=C;VUP871I8FQE)UT[#0H@("`@("`@(&EF("@A
M:7-S970H)&-O;7!A=&EB;&5;,%TI*2![#0H@("`@("`@("`@("`D8V]M<&%T
M:6)L92`](&%R<F%Y*"1C;VUP871I8FQE*3L-"B`@("`@("`@?0T*("`@("`@
M("`D9F]U;F0@/2!F86QS93L-"B`@("`@("`@9F]R96%C:"`H)&-O;7!A=&EB
M;&4@87,@)&EN9F\I('L-"B`@("`@("`@("`@(&EF("AS=')T;VQO=V5R*"1I
M;F9O6R=N86UE)UTI(#T]('-T<G1O;&]W97(H)'!F+3YG971086-K86=E*"DI
M*2![#0H@("`@("`@("`@("`@("`@:68@*'-T<G1O;&]W97(H)&EN9F];)V-H
M86YN96PG72D@/3T@<W1R=&]L;W=E<B@D<&8M/F=E=$-H86YN96PH*2DI('L-
M"B`@("`@("`@("`@("`@("`@("`@)&9O=6YD(#T@=')U93L-"B`@("`@("`@
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@A)&9O=6YD*2![#0H@
M("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&ES<V5T*"1I;F9O6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1I;F9O6R=E>&-L=61E)UU;,%TI*2![#0H@("`@("`@("`@
M("`@("`@)&EN9F];)V5X8VQU9&4G72`](&%R<F%Y*"1I;F9O6R=E>&-L=61E
M)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H)&EN
M9F];)V5X8VQU9&4G72!A<R`D97AC;'5D92D@>PT*("`@("`@("`@("`@("`@
M(&EF("AV97)S:6]N7V-O;7!A<F4H)&UE+"`D97AC;'5D92P@)ST])RDI('L-
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H=F5R<VEO;E]C;VUP87)E*"1M92P@)&EN9F];)VUI;B==+"`G/CTG*2`F
M)B!V97)S:6]N7V-O;7!A<F4H)&UE+"`D:6YF;ULG;6%X)UTL("<\/2<I*2![
M#0H@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0')E
M='5R;B!A<G)A>7QF86QS90T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$-O
M;7!A=&EB;&4H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M<&%C:V%G94EN9F];)V-O;7!A=&EB;&4G72DI('L-"B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VUP871I8FQE)UT[#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N(&=E=$1E<&5N9&5N8VEE<R@I#0H@("`@>PT*("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG9&5P96YD96YC:65S)UTI*2![
M#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULG9&5P
M96YD96YC:65S)UT[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&ES4W5B<&%C:V%G94]F*"1P*0T*
M("`@('L-"B`@("`@("`@<F5T=7)N("1P+3YI<U-U8G!A8VMA9V4H)'1H:7,I
M.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($1E=&5R;6EN97,@=VAE=&AE
M<B!T:&4@<&%S<V5D(&EN('!A8VMA9V4@:7,@82!S=6)P86-K86=E(&]F('1H
M:7,@<&%C:V%G92X-"B`@("`@*@T*("`@("`J($YO('9E<G-I;VX@8VAE8VMI
M;F<@:7,@9&]N92P@;VYL>2!N86UE('9E<FEF:6-A=&EO;BX-"B`@("`@*B!`
M<&%R86T@4$5!4E]086-K86=E1FEL95]V,7Q014%27U!A8VMA9V5&:6QE7W8R
M#0H@("`@("H@0')E='5R;B!B;V]L#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M:7-3=6)P86-K86=E*"1P*0T*("`@('L-"B`@("`@("`@)'-U8B`](&%R<F%Y
M*"D[#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=D
M97!E;F1E;F-I97,G75LG<F5Q=6ER960G75LG<W5B<&%C:V%G92==*2D@>PT*
M("`@("`@("`@("`@)'-U8B`]("1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<&5N
M9&5N8VEE<R==6R=R97%U:7)E9"==6R=S=6)P86-K86=E)UT[#0H@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1S=6);,%TI*2![#0H@("`@("`@("`@("`@("`@
M)'-U8B`](&%R<F%Y*"1S=6(I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=D97!E
M;F1E;F-I97,G75LG;W!T:6]N86PG75LG<W5B<&%C:V%G92==*2D@>PT*("`@
M("`@("`@("`@)'-U8C$@/2`D=&AI<RT^7W!A8VMA9V5);F9O6R=D97!E;F1E
M;F-I97,G75LG;W!T:6]N86PG75LG<W5B<&%C:V%G92==.PT*("`@("`@("`@
M("`@:68@*"%I<W-E="@D<W5B,5LP72DI('L-"B`@("`@("`@("`@("`@("`D
M<W5B,2`](&%R<F%Y*"1S=6(Q*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("1S=6(@/2!A<G)A>5]M97)G92@D<W5B+"`D<W5B,2D[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1E
M<&5N9&5N8VEE<R==6R=G<F]U<"==*2D@>PT*("`@("`@("`@("`@)&=R;W5P
M(#T@)'1H:7,M/E]P86-K86=E26YF;ULG9&5P96YD96YC:65S)UU;)V=R;W5P
M)UT[#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1G<F]U<%LP72DI('L-"B`@
M("`@("`@("`@("`@("`D9W)O=7`@/2!A<G)A>2@D9W)O=7`I.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H)&=R;W5P(&%S("1D97!S
M*2![#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!S6R=S=6)P86-K
M86=E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1S=6(R(#T@)&1E<'-;
M)W-U8G!A8VMA9V4G73L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D<W5B,ELP72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1S=6(R
M(#T@87)R87DH)'-U8C(I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("1S=6(@/2!A<G)A>5]M97)G92@D<W5B+"`D<W5B
M,BD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@(&9O<F5A8V@@*"1S=6(@87,@)&1E<"D@>PT*("`@("`@
M("`@("`@:68@*'-T<G1O;&]W97(H)&1E<%LG;F%M92==*2`]/2!S=')T;VQO
M=V5R*"1P+3YG971086-K86=E*"DI*2![#0H@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1D97!;)V-H86YN96PG72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@:68@*'-T<G1O;&]W97(H)&1E<%LG8VAA;FYE;"==*2`]/2!S=')T;VQO
M=V5R*"1P+3YG971#:&%N;F5L*"DI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@(&EF
M("@D9&5P6R=U<FDG72`]/2`D<"T^9V5T55))*"DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!D97!E;F1S3VXH)'!A8VMA9V4L("1C:&%N;F5L*0T*("`@('L-"B`@
M("`@("`@:68@*"$H)&1E<',@/2`D=&AI<RT^9V5T1&5P96YD96YC:65S*"DI
M*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@
M("`@("`@9F]R96%C:"`H87)R87DH)W!A8VMA9V4G+"`G<W5B<&%C:V%G92<I
M(&%S("1T>7!E*2![#0H@("`@("`@("`@("!F;W)E86-H("AA<G)A>2@G<F5Q
M=6ER960G+"`G;W!T:6]N86PG*2!A<R`D;F5E9&5D*2![#0H@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1D97!S6R1N965D961=6R1T>7!E72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D9&5P<ULD;F5E9&5D75LD
M='EP95U;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D9&5P<ULD
M;F5E9&5D75LD='EP95T@/2!A<G)A>2@D9&5P<ULD;F5E9&5D75LD='EP95TI
M.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1D97!S6R1N965D961=6R1T>7!E72!A<R`D9&5P*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D9&5P8VAA;FYE;"`](&ES<V5T*"1D
M97!;)V-H86YN96PG72D@/R`D9&5P6R=C:&%N;F5L)UT@.B`G7U]U<FDG.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*'-T<G1O;&]W97(H)&1E<%LG
M;F%M92==*2`]/2!S=')T;VQO=V5R*"1P86-K86=E*2`F)@T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&1E<&-H86YN96P@/3T@)&-H86YN96PI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L-
M"B`@("`@("`@("`@("`@("`@("`@("`@('T@(`T*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@:68@*&ES<V5T*"1D97!S6R=G<F]U<"==*2D@>PT*("`@("`@
M("`@("`@("`@(&EF("@A:7-S970H)&1E<'-;)V=R;W5P)UU;,%TI*2![#0H@
M("`@("`@("`@("`@("`@("`@("1D97!;)V=R;W5P)UT@/2!A<G)A>2@D9&5P
M<ULG9W)O=7`G72D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1D97!S6R=G<F]U<"==(&%S("1G<F]U<"D@>PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&=R;W5P6R1T>7!E72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?87)R87DH)&=R;W5P
M6R1T>7!E72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9W)O
M=7!;)'1Y<&5=(#T@87)R87DH)&=R;W5P6R1T>7!E72D[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!F;W)E
M86-H("@D9W)O=7!;)'1Y<&5=(&%S("1D97`I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9&5P8VAA;FYE;"`](&ES<V5T*"1D97!;)V-H86YN
M96PG72D@/R`D9&5P6R=C:&%N;F5L)UT@.B`G7U]U<FDG.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AS=')T;VQO=V5R*"1D97!;)VYA;64G
M72D@/3T@<W1R=&]L;W=E<B@D<&%C:V%G92D@)B8-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9&5P8VAA;FYE;"`]/2`D8VAA;FYE;"D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U
M93L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]("`-"B`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M1V5T('1H92!C;VYT96YT<R!O9B!A(&1E<&5N9&5N8WD@9W)O=7`-"B`@("`@
M*B!`<&%R86T@<W1R:6YG#0H@("`@("H@0')E='5R;B!A<G)A>7QF86QS90T*
M("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$1E<&5N9&5N8WE'<F]U<"@D;F%M
M92D-"B`@("![#0H@("`@("`@("1N86UE(#T@<W1R=&]L;W=E<B@D;F%M92D[
M#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG9&5P
M96YD96YC:65S)UU;)V=R;W5P)UTI*2![#0H@("`@("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)&=R;W5P<R`]("1T:&ES+3Y?
M<&%C:V%G94EN9F];)V1E<&5N9&5N8VEE<R==6R=G<F]U<"==.PT*("`@("`@
M("!I9B`H(6ES<V5T*"1G<F]U<'-;,%TI*2![#0H@("`@("`@("`@("`D9W)O
M=7!S(#T@87)R87DH)&=R;W5P<RD[#0H@("`@("`@('T-"B`@("`@("`@9F]R
M96%C:"`H)&=R;W5P<R!A<R`D9W)O=7`I('L-"B`@("`@("`@("`@(&EF("AS
M=')T;VQO=V5R*"1G<F]U<%LG871T<FEB<R==6R=N86UE)UTI(#T]("1N86UE
M*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1G<F]U<#L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@4F5T<FEE=F4@82!P87)T:6%L('!A8VMA
M9V4N>&UL(#$N,"!R97!R97-E;G1A=&EO;B!O9B!D97!E;F1E;F-I97,-"B`@
M("`@*@T*("`@("`J(&$@=F5R>2!L:6UI=&5D(')E<')E<V5N=&%T:6]N(&]F
M(&1E<&5N9&5N8VEE<R!I<R!R971U<FYE9"!B>2!T:&ES(&UE=&AO9"X-"B`@
M("`@*B!4:&4@/&5X8VQU9&4^('1A9R!F;W(@97AC;'5D:6YG(&-E<G1A:6X@
M=F5R<VEO;G,@;V8@82!D97!E;F1E;F-Y(&ES#0H@("`@("H@8V]M<&QE=&5L
M>2!I9VYO<F5D+B`@26X@861D:71I;VXL(&1E<&5N9&5N8WD@9W)O=7!S(&%R
M92!I9VYO<F5D+"!W:71H('1H90T*("`@("`J(&%S<W5M<'1I;VX@=&AA="!A
M;&P@9&5P96YD96YC:65S(&EN(&1E<&5N9&5N8WD@9W)O=7!S(&%R92!A;'-O
M(&QI<W1E9"!I;@T*("`@("`J('1H92!O<'1I;VYA;"!G<F]U<"!T:&%T('=O
M<FL@=VET:"!A;&P@9&5P96YD96YC>2!G<F]U<',-"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B!R971U<FX@<&%C:V%G92YX;6P@,BXP(#QD97!E;F1E;F-I97,^
M('1A9PT*("`@("`J($!R971U<FX@87)R87E\9F%L<V4-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!G971$97!S*"1R87<@/2!F86QS92P@)&YO<&5A<FEN<W1A
M;&QE<B`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?<&%C:V%G94EN9F];)V1E<&5N9&5N8VEE<R==*2D@>PT*("`@("`@("`@
M("`@:68@*"1R87<I('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]P86-K86=E26YF;ULG9&5P96YD96YC:65S)UT[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`D<F5T(#T@87)R87DH*3L-"B`@("`@("`@("`@("1M
M87`@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`G<&AP)R`]/B`G<&AP)RP-
M"B`@("`@("`@("`@("`@("`G<&%C:V%G92<@/3X@)W!K9R<L#0H@("`@("`@
M("`@("`@("`@)W-U8G!A8VMA9V4G(#T^("=P:V<G+`T*("`@("`@("`@("`@
M("`@("=E>'1E;G-I;VXG(#T^("=E>'0G+`T*("`@("`@("`@("`@("`@("=O
M<R<@/3X@)V]S)RP-"B`@("`@("`@("`@("`@("`G<&5A<FEN<W1A;&QE<B<@
M/3X@)W!K9R<L#0H@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@("`@(&9O
M<F5A8V@@*&%R<F%Y*"=R97%U:7)E9"<L("=O<'1I;VYA;"<I(&%S("1T>7!E
M*2![#0H@("`@("`@("`@("`@("`@)&]P=&EO;F%L(#T@*"1T>7!E(#T]("=O
M<'1I;VYA;"<I(#\@)WEE<R<@.B`G;F\G.PT*("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG9&5P96YD96YC:65S)UU;
M)'1Y<&5=*2D@>PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1H
M:7,M/E]P86-K86=E26YF;ULG9&5P96YD96YC:65S)UU;)'1Y<&5=(&%S("1D
M='EP92`]/B`D9&5P<RD@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H)&1T
M>7!E(#T]("=P96%R:6YS=&%L;&5R)R`F)B`D;F]P96%R:6YS=&%L;&5R*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1D97!S6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&1E<',@
M/2!A<G)A>2@D9&5P<RD[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)&1E<',@87,@)&1E<"D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;6%P6R1D='EP95TI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@;F\@<W5P<&]R
M="!F;W(@87)C:"!T>7!E#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H)&1T>7!E(#T]("=P96%R:6YS=&%L;&5R
M)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D97!;)VYA;64G
M72`]("=014%2)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P
M6R=C:&%N;F5L)UT@/2`G<&5A<BYP:'`N;F5T)SL-"B`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("1S(#T@87)R
M87DH)W1Y<&4G(#T^("1M87!;)&1T>7!E72D[#0H@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&1E<%LG8VAA;FYE;"==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1S6R=C:&%N;F5L)UT@/2`D9&5P6R=C
M:&%N;F5L)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG=7)I)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-;)W5R:2==(#T@)&1E<%LG
M=7)I)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG;F%M92==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1S6R=N86UE)UT@/2`D9&5P6R=N
M86UE)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG8V]N9FQI8W1S)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-;)W)E;"==(#T@)VYO
M="<[#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&1E<%LG;6EN)UTI
M("8F#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(6ES<V5T
M*"1D97!;)VUA>"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<ULG<F5L)UT@/2`G:&%S)SL-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'-;)V]P=&EO;F%L)UT@/2`D;W!T:6]N86P[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1D97!;
M)VUI;B==*2`F)@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&ES<V5T*"1D97!;)VUA>"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<ULG<F5L)UT@/2`G9V4G.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<S$@/2`D<SL-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)',Q6R=R96PG72`]("=L92<[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1S6R=V97)S:6]N)UT@/2`D9&5P6R=M
M:6XG73L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)',Q6R=V
M97)S:6]N)UT@/2`D9&5P6R=M87@G73L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)V-H86YN96PG72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S,5LG8VAA;FYE
M;"==(#T@)&1E<%LG8VAA;FYE;"==.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@D9'1Y<&4@(3T@)W!H<"<I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1S6R=N86UE)UT@/2`D9&5P6R=N86UE)UT[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<S%;)VYA;64G
M72`]("1D97!;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<ULG
M;W!T:6]N86PG72`]("1O<'1I;VYA;#L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)',Q6R=O<'1I;VYA;"==(#T@)&]P=&EO;F%L.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5T6UT@/2`D<S$[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1D
M97!;)VUI;B==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)&1E<%LG97AC;'5D92==*2`F)@T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P6R=E>&-L=61E)UT@/3T@
M)&1E<%LG;6EN)UTI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1S6R=R96PG72`]("=G="<[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<ULG<F5L)UT@/2`G9V4G.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1S6R=V97)S:6]N)UT@/2`D9&5P6R=M:6XG73L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-;)V]P=&EO;F%L)UT@/2`D
M;W!T:6]N86P[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@D9'1Y<&4@(3T@)W!H<"<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1S6R=N86UE)UT@/2`D9&5P6R=N86UE)UT[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!](&5L<V5I9B`H:7-S970H)&1E<%LG;6%X)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M9&5P6R=E>&-L=61E)UTI("8F#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1D97!;)V5X8VQU9&4G72`]/2`D9&5P6R=M87@G72D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-;)W)E
M;"==(#T@)VQT)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1S6R=R96PG72`]("=L92<[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-;
M)W9E<G-I;VXG72`]("1D97!;)VUA>"==.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<ULG;W!T:6]N86PG72`]("1O<'1I;VYA;#L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1D='EP92`A/2`G
M<&AP)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'-;)VYA;64G72`]("1D97!;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1R971;72`]("1S.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@:68@*&-O=6YT*"1R970I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N
M("1R970[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!R971U<FX@
M<&AP?&5X='-R8WQE>'1B:6Y\8G5N9&QE?&9A;'-E#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@9V5T4&%C:V%G951Y<&4H*0T*("`@('L-"B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W!H<')E;&5A<V4G72DI('L-
M"B`@("`@("`@("`@(')E='5R;B`G<&AP)SL-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG97AT<W)C<F5L96%S
M92==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("=E>'1S<F,G.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=E
M>'1B:6YR96QE87-E)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)V5X=&)I
M;B<[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C
M:V%G94EN9F];)V)U;F1L92==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("=B
M=6YD;&4G.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<F5T=7)N(&%R<F%Y?&9A;'-E#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@9V5T4F5L96%S97,H*0T*("`@('L-"B`@
M("`@("`@)'1Y<&4@/2`D=&AI<RT^9V5T4&%C:V%G951Y<&4H*3L-"B`@("`@
M("`@:68@*"1T>7!E("$]("=B=6YD;&4G*2![#0H@("`@("`@("`@("`D='EP
M92`N/2`G<F5L96%S92<[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1T:&ES
M+3YG971086-K86=E5'EP92@I("8F(&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN
M9F];)'1Y<&5=*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C
M:V%G94EN9F];)'1Y<&5=.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F
M86QS93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T0VAA;F=E;&]G*"D-"B`@("![
M#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=C:&%N
M9V5L;V<G72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA
M9V5);F9O6R=C:&%N9V5L;V<G73L-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@:&%S1&5P<R@I#0H@
M("`@>PT*("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/E]P86-K86=E26YF
M;ULG9&5P96YD96YC:65S)UTI.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E
M=%!A8VMA9V5X;6Q697)S:6]N*"D-"B`@("![#0H@("`@("`@(')E='5R;B`G
M,BXP)SL-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M?&9A;'-E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T4V]U<F-E4&%C:V%G
M92@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E
M26YF;ULG97AT8FEN<F5L96%S92==*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M(&%R<F%Y*"=C:&%N;F5L)R`]/B`D=&AI<RT^7W!A8VMA9V5);F9O6R=S<F-C
M:&%N;F5L)UTL#0H@("`@("`@("`@("`@("`@("`@("`@("`@)W!A8VMA9V4G
M(#T^("1T:&ES+3Y?<&%C:V%G94EN9F];)W-R8W!A8VMA9V4G72D[#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N(&=E=$)U;F1L961086-K86=E<R@I#0H@("`@>PT*("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG8G5N9&QE)UTI*2![#0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=&5N
M=',G75LG8G5N9&QE9'!A8VMA9V4G73L-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T3&%S=$UO
M9&EF:65D*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A
M8VMA9V5);F9O6R=?;&%S=&UO9&EF:65D)UTI*2![#0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULG7VQA<W1M;V1I9FEE9"==.PT*
M("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@
M("`O*BH-"B`@("`@*B!'970@=&AE(&-O;G1E;G1S(&]F(&$@9FEL92!L:7-T
M960@=VET:&EN('1H92!P86-K86=E+GAM;`T*("`@("`J($!P87)A;2!S=')I
M;F<-"B`@("`@*B!`<F5T=7)N('-T<FEN9PT*("`@("`J+PT*("`@(&9U;F-T
M:6]N(&=E=$9I;&5#;VYT96YT<R@D9FEL92D-"B`@("![#0H@("`@("`@(&EF
M("@D=&AI<RT^7V%R8VAI=F5&:6QE(#T]("1T:&ES+3Y?<&%C:V%G949I;&4I
M('L@+R\@=6YP86-K960-"B`@("`@("`@("`@("1D:7(@/2!D:7)N86UE*"1T
M:&ES+3Y?<&%C:V%G949I;&4I.PT*("`@("`@("`@("`@)&9I;&4@/2`D9&ER
M("X@1$E214-43U)97U-%4$%2051/4B`N("1F:6QE.PT*("`@("`@("`@("`@
M)&9I;&4@/2!S=')?<F5P;&%C92AA<G)A>2@G+R<L("=<7"<I+`T*("`@("`@
M("`@("`@("`@(&%R<F%Y*$1)4D5#5$]265]315!!4D%43U(L($1)4D5#5$]2
M65]315!!4D%43U(I+"`D9FEL92D[#0H@("`@("`@("`@("!I9B`H9FEL95]E
M>&ES=',H)&9I;&4I("8F(&ES7W)E861A8FQE*"1F:6QE*2D@>PT*("`@("`@
M("`@("`@("`@(')E='5R;B!I;7!L;V1E*"<G+"!F:6QE*"1F:6QE*2D[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![("\O('1G>@T*("`@("`@
M("`@("`@)'1A<B`]("9N97<@07)C:&EV95]487(H)'1H:7,M/E]A<F-H:79E
M1FEL92D[#0H@("`@("`@("`@("`D=&%R+3YP=7-H17)R;W)(86YD;&EN9RA0
M14%27T524D]27U)%5%523BD[#0H@("`@("`@("`@("!I9B`H)&9I;&4@(3T@
M)W!A8VMA9V4N>&UL)R`F)B`D9FEL92`A/2`G<&%C:V%G93(N>&UL)RD@>PT*
M("`@("`@("`@("`@("`@("1F:6QE(#T@)'1H:7,M/F=E=%!A8VMA9V4H*2`N
M("<M)R`N("1T:&ES+3YG971697)S:6]N*"D@+B`G+R<@+B`D9FEL93L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("1F:6QE(#T@)'1A<BT^97AT<F%C
M=$EN4W1R:6YG*"1F:6QE*3L-"B`@("`@("`@("`@("1T87(M/G!O<$5R<F]R
M2&%N9&QI;F<H*3L-"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1F
M:6QE*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*")#86YN;W0@;&]C871E(&9I;&4@)R1F:6QE)R!I;B!A<F-H:79E(BD[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@)&9I;&4[#0H@
M("`@("`@('T-"B`@("!]#0H-"B`@("!F=6YC=&EO;B`F9V5T4E<H*0T*("`@
M('L-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?4&%C:V%G949I
M;&5?=C)?<G<G*2D@>PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2
M+U!A8VMA9V5&:6QE+W8R+W)W+G!H<"<[#0H@("`@("`@('T-"B`@("`@("`@
M)&$@/2!N97<@4$5!4E]086-K86=E1FEL95]V,E]R=SL-"B`@("`@("`@9F]R
M96%C:"`H9V5T7V]B:F5C=%]V87)S*"1T:&ES*2!A<R`D;F%M92`]/B`D=6YU
M<V5D*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3XD;F%M92DI
M('L-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(&EF("@D;F%M92`]/2`G7V-O;F9I9R<@?'P@)&YA;64@
M/3T@)U]L;V=G97(G?'P@)&YA;64@/3T@)U]R96=I<W1R>2<@?'P-"B`@("`@
M("`@("`@("`@("`@("1N86UE(#T]("=?<W1A8VLG*2![#0H@("`@("`@("`@
M("`@("`@)&$M/B1N86UE(#T@)B1T:&ES+3XD;F%M93L-"B`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@)&$M/B1N86UE(#T@)'1H:7,M
M/B1N86UE.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B`D83L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B`F9V5T1&5F875L=$=E
M;F5R871O<B@I#0H@("`@>PT*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G
M4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C(G*2D@>PT*("`@("`@("`@
M("`@<F5Q=6ER95]O;F-E("=014%2+U!A8VMA9V5&:6QE+T=E;F5R871O<B]V
M,BYP:'`G.PT*("`@("`@("!]#0H@("`@("`@("1A(#T@)FYE=R!014%27U!A
M8VMA9V5&:6QE7T=E;F5R871O<E]V,B@D=&AI<RD[#0H@("`@("`@(')E='5R
M;B`D83L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!A;F%L>7IE4V]U<F-E0V]D
M92@D9FEL92P@)'-T<FEN9R`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^7W8R5F%L:61A=&]R*2!\?`T*("`@("`@("`@("`@
M("`A:7-?82@D=&AI<RT^7W8R5F%L:61A=&]R+"`G4$5!4E]086-K86=E1FEL
M95]V,E]686QI9&%T;W(G*2D@>PT*("`@("`@("`@("`@:68@*"%C;&%S<U]E
M>&ES=',H)U!%05)?4&%C:V%G949I;&5?=C)?5F%L:61A=&]R)RDI('L-"B`@
M("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O4&%C:V%G949I;&4O
M=C(O5F%L:61A=&]R+G!H<"<[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`D=&AI<RT^7W8R5F%L:61A=&]R(#T@;F5W(%!%05)?4&%C:V%G949I;&5?
M=C)?5F%L:61A=&]R.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D=&AI
M<RT^7W8R5F%L:61A=&]R+3YA;F%L>7IE4V]U<F-E0V]D92@D9FEL92P@)'-T
M<FEN9RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@=F%L:61A=&4H)'-T871E
M(#T@4$5!4E]604Q)1$%415].3U)-04PI#0H@("`@>PT*("`@("`@("!I9B`H
M(6ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F\I('Q\("%I<U]A<G)A>2@D=&AI
M<RT^7W!A8VMA9V5);F9O*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]V,E9A
M;&ED871O<BD@?'P-"B`@("`@("`@("`@("`@(6ES7V$H)'1H:7,M/E]V,E9A
M;&ED871O<BP@)U!%05)?4&%C:V%G949I;&5?=C)?5F%L:61A=&]R)RDI('L-
M"B`@("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27U!A8VMA9V5&
M:6QE7W8R7U9A;&ED871O<B<I*2![#0H@("`@("`@("`@("`@("`@<F5Q=6ER
M95]O;F-E("=014%2+U!A8VMA9V5&:6QE+W8R+U9A;&ED871O<BYP:'`G.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'1H:7,M/E]V,E9A;&ED871O
M<B`](&YE=R!014%27U!A8VMA9V5&:6QE7W8R7U9A;&ED871O<CL-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG
M>'-D=F5R<VEO;B==*2D@>PT*("`@("`@("`@("`@=6YS970H)'1H:7,M/E]P
M86-K86=E26YF;ULG>'-D=F5R<VEO;B==*3L-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@)'1H:7,M/E]V,E9A;&ED871O<BT^=F%L:61A=&4H)'1H:7,L
M("1S=&%T92D[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T5&%S:W-.<R@I
M#0H@("`@>PT*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?=&%S:W-.<RDI
M('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O
M6R=A='1R:6)S)UTI*2![#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1H
M:7,M/E]P86-K86=E26YF;ULG871T<FEB<R==(&%S("1N86UE(#T^("1V86QU
M92D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H)'9A;'5E(#T]("=H='1P
M.B\O<&5A<BYP:'`N;F5T+V1T9"]T87-K<RTQ+C`G*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W1A<VMS3G,@/2!S=')?<F5P;&%C92@G
M>&UL;G,Z)RP@)R<L("1N86UE*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R
M;B`D=&AI<RT^7W1A<VMS3G,[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M1&5T97)M:6YE('=H971H97(@82!T87-K(&YA;64@:7,@82!V86QI9"!T87-K
M+B`@0W5S=&]M('1A<VMS(&UA>2!B92!D969I;F5D#0H@("`@("H@=7-I;F<@
M<W5B9&ER96-T;W)I97,@8GD@<'5T=&EN9R!A("(M(B!I;B!T:&4@;F%M92P@
M87,@:6X@/'1A<VMS.FUY8W5S=&]M+71A<VL^#0H@("`@("H-"B`@("`@*B!.
M;W1E('1H870@=&AI<R!M971H;V0@=VEL;"!A=71O+6QO860@=&AE('1A<VL@
M8VQA<W,@9FEL92!A;F0@=&5S="!F;W(@=&AE(&5X:7-T96YC90T*("`@("`J
M(&]F('1H92!N86UE('=I=&@@(BTB(')E<&QA8V5D(&)Y(")?(B!A<R!I;B!0
M14%2+U1A<VLO;7EC=7-T;VTO=&%S:RYP:'`@;6%K97,@8VQA<W,-"B`@("`@
M*B!014%27U1A<VM?;7EC=7-T;VU?=&%S:PT*("`@("`J($!P87)A;2!S=')I
M;F<-"B`@("`@*B!`<F5T=7)N(&)O;VQE86X-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!G971487-K*"1T87-K*0T*("`@('L-"B`@("`@("`@)'1H:7,M/F=E
M=%1A<VMS3G,H*3L-"B`@("`@("`@+R\@=')A;G-F;W)M(&%L;"`G+2<@=&\@
M)R\G(&%N9"`G=&%S:W,Z)R!T;R`G)R!S;R!T87-K<SIR97!L86-E(&)E8V]M
M97,@<F5P;&%C90T*("`@("`@("`D=&%S:R`]('-T<E]R97!L86-E*&%R<F%Y
M*"1T:&ES+3Y?=&%S:W-.<R`N("<Z)RP@)RTG*2P@87)R87DH)R<L("<@)RDL
M("1T87-K*3L-"B`@("`@("`@)'1A<VL@/2!S=')?<F5P;&%C92@G("<L("<O
M)RP@=6-W;W)D<R@D=&%S:RDI.PT*("`@("`@("`D<',@/2`H<W1R=&]L;W=E
M<BAS=6)S='(H4$A07T]3+"`P+"`S*2D@/3T@)W=I;B<I(#\@)SLG(#H@)SHG
M.PT*("`@("`@("!F;W)E86-H("AE>'!L;V1E*"1P<RP@:6YI7V=E="@G:6YC
M;'5D95]P871H)RDI(&%S("1P871H*2![#0H@("`@("`@("`@("!I9B`H9FEL
M95]E>&ES=',H)'!A=&@@+B`B+U!%05(O5&%S:R\D=&%S:RYP:'`B*2D@>PT*
M("`@("`@("`@("`@("`@(&EN8VQU9&5?;VYC92`B4$5!4B]487-K+R1T87-K
M+G!H<"([#0H@("`@("`@("`@("`@("`@)'1A<VL@/2!S=')?<F5P;&%C92@G
M+R<L("=?)RP@)'1A<VLI.PT*("`@("`@("`@("`@("`@(&EF("AC;&%S<U]E
M>&ES=',H(E!%05)?5&%S:U\D=&%S:R(I*2![#0H@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`B4$5!4E]487-K7R1T87-K(CL-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($ME>2UF<FEE;F1L
M>2!A<G)A>5]S<&QI8V4-"B`@("`@*B!`<&%R86T@=&%G;F%M92!T;R!S<&QI
M8V4@82!V86QU92!I;B!B969O<F4-"B`@("`@*B!`<&%R86T@;6EX960@=&AE
M('9A;'5E('1O('-P;&EC92!I;@T*("`@("`J($!P87)A;2!S=')I;F<@=&AE
M(&YE=R!T86<@;F%M90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]K<W!L:6-E
M*"1A<G)A>2P@)&ME>2P@)'9A;'5E+"`D;F5W:V5Y*0T*("`@('L-"B`@("`@
M("`@)&]F9G-E="`](&%R<F%Y7W-E87)C:"@D:V5Y+"!A<G)A>5]K97ES*"1A
M<G)A>2DI.PT*("`@("`@("`D869T97(@/2!A<G)A>5]S;&EC92@D87)R87DL
M("1O9F9S970I.PT*("`@("`@("`D8F5F;W)E(#T@87)R87E?<VQI8V4H)&%R
M<F%Y+"`P+"`D;V9F<V5T*3L-"B`@("`@("`@)&)E9F]R95LD;F5W:V5Y72`]
M("1V86QU93L-"B`@("`@("`@<F5T=7)N(&%R<F%Y7VUE<F=E*"1B969O<F4L
M("1A9G1E<BD[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(&%R
M<F%Y(&$@;&ES="!O9B!P;W-S:6)L92!K97ES+"!I;B!T:&4@;W)D97(@=&AE
M>2!M87D@;V-C=7(-"B`@("`@*B!`<&%R86T@;6EX960@8V]N=&5N=',@;V8@
M=&AE(&YE=R!P86-K86=E+GAM;"!T86<-"B`@("`@*B!`<&%R86T@<W1R:6YG
M('1A9R!N86UE#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@7VEN<V5R=$)E9F]R92@D87)R87DL("1K97ES+"`D8V]N
M=&5N=',L("1N97=K97DI#0H@("`@>PT*("`@("`@("!F;W)E86-H("@D:V5Y
M<R!A<R`D:V5Y*2![#0H@("`@("`@("`@("!I9B`H:7-S970H)&%R<F%Y6R1K
M97E=*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D87)R87D@/2`D=&AI
M<RT^7VMS<&QI8V4H)&%R<F%Y+"`D:V5Y+"`D8V]N=&5N=',L("1N97=K97DI
M.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1A<G)A>5LD
M;F5W:V5Y72`]("1C;VYT96YT<SL-"B`@("`@("`@<F5T=7)N("1A<G)A>3L-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W5B<V5C=&EO;B!O
M9B![0&QI;FL@)%]P86-K86=E26YF;WT-"B`@("`@*B!`<&%R86T@87)R87E\
M<W1R:6YG('1A9R!C;VYT96YT<PT*("`@("`J($!P87)A;2!A<G)A>2!F;W)M
M870Z#0H@("`@("H@/'!R93X-"B`@("`@*B!A<G)A>2@-"B`@("`@*B`@('1A
M9VYA;64@/3X@87)R87DH;&ES="!O9B!T86<@;F%M97,@=&AA="!F;VQL;W<@
M=&AI<R!O;F4I+`T*("`@("`J("`@8VAI;&1T86=N86UE(#T^(&%R<F%Y*&QI
M<W0@;V8@8VAI;&0@=&%G(&YA;65S('1H870@9F]L;&]W('1H:7,@;VYE*2P-
M"B`@("`@*B`I#0H@("`@("H@/"]P<F4^#0H@("`@("H-"B`@("`@*B!4:&ES
M(&%L;&]W<R!C;VYS=')U8W1I;VX@;V8@;F5S=&5D('1A9W,-"B`@("`@*B!`
M86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?;65R9V54
M86<H)&UA;FEP+"`D8V]N=&5N=',L("1O<F1E<BD-"B`@("![#0H@("`@("`@
M(&EF("AC;W5N="@D;W)D97(I*2![#0H@("`@("`@("`@("!F;W)E86-H("@D
M;W)D97(@87,@)'1A9R`]/B`D8W5R;W)D97(I('L-"B`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1M86YI<%LD=&%G72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@+R\@96YS=7)E('1H870@=&AE('1A9R!I<R!S970@=7`-"B`@("`@
M("`@("`@("`@("`@("`@)&UA;FEP(#T@)'1H:7,M/E]I;G-E<G1"969O<F4H
M)&UA;FEP+"`D8W5R;W)D97(L(&%R<F%Y*"DL("1T86<I.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)&]R9&5R*2`^
M(#$I('L-"B`@("`@("`@("`@("`@("`@("`@)&UA;FEP6R1T86==(#T@)'1H
M:7,M/E]M97)G951A9R@D;6%N:7!;)'1A9UTL("1C;VYT96YT<RP@87)R87E?
M<VQI8V4H)&]R9&5R+"`Q*2D[#0H@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D;6%N:7`[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@<F5T=7)N("1M86YI<#L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-?87)R87DH)&UA;FEP6R1T86==
M*2`F)B`A96UP='DH)&UA;FEP6R1T86==*2`F)B!I<W-E="@D;6%N:7!;)'1A
M9UU;,%TI*2![#0H@("`@("`@("`@("`D;6%N:7!;)'1A9UU;72`]("1C;VYT
M96YT<SL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(&EF("@A8V]U
M;G0H)&UA;FEP6R1T86==*2D@>PT*("`@("`@("`@("`@("`@("1M86YI<%LD
M=&%G72`]("1C;VYT96YT<SL-"B`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@)&UA;FEP6R1T86==(#T@87)R87DH)&UA;FEP6R1T86==
M*3L-"B`@("`@("`@("`@("`@("`D;6%N:7!;)'1A9UU;72`]("1C;VYT96YT
M<SL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M)&UA;FEP.PT*("`@('T-"GT-"C\^#0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]014%2+U!A8VMA9V5&:6QE+W8Q+G!H<```````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,30U-#8V(#$P-3$U-#,S-S,R(#`R,C0R-@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`T*+RHJ#0H@*B!014%27U!A8VMA9V5&:6QE7W8Q+"!P86-K86=E+GAM;"!V
M97)S:6]N(#$N,`T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*
M("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E
M<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I
M;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO
M=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N
M='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H
M92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR
M;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N
M<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@
M(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP
M+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P
M#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S
M7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@
M)$ED.B!V,2YP:'`L=B`Q+C8Y(#(P,#8O,#,O,#(@,3@Z,30Z,3,@8V5L;&]G
M($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A
M8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN
M8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"B\J*@T*("H@1F]R(&5R<F]R(&AA
M;F1L:6YG#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!4B]%<G)O<E-T86-K+G!H
M<"<[#0H-"B\J*@T*("H@17)R;W(@8V]D92!I9B!P87)S:6YG(&ES(&%T=&5M
M<'1E9"!W:71H(&YO('AM;"!E>'1E;G-I;VX-"B`J+PT*9&5F:6YE*"=014%2
M7U!!0TM!1T5&24Q%7T524D]27TY/7UA-3%]%6%0G+"`S*3L-"@T*+RHJ#0H@
M*B!%<G)O<B!C;V1E(&EF(&-R96%T:6YG('1H92!X;6P@<&%R<V5R(')E<V]U
M<F-E(&9A:6QS#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/
M4E]#04Y47TU!2T5?4$%24T52)RP@-"D[#0H-"B\J*@T*("H@17)R;W(@8V]D
M92!U<V5D(&9O<B!A;&P@<V%X('AM;"!P87)S:6YG(&5R<F]R<PT*("HO#0ID
M969I;F4H)U!%05)?4$%#2T%'149)3$5?15)23U)?4$%24T527T524D]2)RP@
M-2D[#0H-"B\J*@T*("H@17)R;W(@8V]D92!U<V5D('=H96X@=&AE<F4@:7,@
M;F\@;F%M90T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)3$5?15)23U)?
M3D]?3D%-12<L(#8I.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!A('!A
M8VMA9V4@;F%M92!I<R!N;W0@=F%L:60-"B`J+PT*9&5F:6YE*"=014%27U!!
M0TM!1T5&24Q%7T524D]27TE.5D%,241?3D%-12<L(#<I.PT*#0HO*BH-"B`J
M($5R<F]R(&-O9&4@=7-E9"!W:&5N(&YO('-U;6UA<GD@:7,@<&%R<V5D#0H@
M*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]354U-05)9
M)RP@."D[#0H-"B\J*@T*("H@17)R;W(@8V]D92!F;W(@<W5M;6%R:65S('1H
M870@87)E(&UO<F4@=&AA;B`Q(&QI;F4-"B`J+PT*9&5F:6YE*"=014%27U!!
M0TM!1T5&24Q%7T524D]27TU53%1)3$E.15]354U-05)9)RP@.2D[#0H-"B\J
M*@T*("H@17)R;W(@8V]D92!U<V5D('=H96X@;F\@9&5S8W)I<'1I;VX@:7,@
M<')E<V5N=`T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)3$5?15)23U)?
M3D]?1$530U))4%1)3TXG+"`Q,"D[#0H-"B\J*@T*("H@17)R;W(@8V]D92!U
M<V5D('=H96X@;F\@;&EC96YS92!I<R!P<F5S96YT#0H@*B\-"F1E9FEN92@G
M4$5!4E]004-+04=%1DE,15]%4E)/4E].3U],24-%3E-%)RP@,3$I.PT*#0HO
M*BH-"B`J($5R<F]R(&-O9&4@=7-E9"!W:&5N(&$@/'9E<G-I;VX^('9E<G-I
M;VX@;G5M8F5R(&ES(&YO="!P<F5S96YT#0H@*B\-"F1E9FEN92@G4$5!4E]0
M04-+04=%1DE,15]%4E)/4E].3U]615)324].)RP@,3(I.PT*#0HO*BH-"B`J
M($5R<F]R(&-O9&4@=7-E9"!W:&5N(&$@/'9E<G-I;VX^('9E<G-I;VX@;G5M
M8F5R(&ES(&EN=F%L:60-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%
M7T524D]27TE.5D%,241?5D524TE/3B<L(#$S*3L-"@T*+RHJ#0H@*B!%<G)O
M<B!C;V1E('=H96X@<F5L96%S92!S=&%T92!I<R!M:7-S:6YG#0H@*B\-"F1E
M9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]35$%412<L(#$T*3L-
M"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@<F5L96%S92!S=&%T92!I<R!I
M;G9A;&ED#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/4E])
M3E9!3$E$7U-4051%)RP@,34I.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE
M;B!R96QE87-E('-T871E(&ES(&UI<W-I;F<-"B`J+PT*9&5F:6YE*"=014%2
M7U!!0TM!1T5&24Q%7T524D]27TY/7T1!5$4G+"`Q-BD[#0H-"B\J*@T*("H@
M17)R;W(@8V]D92!W:&5N(')E;&5A<V4@<W1A=&4@:7,@:6YV86QI9`T*("HO
M#0ID969I;F4H)U!%05)?4$%#2T%'149)3$5?15)23U)?24Y604Q)1%]$051%
M)RP@,3<I.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!N;R!R96QE87-E
M(&YO=&5S(&%R92!F;W5N9`T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)
M3$5?15)23U)?3D]?3D]415,G+"`Q."D[#0H-"B\J*@T*("H@17)R;W(@8V]D
M92!W:&5N(&YO(&UA:6YT86EN97)S(&%R92!F;W5N9`T*("HO#0ID969I;F4H
M)U!%05)?4$%#2T%'149)3$5?15)23U)?3D]?34%)3E1!24Y%4E,G+"`Q.2D[
M#0H-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(&$@;6%I;G1A:6YE<B!H87,@
M;F\@:&%N9&QE#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/
M4E].3U]-04E.5$A!3D1,12<L(#(P*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E
M('=H96X@82!M86EN=&%I;F5R(&AA<R!N;R!H86YD;&4-"B`J+PT*9&5F:6YE
M*"=014%27U!!0TM!1T5&24Q%7T524D]27TY/7TU!24Y44D],12<L(#(Q*3L-
M"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@82!M86EN=&%I;F5R(&AA<R!N
M;R!N86UE#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/4E].
M3U]-04E.5$Y!344G+"`R,BD[#0H-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N
M(&$@;6%I;G1A:6YE<B!H87,@;F\@96UA:6P-"B`J+PT*9&5F:6YE*"=014%2
M7U!!0TM!1T5&24Q%7T524D]27TY/7TU!24Y414U!24PG+"`R,RD[#0H-"B\J
M*@T*("H@17)R;W(@8V]D92!W:&5N(&$@;6%I;G1A:6YE<B!H87,@;F\@:&%N
M9&QE#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/4E])3E9!
M3$E$7TU!24Y44D],12<L(#(T*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('=H
M96X@82!D97!E;F1E;F-Y(&ES(&YO="!A(%!(4"!D97!E;F1E;F-Y+"!B=70@
M:&%S(&YO(&YA;64-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T52
M4D]27TY/7T1%4$Y!344G+"`R-2D[#0H-"B\J*@T*("H@17)R;W(@8V]D92!W
M:&5N(&$@9&5P96YD96YC>2!H87,@;F\@='EP92`H<&MG+"!P:'`L(&5T8RXI
M#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]$15!4
M65!%)RP@,C8I.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!A(&1E<&5N
M9&5N8WD@:&%S(&YO(')E;&%T:6]N("AL="P@9V4L(&AA<RP@971C+BD-"B`J
M+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T524D]27TY/7T1%4%)%3"<L
M(#(W*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@82!D97!E;F1E;F-Y
M(&ES(&YO="!A("=H87,G(')E;&%T:6]N+"!B=70@:&%S(&YO('9E<G-I;VX-
M"B`J+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T524D]27TY/7T1%4%9%
M4E-)3TXG+"`R."D[#0H-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(&$@9&5P
M96YD96YC>2!H87,@86X@:6YV86QI9"!R96QA=&EO;@T*("HO#0ID969I;F4H
M)U!%05)?4$%#2T%'149)3$5?15)23U)?24Y604Q)1%]$15!214PG+"`R.2D[
M#0H-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(&$@9&5P96YD96YC>2!H87,@
M86X@:6YV86QI9"!T>7!E#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,
M15]%4E)/4E])3E9!3$E$7T1%4%194$4G+"`S,"D[#0H-"B\J*@T*("H@17)R
M;W(@8V]D92!W:&5N(&$@9&5P96YD96YC>2!H87,@86X@:6YV86QI9"!O<'1I
M;VYA;"!O<'1I;VX-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T52
M4D]27TE.5D%,241?1$503U!424].04PG+"`S,2D[#0H-"B\J*@T*("H@17)R
M;W(@8V]D92!W:&5N(&$@9&5P96YD96YC>2!I<R!A('!K9R!D97!E;F1E;F-Y
M+"!A;F0@:&%S(&%N(&EN=F%L:60@<&%C:V%G92!N86UE#0H@*B\-"F1E9FEN
M92@G4$5!4E]004-+04=%1DE,15]%4E)/4E])3E9!3$E$7T1%4$Y!344G+"`S
M,BD[#0H-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(&$@9&5P96YD96YC>2!H
M87,@82!C:&%N;F5L/2)F;V\B(&%T=')I8G5T92P@86YD(&9O;R!I<R!N;W0@
M82!R96=I<W1E<F5D(&-H86YN96P-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!
M1T5&24Q%7T524D]27U5.2TY/5TY?1$500TA!3DY%3"<L(#,S*3L-"@T*+RHJ
M#0H@*B!%<G)O<B!C;V1E('=H96X@<F5L/2)H87,B(&%N9"!V97)S:6]N(&%T
M=')I8G5T92!I<R!P<F5S96YT+@T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'
M149)3$5?15)23U)?1$505D524TE/3E])1TY/4D5$)RP@,S0I.PT*#0HO*BH-
M"B`J($5R<F]R(&-O9&4@=VAE;B!T>7!E/2)P:'`B(&%N9"!D97!E;F1E;F-Y
M(&YA;64@:7,@<')E<V5N=`T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)
M3$5?15)23U)?1$503D%-15])1TY/4D5$)RP@,S4I.PT*#0HO*BH-"B`J($5R
M<F]R(&-O9&4@=VAE;B!A(&-O;F9I9W5R92!O<'1I;VX@:&%S(&YO(&YA;64-
M"B`J+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T524D]27TY/7T-/3D9.
M04U%)RP@,S8I.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!A(&-O;F9I
M9W5R92!O<'1I;VX@:&%S(&YO(&YA;64-"B`J+PT*9&5F:6YE*"=014%27U!!
M0TM!1T5&24Q%7T524D]27TY/7T-/3D904D]-4%0G+"`S-RD[#0H-"B\J*@T*
M("H@17)R;W(@8V]D92!W:&5N(&$@9FEL92!I;B!T:&4@9FEL96QI<W0@:&%S
M(&%N(&EN=F%L:60@<F]L90T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)
M3$5?15)23U)?24Y604Q)1%]&24Q%4D],12<L(#,X*3L-"@T*+RHJ#0H@*B!%
M<G)O<B!C;V1E('=H96X@82!F:6QE(&EN('1H92!F:6QE;&ES="!H87,@;F\@
M<F]L90T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)3$5?15)23U)?3D]?
M1DE,15)/3$4G+"`S.2D[#0H-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(&%N
M86QY>FEN9R!A('!H<"!S;W5R8V4@9FEL92!T:&%T(&AA<R!P87)S92!E<G)O
M<G,-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T524D]27TE.5D%,
M241?4$A01DE,12<L(#0P*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@
M86YA;'EZ:6YG(&$@<&AP('-O=7)C92!F:6QE(')E=F5A;',@82!S;W5R8V4@
M96QE;65N=`T*("H@=VET:&]U="!A('!A8VMA9V4@;F%M92!P<F5F:7@-"B`J
M+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T524D]27TY/7U!.04U%7U!2
M149)6"<L(#0Q*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@86X@=6YK
M;F]W;B!C:&%N;F5L(&ES('-P96-I9FEE9`T*("HO#0ID969I;F4H)U!%05)?
M4$%#2T%'149)3$5?15)23U)?54Y+3D]73E]#2$%.3D5,)RP@-#(I.PT*#0HO
M*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!N;R!F:6QE<R!A<F4@9F]U;F0@:6X@
M=&AE(&9I;&5L:7-T#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%
M4E)/4E].3U]&24Q%4R<L(#0S*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('=H
M96X@82!F:6QE(&ES(&YO="!V86QI9"!P:'`@86-C;W)D:6YG('1O(%]A;F%L
M>7IE4V]U<F-E0V]D92@I#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,
M15]%4E)/4E])3E9!3$E$7T9)3$4G+"`T-"D[#0H-"B\J*@T*("H@17)R;W(@
M8V]D92!W:&5N('1H92!C:&%N;F5L('9A;&ED871O<B!R971U<FYS(&%N(&5R
M<F]R(&]R('=A<FYI;F<-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%
M7T524D]27T-(04Y.14Q604PG+"`T-2D[#0H-"B\J*@T*("H@17)R;W(@8V]D
M92!W:&5N(&$@<&AP-2!P86-K86=E(&ES('!A8VMA9V5D(&EN('!H<#0@*&%N
M86QY<VES(&1O97-N)W0@=V]R:RD-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!
M1T5&24Q%7T524D]27U!(4#4G+"`T-BD[#0H-"B\J*@T*("H@17)R;W(@8V]D
M92!W:&5N(&$@9FEL92!I<R!L:7-T960@:6X@<&%C:V%G92YX;6P@8G5T(&1O
M97,@;F]T(&5X:7-T#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%
M4E)/4E]&24Q%7TY/5$9/54Y$)RP@-#<I.PT*#0HO*BH-"B`J($5R<F]R(&-O
M9&4@=VAE;B!A(#QD97`@='EP93TB<&AP(B!R96P](FYO="(N+BX@:7,@96YC
M;W5N=&5R960@*'5S92!R96P](FYE(BD-"B`J+PT*9&5F:6YE*"=014%27U!!
M0TM!1T5&24Q%7U!(4%].3U].3U0G+"`T."D[#0H-"B\J*@T*("H@17)R;W(@
M8V]D92!W:&5N(&$@<&%C:V%G92YX;6P@8V]N=&%I;G,@;F]N+4E33RTX.#4Y
M+3$@8VAA<F%C=&5R<PT*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)3$5?
M15)23U)?3D].7TE33U]#2$%24R<L(#0Y*3L-"@T*+RHJ#0H@*B!%<G)O<B!C
M;V1E('=H96X@82!D97!E;F1E;F-Y(&ES(&YO="!A("=H87,G(')E;&%T:6]N
M+"!B=70@:&%S(&YO('9E<G-I;VX-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!
M1T5&24Q%7T524D]27TY/7T1%4%!(4%9%4E-)3TXG+"`U,"D[#0H-"B\J*@T*
M("H@17)R;W(@8V]D92!W:&5N(&$@<&%C:V%G92!H87,@;F\@;&5A9"!D979E
M;&]P97(-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T524D]27TY/
M7TQ%040G+"`U,2D[#0H-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(&$@9FEL
M96YA;64@8F5G:6YS('=I=&@@(BXB#0H@*B\-"F1E9FEN92@G4$5!4E]004-+
M04=%1DE,15]%4E)/4E])3E9!3$E$7T9)3$5.04U%)RP@-3(I.PT*+RHJ#0H@
M*B!P86-K86=E+GAM;"!E;F-A<'-U;&%T;W(-"B`J($!C871E9V]R>2`@('!E
M87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@
M0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M
M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J
M($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H
M='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@
M("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO
M#0IC;&%S<R!014%27U!A8VMA9V5&:6QE7W8Q#0I[#0H@("`@+RHJ#0H@("`@
M("H@0&%C8V5S<R!P<FEV871E#0H@("`@("H@0'9A<B!014%27T5R<F]R4W1A
M8VL-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!V87(@
M)%]S=&%C:SL-"@T*("`@("\J*@T*("`@("`J($$@<F5G:7-T<GD@;V)J96-T
M+"!U<V5D('1O(&%C8V5S<R!T:&4@<&%C:V%G92!N86UE('9A;&ED871I;VX@
M<F5G97@@9F]R(&YO;BUS=&%N9&%R9"!C:&%N;F5L<PT*("`@("`J($!V87(@
M4$5!4E]296=I<W1R>0T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J
M+PT*("`@('9A<B`D7W)E9VES=')Y.PT*#0H@("`@+RHJ#0H@("`@("H@06X@
M;V)J96-T('1H870@8V]N=&%I;G,@82!L;V<@;65T:&]D('1H870@;6%T8VAE
M<R!014%27T-O;6UO;CHZ;&]G)W,@<VEG;F%T=7)E#0H@("`@("H@0'9A<B!O
M8FIE8W0-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!V
M87(@)%]L;V=G97([#0H-"B`@("`O*BH-"B`@("`@*B!087)S960@<&%C:V%G
M92!I;F9O<FUA=&EO;@T*("`@("`J($!V87(@87)R87D-"B`@("`@*B!`86-C
M97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!V87(@)%]P86-K86=E26YF;SL-
M"@T*("`@("\J*@T*("`@("`J('!A=&@@=&\@<&%C:V%G92YX;6P-"B`@("`@
M*B!`=F%R('-T<FEN9PT*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J
M+PT*("`@('9A<B`D7W!A8VMA9V5&:6QE.PT*#0H@("`@+RHJ#0H@("`@("H@
M<&%T:"!T;R!P86-K86=E("YT9WH@;W(@9F%L<V4@:68@=&AI<R!I<R!A(&QO
M8V%L+V5X=')A8W1E9"!P86-K86=E+GAM;`T*("`@("`J($!V87(@<W1R:6YG
M#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?
M87)C:&EV949I;&4[#0H-"B`@("`O*BH-"B`@("`@*B!`=F%R(&EN=`T*("`@
M("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D7VES5F%L
M:60@/2`P.PT*#0H@("`@+RHJ#0H@("`@("H@1&5T97)M:6YE<R!W:&5T:&5R
M('1H:7,@<&%C:V%G969I;&4@=V%S(&EN:71I86QI>F5D(&]N;'D@=VET:"!P
M87)T:6%L('!A8VMA9V4@:6YF;PT*("`@("`J#0H@("`@("H@268@=&AI<R!P
M86-K86=E(&9I;&4@=V%S(&-O;G-T<G5C=&5D('9I82!P87)S:6YG(%)%4U0L
M(&ET('=I;&P@;VYL>2!C;VYT86EN#0H@("`@("H-"B`@("`@*B`M('!A8VMA
M9V4@;F%M90T*("`@("`J("T@8VAA;FYE;"!N86UE#0H@("`@("H@+2!D97!E
M;F1E;F-I97,@#0H@("`@("H@0'9A<B!B;V]L96%N#0H@("`@("H@0&%C8V5S
M<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?:6YC;VUP;&5T92`]('1R
M=64[#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@8F]O;"!D971E<FUI;F5S
M('=H971H97(@=&\@<F5T=7)N(&$@4$5!4E]%<G)O<B!O8FIE8W0L(&]R('5S
M92!T:&4@4$5!4E]%<G)O<E-T86-K#0H@("`@("H@0'!A<F%M('-T<FEN9R!.
M86UE(&]F($5R<F]R(%-T86-K(&-L87-S('1O('5S92X-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!014%27U!A8VMA9V5&:6QE7W8Q*"D-"B`@("![#0H@("`@
M("`@("1T:&ES+3Y?<W1A8VL@/2`F;F5W(%!%05)?17)R;W)3=&%C:R@G4$5!
M4E]086-K86=E1FEL95]V,2<I.PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YS
M971%<G)O<DUE<W-A9V5496UP;&%T92@D=&AI<RT^7V=E=$5R<F]R365S<V%G
M92@I*3L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("!]#0H-
M"B`@("!F=6YC=&EO;B!I;G-T86QL0FEN87)Y*"1I;G-T86QL97(I#0H@("`@
M>PT*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@:7-%>'1E;G-I;VXH)&YA;64I#0H@("`@>PT*("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T0V]N9FEG*"8D8V]N
M9FEG*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]C;VYF:6<@/2`F)&-O;F9I
M9SL-"B`@("`@("`@)'1H:7,M/E]R96=I<W1R>2`]("8D8V]N9FEG+3YG9712
M96=I<W1R>2@I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E=%)E<75E<W1E
M9$=R;W5P*"D-"B`@("![#0H@("`@("`@("\O('!L86-E:&]L9&5R#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@1F]R('-A=FEN9R!I;B!T:&4@<F5G:7-T
M<GDN#0H@("`@("H-"B`@("`@*B!3970@=&AE(&QA<W0@=F5R<VEO;B!T:&%T
M('=A<R!I;G-T86QL960-"B`@("`@*B!`<&%R86T@<W1R:6YG#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@<V5T3&%S=$EN<W1A;&QE9%9E<G-I;VXH)'9E<G-I
M;VXI#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=?;&%S
M='9E<G-I;VXG72`]("1V97)S:6]N.PT*("`@('T-"@T*("`@("\J*@T*("`@
M("`J($!R971U<FX@<W1R:6YG?&9A;'-E#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@9V5T3&%S=$EN<W1A;&QE9%9E<G-I;VXH*0T*("`@('L-"B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)U]L87-T=F5R<VEO;B==
M*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];
M)U]L87-T=F5R<VEO;B==.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F
M86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971);G-T86QL961":6YA
M<GDH*0T*("`@('L-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*
M("`@(&9U;F-T:6]N(&QI<W10;W-T:6YS=&%L;%-C<FEP=',H*0T*("`@('L-
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N
M(&EN:710;W-T:6YS=&%L;%-C<FEP=',H*0T*("`@('L-"B`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E=$QO9V=E<B@F
M)&QO9V=E<BD-"B`@("![#0H@("`@("`@(&EF("@D;&]G9V5R("8F("@A:7-?
M;V)J96-T*"1L;V=G97(I('Q\("%M971H;V1?97AI<W1S*"1L;V=G97(L("=L
M;V<G*2DI('L-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"=,;V=G97(@;75S="!B92!C;VUP871I8FQE('=I=&@@4$5!4E]#;VUM;VXZ
M.FQO9R<I.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?;&]G9V5R(#T@
M)B1L;V=G97([#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T4&%C:V%G969I
M;&4H)&9I;&4L("1A<F-H:79E(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D
M=&AI<RT^7W!A8VMA9V5&:6QE(#T@)&9I;&4[#0H@("`@("`@("1T:&ES+3Y?
M87)C:&EV949I;&4@/2`D87)C:&EV92`_("1A<F-H:79E(#H@)&9I;&4[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T4&%C:V%G949I;&4H*0T*("`@('L-
M"B`@("`@("`@<F5T=7)N(&ES<V5T*"1T:&ES+3Y?<&%C:V%G949I;&4I(#\@
M)'1H:7,M/E]P86-K86=E1FEL92`Z(&9A;'-E.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N(&=E=%!A8VMA9V54>7!E*"D-"B`@("![#0H@("`@("`@(')E='5R
M;B`G<&AP)SL-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971!<F-H:79E1FEL
M92@I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/E]A<F-H:79E1FEL
M93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!P86-K86=E26YF;R@D9FEE;&0I
M#0H@("`@>PT*("`@("`@("!I9B`H(6ES7W-T<FEN9R@D9FEE;&0I('Q\(&5M
M<'1Y*"1F:65L9"D@?'P-"B`@("`@("`@("`@("%I<W-E="@D=&AI<RT^7W!A
M8VMA9V5);F9O6R1F:65L9%TI*2![#0H@("`@("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G
M94EN9F];)&9I96QD73L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!S971$:7)T
M<F5E*"1P871H*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF
M;ULG9&ER=')E92==6R1P871H72`]('1R=64[#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@9V5T1&ER=')E92@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]P86-K86=E26YF;ULG9&ER=')E92==*2`F)B!C;W5N="@D=&AI
M<RT^7W!A8VMA9V5);F9O6R=D:7)T<F5E)UTI*2![#0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULG9&ER=')E92==.PT*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!R97-E=$1I<G1R964H*0T*("`@('L-"B`@("`@("`@=6YS970H)'1H
M:7,M/E]P86-K86=E26YF;ULG9&ER=')E92==*3L-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!F<F]M07)R87DH)'!I;F9O*0T*("`@('L-"B`@("`@("`@)'1H
M:7,M/E]I;F-O;7!L971E(#T@9F%L<V4[#0H@("`@("`@("1T:&ES+3Y?<&%C
M:V%G94EN9F\@/2`D<&EN9F\[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@:7-)
M;F-O;7!L971E*"D-"B`@("![#0H@("`@("`@(')E='5R;B`D=&AI<RT^7VEN
M8V]M<&QE=&4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T0VAA;FYE;"@I
M#0H@("`@>PT*("`@("`@("!R971U<FX@)W!E87(N<&AP+FYE="<[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@9V5T57)I*"D-"B`@("![#0H@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G9714:6UE*"D-
M"B`@("![#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!G971%>'1E;F1S*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7W!A8VMA9V5);F9O6R=E>'1E;F1S)UTI*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULG97AT96YD<R==.PT*
M("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@
M("`O*BH-"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@=&]!<G)A>2@I#0H@("`@>PT*("`@("`@("!I9B`H(21T:&ES+3YV
M86QI9&%T92A014%27U9!3$E$051%7TY/4DU!3"DI('L-"B`@("`@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'1H
M:7,M/F=E=$%R<F%Y*"D[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T07)R
M87DH*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN
M9F\[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T3F%M92@I#0H@("`@>PT*
M("`@("`@("!R971U<FX@)'1H:7,M/F=E=%!A8VMA9V4H*3L-"B`@("!]#0H-
M"B`@("!F=6YC=&EO;B!G971086-K86=E*"D-"B`@("![#0H@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=P86-K86=E)UTI*2![#0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULG<&%C:V%G
M92==.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!705).24Y'("T@9&]N)W0@=7-E('1H:7,@
M=6YL97-S('EO=2!K;F]W('=H870@>6]U(&%R92!D;VEN9PT*("`@("`J+PT*
M("`@(&9U;F-T:6]N('-E=%)A=U!A8VMA9V4H)'!A8VMA9V4I#0H@("`@>PT*
M("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=P86-K86=E)UT@/2`D<&%C
M:V%G93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!S971086-K86=E*"1P86-K
M86=E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG<&%C
M:V%G92==(#T@)'!A8VMA9V4[#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`]
M(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=%9E<G-I;VXH*0T*
M("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];
M)W9E<G-I;VXG72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A
M8VMA9V5);F9O6R=V97)S:6]N)UT[#0H@("`@("`@('T-"B`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E=%9E<G-I;VXH
M)'9E<G-I;VXI#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O
M6R=V97)S:6]N)UT@/2`D=F5R<VEO;CL-"B`@("`@("`@)'1H:7,M/E]I<U9A
M;&ED(#T@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@8VQE87)-86EN
M=&%I;F5R<R@I#0H@("`@>PT*("`@("`@("!U;G-E="@D=&AI<RT^7W!A8VMA
M9V5);F9O6R=M86EN=&%I;F5R<R==*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!G971-86EN=&%I;F5R<R@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]P86-K86=E26YF;ULG;6%I;G1A:6YE<G,G72DI('L-"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=M86EN=&%I;F5R
M<R==.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!!9&1S(&$@;F5W(&UA:6YT86EN97(@+2!N
M;R!C:&5C:VEN9R!O9B!D=7!L:6-A=&5S(&ES('!E<F9O<FUE9"P@=7-E#0H@
M("`@("H@=7!D871E;6%I;G1A:6YE<B!F;W(@=&AA="!P=7)P;W-E+@T*("`@
M("`J+PT*("`@(&9U;F-T:6]N(&%D9$UA:6YT86EN97(H)')O;&4L("1H86YD
M;&4L("1N86UE+"`D96UA:6PI#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W!A
M8VMA9V5);F9O6R=M86EN=&%I;F5R<R==6UT@/0T*("`@("`@("`@("`@87)R
M87DH)VAA;F1L92<@/3X@)&AA;F1L92P@)W)O;&4G(#T^("1R;VQE+"`G96UA
M:6PG(#T^("1E;6%I;"P@)VYA;64G(#T^("1N86UE*3L-"B`@("`@("`@)'1H
M:7,M/E]I<U9A;&ED(#T@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M=7!D871E36%I;G1A:6YE<B@D<F]L92P@)&AA;F1L92P@)&YA;64L("1E;6%I
M;"D-"B`@("![#0H@("`@("`@("1F;W5N9"`](&9A;'-E.PT*("`@("`@("!I
M9B`H(6ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)VUA:6YT86EN97)S)UTI
M('Q\#0H@("`@("`@("`@("`@("%I<U]A<G)A>2@D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=M86EN=&%I;F5R<R==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YA9&1-86EN=&%I;F5R*"1R;VQE+"`D:&%N9&QE+"`D;F%M92P@)&5M
M86EL*3L-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D=&AI<RT^7W!A
M8VMA9V5);F9O6R=M86EN=&%I;F5R<R==(&%S("1I(#T^("1M86EN=&%I;F5R
M*2![#0H@("`@("`@("`@("!I9B`H)&UA:6YT86EN97);)VAA;F1L92==(#T]
M("1H86YD;&4I('L-"B`@("`@("`@("`@("`@("`D9F]U;F0@/2`D:3L-"B`@
M("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H)&9O=6YD("$]/2!F86QS92D@>PT*("`@("`@("`@
M("`@=6YS970H)'1H:7,M/E]P86-K86=E26YF;ULG;6%I;G1A:6YE<G,G75LD
M9F]U;F1=*3L-"B`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)VUA
M:6YT86EN97)S)UT@/0T*("`@("`@("`@("`@("`@(&%R<F%Y7W9A;'5E<R@D
M=&AI<RT^7W!A8VMA9V5);F9O6R=M86EN=&%I;F5R<R==*3L-"B`@("`@("`@
M?0T*("`@("`@("`D=&AI<RT^861D36%I;G1A:6YE<B@D<F]L92P@)&AA;F1L
M92P@)&YA;64L("1E;6%I;"D[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9&5L
M971E36%I;G1A:6YE<B@D:&%N9&QE*0T*("`@('L-"B`@("`@("`@)&9O=6YD
M(#T@9F%L<V4[#0H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<&%C:V%G94EN
M9F];)VUA:6YT86EN97)S)UT@87,@)&D@/3X@)&UA:6YT86EN97(I('L-"B`@
M("`@("`@("`@(&EF("@D;6%I;G1A:6YE<ELG:&%N9&QE)UT@/3T@)&AA;F1L
M92D@>PT*("`@("`@("`@("`@("`@("1F;W5N9"`]("1I.PT*("`@("`@("`@
M("`@("`@(&)R96%K.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@(&EF("@D9F]U;F0@(3T](&9A;'-E*2![#0H@("`@("`@("`@("!U;G-E
M="@D=&AI<RT^7W!A8VMA9V5);F9O6R=M86EN=&%I;F5R<R==6R1F;W5N9%TI
M.PT*("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG;6%I;G1A:6YE
M<G,G72`]#0H@("`@("`@("`@("`@("`@87)R87E?=F%L=65S*"1T:&ES+3Y?
M<&%C:V%G94EN9F];)VUA:6YT86EN97)S)UTI.PT*("`@("`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=%-T871E*"D-"B`@("![#0H@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=R96QE87-E7W-T
M871E)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E
M26YF;ULG<F5L96%S95]S=&%T92==.PT*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!S971287=3=&%T
M92@D<W1A=&4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O
M6R=R96QE87-E7W-T871E)UT@/2`D<W1A=&4[#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@<V5T4W1A=&4H)'-T871E*0T*("`@('L-"B`@("`@("`@)'1H:7,M
M/E]P86-K86=E26YF;ULG<F5L96%S95]S=&%T92==(#T@)'-T871E.PT*("`@
M("`@("`D=&AI<RT^7VES5F%L:60@/2!F86QS93L-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!G971$871E*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7W!A8VMA9V5);F9O6R=R96QE87-E7V1A=&4G72DI('L-"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=R96QE87-E7V1A
M=&4G73L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@<V5T1&%T92@D9&%T92D-"B`@("![#0H@("`@
M("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)W)E;&5A<V5?9&%T92==(#T@)&1A
M=&4[#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](&9A;'-E.PT*("`@('T-
M"@T*("`@(&9U;F-T:6]N(&=E=$QI8V5N<V4H*0T*("`@('L-"B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W)E;&5A<V5?;&EC96YS
M92==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN
M9F];)W)E;&5A<V5?;&EC96YS92==.PT*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!S971,:6-E;G-E
M*"1D871E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG
M<F5L96%S95]L:6-E;G-E)UT@/2`D9&%T93L-"B`@("`@("`@)'1H:7,M/E]I
M<U9A;&ED(#T@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T4W5M
M;6%R>2@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K
M86=E26YF;ULG<W5M;6%R>2==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<&%C:V%G94EN9F];)W-U;6UA<GDG73L-"B`@("`@("`@?0T*("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T
M4W5M;6%R>2@D<W5M;6%R>2D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<&%C
M:V%G94EN9F];)W-U;6UA<GDG72`]("1S=6UM87)Y.PT*("`@("`@("`D=&AI
M<RT^7VES5F%L:60@/2!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G
M971$97-C<FEP=&EO;B@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]P86-K86=E26YF;ULG9&5S8W)I<'1I;VXG72DI('L-"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=D97-C<FEP=&EO;B==
M.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-
M"B`@("!F=6YC=&EO;B!S971$97-C<FEP=&EO;B@D9&5S8RD-"B`@("![#0H@
M("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<V-R:7!T:6]N)UT@/2`D
M9&5S8SL-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@9F%L<V4[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@9V5T3F]T97,H*0T*("`@('L-"B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W)E;&5A<V5?;F]T97,G
M72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O
M6R=R96QE87-E7VYO=&5S)UT[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E=$YO=&5S*"1N;W1E
M<RD-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)W)E;&5A
M<V5?;F]T97,G72`]("1N;W1E<SL-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED
M(#T@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T1&5P<R@I#0H@
M("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG
M<F5L96%S95]D97!S)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]P86-K86=E26YF;ULG<F5L96%S95]D97!S)UT[#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J
M(%)E<V5T(&1E<&5N9&5N8VEE<R!P<FEO<B!T;R!A9&1I;F<@;F5W(&]N97,-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!C;&5A<D1E<',H*0T*("`@('L-"B`@
M("`@("`@=6YS970H)'1H:7,M/E]P86-K86=E26YF;ULG<F5L96%S95]D97!S
M)UTI.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&%D9%!H<$1E<"@D=F5R<VEO
M;BP@)')E;"D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](&9A
M;'-E.PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=R96QE87-E7V1E
M<',G75M=(#T-"B`@("`@("`@("`@(&%R<F%Y*"=T>7!E)R`]/B`G<&AP)RP-
M"B`@("`@("`@("`@("`@("`@("=R96PG(#T^("1R96PL#0H@("`@("`@("`@
M("`@("`@("`G=F5R<VEO;B<@/3X@)'9E<G-I;VXI.PT*("`@('T-"@T*("`@
M(&9U;F-T:6]N(&%D9%!A8VMA9V5$97`H)&YA;64L("1V97)S:6]N+"`D<F5L
M+"`D;W!T:6]N86P@/2`G;F\G*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]I
M<U9A;&ED(#T@9F%L<V4[#0H@("`@("`@("1D97`@/0T*("`@("`@("`@("`@
M87)R87DH)W1Y<&4G(#T^("=P:V<G+`T*("`@("`@("`@("`@("`@("`@)VYA
M;64G(#T^("1N86UE+`T*("`@("`@("`@("`@("`@("`@)W)E;"<@/3X@)')E
M;"P-"B`@("`@("`@("`@("`@("`@("=O<'1I;VYA;"<@/3X@)&]P=&EO;F%L
M*3L-"B`@("`@("`@:68@*"1R96P@(3T@)VAA<R<@)B8@)')E;"`A/2`G;F]T
M)RD@>PT*("`@("`@("`@("`@)&1E<%LG=F5R<VEO;B==(#T@)'9E<G-I;VX[
M#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG<F5L
M96%S95]D97!S)UU;72`]("1D97`[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M861D17AT96YS:6]N1&5P*"1N86UE+"`D=F5R<VEO;BP@)')E;"P@)&]P=&EO
M;F%L(#T@)VYO)RD-"B`@("![#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`]
M(&9A;'-E.PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=R96QE87-E
M7V1E<',G75M=(#T-"B`@("`@("`@("`@(&%R<F%Y*"=T>7!E)R`]/B`G97AT
M)RP-"B`@("`@("`@("`@("`@("`@("=N86UE)R`]/B`D;F%M92P-"B`@("`@
M("`@("`@("`@("`@("=R96PG(#T^("1R96PL#0H@("`@("`@("`@("`@("`@
M("`G=F5R<VEO;B<@/3X@)'9E<G-I;VXL#0H@("`@("`@("`@("`@("`@("`G
M;W!T:6]N86PG(#T^("1O<'1I;VYA;"D[#0H@("`@?0T*#0H@("`@+RHJ#0H@
M("`@("H@5T%23DE.1R`M(&1O(&YO="!U<V4@=&AI<R!F=6YC=&EO;B!D:7)E
M8W1L>2!U;FQE<W,@>6]U(&MN;W<@=VAA="!Y;W4G<F4@9&]I;F<-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!S971$97!S*"1D97!S*0T*("`@('L-"B`@("`@
M("`@)'1H:7,M/E]P86-K86=E26YF;ULG<F5L96%S95]D97!S)UT@/2`D9&5P
M<SL-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!H87-$97!S*"D-"B`@("![#0H@
M("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=R96QE
M87-E7V1E<',G72D@)B8-"B`@("`@("`@("`@(&-O=6YT*"1T:&ES+3Y?<&%C
M:V%G94EN9F];)W)E;&5A<V5?9&5P<R==*3L-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!G971$97!E;F1E;F-Y1W)O=7`H)&=R;W5P*0T*("`@('L-"B`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&ES0V]M
M<&%T:6)L92@D<&8I#0H@("`@>PT*("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@:7-3=6)P86-K86=E3V8H)'`I#0H@("`@
M>PT*("`@("`@("!R971U<FX@)'`M/FES4W5B<&%C:V%G92@D=&AI<RD[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@:7-3=6)P86-K86=E*"1P*0T*("`@('L-
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N
M(&1E<&5N9'-/;B@D<&%C:V%G92P@)&-H86YN96PI#0H@("`@>PT*("`@("`@
M("!I9B`H<W1R=&]L;W=E<B@D8VAA;FYE;"D@(3T@)W!E87(N<&AP+FYE="<I
M('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H(2@D9&5P<R`]("1T:&ES+3YG971$97!S*"DI*2![#0H@("`@
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@9F]R
M96%C:"`H)&1E<',@87,@)&1E<"D@>PT*("`@("`@("`@("`@:68@*"1D97!;
M)W1Y<&4G72`A/2`G<&MG)RD@>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*'-T<G1O;&]W97(H
M)&1E<%LG;F%M92==*2`]/2!S=')T;VQO=V5R*"1P86-K86=E*2D@>PT*("`@
M("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!G971#;VYF:6=U<F5/<'1I;VYS*"D-"B`@("![#0H@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYF:6=U<F5?;W!T
M:6]N<R==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G
M94EN9F];)V-O;F9I9W5R95]O<'1I;VYS)UT[#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&AA<T-O
M;F9I9W5R94]P=&EO;G,H*0T*("`@('L-"B`@("`@("`@<F5T=7)N(&ES<V5T
M*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;F9I9W5R95]O<'1I;VYS)UTI("8F
M#0H@("`@("`@("`@("!C;W5N="@D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYF
M:6=U<F5?;W!T:6]N<R==*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!A9&1#
M;VYF:6=U<F5/<'1I;VXH)&YA;64L("1P<F]M<'0L("1D969A=6QT(#T@9F%L
M<V4I#0H@("`@>PT*("`@("`@("`D;R`](&%R<F%Y*"=N86UE)R`]/B`D;F%M
M92P@)W!R;VUP="<@/3X@)'!R;VUP="D[#0H@("`@("`@(&EF("@D9&5F875L
M="`A/3T@9F%L<V4I('L-"B`@("`@("`@("`@("1O6R=D969A=6QT)UT@/2`D
M9&5F875L=#L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3Y?<&%C:V%G94EN9F];)V-O;F9I9W5R95]O<'1I;VYS)UTI*2![#0H@("`@
M("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYF:6=U<F5?;W!T:6]N
M<R==(#T@87)R87DH*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7W!A
M8VMA9V5);F9O6R=C;VYF:6=U<F5?;W!T:6]N<R==6UT@/2`D;SL-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!C;&5A<D-O;F9I9W5R94]P=&EO;G,H*0T*("`@
M('L-"B`@("`@("`@=6YS970H)'1H:7,M/E]P86-K86=E26YF;ULG8V]N9FEG
M=7)E7V]P=&EO;G,G72D[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T4')O
M=FED97,H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C
M:V%G94EN9F];)W!R;W9I9&5S)UTI*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/E]P86-K86=E26YF;ULG<')O=FED97,G73L-"B`@("`@("`@?0T*
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M861D1FEL92@D9&ER+"`D9FEL92P@)&%T=')S*0T*("`@('L-"B`@("`@("`@
M)&1I<B`]('!R96=?<F5P;&%C92AA<G)A>2@G(5Q<7%PK(2<L("<A+RLA)RDL
M(&%R<F%Y*"<O)RP@)R\G*2P@)&1I<BD[#0H@("`@("`@(&EF("@D9&ER(#T]
M("<O)R!\?"`D9&ER(#T]("<G*2![#0H@("`@("`@("`@("`D9&ER(#T@)R<[
M#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D9&ER("X]("<O)SL-
M"B`@("`@("`@?0T*("`@("`@("`D9FEL92`]("1D:7(@+B`D9FEL93L-"B`@
M("`@("`@)&9I;&4@/2!P<F5G7W)E<&QA8V4H)R%;7%PO72LA)RP@)R\G+"`D
M9FEL92D[#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V9I;&5L:7-T
M)UU;)&9I;&5=(#T@)&%T=')S.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E
M=$EN<W1A;&QA=&EO;D9I;&5L:7-T*"D-"B`@("![#0H@("`@("`@(')E='5R
M;B`D=&AI<RT^9V5T1FEL96QI<W0H*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!G971&:6QE;&ES="@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]P86-K86=E26YF;ULG9FEL96QI<W0G72DI('L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=F:6QE;&ES="==.PT*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!S971&:6QE071T<FEB=71E*"1F:6QE+"`D871T<BP@)'9A;'5E
M*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG9FEL96QI
M<W0G75LD9FEL95U;)&%T=')=(#T@)'9A;'5E.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N(')E<V5T1FEL96QI<W0H*0T*("`@('L-"B`@("`@("`@)'1H:7,M
M/E]P86-K86=E26YF;ULG9FEL96QI<W0G72`](&%R<F%Y*"D[#0H@("`@?0T*
M#0H@("`@9G5N8W1I;VX@<V5T26YS=&%L;&5D07,H)&9I;&4L("1P871H*0T*
M("`@('L-"B`@("`@("`@:68@*"1P871H*2![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]P86-K86=E26YF;ULG9FEL96QI<W0G75LD9FEL95U;)VEN
M<W1A;&QE9%]A<R==(#T@)'!A=&@[#0H@("`@("`@('T-"B`@("`@("`@=6YS
M970H)'1H:7,M/E]P86-K86=E26YF;ULG9FEL96QI<W0G75LD9FEL95U;)VEN
M<W1A;&QE9%]A<R==*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!I;G-T86QL
M961&:6QE*"1F:6QE+"`D871T<RD-"B`@("![#0H@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7W!A8VMA9V5);F9O6R=F:6QE;&ES="==6R1F:6QE72DI('L-
M"B`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V9I;&5L:7-T)UU;
M)&9I;&5=(#T-"B`@("`@("`@("`@("`@("!A<G)A>5]M97)G92@D=&AI<RT^
M7W!A8VMA9V5);F9O6R=F:6QE;&ES="==6R1F:6QE72P@)&%T=',I.PT*("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF
M;ULG9FEL96QI<W0G75LD9FEL95T@/2`D871T<SL-"B`@("`@("`@?0T*("`@
M('T-"@T*("`@(&9U;F-T:6]N(&=E=$-H86YG96QO9R@I#0H@("`@>PT*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG8VAA;F=E;&]G
M)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF
M;ULG8VAA;F=E;&]G)UT[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=%!A8VMA9V5X;6Q697)S
M:6]N*"D-"B`@("![#0H@("`@("`@(')E='5R;B`G,2XP)SL-"B`@("!]#0H-
M"B`@("`O*BH-"B`@("`@*B!7<F%P<&5R('1O('M`;&EN:R!014%27T5R<F]R
M4W1A8VLZ.F=E=$5R<F]R<R@I?0T*("`@("`J($!P87)A;2!B;V]L96%N(&1E
M=&5R;6EN97,@=VAE=&AE<B!T;R!P=7)G92!T:&4@97)R;W(@<W1A8VL@869T
M97(@<F5T<FEE=FEN9PT*("`@("`J($!R971U<FX@87)R87D-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!G971686QI9&%T:6]N5V%R;FEN9W,H)'!U<F=E(#T@
M=')U92D-"B`@("![#0H@("`@("`@(')E='5R;B`D=&AI<RT^7W-T86-K+3YG
M971%<G)O<G,H)'!U<F=E*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O
M*BH-"B`@("`@*B!686QI9&%T:6]N(&5R<F]R+B`@06QS;R!M87)K<R!T:&4@
M;V)J96-T(&-O;G1E;G1S(&%S(&EN=F%L:60-"B`@("`@*B!`<&%R86T@97)R
M;W(@8V]D90T*("`@("`J($!P87)A;2!A<G)A>2!E<G)O<B!I;F9O<FUA=&EO
M;@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T
M:6]N(%]V86QI9&%T945R<F]R*"1C;V1E+"`D<&%R86US(#T@87)R87DH*2D-
M"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H)&-O9&4L("=E
M<G)O<B<L("1P87)A;7,L(&9A;'-E+"!F86QS92P@9&5B=6=?8F%C:W1R86-E
M*"DI.PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2!F86QS93L-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!686QI9&%T:6]N('=A<FYI;F<N("!$;V5S
M(&YO="!M87)K('1H92!O8FIE8W0@8V]N=&5N=',@:6YV86QI9"X-"B`@("`@
M*B!`<&%R86T@97)R;W(@8V]D90T*("`@("`J($!P87)A;2!A<G)A>2!E<G)O
M<B!I;F9O<FUA=&EO;@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J
M+PT*("`@(&9U;F-T:6]N(%]V86QI9&%T95=A<FYI;F<H)&-O9&4L("1P87)A
M;7,@/2!A<G)A>2@I*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^
M<'5S:"@D8V]D92P@)W=A<FYI;F<G+"`D<&%R86US+"!F86QS92P@9F%L<V4L
M(&1E8G5G7V)A8VMT<F%C92@I*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!`<&%R86T@:6YT96=E<B!E<G)O<B!C;V1E#0H@("`@("H@0&%C8V5S<R!P
M<F]T96-T960-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?9V5T17)R;W)-97-S
M86=E*"D-"B`@("![#0H@("`@("`@(')E='5R;B!A<G)A>2@-"B`@("`@("`@
M("`@("`@("!014%27U!!0TM!1T5&24Q%7T524D]27TY/7TY!344@/3X-"B`@
M("`@("`@("`@("`@("`@("`@)TUI<W-I;F<@4&%C:V%G92!.86UE)RP-"B`@
M("`@("`@("`@("`@("!014%27U!!0TM!1T5&24Q%7T524D]27TY/7U-534U!
M4ED@/3X-"B`@("`@("`@("`@("`@("`@("`@)TYO('-U;6UA<GD@9F]U;F0G
M+`T*("`@("`@("`@("`@("`@(%!%05)?4$%#2T%'149)3$5?15)23U)?355,
M5$E,24Y%7U-534U!4ED@/3X-"B`@("`@("`@("`@("`@("`@("`@)U-U;6UA
M<GD@<VAO=6QD(&)E(&]N(&]N92!L:6YE)RP-"B`@("`@("`@("`@("`@("!0
M14%27U!!0TM!1T5&24Q%7T524D]27TY/7T1%4T-225!424].(#T^#0H@("`@
M("`@("`@("`@("`@("`@("=-:7-S:6YG(&1E<V-R:7!T:6]N)RP-"B`@("`@
M("`@("`@("`@("!014%27U!!0TM!1T5&24Q%7T524D]27TY/7TQ)0T5.4T4@
M/3X-"B`@("`@("`@("`@("`@("`@("`@)TUI<W-I;F<@;&EC96YS92<L#0H@
M("`@("`@("`@("`@("`@4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]615)3
M24].(#T^#0H@("`@("`@("`@("`@("`@("`@("=.;R!R96QE87-E('9E<G-I
M;VX@9F]U;F0G+`T*("`@("`@("`@("`@("`@(%!%05)?4$%#2T%'149)3$5?
M15)23U)?3D]?4U1!5$4@/3X-"B`@("`@("`@("`@("`@("`@("`@)TYO(')E
M;&5A<V4@<W1A=&4@9F]U;F0G+`T*("`@("`@("`@("`@("`@(%!%05)?4$%#
M2T%'149)3$5?15)23U)?3D]?1$%412`]/@T*("`@("`@("`@("`@("`@("`@
M("`G3F\@<F5L96%S92!D871E(&9O=6YD)RP-"B`@("`@("`@("`@("`@("!0
M14%27U!!0TM!1T5&24Q%7T524D]27TY/7TY/5$53(#T^#0H@("`@("`@("`@
M("`@("`@("`@("=.;R!R96QE87-E(&YO=&5S(&9O=6YD)RP-"B`@("`@("`@
M("`@("`@("!014%27U!!0TM!1T5&24Q%7T524D]27TY/7TQ%040@/3X-"B`@
M("`@("`@("`@("`@("`@("`@)U!A8VMA9V4@;75S="!H879E(&%T(&QE87-T
M(&]N92!L96%D(&UA:6YT86EN97(G+`T*("`@("`@("`@("`@("`@(%!%05)?
M4$%#2T%'149)3$5?15)23U)?3D]?34%)3E1!24Y%4E,@/3X-"B`@("`@("`@
M("`@("`@("`@("`@)TYO(&UA:6YT86EN97)S(&9O=6YD+"!A="!L96%S="!O
M;F4@;75S="!B92!D969I;F5D)RP-"B`@("`@("`@("`@("`@("!014%27U!!
M0TM!1T5&24Q%7T524D]27TY/7TU!24Y42$%.1$Q%(#T^#0H@("`@("`@("`@
M("`@("`@("`@("=-86EN=&%I;F5R("5I;F1E>"4@:&%S(&YO(&AA;F1L92`H
M=7-E<B!)1"!A="!C:&%N;F5L('-E<G9E<BDG+`T*("`@("`@("`@("`@("`@
M(%!%05)?4$%#2T%'149)3$5?15)23U)?3D]?34%)3E123TQ%(#T^#0H@("`@
M("`@("`@("`@("`@("`@("=-86EN=&%I;F5R("5I;F1E>"4@:&%S(&YO(')O
M;&4G+`T*("`@("`@("`@("`@("`@(%!%05)?4$%#2T%'149)3$5?15)23U)?
M3D]?34%)3E1.04U%(#T^#0H@("`@("`@("`@("`@("`@("`@("=-86EN=&%I
M;F5R("5I;F1E>"4@:&%S(&YO(&YA;64G+`T*("`@("`@("`@("`@("`@(%!%
M05)?4$%#2T%'149)3$5?15)23U)?3D]?34%)3E1%34%)3"`]/@T*("`@("`@
M("`@("`@("`@("`@("`G36%I;G1A:6YE<B`E:6YD97@E(&AA<R!N;R!E;6%I
M;"<L#0H@("`@("`@("`@("`@("`@4$5!4E]004-+04=%1DE,15]%4E)/4E].
M3U]$15!.04U%(#T^#0H@("`@("`@("`@("`@("`@("`@("=$97!E;F1E;F-Y
M("5I;F1E>"4@:7,@;F]T(&$@<&AP(&1E<&5N9&5N8WDL(&%N9"!H87,@;F\@
M;F%M92<L#0H@("`@("`@("`@("`@("`@4$5!4E]004-+04=%1DE,15]%4E)/
M4E].3U]$15!214P@/3X-"B`@("`@("`@("`@("`@("`@("`@)T1E<&5N9&5N
M8WD@)6EN9&5X)2!H87,@;F\@<F5L871I;VX@*')E;"DG+`T*("`@("`@("`@
M("`@("`@(%!%05)?4$%#2T%'149)3$5?15)23U)?3D]?1$505%E012`]/@T*
M("`@("`@("`@("`@("`@("`@("`G1&5P96YD96YC>2`E:6YD97@E(&AA<R!N
M;R!T>7!E)RP-"B`@("`@("`@("`@("`@("!014%27U!!0TM!1T5&24Q%7T52
M4D]27T1%4$Y!345?24=.3U)%1"`]/@T*("`@("`@("`@("`@("`@("`@("`G
M4$A0($1E<&5N9&5N8WD@)6EN9&5X)2!H87,@82!N86UE(&%T=')I8G5T92!O
M9B`B)6YA;64E(B!W:&EC:"!W:6QL(&)E)R`N#0H@("`@("`@("`@("`@("`@
M("`@("`@("`G(&EG;F]R960A)RP-"B`@("`@("`@("`@("`@("!014%27U!!
M0TM!1T5&24Q%7T524D]27TY/7T1%4%9%4E-)3TX@/3X-"B`@("`@("`@("`@
M("`@("`@("`@)T1E<&5N9&5N8WD@)6EN9&5X)2!I<R!N;W0@82!R96P](FAA
M<R(@;W(@<F5L/2)N;W0B(&1E<&5N9&5N8WDL("<@+@T*("`@("`@("`@("`@
M("`@("`@("`@("`@)V%N9"!H87,@;F\@=F5R<VEO;B<L#0H@("`@("`@("`@
M("`@("`@4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]$15!02%!615)324].
M(#T^#0H@("`@("`@("`@("`@("`@("`@("=$97!E;F1E;F-Y("5I;F1E>"4@
M:7,@82!T>7!E/2)P:'`B(&1E<&5N9&5N8WDL("<@+@T*("`@("`@("`@("`@
M("`@("`@("`@("`@)V%N9"!H87,@;F\@=F5R<VEO;B<L#0H@("`@("`@("`@
M("`@("`@4$5!4E]004-+04=%1DE,15]%4E)/4E]$15!615)324].7TE'3D]2
M140@/3X-"B`@("`@("`@("`@("`@("`@("`@)T1E<&5N9&5N8WD@)6EN9&5X
M)2!I<R!A(')E;#TB)7)E;"4B(&1E<&5N9&5N8WDL('9E<G-I;VYI;F<@:7,@
M:6=N;W)E9"<L#0H@("`@("`@("`@("`@("`@4$5!4E]004-+04=%1DE,15]%
M4E)/4E])3E9!3$E$7T1%4$]05$E/3D%,(#T^#0H@("`@("`@("`@("`@("`@
M("`@("=$97!E;F1E;F-Y("5I;F1E>"4@:&%S(&EN=F%L:60@;W!T:6]N86P@
M=F%L=64@(B5O<'0E(BP@<VAO=6QD(&)E('EE<R!O<B!N;R<L#0H@("`@("`@
M("`@("`@("`@4$5!4E]004-+04=%1DE,15]02%!?3D]?3D]4(#T^#0H@("`@
M("`@("`@("`@("`@("`@("=$97!E;F1E;F-Y("5I;F1E>"4Z('!H<"!D97!E
M;F1E;F-I97,@8V%N;F]T('5S92`B;F]T(B!R96PL('5S92`B;F4B)R`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`G('1O(&5X8VQU9&4@<W!E8VEF:6,@
M=F5R<VEO;G,G+`T*("`@("`@("`@("`@("`@(%!%05)?4$%#2T%'149)3$5?
M15)23U)?3D]?0T].1DY!344@/3X-"B`@("`@("`@("`@("`@("`@("`@)T-O
M;F9I9W5R92!/<'1I;VX@)6EN9&5X)2!H87,@;F\@;F%M92<L#0H@("`@("`@
M("`@("`@("`@4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]#3TY&4%)/35!4
M(#T^#0H@("`@("`@("`@("`@("`@("`@("=#;VYF:6=U<F4@3W!T:6]N("5I
M;F1E>"4@:&%S(&YO('!R;VUP="<L#0H@("`@("`@("`@("`@("`@4$5!4E]0
M04-+04=%1DE,15]%4E)/4E].3U]&24Q%4R`]/@T*("`@("`@("`@("`@("`@
M("`@("`G3F\@9FEL97,@:6X@/&9I;&5L:7-T/B!S96-T:6]N(&]F('!A8VMA
M9V4N>&UL)RP-"B`@("`@("`@("`@("`@("!014%27U!!0TM!1T5&24Q%7T52
M4D]27TY/7T9)3$523TQ%(#T^#0H@("`@("`@("`@("`@("`@("`@("=&:6QE
M("(E9FEL924B(&AA<R!N;R!R;VQE+"!E>'!E8W1I;F<@;VYE(&]F("(E<F]L
M97,E(B<L#0H@("`@("`@("`@("`@("`@4$5!4E]004-+04=%1DE,15]%4E)/
M4E])3E9!3$E$7T9)3$523TQ%(#T^#0H@("`@("`@("`@("`@("`@("`@("=&
M:6QE("(E9FEL924B(&AA<R!I;G9A;&ED(')O;&4@(B5R;VQE)2(L(&5X<&5C
M=&EN9R!O;F4@;V8@(B5R;VQE<R4B)RP-"B`@("`@("`@("`@("`@("!014%2
M7U!!0TM!1T5&24Q%7T524D]27TE.5D%,241?1DE,14Y!344@/3X-"B`@("`@
M("`@("`@("`@("`@("`@)T9I;&4@(B5F:6QE)2(@8V%N;F]T('-T87)T('=I
M=&@@(BXB+"!C86YN;W0@<&%C:V%G92!O<B!I;G-T86QL)RP-"B`@("`@("`@
M("`@("`@("!014%27U!!0TM!1T5&24Q%7T524D]27TE.5D%,241?4$A01DE,
M12`]/@T*("`@("`@("`@("`@("`@("`@("`G4&%R<V5R(&5R<F]R.B!I;G9A
M;&ED(%!(4"!F;W5N9"!I;B!F:6QE("(E9FEL924B)RP-"B`@("`@("`@("`@
M("`@("!014%27U!!0TM!1T5&24Q%7T524D]27TY/7U!.04U%7U!2149)6"`]
M/@T*("`@("`@("`@("`@("`@("`@("`G:6X@)69I;&4E.B`E='EP924@(B5N
M86UE)2(@;F]T('!R969I>&5D('=I=&@@<&%C:V%G92!N86UE("(E<&%C:V%G
M924B)RP-"B`@("`@("`@("`@("`@("!014%27U!!0TM!1T5&24Q%7T524D]2
M7TE.5D%,241?1DE,12`]/@T*("`@("`@("`@("`@("`@("`@("`G4&%R<V5R
M(&5R<F]R.B!I;G9A;&ED(%!(4"!F:6QE("(E9FEL924B)RP-"B`@("`@("`@
M("`@("`@("!014%27U!!0TM!1T5&24Q%7T524D]27T-(04Y.14Q604P@/3X-
M"B`@("`@("`@("`@("`@("`@("`@)T-H86YN96P@=F%L:61A=&]R(&5R<F]R
M.B!F:65L9"`B)69I96QD)2(@+2`E<F5A<V]N)2<L#0H@("`@("`@("`@("`@
M("`@4$5!4E]004-+04=%1DE,15]%4E)/4E]02%`U(#T^#0H@("`@("`@("`@
M("`@("`@("`@("=%<G)O<BP@4$A0-2!T;VME;B!E;F-O=6YT97)E9"!I;B`E
M9FEL924L(&%N86QY<VES('-H;W5L9"!B92!I;B!02%`U)RP-"B`@("`@("`@
M("`@("`@("!014%27U!!0TM!1T5&24Q%7T524D]27T9)3$5?3D]41D]53D0@
M/3X-"B`@("`@("`@("`@("`@("`@("`@)T9I;&4@(B5F:6QE)2(@:6X@<&%C
M:V%G92YX;6P@9&]E<R!N;W0@97AI<W0G+`T*("`@("`@("`@("`@("`@(%!%
M05)?4$%#2T%'149)3$5?15)23U)?3D].7TE33U]#2$%24R`]/@T*("`@("`@
M("`@("`@("`@("`@("`G4&%C:V%G92YX;6P@8V]N=&%I;G,@;F]N+4E33RTX
M.#4Y+3$@8VAA<F%C=&5R<RP@86YD(&UA>2!N;W0@=F%L:61A=&4G+`T*("`@
M("`@("`@("`@*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!686QI9&%T
M92!834P@<&%C:V%G92!D969I;FET:6]N(&9I;&4N#0H@("`@("H-"B`@("`@
M*B!`86-C97-S('!U8FQI8PT*("`@("`J($!R971U<FX@8F]O;&5A;@T*("`@
M("`J+PT*("`@(&9U;F-T:6]N('9A;&ED871E*"1S=&%T92`](%!%05)?5D%,
M241!5$5?3D]234%,+"`D;F]F:6QE8VAE8VMI;F<@/2!F86QS92D-"B`@("![
M#0H@("`@("`@(&EF("@H)'1H:7,M/E]I<U9A;&ED("8@)'-T871E*2`]/2`D
M<W1A=&4I('L-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]
M#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`]('1R=64[#0H@("`@("`@("1I
M;F9O(#T@)'1H:7,M/E]P86-K86=E26YF;SL-"B`@("`@("`@:68@*&5M<'1Y
M*"1I;F9O6R=P86-K86=E)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W9A
M;&ED871E17)R;W(H4$5!4E]004-+04=%1DE,15]%4E)/4E].3U].04U%*3L-
M"B`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94YA;64@/2`D<&X@/2`G=6YK
M;F]W;B<[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D=&AI<RT^
M7W!A8VMA9V5.86UE(#T@)'!N(#T@)&EN9F];)W!A8VMA9V4G73L-"B`@("`@
M("`@?0T*#0H@("`@("`@(&EF("AE;7!T>2@D:6YF;ULG<W5M;6%R>2==*2D@
M>PT*("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?4$%#
M2T%'149)3$5?15)23U)?3D]?4U5-34%262D[#0H@("`@("`@('T@96QS96EF
M("AS=')P;W,H=')I;2@D:6YF;ULG<W5M;6%R>2==*2P@(EQN(BD@(3T](&9A
M;'-E*2![#0H@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E5V%R;FEN9RA0
M14%27U!!0TM!1T5&24Q%7T524D]27TU53%1)3$E.15]354U-05)9+`T*("`@
M("`@("`@("`@("`@(&%R<F%Y*"=S=6UM87)Y)R`]/B`D:6YF;ULG<W5M;6%R
M>2==*2D[#0H@("`@("`@('T-"B`@("`@("`@:68@*&5M<'1Y*"1I;F9O6R=D
M97-C<FEP=&EO;B==*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T
M945R<F]R*%!%05)?4$%#2T%'149)3$5?15)23U)?3D]?1$530U))4%1)3TXI
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("AE;7!T>2@D:6YF;ULG<F5L96%S
M95]L:6-E;G-E)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E
M17)R;W(H4$5!4E]004-+04=%1DE,15]%4E)/4E].3U],24-%3E-%*3L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H96UP='DH)&EN9F];)W9E<G-I;VXG72DI
M('L-"B`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27U!!
M0TM!1T5&24Q%7T524D]27TY/7U9%4E-)3TXI.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("AE;7!T>2@D:6YF;ULG<F5L96%S95]S=&%T92==*2D@>PT*("`@
M("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?4$%#2T%'149)
M3$5?15)23U)?3D]?4U1!5$4I.PT*("`@("`@("!]#0H@("`@("`@(&EF("AE
M;7!T>2@D:6YF;ULG<F5L96%S95]D871E)UTI*2![#0H@("`@("`@("`@("`D
M=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]004-+04=%1DE,15]%4E)/4E].
M3U]$051%*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H96UP='DH)&EN9F];
M)W)E;&5A<V5?;F]T97,G72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?=F%L
M:61A=&5%<G)O<BA014%27U!!0TM!1T5&24Q%7T524D]27TY/7TY/5$53*3L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H96UP='DH)&EN9F];)VUA:6YT86EN
M97)S)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H
M4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]-04E.5$%)3D524RD[#0H@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`D:&%S;&5A9"`](&9A;'-E.PT*
M("`@("`@("`@("`@)&D@/2`Q.PT*("`@("`@("`@("`@9F]R96%C:"`H)&EN
M9F];)VUA:6YT86EN97)S)UT@87,@)&TI('L-"B`@("`@("`@("`@("`@("!I
M9B`H96UP='DH)&U;)VAA;F1L92==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]004-+04=%1DE,15]%4E)/
M4E].3U]-04E.5$A!3D1,12P-"B`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*"=I;F1E>"<@/3X@)&DI*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@:68@*&5M<'1Y*"1M6R=R;VQE)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27U!!0TM!
M1T5&24Q%7T524D]27TY/7TU!24Y44D],12P-"B`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"=I;F1E>"<@/3X@)&DL("=R;VQE<R<@/3X@4$5!4E]#
M;VUM;VXZ.F=E=%5S97)2;VQE<R@I*2D[#0H@("`@("`@("`@("`@("`@?2!E
M;'-E:68@*"1M6R=R;VQE)UT@/3T@)VQE860G*2![#0H@("`@("`@("`@("`@
M("`@("`@("1H87-L96%D(#T@=')U93L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1M6R=N86UE)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27U!!
M0TM!1T5&24Q%7T524D]27TY/7TU!24Y43D%-12P-"B`@("`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*"=I;F1E>"<@/3X@)&DI*3L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1M6R=E;6%I;"==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R
M;W(H4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]-04E.5$5-04E,+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)VEN9&5X)R`]/B`D:2DI.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D:2LK.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"$D:&%S;&5A9"D@>PT*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27U!!0TM!
M1T5&24Q%7T524D]27TY/7TQ%040I.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@(&EF("@A96UP='DH)&EN9F];)W)E;&5A<V5?9&5P<R==
M*2D@>PT*("`@("`@("`@("`@)&D@/2`Q.PT*("`@("`@("`@("`@9F]R96%C
M:"`H)&EN9F];)W)E;&5A<V5?9&5P<R==(&%S("1D*2![#0H@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D9%LG='EP92==*2!\?"!E;7!T>2@D9%LG='EP
M92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E
M17)R;W(H4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]$15!465!%+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)VEN9&5X)R`]/B`D:2P@)W1Y
M<&5S)R`]/B!014%27T-O;6UO;CHZ9V5T1&5P96YD96YC>51Y<&5S*"DI*3L-
M"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&1;)W)E;"==*2!\
M?"!E;7!T>2@D9%LG<F5L)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27U!!0TM!1T5&24Q%7T524D]27TY/
M7T1%4%)%3"P-"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=I;F1E
M>"<@/3X@)&DL("=R96QS)R`]/B!014%27T-O;6UO;CHZ9V5T1&5P96YD96YC
M>5)E;&%T:6]N<R@I*2D[#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1D6R=O<'1I;VYA;"==*2D@>PT*("`@("`@("`@("`@("`@("`@("!I
M9B`H(6EN7V%R<F%Y*"1D6R=O<'1I;VYA;"==+"!A<G)A>2@G>65S)RP@)VYO
M)RDI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W9A;&ED
M871E17)R;W(H4$5!4E]004-+04=%1DE,15]%4E)/4E])3E9!3$E$7T1%4$]0
M5$E/3D%,+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=I
M;F1E>"<@/3X@)&DL("=O<'0G(#T^("1D6R=O<'1I;VYA;"==*2D[#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@:68@*"1D6R=R96PG72`A/2`G:&%S)R`F)B`D9%LG<F5L)UT@
M(3T@)VYO="<@)B8@96UP='DH)&1;)W9E<G-I;VXG72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?4$%#2T%'
M149)3$5?15)23U)?3D]?1$505D524TE/3BP-"B`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"=I;F1E>"<@/3X@)&DI*3L-"B`@("`@("`@("`@("`@
M("!](&5L<V5I9B`H*"1D6R=R96PG72`]/2`G:&%S)R!\?"`D9%LG<F5L)UT@
M/3T@)VYO="<I("8F("%E;7!T>2@D9%LG=F5R<VEO;B==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E5V%R;FEN9RA014%27U!!
M0TM!1T5&24Q%7T524D]27T1%4%9%4E-)3TY?24=.3U)%1"P-"B`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"=I;F1E>"<@/3X@)&DL("=R96PG(#T^
M("1D6R=R96PG72DI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!I9B`H)&1;)W1Y<&4G72`]/2`G<&AP)R`F)B`A96UP='DH)&1;)VYA
M;64G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T
M95=A<FYI;F<H4$5!4E]004-+04=%1DE,15]%4E)/4E]$15!.04U%7TE'3D]2
M140L#0H@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G:6YD97@G(#T^
M("1I+"`G;F%M92<@/3X@)&1;)VYA;64G72DI.PT*("`@("`@("`@("`@("`@
M('T@96QS96EF("@D9%LG='EP92==("$]("=P:'`G("8F(&5M<'1Y*"1D6R=N
M86UE)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A
M=&5%<G)O<BA014%27U!!0TM!1T5&24Q%7T524D]27TY/7T1%4$Y!344L#0H@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G:6YD97@G(#T^("1I*2D[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D9%LG
M='EP92==(#T]("=P:'`G("8F(&5M<'1Y*"1D6R=V97)S:6]N)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%2
M7U!!0TM!1T5&24Q%7T524D]27TY/7T1%4%!(4%9%4E-)3TXL#0H@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@G:6YD97@G(#T^("1I*2D[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@H)&1;)W)E;"==
M(#T]("=N;W0G*2`F)B`H)&1;)W1Y<&4G72`]/2`G<&AP)RDI('L-"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?4$%#
M2T%'149)3$5?4$A07TY/7TY/5"P-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*"=I;F1E>"<@/3X@)&DI*3L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@)&DK*SL-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H(65M<'1Y*"1I;F9O6R=C;VYF:6=U<F5?;W!T:6]N
M<R==*2D@>PT*("`@("`@("`@("`@)&D@/2`Q.PT*("`@("`@("`@("`@9F]R
M96%C:"`H)&EN9F];)V-O;F9I9W5R95]O<'1I;VYS)UT@87,@)&,I('L-"B`@
M("`@("`@("`@("`@("!I9B`H96UP='DH)&-;)VYA;64G72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?4$%#
M2T%'149)3$5?15)23U)?3D]?0T].1DY!344L#0H@("`@("`@("`@("`@("`@
M("`@("`@("!A<G)A>2@G:6YD97@G(#T^("1I*2D[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D8ULG<')O;7!T)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O
M<BA014%27U!!0TM!1T5&24Q%7T524D]27TY/7T-/3D904D]-4%0L#0H@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@G:6YD97@G(#T^("1I*2D[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1I*RL[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&5M<'1Y*"1I;F9O
M6R=F:6QE;&ES="==*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T
M945R<F]R*%!%05)?4$%#2T%'149)3$5?15)23U)?3D]?1DE,15,I.PT*("`@
M("`@("`@("`@)&5R<F]R<UM=(#T@)VYO(&9I;&5S)SL-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1I;F9O6R=F:6QE;&ES="==
M(&%S("1F:6QE(#T^("1F82D@>PT*("`@("`@("`@("`@("`@(&EF("AE;7!T
M>2@D9F%;)W)O;&4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]V86QI9&%T945R<F]R*%!%05)?4$%#2T%'149)3$5?15)23U)?3D]?1DE,
M15)/3$4L#0H@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G9FEL92<@
M/3X@)&9I;&4L("=R;VQE<R<@/3X@4$5!4E]#;VUM;VXZ.F=E=$9I;&52;VQE
M<R@I*2D[#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@
M("`@("`@("`@('T@96QS96EF("@A:6Y?87)R87DH)&9A6R=R;VQE)UTL(%!%
M05)?0V]M;6]N.CIG971&:6QE4F]L97,H*2DI('L-"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?4$%#2T%'149)3$5?
M15)23U)?24Y604Q)1%]&24Q%4D],12P-"B`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y*"=F:6QE)R`]/B`D9FEL92P@)W)O;&4G(#T^("1F85LG<F]L
M92==+"`G<F]L97,G(#T^(%!%05)?0V]M;6]N.CIG971&:6QE4F]L97,H*2DI
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H)&9I
M;&5[,'T@/3T@)RXG("8F("1F:6QE>S%](#T]("<O)RD@>PT*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]004-+04=%
M1DE,15]%4E)/4E])3E9!3$E$7T9)3$5.04U%+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@87)R87DH)V9I;&4G(#T^("1F:6QE*2D[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7W)E9VES=')Y*2`F)B`D=&AI<RT^7VES5F%L:60I
M('L-"B`@("`@("`@("`@("1C:&%N(#T@)'1H:7,M/E]R96=I<W1R>2T^9V5T
M0VAA;FYE;"@G<&5A<BYP:'`N;F5T)RD[#0H@("`@("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D8VAA;BDI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^
M7W9A;&ED871E17)R;W(H4$5!4E]004-+04=%1DE,15]%4E)/4E]#2$%.3D5,
M5D%,+"`D8VAA;BT^9V5T365S<V%G92@I*3L-"B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("1V86QI9&%T;W(@/2`D8VAA;BT^9V5T5F%L:61A=&EO;D]B
M:F5C="@I.PT*("`@("`@("`@("`@)'9A;&ED871O<BT^<V5T4&%C:V%G949I
M;&4H)'1H:7,I.PT*("`@("`@("`@("`@)'9A;&ED871O<BT^=F%L:61A=&4H
M)'-T871E*3L-"B`@("`@("`@("`@("1F86EL=7)E<R`]("1V86QI9&%T;W(M
M/F=E=$9A:6QU<F5S*"D[#0H@("`@("`@("`@("!F;W)E86-H("@D9F%I;'5R
M97-;)V5R<F]R<R==(&%S("1E<G)O<BD@>PT*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27U!!0TM!1T5&24Q%7T524D]27T-(
M04Y.14Q604PL("1E<G)O<BD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!F;W)E86-H("@D9F%I;'5R97-;)W=A<FYI;F=S)UT@87,@)'=A<FYI;F<I
M('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E5V%R;FEN9RA0
M14%27U!!0TM!1T5&24Q%7T524D]27T-(04Y.14Q604PL("1W87)N:6YG*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'1H:7,M
M/E]I<U9A;&ED("8F("1S=&%T92`]/2!014%27U9!3$E$051%7U!!0TM!1TE.
M1R`F)B`A)&YO9FEL96-H96-K:6YG*2![#0H@("`@("`@("`@("!I9B`H)'1H
M:7,M/E]A;F%L>7IE4&AP1FEL97,H*2D@>PT*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?:7-686QI9"`]('1R=64[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"1T:&ES+3Y?:7-686QI9"D@>PT*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?:7-686QI9"`]("1S=&%T93L-"B`@("`@("`@
M?0T*("`@("`@("!R971U<FX@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!?86YA;'EZ95!H<$9I;&5S*"D-"B`@("![#0H@
M("`@("`@(&EF("@A)'1H:7,M/E]I<U9A;&ED*2![#0H@("`@("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<W-E="@D
M=&AI<RT^7W!A8VMA9V5&:6QE*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@("`@("!]#0H@("`@("`@("1D:7)?<')E9FEX(#T@9&ER;F%M
M92@D=&AI<RT^7W!A8VMA9V5&:6QE*3L-"B`@("`@("`@)&-O;6UO;B`](&YE
M=R!014%27T-O;6UO;CL-"B`@("`@("`@)&QO9R`](&ES<V5T*"1T:&ES+3Y?
M;&]G9V5R*2`_(&%R<F%Y*"8D=&AI<RT^7VQO9V=E<BP@)VQO9R<I(#H-"B`@
M("`@("`@("`@(&%R<F%Y*"1C;VUM;VXL("=L;V<G*3L-"B`@("`@("`@)&EN
M9F\@/2`D=&AI<RT^9V5T1FEL96QI<W0H*3L-"B`@("`@("`@9F]R96%C:"`H
M)&EN9F\@87,@)&9I;&4@/3X@)&9A*2![#0H@("`@("`@("`@("!I9B`H(69I
M;&5?97AI<W1S*"1D:7)?<')E9FEX("X@1$E214-43U)97U-%4$%2051/4B`N
M("1F:6QE*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%
M<G)O<BA014%27U!!0TM!1T5&24Q%7T524D]27T9)3$5?3D]41D]53D0L#0H@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=F:6QE)R`]/B!R96%L<&%T:"@D
M9&ER7W!R969I>"D@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)&9I;&4I*3L-
M"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&EF("@D9F%;)W)O;&4G72`]/2`G<&AP)R`F)B`D9&ER7W!R
M969I>"D@>PT*("`@("`@("`@("`@("`@(&-A;&Q?=7-E<E]F=6YC7V%R<F%Y
M*"1L;V<L(&%R<F%Y*#$L(")!;F%L>7II;F<@)&9I;&4B*2D[#0H@("`@("`@
M("`@("`@("`@)'-R8VEN9F\@/2`D=&AI<RT^7V%N86QY>F53;W5R8V5#;V1E
M*"1D:7)?<')E9FEX("X@1$E214-43U)97U-%4$%2051/4B`N("1F:6QE*3L-
M"B`@("`@("`@("`@("`@("!I9B`H)'-R8VEN9F\I('L-"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]B=6EL9%!R;W9I9&5S07)R87DH)'-R8VEN9F\I
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("`D=&AI<RT^7W!A8VMA9V5.86UE(#T@)'!N(#T@)'1H:7,M
M/F=E=%!A8VMA9V4H*3L-"B`@("`@("`@)'!N;"`]('-T<FQE;B@D<&XI.PT*
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG<')O=FED
M97,G72DI('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"AA<G)A>2D@)'1H:7,M
M/E]P86-K86=E26YF;ULG<')O=FED97,G72!A<R`D:V5Y(#T^("1W:&%T*2![
M#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1W:&%T6R=E>'!L:6-I="==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`O+R!S:VEP(&-O;F9O<FUA;F-E
M(&-H96-K<R!I9B!T:&4@<')O=FED97,@96YT<GD@:7,-"B`@("`@("`@("`@
M("`@("`@("`@+R\@<W!E8VEF:65D(&EN('1H92!P86-K86=E+GAM;"!F:6QE
M#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!E>'1R86-T*"1W:&%T*3L-"B`@("`@
M("`@("`@("`@("!I9B`H)'1Y<&4@/3T@)V-L87-S)RD@>PT*("`@("`@("`@
M("`@("`@("`@("!I9B`H(7-T<FYC87-E8VUP*"1N86UE+"`D<&XL("1P;FPI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W9A;&ED871E5V%R;FEN9RA014%27U!!0TM!1T5&24Q%7T524D]27TY/7U!.
M04U%7U!2149)6"P-"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=F
M:6QE)R`]/B`D9FEL92P@)W1Y<&4G(#T^("1T>7!E+"`G;F%M92<@/3X@)&YA
M;64L("=P86-K86=E)R`]/B`D<&XI*3L-"B`@("`@("`@("`@("`@("!](&5L
M<V5I9B`H)'1Y<&4@/3T@)V9U;F-T:6]N)RD@>PT*("`@("`@("`@("`@("`@
M("`@("!I9B`H<W1R<W1R*"1N86UE+"`G.CHG*2!\?"`A<W1R;F-A<V5C;7`H
M)&YA;64L("1P;BP@)'!N;"DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5787)N:6YG*%!%05)?4$%#2T%'
M149)3$5?15)23U)?3D]?4$Y!345?4%)%1DE8+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@87)R87DH)V9I;&4G(#T^("1F:6QE+"`G='EP92<@/3X@)'1Y
M<&4L("=N86UE)R`]/B`D;F%M92P@)W!A8VMA9V4G(#T^("1P;BDI.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!R971U<FX@)'1H:7,M/E]I<U9A;&ED.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("`J($=E="!T:&4@9&5F875L="!X;6P@9V5N97)A=&]R(&]B:F5C
M=`T*("`@("`J#0H@("`@("H@0')E='5R;B!014%27U!A8VMA9V5&:6QE7T=E
M;F5R871O<E]V,0T*("`@("`J+PT*("`@(&9U;F-T:6]N("9G971$969A=6QT
M1V5N97)A=&]R*"D-"B`@("![#0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S
M*"=014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,2<I*2![#0H@("`@("`@
M("`@("!R97%U:7)E7V]N8V4@)U!%05(O4&%C:V%G949I;&4O1V5N97)A=&]R
M+W8Q+G!H<"<[#0H@("`@("`@('T-"B`@("`@("`@)&$@/2`F;F5W(%!%05)?
M4&%C:V%G949I;&5?1V5N97)A=&]R7W8Q*"1T:&ES*3L-"B`@("`@("`@<F5T
M=7)N("1A.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($=E="!T:&4@8V]N
M=&5N=',@;V8@82!F:6QE(&QI<W1E9"!W:71H:6X@=&AE('!A8VMA9V4N>&UL
M#0H@("`@("H@0'!A<F%M('-T<FEN9PT*("`@("`J($!R971U<FX@<W1R:6YG
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T1FEL94-O;G1E;G1S*"1F:6QE
M*0T*("`@('L-"B`@("`@("`@:68@*"1T:&ES+3Y?87)C:&EV949I;&4@/3T@
M)'1H:7,M/E]P86-K86=E1FEL92D@>R`O+R!U;G!A8VME9`T*("`@("`@("`@
M("`@)&1I<B`](&1I<FYA;64H)'1H:7,M/E]P86-K86=E1FEL92D[#0H@("`@
M("`@("`@("`D9FEL92`]("1D:7(@+B!$25)%0U1/4EE?4T5005)!5$]2("X@
M)&9I;&4[#0H@("`@("`@("`@("`D9FEL92`]('-T<E]R97!L86-E*&%R<F%Y
M*"<O)RP@)UQ<)RDL#0H@("`@("`@("`@("`@("`@87)R87DH1$E214-43U)9
M7U-%4$%2051/4BP@1$E214-43U)97U-%4$%2051/4BDL("1F:6QE*3L-"B`@
M("`@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D9FEL92D@)B8@:7-?<F5A9&%B
M;&4H)&9I;&4I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N(&EM<&QO9&4H
M)R<L(&9I;&4H)&9I;&4I*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E
M;'-E('L@+R\@=&=Z#0H@("`@("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G
M07)C:&EV95]487(G*2D@>PT*("`@("`@("`@("`@("`@(')E<75I<F5?;VYC
M92`G07)C:&EV92]487(N<&AP)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("1T87(@/2`F;F5W($%R8VAI=F5?5&%R*"1T:&ES+3Y?87)C:&EV949I
M;&4I.PT*("`@("`@("`@("`@)'1A<BT^<'5S:$5R<F]R2&%N9&QI;F<H4$5!
M4E]%4E)/4E]215154DXI.PT*("`@("`@("`@("`@:68@*"1F:6QE("$]("=P
M86-K86=E+GAM;"<@)B8@)&9I;&4@(3T@)W!A8VMA9V4R+GAM;"<I('L-"B`@
M("`@("`@("`@("`@("`D9FEL92`]("1T:&ES+3YG971086-K86=E*"D@+B`G
M+2<@+B`D=&AI<RT^9V5T5F5R<VEO;B@I("X@)R\G("X@)&9I;&4[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`D9FEL92`]("1T87(M/F5X=')A8W1)
M;E-T<FEN9R@D9FEL92D[#0H@("`@("`@("`@("`D=&%R+3YP;W!%<G)O<DAA
M;F1L:6YG*"D[#0H@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D9FEL
M92DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@B0V%N;F]T(&QO8V%T92!F:6QE("<D9FEL92<@:6X@87)C:&EV92(I.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N("1F:6QE.PT*("`@
M("`@("!]#0H@("`@?0T*#0H@("`@+R\@>WM[(&%N86QY>F53;W5R8V5#;V1E
M*"D-"B`@("`O*BH-"B`@("`@*B!!;F%L>7IE('1H92!S;W5R8V4@8V]D92!O
M9B!T:&4@9VEV96X@4$A0(&9I;&4-"B`@("`@*@T*("`@("`J($!P87)A;2`@
M<W1R:6YG($9I;&5N86UE(&]F('1H92!02%`@9FEL90T*("`@("`J($!R971U
M<FX@;6EX960-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!?86YA;'EZ95-O=7)C94-O9&4H)&9I;&4I#0H@("`@>PT*
M("`@("`@("!I9B`H(69U;F-T:6]N7V5X:7-T<R@B=&]K96Y?9V5T7V%L;"(I
M*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"%D969I;F5D*"=47T1/0U]#3TU-14Y4)RDI('L-"B`@("`@
M("`@("`@(&1E9FEN92@G5%]$3T-?0T]-345.5"<L(%1?0T]-345.5"D[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"%D969I;F5D*"=47TE.5$521D%#12<I
M*2![#0H@("`@("`@("`@("!D969I;F4H)U1?24Y415)&04-%)RP@+3$I.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("@A9&5F:6YE9"@G5%])35!,14U%3E13
M)RDI('L-"B`@("`@("`@("`@(&1E9FEN92@G5%])35!,14U%3E13)RP@+3$I
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A)&9P(#T@0&9O<&5N*"1F:6QE
M+"`B<B(I*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G9FEL95]G971?8V]N
M=&5N=',G*2D@>PT*("`@("`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@
M("`@("`D8V]N=&5N=',@/2!F:6QE7V=E=%]C;VYT96YT<R@D9FEL92D[#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D8V]N=&5N=',@/2!`9G)E
M860H)&9P+"!F:6QE<VEZ92@D9FEL92DI.PT*("`@("`@("`@("`@9F-L;W-E
M*"1F<"D[#0H@("`@("`@('T-"B`@("`@("`@)'1O:V5N<R`]('1O:V5N7V=E
M=%]A;&PH)&-O;G1E;G1S*3L-"B\J#0H@("`@("`@(&9O<B`H)&D@/2`P.R`D
M:2`\('-I>F5O9B@D=&]K96YS*3L@)&DK*RD@>PT*("`@("`@("`@("`@0&QI
M<W0H)'1O:V5N+"`D9&%T82D@/2`D=&]K96YS6R1I73L-"B`@("`@("`@("`@
M(&EF("AI<U]S=')I;F<H)'1O:V5N*2D@>PT*("`@("`@("`@("`@("`@('9A
M<E]D=6UP*"1T;VME;BD[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@('!R:6YT('1O:V5N7VYA;64H)'1O:V5N*2`N("<@)SL-"B`@
M("`@("`@("`@("`@("!V87)?9'5M<"AR=')I;2@D9&%T82DI.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0HJ+PT*("`@("`@("`D;&]O:U]F;W(@/2`P
M.PT*("`@("`@("`D<&%R96Y?;&5V96P@/2`P.PT*("`@("`@("`D8G)A8VME
M=%]L979E;"`](#`[#0H@("`@("`@("1B<F%C95]L979E;"`](#`[#0H@("`@
M("`@("1L87-T<&AP9&]C(#T@)R<[#0H@("`@("`@("1C=7)R96YT7V-L87-S
M(#T@)R<[#0H@("`@("`@("1C=7)R96YT7VEN=&5R9F%C92`]("<G.PT*("`@
M("`@("`D8W5R<F5N=%]C;&%S<U]L979E;"`]("TQ.PT*("`@("`@("`D8W5R
M<F5N=%]F=6YC=&EO;B`]("<G.PT*("`@("`@("`D8W5R<F5N=%]F=6YC=&EO
M;E]L979E;"`]("TQ.PT*("`@("`@("`D9&5C;&%R961?8VQA<W-E<R`](&%R
M<F%Y*"D[#0H@("`@("`@("1D96-L87)E9%]I;G1E<F9A8V5S(#T@87)R87DH
M*3L-"B`@("`@("`@)&1E8VQA<F5D7V9U;F-T:6]N<R`](&%R<F%Y*"D[#0H@
M("`@("`@("1D96-L87)E9%]M971H;V1S(#T@87)R87DH*3L-"B`@("`@("`@
M)'5S961?8VQA<W-E<R`](&%R<F%Y*"D[#0H@("`@("`@("1U<V5D7V9U;F-T
M:6]N<R`](&%R<F%Y*"D[#0H@("`@("`@("1E>'1E;F1S(#T@87)R87DH*3L-
M"B`@("`@("`@)&EM<&QE;65N=',@/2!A<G)A>2@I.PT*("`@("`@("`D;F]D
M97!S(#T@87)R87DH*3L-"B`@("`@("`@)&EN<75O=&4@/2!F86QS93L-"B`@
M("`@("`@)&EN=&5R9F%C92`](&9A;'-E.PT*("`@("`@("!F;W(@*"1I(#T@
M,#L@)&D@/"!S:7IE;V8H)'1O:V5N<RD[("1I*RLI('L-"B`@("`@("`@("`@
M(&EF("AI<U]A<G)A>2@D=&]K96YS6R1I72DI('L-"B`@("`@("`@("`@("`@
M("!L:7-T*"1T;VME;BP@)&1A=&$I(#T@)'1O:V5N<ULD:5T[#0H@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1T;VME;B`]("1T;VME
M;G-;)&E=.PT*("`@("`@("`@("`@("`@("1D871A(#T@)R<[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!I9B`H)&EN<75O=&4I('L-"B`@("`@("`@
M("`@("`@("!I9B`H)'1O:V5N("$]("<B)R`F)B`D=&]K96X@(3T@5%]%3D1?
M2$52141/0RD@>PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D
M:6YQ=6]T92`](&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU
M93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!S=VET8V@@*"1T;VME;BD@>PT*("`@("`@("`@("`@("`@(&-A<V4@
M5%]72$E415-004-%(#H-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[
M#0H@("`@("`@("`@("`@("`@8V%S92`G.R<Z#0H@("`@("`@("`@("`@("`@
M("`@(&EF("@D:6YT97)F86-E*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D8W5R<F5N=%]F=6YC=&EO;B`]("<G.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)&-U<G)E;G1?9G5N8W1I;VY?;&5V96P@/2`M,3L-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@
M("`@("`@("`@("`@("!C87-E("<B)SH-"B`@("`@("`@("`@("`@("!C87-E
M(%1?4U1!4E1?2$52141/0SH-"B`@("`@("`@("`@("`@("`@("`@)&EN<75O
M=&4@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@
M("`@("`@("`@("!C87-E(%1?0U523%E?3U!%3CH-"B`@("`@("`@("`@("`@
M("!C87-E(%1?1$],3$%27T]014Y?0U523%E?0E)!0T53.@T*("`@("`@("`@
M("`@("`@(&-A<V4@)WLG.B`D8G)A8V5?;&5V96PK*SL@8V]N=&EN=64@,CL-
M"B`@("`@("`@("`@("`@("!C87-E("=])SH-"B`@("`@("`@("`@("`@("`@
M("`@)&)R86-E7VQE=F5L+2T[#0H@("`@("`@("`@("`@("`@("`@(&EF("@D
M8W5R<F5N=%]C;&%S<U]L979E;"`]/2`D8G)A8V5?;&5V96PI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1C=7)R96YT7V-L87-S(#T@)R<[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=%]C;&%S<U]L979E;"`]("TQ
M.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M(&EF("@D8W5R<F5N=%]F=6YC=&EO;E]L979E;"`]/2`D8G)A8V5?;&5V96PI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1C=7)R96YT7V9U;F-T:6]N
M(#T@)R<[#0H@("`@("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=%]F=6YC
M=&EO;E]L979E;"`]("TQ.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@(&-O;G1I;G5E(#([#0H@("`@("`@("`@("`@("`@
M8V%S92`G6R<Z("1B<F%C:V5T7VQE=F5L*RL[(&-O;G1I;G5E(#([#0H@("`@
M("`@("`@("`@("`@8V%S92`G72<Z("1B<F%C:V5T7VQE=F5L+2T[(&-O;G1I
M;G5E(#([#0H@("`@("`@("`@("`@("`@8V%S92`G*"<Z("1P87)E;E]L979E
M;"LK.R`@(&-O;G1I;G5E(#([#0H@("`@("`@("`@("`@("`@8V%S92`G*2<Z
M("1P87)E;E]L979E;"TM.R`@(&-O;G1I;G5E(#([#0H@("`@("`@("`@("`@
M("`@8V%S92!47TE.5$521D%#13H-"B`@("`@("`@("`@("`@("`@("`@)&EN
M=&5R9F%C92`]('1R=64[#0H@("`@("`@("`@("`@("`@8V%S92!47T-,05-3
M.@T*("`@("`@("`@("`@("`@("`@("!I9B`H*"1C=7)R96YT7V-L87-S7VQE
M=F5L("$]("TQ*2!\?"`H)&-U<G)E;G1?9G5N8W1I;VY?;&5V96P@(3T@+3$I
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E
M17)R;W(H4$5!4E]004-+04=%1DE,15]%4E)/4E])3E9!3$E$7U!(4$9)3$4L
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V9I;&4G(#T^
M("1F:6QE*2D[#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!C
M87-E(%1?1E5.0U1)3TXZ#0H@("`@("`@("`@("`@("`@8V%S92!47TY%5SH-
M"B`@("`@("`@("`@("`@("!C87-E(%1?15A414Y$4SH-"B`@("`@("`@("`@
M("`@("!C87-E(%1?24U03$5-14Y44SH-"B`@("`@("`@("`@("`@("`@("`@
M)&QO;VM?9F]R(#T@)'1O:V5N.PT*("`@("`@("`@("`@("`@("`@("!C;VYT
M:6YU92`R.PT*("`@("`@("`@("`@("`@(&-A<V4@5%]35%))3D<Z#0H@("`@
M("`@("`@("`@("`@("`@(&EF("AV97)S:6]N7V-O;7!A<F4H>F5N9%]V97)S
M:6]N*"DL("<R+C`G+"`G/"<I*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H:6Y?87)R87DH<W1R=&]L;W=E<B@D9&%T82DL#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@87)R87DH)W!U8FQI8R<L("=P<FEV871E)RP@
M)W!R;W1E8W1E9"<L("=A8G-T<F%C="<L#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)VEN=&5R9F%C92<L("=I;7!L96UE;G1S)RP@)W1H
M<F]W)RD@#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T
M95=A<FYI;F<H4$5!4E]004-+04=%1DE,15]%4E)/4E]02%`U+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@D9FEL92DI.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@(&EF("@D;&]O:U]F;W(@/3T@5%]#3$%3
M4RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E;G1?8VQA<W,@
M/2`D9&%T83L-"B`@("`@("`@("`@("`@("`@("`@("`@("1C=7)R96YT7V-L
M87-S7VQE=F5L(#T@)&)R86-E7VQE=F5L.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)&1E8VQA<F5D7V-L87-S97-;72`]("1C=7)R96YT7V-L87-S.PT*
M("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&QO;VM?9F]R(#T](%1?
M24Y415)&04-%*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D8W5R<F5N
M=%]I;G1E<F9A8V4@/2`D9&%T83L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1C=7)R96YT7V-L87-S7VQE=F5L(#T@)&)R86-E7VQE=F5L.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)&1E8VQA<F5D7VEN=&5R9F%C97-;72`]("1C
M=7)R96YT7VEN=&5R9F%C93L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M:68@*"1L;V]K7V9O<B`]/2!47TE-4$Q%345.5%,I('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1I;7!L96UE;G1S6R1C=7)R96YT7V-L87-S72`]("1D
M871A.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&QO;VM?9F]R
M(#T](%1?15A414Y$4RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&5X
M=&5N9'-;)&-U<G)E;G1?8VQA<W-=(#T@)&1A=&$[#0H@("`@("`@("`@("`@
M("`@("`@('T@96QS96EF("@D;&]O:U]F;W(@/3T@5%]&54Y#5$E/3BD@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1C=7)R96YT7V-L87-S*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E;G1?9G5N8W1I
M;VX@/2`B)&-U<G)E;G1?8VQA<W,Z.B1D871A(CL-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9&5C;&%R961?;65T:&]D<ULD8W5R<F5N=%]C;&%S
M<UU;72`]("1D871A.PT*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M:68@*"1C=7)R96YT7VEN=&5R9F%C92D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1C=7)R96YT7V9U;F-T:6]N(#T@(B1C=7)R96YT7VEN=&5R
M9F%C93HZ)&1A=&$B.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D
M96-L87)E9%]M971H;V1S6R1C=7)R96YT7VEN=&5R9F%C95U;72`]("1D871A
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=%]F=6YC=&EO;B`]("1D871A
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D96-L87)E9%]F=6YC
M=&EO;G-;72`]("1C=7)R96YT7V9U;F-T:6]N.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E;G1?
M9G5N8W1I;VY?;&5V96P@/2`D8G)A8V5?;&5V96P[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D;2`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@("`@
M('T@96QS96EF("@D;&]O:U]F;W(@/3T@5%].15<I('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1U<V5D7V-L87-S97-;)&1A=&%=(#T@=')U93L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D;&]O
M:U]F;W(@/2`P.PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU92`R.PT*
M("`@("`@("`@("`@("`@(&-A<V4@5%]605))04),13H-"B`@("`@("`@("`@
M("`@("`@("`@)&QO;VM?9F]R(#T@,#L-"B`@("`@("`@("`@("`@("`@("`@
M8V]N=&EN=64@,CL-"B`@("`@("`@("`@("`@("!C87-E(%1?1$]#7T-/34U%
M3E0Z#0H@("`@("`@("`@("`@("`@8V%S92!47T-/34U%3E0Z#0H@("`@("`@
M("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<A7B]<*EPJ7',A)RP@)&1A
M=&$I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D;&%S='!H<&1O8R`]
M("1D871A.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T
M8VA?86QL*"<O0&YO9&5P7',K*%Q3*RDO)RP@)&QA<W1P:'!D;V,L("1M*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N;V1E<',@/2!A<G)A
M>5]M97)G92@D;F]D97!S+"`D;5LQ72D[#0H@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@8V]N=&EN=64@,CL-"B`@("`@("`@("`@("`@("!C87-E(%1?1$]5
M0DQ%7T-/3$]..@T*("`@("`@("`@("`@("`@("`@("!I9B`H(2@D=&]K96YS
M6R1I("T@,5U;,%T@/3T@5%]72$E415-004-%('Q\("1T;VME;G-;)&D@+2`Q
M75LP72`]/2!47U-44DE.1RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27U!!0TM!1T5&24Q%7T524D]2
M7TE.5D%,241?4$A01DE,12P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@G9FEL92<@/3X@)&9I;&4I*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`D8VQA<W,@/2`D=&]K96YS6R1I("T@,5U;
M,5T[#0H@("`@("`@("`@("`@("`@("`@(&EF("AS=')T;VQO=V5R*"1C;&%S
M<RD@(3T@)W!A<F5N="<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1U
M<V5D7V-L87-S97-;)&-L87-S72`]('1R=64[#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64@,CL-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@87)R87DH#0H@
M("`@("`@("`@("`B<V]U<F-E7V9I;&4B(#T^("1F:6QE+`T*("`@("`@("`@
M("`@(F1E8VQA<F5D7V-L87-S97,B(#T^("1D96-L87)E9%]C;&%S<V5S+`T*
M("`@("`@("`@("`@(F1E8VQA<F5D7VEN=&5R9F%C97,B(#T^("1D96-L87)E
M9%]I;G1E<F9A8V5S+`T*("`@("`@("`@("`@(F1E8VQA<F5D7VUE=&AO9',B
M(#T^("1D96-L87)E9%]M971H;V1S+`T*("`@("`@("`@("`@(F1E8VQA<F5D
M7V9U;F-T:6]N<R(@/3X@)&1E8VQA<F5D7V9U;F-T:6]N<RP-"B`@("`@("`@
M("`@(")U<V5D7V-L87-S97,B(#T^(&%R<F%Y7V1I9F8H87)R87E?:V5Y<R@D
M=7-E9%]C;&%S<V5S*2P@)&YO9&5P<RDL#0H@("`@("`@("`@("`B:6YH97)I
M=&%N8V4B(#T^("1E>'1E;F1S+`T*("`@("`@("`@("`@(FEM<&QE;65N=',B
M(#T^("1I;7!L96UE;G1S+`T*("`@("`@("`@("`@*3L-"B`@("!]#0H-"B`@
M("`O*BH-"B`@("`@*B!"=6EL9"!A(")P<F]V:61E<R(@87)R87D@9G)O;2!D
M871A(')E='5R;F5D(&)Y#0H@("`@("H@86YA;'EZ95-O=7)C94-O9&4H*2X@
M(%1H92!F;W)M870@;V8@=&AE(&)U:6QT(&%R<F%Y(&ES(&QI:V4-"B`@("`@
M*B!T:&ES.@T*("`@("`J#0H@("`@("H@(&%R<F%Y*`T*("`@("`J("`@("=C
M;&%S<SM->4-L87-S)R`]/B`G87)R87DH)W1Y<&4G(#T^("=C;&%S<R<L("=N
M86UE)R`]/B`G37E#;&%S<R<I+`T*("`@("`J("`@("XN+@T*("`@("`J("`I
M#0H@("`@("H-"B`@("`@*@T*("`@("`J($!P87)A;2!A<G)A>2`D<W)C:6YF
M;R!A<G)A>2!W:71H(&EN9F]R;6%T:6]N(&%B;W5T(&$@<V]U<F-E(&9I;&4-
M"B`@("`@*B!A<R!R971U<FYE9"!B>2!T:&4@86YA;'EZ95-O=7)C94-O9&4H
M*2!M971H;V0N#0H@("`@("H-"B`@("`@*B!`<F5T=7)N('9O:60-"B`@("`@
M*@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@7V)U:6QD4')O=FED97-!<G)A>2@D<W)C:6YF;RD-"B`@
M("![#0H@("`@("`@(&EF("@A)'1H:7,M/E]I<U9A;&ED*2![#0H@("`@("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)&9I;&4@
M/2!B87-E;F%M92@D<W)C:6YF;ULG<V]U<F-E7V9I;&4G72D[#0H@("`@("`@
M("1P;B`]("1T:&ES+3YG971086-K86=E*"D[#0H@("`@("`@("1P;FP@/2!S
M=')L96XH)'!N*3L-"B`@("`@("`@9F]R96%C:"`H)'-R8VEN9F];)V1E8VQA
M<F5D7V-L87-S97,G72!A<R`D8VQA<W,I('L-"B`@("`@("`@("`@("1K97D@
M/2`B8VQA<W,[)&-L87-S(CL-"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^7W!A8VMA9V5);F9O6R=P<F]V:61E<R==6R1K97E=*2D@>PT*("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@)'1H:7,M/E]P86-K86=E26YF;ULG<')O=FED97,G75LD:V5Y72`]#0H@
M("`@("`@("`@("`@("`@87)R87DH)V9I;&4G/3X@)&9I;&4L("=T>7!E)R`]
M/B`G8VQA<W,G+"`G;F%M92<@/3X@)&-L87-S*3L-"B`@("`@("`@("`@(&EF
M("AI<W-E="@D<W)C:6YF;ULG:6YH97)I=&%N8V4G75LD8VQA<W-=*2D@>PT*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)W!R;W9I9&5S
M)UU;)&ME>5U;)V5X=&5N9',G72`]#0H@("`@("`@("`@("`@("`@("`@("1S
M<F-I;F9O6R=I;FAE<FET86YC92==6R1C;&%S<UT[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H)'-R8VEN9F];)V1E8VQA
M<F5D7VUE=&AO9',G72!A<R`D8VQA<W,@/3X@)&UE=&AO9',I('L-"B`@("`@
M("`@("`@(&9O<F5A8V@@*"1M971H;V1S(&%S("1M971H;V0I('L-"B`@("`@
M("`@("`@("`@("`D9G5N8W1I;VX@/2`B)&-L87-S.CHD;65T:&]D(CL-"B`@
M("`@("`@("`@("`@("`D:V5Y(#T@(F9U;F-T:6]N.R1F=6YC=&EO;B([#0H@
M("`@("`@("`@("`@("`@:68@*"1M971H;V1[,'T@/3T@)U\G('Q\("%S=')C
M87-E8VUP*"1M971H;V0L("1C;&%S<RD@?'P-"B`@("`@("`@("`@("`@("`@
M("`@:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG<')O=FED97,G75LD:V5Y
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN
M9F];)W!R;W9I9&5S)UU;)&ME>5T@/0T*("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@G9FEL92<]/B`D9FEL92P@)W1Y<&4G(#T^("=F=6YC=&EO;B<L("=N
M86UE)R`]/B`D9G5N8W1I;VXI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H-"B`@("`@("`@9F]R96%C:"`H)'-R8VEN9F];)V1E8VQA<F5D7V9U;F-T
M:6]N<R==(&%S("1F=6YC=&EO;BD@>PT*("`@("`@("`@("`@)&ME>2`](")F
M=6YC=&EO;CLD9G5N8W1I;VXB.PT*("`@("`@("`@("`@:68@*"1F=6YC=&EO
M;GLP?2`]/2`G7R<@?'P@:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG<')O
M=FED97,G75LD:V5Y72DI('L-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A<W1R<W1R*"1F=6YC
M=&EO;BP@)SHZ)RD@)B8@<W1R;F-A<V5C;7`H)&9U;F-T:6]N+"`D<&XL("1P
M;FPI*2![#0H@("`@("`@("`@("`@("`@)'=A<FYI;F=S6UT@/2`B:6XQ("(@
M+B`D9FEL92`N("(Z(&9U;F-T:6]N(%PB)&9U;F-T:6]N7"(@;F]T('!R969I
M>&5D('=I=&@@<&%C:V%G92!N86UE(%PB)'!N7"(B.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG<')O=FED97,G
M75LD:V5Y72`]#0H@("`@("`@("`@("`@("`@87)R87DH)V9I;&4G/3X@)&9I
M;&4L("=T>7!E)R`]/B`G9G5N8W1I;VXG+"`G;F%M92<@/3X@)&9U;F-T:6]N
M*3L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\O('U]?0T*?0T*/SX-"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+U!%05(O0VAA;FYE;$9I;&4`````````````````````````````````
M````````````````````````````````````````,#`P-S4U(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S(@,#(Q,S`U`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]#:&%N;F5L1FEL92]087)S97(N
M<&AP````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-#(S,"`Q,#4Q-30S
M,S<S,B`P,C,S,S``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`-"B\J*@T*("H@4$5!4E]#:&%N;F5L1FEL95]087)S
M97(@9F]R('!A<G-I;F<@8VAA;FYE;"YX;6P-"B`J#0H@*B!02%`@=F5R<VEO
M;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@
M:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-
M"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M
M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@
M82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@
M=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD
M(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U
M(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R
M#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E
M879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P
M,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`
M=F5R<VEO;B`@("!#5E,Z("1)9#H@4&%R<V5R+G!H<"QV(#$N-"`R,#`V+S`Q
M+S`V(#`T.C0W.C,V(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T
M<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@
M($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0H-
M"B\J*@T*("H@8F%S92!X;6P@<&%R<V5R(&-L87-S#0H@*B\-"G)E<75I<F5?
M;VYC92`G4$5!4B]834Q087)S97(N<&AP)SL-"G)E<75I<F5?;VYC92`G4$5!
M4B]#:&%N;F5L1FEL92YP:'`G.PT*+RHJ#0H@*B!087)S97(@9F]R(&-H86YN
M96PN>&UL#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!0
M14%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN
M970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*
M("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E
M.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P
M86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S
M:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*8VQA<W,@4$5!4E]#:&%N;F5L
M1FEL95]087)S97(@97AT96YD<R!014%27UA-3%!A<G-E<@T*>PT*("`@('9A
M<B`D7V-O;F9I9SL-"B`@("!V87(@)%]L;V=G97([#0H@("`@=F%R("1?<F5G
M:7-T<GD[#0H-"B`@("!F=6YC=&EO;B!S971#;VYF:6<H)B1C*0T*("`@('L-
M"B`@("`@("`@)'1H:7,M/E]C;VYF:6<@/2`F)&,[#0H@("`@("`@("1T:&ES
M+3Y?<F5G:7-T<GD@/2`F)&,M/F=E=%)E9VES=')Y*"D[#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@<V5T3&]G9V5R*"8D;"D-"B`@("![#0H@("`@("`@("1T
M:&ES+3Y?;&]G9V5R(#T@)B1L.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('!A
M<G-E*"1D871A+"`D9FEL92D-"B`@("![#0H@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1E<G(@/2!P87)E;G0Z.G!A<G-E*"1D871A+"`D9FEL92DI*2![
M#0H@("`@("`@("`@("!R971U<FX@)&5R<CL-"B`@("`@("`@?0T*("`@("`@
M("`D<F5T(#T@;F5W(%!%05)?0VAA;FYE;$9I;&4[#0H@("`@("`@("1R970M
M/G-E=$-O;F9I9R@D=&AI<RT^7V-O;F9I9RD[#0H@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7VQO9V=E<BDI('L-"B`@("`@("`@("`@("1R970M/G-E=$QO
M9V=E<B@D=&AI<RT^7VQO9V=E<BD[#0H@("`@("`@('T-"B`@("`@("`@)')E
M="T^9G)O;4%R<F%Y*"1T:&ES+3Y?=6YS97)I86QI>F5D1&%T82D[#0H@("`@
M("`@("\O(&UA:V4@<W5R92!T:&4@9FEL96QI<W0@:7,@:6X@=&AE(&5A<WD@
M=&\@<F5A9"!F;W)M870@;F5E9&5D#0H@("`@("`@("1R970M/F9L871T96Y&
M:6QE;&ES="@I.PT*("`@("`@("`D<F5T+3YS971086-K86=E9FEL92@D9FEL
M92P@)&%R8VAI=F4I.PT*("`@("`@("!R971U<FX@)')E=#L-"B`@("!]#0I]
M#0H_/@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]$;W=N;&]A
M9&5R+G!H<```````````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#$V
M-C0Q,R`Q,#4Q-30S,S<S,B`P,C(P,S8`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`-"B\J*@T*("H@4$5!4E]$;W=N
M;&]A9&5R+"!T:&4@4$5!4B!);G-T86QL97(G<R!D;W=N;&]A9"!U=&EL:71Y
M(&-L87-S#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,
M24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO
M;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L
M92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG
M(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N
M("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(
M4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H
M('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P
M:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN
M#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!
M4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T
M/@T*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*
M("H@0&%U=&AO<B`@("`@5&]M87,@5BX@5BX@0V]X(#QC;WA`:61E8VYE="YC
M;VT^#0H@*B!`875T:&]R("`@("!-87)T:6X@2F%N<V5N(#QM:D!P:'`N;F5T
M/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J
M($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT
M>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z
M($1O=VYL;V%D97(N<&AP+'8@,2XY.2`R,#`V+S`S+S`R(#$X.C$T.C$S(&-E
M;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE
M="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE
M('-I;F-E(%)E;&5A<V4@,2XS+C`-"B`J+PT*#0HO*BH-"B`J($YE961E9"!F
M;W(@8V]N<W1A;G1S+"!E>'1E;F1I;F<-"B`J+PT*<F5Q=6ER95]O;F-E("=0
M14%2+T-O;6UO;BYP:'`G.PT*#0ID969I;F4H)U!%05)?24Y35$%,3$527T]+
M)RP@("`@("`@,2D[#0ID969I;F4H)U!%05)?24Y35$%,3$527T9!24Q%1"<L
M("`@,"D[#0ID969I;F4H)U!%05)?24Y35$%,3$527U-+25!0140G+"`M,2D[
M#0ID969I;F4H)U!%05)?24Y35$%,3$527T524D]27TY/7U!2149?4U1!5$4G
M+"`R*3L-"@T*+RHJ#0H@*B!!9&UI;FES=')A=&EO;B!C;&%S<R!U<V5D('1O
M(&1O=VYL;V%D(&%N>71H:6YG(&9R;VT@=&AE(&EN=&5R;F5T("A014%2(%!A
M8VMA9V5S+`T*("H@<W1A=&EC(%523',L('AM;"!F:6QE<RD-"B`J#0H@*B!`
M8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T
M:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`875T
M:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R
M("`@("!4;VUA<R!6+B!6+B!#;W@@/&-O>$!I9&5C;F5T+F-O;3X-"B`J($!A
M=71H;W(@("`@($UA<G1I;B!*86YS96X@/&UJ0'!H<"YN970^#0H@*B!`8V]P
M>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@
M("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI
M8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@
M0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-
M"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E
M(#$N,RXP#0H@*B\-"F-L87-S(%!%05)?1&]W;FQO861E<B!E>'1E;F1S(%!%
M05)?0V]M;6]N#0I[#0H@("`@+RHJ#0H@("`@("H@0'9A<B!014%27U)E9VES
M=')Y#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R
M("1?<F5G:7-T<GD[#0H-"B`@("`O*BH-"B`@("`@*B!`=F%R(%!%05)?4F5M
M;W1E#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R
M("1?<F5M;W1E.PT*#0H@("`@+RHJ#0H@("`@("H@4')E9F5R<F5D($EN<W1A
M;&QA=&EO;B!3=&%T92`H<VYA<'-H;W0L(&1E=F5L+"!A;'!H82P@8F5T82P@
M<W1A8FQE*0T*("`@("`J($!V87(@<W1R:6YG?&YU;&P-"B`@("`@*B!`86-C
M97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!V87(@)%]P<F5F97)R9613=&%T
M93L-"@T*("`@("\J*@T*("`@("`J($]P=&EO;G,@9G)O;2!C;VUM86YD+6QI
M;F4@<&%S<V5D('1O($EN<W1A;&PN#0H@("`@("H-"B`@("`@*B!296-O9VYI
M>F5D(&]P=&EO;G,Z/&)R("\^#0H@("`@("H@("T@;VYL>7)E<61E<',@("`Z
M(&EN<W1A;&P@86QL(')E<75I<F5D(&1E<&5N9&5N8VEE<R!A<R!W96QL#0H@
M("`@("H@("T@86QL9&5P<R`@("`@("`Z(&EN<W1A;&P@86QL(&1E<&5N9&5N
M8VEE<RP@:6YC;'5D:6YG(&]P=&EO;F%L#0H@("`@("H@("T@:6YS=&%L;')O
M;W0@("`Z(&)A<V4@<F5L871I=F4@<&%T:"!T;R!I;G-T86QL(&9I;&5S(&EN
M#0H@("`@("H@("T@9F]R8V4@("`@("`@("`Z(&9O<F-E(&$@9&]W;FQO860@
M979E;B!I9B!W87)N:6YG<R!W;W5L9"!P<F5V96YT(&ET#0H@("`@("H@("T@
M;F]C;VUP<F5S<R`@("`Z(&1O=VYL;V%D('5N8V]M<')E<W-E9"!T87)B86QL
M<PT*("`@("`J($!S964@4$5!4E]#;VUM86YD7TEN<W1A;&P-"B`@("`@*B!`
M86-C97-S('!R:79A=&4-"B`@("`@*B!`=F%R(&%R<F%Y#0H@("`@("HO#0H@
M("`@=F%R("1?;W!T:6]N<SL-"@T*("`@("\J*@T*("`@("`J($1O=VYL;V%D
M960@4&%C:V%G97,@869T97(@82!C86QL('1O(&1O=VYL;V%D*"DN#0H@("`@
M("H-"B`@("`@*B!&;W)M870@;V8@96%C:"!E;G1R>3H-"B`@("`@*@T*("`@
M("`J(#QC;V1E/@T*("`@("`J(&%R<F%Y*"=P:V<G(#T^("=P86-K86=E7VYA
M;64G+"`G9FEL92<@/3X@)R]P871H+W1O+VQO8V%L+V9I;&4G+`T*("`@("`J
M("`@("=I;F9O)R`]/B!A<G)A>2@I("\O('!A<G-E9"!P86-K86=E+GAM;`T*
M("`@("`J("D[#0H@("`@("H@/"]C;V1E/@T*("`@("`J($!A8V-E<W,@<')I
M=F%T90T*("`@("`J($!V87(@87)R87D-"B`@("`@*B\-"B`@("!V87(@)%]D
M;W=N;&]A9&5D4&%C:V%G97,@/2!A<G)A>2@I.PT*#0H@("`@+RHJ#0H@("`@
M("H@4&%C:V%G97,@<VQA=&5D(&9O<B!D;W=N;&]A9"X-"B`@("`@*@T*("`@
M("`J(%1H:7,@:7,@=7-E9"!T;R!P<F5V96YT(&1O=VYL;V%D:6YG(&$@<&%C
M:V%G92!M;W)E('1H86X@;VYC92!S:&]U;&0@:70@8F4@82!D97!E;F1E;F-Y
M#0H@("`@("H@9F]R('1W;R!P86-K86=E<R!T;R!B92!I;G-T86QL960N#0H@
M("`@("H@1F]R;6%T(&]F(&5A8V@@96YT<GDZ#0H@("`@("H-"B`@("`@*B`\
M<')E/@T*("`@("`J(&%R<F%Y*"=P86-K86=E7VYA;64Q)R`]/B!P87)S960@
M<&%C:V%G92YX;6PL("=P86-K86=E7VYA;64R)R`]/B!P87)S960@<&%C:V%G
M92YX;6PL#0H@("`@("H@*3L-"B`@("`@*B`\+W!R93X-"B`@("`@*B!`86-C
M97-S('!R:79A=&4-"B`@("`@*B!`=F%R(&%R<F%Y#0H@("`@("HO#0H@("`@
M=F%R("1?=&]$;W=N;&]A9"`](&%R<F%Y*"D[#0H-"B`@("`O*BH-"B`@("`@
M*B!!<G)A>2!O9B!E=F5R>2!P86-K86=E(&EN<W1A;&QE9"P@=VET:"!N86UE
M<R!L;W=E<BUC87-E9"X-"B`@("`@*@T*("`@("`J($9O<FUA=#H-"B`@("`@
M*B`\8V]D93X-"B`@("`@*B!A<G)A>2@G<&%C:V%G93$G(#T^(#`L("=P86-K
M86=E,B<@/3X@,2P@*3L-"B`@("`@*B`\+V-O9&4^#0H@("`@("H@0'9A<B!A
M<G)A>0T*("`@("`J+PT*("`@('9A<B`D7VEN<W1A;&QE9"`](&%R<F%Y*"D[
M#0H-"B`@("`O*BH-"B`@("`@*B!`=F%R(&%R<F%Y#0H@("`@("H@0&%C8V5S
M<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?97)R;W)3=&%C:R`](&%R
M<F%Y*"D[#0H@("`@#0H@("`@+RHJ#0H@("`@("H@0'9A<B!B;V]L96%N#0H@
M("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?:6YT
M97)N86Q$;W=N;&]A9"`](&9A;'-E.PT*#0H@("`@+RHJ#0H@("`@("H@5&5M
M<&]R87)Y('9A<FEA8FQE('5S960@:6X@<V]R=&EN9R!P86-K86=E<R!B>2!D
M97!E;F1E;F-Y(&EN('M`;&EN:R!S;W)T4&MG1&5P<R@I?0T*("`@("`J($!V
M87(@87)R87D-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@
M("!V87(@)%]P86-K86=E4V]R=%1R964[#0H-"B`@("`O*BH-"B`@("`@*B!4
M96UP;W)A<GD@9&ER96-T;W)Y+"!O<B!C;VYF:6=U<F%T:6]N('9A;'5E('=H
M97)E(&1O=VYL;V%D<R!W:6QL(&]C8W5R#0H@("`@("H@0'9A<B!S=')I;F<-
M"B`@("`@*B\-"B`@("!V87(@)%]D;W=N;&]A9$1I<CL-"B`@("`O+R![>WL@
M4$5!4E]$;W=N;&]A9&5R*"D-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!0
M14%27T9R;VYT96YD7RH-"B`@("`@*B!`<&%R86T@87)R87D-"B`@("`@*B!`
M<&%R86T@4$5!4E]#;VYF:6<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!014%2
M7T1O=VYL;V%D97(H)B1U:2P@)&]P=&EO;G,L("8D8V]N9FEG*0T*("`@('L-
M"B`@("`@("`@<&%R96YT.CI014%27T-O;6UO;B@I.PT*("`@("`@("`D=&AI
M<RT^7V]P=&EO;G,@/2`D;W!T:6]N<SL-"B`@("`@("`@)'1H:7,M/F-O;F9I
M9R`]("8D8V]N9FEG.PT*("`@("`@("`D=&AI<RT^7W!R969E<G)E9%-T871E
M(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=P<F5F97)R961?<W1A=&4G*3L-"B`@
M("`@("`@)'1H:7,M/G5I(#T@)B1U:3L-"B`@("`@("`@:68@*"$D=&AI<RT^
M7W!R969E<G)E9%-T871E*2![#0H@("`@("`@("`@("`O+R!D;VXG="!I;F%D
M=F5R=&%N=&QY('5S92!A(&YO;BUS970@<')E9F5R<F5D7W-T871E#0H@("`@
M("`@("`@("`D=&AI<RT^7W!R969E<G)E9%-T871E(#T@;G5L;#L-"B`@("`@
M("`@?0T*#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V]P=&EO;G-;)VEN
M<W1A;&QR;V]T)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^8V]N9FEG+3YS
M971);G-T86QL4F]O="@D=&AI<RT^7V]P=&EO;G-;)VEN<W1A;&QR;V]T)UTI
M.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?<F5G:7-T<GD@/2`F)&-O
M;F9I9RT^9V5T4F5G:7-T<GDH*3L-"B`@("`@("`@)'1H:7,M/E]R96UO=&4@
M/2`F)&-O;F9I9RT^9V5T4F5M;W1E*"D[#0H-"B`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?;W!T:6]N<ULG86QL9&5P<R==*2!\?"!I<W-E="@D=&AI<RT^
M7V]P=&EO;G-;)V]N;'ER97%D97!S)UTI*2![#0H@("`@("`@("`@("`D=&AI
M<RT^7VEN<W1A;&QE9"`]("1T:&ES+3Y?<F5G:7-T<GDM/FQI<W1!;&Q086-K
M86=E<R@I.PT*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]I;G-T86QL
M960@87,@)&ME>2`]/B`D=6YU<V5D*2![#0H@("`@("`@("`@("`@("`@:68@
M*"%C;W5N="@D=6YU<V5D*2D@>PT*("`@("`@("`@("`@("`@("`@("!C;VYT
M:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@0&%R
M<F%Y7W=A;&LH)'1H:7,M/E]I;G-T86QL961;)&ME>5TL("=S=')T;VQO=V5R
M)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O
M*BH-"B`@("`@*B!!='1E;7!T('1O(&1I<V-O=F5R(&$@8VAA;FYE;"=S(')E
M;6]T92!C87!A8FEL:71I97,@9G)O;0T*("`@("`J(&ET<R!S97)V97(@;F%M
M90T*("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!D:7-C;W9E<B@D8VAA;FYE;"D-
M"B`@("![#0H@("`@("`@("1T:&ES+3YL;V<H,2P@)T%T=&5M<'1I;F<@=&\@
M9&ES8V]V97(@8VAA;FYE;"`B)R`N("1C:&%N;F5L("X@)R(N+BXG*3L-"B`@
M("`@("`@4$5!4CHZ<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]21515
M4DXI.PT*("`@("`@("`D8V%L;&)A8VL@/2`D=&AI<RT^=6D@/R!A<G)A>2@F
M)'1H:7,L("=?9&]W;FQO861#86QL8F%C:R<I(#H@;G5L;#L-"B`@("`@("`@
M:68@*"%C;&%S<U]E>&ES=',H)U-Y<W1E;2<I*2![#0H@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)U-Y<W1E;2YP:'`G.PT*("`@("`@("!]#0H@("`@("`@
M("1A(#T@)'1H:7,M/F1O=VYL;V%D2'1T<"@G:'1T<#HO+R<@+B`D8VAA;FYE
M;"`N("<O8VAA;FYE;"YX;6PG+"`D=&AI<RT^=6DL#0H@("`@("`@("`@("!3
M>7-T96TZ.FUK=&5M<"AA<G)A>2@G+60G*2DL("1C86QL8F%C:RP@9F%L<V4I
M.PT*("`@("`@("!014%2.CIP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@
M(&EF("A014%2.CII<T5R<F]R*"1A*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&QI<W0H)&$L("1L87-T;6]D
M:69I960I(#T@)&$[#0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%2
M+T-H86YN96Q&:6QE+G!H<"<I*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N
M8V4@)U!%05(O0VAA;FYE;$9I;&4N<&AP)SL-"B`@("`@("`@?0T*("`@("`@
M("`D8B`](&YE=R!014%27T-H86YN96Q&:6QE.PT*("`@("`@("!I9B`H)&(M
M/F9R;VU8;6Q&:6QE*"1A*2D@>PT*("`@("`@("`@("`@0'5N;&EN:R@D82D[
M#0H@("`@("`@("`@("!I9B`H)'1H:7,M/F-O;F9I9RT^9V5T*"=A=71O7V1I
M<V-O=F5R)RDI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W)E9VES=')Y
M+3YA9&1#:&%N;F5L*"1B+"`D;&%S=&UO9&EF:65D*3L-"B`@("`@("`@("`@
M("`@("`D86QI87,@/2`D8BT^9V5T3F%M92@I.PT*("`@("`@("`@("`@("`@
M(&EF("@D8BT^9V5T3F%M92@I(#T]("1T:&ES+3Y?<F5G:7-T<GDM/F-H86YN
M96Q.86UE*"1B+3YG971!;&EA<R@I*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`D86QI87,@/2`D8BT^9V5T06QI87,H*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@Q+"`G075T;RUD:7-C;W9E
M<F5D(&-H86YN96P@(B<@+B`D8VAA;FYE;"`N#0H@("`@("`@("`@("`@("`@
M("`@("<B+"!A;&EA<R`B)R`N("1A;&EA<R`N("<B+"!A9&1I;F<@=&\@<F5G
M:7-T<GDG*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PT*("`@("`@("!]#0H@("`@("`@($!U;FQI;FLH)&$I.PT*("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@1F]R
M('-I;7!L97(@=6YI="UT97-T:6YG#0H@("`@("H@0'!A<F%M(%!%05)?1&]W
M;FQO861E<@T*("`@("`J($!R971U<FX@4$5!4E]$;W=N;&]A9&5R7U!A8VMA
M9V4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F;F5W1&]W;FQO861E<E!A8VMA
M9V4H)B1T*0T*("`@('L-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%
M05)?1&]W;FQO861E<E]086-K86=E)RDI('L-"B`@("`@("`@("`@(')E<75I
M<F5?;VYC92`G4$5!4B]$;W=N;&]A9&5R+U!A8VMA9V4N<&AP)SL-"B`@("`@
M("`@?0T*("`@("`@("`D82`]("9N97<@4$5!4E]$;W=N;&]A9&5R7U!A8VMA
M9V4H)'0I.PT*("`@("`@("!R971U<FX@)&$[#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@("H@1F]R('-I;7!L97(@=6YI="UT97-T:6YG#0H@("`@("H@0'!A
M<F%M(%!%05)?0V]N9FEG#0H@("`@("H@0'!A<F%M(&%R<F%Y#0H@("`@("H@
M0'!A<F%M(&%R<F%Y#0H@("`@("H@0'!A<F%M(&EN=`T*("`@("`J+PT*("`@
M(&9U;F-T:6]N("9G971$97!E;F1E;F-Y,D]B:F5C="@F)&,L("1I+"`D<"P@
M)',I#0H@("`@>PT*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!4B]$
M97!E;F1E;F-Y,BYP:'`G*2D@>PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E
M("=014%2+T1E<&5N9&5N8WDR+G!H<"<[#0H@("`@("`@('T-"B`@("`@("`@
M)'H@/2`F;F5W(%!%05)?1&5P96YD96YC>3(H)&,L("1I+"`D<"P@)',I.PT*
M("`@("`@("!R971U<FX@)'H[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@)F1O
M=VYL;V%D*"1P87)A;7,I#0H@("`@>PT*("`@("`@("!I9B`H(6-O=6YT*"1P
M87)A;7,I*2![#0H@("`@("`@("`@("`D82`](&%R<F%Y*"D[#0H@("`@("`@
M("`@("!R971U<FX@)&$[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<W-E
M="@D=&AI<RT^7W)E9VES=')Y*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]R
M96=I<W1R>2`]("8D=&AI<RT^8V]N9FEG+3YG971296=I<W1R>2@I.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]R96UO=&4I*2![
M#0H@("`@("`@("`@("`D=&AI<RT^7W)E;6]T92`]("8D=&AI<RT^8V]N9FEG
M+3YG971296UO=&4H*3L-"B`@("`@("`@?0T*("`@("`@("`D8VAA;FYE;'-C
M:&5C:V5D(#T@87)R87DH*3L-"B`@("`@("`@+R\@8V]N=F5R="!A;&P@<&%R
M86UE=&5R<R!I;G1O(%!%05)?1&]W;FQO861E<E]086-K86=E(&]B:F5C=',-
M"B`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D:2`]/B`D<&%R86TI('L-
M"B`@("`@("`@("`@("1P87)A;7-;)&E=(#T@)B1T:&ES+3YN97=$;W=N;&]A
M9&5R4&%C:V%G92@D=&AI<RD[#0H@("`@("`@("`@("!014%2.CIS=&%T:6-0
M=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@
M("`@("`D97)R(#T@)'!A<F%M<ULD:5TM/FEN:71I86QI>F4H)'!A<F%M*3L-
M"B`@("`@("`@("`@(%!%05(Z.G-T871I8U!O<$5R<F]R2&%N9&QI;F<H*3L-
M"B`@("`@("`@("`@(&EF("@A)&5R<BD@>PT*("`@("`@("`@("`@("`@("\O
M('-K:7`@<&%R86UE=&5R<R!T:&%T('=E<F4@;6ES<V5D(&)Y('!R969E<G)E
M9%]S=&%T90T*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<BDI('L-
M"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG
M<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L
M("1E<G(M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("1P87)A;7-;)&E=(#T@9F%L<V4[#0H@("`@("`@("`@
M("`@("`@:68@*&ES7V]B:F5C="@D<&%R86TI*2![#0H@("`@("`@("`@("`@
M("`@("`@("1P87)A;2`]("1P87)A;2T^9V5T0VAA;FYE;"@I("X@)R\G("X@
M)'!A<F%M+3YG971086-K86=E*"D[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("1T:&ES+3YP=7-H17)R;W(H)U!A8VMA9V4@(B<@+B`D
M<&%R86T@+B`G(B!I<R!N;W0@=F%L:60G+`T*("`@("`@("`@("`@("`@("`@
M("!014%27TE.4U1!3$Q%4E]32TE04$5$*3L-"B`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@:68@*"1P87)A;7-;)&E=("8F("%I<W-E
M="@D8VAA;FYE;'-C:&5C:V5D6R1P87)A;7-;)&E=+3YG971#:&%N;F5L*"E=
M*2`F)@T*("`@("`@("`@("`@("`@("`@("`@("%I<W-E="@D=&AI<RT^7V]P
M=&EO;G-;)V]F9FQI;F4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)&-H
M86YN96QS8VAE8VME9%LD<&%R86US6R1I72T^9V5T0VAA;FYE;"@I72`]('1R
M=64[#0H@("`@("`@("`@("`@("`@("`@(%!%05(Z.G-T871I8U!U<VA%<G)O
M<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@("`@("`@
M("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U-Y<W1E;2<I*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U-Y<W1E;2YP:'`G.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1C
M=7)C:&%N;F5L(#T@)B1T:&ES+3Y?<F5G:7-T<GDM/F=E=$-H86YN96PH)'!A
M<F%M<ULD:5TM/F=E=$-H86YN96PH*2D[#0H@("`@("`@("`@("`@("`@("`@
M(&EF("A014%2.CII<T5R<F]R*"1C=7)C:&%N;F5L*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@4$5!4CHZ<W1A=&EC4&]P17)R;W)(86YD;&EN9R@I
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*"1C=7)C:&%N;F5L*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`D82`]("1T:&ES+3YD;W=N;&]A9$AT='`H
M)VAT='`Z+R\G("X@)'!A<F%M<ULD:5TM/F=E=$-H86YN96PH*2`N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`G+V-H86YN96PN>&UL)RP@)'1H:7,M/G5I
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@4WES=&5M.CIM:W1E;7`H87)R
M87DH)RUD)RDI+"!N=6QL+"`D8W5R8VAA;FYE;"T^;&%S=$UO9&EF:65D*"DI
M.PT*("`@("`@("`@("`@("`@("`@("!014%2.CIS=&%T:6-0;W!%<G)O<DAA
M;F1L:6YG*"D[#0H@("`@("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1A*2!\?"`A)&$I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YL;V<H,"P@)U=!4DY)3D<Z(&-H86YN96P@(B<@+B`D
M<&%R86US6R1I72T^9V5T0VAA;FYE;"@I("X@)R(@:&%S("<@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@)W5P9&%T960@:71S('!R;W1O8V]L<RP@=7-E
M(")C:&%N;F5L+75P9&%T92`G("X@)'!A<F%M<ULD:5TM/F=E=$-H86YN96PH
M*2`N#0H@("`@("`@("`@("`@("`@("`@("`@("`G(B!T;R!U<&1A=&4G*3L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"1P87)A
M;7-;)&E=("8F("%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)V1O=VYL;V%D;VYL
M>2==*2D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/E]O<'1I;VYS6R=P86-K86=I;F=R;V]T)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D8VAE8VMD:7(@/2`D=&AI<RT^7W!R97!E;F10871H*`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC;VYF:6<M/F=E
M="@G<&AP7V1I<B<L(&YU;&PL("1P87)A;7-;)&E=+3YG971#:&%N;F5L*"DI
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;W!T:6]N
M<ULG<&%C:V%G:6YG<F]O="==*3L-"B`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1C:&5C:V1I<B`]("1T
M:&ES+3YC;VYF:6<M/F=E="@G<&AP7V1I<B<L#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@;G5L;"P@)'!A<F%M<ULD:5TM/F=E=$-H86YN96PH*2D[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M=VAI;&4@*"1C:&5C:V1I<B`F)B`D8VAE8VMD:7(@(3T@)R\G("8F("%F:6QE
M7V5X:7-T<R@D8VAE8VMD:7(I*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D8VAE8VMD:7(@/2!D:7)N86UE*"1C:&5C:V1I<BD[#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"1C:&5C:V1I
M<B`]/2`G+B<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1C:&5C:V1I
M<B`]("<O)SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("!I9B`H(4!I<U]W<FET96%B;&4H)&-H96-K9&ER*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)T-A;FYO="!I;G-T86QL+"!P:'!?9&ER(&9O<B!C:&%N;F5L("(G("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86US6R1I72T^9V5T0VAA
M;FYE;"@I("X@)R(@:7,@;F]T('=R:71E86)L92!B>2!T:&4@8W5R<F5N="!U
M<V5R)RD[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@=6YS970H
M)&-H86YN96QS8VAE8VME9"D[#0H@("`@("`@(%!%05)?1&]W;FQO861E<E]0
M86-K86=E.CIR96UO=F5$=7!L:6-A=&5S*"1P87)A;7,I.PT*("`@("`@("!I
M9B`H(6-O=6YT*"1P87)A;7,I*2![#0H@("`@("`@("`@("`D82`](&%R<F%Y
M*"D[#0H@("`@("`@("`@("!R971U<FX@)&$[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)VYO9&5P<R==*2`F)B`A
M:7-S970H)'1H:7,M/E]O<'1I;VYS6R=O9F9L:6YE)UTI*2![#0H@("`@("`@
M("`@("`D<F5V97)I9GD@/2!T<G5E.PT*("`@("`@("`@("`@=VAI;&4@*"1R
M979E<FEF>2D@>PT*("`@("`@("`@("`@("`@("1R979E<FEF>2`](&9A;'-E
M.PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)&D@/3X@
M)'!A<F%M*2![#0H@("`@("`@("`@("`@("`@("`@("1R970@/2`D<&%R86US
M6R1I72T^9&5T96-T1&5P96YD96YC:65S*"1P87)A;7,I.PT*("`@("`@("`@
M("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5T*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)')E=F5R:69Y(#T@=')U93L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1P87)A;7-;)&E=(#T@9F%L<V4[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!014%27T1O=VYL;V%D97)?4&%C:V%G93HZ<F5M
M;W9E1'5P;&EC871E<R@D<&%R86US*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=S;V9T)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`D<F5T
M+3YG971-97-S86=E*"DI.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64@,CL-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]O<'1I
M;VYS6R=O9F9L:6YE)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^;&]G*#,L
M("=3:VEP<&EN9R!D97!E;F1E;F-Y(&1O=VYL;V%D(&-H96-K+"`M+6]F9FQI
M;F4@<W!E8VEF:65D)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%C;W5N
M="@D<&%R86US*2D@>PT*("`@("`@("`@("`@)&$@/2!A<G)A>2@I.PT*("`@
M("`@("`@("`@<F5T=7)N("1A.PT*("`@("`@("!]#0H@("`@("`@('=H:6QE
M("A014%27T1O=VYL;V%D97)?4&%C:V%G93HZ;65R9V5$97!E;F1E;F-I97,H
M)'!A<F%M<RDI.PT*("`@("`@("!014%27T1O=VYL;V%D97)?4&%C:V%G93HZ
M<F5M;W9E26YS=&%L;&5D*"1P87)A;7,I.PT*("`@("`@("!I9B`H(6-O=6YT
M*"1P87)A;7,I*2![#0H@("`@("`@("`@("`D=&AI<RT^<'5S:$5R<F]R*"=.
M;R!V86QI9"!P86-K86=E<R!F;W5N9"<L(%!%05)?24Y35$%,3$527T9!24Q%
M1"D[#0H@("`@("`@("`@("`D82`](&%R<F%Y*"D[#0H@("`@("`@("`@("!R
M971U<FX@)&$[#0H@("`@("`@('T-"B`@("`@("`@4$5!4CHZ<'5S:$5R<F]R
M2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`D97)R(#T@
M)'1H:7,M/F%N86QY>F5$97!E;F1E;F-I97,H)'!A<F%M<RD[#0H@("`@("`@
M(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@:68@*"%C;W5N
M="@D<&%R86US*2D@>PT*("`@("`@("`@("`@)'1H:7,M/G!U<VA%<G)O<B@G
M3F\@=F%L:60@<&%C:V%G97,@9F]U;F0G+"!014%27TE.4U1!3$Q%4E]&04E,
M140I.PT*("`@("`@("`@("`@)&$@/2!A<G)A>2@I.PT*("`@("`@("`@("`@
M<F5T=7)N("1A.PT*("`@("`@("!]#0H@("`@("`@("1R970@/2!A<G)A>2@I
M.PT*("`@("`@("`D;F5W<&%R86US(#T@87)R87DH*3L-"B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG<')E=&5N9"==*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1P87)A;7,[#0H@("`@("`@('T-"B`@("`@("`@9F]R
M96%C:"`H)'!A<F%M<R!A<R`D:2`]/B`D<&%C:V%G92D@>PT*("`@("`@("`@
M("`@4$5!4CHZ<W1A=&EC4'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]2
M15154DXI.PT*("`@("`@("`@("`@)'!F(#T@)B1P87)A;7-;)&E=+3YD;W=N
M;&]A9"@I.PT*("`@("`@("`@("`@4$5!4CHZ<W1A=&EC4&]P17)R;W)(86YD
M;&EN9R@I.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'!F*2D@
M>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS
M6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H
M,2P@)'!F+3YG971-97-S86=E*"DI.PT*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^;&]G*#`L("=%<G)O<CH@8V%N;F]T(&1O=VYL;V%D("(G("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E
M9%!A8VMA9V5.86UE5&]3=')I;F<H)'!A8VMA9V4M/F=E=%!A<G-E9%!A8VMA
M9V4H*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!T<G5E*2`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`G(B<I.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("1N97=P87)A;7-;72`]("8D<&%R86US6R1I73L-"B`@
M("`@("`@("`@("1R971;72`](&%R<F%Y*"=F:6QE)R`]/B`D<&8M/F=E=$%R
M8VAI=F5&:6QE*"DL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=I;F9O)R`]/B`F)'!F+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G<&MG)R`]/B`D<&8M/F=E=%!A8VMA9V4H*2D[#0H@("`@
M("`@('T-"B`@("`@("`@)'1H:7,M/E]D;W=N;&]A9&5D4&%C:V%G97,@/2`D
M<F5T.PT*("`@("`@("!R971U<FX@)&YE=W!A<F%M<SL-"B`@("!]#0H-"B`@
M("`O*BH-"B`@("`@*B!`<&%R86T@87)R87D@86QL('!A8VMA9V5S('1O(&)E
M(&EN<W1A;&QE9`T*("`@("`J+PT*("`@(&9U;F-T:6]N(&%N86QY>F5$97!E
M;F1E;F-I97,H)B1P87)A;7,I#0H@("`@>PT*("`@("`@("`D:&%S9F%I;&5D
M(#T@)&9A:6QE9"`](&9A;'-E.PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/E]O<'1I;VYS6R=D;W=N;&]A9&]N;'DG72DI('L-"B`@("`@("`@("`@(')E
M='5R;CL-"B`@("`@("`@?0T*("`@("`@("!014%2.CIS=&%T:6-0=7-H17)R
M;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@("1R961O
M(#T@=')U93L-"B`@("`@("`@)')E<V5T(#T@9F%L<V4[#0H@("`@("`@('=H
M:6QE("@D<F5D;RD@>PT*("`@("`@("`@("`@)')E9&\@/2!F86QS93L-"B`@
M("`@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)&D@/3X@)'!A<F%M*2![
M#0H@("`@("`@("`@("`@("`@)&1E<',@/2`D<&%R86TM/F=E=$1E<',H*3L-
M"B`@("`@("`@("`@("`@("!I9B`H(21D97!S*2![#0H@("`@("`@("`@("`@
M("`@("`@("1D97!C:&5C:V5R(#T@)B1T:&ES+3YG971$97!E;F1E;F-Y,D]B
M:F5C="@D=&AI<RT^8V]N9FEG+"`D=&AI<RT^9V5T3W!T:6]N<R@I+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@)'!A<F%M+3YG971087)S961086-K86=E
M*"DL(%!%05)?5D%,241!5$5?1$]73DQ/041)3D<I.PT*("`@("`@("`@("`@
M("`@("`@("!I9B`H)'!A<F%M+3YG9714>7!E*"D@/3T@)WAM;')P8R<I('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1S96YD(#T@)'!A<F%M+3YG971$
M;W=N;&]A9%523"@I.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)'-E;F0@/2`D<&%R86TM/F=E=%!A
M8VMA9V5&:6QE*"D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@)&EN<W1A;&QC:&5C:R`]("1D97!C:&5C:V5R+3YV86QI
M9&%T95!A8VMA9V4H)'-E;F0L("1T:&ES+"`D<&%R86US*3L-"B`@("`@("`@
M("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&EN<W1A;&QC:&5C:RDI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/E]O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/FQO9R@P+"`D:6YS=&%L;&-H96-K+3YG971-97-S86=E
M*"DI.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`@("`@)&AA<V9A:6QE9"`]('1R=64[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D<&%R86US6R1I72`](&9A;'-E.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)')E<V5T(#T@=')U93L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1R961O(#T@=')U93L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1F86EL960@/2!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@("`@(%!%
M05)?1&]W;FQO861E<E]086-K86=E.CIR96UO=F5$=7!L:6-A=&5S*"1P87)A
M;7,I.PT*("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64@,CL-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!C;VYT
M:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@
M*"$D<F5S970@)B8@)'!A<F%M+3YA;')E861Y5F%L:61A=&5D*"DI('L-"B`@
M("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@(&EF("AC;W5N="@D9&5P<RDI('L-"B`@("`@
M("`@("`@("`@("`@("`@)&1E<&-H96-K97(@/2`F)'1H:7,M/F=E=$1E<&5N
M9&5N8WDR3V)J96-T*"1T:&ES+3YC;VYF:6<L("1T:&ES+3YG971/<'1I;VYS
M*"DL#0H@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86TM/F=E=%!A<G-E
M9%!A8VMA9V4H*2P@4$5!4E]604Q)1$%415]$3U=.3$]!1$E.1RD[#0H@("`@
M("`@("`@("`@("`@("`@(&EF("@D<&%R86TM/F=E=%1Y<&4H*2`]/2`G>&UL
M<G!C)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'-E;F0@/2`D<&%R
M86TM/F=E=$1O=VYL;V%D55),*"D[#0H@("`@("`@("`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`D<V5N9"`]("1P87)A
M;2T^9V5T4&%C:V%G949I;&4H*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`D:6YS=&%L;&-H96-K(#T@)&1E<&-H96-K
M97(M/G9A;&ED871E4&%C:V%G92@D<V5N9"P@)'1H:7,L("1P87)A;7,I.PT*
M("`@("`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YS=&%L
M;&-H96-K*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D=&AI<RT^7V]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L("1I;G-T86QL8VAE8VLM/F=E
M=$UE<W-A9V4H*2D[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D:&%S9F%I;&5D(#T@=')U93L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1P87)A;7-;)&E=(#T@9F%L<V4[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D<F5S970@/2!T<G5E.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)')E9&\@/2!T<G5E.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)&9A:6QE9"`](&9A;'-E.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@4$5!4E]$;W=N;&]A9&5R7U!A8VMA9V4Z.G)E;6]V941U<&QI8V%T
M97,H)'!A<F%M<RD[#0H@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU
M92`R.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("1F86EL960@/2!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1D97!S6R=R97%U:7)E9"==*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)&1E<'-;)W)E<75I<F5D)UT@87,@)'1Y<&4@
M/3X@)&1E<"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(&YO
M=&4Z($1E<&5N9&5N8WDR('=I;&P@;F5V97(@<F5T=7)N(&$@4$5!4E]%<G)O
M<B!I9B!I9VYO<F4M97)R;W)S#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+R\@:7,@<W!E8VEF:65D+"!S;R!S;V9T(&ES(&YE961E9"!T;R!T=7)N
M(&]F9B!L;V=G:6YG#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D9&5P6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92`]("1D97!C:&5C:V5R+3Y[
M(G9A;&ED871E>R1T>7!E?41E<&5N9&5N8WDB?2@D9&5P+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T<G5E+"`D<&%R86US*2DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F86EL
M960@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)W-O9G0G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M;&]G*#`L("1E+3YG971-97-S86=E*"DI.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!](&5L<V5I9B`H:7-?87)R87DH)&4I("8F("$D<&%R86TM/F%L
M<F5A9'E686QI9&%T960H*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)W-O9G0G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^;&]G*#`L("1E6S!=*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1D
M97`@87,@)&0I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1E(#T-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1D97!C:&5C:V5R+3Y[(G9A;&ED
M871E>R1T>7!E?41E<&5N9&5N8WDB?2@D9"P-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('1R=64L("1P87)A;7,I*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F86EL
M960@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=S;V9T)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YL;V<H,"P@)&4M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y*"1E
M*2`F)B`A)'!A<F%M+3YA;')E861Y5F%L:61A=&5D*"DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L("1E6S!=
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<'-;)V]P=&EO
M;F%L)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)&1E<'-;)V]P=&EO;F%L)UT@87,@)'1Y<&4@/3X@)&1E<"D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1D97!;
M,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D92`]#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9&5P8VAE8VME<BT^>R)V86QI9&%T97LD
M='EP97U$97!E;F1E;F-Y(GTH)&1E<"P-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&9A;'-E+"`D<&%R86US*2DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9F%I;&5D
M(#T@=')U93L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG<V]F="==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^;&]G*#`L("1E+3YG971-97-S86=E*"DI.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF("AI<U]A<G)A>2@D92D@
M)B8@(21P87)A;2T^86QR96%D>59A;&ED871E9"@I*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI
M<RT^7V]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`D95LP72D[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&1E<"!A<R`D
M9"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("A014%2.CII<T5R<F]R*"1E(#T-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P8VAE8VME<BT^>R)V86QI
M9&%T97LD='EP97U$97!E;F1E;F-Y(GTH)&0L#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F%L<V4L("1P87)A;7,I
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D9F%I;&5D(#T@=')U93L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO
M;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,"P@)&4M/F=E=$UE<W-A
M9V4H*2D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!](&5L<V5I9B`H:7-?87)R87DH)&4I("8F("$D<&%R86TM/F%L<F5A
M9'E686QI9&%T960H*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG
M<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`D95LP72D[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D9W)O=7!N86UE(#T@)'!A<F%M+3YG971'<F]U<"@I
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!S6R=G
M<F]U<"==*2`F)B`D9W)O=7!N86UE*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D9&5P<ULG9W)O=7`G75LP72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E<'-;)V=R;W5P)UT@
M/2!A<G)A>2@D9&5P<ULG9W)O=7`G72D[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F;W5N
M9"`](&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1D97!S6R=G<F]U<"==(&%S("1G<F]U<"D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H)&=R;W5P6R=A='1R:6)S)UU;)VYA
M;64G72`]/2`D9W)O=7!N86UE*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9F]U;F0@/2!T<G5E.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1F;W5N9"D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D9W)O
M=7!;)V%T=')I8G,G72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1G<F]U<"!A<R`D='EP92`]/B`D9&5P*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1D
M97!;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)&4@/0T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D97!C:&5C:V5R+3Y[
M(G9A;&ED871E>R1T>7!E?41E<&5N9&5N8WDB?2@D9&5P+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9A;'-E+"`D
M<&%R86US*2DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&9A:6QE9"`]('1R=64[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/E]O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L("1E+3YG
M971-97-S86=E*"DI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y*"1E*2`F)B`A)'!A<F%M
M+3YA;')E861Y5F%L:61A=&5D*"DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P
M=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,"P@)&5;,%TI.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W)E
M86-H("@D9&5P(&%S("1D*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E(#T-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&1E<&-H96-K97(M/GLB=F%L:61A=&5[)'1Y<&5]1&5P96YD96YC>2)]
M*"1D+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!F86QS92P@)'!A<F%M<RDI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9F%I;&5D(#T@
M=')U93L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=S;V9T)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`D92T^9V5T365S<V%G92@I*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y*"1E*2`F)B`A)'!A<F%M+3YA;')E
M861Y5F%L:61A=&5D*"DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I
M;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`D95LP72D[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@("`@("`@("!F;W)E86-H("@D9&5P<R!A<R`D9&5P*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&4@
M/2`D9&5P8VAE8VME<BT^=F%L:61A=&5$97!E;F1E;F-Y,2@D9&5P+"`D<&%R
M86US*2DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9A
M:6QE9"`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L
M("1E+3YG971-97-S86=E*"DI.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M:68@*&ES7V%R<F%Y*"1E*2`F)B`A)'!A<F%M+3YA;')E861Y5F%L:61A=&5D
M*"DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I
M<W-E="@D=&AI<RT^7V]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,"P@)&5;,%TI
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("1P87)A;7-;)&E=+3YS971686QI9&%T960H*3L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"1F86EL960I('L-"B`@("`@
M("`@("`@("`@("`@("`@)&AA<V9A:6QE9"`]('1R=64[#0H@("`@("`@("`@
M("`@("`@("`@("1P87)A;7-;)&E=(#T@9F%L<V4[#0H@("`@("`@("`@("`@
M("`@("`@("1R97-E="`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@("1R
M961O(#T@=')U93L-"B`@("`@("`@("`@("`@("`@("`@)&9A:6QE9"`](&9A
M;'-E.PT*("`@("`@("`@("`@("`@("`@("!014%27T1O=VYL;V%D97)?4&%C
M:V%G93HZ<F5M;W9E1'5P;&EC871E<R@D<&%R86US*3L-"B`@("`@("`@("`@
M("`@("`@("`@8V]N=&EN=64@,CL-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@4$5!4CHZ<W1A=&EC4&]P
M17)R;W)(86YD;&EN9R@I.PT*("`@("`@("!I9B`H)&AA<V9A:6QE9"`F)B`H
M:7-S970H)'1H:7,M/E]O<'1I;VYS6R=I9VYO<F4M97)R;W)S)UTI('Q\#0H@
M("`@("`@("`@("`@(&ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;F]D97!S)UTI
M*2D@>PT*("`@("`@("`@("`@+R\@=&AI<R!I<R!P<F]B86)L>2!N;W0@;F5E
M9&5D+"!B=70@:G5S="!I;B!C87-E#0H@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@
M("1T:&ES+3YL;V<H,"P@)U=!4DY)3D<Z(&1E<&5N9&5N8VEE<R!F86EL960G
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J
M*@T*("`@("`J(%)E=')I979E('1H92!D:7)E8W1O<GD@=&AA="!D;W=N;&]A
M9',@=VEL;"!H87!P96X@:6X-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@
M("`@*B!`<F5T=7)N('-T<FEN9PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E
M=$1O=VYL;V%D1&ER*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^7V1O=VYL;V%D1&ER*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?9&]W;FQO861$:7([#0H@("`@("`@('T-"B`@("`@("`@)&1O=VYL;V%D
M9&ER(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=D;W=N;&]A9%]D:7(G*3L-"B`@
M("`@("`@:68@*&5M<'1Y*"1D;W=N;&]A9&1I<BDI('L-"B`@("`@("`@("`@
M(&EF("@A8VQA<W-?97AI<W1S*"=3>7-T96TG*2D@>PT*("`@("`@("`@("`@
M("`@(')E<75I<F5?;VYC92`G4WES=&5M+G!H<"<[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D9&]W;FQO861D:7(@
M/2!3>7-T96TZ.FUK=&5M<"@G+60G*2DI('L-"B`@("`@("`@("`@("`@("!R
M971U<FX@)&1O=VYL;V%D9&ER.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@)'1H:7,M/FQO9R@S+"`G*R!T;7`@9&ER(&-R96%T960@870@)R`N("1D
M;W=N;&]A9&1I<BD[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?9&]W;FQO861$:7(@/2`D9&]W;FQO861D:7([#0H@("`@?0T*#0H@("`@
M9G5N8W1I;VX@<V5T1&]W;FQO861$:7(H)&1I<BD-"B`@("![#0H@("`@("`@
M("1T:&ES+3Y?9&]W;FQO861$:7(@/2`D9&ER.PT*("`@('T-"@T*("`@("\O
M('U]?0T*("`@("\O('M[>R!C;VYF:6=3970H*0T*("`@(&9U;F-T:6]N(&-O
M;F9I9U-E="@D:V5Y+"`D=F%L=64L("1L87EE<B`]("=U<V5R)RP@)&-H86YN
M96P@/2!F86QS92D-"B`@("![#0H@("`@("`@("1T:&ES+3YC;VYF:6<M/G-E
M="@D:V5Y+"`D=F%L=64L("1L87EE<BP@)&-H86YN96PI.PT*("`@("`@("`D
M=&AI<RT^7W!R969E<G)E9%-T871E(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=P
M<F5F97)R961?<W1A=&4G+"!N=6QL+"`D8VAA;FYE;"D[#0H@("`@("`@(&EF
M("@A)'1H:7,M/E]P<F5F97)R9613=&%T92D@>PT*("`@("`@("`@("`@+R\@
M9&]N)W0@:6YA9'9E<G1A;G1L>2!U<V4@82!N;VXM<V5T('!R969E<G)E9%]S
M=&%T90T*("`@("`@("`@("`@)'1H:7,M/E]P<F5F97)R9613=&%T92`](&YU
M;&P[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![
M>WL@<V5T3W!T:6]N<R@I#0H@("`@9G5N8W1I;VX@<V5T3W!T:6]N<R@D;W!T
M:6]N<RD-"B`@("![#0H@("`@("`@("1T:&ES+3Y?;W!T:6]N<R`]("1O<'1I
M;VYS.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!S971/<'1I
M;VYS*"D-"B`@("!F=6YC=&EO;B!G971/<'1I;VYS*"D-"B`@("![#0H@("`@
M("`@(')E='5R;B`D=&AI<RT^7V]P=&EO;G,[#0H@("`@?0T*#0H@("`@+R\@
M?7U]#0H-"B`@("`O*BH-"B`@("`@*B!&;W(@<VEM<&QE<B!U;FET+71E<W1I
M;F<-"B`@("`@*B!`<&%R86T@4$5!4E]#;VYF:6<-"B`@("`@*B!`<&%R86T@
M:6YT#0H@("`@("H@0'!A<F%M('-T<FEN9PT*("`@("`J+PT*("`@(&9U;F-T
M:6]N("9G971086-K86=E9FEL94]B:F5C="@F)&,L("1D+"`D="`](&9A;'-E
M*0T*("`@('L-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?4&%C
M:V%G949I;&4G*2D@>PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2
M+U!A8VMA9V5&:6QE+G!H<"<[#0H@("`@("`@('T-"B`@("`@("`@)&$@/2`F
M;F5W(%!%05)?4&%C:V%G949I;&4H)&,L("1D+"`D="D[#0H@("`@("`@(')E
M='5R;B`D83L-"B`@("!]#0H-"B`@("`O+R![>WL@7V=E=%!A8VMA9V5$;W=N
M;&]A9%5R;"@I#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@87)R87D@;W5T
M<'5T(&]F('M`;&EN:R!P87)S95!A8VMA9V5.86UE*"E]#0H@("`@("H@0&%C
M8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7V=E=%!A8VMA
M9V5$;W=N;&]A9%5R;"@D<&%R<BD-"B`@("![#0H@("`@("`@("1C=7)C:&%N
M;F5L(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=D969A=6QT7V-H86YN96PG*3L-
M"B`@("`@("`@)'1H:7,M/F-O;F9I9U-E="@G9&5F875L=%]C:&%N;F5L)RP@
M)'!A<G);)V-H86YN96PG72D[#0H@("`@("`@("\O(&=E=$1O=VYL;V%D55),
M(')E='5R;G,@86X@87)R87DN("!/;B!E<G)O<BP@:70@;VYL>2!C;VYT86EN
M<R!I;F9O<FUA=&EO;@T*("`@("`@("`O+R!O;B!T:&4@;&%T97-T(')E;&5A
M<V4@87,@87)R87DH=F5R<VEO;BP@:6YF;RDN("!/;B!S=6-C97-S(&ET(&-O
M;G1A:6YS#0H@("`@("`@("\O(&%R<F%Y*'9E<G-I;VXL(&EN9F\L(&1O=VYL
M;V%D('5R;"!S=')I;F<I#0H@("`@("`@("1S=&%T92`](&ES<V5T*"1P87)R
M6R=S=&%T92==*2`_("1P87)R6R=S=&%T92==(#H@)'1H:7,M/F-O;F9I9RT^
M9V5T*"=P<F5F97)R961?<W1A=&4G*3L-"B`@("`@("`@:68@*"$D=&AI<RT^
M7W)E9VES=')Y+3YC:&%N;F5L17AI<W1S*"1P87)R6R=C:&%N;F5L)UTI*2![
M#0H@("`@("`@("`@("!D;R![#0H@("`@("`@("`@("`@("`@:68@*"1T:&ES
M+3YC;VYF:6<M/F=E="@G875T;U]D:7-C;W9E<B<I*2![#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@D=&AI<RT^9&ES8V]V97(H)'!A<G);)V-H86YN96PG
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("1T:&ES+3YC;VYF:6=3970H)V1E9F%U;'1?8VAA;FYE;"<L("1C
M=7)C:&%N;F5L*3L-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@G56YK;F]W;B!R96UO=&4@8VAA;FYE;#H@)R`N("1R96UO=&5C
M:&%N;F5L*3L-"B`@("`@("`@("`@('T@=VAI;&4@*&9A;'-E*3L-"B`@("`@
M("`@?0T*("`@("`@("`D8VAA;B`]("8D=&AI<RT^7W)E9VES=')Y+3YG971#
M:&%N;F5L*"1P87)R6R=C:&%N;F5L)UTI.PT*("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D8VAA;BDI('L-"B`@("`@("`@("`@(')E='5R;B`D8VAA;CL-
M"B`@("`@("`@?0T*("`@("`@("`D=F5R<VEO;B`]("1T:&ES+3Y?<F5G:7-T
M<GDM/G!A8VMA9V5);F9O*"1P87)R6R=P86-K86=E)UTL("=V97)S:6]N)RP-
M"B`@("`@("`@("`@("1P87)R6R=C:&%N;F5L)UTI.PT*("`@("`@("!I9B`H
M)&-H86XM/G-U<'!O<G1S4D535"@D=&AI<RT^8V]N9FEG+3YG970H)W!R969E
M<G)E9%]M:7)R;W(G*2D@)B8-"B`@("`@("`@("`@("`@)&)A<V4@/2`D8VAA
M;BT^9V5T0F%S95523"@G4D535#$N,"<L("1T:&ES+3YC;VYF:6<M/F=E="@G
M<')E9F5R<F5D7VUI<G)O<B<I*2D@>PT*("`@("`@("`@("`@)')E<W0@/2`F
M)'1H:7,M/F-O;F9I9RT^9V5T4D535"@G,2XP)RP@)'1H:7,M/E]O<'1I;VYS
M*3L-"B`@("`@("`@("`@(&EF("@A:7-S970H)'!A<G);)W9E<G-I;VXG72D@
M)B8@(6ES<V5T*"1P87)R6R=S=&%T92==*2`F)B`D=F5R<VEO;@T*("`@("`@
M("`@("`@("`@("`@)B8@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9&]W;FQO
M861O;FQY)UTI*2![#0H@("`@("`@("`@("`@("`@)'5R;"`]("1R97-T+3YG
M971$;W=N;&]A9%523"@D8F%S92P@)'!A<G(L("1S=&%T92P@)'9E<G-I;VXI
M.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D=7)L
M(#T@)')E<W0M/F=E=$1O=VYL;V%D55),*"1B87-E+"`D<&%R<BP@)'-T871E
M+"!F86QS92D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D=7)L*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3YC
M;VYF:6=3970H)V1E9F%U;'1?8VAA;FYE;"<L("1C=7)C:&%N;F5L*3L-"B`@
M("`@("`@("`@("`@("!R971U<FX@)'5R;#L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&EF("@D<&%R<ELG8VAA;FYE;"==("$]("1C=7)C:&%N;F5L
M*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/F-O;F9I9U-E="@G9&5F875L
M=%]C:&%N;F5L)RP@)&-U<F-H86YN96PI.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@:68@*"%I<U]A<G)A>2@D=7)L*2D@>PT*("`@("`@("`@("`@
M("`@(')E='5R;B`D=7)L.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M)'5R;%LG<F%W)UT@/2!F86QS93L@+R\@;F\@8VAE8VMI;F<@:7,@;F5C97-S
M87)Y(&9O<B!215-4#0H@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1U<FQ;
M)VEN9F\G72DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@G26YV86QI9"!R96UO=&4@9&5P96YD96YC:65S(')E=')I979E
M9"!F<F]M(%)%4U0@+2`G("X-"B`@("`@("`@("`@("`@("`@("`@)W1H:7,@
M<VAO=6QD(&YE=F5R(&AA<'!E;B<I.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@:68@*&ES<V5T*"1U<FQ;)VEN9F\G75LG<F5Q=6ER960G72D@?'P@
M)'5R;%LG8V]M<&%T:6)L92==*2![#0H@("`@("`@("`@("`@("`@<F5Q=6ER
M95]O;F-E("=014%2+U!A8VMA9V5&:6QE+W8R+G!H<"<[#0H@("`@("`@("`@
M("`@("`@)'!F(#T@;F5W(%!%05)?4&%C:V%G949I;&5?=C([#0H@("`@("`@
M("`@("`@("`@)'!F+3YS971287=#:&%N;F5L*"1P87)R6R=C:&%N;F5L)UTI
M.PT*("`@("`@("`@("`@("`@(&EF("@D=7)L6R=C;VUP871I8FQE)UTI('L-
M"B`@("`@("`@("`@("`@("`@("`@)'!F+3YS971287=#;VUP871I8FQE*"1U
M<FQ;)V-O;7!A=&EB;&4G72D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M)U!%05(O4&%C:V%G949I;&4O=C$N<&AP)SL-"B`@("`@("`@("`@("`@("`D
M<&8@/2!N97<@4$5!4E]086-K86=E1FEL95]V,3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("1P9BT^<V5T4F%W4&%C:V%G92@D=7)L6R=P86-K86=E
M)UTI.PT*("`@("`@("`@("`@)'!F+3YS971$97!S*"1U<FQ;)VEN9F\G72D[
M#0H@("`@("`@("`@("`D<&8M/G-E=%)A=U-T871E*"1U<FQ;)W-T86)I;&ET
M>2==*3L-"B`@("`@("`@("`@("1U<FQ;)VEN9F\G72`]("8D<&8[#0H@("`@
M("`@("`@("!I9B`H(65X=&5N<VEO;E]L;V%D960H(GIL:6(B*2!\?"!I<W-E
M="@D=&AI<RT^7V]P=&EO;G-;)VYO8V]M<')E<W,G72DI('L-"B`@("`@("`@
M("`@("`@("`D97AT(#T@)RYT87(G.PT*("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`D97AT(#T@)RYT9WHG.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1U<FPI*2![#0H@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1U<FQ;)W5R;"==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`D=7)L6R=U<FPG72`N/2`D97AT.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B`D=7)L
M.PT*("`@("`@("!](&5L<V5I9B`H)&-H86XM/G-U<'!O<G1S*"=X;6QR<&,G
M+"`G<&%C:V%G92YG971$;W=N;&]A9%523"<L(&9A;'-E+"`G,2XQ)RDI('L-
M"B`@("`@("`@("`@("\O(&1O;B=T(&EN<W1A;&P@=VET:"!T:&4@;VQD('9E
M<G-I;VX@:6YF;W)M871I;VX@=6YL97-S('=E)W)E(&1O:6YG(&$@<&QA:6X-
M"B`@("`@("`@("`@("\O('9A;FEL;&$@<VEM<&QE(&EN<W1A;&QA=&EO;BX@
M($EF('1H92!U<V5R('-A>7,@=&\@:6YS=&%L;"!A('!A<G1I8W5L87(-"B`@
M("`@("`@("`@("\O('9E<G-I;VX@;W(@<W1A=&4L(&EG;F]R92!T:&4@8W5R
M<F5N="!I;G-T86QL960@=F5R<VEO;@T*("`@("`@("`@("`@:68@*"%I<W-E
M="@D<&%R<ELG=F5R<VEO;B==*2`F)B`A:7-S970H)'!A<G);)W-T871E)UTI
M("8F("1V97)S:6]N#0H@("`@("`@("`@("`@("`@("`F)B`A:7-S970H)'1H
M:7,M/E]O<'1I;VYS6R=D;W=N;&]A9&]N;'DG72DI('L-"B`@("`@("`@("`@
M("`@("`D=7)L(#T@)'1H:7,M/E]R96UO=&4M/F-A;&PH)W!A8VMA9V4N9V5T
M1&]W;FQO86154DPG+"`D<&%R<BP@)'-T871E+"`D=F5R<VEO;BD[#0H@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1U<FP@/2`D=&AI
M<RT^7W)E;6]T92T^8V%L;"@G<&%C:V%G92YG971$;W=N;&]A9%523"<L("1P
M87)R+"`D<W1A=&4I.PT*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@)'5R;"`]("1T:&ES+3Y?<F5M;W1E+3YC86QL*"=P
M86-K86=E+F=E=$1O=VYL;V%D55),)RP@)'!A<G(L("1S=&%T92D[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'5R;"DI('L-"B`@
M("`@("`@("`@(')E='5R;B`D=7)L.PT*("`@("`@("!]#0H@("`@("`@(&EF
M("@D<&%R<ELG8VAA;FYE;"==("$]("1C=7)C:&%N;F5L*2![#0H@("`@("`@
M("`@("`D=&AI<RT^8V]N9FEG4V5T*"=D969A=6QT7V-H86YN96PG+"`D8W5R
M8VAA;FYE;"D[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1U<FQ;
M)U]?4$5!4E]%4E)/4E]#3$%34U]?)UTI*2![#0H@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@D=7)L6R=M97-S86=E)UTI.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("@A:7-?87)R87DH)'5R;"DI('L-"B`@("`@("`@
M("`@(')E='5R;B`D=7)L.PT*("`@("`@("!]#0H@("`@("`@("1U<FQ;)W)A
M=R==(#T@)'5R;%LG:6YF;R==.PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/E]O<'1I;VYS6R=D;W=N;&]A9&]N;'DG72DI('L-"B`@("`@("`@("`@("1P
M:V<@/2`F)'1H:7,M/F=E=%!A8VMA9V5F:6QE3V)J96-T*"1T:&ES+3YC;VYF
M:6<L("1T:&ES+3YD96)U9RD[#0H@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`D<&MG(#T@)B1T:&ES+3YG971086-K86=E9FEL94]B:F5C="@D=&AI
M<RT^8V]N9FEG+"`D=&AI<RT^9&5B=6<L#0H@("`@("`@("`@("`@("`@)'1H
M:7,M/F=E=$1O=VYL;V%D1&ER*"DI.PT*("`@("`@("!]#0H@("`@("`@(%!%
M05(Z.G-T871I8U!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).
M*3L-"B`@("`@("`@)'!I;F9O(#T@)B1P:V<M/F9R;VU8;6Q3=')I;F<H)'5R
M;%LG:6YF;R==+"!014%27U9!3$E$051%7T1/5TY,3T%$24Y'+"`G<F5M;W1E
M)RD[#0H@("`@("`@(%!%05(Z.G-T871I8U!O<$5R<F]R2&%N9&QI;F<H*3L-
M"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'!I;F9O*2D@>PT*("`@("`@
M("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)W-O9G0G72DI('L-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L("1P:6YF;RT^9V5T365S
M<V%G92@I*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"=296UO=&4@<&%C:V%G92YX;6P@:7,@;F]T('9A
M;&ED("T@=&AI<R!S:&]U;&0@;F5V97(@:&%P<&5N)RD[#0H@("`@("`@('T-
M"B`@("`@("`@)'5R;%LG:6YF;R==(#T@)B1P:6YF;SL-"B`@("`@("`@:68@
M*"%E>'1E;G-I;VY?;&]A9&5D*")Z;&EB(BD@?'P@:7-S970H)'1H:7,M/E]O
M<'1I;VYS6R=N;V-O;7!R97-S)UTI*2![#0H@("`@("`@("`@("`D97AT(#T@
M)RYT87(G.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&5X="`]
M("<N=&=Z)SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-?87)R87DH)'5R
M;"DI('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D=7)L6R=U<FPG72DI('L-
M"B`@("`@("`@("`@("`@("`D=7)L6R=U<FPG72`N/2`D97AT.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D=7)L.PT*("`@
M('T-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T1&5P4&%C:V%G941O=VYL
M;V%D57)L*"D-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!A<G)A>2!D97!E
M;F1E;F-Y(&%R<F%Y#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@7V=E=$1E<%!A8VMA9V5$;W=N;&]A9%5R;"@D9&5P
M+"`D<&%R<BD-"B`@("![#0H@("`@("`@("1X<V1V97)S:6]N(#T@:7-S970H
M)&1E<%LG<F5L)UTI(#\@)S$N,"<@.B`G,BXP)SL-"B`@("`@("`@)&-U<F-H
M86YN96P@/2`D=&AI<RT^8V]N9FEG+3YG970H)V1E9F%U;'1?8VAA;FYE;"<I
M.PT*("`@("`@("!I9B`H:7-S970H)&1E<%LG8VAA;FYE;"==*2D@>PT*("`@
M("`@("`@("`@)')E;6]T96-H86YN96P@/2`D9&5P6R=C:&%N;F5L)UT[#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D<F5M;W1E8VAA;FYE;"`]
M("=P96%R+G!H<"YN970G.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A)'1H
M:7,M/E]R96=I<W1R>2T^8VAA;FYE;$5X:7-T<R@D<F5M;W1E8VAA;FYE;"DI
M('L-"B`@("`@("`@("`@(&1O('L-"B`@("`@("`@("`@("`@("!I9B`H)'1H
M:7,M/F-O;F9I9RT^9V5T*"=A=71O7V1I<V-O=F5R)RDI('L-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"1T:&ES+3YD:7-C;W9E<B@D<F5M;W1E8VAA;FYE
M;"DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=5;FMN;W=N(')E;6]T
M92!C:&%N;F5L.B`G("X@)')E;6]T96-H86YN96PI.PT*("`@("`@("`@("`@
M?2!W:&EL92`H9F%L<V4I.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3YC
M;VYF:6=3970H)V1E9F%U;'1?8VAA;FYE;"<L("1R96UO=&5C:&%N;F5L*3L-
M"B`@("`@("`@)'-T871E(#T@:7-S970H)'!A<G);)W-T871E)UTI(#\@)'!A
M<G);)W-T871E)UT@.B`D=&AI<RT^8V]N9FEG+3YG970H)W!R969E<G)E9%]S
M=&%T92<I.PT*("`@("`@("!I9B`H:7-S970H)'!A<G);)W-T871E)UTI("8F
M(&ES<V5T*"1P87)R6R=V97)S:6]N)UTI*2![#0H@("`@("`@("`@("!U;G-E
M="@D<&%R<ELG<W1A=&4G72D[#0H@("`@("`@('T-"B`@("`@("`@)&-H86X@
M/2`F)'1H:7,M/E]R96=I<W1R>2T^9V5T0VAA;FYE;"@D<F5M;W1E8VAA;FYE
M;"D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1C:&%N*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N("1C:&%N.PT*("`@("`@("!]#0H@("`@("`@("1V
M97)S:6]N(#T@)'1H:7,M/E]R96=I<W1R>2T^<&%C:V%G94EN9F\H)&1E<%LG
M;F%M92==+"`G=F5R<VEO;B<L#0H@("`@("`@("`@("`D<F5M;W1E8VAA;FYE
M;"D[#0H@("`@("`@(&EF("@D8VAA;BT^<W5P<&]R='-215-4*"1T:&ES+3YC
M;VYF:6<M/F=E="@G<')E9F5R<F5D7VUI<G)O<B<I*2`F)@T*("`@("`@("`@
M("`@("`D8F%S92`]("1C:&%N+3YG971"87-E55),*"=215-4,2XP)RP@)'1H
M:7,M/F-O;F9I9RT^9V5T*"=P<F5F97)R961?;6ER<F]R)RDI*2![#0H@("`@
M("`@("`@("`D<F5S="`]("8D=&AI<RT^8V]N9FEG+3YG971215-4*"<Q+C`G
M+"`D=&AI<RT^7V]P=&EO;G,I.PT*("`@("`@("`@("`@)'5R;"`]("1R97-T
M+3YG971$97!$;W=N;&]A9%523"@D8F%S92P@)'AS9'9E<G-I;VXL("1D97`L
M("1P87)R+`T*("`@("`@("`@("`@("`@("`@("`D<W1A=&4L("1V97)S:6]N
M*3L-"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1U<FPI*2![#0H@
M("`@("`@("`@("`@("`@<F5T=7)N("1U<FP[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!I9B`H)'!A<G);)V-H86YN96PG72`A/2`D8W5R8VAA;FYE
M;"D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3YC;VYF:6=3970H)V1E9F%U
M;'1?8VAA;FYE;"<L("1C=7)C:&%N;F5L*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&EF("@A:7-?87)R87DH)'5R;"DI('L-"B`@("`@("`@("`@
M("`@("!R971U<FX@)'5R;#L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("1U<FQ;)W)A=R==(#T@9F%L<V4[("\O(&YO(&-H96-K:6YG(&ES(&YE8V5S
M<V%R>2!F;W(@4D535`T*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D=7)L
M6R=I;F9O)UTI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H)TEN=F%L:60@<F5M;W1E(&1E<&5N9&5N8VEE<R!R971R:65V
M960@9G)O;2!215-4("T@)R`N#0H@("`@("`@("`@("`@("`@("`@("=T:&ES
M('-H;W5L9"!N979E<B!H87!P96XG*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&EF("AI<W-E="@D=7)L6R=I;F9O)UU;)W)E<75I<F5D)UTI*2![
M#0H@("`@("`@("`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?4&%C
M:V%G949I;&5?=C(G*2D@>PT*("`@("`@("`@("`@("`@("`@("!R97%U:7)E
M7V]N8V4@)U!%05(O4&%C:V%G949I;&4O=C(N<&AP)SL-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@)'!F(#T@;F5W(%!%05)?4&%C:V%G
M949I;&5?=C([#0H@("`@("`@("`@("`@("`@)'!F+3YS971287=#:&%N;F5L
M*"1R96UO=&5C:&%N;F5L*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?4&%C:V%G949I
M;&5?=C$G*2D@>PT*("`@("`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M)U!%05(O4&%C:V%G949I;&4O=C$N<&AP)SL-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@)'!F(#T@;F5W(%!%05)?4&%C:V%G949I;&5?
M=C$[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<&8M/G-E=%)A=U!A
M8VMA9V4H)'5R;%LG<&%C:V%G92==*3L-"B`@("`@("`@("`@("1P9BT^<V5T
M1&5P<R@D=7)L6R=I;F9O)UTI.PT*("`@("`@("`@("`@)'!F+3YS971287=3
M=&%T92@D=7)L6R=S=&%B:6QI='DG72D[#0H@("`@("`@("`@("`D=7)L6R=I
M;F9O)UT@/2`F)'!F.PT*("`@("`@("`@("`@:68@*"%E>'1E;G-I;VY?;&]A
M9&5D*")Z;&EB(BD@?'P@:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N;V-O;7!R
M97-S)UTI*2![#0H@("`@("`@("`@("`@("`@)&5X="`]("<N=&%R)SL-"B`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)&5X="`]("<N
M=&=Z)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<U]A<G)A
M>2@D=7)L*2D@>PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=7)L6R=U
M<FPG72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'5R;%LG=7)L)UT@+CT@
M)&5X=#L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!R971U<FX@)'5R;#L-"B`@("`@("`@?2!E;'-E:68@*"1C:&%N
M+3YS=7!P;W)T<R@G>&UL<G!C)RP@)W!A8VMA9V4N9V5T1&5P1&]W;FQO8615
M4DPG+"!F86QS92P@)S$N,2<I*2![#0H@("`@("`@("`@("!I9B`H)'9E<G-I
M;VXI('L-"B`@("`@("`@("`@("`@("`D=7)L(#T@)'1H:7,M/E]R96UO=&4M
M/F-A;&PH)W!A8VMA9V4N9V5T1&5P1&]W;FQO86154DPG+"`D>'-D=F5R<VEO
M;BP@)&1E<"P@)'!A<G(L#0H@("`@("`@("`@("`@("`@("`@("1S=&%T92P@
M)'9E<G-I;VXI.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`D=7)L(#T@)'1H:7,M/E]R96UO=&4M/F-A;&PH)W!A8VMA9V4N9V5T
M1&5P1&]W;FQO86154DPG+"`D>'-D=F5R<VEO;BP@)&1E<"P@)'!A<G(L#0H@
M("`@("`@("`@("`@("`@("`@("1S=&%T92D[#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D=7)L(#T@)'1H:7,M/E]R
M96UO=&4M/F-A;&PH)W!A8VMA9V4N9V5T1&5P1&]W;FQO86154DPG+"`D>'-D
M=F5R<VEO;BP@)&1E<"P@)'!A<G(L("1S=&%T92D[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"1P87)R6R=C:&%N;F5L)UT@(3T@)&-U<F-H86YN96PI('L-
M"B`@("`@("`@("`@("1T:&ES+3YC;VYF:6=3970H)V1E9F%U;'1?8VAA;FYE
M;"<L("1C=7)C:&%N;F5L*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES
M7V%R<F%Y*"1U<FPI*2![#0H@("`@("`@("`@("!R971U<FX@)'5R;#L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)'5R;%LG7U]014%27T524D]2
M7T-,05-37U\G72DI('L-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*"1U<FQ;)VUE<W-A9V4G72D[#0H@("`@("`@('T-"B`@("`@("`@
M)'5R;%LG<F%W)UT@/2`D=7)L6R=I;F9O)UT[#0H@("`@("`@("1P:V<@/2`F
M)'1H:7,M/F=E=%!A8VMA9V5F:6QE3V)J96-T*"1T:&ES+3YC;VYF:6<L("1T
M:&ES+3YD96)U9RD[#0H@("`@("`@(%!%05(Z.G-T871I8U!U<VA%<G)O<DAA
M;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@)'!I;F9O(#T@
M)B1P:V<M/F9R;VU8;6Q3=')I;F<H)'5R;%LG:6YF;R==+"!014%27U9!3$E$
M051%7T1/5TY,3T%$24Y'+"`G<F5M;W1E)RD[#0H@("`@("`@(%!%05(Z.G-T
M871I8U!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)'!I;F9O*2D@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI
M<RT^7V]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`D=&AI
M<RT^;&]G*#`L("1P:6YF;RT^9V5T365S<V%G92@I*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=296UO
M=&4@<&%C:V%G92YX;6P@:7,@;F]T('9A;&ED("T@=&AI<R!S:&]U;&0@;F5V
M97(@:&%P<&5N)RD[#0H@("`@("`@('T-"B`@("`@("`@)'5R;%LG:6YF;R==
M(#T@)B1P:6YF;SL-"B`@("`@("`@:68@*&ES7V%R<F%Y*"1U<FPI*2![#0H@
M("`@("`@("`@("!I9B`H(65X=&5N<VEO;E]L;V%D960H(GIL:6(B*2!\?"!I
M<W-E="@D=&AI<RT^7V]P=&EO;G-;)VYO8V]M<')E<W,G72DI('L-"B`@("`@
M("`@("`@("`@("`D97AT(#T@)RYT87(G.PT*("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`D97AT(#T@)RYT9WHG.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1U<FQ;)W5R;"==*2D@>PT*
M("`@("`@("`@("`@("`@("1U<FQ;)W5R;"==("X]("1E>'0[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1U<FP[#0H@("`@
M?0T*("`@("\O('U]?0T*("`@("\O('M[>R!G971086-K86=E1&]W;FQO8615
M<FPH*0T*#0H@("`@+RHJ#0H@("`@("H@0&1E<')E8V%T960@:6X@9F%V;W(@
M;V8@7V=E=%!A8VMA9V5$;W=N;&]A9%5R;`T*("`@("`J+PT*("`@(&9U;F-T
M:6]N(&=E=%!A8VMA9V5$;W=N;&]A9%5R;"@D<&%C:V%G92P@)'9E<G-I;VX@
M/2!N=6QL+"`D8VAA;FYE;"`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@
M*"1V97)S:6]N*2![#0H@("`@("`@("`@("`D<&%C:V%G92`N/2`B+21V97)S
M:6]N(CL-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'1H:7,@/3T](&YU;&P@
M?'P@)'1H:7,M/E]R96=I<W1R>2`]/3T@;G5L;"D@>PT*("`@("`@("`@("`@
M)'!A8VMA9V4@/2`B:'1T<#HO+W!E87(N<&AP+FYE="]G970O)'!A8VMA9V4B
M.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&-H86X@/2`D=&AI
M<RT^7W)E9VES=')Y+3YG971#:&%N;F5L*"1C:&%N;F5L*3L-"B`@("`@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1C:&%N*2D@>PT*("`@("`@("`@("`@
M("`@(')E='5R;B`G)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1P
M86-K86=E(#T@(FAT='`Z+R\B("X@)&-H86XM/F=E=%-E<G9E<B@I("X@(B]G
M970O)'!A8VMA9V4B.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A97AT96YS
M:6]N7VQO861E9"@B>FQI8B(I*2![#0H@("`@("`@("`@("`D<&%C:V%G92`N
M/2`G/W5N8V]M<')E<W,]>65S)SL-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@)'!A8VMA9V4[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[
M(&=E=$1O=VYL;V%D961086-K86=E<R@I#0H-"B`@("`O*BH-"B`@("`@*B!2
M971R:65V92!A(&QI<W0@;V8@9&]W;FQO861E9"!P86-K86=E<R!A9G1E<B!A
M(&-A;&P@=&\@>T!L:6YK(&1O=VYL;V%D*"E]+@T*("`@("`J#0H@("`@("H@
M06QS;R!R97-E=',@=&AE(&QI<W0@;V8@9&]W;FQO861E9"!P86-K86=E<RX-
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M9V5T1&]W;FQO861E9%!A8VMA9V5S*"D-"B`@("![#0H@("`@("`@("1R970@
M/2`D=&AI<RT^7V1O=VYL;V%D961086-K86=E<SL-"B`@("`@("`@)'1H:7,M
M/E]D;W=N;&]A9&5D4&%C:V%G97,@/2!A<G)A>2@I.PT*("`@("`@("`D=&AI
M<RT^7W1O1&]W;FQO860@/2!A<G)A>2@I.PT*("`@("`@("!R971U<FX@)')E
M=#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@7V1O=VYL;V%D
M0V%L;&)A8VLH*0T*#0H@("`@9G5N8W1I;VX@7V1O=VYL;V%D0V%L;&)A8VLH
M)&US9RP@)'!A<F%M<R`](&YU;&PI#0H@("`@>PT*("`@("`@("!S=VET8V@@
M*"1M<V<I('L-"B`@("`@("`@("`@(&-A<V4@)W-A=F5A<R<Z#0H@("`@("`@
M("`@("`@("`@)'1H:7,M/FQO9R@Q+"`B9&]W;FQO861I;F<@)'!A<F%M<R`N
M+BXB*3L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A
M<V4@)V1O;F4G.@T*("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,2P@)RXN
M+F1O;F4Z("<@+B!N=6UB97)?9F]R;6%T*"1P87)A;7,L(#`L("<G+"`G+"<I
M("X@)R!B>71E<R<I.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@
M("`@("`@8V%S92`G8GET97-R96%D)SH-"B`@("`@("`@("`@("`@("!S=&%T
M:6,@)&)Y=&5S.PT*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D8GET97,I
M*2![#0H@("`@("`@("`@("`@("`@("`@("1B>71E<R`](#`[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@A*"1B>71E<R`E(#$P
M,C0P*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#$L("<N
M)RP@9F%L<V4I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`D8GET97,@*ST@)'!A<F%M<SL-"B`@("`@("`@("`@("`@("!B<F5A:SL-
M"B`@("`@("`@("`@(&-A<V4@)W-T87)T)SH-"B`@("`@("`@("`@("`@("`D
M=&AI<RT^;&]G*#$L(")3=&%R=&EN9R!T;R!D;W=N;&]A9"![)'!A<F%M<ULP
M77T@*"(N;G5M8F5R7V9O<FUA="@D<&%R86US6S%=+"`P+"`G)RP@)RPG*2XB
M(&)Y=&5S*2(I.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("AM971H;V1?97AI<W1S*"1T:&ES+3YU:2P@)U]D;W=N
M;&]A9$-A;&QB86-K)RDI#0H@("`@("`@("`@("`D=&AI<RT^=6DM/E]D;W=N
M;&]A9$-A;&QB86-K*"1M<V<L("1P87)A;7,I.PT*("`@('T-"@T*("`@("\O
M('U]?0T*("`@("\O('M[>R!?<')E<&5N9%!A=&@H)'!A=&@L("1P<F5P96YD
M*0T*#0H@("`@9G5N8W1I;VX@7W!R97!E;F10871H*"1P871H+"`D<')E<&5N
M9"D-"B`@("![#0H@("`@("`@(&EF("AS=')L96XH)'!R97!E;F0I(#X@,"D@
M>PT*("`@("`@("`@("`@:68@*$]37U=)3D1/5U,@)B8@<')E9U]M871C:"@G
M+UY;82UZ73HO:2<L("1P871H*2D@>PT*("`@("`@("`@("`@("`@(&EF("AP
M<F5G7VUA=&-H*"<O7EMA+7I=.B]I)RP@)'!R97!E;F0I*2![#0H@("`@("`@
M("`@("`@("`@("`@("1P<F5P96YD(#T@<W5B<W1R*"1P<F5P96YD+"`R*3L-
M"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)'!R97!E;F1[,'T@(3T@)UQ<
M)RD@>PT*("`@("`@("`@("`@("`@("`@("`D<')E<&5N9"`](")<7"1P<F5P
M96YD(CL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'!A
M=&@@/2!S=6)S='(H)'!A=&@L(#`L(#(I("X@)'!R97!E;F0@+B!S=6)S='(H
M)'!A=&@L(#(I.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`D<&%T:"`]("1P<F5P96YD("X@)'!A=&@[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1P871H.PT*("`@('T-"B`@
M("`O+R!]?7T-"B`@("`O+R![>WL@<'5S:$5R<F]R*"1E<G)M<V<L("1C;V1E
M*0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9PT*("`@("`J($!P
M87)A;2!I;G1E9V5R#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<'5S:$5R<F]R
M*"1E<G)M<V<L("1C;V1E(#T@+3$I#0H@("`@>PT*("`@("`@("!A<G)A>5]P
M=7-H*"1T:&ES+3Y?97)R;W)3=&%C:RP@87)R87DH)&5R<FUS9RP@)&-O9&4I
M*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T17)R;W)-
M<V=S*"D-"@T*("`@(&9U;F-T:6]N(&=E=$5R<F]R37-G<R@I#0H@("`@>PT*
M("`@("`@("`D;7-G<R`](&%R<F%Y*"D[#0H@("`@("`@("1E<G)S(#T@)'1H
M:7,M/E]E<G)O<E-T86-K.PT*("`@("`@("!F;W)E86-H("@D97)R<R!A<R`D
M97)R*2![#0H@("`@("`@("`@("`D;7-G<UM=(#T@)&5R<ELP73L-"B`@("`@
M("`@?0T*("`@("`@("`D=&AI<RT^7V5R<F]R4W1A8VL@/2!A<G)A>2@I.PT*
M("`@("`@("!R971U<FX@)&US9W,[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-
M"B`@("`O*BH-"B`@("`@*B!F;W(@0D,-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!S;W)T4&MG1&5P<R@F)'!A8VMA9V5S+"`D=6YI;G-T86QL(#T@9F%L<V4I
M#0H@("`@>PT*("`@("`@("`D=6YI;G-T86QL(#\@#0H@("`@("`@("`@("`D
M=&AI<RT^<V]R=%!A8VMA9V5S1F]R56YI;G-T86QL*"1P86-K86=E<RD@.@T*
M("`@("`@("`@("`@)'1H:7,M/G-O<G1086-K86=E<T9O<DEN<W1A;&PH)'!A
M8VMA9V5S*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?9V5T1&5P5')E9410
M*"1P86-K86=E+"`D<&%C:V%G97,L("8D9&5P<RP@)B1C:&5C:V5D*0T*("`@
M('L-"B`@("`@("`@)'!F(#T@)'!A8VMA9V4M/F=E=%!A8VMA9V5&:6QE*"D[
M#0H@("`@("`@("1C:&5C:V5D6W-T<G1O;&]W97(H)'!A8VMA9V4M/F=E=$-H
M86YN96PH*2E=6W-T<G1O;&]W97(H)'!A8VMA9V4M/F=E=%!A8VMA9V4H*2E=
M#0H@("`@("`@("`@("`]('1R=64[#0H@("`@("`@("1P9&5P<R`]("1P9BT^
M9V5T1&5P<RAT<G5E*3L-"B`@("`@("`@:68@*"$D<&1E<',I('L-"B`@("`@
M("`@("`@(')E='5R;CL-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'!F+3YG
M971086-K86=E>&UL5F5R<VEO;B@I(#T]("<Q+C`G*2![#0H@("`@("`@("`@
M("!F;W)E86-H("@D<&1E<',@87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@
M(&EF("@D9&5P6R=T>7!E)UT@(3T@)W!K9R<I('L-"B`@("`@("`@("`@("`@
M("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("1D97!S6R=P96%R+G!H<"YN970G75MS=')T;VQO=V5R*"1D97!;
M)VYA;64G72E=(#T@=')U93L-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D
M<&%C:V%G97,@87,@)'`I('L-"B`@("`@("`@("`@("`@("`@("`@)&1E<%LG
M8VAA;FYE;"==(#T@)W!E87(N<&AP+FYE="<[#0H@("`@("`@("`@("`@("`@
M("`@("1D97!;)W!A8VMA9V4G72`]("1D97!;)VYA;64G73L-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"1P+3YI<T5Q=6%L*"1D97`I*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1C:&5C:V5D6W-T<G1O;&]W
M97(H)'`M/F=E=$-H86YN96PH*2E=#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!;<W1R=&]L;W=E<B@D<"T^9V5T4&%C:V%G92@I*5TI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@861D('1H92!D97!E;F1E
M;F-Y)W,@9&5P96YD96YC:65S('1O('1H92!T<F5E#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]G971$97!4<F5E1%`H)'`L("1P86-K
M86=E<RP@)&1E<',L("1C:&5C:V5D*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("1T9&5P<R`](&%R<F%Y*"D[#0H@("`@("`@("`@("!I9B`H:7-S970H
M)'!D97!S6R=R97%U:7)E9"==6R=P86-K86=E)UTI*2![#0H@("`@("`@("`@
M("`@("`@)'0@/2`D<&1E<'-;)W)E<75I<F5D)UU;)W!A8VMA9V4G73L-"B`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T6S!=*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`D="`](&%R<F%Y*"1T*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@)'1D97!S(#T@87)R87E?;65R9V4H)'1D97!S
M+"`D="D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S970H
M)'!D97!S6R=R97%U:7)E9"==6R=S=6)P86-K86=E)UTI*2![#0H@("`@("`@
M("`@("`@("`@)'0@/2`D<&1E<'-;)W)E<75I<F5D)UU;)W-U8G!A8VMA9V4G
M73L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T6S!=*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`D="`](&%R<F%Y*"1T*3L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@)'1D97!S(#T@87)R87E?;65R9V4H
M)'1D97!S+"`D="D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H
M:7-S970H)'!D97!S6R=O<'1I;VYA;"==6R=P86-K86=E)UTI*2![#0H@("`@
M("`@("`@("`@("`@)'0@/2`D<&1E<'-;)V]P=&EO;F%L)UU;)W!A8VMA9V4G
M73L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T6S!=*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`D="`](&%R<F%Y*"1T*3L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@)'1D97!S(#T@87)R87E?;65R9V4H
M)'1D97!S+"`D="D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H
M:7-S970H)'!D97!S6R=O<'1I;VYA;"==6R=S=6)P86-K86=E)UTI*2![#0H@
M("`@("`@("`@("`@("`@)'0@/2`D<&1E<'-;)V]P=&EO;F%L)UU;)W-U8G!A
M8VMA9V4G73L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T6S!=*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`D="`](&%R<F%Y*"1T*3L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'1D97!S(#T@87)R87E?
M;65R9V4H)'1D97!S+"`D="D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!I9B`H:7-S970H)'!D97!S6R=G<F]U<"==*2D@>PT*("`@("`@("`@("`@
M("`@(&EF("@A:7-S970H)'!D97!S6R=G<F]U<"==6S!=*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`D<&1E<'-;)V=R;W5P)UT@/2!A<G)A>2@D<&1E<'-;
M)V=R;W5P)UTI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!F;W)E86-H("@D<&1E<'-;)V=R;W5P)UT@87,@)&=R;W5P*2![#0H@("`@
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9W)O=7!;)W!A8VMA9V4G72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T(#T@)&=R;W5P6R=P86-K
M86=E)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T
M6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T(#T@87)R
M87DH)'0I.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@)'1D97!S(#T@87)R87E?;65R9V4H)'1D97!S+"`D
M="D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1G<F]U<%LG<W5B<&%C:V%G92==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)'0@/2`D9W)O=7!;)W-U8G!A8VMA9V4G73L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1;,%TI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'0@/2!A<G)A>2@D="D[
M#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D=&1E<',@/2!A<G)A>5]M97)G92@D=&1E<',L("1T*3L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@*"1T9&5P<R!A<R`D9&5P
M*2![#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D9&5P6R=C:&%N;F5L
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1D97!C:&%N;F5L(#T@)U]?
M=7)I)SL-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("`@("`D9&5P8VAA;FYE;"`]("1D97!;)V-H86YN96PG73L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&1E<'-;)&1E<&-H86YN
M96Q=6W-T<G1O;&]W97(H)&1E<%LG;F%M92==*5T@/2!T<G5E.PT*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1P86-K86=E<R!A<R`D<"D@>PT*("`@("`@
M("`@("`@("`@("`@("`D9&5P6R=C:&%N;F5L)UT@/2`D9&5P8VAA;FYE;#L-
M"B`@("`@("`@("`@("`@("`@("`@)&1E<%LG<&%C:V%G92==(#T@)&1E<%LG
M;F%M92==.PT*("`@("`@("`@("`@("`@("`@("!I9B`H)'`M/FES17%U86PH
M)&1E<"DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H
M)&-H96-K961;<W1R=&]L;W=E<B@D<"T^9V5T0VAA;FYE;"@I*5T-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%MS=')T;VQO=V5R*"1P+3YG9710
M86-K86=E*"DI72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!A9&0@=&AE(&1E<&5N9&5N8WDG<R!D97!E;F1E;F-I97,@=&\@=&AE('1R
M964-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$1E
M<%1R965$4"@D<"P@)'!A8VMA9V5S+"`D9&5P<RP@)&-H96-K960I.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4V]R="!A(&QI<W0@;V8@87)R
M87ES(&]F(&%R<F%Y*&1O=VYL;V%D960@<&%C:V%G969I;&5N86UE*2!B>2!D
M97!E;F1E;F-Y+@T*("`@("`J#0H@("`@("H@270@86QS;R!R96UO=F5S(&1U
M<&QI8V%T92!D97!E;F1E;F-I97,-"B`@("`@*B!`<&%R86T@87)R87D@86X@
M87)R87D@;V8@9&]W;FQO861E9"!014%27T1O=VYL;V%D97)?4&%C:V%G97,-
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y(&%R<F%Y(&]F(&%R<F%Y*'!A8VMA9V5F
M:6QE;F%M92P@<&%C:V%G92YX;6P@8V]N=&5N=',I#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@<V]R=%!A8VMA9V5S1F]R26YS=&%L;"@F)'!A8VMA9V5S*0T*
M("`@('L-"B`@("`@("`@9F]R96%C:"`H)'!A8VMA9V5S(&%S("1I(#T^("1P
M86-K86=E*2![#0H@("`@("`@("`@("`D8VAE8VME9"`]("1D97!S(#T@87)R
M87DH*3L-"B`@("`@("`@("`@("1T:&ES+3Y?9V5T1&5P5')E9410*"1P86-K
M86=E<ULD:5TL("1P86-K86=E<RP@)&1E<',L("1C:&5C:V5D*3L-"B`@("`@
M("`@("`@("1T:&ES+3Y?9&5P5')E95LD<&%C:V%G92T^9V5T0VAA;FYE;"@I
M75LD<&%C:V%G92T^9V5T4&%C:V%G92@I72`]("1D97!S.PT*("`@("`@("!]
M#0H@("`@("`@('5S;W)T*"1P86-K86=E<RP@87)R87DH)B1T:&ES+"`G7W-O
M<G1);G-T86QL)RDI.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]D97!E;F1S
M3VXH)&$L("1B*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8VAE
M8VM$97!4<F5E*'-T<G1O;&]W97(H)&$M/F=E=$-H86YN96PH*2DL('-T<G1O
M;&]W97(H)&$M/F=E=%!A8VMA9V4H*2DL#0H@("`@("`@("`@("`D8BD[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@7V-H96-K1&5P5')E92@D8VAA;FYE;"P@
M)'!A8VMA9V4L("1B+"`D8VAE8VME9"`](&%R<F%Y*"DI#0H@("`@>PT*("`@
M("`@("`D8VAE8VME9%LD8VAA;FYE;%U;)'!A8VMA9V5=(#T@=')U93L-"B`@
M("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V1E<%1R965;)&-H86YN96Q=6R1P
M86-K86=E72DI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]D97!4<F5E6R1C:&%N
M;F5L75LD<&%C:V%G95U;<W1R=&]L;W=E<B@D8BT^9V5T0VAA;FYE;"@I*5T-
M"B`@("`@("`@("`@("`@6W-T<G1O;&]W97(H)&(M/F=E=%!A8VMA9V4H*2E=
M*2D@>PT*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@
M("`@("`@9F]R96%C:"`H)'1H:7,M/E]D97!4<F5E6R1C:&%N;F5L75LD<&%C
M:V%G95T@87,@)&-H(#T^("1P86-K86=E<RD@>PT*("`@("`@("`@("`@9F]R
M96%C:"`H)'!A8VMA9V5S(&%S("1P82`]/B`D=')U92D@>PT*("`@("`@("`@
M("`@("`@(&EF("@D=&AI<RT^7V-H96-K1&5P5')E92@D8V@L("1P82P@)&(L
M("1C:&5C:V5D*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U
M93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T
M:6]N(%]S;W)T26YS=&%L;"@D82P@)&(I#0H@("`@>PT*("`@("`@("!I9B`H
M(21A+3YG971$97!S*"D@)B8@(21B+3YG971$97!S*"DI('L-"B`@("`@("`@
M("`@(')E='5R;B`P.R`O+R!N96ET:&5R('!A8VMA9V4@:&%S(&1E<&5N9&5N
M8VEE<RP@;W)D97(@:7,@:6YS:6=N:69I8V%N=`T*("`@("`@("!]#0H@("`@
M("`@(&EF("@D82T^9V5T1&5P<R@I("8F("$D8BT^9V5T1&5P<R@I*2![#0H@
M("`@("`@("`@("!R971U<FX@,3L@+R\@)&$@;75S="!B92!I;G-T86QL960@
M869T97(@)&(@8F5C875S92`D82!H87,@9&5P96YD96YC:65S#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"$D82T^9V5T1&5P<R@I("8F("1B+3YG971$97!S
M*"DI('L-"B`@("`@("`@("`@(')E='5R;B`M,3L@+R\@)&(@;75S="!B92!I
M;G-T86QL960@869T97(@)&$@8F5C875S92`D8B!H87,@9&5P96YD96YC:65S
M#0H@("`@("`@('T-"B`@("`@("`@+R\@8F]T:"!P86-K86=E<R!H879E(&1E
M<&5N9&5N8VEE<PT*("`@("`@("!I9B`H)'1H:7,M/E]D97!E;F1S3VXH)&$L
M("1B*2D@>PT*("`@("`@("`@("`@<F5T=7)N(#$[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"1T:&ES+3Y?9&5P96YD<T]N*"1B+"`D82DI('L-"B`@("`@
M("`@("`@(')E='5R;B`M,3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M,#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!$;W=N;&]A9"!A(&9I;&4@
M=&AR;W5G:"!(5%10+B`@0V]N<VED97)S('-U9V=E<W1E9"!F:6QE(&YA;64@
M:6X-"B`@("`@*B!#;VYT96YT+61I<W!O<VET:6]N.B!H96%D97(@86YD(&-A
M;B!R=6X@82!C86QL8F%C:R!F=6YC=&EO;B!F;W(-"B`@("`@*B!D:69F97)E
M;G0@979E;G1S+B`@5&AE(&-A;&QB86-K('=I;&P@8F4@8V%L;&5D('=I=&@@
M='=O#0H@("`@("H@<&%R86UE=&5R<SH@=&AE(&-A;&QB86-K('1Y<&4L(&%N
M9"!P87)A;65T97)S+B`@5&AE(&EM<&QE;65N=&5D#0H@("`@("H@8V%L;&)A
M8VL@='EP97,@87)E.@T*("`@("`J#0H@("`@("H@("=S971U<"<@("`@("`@
M8V%L;&5D(&%T('1H92!V97)Y(&)E9VEN;FEN9RP@<&%R86UE=&5R(&ES(&$@
M54D@;V)J96-T#0H@("`@("H@("`@("`@("`@("`@("`@=&AA="!S:&]U;&0@
M8F4@=7-E9"!F;W(@86QL(&]U='!U=`T*("`@("`J("`G;65S<V%G92<@("`@
M('1H92!P87)A;65T97(@:7,@82!S=')I;F<@=VET:"!A;B!I;F9O<FUA=&EO
M;F%L(&UE<W-A9V4-"B`@("`@*B`@)W-A=F5A<R<@("`@("!M87D@8F4@=7-E
M9"!T;R!S879E('=I=&@@82!D:69F97)E;G0@9FEL92!N86UE+"!T:&4-"B`@
M("`@*B`@("`@("`@("`@("`@("!P87)A;65T97(@:7,@=&AE(&9I;&5N86UE
M('1H870@:7,@86)O=70@=&\@8F4@=7-E9"X-"B`@("`@*B`@("`@("`@("`@
M("`@("!)9B!A("=S879E87,G(&-A;&QB86-K(')E='5R;G,@82!N;VXM96UP
M='D@<W1R:6YG+`T*("`@("`J("`@("`@("`@("`@("`@('1H870@9FEL92!N
M86UE('=I;&P@8F4@=7-E9"!A<R!T:&4@9FEL96YA;64@:6YS=&5A9"X-"B`@
M("`@*B`@("`@("`@("`@("`@("!.;W1E('1H870@)'-A=F5?9&ER('=I;&P@
M;F]T(&)E(&%F9F5C=&5D(&)Y('1H:7,L(&]N;'D-"B`@("`@*B`@("`@("`@
M("`@("`@("!T:&4@8F%S96YA;64@;V8@=&AE(&9I;&4N#0H@("`@("H@("=S
M=&%R="<@("`@("`@9&]W;FQO860@:7,@<W1A<G1I;F<L('!A<F%M971E<B!I
M<R!N=6UB97(@;V8@8GET97,-"B`@("`@*B`@("`@("`@("`@("`@("!T:&%T
M(&%R92!E>'!E8W1E9"P@;W(@+3$@:68@=6YK;F]W;@T*("`@("`J("`G8GET
M97-R96%D)R`@('!A<F%M971E<B!I<R!T:&4@;G5M8F5R(&]F(&)Y=&5S(')E
M860@<V\@9F%R#0H@("`@("H@("=D;VYE)R`@("`@("`@9&]W;FQO860@:7,@
M8V]M<&QE=&4L('!A<F%M971E<B!I<R!T:&4@=&]T86P@;G5M8F5R#0H@("`@
M("H@("`@("`@("`@("`@("`@;V8@8GET97,@<F5A9`T*("`@("`J("`G8V]N
M;F9A:6QE9"<@(&EF('1H92!40U`O4U-,(&-O;FYE8W1I;VX@9F%I;',L('1H
M:7,@8V%L;&)A8VL@:7,@8V%L;&5D#0H@("`@("H@("`@("`@("`@("`@("`@
M=VET:"!A<G)A>2AH;W-T+'!O<G0L97)R;F\L97)R;7-G*0T*("`@("`J("`G
M=W)I=&5F86EL960G(&EF('=R:71I;F<@=&\@9&ES:R!F86EL<RP@=&AI<R!C
M86QL8F%C:R!I<R!C86QL960-"B`@("`@*B`@("`@("`@("`@("`@("!W:71H
M(&%R<F%Y*&1E<W1F:6QE+&5R<FUS9RD-"B`@("`@*@T*("`@("`J($EF(&%N
M($A45%`@<')O>'D@:&%S(&)E96X@8V]N9FEG=7)E9"`H:'1T<%]P<F]X>2!0
M14%27T-O;F9I9PT*("`@("`J('-E='1I;F<I+"!T:&4@<')O>'D@=VEL;"!B
M92!U<V5D+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`@)'5R;"`@
M("`@("!T:&4@55),('1O(&1O=VYL;V%D#0H@("`@("H@0'!A<F%M(&]B:F5C
M="`@)'5I("`@("`@("!014%27T9R;VYT96YD7RH@:6YS=&%N8V4-"B`@("`@
M*B!`<&%R86T@;V)J96-T("`D8V]N9FEG("`@(%!%05)?0V]N9FEG(&EN<W1A
M;F-E#0H@("`@("H@0'!A<F%M('-T<FEN9R`@)'-A=F5?9&ER("!D:7)E8W1O
M<GD@=&\@<V%V92!F:6QE(&EN#0H@("`@("H@0'!A<F%M(&UI>&5D("`@)&-A
M;&QB86-K("!F=6YC=&EO;B]M971H;V0@=&\@8V%L;"!F;W(@<W1A='5S#0H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!U<&1A=&5S#0H@("`@
M("H@0'!A<F%M(&9A;'-E?'-T<FEN9WQA<G)A>2`D;&%S=&UO9&EF:65D(&AE
M861E<B!V86QU97,@=&\@8VAE8VL@86=A:6YS="!F;W(@8V%C:&EN9PT*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@=7-E(&9A;'-E('1O(')E
M='5R;B!T:&4@:&5A9&5R('9A;'5E<R!F<F]M('1H:7,@9&]W;FQO860-"B`@
M("`@*B!`<&%R86T@9F%L<V5\87)R87D@)&%C8V5P="!!8V-E<'0@:&5A9&5R
M<R!T;R!S96YD#0H@("`@("H@0')E='5R;B!S=')I;F=\87)R87D@(%)E='5R
M;G,@=&AE(&9U;&P@<&%T:"!O9B!T:&4@9&]W;FQO861E9"!F:6QE(&]R(&$@
M4$5!4@T*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!E<G)O<B!O;B!F
M86EL=7)E+B`@268@=&AE(&5R<F]R(&ES(&-A=7-E9"!B>0T*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!S;V-K970M<F5L871E9"!E<G)O<G,L('1H
M92!E<G)O<B!O8FIE8W0@=VEL;`T*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!H879E('1H92!F<V]C:V]P96X@97)R;W(@8V]D92!A=F%I;&%B;&4@
M=&AR;W5G:`T*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!G971#;V1E
M*"DN("!)9B!C86-H:6YG(&ES(')E<75E<W1E9"P@=&AE;B!R971U<FX@=&AE
M(&AE861E<@T*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!V86QU97,N
M#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@
M(&9U;F-T:6]N(&1O=VYL;V%D2'1T<"@D=7)L+"`F)'5I+"`D<V%V95]D:7(@
M/2`G+B<L("1C86QL8F%C:R`](&YU;&PL("1L87-T;6]D:69I960@/2!N=6QL
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`D86-C97!T(#T@9F%L<V4I
M#0H@("`@>PT*("`@("`@("!S=&%T:6,@)')E9&ER96-T(#T@,#L-"B`@("`@
M("`@+R\@86QL=V%Y<R!R97-E="`L('-O('=E(&%R92!C;&5A;B!C87-E(&]F
M(&5R<F]R#0H@("`@("`@("1W87-R961I<F5C="`]("1R961I<F5C=#L-"B`@
M("`@("`@)')E9&ER96-T(#T@,#L-"B`@("`@("`@:68@*"1C86QL8F%C:RD@
M>PT*("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F,H)&-A;&QB86-K+"`G<V5T
M=7`G+"!A<G)A>2@F)'5I*2D[#0H@("`@("`@('T-"B`@("`@("`@)&EN9F\@
M/2!P87)S95]U<FPH)'5R;"D[#0H@("`@("`@(&EF("@A:7-S970H)&EN9F];
M)W-C:&5M92==*2!\?"`A:6Y?87)R87DH)&EN9F];)W-C:&5M92==+"!A<G)A
M>2@G:'1T<"<L("=H='1P<R<I*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)T-A;FYO="!D;W=N;&]A9"!N;VXM:'1T<"!54DP@
M(B<@+B`D=7)L("X@)R(G*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES
M<V5T*"1I;F9O6R=H;W-T)UTI*2![#0H@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@G0V%N;F]T(&1O=VYL;V%D(&9R;VT@;F]N+5523"`B
M)R`N("1U<FP@+B`G(B<I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@)&AO<W0@/2!`)&EN9F];)VAO<W0G73L-"B`@("`@("`@("`@("1P;W)T
M(#T@0"1I;F9O6R=P;W)T)UT[#0H@("`@("`@("`@("`D<&%T:"`]($`D:6YF
M;ULG<&%T:"==.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D=&AI
M<RDI('L-"B`@("`@("`@("`@("1C;VYF:6<@/2`F)'1H:7,M/F-O;F9I9SL-
M"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1C;VYF:6<@/2`F4$5!
M4E]#;VYF:6<Z.G-I;F=L971O;B@I.PT*("`@("`@("!]#0H@("`@("`@("1P
M<F]X>5]H;W-T(#T@)'!R;WAY7W!O<G0@/2`D<')O>'E?=7-E<B`]("1P<F]X
M>5]P87-S(#T@)R<[#0H@("`@("`@(&EF("@D8V]N9FEG+3YG970H)VAT='!?
M<')O>'DG*28F(`T*("`@("`@("`@("`@("`D<')O>'D@/2!P87)S95]U<FPH
M)&-O;F9I9RT^9V5T*"=H='1P7W!R;WAY)RDI*2![#0H@("`@("`@("`@("`D
M<')O>'E?:&]S="`]($`D<')O>'E;)VAO<W0G73L-"B`@("`@("`@("`@(&EF
M("AI<W-E="@D<')O>'E;)W-C:&5M92==*2`F)B`D<')O>'E;)W-C:&5M92==
M(#T]("=H='1P<R<I('L-"B`@("`@("`@("`@("`@("`D<')O>'E?:&]S="`]
M("=S<VPZ+R\G("X@)'!R;WAY7VAO<W0[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`D<')O>'E?<&]R="`]($`D<')O>'E;)W!O<G0G73L-"B`@("`@
M("`@("`@("1P<F]X>5]U<V5R(#T@0"1P<F]X>5LG=7-E<B==.PT*("`@("`@
M("`@("`@)'!R;WAY7W!A<W,@/2!`)'!R;WAY6R=P87-S)UT[#0H-"B`@("`@
M("`@("`@(&EF("@D<')O>'E?<&]R="`]/2`G)RD@>PT*("`@("`@("`@("`@
M("`@("1P<F]X>5]P;W)T(#T@.#`X,#L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&EF("@D8V%L;&)A8VLI('L-"B`@("`@("`@("`@("`@("!C86QL
M7W5S97)?9G5N8R@D8V%L;&)A8VLL("=M97-S86=E)RP@(E5S:6YG($A45%`@
M<')O>'D@)&AO<W0Z)'!O<G0B*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H96UP='DH)'!O<G0I*2![#0H@("`@("`@("`@("!I
M9B`H:7-S970H)&EN9F];)W-C:&5M92==*2`F)B`D:6YF;ULG<V-H96UE)UT@
M/3T@)VAT='!S)RD@>PT*("`@("`@("`@("`@("`@("1P;W)T(#T@-#0S.PT*
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D<&]R="`]
M(#@P.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@D
M<')O>'E?:&]S="`A/2`G)RD@>PT*("`@("`@("`@("`@)&9P(#T@0&9S;V-K
M;W!E;B@D<')O>'E?:&]S="P@)'!R;WAY7W!O<G0L("1E<G)N;RP@)&5R<G-T
M<BD[#0H@("`@("`@("`@("!I9B`H(21F<"D@>PT*("`@("`@("`@("`@("`@
M(&EF("@D8V%L;&)A8VLI('L-"B`@("`@("`@("`@("`@("`@("`@8V%L;%]U
M<V5R7V9U;F,H)&-A;&QB86-K+"`G8V]N;F9A:6QE9"<L(&%R<F%Y*"1P<F]X
M>5]H;W-T+"`D<')O>'E?<&]R="P-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E
M<G)N;RP@)&5R<G-T<BDI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B0V]N;F5C=&EO;B!T
M;R!@)'!R;WAY7VAO<W0Z)'!R;WAY7W!O<G0G(&9A:6QE9#H@)&5R<G-T<B(L
M("1E<G)N;RD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)&QA
M<W1M;V1I9FEE9"`]/3T@9F%L<V4@?'P@)&QA<W1M;V1I9FEE9"D@>PT*("`@
M("`@("`@("`@("`@("1R97%U97-T(#T@(D=%5"`D=7)L($A45%`O,2XQ7')<
M;B([#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1R
M97%U97-T(#T@(D=%5"`D=7)L($A45%`O,2XP7')<;B([#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!I9B`H:7-S970H
M)&EN9F];)W-C:&5M92==*2`F)B`D:6YF;ULG<V-H96UE)UT@/3T@)VAT='!S
M)RD@>PT*("`@("`@("`@("`@("`@("1H;W-T(#T@)W-S;#HO+R<@+B`D:&]S
M=#L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1F<"`]($!F<V]C:V]P
M96XH)&AO<W0L("1P;W)T+"`D97)R;F\L("1E<G)S='(I.PT*("`@("`@("`@
M("`@:68@*"$D9G`I('L-"B`@("`@("`@("`@("`@("!I9B`H)&-A;&QB86-K
M*2![#0H@("`@("`@("`@("`@("`@("`@(&-A;&Q?=7-E<E]F=6YC*"1C86QL
M8F%C:RP@)V-O;FYF86EL960G+"!A<G)A>2@D:&]S="P@)'!O<G0L#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D97)R;F\L("1E<G)S='(I*3L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H(D-O;FYE8W1I;VX@=&\@8"1H;W-T.B1P;W)T)R!F86EL960Z("1E
M<G)S='(B+"`D97)R;F\I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M:68@*"1L87-T;6]D:69I960@/3T](&9A;'-E('Q\("1L87-T;6]D:69I960I
M('L-"B`@("`@("`@("`@("`@("`D<F5Q=65S="`](")'150@)'!A=&@@2%14
M4"\Q+C%<<EQN(CL-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@)')E<75E<W0@/2`B1T54("1P871H($A45%`O,2XP7')<;B([#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)&EF;6]D:69I961S
M:6YC92`]("<G.PT*("`@("`@("!I9B`H:7-?87)R87DH)&QA<W1M;V1I9FEE
M9"DI('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D;&%S=&UO9&EF:65D6R=,
M87-T+4UO9&EF:65D)UTI*2![#0H@("`@("`@("`@("`@("`@)&EF;6]D:69I
M961S:6YC92`]("=)9BU-;V1I9FEE9"U3:6YC93H@)R`N("1L87-T;6]D:69I
M961;)TQA<W0M36]D:69I960G72`N(")<<EQN(CL-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(&EF("AI<W-E="@D;&%S=&UO9&EF:65D6R=%5&%G)UTI
M*2![#0H@("`@("`@("`@("`@("`@)&EF;6]D:69I961S:6YC92`N/2`B268M
M3F]N92U-871C:#H@)&QA<W1M;V1I9FEE9%M%5&%G75QR7&XB.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&EF;6]D
M:69I961S:6YC92`]("@D;&%S=&UO9&EF:65D(#\@(DEF+4UO9&EF:65D+5-I
M;F-E.B`D;&%S=&UO9&EF:65D7')<;B(@.B`G)RD[#0H@("`@("`@('T-"B`@
M("`@("`@)')E<75E<W0@+CT@(DAO<W0Z("1H;W-T.B1P;W)T7')<;B(@+B`D
M:69M;V1I9FEE9'-I;F-E("X-"B`@("`@("`@("`@(")5<V5R+4%G96YT.B!0
M14%2+S$N-"XY+U!(4"\B("X@4$A07U9%4E-)3TX@+B`B7')<;B([#0H@("`@
M("`@(&EF("AI<W-E="@D=&AI<RDI('L@+R\@;VYL>2!P87-S(&EN(&%U=&AE
M;G1I8V%T:6]N(&9O<B!N;VXM<W1A=&EC(&-A;&QS#0H@("`@("`@("`@("`D
M=7-E<FYA;64@/2`D8V]N9FEG+3YG970H)W5S97)N86UE)RD[#0H@("`@("`@
M("`@("`D<&%S<W=O<F0@/2`D8V]N9FEG+3YG970H)W!A<W-W;W)D)RD[#0H@
M("`@("`@("`@("!I9B`H)'5S97)N86UE("8F("1P87-S=V]R9"D@>PT*("`@
M("`@("`@("`@("`@("1T;7`@/2!B87-E-C1?96YC;V1E*"(D=7-E<FYA;64Z
M)'!A<W-W;W)D(BD[#0H@("`@("`@("`@("`@("`@)')E<75E<W0@+CT@(D%U
M=&AO<FEZ871I;VXZ($)A<VEC("1T;7!<<EQN(CL-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H)'!R;WAY7VAO<W0@(3T@)R<@)B8@
M)'!R;WAY7W5S97(@(3T@)R<I('L-"B`@("`@("`@("`@("1R97%U97-T("X]
M("=0<F]X>2U!=71H;W)I>F%T:6]N.B!"87-I8R`G("X-"B`@("`@("`@("`@
M("`@("!B87-E-C1?96YC;V1E*"1P<F]X>5]U<V5R("X@)SHG("X@)'!R;WAY
M7W!A<W,I("X@(EQR7&XB.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D86-C
M97!T*2![#0H@("`@("`@("`@("`D<F5Q=65S="`N/2`G06-C97!T.B`G("X@
M:6UP;&]D92@G+"`G+"`D86-C97!T*2`N(")<<EQN(CL-"B`@("`@("`@?0T*
M("`@("`@("`D<F5Q=65S="`N/2`B0V]N;F5C=&EO;CH@8VQO<V5<<EQN(CL-
M"B`@("`@("`@)')E<75E<W0@+CT@(EQR7&XB.PT*("`@("`@("!F=W)I=&4H
M)&9P+"`D<F5Q=65S="D[#0H@("`@("`@("1H96%D97)S(#T@87)R87DH*3L-
M"B`@("`@("`@)')E<&QY(#T@,#L-"B`@("`@("`@=VAI;&4@*'1R:6TH)&QI
M;F4@/2!F9V5T<R@D9G`L(#$P,C0I*2D@>PT*("`@("`@("`@("`@:68@*'!R
M96=?;6%T8V@H)R]>*%M>.ETK*3I<<RLH+BHI7',J)"\G+"`D;&EN92P@)&UA
M=&-H97,I*2![#0H@("`@("`@("`@("`@("`@)&AE861E<G-;<W1R=&]L;W=E
M<B@D;6%T8VAE<ULQ72E=(#T@=')I;2@D;6%T8VAE<ULR72D[#0H@("`@("`@
M("`@("!](&5L<V5I9B`H<')E9U]M871C:"@G?%Y(5%10+S$N6S`Q72`H6S`M
M.5U[,WTI('PG+"`D;&EN92P@)&UA=&-H97,I*2![#0H@("`@("`@("`@("`@
M("`@)')E<&QY(#T@*&EN="D@)&UA=&-H97-;,5T[#0H@("`@("`@("`@("`@
M("`@:68@*"1R97!L>2`]/2`S,#0@)B8@*"1L87-T;6]D:69I960@?'P@*"1L
M87-T;6]D:69I960@/3T](&9A;'-E*2DI('L-"B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!I9B`H(2!I;E]A<G)A>2@D<F5P;'DL(&%R<F%Y*#(P,"P@,S`Q
M+"`S,#(L(#,P,RP@,S`U+"`S,#<I*2D@>PT*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B1FEL92!H='1P.B\O)&AO<W0Z
M)'!O<G0D<&%T:"!N;W0@=F%L:60@*')E8V5I=F5D.B`D;&EN92DB*3L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"1R97!L>2`A/2`R,#`I('L-"B`@("`@("`@("`@(&EF("AI
M<W-E="@D:&5A9&5R<ULG;&]C871I;VXG72DI('L-"B`@("`@("`@("`@("`@
M("!I9B`H)'=A<W)E9&ER96-T(#P@-2D@>PT*("`@("`@("`@("`@("`@("`@
M("`D<F5D:7)E8W0@/2`D=V%S<F5D:7)E8W0@*R`Q.PT*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/F1O=VYL;V%D2'1T<"@D:&5A9&5R<ULG
M;&]C871I;VXG72P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=6DL
M("1S879E7V1I<BP@)&-A;&QB86-K+"`D;&%S=&UO9&EF:65D+"`D86-C97!T
M*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B1FEL92!H='1P.B\O)&AO
M<W0Z)'!O<G0D<&%T:"!N;W0@=F%L:60@*')E9&ER96-T:6]N(&QO;W!E9"!M
M;W)E('1H86X@-2!T:6UE<RDB*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*")&:6QE(&AT='`Z+R\D:&]S=#HD<&]R="1P871H(&YO
M="!V86QI9"`H<F5D:7)E8W1E9"!B=70@;F\@;&]C871I;VXI(BD[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1H96%D
M97)S6R=C;VYT96YT+61I<W!O<VET:6]N)UTI("8F#0H@("`@("`@("`@("!P
M<F5G7VUA=&-H*"<O7'-F:6QE;F%M93U<(BA;7CM=*EQ3*5PB7',J*#M\)"DO
M)RP@)&AE861E<G-;)V-O;G1E;G0M9&ES<&]S:71I;VXG72P@)&UA=&-H97,I
M*2![#0H@("`@("`@("`@("`D<V%V95]A<R`](&)A<V5N86UE*"1M871C:&5S
M6S%=*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1S879E7V%S
M(#T@8F%S96YA;64H)'5R;"D[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1C
M86QL8F%C:RD@>PT*("`@("`@("`@("`@)'1M<"`](&-A;&Q?=7-E<E]F=6YC
M*"1C86QL8F%C:RP@)W-A=F5A<R<L("1S879E7V%S*3L-"B`@("`@("`@("`@
M(&EF("@D=&UP*2![#0H@("`@("`@("`@("`@("`@)'-A=F5?87,@/2`D=&UP
M.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1D97-T7V9I
M;&4@/2`D<V%V95]D:7(@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)'-A=F5?
M87,[#0H@("`@("`@(&EF("@A)'=P(#T@0&9O<&5N*"1D97-T7V9I;&4L("=W
M8B<I*2![#0H@("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@("`@
M(&EF("@D8V%L;&)A8VLI('L-"B`@("`@("`@("`@("`@("!C86QL7W5S97)?
M9G5N8R@D8V%L;&)A8VLL("=W<FET969A:6QE9"<L(&%R<F%Y*"1D97-T7V9I
M;&4L("1P:'!?97)R;W)M<V<I*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")C;W5L9"!N;W0@;W!E;B`D
M9&5S=%]F:6QE(&9O<B!W<FET:6YG(BD[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&ES<V5T*"1H96%D97)S6R=C;VYT96YT+6QE;F=T:"==*2D@>PT*("`@
M("`@("`@("`@)&QE;F=T:"`]("1H96%D97)S6R=C;VYT96YT+6QE;F=T:"==
M.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&QE;F=T:"`]("TQ
M.PT*("`@("`@("!]#0H@("`@("`@("1B>71E<R`](#`[#0H@("`@("`@(&EF
M("@D8V%L;&)A8VLI('L-"B`@("`@("`@("`@(&-A;&Q?=7-E<E]F=6YC*"1C
M86QL8F%C:RP@)W-T87)T)RP@87)R87DH8F%S96YA;64H)&1E<W1?9FEL92DL
M("1L96YG=&@I*3L-"B`@("`@("`@?0T*("`@("`@("!W:&EL92`H)&1A=&$@
M/2!`9G)E860H)&9P+"`Q,#(T*2D@>PT*("`@("`@("`@("`@)&)Y=&5S("L]
M('-T<FQE;B@D9&%T82D[#0H@("`@("`@("`@("!I9B`H)&-A;&QB86-K*2![
M#0H@("`@("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F,H)&-A;&QB86-K+"`G
M8GET97-R96%D)RP@)&)Y=&5S*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(&EF("@A0&9W<FET92@D=W`L("1D871A*2D@>PT*("`@("`@("`@("`@
M("`@(&9C;&]S92@D9G`I.PT*("`@("`@("`@("`@("`@(&EF("@D8V%L;&)A
M8VLI('L-"B`@("`@("`@("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F,H)&-A
M;&QB86-K+"`G=W)I=&5F86EL960G+"!A<G)A>2@D9&5S=%]F:6QE+"`D<&AP
M7V5R<F]R;7-G*2D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"(D9&5S=%]F:6QE.B!W<FET
M92!F86EL960@*"1P:'!?97)R;W)M<V<I(BD[#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@(&9C;&]S
M92@D=W`I.PT*("`@("`@("!I9B`H)&-A;&QB86-K*2![#0H@("`@("`@("`@
M("!C86QL7W5S97)?9G5N8R@D8V%L;&)A8VLL("=D;VYE)RP@)&)Y=&5S*3L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H)&QA<W1M;V1I9FEE9"`]/3T@9F%L
M<V4@?'P@)&QA<W1M;V1I9FEE9"D@>PT*("`@("`@("`@("`@:68@*&ES<V5T
M*"1H96%D97)S6R=E=&%G)UTI*2![#0H@("`@("`@("`@("`@("`@)&QA<W1M
M;V1I9FEE9"`](&%R<F%Y*"=%5&%G)R`]/B`D:&5A9&5R<ULG971A9R==*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D:&5A9&5R
M<ULG;&%S="UM;V1I9FEE9"==*2D@>PT*("`@("`@("`@("`@("`@(&EF("AI
M<U]A<G)A>2@D;&%S=&UO9&EF:65D*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`D;&%S=&UO9&EF:65D6R=,87-T+4UO9&EF:65D)UT@/2`D:&5A9&5R<ULG
M;&%S="UM;V1I9FEE9"==.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@("`@("1L87-T;6]D:69I960@/2`D:&5A9&5R<ULG
M;&%S="UM;V1I9FEE9"==.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(')E='5R;B!A<G)A>2@D9&5S=%]F:6QE+"`D
M;&%S=&UO9&EF:65D+"`D:&5A9&5R<RD[#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N("1D97-T7V9I;&4[#0H@("`@?0T*?0T*+R\@?7U]#0H-"C\^#0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O4$5!4B]%<G)O<E-T86-K+G!H<```````````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#$P,S8Q,R`Q,#4Q-30S,S<S,B`P,C(P,3``(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`-"B\J
M*@T*("H@17)R;W(@4W1A8VL@26UP;&5M96YT871I;VX-"B`J(`T*("H@5&AI
M<R!I<R!A;B!I;F-R961I8FQY('-I;7!L92!I;7!L96UE;G1A=&EO;B!O9B!A
M('9E<GD@8V]M<&QE>"!E<G)O<B!H86YD;&EN9PT*("H@9F%C:6QI='DN("!)
M="!C;VYT86EN<R!T:&4@86)I;&ET>0T*("H@=&\@=')A8VL@;75L=&EP;&4@
M97)R;W)S(&9R;VT@;75L=&EP;&4@<&%C:V%G97,@<VEM=6QT86YE;W5S;'DN
M("!);B!A9&1I=&EO;BP-"B`J(&ET(&-A;B!T<F%C:R!E<G)O<G,@;V8@;6%N
M>2!L979E;',L('-A=F4@9&%T82!A;&]N9R!W:71H('1H92!E<G)O<BP@8V]N
M=&5X=`T*("H@:6YF;W)M871I;VX@<W5C:"!A<R!T:&4@97AA8W0@9FEL92P@
M;&EN92!N=6UB97(L(&-L87-S(&%N9"!F=6YC=&EO;B!T:&%T#0H@*B!G96YE
M<F%T960@=&AE(&5R<F]R+"!A;F0@:68@;F5C97-S87)Y+"!I="!C86X@<F%I
M<V4@82!T<F%D:71I;VYA;"!014%27T5R<F]R+@T*("H@270@:&%S(&)U:6QT
M+6EN('-U<'!O<G0@9F]R(%!%05(Z.DQO9RP@=&\@;&]G(&5R<F]R<R!A<R!T
M:&5Y(&]C8W5R#0H@*B`-"B`J(%-I;F-E('9E<G-I;VX@,"XR86QP:&$L(&ET
M(&ES(&%L<V\@<&]S<VEB;&4@=&\@<V5L96-T:79E;'D@:6=N;W)E(&5R<F]R
M<RP-"B`J('1H<F]U9V@@=&AE('5S92!O9B!A;B!E<G)O<B!C86QL8F%C:RP@
M<V5E('M`;&EN:R!P=7-H0V%L;&)A8VLH*7T-"B`J(`T*("H@4VEN8V4@=F5R
M<VEO;B`P+C-A;'!H82P@:70@:7,@<&]S<VEB;&4@=&\@<W!E8VEF>2!T:&4@
M97AC97!T:6]N(&-L87-S#0H@*B!R971U<FYE9"!F<F]M('M`;&EN:R!P=7-H
M*"E]#0H@*@T*("H@4VEN8V4@=F5R<VEO;B!014%2,2XS+C(L($5R<F]R4W1A
M8VL@;F\@;&]N9V5R(&EN<W1A;G1I871E<R!A;B!E>&-E<'1I;VX@8VQA<W,N
M("!4:&ES(&-A;@T*("H@<W1I;&P@8F4@9&]N92!Q=6ET92!H86YD:6QY(&EN
M(&%N(&5R<F]R(&-A;&QB86-K(&]R(&)Y(&UA;FEP=6QA=&EN9R!T:&4@<F5T
M=7)N960@87)R87D-"B`J($!C871E9V]R>2`@($1E8G5G9VEN9PT*("H@0'!A
M8VMA9V4@("`@4$5!4E]%<G)O<E-T86-K#0H@*B!`875T:&]R("`@("!'<F5G
M($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`R,#`T
M+3(P,#8@1W)E9R!"96%V97(-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@
M0'9E<G-I;VX@("`@0U93.B`D260Z($5R<F]R4W1A8VLN<&AP+'8@,2XR,B`R
M,#`V+S`Q+S`V(#`T.C0W.C,V(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@
M("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05)?17)R;W)3=&%C
M:PT*("HO#0H-"B\J*@T*("H@4VEN9VQE=&]N('-T;W)A9V4-"B`J(`T*("H@
M1F]R;6%T.@T*("H@/'!R93X-"B`J(&%R<F%Y*`T*("H@("=P86-K86=E,2<@
M/3X@4$5!4E]%<G)O<E-T86-K(&]B:F5C="P-"B`J("`G<&%C:V%G93(G(#T^
M(%!%05)?17)R;W)3=&%C:R!O8FIE8W0L#0H@*B`@+BXN#0H@*B`I#0H@*B`\
M+W!R93X-"B`J($!A8V-E<W,@<')I=F%T90T*("H@0&=L;V)A;"!A<G)A>2`D
M1TQ/0D%,4ULG7U!%05)?15)23U)35$%#2U]324Y'3$543TXG70T*("HO#0HD
M1TQ/0D%,4ULG7U!%05)?15)23U)35$%#2U]324Y'3$543TXG72`](&%R<F%Y
M*"D[#0H-"B\J*@T*("H@1VQO8F%L(&5R<F]R(&-A;&QB86-K("AD969A=6QT
M*0T*("H@#0H@*B!4:&ES(&ES(&]N;'D@=7-E9"!I9B!S970@=&\@;F]N+69A
M;'-E+B`@*B!I<R!T:&4@9&5F875L="!C86QL8F%C:R!F;W(-"B`J(&%L;"!P
M86-K86=E<RP@=VAE<F5A<R!S<&5C:69I8R!P86-K86=E<R!M87D@<V5T(&$@
M9&5F875L="!C86QL8F%C:PT*("H@9F]R(&%L;"!I;G-T86YC97,L(')E9V%R
M9&QE<W,@;V8@=VAE=&AE<B!T:&5Y(&%R92!A('-I;F=L971O;B!O<B!N;W0N
M#0H@*@T*("H@5&\@97AC;'5D92!N;VXM<VEN9VQE=&]N<RP@;VYL>2!S970@
M=&AE(&QO8V%L(&-A;&QB86-K(&9O<B!T:&4@<VEN9VQE=&]N#0H@*B!`<V5E
M(%!%05)?17)R;W)3=&%C:SHZ<V5T1&5F875L=$-A;&QB86-K*"D-"B`J($!A
M8V-E<W,@<')I=F%T90T*("H@0&=L;V)A;"!A<G)A>2`D1TQ/0D%,4ULG7U!%
M05)?15)23U)35$%#2U]$149!54Q47T-!3$Q"04-+)UT-"B`J+PT*)$=,3T)!
M3%-;)U]014%27T524D]24U1!0TM?1$5&055,5%]#04Q,0D%#2R==(#T@87)R
M87DH#0H@("`@)RHG(#T^(&9A;'-E+`T**3L-"@T*+RHJ#0H@*B!';&]B86P@
M3&]G(&]B:F5C="`H9&5F875L="D-"B`J(`T*("H@5&AI<R!I<R!O;FQY('5S
M960@:68@<V5T('1O(&YO;BUF86QS92X@(%5S92!T;R!S970@82!D969A=6QT
M(&QO9R!O8FIE8W0@9F]R#0H@*B!A;&P@<W1A8VMS+"!R96=A<F1L97-S(&]F
M(&EN<W1A;G1I871I;VX@;W)D97(@;W(@;&]C871I;VX-"B`J($!S964@4$5!
M4E]%<G)O<E-T86-K.CIS971$969A=6QT3&]G9V5R*"D-"B`J($!A8V-E<W,@
M<')I=F%T90T*("H@0&=L;V)A;"!A<G)A>2`D1TQ/0D%,4ULG7U!%05)?15)2
M3U)35$%#2U]$149!54Q47TQ/1T=%4B==#0H@*B\-"B1'3$]"04Q36R=?4$5!
M4E]%4E)/4E-404-+7T1%1D%53%1?3$]'1T52)UT@/2!F86QS93L-"@T*+RHJ
M#0H@*B!';&]B86P@3W9E<G)I9&EN9R!#86QL8F%C:PT*("H@#0H@*B!4:&ES
M(&-A;&QB86-K('=I;&P@;W9E<G)I9&4@86YY(&5R<F]R(&-A;&QB86-K<R!T
M:&%T('-P96-I9FEC(&QO9V=E<G,@:&%V92!S970N#0H@*B!5<V4@=VET:"!%
M6%1214U%(&-A=71I;VX-"B`J($!S964@4$5!4E]%<G)O<E-T86-K.CIS=&%T
M:6-0=7-H0V%L;&)A8VLH*0T*("H@0&%C8V5S<R!P<FEV871E#0H@*B!`9VQO
M8F%L(&%R<F%Y("1'3$]"04Q36R=?4$5!4E]%4E)/4E-404-+7T1%1D%53%1?
M3$]'1T52)UT-"B`J+PT*)$=,3T)!3%-;)U]014%27T524D]24U1!0TM?3U9%
M4E))1$5?0T%,3$)!0TLG72`](&%R<F%Y*"D[#0H-"B\J*B-`*PT*("H@3VYE
M(&]F(&9O=7(@<&]S<VEB;&4@<F5T=7)N('9A;'5E<R!F<F]M('1H92!E<G)O
M<B!#86QL8F%C:PT*("H@0'-E92!014%27T5R<F]R4W1A8VLZ.E]E<G)O<D-A
M;&QB86-K*"D-"B`J+PT*+RHJ#0H@*B!)9B!T:&ES(&ES(')E='5R;F5D+"!T
M:&5N('1H92!E<G)O<B!W:6QL(&)E(&)O=&@@<'5S:&5D(&]N=&\@=&AE('-T
M86-K#0H@*B!A;F0@;&]G9V5D+@T*("HO#0ID969I;F4H)U!%05)?15)23U)3
M5$%#2U]055-(04Y$3$]')RP@,2D[#0HO*BH-"B`J($EF('1H:7,@:7,@<F5T
M=7)N960L('1H96X@=&AE(&5R<F]R('=I;&P@;VYL>2!B92!P=7-H960@;VYT
M;R!T:&4@<W1A8VLL#0H@*B!A;F0@;F]T(&QO9V=E9"X-"B`J+PT*9&5F:6YE
M*"=014%27T524D]24U1!0TM?4%532"<L(#(I.PT*+RHJ#0H@*B!)9B!T:&ES
M(&ES(')E='5R;F5D+"!T:&5N('1H92!E<G)O<B!W:6QL(&]N;'D@8F4@;&]G
M9V5D+"!B=70@;F]T('!U<VAE9`T*("H@;VYT;R!T:&4@97)R;W(@<W1A8VLN
M#0H@*B\-"F1E9FEN92@G4$5!4E]%4E)/4E-404-+7TQ/1R<L(#,I.PT*+RHJ
M#0H@*B!)9B!T:&ES(&ES(')E='5R;F5D+"!T:&5N('1H92!E<G)O<B!I<R!C
M;VUP;&5T96QY(&EG;F]R960N#0H@*B\-"F1E9FEN92@G4$5!4E]%4E)/4E-4
M04-+7TE'3D]212<L(#0I.PT*+RHJ#0H@*B!)9B!T:&ES(&ES(')E='5R;F5D
M+"!T:&5N('1H92!E<G)O<B!I<R!L;V=G960@86YD(&1I92@I(&ES(&-A;&QE
M9"X-"B`J+PT*9&5F:6YE*"=014%27T524D]24U1!0TM?1$E%)RP@-2D[#0HO
M*BHC0"TJ+PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@9F]R(&%N(&%T=&5M<'0@
M=&\@:6YS=&%N=&EA=&4@82!N;VXM8VQA<W,@87,@82!014%27T5R<F]R4W1A
M8VL@:6X-"B`J('1H92!S:6YG;&5T;VX@;65T:&]D+@T*("HO#0ID969I;F4H
M)U!%05)?15)23U)35$%#2U]%4E)?3D].0TQ!4U,G+"`Q*3L-"@T*+RHJ#0H@
M*B!%<G)O<B!C;V1E(&9O<B!A;B!A='1E;7!T('1O('!A<W,@86X@;V)J96-T
M(&EN=&\@>T!L:6YK(%!%05)?17)R;W)3=&%C:SHZ9V5T365S<V%G92@I?0T*
M("H@=&AA="!H87,@;F\@7U]T;U-T<FEN9R@I(&UE=&AO9`T*("HO#0ID969I
M;F4H)U!%05)?15)23U)35$%#2U]%4E)?3T)*5$]35%))3D<G+"`R*3L-"B\J
M*@T*("H@17)R;W(@4W1A8VL@26UP;&5M96YT871I;VX-"B`J#0H@*B!5<V%G
M93H-"B`J(#QC;V1E/@T*("H@+R\@9VQO8F%L(&5R<F]R('-T86-K#0H@*B`D
M9VQO8F%L7W-T86-K(#T@)E!%05)?17)R;W)3=&%C:SHZ<VEN9VQE=&]N*"=-
M>5!A8VMA9V4G*3L-"B`J("\O(&QO8V%L(&5R<F]R('-T86-K#0H@*B`D;&]C
M86Q?<W1A8VL@/2!N97<@4$5!4E]%<G)O<E-T86-K*"=->5!A8VMA9V4G*3L-
M"B`J(#PO8V]D93X-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL
M;V=`<&AP+FYE=#X-"B`J($!V97)S:6]N("`@(#$N-"XY#0H@*B!`<&%C:V%G
M92`@("!014%27T5R<F]R4W1A8VL-"B`J($!C871E9V]R>2`@($1E8G5G9VEN
M9PT*("H@0&-O<'ER:6=H="`@,C`P-"TR,#`V($=R96<@0F5A=F5R#0H@*B!`
M;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT
M("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!%
M<G)O<E-T86-K+G!H<"QV(#$N,C(@,C`P-B\P,2\P-B`P-#HT-SHS-B!C96QL
M;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O
M<&%C:V%G92]014%27T5R<F]R4W1A8VL-"B`J+PT*8VQA<W,@4$5!4E]%<G)O
M<E-T86-K('L-"B`@("`O*BH-"B`@("`@*B!%<G)O<G,@87)E('-T;W)E9"!I
M;B!T:&4@;W)D97(@=&AA="!T:&5Y(&%R92!P=7-H960@;VX@=&AE('-T86-K
M+@T*("`@("`J($!S:6YC92`P+C1A;'!H82!%<G)O<G,@87)E(&YO(&QO;F=E
M<B!O<F=A;FEZ960@8GD@97)R;W(@;&5V96PN#0H@("`@("H@5&AI<R!R96YD
M97)S('!O<"@I(&YE87)L>2!U;G5S86)L92P@86YD(&QE=F5L<R!C;W5L9"!B
M92!M;W)E(&5A<VEL>0T*("`@("`J(&AA;F1L960@:6X@82!C86QL8F%C:R!A
M;GEW87D-"B`@("`@*B!`=F%R(&%R<F%Y#0H@("`@("H@0&%C8V5S<R!P<FEV
M871E#0H@("`@("HO#0H@("`@=F%R("1?97)R;W)S(#T@87)R87DH*3L-"@T*
M("`@("\J*@T*("`@("`J(%-T;W)A9V4@;V8@97)R;W)S(&)Y(&QE=F5L+@T*
M("`@("`J#0H@("`@("H@06QL;W=S(&5A<WD@<F5T<FEE=F%L(&%N9"!D96QE
M=&EO;B!O9B!O;FQY(&5R<F]R<R!F<F]M(&$@<&%R=&EC=6QA<B!L979E;`T*
M("`@("`J($!S:6YC92!014%2(#$N-"XP9&5V#0H@("`@("H@0'9A<B!A<G)A
M>0T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D
M7V5R<F]R<T)Y3&5V96P@/2!A<G)A>2@I.PT*#0H@("`@+RHJ#0H@("`@("H@
M4&%C:V%G92!N86UE('1H:7,@97)R;W(@<W1A8VL@<F5P<F5S96YT<PT*("`@
M("`J($!V87(@<W1R:6YG#0H@("`@("H@0&%C8V5S<R!P<F]T96-T960-"B`@
M("`@*B\-"B`@("!V87(@)%]P86-K86=E.PT*("`@(`T*("`@("\J*@T*("`@
M("`J($1E=&5R;6EN97,@=VAE=&AE<B!A(%!%05)?17)R;W(@:7,@=&AR;W=N
M('5P;VX@979E<GD@97)R;W(@861D:71I;VX-"B`@("`@*B!`=F%R(&)O;VQE
M86X-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!V87(@
M)%]C;VUP870@/2!F86QS93L-"B`@("`-"B`@("`O*BH-"B`@("`@*B!)9B!S
M970@=&\@82!V86QI9"!C86QL8F%C:RP@=&AI<R!W:6QL(&)E('5S960@=&\@
M9V5N97)A=&4@=&AE(&5R<F]R#0H@("`@("H@;65S<V%G92!F<F]M('1H92!E
M<G)O<B!C;V1E+"!O=&AE<G=I<V4@=&AE(&UE<W-A9V4@<&%S<V5D(&EN('=I
M;&P@8F4-"B`@("`@*B!U<V5D#0H@("`@("H@0'9A<B!F86QS97QS=')I;F=\
M87)R87D-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!V
M87(@)%]M<V=#86QL8F%C:R`](&9A;'-E.PT*("`@(`T*("`@("\J*@T*("`@
M("`J($EF('-E="!T;R!A('9A;&ED(&-A;&QB86-K+"!T:&ES('=I;&P@8F4@
M=7-E9"!T;R!G96YE<F%T92!T:&4@97)R;W(-"B`@("`@*B!C;VYT97AT(&9O
M<B!A;B!E<G)O<BX@($9O<B!02%`M<F5L871E9"!E<G)O<G,L('1H:7,@=VEL
M;"!B92!A(&9I;&4-"B`@("`@*B!A;F0@;&EN92!N=6UB97(@87,@<F5T<FEE
M=F5D(&9R;VT@9&5B=6=?8F%C:W1R86-E*"DL(&)U="!C86X@8F4-"B`@("`@
M*B!C=7-T;VUI>F5D(&9O<B!O=&AE<B!P=7)P;W-E<RX@(%1H92!E<G)O<B!M
M:6=H="!A8W1U86QL>2!B92!I;B!A('-E<&%R871E#0H@("`@("H@8V]N9FEG
M=7)A=&EO;B!F:6QE+"!O<B!I;B!A(&1A=&%B87-E('%U97)Y+@T*("`@("`J
M($!V87(@9F%L<V5\<W1R:6YG?&%R<F%Y#0H@("`@("H@0&%C8V5S<R!P<F]T
M96-T960-"B`@("`@*B\-"B`@("!V87(@)%]C;VYT97AT0V%L;&)A8VL@/2!F
M86QS93L-"B`@("`-"B`@("`O*BH-"B`@("`@*B!)9B!S970@=&\@82!V86QI
M9"!C86QL8F%C:RP@=&AI<R!W:6QL(&)E(&-A;&QE9"!E=F5R>2!T:6UE(&%N
M(&5R<F]R#0H@("`@("H@:7,@<'5S:&5D(&]N=&\@=&AE('-T86-K+B`@5&AE
M(')E='5R;B!V86QU92!W:6QL(&)E('5S960@=&\@9&5T97)M:6YE#0H@("`@
M("H@=VAE=&AE<B!T;R!A;&QO=R!A;B!E<G)O<B!T;R!B92!P=7-H960@;W(@
M;&]G9V5D+@T*("`@("`J(`T*("`@("`J(%1H92!R971U<FX@=F%L=64@;75S
M="!B92!O;F4@86X@4$5!4E]%4E)/4E-404-+7RH@8V]N<W1A;G0-"B`@("`@
M*B!`<V5E(%!%05)?15)23U)35$%#2U]055-(04Y$3$]'+"!014%27T524D]2
M4U1!0TM?4%532"P@4$5!4E]%4E)/4E-404-+7TQ/1PT*("`@("`J($!V87(@
M9F%L<V5\<W1R:6YG?&%R<F%Y#0H@("`@("H@0&%C8V5S<R!P<F]T96-T960-
M"B`@("`@*B\-"B`@("!V87(@)%]E<G)O<D-A;&QB86-K(#T@87)R87DH*3L-
M"B`@("`-"B`@("`O*BH-"B`@("`@*B!014%2.CI,;V<@;V)J96-T(&9O<B!L
M;V=G:6YG(&5R<F]R<PT*("`@("`J($!V87(@9F%L<V5\3&]G#0H@("`@("H@
M0&%C8V5S<R!P<F]T96-T960-"B`@("`@*B\-"B`@("!V87(@)%]L;V=G97(@
M/2!F86QS93L-"B`@("`-"B`@("`O*BH-"B`@("`@*B!%<G)O<B!M97-S86=E
M<R`M(&1E<VEG;F5D('1O(&)E(&]V97)R:61D96X-"B`@("`@*B!`=F%R(&%R
M<F%Y#0H@("`@("H@0&%B<W1R86-T#0H@("`@("HO#0H@("`@=F%R("1?97)R
M;W)-<V=S(#T@87)R87DH*3L-"B`@("`-"B`@("`O*BH-"B`@("`@*B!3970@
M=7`@82!N97<@97)R;W(@<W1A8VL-"B`@("`@*B`-"B`@("`@*B!`<&%R86T@
M<W1R:6YG("`@)'!A8VMA9V4@;F%M92!O9B!T:&4@<&%C:V%G92!T:&ES(&5R
M<F]R('-T86-K(')E<')E<V5N=',-"B`@("`@*B!`<&%R86T@8V%L;&)A8VL@
M)&US9T-A;&QB86-K(&-A;&QB86-K('5S960@9F]R(&5R<F]R(&UE<W-A9V4@
M9V5N97)A=&EO;@T*("`@("`J($!P87)A;2!C86QL8F%C:R`D8V]N=&5X=$-A
M;&QB86-K(&-A;&QB86-K('5S960@9F]R(&-O;G1E>'0@9V5N97)A=&EO;BP-
M"B`@("`@*B`@("`@("`@("`@("`@("`@9&5F875L=',@=&\@>T!L:6YK(&=E
M=$9I;&5,:6YE*"E]#0H@("`@("H@0'!A<F%M(&)O;VQE86X@("1T:')O=U!%
M05)?17)R;W(-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!014%27T5R<F]R4W1A
M8VLH)'!A8VMA9V4L("1M<V=#86QL8F%C:R`](&9A;'-E+"`D8V]N=&5X=$-A
M;&QB86-K(#T@9F%L<V4L#0H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M<F]W4$5!4E]%<G)O<B`](&9A;'-E*0T*("`@('L-"B`@("`@("`@)'1H:7,M
M/E]P86-K86=E(#T@)'!A8VMA9V4[#0H@("`@("`@("1T:&ES+3YS971-97-S
M86=E0V%L;&)A8VLH)&US9T-A;&QB86-K*3L-"B`@("`@("`@)'1H:7,M/G-E
M=$-O;G1E>'1#86QL8F%C:R@D8V]N=&5X=$-A;&QB86-K*3L-"B`@("`@("`@
M)'1H:7,M/E]C;VUP870@/2`D=&AR;W=014%27T5R<F]R.PT*("`@('T-"B`@
M("`-"B`@("`O*BH-"B`@("`@*B!2971U<FX@82!S:6YG;&4@97)R;W(@<W1A
M8VL@9F]R('1H:7,@<&%C:V%G92X-"B`@("`@*B`-"B`@("`@*B!.;W1E('1H
M870@86QL('!A<F%M971E<G,@87)E(&EG;F]R960@:68@=&AE('-T86-K(&9O
M<B!P86-K86=E("1P86-K86=E#0H@("`@("H@:&%S(&%L<F5A9'D@8F5E;B!I
M;G-T86YT:6%T960-"B`@("`@*B!`<&%R86T@<W1R:6YG("`@)'!A8VMA9V4@
M;F%M92!O9B!T:&4@<&%C:V%G92!T:&ES(&5R<F]R('-T86-K(')E<')E<V5N
M=',-"B`@("`@*B!`<&%R86T@8V%L;&)A8VL@)&US9T-A;&QB86-K(&-A;&QB
M86-K('5S960@9F]R(&5R<F]R(&UE<W-A9V4@9V5N97)A=&EO;@T*("`@("`J
M($!P87)A;2!C86QL8F%C:R`D8V]N=&5X=$-A;&QB86-K(&-A;&QB86-K('5S
M960@9F]R(&-O;G1E>'0@9V5N97)A=&EO;BP-"B`@("`@*B`@("`@("`@("`@
M("`@("`@9&5F875L=',@=&\@>T!L:6YK(&=E=$9I;&5,:6YE*"E]#0H@("`@
M("H@0'!A<F%M(&)O;VQE86X@("1T:')O=U!%05)?17)R;W(-"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`@)'-T86-K0VQA<W,@8VQA<W,@=&\@:6YS=&%N=&EA
M=&4-"B`@("`@*B!`<W1A=&EC#0H@("`@("H@0')E='5R;B!014%27T5R<F]R
M4W1A8VL-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1P86-K
M86=E+"`D;7-G0V%L;&)A8VL@/2!F86QS92P@)&-O;G1E>'1#86QL8F%C:R`]
M(&9A;'-E+`T*("`@("`@("`@("`@("`@("`@("`@("`@("1T:')O=U!%05)?
M17)R;W(@/2!F86QS92P@)'-T86-K0VQA<W,@/2`G4$5!4E]%<G)O<E-T86-K
M)RD-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D1TQ/0D%,4ULG7U!%05)?
M15)23U)35$%#2U]324Y'3$543TXG75LD<&%C:V%G95TI*2![#0H@("`@("`@
M("`@("!R971U<FX@)$=,3T)!3%-;)U]014%27T524D]24U1!0TM?4TE.1TQ%
M5$].)UU;)'!A8VMA9V5=.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A8VQA
M<W-?97AI<W1S*"1S=&%C:T-L87-S*2D@>PT*("`@("`@("`@("`@:68@*&9U
M;F-T:6]N7V5X:7-T<R@G9&5B=6=?8F%C:W1R86-E)RDI('L-"B`@("`@("`@
M("`@("`@("`D=')A8V4@/2!D96)U9U]B86-K=')A8V4H*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(%!%05)?17)R;W)3=&%C:SHZ<W1A=&EC4'5S
M:"@G4$5!4E]%<G)O<E-T86-K)RP@4$5!4E]%4E)/4E-404-+7T524E].3TY#
M3$%34RP-"B`@("`@("`@("`@("`@("`G97AC97!T:6]N)RP@87)R87DH)W-T
M86-K8VQA<W,G(#T^("1S=&%C:T-L87-S*2P-"B`@("`@("`@("`@("`@("`G
M<W1A8VL@8VQA<W,@(B5S=&%C:V-L87-S)2(@:7,@;F]T(&$@=F%L:60@8VQA
M<W,@;F%M92`H<VAO=6QD(&)E(&QI:V4@4$5!4E]%<G)O<E-T86-K*2<L#0H@
M("`@("`@("`@("`@("`@9F%L<V4L("1T<F%C92D[#0H@("`@("`@('T-"B`@
M("`@("`@)$=,3T)!3%-;)U]014%27T524D]24U1!0TM?4TE.1TQ%5$].)UU;
M)'!A8VMA9V5=(#T-"B`@("`@("`@("`@(&YE=R`D<W1A8VM#;&%S<R@D<&%C
M:V%G92P@)&US9T-A;&QB86-K+"`D8V]N=&5X=$-A;&QB86-K+"`D=&AR;W=0
M14%27T5R<F]R*3L-"@T*("`@("`@("!R971U<FX@)$=,3T)!3%-;)U]014%2
M7T524D]24U1!0TM?4TE.1TQ%5$].)UU;)'!A8VMA9V5=.PT*("`@('T-"@T*
M("`@("\J*@T*("`@("`J($EN=&5R;F%L(&5R<F]R(&AA;F1L97(@9F]R(%!%
M05)?17)R;W)3=&%C:R!C;&%S<PT*("`@("`J(`T*("`@("`J($1I97,@:68@
M=&AE(&5R<F]R(&ES(&%N(&5X8V5P=&EO;B`H86YD('=O=6QD(&AA=F4@9&EE
M9"!A;GEW87DI#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@7VAA;F1L945R<F]R*"1E<G(I#0H@("`@>PT*("`@("`@
M("!I9B`H)&5R<ELG;&5V96PG72`]/2`G97AC97!T:6]N)RD@>PT*("`@("`@
M("`@("`@)&UE<W-A9V4@/2`D97)R6R=M97-S86=E)UT[#0H@("`@("`@("`@
M("!I9B`H:7-S970H)%]315)615);)U)%455%4U1?55)))UTI*2![#0H@("`@
M("`@("`@("`@("`@96-H;R`G/&)R("\^)SL-"B`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@96-H;R`B7&XB.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@=F%R7V1U;7`H)&5R<ELG8V]N=&5X="==*3L-"B`@
M("`@("`@("`@(&1I92@D;65S<V%G92D[#0H@("`@("`@('T-"B`@("!]#0H@
M("`@#0H@("`@+RHJ#0H@("`@("H@4V5T('5P(&$@4$5!4CHZ3&]G(&]B:F5C
M="!F;W(@86QL(&5R<F]R('-T86-K<R!T:&%T(&1O;B=T(&AA=F4@;VYE#0H@
M("`@("H@0'!A<F%M($QO9R`D;&]G(`T*("`@("`J($!S=&%T:6,-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!S971$969A=6QT3&]G9V5R*"8D;&]G*0T*("`@
M('L-"B`@("`@("`@:68@*&ES7V]B:F5C="@D;&]G*2`F)B!M971H;V1?97AI
M<W1S*"1L;V<L("=L;V<G*2`I('L-"B`@("`@("`@("`@("1'3$]"04Q36R=?
M4$5!4E]%4E)/4E-404-+7T1%1D%53%1?3$]'1T52)UT@/2`F)&QO9SL-"B`@
M("`@("`@?2!E;'-E:68@*&ES7V-A;&QA8FQE*"1L;V<I*2![#0H@("`@("`@
M("`@("`D1TQ/0D%,4ULG7U!%05)?15)23U)35$%#2U]$149!54Q47TQ/1T=%
M4B==(#T@)B1L;V<[#0H)?0T*("`@('T-"B`@("`-"B`@("`O*BH-"B`@("`@
M*B!3970@=7`@82!014%2.CI,;V<@;V)J96-T(&9O<B!T:&ES(&5R<F]R('-T
M86-K#0H@("`@("H@0'!A<F%M($QO9R`D;&]G(`T*("`@("`J+PT*("`@(&9U
M;F-T:6]N('-E=$QO9V=E<B@F)&QO9RD-"B`@("![#0H@("`@("`@(&EF("AI
M<U]O8FIE8W0H)&QO9RD@)B8@;65T:&]D7V5X:7-T<R@D;&]G+"`G;&]G)RD@
M*2![#0H@("`@("`@("`@("`D=&AI<RT^7VQO9V=E<B`]("8D;&]G.PT*("`@
M("`@("!](&5L<V5I9B`H:7-?8V%L;&%B;&4H)&QO9RDI('L-"B`@("`@("`@
M("`@("1T:&ES+3Y?;&]G9V5R(#T@)B1L;V<[#0H@("`@("`@('T-"B`@("!]
M#0H@("`@#0H@("`@+RHJ#0H@("`@("H@4V5T(&%N(&5R<F]R(&-O9&4@/3X@
M97)R;W(@;65S<V%G92!M87!P:6YG(&-A;&QB86-K#0H@("`@("H@#0H@("`@
M("H@5&AI<R!M971H;V0@<V5T<R!T:&4@8V%L;&)A8VL@=&AA="!C86X@8F4@
M=7-E9"!T;R!G96YE<F%T92!E<G)O<@T*("`@("`J(&UE<W-A9V5S(&9O<B!A
M;GD@:6YS=&%N8V4-"B`@("`@*B!`<&%R86T@87)R87E\<W1R:6YG($-A;&QB
M86-K(&9U;F-T:6]N+VUE=&AO9`T*("`@("`J+PT*("`@(&9U;F-T:6]N('-E
M=$UE<W-A9V5#86QL8F%C:R@D;7-G0V%L;&)A8VLI#0H@("`@>PT*("`@("`@
M("!I9B`H(21M<V=#86QL8F%C:RD@>PT*("`@("`@("`@("`@)'1H:7,M/E]M
M<V=#86QL8F%C:R`](&%R<F%Y*"8D=&AI<RP@)V=E=$5R<F]R365S<V%G92<I
M.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@:68@*&ES7V-A;&QA
M8FQE*"1M<V=#86QL8F%C:RDI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^
M7VUS9T-A;&QB86-K(#T@)&US9T-A;&QB86-K.PT*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@?0T*("`@(`T*("`@("\J*@T*("`@("`J($=E="!A
M;B!E<G)O<B!C;V1E(#T^(&5R<F]R(&UE<W-A9V4@;6%P<&EN9R!C86QL8F%C
M:PT*("`@("`J(`T*("`@("`J(%1H:7,@;65T:&]D(')E='5R;G,@=&AE(&-U
M<G)E;G0@8V%L;&)A8VL@=&AA="!C86X@8F4@=7-E9"!T;R!G96YE<F%T92!E
M<G)O<@T*("`@("`J(&UE<W-A9V5S#0H@("`@("H@0')E='5R;B!A<G)A>7QS
M=')I;F=\9F%L<V4@0V%L;&)A8VL@9G5N8W1I;VXO;65T:&]D(&]R(&9A;'-E
M(&EF(&YO;F4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971-97-S86=E0V%L
M;&)A8VLH*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;7-G0V%L
M;&)A8VL[#0H@("`@?0T*("`@(`T*("`@("\J*@T*("`@("`J(%-E=',@82!D
M969A=6QT(&-A;&QB86-K('1O(&)E('5S960@8GD@86QL(&5R<F]R('-T86-K
M<PT*("`@("`J(`T*("`@("`J(%1H:7,@;65T:&]D('-E=',@=&AE(&-A;&QB
M86-K('1H870@8V%N(&)E('5S960@=&\@9V5N97)A=&4@97)R;W(-"B`@("`@
M*B!M97-S86=E<R!F;W(@82!S:6YG;&5T;VX-"B`@("`@*B!`<&%R86T@87)R
M87E\<W1R:6YG($-A;&QB86-K(&9U;F-T:6]N+VUE=&AO9`T*("`@("`J($!P
M87)A;2!S=')I;F<@4&%C:V%G92!N86UE+"!O<B!F86QS92!F;W(@86QL('!A
M8VMA9V5S#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T:6]N
M('-E=$1E9F%U;'1#86QL8F%C:R@D8V%L;&)A8VL@/2!F86QS92P@)'!A8VMA
M9V4@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@A:7-?8V%L;&%B;&4H
M)&-A;&QB86-K*2D@>PT*("`@("`@("`@("`@)&-A;&QB86-K(#T@9F%L<V4[
M#0H@("`@("`@('T-"B`@("`@("`@)'!A8VMA9V4@/2`D<&%C:V%G92`_("1P
M86-K86=E(#H@)RHG.PT*("`@("`@("`D1TQ/0D%,4ULG7U!%05)?15)23U)3
M5$%#2U]$149!54Q47T-!3$Q"04-+)UU;)'!A8VMA9V5=(#T@)&-A;&QB86-K
M.PT*("`@('T-"B`@("`-"B`@("`O*BH-"B`@("`@*B!3970@82!C86QL8F%C
M:R!T:&%T(&=E;F5R871E<R!C;VYT97AT(&EN9F]R;6%T:6]N("AL;V-A=&EO
M;B!O9B!E<G)O<BD@9F]R(&%N(&5R<F]R('-T86-K#0H@("`@("H@#0H@("`@
M("H@5&AI<R!M971H;V0@<V5T<R!T:&4@8V%L;&)A8VL@=&AA="!C86X@8F4@
M=7-E9"!T;R!G96YE<F%T92!C;VYT97AT#0H@("`@("H@:6YF;W)M871I;VX@
M9F]R(&%N(&5R<F]R+B`@4&%S<VEN9R!I;B!.54Q,('=I;&P@9&ES86)L92!C
M;VYT97AT(&=E;F5R871I;VX-"B`@("`@*B!A;F0@<F5M;W9E('1H92!E>'!E
M;G-I=F4@8V%L;"!T;R!D96)U9U]B86-K=')A8V4H*0T*("`@("`J($!P87)A
M;2!A<G)A>7QS=')I;F=\;G5L;"!#86QL8F%C:R!F=6YC=&EO;B]M971H;V0-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S971#;VYT97AT0V%L;&)A8VLH)&-O
M;G1E>'1#86QL8F%C:RD-"B`@("![#0H@("`@("`@(&EF("@D8V]N=&5X=$-A
M;&QB86-K(#T]/2!N=6QL*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]C;VYT97AT0V%L;&)A8VL@/2!F86QS93L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H(21C;VYT97AT0V%L;&)A8VLI('L-"B`@("`@("`@("`@("1T:&ES
M+3Y?8V]N=&5X=$-A;&QB86-K(#T@87)R87DH)B1T:&ES+"`G9V5T1FEL94QI
M;F4G*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(&EF("AI<U]C
M86QL86)L92@D8V]N=&5X=$-A;&QB86-K*2D@>PT*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?8V]N=&5X=$-A;&QB86-K(#T@)&-O;G1E>'1#86QL8F%C:SL-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@('T-"B`@("`-"B`@("`O
M*BH-"B`@("`@*B!3970@86X@97)R;W(@0V%L;&)A8VL-"B`@("`@*B!)9B!S
M970@=&\@82!V86QI9"!C86QL8F%C:RP@=&AI<R!W:6QL(&)E(&-A;&QE9"!E
M=F5R>2!T:6UE(&%N(&5R<F]R#0H@("`@("H@:7,@<'5S:&5D(&]N=&\@=&AE
M('-T86-K+B`@5&AE(')E='5R;B!V86QU92!W:6QL(&)E('5S960@=&\@9&5T
M97)M:6YE#0H@("`@("H@=VAE=&AE<B!T;R!A;&QO=R!A;B!E<G)O<B!T;R!B
M92!P=7-H960@;W(@;&]G9V5D+@T*("`@("`J(`T*("`@("`J(%1H92!R971U
M<FX@=F%L=64@;75S="!B92!O;F4@;V8@=&AE($524D]24U1!0TM?*B!C;VYS
M=&%N=',N#0H@("`@("H@#0H@("`@("H@5&AI<R!F=6YC=&EO;F%L:71Y(&-A
M;B!B92!U<V5D('1O(&5M=6QA=&4@4$5!4B=S('!U<VA%<G)O<DAA;F1L:6YG
M+"!A;F0-"B`@("`@*B!T:&4@4$5!4E]%4E)/4E]#04Q,0D%#2R!M;V1E+"!W
M:71H;W5T(&%F9F5C=&EN9R!T:&4@:6YT96=R:71Y(&]F#0H@("`@("H@=&AE
M(&5R<F]R('-T86-K(&]R(&QO9V=I;F<-"B`@("`@*B!`<V5E(%!%05)?15)2
M3U)35$%#2U]055-(04Y$3$]'+"!014%27T524D]24U1!0TM?4%532"P@4$5!
M4E]%4E)/4E-404-+7TQ/1PT*("`@("`J($!S964@<&]P0V%L;&)A8VLH*0T*
M("`@("`J($!P87)A;2!S=')I;F=\87)R87D@)&-B#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@<'5S:$-A;&QB86-K*"1C8BD-"B`@("![#0H@("`@("`@(&%R
M<F%Y7W!U<V@H)'1H:7,M/E]E<G)O<D-A;&QB86-K+"`D8V(I.PT*("`@('T-
M"B`@("`-"B`@("`O*BH-"B`@("`@*B!296UO=F4@82!C86QL8F%C:R!F<F]M
M('1H92!E<G)O<B!C86QL8F%C:R!S=&%C:PT*("`@("`J($!S964@<'5S:$-A
M;&QB86-K*"D-"B`@("`@*B!`<F5T=7)N(&%R<F%Y?'-T<FEN9WQF86QS90T*
M("`@("`J+PT*("`@(&9U;F-T:6]N('!O<$-A;&QB86-K*"D-"B`@("![#0H@
M("`@("`@(&EF("@A8V]U;G0H)'1H:7,M/E]E<G)O<D-A;&QB86-K*2D@>PT*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B!A<G)A>5]P;W`H)'1H:7,M/E]E<G)O<D-A;&QB86-K*3L-"B`@
M("!]#0H@("`@#0H@("`@+RHJ#0H@("`@("H@4V5T(&$@=&5M<&]R87)Y(&]V
M97)R:61I;F<@97)R;W(@8V%L;&)A8VL@9F]R(&5V97)Y('!A8VMA9V4@97)R
M;W(@<W1A8VL-"B`@("`@*@T*("`@("`J(%5S92!T:&ES('1O('1E;7!O<F%R
M:6QY(&1I<V%B;&4@86QL(&5X:7-T:6YG(&-A;&QB86-K<R`H8V%N(&)E('5S
M960-"B`@("`@*B!T;R!E;75L871E('1H92!`(&]P97)A=&]R+"!F;W(@:6YS
M=&%N8V4I#0H@("`@("H@0'-E92!014%27T524D]24U1!0TM?4%532$%.1$Q/
M1RP@4$5!4E]%4E)/4E-404-+7U!54T@L(%!%05)?15)23U)35$%#2U],3T<-
M"B`@("`@*B!`<V5E('-T871I8U!O<$-A;&QB86-K*"DL('!U<VA#86QL8F%C
M:R@I#0H@("`@("H@0'!A<F%M('-T<FEN9WQA<G)A>2`D8V(-"B`@("`@*B!`
M<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<W1A=&EC4'5S:$-A;&QB
M86-K*"1C8BD-"B`@("![#0H@("`@("`@(&%R<F%Y7W!U<V@H)$=,3T)!3%-;
M)U]014%27T524D]24U1!0TM?3U9%4E))1$5?0T%,3$)!0TLG72P@)&-B*3L-
M"B`@("!]#0H@("`@#0H@("`@+RHJ#0H@("`@("H@4F5M;W9E(&$@=&5M<&]R
M87)Y(&]V97)R:61I;F<@97)R;W(@8V%L;&)A8VL-"B`@("`@*B!`<V5E('-T
M871I8U!U<VA#86QL8F%C:R@I#0H@("`@("H@0')E='5R;B!A<G)A>7QS=')I
M;F=\9F%L<V4-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@<W1A=&EC4&]P0V%L;&)A8VLH*0T*("`@('L-"B`@("`@("`@)')E="`]
M(&%R<F%Y7W!O<"@D1TQ/0D%,4ULG7U!%05)?15)23U)35$%#2U]/5D524DE$
M15]#04Q,0D%#2R==*3L-"B`@("`@("`@:68@*"%I<U]A<G)A>2@D1TQ/0D%,
M4ULG7U!%05)?15)23U)35$%#2U]/5D524DE$15]#04Q,0D%#2R==*2D@>PT*
M("`@("`@("`@("`@)$=,3T)!3%-;)U]014%27T524D]24U1!0TM?3U9%4E))
M1$5?0T%,3$)!0TLG72`](&%R<F%Y*"D[#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N("1R970[#0H@("`@?0T*("`@(`T*("`@("\J*@T*("`@("`J($%D
M9"!A;B!E<G)O<B!T;R!T:&4@<W1A8VL-"B`@("`@*B`-"B`@("`@*B!)9B!T
M:&4@;65S<V%G92!G96YE<F%T;W(@97AI<W1S+"!I="!I<R!C86QL960@=VET
M:"`R('!A<F%M971E<G,N#0H@("`@("H@("T@=&AE(&-U<G)E;G0@17)R;W(@
M4W1A8VL@;V)J96-T#0H@("`@("H@("T@86X@87)R87D@=&AA="!I<R!I;B!T
M:&4@<V%M92!F;W)M870@87,@86X@97)R;W(N("!!=F%I;&%B;&4@:6YD:6-E
M<PT*("`@("`J("`@(&%R92`G8V]D92<L("=P86-K86=E)RP@)W1I;64G+"`G
M<&%R86US)RP@)VQE=F5L)RP@86YD("=C;VYT97AT)PT*("`@("`J(`T*("`@
M("`J($YE>'0L(&EF('1H92!E<G)O<B!S:&]U;&0@8V]N=&%I;B!C;VYT97AT
M(&EN9F]R;6%T:6]N+"!T:&ES(&ES#0H@("`@("H@:&%N9&QE9"!B>2!T:&4@
M8V]N=&5X="!G<F%B8FEN9R!M971H;V0N#0H@("`@("H@1FEN86QL>2P@=&AE
M(&5R<F]R(&ES('!U<VAE9"!O;G1O('1H92!P<F]P97(@97)R;W(@<W1A8VL-
M"B`@("`@*B!`<&%R86T@:6YT("`@("1C;V1E("`@("`@4&%C:V%G92US<&5C
M:69I8R!E<G)O<B!C;V1E#0H@("`@("H@0'!A<F%M('-T<FEN9R`D;&5V96P@
M("`@($5R<F]R(&QE=F5L+B`@5&AI<R!I<R!.3U0@<W!E;&PM8VAE8VME9`T*
M("`@("`J($!P87)A;2!A<G)A>2`@)'!A<F%M<R`@("!A<W-O8VEA=&EV92!A
M<G)A>2!O9B!E<G)O<B!P87)A;65T97)S#0H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;7-G("`@("`@($5R<F]R(&UE<W-A9V4L(&]R(&$@<&]R=&EO;B!O9B!I
M="!I9B!T:&4@;65S<V%G90T*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("!I<R!T;R!B92!G96YE<F%T960-"B`@("`@*B!`<&%R86T@87)R87D@
M("1R97!A8VMA9V4@268@=&AI<R!E<G)O<B!R92UP86-K86=E<R!A;B!E<G)O
M<B!P=7-H960@8GD-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M86YO=&AE<B!P86-K86=E+"!P;&%C92!T:&4@87)R87D@<F5T=7)N960@9G)O
M;0T*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("![0&QI;FL@<&]P
M*"E](&EN('1H:7,@<&%R86UE=&5R#0H@("`@("H@0'!A<F%M(&%R<F%Y("`D
M8F%C:W1R86-E(%!R;W1E8W1E9"!P87)A;65T97(Z('5S92!T:&ES('1O('!A
M<W,@:6X@=&AE#0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('M`
M;&EN:R!D96)U9U]B86-K=')A8V4H*7T@=&AA="!S:&]U;&0@8F4@=7-E9`T*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!T;R!F:6YD(&5R<F]R
M(&-O;G1E>'0-"B`@("`@*B!`<F5T=7)N(%!%05)?17)R;W)\87)R87E\17AC
M97!T:6]N#0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&EF(&-O
M;7!A=&EB:6QI='D@;6]D92!I<R!O;BP@82!014%27T5R<F]R(&ES(&%L<V\-
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@=&AR;W=N+B`@268@
M=&AE(&-L87-S($5X8V5P=&EO;B!E>&ES=',L('1H96X@;VYE#0H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@(&ES(')E='5R;F5D('1O(&%L;&]W
M(&-O9&4@;&EK93H-"B`@("`@*B`\8V]D93X-"B`@("`@*B!T:')O=R`H)'-T
M86-K+3YP=7-H*$U97T524D]27T-/1$4L("=E<G)O<B<L(&%R<F%Y*"=U<V5R
M;F%M92<@/3X@)V=R;V(G*2DI.PT*("`@("`J(#PO8V]D93X-"B`@("`@*B`-
M"B`@("`@*B!4:&4@97)R;W)$871A('!R;W!E<G1Y(&]F('1H92!E>&-E<'1I
M;VX@8VQA<W,@=VEL;"!B92!S970@=&\@=&AE(&%R<F%Y#0H@("`@("H@=&AA
M="!W;W5L9"!N;W)M86QL>2!B92!R971U<FYE9"X@($EF(&$@4$5!4E]%<G)O
M<B!I<R!R971U<FYE9"P@=&AE('5S97)I;F9O#0H@("`@("H@<')O<&5R='D@
M:7,@<V5T('1O('1H92!A<G)A>0T*("`@("`J(`T*("`@("`J($]T:&5R=VES
M92P@86X@87)R87D@:7,@<F5T=7)N960@:6X@=&AI<R!F;W)M870Z#0H@("`@
M("H@/&-O9&4^#0H@("`@("H@87)R87DH#0H@("`@("H@("`@)V-O9&4G(#T^
M("1C;V1E+`T*("`@("`J("`@("=P87)A;7,G(#T^("1P87)A;7,L#0H@("`@
M("H@("`@)W!A8VMA9V4G(#T^("1T:&ES+3Y?<&%C:V%G92P-"B`@("`@*B`@
M("`G;&5V96PG(#T^("1L979E;"P-"B`@("`@*B`@("`G=&EM92<@/3X@=&EM
M92@I+`T*("`@("`J("`@("=C;VYT97AT)R`]/B`D8V]N=&5X="P-"B`@("`@
M*B`@("`G;65S<V%G92<@/3X@)&US9RP-"B`@("`@*B`O+ULG<F5P86-K86=E
M)R`]/B`D97)R72!R97!A8VMA9V5D(&5R<F]R(&%R<F%Y+T5X8V5P=&EO;B!C
M;&%S<PT*("`@("`J("D[#0H@("`@("H@/"]C;V1E/@T*("`@("`J+PT*("`@
M(&9U;F-T:6]N('!U<V@H)&-O9&4L("1L979E;"`]("=E<G)O<B<L("1P87)A
M;7,@/2!A<G)A>2@I+"`D;7-G(#T@9F%L<V4L#0H@("`@("`@("`@("`@("`@
M("`D<F5P86-K86=E(#T@9F%L<V4L("1B86-K=')A8V4@/2!F86QS92D-"B`@
M("![#0H@("`@("`@("1C;VYT97AT(#T@9F%L<V4[#0H@("`@("`@("\O(&=R
M86(@97)R;W(@8V]N=&5X=`T*("`@("`@("!I9B`H)'1H:7,M/E]C;VYT97AT
M0V%L;&)A8VLI('L-"B`@("`@("`@("`@(&EF("@A)&)A8VMT<F%C92D@>PT*
M("`@("`@("`@("`@("`@("1B86-K=')A8V4@/2!D96)U9U]B86-K=')A8V4H
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1C;VYT97AT(#T@8V%L
M;%]U<V5R7V9U;F,H)'1H:7,M/E]C;VYT97AT0V%L;&)A8VLL("1C;V1E+"`D
M<&%R86US+"`D8F%C:W1R86-E*3L-"B`@("`@("`@?0T*("`@("`@("`-"B`@
M("`@("`@+R\@<V%V92!E<G)O<@T*("`@("`@("`D=&EM92`](&5X<&QO9&4H
M)R`G+"!M:6-R;W1I;64H*2D[#0H@("`@("`@("1T:6UE(#T@)'1I;65;,5T@
M*R`D=&EM95LP73L-"B`@("`@("`@)&5R<B`](&%R<F%Y*`T*("`@("`@("`@
M("`@("`@("=C;V1E)R`]/B`D8V]D92P-"B`@("`@("`@("`@("`@("`G<&%R
M86US)R`]/B`D<&%R86US+`T*("`@("`@("`@("`@("`@("=P86-K86=E)R`]
M/B`D=&AI<RT^7W!A8VMA9V4L#0H@("`@("`@("`@("`@("`@)VQE=F5L)R`]
M/B`D;&5V96PL#0H@("`@("`@("`@("`@("`@)W1I;64G(#T^("1T:6UE+`T*
M("`@("`@("`@("`@("`@("=C;VYT97AT)R`]/B`D8V]N=&5X="P-"B`@("`@
M("`@("`@("`@("`G;65S<V%G92<@/3X@)&US9RP-"B`@("`@("`@("`@("`@
M("D[#0H-"B`@("`@("`@:68@*"1R97!A8VMA9V4I('L-"B`@("`@("`@("`@
M("1E<G);)W)E<&%C:V%G92==(#T@)')E<&%C:V%G93L-"B`@("`@("`@?0T*
M#0H@("`@("`@("\O('-E="!U<"!T:&4@97)R;W(@;65S<V%G92P@:68@;F5C
M97-S87)Y#0H@("`@("`@(&EF("@D=&AI<RT^7VUS9T-A;&QB86-K*2![#0H@
M("`@("`@("`@("`D;7-G(#T@8V%L;%]U<V5R7V9U;F-?87)R87DH)'1H:7,M
M/E]M<V=#86QL8F%C:RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@F)'1H:7,L("1E<G(I*3L-"B`@("`@("`@("`@
M("1E<G);)VUE<W-A9V4G72`]("1M<V<[#0H@("`@("`@('T@("`@("`@(`T*
M("`@("`@("`D<'5S:"`]("1L;V<@/2!T<G5E.PT*("`@("`@("`D9&EE(#T@
M9F%L<V4[#0H@("`@("`@("\O('1R>2!T:&4@;W9E<G)I9&EN9R!C86QL8F%C
M:R!F:7)S=`T*("`@("`@("`D8V%L;&)A8VL@/2`D=&AI<RT^<W1A=&EC4&]P
M0V%L;&)A8VLH*3L-"B`@("`@("`@:68@*"1C86QL8F%C:RD@>PT*("`@("`@
M("`@("`@)'1H:7,M/G-T871I8U!U<VA#86QL8F%C:R@D8V%L;&)A8VLI.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("@A:7-?8V%L;&%B;&4H)&-A;&QB86-K
M*2D@>PT*("`@("`@("`@("`@+R\@=')Y('1H92!L;V-A;"!C86QL8F%C:R!N
M97AT#0H@("`@("`@("`@("`D8V%L;&)A8VL@/2`D=&AI<RT^<&]P0V%L;&)A
M8VLH*3L-"B`@("`@("`@("`@(&EF("AI<U]C86QL86)L92@D8V%L;&)A8VLI
M*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/G!U<VA#86QL8F%C:R@D8V%L
M;&)A8VLI.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`O+R!T<GD@=&AE(&1E9F%U;'0@8V%L;&)A8VL-"B`@("`@("`@("`@("`@
M("`D8V%L;&)A8VL@/2!I<W-E="@D1TQ/0D%,4ULG7U!%05)?15)23U)35$%#
M2U]$149!54Q47T-!3$Q"04-+)UU;)'1H:7,M/E]P86-K86=E72D@/PT*("`@
M("`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG7U!%05)?15)23U)35$%#2U]$
M149!54Q47T-!3$Q"04-+)UU;)'1H:7,M/E]P86-K86=E72`Z#0H@("`@("`@
M("`@("`@("`@("`@("1'3$]"04Q36R=?4$5!4E]%4E)/4E-404-+7T1%1D%5
M3%1?0T%,3$)!0TLG75LG*B==.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(&EF("AI<U]C86QL86)L92@D8V%L;&)A8VLI*2![#0H@("`@
M("`@("`@("!S=VET8V@H8V%L;%]U<V5R7V9U;F,H)&-A;&QB86-K+"`D97)R
M*2E[#0H@("`@("`@("`@("`)8V%S92!014%27T524D]24U1!0TM?24=.3U)%
M.B`-"B`@("`@("`@("`@(`D)<F5T=7)N("1E<G([#0H@("`@("`@(`D)8G)E
M86L[#0H@("`@("`@("`@("`)8V%S92!014%27T524D]24U1!0TM?4%532#H@
M#0H@("`@("`@("`@("`)"21L;V<@/2!F86QS93L-"B`@("`@("`@"0EB<F5A
M:SL-"B`@("`@("`@("`@(`EC87-E(%!%05)?15)23U)35$%#2U],3T<Z(`T*
M("`@("`@("`@("`@"0DD<'5S:"`](&9A;'-E.PT*("`@("`@("`)"6)R96%K
M.PT*("`@("`@("`@("`@"6-A<V4@4$5!4E]%4E)/4E-404-+7T1)13H@#0H@
M("`@("`@("`@("`)"21D:64@/2!T<G5E.PT*("`@("`@("`)"6)R96%K.PT*
M("`@("`@("`@("`@("`@("\O(&%N>71H:6YG(&5L<V4@<F5T=7)N960@:&%S
M('1H92!S86UE(&5F9F5C="!A<R!P=7-H86YD;&]G#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"1P=7-H*2![#0H@("`@("`@("`@
M("!A<G)A>5]U;G-H:69T*"1T:&ES+3Y?97)R;W)S+"`D97)R*3L-"B`@("`@
M("`@("`@("1T:&ES+3Y?97)R;W)S0GE,979E;%LD97)R6R=L979E;"==75M=
M(#T@)B1T:&ES+3Y?97)R;W)S6S!=.PT*("`@("`@("!]#0H@("`@("`@(&EF
M("@D;&]G*2![#0H@("`@("`@("`@("!I9B`H)'1H:7,M/E]L;V=G97(@?'P@
M)$=,3T)!3%-;)U]014%27T524D]24U1!0TM?1$5&055,5%],3T='15(G72D@
M>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?;&]G*"1E<G(I.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@D9&EE*2![#0H@("`@
M("`@("`@("!D:64H*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'1H:7,M
M/E]C;VUP870@)B8@)'!U<V@I('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@D;7-G+"`D8V]D92P@;G5L;"P@;G5L;"P@)&5R<BD[
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1E<G([#0H@("`@?0T*("`@
M(`T*("`@("\J*@T*("`@("`J(%-T871I8R!V97)S:6]N(&]F('M`;&EN:R!P
M=7-H*"E]#0H@("`@("H@#0H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%C:V%G
M92`@(%!A8VMA9V4@;F%M92!T:&ES(&5R<F]R(&)E;&]N9W,@=&\-"B`@("`@
M*B!`<&%R86T@:6YT("`@("1C;V1E("`@("`@4&%C:V%G92US<&5C:69I8R!E
M<G)O<B!C;V1E#0H@("`@("H@0'!A<F%M('-T<FEN9R`D;&5V96P@("`@($5R
M<F]R(&QE=F5L+B`@5&AI<R!I<R!.3U0@<W!E;&PM8VAE8VME9`T*("`@("`J
M($!P87)A;2!A<G)A>2`@)'!A<F%M<R`@("!A<W-O8VEA=&EV92!A<G)A>2!O
M9B!E<G)O<B!P87)A;65T97)S#0H@("`@("H@0'!A<F%M('-T<FEN9R`D;7-G
M("`@("`@($5R<F]R(&UE<W-A9V4L(&]R(&$@<&]R=&EO;B!O9B!I="!I9B!T
M:&4@;65S<V%G90T*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!I
M<R!T;R!B92!G96YE<F%T960-"B`@("`@*B!`<&%R86T@87)R87D@("1R97!A
M8VMA9V4@268@=&AI<R!E<G)O<B!R92UP86-K86=E<R!A;B!E<G)O<B!P=7-H
M960@8GD-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@86YO=&AE
M<B!P86-K86=E+"!P;&%C92!T:&4@87)R87D@<F5T=7)N960@9G)O;0T*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("![0&QI;FL@<&]P*"E](&EN
M('1H:7,@<&%R86UE=&5R#0H@("`@("H@0'!A<F%M(&%R<F%Y("`D8F%C:W1R
M86-E(%!R;W1E8W1E9"!P87)A;65T97(Z('5S92!T:&ES('1O('!A<W,@:6X@
M=&AE#0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('M`;&EN:R!D
M96)U9U]B86-K=')A8V4H*7T@=&AA="!S:&]U;&0@8F4@=7-E9`T*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("!T;R!F:6YD(&5R<F]R(&-O;G1E
M>'0-"B`@("`@*B!`<F5T=7)N(%!%05)?17)R;W)\;G5L;'Q%>&-E<'1I;VX-
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@:68@8V]M<&%T:6)I
M;&ET>2!M;V1E(&ES(&]N+"!A(%!%05)?17)R;W(@:7,@86QS;PT*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("!T:')O=VXN("!)9B!T:&4@8VQA
M<W,@17AC97!T:6]N(&5X:7-T<RP@=&AE;B!O;F4-"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@:7,@<F5T=7)N960@=&\@86QL;W<@8V]D92!L
M:6ME.@T*("`@("`J(#QC;V1E/@T*("`@("`J('1H<F]W("@D<W1A8VLM/G!U
M<V@H35E?15)23U)?0T]$12P@)V5R<F]R)RP@87)R87DH)W5S97)N86UE)R`]
M/B`G9W)O8B<I*2D[#0H@("`@("H@/"]C;V1E/@T*("`@("`J($!S=&%T:6,-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S=&%T:6-0=7-H*"1P86-K86=E+"`D
M8V]D92P@)&QE=F5L(#T@)V5R<F]R)RP@)'!A<F%M<R`](&%R<F%Y*"DL#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D;7-G(#T@9F%L<V4L("1R97!A8VMA
M9V4@/2!F86QS92P@)&)A8VMT<F%C92`](&9A;'-E*0T*("`@('L-"B`@("`@
M("`@)',@/2`F4$5!4E]%<G)O<E-T86-K.CIS:6YG;&5T;VXH)'!A8VMA9V4I
M.PT*("`@("`@("!I9B`H)',M/E]C;VYT97AT0V%L;&)A8VLI('L-"B`@("`@
M("`@("`@(&EF("@A)&)A8VMT<F%C92D@>PT*("`@("`@("`@("`@("`@(&EF
M("AF=6YC=&EO;E]E>&ES=',H)V1E8G5G7V)A8VMT<F%C92<I*2![#0H@("`@
M("`@("`@("`@("`@("`@("1B86-K=')A8V4@/2!D96)U9U]B86-K=')A8V4H
M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N("1S+3YP=7-H*"1C;V1E+"`D;&5V96PL("1P
M87)A;7,L("1M<V<L("1R97!A8VMA9V4L("1B86-K=')A8V4I.PT*("`@('T-
M"B`@("`-"B`@("`O*BH-"B`@("`@*B!,;V<@86X@97)R;W(@=7-I;F<@4$5!
M4CHZ3&]G#0H@("`@("H@0'!A<F%M(&%R<F%Y("1E<G(@17)R;W(@87)R87D-
M"B`@("`@*B!`<&%R86T@87)R87D@)&QE=F5L<R!%<G)O<B!L979E;"`]/B!,
M;V<@8V]N<W1A;G0@;6%P#0H@("`@("H@0&%C8V5S<R!P<F]T96-T960-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!?;&]G*"1E<G(I#0H@("`@>PT*("`@("`@
M("!I9B`H)'1H:7,M/E]L;V=G97(I('L-"B`@("`@("`@("`@("1L;V=G97(@
M/2`F)'1H:7,M/E]L;V=G97([#0H@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`D;&]G9V5R(#T@)B1'3$]"04Q36R=?4$5!4E]%4E)/4E-404-+7T1%
M1D%53%1?3$]'1T52)UT[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES7V$H
M)&QO9V=E<BP@)TQO9R<I*2![#0H@("`@("`@("`@("`D;&5V96QS(#T@87)R
M87DH#0H@("`@("`@("`@("`@("`@)V5X8V5P=&EO;B<@/3X@4$5!4E],3T=?
M0U))5"P-"B`@("`@("`@("`@("`@("`G86QE<G0G(#T^(%!%05)?3$]'7T%,
M15)4+`T*("`@("`@("`@("`@("`@("=C<FET:6-A;"<@/3X@4$5!4E],3T=?
M0U))5"P-"B`@("`@("`@("`@("`@("`G97)R;W(G(#T^(%!%05)?3$]'7T52
M4BP-"B`@("`@("`@("`@("`@("`G=V%R;FEN9R<@/3X@4$5!4E],3T=?5T%2
M3DE.1RP-"B`@("`@("`@("`@("`@("`G;F]T:6-E)R`]/B!014%27TQ/1U].
M3U1)0T4L#0H@("`@("`@("`@("`@("`@)VEN9F\G(#T^(%!%05)?3$]'7TE.
M1D\L#0H@("`@("`@("`@("`@("`@)V1E8G5G)R`]/B!014%27TQ/1U]$14)5
M1RD[#0H@("`@("`@("`@("!I9B`H:7-S970H)&QE=F5L<ULD97)R6R=L979E
M;"==72DI('L-"B`@("`@("`@("`@("`@("`D;&5V96P@/2`D;&5V96QS6R1E
M<G);)VQE=F5L)UU=.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`D;&5V96P@/2!014%27TQ/1U])3D9/.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@)&QO9V=E<BT^;&]G*"1E<G);)VUE<W-A9V4G72P@
M)&QE=F5L+"`D97)R*3L-"B`@("`@("`@?2!E;'-E('L@+R\@<W5P<&]R="!N
M;VXM<W1A;F1A<F0@;&]G<PT*("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F,H
M)&QO9V=E<BP@)&5R<BD[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`-"B`@
M("`O*BH-"B`@("`@*B!0;W`@86X@97)R;W(@;V9F(&]F('1H92!E<G)O<B!S
M=&%C:PT*("`@("`J(`T*("`@("`J($!R971U<FX@9F%L<V5\87)R87D-"B`@
M("`@*B!`<VEN8V4@,"XT86QP:&$@:70@:7,@;F\@;&]N9V5R('!O<W-I8FQE
M('1O('-P96-I9GD@82!S<&5C:69I8R!E<G)O<@T*("`@("`J(&QE=F5L('1O
M(')E='5R;B`M('1H92!L87-T(&5R<F]R('!U<VAE9"!W:6QL(&)E(')E='5R
M;F5D+"!I;G-T96%D#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<&]P*"D-"B`@
M("![#0H@("`@("`@(')E='5R;B!`87)R87E?<VAI9G0H)'1H:7,M/E]E<G)O
M<G,I.PT*("`@('T-"B`@("`-"B`@("`O*BH-"B`@("`@*B!$971E<FUI;F4@
M=VAE=&AE<B!T:&5R92!A<F4@86YY(&5R<F]R<R!O;B!T:&4@<W1A8VL-"B`@
M("`@*B!`<&%R86T@<W1R:6YG?&%R<F%Y($QE=F5L(&YA;64N("!5<V4@=&\@
M9&5T97)M:6YE(&EF(&%N>2!E<G)O<G,-"B`@("`@*B!O9B!L979E;"`H<W1R
M:6YG*2P@;W(@;&5V96QS("AA<G)A>2D@:&%V92!B965N('!U<VAE9`T*("`@
M("`J($!R971U<FX@8F]O;&5A;@T*("`@("`J+PT*("`@(&9U;F-T:6]N(&AA
M<T5R<F]R<R@D;&5V96P@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@D
M;&5V96PI('L-"B`@("`@("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^7V5R
M<F]R<T)Y3&5V96Q;)&QE=F5L72D[#0H@("`@("`@('T-"B`@("`@("`@<F5T
M=7)N(&-O=6YT*"1T:&ES+3Y?97)R;W)S*3L-"B`@("!]#0H@("`@#0H@("`@
M+RHJ#0H@("`@("H@4F5T<FEE=F4@86QL(&5R<F]R<R!S:6YC92!L87-T('!U
M<F=E#0H@("`@("H@#0H@("`@("H@0'!A<F%M(&)O;VQE86X@<V5T(&EN(&]R
M9&5R('1O(&5M<'1Y('1H92!E<G)O<B!S=&%C:PT*("`@("`J($!P87)A;2!S
M=')I;F<@;&5V96P@;F%M92P@=&\@<F5T=7)N(&]N;'D@97)R;W)S(&]F(&$@
M<&%R=&EC=6QA<B!S979E<FET>0T*("`@("`J($!R971U<FX@87)R87D-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!G971%<G)O<G,H)'!U<F=E(#T@9F%L<V4L
M("1L979E;"`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*"$D<'5R9V4I
M('L-"B`@("`@("`@("`@(&EF("@D;&5V96PI('L-"B`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1T:&ES+3Y?97)R;W)S0GE,979E;%LD;&5V96Q=*2D@
M>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@87)R87DH*3L-"B`@("`@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]E<G)O<G-">4QE=F5L6R1L979E;%T[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]E<G)O<G,[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"1L979E;"D@>PT*("`@("`@("`@("`@)')E
M="`]("1T:&ES+3Y?97)R;W)S0GE,979E;%LD;&5V96Q=.PT*("`@("`@("`@
M("`@9F]R96%C:"`H)'1H:7,M/E]E<G)O<G-">4QE=F5L6R1L979E;%T@87,@
M)&D@/3X@)'5N=7-E9"D@>PT*("`@("`@("`@("`@("`@("\O(&5N=')I97,@
M87)E(')E9F5R96YC97,@=&\@=&AE("1?97)R;W)S(&%R<F%Y#0H@("`@("`@
M("`@("`@("`@)'1H:7,M/E]E<G)O<G-">4QE=F5L6R1L979E;%U;)&E=(#T@
M9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`O+R!A<G)A>5]F
M:6QT97(@<F5M;W9E<R!A;&P@96YT<FEE<R`]/3T@9F%L<V4-"B`@("`@("`@
M("`@("1T:&ES+3Y?97)R;W)S(#T@87)R87E?9FEL=&5R*"1T:&ES+3Y?97)R
M;W)S*3L-"B`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?97)R;W)S0GE,979E
M;%LD;&5V96Q=*3L-"B`@("`@("`@("`@(')E='5R;B`D<F5T.PT*("`@("`@
M("!]#0H@("`@("`@("1R970@/2`D=&AI<RT^7V5R<F]R<SL-"B`@("`@("`@
M)'1H:7,M/E]E<G)O<G,@/2!A<G)A>2@I.PT*("`@("`@("`D=&AI<RT^7V5R
M<F]R<T)Y3&5V96P@/2!A<G)A>2@I.PT*("`@("`@("!R971U<FX@)')E=#L-
M"B`@("!]#0H@("`@#0H@("`@+RHJ#0H@("`@("H@1&5T97)M:6YE('=H971H
M97(@=&AE<F4@87)E(&%N>2!E<G)O<G,@;VX@82!S:6YG;&4@97)R;W(@<W1A
M8VLL(&]R(&]N(&%N>2!E<G)O<B!S=&%C:PT*("`@("`J#0H@("`@("H@5&AE
M(&]P=&EO;F%L('!A<F%M971E<B!C86X@8F4@=7-E9"!T;R!T97-T('1H92!E
M>&ES=&5N8V4@;V8@86YY(&5R<F]R<R!W:71H;W5T('1H92!N965D(&]F#0H@
M("`@("H@<VEN9VQE=&]N(&EN<W1A;G1I871I;VX-"B`@("`@*B!`<&%R86T@
M<W1R:6YG?&9A;'-E(%!A8VMA9V4@;F%M92!T;R!C:&5C:R!F;W(@97)R;W)S
M#0H@("`@("H@0'!A<F%M('-T<FEN9R!,979E;"!N86UE('1O(&-H96-K(&9O
M<B!A('!A<G1I8W5L87(@<V5V97)I='D-"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<W1A
M=&EC2&%S17)R;W)S*"1P86-K86=E(#T@9F%L<V4L("1L979E;"`](&9A;'-E
M*0T*("`@('L-"B`@("`@("`@:68@*"1P86-K86=E*2![#0H@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1'3$]"04Q36R=?4$5!4E]%4E)/4E-404-+7U-)3D=,
M151/3B==6R1P86-K86=E72DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@)$=,
M3T)!3%-;)U]014%27T524D]24U1!0TM?4TE.1TQ%5$].)UU;)'!A8VMA9V5=
M+3YH87-%<G)O<G,H)&QE=F5L*3L-"B`@("`@("`@?0T*("`@("`@("!F;W)E
M86-H("@D1TQ/0D%,4ULG7U!%05)?15)23U)35$%#2U]324Y'3$543TXG72!A
M<R`D<&%C:V%G92`]/B`D;V)J*2![#0H@("`@("`@("`@("!I9B`H)&]B:BT^
M:&%S17)R;W)S*"1L979E;"DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@
M=')U93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@?0T*("`@(`T*("`@("\J*@T*("`@("`J($=E="!A
M(&QI<W0@;V8@86QL(&5R<F]R<R!S:6YC92!L87-T('!U<F=E+"!O<F=A;FEZ
M960@8GD@<&%C:V%G90T*("`@("`J($!S:6YC92!014%2(#$N-"XP9&5V($)#
M(&)R96%K(2`D;&5V96P@:7,@;F]W(&EN('1H92!P;&%C92`D;65R9V4@=7-E
M9"!T;R!B90T*("`@("`J($!P87)A;2!B;V]L96%N("1P=7)G92!3970@=&\@
M<'5R9V4@=&AE(&5R<F]R('-T86-K(&]F(&5X:7-T:6YG(&5R<F]R<PT*("`@
M("`J($!P87)A;2!S=')I;F<@("1L979E;"!3970@=&\@82!L979E;"!N86UE
M(&EN(&]R9&5R('1O(')E=')I979E(&]N;'D@97)R;W)S(&]F(&$@<&%R=&EC
M=6QA<B!L979E;`T*("`@("`J($!P87)A;2!B;V]L96%N("1M97)G92!3970@
M=&\@<F5T=7)N(&$@9FQA="!A<G)A>2P@;F]T(&]R9V%N:7IE9"!B>2!P86-K
M86=E#0H@("`@("H@0'!A<F%M(&%R<F%Y("`@)'-O<G1F=6YC($9U;F-T:6]N
M('5S960@=&\@<V]R="!A(&UE<F=E9"!A<G)A>2`M(&1E9F%U;'0-"B`@("`@
M*B`@("`@("`@<V]R=',@8GD@=&EM92P@86YD('-H;W5L9"!B92!G;V]D(&9O
M<B!M;W-T(&-A<V5S#0H@("`@("H@0'-T871I8PT*("`@("`J($!R971U<FX@
M87)R87D@#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<W1A=&EC1V5T17)R;W)S
M*"1P=7)G92`](&9A;'-E+"`D;&5V96P@/2!F86QS92P@)&UE<F=E(#T@9F%L
M<V4L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S;W)T9G5N8R`]
M(&%R<F%Y*"=014%27T5R<F]R4W1A8VLG+"`G7W-O<G1%<G)O<G,G*2D-"B`@
M("![#0H@("`@("`@("1R970@/2!A<G)A>2@I.PT*("`@("`@("!I9B`H(6ES
M7V-A;&QA8FQE*"1S;W)T9G5N8RDI('L-"B`@("`@("`@("`@("1S;W)T9G5N
M8R`](&%R<F%Y*"=014%27T5R<F]R4W1A8VLG+"`G7W-O<G1%<G)O<G,G*3L-
M"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D1TQ/0D%,4ULG7U!%05)?
M15)23U)35$%#2U]324Y'3$543TXG72!A<R`D<&%C:V%G92`]/B`D;V)J*2![
M#0H@("`@("`@("`@("`D=&5S="`]("1'3$]"04Q36R=?4$5!4E]%4E)/4E-4
M04-+7U-)3D=,151/3B==6R1P86-K86=E72T^9V5T17)R;W)S*"1P=7)G92P@
M)&QE=F5L*3L-"B`@("`@("`@("`@(&EF("@D=&5S="D@>PT*("`@("`@("`@
M("`@("`@(&EF("@D;65R9V4I('L-"B`@("`@("`@("`@("`@("`@("`@)')E
M="`](&%R<F%Y7VUE<F=E*"1R970L("1T97-T*3L-"B`@("`@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D<F5T6R1P86-K86=E
M72`]("1T97-T.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H)&UE<F=E*2![#0H@("`@("`@("`@
M("!U<V]R="@D<F5T+"`D<V]R=&9U;F,I.PT*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B`D<F5T.PT*("`@('T-"B`@("`-"B`@("`O*BH-"B`@("`@*B!%
M<G)O<B!S;W)T:6YG(&9U;F-T:6]N+"!S;W)T<R!B>2!T:6UE#0H@("`@("H@
M0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7W-O<G1%
M<G)O<G,H)&$L("1B*0T*("`@('L-"B`@("`@("`@:68@*"1A6R=T:6UE)UT@
M/3T@)&);)W1I;64G72D@>PT*("`@("`@("`@("`@<F5T=7)N(#`[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"1A6R=T:6UE)UT@/"`D8ELG=&EM92==*2![
M#0H@("`@("`@("`@("!R971U<FX@,3L-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@+3$[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4W1A;F1A<F0@
M9FEL92]L:6YE(&YU;6)E<B]F=6YC=&EO;B]C;&%S<R!C;VYT97AT(&-A;&QB
M86-K#0H@("`@("H-"B`@("`@*B!4:&ES(&9U;F-T:6]N('5S97,@82!B86-K
M=')A8V4@9V5N97)A=&5D(&9R;VT@>T!L:6YK(&1E8G5G7V)A8VMT<F%C92@I
M?0T*("`@("`J(&%N9"!S;R!W:6QL(&YO="!W;W)K(&%T(&%L;"!I;B!02%`@
M/"`T+C,N,"X@(%1H92!F<F%M92!S:&]U;&0-"B`@("`@*B!R969E<F5N8V4@
M=&AE(&9R86UE('1H870@8V]N=&%I;G,@=&AE('-O=7)C92!O9B!T:&4@97)R
M;W(N#0H@("`@("H@0')E='5R;B!A<G)A>7QF86QS92!E:71H97(@87)R87DH
M)V9I;&4G(#T^(&9I;&4L("=L:6YE)R`]/B!L:6YE+`T*("`@("`J("`@("`@
M("`@)V9U;F-T:6]N)R`]/B!F=6YC=&EO;B!N86UE+"`G8VQA<W,G(#T^(&-L
M87-S(&YA;64I(&]R#0H@("`@("H@("`@("`@("!I9B!T:&ES(&1O97-N)W0@
M=V]R:RP@=&AE;B!F86QS90T*("`@("`J($!P87)A;2!U;G5S960-"B`@("`@
M*B!`<&%R86T@:6YT96=E<B!B86-K=')A8V4@9G)A;64N#0H@("`@("H@0'!A
M<F%M(&%R<F%Y(%)E<W5L=',@;V8@9&5B=6=?8F%C:W1R86-E*"D-"B`@("`@
M*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T1FEL94QI;F4H
M)&-O9&4L("1P87)A;7,L("1B86-K=')A8V4@/2!N=6QL*0T*("`@('L-"B`@
M("`@("`@:68@*"1B86-K=')A8V4@/3T](&YU;&PI('L-"B`@("`@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D9G)A;64@/2`P
M.PT*("`@("`@("`D9G5N8W1I;VYF<F%M92`](#$[#0H@("`@("`@(&EF("@A
M:7-S970H)&)A8VMT<F%C95LQ72DI('L-"B`@("`@("`@("`@("1F=6YC=&EO
M;F9R86UE(#T@,#L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@('=H
M:6QE("AI<W-E="@D8F%C:W1R86-E6R1F=6YC=&EO;F9R86UE75LG9G5N8W1I
M;VXG72D@)B8-"B`@("`@("`@("`@("`@("`@("1B86-K=')A8V5;)&9U;F-T
M:6]N9G)A;65=6R=F=6YC=&EO;B==(#T]("=E=F%L)R`F)@T*("`@("`@("`@
M("`@("`@("`@:7-S970H)&)A8VMT<F%C95LD9G5N8W1I;VYF<F%M92`K(#%=
M*2D@>PT*("`@("`@("`@("`@("`@("1F=6YC=&EO;F9R86UE*RL[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1B86-K
M=')A8V5;)&9R86UE72DI('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)&)A
M8VMT<F%C95LD9G)A;65=6R=F:6QE)UTI*2![#0H@("`@("`@("`@("`@("`@
M)&9R86UE*RL[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D9G5N8V)A
M8VMT<F%C92`]("1B86-K=')A8V5;)&9U;F-T:6]N9G)A;65=.PT*("`@("`@
M("`@("`@)&9I;&5B86-K=')A8V4@/2`D8F%C:W1R86-E6R1F<F%M95T[#0H@
M("`@("`@("`@("`D<F5T(#T@87)R87DH)V9I;&4G(#T^("1F:6QE8F%C:W1R
M86-E6R=F:6QE)UTL#0H@("`@("`@("`@("`@("`@("`@("`@("`@)VQI;F4G
M(#T^("1F:6QE8F%C:W1R86-E6R=L:6YE)UTI.PT*("`@("`@("`@("`@+R\@
M<F5A<G)A;F=E(&9O<B!E=F%L)V0@8V]D92!O<B!C<F5A=&4@9G5N8W1I;VX@
M97)R;W)S#0H@("`@("`@("`@("!I9B`H<W1R<&]S*"1F:6QE8F%C:W1R86-E
M6R=F:6QE)UTL("<H)RD@)B8@#0H@("`@("`@("`@("`)("!P<F5G7VUA=&-H
M*"<[7B@N*C\I7"@H7&0K*5PI(#H@*"XJ/RDD.R<L("1F:6QE8F%C:W1R86-E
M6R=F:6QE)UTL#0H@("`@("`@("`@("`@("`@("`D;6%T8VAE<RDI('L-"B`@
M("`@("`@("`@("`@("`D<F5T6R=F:6QE)UT@/2`D;6%T8VAE<ULQ73L-"B`@
M("`@("`@("`@("`@("`D<F5T6R=L:6YE)UT@/2`D;6%T8VAE<ULR72`K(#`[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)&9U;F-B
M86-K=')A8V5;)V9U;F-T:6]N)UTI("8F(&ES<V5T*"1B86-K=')A8V5;,5TI
M*2![#0H@("`@("`@("`@("`@("`@:68@*"1F=6YC8F%C:W1R86-E6R=F=6YC
M=&EO;B==("$]("=E=F%L)RD@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H
M)&9U;F-B86-K=')A8V5;)V9U;F-T:6]N)UT@/3T@)U]?;&%M8F1A7V9U;F,G
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D<F5T6R=F=6YC=&EO;B==
M(#T@)V-R96%T95]F=6YC=&EO;B@I(&-O9&4G.PT*("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)')E=%LG
M9G5N8W1I;VXG72`]("1F=6YC8F%C:W1R86-E6R=F=6YC=&EO;B==.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1F=6YC8F%C:W1R86-E
M6R=C;&%S<R==*2`F)B!I<W-E="@D8F%C:W1R86-E6S%=*2D@>PT*("`@("`@
M("`@("`@("`@("1R971;)V-L87-S)UT@/2`D9G5N8V)A8VMT<F%C95LG8VQA
M<W,G73L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B`D<F5T
M.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H@
M("`@#0H@("`@+RHJ#0H@("`@("H@4W1A;F1A<F0@97)R;W(@;65S<V%G92!G
M96YE<F%T:6]N(&-A;&QB86-K#0H@("`@("H@#0H@("`@("H@5&AI<R!M971H
M;V0@;6%Y(&%L<V\@8F4@8V%L;&5D(&)Y(&$@8W5S=&]M(&5R<F]R(&UE<W-A
M9V4@9V5N97)A=&]R#0H@("`@("H@=&\@9FEL;"!I;B!T96UP;&%T92!V86QU
M97,@9G)O;2!T:&4@<&%R86US(&%R<F%Y+"!S:6UP;'D-"B`@("`@*B!S970@
M=&AE('1H:7)D('!A<F%M971E<B!T;R!T:&4@97)R;W(@;65S<V%G92!T96UP
M;&%T92!S=')I;F<@=&\@=7-E#0H@("`@("H@#0H@("`@("H@5&AE('-P96-I
M86P@=F%R:6%B;&4@)5]?;7-G)2!I<R!R97-E<G9E9#H@=7-E(&ET(&]N;'D@
M=&\@<W!E8VEF>0T*("`@("`J('=H97)E(&$@;65S<V%G92!P87-S960@:6X@
M8GD@=&AE('5S97(@<VAO=6QD(&)E('!L86-E9"!I;B!T:&4@=&5M<&QA=&4L
M#0H@("`@("H@;&EK92!S;SH-"B`@("`@*B`-"B`@("`@*B!%<G)O<B!M97-S
M86=E.B`E;7-G)2`M(&EN=&5R;F%L(&5R<F]R#0H@("`@("H@#0H@("`@("H@
M268@=&AE(&UE<W-A9V4@<&%S<V5D(&QI:V4@<V\Z#0H@("`@("H@#0H@("`@
M("H@/&-O9&4^#0H@("`@("H@)'-T86-K+3YP=7-H*$524D]27T-/1$4L("=E
M<G)O<B<L(&%R<F%Y*"DL("=S97)V97(@97)R;W(@-3`P)RD[#0H@("`@("H@
M/"]C;V1E/@T*("`@("`J(`T*("`@("`J(%1H92!R971U<FYE9"!E<G)O<B!M
M97-S86=E('=I;&P@8F4@(D5R<F]R(&UE<W-A9V4Z('-E<G9E<B!E<G)O<B`U
M,#`@+0T*("`@("`J(&EN=&5R;F%L(&5R<F]R(@T*("`@("`J($!P87)A;2!0
M14%27T5R<F]R4W1A8VL-"B`@("`@*B!`<&%R86T@87)R87D-"B`@("`@*B!`
M<&%R86T@<W1R:6YG?&9A;'-E(%!R92UG96YE<F%T960@97)R;W(@;65S<V%G
M92!T96UP;&%T90T*("`@("`J($!S=&%T:6,-"B`@("`@*B!`<F5T=7)N('-T
M<FEN9PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$5R<F]R365S<V%G92@F
M)'-T86-K+"`D97)R+"`D=&5M<&QA=&4@/2!F86QS92D-"B`@("![#0H@("`@
M("`@(&EF("@D=&5M<&QA=&4I('L-"B`@("`@("`@("`@("1M86EN;7-G(#T@
M)'1E;7!L871E.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&UA
M:6YM<V<@/2`D<W1A8VLM/F=E=$5R<F]R365S<V%G951E;7!L871E*"1E<G);
M)V-O9&4G72D[#0H@("`@("`@('T-"B`@("`@("`@)&UA:6YM<V<@/2!S=')?
M<F5P;&%C92@G)5]?;7-G)2<L("1E<G);)VUE<W-A9V4G72P@)&UA:6YM<V<I
M.PT*("`@("`@("!I9B`H:7-?87)R87DH)&5R<ELG<&%R86US)UTI("8F(&-O
M=6YT*"1E<G);)W!A<F%M<R==*2D@>PT*("`@("`@("`@("`@9F]R96%C:"`H
M)&5R<ELG<&%R86US)UT@87,@)&YA;64@/3X@)'9A;"D@>PT*("`@("`@("`@
M("`@("`@(&EF("AI<U]A<G)A>2@D=F%L*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`O+R!`(&ES(&YE961E9"!I;B!C87-E("1V86P@:7,@82!M=6QT:2UD
M:6UE;G-I;VYA;"!A<G)A>0T*("`@("`@("`@("`@("`@("`@("`D=F%L(#T@
M0&EM<&QO9&4H)RP@)RP@)'9A;"D[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@(&EF("AI<U]O8FIE8W0H)'9A;"DI('L-"B`@("`@("`@
M("`@("`@("`@("`@:68@*&UE=&AO9%]E>&ES=',H)'9A;"P@)U]?=&]3=')I
M;F<G*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;"`]("1V86PM
M/E]?=&]3=')I;F<H*3L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?17)R;W)3=&%C:SHZ<W1A
M=&EC4'5S:"@G4$5!4E]%<G)O<E-T86-K)RP@4$5!4E]%4E)/4E-404-+7T52
M4E]/0DI43U-44DE.1RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M=V%R;FEN9R<L(&%R<F%Y*"=O8FHG(#T^(&=E=%]C;&%S<R@D=F%L*2DL#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)V]B:F5C="`E;V)J)2!P87-S
M960@:6YT;R!G971%<G)O<DUE<W-A9V4L(&)U="!H87,@;F\@7U]T;U-T<FEN
M9R@I(&UE=&AO9"<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;"`]
M("=/8FIE8W0G.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("1M86EN;7-G(#T@<W1R7W)E<&QA
M8V4H)R4G("X@)&YA;64@+B`G)2<L("1V86PL("1M86EN;7-G*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)&UA:6YM<V<[
M#0H@("`@?0T*("`@(`T*("`@("\J*@T*("`@("`J(%-T86YD87)D($5R<F]R
M($UE<W-A9V4@5&5M<&QA=&4@9V5N97)A=&]R(&9R;VT@8V]D90T*("`@("`J
M($!R971U<FX@<W1R:6YG#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T17)R
M;W)-97-S86=E5&5M<&QA=&4H)&-O9&4I#0H@("`@>PT*("`@("`@("!I9B`H
M(6ES<V5T*"1T:&ES+3Y?97)R;W)-<V=S6R1C;V1E72DI('L-"B`@("`@("`@
M("`@(')E='5R;B`G)5]?;7-G)2<[#0H@("`@("`@('T-"B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?97)R;W)-<V=S6R1C;V1E73L-"B`@("!]#0H@("`@#0H@
M("`@+RHJ#0H@("`@("H@4V5T('1H92!%<G)O<B!-97-S86=E(%1E;7!L871E
M(&%R<F%Y#0H@("`@("H@#0H@("`@("H@5&AE(&%R<F%Y(&9O<FUA="!M=7-T
M(&)E.@T*("`@("`J(#QP<F4^#0H@("`@("H@87)R87DH97)R;W(@8V]D92`]
M/B`G;65S<V%G92!T96UP;&%T92<L+BXN*0T*("`@("`J(#PO<')E/@T*("`@
M("`J(`T*("`@("`J($5R<F]R(&UE<W-A9V4@<&%R86UE=&5R<R!P87-S960@
M:6YT;R![0&QI;FL@<'5S:"@I?2!W:6QL(&)E('5S960@87,@:6YP=70-"B`@
M("`@*B!F;W(@=&AE(&5R<F]R(&UE<W-A9V4N("!)9B!T:&4@=&5M<&QA=&4@
M:7,@)VUE<W-A9V4@)69O;R4@=V%S("5B87(E)RP@86YD('1H90T*("`@("`J
M('!A<F%M971E<G,@87)E(&%R<F%Y*"=F;V\G(#T^("=O;F4G+"`G8F%R)R`]
M/B`G<VEX)RDL('1H92!E<G)O<B!M97-S86=E(')E='5R;F5D('=I;&P-"B`@
M("`@*B!B92`G;65S<V%G92!O;F4@=V%S('-I>"<-"B`@("`@*B!`<F5T=7)N
M('-T<FEN9PT*("`@("`J+PT*("`@(&9U;F-T:6]N('-E=$5R<F]R365S<V%G
M951E;7!L871E*"1T96UP;&%T92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?
M97)R;W)-<V=S(#T@)'1E;7!L871E.PT*("`@('T-"B`@("`-"B`@("`-"B`@
M("`O*BH-"B`@("`@*B!E;75L871E(%!%05(Z.G)A:7-E17)R;W(H*0T*("`@
M("`J(`T*("`@("`J($!R971U<FX@4$5!4E]%<G)O<@T*("`@("`J+PT*("`@
M(&9U;F-T:6]N(')A:7-E17)R;W(H*0T*("`@('L-"B`@("`@("`@<F5Q=6ER
M95]O;F-E("=014%2+G!H<"<[#0H@("`@("`@("1A<F=S(#T@9G5N8U]G971?
M87)G<R@I.PT*("`@("`@("!R971U<FX@8V%L;%]U<V5R7V9U;F-?87)R87DH
M87)R87DH)U!%05(G+"`G<F%I<V5%<G)O<B<I+"`D87)G<RD[#0H@("`@?0T*
M?0T*)'-T86-K(#T@)E!%05)?17)R;W)3=&%C:SHZ<VEN9VQE=&]N*"=014%2
M7T5R<F]R4W1A8VLG*3L-"B1S=&%C:RT^<'5S:$-A;&QB86-K*&%R<F%Y*"=0
M14%27T5R<F]R4W1A8VLG+"`G7VAA;F1L945R<F]R)RDI.PT*/SX-"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O4$5!4B]%>&-E<'1I;VXN<&AP````````````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`S,38Q,"`Q,#4Q-30S,S<S,B`P,C$V-C0`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`-
M"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT
M(&9O;&1M971H;V0];6%R:V5R.B`J+PT*+RHJ#0H@*B!014%27T5X8V5P=&EO
M;@T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y3
M13H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP
M(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ
M#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@
M>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC
M96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@
M=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE
M="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-
M"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J
M($!A=71H;W(@("`@(%1O;6%S(%8N(%8N($-O>"`\8V]X0&ED96-N970N8V]M
M/@T*("H@0&%U=&AO<B`@("`@2&%N<R!,96QL96QI9"`\:&%N<T!V96QU;2YN
M970^#0H@*B!`875T:&]R("`@("!"97)T<F%N9"!-86YS:6]N(#QB;6%N<VEO
M;D!M86UA<V%M+F-O;3X-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC
M96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@
M4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N
M("`@($-64SH@)$ED.B!%>&-E<'1I;VXN<&AP+'8@,2XR,R`R,#`V+S`Q+S`V
M(#`T.C0W.C,V(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I
M;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XS+C,-"B`J+PT*#0H-"B\J
M*@T*("H@0F%S92!014%27T5X8V5P=&EO;B!#;&%S<PT*("H-"B`J(#$I($9E
M871U<F5S.@T*("H-"B`J("T@3F5S=&%B;&4@97AC97!T:6]N<R`H=&AR;W<@
M;F5W(%!%05)?17AC97!T:6]N*"1M<V<L("1P<F5V7V5X8V5P=&EO;BDI#0H@
M*B`M($1E9FEN86)L92!T<FEG9V5R<RP@<VAO="!W:&5N(&5X8V5P=&EO;G,@
M;V-C=7(-"B`J("T@4')E='1Y(&%N9"!I;F9O<FUA=&EV92!E<G)O<B!M97-S
M86=E<PT*("H@+2!!9&1E9"!M;W)E(&-O;G1E>'0@:6YF;R!A=F%I;&%B;&4@
M*&QI:V4@8VQA<W,L(&UE=&AO9"!O<B!C875S92D-"B`J("T@8V%U<V4@8V%N
M(&)E(&$@4$5!4E]%>&-E<'1I;VX@;W(@86X@87)R87D@;V8@;6EX960-"B`J
M("`@4$5!4E]%>&-E<'1I;VYS+U!%05)?17)R;W)3=&%C:R!W87)N:6YG<PT*
M("H@+2!C86QL8F%C:W,@9F]R('-P96-I9FEC(&5X8V5P=&EO;B!C;&%S<V5S
M(&%N9"!T:&5I<B!C:&EL9')E;@T*("H-"B`J(#(I($ED96%S.@T*("H-"B`J
M("T@36%Y8F4@82!W87D@=&\@9&5F:6YE(&$@)W1E;7!L871E)R!F;W(@=&AE
M(&]U='!U=`T*("H-"B`J(#,I($EN:&5R:71E9"!P<F]P97)T:65S(&9R;VT@
M4$A0($5X8V5P=&EO;B!#;&%S<SH-"B`J#0H@*B!P<F]T96-T960@)&UE<W-A
M9V4-"B`J('!R;W1E8W1E9"`D8V]D90T*("H@<')O=&5C=&5D("1L:6YE#0H@
M*B!P<F]T96-T960@)&9I;&4-"B`J('!R:79A=&4@("`D=')A8V4-"B`J#0H@
M*B`T*2!);FAE<FET960@;65T:&]D<R!F<F]M(%!(4"!%>&-E<'1I;VX@0VQA
M<W,Z#0H@*@T*("H@7U]C;&]N90T*("H@7U]C;VYS=')U8W0-"B`J(&=E=$UE
M<W-A9V4-"B`J(&=E=$-O9&4-"B`J(&=E=$9I;&4-"B`J(&=E=$QI;F4-"B`J
M(&=E=%1R86-E4V%F90T*("H@9V5T5')A8V53869E07-3=')I;F<-"B`J(%]?
M=&]3=')I;F<-"B`J#0H@*B`U*2!5<V%G92!E>&%M<&QE#0H@*@T*("H@/&-O
M9&4^#0H@*B`@<F5Q=6ER95]O;F-E("=014%2+T5X8V5P=&EO;BYP:'`G.PT*
M("H-"B`J("!C;&%S<R!497-T('L-"B`J("`@("!F=6YC=&EO;B!F;V\H*2![
M#0H@*B`@("`@("`@('1H<F]W(&YE=R!014%27T5X8V5P=&EO;B@G17)R;W(@
M365S<V%G92<L($524D]27T-/1$4I.PT*("H@("`@('T-"B`J("!]#0H@*@T*
M("H@(&9U;F-T:6]N(&UY3&]G9V5R*"1P96%R7V5X8V5P=&EO;BD@>PT*("H@
M("`@(&5C:&\@)'!E87)?97AC97!T:6]N+3YG971-97-S86=E*"D[#0H@*B`@
M?0T*("H@("\O(&5A8V@@=&EM92!A(&5X8V5P=&EO;B!I<R!T:')O=VX@=&AE
M("=M>4QO9V=E<B<@=VEL;"!B92!C86QL960-"B`J("`O+R`H:71S('5S92!I
M<R!C;VUP;&5T96QY(&]P=&EO;F%L*0T*("H@(%!%05)?17AC97!T:6]N.CIA
M9&1/8G-E<G9E<B@G;7E,;V=G97(G*3L-"B`J("`D=&5S="`](&YE=R!497-T
M.PT*("H@('1R>2![#0H@*B`@("`@)'1E<W0M/F9O;R@I.PT*("H@('T@8V%T
M8V@@*%!%05)?17AC97!T:6]N("1E*2![#0H@*B`@("`@<')I;G0@)&4[#0H@
M*B`@?0T*("H@/"]C;V1E/@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J
M($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@(%1O;6%S(%8N5BY#
M;W@@/&-O>$!I9&5C;F5T+F-O;3X-"B`J($!A=71H;W(@("`@($AA;G,@3&5L
M;&5L:60@/&AA;G-`=F5L=6TN;F5T/@T*("H@0&%U=&AO<B`@("`@0F5R=')A
M;F0@36%N<VEO;B`\8FUA;G-I;VY`;6%M87-A;2YC;VT^#0H@*B!`875T:&]R
M("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I
M9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N
M<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@0&QI
M;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J
M($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#$N
M,RXS#0H@*@T*("HO#0IC;&%S<R!014%27T5X8V5P=&EO;B!E>'1E;F1S($5X
M8V5P=&EO;@T*>PT*("`@(&-O;G-T($]"4T525D527U!224Y4(#T@+3([#0H@
M("`@8V]N<W0@3T)315)615)?5%))1T=%4B`]("TT.PT*("`@(&-O;G-T($]"
M4T525D527T1)12`]("TX.PT*("`@('!R;W1E8W1E9"`D8V%U<V4[#0H@("`@
M<')I=F%T92!S=&%T:6,@)%]O8G-E<G9E<G,@/2!A<G)A>2@I.PT*("`@('!R
M:79A=&4@<W1A=&EC("1?=6YI<75E:60@/2`P.PT*("`@('!R:79A=&4@)%]T
M<F%C93L-"@T*("`@("\J*@T*("`@("`J(%-U<'!O<G1E9"!S:6=N871U<F5S
M.@T*("`@("`J(%!%05)?17AC97!T:6]N*'-T<FEN9R`D;65S<V%G92D[#0H@
M("`@("H@4$5!4E]%>&-E<'1I;VXH<W1R:6YG("1M97-S86=E+"!I;G0@)&-O
M9&4I.PT*("`@("`J(%!%05)?17AC97!T:6]N*'-T<FEN9R`D;65S<V%G92P@
M17AC97!T:6]N("1C875S92D[#0H@("`@("H@4$5!4E]%>&-E<'1I;VXH<W1R
M:6YG("1M97-S86=E+"!%>&-E<'1I;VX@)&-A=7-E+"!I;G0@)&-O9&4I.PT*
M("`@("`J(%!%05)?17AC97!T:6]N*'-T<FEN9R`D;65S<V%G92P@87)R87D@
M)&-A=7-E<RD[#0H@("`@("H@4$5!4E]%>&-E<'1I;VXH<W1R:6YG("1M97-S
M86=E+"!A<G)A>2`D8V%U<V5S+"!I;G0@)&-O9&4I.PT*("`@("`J+PT*("`@
M('!U8FQI8R!F=6YC=&EO;B!?7V-O;G-T<G5C="@D;65S<V%G92P@)'`R(#T@
M;G5L;"P@)'`S(#T@;G5L;"D-"B`@("![#0H@("`@("`@(&EF("AI<U]I;G0H
M)'`R*2D@>PT*("`@("`@("`@("`@)&-O9&4@/2`D<#([#0H@("`@("`@("`@
M("`D=&AI<RT^8V%U<V4@/2!N=6QL.PT*("`@("`@("!](&5L<V5I9B`H)'`R
M(&EN<W1A;F-E;V8@17AC97!T:6]N('Q\(&ES7V%R<F%Y*"1P,BDI('L-"B`@
M("`@("`@("`@("1C;V1E(#T@)'`S.PT*("`@("`@("`@("`@:68@*&ES7V%R
M<F%Y*"1P,BD@)B8@:7-S970H)'`R6R=M97-S86=E)UTI*2![#0H@("`@("`@
M("`@("`@("`@+R\@9FEX('!O=&5N=&EA;"!P<F]B;&5M(&]F('!A<W-I;F<@
M:6X@82!S:6YG;&4@=V%R;FEN9PT*("`@("`@("`@("`@("`@("1P,B`](&%R
M<F%Y*"1P,BD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D=&AI<RT^
M8V%U<V4@/2`D<#([#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D
M8V]D92`](&YU;&P[#0H@("`@("`@("`@("`D=&AI<RT^8V%U<V4@/2!N=6QL
M.PT*("`@("`@("!]#0H@("`@("`@('!A<F5N=#HZ7U]C;VYS=')U8W0H)&UE
M<W-A9V4L("1C;V1E*3L-"B`@("`@("`@)'1H:7,M/G-I9VYA;"@I.PT*("`@
M('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!M:7AE9"`D8V%L;&)A8VL@
M("T@02!V86QI9"!P:'`@8V%L;&)A8VLL('-E92!P:'`@9G5N8R!I<U]C86QL
M86)L92@I#0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@+2!!(%!%
M05)?17AC97!T:6]N.CI/0E-%4E9%4E\J(&-O;G-T86YT#0H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@+2!!;B!A<G)A>2AC;VYS="!014%27T5X
M8V5P=&EO;CHZ3T)315)615)?*BP-"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&UI>&5D("1O<'1I;VYS*0T*("`@("`J($!P87)A;2!S=')I
M;F<@)&QA8F5L("`@(%1H92!N86UE(&]F('1H92!O8G-E<G9E<BX@57-E('1H
M:7,@:68@>6]U('=A;G0-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("!T;R!R96UO=F4@:70@;&%T97(@=VET:"!R96UO=F5/8G-E<G9E<B@I#0H@
M("`@("HO#0H@("`@<'5B;&EC('-T871I8R!F=6YC=&EO;B!A9&1/8G-E<G9E
M<B@D8V%L;&)A8VLL("1L86)E;"`]("=D969A=6QT)RD-"B`@("![#0H@("`@
M("`@('-E;&8Z.B1?;V)S97)V97)S6R1L86)E;%T@/2`D8V%L;&)A8VL[#0H@
M("`@?0T*#0H@("`@<'5B;&EC('-T871I8R!F=6YC=&EO;B!R96UO=F5/8G-E
M<G9E<B@D;&%B96P@/2`G9&5F875L="<I#0H@("`@>PT*("`@("`@("!U;G-E
M="AS96QF.CHD7V]B<V5R=F5R<ULD;&%B96Q=*3L-"B`@("!]#0H-"B`@("`O
M*BH-"B`@("`@*B!`<F5T=7)N(&EN="!U;FEQ=64@:61E;G1I9FEE<B!F;W(@
M86X@;V)S97)V97(-"B`@("`@*B\-"B`@("!P=6)L:6,@<W1A=&EC(&9U;F-T
M:6]N(&=E=%5N:7%U94ED*"D-"B`@("![#0H@("`@("`@(')E='5R;B!S96QF
M.CHD7W5N:7%U96ED*RL[#0H@("`@?0T*#0H@("`@<')I=F%T92!F=6YC=&EO
M;B!S:6=N86PH*0T*("`@('L-"B`@("`@("`@9F]R96%C:"`H<V5L9CHZ)%]O
M8G-E<G9E<G,@87,@)&9U;F,I('L-"B`@("`@("`@("`@(&EF("AI<U]C86QL
M86)L92@D9G5N8RDI('L-"B`@("`@("`@("`@("`@("!C86QL7W5S97)?9G5N
M8R@D9G5N8RP@)'1H:7,I.PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@<V5T='EP92@D9G5N8RP@)V%R
M<F%Y)RD[#0H@("`@("`@("`@("!S=VET8V@@*"1F=6YC6S!=*2![#0H@("`@
M("`@("`@("`@("`@8V%S92!S96QF.CI/0E-%4E9%4E]04DE.5"`Z#0H@("`@
M("`@("`@("`@("`@("`@("1F(#T@*&ES<V5T*"1F=6YC6S%=*2D@/R`D9G5N
M8ULQ72`Z("<E<R<[#0H@("`@("`@("`@("`@("`@("`@('!R:6YT9B@D9BP@
M)'1H:7,M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@("`@(&-A<V4@<V5L9CHZ3T)315)615)?5%))
M1T=%4B`Z#0H@("`@("`@("`@("`@("`@("`@("1F(#T@*&ES<V5T*"1F=6YC
M6S%=*2D@/R`D9G5N8ULQ72`Z($5?55-%4E].3U1)0T4[#0H@("`@("`@("`@
M("`@("`@("`@('1R:6=G97)?97)R;W(H)'1H:7,M/F=E=$UE<W-A9V4H*2P@
M)&8I.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@
M("`@("!C87-E('-E;&8Z.D]"4T525D527T1)12`Z#0H@("`@("`@("`@("`@
M("`@("`@("1F(#T@*&ES<V5T*"1F=6YC6S%=*2D@/R`D9G5N8ULQ72`Z("<E
M<R<[#0H@("`@("`@("`@("`@("`@("`@(&1I92AP<FEN=&8H)&8L("1T:&ES
M+3YG971-97-S86=E*"DI*3L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[
M#0H@("`@("`@("`@("`@("`@9&5F875L=#H-"B`@("`@("`@("`@("`@("`@
M("`@=')I9V=E<E]E<G)O<B@G:6YV86QI9"!O8G-E<G9E<B!T>7!E)RP@15]5
M4T527U=!4DY)3D<I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@4F5T=7)N('-P96-I9FEC(&5R<F]R(&EN
M9F]R;6%T:6]N('1H870@8V%N(&)E('5S960@9F]R(&UO<F4@9&5T86EL960-
M"B`@("`@*B!E<G)O<B!M97-S86=E<R!O<B!T<F%N<VQA=&EO;BX-"B`@("`@
M*@T*("`@("`J(%1H:7,@;65T:&]D(&UA>2!B92!O=F5R<FED9&5N(&EN(&-H
M:6QD(&5X8V5P=&EO;B!C;&%S<V5S(&EN(&]R9&5R#0H@("`@("H@=&\@861D
M(&9U;F-T:6]N86QI='D@;F]T('!R97-E;G0@:6X@4$5!4E]%>&-E<'1I;VX@
M86YD(&ES(&$@<&QA8V5H;VQD97(-"B`@("`@*B!T;R!D969I;F4@05!)#0H@
M("`@("H-"B`@("`@*B!4:&4@<F5T=7)N960@87)R87D@;75S="!B92!A;B!A
M<W-O8VEA=&EV92!A<G)A>2!O9B!P87)A;65T97(@/3X@=F%L=64@;&EK92!S
M;SH-"B`@("`@*B`\<')E/@T*("`@("`J(&%R<F%Y*"=N86UE)R`]/B`D;F%M
M92P@)V-O;G1E>'0G(#T^(&%R<F%Y*"XN+BDI#0H@("`@("H@/"]P<F4^#0H@
M("`@("H@0')E='5R;B!A<G)A>0T*("`@("`J+PT*("`@('!U8FQI8R!F=6YC
M=&EO;B!G971%<G)O<D1A=&$H*0T*("`@('L-"B`@("`@("`@<F5T=7)N(&%R
M<F%Y*"D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4F5T=7)N<R!T:&4@
M97AC97!T:6]N('1H870@8V%U<V5D('1H:7,@97AC97!T:6]N('1O(&)E('1H
M<F]W;@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H@0')E='5R;B!%
M>&-E<'1I;VY\87)R87D@5&AE(&-O;G1E>'0@;V8@=&AE(&5X8V5P=&EO;@T*
M("`@("`J+PT*("`@('!U8FQI8R!F=6YC=&EO;B!G971#875S92@I#0H@("`@
M>PT*("`@("`@("!R971U<FX@)'1H:7,M/F-A=7-E.PT*("`@('T-"@T*("`@
M("\J*@T*("`@("`J($9U;F-T:6]N(&UU<W0@8F4@<'5B;&EC('1O(&-A;&P@
M;VX@8V%U<V5D(&5X8V5P=&EO;G,-"B`@("`@*B!`<&%R86T@87)R87D-"B`@
M("`@*B\-"B`@("!P=6)L:6,@9G5N8W1I;VX@9V5T0V%U<V5-97-S86=E*"8D
M8V%U<V5S*0T*("`@('L-"B`@("`@("`@)'1R86-E(#T@)'1H:7,M/F=E=%1R
M86-E4V%F92@I.PT*("`@("`@("`D8V%U<V4@/2!A<G)A>2@G8VQA<W,G("`@
M/3X@9V5T7V-L87-S*"1T:&ES*2P-"B`@("`@("`@("`@("`@("`@("`@("`@
M)VUE<W-A9V4G(#T^("1T:&ES+3YM97-S86=E+`T*("`@("`@("`@("`@("`@
M("`@("`@("`G9FEL92<@/3X@)W5N:VYO=VXG+`T*("`@("`@("`@("`@("`@
M("`@("`@("`G;&EN92<@/3X@)W5N:VYO=VXG*3L-"B`@("`@("`@:68@*&ES
M<V5T*"1T<F%C95LP72DI('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D=')A
M8V5;,%U;)V9I;&4G72DI('L-"B`@("`@("`@("`@("`@("`D8V%U<V5;)V9I
M;&4G72`]("1T<F%C95LP75LG9FEL92==.PT*("`@("`@("`@("`@("`@("1C
M875S95LG;&EN92==(#T@)'1R86-E6S!=6R=L:6YE)UT[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@)&-A=7-E<UM=(#T@)&-A=7-E.PT*
M("`@("`@("!I9B`H)'1H:7,M/F-A=7-E(&EN<W1A;F-E;V8@4$5!4E]%>&-E
M<'1I;VXI('L-"B`@("`@("`@("`@("1T:&ES+3YC875S92T^9V5T0V%U<V5-
M97-S86=E*"1C875S97,I.PT*("`@("`@("!](&5L<V5I9B`H)'1H:7,M/F-A
M=7-E(&EN<W1A;F-E;V8@17AC97!T:6]N*2![#0H@("`@("`@("`@("`D8V%U
M<V5S6UT@/2!A<G)A>2@G8VQA<W,G("`@/3X@9V5T7V-L87-S*"1C875S92DL
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`G;65S<V%G92<@/3X@)&-A
M=7-E+3YG971-97-S86=E*"DL#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G9FEL92<@/3X@)&-A=7-E+3YG971&:6QE*"DL#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G;&EN92<@/3X@)&-A=7-E+3YG971,:6YE*"DI.PT*
M#0H@("`@("`@('T@96QS96EF("AI<U]A<G)A>2@D=&AI<RT^8V%U<V4I*2![
M#0H@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^8V%U<V4@87,@)&-A=7-E
M*2![#0H@("`@("`@("`@("`@("`@:68@*"1C875S92!I;G-T86YC96]F(%!%
M05)?17AC97!T:6]N*2![#0H@("`@("`@("`@("`@("`@("`@("1C875S92T^
M9V5T0V%U<V5-97-S86=E*"1C875S97,I.PT*("`@("`@("`@("`@("`@('T@
M96QS96EF("@D8V%U<V4@:6YS=&%N8V5O9B!%>&-E<'1I;VXI('L-"B`@("`@
M("`@("`@("`@("`@("`@)&-A=7-E<UM=(#T@87)R87DH)V-L87-S)R`@(#T^
M(&=E=%]C;&%S<R@D8V%U<V4I+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G;65S<V%G92<@/3X@)&-A=7-E+3YG971-97-S86=E*"DL
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=F:6QE)R`]
M/B`D8V%U<V4M/F=E=$9I;&4H*2P-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)VQI;F4G(#T^("1C875S92T^9V5T3&EN92@I*3L-"B`@
M("`@("`@("`@("`@("!](&5L<V5I9B`H:7-?87)R87DH)&-A=7-E*2`F)B!I
M<W-E="@D8V%U<V5;)VUE<W-A9V4G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@+R\@4$5!4E]%<G)O<E-T86-K('=A<FYI;F<-"B`@("`@("`@("`@("`@
M("`@("`@)&-A=7-E<UM=(#T@87)R87DH#0H@("`@("`@("`@("`@("`@("`@
M("`@("`G8VQA<W,G(#T^("1C875S95LG<&%C:V%G92==+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@)VUE<W-A9V4G(#T^("1C875S95LG;65S<V%G92==
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@)V9I;&4G(#T^(&ES<V5T*"1C
M875S95LG8V]N=&5X="==6R=F:6QE)UTI(#\-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-A=7-E6R=C;VYT97AT)UU;
M)V9I;&4G72`Z#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=U;FMN;W=N)RP-"B`@("`@("`@("`@("`@("`@("`@("`@
M("=L:6YE)R`]/B!I<W-E="@D8V%U<V5;)V-O;G1E>'0G75LG;&EN92==*2`_
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1C875S95LG8V]N=&5X="==6R=L:6YE)UT@.@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=6YK;F]W;B<L#0H@("`@
M("`@("`@("`@("`@("`@("D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*#0H@("`@<'5B;&EC(&9U;F-T
M:6]N(&=E=%1R86-E4V%F92@I#0H@("`@>R`@(`T*("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3Y?=')A8V4I*2![#0H@("`@("`@("`@("`D=&AI<RT^7W1R
M86-E(#T@)'1H:7,M/F=E=%1R86-E*"D[#0H@("`@("`@("`@("!I9B`H96UP
M='DH)'1H:7,M/E]T<F%C92DI('L-"B`@("`@("`@("`@("`@("`D8F%C:W1R
M86-E(#T@9&5B=6=?8F%C:W1R86-E*"D[#0H@("`@("`@("`@("`@("`@)'1H
M:7,M/E]T<F%C92`](&%R<F%Y*"1B86-K=')A8V5;8V]U;G0H)&)A8VMT<F%C
M92DM,5TI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B`D=&AI<RT^7W1R86-E.PT*("`@('T-"@T*("`@('!U8FQI8R!F=6YC
M=&EO;B!G971%<G)O<D-L87-S*"D-"B`@("![#0H@("`@("`@("1T<F%C92`]
M("1T:&ES+3YG9714<F%C95-A9F4H*3L-"B`@("`@("`@<F5T=7)N("1T<F%C
M95LP75LG8VQA<W,G73L-"B`@("!]#0H-"B`@("!P=6)L:6,@9G5N8W1I;VX@
M9V5T17)R;W)-971H;V0H*0T*("`@('L-"B`@("`@("`@)'1R86-E(#T@)'1H
M:7,M/F=E=%1R86-E4V%F92@I.PT*("`@("`@("!R971U<FX@)'1R86-E6S!=
M6R=F=6YC=&EO;B==.PT*("`@('T-"@T*("`@('!U8FQI8R!F=6YC=&EO;B!?
M7W1O4W1R:6YG*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D7U-%4E9%
M4ELG4D5154535%]54DDG72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^=&](=&UL*"D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1T:&ES
M+3YT;U1E>'0H*3L-"B`@("!]#0H-"B`@("!P=6)L:6,@9G5N8W1I;VX@=&](
M=&UL*"D-"B`@("![#0H@("`@("`@("1T<F%C92`]("1T:&ES+3YG9714<F%C
M95-A9F4H*3L-"B`@("`@("`@)&-A=7-E<R`](&%R<F%Y*"D[#0H@("`@("`@
M("1T:&ES+3YG971#875S94UE<W-A9V4H)&-A=7-E<RD[#0H@("`@("`@("1H
M=&UL(#T@("<\=&%B;&4@8F]R9&5R/2(Q(B!C96QL<W!A8VEN9STB,"(^)R`N
M(")<;B([#0H@("`@("`@(&9O<F5A8V@@*"1C875S97,@87,@)&D@/3X@)&-A
M=7-E*2![#0H@("`@("`@("`@("`D:'1M;"`N/2`G/'1R/CQT9"!C;VQS<&%N
M/2(S(B!B9V-O;&]R/2(C9F8Y.3DY(CXG#0H@("`@("`@("`@("`@("`N('-T
M<E]R97!E870H)RTG+"`D:2D@+B`G(#QB/B<@+B`D8V%U<V5;)V-L87-S)UT@
M+B`G/"]B/CH@)PT*("`@("`@("`@("`@("`@+B!H=&UL<W!E8VEA;&-H87)S
M*"1C875S95LG;65S<V%G92==*2`N("<@:6X@/&(^)R`N("1C875S95LG9FEL
M92==("X@)SPO8CX@)PT*("`@("`@("`@("`@("`@+B`G;VX@;&EN92`\8CXG
M("X@)&-A=7-E6R=L:6YE)UT@+B`G/"]B/B<-"B`@("`@("`@("`@("`@("X@
M(CPO=&0^/"]T<CY<;B([#0H@("`@("`@('T-"B`@("`@("`@)&AT;6P@+CT@
M)SQT<CX\=&0@8V]L<W!A;CTB,R(@8F=C;VQO<CTB(V%A86%A82(@86QI9VX]
M(F-E;G1E<B(^/&(^17AC97!T:6]N('1R86-E/"]B/CPO=&0^/"]T<CXG("X@
M(EQN(@T*("`@("`@("`@("`@("`@+B`G/'1R/CQT9"!A;&EG;CTB8V5N=&5R
M(B!B9V-O;&]R/2(C8V-C8V-C(B!W:61T:#TB,C`B/CQB/B,\+V(^/"]T9#XG
M#0H@("`@("`@("`@("`@("`N("<\=&0@86QI9VX](F-E;G1E<B(@8F=C;VQO
M<CTB(V-C8V-C8R(^/&(^1G5N8W1I;VX\+V(^/"]T9#XG#0H@("`@("`@("`@
M("`@("`N("<\=&0@86QI9VX](F-E;G1E<B(@8F=C;VQO<CTB(V-C8V-C8R(^
M/&(^3&]C871I;VX\+V(^/"]T9#X\+W1R/B<@+B`B7&XB.PT*#0H@("`@("`@
M(&9O<F5A8V@@*"1T<F%C92!A<R`D:R`]/B`D=BD@>PT*("`@("`@("`@("`@
M)&AT;6P@+CT@)SQT<CX\=&0@86QI9VX](F-E;G1E<B(^)R`N("1K("X@)SPO
M=&0^)PT*("`@("`@("`@("`@("`@("`@("X@)SQT9#XG.PT*("`@("`@("`@
M("`@:68@*"%E;7!T>2@D=ELG8VQA<W,G72DI('L-"B`@("`@("`@("`@("`@
M("`D:'1M;"`N/2`D=ELG8VQA<W,G72`N("1V6R=T>7!E)UT[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`D:'1M;"`N/2`D=ELG9G5N8W1I;VXG73L-
M"B`@("`@("`@("`@("1A<F=S(#T@87)R87DH*3L-"B`@("`@("`@("`@(&EF
M("@A96UP='DH)'9;)V%R9W,G72DI('L-"B`@("`@("`@("`@("`@("!F;W)E
M86-H("@D=ELG87)G<R==(&%S("1A<F<I('L-"B`@("`@("`@("`@("`@("`@
M("`@:68@*&ES7VYU;&PH)&%R9RDI("1A<F=S6UT@/2`G;G5L;"<[#0H@("`@
M("`@("`@("`@("`@("`@(&5L<V5I9B`H:7-?87)R87DH)&%R9RDI("1A<F=S
M6UT@/2`G07)R87DG.PT*("`@("`@("`@("`@("`@("`@("!E;'-E:68@*&ES
M7V]B:F5C="@D87)G*2D@)&%R9W-;72`]("=/8FIE8W0H)RYG971?8VQA<W,H
M)&%R9RDN)RDG.PT*("`@("`@("`@("`@("`@("`@("!E;'-E:68@*&ES7V)O
M;VPH)&%R9RDI("1A<F=S6UT@/2`D87)G(#\@)W1R=64G(#H@)V9A;'-E)SL-
M"B`@("`@("`@("`@("`@("`@("`@96QS96EF("AI<U]I;G0H)&%R9RD@?'P@
M:7-?9&]U8FQE*"1A<F<I*2`D87)G<UM=(#T@)&%R9SL-"B`@("`@("`@("`@
M("`@("`@("`@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`D87)G
M(#T@*'-T<FEN9RDD87)G.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'-T
M<B`](&AT;6QS<&5C:6%L8VAA<G,H<W5B<W1R*"1A<F<L(#`L(#$V*2D[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H<W1R;&5N*"1A<F<I(#X@,38I
M("1S='(@+CT@)R9H96QL:7`[)SL-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1A<F=S6UT@/2`B)R(@+B`D<W1R("X@(B<B.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@)&AT;6P@+CT@)R@G("X@:6UP;&]D92@G+"`G+"1A<F=S*2`N
M("<I)PT*("`@("`@("`@("`@("`@("`@("X@)SPO=&0^)PT*("`@("`@("`@
M("`@("`@("`@("X@)SQT9#XG("X@*&ES<V5T*"1V6R=F:6QE)UTI(#\@)'9;
M)V9I;&4G72`Z("=U;FMN;W=N)RD-"B`@("`@("`@("`@("`@("`@("`N("<Z
M)R`N("AI<W-E="@D=ELG;&EN92==*2`_("1V6R=L:6YE)UT@.B`G=6YK;F]W
M;B<I#0H@("`@("`@("`@("`@("`@("`@+B`G/"]T9#X\+W1R/B<@+B`B7&XB
M.PT*("`@("`@("!]#0H@("`@("`@("1H=&UL("X]("<\='(^/'1D(&%L:6=N
M/2)C96YT97(B/B<@+B`H)&LK,2D@+B`G/"]T9#XG#0H@("`@("`@("`@("`@
M("`N("<\=&0^>VUA:6Y]/"]T9#XG#0H@("`@("`@("`@("`@("`N("<\=&0^
M)FYB<W`[/"]T9#X\+W1R/B<@+B`B7&XB#0H@("`@("`@("`@("`@("`N("<\
M+W1A8FQE/B<[#0H@("`@("`@(')E='5R;B`D:'1M;#L-"B`@("!]#0H-"B`@
M("!P=6)L:6,@9G5N8W1I;VX@=&]497AT*"D-"B`@("![#0H@("`@("`@("1C
M875S97,@/2!A<G)A>2@I.PT*("`@("`@("`D=&AI<RT^9V5T0V%U<V5-97-S
M86=E*"1C875S97,I.PT*("`@("`@("`D8V%U<V5-<V<@/2`G)SL-"B`@("`@
M("`@9F]R96%C:"`H)&-A=7-E<R!A<R`D:2`]/B`D8V%U<V4I('L-"B`@("`@
M("`@("`@("1C875S94US9R`N/2!S=')?<F5P96%T*"<@)RP@)&DI("X@)&-A
M=7-E6R=C;&%S<R==("X@)SH@)PT*("`@("`@("`@("`@("`@("`@("X@)&-A
M=7-E6R=M97-S86=E)UT@+B`G(&EN("<@+B`D8V%U<V5;)V9I;&4G70T*("`@
M("`@("`@("`@("`@("`@("X@)R!O;B!L:6YE("<@+B`D8V%U<V5;)VQI;F4G
M72`N(")<;B([#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1C875S94US
M9R`N("1T:&ES+3YG9714<F%C94%S4W1R:6YG*"D[#0H@("`@?0T*?0T*#0H_
M/@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O4$5!4B]&<F]N=&5N9"YP:'``````````````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q-#$W-"`Q,#4Q-30S,S<S,B`P
M,C$U,3,`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`-"B\J*@T*("H@4$5!4E]&<F]N=&5N9"P@=&AE('-I;F=L971O
M;BUB87-E9"!F<F]N=&5N9"!F;W(@=7-E<B!I;G!U="]O=71P=70-"B`J#0H@
M*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@
M<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@
M4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE
M('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@
M;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD
M(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE
M87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@
M8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T
M96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R
M("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I
M9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N
M<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@1G)O;G1E;F0N<&AP
M+'8@,2XY(#(P,#8O,#,O,#,@,3,Z,3,Z,#<@<&%J;WEE($5X<"`D#0H@*B!`
M;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*
M("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q
M+C0N,&$Q#0H@*B\-"@T*+RHJ#0H@*B!7:&EC:"!U<V5R(&EN=&5R9F%C92!C
M;&%S<R!I<R!B96EN9R!U<V5D+@T*("H@0'9A<B!S=')I;F<@8VQA<W,@;F%M
M90T*("HO#0HD1TQ/0D%,4ULG7U!%05)?1E)/3E1%3D1?0TQ!4U,G72`]("=0
M14%27T9R;VYT96YD7T-,22<[#0H-"B\J*@T*("H@26YS=&%N8V4@;V8@)%]0
M14%27T-O;6UA;F1?=6EC;&%S<RX-"B`J($!V87(@;V)J96-T#0H@*B\-"B1'
M3$]"04Q36R=?4$5!4E]&4D].5$5.1%]324Y'3$543TXG72`](&YU;&P[#0H-
M"B\J*@T*("H@4VEN9VQE=&]N+6)A<V5D(&9R;VYT96YD(&9O<B!014%2('5S
M97(@:6YP=70O;W5T<'5T#0H@*@T*("H@3F]T92!T:&%T(&9R;VYT96YD(&-L
M87-S97,@;75S="!I;7!L96UE;G0@=7-E<D-O;F9I<FTH*2P@86YD('-H;W5L
M(&EM<&QE;65N=`T*("H@9&ES<&QA>49A=&%L17)R;W(H*2!A;F0@;W5T<'5T
M1&%T82@I#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!0
M14%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN
M970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*
M("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E
M.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P
M86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S
M:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*8VQA<W,@4$5!4E]&<F]N=&5N
M9"!E>'1E;F1S(%!%05(-"GL-"B`@("`O*BH-"B`@("`@*B!2971R:65V92!T
M:&4@9G)O;G1E;F0@;V)J96-T#0H@("`@("H@0')E='5R;B!014%27T9R;VYT
M96YD7T-,27Q014%27T9R;VYT96YD7U=E8GQ014%27T9R;VYT96YD7T=T:PT*
M("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F<VEN9VQE
M=&]N*"1T>7!E(#T@;G5L;"D-"B`@("![#0H@("`@("`@(&EF("@D='EP92`]
M/3T@;G5L;"D@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D1TQ/0D%,4ULG
M7U!%05)?1E)/3E1%3D1?4TE.1TQ%5$].)UTI*2![#0H@("`@("`@("`@("`@
M("`@)&$@/2!F86QS93L-"B`@("`@("`@("`@("`@("!R971U<FX@)&$[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@)$=,3T)!3%-;)U]0
M14%27T923TY414Y$7U-)3D=,151/3B==.PT*("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@)&$@/2!014%27T9R;VYT96YD.CIS971&<F]N=&5N9$-L
M87-S*"1T>7!E*3L-"B`@("`@("`@("`@(')E='5R;B`D83L-"B`@("`@("`@
M?0T*("`@('T-"@T*("`@("\J*@T*("`@("`J(%-E="!T:&4@9G)O;G1E;F0@
M8VQA<W,@=&AA="!W:6QL(&)E('5S960@8GD@8V%L;',@=&\@>T!L:6YK('-I
M;F=L971O;B@I?0T*("`@("`J#0H@("`@("H@1G)O;G1E;F1S(&%R92!E>'!E
M8W1E9"!T;R!C;VYF;W)M('1O('1H92!014%2(&YA;6EN9R!S=&%N9&%R9"!O
M9@T*("`@("`J(%\@/3X@1$E214-43U)97U-%4$%2051/4B`H4$5!4E]&<F]N
M=&5N9%]#3$D@:7,@:6X@4$5!4B]&<F]N=&5N9"]#3$DN<&AP*0T*("`@("`J
M($!P87)A;2!S=')I;F<@)'5I8VQA<W,@9G5L;"!C;&%S<R!N86UE#0H@("`@
M("H@0')E='5R;B!014%27T9R;VYT96YD#0H@("`@("H@0'-T871I8PT*("`@
M("`J+PT*("`@(&9U;F-T:6]N("9S971&<F]N=&5N9$-L87-S*"1U:6-L87-S
M*0T*("`@('L-"B`@("`@("`@:68@*&ES7V]B:F5C="@D1TQ/0D%,4ULG7U!%
M05)?1E)/3E1%3D1?4TE.1TQ%5$].)UTI("8F#0H@("`@("`@("`@("`@(&ES
M7V$H)$=,3T)!3%-;)U]014%27T923TY414Y$7U-)3D=,151/3B==+"`D=6EC
M;&%S<RDI('L-"B`@("`@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG7U!%05)?
M1E)/3E1%3D1?4TE.1TQ%5$].)UT[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*"%C;&%S<U]E>&ES=',H)'5I8VQA<W,I*2![#0H@("`@("`@("`@("`D9FEL
M92`]('-T<E]R97!L86-E*"=?)RP@)R\G+"`D=6EC;&%S<RD@+B`G+G!H<"<[
M#0H@("`@("`@("`@("!I9B`H4$5!4E]&<F]N=&5N9#HZ:7-);F-L=61E86)L
M92@D9FEL92DI('L-"B`@("`@("`@("`@("`@("!I;F-L=61E7V]N8V4@)&9I
M;&4[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&-L
M87-S7V5X:7-T<R@D=6EC;&%S<RDI('L-"B`@("`@("`@("`@("1O8FH@/2`F
M;F5W("1U:6-L87-S.PT*("`@("`@("`@("`@+R\@<75I8VL@=&5S="!T;R!S
M964@:68@=&AI<R!C;&%S<R!I;7!L96UE;G1S(&$@9F5W(&]F('1H92!M;W-T
M#0H@("`@("`@("`@("`O+R!I;7!O<G1A;G0@9G)O;G1E;F0@;65T:&]D<PT*
M("`@("`@("`@("`@:68@*&UE=&AO9%]E>&ES=',H)&]B:BP@)W5S97)#;VYF
M:7)M)RDI('L-"B`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG7U!%05)?1E)/
M3E1%3D1?4TE.1TQ%5$].)UT@/2`F)&]B:CL-"B`@("`@("`@("`@("`@("`D
M1TQ/0D%,4ULG7U!%05)?1E)/3E1%3D1?0TQ!4U,G72`]("1U:6-L87-S.PT*
M("`@("`@("`@("`@("`@(')E='5R;B`D;V)J.PT*("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`D97)R(#T@4$5!4CHZ<F%I<V5%<G)O
M<B@B;F]T(&$@9G)O;G1E;F0@8VQA<W,Z("1U:6-L87-S(BD[#0H@("`@("`@
M("`@("`@("`@<F5T=7)N("1E<G([#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@)&5R<B`](%!%05(Z.G)A:7-E17)R;W(H(FYO('-U8V@@
M8VQA<W,Z("1U:6-L87-S(BD[#0H@("`@("`@(')E='5R;B`D97)R.PT*("`@
M('T-"@T*("`@("\J*@T*("`@("`J(%-E="!T:&4@9G)O;G1E;F0@8VQA<W,@
M=&AA="!W:6QL(&)E('5S960@8GD@8V%L;',@=&\@>T!L:6YK('-I;F=L971O
M;B@I?0T*("`@("`J#0H@("`@("H@1G)O;G1E;F1S(&%R92!E>'!E8W1E9"!T
M;R!B92!A(&1E<V-E;F1A;G0@;V8@4$5!4E]&<F]N=&5N9`T*("`@("`J($!P
M87)A;2!014%27T9R;VYT96YD#0H@("`@("H@0')E='5R;B!014%27T9R;VYT
M96YD#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T:6]N("9S
M971&<F]N=&5N9$]B:F5C="@D=6EO8FIE8W0I#0H@("`@>PT*("`@("`@("!I
M9B`H:7-?;V)J96-T*"1'3$]"04Q36R=?4$5!4E]&4D].5$5.1%]324Y'3$54
M3TXG72D@)B8-"B`@("`@("`@("`@("`@:7-?82@D1TQ/0D%,4ULG7U!%05)?
M1E)/3E1%3D1?4TE.1TQ%5$].)UTL(&=E=%]C;&%S<R@D=6EO8FIE8W0I*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N("1'3$]"04Q36R=?4$5!4E]&4D].5$5.
M1%]324Y'3$543TXG73L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES7V$H
M)'5I;V)J96-T+"`G4$5!4E]&<F]N=&5N9"<I*2![#0H@("`@("`@("`@("`D
M97)R(#T@4$5!4CHZ<F%I<V5%<G)O<B@G;F]T(&$@=F%L:60@9G)O;G1E;F0@
M8VQA<W,Z("@G("X-"B`@("`@("`@("`@("`@("!G971?8VQA<W,H)'5I;V)J
M96-T*2`N("<I)RD[#0H@("`@("`@("`@("!R971U<FX@)&5R<CL-"B`@("`@
M("`@?0T*("`@("`@("`O+R!Q=6EC:R!T97-T('1O('-E92!I9B!T:&ES(&-L
M87-S(&EM<&QE;65N=',@82!F97<@;V8@=&AE(&UO<W0-"B`@("`@("`@+R\@
M:6UP;W)T86YT(&9R;VYT96YD(&UE=&AO9',-"B`@("`@("`@:68@*&UE=&AO
M9%]E>&ES=',H)'5I;V)J96-T+"`G=7-E<D-O;F9I<FTG*2D@>PT*("`@("`@
M("`@("`@)$=,3T)!3%-;)U]014%27T923TY414Y$7U-)3D=,151/3B==(#T@
M)B1U:6]B:F5C=#L-"B`@("`@("`@("`@("1'3$]"04Q36R=?4$5!4E]&4D].
M5$5.1%]#3$%34R==(#T@9V5T7V-L87-S*"1U:6]B:F5C="D[#0H@("`@("`@
M("`@("!R971U<FX@)'5I;V)J96-T.PT*("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@)&5R<B`](%!%05(Z.G)A:7-E17)R;W(H(FYO="!A('9A;'5E
M(&9R;VYT96YD(&-L87-S.B`H(B`N(&=E=%]C;&%S<R@D=6EO8FIE8W0I#0H@
M("`@("`@("`@("`@("`@+B`G*2<I.PT*("`@("`@("`@("`@<F5T=7)N("1E
M<G([#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1P871H(')E;&%T:79E(&]R(&%B<V]L=71E(&EN8VQU9&4@
M<&%T:`T*("`@("`J($!R971U<FX@8F]O;&5A;@T*("`@("`J($!S=&%T:6,-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!I<TEN8VQU9&5A8FQE*"1P871H*0T*
M("`@('L-"B`@("`@("`@:68@*&9I;&5?97AI<W1S*"1P871H*2`F)B!I<U]R
M96%D86)L92@D<&%T:"DI('L-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*
M("`@("`@("!]#0H@("`@("`@("1I<&%T:"`](&5X<&QO9&4H4$%42%]315!!
M4D%43U(L(&EN:5]G970H)VEN8VQU9&5?<&%T:"<I*3L-"B`@("`@("`@9F]R
M96%C:"`H)&EP871H(&%S("1I;F-L=61E*2![#0H@("`@("`@("`@("`D=&5S
M="`](')E86QP871H*"1I;F-L=61E("X@1$E214-43U)97U-%4$%2051/4B`N
M("1P871H*3L-"B`@("`@("`@("`@(&EF("@A)'1E<W0I('L@+R\@<W5P<&]R
M="!W<F%P<&5R<R!L:6ME('!H87(@*')E86QP871H(&IU<W0@9&]N)W0@=V]R
M:R!W:71H('1H96TI#0H@("`@("`@("`@("`@("`@)'1E<W0@/2`D:6YC;'5D
M92`N($1)4D5#5$]265]315!!4D%43U(@+B`D<&%T:#L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D=&5S="D@)B8@:7-?
M<F5A9&%B;&4H)'1E<W0I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!014%2
M7T-O;F9I9PT*("`@("`J+PT*("`@(&9U;F-T:6]N('-E=$-O;F9I9R@F)&-O
M;F9I9RD-"B`@("![#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@5&AI<R!C
M86X@8F4@;W9E<G)I9&1E;B!T;R!A;&QO=R!S97-S:6]N+6)A<V5D('1E;7!O
M<F%R>2!F:6QE(&UA;F%G96UE;G0-"B`@("`@*@T*("`@("`J($)Y(&1E9F%U
M;'0L(&%L;"!F:6QE<R!A<F4@9&5L971E9"!A="!T:&4@96YD(&]F(&$@<V5S
M<VEO;BX@(%1H92!W96(@:6YS=&%L;&5R#0H@("`@("H@;F5E9',@=&\@8F4@
M86)L92!T;R!S=7-T86EN(&$@;&ES="!O=F5R(&UA;GD@<V5S<VEO;G,@:6X@
M;W)D97(@=&\@<W5P<&]R=`T*("`@("`J('5S97(@:6YT97)A8W1I;VX@=VET
M:"!I;G-T86QL('-C<FEP=',-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!A9&14
M96UP1FEL92@D9FEL92D-"B`@("![#0H@("`@("`@("1'3$]"04Q36R=?4$5!
M4E]#;VUM;VY?=&5M<&9I;&5S)UU;72`]("1F:6QE.PT*("`@('T-"@T*("`@
M(&9U;F-T:6]N(&QO9R@D;7-G+"`D87!P96YD7V-R;&8@/2!T<G5E*0T*("`@
M('L-"B`@("!]#0I]#0H_/@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O26YS=&%L;&5R+G!H
M<```````````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`Q-S8Q-3$@
M,3`U,34T,S,W,S(@,#(Q-C<U`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP#0HO*BH-"B`J(%!%05)?26YS=&%L;&5R
M#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%
M.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@
M;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O
M=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-
M"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y
M;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E
M;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W
M96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T
M('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*
M("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@
M0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U
M=&AO<B`@("`@5&]M87,@5BY6+B!#;W@@/&-O>$!I9&5C;F5T+F-O;3X-"B`J
M($!A=71H;W(@("`@($UA<G1I;B!*86YS96X@/&UJ0'!H<"YN970^#0H@*B!`
M875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`
M8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N
M<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0
M($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@26YS=&%L
M;&5R+G!H<"QV(#$N,C(X+C(N,2`R,#`V+S`S+S`U(#(P.C`W.C4R(&-E;&QO
M9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P
M86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I
M;F-E(%)E;&5A<V4@,"XQ#0H@*B\-"@T*+RHJ#0H@*B!5<V5D(&9O<B!I;G-T
M86QL871I;VX@9W)O=7!S(&EN('!A8VMA9V4N>&UL(#(N,"!A;F0@<&QA=&9O
M<FT@97AC97!T:6]N<PT*("HO#0IR97%U:7)E7V]N8V4@)T]3+T=U97-S+G!H
M<"<[#0IR97%U:7)E7V]N8V4@)U!%05(O1&]W;FQO861E<BYP:'`G.PT*#0ID
M969I;F4H)U!%05)?24Y35$%,3$527TY/0DE.05)9)RP@+3(T,"D[#0HO*BH-
M"B`J($%D;6EN:7-T<F%T:6]N(&-L87-S('5S960@=&\@:6YS=&%L;"!014%2
M('!A8VMA9V5S(&%N9"!M86EN=&%I;B!T:&4-"B`J(&EN<W1A;&QE9"!P86-K
M86=E(&1A=&%B87-E+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P
M86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS
M<V)`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@(%1O;6%S(%8N5BX@0V]X(#QC
M;WA`:61E8VYE="YC;VT^#0H@*B!`875T:&]R("`@("!-87)T:6X@2F%N<V5N
M(#QM:D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E
M;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!0
M2%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L
M:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@
M("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R
M+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A
M=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J+PT*8VQA<W,@4$5!4E])
M;G-T86QL97(@97AT96YD<R!014%27T1O=VYL;V%D97(-"GL-"B`@("`O+R![
M>WL@<')O<&5R=&EE<PT*#0H@("`@+RHJ(&YA;64@;V8@=&AE('!A8VMA9V4@
M9&ER96-T;W)Y+"!F;W(@97AA;7!L92!&;V\M,2XP#0H@("`@("H@0'9A<B!S
M=')I;F<-"B`@("`@*B\-"B`@("!V87(@)'!K9V1I<CL-"@T*("`@("\J*B!D
M:7)E8W1O<GD@=VAE<F4@4$A0(&-O9&4@9FEL97,@9V\-"B`@("`@*B!`=F%R
M('-T<FEN9PT*("`@("`J+PT*("`@('9A<B`D<&AP9&ER.PT*#0H@("`@+RHJ
M(&1I<F5C=&]R>2!W:&5R92!02%`@97AT96YS:6]N(&9I;&5S(&=O#0H@("`@
M("H@0'9A<B!S=')I;F<-"B`@("`@*B\-"B`@("!V87(@)&5X=&1I<CL-"@T*
M("`@("\J*B!D:7)E8W1O<GD@=VAE<F4@9&]C=6UE;G1A=&EO;B!G;V5S#0H@
M("`@("H@0'9A<B!S=')I;F<-"B`@("`@*B\-"B`@("!V87(@)&1O8V1I<CL-
M"@T*("`@("\J*B!I;G-T86QL871I;VX@<F]O="!D:7)E8W1O<GD@*&%L82!0
M2%`G<R!)3E-404Q,7U)/3U0@;W(-"B`@("`@*B!A=71O;6%K92=S($1%4U1$
M25(-"B`@("`@*B!`=F%R('-T<FEN9PT*("`@("`J+PT*("`@('9A<B`D:6YS
M=&%L;')O;W0@/2`G)SL-"@T*("`@("\J*B!D96)U9R!L979E;`T*("`@("`J
M($!V87(@:6YT#0H@("`@("HO#0H@("`@=F%R("1D96)U9R`](#$[#0H-"B`@
M("`O*BH@=&5M<&]R87)Y(&1I<F5C=&]R>0T*("`@("`J($!V87(@<W1R:6YG
M#0H@("`@("HO#0H@("`@=F%R("1T;7!D:7([#0H-"B`@("`O*BH-"B`@("`@
M*B!014%27U)E9VES=')Y(&]B:F5C="!U<V5D(&)Y('1H92!I;G-T86QL97(-
M"B`@("`@*B!`=F%R(%!%05)?4F5G:7-T<GD-"B`@("`@*B\-"B`@("!V87(@
M)')E9VES=')Y.PT*#0H@("`@+RHJ#0H@("`@("H@87)R87D@;V8@4$5!4E]$
M;W=N;&]A9&5R7U!A8VMA9V5S#0H@("`@("H@0'9A<B!A<G)A>0T*("`@("`J
M+PT*("`@('9A<B`D7V1O=VYL;V%D961086-K86=E<SL-"@T*("`@("\J*B!,
M:7-T(&]F(&9I;&4@=')A;G-A8W1I;VYS('%U975E9"!F;W(@86X@:6YS=&%L
M;"]U<&=R861E+W5N:6YS=&%L;"X-"B`@("`@*@T*("`@("`J("!&;W)M870Z
M#0H@("`@("H@("`@87)R87DH#0H@("`@("H@("`@("`P(#T^(&%R<F%Y*")R
M96YA;64@/3X@87)R87DH(F9R;VTM9FEL92(L(")T;RUF:6QE(BDI+`T*("`@
M("`J("`@("`@,2`]/B!A<G)A>2@B9&5L971E(B`]/B!A<G)A>2@B9FEL92UT
M;RUD96QE=&4B*2DL#0H@("`@("H@("`@("`N+BX-"B`@("`@*B`@("`I#0H@
M("`@("H-"B`@("`@*B!`=F%R(&%R<F%Y#0H@("`@("HO#0H@("`@=F%R("1F
M:6QE7V]P97)A=&EO;G,@/2!A<G)A>2@I.PT*#0H@("`@+R\@?7U]#0H-"B`@
M("`O+R![>WL@8V]N<W1R=6-T;W(-"@T*("`@("\J*@T*("`@("`J(%!%05)?
M26YS=&%L;&5R(&-O;G-T<G5C=&]R+@T*("`@("`J#0H@("`@("H@0'!A<F%M
M(&]B:F5C="`D=6D@=7-E<B!I;G1E<F9A8V4@;V)J96-T("AI;G-T86YC92!O
M9B!014%27T9R;VYT96YD7RHI#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U
M8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(%!%05)?26YS=&%L;&5R*"8D
M=6DI#0H@("`@>PT*("`@("`@("!P87)E;G0Z.E!%05)?0V]M;6]N*"D[#0H@
M("`@("`@("1T:&ES+3YS971&<F]N=&5N9$]B:F5C="@D=6DI.PT*("`@("`@
M("`D=&AI<RT^9&5B=6<@/2`D=&AI<RT^8V]N9FEG+3YG970H)W9E<F)O<V4G
M*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!S971/<'1I;VYS*"1O<'1I;VYS
M*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]O<'1I;VYS(#T@)&]P=&EO;G,[
M#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T0V]N9FEG*"8D8V]N9FEG*0T*
M("`@('L-"B`@("`@("`@)'1H:7,M/F-O;F9I9R`]("8D8V]N9FEG.PT*("`@
M("`@("`D=&AI<RT^7W)E9VES=')Y(#T@)B1C;VYF:6<M/F=E=%)E9VES=')Y
M*"D[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-"B`@("!F=6YC=&EO;B!?<F5M
M;W9E0F%C:W5P<R@D9FEL97,I#0H@("`@>PT*("`@("`@("!F;W)E86-H("@D
M9FEL97,@87,@)'!A=&@I('L-"B`@("`@("`@("`@("1T:&ES+3YA9&1&:6QE
M3W!E<F%T:6]N*"=R96UO=F5B86-K=7`G+"!A<G)A>2@D<&%T:"DI.PT*("`@
M("`@("!]#0H@("`@?0T*#0H@("`@+R\@>WM[(%]D96QE=&5086-K86=E1FEL
M97,H*0T*#0H@("`@+RHJ#0H@("`@("H@1&5L971E(&$@<&%C:V%G92=S(&EN
M<W1A;&QE9"!F:6QE<RP@9&]E<R!N;W0@<F5M;W9E(&5M<'1Y(&1I<F5C=&]R
M:65S+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R!P86-K86=E(&YA
M;64-"B`@("`@*B!`<&%R86T@<W1R:6YG(&-H86YN96P@;F%M90T*("`@("`J
M($!P87)A;2!B;V]L(&EF('1R=64L('1H96X@9FEL97,@87)E(&)A8VME9"!U
M<"!F:7)S=`T*("`@("`J($!R971U<FX@8F]O;"!44E5%(&]N('-U8V-E<W,L
M(&]R(&$@4$5!4B!E<G)O<B!O;B!F86EL=7)E#0H@("`@("H@0&%C8V5S<R!P
M<F]T96-T960-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?9&5L971E4&%C:V%G
M949I;&5S*"1P86-K86=E+"`D8VAA;FYE;"`](&9A;'-E+"`D8F%C:W5P(#T@
M9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H(21C:&%N;F5L*2![#0H@("`@
M("`@("`@("`D8VAA;FYE;"`]("=P96%R+G!H<"YN970G.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("@A<W1R;&5N*"1P86-K86=E*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*").;R!P86-K86=E('1O('5N
M:6YS=&%L;"!G:79E;B(I.PT*("`@("`@("!]#0H@("`@("`@(&EF("AS=')T
M;VQO=V5R*"1P86-K86=E*2`]/2`G<&5A<B<@)B8@)&-H86YN96P@/3T@)W!E
M87(N<&AP+FYE="<I('L-"B`@("`@("`@("`@("\O('1O(&%V;VED(')A8V4@
M8V]N9&ET:6]N<RP@:6YC;'5D92!A;&P@<&]S<VEB;&4@;F5E9&5D(&9I;&5S
M#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O5&%S:R]#;VUM;VXN
M<&AP)SL-"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]487-K+U)E
M<&QA8V4N<&AP)SL-"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]4
M87-K+U5N:7AE;VPN<&AP)SL-"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G
M4$5!4B]487-K+U=I;F1O=W-E;VPN<&AP)SL-"B`@("`@("`@("`@(')E<75I
M<F5?;VYC92`G4$5!4B]086-K86=E1FEL92]V,2YP:'`G.PT*("`@("`@("`@
M("`@<F5Q=6ER95]O;F-E("=014%2+U!A8VMA9V5&:6QE+W8R+G!H<"<[#0H@
M("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O4&%C:V%G949I;&4O1V5N
M97)A=&]R+W8Q+G!H<"<[#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%
M05(O4&%C:V%G949I;&4O1V5N97)A=&]R+W8R+G!H<"<[#0H@("`@("`@('T-
M"B`@("`@("`@)&9I;&5L:7-T(#T@)'1H:7,M/E]R96=I<W1R>2T^<&%C:V%G
M94EN9F\H)'!A8VMA9V4L("=F:6QE;&ES="<L("1C:&%N;F5L*3L-"B`@("`@
M("`@:68@*"1F:6QE;&ES="`]/2!N=6QL*2![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H(B1C:&%N;F5L+R1P86-K86=E(&YO="!I
M;G-T86QL960B*3L-"B`@("`@("`@?0T*("`@("`@("`D<F5T(#T@87)R87DH
M*3L-"B`@("`@("`@9F]R96%C:"`H)&9I;&5L:7-T(&%S("1F:6QE(#T^("1P
M<F]P<RD@>PT*("`@("`@("`@("`@:68@*&5M<'1Y*"1P<F]P<ULG:6YS=&%L
M;&5D7V%S)UTI*2![#0H@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`D<&%T:"`]("1P<F]P<ULG:6YS=&%L
M;&5D7V%S)UT[#0H@("`@("`@("`@("!I9B`H)&)A8VMU<"D@>PT*("`@("`@
M("`@("`@("`@("1T:&ES+3YA9&1&:6QE3W!E<F%T:6]N*"=B86-K=7`G+"!A
M<G)A>2@D<&%T:"DI.PT*("`@("`@("`@("`@("`@("1R971;72`]("1P871H
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'1H:7,M/F%D9$9I;&5/
M<&5R871I;VXH)V1E;&5T92<L(&%R<F%Y*"1P871H*2D[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"1B86-K=7`I('L-"B`@("`@("`@("`@(')E='5R;B`D
M<F5T.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-
M"@T*("`@("\O('U]?0T*("`@("\O('M[>R!?:6YS=&%L;$9I;&4H*0T*#0H@
M("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9R!F:6QE;F%M90T*("`@("`J
M($!P87)A;2!A<G)A>2!A='1R:6)U=&5S(&9R;VT@/&9I;&4^('1A9R!I;B!P
M86-K86=E+GAM;`T*("`@("`J($!P87)A;2!S=')I;F<@<&%T:"!T;R!I;G-T
M86QL('1H92!F:6QE(&EN#0H@("`@("H@0'!A<F%M(&%R<F%Y(&]P=&EO;G,@
M9G)O;2!C;VUM86YD+6QI;F4-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!?:6YS=&%L;$9I;&4H)&9I;&4L("1A='1S
M+"`D=&UP7W!A=&@L("1O<'1I;VYS*0T*("`@('L-"B`@("`@("`@+R\@>WM[
M(')E='5R;B!I9B!T:&ES(&9I;&4@:7,@;65A;G0@9F]R(&%N;W1H97(@<&QA
M=&9O<FT-"B`@("`@("`@<W1A=&EC("1O<SL-"B`@("`@("`@:68@*"%I<W-E
M="@D=&AI<RT^7W)E9VES=')Y*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]R
M96=I<W1R>2`]("8D=&AI<RT^8V]N9FEG+3YG971296=I<W1R>2@I.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D871T<ULG<&QA=&9O<FTG72DI
M('L-"B`@("`@("`@("`@(&EF("AE;7!T>2@D;W,I*2![#0H@("`@("`@("`@
M("`@("`@)&]S(#T@;F5W($]37T=U97-S*"D[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!I9B`H<W1R;&5N*"1A='1S6R=P;&%T9F]R;2==*2`F)B`D
M871T<ULG<&QA=&9O<FTG77LP?2`]/2`G(2<I('L-"B`@("`@("`@("`@("`@
M("`D;F5G871E(#T@=')U93L-"B`@("`@("`@("`@("`@("`D<&QA=&9O<FT@
M/2!S=6)S='(H)&%T='-;)W!L871F;W)M)UTL(#$I.PT*("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D;F5G871E(#T@9F%L<V4[#0H@
M("`@("`@("`@("`@("`@)'!L871F;W)M(#T@)&%T='-;)W!L871F;W)M)UT[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H*&)O;VPI("1O<RT^
M;6%T8VA3:6=N871U<F4H)'!L871F;W)M*2`]/3T@)&YE9V%T92D@>PT*("`@
M("`@("`@("`@("`@("1T:&ES+3YL;V<H,RP@(G-K:7!P960@)&9I;&4@*&UE
M86YT(&9O<B`D871T<UMP;&%T9F]R;5TL('=E(&%R92`B+B1O<RT^9V5T4VEG
M;F%T=7)E*"DN(BDB*3L-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4E])
M3E-404Q,15)?4TM)4%!%1#L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("`O+R!]?7T-"@T*("`@("`@("`D8VAA;FYE;"`]("1T:&ES+3YP
M:V=I;F9O+3YG971#:&%N;F5L*"D[#0H@("`@("`@("\O('M[>R!A<W-E;6)L
M92!T:&4@9&5S=&EN871I;VX@<&%T:',-"B`@("`@("`@<W=I=&-H("@D871T
M<ULG<F]L92==*2![#0H@("`@("`@("`@("!C87-E("=D;V,G.@T*("`@("`@
M("`@("`@8V%S92`G9&%T82<Z#0H@("`@("`@("`@("!C87-E("=T97-T)SH-
M"B`@("`@("`@("`@("`@("`D9&5S=%]D:7(@/2`D=&AI<RT^8V]N9FEG+3YG
M970H)&%T='-;)W)O;&4G72`N("=?9&ER)RP@;G5L;"P@)&-H86YN96PI("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!$25)%0U1/4EE?4T5005)!
M5$]2("X@)'1H:7,M/G!K9VEN9F\M/F=E=%!A8VMA9V4H*3L-"B`@("`@("`@
M("`@("`@("!U;G-E="@D871T<ULG8F%S96EN<W1A;&QD:7(G72D[#0H@("`@
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=E>'0G.@T*
M("`@("`@("`@("`@8V%S92`G<&AP)SH-"B`@("`@("`@("`@("`@("`D9&5S
M=%]D:7(@/2`D=&AI<RT^8V]N9FEG+3YG970H)&%T='-;)W)O;&4G72`N("=?
M9&ER)RP@;G5L;"P@)&-H86YN96PI.PT*("`@("`@("`@("`@("`@(&)R96%K
M.PT*("`@("`@("`@("`@8V%S92`G<V-R:7!T)SH-"B`@("`@("`@("`@("`@
M("`D9&5S=%]D:7(@/2`D=&AI<RT^8V]N9FEG+3YG970H)V)I;E]D:7(G+"!N
M=6QL+"`D8VAA;FYE;"D[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@
M("`@("`@("!C87-E("=S<F,G.@T*("`@("`@("`@("`@8V%S92`G97AT<W)C
M)SH-"B`@("`@("`@("`@("`@("`D=&AI<RT^<V]U<F-E7V9I;&5S*RL[#0H@
M("`@("`@("`@("`@("`@<F5T=7)N.PT*("`@("`@("`@("`@9&5F875L=#H-
M"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(DEN
M=F%L:60@<F]L92!@)&%T='-;<F]L95TG(&9O<B!F:6QE("1F:6QE(BD[#0H@
M("`@("`@('T-"B`@("`@("`@)'-A=F5?9&5S=&1I<B`]("1D97-T7V1I<CL-
M"B`@("`@("`@:68@*"%E;7!T>2@D871T<ULG8F%S96EN<W1A;&QD:7(G72DI
M('L-"B`@("`@("`@("`@("1D97-T7V1I<B`N/2!$25)%0U1/4EE?4T5005)!
M5$]2("X@)&%T='-;)V)A<V5I;G-T86QL9&ER)UT[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*&1I<FYA;64H)&9I;&4I("$]("<N)R`F)B!E;7!T>2@D871T
M<ULG:6YS=&%L;"UA<R==*2D@>PT*("`@("`@("`@("`@)&1E<W1?9&ER("X]
M($1)4D5#5$]265]315!!4D%43U(@+B!D:7)N86UE*"1F:6QE*3L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H96UP='DH)&%T='-;)VEN<W1A;&PM87,G72DI
M('L-"B`@("`@("`@("`@("1D97-T7V9I;&4@/2`D9&5S=%]D:7(@+B!$25)%
M0U1/4EE?4T5005)!5$]2("X@8F%S96YA;64H)&9I;&4I.PT*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@)&1E<W1?9FEL92`]("1D97-T7V1I<B`N
M($1)4D5#5$]265]315!!4D%43U(@+B`D871T<ULG:6YS=&%L;"UA<R==.PT*
M("`@("`@("!]#0H@("`@("`@("1O<FEG7V9I;&4@/2`D=&UP7W!A=&@@+B!$
M25)%0U1/4EE?4T5005)!5$]2("X@)&9I;&4[#0H-"B`@("`@("`@+R\@0VQE
M86X@=7`@=&AE($1)4D5#5$]265]315!!4D%43U(@;65S<PT*("`@("`@("`D
M9',R(#T@1$E214-43U)97U-%4$%2051/4B`N($1)4D5#5$]265]315!!4D%4
M3U([#0H@("`@("`@(&QI<W0H)&1E<W1?9FEL92P@)&]R:6=?9FEL92D@/2!P
M<F5G7W)E<&QA8V4H87)R87DH)R%<7%Q<*R$G+"`G(2\A)RP@(B$D9',R*R$B
M*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2A$25)%0U1/4EE?4T5005)!5$]2+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@($1)4D5#5$]265]315!!4D%43U(L#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1$E2
M14-43U)97U-%4$%2051/4BDL#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)&1E<W1?9FEL92P@
M)&]R:6=?9FEL92DI.PT*("`@("`@("`D9FEN86Q?9&5S=%]F:6QE(#T@)&EN
M<W1A;&QE9%]A<R`]("1D97-T7V9I;&4[#0H@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7V]P=&EO;G-;)W!A8VMA9VEN9W)O;W0G72DI('L-"B`@("`@("`@
M("`@("1I;G-T86QL961A<U]D97-T7V1I<B`](&1I<FYA;64H)&9I;F%L7V1E
M<W1?9FEL92D[#0H@("`@("`@("`@("`D:6YS=&%L;&5D87-?9&5S=%]F:6QE
M(#T@)&1E<W1?9&ER("X@1$E214-43U)97U-%4$%2051/4B`N("<N=&UP)R`N
M(&)A<V5N86UE*"1F:6YA;%]D97-T7V9I;&4I.PT*("`@("`@("`@("`@)&9I
M;F%L7V1E<W1?9FEL92`]("1T:&ES+3Y?<')E<&5N9%!A=&@H)&9I;F%L7V1E
M<W1?9FEL92P-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V]P=&EO;G-;)W!A
M8VMA9VEN9W)O;W0G72D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`D:6YS=&%L;&5D87-?9&5S=%]D:7(@/2!D:7)N86UE*"1F:6YA;%]D97-T
M7V9I;&4I.PT*("`@("`@("`@("`@)&EN<W1A;&QE9&%S7V1E<W1?9FEL92`]
M("1I;G-T86QL961A<U]D97-T7V1I<B`N($1)4D5#5$]265]315!!4D%43U(@
M+B`G+G1M<"<@+B!B87-E;F%M92@D9FEN86Q?9&5S=%]F:6QE*3L-"B`@("`@
M("`@?0T*("`@("`@("`D9&5S=%]D:7(@/2!D:7)N86UE*"1F:6YA;%]D97-T
M7V9I;&4I.PT*("`@("`@("`D9&5S=%]F:6QE(#T@)&1E<W1?9&ER("X@1$E2
M14-43U)97U-%4$%2051/4B`N("<N=&UP)R`N(&)A<V5N86UE*"1F:6YA;%]D
M97-T7V9I;&4I.PT*("`@("`@("`O+R!]?7T-"@T*("`@("`@("!I9B`H96UP
M='DH)'1H:7,M/E]O<'1I;VYS6R=R96=I<W1E<BUO;FQY)UTI("8F("%`:7-?
M9&ER*"1D97-T7V1I<BDI('L-"B`@("`@("`@("`@(&EF("@A)'1H:7,M/FUK
M1&ER2&EE<B@D9&5S=%]D:7(I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*")F86EL960@=&\@;6MD:7(@)&1E<W1?9&ER
M(BP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M4$5!4E])3E-404Q,15)?1D%)3$5$*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("1T:&ES+3YL;V<H,RP@(BL@;6MD:7(@)&1E<W1?9&ER(BD[#0H@
M("`@("`@('T-"B`@("`@("`@+R\@<')E='1Y(&UU8V@@;F]T:&EN9R!H87!P
M96YS(&EF('=E(&%R92!O;FQY(')E9VES=&5R:6YG('1H92!I;G-T86QL#0H@
M("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7V]P=&EO;G-;)W)E9VES=&5R+6]N
M;'DG72DI('L-"B`@("`@("`@("`@(&EF("AE;7!T>2@D871T<ULG<F5P;&%C
M96UE;G1S)UTI*2![#0H@("`@("`@("`@("`@("`@:68@*"%F:6QE7V5X:7-T
M<R@D;W)I9U]F:6QE*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H(F9I;&4@)&]R:6=?9FEL92!D;V5S(&YO="!E
M>&ES="(L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!014%27TE.4U1!3$Q%4E]&04E,140I.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!I9B`H(4!C;W!Y*"1O<FEG7V9I;&4L
M("1D97-T7V9I;&4I*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@B9F%I;&5D('1O('=R:71E("1D97-T7V9I;&4B
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@4$5!4E])3E-404Q,15)?1D%)3$5$*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@S+"`B*R!C<"`D;W)I9U]F
M:6QE("1D97-T7V9I;&4B*3L-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)&%T='-;)VUD-7-U;2==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D;60U
M<W5M(#T@;60U7V9I;&4H)&1E<W1?9FEL92D[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`O+R![
M>WL@9FEL92!W:71H(')E<&QA8V5M96YT<PT*("`@("`@("`@("`@("`@(&EF
M("@A9FEL95]E>&ES=',H)&]R:6=?9FEL92DI('L-"B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")F:6QE(&1O97,@;F]T
M(&5X:7-T(BP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%!%05)?24Y35$%,3$527T9!24Q%1"D[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H
M)V9I;&5?9V5T7V-O;G1E;G1S)RDI('L-"B`@("`@("`@("`@("`@("`@("`@
M)&-O;G1E;G1S(#T@9FEL95]G971?8V]N=&5N=',H)&]R:6=?9FEL92D[#0H@
M("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@
M)&9P(#T@9F]P96XH)&]R:6=?9FEL92P@(G(B*3L-"B`@("`@("`@("`@("`@
M("`@("`@)&-O;G1E;G1S(#T@0&9R96%D*"1F<"P@9FEL97-I>F4H)&]R:6=?
M9FEL92DI.PT*("`@("`@("`@("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"1C;VYT96YT
M<R`]/3T@9F%L<V4I('L-"B`@("`@("`@("`@("`@("`@("`@)&-O;G1E;G1S
M(#T@)R<[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D871T<ULG;60U<W5M)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("1M9#5S=6T@/2!M9#4H)&-O;G1E;G1S*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@)'-U8G-T7V9R;VT@/2`D<W5B<W1?=&\@
M/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1A='1S6R=R
M97!L86-E;65N=',G72!A<R`D82D@>PT*("`@("`@("`@("`@("`@("`@("`D
M=&\@/2`G)SL-"B`@("`@("`@("`@("`@("`@("`@:68@*"1A6R=T>7!E)UT@
M/3T@)W!H<"UC;VYS="<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("AP<F5G7VUA=&-H*"<O7EMA+7HP+3E?72LD+VDG+"`D85LG=&\G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!E=F%L*")<)'1O(#T@)&%;
M=&]=.R(I.PT*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS
M6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YL;V<H,"P@(FEN=F%L:60@<&AP+6-O;G-T(')E<&QA8V5M96YT
M.B`D85MT;UTB*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T@96QS
M96EF("@D85LG='EP92==(#T]("=P96%R+6-O;F9I9R<I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@D85LG=&\G72`]/2`G;6%S=&5R7W-E<G9E
M<B<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8VAA;B`]("1T
M:&ES+3Y?<F5G:7-T<GDM/F=E=$-H86YN96PH)&-H86YN96PI.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@A4$5!4CHZ:7-%<G)O<B@D8VAA
M;BDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1O(#T@
M)&-H86XM/F=E=%-E<G9E<B@I.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T;R`]("1T:&ES+3YC;VYF:6<M/F=E="@D85LG=&\G72P@;G5L;"P@)&-H
M86YN96PI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1O(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"1A6R=T;R==
M+"!N=6QL+"`D8VAA;FYE;"D[#0H@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-?;G5L;"@D=&\I*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T
M:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^;&]G*#`L(")I;G9A;&ED('!E87(M8V]N9FEG(')E<&QA
M8V5M96YT.B`D85MT;UTB*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M('T@96QS96EF("@D85LG='EP92==(#T]("=P86-K86=E+6EN9F\G*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'0@/2`D=&AI<RT^<&MG:6YF
M;RT^<&%C:V%G94EN9F\H)&%;)W1O)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1O(#T@)'0[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A
M:7-S970H)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`B:6YV86QI9"!P86-K86=E
M+6EN9F\@<F5P;&%C96UE;G0Z("1A6W1O72(I.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!C
M;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES7VYU
M;&PH)'1O*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'-U8G-T7V9R
M;VU;72`]("1A6R=F<F]M)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M<W5B<W1?=&];72`]("1T;SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#,L
M(")D;VEN9R`B+G-I>F5O9B@D<W5B<W1?9G)O;2DN(B!S=6)S=&ET=71I;VXH
M<RD@9F]R("1F:6YA;%]D97-T7V9I;&4B*3L-"B`@("`@("`@("`@("`@("!I
M9B`H<VEZ96]F*"1S=6)S=%]F<F]M*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`D8V]N=&5N=',@/2!S=')?<F5P;&%C92@D<W5B<W1?9G)O;2P@)'-U8G-T
M7W1O+"`D8V]N=&5N=',I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`D=W`@/2!`9F]P96XH)&1E<W1?9FEL92P@(G=B(BD[#0H@("`@
M("`@("`@("`@("`@:68@*"%I<U]R97-O=7)C92@D=W`I*2![#0H@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B9F%I;&5D
M('1O(&-R96%T92`D9&5S=%]F:6QE.B`D<&AP7V5R<F]R;7-G(BP-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?
M24Y35$%,3$527T9!24Q%1"D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(&EF("AF=W)I=&4H)'=P+"`D8V]N=&5N=',I(#T]/2!F86QS
M92D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H(F9A:6QE9"!W<FET:6YG('1O("1D97-T7V9I;&4Z("1P:'!?97)R
M;W)M<V<B+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@4$5!4E])3E-404Q,15)?1D%)3$5$*3L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@9F-L;W-E*"1W<"D[#0H@("`@("`@
M("`@("`@("`@+R\@?7U]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`O
M+R![>WL@8VAE8VL@=&AE(&UD-0T*("`@("`@("`@("`@:68@*&ES<V5T*"1M
M9#5S=6TI*2![#0H@("`@("`@("`@("`@("`@:68@*'-T<G1O;&]W97(H)&UD
M-7-U;2D@/3T@<W1R=&]L;W=E<B@D871T<ULG;60U<W5M)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,BP@(FUD-7-U;2!O:SH@)&9I
M;F%L7V1E<W1?9FEL92(I.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D;W!T:6]N<ULG9F]R8V4G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("\O(&1E;&5T92!T:&4@
M9FEL90T*("`@("`@("`@("`@("`@("`@("`@("`@0'5N;&EN:R@D9&5S=%]F
M:6QE*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&]P
M=&EO;G-;)VEG;F]R92UE<G)O<G,G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F)A9"!M9#5S
M=6T@9F]R(&9I;&4@)&9I;F%L7V1E<W1?9FEL92(L#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E])3E-4
M04Q,15)?1D%)3$5$*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^;&]G*#`L(")W87)N:6YG(#H@8F%D(&UD-7-U;2!F
M;W(@9FEL92`D9FEN86Q?9&5S=%]F:6QE(BD[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,"P@(G=A<FYI;F<@
M.B!B860@;60U<W5M(&9O<B!F:6QE("1F:6YA;%]D97-T7V9I;&4B*3L-"B`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("\O('U]?0T*("`@("`@("`@("`@+R\@>WM[('-E="!F:6QE('!E<FUI
M<W-I;VYS#0H@("`@("`@("`@("!I9B`H(4]37U=)3D1/5U,I('L-"B`@("`@
M("`@("`@("`@("!I9B`H)&%T='-;)W)O;&4G72`]/2`G<V-R:7!T)RD@>PT*
M("`@("`@("`@("`@("`@("`@("`D;6]D92`](#`W-S<@)B!^*&EN="EO8W1D
M96,H)'1H:7,M/F-O;F9I9RT^9V5T*"=U;6%S:R<I*3L-"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/FQO9R@S+"`B*R!C:&UO9"`K>"`D9&5S=%]F:6QE
M(BD[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@)&UO9&4@/2`P-C8V("8@?BAI;G0I;V-T9&5C*"1T:&ES+3YC;VYF
M:6<M/F=E="@G=6UA<VLG*2D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("1T:&ES+3YA9&1&:6QE3W!E<F%T:6]N*")C:&UO9"(L(&%R
M<F%Y*"1M;V1E+"`D9&5S=%]F:6QE*2D[#0H@("`@("`@("`@("`@("`@:68@
M*"%`8VAM;V0H)&1E<W1?9FEL92P@)&UO9&4I*2![#0H@("`@("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,"P@(F9A:6QE9"!T;R!C
M:&%N9V4@;6]D92!O9B`D9&5S=%]F:6QE(BD[#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`O+R!]?7T-"B`@("`@("`@("`@("1T:&ES+3YA9&1&:6QE3W!E
M<F%T:6]N*")R96YA;64B+"!A<G)A>2@D9&5S=%]F:6QE+"`D9FEN86Q?9&5S
M=%]F:6QE+`T*("`@("`@("`@("`@("`@("1A='1S6R=R;VQE)UT@/3T@)V5X
M="<I*3L-"B`@("`@("`@?0T*("`@("`@("`O+R!3=&]R92!T:&4@9G5L;"!P
M871H('=H97)E('1H92!F:6QE('=A<R!I;G-T86QL960@9F]R(&5A<WD@=6YI
M<W1A;&P-"B`@("`@("`@)'1H:7,M/F%D9$9I;&5/<&5R871I;VXH(FEN<W1A
M;&QE9%]A<R(L(&%R<F%Y*"1F:6QE+"`D:6YS=&%L;&5D7V%S+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<V%V95]D97-T9&ER+"!D:7)N
M86UE*'-U8G-T<B@D:6YS=&%L;&5D87-?9&5S=%]F:6QE+"!S=')L96XH)'-A
M=F5?9&5S=&1I<BDI*2DI.PT*#0H@("`@("`@("\O)'1H:7,M/FQO9R@R+"`B
M:6YS=&%L;&5D.B`D9&5S=%]F:6QE(BD[#0H@("`@("`@(')E='5R;B!014%2
M7TE.4U1!3$Q%4E]/2SL-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![
M>WL@7VEN<W1A;&Q&:6QE,B@I#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@
M4$5!4E]086-K86=E1FEL95]V,7Q014%27U!A8VMA9V5&:6QE7W8R#0H@("`@
M("H@0'!A<F%M('-T<FEN9R!F:6QE;F%M90T*("`@("`J($!P87)A;2!A<G)A
M>2!A='1R:6)U=&5S(&9R;VT@/&9I;&4^('1A9R!I;B!P86-K86=E+GAM;`T*
M("`@("`J($!P87)A;2!S=')I;F<@<&%T:"!T;R!I;G-T86QL('1H92!F:6QE
M(&EN#0H@("`@("H@0'!A<F%M(&%R<F%Y(&]P=&EO;G,@9G)O;2!C;VUM86YD
M+6QI;F4-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!?:6YS=&%L;$9I;&4R*"8D<&MG+"`D9FEL92P@)&%T=',L("1T
M;7!?<&%T:"P@)&]P=&EO;G,I#0H@("`@>PT*("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?<F5G:7-T<GDI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W)E
M9VES=')Y(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@
M("`@('T-"@T*("`@("`@("`D8VAA;FYE;"`]("1P:V<M/F=E=$-H86YN96PH
M*3L-"B`@("`@("`@+R\@>WM[(&%S<V5M8FQE('1H92!D97-T:6YA=&EO;B!P
M871H<PT*("`@("`@("!I9B`H(6EN7V%R<F%Y*"1A='1S6R=A='1R:6)S)UU;
M)W)O;&4G72P-"B`@("`@("`@("`@("`@4$5!4E]);G-T86QL97)?4F]L93HZ
M9V5T5F%L:612;VQE<R@D<&MG+3YG971086-K86=E5'EP92@I*2DI('L-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G26YV86QI9"!R
M;VQE(&`G("X@)&%T='-;)V%T=')I8G,G75LG<F]L92==("X-"B`@("`@("`@
M("`@("`@("`@("`@(B<@9F]R(&9I;&4@)&9I;&4B*3L-"B`@("`@("`@?0T*
M("`@("`@("`D<F]L92`]("9014%27TEN<W1A;&QE<E]2;VQE.CIF86-T;W)Y
M*"1P:V<L("1A='1S6R=A='1R:6)S)UU;)W)O;&4G72P@)'1H:7,M/F-O;F9I
M9RD[#0H@("`@("`@("1E<G(@/2`D<F]L92T^<V5T=7`H)'1H:7,L("1P:V<L
M("1A='1S6R=A='1R:6)S)UTL("1F:6QE*3L-"B`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)&5R<BDI('L-"B`@("`@("`@("`@(')E='5R;B`D97)R.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("@A)')O;&4M/FES26YS=&%L;&%B;&4H
M*2D@>PT*("`@("`@("`@("`@<F5T=7)N.PT*("`@("`@("!]#0H@("`@("`@
M("1I;F9O(#T@)')O;&4M/G!R;V-E<W-);G-T86QL871I;VXH)'!K9RP@)&%T
M='-;)V%T=')I8G,G72P@)&9I;&4L("1T;7!?<&%T:"D[#0H@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1I;F9O*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M("1I;F9O.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@;&ES="@D
M<V%V95]D97-T9&ER+"`D9&5S=%]D:7(L("1D97-T7V9I;&4L("1O<FEG7V9I
M;&4I(#T@)&EN9F\[#0H@("`@("`@('T-"B`@("`@("`@)&9I;F%L7V1E<W1?
M9FEL92`]("1I;G-T86QL961?87,@/2`D9&5S=%]F:6QE.PT*("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/E]O<'1I;VYS6R=P86-K86=I;F=R;V]T)UTI*2![
M#0H@("`@("`@("`@("`D9FEN86Q?9&5S=%]F:6QE(#T@)'1H:7,M/E]P<F5P
M96YD4&%T:"@D9FEN86Q?9&5S=%]F:6QE+`T*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?;W!T:6]N<ULG<&%C:V%G:6YG<F]O="==*3L-"B`@("`@("`@?0T*
M("`@("`@("`D9&5S=%]D:7(@/2!D:7)N86UE*"1F:6YA;%]D97-T7V9I;&4I
M.PT*("`@("`@("`D9&5S=%]F:6QE(#T@)&1E<W1?9&ER("X@1$E214-43U)9
M7U-%4$%2051/4B`N("<N=&UP)R`N(&)A<V5N86UE*"1F:6YA;%]D97-T7V9I
M;&4I.PT*("`@("`@("`O+R!]?7T-"@T*("`@("`@("!I9B`H96UP='DH)'1H
M:7,M/E]O<'1I;VYS6R=R96=I<W1E<BUO;FQY)UTI*2![#0H@("`@("`@("`@
M("!I9B`H(4!I<U]D:7(H)&1E<W1?9&ER*2D@>PT*("`@("`@("`@("`@("`@
M(&EF("@A)'1H:7,M/FUK1&ER2&EE<B@D9&5S=%]D:7(I*2![#0H@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B9F%I;&5D
M('1O(&UK9&ER("1D97-T7V1I<B(L#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!014%27TE.4U1!3$Q%4E]&04E,140I
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D=&AI<RT^
M;&]G*#,L("(K(&UK9&ER("1D97-T7V1I<B(I.PT*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@("1A='1R:6)S(#T@)&%T='-;)V%T=')I8G,G
M73L-"B`@("`@("`@=6YS970H)&%T='-;)V%T=')I8G,G72D[#0H@("`@("`@
M("\O('!R971T>2!M=6-H(&YO=&AI;F<@:&%P<&5N<R!I9B!W92!A<F4@;VYL
M>2!R96=I<W1E<FEN9R!T:&4@:6YS=&%L;`T*("`@("`@("!I9B`H96UP='DH
M)'1H:7,M/E]O<'1I;VYS6R=R96=I<W1E<BUO;FQY)UTI*2![#0H@("`@("`@
M("`@("!I9B`H(6-O=6YT*"1A='1S*2D@>R`O+R!N;R!T87-K<PT*("`@("`@
M("`@("`@("`@(&EF("@A9FEL95]E>&ES=',H)&]R:6=?9FEL92DI('L-"B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")F
M:6QE("1O<FEG7V9I;&4@9&]E<R!N;W0@97AI<W0B+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E])3E-404Q,
M15)?1D%)3$5$*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@:68@*"%`8V]P>2@D;W)I9U]F:6QE+"`D9&5S=%]F:6QE*2D@>PT*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F9A
M:6QE9"!T;R!W<FET92`D9&5S=%]F:6QE(BP-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?24Y35$%,3$527T9!
M24Q%1"D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1T
M:&ES+3YL;V<H,RP@(BL@8W`@)&]R:6=?9FEL92`D9&5S=%]F:6QE(BD[#0H@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A='1R:6)S6R=M9#5S=6TG72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@)&UD-7-U;2`](&UD-5]F:6QE*"1D
M97-T7V9I;&4I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T@
M96QS92![("\O(&9I;&4@=VET:"!T87-K<PT*("`@("`@("`@("`@("`@(&EF
M("@A9FEL95]E>&ES=',H)&]R:6=?9FEL92DI('L-"B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")F:6QE("1O<FEG7V9I
M;&4@9&]E<R!N;W0@97AI<W0B+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@4$5!4E])3E-404Q,15)?1D%)3$5$*3L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&9U;F-T
M:6]N7V5X:7-T<R@G9FEL95]G971?8V]N=&5N=',G*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`D8V]N=&5N=',@/2!F:6QE7V=E=%]C;VYT96YT<R@D;W)I
M9U]F:6QE*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@("`D9G`@/2!F;W!E;B@D;W)I9U]F:6QE+"`B<B(I.PT*("`@
M("`@("`@("`@("`@("`@("`D8V]N=&5N=',@/2!`9G)E860H)&9P+"!F:6QE
M<VEZ92@D;W)I9U]F:6QE*2D[("\O(&9I;&5S:7IE(&-A;B!B92`P#0H@("`@
M("`@("`@("`@("`@("`@(&9C;&]S92@D9G`I.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!I9B`H)&-O;G1E;G1S(#T]/2!F86QS92D@
M>PT*("`@("`@("`@("`@("`@("`@("`D8V]N=&5N=',@/2`G)SL-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A='1R
M:6)S6R=M9#5S=6TG72DI('L-"B`@("`@("`@("`@("`@("`@("`@)&UD-7-U
M;2`](&UD-2@D8V]N=&5N=',I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D871T<R!A<R`D=&%G(#T^("1R87<I('L-
M"B`@("`@("`@("`@("`@("`@("`@)'1A9R`]('-T<E]R97!L86-E*"1P:V<M
M/F=E=%1A<VMS3G,H*2`N("<Z)RP@)R<L("1T86<I.PT*("`@("`@("`@("`@
M("`@("`@("`D=&%S:R`](")014%27U1A<VM?)'1A9R([#0H@("`@("`@("`@
M("`@("`@("`@("1T87-K(#T@)FYE=R`D=&%S:R@D=&AI<RT^8V]N9FEG+"`D
M=&AI<RP@4$5!4E]405-+7TE.4U1!3$PI.PT*("`@("`@("`@("`@("`@("`@
M("!I9B`H(21T87-K+3YI<U-C<FEP="@I*2![("\O('-C<FEP=',@87)E(&]N
M;'D@:&%N9&QE9"!A9G1E<B!I;G-T86QL871I;VX-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1T87-K+3YI;FET*"1R87<L("1A='1R:6)S+"`D<&MG+3YG
M971,87-T26YS=&%L;&5D5F5R<VEO;B@I*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1R97,@/2`D=&%S:RT^<W1A<G1397-S:6]N*"1P:V<L("1C;VYT
M96YT<RP@)&9I;F%L7V1E<W1?9FEL92D[#0H@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H)')E<R`]/3T@9F%L<V4I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!C;VYT:6YU93L@+R\@<VMI<"!T:&ES(&9I;&4-"B`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("A014%2.CII<T5R<F]R*"1R97,I*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1R97,[#0H@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`D8V]N=&5N=',@/2`D
M<F5S.R`O+R!S879E(&-H86YG97,-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`D=W`@/2!`9F]P96XH)&1E<W1?9FEL92P@
M(G=B(BD[#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?<F5S;W5R8V4H
M)'=P*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*")F86EL960@=&\@8W)E871E("1D97-T7V9I;&4Z("1P
M:'!?97)R;W)M<V<B+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%!%05)?24Y35$%,3$527T9!24Q%1"D[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@
M*&9W<FET92@D=W`L("1C;VYT96YT<RD@/3T](&9A;'-E*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F9A
M:6QE9"!W<FET:6YG('1O("1D97-T7V9I;&4Z("1P:'!?97)R;W)M<V<B+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(%!%05)?24Y35$%,3$527T9!24Q%1"D[#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@9F-L;W-E*"1W<"D[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@+R\@
M>WM[(&-H96-K('1H92!M9#4-"B`@("`@("`@("`@(&EF("AI<W-E="@D;60U
M<W5M*2D@>PT*("`@("`@("`@("`@("`@(&EF("AS=')T;VQO=V5R*"1M9#5S
M=6TI(#T]('-T<G1O;&]W97(H)&%T=')I8G-;)VUD-7-U;2==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#(L(")M9#5S=6T@;VLZ("1F
M:6YA;%]D97-T7V9I;&4B*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("!I9B`H96UP='DH)&]P=&EO;G-;)V9O<F-E
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`O+R!D96QE=&4@=&AE
M(&9I;&4-"B`@("`@("`@("`@("`@("`@("`@("`@($!U;FQI;FLH)&1E<W1?
M9FEL92D[#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O
M<'1I;VYS6R=I9VYO<F4M97)R;W)S)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")B860@;60U
M<W5M(&9O<B!F:6QE("1F:6YA;%]D97-T7V9I;&4B+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!014%2
M7TE.4U1!3$Q%4E]&04E,140I.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YL;V<H,"P@(G=A<FYI;F<@.B!B860@;60U
M<W5M(&9O<B!F:6QE("1F:6YA;%]D97-T7V9I;&4B*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`B=V%R
M;FEN9R`Z(&)A9"!M9#5S=6T@9F]R(&9I;&4@)&9I;F%L7V1E<W1?9FEL92(I
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@+R\@?7U]#0H@("`@("`@("`@("`O+R![>WL@<V5T(&9I;&4@
M<&5R;6ES<VEO;G,-"B`@("`@("`@("`@(&EF("@A3U-?5TE.1$]74RD@>PT*
M("`@("`@("`@("`@("`@(&EF("@D<F]L92T^:7-%>&5C=71A8FQE*"DI('L-
M"B`@("`@("`@("`@("`@("`@("`@)&UO9&4@/2`P-S<W("8@?BAI;G0I;V-T
M9&5C*"1T:&ES+3YC;VYF:6<M/F=E="@G=6UA<VLG*2D[#0H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YL;V<H,RP@(BL@8VAM;V0@*W@@)&1E<W1?9FEL
M92(I.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@("`@("1M;V1E(#T@,#8V-B`F('XH:6YT*6]C=&1E8R@D=&AI<RT^8V]N
M9FEG+3YG970H)W5M87-K)RDI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`D=&AI<RT^861D1FEL94]P97)A=&EO;B@B8VAM;V0B+"!A
M<G)A>2@D;6]D92P@)&1E<W1?9FEL92DI.PT*("`@("`@("`@("`@("`@(&EF
M("@A0&-H;6]D*"1D97-T7V9I;&4L("1M;V1E*2D@>PT*("`@("`@("`@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L(")F86EL960@=&\@
M8VAA;F=E(&UO9&4@;V8@)&1E<W1?9FEL92(I.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@+R\@?7U]#0H@("`@("`@("`@("`D=&AI<RT^861D1FEL94]P
M97)A=&EO;B@B<F5N86UE(BP@87)R87DH)&1E<W1?9FEL92P@)&9I;F%L7V1E
M<W1?9FEL92P@)')O;&4M/FES17AT96YS:6]N*"DI*3L-"B`@("`@("`@?0T*
M("`@("`@("`O+R!3=&]R92!T:&4@9G5L;"!P871H('=H97)E('1H92!F:6QE
M('=A<R!I;G-T86QL960@9F]R(&5A<WD@=6YI;G-T86QL#0H@("`@("`@("1T
M:&ES+3YA9&1&:6QE3W!E<F%T:6]N*")I;G-T86QL961?87,B+"!A<G)A>2@D
M9FEL92P@)&EN<W1A;&QE9%]A<RP-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<V%V95]D97-T9&ER+"!D:7)N86UE*'-U8G-T<B@D9&5S=%]F:6QE
M+"!S=')L96XH)'-A=F5?9&5S=&1I<BDI*2DI.PT*#0H@("`@("`@("\O)'1H
M:7,M/FQO9R@R+"`B:6YS=&%L;&5D.B`D9&5S=%]F:6QE(BD[#0H@("`@("`@
M(')E='5R;B!014%27TE.4U1!3$Q%4E]/2SL-"B`@("!]#0H-"B`@("`O+R!]
M?7T-"B`@("`O+R![>WL@861D1FEL94]P97)A=&EO;B@I#0H-"B`@("`O*BH-
M"B`@("`@*B!!9&0@82!F:6QE(&]P97)A=&EO;B!T;R!T:&4@8W5R<F5N="!F
M:6QE('1R86YS86-T:6]N+@T*("`@("`J#0H@("`@("H@0'-E92!S=&%R=$9I
M;&54<F%N<V%C=&EO;B@I#0H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92!4
M:&ES(&-A;B!B92!O;F4@;V8Z#0H@("`@("H@("`@+2!R96YA;64Z("!R96YA
M;64@82!F:6QE("@D9&%T82!H87,@,R!V86QU97,I#0H@("`@("H@("`@+2!B
M86-K=7`Z("!B86-K=7`@86X@97AI<W1I;F<@9FEL92`H)&1A=&$@:&%S(#$@
M=F%L=64I#0H@("`@("H@("`@+2!R96UO=F5B86-K=7`Z("!C;&5A;B!U<"!B
M86-K=7!S(&-R96%T960@9'5R:6YG(&EN<W1A;&P@*"1D871A(&AA<R`Q('9A
M;'5E*0T*("`@("`J("`@("T@8VAM;V0Z("`@8VAA;F=E('!E<FUI<W-I;VYS
M(&]N(&$@9FEL92`H)&1A=&$@:&%S(#(@=F%L=65S*0T*("`@("`J("`@("T@
M9&5L971E.B`@9&5L971E(&$@9FEL92`H)&1A=&$@:&%S(#$@=F%L=64I#0H@
M("`@("H@("`@+2!R;61I<CH@("!D96QE=&4@82!D:7)E8W1O<GD@:68@96UP
M='D@*"1D871A(&AA<R`Q('9A;'5E*0T*("`@("`J("`@("T@:6YS=&%L;&5D
M7V%S.B!M87)K(&$@9FEL92!A<R!I;G-T86QL960@*"1D871A(&AA<R`T('9A
M;'5E<RDN#0H@("`@("H@0'!A<F%M(&%R<F%Y("1D871A($9O<B!A;&P@9FEL
M92!O<&5R871I;VYS+"!T:&ES(&%R<F%Y(&UU<W0@8V]N=&%I;B!T:&4-"B`@
M("`@*B`@("!F=6QL('!A=&@@=&\@=&AE(&9I;&4@;W(@9&ER96-T;W)Y('1H
M870@:7,@8F5I;F<@;W!E<F%T960@;VXN("!&;W(-"B`@("`@*B`@("!T:&4@
M<F5N86UE(&-O;6UA;F0L('1H92!F:7)S="!P87)A;65T97(@;75S="!B92!T
M:&4@9FEL92!T;R!R96YA;64L#0H@("`@("H@("`@=&AE('-E8V]N9"!I=',@
M;F5W(&YA;64L('1H92!T:&ER9"!W:&5T:&5R('1H:7,@:7,@82!02%`@97AT
M96YS:6]N+@T*("`@("`J#0H@("`@("H@("`@5&AE(&EN<W1A;&QE9%]A<R!O
M<&5R871I;VX@8V]N=&%I;G,@-"!E;&5M96YT<R!I;B!T:&ES(&]R9&5R.@T*
M("`@("`J("`@(#$N($9I;&5N86UE(&%S(&QI<W1E9"!I;B!T:&4@9FEL96QI
M<W0@96QE;65N="!F<F]M('!A8VMA9V4N>&UL#0H@("`@("H@("`@,BX@1G5L
M;"!P871H('1O('1H92!I;G-T86QL960@9FEL90T*("`@("`J("`@(#,N($9U
M;&P@<&%T:"!F<F]M('1H92!P:'!?9&ER(&-O;F9I9W5R871I;VX@=F%R:6%B
M;&4@=7-E9"!I;B!T:&ES#0H@("`@("H@("`@("`@:6YS=&%L;&%T:6]N#0H@
M("`@("H@("`@-"X@4F5L871I=F4@<&%T:"!F<F]M('1H92!P:'!?9&ER('1H
M870@=&AI<R!F:6QE(&ES(&EN<W1A;&QE9"!I;@T*("`@("`J+PT*("`@(&9U
M;F-T:6]N(&%D9$9I;&5/<&5R871I;VXH)'1Y<&4L("1D871A*0T*("`@('L-
M"B`@("`@("`@:68@*"%I<U]A<G)A>2@D9&%T82DI('L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G26YT97)N86P@17)R;W(Z("1D
M871A(&EN(&%D9$9I;&5/<&5R871I;VXG#0H@("`@("`@("`@("`@("`@+B`G
M(&UU<W0@8F4@86X@87)R87DL('=A<R`G("X@9V5T='EP92@D9&%T82DI.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("@D='EP92`]/2`G8VAM;V0G*2![#0H@
M("`@("`@("`@("`D;V-T;6]D92`](&1E8V]C="@D9&%T85LP72D[#0H@("`@
M("`@("`@("`D=&AI<RT^;&]G*#,L(")A9&1I;F<@=&\@=')A;G-A8W1I;VXZ
M("1T>7!E("1O8W1M;V1E("1D871A6S%=(BD[#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`D=&AI<RT^;&]G*#,L(")A9&1I;F<@=&\@=')A;G-A
M8W1I;VXZ("1T>7!E("(@+B!I;7!L;V1E*"(@(BP@)&1A=&$I*3L-"B`@("`@
M("`@?0T*("`@("`@("`D=&AI<RT^9FEL95]O<&5R871I;VYS6UT@/2!A<G)A
M>2@D='EP92P@)&1A=&$I.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O
M('M[>R!S=&%R=$9I;&54<F%N<V%C=&EO;B@I#0H-"B`@("!F=6YC=&EO;B!S
M=&%R=$9I;&54<F%N<V%C=&EO;B@D<F]L;&)A8VM?:6Y?8V%S92`](&9A;'-E
M*0T*("`@('L-"B`@("`@("`@:68@*&-O=6YT*"1T:&ES+3YF:6QE7V]P97)A
M=&EO;G,I("8F("1R;VQL8F%C:U]I;E]C87-E*2![#0H@("`@("`@("`@("`D
M=&AI<RT^<F]L;&)A8VM&:6QE5')A;G-A8W1I;VXH*3L-"B`@("`@("`@?0T*
M("`@("`@("`D=&AI<RT^9FEL95]O<&5R871I;VYS(#T@87)R87DH*3L-"B`@
M("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@8V]M;6ET1FEL951R86YS
M86-T:6]N*"D-"@T*("`@(&9U;F-T:6]N(&-O;6UI=$9I;&54<F%N<V%C=&EO
M;B@I#0H@("`@>PT*("`@("`@("`D;B`](&-O=6YT*"1T:&ES+3YF:6QE7V]P
M97)A=&EO;G,I.PT*("`@("`@("`D=&AI<RT^;&]G*#(L(")A8F]U="!T;R!C
M;VUM:70@)&X@9FEL92!O<&5R871I;VYS(BD[#0H@("`@("`@("\O('M[>R!F
M:7)S="P@8VAE8VL@<&5R;6ES<VEO;G,@86YD('-U8V@@;6%N=6%L;'D-"B`@
M("`@("`@)&5R<F]R<R`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*"1T
M:&ES+3YF:6QE7V]P97)A=&EO;G,@87,@)'1R*2![#0H@("`@("`@("`@("!L
M:7-T*"1T>7!E+"`D9&%T82D@/2`D='([#0H@("`@("`@("`@("!S=VET8V@@
M*"1T>7!E*2![#0H@("`@("`@("`@("`@("`@8V%S92`G<F5N86UE)SH-"B`@
M("`@("`@("`@("`@("`@("`@:68@*"%F:6QE7V5X:7-T<R@D9&%T85LP72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1E<G)O<G-;72`](")C86YN
M;W0@<F5N86UE(&9I;&4@)&1A=&%;,%TL(&1O97-N)W0@97AI<W0B.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("\O(&-H
M96-K('1H870@9&5S="!D:7(N(&ES('=R:71A8FQE#0H@("`@("`@("`@("`@
M("`@("`@(&EF("@A:7-?=W)I=&%B;&4H9&ER;F%M92@D9&%T85LQ72DI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D97)R;W)S6UT@/2`B<&5R;6ES
M<VEO;B!D96YI960@*"1T>7!E*3H@)&1A=&%;,5TB.PT*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@
M("`@("`@("`@(&-A<V4@)V-H;6]D)SH-"B`@("`@("`@("`@("`@("`@("`@
M+R\@8VAE8VL@=&AA="!F:6QE(&ES('=R:71A8FQE#0H@("`@("`@("`@("`@
M("`@("`@(&EF("@A:7-?=W)I=&%B;&4H)&1A=&%;,5TI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D97)R;W)S6UT@/2`B<&5R;6ES<VEO;B!D96YI
M960@*"1T>7!E*3H@)&1A=&%;,5T@(B`N(&1E8V]C="@D9&%T85LP72D[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@8G)E
M86L[#0H@("`@("`@("`@("`@("`@8V%S92`G9&5L971E)SH-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"%F:6QE7V5X:7-T<R@D9&%T85LP72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,BP@(G=A<FYI;F<Z
M(&9I;&4@)&1A=&%;,%T@9&]E<VXG="!E>&ES="P@8V%N)W0@8F4@9&5L971E
M9"(I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("\O(&-H96-K('1H870@9&ER96-T;W)Y(&ES('=R:71A8FQE#0H@("`@
M("`@("`@("`@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D9&%T85LP72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?=W)I=&%B;&4H9&ER
M;F%M92@D9&%T85LP72DI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&5R<F]R<UM=(#T@(G!E<FUI<W-I;VX@9&5N:65D("@D='EP92DZ("1D
M871A6S!=(CL-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@;6%K92!S=7)E('1H92!F
M:6QE('1O(&)E(&1E;&5T960@8V%N(&)E(&]P96YE9"!F;W(@=W)I=&EN9PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F<"`](&9A;'-E.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?9&ER*"1D871A6S!=
M*2`F)B`A*"1F<"`]($!F;W!E;B@D9&%T85LP72P@)V$G*2DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5R<F]R<UM=(#T@(G!E<FUI
M<W-I;VX@9&5N:65D("@D='EP92DZ("1D871A6S!=(CL-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&9P*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&9C;&]S92@D9G`I.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL-"B`@("`@("`@("`@('T-"@T*("`@("`@("!]#0H@("`@("`@
M("\O('U]?0T*("`@("`@("`D;2`]('-I>F5O9B@D97)R;W)S*3L-"B`@("`@
M("`@:68@*"1M(#X@,"D@>PT*("`@("`@("`@("`@9F]R96%C:"`H)&5R<F]R
M<R!A<R`D97)R;W(I('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^;&]G*#$L("1E<G)O<BD[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^
M7V]P=&EO;G-;)VEG;F]R92UE<G)O<G,G72DI('L-"B`@("`@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@)'1H:7,M/E]D:7)T<F5E(#T@87)R87DH*3L-"B`@("`@("`@+R\@
M>WM[(')E86QL>2!C;VUM:70@=&AE('1R86YS86-T:6]N#0H@("`@("`@(&9O
M<F5A8V@@*"1T:&ES+3YF:6QE7V]P97)A=&EO;G,@87,@)'1R*2![#0H@("`@
M("`@("`@("!L:7-T*"1T>7!E+"`D9&%T82D@/2`D='([#0H@("`@("`@("`@
M("!S=VET8V@@*"1T>7!E*2![#0H@("`@("`@("`@("`@("`@8V%S92`G8F%C
M:W5P)SH-"B`@("`@("`@("`@("`@("`@("`@0&-O<'DH)&1A=&%;,%TL("1D
M871A6S!=("X@)RYB86LG*3L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/FQO9R@S+"`B*R!B86-K=7`@)&1A=&%;,%T@=&\@)&1A=&%;,%TN8F%K(BD[
M#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@
M(&-A<V4@)W)E;6]V96)A8VMU<"<Z#0H@("`@("`@("`@("`@("`@("`@($!U
M;FQI;FLH)&1A=&%;,%T@+B`G+F)A:R<I.PT*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^;&]G*#,L("(K(')M(&)A8VMU<"!O9B`D9&%T85LP72`H)&1A
M=&%;,%TN8F%K*2(I.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@
M("`@("`@("`@("`@("!C87-E("=R96YA;64G.@T*("`@("`@("`@("`@("`@
M("`@("`D=&5S="`]($!U;FQI;FLH)&1A=&%;,5TI.PT*("`@("`@("`@("`@
M("`@("`@("!I9B`H(21T97-T("8F(&9I;&5?97AI<W1S*"1D871A6S%=*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1D871A6S)=*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5X=')A(#T@)RP@=&AI<R!E
M>'1E;G-I;VX@;75S="!B92!I;G-T86QL960@;6%N=6%L;'DN("!296YA;64@
M=&\@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!B87-E
M;F%M92@D9&%T85LQ72D@+B`G(B<[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E>'1R
M82`]("<G.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)W-O
M9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M;&]G*#$L("=#;W5L9"!N;W0@9&5L971E("<@+B`D9&%T85LQ72`N("<L(&-A
M;FYO="!R96YA;64@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1D871A6S!=("X@)&5X=')A*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H
M:7,M/E]O<'1I;VYS6R=I9VYO<F4M97)R;W)S)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@($!R96YA;64H)&1A=&%;,%TL("1D871A6S%=*3L-"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@S+"`B*R!M=B`D9&%T85LP
M72`D9&%T85LQ72(I.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@
M("`@("`@("`@("`@("!C87-E("=C:&UO9"<Z#0H@("`@("`@("`@("`@("`@
M("`@($!C:&UO9"@D9&%T85LQ72P@)&1A=&%;,%TI.PT*("`@("`@("`@("`@
M("`@("`@("`D;V-T;6]D92`](&1E8V]C="@D9&%T85LP72D[#0H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YL;V<H,RP@(BL@8VAM;V0@)&]C=&UO9&4@
M)&1A=&%;,5TB*3L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@
M("`@("`@("`@("`@8V%S92`G9&5L971E)SH-"B`@("`@("`@("`@("`@("`@
M("`@0'5N;&EN:R@D9&%T85LP72D[#0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YL;V<H,RP@(BL@<FT@)&1A=&%;,%TB*3L-"B`@("`@("`@("`@("`@
M("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@8V%S92`G<FUD:7(G.@T*
M("`@("`@("`@("`@("`@("`@("!`<FUD:7(H)&1A=&%;,%TI.PT*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^;&]G*#,L("(K(')M9&ER("1D871A6S!=
M(BD[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@
M("`@(&-A<V4@)VEN<W1A;&QE9%]A<R<Z#0H@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YP:V=I;F9O+3YS971);G-T86QL961!<R@D9&%T85LP72P@)&1A
M=&%;,5TI.PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3Y?9&ER=')E95MD:7)N86UE*"1D871A6S%=*5TI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7V1I<G1R965;9&ER;F%M92@D9&%T85LQ
M72E=(#T@=')U93L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YP
M:V=I;F9O+3YS971$:7)T<F5E*&1I<FYA;64H)&1A=&%;,5TI*3L-"@T*("`@
M("`@("`@("`@("`@("`@("`@("`@=VAI;&4H(65M<'1Y*"1D871A6S-=*2`F
M)B`D9&%T85LS72`A/2`G+R<@)B8@)&1A=&%;,UT@(3T@)UQ<)PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)B8@)&1A=&%;,UT@(3T@)RXG*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G!K9VEN9F\M
M/G-E=$1I<G1R964H)'!P(#T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P<F5P96YD4&%T:"@D9&%T85LS72P@)&1A=&%;,ETI
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1I<G1R
M965;)'!P72`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&1A=&%;,UT@/2!D:7)N86UE*"1D871A6S-=*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("`O+R!]?7T-"B`@("`@("`@)'1H:7,M/FQO9R@R+"`B<W5C8V5S
M<V9U;&QY(&-O;6UI='1E9"`D;B!F:6QE(&]P97)A=&EO;G,B*3L-"B`@("`@
M("`@)'1H:7,M/F9I;&5?;W!E<F%T:6]N<R`](&%R<F%Y*"D[#0H@("`@("`@
M(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[
M>R!R;VQL8F%C:T9I;&54<F%N<V%C=&EO;B@I#0H-"B`@("!F=6YC=&EO;B!R
M;VQL8F%C:T9I;&54<F%N<V%C=&EO;B@I#0H@("`@>PT*("`@("`@("`D;B`]
M(&-O=6YT*"1T:&ES+3YF:6QE7V]P97)A=&EO;G,I.PT*("`@("`@("`D=&AI
M<RT^;&]G*#(L(")R;VQL:6YG(&)A8VL@)&X@9FEL92!O<&5R871I;VYS(BD[
M#0H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YF:6QE7V]P97)A=&EO;G,@87,@
M)'1R*2![#0H@("`@("`@("`@("!L:7-T*"1T>7!E+"`D9&%T82D@/2`D='([
M#0H@("`@("`@("`@("!S=VET8V@@*"1T>7!E*2![#0H@("`@("`@("`@("`@
M("`@8V%S92`G8F%C:W5P)SH-"B`@("`@("`@("`@("`@("`@("`@:68@*&9I
M;&5?97AI<W1S*"1D871A6S!=("X@)RYB86LG*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@0'5N;&EN:R@D9&%T85LP72D[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!`8V]P>2@D9&%T85LP72`N("<N8F%K)RP@)&1A=&%;,%TI
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@S+"`B*R!R
M97-T;W)E("1D871A6S!=(&9R;VT@)&1A=&%;,%TN8F%K(BD[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@
M("`@("`@("`@("`@("`@8V%S92`G<F5N86UE)SH-"B`@("`@("`@("`@("`@
M("`@("`@0'5N;&EN:R@D9&%T85LP72D[#0H@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YL;V<H,RP@(BL@<FT@)&1A=&%;,%TB*3L-"B`@("`@("`@("`@
M("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@8V%S92`G;6MD:7(G
M.@T*("`@("`@("`@("`@("`@("`@("!`<FUD:7(H)&1A=&%;,%TI.PT*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#,L("(K(')M9&ER("1D871A
M6S!=(BD[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@
M("`@("`@(&-A<V4@)V-H;6]D)SH-"B`@("`@("`@("`@("`@("`@("`@8G)E
M86L[#0H@("`@("`@("`@("`@("`@8V%S92`G9&5L971E)SH-"B`@("`@("`@
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@8V%S92`G:6YS
M=&%L;&5D7V%S)SH-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G!K9VEN
M9F\M/G-E=$EN<W1A;&QE9$%S*"1D871A6S!=+"!F86QS92D[#0H@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@("1T:&ES+3YP:V=I;F9O+3YR97-E=$1I<G1R964H*3L-"B`@
M("`@("`@)'1H:7,M/F9I;&5?;W!E<F%T:6]N<R`](&%R<F%Y*"D[#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&UK1&ER2&EE<B@D9&ER*0T*
M#0H@("`@9G5N8W1I;VX@;6M$:7)(:65R*"1D:7(I#0H@("`@>PT*("`@("`@
M("`D=&AI<RT^861D1FEL94]P97)A=&EO;B@G;6MD:7(G+"!A<G)A>2@D9&ER
M*2D[#0H@("`@("`@(')E='5R;B!P87)E;G0Z.FUK1&ER2&EE<B@D9&ER*3L-
M"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9&]W;FQO860H*0T*
M#0H@("`@+RHJ#0H@("`@("H@1&]W;FQO860@86YY(&9I;&5S(&%N9"!T:&5I
M<B!D97!E;F1E;F-I97,L(&EF(&YE8V5S<V%R>0T*("`@("`J#0H@("`@("H@
M0'!A<F%M(&%R<F%Y(&$@;6EX960@;&ES="!O9B!P86-K86=E(&YA;65S+"!L
M;V-A;"!F:6QE<RP@;W(@<&%C:V%G92YX;6P-"B`@("`@*B!`<&%R86T@4$5!
M4E]#;VYF:6<-"B`@("`@*B!`<&%R86T@87)R87D@;W!T:6]N<R!F<F]M('1H
M92!C;VUM86YD(&QI;F4-"B`@("`@*B!`<&%R86T@87)R87D@=&AI<R!I<R!T
M:&4@87)R87D@=&AA="!W:6QL(&)E('!O<'5L871E9"!W:71H('!A8VMA9V5S
M('1O#0H@("`@("H@("`@("`@("`@("`@(&EN<W1A;&PN("!&;W)M870@;V8@
M96%C:"!E;G1R>3H-"B`@("`@*@T*("`@("`J(#QC;V1E/@T*("`@("`J(&%R
M<F%Y*"=P:V<G(#T^("=P86-K86=E7VYA;64G+"`G9FEL92<@/3X@)R]P871H
M+W1O+VQO8V%L+V9I;&4G+`T*("`@("`J("`@("=I;F9O)R`]/B!A<G)A>2@I
M("\O('!A<G-E9"!P86-K86=E+GAM;`T*("`@("`J("D[#0H@("`@("H@/"]C
M;V1E/@T*("`@("`J($!P87)A;2!A<G)A>2!T:&ES('=I;&P@8F4@<&]P=6QA
M=&5D('=I=&@@86YY(&5R<F]R(&UE<W-A9V5S#0H@("`@("H@0'!A<F%M(&9A
M;'-E('!R:79A=&4@<F5C=7)S:6]N('9A<FEA8FQE#0H@("`@("H@0'!A<F%M
M(&9A;'-E('!R:79A=&4@<F5C=7)S:6]N('9A<FEA8FQE#0H@("`@("H@0'!A
M<F%M(&9A;'-E('!R:79A=&4@<F5C=7)S:6]N('9A<FEA8FQE#0H@("`@("H@
M0&1E<')E8V%T960@:6X@9F%V;W(@;V8@4$5!4E]$;W=N;&]A9&5R#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@9&]W;FQO860H)'!A8VMA9V5S+"`D;W!T:6]N
M<RP@)B1C;VYF:6<L("8D:6YS=&%L;'!A8VMA9V5S+`T*("`@("`@("`@("`@
M("`@("`@("`@("8D97)R;W)S+"`D:6YS=&%L;&5D(#T@9F%L<V4L("1W:6QL
M:6YS=&%L;"`](&9A;'-E+"`D<W1A=&4@/2!F86QS92D-"B`@("![#0H@("`@
M("`@("\O('1R:6-K:6YE<W,Z(&EN:71I86QI>F4@:&5R90T*("`@("`@("!P
M87)E;G0Z.E!%05)?1&]W;FQO861E<B@D=&AI<RT^=6DL("1O<'1I;VYS+"`D
M8V]N9FEG*3L-"B`@("`@("`@)')E="`]('!A<F5N=#HZ9&]W;FQO860H)'!A
M8VMA9V5S*3L-"B`@("`@("`@)&5R<F]R<R`]("1T:&ES+3YG971%<G)O<DUS
M9W,H*3L-"B`@("`@("`@)&EN<W1A;&QP86-K86=E<R`]("1T:&ES+3YG971$
M;W=N;&]A9&5D4&%C:V%G97,H*3L-"B`@("`@("`@=')I9V=E<E]E<G)O<B@B
M4$5!4B!787)N:6YG.B!014%27TEN<W1A;&QE<CHZ9&]W;FQO860H*2!I<R!D
M97!R96-A=&5D("(@+@T*("`@("`@("`@("`@("`@("`@("`@(")I;B!F879O
M<B!O9B!014%27T1O=VYL;V%D97(@8VQA<W,B+"!%7U5315)?5T%23DE.1RD[
M#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*("`@("\O('U]?0T*
M("`@("\O('M[>R!?<&%R<V5086-K86=E6&UL*"D-"@T*("`@(&9U;F-T:6]N
M(%]P87)S95!A8VMA9V58;6PH)B1D97-C9FEL92P@)B1T;7!D:7(I#0H@("`@
M>PT*("`@("`@("!I9B`H<W5B<W1R*"1D97-C9FEL92P@+30I(#T]("<N>&UL
M)RD@>PT*("`@("`@("`@("`@)'1M<&1I<B`](&9A;'-E.PT*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@+R\@>WM[($1E8V]M<')E<W,@<&%C:R!I
M;B!T;7`@9&ER("TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2T-"@T*("`@("`@("`@("`@+R\@5&\@86QL;W<@<F5L871I=F4@<&%C:V%G
M92!F:6QE(&YA;65S#0H@("`@("`@("`@("`D9&5S8V9I;&4@/2!R96%L<&%T
M:"@D9&5S8V9I;&4I.PT*#0H@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D=&UP9&ER(#T@4WES=&5M.CIM:W1E;7`H)RUD)RDI*2![#0H@("`@("`@
M("`@("`@("`@<F5T=7)N("1T;7!D:7([#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`D=&AI<RT^;&]G*#,L("<K('1M<"!D:7(@8W)E871E9"!A="`G
M("X@)'1M<&1I<BD[#0H@("`@("`@("`@("`O+R!]?7T-"B`@("`@("`@?0T*
M("`@("`@("`O+R!087)S92!X;6P@9FEL92`M+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0T*("`@("`@("`D<&MG(#T@
M;F5W(%!%05)?4&%C:V%G949I;&4H)'1H:7,M/F-O;F9I9RP@)'1H:7,M/F1E
M8G5G+"`D=&UP9&ER*3L-"B`@("`@("`@4$5!4CHZ<W1A=&EC4'5S:$5R<F]R
M2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`D<"`]("8D
M<&MG+3YF<F]M06YY1FEL92@D9&5S8V9I;&4L(%!%05)?5D%,241!5$5?24Y3
M5$%,3$E.1RD[#0H@("`@("`@(%!%05(Z.G-T871I8U!O<$5R<F]R2&%N9&QI
M;F<H*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'`I*2![#0H@("`@
M("`@("`@("!I9B`H:7-?87)R87DH)'`M/F=E=%5S97));F9O*"DI*2![#0H@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)'`M/F=E=%5S97));F9O*"D@87,@
M)&5R<BD@>PT*("`@("`@("`@("`@("`@("`@("`D;&]G;&5V96P@/2`D97)R
M6R=L979E;"==(#T]("=E<G)O<B<@/R`P(#H@,3L-"B`@("`@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)W-O9G0G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H)&QO9VQE=F5L
M+"!U8V9I<G-T*"1E<G);)VQE=F5L)UTI("X@)SH@)R`N("1E<G);)VUE<W-A
M9V4G72D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H)TEN<W1A;&QA=&EO;B!F86EL960Z(&EN=F%L:60@<&%C
M:V%G92!F:6QE)RD[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D
M9&5S8V9I;&4@/2`D<"T^9V5T4&%C:V%G949I;&4H*3L-"B`@("`@("`@?0T*
M("`@("`@("!R971U<FX@)'`[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@
M+RHJ#0H@("`@("H@4V5T('1H92!L:7-T(&]F(%!%05)?1&]W;FQO861E<E]0
M86-K86=E(&]B:F5C=',@=&\@86QL;W<@;6]R92!S86YE#0H@("`@("H@9&5P
M96YD96YC>2!V86QI9&%T:6]N#0H@("`@("H@0'!A<F%M(&%R<F%Y#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@<V5T1&]W;FQO861E9%!A8VMA9V5S*"8D<&MG
M<RD-"B`@("![#0H@("`@("`@(%!%05(Z.G!U<VA%<G)O<DAA;F1L:6YG*%!%
M05)?15)23U)?4D5455).*3L-"B`@("`@("`@)&5R<B`]("1T:&ES+3YA;F%L
M>7IE1&5P96YD96YC:65S*"1P:V=S*3L-"B`@("`@("`@4$5!4CHZ<&]P17)R
M;W)(86YD;&EN9R@I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R
M*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1E<G([#0H@("`@("`@('T-"B`@
M("`@("`@)'1H:7,M/E]D;W=N;&]A9&5D4&%C:V%G97,@/2`F)'!K9W,[#0H@
M("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4V5T('1H92!L:7-T(&]F(%!%05)?
M1&]W;FQO861E<E]086-K86=E(&]B:F5C=',@=&\@86QL;W<@;6]R92!S86YE
M#0H@("`@("H@9&5P96YD96YC>2!V86QI9&%T:6]N#0H@("`@("H@0'!A<F%M
M(&%R<F%Y#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T56YI;G-T86QL4&%C
M:V%G97,H)B1P:V=S*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]D;W=N;&]A
M9&5D4&%C:V%G97,@/2`F)'!K9W,[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M9V5T26YS=&%L;%!A8VMA9V5S*"D-"B`@("![#0H@("`@("`@(')E='5R;B`D
M=&AI<RT^7V1O=VYL;V%D961086-K86=E<SL-"B`@("!]#0H-"B`@("`O+R![
M>WL@:6YS=&%L;"@I#0H-"B`@("`O*BH-"B`@("`@*B!);G-T86QL<R!T:&4@
M9FEL97,@=VET:&EN('1H92!P86-K86=E(&9I;&4@<W!E8VEF:65D+@T*("`@
M("`J#0H@("`@("H@0'!A<F%M('-T<FEN9WQ014%27T1O=VYL;V%D97)?4&%C
M:V%G92`D<&MG9FEL92!P871H('1O('1H92!P86-K86=E(&9I;&4L#0H@("`@
M("H@("`@("`@(&]R(&$@<')E+6EN:71I86QI>F5D('!A8VMA9V5F:6QE(&]B
M:F5C=`T*("`@("`J($!P87)A;2!A<G)A>2`D;W!T:6]N<PT*("`@("`J(')E
M8V]G;FEZ960@;W!T:6]N<SH-"B`@("`@*B`M(&EN<W1A;&QR;V]T("`@.B!O
M<'1I;VYA;"!P<F5F:7@@9&ER96-T;W)Y(&9O<B!I;G-T86QL871I;VX-"B`@
M("`@*B`M(&9O<F-E("`@("`@("`@.B!F;W)C92!I;G-T86QL871I;VX-"B`@
M("`@*B`M(')E9VES=&5R+6]N;'D@.B!U<&1A=&4@<F5G:7-T<GD@8G5T(&1O
M;B=T(&EN<W1A;&P@9FEL97,-"B`@("`@*B`M('5P9W)A9&4@("`@("`@.B!U
M<&=R861E(&5X:7-T:6YG(&EN<W1A;&P-"B`@("`@*B`M('-O9G0@("`@("`@
M("`@.B!F86EL('-I;&5N=&QY#0H@("`@("H@+2!N;V1E<',@("`@("`@(#H@
M:6=N;W)E(&1E<&5N9&5N8WD@8V]N9FQI8W1S+VUI<W-I;F<@9&5P96YD96YC
M:65S#0H@("`@("H@+2!A;&QD97!S("`@("`@(#H@:6YS=&%L;"!A;&P@9&5P
M96YD96YC:65S#0H@("`@("H@+2!O;FQY<F5Q9&5P<R`@(#H@:6YS=&%L;"!O
M;FQY(')E<75I<F5D(&1E<&5N9&5N8VEE<PT*("`@("`J#0H@("`@("H@0')E
M='5R;B!A<G)A>7Q014%27T5R<F]R('!A8VMA9V4@:6YF;R!I9B!S=6-C97-S
M9G5L#0H@("`@("HO#0H-"B`@("!F=6YC=&EO;B!I;G-T86QL*"1P:V=F:6QE
M+"`D;W!T:6]N<R`](&%R<F%Y*"DI#0H@("`@>PT*("`@("`@("`D=&AI<RT^
M7V]P=&EO;G,@/2`D;W!T:6]N<SL-"B`@("`@("`@)'1H:7,M/E]R96=I<W1R
M>2`]("8D=&AI<RT^8V]N9FEG+3YG971296=I<W1R>2@I.PT*("`@("`@("!I
M9B`H:7-?;V)J96-T*"1P:V=F:6QE*2D@>PT*("`@("`@("`@("`@)&1L<&MG
M(#T@)B1P:V=F:6QE.PT*("`@("`@("`@("`@)'!K9R`]("1P:V=F:6QE+3YG
M971086-K86=E1FEL92@I.PT*("`@("`@("`@("`@)'!K9V9I;&4@/2`D<&MG
M+3YG971!<F-H:79E1FEL92@I.PT*("`@("`@("`@("`@)&1E<V-F:6QE(#T@
M)'!K9RT^9V5T4&%C:V%G949I;&4H*3L-"B`@("`@("`@("`@("1T;7!D:7(@
M/2!D:7)N86UE*"1D97-C9FEL92D[#0H@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`D9&5S8V9I;&4@/2`D<&MG9FEL93L-"B`@("`@("`@("`@("1T
M;7!D:7(@/2`G)SL-"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1P
M:V<@/2`F)'1H:7,M/E]P87)S95!A8VMA9V58;6PH)&1E<V-F:6QE+"`D=&UP
M9&ER*2DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'!K9SL-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*#0H@("`@("`@(&EF("AR96%L<&%T:"@D
M9&5S8V9I;&4I("$](')E86QP871H*"1P:V=F:6QE*2D@>PT*("`@("`@("`@
M("`@)'1A<B`](&YE=R!!<F-H:79E7U1A<B@D<&MG9FEL92D[#0H@("`@("`@
M("`@("!I9B`H(4`D=&%R+3YE>'1R86-T*"1T;7!D:7(I*2![#0H@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")U;F%B;&4@=&\@
M=6YP86-K("1P:V=F:6QE(BD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"@T*("`@("`@("`D<&MG;F%M92`]("1P:V<M/F=E=$YA;64H*3L-"B`@("`@
M("`@)&-H86YN96P@/2`D<&MG+3YG971#:&%N;F5L*"D[#0H@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7V]P=&EO;G-;)W!A8VMA9VEN9W)O;W0G72DI('L-
M"B`@("`@("`@("`@("1P86-K<F]O='!H<%]D:7(@/2`D=&AI<RT^7W!R97!E
M;F10871H*`T*("`@("`@("`@("`@("`@("1T:&ES+3YC;VYF:6<M/F=E="@G
M<&AP7V1I<B<L(&YU;&PL("1C:&%N;F5L*2P-"B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V]P=&EO;G-;)W!A8VMA9VEN9W)O;W0G72D[#0H@("`@("`@('T-
M"@T*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)VEN<W1A;&QR;V]T)UTI
M*2![#0H@("`@("`@("`@("`D=&AI<RT^8V]N9FEG+3YS971);G-T86QL4F]O
M="@D;W!T:6]N<ULG:6YS=&%L;')O;W0G72D[#0H@("`@("`@("`@("`D=&AI
M<RT^7W)E9VES=')Y(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[
M#0H@("`@("`@("`@("`D:6YS=&%L;')E9VES=')Y(#T@)B1T:&ES+3Y?<F5G
M:7-T<GD[#0H@("`@("`@("`@("`D=&AI<RT^:6YS=&%L;')O;W0@/2`G)SL@
M+R\@86QL(&1O;F4@875T;VUA9VEC86QL>2!N;W<-"B`@("`@("`@("`@("1P
M:'!?9&ER(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=P:'!?9&ER)RP@;G5L;"P@
M)&-H86YN96PI.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'1H
M:7,M/F-O;F9I9RT^<V5T26YS=&%L;%)O;W0H9F%L<V4I.PT*("`@("`@("`@
M("`@)'1H:7,M/E]R96=I<W1R>2`]("8D=&AI<RT^8V]N9FEG+3YG971296=I
M<W1R>2@I.PT*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?;W!T:6]N
M<ULG<&%C:V%G:6YG<F]O="==*2D@>PT*("`@("`@("`@("`@("`@("1I;G-T
M86QL<F5G:7-T<GD@/2`F;F5W(%!%05)?4F5G:7-T<GDH)'!A8VMR;V]T<&AP
M7V1I<BD[#0H@("`@("`@("`@("`@("`@)'!H<%]D:7(@/2`D<&%C:W)O;W1P
M:'!?9&ER.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`D:6YS=&%L;')E9VES=')Y(#T@)B1T:&ES+3Y?<F5G:7-T<GD[#0H@("`@
M("`@("`@("`@("`@)'!H<%]D:7(@/2`D=&AI<RT^8V]N9FEG+3YG970H)W!H
M<%]D:7(G+"!N=6QL+"`D8VAA;FYE;"D[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`D=&AI<RT^:6YS=&%L;')O;W0@/2`G)SL-"B`@("`@("`@?0T*
M#0H@("`@("`@("\O('M[>R!C:&5C:W,@=&\@9&\@=VAE;B!N;W0@:6X@(F9O
M<F-E(B!M;V1E#0H@("`@("`@(&EF("AE;7!T>2@D;W!T:6]N<ULG9F]R8V4G
M72D@)B8@0&ES7V1I<B@D=&AI<RT^8V]N9FEG+3YG970H)W!H<%]D:7(G*2DI
M('L-"B`@("`@("`@("`@("1T97-T<"`]("1C:&%N;F5L(#T]("=P96%R+G!H
M<"YN970G(#\@)'!K9VYA;64@.B!A<G)A>2@D8VAA;FYE;"P@)'!K9VYA;64I
M.PT*("`@("`@("`@("`@)&EN<W1F:6QE;&ES="`]("1P:V<M/F=E=$EN<W1A
M;&QA=&EO;D9I;&5,:7-T*'1R=64I.PT*("`@("`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)&EN<W1F:6QE;&ES="DI('L-"B`@("`@("`@("`@("`@("!R
M971U<FX@)&EN<W1F:6QE;&ES=#L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("1T97-T(#T@)&EN<W1A;&QR96=I<W1R>2T^8VAE8VM&:6QE36%P*"1I
M;G-T9FEL96QI<W0L("1T97-T<"P@)S$N,2<I.PT*("`@("`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)'1E<W0I*2![#0H@("`@("`@("`@("`@("`@<F5T
M=7)N("1T97-T.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*'-I
M>F5O9B@D=&5S="DI('L-"B`@("`@("`@("`@("`@("`D<&MG<R`]("1T:&ES
M+3YG971);G-T86QL4&%C:V%G97,H*3L-"B`@("`@("`@("`@("`@("`D9F]U
M;F0@/2!F86QS93L-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D<&MG<R!A
M<R`D<&%R86TI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1P:V<M/FES
M4W5B<&%C:V%G94]F*"1P87)A;2DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1F;W5N9"`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!I9B`H)&9O=6YD*2![#0H@("`@("`@("`@
M("`@("`@("`@("\O('-U8G!A8VMA9V5S(&-A;B!C;VYF;&EC="!W:71H(&5A
M<FQI97(@=F5R<VEO;G,@;V8@<&%R96YT('!A8VMA9V5S#0H@("`@("`@("`@
M("`@("`@("`@("1P87)E;G1R96<@/2`D:6YS=&%L;')E9VES=')Y+3YP86-K
M86=E26YF;R@D<&%R86TM/F=E=%!A8VMA9V4H*2P@;G5L;"P@)'!A<F%M+3YG
M971#:&%N;F5L*"DI.PT*("`@("`@("`@("`@("`@("`@("`D=&UP(#T@)'1E
M<W0[#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T;7`@87,@)&9I
M;&4@/3X@)&EN9F\I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI
M<U]A<G)A>2@D:6YF;RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H<W1R=&]L;W=E<B@D:6YF;ULQ72D@/3T@<W1R=&]L;W=E<B@D<&%R
M86TM/F=E=%!A8VMA9V4H*2D@)B8-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!S=')T;VQO=V5R*"1I;F9O6S!=*2`]/2!S=')T;VQO=V5R
M*"1P87)A;2T^9V5T0VAA;FYE;"@I*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!U;G-E="@D=&5S=%LD9FEL95TI.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D<&%R96YT<F5G6R=F:6QE
M;&ES="==6R1F:6QE72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H<W1R=&]L;W=E<B@D<&%R86TM/F=E
M=$-H86YN96PH*2D@(3T@)W!E87(N<&AP+FYE="<I('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("AS=')T;VQO=V5R*"1I;F9O*2`]/2!S=')T;VQO=V5R*"1P87)A;2T^
M9V5T4&%C:V%G92@I*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!U;G-E="@D=&5S=%LD9FEL95TI.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!U;G-E="@D<&%R96YT<F5G6R=F:6QE;&ES="==6R1F
M:6QE72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@("1P9FL@/2`F;F5W(%!%05)?4&%C:V%G949I
M;&4H)'1H:7,M/F-O;F9I9RD[#0H@("`@("`@("`@("`@("`@("`@("1P87)E
M;G1P:V<@/2`F)'!F:RT^9G)O;4%R<F%Y*"1P87)E;G1R96<I.PT*("`@("`@
M("`@("`@("`@("`@("`D:6YS=&%L;')E9VES=')Y+3YU<&1A=&5086-K86=E
M,B@D<&%R96YT<&MG*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@:68@*"1P87)A;2T^9V5T0VAA;FYE;"@I(#T]("=P96-L+G!H<"YN
M970G("8F(&ES<V5T*"1O<'1I;VYS6R=U<&=R861E)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("1T;7`@/2`D=&5S=#L-"B`@("`@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)'1M<"!A<R`D9FEL92`]/B`D:6YF;RD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&ES7W-T<FEN9R@D:6YF;RDI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!P96%R+G!H<"YN970@<&%C
M:V%G97,@87)E(&%L=V%Y<R!S=&]R960@87,@<W1R:6YG<PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AS=')T;VQO=V5R*"1I;F9O*2`]/2!S
M=')T;VQO=V5R*"1P87)A;2T^9V5T4&%C:V%G92@I*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`O+R!U<&=R861I;F<@97AI<W1I;F<@
M<&%C:V%G90T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!U;G-E
M="@D=&5S=%LD9FEL95TI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I
M9B`H<VEZ96]F*"1T97-T*2D@>PT*("`@("`@("`@("`@("`@("`@("`D;7-G
M(#T@(B1C:&%N;F5L+R1P:V=N86UE.B!C;VYF;&EC=&EN9R!F:6QE<R!F;W5N
M9#I<;B([#0H@("`@("`@("`@("`@("`@("`@("1L;VYG97-T(#T@;6%X*&%R
M<F%Y7VUA<"@B<W1R;&5N(BP@87)R87E?:V5Y<R@D=&5S="DI*3L-"B`@("`@
M("`@("`@("`@("`@("`@)&9M="`]("(E)'ML;VYG97-T?7,@*"5S*5QN(CL-
M"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1E<W0@87,@)&9I;&4@
M/3X@)&EN9F\I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?
M87)R87DH)&EN9F\I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&EN9F\@/2!A<G)A>2@G<&5A<BYP:'`N;F5T)RP@)&EN9F\I.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M)&EN9F\@/2`D:6YF;ULP72`N("<O)R`N("1I;F9O6S%=.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)&US9R`N/2!S<')I;G1F*"1F;70L("1F:6QE+"`D
M:6YF;RD[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG:6=N;W)E+65R<F]R<R==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*"1M<V<I.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG
M<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YL;V<H,"P@(E=!4DY)3D<Z("1M<V<B*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`O+R!]
M?7T-"@T*("`@("`@("`D=&AI<RT^<W1A<G1&:6QE5')A;G-A8W1I;VXH*3L-
M"@T*("`@("`@("!I9B`H96UP='DH)&]P=&EO;G-;)W5P9W)A9&4G72D@)B8@
M96UP='DH)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("\O(&-H
M96-K<R!T;R!D;R!O;FQY('=H96X@:6YS=&%L;&EN9R!N97<@<&%C:V%G97,-
M"B`@("`@("`@("`@(&EF("@D8VAA;FYE;"`]/2`G<&5C;"YP:'`N;F5T)RD@
M>PT*("`@("`@("`@("`@("`@("1T97-T(#T@)&EN<W1A;&QR96=I<W1R>2T^
M<&%C:V%G945X:7-T<R@D<&MG;F%M92P@)&-H86YN96PI.PT*("`@("`@("`@
M("`@("`@(&EF("@A)'1E<W0I('L-"B`@("`@("`@("`@("`@("`@("`@)'1E
M<W0@/2`D:6YS=&%L;')E9VES=')Y+3YP86-K86=E17AI<W1S*"1P:V=N86UE
M+"`G<&5A<BYP:'`N;F5T)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D=&5S="`]("1I;G-T
M86QL<F5G:7-T<GDM/G!A8VMA9V5%>&ES=',H)'!K9VYA;64L("1C:&%N;F5L
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AE;7!T>2@D;W!T
M:6]N<ULG9F]R8V4G72D@)B8@)'1E<W0I('L-"B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(B1C:&%N;F5L+R1P:V=N86UE(&ES
M(&%L<F5A9'D@:6YS=&%L;&5D(BD[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`D=7-E8VAA;FYE;"`]("1C:&%N;F5L
M.PT*("`@("`@("`@("`@:68@*"1C:&%N;F5L(#T]("=P96-L+G!H<"YN970G
M*2![#0H@("`@("`@("`@("`@("`@)'1E<W0@/2`D:6YS=&%L;')E9VES=')Y
M+3YP86-K86=E17AI<W1S*"1P:V=N86UE+"`D8VAA;FYE;"D[#0H@("`@("`@
M("`@("`@("`@:68@*"$D=&5S="D@>PT*("`@("`@("`@("`@("`@("`@("`D
M=&5S="`]("1I;G-T86QL<F5G:7-T<GDM/G!A8VMA9V5%>&ES=',H)'!K9VYA
M;64L("=P96%R+G!H<"YN970G*3L-"B`@("`@("`@("`@("`@("`@("`@)'5S
M96-H86YN96P@/2`G<&5A<BYP:'`N;F5T)SL-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1T97-T
M(#T@)&EN<W1A;&QR96=I<W1R>2T^<&%C:V%G945X:7-T<R@D<&MG;F%M92P@
M)&-H86YN96PI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1T
M97-T*2![#0H@("`@("`@("`@("`@("`@)'8Q(#T@)&EN<W1A;&QR96=I<W1R
M>2T^<&%C:V%G94EN9F\H)'!K9VYA;64L("=V97)S:6]N)RP@)'5S96-H86YN
M96PI.PT*("`@("`@("`@("`@("`@("1V,B`]("1P:V<M/F=E=%9E<G-I;VXH
M*3L-"B`@("`@("`@("`@("`@("`D8VUP(#T@=F5R<VEO;E]C;VUP87)E*"(D
M=C$B+"`B)'8R(BP@)V=T)RD[#0H@("`@("`@("`@("`@("`@:68@*&5M<'1Y
M*"1O<'1I;VYS6R=F;W)C92==*2`F)B`A=F5R<VEO;E]C;VUP87)E*"(D=C(B
M+"`B)'8Q(BP@)V=T)RDI('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*")U<&=R861E('1O(&$@;F5W97(@=F5R<VEO
M;B`H)'8R(&ES(&YO="!N97=E<B!T:&%N("1V,2DB*3L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1O<'1I;VYS6R=R
M96=I<W1E<BUO;FQY)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("\O('=H
M96X@=7!G<F%D:6YG+"!R96UO=F4@;VQD(')E;&5A<V4G<R!F:6QE<R!F:7)S
M=#H-"B`@("`@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R
M<B`]("1T:&ES+3Y?9&5L971E4&%C:V%G949I;&5S*"1P:V=N86UE+"`D=7-E
M8VAA;FYE;"P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@=')U92DI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS
M6R=I9VYO<F4M97)R;W)S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1E<G(I.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,"P@
M)U=!4DY)3D<Z("<@+B`D97)R+3YG971-97-S86=E*"DI.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1B86-K961U<"`]("1E<G([#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"@T*("`@("`@("`O+R![>WL@0V]P>2!F:6QE<R!T;R!D97-T
M(&1I<B`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T-
M"@T*("`@("`@("`O+R!I;F9O(&9R;VT@=&AE('!A8VMA9V4@:70@<V5L9B!W
M92!W86YT('1O(&%C8V5S<R!F<F]M(%]I;G-T86QL1FEL90T*("`@("`@("`D
M=&AI<RT^<&MG:6YF;R`]("8D<&MG.PT*("`@("`@("`O+R!U<V5D('1O(&1E
M=&5R;6EN92!W:&5T:&5R('=E('-H;W5L9"!B=6EL9"!A;GD@0R!C;V1E#0H@
M("`@("`@("1T:&ES+3YS;W5R8V5?9FEL97,@/2`P.PT*#0H@("`@("`@("1S
M879E8VAA;FYE;"`]("1T:&ES+3YC;VYF:6<M/F=E="@G9&5F875L=%]C:&%N
M;F5L)RD[#0H@("`@("`@(&EF("AE;7!T>2@D;W!T:6]N<ULG<F5G:7-T97(M
M;VYL>2==*2`F)B`A:7-?9&ER*"1P:'!?9&ER*2D@>PT*("`@("`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H4WES=&5M.CIM:V1I<BAA<G)A>2@G+7`G*2P@
M)'!H<%]D:7(I*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@B;F\@:6YS=&%L;&%T:6]N(&1E<W1I;F%T:6]N(&1I<F5C
M=&]R>2`G)'!H<%]D:7(G7&XB*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*#0H@("`@("`@("1T;7!?<&%T:"`](&1I<FYA;64H)&1E<V-F:6QE*3L-
M"B`@("`@("`@:68@*'-U8G-T<B@D<&MG9FEL92P@+30I("$]("<N>&UL)RD@
M>PT*("`@("`@("`@("`@)'1M<%]P871H("X]($1)4D5#5$]265]315!!4D%4
M3U(@+B`D<&MG;F%M92`N("<M)R`N("1P:V<M/F=E=%9E<G-I;VXH*3L-"B`@
M("`@("`@?0T*#0H@("`@("`@("1T:&ES+3YC;VYF:6=3970H)V1E9F%U;'1?
M8VAA;FYE;"<L("1C:&%N;F5L*3L-"B`@("`@("`@+R\@>WM[(&EN<W1A;&P@
M9FEL97,-"B`@("`@("`@#0H@("`@("`@(&EF("@D<&MG+3YG971086-K86=E
M>&UL5F5R<VEO;B@I(#T]("<R+C`G*2![#0H@("`@("`@("`@("`D9FEL96QI
M<W0@/2`D<&MG+3YG971);G-T86QL871I;VY&:6QE;&ES="@I.PT*("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@)&9I;&5L:7-T(#T@)'!K9RT^9V5T
M1FEL94QI<W0H*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D9FEL96QI<W0I*2![#0H@("`@("`@("`@("!R971U<FX@)&9I;&5L
M:7-T.PT*("`@("`@("!]#0H@("`@("`@("1P:V<M/G)E<V5T1FEL96QI<W0H
M*3L-"B`@("`@("`@)'!K9RT^<V5T3&%S=$EN<W1A;&QE9%9E<G-I;VXH)&EN
M<W1A;&QR96=I<W1R>2T^<&%C:V%G94EN9F\H)'!K9RT^9V5T4&%C:V%G92@I
M+`T*("`@("`@("`@("`@)W9E<G-I;VXG+"`D<&MG+3YG971#:&%N;F5L*"DI
M*3L-"B`@("`@("`@9F]R96%C:"`H)&9I;&5L:7-T(&%S("1F:6QE(#T^("1A
M='1S*2![#0H@("`@("`@("`@("!I9B`H)'!K9RT^9V5T4&%C:V%G97AM;%9E
M<G-I;VXH*2`]/2`G,2XP)RD@>PT*("`@("`@("`@("`@("`@("1T:&ES+3YE
M>'!E8W1%<G)O<BA014%27TE.4U1!3$Q%4E]&04E,140I.PT*("`@("`@("`@
M("`@("`@("1R97,@/2`D=&AI<RT^7VEN<W1A;&Q&:6QE*"1F:6QE+"`D871T
M<RP@)'1M<%]P871H+"`D;W!T:6]N<RD[#0H@("`@("`@("`@("`@("`@)'1H
M:7,M/G!O<$5X<&5C="@I.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`D=&AI<RT^97AP96-T17)R;W(H4$5!4E])3E-404Q,15)?
M1D%)3$5$*3L-"B`@("`@("`@("`@("`@("`D<F5S(#T@)'1H:7,M/E]I;G-T
M86QL1FEL93(H)'!K9RP@)&9I;&4L("1A='1S+"`D=&UP7W!A=&@L("1O<'1I
M;VYS*3L-"B`@("`@("`@("`@("`@("`D=&AI<RT^<&]P17AP96-T*"D[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M<F5S*2D@>PT*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D;W!T:6]N<ULG
M:6=N;W)E+65R<F]R<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^<F]L;&)A8VM&:6QE5')A;G-A8W1I;VXH*3L-"B`@("`@("`@("`@("`@
M("`@("`@:68@*"1R97,M/F=E=$UE<W-A9V4H*2`]/2`B9FEL92!D;V5S(&YO
M="!E>&ES="(I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YR
M86ES945R<F]R*")F:6QE("1F:6QE(&EN('!A8VMA9V4N>&UL(&1O97,@;F]T
M(&5X:7-T(BD[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1R97,I.PT*("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YL;V<H,"P@(E=A<FYI;F<Z("(@+B`D<F5S+3YG
M971-97-S86=E*"DI.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1R
M97,@/3T@4$5!4E])3E-404Q,15)?3TLI('L-"B`@("`@("`@("`@("`@("`O
M+R!296=I<W1E<B!F:6QE<R!T:&%T('=E<F4@:6YS=&%L;&5D#0H@("`@("`@
M("`@("`@("`@)'!K9RT^:6YS=&%L;&5D1FEL92@D9FEL92P@)&%T=',I.PT*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("\O('U]?0T*#0H@
M("`@("`@("\O('M[>R!C;VUP:6QE(&%N9"!I;G-T86QL('-O=7)C92!F:6QE
M<PT*("`@("`@("!I9B`H)'1H:7,M/G-O=7)C95]F:6QE<R`^(#`@)B8@96UP
M='DH)&]P=&EO;G-;)VYO8G5I;&0G72DI('L-"B`@("`@("`@("`@(&EF("A0
M14%2.CII<T5R<F]R*"1E<G(@/0T*("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]C;VUP:6QE4V]U<F-E1FEL97,H)'-A=F5C:&%N;F5L+"`D<&MG*2DI('L-
M"B`@("`@("`@("`@("`@("!R971U<FX@)&5R<CL-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("`O+R!]?7T-"@T*("`@("`@("!I9B`H:7-S
M970H)&)A8VME9'5P*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]R96UO=F5"
M86-K=7!S*"1B86-K961U<"D[#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D
M=&AI<RT^8V]M;6ET1FEL951R86YS86-T:6]N*"DI('L-"B`@("`@("`@("`@
M("1T:&ES+3YR;VQL8F%C:T9I;&54<F%N<V%C=&EO;B@I.PT*("`@("`@("`@
M("`@)'1H:7,M/F-O;F9I9U-E="@G9&5F875L=%]C:&%N;F5L)RP@)'-A=F5C
M:&%N;F5L*3L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@B8V]M;6ET(&9A:6QE9"(L(%!%05)?24Y35$%,3$527T9!24Q%1"D[#0H@
M("`@("`@('T-"B`@("`@("`@+R\@?7U]#0H-"B`@("`@("`@)')E="`](&9A
M;'-E.PT*("`@("`@("`D:6YS=&%L;'!H87-E(#T@)VEN<W1A;&PG.PT*("`@
M("`@("`D;VQD=F5R<VEO;B`](&9A;'-E.PT*("`@("`@("`O+R![>WL@4F5G
M:7-T97(@=&AA="!T:&4@<&%C:V%G92!I<R!I;G-T86QL960@+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2T-"B`@("`@("`@:68@*&5M<'1Y*"1O<'1I;VYS6R=U
M<&=R861E)UTI*2![#0H@("`@("`@("`@("`O+R!I9B`G9F]R8V4G(&ES('5S
M960L(')E<&QA8V4@=&AE(&EN9F\@:6X@<F5G:7-T<GD-"B`@("`@("`@("`@
M("1U<V5C:&%N;F5L(#T@)&-H86YN96P[#0H@("`@("`@("`@("!I9B`H)&-H
M86YN96P@/3T@)W!E8VPN<&AP+FYE="<I('L-"B`@("`@("`@("`@("`@("`D
M=&5S="`]("1I;G-T86QL<F5G:7-T<GDM/G!A8VMA9V5%>&ES=',H)'!K9VYA
M;64L("1C:&%N;F5L*3L-"B`@("`@("`@("`@("`@("!I9B`H(21T97-T*2![
M#0H@("`@("`@("`@("`@("`@("`@("1T97-T(#T@)&EN<W1A;&QR96=I<W1R
M>2T^<&%C:V%G945X:7-T<R@D<&MG;F%M92P@)W!E87(N<&AP+FYE="<I.PT*
M("`@("`@("`@("`@("`@("`@("`D=7-E8VAA;FYE;"`]("=P96%R+G!H<"YN
M970G.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@)'1E<W0@/2`D:6YS=&%L;')E9VES=')Y+3YP
M86-K86=E17AI<W1S*"1P:V=N86UE+"`D8VAA;FYE;"D[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!I9B`H(65M<'1Y*"1O<'1I;VYS6R=F;W)C92==
M*2`F)B`D=&5S="D@>PT*("`@("`@("`@("`@("`@("1O;&1V97)S:6]N(#T@
M)&EN<W1A;&QR96=I<W1R>2T^<&%C:V%G94EN9F\H)'!K9VYA;64L("=V97)S
M:6]N)RP@)'5S96-H86YN96PI.PT*("`@("`@("`@("`@("`@("1I;G-T86QL
M<F5G:7-T<GDM/F1E;&5T95!A8VMA9V4H)'!K9VYA;64L("1U<V5C:&%N;F5L
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1R970@/2`D:6YS=&%L
M;')E9VES=')Y+3YA9&1086-K86=E,B@D<&MG*3L-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("1U<V5C:&%N;F5L(#T@)&-H86YN96P[#0H@("`@
M("`@("`@("!I9B`H)&-H86YN96P@/3T@)W!E8VPN<&AP+FYE="<I('L-"B`@
M("`@("`@("`@("`@("`D=&5S="`]("1I;G-T86QL<F5G:7-T<GDM/G!A8VMA
M9V5%>&ES=',H)'!K9VYA;64L("1C:&%N;F5L*3L-"B`@("`@("`@("`@("`@
M("!I9B`H(21T97-T*2![#0H@("`@("`@("`@("`@("`@("`@("1T97-T(#T@
M)&EN<W1A;&QR96=I<W1R>2T^<&%C:V%G945X:7-T<R@D<&MG;F%M92P@)W!E
M87(N<&AP+FYE="<I.PT*("`@("`@("`@("`@("`@("`@("`D=7-E8VAA;FYE
M;"`]("=P96%R+G!H<"YN970G.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)'1E<W0@/2`D:6YS
M=&%L;')E9VES=')Y+3YP86-K86=E17AI<W1S*"1P:V=N86UE+"`D8VAA;FYE
M;"D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`O+R!N97<Z('5P9W)A
M9&4@:6YS=&%L;',@82!P86-K86=E(&EF(&ET(&ES;B=T(&EN<W1A;&QE9`T*
M("`@("`@("`@("`@:68@*"$D=&5S="D@>PT*("`@("`@("`@("`@("`@("1R
M970@/2`D:6YS=&%L;')E9VES=')Y+3YA9&1086-K86=E,B@D<&MG*3L-"B`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@:68@*"1U<V5C
M:&%N;F5L("$]("1C:&%N;F5L*2![#0H@("`@("`@("`@("`@("`@("`@("1I
M;G-T86QL<F5G:7-T<GDM/F1E;&5T95!A8VMA9V4H)'!K9VYA;64L("1U<V5C
M:&%N;F5L*3L-"B`@("`@("`@("`@("`@("`@("`@)')E="`]("1I;G-T86QL
M<F5G:7-T<GDM/F%D9%!A8VMA9V4R*"1P:V<I.PT*("`@("`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1R970@/2`D:6YS=&%L
M;')E9VES=')Y+3YU<&1A=&5086-K86=E,B@D<&MG*3L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@)&EN<W1A;&QP:&%S92`]("=U<&=R
M861E)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M(21R970I('L-"B`@("`@("`@("`@("1T:&ES+3YC;VYF:6=3970H)V1E9F%U
M;'1?8VAA;FYE;"<L("1S879E8VAA;FYE;"D[#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H(D%D9&EN9R!P86-K86=E("1C:&%N;F5L
M+R1P:V=N86UE('1O(')E9VES=')Y(&9A:6QE9"(I.PT*("`@("`@("!]#0H@
M("`@("`@("\O('U]?0T*("`@("`@("`D=&AI<RT^8V]N9FEG4V5T*"=D969A
M=6QT7V-H86YN96PG+"`D<V%V96-H86YN96PI.PT*("`@("`@("!I9B`H8VQA
M<W-?97AI<W1S*"=014%27U1A<VM?0V]M;6]N)RDI('L@+R\@=&AI<R!I<R!A
M=71O+6EN8VQU9&5D(&EF(&%N>2!T87-K<R!E>&ES=`T*("`@("`@("`@("`@
M:68@*%!%05)?5&%S:U]#;VUM;VXZ.FAA<U!O<W1I;G-T86QL5&%S:W,H*2D@
M>PT*("`@("`@("`@("`@("`@(%!%05)?5&%S:U]#;VUM;VXZ.G)U;E!O<W1I
M;G-T86QL5&%S:W,H)&EN<W1A;&QP:&%S92D[#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("`@("`@<F5T=7)N("1P:V<M/G1O07)R87DH=')U92D[
M#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@7V-O;7!I;&53
M;W5R8V5&:6QE<R@I#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9PT*
M("`@("`J($!P87)A;2!014%27U!A8VMA9V5&:6QE7W8Q?%!%05)?4&%C:V%G
M949I;&5?=C(-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?8V]M<&EL95-O=7)C
M949I;&5S*"1S879E8VAA;FYE;"P@)B1F:6QE;&ES="D-"B`@("![#0H@("`@
M("`@(')E<75I<F5?;VYC92`G4$5!4B]"=6EL9&5R+G!H<"<[#0H@("`@("`@
M("1T:&ES+3YL;V<H,2P@(B1T:&ES+3YS;W5R8V5?9FEL97,@<V]U<F-E(&9I
M;&5S+"!B=6EL9&EN9R(I.PT*("`@("`@("`D8F]B(#T@)FYE=R!014%27T)U
M:6QD97(H)'1H:7,M/G5I*3L-"B`@("`@("`@)&)O8BT^9&5B=6<@/2`D=&AI
M<RT^9&5B=6<[#0H@("`@("`@("1B=6EL="`]("1B;V(M/F)U:6QD*"1F:6QE
M;&ES="P@87)R87DH)B1T:&ES+"`G7V)U:6QD0V%L;&)A8VLG*2D[#0H@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1B=6EL="DI('L-"B`@("`@("`@("`@
M("1T:&ES+3YR;VQL8F%C:T9I;&54<F%N<V%C=&EO;B@I.PT*("`@("`@("`@
M("`@)'1H:7,M/F-O;F9I9U-E="@G9&5F875L=%]C:&%N;F5L)RP@)'-A=F5C
M:&%N;F5L*3L-"B`@("`@("`@("`@(')E='5R;B`D8G5I;'0[#0H@("`@("`@
M('T-"B`@("`@("`@)'1H:7,M/FQO9R@Q+"`B7&Y"=6EL9"!P<F]C97-S(&-O
M;7!L971E9"!S=6-C97-S9G5L;'DB*3L-"B`@("`@("`@9F]R96%C:"`H)&)U
M:6QT(&%S("1E>'0I('L-"B`@("`@("`@("`@("1B;B`](&)A<V5N86UE*"1E
M>'1;)V9I;&4G72D[#0H@("`@("`@("`@("!L:7-T*"1?97AT7VYA;64L("1?
M97AT7W-U9F8I(#T@97AP;&]D92@G+B<L("1B;BD[#0H@("`@("`@("`@("!I
M9B`H)%]E>'1?<W5F9B`]/2`G+G-O)R!\?"`D7V5X=%]S=69F(#T]("<N9&QL
M)RD@>PT*("`@("`@("`@("`@("`@(&EF("AE>'1E;G-I;VY?;&]A9&5D*"1?
M97AT7VYA;64I*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YR86ES
M945R<F]R*")%>'1E;G-I;VX@)R1?97AT7VYA;64G(&%L<F5A9'D@;&]A9&5D
M+B`B("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)U!L96%S92!U;FQO860@:70@:6X@>6]U<B!P:'`N:6YI(&9I;&4@)R`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P<FEO<B!T
M;R!I;G-T86QL(&]R('5P9W)A9&4G*3L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@)')O;&4@/2`G97AT)SL-"B`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@)')O;&4@/2`G<W)C)SL-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("1D97-T(#T@)&5X=%LG9&5S="==.PT*
M("`@("`@("`@("`@)'1H:7,M/FQO9R@Q+"`B26YS=&%L;&EN9R`G)&5X=%MF
M:6QE72<B*3L-"B`@("`@("`@("`@("1P86-K86=I;F=R;V]T(#T@)R<[#0H@
M("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]O<'1I;VYS6R=P86-K86=I
M;F=R;V]T)UTI*2![#0H@("`@("`@("`@("`@("`@)'!A8VMA9VEN9W)O;W0@
M/2`D=&AI<RT^7V]P=&EO;G-;)W!A8VMA9VEN9W)O;W0G73L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("1C;W!Y=&\@/2`D=&AI<RT^7W!R97!E;F10
M871H*"1D97-T+"`D<&%C:V%G:6YG<F]O="D[#0H@("`@("`@("`@("`D8V]P
M>61I<B`](&1I<FYA;64H)&-O<'ET;RD[#0H@("`@("`@("`@("`O+R!P<F5T
M='D@;75C:"!N;W1H:6YG(&AA<'!E;G,@:68@=V4@87)E(&]N;'D@<F5G:7-T
M97)I;F<@=&AE(&EN<W1A;&P-"B`@("`@("`@("`@(&EF("AE;7!T>2@D=&AI
M<RT^7V]P=&EO;G-;)W)E9VES=&5R+6]N;'DG72DI('L-"B`@("`@("`@("`@
M("`@("!I9B`H(4!I<U]D:7(H)&-O<'ED:7(I*2![#0H@("`@("`@("`@("`@
M("`@("`@(&EF("@A)'1H:7,M/FUK1&ER2&EE<B@D8V]P>61I<BDI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@B9F%I;&5D('1O(&UK9&ER("1C;W!Y9&ER(BP-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!014%27TE.4U1!3$Q%4E]&04E,140I.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL
M;V<H,RP@(BL@;6MD:7(@)&-O<'ED:7(B*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@:68@*"%`8V]P>2@D97AT6R=F:6QE)UTL("1C
M;W!Y=&\I*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@B9F%I;&5D('1O('=R:71E("1C;W!Y=&\B+"!014%27TE.
M4U1!3$Q%4E]&04E,140I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`D=&AI<RT^;&]G*#,L("(K(&-P("1E>'1;9FEL95T@)&-O<'ET
M;R(I.PT*("`@("`@("`@("`@("`@(&EF("@A3U-?5TE.1$]74RD@>PT*("`@
M("`@("`@("`@("`@("`@("`D;6]D92`](#`V-C8@)B!^*&EN="EO8W1D96,H
M)'1H:7,M/F-O;F9I9RT^9V5T*"=U;6%S:R<I*3L-"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/F%D9$9I;&5/<&5R871I;VXH)V-H;6]D)RP@87)R87DH
M)&UO9&4L("1C;W!Y=&\I*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%`
M8VAM;V0H)&-O<'ET;RP@)&UO9&4I*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^;&]G*#`L(")F86EL960@=&\@8VAA;F=E(&UO9&4@;V8@
M)&-O<'ET;R(I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("1T:&ES+3YA9&1&:6QE3W!E<F%T
M:6]N*"=R96YA;64G+"!A<G)A>2@D97AT6R=F:6QE)UTL("1C;W!Y=&\I*3L-
M"B`@("`@("`@("`@('T-"@T*("`@("`@("`@("`@:68@*"1F:6QE;&ES="T^
M9V5T4&%C:V%G95AM;%9E<G-I;VXH*2`]/2`G,2XP)RD@>PT*("`@("`@("`@
M("`@("`@("1F:6QE;&ES="T^:6YS=&%L;&5D1FEL92@D8FXL(&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("`@("`G<F]L92<@/3X@)')O;&4L#0H@("`@("`@
M("`@("`@("`@("`@("=N86UE)R`]/B`D8FXL#0H@("`@("`@("`@("`@("`@
M("`@("=I;G-T86QL961?87,G(#T^("1D97-T+`T*("`@("`@("`@("`@("`@
M("`@("`G<&AP7V%P:2<@/3X@)&5X=%LG<&AP7V%P:2==+`T*("`@("`@("`@
M("`@("`@("`@("`G>F5N9%]M;V1?87!I)R`]/B`D97AT6R=Z96YD7VUO9%]A
M<&DG72P-"B`@("`@("`@("`@("`@("`@("`@)WIE;F1?97AT7V%P:2<@/3X@
M)&5X=%LG>F5N9%]E>'1?87!I)UTL#0H@("`@("`@("`@("`@("`@("`@("DI
M.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D9FEL
M96QI<W0M/FEN<W1A;&QE9$9I;&4H)&)N+"!A<G)A>2@G871T<FEB<R<@/3X@
M87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=R;VQE)R`]/B`D<F]L92P-
M"B`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^("1B;BP-"B`@("`@("`@
M("`@("`@("`@("`@)VEN<W1A;&QE9%]A<R<@/3X@)&1E<W0L#0H@("`@("`@
M("`@("`@("`@("`@("=P:'!?87!I)R`]/B`D97AT6R=P:'!?87!I)UTL#0H@
M("`@("`@("`@("`@("`@("`@("=Z96YD7VUO9%]A<&DG(#T^("1E>'1;)WIE
M;F1?;6]D7V%P:2==+`T*("`@("`@("`@("`@("`@("`@("`G>F5N9%]E>'1?
M87!I)R`]/B`D97AT6R=Z96YD7V5X=%]A<&DG72P-"B`@("`@("`@("`@("`@
M("`@("`@*2DI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*
M#0H@("`@+R\@?7U]#0H@("`@9G5N8W1I;VX@)F=E=%5N:6YS=&%L;%!A8VMA
M9V5S*"D-"B`@("![#0H@("`@("`@(')E='5R;B`D=&AI<RT^7V1O=VYL;V%D
M961086-K86=E<SL-"B`@("!]#0H@("`@+R\@>WM[('5N:6YS=&%L;"@I#0H-
M"B`@("`O*BH-"B`@("`@*B!5;FEN<W1A;&P@82!P86-K86=E#0H@("`@("H-
M"B`@("`@*B!4:&ES(&UE=&AO9"!R96UO=F5S(&%L;"!F:6QE<R!I;G-T86QL
M960@8GD@=&AE(&%P<&QI8V%T:6]N+"!A;F0@=&AE;@T*("`@("`J(')E;6]V
M97,@86YY(&5M<'1Y(&1I<F5C=&]R:65S+@T*("`@("`J($!P87)A;2!S=')I
M;F<@<&%C:V%G92!N86UE#0H@("`@("H@0'!A<F%M(&%R<F%Y($-O;6UA;F0M
M;&EN92!O<'1I;VYS+B`@4&]S<VEB:6QI=&EE<R!I;F-L=61E.@T*("`@("`J
M#0H@("`@("H@("`@("`@("`@("`@("T@:6YS=&%L;')O;W0Z(&)A<V4@:6YS
M=&%L;&%T:6]N(&1I<BP@:68@;F]T('1H92!D969A=6QT#0H@("`@("H@("`@
M("`@("`@("`@("T@;F]D97!S.B!D;R!N;W0@<')O8V5S<R!D97!E;F1E;F-I
M97,@;V8@;W1H97(@<&%C:V%G97,@=&\@96YS=7)E#0H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("!U;FEN<W1A;&QA=&EO;B!D;V5S(&YO="!B<F5A
M:R!T:&EN9W,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!U;FEN<W1A;&PH)'!A
M8VMA9V4L("1O<'1I;VYS(#T@87)R87DH*2D-"B`@("![#0H@("`@("`@(&EF
M("AI<W-E="@D;W!T:6]N<ULG:6YS=&%L;')O;W0G72DI('L-"B`@("`@("`@
M("`@("1T:&ES+3YC;VYF:6<M/G-E=$EN<W1A;&Q2;V]T*"1O<'1I;VYS6R=I
M;G-T86QL<F]O="==*3L-"B`@("`@("`@("`@("1T:&ES+3YI;G-T86QL<F]O
M="`]("<G.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'1H:7,M
M/F-O;F9I9RT^<V5T26YS=&%L;%)O;W0H)R<I.PT*("`@("`@("`@("`@)'1H
M:7,M/FEN<W1A;&QR;V]T(#T@)R<[#0H@("`@("`@('T-"B`@("`@("`@)'1H
M:7,M/E]R96=I<W1R>2`]("8D=&AI<RT^8V]N9FEG+3YG971296=I<W1R>2@I
M.PT*("`@("`@("!I9B`H:7-?;V)J96-T*"1P86-K86=E*2D@>PT*("`@("`@
M("`@("`@)&-H86YN96P@/2`D<&%C:V%G92T^9V5T0VAA;FYE;"@I.PT*("`@
M("`@("`@("`@)'!K9R`]("1P86-K86=E.PT*("`@("`@("`@("`@)'!A8VMA
M9V4@/2`D<&MG+3YG971086-K86=E*"D[#0H@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`D<&MG(#T@9F%L<V4[#0H@("`@("`@("`@("`D:6YF;R`]
M("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E4&%C:V%G94YA;64H)'!A8VMA9V4L
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/F-O;F9I9RT^9V5T*"=D969A=6QT
M7V-H86YN96PG*2D[#0H@("`@("`@("`@("`D8VAA;FYE;"`]("1I;F9O6R=C
M:&%N;F5L)UT[#0H@("`@("`@("`@("`D<&%C:V%G92`]("1I;F9O6R=P86-K
M86=E)UT[#0H@("`@("`@('T-"B`@("`@("`@)'-A=F5C:&%N;F5L(#T@)'1H
M:7,M/F-O;F9I9RT^9V5T*"=D969A=6QT7V-H86YN96PG*3L-"B`@("`@("`@
M)'1H:7,M/F-O;F9I9U-E="@G9&5F875L=%]C:&%N;F5L)RP@)&-H86YN96PI
M.PT*("`@("`@("!I9B`H(6ES7V]B:F5C="@D<&MG*2D@>PT*("`@("`@("`@
M("`@)'!K9R`]("1T:&ES+3Y?<F5G:7-T<GDM/F=E=%!A8VMA9V4H)'!A8VMA
M9V4L("1C:&%N;F5L*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21P:V<I
M('L-"B`@("`@("`@("`@("1T:&ES+3YC;VYF:6=3970H)V1E9F%U;'1?8VAA
M;FYE;"<L("1S879E8VAA;FYE;"D[#0H@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H)'1H:7,M/E]R96=I<W1R>2T^<&%R<V5D4&%C:V%G
M94YA;654;U-T<FEN9R@-"B`@("`@("`@("`@("`@("!A<G)A>2@-"B`@("`@
M("`@("`@("`@("`@("`@)V-H86YN96PG(#T^("1C:&%N;F5L+`T*("`@("`@
M("`@("`@("`@("`@("`G<&%C:V%G92<@/3X@)'!A8VMA9V4-"B`@("`@("`@
M("`@("`@("`I+"!T<G5E*2`N("<@;F]T(&EN<W1A;&QE9"<I.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("@D<&MG+3YG971);G-T86QL961":6YA<GDH*2D@
M>PT*("`@("`@("`@("`@+R\@=&AI<R!I<R!J=7-T(&%N(&%L:6%S(&9O<B!A
M(&)I;F%R>2!P86-K86=E#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R
M96=I<W1R>2T^9&5L971E4&%C:V%G92@D<&%C:V%G92P@)&-H86YN96PI.PT*
M("`@("`@("!]#0H@("`@("`@("1F:6QE;&ES="`]("1P:V<M/F=E=$9I;&5L
M:7-T*"D[#0H@("`@("`@(%!%05(Z.G-T871I8U!U<VA%<G)O<DAA;F1L:6YG
M*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES
M=',H)U!%05)?1&5P96YD96YC>3(G*2D@>PT*("`@("`@("`@("`@<F5Q=6ER
M95]O;F-E("=014%2+T1E<&5N9&5N8WDR+G!H<"<[#0H@("`@("`@('T-"B`@
M("`@("`@)&1E<&-H96-K97(@/2`F;F5W(%!%05)?1&5P96YD96YC>3(H)'1H
M:7,M/F-O;F9I9RP@)&]P=&EO;G,L(`T*("`@("`@("`@("`@87)R87DH)V-H
M86YN96PG(#T^("1C:&%N;F5L+"`G<&%C:V%G92<@/3X@)'!A8VMA9V4I+`T*
M("`@("`@("`@("`@4$5!4E]604Q)1$%415]53DE.4U1!3$Q)3D<I.PT*("`@
M("`@("`D92`]("1D97!C:&5C:V5R+3YV86QI9&%T95!A8VMA9V55;FEN<W1A
M;&PH)'1H:7,I.PT*("`@("`@("!014%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L
M:6YG*"D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E*2D@>PT*("`@
M("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG:6=N;W)E+65R<F]R<R==
M*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@D92D[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M(&EF("@A:7-S970H)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/FQO9R@P+"`G5T%23DE.1SH@)R`N("1E+3YG971-
M97-S86=E*"DI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y*"1E*2D@>PT*("`@("`@("`@
M("`@:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@
M("`@("`@("1T:&ES+3YL;V<H,"P@)&5;,%TI.PT*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@("\O('M[>R!$96QE=&4@=&AE(&9I;&5S#0H@
M("`@("`@("1T:&ES+3YS=&%R=$9I;&54<F%N<V%C=&EO;B@I.PT*("`@("`@
M("!014%2.CIP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[
M#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G(@/2`D=&AI<RT^7V1E
M;&5T95!A8VMA9V5&:6QE<R@D<&%C:V%G92P@)&-H86YN96PI*2D@>PT*("`@
M("`@("`@("`@4$5!4CHZ<&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`@
M("`@)'1H:7,M/G)O;&QB86-K1FEL951R86YS86-T:6]N*"D[#0H@("`@("`@
M("`@("`D=&AI<RT^8V]N9FEG4V5T*"=D969A=6QT7V-H86YN96PG+"`D<V%V
M96-H86YN96PI.PT*("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG
M:6=N;W)E+65R<F]R<R==*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@D97)R*3L-"B`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L("=705).
M24Y'.B`G("X@)&5R<BT^9V5T365S<V%G92@I*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("!014%2.CIP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"$D=&AI<RT^8V]M;6ET1FEL951R86YS86-T:6]N*"DI('L-
M"B`@("`@("`@("`@("1T:&ES+3YR;VQL8F%C:T9I;&54<F%N<V%C=&EO;B@I
M.PT*("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG:6=N;W)E+65R
M<F]R<R==*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@B=6YI;G-T86QL(&9A:6QE9"(I.PT*("`@("`@("`@("`@?2!E
M;'-E:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@
M("`@("`@("1T:&ES+3YL;V<H,"P@)U=!4DY)3D<Z('5N:6YS=&%L;"!F86EL
M960G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("1T:&ES+3YS=&%R=$9I;&54<F%N<V%C=&EO;B@I.PT*("`@("`@
M("`@("`@:68@*"1D:7)T<F5E(#T@)'!K9RT^9V5T1&ER5')E92@I*2![#0H@
M("`@("`@("`@("`@("`@+R\@871T96UP="!T;R!D96QE=&4@96UP='D@9&ER
M96-T;W)I97,-"B`@("`@("`@("`@("`@("!U:W-O<G0H)&1I<G1R964L(&%R
M<F%Y*"1T:&ES+"`G7W-O<G1$:7)S)RDI.PT*("`@("`@("`@("`@("`@(&9O
M<F5A8V@H)&1I<G1R964@87,@)&1I<B`]/B`D;F]T=7-E9"D@>PT*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^861D1FEL94]P97)A=&EO;B@G<FUD:7(G
M+"!A<G)A>2@D9&ER*2D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^8V]N9FEG4V5T
M*"=D969A=6QT7V-H86YN96PG+"`D<V%V96-H86YN96PI.PT*("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7W)E9VES=')Y+3YD96QE=&5086-K86=E
M*"1P86-K86=E+"`D8VAA;FYE;"D[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!I9B`H(21T:&ES+3YC;VUM:71&:6QE5')A;G-A8W1I;VXH*2D@>PT*
M("`@("`@("`@("`@("`@("1T:&ES+3YR;VQL8F%C:T9I;&54<F%N<V%C=&EO
M;B@I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("\O('U]
M?0T*#0H@("`@("`@("1T:&ES+3YC;VYF:6=3970H)V1E9F%U;'1?8VAA;FYE
M;"<L("1S879E8VAA;FYE;"D[#0H@("`@("`@("\O(%)E9VES=&5R('1H870@
M=&AE('!A8VMA9V4@:7,@;F\@;&]N9V5R(&EN<W1A;&QE9`T*("`@("`@("!R
M971U<FX@)'1H:7,M/E]R96=I<W1R>2T^9&5L971E4&%C:V%G92@D<&%C:V%G
M92P@)&-H86YN96PI.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%-O<G0@
M82!L:7-T(&]F(&%R<F%Y<R!O9B!A<G)A>2AD;W=N;&]A9&5D('!A8VMA9V5F
M:6QE;F%M92D@8GD@9&5P96YD96YC>2X-"B`@("`@*@T*("`@("`J($ET(&%L
M<V\@<F5M;W9E<R!D=7!L:6-A=&4@9&5P96YD96YC:65S#0H@("`@("H@0'!A
M<F%M(&%R<F%Y(&%N(&%R<F%Y(&]F(%!%05)?4&%C:V%G949I;&5?=ELQ+S)=
M(&]B:F5C=',-"B`@("`@*B!`<F5T=7)N(&%R<F%Y?%!%05)?17)R;W(@87)R
M87D@;V8@87)R87DH<&%C:V%G969I;&5N86UE+"!P86-K86=E+GAM;"!C;VYT
M96YT<RD-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S;W)T4&%C:V%G97-&;W)5
M;FEN<W1A;&PH)B1P86-K86=E<RD-"B`@("![#0H@("`@("`@("1T:&ES+3Y?
M9&5P96YD96YC>41"(#T@)E!%05)?1&5P96YD96YC>41".CIS:6YG;&5T;VXH
M)'1H:7,M/F-O;F9I9RD[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1T
M:&ES+3Y?9&5P96YD96YC>41"*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?9&5P96YD96YC>41".PT*("`@("`@("!]#0H@("`@("`@('5S;W)T
M*"1P86-K86=E<RP@87)R87DH)B1T:&ES+"`G7W-O<G15;FEN<W1A;&PG*2D[
M#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7W-O<G15;FEN<W1A;&PH)&$L("1B
M*0T*("`@('L-"B`@("`@("`@:68@*"$D82T^9V5T1&5P<R@I("8F("$D8BT^
M9V5T1&5P<R@I*2![#0H@("`@("`@("`@("!R971U<FX@,#L@+R\@;F5I=&AE
M<B!P86-K86=E(&AA<R!D97!E;F1E;F-I97,L(&]R9&5R(&ES(&EN<VEG;FEF
M:6-A;G0-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&$M/F=E=$1E<',H*2`F
M)B`A)&(M/F=E=$1E<',H*2D@>PT*("`@("`@("`@("`@<F5T=7)N("TQ.R`O
M+R`D82!M=7-T(&)E(&EN<W1A;&QE9"!A9G1E<B`D8B!B96-A=7-E("1A(&AA
M<R!D97!E;F1E;F-I97,-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21A+3YG
M971$97!S*"D@)B8@)&(M/F=E=$1E<',H*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N(#$[("\O("1B(&UU<W0@8F4@:6YS=&%L;&5D(&%F=&5R("1A(&)E8V%U
M<V4@)&(@:&%S(&1E<&5N9&5N8VEE<PT*("`@("`@("!]#0H@("`@("`@("\O
M(&)O=&@@<&%C:V%G97,@:&%V92!D97!E;F1E;F-I97,-"B`@("`@("`@:68@
M*"1T:&ES+3Y?9&5P96YD96YC>41"+3YD97!E;F1S3VXH)&$L("1B*2D@>PT*
M("`@("`@("`@("`@<F5T=7)N("TQ.PT*("`@("`@("!]#0H@("`@("`@(&EF
M("@D=&AI<RT^7V1E<&5N9&5N8WE$0BT^9&5P96YD<T]N*"1B+"`D82DI('L-
M"B`@("`@("`@("`@(')E='5R;B`Q.PT*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B`P.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!?<V]R
M=$1I<G,H*0T*("`@(&9U;F-T:6]N(%]S;W)T1&ER<R@D82P@)&(I#0H@("`@
M>PT*("`@("`@("!I9B`H<W1R;F%T8VUP*"1A+"`D8BD@/3T@+3$I(')E='5R
M;B`Q.PT*("`@("`@("!I9B`H<W1R;F%T8VUP*"1A+"`D8BD@/3T@,2D@<F5T
M=7)N("TQ.PT*("`@("`@("!R971U<FX@,#L-"B`@("!]#0H-"B`@("`O+R!]
M?7T-"@T*("`@("\O('M[>R!?8G5I;&1#86QL8F%C:R@I#0H-"B`@("!F=6YC
M=&EO;B!?8G5I;&1#86QL8F%C:R@D=VAA="P@)&1A=&$I#0H@("`@>PT*("`@
M("`@("!I9B`H*"1W:&%T(#T]("=C;61O=71P=70G("8F("1T:&ES+3YD96)U
M9R`^(#$I('Q\#0H@("`@("`@("`@("`H)'=H870@/3T@)V]U='!U="<@)B8@
M)'1H:7,M/F1E8G5G(#X@,"DI('L-"B`@("`@("`@("`@("1T:&ES+3YU:2T^
M;W5T<'5T1&%T82AR=')I;2@D9&%T82DL("=B=6EL9"<I.PT*("`@("`@("!]
M#0H@("`@?0T*#0H@("`@+R\@?7U]#0I]#0H-"B\O('M[>R!M9#5?9FEL92@I
M('5T:6QI='D@9G5N8W1I;VX-"FEF("@A9G5N8W1I;VY?97AI<W1S*")M9#5?
M9FEL92(I*2![#0H@("`@9G5N8W1I;VX@;60U7V9I;&4H)&9I;&5N86UE*2![
M#0H@("`@("`@("1F<"`](&9O<&5N*"1F:6QE;F%M92P@(G(B*3L-"B`@("`@
M("`@:68@*"$D9G`I(')E='5R;B!N=6QL.PT*("`@("`@("!I9B`H9G5N8W1I
M;VY?97AI<W1S*"=F:6QE7V=E=%]C;VYT96YT<R<I*2![#0H@("`@("`@("`@
M("!F8VQO<V4H)&9P*3L-"B`@("`@("`@("`@("1C;VYT96YT<R`](&9I;&5?
M9V5T7V-O;G1E;G1S*"1F:6QE;F%M92D[#0H@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`D8V]N=&5N=',@/2!F<F5A9"@D9G`L(&9I;&5S:7IE*"1F
M:6QE;F%M92DI.PT*("`@("`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N(&UD-2@D8V]N=&5N=',I.PT*("`@('T-"GT-
M"B\O('U]?0T*#0H_/@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]0
M14%2+U)E;6]T92YP:'``````````````````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#0U,S8S(#$P-3$U-#,S-S,R(#`R,3$W,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`T*+RHJ#0H@
M*B!014%27U)E;6]T90T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@
M*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O
M('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A
M=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O
M;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S
M7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J
M('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@
M=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI
M8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D
M:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E
M("`@(%!%05(-"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP
M+FYE=#X-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP
M+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P
M#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S
M7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@
M)$ED.B!296UO=&4N<&AP+'8@,2XW-B`R,#`V+S`S+S`R(#$X.C$T.C$S(&-E
M;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE
M="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE
M('-I;F-E(%)E;&5A<V4@,"XQ#0H@*B\-"@T*+RHJ#0H@*B!N965D960@9F]R
M(%!%05)?17)R;W(-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2+G!H<"<[#0IR
M97%U:7)E7V]N8V4@)U!%05(O0V]N9FEG+G!H<"<[#0H-"B\J*@T*("H@5&AI
M<R!I<R!A(&-L87-S(&9O<B!D;VEN9R!R96UO=&4@;W!E<F%T:6]N<R!A9V%I
M;G-T('1H92!C96YT<F%L#0H@*B!014%2(&1A=&%B87-E+@T*("H-"B`J($!N
M;V1E<"!834Q?4E!#7U9A;'5E#0H@*B!`;F]D97`@6$U,7U)00U]-97-S86=E
M#0H@*B!`;F]D97`@6$U,7U)00U]#;&EE;G0-"B`J($!C871E9V]R>2`@('!E
M87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@(%-T:6<@
M0F%K:V5N(#QS<V)`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@($=R96<@0F5A
M=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P
M-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V
M97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P
M.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@
M0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,"XQ#0H@*B\-"F-L87-S
M(%!%05)?4F5M;W1E(&5X=&5N9',@4$5!4@T*>PT*("`@("\O('M[>R!P<F]P
M97)T:65S#0H-"B`@("!V87(@)&-O;F9I9R`](&YU;&P[#0H@("`@=F%R("1C
M86-H92`@/2!N=6QL.PT*("`@("\J*@T*("`@("`J($!V87(@4$5!4E]296=I
M<W1R>0T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A
M<B`D7W)E9VES=')Y.PT*#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@4$5!
M4E]296UO=&4H8V]N9FEG7V]B:F5C="D-"@T*("`@(&9U;F-T:6]N(%!%05)?
M4F5M;W1E*"8D8V]N9FEG*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E!%05(H
M*3L-"B`@("`@("`@)'1H:7,M/F-O;F9I9R`]("8D8V]N9FEG.PT*("`@("`@
M("`D=&AI<RT^7W)E9VES=')Y(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES
M=')Y*"D[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[('-E=%)E
M9VES=')Y*"D-"B`@("`-"B`@("!F=6YC=&EO;B!S971296=I<W1R>2@F)')E
M9RD-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<F5G:7-T<GD@/2`F)')E9SL-
M"B`@("!]#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&=E=$-A8VAE*"D-"@T*
M#0H@("`@9G5N8W1I;VX@9V5T0V%C:&4H)&%R9W,I#0H@("`@>PT*("`@("`@
M("`D:60@("`@("`@/2!M9#4H<V5R:6%L:7IE*"1A<F=S*2D[#0H@("`@("`@
M("1C86-H961I<B`]("1T:&ES+3YC;VYF:6<M/F=E="@G8V%C:&5?9&ER)RD[
M#0H@("`@("`@("1F:6QE;F%M92`]("1C86-H961I<B`N($1)4D5#5$]265]3
M15!!4D%43U(@+B`G>&UL<G!C7V-A8VAE7R<@+B`D:60[#0H@("`@("`@(&EF
M("@A9FEL95]E>&ES=',H)&9I;&5N86UE*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N(&YU;&P[#0H@("`@("`@('T-"@T*("`@("`@("`D9G`@/2!F;W!E;B@D
M9FEL96YA;64L("=R8B<I.PT*("`@("`@("!I9B`H(21F<"D@>PT*("`@("`@
M("`@("`@<F5T=7)N(&YU;&P[#0H@("`@("`@('T-"B`@("`@("`@:68@*&9U
M;F-T:6]N7V5X:7-T<R@G9FEL95]G971?8V]N=&5N=',G*2D@>PT*("`@("`@
M("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@("`@("`D8V]N=&5N="`](&9I
M;&5?9V5T7V-O;G1E;G1S*"1F:6QE;F%M92D[#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`D8V]N=&5N="`@/2!F<F5A9"@D9G`L(&9I;&5S:7IE
M*"1F:6QE;F%M92DI.PT*("`@("`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@
M("`@('T-"B`@("`@("`@)')E<W5L="`@(#T@87)R87DH#0H@("`@("`@("`@
M("`G86=E)R`@("`@("`@/3X@=&EM92@I("T@9FEL96UT:6UE*"1F:6QE;F%M
M92DL#0H@("`@("`@("`@("`G;&%S=$-H86YG92<@/3X@9FEL96UT:6UE*"1F
M:6QE;F%M92DL#0H@("`@("`@("`@("`G8V]N=&5N="<@("`@/3X@=6YS97)I
M86QI>F4H)&-O;G1E;G0I+`T*("`@("`@("`@("`@*3L-"B`@("`@("`@<F5T
M=7)N("1R97-U;'0[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-"B`@("`O+R![
M>WL@<V%V94-A8VAE*"D-"@T*("`@(&9U;F-T:6]N('-A=F5#86-H92@D87)G
M<RP@)&1A=&$I#0H@("`@>PT*("`@("`@("`D:60@("`@("`@/2!M9#4H<V5R
M:6%L:7IE*"1A<F=S*2D[#0H@("`@("`@("1C86-H961I<B`]("1T:&ES+3YC
M;VYF:6<M/F=E="@G8V%C:&5?9&ER)RD[#0H@("`@("`@(&EF("@A9FEL95]E
M>&ES=',H)&-A8VAE9&ER*2D@>PT*("`@("`@("`@("`@4WES=&5M.CIM:V1I
M<BAA<G)A>2@G+7`G+"`D8V%C:&5D:7(I*3L-"B`@("`@("`@?0T*("`@("`@
M("`D9FEL96YA;64@/2`D8V%C:&5D:7(N)R]X;6QR<&-?8V%C:&5?)RXD:60[
M#0H-"B`@("`@("`@)&9P(#T@0&9O<&5N*"1F:6QE;F%M92P@(G=B(BD[#0H@
M("`@("`@(&EF("@D9G`I('L-"B`@("`@("`@("`@(&9W<FET92@D9G`L('-E
M<FEA;&EZ92@D9&%T82DI.PT*("`@("`@("`@("`@9F-L;W-E*"1F<"D[#0H@
M("`@("`@('T-"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!C
M;&5A<D-A8VAE*"D-"@T*("`@(&9U;F-T:6]N(&-L96%R0V%C:&4H)&UE=&AO
M9"P@)&%R9W,I#0H@("`@>PT*("`@("`@("!A<G)A>5]U;G-H:69T*"1A<F=S
M+"`D;65T:&]D*3L-"B`@("`@("`@87)R87E?=6YS:&EF="@D87)G<RP@)'1H
M:7,M/F-O;F9I9RT^9V5T*"=D969A=6QT7V-H86YN96PG*2D[("\O(&-A8VAE
M(&)Y(&-H86YN96P-"B`@("`@("`@)&ED("`@("`@(#T@;60U*'-E<FEA;&EZ
M92@D87)G<RDI.PT*("`@("`@("`D8V%C:&5D:7(@/2`D=&AI<RT^8V]N9FEG
M+3YG970H)V-A8VAE7V1I<B<I.PT*("`@("`@("`D9FEL96YA;64@/2`D8V%C
M:&5D:7(N)R]X;6QR<&-?8V%C:&5?)RXD:60[#0H@("`@("`@(&EF("AF:6QE
M7V5X:7-T<R@D9FEL96YA;64I*2![#0H@("`@("`@("`@("!`=6YL:6YK*"1F
M:6QE;F%M92D[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@
M("`O+R![>WL@8V%L;"AM971H;V0L(%MA<F=S+BXN72D-"@T*("`@(&9U;F-T
M:6]N(&-A;&PH)&UE=&AO9"D-"B`@("![#0H@("`@("`@("1?87)G<R`]("1A
M<F=S(#T@9G5N8U]G971?87)G<R@I.PT*#0H@("`@("`@("1S97)V97)?8VAA
M;FYE;"`]("1T:&ES+3YC;VYF:6<M/F=E="@G9&5F875L=%]C:&%N;F5L)RD[
M#0H@("`@("`@("1C:&%N;F5L(#T@)'1H:7,M/E]R96=I<W1R>2T^9V5T0VAA
M;FYE;"@D<V5R=F5R7V-H86YN96PI.PT*("`@("`@("!I9B`H(5!%05(Z.FES
M17)R;W(H)&-H86YN96PI*2![#0H@("`@("`@("`@("`D;6ER<F]R(#T@)'1H
M:7,M/F-O;F9I9RT^9V5T*"=P<F5F97)R961?;6ER<F]R)RD[#0H@("`@("`@
M("`@("!I9B`H)&-H86YN96PM/F=E=$UI<G)O<B@D;6ER<F]R*2D@>PT*("`@
M("`@("`@("`@("`@(&EF("@D8VAA;FYE;"T^<W5P<&]R=',H)WAM;')P8R<L
M("1M971H;V0L("1M:7)R;W(I*2![#0H@("`@("`@("`@("`@("`@("`@("1S
M97)V97)?8VAA;FYE;"`]("1S97)V97)?:&]S="`]("1M:7)R;W([("\O('5S
M92!T:&4@<')E9F5R<F5D(&UI<G)O<@T*("`@("`@("`@("`@("`@("`@("`D
M<V5R=F5R7W!O<G0@/2`D8VAA;FYE;"T^9V5T4&]R="@D;6ER<F]R*3L-"B`@
M("`@("`@("`@("`@("!](&5L<V5I9B`H(21C:&%N;F5L+3YS=7!P;W)T<R@G
M>&UL<G!C)RP@)&UE=&AO9"DI('L-"B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*")#:&%N;F5L("1S97)V97)?8VAA;FYE
M;"!D;V5S(&YO="`B("X-"B`@("`@("`@("`@("`@("`@("`@("`@(")S=7!P
M;W)T('AM;"UR<&,@;65T:&]D("1M971H;V0B*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1S
M97)V97)?:&]S="DI('L-"B`@("`@("`@("`@("`@("!I9B`H(21C:&%N;F5L
M+3YS=7!P;W)T<R@G>&UL<G!C)RP@)&UE=&AO9"DI('L-"B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")#:&%N;F5L("1S
M97)V97)?8VAA;FYE;"!D;V5S(&YO="!S=7!P;W)T("(@+@T*("`@("`@("`@
M("`@("`@("`@("`@("`@(GAM;"UR<&,@;65T:&]D("1M971H;V0B*3L-"B`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D
M<V5R=F5R7VAO<W0@/2`D<V5R=F5R7V-H86YN96P[#0H@("`@("`@("`@("`@
M("`@("`@("1S97)V97)?<&]R="`]("1C:&%N;F5L+3YG9710;W)T*"D[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")5
M;FMN;W=N(&-H86YN96P@)R1S97)V97)?8VAA;FYE;"<B*3L-"B`@("`@("`@
M?0T*#0H@("`@("`@(&%R<F%Y7W5N<VAI9G0H)%]A<F=S+"`D<V5R=F5R7V-H
M86YN96PI.R`O+R!C86-H92!B>2!C:&%N;F5L#0H@("`@("`@("1T:&ES+3YC
M86-H92`]("1T:&ES+3YG971#86-H92@D7V%R9W,I.PT*("`@("`@("`D8V%C
M:&5T=&P@/2`D=&AI<RT^8V]N9FEG+3YG970H)V-A8VAE7W1T;"<I.PT*("`@
M("`@("`O+R!)9B!C86-H92!I<R!N97=E<B!T:&%N("1C86-H971T;"!S96-O
M;F1S+"!W92!U<V4@=&AE(&-A8VAE(0T*("`@("`@("!I9B`H)'1H:7,M/F-A
M8VAE("$]/2!N=6QL("8F("1T:&ES+3YC86-H95LG86=E)UT@/"`D8V%C:&5T
M=&PI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^8V%C:&5;)V-O;G1E
M;G0G73L-"B`@("`@("`@?0T*("`@("`@("!I9B`H97AT96YS:6]N7VQO861E
M9"@B>&UL<G!C(BDI('L-"B`@("`@("`@("`@("1R97-U;'0@/2!C86QL7W5S
M97)?9G5N8U]A<G)A>2AA<G)A>2@F)'1H:7,L("=C86QL7V5P:2<I+"`D87)G
M<RD[#0H@("`@("`@("`@("!I9B`H(5!%05(Z.FES17)R;W(H)')E<W5L="DI
M('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^<V%V94-A8VAE*"1?87)G<RP@
M)')E<W5L="D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@
M)')E<W5L=#L-"B`@("`@("`@?2!E;'-E:68@*"%`:6YC;'5D95]O;F-E("=8
M34PO4E!#+G!H<"<I('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@B1F]R('1H:7,@<F5M;W1E(%!%05(@;W!E<F%T:6]N('EO=2!N
M965D('1O(&QO860@=&AE('AM;')P8R!E>'1E;G-I;VX@;W(@:6YS=&%L;"!8
M34Q?4E!#(BD[#0H@("`@("`@('T-"@T*("`@("`@("!A<G)A>5]S:&EF="@D
M87)G<RD[#0H@("`@("`@("1U<V5R;F%M92`]("1T:&ES+3YC;VYF:6<M/F=E
M="@G=7-E<FYA;64G*3L-"B`@("`@("`@)'!A<W-W;W)D(#T@)'1H:7,M/F-O
M;F9I9RT^9V5T*"=P87-S=V]R9"<I.PT*("`@("`@("`D96%R9W,@/2!A<G)A
M>2@I.PT*("`@("`@("!F;W)E86-H*"1A<F=S(&%S("1A<F<I('L-"B`@("`@
M("`@("`@("1E87)G<UM=(#T@)'1H:7,M/E]E;F-O9&4H)&%R9RD[#0H@("`@
M("`@('T-"B`@("`@("`@)&8@/2!N97<@6$U,7U)00U]-97-S86=E*"1M971H
M;V0L("1E87)G<RD[#0H@("`@("`@(&EF("@D=&AI<RT^8V%C:&4@(3T](&YU
M;&PI('L-"B`@("`@("`@("`@("1M87A!9V4@/2`G/VUA>$%G93TG+B1T:&ES
M+3YC86-H95LG;&%S=$-H86YG92==.PT*("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@)&UA>$%G92`]("<G.PT*("`@("`@("!]#0H@("`@("`@("1P
M<F]X>5]H;W-T(#T@)'!R;WAY7W!O<G0@/2`D<')O>'E?=7-E<B`]("1P<F]X
M>5]P87-S(#T@)R<[#0H@("`@("`@(&EF("@D<')O>'D@/2!P87)S95]U<FPH
M)'1H:7,M/F-O;F9I9RT^9V5T*"=H='1P7W!R;WAY)RDI*2![#0H@("`@("`@
M("`@("`D<')O>'E?:&]S="`]($`D<')O>'E;)VAO<W0G73L-"B`@("`@("`@
M("`@(&EF("AI<W-E="@D<')O>'E;)W-C:&5M92==*2`F)B`D<')O>'E;)W-C
M:&5M92==(#T]("=H='1P<R<I('L-"B`@("`@("`@("`@("`@("`D<')O>'E?
M:&]S="`]("=H='1P<SHO+R<@+B`D<')O>'E?:&]S=#L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("1P<F]X>5]P;W)T(#T@0"1P<F]X>5LG<&]R="==
M.PT*("`@("`@("`@("`@)'!R;WAY7W5S97(@/2!`=7)L9&5C;V1E*$`D<')O
M>'E;)W5S97(G72D[#0H@("`@("`@("`@("`D<')O>'E?<&%S<R`]($!U<FQD
M96-O9&4H0"1P<F]X>5LG<&%S<R==*3L-"B`@("`@("`@?0T*("`@("`@("`D
M<VAO<W0@/2`D<V5R=F5R7VAO<W0[#0H@("`@("`@(&EF("@D8VAA;FYE;"T^
M9V5T4U-,*"DI('L-"B`@("`@("`@("`@("1S:&]S="`](")H='1P<SHO+R1S
M:&]S="([#0H@("`@("`@('T-"B`@("`@("`@)&,@/2!N97<@6$U,7U)00U]#
M;&EE;G0H)R\G("X@)&-H86YN96PM/F=E=%!A=&@H)WAM;')P8R<I#0H@("`@
M("`@("`@("`N("1M87A!9V4L("1S:&]S="P@)'-E<G9E<E]P;W)T+"`D<')O
M>'E?:&]S="P@)'!R;WAY7W!O<G0L#0H@("`@("`@("`@("`D<')O>'E?=7-E
M<BP@)'!R;WAY7W!A<W,I.PT*("`@("`@("!I9B`H)'5S97)N86UE("8F("1P
M87-S=V]R9"D@>PT*("`@("`@("`@("`@)&,M/G-E=$-R961E;G1I86QS*"1U
M<V5R;F%M92P@)'!A<W-W;W)D*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M)'1H:7,M/F-O;F9I9RT^9V5T*"=V97)B;W-E)RD@/CT@,RD@>PT*("`@("`@
M("`@("`@)&,M/G-E=$1E8G5G*#$I.PT*("`@("`@("!]#0H@("`@("`@("1R
M(#T@)&,M/G-E;F0H)&8I.PT*("`@("`@("!I9B`H(21R*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(EA-3%]24$,@<V5N9"!F
M86EL960B*3L-"B`@("`@("`@?0T*("`@("`@("`D=B`]("1R+3YV86QU92@I
M.PT*("`@("`@("!I9B`H)&4@/2`D<BT^9F%U;'1#;V1E*"DI('L-"B`@("`@
M("`@("`@(&EF("@D92`]/2`D1TQ/0D%,4ULG6$U,7U)00U]E<G(G75LG:'1T
M<%]E<G)O<B==("8F('-T<G-T<B@D<BT^9F%U;'13=')I;F<H*2P@)S,P-"!.
M;W0@36]D:69I960G*2`A/3T@9F%L<V4I('L-"B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/F-A8VAE6R=C;VYT96YT)UT[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)'(M/F9A
M=6QT4W1R:6YG*"DL("1E*3L-"B`@("`@("`@?0T*#0H@("`@("`@("1R97-U
M;'0@/2!834Q?4E!#7V1E8V]D92@D=BD[#0H@("`@("`@("1T:&ES+3YS879E
M0V%C:&4H)%]A<F=S+"`D<F5S=6QT*3L-"B`@("`@("`@<F5T=7)N("1R97-U
M;'0[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@8V%L;%]E
M<&DH;65T:&]D+"!;87)G<RXN+ETI#0H-"B`@("!F=6YC=&EO;B!C86QL7V5P
M:2@D;65T:&]D*0T*("`@('L-"B`@("`@("`@9&\@>PT*("`@("`@("`@("`@
M:68@*&5X=&5N<VEO;E]L;V%D960H(GAM;')P8R(I*2![#0H@("`@("`@("`@
M("`@("`@8G)E86L[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H
M3U-?5TE.1$]74RD@>PT*("`@("`@("`@("`@("`@("1E>'0@/2`G9&QL)SL-
M"B`@("`@("`@("`@('T@96QS96EF("A02%!?3U,@/3T@)TA0+558)RD@>PT*
M("`@("`@("`@("`@("`@("1E>'0@/2`G<VPG.PT*("`@("`@("`@("`@?2!E
M;'-E:68@*%!(4%]/4R`]/2`G04E8)RD@>PT*("`@("`@("`@("`@("`@("1E
M>'0@/2`G82<[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("1E>'0@/2`G<V\G.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M)&5X="`]($]37U=)3D1/5U,@/R`G9&QL)R`Z("=S;R<[#0H@("`@("`@("`@
M("!`9&PH(GAM;')P8RUE<&DN)&5X="(I.PT*("`@("`@("`@("`@:68@*&5X
M=&5N<VEO;E]L;V%D960H(GAM;')P8R(I*2![#0H@("`@("`@("`@("`@("`@
M8G)E86L[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!`9&PH(GAM;')P
M8RXD97AT(BD[#0H@("`@("`@("`@("!I9B`H97AT96YS:6]N7VQO861E9"@B
M>&UL<G!C(BDI('L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B
M=6YA8FQE('1O(&QO860@>&UL<G!C(&5X=&5N<VEO;B(I.PT*("`@("`@("!]
M('=H:6QE("AF86QS92D[#0H@("`@("`@("1S97)V97)?8VAA;FYE;"`]("1T
M:&ES+3YC;VYF:6<M/F=E="@G9&5F875L=%]C:&%N;F5L)RD[#0H@("`@("`@
M("1C:&%N;F5L(#T@)'1H:7,M/E]R96=I<W1R>2T^9V5T0VAA;FYE;"@D<V5R
M=F5R7V-H86YN96PI.PT*("`@("`@("!I9B`H(5!%05(Z.FES17)R;W(H)&-H
M86YN96PI*2![#0H@("`@("`@("`@("`D;6ER<F]R(#T@)'1H:7,M/F-O;F9I
M9RT^9V5T*"=P<F5F97)R961?;6ER<F]R)RD[#0H@("`@("`@("`@("!I9B`H
M)&-H86YN96PM/F=E=$UI<G)O<B@D;6ER<F]R*2D@>PT*("`@("`@("`@("`@
M("`@(&EF("@D8VAA;FYE;"T^<W5P<&]R=',H)WAM;')P8R<L("1M971H;V0L
M("1M:7)R;W(I*2![#0H@("`@("`@("`@("`@("`@("`@("1S97)V97)?8VAA
M;FYE;"`]("1S97)V97)?:&]S="`]("1M:7)R;W([("\O('5S92!T:&4@<')E
M9F5R<F5D(&UI<G)O<@T*("`@("`@("`@("`@("`@("`@("`D<V5R=F5R7W!O
M<G0@/2`D8VAA;FYE;"T^9V5T4&]R="@D;6ER<F]R*3L-"B`@("`@("`@("`@
M("`@("!](&5L<V5I9B`H(21C:&%N;F5L+3YS=7!P;W)T<R@G>&UL<G!C)RP@
M)&UE=&AO9"DI('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*")#:&%N;F5L("1S97)V97)?8VAA;FYE;"!D;V5S(&YO
M="`B("X-"B`@("`@("`@("`@("`@("`@("`@("`@(")S=7!P;W)T('AM;"UR
M<&,@;65T:&]D("1M971H;V0B*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1S97)V97)?:&]S
M="DI('L-"B`@("`@("`@("`@("`@("!I9B`H(21C:&%N;F5L+3YS=7!P;W)T
M<R@G>&UL<G!C)RP@)&UE=&AO9"DI('L-"B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")#:&%N;F5L("1S97)V97)?8VAA
M;FYE;"!D;V5S(&YO="!S=7!P;W)T("(@+@T*("`@("`@("`@("`@("`@("`@
M("`@("`@(GAM;"UR<&,@;65T:&]D("1M971H;V0B*3L-"B`@("`@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D<V5R=F5R7VAO
M<W0@/2`D<V5R=F5R7V-H86YN96P[#0H@("`@("`@("`@("`@("`@("`@("1S
M97)V97)?<&]R="`]("1C:&%N;F5L+3YG9710;W)T*"D[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")5;FMN;W=N(&-H
M86YN96P@)R1S97)V97)?8VAA;FYE;"<B*3L-"B`@("`@("`@?0T*("`@("`@
M("`D<&%R86US(#T@9G5N8U]G971?87)G<R@I.PT*("`@("`@("!A<G)A>5]S
M:&EF="@D<&%R86US*3L-"B`@("`@("`@)&UE=&AO9"`]('-T<E]R97!L86-E
M*")?(BP@(BXB+"`D;65T:&]D*3L-"B`@("`@("`@)')E<75E<W0@/2!X;6QR
M<&-?96YC;V1E7W)E<75E<W0H)&UE=&AO9"P@)'!A<F%M<RD[#0H@("`@("`@
M(&EF("@D:'1T<%]P<F]X>2`]("1T:&ES+3YC;VYF:6<M/F=E="@G:'1T<%]P
M<F]X>2<I*2![#0H@("`@("`@("`@("`D<')O>'D@/2!P87)S95]U<FPH)&AT
M='!?<')O>'DI.PT*("`@("`@("`@("`@)'!R;WAY7VAO<W0@/2`D<')O>'E?
M<&]R="`]("1P<F]X>5]U<V5R(#T@)'!R;WAY7W!A<W,@/2`G)SL-"B`@("`@
M("`@("`@("1P<F]X>5]H;W-T(#T@0"1P<F]X>5LG:&]S="==.PT*("`@("`@
M("`@("`@:68@*&ES<V5T*"1P<F]X>5LG<V-H96UE)UTI("8F("1P<F]X>5LG
M<V-H96UE)UT@/3T@)VAT='!S)RD@>PT*("`@("`@("`@("`@("`@("1P<F]X
M>5]H;W-T(#T@)W-S;#HO+R<@+B`D<')O>'E?:&]S=#L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("1P<F]X>5]P;W)T(#T@0"1P<F]X>5LG<&]R="==
M.PT*("`@("`@("`@("`@)'!R;WAY7W5S97(@/2!`=7)L9&5C;V1E*$`D<')O
M>'E;)W5S97(G72D[#0H@("`@("`@("`@("`D<')O>'E?<&%S<R`]($!U<FQD
M96-O9&4H0"1P<F]X>5LG<&%S<R==*3L-"B`@("`@("`@("`@("1F<"`]($!F
M<V]C:V]P96XH)'!R;WAY7VAO<W0L("1P<F]X>5]P;W)T*3L-"B`@("`@("`@
M("`@("1U<V5?<')O>'D@/2!T<G5E.PT*("`@("`@("`@("`@:68@*"1C:&%N
M;F5L+3YG97134TPH*2D@>PT*("`@("`@("`@("`@("`@("1S97)V97)?:&]S
M="`](")H='1P<SHO+R1S97)V97)?:&]S="([#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D=7-E7W!R;WAY(#T@9F%L
M<V4[#0H@("`@("`@("`@("`D<W-L(#T@)&-H86YN96PM/F=E=%-33"@I.PT*
M("`@("`@("`@("`@)&9P(#T@0&9S;V-K;W!E;B@H)'-S;"`_("=S<VPZ+R\G
M(#H@)R<I("X@)'-E<G9E<E]H;W-T+"`D<V5R=F5R7W!O<G0I.PT*("`@("`@
M("`@("`@:68@*"$D9G`I('L-"B`@("`@("`@("`@("`@("`D<V5R=F5R7VAO
M<W0@/2`B)'-S;"1S97)V97)?:&]S="([("\O(&9O<B!E<G)O<BUR97!O<G1I
M;F<-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21F
M<"`F)B`D:'1T<%]P<F]X>2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*")014%27U)E;6]T93HZ8V%L;#H@9G-O8VMO<&5N*&`D
M<')O>'E?:&]S="<L("1P<F]X>5]P;W)T*2!F86EL960B*3L-"B`@("`@("`@
M?2!E;'-E:68@*"$D9G`I('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@B4$5!4E]296UO=&4Z.F-A;&PZ(&9S;V-K;W!E;BA@)'-E
M<G9E<E]H;W-T)RP@)'-E<G9E<E]P;W)T*2!F86EL960B*3L-"B`@("`@("`@
M?0T*("`@("`@("`D;&5N(#T@<W1R;&5N*"1R97%U97-T*3L-"B`@("`@("`@
M)')E<5]H96%D97)S(#T@(DAO<W0Z("1S97)V97)?:&]S=#HD<V5R=F5R7W!O
M<G1<<EQN(B`N#0H@("`@("`@("`@("`@(D-O;G1E;G0M='EP93H@=&5X="]X
M;6Q<<EQN(B`N#0H@("`@("`@("`@("`@(D-O;G1E;G0M;&5N9W1H.B`D;&5N
M7')<;B([#0H@("`@("`@("1U<V5R;F%M92`]("1T:&ES+3YC;VYF:6<M/F=E
M="@G=7-E<FYA;64G*3L-"B`@("`@("`@)'!A<W-W;W)D(#T@)'1H:7,M/F-O
M;F9I9RT^9V5T*"=P87-S=V]R9"<I.PT*("`@("`@("!I9B`H)'5S97)N86UE
M("8F("1P87-S=V]R9"D@>PT*("`@("`@("`@("`@)')E<5]H96%D97)S("X]
M(")#;V]K:64Z(%!%05)?55-%4CTD=7-E<FYA;64[(%!%05)?4%<])'!A<W-W
M;W)D7')<;B([#0H@("`@("`@("`@("`D=&UP(#T@8F%S938T7V5N8V]D92@B
M)'5S97)N86UE.B1P87-S=V]R9"(I.PT*("`@("`@("`@("`@)')E<5]H96%D
M97)S("X](")!=71H;W)I>F%T:6]N.B!"87-I8R`D=&UP7')<;B([#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"1T:&ES+3YC86-H92`A/3T@;G5L;"D@>PT*
M("`@("`@("`@("`@)&UA>$%G92`]("<_;6%X06=E/2<N)'1H:7,M/F-A8VAE
M6R=L87-T0VAA;F=E)UT[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`D;6%X06=E(#T@)R<[#0H@("`@("`@('T-"@T*("`@("`@("!I9B`H)'5S
M95]P<F]X>2`F)B`D<')O>'E?:&]S="`A/2`G)R`F)B`D<')O>'E?=7-E<B`A
M/2`G)RD@>PT*("`@("`@("`@("`@)')E<5]H96%D97)S("X]("=0<F]X>2U!
M=71H;W)I>F%T:6]N.B!"87-I8R`G#0H@("`@("`@("`@("`@("`@+F)A<V4V
M-%]E;F-O9&4H)'!R;WAY7W5S97(N)SHG+B1P<F]X>5]P87-S*0T*("`@("`@
M("`@("`@("`@("XB7')<;B([#0H@("`@("`@('T-"@T*("`@("`@("!I9B`H
M)'1H:7,M/F-O;F9I9RT^9V5T*"=V97)B;W-E)RD@/B`S*2![#0H@("`@("`@
M("`@("!P<FEN="`B6$U,4E!#(%)%455%4U0@2$5!1$524SI<;B([#0H@("`@
M("`@("`@("!V87)?9'5M<"@D<F5Q7VAE861E<G,I.PT*("`@("`@("`@("`@
M<')I;G0@(EA-3%)00R!215%515-4($)/1%DZ7&XB.PT*("`@("`@("`@("`@
M=F%R7V1U;7`H)')E<75E<W0I.PT*("`@("`@("!]#0H-"B`@("`@("`@:68@
M*"1U<V5?<')O>'D@)B8@)'!R;WAY7VAO<W0@(3T@)R<I('L-"B`@("`@("`@
M("`@("1P;W-T7W-T<FEN9R`](")03U-4(&AT='`Z+R\B+B1S97)V97)?:&]S
M=#L-"B`@("`@("`@("`@(&EF("@D<')O>'E?<&]R="`^("<G*2![#0H@("`@
M("`@("`@("`@("`@)'!O<W1?<W1R:6YG("X]("<Z)RXD<V5R=F5R7W!O<G0[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`D<&]S=%]S=')I;F<@/2`B4$]35"`B.PT*("`@("`@("!]#0H-"B`@("`@
M("`@)'!A=&@@/2`G+R<@+B`D8VAA;FYE;"T^9V5T4&%T:"@G>&UL<G!C)RD[
M#0H@("`@("`@(&9W<FET92@D9G`L("@D<&]S=%]S=')I;F<@+B`D<&%T:"`N
M("(D;6%X06=E($A45%`O,2XP7')<;B1R97%?:&5A9&5R<UQR7&XD<F5Q=65S
M="(I*3L-"B`@("`@("`@)')E<W!O;G-E(#T@)R<[#0H@("`@("`@("1L:6YE
M,2`](&9G971S*"1F<"P@,C`T."D[#0H@("`@("`@(&EF("@A<')E9U]M871C
M:"@G(5Y(5%10+ULP+3E<+ETK("A<9"LI("@N*BDA)RP@)&QI;F4Q+"`D;6%T
M8VAE<RDI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@B4$5!4E]296UO=&4Z(&EN=F%L:60@2%144"!R97-P;VYS92!F<F]M(%A-
M3"U24$,@<V5R=F5R(BD[#0H@("`@("`@('T-"B`@("`@("`@<W=I=&-H("@D
M;6%T8VAE<ULQ72D@>PT*("`@("`@("`@("`@8V%S92`B,C`P(CH@+R\@3TL-
M"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@(C,P
M-"(Z("\O($YO="!-;V1I9FEE9`T*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^8V%C:&5;)V-O;G1E;G0G73L-"B`@("`@("`@("`@(&-A<V4@(C0P
M,2(Z("\O(%5N875T:&]R:7IE9`T*("`@("`@("`@("`@("`@(&EF("@D=7-E
M<FYA;64@)B8@)'!A<W-W;W)D*2![#0H@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B4$5!4E]296UO=&4@*"1S97)V97)?
M:&]S=#HD<V5R=F5R7W!O<G0I("(@+@T*("`@("`@("`@("`@("`@("`@("`@
M("`@(CH@875T:&]R:7IA=&EO;B!F86EL960B+"`T,#$I.PT*("`@("`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@B4$5!4E]296UO=&4@*"1S97)V97)?:&]S=#HD
M<V5R=F5R7W!O<G0I("(@+@T*("`@("`@("`@("`@("`@("`@("`@("`@(CH@
M875T:&]R:7IA=&EO;B!R97%U:7)E9"P@<&QE87-E(&QO9R!I;B!F:7)S="(L
M(#0P,2D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@9&5F875L
M=#H-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M(E!%05)?4F5M;W1E("@D<V5R=F5R7VAO<W0Z)'-E<G9E<E]P;W)T*2`Z("(@
M+@T*("`@("`@("`@("`@("`@("`@("`B=6YE>'!E8W1E9"!(5%10(')E<W!O
M;G-E(BP@*&EN="DD;6%T8VAE<ULQ72P@;G5L;"P@;G5L;"P-"B`@("`@("`@
M("`@("`@("`@("`@(B1M871C:&5S6S%=("1M871C:&5S6S)=(BD[#0H@("`@
M("`@('T-"B`@("`@("`@=VAI;&4@*'1R:6TH9F=E=',H)&9P+"`R,#0X*2D@
M(3T@)R<I.R`O+R!S:VEP(')E<W0@;V8@:&5A9&5R<PT*("`@("`@("!W:&EL
M92`H)&-H=6YK(#T@9G)E860H)&9P+"`Q,#(T,"DI('L-"B`@("`@("`@("`@
M("1R97-P;VYS92`N/2`D8VAU;FL[#0H@("`@("`@('T-"B`@("`@("`@9F-L
M;W-E*"1F<"D[#0H@("`@("`@(&EF("@D=&AI<RT^8V]N9FEG+3YG970H)W9E
M<F)O<V4G*2`^(#,I('L-"B`@("`@("`@("`@('!R:6YT(")834Q24$,@4D53
M4$].4T4Z7&XB.PT*("`@("`@("`@("`@=F%R7V1U;7`H)')E<W!O;G-E*3L-
M"B`@("`@("`@?0T*("`@("`@("`D<F5T(#T@>&UL<G!C7V1E8V]D92@D<F5S
M<&]N<V4I.PT*("`@("`@("!I9B`H:7-?87)R87DH)')E="D@)B8@:7-S970H
M)')E=%LG7U]014%27U194$5?7R==*2D@>PT*("`@("`@("`@("`@:68@*"1R
M971;)U]?4$5!4E]465!%7U\G72`]/2`G97)R;W(G*2![#0H@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1R971;)U]?4$5!4E]#3$%34U]?)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("1C;&%S<R`]("1R971;)U]?4$5!4E]#3$%3
M4U]?)UT[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@)&-L87-S(#T@(E!%05)?17)R;W(B.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!I9B`H)')E=%LG8V]D92==("`@("`]
M/3T@)R<I("1R971;)V-O9&4G72`@("`@/2!N=6QL.PT*("`@("`@("`@("`@
M("`@(&EF("@D<F5T6R=M97-S86=E)UT@(#T]/2`G)RD@)')E=%LG;65S<V%G
M92==("`](&YU;&P[#0H@("`@("`@("`@("`@("`@:68@*"1R971;)W5S97)I
M;F9O)UT@/3T]("<G*2`D<F5T6R=U<V5R:6YF;R==(#T@;G5L;#L-"B`@("`@
M("`@("`@("`@("!I9B`H<W1R=&]L;W=E<B@D8VQA<W,I(#T]("=D8E]E<G)O
M<B<I('L-"B`@("`@("`@("`@("`@("`@("`@)')E="`]("1T:&ES+3YR86ES
M945R<F]R*%!%05(Z.F5R<F]R365S<V%G92@D<F5T6R=C;V1E)UTI+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E
M=%LG8V]D92==+"!N=6QL+"!N=6QL+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)')E=%LG=7-E<FEN9F\G72D[#0H@
M("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@
M)')E="`]("1T:&ES+3YR86ES945R<F]R*"1R971;)VUE<W-A9V4G72P@)')E
M=%LG8V]D92==+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@;G5L;"P@;G5L;"P@)')E=%LG=7-E<FEN9F\G72D[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!](&5L
M<V5I9B`H:7-?87)R87DH)')E="D@)B8@<VEZ96]F*"1R970I(#T](#$@)B8@
M:7-S970H)')E=%LP72D-"B`@("`@("`@("`@("`@("`@("8F(&ES7V%R<F%Y
M*"1R971;,%TI("8F#0H@("`@("`@("`@("`@("`@("`A96UP='DH)')E=%LP
M75LG9F%U;'13=')I;F<G72D@)B8-"B`@("`@("`@("`@("`@("`@("%E;7!T
M>2@D<F5T6S!=6R=F875L=$-O9&4G72DI('L-"B`@("`@("`@("`@(&5X=')A
M8W0H)')E=%LP72D[#0H@("`@("`@("`@("`D9F%U;'13=')I;F<@/2`B6$U,
M+5)00R!397)V97(@1F%U;'0Z("(@+@T*("`@("`@("`@("`@("`@("!S=')?
M<F5P;&%C92@B7&XB+"`B("(L("1F875L=%-T<FEN9RD[#0H@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&9A=6QT4W1R:6YG+"`D9F%U
M;'1#;V1E*3L-"B`@("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y*"1R970I("8F
M('-I>F5O9B@D<F5T*2`]/2`R("8F("%E;7!T>2@D<F5T6R=F875L=%-T<FEN
M9R==*2`F)@T*("`@("`@("`@("`@("`A96UP='DH)')E=%LG9F%U;'1#;V1E
M)UTI*2![#0H@("`@("`@("`@("!E>'1R86-T*"1R970I.PT*("`@("`@("`@
M("`@)&9A=6QT4W1R:6YG(#T@(EA-3"U24$,@4V5R=F5R($9A=6QT.B`B("X-
M"B`@("`@("`@("`@("`@("`@<W1R7W)E<&QA8V4H(EQN(BP@(B`B+"`D9F%U
M;'13=')I;F<I.PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*"1F875L=%-T<FEN9RP@)&9A=6QT0V]D92D[#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-"B`@
M("`O+R![>WL@7V5N8V]D90T*#0H@("`@+R\@82!S;&EG:'1L>2!E>'1E;F1E
M9"!V97)S:6]N(&]F(%A-3%]24$-?96YC;V1E#0H@("`@9G5N8W1I;VX@7V5N
M8V]D92@D<&AP7W9A;"D-"B`@("![#0H@("`@("`@(&=L;V)A;"`D6$U,7U)0
M0U]";V]L96%N+"`D6$U,7U)00U]);G0L("1834Q?4E!#7T1O=6)L93L-"B`@
M("`@("`@9VQO8F%L("1834Q?4E!#7U-T<FEN9RP@)%A-3%]24$-?07)R87DL
M("1834Q?4E!#7U-T<G5C=#L-"@T*("`@("`@("`D='EP92`](&=E='1Y<&4H
M)'!H<%]V86PI.PT*("`@("`@("`D>&UL<G!C=F%L(#T@;F5W(%A-3%]24$-?
M5F%L=64[#0H-"B`@("`@("`@<W=I=&-H*"1T>7!E*2![#0H@("`@("`@("`@
M("!C87-E(")A<G)A>2(Z#0H@("`@("`@("`@("`@("`@<F5S970H)'!H<%]V
M86PI.PT*("`@("`@("`@("`@("`@("1F:7)S=&ME>2`](&ME>2@D<&AP7W9A
M;"D[#0H@("`@("`@("`@("`@("`@96YD*"1P:'!?=F%L*3L-"B`@("`@("`@
M("`@("`@("`D;&%S=&ME>2`](&ME>2@D<&AP7W9A;"D[#0H@("`@("`@("`@
M("`@("`@<F5S970H)'!H<%]V86PI.PT*("`@("`@("`@("`@("`@(&EF("@D
M9FER<W1K97D@/3T](#`@)B8@:7-?:6YT*"1L87-T:V5Y*2`F)@T*("`@("`@
M("`@("`@("`@("`@("`H)&QA<W1K97D@*R`Q*2`]/2!C;W5N="@D<&AP7W9A
M;"DI('L-"B`@("`@("`@("`@("`@("`@("`@)&ES7V-O;G1I;G5O=7,@/2!T
M<G5E.PT*("`@("`@("`@("`@("`@("`@("!R97-E="@D<&AP7W9A;"D[#0H@
M("`@("`@("`@("`@("`@("`@("1S:7IE(#T@8V]U;G0H)'!H<%]V86PI.PT*
M("`@("`@("`@("`@("`@("`@("!F;W(@*"1E>'!E8W0@/2`P.R`D97AP96-T
M(#P@)'-I>F4[("1E>'!E8W0K*RP@;F5X="@D<&AP7W9A;"DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AK97DH)'!H<%]V86PI("$]/2`D97AP
M96-T*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&ES7V-O;G1I
M;G5O=7,@/2!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H)&ES7V-O;G1I
M;G5O=7,I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E<V5T*"1P:'!?
M=F%L*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("1A<G(@/2!A<G)A>2@I
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@=VAI;&4@*&QI<W0H)&LL("1V
M*2`](&5A8V@H)'!H<%]V86PI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&%R<ELD:UT@/2`D=&AI<RT^7V5N8V]D92@D=BD[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M>&UL<G!C=F%L+3YA9&1!<G)A>2@D87)R*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("\O(&9A;&P@=&AO=6=H(&EF
M(&YO="!N=6UE<FEC86P@86YD(&-O;G1I;G5O=7,-"B`@("`@("`@("`@(&-A
M<V4@(F]B:F5C="(Z#0H@("`@("`@("`@("`@("`@)&%R<B`](&%R<F%Y*"D[
M#0H@("`@("`@("`@("`@("`@=VAI;&4@*&QI<W0H)&LL("1V*2`](&5A8V@H
M)'!H<%]V86PI*2![#0H@("`@("`@("`@("`@("`@("`@("1A<G);)&M=(#T@
M)'1H:7,M/E]E;F-O9&4H)'8I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`D>&UL<G!C=F%L+3YA9&13=')U8W0H)&%R<BD[#0H@("`@
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E(")I;G1E9V5R
M(CH-"B`@("`@("`@("`@("`@("`D>&UL<G!C=F%L+3YA9&138V%L87(H)'!H
M<%]V86PL("1834Q?4E!#7TEN="D[#0H@("`@("`@("`@("`@("`@8G)E86L[
M#0H@("`@("`@("`@("!C87-E(")D;W5B;&4B.@T*("`@("`@("`@("`@("`@
M("1X;6QR<&-V86PM/F%D9%-C86QA<B@D<&AP7W9A;"P@)%A-3%]24$-?1&]U
M8FQE*3L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A
M<V4@(G-T<FEN9R(Z#0H@("`@("`@("`@("!C87-E(").54Q,(CH-"B`@("`@
M("`@("`@("`@("`D>&UL<G!C=F%L+3YA9&138V%L87(H)'!H<%]V86PL("18
M34Q?4E!#7U-T<FEN9RD[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@
M("`@("`@("!C87-E(")B;V]L96%N(CH-"B`@("`@("`@("`@("`@("`D>&UL
M<G!C=F%L+3YA9&138V%L87(H)'!H<%]V86PL("1834Q?4E!#7T)O;VQE86XI
M.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`B
M=6YK;F]W;B!T>7!E(CH-"B`@("`@("`@("`@(&1E9F%U;'0Z#0H@("`@("`@
M("`@("`@("`@<F5T=7)N(&YU;&P[#0H@("`@("`@('T-"B`@("`@("`@<F5T
M=7)N("1X;6QR<&-V86P[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-"GT-"@T*
M/SX-"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+U!A8VMA9V5R
M+G!H<```````````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$W
M-34S(#$P-3$U-#,S-S,R(#`R,30U-0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`T*+RHJ#0H@*B!014%27U!A8VMA
M9V5R(&9O<B!G96YE<F%T:6YG(')E;&5A<V5S#0H@*@T*("H@4$A0('9E<G-I
M;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE
M(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E
M#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E
M+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E
M(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE
M('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N
M9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO
M=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A
M<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@4W1I9R!"
M86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@5&]M87,@5BX@
M5BX@0V]X(#QC;WA`:61E8VYE="YC;VT^#0H@*B!`875T:&]R("`@("!'<F5G
M($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW
M+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@
M*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@4&%C:V%G97(N<&AP+'8@,2XV."`R
M,#`V+S`Q+S`V(#`T.C0W.C,V(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@
M("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC
M92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,"XQ#0H@*B\-
M"@T*+RHJ#0H@*B!B87-E(&-L87-S#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!
M4B]#;VUM;VXN<&AP)SL-"G)E<75I<F5?;VYC92`G4$5!4B]086-K86=E1FEL
M92YP:'`G.PT*<F5Q=6ER95]O;F-E("=3>7-T96TN<&AP)SL-"@T*+RHJ#0H@
M*B!!9&UI;FES=')A=&EO;B!C;&%S<R!U<V5D('1O(&UA:V4@82!014%2(')E
M;&5A<V4@=&%R8F%L;"X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`
M<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\
M8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE
M(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO
M;B`@("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E
M87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S
M(&%V86EL86)L92!S:6YC92!296QE87-E(#`N,0T*("HO#0IC;&%S<R!014%2
M7U!A8VMA9V5R(&5X=&5N9',@4$5!4E]#;VUM;VX-"GL-"B`@("`O*BH-"B`@
M("`@*B!`=F%R(%!%05)?4F5G:7-T<GD-"B`@("`@*B\-"B`@("!V87(@)%]R
M96=I<W1R>3L-"B`@("`O+R![>WL@<&%C:V%G92@I#0H-"B`@("!F=6YC=&EO
M;B!P86-K86=E*"1P:V=F:6QE(#T@;G5L;"P@)&-O;7!R97-S(#T@=')U92P@
M)'!K9S(@/2!N=6QL*0T*("`@('L-"B`@("`@("`@+R\@>WM[('9A;&ED871E
M('-U<'!L:65D('!A8VMA9V4N>&UL(&9I;&4-"B`@("`@("`@:68@*&5M<'1Y
M*"1P:V=F:6QE*2D@>PT*("`@("`@("`@("`@)'!K9V9I;&4@/2`G<&%C:V%G
M92YX;6PG.PT*("`@("`@("!]#0H@("`@("`@(%!%05(Z.G-T871I8U!U<VA%
M<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@)'!K
M9R`]("9N97<@4$5!4E]086-K86=E1FEL92@D=&AI<RT^8V]N9FEG+"`D=&AI
M<RT^9&5B=6<I.PT*("`@("`@("`D<&8@/2`F)'!K9RT^9G)O;5!A8VMA9V5&
M:6QE*"1P:V=F:6QE+"!014%27U9!3$E$051%7TY/4DU!3"D[#0H@("`@("`@
M("1M86EN(#T@)B1P9CL-"B`@("`@("`@4$5!4CHZ<W1A=&EC4&]P17)R;W)(
M86YD;&EN9R@I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<&8I*2![
M#0H@("`@("`@("`@("!I9B`H:7-?87)R87DH)'!F+3YG9715<V5R26YF;R@I
M*2D@>PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1P9BT^9V5T57-E<DEN
M9F\H*2!A<R`D97)R;W(I('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/FQO9R@P+"`G17)R;W(Z("<@+B`D97)R;W);)VUE<W-A9V4G72D[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'1H
M:7,M/FQO9R@P+"`D<&8M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D-A;FYO="!P86-K86=E+"!E<G)O
M<G,@:6X@<&%C:V%G92!F:6QE(BD[#0H@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("!F;W)E86-H("@D<&8M/F=E=%9A;&ED871I;VY787)N:6YG<R@I
M(&%S("1W87)N:6YG*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@Q
M+"`G5V%R;FEN9SH@)R`N("1W87)N:6YG6R=M97-S86=E)UTI.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H-"B`@("`@("`@+R\@?7U]#0H@("`@("`@
M(&EF("@D<&MG,BD@>PT*("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`G071T
M96UP=&EN9R!T;R!P<F]C97-S('1H92!S96-O;F0@<&%C:V%G92!F:6QE)RD[
M#0H@("`@("`@("`@("!014%2.CIS=&%T:6-0=7-H17)R;W)(86YD;&EN9RA0
M14%27T524D]27U)%5%523BD[#0H@("`@("`@("`@("`D<&8R(#T@)B1P:V<M
M/F9R;VU086-K86=E1FEL92@D<&MG,BP@4$5!4E]604Q)1$%415].3U)-04PI
M.PT*("`@("`@("`@("`@4$5!4CHZ<W1A=&EC4&]P17)R;W)(86YD;&EN9R@I
M.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'!F,BDI('L-"B`@
M("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)'!F,BT^9V5T57-E<DEN9F\H
M*2DI('L-"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!F,BT^9V5T
M57-E<DEN9F\H*2!A<R`D97)R;W(I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YL;V<H,"P@)T5R<F]R.B`G("X@)&5R<F]R6R=M97-S86=E
M)UTI.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,"P@)'!F,BT^9V5T365S
M<V%G92@I*3L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H(D-A;FYO="!P86-K86=E+"!E<G)O<G,@:6X@<V5C;VYD('!A8VMA
M9V4@9FEL92(I.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("!F;W)E86-H("@D<&8R+3YG971686QI9&%T:6]N5V%R;FEN9W,H*2!A
M<R`D=V%R;FEN9RD@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G
M*#$L("=787)N:6YG.B`G("X@)'=A<FYI;F=;)VUE<W-A9V4G72D[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@
M*"1P9C(M/F=E=%!A8VMA9V5X;6Q697)S:6]N*"D@/3T@)S(N,"<I('L-"B`@
M("`@("`@("`@("`@("`D;6%I;B`]("8D<&8R.PT*("`@("`@("`@("`@("`@
M("1O=&AE<B`]("8D<&8[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("1M86EN(#T@)B1P9CL-"B`@("`@("`@("`@("`@("`D;W1H
M97(@/2`F)'!F,CL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D
M;6%I;BT^9V5T4&%C:V%G97AM;%9E<G-I;VXH*2`A/2`G,BXP)RD@>PT*("`@
M("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=%<G)O<CH@
M8V%N;F]T('!A8VMA9V4@='=O('!A8VMA9V4N>&UL('9E<G-I;VX@,2XP+"!C
M86X@)R`N#0H@("`@("`@("`@("`@("`@("`@("=O;FQY('!A8VMA9V4@=&]G
M971H97(@82!P86-K86=E+GAM;"`Q+C`@86YD('!A8VMA9V4N>&UL(#(N,"<I
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1O=&AE<BT^9V5T
M4&%C:V%G97AM;%9E<G-I;VXH*2`A/2`G,2XP)RD@>PT*("`@("`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=%<G)O<CH@8V%N;F]T('!A
M8VMA9V4@='=O('!A8VMA9V4N>&UL('9E<G-I;VX@,BXP+"!C86X@)R`N#0H@
M("`@("`@("`@("`@("`@("`@("=O;FQY('!A8VMA9V4@=&]G971H97(@82!P
M86-K86=E+GAM;"`Q+C`@86YD('!A8VMA9V4N>&UL(#(N,"<I.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1M86EN+3YS971,;V=G97(H
M)'1H:7,I.PT*("`@("`@("!I9B`H(21M86EN+3YV86QI9&%T92A014%27U9!
M3$E$051%7U!!0TM!1TE.1RDI('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1M
M86EN+3YG971686QI9&%T:6]N5V%R;FEN9W,H*2!A<R`D=V%R;FEN9RD@>PT*
M("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,"P@)T5R<F]R.B`G("X@)'=A
M<FYI;F=;)VUE<W-A9V4G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D-A;FYO="!P86-K86=E+"!E
M<G)O<G,@:6X@<&%C:V%G92(I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@9F]R96%C:"`H)&UA:6XM/F=E=%9A;&ED871I;VY787)N:6YG<R@I
M(&%S("1W87)N:6YG*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@Q
M+"`G5V%R;FEN9SH@)R`N("1W87)N:6YG6R=M97-S86=E)UTI.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@D<&MG,BD@>PT*("`@
M("`@("`@("`@)&]T:&5R+3YS971,;V=G97(H)'1H:7,I.PT*("`@("`@("`@
M("`@)&$@/2!F86QS93L-"B`@("`@("`@("`@(&EF("@A)&]T:&5R+3YV86QI
M9&%T92A014%27U9!3$E$051%7TY/4DU!3"D@?'P@)&$@/2`A)&UA:6XM/FES
M17%U:79A;&5N="@D;W1H97(I*2![#0H@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)&]T:&5R+3YG971686QI9&%T:6]N5V%R;FEN9W,H*2!A<R`D=V%R;FEN
M9RD@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L("=%<G)O
M<CH@)R`N("1W87)N:6YG6R=M97-S86=E)UTI.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D;6%I;BT^9V5T5F%L:61A
M=&EO;E=A<FYI;F=S*"D@87,@)'=A<FYI;F<I('L-"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/FQO9R@P+"`G17)R;W(Z("<@+B`D=V%R;FEN9ULG;65S
M<V%G92==*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M:68@*"1A*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@G5&AE('1W;R!P86-K86=E+GAM;"!F:6QE<R!A<F4@;F]T
M(&5Q=6EV86QE;G0A)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B0V%N;F]T('!A8VMA
M9V4L(&5R<F]R<R!I;B!P86-K86=E(BD[#0H@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1O=&AE<BT^9V5T5F%L:61A
M=&EO;E=A<FYI;F=S*"D@87,@)'=A<FYI;F<I('L-"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/FQO9R@Q+"`G5V%R;FEN9SH@)R`N("1W87)N:6YG6R=M
M97-S86=E)UTI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("1G96X@/2`F)&UA:6XM/F=E=$1E9F%U;'1'96YE<F%T
M;W(H*3L-"B`@("`@("`@("`@("1T9WIF:6QE(#T@)&=E;BT^=&]49WHR*"1T
M:&ES+"`D;W1H97(L("1C;VUP<F5S<RD[#0H@("`@("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D=&=Z9FEL92DI('L-"B`@("`@("`@("`@("`@("!R971U
M<FX@)'1G>F9I;&4[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D9&5S
M=%]P86-K86=E(#T@8F%S96YA;64H)'1G>F9I;&4I.PT*("`@("`@("`@("`@
M)'!K9V1I<B`](&1I<FYA;64H)'!K9V9I;&4I.PT*("`@(`T*("`@("`@("`@
M("`@+R\@5$%2('1H92!086-K86=E("TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2T-"B`@("`@("`@("`@("1T:&ES+3YL;V<H
M,2P@(E!A8VMA9V4@)&1E<W1?<&%C:V%G92!D;VYE(BD[#0H@("`@("`@("`@
M("!I9B`H9FEL95]E>&ES=',H(B1P:V=D:7(O0U93+U)O;W0B*2D@>PT*("`@
M("`@("`@("`@("`@("1C=G-V97)S:6]N(#T@<')E9U]R97!L86-E*"<O6UYA
M+7HP+3E=+VDG+"`G7R<L("1P9BT^9V5T5F5R<VEO;B@I*3L-"B`@("`@("`@
M("`@("`@("`D8W9S=&%G(#T@(E)%3$5!4T5?)&-V<W9E<G-I;VXB.PT*("`@
M("`@("`@("`@("`@("1T:&ES+3YL;V<H,2P@)U1A9R!T:&4@<F5L96%S960@
M8V]D92!W:71H(")P96%R(&-V<W1A9R`G("X-"B`@("`@("`@("`@("`@("`@
M("`@)&UA:6XM/F=E=%!A8VMA9V5&:6QE*"D@+B`G(B<I.PT*("`@("`@("`@
M("`@("`@("1T:&ES+3YL;V<H,2P@(BAO<B!S970@=&AE($-64R!T86<@)&-V
M<W1A9R!B>2!H86YD*2(I.PT*("`@("`@("`@("`@?0T*("`@("`@("!](&5L
M<V4@>R`O+R!T:&ES(&)R86YC:"!I<R!E>&5C=71E9"!F;W(@<VEN9VQE('!A
M8VMA9V5F:6QE('!A8VMA9VEN9PT*("`@("`@("`@("`@)&=E;B`]("8D<&8M
M/F=E=$1E9F%U;'1'96YE<F%T;W(H*3L-"B`@("`@("`@("`@("1T9WIF:6QE
M(#T@)&=E;BT^=&]49WHH)'1H:7,L("1C;VUP<F5S<RD[#0H@("`@("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D=&=Z9FEL92DI('L-"B`@("`@("`@("`@
M("`@("`D=&AI<RT^;&]G*#`L("1T9WIF:6QE+3YG971-97-S86=E*"DI.PT*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B0V%N
M;F]T('!A8VMA9V4L(&5R<F]R<R!I;B!P86-K86=E(BD[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`D9&5S=%]P86-K86=E(#T@8F%S96YA;64H)'1G
M>F9I;&4I.PT*("`@("`@("`@("`@)'!K9V1I<B`](&1I<FYA;64H)'!K9V9I
M;&4I.PT*("`@(`T*("`@("`@("`@("`@+R\@5$%2('1H92!086-K86=E("TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T-"B`@
M("`@("`@("`@("1T:&ES+3YL;V<H,2P@(E!A8VMA9V4@)&1E<W1?<&%C:V%G
M92!D;VYE(BD[#0H@("`@("`@("`@("!I9B`H9FEL95]E>&ES=',H(B1P:V=D
M:7(O0U93+U)O;W0B*2D@>PT*("`@("`@("`@("`@("`@("1C=G-V97)S:6]N
M(#T@<')E9U]R97!L86-E*"<O6UYA+7HP+3E=+VDG+"`G7R<L("1P9BT^9V5T
M5F5R<VEO;B@I*3L-"B`@("`@("`@("`@("`@("`D8W9S=&%G(#T@(E)%3$5!
M4T5?)&-V<W9E<G-I;VXB.PT*("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H
M,2P@(E1A9R!T:&4@<F5L96%S960@8V]D92!W:71H(&!P96%R(&-V<W1A9R`D
M<&MG9FEL92<B*3L-"B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#$L("(H
M;W(@<V5T('1H92!#5E,@=&%G("1C=G-T86<@8GD@:&%N9"DB*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)&1E<W1?<&%C
M:V%G93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"GT-"@T*+R\@>WM[(&UD-5]F
M:6QE*"D@=71I;&ET>2!F=6YC=&EO;@T*:68@*"%F=6YC=&EO;E]E>&ES=',H
M)VUD-5]F:6QE)RDI('L-"B`@("!F=6YC=&EO;B!M9#5?9FEL92@D9FEL92D@
M>PT*("`@("`@("!I9B`H(21F9"`]($!F;W!E;B@D9FEL92P@)W(G*2D@>PT*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@
M(&EF("AF=6YC=&EO;E]E>&ES=',H)V9I;&5?9V5T7V-O;G1E;G1S)RDI('L-
M"B`@("`@("`@("`@(&9C;&]S92@D9F0I.PT*("`@("`@("`@("`@)&UD-2`]
M(&UD-2AF:6QE7V=E=%]C;VYT96YT<R@D9FEL92DI.PT*("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@)&UD-2`](&UD-2AF<F5A9"@D9F0L(&9I;&5S
M:7IE*"1F:6QE*2DI.PT*("`@("`@("`@("`@9F-L;W-E*"1F9"D[#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N("1M9#4[#0H@("`@?0T*?0T*+R\@?7U]
M#0H-"C\^#0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O4$5!4B]086-K86=E1FEL92YP:'``````````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`S-C4W,2`Q,#4Q-30S,S<S,B`P,C(P-S0`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`-
M"B\J*@T*("H@4$5!4E]086-K86=E1FEL92P@<&%C:V%G92YX;6P@<&%R<VEN
M9R!U=&EL:71Y(&-L87-S#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-
M"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@
M=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES
M(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@
M9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*
M("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I
M="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@
M;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM
M961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA
M9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO
M9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@
M1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@
M0U93.B`D260Z(%!A8VMA9V5&:6QE+G!H<"QV(#$N,S,@,C`P-B\P,B\P.2`R
M,CHS.3HS,B!C96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P
M96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE
M(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*#0HO*BH-
M"B`J(&YE961E9"!F;W(@4$5!4E]604Q)1$%415\J(&-O;G-T86YT<PT*("HO
M#0IR97%U:7)E7V]N8V4@)U!%05(O5F%L:61A=&4N<&AP)SL-"B\J*@T*("H@
M17)R;W(@8V]D92!I9B!T:&4@<&%C:V%G92YX;6P@/'!A8VMA9V4^('1A9R!D
M;V5S(&YO="!C;VYT86EN(&$@=F%L:60@=F5R<VEO;@T*("HO#0ID969I;F4H
M)U!%05)?4$%#2T%'149)3$5?15)23U)?3D]?4$%#2T%'159%4E-)3TXG+"`Q
M*3L-"B\J*@T*("H@17)R;W(@8V]D92!I9B!T:&4@<&%C:V%G92YX;6P@/'!A
M8VMA9V4^('1A9R!V97)S:6]N(&ES(&YO="!S=7!P;W)T960@*'9E<G-I;VX@
M,2XP(&%N9"`Q+C$@87)E('1H92!O;FQY('-U<'!O<G1E9"!V97)S:6]N<RP-
M"B`J(&-U<G)E;G1L>0T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)3$5?
M15)23U)?24Y604Q)1%]004-+04=%5D524TE/3B<L(#(I.PT*+RHJ#0H@*B!!
M8G-T<F%C=&EO;B!F;W(@=&AE('!A8VMA9V4N>&UL('!A8VMA9V4@9&5S8W)I
M<'1I;VX@9FEL90T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K
M86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL
M;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0
M($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@
M(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP
M:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A
M:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0IC;&%S<R!014%2
M7U!A8VMA9V5&:6QE#0I[#0H@("`@+RHJ#0H@("`@("H@0'9A<B!014%27T-O
M;F9I9PT*("`@("`J+PT*("`@('9A<B`D7V-O;F9I9SL-"B`@("!V87(@)%]D
M96)U9SL-"B`@("`O*BH-"B`@("`@*B!496UP(&1I<F5C=&]R>2!F;W(@=6YC
M;VUP<F5S<VEN9R!T9WH@9FEL97,N#0H@("`@("H@0'9A<B!S=')I;F=\9F%L
M<V4-"B`@("`@*B\-"B`@("!V87(@)%]T;7!D:7([#0H@("`@=F%R("1?;&]G
M9V5R(#T@9F%L<V4[#0H@("`@+RHJ#0H@("`@("H@0'9A<B!B;V]L96%N#0H@
M("`@("HO#0H@("`@=F%R("1?<F%W4F5T=7)N(#T@9F%L<V4[#0H-"B`@("`O
M*BH-"B`@("`@*@T*("`@("`J($!P87)A;2`@(%!%05)?0V]N9FEG("1C;VYF
M:6<-"B`@("`@*B!`<&%R86T@("`_("`@)&1E8G5G#0H@("`@("H@0'!A<F%M
M("`@<W1R:6YG($!T;7!D:7(@3W!T:6]N86P@=&5M<&]R87)Y(&1I<F5C=&]R
M>2!F;W(@=6YC;VUP<F5S<VEN9PT*("`@("`J("`@("`@("`@(&9I;&5S#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@4$5!4E]086-K86=E1FEL92@F)&-O;F9I
M9RP@)&1E8G5G(#T@9F%L<V4L("1T;7!D:7(@/2!F86QS92D-"B`@("![#0H@
M("`@("`@("1T:&ES+3Y?8V]N9FEG(#T@)&-O;F9I9SL-"B`@("`@("`@)'1H
M:7,M/E]D96)U9R`]("1D96)U9SL-"B`@("`@("`@)'1H:7,M/E]T;7!D:7(@
M/2`D=&UP9&ER.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%1U<FX@;V9F
M('9A;&ED871I;VX@+2!R971U<FX@82!P87)S960@<&%C:V%G92YX;6P@=VET
M:&]U="!C:&5C:VEN9R!I=`T*("`@("`J#0H@("`@("H@5&AI<R!I<R!U<V5D
M(&)Y('1H92!P86-K86=E+79A;&ED871E(&-O;6UA;F0-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!R87=2971U<FXH*0T*("`@('L-"B`@("`@("`@)'1H:7,M
M/E]R87=2971U<FX@/2!T<G5E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E
M=$QO9V=E<B@F)&PI#0H@("`@>PT*("`@("`@("`D=&AI<RT^7VQO9V=E<B`]
M("8D;#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!#<F5A=&4@82!014%2
M7U!A8VMA9V5&:6QE7U!A<G-E<E]V*B!O9B!A(&=I=F5N('9E<G-I;VXN#0H@
M("`@("H@0'!A<F%M("`@:6YT("1V97)S:6]N#0H@("`@("H@0')E='5R;B`@
M4$5!4E]086-K86=E1FEL95]087)S97)?=C%\4$5!4E]086-K86=E1FEL95]0
M87)S97)?=C$-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F<&%R<V5R1F%C=&]R
M>2@D=F5R<VEO;BD-"B`@("![#0H@("`@("`@(&EF("@A:6Y?87)R87DH)'9E
M<G-I;VY[,'TL(&%R<F%Y*"<Q)RP@)S(G*2DI('L-"B`@("`@("`@("`@("1A
M(#T@9F%L<V4[#0H@("`@("`@("`@("!R971U<FX@)&$[#0H@("`@("`@('T-
M"B`@("`@("`@:6YC;'5D95]O;F-E("=014%2+U!A8VMA9V5&:6QE+U!A<G-E
M<B]V)R`N("1V97)S:6]N>S!]("X@)RYP:'`G.PT*("`@("`@("`D=F5R<VEO
M;B`]("1V97)S:6]N>S!].PT*("`@("`@("`D8VQA<W,@/2`B4$5!4E]086-K
M86=E1FEL95]087)S97)?=B1V97)S:6]N(CL-"B`@("`@("`@)&$@/2!N97<@
M)&-L87-S.PT*("`@("`@("!R971U<FX@)&$[#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@("H@1F]R('-I;7!L97(@=6YI="UT97-T:6YG#0H@("`@("H@0')E
M='5R;B!S=')I;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971#;&%S<U!R
M969I>"@I#0H@("`@>PT*("`@("`@("!R971U<FX@)U!%05)?4&%C:V%G949I
M;&5?=B<[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0W)E871E(&$@4$5!
M4E]086-K86=E1FEL95]V*B!O9B!A(&=I=F5N('9E<G-I;VXN#0H@("`@("H@
M0'!A<F%M("`@:6YT("1V97)S:6]N#0H@("`@("H@0')E='5R;B`@4$5!4E]0
M86-K86=E1FEL95]V,7Q014%27U!A8VMA9V5&:6QE7W8Q#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@)F9A8W1O<GDH)'9E<G-I;VXI#0H@("`@>PT*("`@("`@
M("!I9B`H(6EN7V%R<F%Y*"1V97)S:6]N>S!]+"!A<G)A>2@G,2<L("<R)RDI
M*2![#0H@("`@("`@("`@("`D82`](&9A;'-E.PT*("`@("`@("`@("`@<F5T
M=7)N("1A.PT*("`@("`@("!]#0H@("`@("`@(&EN8VQU9&5?;VYC92`G4$5!
M4B]086-K86=E1FEL92]V)R`N("1V97)S:6]N>S!]("X@)RYP:'`G.PT*("`@
M("`@("`D=F5R<VEO;B`]("1V97)S:6]N>S!].PT*("`@("`@("`D8VQA<W,@
M/2`D=&AI<RT^9V5T0VQA<W-0<F5F:7@H*2`N("1V97)S:6]N.PT*("`@("`@
M("`D82`](&YE=R`D8VQA<W,[#0H@("`@("`@(')E='5R;B`D83L-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!#<F5A=&4@82!014%27U!A8VMA9V5&:6QE
M7W8J(&9R;VT@:71S('1O07)R87DH*2!M971H;V0-"B`@("`@*@T*("`@("`J
M(%=!4DY)3D<Z(&YO('9A;&ED871I;VX@:7,@<&5R9F]R;65D+"!T:&4@87)R
M87D@:7,@87-S=6UE9"!T;R!B92!V86QI9"P-"B`@("`@*B!A;'=A>7,@<&%R
M<V4@9G)O;2!X;6P@:68@>6]U('=A;G0@=F%L:61A=&EO;BX-"B`@("`@*B!`
M<&%R86T@("!A<G)A>2`D87)R#0H@("`@("H@0')E='5R;B!014%27U!A8VMA
M9V5&:6QE36%N86=E<E]V,7Q014%27U!A8VMA9V5&:6QE36%N86=E<E]V,@T*
M("`@("`J($!U<V5S("`@(&9A8W1O<GDH*2!T;R!C;VYS=')U8W0@=&AE(')E
M='5R;F5D(&]B:F5C="X-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F9G)O;4%R
M<F%Y*"1A<G(I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)&%R<ELG>'-D
M=F5R<VEO;B==*2D@>PT*("`@("`@("`@("`@)&]B:B`]("8D=&AI<RT^9F%C
M=&]R>2@D87)R6R=X<V1V97)S:6]N)UTI.PT*("`@("`@("`@("`@:68@*"1T
M:&ES+3Y?;&]G9V5R*2![#0H@("`@("`@("`@("`@("`@)&]B:BT^<V5T3&]G
M9V5R*"1T:&ES+3Y?;&]G9V5R*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("1O8FHM/G-E=$-O;F9I9R@D=&AI<RT^7V-O;F9I9RD[#0H@("`@("`@
M("`@("`D;V)J+3YF<F]M07)R87DH)&%R<BD[#0H@("`@("`@("`@("!R971U
M<FX@)&]B:CL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(&EF("AI
M<W-E="@D87)R6R=P86-K86=E)UU;)V%T=')I8G,G75LG=F5R<VEO;B==*2D@
M>PT*("`@("`@("`@("`@("`@("1O8FH@/2`F)'1H:7,M/F9A8W1O<GDH)&%R
M<ELG<&%C:V%G92==6R=A='1R:6)S)UU;)W9E<G-I;VXG72D[#0H@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1O8FH@/2`F)'1H:7,M
M/F9A8W1O<GDH)S$N,"<I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M:68@*"1T:&ES+3Y?;&]G9V5R*2![#0H@("`@("`@("`@("`@("`@)&]B:BT^
M<V5T3&]G9V5R*"1T:&ES+3Y?;&]G9V5R*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("1O8FHM/G-E=$-O;F9I9R@D=&AI<RT^7V-O;F9I9RD[#0H@
M("`@("`@("`@("`D;V)J+3YF<F]M07)R87DH)&%R<BD[#0H@("`@("`@("`@
M("!R971U<FX@)&]B:CL-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*
M("`@("`J($-R96%T92!A(%!%05)?4&%C:V%G949I;&5?=BH@9G)O;2!A;B!8
M34P@<W1R:6YG+@T*("`@("`J($!A8V-E<W,@('!U8FQI8PT*("`@("`J($!P
M87)A;2`@('-T<FEN9R`D9&%T82!C;VYT96YT<R!O9B!P86-K86=E+GAM;"!F
M:6QE#0H@("`@("H@0'!A<F%M("`@:6YT("1S=&%T92!P86-K86=E('-T871E
M("AO;F4@;V8@4$5!4E]604Q)1$%415\J(&-O;G-T86YT<RD-"B`@("`@*B!`
M<&%R86T@("!S=')I;F<@)&9I;&4@9G5L;"!P871H('1O('1H92!P86-K86=E
M+GAM;"!F:6QE("AA;F0@=&AE(&9I;&5S#0H@("`@("H@("`@("`@("`@:70@
M<F5F97)E;F-E<RD-"B`@("`@*B!`<&%R86T@("!S=')I;F<@)&%R8VAI=F4@
M;W!T:6]N86P@;F%M92!O9B!T:&4@87)C:&EV92!T:&%T('1H92!834P@=V%S
M#0H@("`@("H@("`@("`@("`@97AT<F%C=&5D(&9R;VTL(&EF(&%N>0T*("`@
M("`J($!R971U<FX@(%!%05)?4&%C:V%G949I;&5?=C%\4$5!4E]086-K86=E
M1FEL95]V,@T*("`@("`J($!U<V5S("`@('!A<G-E<D9A8W1O<GDH*2!T;R!C
M;VYS=')U8W0@82!P87)S97(@=&\@;&]A9"!T:&4@<&%C:V%G92X-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B`F9G)O;5AM;%-T<FEN9R@D9&%T82P@)'-T871E
M+"`D9FEL92P@)&%R8VAI=F4@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF
M("AP<F5G7VUA=&-H*"<O/'!A8VMA9V5;7CY=*W9E<G-I;VX](BA;,"TY72M<
M+ELP+3E=*RDB+R<L("1D871A+"`D<&%C:V%G979E<G-I;VXI*2![#0H@("`@
M("`@("`@("!I9B`H(6EN7V%R<F%Y*"1P86-K86=E=F5R<VEO;ELQ72P@87)R
M87DH)S$N,"<L("<R+C`G*2DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@G<&%C:V%G92YX;6P@=F5R<VEO;B`B)R`N("1P
M86-K86=E=F5R<VEO;ELQ72`N#0H@("`@("`@("`@("`@("`@("`@("<B(&ES
M(&YO="!S=7!P;W)T960L(&]N;'D@,2XP(&%N9"`R+C`@87)E('-U<'!O<G1E
M9"XG*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1O8FIE8W0@/2`F
M)'1H:7,M/G!A<G-E<D9A8W1O<GDH)'!A8VMA9V5V97)S:6]N6S%=*3L-"B`@
M("`@("`@("`@(&EF("@D=&AI<RT^7VQO9V=E<BD@>PT*("`@("`@("`@("`@
M("`@("1O8FIE8W0M/G-E=$QO9V=E<B@D=&AI<RT^7VQO9V=E<BD[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`D;V)J96-T+3YS971#;VYF:6<H)'1H
M:7,M/E]C;VYF:6<I.PT*("`@("`@("`@("`@)'!F(#T@)&]B:F5C="T^<&%R
M<V4H)&1A=&$L("1F:6QE+"`D87)C:&EV92D[#0H@("`@("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D<&8I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N
M("1P9CL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D=&AI<RT^
M7W)A=U)E='5R;BD@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D<&8[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)'!F+3YV86QI9&%T92@D
M<W1A=&4I*2![#0H@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?;&]G9V5R
M*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@D<&8M/F=E=%9A;&ED871I
M;VY787)N:6YG<RAF86QS92DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1P9BT^9V5T5F%L:61A=&EO;E=A<FYI;F=S*"D@87,@)'=A
M<FYI;F<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7VQO9V=E<BT^;&]G*#`L("=705).24Y'.B`G("X@)'=A<FYI;F=;)VUE<W-A
M9V4G72D[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@:68@*&UE=&AO9%]E>&ES=',H)'!F+"`G9FQA='1E;D9I;&5L:7-T)RDI
M('L-"B`@("`@("`@("`@("`@("`@("`@)'!F+3YF;&%T=&5N1FEL96QI<W0H
M*3L@+R\@9F]R('8R#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(')E='5R;B`D<&8[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@(&EF("@D=&AI<RT^7V-O;F9I9RT^9V5T*"=V97)B;W-E)RD@
M/B`P*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7VQO9V=E
M<BD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1P9BT^9V5T5F%L
M:61A=&EO;E=A<FYI;F=S*&9A;'-E*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1P9BT^9V5T5F%L:61A=&EO;E=A<FYI;F=S
M*&9A;'-E*2!A<R`D=V%R;FEN9RD@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7VQO9V=E<BT^;&]G*#`L("=%4E)/4CH@)R`N
M("1W87)N:6YG6R=M97-S86=E)UTI.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`D82`](%!%05(Z.G)A:7-E17)R;W(H)U!A<G-I;F<@;V8@<&%C:V%G
M92YX;6P@9G)O;2!F:6QE("(G("X@)&9I;&4@+B`G(B!F86EL960G+`T*("`@
M("`@("`@("`@("`@("`@("`R+"!N=6QL+"!N=6QL+"`D<&8M/F=E=%9A;&ED
M871I;VY787)N:6YG<R@I*3L-"B`@("`@("`@("`@("`@("!R971U<FX@)&$[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H
M*"<O/'!A8VMA9V5;7CY=*W9E<G-I;VX](BA;7B)=*RDB+R<L("1D871A+"`D
M<&%C:V%G979E<G-I;VXI*2![#0H@("`@("`@("`@("`D82`](%!%05(Z.G)A
M:7-E17)R;W(H)W!A8VMA9V4N>&UL(&9I;&4@(B<@+B`D9FEL92`N#0H@("`@
M("`@("`@("`@("`@)R(@:&%S('5N<W5P<&]R=&5D('!A8VMA9V4N>&UL(#QP
M86-K86=E/B!V97)S:6]N("(G("X@)'!A8VMA9V5V97)S:6]N6S%=("X@)R(G
M*3L-"B`@("`@("`@("`@(')E='5R;B`D83L-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27T5R<F]R4W1A
M8VLG*2D@>PT*("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]%
M<G)O<E-T86-K+G!H<"<[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!0
M14%27T5R<F]R4W1A8VLZ.G-T871I8U!U<V@H)U!%05)?4&%C:V%G949I;&4G
M+`T*("`@("`@("`@("`@("`@(%!%05)?4$%#2T%'149)3$5?15)23U)?3D]?
M4$%#2T%'159%4E-)3TXL#0H@("`@("`@("`@("`@("`@)W=A<FYI;F<G+"!A
M<G)A>2@G>&UL)R`]/B`D9&%T82DL("=P86-K86=E+GAM;"`B)R`N("1F:6QE
M("X-"B`@("`@("`@("`@("`@("`@("`@)R(@:&%S(&YO('!A8VMA9V4N>&UL
M(#QP86-K86=E/B!V97)S:6]N)RD[#0H@("`@("`@("`@("`D;V)J96-T(#T@
M)B1T:&ES+3YP87)S97)&86-T;W)Y*"<Q+C`G*3L-"B`@("`@("`@("`@("1O
M8FIE8W0M/G-E=$-O;F9I9R@D=&AI<RT^7V-O;F9I9RD[#0H@("`@("`@("`@
M("`D<&8@/2`D;V)J96-T+3YP87)S92@D9&%T82P@)&9I;&4L("1A<F-H:79E
M*3L-"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1P9BDI('L-"B`@
M("`@("`@("`@("`@("!R971U<FX@)'!F.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@:68@*"1T:&ES+3Y?<F%W4F5T=7)N*2![#0H@("`@("`@("`@
M("`@("`@<F5T=7)N("1P9CL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&EF("@D<&8M/G9A;&ED871E*"1S=&%T92DI('L-"B`@("`@("`@("`@("`@
M("!I9B`H)'1H:7,M/E]L;V=G97(I('L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*"1P9BT^9V5T5F%L:61A=&EO;E=A<FYI;F=S*&9A;'-E*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!F+3YG971686QI9&%T
M:6]N5V%R;FEN9W,H*2!A<R`D=V%R;FEN9RD@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?;&]G9V5R+3YL;V<H,"P@)U=!4DY)3D<Z
M("<@+B`D=V%R;FEN9ULG;65S<V%G92==*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!I9B`H;65T:&]D7V5X:7-T<R@D<&8L
M("=F;&%T=&5N1FEL96QI<W0G*2D@>PT*("`@("`@("`@("`@("`@("`@("`D
M<&8M/F9L871T96Y&:6QE;&ES="@I.R`O+R!F;W(@=C(-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@<F5T=7)N("1P9CL-"B`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)&$@/2!014%2.CIR86ES
M945R<F]R*"=087)S:6YG(&]F('!A8VMA9V4N>&UL(&9R;VT@9FEL92`B)R`N
M("1F:6QE("X@)R(@9F%I;&5D)RP-"B`@("`@("`@("`@("`@("`@("`@,BP@
M;G5L;"P@;G5L;"P@)'!F+3YG971686QI9&%T:6]N5V%R;FEN9W,H*2D[#0H@
M("`@("`@("`@("`@("`@<F5T=7)N("1A.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4F5G:7-T97(@82!T
M96UP;W)A<GD@9FEL92!O<B!D:7)E8W1O<GDN("!7:&5N('1H92!D97-T<G5C
M=&]R(&ES#0H@("`@("H@97AE8W5T960L(&%L;"!R96=I<W1E<F5D('1E;7!O
M<F%R>2!F:6QE<R!A;F0@9&ER96-T;W)I97,@87)E#0H@("`@("H@<F5M;W9E
M9"X-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@("1F:6QE("!N86UE
M(&]F(&9I;&4@;W(@9&ER96-T;W)Y#0H@("`@("H@0')E='5R;B`@=F]I9`T*
M("`@("`J+PT*("`@(&9U;F-T:6]N(&%D9%1E;7!&:6QE*"1F:6QE*0T*("`@
M('L-"B`@("`@("`@)$=,3T)!3%-;)U]014%27T-O;6UO;E]T96UP9FEL97,G
M75M=(#T@)&9I;&4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0W)E871E
M(&$@4$5!4E]086-K86=E1FEL95]V*B!F<F]M(&$@8V]M<')E<V5D(%1A<B!O
M<B!49WH@9FEL92X-"B`@("`@*B!`86-C97-S("!P=6)L:6,-"B`@("`@*B!`
M<&%R86T@<W1R:6YG(&-O;G1E;G1S(&]F('!A8VMA9V4N>&UL(&9I;&4-"B`@
M("`@*B!`<&%R86T@:6YT('!A8VMA9V4@<W1A=&4@*&]N92!O9B!014%27U9!
M3$E$051%7RH@8V]N<W1A;G1S*0T*("`@("`J($!R971U<FX@(%!%05)?4&%C
M:V%G949I;&5?=C%\4$5!4E]086-K86=E1FEL95]V,@T*("`@("`J($!U<VEN
M9R`@($%R8VAI=F5?5&%R('1O(&5X=')A8W0@=&AE(&9I;&5S#0H@("`@("H@
M0'5S:6YG("`@9G)O;5!A8VMA9V5&:6QE*"D@=&\@;&]A9"!T:&4@<&%C:V%G
M92!A9G1E<B!T:&4@<&%C:V%G92YX;6P-"B`@("`@*B`@("`@("`@("!F:6QE
M(&ES(&5X=')A8W1E9"X-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F9G)O;51G
M>D9I;&4H)&9I;&4L("1S=&%T92D-"B`@("![#0H@("`@("`@(&EF("@A8VQA
M<W-?97AI<W1S*"=!<F-H:79E7U1A<B<I*2![#0H@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@)T%R8VAI=F4O5&%R+G!H<"<[#0H@("`@("`@('T-"B`@("`@
M("`@)'1A<B`](&YE=R!!<F-H:79E7U1A<B@D9FEL92D[#0H@("`@("`@(&EF
M("@D=&AI<RT^7V1E8G5G(#P](#$I('L-"B`@("`@("`@("`@("1T87(M/G!U
M<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@
M?0T*("`@("`@("`D8V]N=&5N="`]("1T87(M/FQI<W1#;VYT96YT*"D[#0H@
M("`@("`@(&EF("@D=&AI<RT^7V1E8G5G(#P](#$I('L-"B`@("`@("`@("`@
M("1T87(M/G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H(6ES7V%R<F%Y*"1C;VYT96YT*2D@>PT*("`@("`@("`@("`@:68@
M*&ES7W-T<FEN9R@D9FEL92D@)B8@<W1R;&5N*"1F:6QE(#P@,C4U*2`F)B`A
M0&ES7V9I;&4H)&9I;&4I*2![#0H@("`@("`@("`@("`@("`@)')E="`](%!%
M05(Z.G)A:7-E17)R;W(H(F-O=6QD(&YO="!O<&5N(&9I;&4@7"(D9FEL95PB
M(BD[#0H@("`@("`@("`@("`@("`@<F5T=7)N("1R970[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`D9FEL92`](')E86QP871H*"1F:6QE*3L-"B`@
M("`@("`@("`@("1R970@/2!014%2.CIR86ES945R<F]R*")#;W5L9"!N;W0@
M9V5T(&-O;G1E;G1S(&]F('!A8VMA9V4@7"(D9FEL95PB(BX-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G+B!);G9A;&ED('1G>B!F
M:6QE+B<I.PT*("`@("`@("`@("`@<F5T=7)N("1R970[#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("!I9B`H(6-O=6YT*"1C;VYT96YT*2`F)B`A
M0&ES7V9I;&4H)&9I;&4I*2![#0H@("`@("`@("`@("`@("`@)')E="`](%!%
M05(Z.G)A:7-E17)R;W(H(F-O=6QD(&YO="!O<&5N(&9I;&4@7"(D9FEL95PB
M(BD[#0H@("`@("`@("`@("`@("`@<F5T=7)N("1R970[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@)'AM;"`](&YU;&P[#0H@("`@("`@
M("1O<FEG9FEL92`]("1F:6QE.PT*("`@("`@("!F;W)E86-H("@D8V]N=&5N
M="!A<R`D9FEL92D@>PT*("`@("`@("`@("`@)&YA;64@/2`D9FEL95LG9FEL
M96YA;64G73L-"B`@("`@("`@("`@(&EF("@D;F%M92`]/2`G<&%C:V%G93(N
M>&UL)RD@>R`O+R!A;&QO=R!A("YT9WH@=&\@9&ES=')I8G5T92!B;W1H('9E
M<G-I;VYS#0H@("`@("`@("`@("`@("`@)'AM;"`]("1N86UE.PT*("`@("`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M:68@*"1N86UE(#T]("=P86-K86=E+GAM;"<I('L-"B`@("`@("`@("`@("`@
M("`D>&UL(#T@)&YA;64[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@
M("`@("`@("!](&5L<V5I9B`H97)E9R@G<&%C:V%G92YX;6PD)RP@)&YA;64L
M("1M871C:"DI('L-"B`@("`@("`@("`@("`@("`D>&UL(#T@)&YA;64[#0H@
M("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"1T:&ES+3Y?=&UP9&ER*2![#0H@("`@("`@("`@
M("`D=&UP9&ER(#T@)'1H:7,M/E]T;7!D:7([#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`D=&UP9&ER(#T@4WES=&5M.CIM:U1E;7`H87)R87DH
M)RUD)RP@)W!E87(G*2D[#0H@("`@("`@("`@("!014%27U!A8VMA9V5&:6QE
M.CIA9&1496UP1FEL92@D=&UP9&ER*3L-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H(21X;6P@?'P@(21T87(M/F5X=')A8W1,:7-T*&%R<F%Y*"1X;6PI+"`D
M=&UP9&ER*2D@>PT*("`@("`@("`@("`@)')E="`](%!%05(Z.G)A:7-E17)R
M;W(H)V-O=6QD(&YO="!E>'1R86-T('1H92!P86-K86=E+GAM;"!F:6QE(&9R
M;VT@(B<@+@T*("`@("`@("`@("`@("`@("1O<FEG9FEL92`N("<B)RD[#0H@
M("`@("`@("`@("!R971U<FX@)')E=#L-"B`@("`@("`@?0T*("`@("`@("`D
M<F5T(#T@)E!%05)?4&%C:V%G949I;&4Z.F9R;VU086-K86=E1FEL92@B)'1M
M<&1I<B\D>&UL(BP@)'-T871E+"`D;W)I9V9I;&4I.PT*("`@("`@("!R971U
M<FX@)')E=#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!#<F5A=&4@82!0
M14%27U!A8VMA9V5&:6QE7W8J(&9R;VT@82!P86-K86=E+GAM;"!F:6QE+@T*
M("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`<&%R86T@
M("!S=')I;F<@("1D97-C9FEL92`@;F%M92!O9B!P86-K86=E('AM;"!F:6QE
M#0H@("`@("H@0'!A<F%M("`@:6YT("`@("`D<W1A=&4@<&%C:V%G92!S=&%T
M92`H;VYE(&]F(%!%05)?5D%,241!5$5?*B!C;VYS=&%N=',I#0H@("`@("H@
M0'!A<F%M("`@<W1R:6YG?&9A;'-E("1A<F-H:79E(&YA;64@;V8@=&AE(&%R
M8VAI=F4@=&AI<R!P86-K86=E+GAM;"!C86UE#0H@("`@("H@("`@("`@("`@
M9G)O;2P@:68@86YY#0H@("`@("H@0')E='5R;B`@4$5!4E]086-K86=E1FEL
M95]V,7Q014%27U!A8VMA9V5&:6QE7W8R#0H@("`@("H@0'5S97,@("`@4$5!
M4E]086-K86=E1FEL93HZ9G)O;5AM;%-T<FEN9R!T;R!C<F5A=&4@=&AE(&]J
M96-T(&%F=&5R('1H90T*("`@("`J("`@("`@("`@(%A-3"!I<R!L;V%D960@
M9G)O;2!T:&4@<&%C:V%G92YX;6P@9FEL92X-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B`F9G)O;5!A8VMA9V5&:6QE*"1D97-C9FEL92P@)'-T871E+"`D87)C
M:&EV92`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*&ES7W-T<FEN9R@D
M9&5S8V9I;&4I("8F('-T<FQE;B@D9&5S8V9I;&4I(#P@,C4U("8F#0H@("`@
M("`@("`@("`@(4!I<U]F:6QE*"1D97-C9FEL92D@?'P@(6ES7W)E861A8FQE
M*"1D97-C9FEL92D@?'P-"B`@("`@("`@("`@("`H(21F<"`]($!F;W!E;B@D
M9&5S8V9I;&4L("=R)RDI*2![#0H@("`@("`@("`@("`D82`](%!%05(Z.G)A
M:7-E17)R;W(H(E5N86)L92!T;R!O<&5N("1D97-C9FEL92(I.PT*("`@("`@
M("`@("`@<F5T=7)N("1A.PT*("`@("`@("!]#0H-"B`@("`@("`@+R\@<F5A
M9"!T:&4@=VAO;&4@=&AI;F<@<V\@=V4@;VYL>2!G970@;VYE(&-D871A(&-A
M;&QB86-K#0H@("`@("`@("\O(&9O<B!E86-H(&)L;V-K(&]F(&-D871A#0H@
M("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V9I;&5?9V5T7V-O;G1E;G1S
M)RDI('L-"B`@("`@("`@("`@($!F8VQO<V4H)&9P*3L-"B`@("`@("`@("`@
M("1D871A(#T@9FEL95]G971?8V]N=&5N=',H)&1E<V-F:6QE*3L-"B`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("1D871A(#T@)R<[#0H@("`@("`@
M("`@("!W:&EL92`H(69E;V8H)&9P*2D@>PT*("`@("`@("`@("`@("`@("1D
M871A("X]($!F<F5A9"@D9G`L(#@Q.3(I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@('T-"B`@("`@("`@)')E
M="`]("9014%27U!A8VMA9V5&:6QE.CIF<F]M6&UL4W1R:6YG*"1D871A+"`D
M<W1A=&4L("1D97-C9FEL92P@)&%R8VAI=F4I.PT*("`@("`@("!R971U<FX@
M)')E=#L-"B`@("!]#0H-"@T*("`@("\J*@T*("`@("`J($-R96%T92!A(%!%
M05)?4&%C:V%G949I;&5?=BH@9G)O;2!A("YT9WH@87)C:&EV92!O<B!P86-K
M86=E+GAM;"!F:6QE+@T*("`@("`J#0H@("`@("H@5&AI<R!M971H;V0@:7,@
M86)L92!T;R!E>'1R86-T(&EN9F]R;6%T:6]N(&%B;W5T(&$@<&%C:V%G92!F
M<F]M(&$@+G1G>@T*("`@("`J(&%R8VAI=F4@;W(@9G)O;2!A(%A-3"!P86-K
M86=E(&1E9FEN:71I;VX@9FEL92X-"B`@("`@*@T*("`@("`J($!A8V-E<W,@
M<'5B;&EC#0H@("`@("H@0'!A<F%M("`@<W1R:6YG("`D:6YF;R!F:6QE(&YA
M;64-"B`@("`@*B!`<&%R86T@("!I;G0@("`@("1S=&%T92!P86-K86=E('-T
M871E("AO;F4@;V8@4$5!4E]604Q)1$%415\J(&-O;G-T86YT<RD-"B`@("`@
M*B!`<F5T=7)N("!014%27U!A8VMA9V5&:6QE7W8Q?%!%05)?4&%C:V%G949I
M;&5?=C(-"B`@("`@*B!`=7-E<R`@("!F<F]M4&%C:V%G949I;&4H*2!I9B!T
M:&4@9FEL92!A<'!E87)S('1O(&)E(%A-3`T*("`@("`J($!U<V5S("`@(&9R
M;VU49WI&:6QE*"D@=&\@;&]A9"!A;&P@;F]N+5A-3"!F:6QE<PT*("`@("`J
M+PT*("`@(&9U;F-T:6]N("9F<F]M06YY1FEL92@D:6YF;RP@)'-T871E*0T*
M("`@('L-"B`@("`@("`@)&9P(#T@9F%L<V4[#0H@("`@("`@(&EF("AI<U]S
M=')I;F<H)&EN9F\I("8F('-T<FQE;B@D:6YF;RD@/"`R-34@)B8-"B`@("`@
M("`@("`@("`H9FEL95]E>&ES=',H)&EN9F\I('Q\("@D9G`@/2!`9F]P96XH
M)&EN9F\L("=R)RDI*2D@>PT*("`@("`@("`@("`@:68@*"1F<"D@>PT*("`@
M("`@("`@("`@("`@(&9C;&]S92@D9G`I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@)'1M<"`]('-U8G-T<B@D:6YF;RP@+30I.PT*("`@("`@("`@
M("`@:68@*"1T;7`@/3T@)RYX;6PG*2![#0H@("`@("`@("`@("`@("`@)&EN
M9F\@/2`F4$5!4E]086-K86=E1FEL93HZ9G)O;5!A8VMA9V5&:6QE*"1I;F9O
M+"`D<W1A=&4I.PT*("`@("`@("`@("`@?2!E;'-E:68@*"1T;7`@/3T@)RYT
M87(G('Q\("1T;7`@/3T@)RYT9WHG*2![#0H@("`@("`@("`@("`@("`@)&EN
M9F\@/2`F4$5!4E]086-K86=E1FEL93HZ9G)O;51G>D9I;&4H)&EN9F\L("1S
M=&%T92D[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("1F<"`](&9O<&5N*"1I;F9O+"`B<B(I.PT*("`@("`@("`@("`@("`@("1T
M97-T(#T@9G)E860H)&9P+"`U*3L-"B`@("`@("`@("`@("`@("!F8VQO<V4H
M)&9P*3L-"B`@("`@("`@("`@("`@("!I9B`H)'1E<W0@/3T@(CP_>&UL(BD@
M>PT*("`@("`@("`@("`@("`@("`@("`D:6YF;R`]("9014%27U!A8VMA9V5&
M:6QE.CIF<F]M4&%C:V%G949I;&4H)&EN9F\L("1S=&%T92D[#0H@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)&EN9F\@
M/2`F4$5!4E]086-K86=E1FEL93HZ9G)O;51G>D9I;&4H)&EN9F\L("1S=&%T
M92D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@)&EN9F\@/2!014%2.CIR86ES945R
M<F]R*")#86YN;W0@;W!E;B`G)&EN9F\G(&9O<B!P87)S:6YG(BD[#0H@("`@
M("`@("`@("!R971U<FX@)&EN9F\[#0H@("`@("`@('T-"B`@("`@("`@<F5T
M=7)N("1I;F9O.PT*("`@('T-"GT-"@T*/SX`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+U!%05(O4F5G:7-T<GDN<&AP````````````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`R,38R,C`@,3`U,34T,S,W,S(@,#(Q-30P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP#0HO*BH-"B`J(%!%05)?4F5G:7-T<GD-"B`J#0H@*B!02%`@=F5R<VEO
M;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@
M:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-
M"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M
M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@
M82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@
M=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD
M(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U
M(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R
M#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!3=&EG($)A
M:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R("`@("!4;VUA<R!6+B!6
M+B!#;W@@/&-O>$!I9&5C;F5T+F-O;3X-"B`J($!A=71H;W(@("`@($=R96<@
M0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M
M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J
M($!V97)S:6]N("`@($-64SH@)$ED.B!296=I<W1R>2YP:'`L=B`Q+C$U,"XR
M+C(@,C`P-B\P,R\Q,2`P-#HQ-CHT."!C96QL;V<@17AP("0-"B`J($!L:6YK
M("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`
M<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#`N,0T*
M("HO#0H-"B\J*@T*("H@9F]R(%!%05)?17)R;W(-"B`J+PT*<F5Q=6ER95]O
M;F-E("=014%2+G!H<"<[#0IR97%U:7)E7V]N8V4@)U!%05(O1&5P96YD96YC
M>41"+G!H<"<[#0H-"F1E9FEN92@G4$5!4E]214=)4U1265]%4E)/4E],3T-+
M)RP@("`M,BD[#0ID969I;F4H)U!%05)?4D5'25-44EE?15)23U)?1D]234%4
M)RP@+3,I.PT*9&5F:6YE*"=014%27U)%1TE35%)97T524D]27T9)3$4G+"`@
M("TT*3L-"F1E9FEN92@G4$5!4E]214=)4U1265]%4E)/4E]#3TY&3$E#5"<L
M("TU*3L-"F1E9FEN92@G4$5!4E]214=)4U1265]%4E)/4E]#2$%.3D5,7T9)
M3$4G+"`M-BD[#0H-"B\J*@T*("H@061M:6YI<W1R871I;VX@8VQA<W,@=7-E
M9"!T;R!M86EN=&%I;B!T:&4@:6YS=&%L;&5D('!A8VMA9V4@9&%T86)A<V4N
M#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@
M*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`
M875T:&]R("`@("!4;VUA<R!6+B!6+B!#;W@@/&-O>$!I9&5C;F5T+F-O;3X-
M"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-
M"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`
M;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT
M("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N
M-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA
M9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E
M(%)E;&5A<V4@,2XT+C!A,0T*("HO#0IC;&%S<R!014%27U)E9VES=')Y(&5X
M=&5N9',@4$5!4@T*>PT*("`@("\O('M[>R!P<F]P97)T:65S#0H-"B`@("`O
M*BH-"B`@("`@*B!&:6QE(&-O;G1A:6YI;F<@86QL(&-H86YN96P@:6YF;W)M
M871I;VXN#0H@("`@("H@0'9A<B!S=')I;F<-"B`@("`@*B\-"B`@("!V87(@
M)&-H86YN96QS(#T@)R<[#0H-"B`@("`O*BH@1&ER96-T;W)Y('=H97)E(')E
M9VES=')Y(&9I;&5S(&%R92!S=&]R960N#0H@("`@("H@0'9A<B!S=')I;F<-
M"B`@("`@*B\-"B`@("!V87(@)'-T871E9&ER(#T@)R<[#0H-"B`@("`O*BH@
M1FEL92!W:&5R92!T:&4@9FEL92!M87`@:7,@<W1O<F5D#0H@("`@("H@0'9A
M<B!S=')I;F<-"B`@("`@*B\-"B`@("!V87(@)&9I;&5M87`@/2`G)SL-"@T*
M("`@("\J*B!$:7)E8W1O<GD@=VAE<F4@<F5G:7-T<GD@9FEL97,@9F]R(&-H
M86YN96QS(&%R92!S=&]R960N#0H@("`@("H@0'9A<B!S=')I;F<-"B`@("`@
M*B\-"B`@("!V87(@)&-H86YN96QS9&ER(#T@)R<[#0H-"B`@("`O*BH@3F%M
M92!O9B!F:6QE('5S960@9F]R(&QO8VMI;F<@=&AE(')E9VES=')Y#0H@("`@
M("H@0'9A<B!S=')I;F<-"B`@("`@*B\-"B`@("!V87(@)&QO8VMF:6QE(#T@
M)R<[#0H-"B`@("`O*BH@1FEL92!D97-C<FEP=&]R('5S960@9'5R:6YG(&QO
M8VMI;F<-"B`@("`@*B!`=F%R(')E<V]U<F-E#0H@("`@("HO#0H@("`@=F%R
M("1L;V-K7V9P(#T@;G5L;#L-"@T*("`@("\J*B!-;V1E('5S960@9'5R:6YG
M(&QO8VMI;F<-"B`@("`@*B!`=F%R(&EN=`T*("`@("`J+PT*("`@('9A<B`D
M;&]C:U]M;V1E(#T@,#L@+R\@6%A8(%5.55-%1`T*#0H@("`@+RHJ($-A8VAE
M(&]F('!A8VMA9V4@:6YF;W)M871I;VXN("!3=')U8W1U<F4Z#0H@("`@("H@
M87)R87DH#0H@("`@("H@("`G<&%C:V%G92<@/3X@87)R87DH)VED)R`]/B`N
M+BX@*2P-"B`@("`@*B`@("XN+B`I#0H@("`@("H@0'9A<B!A<G)A>0T*("`@
M("`J+PT*("`@('9A<B`D<&MG:6YF;U]C86-H92`](&%R<F%Y*"D[#0H-"B`@
M("`O*BH@0V%C:&4@;V8@9FEL92!M87`N("!3=')U8W1U<F4Z#0H@("`@("H@
M87)R87DH("<O<&%T:"]T;R]F:6QE)R`]/B`G<&%C:V%G92<L("XN+B`I#0H@
M("`@("H@0'9A<B!A<G)A>0T*("`@("`J+PT*("`@('9A<B`D9FEL96UA<%]C
M86-H92`](&%R<F%Y*"D[#0H-"B`@("`O*BH-"B`@("`@*B!`=F%R(&9A;'-E
M?%!%05)?0VAA;FYE;$9I;&4-"B`@("`@*B\-"B`@("!V87(@)%]P96%R0VAA
M;FYE;#L-"@T*("`@("\J*@T*("`@("`J($!V87(@9F%L<V5\4$5!4E]#:&%N
M;F5L1FEL90T*("`@("`J+PT*("`@('9A<B`D7W!E8VQ#:&%N;F5L.PT*#0H@
M("`@+RHJ#0H@("`@("H@0'9A<B!014%27T1E<&5N9&5N8WE$0@T*("`@("`J
M+PT*("`@('9A<B`D7V1E<&5N9&5N8WE$0CL-"@T*("`@("\J*@T*("`@("`J
M($!V87(@4$5!4E]#;VYF:6<-"B`@("`@*B\-"B`@("!V87(@)%]C;VYF:6<[
M#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@8V]N<W1R=6-T;W(-"@T*("`@
M("\J*@T*("`@("`J(%!%05)?4F5G:7-T<GD@8V]N<W1R=6-T;W(N#0H@("`@
M("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("AO<'1I;VYA;"D@4$5!4B!I;G-T
M86QL(&1I<F5C=&]R>2`H9F]R("YP:'`@9FEL97,I#0H@("`@("H@0'!A<F%M
M(%!%05)?0VAA;FYE;$9I;&4@4$5!4E]#:&%N;F5L1FEL92!O8FIE8W0@<F5P
M<F5S96YT:6YG('1H92!014%2(&-H86YN96PL(&EF#0H@("`@("H@("`@("`@
M(&1E9F%U;'0@=F%L=65S(&%R92!N;W0@9&5S:7)E9"X@($]N;'D@=7-E9"!T
M:&4@=F5R>2!F:7)S="!T:6UE(&$@4$5!4@T*("`@("`J("`@("`@("!R97!O
M<VET;W)Y(&ES(&EN:71I86QI>F5D#0H@("`@("H@0'!A<F%M(%!%05)?0VAA
M;FYE;$9I;&4@4$5!4E]#:&%N;F5L1FEL92!O8FIE8W0@<F5P<F5S96YT:6YG
M('1H92!014-,(&-H86YN96PL(&EF#0H@("`@("H@("`@("`@(&1E9F%U;'0@
M=F%L=65S(&%R92!N;W0@9&5S:7)E9"X@($]N;'D@=7-E9"!T:&4@=F5R>2!F
M:7)S="!T:6UE(&$@4$5!4@T*("`@("`J("`@("`@("!R97!O<VET;W)Y(&ES
M(&EN:71I86QI>F5D#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*
M("`@("`J+PT*("`@(&9U;F-T:6]N(%!%05)?4F5G:7-T<GDH)'!E87)?:6YS
M=&%L;%]D:7(@/2!014%27TE.4U1!3$Q?1$E2+"`D<&5A<E]C:&%N;F5L(#T@
M9F%L<V4L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&5C;%]C:&%N
M;F5L(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!P87)E;G0Z.E!%05(H*3L-
M"B`@("`@("`@)&1S(#T@1$E214-43U)97U-%4$%2051/4CL-"B`@("`@("`@
M)'1H:7,M/FEN<W1A;&Q?9&ER(#T@)'!E87)?:6YS=&%L;%]D:7([#0H@("`@
M("`@("1T:&ES+3YC:&%N;F5L<V1I<B`]("1P96%R7VEN<W1A;&Q?9&ER+B1D
M<RXG+F-H86YN96QS)SL-"B`@("`@("`@)'1H:7,M/G-T871E9&ER(#T@)'!E
M87)?:6YS=&%L;%]D:7(N)&1S+B<N<F5G:7-T<GDG.PT*("`@("`@("`D=&AI
M<RT^9FEL96UA<"`@/2`D<&5A<E]I;G-T86QL7V1I<BXD9',N)RYF:6QE;6%P
M)SL-"B`@("`@("`@)'1H:7,M/FQO8VMF:6QE(#T@)'!E87)?:6YS=&%L;%]D
M:7(N)&1S+B<N;&]C:R<[#0H@("`@("`@("1T:&ES+3Y?<&5A<D-H86YN96P@
M/2`D<&5A<E]C:&%N;F5L.PT*("`@("`@("`D=&AI<RT^7W!E8VQ#:&%N;F5L
M(#T@)'!E8VQ?8VAA;FYE;#L-"B`@("`@("`@)'1H:7,M/E]C;VYF:6<@/2!F
M86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!H87-7<FET94%C8V5S<R@I
M#0H@("`@>PT*("`@("`@("!I9B`H(4!F:6QE7V5X:7-T<R@D=&AI<RT^:6YS
M=&%L;%]D:7(I*2![#0H@("`@("`@("`@("`D9&ER(#T@)'1H:7,M/FEN<W1A
M;&Q?9&ER.PT*("`@("`@("`@("`@=VAI;&4@*"1D:7(@)B8@)&1I<B`A/2`G
M+B<I('L-"B`@("`@("`@("`@("`@("`D9&ER(#T@9&ER;F%M92@D9&ER*3L@
M+R\@8V0@+BX-"B`@("`@("`@("`@("`@("!I9B`H)&1I<B`A/2`G+B<@)B8@
M0&9I;&5?97AI<W1S*"1D:7(I*2![#0H@("`@("`@("`@("`@("`@("`@(&EF
M("A`:7-?=W)I=&5A8FQE*"1D:7(I*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@
M?0T*("`@("`@("!R971U<FX@0&ES7W=R:71E86)L92@D=&AI<RT^:6YS=&%L
M;%]D:7(I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E=$-O;F9I9R@F)&-O
M;F9I9RD-"B`@("![#0H@("`@("`@("1T:&ES+3Y?8V]N9FEG(#T@)B1C;VYF
M:6<[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7VEN:71I86QI>F5#:&%N;F5L
M1&ER<R@I#0H@("`@>PT*("`@("`@("!S=&%T:6,@)')U;FYI;F<@/2!F86QS
M93L-"B`@("`@("`@:68@*"$D<G5N;FEN9RD@>PT*("`@("`@("`@("`@)')U
M;FYI;F<@/2!T<G5E.PT*("`@("`@("`@("`@)&1S(#T@1$E214-43U)97U-%
M4$%2051/4CL-"B`@("`@("`@("`@(&EF("@A:7-?9&ER*"1T:&ES+3YC:&%N
M;F5L<V1I<BD@?'P-"B`@("`@("`@("`@("`@("`@("%F:6QE7V5X:7-T<R@D
M=&AI<RT^8VAA;FYE;'-D:7(@+B`D9',@+B`G<&5A<BYP:'`N;F5T+G)E9R<I
M('Q\#0H@("`@("`@("`@("`@("`@("`A9FEL95]E>&ES=',H)'1H:7,M/F-H
M86YN96QS9&ER("X@)&1S("X@)W!E8VPN<&AP+FYE="YR96<G*2!\?`T*("`@
M("`@("`@("`@("`@("`@(69I;&5?97AI<W1S*"1T:&ES+3YC:&%N;F5L<V1I
M<B`N("1D<R`N("=?7W5R:2YR96<G*2D@>PT*("`@("`@("`@("`@("`@(&EF
M("@A9FEL95]E>&ES=',H)'1H:7,M/F-H86YN96QS9&ER("X@)&1S("X@)W!E
M87(N<&AP+FYE="YR96<G*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<&5A
M<E]C:&%N;F5L(#T@)'1H:7,M/E]P96%R0VAA;FYE;#L-"B`@("`@("`@("`@
M("`@("`@("`@:68@*"%I<U]A*"1P96%R7V-H86YN96PL("=014%27T-H86YN
M96Q&:6QE)RD@?'P@(21P96%R7V-H86YN96PM/G9A;&ED871E*"DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%2
M7T-H86YN96Q&:6QE)RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!R97%U:7)E7V]N8V4@)U!%05(O0VAA;FYE;$9I;&4N<&AP)SL-"B`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1P96%R7V-H86YN96P@/2!N97<@4$5!4E]#:&%N;F5L1FEL93L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1P96%R7V-H86YN96PM/G-E=$YA;64H)W!E
M87(N<&AP+FYE="<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'!E87)?
M8VAA;FYE;"T^<V5T06QI87,H)W!E87(G*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1P96%R7V-H86YN96PM/G-E=%-E<G9E<B@G<&5A<BYP:'`N;F5T
M)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`D<&5A<E]C:&%N;F5L+3YS
M9713=6UM87)Y*"=02%`@17AT96YS:6]N(&%N9"!!<'!L:6-A=&EO;B!297!O
M<VET;W)Y)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`D<&5A<E]C:&%N
M;F5L+3YS971$969A=6QT4$5!4E!R;W1O8V]L<R@I.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)'!E87)?8VAA;FYE;"T^<V5T0F%S95523"@G4D535#$N
M,"<L("=H='1P.B\O<&5A<BYP:'`N;F5T+W)E<W0O)RD[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D<&5A<E]C:&%N;F5L+3YS971"87-E55),*"=215-4
M,2XQ)RP@)VAT='`Z+R]P96%R+G!H<"YN970O<F5S="\G*3L-"B`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1P96%R7V-H86YN96PM/G-E=$YA;64H)W!E87(N<&AP+FYE="<I.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)'!E87)?8VAA;FYE;"T^<V5T06QI87,H
M)W!E87(G*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`D<&5A<E]C:&%N;F5L+3YV86QI9&%T92@I.PT*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7V%D9$-H86YN96PH)'!E87)?8VAA;FYE;"D[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@A9FEL
M95]E>&ES=',H)'1H:7,M/F-H86YN96QS9&ER("X@)&1S("X@)W!E8VPN<&AP
M+FYE="YR96<G*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<&5C;%]C:&%N
M;F5L(#T@)'1H:7,M/E]P96-L0VAA;FYE;#L-"B`@("`@("`@("`@("`@("`@
M("`@:68@*"%I<U]A*"1P96-L7V-H86YN96PL("=014%27T-H86YN96Q&:6QE
M)RD@?'P@(21P96-L7V-H86YN96PM/G9A;&ED871E*"DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27T-H86YN
M96Q&:6QE)RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@)U!%05(O0VAA;FYE;$9I;&4N<&AP)SL-"B`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("1P96-L
M7V-H86YN96P@/2!N97<@4$5!4E]#:&%N;F5L1FEL93L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1P96-L7V-H86YN96PM/G-E=$YA;64H)W!E8VPN<&AP
M+FYE="<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'!E8VQ?8VAA;FYE
M;"T^<V5T06QI87,H)W!E8VPG*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1P96-L7V-H86YN96PM/G-E=%-E<G9E<B@G<&5C;"YP:'`N;F5T)RD[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D<&5C;%]C:&%N;F5L+3YS9713=6UM
M87)Y*"=02%`@17AT96YS:6]N($-O;6UU;FET>2!,:6)R87)Y)RD[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D<&5C;%]C:&%N;F5L+3YS971$969A=6QT
M4$5!4E!R;W1O8V]L<R@I.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'!E
M8VQ?8VAA;FYE;"T^<V5T0F%S95523"@G4D535#$N,"<L("=H='1P.B\O<&5C
M;"YP:'`N;F5T+W)E<W0O)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M<&5C;%]C:&%N;F5L+3YS971"87-E55),*"=215-4,2XQ)RP@)VAT='`Z+R]P
M96-L+G!H<"YN970O<F5S="\G*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1P96-L7V-H86YN96PM/G-E=%9A;&ED871I;VY086-K86=E*"=014%27U9A
M;&ED871O<E]014-,)RP@)S$N,"<I.PT*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'!E8VQ?8VAA;FYE
M;"T^<V5T3F%M92@G<&5C;"YP:'`N;F5T)RD[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D<&5C;%]C:&%N;F5L+3YS971!;&EA<R@G<&5C;"<I.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1P96-L
M7V-H86YN96PM/G9A;&ED871E*"D[#0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?861D0VAA;FYE;"@D<&5C;%]C:&%N;F5L*3L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"%F:6QE7V5X:7-T<R@D=&AI
M<RT^8VAA;FYE;'-D:7(@+B`D9',@+B`G7U]U<FDN<F5G)RDI('L-"B`@("`@
M("`@("`@("`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?0VAA;FYE
M;$9I;&4G*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5Q=6ER95]O
M;F-E("=014%2+T-H86YN96Q&:6QE+G!H<"<[#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@)'!R:79A=&4@/2!N97<@4$5!
M4E]#:&%N;F5L1FEL93L-"B`@("`@("`@("`@("`@("`@("`@)'!R:79A=&4M
M/G-E=$YA;64H)U]?=7)I)RD[#0H@("`@("`@("`@("`@("`@("`@("1P<FEV
M871E+3YA9&1&=6YC=&EO;B@G>&UL<G!C)RP@)S$N,"<L("<J*BHJ)RD[#0H@
M("`@("`@("`@("`@("`@("`@("1P<FEV871E+3YS9713=6UM87)Y*"=0<V5U
M9&\M8VAA;FYE;"!F;W(@<W1A=&EC('!A8VMA9V5S)RD[#0H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?861D0VAA;FYE;"@D<')I=F%T92D[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5B=6EL
M9$9I;&5-87`H*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1R=6YN
M:6YG(#T@9F%L<V4[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!?:6YI=&EA;&EZ941I<G,H*0T*("`@('L-"B`@("`@("`@)&1S(#T@1$E2
M14-43U)97U-%4$%2051/4CL-"B`@("`@("`@+R\@6%A8($-O;7!A=&EB:6QI
M='D@8V]D92!S:&]U;&0@8F4@<F5M;W9E9"!I;B!T:&4@9G5T=7)E#0H@("`@
M("`@("\O(')E;F%M92!A;&P@<F5G:7-T<GD@9FEL97,@:68@86YY('1O(&QO
M=V5R8V%S90T*("`@("`@("!I9B`H(4]37U=)3D1/5U,@)B8@)&AA;F1L92`]
M($!O<&5N9&ER*"1T:&ES+3YS=&%T961I<BDI('L-"B`@("`@("`@("`@("1D
M97-T(#T@)'1H:7,M/G-T871E9&ER("X@)&1S.PT*("`@("`@("`@("`@=VAI
M;&4@*&9A;'-E("$]/2`H)&9I;&4@/2!R96%D9&ER*"1H86YD;&4I*2D@>PT*
M("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7BXJ6T$M6ETN*EPN
M<F5G)"\G+"`D9FEL92DI('L-"B`@("`@("`@("`@("`@("`@("`@<F5N86UE
M*"1D97-T("X@)&9I;&4L("1D97-T("X@<W1R=&]L;W=E<B@D9FEL92DI.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&-L;W-E9&ER*"1H86YD;&4I.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES
M+3Y?:6YI=&EA;&EZ94-H86YN96Q$:7)S*"D[#0H@("`@("`@(&EF("@A9FEL
M95]E>&ES=',H)'1H:7,M/F9I;&5M87`I*2![#0H@("`@("`@("`@("`D=&AI
M<RT^7W)E8G5I;&1&:6QE36%P*"D[#0H@("`@("`@('T-"B`@("`@("`@)'1H
M:7,M/E]I;FET:6%L:7IE1&5P1$(H*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!?:6YI=&EA;&EZ941E<$1"*"D-"B`@("![#0H@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]D97!E;F1E;F-Y1$(I*2![#0H@("`@("`@("`@("!S=&%T
M:6,@)&EN:71I86QI>FEN9R`](&9A;'-E.PT*("`@("`@("`@("`@:68@*"$D
M:6YI=&EA;&EZ:6YG*2![#0H@("`@("`@("`@("`@("`@)&EN:71I86QI>FEN
M9R`]('1R=64[#0H@("`@("`@("`@("`@("`@:68@*"$D=&AI<RT^7V-O;F9I
M9RD@>R`O+R!N979E<B!U<V5D/PT*("`@("`@("`@("`@("`@("`@("!I9B`H
M3U-?5TE.1$]74RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&9I;&4@
M/2`G<&5A<BYI;FDG.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)&9I;&4@/2`G+G!E87)R8R<[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]C;VYF:6<@/2`F;F5W(%!%05)?0V]N9FEG*"1T:&ES+3YS=&%T961I
M<B`N($1)4D5#5$]265]315!!4D%43U(@+@T*("`@("`@("`@("`@("`@("`@
M("`@("`@)&9I;&4I.PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-O
M;F9I9RT^<V5T4F5G:7-T<GDH)'1H:7,I.PT*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V-O;F9I9RT^<V5T*"=P:'!?9&ER)RP@)'1H:7,M/FEN<W1A
M;&Q?9&ER*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M)'1H:7,M/E]D97!E;F1E;F-Y1$(@/2`F4$5!4E]$97!E;F1E;F-Y1$(Z.G-I
M;F=L971O;B@D=&AI<RT^7V-O;F9I9RD[#0H@("`@("`@("`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)'1H:7,M/E]D97!E;F1E;F-Y1$(I*2![#0H@("`@
M("`@("`@("`@("`@("`@("\O(&%T=&5M<'0@=&\@<F5C;W9E<B!B>2!R96UO
M=FEN9R!T:&4@9&5P(&1B#0H@("`@("`@("`@("`@("`@("`@($!U;FQI;FLH
M)'1H:7,M/E]C;VYF:6<M/F=E="@G<&AP7V1I<B<L(&YU;&PL("=P96%R+G!H
M<"YN970G*2`N#0H@("`@("`@("`@("`@("`@("`@("`@("!$25)%0U1/4EE?
M4T5005)!5$]2("X@)RYD97!D8B<I.PT*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7V1E<&5N9&5N8WE$0B`]("9014%27T1E<&5N9&5N8WE$0CHZ<VEN
M9VQE=&]N*"1T:&ES+3Y?8V]N9FEG*3L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)'1H:7,M/E]D97!E;F1E;F-Y1$(I*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("!E8VAO("1T:&ES+3Y?9&5P96YD96YC
M>41"+3YG971-97-S86=E*"D[#0H@("`@("`@("`@("`@("`@("`@("`@("!D
M:64H)U5N<F5C;W9E<F%B;&4@97)R;W(G*3L-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D:6YI
M=&EA;&EZ:6YG(#T@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("!]#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&1E<W1R=6-T;W(-"@T*
M("`@("\J*@T*("`@("`J(%!%05)?4F5G:7-T<GD@9&5S=')U8W1O<BX@($UA
M:V5S('-U<F4@;F\@;&]C:W,@87)E(&9O<F=O='1E;BX-"B`@("`@*@T*("`@
M("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]0
M14%27U)E9VES=')Y*"D-"B`@("![#0H@("`@("`@('!A<F5N=#HZ7U!%05(H
M*3L-"B`@("`@("`@:68@*&ES7W)E<V]U<F-E*"1T:&ES+3YL;V-K7V9P*2D@
M>PT*("`@("`@("`@("`@)'1H:7,M/E]U;FQO8VLH*3L-"B`@("`@("`@?0T*
M("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(%]A<W-E<G13=&%T
M941I<B@I#0H-"B`@("`O*BH-"B`@("`@*B!-86ME('-U<F4@=&AE(&1I<F5C
M=&]R>2!W:&5R92!W92!K965P(')E9VES=')Y(&9I;&5S(&5X:7-T<RX-"B`@
M("`@*@T*("`@("`J($!R971U<FX@8F]O;"!44E5%(&EF(&1I<F5C=&]R>2!E
M>&ES=',L($9!3%-%(&EF(&ET(&-O=6QD(&YO="!B90T*("`@("`J(&-R96%T
M960-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*
M("`@(&9U;F-T:6]N(%]A<W-E<G13=&%T941I<B@D8VAA;FYE;"`](&9A;'-E
M*0T*("`@('L-"B`@("`@("`@:68@*"1C:&%N;F5L("8F("1T:&ES+3Y?9V5T
M0VAA;FYE;$9R;VU!;&EA<R@D8VAA;FYE;"D@(3T@)W!E87(N<&AP+FYE="<I
M('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V%S<V5R=$-H86YN96Q3
M=&%T941I<B@D8VAA;FYE;"D[#0H@("`@("`@('T-"B`@("`@("`@<W1A=&EC
M("1I;FET(#T@9F%L<V4[#0H@("`@("`@(&EF("@A0&ES7V1I<B@D=&AI<RT^
M<W1A=&5D:7(I*2![#0H@("`@("`@("`@("!I9B`H(21T:&ES+3YH87-7<FET
M94%C8V5S<R@I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=3>7-T
M96TN<&AP)SL-"B`@("`@("`@("`@(&EF("@A4WES=&5M.CIM:V1I<BAA<G)A
M>2@G+7`G+"`D=&AI<RT^<W1A=&5D:7(I*2D@>PT*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B8V]U;&0@;F]T(&-R96%T92!D
M:7)E8W1O<GD@)WLD=&AI<RT^<W1A=&5D:7)])R(I.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@)&EN:70@/2!T<G5E.PT*("`@("`@("!]#0H@("`@
M("`@("1D<R`]($1)4D5#5$]265]315!!4D%43U([#0H@("`@("`@(&EF("@A
M0&ES7V1I<B@D=&AI<RT^8VAA;FYE;'-D:7(I('Q\#0H@("`@("`@("`@("`@
M("%F:6QE7V5X:7-T<R@D=&AI<RT^8VAA;FYE;'-D:7(@+B`D9',@+B`G<&5A
M<BYP:'`N;F5T+G)E9R<I('Q\#0H@("`@("`@("`@("`@("%F:6QE7V5X:7-T
M<R@D=&AI<RT^8VAA;FYE;'-D:7(@+B`D9',@+B`G<&5C;"YP:'`N;F5T+G)E
M9R<I('Q\#0H@("`@("`@("`@("`@("%F:6QE7V5X:7-T<R@D=&AI<RT^8VAA
M;FYE;'-D:7(@+B`D9',@+B`G7U]U<FDN<F5G)RDI('L-"B`@("`@("`@("`@
M("1I;FET(#T@=')U93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&EN:70I
M('L-"B`@("`@("`@("`@('-T871I8R`D<G5N;FEN9R`](&9A;'-E.PT*("`@
M("`@("`@("`@:68@*"$D<G5N;FEN9RD@>PT*("`@("`@("`@("`@("`@("1R
M=6YN:6YG(#T@=')U93L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7VEN:71I
M86QI>F5$:7)S*"D[#0H@("`@("`@("`@("`@("`@)')U;FYI;F<@/2!F86QS
M93L-"B`@("`@("`@("`@("`@("`D:6YI="`](&9A;'-E.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'1H:7,M/E]I
M;FET:6%L:7IE1&5P1$(H*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M=')U93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@7V%S<V5R
M=$-H86YN96Q3=&%T941I<B@I#0H-"B`@("`O*BH-"B`@("`@*B!-86ME('-U
M<F4@=&AE(&1I<F5C=&]R>2!W:&5R92!W92!K965P(')E9VES=')Y(&9I;&5S
M(&5X:7-T<R!F;W(@82!N;VXM<W1A;F1A<F0@8VAA;FYE;"X-"B`@("`@*@T*
M("`@("`J($!P87)A;2!S=')I;F<@8VAA;FYE;"!N86UE#0H@("`@("H@0')E
M='5R;B!B;V]L(%12544@:68@9&ER96-T;W)Y(&5X:7-T<RP@1D%,4T4@:68@
M:70@8V]U;&0@;F]T(&)E#0H@("`@("H@8W)E871E9`T*("`@("`J#0H@("`@
M("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7V%S
M<V5R=$-H86YN96Q3=&%T941I<B@D8VAA;FYE;"D-"B`@("![#0H@("`@("`@
M("1D<R`]($1)4D5#5$]265]315!!4D%43U([#0H@("`@("`@(&EF("@A)&-H
M86YN96P@?'P@)'1H:7,M/E]G971#:&%N;F5L1G)O;4%L:6%S*"1C:&%N;F5L
M*2`]/2`G<&5A<BYP:'`N;F5T)RD@>PT*("`@("`@("`@("`@:68@*"%F:6QE
M7V5X:7-T<R@D=&AI<RT^8VAA;FYE;'-D:7(@+B`D9',@+B`G<&5A<BYP:'`N
M;F5T+G)E9R<I*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]I;FET:6%L
M:7IE0VAA;FYE;$1I<G,H*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7V%S<V5R=%-T871E1&ER*"1C:&%N;F5L*3L-"B`@
M("`@("`@?0T*("`@("`@("`D8VAA;FYE;$1I<B`]("1T:&ES+3Y?8VAA;FYE
M;$1I<F5C=&]R>4YA;64H)&-H86YN96PI.PT*("`@("`@("!I9B`H(6ES7V1I
M<B@D=&AI<RT^8VAA;FYE;'-D:7(I('Q\#0H@("`@("`@("`@("`@("%F:6QE
M7V5X:7-T<R@D=&AI<RT^8VAA;FYE;'-D:7(@+B`D9',@+B`G<&5A<BYP:'`N
M;F5T+G)E9R<I*2![#0H@("`@("`@("`@("`D=&AI<RT^7VEN:71I86QI>F5#
M:&%N;F5L1&ER<R@I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A0&ES7V1I
M<B@D8VAA;FYE;$1I<BDI('L-"B`@("`@("`@("`@(&EF("@A)'1H:7,M/FAA
M<U=R:71E06-C97-S*"DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M)U-Y<W1E;2YP:'`G.PT*("`@("`@("`@("`@:68@*"%3>7-T96TZ.FUK9&ER
M*&%R<F%Y*"<M<"<L("1C:&%N;F5L1&ER*2DI('L-"B`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F-O=6QD(&YO="!C<F5A=&4@
M9&ER96-T;W)Y("<B("X@)&-H86YN96Q$:7(@+@T*("`@("`@("`@("`@("`@
M("`@("`B)R(I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[
M>R!?87-S97)T0VAA;FYE;$1I<B@I#0H-"B`@("`O*BH-"B`@("`@*B!-86ME
M('-U<F4@=&AE(&1I<F5C=&]R>2!W:&5R92!W92!K965P(')E9VES=')Y(&9I
M;&5S(&9O<B!C:&%N;F5L<R!E>&ES=',-"B`@("`@*@T*("`@("`J($!R971U
M<FX@8F]O;"!44E5%(&EF(&1I<F5C=&]R>2!E>&ES=',L($9!3%-%(&EF(&ET
M(&-O=6QD(&YO="!B90T*("`@("`J(&-R96%T960-"B`@("`@*@T*("`@("`J
M($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]A<W-E
M<G1#:&%N;F5L1&ER*"D-"B`@("![#0H@("`@("`@(&EF("@A0&ES7V1I<B@D
M=&AI<RT^8VAA;FYE;'-D:7(I*2![#0H@("`@("`@("`@("!I9B`H(21T:&ES
M+3YH87-7<FET94%C8V5S<R@I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5Q=6ER95]O
M;F-E("=3>7-T96TN<&AP)SL-"B`@("`@("`@("`@(&EF("@A4WES=&5M.CIM
M:V1I<BAA<G)A>2@G+7`G+"`D=&AI<RT^8VAA;FYE;'-D:7(I*2D@>PT*("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B8V]U;&0@
M;F]T(&-R96%T92!D:7)E8W1O<GD@)WLD=&AI<RT^8VAA;FYE;'-D:7)])R(I
M.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@A0&ES
M7V1I<B@D=&AI<RT^8VAA;FYE;'-D:7(@+B!$25)%0U1/4EE?4T5005)!5$]2
M("X@)RYA;&EA<R<I*2![#0H@("`@("`@("`@("!I9B`H(21T:&ES+3YH87-7
M<FET94%C8V5S<R@I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=3
M>7-T96TN<&AP)SL-"B`@("`@("`@("`@(&EF("@A4WES=&5M.CIM:V1I<BAA
M<G)A>2@G+7`G+"`D=&AI<RT^8VAA;FYE;'-D:7(@+B!$25)%0U1/4EE?4T50
M05)!5$]2("X@)RYA;&EA<R<I*2D@>PT*("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@B8V]U;&0@;F]T(&-R96%T92!D:7)E8W1O
M<GD@)WLD=&AI<RT^8VAA;FYE;'-D:7)]+RYA;&EA<R<B*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]
M#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@7W!A8VMA9V5&:6QE3F%M92@I
M#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE(&YA;64@;V8@=&AE(&9I;&4@
M=VAE<F4@9&%T82!F;W(@82!G:79E;B!P86-K86=E(&ES('-T;W)E9"X-"B`@
M("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@8VAA;FYE;"!N86UE+"!O<B!F
M86QS92!I9B!T:&ES(&ES(&$@4$5!4B!P86-K86=E#0H@("`@("H@0'!A<F%M
M('-T<FEN9R!P86-K86=E(&YA;64-"B`@("`@*@T*("`@("`J($!R971U<FX@
M<W1R:6YG(')E9VES=')Y(&9I;&4@;F%M90T*("`@("`J#0H@("`@("H@0&%C
M8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?<&%C:V%G949I
M;&5.86UE*"1P86-K86=E+"`D8VAA;FYE;"`](&9A;'-E*0T*("`@('L-"B`@
M("`@("`@:68@*"1C:&%N;F5L("8F("1T:&ES+3Y?9V5T0VAA;FYE;$9R;VU!
M;&EA<R@D8VAA;FYE;"D@(3T@)W!E87(N<&AP+FYE="<I('L-"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7V-H86YN96Q$:7)E8W1O<GE.86UE*"1C:&%N
M;F5L*2`N($1)4D5#5$]265]315!!4D%43U(@+@T*("`@("`@("`@("`@("`@
M('-T<G1O;&]W97(H)'!A8VMA9V4I("X@)RYR96<G.PT*("`@("`@("!]#0H@
M("`@("`@(')E='5R;B`D=&AI<RT^<W1A=&5D:7(@+B!$25)%0U1/4EE?4T50
M05)!5$]2("X@<W1R=&]L;W=E<B@D<&%C:V%G92D@+B`G+G)E9R<[#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(%]C:&%N;F5L1FEL94YA;64H
M*0T*#0H@("`@+RHJ#0H@("`@("H@1V5T('1H92!N86UE(&]F('1H92!F:6QE
M('=H97)E(&1A=&$@9F]R(&$@9VEV96X@8VAA;FYE;"!I<R!S=&]R960N#0H@
M("`@("H@0'!A<F%M('-T<FEN9R!C:&%N;F5L(&YA;64-"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R!R96=I<W1R>2!F:6QE(&YA;64-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!?8VAA;FYE;$9I;&5.86UE*"1C:&%N;F5L+"`D;F]A;&EA<V5S
M(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H(21N;V%L:6%S97,I('L-
M"B`@("`@("`@("`@(&EF("A`9FEL95]E>&ES=',H)'1H:7,M/E]G971#:&%N
M;F5L06QI87-&:6QE3F%M92@D8VAA;FYE;"DI*2![#0H@("`@("`@("`@("`@
M("`@)&-H86YN96P@/2!I;7!L;V1E*"<G+"!F:6QE*"1T:&ES+3Y?9V5T0VAA
M;FYE;$%L:6%S1FEL94YA;64H)&-H86YN96PI*2D[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1T:&ES+3YC:&%N;F5L<V1I
M<B`N($1)4D5#5$]265]315!!4D%43U(@+B!S=')?<F5P;&%C92@G+R<L("=?
M)RP-"B`@("`@("`@("`@('-T<G1O;&]W97(H)&-H86YN96PI*2`N("<N<F5G
M)SL-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T0VAA;FYE
M;$%L:6%S1FEL94YA;64H*0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('-T
M<FEN9PT*("`@("`J($!R971U<FX@<W1R:6YG#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@7V=E=$-H86YN96Q!;&EA<T9I;&5.86UE*"1A;&EA<RD-"B`@("![
M#0H@("`@("`@(')E='5R;B`D=&AI<RT^8VAA;FYE;'-D:7(@+B!$25)%0U1/
M4EE?4T5005)!5$]2("X@)RYA;&EA<R<@+@T*("`@("`@("`@("`@("!$25)%
M0U1/4EE?4T5005)!5$]2("X@<W1R7W)E<&QA8V4H)R\G+"`G7R<L('-T<G1O
M;&]W97(H)&%L:6%S*2D@+B`G+G1X="<[#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0H@("`@+R\@>WM[(%]G971#:&%N;F5L1G)O;4%L:6%S*"D-"@T*("`@("\J
M*@T*("`@("`J($=E="!T:&4@;F%M92!O9B!A(&-H86YN96P@9G)O;2!I=',@
M86QI87,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?9V5T0VAA;FYE;$9R;VU!
M;&EA<R@D8VAA;FYE;"D-"B`@("![#0H@("`@("`@(&EF("@A)'1H:7,M/E]C
M:&%N;F5L17AI<W1S*"1C:&%N;F5L*2D@>PT*("`@("`@("`@("`@:68@*"1C
M:&%N;F5L(#T]("=P96%R+G!H<"YN970G*2![#0H@("`@("`@("`@("`@("`@
M<F5T=7)N("=P96%R+G!H<"YN970G.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@:68@*"1C:&%N;F5L(#T]("=P96-L+G!H<"YN970G*2![#0H@("`@
M("`@("`@("`@("`@<F5T=7)N("=P96-L+G!H<"YN970G.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@:68@*"1C:&%N;F5L(#T]("=?7W5R:2<I('L-
M"B`@("`@("`@("`@("`@("!R971U<FX@)U]?=7)I)SL-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@
M("`@("`D8VAA;FYE;"`]('-T<G1O;&]W97(H)&-H86YN96PI.PT*("`@("`@
M("!I9B`H9FEL95]E>&ES=',H)'1H:7,M/E]G971#:&%N;F5L06QI87-&:6QE
M3F%M92@D8VAA;FYE;"DI*2![#0H@("`@("`@("`@("`O+R!T<F%N<VQA=&4@
M86X@86QI87,@=&\@86X@86-T=6%L(&-H86YN96P-"B`@("`@("`@("`@(')E
M='5R;B!I;7!L;V1E*"<G+"!F:6QE*"1T:&ES+3Y?9V5T0VAA;FYE;$%L:6%S
M1FEL94YA;64H)&-H86YN96PI*2D[#0H@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("!R971U<FX@)&-H86YN96P[#0H@("`@("`@('T-"B`@("!]("`@
M(`T*("`@("\O('U]?0T*("`@("\O('M[>R!?9V5T0VAA;FYE;$9R;VU!;&EA
M<R@I#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE(&%L:6%S(&]F(&$@8VAA
M;FYE;"!F<F]M(&ET<R!A;&EA<R!O<B!I=',@;F%M90T*("`@("`J+PT*("`@
M(&9U;F-T:6]N(%]G971!;&EA<R@D8VAA;FYE;"D-"B`@("![#0H@("`@("`@
M(&EF("@A)'1H:7,M/E]C:&%N;F5L17AI<W1S*"1C:&%N;F5L*2D@>PT*("`@
M("`@("`@("`@:68@*"1C:&%N;F5L(#T]("=P96%R+G!H<"YN970G*2![#0H@
M("`@("`@("`@("`@("`@<F5T=7)N("=P96%R)SL-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(&EF("@D8VAA;FYE;"`]/2`G<&5C;"YP:'`N;F5T)RD@
M>PT*("`@("`@("`@("`@("`@(')E='5R;B`G<&5C;"<[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@
M("`@("`@)&-H86YN96P@/2`D=&AI<RT^7V=E=$-H86YN96PH)&-H86YN96PI
M.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8VAA;FYE;"DI('L-"B`@
M("`@("`@("`@(')E='5R;B`D8VAA;FYE;#L-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@)&-H86YN96PM/F=E=$%L:6%S*"D[#0H@("`@?2`@("`-"B`@
M("`O+R!]?7T-"B`@("`O+R![>WL@7V-H86YN96Q$:7)E8W1O<GE.86UE*"D-
M"@T*("`@("\J*@T*("`@("`J($=E="!T:&4@;F%M92!O9B!T:&4@9FEL92!W
M:&5R92!D871A(&9O<B!A(&=I=F5N('!A8VMA9V4@:7,@<W1O<F5D+@T*("`@
M("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R!C:&%N;F5L(&YA;64L(&]R(&9A
M;'-E(&EF('1H:7,@:7,@82!014%2('!A8VMA9V4-"B`@("`@*B!`<&%R86T@
M<W1R:6YG('!A8VMA9V4@;F%M90T*("`@("`J#0H@("`@("H@0')E='5R;B!S
M=')I;F<@<F5G:7-T<GD@9FEL92!N86UE#0H@("`@("H-"B`@("`@*B!`86-C
M97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(%]C:&%N;F5L1&ER
M96-T;W)Y3F%M92@D8VAA;FYE;"D-"B`@("![#0H@("`@("`@(&EF("@A)&-H
M86YN96P@?'P@)'1H:7,M/E]G971#:&%N;F5L1G)O;4%L:6%S*"1C:&%N;F5L
M*2`]/2`G<&5A<BYP:'`N;F5T)RD@>PT*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YS=&%T961I<CL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("1C:"`]("1T:&ES+3Y?9V5T0VAA;FYE;$9R;VU!;&EA<R@D8VAA;FYE;"D[
M#0H@("`@("`@("`@("!I9B`H(21C:"D@>PT*("`@("`@("`@("`@("`@("1C
M:"`]("1C:&%N;F5L.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YS=&%T961I<B`N($1)4D5#5$]265]315!!4D%43U(@+B!S
M=')T;VQO=V5R*"<N8VAA;FYE;"XG("X-"B`@("`@("`@("`@("`@("!S=')?
M<F5P;&%C92@G+R<L("=?)RP@)&-H*2D[#0H@("`@("`@('T-"B`@("!]#0H-
M"B`@("`O+R!]?7T-"B`@("`O+R![>WL@7V]P96Y086-K86=E1FEL92@I#0H-
M"B`@("!F=6YC=&EO;B!?;W!E;E!A8VMA9V5&:6QE*"1P86-K86=E+"`D;6]D
M92P@)&-H86YN96P@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@A)'1H
M:7,M/E]A<W-E<G13=&%T941I<B@D8VAA;FYE;"DI('L-"B`@("`@("`@("`@
M(')E='5R;B!N=6QL.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:6Y?87)R
M87DH)&UO9&4L(&%R<F%Y*"=R)RP@)W)B)RDI("8F("$D=&AI<RT^:&%S5W)I
M=&5!8V-E<W,H*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&YU;&P[#0H@("`@
M("`@('T-"B`@("`@("`@)&9I;&4@/2`D=&AI<RT^7W!A8VMA9V5&:6QE3F%M
M92@D<&%C:V%G92P@)&-H86YN96PI.PT*("`@("`@("`D9G`@/2!`9F]P96XH
M)&9I;&4L("1M;V1E*3L-"B`@("`@("`@:68@*"$D9G`I('L-"B`@("`@("`@
M("`@(')E='5R;B!N=6QL.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D
M9G`[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(%]C;&]S95!A
M8VMA9V5&:6QE*"D-"@T*("`@(&9U;F-T:6]N(%]C;&]S95!A8VMA9V5&:6QE
M*"1F<"D-"B`@("![#0H@("`@("`@(&9C;&]S92@D9G`I.PT*("`@('T-"@T*
M("`@("\O('U]?0T*("`@("\O('M[>R!?;W!E;E!A8VMA9V5&:6QE*"D-"@T*
M("`@(&9U;F-T:6]N(%]O<&5N0VAA;FYE;$9I;&4H)&-H86YN96PL("1M;V1E
M*0T*("`@('L-"B`@("`@("`@:68@*"$D=&AI<RT^7V%S<V5R=$-H86YN96Q$
M:7(H*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&YU;&P[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"%I;E]A<G)A>2@D;6]D92P@87)R87DH)W(G+"`G<F(G
M*2D@)B8@(21T:&ES+3YH87-7<FET94%C8V5S<R@I*2![#0H@("`@("`@("`@
M("!R971U<FX@;G5L;#L-"B`@("`@("`@?0T*("`@("`@("`D9FEL92`]("1T
M:&ES+3Y?8VAA;FYE;$9I;&5.86UE*"1C:&%N;F5L*3L-"B`@("`@("`@)&9P
M(#T@0&9O<&5N*"1F:6QE+"`D;6]D92D[#0H@("`@("`@(&EF("@A)&9P*2![
M#0H@("`@("`@("`@("!R971U<FX@;G5L;#L-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@)&9P.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[
M>R!?8VQO<V5086-K86=E1FEL92@I#0H-"B`@("!F=6YC=&EO;B!?8VQO<V5#
M:&%N;F5L1FEL92@D9G`I#0H@("`@>PT*("`@("`@("!F8VQO<V4H)&9P*3L-
M"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@7W)E8G5I;&1&:6QE
M36%P*"D-"@T*("`@(&9U;F-T:6]N(%]R96)U:6QD1FEL94UA<"@I#0H@("`@
M>PT*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]);G-T86QL97)?
M4F]L92<I*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O26YS
M=&%L;&5R+U)O;&4N<&AP)SL-"B`@("`@("`@?0T*("`@("`@("`D8VAA;FYE
M;',@/2`D=&AI<RT^7VQI<W1!;&Q086-K86=E<R@I.PT*("`@("`@("`D9FEL
M97,@/2!A<G)A>2@I.PT*("`@("`@("!F;W)E86-H("@D8VAA;FYE;',@87,@
M)&-H86YN96P@/3X@)'!A8VMA9V5S*2![#0H@("`@("`@("`@("!F;W)E86-H
M("@D<&%C:V%G97,@87,@)'!A8VMA9V4I('L-"B`@("`@("`@("`@("`@("`D
M=F5R<VEO;B`]("1T:&ES+3Y?<&%C:V%G94EN9F\H)'!A8VMA9V4L("=V97)S
M:6]N)RP@)&-H86YN96PI.PT*("`@("`@("`@("`@("`@("1F:6QE;&ES="`]
M("1T:&ES+3Y?<&%C:V%G94EN9F\H)'!A8VMA9V4L("=F:6QE;&ES="<L("1C
M:&%N;F5L*3L-"B`@("`@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1F:6QE
M;&ES="DI('L-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1F:6QE
M;&ES="!A<R`D;F%M92`]/B`D871T<G,I('L-"B`@("`@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1A='1R<ULG871T<FEB<R==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)&%T=')S(#T@)&%T=')S6R=A='1R:6)S)UT[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@+R\@
M:70@:7,@<&]S<VEB;&4@9F]R(&-O;F9L:6-T:6YG('!A8VMA9V5S(&EN(&1I
M9F9E<F5N="!C:&%N;F5L<R!T;PT*("`@("`@("`@("`@("`@("`@("`O+R!C
M;VYF;&EC="!W:71H(&1A=&$@9FEL97,O9&]C(&9I;&5S#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@D;F%M92`]/2`G9&ER=')E92<I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D871T<G-;)W)O
M;&4G72D@)B8@(6EN7V%R<F%Y*"1A='1R<ULG<F]L92==+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("!014%27TEN<W1A;&QE<E]2;VQE.CIG971);G-T
M86QL86)L95)O;&5S*"DI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!T:&5S92!A<F4@;F]T(&EN<W1A;&QE9`T*("`@("`@("`@("`@("`@("`@
M("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A='1R<ULG<F]L92==*2`F)B`A
M:6Y?87)R87DH)&%T=')S6R=R;VQE)UTL#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@(%!%05)?26YS=&%L;&5R7U)O;&4Z.F=E=$)A<V5I;G-T86QL4F]L
M97,H*2DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1A='1R<ULG8F%S
M96EN<W1A;&QD:7(G72`]("1P86-K86=E.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D871T<G-;)V)A
M<V5I;G-T86QL9&ER)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M9FEL92`]("1A='1R<ULG8F%S96EN<W1A;&QD:7(G72Y$25)%0U1/4EE?4T50
M05)!5$]2+B1N86UE.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)&9I;&4@/2`D;F%M93L-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D9FEL92`]
M('!R96=?<F5P;&%C92@G+%XO*RPG+"`G)RP@)&9I;&4I.PT*("`@("`@("`@
M("`@("`@("`@("!I9B`H)&-H86YN96P@(3T@)W!E87(N<&AP+FYE="<I('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1F:6QE<ULD871T<G-;)W)O;&4G
M75U;)&9I;&5=(#T@87)R87DH<W1R=&]L;W=E<B@D8VAA;FYE;"DL#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@<W1R=&]L;W=E<B@D<&%C:V%G92DI
M.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)&9I;&5S6R1A='1R<ULG<F]L92==75LD9FEL95T@/2!S
M=')T;VQO=V5R*"1P86-K86=E*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("`D=&AI<RT^7V%S<V5R=%-T871E1&ER*"D[#0H@("`@("`@(&EF
M("@A)'1H:7,M/FAA<U=R:71E06-C97-S*"DI('L-"B`@("`@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D9G`@/2!`9F]P96XH
M)'1H:7,M/F9I;&5M87`L("=W8B<I.PT*("`@("`@("!I9B`H(21F<"D@>PT*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@
M("1T:&ES+3YF:6QE;6%P7V-A8VAE(#T@)&9I;&5S.PT*("`@("`@("!F=W)I
M=&4H)&9P+"!S97)I86QI>F4H)&9I;&5S*2D[#0H@("`@("`@(&9C;&]S92@D
M9G`I.PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O+R!]
M?7T-"B`@("`O+R![>WL@7W)E861&:6QE36%P*"D-"@T*("`@(&9U;F-T:6]N
M(%]R96%D1FEL94UA<"@I#0H@("`@>PT*("`@("`@("`D9G`@/2!`9F]P96XH
M)'1H:7,M/F9I;&5M87`L("=R)RD[#0H@("`@("`@(&EF("@A)&9P*2![#0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)U!%05)?4F5G
M:7-T<GDZ(&-O=6QD(&YO="!O<&5N(&9I;&5M87`@(B<@+B`D=&AI<RT^9FEL
M96UA<"`N("<B)RP@4$5!4E]214=)4U1265]%4E)/4E]&24Q%+"!N=6QL+"!N
M=6QL+"`D<&AP7V5R<F]R;7-G*3L-"B`@("`@("`@?0T*("`@("`@("!C;&5A
M<G-T871C86-H92@I.PT*("`@("`@("`D<G0@/2!G971?;6%G:6-?<75O=&5S
M7W)U;G1I;64H*3L-"B`@("`@("`@<V5T7VUA9VEC7W%U;W1E<U]R=6YT:6UE
M*#`I.PT*("`@("`@("`D9G-I>F4@/2!F:6QE<VEZ92@D=&AI<RT^9FEL96UA
M<"D[#0H@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V9I;&5?9V5T7V-O
M;G1E;G1S)RDI('L-"B`@("`@("`@("`@(&9C;&]S92@D9G`I.PT*("`@("`@
M("`@("`@)&1A=&$@/2!F:6QE7V=E=%]C;VYT96YT<R@D=&AI<RT^9FEL96UA
M<"D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D9&%T82`](&9R
M96%D*"1F<"P@)&9S:7IE*3L-"B`@("`@("`@("`@(&9C;&]S92@D9G`I.PT*
M("`@("`@("!]#0H@("`@("`@('-E=%]M86=I8U]Q=6]T97-?<G5N=&EM92@D
M<G0I.PT*("`@("`@("`D=&UP(#T@=6YS97)I86QI>F4H)&1A=&$I.PT*("`@
M("`@("!I9B`H(21T;7`@)B8@)&9S:7IE(#X@-RD@>PT*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=014%27U)E9VES=')Y.B!I;G9A
M;&ED(&9I;&5M87`@9&%T82<L(%!%05)?4D5'25-44EE?15)23U)?1D]234%4
M+"!N=6QL+"!N=6QL+"`D9&%T82D[#0H@("`@("`@('T-"B`@("`@("`@)'1H
M:7,M/F9I;&5M87!?8V%C:&4@/2`D=&UP.PT*("`@("`@("!R971U<FX@=')U
M93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@7VQO8VLH*0T*
M#0H@("`@+RHJ#0H@("`@("H@3&]C:R!T:&4@<F5G:7-T<GDN#0H@("`@("H-
M"B`@("`@*B!`<&%R86T@:6YT96=E<B!L;V-K(&UO9&4L(&]N92!O9B!,3T-+
M7T58+"!,3T-+7U-((&]R($Q/0TM?54XN#0H@("`@("H@("`@("`@("`@("`@
M("`@4V5E(&9L;V-K(&UA;G5A;"!F;W(@;6]R92!I;F9O<FUA=&EO;BX-"B`@
M("`@*@T*("`@("`J($!R971U<FX@8F]O;"!44E5%(&]N('-U8V-E<W,L($9!
M3%-%(&EF(&QO8VMI;F<@9F%I;&5D+"!O<B!A#0H@("`@("H@("`@("`@("`@
M("`@(%!%05(@97)R;W(@:68@<V]M92!O=&AE<B!E<G)O<B!O8V-U<G,@*'-U
M8V@@87,@=&AE#0H@("`@("H@("`@("`@("`@("`@(&QO8VL@9FEL92!N;W0@
M8F5I;F<@=W)I=&%B;&4I+@T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P<FEV
M871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7VQO8VLH)&UO9&4@/2!,3T-+
M7T58*0T*("`@('L-"B`@("`@("`@:68@*"%E<F5G:2@G5VEN9&]W<R`Y)RP@
M<&AP7W5N86UE*"DI*2![#0H@("`@("`@("`@("!I9B`H)&UO9&4@(3T@3$]#
M2U]53B`F)B!I<U]R97-O=7)C92@D=&AI<RT^;&]C:U]F<"DI('L-"B`@("`@
M("`@("`@("`@("`O+R!86%@@9&]E<R!N;W0@8VAE8VL@='EP92!O9B!L;V-K
M("A,3T-+7U-(+TQ/0TM?15@I#0H@("`@("`@("`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(21T:&ES+3Y?
M87-S97)T4W1A=&5$:7(H*2D@>PT*("`@("`@("`@("`@("`@(&EF("@D;6]D
M92`]/2!,3T-+7T58*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@G4F5G:7-T<GD@9&ER96-T;W)Y(&ES(&YO="!W
M<FET96%B;&4@8GD@=&AE(&-U<G)E;G0@=7-E<B<I.PT*("`@("`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("1O<&5N7VUO9&4@/2`G=R<[#0H@("`@("`@("`@("`O+R!86%@@4&5O
M<&QE(')E<&]R=&5D('!R;V)L96US('=I=&@@3$]#2U]32"!A;F0@)W<G#0H@
M("`@("`@("`@("!I9B`H)&UO9&4@/3T]($Q/0TM?4T@@?'P@)&UO9&4@/3T]
M($Q/0TM?54XI('L-"B`@("`@("`@("`@("`@("!I9B`H0"%I<U]F:6QE*"1T
M:&ES+3YL;V-K9FEL92DI('L-"B`@("`@("`@("`@("`@("`@("`@=&]U8V@H
M)'1H:7,M/FQO8VMF:6QE*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@)&]P96Y?;6]D92`]("=R)SL-"B`@("`@("`@("`@('T-"@T*
M("`@("`@("`@("`@:68@*"%I<U]R97-O=7)C92@D=&AI<RT^;&]C:U]F<"DI
M('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^;&]C:U]F<"`]($!F;W!E;B@D
M=&AI<RT^;&]C:V9I;&4L("1O<&5N7VUO9&4I.PT*("`@("`@("`@("`@?0T*
M#0H@("`@("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1T:&ES+3YL;V-K7V9P
M*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@B8V]U;&0@;F]T(&-R96%T92!L;V-K(&9I;&4B("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*&ES<V5T*"1P:'!?97)R
M;W)M<V<I(#\@(CH@(B`N("1P:'!?97)R;W)M<V<@.B`B(BDI.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@:68@*"$H:6YT*69L;V-K*"1T:&ES+3YL
M;V-K7V9P+"`D;6]D92DI('L-"B`@("`@("`@("`@("`@("!S=VET8V@@*"1M
M;V1E*2![#0H@("`@("`@("`@("`@("`@("`@(&-A<V4@3$]#2U]32#H@)'-T
M<B`]("=S:&%R960G.R`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@
M8V%S92!,3T-+7T58.B`D<W1R(#T@)V5X8VQU<VEV92<[(&)R96%K.PT*("`@
M("`@("`@("`@("`@("`@("!C87-E($Q/0TM?54XZ("1S='(@/2`G=6YL;V-K
M)SL@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@(&1E9F%U;'0Z("`@
M("`@)'-T<B`]("=U;FMN;W=N)SL@("!B<F5A:SL-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*")C;W5L9"!N;W0@86-Q=6ER92`D<W1R(&QO8VL@*"1T:&ES+3YL;V-K9FEL
M92DB+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!014%27U)%1TE35%)97T524D]27TQ/0TLI.PT*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@
M("\O('U]?0T*("`@("\O('M[>R!?=6YL;V-K*"D-"@T*("`@(&9U;F-T:6]N
M(%]U;FQO8VLH*0T*("`@('L-"B`@("`@("`@)')E="`]("1T:&ES+3Y?;&]C
M:RA,3T-+7U5.*3L-"B`@("`@("`@:68@*&ES7W)E<V]U<F-E*"1T:&ES+3YL
M;V-K7V9P*2D@>PT*("`@("`@("`@("`@9F-L;W-E*"1T:&ES+3YL;V-K7V9P
M*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^;&]C:U]F<"`](&YU;&P[
M#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*("`@("\O('U]?0T*
M("`@("\O('M[>R!?<&%C:V%G945X:7-T<R@I#0H-"B`@("!F=6YC=&EO;B!?
M<&%C:V%G945X:7-T<R@D<&%C:V%G92P@)&-H86YN96P@/2!F86QS92D-"B`@
M("![#0H@("`@("`@(')E='5R;B!F:6QE7V5X:7-T<R@D=&AI<RT^7W!A8VMA
M9V5&:6QE3F%M92@D<&%C:V%G92P@)&-H86YN96PI*3L-"B`@("!]#0H-"B`@
M("`O+R!]?7T-"B`@("`O+R![>WL@7V-H86YN96Q%>&ES=',H*0T*#0H@("`@
M+RHJ#0H@("`@("H@1&5T97)M:6YE('=H971H97(@82!C:&%N;F5L(&5X:7-T
M<R!I;B!T:&4@<F5G:7-T<GD-"B`@("`@*B!`<&%R86T@<W1R:6YG($-H86YN
M96P@;F%M90T*("`@("`J($!P87)A;2!B;V]L(&EF('1R=64L('1H96X@86QI
M87-E<R!W:6QL(&)E(&EG;F]R960-"B`@("`@*B!`<F5T=7)N(&)O;VQE86X-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?8VAA;FYE;$5X:7-T<R@D8VAA;FYE
M;"P@)&YO86QI87-E<R`](&9A;'-E*0T*("`@('L-"B`@("`@("`@)&$@/2!F
M:6QE7V5X:7-T<R@D=&AI<RT^7V-H86YN96Q&:6QE3F%M92@D8VAA;FYE;"P@
M)&YO86QI87-E<RDI.PT*("`@("`@("!I9B`H(21A("8F("1C:&%N;F5L(#T]
M("=P96%R+G!H<"YN970G*2![#0H@("`@("`@("`@("!R971U<FX@=')U93L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H(21A("8F("1C:&%N;F5L(#T]("=P
M96-L+G!H<"YN970G*2![#0H@("`@("`@("`@("!R971U<FX@=')U93L-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@)&$[#0H@("`@?0T*#0H@("`@+R\@
M?7U]#0H@("`@+R\@>WM[(%]A9&1#:&%N;F5L*"D-"@T*("`@("\J*@T*("`@
M("`J($!P87)A;2!014%27T-H86YN96Q&:6QE($-H86YN96P@;V)J96-T#0H@
M("`@("H@0'!A<F%M(&1O;F]T=7-E#0H@("`@("H@0'!A<F%M('-T<FEN9R!,
M87-T+4UO9&EF:65D($A45%`@=&%G(&9R;VT@<F5M;W1E(')E<75E<W0-"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86Y\4$5!4E]%<G)O<B!4<G5E(&]N(&-R96%T
M:6]N+"!F86QS92!I9B!I="!A;')E861Y(&5X:7-T<PT*("`@("`J+PT*("`@
M(&9U;F-T:6]N(%]A9&1#:&%N;F5L*"1C:&%N;F5L+"`D=7!D871E(#T@9F%L
M<V4L("1L87-T;6]D:69I960@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF
M("@A:7-?82@D8VAA;FYE;"P@)U!%05)?0VAA;FYE;$9I;&4G*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF
M("@A)&-H86YN96PM/G9A;&ED871E*"DI('L-"B`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H9FEL95]E>&ES=',H
M)'1H:7,M/E]C:&%N;F5L1FEL94YA;64H)&-H86YN96PM/F=E=$YA;64H*2DI
M*2![#0H@("`@("`@("`@("!I9B`H(21U<&1A=&4I('L-"B`@("`@("`@("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`D8VAE8VME<B`]("1T:&ES+3Y?9V5T0VAA;FYE;"@D8VAA;FYE;"T^9V5T
M3F%M92@I*3L-"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1C:&5C
M:V5R*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D8VAE8VME<CL-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D8VAA;FYE;"T^9V5T06QI
M87,H*2`A/2`D8VAE8VME<BT^9V5T06QI87,H*2D@>PT*("`@("`@("`@("`@
M("`@($!U;FQI;FLH)'1H:7,M/E]G971#:&%N;F5L06QI87-&:6QE3F%M92@D
M8VAE8VME<BT^9V5T06QI87,H*2DI.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@:68@*"1U<&1A=&4@)B8@(6EN7V%R
M<F%Y*"1C:&%N;F5L+3YG971.86UE*"DL(&%R<F%Y*"=P96%R+G!H<"YN970G
M+"`G<&5C;"YP:'`N;F5T)RDI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1R
M970@/2`D=&AI<RT^7V%S<V5R=$-H86YN96Q$:7(H*3L-"B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)')E="DI('L-"B`@("`@("`@("`@(')E='5R;B`D
M<F5T.PT*("`@("`@("!]#0H@("`@("`@("1R970@/2`D=&AI<RT^7V%S<V5R
M=$-H86YN96Q3=&%T941I<B@D8VAA;FYE;"T^9V5T3F%M92@I*3L-"B`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)')E="DI('L-"B`@("`@("`@("`@(')E
M='5R;B`D<F5T.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D8VAA;FYE;"T^
M9V5T06QI87,H*2`A/2`D8VAA;FYE;"T^9V5T3F%M92@I*2![#0H@("`@("`@
M("`@("!I9B`H9FEL95]E>&ES=',H)'1H:7,M/E]G971#:&%N;F5L06QI87-&
M:6QE3F%M92@D8VAA;FYE;"T^9V5T06QI87,H*2DI("8F#0H@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7V=E=$-H86YN96Q&<F]M06QI87,H)&-H86YN96PM
M/F=E=$%L:6%S*"DI("$]("1C:&%N;F5L+3YG971.86UE*"DI('L-"B`@("`@
M("`@("`@("`@("`D8VAA;FYE;"T^<V5T06QI87,H)&-H86YN96PM/F=E=$YA
M;64H*2D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(21T:&ES
M+3YH87-7<FET94%C8V5S<R@I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&9P(#T@0&9O
M<&5N*"1T:&ES+3Y?9V5T0VAA;FYE;$%L:6%S1FEL94YA;64H)&-H86YN96PM
M/F=E=$%L:6%S*"DI+"`G=R<I.PT*("`@("`@("`@("`@:68@*"$D9G`I('L-
M"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!F=W)I=&4H)&9P+"`D8VAA;FYE;"T^9V5T3F%M92@I
M*3L-"B`@("`@("`@("`@(&9C;&]S92@D9G`I.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("@A)'1H:7,M/FAA<U=R:71E06-C97-S*"DI('L-"B`@("`@("`@
M("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D9G`@/2!`
M9F]P96XH)'1H:7,M/E]C:&%N;F5L1FEL94YA;64H)&-H86YN96PM/F=E=$YA
M;64H*2DL("=W8B<I.PT*("`@("`@("!I9B`H(21F<"D@>PT*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1I;F9O(#T@
M)&-H86YN96PM/G1O07)R87DH*3L-"B`@("`@("`@:68@*"1L87-T;6]D:69I
M960I('L-"B`@("`@("`@("`@("1I;F9O6R=?;&%S=&UO9&EF:65D)UT@/2`D
M;&%S=&UO9&EF:65D.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M)&EN9F];)U]L87-T;6]D:69I960G72`](&1A=&4H)W(G*3L-"B`@("`@("`@
M?0T*("`@("`@("!F=W)I=&4H)&9P+"!S97)I86QI>F4H)&EN9F\I*3L-"B`@
M("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@
M('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!?9&5L971E0VAA;FYE;"@I
M#0H-"B`@("`O*BH-"B`@("`@*B!$96QE=&EO;B!F86EL<R!I9B!T:&5R92!A
M<F4@86YY('!A8VMA9V5S(&EN<W1A;&QE9"!F<F]M('1H92!C:&%N;F5L#0H@
M("`@("H@0'!A<F%M('-T<FEN9WQ014%27T-H86YN96Q&:6QE(&-H86YN96P@
M;F%M90T*("`@("`J($!R971U<FX@8F]O;&5A;GQ014%27T5R<F]R(%1R=64@
M;VX@9&5L971I;VXL(&9A;'-E(&EF(&ET(&1O97-N)W0@97AI<W0-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!?9&5L971E0VAA;FYE;"@D8VAA;FYE;"D-"B`@
M("![#0H@("`@("`@(&EF("@A:7-?<W1R:6YG*"1C:&%N;F5L*2D@>PT*("`@
M("`@("`@("`@:68@*&ES7V$H)&-H86YN96PL("=014%27T-H86YN96Q&:6QE
M)RDI('L-"B`@("`@("`@("`@("`@("!I9B`H(21C:&%N;F5L+3YV86QI9&%T
M92@I*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&-H86YN96P@/2`D
M8VAA;FYE;"T^9V5T3F%M92@I.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"1T:&ES+3Y?9V5T0VAA;FYE;$9R;VU!
M;&EA<R@D8VAA;FYE;"D@/3T@)U]?=7)I)RD@>PT*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D=&AI<RT^7V=E
M=$-H86YN96Q&<F]M06QI87,H)&-H86YN96PI(#T]("=P96-L+G!H<"YN970G
M*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"$D=&AI<RT^7V-H86YN96Q%>&ES=',H)&-H86YN96PI*2![
M#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*"$D8VAA;FYE;"!\?"`D=&AI<RT^7V=E=$-H86YN96Q&<F]M06QI
M87,H)&-H86YN96PI(#T]("=P96%R+G!H<"YN970G*2![#0H@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)&-H86YN96P@
M/2`D=&AI<RT^7V=E=$-H86YN96Q&<F]M06QI87,H)&-H86YN96PI.PT*("`@
M("`@("!I9B`H)&-H86YN96P@/3T@)W!E87(N<&AP+FYE="<I('L-"B`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D=&5S
M="`]("1T:&ES+3Y?;&ES=$-H86YN96Q086-K86=E<R@D8VAA;FYE;"D[#0H@
M("`@("`@(&EF("AC;W5N="@D=&5S="DI('L-"B`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D=&5S="`]($!R;61I<B@D
M=&AI<RT^7V-H86YN96Q$:7)E8W1O<GE.86UE*"1C:&%N;F5L*2D[#0H@("`@
M("`@(&EF("@A)'1E<W0I('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("`@("`@?0T*("`@("`@("`D9FEL92`]("1T:&ES+3Y?9V5T0VAA;FYE
M;$%L:6%S1FEL94YA;64H)'1H:7,M/E]G971!;&EA<R@D8VAA;FYE;"DI.PT*
M("`@("`@("!I9B`H0&9I;&5?97AI<W1S*"1F:6QE*2D@>PT*("`@("`@("`@
M("`@)'1E<W0@/2!`=6YL:6YK*"1F:6QE*3L-"B`@("`@("`@("`@(&EF("@A
M)'1E<W0I('L-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)&9I;&4@/2`D=&AI<RT^
M7V-H86YN96Q&:6QE3F%M92@D8VAA;FYE;"D[#0H@("`@("`@("1R970@/2!`
M=6YL:6YK*"1F:6QE*3L-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*
M#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(%]I<T-H86YN96Q!;&EA<R@I#0H-
M"B`@("`O*BH-"B`@("`@*B!$971E<FUI;F4@=VAE=&AE<B!A(&-H86YN96P@
M97AI<W1S(&EN('1H92!R96=I<W1R>0T*("`@("`J($!P87)A;2!S=')I;F<@
M0VAA;FYE;"!!;&EA<PT*("`@("`J($!R971U<FX@8F]O;&5A;@T*("`@("`J
M+PT*("`@(&9U;F-T:6]N(%]I<T-H86YN96Q!;&EA<R@D86QI87,I#0H@("`@
M>PT*("`@("`@("!R971U<FX@9FEL95]E>&ES=',H)'1H:7,M/E]G971#:&%N
M;F5L06QI87-&:6QE3F%M92@D86QI87,I*3L-"B`@("!]#0H-"B`@("`O+R!]
M?7T-"B`@("`O+R![>WL@7W!A8VMA9V5);F9O*"D-"@T*("`@("\J*@T*("`@
M("`J($!P87)A;2!S=')I;F=\;G5L;`T*("`@("`J($!P87)A;2!S=')I;F=\
M;G5L;`T*("`@("`J($!P87)A;2!S=')I;F=\;G5L;`T*("`@("`J($!R971U
M<FX@87)R87E\;G5L;`T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J
M+PT*("`@(&9U;F-T:6]N(%]P86-K86=E26YF;R@D<&%C:V%G92`](&YU;&PL
M("1K97D@/2!N=6QL+"`D8VAA;FYE;"`]("=P96%R+G!H<"YN970G*0T*("`@
M('L-"B`@("`@("`@:68@*"1P86-K86=E(#T]/2!N=6QL*2![#0H@("`@("`@
M("`@("!I9B`H)&-H86YN96P@/3T](&YU;&PI('L-"B`@("`@("`@("`@("`@
M("`D8VAA;FYE;',@/2`D=&AI<RT^7VQI<W1#:&%N;F5L<R@I.PT*("`@("`@
M("`@("`@("`@("1R970@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*"1C:&%N;F5L<R!A<R`D8VAA;FYE;"D@>PT*("`@("`@("`@("`@
M("`@("`@("`D8VAA;FYE;"`]('-T<G1O;&]W97(H)&-H86YN96PI.PT*("`@
M("`@("`@("`@("`@("`@("`D<F5T6R1C:&%N;F5L72`](&%R<F%Y*"D[#0H@
M("`@("`@("`@("`@("`@("`@("1P86-K86=E<R`]("1T:&ES+3Y?;&ES=%!A
M8VMA9V5S*"1C:&%N;F5L*3L-"B`@("`@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)'!A8VMA9V5S(&%S("1P86-K86=E*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D<F5T6R1C:&%N;F5L75M=(#T@)'1H:7,M/E]P86-K86=E26YF
M;R@D<&%C:V%G92P@;G5L;"P@)&-H86YN96PI.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(')E
M='5R;B`D<F5T.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'!S(#T@
M)'1H:7,M/E]L:7-T4&%C:V%G97,H)&-H86YN96PI.PT*("`@("`@("`@("`@
M:68@*"%C;W5N="@D<',I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N(&%R
M<F%Y*"D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@87)R
M87E?;6%P*&%R<F%Y*"8D=&AI<RP@)U]P86-K86=E26YF;R<I+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<',L(&%R<F%Y7V9I;&PH,"P@8V]U
M;G0H)'!S*2P@;G5L;"DL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y7V9I;&PH,"P@8V]U;G0H)'!S*2P@)&-H86YN96PI*3L-"B`@("`@
M("`@?0T*("`@("`@("`D9G`@/2`D=&AI<RT^7V]P96Y086-K86=E1FEL92@D
M<&%C:V%G92P@)W(G+"`D8VAA;FYE;"D[#0H@("`@("`@(&EF("@D9G`@/3T]
M(&YU;&PI('L-"B`@("`@("`@("`@(')E='5R;B!N=6QL.PT*("`@("`@("!]
M#0H@("`@("`@("1R="`](&=E=%]M86=I8U]Q=6]T97-?<G5N=&EM92@I.PT*
M("`@("`@("!S971?;6%G:6-?<75O=&5S7W)U;G1I;64H,"D[#0H@("`@("`@
M(&-L96%R<W1A=&-A8VAE*"D[#0H@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES
M=',H)V9I;&5?9V5T7V-O;G1E;G1S)RDI('L-"B`@("`@("`@("`@("1T:&ES
M+3Y?8VQO<V5086-K86=E1FEL92@D9G`I.PT*("`@("`@("`@("`@)&1A=&$@
M/2!F:6QE7V=E=%]C;VYT96YT<R@D=&AI<RT^7W!A8VMA9V5&:6QE3F%M92@D
M<&%C:V%G92P@)&-H86YN96PI*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("1D871A(#T@9G)E860H)&9P+"!F:6QE<VEZ92@D=&AI<RT^7W!A
M8VMA9V5&:6QE3F%M92@D<&%C:V%G92P@)&-H86YN96PI*2D[#0H@("`@("`@
M("`@("`D=&AI<RT^7V-L;W-E4&%C:V%G949I;&4H)&9P*3L-"B`@("`@("`@
M?0T*("`@("`@("!S971?;6%G:6-?<75O=&5S7W)U;G1I;64H)')T*3L-"B`@
M("`@("`@)&1A=&$@/2!U;G-E<FEA;&EZ92@D9&%T82D[#0H@("`@("`@(&EF
M("@D:V5Y(#T]/2!N=6QL*2![#0H@("`@("`@("`@("!R971U<FX@)&1A=&$[
M#0H@("`@("`@('T-"B`@("`@("`@+R\@8V]M<&%T:6)I;&ET>2!F;W(@<&%C
M:V%G92YX;6P@=F5R<VEO;B`R+C`-"B`@("`@("`@:68@*&ES<V5T*"1D871A
M6R=O;&0G75LD:V5Y72DI('L-"B`@("`@("`@("`@(')E='5R;B`D9&%T85LG
M;VQD)UU;)&ME>5T[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D
M871A6R1K97E=*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1D871A6R1K97E=
M.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!N=6QL.PT*("`@('T-"@T*
M("`@("\O('U]?0T*("`@("\O('M[>R!?8VAA;FYE;$EN9F\H*0T*#0H@("`@
M+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9R!#:&%N;F5L(&YA;64-"B`@("`@
M*B!`<&%R86T@8F]O;"!W:&5T:&5R('1O('-T<FEC=&QY(')E=')I979E(&EN
M9F\@;V8@8VAA;FYE;',L(&YO="!J=7-T(&%L:6%S97,-"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y?&YU;&P-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?8VAA;FYE
M;$EN9F\H)&-H86YN96PL("1N;V%L:6%S97,@/2!F86QS92D-"B`@("![#0H@
M("`@("`@(&EF("@A)'1H:7,M/E]C:&%N;F5L17AI<W1S*"1C:&%N;F5L+"`D
M;F]A;&EA<V5S*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&YU;&P[#0H@("`@
M("`@('T-"B`@("`@("`@)&9P(#T@)'1H:7,M/E]O<&5N0VAA;FYE;$9I;&4H
M)&-H86YN96PL("=R)RD[#0H@("`@("`@(&EF("@D9G`@/3T](&YU;&PI('L-
M"B`@("`@("`@("`@(')E='5R;B!N=6QL.PT*("`@("`@("!]#0H@("`@("`@
M("1R="`](&=E=%]M86=I8U]Q=6]T97-?<G5N=&EM92@I.PT*("`@("`@("!S
M971?;6%G:6-?<75O=&5S7W)U;G1I;64H,"D[#0H@("`@("`@(&-L96%R<W1A
M=&-A8VAE*"D[#0H@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V9I;&5?
M9V5T7V-O;G1E;G1S)RDI('L-"B`@("`@("`@("`@("1T:&ES+3Y?8VQO<V5#
M:&%N;F5L1FEL92@D9G`I.PT*("`@("`@("`@("`@)&1A=&$@/2!F:6QE7V=E
M=%]C;VYT96YT<R@D=&AI<RT^7V-H86YN96Q&:6QE3F%M92@D8VAA;FYE;"DI
M.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&1A=&$@/2!F<F5A
M9"@D9G`L(&9I;&5S:7IE*"1T:&ES+3Y?8VAA;FYE;$9I;&5.86UE*"1C:&%N
M;F5L*2DI.PT*("`@("`@("`@("`@)'1H:7,M/E]C;&]S94-H86YN96Q&:6QE
M*"1F<"D[#0H@("`@("`@('T-"B`@("`@("`@<V5T7VUA9VEC7W%U;W1E<U]R
M=6YT:6UE*"1R="D[#0H@("`@("`@("1D871A(#T@=6YS97)I86QI>F4H)&1A
M=&$I.PT*("`@("`@("!R971U<FX@)&1A=&$[#0H@("`@?0T*#0H@("`@+R\@
M?7U]#0H@("`@+R\@>WM[(%]L:7-T0VAA;FYE;',H*0T*#0H@("`@9G5N8W1I
M;VX@7VQI<W1#:&%N;F5L<R@I#0H@("`@>PT*("`@("`@("`D8VAA;FYE;&QI
M<W0@/2!A<G)A>2@I.PT*("`@("`@("`D9'`@/2!`;W!E;F1I<B@D=&AI<RT^
M8VAA;FYE;'-D:7(I.PT*("`@("`@("!I9B`H(21D<"`@?'P@(4!I<U]D:7(H
M)'1H:7,M/F-H86YN96QS9&ER*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&%R
M<F%Y*"=P96%R+G!H<"YN970G+"`G<&5C;"YP:'`N;F5T)RP@)U]?=7)I)RD[
M#0H@("`@("`@('T-"B`@("`@("`@=VAI;&4@*"1E;G0@/2!R96%D9&ER*"1D
M<"DI('L-"B`@("`@("`@("`@(&EF("@D96YT>S!](#T]("<N)R!\?"!S=6)S
M='(H)&5N="P@+30I("$]("<N<F5G)RD@>PT*("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1E;G0@
M/3T@)U]?=7)I+G)E9R<I('L-"B`@("`@("`@("`@("`@("`D8VAA;FYE;&QI
M<W1;72`]("=?7W5R:2<[#0H@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`D8VAA;FYE;&QI<W1;72`]('-T
M<E]R97!L86-E*"=?)RP@)R\G+"!S=6)S='(H)&5N="P@,"P@+30I*3L-"B`@
M("`@("`@?0T*("`@("`@("!C;&]S961I<B@D9'`I.PT*("`@("`@("!I9B`H
M(6EN7V%R<F%Y*"=P96%R+G!H<"YN970G+"`D8VAA;FYE;&QI<W0I*2![#0H@
M("`@("`@("`@("`D8VAA;FYE;&QI<W1;72`]("=P96%R+G!H<"YN970G.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("@A:6Y?87)R87DH)W!E8VPN<&AP+FYE
M="<L("1C:&%N;F5L;&ES="DI('L-"B`@("`@("`@("`@("1C:&%N;F5L;&ES
M=%M=(#T@)W!E8VPN<&AP+FYE="<[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*"%I;E]A<G)A>2@G7U]U<FDG+"`D8VAA;FYE;&QI<W0I*2![#0H@("`@("`@
M("`@("`D8VAA;FYE;&QI<W1;72`]("=?7W5R:2<[#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N("1C:&%N;F5L;&ES=#L-"B`@("!]#0H-"B`@("`O+R!]
M?7T-"B`@("`O+R![>WL@7VQI<W1086-K86=E<R@I#0H-"B`@("!F=6YC=&EO
M;B!?;&ES=%!A8VMA9V5S*"1C:&%N;F5L(#T@9F%L<V4I#0H@("`@>PT*("`@
M("`@("!I9B`H)&-H86YN96P@)B8@)'1H:7,M/E]G971#:&%N;F5L1G)O;4%L
M:6%S*"1C:&%N;F5L*2`A/2`G<&5A<BYP:'`N;F5T)RD@>PT*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?;&ES=$-H86YN96Q086-K86=E<R@D8VAA;FYE
M;"D[#0H@("`@("`@('T-"B`@("`@("`@)'!K9VQI<W0@/2!A<G)A>2@I.PT*
M("`@("`@("`D9'`@/2!`;W!E;F1I<B@D=&AI<RT^<W1A=&5D:7(I.PT*("`@
M("`@("!I9B`H(21D<"D@>PT*("`@("`@("`@("`@<F5T=7)N("1P:V=L:7-T
M.PT*("`@("`@("!]#0H@("`@("`@('=H:6QE("@D96YT(#T@<F5A9&1I<B@D
M9'`I*2![#0H@("`@("`@("`@("!I9B`H)&5N='LP?2`]/2`G+B<@?'P@<W5B
M<W1R*"1E;G0L("TT*2`A/2`G+G)E9R<I('L-"B`@("`@("`@("`@("`@("!C
M;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1P:V=L:7-T
M6UT@/2!S=6)S='(H)&5N="P@,"P@+30I.PT*("`@("`@("!]#0H@("`@("`@
M(&-L;W-E9&ER*"1D<"D[#0H@("`@("`@(')E='5R;B`D<&MG;&ES=#L-"B`@
M("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@7VQI<W1#:&%N;F5L4&%C
M:V%G97,H*0T*#0H@("`@9G5N8W1I;VX@7VQI<W1#:&%N;F5L4&%C:V%G97,H
M)&-H86YN96PI#0H@("`@>PT*("`@("`@("`D<&MG;&ES="`](&%R<F%Y*"D[
M#0H@("`@("`@("1D<"`]($!O<&5N9&ER*"1T:&ES+3Y?8VAA;FYE;$1I<F5C
M=&]R>4YA;64H)&-H86YN96PI*3L-"B`@("`@("`@:68@*"$D9'`I('L-"B`@
M("`@("`@("`@(')E='5R;B`D<&MG;&ES=#L-"B`@("`@("`@?0T*("`@("`@
M("!W:&EL92`H)&5N="`](')E861D:7(H)&1P*2D@>PT*("`@("`@("`@("`@
M:68@*"1E;G1[,'T@/3T@)RXG('Q\('-U8G-T<B@D96YT+"`M-"D@(3T@)RYR
M96<G*2![#0H@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`D<&MG;&ES=%M=(#T@<W5B<W1R*"1E;G0L(#`L
M("TT*3L-"B`@("`@("`@?0T*("`@("`@("!C;&]S961I<B@D9'`I.PT*("`@
M("`@("!R971U<FX@)'!K9VQI<W0[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@#0H@("`@9G5N8W1I;VX@7VQI<W1!;&Q086-K86=E<R@I#0H@("`@>PT*
M("`@("`@("`D<F5T(#T@87)R87DH*3L-"B`@("`@("`@9F]R96%C:"`H)'1H
M:7,M/E]L:7-T0VAA;FYE;',H*2!A<R`D8VAA;FYE;"D@>PT*("`@("`@("`@
M("`@)')E=%LD8VAA;FYE;%T@/2`D=&AI<RT^7VQI<W1086-K86=E<R@D8VAA
M;FYE;"D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@061D(&%N(&EN<W1A;&QE9"!P86-K86=E
M('1O('1H92!R96=I<W1R>0T*("`@("`J($!P87)A;2!S=')I;F<@<&%C:V%G
M92!N86UE#0H@("`@("H@0'!A<F%M(&%R<F%Y('!A8VMA9V4@:6YF;R`H<&%R
M<V5D(&)Y(%!%05)?0V]M;6]N.CII;F9O1G)O;2HH*2!M971H;V1S*0T*("`@
M("`J($!R971U<FX@8F]O;"!S=6-C97-S(&]F('-A=FEN9PT*("`@("`J($!A
M8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]A9&1086-K
M86=E*"1P86-K86=E+"`D:6YF;RD-"B`@("![#0H@("`@("`@(&EF("@D=&AI
M<RT^7W!A8VMA9V5%>&ES=',H)'!A8VMA9V4I*2![#0H@("`@("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)&9P(#T@)'1H:7,M
M/E]O<&5N4&%C:V%G949I;&4H)'!A8VMA9V4L("=W8B<I.PT*("`@("`@("!I
M9B`H)&9P(#T]/2!N=6QL*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@("`@('T-"B`@("`@("`@)&EN9F];)U]L87-T;6]D:69I960G72`]
M('1I;64H*3L-"B`@("`@("`@9G=R:71E*"1F<"P@<V5R:6%L:7IE*"1I;F9O
M*2D[#0H@("`@("`@("1T:&ES+3Y?8VQO<V5086-K86=E1FEL92@D9G`I.PT*
M("`@("`@("!I9B`H:7-S970H)&EN9F];)V9I;&5L:7-T)UTI*2![#0H@("`@
M("`@("`@("`D=&AI<RT^7W)E8G5I;&1&:6QE36%P*"D[#0H@("`@("`@('T-
M"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C%\4$5!4E]086-K86=E1FEL
M95]V,@T*("`@("`J($!R971U<FX@8F]O;`T*("`@("`J($!A8V-E<W,@<')I
M=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]A9&1086-K86=E,B@D:6YF
M;RD-"B`@("![#0H@("`@("`@(&EF("@A)&EN9F\M/G9A;&ED871E*"DI('L-
M"B`@("`@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)U!%05)?0V]M;6]N)RDI
M('L-"B`@("`@("`@("`@("`@("`D=6D@/2!014%27T9R;VYT96YD.CIS:6YG
M;&5T;VXH*3L-"B`@("`@("`@("`@("`@("!I9B`H)'5I*2![#0H@("`@("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1I;F9O+3YG971686QI9&%T:6]N5V%R
M;FEN9W,H*2!A<R`D97)R*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M=6DM/FQO9R@R+"`D97)R6R=M97-S86=E)UTI.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1C
M:&%N;F5L(#T@)&EN9F\M/F=E=$-H86YN96PH*3L-"B`@("`@("`@)'!A8VMA
M9V4@/2`D:6YF;RT^9V5T4&%C:V%G92@I.PT*("`@("`@("`D<V%V92`]("1I
M;F9O.PT*("`@("`@("!I9B`H)'1H:7,M/E]P86-K86=E17AI<W1S*"1P86-K
M86=E+"`D8VAA;FYE;"DI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H(21T:&ES+3Y?8VAA;FYE;$5X:7-T
M<R@D8VAA;FYE;"P@=')U92DI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS
M93L-"B`@("`@("`@?0T*("`@("`@("`D:6YF;R`]("1I;F9O+3YT;T%R<F%Y
M*'1R=64I.PT*("`@("`@("!I9B`H(21I;F9O*2![#0H@("`@("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)&9P(#T@)'1H:7,M
M/E]O<&5N4&%C:V%G949I;&4H)'!A8VMA9V4L("=W8B<L("1C:&%N;F5L*3L-
M"B`@("`@("`@:68@*"1F<"`]/3T@;G5L;"D@>PT*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1I;F9O6R=?;&%S=&UO
M9&EF:65D)UT@/2!T:6UE*"D[#0H@("`@("`@(&9W<FET92@D9G`L('-E<FEA
M;&EZ92@D:6YF;RDI.PT*("`@("`@("`D=&AI<RT^7V-L;W-E4&%C:V%G949I
M;&4H)&9P*3L-"B`@("`@("`@)'1H:7,M/E]R96)U:6QD1FEL94UA<"@I.PT*
M("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!`<&%R86T@<W1R:6YG(%!A8VMA9V4@;F%M90T*("`@("`J($!P87)A;2!A
M<G)A>2!P87)S960@<&%C:V%G92YX;6P@,2XP#0H@("`@("H@0'!A<F%M(&)O
M;VP@=&AI<R!P87)A;65T97(@:7,@;VYL>2!H97)E(&9O<B!"0RX@($1O;B=T
M('5S92!I="X-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!?=7!D871E4&%C:V%G92@D<&%C:V%G92P@)&EN9F\L("1M
M97)G92`]('1R=64I#0H@("`@>PT*("`@("`@("`D;VQD:6YF;R`]("1T:&ES
M+3Y?<&%C:V%G94EN9F\H)'!A8VMA9V4I.PT*("`@("`@("!I9B`H96UP='DH
M)&]L9&EN9F\I*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M("`@('T-"B`@("`@("`@)&9P(#T@)'1H:7,M/E]O<&5N4&%C:V%G949I;&4H
M)'!A8VMA9V4L("=W)RD[#0H@("`@("`@(&EF("@D9G`@/3T](&YU;&PI('L-
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H:7-?;V)J96-T*"1I;F9O*2D@>PT*("`@("`@("`@("`@)&EN9F\@
M/2`D:6YF;RT^=&]!<G)A>2@I.PT*("`@("`@("!]#0H@("`@("`@("1I;F9O
M6R=?;&%S=&UO9&EF:65D)UT@/2!T:6UE*"D[#0H@("`@("`@("1N97=I;F9O
M(#T@)&EN9F\[#0H@("`@("`@(&EF("@D;65R9V4I('L-"B`@("`@("`@("`@
M("1I;F9O(#T@87)R87E?;65R9V4H)&]L9&EN9F\L("1I;F9O*3L-"B`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("1D:69F(#T@)&EN9F\[#0H@("`@
M("`@('T-"B`@("`@("`@9G=R:71E*"1F<"P@<V5R:6%L:7IE*"1I;F9O*2D[
M#0H@("`@("`@("1T:&ES+3Y?8VQO<V5086-K86=E1FEL92@D9G`I.PT*("`@
M("`@("!I9B`H:7-S970H)&YE=VEN9F];)V9I;&5L:7-T)UTI*2![#0H@("`@
M("`@("`@("`D=&AI<RT^7W)E8G5I;&1&:6QE36%P*"D[#0H@("`@("`@('T-
M"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C%\4$5!4E]086-K86=E1FEL
M95]V,@T*("`@("`J($!R971U<FX@8F]O;`T*("`@("`J($!A8V-E<W,@<')I
M=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]U<&1A=&5086-K86=E,B@D
M:6YF;RD-"B`@("![#0H@("`@("`@(&EF("@A)'1H:7,M/E]P86-K86=E17AI
M<W1S*"1I;F9O+3YG971086-K86=E*"DL("1I;F9O+3YG971#:&%N;F5L*"DI
M*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@
M("`@("`@)&9P(#T@)'1H:7,M/E]O<&5N4&%C:V%G949I;&4H)&EN9F\M/F=E
M=%!A8VMA9V4H*2P@)W<G+"`D:6YF;RT^9V5T0VAA;FYE;"@I*3L-"B`@("`@
M("`@:68@*"1F<"`]/3T@;G5L;"D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@("`@("!]#0H@("`@("`@("1S879E(#T@)&EN9F\[#0H@("`@
M("`@("1I;F9O(#T@)'-A=F4M/F=E=$%R<F%Y*'1R=64I.PT*("`@("`@("`D
M:6YF;ULG7VQA<W1M;V1I9FEE9"==(#T@=&EM92@I.PT*("`@("`@("!F=W)I
M=&4H)&9P+"!S97)I86QI>F4H)&EN9F\I*3L-"B`@("`@("`@)'1H:7,M/E]C
M;&]S95!A8VMA9V5&:6QE*"1F<"D[#0H@("`@("`@("1T:&ES+3Y?<F5B=6EL
M9$9I;&5-87`H*3L-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9R!086-K86=E(&YA;64-"B`@
M("`@*B!`<&%R86T@<W1R:6YG($-H86YN96P@;F%M90T*("`@("`J($!R971U
M<FX@4$5!4E]086-K86=E1FEL95]V,7Q014%27U!A8VMA9V5&:6QE7W8R?&YU
M;&P-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B`F7V=E=%!A8VMA9V4H)'!A8VMA9V4L("1C:&%N;F5L(#T@)W!E87(N
M<&AP+FYE="<I#0H@("`@>PT*("`@("`@("`D:6YF;R`]("1T:&ES+3Y?<&%C
M:V%G94EN9F\H)'!A8VMA9V4L(&YU;&PL("1C:&%N;F5L*3L-"B`@("`@("`@
M:68@*"1I;F9O(#T]/2!N=6QL*2![#0H@("`@("`@("`@("!R971U<FX@)&EN
M9F\[#0H@("`@("`@('T-"B`@("`@("`@)&$@/2`D=&AI<RT^7V-O;F9I9SL-
M"B`@("`@("`@:68@*"$D82D@>PT*("`@("`@("`@("`@)'1H:7,M/E]C;VYF
M:6<@/2`F;F5W(%!%05)?0V]N9FEG.PT*("`@("`@("`@("`@)'1H:7,M/E]C
M;VYF:6<M/G-E="@G<&AP7V1I<B<L("1T:&ES+3YS=&%T961I<BD[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?4&%C:V%G
M949I;&4G*2D@>PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+U!A
M8VMA9V5&:6QE+G!H<"<[#0H@("`@("`@('T-"B`@("`@("`@)'!K9R`]("9N
M97<@4$5!4E]086-K86=E1FEL92@D=&AI<RT^7V-O;F9I9RD[#0H@("`@("`@
M("1P9B`]("8D<&MG+3YF<F]M07)R87DH)&EN9F\I.PT*("`@("`@("!R971U
M<FX@)'!F.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S=')I
M;F<@8VAA;FYE;"!N86UE#0H@("`@("H@0'!A<F%M(&)O;VP@=VAE=&AE<B!T
M;R!S=')I8W1L>2!R971R:65V92!C:&%N;F5L(&YA;65S#0H@("`@("H@0')E
M='5R;B!014%27T-H86YN96Q&:6QE?%!%05)?17)R;W(-"B`@("`@*B!`86-C
M97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F7V=E=$-H86YN
M96PH)&-H86YN96PL("1N;V%L:6%S97,@/2!F86QS92D-"B`@("![#0H@("`@
M("`@("1C:"`](&9A;'-E.PT*("`@("`@("!I9B`H)'1H:7,M/E]C:&%N;F5L
M17AI<W1S*"1C:&%N;F5L+"`D;F]A;&EA<V5S*2D@>PT*("`@("`@("`@("`@
M)&-H:6YF;R`]("1T:&ES+3Y?8VAA;FYE;$EN9F\H)&-H86YN96PL("1N;V%L
M:6%S97,I.PT*("`@("`@("`@("`@:68@*"1C:&EN9F\I('L-"B`@("`@("`@
M("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]#:&%N;F5L1FEL92<I
M*2![#0H@("`@("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]#
M:&%N;F5L1FEL92YP:'`G.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`D8V@@/2`F4$5!4E]#:&%N;F5L1FEL93HZ9G)O;4%R<F%Y5VET
M:$5R<F]R<R@D8VAI;F9O*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H)&-H*2![#0H@("`@("`@("`@("!I9B`H)&-H+3YV86QI
M9&%T92@I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1C:#L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@*"1C:"T^9V5T17)R;W)S
M*'1R=64I(&%S("1E<G(I('L-"B`@("`@("`@("`@("`@("`D;65S<V%G92`]
M("1E<G);)VUE<W-A9V4G72`N(")<;B([#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`D8V@@/2!014%2.CIR86ES945R<F]R*"1M97-S86=E*3L-"B`@
M("`@("`@("`@(')E='5R;B`D8V@[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*"1T:&ES+3Y?9V5T0VAA;FYE;$9R;VU!;&EA<R@D8VAA;FYE;"D@/3T@)W!E
M87(N<&AP+FYE="<I('L-"B`@("`@("`@("`@("\O('1H92!R96=I<W1R>2!I
M<R!N;W0@<')O<&5R;'D@<V5T('5P+"!S;R!U<V4@9&5F875L=',-"B`@("`@
M("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27T-H86YN96Q&:6QE)RDI
M('L-"B`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O0VAA;FYE
M;$9I;&4N<&AP)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1P96%R
M7V-H86YN96P@/2!N97<@4$5!4E]#:&%N;F5L1FEL93L-"B`@("`@("`@("`@
M("1P96%R7V-H86YN96PM/G-E=$YA;64H)W!E87(N<&AP+FYE="<I.PT*("`@
M("`@("`@("`@)'!E87)?8VAA;FYE;"T^<V5T06QI87,H)W!E87(G*3L-"B`@
M("`@("`@("`@("1P96%R7V-H86YN96PM/G-E=%-U;6UA<GDH)U!(4"!%>'1E
M;G-I;VX@86YD($%P<&QI8V%T:6]N(%)E<&]S:71O<GDG*3L-"B`@("`@("`@
M("`@("1P96%R7V-H86YN96PM/G-E=$1E9F%U;'1014%24')O=&]C;VQS*"D[
M#0H@("`@("`@("`@("`D<&5A<E]C:&%N;F5L+3YS971"87-E55),*"=215-4
M,2XP)RP@)VAT='`Z+R]P96%R+G!H<"YN970O<F5S="\G*3L-"B`@("`@("`@
M("`@("1P96%R7V-H86YN96PM/G-E=$)A<V554DPH)U)%4U0Q+C$G+"`G:'1T
M<#HO+W!E87(N<&AP+FYE="]R97-T+R<I.PT*("`@("`@("`@("`@<F5T=7)N
M("1P96%R7V-H86YN96P[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1T:&ES
M+3Y?9V5T0VAA;FYE;$9R;VU!;&EA<R@D8VAA;FYE;"D@/3T@)W!E8VPN<&AP
M+FYE="<I('L-"B`@("`@("`@("`@("\O('1H92!R96=I<W1R>2!I<R!N;W0@
M<')O<&5R;'D@<V5T('5P+"!S;R!U<V4@9&5F875L=',-"B`@("`@("`@("`@
M(&EF("@A8VQA<W-?97AI<W1S*"=014%27T-H86YN96Q&:6QE)RDI('L-"B`@
M("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O0VAA;FYE;$9I;&4N
M<&AP)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1P96%R7V-H86YN
M96P@/2!N97<@4$5!4E]#:&%N;F5L1FEL93L-"B`@("`@("`@("`@("1P96%R
M7V-H86YN96PM/G-E=$YA;64H)W!E8VPN<&AP+FYE="<I.PT*("`@("`@("`@
M("`@)'!E87)?8VAA;FYE;"T^<V5T06QI87,H)W!E8VPG*3L-"B`@("`@("`@
M("`@("1P96%R7V-H86YN96PM/G-E=%-U;6UA<GDH)U!(4"!%>'1E;G-I;VX@
M0V]M;75N:71Y($QI8G)A<GDG*3L-"B`@("`@("`@("`@("1P96%R7V-H86YN
M96PM/G-E=$1E9F%U;'1014%24')O=&]C;VQS*"D[#0H@("`@("`@("`@("`D
M<&5A<E]C:&%N;F5L+3YS971"87-E55),*"=215-4,2XP)RP@)VAT='`Z+R]P
M96-L+G!H<"YN970O<F5S="\G*3L-"B`@("`@("`@("`@("1P96%R7V-H86YN
M96PM/G-E=$)A<V554DPH)U)%4U0Q+C$G+"`G:'1T<#HO+W!E8VPN<&AP+FYE
M="]R97-T+R<I.PT*("`@("`@("`@("`@)'!E87)?8VAA;FYE;"T^<V5T5F%L
M:61A=&EO;E!A8VMA9V4H)U!%05)?5F%L:61A=&]R7U!%0TPG+"`G,2XP)RD[
M#0H@("`@("`@("`@("!R971U<FX@)'!E87)?8VAA;FYE;#L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H)'1H:7,M/E]G971#:&%N;F5L1G)O;4%L:6%S*"1C
M:&%N;F5L*2`]/2`G7U]U<FDG*2![#0H@("`@("`@("`@("`O+R!T:&4@<F5G
M:7-T<GD@:7,@;F]T('!R;W!E<FQY('-E="!U<"P@<V\@=7-E(&1E9F%U;'1S
M#0H@("`@("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]#:&%N;F5L
M1FEL92<I*2![#0H@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2
M+T-H86YN96Q&:6QE+G!H<"<[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`D<')I=F%T92`](&YE=R!014%27T-H86YN96Q&:6QE.PT*("`@("`@("`@
M("`@)'!R:79A=&4M/G-E=$YA;64H)U]?=7)I)RD[#0H@("`@("`@("`@("`D
M<')I=F%T92T^861D1G5N8W1I;VXH)WAM;')P8R<L("<Q+C`G+"`G*BHJ*B<I
M.PT*("`@("`@("`@("`@)'!R:79A=&4M/G-E=%-U;6UA<GDH)U!S975D;RUC
M:&%N;F5L(&9O<B!S=&%T:6,@<&%C:V%G97,G*3L-"B`@("`@("`@("`@(')E
M='5R;B`D<')I=F%T93L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)&-H
M.PT*("`@('T-"@T*("`@("\O('M[>R!P86-K86=E17AI<W1S*"D-"@T*("`@
M("\J*@T*("`@("`J($!P87)A;2!S=')I;F<@4&%C:V%G92!N86UE#0H@("`@
M("H@0'!A<F%M('-T<FEN9R!#:&%N;F5L(&YA;64-"B`@("`@*B!`<F5T=7)N
M(&)O;VP-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!P86-K86=E17AI<W1S*"1P
M86-K86=E+"`D8VAA;FYE;"`]("=P96%R+G!H<"YN970G*0T*("`@('L-"B`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)&4@/2`D=&AI<RT^7VQO8VLH3$]#
M2U]32"DI*2![#0H@("`@("`@("`@("!R971U<FX@)&4[#0H@("`@("`@('T-
M"B`@("`@("`@)')E="`]("1T:&ES+3Y?<&%C:V%G945X:7-T<R@D<&%C:V%G
M92P@)&-H86YN96PI.PT*("`@("`@("`D=&AI<RT^7W5N;&]C:R@I.PT*("`@
M("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*("`@
M("\O('M[>R!C:&%N;F5L17AI<W1S*"D-"@T*("`@("\J*@T*("`@("`J($!P
M87)A;2!S=')I;F<@8VAA;FYE;"!N86UE#0H@("`@("H@0'!A<F%M(&)O;VP@
M:68@=')U92P@=&AE;B!A;&EA<V5S('=I;&P@8F4@:6=N;W)E9`T*("`@("`J
M($!R971U<FX@8F]O;`T*("`@("`J+PT*("`@(&9U;F-T:6]N(&-H86YN96Q%
M>&ES=',H)&-H86YN96PL("1N;V%L:6%S97,@/2!F86QS92D-"B`@("![#0H@
M("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E(#T@)'1H:7,M/E]L;V-K*$Q/
M0TM?4T@I*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1E.PT*("`@("`@("!]
M#0H@("`@("`@("1R970@/2`D=&AI<RT^7V-H86YN96Q%>&ES=',H)&-H86YN
M96PL("1N;V%L:6%S97,I.PT*("`@("`@("`D=&AI<RT^7W5N;&]C:R@I.PT*
M("`@("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*
M("`@("\O('M[>R!I<T%L:6%S*"D-"@T*("`@("\J*@T*("`@("`J($1E=&5R
M;6EN97,@=VAE=&AE<B!T:&4@<&%R86UE=&5R(&ES(&%N(&%L:6%S(&]F(&$@
M8VAA;FYE;`T*("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@*B!`<F5T=7)N
M(&)O;VP-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!I<T%L:6%S*"1A;&EA<RD-
M"B`@("![#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E(#T@)'1H:7,M
M/E]L;V-K*$Q/0TM?4T@I*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1E.PT*
M("`@("`@("!]#0H@("`@("`@("1R970@/2`D=&AI<RT^7VES0VAA;FYE;$%L
M:6%S*"1A;&EA<RD[#0H@("`@("`@("1T:&ES+3Y?=6YL;V-K*"D[#0H@("`@
M("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O
M('M[>R!P86-K86=E26YF;R@I#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@
M<W1R:6YG?&YU;&P-"B`@("`@*B!`<&%R86T@<W1R:6YG?&YU;&P-"B`@("`@
M*B!`<&%R86T@<W1R:6YG#0H@("`@("H@0')E='5R;B!A<G)A>7QN=6QL#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@<&%C:V%G94EN9F\H)'!A8VMA9V4@/2!N
M=6QL+"`D:V5Y(#T@;G5L;"P@)&-H86YN96P@/2`G<&5A<BYP:'`N;F5T)RD-
M"B`@("![#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E(#T@)'1H:7,M
M/E]L;V-K*$Q/0TM?4T@I*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1E.PT*
M("`@("`@("!]#0H@("`@("`@("1R970@/2`D=&AI<RT^7W!A8VMA9V5);F9O
M*"1P86-K86=E+"`D:V5Y+"`D8VAA;FYE;"D[#0H@("`@("`@("1T:&ES+3Y?
M=6YL;V-K*"D[#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*("`@
M("\O('U]?0T*("`@("\O('M[>R!C:&%N;F5L26YF;R@I#0H-"B`@("`O*BH-
M"B`@("`@*B!2971R:65V92!A(')A=R!A<G)A>2!O9B!C:&%N;F5L(&1A=&$N
M#0H@("`@("H-"B`@("`@*B!$;R!N;W0@=7-E('1H:7,L(&EN<W1E860@=7-E
M('M`;&EN:R!G971#:&%N;F5L*"E](&9O<B!N;W)M86P-"B`@("`@*B!O<&5R
M871I;VYS+B`@07)R87D@<W1R=6-T=7)E(&ES('5N9&5F:6YE9"!I;B!T:&ES
M(&UE=&AO9`T*("`@("`J($!P87)A;2!S=')I;F<@8VAA;FYE;"!N86UE#0H@
M("`@("H@0'!A<F%M(&)O;VP@=VAE=&AE<B!T;R!S=')I8W1L>2!R971R:65V
M92!I;F9O<FUA=&EO;B!O;FQY(&]N(&YO;BUA;&EA<V5S#0H@("`@("H@0')E
M='5R;B!A<G)A>7QN=6QL?%!%05)?17)R;W(-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!C:&%N;F5L26YF;R@D8VAA;FYE;"`](&YU;&PL("1N;V%L:6%S97,@
M/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E
M(#T@)'1H:7,M/E]L;V-K*$Q/0TM?4T@I*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N("1E.PT*("`@("`@("!]#0H@("`@("`@("1R970@/2`D=&AI<RT^7V-H
M86YN96Q);F9O*"1C:&%N;F5L+"`D;F]A;&EA<V5S*3L-"B`@("`@("`@)'1H
M:7,M/E]U;FQO8VLH*3L-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*
M#0H@("`@+R\@?7U]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W1R:6YG
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@8VAA;FYE;$YA;64H)&-H86YN96PI
M#0H@("`@>PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92`]("1T:&ES
M+3Y?;&]C:RA,3T-+7U-(*2DI('L-"B`@("`@("`@("`@(')E='5R;B`D93L-
M"B`@("`@("`@?0T*("`@("`@("`D<F5T(#T@)'1H:7,M/E]G971#:&%N;F5L
M1G)O;4%L:6%S*"1C:&%N;F5L*3L-"B`@("`@("`@)'1H:7,M/E]U;FQO8VLH
M*3L-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@+RHJ#0H@
M("`@("H@0'!A<F%M('-T<FEN9PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&-H
M86YN96Q!;&EA<R@D8VAA;FYE;"D-"B`@("![#0H@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1E(#T@)'1H:7,M/E]L;V-K*$Q/0TM?4T@I*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N("1E.PT*("`@("`@("!]#0H@("`@("`@("1R970@
M/2`D=&AI<RT^7V=E=$%L:6%S*"1C:&%N;F5L*3L-"B`@("`@("`@)'1H:7,M
M/E]U;FQO8VLH*3L-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*("`@
M("\O('M[>R!L:7-T4&%C:V%G97,H*0T*#0H@("`@9G5N8W1I;VX@;&ES=%!A
M8VMA9V5S*"1C:&%N;F5L(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D92`]("1T:&ES+3Y?;&]C:RA,3T-+7U-(*2DI('L-
M"B`@("`@("`@("`@(')E='5R;B`D93L-"B`@("`@("`@?0T*("`@("`@("`D
M<F5T(#T@)'1H:7,M/E]L:7-T4&%C:V%G97,H)&-H86YN96PI.PT*("`@("`@
M("`D=&AI<RT^7W5N;&]C:R@I.PT*("`@("`@("!R971U<FX@)')E=#L-"B`@
M("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@;&ES=$%L;%!A8VMA9V5S
M*"D-"@T*("`@(&9U;F-T:6]N(&QI<W1!;&Q086-K86=E<R@I#0H@("`@>PT*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92`]("1T:&ES+3Y?;&]C:RA,
M3T-+7U-(*2DI('L-"B`@("`@("`@("`@(')E='5R;B`D93L-"B`@("`@("`@
M?0T*("`@("`@("`D<F5T(#T@)'1H:7,M/E]L:7-T06QL4&%C:V%G97,H*3L-
M"B`@("`@("`@)'1H:7,M/E]U;FQO8VLH*3L-"B`@("`@("`@<F5T=7)N("1R
M970[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&QI<W1#:&%N
M;F5L*"D-"@T*("`@(&9U;F-T:6]N(&QI<W1#:&%N;F5L<R@I#0H@("`@>PT*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92`]("1T:&ES+3Y?;&]C:RA,
M3T-+7U-(*2DI('L-"B`@("`@("`@("`@(')E='5R;B`D93L-"B`@("`@("`@
M?0T*("`@("`@("`D<F5T(#T@)'1H:7,M/E]L:7-T0VAA;FYE;',H*3L-"B`@
M("`@("`@)'1H:7,M/E]U;FQO8VLH*3L-"B`@("`@("`@<F5T=7)N("1R970[
M#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&%D9%!A8VMA9V4H
M*0T*#0H@("`@+RHJ#0H@("`@("H@061D(&%N(&EN<W1A;&QE9"!P86-K86=E
M('1O('1H92!R96=I<W1R>0T*("`@("`J($!P87)A;2!S=')I;F=\4$5!4E]0
M86-K86=E1FEL95]V,7Q014%27U!A8VMA9V5&:6QE7W8R('!A8VMA9V4@;F%M
M92!O<B!O8FIE8W0-"B`@("`@*B`@("`@("`@("`@("`@('1H870@=VEL;"!B
M92!P87-S960@=&\@>T!L:6YK(&%D9%!A8VMA9V4R*"E]#0H@("`@("H@0'!A
M<F%M(&%R<F%Y('!A8VMA9V4@:6YF;R`H<&%R<V5D(&)Y(%!%05)?0V]M;6]N
M.CII;F9O1G)O;2HH*2!M971H;V1S*0T*("`@("`J($!R971U<FX@8F]O;"!S
M=6-C97-S(&]F('-A=FEN9PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&%D9%!A
M8VMA9V4H)'!A8VMA9V4L("1I;F9O*0T*("`@('L-"B`@("`@("`@:68@*&ES
M7V]B:F5C="@D:6YF;RDI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M861D4&%C:V%G93(H)&EN9F\I.PT*("`@("`@("!]#0H@("`@("`@(&EF("A0
M14%2.CII<T5R<F]R*"1E(#T@)'1H:7,M/E]L;V-K*$Q/0TM?15@I*2D@>PT*
M("`@("`@("`@("`@<F5T=7)N("1E.PT*("`@("`@("!]#0H@("`@("`@("1R
M970@/2`D=&AI<RT^7V%D9%!A8VMA9V4H)'!A8VMA9V4L("1I;F9O*3L-"B`@
M("`@("`@)'1H:7,M/E]U;FQO8VLH*3L-"B`@("`@("`@:68@*"1R970I('L-
M"B`@("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27U!A8VMA9V5&
M:6QE7W8Q)RDI('L-"B`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%
M05(O4&%C:V%G949I;&4O=C$N<&AP)SL-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("1P9B`](&YE=R!014%27U!A8VMA9V5&:6QE7W8Q.PT*("`@("`@
M("`@("`@)'!F+3YS971#;VYF:6<H)'1H:7,M/E]C;VYF:6<I.PT*("`@("`@
M("`@("`@)'!F+3YF<F]M07)R87DH)&EN9F\I.PT*("`@("`@("`@("`@)'1H
M:7,M/E]D97!E;F1E;F-Y1$(M/G5N:6YS=&%L;%!A8VMA9V4H)'!F*3L-"B`@
M("`@("`@("`@("1T:&ES+3Y?9&5P96YD96YC>41"+3YI;G-T86QL4&%C:V%G
M92@D<&8I.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@
M('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!A9&1086-K86=E,B@I#0H-
M"B`@("!F=6YC=&EO;B!A9&1086-K86=E,B@D:6YF;RD-"B`@("![#0H@("`@
M("`@(&EF("@A:7-?;V)J96-T*"1I;F9O*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YA9&1086-K86=E*"1I;F9O6R=P86-K86=E)UTL("1I;F9O
M*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92`]
M("1T:&ES+3Y?;&]C:RA,3T-+7T58*2DI('L-"B`@("`@("`@("`@(')E='5R
M;B`D93L-"B`@("`@("`@?0T*("`@("`@("`D<F5T(#T@)'1H:7,M/E]A9&10
M86-K86=E,B@D:6YF;RD[#0H@("`@("`@("1T:&ES+3Y?=6YL;V-K*"D[#0H@
M("`@("`@(&EF("@D<F5T*2![#0H@("`@("`@("`@("`D=&AI<RT^7V1E<&5N
M9&5N8WE$0BT^=6YI;G-T86QL4&%C:V%G92@D:6YF;RD[#0H@("`@("`@("`@
M("`D=&AI<RT^7V1E<&5N9&5N8WE$0BT^:6YS=&%L;%!A8VMA9V4H)&EN9F\I
M.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*
M("`@("\O('U]?0T*("`@("\O('M[>R!U<&1A=&5#:&%N;F5L*"D-"@T*("`@
M("\J*@T*("`@("`J($9O<B!F=71U<F4@97AP86YD:6)I;&ET>2!P=7)P;W-E
M<RP@<V5P87)A=&4@=&AI<PT*("`@("`J($!P87)A;2!014%27T-H86YN96Q&
M:6QE#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=7!D871E0VAA;FYE;"@D8VAA
M;FYE;"P@)&QA<W1M;V1I9FEE9"`](&YU;&PI#0H@("`@>PT*("`@("`@("!I
M9B`H)&-H86YN96PM/F=E=$YA;64H*2`]/2`G7U]U<FDG*2![#0H@("`@("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N
M("1T:&ES+3YA9&1#:&%N;F5L*"1C:&%N;F5L+"`D;&%S=&UO9&EF:65D+"!T
M<G5E*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9&5L971E
M0VAA;FYE;"@I#0H-"B`@("`O*BH-"B`@("`@*B!$96QE=&EO;B!F86EL<R!I
M9B!T:&5R92!A<F4@86YY('!A8VMA9V5S(&EN<W1A;&QE9"!F<F]M('1H92!C
M:&%N;F5L#0H@("`@("H@0'!A<F%M('-T<FEN9WQ014%27T-H86YN96Q&:6QE
M(&-H86YN96P@;F%M90T*("`@("`J($!R971U<FX@8F]O;&5A;GQ014%27T5R
M<F]R(%1R=64@;VX@9&5L971I;VXL(&9A;'-E(&EF(&ET(&1O97-N)W0@97AI
M<W0-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!D96QE=&5#:&%N;F5L*"1C:&%N
M;F5L*0T*("`@('L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&4@/2`D
M=&AI<RT^7VQO8VLH3$]#2U]%6"DI*2![#0H@("`@("`@("`@("!R971U<FX@
M)&4[#0H@("`@("`@('T-"B`@("`@("`@)')E="`]("1T:&ES+3Y?9&5L971E
M0VAA;FYE;"@D8VAA;FYE;"D[#0H@("`@("`@("1T:&ES+3Y?=6YL;V-K*"D[
M#0H@("`@("`@(&EF("@D<F5T("8F(&ES7V$H)'1H:7,M/E]C;VYF:6<L("=0
M14%27T-O;F9I9R<I*2![#0H@("`@("`@("`@("`D=&AI<RT^7V-O;F9I9RT^
M<V5T0VAA;FYE;',H)'1H:7,M/FQI<W1#:&%N;F5L<R@I*3L-"B`@("`@("`@
M?0T*("`@("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O+R!]?7T-
M"B`@("`O+R![>WL@861D0VAA;FYE;"@I#0H-"B`@("`O*BH-"B`@("`@*B!`
M<&%R86T@4$5!4E]#:&%N;F5L1FEL92!#:&%N;F5L(&]B:F5C=`T*("`@("`J
M($!P87)A;2!S=')I;F<@3&%S="U-;V1I9FEE9"!H96%D97(@9G)O;2!(5%10
M(&9O<B!C86-H:6YG#0H@("`@("H@0')E='5R;B!B;V]L96%N?%!%05)?17)R
M;W(@5')U92!O;B!C<F5A=&EO;BP@9F%L<V4@:68@:70@86QR96%D>2!E>&ES
M=',-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!A9&1#:&%N;F5L*"1C:&%N;F5L
M+"`D;&%S=&UO9&EF:65D(#T@9F%L<V4L("1U<&1A=&4@/2!F86QS92D-"B`@
M("![#0H@("`@("`@(&EF("@A:7-?82@D8VAA;FYE;"P@)U!%05)?0VAA;FYE
M;$9I;&4G*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("@A)&-H86YN96PM/G9A;&ED871E*"DI('L-"B`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D92`]("1T:&ES+3Y?;&]C:RA,3T-+7T58*2DI
M('L-"B`@("`@("`@("`@(')E='5R;B`D93L-"B`@("`@("`@?0T*("`@("`@
M("`D<F5T(#T@)'1H:7,M/E]A9&1#:&%N;F5L*"1C:&%N;F5L+"`D=7!D871E
M+"`D;&%S=&UO9&EF:65D*3L-"B`@("`@("`@)'1H:7,M/E]U;FQO8VLH*3L-
M"B`@("`@("`@:68@*"$D=7!D871E("8F("1R970@)B8@:7-?82@D=&AI<RT^
M7V-O;F9I9RP@)U!%05)?0V]N9FEG)RDI('L-"B`@("`@("`@("`@("1T:&ES
M+3Y?8V]N9FEG+3YS971#:&%N;F5L<R@D=&AI<RT^;&ES=$-H86YN96QS*"DI
M.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*
M("`@("\O('U]?0T*("`@("\O('M[>R!D96QE=&5086-K86=E*"D-"@T*("`@
M(&9U;F-T:6]N(&1E;&5T95!A8VMA9V4H)'!A8VMA9V4L("1C:&%N;F5L(#T@
M)W!E87(N<&AP+FYE="<I#0H@("`@>PT*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D92`]("1T:&ES+3Y?;&]C:RA,3T-+7T58*2DI('L-"B`@("`@("`@
M("`@(')E='5R;B`D93L-"B`@("`@("`@?0T*("`@("`@("`D9FEL92`]("1T
M:&ES+3Y?<&%C:V%G949I;&5.86UE*"1P86-K86=E+"`D8VAA;FYE;"D[#0H@
M("`@("`@("1R970@/2!`=6YL:6YK*"1F:6QE*3L-"B`@("`@("`@)'1H:7,M
M/E]R96)U:6QD1FEL94UA<"@I.PT*("`@("`@("`D=&AI<RT^7W5N;&]C:R@I
M.PT*("`@("`@("`D<"`](&%R<F%Y*"=C:&%N;F5L)R`]/B`D8VAA;FYE;"P@
M)W!A8VMA9V4G(#T^("1P86-K86=E*3L-"B`@("`@("`@)'1H:7,M/E]D97!E
M;F1E;F-Y1$(M/G5N:6YS=&%L;%!A8VMA9V4H)'`I.PT*("`@("`@("!R971U
M<FX@)')E=#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@=7!D
M871E4&%C:V%G92@I#0H-"B`@("!F=6YC=&EO;B!U<&1A=&5086-K86=E*"1P
M86-K86=E+"`D:6YF;RP@)&UE<F=E(#T@=')U92D-"B`@("![#0H@("`@("`@
M(&EF("AI<U]O8FIE8W0H)&EN9F\I*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G5P9&%T95!A8VMA9V4R*"1I;F9O+"`D;65R9V4I.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E(#T@)'1H:7,M/E]L
M;V-K*$Q/0TM?15@I*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1E.PT*("`@
M("`@("!]#0H@("`@("`@("1R970@/2`D=&AI<RT^7W5P9&%T95!A8VMA9V4H
M)'!A8VMA9V4L("1I;F9O+"`D;65R9V4I.PT*("`@("`@("`D=&AI<RT^7W5N
M;&]C:R@I.PT*("`@("`@("!I9B`H)')E="D@>PT*("`@("`@("`@("`@:68@
M*"%C;&%S<U]E>&ES=',H)U!%05)?4&%C:V%G949I;&5?=C$G*2D@>PT*("`@
M("`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]086-K86=E1FEL92]V
M,2YP:'`G.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'!F(#T@;F5W
M(%!%05)?4&%C:V%G949I;&5?=C$[#0H@("`@("`@("`@("`D<&8M/G-E=$-O
M;F9I9R@D=&AI<RT^7V-O;F9I9RD[#0H@("`@("`@("`@("`D<&8M/F9R;VU!
M<G)A>2@D=&AI<RT^<&%C:V%G94EN9F\H)'!A8VMA9V4I*3L-"B`@("`@("`@
M("`@("1T:&ES+3Y?9&5P96YD96YC>41"+3YU;FEN<W1A;&Q086-K86=E*"1P
M9BD[#0H@("`@("`@("`@("`D=&AI<RT^7V1E<&5N9&5N8WE$0BT^:6YS=&%L
M;%!A8VMA9V4H)'!F*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)')E
M=#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@=7!D871E4&%C
M:V%G93(H*0T*#0H@("`@9G5N8W1I;VX@=7!D871E4&%C:V%G93(H)&EN9F\I
M#0H@("`@>PT*("`@("`@("!I9B`H(6ES7V]B:F5C="@D:6YF;RDI('L-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^=7!D871E4&%C:V%G92@D:6YF;ULG
M<&%C:V%G92==+"`D:6YF;RP@)&UE<F=E*3L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H(21I;F9O+3YV86QI9&%T92A014%27U9!3$E$051%7T1/5TY,3T%$
M24Y'*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E(#T@)'1H:7,M/E]L;V-K
M*$Q/0TM?15@I*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1E.PT*("`@("`@
M("!]#0H@("`@("`@("1R970@/2`D=&AI<RT^7W5P9&%T95!A8VMA9V4R*"1I
M;F9O*3L-"B`@("`@("`@)'1H:7,M/E]U;FQO8VLH*3L-"B`@("`@("`@:68@
M*"1R970I('L-"B`@("`@("`@("`@("1T:&ES+3Y?9&5P96YD96YC>41"+3YU
M;FEN<W1A;&Q086-K86=E*"1I;F9O*3L-"B`@("`@("`@("`@("1T:&ES+3Y?
M9&5P96YD96YC>41"+3YI;G-T86QL4&%C:V%G92@D:6YF;RD[#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0H@("`@+R\@>WM[(&=E=$-H86YN96PH*0T*("`@("\J*@T*("`@("`J($!P
M87)A;2!S=')I;F<@8VAA;FYE;"!N86UE#0H@("`@("H@0'!A<F%M(&)O;VP@
M=VAE=&AE<B!T;R!S=')I8W1L>2!R971U<FX@<F%W(&-H86YN96QS("AN;R!A
M;&EA<V5S*0T*("`@("`J($!R971U<FX@4$5!4E]#:&%N;F5L1FEL97Q014%2
M7T5R<F]R#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)F=E=$-H86YN96PH)&-H
M86YN96PL("1N;V%L:6%S97,@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1E(#T@)'1H:7,M/E]L;V-K*$Q/0TM?4T@I*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N("1E.PT*("`@("`@("!]#0H@("`@("`@
M("1R970@/2`F)'1H:7,M/E]G971#:&%N;F5L*"1C:&%N;F5L+"`D;F]A;&EA
M<V5S*3L-"B`@("`@("`@:68@*"$D<F5T*2![#0H@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@G56YK;F]W;B!C:&%N;F5L.B`G("X@)&-H
M86YN96PI.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?=6YL;V-K*"D[
M#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*("`@("\O('U]?0T*
M("`@("\O('M[>R!G971086-K86=E*"D-"B`@("`O*BH-"B`@("`@*B!`<&%R
M86T@<W1R:6YG('!A8VMA9V4@;F%M90T*("`@("`J($!P87)A;2!S=')I;F<@
M8VAA;FYE;"!N86UE#0H@("`@("H@0')E='5R;B!014%27U!A8VMA9V5&:6QE
M7W8Q?%!%05)?4&%C:V%G949I;&5?=C)\;G5L;`T*("`@("`J+PT*("`@(&9U
M;F-T:6]N("9G971086-K86=E*"1P86-K86=E+"`D8VAA;FYE;"`]("=P96%R
M+G!H<"YN970G*0T*("`@('L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)&4@/2`D=&AI<RT^7VQO8VLH3$]#2U]32"DI*2![#0H@("`@("`@("`@("!R
M971U<FX@)&4[#0H@("`@("`@('T-"B`@("`@("`@)'!F(#T@)B1T:&ES+3Y?
M9V5T4&%C:V%G92@D<&%C:V%G92P@)&-H86YN96PI.PT*("`@("`@("`D=&AI
M<RT^7W5N;&]C:R@I.PT*("`@("`@("!R971U<FX@)'!F.PT*("`@('T-"@T*
M("`@("\O('U]?0T*#0H@("`@+RHJ#0H@("`@("H@1V5T(%!%05)?4&%C:V%G
M949I;&5?=ELQ+S)=(&]B:F5C=',@<F5P<F5S96YT:6YG('1H92!C;VYT96YT
M<R!O9@T*("`@("`J(&$@9&5P96YD96YC>2!G<F]U<"!T:&%T(&%R92!I;G-T
M86QL960N#0H@("`@("H-"B`@("`@*B!4:&ES(&ES('5S960@870@=6YI;G-T
M86QL+71I;64-"B`@("`@*B!`<&%R86T@87)R87D-"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y?&9A;'-E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T26YS=&%L
M;&5D1W)O=7`H)&=R;W5P*0T*("`@('L-"B`@("`@("`@)')E="`](&%R<F%Y
M*"D[#0H@("`@("`@(&EF("AI<W-E="@D9W)O=7!;)W!A8VMA9V4G72DI('L-
M"B`@("`@("`@("`@(&EF("@A:7-S970H)&=R;W5P6R=P86-K86=E)UU;,%TI
M*2![#0H@("`@("`@("`@("`@("`@)&=R;W5P6R=P86-K86=E)UT@/2!A<G)A
M>2@D9W)O=7!;)W!A8VMA9V4G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!F;W)E86-H("@D9W)O=7!;)W!A8VMA9V4G72!A<R`D<&%C:V%G92D@
M>PT*("`@("`@("`@("`@("`@("1D97!C:&%N;F5L(#T@:7-S970H)'!A8VMA
M9V5;)V-H86YN96PG72D@/R`D<&%C:V%G95LG8VAA;FYE;"==(#H@)U]?=7)I
M)SL-"B`@("`@("`@("`@("`@("`D<"`]("8D=&AI<RT^9V5T4&%C:V%G92@D
M<&%C:V%G95LG;F%M92==+"`D9&5P8VAA;FYE;"D[#0H@("`@("`@("`@("`@
M("`@:68@*"1P*2![#0H@("`@("`@("`@("`@("`@("`@("1S879E(#T@)B1P
M.PT*("`@("`@("`@("`@("`@("`@("`D<F5T6UT@/2`F)'-A=F4[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@(&EF("AI<W-E="@D9W)O=7!;)W-U8G!A8VMA9V4G72DI('L-"B`@("`@
M("`@("`@(&EF("@A:7-S970H)&=R;W5P6R=S=6)P86-K86=E)UU;,%TI*2![
M#0H@("`@("`@("`@("`@("`@)&=R;W5P6R=S=6)P86-K86=E)UT@/2!A<G)A
M>2@D9W)O=7!;)W-U8G!A8VMA9V4G72D[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!F;W)E86-H("@D9W)O=7!;)W-U8G!A8VMA9V4G72!A<R`D<&%C
M:V%G92D@>PT*("`@("`@("`@("`@("`@("1D97!C:&%N;F5L(#T@:7-S970H
M)'!A8VMA9V5;)V-H86YN96PG72D@/R`D<&%C:V%G95LG8VAA;FYE;"==(#H@
M)U]?=7)I)SL-"B`@("`@("`@("`@("`@("`D<"`]("8D=&AI<RT^9V5T4&%C
M:V%G92@D<&%C:V%G95LG;F%M92==+"`D9&5P8VAA;FYE;"D[#0H@("`@("`@
M("`@("`@("`@:68@*"1P*2![#0H@("`@("`@("`@("`@("`@("`@("1S879E
M(#T@)B1P.PT*("`@("`@("`@("`@("`@("`@("`D<F5T6UT@/2`F)'-A=F4[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(&EF("@A8V]U;G0H)')E="DI('L-"B`@("`@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)')E=#L-
M"B`@("!]#0H-"B`@("`O+R![>WL@9V5T0VAA;FYE;%9A;&ED871O<B@I#0H@
M("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9R!C:&%N;F5L(&YA;64-"B`@
M("`@*B!`<F5T=7)N(%!%05)?5F%L:61A=&5\9F%L<V4-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B`F9V5T0VAA;FYE;%9A;&ED871O<B@D8VAA;FYE;"D-"B`@
M("![#0H@("`@("`@("1C:&%N(#T@)'1H:7,M/F=E=$-H86YN96PH)&-H86YN
M96PI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8VAA;BDI('L-"B`@
M("`@("`@("`@(')E='5R;B`D8VAA;CL-"B`@("`@("`@?0T*("`@("`@("`D
M=F%L(#T@)&-H86XM/F=E=%9A;&ED871I;VY/8FIE8W0H*3L-"B`@("`@("`@
M<F5T=7)N("1V86P[#0H@("`@?0T*("`@("\O('U]?0T*("`@("\O('M[>R!G
M971#:&%N;F5L<R@I#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9R!C
M:&%N;F5L(&YA;64-"B`@("`@*B!`<F5T=7)N(&%R<F%Y(&%N(&%R<F%Y(&]F
M(%!%05)?0VAA;FYE;$9I;&4@;V)J96-T<R!R97!R97-E;G1I;F<@979E<GD@
M:6YS=&%L;&5D(&-H86YN96P-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F9V5T
M0VAA;FYE;',H*0T*("`@('L-"B`@("`@("`@)')E="`](&%R<F%Y*"D[#0H@
M("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E(#T@)'1H:7,M/E]L;V-K*$Q/
M0TM?4T@I*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1E.PT*("`@("`@("!]
M#0H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?;&ES=$-H86YN96QS*"D@87,@
M)&-H86YN96PI('L-"B`@("`@("`@("`@("1E(#T@)B1T:&ES+3Y?9V5T0VAA
M;FYE;"@D8VAA;FYE;"D[#0H@("`@("`@("`@("!I9B`H(21E('Q\(%!%05(Z
M.FES17)R;W(H)&4I*2![#0H@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`D<F5T6UT@/2`D93L-"B`@("`@
M("`@?0T*("`@("`@("`D=&AI<RT^7W5N;&]C:R@I.PT*("`@("`@("!R971U
M<FX@)')E=#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@8VAE
M8VM&:6QE36%P*"D-"@T*("`@("\J*@T*("`@("`J(%1E<W0@=VAE=&AE<B!A
M(&9I;&4@;W(@<V5T(&]F(&9I;&5S(&)E;&]N9W,@=&\@82!P86-K86=E+@T*
M("`@("`J#0H@("`@("H@268@86X@87)R87D@:7,@<&%S<V5D(&EN#0H@("`@
M("H@0'!A<F%M('-T<FEN9WQA<G)A>2!F:6QE('!A=&@L(&%B<V]L=71E(&]R
M(')E;&%T:79E('1O('1H92!P96%R#0H@("`@("H@("`@("`@("`@("`@("`@
M("`@("!I;G-T86QL(&1I<@T*("`@("`J($!P87)A;2!S=')I;F=\87)R87D@
M;F%M92!O9B!014%2('!A8VMA9V4@;W(@87)R87DH)W!A8VMA9V4G(#T^(&YA
M;64L("=C:&%N;F5L)R`]/@T*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M8VAA;FYE;"D@;V8@82!P86-K86=E('1H870@=VEL;"!B92!I9VYO<F5D#0H@
M("`@("H@0'!A<F%M('-T<FEN9R!!4$D@=F5R<VEO;B`M(#$N,2!W:6QL(&5X
M8VQU9&4@86YY(&9I;&5S(&)E;&]N9VEN9R!T;R!A('!A8VMA9V4-"B`@("`@
M*B!`<&%R86T@87)R87D@<')I=F%T92!R96-U<G-I;VX@=F%R:6%B;&4-"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y?&9A;'-E('=H:6-H('!A8VMA9V4@86YD(&-H
M86YN96P@=&AE(&9I;&4@8F5L;VYG<R!T;RP@;W(@86X@96UP='D-"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@('-T<FEN9R!I9B!T:&4@9FEL92!D;V5S
M(&YO="!B96QO;F<@=&\@86X@:6YS=&%L;&5D('!A8VMA9V4L#0H@("`@("H@
M("`@("`@("`@("`@("`@("`@("!O<B!B96QO;F=S('1O('1H92!S96-O;F0@
M<&%R86UE=&5R)W,@<&%C:V%G90T*("`@("`J+PT*("`@(&9U;F-T:6]N(&-H
M96-K1FEL94UA<"@D<&%T:"P@)'!A8VMA9V4@/2!F86QS92P@)&%P:2`]("<Q
M+C`G+"`D871T<G,@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("AI<U]A
M<G)A>2@D<&%T:"DI('L-"B`@("`@("`@("`@('-T871I8R`D;F]T96UP='D[
M#0H@("`@("`@("`@("!I9B`H96UP='DH)&YO=&5M<'1Y*2D@>PT*("`@("`@
M("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27TEN<W1A;&QE<E]2
M;VQE)RDI('L-"B`@("`@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=0
M14%2+TEN<W1A;&QE<B]2;VQE+G!H<"<[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("1N;W1E;7!T>2`](&-R96%T95]F=6YC=&EO;B@G
M)&$G+"=R971U<FX@(65M<'1Y*"1A*3LG*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("1P86-K86=E(#T@:7-?87)R87DH)'!A8VMA9V4I(#\@87)R
M87DH<W1R=&]L;W=E<B@D<&%C:V%G95LP72DL('-T<G1O;&]W97(H)'!A8VMA
M9V5;,5TI*0T*("`@("`@("`@("`@("`@(#H@<W1R=&]L;W=E<B@D<&%C:V%G
M92D[#0H@("`@("`@("`@("`D<&MG<R`](&%R<F%Y*"D[#0H@("`@("`@("`@
M("!F;W)E86-H("@D<&%T:"!A<R`D;F%M92`]/B`D871T<G,I('L-"B`@("`@
M("`@("`@("`@("!I9B`H:7-?87)R87DH)&%T=')S*2D@>PT*("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&%T=')S6R=I;G-T86QL+6%S)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D;F%M92`]("1A='1R<ULG:6YS
M=&%L;"UA<R==.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@A:6Y?87)R87DH)&%T=')S6R=R;VQE)UTL(%!%05)?
M26YS=&%L;&5R7U)O;&4Z.F=E=$EN<W1A;&QA8FQE4F]L97,H*2DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("\O('1H97-E(&%R92!N;W0@:6YS=&%L
M;&5D#0H@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H(6EN
M7V%R<F%Y*"1A='1R<ULG<F]L92==+"!014%27TEN<W1A;&QE<E]2;VQE.CIG
M971"87-E:6YS=&%L;%)O;&5S*"DI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D871T<G-;)V)A<V5I;G-T86QL9&ER)UT@/2!I<U]A<G)A>2@D<&%C
M:V%G92D@/R`D<&%C:V%G95LQ72`Z("1P86-K86=E.PT*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D871T
M<G-;)V)A<V5I;G-T86QL9&ER)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D;F%M92`]("1A='1R<ULG8F%S96EN<W1A;&QD:7(G72`N($1)4D5#
M5$]265]315!!4D%43U(@+B`D;F%M93L-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D<&MG<ULD
M;F%M95T@/2`D=&AI<RT^8VAE8VM&:6QE36%P*"1N86UE+"`D<&%C:V%G92P@
M)&%P:2P@)&%T=')S*3L-"B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D<&MG<ULD;F%M95TI*2![#0H@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D<&MG<ULD;F%M95T[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y7V9I;'1E<B@D<&MG
M<RP@)&YO=&5M<'1Y*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H96UP='DH
M)'1H:7,M/F9I;&5M87!?8V%C:&4I*2![#0H@("`@("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D92`]("1T:&ES+3Y?;&]C:RA,3T-+7U-(*2DI('L-"B`@
M("`@("`@("`@("`@("!R971U<FX@)&4[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`D97)R(#T@)'1H:7,M/E]R96%D1FEL94UA<"@I.PT*("`@("`@
M("`@("`@)'1H:7,M/E]U;FQO8VLH*3L-"B`@("`@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1E<G(I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1E
M<G([#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D
M871T<G,I('L-"B`@("`@("`@("`@("1A='1R<R`](&%R<F%Y*"=R;VQE)R`]
M/B`G<&AP)RD[("\O(&%N>2!O;&0@8V%L;"!W;W5L9"!B92!F;W(@4$A0(')O
M;&4@;VYL>0T*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M9FEL96UA<%]C86-H95LD871T<G-;)W)O;&4G75U;)'!A=&A=*2D@>PT*("`@
M("`@("`@("`@:68@*"1A<&D@/CT@)S$N,2<@)B8@)'1H:7,M/F9I;&5M87!?
M8V%C:&5;)&%T=')S6R=R;VQE)UU=6R1P871H72`]/2`D<&%C:V%G92D@>PT*
M("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9FEL96UA<%]C86-H95LD871T
M<G-;)W)O;&4G75U;)'!A=&A=.PT*("`@("`@("!]#0H@("`@("`@("1L(#T@
M<W1R;&5N*"1T:&ES+3YI;G-T86QL7V1I<BD[#0H@("`@("`@(&EF("AS=6)S
M='(H)'!A=&@L(#`L("1L*2`]/2`D=&AI<RT^:6YS=&%L;%]D:7(I('L-"B`@
M("`@("`@("`@("1P871H(#T@<')E9U]R97!L86-E*"<A7B<N1$E214-43U)9
M7U-%4$%2051/4BXG*R$G+"`G)RP@<W5B<W1R*"1P871H+"`D;"DI.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^9FEL96UA<%]C86-H
M95LD871T<G-;)W)O;&4G75U;)'!A=&A=*2D@>PT*("`@("`@("`@("`@:68@
M*"1A<&D@/CT@)S$N,2<@)B8@)'1H:7,M/F9I;&5M87!?8V%C:&5;)&%T=')S
M6R=R;VQE)UU=6R1P871H72`]/2`D<&%C:V%G92D@>PT*("`@("`@("`@("`@
M("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^9FEL96UA<%]C86-H95LD871T<G-;)W)O;&4G75U;
M)'!A=&A=.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@87!I5F5R<VEO;B@I#0H@
M("`@+RHJ#0H@("`@("H@1V5T('1H92!E>'!E8W1E9"!!4$D@=F5R<VEO;BX@
M($-H86YN96QS($%022!I<R!V97)S:6]N(#$N,2P@87,@:70@:7,@8F%C:W=A
M<F1S#0H@("`@("H@8V]M<&%T:6)L92!W:71H(#$N,`T*("`@("`J($!R971U
M<FX@<W1R:6YG#0H@("`@("HO#0H@("`@9G5N8W1I;VX@87!I5F5R<VEO;B@I
M#0H@("`@>PT*("`@("`@("!R971U<FX@)S$N,2<[#0H@("`@?0T*("`@("\O
M('U]?0T*#0H-"B`@("`O*BH-"B`@("`@*B!087)S92!A('!A8VMA9V4@;F%M
M92P@;W(@=F%L:61A=&4@82!P87)S960@<&%C:V%G92!N86UE(&%R<F%Y#0H@
M("`@("H@0'!A<F%M('-T<FEN9WQA<G)A>2!P87-S(&EN(&%N(&%R<F%Y(&]F
M(&9O<FUA=`T*("`@("`J("`@("`@("`@("`@("`@("`@("`@87)R87DH#0H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@)W!A8VMA9V4G(#T^("=P;F%M
M92<L#0H@("`@("H@("`@("`@("`@("`@("`@("`@("!;)V-H86YN96PG(#T^
M("=C:&%N;F%M92<L70T*("`@("`J("`@("`@("`@("`@("`@("`@("`@6R=V
M97)S:6]N)R`]/B`G=F5R<VEO;B<L70T*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@6R=S=&%T92<@/3X@)W-T871E)RQ=#0H@("`@("H@("`@("`@("`@
M("`@("`@("`@("!;)V=R;W5P)R`]/B`G9W)O=7!N86UE)UTI#0H@("`@("H@
M("`@("`@("`@("`@("`@("`@("!O<B!A('-T<FEN9R!O9B!F;W)M870-"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@(%MC:&%N;F5L.B\O75MC:&%N;F%M
M92]=<&YA;65;+79E<G-I;VY\+7-T871E75LO9W)O=7`]9W)O=7!N86UE70T*
M("`@("`J($!R971U<FX@87)R87E\4$5!4E]%<G)O<@T*("`@("`J+PT*("`@
M(&9U;F-T:6]N('!A<G-E4&%C:V%G94YA;64H)'!A<F%M+"`D9&5F875L=&-H
M86YN96P@/2`G<&5A<BYP:'`N;F5T)RD-"B`@("![#0H@("`@("`@("1S879E
M<&%R86T@/2`D<&%R86T[#0H@("`@("`@(&EF("AI<U]A<G)A>2@D<&%R86TI
M*2![#0H@("`@("`@("`@("`O+R!C;VYV97)T('1O('-T<FEN9R!F;W(@97)R
M;W(@;65S<V%G97,-"B`@("`@("`@("`@("1S879E<&%R86T@/2`D=&AI<RT^
M<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9R@D<&%R86TI.PT*("`@("`@("`@
M("`@+R\@<')O8V5S<R!T:&4@87)R87D-"B`@("`@("`@("`@(&EF("@A:7-S
M970H)'!A<F%M6R=P86-K86=E)UTI*2![#0H@("`@("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H)W!A<G-E4&%C:V%G94YA;64H*3H@87)R
M87D@)'!A<F%M("<@+@T*("`@("`@("`@("`@("`@("`@("`G;75S="!C;VYT
M86EN(&$@=F%L:60@<&%C:V%G92!N86UE(&EN(&EN9&5X(")P87)A;2(G+`T*
M("`@("`@("`@("`@("`@("`@("`G<&%C:V%G92<L(&YU;&PL(&YU;&PL("1P
M87)A;2D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1P87)A;5LG=7)I)UTI*2![#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D<&%R86U;)V-H86YN96PG72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M)'!A<F%M6R=C:&%N;F5L)UT@/2`D9&5F875L=&-H86YN96P[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`D<&%R86U;)V-H86YN96PG72`]("=?7W5R:2<[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D8V]M<&]N96YT
M<R`]($!P87)S95]U<FPH)'!A<F%M*3L-"B`@("`@("`@("`@(&EF("AI<W-E
M="@D8V]M<&]N96YT<ULG<V-H96UE)UTI*2![#0H@("`@("`@("`@("`@("`@
M:68@*"1C;VUP;VYE;G1S6R=S8VAE;64G72`]/2`G:'1T<"<I('L-"B`@("`@
M("`@("`@("`@("`@("`@+R\@=7)I('!A8VMA9V4-"B`@("`@("`@("`@("`@
M("`@("`@)'!A<F%M(#T@87)R87DH)W5R:2<@/3X@)'!A<F%M+"`G8VAA;FYE
M;"<@/3X@)U]?=7)I)RD[#0H@("`@("`@("`@("`@("`@?2!E;'-E:68H)&-O
M;7!O;F5N='-;)W-C:&5M92==("$]("=C:&%N;F5L)RD@>PT*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G<&%R<V5086-K
M86=E3F%M92@I.B!O;FQY(&-H86YN96PZ+R\@=7)I<R!M87D@)R`N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`G8F4@9&]W;FQO861E9"P@;F]T("(G("X@
M)'!A<F%M("X@)R(G+"`G:6YV86QI9"<L(&YU;&PL(&YU;&PL("1P87)A;2D[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@:68@*"%I<W-E="@D8V]M<&]N96YT<ULG<&%T:"==*2D@>PT*("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=P87)S95!A8VMA
M9V5.86UE*"DZ(&%R<F%Y("1P87)A;2`G("X-"B`@("`@("`@("`@("`@("`@
M("`@)VUU<W0@8V]N=&%I;B!A('9A;&ED('!A8VMA9V4@;F%M92!I;B`B)R`N
M("1P87)A;2`N("<B)RP-"B`@("`@("`@("`@("`@("`@("`@)W!A8VMA9V4G
M+"!N=6QL+"!N=6QL+"`D<&%R86TI.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@:68@*&ES<V5T*"1C;VUP;VYE;G1S6R=H;W-T)UTI*2![#0H@("`@
M("`@("`@("`@("`@+R\@<F5M;W9E('1H92!L96%D:6YG("(O(@T*("`@("`@
M("`@("`@("`@("1C;VUP;VYE;G1S6R=P871H)UT@/2!S=6)S='(H)&-O;7!O
M;F5N='-;)W!A=&@G72P@,2D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1C;VUP;VYE;G1S6R=S8VAE;64G72DI('L-"B`@("`@
M("`@("`@("`@("!I9B`H<W1R<&]S*"1C;VUP;VYE;G1S6R=P871H)UTL("<O
M)RD@(3T](&9A;'-E*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@D8V]M
M<&]N96YT<ULG<&%T:"==>S!](#T]("<O)RD@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)W!A<G-E4&%C:V%G
M94YA;64H*3H@=&AI<R!I<R!N;W0@)R`N#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)V$@<&%C:V%G92!N86UE+"!I="!B96=I;G,@=VET:"`B+R(@
M:6X@(B<@+B`D<&%R86T@+B`G(B<L#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VEN=F%L:60G+"!N=6QL+"!N=6QL+"`D<&%R86TI.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1P87)T<R`]
M(&5X<&QO9&4H)R\G+"`D8V]M<&]N96YT<ULG<&%T:"==*3L-"B`@("`@("`@
M("`@("`@("`@("`@)&-O;7!O;F5N='-;)VAO<W0G72`](&%R<F%Y7W-H:69T
M*"1P87)T<RD[#0H@("`@("`@("`@("`@("`@("`@(&EF("AC;W5N="@D<&%R
M=',I(#X@,2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&-O;7!O;F5N
M='-;)W!A=&@G72`](&%R<F%Y7W!O<"@D<&%R=',I.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)&-O;7!O;F5N='-;)VAO<W0G72`N/2`G+R<@+B!I;7!L
M;V1E*"<O)RP@)'!A<G1S*3L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1C;VUP;VYE;G1S6R=P871H
M)UT@/2!I;7!L;V1E*"<O)RP@)'!A<G1S*3L-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@("`@("1C;VUP;VYE;G1S6R=H;W-T)UT@/2`D9&5F875L=&-H86YN96P[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("!I9B`H<W1R<&]S*"1C;VUP;VYE;G1S6R=P871H)UTL
M("<O)RDI('L-"B`@("`@("`@("`@("`@("`@("`@)'!A<G1S(#T@97AP;&]D
M92@G+R<L("1C;VUP;VYE;G1S6R=P871H)UTI.PT*("`@("`@("`@("`@("`@
M("`@("`D8V]M<&]N96YT<ULG<&%T:"==(#T@87)R87E?<&]P*"1P87)T<RD[
M#0H@("`@("`@("`@("`@("`@("`@("1C;VUP;VYE;G1S6R=H;W-T)UT@+CT@
M)R\G("X@:6UP;&]D92@G+R<L("1P87)T<RD[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?0T*#0H@("`@("`@("`@("!I9B`H:7-?87)R87DH
M)'!A<F%M*2D@>PT*("`@("`@("`@("`@("`@("1P87)A;5LG<&%C:V%G92==
M(#T@)&-O;7!O;F5N='-;)W!A=&@G73L-"B`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@)'!A<F%M(#T@87)R87DH#0H@("`@("`@("`@
M("`@("`@("`@("=P86-K86=E)R`]/B`D8V]M<&]N96YT<ULG<&%T:"==#0H@
M("`@("`@("`@("`@("`@("`@("D[#0H@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1C;VUP;VYE;G1S6R=H;W-T)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("1P87)A;5LG8VAA;FYE;"==(#T@)&-O;7!O;F5N='-;)VAO<W0G73L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!I9B`H:7-S970H)&-O;7!O;F5N='-;)V9R86=M96YT)UTI*2![#0H@("`@
M("`@("`@("`@("`@)'!A<F%M6R=G<F]U<"==(#T@)&-O;7!O;F5N='-;)V9R
M86=M96YT)UT[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S
M970H)&-O;7!O;F5N='-;)W5S97(G72DI('L-"B`@("`@("`@("`@("`@("`D
M<&%R86U;)W5S97(G72`]("1C;VUP;VYE;G1S6R=U<V5R)UT[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)&-O;7!O;F5N='-;)W!A
M<W,G72DI('L-"B`@("`@("`@("`@("`@("`D<&%R86U;)W!A<W,G72`]("1C
M;VUP;VYE;G1S6R=P87-S)UT[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!I9B`H:7-S970H)&-O;7!O;F5N='-;)W%U97)Y)UTI*2![#0H@("`@("`@
M("`@("`@("`@<&%R<V5?<W1R*"1C;VUP;VYE;G1S6R=Q=65R>2==+"`D<&%R
M86U;)V]P=',G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`O+R!C
M:&5C:R!F;W(@97AT96YS:6]N#0H@("`@("`@("`@("`D<&%T:&EN9F\@/2!P
M871H:6YF;R@D<&%R86U;)W!A8VMA9V4G72D[#0H@("`@("`@("`@("!I9B`H
M:7-S970H)'!A=&AI;F9O6R=E>'1E;G-I;VXG72D@)B8-"B`@("`@("`@("`@
M("`@("`@(&EN7V%R<F%Y*'-T<G1O;&]W97(H)'!A=&AI;F9O6R=E>'1E;G-I
M;VXG72DL(&%R<F%Y*"=T9WHG+"`G=&%R)RDI*2![#0H@("`@("`@("`@("`@
M("`@)'!A<F%M6R=E>'1E;G-I;VXG72`]("1P871H:6YF;ULG97AT96YS:6]N
M)UT[#0H@("`@("`@("`@("`@("`@)'!A<F%M6R=P86-K86=E)UT@/2!S=6)S
M='(H)'!A=&AI;F9O6R=B87-E;F%M92==+"`P+`T*("`@("`@("`@("`@("`@
M("`@("!S=')L96XH)'!A=&AI;F9O6R=B87-E;F%M92==*2`M(#0I.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@+R\@8VAE8VL@9F]R('9E<G-I;VX-
M"B`@("`@("`@("`@(&EF("AS=')P;W,H)'!A<F%M6R=P86-K86=E)UTL("<M
M)RDI('L-"B`@("`@("`@("`@("`@("`D=&5S="`](&5X<&QO9&4H)RTG+"`D
M<&%R86U;)W!A8VMA9V4G72D[#0H@("`@("`@("`@("`@("`@:68@*&-O=6YT
M*"1T97-T*2`A/2`R*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"=P87)S95!A8VMA9V5.86UE*"DZ(&]N;'D@;VYE
M('9E<G-I;VXO<W1A=&4@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`G
M9&5L:6UI=&5R("(M(B!I<R!A;&QO=V5D(&EN("(G("X@)'-A=F5P87)A;2`N
M("<B)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("=V97)S:6]N)RP@;G5L
M;"P@;G5L;"P@)'!A<F%M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@;&ES="@D<&%R86U;)W!A8VMA9V4G72P@)'!A<F%M6R=V97)S
M:6]N)UTI(#T@)'1E<W0[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@+R\@=F%L:61A=&EO;@T*("`@("`@("`D:6YF;R`]("1T:&ES+3YC
M:&%N;F5L17AI<W1S*"1P87)A;5LG8VAA;FYE;"==*3L-"B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&EN9F\I*2![#0H@("`@("`@("`@("!R971U<FX@
M)&EN9F\[#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D:6YF;RD@>PT*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)W5N:VYO=VX@8VAA
M;FYE;"`B)R`N("1P87)A;5LG8VAA;FYE;"==("X-"B`@("`@("`@("`@("`@
M("`G(B!I;B`B)R`N("1S879E<&%R86T@+B`G(B<L("=C:&%N;F5L)RP@;G5L
M;"P@;G5L;"P@)'!A<F%M*3L-"B`@("`@("`@?0T*("`@("`@("`D8VAA;B`]
M("1T:&ES+3YG971#:&%N;F5L*"1P87)A;5LG8VAA;FYE;"==*3L-"B`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)&-H86XI*2![#0H@("`@("`@("`@("!R
M971U<FX@)&-H86X[#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D8VAA;BD@
M>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D5X8V5P
M=&EO;CH@8V]R<G5P="!R96=I<W1R>2P@8V]U;&0@;F]T("(@+@T*("`@("`@
M("`@("`@("`@(")R971R:65V92!C:&%N;F5L("(@+B`D<&%R86U;)V-H86YN
M96PG72`N("(@:6YF;W)M871I;VXB+`T*("`@("`@("`@("`@("`@("=R96=I
M<W1R>2<L(&YU;&PL(&YU;&PL("1P87)A;2D[#0H@("`@("`@('T-"B`@("`@
M("`@)'!A<F%M6R=C:&%N;F5L)UT@/2`D8VAA;BT^9V5T3F%M92@I.PT*("`@
M("`@("`D=F%L:61A=&4@/2`D8VAA;BT^9V5T5F%L:61A=&EO;D]B:F5C="@I
M.PT*("`@("`@("`D=G!A8VMA9V4@/2`D8VAA;BT^9V5T5F%L:61A=&EO;E!A
M8VMA9V4H*3L-"B`@("`@("`@+R\@=F%L:61A=&4@<&%C:V%G92!N86UE#0H@
M("`@("`@(&EF("@A)'9A;&ED871E+3YV86QI9%!A8VMA9V5.86UE*"1P87)A
M;5LG<&%C:V%G92==+"`D=G!A8VMA9V5;)U]C;VYT96YT)UTI*2![#0H@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G<&%R<V5086-K86=E
M3F%M92@I.B!I;G9A;&ED('!A8VMA9V4@;F%M92`B)R`N#0H@("`@("`@("`@
M("`@("`@)'!A<F%M6R=P86-K86=E)UT@+B`G(B!I;B`B)R`N("1S879E<&%R
M86T@+B`G(B<L#0H@("`@("`@("`@("`@("`@)W!A8VMA9V4G+"!N=6QL+"!N
M=6QL+"`D<&%R86TI.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D
M<&%R86U;)V=R;W5P)UTI*2![#0H@("`@("`@("`@("!I9B`H(5!%05)?5F%L
M:61A=&4Z.G9A;&ED1W)O=7!.86UE*"1P87)A;5LG9W)O=7`G72DI('L-"B`@
M("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G<&%R<V50
M86-K86=E3F%M92@I.B!D97!E;F1E;F-Y(&=R;W5P("(G("X@)'!A<F%M6R=G
M<F]U<"==("X-"B`@("`@("`@("`@("`@("`@("`@)R(@:7,@;F]T(&$@=F%L
M:60@9W)O=7`@;F%M92!I;B`B)R`N("1S879E<&%R86T@+B`G(B<L("=G<F]U
M<"<L(&YU;&PL(&YU;&PL#0H@("`@("`@("`@("`@("`@("`@("1P87)A;2D[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T
M*"1P87)A;5LG<W1A=&4G72DI('L-"B`@("`@("`@("`@(&EF("@A:6Y?87)R
M87DH<W1R=&]L;W=E<B@D<&%R86U;)W-T871E)UTI+"`D=F%L:61A=&4M/F=E
M=%9A;&ED4W1A=&5S*"DI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)W!A<G-E4&%C:V%G94YA;64H*3H@<W1A=&4@(B<@
M+B`D<&%R86U;)W-T871E)UT-"B`@("`@("`@("`@("`@("`@("`@+B`G(B!I
M<R!N;W0@82!V86QI9"!S=&%T92!I;B`B)R`N("1S879E<&%R86T@+B`G(B<L
M#0H@("`@("`@("`@("`@("`@("`@("=S=&%T92<L(&YU;&PL(&YU;&PL("1P
M87)A;2D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@
M*&ES<V5T*"1P87)A;5LG=F5R<VEO;B==*2D@>PT*("`@("`@("`@("`@:68@
M*&ES<V5T*"1P87)A;5LG<W1A=&4G72DI('L-"B`@("`@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G<&%R<V5086-K86=E3F%M92@I.B!C
M86YN;W0@8V]N=&%I;B!B;W1H("<@+@T*("`@("`@("`@("`@("`@("`@("`G
M82!V97)S:6]N(&%N9"!A('-T86)I;&ET>2`H<W1A=&4I(&EN("(G("X@)'-A
M=F5P87)A;2`N("<B)RP-"B`@("`@("`@("`@("`@("`@("`@)W9E<G-I;VXO
M<W1A=&4G+"!N=6QL+"!N=6QL+"`D<&%R86TI.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@+R\@8VAE8VL@=VAE=&AE<B!V97)S:6]N(&ES(&%C='5A
M;&QY(&$@<W1A=&4-"B`@("`@("`@("`@(&EF("AI;E]A<G)A>2AS=')T;VQO
M=V5R*"1P87)A;5LG=F5R<VEO;B==*2P@)'9A;&ED871E+3YG971686QI9%-T
M871E<R@I*2D@>PT*("`@("`@("`@("`@("`@("1P87)A;5LG<W1A=&4G72`]
M('-T<G1O;&]W97(H)'!A<F%M6R=V97)S:6]N)UTI.PT*("`@("`@("`@("`@
M("`@('5N<V5T*"1P87)A;5LG=F5R<VEO;B==*3L-"B`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@:68@*"$D=F%L:61A=&4M/G9A;&ED
M5F5R<VEO;B@D<&%R86U;)W9E<G-I;VXG72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)W!A<G-E4&%C:V%G94YA
M;64H*3H@(B<@+B`D<&%R86U;)W9E<G-I;VXG72`N#0H@("`@("`@("`@("`@
M("`@("`@("`@("`G(B!I<R!N96ET:&5R(&$@=F%L:60@=F5R<VEO;B!N;W(@
M82!V86QI9"!S=&%T92!I;B`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D<V%V97!A<F%M("X@)R(G+"`G=F5R<VEO;B]S=&%T92<L(&YU;&PL(&YU
M;&PL("1P87)A;2D[#0H@("`@("`@("`@("`@("`@?2`@("`@("`@("`@("`@
M("`@("`@#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T
M=7)N("1P87)A;3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@
M87)R87D-"B`@("`@*B!`<F5T=7)N('-T<FEN9PT*("`@("`J+PT*("`@(&9U
M;F-T:6]N('!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H)'!A<G-E9"P@)&)R
M:65F(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H:7-?<W1R:6YG*"1P
M87)S960I*2![#0H@("`@("`@("`@("!R971U<FX@)'!A<G-E9#L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H:7-?;V)J96-T*"1P87)S960I*2![#0H@("`@
M("`@("`@("`D<"`]("1P87)S960[#0H@("`@("`@("`@("`D<&%R<V5D(#T@
M87)R87DH#0H@("`@("`@("`@("`@("`@)W!A8VMA9V4G(#T^("1P+3YG9710
M86-K86=E*"DL#0H@("`@("`@("`@("`@("`@)V-H86YN96PG(#T^("1P+3YG
M971#:&%N;F5L*"DL#0H@("`@("`@("`@("`@("`@)W9E<G-I;VXG(#T^("1P
M+3YG971697)S:6]N*"DL#0H@("`@("`@("`@("`I.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("AI<W-E="@D<&%R<V5D6R=U<FDG72DI('L-"B`@("`@("`@
M("`@(')E='5R;B`D<&%R<V5D6R=U<FDG73L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H)&)R:65F*2![#0H@("`@("`@("`@("!I9B`H)&-H86YN96P@/2`D
M=&AI<RT^8VAA;FYE;$%L:6%S*"1P87)S961;)V-H86YN96PG72DI('L-"B`@
M("`@("`@("`@("`@("!R971U<FX@)&-H86YN96P@+B`G+R<@+B`D<&%R<V5D
M6R=P86-K86=E)UT[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@)'5P87-S(#T@)R<[#0H@("`@("`@(&EF("AI<W-E="@D<&%R<V5D6R=U
M<V5R)UTI*2![#0H@("`@("`@("`@("`D=7!A<W,@/2`D<&%R<V5D6R=U<V5R
M)UT[#0H@("`@("`@("`@("!I9B`H:7-S970H)'!A<G-E9%LG<&%S<R==*2D@
M>PT*("`@("`@("`@("`@("`@("1U<&%S<R`N/2`G.B<@+B`D<&%R<V5D6R=P
M87-S)UT[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D=7!A<W,@/2`B
M)'5P87-S0"([#0H@("`@("`@('T-"B`@("`@("`@)')E="`]("=C:&%N;F5L
M.B\O)R`N("1U<&%S<R`N("1P87)S961;)V-H86YN96PG72`N("<O)R`N("1P
M87)S961;)W!A8VMA9V4G73L-"B`@("`@("`@:68@*&ES<V5T*"1P87)S961;
M)W9E<G-I;VXG72D@?'P@:7-S970H)'!A<G-E9%LG<W1A=&4G72DI('L-"B`@
M("`@("`@("`@("1R970@+CT@)RTG("X@0"1P87)S961;)W9E<G-I;VXG72`N
M($`D<&%R<V5D6R=S=&%T92==.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI
M<W-E="@D<&%R<V5D6R=E>'1E;G-I;VXG72DI('L-"B`@("`@("`@("`@("1R
M970@+CT@)RXG("X@)'!A<G-E9%LG97AT96YS:6]N)UT[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*&ES<V5T*"1P87)S961;)V]P=',G72DI('L-"B`@("`@
M("`@("`@("1R970@+CT@)S\G.PT*("`@("`@("`@("`@9F]R96%C:"`H)'!A
M<G-E9%LG;W!T<R==(&%S("1N86UE(#T^("1V86QU92D@>PT*("`@("`@("`@
M("`@("`@("1P87)S961;)V]P=',G75LD;F%M95T@/2`B)&YA;64])'9A;'5E
M(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1R970@+CT@:6UP;&]D
M92@G)B<L("1P87)S961;)V]P=',G72D[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&ES<V5T*"1P87)S961;)V=R;W5P)UTI*2![#0H@("`@("`@("`@("`D
M<F5T("X]("<C)R`N("1P87)S961;)V=R;W5P)UT[#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*?0T*#0H_/@T*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O4D535"YP:'``````
M````````````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,S4T-C$@
M,3`U,34T,S,W,S(@,#(P-3$S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP#0HO*BH-"B`J(%!%05)?4D535`T*("H-
M"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H
M92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I
M9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A
M;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P
M;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W
M92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C
M871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H
M;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y
M<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@
M("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC
M96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!215-4+G!H<"QV
M(#$N,C`@,C`P-B\P,R\P,B`P,SHP.3HS,2!P86IO>64@17AP("0-"B`J($!L
M:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@
M*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N
M-"XP83$-"B`J+PT*#0HO*BH-"B`J($9O<B!D;W=N;&]A9&EN9R!X;6P@9FEL
M97,-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2+G!H<"<[#0IR97%U:7)E7V]N
M8V4@)U!%05(O6$U,4&%R<V5R+G!H<"<[#0H-"B\J*@T*("H@26YT96QL:6=E
M;G1L>2!R971R:65V92!D871A+"!F;VQL;W=I;F<@:'EP97)L:6YK<R!I9B!N
M96-E<W-A<GDL(&%N9"!R92UD:7)E8W1I;F<-"B`J(&%S('=E;&P-"B`J($!C
M871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H
M;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y
M<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@
M("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC
M96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`
M;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*
M("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@
M,2XT+C!A,0T*("HO#0IC;&%S<R!014%27U)%4U0-"GL-"B`@("!V87(@)&-O
M;F9I9SL-"B`@("!V87(@)%]O<'1I;VYS.PT*("`@(&9U;F-T:6]N(%!%05)?
M4D535"@F)&-O;F9I9RP@)&]P=&EO;G,@/2!A<G)A>2@I*0T*("`@('L-"B`@
M("`@("`@)'1H:7,M/F-O;F9I9R`]("8D8V]N9FEG.PT*("`@("`@("`D=&AI
M<RT^7V]P=&EO;G,@/2`D;W!T:6]N<SL-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!2971R:65V92!215-4(&1A=&$L(&)U="!A;'=A>7,@<F5T<FEE=F4@
M=&AE(&QO8V%L(&-A8VAE(&EF(&ET(&ES(&%V86EL86)L92X-"B`@("`@*@T*
M("`@("`J(%1H:7,@:7,@=7-E9G5L(&9O<B!E;&5M96YT<R!T:&%T('-H;W5L
M9"!N979E<B!C:&%N9V4L('-U8V@@87,@:6YF;W)M871I;VX@;VX@82!P87)T
M:6-U;&%R#0H@("`@("H@<F5L96%S90T*("`@("`J($!P87)A;2!S=')I;F<@
M9G5L;"!54DP@=&\@=&AI<R!R97-O=7)C90T*("`@("`J($!P87)A;2!A<G)A
M>7QF86QS92!C;VYT96YT<R!O9B!T:&4@86-C97!T+65N8V]D:6YG(&AE861E
M<@T*("`@("`J($!P87)A;2!B;V]L96%N("`@("!I9B!T<G5E+"!X;6P@=VEL
M;"!B92!R971U<FYE9"!A<R!A('-T<FEN9RP@;W1H97)W:7-E+"!X;6P@=VEL
M;"!B90T*("`@("`J("`@("`@("`@("`@("`@("`@("!P87)S960@=7-I;F<@
M4$5!4E]834Q087)S97(-"B`@("`@*B!`<F5T=7)N('-T<FEN9WQA<G)A>0T*
M("`@("`J+PT*("`@(&9U;F-T:6]N(')E=')I979E0V%C:&5&:7)S="@D=7)L
M+"`D86-C97!T(#T@9F%L<V4L("1F;W)C97-T<FEN9R`](&9A;'-E*0T*("`@
M('L-"B`@("`@("`@)&-A8VAE9FEL92`]("1T:&ES+3YC;VYF:6<M/F=E="@G
M8V%C:&5?9&ER)RD@+B!$25)%0U1/4EE?4T5005)!5$]2("X-"B`@("`@("`@
M("`@(&UD-2@D=7)L*2`N("=R97-T+F-A8VAE9FEL92<[#0H@("`@("`@(&EF
M("A`9FEL95]E>&ES=',H)&-A8VAE9FEL92DI('L-"B`@("`@("`@("`@(')E
M='5R;B!U;G-E<FEA;&EZ92AI;7!L;V1E*"<G+"!F:6QE*"1C86-H969I;&4I
M*2D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1T:&ES+3YR971R:65V
M941A=&$H)'5R;"P@)&%C8V5P="P@)&9O<F-E<W1R:6YG*3L-"B`@("!]#0H-
M"B`@("`O*BH-"B`@("`@*B!2971R:65V92!A(')E;6]T92!215-4(')E<V]U
M<F-E#0H@("`@("H@0'!A<F%M('-T<FEN9R!F=6QL(%523"!T;R!T:&ES(')E
M<V]U<F-E#0H@("`@("H@0'!A<F%M(&%R<F%Y?&9A;'-E(&-O;G1E;G1S(&]F
M('1H92!A8V-E<'0M96YC;V1I;F<@:&5A9&5R#0H@("`@("H@0'!A<F%M(&)O
M;VQE86X@("`@(&EF('1R=64L('AM;"!W:6QL(&)E(')E='5R;F5D(&%S(&$@
M<W1R:6YG+"!O=&AE<G=I<V4L('AM;"!W:6QL(&)E#0H@("`@("H@("`@("`@
M("`@("`@("`@("`@('!A<G-E9"!U<VEN9R!014%27UA-3%!A<G-E<@T*("`@
M("`J($!R971U<FX@<W1R:6YG?&%R<F%Y#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@<F5T<FEE=F5$871A*"1U<FPL("1A8V-E<'0@/2!F86QS92P@)&9O<F-E
M<W1R:6YG(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D8V%C:&5)9"`]("1T
M:&ES+3YG971#86-H94ED*"1U<FPI.PT*("`@("`@("!I9B`H)')E="`]("1T
M:&ES+3YU<V5,;V-A;$-A8VAE*"1U<FPL("1C86-H94ED*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1R970[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I
M<W-E="@D=&AI<RT^7V]P=&EO;G-;)V]F9FQI;F4G72DI('L-"B`@("`@("`@
M("`@("1T<FEE9&1O=VYL;V%D(#T@=')U93L-"B`@("`@("`@("`@("1F:6QE
M(#T@)'1H:7,M/F1O=VYL;V%D2'1T<"@D=7)L+"`D8V%C:&5)9"`_("1C86-H
M94ED6R=L87-T0VAA;F=E)UT@.B!F86QS92P@)&%C8V5P="D[#0H@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`D=')I961D;W=N;&]A9"`](&9A;'-E
M.PT*("`@("`@("`@("`@)&9I;&4@/2!F86QS93L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D9FEL92DI('L-"B`@("`@("`@("`@
M(&EF("@D9FEL92T^9V5T0V]D92@I(#T]("TY,C<V*2![#0H@("`@("`@("`@
M("`@("`@)'1R:65D9&]W;FQO860@/2!F86QS93L-"B`@("`@("`@("`@("`@
M("`D9FEL92`](&9A;'-E.R`O+R!U<V4@;&]C86P@8V]P>2!I9B!A=F%I;&%B
M;&4@;VX@<V]C:V5T(&-O;FYE8W0@97)R;W(-"B`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1F:6QE.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@A)&9I;&4I('L-"B`@("`@
M("`@("`@("1R970@/2`D=&AI<RT^9V5T0V%C:&4H)'5R;"D[#0H@("`@("`@
M("`@("!I9B`H(5!%05(Z.FES17)R;W(H)')E="D@)B8@)'1R:65D9&]W;FQO
M860I('L-"B`@("`@("`@("`@("`@("`O+R!R97-E="!T:&4@86=E(&]F('1H
M92!C86-H92!I9B!T:&4@<V5R=F5R('-A>7,@:70@=V%S('5N;6]D:69I960-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<V%V94-A8VAE*"1U<FPL("1R970L
M(&YU;&PL('1R=64L("1C86-H94ED*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(')E='5R;B`D<F5T.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI
M<U]A<G)A>2@D9FEL92DI('L-"B`@("`@("`@("`@("1H96%D97)S(#T@)&9I
M;&5;,ET[#0H@("`@("`@("`@("`D;&%S=&UO9&EF:65D(#T@)&9I;&5;,5T[
M#0H@("`@("`@("`@("`D8V]N=&5N="`]("1F:6QE6S!=.PT*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@)&-O;G1E;G0@/2`D9FEL93L-"B`@("`@
M("`@("`@("1L87-T;6]D:69I960@/2!F86QS93L-"B`@("`@("`@("`@("1H
M96%D97)S(#T@87)R87DH*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&9O
M<F-E<W1R:6YG*2![#0H@("`@("`@("`@("`D=&AI<RT^<V%V94-A8VAE*"1U
M<FPL("1C;VYT96YT+"`D;&%S=&UO9&EF:65D+"!F86QS92P@)&-A8VAE260I
M.PT*("`@("`@("`@("`@<F5T=7)N("1C;VYT96YT.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("AI<W-E="@D:&5A9&5R<ULG8V]N=&5N="UT>7!E)UTI*2![
M#0H@("`@("`@("`@("!S=VET8V@@*"1H96%D97)S6R=C;VYT96YT+71Y<&4G
M72D@>PT*("`@("`@("`@("`@("`@(&-A<V4@)W1E>'0O>&UL)R`Z#0H@("`@
M("`@("`@("`@("`@8V%S92`G87!P;&EC871I;VXO>&UL)R`Z#0H@("`@("`@
M("`@("`@("`@("`@("1P87)S97(@/2!N97<@4$5!4E]834Q087)S97([#0H@
M("`@("`@("`@("`@("`@("`@(%!%05(Z.G!U<VA%<G)O<DAA;F1L:6YG*%!%
M05)?15)23U)?4D5455).*3L-"B`@("`@("`@("`@("`@("`@("`@)&5R<B`]
M("1P87)S97(M/G!A<G-E*"1C;VYT96YT*3L-"B`@("`@("`@("`@("`@("`@
M("`@4$5!4CHZ<&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TEN=F%L:60@
M>&UL(&1O=VYL;V%D960@9G)O;2`B)R`N("1U<FP@+B`G(CH@)R`N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&5R<BT^9V5T365S<V%G92@I*3L-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D
M8V]N=&5N="`]("1P87)S97(M/F=E=$1A=&$H*3L-"B`@("`@("`@("`@("`@
M("!C87-E("=T97AT+VAT;6PG(#H-"B`@("`@("`@("`@("`@("!D969A=6QT
M(#H-"B`@("`@("`@("`@("`@("`@("`@+R\@=7-E(&ET(&%S(&$@<W1R:6YG
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`O+R!A<W-U;64@6$U,#0H@("`@("`@("`@("`D<&%R<V5R(#T@;F5W(%!%
M05)?6$U,4&%R<V5R.PT*("`@("`@("`@("`@)'!A<G-E<BT^<&%R<V4H)&-O
M;G1E;G0I.PT*("`@("`@("`@("`@)&-O;G1E;G0@/2`D<&%R<V5R+3YG971$
M871A*"D[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/G-A=F5#86-H92@D
M=7)L+"`D8V]N=&5N="P@)&QA<W1M;V1I9FEE9"P@9F%L<V4L("1C86-H94ED
M*3L-"B`@("`@("`@<F5T=7)N("1C;VYT96YT.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N('5S94QO8V%L0V%C:&4H)'5R;"P@)&-A8VAE:60@/2!N=6QL*0T*
M("`@('L-"B`@("`@("`@:68@*"1C86-H96ED(#T]/2!N=6QL*2![#0H@("`@
M("`@("`@("`D8V%C:&5I9&9I;&4@/2`D=&AI<RT^8V]N9FEG+3YG970H)V-A
M8VAE7V1I<B<I("X@1$E214-43U)97U-%4$%2051/4B`N#0H@("`@("`@("`@
M("`@("`@;60U*"1U<FPI("X@)W)E<W0N8V%C:&5I9"<[#0H@("`@("`@("`@
M("!I9B`H0&9I;&5?97AI<W1S*"1C86-H96ED9FEL92DI('L-"B`@("`@("`@
M("`@("`@("`D8V%C:&5I9"`]('5N<V5R:6%L:7IE*&EM<&QO9&4H)R<L(&9I
M;&4H)&-A8VAE:61F:6QE*2DI.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("`@("`@)&-A8VAE='1L(#T@)'1H:7,M/F-O;F9I9RT^
M9V5T*"=C86-H95]T=&PG*3L-"B`@("`@("`@+R\@268@8V%C:&4@:7,@;F5W
M97(@=&AA;B`D8V%C:&5T=&P@<V5C;VYD<RP@=V4@=7-E('1H92!C86-H92$-
M"B`@("`@("`@:68@*'1I;64H*2`M("1C86-H96ED6R=A9V4G72`\("1C86-H
M971T;"D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YG971#86-H92@D
M=7)L*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@9V5T0V%C:&5)9"@D=7)L*0T*("`@('L-"B`@
M("`@("`@)&-A8VAE:61F:6QE(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=C86-H
M95]D:7(G*2`N($1)4D5#5$]265]315!!4D%43U(@+@T*("`@("`@("`@("`@
M;60U*"1U<FPI("X@)W)E<W0N8V%C:&5I9"<[#0H@("`@("`@(&EF("A`9FEL
M95]E>&ES=',H)&-A8VAE:61F:6QE*2D@>PT*("`@("`@("`@("`@)')E="`]
M('5N<V5R:6%L:7IE*&EM<&QO9&4H)R<L(&9I;&4H)&-A8VAE:61F:6QE*2DI
M.PT*("`@("`@("`@("`@<F5T=7)N("1R970[#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!G971#86-H92@D=7)L*0T*("`@('L-"B`@("`@
M("`@)&-A8VAE9FEL92`]("1T:&ES+3YC;VYF:6<M/F=E="@G8V%C:&5?9&ER
M)RD@+B!$25)%0U1/4EE?4T5005)!5$]2("X-"B`@("`@("`@("`@(&UD-2@D
M=7)L*2`N("=R97-T+F-A8VAE9FEL92<[#0H@("`@("`@(&EF("A`9FEL95]E
M>&ES=',H)&-A8VAE9FEL92DI('L-"B`@("`@("`@("`@(')E='5R;B!U;G-E
M<FEA;&EZ92AI;7!L;V1E*"<G+"!F:6QE*"1C86-H969I;&4I*2D[#0H@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@G3F\@8V%C:&5D(&-O;G1E;G0@879A:6QA8FQE(&9O<B`B)R`N("1U
M<FP@+B`G(B<I.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@0'!A<F%M('-T<FEN9R!F=6QL(%523"!T;R!215-4(')E<V]U<F-E#0H@
M("`@("H@0'!A<F%M('-T<FEN9R!O<FEG:6YA;"!C;VYT96YT<R!O9B!T:&4@
M4D535"!R97-O=7)C90T*("`@("`J($!P87)A;2!A<G)A>2`@2%144"!,87-T
M+4UO9&EF:65D(&%N9"!%5&%G(&AE861E<G,-"B`@("`@*B!`<&%R86T@8F]O
M;"`@(&EF('1R=64L('1H96X@=&AE(&-A8VAE(&ED(&9I;&4@<VAO=6QD(&)E
M(')E9V5N97)A=&5D('1O#0H@("`@("H@("`@("`@("`@("`@("!T<FEG9V5R
M(&$@;F5W('1I;64M=&\M;&EV92!V86QU90T*("`@("`J+PT*("`@(&9U;F-T
M:6]N('-A=F5#86-H92@D=7)L+"`D8V]N=&5N=',L("1L87-T;6]D:69I960L
M("1N;V-H86YG92`](&9A;'-E+"`D8V%C:&5I9"`](&YU;&PI#0H@("`@>PT*
M("`@("`@("`D8V%C:&5I9&9I;&4@/2`D=&AI<RT^8V]N9FEG+3YG970H)V-A
M8VAE7V1I<B<I("X@1$E214-43U)97U-%4$%2051/4B`N#0H@("`@("`@("`@
M("!M9#4H)'5R;"D@+B`G<F5S="YC86-H96ED)SL-"B`@("`@("`@)&-A8VAE
M9FEL92`]("1T:&ES+3YC;VYF:6<M/F=E="@G8V%C:&5?9&ER)RD@+B!$25)%
M0U1/4EE?4T5005)!5$]2("X-"B`@("`@("`@("`@(&UD-2@D=7)L*2`N("=R
M97-T+F-A8VAE9FEL92<[#0H@("`@("`@(&EF("@D8V%C:&5I9"`]/3T@;G5L
M;"`F)B`D;F]C:&%N9V4I('L-"B`@("`@("`@("`@("1C86-H96ED(#T@=6YS
M97)I86QI>F4H:6UP;&]D92@G)RP@9FEL92@D8V%C:&5I9&9I;&4I*2D[#0H@
M("`@("`@('T-"@T*("`@("`@("`D9G`@/2!`9F]P96XH)&-A8VAE:61F:6QE
M+"`G=V(G*3L-"B`@("`@("`@:68@*"$D9G`I('L-"B`@("`@("`@("`@("1C
M86-H95]D:7(@/2`D=&AI<RT^8V]N9FEG+3YG970H)V-A8VAE7V1I<B<I.PT*
M("`@("`@("`@("`@:68@*"%I<U]D:7(H)&-A8VAE7V1I<BDI('L-"B`@("`@
M("`@("`@("`@("!3>7-T96TZ.FUK9&ER*&%R<F%Y*"<M<"<L("1C86-H95]D
M:7(I*3L-"B`@("`@("`@("`@("`@("`D9G`@/2!`9F]P96XH)&-A8VAE:61F
M:6QE+"`G=V(G*3L-"B`@("`@("`@("`@("`@("!I9B`H(21F<"D@>PT*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"@T*("`@
M("`@("!I9B`H)&YO8VAA;F=E*2![#0H@("`@("`@("`@("!F=W)I=&4H)&9P
M+"!S97)I86QI>F4H87)R87DH#0H@("`@("`@("`@("`@("`@)V%G92<@("`@
M("`@(#T^('1I;64H*2P-"B`@("`@("`@("`@("`@("`G;&%S=$-H86YG92<@
M/3X@)&-A8VAE:61;)VQA<W1#:&%N9V4G72P-"B`@("`@("`@("`@("`@("`I
M*2D[#0H@("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@("`@(')E
M='5R;B!T<G5E.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@9G=R
M:71E*"1F<"P@<V5R:6%L:7IE*&%R<F%Y*`T*("`@("`@("`@("`@("`@("=A
M9V4G("`@("`@("`]/B!T:6UE*"DL#0H@("`@("`@("`@("`@("`@)VQA<W1#
M:&%N9V4G(#T^("1L87-T;6]D:69I960L#0H@("`@("`@("`@("`@("`@*2DI
M.PT*("`@("`@("!]#0H@("`@("`@(&9C;&]S92@D9G`I.PT*("`@("`@("`D
M9G`@/2!`9F]P96XH)&-A8VAE9FEL92P@)W=B)RD[#0H@("`@("`@(&EF("@A
M)&9P*2![#0H@("`@("`@("`@("!`=6YL:6YK*"1C86-H96ED9FEL92D[#0H@
M("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@
M9G=R:71E*"1F<"P@<V5R:6%L:7IE*"1C;VYT96YT<RDI.PT*("`@("`@("!F
M8VQO<V4H)&9P*3L-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@169F:6-I96YT;'D@1&]W;FQO860@82!F:6QE('1H
M<F]U9V@@2%144"X@(%)E='5R;G,@9&]W;FQO861E9"!F:6QE(&%S(&$@<W1R
M:6YG(&EN+6UE;6]R>0T*("`@("`J(%1H:7,@:7,@8F5S="!U<V5D(&9O<B!S
M;6%L;"!F:6QE<PT*("`@("`J#0H@("`@("H@268@86X@2%144"!P<F]X>2!H
M87,@8F5E;B!C;VYF:6=U<F5D("AH='1P7W!R;WAY(%!%05)?0V]N9FEG#0H@
M("`@("H@<V5T=&EN9RDL('1H92!P<F]X>2!W:6QL(&)E('5S960N#0H@("`@
M("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("`D=7)L("`@("`@('1H92!54DP@
M=&\@9&]W;FQO860-"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<V%V95]D:7(@
M(&1I<F5C=&]R>2!T;R!S879E(&9I;&4@:6X-"B`@("`@*B!`<&%R86T@9F%L
M<V5\<W1R:6YG?&%R<F%Y("1L87-T;6]D:69I960@:&5A9&5R('9A;'5E<R!T
M;R!C:&5C:R!A9V%I;G-T(&9O<B!C86-H:6YG#0H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("!U<V4@9F%L<V4@=&\@<F5T=7)N('1H92!H96%D
M97(@=F%L=65S(&9R;VT@=&AI<R!D;W=N;&]A9`T*("`@("`J($!P87)A;2!F
M86QS97QA<G)A>2`D86-C97!T($%C8V5P="!H96%D97)S('1O('-E;F0-"B`@
M("`@*B!`<F5T=7)N('-T<FEN9WQA<G)A>2`@4F5T=7)N<R!T:&4@8V]N=&5N
M=',@;V8@=&AE(&1O=VYL;V%D960@9FEL92!O<B!A(%!%05(-"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@97)R;W(@;VX@9F%I;'5R92X@($EF('1H
M92!E<G)O<B!I<R!C875S960@8GD-"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@<V]C:V5T+7)E;&%T960@97)R;W)S+"!T:&4@97)R;W(@;V)J96-T
M('=I;&P-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@:&%V92!T:&4@
M9G-O8VMO<&5N(&5R<F]R(&-O9&4@879A:6QA8FQE('1H<F]U9V@-"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@9V5T0V]D92@I+B`@268@8V%C:&EN
M9R!I<R!R97%U97-T960L('1H96X@<F5T=7)N('1H92!H96%D97(-"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@=F%L=65S+@T*("`@("`J#0H@("`@
M("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!D;W=N
M;&]A9$AT='`H)'5R;"P@)&QA<W1M;V1I9FEE9"`](&YU;&PL("1A8V-E<'0@
M/2!F86QS92D-"B`@("![#0H@("`@("`@("1I;F9O(#T@<&%R<V5?=7)L*"1U
M<FPI.PT*("`@("`@("!I9B`H(6ES<V5T*"1I;F9O6R=S8VAE;64G72D@?'P@
M(6EN7V%R<F%Y*"1I;F9O6R=S8VAE;64G72P@87)R87DH)VAT='`G+"`G:'1T
M<',G*2DI('L-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"=#86YN;W0@9&]W;FQO860@;F]N+6AT='`@55),("(G("X@)'5R;"`N("<B
M)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<W-E="@D:6YF;ULG:&]S
M="==*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)T-A;FYO="!D;W=N;&]A9"!F<F]M(&YO;BU54DP@(B<@+B`D=7)L("X@)R(G
M*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1H;W-T(#T@)&EN
M9F];)VAO<W0G73L-"B`@("`@("`@("`@(&EF("@A87)R87E?:V5Y7V5X:7-T
M<R@G<&]R="<L("1I;F9O*2D@>PT*("`@("`@("`@("`@("`@("1I;F9O6R=P
M;W)T)UT@/2!N=6QL.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@
M*"%A<G)A>5]K97E?97AI<W1S*"=P871H)RP@)&EN9F\I*2![#0H@("`@("`@
M("`@("`@("`@)&EN9F];)W!A=&@G72`](&YU;&P[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`D<&]R="`]("1I;F9O6R=P;W)T)UT[#0H@("`@("`@
M("`@("`D<&%T:"`]("1I;F9O6R=P871H)UT[#0H@("`@("`@('T-"B`@("`@
M("`@)'!R;WAY7VAO<W0@/2`D<')O>'E?<&]R="`]("1P<F]X>5]U<V5R(#T@
M)'!R;WAY7W!A<W,@/2`G)SL-"B`@("`@("`@:68@*"1T:&ES+3YC;VYF:6<M
M/F=E="@G:'1T<%]P<F]X>2<I)B8@#0H@("`@("`@("`@("`@("1P<F]X>2`]
M('!A<G-E7W5R;"@D=&AI<RT^8V]N9FEG+3YG970H)VAT='!?<')O>'DG*2DI
M('L-"B`@("`@("`@("`@("1P<F]X>5]H;W-T(#T@0"1P<F]X>5LG:&]S="==
M.PT*("`@("`@("`@("`@:68@*&ES<V5T*"1P<F]X>5LG<V-H96UE)UTI("8F
M("1P<F]X>5LG<V-H96UE)UT@/3T@)VAT='!S)RD@>PT*("`@("`@("`@("`@
M("`@("1P<F]X>5]H;W-T(#T@)W-S;#HO+R<@+B`D<')O>'E?:&]S=#L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("1P<F]X>5]P;W)T(#T@0"1P<F]X
M>5LG<&]R="==.PT*("`@("`@("`@("`@)'!R;WAY7W5S97(@/2!`)'!R;WAY
M6R=U<V5R)UT[#0H@("`@("`@("`@("`D<')O>'E?<&%S<R`]($`D<')O>'E;
M)W!A<W,G73L-"@T*("`@("`@("`@("`@:68@*"1P<F]X>5]P;W)T(#T]("<G
M*2![#0H@("`@("`@("`@("`@("`@)'!R;WAY7W!O<G0@/2`X,#@P.PT*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AE;7!T>2@D<&]R
M="DI('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D:6YF;ULG<V-H96UE)UTI
M("8F("1I;F9O6R=S8VAE;64G72`]/2`G:'1T<',G*2![#0H@("`@("`@("`@
M("`@("`@)'!O<G0@/2`T-#,[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("1P;W)T(#T@.#`[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@268@*&ES<V5T*"1P<F]X>5LG:&]S="==*2D@>PT*
M("`@("`@("`@("`@)')E<75E<W0@/2`B1T54("1U<FP@2%144"\Q+C%<<EQN
M(CL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1R97%U97-T(#T@
M(D=%5"`D<&%T:"!(5%10+S$N,5QR7&XB.PT*("`@("`@("!]#0H-"B`@("`@
M("`@)&EF;6]D:69I961S:6YC92`]("<G.PT*("`@("`@("!I9B`H:7-?87)R
M87DH)&QA<W1M;V1I9FEE9"DI('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D
M;&%S=&UO9&EF:65D6R=,87-T+4UO9&EF:65D)UTI*2![#0H@("`@("`@("`@
M("`@("`@)&EF;6]D:69I961S:6YC92`]("=)9BU-;V1I9FEE9"U3:6YC93H@
M)R`N("1L87-T;6]D:69I961;)TQA<W0M36]D:69I960G72`N(")<<EQN(CL-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D;&%S=&UO
M9&EF:65D6R=%5&%G)UTI*2![#0H@("`@("`@("`@("`@("`@)&EF;6]D:69I
M961S:6YC92`N/2`B268M3F]N92U-871C:#H@)&QA<W1M;V1I9FEE9%M%5&%G
M75QR7&XB.PT*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@)&EF;6]D:69I961S:6YC92`]("@D;&%S=&UO9&EF:65D(#\@
M(DEF+4UO9&EF:65D+5-I;F-E.B`D;&%S=&UO9&EF:65D7')<;B(@.B`G)RD[
M#0H@("`@("`@('T-"B`@("`@("`@)')E<75E<W0@+CT@(DAO<W0Z("1H;W-T
M.B1P;W)T7')<;B(@+B`D:69M;V1I9FEE9'-I;F-E("X-"B`@("`@("`@("`@
M(")5<V5R+4%G96YT.B!014%2+S$N-"XY+U!(4"\B("X@4$A07U9%4E-)3TX@
M+B`B7')<;B([#0H@("`@("`@("1U<V5R;F%M92`]("1T:&ES+3YC;VYF:6<M
M/F=E="@G=7-E<FYA;64G*3L-"B`@("`@("`@)'!A<W-W;W)D(#T@)'1H:7,M
M/F-O;F9I9RT^9V5T*"=P87-S=V]R9"<I.PT*("`@("`@("!I9B`H)'5S97)N
M86UE("8F("1P87-S=V]R9"D@>PT*("`@("`@("`@("`@)'1M<"`](&)A<V4V
M-%]E;F-O9&4H(B1U<V5R;F%M93HD<&%S<W=O<F0B*3L-"B`@("`@("`@("`@
M("1R97%U97-T("X](")!=71H;W)I>F%T:6]N.B!"87-I8R`D=&UP7')<;B([
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"1P<F]X>5]H;W-T("$]("<G("8F
M("1P<F]X>5]U<V5R("$]("<G*2![#0H@("`@("`@("`@("`D<F5Q=65S="`N
M/2`G4')O>'DM075T:&]R:7IA=&EO;CH@0F%S:6,@)R`N#0H@("`@("`@("`@
M("`@("`@8F%S938T7V5N8V]D92@D<')O>'E?=7-E<B`N("<Z)R`N("1P<F]X
M>5]P87-S*2`N(")<<EQN(CL-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&%C
M8V5P="D@>PT*("`@("`@("`@("`@)')E<75E<W0@+CT@)T%C8V5P=#H@)R`N
M(&EM<&QO9&4H)RP@)RP@)&%C8V5P="D@+B`B7')<;B([#0H@("`@("`@('T-
M"B`@("`@("`@)')E<75E<W0@+CT@(D-O;FYE8W1I;VXZ(&-L;W-E7')<;B([
M#0H@("`@("`@("1R97%U97-T("X](")<<EQN(CL-"B`@("`@("`@:68@*"1P
M<F]X>5]H;W-T("$]("<G*2![#0H@("`@("`@("`@("`D9G`@/2!`9G-O8VMO
M<&5N*"1P<F]X>5]H;W-T+"`D<')O>'E?<&]R="P@)&5R<FYO+"`D97)R<W1R
M+"`Q-2D[#0H@("`@("`@("`@("!I9B`H(21F<"D@>PT*("`@("`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")#;VYN96-T:6]N('1O(&`D
M<')O>'E?:&]S=#HD<')O>'E?<&]R="<@9F%I;&5D.B`D97)R<W1R(BP-"B`@
M("`@("`@("`@("`@("`@("`@+3DR-S8I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1I;F9O6R=S
M8VAE;64G72D@)B8@)&EN9F];)W-C:&5M92==(#T]("=H='1P<R<I('L-"B`@
M("`@("`@("`@("`@("`D:&]S="`]("=S<VPZ+R\G("X@)&AO<W0[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`D9G`@/2!`9G-O8VMO<&5N*"1H;W-T
M+"`D<&]R="P@)&5R<FYO+"`D97)R<W1R*3L-"B`@("`@("`@("`@(&EF("@A
M)&9P*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H(D-O;FYE8W1I;VX@=&\@8"1H;W-T.B1P;W)T)R!F86EL960Z("1E<G)S
M='(B+"`D97)R;F\I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@(&9W<FET92@D9G`L("1R97%U97-T*3L-"B`@("`@("`@)&AE861E<G,@
M/2!A<G)A>2@I.PT*("`@("`@("!W:&EL92`H=')I;2@D;&EN92`](&9G971S
M*"1F<"P@,3`R-"DI*2![#0H@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G
M+UXH6UXZ72LI.EQS*R@N*BE<<RHD+R<L("1L:6YE+"`D;6%T8VAE<RDI('L-
M"B`@("`@("`@("`@("`@("`D:&5A9&5R<UMS=')T;VQO=V5R*"1M871C:&5S
M6S%=*5T@/2!T<FEM*"1M871C:&5S6S)=*3L-"B`@("`@("`@("`@('T@96QS
M96EF("AP<F5G7VUA=&-H*"=\7DA45%`O,2Y;,#%=("A;,"TY77LS?2D@?"<L
M("1L:6YE+"`D;6%T8VAE<RDI('L-"B`@("`@("`@("`@("`@("!I9B`H)&UA
M=&-H97-;,5T@/3T@,S`T("8F("@D;&%S=&UO9&EF:65D('Q\("@D;&%S=&UO
M9&EF:65D(#T]/2!F86QS92DI*2![#0H@("`@("`@("`@("`@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@:68@*"1M871C:&5S6S%=("$](#(P,"D@>PT*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B1FEL92!H='1P.B\O)&AO
M<W0Z)'!O<G0D<&%T:"!N;W0@=F%L:60@*')E8V5I=F5D.B`D;&EN92DB+"`H
M:6YT*2`D;6%T8VAE<ULQ72D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D:&5A9&5R
M<ULG8V]N=&5N="UL96YG=&@G72DI('L-"B`@("`@("`@("`@("1L96YG=&@@
M/2`D:&5A9&5R<ULG8V]N=&5N="UL96YG=&@G73L-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("1L96YG=&@@/2`M,3L-"B`@("`@("`@?0T*("`@
M("`@("`D9&%T82`]("<G.PT*("`@("`@("!W:&EL92`H)&-H=6YK(#T@0&9R
M96%D*"1F<"P@.#$Y,BDI('L-"B`@("`@("`@("`@("1D871A("X]("1C:'5N
M:SL-"B`@("`@("`@?0T*("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@
M:68@*"1L87-T;6]D:69I960@/3T](&9A;'-E('Q\("1L87-T;6]D:69I960I
M('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D:&5A9&5R<ULG971A9R==*2D@
M>PT*("`@("`@("`@("`@("`@("1L87-T;6]D:69I960@/2!A<G)A>2@G151A
M9R<@/3X@)&AE861E<G-;)V5T86<G72D[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!I9B`H:7-S970H)&AE861E<G-;)VQA<W0M;6]D:69I960G72DI
M('L-"B`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)&QA<W1M;V1I9FEE
M9"DI('L-"B`@("`@("`@("`@("`@("`@("`@)&QA<W1M;V1I9FEE9%LG3&%S
M="U-;V1I9FEE9"==(#T@)&AE861E<G-;)VQA<W0M;6]D:69I960G73L-"B`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D
M;&%S=&UO9&EF:65D(#T@)&AE861E<G-;)VQA<W0M;6]D:69I960G73L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R
M971U<FX@87)R87DH)&1A=&$L("1L87-T;6]D:69I960L("1H96%D97)S*3L-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)&1A=&$[#0H@("`@?0T*?0T*
M/SX-"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O4$5!4B]2=6Y497-T+G!H<```````````````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`S-#4V,"`Q,#4Q-30S,S<S,B`P
M,C$S-#$`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`-"B\J*@T*("H@4$5!4E]2=6Y497-T#0H@*@T*("H@4$A0('9E
M<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F
M:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E
M;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E
M:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA
M8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@
M<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL
M('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@
M<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@5&]M
M87,@5BY6+D-O>"`\8V]X0&ED96-N970N8V]M/@T*("H@0&%U=&AO<B`@("`@
M1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@
M,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N
M,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%)U;E1E<W0N<&AP+'8@,2XR
M,"`R,#`V+S`R+S`S(#`R.C`X.C$Q(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@
M("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S
M:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XS+C,-
M"B`J+PT*#0HO*BH-"B`J(&9O<B!E<G)O<B!H86YD;&EN9PT*("HO#0IR97%U
M:7)E7V]N8V4@)U!%05(N<&AP)SL-"G)E<75I<F5?;VYC92`G4$5!4B]#;VYF
M:6<N<&AP)SL-"@T*9&5F:6YE*"=$151!24Q%1"<L(#$I.PT*<'5T96YV*")0
M2%!?4$5!4E]254Y415-44STQ(BD[#0H-"B\J*@T*("H@4VEM<&QI9FEE9"!V
M97)S:6]N(&]F(%!(4"=S('1E<W0@<W5I=&4-"B`J#0H@*B!4<GD@:70@=VET
M:#H-"B`J#0H@*B`D('!H<"`M<B`G:6YC;'5D92`B+BXO4$5!4B]2=6Y497-T
M+G!H<"([("1T/6YE=R!014%27U)U;E1E<W0[("1O/21T+3YR=6XH(BXO<&5A
M<E]S>7-T96TN<&AP="(I.W!R:6YT7W(H)&\I.R<-"B`J#0H@*@T*("H@0&-A
M=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO
M<B`@("`@5&]M87,@5BY6+D-O>"`\8V]X0&ED96-N970N8V]M/@T*("H@0&%U
M=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O
M<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J
M($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2
M#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S
M92`Q+C,N,PT*("HO#0IC;&%S<R!014%27U)U;E1E<W0-"GL-"B`@("!V87(@
M)%]L;V=G97([#0H@("`@=F%R("1?;W!T:6]N<SL-"@T*("`@("\J*@T*("`@
M("`J($%N(&]B:F5C="!T:&%T('-U<'!O<G1S('1H92!014%27T-O;6UO;BT^
M;&]G*"D@<VEG;F%T=7)E+"!O<B!N=6QL#0H@("`@("H@0'!A<F%M(%!%05)?
M0V]M;6]N?&YU;&P-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!014%27U)U;E1E
M<W0H)&QO9V=E<B`](&YU;&PL("1O<'1I;VYS(#T@87)R87DH*2D-"B`@("![
M#0H@("`@("`@(&EF("AI<U]N=6QL*"1L;V=G97(I*2![#0H@("`@("`@("`@
M("!R97%U:7)E7V]N8V4@)U!%05(O0V]M;6]N+G!H<"<[#0H@("`@("`@("`@
M("`D;&]G9V5R(#T@;F5W(%!%05)?0V]M;6]N.PT*("`@("`@("!]#0H@("`@
M("`@("1T:&ES+3Y?;&]G9V5R(#T@)&QO9V=E<CL-"B`@("`@("`@)'1H:7,M
M/E]O<'1I;VYS(#T@)&]P=&EO;G,[#0H@("`@?0T*#0H@("`@+R\-"B`@("`O
M+R`@4G5N(&%N(&EN9&EV:61U86P@=&5S="!C87-E+@T*("`@("\O#0H-"B`@
M("!F=6YC=&EO;B!R=6XH)&9I;&4L("1I;FE?<V5T=&EN9W,@/2`G)RD-"B`@
M("![#0H@("`@("`@("1C=V0@/2!G971C=V0H*3L-"B`@("`@("`@)&-O;F8@
M/2`F4$5!4E]#;VYF:6<Z.G-I;F=L971O;B@I.PT*("`@("`@("`D<&AP(#T@
M)&-O;F8M/F=E="@G<&AP7V)I;B<I.PT*("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]O<'1I;VYS6R=P:'!U;FET)UTI*2![#0H@("`@("`@("`@("`D8VUD
M(#T@(B1P:'`D:6YI7W-E='1I;F=S("UF("1F:6QE(CL-"B`@("`@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^7VQO9V=E<BDI('L-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^7VQO9V=E<BT^;&]G*#(L("=2=6YN:6YG(&-O;6UA;F0@(B<@
M+B`D8VUD("X@)R(G*3L-"B`@("`@("`@("`@('T-"B`@("`-"B`@("`@("`@
M("`@("1S879E9&ER(#T@9V5T8W=D*"D[("\O(&EN(&-A<V4@=&AE('1E<W0@
M;6]V97,@=7,@87)O=6YD#0H@("`@("`@("`@("!C:&1I<BAD:7)N86UE*"1F
M:6QE*2D[#0H@("`@("`@("`@("!E8VAO(&`D8VUD8#L-"B`@("`@("`@("`@
M(&-H9&ER*"1S879E9&ER*3L-"B`@("`@("`@("`@(')E='5R;B`G4$%34T5$
M)SL@+R\@=V4@:&%V92!N;R!W87D@;V8@:VYO=VEN9R!T:&ES(&EN9F]R;6%T
M:6]N('-O(&%S<W5M92!P87-S:6YG#0H@("`@("`@('T-"B`@("`@("`@+R]V
M87)?9'5M<"@D<&AP*3ME>&ET.PT*("`@("`@("!G;&]B86P@)&QO9U]F;W)M
M870L("1I;F9O7W!A<F%M<RP@)&EN:5]O=F5R=W)I=&5S.PT*#0H@("`@("`@
M("1I;F9O7W!A<F%M<R`]("<G.PT*("`@("`@("`D;&]G7V9O<FUA="`]("=,
M14]$)SL-"@T*("`@("`@("`O+R!,;V%D('1H92!S96-T:6]N<R!O9B!T:&4@
M=&5S="!F:6QE+@T*("`@("`@("`D<V5C=&EO;E]T97AT(#T@87)R87DH#0H@
M("`@("`@("`@("`G5$535"<@("`@/3X@)RAU;FYA;65D('1E<W0I)RP-"B`@
M("`@("`@("`@("=32TE0248G("`]/B`G)RP-"B`@("`@("`@("`@("='150G
M("`@("`]/B`G)RP-"B`@("`@("`@("`@("=!4D=3)R`@("`]/B`G)RP-"B`@
M("`@("`@("`@("=#3$5!3B<@("`]/B`G)RP-"B`@("`@("`@*3L-"@T*("`@
M("`@("`D9FEL92`](')E86QP871H*"1F:6QE*3L-"B`@("`@("`@:68@*"%I
M<U]F:6QE*"1F:6QE*2!\?"`A)&9P(#T@9F]P96XH)&9I;&4L(")R(BDI('L-
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")#86YN;W0@
M;W!E;B!T97-T(&9I;&4Z("1F:6QE(BD[#0H@("`@("`@('T-"@T*("`@("`@
M("`D<V5C=&EO;B`]("<G.PT*("`@("`@("!W:&EL92`H(69E;V8H)&9P*2D@
M>PT*("`@("`@("`@("`@)&QI;F4@/2!F9V5T<R@D9G`I.PT*#0H@("`@("`@
M("`@("`O+R!-871C:"!T:&4@8F5G:6YN:6YG(&]F(&$@<V5C=&EO;BX-"B`@
M("`@("`@("`@(&EF("AE<F5G*"=>+2TH6T$M6ETK*2TM)RPD;&EN92PD<BDI
M('L-"B`@("`@("`@("`@("`@("`D<V5C=&EO;B`]("1R6S%=.PT*("`@("`@
M("`@("`@("`@("1S96-T:6]N7W1E>'1;)'-E8W1I;VY=(#T@)R<[#0H@("`@
M("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!](&5L<V5I9B`H
M96UP='DH)'-E8W1I;VXI*2![#0H@("`@("`@("`@("`@("`@9F-L;W-E*"1F
M<"D[#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M(DEN=F%L:60@<V5C=&EO;G,@9F]R;6%T<R!I;B!T97-T(&9I;&4Z("1F:6QE
M(BD[#0H)"0E]#0H-"B`@("`@("`@("`@("\O($%D9"!T;R!T:&4@<V5C=&EO
M;B!T97AT+@T*("`@("`@("`@("`@)'-E8W1I;VY?=&5X=%LD<V5C=&EO;ET@
M+CT@)&QI;F4[#0H@("`@("`@('T-"B`@("`@("`@9F-L;W-E*"1F<"D[#0H-
M"B`@("`@("`@)'-H;W)T;F%M92`]('-T<E]R97!L86-E*"1C=V0@+B!$25)%
M0U1/4EE?4T5005)!5$]2+"`G)RP@)&9I;&4I.PT*("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3Y?;W!T:6]N<ULG<VEM<&QE)UTI*2![#0H@("`@("`@("`@
M("`D=&5S=&5D(#T@=')I;2@D<V5C=&EO;E]T97AT6R=415-4)UTI("X@(ELD
M<VAO<G1N86UE72([#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D
M=&5S=&5D(#T@=')I;2@D<V5C=&EO;E]T97AT6R=415-4)UTI("X@)R`G.PT*
M("`@("`@("!]#0H-"B`@("`@("`@)'1M<"`](')E86QP871H*&1I<FYA;64H
M)&9I;&4I*3L-"B`@("`@("`@)'1M<%]S:VEP:68@/2`D=&UP("X@=6YI<6ED
M*"<O<&AP="XG*3L-"B`@("`@("`@)'1M<%]F:6QE("`@/2!E<F5G7W)E<&QA
M8V4H)UPN<&AP="0G+"<N<&AP)RPD9FEL92D[#0H@("`@("`@("1T;7!?<&]S
M="`@(#T@)'1M<"`N('5N:7%I9"@G+W!H<'0N)RD[#0H-"B`@("`@("`@0'5N
M;&EN:R@D=&UP7W-K:7!I9BD[#0H@("`@("`@($!U;FQI;FLH)'1M<%]F:6QE
M*3L-"B`@("`@("`@0'5N;&EN:R@D=&UP7W!O<W0I.PT*#0H@("`@("`@("\O
M('5N;&EN:R!O;&0@=&5S="!R97-U;'1S#0H@("`@("`@($!U;FQI;FLH97)E
M9U]R97!L86-E*"=<+G!H<'0D)RPG+F1I9F8G+"1F:6QE*2D[#0H@("`@("`@
M($!U;FQI;FLH97)E9U]R97!L86-E*"=<+G!H<'0D)RPG+FQO9R<L)&9I;&4I
M*3L-"B`@("`@("`@0'5N;&EN:RAE<F5G7W)E<&QA8V4H)UPN<&AP="0G+"<N
M97AP)RPD9FEL92DI.PT*("`@("`@("!`=6YL:6YK*&5R96=?<F5P;&%C92@G
M7"YP:'!T)"<L)RYO=70G+"1F:6QE*2D[#0H-"B`@("`@("`@+R\@0VAE8VL@
M:68@=&5S="!S:&]U;&0@8F4@<VMI<'!E9"X-"B`@("`@("`@)&EN9F\@/2`G
M)SL-"B`@("`@("`@)'=A<FX@/2!F86QS93L-"B`@("`@("`@:68@*&%R<F%Y
M7VME>5]E>&ES=',H)U-+25!)1B<L("1S96-T:6]N7W1E>'0I*2![#0H@("`@
M("`@("`@("!I9B`H=')I;2@D<V5C=&EO;E]T97AT6R=32TE0248G72DI('L-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<V%V95]T97AT*"1T;7!?<VMI<&EF
M+"`D<V5C=&EO;E]T97AT6R=32TE0248G72D[#0H@("`@("`@("`@("`@("`@
M+R\D97AT<F$@/2!S=6)S='(H4$A07T]3+"`P+"`S*2`A/3T@(E=)3B(@/PT*
M("`@("`@("`@("`@("`@("\O("`@(")U;G-E="!215%515-47TU%5$A/1#LB
M.B`B(CL-"@T*("`@("`@("`@("`@("`@("\O)&]U='!U="`](&`D97AT<F$@
M)'!H<"`D:6YF;U]P87)A;7,@+68@)'1M<%]S:VEP:69@.PT*("`@("`@("`@
M("`@("`@("1O=71P=70@/2!@)'!H<"`D:6YF;U]P87)A;7,@+68@)'1M<%]S
M:VEP:69@.PT*("`@("`@("`@("`@("`@('5N;&EN:R@D=&UP7W-K:7!I9BD[
M#0H@("`@("`@("`@("`@("`@:68@*&5R96=I*")><VMI<"(L('1R:6TH)&]U
M='!U="DI*2![#0H@("`@("`@("`@("`@("`@("`@("1S:VEP<F5A<V]N(#T@
M(E-+25`@)'1E<W1E9"([#0H@("`@("`@("`@("`@("`@("`@("1R96%S;VX@
M/2`H97)E9VDH(EYS:VEP6ULZ<W!A8V4Z75TJ*"XK*5PD(BP@=')I;2@D;W5T
M<'5T*2DI(#\@97)E9VE?<F5P;&%C92@B7G-K:7!;6SIS<&%C93I=72HH+BLI
M7"0B+"`B7%PQ(BP@=')I;2@D;W5T<'5T*2D@.B!&04Q313L-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"1R96%S;VXI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1S:VEP<F5A<V]N("X]("(@*')E87-O;CH@)')E87-O;BDB.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=Q=6EE="==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]L;V=G97(M/FQO9R@P+"`D<VMI
M<')E87-O;BD[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1O;&1?<&AP*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)'!H<"`]("1O;&1?<&AP.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`G4TM)4%!%1"<[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AE<F5G
M:2@B7FEN9F\B+"!T<FEM*"1O=71P=70I*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`D<F5A<V]N(#T@*&5R96<H(EYI;F9O6ULZ<W!A8V4Z75TJ*"XK*5PD
M(BP@=')I;2@D;W5T<'5T*2DI(#\@97)E9U]R97!L86-E*")>:6YF;UM;.G-P
M86-E.EU=*B@N*RE<)"(L(")<7#$B+"!T<FEM*"1O=71P=70I*2`Z($9!3%-%
M.PT*("`@("`@("`@("`@("`@("`@("!I9B`H)')E87-O;BD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)&EN9F\@/2`B("AI;F9O.B`D<F5A<V]N*2([
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@:68@*&5R96=I*")>=V%R;B(L('1R:6TH)&]U='!U
M="DI*2![#0H@("`@("`@("`@("`@("`@("`@("1R96%S;VX@/2`H97)E9R@B
M7G=A<FY;6SIS<&%C93I=72HH+BLI7"0B+"!T<FEM*"1O=71P=70I*2D@/R!E
M<F5G7W)E<&QA8V4H(EYW87)N6ULZ<W!A8V4Z75TJ*"XK*5PD(BP@(EQ<,2(L
M('1R:6TH)&]U='!U="DI(#H@1D%,4T4[#0H@("`@("`@("`@("`@("`@("`@
M(&EF("@D<F5A<V]N*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=V%R
M;B`]('1R=64[("\J(&]N;'D@:68@=&AE<F4@:7,@82!R96%S;VX@*B\-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1I;F9O(#T@(B`H=V%R;CH@)')E87-O
M;BDB.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H-"B`@("`@("`@+R\@5V4G
M=F4@<V%T:7-F:65D('1H92!P<F5C;VYD:71I;VYS("T@<G5N('1H92!T97-T
M(0T*("`@("`@("`D=&AI<RT^<V%V95]T97AT*"1T;7!?9FEL92PD<V5C=&EO
M;E]T97AT6R=&24Q%)UTI.PT*#0H@("`@("`@("1A<F=S(#T@)'-E8W1I;VY?
M=&5X=%LG05)'4R==(#\@)R`M+2`G+B1S96-T:6]N7W1E>'1;)T%21U,G72`Z
M("<G.PT*#0H@("`@("`@("1C;60@/2`B)'!H<"1I;FE?<V5T=&EN9W,@+68@
M)'1M<%]F:6QE)&%R9W,@,CXF,2([#0H@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^7VQO9V=E<BDI('L-"B`@("`@("`@("`@("1T:&ES+3Y?;&]G9V5R+3YL
M;V<H,BP@)U)U;FYI;F<@8V]M;6%N9"`B)R`N("1C;60@+B`G(B<I.PT*("`@
M("`@("!]#0H-"B`@("`@("`@)'-A=F5D:7(@/2!G971C=V0H*3L@+R\@:6X@
M8V%S92!T:&4@=&5S="!M;W9E<R!U<R!A<F]U;F0-"B`@("`@("`@:68@*&ES
M<V5T*"1S96-T:6]N7W1E>'1;)U)%5%523E,G72DI('L-"B`@("`@("`@("`@
M(&]B7W-T87)T*"D[#0H@("`@("`@("`@("!S>7-T96TH)&-M9"P@)')E='5R
M;E]V86QU92D[#0H@("`@("`@("`@("`D;W5T(#T@;V)?9V5T7V-O;G1E;G1S
M*"D[#0H@("`@("`@("`@("!O8E]E;F1?8VQE86XH*3L-"B`@("`@("`@("`@
M($!U;FQI;FLH)'1M<%]P;W-T*3L-"B`@("`@("`@("`@("1S96-T:6]N7W1E
M>'1;)U)%5%523E,G72`]("AI;G0I('1R:6TH)'-E8W1I;VY?=&5X=%LG4D54
M55).4R==*3L-"B`@("`@("`@("`@("1R971U<FYF86EL(#T@*"1R971U<FY?
M=F%L=64@(3T@)'-E8W1I;VY?=&5X=%LG4D5455).4R==*3L-"B`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("1O=70@/2!@)&-M9&`[#0H@("`@("`@
M("`@("`D<F5T=7)N9F%I;"`](&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@
M(&-H9&ER*"1S879E9&ER*3L-"@T*("`@("`@("!I9B`H)'-E8W1I;VY?=&5X
M=%LG0TQ%04XG72D@>PT*("`@("`@("`@("`@+R\@<&5R9F]R;2!T97-T(&-L
M96%N=7`-"B`@("`@("`@("`@("1T:&ES+3YS879E7W1E>'0H)&-L96%N(#T@
M)'1M<"`N('5N:7%I9"@G+W!H<'0N)RDL("1S96-T:6]N7W1E>'1;)T-,14%.
M)UTI.PT*("`@("`@("`@("`@8"1P:'`@)&-L96%N8#L-"B`@("`@("`@("`@
M($!U;FQI;FLH)&-L96%N*3L-"B`@("`@("`@?0T*("`@("`@("`O+R!$;V5S
M('1H92!O=71P=70@;6%T8V@@=VAA="!I<R!E>'!E8W1E9#\-"B`@("`@("`@
M)&]U='!U="`]('1R:6TH)&]U="D[#0H@("`@("`@("1O=71P=70@/2!P<F5G
M7W)E<&QA8V4H)R]<<EQN+R<L(")<;B(L("1O=71P=70I.PT*#0H@("`@("`@
M(&EF("AI<W-E="@D<V5C=&EO;E]T97AT6R=%6%!%0U1&)UTI('Q\(&ES<V5T
M*"1S96-T:6]N7W1E>'1;)T584$5#5%)%1T58)UTI*2![#0H@("`@("`@("`@
M("!I9B`H:7-S970H)'-E8W1I;VY?=&5X=%LG15A014-41B==*2D@>PT*("`@
M("`@("`@("`@("`@("1W86YT960@/2!T<FEM*"1S96-T:6]N7W1E>'1;)T58
M4$5#5$8G72D[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("1W86YT960@/2!T<FEM*"1S96-T:6]N7W1E>'1;)T584$5#5%)%1T58
M)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'=A;G1E9%]R92`]
M('!R96=?<F5P;&%C92@G+UQR7&XO)RPB7&XB+"1W86YT960I.PT*("`@("`@
M("`@("`@:68@*&ES<V5T*"1S96-T:6]N7W1E>'1;)T584$5#5$8G72DI('L-
M"B`@("`@("`@("`@("`@("`D=V%N=&5D7W)E(#T@<')E9U]Q=6]T92@D=V%N
M=&5D7W)E+"`G+R<I.PT*("`@("`@("`@("`@("`@("\O(%-T:6-K('1O(&)A
M<VEC<PT*("`@("`@("`@("`@("`@("1W86YT961?<F4@/2!S=')?<F5P;&%C
M92@B)7,B+"`B+BL_(BP@)'=A;G1E9%]R92D[("\O;F]T(&=R965D>0T*("`@
M("`@("`@("`@("`@("1W86YT961?<F4@/2!S=')?<F5P;&%C92@B)6DB+"`B
M6RM<+5T_6S`M.5TK(BP@)'=A;G1E9%]R92D[#0H@("`@("`@("`@("`@("`@
M)'=A;G1E9%]R92`]('-T<E]R97!L86-E*"(E9"(L(");,"TY72LB+"`D=V%N
M=&5D7W)E*3L-"B`@("`@("`@("`@("`@("`D=V%N=&5D7W)E(#T@<W1R7W)E
M<&QA8V4H(B5X(BP@(ELP+3EA+69!+49=*R(L("1W86YT961?<F4I.PT*("`@
M("`@("`@("`@("`@("1W86YT961?<F4@/2!S=')?<F5P;&%C92@B)68B+"`B
M6RM<+5T_7"X_6S`M.5TK7"X_6S`M.5TJ*$4M/ULP+3E=*RD_(BP@)'=A;G1E
M9%]R92D[#0H@("`@("`@("`@("`@("`@)'=A;G1E9%]R92`]('-T<E]R97!L
M86-E*"(E8R(L("(N(BP@)'=A;G1E9%]R92D[#0H@("`@("`@("`@("`@("`@
M+R\@)68@86QL;W=S('1W;R!P;VEN=',@(BTN,"XP(B!B=70@=&AA="!I<R!T
M:&4@8F5S="`J<VEM<&QE*B!E>'!R97-S:6]N#0H@("`@("`@("`@("!]#0H@
M("`@+RH@1$5"54<@64]54B!214=%6"!(15)%#0H@("`@("`@("`@("!V87)?
M9'5M<"@D=V%N=&5D7W)E*3L-"B`@("`@("`@("`@('!R:6YT*'-T<E]R97!E
M870H)STG+"`X,"D@+B`B7&XB*3L-"B`@("`@("`@("`@('9A<E]D=6UP*"1O
M=71P=70I.PT*("`@("HO#0H@("`@("`@("`@("!I9B`H(21R971U<FYF86EL
M("8F('!R96=?;6%T8V@H(B]>)'=A;G1E9%]R95PD+W,B+"`D;W5T<'5T*2D@
M>PT*("`@("`@("`@("`@("`@($!U;FQI;FLH)'1M<%]F:6QE*3L-"B`@("`@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG<75I970G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]L;V=G97(M/FQO
M9R@P+"`B4$%34R`D=&5S=&5D)&EN9F\B*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1O;&1?<&AP*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`D<&AP(#T@)&]L9%]P:'`[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(')E='5R;B`G4$%34T5$)SL-"B`@
M("`@("`@("`@('T-"@T*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M)'=A;G1E9"`]('1R:6TH)'-E8W1I;VY?=&5X=%LG15A014-4)UTI.PT*("`@
M("`@("`@("`@)'=A;G1E9"`]('!R96=?<F5P;&%C92@G+UQR7&XO)RPB7&XB
M+"1W86YT960I.PT*("`@("`@("`O+R!C;VUP87)E(&%N9"!L96%V92!O;B!S
M=6-C97-S#0H@("`@("`@("`@("`D;VL@/2`H,"`]/2!S=')C;7`H)&]U='!U
M="PD=V%N=&5D*2D[#0H@("`@("`@("`@("!I9B`H(21R971U<FYF86EL("8F
M("1O:RD@>PT*("`@("`@("`@("`@("`@($!U;FQI;FLH)'1M<%]F:6QE*3L-
M"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG
M<75I970G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]L;V=G
M97(M/FQO9R@P+"`B4$%34R`D=&5S=&5D)&EN9F\B*3L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1O;&1?<&AP*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`D<&AP(#T@)&]L9%]P:'`[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(')E='5R;B`G4$%34T5$
M)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*#0H@("`@("`@("\O(%1E
M<W0@9F%I;&5D('-O('=E(&YE960@=&\@<F5P;W)T(&1E=&%I;',N#0H@("`@
M("`@(&EF("@D=V%R;BD@>PT*("`@("`@("`@("`@)'1H:7,M/E]L;V=G97(M
M/FQO9R@P+"`B5T%23B`D=&5S=&5D)&EN9F\B*3L-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("1T:&ES+3Y?;&]G9V5R+3YL;V<H,"P@(D9!24P@
M)'1E<W1E9"1I;F9O(BD[#0H@("`@("`@('T-"@T*("`@("`@("!I9B`H:7-S
M970H)'-E8W1I;VY?=&5X=%LG4D5455).4R==*2D@>PT*("`@("`@("`@("`@
M)$=,3T)!3%-;)U]?4$A07T9!24Q%1%]415-44U]?)UU;72`](&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B`D9FEL92P-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=&5S=%]N86UE)R`]/B`D
M=&5S=&5D+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=O=71P=70G
M(#T^(&5R96=?<F5P;&%C92@G7"YP:'!T)"<L)RYL;V<G+"`D9FEL92DL#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1I9F8G("`@/3X@97)E9U]R
M97!L86-E*"=<+G!H<'0D)RPG+F1I9F8G+"`D9FEL92DL#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)VEN9F\G("`@/3X@)&EN9F\L#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W)E='5R;B<@/3X@)')E='5R;E]V86QU
M90T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("D[#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`D1TQ/0D%,4ULG7U]02%!?1D%)3$5$7U1%
M4U137U\G75M=(#T@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)VYA;64G(#T^("1F:6QE+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=T97-T7VYA;64G(#T^("1T97-T960L#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V]U='!U="<@/3X@97)E9U]R97!L86-E*"=<+G!H<'0D
M)RPG+FQO9R<L("1F:6QE*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G9&EF9B<@("`]/B!E<F5G7W)E<&QA8V4H)UPN<&AP="0G+"<N9&EF9B<L
M("1F:6QE*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:6YF;R<@
M("`]/B`D:6YF;RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`I.PT*
M("`@("`@("!]#0H-"B`@("`@("`@+R\@=W)I=&4@+F5X<`T*("`@("`@("!I
M9B`H<W1R<&]S*"1L;V=?9F]R;6%T+"=%)RD@(3T]($9!3%-%*2![#0H@("`@
M("`@("`@("`D;&]G;F%M92`](&5R96=?<F5P;&%C92@G7"YP:'!T)"<L)RYE
M>'`G+"1F:6QE*3L-"B`@("`@("`@("`@(&EF("@A)&QO9R`](&9O<&5N*"1L
M;V=N86UE+"=W)RDI('L-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@B0V%N;F]T(&-R96%T92!T97-T(&QO9R`M("1L;V=N86UE
M(BD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F=W)I=&4H)&QO9RPD
M=V%N=&5D*3L-"B`@("`@("`@("`@(&9C;&]S92@D;&]G*3L-"B`@("`@("`@
M?0T*#0H@("`@("`@("\O('=R:71E("YO=70-"B`@("`@("`@:68@*'-T<G!O
M<R@D;&]G7V9O<FUA="PG3R<I("$]/2!&04Q312D@>PT*("`@("`@("`@("`@
M)&QO9VYA;64@/2!E<F5G7W)E<&QA8V4H)UPN<&AP="0G+"<N;W5T)RPD9FEL
M92D[#0H@("`@("`@("`@("!I9B`H(21L;V<@/2!F;W!E;B@D;&]G;F%M92PG
M=R<I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H(D-A;FYO="!C<F5A=&4@=&5S="!L;V<@+2`D;&]G;F%M92(I.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@9G=R:71E*"1L;V<L)&]U='!U="D[
M#0H@("`@("`@("`@("!F8VQO<V4H)&QO9RD[#0H@("`@("`@('T-"@T*("`@
M("`@("`O+R!W<FET92`N9&EF9@T*("`@("`@("!I9B`H<W1R<&]S*"1L;V=?
M9F]R;6%T+"=$)RD@(3T]($9!3%-%*2![#0H@("`@("`@("`@("`D;&]G;F%M
M92`](&5R96=?<F5P;&%C92@G7"YP:'!T)"<L)RYD:69F)RPD9FEL92D[#0H@
M("`@("`@("`@("!I9B`H(21L;V<@/2!F;W!E;B@D;&]G;F%M92PG=R<I*2![
M#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D-A
M;FYO="!C<F5A=&4@=&5S="!L;V<@+2`D;&]G;F%M92(I.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@9G=R:71E*"1L;V<L("1T:&ES+3YG96YE<F%T
M95]D:69F*"1W86YT960L("1O=71P=70L#0H@("`@("`@("`@("`@("`@:7-S
M970H)'-E8W1I;VY?=&5X=%LG4D5455).4R==*2`_(&%R<F%Y*'1R:6TH)'-E
M8W1I;VY?=&5X=%LG4D5455).4R==*2P-"B`@("`@("`@("`@("`@("`@("`@
M)')E='5R;E]V86QU92D@.B!N=6QL*2D[#0H@("`@("`@("`@("!F8VQO<V4H
M)&QO9RD[#0H@("`@("`@('T-"@T*("`@("`@("`O+R!W<FET92`N;&]G#0H@
M("`@("`@(&EF("AS=')P;W,H)&QO9U]F;W)M870L)TPG*2`A/3T@1D%,4T4I
M('L-"B`@("`@("`@("`@("1L;V=N86UE(#T@97)E9U]R97!L86-E*"=<+G!H
M<'0D)RPG+FQO9R<L)&9I;&4I.PT*("`@("`@("`@("`@:68@*"$D;&]G(#T@
M9F]P96XH)&QO9VYA;64L)W<G*2D@>PT*("`@("`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*")#86YN;W0@8W)E871E('1E<W0@;&]G("T@
M)&QO9VYA;64B*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9W<FET
M92@D;&]G+"(-"BTM+2T@15A014-4140@3U544%54#0HD=V%N=&5D#0HM+2TM
M($%#5%5!3"!/5510550-"B1O=71P=70-"BTM+2T@1D%)3$5$#0HB*3L-"B`@
M("`@("`@("`@(&EF("@D<F5T=7)N9F%I;"D@>PT*("`@("`@("`@("`@("`@
M(&9W<FET92@D;&]G+"(-"BTM+2T@15A014-4140@4D5455).#0HD<V5C=&EO
M;E]T97AT6U)%5%523E-=#0HM+2TM($%#5%5!3"!215154DX-"B1R971U<FY?
M=F%L=64-"B(I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F-L;W-E
M*"1L;V<I.PT*("`@("`@("`@("`@+R]E<G)O<E]R97!O<G0H)&9I;&4L)&QO
M9VYA;64L)'1E<W1E9"D[#0H@("`@("`@('T-"@T*("`@("`@("!I9B`H:7-S
M970H)&]L9%]P:'`I*2![#0H@("`@("`@("`@("`D<&AP(#T@)&]L9%]P:'`[
M#0H@("`@("`@('T-"@T*("`@("`@("!R971U<FX@)'=A<FX@/R`G5T%23D5$
M)R`Z("=&04E,140G.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E;F5R871E
M7V1I9F8H)'=A;G1E9"P@)&]U='!U="P@)')E='5R;E]V86QU92D-"B`@("![
M#0H@("`@("`@("1W(#T@97AP;&]D92@B7&XB+"`D=V%N=&5D*3L-"B`@("`@
M("`@)&\@/2!E>'!L;V1E*")<;B(L("1O=71P=70I.PT*("`@("`@("`D=S$@
M/2!A<G)A>5]D:69F7V%S<V]C*"1W+"1O*3L-"B`@("`@("`@)&\Q(#T@87)R
M87E?9&EF9E]A<W-O8R@D;RPD=RD[#0H@("`@("`@("1W,B`](&%R<F%Y*"D[
M#0H@("`@("`@("1O,B`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@H)'<Q
M(&%S("1I9'@@/3X@)'9A;"D@)'<R6W-P<FEN=&8H(B4P,V0\(BPD:61X*5T@
M/2!S<')I;G1F*"(E,#-D+2`B+"`D:61X*S$I+B1V86P[#0H@("`@("`@(&9O
M<F5A8V@H)&\Q(&%S("1I9'@@/3X@)'9A;"D@)&\R6W-P<FEN=&8H(B4P,V0^
M(BPD:61X*5T@/2!S<')I;G1F*"(E,#-D*R`B+"`D:61X*S$I+B1V86P[#0H@
M("`@("`@("1D:69F(#T@87)R87E?;65R9V4H)'<R+"`D;S(I.PT*("`@("`@
M("!K<V]R="@D9&EF9BD[#0H@("`@("`@(&EF("@D<F5T=7)N7W9A;'5E*2![
M#0H@("`@("`@("`@("`D97AT<F$@/2`B(R-%6%!%0U1%1#H@)')E='5R;E]V
M86QU95LP75QR7&XC(U)%5%523D5$.B`D<F5T=7)N7W9A;'5E6S%=(CL-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1E>'1R82`]("<G.PT*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B!I;7!L;V1E*")<<EQN(BP@)&1I9F8I
M("X@)&5X=')A.PT*("`@('T-"@T*("`@("\O#0H@("`@+R\@(%=R:71E('1H
M92!G:79E;B!T97AT('1O(&$@=&5M<&]R87)Y(&9I;&4L(&%N9"!R971U<FX@
M=&AE(&9I;&5N86UE+@T*("`@("\O#0H-"B`@("!F=6YC=&EO;B!S879E7W1E
M>'0H)&9I;&5N86UE+"`D=&5X="D-"B`@("![#0H@("`@("`@(&EF("@A)&9P
M(#T@9F]P96XH)&9I;&5N86UE+"`G=R<I*2![#0H@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@B0V%N;F]T(&]P96X@9FEL92`G(B`N("1F
M:6QE;F%M92`N("(G("AS879E7W1E>'0I(BD[#0H@("`@("`@('T-"B`@("`@
M("`@9G=R:71E*"1F<"PD=&5X="D[#0H@("`@("`@(&9C;&]S92@D9G`I.PT*
M("`@(&EF("@Q(#P@1$5404E,140I(&5C:&\@(@T*1DE,12`D9FEL96YA;64@
M>WM[#0HD=&5X=`T*?7U]#0HB.PT*("`@('T-"@T*?0T*/SX-"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]686QI9&%T92YP
M:'``````````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`U-#8Q
M,"`Q,#4Q-30S,S<S,B`P,C$T-C0`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`-"B\J*@T*("H@4$5!4E]686QI9&%T
M90T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y3
M13H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP
M(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ
M#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@
M>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC
M96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@
M=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE
M="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-
M"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J
M($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J
M($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC
M96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!0
M2%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!686QI
M9&%T92YP:'`L=B`Q+C0V(#(P,#8O,#$O,C,@,3<Z,38Z,S4@8V5L;&]G($5X
M<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA
M9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@
M4F5L96%S92`Q+C0N,&$Q#0H@*B\-"B\J*B-`*PT*("H@0V]N<W1A;G1S(&9O
M<B!I;G-T86QL('-T86=E#0H@*B\-"F1E9FEN92@G4$5!4E]604Q)1$%415])
M3E-404Q,24Y')RP@,2D[#0ID969I;F4H)U!%05)?5D%,241!5$5?54Y)3E-4
M04Q,24Y')RP@,BD[("\O('1H:7,@:7,@;F]T(&)I="UM87!P960@;&EK92!T
M:&4@;W1H97)S#0ID969I;F4H)U!%05)?5D%,241!5$5?3D]234%,)RP@,RD[
M#0ID969I;F4H)U!%05)?5D%,241!5$5?1$]73DQ/041)3D<G+"`T*3L@+R\@
M=&AI<R!I<R!N;W0@8FET+6UA<'!E9"!L:6ME('1H92!O=&AE<G,-"F1E9FEN
M92@G4$5!4E]604Q)1$%415]004-+04=)3D<G+"`W*3L-"B\J*B-`+2HO#0IR
M97%U:7)E7V]N8V4@)U!%05(O0V]M;6]N+G!H<"<[#0IR97%U:7)E7V]N8V4@
M)U!%05(O5F%L:61A=&]R+U!%0TPN<&AP)SL-"@T*+RHJ#0H@*B!686QI9&%T
M:6]N(&-L87-S(&9O<B!P86-K86=E+GAM;"`M(&-H86YN96PM;&5V96P@861V
M86YC960@=F%L:61A=&EO;@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A
M8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E
M;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!0
M2%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L
M:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@
M("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R
M+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A
M=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"F-L87-S(%!%
M05)?5F%L:61A=&4-"GL-"B`@("!V87(@)'!A8VMA9V5R96=E>"`](%]014%2
M7T-/34U/3E]004-+04=%7TY!345?4%)%1SL-"B`@("`O*BH-"B`@("`@*B!`
M=F%R(%!%05)?4&%C:V%G949I;&5?=C%\4$5!4E]086-K86=E1FEL95]V,@T*
M("`@("`J+PT*("`@('9A<B`D7W!A8VMA9V5X;6P[#0H@("`@+RHJ#0H@("`@
M("H@0'9A<B!I;G0@;VYE(&]F('1H92!014%27U9!3$E$051%7RH@8V]N<W1A
M;G1S#0H@("`@("HO#0H@("`@=F%R("1?<W1A=&4@/2!014%27U9!3$E$051%
M7TY/4DU!3#L-"B`@("`O*BH-"B`@("`@*B!&;W)M870Z("@G97)R;W(G(#T^
M(&%R<F%Y*"=F:65L9"<@/3X@;F%M92P@)W)E87-O;B<@/3X@<F5A<V]N*2P@
M)W=A<FYI;F<G(#T^('-A;64I#0H@("`@("H@0'9A<B!A<G)A>0T*("`@("`J
M($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D7V9A:6QU<F5S
M(#T@87)R87DH)V5R<F]R)R`]/B!A<G)A>2@I+"`G=V%R;FEN9R<@/3X@87)R
M87DH*2D[#0H-"B`@("`O*BH-"B`@("`@*B!/=F5R<FED92!T:&ES(&UE=&AO
M9"!T;R!H86YD;&4@=F%L:61A=&EO;B!O9B!N;W)M86P@<&%C:V%G92!N86UE
M<PT*("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@*B!`<F5T=7)N(&)O;VP-
M"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`T*("`@("`J+PT*("`@(&9U;F-T
M:6]N(%]V86QI9%!A8VMA9V5.86UE*"1N86UE*0T*("`@('L-"B`@("`@("`@
M<F5T=7)N("AB;V]L*2!P<F5G7VUA=&-H*"<O7B<@+B`D=&AI<RT^<&%C:V%G
M97)E9V5X("X@)R0O)RP@)&YA;64I.PT*("`@('T-"@T*("`@("\J*@T*("`@
M("`J($!P87)A;2!S=')I;F<@<&%C:V%G92!N86UE('1O('9A;&ED871E#0H@
M("`@("H@0'!A<F%M('-T<FEN9R!N86UE(&]F(&-H86YN96PM<W!E8VEF:6,@
M=F%L:61A=&EO;B!P86-K86=E#0H@("`@("H@0&9I;F%L#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@=F%L:61086-K86=E3F%M92@D;F%M92P@)'9A;&ED871E
M<&%C:V%G96YA;64@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@D=F%L
M:61A=&5P86-K86=E;F%M92D@>PT*("`@("`@("`@("`@:68@*'-T<G1O;&]W
M97(H)&YA;64I(#T]('-T<G1O;&]W97(H)'9A;&ED871E<&%C:V%G96YA;64I
M*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("AB;V]L*2!P<F5G7VUA=&-H
M*"<O7EMA+7I!+5HP+3E?72LH/SI<+EMA+7I!+5HP+3E?72LI*B0O)RP@)&YA
M;64I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R
M;B`D=&AI<RT^7W9A;&ED4&%C:V%G94YA;64H)&YA;64I.PT*("`@('T-"@T*
M("`@("\J*@T*("`@("`J(%1H:7,@=F%L:61A=&5S(&$@8G5N9&QE(&YA;64L
M(&%N9"!B=6YD;&4@;F%M97,@;75S="!C;VYF;W)M#0H@("`@("H@=&\@=&AE
M(%!%05(@;F%M:6YG(&-O;G9E;G1I;VXL('-O('1H92!M971H;V0@:7,@9FEN
M86P@86YD('-T871I8RX-"B`@("`@*B!`<&%R86T@<W1R:6YG#0H@("`@("H@
M0&9I;F%L#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T:6]N
M('9A;&ED1W)O=7!.86UE*"1N86UE*0T*("`@('L-"B`@("`@("`@<F5T=7)N
M("AB;V]L*2!P<F5G7VUA=&-H*"<O7B<@+B!?4$5!4E]#3TU-3TY?4$%#2T%'
M15].04U%7U!214<@+B`G)"\G+"`D;F%M92D[#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@("H@1&5T97)M:6YE('=H971H97(@)'-T871E(')E<')E<V5N=',@
M82!V86QI9"!S=&%B:6QI='D@;&5V96P-"B`@("`@*B!`<&%R86T@<W1R:6YG
M#0H@("`@("H@0')E='5R;B!B;V]L#0H@("`@("H@0'-T871I8PT*("`@("`J
M($!F:6YA;`T*("`@("`J+PT*("`@(&9U;F-T:6]N('9A;&ED4W1A=&4H)'-T
M871E*0T*("`@('L-"B`@("`@("`@<F5T=7)N(&EN7V%R<F%Y*"1S=&%T92P@
M87)R87DH)W-N87!S:&]T)RP@)V1E=F5L)RP@)V%L<&AA)RP@)V)E=&$G+"`G
M<W1A8FQE)RDI.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($=E="!A(&QI
M<W0@;V8@=F%L:60@<W1A8FEL:71Y(&QE=F5L<PT*("`@("`J($!R971U<FX@
M87)R87D-"B`@("`@*B!`<W1A=&EC#0H@("`@("H@0&9I;F%L#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@9V5T5F%L:613=&%T97,H*0T*("`@('L-"B`@("`@
M("`@<F5T=7)N(&%R<F%Y*"=S;F%P<VAO="<L("=D979E;"<L("=A;'!H82<L
M("=B971A)RP@)W-T86)L92<I.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J
M($1E=&5R;6EN92!W:&5T:&5R(&$@=F5R<VEO;B!I<R!A('!R;W!E<FQY(&9O
M<FUA='1E9"!V97)S:6]N(&YU;6)E<B!T:&%T(&-A;B!B92!U<V5D#0H@("`@
M("H@8GD@=F5R<VEO;E]C;VUP87)E#0H@("`@("H@0'!A<F%M('-T<FEN9PT*
M("`@("`J($!R971U<FX@8F]O;`T*("`@("`J($!S=&%T:6,-"B`@("`@*B!`
M9FEN86P-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!V86QI9%9E<G-I;VXH)'9E
M<BD-"B`@("![#0H@("`@("`@(')E='5R;B`H8F]O;"D@<')E9U]M871C:"A0
M14%27T-/34U/3E]004-+04=%7U9%4E-)3TY?4%)%1RP@)'9E<BD[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?
M=C%\4$5!4E]086-K86=E1FEL95]V,@T*("`@("`J+PT*("`@(&9U;F-T:6]N
M('-E=%!A8VMA9V5&:6QE*"8D<&8I#0H@("`@>PT*("`@("`@("`D=&AI<RT^
M7W!A8VMA9V5X;6P@/2`F)'!F.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J
M($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]A9&1&
M86EL=7)E*"1F:65L9"P@)')E87-O;BD-"B`@("![#0H@("`@("`@("1T:&ES
M+3Y?9F%I;'5R97-;)V5R<F]R<R==6UT@/2!A<G)A>2@G9FEE;&0G(#T^("1F
M:65L9"P@)W)E87-O;B<@/3X@)')E87-O;BD[#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@7V%D9%=A<FYI;F<H)&9I96QD+"`D<F5A<V]N*0T*("`@('L-"B`@("`@
M("`@)'1H:7,M/E]F86EL=7)E<ULG=V%R;FEN9W,G75M=(#T@87)R87DH)V9I
M96QD)R`]/B`D9FEE;&0L("=R96%S;VXG(#T^("1R96%S;VXI.PT*("`@('T-
M"@T*("`@(&9U;F-T:6]N(&=E=$9A:6QU<F5S*"D-"B`@("![#0H@("`@("`@
M("1F86EL=7)E<R`]("1T:&ES+3Y?9F%I;'5R97,[#0H@("`@("`@("1T:&ES
M+3Y?9F%I;'5R97,@/2!A<G)A>2@G=V%R;FEN9W,G(#T^(&%R<F%Y*"DL("=E
M<G)O<G,G(#T^(&%R<F%Y*"DI.PT*("`@("`@("!R971U<FX@)&9A:6QU<F5S
M.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!I;G0@;VYE(&]F
M('1H92!014%27U9!3$E$051%7RH@8V]N<W1A;G1S#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@=F%L:61A=&4H)'-T871E(#T@;G5L;"D-"B`@("![#0H@("`@
M("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E>&UL*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D
M<W1A=&4@(3T](&YU;&PI('L-"B`@("`@("`@("`@("1T:&ES+3Y?<W1A=&4@
M/2`D<W1A=&4[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]F86EL=7)E
M<R`](&%R<F%Y*"=W87)N:6YG<R<@/3X@87)R87DH*2P@)V5R<F]R<R<@/3X@
M87)R87DH*2D[#0H@("`@("`@("1T:&ES+3YV86QI9&%T95!A8VMA9V5.86UE
M*"D[#0H@("`@("`@("1T:&ES+3YV86QI9&%T959E<G-I;VXH*3L-"B`@("`@
M("`@)'1H:7,M/G9A;&ED871E36%I;G1A:6YE<G,H*3L-"B`@("`@("`@)'1H
M:7,M/G9A;&ED871E1&%T92@I.PT*("`@("`@("`D=&AI<RT^=F%L:61A=&53
M=6UM87)Y*"D[#0H@("`@("`@("1T:&ES+3YV86QI9&%T941E<V-R:7!T:6]N
M*"D[#0H@("`@("`@("1T:&ES+3YV86QI9&%T94QI8V5N<V4H*3L-"B`@("`@
M("`@)'1H:7,M/G9A;&ED871E3F]T97,H*3L-"B`@("`@("`@:68@*"1T:&ES
M+3Y?<&%C:V%G97AM;"T^9V5T4&%C:V%G97AM;%9E<G-I;VXH*2`]/2`G,2XP
M)RD@>PT*("`@("`@("`@("`@)'1H:7,M/G9A;&ED871E4W1A=&4H*3L-"B`@
M("`@("`@("`@("1T:&ES+3YV86QI9&%T949I;&5L:7-T*"D[#0H@("`@("`@
M('T@96QS96EF("@D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=%!A8VMA9V5X;6Q6
M97)S:6]N*"D@/3T@)S(N,"<I('L-"B`@("`@("`@("`@("1T:&ES+3YV86QI
M9&%T951I;64H*3L-"B`@("`@("`@("`@("1T:&ES+3YV86QI9&%T95-T86)I
M;&ET>2@I.PT*("`@("`@("`@("`@)'1H:7,M/G9A;&ED871E1&5P<R@I.PT*
M("`@("`@("`@("`@)'1H:7,M/G9A;&ED871E36%I;D9I;&5L:7-T*"D[#0H@
M("`@("`@("`@("`D=&AI<RT^=F%L:61A=&5296QE87-E1FEL96QI<W0H*3L-
M"B`@("`@("`@("`@("\O)'1H:7,M/G9A;&ED871E1VQO8F%L5&%S:W,H*3L-
M"B`@("`@("`@("`@("1T:&ES+3YV86QI9&%T94-H86YG96QO9R@I.PT*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B`A*"AB;V]L*2!C;W5N="@D=&AI<RT^
M7V9A:6QU<F5S6R=E<G)O<G,G72DI.PT*("`@('T-"@T*("`@("\J*@T*("`@
M("`J($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M=F%L:61A=&5086-K86=E3F%M92@I#0H@("`@>PT*("`@("`@("!I9B`H)'1H
M:7,M/E]S=&%T92`]/2!014%27U9!3$E$051%7U!!0TM!1TE.1R!\?`T*("`@
M("`@("`@("`@("`D=&AI<RT^7W-T871E(#T](%!%05)?5D%,241!5$5?3D]2
M34%,*2![#0H@("`@("`@("`@("!I9B`H)'1H:7,M/E]P86-K86=E>&UL+3YG
M971086-K86=E>&UL5F5R<VEO;B@I(#T]("<R+C`G("8F#0H@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=$5X=&5N9',H*2D@>PT*
M("`@("`@("`@("`@("`@("1V97)S:6]N(#T@)'1H:7,M/E]P86-K86=E>&UL
M+3YG971697)S:6]N*"D@+B`G)SL-"B`@("`@("`@("`@("`@("`D;F%M92`]
M("1T:&ES+3Y?<&%C:V%G97AM;"T^9V5T4&%C:V%G92@I.PT*("`@("`@("`@
M("`@("`@("1T97-T(#T@87)R87E?<VAI9G0H)&$@/2!E>'!L;V1E*"<N)RP@
M)'9E<G-I;VXI*3L-"B`@("`@("`@("`@("`@("!I9B`H)'1E<W0@/3T@)S`G
M*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D=FQE;B`]('-T<FQE;B@D
M=&5S="D[#0H@("`@("`@("`@("`@("`@)&UA:G9E<B`]('-U8G-T<B@D;F%M
M92P@<W1R;&5N*"1N86UE*2`M("1V;&5N*3L-"B`@("`@("`@("`@("`@("!W
M:&EL92`H)&UA:G9E<B`F)B`A:7-?;G5M97)I8R@D;6%J=F5R>S!]*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`D;6%J=F5R(#T@<W5B<W1R*"1M86IV97(L
M(#$I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H
M)&UA:G9E<B`A/2`D=&5S="D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7V%D9%=A<FYI;F<H)W!A8VMA9V4G+"`B<&%C:V%G92`D;F%M92!E>'1E
M;F1S('!A8VMA9V4@(B`N#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A8VMA9V5X;6PM/F=E=$5X=&5N9',H*2`N("<@86YD('-O('1H92!N
M86UE('-H;W5L9"`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("=H879E
M(&$@<&]S=&9I>"!E<75A;"!T;R!T:&4@;6%J;W(@=F5R<VEO;B!L:6ME("(G
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G97AM
M;"T^9V5T17AT96YD<R@I("X@)'1E<W0@+B`G(B<I.PT*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@("`@("!](&5L<V5I
M9B`H<W5B<W1R*"1N86UE+"`P+"!S=')L96XH)&YA;64I("T@)'9L96XI("$]
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E
M>&UL+3YG971%>'1E;F1S*"DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]A9&1787)N:6YG*"=P86-K86=E)RP@(G!A8VMA9V4@)&YA;64@97AT
M96YD<R!P86-K86=E("(@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P86-K86=E>&UL+3YG971%>'1E;F1S*"D@+B`G(&%N9"!S;R!T:&4@
M;F%M92!M=7-T("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)V)E(&%N
M(&5X=&5N<VEO;B!L:6ME("(G("X@)'1H:7,M/E]P86-K86=E>&UL+3YG971%
M>'1E;F1S*"D@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)'1E<W0@+B`G
M(B<I.PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@:68@*"$D=&AI<RT^=F%L:61086-K86=E3F%M92@D=&AI<RT^7W!A8VMA
M9V5X;6PM/F=E=%!A8VMA9V4H*2DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?
M861D1F%I;'5R92@G;F%M92<L("=P86-K86=E(&YA;64@(B<@+@T*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&%C:V%G97AM;"T^9V5T4&%C:V%G92@I("X@
M)R(@:7,@:6YV86QI9"<I.PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@("`@("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0&%C8V5S<R!P
M<F]T96-T960-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!V86QI9&%T959E<G-I
M;VXH*0T*("`@('L-"B`@("`@("`@:68@*"1T:&ES+3Y?<W1A=&4@(3T@4$5!
M4E]604Q)1$%415]004-+04=)3D<I('L-"B`@("`@("`@("`@(&EF("@A)'1H
M:7,M/G9A;&ED5F5R<VEO;B@D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=%9E<G-I
M;VXH*2DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V%D9$9A:6QU<F4H
M)W9E<G-I;VXG+`T*("`@("`@("`@("`@("`@("`@("`G26YV86QI9"!V97)S
M:6]N(&YU;6)E<B`B)R`N("1T:&ES+3Y?<&%C:V%G97AM;"T^9V5T5F5R<VEO
M;B@I("X@)R(G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D=F5R<VEO;B`]("1T:&ES
M+3Y?<&%C:V%G97AM;"T^9V5T5F5R<VEO;B@I.PT*("`@("`@("`D=F5R<VEO
M;F-O;7!O;F5N=',@/2!E>'!L;V1E*"<N)RP@)'9E<G-I;VXI.PT*("`@("`@
M("!I9B`H8V]U;G0H)'9E<G-I;VYC;VUP;VYE;G1S*2`A/2`S*2![#0H@("`@
M("`@("`@("`D=&AI<RT^7V%D9%=A<FYI;F<H)W9E<G-I;VXG+`T*("`@("`@
M("`@("`@("`@("=!('9E<G-I;VX@;G5M8F5R('-H;W5L9"!H879E(#,@9&5C
M:6UA;',@*'@N>2YZ*2<I.PT*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@
M("`@("`@('T-"B`@("`@("`@)&YA;64@/2`D=&AI<RT^7W!A8VMA9V5X;6PM
M/F=E=%!A8VMA9V4H*3L-"B`@("`@("`@+R\@=F5R<VEO;B!M=7-T(&)E(&)A
M<V5D('5P;VX@<W1A=&4-"B`@("`@("`@<W=I=&-H("@D=&AI<RT^7W!A8VMA
M9V5X;6PM/F=E=%-T871E*"DI('L-"B`@("`@("`@("`@(&-A<V4@)W-N87!S
M:&]T)R`Z#0H@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@
M("`@("!C87-E("=D979E;"<@.@T*("`@("`@("`@("`@("`@(&EF("@D=F5R
M<VEO;F-O;7!O;F5N='-;,%T@+B`G82<@/3T@)S!A)RD@>PT*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@:68@*"1V97)S:6]N8V]M<&]N96YT<ULP72`]/2`P
M*2![#0H@("`@("`@("`@("`@("`@("`@("1V97)S:6]N8V]M<&]N96YT<ULP
M72`]("<P)SL-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1787)N
M:6YG*"=V97)S:6]N)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("=V97)S
M:6]N("(G("X@)'9E<G-I;VX@+B`G(B!S:&]U;&0@8F4@(B<@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@:6UP;&]D92@G+B<@+"1V97)S:6]N8V]M<&]N
M96YT<RD@+B`G(B<I.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?861D5V%R;FEN9R@G=F5R<VEO;B<L
M#0H@("`@("`@("`@("`@("`@("`@("`@("`G<&%C:V%G97,@=VET:"!D979E
M;"!S=&%B:6QI='D@;75S="!B92`\('9E<G-I;VX@,2XP+C`G*3L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@
M("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)V%L<&AA)R`Z
M#0H@("`@("`@("`@("!C87-E("=B971A)R`Z#0H@("`@("`@("`@("`@("`@
M+R\@8VAE8VL@9F]R(&$@<&%C:V%G92!T:&%T(&5X=&5N9',@82!P86-K86=E
M+`T*("`@("`@("`@("`@("`@("\O(&QI:V4@1F]O(&%N9"!&;V\R#0H@("`@
M("`@("`@("`@("`@:68@*"1T:&ES+3Y?<W1A=&4@/3T@4$5!4E]604Q)1$%4
M15]004-+04=)3D<I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*'-U8G-T
M<B@D=F5R<VEO;F-O;7!O;F5N='-;,ETL(#$L(#(I(#T]("=R8R<I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?861D1F%I;'5R92@G=F5R
M<VEO;B<L("=296QE87-E($-A;F1I9&%T92!V97)S:6]N<R`G("X-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G;75S="!H879E(&-A<&ET86P@4D,L
M(&YO="!L;W=E<BUC87-E(')C)RD[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"$D=&AI<RT^7W!A
M8VMA9V5X;6PM/F=E=$5X=&5N9',H*2D@>PT*("`@("`@("`@("`@("`@("`@
M("!I9B`H)'9E<G-I;VYC;VUP;VYE;G1S6S!=(#T]("<Q)RD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"1V97)S:6]N8V]M<&]N96YT<ULR77LP
M?2`]/2`G,"<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M)'9E<G-I;VYC;VUP;VYE;G1S6S)=(#T]("<P)RD@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`O+R!V97)S:6]N(#$N*BXP,#`P#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?861D5V%R;FEN
M9R@G=F5R<VEO;B<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G=F5R<VEO;B`Q+B<@+B`D=F5R<VEO;F-O;7!O;F5N='-;,5T@+@T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<N,"!P
M<F]B86)L>2!S:&]U;&0@;F]T(&)E(&%L<&AA(&]R(&)E=&$G*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*'-T<FQE;B@D=F5R
M<VEO;F-O;7!O;F5N='-;,ETI(#X@,2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!V97)S:6]N(#$N*BXP4D,Q(&]R(#$N*BXP8F5T
M83(T(&5T8RX-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@=F5R<VEO
M;B`Q+BHN,`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7V%D9%=A<FYI;F<H)W9E<G-I;VXG+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W9E<G-I;VX@,2XG("X@)'9E<G-I;VYC;VUP
M;VYE;G1S6S%=("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G+C`@<')O8F%B;'D@<VAO=6QD(&YO="!B92!A;'!H82!O<B!B
M971A)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;B!T<G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]A9&1787)N:6YG*"=V97)S:6]N)RP-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V)U9V9I>"!V97)S:6]N
M<R`H,2XS+G@@=VAE<F4@>"`^(#`I('!R;V)A8FQY('-H;W5L9"`G("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYO="!B92!A;'!H82!O
M<B!B971A)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M('1R=64[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@('T@96QS96EF("@D=F5R<VEO;F-O;7!O;F5N='-;,%T@(3T@
M)S`G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%D9%=A
M<FYI;F<H)W9E<G-I;VXG+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=M86IO<B!V97)S:6]N<R!G<F5A=&5R('1H86X@,2!A<F4@;F]T(&%L;&]W
M960@9F]R('!A8VMA9V5S("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=W:71H;W5T(&%N(#QE>'1E;F1S/B!T86<@;W(@86X@:61E;G1I8V%L
M('!O<W1F:7@@*&9O;S(@=C(N,"XP*2<I.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@:68@*"1V97)S:6]N8V]M<&]N96YT<ULP72`N
M("=A)R`]/2`G,&$G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U
M<FX@=')U93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("!I9B`H)'9E<G-I;VYC;VUP;VYE;G1S6S!=(#T](#`I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1V97)S:6]N8V]M<&]N96YT<ULP72`]
M("<P)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?861D5V%R
M;FEN9R@G=F5R<VEO;B<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W9E<G-I;VX@(B<@+B`D=F5R<VEO;B`N("<B('-H;W5L9"!B92`B)R`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:6UP;&]D92@G+B<@+"1V97)S
M:6]N8V]M<&]N96YT<RD@+B`G(B<I.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@
M("`@)'9L96X@/2!S=')L96XH)'9E<G-I;VYC;VUP;VYE;G1S6S!=("X@)R<I
M.PT*("`@("`@("`@("`@("`@("`@("`D;6%J=F5R(#T@<W5B<W1R*"1N86UE
M+"!S=')L96XH)&YA;64I("T@)'9L96XI.PT*("`@("`@("`@("`@("`@("`@
M("!W:&EL92`H)&UA:G9E<B`F)B`A:7-?;G5M97)I8R@D;6%J=F5R>S!]*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&UA:G9E<B`]('-U8G-T<B@D
M;6%J=F5R+"`Q*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("!I9B`H*"1V97)S:6]N8V]M<&]N96YT<ULP72`A/2`P*2`F
M)B`D;6%J=F5R("$]("1V97)S:6]N8V]M<&]N96YT<ULP72D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1787)N:6YG*"=V97)S:6]N
M)RP@)V9I<G-T('9E<G-I;VX@;G5M8F5R("(G("X-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=F5R<VEO;F-O;7!O;F5N='-;,%T@+B`G(B!M=7-T
M(&UA=&-H('1H92!P;W-T9FEX(&]F("<@+@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=P86-K86=E(&YA;64@(B<@+B`D;F%M92`N("<B("@G("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;6%J=F5R("X@)RDG*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@D=F5R
M<VEO;F-O;7!O;F5N='-;,%T@/3T@)&UA:G9E<BD@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"1V97)S:6]N8V]M<&]N96YT<ULR77LP?2`]/2`G
M,"<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'9E<G-I
M;VYC;VUP;VYE;G1S6S)=(#T]("<P)RD@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!V97)S:6]N(#(N*BXP,#`P#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?861D5V%R;FEN9R@G=F5R
M<VEO;B<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B
M=F5R<VEO;B`D;6%J=F5R+B(@+B`D=F5R<VEO;F-O;7!O;F5N='-;,5T@+@T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<N,"!P
M<F]B86)L>2!S:&]U;&0@;F]T(&)E(&%L<&AA(&]R(&)E=&$G*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF("AS=')L96XH)'9E
M<G-I;VYC;VUP;VYE;G1S6S)=*2`^(#$I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@=F5R<VEO;B`R+BHN,%)#,2!O<B`R+BHN,&)E
M=&$R-"!E=&,N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E
M='5R;B!T<G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O('9E<G-I
M;VX@,BXJ+C`-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]A9&1787)N:6YG*"=V97)S:6]N)RP-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(")V97)S:6]N("1M86IV97(N(B`N("1V97)S
M:6]N8V]M<&]N96YT<ULQ72`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)RXP(&-A;FYO="!B92!A;'!H82!O<B!B971A)RD[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]A9&1787)N:6YG*"=V97)S:6]N)RP-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(F)U9V9I>"!V97)S:6]N<R`H)&UA
M:G9E<BYX+GD@=VAE<F4@>2`^(#`I('-H;W5L9"`B("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)VYO="!B92!A;'!H82!O<B!B971A)RD[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M('T@96QS96EF("@D=F5R<VEO;F-O;7!O;F5N='-;,%T@(3T@)S`G*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%D9%=A<FYI;F<H)W9E
M<G-I;VXG+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(")O;FQY('9E
M<G-I;VYS(#`N>"YY(&%N9"`D;6%J=F5R+G@N>2!A<F4@86QL;W=E9"!F;W(@
M86QP:&$O8F5T82!R96QE87-E<R(I.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@:68@*"1V97)S:6]N8V]M<&]N96YT<ULP72`N("=A
M)R`]/2`G,&$G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@
M=')U93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("!I9B`H)'9E<G-I;VYC;VUP;VYE;G1S6S!=(#T](#`I('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1V97)S:6]N8V]M<&]N96YT<ULP72`]("<P
M)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?861D5V%R;FEN
M9R@G=F5R<VEO;B<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W9E
M<G-I;VX@(B<@+B`D=F5R<VEO;B`N("<B('-H;W5L9"!B92`B)R`N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:6UP;&]D92@G+B<@+"1V97)S:6]N
M8V]M<&]N96YT<RD@+B`G(B<I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E
M.PT*("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=S=&%B
M;&4G(#H-"B`@("`@("`@("`@("`@("!I9B`H)'9E<G-I;VYC;VUP;VYE;G1S
M6S!=(#T]("<P)RD@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%D
M9%=A<FYI;F<H)W9E<G-I;VXG+"`G=F5R<VEO;G,@;&5S<R!T:&%N(#$N,"XP
M(&-A;FYO="`G("X-"B`@("`@("`@("`@("`@("`@("`@)V)E('-T86)L92<I
M.PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"%I<U]N=6UE<FEC*"1V
M97)S:6]N8V]M<&]N96YT<ULR72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*'!R96=?;6%T8V@H)R]<9"LH<F-\87QA;'!H87QB?&)E=&$I7&0J+VDG
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`D=F5R<VEO;F-O;7!O;F5N
M='-;,ETI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%D
M9%=A<FYI;F<H)W9E<G-I;VXG+"`G=F5R<VEO;B`B)R`N("1V97)S:6]N("X@
M)R(@;W(@86YY("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=2
M0R]B971A+V%L<&AA('9E<G-I;VX@8V%N;F]T(&)E('-T86)L92<I.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@+R\@8VAE8VL@9F]R(&$@<&%C:V%G92!T:&%T(&5X=&5N9',@82!P86-K
M86=E+`T*("`@("`@("`@("`@("`@("\O(&QI:V4@1F]O(&%N9"!&;V\R#0H@
M("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?<&%C:V%G97AM;"T^9V5T17AT
M96YD<R@I*2![#0H@("`@("`@("`@("`@("`@("`@("1V;&5N(#T@<W1R;&5N
M*"1V97)S:6]N8V]M<&]N96YT<ULP72`N("<G*3L-"B`@("`@("`@("`@("`@
M("`@("`@)&UA:G9E<B`]('-U8G-T<B@D;F%M92P@<W1R;&5N*"1N86UE*2`M
M("1V;&5N*3L-"B`@("`@("`@("`@("`@("`@("`@=VAI;&4@*"1M86IV97(@
M)B8@(6ES7VYU;65R:6,H)&UA:G9E<GLP?2DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1M86IV97(@/2!S=6)S='(H)&UA:G9E<BP@,2D[#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"@D
M=F5R<VEO;F-O;7!O;F5N='-;,%T@(3T@,"D@)B8@)&UA:G9E<B`A/2`D=F5R
M<VEO;F-O;7!O;F5N='-;,%TI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?861D5V%R;FEN9R@G=F5R<VEO;B<L("=F:7)S="!V97)S:6]N
M(&YU;6)E<B`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9E
M<G-I;VYC;VUP;VYE;G1S6S!=("X@)R(@;75S="!M871C:"!T:&4@<&]S=&9I
M>"!O9B`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<&%C:V%G
M92!N86UE("(G("X@)&YA;64@+B`G(B`H)R`N#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&UA:G9E<B`N("<I)RD[#0H@("`@("`@("`@("`@("`@
M("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@('T@96QS96EF("@D=F5R<VEO;F-O;7!O;F5N='-;
M,%T@/B`Q*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?861D5V%R
M;FEN9R@G=F5R<VEO;B<L("=M86IO<B!V97)S:6]N('@@:6X@>"YY+GH@;6%Y
M(&YO="!B92!G<F5A=&5R('1H86X@)R`N#0H@("`@("`@("`@("`@("`@("`@
M("`@("`G,2!F;W(@86YY('!A8VMA9V4@=&AA="!D;V5S(&YO="!H879E(&%N
M(#QE>'1E;F1S/B!T86<G*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("!B<F5A:SL-"B`@
M("`@("`@("`@(&1E9F%U;'0@.@T*("`@("`@("`@("`@("`@(')E='5R;B!F
M86QS93L-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("!]#0H@("`@?0T*
M#0H@("`@+RHJ#0H@("`@("H@0&%C8V5S<R!P<F]T96-T960-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!V86QI9&%T94UA:6YT86EN97)S*"D-"B`@("![#0H@
M("`@("`@("\O(&UA:6YT86EN97)S(&-A;B!O;FQY(&)E('1R=6QY('9A;&ED
M871E9"!S97)V97(M<VED92!F;W(@;6]S="!C:&%N;F5L<PT*("`@("`@("`O
M+R!B=70@86QL;W<@=&AI<R!C=7-T;VUI>F%T:6]N(&9O<B!T:&]S92!W:&\@
M=VES:"!I=`T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O
M*BH-"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`T*("`@("`J+PT*("`@(&9U
M;F-T:6]N('9A;&ED871E1&%T92@I#0H@("`@>PT*("`@("`@("!I9B`H)'1H
M:7,M/E]S=&%T92`]/2!014%27U9!3$E$051%7TY/4DU!3"!\?`T*("`@("`@
M("`@("`@("`D=&AI<RT^7W-T871E(#T](%!%05)?5D%,241!5$5?4$%#2T%'
M24Y'*2![#0H@("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H)R]<9%QD7&1<
M9%PM7&1<9%PM7&1<9"\G+`T*("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M86-K86=E>&UL+3YG971$871E*"DI*2![#0H@("`@("`@("`@("`@("`@)'1H
M:7,M/E]A9&1&86EL=7)E*"=D871E)RP@)VEN=F%L:60@<F5L96%S92!D871E
M("(G("X-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E>&UL
M+3YG971$871E*"D@+B`G(B<I.PT*("`@("`@("`@("`@("`@(')E='5R;B!F
M86QS93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AS=')T;W1I
M;64H)'1H:7,M/E]P86-K86=E>&UL+3YG971$871E*"DI(#T]("TQ*2![#0H@
M("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1&86EL=7)E*"=D871E)RP@)VEN
M=F%L:60@<F5L96%S92!D871E("(G("X-"B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P86-K86=E>&UL+3YG971$871E*"D@+B`G(B<I.PT*("`@("`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&EF("@D=&AI<RT^7W-T871E(#T](%!%05)?5D%,241!5$5?4$%#
M2T%'24Y'("8F#0H@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5X
M;6PM/F=E=$1A=&4H*2`A/2!D871E*"=9+6TM9"<I*2![#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]A9&1787)N:6YG*"=D871E)RP@)U)E;&5A<V4@1&%T
M92`B)R`N#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G97AM
M;"T^9V5T1&%T92@I("X@)R(@:7,@;F]T('1O9&%Y)RD[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*
M#0H@("`@+RHJ#0H@("`@("H@0&%C8V5S<R!P<F]T96-T960-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!V86QI9&%T951I;64H*0T*("`@('L-"B`@("`@("`@
M:68@*"$D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=%1I;64H*2D@>PT*("`@("`@
M("`@("`@+R\@9&5F875L="!O9B!N;R!T:6UE('9A;'5E('-E=`T*("`@("`@
M("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@+R\@<&%C
M:V%G97(@875T;VUA=&EC86QL>2!S971S('1I;64L('-O(&]N;'D@=F%L:61A
M=&4@:68-"B`@("`@("`@+R\@<&5A<B!V86QI9&%T92!I<R!C86QL960-"B`@
M("`@("`@:68@*"1T:&ES+3Y?<W1A=&4@/2!014%27U9!3$E$051%7TY/4DU!
M3"D@>PT*("`@("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"<O7&1<9#I<9%QD
M.EQD7&0O)RP-"B`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G97AM
M;"T^9V5T5&EM92@I*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?861D
M1F%I;'5R92@G=&EM92<L("=I;G9A;&ED(')E;&5A<V4@=&EM92`B)R`N#0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G97AM;"T^9V5T5&EM
M92@I("X@)R(G*3L-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H<W1R=&]T:6UE*"1T:&ES
M+3Y?<&%C:V%G97AM;"T^9V5T5&EM92@I*2`]/2`M,2D@>PT*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?861D1F%I;'5R92@G=&EM92<L("=I;G9A;&ED(')E
M;&5A<V4@=&EM92`B)R`N#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%C:V%G97AM;"T^9V5T5&EM92@I("X@)R(G*3L-"B`@("`@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M0&%C8V5S<R!P<F]T96-T960-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!V86QI
M9&%T95-T871E*"D-"B`@("![#0H@("`@("`@("\O('1H:7,@:7,@=&AE(&-L
M;W-E<W0@=&\@(F9I;F%L(B!P:'`T(&-A;B!G970-"B`@("`@("`@:68@*"%0
M14%27U9A;&ED871E.CIV86QI9%-T871E*"1T:&ES+3Y?<&%C:V%G97AM;"T^
M9V5T4W1A=&4H*2DI('L-"B`@("`@("`@("`@(&EF("AS=')T;VQO=V5R*"1T
M:&ES+3Y?<&%C:V%G97AM;"T^9V5T4W1A=&4H*2`]/2`G<F,G*2D@>PT*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?861D1F%I;'5R92@G<W1A=&4G+"`G4D,@
M:7,@;F]T(&$@<W1A=&4L(&ET(&ES(&$@=F5R<VEO;B`G("X-"B`@("`@("`@
M("`@("`@("`@("`@)W!O<W1F:7@L('5S92`G("X@)'1H:7,M/E]P86-K86=E
M>&UL+3YG971697)S:6]N*"D@+B`G4D,Q+"!S=&%T92!B971A)RD[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`D=&AI<RT^7V%D9$9A:6QU<F4H)W-T
M871E)RP@)VEN=F%L:60@<F5L96%S92!S=&%T92`B)R`N#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P86-K86=E>&UL+3YG9713=&%T92@I("X@)R(L(&UU
M<W0@8F4@;VYE(&]F.B`G("X-"B`@("`@("`@("`@("`@("!I;7!L;V1E*"<L
M("<L(%!%05)?5F%L:61A=&4Z.F=E=%9A;&ED4W1A=&5S*"DI*3L-"B`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`86-C97-S('!R
M;W1E8W1E9`T*("`@("`J+PT*("`@(&9U;F-T:6]N('9A;&ED871E4W1A8FEL
M:71Y*"D-"B`@("![#0H@("`@("`@("1R970@/2!T<G5E.PT*("`@("`@("`D
M<&%C:V%G97-T86)I;&ET>2`]("1T:&ES+3Y?<&%C:V%G97AM;"T^9V5T4W1A
M=&4H*3L-"B`@("`@("`@)&%P:7-T86)I;&ET>2`]("1T:&ES+3Y?<&%C:V%G
M97AM;"T^9V5T4W1A=&4H)V%P:2<I.PT*("`@("`@("!I9B`H(5!%05)?5F%L
M:61A=&4Z.G9A;&ED4W1A=&4H)'!A8VMA9V5S=&%B:6QI='DI*2![#0H@("`@
M("`@("`@("`D=&AI<RT^7V%D9$9A:6QU<F4H)W-T871E)RP@)VEN=F%L:60@
M<F5L96%S92!S=&%B:6QI='D@(B<@+@T*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%C:V%G97AM;"T^9V5T4W1A=&4H*2`N("<B+"!M=7-T(&)E(&]N92!O
M9CH@)R`N#0H@("`@("`@("`@("`@("`@:6UP;&]D92@G+"`G+"!014%27U9A
M;&ED871E.CIG971686QI9%-T871E<R@I*2D[#0H@("`@("`@("`@("`D<F5T
M(#T@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)&%P:7-T871E<R`](%!%
M05)?5F%L:61A=&4Z.F=E=%9A;&ED4W1A=&5S*"D[#0H@("`@("`@(&%R<F%Y
M7W-H:69T*"1A<&ES=&%T97,I.R`O+R!S;F%P<VAO="!I<R!N;W0@86QL;W=E
M9`T*("`@("`@("!I9B`H(6EN7V%R<F%Y*"1A<&ES=&%B:6QI='DL("1A<&ES
M=&%T97,I*2![#0H@("`@("`@("`@("`D=&AI<RT^7V%D9$9A:6QU<F4H)W-T
M871E)RP@)VEN=F%L:60@05!)('-T86)I;&ET>2`B)R`N#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P86-K86=E>&UL+3YG9713=&%T92@G87!I)RD@+B`G
M(BP@;75S="!B92!O;F4@;V8Z("<@+@T*("`@("`@("`@("`@("`@(&EM<&QO
M9&4H)RP@)RP@)&%P:7-T871E<RDI.PT*("`@("`@("`@("`@)')E="`](&9A
M;'-E.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-
M"@T*("`@("\J*@T*("`@("`J($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@=F%L:61A=&53=6UM87)Y*"D-"B`@("![#0H@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!A
M8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=F%L:61A
M=&5$97-C<FEP=&EO;B@I#0H@("`@>PT*("`@("`@("!R971U<FX@=')U93L-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`T*
M("`@("`J+PT*("`@(&9U;F-T:6]N('9A;&ED871E3&EC96YS92@I#0H@("`@
M>PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!`86-C97-S('!R;W1E8W1E9`T*("`@("`J+PT*("`@(&9U;F-T:6]N
M('9A;&ED871E3F]T97,H*0T*("`@('L-"B`@("`@("`@<F5T=7)N('1R=64[
M#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@9F]R('!A8VMA9V4N>&UL(#(N
M,"!O;FQY("T@8VAA;FYE;',@8V%N)W0@=7-E('!A8VMA9V4N>&UL(#$N,`T*
M("`@("`J($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@=F%L:61A=&5$97!E;F1E;F-I97,H*0T*("`@('L-"B`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@9F]R('!A8VMA
M9V4N>&UL(#$N,"!O;FQY#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@7W9A;&ED871E1FEL96QI<W0H*0T*("`@('L-
M"B`@("`@("`@<F5T=7)N('1R=64[("\O('!L86-E:&]L9&5R(&9O<B!N;W<-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!F;W(@<&%C:V%G92YX;6P@,BXP
M(&]N;'D-"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`T*("`@("`J+PT*("`@
M(&9U;F-T:6]N('9A;&ED871E36%I;D9I;&5L:7-T*"D-"B`@("![#0H@("`@
M("`@(')E='5R;B!T<G5E.R`O+R!P;&%C96AO;&1E<B!F;W(@;F]W#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@9F]R('!A8VMA9V4N>&UL(#(N,"!O;FQY
M#0H@("`@("H@0&%C8V5S<R!P<F]T96-T960-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!V86QI9&%T95)E;&5A<V5&:6QE;&ES="@I#0H@("`@>PT*("`@("`@
M("!R971U<FX@=')U93L@+R\@<&QA8V5H;VQD97(@9F]R(&YO=PT*("`@('T-
M"@T*("`@("\J*@T*("`@("`J($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@=F%L:61A=&5#:&%N9V5L;V<H*0T*("`@('L-"B`@
M("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M0&%C8V5S<R!P<F]T96-T960-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!V86QI
M9&%T949I;&5L:7-T*"D-"B`@("![#0H@("`@("`@(')E='5R;B!T<G5E.PT*
M("`@('T-"@T*("`@("\J*@T*("`@("`J($!A8V-E<W,@<')O=&5C=&5D#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@=F%L:61A=&5$97!S*"D-"B`@("![#0H@
M("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"GT-"C\^````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]014%2+UA-3%!A<G-E<BYP:'``````````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#$W-#<Q(#$P-3$U-#,S-S,R(#`R,34U-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`T*+RHJ
M#0H@*B!014%27T944`T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@
M*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O
M('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A
M=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O
M;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S
M7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J
M('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@
M=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI
M8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D
M:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E
M("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`
M<&AP+FYE=#X-"B`J($!A=71H;W(@("`@(%-T97!H86X@4V-H;6ED="`H;W)I
M9VEN86P@6$U,7U5N<V5R:6%L:7IE<B!C;V1E*0T*("H@0&-O<'ER:6=H="`@
M,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N
M,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%A-3%!A<G-E<BYP:'`L=B`Q
M+C$Q(#(P,#8O,#$O,#8@,#0Z-#<Z,S8@8V5L;&]G($5X<"`D#0H@*B!`;&EN
M:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@
M0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N
M,&$Q#0H@*B\-"@T*+RHJ#0H@*B!087)S97(@9F]R(&%N>2!X;6P@9FEL90T*
M("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@
M0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@
M0&%U=&AO<B`@("`@4W1E<&AA;B!38VAM:61T("AO<FEG:6YA;"!834Q?56YS
M97)I86QI>F5R(&-O9&4I#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE
M(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO
M;B`@("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E
M87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S
M(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*8VQA<W,@
M4$5!4E]834Q087)S97(-"GL-"B`@("`O*BH-"B`@("`@*B!U;G-E<FEL:6%L
M:7IE9"!D871A#0H@("`@("H@0'9A<B!S=')I;F<@)%]S97)I86QI>F5D1&%T
M80T*("`@("`J+PT*("`@('9A<B`D7W5N<V5R:6%L:7IE9$1A=&$@/2!N=6QL
M.PT*#0H@("`@+RHJ#0H@("`@("H@;F%M92!O9B!T:&4@<F]O="!T86<-"B`@
M("`@*B!`=F%R('-T<FEN9R`D7W)O;W0-"B`@("`@*B\-"B`@("!V87(@)%]R
M;V]T(#T@;G5L;#L-"@T*("`@("\J*@T*("`@("`J('-T86-K(&9O<B!A;&P@
M9&%T82!T:&%T(&ES(&9O=6YD#0H@("`@("H@0'9A<B!A<G)A>2`@("`D7V1A
M=&%3=&%C:PT*("`@("`J+PT*("`@('9A<B`D7V1A=&%3=&%C:R`@/2`@(&%R
M<F%Y*"D[#0H-"B`@("`O*BH-"B`@("`@*B!S=&%C:R!F;W(@86QL('9A;'5E
M<R!T:&%T(&%R92!G96YE<F%T960-"B`@("`@*B!`=F%R(&%R<F%Y("`@("1?
M=F%L4W1A8VL-"B`@("`@*B\-"B`@("!V87(@)%]V86Q3=&%C:R`@/2`@(&%R
M<F%Y*"D[#0H-"B`@("`O*BH-"B`@("`@*B!C=7)R96YT('1A9R!D97!T:`T*
M("`@("`J($!V87(@:6YT("`@("1?9&5P=&@-"B`@("`@*B\-"B`@("!V87(@
M)%]D97!T:"`](#`[#0H-"B`@("`O*BH-"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T1&%T82@I#0H@("`@>PT*("`@
M("`@("!R971U<FX@)'1H:7,M/E]U;G-E<FEA;&EZ961$871A.PT*("`@('T-
M"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S=')I;F<@>&UL(&-O;G1E;G0-
M"B`@("`@*B!`<F5T=7)N('1R=65\4$5!4E]%<G)O<@T*("`@("`J+PT*("`@
M(&9U;F-T:6]N('!A<G-E*"1D871A*0T*("`@('L-"B`@("`@("`@:68@*"%E
M>'1E;G-I;VY?;&]A9&5D*"=X;6PG*2D@>PT*("`@("`@("`@("`@:6YC;'5D
M95]O;F-E("=014%2+G!H<"<[#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@B6$U,($5X=&5N<VEO;B!N;W0@9F]U;F0B+"`Q*3L-"B`@
M("`@("`@?0T*("`@("`@("`D=&AI<RT^7W9A;%-T86-K(#T@87)R87DH*3L-
M"B`@("`@("`@)'1H:7,M/E]D871A4W1A8VL@/2!A<G)A>2@I.PT*("`@("`@
M("`D=&AI<RT^7V1E<'1H(#T@,#L-"@T*("`@("`@("!I9B`H=F5R<VEO;E]C
M;VUP87)E*'!H<'9E<G-I;VXH*2P@)S4N,"XP)RP@)VQT)RDI('L-"B`@("`@
M("`@("`@(&EF("AS=')P;W,H)&1A=&$L("=E;F-O9&EN9STB551&+3@B)RDI
M('L-"B`@("`@("`@("`@("`@("`D9&%T82`]('5T9CA?9&5C;V1E*"1D871A
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1X<"`]($!X;6Q?<&%R
M<V5R7V-R96%T92@G25-/+3@X-3DM,2<I.PT*("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@:68@*'-T<G!O<R@D9&%T82P@)V5N8V]D:6YG/2)55$8M
M."(G*2D@>PT*("`@("`@("`@("`@("`@("1X<"`]($!X;6Q?<&%R<V5R7V-R
M96%T92@G551&+3@G*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@)'AP(#T@0'AM;%]P87)S97)?8W)E871E*"=)4T\M.#@U.2TQ
M)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@>&UL7W!A
M<G-E<E]S971?;W!T:6]N*"1X<"P@6$U,7T]05$E/3E]#05-%7T9/3$1)3D<L
M(#`I.PT*("`@("`@("!X;6Q?<V5T7V]B:F5C="@D>'`L("1T:&ES*3L-"B`@
M("`@("`@>&UL7W-E=%]E;&5M96YT7VAA;F1L97(H)'AP+"`G<W1A<G1(86YD
M;&5R)RP@)V5N9$AA;F1L97(G*3L-"B`@("`@("`@>&UL7W-E=%]C:&%R86-T
M97)?9&%T85]H86YD;&5R*"1X<"P@)V-D871A2&%N9&QE<B<I.PT*("`@("`@
M("!I9B`H(7AM;%]P87)S92@D>'`L("1D871A*2D@>PT*("`@("`@("`@("`@
M)&US9R`]('AM;%]E<G)O<E]S=')I;F<H>&UL7V=E=%]E<G)O<E]C;V1E*"1X
M<"DI.PT*("`@("`@("`@("`@)&QI;F4@/2!X;6Q?9V5T7V-U<G)E;G1?;&EN
M95]N=6UB97(H)'AP*3L-"B`@("`@("`@("`@('AM;%]P87)S97)?9G)E92@D
M>'`I.PT*("`@("`@("`@("`@:6YC;'5D95]O;F-E("=014%2+G!H<"<[#0H@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B6$U,($5R<F]R
M.B`G)&US9R<@;VX@;&EN92`G)&QI;F4G(BP@,BD[#0H@("`@("`@('T-"B`@
M("`@("`@>&UL7W!A<G-E<E]F<F5E*"1X<"D[#0H@("`@("`@(')E='5R;B!T
M<G5E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%-T87)T(&5L96UE;G0@
M:&%N9&QE<B!F;W(@6$U,('!A<G-E<@T*("`@("`J#0H@("`@("H@0&%C8V5S
M<R!P<FEV871E#0H@("`@("H@0'!A<F%M("!O8FIE8W0@)'!A<G-E<B`@6$U,
M('!A<G-E<B!O8FIE8W0-"B`@("`@*B!`<&%R86T@('-T<FEN9R`D96QE;65N
M="!834P@96QE;65N=`T*("`@("`J($!P87)A;2`@87)R87D@("1A='1R:6)S
M(&%T=')I8G5T97,@;V8@6$U,('1A9PT*("`@("`J($!R971U<FX@=F]I9`T*
M("`@("`J+PT*("`@(&9U;F-T:6]N('-T87)T2&%N9&QE<B@D<&%R<V5R+"`D
M96QE;65N="P@)&%T=')I8G,I#0H@("`@>PT*("`@("`@("`D='EP92`]("=S
M=')I;F<G.PT*#0H@("`@("`@("1T:&ES+3Y?9&5P=&@K*SL-"B`@("`@("`@
M)'1H:7,M/E]D871A4W1A8VM;)'1H:7,M/E]D97!T:%T@/2!N=6QL.PT*#0H@
M("`@("`@("1V86P@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("=N
M86UE)R`@("`@("`@(#T^("1E;&5M96YT+`T*("`@("`@("`@("`@("`@("`@
M("`@)W9A;'5E)R`@("`@("`@/3X@;G5L;"P-"B`@("`@("`@("`@("`@("`@
M("`@("=T>7!E)R`@("`@("`@(#T^("1T>7!E+`T*("`@("`@("`@("`@("`@
M("`@("`@)V-H:6QD<F5N2V5Y<R<@/3X@87)R87DH*2P-"B`@("`@("`@("`@
M("`@("`@("`@("=A9V=R96=+97ES)R`@(#T^(&%R<F%Y*"D-"B`@("`@("`@
M("`@("`@("`@("`@*3L-"@T*("`@("`@("!I9B`H8V]U;G0H)&%T=')I8G,I
M(#X@,"D@>PT*("`@("`@("`@("`@)'9A;%LG8VAI;&1R96XG72`](&%R<F%Y
M*"D[#0H@("`@("`@("`@("`D=F%L6R=T>7!E)UT@/2`G87)R87DG.PT*#0H@
M("`@("`@("`@("`D=F%L6R=C:&EL9')E;B==6R=A='1R:6)S)UT@/2`D871T
M<FEB<SL-"@T*("`@("`@("!]#0H-"B`@("`@("`@87)R87E?<'5S:"@D=&AI
M<RT^7W9A;%-T86-K+"`D=F%L*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!P;W-T+7!R;V-E<W,@9&%T80T*("`@("`J#0H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9&%T80T*("`@("`J($!P87)A;2!S=')I;F<@)&5L96UE;G0@96QE
M;65N="!N86UE#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<&]S=%!R;V-E<W,H
M)&1A=&$L("1E;&5M96YT*0T*("`@('L-"B`@("`@("`@<F5T=7)N('1R:6TH
M)&1A=&$I.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($5N9"!E;&5M96YT
M(&AA;F1L97(@9F]R(%A-3"!P87)S97(-"B`@("`@*@T*("`@("`J($!A8V-E
M<W,@<')I=F%T90T*("`@("`J($!P87)A;2`@;V)J96-T(%A-3"!P87)S97(@
M;V)J96-T#0H@("`@("H@0'!A<F%M("!S=')I;F<-"B`@("`@*B!`<F5T=7)N
M('9O:60-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!E;F1(86YD;&5R*"1P87)S
M97(L("1E;&5M96YT*0T*("`@('L-"B`@("`@("`@)'9A;'5E(#T@87)R87E?
M<&]P*"1T:&ES+3Y?=F%L4W1A8VLI.PT*("`@("`@("`D9&%T82`@/2`D=&AI
M<RT^<&]S=%!R;V-E<W,H)'1H:7,M/E]D871A4W1A8VM;)'1H:7,M/E]D97!T
M:%TL("1E;&5M96YT*3L-"@T*("`@("`@("`O+R!A9&IU<W0@='EP92!O9B!T
M:&4@=F%L=64-"B`@("`@("`@<W=I=&-H*'-T<G1O;&]W97(H)'9A;'5E6R=T
M>7!E)UTI*2![#0H-"B`@("`@("`@("`@("\J#0H@("`@("`@("`@("`@*B!U
M;G-E<FEA;&EZ92!A;B!A<G)A>0T*("`@("`@("`@("`@("HO#0H@("`@("`@
M("`@("!C87-E("=A<G)A>2<Z#0H@("`@("`@("`@("`@("`@:68@*"1D871A
M("$]/2`G)RD@>PT*("`@("`@("`@("`@("`@("`@("`D=F%L=65;)V-H:6QD
M<F5N)UU;)U]C;VYT96YT)UT@/2`D9&%T83L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1V86QU95LG8VAI;&1R96XG
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'9A;'5E6R=V86QU92==(#T@
M)'9A;'5E6R=C:&EL9')E;B==.PT*("`@("`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@("`@("1V86QU95LG=F%L=64G72`](&%R<F%Y
M*"D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&)R96%K
M.PT*#0H@("`@("`@("`@("`O*@T*("`@("`@("`@("`@("H@=6YS97)I86QI
M>F4@82!N=6QL('9A;'5E#0H@("`@("`@("`@("`@*B\-"B`@("`@("`@("`@
M(&-A<V4@)VYU;&PG.@T*("`@("`@("`@("`@("`@("1D871A(#T@;G5L;#L-
M"B`@("`@("`@("`@("`@("!B<F5A:SL-"@T*("`@("`@("`@("`@+RH-"B`@
M("`@("`@("`@("`J('5N<V5R:6%L:7IE(&%N>2!S8V%L87(@=F%L=64-"B`@
M("`@("`@("`@("`J+PT*("`@("`@("`@("`@9&5F875L=#H-"B`@("`@("`@
M("`@("`@("!S971T>7!E*"1D871A+"`D=F%L=65;)W1Y<&4G72D[#0H@("`@
M("`@("`@("`@("`@)'9A;'5E6R=V86QU92==(#T@)&1A=&$[#0H@("`@("`@
M("`@("`@("`@8G)E86L[#0H@("`@("`@('T-"B`@("`@("`@)'!A<F5N="`]
M(&%R<F%Y7W!O<"@D=&AI<RT^7W9A;%-T86-K*3L-"B`@("`@("`@:68@*"1P
M87)E;G0@/3T](&YU;&PI('L-"B`@("`@("`@("`@("1T:&ES+3Y?=6YS97)I
M86QI>F5D1&%T82`]("8D=F%L=65;)W9A;'5E)UT[#0H@("`@("`@("`@("`D
M=&AI<RT^7W)O;W0@/2`F)'9A;'5E6R=N86UE)UT[#0H@("`@("`@("`@("!R
M971U<FX@=')U93L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("\O
M('!A<F5N="!H87,@=&\@8F4@86X@87)R87D-"B`@("`@("`@("`@(&EF("@A
M:7-S970H)'!A<F5N=%LG8VAI;&1R96XG72D@?'P@(6ES7V%R<F%Y*"1P87)E
M;G1;)V-H:6QD<F5N)UTI*2![#0H@("`@("`@("`@("`@("`@)'!A<F5N=%LG
M8VAI;&1R96XG72`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@:68@*"1P
M87)E;G1;)W1Y<&4G72`A/2`G87)R87DG*2![#0H@("`@("`@("`@("`@("`@
M("`@("1P87)E;G1;)W1Y<&4G72`]("=A<G)A>2<[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@?0T*#0H@("`@("`@("`@("!I9B`H(65M<'1Y
M*"1V86QU95LG;F%M92==*2D@>PT*("`@("`@("`@("`@("`@("\O('1H97)E
M(&%L<F5A9'D@:&%S(&)E96X@82!T86<@=VET:"!T:&ES(&YA;64-"B`@("`@
M("`@("`@("`@("!I9B`H:6Y?87)R87DH)'9A;'5E6R=N86UE)UTL("1P87)E
M;G1;)V-H:6QD<F5N2V5Y<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`O
M+R!N;R!A9V=R96=A=&4@:&%S(&)E96X@8W)E871E9"!F;W(@=&AI<R!T86<-
M"B`@("`@("`@("`@("`@("`@("`@:68@*"%I;E]A<G)A>2@D=F%L=65;)VYA
M;64G72P@)'!A<F5N=%LG86=G<F5G2V5Y<R==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1P87)E;G1;)V-H:6QD<F5N)UU;)'9A
M;'5E6R=N86UE)UU=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1P87)E;G1;)V-H:6QD<F5N)UU;)'9A;'5E6R=N86UE)UU=(#T@87)R87DH
M)'!A<F5N=%LG8VAI;&1R96XG75LD=F%L=65;)VYA;64G75TI.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<&%R96YT6R=C:&EL9')E;B==6R1V86QU95LG;F%M92==
M72`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>5]P=7-H*"1P87)E;G1;)V%G9W)E
M9TME>7,G72P@)'9A;'5E6R=N86UE)UTI.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W!U<V@H)'!A<F5N=%LG
M8VAI;&1R96XG75LD=F%L=65;)VYA;64G75TL("1V86QU95LG=F%L=64G72D[
M#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@
M("`@)'!A<F5N=%LG8VAI;&1R96XG75LD=F%L=65;)VYA;64G75T@/2`F)'9A
M;'5E6R=V86QU92==.PT*("`@("`@("`@("`@("`@("`@("!A<G)A>5]P=7-H
M*"1P87)E;G1;)V-H:6QD<F5N2V5Y<R==+"`D=F%L=65;)VYA;64G72D[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("!A<G)A>5]P=7-H*"1P87)E;G1;)V-H:6QD<F5N)UTL)'9A
M;'5E6R=V86QU92==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&%R
M<F%Y7W!U<V@H)'1H:7,M/E]V86Q3=&%C:RP@)'!A<F5N="D[#0H@("`@("`@
M('T-"@T*("`@("`@("`D=&AI<RT^7V1E<'1H+2T[#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@2&%N9&QE<B!F;W(@8VAA<F%C=&5R(&1A=&$-"B`@("`@
M*@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J($!P87)A;2`@;V)J
M96-T(%A-3"!P87)S97(@;V)J96-T#0H@("`@("H@0'!A<F%M("!S=')I;F<@
M0T1!5$$-"B`@("`@*B!`<F5T=7)N('9O:60-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!C9&%T84AA;F1L97(H)'!A<G-E<BP@)&-D871A*0T*("`@('L-"B`@
M("`@("`@)'1H:7,M/E]D871A4W1A8VM;)'1H:7,M/E]D97!T:%T@+CT@)&-D
M871A.PT*("`@('T-"GT-"C\^````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]"=6EL9&5R+G!H<```````````
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`S-3(W-R`Q,#4Q-30S
M,S<S,B`P,C$S,S$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`-"B\J*@T*("H@4$5!4E]"=6EL9&5R(&9O<B!B=6EL
M9&EN9R!02%`@97AT96YS:6]N<R`H4$5#3"!P86-K86=E<RD-"B`J#0H@*B!0
M2%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U
M<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0
M(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O
M<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R
M92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E
M#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N
M(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O
M<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@
M("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R("`@("!'
M<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q
M.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP
M#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@0G5I;&1E<BYP:'`L=B`Q+C(W
M(#(P,#8O,#$O,#8@,#0Z-#<Z,S8@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@
M("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I
M;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J
M+PT*#0HO*BH-"B`J($YE961E9"!F;W(@97AT96YD:6YG(%!%05)?0G5I;&1E
M<@T*("HO#0IR97%U:7)E7V]N8V4@)U!%05(O0V]M;6]N+G!H<"<[#0IR97%U
M:7)E7V]N8V4@)U!%05(O4&%C:V%G949I;&4N<&AP)SL-"B\J*@T*("H@0VQA
M<W,@=&\@:&%N9&QE(&)U:6QD:6YG("AC;VUP:6QI;F<I(&5X=&5N<VEO;G,N
M#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!
M4@T*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*
M("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*
M("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L
M:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@
M(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT
M+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G
M92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@
M4$A0(#0N,"XR#0H@*B!`<V5E("`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T
M+VUA;G5A;"]E;B]C;W)E+G!P;2YP96%R+6)U:6QD97(N<&AP#0H@*B\-"F-L
M87-S(%!%05)?0G5I;&1E<B!E>'1E;F1S(%!%05)?0V]M;6]N#0I[#0H@("`@
M+R\@>WM[('!R;W!E<G1I97,-"@T*("`@('9A<B`D<&AP7V%P:5]V97)S:6]N
M(#T@,#L-"B`@("!V87(@)'IE;F1?;6]D=6QE7V%P:5]N;R`](#`[#0H@("`@
M=F%R("1Z96YD7V5X=&5N<VEO;E]A<&E?;F\@/2`P.PT*#0H@("`@=F%R("1E
M>'1E;G-I;VYS7V)U:6QT(#T@87)R87DH*3L-"@T*("`@('9A<B`D8W5R<F5N
M=%]C86QL8F%C:R`](&YU;&P[#0H-"B`@("`O+R!U<V5D(&9O<B!M<V1E=B!B
M=6EL9',-"B`@("!V87(@)%]L87-T;&EN92`](&YU;&P[#0H@("`@=F%R("1?
M9FER<W1L:6YE(#T@;G5L;#L-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@8V]N
M<W1R=6-T;W(-"@T*("`@("\J*@T*("`@("`J(%!%05)?0G5I;&1E<B!C;VYS
M=')U8W1O<BX-"B`@("`@*@T*("`@("`J($!P87)A;2!O8FIE8W0@)'5I('5S
M97(@:6YT97)F86-E(&]B:F5C="`H:6YS=&%N8V4@;V8@4$5!4E]&<F]N=&5N
M9%\J*0T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!014%27T)U:6QD97(H)B1U:2D-"B`@("![#0H@("`@
M("`@('!A<F5N=#HZ4$5!4E]#;VUM;VXH*3L-"B`@("`@("`@)'1H:7,M/G-E
M=$9R;VYT96YD3V)J96-T*"1U:2D[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-
M"B`@("`O+R![>WL@7V)U:6QD7W=I;C,R*"D-"@T*("`@("\J*@T*("`@("`J
M($)U:6QD(&%N(&5X=&5N<VEO;B!F<F]M('-O=7)C92!O;B!W:6YD;W=S+@T*
M("`@("`J(')E<75I<F5S(&US9&5V#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M7V)U:6QD7W=I;C,R*"1D97-C9FEL92P@)&-A;&QB86-K(#T@;G5L;"D-"B`@
M("![#0H@("`@("`@(&EF("AI<U]O8FIE8W0H)&1E<V-F:6QE*2D@>PT*("`@
M("`@("`@("`@)'!K9R`]("1D97-C9FEL93L-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("1P9B`]("9N97<@4$5!4E]086-K86=E1FEL92@D=&AI
M<RT^8V]N9FEG+"`D=&AI<RT^9&5B=6<I.PT*("`@("`@("`@("`@)'!K9R`]
M("8D<&8M/F9R;VU086-K86=E1FEL92@D9&5S8V9I;&4L(%!%05)?5D%,241!
M5$5?3D]234%,*3L-"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1P
M:V<I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1P:V<[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)&1I<B`](&1I<FYA;64H)'!K
M9RT^9V5T07)C:&EV949I;&4H*2D[#0H@("`@("`@("1O;&1?8W=D(#T@9V5T
M8W=D*"D[#0H-"B`@("`@("`@:68@*"%`8VAD:7(H)&1I<BDI('L-"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B8V]U;&0@;F]T(&-H
M9&ER('1O("1D:7(B*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^;&]G
M*#(L(")B=6EL9&EN9R!I;B`D9&ER(BD[#0H-"B`@("`@("`@)&1S<"`]("1P
M:V<M/F=E=%!A8VMA9V4H*2XG+F1S<"<[#0H@("`@("`@(&EF("@A0&ES7V9I
M;&4H(B1D:7(O)&1S<"(I*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H(E1H92!$4U`@)&1S<"!D;V5S(&YO="!E>&ES="XB*3L-
M"B`@("`@("`@?0T*("`@("`@("`O+R!86%@@5$]$3SH@;6%K92!R96QE87-E
M(&)U:6QD('1Y<&4@8V]N9FEG=7)A8FQE#0H@("`@("`@("1C;VUM86YD(#T@
M)VUS9&5V("<N)&1S<"XG("]-04M%("(G+B1I;F9O6R=P86-K86=E)UTN("<@
M+2!296QE87-E(B<[#0H-"B`@("`@("`@)'1H:7,M/F-U<G)E;G1?8V%L;&)A
M8VL@/2`D8V%L;&)A8VL[#0H@("`@("`@("1E<G(@/2`D=&AI<RT^7W)U;D-O
M;6UA;F0H)&-O;6UA;F0L(&%R<F%Y*"8D=&AI<RP@)VUS9&5V0V%L;&)A8VLG
M*2D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G(I*2![#0H@("`@
M("`@("`@("!R971U<FX@)&5R<CL-"B`@("`@("`@?0T*#0H@("`@("`@("\O
M(&9I9W5R92!O=70@=&AE(&)U:6QD('!L871F;W)M(&%N9"!T>7!E#0H@("`@
M("`@("1P;&%T9F]R;2`]("=7:6XS,B<[#0H@("`@("`@("1B=6EL9'1Y<&4@
M/2`G4F5L96%S92<[#0H@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O+BH_)RXD
M<&MG+3YG971086-K86=E*"DN)UQS+5QS*%QW*RE<<R@N*C\I+2LO:2<L)'1H
M:7,M/E]F:7)S=&QI;F4L)&UA=&-H97,I*2![#0H@("`@("`@("`@("`D<&QA
M=&9O<FT@/2`D;6%T8VAE<ULQ73L-"B`@("`@("`@("`@("1B=6EL9'1Y<&4@
M/2`D;6%T8VAE<ULR73L-"B`@("`@("`@?0T*#0H@("`@("`@(&EF("AP<F5G
M7VUA=&-H*"<O*"XJ*3]<<RU<<RA<9"LI+BH_*%QD*RDO)RPD=&AI<RT^7VQA
M<W1L:6YE+"1M871C:&5S*2D@>PT*("`@("`@("`@("`@:68@*"1M871C:&5S
M6S)=*2![#0H@("`@("`@("`@("`@("`@+R\@=&AE<F4@=V5R92!E<G)O<G,@
M:6X@=&AE(&)U:6QD#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*")4:&5R92!W97)E(&5R<F]R<R!D=7)I;F<@8V]M<&EL871I
M;VXN(BD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D;W5T(#T@)&UA
M=&-H97-;,5T[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H(D1I9"!N;W0@=6YD97)S=&%N9"!T:&4@
M8V]M<&QE=&EO;B!S=&%T=7,@<F5T=7)N960@9G)O;2!M<V1E=BYE>&4N(BD[
M#0H@("`@("`@('T-"@T*("`@("`@("`O+R!M<V1E=B!D;V5S;B=T('1E;&P@
M=7,@=&AE(&]U='!U="!D:7)E8W1O<GD@.B\-"B`@("`@("`@+R\@;W!E;B!T
M:&4@9'-P+"!F:6YD("]O=70@86YD('5S92!T:&%T(&1I<F5C=&]R>0T*("`@
M("`@("`D9'-P=&5X="`](&IO:6XH9FEL92@D9'-P*2PG)RD[#0H-"B`@("`@
M("`@+R\@=&AI<R!R96=E>"!D97!E;F1S(&]N('1H92!B=6EL9"!P;&%T9F]R
M;2!A;F0@='EP92!H879I;F<@8F5E;@T*("`@("`@("`O+R!C;W)R96-T;'D@
M:61E;G1I9FEE9"!A8F]V92X-"B`@("`@("`@)')E9V5X(#TG+RXJ/R%)1EQS
M*R)<)%PH0T9'7"DB7',K/3U<<RLH(B<N#0H@("`@("`@("`@("`@("`@("`@
M("1P:V<M/F=E=%!A8VMA9V4H*2XG7',M7',G+@T*("`@("`@("`@("`@("`@
M("`@("`D<&QA=&9O<FTN)UQS)RX-"B`@("`@("`@("`@("`@("`@("`@)&)U
M:6QD='EP92XG(BDN*C\G+@T*("`@("`@("`@("`@("`@("`@("`G7"]O=70Z
M(B@N*C\I(B]I<R<[#0H-"B`@("`@("`@:68@*"1D<W!T97AT("8F('!R96=?
M;6%T8V@H)')E9V5X+"1D<W!T97AT+"1M871C:&5S*2D@>PT*("`@("`@("`@
M("`@+R\@=VAA="!W92!G970@8F%C:R!I<R!A(')E;&%T:79E('!A=&@@=&\@
M=&AE(&]U='!U="!F:6QE(&ET<V5L9BX-"B`@("`@("`@("`@("1O=71F:6QE
M(#T@<F5A;'!A=&@H)&UA=&-H97-;,ETI.PT*("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")#;W5L9"!N
M;W0@<F5T<FEE=F4@;W5T<'5T(&EN9F]R;6%T:6]N(&9R;VT@)&1S<"XB*3L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H0&-O<'DH)&]U=&9I;&4L("(D9&ER
M+R1O=70B*2D@>PT*("`@("`@("`@("`@)&]U=&9I;&4@/2`B)&1I<B\D;W5T
M(CL-"B`@("`@("`@?0T*#0H@("`@("`@("1B=6EL=%]F:6QE<UM=(#T@87)R
M87DH#0H@("`@("`@("`@("`G9FEL92<@/3X@(B1O=71F:6QE(BP-"B`@("`@
M("`@("`@("=P:'!?87!I)R`]/B`D=&AI<RT^<&AP7V%P:5]V97)S:6]N+`T*
M("`@("`@("`@("`@)WIE;F1?;6]D7V%P:2<@/3X@)'1H:7,M/GIE;F1?;6]D
M=6QE7V%P:5]N;RP-"B`@("`@("`@("`@("=Z96YD7V5X=%]A<&DG(#T^("1T
M:&ES+3YZ96YD7V5X=&5N<VEO;E]A<&E?;F\L#0H@("`@("`@("`@("`I.PT*
M#0H@("`@("`@(')E='5R;B`D8G5I;'1?9FEL97,[#0H@("`@?0T*("`@("\O
M('U]?0T*#0H@("`@+R\@>WM[(&US9&5V0V%L;&)A8VLH*0T*("`@(&9U;F-T
M:6]N(&US9&5V0V%L;&)A8VLH)'=H870L("1D871A*0T*("`@('L-"B`@("`@
M("`@:68@*"$D=&AI<RT^7V9I<G-T;&EN92D-"B`@("`@("`@("`@("1T:&ES
M+3Y?9FER<W1L:6YE(#T@)&1A=&$[#0H@("`@("`@("1T:&ES+3Y?;&%S=&QI
M;F4@/2`D9&%T83L-"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@
M7VAA<G9E;G1);G-T1&ER#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN
M9PT*("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@*B!`<&%R86T@87)R87D-
M"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!?:&%R=F5S=$EN<W1$:7(H)&1E<W1?<')E9FEX+"`D9&ER;F%M92P@)B1B
M=6EL=%]F:6QE<RD-"B`@("![#0H@("`@("`@("1D(#T@;W!E;F1I<B@D9&ER
M;F%M92D[#0H@("`@("`@(&EF("@A)&0I#0H@("`@("`@("`@("!R971U<FX@
M9F%L<V4[#0H-"B`@("`@("`@)')E="`]('1R=64[#0H@("`@("`@('=H:6QE
M("@H)&5N="`](')E861D:7(H)&0I*2`A/3T@9F%L<V4I('L-"B`@("`@("`@
M("`@(&EF("@D96YT>S!](#T]("<N)RD-"B`@("`@("`@("`@("`@("!C;VYT
M:6YU93L-"@T*("`@("`@("`@("`@)&9U;&P@/2`D9&ER;F%M92`N($1)4D5#
M5$]265]315!!4D%43U(@+B`D96YT.PT*("`@("`@("`@("`@:68@*&ES7V1I
M<B@D9G5L;"DI('L-"B`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3Y?:&%R
M=F5S=$EN<W1$:7(H#0H@("`@("`@("`@("`@("`@("`@("`@("`D9&5S=%]P
M<F5F:7@@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)&5N="P-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1F=6QL+"`D8G5I;'1?9FEL97,I*2![#0H@("`@
M("`@("`@("`@("`@("`@("1R970@/2!F86QS93L-"B`@("`@("`@("`@("`@
M("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D9&5S="`]("1D97-T7W!R969I
M>"`N($1)4D5#5$]265]315!!4D%43U(@+B`D96YT.PT*("`@("`@("`@("`@
M("`@("1B=6EL=%]F:6QE<UM=(#T@87)R87DH#0H@("`@("`@("`@("`@("`@
M("`@("`@("`G9FEL92<@/3X@)&9U;&PL#0H@("`@("`@("`@("`@("`@("`@
M("`@("`G9&5S="<@/3X@)&1E<W0L#0H@("`@("`@("`@("`@("`@("`@("`@
M("`G<&AP7V%P:2<@/3X@)'1H:7,M/G!H<%]A<&E?=F5R<VEO;BP-"B`@("`@
M("`@("`@("`@("`@("`@("`@("=Z96YD7VUO9%]A<&DG(#T^("1T:&ES+3YZ
M96YD7VUO9'5L95]A<&E?;F\L#0H@("`@("`@("`@("`@("`@("`@("`@("`G
M>F5N9%]E>'1?87!I)R`]/B`D=&AI<RT^>F5N9%]E>'1E;G-I;VY?87!I7VYO
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("!C;&]S961I<B@D9"D[#0H@("`@("`@(')E
M='5R;B`D<F5T.PT*("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[
M(&)U:6QD*"D-"@T*("`@("\J*@T*("`@("`J($)U:6QD(&%N(&5X=&5N<VEO
M;B!F<F]M('-O=7)C92X@(%)U;G,@(G!H<&EZ92(@:6X@=&AE('-O=7)C90T*
M("`@("`J(&1I<F5C=&]R>2P@8G5T(&-O;7!I;&5S(&EN(&$@=&5M<&]R87)Y
M(&1I<F5C=&]R>0T*("`@("`J("@O=F%R+W1M<"]P96%R+6)U:6QD+55315(O
M4$%#2T%'12U615)324].*2X-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I
M;F=\4$5!4E]086-K86=E1FEL95]V*B`D9&5S8V9I;&4@<&%T:"!T;R!834P@
M<&%C:V%G92!D97-C<FEP=&EO;B!F:6QE+"!O<@T*("`@("`J("`@("`@("`@
M("`@("`@82!014%27U!A8VMA9V5&:6QE(&]B:F5C=`T*("`@("`J#0H@("`@
M("H@0'!A<F%M(&UI>&5D("1C86QL8F%C:R!C86QL8F%C:R!F=6YC=&EO;B!U
M<V5D('1O(')E<&]R="!O=71P=70L#0H@("`@("H@<V5E(%!%05)?0G5I;&1E
M<CHZ7W)U;D-O;6UA;F0@9F]R(&1E=&%I;',-"B`@("`@*@T*("`@("`J($!R
M971U<FX@87)R87D@86X@87)R87D@;V8@87-S;V-I871I=F4@87)R87ES('=I
M=&@@8G5I;'0@9FEL97,L#0H@("`@("H@9F]R;6%T.@T*("`@("`J(&%R<F%Y
M*"!A<G)A>2@@)V9I;&4G(#T^("<O<&%T:"]T;R]E>'0N<V\G+`T*("`@("`J
M("`@("`@("`@("`@("`@)W!H<%]A<&DG(#T^(%E965E-341$+`T*("`@("`J
M("`@("`@("`@("`@("`@)WIE;F1?;6]D7V%P:2<@/3X@65E964U-1$0L#0H@
M("`@("H@("`@("`@("`@("`@("`G>F5N9%]E>'1?87!I)R`]/B!965E934U$
M1"`I+`T*("`@("`J("`@("`@("`N+BX@*0T*("`@("`J#0H@("`@("H@0&%C
M8V5S<R!P=6)L:6,-"B`@("`@*@T*("`@("`J($!S964@4$5!4E]"=6EL9&5R
M.CI?<G5N0V]M;6%N9`T*("`@("`J+PT*("`@(&9U;F-T:6]N(&)U:6QD*"1D
M97-C9FEL92P@)&-A;&QB86-K(#T@;G5L;"D-"B`@("![#0H@("`@("`@(&EF
M("A014%27T]3(#T](")7:6YD;W=S(BD@>PT*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?8G5I;&1?=VEN,S(H)&1E<V-F:6QE+"1C86QL8F%C:RD[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*%!%05)?3U,@(3T@)U5N:7@G*2![#0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F)U:6QD:6YG
M(&5X=&5N<VEO;G,@;F]T('-U<'!O<G1E9"!O;B!T:&ES('!L871F;W)M(BD[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES7V]B:F5C="@D9&5S8V9I;&4I
M*2![#0H@("`@("`@("`@("`D<&MG(#T@)&1E<V-F:6QE.PT*("`@("`@("`@
M("`@)&1E<V-F:6QE(#T@)'!K9RT^9V5T4&%C:V%G949I;&4H*3L-"B`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("1P9B`]("9N97<@4$5!4E]086-K
M86=E1FEL92@D=&AI<RT^8V]N9FEG*3L-"B`@("`@("`@("`@("1P:V<@/2`F
M)'!F+3YF<F]M4&%C:V%G949I;&4H)&1E<V-F:6QE+"!014%27U9!3$E$051%
M7TY/4DU!3"D[#0H@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<&MG
M*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D<&MG.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@("1D:7(@/2!D:7)N86UE*"1D97-C
M9FEL92D[#0H@("`@("`@("1O;&1?8W=D(#T@9V5T8W=D*"D[#0H@("`@("`@
M(&EF("@A0&-H9&ER*"1D:7(I*2![#0H@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H(F-O=6QD(&YO="!C:&1I<B!T;R`D9&ER(BD[#0H@
M("`@("`@('T-"B`@("`@("`@)'9D:7(@/2`D<&MG+3YG971086-K86=E*"D@
M+B`G+2<@+B`D<&MG+3YG971697)S:6]N*"D[#0H@("`@("`@(&EF("AI<U]D
M:7(H)'9D:7(I*2![#0H@("`@("`@("`@("!C:&1I<B@D=F1I<BD[#0H@("`@
M("`@('T-"B`@("`@("`@)&1I<B`](&=E=&-W9"@I.PT*("`@("`@("`D=&AI
M<RT^;&]G*#(L(")B=6EL9&EN9R!I;B`D9&ER(BD[#0H@("`@("`@("1T:&ES
M+3YC=7)R96YT7V-A;&QB86-K(#T@)&-A;&QB86-K.PT*("`@("`@("!P=71E
M;G8H)U!!5$@])R`N("1T:&ES+3YC;VYF:6<M/F=E="@G8FEN7V1I<B<I("X@
M)SHG("X@9V5T96YV*"=0051()RDI.PT*("`@("`@("`D97)R(#T@)'1H:7,M
M/E]R=6Y#;VUM86YD*")P:'!I>F4B+"!A<G)A>2@F)'1H:7,L("=P:'!I>F5#
M86QL8F%C:R<I*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<BDI
M('L-"B`@("`@("`@("`@(')E='5R;B`D97)R.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("@A)&5R<BD@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*")@<&AP:7IE)R!F86EL960B*3L-"B`@("`@("`@?0T*#0H@
M("`@("`@("\O('M[>R!S=&%R="!O9B!I;G1E<F%C=&EV92!P87)T#0H@("`@
M("`@("1C;VYF:6=U<F5?8V]M;6%N9"`]("(D9&ER+V-O;F9I9W5R92([#0H@
M("`@("`@("1C;VYF:6=U<F5?;W!T:6]N<R`]("1P:V<M/F=E=$-O;F9I9W5R
M94]P=&EO;G,H*3L-"B`@("`@("`@:68@*"1C;VYF:6=U<F5?;W!T:6]N<RD@
M>PT*("`@("`@("`@("`@9F]R96%C:"`H)&-O;F9I9W5R95]O<'1I;VYS(&%S
M("1O*2![#0H@("`@("`@("`@("`@("`@;&ES="@D<BD@/2`D=&AI<RT^=6DM
M/G5S97)$:6%L;V<H)V)U:6QD)RP-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@D;ULG<')O;7!T)UTI
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"=T97AT)RDL#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH0"1O6R=D969A=6QT
M)UTI*3L-"B`@("`@("`@("`@("`@("!I9B`H<W5B<W1R*"1O6R=N86UE)UTL
M(#`L(#4I(#T]("=W:71H+2<@)B8-"B`@("`@("`@("`@("`@("`@("`@*"1R
M(#T]("=Y97,G('Q\("1R(#T]("=A=71O9&5T96-T)RDI('L-"B`@("`@("`@
M("`@("`@("`@("`@)&-O;F9I9W5R95]C;VUM86YD("X]("(@+2TD;UMN86UE
M72([#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@)&-O;F9I9W5R95]C;VUM86YD("X]("(@+2TD;UMN86UE73TB+G1R
M:6TH)'(I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@("`@("`O+R!]?7T@96YD(&]F(&EN=&5R86-T:79E('!A
M<G0-"@T*("`@("`@("`O+R!&25A-12!M86ME(&-O;F9I9W5R86)L90T*("`@
M("`@("!I9B@A)'5S97(]9V5T96YV*"=54T52)RDI>PT*("`@("`@("`@("`@
M)'5S97(])V1E9F%U;'1U<V5R)SL-"B`@("`@("`@?0T*("`@("`@("`D8G5I
M;&1?8F%S961I<B`]("(O=F%R+W1M<"]P96%R+6)U:6QD+21U<V5R(CL-"B`@
M("`@("`@)&)U:6QD7V1I<B`]("(D8G5I;&1?8F%S961I<B\D=F1I<B([#0H@
M("`@("`@("1I;G-T7V1I<B`]("(D8G5I;&1?8F%S961I<B]I;G-T86QL+21V
M9&ER(CL-"B`@("`@("`@)'1H:7,M/FQO9R@Q+"`B8G5I;&1I;F<@:6X@)&)U
M:6QD7V1I<B(I.PT*("`@("`@("!I9B`H:7-?9&ER*"1B=6EL9%]D:7(I*2![
M#0H@("`@("`@("`@("!3>7-T96TZ.G)M*&%R<F%Y*"<M<F8G+"`D8G5I;&1?
M9&ER*2D[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%3>7-T96TZ.FUK1&ER
M*&%R<F%Y*"<M<"<L("1B=6EL9%]D:7(I*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*")C;W5L9"!N;W0@8W)E871E(&)U:6QD
M(&1I<CH@)&)U:6QD7V1I<B(I.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES
M+3YA9&1496UP1FEL92@D8G5I;&1?9&ER*3L-"B`@("`@("`@:68@*"%3>7-T
M96TZ.FUK1&ER*&%R<F%Y*"<M<"<L("1I;G-T7V1I<BDI*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F-O=6QD(&YO="!C<F5A
M=&4@=&5M<&]R87)Y(&EN<W1A;&P@9&ER.B`D:6YS=%]D:7(B*3L-"B`@("`@
M("`@?0T*("`@("`@("`D=&AI<RT^861D5&5M<$9I;&4H)&EN<W1?9&ER*3L-
M"@T*("`@("`@("!I9B`H9V5T96YV*"=-04M%)RDI('L-"B`@("`@("`@("`@
M("1M86ME7V-O;6UA;F0@/2!G971E;G8H)TU!2T4G*3L-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("1M86ME7V-O;6UA;F0@/2`G;6%K92<[#0H@
M("`@("`@('T-"B`@("`@("`@)'1O7W)U;B`](&%R<F%Y*`T*("`@("`@("`@
M("`@)&-O;F9I9W5R95]C;VUM86YD+`T*("`@("`@("`@("`@)&UA:V5?8V]M
M;6%N9"P-"B`@("`@("`@("`@("(D;6%K95]C;VUM86YD($E.4U1!3$Q?4D]/
M5#U<(B1I;G-T7V1I<EPB(&EN<W1A;&PB+`T*("`@("`@("`@("`@(F9I;F0@
M7"(D:6YS=%]D:7)<(B`M;',B#0H@("`@("`@("`@("`I.PT*("`@("`@("!I
M9B`H(4!C:&1I<B@D8G5I;&1?9&ER*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*")C;W5L9"!N;W0@8VAD:7(@=&\@)&)U:6QD
M7V1I<B(I.PT*("`@("`@("!]#0H@("`@("`@('!U=&5N=B@G4$A07U!%05)?
M5D524TE/3CTQ+C0N.2<I.PT*("`@("`@("!F;W)E86-H("@D=&]?<G5N(&%S
M("1C;60I('L-"B`@("`@("`@("`@("1E<G(@/2`D=&AI<RT^7W)U;D-O;6UA
M;F0H)&-M9"P@)&-A;&QB86-K*3L-"B`@("`@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1E<G(I*2![#0H@("`@("`@("`@("`@("`@8VAD:7(H)&]L9%]C
M=V0I.PT*("`@("`@("`@("`@("`@(')E='5R;B`D97)R.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@:68@*"$D97)R*2![#0H@("`@("`@("`@("`@
M("`@8VAD:7(H)&]L9%]C=V0I.PT*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@B8"1C;60G(&9A:6QE9"(I.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@A*"1D<"`](&]P96YD:7(H
M(FUO9'5L97,B*2DI('L-"B`@("`@("`@("`@(&-H9&ER*"1O;&1?8W=D*3L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B;F\@8&UO
M9'5L97,G(&1I<F5C=&]R>2!F;W5N9"(I.PT*("`@("`@("!]#0H@("`@("`@
M("1B=6EL=%]F:6QE<R`](&%R<F%Y*"D[#0H@("`@("`@("1P<F5F:7@@/2!E
M>&5C*")P:'`M8V]N9FEG("TM<')E9FEX(BD[#0H@("`@("`@("1T:&ES+3Y?
M:&%R=F5S=$EN<W1$:7(H)'!R969I>"P@)&EN<W1?9&ER("X@1$E214-43U)9
M7U-%4$%2051/4B`N("1P<F5F:7@L("1B=6EL=%]F:6QE<RD[#0H@("`@("`@
M(&-H9&ER*"1O;&1?8W=D*3L-"B`@("`@("`@<F5T=7)N("1B=6EL=%]F:6QE
M<SL-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@<&AP:7IE0V%L
M;&)A8VLH*0T*#0H@("`@+RHJ#0H@("`@("H@365S<V%G92!C86QL8F%C:R!F
M=6YC=&EO;B!U<V5D('=H96X@<G5N;FEN9R!T:&4@(G!H<&EZ92(-"B`@("`@
M*B!P<F]G<F%M+B`@17AT<F%C=',@=&AE($%022!N=6UB97)S('5S960N("!)
M9VYO<F5S(&]T:&5R(&UE<W-A9V4-"B`@("`@*B!T>7!E<R!T:&%N(")C;61O
M=71P=70B+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`D=VAA="!T
M:&4@='EP92!O9B!M97-S86=E#0H@("`@("H@0'!A<F%M(&UI>&5D("1D871A
M('1H92!M97-S86=E#0H@("`@("H-"B`@("`@*B!`<F5T=7)N('9O:60-"B`@
M("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@<&AP:7IE0V%L;&)A8VLH)'=H870L("1D871A*0T*("`@('L-"B`@
M("`@("`@:68@*"1W:&%T("$]("=C;61O=71P=70G*2![#0H@("`@("`@("`@
M("!R971U<FX[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/FQO9R@Q+"!R
M=')I;2@D9&%T82DI.PT*("`@("`@("!I9B`H<')E9U]M871C:"@G+UEO=2!S
M:&]U;&0@=7!D871E('EO=7(@+F%C;&]C86PN;30O)RP@)&1A=&$I*2![#0H@
M("`@("`@("`@("!R971U<FX[#0H@("`@("`@('T-"B`@("`@("`@)&UA=&-H
M97,@/2!A<G)A>2@I.PT*("`@("`@("!I9B`H<')E9U]M871C:"@G+UY<<RLH
M7%-;7CI=*RDZ7',K*%QD>SA]*2\G+"`D9&%T82P@)&UA=&-H97,I*2![#0H@
M("`@("`@("`@("`D;65M8F5R(#T@<')E9U]R97!L86-E*"<O6UYA+7I=+R<L
M("=?)RP@<W1R=&]L;W=E<B@D;6%T8VAE<ULQ72DI.PT*("`@("`@("`@("`@
M)&%P:6YO(#T@*&EN="DD;6%T8VAE<ULR73L-"B`@("`@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^)&UE;6)E<BDI('L-"B`@("`@("`@("`@("`@("`D=&AI
M<RT^)&UE;6)E<B`]("1A<&EN;SL-"B`@("`@("`@("`@("`@("`O+R1M<V<@
M/2!S<')I;G1F*"(E+3(R<R`Z("5D(BP@)&UA=&-H97-;,5TL("1A<&EN;RD[
M#0H@("`@("`@("`@("`@("`@+R\D=&AI<RT^;&]G*#$L("1M<V<I.PT*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[(%]R=6Y#;VUM86YD*"D-"@T*("`@("\J*@T*("`@("`J(%)U
M;B!A;B!E>'1E<FYA;"!C;VUM86YD+"!U<VEN9R!A(&UE<W-A9V4@8V%L;&)A
M8VL@=&\@<F5P;W)T#0H@("`@("H@;W5T<'5T+B`@5&AE(&-O;6UA;F0@=VEL
M;"!B92!R=6X@=&AR;W5G:"!P;W!E;B!A;F0@;W5T<'5T(&ES#0H@("`@("H@
M<F5P;W)T960@9F]R(&5V97)Y(&QI;F4@=VET:"!A(")C;61O=71P=70B(&UE
M<W-A9V4@=VET:"!T:&4-"B`@("`@*B!L:6YE('-T<FEN9RP@:6YC;'5D:6YG
M(&YE=VQI;F5S+"!A<R!P87EL;V%D+@T*("`@("`J#0H@("`@("H@0'!A<F%M
M('-T<FEN9R`D8V]M;6%N9"!T:&4@8V]M;6%N9"!T;R!R=6X-"B`@("`@*@T*
M("`@("`J($!P87)A;2!M:7AE9"`D8V%L;&)A8VL@*&]P=&EO;F%L*2!F=6YC
M=&EO;B!T;R!U<V4@87,@;65S<V%G90T*("`@("`J(&-A;&QB86-K#0H@("`@
M("H-"B`@("`@*B!`<F5T=7)N(&)O;VP@=VAE=&AE<B!T:&4@8V]M;6%N9"!W
M87,@<W5C8V5S<V9U;"`H97AI="!C;V1E(#`-"B`@("`@*B!M96%N<R!S=6-C
M97-S+"!A;GD@;W1H97(@;65A;G,@9F%I;'5R92D-"B`@("`@*@T*("`@("`J
M($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]R=6Y#
M;VUM86YD*"1C;VUM86YD+"`D8V%L;&)A8VL@/2!N=6QL*0T*("`@('L-"B`@
M("`@("`@)'1H:7,M/FQO9R@Q+"`B<G5N;FEN9SH@)&-O;6UA;F0B*3L-"B`@
M("`@("`@)'!P(#T@0'!O<&5N*"(D8V]M;6%N9"`R/B8Q(BP@(G(B*3L-"B`@
M("`@("`@:68@*"$D<'`I('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@B9F%I;&5D('1O(')U;B!@)&-O;6UA;F0G(BD[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"1C86QL8F%C:R`F)B`D8V%L;&)A8VM;,%TM
M/F1E8G5G(#T](#$I('L-"B`@("`@("`@("`@("1O;&1D8F<@/2`D8V%L;&)A
M8VM;,%TM/F1E8G5G.PT*("`@("`@("`@("`@)&-A;&QB86-K6S!=+3YD96)U
M9R`](#([#0H@("`@("`@('T-"@T*("`@("`@("!W:&EL92`H)&QI;F4@/2!F
M9V5T<R@D<'`L(#$P,C0I*2![#0H@("`@("`@("`@("!I9B`H)&-A;&QB86-K
M*2![#0H@("`@("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F,H)&-A;&QB86-K
M+"`G8VUD;W5T<'5T)RP@)&QI;F4I.PT*("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#(L(')T<FEM*"1L:6YE*2D[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"1C86QL
M8F%C:R`F)B!I<W-E="@D;VQD9&)G*2D@>PT*("`@("`@("`@("`@)&-A;&QB
M86-K6S!=+3YD96)U9R`]("1O;&1D8F<[#0H@("`@("`@('T-"B`@("`@("`@
M)&5X:71C;V1E(#T@0'!C;&]S92@D<'`I.PT*("`@("`@("!R971U<FX@*"1E
M>&ET8V]D92`]/2`P*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![
M>WL@;&]G*"D-"@T*("`@(&9U;F-T:6]N(&QO9R@D;&5V96PL("1M<V<I#0H@
M("`@>PT*("`@("`@("!I9B`H)'1H:7,M/F-U<G)E;G1?8V%L;&)A8VLI('L-
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^9&5B=6<@/CT@)&QE=F5L*2![#0H@
M("`@("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F,H)'1H:7,M/F-U<G)E;G1?
M8V%L;&)A8VLL("=O=71P=70G+"`D;7-G*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(')E='5R;CL-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M4$5!4E]#;VUM;VXZ.FQO9R@D;&5V96PL("1M<V<I.PT*("`@('T-"@T*("`@
M("\O('U]?0T*?0T*#0H_/@T*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]014%2+T%U=&]L;V%D97(N<&AP````````````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#$U-S0Q(#$P-3$U-#,S-S,R(#`R,C`S-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`T*+RHJ#0H@*B!#;&%S<R!A=71O+6QO861E<@T*("H-"B`J(%!(4"!V97)S
M:6]N<R`T#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S
M=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@
M=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@
M870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O
M<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O
M8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N
M;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C
M;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J
M($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N
M(#QS<V)`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@
M4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N
M("`@($-64SH@)$ED.B!!=71O;&]A9&5R+G!H<"QV(#$N,3,@,C`P-B\P,2\P
M-B`P-#HT-SHS-B!C96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z
M+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+V-O<F4N<'!M+G!H<"-C;W)E+G!P
M;2YP96%R+6%U=&]L;V%D97(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA
M8FQE('-I;F-E(%)E;&5A<V4@,"XQ#0H@*B!`9&5P<F5C871E9"!&:6QE(&1E
M<')E8V%T960@:6X@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"@T*+R\@+RH@=FEM
M.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30Z("HO#0H-
M"FEF("@A97AT96YS:6]N7VQO861E9"@B;W9E<FQO860B*2D@>PT*("`@("\O
M(&1I92!H87)D('=I=&AO=70@97AT+V]V97)L;V%D#0H@("`@9&EE*")296)U
M:6QD(%!(4"!W:71H('1H92!@;W9E<FQO860G(&5X=&5N<VEO;B!T;R!U<V4@
M4$5!4E]!=71O;&]A9&5R(BD[#0I]#0H-"B\J*@T*("H@26YC;'5D92!F;W(@
M4$5!4E]%<G)O<B!A;F0@4$5!4B!C;&%S<V5S#0H@*B\-"G)E<75I<F5?;VYC
M92`B4$5!4BYP:'`B.PT*#0HO*BH-"B`J(%1H:7,@8VQA<W,@:7,@9F]R(&]B
M:F5C=',@=VAE<F4@>6]U('=A;G0@=&\@<V5P87)A=&4@=&AE(&-O9&4@9F]R
M#0H@*B!S;VUE(&UE=&AO9',@:6YT;R!S97!A<F%T92!C;&%S<V5S+B`@5&AI
M<R!I<R!U<V5F=6P@:68@>6]U(&AA=F4@80T*("H@8VQA<W,@=VET:"!N;W0M
M9G)E<75E;G1L>2UU<V5D(&UE=&AO9',@=&AA="!C;VYT86EN(&QO=',@;V8@
M8V]D90T*("H@=&AA="!Y;W4@=V]U;&0@;&EK92!T;R!A=F]I9"!A;'=A>7,@
M<&%R<VEN9RX-"B`J#0H@*B!4:&4@4$5!4E]!=71O;&]A9&5R(&-L87-S('!R
M;W9I9&5S(&%U=&]L;V%D:6YG(&%N9"!A9V=R96=A=&EO;BX-"B`J(%1H92!A
M=71O;&]A9&EN9R!L971S('EO=2!S970@=7`@:6X@=VAI8V@@8VQA<W-E<R!T
M:&4@<V5P87)A=&5D#0H@*B!M971H;V1S(&%R92!F;W5N9"X@($%G9W)E9V%T
M:6]N(&ES('1H92!T96-H;FEQ=64@=7-E9"!T;R!I;7!O<G0@;F5W#0H@*B!M
M971H;V1S+"!A;B!I;G-T86YC92!O9B!E86-H(&-L87-S('!R;W9I9&EN9R!S
M97!A<F%T960@;65T:&]D<R!I<PT*("H@<W1O<F5D(&%N9"!C86QL960@979E
M<GD@=&EM92!T:&4@86=G<F5G871E9"!M971H;V0@:7,@8V%L;&5D+@T*("H-
M"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J
M($!A=71H;W(@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&-O<'ER
M:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E
M;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L
M:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+V-O<F4N
M<'!M+G!H<"-C;W)E+G!P;2YP96%R+6%U=&]L;V%D97(-"B`J($!S:6YC92`@
M("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,"XQ#0H@*B!`9&5P
M<F5C871E9"!&:6QE(&1E<')E8V%T960@:6X@4F5L96%S92`Q+C0N,&$Q#0H@
M*B\-"F-L87-S(%!%05)?075T;VQO861E<B!E>'1E;F1S(%!%05(-"GL-"B`@
M("`O+R![>WL@<')O<&5R=&EE<PT*#0H@("`@+RHJ#0H@("`@("H@36%P(&]F
M(&UE=&AO9',@86YD(&-L87-S97,@=VAE<F4@=&AE>2!A<F4@9&5F:6YE9`T*
M("`@("`J#0H@("`@("H@0'9A<B!A<G)A>0T*("`@("`J#0H@("`@("H@0&%C
M8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?875T;VQO861?;6%P
M(#T@87)R87DH*3L-"@T*("`@("\J*@T*("`@("`J($UA<"!O9B!M971H;V1S
M(&%N9"!A9V=R96=A=&4@;V)J96-T<PT*("`@("`J#0H@("`@("H@0'9A<B!A
M<G)A>0T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO
M#0H@("`@=F%R("1?;65T:&]D7VUA<"`](&%R<F%Y*"D[#0H-"B`@("`O+R!]
M?7T-"B`@("`O+R![>WL@861D075T;VQO860H*0T*#0H@("`@+RHJ#0H@("`@
M("H@061D(&]N92!O<B!M;W)E(&%U=&]L;V%D(&5N=')I97,N#0H@("`@("H-
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1M971H;V0@("`@('=H:6-H(&UE=&AO
M9"!T;R!A=71O;&]A9`T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`D
M8VQA<W-N86UE("`H;W!T:6]N86PI('=H:6-H(&-L87-S('1O(&9I;F0@=&AE
M(&UE=&AO9"!I;BX-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M($EF('1H92`D;65T:&]D('!A<F%M971E<B!I<R!A;B!A<G)A>2P@=&AI<PT*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@<&%R86UE=&5R(&UA
M>2!B92!O;6ET=&5D("AA;F0@=VEL;"!B92!I9VYO<F5D#0H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B!N;W0I+"!A;F0@=&AE("1M971H
M;V0@<&%R86UE=&5R('=I;&P@8F4-"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@('1R96%T960@87,@86X@87-S;V-I871I=F4@87)R87D@=VET
M:"!M971H;V0-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&YA
M;65S(&%S(&ME>7,@86YD(&-L87-S(&YA;65S(&%S('9A;'5E<RX-"B`@("`@
M*@T*("`@("`J($!R971U<FX@=F]I9`T*("`@("`J#0H@("`@("H@0&%C8V5S
M<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!A9&1!=71O;&]A9"@D
M;65T:&]D+"`D8VQA<W-N86UE(#T@;G5L;"D-"B`@("![#0H@("`@("`@(&EF
M("AI<U]A<G)A>2@D;65T:&]D*2D@>PT*("`@("`@("`@("`@87)R87E?=V%L
M:R@D;65T:&]D+"!C<F5A=&5?9G5N8W1I;VXH)R1A+"8D8B<L("<D8B`]('-T
M<G1O;&]W97(H)&(I.R<I*3L-"B`@("`@("`@("`@("1T:&ES+3Y?875T;VQO
M861?;6%P(#T@87)R87E?;65R9V4H)'1H:7,M/E]A=71O;&]A9%]M87`L("1M
M971H;V0I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'1H:7,M
M/E]A=71O;&]A9%]M87!;<W1R=&]L;W=E<B@D;65T:&]D*5T@/2`D8VQA<W-N
M86UE.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@
M>WM[(')E;6]V94%U=&]L;V%D*"D-"@T*("`@("\J*@T*("`@("`J(%)E;6]V
M92!A;B!A=71O;&]A9"!E;G1R>2X-"B`@("`@*@T*("`@("`J($!P87)A;2!S
M=')I;F<@)&UE=&AO9"`@=VAI8V@@;65T:&]D('1O(')E;6]V92!T:&4@875T
M;VQO860@96YT<GD@9F]R#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&)O;VP@
M5%)512!I9B!A;B!E;G1R>2!W87,@<F5M;W9E9"P@1D%,4T4@:68@;F]T#0H@
M("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U
M;F-T:6]N(')E;6]V94%U=&]L;V%D*"1M971H;V0I#0H@("`@>PT*("`@("`@
M("`D;65T:&]D(#T@<W1R=&]L;W=E<B@D;65T:&]D*3L-"B`@("`@("`@)&]K
M(#T@:7-S970H)'1H:7,M/E]A=71O;&]A9%]M87!;)&UE=&AO9%TI.PT*("`@
M("`@("!U;G-E="@D=&AI<RT^7V%U=&]L;V%D7VUA<%LD;65T:&]D72D[#0H@
M("`@("`@(')E='5R;B`D;VL[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@
M+R\@>WM[(&%D9$%G9W)E9V%T94]B:F5C="@I#0H-"B`@("`O*BH-"B`@("`@
M*B!!9&0@86X@86=G<F5G871E(&]B:F5C="!T;R!T:&ES(&]B:F5C="X@($EF
M('1H92!S<&5C:69I960@8VQA<W,-"B`@("`@*B!I<R!N;W0@9&5F:6YE9"P@
M;&]A9&EN9R!I="!W:6QL(&)E(&%T=&5M<'1E9"!F;VQL;W=I;F<@4$5!4B=S
M#0H@("`@("H@9FEL92!N86UI;F<@<V-H96UE+B`@06QL('1H92!M971H;V1S
M(&EN('1H92!C;&%S<R!W:6QL(&)E#0H@("`@("H@86=G<F5G871E9"P@97AC
M97!T('!R:79A=&4@;VYE<R`H;F%M92!S=&%R=&EN9R!W:71H(&%N#0H@("`@
M("H@=6YD97)S8V]R92D@86YD(&-O;G-T<G5C=&]R<RX-"B`@("`@*@T*("`@
M("`J($!P87)A;2!S=')I;F<@)&-L87-S;F%M92`@=VAA="!C;&%S<R!T;R!I
M;G-T86YT:6%T92!F;W(@=&AE(&]B:F5C="X-"B`@("`@*@T*("`@("`J($!R
M971U<FX@=F]I9`T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!A9&1!9V=R96=A=&5/8FIE8W0H)&-L87-S
M;F%M92D-"B`@("![#0H@("`@("`@("1C;&%S<VYA;64@/2!S=')T;VQO=V5R
M*"1C;&%S<VYA;64I.PT*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@D8VQA
M<W-N86UE*2D@>PT*("`@("`@("`@("`@)&EN8VQU9&5?9FEL92`]('!R96=?
M<F5P;&%C92@G+UM>82UZ,"TY72]I)RP@)U\G+"`D8VQA<W-N86UE*3L-"B`@
M("`@("`@("`@(&EN8VQU9&5?;VYC92`D:6YC;'5D95]F:6QE.PT*("`@("`@
M("!]#0H@("`@("`@("1O8FH@/28@;F5W("1C;&%S<VYA;64[#0H@("`@("`@
M("1M971H;V1S(#T@9V5T7V-L87-S7VUE=&AO9',H)&-L87-S;F%M92D[#0H@
M("`@("`@(&9O<F5A8V@@*"1M971H;V1S(&%S("1M971H;V0I('L-"B`@("`@
M("`@("`@("\O(&1O;B=T(&EM<&]R="!P<FEV:6%T92!M971H;V1S(&%N9"!C
M;VYS=')U8W1O<G,-"B`@("`@("`@("`@(&EF("@D;65T:&]D>S!]("$]("=?
M)R`F)B`D;65T:&]D("$]("1C;&%S<VYA;64I('L-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^7VUE=&AO9%]M87!;)&UE=&AO9%T@/2`D;V)J.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@
M+R\@>WM[(')E;6]V94%G9W)E9V%T94]B:F5C="@I#0H-"B`@("`O*BH-"B`@
M("`@*B!296UO=F4@86X@86=G<F5G871E(&]B:F5C="X-"B`@("`@*@T*("`@
M("`J($!P87)A;2!S=')I;F<@)&-L87-S;F%M92`@=&AE(&-L87-S(&]F('1H
M92!O8FIE8W0@=&\@<F5M;W9E#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&)O
M;VP@(%12544@:68@86X@;V)J96-T('=A<R!R96UO=F5D+"!&04Q312!I9B!N
M;W0-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@<F5M;W9E06=G<F5G871E3V)J96-T*"1C;&%S<VYA;64I
M#0H@("`@>PT*("`@("`@("`D;VL@/2!F86QS93L-"B`@("`@("`@)&-L87-S
M;F%M92`]('-T<G1O;&]W97(H)&-L87-S;F%M92D[#0H@("`@("`@(')E<V5T
M*"1T:&ES+3Y?;65T:&]D7VUA<"D[#0H@("`@("`@('=H:6QE("AL:7-T*"1M
M971H;V0L("1O8FHI(#T@96%C:"@D=&AI<RT^7VUE=&AO9%]M87`I*2![#0H@
M("`@("`@("`@("!I9B`H:7-?82@D;V)J+"`D8VQA<W-N86UE*2D@>PT*("`@
M("`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?;65T:&]D7VUA<%LD;65T:&]D
M72D[#0H@("`@("`@("`@("`@("`@)&]K(#T@=')U93L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)&]K.PT*("`@('T-"@T*
M("`@("\O('U]?0T*("`@("\O('M[>R!?7V-A;&PH*0T*#0H@("`@+RHJ#0H@
M("`@("H@3W9E<FQO861E9"!O8FIE8W0@8V%L;"!H86YD;&5R+"!C86QL960@
M96%C:"!T:6UE(&%N#0H@("`@("H@=6YD969I;F5D+V%G9W)E9V%T960@;65T
M:&]D(&ES(&EN=F]K960N("!4:&ES(&UE=&AO9"!R97!E871S#0H@("`@("H@
M=&AE(&-A;&P@:6X@=&AE(')I9VAT(&%G9W)E9V%T92!O8FIE8W0@86YD('!A
M<W-E<R!O;B!T:&4@<F5T=7)N#0H@("`@("H@=F%L=64N#0H@("`@("H-"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1M971H;V0@('=H:6-H(&UE=&AO9"!T:&%T
M('=A<R!C86QL960-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@)&%R
M9W,@("`@06X@87)R87D@;V8@=&AE('!A<F%M971E<G,@<&%S<V5D(&EN('1H
M90T*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@;W)I9VEN86P@8V%L
M;`T*("`@("`J#0H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(')E='5R;B!V
M86QU92!F<F]M('1H92!A9V=R96=A=&5D(&UE=&AO9"P@;W(@82!014%2#0H@
M("`@("H@("`@("`@("`@("`@("`@97)R;W(@:68@=&AE(&-A;&QE9"!M971H
M;V0@=V%S('5N:VYO=VXN#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7U]C86QL
M*"1M971H;V0L("1A<F=S+"`F)')E='9A;"D-"B`@("![#0H@("`@("`@("1M
M971H;V0@/2!S=')T;VQO=V5R*"1M971H;V0I.PT*("`@("`@("!I9B`H96UP
M='DH)'1H:7,M/E]M971H;V1?;6%P6R1M971H;V1=*2`F)B!I<W-E="@D=&AI
M<RT^7V%U=&]L;V%D7VUA<%LD;65T:&]D72DI('L-"B`@("`@("`@("`@("1T
M:&ES+3YA9&1!9V=R96=A=&5/8FIE8W0H)'1H:7,M/E]A=71O;&]A9%]M87!;
M)&UE=&AO9%TI.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^7VUE=&AO9%]M87!;)&UE=&AO9%TI*2![#0H@("`@("`@("`@("`D<F5T
M=F%L(#T@8V%L;%]U<V5R7V9U;F-?87)R87DH87)R87DH)'1H:7,M/E]M971H
M;V1?;6%P6R1M971H;V1=+"`D;65T:&]D*2P@)&%R9W,I.PT*("`@("`@("`@
M("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@('T-"@T*("`@("\O('U]?0T*?0T*#0IO=F5R;&]A9"@B4$5!
M4E]!=71O;&]A9&5R(BD[#0H-"C\^#0H`````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+T-H
M86YN96Q&:6QE+G!H<```````````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,38Q-S<S(#$P-3$U-#,S-S,R(#`R,C$Q-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`T*+RHJ#0H@*B!014%2
M7T-H86YN96Q&:6QE+"!T:&4@8VAA;FYE;"!H86YD;&EN9R!C;&%S<PT*("H-
M"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H
M92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I
M9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A
M;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P
M;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W
M92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C
M871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H
M;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y
M<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@
M("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC
M96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!#:&%N;F5L1FEL
M92YP:'`L=B`Q+C<U(#(P,#8O,#,O,#(@,3@Z,30Z,3(@8V5L;&]G($5X<"`D
M#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O
M4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L
M96%S92`Q+C0N,&$Q#0H@*B\-"@T*+RHJ#0H@*B!.965D960@9F]R(&5R<F]R
M(&AA;F1L:6YG#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!4B]%<G)O<E-T86-K
M+G!H<"<[#0IR97%U:7)E7V]N8V4@)U!%05(O6$U,4&%R<V5R+G!H<"<[#0IR
M97%U:7)E7V]N8V4@)U!%05(O0V]M;6]N+G!H<"<[#0H-"B\J*@T*("H@17)R
M;W(@8V]D92!I9B!T:&4@8VAA;FYE;"YX;6P@/&-H86YN96P^('1A9R!D;V5S
M(&YO="!C;VYT86EN(&$@=F%L:60@=F5R<VEO;@T*("HO#0ID969I;F4H)U!%
M05)?0TA!3DY%3$9)3$5?15)23U)?3D]?5D524TE/3B<L(#$I.PT*+RHJ#0H@
M*B!%<G)O<B!C;V1E(&EF('1H92!C:&%N;F5L+GAM;"`\8VAA;FYE;#X@=&%G
M('9E<G-I;VX@:7,@;F]T('-U<'!O<G1E9"`H=F5R<VEO;B`Q+C`@:7,@=&AE
M(&]N;'D@<W5P<&]R=&5D('9E<G-I;VXL#0H@*B!C=7)R96YT;'D-"B`J+PT*
M9&5F:6YE*"=014%27T-(04Y.14Q&24Q%7T524D]27TE.5D%,241?5D524TE/
M3B<L(#(I.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@:68@<&%R<VEN9R!I<R!A
M='1E;7!T960@=VET:"!N;R!X;6P@97AT96YS:6]N#0H@*B\-"F1E9FEN92@G
M4$5!4E]#2$%.3D5,1DE,15]%4E)/4E].3U]834Q?15A4)RP@,RD[#0H-"B\J
M*@T*("H@17)R;W(@8V]D92!I9B!C<F5A=&EN9R!T:&4@>&UL('!A<G-E<B!R
M97-O=7)C92!F86EL<PT*("HO#0ID969I;F4H)U!%05)?0TA!3DY%3$9)3$5?
M15)23U)?0T%.5%]-04M%7U!!4E-%4B<L(#0I.PT*#0HO*BH-"B`J($5R<F]R
M(&-O9&4@=7-E9"!F;W(@86QL('-A>"!X;6P@<&%R<VEN9R!E<G)O<G,-"B`J
M+PT*9&5F:6YE*"=014%27T-(04Y.14Q&24Q%7T524D]27U!!4E-%4E]%4E)/
M4B<L(#4I.PT*#0HO*BHC0"L-"B`J(%9A;&ED871I;VX@97)R;W)S#0H@*B\-
M"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(&-H86YN96P@;F%M92!I<R!M:7-S
M:6YG#0H@*B\-"F1E9FEN92@G4$5!4E]#2$%.3D5,1DE,15]%4E)/4E].3U].
M04U%)RP@-BD[#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!C:&%N;F5L(&YA
M;64@:7,@:6YV86QI9`T*("HO#0ID969I;F4H)U!%05)?0TA!3DY%3$9)3$5?
M15)23U)?24Y604Q)1%].04U%)RP@-RD[#0HO*BH-"B`J($5R<F]R(&-O9&4@
M=VAE;B!C:&%N;F5L('-U;6UA<GD@:7,@;6ES<VEN9PT*("HO#0ID969I;F4H
M)U!%05)?0TA!3DY%3$9)3$5?15)23U)?3D]?4U5-34%262<L(#@I.PT*+RHJ
M#0H@*B!%<G)O<B!C;V1E('=H96X@8VAA;FYE;"!S=6UM87)Y(&ES(&UU;'1I
M+6QI;F4-"B`J+PT*9&5F:6YE*"=014%27T-(04Y.14Q&24Q%7T524D]27TU5
M3%1)3$E.15]354U-05)9)RP@.2D[#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE
M;B!C:&%N;F5L('-E<G9E<B!I<R!M:7-S:6YG(&9O<B!X;6QR<&,@;W(@<V]A
M<"!P<F]T;V-O;`T*("HO#0ID969I;F4H)U!%05)?0TA!3DY%3$9)3$5?15)2
M3U)?3D]?2$]35"<L(#$P*3L-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(&-H
M86YN96P@<V5R=F5R(&ES(&EN=F%L:60@9F]R('AM;')P8R!O<B!S;V%P('!R
M;W1O8V]L#0H@*B\-"F1E9FEN92@G4$5!4E]#2$%.3D5,1DE,15]%4E)/4E])
M3E9!3$E$7TA/4U0G+"`Q,2D[#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!A
M(&UI<G)O<B!N86UE(&ES(&EN=F%L:60-"B`J+PT*9&5F:6YE*"=014%27T-(
M04Y.14Q&24Q%7T524D]27TE.5D%,241?34E24D]2)RP@,C$I.PT*+RHJ#0H@
M*B!%<G)O<B!C;V1E('=H96X@82!M:7)R;W(@='EP92!I<R!I;G9A;&ED#0H@
M*B\-"F1E9FEN92@G4$5!4E]#2$%.3D5,1DE,15]%4E)/4E])3E9!3$E$7TU)
M4E)/4E194$4G+"`R,BD[#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!A;B!A
M='1E;7!T(&ES(&UA9&4@=&\@9V5N97)A=&4@>&UL+"!B=70@=&AE('!A<G-E
M9"!C;VYT96YT(&ES(&EN=F%L:60-"B`J+PT*9&5F:6YE*"=014%27T-(04Y.
M14Q&24Q%7T524D]27TE.5D%,240G+"`R,RD[#0HO*BH-"B`J($5R<F]R(&-O
M9&4@=VAE;B!A;B!E;7!T>2!P86-K86=E(&YA;64@=F%L:61A=&4@<F5G97@@
M:7,@<&%S<V5D(&EN#0H@*B\-"F1E9FEN92@G4$5!4E]#2$%.3D5,1DE,15]%
M4E)/4E]%35!465]214=%6"<L(#(T*3L-"B\J*@T*("H@17)R;W(@8V]D92!W
M:&5N(&$@/&9U;F-T:6]N/B!T86<@:&%S(&YO('9E<G-I;VX-"B`J+PT*9&5F
M:6YE*"=014%27T-(04Y.14Q&24Q%7T524D]27TY/7T953D-424].5D524TE/
M3B<L(#(U*3L-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(&$@/&9U;F-T:6]N
M/B!T86<@:&%S(&YO(&YA;64-"B`J+PT*9&5F:6YE*"=014%27T-(04Y.14Q&
M24Q%7T524D]27TY/7T953D-424].3D%-12<L(#(V*3L-"B\J*@T*("H@17)R
M;W(@8V]D92!W:&5N(&$@/'9A;&ED871E<&%C:V%G93X@=&%G(&AA<R!N;R!N
M86UE#0H@*B\-"F1E9FEN92@G4$5!4E]#2$%.3D5,1DE,15]%4E)/4E].3U9!
M3$E$051%7TY!344G+"`R-RD[#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!A
M(#QV86QI9&%T97!A8VMA9V4^('1A9R!H87,@;F\@=F5R<VEO;B!A='1R:6)U
M=&4-"B`J+PT*9&5F:6YE*"=014%27T-(04Y.14Q&24Q%7T524D]27TY/5D%,
M241!5$5?5D524TE/3B<L(#(X*3L-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N
M(&$@;6ER<F]R(&1O97,@;F]T(&5X:7-T(&)U="!I<R!C86QL960@9F]R(&EN
M(&]N92!O9B!T:&4@<V5T*@T*("H@;65T:&]D<RX-"B`J+PT*9&5F:6YE*"=0
M14%27T-(04Y.14Q&24Q%7T524D]27TU)4E)/4E].3U1?1D]53D0G+"`S,BD[
M#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!A('-E<G9E<B!P;W)T(&ES(&YO
M="!N=6UE<FEC#0H@*B\-"F1E9FEN92@G4$5!4E]#2$%.3D5,1DE,15]%4E)/
M4E])3E9!3$E$7U!/4E0G+"`S,RD[#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE
M;B`\<W1A=&EC/B!C;VYT86EN<R!N;R!V97)S:6]N(&%T=')I8G5T90T*("HO
M#0ID969I;F4H)U!%05)?0TA!3DY%3$9)3$5?15)23U)?3D]?4U1!5$E#5D52
M4TE/3B<L(#,T*3L-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(#QB87-E=7)L
M/B!C;VYT86EN<R!N;R!T>7!E(&%T=')I8G5T92!I;B!A(#QR97-T/B!P<F]T
M;V-O;"!D969I;FET:6]N#0H@*B\-"F1E9FEN92@G4$5!4E]#2$%.3D5,1DE,
M15]%4E)/4E].3T)!4T554DQ465!%)RP@,S4I.PT*+RHJ(`T*("H@17)R;W(@
M8V]D92!W:&5N(&$@;6ER<F]R(&ES(&1E9FEN960@86YD('1H92!C:&%N;F5L
M+GAM;"!R97!R97-E;G1S('1H92!?7W5R:2!P<V5U9&\M8VAA;FYE;`T*("HO
M#0ID969I;F4H)U!%05)?0TA!3DY%3$9)3$5?55))7T-!3E1?34E24D]2)RP@
M,S8I.PT*+RHJ(`T*("H@17)R;W(@8V]D92!W:&5N('-S;"!A='1R:6)U=&4@
M:7,@<')E<V5N="!A;F0@:7,@;F]T(")Y97,B#0H@*B\-"F1E9FEN92@G4$5!
M4E]#2$%.3D5,1DE,15]%4E)/4E])3E9!3$E$7U-33"<L(#,W*3L-"B\J*B-`
M+2HO#0H-"B\J*@T*("H@36ER<F]R('1Y<&5S(&%L;&]W960N("!#=7)R96YT
M;'D@;VYL>2!I;G1E<FYE="!S97)V97)S(&%R92!R96-O9VYI>F5D+@T*("HO
M#0HD1TQ/0D%,4ULG7U!%05)?0TA!3DY%3%-?34E24D]27U194$53)UT@/2`@
M87)R87DH)W-E<G9E<B<I.PT*#0H-"B\J*@T*("H@5&AE($-H86YN96P@:&%N
M9&QI;F<@8VQA<W,-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C
M:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L
M;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(
M4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@
M("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N
M<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V
M86EL86)L92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*8VQA<W,@4$5!
M4E]#:&%N;F5L1FEL92![#0H@("`@+RHJ#0H@("`@("H@0&%C8V5S<R!P<FEV
M871E#0H@("`@("H@0'9A<B!014%27T5R<F]R4W1A8VL-"B`@("`@*B!`86-C
M97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!V87(@)%]S=&%C:SL-"B`@("`-
M"B`@("`O*BH-"B`@("`@*B!3=7!P;W)T960@8VAA;FYE;"YX;6P@=F5R<VEO
M;G,L(&9O<B!P87)S:6YG#0H@("`@("H@0'9A<B!A<G)A>0T*("`@("`J($!A
M8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D7W-U<'!O<G1E9%9E
M<G-I;VYS(#T@87)R87DH)S$N,"<I.PT*#0H@("`@+RHJ#0H@("`@("H@4&%R
M<V5D(&-H86YN96P@:6YF;W)M871I;VX-"B`@("`@*B!`=F%R(&%R<F%Y#0H@
M("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?8VAA
M;FYE;$EN9F\[#0H-"B`@("`O*BH-"B`@("`@*B!I;F1E>"!I;G1O('1H92!S
M=6)C:&%N;F5L<R!A<G)A>2P@=7-E9"!F;W(@<&%R<VEN9R!X;6P-"B`@("`@
M*B!`=F%R(&EN=`T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*
M("`@('9A<B`D7W-U8F-H86YN96Q);F1E>#L-"@T*("`@("\J*@T*("`@("`J
M(&EN9&5X(&EN=&\@=&AE(&UI<G)O<G,@87)R87DL('5S960@9F]R('!A<G-I
M;F<@>&UL#0H@("`@("H@0'9A<B!I;G0-"B`@("`@*B!`86-C97-S('!R:79A
M=&4-"B`@("`@*B\-"B`@("!V87(@)%]M:7)R;W));F1E>#L-"B`@("`-"B`@
M("`O*BH-"B`@("`@*B!&;&%G('5S960@=&\@9&5T97)M:6YE('1H92!V86QI
M9&ET>2!O9B!P87)S960@8V]N=&5N=`T*("`@("`J($!V87(@8F]O;&5A;@T*
M("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D7VES
M5F%L:60@/2!F86QS93L-"@T*("`@(&9U;F-T:6]N(%!%05)?0VAA;FYE;$9I
M;&4H*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:R`]("9N97<@4$5!
M4E]%<G)O<E-T86-K*"=014%27T-H86YN96Q&:6QE)RD[#0H@("`@("`@("1T
M:&ES+3Y?<W1A8VLM/G-E=$5R<F]R365S<V%G951E;7!L871E*"1T:&ES+3Y?
M9V5T17)R;W)-97-S86=E*"DI.PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@
M/2!F86QS93L-"B`@("!]#0H@("`@#0H@("`@+RHJ#0H@("`@("H@0')E='5R
M;B!A<G)A>0T*("`@("`J($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@7V=E=$5R<F]R365S<V%G92@I#0H@("`@>PT*("`@("`@
M("!R971U<FX-"B`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@("`@
M(%!%05)?0TA!3DY%3$9)3$5?15)23U)?24Y604Q)1%]615)324].(#T^#0H@
M("`@("`@("`@("`@("`@("`@("=7:&EL92!P87)S:6YG(&-H86YN96PN>&UL
M+"!A;B!I;G9A;&ED('9E<G-I;VX@;G5M8F5R("(E=F5R<VEO;B4@=V%S('!A
M<W-E9"!I;BP@97AP96-T:6YG(&]N92!O9B`E=F5R<VEO;G,E)RP-"B`@("`@
M("`@("`@("`@("!014%27T-(04Y.14Q&24Q%7T524D]27TY/7U9%4E-)3TX@
M/3X-"B`@("`@("`@("`@("`@("`@("`@)TYO('9E<G-I;VX@;G5M8F5R(&9O
M=6YD(&EN(#QC:&%N;F5L/B!T86<G+`T*("`@("`@("`@("`@("`@(%!%05)?
M0TA!3DY%3$9)3$5?15)23U)?3D]?6$U,7T585"`]/@T*("`@("`@("`@("`@
M("`@("`@("`G)65R<F]R)2<L#0H@("`@("`@("`@("`@("`@4$5!4E]#2$%.
M3D5,1DE,15]%4E)/4E]#04Y47TU!2T5?4$%24T52(#T^#0H@("`@("`@("`@
M("`@("`@("`@("=5;F%B;&4@=&\@8W)E871E(%A-3"!P87)S97(G+`T*("`@
M("`@("`@("`@("`@(%!%05)?0TA!3DY%3$9)3$5?15)23U)?4$%24T527T52
M4D]2(#T^#0H@("`@("`@("`@("`@("`@("`@("<E97)R;W(E)RP-"B`@("`@
M("`@("`@("`@("!014%27T-(04Y.14Q&24Q%7T524D]27TY/7TY!344@/3X-
M"B`@("`@("`@("`@("`@("`@("`@)TUI<W-I;F<@8VAA;FYE;"!N86UE)RP-
M"B`@("`@("`@("`@("`@("!014%27T-(04Y.14Q&24Q%7T524D]27TE.5D%,
M241?3D%-12`]/@T*("`@("`@("`@("`@("`@("`@("`G26YV86QI9"!C:&%N
M;F5L("5T86<E("(E;F%M924B)RP-"B`@("`@("`@("`@("`@("!014%27T-(
M04Y.14Q&24Q%7T524D]27TY/7U-534U!4ED@/3X-"B`@("`@("`@("`@("`@
M("`@("`@)TUI<W-I;F<@8VAA;FYE;"!S=6UM87)Y)RP-"B`@("`@("`@("`@
M("`@("!014%27T-(04Y.14Q&24Q%7T524D]27TU53%1)3$E.15]354U-05)9
M(#T^#0H@("`@("`@("`@("`@("`@("`@("=#:&%N;F5L('-U;6UA<GD@<VAO
M=6QD(&)E(&]N(&]N92!L:6YE+"!B=70@:7,@;75L=&DM;&EN92<L#0H@("`@
M("`@("`@("`@("`@4$5!4E]#2$%.3D5,1DE,15]%4E)/4E].3U](3U-4(#T^
M#0H@("`@("`@("`@("`@("`@("`@("=-:7-S:6YG(&-H86YN96P@<V5R=F5R
M(&9O<B`E='EP924@<V5R=F5R)RP-"B`@("`@("`@("`@("`@("!014%27T-(
M04Y.14Q&24Q%7T524D]27TE.5D%,241?2$]35"`]/@T*("`@("`@("`@("`@
M("`@("`@("`G4V5R=F5R(&YA;64@(B5S97)V97(E(B!I<R!I;G9A;&ED(&9O
M<B`E='EP924@<V5R=F5R)RP-"B`@("`@("`@("`@("`@("!014%27T-(04Y.
M14Q&24Q%7T524D]27TE.5D%,241?34E24D]2(#T^#0H@("`@("`@("`@("`@
M("`@("`@("=);G9A;&ED(&UI<G)O<B!N86UE("(E;F%M924B+"!M:7)R;W(@
M='EP92`E='EP924G+`T*("`@("`@("`@("`@("`@(%!%05)?0TA!3DY%3$9)
M3$5?15)23U)?24Y604Q)1%]-25)23U)465!%(#T^#0H@("`@("`@("`@("`@
M("`@("`@("=);G9A;&ED(&UI<G)O<B!T>7!E("(E='EP924B)RP-"B`@("`@
M("`@("`@("`@("!014%27T-(04Y.14Q&24Q%7T524D]27TE.5D%,240@/3X-
M"B`@("`@("`@("`@("`@("`@("`@)T-A;FYO="!G96YE<F%T92!X;6PL(&-O
M;G1E;G1S(&%R92!I;G9A;&ED)RP-"B`@("`@("`@("`@("`@("!014%27T-(
M04Y.14Q&24Q%7T524D]27T5-4%197U)%1T58(#T^#0H@("`@("`@("`@("`@
M("`@("`@("=P86-K86=E;F%M97)E9V5X(&-A;FYO="!B92!E;7!T>2<L#0H@
M("`@("`@("`@("`@("`@4$5!4E]#2$%.3D5,1DE,15]%4E)/4E].3U]&54Y#
M5$E/3E9%4E-)3TX@/3X-"B`@("`@("`@("`@("`@("`@("`@)R5P87)E;G0E
M("5P<F]T;V-O;"4@9G5N8W1I;VX@:&%S(&YO('9E<G-I;VXG+`T*("`@("`@
M("`@("`@("`@(%!%05)?0TA!3DY%3$9)3$5?15)23U)?3D]?1E5.0U1)3TY.
M04U%(#T^#0H@("`@("`@("`@("`@("`@("`@("<E<&%R96YT)2`E<')O=&]C
M;VPE(&9U;F-T:6]N(&AA<R!N;R!N86UE)RP-"B`@("`@("`@("`@("`@("!0
M14%27T-(04Y.14Q&24Q%7T524D]27TY/0D%315523%194$4@/3X-"B`@("`@
M("`@("`@("`@("`@("`@)R5P87)E;G0E(')E<W0@8F%S975R;"!H87,@;F\@
M='EP92<L#0H@("`@("`@("`@("`@("`@4$5!4E]#2$%.3D5,1DE,15]%4E)/
M4E].3U9!3$E$051%7TY!344@/3X-"B`@("`@("`@("`@("`@("`@("`@)U9A
M;&ED871I;VX@<&%C:V%G92!H87,@;F\@;F%M92!I;B`\=F%L:61A=&5P86-K
M86=E/B!T86<G+`T*("`@("`@("`@("`@("`@(%!%05)?0TA!3DY%3$9)3$5?
M15)23U)?3D]604Q)1$%415]615)324].(#T^#0H@("`@("`@("`@("`@("`@
M("`@("=686QI9&%T:6]N('!A8VMA9V4@(B5P86-K86=E)2(@:&%S(&YO('9E
M<G-I;VXG+`T*("`@("`@("`@("`@("`@(%!%05)?0TA!3DY%3$9)3$5?15)2
M3U)?34E24D]27TY/5%]&3U5.1"`]/@T*("`@("`@("`@("`@("`@("`@("`G
M36ER<F]R("(E;6ER<F]R)2(@9&]E<R!N;W0@97AI<W0G+`T*("`@("`@("`@
M("`@("`@(%!%05)?0TA!3DY%3$9)3$5?15)23U)?24Y604Q)1%]03U)4(#T^
M#0H@("`@("`@("`@("`@("`@("`@("=0;W)T("(E<&]R="4B(&UU<W0@8F4@
M;G5M97)I8R<L#0H@("`@("`@("`@("`@("`@4$5!4E]#2$%.3D5,1DE,15]%
M4E)/4E].3U]35$%424-615)324].(#T^#0H@("`@("`@("`@("`@("`@("`@
M("<\<W1A=&EC/B!T86<@;75S="!C;VYT86EN('9E<G-I;VX@871T<FEB=71E
M)RP-"B`@("`@("`@("`@("`@("!014%27T-(04Y.14Q&24Q%7U5225]#04Y4
M7TU)4E)/4B`]/@T*("`@("`@("`@("`@("`@("`@("`G5&AE(%]?=7)I('!S
M975D;RUC:&%N;F5L(&-A;FYO="!H879E(&UI<G)O<G,G+`T*("`@("`@("`@
M("`@("`@(%!%05)?0TA!3DY%3$9)3$5?15)23U)?24Y604Q)1%]34TP@/3X-
M"B`@("`@("`@("`@("`@("`@("`@)R5S97)V97(E(&AA<R!I;G9A;&ED('-S
M;"!A='1R:6)U=&4@(B5S<VPE(B!C86X@;VYL>2!B92!Y97,@;W(@;F]T('!R
M97-E;G0G+`T*("`@("`@("`@("`@*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!`<&%R86T@<W1R:6YG(&-O;G1E;G1S(&]F('!A8VMA9V4N>&UL(&9I
M;&4-"B`@("`@*B!`<F5T=7)N(&)O;VP@<W5C8V5S<R!O9B!P87)S:6YG#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@9G)O;5AM;%-T<FEN9R@D9&%T82D-"B`@
M("![#0H@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O/&-H86YN96Q<<RMV97)S
M:6]N/2(H6S`M.5TK7"Y;,"TY72LI(B\G+"`D9&%T82P@)&-H86YN96QV97)S
M:6]N*2D@>PT*("`@("`@("`@("`@:68@*"%I;E]A<G)A>2@D8VAA;FYE;'9E
M<G-I;VY;,5TL("1T:&ES+3Y?<W5P<&]R=&5D5F5R<VEO;G,I*2![#0H@("`@
M("`@("`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A014%27T-(04Y.14Q&
M24Q%7T524D]27TE.5D%,241?5D524TE/3BP@)V5R<F]R)RP-"B`@("`@("`@
M("`@("`@("`@("`@87)R87DH)W9E<G-I;VXG(#T^("1C:&%N;F5L=F5R<VEO
M;ELQ72DI.PT*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("1P87)S97(@/2!N97<@4$5!4E]834Q0
M87)S97([#0H@("`@("`@("`@("`D<F5S=6QT(#T@)'!A<G-E<BT^<&%R<V4H
M)&1A=&$I.PT*("`@("`@("`@("`@:68@*"1R97-U;'0@(3T]('1R=64I('L-
M"B`@("`@("`@("`@("`@("!I9B`H)')E<W5L="T^9V5T0V]D92@I(#T](#$I
M('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A0
M14%27T-(04Y.14Q&24Q%7T524D]27TY/7UA-3%]%6%0L("=E<G)O<B<L#0H@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G97)R;W(G(#T^("1E<G)O
M<BDI.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H4$5!4E]#2$%.3D5,1DE,15]%
M4E)/4E]#04Y47TU!2T5?4$%24T52+"`G97)R;W(G*3L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@)'1H:7,M/E]C:&%N;F5L26YF;R`]("1P
M87)S97(M/F=E=$1A=&$H*3L-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'1H:7,M/E]S=&%C:RT^
M<'5S:"A014%27T-(04Y.14Q&24Q%7T524D]27TY/7U9%4E-)3TXL("=E<G)O
M<B<L(&%R<F%Y*"=X;6PG(#T^("1D871A*2D[#0H@("`@("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("!]#0H@("`@#0H@("`@+RHJ#0H@
M("`@("H@0')E='5R;B!A<G)A>0T*("`@("`J+PT*("`@(&9U;F-T:6]N('1O
M07)R87DH*0T*("`@('L-"B`@("`@("`@:68@*"$D=&AI<RT^7VES5F%L:60@
M)B8@(21T:&ES+3YV86QI9&%T92@I*2![#0H@("`@("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8VAA
M;FYE;$EN9F\[#0H@("`@?0T*("`@(`T*("`@("\J*@T*("`@("`J($!P87)A
M;2!A<G)A>0T*("`@("`J($!S=&%T:6,-"B`@("`@*B!`<F5T=7)N(%!%05)?
M0VAA;FYE;$9I;&5\9F%L<V4@9F%L<V4@:68@:6YV86QI9`T*("`@("`J+PT*
M("`@(&9U;F-T:6]N("9F<F]M07)R87DH)&1A=&$L("1C;VUP871I8FEL:71Y
M(#T@9F%L<V4L("1S=&%C:T-L87-S(#T@)U!%05)?17)R;W)3=&%C:R<I#0H@
M("`@>PT*("`@("`@("`D82`](&YE=R!014%27T-H86YN96Q&:6QE*"1C;VUP
M871I8FEL:71Y+"`D<W1A8VM#;&%S<RD[#0H@("`@("`@("1A+3Y?9G)O;4%R
M<F%Y*"1D871A*3L-"B`@("`@("`@:68@*"$D82T^=F%L:61A=&4H*2D@>PT*
M("`@("`@("`@("`@)&$@/2!F86QS93L-"B`@("`@("`@("`@(')E='5R;B`D
M83L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)&$[#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@56YL:6ME('M`;&EN:R!F<F]M07)R87DH*7T@=&AI
M<R!D;V5S(&YO="!D;R!A;GD@=F%L:61A=&EO;@T*("`@("`J($!P87)A;2!A
M<G)A>0T*("`@("`J($!S=&%T:6,-"B`@("`@*B!`<F5T=7)N(%!%05)?0VAA
M;FYE;$9I;&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F9G)O;4%R<F%Y5VET
M:$5R<F]R<R@D9&%T82P@)&-O;7!A=&EB:6QI='D@/2!F86QS92P-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<W1A8VM#;&%S<R`]("=0
M14%27T5R<F]R4W1A8VLG*0T*("`@('L-"B`@("`@("`@)&$@/2!N97<@4$5!
M4E]#:&%N;F5L1FEL92@D8V]M<&%T:6)I;&ET>2P@)'-T86-K0VQA<W,I.PT*
M("`@("`@("`D82T^7V9R;VU!<G)A>2@D9&%T82D[#0H@("`@("`@(')E='5R
M;B`D83L-"B`@("!]#0H@("`@#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(&%R
M<F%Y#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@7V9R;VU!<G)A>2@D9&%T82D-"B`@("![#0H@("`@("`@("1T:&ES
M+3Y?8VAA;FYE;$EN9F\@/2`D9&%T83L-"B`@("!]#0H@("`@#0H@("`@+RHJ
M#0H@("`@("H@5W)A<'!E<B!T;R![0&QI;FL@4$5!4E]%<G)O<E-T86-K.CIG
M971%<G)O<G,H*7T-"B`@("`@*B!`<&%R86T@8F]O;&5A;B!D971E<FUI;F5S
M('=H971H97(@=&\@<'5R9V4@=&AE(&5R<F]R('-T86-K(&%F=&5R(')E=')I
M979I;F<-"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@9V5T17)R;W)S*"1P=7)G92`](&9A;'-E*0T*("`@('L-"B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?<W1A8VLM/F=E=$5R<F]R<R@D<'5R9V4I.PT*
M("`@('T-"@T*("`@("\J*@T*("`@("`J(%5N:6YD96YT(&=I=F5N('-T<FEN
M9R`H/RD-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@)'-T<B!4:&4@
M<W1R:6YG('1H870@:&%S('1O(&)E('5N:6YD96YT960N#0H@("`@("H@0')E
M='5R;B!S=')I;F<-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!?=6Y);F1E;G0H)'-T<BD-"B`@("![#0H@("`@("`@
M("\O(')E;6]V92!L96%D:6YG(&YE=VQI;F5S#0H@("`@("`@("1S='(@/2!P
M<F5G7W)E<&QA8V4H)R]>6UQR7&Y=*R\G+"`G)RP@)'-T<BD[#0H@("`@("`@
M("\O(&9I;F0@=VAI=&5S<&%C92!A="!T:&4@8F5G:6YN:6YG(&]F('1H92!F
M:7)S="!L:6YE#0H@("`@("`@("1I;F1E;G1?;&5N(#T@<W1R<W!N*"1S='(L
M("(@7'0B*3L-"B`@("`@("`@)&EN9&5N="`]('-U8G-T<B@D<W1R+"`P+"`D
M:6YD96YT7VQE;BD[#0H@("`@("`@("1D871A(#T@)R<[#0H@("`@("`@("\O
M(')E;6]V92!T:&4@<V%M92!A;6]U;G0@;V8@=VAI=&5S<&%C92!F<F]M(&9O
M;&QO=VEN9R!L:6YE<PT*("`@("`@("!F;W)E86-H("AE>'!L;V1E*")<;B(L
M("1S='(I(&%S("1L:6YE*2![#0H@("`@("`@("`@("!I9B`H<W5B<W1R*"1L
M:6YE+"`P+"`D:6YD96YT7VQE;BD@/3T@)&EN9&5N="D@>PT*("`@("`@("`@
M("`@("`@("1D871A("X]('-U8G-T<B@D;&EN92P@)&EN9&5N=%]L96XI("X@
M(EQN(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@)&1A=&$[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4&%R<V4@82!C
M:&%N;F5L+GAM;"!F:6QE+B`@17AP96-T<R!T:&4@;F%M92!O9@T*("`@("`J
M(&$@8VAA;FYE;"!X;6P@9FEL92!A<R!I;G!U="X-"B`@("`@*@T*("`@("`J
M($!P87)A;2!S=')I;F<@("1D97-C9FEL92`@;F%M92!O9B!C:&%N;F5L('AM
M;"!F:6QE#0H@("`@("H@0')E='5R;B!B;V]L('-U8V-E<W,@;V8@<&%R<VEN
M9PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&9R;VU8;6Q&:6QE*"1D97-C9FEL
M92D-"B`@("![#0H@("`@("`@(&EF("@A0&ES7V9I;&4H)&1E<V-F:6QE*2!\
M?"`A:7-?<F5A9&%B;&4H)&1E<V-F:6QE*2!\?`T*("`@("`@("`@("`@("@A
M)&9P(#T@0&9O<&5N*"1D97-C9FEL92P@)W(G*2DI('L-"B`@("`@("`@("`@
M(')E<75I<F5?;VYC92`G4$5!4BYP:'`G.PT*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H(E5N86)L92!T;R!O<&5N("1D97-C9FEL92(I
M.PT*("`@("`@("!]#0H-"B`@("`@("`@+R\@<F5A9"!T:&4@=VAO;&4@=&AI
M;F<@<V\@=V4@;VYL>2!G970@;VYE(&-D871A(&-A;&QB86-K#0H@("`@("`@
M("\O(&9O<B!E86-H(&)L;V-K(&]F(&-D871A#0H@("`@("`@(&EF("AF=6YC
M=&EO;E]E>&ES=',H)V9I;&5?9V5T7V-O;G1E;G1S)RDI('L-"B`@("`@("`@
M("`@(&9C;&]S92@D9G`I.PT*("`@("`@("`@("`@)&1A=&$@/2!F:6QE7V=E
M=%]C;VYT96YT<R@D9&5S8V9I;&4I.PT*("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@)&1A=&$@/2!F<F5A9"@D9G`L(&9I;&5S:7IE*"1D97-C9FEL
M92DI.PT*("`@("`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N("1T:&ES+3YF<F]M6&UL4W1R:6YG*"1D871A*3L-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`@*B!087)S92!C:&%N;F5L(&EN9F]R;6%T
M:6]N(&9R;VT@9&EF9F5R96YT('-O=7)C97,-"B`@("`@*@T*("`@("`J(%1H
M:7,@;65T:&]D(&ES(&%B;&4@=&\@97AT<F%C="!I;F9O<FUA=&EO;B!A8F]U
M="!A(&-H86YN96P-"B`@("`@*B!F<F]M(&%N("YX;6P@9FEL92!O<B!A('-T
M<FEN9PT*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`
M<&%R86T@('-T<FEN9R!&:6QE;F%M92!O9B!T:&4@<V]U<F-E(&]R('1H92!S
M;W5R8V4@:71S96QF#0H@("`@("H@0')E='5R;B!B;V]L#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@9G)O;4%N>2@D:6YF;RD-"B`@("![#0H@("`@("`@(&EF
M("AI<U]S=')I;F<H)&EN9F\I("8F(&9I;&5?97AI<W1S*"1I;F9O*2`F)B!S
M=')L96XH)&EN9F\I(#P@,C4U*2![#0H@("`@("`@("`@("`D=&UP(#T@<W5B
M<W1R*"1I;F9O+"`M-"D[#0H@("`@("`@("`@("!I9B`H)'1M<"`]/2`G+GAM
M;"<I('L-"B`@("`@("`@("`@("`@("`D:6YF;R`]("1T:&ES+3YF<F]M6&UL
M1FEL92@D:6YF;RD[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("1F<"`](&9O<&5N*"1I;F9O+"`B<B(I.PT*("`@("`@("`@("`@
M("`@("1T97-T(#T@9G)E860H)&9P+"`U*3L-"B`@("`@("`@("`@("`@("!F
M8VQO<V4H)&9P*3L-"B`@("`@("`@("`@("`@("!I9B`H)'1E<W0@/3T@(CP_
M>&UL(BD@>PT*("`@("`@("`@("`@("`@("`@("`D:6YF;R`]("1T:&ES+3YF
M<F]M6&UL1FEL92@D:6YF;RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&EN9F\I
M*2![#0H@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+G!H<"<[
M#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)&EN
M9F\I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI
M<U]S=')I;F<H)&EN9F\I*2![#0H@("`@("`@("`@("`D:6YF;R`]("1T:&ES
M+3YF<F]M6&UL4W1R:6YG*"1I;F9O*3L-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@)&EN9F\[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4F5T=7)N
M(&%N(%A-3"!D;V-U;65N="!B87-E9"!O;B!P<F5V:6]U<R!P87)S:6YG(&%N
M9"!M;V1I9FEC871I;VYS#0H@("`@("H-"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R!834P@9&%T80T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!T;UAM;"@I#0H@("`@>PT*("`@("`@("!I
M9B`H(21T:&ES+3Y?:7-686QI9"`F)B`A)'1H:7,M/G9A;&ED871E*"DI('L-
M"B`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27T-(04Y.
M14Q&24Q%7T524D]27TE.5D%,240I.PT*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]C
M:&%N;F5L26YF;ULG871T<FEB<R==6R=V97)S:6]N)UTI*2![#0H@("`@("`@
M("`@("`D=&AI<RT^7V-H86YN96Q);F9O6R=A='1R:6)S)UU;)W9E<G-I;VXG
M72`]("<Q+C`G.PT*("`@("`@("!]#0H@("`@("`@("1C:&%N;F5L26YF;R`]
M("1T:&ES+3Y?8VAA;FYE;$EN9F\[#0H@("`@("`@("1R970@/2`B/#]X;6P@
M=F5R<VEO;CU<(C$N,%PB(&5N8V]D:6YG/5PB25-/+3@X-3DM,5PB(#\^7&XB
M.PT*("`@("`@("`D<F5T("X]("(\8VAA;FYE;"!V97)S:6]N/5PB(B`N#0H@
M("`@("`@("`@("`D8VAA;FYE;$EN9F];)V%T=')I8G,G75LG=F5R<VEO;B==
M("X@(EPB('AM;&YS/5PB:'1T<#HO+W!E87(N<&AP+FYE="]C:&%N;F5L+3$N
M,%PB#0H@('AM;&YS.GAS:3U<(FAT='`Z+R]W=W<N=S,N;W)G+S(P,#$O6$U,
M4V-H96UA+6EN<W1A;F-E7"(-"B`@>'-I.G-C:&5M84QO8V%T:6]N/5PB:'1T
M<#HO+W!E87(N<&AP+FYE="]D=&0O8VAA;FYE;"TB#0H@("`@("`@("`@("`N
M("1C:&%N;F5L26YF;ULG871T<FEB<R==6R=V97)S:6]N)UT@+B`B(&AT='`Z
M+R]P96%R+G!H<"YN970O9'1D+V-H86YN96PM(B`N#0H@("`@("`@("`@("`D
M8VAA;FYE;$EN9F];)V%T=')I8G,G75LG=F5R<VEO;B==("X@(BYX<V1<(CX-
M"B`\;F%M93XD8VAA;FYE;$EN9F];;F%M95T\+VYA;64^#0H@/'-U;6UA<GD^
M(B`N(&AT;6QS<&5C:6%L8VAA<G,H)&-H86YN96Q);F9O6R=S=6UM87)Y)UTI
M+B(\+W-U;6UA<GD^#0HB.PT*("`@("`@("!I9B`H:7-S970H)&-H86YN96Q)
M;F9O6R=S=6=G97-T961A;&EA<R==*2D@>PT*("`@("`@("`@("`@)')E="`N
M/2`G(#QS=6=G97-T961A;&EA<SXG("X@)&-H86YN96Q);F9O6R=S=6=G97-T
M961A;&EA<R==("X@(CPO<W5G9V5S=&5D86QI87,^7&XB.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("AI<W-E="@D8VAA;FYE;$EN9F];)W9A;&ED871E<&%C
M:V%G92==*2D@>PT*("`@("`@("`@("`@)')E="`N/2`G(#QV86QI9&%T97!A
M8VMA9V4@=F5R<VEO;CTB)R`N#0H@("`@("`@("`@("`@("`@)&-H86YN96Q)
M;F9O6R=V86QI9&%T97!A8VMA9V4G75LG871T<FEB<R==6R=V97)S:6]N)UTN
M("<B/B<@+@T*("`@("`@("`@("`@("`@(&AT;6QS<&5C:6%L8VAA<G,H)&-H
M86YN96Q);F9O6R=V86QI9&%T97!A8VMA9V4G75LG7V-O;G1E;G0G72D@+@T*
M("`@("`@("`@("`@("`@("(\+W9A;&ED871E<&%C:V%G93Y<;B([#0H@("`@
M("`@('T-"B`@("`@("`@)')E="`N/2`B(#QS97)V97)S/EQN(CL-"B`@("`@
M("`@)')E="`N/2`G("`\<')I;6%R>2<[#0H@("`@("`@(&EF("AI<W-E="@D
M8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R=A='1R:6)S)UU;
M)W-S;"==*2D@>PT*("`@("`@("`@("`@)')E="`N/2`G('-S;#TB)R`N("1C
M:&%N;F5L26YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)V%T=')I8G,G75LG
M<W-L)UT@+B`G(B<[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1C
M:&%N;F5L26YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)V%T=')I8G,G75LG
M<&]R="==*2D@>PT*("`@("`@("`@("`@)')E="`N/2`G('!O<G0](B<@+B`D
M8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R=A='1R:6)S)UU;
M)W!O<G0G72`N("<B)SL-"B`@("`@("`@?0T*("`@("`@("`D<F5T("X]("(^
M7&XB.PT*("`@("`@("!I9B`H:7-S970H)&-H86YN96Q);F9O6R=S97)V97)S
M)UU;)W!R:6UA<GDG75LG>&UL<G!C)UTI*2![#0H@("`@("`@("`@("`D<F5T
M("X]("1T:&ES+3Y?;6%K95AM;')P8UAM;"@D8VAA;FYE;$EN9F];)W-E<G9E
M<G,G75LG<')I;6%R>2==6R=X;6QR<&,G72P@)R`@("<I.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("AI<W-E="@D8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG
M<')I;6%R>2==6R=R97-T)UTI*2![#0H@("`@("`@("`@("`D<F5T("X]("1T
M:&ES+3Y?;6%K95)E<W18;6PH)&-H86YN96Q);F9O6R=S97)V97)S)UU;)W!R
M:6UA<GDG75LG<F5S="==+"`G("`@)RD[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&ES<V5T*"1C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;
M)W-O87`G72DI('L-"B`@("`@("`@("`@("1R970@+CT@)'1H:7,M/E]M86ME
M4V]A<%AM;"@D8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R=S
M;V%P)UTL("<@("`G*3L-"B`@("`@("`@?0T*("`@("`@("`D<F5T("X]("(@
M(#PO<')I;6%R>3Y<;B([#0H@("`@("`@(&EF("AI<W-E="@D8VAA;FYE;$EN
M9F];)W-E<G9E<G,G75LG;6ER<F]R)UTI*2![#0H@("`@("`@("`@("`D<F5T
M("X]("1T:&ES+3Y?;6%K94UI<G)O<G-8;6PH)&-H86YN96Q);F9O*3L-"B`@
M("`@("`@?0T*("`@("`@("`D<F5T("X]("(@/"]S97)V97)S/EQN(CL-"B`@
M("`@("`@)')E="`N/2`B/"]C:&%N;F5L/B([#0H@("`@("`@(')E='5R;B!S
M=')?<F5P;&%C92@B7'(B+"`B7&XB+"!S=')?<F5P;&%C92@B7')<;B(L(")<
M;B(L("1R970I*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!'96YE<F%T
M92!T:&4@/'AM;')P8SX@=&%G#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@7VUA:V58;6QR<&-8;6PH)&EN9F\L("1I
M;F1E;G0I#0H@("`@>PT*("`@("`@("`D<F5T(#T@)&EN9&5N="`N("(\>&UL
M<G!C(CL-"B`@("`@("`@:68@*&ES<V5T*"1I;F9O6R=A='1R:6)S)UU;)W!A
M=&@G72DI('L-"B`@("`@("`@("`@("1R970@+CT@)R!P871H/2(G("X@:'1M
M;'-P96-I86QC:&%R<R@D:6YF;ULG871T<FEB<R==6R=P871H)UTI("X@)R(G
M.PT*("`@("`@("!]#0H@("`@("`@("1R970@+CT@(CY<;B([#0H@("`@("`@
M("1R970@+CT@)'1H:7,M/E]M86ME1G5N8W1I;VYS6&UL*"1I;F9O6R=F=6YC
M=&EO;B==+"`B)&EN9&5N="`B*3L-"B`@("`@("`@)')E="`N/2`D:6YD96YT
M("X@(CPO>&UL<G!C/EQN(CL-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@1V5N97)A=&4@=&AE(#QS;V%P/B!T86<-
M"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!?;6%K95-O87!8;6PH)&EN9F\L("1I;F1E;G0I#0H@("`@>PT*("`@("`@
M("`D<F5T(#T@)&EN9&5N="`N("(\<V]A<"([#0H@("`@("`@(&EF("AI<W-E
M="@D:6YF;ULG871T<FEB<R==6R=P871H)UTI*2![#0H@("`@("`@("`@("`D
M<F5T("X]("<@<&%T:#TB)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&EN9F];)V%T
M=')I8G,G75LG<&%T:"==*2`N("<B)SL-"B`@("`@("`@?0T*("`@("`@("`D
M<F5T("X]("(^7&XB.PT*("`@("`@("`D<F5T("X]("1T:&ES+3Y?;6%K949U
M;F-T:6]N<UAM;"@D:6YF;ULG9G5N8W1I;VXG72P@(B1I;F1E;G0@(BD[#0H@
M("`@("`@("1R970@+CT@)&EN9&5N="`N("(\+W-O87`^7&XB.PT*("`@("`@
M("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!'96YE
M<F%T92!T:&4@/')E<W0^('1A9PT*("`@("`J($!A8V-E<W,@<')I=F%T90T*
M("`@("`J+PT*("`@(&9U;F-T:6]N(%]M86ME4F5S=%AM;"@D:6YF;RP@)&EN
M9&5N="D-"B`@("![#0H@("`@("`@("1R970@/2`D:6YD96YT("X@(CQR97-T
M/EQN(CL-"B`@("`@("`@:68@*"%I<W-E="@D:6YF;ULG8F%S975R;"==6S!=
M*2D@>PT*("`@("`@("`@("`@)&EN9F];)V)A<V5U<FPG72`](&%R<F%Y*"1I
M;F9O6R=B87-E=7)L)UTI.PT*("`@("`@("!]#0H@("`@("`@(&9O<F5A8V@@
M*"1I;F9O6R=B87-E=7)L)UT@87,@)'5R;"D@>PT*("`@("`@("`@("`@)')E
M="`N/2`B)&EN9&5N="`\8F%S975R;"!T>7!E/5PB(B`N("1U<FQ;)V%T=')I
M8G,G75LG='EP92==("X@(EPB(CL-"B`@("`@("`@("`@("1R970@+CT@(CXB
M("X@)'5R;%LG7V-O;G1E;G0G72`N("(\+V)A<V5U<FP^7&XB.PT*("`@("`@
M("!]#0H@("`@("`@("1R970@+CT@)&EN9&5N="`N("(\+W)E<W0^7&XB.PT*
M("`@("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!'96YE<F%T92!T:&4@/&UI<G)O<G,^('1A9PT*("`@("`J($!A8V-E<W,@
M<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]M86ME36ER<F]R<UAM
M;"@D8VAA;FYE;$EN9F\I#0H@("`@>PT*("`@("`@("`D<F5T(#T@(B([#0H@
M("`@("`@(&EF("@A:7-S970H)&-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI
M<G)O<B==6S!=*2D@>PT*("`@("`@("`@("`@)&-H86YN96Q);F9O6R=S97)V
M97)S)UU;)VUI<G)O<B==(#T@87)R87DH)&-H86YN96Q);F9O6R=S97)V97)S
M)UU;)VUI<G)O<B==*3L-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D
M8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UT@87,@)&UI<G)O<BD@
M>PT*("`@("`@("`@("`@)')E="`N/2`G("`\;6ER<F]R(&AO<W0](B<@+B`D
M;6ER<F]R6R=A='1R:6)S)UU;)VAO<W0G72`N("<B)SL-"B`@("`@("`@("`@
M(&EF("AI<W-E="@D;6ER<F]R6R=A='1R:6)S)UU;)W!O<G0G72DI('L-"B`@
M("`@("`@("`@("`@("`D<F5T("X]("<@<&]R=#TB)R`N("1M:7)R;W);)V%T
M=')I8G,G75LG<&]R="==("X@)R(G.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@:68@*&ES<V5T*"1M:7)R;W);)V%T=')I8G,G75LG<W-L)UTI*2![
M#0H@("`@("`@("`@("`@("`@)')E="`N/2`G('-S;#TB)R`N("1M:7)R;W);
M)V%T=')I8G,G75LG<W-L)UT@+B`G(B<[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`D<F5T("X]("(^7&XB.PT*("`@("`@("`@("`@:68@*&ES<V5T
M*"1M:7)R;W);)WAM;')P8R==*2!\?"!I<W-E="@D;6ER<F]R6R=S;V%P)UTI
M*2![#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1M:7)R;W);)WAM;')P
M8R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<F5T("X]("1T:&ES+3Y?
M;6%K95AM;')P8UAM;"@D;6ER<F]R6R=X;6QR<&,G72P@)R`@("<I.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&UI
M<G)O<ELG<F5S="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<F5T("X]
M("1T:&ES+3Y?;6%K95)E<W18;6PH)&UI<G)O<ELG<F5S="==+"`G("`@)RD[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D;6ER<F]R6R=S;V%P)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1R
M970@+CT@)'1H:7,M/E]M86ME4V]A<%AM;"@D;6ER<F]R6R=S;V%P)UTL("<@
M("`G*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)')E
M="`N/2`B("`\+VUI<G)O<CY<;B([#0H@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("1R970@+CT@(B\^7&XB.PT*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*
M("`@("\J*@T*("`@("`J($=E;F5R871E('1H92`\9G5N8W1I;VYS/B!T86<-
M"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!?;6%K949U;F-T:6]N<UAM;"@D9G5N8W1I;VYS+"`D:6YD96YT+"`D<F5S
M="`](&9A;'-E*0T*("`@('L-"B`@("`@("`@)')E="`]("<G.PT*("`@("`@
M("!I9B`H(6ES<V5T*"1F=6YC=&EO;G-;,%TI*2![#0H@("`@("`@("`@("`D
M9G5N8W1I;VYS(#T@87)R87DH)&9U;F-T:6]N<RD[#0H@("`@("`@('T-"B`@
M("`@("`@9F]R96%C:"`H)&9U;F-T:6]N<R!A<R`D9G5N8W1I;VXI('L-"B`@
M("`@("`@("`@("1R970@+CT@(B1I;F1E;G0\9G5N8W1I;VX@=F5R<VEO;CU<
M(B(@+B`D9G5N8W1I;VY;)V%T=')I8G,G75LG=F5R<VEO;B==("X@(EPB(CL-
M"B`@("`@("`@("`@(&EF("@D<F5S="D@>PT*("`@("`@("`@("`@("`@("1R
M970@+CT@)R!U<FD](B<@+B`D9G5N8W1I;VY;)V%T=')I8G,G75LG=7)I)UT@
M+B`G(B<[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<F5T("X]("(^
M(B`N("1F=6YC=&EO;ELG7V-O;G1E;G0G72`N("(\+V9U;F-T:6]N/EQN(CL-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@
M("`O*BH-"B`@("`@*B!686QI9&%T:6]N(&5R<F]R+B`@06QS;R!M87)K<R!T
M:&4@;V)J96-T(&-O;G1E;G1S(&%S(&EN=F%L:60-"B`@("`@*B!`<&%R86T@
M97)R;W(@8V]D90T*("`@("`J($!P87)A;2!A<G)A>2!E<G)O<B!I;F9O<FUA
M=&EO;@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U
M;F-T:6]N(%]V86QI9&%T945R<F]R*"1C;V1E+"`D<&%R86US(#T@87)R87DH
M*2D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H)&-O9&4L
M("=E<G)O<B<L("1P87)A;7,I.PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@
M/2!F86QS93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!686QI9&%T:6]N
M('=A<FYI;F<N("!$;V5S(&YO="!M87)K('1H92!O8FIE8W0@8V]N=&5N=',@
M:6YV86QI9"X-"B`@("`@*B!`<&%R86T@97)R;W(@8V]D90T*("`@("`J($!P
M87)A;2!A<G)A>2!E<G)O<B!I;F9O<FUA=&EO;@T*("`@("`J($!A8V-E<W,@
M<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]V86QI9&%T95=A<FYI
M;F<H)&-O9&4L("1P87)A;7,@/2!A<G)A>2@I*0T*("`@('L-"B`@("`@("`@
M)'1H:7,M/E]S=&%C:RT^<'5S:"@D8V]D92P@)W=A<FYI;F<G+"`D<&%R86US
M*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!686QI9&%T92!P87)S960@
M9FEL92X-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H@
M0')E='5R;B!B;V]L96%N#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=F%L:61A
M=&4H*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@=')U93L-
M"B`@("`@("`@)&EN9F\@/2`D=&AI<RT^7V-H86YN96Q);F9O.PT*("`@("`@
M("!I9B`H96UP='DH)&EN9F];)VYA;64G72DI('L-"B`@("`@("`@("`@("1T
M:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27T-(04Y.14Q&24Q%7T524D]27TY/
M7TY!344I.PT*("`@("`@("!](&5L<V5I9B`H(21T:&ES+3YV86QI9$-H86YN
M96Q397)V97(H)&EN9F];)VYA;64G72DI('L-"B`@("`@("`@("`@(&EF("@D
M:6YF;ULG;F%M92==("$]("=?7W5R:2<I('L-"B`@("`@("`@("`@("`@("`D
M=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]#2$%.3D5,1DE,15]%4E)/4E])
M3E9!3$E$7TY!344L(&%R<F%Y*"=T86<G(#T^("=N86UE)RP-"B`@("`@("`@
M("`@("`@("`@("`@)VYA;64G(#T^("1I;F9O6R=N86UE)UTI*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H96UP='DH)&EN9F];
M)W-U;6UA<GDG72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%
M<G)O<BA014%27T-(04Y.14Q&24Q%7T524D]27TY/7U-534U!4EDI.PT*("`@
M("`@("!](&5L<V5I9B`H<W1R<&]S*'1R:6TH)&EN9F];)W-U;6UA<GDG72DL
M(")<;B(I("$]/2!F86QS92D@>PT*("`@("`@("`@("`@)'1H:7,M/E]V86QI
M9&%T95=A<FYI;F<H4$5!4E]#2$%.3D5,1DE,15]%4E)/4E]-54Q424Q)3D5?
M4U5-34%262P-"B`@("`@("`@("`@("`@("!A<G)A>2@G<W5M;6%R>2<@/3X@
M)&EN9F];)W-U;6UA<GDG72DI.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI
M<W-E="@D:6YF;ULG<W5G9V5S=&5D86QI87,G72DI('L-"B`@("`@("`@("`@
M(&EF("@A)'1H:7,M/G9A;&ED0VAA;FYE;%-E<G9E<B@D:6YF;ULG<W5G9V5S
M=&5D86QI87,G72DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W9A;&ED
M871E17)R;W(H4$5!4E]#2$%.3D5,1DE,15]%4E)/4E])3E9!3$E$7TY!344L
M#0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=T86<G(#T^("=S=6=G97-T
M961A;&EA<R<L("=N86UE)R`]/B1I;F9O6R=S=6=G97-T961A;&EA<R==*2D[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T
M*"1I;F9O6R=L;V-A;&%L:6%S)UTI*2![#0H@("`@("`@("`@("!I9B`H(21T
M:&ES+3YV86QI9$-H86YN96Q397)V97(H)&EN9F];)VQO8V%L86QI87,G72DI
M('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!
M4E]#2$%.3D5,1DE,15]%4E)/4E])3E9!3$E$7TY!344L#0H@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*"=T86<G(#T^("=L;V-A;&%L:6%S)RP@)VYA;64G
M(#T^)&EN9F];)VQO8V%L86QI87,G72DI.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D:6YF;ULG=F%L:61A=&5P86-K
M86=E)UTI*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1I;F9O6R=V86QI
M9&%T97!A8VMA9V4G75LG7V-O;G1E;G0G72DI('L-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]#2$%.3D5,1DE,15]%4E)/
M4E].3U9!3$E$051%7TY!344I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@:68@*"%I<W-E="@D:6YF;ULG=F%L:61A=&5P86-K86=E)UU;)V%T=')I
M8G,G75LG=F5R<VEO;B==*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M=F%L:61A=&5%<G)O<BA014%27T-(04Y.14Q&24Q%7T524D]27TY/5D%,241!
M5$5?5D524TE/3BP-"B`@("`@("`@("`@("`@("`@("`@87)R87DH)W!A8VMA
M9V4G(#T^($`D:6YF;ULG=F%L:61A=&5P86-K86=E)UU;)U]C;VYT96YT)UTI
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S
M970H)&EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R=A='1R:6)S)UU;)W!O
M<G0G72D@)B8-"B`@("`@("`@("`@("`@(6ES7VYU;65R:6,H)&EN9F];)W-E
M<G9E<G,G75LG<')I;6%R>2==6R=A='1R:6)S)UU;)W!O<G0G72DI('L-"B`@
M("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27T-(04Y.14Q&
M24Q%7T524D]27TE.5D%,241?4$]25"P-"B`@("`@("`@("`@("`@("!A<G)A
M>2@G<&]R="<@/3X@)&EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R=A='1R
M:6)S)UU;)W!O<G0G72DI.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E
M="@D:6YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)V%T=')I8G,G75LG<W-L
M)UTI("8F#0H@("`@("`@("`@("`@("1I;F9O6R=S97)V97)S)UU;)W!R:6UA
M<GDG75LG871T<FEB<R==6R=S<VPG72`A/2`G>65S)RD@>PT*("`@("`@("`@
M("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?0TA!3DY%3$9)3$5?15)2
M3U)?24Y604Q)1%]34TPL#0H@("`@("`@("`@("`@("`@87)R87DH)W-S;"<@
M/3X@)&EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R=A='1R:6)S)UU;)W-S
M;"==+`T*("`@("`@("`@("`@("`@("`@("`G<V5R=F5R)R`]/B`D:6YF;ULG
M;F%M92==*2D[#0H@("`@("`@('T-"@T*("`@("`@("!I9B`H:7-S970H)&EN
M9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R=X;6QR<&,G72D@)B8-"B`@("`@
M("`@("`@("`@:7-S970H)&EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R=X
M;6QR<&,G75LG9G5N8W1I;VXG72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?
M=F%L:61A=&5&=6YC=&EO;G,H)WAM;')P8R<L("1I;F9O6R=S97)V97)S)UU;
M)W!R:6UA<GDG75LG>&UL<G!C)UU;)V9U;F-T:6]N)UTI.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("AI<W-E="@D:6YF;ULG<V5R=F5R<R==6R=P<FEM87)Y
M)UU;)W-O87`G72D@)B8-"B`@("`@("`@("`@("`@:7-S970H)&EN9F];)W-E
M<G9E<G,G75LG<')I;6%R>2==6R=S;V%P)UU;)V9U;F-T:6]N)UTI*2![#0H@
M("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E1G5N8W1I;VYS*"=S;V%P)RP@
M)&EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R=S;V%P)UU;)V9U;F-T:6]N
M)UTI.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D:6YF;ULG<V5R
M=F5R<R==6R=P<FEM87)Y)UU;)W)E<W0G72D@)B8-"B`@("`@("`@("`@("`@
M:7-S970H)&EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R=R97-T)UU;)V)A
M<V5U<FPG72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5&=6YC
M=&EO;G,H)W)E<W0G+"`D:6YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)W)E
M<W0G75LG8F%S975R;"==*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S
M970H)&EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UTI*2![#0H@("`@("`@("`@
M("!I9B`H)'1H:7,M/E]C:&%N;F5L26YF;ULG;F%M92==(#T]("=?7W5R:2<I
M('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!
M4E]#2$%.3D5,1DE,15]54DE?0T%.5%]-25)23U(I.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@:68@*"%I<W-E="@D:6YF;ULG<V5R=F5R<R==6R=M
M:7)R;W(G75LP72DI('L-"B`@("`@("`@("`@("`@("`D:6YF;ULG<V5R=F5R
M<R==6R=M:7)R;W(G72`](&%R<F%Y*"1I;F9O6R=S97)V97)S)UU;)VUI<G)O
M<B==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1I(#T@,#L-"B`@
M("`@("`@("`@(&9O<F5A8V@@*"1I;F9O6R=S97)V97)S)UU;)VUI<G)O<B==
M(&%S("1M:7)R;W(I('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1M
M:7)R;W);)V%T=')I8G,G75LG:&]S="==*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]#2$%.3D5,1DE,15]%
M4E)/4E].3U](3U-4+`T*("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=T
M>7!E)R`]/B`G;6ER<F]R)RDI.PT*("`@("`@("`@("`@("`@('T@96QS96EF
M("@A)'1H:7,M/G9A;&ED0VAA;FYE;%-E<G9E<B@D;6ER<F]R6R=A='1R:6)S
M)UU;)VAO<W0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]V
M86QI9&%T945R<F]R*%!%05)?0TA!3DY%3$9)3$5?15)23U)?24Y604Q)1%](
M3U-4+`T*("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W-E<G9E<B<@
M/3X@)&UI<G)O<ELG871T<FEB<R==6R=H;W-T)UTL("=T>7!E)R`]/B`G;6ER
M<F]R)RDI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)&UI<G)O<ELG871T<FEB<R==6R=S<VPG72D@)B8@)&UI<G)O
M<ELG871T<FEB<R==6R=S<VPG72`A/2`G>65S)RD@>PT*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]#2$%.3D5,1DE,
M15]%4E)/4E])3E9!3$E$7U-33"P-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*"=S<VPG(#T^("1I;F9O6R=S<VPG72P@)W-E<G9E<B<@/3X@)&UI
M<G)O<ELG871T<FEB<R==6R=H;W-T)UTI*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1M:7)R;W);)WAM;')P8R==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E1G5N
M8W1I;VYS*"=X;6QR<&,G+`T*("`@("`@("`@("`@("`@("`@("`@("`@)&UI
M<G)O<ELG>&UL<G!C)UU;)V9U;F-T:6]N)UTL("1M:7)R;W);)V%T=')I8G,G
M75LG:&]S="==*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1M:7)R;W);)W-O87`G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]V86QI9&%T949U;F-T:6]N<R@G<V]A<"<L("1M
M:7)R;W);)W-O87`G75LG9G5N8W1I;VXG72P-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1M:7)R;W);)V%T=')I8G,G75LG:&]S="==*3L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1M:7)R;W);
M)W)E<W0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI
M9&%T949U;F-T:6]N<R@G<F5S="<L("1M:7)R;W);)W)E<W0G75LG8F%S975R
M;"==+`T*("`@("`@("`@("`@("`@("`@("`@("`@)&UI<G)O<ELG871T<FEB
M<R==6R=H;W-T)UTI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'1H:7,M/E]I<U9A;&ED
M.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S=')I;F<@>&UL
M<G!C(&]R('-O87`@+2!P<F]T;V-O;"!N86UE('1H:7,@9G5N8W1I;VX@87!P
M;&EE<R!T;PT*("`@("`J($!P87)A;2!A<G)A>2!T:&4@9G5N8W1I;VYS#0H@
M("`@("H@0'!A<F%M('-T<FEN9R!T:&4@;F%M92!O9B!T:&4@<&%R96YT(&5L
M96UE;G0@*&UI<G)O<B!N86UE+"!F;W(@:6YS=&%N8V4I#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@7W9A;&ED871E1G5N8W1I;VYS*"1P<F]T;V-O;"P@)&9U
M;F-T:6]N<RP@)'!A<F5N="`]("<G*0T*("`@('L-"B`@("`@("`@:68@*"%I
M<W-E="@D9G5N8W1I;VYS6S!=*2D@>PT*("`@("`@("`@("`@)&9U;F-T:6]N
M<R`](&%R<F%Y*"1F=6YC=&EO;G,I.PT*("`@("`@("!]#0H@("`@("`@(&9O
M<F5A8V@@*"1F=6YC=&EO;G,@87,@)&9U;F-T:6]N*2![#0H@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1F=6YC=&EO;ELG7V-O;G1E;G0G72D@?'P@96UP='DH
M)&9U;F-T:6]N6R=?8V]N=&5N="==*2D@>PT*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27T-(04Y.14Q&24Q%7T524D]27TY/
M7T953D-424].3D%-12P-"B`@("`@("`@("`@("`@("`@("`@87)R87DH)W!A
M<F5N="<@/3X@)'!A<F5N="P@)W!R;W1O8V]L)R`]/B`D<')O=&]C;VPI*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D<')O=&]C;VP@/3T@
M)W)E<W0G*2![#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D9G5N8W1I
M;VY;)V%T=')I8G,G75LG='EP92==*2!\?`T*("`@("`@("`@("`@("`@("`@
M("`@(&5M<'1Y*"1F=6YC=&EO;ELG871T<FEB<R==6R=T>7!E)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%2
M7T-(04Y.14Q&24Q%7T524D]27TY/7T)!4T554DQ465!%+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87DH)W!A<F5N="<@/3X@)'!A<F5N="P@)W!R
M;W1O8V]L)R`]/B`D<')O=&]C;VPI*3L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)&9U;F-T:6]N6R=A='1R:6)S)UU;)W9E<G-I;VXG72D@?'P-"B`@("`@
M("`@("`@("`@("`@("`@("!E;7!T>2@D9G5N8W1I;VY;)V%T=')I8G,G75LG
M=F5R<VEO;B==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W9A
M;&ED871E17)R;W(H4$5!4E]#2$%.3D5,1DE,15]%4E)/4E].3U]&54Y#5$E/
M3E9%4E-)3TXL#0H@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<&%R
M96YT)R`]/B`D<&%R96YT+"`G<')O=&]C;VPG(#T^("1P<F]T;V-O;"DI.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@('T-"@T*("`@("\J*@T*("`@("`J(%1E<W0@=VAE=&AE<B!A('-T<FEN
M9R!C;VYT86EN<R!A('9A;&ED(&-H86YN96P@<V5R=F5R+@T*("`@("`J($!P
M87)A;2!S=')I;F<@)'9E<B!T:&4@<&%C:V%G92!V97)S:6]N('1O('1E<W0-
M"B`@("`@*B!`<F5T=7)N(&)O;VP-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!V
M86QI9$-H86YN96Q397)V97(H)'-E<G9E<BD-"B`@("![#0H@("`@("`@(&EF
M("@D<V5R=F5R(#T]("=?7W5R:2<I('L-"B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`H8F]O;"D@<')E9U]M
M871C:"A014%27T-(04Y.14Q37U-%4E9%4E]04D5'+"`D<V5R=F5R*3L-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<F5T=7)N('-T<FEN9WQF86QS90T*
M("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$YA;64H*0T*("`@('L-"B`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3Y?8VAA;FYE;$EN9F];)VYA;64G72DI('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V-H86YN96Q);F9O6R=N86UE
M)UT[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<F5T
M=7)N('-T<FEN9WQF86QS90T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=%-E
M<G9E<B@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]C:&%N
M;F5L26YF;ULG;F%M92==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?8VAA;FYE;$EN9F];)VYA;64G73L-"B`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@('T-"@T*
M("`@("\J*@T*("`@("`J($!R971U<FX@:6YT?#@P('!O<G0@;G5M8F5R('1O
M(&-O;FYE8W0@=&\-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G9710;W)T*"1M
M:7)R;W(@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@D;6ER<F]R*2![
M#0H@("`@("`@("`@("!I9B`H)&UI<B`]("1T:&ES+3YG971-:7)R;W(H)&UI
M<G)O<BDI('L-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&UI<ELG871T
M<FEB<R==6R=P;W)T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D;6ER6R=A='1R:6)S)UU;)W!O<G0G73L-"B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/F=E=%-3
M3"@D;6ER<F]R*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M(#0T,SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@.#`[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S
M)UU;)W!R:6UA<GDG75LG871T<FEB<R==6R=P;W)T)UTI*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=P
M<FEM87)Y)UU;)V%T=')I8G,G75LG<&]R="==.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("@D=&AI<RT^9V5T4U-,*"DI('L-"B`@("`@("`@("`@(')E='5R
M;B`T-#,[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(#@P.PT*("`@('T-
M"@T*("`@("\J*@T*("`@("`J($!R971U<FX@8F]O;"!$971E<FUI;F5S('=H
M971H97(@<V5C=7)E('-O8VME=',@;&%Y97(@*%-33"D@:7,@=7-E9"!T;R!C
M;VYN96-T('1O('1H:7,@8VAA;FYE;`T*("`@("`J+PT*("`@(&9U;F-T:6]N
M(&=E=%-33"@D;6ER<F]R(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H
M)&UI<G)O<BD@>PT*("`@("`@("`@("`@:68@*"1M:7(@/2`D=&AI<RT^9V5T
M36ER<F]R*"1M:7)R;W(I*2![#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1M:7);)V%T=')I8G,G75LG<W-L)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8VAA
M;FYE;$EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R=A='1R:6)S)UU;)W-S
M;"==*2D@>PT*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@
M("`J($!R971U<FX@<W1R:6YG?&9A;'-E#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@9V5T4W5M;6%R>2@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]C:&%N;F5L26YF;ULG<W5M;6%R>2==*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?8VAA;FYE;$EN9F];)W-U;6UA<GDG73L-"B`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S=')I;F<@
M>&UL<G!C(&]R('-O87`-"B`@("`@*B!`<&%R86T@<W1R:6YG?&9A;'-E(&UI
M<G)O<B!N86UE(&]R(&9A;'-E(&9O<B!P<FEM87)Y('-E<G9E<@T*("`@("`J
M+PT*("`@(&9U;F-T:6]N(&=E=%!A=&@H)'!R;W1O8V]L+"`D;6ER<F]R(#T@
M9F%L<V4I#0H@("`@>R`@(`T*("`@("`@("!I9B`H(6EN7V%R<F%Y*"1P<F]T
M;V-O;"P@87)R87DH)WAM;')P8R<L("=S;V%P)RDI*2![#0H@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1M:7)R
M;W(I('L-"B`@("`@("`@("`@(&EF("@A*"1M:7(@/2`D=&AI<RT^9V5T36ER
M<F]R*"1M:7)R;W(I*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B!F86QS
M93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D;6ER
M6R1P<F]T;V-O;%U;)V%T=')I8G,G75LG<&%T:"==*2D@>PT*("`@("`@("`@
M("`@("`@(')E='5R;B`D;6ER6R1P<F]T;V-O;%U;)V%T=')I8G,G75LG<&%T
M:"==.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!R
M971U<FX@)'!R;W1O8V]L("X@)RYP:'`G.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!](&5L<V5I9B`H:7-S970H)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R
M=F5R<R==6R=P<FEM87)Y)UU;)'!R;W1O8V]L75LG871T<FEB<R==6R=P871H
M)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]C:&%N;F5L26YF
M;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)'!R;W1O8V]L75LG871T<FEB<R==
M6R=P871H)UT[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1P<F]T;V-O
M;"`N("<N<&AP)SL-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@
M<W1R:6YG('!R;W1O8V]L('1Y<&4@*'AM;')P8RP@<V]A<"D-"B`@("`@*B!`
M<&%R86T@<W1R:6YG($UI<G)O<B!N86UE#0H@("`@("H@0')E='5R;B!A<G)A
M>7QF86QS90T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$9U;F-T:6]N<R@D
M<')O=&]C;VPL("1M:7)R;W(@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF
M("@D=&AI<RT^9V5T3F%M92@I(#T]("=?7W5R:2<I('L-"B`@("`@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'!R;W1O
M8V]L(#T]("=R97-T)RD@>PT*("`@("`@("`@("`@)&9U;F-T:6]N(#T@)V)A
M<V5U<FPG.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&9U;F-T
M:6]N(#T@)V9U;F-T:6]N)SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&UI
M<G)O<BD@>PT*("`@("`@("`@("`@:68@*"1M:7(@/2`D=&AI<RT^9V5T36ER
M<F]R*"1M:7)R;W(I*2![#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1M
M:7);)'!R;W1O8V]L75LD9G5N8W1I;VY=*2D@>PT*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)&UI<ELD<')O=&]C;VQ=6R1F=6YC=&EO;ET[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)W!R:6UA<GDG75LD<')O=&]C
M;VQ=6R1F=6YC=&EO;ETI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)'!R;W1O8V]L
M75LD9G5N8W1I;VY=.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@
M("`@("H@0'!A<F%M('-T<FEN9R!0<F]T;V-O;"!T>7!E#0H@("`@("H@0'!A
M<F%M('-T<FEN9R!&=6YC=&EO;B!N86UE("AN=6QL('1O(')E='5R;B!T:&4-
M"B`@("`@*B`@("`@("`@("`@("`@(&9I<G-T('!R;W1O8V]L(&]F('1H92!T
M>7!E(')E<75E<W1E9"D-"B`@("`@*B!`<&%R86T@<W1R:6YG($UI<G)O<B!N
M86UE+"!I9B!A;GD-"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@("`@("HO#0H@
M("`@(&9U;F-T:6]N(&=E=$9U;F-T:6]N*"1T>7!E+"`D;F%M92`](&YU;&PL
M("1M:7)R;W(@/2!F86QS92D-"B`@("`@>PT*("`@("`@("`D<')O=&]C;VQS
M(#T@)'1H:7,M/F=E=$9U;F-T:6]N<R@D='EP92P@)&UI<G)O<BD[#0H@("`@
M("`@(&EF("@A)'!R;W1O8V]L<RD@>PT*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@("`@("!]#0H@("`@("`@(&9O<F5A8V@@*"1P<F]T;V-O;',@
M87,@)'!R;W1O8V]L*2![#0H@("`@("`@("`@("!I9B`H)&YA;64@/3T](&YU
M;&PI('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'!R;W1O8V]L.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1P<F]T;V-O;%LG7V-O;G1E
M;G0G72`A/2`D;F%M92D@>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N("1P<F]T;V-O;#L-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@('T-"@T*
M("`@("\J*@T*("`@("`J($!P87)A;2!S=')I;F<@<')O=&]C;VP@='EP90T*
M("`@("`J($!P87)A;2!S=')I;F<@<')O=&]C;VP@;F%M90T*("`@("`J($!P
M87)A;2!S=')I;F<@=F5R<VEO;@T*("`@("`J($!P87)A;2!S=')I;F<@;6ER
M<F]R(&YA;64-"B`@("`@*B!`<F5T=7)N(&)O;VQE86X-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!S=7!P;W)T<R@D='EP92P@)&YA;64@/2!N=6QL+"`D;6ER
M<F]R(#T@9F%L<V4L("1V97)S:6]N(#T@)S$N,"<I#0H@("`@>PT*("`@("`@
M("`D<')O=&]C;VQS(#T@)'1H:7,M/F=E=$9U;F-T:6]N<R@D='EP92P@)&UI
M<G)O<BD[#0H@("`@("`@(&EF("@A)'!R;W1O8V]L<RD@>PT*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&9O<F5A8V@@
M*"1P<F]T;V-O;',@87,@)'!R;W1O8V]L*2![#0H@("`@("`@("`@("!I9B`H
M)'!R;W1O8V]L6R=A='1R:6)S)UU;)W9E<G-I;VXG72`A/2`D=F5R<VEO;BD@
M>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@:68@*"1N86UE(#T]/2!N=6QL*2![#0H@("`@("`@("`@
M("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!I9B`H)'!R;W1O8V]L6R=?8V]N=&5N="==("$]("1N86UE*2![#0H@("`@
M("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!R971U<FX@=')U93L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@1&5T97)M:6YE<R!W
M:&5T:&5R(&$@8VAA;FYE;"!S=7!P;W)T<R!297!R97-E;G1A=&EO;F%L(%-T
M871E(%1R86YS9F5R("A215-4*2!P<F]T;V-O;',-"B`@("`@*B!F;W(@<F5T
M<FEE=FEN9R!C:&%N;F5L(&EN9F]R;6%T:6]N#0H@("`@("H@0'!A<F%M('-T
M<FEN9PT*("`@("`J($!R971U<FX@8F]O;`T*("`@("`J+PT*("`@(&9U;F-T
M:6]N('-U<'!O<G1S4D535"@D;6ER<F]R(#T@9F%L<V4I#0H@("`@>PT*("`@
M("`@("!I9B`H)&UI<G)O<B`]/2`D=&AI<RT^7V-H86YN96Q);F9O6R=N86UE
M)UTI('L-"B`@("`@("`@("`@("1M:7)R;W(@/2!F86QS93L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H)&UI<G)O<BD@>PT*("`@("`@("`@("`@:68@*"1M
M:7(@/2`D=&AI<RT^9V5T36ER<F]R*"1M:7)R;W(I*2![#0H@("`@("`@("`@
M("`@("`@<F5T=7)N(&ES<V5T*"1M:7);)W)E<W0G72D[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N(&ES<V5T*"1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E
M<G,G75LG<')I;6%R>2==6R=R97-T)UTI.PT*("`@('T-"@T*("`@("\J*@T*
M("`@("`J($=E="!T:&4@55),('1O(&%C8V5S<R!A(&)A<V4@<F5S;W5R8V4N
M#0H@("`@("H-"B`@("`@*B!(>7!E<FQI;FMS(&EN('1H92!R971U<FYE9"!X
M;6P@=VEL;"!B92!U<V5D('1O(')E=')I979E('1H92!P<F]P97(@:6YF;W)M
M871I;VX-"B`@("`@*B!N965D960N("!4:&ES(&%L;&]W<R!E>'1R96UE(&5X
M=&5N<VEB:6QI='D@86YD(&9L97AI8FEL:71Y(&EN(&EM<&QE;65N=&%T:6]N
M#0H@("`@("H@0'!A<F%M('-T<FEN9R!297-O=7)C92!4>7!E('1O(')E=')I
M979E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T0F%S95523"@D<F5S;W5R
M8V54>7!E+"`D;6ER<F]R(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H
M)&UI<G)O<B`]/2`D=&AI<RT^7V-H86YN96Q);F9O6R=N86UE)UTI('L-"B`@
M("`@("`@("`@("1M:7)R;W(@/2!F86QS93L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H)&UI<G)O<BD@>PT*("`@("`@("`@("`@:68@*"1M:7(@/2`D=&AI
M<RT^9V5T36ER<F]R*"1M:7)R;W(I*2![#0H@("`@("`@("`@("`@("`@)')E
M<W0@/2`D;6ER6R=R97-T)UT[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("1S97)V97(@/2`D;6ER<F]R.PT*("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@)')E<W0@/2`D=&AI<RT^7V-H86YN96Q);F9O6R=S
M97)V97)S)UU;)W!R:6UA<GDG75LG<F5S="==.PT*("`@("`@("`@("`@)'-E
M<G9E<B`]("1T:&ES+3YG971397)V97(H*3L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H(6ES<V5T*"1R97-T6R=B87-E=7)L)UU;,%TI*2![#0H@("`@("`@
M("`@("`D<F5S=%LG8F%S975R;"==(#T@87)R87DH)')E<W1;)V)A<V5U<FPG
M72D[#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H)')E<W1;)V)A<V5U
M<FPG72!A<R`D8F%S975R;"D@>PT*("`@("`@("`@("`@:68@*'-T<G1O;&]W
M97(H)&)A<V5U<FQ;)V%T=')I8G,G75LG='EP92==*2`]/2!S=')T;VQO=V5R
M*"1R97-O=7)C951Y<&4I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1B
M87-E=7)L6R=?8V]N=&5N="==.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!3:6YC92!215-4(&1O97,@;F]T(&EM<&QE;65N="!24$,L('!R;W9I
M9&4@=&AI<R!A<R!A(&QO9VEC86P@=W)A<'!E<B!A<F]U;F0-"B`@("`@*B!R
M97-E=$9U;F-T:6]N<R!F;W(@4D535`T*("`@("`J($!P87)A;2!S=')I;F=\
M9F%L<V4@;6ER<F]R(&YA;64L(&EF(&%N>0T*("`@("`J+PT*("`@(&9U;F-T
M:6]N(')E<V5T4D535"@D;6ER<F]R(#T@9F%L<V4I#0H@("`@>PT*("`@("`@
M("!R971U<FX@)'1H:7,M/G)E<V5T1G5N8W1I;VYS*"=R97-T)RP@)&UI<G)O
M<BD[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@16UP='D@86QL('!R;W1O
M8V]L(&1E9FEN:71I;VYS#0H@("`@("H@0'!A<F%M('-T<FEN9R!P<F]T;V-O
M;"!T>7!E("AX;6QR<&,L('-O87`I#0H@("`@("H@0'!A<F%M('-T<FEN9WQF
M86QS92!M:7)R;W(@;F%M92P@:68@86YY#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@<F5S971&=6YC=&EO;G,H)'1Y<&4L("1M:7)R;W(@/2!F86QS92D-"B`@
M("![#0H@("`@("`@(&EF("@D;6ER<F]R*2![#0H@("`@("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G
M72DI('L-"B`@("`@("`@("`@("`@("`D;6ER<F]R<R`]("1T:&ES+3Y?8VAA
M;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UT[#0H@("`@("`@("`@("`@
M("`@:68@*"%I<W-E="@D;6ER<F]R<ULP72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@)&UI<G)O<G,@/2!A<G)A>2@D;6ER<F]R<RD[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1M:7)R;W)S(&%S
M("1I(#T^("1M:7(I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1M:7);
M)V%T=')I8G,G75LG:&]S="==(#T]("1M:7)R;W(I('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-H86YN96Q);F9O6R=S
M97)V97)S)UU;)VUI<G)O<B==6R1I75LD='EP95TI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@=6YS970H)'1H:7,M/E]C:&%N;F5L26YF;ULG
M<V5R=F5R<R==6R=M:7)R;W(G75LD:5U;)'1Y<&5=*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;B!T<G5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG<')I
M;6%R>2==6R1T>7!E72DI('L-"B`@("`@("`@("`@("`@("!U;G-E="@D=&AI
M<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)W!R:6UA<GDG75LD='EP95TI
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@
M("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!3970@82!C:&%N
M;F5L)W,@<')O=&]C;VQS('1O('1H92!P<F]T;V-O;',@<W5P<&]R=&5D(&)Y
M('!E87)W96(-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S971$969A=6QT4$5!
M4E!R;W1O8V]L<R@D=F5R<VEO;B`]("<Q+C`G+"`D;6ER<F]R(#T@9F%L<V4I
M#0H@("`@>PT*("`@("`@("!S=VET8V@@*"1V97)S:6]N*2![#0H@("`@("`@
M("`@("!C87-E("<Q+C`G(#H-"B`@("`@("`@("`@("`@("`D=&AI<RT^<F5S
M971&=6YC=&EO;G,H)WAM;')P8R<L("1M:7)R;W(I.PT*("`@("`@("`@("`@
M("`@("1T:&ES+3YR97-E=$9U;F-T:6]N<R@G<V]A<"<L("1M:7)R;W(I.PT*
M("`@("`@("`@("`@("`@("1T:&ES+3YR97-E=%)%4U0H)&UI<G)O<BD[#0H@
M("`@("`@("`@("`@("`@)'1H:7,M/F%D9$9U;F-T:6]N*"=X;6QR<&,G+"`G
M,2XP)RP@)VQO9VEN=&5S="<L("1M:7)R;W(I.PT*("`@("`@("`@("`@("`@
M("1T:&ES+3YA9&1&=6YC=&EO;B@G>&UL<G!C)RP@)S$N,"<L("=P86-K86=E
M+FQI<W1,871E<W1296QE87-E<R<L("1M:7)R;W(I.PT*("`@("`@("`@("`@
M("`@("1T:&ES+3YA9&1&=6YC=&EO;B@G>&UL<G!C)RP@)S$N,"<L("=P86-K
M86=E+FQI<W1!;&PG+"`D;6ER<F]R*3L-"B`@("`@("`@("`@("`@("`D=&AI
M<RT^861D1G5N8W1I;VXH)WAM;')P8R<L("<Q+C`G+"`G<&%C:V%G92YI;F9O
M)RP@)&UI<G)O<BD[#0H@("`@("`@("`@("`@("`@)'1H:7,M/F%D9$9U;F-T
M:6]N*"=X;6QR<&,G+"`G,2XP)RP@)W!A8VMA9V4N9V5T1&]W;FQO86154DPG
M+"`D;6ER<F]R*3L-"B`@("`@("`@("`@("`@("`D=&AI<RT^861D1G5N8W1I
M;VXH)WAM;')P8R<L("<Q+C$G+"`G<&%C:V%G92YG971$;W=N;&]A9%523"<L
M("1M:7)R;W(I.PT*("`@("`@("`@("`@("`@("1T:&ES+3YA9&1&=6YC=&EO
M;B@G>&UL<G!C)RP@)S$N,"<L("=P86-K86=E+F=E=$1E<$1O=VYL;V%D55),
M)RP@)&UI<G)O<BD[#0H@("`@("`@("`@("`@("`@)'1H:7,M/F%D9$9U;F-T
M:6]N*"=X;6QR<&,G+"`G,2XQ)RP@)W!A8VMA9V4N9V5T1&5P1&]W;FQO8615
M4DPG+"`D;6ER<F]R*3L-"B`@("`@("`@("`@("`@("`D=&AI<RT^861D1G5N
M8W1I;VXH)WAM;')P8R<L("<Q+C`G+"`G<&%C:V%G92YS96%R8V@G+"`D;6ER
M<F]R*3L-"B`@("`@("`@("`@("`@("`D=&AI<RT^861D1G5N8W1I;VXH)WAM
M;')P8R<L("<Q+C`G+"`G8VAA;FYE;"YL:7-T06QL)RP@)&UI<G)O<BD[#0H@
M("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("!B<F5A
M:SL-"B`@("`@("`@("`@(&1E9F%U;'0@.@T*("`@("`@("`@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("!]#0H@
M("`@?0T*("`@(`T*("`@("\J*@T*("`@("`J($!R971U<FX@87)R87D-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!G971-:7)R;W)S*"D-"B`@("![#0H@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;
M)VUI<G)O<B==*2D@>PT*("`@("`@("`@("`@)&UI<G)O<G,@/2`D=&AI<RT^
M7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==.PT*("`@("`@("`@
M("`@:68@*"%I<W-E="@D;6ER<F]R<ULP72DI('L-"B`@("`@("`@("`@("`@
M("`D;6ER<F]R<R`](&%R<F%Y*"1M:7)R;W)S*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(')E='5R;B`D;6ER<F]R<SL-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@(')E='5R;B!A<G)A>2@I.PT*("`@("`@("!]#0H@
M("`@?0T*#0H@("`@+RHJ#0H@("`@("H@1V5T('1H92!U;G-E<FEA;&EZ960@
M6$U,(')E<')E<V5N=&EN9R!A(&UI<G)O<@T*("`@("`J($!R971U<FX@87)R
M87E\9F%L<V4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971-:7)R;W(H)'-E
M<G9E<BD-"B`@("![#0H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YG971-:7)R
M;W)S*"D@87,@)&UI<G)O<BD@>PT*("`@("`@("`@("`@:68@*"1M:7)R;W);
M)V%T=')I8G,G75LG:&]S="==(#T]("1S97)V97(I('L-"B`@("`@("`@("`@
M("`@("!R971U<FX@)&UI<G)O<CL-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@
M("`@("H@0'!A<F%M('-T<FEN9PT*("`@("`J($!R971U<FX@<W1R:6YG?&9A
M;'-E#0H@("`@("H@0&5R<F]R(%!%05)?0TA!3DY%3$9)3$5?15)23U)?3D]?
M3D%-10T*("`@("`J($!E<G)O<B!014%27T-(04Y.14Q&24Q%7T524D]27TE.
M5D%,241?3D%-10T*("`@("`J+PT*("`@(&9U;F-T:6]N('-E=$YA;64H)&YA
M;64I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/G-E=%-E<G9E<B@D
M;F%M92D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4V5T('1H92!S;V-K
M970@;G5M8F5R("AP;W)T*2!T:&%T(&ES('5S960@=&\@8V]N;F5C="!T;R!T
M:&ES(&-H86YN96P-"B`@("`@*B!`<&%R86T@:6YT96=E<@T*("`@("`J($!P
M87)A;2!S=')I;F=\9F%L<V4@;F%M92!O9B!T:&4@;6ER<F]R('-E<G9E<BP@
M;W(@9F%L<V4@9F]R('1H92!P<FEM87)Y#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@<V5T4&]R="@D<&]R="P@)&UI<G)O<B`](&9A;'-E*0T*("`@('L-"B`@
M("`@("`@:68@*"1M:7)R;W(I('L-"B`@("`@("`@("`@(&EF("@A:7-S970H
M)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G72DI('L-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]#
M2$%.3D5,1DE,15]%4E)/4E]-25)23U)?3D]47T9/54Y$+`T*("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@G;6ER<F]R)R`]/B`D;6ER<F]R*2D[#0H@("`@
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@)'-E=&UI<G)O<B`](&9A;'-E.PT*("`@("`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R
M)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]C
M:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G72!A<R`D:2`]/B`D;6ER
M*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@D;6ER<F]R(#T]("1M:7);
M)V%T=')I8G,G75LG:&]S="==*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==6R1I
M75LG871T<FEB<R==6R=P;W)T)UT@/2`D<&]R=#L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(')E='5R;B!F
M86QS93L-"B`@("`@("`@("`@('T@96QS96EF("@D=&AI<RT^7V-H86YN96Q)
M;F9O6R=S97)V97)S)UU;)VUI<G)O<B==6R=A='1R:6)S)UU;)VAO<W0G72`]
M/2`D;6ER<F]R*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]C:&%N;F5L
M26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G75LG871T<FEB<R==6R=P;W)T)UT@
M/2`D<&]R=#L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7VES5F%L:60@/2!F
M86QS93L-"B`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7V-H86YN96Q);F9O
M6R=S97)V97)S)UU;)W!R:6UA<GDG75LG871T<FEB<R==6R=P;W)T)UT@/2`D
M<&]R=#L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@9F%L<V4[#0H@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%-E
M="!T:&4@<V]C:V5T(&YU;6)E<B`H<&]R="D@=&AA="!I<R!U<V5D('1O(&-O
M;FYE8W0@=&\@=&AI<R!C:&%N;F5L#0H@("`@("H@0'!A<F%M(&)O;VP@1&5T
M97)M:6YE<R!W:&5T:&5R('1O('1U<FX@;VX@4U-,('-U<'!O<G0@;W(@='5R
M;B!I="!O9F8-"B`@("`@*B!`<&%R86T@<W1R:6YG?&9A;'-E(&YA;64@;V8@
M=&AE(&UI<G)O<B!S97)V97(L(&]R(&9A;'-E(&9O<B!T:&4@<')I;6%R>0T*
M("`@("`J+PT*("`@(&9U;F-T:6]N('-E=%-33"@D<W-L(#T@=')U92P@)&UI
M<G)O<B`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*"1M:7)R;W(I('L-
M"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]C:&%N;F5L26YF;ULG
M<V5R=F5R<R==6R=M:7)R;W(G72DI('L-"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7W9A;&ED871E17)R;W(H4$5!4E]#2$%.3D5,1DE,15]%4E)/4E]-25)2
M3U)?3D]47T9/54Y$+`T*("`@("`@("`@("`@("`@("`@("!A<G)A>2@G;6ER
M<F]R)R`]/B`D;6ER<F]R*2D[#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'-E=&UI<G)O<B`]
M(&9A;'-E.PT*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8VAA;FYE
M;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UU;,%TI*2![#0H@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==
M6R=M:7)R;W(G72!A<R`D:2`]/B`D;6ER*2![#0H@("`@("`@("`@("`@("`@
M("`@(&EF("@D;6ER<F]R(#T]("1M:7);)V%T=')I8G,G75LG:&]S="==*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(21S<VPI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]C:&%N
M;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G75LD:5T-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!;)V%T=')I8G,G75LG<W-L)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES
M+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UU;)&E=6R=A='1R
M:6)S)UU;)W-S;"==*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E
M<G,G75LG;6ER<F]R)UU;)&E=6R=A='1R:6)S)UU;)W-S;"==(#T@)WEE<R<[
M#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@("`@("`@("!](&5L<V5I9B`H)'1H:7,M/E]C:&%N;F5L26YF
M;ULG<V5R=F5R<R==6R=M:7)R;W(G75LG871T<FEB<R==6R=H;W-T)UT@/3T@
M)&UI<G)O<BD@>PT*("`@("`@("`@("`@("`@(&EF("@A)'-S;"D@>PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]C:&%N;F5L26YF
M;ULG<V5R=F5R<R==6R=M:7)R;W(G75LG871T<FEB<R==6R=S<VPG72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?8VAA;FYE
M;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UU;)V%T=')I8G,G75LG<W-L)UTI
M.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C:&%N;F5L26YF
M;ULG<V5R=F5R<R==6R=M:7)R;W(G75LG871T<FEB<R==6R=S<VPG72`]("=Y
M97,G.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7VES5F%L:60@/2!F86QS93L-"B`@("`@("`@("`@("`@("!R971U<FX@
M=')U93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M)'-S;"D@>PT*("`@("`@("`@("`@)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R
M=F5R<R==6R=P<FEM87)Y)UU;)V%T=')I8G,G75LG<W-L)UT@/2`G>65S)SL-
M"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)W!R:6UA<GDG75LG871T<FEB
M<R==6R=S<VPG72DI('L-"B`@("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^
M7V-H86YN96Q);F9O6R=S97)V97)S)UU;)W!R:6UA<GDG75LG871T<FEB<R==
M6R=S<VPG72D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M)'1H:7,M/E]I<U9A;&ED(#T@9F%L<V4[#0H@("`@("`@(')E='5R;B!T<G5E
M.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%-E="!T:&4@<V]C:V5T(&YU
M;6)E<B`H<&]R="D@=&AA="!I<R!U<V5D('1O(&-O;FYE8W0@=&\@=&AI<R!C
M:&%N;F5L#0H@("`@("H@0'!A<F%M(&EN=&5G97(-"B`@("`@*B!`<&%R86T@
M<W1R:6YG?&9A;'-E(&YA;64@;V8@=&AE(&UI<G)O<B!S97)V97(L(&]R(&9A
M;'-E(&9O<B!T:&4@<')I;6%R>0T*("`@("`J+PT*("`@(&9U;F-T:6]N('-E
M=%!A=&@H)'!R;W1O8V]L+"`D<&%T:"P@)&UI<G)O<B`](&9A;'-E*0T*("`@
M('L-"B`@("`@("`@:68@*"%I;E]A<G)A>2@D<')O=&]C;VPL(&%R<F%Y*"=X
M;6QR<&,G+"`G<V]A<"<I*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D;6ER<F]R*2![#0H@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G
M75LG;6ER<F]R)UTI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI
M9&%T945R<F]R*%!%05)?0TA!3DY%3$9)3$5?15)23U)?34E24D]27TY/5%]&
M3U5.1"P-"B`@("`@("`@("`@("`@("`@("`@87)R87DH)VUI<G)O<B<@/3X@
M)&UI<G)O<BDI.PT*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("1S971M:7)R;W(@/2!F86QS93L-
M"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-H86YN96Q);F9O6R=S
M97)V97)S)UU;)VUI<G)O<B==6S!=*2D@>PT*("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*"1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R
M)UT@87,@)&D@/3X@)&UI<BD@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H
M)&UI<G)O<B`]/2`D;6ER6R=A='1R:6)S)UU;)VAO<W0G72D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R
M<R==6R=M:7)R;W(G75LD:5U;)'!R;W1O8V]L75LG871T<FEB<R==6R=P871H
M)UT@/0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P871H.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?0TA!3DY%3$9)3$5?15)2
M3U)?34E24D]27TY/5%]&3U5.1"P-"B`@("`@("`@("`@("`@("`@("`@87)R
M87DH)VUI<G)O<B<@/3X@)&UI<G)O<BDI.PT*("`@("`@("`@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("`@("`@("`@('T@96QS96EF("@D=&AI<RT^7V-H
M86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==6R=A='1R:6)S)UU;)VAO
M<W0G72`]/2`D;6ER<F]R*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]C
M:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G75LD<')O=&]C;VQ=6R=A
M='1R:6)S)UU;)W!A=&@G72`]("1P871H.PT*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?:7-686QI9"`](&9A;'-E.PT*("`@("`@("`@("`@("`@(')E='5R
M;B!T<G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1T
M:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R1P<F]T
M;V-O;%U;)V%T=')I8G,G75LG<&%T:"==(#T@)'!A=&@[#0H@("`@("`@("1T
M:&ES+3Y?:7-686QI9"`](&9A;'-E.PT*("`@("`@("!R971U<FX@=')U93L-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W1R:6YG#0H@("`@
M("H@0')E='5R;B!S=')I;F=\9F%L<V4-"B`@("`@*B!`97)R;W(@4$5!4E]#
M2$%.3D5,1DE,15]%4E)/4E].3U]315)615(-"B`@("`@*B!`97)R;W(@4$5!
M4E]#2$%.3D5,1DE,15]%4E)/4E])3E9!3$E$7U-%4E9%4@T*("`@("`J+PT*
M("`@(&9U;F-T:6]N('-E=%-E<G9E<B@D<V5R=F5R+"`D;6ER<F]R(#T@9F%L
M<V4I#0H@("`@>PT*("`@("`@("!I9B`H96UP='DH)'-E<G9E<BDI('L-"B`@
M("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27T-(04Y.14Q&
M24Q%7T524D]27TY/7U-%4E9%4BD[#0H@("`@("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@("`@('T@96QS96EF("@A)'1H:7,M/G9A;&ED0VAA;FYE;%-E
M<G9E<B@D<V5R=F5R*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T
M945R<F]R*%!%05)?0TA!3DY%3$9)3$5?15)23U)?24Y604Q)1%].04U%+`T*
M("`@("`@("`@("`@("`@(&%R<F%Y*"=T86<G(#T^("=N86UE)RP@)VYA;64G
M(#T^("1S97)V97(I*3L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H)&UI<G)O<BD@>PT*("`@("`@("`@("`@
M)&9O=6YD(#T@9F%L<V4[#0H@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^
M7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==(&%S("1I(#T^("1M
M:7(I('L-"B`@("`@("`@("`@("`@("!I9B`H)&UI<G)O<B`]/2`D;6ER6R=A
M='1R:6)S)UU;)VAO<W0G72D@>PT*("`@("`@("`@("`@("`@("`@("`D9F]U
M;F0@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H
M(21F;W5N9"D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%
M<G)O<BA014%27T-(04Y.14Q&24Q%7T524D]27TU)4E)/4E].3U1?1D]53D0L
M#0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=M:7)R;W(G(#T^("1M:7)R
M;W(I*3L-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`D=&AI<RT^7V-H86YN96Q);F9O6R=M:7)R
M;W(G75LD:5U;)V%T=')I8G,G75LG:&]S="==(#T@)'-E<G9E<CL-"B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES
M+3Y?8VAA;FYE;$EN9F];)VYA;64G72`]("1S97)V97([#0H@("`@("`@(')E
M='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S
M=')I;F<-"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@<W5C8V5S<PT*("`@("`J
M($!E<G)O<B!014%27T-(04Y.14Q&24Q%7T524D]27TY/7U-534U!4ED-"B`@
M("`@*B!`=V%R;FEN9R!014%27T-(04Y.14Q&24Q%7T524D]27TU53%1)3$E.
M15]354U-05)9#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T4W5M;6%R>2@D
M<W5M;6%R>2D-"B`@("![#0H@("`@("`@(&EF("AE;7!T>2@D<W5M;6%R>2DI
M('L-"B`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27T-(
M04Y.14Q&24Q%7T524D]27TY/7U-534U!4EDI.PT*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@("`@("!](&5L<V5I9B`H<W1R<&]S*'1R:6TH)'-U
M;6UA<GDI+"`B7&XB*2`A/3T@9F%L<V4I('L-"B`@("`@("`@("`@("1T:&ES
M+3Y?=F%L:61A=&5787)N:6YG*%!%05)?0TA!3DY%3$9)3$5?15)23U)?355,
M5$E,24Y%7U-534U!4EDL#0H@("`@("`@("`@("`@("`@87)R87DH)W-U;6UA
M<GDG(#T^("1S=6UM87)Y*2D[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M
M/E]C:&%N;F5L26YF;ULG<W5M;6%R>2==(#T@)'-U;6UA<GD[#0H@("`@("`@
M(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A
M;2!S=')I;F<-"B`@("`@*B!`<&%R86T@8F]O;&5A;B!D971E<FUI;F5S('=H
M971H97(@=&AE(&%L:6%S(&ES(&EN(&-H86YN96PN>&UL(&]R(&QO8V%L#0H@
M("`@("H@0')E='5R;B!B;V]L96%N('-U8V-E<W,-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!S971!;&EA<R@D86QI87,L("1L;V-A;"`](&9A;'-E*0T*("`@
M('L-"B`@("`@("`@:68@*"$D=&AI<RT^=F%L:61#:&%N;F5L4V5R=F5R*"1A
M;&EA<RDI('L-"B`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA0
M14%27T-(04Y.14Q&24Q%7T524D]27TE.5D%,241?3D%-12P-"B`@("`@("`@
M("`@("`@("!A<G)A>2@G=&%G)R`]/B`G<W5G9V5S=&5D86QI87,G+"`G;F%M
M92<@/3X@)&%L:6%S*2D[#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"1L;V-A;"D@>PT*("`@("`@("`@("`@
M)'1H:7,M/E]C:&%N;F5L26YF;ULG;&]C86QA;&EA<R==(#T@)&%L:6%S.PT*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'1H:7,M/E]C:&%N;F5L
M26YF;ULG<W5G9V5S=&5D86QI87,G72`]("1A;&EA<SL-"B`@("`@("`@?0T*
M("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!`<F5T=7)N('-T<FEN9PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$%L
M:6%S*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-H86YN
M96Q);F9O6R=L;V-A;&%L:6%S)UTI*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/E]C:&%N;F5L26YF;ULG;&]C86QA;&EA<R==.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-H86YN96Q);F9O6R=S=6=G
M97-T961A;&EA<R==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M8VAA;FYE;$EN9F];)W-U9V=E<W1E9&%L:6%S)UT[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8VAA;FYE;$EN9F];)VYA;64G72DI
M('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V-H86YN96Q);F9O6R=N
M86UE)UT[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!3
M970@=&AE('!A8VMA9V4@=F%L:61A=&EO;B!O8FIE8W0@:68@:70@9&EF9F5R
M<R!F<F]M(%!%05(G<R!D969A=6QT#0H@("`@("H@5&AE(&-L87-S(&UU<W0@
M8F4@:6YC;'5D96%B;&4@=FEA(&-H86YG:6YG(%\@:6X@=&AE(&-L87-S;F%M
M92!T;R!P871H('-E<&%R871O<BP-"B`@("`@*B!B=70@;F\@8VAE8VMI;F<@
M;V8@=&AI<R!I<R!M861E+@T*("`@("`J($!P87)A;2!S=')I;F=\9F%L<V4@
M<&%S<R!I;B!F86QS92!T;R!R97-E="!T;R!T:&4@9&5F875L="!P86-K86=E
M;F%M92!R96=E>`T*("`@("`J($!R971U<FX@8F]O;&5A;B!S=6-C97-S#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@<V5T5F%L:61A=&EO;E!A8VMA9V4H)'9A
M;&ED871E8VQA<W,L("1V97)S:6]N*0T*("`@('L-"B`@("`@("`@:68@*&5M
M<'1Y*"1V86QI9&%T96-L87-S*2D@>PT*("`@("`@("`@("`@=6YS970H)'1H
M:7,M/E]C:&%N;F5L26YF;ULG=F%L:61A=&5P86-K86=E)UTI.PT*("`@("`@
M("!]#0H@("`@("`@("1T:&ES+3Y?8VAA;FYE;$EN9F];)W9A;&ED871E<&%C
M:V%G92==(#T@87)R87DH)U]C;VYT96YT)R`]/B`D=F%L:61A=&5C;&%S<RD[
M#0H@("`@("`@("1T:&ES+3Y?8VAA;FYE;$EN9F];)W9A;&ED871E<&%C:V%G
M92==6R=A='1R:6)S)UT@/2!A<G)A>2@G=F5R<VEO;B<@/3X@)'9E<G-I;VXI
M.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($%D9"!A('!R;W1O8V]L('1O
M('1H92!P<F]V:61E<R!S96-T:6]N#0H@("`@("H@0'!A<F%M('-T<FEN9R!P
M<F]T;V-O;"!T>7!E#0H@("`@("H@0'!A<F%M('-T<FEN9R!P<F]T;V-O;"!V
M97)S:6]N#0H@("`@("H@0'!A<F%M('-T<FEN9R!P<F]T;V-O;"!N86UE+"!I
M9B!A;GD-"B`@("`@*B!`<&%R86T@<W1R:6YG(&UI<G)O<B!N86UE+"!I9B!T
M:&ES(&ES(&$@;6ER<F]R)W,@<')O=&]C;VP-"B`@("`@*B!`<F5T=7)N(&)O
M;VP-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!A9&1&=6YC=&EO;B@D='EP92P@
M)'9E<G-I;VXL("1N86UE(#T@)R<L("1M:7)R;W(@/2!F86QS92D-"B`@("![
M#0H@("`@("`@(&EF("@D;6ER<F]R*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/F%D9$UI<G)O<D9U;F-T:6]N*"1M:7)R;W(L("1T>7!E+"`D=F5R
M<VEO;BP@)&YA;64I.PT*("`@("`@("!]#0H@("`@("`@("1S970@/2!A<G)A
M>2@G871T<FEB<R<@/3X@87)R87DH)W9E<G-I;VXG(#T^("1V97)S:6]N*2P@
M)U]C;VYT96YT)R`]/B`D;F%M92D[#0H@("`@("`@(&EF("@A:7-S970H)'1H
M:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)'1Y<&5=
M6R=F=6YC=&EO;B==*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]C:&%N;F5L
M26YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)'1Y<&5=6R=F=6YC=&EO;B==
M(#T@)'-E=#L-"B`@("`@("`@("`@("1T:&ES+3Y?:7-686QI9"`](&9A;'-E
M.PT*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T@96QS96EF
M("@A:7-S970H)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=P<FEM
M87)Y)UU;)'1Y<&5=6R=F=6YC=&EO;B==6S!=*2D@>PT*("`@("`@("`@("`@
M)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)'1Y
M<&5=6R=F=6YC=&EO;B==(#T@87)R87DH#0H@("`@("`@("`@("`@("`@)'1H
M:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)'1Y<&5=
M6R=F=6YC=&EO;B==*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7V-H
M86YN96Q);F9O6R=S97)V97)S)UU;)W!R:6UA<GDG75LD='EP95U;)V9U;F-T
M:6]N)UU;72`]("1S970[#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-
M"B`@("`O*BH-"B`@("`@*B!!9&0@82!P<F]T;V-O;"!T;R!A(&UI<G)O<B=S
M('!R;W9I9&5S('-E8W1I;VX-"B`@("`@*B!`<&%R86T@<W1R:6YG(&UI<G)O
M<B!N86UE("AS97)V97(I#0H@("`@("H@0'!A<F%M('-T<FEN9R!P<F]T;V-O
M;"!T>7!E#0H@("`@("H@0'!A<F%M('-T<FEN9R!P<F]T;V-O;"!V97)S:6]N
M#0H@("`@("H@0'!A<F%M('-T<FEN9R!P<F]T;V-O;"!N86UE+"!I9B!A;GD-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!A9&1-:7)R;W)&=6YC=&EO;B@D;6ER
M<F]R+"`D='EP92P@)'9E<G-I;VXL("1N86UE(#T@)R<I#0H@("`@>PT*("`@
M("`@("`D9F]U;F0@/2!F86QS93L-"B`@("`@("`@:68@*"%I<W-E="@D=&AI
M<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==*2D@>PT*("`@
M("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?0TA!3DY%3$9)
M3$5?15)23U)?34E24D]27TY/5%]&3U5.1"P-"B`@("`@("`@("`@("`@("!A
M<G)A>2@G;6ER<F]R)R`]/B`D;6ER<F]R*2D[#0H@("`@("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)'-E=&UI<G)O<B`](&9A
M;'-E.PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]C:&%N;F5L26YF;ULG
M<V5R=F5R<R==6R=M:7)R;W(G75LP72DI('L-"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UT@
M87,@)&D@/3X@)&UI<BD@>PT*("`@("`@("`@("`@("`@(&EF("@D;6ER<F]R
M(#T]("1M:7);)V%T=')I8G,G75LG:&]S="==*2![#0H@("`@("`@("`@("`@
M("`@("`@("1S971M:7)R;W(@/2`F)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R
M=F5R<R==6R=M:7)R;W(G75LD:5T[#0H@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@(&EF("@D=&AI<RT^7V-H86YN96Q)
M;F9O6R=S97)V97)S)UU;)VUI<G)O<B==6R=A='1R:6)S)UU;)VAO<W0G72`]
M/2`D;6ER<F]R*2![#0H@("`@("`@("`@("`@("`@)'-E=&UI<G)O<B`]("8D
M=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==.PT*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@A)'-E=&UI<G)O
M<BD@>PT*("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?
M0TA!3DY%3$9)3$5?15)23U)?34E24D]27TY/5%]&3U5.1"P-"B`@("`@("`@
M("`@("`@("!A<G)A>2@G;6ER<F]R)R`]/B`D;6ER<F]R*2D[#0H@("`@("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)'-E="`]
M(&%R<F%Y*"=A='1R:6)S)R`]/B!A<G)A>2@G=F5R<VEO;B<@/3X@)'9E<G-I
M;VXI+"`G7V-O;G1E;G0G(#T^("1N86UE*3L-"B`@("`@("`@:68@*"%I<W-E
M="@D<V5T;6ER<F]R6R1T>7!E75LG9G5N8W1I;VXG72DI('L-"B`@("`@("`@
M("`@("1S971M:7)R;W);)'1Y<&5=6R=F=6YC=&EO;B==(#T@)'-E=#L-"B`@
M("`@("`@("`@("1T:&ES+3Y?:7-686QI9"`](&9A;'-E.PT*("`@("`@("`@
M("`@<F5T=7)N('1R=64[#0H@("`@("`@('T@96QS96EF("@A:7-S970H)'-E
M=&UI<G)O<ELD='EP95U;)V9U;F-T:6]N)UU;,%TI*2![#0H@("`@("`@("`@
M("`D<V5T;6ER<F]R6R1T>7!E75LG9G5N8W1I;VXG72`](&%R<F%Y*"1S971M
M:7)R;W);)'1Y<&5=6R=F=6YC=&EO;B==*3L-"B`@("`@("`@?0T*("`@("`@
M("`D<V5T;6ER<F]R6R1T>7!E75LG9G5N8W1I;VXG75M=(#T@)'-E=#L-"B`@
M("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@9F%L<V4[#0H@("`@("`@(')E='5R
M;B!T<G5E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S=')I
M;F<@4F5S;W5R8V4@5'EP92!T:&ES('5R;"!L:6YK<R!T;PT*("`@("`J($!P
M87)A;2!S=')I;F<@55),#0H@("`@("H@0'!A<F%M('-T<FEN9WQF86QS92!M
M:7)R;W(@;F%M92P@:68@=&AI<R!I<R!N;W0@82!P<FEM87)Y('-E<G9E<B!2
M15-4(&)A<V4@55),#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T0F%S9552
M3"@D<F5S;W5R8V54>7!E+"`D=7)L+"`D;6ER<F]R(#T@9F%L<V4I#0H@("`@
M>PT*("`@("`@("!I9B`H)&UI<G)O<BD@>PT*("`@("`@("`@("`@)&9O=6YD
M(#T@9F%L<V4[#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?8VAA
M;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UTI*2![#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?0TA!3DY%3$9)3$5?
M15)23U)?34E24D]27TY/5%]&3U5.1"P-"B`@("`@("`@("`@("`@("`@("`@
M87)R87DH)VUI<G)O<B<@/3X@)&UI<G)O<BDI.PT*("`@("`@("`@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1S
M971M:7)R;W(@/2!F86QS93L-"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==6S!=*2D@>PT*
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?8VAA;FYE;$EN9F];
M)W-E<G9E<G,G75LG;6ER<F]R)UT@87,@)&D@/3X@)&UI<BD@>PT*("`@("`@
M("`@("`@("`@("`@("!I9B`H)&UI<G)O<B`]/2`D;6ER6R=A='1R:6)S)UU;
M)VAO<W0G72D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'-E=&UI<G)O
M<B`]("8D=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==
M6R1I73L-"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]C:&%N
M;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G75LG871T<FEB<R==6R=H;W-T
M)UT@/3T@)&UI<G)O<BD@>PT*("`@("`@("`@("`@("`@("`@("`D<V5T;6ER
M<F]R(#T@)B1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R
M)UT[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@)'-E=&UI<G)O<B`]("8D=&AI<RT^
M7V-H86YN96Q);F9O6R=S97)V97)S)UU;)W!R:6UA<GDG73L-"B`@("`@("`@
M?0T*("`@("`@("`D<V5T(#T@87)R87DH)V%T=')I8G,G(#T^(&%R<F%Y*"=T
M>7!E)R`]/B`D<F5S;W5R8V54>7!E*2P@)U]C;VYT96YT)R`]/B`D=7)L*3L-
M"B`@("`@("`@:68@*"%I<W-E="@D<V5T;6ER<F]R6R=R97-T)UU;)V)A<V5U
M<FPG72DI('L-"B`@("`@("`@("`@("1S971M:7)R;W);)W)E<W0G75LG8F%S
M975R;"==(#T@)'-E=#L-"B`@("`@("`@("`@("1T:&ES+3Y?:7-686QI9"`]
M(&9A;'-E.PT*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T@
M96QS96EF("@A:7-S970H)'-E=&UI<G)O<ELG<F5S="==6R=B87-E=7)L)UU;
M,%TI*2![#0H@("`@("`@("`@("`D<V5T;6ER<F]R6R=R97-T)UU;)V)A<V5U
M<FPG72`](&%R<F%Y*"1S971M:7)R;W);)W)E<W0G75LG8F%S975R;"==*3L-
M"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D<V5T;6ER<F]R6R=R97-T
M)UU;)V)A<V5U<FPG72!A<R`D:2`]/B`D=7)L*2![#0H@("`@("`@("`@("!I
M9B`H)'5R;%LG871T<FEB<R==6R=T>7!E)UT@/3T@)')E<V]U<F-E5'EP92D@
M>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?:7-686QI9"`](&9A;'-E.PT*
M("`@("`@("`@("`@("`@("1S971M:7)R;W);)W)E<W0G75LG8F%S975R;"==
M6R1I72`]("1S970[#0H@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)'-E=&UI<G)O<ELG
M<F5S="==6R=B87-E=7)L)UU;72`]("1S970[#0H@("`@("`@("1T:&ES+3Y?
M:7-686QI9"`](&9A;'-E.PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W1R:6YG(&UI<G)O<B!S97)V
M97(-"B`@("`@*B!`<&%R86T@:6YT(&UI<G)O<B!H='1P('!O<G0-"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86X-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!A9&1-
M:7)R;W(H)'-E<G9E<BP@)'!O<G0@/2!N=6QL*0T*("`@('L-"B`@("`@("`@
M:68@*"1T:&ES+3Y?8VAA;FYE;$EN9F];)VYA;64G72`]/2`G7U]U<FDG*2![
M#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[("\O('1H92!?7W5R:2!C:&%N
M;F5L(&-A;FYO="!H879E(&UI<G)O<G,@8GD@9&5F:6YI=&EO;@T*("`@("`@
M("!]#0H@("`@("`@("1S970@/2!A<G)A>2@G871T<FEB<R<@/3X@87)R87DH
M)VAO<W0G(#T^("1S97)V97(I*3L-"B`@("`@("`@:68@*&ES7VYU;65R:6,H
M)'!O<G0I*2![#0H@("`@("`@("`@("`D<V5T6R=A='1R:6)S)UU;)W!O<G0G
M72`]("1P;W)T.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)'1H
M:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G72DI('L-"B`@
M("`@("`@("`@("1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER
M<F]R)UT@/2`D<V5T.PT*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?
M8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UU;,%TI*2![#0H@("`@
M("`@("`@("`@("`@)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M
M:7)R;W(G72`]#0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1T:&ES+3Y?
M8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UTI.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?8VAA;FYE;$EN9F];
M)W-E<G9E<G,G75LG;6ER<F]R)UU;72`]("1S970[#0H@("`@("`@(')E='5R
M;B!T<G5E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%)E=')I979E('1H
M92!N86UE(&]F('1H92!V86QI9&%T:6]N('!A8VMA9V4@9F]R('1H:7,@8VAA
M;FYE;`T*("`@("`J($!R971U<FX@<W1R:6YG?&9A;'-E#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@9V5T5F%L:61A=&EO;E!A8VMA9V4H*0T*("`@('L-"B`@
M("`@("`@:68@*"$D=&AI<RT^7VES5F%L:60@)B8@(21T:&ES+3YV86QI9&%T
M92@I*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V-H86YN96Q);F9O6R=V86QI
M9&%T97!A8VMA9V4G72DI('L-"B`@("`@("`@("`@(')E='5R;B!A<G)A>2@G
M871T<FEB<R<@/3X@87)R87DH)W9E<G-I;VXG(#T^("=D969A=6QT)RDL#0H@
M("`@("`@("`@("`@("`@)U]C;VYT96YT)R`]/B`G4$5!4E]686QI9&%T92<I
M.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D=&AI<RT^7V-H86YN96Q)
M;F9O6R=V86QI9&%T97!A8VMA9V4G73L-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!2971R:65V92!T:&4@;V)J96-T('1H870@8V%N(&)E('5S960@9F]R
M(&-U<W1O;2!V86QI9&%T:6]N#0H@("`@("H@0'!A<F%M('-T<FEN9WQF86QS
M92!T:&4@;F%M92!O9B!T:&4@<&%C:V%G92!T;R!V86QI9&%T92X@($EF('1H
M92!P86-K86=E(&ES#0H@("`@("H@("`@("`@("`@("`@("`@("`@("!T:&4@
M8VAA;FYE;"!V86QI9&%T:6]N('!A8VMA9V4L(%!%05)?5F%L:61A=&4@:7,@
M<F5T=7)N960-"B`@("`@*B!`<F5T=7)N(%!%05)?5F%L:61A=&5\9F%L<V4@
M9F%L<V4@:7,@<F5T=7)N960@:68@=&AE('9A;&ED871I;VX@<&%C:V%G90T*
M("`@("`J("`@("`@("`@8V%N;F]T(&)E(&QO8V%T960-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B`F9V5T5F%L:61A=&EO;D]B:F5C="@D<&%C:V%G92`](&9A
M;'-E*0T*("`@('L-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?
M5F%L:61A=&4G*2D@>PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2
M+U9A;&ED871E+G!H<"<[#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D=&AI
M<RT^7VES5F%L:60I('L-"B`@("`@("`@("`@(&EF("@A)'1H:7,M/G9A;&ED
M871E*"DI('L-"B`@("`@("`@("`@("`@("`D82`](&9A;'-E.PT*("`@("`@
M("`@("`@("`@(')E='5R;B`D83L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]C:&%N;F5L26YF;ULG=F%L
M:61A=&5P86-K86=E)UTI*2![#0H@("`@("`@("`@("!I9B`H)'!A8VMA9V4@
M/3T@)'1H:7,M/E]C:&%N;F5L26YF;ULG=F%L:61A=&5P86-K86=E)UTI('L-
M"B`@("`@("`@("`@("`@("`O+R!C:&%N;F5L('9A;&ED871I;VX@<&%C:V%G
M97,@87)E(&%L=V%Y<R!V86QI9&%T960@8GD@4$5!4E]686QI9&%T90T*("`@
M("`@("`@("`@("`@("1V86P@/2`F;F5W(%!%05)?5F%L:61A=&4[#0H@("`@
M("`@("`@("`@("`@<F5T=7)N("1V86P[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!I9B`H(6-L87-S7V5X:7-T<RAS=')?<F5P;&%C92@G+B<L("=?
M)RP-"B`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8VAA;FYE;$EN9F];)W9A
M;&ED871E<&%C:V%G92==6R=?8V]N=&5N="==*2DI('L-"B`@("`@("`@("`@
M("`@("!I9B`H)'1H:7,M/FES26YC;'5D96%B;&4H<W1R7W)E<&QA8V4H)U\G
M+"`G+R<L#0H@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C:&%N;F5L
M26YF;ULG=F%L:61A=&5P86-K86=E)UU;)U]C;VYT96YT)UTI("X@)RYP:'`G
M*2D@>PT*("`@("`@("`@("`@("`@("`@("!I;F-L=61E7V]N8V4@<W1R7W)E
M<&QA8V4H)U\G+"`G+R<L#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7V-H86YN96Q);F9O6R=V86QI9&%T97!A8VMA9V4G75LG7V-O;G1E;G0G
M72D@+B`G+G!H<"<[#0H@("`@("`@("`@("`@("`@("`@("1V8VQA<W,@/2!S
M=')?<F5P;&%C92@G+B<L("=?)RP-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?8VAA;FYE;$EN9F];)W9A;&ED871E<&%C:V%G92==6R=?8V]N
M=&5N="==*3L-"B`@("`@("`@("`@("`@("`@("`@)'9A;"`]("9N97<@)'9C
M;&%S<SL-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("`@("`D82`](&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)&$[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`D=F-L87-S(#T@<W1R7W)E<&QA8V4H)RXG
M+"`G7R<L#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8VAA;FYE;$EN
M9F];)W9A;&ED871E<&%C:V%G92==6R=?8V]N=&5N="==*3L-"B`@("`@("`@
M("`@("`@("`D=F%L(#T@)FYE=R`D=F-L87-S.PT*("`@("`@("`@("`@?0T*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'9A;"`]("9N97<@4$5!
M4E]686QI9&%T93L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'9A;#L-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!I<TEN8VQU9&5A8FQE*"1P871H*0T*
M("`@('L-"B`@("`@("`@)'!O<W-I8FEL:71I97,@/2!E>'!L;V1E*%!!5$A?
M4T5005)!5$]2+"!I;FE?9V5T*"=I;F-L=61E7W!A=&@G*2D[#0H@("`@("`@
M(&9O<F5A8V@@*"1P;W-S:6)I;&ET:65S(&%S("1D:7(I('L-"B`@("`@("`@
M("`@(&EF("AF:6QE7V5X:7-T<R@D9&ER("X@1$E214-43U)97U-%4$%2051/
M4B`N("1P871H*0T*("`@("`@("`@("`@("`@("`@)B8@:7-?<F5A9&%B;&4H
M)&1I<B`N($1)4D5#5$]265]315!!4D%43U(@+B`D<&%T:"DI('L-"B`@("`@
M("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@("H@5&AI<R!F=6YC=&EO;B!I<R!U<V5D(&)Y('1H92!C:&%N;F5L
M('5P9&%T97(@86YD(')E=')I979E<R!A('9A;'5E('-E="!B>0T*("`@("`J
M('1H92!R96=I<W1R>2P@;W(@=&AE(&-U<G)E;G0@=&EM92!I9B!I="!H87,@
M;F]T(&)E96X@<V5T#0H@("`@("H@0')E='5R;B!S=')I;F<-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!L87-T36]D:69I960H*0T*("`@('L-"B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?8VAA;FYE;$EN9F];)U]L87-T;6]D:69I960G
M72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V-H86YN96Q);F9O
M6R=?;&%S=&UO9&EF:65D)UT[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N
M('1I;64H*3L-"B`@("!]#0I]#0H_/@T*``````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"YP:'``````````````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,S$V,S$@,3`U,34T,S,W,S(@,#(Q
M,S`W`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP#0HO*BH-"B`J(%!%05)?0V]M;6%N9"P@8V]M;6%N9"!P871T97)N
M(&-L87-S#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,
M24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO
M;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L
M92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG
M(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N
M("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(
M4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H
M('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P
M:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN
M#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!
M4@T*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*
M("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*
M("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L
M:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@
M(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z($-O
M;6UA;F0N<&AP+'8@,2XS-B`R,#`V+S`Q+S`V(#`T.C0W.C,V(&-E;&QO9R!%
M>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K
M86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E
M(%)E;&5A<V4@,"XQ#0H@*B\-"@T*+RHJ#0H@*B!.965D960@9F]R(&5R<F]R
M(&AA;F1L:6YG#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PT*<F5Q
M=6ER95]O;F-E("=014%2+T9R;VYT96YD+G!H<"<[#0IR97%U:7)E7V]N8V4@
M)U!%05(O6$U,4&%R<V5R+G!H<"<[#0H-"B\J*@T*("H@3&ES="!O9B!C;VUM
M86YD<R!A;F0@=VAA="!C;&%S<V5S('1H97D@87)E(&EM<&QE;65N=&5D(&EN
M+@T*("H@0'9A<B!A<G)A>2!C;VUM86YD(#T^(&EM<&QE;65N=&EN9R!C;&%S
M<PT*("HO#0HD1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]C;VUM86YD;&ES="==
M(#T@87)R87DH*3L-"@T*+RHJ#0H@*B!,:7-T(&]F('-H;W)T8W5T<R!T;R!C
M;VUM;VX@8V]M;6%N9',N#0H@*B!`=F%R(&%R<F%Y('-H;W)T8W5T(#T^(&-O
M;6UA;F0-"B`J+PT*)$=,3T)!3%-;)U]014%27T-O;6UA;F1?<VAO<G1C=71S
M)UT@/2!A<G)A>2@I.PT*#0HO*BH-"B`J($%R<F%Y(&]F(&-O;6UA;F0@;V)J
M96-T<PT*("H@0'9A<B!A<G)A>2!C;&%S<R`]/B!O8FIE8W0-"B`J+PT*)$=,
M3T)!3%-;)U]014%27T-O;6UA;F1?;V)J96-T<R==(#T@87)R87DH*3L-"@T*
M+RHJ#0H@*B!014%2(&-O;6UA;F0@8VQA<W,L(&$@<VEM<&QE(&9A8W1O<GD@
M8VQA<W,@9F]R(&%D;6EN:7-T<F%T:79E#0H@*B!C;VUM86YD<RX-"B`J#0H@
M*B!(;W<@=&\@:6UP;&5M96YT(&-O;6UA;F0@8VQA<W-E<SH-"B`J#0H@*B`M
M(%1H92!C;&%S<R!M=7-T(&)E(&-A;&QE9"!014%27T-O;6UA;F1?3FYN+"!I
M;G-T86QL960@:6X@=&AE#0H@*B`@(")014%2+T-O;6UO;B(@<W5B9&ER+"!W
M:71H(&$@;65T:&]D(&-A;&QE9"!G971#;VUM86YD<R@I('1H870-"B`J("`@
M<F5T=7)N<R!A;B!A<G)A>2!O9B!T:&4@8V]M;6%N9',@:6UP;&5M96YT960@
M8GD@=&AE(&-L87-S("AS964-"B`J("`@4$5!4B]#;VUM86YD+TEN<W1A;&PN
M<&AP(&9O<B!A;B!E>&%M<&QE*2X-"B`J#0H@*B`M(%1H92!C;&%S<R!M=7-T
M(&EM<&QE;65N="!A(')U;B@I(&9U;F-T:6]N('1H870@:7,@8V%L;&5D('=I
M=&@@=&AR964-"B`J("`@<&%R86US.@T*("H-"B`J("`@("AS=')I;F<I(&-O
M;6UA;F0@;F%M90T*("H@("`@*&%R<F%Y*2`@87-S;V,@87)R87D@=VET:"!O
M<'1I;VYS+"!F<F5E;'D@9&5F:6YE9"!B>2!E86-H#0H@*B`@("`@("`@("`@
M("!C;VUM86YD+"!F;W(@97AA;7!L93H-"B`J("`@("`@("`@("`@(&%R<F%Y
M*"=F;W)C92<@/3X@=')U92D-"B`J("`@("AA<G)A>2D@(&QI<W0@;V8@=&AE
M(&]T:&5R('!A<F%M971E<G,-"B`J#0H@*B`@(%1H92!R=6XH*2!F=6YC=&EO
M;B!R971U<FYS(&$@4$5!4E]#;VUM86YD4F5S<&]N<V4@;V)J96-T+B`@57-E
M#0H@*B`@('1H97-E(&UE=&AO9',@=&\@9V5T(&EN9F]R;6%T:6]N.@T*("H-
M"B`J("`@(&EN="!G9713=&%T=7,H*2`@(%)E='5R;G,@4$5!4E]#3TU-04Y$
M7RA354-#15-3?$9!24Q54D5\4$%25$E!3"D-"B`J("`@("`@("`@("`@("`@
M("`@("`@("I?4$%25$E!3"!M96%N<R!T:&%T('EO=2!N965D('1O(&ES<W5E
M(&%T(&QE87-T#0H@*B`@("`@("`@("`@("`@("`@("`@("!O;F4@;6]R92!C
M;VUM86YD('1O(&-O;7!L971E('1H92!O<&5R871I;VX-"B`J("`@("`@("`@
M("`@("`@("`@("`@("AU<V5D(&9O<B!E>&%M<&QE(&9O<B!V86QI9&%T:6]N
M('-T97!S*2X-"B`J#0H@*B`@("!S=')I;F<@9V5T365S<V%G92@I("!2971U
M<FYS(&$@;65S<V%G92!F;W(@=&AE('5S97(N("!296UE;6)E<BP-"B`J("`@
M("`@("`@("`@("`@("`@("`@("`@(&YO($A434P@;W(@;W1H97(@:6YT97)F
M86-E+7-P96-I9FEC(&UA<FMU<"X-"B`J#0H@*B`@($EF('-O;65T:&EN9R!U
M;F5X<&5C=&5D(&AA<'!E;G,L(')U;B@I(')E='5R;G,@82!014%2(&5R<F]R
M+@T*("H-"B`J("T@1$].)U0@3U544%54($%.651(24Y'(2!2971U<FX@=&5X
M="!F;W(@;W5T<'5T(&EN<W1E860N#0H@*@T*("H@+2!$3TXG5"!54T4@2%1-
M3"$@5&AE('1E>'0@>6]U(')E='5R;B!W:6QL(&)E('5S960@9G)O;2!B;W1H
M($=T:RP-"B`J("`@=V5B(&%N9"!C;VUM86YD+6QI;F4@:6YT97)F86-E<RP@
M<V\@9F]R(&YO=RP@:V5E<"!E=F5R>71H:6YG('1O#0H@*B`@('!L86EN('1E
M>'0N#0H@*@T*("H@+2!$3TXG5"!54T4@15A)5"!/4B!$244A($%L=V%Y<R!U
M<V4@<&5A<B!E<G)O<G,N("!&<F]M('-T871I8PT*("H@("!C;&%S<V5S(&1O
M(%!%05(Z.G)A:7-E17)R;W(H*2P@9G)O;2!O=&AE<B!C;&%S<V5S(&1O#0H@
M*B`@("1T:&ES+3YR86ES945R<F]R*"DN#0H@*B!`8V%T96=O<GD@("!P96%R
M#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!3=&EG($)A
M:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R("`@("!'<F5G($)E879E
M<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@
M5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R
M<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L
M87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#`N,0T*("HO#0IC;&%S<R!0
M14%27T-O;6UA;F0-"GL-"B`@("`O+R![>WL@9F%C=&]R>2@I#0H-"B`@("`O
M*BH-"B`@("`@*B!'970@=&AE(')I9VAT(&]B:F5C="!F;W(@97AE8W5T:6YG
M(&$@8V]M;6%N9"X-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@)&-O
M;6UA;F0@5&AE(&YA;64@;V8@=&AE(&-O;6UA;F0-"B`@("`@*B!`<&%R86T@
M;V)J96-T("1C;VYF:6<@($EN<W1A;F-E(&]F(%!%05)?0V]N9FEG(&]B:F5C
M=`T*("`@("`J#0H@("`@("H@0')E='5R;B!O8FIE8W0@=&AE(&-O;6UA;F0@
M;V)J96-T(&]R(&$@4$5!4B!E<G)O<@T*("`@("`J#0H@("`@("H@0&%C8V5S
M<R!P=6)L:6,-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@)F9A8W1O<GDH)&-O;6UA;F0L("8D8V]N9FEG*0T*("`@('L-"B`@("`@
M("`@:68@*&5M<'1Y*"1'3$]"04Q36R=?4$5!4E]#;VUM86YD7V-O;6UA;F1L
M:7-T)UTI*2![#0H@("`@("`@("`@("!014%27T-O;6UA;F0Z.G)E9VES=&5R
M0V]M;6%N9',H*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)$=,
M3T)!3%-;)U]014%27T-O;6UA;F1?<VAO<G1C=71S)UU;)&-O;6UA;F1=*2D@
M>PT*("`@("`@("`@("`@)&-O;6UA;F0@/2`D1TQ/0D%,4ULG7U!%05)?0V]M
M;6%N9%]S:&]R=&-U=',G75LD8V]M;6%N9%T[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*"%I<W-E="@D1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]C;VUM86YD
M;&ES="==6R1C;VUM86YD72DI('L-"B`@("`@("`@("`@("1A(#T@4$5!4CHZ
M<F%I<V5%<G)O<B@B=6YK;F]W;B!C;VUM86YD(&`D8V]M;6%N9"<B*3L-"B`@
M("`@("`@("`@(')E='5R;B`D83L-"B`@("`@("`@?0T*("`@("`@("`D8VQA
M<W,@/2`D1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]C;VUM86YD;&ES="==6R1C
M;VUM86YD73L-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)&-L87-S*2D@
M>PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("1'3$]"04Q36R=?4$5!4E]#
M;VUM86YD7V]B:F5C=',G75LD8VQA<W-=.PT*("`@("`@("!]#0H@("`@("`@
M(&EF("@A8VQA<W-?97AI<W1S*"1C;&%S<RDI('L-"B`@("`@("`@("`@("1A
M(#T@4$5!4CHZ<F%I<V5%<G)O<B@B=6YK;F]W;B!C;VUM86YD(&`D8V]M;6%N
M9"<B*3L-"B`@("`@("`@("`@(')E='5R;B`D83L-"B`@("`@("`@?0T*("`@
M("`@("`D=6D@/28@4$5!4E]#;VUM86YD.CIG971&<F]N=&5N9$]B:F5C="@I
M.PT*("`@("`@("`D;V)J(#T@)FYE=R`D8VQA<W,H)'5I+"`D8V]N9FEG*3L-
M"B`@("`@("`@<F5T=7)N("1O8FH[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[("8@9V5T3V)J96-T*"D-"B`@("!F=6YC=&EO;B`F9V5T3V)J
M96-T*"1C;VUM86YD*0T*("`@('L-"B`@("`@("`@)&-L87-S(#T@)$=,3T)!
M3%-;)U]014%27T-O;6UA;F1?8V]M;6%N9&QI<W0G75LD8V]M;6%N9%T[#0H@
M("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"1C;&%S<RDI('L-"B`@("`@("`@
M("`@(')E<75I<F5?;VYC92`D1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]O8FIE
M8W1S)UU;)&-L87-S73L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6-L87-S
M7V5X:7-T<R@D8VQA<W,I*2![#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@B=6YK;F]W;B!C;VUM86YD(&`D8V]M;6%N9"<B*3L-"B`@
M("`@("`@?0T*("`@("`@("`D=6D@/28@4$5!4E]#;VUM86YD.CIG971&<F]N
M=&5N9$]B:F5C="@I.PT*("`@("`@("`D8V]N9FEG(#T@)E!%05)?0V]N9FEG
M.CIS:6YG;&5T;VXH*3L-"B`@("`@("`@)&]B:B`]("9N97<@)&-L87-S*"1U
M:2P@)&-O;F9I9RD[#0H@("`@("`@(')E='5R;B`D;V)J.PT*("`@('T-"@T*
M("`@("\O('U]?0T*("`@("\O('M[>R`F(&=E=$9R;VYT96YD3V)J96-T*"D-
M"@T*("`@("\J*@T*("`@("`J($=E="!I;G-T86YC92!O9B!F<F]N=&5N9"!O
M8FIE8W0N#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&]B:F5C='Q014%27T5R
M<F]R#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T:6]N("9G
M971&<F]N=&5N9$]B:F5C="@I#0H@("`@>PT*("`@("`@("`D82`]("9014%2
M7T9R;VYT96YD.CIS:6YG;&5T;VXH*3L-"B`@("`@("`@<F5T=7)N("1A.PT*
M("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R`F('-E=$9R;VYT96YD
M0VQA<W,H*0T*#0H@("`@+RHJ#0H@("`@("H@3&]A9"!C=7)R96YT(&9R;VYT
M96YD(&-L87-S+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`D=6EC
M;&%S<R!.86UE(&]F(&-L87-S(&EM<&QE;65N=&EN9R!T:&4@9G)O;G1E;F0-
M"B`@("`@*@T*("`@("`J($!R971U<FX@;V)J96-T('1H92!F<F]N=&5N9"!O
M8FIE8W0L(&]R(&$@4$5!4B!E<G)O<@T*("`@("`J($!S=&%T:6,-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B`F<V5T1G)O;G1E;F1#;&%S<R@D=6EC;&%S<RD-
M"B`@("![#0H@("`@("`@("1A(#T@)E!%05)?1G)O;G1E;F0Z.G-E=$9R;VYT
M96YD0VQA<W,H)'5I8VQA<W,I.PT*("`@("`@("!R971U<FX@)&$[#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[('-E=$9R;VYT96YD5'EP92@I
M#0H-"B`@("`O*BH-"B`@("`@*B!3970@8W5R<F5N="!F<F]N=&5N9"X-"B`@
M("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@)'5I='EP92!.86UE(&]F('1H
M92!F<F]N=&5N9"!T>7!E("AF;W(@97AA;7!L92`B0TQ)(BD-"B`@("`@*@T*
M("`@("`J($!R971U<FX@;V)J96-T('1H92!F<F]N=&5N9"!O8FIE8W0L(&]R
M(&$@4$5!4B!E<G)O<@T*("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!S971&<F]N=&5N9%1Y<&4H)'5I='EP92D-"B`@("![#0H@("`@
M("`@("1U:6-L87-S(#T@)U!%05)?1G)O;G1E;F1?)R`N("1U:71Y<&4[#0H@
M("`@("`@(')E='5R;B!014%27T-O;6UA;F0Z.G-E=$9R;VYT96YD0VQA<W,H
M)'5I8VQA<W,I.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!R
M96=I<W1E<D-O;6UA;F1S*"D-"@T*("`@("\J*@T*("`@("`J(%-C86X@=&AR
M;W5G:"!T:&4@0V]M;6%N9"!D:7)E8W1O<GD@;&]O:VEN9R!F;W(@8VQA<W-E
M<PT*("`@("`J(&%N9"!S964@=VAA="!C;VUM86YD<R!T:&5Y(&EM<&QE;65N
M="X-"B`@("`@*@T*("`@("`J($!P87)A;2!B;V]L("`@*&]P=&EO;F%L*2!I
M9B!&04Q312`H9&5F875L="DL('1H92!N97<@;&ES="!O9@T*("`@("`J("`@
M("`@("`@("`@("`@8V]M;6%N9',@<VAO=6QD(')E<&QA8V4@=&AE(&-U<G)E
M;G0@;VYE+B`@268@5%)512P-"B`@("`@*B`@("`@("`@("`@("`@(&YE=R!E
M;G1R:65S('=I;&P@8F4@;65R9V5D('=I=&@@;VQD+@T*("`@("`J#0H@("`@
M("H@0'!A<F%M('-T<FEN9R`H;W!T:6]N86PI('=H97)E("AW:&%T(&1I<F5C
M=&]R>2D@=&\@;&]O:R!F;W(-"B`@("`@*B`@("`@("`@("`@("`@(&-L87-S
M97,L(&1E9F%U;'1S('1O('1H92!#;VUM86YD('-U8F1I<F5C=&]R>2!O9@T*
M("`@("`J("`@("`@("`@("`@("`@=&AE(&1I<F5C=&]R>2!F<F]M('=H97)E
M('1H:7,@9FEL92`H7U]&24Q%7U\I(&ES#0H@("`@("H@("`@("`@("`@("`@
M("!I;F-L=61E9"X-"B`@("`@*@T*("`@("`J($!R971U<FX@8F]O;"!44E5%
M(&]N('-U8V-E<W,L(&$@4$5!4B!E<G)O<B!O;B!F86EL=7)E#0H@("`@("H-
M"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J($!S=&%T:6,-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!R96=I<W1E<D-O;6UA;F1S*"1M97)G92`](&9A
M;'-E+"`D9&ER(#T@;G5L;"D-"B`@("![#0H@("`@("`@("1P87)S97(@/2!N
M97<@4$5!4E]834Q087)S97([#0H@("`@("`@(&EF("@D9&ER(#T]/2!N=6QL
M*2![#0H@("`@("`@("`@("`D9&ER(#T@9&ER;F%M92A?7T9)3$5?7RD@+B`G
M+T-O;6UA;F0G.PT*("`@("`@("!]#0H@("`@("`@("1D<"`]($!O<&5N9&ER
M*"1D:7(I.PT*("`@("`@("!I9B`H96UP='DH)&1P*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(G)E9VES=&5R0V]M;6%N9',Z
M(&]P96YD:7(H)&1I<BD@9F%I;&5D(BD[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*"$D;65R9V4I('L-"B`@("`@("`@("`@("1'3$]"04Q36R=?4$5!4E]#
M;VUM86YD7V-O;6UA;F1L:7-T)UT@/2!A<G)A>2@I.PT*("`@("`@("!]#0H@
M("`@("`@('=H:6QE("@D96YT<GD@/2!R96%D9&ER*"1D<"DI('L-"B`@("`@
M("`@("`@(&EF("@D96YT<GE[,'T@/3T@)RXG('Q\('-U8G-T<B@D96YT<GDL
M("TT*2`A/2`G+GAM;"<I('L-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1C;&%S<R`](")014%27T-O
M;6UA;F1?(BYS=6)S='(H)&5N=')Y+"`P+"`M-"D[#0H@("`@("`@("`@("`D
M9FEL92`]("(D9&ER+R1E;G1R>2([#0H@("`@("`@("`@("`D<&%R<V5R+3YP
M87)S92AF:6QE7V=E=%]C;VYT96YT<R@D9FEL92DI.PT*("`@("`@("`@("`@
M)&EM<&QE;65N=',@/2`D<&%R<V5R+3YG971$871A*"D[#0H@("`@("`@("`@
M("`O+R!,:7-T(&]F(&-O;6UA;F1S#0H@("`@("`@("`@("!I9B`H96UP='DH
M)$=,3T)!3%-;)U]014%27T-O;6UA;F1?;V)J96-T<R==6R1C;&%S<UTI*2![
M#0H@("`@("`@("`@("`@("`@)$=,3T)!3%-;)U]014%27T-O;6UA;F1?;V)J
M96-T<R==6R1C;&%S<UT@/2`B)&1I<B\B("X@<W5B<W1R*"1E;G1R>2P@,"P@
M+30I("X-"B`@("`@("`@("`@("`@("`@("`@)RYP:'`G.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H)&EM<&QE;65N=',@87,@)&-O
M;6UA;F0@/3X@)&1E<V,I('L-"B`@("`@("`@("`@("`@("!I9B`H)&-O;6UA
M;F0@/3T@)V%T=')I8G,G*2![#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)$=,3T)!3%-;)U]014%27T-O;6UA;F1?8V]M;6%N9&QI<W0G75LD
M8V]M;6%N9%TI*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*"=#;VUM86YD("(G("X@)&-O;6UA;F0@+B`G(B!A;')E
M861Y(')E9VES=&5R960@:6X@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`G8VQA<W,@(B<@+B`D1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]C;VUM86YD
M;&ES="==6R1C;VUM86YD72`N("<B)RD[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("1'3$]"04Q36R=?4$5!4E]#;VUM86YD7V-O;6UA
M;F1L:7-T)UU;)&-O;6UA;F1=(#T@)&-L87-S.PT*("`@("`@("`@("`@("`@
M("1'3$]"04Q36R=?4$5!4E]#;VUM86YD7V-O;6UA;F1D97-C)UU;)&-O;6UA
M;F1=(#T@)&1E<V-;)W-U;6UA<GDG73L-"B`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)&1E<V-;)W-H;W)T8W5T)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("1S:&]R=&-U="`]("1D97-C6R=S:&]R=&-U="==.PT*("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)$=,3T)!3%-;)U]014%27T-O;6UA;F1?
M<VAO<G1C=71S)UU;)'-H;W)T8W5T72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=#;VUM86YD('-H;W)T
M8W5T("(G("X@)'-H;W)T8W5T("X@)R(@86QR96%D>2`G("X-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G<F5G:7-T97)E9"!T;R!C;VUM86YD("(G
M("X@)&-O;6UA;F0@+B`G(B!I;B!C;&%S<R`B)R`N#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)$=,3T)!3%-;)U]014%27T-O;6UA;F1?8V]M;6%N
M9&QI<W0G75LD8V]M;6%N9%T@+B`G(B<I.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("1'3$]"04Q36R=?4$5!4E]#;VUM
M86YD7W-H;W)T8W5T<R==6R1S:&]R=&-U=%T@/2`D8V]M;6%N9#L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97-C
M6R=O<'1I;VYS)UTI("8F("1D97-C6R=O<'1I;VYS)UTI('L-"B`@("`@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)&1E<V-;)V]P=&EO;G,G72!A<R`D;VYA
M;64@/3X@)&]P=&EO;BD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1O<'1I;VY;)W-H;W)T;W!T)UTI("8F('-T<FQE;B@D;W!T:6]N
M6R=S:&]R=&]P="==*2`^(#$I('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G3W!T:6]N("(G("X@)&]N
M86UE("X@)R(@<VAO<G0@;W!T:6]N("(G("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&]P=&EO;ELG<VAO<G1O<'0G72`N("<B(&UU<W0@
M8F4@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=O;FQY
M(#$@8VAA<F%C=&5R(&EN($-O;6UA;F0@(B<@+B`D8V]M;6%N9"`N("<B(&EN
M(&-L87-S("(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&-L87-S("X@)R(G*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!K<V]R="@D1TQ/0D%,4ULG
M7U!%05)?0V]M;6%N9%]S:&]R=&-U=',G72D[#0H@("`@("`@(&MS;W)T*"1'
M3$]"04Q36R=?4$5!4E]#;VUM86YD7V-O;6UA;F1L:7-T)UTI.PT*("`@("`@
M("!`8VQO<V5D:7(H)&1P*3L-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&=E=$-O;6UA;F1S*"D-"@T*
M("`@("\J*@T*("`@("`J($=E="!T:&4@;&ES="!O9B!C=7)R96YT;'D@<W5P
M<&]R=&5D(&-O;6UA;F1S+"!A;F0@=VAA=`T*("`@("`J(&-L87-S97,@:6UP
M;&5M96YT('1H96TN#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&%R<F%Y(&-O
M;6UA;F0@/3X@:6UP;&5M96YT:6YG(&-L87-S#0H@("`@("H-"B`@("`@*B!`
M86-C97-S('!U8FQI8PT*("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!G971#;VUM86YD<R@I#0H@("`@>PT*("`@("`@("!I9B`H96UP
M='DH)$=,3T)!3%-;)U]014%27T-O;6UA;F1?8V]M;6%N9&QI<W0G72DI('L-
M"B`@("`@("`@("`@(%!%05)?0V]M;6%N9#HZ<F5G:7-T97)#;VUM86YD<R@I
M.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG7U!%05)?
M0V]M;6%N9%]C;VUM86YD;&ES="==.PT*("`@('T-"@T*("`@("\O('U]?0T*
M("`@("\O('M[>R!G9713:&]R=&-U=',H*0T*#0H@("`@+RHJ#0H@("`@("H@
M1V5T('1H92!L:7-T(&]F(&-O;6UA;F0@<VAO<G1C=71S+@T*("`@("`J#0H@
M("`@("H@0')E='5R;B!A<G)A>2!S:&]R=&-U="`]/B!C;VUM86YD#0H@("`@
M("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J($!S=&%T:6,-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!G9713:&]R=&-U=',H*0T*("`@('L-"B`@
M("`@("`@:68@*&5M<'1Y*"1'3$]"04Q36R=?4$5!4E]#;VUM86YD7W-H;W)T
M8W5T<R==*2D@>PT*("`@("`@("`@("`@4$5!4E]#;VUM86YD.CIR96=I<W1E
M<D-O;6UA;F1S*"D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1'3$]"
M04Q36R=?4$5!4E]#;VUM86YD7W-H;W)T8W5T<R==.PT*("`@('T-"@T*("`@
M("\O('U]?0T*("`@("\O('M[>R!G971'971O<'1!<F=S*"D-"@T*("`@("\J
M*@T*("`@("`J($-O;7!I;&5S(&%R9W5M96YT<R!F;W(@9V5T;W!T+@T*("`@
M("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]M;6%N9"`@("`@8V]M;6%N
M9"!T;R!G970@;W!T<W1R:6YG(&9O<@T*("`@("`J($!P87)A;2!S=')I;F<@
M)'-H;W)T7V%R9W,@("AR969E<F5N8V4I('-H;W)T(&=E=&]P="!F;W)M870-
M"B`@("`@*B!`<&%R86T@87)R87D@("1L;VYG7V%R9W,@("`H<F5F97)E;F-E
M*2!L;VYG(&=E=&]P="!F;W)M870-"B`@("`@*@T*("`@("`J($!R971U<FX@
M=F]I9`T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`
M<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T1V5T;W!T07)G<R@D
M8V]M;6%N9"P@)B1S:&]R=%]A<F=S+"`F)&QO;F=?87)G<RD-"B`@("![#0H@
M("`@("`@(&EF("AE;7!T>2@D1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]C;VUM
M86YD;&ES="==*2D@>PT*("`@("`@("`@("`@4$5!4E]#;VUM86YD.CIR96=I
M<W1E<D-O;6UA;F1S*"D[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T
M*"1'3$]"04Q36R=?4$5!4E]#;VUM86YD7W-H;W)T8W5T<R==6R1C;VUM86YD
M72DI('L-"B`@("`@("`@("`@("1C;VUM86YD(#T@)$=,3T)!3%-;)U]014%2
M7T-O;6UA;F1?<VAO<G1C=71S)UU;)&-O;6UA;F1=.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@A:7-S970H)$=,3T)!3%-;)U]014%27T-O;6UA;F1?8V]M
M;6%N9&QI<W0G75LD8V]M;6%N9%TI*2![#0H@("`@("`@("`@("!R971U<FX@
M;G5L;#L-"B`@("`@("`@?0T*("`@("`@("`D;V)J(#T@)E!%05)?0V]M;6%N
M9#HZ9V5T3V)J96-T*"1C;VUM86YD*3L-"B`@("`@("`@<F5T=7)N("1O8FHM
M/F=E=$=E=&]P=$%R9W,H)&-O;6UA;F0L("1S:&]R=%]A<F=S+"`D;&]N9U]A
M<F=S*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T1&5S
M8W)I<'1I;VXH*0T*#0H@("`@+RHJ#0H@("`@("H@1V5T(&1E<V-R:7!T:6]N
M(&9O<B!A(&-O;6UA;F0N#0H@("`@("H-"B`@("`@*B!`<&%R86T@('-T<FEN
M9R`D8V]M;6%N9"!.86UE(&]F('1H92!C;VUM86YD#0H@("`@("H-"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R!C;VUM86YD(&1E<V-R:7!T:6]N#0H@("`@("H-
M"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J($!S=&%T:6,-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!G971$97-C<FEP=&EO;B@D8V]M;6%N9"D-"B`@
M("![#0H@("`@("`@(&EF("@A:7-S970H)$=,3T)!3%-;)U]014%27T-O;6UA
M;F1?8V]M;6%N9&1E<V,G75LD8V]M;6%N9%TI*2![#0H@("`@("`@("`@("!R
M971U<FX@;G5L;#L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)$=,3T)!
M3%-;)U]014%27T-O;6UA;F1?8V]M;6%N9&1E<V,G75LD8V]M;6%N9%T[#0H@
M("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&=E=$AE;'`H*0T*#0H@
M("`@+RHJ#0H@("`@("H@1V5T(&AE;'`@9F]R(&-O;6UA;F0N#0H@("`@("H-
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VUM86YD($YA;64@;V8@=&AE(&-O
M;6UA;F0@=&\@<F5T=7)N(&AE;'`@9F]R#0H@("`@("H-"B`@("`@*B!`86-C
M97-S('!U8FQI8PT*("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!G971(96QP*"1C;VUM86YD*0T*("`@('L-"B`@("`@("`@)&-M9',@
M/2!014%27T-O;6UA;F0Z.F=E=$-O;6UA;F1S*"D[#0H@("`@("`@(&EF("AI
M<W-E="@D1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]S:&]R=&-U=',G75LD8V]M
M;6%N9%TI*2![#0H@("`@("`@("`@("`D8V]M;6%N9"`]("1'3$]"04Q36R=?
M4$5!4E]#;VUM86YD7W-H;W)T8W5T<R==6R1C;VUM86YD73L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H:7-S970H)&-M9'-;)&-O;6UA;F1=*2D@>PT*("`@
M("`@("`@("`@)&]B:B`]("9014%27T-O;6UA;F0Z.F=E=$]B:F5C="@D8V]M
M;6%N9"D[#0H@("`@("`@("`@("!R971U<FX@)&]B:BT^9V5T2&5L<"@D8V]M
M;6%N9"D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M('T-"B`@("`O+R!]?7T-"GT-"@T*/SX-"@``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6]N+G!H<```````````
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`Q,#<W,S0@,3`U,34T
M,S,W,S(@,#(Q,3<Q`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP#0HO*BH-"B`J(%!%05)?0V]M;6]N+"!T:&4@8F%S
M92!C;&%S<R!F;W(@=&AE(%!%05(@26YS=&%L;&5R#0H@*@T*("H@4$A0('9E
M<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F
M:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E
M;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E
M:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA
M8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@
M<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL
M('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@
M<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@4W1I
M9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@5&]M87,@
M5BX@5BX@0V]X(#QC;WA`:61E8VYE="YC;VT^#0H@*B!`875T:&]R("`@("!'
M<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q
M.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP
M#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@0V]M;6]N+G!H<"QV(#$N,34U
M(#(P,#8O,#,O,#(@,3@Z,30Z,3(@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@
M("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I
M;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$N,`T*
M("H@0&1E<')E8V%T960@1FEL92!D97!R96-A=&5D('-I;F-E(%)E;&5A<V4@
M,2XT+C!A,0T*("HO#0H-"B\J*@T*("H@26YC;'5D92!E<G)O<B!H86YD;&EN
M9PT*("HO#0IR97%U:7)E7V]N8V4@)U!%05(N<&AP)SL-"@T*+R\@>WM[(&-O
M;G-T86YT<R!A;F0@9VQO8F%L<PT*#0HO*BH-"B`J(%!%05)?0V]M;6]N(&5R
M<F]R('=H96X@86X@:6YV86QI9"!02%`@9FEL92!I<R!P87-S960@=&\@4$5!
M4E]#;VUM;VXZ.F%N86QY>F53;W5R8V5#;V1E*"D-"B`J+PT*9&5F:6YE*"=0
M14%27T-/34U/3E]%4E)/4E])3E9!3$E$4$A0)RP@,2D[#0ID969I;F4H)U]0
M14%27T-/34U/3E]004-+04=%7TY!345?4%)%1R<L("=;02U:82UZ75MA+7I!
M+5HP+3E?72LG*3L-"F1E9FEN92@G4$5!4E]#3TU-3TY?4$%#2T%'15].04U%
M7U!214<G+"`G+UXG("X@7U!%05)?0T]-34].7U!!0TM!1T5?3D%-15]04D5'
M("X@)R0O)RD[#0H-"B\O('1H:7,@<VAO=6QD(&%L;&]W.B`Q+"`Q+C`L(#$N
M,%)#,2P@,2XP9&5V+"`Q+C!D978Q,C,R,S0R,S0R,S0L(#$N,&$Q+"`Q+C!B
M,2P@,2XP<&PQ#0ID969I;F4H)U]014%27T-/34U/3E]004-+04=%7U9%4E-)
M3TY?4%)%1R<L("=<9"LH/SI<+EQD*RDJ*#\Z6V$M>D$M6ETK7&0J*3\G*3L-
M"F1E9FEN92@G4$5!4E]#3TU-3TY?4$%#2T%'15]615)324].7U!214<G+"`G
M+UXG("X@7U!%05)?0T]-34].7U!!0TM!1T5?5D524TE/3E]04D5'("X@)R0O
M:2<I.PT*#0HO+R!86%@@9F%R(&9R;VT@<&5R9F5C="`Z+2D-"F1E9FEN92@G
M7U!%05)?0T]-34].7U!!0TM!1T5?1$]73DQ/041?4%)%1R<L("<H)R`N(%]0
M14%27T-/34U/3E]004-+04=%7TY!345?4%)%1R`N#0H@("`@)RDH+2A;+C`M
M.6$M>D$M6ETK*2D_)RD[#0ID969I;F4H)U!%05)?0T]-34].7U!!0TM!1T5?
M1$]73DQ/041?4%)%1R<L("<O7B<@+B!?4$5!4E]#3TU-3TY?4$%#2T%'15]$
M3U=.3$]!1%]04D5'("X-"B`@("`G)"\G*3L-"@T*9&5F:6YE*"=?4$5!4E]#
M2$%.3D5,4U].04U%7U!214<G+"`G6T$M6F$M>EU;82UZ02U:,"TY7"Y=*R<I
M.PT*9&5F:6YE*"=014%27T-(04Y.14Q37TY!345?4%)%1R<L("<O7B<@+B!?
M4$5!4E]#2$%.3D5,4U].04U%7U!214<@+B`G)"\G*3L-"@T*+R\@=&AI<R!S
M:&]U;&0@86QL;W<@86YY(&1N<R!O<B!)4"!A9&1R97-S+"!P;'5S(&$@<&%T
M:"`M($Y/(%5.1$524T-/4D53($%,3$]7140-"F1E9FEN92@G7U!%05)?0TA!
M3DY%3%-?4T525D527U!214<G+"`G6V$M>D$M6C`M.5PM72LH/SI<+EMA+7I!
M+5HP+3E<+5TK*2HH7"];82UZ02U:,"TY7"U=*RDJ)RD[#0ID969I;F4H)U!%
M05)?0TA!3DY%3%-?4T525D527U!214<G+"`G+UXG("X@7U!%05)?0TA!3DY%
M3%-?4T525D527U!214<@+B`G)"]I)RD[#0H-"F1E9FEN92@G7U!%05)?0TA!
M3DY%3%-?4$%#2T%'15]04D5')RP@("<H)R`N7U!%05)?0TA!3DY%3%-?4T52
M5D527U!214<@+B`G*5PO*"<-"B`@("`@("`@("X@7U!%05)?0T]-34].7U!!
M0TM!1T5?3D%-15]04D5'("X@)RDG*3L-"F1E9FEN92@G4$5!4E]#2$%.3D5,
M4U]004-+04=%7U!214<G+"`G+UXG("X@7U!%05)?0TA!3DY%3%-?4$%#2T%'
M15]04D5'("X@)R0O:2<I.PT*#0ID969I;F4H)U]014%27T-/34U/3E]#2$%.
M3D5,7T1/5TY,3T%$7U!214<G+"`G*"<@+B!?4$5!4E]#2$%.3D5,4U].04U%
M7U!214<@+B`G*3HZ*"<-"B`@("`N(%]014%27T-/34U/3E]004-+04=%7TY!
M345?4%)%1R`N("<I*"TH6RXP+3EA+7I!+5I=*RDI/R<I.PT*9&5F:6YE*"=0
M14%27T-/34U/3E]#2$%.3D5,7T1/5TY,3T%$7U!214<G+"`G+UXG("X@7U!%
M05)?0T]-34].7T-(04Y.14Q?1$]73DQ/041?4%)%1R`N("<D+R<I.PT*#0HO
M*BH-"B`J($QI<W0@;V8@=&5M<&]R87)Y(&9I;&5S(&%N9"!D:7)E8W1O<FEE
M<R!R96=I<W1E<F5D(&)Y#0H@*B!014%27T-O;6UO;CHZ861D5&5M<$9I;&4H
M*2X-"B`J($!V87(@87)R87D-"B`J+PT*)$=,3T)!3%-;)U]014%27T-O;6UO
M;E]T96UP9FEL97,G72`](&%R<F%Y*"D[#0H-"B\J*@T*("H@5F%L:60@;6%I
M;G1A:6YE<B!R;VQE<PT*("H@0'9A<B!A<G)A>0T*("HO#0HD1TQ/0D%,4ULG
M7U!%05)?0V]M;6]N7VUA:6YT86EN97)?<F]L97,G72`](&%R<F%Y*"=L96%D
M)RPG9&5V96QO<&5R)RPG8V]N=')I8G5T;W(G+"=H96QP97(G*3L-"@T*+RHJ
M#0H@*B!686QI9"!R96QE87-E('-T871E<PT*("H@0'9A<B!A<G)A>0T*("HO
M#0HD1TQ/0D%,4ULG7U!%05)?0V]M;6]N7W)E;&5A<V5?<W1A=&5S)UT@/2!A
M<G)A>2@G86QP:&$G+"=B971A)RPG<W1A8FQE)RPG<VYA<'-H;W0G+"=D979E
M;"<I.PT*#0HO*BH-"B`J(%9A;&ED(&1E<&5N9&5N8WD@='EP97,-"B`J($!V
M87(@87)R87D-"B`J+PT*)$=,3T)!3%-;)U]014%27T-O;6UO;E]D97!E;F1E
M;F-Y7W1Y<&5S)UT@/2!A<G)A>2@G<&MG)RPG97AT)RPG<&AP)RPG<')O9R<L
M)VQD;&EB)RPG<G1L:6(G+"=O<R<L)W=E8G-R=B<L)W-A<&DG*3L-"@T*+RHJ
M#0H@*B!686QI9"!D97!E;F1E;F-Y(')E;&%T:6]N<PT*("H@0'9A<B!A<G)A
M>0T*("HO#0HD1TQ/0D%,4ULG7U!%05)?0V]M;6]N7V1E<&5N9&5N8WE?<F5L
M871I;VYS)UT@/2!A<G)A>2@G:&%S)RPG97$G+"=L="<L)VQE)RPG9W0G+"=G
M92<L)VYO="<L("=N92<I.PT*#0HO*BH-"B`J(%9A;&ED(&9I;&4@<F]L97,-
M"B`J($!V87(@87)R87D-"B`J+PT*)$=,3T)!3%-;)U]014%27T-O;6UO;E]F
M:6QE7W)O;&5S)UT@/2!A<G)A>2@G<&AP)RPG97AT)RPG=&5S="<L)V1O8R<L
M)V1A=&$G+"=S<F,G+"=S8W)I<'0G*3L-"@T*+RHJ#0H@*B!686QI9"!R97!L
M86-E;65N="!T>7!E<PT*("H@0'9A<B!A<G)A>0T*("HO#0HD1TQ/0D%,4ULG
M7U!%05)?0V]M;6]N7W)E<&QA8V5M96YT7W1Y<&5S)UT@/2!A<G)A>2@G<&AP
M+6-O;G-T)RP@)W!E87(M8V]N9FEG)RP@)W!A8VMA9V4M:6YF;R<I.PT*#0HO
M*BH-"B`J(%9A;&ED(")P<F]V:61E(B!T>7!E<PT*("H@0'9A<B!A<G)A>0T*
M("HO#0HD1TQ/0D%,4ULG7U!%05)?0V]M;6]N7W!R;W9I9&5?='EP97,G72`]
M(&%R<F%Y*"=E>'0G+"`G<')O9R<L("=C;&%S<R<L("=F=6YC=&EO;B<L("=F
M96%T=7)E)RP@)V%P:2<I.PT*#0HO*BH-"B`J(%9A;&ED(")P<F]V:61E(B!T
M>7!E<PT*("H@0'9A<B!A<G)A>0T*("HO#0HD1TQ/0D%,4ULG7U!%05)?0V]M
M;6]N7W-C<FEP=%]P:&%S97,G72`](&%R<F%Y*"=P<F4M:6YS=&%L;"<L("=P
M;W-T+6EN<W1A;&PG+"`G<')E+75N:6YS=&%L;"<L("=P;W-T+75N:6YS=&%L
M;"<L("=P<F4M8G5I;&0G+"`G<&]S="UB=6EL9"<L("=P<F4M8V]N9FEG=7)E
M)RP@)W!O<W0M8V]N9FEG=7)E)RP@)W!R92US971U<"<L("=P;W-T+7-E='5P
M)RD[#0H-"B\O('U]?0T*#0HO*BH-"B`J($-L87-S('!R;W9I9&EN9R!C;VUM
M;VX@9G5N8W1I;VYA;&ET>2!F;W(@4$5!4B!A9&UI;FES=')A=&EO;B!C;&%S
M<V5S+@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!
M4@T*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*
M("H@0&%U=&AO<B`@("`@5&]M87,@5BX@5BX@0V]X(#QC;WA`:61E8VYE="YC
M;VT^#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN
M970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*
M("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E
M.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P
M86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S
M:6YC92!296QE87-E(#$N-"XP83$-"B`J($!D97!R96-A=&5D(%1H:7,@8VQA
M<W,@=VEL;"!D:7-A<'!E87(L(&%N9"!I=',@8V]M<&]N96YT<R!W:6QL(&)E
M('-P<F5A9`T*("H@("`@("`@("`@("`@:6YT;R!S;6%L;&5R(&-L87-S97,L
M(&QI:V4@=&AE($%4)E0@8G)E86MU<"P@87,@;V8@4F5L96%S92`Q+C0N,&$Q
M#0H@*B\-"F-L87-S(%!%05)?0V]M;6]N(&5X=&5N9',@4$5!4@T*>PT*("`@
M("\O('M[>R!P<F]P97)T:65S#0H-"B`@("`O*BH@<W1A8VL@;V8@96QE;65N
M=',L(&=I=F5S('-O;64@<V]R="!O9B!834P@8V]N=&5X="`J+PT*("`@('9A
M<B`D96QE;65N=%]S=&%C:R`](&%R<F%Y*"D[#0H-"B`@("`O*BH@;F%M92!O
M9B!C=7)R96YT;'D@<&%R<V5D(%A-3"!E;&5M96YT("HO#0H@("`@=F%R("1C
M=7)R96YT7V5L96UE;G0[#0H-"B`@("`O*BH@87)R87D@;V8@871T<FEB=71E
M<R!O9B!T:&4@8W5R<F5N=&QY('!A<G-E9"!834P@96QE;65N="`J+PT*("`@
M('9A<B`D8W5R<F5N=%]A='1R:6)U=&5S(#T@87)R87DH*3L-"@T*("`@("\J
M*B!A<W-O8R!W:71H(&EN9F]R;6%T:6]N(&%B;W5T(&$@<&%C:V%G92`J+PT*
M("`@('9A<B`D<&MG:6YF;R`](&%R<F%Y*"D[#0H-"B`@("`O*BH-"B`@("`@
M*B!5<V5R($EN=&5R9F%C92!O8FIE8W0@*%!%05)?1G)O;G1E;F1?*B!C;&%S
M<RDN("!)9B!N=6QL+`T*("`@("`J('1H92!L;V<H*2!M971H;V0@=7-E<R!P
M<FEN="X-"B`@("`@*B!`=F%R(&]B:F5C=`T*("`@("`J+PT*("`@('9A<B`D
M=6D@/2!N=6QL.PT*#0H@("`@+RHJ#0H@("`@("H@0V]N9FEG=7)A=&EO;B!O
M8FIE8W0@*%!%05)?0V]N9FEG*2X-"B`@("`@*B!`=F%R(&]B:F5C=`T*("`@
M("`J+PT*("`@('9A<B`D8V]N9FEG(#T@;G5L;#L-"@T*("`@('9A<B`D8W5R
M<F5N=%]P871H(#T@;G5L;#L-"@T*("`@("\J*@T*("`@("`J(%!%05)?4V]U
M<F-E06YA;'EZ97(@:6YS=&%N8V4-"B`@("`@*B!`=F%R(&]B:F5C=`T*("`@
M("`J+PT*("`@('9A<B`D<V]U<F-E7V%N86QY>F5R(#T@;G5L;#L-"B`@("`O
M*BH-"B`@("`@*B!&;&%G('9A<FEA8FQE('5S960@=&\@;6%R:R!A('9A;&ED
M('!A8VMA9V4@9FEL90T*("`@("`J($!V87(@8F]O;&5A;@T*("`@("`J($!A
M8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D7W9A;&ED4&%C:V%G
M949I;&4[#0H-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!C;VYS=')U8W1O
M<@T*#0H@("`@+RHJ#0H@("`@("H@4$5!4E]#;VUM;VX@8V]N<W1R=6-T;W(-
M"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@4$5!4E]#;VUM;VXH*0T*("`@('L-"B`@("`@("`@<&%R96YT
M.CI014%2*"D[#0H@("`@("`@("1T:&ES+3YC;VYF:6<@/2`F4$5!4E]#;VYF
M:6<Z.G-I;F=L971O;B@I.PT*("`@("`@("`D=&AI<RT^9&5B=6<@/2`D=&AI
M<RT^8V]N9FEG+3YG970H)W9E<F)O<V4G*3L-"B`@("!]#0H-"B`@("`O+R!]
M?7T-"B`@("`O+R![>WL@9&5S=')U8W1O<@T*#0H@("`@+RHJ#0H@("`@("H@
M4$5!4E]#;VUM;VX@9&5S=')U8W1O<@T*("`@("`J#0H@("`@("H@0&%C8V5S
M<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7U!%05)?0V]M;6]N
M*"D-"B`@("![#0H@("`@("`@("\O(&1O97-N)W0@=V]R:R!D=64@=&\@8G5G
M(",Q-#<T-`T*("`@("`@("`O+R1T96UP9FEL97,@/2`D=&AI<RT^7W1E;7!F
M:6QE<SL-"B`@("`@("`@)'1E;7!F:6QE<R`])B`D1TQ/0D%,4ULG7U!%05)?
M0V]M;6]N7W1E;7!F:6QE<R==.PT*("`@("`@("!W:&EL92`H)&9I;&4@/2!A
M<G)A>5]S:&EF="@D=&5M<&9I;&5S*2D@>PT*("`@("`@("`@("`@:68@*$!I
M<U]D:7(H)&9I;&4I*2![#0H@("`@("`@("`@("`@("`@:68@*"%C;&%S<U]E
M>&ES=',H)U-Y<W1E;2<I*2![#0H@("`@("`@("`@("`@("`@("`@(')E<75I
M<F5?;VYC92`G4WES=&5M+G!H<"<[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@(%-Y<W1E;3HZ<FTH87)R87DH)RUR9B<L("1F:6QE*2D[
M#0H@("`@("`@("`@("!](&5L<V5I9B`H9FEL95]E>&ES=',H)&9I;&4I*2![
M#0H@("`@("`@("`@("`@("`@=6YL:6YK*"1F:6QE*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[
M>R!A9&1496UP1FEL92@I#0H-"B`@("`O*BH-"B`@("`@*B!296=I<W1E<B!A
M('1E;7!O<F%R>2!F:6QE(&]R(&1I<F5C=&]R>2X@(%=H96X@=&AE(&1E<W1R
M=6-T;W(@:7,-"B`@("`@*B!E>&5C=71E9"P@86QL(')E9VES=&5R960@=&5M
M<&]R87)Y(&9I;&5S(&%N9"!D:7)E8W1O<FEE<R!A<F4-"B`@("`@*B!R96UO
M=F5D+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`@)&9I;&4@(&YA
M;64@;V8@9FEL92!O<B!D:7)E8W1O<GD-"B`@("`@*@T*("`@("`J($!R971U
M<FX@=F]I9`T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!A9&1496UP1FEL92@D9FEL92D-"B`@("![#0H@
M("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27T9R;VYT96YD)RDI('L-
M"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]&<F]N=&5N9"YP:'`G
M.PT*("`@("`@("!]#0H@("`@("`@(%!%05)?1G)O;G1E;F0Z.F%D9%1E;7!&
M:6QE*"1F:6QE*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@
M;6M$:7)(:65R*"D-"@T*("`@("\J*@T*("`@("`J(%=R87!P97(@=&\@4WES
M=&5M.CIM:T1I<B@I+"!C<F5A=&5S(&$@9&ER96-T;W)Y(&%S('=E;&P@87,-
M"B`@("`@*B!A;GD@;F5C97-S87)Y('!A<F5N="!D:7)E8W1O<FEE<RX-"B`@
M("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@("1D:7(@(&1I<F5C=&]R>2!N
M86UE#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&)O;VP@5%)512!O;B!S=6-C
M97-S+"!O<B!A(%!%05(@97)R;W(-"B`@("`@*@T*("`@("`J($!A8V-E<W,@
M<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@;6M$:7)(:65R*"1D:7(I
M#0H@("`@>PT*("`@("`@("`D=&AI<RT^;&]G*#(L("(K(&-R96%T92!D:7(@
M)&1I<B(I.PT*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4WES=&5M)RDI
M('L-"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4WES=&5M+G!H<"<[#0H@
M("`@("`@('T-"B`@("`@("`@<F5T=7)N(%-Y<W1E;3HZ;6M$:7(H87)R87DH
M)RUP)RP@)&1I<BDI.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[
M>R!L;V<H*0T*#0H@("`@+RHJ#0H@("`@("H@3&]G9VEN9R!M971H;V0N#0H@
M("`@("H-"B`@("`@*B!`<&%R86T@:6YT("`@("1L979E;"`@;&]G(&QE=F5L
M("@P(&ES('%U:65T+"!H:6=H97(@:7,@;F]I<VEE<BD-"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1M<V<@("`@;65S<V%G92!T;R!W<FET92!T;R!T:&4@;&]G
M#0H@("`@("H-"B`@("`@*B!`<F5T=7)N('9O:60-"B`@("`@*@T*("`@("`J
M($!A8V-E<W,@<'5B;&EC#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@
M(&9U;F-T:6]N(&QO9R@D;&5V96PL("1M<V<L("1A<'!E;F1?8W)L9B`]('1R
M=64I#0H@("`@>PT*("`@("`@("!I9B`H)'1H:7,M/F1E8G5G(#X]("1L979E
M;"D@>PT*("`@("`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?1G)O
M;G1E;F0G*2D@>PT*("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!
M4B]&<F]N=&5N9"YP:'`G.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M)'5I(#T@)E!%05)?1G)O;G1E;F0Z.G-I;F=L971O;B@I.PT*("`@("`@("`@
M("`@:68@*&ES7V$H)'5I+"`G4$5!4E]&<F]N=&5N9"<I*2![#0H@("`@("`@
M("`@("`@("`@)'5I+3YL;V<H)&US9RP@)&%P<&5N9%]C<FQF*3L-"B`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@<')I;G0@(B1M<V=<
M;B([#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O
M+R!]?7T-"B`@("`O+R![>WL@;6M496UP1&ER*"D-"@T*("`@("\J*@T*("`@
M("`J($-R96%T92!A;F0@<F5G:7-T97(@82!T96UP;W)A<GD@9&ER96-T;W)Y
M+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`D=&UP9&ER("AO<'1I
M;VYA;"D@1&ER96-T;W)Y('1O('5S92!A<R!T;7!D:7(N#0H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@(%=I;&P@=7-E('-Y<W1E;2!D969A=6QT<R`H
M9F]R(&5X86UP;&4-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@+W1M
M<"!O<B!C.EQW:6YD;W=S7'1E;7`I(&EF(&YO="!S<&5C:69I960-"B`@("`@
M*@T*("`@("`J($!R971U<FX@<W1R:6YG(&YA;64@;V8@8W)E871E9"!D:7)E
M8W1O<GD-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@;6M496UP1&ER*"1T;7!D:7(@/2`G)RD-"B`@("![
M#0H@("`@("`@(&EF("@D=&UP9&ER*2![#0H@("`@("`@("`@("`D=&]P="`]
M(&%R<F%Y*"<M="<L("1T;7!D:7(I.PT*("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@)'1O<'0@/2!A<G)A>2@I.PT*("`@("`@("!]#0H@("`@("`@
M("1T;W!T(#T@87)R87E?;65R9V4H)'1O<'0L(&%R<F%Y*"<M9"<L("=P96%R
M)RDI.PT*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4WES=&5M)RDI('L-
M"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4WES=&5M+G!H<"<[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"$D=&UP9&ER(#T@4WES=&5M.CIM:W1E;7`H
M)'1O<'0I*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@
M('T-"B`@("`@("`@)'1H:7,M/F%D9%1E;7!&:6QE*"1T;7!D:7(I.PT*("`@
M("`@("!R971U<FX@)'1M<&1I<CL-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@
M("`O+R![>WL@<V5T1G)O;G1E;F1/8FIE8W0H*0T*#0H@("`@+RHJ#0H@("`@
M("H@4V5T(&]B:F5C="!T:&%T(')E<')E<V5N=',@=&AE(&9R;VYT96YD('1O
M(&)E('5S960N#0H@("`@("H-"B`@("`@*B!`<&%R86T@(&]B:F5C="!2969E
M<F5N8V4@;V8@=&AE(&9R;VYT96YD(&]B:F5C=`T*("`@("`J($!R971U<FX@
M=F]I9`T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@<V5T1G)O;G1E;F1/8FIE8W0H)B1U:2D-"B`@("![#0H@("`@("`@
M("1T:&ES+3YU:2`]("8D=6D[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-"B`@
M("`O+R![>WL@:6YF;T9R;VU49WI&:6QE*"D-"@T*("`@("\J*@T*("`@("`J
M(%)E='5R;G,@:6YF;W)M871I;VX@86)O=70@82!P86-K86=E(&9I;&4N("!%
M>'!E8W1S('1H92!N86UE(&]F#0H@("`@("H@82!G>FEP<&5D('1A<B!F:6QE
M(&%S(&EN<'5T+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`@)&9I
M;&4@(&YA;64@;V8@+G1G>B!F:6QE#0H@("`@("H-"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("!A<G)A>2!W:71H('!A8VMA9V4@:6YF;W)M871I;VX-"B`@("`@
M*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H@0&1E<')E8V%T960@
M=7-E(%!%05)?4&%C:V%G949I;&4M/F9R;VU49WI&:6QE*"D@:6YS=&5A9`T*
M("`@("`J#0H@("`@("HO#0H@("`@9G5N8W1I;VX@:6YF;T9R;VU49WI&:6QE
M*"1F:6QE*0T*("`@('L-"B`@("`@("`@)'!A8VMA9V5F:6QE(#T@)FYE=R!0
M14%27U!A8VMA9V5&:6QE*"1T:&ES+3YC;VYF:6<I.PT*("`@("`@("`D<&8@
M/2`F)'!A8VMA9V5F:6QE+3YF<F]M5&=Z1FEL92@D9FEL92P@4$5!4E]604Q)
M1$%415].3U)-04PI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<&8I
M*2![#0H@("`@("`@("`@("`D97)R<R`]("1P9BT^9V5T57-E<FEN9F\H*3L-
M"B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D97)R<RDI('L-"B`@("`@("`@
M("`@("`@("!F;W)E86-H("@D97)R<R!A<R`D97)R;W(I('L-"B`@("`@("`@
M("`@("`@("`@("`@)&4@/2`D=&AI<RT^<F%I<V5%<G)O<B@D97)R;W);)VUE
M<W-A9V4G72P@)&5R<F]R6R=C;V1E)UTL(&YU;&PL(&YU;&PL("1E<G)O<BD[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@<F5T=7)N("1P9CL-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'1H
M:7,M/E]P;W-T4')O8V5S<U9A;&ED4&%C:V%G97AM;"@D<&8I.PT*("`@('T-
M"@T*("`@("\O('U]?0T*("`@("\O('M[>R!I;F9O1G)O;41E<V-R:7!T:6]N
M1FEL92@I#0H-"B`@("`O*BH-"B`@("`@*B!2971U<FYS(&EN9F]R;6%T:6]N
M(&%B;W5T(&$@<&%C:V%G92!F:6QE+B`@17AP96-T<R!T:&4@;F%M92!O9@T*
M("`@("`J(&$@<&%C:V%G92!X;6P@9FEL92!A<R!I;G!U="X-"B`@("`@*@T*
M("`@("`J($!P87)A;2!S=')I;F<@("1D97-C9FEL92`@;F%M92!O9B!P86-K
M86=E('AM;"!F:6QE#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!A
M<G)A>2!W:71H('!A8VMA9V4@:6YF;W)M871I;VX-"B`@("`@*@T*("`@("`J
M($!A8V-E<W,@<'5B;&EC#0H@("`@("H@0&1E<')E8V%T960@=7-E(%!%05)?
M4&%C:V%G949I;&4M/F9R;VU086-K86=E1FEL92@I(&EN<W1E860-"B`@("`@
M*@T*("`@("`J+PT*("`@(&9U;F-T:6]N(&EN9F]&<F]M1&5S8W)I<'1I;VY&
M:6QE*"1D97-C9FEL92D-"B`@("![#0H@("`@("`@("1P86-K86=E9FEL92`]
M("9N97<@4$5!4E]086-K86=E1FEL92@D=&AI<RT^8V]N9FEG*3L-"B`@("`@
M("`@)'!F(#T@)B1P86-K86=E9FEL92T^9G)O;5!A8VMA9V5&:6QE*"1D97-C
M9FEL92P@4$5!4E]604Q)1$%415].3U)-04PI.PT*("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D<&8I*2![#0H@("`@("`@("`@("`D97)R<R`]("1P9BT^
M9V5T57-E<FEN9F\H*3L-"B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D97)R
M<RDI('L-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D97)R<R!A<R`D97)R
M;W(I('L-"B`@("`@("`@("`@("`@("`@("`@)&4@/2`D=&AI<RT^<F%I<V5%
M<G)O<B@D97)R;W);)VUE<W-A9V4G72P@)&5R<F]R6R=C;V1E)UTL(&YU;&PL
M(&YU;&PL("1E<G)O<BD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@<F5T=7)N("1P9CL-"B`@("`@("`@?0T*("`@
M("`@("!R971U<FX@)'1H:7,M/E]P;W-T4')O8V5S<U9A;&ED4&%C:V%G97AM
M;"@D<&8I.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!I;F9O
M1G)O;5-T<FEN9R@I#0H-"B`@("`O*BH-"B`@("`@*B!2971U<FYS(&EN9F]R
M;6%T:6]N(&%B;W5T(&$@<&%C:V%G92!F:6QE+B`@17AP96-T<R!T:&4@8V]N
M=&5N=',-"B`@("`@*B!O9B!A('!A8VMA9V4@>&UL(&9I;&4@87,@:6YP=70N
M#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("`D9&%T82`@8V]N=&5N
M=',@;V8@<&%C:V%G92YX;6P@9FEL90T*("`@("`J#0H@("`@("H@0')E='5R
M;B!A<G)A>2`@(&%R<F%Y('=I=&@@<&%C:V%G92!I;F9O<FUA=&EO;@T*("`@
M("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`9&5P<F5C871E
M9"!U<V4@4$5!4E]086-K86=E1FEL92T^9G)O;5AM;'-T<FEN9R@I(&EN<W1E
M860-"B`@("`@*@T*("`@("`J+PT*("`@(&9U;F-T:6]N(&EN9F]&<F]M4W1R
M:6YG*"1D871A*0T*("`@('L-"B`@("`@("`@)'!A8VMA9V5F:6QE(#T@)FYE
M=R!014%27U!A8VMA9V5&:6QE*"1T:&ES+3YC;VYF:6<I.PT*("`@("`@("`D
M<&8@/2`F)'!A8VMA9V5F:6QE+3YF<F]M6&UL4W1R:6YG*"1D871A+"!014%2
M7U9!3$E$051%7TY/4DU!3"P@9F%L<V4I.PT*("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D<&8I*2![#0H@("`@("`@("`@("`D97)R<R`]("1P9BT^9V5T
M57-E<FEN9F\H*3L-"B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D97)R<RDI
M('L-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D97)R<R!A<R`D97)R;W(I
M('L-"B`@("`@("`@("`@("`@("`@("`@)&4@/2`D=&AI<RT^<F%I<V5%<G)O
M<B@D97)R;W);)VUE<W-A9V4G72P@)&5R<F]R6R=C;V1E)UTL(&YU;&PL(&YU
M;&PL("1E<G)O<BD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@<F5T=7)N("1P9CL-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@)'1H:7,M/E]P;W-T4')O8V5S<U9A;&ED4&%C:V%G97AM;"@D
M<&8I.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\J*@T*("`@("`J($!P
M87)A;2!014%27U!A8VMA9V5&:6QE7W8Q?%!%05)?4&%C:V%G949I;&5?=C(-
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M7W!O<W10<F]C97-S5F%L:61086-K86=E>&UL*"8D<&8I#0H@("`@>PT*("`@
M("`@("!I9B`H:7-?82@D<&8L("=014%27U!A8VMA9V5&:6QE7W8R)RDI('L-
M"B`@("`@("`@("`@("\O('-O<G0@;V8@;6%K92!T:&ES(&EN=&\@82!P86-K
M86=E+GAM;"`Q+C`M<W1Y;&4@87)R87D-"B`@("`@("`@("`@("\O(&-H86YG
M96QO9R!I<R!N;W0@8V]N=F5R=&5D('1O(&]L9"!F;W)M870N#0H@("`@("`@
M("`@("`D87)R(#T@)'!F+3YT;T%R<F%Y*'1R=64I.PT*("`@("`@("`@("`@
M)&%R<B`](&%R<F%Y7VUE<F=E*"1A<G(L("1A<G);)V]L9"==*3L-"B`@("`@
M("`@("`@('5N<V5T*"1A<G);)V]L9"==*3L-"B`@("`@("`@("`@('5N<V5T
M*"1A<G);)WAS9'9E<G-I;VXG72D[#0H@("`@("`@("`@("!U;G-E="@D87)R
M6R=C;VYT96YT<R==*3L-"B`@("`@("`@("`@('5N<V5T*"1A<G);)V-O;7!A
M=&EB;&4G72D[#0H@("`@("`@("`@("!U;G-E="@D87)R6R=C:&%N;F5L)UTI
M.PT*("`@("`@("`@("`@=6YS970H)&%R<ELG=7)I)UTI.PT*("`@("`@("`@
M("`@=6YS970H)&%R<ELG9&5P96YD96YC:65S)UTI.PT*("`@("`@("`@("`@
M=6YS970H)&%R<ELG<&AP<F5L96%S92==*3L-"B`@("`@("`@("`@('5N<V5T
M*"1A<G);)V5X='-R8W)E;&5A<V4G72D[#0H@("`@("`@("`@("!U;G-E="@D
M87)R6R=E>'1B:6YR96QE87-E)UTI.PT*("`@("`@("`@("`@=6YS970H)&%R
M<ELG8G5N9&QE)UTI.PT*("`@("`@("`@("`@=6YS970H)&%R<ELG;&5A9"==
M*3L-"B`@("`@("`@("`@('5N<V5T*"1A<G);)V1E=F5L;W!E<B==*3L-"B`@
M("`@("`@("`@('5N<V5T*"1A<G);)VAE;'!E<B==*3L-"B`@("`@("`@("`@
M('5N<V5T*"1A<G);)V-O;G1R:6)U=&]R)UTI.PT*("`@("`@("`@("`@)&%R
M<ELG9FEL96QI<W0G72`]("1P9BT^9V5T1FEL96QI<W0H*3L-"B`@("`@("`@
M("`@("1T:&ES+3YP:V=I;F9O(#T@)&%R<CL-"B`@("`@("`@("`@(')E='5R
M;B`D87)R.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'1H:7,M
M/G!K9VEN9F\@/2`D<&8M/G1O07)R87DH*3L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<&MG:6YF;SL-"B`@("`@("`@?0T*("`@('T-"B`@("`O+R![
M>WL@:6YF;T9R;VU!;GDH*0T*#0H@("`@+RHJ#0H@("`@("H@4F5T=7)N<R!P
M86-K86=E(&EN9F]R;6%T:6]N(&9R;VT@9&EF9F5R96YT('-O=7)C97,-"B`@
M("`@*@T*("`@("`J(%1H:7,@;65T:&]D(&ES(&%B;&4@=&\@97AT<F%C="!I
M;F9O<FUA=&EO;B!A8F]U="!A('!A8VMA9V4-"B`@("`@*B!F<F]M(&$@+G1G
M>B!A<F-H:79E(&]R(&9R;VT@82!834P@<&%C:V%G92!D969I;FET:6]N(&9I
M;&4N#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J($!P
M87)A;2`@<W1R:6YG($9I;&5N86UE(&]F('1H92!S;W5R8V4@*"=P86-K86=E
M+GAM;"<L("<\<&%C:V%G93XN=&=Z)RD-"B`@("`@*B!`<F5T=7)N('-T<FEN
M9PT*("`@("`J($!D97!R96-A=&5D('5S92!014%27U!A8VMA9V5&:6QE+3YF
M<F]M06YY1FEL92@I(&EN<W1E860-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!I
M;F9O1G)O;4%N>2@D:6YF;RD-"B`@("![#0H@("`@("`@(&EF("AI<U]S=')I
M;F<H)&EN9F\I("8F(&9I;&5?97AI<W1S*"1I;F9O*2D@>PT*("`@("`@("`@
M("`@)'!A8VMA9V5F:6QE(#T@)FYE=R!014%27U!A8VMA9V5&:6QE*"1T:&ES
M+3YC;VYF:6<I.PT*("`@("`@("`@("`@)'!F(#T@)B1P86-K86=E9FEL92T^
M9G)O;4%N>49I;&4H)&EN9F\L(%!%05)?5D%,241!5$5?3D]234%,*3L-"B`@
M("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1P9BDI('L-"B`@("`@("`@
M("`@("`@("`D97)R<R`]("1P9BT^9V5T57-E<FEN9F\H*3L-"B`@("`@("`@
M("`@("`@("!I9B`H:7-?87)R87DH)&5R<G,I*2![#0H@("`@("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1E<G)S(&%S("1E<G)O<BD@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)&4@/2`D=&AI<RT^<F%I<V5%<G)O<B@D97)R;W);
M)VUE<W-A9V4G72P@)&5R<F]R6R=C;V1E)UTL(&YU;&PL(&YU;&PL("1E<G)O
M<BD[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@<F5T=7)N("1P9CL-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!O<W10<F]C97-S5F%L:610
M86-K86=E>&UL*"1P9BD[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1I
M;F9O.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!X;6Q&<F]M
M26YF;R@I#0H-"B`@("`O*BH-"B`@("`@*B!2971U<FX@86X@6$U,(&1O8W5M
M96YT(&)A<V5D(&]N('1H92!P86-K86=E(&EN9F\@*&%S(')E='5R;F5D#0H@
M("`@("H@8GD@=&AE(%!%05)?0V]M;6]N.CII;F9O1G)O;2H@;65T:&]D<RDN
M#0H@("`@("H-"B`@("`@*B!`<&%R86T@87)R87D@("1P:V=I;F9O("!P86-K
M86=E(&EN9F\-"B`@("`@*@T*("`@("`J($!R971U<FX@<W1R:6YG(%A-3"!D
M871A#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J($!D
M97!R96-A=&5D('5S92!A(%!%05)?4&%C:V%G949I;&5?=BH@;V)J96-T)W,@
M9V5N97)A=&]R(&EN<W1E860-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!X;6Q&
M<F]M26YF;R@D<&MG:6YF;RD-"B`@("![#0H@("`@("`@("1C;VYF:6<@/2`F
M4$5!4E]#;VYF:6<Z.G-I;F=L971O;B@I.PT*("`@("`@("`D<&%C:V%G969I
M;&4@/2`F;F5W(%!%05)?4&%C:V%G949I;&4H)&-O;F9I9RD[#0H@("`@("`@
M("1P9B`]("8D<&%C:V%G969I;&4M/F9R;VU!<G)A>2@D<&MG:6YF;RD[#0H@
M("`@("`@("1G96X@/2`F)'!F+3YG971$969A=6QT1V5N97)A=&]R*"D[#0H@
M("`@("`@(')E='5R;B`D9V5N+3YT;UAM;"A014%27U9!3$E$051%7U!!0TM!
M1TE.1RD[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[('9A;&ED
M871E4&%C:V%G94EN9F\H*0T*#0H@("`@+RHJ#0H@("`@("H@5F%L:61A=&4@
M6$U,('!A8VMA9V4@9&5F:6YI=&EO;B!F:6QE+@T*("`@("`J#0H@("`@("H@
M0'!A<F%M("!S=')I;F<@)&EN9F\@1FEL96YA;64@;V8@=&AE('!A8VMA9V4@
M87)C:&EV92!O<B!O9B!T:&4-"B`@("`@*B`@("`@("`@("`@("`@("!P86-K
M86=E(&1E9FEN:71I;VX@9FEL90T*("`@("`J($!P87)A;2`@87)R87D@)&5R
M<F]R<R!!<G)A>2!T:&%T('=I;&P@8V]N=&%I;B!T:&4@97)R;W)S#0H@("`@
M("H@0'!A<F%M("!A<G)A>2`D=V%R;FEN9W,@07)R87D@=&AA="!W:6QL(&-O
M;G1A:6X@=&AE('=A<FYI;F=S#0H@("`@("H@0'!A<F%M("!S=')I;F<@)&1I
M<E]P<F5F:7@@*&]P=&EO;F%L*2!D:7)E8W1O<GD@=VAE<F4@<V]U<F-E(&9I
M;&5S#0H@("`@("H@("`@("`@("`@("`@("`@;6%Y(&)E(&9O=6YD+"!O<B!E
M;7!T>2!I9B!T:&5Y(&%R92!N;W0@879A:6QA8FQE#0H@("`@("H@0&%C8V5S
M<R!P=6)L:6,-"B`@("`@*B!`<F5T=7)N(&)O;VQE86X-"B`@("`@*B!`9&5P
M<F5C871E9"!U<V4@=&AE('9A;&ED871I;VX@;V8@4$5!4E]086-K86=E1FEL
M92!O8FIE8W1S#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=F%L:61A=&5086-K
M86=E26YF;R@D:6YF;RP@)B1E<G)O<G,L("8D=V%R;FEN9W,L("1D:7)?<')E
M9FEX(#T@)R<I#0H@("`@>PT*("`@("`@("`D8V]N9FEG(#T@)E!%05)?0V]N
M9FEG.CIS:6YG;&5T;VXH*3L-"B`@("`@("`@)'!A8VMA9V5F:6QE(#T@)FYE
M=R!014%27U!A8VMA9V5&:6QE*"1C;VYF:6<I.PT*("`@("`@("!014%2.CIS
M=&%T:6-0=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@
M("`@("`@(&EF("AS=')P;W,H)&EN9F\L("<\/WAM;"<I("$]/2!F86QS92D@
M>PT*("`@("`@("`@("`@)'!F(#T@)B1P86-K86=E9FEL92T^9G)O;5AM;%-T
M<FEN9R@D:6YF;RP@4$5!4E]604Q)1$%415].3U)-04PL("<G*3L-"B`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("1P9B`]("8D<&%C:V%G969I;&4M
M/F9R;VU!;GE&:6QE*"1I;F9O+"!014%27U9!3$E$051%7TY/4DU!3"D[#0H@
M("`@("`@('T-"B`@("`@("`@4$5!4CHZ<W1A=&EC4&]P17)R;W)(86YD;&EN
M9R@I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<&8I*2![#0H@("`@
M("`@("`@("`D97)R<R`]("1P9BT^9V5T57-E<FEN9F\H*3L-"B`@("`@("`@
M("`@(&EF("AI<U]A<G)A>2@D97)R<RDI('L-"B`@("`@("`@("`@("`@("!F
M;W)E86-H("@D97)R<R!A<R`D97)R;W(I('L-"B`@("`@("`@("`@("`@("`@
M("`@:68@*"1E<G)O<ELG;&5V96PG72`]/2`G97)R;W(G*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D97)R;W)S6UT@/2`D97)R;W);)VUE<W-A9V4G
M73L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1W87)N:6YG<UM=(#T@)&5R<F]R6R=M97-S86=E)UT[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@
M?7U]#0H@("`@+R\@>WM[(&)U:6QD4')O=FED97-!<G)A>2@I#0H-"B`@("`O
M*BH-"B`@("`@*B!"=6EL9"!A(")P<F]V:61E<R(@87)R87D@9G)O;2!D871A
M(')E='5R;F5D(&)Y#0H@("`@("H@86YA;'EZ95-O=7)C94-O9&4H*2X@(%1H
M92!F;W)M870@;V8@=&AE(&)U:6QT(&%R<F%Y(&ES(&QI:V4-"B`@("`@*B!T
M:&ES.@T*("`@("`J#0H@("`@("H@(&%R<F%Y*`T*("`@("`J("`@("=C;&%S
M<SM->4-L87-S)R`]/B`G87)R87DH)W1Y<&4G(#T^("=C;&%S<R<L("=N86UE
M)R`]/B`G37E#;&%S<R<I+`T*("`@("`J("`@("XN+@T*("`@("`J("`I#0H@
M("`@("H-"B`@("`@*@T*("`@("`J($!P87)A;2!A<G)A>2`D<W)C:6YF;R!A
M<G)A>2!W:71H(&EN9F]R;6%T:6]N(&%B;W5T(&$@<V]U<F-E(&9I;&4-"B`@
M("`@*B!A<R!R971U<FYE9"!B>2!T:&4@86YA;'EZ95-O=7)C94-O9&4H*2!M
M971H;V0N#0H@("`@("H-"B`@("`@*B!`<F5T=7)N('9O:60-"B`@("`@*@T*
M("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!B=6EL9%!R;W9I9&5S07)R87DH)'-R8VEN9F\I#0H@("`@>PT*
M("`@("`@("`D9FEL92`](&)A<V5N86UE*"1S<F-I;F9O6R=S;W5R8V5?9FEL
M92==*3L-"B`@("`@("`@)'!N(#T@)R<[#0H@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7W!A8VMA9V5.86UE*2D@>PT*("`@("`@("`@("`@)'!N(#T@)'1H
M:7,M/E]P86-K86=E3F%M93L-"B`@("`@("`@?0T*("`@("`@("`D<&YL(#T@
M<W1R;&5N*"1P;BD[#0H@("`@("`@(&9O<F5A8V@@*"1S<F-I;F9O6R=D96-L
M87)E9%]C;&%S<V5S)UT@87,@)&-L87-S*2![#0H@("`@("`@("`@("`D:V5Y
M(#T@(F-L87-S.R1C;&%S<R([#0H@("`@("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/G!K9VEN9F];)W!R;W9I9&5S)UU;)&ME>5TI*2![#0H@("`@("`@("`@
M("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D
M=&AI<RT^<&MG:6YF;ULG<')O=FED97,G75LD:V5Y72`]#0H@("`@("`@("`@
M("`@("`@87)R87DH)V9I;&4G/3X@)&9I;&4L("=T>7!E)R`]/B`G8VQA<W,G
M+"`G;F%M92<@/3X@)&-L87-S*3L-"B`@("`@("`@("`@(&EF("AI<W-E="@D
M<W)C:6YF;ULG:6YH97)I=&%N8V4G75LD8VQA<W-=*2D@>PT*("`@("`@("`@
M("`@("`@("1T:&ES+3YP:V=I;F9O6R=P<F]V:61E<R==6R1K97E=6R=E>'1E
M;F1S)UT@/0T*("`@("`@("`@("`@("`@("`@("`D<W)C:6YF;ULG:6YH97)I
M=&%N8V4G75LD8VQA<W-=.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@(&9O<F5A8V@@*"1S<F-I;F9O6R=D96-L87)E9%]M971H;V1S)UT@
M87,@)&-L87-S(#T^("1M971H;V1S*2![#0H@("`@("`@("`@("!F;W)E86-H
M("@D;65T:&]D<R!A<R`D;65T:&]D*2![#0H@("`@("`@("`@("`@("`@)&9U
M;F-T:6]N(#T@(B1C;&%S<SHZ)&UE=&AO9"([#0H@("`@("`@("`@("`@("`@
M)&ME>2`](")F=6YC=&EO;CLD9G5N8W1I;VXB.PT*("`@("`@("`@("`@("`@
M(&EF("@D;65T:&]D>S!](#T]("=?)R!\?"`A<W1R8V%S96-M<"@D;65T:&]D
M+"`D8VQA<W,I('Q\#0H@("`@("`@("`@("`@("`@("`@(&ES<V5T*"1T:&ES
M+3YP:V=I;F9O6R=P<F]V:61E<R==6R1K97E=*2D@>PT*("`@("`@("`@("`@
M("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@)'1H:7,M/G!K9VEN9F];)W!R;W9I9&5S)UU;)&ME>5T@/0T*
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@G9FEL92<]/B`D9FEL92P@)W1Y
M<&4G(#T^("=F=6YC=&EO;B<L("=N86UE)R`]/B`D9G5N8W1I;VXI.PT*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H-"B`@("`@("`@9F]R96%C:"`H)'-R
M8VEN9F];)V1E8VQA<F5D7V9U;F-T:6]N<R==(&%S("1F=6YC=&EO;BD@>PT*
M("`@("`@("`@("`@)&ME>2`](")F=6YC=&EO;CLD9G5N8W1I;VXB.PT*("`@
M("`@("`@("`@:68@*"1F=6YC=&EO;GLP?2`]/2`G7R<@?'P@:7-S970H)'1H
M:7,M/G!K9VEN9F];)W!R;W9I9&5S)UU;)&ME>5TI*2![#0H@("`@("`@("`@
M("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I
M9B`H(7-T<G-T<B@D9G5N8W1I;VXL("<Z.B<I("8F('-T<FYC87-E8VUP*"1F
M=6YC=&EO;BP@)'!N+"`D<&YL*2D@>PT*("`@("`@("`@("`@("`@("1W87)N
M:6YG<UM=(#T@(FEN,2`B("X@)&9I;&4@+B`B.B!F=6YC=&EO;B!<(B1F=6YC
M=&EO;EPB(&YO="!P<F5F:7AE9"!W:71H('!A8VMA9V4@;F%M92!<(B1P;EPB
M(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1T:&ES+3YP:V=I;F9O
M6R=P<F]V:61E<R==6R1K97E=(#T-"B`@("`@("`@("`@("`@("!A<G)A>2@G
M9FEL92<]/B`D9FEL92P@)W1Y<&4G(#T^("=F=6YC=&EO;B<L("=N86UE)R`]
M/B`D9G5N8W1I;VXI.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0H@("`@+R\@>WM[(&%N86QY>F53;W5R8V5#;V1E*"D-"@T*("`@("\J*@T*
M("`@("`J($%N86QY>F4@=&AE('-O=7)C92!C;V1E(&]F('1H92!G:79E;B!0
M2%`@9FEL90T*("`@("`J#0H@("`@("H@0'!A<F%M("!S=')I;F<@1FEL96YA
M;64@;V8@=&AE(%!(4"!F:6QE#0H@("`@("H@0')E='5R;B!M:7AE9`T*("`@
M("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@86YA
M;'EZ95-O=7)C94-O9&4H)&9I;&4I#0H@("`@>PT*("`@("`@("!I9B`H(69U
M;F-T:6]N7V5X:7-T<R@B=&]K96Y?9V5T7V%L;"(I*2![#0H@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%D969I
M;F5D*"=47T1/0U]#3TU-14Y4)RDI('L-"B`@("`@("`@("`@(&1E9FEN92@G
M5%]$3T-?0T]-345.5"<L(%1?0T]-345.5"D[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*"%D969I;F5D*"=47TE.5$521D%#12<I*2![#0H@("`@("`@("`@
M("!D969I;F4H)U1?24Y415)&04-%)RP@+3$I.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("@A9&5F:6YE9"@G5%])35!,14U%3E13)RDI('L-"B`@("`@("`@
M("`@(&1E9FEN92@G5%])35!,14U%3E13)RP@+3$I.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@A)&9P(#T@0&9O<&5N*"1F:6QE+"`B<B(I*2![#0H@("`@
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*&9U;F-T:6]N7V5X:7-T<R@G9FEL95]G971?8V]N=&5N=',G*2D@>PT*("`@
M("`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@("`@("`D8V]N=&5N=',@
M/2!F:6QE7V=E=%]C;VYT96YT<R@D9FEL92D[#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`D8V]N=&5N=',@/2!F<F5A9"@D9G`L(&9I;&5S:7IE
M*"1F:6QE*2D[#0H@("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@
M?0T*("`@("`@("`D=&]K96YS(#T@=&]K96Y?9V5T7V%L;"@D8V]N=&5N=',I
M.PT*+RH-"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F*"1T;VME
M;G,I.R`D:2LK*2![#0H@("`@("`@("`@("!`;&ES="@D=&]K96XL("1D871A
M*2`]("1T;VME;G-;)&E=.PT*("`@("`@("`@("`@:68@*&ES7W-T<FEN9R@D
M=&]K96XI*2![#0H@("`@("`@("`@("`@("`@=F%R7V1U;7`H)'1O:V5N*3L-
M"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@<')I;G0@
M=&]K96Y?;F%M92@D=&]K96XI("X@)R`G.PT*("`@("`@("`@("`@("`@('9A
M<E]D=6UP*')T<FEM*"1D871A*2D[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"BHO#0H@("`@("`@("1L;V]K7V9O<B`](#`[#0H@("`@("`@("1P87)E
M;E]L979E;"`](#`[#0H@("`@("`@("1B<F%C:V5T7VQE=F5L(#T@,#L-"B`@
M("`@("`@)&)R86-E7VQE=F5L(#T@,#L-"B`@("`@("`@)&QA<W1P:'!D;V,@
M/2`G)SL-"B`@("`@("`@)&-U<G)E;G1?8VQA<W,@/2`G)SL-"B`@("`@("`@
M)&-U<G)E;G1?:6YT97)F86-E(#T@)R<[#0H@("`@("`@("1C=7)R96YT7V-L
M87-S7VQE=F5L(#T@+3$[#0H@("`@("`@("1C=7)R96YT7V9U;F-T:6]N(#T@
M)R<[#0H@("`@("`@("1C=7)R96YT7V9U;F-T:6]N7VQE=F5L(#T@+3$[#0H@
M("`@("`@("1D96-L87)E9%]C;&%S<V5S(#T@87)R87DH*3L-"B`@("`@("`@
M)&1E8VQA<F5D7VEN=&5R9F%C97,@/2!A<G)A>2@I.PT*("`@("`@("`D9&5C
M;&%R961?9G5N8W1I;VYS(#T@87)R87DH*3L-"B`@("`@("`@)&1E8VQA<F5D
M7VUE=&AO9',@/2!A<G)A>2@I.PT*("`@("`@("`D=7-E9%]C;&%S<V5S(#T@
M87)R87DH*3L-"B`@("`@("`@)'5S961?9G5N8W1I;VYS(#T@87)R87DH*3L-
M"B`@("`@("`@)&5X=&5N9',@/2!A<G)A>2@I.PT*("`@("`@("`D:6UP;&5M
M96YT<R`](&%R<F%Y*"D[#0H@("`@("`@("1N;V1E<',@/2!A<G)A>2@I.PT*
M("`@("`@("`D:6YQ=6]T92`](&9A;'-E.PT*("`@("`@("`D:6YT97)F86-E
M(#T@9F%L<V4[#0H@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D
M=&]K96YS*3L@)&DK*RD@>PT*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1T
M;VME;G-;)&E=*2D@>PT*("`@("`@("`@("`@("`@(&QI<W0H)'1O:V5N+"`D
M9&%T82D@/2`D=&]K96YS6R1I73L-"B`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@)'1O:V5N(#T@)'1O:V5N<ULD:5T[#0H@("`@("`@
M("`@("`@("`@)&1A=&$@/2`G)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(&EF("@D:6YQ=6]T92D@>PT*("`@("`@("`@("`@("`@(&EF("@D=&]K
M96X@(3T@)R(G*2![#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*
M("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@
M("1I;G%U;W1E(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('-W:71C:"`H)'1O:V5N*2![#0H@("`@("`@("`@("`@("`@8V%S
M92!47U=(251%4U!!0T4Z#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PT*("`@("`@("`@("`@("`@(&-A<V4@)SLG.@T*("`@("`@("`@("`@("`@
M("`@("!I9B`H)&EN=&5R9F%C92D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)&-U<G)E;G1?9G5N8W1I;VX@/2`G)SL-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1C=7)R96YT7V9U;F-T:6]N7VQE=F5L(#T@+3$[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@
M("`@("`@("`@("`@("`@8V%S92`G(B<Z#0H@("`@("`@("`@("`@("`@("`@
M("1I;G%U;W1E(#T@=')U93L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[
M#0H@("`@("`@("`@("`@("`@8V%S92!47T-54DQ97T]014XZ#0H@("`@("`@
M("`@("`@("`@8V%S92!47T1/3$Q!4E]/4$5.7T-54DQ97T)204-%4SH-"B`@
M("`@("`@("`@("`@("!C87-E("=[)SH@)&)R86-E7VQE=F5L*RL[(&-O;G1I
M;G5E(#([#0H@("`@("`@("`@("`@("`@8V%S92`G?2<Z#0H@("`@("`@("`@
M("`@("`@("`@("1B<F%C95]L979E;"TM.PT*("`@("`@("`@("`@("`@("`@
M("!I9B`H)&-U<G)E;G1?8VQA<W-?;&5V96P@/3T@)&)R86-E7VQE=F5L*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=%]C;&%S<R`]("<G
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E;G1?8VQA<W-?;&5V
M96P@/2`M,3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("!I9B`H)&-U<G)E;G1?9G5N8W1I;VY?;&5V96P@/3T@)&)R86-E
M7VQE=F5L*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=%]F
M=6YC=&EO;B`]("<G.PT*("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E
M;G1?9G5N8W1I;VY?;&5V96P@/2`M,3L-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU92`R.PT*("`@("`@("`@
M("`@("`@(&-A<V4@)ULG.B`D8G)A8VME=%]L979E;"LK.R!C;VYT:6YU92`R
M.PT*("`@("`@("`@("`@("`@(&-A<V4@)UTG.B`D8G)A8VME=%]L979E;"TM
M.R!C;VYT:6YU92`R.PT*("`@("`@("`@("`@("`@(&-A<V4@)R@G.B`D<&%R
M96Y?;&5V96PK*SL@("!C;VYT:6YU92`R.PT*("`@("`@("`@("`@("`@(&-A
M<V4@)RDG.B`D<&%R96Y?;&5V96PM+3L@("!C;VYT:6YU92`R.PT*("`@("`@
M("`@("`@("`@(&-A<V4@5%])3E1%4D9!0T4Z#0H@("`@("`@("`@("`@("`@
M("`@("1I;G1E<F9A8V4@/2!T<G5E.PT*("`@("`@("`@("`@("`@(&-A<V4@
M5%]#3$%34SH-"B`@("`@("`@("`@("`@("`@("`@:68@*"@D8W5R<F5N=%]C
M;&%S<U]L979E;"`A/2`M,2D@?'P@*"1C=7)R96YT7V9U;F-T:6]N7VQE=F5L
M("$]("TQ*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@4$5!4CHZ<F%I
M<V5%<G)O<B@B4&%R<V5R(&5R<F]R.B!I;G9A;&ED(%!(4"!F;W5N9"!I;B!F
M:6QE(%PB)&9I;&5<(B(L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M4$5!4E]#3TU-3TY?15)23U)?24Y604Q)1%!(4"D[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!C87-E(%1?1E5.0U1)3TXZ#0H@("`@("`@
M("`@("`@("`@8V%S92!47TY%5SH-"B`@("`@("`@("`@("`@("!C87-E(%1?
M15A414Y$4SH-"B`@("`@("`@("`@("`@("!C87-E(%1?24U03$5-14Y44SH-
M"B`@("`@("`@("`@("`@("`@("`@)&QO;VM?9F]R(#T@)'1O:V5N.PT*("`@
M("`@("`@("`@("`@("`@("!C;VYT:6YU92`R.PT*("`@("`@("`@("`@("`@
M(&-A<V4@5%]35%))3D<Z#0H@("`@("`@("`@("`@("`@("`@(&EF("AV97)S
M:6]N7V-O;7!A<F4H>F5N9%]V97)S:6]N*"DL("<R+C`G+"`G/"<I*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H:6Y?87)R87DH<W1R=&]L;W=E
M<B@D9&%T82DL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH
M)W!U8FQI8R<L("=P<FEV871E)RP@)W!R;W1E8W1E9"<L("=A8G-T<F%C="<L
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VEN=&5R9F%C
M92<L("=I;7!L96UE;G1S)RP@)W1H<F]W)RD@#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`I*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@4$5!4CHZ<F%I<V5%<G)O<B@G17)R;W(Z(%!(4#4@=&]K96X@96YC
M;W5N=&5R960@:6X@)R`N("1F:6QE("X@#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W!A8VMA9VEN9R!S:&]U;&0@8F4@9&]N92!I;B!02%`@-2<I
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H)&QO;VM?9F]R(#T](%1?
M0TQ!4U,I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1C=7)R96YT7V-L
M87-S(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@("`@("`@("`D8W5R<F5N
M=%]C;&%S<U]L979E;"`]("1B<F%C95]L979E;#L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1D96-L87)E9%]C;&%S<V5S6UT@/2`D8W5R<F5N=%]C;&%S
M<SL-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1L;V]K7V9O<B`]
M/2!47TE.5$521D%#12D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&-U
M<G)E;G1?:6YT97)F86-E(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D8W5R<F5N=%]C;&%S<U]L979E;"`]("1B<F%C95]L979E;#L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1D96-L87)E9%]I;G1E<F9A8V5S6UT@
M/2`D8W5R<F5N=%]I;G1E<F9A8V4[#0H@("`@("`@("`@("`@("`@("`@('T@
M96QS96EF("@D;&]O:U]F;W(@/3T@5%])35!,14U%3E13*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D:6UP;&5M96YT<ULD8W5R<F5N=%]C;&%S<UT@
M/2`D9&%T83L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1L;V]K
M7V9O<B`]/2!47T585$5.1%,I('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1E>'1E;F1S6R1C=7)R96YT7V-L87-S72`]("1D871A.PT*("`@("`@("`@
M("`@("`@("`@("!](&5L<V5I9B`H)&QO;VM?9F]R(#T](%1?1E5.0U1)3TXI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D8W5R<F5N=%]C;&%S
M<RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C=7)R96YT7V9U
M;F-T:6]N(#T@(B1C=7)R96YT7V-L87-S.CHD9&%T82([#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&1E8VQA<F5D7VUE=&AO9'-;)&-U<G)E;G1?
M8VQA<W-=6UT@/2`D9&%T83L-"B`@("`@("`@("`@("`@("`@("`@("`@('T@
M96QS96EF("@D8W5R<F5N=%]I;G1E<F9A8V4I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D8W5R<F5N=%]F=6YC=&EO;B`]("(D8W5R<F5N=%]I
M;G1E<F9A8V4Z.B1D871A(CL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9&5C;&%R961?;65T:&]D<ULD8W5R<F5N=%]I;G1E<F9A8V5=6UT@/2`D
M9&%T83L-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E;G1?9G5N8W1I;VX@/2`D
M9&%T83L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5C;&%R961?
M9G5N8W1I;VYS6UT@/2`D8W5R<F5N=%]F=6YC=&EO;CL-"B`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("1C=7)R
M96YT7V9U;F-T:6]N7VQE=F5L(#T@)&)R86-E7VQE=F5L.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)&T@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@
M("`@("!](&5L<V5I9B`H)&QO;VM?9F]R(#T](%1?3D57*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D=7-E9%]C;&%S<V5S6R1D871A72`]('1R=64[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M)&QO;VM?9F]R(#T@,#L-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64@
M,CL-"B`@("`@("`@("`@("`@("!C87-E(%1?5D%224%"3$4Z#0H@("`@("`@
M("`@("`@("`@("`@("1L;V]K7V9O<B`](#`[#0H@("`@("`@("`@("`@("`@
M("`@(&-O;G1I;G5E(#([#0H@("`@("`@("`@("`@("`@8V%S92!47T1/0U]#
M3TU-14Y4.@T*("`@("`@("`@("`@("`@(&-A<V4@5%]#3TU-14Y4.@T*("`@
M("`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G(5XO7"I<*EQS(2<L
M("1D871A*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&QA<W1P:'!D
M;V,@/2`D9&%T83L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AP<F5G
M7VUA=&-H7V%L;"@G+T!N;V1E<%QS*RA<4RLI+R<L("1L87-T<&AP9&]C+"`D
M;2DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F]D97!S(#T@
M87)R87E?;65R9V4H)&YO9&5P<RP@)&U;,5TI.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@(&-O;G1I;G5E(#([#0H@("`@("`@("`@("`@("`@8V%S92!4
M7T1/54),15]#3TQ/3CH-"B`@("`@("`@("`@("`@("`@("`@:68@*"$H)'1O
M:V5N<ULD:2`M(#%=6S!=(#T](%1?5TA)5$534$%#12!\?"`D=&]K96YS6R1I
M("T@,5U;,%T@/3T@5%]35%))3D<I*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("!014%2.CIR86ES945R<F]R*")087)S97(@97)R;W(Z(&EN=F%L:60@
M4$A0(&9O=6YD(&EN(&9I;&4@7"(D9FEL95PB(BP-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!014%27T-/34U/3E]%4E)/4E])3E9!3$E$4$A0*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D8VQA<W,@
M/2`D=&]K96YS6R1I("T@,5U;,5T[#0H@("`@("`@("`@("`@("`@("`@(&EF
M("AS=')T;VQO=V5R*"1C;&%S<RD@(3T@)W!A<F5N="<I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1U<V5D7V-L87-S97-;)&-L87-S72`]('1R=64[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M8V]N=&EN=64@,CL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@87)R87DH#0H@("`@("`@("`@("`B<V]U<F-E7V9I;&4B(#T^
M("1F:6QE+`T*("`@("`@("`@("`@(F1E8VQA<F5D7V-L87-S97,B(#T^("1D
M96-L87)E9%]C;&%S<V5S+`T*("`@("`@("`@("`@(F1E8VQA<F5D7VEN=&5R
M9F%C97,B(#T^("1D96-L87)E9%]I;G1E<F9A8V5S+`T*("`@("`@("`@("`@
M(F1E8VQA<F5D7VUE=&AO9',B(#T^("1D96-L87)E9%]M971H;V1S+`T*("`@
M("`@("`@("`@(F1E8VQA<F5D7V9U;F-T:6]N<R(@/3X@)&1E8VQA<F5D7V9U
M;F-T:6]N<RP-"B`@("`@("`@("`@(")U<V5D7V-L87-S97,B(#T^(&%R<F%Y
M7V1I9F8H87)R87E?:V5Y<R@D=7-E9%]C;&%S<V5S*2P@)&YO9&5P<RDL#0H@
M("`@("`@("`@("`B:6YH97)I=&%N8V4B(#T^("1E>'1E;F1S+`T*("`@("`@
M("`@("`@(FEM<&QE;65N=',B(#T^("1I;7!L96UE;G1S+`T*("`@("`@("`@
M("`@*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@(&)E='1E
M<E-T871E<R@I#0H-"B`@("`O*BH-"B`@("`@*B!2971U<FX@86X@87)R87D@
M8V]N=&%I;FEN9R!A;&P@;V8@=&AE('-T871E<R!T:&%T(&%R92!M;W)E('-T
M86)L92!T:&%N#0H@("`@("H@;W(@97%U86P@=&\@=&AE('!A<W-E9"!I;B!S
M=&%T90T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R!296QE87-E('-T
M871E#0H@("`@("H@0'!A<F%M(&)O;VQE86X@1&5T97)M:6YE<R!W:&5T:&5R
M('1O(&EN8VQU9&4@)'-T871E(&EN('1H92!L:7-T#0H@("`@("H@0')E='5R
M;B!F86QS97QA<G)A>2!&86QS92!I9B`D<W1A=&4@:7,@;F]T(&$@=F%L:60@
M<F5L96%S92!S=&%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(&)E='1E<E-T
M871E<R@D<W1A=&4L("1I;F-L=61E(#T@9F%L<V4I#0H@("`@>PT*("`@("`@
M("!S=&%T:6,@)'-T871E<R`](&%R<F%Y*"=S;F%P<VAO="<L("=D979E;"<L
M("=A;'!H82<L("=B971A)RP@)W-T86)L92<I.PT*("`@("`@("`D:2`](&%R
M<F%Y7W-E87)C:"@D<W1A=&4L("1S=&%T97,I.PT*("`@("`@("!I9B`H)&D@
M/3T](&9A;'-E*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"1I;F-L=61E*2![#0H@("`@("`@("`@("`D
M:2TM.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!A<G)A>5]S;&EC92@D
M<W1A=&5S+"`D:2`K(#$I.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O
M('M[>R!D971E8W1$97!E;F1E;F-I97,H*0T*#0H@("`@9G5N8W1I;VX@9&5T
M96-T1&5P96YD96YC:65S*"1A;GDL("1S=&%T=7-?8V%L;&)A8VL@/2!N=6QL
M*0T*("`@('L-"B`@("`@("`@:68@*"%F=6YC=&EO;E]E>&ES=',H(G1O:V5N
M7V=E=%]A;&PB*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1I;F9O(#T@)'1H
M:7,M/FEN9F]&<F]M06YY*"1A;GDI*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*"1I;F9O*3L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H(6ES7V%R<F%Y*"1I;F9O*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1D97!S(#T@87)R87DH*3L-
M"B`@("`@("`@)'5S961?8R`]("1D96-L7V,@/2`D9&5C;%]F(#T@)&1E8VQ?
M;2`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*"1I;F9O6R=F:6QE;&ES
M="==(&%S("1F:6QE(#T^("1F82D@>PT*("`@("`@("`@("`@)'1M<"`]("1T
M:&ES+3YA;F%L>7IE4V]U<F-E0V]D92@D9FEL92D[#0H@("`@("`@("`@("`D
M=7-E9%]C(#T@0&%R<F%Y7VUE<F=E*"1U<V5D7V,L("1T;7!;)W5S961?8VQA
M<W-E<R==*3L-"B`@("`@("`@("`@("1D96-L7V,@/2!`87)R87E?;65R9V4H
M)&1E8VQ?8RP@)'1M<%LG9&5C;&%R961?8VQA<W-E<R==*3L-"B`@("`@("`@
M("`@("1D96-L7V8@/2!`87)R87E?;65R9V4H)&1E8VQ?9BP@)'1M<%LG9&5C
M;&%R961?9G5N8W1I;VYS)UTI.PT*("`@("`@("`@("`@)&1E8VQ?;2`]($!A
M<G)A>5]M97)G92@D9&5C;%]M+"`D=&UP6R=D96-L87)E9%]M971H;V1S)UTI
M.PT*("`@("`@("`@("`@)&EN:&5R:2`]($!A<G)A>5]M97)G92@D:6YH97)I
M+"`D=&UP6R=I;FAE<FET86YC92==*3L-"B`@("`@("`@?0T*("`@("`@("`D
M=7-E9%]C(#T@87)R87E?=6YI<75E*"1U<V5D7V,I.PT*("`@("`@("`D9&5C
M;%]C(#T@87)R87E?=6YI<75E*"1D96-L7V,I.PT*("`@("`@("`D=6YD96-L
M7V,@/2!A<G)A>5]D:69F*"1U<V5D7V,L("1D96-L7V,I.PT*("`@("`@("!R
M971U<FX@87)R87DH)W5S961?8VQA<W-E<R<@/3X@)'5S961?8RP-"B`@("`@
M("`@("`@("`@("`@("`@("=D96-L87)E9%]C;&%S<V5S)R`]/B`D9&5C;%]C
M+`T*("`@("`@("`@("`@("`@("`@("`@)V1E8VQA<F5D7VUE=&AO9',G(#T^
M("1D96-L7VTL#0H@("`@("`@("`@("`@("`@("`@("`G9&5C;&%R961?9G5N
M8W1I;VYS)R`]/B`D9&5C;%]F+`T*("`@("`@("`@("`@("`@("`@("`@)W5N
M9&5C;&%R961?8VQA<W-E<R<@/3X@)'5N9&5C;%]C+`T*("`@("`@("`@("`@
M("`@("`@("`@)VEN:&5R:71A;F-E)R`]/B`D:6YH97)I+`T*("`@("`@("`@
M("`@("`@("`@("`@*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![
M>WL@9V5T57-E<E)O;&5S*"D-"@T*("`@("\J*@T*("`@("`J($=E="!T:&4@
M=F%L:60@<F]L97,@9F]R(&$@4$5!4B!P86-K86=E(&UA:6YT86EN97(-"B`@
M("`@*@T*("`@("`J($!R971U<FX@87)R87D-"B`@("`@*B!`<W1A=&EC#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@9V5T57-E<E)O;&5S*"D-"B`@("![#0H@
M("`@("`@(')E='5R;B`D1TQ/0D%,4ULG7U!%05)?0V]M;6]N7VUA:6YT86EN
M97)?<F]L97,G73L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@
M9V5T4F5L96%S95-T871E<R@I#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE
M('9A;&ED('!A8VMA9V4@<F5L96%S92!S=&%T97,@;V8@<&%C:V%G97,-"B`@
M("`@*@T*("`@("`J($!R971U<FX@87)R87D-"B`@("`@*B!`<W1A=&EC#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@9V5T4F5L96%S95-T871E<R@I#0H@("`@
M>PT*("`@("`@("!R971U<FX@)$=,3T)!3%-;)U]014%27T-O;6UO;E]R96QE
M87-E7W-T871E<R==.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[
M>R!G971$97!E;F1E;F-Y5'EP97,H*0T*#0H@("`@+RHJ#0H@("`@("H@1V5T
M('1H92!I;7!L96UE;G1E9"!D97!E;F1E;F-Y('1Y<&5S("AP:'`L(&5X="P@
M<&MG(&5T8RXI#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@("`@
M("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$1E<&5N9&5N
M8WE4>7!E<R@I#0H@("`@>PT*("`@("`@("!R971U<FX@)$=,3T)!3%-;)U]0
M14%27T-O;6UO;E]D97!E;F1E;F-Y7W1Y<&5S)UT[#0H@("`@?0T*#0H@("`@
M+R\@?7U]#0H@("`@+R\@>WM[(&=E=$1E<&5N9&5N8WE296QA=&EO;G,H*0T*
M#0H@("`@+RHJ#0H@("`@("H@1V5T('1H92!I;7!L96UE;G1E9"!D97!E;F1E
M;F-Y(')E;&%T:6]N<R`H:&%S+"!L="P@9V4@971C+BD-"B`@("`@*@T*("`@
M("`J($!R971U<FX@87)R87D-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@9V5T1&5P96YD96YC>5)E;&%T:6]N<R@I#0H@("`@>PT*
M("`@("`@("!R971U<FX@)$=,3T)!3%-;)U]014%27T-O;6UO;E]D97!E;F1E
M;F-Y7W)E;&%T:6]N<R==.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O
M('M[>R!G971&:6QE4F]L97,H*0T*#0H@("`@+RHJ#0H@("`@("H@1V5T('1H
M92!I;7!L96UE;G1E9"!F:6QE(')O;&5S#0H@("`@("H-"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T
M:6]N(&=E=$9I;&52;VQE<R@I#0H@("`@>PT*("`@("`@("!R971U<FX@)$=,
M3T)!3%-;)U]014%27T-O;6UO;E]F:6QE7W)O;&5S)UT[#0H@("`@?0T*#0H@
M("`@+R\@?7U]#0H@("`@+R\@>WM[(&=E=%)E<&QA8V5M96YT5'EP97,H*0T*
M#0H@("`@+RHJ#0H@("`@("H@1V5T('1H92!I;7!L96UE;G1E9"!F:6QE(')E
M<&QA8V5M96YT('1Y<&5S(&EN#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E
M=%)E<&QA8V5M96YT5'EP97,H*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1'
M3$]"04Q36R=?4$5!4E]#;VUM;VY?<F5P;&%C96UE;G1?='EP97,G73L-"B`@
M("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T4')O=FED951Y<&5S
M*"D-"@T*("`@("\J*@T*("`@("`J($=E="!T:&4@:6UP;&5M96YT960@9FEL
M92!R97!L86-E;65N="!T>7!E<R!I;@T*("`@("`J#0H@("`@("H@0')E='5R
M;B!A<G)A>0T*("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!G9710<F]V:61E5'EP97,H*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1'
M3$]"04Q36R=?4$5!4E]#;VUM;VY?<')O=FED95]T>7!E<R==.PT*("`@('T-
M"@T*("`@("\O('U]?0T*("`@("\O('M[>R!G97138W)I<'10:&%S97,H*0T*
M#0H@("`@+RHJ#0H@("`@("H@1V5T('1H92!I;7!L96UE;G1E9"!F:6QE(')E
M<&QA8V5M96YT('1Y<&5S(&EN#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E
M=%-C<FEP=%!H87-E<R@I#0H@("`@>PT*("`@("`@("!R971U<FX@)$=,3T)!
M3%-;)U]014%27T-O;6UO;E]S8W)I<'1?<&AA<V5S)UT[#0H@("`@?0T*#0H@
M("`@+R\@?7U]#0H@("`@+R\@>WM[('9A;&ED4&%C:V%G94YA;64H*0T*#0H@
M("`@+RHJ#0H@("`@("H@5&5S="!W:&5T:&5R(&$@<W1R:6YG(&-O;G1A:6YS
M(&$@=F%L:60@<&%C:V%G92!N86UE+@T*("`@("`J#0H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;F%M92!T:&4@<&%C:V%G92!N86UE('1O('1E<W0-"B`@("`@
M*@T*("`@("`J($!R971U<FX@8F]O;`T*("`@("`J#0H@("`@("H@0&%C8V5S
M<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!V86QI9%!A8VMA9V5.
M86UE*"1N86UE*0T*("`@('L-"B`@("`@("`@<F5T=7)N("AB;V]L*7!R96=?
M;6%T8V@H4$5!4E]#3TU-3TY?4$%#2T%'15].04U%7U!214<L("1N86UE*3L-
M"B`@("!]#0H-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!V86QI9%!A8VMA
M9V5697)S:6]N*"D-"@T*("`@("\J*@T*("`@("`J(%1E<W0@=VAE=&AE<B!A
M('-T<FEN9R!C;VYT86EN<R!A('9A;&ED('!A8VMA9V4@=F5R<VEO;BX-"B`@
M("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@)'9E<B!T:&4@<&%C:V%G92!V
M97)S:6]N('1O('1E<W0-"B`@("`@*@T*("`@("`J($!R971U<FX@8F]O;`T*
M("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!V86QI9%!A8VMA9V5697)S:6]N*"1V97(I#0H@("`@>PT*("`@
M("`@("!R971U<FX@*&)O;VPI<')E9U]M871C:"A014%27T-/34U/3E]004-+
M04=%7U9%4E-)3TY?4%)%1RP@)'9E<BD[#0H@("`@?0T*#0H-"B`@("`O+R!]
M?7T-"@T*("`@("\O('M[>R!D;W=N;&]A9$AT='`H*0T*#0H@("`@+RHJ#0H@
M("`@("H@1&]W;FQO860@82!F:6QE('1H<F]U9V@@2%144"X@($-O;G-I9&5R
M<R!S=6=G97-T960@9FEL92!N86UE(&EN#0H@("`@("H@0V]N=&5N="UD:7-P
M;W-I=&EO;CH@:&5A9&5R(&%N9"!C86X@<G5N(&$@8V%L;&)A8VL@9G5N8W1I
M;VX@9F]R#0H@("`@("H@9&EF9F5R96YT(&5V96YT<RX@(%1H92!C86QL8F%C
M:R!W:6QL(&)E(&-A;&QE9"!W:71H('1W;PT*("`@("`J('!A<F%M971E<G,Z
M('1H92!C86QL8F%C:R!T>7!E+"!A;F0@<&%R86UE=&5R<RX@(%1H92!I;7!L
M96UE;G1E9`T*("`@("`J(&-A;&QB86-K('1Y<&5S(&%R93H-"B`@("`@*@T*
M("`@("`J("`G<V5T=7`G("`@("`@(&-A;&QE9"!A="!T:&4@=F5R>2!B96=I
M;FYI;F<L('!A<F%M971E<B!I<R!A(%5)(&]B:F5C=`T*("`@("`J("`@("`@
M("`@("`@("`@('1H870@<VAO=6QD(&)E('5S960@9F]R(&%L;"!O=71P=70-
M"B`@("`@*B`@)VUE<W-A9V4G("`@("!T:&4@<&%R86UE=&5R(&ES(&$@<W1R
M:6YG('=I=&@@86X@:6YF;W)M871I;VYA;"!M97-S86=E#0H@("`@("H@("=S
M879E87,G("`@("`@;6%Y(&)E('5S960@=&\@<V%V92!W:71H(&$@9&EF9F5R
M96YT(&9I;&4@;F%M92P@=&AE#0H@("`@("H@("`@("`@("`@("`@("`@<&%R
M86UE=&5R(&ES('1H92!F:6QE;F%M92!T:&%T(&ES(&%B;W5T('1O(&)E('5S
M960N#0H@("`@("H@("`@("`@("`@("`@("`@268@82`G<V%V96%S)R!C86QL
M8F%C:R!R971U<FYS(&$@;F]N+65M<'1Y('-T<FEN9RP-"B`@("`@*B`@("`@
M("`@("`@("`@("!T:&%T(&9I;&4@;F%M92!W:6QL(&)E('5S960@87,@=&AE
M(&9I;&5N86UE(&EN<W1E860N#0H@("`@("H@("`@("`@("`@("`@("`@3F]T
M92!T:&%T("1S879E7V1I<B!W:6QL(&YO="!B92!A9F9E8W1E9"!B>2!T:&ES
M+"!O;FQY#0H@("`@("H@("`@("`@("`@("`@("`@=&AE(&)A<V5N86UE(&]F
M('1H92!F:6QE+@T*("`@("`J("`G<W1A<G0G("`@("`@(&1O=VYL;V%D(&ES
M('-T87)T:6YG+"!P87)A;65T97(@:7,@;G5M8F5R(&]F(&)Y=&5S#0H@("`@
M("H@("`@("`@("`@("`@("`@=&AA="!A<F4@97AP96-T960L(&]R("TQ(&EF
M('5N:VYO=VX-"B`@("`@*B`@)V)Y=&5S<F5A9"<@("!P87)A;65T97(@:7,@
M=&AE(&YU;6)E<B!O9B!B>71E<R!R96%D('-O(&9A<@T*("`@("`J("`G9&]N
M92<@("`@("`@(&1O=VYL;V%D(&ES(&-O;7!L971E+"!P87)A;65T97(@:7,@
M=&AE('1O=&%L(&YU;6)E<@T*("`@("`J("`@("`@("`@("`@("`@(&]F(&)Y
M=&5S(')E860-"B`@("`@*B`@)V-O;FYF86EL960G("!I9B!T:&4@5$-0(&-O
M;FYE8W1I;VX@9F%I;',L('1H:7,@8V%L;&)A8VL@:7,@8V%L;&5D#0H@("`@
M("H@("`@("`@("`@("`@("`@=VET:"!A<G)A>2AH;W-T+'!O<G0L97)R;F\L
M97)R;7-G*0T*("`@("`J("`G=W)I=&5F86EL960G(&EF('=R:71I;F<@=&\@
M9&ES:R!F86EL<RP@=&AI<R!C86QL8F%C:R!I<R!C86QL960-"B`@("`@*B`@
M("`@("`@("`@("`@("!W:71H(&%R<F%Y*&1E<W1F:6QE+&5R<FUS9RD-"B`@
M("`@*@T*("`@("`J($EF(&%N($A45%`@<')O>'D@:&%S(&)E96X@8V]N9FEG
M=7)E9"`H:'1T<%]P<F]X>2!014%27T-O;F9I9PT*("`@("`J('-E='1I;F<I
M+"!T:&4@<')O>'D@=VEL;"!B92!U<V5D+@T*("`@("`J#0H@("`@("H@0'!A
M<F%M('-T<FEN9R`@)'5R;"`@("`@("!T:&4@55),('1O(&1O=VYL;V%D#0H@
M("`@("H@0'!A<F%M(&]B:F5C="`@)'5I("`@("`@("!014%27T9R;VYT96YD
M7RH@:6YS=&%N8V4-"B`@("`@*B!`<&%R86T@;V)J96-T("`D8V]N9FEG("`@
M(%!%05)?0V]N9FEG(&EN<W1A;F-E#0H@("`@("H@0'!A<F%M('-T<FEN9R`@
M)'-A=F5?9&ER("`H;W!T:6]N86PI(&1I<F5C=&]R>2!T;R!S879E(&9I;&4@
M:6X-"B`@("`@*B!`<&%R86T@;6EX960@("`D8V%L;&)A8VL@("AO<'1I;VYA
M;"D@9G5N8W1I;VXO;65T:&]D('1O(&-A;&P@9F]R('-T871U<PT*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@=7!D871E<PT*("`@("`J#0H@
M("`@("H@0')E='5R;B!S=')I;F<@(%)E='5R;G,@=&AE(&9U;&P@<&%T:"!O
M9B!T:&4@9&]W;FQO861E9"!F:6QE(&]R(&$@4$5!4@T*("`@("`J("`@("`@
M("`@("`@("`@("!E<G)O<B!O;B!F86EL=7)E+B`@268@=&AE(&5R<F]R(&ES
M(&-A=7-E9"!B>0T*("`@("`J("`@("`@("`@("`@("`@("!S;V-K970M<F5L
M871E9"!E<G)O<G,L('1H92!E<G)O<B!O8FIE8W0@=VEL;`T*("`@("`J("`@
M("`@("`@("`@("`@("!H879E('1H92!F<V]C:V]P96X@97)R;W(@8V]D92!A
M=F%I;&%B;&4@=&AR;W5G:`T*("`@("`J("`@("`@("`@("`@("`@("!G971#
M;V1E*"DN#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J
M($!D97!R96-A=&5D(&EN(&9A=F]R(&]F(%!%05)?1&]W;FQO861E<CHZ9&]W
M;FQO861(='1P*"D-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!D;W=N;&]A9$AT
M='`H)'5R;"P@)B1U:2P@)'-A=F5?9&ER(#T@)RXG+"`D8V%L;&)A8VL@/2!N
M=6QL*0T*("`@('L-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?
M1&]W;FQO861E<B<I*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%
M05(O1&]W;FQO861E<BYP:'`G.PT*("`@("`@("!]#0H@("`@("`@(')E='5R
M;B!014%27T1O=VYL;V%D97(Z.F1O=VYL;V%D2'1T<"@D=7)L+"`D=6DL("1S
M879E7V1I<BP@)&-A;&QB86-K*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*
M("`@("\J*@T*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@<F5L871I=F4@
M;W(@86)S;VQU=&4@:6YC;'5D92!P871H#0H@("`@("H@0')E='5R;B!B;V]L
M96%N#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&ES
M26YC;'5D96%B;&4H)'!A=&@I#0H@("`@>PT*("`@("`@("!I9B`H9FEL95]E
M>&ES=',H)'!A=&@I("8F(&ES7W)E861A8FQE*"1P871H*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@)&EP871H
M(#T@97AP;&]D92A0051(7U-%4$%2051/4BP@:6YI7V=E="@G:6YC;'5D95]P
M871H)RDI.PT*("`@("`@("!F;W)E86-H("@D:7!A=&@@87,@)&EN8VQU9&4I
M('L-"B`@("`@("`@("`@("1T97-T(#T@<F5A;'!A=&@H)&EN8VQU9&4@+B!$
M25)%0U1/4EE?4T5005)!5$]2("X@)'!A=&@I.PT*("`@("`@("`@("`@:68@
M*&9I;&5?97AI<W1S*"1T97-T*2`F)B!I<U]R96%D86)L92@D=&5S="DI('L-
M"B`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*?0T*
M<F5Q=6ER95]O;F-E("=014%2+T-O;F9I9RYP:'`G.PT*<F5Q=6ER95]O;F-E
M("=014%2+U!A8VMA9V5&:6QE+G!H<"<[#0H_/@``````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O4$5!4B]#;VYF:6<N<&AP````````````````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#(P-S,W,R`Q,#4Q-30S,S<S,B`P,C$Q-#8`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`-"B\J
M*@T*("H@4$5!4E]#;VYF:6<L(&-U<W1O;6EZ960@8V]N9FEG=7)A=&EO;B!H
M86YD;&EN9R!F;W(@=&AE(%!%05(@26YS=&%L;&5R#0H@*@T*("H@4$A0('9E
M<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F
M:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E
M;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E
M:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA
M8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@
M<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL
M('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@
M<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@4W1I
M9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@1W)E9R!"
M96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR
M,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@
M0'9E<G-I;VX@("`@0U93.B`D260Z($-O;F9I9RYP:'`L=B`Q+C$R-"`R,#`V
M+S`S+S`R(#$X.C$T.C$R(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@
M:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@
M("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,"XQ#0H@*B\-"@T*
M+RHJ#0H@*B!297%U:7)E9"!F;W(@97)R;W(@:&%N9&QI;F<-"B`J+PT*<F5Q
M=6ER95]O;F-E("=014%2+G!H<"<[#0IR97%U:7)E7V]N8V4@)U!%05(O4F5G
M:7-T<GDN<&AP)SL-"G)E<75I<F5?;VYC92`G4$5!4B]);G-T86QL97(O4F]L
M92YP:'`G.PT*<F5Q=6ER95]O;F-E("=3>7-T96TN<&AP)SL-"G)E<75I<F5?
M;VYC92`G4$5!4B]296UO=&4N<&AP)SL-"@T*+RHJ#0H@*B!,87-T(&-R96%T
M960@4$5!4E]#;VYF:6<@:6YS=&%N8V4N#0H@*B!`=F%R(&]B:F5C=`T*("HO
M#0HD1TQ/0D%,4ULG7U!%05)?0V]N9FEG7VEN<W1A;F-E)UT@/2!N=6QL.PT*
M:68@*"%D969I;F5D*"=014%27TE.4U1!3$Q?1$E2)RD@?'P@(5!%05)?24Y3
M5$%,3%]$25(I('L-"B`@("`D4$5!4E])3E-404Q,7T1)4B`](%!(4%],24)$
M25(@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)W!E87(G.PT*?2!E;'-E('L-
M"B`@("`D4$5!4E])3E-404Q,7T1)4B`](%!%05)?24Y35$%,3%]$25([#0I]
M#0H-"B\O($)E;&]W('=E(&1E9FEN92!C;VYS=&%N=',@=VET:"!D969A=6QT
M('9A;'5E<R!F;W(@86QL(&-O;F9I9W5R871I;VX-"B\O('!A<F%M971E<G,@
M97AC97!T('5S97)N86UE+W!A<W-W;W)D+B`@06QL(&]F('1H96T@8V%N(&AA
M=F4@=&AE:7(-"B\O(&1E9F%U;'1S('-E="!T:')O=6=H(&5N=FER;VYM96YT
M('9A<FEA8FQE<RX@(%1H92!R96%S;VX@=V4@=7-E('1H90T*+R\@4$A07R!P
M<F5F:7@@:7,@9F]R('-O;64@<V5C=7)I='DL(%!(4"!P<F]T96-T<R!E;G9I
M<F]N;65N=`T*+R\@=F%R:6%B;&5S('-T87)T:6YG('=I=&@@4$A07RHN#0H-
M"B\O(&1E9F%U;'0@8VAA;FYE;"!A;F0@<')E9F5R<F5D(&UI<G)O<B!I<R!B
M87-E9"!O;B!W:&5T:&5R('=E(&%R92!I;G9O:V5D('1H<F]U9V@-"B\O('1H
M92`B<&5A<B(@;W(@=&AE(")P96-L(B!C;VUM86YD#0H-"FEF("@A9&5F:6YE
M9"@G4$5!4E]254Y465!%)RD@?'P@4$5!4E]254Y465!%(#T]("=P96%R)RD@
M>PT*("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%]#2$%.3D5,)RP@
M)W!E87(N<&AP+FYE="<I.PT*?2!E;'-E('L-"B`@("!D969I;F4H)U!%05)?
M0T].1DE'7T1%1D%53%1?0TA!3DY%3"<L("=P96-L+G!H<"YN970G*3L-"GT-
M"@T*:68@*&=E=&5N=B@G4$A07U!%05)?4UE30T].1E]$25(G*2D@>PT*("`@
M(&1E9FEN92@G4$5!4E]#3TY&24=?4UE30T].1D1)4B<L(&=E=&5N=B@G4$A0
M7U!%05)?4UE30T].1E]$25(G*2D[#0I](&5L<V5I9B`H9V5T96YV*"=3>7-T
M96U2;V]T)RDI('L-"B`@("!D969I;F4H)U!%05)?0T].1DE'7U-94T-/3D9$
M25(G+"!G971E;G8H)U-Y<W1E;5)O;W0G*2D[#0I](&5L<V4@>PT*("`@(&1E
M9FEN92@G4$5!4E]#3TY&24=?4UE30T].1D1)4B<L(%!(4%]365-#3TY&1$E2
M*3L-"GT-"@T*+R\@1&5F875L="!F;W(@;6%S=&5R7W-E<G9E<@T*:68@*&=E
M=&5N=B@G4$A07U!%05)?34%35$527U-%4E9%4B<I*2![#0H@("`@9&5F:6YE
M*"=014%27T-/3D9)1U]$149!54Q47TU!4U1%4E]315)615(G+"!G971E;G8H
M)U!(4%]014%27TU!4U1%4E]315)615(G*2D[#0I](&5L<V4@>PT*("`@(&1E
M9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%]-05-415)?4T525D52)RP@)W!E
M87(N<&AP+FYE="<I.PT*?0T*#0HO+R!$969A=6QT(&9O<B!H='1P7W!R;WAY
M#0II9B`H9V5T96YV*"=02%!?4$5!4E](5%107U!23UA9)RDI('L-"B`@("!D
M969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?2%144%]04D]862<L(&=E=&5N
M=B@G4$A07U!%05)?2%144%]04D]862<I*3L-"GT@96QS96EF("AG971E;G8H
M)VAT='!?<')O>'DG*2D@>PT*("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&
M055,5%](5%107U!23UA9)RP@9V5T96YV*"=H='1P7W!R;WAY)RDI.PT*?2!E
M;'-E('L-"B`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?2%144%]0
M4D]862<L("<G*3L-"GT-"@T*+R\@1&5F875L="!F;W(@<&AP7V1I<@T*:68@
M*&=E=&5N=B@G4$A07U!%05)?24Y35$%,3%]$25(G*2D@>PT*("`@(&1E9FEN
M92@G4$5!4E]#3TY&24=?1$5&055,5%]02%!?1$E2)RP@9V5T96YV*"=02%!?
M4$5!4E])3E-404Q,7T1)4B<I*3L-"GT@96QS92![#0H@("`@:68@*$!I<U]D
M:7(H)%!%05)?24Y35$%,3%]$25(I*2![#0H@("`@("`@(&1E9FEN92@G4$5!
M4E]#3TY&24=?1$5&055,5%]02%!?1$E2)RP-"B`@("`@("`@("`@("`@("10
M14%27TE.4U1!3$Q?1$E2*3L-"B`@("!](&5L<V4@>PT*("`@("`@("!D969I
M;F4H)U!%05)?0T].1DE'7T1%1D%53%1?4$A07T1)4B<L("1014%27TE.4U1!
M3$Q?1$E2*3L-"B`@("!]#0I]#0H-"B\O($1E9F%U;'0@9F]R(&5X=%]D:7(-
M"FEF("AG971E;G8H)U!(4%]014%27T585$5.4TE/3E]$25(G*2D@>PT*("`@
M(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%]%6%1?1$E2)RP@9V5T96YV
M*"=02%!?4$5!4E]%6%1%3E-)3TY?1$E2)RDI.PT*?2!E;'-E('L-"B`@("!I
M9B`H:6YI7V=E="@G97AT96YS:6]N7V1I<B<I*2![#0H@("`@("`@(&1E9FEN
M92@G4$5!4E]#3TY&24=?1$5&055,5%]%6%1?1$E2)RP@:6YI7V=E="@G97AT
M96YS:6]N7V1I<B<I*3L-"B`@("!](&5L<V5I9B`H9&5F:6YE9"@G4$5!4E]%
M6%1%3E-)3TY?1$E2)RD@)B8@0&ES7V1I<BA014%27T585$5.4TE/3E]$25(I
M*2![#0H@("`@("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%]%6%1?
M1$E2)RP@4$5!4E]%6%1%3E-)3TY?1$E2*3L-"B`@("!](&5L<V5I9B`H9&5F
M:6YE9"@G4$A07T585$5.4TE/3E]$25(G*2D@>PT*("`@("`@("!D969I;F4H
M)U!%05)?0T].1DE'7T1%1D%53%1?15A47T1)4B<L(%!(4%]%6%1%3E-)3TY?
M1$E2*3L-"B`@("!](&5L<V4@>PT*("`@("`@("!D969I;F4H)U!%05)?0T].
M1DE'7T1%1D%53%1?15A47T1)4B<L("<N)RD[#0H@("`@?0T*?0T*#0HO+R!$
M969A=6QT(&9O<B!D;V-?9&ER#0II9B`H9V5T96YV*"=02%!?4$5!4E]$3T-?
M1$E2)RDI('L-"B`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?1$]#
M7T1)4B<L(&=E=&5N=B@G4$A07U!%05)?1$]#7T1)4B<I*3L-"GT@96QS92![
M#0H@("`@9&5F:6YE*"=014%27T-/3D9)1U]$149!54Q47T1/0U]$25(G+`T*
M("`@("`@("`@("`D4$5!4E])3E-404Q,7T1)4BY$25)%0U1/4EE?4T5005)!
M5$]2+B=D;V-S)RD[#0I]#0H-"B\O($1E9F%U;'0@9F]R(&)I;E]D:7(-"FEF
M("AG971E;G8H)U!(4%]014%27T))3E]$25(G*2D@>PT*("`@(&1E9FEN92@G
M4$5!4E]#3TY&24=?1$5&055,5%]"24Y?1$E2)RP@9V5T96YV*"=02%!?4$5!
M4E]"24Y?1$E2)RDI.PT*?2!E;'-E('L-"B`@("!D969I;F4H)U!%05)?0T].
M1DE'7T1%1D%53%1?0DE.7T1)4B<L(%!(4%]"24Y$25(I.PT*?0T*#0HO+R!$
M969A=6QT(&9O<B!D871A7V1I<@T*:68@*&=E=&5N=B@G4$A07U!%05)?1$%4
M05]$25(G*2D@>PT*("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%]$
M051!7T1)4B<L(&=E=&5N=B@G4$A07U!%05)?1$%405]$25(G*2D[#0I](&5L
M<V4@>PT*("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%]$051!7T1)
M4B<L#0H@("`@("`@("`@("1014%27TE.4U1!3$Q?1$E2+D1)4D5#5$]265]3
M15!!4D%43U(N)V1A=&$G*3L-"GT-"@T*+R\@1&5F875L="!F;W(@=&5S=%]D
M:7(-"FEF("AG971E;G8H)U!(4%]014%27U1%4U1?1$E2)RDI('L-"B`@("!D
M969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?5$535%]$25(G+"!G971E;G8H
M)U!(4%]014%27U1%4U1?1$E2)RDI.PT*?2!E;'-E('L-"B`@("!D969I;F4H
M)U!%05)?0T].1DE'7T1%1D%53%1?5$535%]$25(G+`T*("`@("`@("`@("`D
M4$5!4E])3E-404Q,7T1)4BY$25)%0U1/4EE?4T5005)!5$]2+B=T97-T<R<I
M.PT*?0T*#0HO+R!$969A=6QT(&9O<B!C86-H95]D:7(-"FEF("AG971E;G8H
M)U!(4%]014%27T-!0TA%7T1)4B<I*2![#0H@("`@9&5F:6YE*"=014%27T-/
M3D9)1U]$149!54Q47T-!0TA%7T1)4B<L(&=E=&5N=B@G4$A07U!%05)?0T%#
M2$5?1$E2)RDI.PT*?2!E;'-E('L-"B`@("!D969I;F4H)U!%05)?0T].1DE'
M7T1%1D%53%1?0T%#2$5?1$E2)RP-"B`@("`@("`@("`@4WES=&5M.CIT;7!D
M:7(H*2`N($1)4D5#5$]265]315!!4D%43U(@+B`G<&5A<B<@+@T*("`@("`@
M("`@("!$25)%0U1/4EE?4T5005)!5$]2("X@)V-A8VAE)RD[#0I]#0H-"B\O
M($1E9F%U;'0@9F]R('!H<%]B:6X-"FEF("AG971E;G8H)U!(4%]014%27U!(
M4%]"24XG*2D@>PT*("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%]0
M2%!?0DE.)RP@9V5T96YV*"=02%!?4$5!4E]02%!?0DE.)RDI.PT*?2!E;'-E
M('L-"B`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?4$A07T))3B<L
M(%!%05)?0T].1DE'7T1%1D%53%1?0DE.7T1)4BX-"B`@("`@("`@("`@1$E2
M14-43U)97U-%4$%2051/4BXG<&AP)RXH3U-?5TE.1$]74R`_("<N97AE)R`Z
M("<G*2D[#0I]#0H-"B\O($1E9F%U;'0@9F]R('9E<F)O<V4-"FEF("AG971E
M;G8H)U!(4%]014%27U9%4D)/4T4G*2D@>PT*("`@(&1E9FEN92@G4$5!4E]#
M3TY&24=?1$5&055,5%]615)"3U-%)RP@9V5T96YV*"=02%!?4$5!4E]615)"
M3U-%)RDI.PT*?2!E;'-E('L-"B`@("!D969I;F4H)U!%05)?0T].1DE'7T1%
M1D%53%1?5D520D]312<L(#$I.PT*?0T*#0HO+R!$969A=6QT(&9O<B!P<F5F
M97)R961?<W1A=&4-"FEF("AG971E;G8H)U!(4%]014%27U!2149%4E)%1%]3
M5$%412<I*2![#0H@("`@9&5F:6YE*"=014%27T-/3D9)1U]$149!54Q47U!2
M149%4E)%1%]35$%412<L(&=E=&5N=B@G4$A07U!%05)?4%)%1D524D5$7U-4
M051%)RDI.PT*?2!E;'-E('L-"B`@("!D969I;F4H)U!%05)?0T].1DE'7T1%
M1D%53%1?4%)%1D524D5$7U-4051%)RP@)W-T86)L92<I.PT*?0T*#0HO+R!$
M969A=6QT(&9O<B!U;6%S:PT*:68@*&=E=&5N=B@G4$A07U!%05)?54U!4TLG
M*2D@>PT*("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%]534%32R<L
M(&=E=&5N=B@G4$A07U!%05)?54U!4TLG*2D[#0I](&5L<V4@>PT*("`@(&1E
M9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%]534%32R<L(&1E8V]C="AU;6%S
M:R@I*2D[#0I]#0H-"B\O($1E9F%U;'0@9F]R(&-A8VAE7W1T;`T*:68@*&=E
M=&5N=B@G4$A07U!%05)?0T%#2$5?5%1,)RDI('L-"B`@("!D969I;F4H)U!%
M05)?0T].1DE'7T1%1D%53%1?0T%#2$5?5%1,)RP@9V5T96YV*"=02%!?4$5!
M4E]#04-(15]45$PG*2D[#0I](&5L<V4@>PT*("`@(&1E9FEN92@G4$5!4E]#
M3TY&24=?1$5&055,5%]#04-(15]45$PG+"`S-C`P*3L-"GT-"@T*+R\@1&5F
M875L="!F;W(@<VEG7W1Y<&4-"FEF("AG971E;G8H)U!(4%]014%27U-)1U]4
M65!%)RDI('L-"B`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?4TE'
M7U194$4G+"!G971E;G8H)U!(4%]014%27U-)1U]465!%)RDI.PT*?2!E;'-E
M('L-"B`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?4TE'7U194$4G
M+"`G9W!G)RD[#0I]#0H-"B\O($1E9F%U;'0@9F]R('-I9U]B:6X-"FEF("AG
M971E;G8H)U!(4%]014%27U-)1U]"24XG*2D@>PT*("`@(&1E9FEN92@G4$5!
M4E]#3TY&24=?1$5&055,5%]324=?0DE.)RP@9V5T96YV*"=02%!?4$5!4E]3
M24=?0DE.)RDI.PT*?2!E;'-E('L-"B`@("!D969I;F4H)U!%05)?0T].1DE'
M7T1%1D%53%1?4TE'7T))3B<L#0H@("`@("`@("`@(%-Y<W1E;3HZ=VAI8V@H
M#0H@("`@("`@("`@("`@("`G9W!G)RP@3U-?5TE.1$]74R`_("=C.EQG;G5P
M9UQG<&<N97AE)R`Z("<O=7-R+VQO8V%L+V)I;B]G<&<G*2D[#0I]#0H-"B\O
M($1E9F%U;'0@9F]R('-I9U]K97ED:7(-"FEF("AG971E;G8H)U!(4%]014%2
M7U-)1U]+15E$25(G*2D@>PT*("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&
M055,5%]324=?2T591$E2)RP@9V5T96YV*"=02%!?4$5!4E]324=?2T591$E2
M)RDI.PT*?2!E;'-E('L-"B`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%5
M3%1?4TE'7TM%641)4B<L#0H@("`@("`@("`@(%!%05)?0T].1DE'7U-94T-/
M3D9$25(@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)W!E87)K97ES)RD[#0I]
M#0H-"B\J*@T*("H@5&AI<R!I<R!A(&-L87-S(&9O<B!S=&]R:6YG(&-O;F9I
M9W5R871I;VX@9&%T82P@:V5E<&EN9R!T<F%C:R!O9@T*("H@=VAI8V@@87)E
M('-Y<W1E;2UD969I;F5D+"!U<V5R+61E9FEN960@;W(@9&5F875L=&5D+@T*
M("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@
M0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U
M=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O
M<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J
M($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2
M#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S
M92`P+C$-"B`J+PT*8VQA<W,@4$5!4E]#;VYF:6<@97AT96YD<R!014%2#0I[
M#0H@("`@+R\@>WM[('!R;W!E<G1I97,-"@T*("`@("\J*@T*("`@("`J($%R
M<F%Y(&]F(&-O;F9I9R!F:6QE<R!U<V5D+@T*("`@("`J#0H@("`@("H@0'9A
M<B!A<G)A>2!L87EE<B`]/B!C;VYF:6<@9FEL90T*("`@("`J+PT*("`@('9A
M<B`D9FEL97,@/2!A<G)A>2@-"B`@("`@("`@)W-Y<W1E;2<@/3X@)R<L#0H@
M("`@("`@("=U<V5R)R`]/B`G)RP-"B`@("`@("`@*3L-"@T*("`@('9A<B`D
M;&%Y97)S(#T@87)R87DH*3L-"B`@("`-"B`@("`O*BH-"B`@("`@*B!#;VYF
M:6=U<F%T:6]N(&1A=&$L('1W;RUD:6UE;G-I;VYA;"!A<G)A>2!W:&5R92!T
M:&4@9FER<W0-"B`@("`@*B!D:6UE;G-I;VX@:7,@=&AE(&-O;F9I9R!L87EE
M<B`H)W5S97(G+"`G<WES=&5M)R!A;F0@)V1E9F%U;'0G*2P-"B`@("`@*B!A
M;F0@=&AE('-E8V]N9"!D:6UE;G-I;VX@:7,@:V5Y;F%M92`]/B!V86QU92X-
M"B`@("`@*@T*("`@("`J(%1H92!O<F1E<B!I;B!T:&4@9FER<W0@9&EM96YS
M:6]N(&ES(&EM<&]R=&%N="$@($5A<FQI97(-"B`@("`@*B!L87EE<G,@=VEL
M;"!S:&%D;W<@;&%T97(@;VYE<R!W:&5N(&$@8V]N9FEG('9A;'5E(&ES#0H@
M("`@("H@<F5Q=65S=&5D("AI9B!A("=U<V5R)R!V86QU92!E>&ES=',L(&ET
M('=I;&P@8F4@<F5T=7)N960@9FER<W0L#0H@("`@("H@=&AE;B`G<WES=&5M
M)R!A;F0@9FEN86QL>2`G9&5F875L="<I+@T*("`@("`J#0H@("`@("H@0'9A
M<B!A<G)A>2!L87EE<B`]/B!A<G)A>2AK97EN86UE(#T^('9A;'5E+"`N+BXI
M#0H@("`@("HO#0H@("`@=F%R("1C;VYF:6=U<F%T:6]N(#T@87)R87DH#0H@
M("`@("`@("=U<V5R)R`]/B!A<G)A>2@I+`T*("`@("`@("`G<WES=&5M)R`]
M/B!A<G)A>2@I+`T*("`@("`@("`G9&5F875L="<@/3X@87)R87DH*2P-"B`@
M("`@("`@*3L-"B`@("`-"B`@("`O*BH-"B`@("`@*B!#;VYF:6=U<F%T:6]N
M('9A;'5E<R!T:&%T(&-A;B!B92!S970@9F]R(&$@8VAA;FYE;`T*("`@("`J
M#0H@("`@("H@06QL(&]T:&5R(&-O;F9I9W5R871I;VX@=F%L=65S(&-A;B!O
M;FQY(&AA=F4@82!G;&]B86P@=F%L=64-"B`@("`@*B!`=F%R(&%R<F%Y#0H@
M("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?8VAA
M;FYE;$-O;F9I9TEN9F\@/2!A<G)A>2@-"B`@("`@("`@)W!H<%]D:7(G+"`G
M97AT7V1I<B<L("=D;V-?9&ER)RP@)V)I;E]D:7(G+"`G9&%T85]D:7(G+`T*
M("`@("`@("`G=&5S=%]D:7(G+"`G<&AP7V)I;B<L("=U<V5R;F%M92<L("=P
M87-S=V]R9"<L("=V97)B;W-E)RP-"B`@("`@("`@)W!R969E<G)E9%]S=&%T
M92<L("=U;6%S:R<L("=P<F5F97)R961?;6ER<F]R)RP-"B`@("`@("`@*3L-
M"@T*("`@("\J*@T*("`@("`J($-H86YN96QS('1H870@8V%N(&)E(&%C8V5S
M<V5D#0H@("`@("H@0'-E92!S971#:&%N;F5L<R@I#0H@("`@("H@0'9A<B!A
M<G)A>0T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A
M<B`D7V-H86YN96QS(#T@87)R87DH)W!E87(N<&AP+FYE="<L("=P96-L+G!H
M<"YN970G+"`G7U]U<FDG*3L-"@T*("`@("\J*@T*("`@("`J(%1H:7,@=F%R
M:6%B;&4@:7,@=7-E9"!T;R!C;VYT<F]L('1H92!D:7)E8W1O<GD@=F%L=65S
M(')E='5R;F5D#0H@("`@("H@0'-E92!S971);G-T86QL4F]O="@I.PT*("`@
M("`J($!V87(@<W1R:6YG?&9A;'-E#0H@("`@("H@0&%C8V5S<R!P<FEV871E
M#0H@("`@("HO#0H@("`@=F%R("1?:6YS=&%L;%)O;W0@/2!F86QS93L-"@T*
M("`@("\J*@T*("`@("`J($EF(')E<75E<W1E9"P@=&AI<R!W:6QL(&%L=V%Y
M<R!R969E<B!T;R!T:&4@<F5G:7-T<GD-"B`@("`@*B!C;VYT86EN960@:6X@
M<&AP7V1I<@T*("`@("`J($!V87(@4$5!4E]296=I<W1R>0T*("`@("`J+PT*
M("`@('9A<B`D7W)E9VES=')Y(#T@87)R87DH*3L-"@T*("`@("\J*@T*("`@
M("`J($!V87(@87)R87D-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@
M*B\-"B`@("!V87(@)%]R96=);FET:6%L:7IE9"`](&%R<F%Y*"D[#0H-"B`@
M("`O*BH-"B`@("`@*B!`=F%R(&)O;VP-"B`@("`@*B!`86-C97-S('!R:79A
M=&4-"B`@("`@*B\-"B`@("!V87(@)%]N;U)E9VES=')Y(#T@9F%L<V4[#0H-
M"B`@("`O*BH-"B`@("`@*B!A;6]U;G0@;V8@97)R;W)S(&9O=6YD('=H:6QE
M('!A<G-I;F<@8V]N9FEG#0H@("`@("H@0'9A<B!I;G1E9V5R#0H@("`@("H@
M0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?97)R;W)S1F]U
M;F0@/2`P.PT*("`@('9A<B`D7VQA<W1%<G)O<B`](&YU;&P[#0H-"B`@("`O
M*BH-"B`@("`@*B!);F9O<FUA=&EO;B!A8F]U="!T:&4@8V]N9FEG=7)A=&EO
M;B!D871A+B`@4W1O<F5S('1H92!T>7!E+`T*("`@("`J(&1E9F%U;'0@=F%L
M=64@86YD(&$@9&]C=6UE;G1A=&EO;B!S=')I;F<@9F]R(&5A8V@@8V]N9FEG
M=7)A=&EO;@T*("`@("`J('9A;'5E+@T*("`@("`J#0H@("`@("H@0'9A<B!A
M<G)A>2!L87EE<B`]/B!A<G)A>2AI;F9O='EP92`]/B!V86QU92P@+BXN*0T*
M("`@("`J+PT*("`@('9A<B`D8V]N9FEG=7)A=&EO;E]I;F9O(#T@87)R87DH
M#0H@("`@("`@("\O($-H86YN96QS+TEN=&5R;F5T($%C8V5S<PT*("`@("`@
M("`G9&5F875L=%]C:&%N;F5L)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=T
M>7!E)R`]/B`G<W1R:6YG)RP-"B`@("`@("`@("`@("=D969A=6QT)R`]/B!0
M14%27T-/3D9)1U]$149!54Q47T-(04Y.14PL#0H@("`@("`@("`@("`G9&]C
M)R`]/B`G=&AE(&1E9F%U;'0@8VAA;FYE;"!T;R!U<V4@9F]R(&%L;"!N;VX@
M97AP;&EC:70@8V]M;6%N9',G+`T*("`@("`@("`@("`@)W!R;VUP="<@/3X@
M)T1E9F%U;'0@0VAA;FYE;"<L#0H@("`@("`@("`@("`G9W)O=7`G(#T^("=)
M;G1E<FYE="!!8V-E<W,G+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@)W!R
M969E<G)E9%]M:7)R;W(G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W1Y<&4G
M(#T^("=S=')I;F<G+`T*("`@("`@("`@("`@)V1E9F%U;'0G(#T^(%!%05)?
M0T].1DE'7T1%1D%53%1?0TA!3DY%3"P-"B`@("`@("`@("`@("=D;V,G(#T^
M("=T:&4@9&5F875L="!S97)V97(@;W(@;6ER<F]R('1O('5S92!F;W(@8VAA
M;FYE;"!A8W1I;VYS)RP-"B`@("`@("`@("`@("=P<F]M<'0G(#T^("=$969A
M=6QT($-H86YN96P@36ER<F]R)RP-"B`@("`@("`@("`@("=G<F]U<"<@/3X@
M)TEN=&5R;F5T($%C8V5S<R<L#0H@("`@("`@("`@("`I+`T*("`@("`@("`G
M<F5M;W1E7V-O;F9I9R<@/3X@87)R87DH#0H@("`@("`@("`@("`G='EP92<@
M/3X@)W!A<W-W;W)D)RP-"B`@("`@("`@("`@("=D969A=6QT)R`]/B`G)RP-
M"B`@("`@("`@("`@("=D;V,G(#T^("=F='`@=7)L(&]F(')E;6]T92!C;VYF
M:6=U<F%T:6]N(&9I;&4@=&\@=7-E(&9O<B!S>6YC:')O;FEZ960@:6YS=&%L
M;"<L#0H@("`@("`@("`@("`G<')O;7!T)R`]/B`G4F5M;W1E($-O;F9I9W5R
M871I;VX@1FEL92<L#0H@("`@("`@("`@("`G9W)O=7`G(#T^("=);G1E<FYE
M="!!8V-E<W,G+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@)V%U=&]?9&ES
M8V]V97(G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W1Y<&4G(#T^("=I;G1E
M9V5R)RP-"B`@("`@("`@("`@("=D969A=6QT)R`]/B`P+`T*("`@("`@("`@
M("`@)V1O8R<@/3X@)W=H971H97(@=&\@875T;VUA=&EC86QL>2!D:7-C;W9E
M<B!N97<@8VAA;FYE;',G+`T*("`@("`@("`@("`@)W!R;VUP="<@/3X@)T%U
M=&\M9&ES8V]V97(@;F5W($-H86YN96QS)RP-"B`@("`@("`@("`@("=G<F]U
M<"<@/3X@)TEN=&5R;F5T($%C8V5S<R<L#0H@("`@("`@("`@("`I+`T*("`@
M("`@("`O+R!);G1E<FYE="!!8V-E<W,-"B`@("`@("`@)VUA<W1E<E]S97)V
M97(G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W1Y<&4G(#T^("=S=')I;F<G
M+`T*("`@("`@("`@("`@)V1E9F%U;'0G(#T^("=P96%R+G!H<"YN970G+`T*
M("`@("`@("`@("`@)V1O8R<@/3X@)VYA;64@;V8@=&AE(&UA:6X@4$5!4B!S
M97)V97(@6TY/5"!54T5$($E.(%1(25,@5D524TE/3ETG+`T*("`@("`@("`@
M("`@)W!R;VUP="<@/3X@)U!%05(@<V5R=F5R(%M$15!214-!5$5$72<L#0H@
M("`@("`@("`@("`G9W)O=7`G(#T^("=);G1E<FYE="!!8V-E<W,G+`T*("`@
M("`@("`@("`@*2P-"B`@("`@("`@)VAT='!?<')O>'DG(#T^(&%R<F%Y*`T*
M("`@("`@("`@("`@)W1Y<&4G(#T^("=S=')I;F<G+`T*("`@("`@("`@("`@
M)V1E9F%U;'0G(#T^(%!%05)?0T].1DE'7T1%1D%53%1?2%144%]04D]862P-
M"B`@("`@("`@("`@("=D;V,G(#T^("=(5%10('!R;WAY("AH;W-T.G!O<G0I
M('1O('5S92!W:&5N(&1O=VYL;V%D:6YG('!A8VMA9V5S)RP-"B`@("`@("`@
M("`@("=P<F]M<'0G(#T^("=(5%10(%!R;WAY(%-E<G9E<B!!9&1R97-S)RP-
M"B`@("`@("`@("`@("=G<F]U<"<@/3X@)TEN=&5R;F5T($%C8V5S<R<L#0H@
M("`@("`@("`@("`I+`T*("`@("`@("`O+R!&:6QE($QO8V%T:6]N<PT*("`@
M("`@("`G<&AP7V1I<B<@/3X@87)R87DH#0H@("`@("`@("`@("`G='EP92<@
M/3X@)V1I<F5C=&]R>2<L#0H@("`@("`@("`@("`G9&5F875L="<@/3X@4$5!
M4E]#3TY&24=?1$5&055,5%]02%!?1$E2+`T*("`@("`@("`@("`@)V1O8R<@
M/3X@)V1I<F5C=&]R>2!W:&5R92`N<&AP(&9I;&5S(&%R92!I;G-T86QL960G
M+`T*("`@("`@("`@("`@)W!R;VUP="<@/3X@)U!%05(@9&ER96-T;W)Y)RP-
M"B`@("`@("`@("`@("=G<F]U<"<@/3X@)T9I;&4@3&]C871I;VYS)RP-"B`@
M("`@("`@("`@("DL#0H@("`@("`@("=E>'1?9&ER)R`]/B!A<G)A>2@-"B`@
M("`@("`@("`@("=T>7!E)R`]/B`G9&ER96-T;W)Y)RP-"B`@("`@("`@("`@
M("=D969A=6QT)R`]/B!014%27T-/3D9)1U]$149!54Q47T585%]$25(L#0H@
M("`@("`@("`@("`G9&]C)R`]/B`G9&ER96-T;W)Y('=H97)E(&QO861A8FQE
M(&5X=&5N<VEO;G,@87)E(&EN<W1A;&QE9"<L#0H@("`@("`@("`@("`G<')O
M;7!T)R`]/B`G4$A0(&5X=&5N<VEO;B!D:7)E8W1O<GDG+`T*("`@("`@("`@
M("`@)V=R;W5P)R`]/B`G1FEL92!,;V-A=&EO;G,G+`T*("`@("`@("`@("`@
M*2P-"B`@("`@("`@)V1O8U]D:7(G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@
M)W1Y<&4G(#T^("=D:7)E8W1O<GDG+`T*("`@("`@("`@("`@)V1E9F%U;'0G
M(#T^(%!%05)?0T].1DE'7T1%1D%53%1?1$]#7T1)4BP-"B`@("`@("`@("`@
M("=D;V,G(#T^("=D:7)E8W1O<GD@=VAE<F4@9&]C=6UE;G1A=&EO;B!I<R!I
M;G-T86QL960G+`T*("`@("`@("`@("`@)W!R;VUP="<@/3X@)U!%05(@9&]C
M=6UE;G1A=&EO;B!D:7)E8W1O<GDG+`T*("`@("`@("`@("`@)V=R;W5P)R`]
M/B`G1FEL92!,;V-A=&EO;G,G+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@
M)V)I;E]D:7(G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W1Y<&4G(#T^("=D
M:7)E8W1O<GDG+`T*("`@("`@("`@("`@)V1E9F%U;'0G(#T^(%!%05)?0T].
M1DE'7T1%1D%53%1?0DE.7T1)4BP-"B`@("`@("`@("`@("=D;V,G(#T^("=D
M:7)E8W1O<GD@=VAE<F4@97AE8W5T86)L97,@87)E(&EN<W1A;&QE9"<L#0H@
M("`@("`@("`@("`G<')O;7!T)R`]/B`G4$5!4B!E>&5C=71A8FQE<R!D:7)E
M8W1O<GDG+`T*("`@("`@("`@("`@)V=R;W5P)R`]/B`G1FEL92!,;V-A=&EO
M;G,G+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@)V1A=&%?9&ER)R`]/B!A
M<G)A>2@-"B`@("`@("`@("`@("=T>7!E)R`]/B`G9&ER96-T;W)Y)RP-"B`@
M("`@("`@("`@("=D969A=6QT)R`]/B!014%27T-/3D9)1U]$149!54Q47T1!
M5$%?1$E2+`T*("`@("`@("`@("`@)V1O8R<@/3X@)V1I<F5C=&]R>2!W:&5R
M92!D871A(&9I;&5S(&%R92!I;G-T86QL960G+`T*("`@("`@("`@("`@)W!R
M;VUP="<@/3X@)U!%05(@9&%T82!D:7)E8W1O<GDG+`T*("`@("`@("`@("`@
M)V=R;W5P)R`]/B`G1FEL92!,;V-A=&EO;G,@*$%D=F%N8V5D*2<L#0H@("`@
M("`@("`@("`I+`T*("`@("`@("`G=&5S=%]D:7(G(#T^(&%R<F%Y*`T*("`@
M("`@("`@("`@)W1Y<&4G(#T^("=D:7)E8W1O<GDG+`T*("`@("`@("`@("`@
M)V1E9F%U;'0G(#T^(%!%05)?0T].1DE'7T1%1D%53%1?5$535%]$25(L#0H@
M("`@("`@("`@("`G9&]C)R`]/B`G9&ER96-T;W)Y('=H97)E(')E9W)E<W-I
M;VX@=&5S=',@87)E(&EN<W1A;&QE9"<L#0H@("`@("`@("`@("`G<')O;7!T
M)R`]/B`G4$5!4B!T97-T(&1I<F5C=&]R>2<L#0H@("`@("`@("`@("`G9W)O
M=7`G(#T^("=&:6QE($QO8V%T:6]N<R`H061V86YC960I)RP-"B`@("`@("`@
M("`@("DL#0H@("`@("`@("=C86-H95]D:7(G(#T^(&%R<F%Y*`T*("`@("`@
M("`@("`@)W1Y<&4G(#T^("=D:7)E8W1O<GDG+`T*("`@("`@("`@("`@)V1E
M9F%U;'0G(#T^(%!%05)?0T].1DE'7T1%1D%53%1?0T%#2$5?1$E2+`T*("`@
M("`@("`@("`@)V1O8R<@/3X@)V1I<F5C=&]R>2!W:&EC:"!I<R!U<V5D(&9O
M<B!834Q24$,@8V%C:&4G+`T*("`@("`@("`@("`@)W!R;VUP="<@/3X@)U!%
M05(@26YS=&%L;&5R(&-A8VAE(&1I<F5C=&]R>2<L#0H@("`@("`@("`@("`G
M9W)O=7`G(#T^("=&:6QE($QO8V%T:6]N<R`H061V86YC960I)RP-"B`@("`@
M("`@("`@("DL#0H@("`@("`@("=P:'!?8FEN)R`]/B!A<G)A>2@-"B`@("`@
M("`@("`@("=T>7!E)R`]/B`G9FEL92<L#0H@("`@("`@("`@("`G9&5F875L
M="<@/3X@4$5!4E]#3TY&24=?1$5&055,5%]02%!?0DE.+`T*("`@("`@("`@
M("`@)V1O8R<@/3X@)U!(4"!#3$DO0T=)(&)I;F%R>2!F;W(@97AE8W5T:6YG
M('-C<FEP=',G+`T*("`@("`@("`@("`@)W!R;VUP="<@/3X@)U!(4"!#3$DO
M0T=)(&)I;F%R>2<L#0H@("`@("`@("`@("`G9W)O=7`G(#T^("=&:6QE($QO
M8V%T:6]N<R`H061V86YC960I)RP-"B`@("`@("`@("`@("DL#0H@("`@("`@
M("\O($UA:6YT86EN97)S#0H@("`@("`@("=U<V5R;F%M92<@/3X@87)R87DH
M#0H@("`@("`@("`@("`G='EP92<@/3X@)W-T<FEN9R<L#0H@("`@("`@("`@
M("`G9&5F875L="<@/3X@)R<L#0H@("`@("`@("`@("`G9&]C)R`]/B`G*&UA
M:6YT86EN97)S*2!Y;W5R(%!%05(@86-C;W5N="!N86UE)RP-"B`@("`@("`@
M("`@("=P<F]M<'0G(#T^("=014%2('5S97)N86UE("AF;W(@;6%I;G1A:6YE
M<G,I)RP-"B`@("`@("`@("`@("=G<F]U<"<@/3X@)TUA:6YT86EN97)S)RP-
M"B`@("`@("`@("`@("DL#0H@("`@("`@("=P87-S=V]R9"<@/3X@87)R87DH
M#0H@("`@("`@("`@("`G='EP92<@/3X@)W!A<W-W;W)D)RP-"B`@("`@("`@
M("`@("=D969A=6QT)R`]/B`G)RP-"B`@("`@("`@("`@("=D;V,G(#T^("<H
M;6%I;G1A:6YE<G,I('EO=7(@4$5!4B!A8V-O=6YT('!A<W-W;W)D)RP-"B`@
M("`@("`@("`@("=P<F]M<'0G(#T^("=014%2('!A<W-W;W)D("AF;W(@;6%I
M;G1A:6YE<G,I)RP-"B`@("`@("`@("`@("=G<F]U<"<@/3X@)TUA:6YT86EN
M97)S)RP-"B`@("`@("`@("`@("DL#0H@("`@("`@("\O($%D=F%N8V5D#0H@
M("`@("`@("=V97)B;W-E)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=T>7!E
M)R`]/B`G:6YT96=E<B<L#0H@("`@("`@("`@("`G9&5F875L="<@/3X@4$5!
M4E]#3TY&24=?1$5&055,5%]615)"3U-%+`T*("`@("`@("`@("`@)V1O8R<@
M/3X@)W9E<F)O<VET>2!L979E;`T*,#H@<F5A;&QY('%U:65T#0HQ.B!S;VUE
M=VAA="!Q=6EE=`T*,CH@=F5R8F]S90T*,SH@9&5B=6<G+`T*("`@("`@("`@
M("`@)W!R;VUP="<@/3X@)T1E8G5G($QO9R!,979E;"<L#0H@("`@("`@("`@
M("`G9W)O=7`G(#T^("=!9'9A;F-E9"<L#0H@("`@("`@("`@("`I+`T*("`@
M("`@("`G<')E9F5R<F5D7W-T871E)R`]/B!A<G)A>2@-"B`@("`@("`@("`@
M("=T>7!E)R`]/B`G<V5T)RP-"B`@("`@("`@("`@("=D969A=6QT)R`]/B!0
M14%27T-/3D9)1U]$149!54Q47U!2149%4E)%1%]35$%412P-"B`@("`@("`@
M("`@("=D;V,G(#T^("=T:&4@:6YS=&%L;&5R('=I;&P@<')E9F5R(')E;&5A
M<V5S('=I=&@@=&AI<R!S=&%T92!W:&5N(&EN<W1A;&QI;F<@<&%C:V%G97,@
M=VET:&]U="!A('9E<G-I;VX@;W(@<W1A=&4@<W!E8VEF:65D)RP-"B`@("`@
M("`@("`@("=V86QI9%]S970G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@
M("=S=&%B;&4G+"`G8F5T82<L("=A;'!H82<L("=D979E;"<L("=S;F%P<VAO
M="<I+`T*("`@("`@("`@("`@)W!R;VUP="<@/3X@)U!R969E<G)E9"!086-K
M86=E(%-T871E)RP-"B`@("`@("`@("`@("=G<F]U<"<@/3X@)T%D=F%N8V5D
M)RP-"B`@("`@("`@("`@("DL#0H@("`@("`@("=U;6%S:R<@/3X@87)R87DH
M#0H@("`@("`@("`@("`G='EP92<@/3X@)VUA<VLG+`T*("`@("`@("`@("`@
M)V1E9F%U;'0G(#T^(%!%05)?0T].1DE'7T1%1D%53%1?54U!4TLL#0H@("`@
M("`@("`@("`G9&]C)R`]/B`G=6UA<VL@=7-E9"!W:&5N(&-R96%T:6YG(&9I
M;&5S("A5;FEX+6QI:V4@<WES=&5M<R!O;FQY*2<L#0H@("`@("`@("`@("`G
M<')O;7!T)R`]/B`G56YI>"!F:6QE(&UA<VLG+`T*("`@("`@("`@("`@)V=R
M;W5P)R`]/B`G061V86YC960G+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@
M)V-A8VAE7W1T;"<@/3X@87)R87DH#0H@("`@("`@("`@("`G='EP92<@/3X@
M)VEN=&5G97(G+`T*("`@("`@("`@("`@)V1E9F%U;'0G(#T^(%!%05)?0T].
M1DE'7T1%1D%53%1?0T%#2$5?5%1,+`T*("`@("`@("`@("`@)V1O8R<@/3X@
M)V%M;W5N="!O9B!S96-S('=H97)E('1H92!L;V-A;"!C86-H92!I<R!U<V5D
M(&%N9"!N;W0@=7!D871E9"<L#0H@("`@("`@("`@("`G<')O;7!T)R`]/B`G
M0V%C:&4@5&EM951O3&EV92<L#0H@("`@("`@("`@("`G9W)O=7`G(#T^("=!
M9'9A;F-E9"<L#0H@("`@("`@("`@("`I+`T*("`@("`@("`G<VEG7W1Y<&4G
M(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W1Y<&4G(#T^("=S970G+`T*("`@
M("`@("`@("`@)V1E9F%U;'0G(#T^(%!%05)?0T].1DE'7T1%1D%53%1?4TE'
M7U194$4L#0H@("`@("`@("`@("`G9&]C)R`]/B`G=VAI8V@@<&%C:V%G92!S
M:6=N871U<F4@;65C:&%N:7-M('1O('5S92<L#0H@("`@("`@("`@("`G=F%L
M:61?<V5T)R`]/B!A<G)A>2@G9W!G)RDL#0H@("`@("`@("`@("`G<')O;7!T
M)R`]/B`G4&%C:V%G92!3:6=N871U<F4@5'EP92<L#0H@("`@("`@("`@("`G
M9W)O=7`G(#T^("=-86EN=&%I;F5R<R<L#0H@("`@("`@("`@("`I+`T*("`@
M("`@("`G<VEG7V)I;B<@/3X@87)R87DH#0H@("`@("`@("`@("`G='EP92<@
M/3X@)W-T<FEN9R<L#0H@("`@("`@("`@("`G9&5F875L="<@/3X@4$5!4E]#
M3TY&24=?1$5&055,5%]324=?0DE.+`T*("`@("`@("`@("`@)V1O8R<@/3X@
M)W=H:6-H('!A8VMA9V4@<VEG;F%T=7)E(&UE8VAA;FES;2!T;R!U<V4G+`T*
M("`@("`@("`@("`@)W!R;VUP="<@/3X@)U-I9VYA='5R92!(86YD;&EN9R!0
M<F]G<F%M)RP-"B`@("`@("`@("`@("=G<F]U<"<@/3X@)TUA:6YT86EN97)S
M)RP-"B`@("`@("`@("`@("DL#0H@("`@("`@("=S:6=?:V5Y:60G(#T^(&%R
M<F%Y*`T*("`@("`@("`@("`@)W1Y<&4G(#T^("=S=')I;F<G+`T*("`@("`@
M("`@("`@)V1E9F%U;'0G(#T^("<G+`T*("`@("`@("`@("`@)V1O8R<@/3X@
M)W=H:6-H(&ME>2!T;R!U<V4@9F]R('-I9VYI;F<@=VET:"<L#0H@("`@("`@
M("`@("`G<')O;7!T)R`]/B`G4VEG;F%T=7)E($ME>2!)9"<L#0H@("`@("`@
M("`@("`G9W)O=7`G(#T^("=-86EN=&%I;F5R<R<L#0H@("`@("`@("`@("`I
M+`T*("`@("`@("`G<VEG7VME>61I<B<@/3X@87)R87DH#0H@("`@("`@("`@
M("`G='EP92<@/3X@)V1I<F5C=&]R>2<L#0H@("`@("`@("`@("`G9&5F875L
M="<@/3X@4$5!4E]#3TY&24=?1$5&055,5%]324=?2T591$E2+`T*("`@("`@
M("`@("`@)V1O8R<@/3X@)V1I<F5C=&]R>2!W:&5R92!S:6=N871U<F4@:V5Y
M<R!A<F4@;&]C871E9"<L#0H@("`@("`@("`@("`G<')O;7!T)R`]/B`G4VEG
M;F%T=7)E($ME>2!$:7)E8W1O<GDG+`T*("`@("`@("`@("`@)V=R;W5P)R`]
M/B`G36%I;G1A:6YE<G,G+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@+R\@
M7U]C:&%N;F5L<R!I<R!R97-E<G9E9"`M('5S960@9F]R(&-H86YN96PM<W!E
M8VEF:6,@8V]N9FEG=7)A=&EO;@T*("`@("`@("`I.PT*#0H@("`@+R\@?7U]
M#0H-"B`@("`O+R![>WL@4$5!4E]#;VYF:6<H6V9I;&5=+"!;9&5F875L='-?
M9FEL95TI#0H-"B`@("`O*BH-"B`@("`@*B!#;VYS=')U8W1O<BX-"B`@("`@
M*@T*("`@("`J($!P87)A;2!S=')I;F<@9FEL92!T;R!R96%D('5S97(M9&5F
M:6YE9"!O<'1I;VYS(&9R;VT-"B`@("`@*B!`<&%R86T@<W1R:6YG(&9I;&4@
M=&\@<F5A9"!S>7-T96TM=VED92!D969A=6QT<R!F<F]M#0H@("`@("H@0'!A
M<F%M(&)O;VP@("!D971E<FUI;F5S('=H971H97(@82!R96=I<W1R>2!O8FIE
M8W0@(F9O;&QO=W,B#0H@("`@("H@("`@("`@("`@("`@("!T:&4@=F%L=64@
M;V8@<&AP7V1I<B`H:7,@875T;VUA=&EC86QL>2!C<F5A=&5D#0H@("`@("H@
M("`@("`@("`@("`@("!A;F0@;6]V960@=VAE;B!P:'!?9&ER(&ES(&-H86YG
M960I#0H@("`@("H@0'!A<F%M(&)O;VP@("!I9B!T<G5E+"!F86EL<R!I9B!C
M;VYF:6=U<F%T:6]N(&9I;&5S(&-A;FYO="!B92!L;V%D960-"B`@("`@*@T*
M("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H-"B`@("`@*B!`<V5E(%!%
M05)?0V]N9FEG.CIS:6YG;&5T;VX-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!0
M14%27T-O;F9I9R@D=7-E<E]F:6QE(#T@)R<L("1S>7-T96U?9FEL92`]("<G
M+"`D9G1P7V9I;&4@/2!F86QS92P-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`D<W1R:6-T(#T@=')U92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y014%2
M*"D[#0H@("`@("`@(%!%05)?26YS=&%L;&5R7U)O;&4Z.FEN:71I86QI>F5#
M;VYF:6<H)'1H:7,I.PT*("`@("`@("`D<VP@/2!$25)%0U1/4EE?4T5005)!
M5$]2.PT*("`@("`@("!I9B`H96UP='DH)'5S97)?9FEL92DI('L-"B`@("`@
M("`@("`@(&EF("A/4U]724Y$3U=3*2![#0H@("`@("`@("`@("`@("`@)'5S
M97)?9FEL92`](%!%05)?0T].1DE'7U-94T-/3D9$25(@+B`D<VP@+B`G<&5A
M<BYI;FDG.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`D=7-E<E]F:6QE(#T@9V5T96YV*"=(3TU%)RD@+B`D<VP@+B`G+G!E87)R
M8R<[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&5M
M<'1Y*"1S>7-T96U?9FEL92DI('L-"B`@("`@("`@("`@(&EF("A/4U]724Y$
M3U=3*2![#0H@("`@("`@("`@("`@("`@)'-Y<W1E;5]F:6QE(#T@4$5!4E]#
M3TY&24=?4UE30T].1D1)4B`N("1S;"`N("=P96%R<WES+FEN:2<[#0H@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1S>7-T96U?9FEL
M92`](%!%05)?0T].1DE'7U-94T-/3D9$25(@+B`D<VP@+B`G<&5A<BYC;VYF
M)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*#0H@("`@("`@("1T:&ES
M+3YL87EE<G,@/2!A<G)A>5]K97ES*"1T:&ES+3YC;VYF:6=U<F%T:6]N*3L-
M"B`@("`@("`@)'1H:7,M/F9I;&5S6R=U<V5R)UT@/2`D=7-E<E]F:6QE.PT*
M("`@("`@("`D=&AI<RT^9FEL97-;)W-Y<W1E;2==(#T@)'-Y<W1E;5]F:6QE
M.PT*("`@("`@("!I9B`H)'5S97)?9FEL92`F)B!`9FEL95]E>&ES=',H)'5S
M97)?9FEL92DI('L-"B`@("`@("`@("`@("1T:&ES+3YP=7-H17)R;W)(86YD
M;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@("`@("`D=&AI<RT^
M<F5A9$-O;F9I9T9I;&4H)'5S97)?9FEL92P@)W5S97(G+"`D<W1R:6-T*3L-
M"B`@("`@("`@("`@("1T:&ES+3YP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@
M("`@("`@("!I9B`H)'1H:7,M/E]E<G)O<G-&;W5N9"`^(#`I('L-"B`@("`@
M("`@("`@("`@("!R971U<FX[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"@T*("`@("`@("!I9B`H)'-Y<W1E;5]F:6QE("8F($!F:6QE7V5X:7-T<R@D
M<WES=&5M7V9I;&4I*2![#0H@("`@("`@("`@("`D=&AI<RT^;65R9V5#;VYF
M:6=&:6QE*"1S>7-T96U?9FEL92P@9F%L<V4L("=S>7-T96TG+"`D<W1R:6-T
M*3L-"B`@("`@("`@("`@(&EF("@D=&AI<RT^7V5R<F]R<T9O=6YD(#X@,"D@
M>PT*("`@("`@("`@("`@("`@(')E='5R;CL-"B`@("`@("`@("`@('T-"@T*
M("`@("`@("!]#0H-"B`@("`@("`@:68@*"$D9G1P7V9I;&4I('L-"B`@("`@
M("`@("`@("1F='!?9FEL92`]("1T:&ES+3YG970H)W)E;6]T95]C;VYF:6<G
M*3L-"B`@("`@("`@?0T*#0H@("`@("`@(&EF("@D9G1P7V9I;&4@)B8@9&5F
M:6YE9"@G4$5!4E]214U/5$5)3E-404Q,7T]+)RDI('L-"B`@("`@("`@("`@
M("1T:&ES+3YR96%D1E100V]N9FEG1FEL92@D9G1P7V9I;&4I.PT*("`@("`@
M("!]#0H-"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/F-O;F9I9W5R871I;VY?
M:6YF;R!A<R`D:V5Y(#T^("1I;F9O*2![#0H@("`@("`@("`@("`D=&AI<RT^
M8V]N9FEG=7)A=&EO;ELG9&5F875L="==6R1K97E=(#T@)&EN9F];)V1E9F%U
M;'0G73L-"B`@("`@("`@?0T*#0H@("`@("`@("1T:&ES+3Y?<F5G:7-T<GE;
M)V1E9F%U;'0G72`]("9N97<@4$5!4E]296=I<W1R>2@D=&AI<RT^8V]N9FEG
M=7)A=&EO;ELG9&5F875L="==6R=P:'!?9&ER)UTI.PT*("`@("`@("`D=&AI
M<RT^7W)E9VES=')Y6R=D969A=6QT)UTM/G-E=$-O;F9I9R@D=&AI<RD[#0H@
M("`@("`@("1T:&ES+3Y?<F5G26YI=&EA;&EZ961;)V1E9F%U;'0G72`](&9A
M;'-E.PT*("`@("`@("`O+R1'3$]"04Q36R=?4$5!4E]#;VYF:6=?:6YS=&%N
M8V4G72`]("8D=&AI<SL-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![
M>WL@<VEN9VQE=&]N*%MF:6QE72P@6V1E9F%U;'1S7V9I;&5=*0T*#0H@("`@
M+RHJ#0H@("`@("H@4W1A=&EC('-I;F=L971O;B!M971H;V0N("!)9B!Y;W4@
M=V%N="!T;R!K965P(&]N;'D@;VYE(&EN<W1A;F-E#0H@("`@("H@;V8@=&AI
M<R!C;&%S<R!I;B!U<V4L('1H:7,@;65T:&]D('=I;&P@9VEV92!Y;W4@82!R
M969E<F5N8V4@=&\-"B`@("`@*B!T:&4@;&%S="!C<F5A=&5D(%!%05)?0V]N
M9FEG(&]B:F5C="!I9B!O;F4@97AI<W1S+"!O<B!C<F5A=&4@80T*("`@("`J
M(&YE=R!O8FIE8W0N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("AO
M<'1I;VYA;"D@9FEL92!T;R!R96%D('5S97(M9&5F:6YE9"!O<'1I;VYS(&9R
M;VT-"B`@("`@*B!`<&%R86T@<W1R:6YG("AO<'1I;VYA;"D@9FEL92!T;R!R
M96%D('-Y<W1E;2UW:61E(&1E9F%U;'1S(&9R;VT-"B`@("`@*@T*("`@("`J
M($!R971U<FX@;V)J96-T(&%N(&5X:7-T:6YG(&]R(&YE=R!014%27T-O;F9I
M9R!I;G-T86YC90T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@
M("`@*@T*("`@("`J($!S964@4$5!4E]#;VYF:6<Z.E!%05)?0V]N9FEG#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@)G-I;F=L971O;B@D=7-E<E]F:6QE(#T@
M)R<L("1S>7-T96U?9FEL92`]("<G+"`D<W1R:6-T(#T@=')U92D-"B`@("![
M#0H@("`@("`@(&EF("AI<U]O8FIE8W0H)$=,3T)!3%-;)U]014%27T-O;F9I
M9U]I;G-T86YC92==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1'3$]"04Q3
M6R=?4$5!4E]#;VYF:6=?:6YS=&%N8V4G73L-"B`@("`@("`@?0T*#0H@("`@
M("`@("1T7V-O;F8@/2`F;F5W(%!%05)?0V]N9FEG*"1U<V5R7V9I;&4L("1S
M>7-T96U?9FEL92P@9F%L<V4L("1S=')I8W0I.PT*("`@("`@("!I9B`H)'1?
M8V]N9BT^7V5R<F]R<T9O=6YD(#X@,"D@>PT*("`@("`@("`@("`@(')E='5R
M;B`D=%]C;VYF+3YL87-T17)R;W([#0H@("`@("`@('T-"@T*("`@("`@("`D
M1TQ/0D%,4ULG7U!%05)?0V]N9FEG7VEN<W1A;F-E)UT@/2`F)'1?8V]N9CL-
M"B`@("`@("`@<F5T=7)N("1'3$]"04Q36R=?4$5!4E]#;VYF:6=?:6YS=&%N
M8V4G73L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@=F%L:61#
M;VYF:6=U<F%T:6]N*"D-"@T*("`@("\J*@T*("`@("`J($1E=&5R;6EN92!W
M:&5T:&5R(&%N>2!C;VYF:6=U<F%T:6]N(&9I;&5S(&AA=F4@8F5E;B!D971E
M8W1E9"P@86YD('=H971H97(@80T*("`@("`J(')E9VES=')Y(&]B:F5C="!C
M86X@8F4@<F5T<FEE=F5D(&9R;VT@=&AI<R!C;VYF:6=U<F%T:6]N+@T*("`@
M("`J($!R971U<FX@8F]O;`T*("`@("`J($!S:6YC92!014%2(#$N-"XP83$-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!V86QI9$-O;F9I9W5R871I;VXH*0T*
M("`@('L-"B`@("`@("`@:68@*"1T:&ES+3YI<T1E9FEN961,87EE<B@G=7-E
M<B<I('Q\("1T:&ES+3YI<T1E9FEN961,87EE<B@G<WES=&5M)RDI('L-"B`@
M("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@
M<F5A9$-O;F9I9T9I;&4H6V9I;&5=+"!;;&%Y97)=*0T*#0H@("`@+RHJ#0H@
M("`@("H@4F5A9',@8V]N9FEG=7)A=&EO;B!D871A(&9R;VT@82!F:6QE+B`@
M06QL(&5X:7-T:6YG('9A;'5E<R!I;@T*("`@("`J('1H92!C;VYF:6<@;&%Y
M97(@87)E(&1I<V-A<F1E9"!A;F0@<F5P;&%C960@=VET:"!D871A(&9R;VT@
M=&AE#0H@("`@("H@9FEL92X-"B`@("`@*B!`<&%R86T@<W1R:6YG(&9I;&4@
M=&\@<F5A9"!F<F]M+"!I9B!.54Q,(&]R(&YO="!S<&5C:69I960L('1H90T*
M("`@("`J("`@("`@("`@("`@("`@;&%S="UU<V5D(&9I;&4@9F]R('1H92!S
M86UE(&QA>65R("AS96-O;F0@<&%R86TI(&ES('5S960-"B`@("`@*B!`<&%R
M86T@<W1R:6YG(&-O;F9I9R!L87EE<B!T;R!I;G-E<G0@9&%T82!I;G1O("@G
M=7-E<B<@;W(@)W-Y<W1E;2<I#0H@("`@("H@0')E='5R;B!B;V]L(%12544@
M;VX@<W5C8V5S<R!O<B!A(%!%05(@97)R;W(@;VX@9F%I;'5R90T*("`@("`J
M+PT*("`@(&9U;F-T:6]N(')E861#;VYF:6=&:6QE*"1F:6QE(#T@;G5L;"P@
M)&QA>65R(#T@)W5S97(G+"`D<W1R:6-T(#T@=')U92D-"B`@("![#0H@("`@
M("`@(&EF("AE;7!T>2@D=&AI<RT^9FEL97-;)&QA>65R72DI('L-"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B=6YK;F]W;B!C;VYF
M:6<@;&%Y97(@8"1L87EE<B<B*3L-"B`@("`@("`@?0T*#0H@("`@("`@(&EF
M("@D9FEL92`]/3T@;G5L;"D@>PT*("`@("`@("`@("`@)&9I;&4@/2`D=&AI
M<RT^9FEL97-;)&QA>65R73L-"B`@("`@("`@?0T*#0H@("`@("`@("1D871A
M(#T@)'1H:7,M/E]R96%D0V]N9FEG1&%T849R;VTH)&9I;&4I.PT*#0H@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1D871A*2D@>PT*("`@("`@("`@("`@
M:68@*"1S=')I8W0I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V5R<F]R
M<T9O=6YD*RL[#0H@("`@("`@("`@("`@("`@)'1H:7,M/FQA<W1%<G)O<B`]
M("1D871A.PT*#0H@("`@("`@("`@("`@("`@<F5T=7)N("1D871A.PT*("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!R971U<FX@=')U
M93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("1T:&ES+3YF:6QE<ULD;&%Y97)=(#T@)&9I;&4[#0H@("`@("`@('T-
M"@T*("`@("`@("`D=&AI<RT^7V1E8V]D94EN<'5T*"1D871A*3L-"B`@("`@
M("`@)'1H:7,M/F-O;F9I9W5R871I;VY;)&QA>65R72`]("1D871A.PT*("`@
M("`@("`D=&AI<RT^7W-E='5P0VAA;FYE;',H*3L-"B`@("`@("`@:68@*"$D
M=&AI<RT^7VYO4F5G:7-T<GD@)B8@*"1P:'!D:7(@/2`D=&AI<RT^9V5T*"=P
M:'!?9&ER)RP@)&QA>65R+"`G<&5A<BYP:'`N;F5T)RDI*2![#0H@("`@("`@
M("`@("`D=&AI<RT^7W)E9VES=')Y6R1L87EE<ET@/2`F;F5W(%!%05)?4F5G
M:7-T<GDH)'!H<&1I<BD[#0H@("`@("`@("`@("`D=&AI<RT^7W)E9VES=')Y
M6R1L87EE<ETM/G-E=$-O;F9I9R@D=&AI<RD[#0H@("`@("`@("`@("`D=&AI
M<RT^7W)E9TEN:71I86QI>F5D6R1L87EE<ET@/2!F86QS93L-"B`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?<F5G:7-T<GE;
M)&QA>65R72D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@
M("`@?0T*#0H@("`@+R\@?7U]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@
M<W1R:6YG('5R;"!T;R!T:&4@<F5M;W1E(&-O;F9I9R!F:6QE+"!L:6ME(&9T
M<#HO+W=W=RYE>&%M<&QE+F-O;2]P96%R+V-O;F9I9RYI;FD-"B`@("`@*B!`
M<F5T=7)N('1R=65\4$5!4E]%<G)O<@T*("`@("`J+PT*("`@(&9U;F-T:6]N
M(')E861&5%!#;VYF:6=&:6QE*"1P871H*0T*("`@('L-"B`@("`@("`@9&\@
M>R`O+R!P;V]R(&UA;B=S('1R>0T*("`@("`@("`@("`@:68@*"%C;&%S<U]E
M>&ES=',H)TYE=%]&5%`G*2D@>PT*("`@("`@("`@("`@("`@(&EF("@A8VQA
M<W-?97AI<W1S*"=014%27T-O;6UO;B<I*2![#0H@("`@("`@("`@("`@("`@
M("`@(')E<75I<F5?;VYC92`G4$5!4B]#;VUM;VXN<&AP)SL-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*%!%05)?0V]M;6]N.CII
M<TEN8VQU9&5A8FQE*"=.970O1E10+G!H<"<I*2![#0H@("`@("`@("`@("`@
M("`@("`@(&EN8VQU9&5?;VYC92`G3F5T+T944"YP:'`G.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AC;&%S
M<U]E>&ES=',H)TYE=%]&5%`G*2`F)@T*("`@("`@("`@("`@("`@("`@*&-L
M87-S7V5X:7-T<R@G4$5!4E]&5%`G*2!\?"!014%27T-O;6UO;CHZ:7-);F-L
M=61E86)L92@G4$5!4B]&5%`N<&AP)RDI*2![#0H@("`@("`@("`@("`@("`@
M<F5Q=6ER95]O;F-E("=014%2+T944"YP:'`G.PT*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?9G1P(#T@)FYE=R!014%27T944#L-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^7V9T<"T^<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]2
M15154DXI.PT*("`@("`@("`@("`@("`@("1E(#T@)'1H:7,M/E]F='`M/FEN
M:70H)'!A=&@I.PT*("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1E*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V9T<"T^<&]P
M17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)&4[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1T;7`@
M/2!3>7-T96TZ.FUK=&5M<"@G+60G*3L-"B`@("`@("`@("`@("`@("!014%2
M7T-O;6UO;CHZ861D5&5M<$9I;&4H)'1M<"D[#0H@("`@("`@("`@("`@("`@
M)&4@/2`D=&AI<RT^7V9T<"T^9V5T*&)A<V5N86UE*"1P871H*2P@)'1M<"`N
M($1)4D5#5$]265]315!!4D%43U(@+@T*("`@("`@("`@("`@("`@("`@("`G
M<&5A<BYI;FDG+"!F86QS92P@1E107T))3D%262D[#0H@("`@("`@("`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)&4I*2![#0H@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9G1P+3YP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D93L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@4$5!4E]#;VUM;VXZ.F%D9%1E;7!&:6QE*"1T;7`@
M+B!$25)%0U1/4EE?4T5005)!5$]2("X@)W!E87(N:6YI)RD[#0H@("`@("`@
M("`@("`@("`@)'1H:7,M/E]F='`M/F1I<V-O;FYE8W0H*3L-"B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V9T<"T^<&]P17)R;W)(86YD;&EN9R@I.PT*("`@
M("`@("`@("`@("`@("1T:&ES+3YF:6QE<ULG9G1P)UT@/2`D=&UP("X@1$E2
M14-43U)97U-%4$%2051/4B`N("=P96%R+FEN:2<[#0H@("`@("`@("`@("`@
M("`@)&4@/2`D=&AI<RT^<F5A9$-O;F9I9T9I;&4H;G5L;"P@)V9T<"<I.PT*
M("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E*2D@>PT*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)&4[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("1F86EL(#T@87)R87DH*3L-"B`@("`@("`@
M("`@("`@("!F;W)E86-H("@D=&AI<RT^8V]N9FEG=7)A=&EO;E]I;F9O(&%S
M("1K97D@/3X@)'9A;"D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H:6Y?
M87)R87DH)'1H:7,M/F=E=$=R;W5P*"1K97DI+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@G1FEL92!,;V-A=&EO;G,G+"`G1FEL92!,;V-A
M=&EO;G,@*$%D=F%N8V5D*2<I*2`F)@T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^9V5T5'EP92@D:V5Y*2`]/2`G9&ER96-T;W)Y)RD@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@+R\@86YY(&1I<F5C=&]R>2!C;VYF
M:6=S(&UU<W0@8F4@<V5T(&9O<B!T:&ES('1O('=O<FL-"B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/F-O;F9I9W5R871I;VY;
M)V9T<"==6R1K97E=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1F86EL6UT@/2`D:V5Y.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@(&EF("AC;W5N="@D9F%I;"DI('L-"B`@("`@("`@("`@
M("`@("`@("`@)&9A:6P@/2`G(B<@+B!I;7!L;V1E*"<B+"`B)RP@)&9A:6PI
M("X@)R(G.PT*("`@("`@("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^9FEL
M97-;)V9T<"==*3L-"B`@("`@("`@("`@("`@("`@("`@=6YS970H)'1H:7,M
M/F-O;F9I9W5R871I;VY;)V9T<"==*3L-"B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T524D]2.B!&='`@8V]N9FEG=7)A
M=&EO;B!F:6QE(&UU<W0@<V5T(&%L;"`G("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("=D:7)E8W1O<GD@8V]N9FEG=7)A=&EO;B!V87)I86)L97,N("!4
M:&5S92!V87)I86)L97,@=V5R92!N;W0@<V5T.B`G("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1F86EL*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=.971?1E10(&UU<W0@8F4@
M:6YS=&%L;&5D('1O('5S92!R96UO=&4@8V]N9FEG)RD[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T@=VAI;&4@*&9A;'-E*3L@+R\@<&]O<B!M86XG<R!C
M871C:`T*("`@("`@("!U;G-E="@D=&AI<RT^9FEL97-;)V9T<"==*3L-"B`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)VYO(')E;6]T92!H;W-T
M('-P96-I9FEE9"<I.PT*("`@('T-"@T*("`@("\O('M[>R!?<V5T=7!#:&%N
M;F5L<R@I#0H@("`@#0H@("`@+RHJ#0H@("`@("H@4F5A9',@=&AE(&5X:7-T
M:6YG(&-O;F9I9W5R871I;VYS(&%N9"!C<F5A=&5S('1H92!?8VAA;FYE;',@
M87)R87D@9G)O;2!I=`T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]S971U<$-H
M86YN96QS*"D-"B`@("![#0H@("`@("`@("1S970@/2!A<G)A>5]F;&EP*&%R
M<F%Y7W9A;'5E<R@D=&AI<RT^7V-H86YN96QS*2D[#0H@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3YC;VYF:6=U<F%T:6]N(&%S("1L87EE<B`]/B`D9&%T82D@
M>PT*("`@("`@("`@("`@)&D@/2`Q,#`P.PT*("`@("`@("`@("`@:68@*&ES
M<V5T*"1D871A6R=?7V-H86YN96QS)UTI*2![#0H@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)&1A=&%;)U]?8VAA;FYE;',G72!A<R`D8VAA;FYE;"`]/B`D
M:6YF;RD@>PT*("`@("`@("`@("`@("`@("`@("`D<V5T6R1C:&%N;F5L72`]
M("1I*RL[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@("1T:&ES+3Y?8VAA;FYE;',@/2!A<G)A>5]V86QU
M97,H87)R87E?9FQI<"@D<V5T*2D[#0H@("`@("`@("1T:&ES+3YS971#:&%N
M;F5L<R@D=&AI<RT^7V-H86YN96QS*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-
M"B`@("`O+R![>WL@9&5L971E0VAA;FYE;"AC:&%N;F5L*0T*#0H@("`@9G5N
M8W1I;VX@9&5L971E0VAA;FYE;"@D8VAA;FYE;"D-"B`@("![#0H@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3YC;VYF:6=U<F%T:6]N(&%S("1L87EE<B`]/B`D
M9&%T82D@>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1D871A6R=?7V-H86YN
M96QS)UTI*2![#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D871A6R=?
M7V-H86YN96QS)UU;<W1R=&]L;W=E<B@D8VAA;FYE;"E=*2D@>PT*("`@("`@
M("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^8V]N9FEG=7)A=&EO;ELD;&%Y
M97)=6R=?7V-H86YN96QS)UU;<W1R=&]L;W=E<B@D8VAA;FYE;"E=*3L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@)'1H:7,M/E]C:&%N;F5L<R`](&%R<F%Y7V9L:7`H)'1H:7,M/E]C
M:&%N;F5L<RD[#0H@("`@("`@('5N<V5T*"1T:&ES+3Y?8VAA;FYE;'-;<W1R
M=&]L;W=E<B@D8VAA;FYE;"E=*3L-"B`@("`@("`@)'1H:7,M/E]C:&%N;F5L
M<R`](&%R<F%Y7V9L:7`H)'1H:7,M/E]C:&%N;F5L<RD[#0H@("`@?0T*#0H@
M("`@+R\@?7U]#0H@("`@+R\@>WM[(&UE<F=E0V]N9FEG1FEL92AF:6QE+"!;
M;W9E<G)I9&5=+"!;;&%Y97)=*0T*#0H@("`@+RHJ#0H@("`@("H@365R9V5S
M(&1A=&$@:6YT;R!A(&-O;F9I9R!L87EE<B!F<F]M(&$@9FEL92X@($1O97,@
M=&AE('-A;64-"B`@("`@*B!T:&EN9R!A<R!R96%D0V]N9FEG1FEL92P@97AC
M97!T(&ET(&1O97,@;F]T(')E<&QA8V4@86QL#0H@("`@("H@97AI<W1I;F<@
M=F%L=65S(&EN('1H92!C;VYF:6<@;&%Y97(N#0H@("`@("H@0'!A<F%M('-T
M<FEN9R!F:6QE('1O(')E860@9G)O;0T*("`@("`J($!P87)A;2!B;V]L('=H
M971H97(@=&\@;W9E<G=R:71E(&5X:7-T:6YG(&1A=&$@*&1E9F%U;'0@5%)5
M12D-"B`@("`@*B!`<&%R86T@<W1R:6YG(&-O;F9I9R!L87EE<B!T;R!I;G-E
M<G0@9&%T82!I;G1O("@G=7-E<B<@;W(@)W-Y<W1E;2<I#0H@("`@("H@0'!A
M<F%M('-T<FEN9R!I9B!T<G5E+"!E<G)O<G,@87)E(')E='5R;F5D(&EF(&9I
M;&4@;W!E;FEN9R!F86EL<PT*("`@("`J($!R971U<FX@8F]O;"!44E5%(&]N
M('-U8V-E<W,@;W(@82!014%2(&5R<F]R(&]N(&9A:6QU<F4-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!M97)G94-O;F9I9T9I;&4H)&9I;&4L("1O=F5R<FED
M92`]('1R=64L("1L87EE<B`]("=U<V5R)RP@)'-T<FEC="`]('1R=64I#0H@
M("`@>PT*("`@("`@("!I9B`H96UP='DH)'1H:7,M/F9I;&5S6R1L87EE<ETI
M*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(G5N
M:VYO=VX@8V]N9FEG(&QA>65R(&`D;&%Y97(G(BD[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"1F:6QE(#T]/2!N=6QL*2![#0H@("`@("`@("`@("`D9FEL
M92`]("1T:&ES+3YF:6QE<ULD;&%Y97)=.PT*("`@("`@("!]#0H@("`@("`@
M("1D871A(#T@)'1H:7,M/E]R96%D0V]N9FEG1&%T849R;VTH)&9I;&4I.PT*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D9&%T82DI('L-"B`@("`@("`@
M("`@(&EF("@D<W1R:6-T*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]E
M<G)O<G-&;W5N9"LK.PT*("`@("`@("`@("`@("`@("1T:&ES+3YL87-T17)R
M;W(@/2`D9&%T83L-"@T*("`@("`@("`@("`@("`@(')E='5R;B`D9&%T83L-
M"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@<F5T=7)N
M('1R=64[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)'1H
M:7,M/E]D96-O9&5);G!U="@D9&%T82D[#0H@("`@("`@(&EF("@D;W9E<G)I
M9&4I('L-"B`@("`@("`@("`@("1T:&ES+3YC;VYF:6=U<F%T:6]N6R1L87EE
M<ET@/0T*("`@("`@("`@("`@("`@(%!%05)?0V]N9FEG.CIA<G)A>4UE<F=E
M4F5C=7)S:79E*"1T:&ES+3YC;VYF:6=U<F%T:6]N6R1L87EE<ETL("1D871A
M*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1T:&ES+3YC;VYF
M:6=U<F%T:6]N6R1L87EE<ET@/0T*("`@("`@("`@("`@("`@(%!%05)?0V]N
M9FEG.CIA<G)A>4UE<F=E4F5C=7)S:79E*"1D871A+"`D=&AI<RT^8V]N9FEG
M=7)A=&EO;ELD;&%Y97)=*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^
M7W-E='5P0VAA;FYE;',H*3L-"B`@("`@("`@:68@*"$D=&AI<RT^7VYO4F5G
M:7-T<GD@)B8@*"1P:'!D:7(@/2`D=&AI<RT^9V5T*"=P:'!?9&ER)RP@)&QA
M>65R+"`G<&5A<BYP:'`N;F5T)RDI*2![#0H@("`@("`@("`@("`D=&AI<RT^
M7W)E9VES=')Y6R1L87EE<ET@/2`F;F5W(%!%05)?4F5G:7-T<GDH)'!H<&1I
M<BD[#0H@("`@("`@("`@("`D=&AI<RT^7W)E9VES=')Y6R1L87EE<ETM/G-E
M=$-O;F9I9R@D=&AI<RD[#0H@("`@("`@("`@("`D=&AI<RT^7W)E9TEN:71I
M86QI>F5D6R1L87EE<ET@/2!F86QS93L-"B`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@('5N<V5T*"1T:&ES+3Y?<F5G:7-T<GE;)&QA>65R72D[#0H@
M("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@
M+R\@?7U]#0H@("`@+R\@>WM[(&%R<F%Y365R9V5296-U<G-I=F4H)&%R<C(L
M("1A<G(Q*0T*("`@("\J*@T*("`@("`J($!P87)A;2!A<G)A>0T*("`@("`J
M($!P87)A;2!A<G)A>0T*("`@("`J($!R971U<FX@87)R87D-"B`@("`@*B!`
M<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@87)R87E-97)G95)E8W5R
M<VEV92@D87)R,BP@)&%R<C$I#0H@("`@>PT*("`@("`@("`D<F5T(#T@87)R
M87DH*3L-"B`@("`@("`@9F]R96%C:"`H)&%R<C(@87,@)&ME>2`]/B`D9&%T
M82D@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D87)R,5LD:V5Y72DI('L-
M"B`@("`@("`@("`@("`@("`D<F5T6R1K97E=(#T@)&1A=&$[#0H@("`@("`@
M("`@("`@("`@=6YS970H)&%R<C%;)&ME>5TI.PT*("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&ES
M7V%R<F%Y*"1D871A*2D@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-?87)R
M87DH)&%R<C%;)&ME>5TI*2![#0H@("`@("`@("`@("`@("`@("`@("1R971;
M)&ME>5T@/2`D87)R,5LD:V5Y73L-"B`@("`@("`@("`@("`@("`@("`@=6YS
M970H)&%R<C%;)&ME>5TI.PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU
M93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)')E=%LD
M:V5Y72`](%!%05)?0V]N9FEG.CIA<G)A>4UE<F=E4F5C=7)S:79E*"1A<G(Q
M6R1K97E=+"`D87)R,ELD:V5Y72D[#0H@("`@("`@("`@("`@("`@=6YS970H
M)&%R<C%;)&ME>5TI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B!A<G)A>5]M97)G92@D<F5T+"`D87)R,2D[#0H@("`@?0T*
M#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[('=R:71E0V]N9FEG1FEL92A;9FEL
M95TL(%ML87EE<ETI#0H-"B`@("`O*BH-"B`@("`@*B!7<FET97,@9&%T82!I
M;G1O(&$@8V]N9FEG(&QA>65R(&9R;VT@82!F:6QE+@T*("`@("`J#0H@("`@
M("H@0'!A<F%M('-T<FEN9WQN=6QL(&9I;&4@=&\@<F5A9"!F<F]M+"!O<B!N
M=6QL(&9O<B!D969A=6QT#0H@("`@("H@0'!A<F%M('-T<FEN9R!C;VYF:6<@
M;&%Y97(@=&\@:6YS97)T(&1A=&$@:6YT;R`H)W5S97(G(&]R#0H@("`@("H@
M("`@("`@("`@("`@("`G<WES=&5M)RD-"B`@("`@*B!`<&%R86T@<W1R:6YG
M?&YU;&P@9&%T82!T;R!W<FET92!T;R!C;VYF:6<@9FEL92!O<B!N=6QL(&9O
M<B!I;G1E<FYA;"!D871A(%M$15!214-!5$5$70T*("`@("`J($!R971U<FX@
M8F]O;"!44E5%(&]N('-U8V-E<W,@;W(@82!014%2(&5R<F]R(&]N(&9A:6QU
M<F4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!W<FET94-O;F9I9T9I;&4H)&9I
M;&4@/2!N=6QL+"`D;&%Y97(@/2`G=7-E<B<L("1D871A(#T@;G5L;"D-"B`@
M("![#0H@("`@("`@("1T:&ES+3Y?;&%Z>4-H86YN96Q3971U<"@D;&%Y97(I
M.PT*("`@("`@("!I9B`H)&QA>65R(#T]("=B;W1H)R!\?"`D;&%Y97(@/3T@
M)V%L;"<I('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YF:6QE<R!A
M<R`D='EP92`]/B`D9FEL92D@>PT*("`@("`@("`@("`@("`@("1E<G(@/2`D
M=&AI<RT^=W)I=&5#;VYF:6=&:6QE*"1F:6QE+"`D='EP92P@)&1A=&$I.PT*
M("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G(I*2![#0H@
M("`@("`@("`@("`@("`@("`@(')E='5R;B`D97)R.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B!T<G5E
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^9FEL97-;
M)&QA>65R72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@B=6YK;F]W;B!C;VYF:6<@9FEL92!T>7!E(&`D;&%Y97(G(BD[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"1F:6QE(#T]/2!N=6QL*2![#0H@("`@
M("`@("`@("`D9FEL92`]("1T:&ES+3YF:6QE<ULD;&%Y97)=.PT*("`@("`@
M("!]#0H@("`@("`@("1D871A(#T@*"1D871A(#T]/2!N=6QL*2`_("1T:&ES
M+3YC;VYF:6=U<F%T:6]N6R1L87EE<ET@.B`D9&%T83L-"B`@("`@("`@)'1H
M:7,M/E]E;F-O9&5/=71P=70H)&1A=&$I.PT*("`@("`@("`D;W!T(#T@87)R
M87DH)RUP)RP@9&ER;F%M92@D9FEL92DI.PT*("`@("`@("!I9B`H(4!3>7-T
M96TZ.FUK1&ER*"1O<'0I*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H(F-O=6QD(&YO="!C<F5A=&4@9&ER96-T;W)Y.B`B("X@
M9&ER;F%M92@D9FEL92DI.PT*("`@("`@("!]#0H@("`@("`@(&EF("A`:7-?
M9FEL92@D9FEL92D@)B8@(4!I<U]W<FET96%B;&4H)&9I;&4I*2![#0H@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(FYO('=R:71E(&%C
M8V5S<R!T;R`D9FEL92$B*3L-"B`@("`@("`@?0T*("`@("`@("`D9G`@/2!`
M9F]P96XH)&9I;&4L(")W(BD[#0H@("`@("`@(&EF("@A)&9P*2![#0H@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(E!%05)?0V]N9FEG
M.CIW<FET94-O;F9I9T9I;&4@9F]P96XH)R1F:6QE)RPG=R<I(&9A:6QE9"(I
M.PT*("`@("`@("!]#0H@("`@("`@("1C;VYT96YT<R`]("(C4$5!4E]#;VYF
M:6<@,"XY7&XB("X@<V5R:6%L:7IE*"1D871A*3L-"B`@("`@("`@:68@*"%`
M9G=R:71E*"1F<"P@)&-O;G1E;G1S*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*")014%27T-O;F9I9SHZ=W)I=&5#;VYF:6=&
M:6QE.B!F=W)I=&4@9F%I;&5D(BD[#0H@("`@("`@('T-"B`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(%]R
M96%D0V]N9FEG1&%T849R;VTH9FEL92D-"@T*("`@("\J*@T*("`@("`J(%)E
M861S(&-O;F9I9W5R871I;VX@9&%T82!F<F]M(&$@9FEL92!A;F0@<F5T=7)N
M<R!T:&4@<&%R<V5D(&1A=&$-"B`@("`@*B!I;B!A;B!A<G)A>2X-"B`@("`@
M*@T*("`@("`J($!P87)A;2!S=')I;F<@9FEL92!T;R!R96%D(&9R;VT-"B`@
M("`@*@T*("`@("`J($!R971U<FX@87)R87D@8V]N9FEG=7)A=&EO;B!D871A
M(&]R(&$@4$5!4B!E<G)O<B!O;B!F86EL=7)E#0H@("`@("H-"B`@("`@*B!`
M86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?<F5A9$-O
M;F9I9T1A=&%&<F]M*"1F:6QE*0T*("`@('L-"B`@("`@("`@)&9P(#T@0&9O
M<&5N*"1F:6QE+"`B<B(I.PT*("`@("`@("!I9B`H(21F<"D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")014%27T-O;F9I9SHZ
M<F5A9$-O;F9I9T9I;&4@9F]P96XH)R1F:6QE)RPG<B<I(&9A:6QE9"(I.PT*
M("`@("`@("!]#0H@("`@("`@("1S:7IE(#T@9FEL97-I>F4H)&9I;&4I.PT*
M("`@("`@("`D<G0@/2!G971?;6%G:6-?<75O=&5S7W)U;G1I;64H*3L-"B`@
M("`@("`@<V5T7VUA9VEC7W%U;W1E<U]R=6YT:6UE*#`I.PT*("`@("`@("!I
M9B`H9G5N8W1I;VY?97AI<W1S*"=F:6QE7V=E=%]C;VYT96YT<R<I*2![#0H@
M("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@("`@("1C;VYT96YT
M<R`](&9I;&5?9V5T7V-O;G1E;G1S*"1F:6QE*3L-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("1C;VYT96YT<R`]($!F<F5A9"@D9G`L("1S:7IE
M*3L-"B`@("`@("`@("`@(&9C;&]S92@D9G`I.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("AE;7!T>2@D8V]N=&5N=',I*2![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-O;F9I9W5R871I;VX@9FEL92`B)R`N
M("1F:6QE("X@)R(@:7,@96UP='DG*3L-"B`@("`@("`@?0T*("`@("`@("`-
M"B`@("`@("`@<V5T7VUA9VEC7W%U;W1E<U]R=6YT:6UE*"1R="D[#0H-"B`@
M("`@("`@)'9E<G-I;VX@/2!F86QS93L-"B`@("`@("`@:68@*'!R96=?;6%T
M8V@H)R]>(U!%05)?0V]N9FEG7',K*%Q3*RE<<RLO<VDG+"`D8V]N=&5N=',L
M("1M871C:&5S*2D@>PT*("`@("`@("`@("`@)'9E<G-I;VX@/2`D;6%T8VAE
M<ULQ73L-"B`@("`@("`@("`@("1C;VYT96YT<R`]('-U8G-T<B@D8V]N=&5N
M=',L('-T<FQE;B@D;6%T8VAE<ULP72DI.PT*("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@+R\@375S975M(&-O;F9I9R!F:6QE#0H@("`@("`@("`@
M("!I9B`H<W5B<W1R*"1C;VYT96YT<RPP+#(I(#T]("=A.B<I('L-"B`@("`@
M("`@("`@("`@("`D=F5R<VEO;B`]("<P+C$G.PT*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@(&EF("@D=F5R<VEO;B`F)B!V97)S:6]N7V-O
M;7!A<F4H(B1V97)S:6]N(BP@)S$G+"`G/"<I*2![#0H-"B`@("`@("`@("`@
M("\O(&YO("=`)RP@:70@:7,@<&]S<VEB;&4@=&AA="!U;G-E<FEA;&EZ90T*
M("`@("`@("`@("`@+R\@<F%I<V5S(&$@;F]T:6-E(&)U="!I="!S965M<R!T
M;R!B;&]C:R!)3R!T;PT*("`@("`@("`@("`@+R\@4U1$3U54(&EF(&$@)T`G
M(&ES('5S960@86YD(&$@;F]T:6-E(&ES(')A:7-E#0H@("`@("`@("`@("`D
M9&%T82`]('5N<V5R:6%L:7IE*"1C;VYT96YT<RD[#0H-"B`@("`@("`@("`@
M(&EF("@A:7-?87)R87DH)&1A=&$I("8F("$D9&%T82D@>PT*("`@("`@("`@
M("`@("`@(&EF("@D8V]N=&5N=',@/3T@<V5R:6%L:7IE*&9A;'-E*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`D9&%T82`](&%R<F%Y*"D[#0H@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)&5R<B`]
M("1T:&ES+3YR86ES945R<F]R*")014%27T-O;F9I9SH@8F%D(&1A=&$@:6X@
M)&9I;&4B*3L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1E<G([#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M:68@*"%I<U]A<G)A>2@D9&%T82DI('L-"B`@("`@("`@("`@("`@("!I9B`H
M<W1R;&5N*'1R:6TH)&-O;G1E;G1S*2D@/B`P*2![#0H@("`@("`@("`@("`@
M("`@("`@("1E<G)O<B`](")014%27T-O;F9I9SH@8F%D(&1A=&$@:6X@)&9I
M;&4B.PT*("`@("`@("`@("`@("`@("`@("`D97)R(#T@)'1H:7,M/G)A:7-E
M17)R;W(H)&5R<F]R*3L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1E
M<G([#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@)&1A=&$@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T-"B`@("`@("`@+R\@861D('!A<G-I;F<@;V8@;F5W97(@
M9F]R;6%T<R!H97)E+BXN#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`D97)R(#T@)'1H:7,M/G)A:7-E17)R;W(H(B1F:6QE.B!U;FMN;W=N('9E
M<G-I;VX@8"1V97)S:6]N)R(I.PT*("`@("`@("`@("`@<F5T=7)N("1E<G([
M(`T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D9&%T83L-"B`@("!]#0H-
M"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T0V]N9D9I;&4H;&%Y97(I#0H@
M("`@+RHJ#0H@("`@*B!'971S('1H92!F:6QE('5S960@9F]R('-T;W)I;F<@
M=&AE(&-O;F9I9R!F;W(@82!L87EE<@T*("`@("H-"B`@("`J($!P87)A;2!S
M=')I;F<@)&QA>65R("=U<V5R)R!O<B`G<WES=&5M)PT*("`@("HO#0H-"B`@
M("!F=6YC=&EO;B!G971#;VYF1FEL92@D;&%Y97(I#0H@("`@>PT*("`@("`@
M("!R971U<FX@)'1H:7,M/F9I;&5S6R1L87EE<ET[#0H@("`@?0T*#0H@("`@
M+R\@?7U]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@87)R87D@:6YF;W)M
M871I;VX@;VX@82!R;VQE(&%S('!A<G-E9"!F<F]M(&ET<R!X;6P@9FEL90T*
M("`@("`J($!R971U<FX@=')U97Q014%27T5R<F]R#0H@("`@("H@0&%C8V5S
M<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7V%D9$-O;F9I9U9A
M<G,H)'9A<G,I#0H@("`@>PT*("`@("`@("!I9B`H8V]U;G0H)'9A<G,I(#X@
M,RD@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=2
M;VQE<R!C86X@;VYL>2!D969I;F4@,R!N97<@8V]N9FEG('9A<FEA8FQE<R!O
M<B!L97-S)RD[#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H)'9A<G,@
M87,@)&YA;64@/3X@)'9A<BD@>PT*("`@("`@("`@("`@:68@*"%I<U]A<G)A
M>2@D=F%R*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@G0V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!M=7-T(&)E(&%N
M(&%R<F%Y)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1V87);)W1Y<&4G72DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H)T-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M;75S="!C;VYT86EN(&$@='EP92<I.PT*("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("!I9B`H(6EN7V%R<F%Y*"1V87);)W1Y<&4G72P-
M"B`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<W1R:6YG)RP@)VUA<VLG
M+"`G<&%S<W=O<F0G+"`G9&ER96-T;W)Y)RP@)V9I;&4G+"`G<V5T)RDI*2![
M#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@-"B`@("`@("`@("`@("`@("`@("`@("`@("=#;VYF:6=U<F%T:6]N('1Y
M<&4@;75S="!B92!O;F4@;V8@9&ER96-T;W)Y+"!F:6QE+"!S=')I;F<L("<@
M+@T*("`@("`@("`@("`@("`@("`@("`@("`@)VUA<VLL('-E="P@;W(@<&%S
M<W=O<F0G*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1V87);)V1E9F%U;'0G72DI('L-"B`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H#0H@("`@
M("`@("`@("`@("`@("`@("=#;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N(&UU
M<W0@8V]N=&%I;B!A(&1E9F%U;'0@=F%L=64@*")D969A=6QT(B!I;F1E>"DG
M*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@:68@
M*&ES7V%R<F%Y*"1V87);)V1E9F%U;'0G72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@)')E86Q?9&5F875L="`]("<G.PT*("`@("`@("`@("`@("`@("`@
M("!F;W)E86-H("@D=F%R6R=D969A=6QT)UT@87,@)&-O;F9I9U]V87(@/3X@
M)'9A;"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*'-T<G!O<R@D
M8V]N9FEG7W9A<BP@)W1E>'0G*2`]/3T@,"D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1R96%L7V1E9F%U;'0@+CT@)'9A;#L-"B`@("`@("`@
M("`@("`@("`@("`@("`@('T@96QS96EF("AS=')P;W,H)&-O;F9I9U]V87(L
M("=C;VYS=&%N="<I(#T]/2`P*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*&1E9FEN960H)'9A;"DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)')E86Q?9&5F875L="`N/2!C;VYS=&%N="@D=F%L
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G56YK;F]W;B!C;VYS=&%N="`B)R`N("1V86P@+B`G(B!R97%U97-T960@
M:6X@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M9&5F875L="!V86QU92!F;W(@8V]N9FEG=7)A=&EO;B!V87)I86)L92`B)R`N
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F%M92`N
M("<B)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES+3YC;VYF
M:6=U<F%T:6]N7VEN9F];)&-O;F9I9U]V87)=*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1R96%L7V1E9F%U;'0@+CT-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-O;F9I9W5R871I;VY?:6YF
M;ULD8V]N9FEG7W9A<EU;)V1E9F%U;'0G73L-"B`@("`@("`@("`@("`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G56YK;F]W;B!R97%U97-T(&9O<B`B)R`N("1C;VYF
M:6=?=F%R("X@)R(@=F%L=64@:6X@)R`N#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=D969A=6QT('9A;'5E(&9O<B!C;VYF:6=U<F%T:6]N
M('9A<FEA8FQE("(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&YA;64@+B`G(B<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1V
M87);)V1E9F%U;'0G72`]("1R96%L7V1E9F%U;'0[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@(&EF("@D=F%R6R=T>7!E)UT@/3T@)VEN
M=&5G97(G*2![#0H@("`@("`@("`@("`@("`@("`@("1V87);)V1E9F%U;'0G
M72`]("AI;G1E9V5R*2`D=F%R6R=D969A=6QT)UT[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"%I<W-E="@D
M=F%R6R=D;V,G72DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H#0H@("`@("`@("`@("`@("`@("`@("=#;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N(&UU<W0@8V]N=&%I;B!A('-U;6UA<GD@*")D;V,B
M(&EN9&5X*2<I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"%I
M<W-E="@D=F%R6R=P<F]M<'0G72DI('L-"B`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H#0H@("`@("`@("`@("`@("`@("`@("=#
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N(&UU<W0@8V]N=&%I;B!A('-I;7!L
M92!P<F]M<'0@*")P<F]M<'0B(&EN9&5X*2<I.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@:68@*"%I<W-E="@D=F%R6R=G<F]U<"==*2D@>PT*("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@-"B`@("`@
M("`@("`@("`@("`@("`@)T-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@;75S
M="!C;VYT86EN(&$@<VEM<&QE(&=R;W5P("@B9W)O=7`B(&EN9&5X*2<I.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YC
M;VYF:6=U<F%T:6]N7VEN9F];)&YA;65=*2D@>PT*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G0V]N9FEG=7)A=&EO;B!V87)I
M86)L92`B)R`N("1N86UE("X-"B`@("`@("`@("`@("`@("`@("`@)R(@86QR
M96%D>2!E>&ES=',G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1T
M:&ES+3YC;VYF:6=U<F%T:6]N7VEN9F];)&YA;65=(#T@)'9A<CL-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O+R![
M>WL@7V5N8V]D94]U='!U="@F9&%T82D-"@T*("`@("\J*@T*("`@("`J($5N
M8V]D97,O<V-R86UB;&5S(&-O;F9I9W5R871I;VX@9&%T82!B969O<F4@=W)I
M=&EN9R!T;R!F:6QE<RX-"B`@("`@*B!#=7)R96YT;'DL("=P87-S=V]R9"<@
M=F%L=65S('=I;&P@8F4@8F%S938T+65N8V]D960@87,@=&\@879O:60-"B`@
M("`@*B!T:&%T('!E;W!L92!S<&]T(&-L96%R=&5X="!P87-S=V]R9',@8GD@
M86-C:61E;G0N#0H@("`@("H-"B`@("`@*B!`<&%R86T@87)R87D@*')E9F5R
M96YC92D@87)R87D@=&\@96YC;V1E('9A;'5E<R!I;@T*("`@("`J#0H@("`@
M("H@0')E='5R;B!B;V]L(%12544@;VX@<W5C8V5S<PT*("`@("`J#0H@("`@
M("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7V5N
M8V]D94]U='!U="@F)&1A=&$I#0H@("`@>PT*("`@("`@("!F;W)E86-H("@D
M9&%T82!A<R`D:V5Y(#T^("1V86QU92D@>PT*("`@("`@("`@("`@:68@*"1K
M97D@/3T@)U]?8VAA;FYE;',G*2![#0H@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)&1A=&%;)U]?8VAA;FYE;',G72!A<R`D8VAA;FYE;"`]/B`D8FQA:"D@
M>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V5N8V]D94]U='!U="@D
M9&%T85LG7U]C:&%N;F5L<R==6R1C:&%N;F5L72D[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"%I<W-E="@D
M=&AI<RT^8V]N9FEG=7)A=&EO;E]I;F9O6R1K97E=*2D@>PT*("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M)'1Y<&4@/2`D=&AI<RT^8V]N9FEG=7)A=&EO;E]I;F9O6R1K97E=6R=T>7!E
M)UT[#0H@("`@("`@("`@("!S=VET8V@@*"1T>7!E*2![#0H@("`@("`@("`@
M("`@("`@+R\@=V4@8F%S938T+65N8V]D92!P87-S=V]R9',@<V\@=&AE>2!A
M<F4@870@;&5A<W0-"B`@("`@("`@("`@("`@("`O+R!N;W0@<VAO=VX@:6X@
M<&QA:6X@8GD@86-C:61E;G0-"B`@("`@("`@("`@("`@("!C87-E("=P87-S
M=V]R9"<Z('L-"B`@("`@("`@("`@("`@("`@("`@)&1A=&%;)&ME>5T@/2!B
M87-E-C1?96YC;V1E*"1D871A6R1K97E=*3L-"B`@("`@("`@("`@("`@("`@
M("`@8G)E86L[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(&-A<V4@)VUA<VLG.B![#0H@("`@("`@("`@("`@("`@("`@("1D871A6R1K
M97E=(#T@;V-T9&5C*"1D871A6R1K97E=*3L-"B`@("`@("`@("`@("`@("`@
M("`@8G)E86L[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@
M("\O('U]?0T*("`@("\O('M[>R!?9&5C;V1E26YP=70H)F1A=&$I#0H-"B`@
M("`O*BH-"B`@("`@*B!$96-O9&5S+W5N<V-R86UB;&5S(&-O;F9I9W5R871I
M;VX@9&%T82!A9G1E<B!R96%D:6YG(&9R;VT@9FEL97,N#0H@("`@("H-"B`@
M("`@*B!`<&%R86T@87)R87D@*')E9F5R96YC92D@87)R87D@=&\@96YC;V1E
M('9A;'5E<R!I;@T*("`@("`J#0H@("`@("H@0')E='5R;B!B;V]L(%12544@
M;VX@<W5C8V5S<PT*("`@("`J#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@
M("`@("H-"B`@("`@*B!`<V5E(%!%05)?0V]N9FEG.CI?96YC;V1E3W5T<'5T
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7V1E8V]D94EN<'5T*"8D9&%T82D-
M"B`@("![#0H@("`@("`@(&EF("@A:7-?87)R87DH)&1A=&$I*2![#0H@("`@
M("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@?0T*("`@("`@("!F;W)E
M86-H("@D9&%T82!A<R`D:V5Y(#T^("1V86QU92D@>PT*("`@("`@("`@("`@
M:68@*"1K97D@/3T@)U]?8VAA;FYE;',G*2![#0H@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)&1A=&%;)U]?8VAA;FYE;',G72!A<R`D8VAA;FYE;"`]/B`D
M8FQA:"D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1E8V]D94EN
M<'5T*"1D871A6R=?7V-H86YN96QS)UU;)&-H86YN96Q=*3L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3YC;VYF:6=U<F%T:6]N7VEN9F];)&ME>5TI*2![#0H@("`@
M("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`D='EP92`]("1T:&ES+3YC;VYF:6=U<F%T:6]N7VEN9F];)&ME>5U;
M)W1Y<&4G73L-"B`@("`@("`@("`@('-W:71C:"`H)'1Y<&4I('L-"B`@("`@
M("`@("`@("`@("!C87-E("=P87-S=V]R9"<Z('L-"B`@("`@("`@("`@("`@
M("`@("`@)&1A=&%;)&ME>5T@/2!B87-E-C1?9&5C;V1E*"1D871A6R1K97E=
M*3L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@(&-A<V4@)VUA<VLG.B![#0H@("`@("`@
M("`@("`@("`@("`@("1D871A6R1K97E=(#T@9&5C;V-T*"1D871A6R1K97E=
M*3L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R
M;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!G971$
M969A=6QT0VAA;FYE;"A;;&%Y97)=*0T*("`@("\J*@T*("`@("`J(%)E=')I
M979E('1H92!D969A=6QT(&-H86YN96PN#0H@("`@("H-"B`@("`@*B!/;B!S
M=&%R='5P+"!C:&%N;F5L<R!A<F4@;F]T(&EN:71I86QI>F5D+"!S;R!I9B!T
M:&4@9&5F875L="!C:&%N;F5L(&ES(&YO=`T*("`@("`J('!E87(N<&AP+FYE
M="P@=&AE;B!I;FET:6%L:7IE('1H92!C;VYF:6<N#0H@("`@("H@0'!A<F%M
M('-T<FEN9R!R96=I<W1R>2!L87EE<@T*("`@("`J($!R971U<FX@<W1R:6YG
M?&9A;'-E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T1&5F875L=$-H86YN
M96PH)&QA>65R(#T@;G5L;"D-"B`@("![#0H@("`@("`@("1R970@/2!F86QS
M93L-"B`@("`@("`@:68@*"1L87EE<B`]/3T@;G5L;"D@>PT*("`@("`@("`@
M("`@9F]R96%C:"`H)'1H:7,M/FQA>65R<R!A<R`D;&%Y97(I('L-"B`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/F-O;F9I9W5R871I;VY;)&QA
M>65R75LG9&5F875L=%]C:&%N;F5L)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("1R970@/2`D=&AI<RT^8V]N9FEG=7)A=&EO;ELD;&%Y97)=6R=D969A
M=6QT7V-H86YN96PG73L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!](&5L
M<V5I9B`H:7-S970H)'1H:7,M/F-O;F9I9W5R871I;VY;)&QA>65R75LG9&5F
M875L=%]C:&%N;F5L)UTI*2![#0H@("`@("`@("`@("`D<F5T(#T@)'1H:7,M
M/F-O;F9I9W5R871I;VY;)&QA>65R75LG9&5F875L=%]C:&%N;F5L)UT[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"1R970@/3T@)W!E87(N<&AP+FYE="<@
M)B8@9&5F:6YE9"@G4$5!4E]254Y465!%)RD@)B8@4$5!4E]254Y465!%(#T]
M("=P96-L)RD@>PT*("`@("`@("`@("`@)')E="`]("=P96-L+G!H<"YN970G
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D<F5T*2![#0H@("`@("`@("`@
M("!I9B`H)')E="`A/2`G<&5A<BYP:'`N;F5T)RD@>PT*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?;&%Z>4-H86YN96Q3971U<"@I.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@<F5T=7)N("1R970[#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N(%!%05)?0T].1DE'7T1%1D%53%1?0TA!3DY%3#L-"B`@("!]
M#0H-"B`@("`O+R![>WL@9V5T*&ME>2P@6VQA>65R72D-"B`@("`O*BH-"B`@
M("`@*B!2971U<FYS(&$@8V]N9FEG=7)A=&EO;B!V86QU92P@<')I;W)I=&EZ
M:6YG(&QA>65R<R!A<R!P97(@=&AE#0H@("`@("H@;&%Y97)S('!R;W!E<G1Y
M+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R!C;VYF:6<@:V5Y#0H@
M("`@("H-"B`@("`@*B!`<F5T=7)N(&UI>&5D('1H92!C;VYF:6<@=F%L=64L
M(&]R($Y53$P@:68@;F]T(&9O=6YD#0H@("`@("H-"B`@("`@*B!`86-C97-S
M('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E="@D:V5Y+"`D;&%Y
M97(@/2!N=6QL+"`D8VAA;FYE;"`](&9A;'-E*0T*("`@('L-"B`@("`@("`@
M:68@*"%I<W-E="@D=&AI<RT^8V]N9FEG=7)A=&EO;E]I;F9O6R1K97E=*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N(&YU;&P[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*"1K97D@/3T@)U]?8VAA;FYE;',G*2![#0H@("`@("`@("`@("!R
M971U<FX@;G5L;#L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&ME>2`]/2`G
M9&5F875L=%]C:&%N;F5L)RD@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YG971$969A=6QT0VAA;FYE;"@D;&%Y97(I.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("@A)&-H86YN96PI('L-"B`@("`@("`@("`@("1C:&%N;F5L(#T@
M)'1H:7,M/F=E=$1E9F%U;'1#:&%N;F5L*"D[#0H@("`@("`@('T@96QS96EF
M("@D8VAA;FYE;"`A/2`G<&5A<BYP:'`N;F5T)RD@>PT*("`@("`@("`@("`@
M)'1H:7,M/E]L87IY0VAA;FYE;%-E='5P*"D[#0H@("`@("`@('T-"B`@("`@
M("`@)&-H86YN96P@/2!S=')T;VQO=V5R*"1C:&%N;F5L*3L-"B`@("`@("`@
M#0H@("`@("`@("1T97-T(#T@*&EN7V%R<F%Y*"1K97DL("1T:&ES+3Y?8VAA
M;FYE;$-O;F9I9TEN9F\I*2`_#0H@("`@("`@("`@("`D=&AI<RT^7V=E=$-H
M86YN96Q686QU92@D:V5Y+"`D;&%Y97(L("1C:&%N;F5L*2`Z#0H@("`@("`@
M("`@("!N=6QL.PT*("`@("`@("!I9B`H)'1E<W0@(3T](&YU;&PI('L-"B`@
M("`@("`@("`@(&EF("@D=&AI<RT^7VEN<W1A;&Q2;V]T*2![#0H@("`@("`@
M("`@("`@("`@:68@*&EN7V%R<F%Y*"1T:&ES+3YG971'<F]U<"@D:V5Y*2P-
M"B`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G1FEL92!,;V-A=&EO;G,G
M+"`G1FEL92!,;V-A=&EO;G,@*$%D=F%N8V5D*2<I*2`F)@T*("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YG9714>7!E*"1K97DI(#T]("=D:7)E8W1O
M<GDG*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!R
M97!E;F10871H*"1T97-T+"`D=&AI<RT^7VEN<W1A;&Q2;V]T*3L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U
M<FX@)'1E<W0[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1L87EE<B`]/3T@
M;G5L;"D@>PT*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/FQA>65R<R!A
M<R`D;&%Y97(I('L-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/F-O;F9I9W5R871I;VY;)&QA>65R75LD:V5Y72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@)'1E<W0@/2`D=&AI<RT^8V]N9FEG=7)A=&EO;ELD;&%Y97)=
M6R1K97E=.PT*("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]I;G-T
M86QL4F]O="D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&EN7V%R
M<F%Y*"1T:&ES+3YG971'<F]U<"@D:V5Y*2P-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*"=&:6QE($QO8V%T:6]N<R<L("=&:6QE($QO
M8V%T:6]N<R`H061V86YC960I)RDI("8F#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^9V5T5'EP92@D:V5Y*2`]/2`G9&ER96-T;W)Y
M)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7W!R97!E;F10871H*"1T97-T+"`D=&AI<RT^7VEN<W1A;&Q2;V]T*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H)&ME>2`]/2`G<')E9F5R
M<F5D7VUI<G)O<B<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1R96<@
M/2`F)'1H:7,M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-?;V)J96-T*"1R96<I*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&-H86X@/2`F)')E9RT^9V5T0VAA;FYE;"@D8VAA;FYE
M;"D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)&-H86XI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`D8VAA;FYE;#L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"$D8VAA
M;BT^9V5T36ER<F]R*"1T97-T*2`F)B`D8VAA;BT^9V5T3F%M92@I("$]("1T
M97-T*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D8VAA;FYE;#L@+R\@;6ER<F]R(&1O97,@;F]T(&5X:7-T#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`D=&5S=#L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T@96QS96EF("AI<W-E="@D=&AI<RT^8V]N9FEG
M=7)A=&EO;ELD;&%Y97)=6R1K97E=*2D@>PT*("`@("`@("`@("`@)'1E<W0@
M/2`D=&AI<RT^8V]N9FEG=7)A=&EO;ELD;&%Y97)=6R1K97E=.PT*("`@("`@
M("`@("`@:68@*"1T:&ES+3Y?:6YS=&%L;%)O;W0I('L-"B`@("`@("`@("`@
M("`@("!I9B`H:6Y?87)R87DH)'1H:7,M/F=E=$=R;W5P*"1K97DI+`T*("`@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=&:6QE($QO8V%T:6]N<R<L("=&
M:6QE($QO8V%T:6]N<R`H061V86YC960I)RDI("8F#0H@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/F=E=%1Y<&4H)&ME>2D@/3T@)V1I<F5C=&]R>2<I
M('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<')E<&5N
M9%!A=&@H)'1E<W0L("1T:&ES+3Y?:6YS=&%L;%)O;W0I.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D:V5Y
M(#T]("=P<F5F97)R961?;6ER<F]R)RD@>PT*("`@("`@("`@("`@("`@("1R
M96<@/2`F)'1H:7,M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@("`@("`@("`@
M:68@*&ES7V]B:F5C="@D<F5G*2D@>PT*("`@("`@("`@("`@("`@("`@("`D
M8VAA;B`]("8D<F5G+3YG971#:&%N;F5L*"1C:&%N;F5L*3L-"B`@("`@("`@
M("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&-H86XI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("!R971U<FX@)&-H86YN96P[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"$D8VAA
M;BT^9V5T36ER<F]R*"1T97-T*2`F)B`D8VAA;BT^9V5T3F%M92@I("$]("1T
M97-T*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)&-H86YN
M96P[("\O(&UI<G)O<B!D;V5S(&YO="!E>&ES=`T*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@<F5T=7)N("1T97-T.PT*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B!N=6QL.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!?
M9V5T0VAA;FYE;%9A;'5E*&ME>2P@=F%L=64L(%ML87EE<ETI#0H@("`@+RHJ
M#0H@("`@("H@4F5T=7)N<R!A(&-H86YN96PM<W!E8VEF:6,@8V]N9FEG=7)A
M=&EO;B!V86QU92P@<')I;W)I=&EZ:6YG(&QA>65R<R!A<R!P97(@=&AE#0H@
M("`@("H@;&%Y97)S('!R;W!E<G1Y+@T*("`@("`J#0H@("`@("H@0'!A<F%M
M('-T<FEN9R!C;VYF:6<@:V5Y#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&UI
M>&5D('1H92!C;VYF:6<@=F%L=64L(&]R($Y53$P@:68@;F]T(&9O=6YD#0H@
M("`@("H-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!?9V5T0VAA;FYE;%9A;'5E*"1K97DL("1L87EE<BP@)&-H86YN
M96PI#0H@("`@>PT*("`@("`@("!I9B`H)&ME>2`]/2`G7U]C:&%N;F5L<R<@
M?'P@)&-H86YN96P@/3T@)W!E87(N<&AP+FYE="<I('L-"B`@("`@("`@("`@
M(')E='5R;B!N=6QL.PT*("`@("`@("!]#0H@("`@("`@("1R970@/2!N=6QL
M.PT*("`@("`@("!I9B`H)&QA>65R(#T]/2!N=6QL*2![#0H@("`@("`@("`@
M("!F;W)E86-H("@D=&AI<RT^;&%Y97)S(&%S("1I;&%Y97(I('L-"B`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/F-O;F9I9W5R871I;VY;)&EL
M87EE<EU;)U]?8VAA;FYE;',G75LD8VAA;FYE;%U;)&ME>5TI*2![#0H@("`@
M("`@("`@("`@("`@("`@("1R970@/2`D=&AI<RT^8V]N9FEG=7)A=&EO;ELD
M:6QA>65R75LG7U]C:&%N;F5L<R==6R1C:&%N;F5L75LD:V5Y73L-"B`@("`@
M("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@?0T*("`@("`@("!](&5L<V5I9B`H:7-S970H)'1H:7,M/F-O
M;F9I9W5R871I;VY;)&QA>65R75LG7U]C:&%N;F5L<R==6R1C:&%N;F5L75LD
M:V5Y72DI('L-"B`@("`@("`@("`@("1R970@/2`D=&AI<RT^8V]N9FEG=7)A
M=&EO;ELD;&%Y97)=6R=?7V-H86YN96QS)UU;)&-H86YN96Q=6R1K97E=.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("@D:V5Y(#T]("=P<F5F97)R961?;6ER
M<F]R)RD@>PT*("`@("`@("`@("`@:68@*"1R970@(3T](&YU;&PI('L-"B`@
M("`@("`@("`@("`@("`D<F5G(#T@)B1T:&ES+3YG971296=I<W1R>2@D;&%Y
M97(I.PT*("`@("`@("`@("`@("`@(&EF("AI<U]O8FIE8W0H)')E9RDI('L-
M"B`@("`@("`@("`@("`@("`@("`@)&-H86X@/2`F)')E9RT^9V5T0VAA;FYE
M;"@D8VAA;FYE;"D[#0H@("`@("`@("`@("`@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1C:&%N*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N("1C:&%N;F5L.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@(&EF("@A)&-H86XM/F=E=$UI<G)O<B@D<F5T*2`F)B`D
M8VAA;BT^9V5T3F%M92@I("$]("1R970I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D8VAA;FYE;#L@+R\@;6ER<F]R(&1O97,@;F]T(&5X
M:7-T#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@<F5T=7)N("1R970[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!I9B`H)&-H86YN96P@/3T@)'1H:7,M/F=E=$1E9F%U
M;'1#:&%N;F5L*"1L87EE<BDI('L-"B`@("`@("`@("`@("`@("!R971U<FX@
M)&-H86YN96P[("\O('=E(&UU<W0@=7-E('1H92!C:&%N;F5L(&YA;64@87,@
M=&AE('!R969E<G)E9"!M:7)R;W(-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("\O(&EF('1H92!U<V5R(&AA<R!N;W0@8VAO<V5N(&%N(&%L
M=&5R;F%T90T*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/F=E=$1E9F%U;'1#:&%N;F5L*"1L87EE<BD[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1R970[
M#0H@("`@?0T*#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@<V5T*&ME>2P@
M=F%L=64L(%ML87EE<ETI#0H-"B`@("`O*BH-"B`@("`@*B!3970@82!C;VYF
M:6<@=F%L=64@:6X@82!S<&5C:69I8R!L87EE<B`H9&5F875L=',@=&\@)W5S
M97(G*2X-"B`@("`@*B!%;F9O<F-E<R!T:&4@='EP97,@9&5F:6YE9"!I;B!T
M:&4@8V]N9FEG=7)A=&EO;E]I;F9O(&%R<F%Y+B`@06X-"B`@("`@*B!I;G1E
M9V5R(&-O;F9I9R!V87)I86)L92!W:6QL(&)E(&-A<W0@=&\@:6YT+"!A;F0@
M82!S970@8V]N9FEG#0H@("`@("H@=F%R:6%B;&4@=VEL;"!B92!V86QI9&%T
M960@86=A:6YS="!I=',@;&5G86P@=F%L=65S+@T*("`@("`J#0H@("`@("H@
M0'!A<F%M('-T<FEN9R!C;VYF:6<@:V5Y#0H@("`@("H@0'!A<F%M('-T<FEN
M9R!C;VYF:6<@=F%L=64-"B`@("`@*B!`<&%R86T@<W1R:6YG("AO<'1I;VYA
M;"D@8V]N9FEG(&QA>65R#0H@("`@("H@0'!A<F%M('-T<FEN9R!C:&%N;F5L
M('1O('-E="!T:&ES('9A;'5E(&9O<BP@;W(@;G5L;"!F;W(@9VQO8F%L('9A
M;'5E#0H@("`@("H@0')E='5R;B!B;V]L(%12544@;VX@<W5C8V5S<RP@1D%,
M4T4@;VX@9F%I;'5R90T*("`@("`J+PT*("`@(&9U;F-T:6]N('-E="@D:V5Y
M+"`D=F%L=64L("1L87EE<B`]("=U<V5R)RP@)&-H86YN96P@/2!F86QS92D-
M"B`@("![#0H@("`@("`@(&EF("@D:V5Y(#T]("=?7V-H86YN96QS)RD@>PT*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/F-O;F9I9W5R871I;VY;)&QA>65R72DI('L-
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H)&ME>2`]/2`G9&5F875L=%]C:&%N;F5L)RD@>PT*("`@("`@("`@
M("`@+R\@8V%N(&]N;'D@<V5T('1H:7,@=F%L=64@9VQO8F%L;'D-"B`@("`@
M("`@("`@("1C:&%N;F5L(#T@)W!E87(N<&AP+FYE="<[#0H@("`@("`@("`@
M("!I9B`H)'9A;'5E("$]("=P96%R+G!H<"YN970G*2![#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]L87IY0VAA;FYE;%-E='5P*"1L87EE<BD[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"1K97D@/3T@)W!R
M969E<G)E9%]M:7)R;W(G*2![#0H@("`@("`@("`@("!I9B`H)&-H86YN96P@
M/3T@)U]?=7)I)RD@>PT*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L@
M+R\@8V%N)W0@<V5T('1H92!?7W5R:2!P<V5U9&\M8VAA;FYE;"=S(&UI<G)O
M<@T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)')E9R`]("8D=&AI<RT^
M9V5T4F5G:7-T<GDH)&QA>65R*3L-"B`@("`@("`@("`@(&EF("AI<U]O8FIE
M8W0H)')E9RDI('L-"B`@("`@("`@("`@("`@("`D8VAA;B`]("8D<F5G+3YG
M971#:&%N;F5L*"1C:&%N;F5L(#\@)&-H86YN96P@.B`G<&5A<BYP:'`N;F5T
M)RD[#0H@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&-H86XI
M*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"$D8VAA;BT^9V5T
M36ER<F]R*"1V86QU92D@)B8@)&-H86XM/F=E=$YA;64H*2`A/2`D=F%L=64I
M('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.R`O+R!M:7)R
M;W(@9&]E<R!N;W0@97AI<W0-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3YC
M;VYF:6=U<F%T:6]N7VEN9F];)&ME>5TI*2![#0H@("`@("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@97AT<F%C="@D=&AI<RT^
M8V]N9FEG=7)A=&EO;E]I;F9O6R1K97E=*3L-"B`@("`@("`@<W=I=&-H("@D
M='EP92D@>PT*("`@("`@("`@("`@8V%S92`G:6YT96=E<B<Z#0H@("`@("`@
M("`@("`@("`@)'9A;'5E(#T@*&EN="DD=F%L=64[#0H@("`@("`@("`@("`@
M("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=S970G.B![#0H@("`@("`@
M("`@("`@("`@+R\@268@82!V86QI9%]S970@:7,@<W!E8VEF:65D+"!R97%U
M:7)E('1H92!V86QU92!T;PT*("`@("`@("`@("`@("`@("\O(&)E(&EN('1H
M92!S970N("!)9B!T:&5R92!I<R!N;R!V86QI9%]S970L(&%C8V5P=`T*("`@
M("`@("`@("`@("`@("\O(&%N>2!V86QU92X-"B`@("`@("`@("`@("`@("!I
M9B`H)'9A;&ED7W-E="D@>PT*("`@("`@("`@("`@("`@("`@("!R97-E="@D
M=F%L:61?<V5T*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*"AK97DH)'9A
M;&ED7W-E="D@/3T](#`@)B8@(6EN7V%R<F%Y*"1V86QU92P@)'9A;&ED7W-E
M="DI('Q\#0H@("`@("`@("`@("`@("`@("`@("`@("`H:V5Y*"1V86QI9%]S
M970I("$]/2`P("8F(&5M<'1Y*"1V86QI9%]S971;)'9A;'5E72DI*0T*("`@
M("`@("`@("`@("`@("`@("![#0H@("`@("`@("`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D8VAA;FYE;"D@>PT*("`@
M("`@("`@("`@)&-H86YN96P@/2`D=&AI<RT^9V5T*"=D969A=6QT7V-H86YN
M96PG+"!N=6QL+"`G<&5A<BYP:'`N;F5T)RD[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*"%I;E]A<G)A>2@D8VAA;FYE;"P@)'1H:7,M/E]C:&%N;F5L<RDI
M('L-"B`@("`@("`@("`@("1T:&ES+3Y?;&%Z>4-H86YN96Q3971U<"@D;&%Y
M97(I.PT*("`@("`@("`@("`@)')E9R`]("8D=&AI<RT^9V5T4F5G:7-T<GDH
M)&QA>65R*3L-"B`@("`@("`@("`@(&EF("@D<F5G*2![#0H@("`@("`@("`@
M("`@("`@)&-H86YN96P@/2`D<F5G+3YC:&%N;F5L3F%M92@D8VAA;FYE;"D[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(6EN7V%R<F%Y*"1C
M:&%N;F5L+"`D=&AI<RT^7V-H86YN96QS*2D@>PT*("`@("`@("`@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H)&-H86YN96P@(3T@)W!E87(N<&AP+FYE="<I('L-"B`@("`@
M("`@("`@(&EF("AI;E]A<G)A>2@D:V5Y+"`D=&AI<RT^7V-H86YN96Q#;VYF
M:6=);F9O*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3YC;VYF:6=U<F%T
M:6]N6R1L87EE<EU;)U]?8VAA;FYE;',G75LD8VAA;FYE;%U;)&ME>5T@/2`D
M=F%L=64[#0H@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M(&EF("@D:V5Y(#T]("=D969A=6QT7V-H86YN96PG*2![#0H@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D<F5G*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`D<F5G(#T@)B1T:&ES+3YG971296=I<W1R>2@D;&%Y97(I.PT*("`@("`@
M("`@("`@("`@("`@("!I9B`H(21R96<I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1R96<@/2`F)'1H:7,M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@:68@*"1R96<I('L-"B`@("`@("`@("`@("`@("`@("`@)'9A;'5E
M(#T@)')E9RT^8VAA;FYE;$YA;64H)'9A;'5E*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@:68@*"$D=F%L=64I('L-"B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^8V]N
M9FEG=7)A=&EO;ELD;&%Y97)=6R1K97E=(#T@)'9A;'5E.PT*("`@("`@("!I
M9B`H)&ME>2`]/2`G<&AP7V1I<B<@)B8@(21T:&ES+3Y?;F]296=I<W1R>2D@
M>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W)E9VES=')Y6R1L
M87EE<ETI('Q\#0H@("`@("`@("`@("`@("`@("`D=F%L=64@(3T@)'1H:7,M
M/E]R96=I<W1R>5LD;&%Y97)=+3YI;G-T86QL7V1I<BD@>PT*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<F5G:7-T<GE;)&QA>65R72`]("9N97<@4$5!4E]2
M96=I<W1R>2@D=F%L=64I.PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5G
M26YI=&EA;&EZ961;)&QA>65R72`](&9A;'-E.PT*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<F5G:7-T<GE;)&QA>65R72T^<V5T0V]N9FEG*"1T:&ES*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@=')U
M93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("!F=6YC=&EO;B!?;&%Z>4-H
M86YN96Q3971U<"@D=7-E;&%Y97(@/2!F86QS92D-"B`@("![#0H@("`@("`@
M(&EF("@D=&AI<RT^7VYO4F5G:7-T<GDI('L-"B`@("`@("`@("`@(')E='5R
M;CL-"B`@("`@("`@?0T*("`@("`@("`D;65R9V4@/2!F86QS93L-"B`@("`@
M("`@9F]R96%C:"`H)'1H:7,M/E]R96=I<W1R>2!A<R`D;&%Y97(@/3X@)'`I
M('L-"B`@("`@("`@("`@(&EF("@D=7-E;&%Y97(@)B8@)'5S96QA>65R("$]
M("1L87EE<BD@>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@:68@*"$D=&AI<RT^7W)E9TEN:71I86QI
M>F5D6R1L87EE<ETI('L-"B`@("`@("`@("`@("`@("!I9B`H)&QA>65R(#T]
M("=D969A=6QT)R`F)B!I<W-E="@D=&AI<RT^7W)E9VES=')Y6R=U<V5R)UTI
M('Q\#0H@("`@("`@("`@("`@("`@("`@("`@:7-S970H)'1H:7,M/E]R96=I
M<W1R>5LG<WES=&5M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("\O(&]N
M;'D@=7-E('1H92!D969A=6QT(')E9VES=')Y(&EF('1H97)E(&%R92!N;R!A
M;'1E<FYA=&EV97,-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@A:7-?;V)J
M96-T*"1T:&ES+3Y?<F5G:7-T<GE;)&QA>65R72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@:68@*"1P:'!D:7(@/2`D=&AI<RT^9V5T*"=P:'!?9&ER)RP@
M)&QA>65R+"`G<&5A<BYP:'`N;F5T)RDI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<F5G:7-T<GE;)&QA>65R72`]("9N97<@4$5!4E]2
M96=I<W1R>2@D<&AP9&ER*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<F5G:7-T<GE;)&QA>65R72T^<V5T0V]N9FEG*"1T:&ES*3L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5G26YI=&EA;&EZ961;
M)&QA>65R72`](&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)'1H:7,M/E]R96=I
M<W1R>5LD;&%Y97)=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;CL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T0VAA;FYE;',H)'1H:7,M/E]R
M96=I<W1R>5LD;&%Y97)=+3YL:7-T0VAA;FYE;',H*2P@)&UE<F=E*3L-"B`@
M("`@("`@("`@("`@("`D=&AI<RT^7W)E9TEN:71I86QI>F5D6R1L87EE<ET@
M/2!T<G5E.PT*("`@("`@("`@("`@("`@("1M97)G92`]('1R=64[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("!]#0H@("`@+R\@>WM[('-E=$-H
M86YN96QS*"D-"B`@("`-"B`@("`O*BH-"B`@("`@*B!3970@=&AE(&QI<W0@
M;V8@8VAA;FYE;',N#0H@("`@("H-"B`@("`@*B!4:&ES('-H;W5L9"!B92!S
M970@=FEA(&$@8V%L;"!T;R![0&QI;FL@4$5!4E]296=I<W1R>3HZ;&ES=$-H
M86YN96QS*"E]#0H@("`@("H@0'!A<F%M(&%R<F%Y#0H@("`@("H@0'!A<F%M
M(&)O;VP-"B`@("`@*B!`<F5T=7)N(&)O;VP@<W5C8V5S<R!O9B!O<&5R871I
M;VX-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S971#:&%N;F5L<R@D8VAA;FYE
M;',L("1M97)G92`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*"%I<U]A
M<G)A>2@D8VAA;FYE;',I*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"1M97)G92D@>PT*("`@("`@("`@
M("`@)'1H:7,M/E]C:&%N;F5L<R`](&%R<F%Y7VUE<F=E*"1T:&ES+3Y?8VAA
M;FYE;',L("1C:&%N;F5L<RD[#0H@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`D=&AI<RT^7V-H86YN96QS(#T@)&-H86YN96QS.PT*("`@("`@("!]
M#0H@("`@("`@(&9O<F5A8V@@*"1C:&%N;F5L<R!A<R`D8VAA;FYE;"D@>PT*
M("`@("`@("`@("`@)&-H86YN96P@/2!S=')T;VQO=V5R*"1C:&%N;F5L*3L-
M"B`@("`@("`@("`@(&EF("@D8VAA;FYE;"`]/2`G<&5A<BYP:'`N;F5T)RD@
M>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/FQA>65R<R!A<R`D;&%Y97(I
M('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YC;VYF:6=U
M<F%T:6]N6R1L87EE<EU;)U]?8VAA;FYE;',G75LD8VAA;FYE;%TI#0H@("`@
M("`@("`@("`@("`@("`@("`@?'P@(6ES7V%R<F%Y*"1T:&ES+3YC;VYF:6=U
M<F%T:6]N6R1L87EE<EU;)U]?8VAA;FYE;',G75LD8VAA;FYE;%TI*2![#0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YC;VYF:6=U<F%T:6]N6R1L87EE
M<EU;)U]?8VAA;FYE;',G75LD8VAA;FYE;%T@/2!A<G)A>2@I.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![
M>WL@9V5T5'EP92AK97DI#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE('1Y
M<&4@;V8@82!C;VYF:6<@=F%L=64N#0H@("`@("H-"B`@("`@*B!`<&%R86T@
M<W1R:6YG("!C;VYF:6<@:V5Y#0H@("`@("H-"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R!T>7!E+"!O;F4@;V8@(G-T<FEN9R(L(")I;G1E9V5R(BP@(F9I;&4B
M+`T*("`@("`J(")D:7)E8W1O<GDB+"`B<V5T(B!O<B`B<&%S<W=O<F0B+@T*
M("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*@T*("`@("`J
M+PT*("`@(&9U;F-T:6]N(&=E=%1Y<&4H)&ME>2D-"B`@("![#0H@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^8V]N9FEG=7)A=&EO;E]I;F9O6R1K97E=*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YC;VYF:6=U<F%T:6]N7VEN
M9F];)&ME>5U;)W1Y<&4G73L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&=E=$1O
M8W,H:V5Y*0T*#0H@("`@+RHJ#0H@("`@("H@1V5T('1H92!D;V-U;65N=&%T
M:6]N(&9O<B!A(&-O;F9I9R!V86QU92X-"B`@("`@*@T*("`@("`J($!P87)A
M;2!S=')I;F<@(&-O;F9I9R!K97D-"B`@("`@*@T*("`@("`J($!R971U<FX@
M<W1R:6YG(&1O8W5M96YT871I;VX@<W1R:6YG#0H@("`@("H-"B`@("`@*B!`
M86-C97-S('!U8FQI8PT*("`@("`J#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M9V5T1&]C<R@D:V5Y*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3YC;VYF:6=U<F%T:6]N7VEN9F];)&ME>5TI*2![#0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/F-O;F9I9W5R871I;VY?:6YF;ULD:V5Y75LG9&]C)UT[
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"B`@
M("`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T4')O;7!T*&ME>2D-"@T*("`@
M("\J*@T*("`@("`J($=E="!T:&4@<VAO<G0@9&]C=6UE;G1A=&EO;B!F;W(@
M82!C;VYF:6<@=F%L=64N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG
M("!C;VYF:6<@:V5Y#0H@("`@("H-"B`@("`@*B!`<F5T=7)N('-T<FEN9R!S
M:&]R="!D;V-U;65N=&%T:6]N('-T<FEN9PT*("`@("`J#0H@("`@("H@0&%C
M8V5S<R!P=6)L:6,-"B`@("`@*@T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E
M=%!R;VUP="@D:V5Y*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3YC;VYF:6=U<F%T:6]N7VEN9F];)&ME>5TI*2![#0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/F-O;F9I9W5R871I;VY?:6YF;ULD:V5Y75LG<')O;7!T
M)UT[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-
M"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T1W)O=7`H:V5Y*0T*#0H@("`@
M+RHJ#0H@("`@("H@1V5T('1H92!P87)A;65T97(@9W)O=7`@9F]R(&$@8V]N
M9FEG(&ME>2X-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@(&-O;F9I
M9R!K97D-"B`@("`@*@T*("`@("`J($!R971U<FX@<W1R:6YG('!A<F%M971E
M<B!G<F]U<`T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@
M*@T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$=R;W5P*"1K97DI#0H@("`@
M>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/F-O;F9I9W5R871I;VY?:6YF
M;ULD:V5Y72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^8V]N9FEG
M=7)A=&EO;E]I;F9O6R1K97E=6R=G<F]U<"==.PT*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O
M+R![>WL@9V5T1W)O=7!S*"D-"@T*("`@("\J*@T*("`@("`J($=E="!T:&4@
M;&ES="!O9B!P87)A;65T97(@9W)O=7!S+@T*("`@("`J#0H@("`@("H@0')E
M='5R;B!A<G)A>2!L:7-T(&]F('!A<F%M971E<B!G<F]U<',-"B`@("`@*@T*
M("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!G971'<F]U<',H*0T*("`@('L-"B`@("`@("`@)'1M<"`](&%R
M<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YC;VYF:6=U<F%T:6]N
M7VEN9F\@87,@)&ME>2`]/B`D:6YF;RD@>PT*("`@("`@("`@("`@)'1M<%LD
M:6YF;ULG9W)O=7`G75T@/2`Q.PT*("`@("`@("!]#0H@("`@("`@(')E='5R
M;B!A<G)A>5]K97ES*"1T;7`I.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@
M("\O('M[>R!G971'<F]U<$ME>7,H*0T*#0H@("`@+RHJ#0H@("`@("H@1V5T
M('1H92!L:7-T(&]F('1H92!P87)A;65T97)S(&EN(&$@9W)O=7`N#0H@("`@
M("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("1G<F]U<"!P87)A;65T97(@9W)O
M=7`-"B`@("`@*@T*("`@("`J($!R971U<FX@87)R87D@;&ES="!O9B!P87)A
M;65T97)S(&EN("1G<F]U<`T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L
M:6,-"B`@("`@*@T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$=R;W5P2V5Y
M<R@D9W)O=7`I#0H@("`@>PT*("`@("`@("`D:V5Y<R`](&%R<F%Y*"D[#0H@
M("`@("`@(&9O<F5A8V@@*"1T:&ES+3YC;VYF:6=U<F%T:6]N7VEN9F\@87,@
M)&ME>2`]/B`D:6YF;RD@>PT*("`@("`@("`@("`@:68@*"1I;F9O6R=G<F]U
M<"==(#T]("1G<F]U<"D@>PT*("`@("`@("`@("`@("`@("1K97ES6UT@/2`D
M:V5Y.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R
M;B`D:V5Y<SL-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T
M4V5T5F%L=65S*&ME>2D-"@T*("`@("\J*@T*("`@("`J($=E="!T:&4@;&ES
M="!O9B!A;&QO=V5D('-E="!V86QU97,@9F]R(&$@8V]N9FEG('9A;'5E+B`@
M4F5T=7)N<PT*("`@("`J($Y53$P@9F]R(&-O;F9I9R!V86QU97,@=&AA="!A
M<F4@;F]T('-E=',N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("!C
M;VYF:6<@:V5Y#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&%R<F%Y(&5N=6UE
M<F%T960@87)R87D@;V8@<V5T('9A;'5E<RP@;W(@3E5,3"!I9B!T:&4-"B`@
M("`@*B`@("`@("`@("`@("`@(&-O;F9I9R!K97D@:7,@=6YK;F]W;B!O<B!N
M;W0@82!S970-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@
M("H-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G9713971686QU97,H)&ME>2D-
M"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^8V]N9FEG=7)A=&EO
M;E]I;F9O6R1K97E=*2`F)@T*("`@("`@("`@("`@:7-S970H)'1H:7,M/F-O
M;F9I9W5R871I;VY?:6YF;ULD:V5Y75LG='EP92==*2`F)@T*("`@("`@("`@
M("`@)'1H:7,M/F-O;F9I9W5R871I;VY?:6YF;ULD:V5Y75LG='EP92==(#T]
M("=S970G*0T*("`@("`@("![#0H@("`@("`@("`@("`D=F%L:61?<V5T(#T@
M)'1H:7,M/F-O;F9I9W5R871I;VY?:6YF;ULD:V5Y75LG=F%L:61?<V5T)UT[
M#0H@("`@("`@("`@("!R97-E="@D=F%L:61?<V5T*3L-"B`@("`@("`@("`@
M(&EF("AK97DH)'9A;&ED7W-E="D@/3T](#`I('L-"B`@("`@("`@("`@("`@
M("!R971U<FX@)'9A;&ED7W-E=#L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(')E='5R;B!A<G)A>5]K97ES*"1V86QI9%]S970I.PT*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B!N=6QL.PT*("`@('T-"@T*("`@("\O('U]?0T*
M("`@("\O('M[>R!G971+97ES*"D-"@T*("`@("\J*@T*("`@("`J($=E="!A
M;&P@=&AE(&-U<G)E;G0@8V]N9FEG(&ME>7,N#0H@("`@("H-"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y('-I;7!L92!A<G)A>2!O9B!C;VYF:6<@:V5Y<PT*("`@
M("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!G971+97ES*"D-"B`@("![#0H@("`@("`@("1K97ES(#T@87)R87DH
M*3L-"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/FQA>65R<R!A<R`D;&%Y97(I
M('L-"B`@("`@("`@("`@("1T97-T(#T@)'1H:7,M/F-O;F9I9W5R871I;VY;
M)&QA>65R73L-"B`@("`@("`@("`@(&EF("AI<W-E="@D=&5S=%LG7U]C:&%N
M;F5L<R==*2D@>PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T97-T6R=?
M7V-H86YN96QS)UT@87,@)&-H86YN96P@/3X@)&-O;F9I9W,I('L-"B`@("`@
M("`@("`@("`@("`@("`@)&ME>7,@/2!A<G)A>5]M97)G92@D:V5Y<RP@)&-O
M;F9I9W,I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('5N<V5T*"1T97-T6R=?7V-H86YN96QS)UTI.PT*("`@("`@
M("`@("`@)&ME>7,@/2!A<G)A>5]M97)G92@D:V5Y<RP@)'1E<W0I.PT*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B!A<G)A>5]K97ES*"1K97ES*3L-"B`@
M("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@<F5M;W9E*&ME>2P@6VQA
M>65R72D-"@T*("`@("\J*@T*("`@("`J(%)E;6]V92!T:&4@82!C;VYF:6<@
M:V5Y(&9R;VT@82!S<&5C:69I8R!C;VYF:6<@;&%Y97(N#0H@("`@("H-"B`@
M("`@*B!`<&%R86T@<W1R:6YG(&-O;F9I9R!K97D-"B`@("`@*@T*("`@("`J
M($!P87)A;2!S=')I;F<@*&]P=&EO;F%L*2!C;VYF:6<@;&%Y97(-"B`@("`@
M*@T*("`@("`J($!R971U<FX@8F]O;"!44E5%(&]N('-U8V-E<W,L($9!3%-%
M(&]N(&9A:6QU<F4-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@<F5M;W9E*"1K97DL("1L87EE<B`]("=U
M<V5R)RD-"B`@("![#0H@("`@("`@("1C:&%N;F5L(#T@)'1H:7,M/F=E=$1E
M9F%U;'1#:&%N;F5L*"D[#0H@("`@("`@(&EF("@D8VAA;FYE;"`A/3T@)W!E
M87(N<&AP+FYE="<I('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M8V]N9FEG=7)A=&EO;ELD;&%Y97)=6R=?7V-H86YN96QS)UU;)&-H86YN96Q=
M6R1K97E=*2D@>PT*("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES+3YC;VYF
M:6=U<F%T:6]N6R1L87EE<EU;)U]?8VAA;FYE;',G75LD8VAA;FYE;%U;)&ME
M>5TI.PT*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^8V]N
M9FEG=7)A=&EO;ELD;&%Y97)=6R1K97E=*2D@>PT*("`@("`@("`@("`@=6YS
M970H)'1H:7,M/F-O;F9I9W5R871I;VY;)&QA>65R75LD:V5Y72D[#0H@("`@
M("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(')E
M;6]V94QA>65R*&QA>65R*0T*#0H@("`@+RHJ#0H@("`@("H@5&5M<&]R87)I
M;'D@<F5M;W9E(&%N(&5N=&ER92!C;VYF:6<@;&%Y97(N("!54T4@5TE42"!#
M05)%(0T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R!C;VYF:6<@:V5Y
M#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("AO<'1I;VYA;"D@8V]N
M9FEG(&QA>65R#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&)O;VP@5%)512!O
M;B!S=6-C97-S+"!&04Q312!O;B!F86EL=7)E#0H@("`@("H-"B`@("`@*B!`
M86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(')E;6]V94QA
M>65R*"1L87EE<BD-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M8V]N9FEG=7)A=&EO;ELD;&%Y97)=*2D@>PT*("`@("`@("`@("`@)'1H:7,M
M/F-O;F9I9W5R871I;VY;)&QA>65R72`](&%R<F%Y*"D[#0H@("`@("`@("`@
M("!R971U<FX@=')U93L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[('-T;W)E*%ML
M87EE<ETI#0H-"B`@("`O*BH-"B`@("`@*B!3=&]R97,@8V]N9FEG=7)A=&EO
M;B!D871A(&EN(&$@;&%Y97(N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R
M:6YG(&-O;F9I9R!L87EE<B!T;R!S=&]R90T*("`@("`J#0H@("`@("H@0')E
M='5R;B!B;V]L(%12544@;VX@<W5C8V5S<RP@;W(@4$5!4B!E<G)O<B!O;B!F
M86EL=7)E#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J
M+PT*("`@(&9U;F-T:6]N('-T;W)E*"1L87EE<B`]("=U<V5R)RP@)&1A=&$@
M/2!N=6QL*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3YW<FET94-O
M;F9I9T9I;&4H;G5L;"P@)&QA>65R+"`D9&%T82D[#0H@("`@?0T*#0H@("`@
M+R\@?7U]#0H@("`@+R\@>WM[('1O1&5F875L="AK97DI#0H-"B`@("`O*BH-
M"B`@("`@*B!5;G-E="!T:&4@=7-E<BUD969I;F5D('9A;'5E(&]F(&$@8V]N
M9FEG(&ME>2P@<F5V97)T:6YG('1H90T*("`@("`J('9A;'5E('1O('1H92!S
M>7-T96TM9&5F:6YE9"!O;F4N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R
M:6YG(&-O;F9I9R!K97D-"B`@("`@*@T*("`@("`J($!R971U<FX@8F]O;"!4
M4E5%(&]N('-U8V-E<W,L($9!3%-%(&]N(&9A:6QU<F4-"B`@("`@*@T*("`@
M("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=&]$
M969A=6QT*"1K97DI#0H@("`@>PT*("`@("`@("!T<FEG9V5R7V5R<F]R*")0
M14%27T-O;F9I9SHZ=&]$969A=6QT*"D@9&5P<F5C871E9"P@=7-E(%!%05)?
M0V]N9FEG.CIR96UO=F4H*2!I;G-T96%D(BP@15]54T527TY/5$E#12D[#0H@
M("`@("`@(')E='5R;B`D=&AI<RT^<F5M;W9E*"1K97DL("=U<V5R)RD[#0H@
M("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&1E9FEN961">2AK97DI
M#0H-"B`@("`O*BH-"B`@("`@*B!496QL<R!W:&%T(&-O;F9I9R!L87EE<B!T
M:&%T(&=E=',@=&\@9&5F:6YE(&$@:V5Y+@T*("`@("`J#0H@("`@("H@0'!A
M<F%M('-T<FEN9R!C;VYF:6<@:V5Y#0H@("`@("H@0'!A<F%M(&)O;VQE86X@
M<F5T=7)N('1H92!D969I;FEN9R!C:&%N;F5L#0H@("`@("H-"B`@("`@*B!`
M<F5T=7)N('-T<FEN9WQA<G)A>2!T:&4@8V]N9FEG(&QA>65R+"!O<B!A;B!E
M;7!T>2!S=')I;F<@:68@;F]T(&9O=6YD+@T*("`@("`J#0H@("`@("H@("`@
M("`@("!I9B`D<F5T=7)N8VAA;FYE;"P@=&AE(')E='5R;B!I<R!A;B!A<G)A
M>2!A<G)A>2@G;&%Y97(G(#T^(&QA>65R;F%M92P-"B`@("`@*B`@("`@("`@
M("=C:&%N;F5L)R`]/B!C:&%N;F5L;F%M92DL(&]R(&%N(&5M<'1Y('-T<FEN
M9R!I9B!N;W0@9F]U;F0-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9&5F:6YE9$)Y*"1K97DL("1R971U
M<FYC:&%N;F5L(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!F;W)E86-H("@D
M=&AI<RT^;&%Y97)S(&%S("1L87EE<BD@>PT*("`@("`@("`@("`@)&-H86YN
M96P@/2`D=&AI<RT^9V5T1&5F875L=$-H86YN96PH*3L-"B`@("`@("`@("`@
M(&EF("@D8VAA;FYE;"`A/3T@)W!E87(N<&AP+FYE="<I('L-"B`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/F-O;F9I9W5R871I;VY;)&QA>65R
M75LG7U]C:&%N;F5L<R==6R1C:&%N;F5L75LD:V5Y72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"1R971U<FYC:&%N;F5L*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("!R971U<FX@87)R87DH)VQA>65R)R`]/B`D;&%Y97(L
M("=C:&%N;F5L)R`]/B`D8VAA;FYE;"D[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1L87EE<CL-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/F-O;F9I9W5R871I;VY;)&QA>65R75LD:V5Y72DI('L-
M"B`@("`@("`@("`@("`@("!I9B`H)')E='5R;F-H86YN96PI('L-"B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"=L87EE<B<@/3X@)&QA>65R
M+"`G8VAA;FYE;"<@/3X@)W!E87(N<&AP+FYE="<I.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!R971U<FX@)&QA>65R.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`G)SL-"B`@("!]
M#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@:7-$969A=6QT960H:V5Y*0T*
M#0H@("`@+RHJ#0H@("`@("H@5&5L;',@=VAE=&AE<B!A(&-O;F9I9R!V86QU
M92!H87,@82!S>7-T96TM9&5F:6YE9"!V86QU92X-"B`@("`@*@T*("`@("`J
M($!P87)A;2!S=')I;F<@("!C;VYF:6<@:V5Y#0H@("`@("H-"B`@("`@*B!`
M<F5T=7)N(&)O;VP-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@
M("`@("H-"B`@("`@*B!`9&5P<F5C871E9`T*("`@("`J+PT*("`@(&9U;F-T
M:6]N(&ES1&5F875L=&5D*"1K97DI#0H@("`@>PT*("`@("`@("!T<FEG9V5R
M7V5R<F]R*")014%27T-O;F9I9SHZ:7-$969A=6QT960H*2!D97!R96-A=&5D
M+"!U<V4@4$5!4E]#;VYF:6<Z.F1E9FEN961">2@I(&EN<W1E860B+"!%7U53
M15)?3D]424-%*3L-"B`@("`@("`@<F5T=7)N("1T:&ES+3YD969I;F5D0GDH
M)&ME>2D@/3T@)W-Y<W1E;2<[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@
M+R\@>WM[(&ES1&5F:6YE9"AK97DI#0H-"B`@("`O*BH-"B`@("`@*B!496QL
M<R!W:&5T:&5R(&$@9VEV96X@:V5Y(&5X:7-T<R!A<R!A(&-O;F9I9R!V86QU
M92X-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@8V]N9FEG(&ME>0T*
M("`@("`J#0H@("`@("H@0')E='5R;B!B;V]L('=H971H97(@/&-O;F9I9R!K
M97D^(&5X:7-T<R!I;B!T:&ES(&]B:F5C=`T*("`@("`J#0H@("`@("H@0&%C
M8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!I<T1E9FEN960H
M)&ME>2D-"B`@("![#0H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YL87EE<G,@
M87,@)&QA>65R*2![#0H@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/F-O
M;F9I9W5R871I;VY;)&QA>65R75LD:V5Y72DI('L-"B`@("`@("`@("`@("`@
M("!R971U<FX@=')U93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@
M+R\@>WM[(&ES1&5F:6YE9$QA>65R*&ME>2D-"@T*("`@("\J*@T*("`@("`J
M(%1E;&QS('=H971H97(@82!G:79E;B!C;VYF:6<@;&%Y97(@97AI<W1S+@T*
M("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R!C;VYF:6<@;&%Y97(-"B`@
M("`@*@T*("`@("`J($!R971U<FX@8F]O;"!W:&5T:&5R(#QC;VYF:6<@;&%Y
M97(^(&5X:7-T<R!I;B!T:&ES(&]B:F5C=`T*("`@("`J#0H@("`@("H@0&%C
M8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!I<T1E9FEN961,
M87EE<B@D;&%Y97(I#0H@("`@>PT*("`@("`@("!R971U<FX@:7-S970H)'1H
M:7,M/F-O;F9I9W5R871I;VY;)&QA>65R72D[#0H@("`@?0T*#0H@("`@+R\@
M?7U]#0H@("`@+R\@>WM[(&=E=$QA>65R<R@I#0H-"B`@("`O*BH-"B`@("`@
M*B!2971U<FYS('1H92!L87EE<G,@9&5F:6YE9"`H97AC97!T('1H92`G9&5F
M875L="<@;VYE*0T*("`@("`J#0H@("`@("H@0')E='5R;B!A<G)A>2!O9B!T
M:&4@9&5F:6YE9"!L87EE<G,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971,
M87EE<G,H*0T*("`@('L-"B`@("`@("`@)&-F(#T@)'1H:7,M/F-O;F9I9W5R
M871I;VX[#0H@("`@("`@('5N<V5T*"1C9ELG9&5F875L="==*3L-"B`@("`@
M("`@<F5T=7)N(&%R<F%Y7VME>7,H)&-F*3L-"B`@("!]#0H-"B`@("`O+R!]
M?7T-"B`@("`O+R![>WL@87!I5F5R<VEO;B@I#0H@("`@9G5N8W1I;VX@87!I
M5F5R<VEO;B@I#0H@("`@>PT*("`@("`@("!R971U<FX@)S$N,2<[#0H@("`@
M?0T*("`@("\O('U]?0T*#0H@("`@+RHJ#0H@("`@("H@0')E='5R;B!014%2
M7U)E9VES=')Y#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)F=E=%)E9VES=')Y
M*"1U<V4@/2!N=6QL*0T*("`@('L-"B`@("`@("`@:68@*"1U<V4@/3T](&YU
M;&PI('L-"B`@("`@("`@("`@("1L87EE<B`]("=U<V5R)SL-"B`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("1L87EE<B`]("1U<V4[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<F5G:7-T<GE;)&QA>65R
M72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)E9VES=')Y6R1L
M87EE<ET[#0H@("`@("`@('T@96QS96EF("@D=7-E(#T]/2!N=6QL("8F(&ES
M<V5T*"1T:&ES+3Y?<F5G:7-T<GE;)W-Y<W1E;2==*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?<F5G:7-T<GE;)W-Y<W1E;2==.PT*("`@("`@
M("!](&5L<V5I9B`H)'5S92`]/3T@;G5L;"`F)B!I<W-E="@D=&AI<RT^7W)E
M9VES=')Y6R=D969A=6QT)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]R96=I<W1R>5LG9&5F875L="==.PT*("`@("`@("!](&5L<V5I9B`H
M)'5S92D@>PT*("`@("`@("`@("`@)&$@/2!F86QS93L-"B`@("`@("`@("`@
M(')E='5R;B`D83L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("\O
M(&]N;'D@9V\@:&5R92!I9B!N=6QL('=A<R!P87-S960@:6X-"B`@("`@("`@
M("`@(&1I92@B0U))5$E#04P@15)23U(Z(%)E9VES=')Y(&-O=6QD(&YO="!B
M92!I;FET:6%L:7IE9"!F<F]M(&%N>2!V86QU92(I.PT*("`@("`@("!]#0H@
M("`@?0T*("`@("\J*@T*("`@("`J(%1H:7,@:7,@=&\@86QL;W<@8W5S=&]M
M:7IA=&EO;B!L:6ME('1H92!U<V4@;V8@:6YS=&%L;')O;W0-"B`@("`@*B!`
M<&%R86T@4$5!4E]296=I<W1R>0T*("`@("`J($!R971U<FX@8F]O;`T*("`@
M("`J+PT*("`@(&9U;F-T:6]N('-E=%)E9VES=')Y*"8D<F5G+"`D;&%Y97(@
M/2`G=7-E<B<I#0H@("`@>PT*("`@("`@("!I9B`H)'1H:7,M/E]N;U)E9VES
M=')Y*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"%I;E]A<G)A>2@D;&%Y97(L(&%R<F%Y*"=U<V5R)RP@
M)W-Y<W1E;2<I*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M("`@("!]#0H@("`@("`@("1T:&ES+3Y?<F5G:7-T<GE;)&QA>65R72`]("8D
M<F5G.PT*("`@("`@("!I9B`H:7-?;V)J96-T*"1R96<I*2![#0H@("`@("`@
M("`@("`D=&AI<RT^7W)E9VES=')Y6R1L87EE<ETM/G-E=$-O;F9I9R@D=&AI
M<RD[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*
M#0H@("`@9G5N8W1I;VX@;F]296=I<W1R>2@I#0H@("`@>PT*("`@("`@("`D
M=&AI<RT^7VYO4F5G:7-T<GD@/2!T<G5E.PT*("`@('T-"@T*("`@("\J*@T*
M("`@("`J($!R971U<FX@4$5!4E]296UO=&4-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B`F9V5T4F5M;W1E*"D-"B`@("![#0H@("`@("`@("1R96UO=&4@/2`F
M;F5W(%!%05)?4F5M;W1E*"1T:&ES*3L-"B`@("`@("`@<F5T=7)N("1R96UO
M=&4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0')E='5R;B!014%27U)%
M4U0-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F9V5T4D535"@D=F5R<VEO;BP@
M)&]P=&EO;G,@/2!A<G)A>2@I*0T*("`@('L-"B`@("`@("`@)'9E<G-I;VX@
M/2!S=')?<F5P;&%C92@G+B<L("<G+"`D=F5R<VEO;BD[#0H@("`@("`@(&EF
M("@A8VQA<W-?97AI<W1S*"1C;&%S<R`]("=014%27U)%4U1?)R`N("1V97)S
M:6]N*2D@>PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+U)%4U0O
M)R`N("1V97)S:6]N("X@)RYP:'`G.PT*("`@("`@("!]#0H@("`@("`@("1R
M96UO=&4@/2`F;F5W("1C;&%S<R@D=&AI<RP@)&]P=&EO;G,I.PT*("`@("`@
M("!R971U<FX@)')E;6]T93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!4
M:&4@9G1P('-E<G9E<B!I<R!S970@:6X@>T!L:6YK(')E861&5%!#;VYF:6=&
M:6QE*"E]+B`@270@97AI<W1S(&]N;'D@:68@80T*("`@("`J(')E;6]T92!C
M;VYF:6=U<F%T:6]N(&9I;&4@:&%S(&)E96X@<W!E8VEF:65D#0H@("`@("H@
M0')E='5R;B!014%27T944'QF86QS90T*("`@("`J+PT*("`@(&9U;F-T:6]N
M("9G971&5%`H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M9G1P*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9G1P.PT*("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&$@/2!F86QS93L-"B`@("`@
M("`@("`@(')E='5R;B`D83L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\O
M('M[>R!?<')E<&5N9%!A=&@H)'!A=&@L("1P<F5P96YD*0T*#0H@("`@9G5N
M8W1I;VX@7W!R97!E;F10871H*"1P871H+"`D<')E<&5N9"D-"B`@("![#0H@
M("`@("`@(&EF("AS=')L96XH)'!R97!E;F0I(#X@,"D@>PT*("`@("`@("`@
M("`@:68@*$]37U=)3D1/5U,@)B8@<')E9U]M871C:"@G+UY;82UZ73HO:2<L
M("1P871H*2D@>PT*("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O
M7EMA+7I=.B]I)RP@)'!R97!E;F0I*2![#0H@("`@("`@("`@("`@("`@("`@
M("1P<F5P96YD(#T@<W5B<W1R*"1P<F5P96YD+"`R*3L-"B`@("`@("`@("`@
M("`@("!](&5L<V5I9B`H)'!R97!E;F1[,'T@(3T@)UQ<)RD@>PT*("`@("`@
M("`@("`@("`@("`@("`D<')E<&5N9"`](")<7"1P<F5P96YD(CL-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'!A=&@@/2!S=6)S='(H
M)'!A=&@L(#`L(#(I("X@)'!R97!E;F0@+B!S=6)S='(H)'!A=&@L(#(I.PT*
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D<&%T:"`]
M("1P<F5P96YD("X@)'!A=&@[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("`@("`@<F5T=7)N("1P871H.PT*("`@('T-"B`@("`O+R!]?7T-"@T*
M("`@("\J*@T*("`@("`J($!P87)A;2!S=')I;F=\9F%L<V4@:6YS=&%L;&%T
M:6]N(&1I<F5C=&]R>2!T;R!P<F5P96YD('1O(&%L;"!?9&ER('9A<FEA8FQE
M<RP@;W(@9F%L<V4@=&\-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(&1I
M<V%B;&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S971);G-T86QL4F]O="@D
M<F]O="D-"B`@("![#0H@("`@("`@(&EF("AS=6)S='(H)')O;W0L("TQ*2`]
M/2!$25)%0U1/4EE?4T5005)!5$]2*2![#0H@("`@("`@("`@("`D<F]O="`]
M('-U8G-T<B@D<F]O="P@,"P@+3$I.PT*("`@("`@("!]#0H@("`@("`@("1O
M;&0@/2`D=&AI<RT^7VEN<W1A;&Q2;V]T.PT*("`@("`@("`D=&AI<RT^7VEN
M<W1A;&Q2;V]T(#T@)')O;W0[#0H@("`@("`@(&EF("@H)&]L9"`A/2`D<F]O
M="D@)B8@(21T:&ES+3Y?;F]296=I<W1R>2D@>PT*("`@("`@("`@("`@9F]R
M96%C:"`H87)R87E?:V5Y<R@D=&AI<RT^7W)E9VES=')Y*2!A<R`D;&%Y97(I
M('L-"B`@("`@("`@("`@("`@("!I9B`H)&QA>65R(#T]("=F='`G('Q\("%I
M<W-E="@D=&AI<RT^7W)E9VES=')Y6R1L87EE<ETI*2![#0H@("`@("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7W)E9VES=')Y6R1L87EE<ET@/0T*("`@("`@
M("`@("`@("`@("`@("`F;F5W(%!%05)?4F5G:7-T<GDH)'1H:7,M/F=E="@G
M<&AP7V1I<B<L("1L87EE<BP@)W!E87(N<&AP+FYE="<I*3L-"B`@("`@("`@
M("`@("`@("`D=&AI<RT^7W)E9VES=')Y6R1L87EE<ETM/G-E=$-O;F9I9R@D
M=&AI<RD[#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]R96=);FET:6%L:7IE
M9%LD;&%Y97)=(#T@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("!]#0I]#0H-"C\^#0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O1&5P
M96YD96YC>2YP:'``````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P-#,R,C(@,3`U,34T,S,W,S(@,#(R,#`V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP#0HO+PT*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\(%!(4"!697)S:6]N(#4@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@
M?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P-"!4:&4@4$A0($=R;W5P("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L-"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J
M96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@
M?`T*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@
M=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\#0HO+R!\(&%V86EL
M86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W
M:6YG('5R;#H@("`@("`@("`@('P-"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`T*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O
M9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\#0HO+R!\
M(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E
M('-E;F0@82!N;W1E('1O("`@("`@("`@('P-"B\O('P@;&EC96YS94!P:'`N
M;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@
M("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M#0HO+R!\($%U=&AO<G,Z(%1O;6%S(%8N5BY#;W@@/&-O>$!I9&5C;F5T+F-O
M;3X@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@("`@("`@
M("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK#0HO+PT*+R\@5$A)4R!&24Q%($E3($1%4%)%0T%4140@24X@1D%6
M3U(@3T8@1$5014Y$14Y#63(N4$A0+"!!3D0@25,@3D]4(%53140@24X@5$A%
M($E.4U1!3$Q%4@T*+R\@)$ED.B!$97!E;F1E;F-Y+G!H<"QV(#$N-#$@,C`P
M-B\P,2\P-B`P-#HT-SHS-B!C96QL;V<@17AP("0-"@T*<F5Q=6ER95]O;F-E
M(")014%2+G!H<"([#0IR97%U:7)E7V]N8V4@(D]3+T=U97-S+G!H<"([#0H-
M"F1E9FEN92@G4$5!4E]$15!%3D1%3D-97TU)4U-)3D<G+"`@("`@("`@+3$I
M.PT*9&5F:6YE*"=014%27T1%4$5.1$5.0UE?0T].1DQ)0U0G+"`@("`@("`M
M,BD[#0ID969I;F4H)U!%05)?1$5014Y$14Y#65]54$=2041%7TU)3D]2)RP@
M("TS*3L-"F1E9FEN92@G4$5!4E]$15!%3D1%3D-97U501U)!1$5?34%*3U(G
M+"`@+30I.PT*9&5F:6YE*"=014%27T1%4$5.1$5.0UE?0D%$7T1%4$5.1$5.
M0UDG+"`M-2D[#0ID969I;F4H)U!%05)?1$5014Y$14Y#65]-25-324Y'7T]0
M5$E/3D%,)RP@+38I.PT*9&5F:6YE*"=014%27T1%4$5.1$5.0UE?0T].1DQ)
M0U1?3U!424].04PG+"`@("`@("`M-RD[#0ID969I;F4H)U!%05)?1$5014Y$
M14Y#65]54$=2041%7TU)3D]27T]05$E/3D%,)RP@("TX*3L-"F1E9FEN92@G
M4$5!4E]$15!%3D1%3D-97U501U)!1$5?34%*3U)?3U!424].04PG+"`@+3DI
M.PT*#0HO*BH-"B`J($1E<&5N9&5N8WD@8VAE8VL@9F]R(%!%05(@<&%C:V%G
M97,-"B`J#0H@*B!4:&4@8VQA<W,@:7,@8F%S960@;VX@=&AE(&1E<&5N9&5N
M8WD@4D9#('1H870@8V%N(&)E(&9O=6YD(&%T#0H@*B!H='1P.B\O8W9S+G!H
M<"YN970O8W9S+G!H<"]P96%R=V5B+W)F8RX@270@<F5Q=6ER97,@4$A0(#X]
M(#0N,0T*("H-"B`J($!A=71H;W(@5&]M87,@5BY6+E9O>"`\8V]X0&ED96-N
M970N8V]M/@T*("H@0&%U=&AO<B!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^
M#0H@*B\-"F-L87-S(%!%05)?1&5P96YD96YC>0T*>PT*("`@("\O('M[>R!C
M;VYS=')U8W1O<@T*("`@("\J*@T*("`@("`J($-O;G-T<G5C=&]R#0H@("`@
M("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J($!P87)A;2`@;V)J
M96-T(%)E9VES=')Y(&]B:F5C=`T*("`@("`J($!R971U<FX@=F]I9`T*("`@
M("`J+PT*("`@(&9U;F-T:6]N(%!%05)?1&5P96YD96YC>2@F)')E9VES=')Y
M*0T*("`@('L-"B`@("`@("`@)'1H:7,M/G)E9VES=')Y(#T@)B1R96=I<W1R
M>3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@8V%L;$-H96-K
M365T:&]D*"D-"@T*("`@("\J*@T*("`@("H@5&AI<R!M971H;V0@;6%P<R!T
M:&4@6$U,(&1E<&5N9&5N8WD@9&5F:6YI=&EO;B!T;R!T:&4-"B`@("`J(&-O
M<G)E<W!O;F1I;F<@;VYE(&9R;VT@4$5!4E]$97!E;F1E;F-Y#0H@("`@*@T*
M("`@("H@/'!R93X-"B`@("`J("1O<'1S(#T^($%R<F%Y#0H@("`@*B`@("`H
M#0H@("`@*B`@("`@("`@6W1Y<&5=(#T^('!K9PT*("`@("H@("`@("`@(%MR
M96Q=(#T^(&=E#0H@("`@*B`@("`@("`@6W9E<G-I;VY=(#T^(#,N-`T*("`@
M("H@("`@("`@(%MN86UE72`]/B!(5$U,7T-O;6UO;@T*("`@("H@("`@("`@
M(%MO<'1I;VYA;%T@/3X@9F%L<V4-"B`@("`J("`@("D-"B`@("`J(#PO<')E
M/@T*("`@("H-"B`@("`J($!P87)A;2`@<W1R:6YG($5R<F]R(&UE<W-A9V4-
M"B`@("`J($!P87)A;2`@87)R87D@($]P=&EO;G,-"B`@("`J($!R971U<FX@
M8F]O;&5A;@T*("`@("HO#0H@("`@9G5N8W1I;VX@8V%L;$-H96-K365T:&]D
M*"8D97)R;7-G+"`D;W!T<RD-"B`@("![#0H@("`@("`@("1R96P@/2!I<W-E
M="@D;W!T<ULG<F5L)UTI(#\@)&]P='-;)W)E;"==(#H@)VAA<R<[#0H@("`@
M("`@("1R97$@/2!I<W-E="@D;W!T<ULG=F5R<VEO;B==*2`_("1O<'1S6R=V
M97)S:6]N)UT@.B!N=6QL.PT*("`@("`@("`D;F%M92`](&ES<V5T*"1O<'1S
M6R=N86UE)UTI(#\@)&]P='-;)VYA;64G72`Z(&YU;&P[#0H@("`@("`@("1C
M:&%N;F5L(#T@:7-S970H)&]P='-;)V-H86YN96PG72D@/R`D;W!T<ULG8VAA
M;FYE;"==(#H@)W!E87(N<&AP+FYE="<[#0H@("`@("`@("1O<'0@/2`H:7-S
M970H)&]P='-;)V]P=&EO;F%L)UTI("8F("1O<'1S6R=O<'1I;VYA;"==(#T]
M("=Y97,G*2`_#0H@("`@("`@("`@("`D;W!T<ULG;W!T:6]N86PG72`Z(&YU
M;&P[#0H@("`@("`@("1E<G)M<V<@/2`G)SL-"B`@("`@("`@<W=I=&-H("@D
M;W!T<ULG='EP92==*2![#0H@("`@("`@("`@("!C87-E("=P:V<G.@T*("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^8VAE8VM086-K86=E*"1E<G)M
M<V<L("1N86UE+"`D<F5Q+"`D<F5L+"`D;W!T+"`D8VAA;FYE;"D[#0H@("`@
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=E>'0G.@T*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^8VAE8VM%>'1E;G-I;VXH
M)&5R<FUS9RP@)&YA;64L("1R97$L("1R96PL("1O<'0I.PT*("`@("`@("`@
M("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G<&AP)SH-"B`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/F-H96-K4$A0*"1E<G)M<V<L("1R
M97$L("1R96PI.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@
M("`@8V%S92`G<')O9R<Z#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YC:&5C:U!R;V=R86TH)&5R<FUS9RP@)&YA;64I.PT*("`@("`@("`@("`@
M("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G;W,G.@T*("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^8VAE8VM/4R@D97)R;7-G+"`D;F%M92D[
M#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=S
M87!I)SH-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/F-H96-K4T%0
M22@D97)R;7-G+"`D;F%M92D[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@
M("`@("`@("`@("!C87-E("=Z96YD)SH-"B`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/F-H96-K6F5N9"@D97)R;7-G+"`D;F%M92D[#0H@("`@("`@
M("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!D969A=6QT.@T*("`@("`@
M("`@("`@("`@(')E='5R;B`B)WLD;W!T<ULG='EP92==?2<@9&5P96YD96YC
M>2!T>7!E(&YO="!S=7!P;W)T960B.PT*("`@("`@("!]#0H@("`@?0T*#0H@
M("`@+R\@?7U]#0H@("`@+R\@>WM[(&-H96-K4&%C:V%G92@I#0H-"B`@("`O
M*BH-"B`@("`@*B!086-K86=E(&1E<&5N9&5N8VEE<R!C:&5C:R!M971H;V0-
M"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@)&5R<FUS9R`@("!%;7!T
M>2!S=')I;F<L(&ET('=I;&P@8F4@<&]P=6QA=&5D('=I=&@@86X@97)R;W(@
M;65S<V%G92P@:68@86YY#0H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@
M("`@($YA;64@;V8@=&AE('!A8VMA9V4@=&\@=&5S=`T*("`@("`J($!P87)A
M;2!S=')I;F<@)')E<2`@("`@("!4:&4@<&%C:V%G92!V97)S:6]N(')E<75I
M<F5D#0H@("`@("H@0'!A<F%M('-T<FEN9R`D<F5L871I;VX@($AO=R!T;R!C
M;VUP87)E('9E<G-I;VYS('=I=&@@96%C:"!O=&AE<@T*("`@("`J($!P87)A
M;2!B;V]L("`@)&]P="`@("`@("!7:&5T:&5R('1H92!R96QA=&EO;G-H:7`@
M:7,@;W!T:6]N86P-"B`@("`@*B!`<&%R86T@<W1R:6YG("1C:&%N;F5L("`@
M0VAA;FYE;"!N86UE#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&UI>&5D(&)O
M;VP@9F%L<V4@:68@;F\@97)R;W(@;W(@=&AE(&5R<F]R('-T<FEN9PT*("`@
M("`J+PT*("`@(&9U;F-T:6]N(&-H96-K4&%C:V%G92@F)&5R<FUS9RP@)&YA
M;64L("1R97$@/2!N=6QL+"`D<F5L871I;VX@/2`G:&%S)RP-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&]P="`](&9A;'-E+"`D8VAA;FYE;"`]("=P
M96%R+G!H<"YN970G*0T*("`@('L-"B`@("`@("`@:68@*&ES7W-T<FEN9R@D
M<F5Q*2`F)B!S=6)S='(H)')E<2P@,"P@,BD@/3T@)W8N)RD@>PT*("`@("`@
M("`@("`@)')E<2`]('-U8G-T<B@D<F5Q+"`R*3L-"B`@("`@("`@?0T*("`@
M("`@("!S=VET8V@@*"1R96QA=&EO;BD@>PT*("`@("`@("`@("`@8V%S92`G
M:&%S)SH-"B`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3YR96=I<W1R>2T^
M<&%C:V%G945X:7-T<R@D;F%M92P@)&-H86YN96PI*2![#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@D;W!T*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D97)R;7-G(#T@(G!A8VMA9V4@8"1C:&%N;F5L+R1N86UE)R!I<R!R96-O
M;6UE;F1E9"!T;R!U=&EL:7IE('-O;64@9F5A='5R97,N(CL-"B`@("`@("`@
M("`@("`@("`@("`@("`@(')E='5R;B!014%27T1%4$5.1$5.0UE?34E34TE.
M1U]/4%1)3TY!3#L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`D97)R;7-G(#T@(G)E<75I<F5S('!A8VMA9V4@8"1C:&%N
M;F5L+R1N86UE)R([#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2
M7T1%4$5.1$5.0UE?34E34TE.1SL-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@8V%S92`G
M;F]T)SH-"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/G)E9VES=')Y+3YP
M86-K86=E17AI<W1S*"1N86UE+"`D8VAA;FYE;"DI('L-"B`@("`@("`@("`@
M("`@("`@("`@)&5R<FUS9R`](")C;VYF;&EC=',@=VET:"!P86-K86=E(&`D
M8VAA;FYE;"\D;F%M92<B.PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M4$5!4E]$15!%3D1%3D-97T-/3D9,24-4.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!C
M87-E("=L="<Z#0H@("`@("`@("`@("!C87-E("=L92<Z#0H@("`@("`@("`@
M("!C87-E("=E<2<Z#0H@("`@("`@("`@("!C87-E("=N92<Z#0H@("`@("`@
M("`@("!C87-E("=G92<Z#0H@("`@("`@("`@("!C87-E("=G="<Z#0H@("`@
M("`@("`@("`@("`@)'9E<G-I;VX@/2`D=&AI<RT^<F5G:7-T<GDM/G!A8VMA
M9V5);F9O*"1N86UE+"`G=F5R<VEO;B<L("1C:&%N;F5L*3L-"B`@("`@("`@
M("`@("`@("!I9B`H(21T:&ES+3YR96=I<W1R>2T^<&%C:V%G945X:7-T<R@D
M;F%M92P@)&-H86YN96PI#0H@("`@("`@("`@("`@("`@("`@('Q\("%V97)S
M:6]N7V-O;7!A<F4H(B1V97)S:6]N(BP@(B1R97$B+"`D<F5L871I;VXI*0T*
M("`@("`@("`@("`@("`@('L-"B`@("`@("`@("`@("`@("`@("`@)&-O9&4@
M/2`D=&AI<RT^8V]D949R;VU296QA=&EO;B@D<F5L871I;VXL("1V97)S:6]N
M+"`D<F5Q+"`D;W!T*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1O<'0I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1E<G)M<V<@/2`B<&%C:V%G
M92!@)&-H86YN96PO)&YA;64G('9E<G-I;VX@(B`N("1T:&ES+3YS:6=N3W!E
M<F%T;W(H)')E;&%T:6]N*2`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(B`D<F5Q(&ES(')E8V]M;65N9&5D('1O('5T:6QI>F4@<V]M92!F96%T
M=7)E<RXB.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1V97)S:6]N
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5R<FUS9R`N/2`B
M("!);G-T86QL960@=F5R<VEO;B!I<R`D=F5R<VEO;B([#0H@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)&-O9&4[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@)&5R<FUS9R`](")R97%U:7)E<R!P86-K86=E(&`D8VAA;FYE
M;"\D;F%M92<@(B`N#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M<VEG;D]P97)A=&]R*"1R96QA=&EO;BD@+B`B("1R97$B.PT*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)&-O9&4[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@
M("`@("`D97)R;7-G(#T@(G)E;&%T:6]N("<D<F5L871I;VXG('=I=&@@<F5Q
M=6ER96UE;G0@)R1R97$G(&ES(&YO="!S=7!P;W)T960@*&YA;64])&-H86YN
M96PO)&YA;64I(CL-"B`@("`@("`@<F5T=7)N(%!%05)?1$5014Y$14Y#65]"
M041?1$5014Y$14Y#63L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![
M>WL@8VAE8VM086-K86=E56YI;G-T86QL*"D-"@T*("`@("\J*@T*("`@("`J
M($-H96-K('!A8VMA9V4@9&5P96YD96YC:65S(&]N('5N:6YS=&%L;`T*("`@
M("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`D97)R;W(@("`@(%1H92!R97-U
M;'1A;G0@97)R;W(@<W1R:6YG#0H@("`@("H@0'!A<F%M('-T<FEN9R`D=V%R
M;FEN9R`@(%1H92!R97-U;'1A;G0@=V%R;FEN9R!S=')I;F<-"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1N86UE("`@("`@3F%M92!O9B!T:&4@<&%C:V%G92!T
M;R!T97-T#0H@("`@("H@0'!A<F%M('-T<FEN9R`D8VAA;FYE;"`@($-H86YN
M96P@;F%M92!O9B!T:&4@<&%C:V%G90T*("`@("`J#0H@("`@("H@0')E='5R
M;B!B;V]L('1R=64@:68@=&AE<F4@=V5R92!E<G)O<G,-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!C:&5C:U!A8VMA9V55;FEN<W1A;&PH)B1E<G)O<BP@)B1W
M87)N:6YG+"`D<&%C:V%G92P@)&-H86YN96P@/2`G<&5A<BYP:'`N;F5T)RD-
M"B`@("![#0H@("`@("`@("1C:&%N;F5L(#T@<W1R=&]L;W=E<B@D8VAA;FYE
M;"D[#0H@("`@("`@("1E<G)O<B`](&YU;&P[#0H@("`@("`@("1C:&%N;F5L
M<R`]("1T:&ES+3YR96=I<W1R>2T^;&ES=$%L;%!A8VMA9V5S*"D[#0H@("`@
M("`@(&9O<F5A8V@@*"1C:&%N;F5L<R!A<R`D8VAA;FYE;&YA;64@/3X@)'!A
M8VMA9V5S*2![#0H@("`@("`@("`@("!F;W)E86-H("@D<&%C:V%G97,@87,@
M)'!K9RD@>PT*("`@("`@("`@("`@("`@(&EF("@D<&MG(#T]("1P86-K86=E
M("8F("1C:&%N;F5L(#T]("1C:&%N;F5L;F%M92D@>PT*("`@("`@("`@("`@
M("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@)&1E<',@/2`D=&AI<RT^<F5G:7-T<GDM/G!A8VMA9V5);F9O
M*"1P:V<L("=R96QE87-E7V1E<',G+"`D8VAA;FYE;"D[#0H@("`@("`@("`@
M("`@("`@:68@*&5M<'1Y*"1D97!S*2D@>PT*("`@("`@("`@("`@("`@("`@
M("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)&1E<',@87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@
M("`@("`D9&5P8VAA;FYE;"`](&ES<V5T*"1D97!;)V-H86YN96PG72D@/R`D
M9&5P6R=C:&%N;F5L)UT@.B`G<&5A<BYP:'`N;F5T)SL-"B`@("`@("`@("`@
M("`@("`@("`@:68@*"1D97!;)W1Y<&4G72`]/2`G<&MG)R`F)B`H<W1R8V%S
M96-M<"@D9&5P6R=N86UE)UTL("1P86-K86=E*2`]/2`P*2`F)@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`H)&1E<&-H86YN96P@/3T@)&-H86YN96PI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&1E<%LG<F5L)UT@
M/3T@)VYE)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)V]P=&EO;F%L)UTI("8F("1D
M97!;)V]P=&EO;F%L)UT@/3T@)WEE<R<I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=V%R;FEN9R`N/2`B7&Y787)N:6YG.B!086-K86=E("<D
M9&5P8VAA;FYE;"\D<&MG)R!O<'1I;VYA;&QY(&1E<&5N9',@;VX@)R1C:&%N
M;F5L.B]P86-K86=E)R([#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E<G)O<B`N/2`B
M4&%C:V%G92`G)&1E<&-H86YN96PO)'!K9R<@9&5P96YD<R!O;B`G)&-H86YN
M96PO)'!A8VMA9V4G7&XB.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`H)&5R<F]R
M*2`_('1R=64@.B!F86QS93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O
M+R![>WL@8VAE8VM%>'1E;G-I;VXH*0T*#0H@("`@+RHJ#0H@("`@("H@17AT
M96YS:6]N(&1E<&5N9&5N8VEE<R!C:&5C:R!M971H;V0-"B`@("`@*@T*("`@
M("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@("`@($YA;64@;V8@=&AE(&5X
M=&5N<VEO;B!T;R!T97-T#0H@("`@("H@0'!A<F%M('-T<FEN9R`D<F5Q7V5X
M=%]V97(@4F5Q=6ER960@97AT96YS:6]N('9E<G-I;VX@=&\@8V]M<&%R92!W
M:71H#0H@("`@("H@0'!A<F%M('-T<FEN9R`D<F5L871I;VX@("`@2&]W('1O
M(&-O;7!A<F4@=F5R<VEO;G,@=VET:"!E86-H;W1H97(-"B`@("`@*B!`<&%R
M86T@8F]O;"`@("1O<'0@("`@("`@("!7:&5T:&5R('1H92!R96QA=&EO;G-H
M:7`@:7,@;W!T:6]N86P-"B`@("`@*@T*("`@("`J($!R971U<FX@;6EX960@
M8F]O;"!F86QS92!I9B!N;R!E<G)O<B!O<B!T:&4@97)R;W(@<W1R:6YG#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@8VAE8VM%>'1E;G-I;VXH)B1E<G)M<V<L
M("1N86UE+"`D<F5Q(#T@;G5L;"P@)')E;&%T:6]N(#T@)VAA<R<L#0H@("`@
M("`@("1O<'0@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@D<F5L871I
M;VX@/3T@)VYO="<I('L-"B`@("`@("`@("`@(&EF("AE>'1E;G-I;VY?;&]A
M9&5D*"1N86UE*2D@>PT*("`@("`@("`@("`@("`@("1E<G)M<V<@/2`B8V]N
M9FQI8W1S('=I=&@@(%!(4"!E>'1E;G-I;VX@)R1N86UE)R([#0H@("`@("`@
M("`@("`@("`@<F5T=7)N(%!%05)?1$5014Y$14Y#65]#3TY&3$E#5#L-"B`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H-"B`@("`@("`@:68@
M*"%E>'1E;G-I;VY?;&]A9&5D*"1N86UE*2D@>PT*("`@("`@("`@("`@:68@
M*"1R96QA=&EO;B`]/2`G;F4G*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1O<'0I
M('L-"B`@("`@("`@("`@("`@("`D97)R;7-G(#T@(B<D;F%M92<@4$A0(&5X
M=&5N<VEO;B!I<R!R96-O;6UE;F1E9"!T;R!U=&EL:7IE('-O;64@9F5A='5R
M97,B.PT*("`@("`@("`@("`@("`@(')E='5R;B!014%27T1%4$5.1$5.0UE?
M34E34TE.1U]/4%1)3TY!3#L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("1E<G)M<V<@/2`B)R1N86UE)R!02%`@97AT96YS:6]N(&ES(&YO="!I;G-T
M86QL960B.PT*("`@("`@("`@("`@<F5T=7)N(%!%05)?1$5014Y$14Y#65]-
M25-324Y'.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D<F5L871I;VX@/3T@
M)VAA<R<I('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@
M?0T*("`@("`@("`D8V]D92`](&9A;'-E.PT*("`@("`@("!I9B`H:7-?<W1R
M:6YG*"1R97$I("8F('-U8G-T<B@D<F5Q+"`P+"`R*2`]/2`G=BXG*2![#0H@
M("`@("`@("`@("`D<F5Q(#T@<W5B<W1R*"1R97$L(#(I.PT*("`@("`@("!]
M#0H@("`@("`@("1E>'1?=F5R(#T@<&AP=F5R<VEO;B@D;F%M92D[#0H@("`@
M("`@("1O<&5R871O<B`]("1R96QA=&EO;CL-"B`@("`@("`@+R\@1F]R8V4@
M<&%R86US('1O(&)E('-T<FEN9W,L(&]T:&5R=VES92!T:&4@8V]M<&%R871I
M;VX@=VEL;"!F86EL("AE>"X@,"XY/3TP+CDP*0T*("`@("`@("!I9B`H(79E
M<G-I;VY?8V]M<&%R92@B)&5X=%]V97(B+"`B)')E<2(L("1O<&5R871O<BDI
M('L-"B`@("`@("`@("`@("1E<G)M<V<@/2`B)R1N86UE)R!02%`@97AT96YS
M:6]N('9E<G-I;VX@(B`N#0H@("`@("`@("`@("`@("`@)'1H:7,M/G-I9VY/
M<&5R871O<B@D;W!E<F%T;W(I("X@(B`D<F5Q(&ES(')E<75I<F5D(CL-"B`@
M("`@("`@("`@("1C;V1E(#T@)'1H:7,M/F-O9&5&<F]M4F5L871I;VXH)')E
M;&%T:6]N+"`D97AT7W9E<BP@)')E<2P@)&]P="D[#0H@("`@("`@("`@("!I
M9B`H)&]P="D@>PT*("`@("`@("`@("`@("`@("1E<G)M<V<@/2`B)R1N86UE
M)R!02%`@97AT96YS:6]N('9E<G-I;VX@(B`N("1T:&ES+3YS:6=N3W!E<F%T
M;W(H)&]P97)A=&]R*2`N#0H@("`@("`@("`@("`@("`@("`@("(@)')E<2!I
M<R!R96-O;6UE;F1E9"!T;R!U=&EL:7IE('-O;64@9F5A='5R97,B.PT*("`@
M("`@("`@("`@("`@(')E='5R;B`D8V]D93L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@)&-O9&4[#0H@("`@?0T*#0H@("`@
M+R\@?7U]#0H@("`@+R\@>WM[(&-H96-K3U,H*0T*#0H@("`@+RHJ#0H@("`@
M("H@3W!E<F%T:6YG('-Y<W1E;2`@9&5P96YD96YC:65S(&-H96-K(&UE=&AO
M9`T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`D;W,@($YA;64@;V8@
M=&AE(&]P97)A=&EN9R!S>7-T96T-"B`@("`@*@T*("`@("`J($!R971U<FX@
M;6EX960@8F]O;"!F86QS92!I9B!N;R!E<G)O<B!O<B!T:&4@97)R;W(@<W1R
M:6YG#0H@("`@("HO#0H@("`@9G5N8W1I;VX@8VAE8VM/4R@F)&5R<FUS9RP@
M)&]S*0T*("`@('L-"B`@("`@("`@+R\@6%A8($9I>&UE.B!);7!L96UE;G0@
M82!M;W)E(&9L97AI8FQE('=A>2P@;&EK90T*("`@("`@("`O+R!C;VUM82!S
M97!A<F%T960@=F%L=65S(&]R('-O;65T:&EN9R!S:6UI;&%R('1O(%!%05)?
M3U,-"B`@("`@("`@<W1A=&EC("1M>6]S.PT*("`@("`@("!I9B`H96UP='DH
M)&UY;W,I*2![#0H@("`@("`@("`@("`D;7EO<R`](&YE=R!/4U]'=65S<R@I
M.PT*("`@("`@("!]#0H@("`@("`@("\O(&]N;'D@)VAA<R<@<F5L871I;VX@
M:7,@8W5R<F5N=&QY('-U<'!O<G1E9`T*("`@("`@("!I9B`H)&UY;W,M/FUA
M=&-H4VEG;F%T=7)E*"1O<RDI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS
M93L-"B`@("`@("`@?0T*("`@("`@("`D97)R;7-G(#T@(B<D;W,G(&]P97)A
M=&EN9R!S>7-T96T@;F]T('-U<'!O<G1E9"([#0H@("`@("`@(')E='5R;B!0
M14%27T1%4$5.1$5.0UE?0T].1DQ)0U0[#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0H@("`@+R\@>WM[(&-H96-K4$A0*"D-"@T*("`@("\J*@T*("`@("`J(%!(
M4"!V97)S:6]N(&-H96-K(&UE=&AO9`T*("`@("`J#0H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<F5Q("`@=VAI8V@@=F5R<VEO;B!T;R!C;VUP87)E#0H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<F5L871I;VX@(&AO=R!T;R!C;VUP87)E('1H
M92!V97)S:6]N#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&UI>&5D(&)O;VP@
M9F%L<V4@:68@;F\@97)R;W(@;W(@=&AE(&5R<F]R('-T<FEN9PT*("`@("`J
M+PT*("`@(&9U;F-T:6]N(&-H96-K4$A0*"8D97)R;7-G+"`D<F5Q+"`D<F5L
M871I;VX@/2`G9V4G*0T*("`@('L-"B`@("`@("`@+R\@=&AI<R!W;W5L9"!B
M92!A(&)I="!S='5P:60L(&)U="!O:"!W96QL(#HI#0H@("`@("`@(&EF("@D
M<F5L871I;VX@/3T@)VAA<R<I('L-"B`@("`@("`@("`@(')E='5R;B!F86QS
M93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)')E;&%T:6]N(#T]("=N;W0G
M*2![#0H@("`@("`@("`@("`D97)R;7-G(#T@(DEN=F%L:60@9&5P96YD96YC
M>2`M("=N;W0G(&ES(&%L;&]W960@=VAE;B!S<&5C:69Y:6YG(%!(4"P@>6]U
M(&UU<W0@<G5N(%!(4"!I;B!02%`B.PT*("`@("`@("`@("`@<F5T=7)N(%!%
M05)?1$5014Y$14Y#65]"041?1$5014Y$14Y#63L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H<W5B<W1R*"1R97$L(#`L(#(I(#T]("=V+B<I('L-"B`@("`@
M("`@("`@("1R97$@/2!S=6)S='(H)')E<2PR+"!S=')L96XH)')E<2D@+2`R
M*3L-"B`@("`@("`@?0T*("`@("`@("`D<&AP7W9E<B`]('!H<'9E<G-I;VXH
M*3L-"B`@("`@("`@)&]P97)A=&]R(#T@)')E;&%T:6]N.PT*("`@("`@("!I
M9B`H(79E<G-I;VY?8V]M<&%R92@B)'!H<%]V97(B+"`B)')E<2(L("1O<&5R
M871O<BDI('L-"B`@("`@("`@("`@("1E<G)M<V<@/2`B4$A0('9E<G-I;VX@
M(B`N("1T:&ES+3YS:6=N3W!E<F%T;W(H)&]P97)A=&]R*2`N#0H@("`@("`@
M("`@("`@("`@(B`D<F5Q(&ES(')E<75I<F5D(CL-"B`@("`@("`@("`@(')E
M='5R;B!014%27T1%4$5.1$5.0UE?0T].1DQ)0U0[#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@
M("\O('M[>R!C:&5C:U!R;V=R86TH*0T*#0H@("`@+RHJ#0H@("`@("H@17AT
M97)N86P@<')O9W)A;2!C:&5C:R!M971H;V0N("!,;V]K<R!F;W(@97AE8W5T
M86)L92!F:6QE<R!I;@T*("`@("`J(&1I<F5C=&]R:65S(&QI<W1E9"!I;B!T
M:&4@4$%42"!E;G9I<F]N;65N="!V87)I86)L92X-"B`@("`@*@T*("`@("`J
M($!P87)A;2!S=')I;F<@)'!R;V=R86T@("!W:&EC:"!P<F]G<F%M('1O(&QO
M;VL@9F]R#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&UI>&5D(&)O;VP@9F%L
M<V4@:68@;F\@97)R;W(@;W(@=&AE(&5R<F]R('-T<FEN9PT*("`@("`J+PT*
M("`@(&9U;F-T:6]N(&-H96-K4')O9W)A;2@F)&5R<FUS9RP@)'!R;V=R86TI
M#0H@("`@>PT*("`@("`@("`O+R!86%@@1DE8344@:&]N;W(@<V%F92!M;V1E
M#0H@("`@("`@("1E>&5?<W5F9FEX(#T@3U-?5TE.1$]74R`_("<N97AE)R`Z
M("<G.PT*("`@("`@("`D<&%T:%]E;&5M96YT<R`](&5X<&QO9&4H4$%42%]3
M15!!4D%43U(L(&=E=&5N=B@G4$%42"<I*3L-"B`@("`@("`@9F]R96%C:"`H
M)'!A=&A?96QE;65N=',@87,@)&1I<BD@>PT*("`@("`@("`@("`@)&9I;&4@
M/2`D9&ER("X@1$E214-43U)97U-%4$%2051/4B`N("1P<F]G<F%M("X@)&5X
M95]S=69F:7@[#0H@("`@("`@("`@("!I9B`H0&9I;&5?97AI<W1S*"1F:6QE
M*2`F)B!`:7-?97AE8W5T86)L92@D9FEL92DI('L-"B`@("`@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@)&5R<FUS9R`]("(G)'!R;V=R86TG('!R;V=R86T@:7,@;F]T('!R
M97-E;G0@:6X@=&AE(%!!5$@B.PT*("`@("`@("!R971U<FX@4$5!4E]$15!%
M3D1%3D-97TU)4U-)3D<[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@
M>WM[(&-H96-K4T%022@I#0H-"B`@("`O*BH-"B`@("`@*B!305!)(&)A8VME
M;F0@8VAE8VL@;65T:&]D+B`@5F5R<VEO;B!C;VUP87)I<V]N(&ES(&YO="!Y
M970-"B`@("`@*B!A=F%I;&%B;&4@:&5R92X-"B`@("`@*@T*("`@("`J($!P
M87)A;2!S=')I;F<@)&YA;64@("`@("!N86UE(&]F(%-!4$D@8F%C:V5N9`T*
M("`@("`J($!P87)A;2!S=')I;F<@)')E<2`@('=H:6-H('9E<G-I;VX@=&\@
M8V]M<&%R90T*("`@("`J($!P87)A;2!S=')I;F<@)')E;&%T:6]N("!H;W<@
M=&\@8V]M<&%R92!V97)S:6]N<R`H8W5R<F5N=&QY#0H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@(&AA<F1C;V1E9"!T;R`G:&%S)RD-"B`@("`@
M*B!`<F5T=7)N(&UI>&5D(&)O;VP@9F%L<V4@:68@;F\@97)R;W(@;W(@=&AE
M(&5R<F]R('-T<FEN9PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&-H96-K4T%0
M22@F)&5R<FUS9RP@)&YA;64L("1R97$@/2!N=6QL+"`D<F5L871I;VX@/2`G
M:&%S)RD-"B`@("![#0H@("`@("`@("\O(%A86"!&:7AM93H@5&AE<F4@:7,@
M;F\@=V%Y('1O(&MN;W<@:68@=&AE('5S97(@:&%S(&]R#0H@("`@("`@("\O
M(&YO="!O=&AE<B!305!)(&)A8VME;F1S(&EN<W1A;&QE9"!T:&%N('1H92!I
M;G-T86QL97(@;VYE#0H-"B`@("`@("`@)'-A<&E?8F%C:V5N9"`]('!H<%]S
M87!I7VYA;64H*3L-"B`@("`@("`@+R\@5F5R<VEO;B!C;VUP87)I<V]N<R!N
M;W0@<W5P<&]R=&5D+"!S87!I(&)A8VME;F1S(&1O;B=T(&AA=F4-"B`@("`@
M("`@+R\@=F5R<VEO;B!I;F9O<FUA=&EO;B!Y970N#0H@("`@("`@(&EF("@D
M<V%P:5]B86-K96YD(#T]("1N86UE*2![#0H@("`@("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)&5R<FUS9R`]("(G)'-A<&E?
M8F%C:V5N9"<@4T%022!B86-K96YD(&YO="!S=7!P;W)T960B.PT*("`@("`@
M("!R971U<FX@4$5!4E]$15!%3D1%3D-97T-/3D9,24-4.PT*("`@('T-"@T*
M("`@("\O('U]?0T*("`@("\O('M[>R!C:&5C:UIE;F0H*0T*#0H@("`@+RHJ
M#0H@("`@("H@6F5N9"!V97)S:6]N(&-H96-K(&UE=&AO9`T*("`@("`J#0H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<F5Q("`@=VAI8V@@=F5R<VEO;B!T;R!C
M;VUP87)E#0H@("`@("H@0'!A<F%M('-T<FEN9R`D<F5L871I;VX@(&AO=R!T
M;R!C;VUP87)E('1H92!V97)S:6]N#0H@("`@("H-"B`@("`@*B!`<F5T=7)N
M(&UI>&5D(&)O;VP@9F%L<V4@:68@;F\@97)R;W(@;W(@=&AE(&5R<F]R('-T
M<FEN9PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&-H96-K6F5N9"@F)&5R<FUS
M9RP@)')E<2P@)')E;&%T:6]N(#T@)V=E)RD-"B`@("![#0H@("`@("`@(&EF
M("AS=6)S='(H)')E<2P@,"P@,BD@/3T@)W8N)RD@>PT*("`@("`@("`@("`@
M)')E<2`]('-U8G-T<B@D<F5Q+#(L('-T<FQE;B@D<F5Q*2`M(#(I.PT*("`@
M("`@("!]#0H@("`@("`@("1Z96YD7W9E<B`]('IE;F1?=F5R<VEO;B@I.PT*
M("`@("`@("`D;W!E<F%T;W(@/2!S=6)S='(H)')E;&%T:6]N+#`L,BD[#0H@
M("`@("`@(&EF("@A=F5R<VEO;E]C;VUP87)E*"(D>F5N9%]V97(B+"`B)')E
M<2(L("1O<&5R871O<BDI('L-"B`@("`@("`@("`@("1E<G)M<V<@/2`B6F5N
M9"!V97)S:6]N("(@+B`D=&AI<RT^<VEG;D]P97)A=&]R*"1O<&5R871O<BD@
M+@T*("`@("`@("`@("`@("`@("(@)')E<2!I<R!R97%U:7)E9"([#0H@("`@
M("`@("`@("!R971U<FX@4$5!4E]$15!%3D1%3D-97T-/3D9,24-4.PT*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("`O
M+R!]?7T-"B`@("`O+R![>WL@<VEG;D]P97)A=&]R*"D-"@T*("`@("\J*@T*
M("`@("`J($-O;G9E<G1S('1E>'0@8V]M<&%R:6YG(&]P97)A=&]R<R!T;R!T
M:&5M('-I9VX@97%U:79A;&5N=',-"B`@("`@*@T*("`@("`J($5X86UP;&4Z
M("=G92<@=&\@)SX])PT*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-
M"B`@("`@*B!`<&%R86T@('-T<FEN9R!/<&5R871O<@T*("`@("`J($!R971U
M<FX@<W1R:6YG(%-I9VX@97%U:79A;&5N=`T*("`@("`J+PT*("`@(&9U;F-T
M:6]N('-I9VY/<&5R871O<B@D;W!E<F%T;W(I#0H@("`@>PT*("`@("`@("!S
M=VET8V@H)&]P97)A=&]R*2![#0H@("`@("`@("`@("!C87-E("=L="<Z(')E
M='5R;B`G/"<[#0H@("`@("`@("`@("!C87-E("=L92<Z(')E='5R;B`G/#TG
M.PT*("`@("`@("`@("`@8V%S92`G9W0G.B!R971U<FX@)SXG.PT*("`@("`@
M("`@("`@8V%S92`G9V4G.B!R971U<FX@)SX])SL-"B`@("`@("`@("`@(&-A
M<V4@)V5Q)SH@<F5T=7)N("<]/2<[#0H@("`@("`@("`@("!C87-E("=N92<Z
M(')E='5R;B`G(3TG.PT*("`@("`@("`@("`@9&5F875L=#H-"B`@("`@("`@
M("`@("`@("!R971U<FX@)&]P97)A=&]R.PT*("`@("`@("!]#0H@("`@?0T*
M#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&-O9&5&<F]M4F5L871I;VXH*0T*
M#0H@("`@+RHJ#0H@("`@("H@0V]N=F5R="!R96QA=&EO;B!I;G1O(&-O<G)E
M<W!O;F1I;F<@8V]D90T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-
M"B`@("`@*B!`<&%R86T@('-T<FEN9R!296QA=&EO;@T*("`@("`J($!P87)A
M;2`@<W1R:6YG(%9E<G-I;VX-"B`@("`@*B!`<&%R86T@('-T<FEN9R!297%U
M:7)E;65N=`T*("`@("`J($!P87)A;2`@8F]O;"`@($]P=&EO;F%L(&1E<&5N
M9&5N8WD@:6YD:6-A=&]R#0H@("`@("H@0')E='5R;B!I;G1E9V5R#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@8V]D949R;VU296QA=&EO;B@D<F5L871I;VXL
M("1V97)S:6]N+"`D<F5Q+"`D;W!T(#T@9F%L<V4I#0H@("`@>PT*("`@("`@
M("`D8V]D92`](%!%05)?1$5014Y$14Y#65]"041?1$5014Y$14Y#63L-"B`@
M("`@("`@<W=I=&-H("@D<F5L871I;VXI('L-"B`@("`@("`@("`@(&-A<V4@
M)V=T)SH@8V%S92`G9V4G.B!C87-E("=E<2<Z#0H@("`@("`@("`@("`@("`@
M+R\@=7!G<F%D90T*("`@("`@("`@("`@("`@("1H879E7VUA:F]R(#T@<')E
M9U]R97!L86-E*"<O7$0N*B\G+"`G)RP@)'9E<G-I;VXI.PT*("`@("`@("`@
M("`@("`@("1N965D7VUA:F]R(#T@<')E9U]R97!L86-E*"<O7$0N*B\G+"`G
M)RP@)')E<2D[#0H@("`@("`@("`@("`@("`@:68@*"1N965D7VUA:F]R(#X@
M)&AA=F5?;6%J;W(I('L-"B`@("`@("`@("`@("`@("`@("`@)&-O9&4@/2`D
M;W!T(#\@4$5!4E]$15!%3D1%3D-97U501U)!1$5?34%*3U)?3U!424].04P@
M.@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!014%27T1%
M4$5.1$5.0UE?55!'4D%$15]-04I/4CL-"B`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`D8V]D92`]("1O<'0@/R!014%2
M7T1%4$5.1$5.0UE?55!'4D%$15]-24Y/4E]/4%1)3TY!3"`Z#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?1$5014Y$14Y#65]5
M4$=2041%7TU)3D]2.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)VQT)SH@8V%S92`G;&4G
M.B!C87-E("=N92<Z#0H@("`@("`@("`@("`@("`@)&-O9&4@/2`D;W!T(#\@
M4$5!4E]$15!%3D1%3D-97T-/3D9,24-47T]05$E/3D%,(#H-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!014%27T1%4$5.1$5.0UE?0T].1DQ)
M0U0[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N("1C;V1E.PT*("`@('T-"@T*("`@("\O('U]?0T*?0T*/SX-
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]$97!E
M;F1E;F-Y1$(N<&AP````````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`U-C$V,B`Q,#4Q-30S,S<S,B`P,C(R,C,`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`-"B\J*@T*("H@4$5!4E]$
M97!E;F1E;F-Y1$(L(&%D=F%N8V5D(&EN<W1A;&QE9"!P86-K86=E<R!D97!E
M;F1E;F-Y(&1A=&%B87-E#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-
M"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@
M=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES
M(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@
M9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*
M("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I
M="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@
M;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM
M961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA
M9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@5&]M87,@5BX@5BX@0V]X(#QC
M;WA`:61E8VYE="YC;VT^#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\
M8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE
M(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO
M;B`@("!#5E,Z("1)9#H@1&5P96YD96YC>41"+G!H<"QV(#$N,S`@,C`P-B\P
M,2\P-B`P-#HT-SHS-B!C96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@
M("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*
M#0HO*BH-"B`J($YE961E9"!F;W(@97)R;W(@:&%N9&QI;F<-"B`J+PT*<F5Q
M=6ER95]O;F-E("=014%2+G!H<"<[#0IR97%U:7)E7V]N8V4@)U!%05(O0V]N
M9FEG+G!H<"<[#0H-"B\J*@T*("H@5')A8VL@9&5P96YD96YC>2!R96QA=&EO
M;G-H:7!S(&)E='=E96X@:6YS=&%L;&5D('!A8VMA9V5S#0H@*B!`8V%T96=O
M<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@
M("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`875T:&]R("`@
M("!4;VUA<R!6+E8N0V]X(#QC;WA`:61E8RYN970N8V]M/@T*("H@0&-O<'ER
M:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E
M;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L
M:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@
M*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q
M+C0N,&$Q#0H@*B\-"F-L87-S(%!%05)?1&5P96YD96YC>41"#0I[#0H@("`@
M+R\@>WM[('!R;W!E<G1I97,-"@T*("`@("\J*@T*("`@("`J(%1H:7,@:7,@
M:6YI=&EA;&EZ960@8GD@>T!L:6YK('-E=$-O;F9I9R@I?0T*("`@("`J($!V
M87(@4$5!4E]#;VYF:6<-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@
M*B\-"B`@("!V87(@)%]C;VYF:6<[#0H@("`@+RHJ#0H@("`@("H@5&AI<R!I
M<R!I;FET:6%L:7IE9"!B>2![0&QI;FL@<V5T0V]N9FEG*"E]#0H@("`@("H@
M0'9A<B!014%27U)E9VES=')Y#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@
M("`@("HO#0H@("`@=F%R("1?<F5G:7-T<GD[#0H@("`@+RHJ#0H@("`@("H@
M1FEL96YA;64@;V8@=&AE(&1E<&5N9&5N8WD@1$(@*'5S=6%L;'D@+F1E<&1B
M*0T*("`@("`J($!V87(@<W1R:6YG#0H@("`@("H@0&%C8V5S<R!P<FEV871E
M#0H@("`@("HO#0H@("`@=F%R("1?9&5P9&(@/2!F86QS93L-"B`@("`O*BH-
M"B`@("`@*B!&:6QE(&YA;64@;V8@=&AE(&QO8VMF:6QE("AU<W5A;&QY("YD
M97!D8FQO8VLI#0H@("`@("H@0'9A<B!S=')I;F<-"B`@("`@*B!`86-C97-S
M('!R:79A=&4-"B`@("`@*B\-"B`@("!V87(@)%]L;V-K9FEL92`](&9A;'-E
M.PT*("`@("\J*@T*("`@("`J($]P96X@9FEL92!R97-O=7)C92!F;W(@;&]C
M:VEN9R!T:&4@;&]C:V9I;&4-"B`@("`@*B!`=F%R(')E<V]U<F-E?&9A;'-E
M#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?
M;&]C:T9P(#T@9F%L<V4[#0H@("`@+RHJ#0H@("`@("H@05!)('9E<G-I;VX@
M;V8@=&AI<R!C;&%S<RP@=7-E9"!T;R!V86QI9&%T92!A(&9I;&4@;VXM9&ES
M:PT*("`@("`J($!V87(@<W1R:6YG#0H@("`@("H@0&%C8V5S<R!P<FEV871E
M#0H@("`@("HO#0H@("`@=F%R("1?=F5R<VEO;B`]("<Q+C`G.PT*("`@("\J
M*@T*("`@("`J($-A8VAE9"!D97!E;F1E;F-Y(&1A=&%B87-E(&9I;&4-"B`@
M("`@*B!`=F%R(&%R<F%Y?&YU;&P-"B`@("`@*B!`86-C97-S('!R:79A=&4-
M"B`@("`@*B\-"B`@("!V87(@)%]C86-H93L-"@T*("`@("\O('U]?0T*("`@
M("\O('M[>R`F('-I;F=L971O;B@I#0H-"B`@("`O*BH-"B`@("`@*B!'970@
M82!R87<@9&5P96YD96YC>2!D871A8F%S92X@($-A;&QS('-E=$-O;F9I9R@I
M(&%N9"!A<W-E<G1$97!S1$(H*0T*("`@("`J($!P87)A;2!014%27T-O;F9I
M9PT*("`@("`J($!P87)A;2!S=')I;F=\9F%L<V4@9G5L;"!P871H('1O('1H
M92!D97!E;F1E;F-Y(&1A=&%B87-E+"!O<B!F86QS92!T;R!U<V4@9&5F875L
M=`T*("`@("`J($!R971U<FX@4$5!4E]$97!E;F1E;F-Y1$)\4$5!4E]%<G)O
M<@T*("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F<VEN
M9VQE=&]N*"8D8V]N9FEG+"`D9&5P9&(@/2!F86QS92D-"B`@("![#0H@("`@
M("`@(&EF("@A:7-S970H)$=,3T)!3%-;)U]014%27T1%4$5.1$5.0UE$0E])
M3E-404Y#12==#0H@("`@("`@("`@("`@(%LD8V]N9FEG+3YG970H)W!H<%]D
M:7(G+"!N=6QL+"`G<&5A<BYP:'`N;F5T)RE=*2D@>PT*("`@("`@("`@("`@
M)&$@/2!N97<@4$5!4E]$97!E;F1E;F-Y1$([#0H@("`@("`@("`@("`D1TQ/
M0D%,4ULG7U!%05)?1$5014Y$14Y#641"7TE.4U1!3D-%)UT-"B`@("`@("`@
M("`@("`@6R1C;VYF:6<M/F=E="@G<&AP7V1I<B<L(&YU;&PL("=P96%R+G!H
M<"YN970G*5T@/2`F)&$[#0H@("`@("`@("`@("`D82T^<V5T0V]N9FEG*"1C
M;VYF:6<L("1D97!D8BD[#0H@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D92`]("1A+3YA<W-E<G1$97!S1$(H*2DI('L-"B`@("`@("`@("`@("`@
M("!R971U<FX@)&4[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N("1'3$]"04Q36R=?4$5!4E]$15!%3D1%3D-91$)?24Y35$%.
M0T4G70T*("`@("`@("`@("`@("!;)&-O;F9I9RT^9V5T*"=P:'!?9&ER)RP@
M;G5L;"P@)W!E87(N<&AP+FYE="<I73L-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!3970@=7`@=&AE(')E9VES=')Y+VQO8V%T:6]N(&]F(&1E<&5N9&5N
M8WD@1$(-"B`@("`@*B!`<&%R86T@4$5!4E]#;VYF:6=\9F%L<V4-"B`@("`@
M*B!`<&%R86T@<W1R:6YG?&9A;'-E(&9U;&P@<&%T:"!T;R!T:&4@9&5P96YD
M96YC>2!D871A8F%S92P@;W(@9F%L<V4@=&\@=7-E(&1E9F%U;'0-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!S971#;VYF:6<H)B1C;VYF:6<L("1D97!D8B`]
M(&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*"$D8V]N9FEG*2![#0H@("`@
M("`@("`@("`D=&AI<RT^7V-O;F9I9R`]("9014%27T-O;F9I9SHZ<VEN9VQE
M=&]N*"D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D=&AI<RT^
M7V-O;F9I9R`]("8D8V]N9FEG.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES
M+3Y?<F5G:7-T<GD@/2`F)'1H:7,M/E]C;VYF:6<M/F=E=%)E9VES=')Y*"D[
M#0H@("`@("`@(&EF("@A)&1E<&1B*2![#0H@("`@("`@("`@("`D=&AI<RT^
M7V1E<&1B(#T@)'1H:7,M/E]C;VYF:6<M/F=E="@G<&AP7V1I<B<L(&YU;&PL
M("=P96%R+G!H<"YN970G*2`N#0H@("`@("`@("`@("`@("`@1$E214-43U)9
M7U-%4$%2051/4B`N("<N9&5P9&(G.PT*("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@)'1H:7,M/E]D97!D8B`]("1D97!D8CL-"B`@("`@("`@?0T*
M("`@("`@("`D=&AI<RT^7VQO8VMF:6QE(#T@9&ER;F%M92@D=&AI<RT^7V1E
M<&1B*2`N($1)4D5#5$]265]315!!4D%43U(@+B`G+F1E<&1B;&]C:R<[#0H@
M("`@?0T*("`@("\O('U]?0T*#0H@("`@9G5N8W1I;VX@:&%S5W)I=&5!8V-E
M<W,H*0T*("`@('L-"B`@("`@("`@:68@*"%`9FEL95]E>&ES=',H)'1H:7,M
M/E]D97!D8BDI('L-"B`@("`@("`@("`@("1D:7(@/2`D=&AI<RT^7V1E<&1B
M.PT*("`@("`@("`@("`@=VAI;&4@*"1D:7(@)B8@)&1I<B`A/2`G+B<I('L-
M"B`@("`@("`@("`@("`@("`D9&ER(#T@9&ER;F%M92@D9&ER*3L@+R\@8V0@
M+BX-"B`@("`@("`@("`@("`@("!I9B`H)&1I<B`A/2`G+B<@)B8@0&9I;&5?
M97AI<W1S*"1D:7(I*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("A`:7-?
M=W)I=&5A8FQE*"1D:7(I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!R
M971U<FX@=')U93L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@
M("`@("!R971U<FX@0&ES7W=R:71E86)L92@D=&AI<RT^7V1E<&1B*3L-"B`@
M("!]#0H-"B`@("`O+R![>WL@87-S97)T1&5P<T1"*"D-"@T*("`@("\J*@T*
M("`@("`J($-R96%T92!T:&4@9&5P96YD96YC>2!D871A8F%S92P@:68@:70@
M9&]E<VXG="!E>&ES="X@($5R<F]R(&EF('1H92!D871A8F%S92!I<PT*("`@
M("`J(&YE=V5R('1H86X@=&AE(&-O9&4@<F5A9&EN9R!I="X-"B`@("`@*B!`
M<F5T=7)N('9O:61\4$5!4E]%<G)O<@T*("`@("`J+PT*("`@(&9U;F-T:6]N
M(&%S<V5R=$1E<'-$0B@I#0H@("`@>PT*("`@("`@("!I9B`H(6ES7V9I;&4H
M)'1H:7,M/E]D97!D8BDI('L-"B`@("`@("`@("`@("1T:&ES+3YR96)U:6QD
M1$(H*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1D97!D8B`]
M("1T:&ES+3Y?9V5T1&5P1$(H*3L-"B`@("`@("`@("`@("\O($1A=&%T>7!E
M(&9O<FUA="!H87,@8F5E;B!C:&%N9V5D+"!R96)U:6QD('1H92!$97!S($1"
M#0H@("`@("`@("`@("!I9B`H)&1E<&1B6R=?=F5R<VEO;B==(#P@)'1H:7,M
M/E]V97)S:6]N*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/G)E8G5I;&1$
M0B@I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1D97!D8ELG
M7W9E<G-I;VXG77LP?2`^("1T:&ES+3Y?=F5R<VEO;GLP?2D@>PT*("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=$97!E;F1E;F-Y
M(&1A=&%B87-E(&ES('9E<G-I;VX@)R`N#0H@("`@("`@("`@("`@("`@("`@
M("1D97!D8ELG7W9E<G-I;VXG72`N("<L(&%N9"!W92!A<F4@=F5R<VEO;B`G
M("X-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]V97)S:6]N("X@)RP@
M8V%N;F]T(&-O;G1I;G5E)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!'970@82!L:7-T(&]F(&EN<W1A
M;&QE9"!P86-K86=E<R!T:&%T(&1E<&5N9"!O;B!T:&ES('!A8VMA9V4-"B`@
M("`@*B!`<&%R86T@4$5!4E]086-K86=E1FEL95]V,7Q014%27U!A8VMA9V5&
M:6QE7W8R?&%R<F%Y#0H@("`@("H@0')E='5R;B!A<G)A>7QF86QS90T*("`@
M("`J+PT*("`@(&9U;F-T:6]N(&=E=$1E<&5N9&5N=%!A8VMA9V5S*"8D<&MG
M*0T*("`@('L-"B`@("`@("`@)&1A=&$@/2`D=&AI<RT^7V=E=$1E<$1"*"D[
M#0H@("`@("`@(&EF("AI<U]O8FIE8W0H)'!K9RDI('L-"B`@("`@("`@("`@
M("1C:&%N;F5L(#T@<W1R=&]L;W=E<B@D<&MG+3YG971#:&%N;F5L*"DI.PT*
M("`@("`@("`@("`@)'!A8VMA9V4@/2!S=')T;VQO=V5R*"1P:V<M/F=E=%!A
M8VMA9V4H*2D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D8VAA
M;FYE;"`]('-T<G1O;&]W97(H)'!K9ULG8VAA;FYE;"==*3L-"B`@("`@("`@
M("`@("1P86-K86=E(#T@<W1R=&]L;W=E<B@D<&MG6R=P86-K86=E)UTI.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&%T85LG<&%C:V%G97,G
M75LD8VAA;FYE;%U;)'!A8VMA9V5=*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M("1D871A6R=P86-K86=E<R==6R1C:&%N;F5L75LD<&%C:V%G95T[#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("`J($=E="!A(&QI<W0@;V8@=&AE(&%C='5A;"!D97!E;F1E;F-I
M97,@;V8@:6YS=&%L;&5D('!A8VMA9V5S('1H870@9&5P96YD(&]N#0H@("`@
M("H@82!P86-K86=E+@T*("`@("`J($!P87)A;2!014%27U!A8VMA9V5&:6QE
M7W8Q?%!%05)?4&%C:V%G949I;&5?=C)\87)R87D-"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y?&9A;'-E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T1&5P96YD
M96YT4&%C:V%G941E<&5N9&5N8VEE<R@F)'!K9RD-"B`@("![#0H@("`@("`@
M("1D871A(#T@)'1H:7,M/E]G971$97!$0B@I.PT*("`@("`@("!I9B`H:7-?
M;V)J96-T*"1P:V<I*2![#0H@("`@("`@("`@("`D8VAA;FYE;"`]('-T<G1O
M;&]W97(H)'!K9RT^9V5T0VAA;FYE;"@I*3L-"B`@("`@("`@("`@("1P86-K
M86=E(#T@<W1R=&]L;W=E<B@D<&MG+3YG971086-K86=E*"DI.PT*("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@)&-H86YN96P@/2!S=')T;VQO=V5R
M*"1P:V=;)V-H86YN96PG72D[#0H@("`@("`@("`@("`D<&%C:V%G92`]('-T
M<G1O;&]W97(H)'!K9ULG<&%C:V%G92==*3L-"B`@("`@("`@?0T*("`@("`@
M("`D9&5P96YD(#T@)'1H:7,M/F=E=$1E<&5N9&5N=%!A8VMA9V5S*"1P:V<I
M.PT*("`@("`@("!I9B`H(21D97!E;F0I('L-"B`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D9&5P96YD96YC:65S(#T@
M87)R87DH*3L-"B`@("`@("`@9F]R96%C:"`H)&1E<&5N9"!A<R`D:6YF;RD@
M>PT*("`@("`@("`@("`@)'1E;7`@/2`D=&AI<RT^9V5T1&5P96YD96YC:65S
M*"1I;F9O*3L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1T96UP(&%S("1D97`I
M('L-"B`@("`@("`@("`@("`@("!I9B`H<W1R=&]L;W=E<B@D9&5P6R=D97`G
M75LG8VAA;FYE;"==*2`]/2!S=')T;VQO=V5R*"1C:&%N;F5L*2`F)@T*("`@
M("`@("`@("`@("`@("`@("`@('-T<G1O;&]W97(H)&1E<%LG9&5P)UU;)VYA
M;64G72D@/3T@<W1R=&]L;W=E<B@D<&%C:V%G92DI('L-"B`@("`@("`@("`@
M("`@("`@("`@)&1E<&5N9&5N8VEE<ULD:6YF;ULG8VAA;FYE;"==75LD:6YF
M;ULG<&%C:V%G92==75M=(#T@)&1E<#L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1D97!E
M;F1E;F-I97,[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@1V5T(&$@;&ES
M="!O9B!D97!E;F1E;F-I97,@;V8@=&AI<R!I;G-T86QL960@<&%C:V%G90T*
M("`@("`J($!P87)A;2!014%27U!A8VMA9V5&:6QE7W8Q?%!%05)?4&%C:V%G
M949I;&5?=C)\87)R87D-"B`@("`@*B!`<F5T=7)N(&%R<F%Y?&9A;'-E#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@9V5T1&5P96YD96YC:65S*"8D<&MG*0T*
M("`@('L-"B`@("`@("`@:68@*&ES7V]B:F5C="@D<&MG*2D@>PT*("`@("`@
M("`@("`@)&-H86YN96P@/2!S=')T;VQO=V5R*"1P:V<M/F=E=$-H86YN96PH
M*2D[#0H@("`@("`@("`@("`D<&%C:V%G92`]('-T<G1O;&]W97(H)'!K9RT^
M9V5T4&%C:V%G92@I*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("1C:&%N;F5L(#T@<W1R=&]L;W=E<B@D<&MG6R=C:&%N;F5L)UTI.PT*("`@
M("`@("`@("`@)'!A8VMA9V4@/2!S=')T;VQO=V5R*"1P:V=;)W!A8VMA9V4G
M72D[#0H@("`@("`@('T-"B`@("`@("`@)&1A=&$@/2`D=&AI<RT^7V=E=$1E
M<$1"*"D[#0H@("`@("`@(&EF("AI<W-E="@D9&%T85LG9&5P96YD96YC:65S
M)UU;)&-H86YN96Q=6R1P86-K86=E72DI('L-"B`@("`@("`@("`@(')E='5R
M;B`D9&%T85LG9&5P96YD96YC:65S)UU;)&-H86YN96Q=6R1P86-K86=E73L-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@1&5T97)M:6YE('=H971H97(@)'!A<F5N="!D97!E
M;F1S(&]N("1C:&EL9"P@;F5A<B!O<B!D965P#0H@("`@("H@0'!A<F%M(&%R
M<F%Y?%!%05)?4&%C:V%G949I;&5?=C)\4$5!4E]086-K86=E1FEL95]V,@T*
M("`@("`J($!P87)A;2!A<G)A>7Q014%27U!A8VMA9V5&:6QE7W8R?%!%05)?
M4&%C:V%G949I;&5?=C(-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!D97!E;F1S
M3VXH)'!A<F5N="P@)&-H:6QD*0T*("`@('L-"B`@("`@("`@)&,@/2!A<G)A
M>2@I.PT*("`@("`@("`D=&AI<RT^7V=E=$1E<$1"*"D[#0H@("`@("`@(')E
M='5R;B`D=&AI<RT^7V1E<&5N9'-/;B@D<&%R96YT+"`D8VAI;&0L("1C*3L-
M"B`@("!]#0H@("`@#0H@("`@9G5N8W1I;VX@7V1E<&5N9'-/;B@D<&%R96YT
M+"`D8VAI;&0L("8D8VAE8VME9"D-"B`@("![#0H@("`@("`@(&EF("AI<U]O
M8FIE8W0H)'!A<F5N="DI('L-"B`@("`@("`@("`@("1C:&%N;F5L(#T@<W1R
M=&]L;W=E<B@D<&%R96YT+3YG971#:&%N;F5L*"DI.PT*("`@("`@("`@("`@
M)'!A8VMA9V4@/2!S=')T;VQO=V5R*"1P87)E;G0M/F=E=%!A8VMA9V4H*2D[
M#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D8VAA;FYE;"`]('-T
M<G1O;&]W97(H)'!A<F5N=%LG8VAA;FYE;"==*3L-"B`@("`@("`@("`@("1P
M86-K86=E(#T@<W1R=&]L;W=E<B@D<&%R96YT6R=P86-K86=E)UTI.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("AI<U]O8FIE8W0H)&-H:6QD*2D@>PT*("`@
M("`@("`@("`@)&1E<&-H86YN96P@/2!S=')T;VQO=V5R*"1C:&EL9"T^9V5T
M0VAA;FYE;"@I*3L-"B`@("`@("`@("`@("1D97!P86-K86=E(#T@<W1R=&]L
M;W=E<B@D8VAI;&0M/F=E=%!A8VMA9V4H*2D[#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`D9&5P8VAA;FYE;"`]('-T<G1O;&]W97(H)&-H:6QD
M6R=C:&%N;F5L)UTI.PT*("`@("`@("`@("`@)&1E<'!A8VMA9V4@/2!S=')T
M;VQO=V5R*"1C:&EL9%LG<&%C:V%G92==*3L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H:7-S970H)&-H96-K961;)&-H86YN96Q=6R1P86-K86=E75LD9&5P
M8VAA;FYE;%U;)&1E<'!A8VMA9V5=*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.R`O+R!A=F]I9"!E;F1L97-S(')E8W5R<VEO;@T*("`@("`@("!]
M#0H@("`@("`@("1C:&5C:V5D6R1C:&%N;F5L75LD<&%C:V%G95U;)&1E<&-H
M86YN96Q=6R1D97!P86-K86=E72`]('1R=64[#0H@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]C86-H95LG9&5P96YD96YC:65S)UU;)&-H86YN96Q=6R1P
M86-K86=E72DI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@?0T*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V-A8VAE6R=D97!E;F1E
M;F-I97,G75LD8VAA;FYE;%U;)'!A8VMA9V5=(&%S("1I;F9O*2![#0H@("`@
M("`@("`@("!I9B`H<W1R=&]L;W=E<B@D:6YF;ULG9&5P)UU;)V-H86YN96PG
M72D@/3T@<W1R=&]L;W=E<B@D9&5P8VAA;FYE;"D@)B8-"B`@("`@("`@("`@
M("`@("`@('-T<G1O;&]W97(H)&EN9F];)V1E<"==6R=N86UE)UTI(#T]('-T
M<G1O;&]W97(H)&1E<'!A8VMA9V4I*2![#0H@("`@("`@("`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/E]C86-H95LG9&5P96YD96YC:65S)UU;)&-H86YN
M96Q=6R1P86-K86=E72!A<R`D:6YF;RD@>PT*("`@("`@("`@("`@:68@*"1T
M:&ES+3Y?9&5P96YD<T]N*&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G
M8VAA;FYE;"<@/3X@)&EN9F];)V1E<"==6R=C:&%N;F5L)UTL#0H@("`@("`@
M("`@("`@("`@("`@("=P86-K86=E)R`]/B`D:6YF;ULG9&5P)UU;)VYA;64G
M72DL("1C:&EL9"P@)&-H96-K960I*2![#0H@("`@("`@("`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%)E9VES
M=&5R(&1E<&5N9&5N8VEE<R!O9B!A('!A8VMA9V4@=&AA="!I<R!B96EN9R!I
M;G-T86QL960@;W(@=7!G<F%D960-"B`@("`@*B!`<&%R86T@4$5!4E]086-K
M86=E1FEL95]V,GQ014%27U!A8VMA9V5&:6QE7W8R#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@:6YS=&%L;%!A8VMA9V4H)B1P86-K86=E*0T*("`@('L-"B`@
M("`@("`@)&1A=&$@/2`D=&AI<RT^7V=E=$1E<$1"*"D[#0H@("`@("`@('5N
M<V5T*"1T:&ES+3Y?8V%C:&4I.PT*("`@("`@("`D=&AI<RT^7W-E=%!A8VMA
M9V5$97!S*"1D871A+"`D<&%C:V%G92D[#0H@("`@("`@("1T:&ES+3Y?=W)I
M=&5$97!$0B@D9&%T82D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4F5M
M;W9E(&1E<&5N9&5N8VEE<R!O9B!A('!A8VMA9V4@=&AA="!I<R!B96EN9R!U
M;FEN<W1A;&QE9"P@;W(@=7!G<F%D960N#0H@("`@("H-"B`@("`@*B!5<&=R
M861E9"!P86-K86=E<R!F:7)S="!U;FEN<W1A;&PL('1H96X@:6YS=&%L;`T*
M("`@("`J($!P87)A;2!014%27U!A8VMA9V5&:6QE7W8Q?%!%05)?4&%C:V%G
M949I;&5?=C)\87)R87D@268@86X@87)R87DL('1H96X@:70@;75S="!H879E
M#0H@("`@("H@("`@("`@(&EN9&EC97,@)V-H86YN96PG(&%N9"`G<&%C:V%G
M92<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!U;FEN<W1A;&Q086-K86=E*"8D
M<&MG*0T*("`@('L-"B`@("`@("`@)&1A=&$@/2`D=&AI<RT^7V=E=$1E<$1"
M*"D[#0H@("`@("`@('5N<V5T*"1T:&ES+3Y?8V%C:&4I.PT*("`@("`@("!I
M9B`H:7-?;V)J96-T*"1P:V<I*2![#0H@("`@("`@("`@("`D8VAA;FYE;"`]
M('-T<G1O;&]W97(H)'!K9RT^9V5T0VAA;FYE;"@I*3L-"B`@("`@("`@("`@
M("1P86-K86=E(#T@<W1R=&]L;W=E<B@D<&MG+3YG971086-K86=E*"DI.PT*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&-H86YN96P@/2!S=')T
M;VQO=V5R*"1P:V=;)V-H86YN96PG72D[#0H@("`@("`@("`@("`D<&%C:V%G
M92`]('-T<G1O;&]W97(H)'!K9ULG<&%C:V%G92==*3L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H(6ES<V5T*"1D871A6R=D97!E;F1E;F-I97,G75LD8VAA
M;FYE;%U;)'!A8VMA9V5=*2D@>PT*("`@("`@("`@("`@<F5T=7)N('1R=64[
M#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H)&1A=&%;)V1E<&5N9&5N
M8VEE<R==6R1C:&%N;F5L75LD<&%C:V%G95T@87,@)&1E<"D@>PT*("`@("`@
M("`@("`@)&9O=6YD(#T@9F%L<V4[#0H@("`@("`@("`@("!I9B`H:7-S970H
M)&1E<%LG9&5P)UU;)W5R:2==*2D@>PT*("`@("`@("`@("`@("`@("1D97!C
M:&%N;F5L(#T@)U]?=7)I)SL-"B`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@)&1E<&-H86YN96P@/2!S=')T;VQO=V5R*"1D97!;)V1E
M<"==6R=C:&%N;F5L)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M:68@*&ES<V5T*"1D871A6R=P86-K86=E<R==6R1D97!C:&%N;F5L75MS=')T
M;VQO=V5R*"1D97!;)V1E<"==6R=N86UE)UTI72DI('L-"B`@("`@("`@("`@
M("`@("!F;W)E86-H("@D9&%T85LG<&%C:V%G97,G75LD9&5P8VAA;FYE;%U;
M<W1R=&]L;W=E<B@D9&5P6R=D97`G75LG;F%M92==*5T@87,-"B`@("`@("`@
M("`@("`@("`@("`@("`D:2`]/B`D:6YF;RD@>PT*("`@("`@("`@("`@("`@
M("`@("!I9B`H)&EN9F];)V-H86YN96PG72`]/2`D8VAA;FYE;"`F)@T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`D:6YF;ULG<&%C:V%G92==(#T]("1P
M86-K86=E*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D9F]U;F0@/2!T
M<G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!I9B`H)&9O=6YD*2![#0H@("`@("`@("`@("`@
M("`@=6YS970H)&1A=&%;)W!A8VMA9V5S)UU;)&1E<&-H86YN96Q=6W-T<G1O
M;&]W97(H)&1E<%LG9&5P)UU;)VYA;64G72E=6R1I72D[#0H@("`@("`@("`@
M("`@("`@:68@*"%C;W5N="@D9&%T85LG<&%C:V%G97,G75LD9&5P8VAA;FYE
M;%U;<W1R=&]L;W=E<B@D9&5P6R=D97`G75LG;F%M92==*5TI*2![#0H@("`@
M("`@("`@("`@("`@("`@('5N<V5T*"1D871A6R=P86-K86=E<R==6R1D97!C
M:&%N;F5L75MS=')T;VQO=V5R*"1D97!;)V1E<"==6R=N86UE)UTI72D[#0H@
M("`@("`@("`@("`@("`@("`@(&EF("@A8V]U;G0H)&1A=&%;)W!A8VMA9V5S
M)UU;)&1E<&-H86YN96Q=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M=6YS970H)&1A=&%;)W!A8VMA9V5S)UU;)&1E<&-H86YN96Q=*3L-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@("`@("1D871A6R=P86-K86=E<R==6R1D97!C:&%N
M;F5L75MS=')T;VQO=V5R*"1D97!;)V1E<"==6R=N86UE)UTI72`]#0H@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>5]V86QU97,H#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&1A=&%;)W!A8VMA9V5S)UU;)&1E<&-H86YN
M96Q=6W-T<G1O;&]W97(H)&1E<%LG9&5P)UU;)VYA;64G72E=*3L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@=6YS970H)&1A=&%;)V1E<&5N9&5N8VEE<R==6R1C:&%N;F5L75LD<&%C
M:V%G95TI.PT*("`@("`@("!I9B`H(6-O=6YT*"1D871A6R=D97!E;F1E;F-I
M97,G75LD8VAA;FYE;%TI*2![#0H@("`@("`@("`@("!U;G-E="@D9&%T85LG
M9&5P96YD96YC:65S)UU;)&-H86YN96Q=*3L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H(6-O=6YT*"1D871A6R=D97!E;F1E;F-I97,G72DI('L-"B`@("`@
M("`@("`@('5N<V5T*"1D871A6R=D97!E;F1E;F-I97,G72D[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"%C;W5N="@D9&%T85LG<&%C:V%G97,G72DI('L-
M"B`@("`@("`@("`@('5N<V5T*"1D871A6R=P86-K86=E<R==*3L-"B`@("`@
M("`@?0T*("`@("`@("`D=&AI<RT^7W=R:71E1&5P1$(H)&1A=&$I.PT*("`@
M('T-"@T*("`@("\J*@T*("`@("`J(%)E8G5I;&0@=&AE(&1E<&5N9&5N8WD@
M1$(@8GD@<F5A9&EN9R!R96=I<W1R>2!E;G1R:65S+@T*("`@("`J($!R971U
M<FX@=')U97Q014%27T5R<F]R#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<F5B
M=6EL9$1"*"D-"B`@("![#0H@("`@("`@("1D97!D8B`](&%R<F%Y*"=?=F5R
M<VEO;B<@/3X@)'1H:7,M/E]V97)S:6]N*3L-"B`@("`@("`@:68@*"$D=&AI
M<RT^:&%S5W)I=&5!8V-E<W,H*2D@>PT*("`@("`@("`@("`@+R\@86QL;W<@
M<W1A<G1U<"!F;W(@<F5A9"UO;FQY('=I=&@@;VQD97(@4F5G:7-T<GD-"B`@
M("`@("`@("`@(')E='5R;B`D9&5P9&([#0H@("`@("`@('T-"B`@("`@("`@
M)'!A8VMA9V5S(#T@)'1H:7,M/E]R96=I<W1R>2T^;&ES=$%L;%!A8VMA9V5S
M*"D[#0H@("`@("`@(&9O<F5A8V@@*"1P86-K86=E<R!A<R`D8VAA;FYE;"`]
M/B`D<',I('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1P<R!A<R`D<&%C:V%G
M92D@>PT*("`@("`@("`@("`@("`@("1P86-K86=E(#T@)'1H:7,M/E]R96=I
M<W1R>2T^9V5T4&%C:V%G92@D<&%C:V%G92P@)&-H86YN96PI.PT*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<V5T4&%C:V%G941E<',H)&1E<&1B+"`D<&%C
M:V%G92D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)&5R
M<F]R(#T@)'1H:7,M/E]W<FET941E<$1"*"1D97!D8BD[#0H@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1E<G)O<BDI('L-"B`@("`@("`@("`@(')E='5R
M;B`D97)R;W([#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]C86-H92`]
M("1D97!D8CL-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@4F5G:7-T97(@=7-A9V4@;V8@=&AE(&1E<&5N9&5N8WD@
M1$(@=&\@<')E=F5N="!R86-E(&-O;F1I=&EO;G,-"B`@("`@*B!`<&%R86T@
M:6YT(&]N92!O9B!T:&4@3$]#2U\J(&-O;G-T86YT<PT*("`@("`J($!R971U
M<FX@=')U97Q014%27T5R<F]R#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@7VQO8VLH)&UO9&4@/2!,3T-+7T58*0T*
M("`@('L-"B`@("`@("`@:68@*"%E<F5G:2@G5VEN9&]W<R`Y)RP@<&AP7W5N
M86UE*"DI*2![#0H@("`@("`@("`@("!I9B`H)&UO9&4@(3T@3$]#2U]53B`F
M)B!I<U]R97-O=7)C92@D=&AI<RT^7VQO8VM&<"DI('L-"B`@("`@("`@("`@
M("`@("`O+R!86%@@9&]E<R!N;W0@8VAE8VL@='EP92!O9B!L;V-K("A,3T-+
M7U-(+TQ/0TM?15@I#0H@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`D;W!E;E]M;V1E(#T@)W<G.PT*
M("`@("`@("`@("`@+R\@6%A8(%!E;W!L92!R97!O<G1E9"!P<F]B;&5M<R!W
M:71H($Q/0TM?4T@@86YD("=W)PT*("`@("`@("`@("`@:68@*"1M;V1E(#T]
M/2!,3T-+7U-(*2![#0H@("`@("`@("`@("`@("`@:68@*$`A:7-?9FEL92@D
M=&AI<RT^7VQO8VMF:6QE*2D@>PT*("`@("`@("`@("`@("`@("`@("!T;W5C
M:"@D=&AI<RT^7VQO8VMF:6QE*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@)&]P96Y?;6]D92`]("=R)SL-"B`@("`@("`@("`@('T-
M"@T*("`@("`@("`@("`@:68@*"%I<U]R97-O=7)C92@D=&AI<RT^7VQO8VM&
M<"DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7VQO8VM&<"`]($!F;W!E
M;B@D=&AI<RT^7VQO8VMF:6QE+"`D;W!E;E]M;V1E*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(&EF("@A:7-?<F5S;W5R8V4H)'1H:7,M/E]L;V-K
M1G`I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H(F-O=6QD(&YO="!C<F5A=&4@1&5P96YD96YC>2!L;V-K(&9I;&4B("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*&ES
M<V5T*"1P:'!?97)R;W)M<V<I(#\@(CH@(B`N("1P:'!?97)R;W)M<V<@.B`B
M(BDI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"$H:6YT*69L
M;V-K*"1T:&ES+3Y?;&]C:T9P+"`D;6]D92DI('L-"B`@("`@("`@("`@("`@
M("!S=VET8V@@*"1M;V1E*2![#0H@("`@("`@("`@("`@("`@("`@(&-A<V4@
M3$]#2U]32#H@)'-T<B`]("=S:&%R960G.R`@("!B<F5A:SL-"B`@("`@("`@
M("`@("`@("`@("`@8V%S92!,3T-+7T58.B`D<W1R(#T@)V5X8VQU<VEV92<[
M(&)R96%K.PT*("`@("`@("`@("`@("`@("`@("!C87-E($Q/0TM?54XZ("1S
M='(@/2`G=6YL;V-K)SL@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@
M(&1E9F%U;'0Z("`@("`@)'-T<B`]("=U;FMN;W=N)SL@("!B<F5A:SL-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H(F-O=6QD(&YO="!A8W%U:7)E("1S='(@;&]C:R`H)'1H
M:7,M/E]L;V-K9FEL92DB*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!296QE87-E('5S86=E(&]F(&1E<&5N9&5N8WD@1$(-"B`@("`@*B!`<F5T
M=7)N('1R=65\4$5!4E]%<G)O<@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*
M("`@("`J+PT*("`@(&9U;F-T:6]N(%]U;FQO8VLH*0T*("`@('L-"B`@("`@
M("`@)')E="`]("1T:&ES+3Y?;&]C:RA,3T-+7U5.*3L-"B`@("`@("`@:68@
M*&ES7W)E<V]U<F-E*"1T:&ES+3Y?;&]C:T9P*2D@>PT*("`@("`@("`@("`@
M9F-L;W-E*"1T:&ES+3Y?;&]C:T9P*3L-"B`@("`@("`@?0T*("`@("`@("`D
M=&AI<RT^7VQO8VM&<"`](&YU;&P[#0H@("`@("`@(')E='5R;B`D<F5T.PT*
M("`@('T-"@T*("`@("\J*@T*("`@("`J($QO860@=&AE(&1E<&5N9&5N8WD@
M9&%T86)A<V4@9G)O;2!D:7-K+"!O<B!R971U<FX@=&AE(&-A8VAE#0H@("`@
M("H@0')E='5R;B!A<G)A>7Q014%27T5R<F]R#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@7V=E=$1E<$1"*"D-"B`@("![#0H@("`@("`@(&EF("@A)'1H:7,M
M/FAA<U=R:71E06-C97-S*"DI('L-"B`@("`@("`@("`@(')E='5R;B!A<G)A
M>2@G7W9E<G-I;VXG(#T^("1T:&ES+3Y?=F5R<VEO;BD[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8V%C:&4I*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]C86-H93L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H(21F<"`](&9O<&5N*"1T:&ES+3Y?9&5P9&(L("=R)RDI('L-"B`@
M("`@("`@("`@("1E<G(@/2!014%2.CIR86ES945R<F]R*")#;W5L9"!N;W0@
M;W!E;B!D97!E;F1E;F-I97,@9FEL92!@(BXD=&AI<RT^7V1E<&1B+B(G(BD[
M#0H@("`@("`@("`@("!R971U<FX@)&5R<CL-"B`@("`@("`@?0T*("`@("`@
M("`D<G0@/2!G971?;6%G:6-?<75O=&5S7W)U;G1I;64H*3L-"B`@("`@("`@
M<V5T7VUA9VEC7W%U;W1E<U]R=6YT:6UE*#`I.PT*("`@("`@("!C;&5A<G-T
M871C86-H92@I.PT*("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=F:6QE
M7V=E=%]C;VYT96YT<R<I*2![#0H@("`@("`@("`@("!F8VQO<V4H)&9P*3L-
M"B`@("`@("`@("`@("1D871A(#T@=6YS97)I86QI>F4H9FEL95]G971?8V]N
M=&5N=',H)'1H:7,M/E]D97!D8BDI.PT*("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@)&1A=&$@/2!U;G-E<FEA;&EZ92AF<F5A9"@D9G`L(&9I;&5S
M:7IE*"1T:&ES+3Y?9&5P9&(I*2D[#0H@("`@("`@("`@("!F8VQO<V4H)&9P
M*3L-"B`@("`@("`@?0T*("`@("`@("!S971?;6%G:6-?<75O=&5S7W)U;G1I
M;64H)')T*3L-"B`@("`@("`@)'1H:7,M/E]C86-H92`]("1D871A.PT*("`@
M("`@("!R971U<FX@)&1A=&$[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M5W)I=&4@;W5T('1H92!D97!E;F1E;F-Y(&1A=&%B87-E('1O(&1I<VL-"B`@
M("`@*B!`<&%R86T@87)R87D@=&AE(&1A=&%B87-E#0H@("`@("H@0')E='5R
M;B!T<G5E?%!%05)?17)R;W(-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!?=W)I=&5$97!$0B@F)&1E<',I#0H@("`@
M>PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92`]("1T:&ES+3Y?;&]C
M:RA,3T-+7T58*2DI('L-"B`@("`@("`@("`@(')E='5R;B`D93L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H(21F<"`](&9O<&5N*"1T:&ES+3Y?9&5P9&(L
M("=W8B<I*2![#0H@("`@("`@("`@("`D=&AI<RT^7W5N;&]C:R@I.PT*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D-O=6QD(&YO="!O
M<&5N(&1E<&5N9&5N8VEE<R!F:6QE(&`B+B1T:&ES+3Y?9&5P9&(N(B<@9F]R
M('=R:71I;F<B*3L-"B`@("`@("`@?0T*("`@("`@("`D<G0@/2!G971?;6%G
M:6-?<75O=&5S7W)U;G1I;64H*3L-"B`@("`@("`@<V5T7VUA9VEC7W%U;W1E
M<U]R=6YT:6UE*#`I.PT*("`@("`@("!F=W)I=&4H)&9P+"!S97)I86QI>F4H
M)&1E<',I*3L-"B`@("`@("`@<V5T7VUA9VEC7W%U;W1E<U]R=6YT:6UE*"1R
M="D[#0H@("`@("`@(&9C;&]S92@D9G`I.PT*("`@("`@("`D=&AI<RT^7W5N
M;&]C:R@I.PT*("`@("`@("`D=&AI<RT^7V-A8VAE(#T@)&1E<',[#0H@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%)E
M9VES=&5R(&%L;"!D97!E;F1E;F-I97,@9G)O;2!A('!A8VMA9V4@:6X@=&AE
M(&1E<&5N9&5N8VEE<R!D871A8F%S92P@:6X@97-S96YC90T*("`@("`J(")I
M;G-T86QL:6YG(B!T:&4@<&%C:V%G92=S(&1E<&5N9&5N8WD@:6YF;W)M871I
M;VX-"B`@("`@*B!`<&%R86T@87)R87D@=&AE(&1A=&%B87-E#0H@("`@("H@
M0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C%\4$5!4E]086-K86=E1FEL95]V
M,@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T
M:6]N(%]S971086-K86=E1&5P<R@F)&1A=&$L("8D<&MG*0T*("`@('L-"B`@
M("`@("`@)'!K9RT^<V5T0V]N9FEG*"1T:&ES+3Y?8V]N9FEG*3L-"B`@("`@
M("`@:68@*"1P:V<M/F=E=%!A8VMA9V5X;6Q697)S:6]N*"D@/3T@)S$N,"<I
M('L-"B`@("`@("`@("`@("1G96X@/2`F)'!K9RT^9V5T1&5F875L=$=E;F5R
M871O<B@I.PT*("`@("`@("`@("`@)&1E<',@/2`D9V5N+3YD97!E;F1E;F-I
M97-4;U8R*"D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D9&5P
M<R`]("1P:V<M/F=E=$1E<',H=')U92D[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*"$D9&5P<RD@>PT*("`@("`@("`@("`@<F5T=7)N.PT*("`@("`@("!]
M#0H@("`@("`@("1D871A6R=D97!E;F1E;F-I97,G75MS=')T;VQO=V5R*"1P
M:V<M/F=E=$-H86YN96PH*2E=6W-T<G1O;&]W97(H)'!K9RT^9V5T4&%C:V%G
M92@I*5T-"B`@("`@("`@("`@(#T@87)R87DH*3L-"B`@("`@("`@:68@*&ES
M<V5T*"1D97!S6R=R97%U:7)E9"==6R=P86-K86=E)UTI*2![#0H@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1D97!S6R=R97%U:7)E9"==6R=P86-K86=E)UU;
M,%TI*2![#0H@("`@("`@("`@("`@("`@)&1E<'-;)W)E<75I<F5D)UU;)W!A
M8VMA9V4G72`](&%R<F%Y*"1D97!S6R=R97%U:7)E9"==6R=P86-K86=E)UTI
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H)&1E<'-;
M)W)E<75I<F5D)UU;)W!A8VMA9V4G72!A<R`D9&5P*2![#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]R96=I<W1E<D1E<"@D9&%T82P@)'!K9RP@)&1E<"P@
M)W)E<75I<F5D)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@:68@*&ES<V5T*"1D97!S6R=O<'1I;VYA;"==6R=P86-K86=E)UTI*2![
M#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1D97!S6R=O<'1I;VYA;"==6R=P
M86-K86=E)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@)&1E<'-;)V]P=&EO
M;F%L)UU;)W!A8VMA9V4G72`](&%R<F%Y*"1D97!S6R=O<'1I;VYA;"==6R=P
M86-K86=E)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C
M:"`H)&1E<'-;)V]P=&EO;F%L)UU;)W!A8VMA9V4G72!A<R`D9&5P*2![#0H@
M("`@("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1E<D1E<"@D9&%T82P@)'!K
M9RP@)&1E<"P@)V]P=&EO;F%L)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!S6R=R97%U:7)E9"==6R=S=6)P
M86-K86=E)UTI*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1D97!S6R=R
M97%U:7)E9"==6R=S=6)P86-K86=E)UU;,%TI*2![#0H@("`@("`@("`@("`@
M("`@)&1E<'-;)W)E<75I<F5D)UU;)W-U8G!A8VMA9V4G72`](&%R<F%Y*"1D
M97!S6R=R97%U:7)E9"==6R=S=6)P86-K86=E)UTI.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@9F]R96%C:"`H)&1E<'-;)W)E<75I<F5D)UU;)W-U
M8G!A8VMA9V4G72!A<R`D9&5P*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M
M/E]R96=I<W1E<D1E<"@D9&%T82P@)'!K9RP@)&1E<"P@)W)E<75I<F5D)RD[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T
M*"1D97!S6R=O<'1I;VYA;"==6R=S=6)P86-K86=E)UTI*2![#0H@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1D97!S6R=O<'1I;VYA;"==6R=S=6)P86-K86=E
M)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@)&1E<'-;)V]P=&EO;F%L)UU;
M)W-U8G!A8VMA9V4G72`](&%R<F%Y*"1D97!S6R=O<'1I;VYA;"==6R=S=6)P
M86-K86=E)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C
M:"`H)&1E<'-;)V]P=&EO;F%L)UU;)W-U8G!A8VMA9V4G72!A<R`D9&5P*2![
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1E<D1E<"@D9&%T82P@
M)'!K9RP@)&1E<"P@)V]P=&EO;F%L)RD[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!S6R=G<F]U<"==*2D@>PT*
M("`@("`@("`@("`@:68@*"%I<W-E="@D9&5P<ULG9W)O=7`G75LP72DI('L-
M"B`@("`@("`@("`@("`@("`D9&5P<ULG9W)O=7`G72`](&%R<F%Y*"1D97!S
M6R=G<F]U<"==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1D97!S6R=G<F]U<"==(&%S("1G<F]U<"D@>PT*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D9W)O=7!;)W!A8VMA9V4G72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D9W)O=7!;)W!A8VMA9V4G75LP72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1G<F]U<%LG<&%C:V%G92==
M(#T@87)R87DH)&=R;W5P6R=P86-K86=E)UTI.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1G<F]U<%LG
M<&%C:V%G92==(&%S("1D97`I('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<F5G:7-T97)$97`H)&1A=&$L("1P:V<L("1D97`L("=O<'1I
M;VYA;"<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&=R;W5P6R=A
M='1R:6)S)UU;)VYA;64G72D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1G
M<F]U<%LG<W5B<&%C:V%G92==*2D@>PT*("`@("`@("`@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1G<F]U<%LG<W5B<&%C:V%G92==6S!=*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)&=R;W5P6R=S=6)P86-K86=E)UT@/2!A<G)A
M>2@D9W)O=7!;)W-U8G!A8VMA9V4G72D[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&=R;W5P6R=S=6)P
M86-K86=E)UT@87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]R96=I<W1E<D1E<"@D9&%T82P@)'!K9RP@)&1E<"P@)V]P=&EO
M;F%L)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9W)O=7!;)V%T
M=')I8G,G75LG;F%M92==*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H)&1A=&%;)V1E<&5N9&5N8VEE<R==6W-T<G1O;&]W97(H)'!K
M9RT^9V5T0VAA;FYE;"@I*5T-"B`@("`@("`@("`@("`@6W-T<G1O;&]W97(H
M)'!K9RT^9V5T4&%C:V%G92@I*5T@/3T@87)R87DH*2D@>PT*("`@("`@("`@
M("`@=6YS970H)&1A=&%;)V1E<&5N9&5N8VEE<R==6W-T<G1O;&]W97(H)'!K
M9RT^9V5T0VAA;FYE;"@I*5T-"B`@("`@("`@("`@("`@6W-T<G1O;&]W97(H
M)'!K9RT^9V5T4&%C:V%G92@I*5TI.PT*("`@("`@("`@("`@:68@*"%C;W5N
M="@D9&%T85LG9&5P96YD96YC:65S)UU;<W1R=&]L;W=E<B@D<&MG+3YG971#
M:&%N;F5L*"DI72DI('L-"B`@("`@("`@("`@("`@("!U;G-E="@D9&%T85LG
M9&5P96YD96YC:65S)UU;<W1R=&]L;W=E<B@D<&MG+3YG971#:&%N;F5L*"DI
M72D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O
M*BH-"B`@("`@*B!`<&%R86T@87)R87D@=&AE(&1A=&%B87-E#0H@("`@("H@
M0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C%\4$5!4E]086-K86=E1FEL95]V
M,@T*("`@("`J($!P87)A;2!A<G)A>2!T:&4@<W!E8VEF:6,@9&5P96YD96YC
M>0T*("`@("`J($!P87)A;2!R97%U:7)E9'QO<'1I;VYA;"!W:&5T:&5R('1H
M:7,@:7,@82!R97%U:7)E9"!O<B!A;B!O<'1I;VYA;"!D97`-"B`@("`@*B!`
M<&%R86T@<W1R:6YG?&9A;'-E(&1E<&5N9&5N8WD@9W)O=7`@=&AI<R!D97!E
M;F1E;F-Y(&ES(&9R;VTL(&]R(&9A;'-E(&9O<B!O<F1I;F%R>2!D97`-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!?<F5G:7-T97)$97`H)B1D871A+"`F)'!K
M9RP@)&1E<"P@)'1Y<&4L("1G<F]U<"`](&9A;'-E*0T*("`@('L-"B`@("`@
M("`@)&EN9F\@/2!A<G)A>2@-"B`@("`@("`@("`@("=D97`G(#T^("1D97`L
M#0H@("`@("`@("`@("`G='EP92<@/3X@)'1Y<&4L#0H@("`@("`@("`@("`G
M9W)O=7`G(#T^("1G<F]U<"D[#0H-"B`@("`@("`@:68@*&ES<V5T*"1D97!;
M)V-H86YN96PG72DI('L-"B`@("`@("`@("`@("1D97!C:&%N;F5L(#T@)&1E
M<%LG8VAA;FYE;"==.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M)&1E<&-H86YN96P@/2`G7U]U<FDG.PT*("`@("`@("!]#0H@("`@("`@("1D
M871A6R=D97!E;F1E;F-I97,G75MS=')T;VQO=V5R*"1P:V<M/F=E=$-H86YN
M96PH*2E=6W-T<G1O;&]W97(H)'!K9RT^9V5T4&%C:V%G92@I*5U;70T*("`@
M("`@("`@("`@/2`D:6YF;SL-"B`@("`@("`@:68@*&ES<V5T*"1D871A6R=P
M86-K86=E<R==6W-T<G1O;&]W97(H)&1E<&-H86YN96PI75MS=')T;VQO=V5R
M*"1D97!;)VYA;64G72E=*2D@>PT*("`@("`@("`@("`@)&9O=6YD(#T@9F%L
M<V4[#0H@("`@("`@("`@("!F;W)E86-H("@D9&%T85LG<&%C:V%G97,G75MS
M=')T;VQO=V5R*"1D97!C:&%N;F5L*5U;<W1R=&]L;W=E<B@D9&5P6R=N86UE
M)UTI70T*("`@("`@("`@("`@("`@("`@87,@)&D@/3X@)'`I('L-"B`@("`@
M("`@("`@("`@("!I9B`H)'!;)V-H86YN96PG72`]/2!S=')T;VQO=V5R*"1P
M:V<M/F=E=$-H86YN96PH*2D@)B8-"B`@("`@("`@("`@("`@("`@("`@("`D
M<%LG<&%C:V%G92==(#T]('-T<G1O;&]W97(H)'!K9RT^9V5T4&%C:V%G92@I
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`D9F]U;F0@/2!T<G5E.PT*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(21F;W5N9"D@>PT*("`@
M("`@("`@("`@("`@("1D871A6R=P86-K86=E<R==6W-T<G1O;&]W97(H)&1E
M<&-H86YN96PI75MS=')T;VQO=V5R*"1D97!;)VYA;64G72E=6UT-"B`@("`@
M("`@("`@("`@("`@("`@/2!A<G)A>2@G8VAA;FYE;"<@/3X@<W1R=&]L;W=E
M<B@D<&MG+3YG971#:&%N;F5L*"DI+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=P86-K86=E)R`]/B!S=')T;VQO=V5R*"1P:V<M/F=E=%!A8VMA
M9V4H*2DI.PT*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@)&1A=&%;)W!A8VMA9V5S)UU;<W1R=&]L;W=E<B@D9&5P8VAA
M;FYE;"E=6W-T<G1O;&]W97(H)&1E<%LG;F%M92==*5U;70T*("`@("`@("`@
M("`@("`@(#T@87)R87DH)V-H86YN96PG(#T^('-T<G1O;&]W97(H)'!K9RT^
M9V5T0VAA;FYE;"@I*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("=P86-K
M86=E)R`]/B!S=')T;VQO=V5R*"1P:V<M/F=E=%!A8VMA9V4H*2DI.PT*("`@
M("`@("!]#0H@("`@?0T*?0T*/SX`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!
M4B]$97!E;F1E;F-Y,BYP:'``````````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#$T,3`V,2`Q,#4Q-30S,S<S,B`P,C(P-S``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`-"B\J*@T*("H@
M4$5!4E]$97!E;F1E;F-Y,BP@861V86YC960@9&5P96YD96YC>2!V86QI9&%T
M:6]N#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%
M3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S
M+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%52
M23H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)
M9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,
M:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H
M92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N
M;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@
M*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*
M("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*
M("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L
M:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@
M(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z($1E
M<&5N9&5N8WDR+G!H<"QV(#$N-3`@,C`P-B\P,2\P-B`P-#HT-SHS-B!C96QL
M;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O
M<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S
M:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*#0HO*BH-"B`J(%)E<75I<F5D
M(&9O<B!T:&4@4$5!4E]604Q)1$%415\J(&-O;G-T86YT<PT*("HO#0IR97%U
M:7)E7V]N8V4@)U!%05(O5F%L:61A=&4N<&AP)SL-"@T*+RHJ#0H@*B!$97!E
M;F1E;F-Y(&-H96-K(&9O<B!014%2('!A8VMA9V5S#0H@*@T*("H@5&AI<R!C
M;&%S<R!H86YD;&5S(&)O=&@@=F5R<VEO;B`Q+C`@86YD(#(N,"!D97!E;F1E
M;F-I97,-"B`J(%=!4DY)3D<Z("IA;GDJ(&-H86YG97,@=&\@=&AI<R!C;&%S
M<R!M=7-T(&)E(&1U<&QI8V%T960@:6X@=&AE#0H@*B!T97-T7U!%05)?1&5P
M96YD96YC>3(@8VQA<W,@9F]U;F0@:6X@=&5S=',O4$5!4E]$97!E;F1E;F-Y
M,B]S971U<"YP:'`N:6YC+`T*("H@;W(@=6YI="!T97-T<R!W:6QL(&YO="!A
M8W1U86QL>2!V86QI9&%T92!T:&4@8VAA;F=E<PT*("H@0&-A=&5G;W)Y("`@
M<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E
M9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY
M-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*
M("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@
M("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@
M*B\-"F-L87-S(%!%05)?1&5P96YD96YC>3(-"GL-"B`@("`O*BH-"B`@("`@
M*B!/;F4@;V8@=&AE(%!%05)?5D%,241!5$5?*B!S=&%T97,-"B`@("`@*B!`
M<V5E(%!%05)?5D%,241!5$5?3D]234%,#0H@("`@("H@0'9A<B!I;G1E9V5R
M#0H@("`@("HO#0H@("`@=F%R("1?<W1A=&4[#0H@("`@+RHJ#0H@("`@("H@
M0V]M;6%N9"UL:6YE(&]P=&EO;G,@=&\@:6YS=&%L;"]U<&=R861E+W5N:6YS
M=&%L;"!C;VUM86YD<PT*("`@("`J($!P87)A;2!A<G)A>0T*("`@("`J+PT*
M("`@('9A<B`D7V]P=&EO;G,[#0H@("`@+RHJ#0H@("`@("H@0'9A<B!/4U]'
M=65S<PT*("`@("`J+PT*("`@('9A<B`D7V]S.PT*("`@("\J*@T*("`@("`J
M($!V87(@4$5!4E]296=I<W1R>0T*("`@("`J+PT*("`@('9A<B`D7W)E9VES
M=')Y.PT*("`@("\J*@T*("`@("`J($!V87(@4$5!4E]#;VYF:6<-"B`@("`@
M*B\-"B`@("!V87(@)%]C;VYF:6<[#0H@("`@+RHJ#0H@("`@("H@0'9A<B!0
M14%27T1E<&5N9&5N8WE$0@T*("`@("`J+PT*("`@('9A<B`D7V1E<&5N9&5N
M8WED8CL-"B`@("`O*BH-"B`@("`@*B!/=71P=70@;V8@4$5!4E]296=I<W1R
M>3HZ<&%R<V5D4&%C:V%G94YA;64H*0T*("`@("`J($!V87(@87)R87D-"B`@
M("`@*B\-"B`@("!V87(@)%]C=7)R96YT4&%C:V%G93L-"B`@("`O*BH-"B`@
M("`@*B!`<&%R86T@4$5!4E]#;VYF:6<-"B`@("`@*B!`<&%R86T@87)R87D@
M:6YS=&%L;&%T:6]N(&]P=&EO;G,-"B`@("`@*B!`<&%R86T@87)R87D@9F]R
M;6%T(&]F(%!%05)?4F5G:7-T<GDZ.G!A<G-E9%!A8VMA9V5.86UE*"D-"B`@
M("`@*B!`<&%R86T@:6YT(&EN<W1A;&QA=&EO;B!S=&%T92`H;VYE(&]F(%!%
M05)?5D%,241!5$5?*BD-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!014%27T1E
M<&5N9&5N8WDR*"8D8V]N9FEG+"`D:6YS=&%L;&]P=&EO;G,L("1P86-K86=E
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-T871E(#T@4$5!
M4E]604Q)1$%415])3E-404Q,24Y'*0T*("`@('L-"B`@("`@("`@)'1H:7,M
M/E]C;VYF:6<@/2`F)&-O;F9I9SL-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES
M=',H)U!%05)?1&5P96YD96YC>41")RDI('L-"B`@("`@("`@("`@(')E<75I
M<F5?;VYC92`G4$5!4B]$97!E;F1E;F-Y1$(N<&AP)SL-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H:7-S970H)&EN<W1A;&QO<'1I;VYS6R=P86-K86=I;F=R
M;V]T)UTI*2![#0H@("`@("`@("`@("`O+R!M86ME('-U<F4@9&5P9&(@:7,@
M:6X@=&AE(')I9VAT(&QO8V%T:6]N#0H@("`@("`@("`@("`D8V]N9FEG+3YS
M971);G-T86QL4F]O="@D:6YS=&%L;&]P=&EO;G-;)W!A8VMA9VEN9W)O;W0G
M72D[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]R96=I<W1R>2`]("8D
M8V]N9FEG+3YG971296=I<W1R>2@I.PT*("`@("`@("`D=&AI<RT^7V1E<&5N
M9&5N8WED8B`]("9014%27T1E<&5N9&5N8WE$0CHZ<VEN9VQE=&]N*"1C;VYF
M:6<I.PT*("`@("`@("!I9B`H:7-S970H)&EN<W1A;&QO<'1I;VYS6R=P86-K
M86=I;F=R;V]T)UTI*2![#0H@("`@("`@("`@("`D8V]N9FEG+3YS971);G-T
M86QL4F]O="AF86QS92D[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]O
M<'1I;VYS(#T@)&EN<W1A;&QO<'1I;VYS.PT*("`@("`@("`D=&AI<RT^7W-T
M871E(#T@)'-T871E.PT*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G3U-?
M1W5E<W,G*2D@>PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=/4R]'=65S
M<RYP:'`G.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?;W,@/2!N97<@
M3U-?1W5E<W,[#0H@("`@("`@("1T:&ES+3Y?8W5R<F5N=%!A8VMA9V4@/2`D
M<&%C:V%G93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?9V5T17AT<F%3=')I
M;F<H)&1E<"D-"B`@("![#0H@("`@("`@("1E>'1R82`]("<@*"<[#0H@("`@
M("`@(&EF("AI<W-E="@D9&5P6R=U<FDG72DI('L-"B`@("`@("`@("`@(')E
M='5R;B`G)SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&1E<%LG
M<F5C;VUM96YD960G72DI('L-"B`@("`@("`@("`@("1E>'1R82`N/2`G<F5C
M;VUM96YD960@=F5R<VEO;B`G("X@)&1E<%LG<F5C;VUM96YD960G73L-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=M
M:6XG72DI('L-"B`@("`@("`@("`@("`@("`D97AT<F$@+CT@)W9E<G-I;VX@
M/CT@)R`N("1D97!;)VUI;B==.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@:68@*&ES<V5T*"1D97!;)VUA>"==*2D@>PT*("`@("`@("`@("`@("`@
M(&EF("@D97AT<F$@(3T@)R`H)RD@>PT*("`@("`@("`@("`@("`@("`@("`D
M97AT<F$@+CT@)RP@)SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@)&5X=')A("X]("=V97)S:6]N(#P]("<@+B`D9&5P6R=M87@G73L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=E
M>&-L=61E)UTI*2![#0H@("`@("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D
M9&5P6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1D97!;
M)V5X8VQU9&4G72`](&%R<F%Y*"1D97!;)V5X8VQU9&4G72D[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D97AT<F$@(3T@)R`H
M)RD@>PT*("`@("`@("`@("`@("`@("`@("`D97AT<F$@+CT@)RP@)SL-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&5X=')A("X]("=E
M>&-L=61E9"!V97)S:6]N<SH@)SL-"B`@("`@("`@("`@("`@("!F;W)E86-H
M("@D9&5P6R=E>&-L=61E)UT@87,@)&D@/3X@)&5X8VQU9&4I('L-"B`@("`@
M("`@("`@("`@("`@("`@:68@*"1I*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D97AT<F$@+CT@)RP@)SL-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`D97AT<F$@+CT@)&5X8VQU9&4[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@("1E>'1R82`N/2`G*2<[#0H@("`@("`@(&EF("@D97AT<F$@/3T@)R`H
M*2<I('L-"B`@("`@("`@("`@("1E>'1R82`]("<G.PT*("`@("`@("!]#0H@
M("`@("`@(')E='5R;B`D97AT<F$[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@5&AI<R!M86ME<R!U;FET+71E<W1I;F<@82!H96-K(&]F(&$@;&]T(&5A
M<VEE<@T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=%!(4%]/4R@I#0H@("`@
M>PT*("`@("`@("!R971U<FX@4$A07T]3.PT*("`@('T-"@T*("`@("\J*@T*
M("`@("`J(%1H:7,@;6%K97,@=6YI="UT97-T:6YG(&$@:&5C:R!O9B!A(&QO
M="!E87-I97(-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971S>7-N86UE*"D-
M"B`@("![#0H@("`@("`@(')E='5R;B`D=&AI<RT^7V]S+3YG9713>7-N86UE
M*"D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4W!E8VEF>2!A(&1E<&5N
M9&5N8WD@;VX@86X@3U,N("!5<V4@87)C:"!F;W(@9&5T86EL960@;W,O<')O
M8V5S<V]R(&EN9F]R;6%T:6]N#0H@("`@("H-"B`@("`@*B!4:&5R92!A<F4@
M='=O(&=E;F5R:6,@3U,@9&5P96YD96YC:65S('1H870@=VEL;"!B92!T:&4@
M;6]S="!C;VUM;VXL('5N:7@@86YD('=I;F1O=W,N#0H@("`@("H@3W1H97(@
M;W!T:6]N<R!A<F4@;&EN=7@L(&9R965B<V0L(&1A<G=I;B`H3U,@6"DL('-U
M;F]S+"!I<FEX+"!H<'5X+"!A:7@-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!V
M86QI9&%T94]S1&5P96YD96YC>2@D9&5P*0T*("`@('L-"B`@("`@("`@:68@
M*"1T:&ES+3Y?<W1A=&4@(3T@4$5!4E]604Q)1$%415])3E-404Q,24Y'("8F
M#0H@("`@("`@("`@("`@("1T:&ES+3Y?<W1A=&4@(3T@4$5!4E]604Q)1$%4
M15]$3U=.3$]!1$E.1RD@>PT*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!;)V-O;F9L:6-T<R==
M*2D@>PT*("`@("`@("`@("`@)&YO="`]('1R=64[#0H@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`D;F]T(#T@9F%L<V4[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"1D97!;)VYA;64G72`]/2`G*B<I('L-"B`@("`@("`@("`@
M(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@("`@("`@('-W:71C:"`H<W1R
M=&]L;W=E<B@D9&5P6R=N86UE)UTI*2![#0H@("`@("`@("`@("!C87-E("=W
M:6YD;W=S)R`Z#0H@("`@("`@("`@("`@("`@:68@*"1N;W0I('L-"B`@("`@
M("`@("`@("`@("`@("`@:68@*'-T<G1O;&]W97(H<W5B<W1R*"1T:&ES+3YG
M97102%!?3U,H*2P@,"P@,RDI(#T]("=W:6XG*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;F]D97!S
M)UTI("8F#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`A:7-S970H
M)'1H:7,M/E]O<'1I;VYS6R=F;W)C92==*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B0V%N;F]T
M(&EN<W1A;&P@)7,@;VX@5VEN9&]W<R(I.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G=A<FYI;F<H(G=A<FYI;F<Z($-A;FYO="!I;G-T86QL
M("5S(&]N(%=I;F1O=W,B*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@("`@(&EF("AS=')T;VQO=V5R*'-U8G-T
M<B@D=&AI<RT^9V5T4$A07T]3*"DL(#`L(#,I*2`A/2`G=VEN)RD@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO
M;G-;)VYO9&5P<R==*2`F)@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9F]R8V4G72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H(D-A;B!O;FQY(&EN<W1A;&P@)7,@;VX@5VEN9&]W<R(I.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G=A<FYI;F<H(G=A<FYI;F<Z($-A
M;B!O;FQY(&EN<W1A;&P@)7,@;VX@5VEN9&]W<R(I.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C
M87-E("=U;FEX)R`Z#0H@("`@("`@("`@("`@("`@)'5N:6-E<R`](&%R<F%Y
M*"=L:6YU>"<L("=F<F5E8G-D)RP@)V1A<G=I;B<L("=S=6YO<R<L("=I<FEX
M)RP@)VAP=7@G+"`G86EX)RD[#0H@("`@("`@("`@("`@("`@:68@*"1N;W0I
M('L-"B`@("`@("`@("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"1T:&ES+3YG
M9713>7-N86UE*"DL("1U;FEC97,I*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;F]D97!S)UTI("8F
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`A:7-S970H)'1H:7,M
M/E]O<'1I;VYS6R=F;W)C92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B0V%N;F]T(&EN<W1A
M;&P@)7,@;VX@86YY(%5N:7@@<WES=&5M(BD[#0H@("`@("`@("`@("`@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^=V%R;FEN9R@-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(G=A<FYI;F<Z($-A;FYO="!I;G-T86QL("5S(&]N(&%N
M>2!5;FEX('-Y<W1E;2(I.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I;E]A<G)A>2@D=&AI<RT^
M9V5T4WES;F%M92@I+"`D=6YI8V5S*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)VYO9&5P<R==*2`F
M)@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(6ES<V5T*"1T:&ES
M+3Y?;W!T:6]N<ULG9F]R8V4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D-A;B!O;FQY(&EN
M<W1A;&P@)7,@;VX@82!5;FEX('-Y<W1E;2(I.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G=A<FYI;F<H#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(")W87)N:6YG.B!#86X@;VYL>2!I;G-T86QL("5S(&]N
M(&$@56YI>"!S>7-T96TB*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@9&5F875L="`Z#0H@("`@
M("`@("`@("`@("`@:68@*"1N;W0I('L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*'-T<G1O;&]W97(H)&1E<%LG;F%M92==*2`]/2!S=')T;VQO=V5R*"1T
M:&ES+3YG9713>7-N86UE*"DI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;F]D97!S)UTI("8F#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`A:7-S970H)'1H:7,M/E]O
M<'1I;VYS6R=F;W)C92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G0V%N;F]T(&EN<W1A;&P@
M)7,@;VX@)R`N("1D97!;)VYA;64G72`N#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("<@;W!E<F%T:6YG('-Y<W1E;2<I.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G=A<FYI;F<H)W=A<FYI;F<Z($-A;FYO
M="!I;G-T86QL("5S(&]N("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9&5P6R=N86UE)UT@+B`G(&]P97)A=&EN9R!S>7-T96TG*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@("`@(&EF("AS=')T;VQO=V5R*"1D97!;)VYA;64G72D@(3T@<W1R=&]L
M;W=E<B@D=&AI<RT^9V5T4WES;F%M92@I*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)VYO9&5P<R==
M*2`F)@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(6ES<V5T*"1T
M:&ES+3Y?;W!T:6]N<ULG9F]R8V4G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-A;FYO="!I
M;G-T86QL("5S(&]N("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^9V5T4WES;F%M92@I("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)R!O<&5R871I;F<@<WES=&5M+"!C86X@;VYL>2!I
M;G-T86QL(&]N("<@+B`D9&5P6R=N86UE)UTI.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G=A<FYI;F<H)W=A<FYI;F<Z($-A;FYO="!I;G-T
M86QL("5S(&]N("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^9V5T4WES;F%M92@I("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)R!O<&5R871I;F<@<WES=&5M+"!C86X@;VYL>2!I;G-T
M86QL(&]N("<@+B`D9&5P6R=N86UE)UTI.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-
M"@T*("`@("\J*@T*("`@("`J(%1H:7,@;6%K97,@=6YI="UT97-T:6YG(&$@
M:&5C:R!O9B!A(&QO="!E87-I97(-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!M
M871C:%-I9VYA='5R92@D<&%T=&5R;BD-"B`@("![#0H@("`@("`@(')E='5R
M;B`D=&AI<RT^7V]S+3YM871C:%-I9VYA='5R92@D<&%T=&5R;BD[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@4W!E8VEF>2!A(&-O;7!L97@@9&5P96YD
M96YC>2!O;B!A;B!/4R]P<F]C97-S;W(O:V5R;F5L('9E<G-I;VXL#0H@("`@
M("H@57-E($]3(&9O<B!S:6UP;&4@;W!E<F%T:6YG('-Y<W1E;2!D97!E;F1E
M;F-Y+@T*("`@("`J#0H@("`@("H@5&AI<R!I<R!T:&4@;VYL>2!D97!E;F1E
M;F-Y('1H870@86-C97!T<R!A;B!E<F5G86)L92!P871T97)N+B`@5&AE('!A
M='1E<FX-"B`@("`@*B!W:6QL(&)E(&UA=&-H960@86=A:6YS="!T:&4@<&AP
M7W5N86UE*"D@;W5T<'5T('!A<G-E9"!B>2!/4U]'=65S<PT*("`@("`J+PT*
M("`@(&9U;F-T:6]N('9A;&ED871E07)C:$1E<&5N9&5N8WDH)&1E<"D-"B`@
M("![#0H@("`@("`@(&EF("@D=&AI<RT^7W-T871E("$](%!%05)?5D%,241!
M5$5?24Y35$%,3$E.1RD@>PT*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!;)V-O;F9L:6-T<R==
M*2D@>PT*("`@("`@("`@("`@)&YO="`]('1R=64[#0H@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`D;F]T(#T@9F%L<V4[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"$D=&AI<RT^;6%T8VA3:6=N871U<F4H)&1E<%LG<&%T=&5R
M;B==*2D@>PT*("`@("`@("`@("`@:68@*"$D;F]T*2![#0H@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)VYO9&5P<R==*2`F
M)B`A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=F;W)C92==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)R5S($%R
M8VAI=&5C='5R92!D97!E;F1E;F-Y(&9A:6QE9"P@9&]E<R!N;W0@)R`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`G;6%T8V@@(B<@+B`D9&5P6R=P871T
M97)N)UT@+B`G(B<I.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^=V%R;FEN9R@G=V%R;FEN
M9SH@)7,@07)C:&ET96-T=7)E(&1E<&5N9&5N8WD@9F%I;&5D+"!D;V5S("<@
M+@T*("`@("`@("`@("`@("`@("`@("`@("`@)VYO="!M871C:"`B)R`N("1D
M97!;)W!A='1E<FXG72`N("<B)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("!I9B`H)&YO="D@>PT*("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N;V1E<',G72D@
M)B8@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9F]R8V4G72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"<E<R!!
M<F-H:71E8W1U<F4@9&5P96YD96YC>2!F86EL960L(')E<75I<F5D("(G("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1D97!;)W!A='1E<FXG72`N("<B
M)RD[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YW87)N:6YG*"=W87)N:6YG.B`E<R!!<F-H
M:71E8W1U<F4@9&5P96YD96YC>2!F86EL960L("<@+@T*("`@("`@("`@("`@
M("`@("`@("`@("`@)W)E<75I<F5D("(G("X@)&1E<%LG<&%T=&5R;B==("X@
M)R(G*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@?0T*("`@('T-"@T*("`@
M("\J*@T*("`@("`J(%1H:7,@;6%K97,@=6YI="UT97-T:6YG(&$@:&5C:R!O
M9B!A(&QO="!E87-I97(-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!E>'1E;G-I
M;VY?;&]A9&5D*"1N86UE*0T*("`@('L-"B`@("`@("`@<F5T=7)N(&5X=&5N
M<VEO;E]L;V%D960H)&YA;64I.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J
M(%1H:7,@;6%K97,@=6YI="UT97-T:6YG(&$@:&5C:R!O9B!A(&QO="!E87-I
M97(-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!P:'!V97)S:6]N*"1N86UE(#T@
M;G5L;"D-"B`@("![#0H@("`@("`@(&EF("@D;F%M92`A/3T@;G5L;"D@>PT*
M("`@("`@("`@("`@<F5T=7)N('!H<'9E<G-I;VXH)&YA;64I.PT*("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@<F5T=7)N('!H<'9E<G-I;VXH*3L-
M"B`@("`@("`@?0T*("`@('T-"@T*("`@(&9U;F-T:6]N('9A;&ED871E17AT
M96YS:6]N1&5P96YD96YC>2@D9&5P+"`D<F5Q=6ER960@/2!T<G5E*0T*("`@
M('L-"B`@("`@("`@:68@*"1T:&ES+3Y?<W1A=&4@(3T@4$5!4E]604Q)1$%4
M15])3E-404Q,24Y'("8F#0H@("`@("`@("`@("`@("1T:&ES+3Y?<W1A=&4@
M(3T@4$5!4E]604Q)1$%415]$3U=.3$]!1$E.1RD@>PT*("`@("`@("`@("`@
M<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@)&QO861E9"`]("1T
M:&ES+3YE>'1E;G-I;VY?;&]A9&5D*"1D97!;)VYA;64G72D[#0H@("`@("`@
M("1E>'1R82`]("1T:&ES+3Y?9V5T17AT<F%3=')I;F<H)&1E<"D[#0H@("`@
M("`@(&EF("AI<W-E="@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@
M("!I9B`H(6ES7V%R<F%Y*"1D97!;)V5X8VQU9&4G72DI('L-"B`@("`@("`@
M("`@("`@("`D9&5P6R=E>&-L=61E)UT@/2!A<G)A>2@D9&5P6R=E>&-L=61E
M)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@A
M:7-S970H)&1E<%LG;6EN)UTI("8F("%I<W-E="@D9&5P6R=M87@G72D@)B8-
M"B`@("`@("`@("`@("`@(6ES<V5T*"1D97!;)W)E8V]M;65N9&5D)UTI("8F
M("%I<W-E="@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("!I9B`H
M)&QO861E9"D@>PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=C
M;VYF;&EC=',G72DI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D=&AI<RT^7V]P=&EO;G-;)VYO9&5P<R==*2`F)B`A:7-S970H)'1H:7,M
M/E]O<'1I;VYS6R=F;W)C92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"<E<R!C;VYF;&EC=',@=VET
M:"!02%`@97AT96YS:6]N("(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D9&5P6R=N86UE)UT@+B`G(B<@+B`D97AT<F$I.PT*("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YW87)N:6YG*"=W87)N:6YG.B`E<R!C;VYF;&EC=',@
M=VET:"!02%`@97AT96YS:6]N("(G("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9&5P6R=N86UE)UT@+B`G(B<@+B`D97AT<F$I.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG8V]N9FQI8W1S)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H)')E<75I<F5D*2![#0H@
M("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS
M6R=N;V1E<',G72D@)B8@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9F]R8V4G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@G)7,@<F5Q=6ER97,@4$A0(&5X=&5N<VEO;B`B)R`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E<%LG;F%M92==("X@)R(G
M("X@)&5X=')A*3L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^=V%R;FEN9R@G
M=V%R;FEN9SH@)7,@<F5Q=6ER97,@4$A0(&5X=&5N<VEO;B`B)R`N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&1E<%LG;F%M92==("X@)R(G("X@
M)&5X=')A*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^=V%R;FEN9R@G)7,@8V%N(&]P=&EO;F%L;'D@=7-E(%!(4"!E>'1E;G-I
M;VX@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)&1E<%LG;F%M92==
M("X@)R(G("X@)&5X=')A*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D;&]A9&5D*2![#0H@
M("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG8V]N9FQI8W1S)UTI*2![#0H@
M("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!I9B`H(21R97%U:7)E9"D@>PT*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^=V%R;FEN9R@G)7,@8V%N(&]P=&EO;F%L;'D@=7-E
M(%!(4"!E>'1E;G-I;VX@(B<@+@T*("`@("`@("`@("`@("`@("`@("`D9&5P
M6R=N86UE)UT@+B`G(B<@+B`D97AT<F$I.PT*("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N
M<ULG;F]D97!S)UTI("8F("%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)V9O<F-E
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@G)7,@<F5Q=6ER97,@4$A0(&5X=&5N<VEO;B`B)R`N("1D97!;
M)VYA;64G72`N#0H@("`@("`@("`@("`@("`@("`@("`@("`G(B<@+B`D97AT
M<F$I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YW87)N:6YG*"=W87)N:6YG.B`E<R!R97%U:7)E<R!0
M2%`@97AT96YS:6]N("(G("X@)&1E<%LG;F%M92==("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("<B)R`N("1E>'1R82D[#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("`@("`@)'9E<G-I;VX@/2`H<W1R:6YG*2`D=&AI<RT^
M<&AP=F5R<VEO;B@D9&5P6R=N86UE)UTI.PT*("`@("`@("!I9B`H96UP='DH
M)'9E<G-I;VXI*2![#0H@("`@("`@("`@("`D=F5R<VEO;B`]("<P)SL-"B`@
M("`@("`@?0T*("`@("`@("`D9F%I;"`](&9A;'-E.PT*("`@("`@("!I9B`H
M:7-S970H)&1E<%LG;6EN)UTI*2![#0H@("`@("`@("`@("!I9B`H(79E<G-I
M;VY?8V]M<&%R92@D=F5R<VEO;BP@)&1E<%LG;6EN)UTL("<^/2<I*2![#0H@
M("`@("`@("`@("`@("`@)&9A:6P@/2!T<G5E.PT*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=M87@G72DI('L-
M"B`@("`@("`@("`@(&EF("@A=F5R<VEO;E]C;VUP87)E*"1V97)S:6]N+"`D
M9&5P6R=M87@G72P@)SP])RDI('L-"B`@("`@("`@("`@("`@("`D9F%I;"`]
M('1R=64[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@
M*"1F86EL("8F("%I<W-E="@D9&5P6R=C;VYF;&EC=',G72DI('L-"B`@("`@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N;V1E<',G72D@
M)B8@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9F]R8V4G72DI('L-"B`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)R5S(')E<75I
M<F5S(%!(4"!E>'1E;G-I;VX@(B<@+B`D9&5P6R=N86UE)UT@+@T*("`@("`@
M("`@("`@("`@("`@("`G(B<@+B`D97AT<F$@+B`G+"!I;G-T86QL960@=F5R
M<VEO;B!I<R`G("X@)'9E<G-I;VXI.PT*("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G=A<FYI;F<H)W=A<FYI
M;F<Z("5S(')E<75I<F5S(%!(4"!E>'1E;G-I;VX@(B<@+B`D9&5P6R=N86UE
M)UT@+@T*("`@("`@("`@("`@("`@("`@("`G(B<@+B`D97AT<F$@+B`G+"!I
M;G-T86QL960@=F5R<VEO;B!I<R`G("X@)'9E<G-I;VXI.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!](&5L<V5I9B`H*&ES<V5T*"1D97!;)VUI;B==*2!\
M?"!I<W-E="@D9&5P6R=M87@G72DI("8F("$D9F%I;"`F)B!I<W-E="@D9&5P
M6R=C;VYF;&EC=',G72DI('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H
M:7,M/E]O<'1I;VYS6R=N;V1E<',G72D@)B8@(6ES<V5T*"1T:&ES+3Y?;W!T
M:6]N<ULG9F]R8V4G72DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H)R5S(&-O;F9L:6-T<R!W:71H(%!(4"!E>'1E;G-I
M;VX@(B<@+@T*("`@("`@("`@("`@("`@("`@("`D9&5P6R=N86UE)UT@+B`G
M(B<@+B`D97AT<F$@+B`G+"!I;G-T86QL960@=F5R<VEO;B!I<R`G("X@)'9E
M<G-I;VXI.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G=A<FYI;F<H)W=A<FYI;F<Z("5S(&-O;F9L:6-T
M<R!W:71H(%!(4"!E>'1E;G-I;VX@(B<@+@T*("`@("`@("`@("`@("`@("`@
M("`D9&5P6R=N86UE)UT@+B`G(B<@+B`D97AT<F$@+B`G+"!I;G-T86QL960@
M=F5R<VEO;B!I<R`G("X@)'9E<G-I;VXI.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=E>&-L=61E)UTI*2![
M#0H@("`@("`@("`@("!F;W)E86-H("@D9&5P6R=E>&-L=61E)UT@87,@)&5X
M8VQU9&4I('L-"B`@("`@("`@("`@("`@("!I9B`H=F5R<VEO;E]C;VUP87)E
M*"1V97)S:6]N+"`D97AC;'5D92P@)ST])RDI('L-"B`@("`@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1D97!;)V-O;F9L:6-T<R==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^
M7V]P=&EO;G-;)VYO9&5P<R==*2`F)@T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=F;W)C92==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*"<E<R!I<R!N;W0@8V]M<&%T:6)L92!W:71H(%!(4"!E>'1E;G-I;VX@(B<@
M+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D97!;)VYA;64G72`N
M("<B('9E<G-I;VX@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&5X8VQU9&4I.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YW87)N:6YG*"=W
M87)N:6YG.B`E<R!I<R!N;W0@8V]M<&%T:6)L92!W:71H(%!(4"!E>'1E;G-I
M;VX@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D97!;)VYA
M;64G72`N("<B('9E<G-I;VX@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&5X8VQU9&4I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@?2!E;'-E:68@*'9E<G-I;VY?8V]M<&%R92@D=F5R<VEO
M;BP@)&5X8VQU9&4L("<A/2<I("8F(&ES<V5T*"1D97!;)V-O;F9L:6-T<R==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?
M;W!T:6]N<ULG;F]D97!S)UTI("8F("%I<W-E="@D=&AI<RT^7V]P=&EO;G-;
M)V9O<F-E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H)R5S(&-O;F9L:6-T<R!W:71H(%!(4"!E>'1E
M;G-I;VX@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D97!;
M)VYA;64G72`N("<B)R`N("1E>'1R82`N("<L(&EN<W1A;&QE9"!V97)S:6]N
M(&ES("<@+B`D=F5R<VEO;BD[#0H@("`@("`@("`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G=A
M<FYI;F<H)W=A<FYI;F<Z("5S(&-O;F9L:6-T<R!W:71H(%!(4"!E>'1E;G-I
M;VX@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D97!;)VYA
M;64G72`N("<B)R`N("1E>'1R82`N("<L(&EN<W1A;&QE9"!V97)S:6]N(&ES
M("<@+B`D=F5R<VEO;BD[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@:68@*&ES<V5T*"1D97!;)W)E8V]M;65N9&5D)UTI*2![#0H@("`@("`@
M("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*"1V97)S:6]N+"`D9&5P6R=R96-O
M;6UE;F1E9"==+"`G/3TG*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B!T
M<G5E.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;F]D97!S)UTI("8F("%I<W-E
M="@D=&AI<RT^7V]P=&EO;G-;)V9O<F-E)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G)7,@9&5P96YD96YC
M>3H@4$A0(&5X=&5N<VEO;B`G("X@)&1E<%LG;F%M92==("X-"B`@("`@("`@
M("`@("`@("`@("`@("`@("<@=F5R<VEO;B`B)R`N("1V97)S:6]N("X@)R(G
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("<@:7,@;F]T('1H92!R96-O
M;6UE;F1E9"!V97)S:6]N("(G("X@)&1E<%LG<F5C;VUM96YD960G72`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`G(BP@8G5T(&UA>2!B92!C;VUP871I
M8FQE+"!U<V4@+2UF;W)C92!T;R!I;G-T86QL)RD[#0H@("`@("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YW87)N:6YG*"=W87)N:6YG.B`E<R!D97!E;F1E;F-Y.B!02%`@97AT96YS
M:6]N("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)&1E<%LG;F%M92==
M("X@)R!V97)S:6]N("(G("X@)'9E<G-I;VX@+B`G(B<@+@T*("`@("`@("`@
M("`@("`@("`@("`@("`@)R!I<R!N;W0@=&AE(')E8V]M;65N9&5D('9E<G-I
M;VX@(B<@+B`D9&5P6R=R96-O;6UE;F1E9"==+B<B)RD[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B!T<G5E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('9A;&ED871E4&AP
M1&5P96YD96YC>2@D9&5P*0T*("`@('L-"B`@("`@("`@:68@*"1T:&ES+3Y?
M<W1A=&4@(3T@4$5!4E]604Q)1$%415])3E-404Q,24Y'("8F#0H@("`@("`@
M("`@("`@("1T:&ES+3Y?<W1A=&4@(3T@4$5!4E]604Q)1$%415]$3U=.3$]!
M1$E.1RD@>PT*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-
M"B`@("`@("`@)'9E<G-I;VX@/2`D=&AI<RT^<&AP=F5R<VEO;B@I.PT*("`@
M("`@("`D97AT<F$@/2`D=&AI<RT^7V=E=$5X=')A4W1R:6YG*"1D97`I.PT*
M("`@("`@("!I9B`H:7-S970H)&1E<%LG97AC;'5D92==*2D@>PT*("`@("`@
M("`@("`@:68@*"%I<U]A<G)A>2@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@
M("`@("`@("`@("`@)&1E<%LG97AC;'5D92==(#T@87)R87DH)&1E<%LG97AC
M;'5D92==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H:7-S970H)&1E<%LG;6EN)UTI*2![#0H@("`@("`@("`@("!I9B`H(79E
M<G-I;VY?8V]M<&%R92@D=F5R<VEO;BP@)&1E<%LG;6EN)UTL("<^/2<I*2![
M#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;
M)VYO9&5P<R==*2`F)B`A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=F;W)C92==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H)R5S(')E<75I<F5S(%!(4"<@+@T*("`@("`@("`@("`@("`@("`@
M("`@("`@)&5X=')A("X@)RP@:6YS=&%L;&5D('9E<G-I;VX@:7,@)R`N("1V
M97)S:6]N*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G=A<FYI;F<H)W=A<FYI;F<Z("5S
M(')E<75I<F5S(%!(4"<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)&5X
M=')A("X@)RP@:6YS=&%L;&5D('9E<G-I;VX@:7,@)R`N("1V97)S:6]N*3L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("`@("`@:68@*&ES<V5T*"1D97!;)VUA>"==*2D@>PT*("`@("`@("`@
M("`@:68@*"%V97)S:6]N7V-O;7!A<F4H)'9E<G-I;VXL("1D97!;)VUA>"==
M+"`G/#TG*2D@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/E]O<'1I;VYS6R=N;V1E<',G72D@)B8@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N
M<ULG9F]R8V4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*"<E<R!R97%U:7)E<R!02%`G("X-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1E>'1R82`N("<L(&EN<W1A;&QE9"!V97)S:6]N
M(&ES("<@+B`D=F5R<VEO;BD[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YW87)N:6YG*"=W
M87)N:6YG.B`E<R!R97%U:7)E<R!02%`G("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1E>'1R82`N("<L(&EN<W1A;&QE9"!V97)S:6]N(&ES("<@+B`D
M=F5R<VEO;BD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=E>&-L=61E)UTI
M*2![#0H@("`@("`@("`@("!F;W)E86-H("@D9&5P6R=E>&-L=61E)UT@87,@
M)&5X8VQU9&4I('L-"B`@("`@("`@("`@("`@("!I9B`H=F5R<VEO;E]C;VUP
M87)E*"1V97)S:6]N+"`D97AC;'5D92P@)ST])RDI('L-"B`@("`@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)VYO9&5P<R==
M*2`F)@T*("`@("`@("`@("`@("`@("`@("`@("`@("`A:7-S970H)'1H:7,M
M/E]O<'1I;VYS6R=F;W)C92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"<E<R!I<R!N;W0@8V]M<&%T
M:6)L92!W:71H(%!(4"!V97)S:6]N("<@+@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1E>&-L=61E*3L-"B`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M=V%R;FEN9R@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=V%R;FEN
M9SH@)7,@:7,@;F]T(&-O;7!A=&EB;&4@=VET:"!02%`@=F5R<VEO;B`G("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D97AC;'5D92D[#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@5&AI<R!M86ME<R!U;FET+71E<W1I;F<@
M82!H96-K(&]F(&$@;&]T(&5A<VEE<@T*("`@("`J+PT*("`@(&9U;F-T:6]N
M(&=E=%!%05)697)S:6]N*"D-"B`@("![#0H@("`@("`@(')E='5R;B`G,2XT
M+CDG.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('9A;&ED871E4&5A<FEN<W1A
M;&QE<D1E<&5N9&5N8WDH)&1E<"D-"B`@("![#0H@("`@("`@("1P96%R=F5R
M<VEO;B`]("1T:&ES+3YG971014%25F5R<VEO;B@I.PT*("`@("`@("`D97AT
M<F$@/2`D=&AI<RT^7V=E=$5X=')A4W1R:6YG*"1D97`I.PT*("`@("`@("!I
M9B`H:7-S970H)&1E<%LG97AC;'5D92==*2D@>PT*("`@("`@("`@("`@:68@
M*"%I<U]A<G)A>2@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("`@
M("`@)&1E<%LG97AC;'5D92==(#T@87)R87DH)&1E<%LG97AC;'5D92==*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H=F5R<VEO
M;E]C;VUP87)E*"1P96%R=F5R<VEO;BP@)&1E<%LG;6EN)UTL("<\)RDI('L-
M"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N;V1E
M<',G72D@)B8@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9F]R8V4G72DI('L-
M"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)R5S
M(')E<75I<F5S(%!%05(@26YS=&%L;&5R)R`N("1E>'1R82`N#0H@("`@("`@
M("`@("`@("`@("`@("<L(&EN<W1A;&QE9"!V97)S:6]N(&ES("<@+B`D<&5A
M<G9E<G-I;VXI.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G=A<FYI;F<H)W=A<FYI;F<Z("5S(')E<75I
M<F5S(%!%05(@26YS=&%L;&5R)R`N("1E>'1R82`N#0H@("`@("`@("`@("`@
M("`@("`@("<L(&EN<W1A;&QE9"!V97)S:6]N(&ES("<@+B`D<&5A<G9E<G-I
M;VXI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI
M<W-E="@D9&5P6R=M87@G72DI('L-"B`@("`@("`@("`@(&EF("AV97)S:6]N
M7V-O;7!A<F4H)'!E87)V97)S:6]N+"`D9&5P6R=M87@G72P@)SXG*2D@>PT*
M("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N
M;V1E<',G72D@)B8@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9F]R8V4G72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*"<E<R!R97%U:7)E<R!014%2($EN<W1A;&QE<B<@+B`D97AT<F$@+@T*
M("`@("`@("`@("`@("`@("`@("`@("`@)RP@:6YS=&%L;&5D('9E<G-I;VX@
M:7,@)R`N("1P96%R=F5R<VEO;BD[#0H@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YW87)N:6YG
M*"=W87)N:6YG.B`E<R!R97%U:7)E<R!014%2($EN<W1A;&QE<B<@+B`D97AT
M<F$@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)RP@:6YS=&%L;&5D('9E
M<G-I;VX@:7,@)R`N("1P96%R=F5R<VEO;BD[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E
M="@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1D97!;)V5X8VQU9&4G75LP72DI('L-"B`@("`@("`@("`@("`@("`D9&5P
M6R=E>&-L=61E)UT@/2!A<G)A>2@D9&5P6R=E>&-L=61E)UTI.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H)&1E<%LG97AC;'5D92==
M(&%S("1E>&-L=61E*2![#0H@("`@("`@("`@("`@("`@:68@*'9E<G-I;VY?
M8V]M<&%R92@D97AC;'5D92P@)'!E87)V97)S:6]N+"`G/3TG*2D@>PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG
M;F]D97!S)UTI("8F("%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)V9O<F-E)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H)R5S(&ES(&YO="!C;VUP871I8FQE('=I=&@@4$5!4B!);G-T
M86QL97(@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W9E<G-I
M;VX@)R`N("1E>&-L=61E*3L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^=V%R
M;FEN9R@G=V%R;FEN9SH@)7,@:7,@;F]T(&-O;7!A=&EB;&4@=VET:"!014%2
M("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=);G-T86QL97(@
M=F5R<VEO;B`G("X@)&5X8VQU9&4I.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N
M('9A;&ED871E4W5B<&%C:V%G941E<&5N9&5N8WDH)&1E<"P@)')E<75I<F5D
M+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3YV86QI
M9&%T95!A8VMA9V5$97!E;F1E;F-Y*"1D97`L("1R97%U:7)E9"P@)'!A<F%M
M<RD[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(&%R<F%Y(&1E
M<&5N9&5N8WD@:6YF;W)M871I;VX@*#(N,"!F;W)M870I#0H@("`@("H@0'!A
M<F%M(&)O;VQE86X@=VAE=&AE<B!T:&ES(&ES(&$@<F5Q=6ER960@9&5P96YD
M96YC>0T*("`@("`J($!P87)A;2!A<G)A>2!A(&QI<W0@;V8@9&]W;FQO861E
M9"!P86-K86=E<R!T;R!B92!I;G-T86QL960L(&EF(&%N>0T*("`@("`J($!P
M87)A;2!B;V]L96%N(&EF('1R=64L('1H96X@9&5P<R!O;B!P96%R+G!H<"YN
M970@=&AA="!F86EL('=I;&P@86QS;R!C:&5C:PT*("`@("`J("`@("`@("`@
M("`@("`@(&%G86EN<W0@<&5C;"YP:'`N;F5T('!A8VMA9V5S('1O(&%C8V]M
M;V1A=&4@97AT96YS:6]N<R!T:&%T(&AA=F4-"B`@("`@*B`@("`@("`@("`@
M("`@("!M;W9E9"!T;R!P96-L+G!H<"YN970@9G)O;2!P96%R+G!H<"YN970-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!V86QI9&%T95!A8VMA9V5$97!E;F1E
M;F-Y*"1D97`L("1R97%U:7)E9"P@)'!A<F%M<RP@)&1E<'8Q(#T@9F%L<V4I
M#0H@("`@>PT*("`@("`@("!I9B`H)'1H:7,M/E]S=&%T92`A/2!014%27U9!
M3$E$051%7TE.4U1!3$Q)3D<@)B8-"B`@("`@("`@("`@("`@)'1H:7,M/E]S
M=&%T92`A/2!014%27U9!3$E$051%7T1/5TY,3T%$24Y'*2![#0H@("`@("`@
M("`@("!R971U<FX@=')U93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S
M970H)&1E<%LG<')O=FED97-E>'1E;G-I;VXG72DI('L-"B`@("`@("`@("`@
M(&EF("@D=&AI<RT^97AT96YS:6]N7VQO861E9"@D9&5P6R=P<F]V:61E<V5X
M=&5N<VEO;B==*2D@>PT*("`@("`@("`@("`@("`@("1S879E(#T@)&1E<#L-
M"B`@("`@("`@("`@("`@("`D<W5B9&5P(#T@)&1E<#L-"B`@("`@("`@("`@
M("`@("`D<W5B9&5P6R=N86UE)UT@/2`D<W5B9&5P6R=P<F]V:61E<V5X=&5N
M<VEO;B==.PT*("`@("`@("`@("`@("`@(%!%05(Z.G!U<VA%<G)O<DAA;F1L
M:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@("`@("`@("`D<F5T
M(#T@)'1H:7,M/G9A;&ED871E17AT96YS:6]N1&5P96YD96YC>2@D<W5B9&5P
M+"`D<F5Q=6ER960I.PT*("`@("`@("`@("`@("`@(%!%05(Z.G!O<$5R<F]R
M2&%N9&QI;F<H*3L-"B`@("`@("`@("`@("`@("!I9B`H(5!%05(Z.FES17)R
M;W(H)')E="DI('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(&EF("@D=&AI<RT^7W-T871E(#T](%!%05)?5D%,241!5$5?
M24Y35$%,3$E.1RD@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?=F%L
M:61A=&5086-K86=E26YS=&%L;"@D9&5P+"`D<F5Q=6ER960L("1D97!V,2D[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"1T:&ES+3Y?<W1A=&4@/3T@4$5!
M4E]604Q)1$%415]$3U=.3$]!1$E.1RD@>PT*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?=F%L:61A=&5086-K86=E1&]W;FQO860H)&1E<"P@)')E<75I
M<F5D+"`D<&%R86US+"`D9&5P=C$I.PT*("`@("`@("!]#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@7W9A;&ED871E4&%C:V%G941O=VYL;V%D*"1D97`L("1R
M97%U:7)E9"P@)'!A<F%M<RP@)&1E<'8Q(#T@9F%L<V4I#0H@("`@>PT*("`@
M("`@("`D9&5P6R=P86-K86=E)UT@/2`D9&5P6R=N86UE)UT[#0H@("`@("`@
M(&EF("AI<W-E="@D9&5P6R=U<FDG72DI('L-"B`@("`@("`@("`@("1D97!;
M)V-H86YN96PG72`]("=?7W5R:2<[#0H@("`@("`@('T-"B`@("`@("`@)&1E
M<&YA;64@/2`D=&AI<RT^7W)E9VES=')Y+3YP87)S961086-K86=E3F%M951O
M4W1R:6YG*"1D97`L('1R=64I.PT*("`@("`@("`D9F]U;F0@/2!F86QS93L-
M"B`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D<&%R86TI('L-"B`@("`@
M("`@("`@(&EF("@D<&%R86TM/FES17%U86PH#0H@("`@("`@("`@("`@("`@
M("!A<G)A>2@G<&%C:V%G92<@/3X@)&1E<%LG;F%M92==+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@)V-H86YN96PG(#T^("1D97!;)V-H86YN96PG72DI
M*2![#0H@("`@("`@("`@("`@("`@)&9O=6YD(#T@=')U93L-"B`@("`@("`@
M("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF
M("@D9&5P=C$@)B8@)&1E<%LG8VAA;FYE;"==(#T]("=P96%R+G!H<"YN970G
M*2![#0H@("`@("`@("`@("`@("`@:68@*"1P87)A;2T^:7-%<75A;"@-"B`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"=P86-K86=E)R`]/B`D9&5P6R=N86UE
M)UTL#0H@("`@("`@("`@("`@("`@("`@("`@("`G8VAA;FYE;"<@/3X@)W!E
M8VPN<&AP+FYE="<I*2D@>PT*("`@("`@("`@("`@("`@("`@("`D9F]U;F0@
M/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M:68@*"$D9F]U;F0@)B8@:7-S970H)&1E<%LG<')O=FED97-E>'1E;G-I;VXG
M72DI('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)'!A<F%M
M*2![#0H@("`@("`@("`@("`@("`@:68@*"1P87)A;2T^:7-%>'1E;G-I;VXH
M)&1E<%LG<')O=FED97-E>'1E;G-I;VXG72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@)&9O=6YD(#T@=')U93L-"B`@("`@("`@("`@("`@("`@("`@8G)E
M86L[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@(&EF("@D9F]U;F0I('L-"B`@("`@("`@("`@("1V97)S
M:6]N(#T@)'!A<F%M+3YG971697)S:6]N*"D[#0H@("`@("`@("`@("`D:6YS
M=&%L;&5D(#T@9F%L<V4[#0H@("`@("`@("`@("`D9&]W;FQO861E9"`]('1R
M=64[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!I9B`H)'1H:7,M
M/E]R96=I<W1R>2T^<&%C:V%G945X:7-T<R@D9&5P6R=N86UE)UTL("1D97!;
M)V-H86YN96PG72DI('L-"B`@("`@("`@("`@("`@("`D:6YS=&%L;&5D(#T@
M=')U93L-"B`@("`@("`@("`@("`@("`D9&]W;FQO861E9"`](&9A;'-E.PT*
M("`@("`@("`@("`@("`@("1V97)S:6]N(#T@)'1H:7,M/E]R96=I<W1R>2T^
M<&%C:V%G96EN9F\H)&1E<%LG;F%M92==+"`G=F5R<VEO;B<L#0H@("`@("`@
M("`@("`@("`@("`@("1D97!;)V-H86YN96PG72D[#0H@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@(&EF("@D9&5P6R=C:&%N;F5L)UT@
M/3T@)W!E8VPN<&AP+FYE="<@)B8@)'1H:7,M/E]R96=I<W1R>2T^<&%C:V%G
M945X:7-T<R@D9&5P6R=N86UE)UTL#0H@("`@("`@("`@("`@("`@("`@("`@
M)W!E87(N<&AP+FYE="<I*2![#0H@("`@("`@("`@("`@("`@("`@("1I;G-T
M86QL960@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("`D9&]W;FQO861E
M9"`](&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("`D=F5R<VEO;B`]("1T
M:&ES+3Y?<F5G:7-T<GDM/G!A8VMA9V5I;F9O*"1D97!;)VYA;64G72P@)W9E
M<G-I;VXG+`T*("`@("`@("`@("`@("`@("`@("`@("`@)W!E87(N<&AP+FYE
M="<I.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@("`@("1V97)S:6]N(#T@)VYO="!I;G-T86QL960@;W(@9&]W;FQO861E
M9"<[#0H@("`@("`@("`@("`@("`@("`@("1I;G-T86QL960@/2!F86QS93L-
M"B`@("`@("`@("`@("`@("`@("`@)&1O=VYL;V%D960@/2!F86QS93L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@)&5X=')A(#T@)'1H:7,M/E]G971%>'1R85-T<FEN9R@D9&5P*3L-
M"B`@("`@("`@:68@*&ES<V5T*"1D97!;)V5X8VQU9&4G72DI('L-"B`@("`@
M("`@("`@(&EF("@A:7-?87)R87DH)&1E<%LG97AC;'5D92==*2D@>PT*("`@
M("`@("`@("`@("`@("1D97!;)V5X8VQU9&4G72`](&%R<F%Y*"1D97!;)V5X
M8VQU9&4G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M:68@*"%I<W-E="@D9&5P6R=M:6XG72D@)B8@(6ES<V5T*"1D97!;)VUA>"==
M*2`F)@T*("`@("`@("`@("`@("`A:7-S970H)&1E<%LG<F5C;VUM96YD960G
M72D@)B8@(6ES<V5T*"1D97!;)V5X8VQU9&4G72DI('L-"B`@("`@("`@("`@
M(&EF("@D:6YS=&%L;&5D('Q\("1D;W=N;&]A9&5D*2![#0H@("`@("`@("`@
M("`@("`@)&EN<W1A;&QE9"`]("1I;G-T86QL960@/R`G:6YS=&%L;&5D)R`Z
M("=D;W=N;&]A9&5D)SL-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E
M<%LG8V]N9FQI8W1S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@D
M=F5R<VEO;BD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)')E<W0@/2`B
M+"`D:6YS=&%L;&5D('9E<G-I;VX@:7,@(B`N("1V97)S:6]N.PT*("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)')E<W0@/2`G)SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;F]D
M97!S)UTI("8F("%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)V9O<F-E)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H)R5S(&-O;F9L:6-T<R!W:71H('!A8VMA9V4@(B<@+B`D9&5P;F%M
M92`N("<B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5X=')A
M("X@)')E<W0I.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YW87)N:6YG*"=W
M87)N:6YG.B`E<R!C;VYF;&EC=',@=VET:"!P86-K86=E("(G("X@)&1E<&YA
M;64@+B`G(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E>'1R
M82`N("1R97-T*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D
M97!;)V-O;F9L:6-T<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@=')U93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M:68@*"1R97%U:7)E9"D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;F]D97!S)UTI("8F("%I<W-E="@D=&AI
M<RT^7V]P=&EO;G-;)V9O<F-E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)R5S(')E<75I<F5S('!A
M8VMA9V4@(B<@+B`D9&5P;F%M92`N("<B)R`N#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&5X=')A*3L-"B`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M=V%R;FEN9R@G=V%R;FEN9SH@)7,@<F5Q=6ER97,@<&%C:V%G92`B)R`N("1D
M97!N86UE("X@)R(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M97AT<F$I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YW87)N:6YG*"<E<R!C86X@;W!T:6]N86QL>2!U<V4@<&%C:V%G92`B)R`N
M("1D97!N86UE("X@)R(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("1E
M>'1R82D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@(&EF("@A)&EN<W1A;&QE9"`F)B`A)&1O=VYL;V%D
M960I('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=C;VYF;&EC=',G
M72DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(&EF("@D<F5Q=6ER960I('L-"B`@("`@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;F]D97!S)UTI
M("8F("%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)V9O<F-E)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G)7,@
M<F5Q=6ER97,@<&%C:V%G92`B)R`N("1D97!N86UE("X@)R(G("X-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1E>'1R82D[#0H@("`@("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YW
M87)N:6YG*"=W87)N:6YG.B`E<R!R97%U:7)E<R!P86-K86=E("(G("X@)&1E
M<&YA;64@+B`G(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)&5X=')A
M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^=V%R;FEN9R@G)7,@8V%N
M(&]P=&EO;F%L;'D@=7-E('!A8VMA9V4@(B<@+B`D9&5P;F%M92`N("<B)R`N
M#0H@("`@("`@("`@("`@("`@("`@("1E>'1R82D[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@)&9A:6P@/2!F86QS93L-"B`@("`@("`@
M:68@*&ES<V5T*"1D97!;)VUI;B==*2D@>PT*("`@("`@("`@("`@:68@*'9E
M<G-I;VY?8V]M<&%R92@D=F5R<VEO;BP@)&1E<%LG;6EN)UTL("<\)RDI('L-
M"B`@("`@("`@("`@("`@("`D9F%I;"`]('1R=64[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!;)VUA>"==*2D@
M>PT*("`@("`@("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92@D=F5R<VEO;BP@
M)&1E<%LG;6%X)UTL("<^)RDI('L-"B`@("`@("`@("`@("`@("`D9F%I;"`]
M('1R=64[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@
M*"1F86EL("8F("%I<W-E="@D9&5P6R=C;VYF;&EC=',G72DI('L-"B`@("`@
M("`@("`@("1I;G-T86QL960@/2`D:6YS=&%L;&5D(#\@)VEN<W1A;&QE9"<@
M.B`G9&]W;FQO861E9"<[#0H@("`@("`@("`@("`D9&5P6R=P86-K86=E)UT@
M/2`D9&5P6R=N86UE)UT[#0H@("`@("`@("`@("`D9&5P(#T@)'1H:7,M/E]R
M96=I<W1R>2T^<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9R@D9&5P+"!T<G5E
M*3L-"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N
M;V1E<',G72D@)B8@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9F]R8V4G72DI
M('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M)R5S(')E<75I<F5S('!A8VMA9V4@(B<@+B`D9&5P;F%M92`N("<B)R`N#0H@
M("`@("`@("`@("`@("`@("`@("1E>'1R82`N("(L("1I;G-T86QL960@=F5R
M<VEO;B!I<R`B("X@)'9E<G-I;VXI.PT*("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G=A<FYI;F<H)W=A<FYI
M;F<Z("5S(')E<75I<F5S('!A8VMA9V4@(B<@+B`D9&5P;F%M92`N("<B)R`N
M#0H@("`@("`@("`@("`@("`@("`@("1E>'1R82`N("(L("1I;G-T86QL960@
M=F5R<VEO;B!I<R`B("X@)'9E<G-I;VXI.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!](&5L<V5I9B`H*&ES<V5T*"1D97!;)VUI;B==*2!\?"!I<W-E="@D
M9&5P6R=M87@G72DI("8F("$D9F%I;"`F)@T*("`@("`@("`@("`@("!I<W-E
M="@D9&5P6R=C;VYF;&EC=',G72D@)B8@(6ES<V5T*"1D97!;)V5X8VQU9&4G
M72DI('L-"B`@("`@("`@("`@("1I;G-T86QL960@/2`D:6YS=&%L;&5D(#\@
M)VEN<W1A;&QE9"<@.B`G9&]W;FQO861E9"<[#0H@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;F]D97!S)UTI("8F("%I<W-E="@D
M=&AI<RT^7V]P=&EO;G-;)V9O<F-E)UTI*2![#0H@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"<E<R!C;VYF;&EC=',@=VET:"!P
M86-K86=E("(G("X@)&1E<&YA;64@+B`G(B<@+B`D97AT<F$@+@T*("`@("`@
M("`@("`@("`@("`@("`B+"`D:6YS=&%L;&5D('9E<G-I;VX@:7,@(B`N("1V
M97)S:6]N*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YW87)N:6YG*"=W87)N:6YG.B`E<R!C;VYF;&EC
M=',@=VET:"!P86-K86=E("(G("X@)&1E<&YA;64@+B`G(B<@+@T*("`@("`@
M("`@("`@("`@("`@("`D97AT<F$@+B`B+"`D:6YS=&%L;&5D('9E<G-I;VX@
M:7,@(B`N("1V97)S:6]N*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H:7-S970H)&1E<%LG97AC;'5D92==*2D@>PT*("`@("`@
M("`@("`@)&EN<W1A;&QE9"`]("1I;G-T86QL960@/R`G:6YS=&%L;&5D)R`Z
M("=D;W=N;&]A9&5D)SL-"B`@("`@("`@("`@(&9O<F5A8V@@*"1D97!;)V5X
M8VQU9&4G72!A<R`D97AC;'5D92D@>PT*("`@("`@("`@("`@("`@(&EF("AV
M97)S:6]N7V-O;7!A<F4H)'9E<G-I;VXL("1E>&-L=61E+"`G/3TG*2`F)B`A
M:7-S970H)&1E<%LG8V]N9FQI8W1S)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N;V1E<',G72D@)B8-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@(6ES<V5T*"1T:&ES+3Y?;W!T
M:6]N<ULG9F]R8V4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G)7,@:7,@;F]T(&-O;7!A=&EB;&4@
M=VET:"`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:6YS=&%L
M;&5D("X@)R!P86-K86=E("(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D9&5P;F%M92`N("<B('9E<G-I;VX@)R`N#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&5X8VQU9&4I.PT*("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YW87)N:6YG*"=W87)N:6YG.B`E<R!I<R!N;W0@8V]M<&%T:6)L92!W
M:71H("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I;G-T86QL
M960@+B`G('!A8VMA9V4@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1D97!N86UE("X@)R(@=F5R<VEO;B`G("X-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D97AC;'5D92D[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H=F5R<VEO;E]C;VUP87)E
M*"1V97)S:6]N+"`D97AC;'5D92P@)R$])RD@)B8@:7-S970H)&1E<%LG8V]N
M9FQI8W1S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1I;G-T86QL960@
M/2`D:6YS=&%L;&5D(#\@)VEN<W1A;&QE9"<@.B`G9&]W;FQO861E9"<[#0H@
M("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS
M6R=N;V1E<',G72D@)B8@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9F]R8V4G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@G)7,@8V]N9FQI8W1S('=I=&@@<&%C:V%G92`B)R`N("1D
M97!N86UE("X@)R(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M97AT<F$@+B`B+"`D:6YS=&%L;&5D('9E<G-I;VX@:7,@(B`N("1V97)S:6]N
M*3L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^=V%R;FEN9R@G=V%R;FEN9SH@
M)7,@8V]N9FQI8W1S('=I=&@@<&%C:V%G92`B)R`N("1D97!N86UE("X@)R(G
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D97AT<F$@+B`B+"`D
M:6YS=&%L;&5D('9E<G-I;VX@:7,@(B`N("1V97)S:6]N*3L-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&1E<%LG<F5C;VUM
M96YD960G72DI('L-"B`@("`@("`@("`@("1I;G-T86QL960@/2`D:6YS=&%L
M;&5D(#\@)VEN<W1A;&QE9"<@.B`G9&]W;FQO861E9"<[#0H@("`@("`@("`@
M("!I9B`H=F5R<VEO;E]C;VUP87)E*"1V97)S:6]N+"`D9&5P6R=R96-O;6UE
M;F1E9"==+"`G/3TG*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E
M.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!I9B`H
M(21F;W5N9"`F)B`D:6YS=&%L;&5D*2![#0H@("`@("`@("`@("`@("`@("`@
M("1P87)A;2`]("1T:&ES+3Y?<F5G:7-T<GDM/F=E=%!A8VMA9V4H)&1E<%LG
M;F%M92==+"`D9&5P6R=C:&%N;F5L)UTI.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!I9B`H)'!A<F%M*2![#0H@("`@("`@("`@("`@
M("`@("`@("1F;W5N9"`](&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("!F
M;W)E86-H("@D<&%R86US(&%S("1P87)E;G0I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@D<&%R96YT+3YI<T5Q=6%L*"1T:&ES+3Y?8W5R<F5N
M=%!A8VMA9V4I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O
M=6YD(#T@=')U93L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H)&9O=6YD*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'!A<F%M+3YI<T-O;7!A=&EB
M;&4H)'!A<F5N="DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R
M971U<FX@=')U93L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L@+R\@=&AI<R!I<R!F;W(@=F%L:610
M86-K86=E*"D@8V%L;',-"B`@("`@("`@("`@("`@("`@("`@("`@("1P87)E
M;G0@/2`D=&AI<RT^7W)E9VES=')Y+3YG971086-K86=E*"1T:&ES+3Y?8W5R
M<F5N=%!A8VMA9V5;)W!A8VMA9V4G72P-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7V-U<G)E;G1086-K86=E6R=C:&%N;F5L)UTI.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1P87)E;G0@(3T](&YU;&PI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'!A<F%M+3YI
M<T-O;7!A=&EB;&4H)'!A<F5N="DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N;V1E<',G72D@
M)B8@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9F]R8V4G72D@)B8-"B`@("`@
M("`@("`@("`@("`@("`@("`A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=L;V]S
M92==*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H)R5S(&1E<&5N9&5N8WD@<&%C:V%G92`B)R`N("1D97!N86UE
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("<B("<@+B`D:6YS=&%L;&5D
M("X@)R!V97)S:6]N("<@+B`D=F5R<VEO;B`N(`T*("`@("`@("`@("`@("`@
M("`@("`@("`@)R!I<R!N;W0@=&AE(')E8V]M;65N9&5D('9E<G-I;VX@)R`N
M("1D97!;)W)E8V]M;65N9&5D)UT@+@T*("`@("`@("`@("`@("`@("`@("`@
M("`@)RP@8G5T(&UA>2!B92!C;VUP871I8FQE+"!U<V4@+2UF;W)C92!T;R!I
M;G-T86QL)RD[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YW87)N:6YG*"=W87)N:6YG.B`E
M<R!D97!E;F1E;F-Y('!A8VMA9V4@(B<@+B`D9&5P;F%M92`N#0H@("`@("`@
M("`@("`@("`@("`@("`@("`G(B`G("X@)&EN<W1A;&QE9"`N("<@=F5R<VEO
M;B`G("X@)'9E<G-I;VX@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)R!I
M<R!N;W0@=&AE(')E8V]M;65N9&5D('9E<G-I;VX@)R`N("1D97!;)W)E8V]M
M;65N9&5D)UTI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!?=F%L:61A=&5086-K86=E26YS=&%L;"@D9&5P+"`D<F5Q
M=6ER960L("1D97!V,2`](&9A;'-E*0T*("`@('L-"B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?=F%L:61A=&5086-K86=E1&]W;FQO860H)&1E<"P@)')E<75I
M<F5D+"!A<G)A>2@I+"`D9&5P=C$I.PT*("`@('T-"@T*("`@("\J*@T*("`@
M("`J(%9E<FEF>2!T:&%T('5N:6YS=&%L;&EN9R!P86-K86=E<R!P87-S960@
M:6X@=&\@8V]M;6%N9"!L:6YE(&ES($]++@T*("`@("`J#0H@("`@("H@0'!A
M<F%M(%!%05)?26YS=&%L;&5R("1D;`T*("`@("`J($!R971U<FX@4$5!4E]%
M<G)O<GQT<G5E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=F%L:61A=&5086-K
M86=E56YI;G-T86QL*"8D9&PI#0H@("`@>PT*("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D=&AI<RT^7V1E<&5N9&5N8WED8BDI('L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7V1E<&5N9&5N8WED8CL-"B`@("`@("`@?0T*("`@
M("`@("`D<&%R86US(#T@87)R87DH*3L-"B`@("`@("`@+R\@8V]N<W1R=6-T
M(&%N(&%R<F%Y(&]F(")D;W=N;&]A9&5D(B!P86-K86=E<R!T;R!F;V]L('1H
M92!P86-K86=E(&1E<&5N9&5N8WD@8VAE8VME<@T*("`@("`@("`O+R!I;G1O
M('5S:6YG('1H97-E('1O('9A;&ED871E('5N:6YS=&%L;',@;V8@8VER8W5L
M87(@9&5P96YD96YC:65S#0H@("`@("`@("1D;W=N;&]A9&5D(#T@)B1D;"T^
M9V5T56YI;G-T86QL4&%C:V%G97,H*3L-"B`@("`@("`@9F]R96%C:"`H)&1O
M=VYL;V%D960@87,@)&D@/3X@)'!F*2![#0H@("`@("`@("`@("!I9B`H(6-L
M87-S7V5X:7-T<R@G4$5!4E]$;W=N;&]A9&5R7U!A8VMA9V4G*2D@>PT*("`@
M("`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]$;W=N;&]A9&5R+U!A
M8VMA9V4N<&AP)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1D<"`]
M("9N97<@4$5!4E]$;W=N;&]A9&5R7U!A8VMA9V4H)&1L*3L-"B`@("`@("`@
M("`@("1D<"T^<V5T4&%C:V%G949I;&4H)&1O=VYL;V%D961;)&E=*3L-"B`@
M("`@("`@("`@("1P87)A;7-;)&E=(#T@)B1D<#L-"B`@("`@("`@?0T*("`@
M("`@("`D9&5P<R`]("1T:&ES+3Y?9&5P96YD96YC>61B+3YG971$97!E;F1E
M;G1086-K86=E1&5P96YD96YC:65S*"1T:&ES+3Y?8W5R<F5N=%!A8VMA9V4I
M.PT*("`@("`@("`D9F%I;"`](&9A;'-E.PT*("`@("`@("!I9B`H)&1E<',I
M('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1D97!S(&%S("1C:&%N;F5L(#T^
M("1I;F9O*2![#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&EN9F\@87,@
M)'!A8VMA9V4@/3X@)&1S*2![#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1D<R!A<R`D9"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&1;
M)V1E<"==6R=P86-K86=E)UT@/2`D9%LG9&5P)UU;)VYA;64G73L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1C:&5C:V5R(#T@)FYE=R!014%27T1E<&5N
M9&5N8WDR*"1T:&ES+3Y?8V]N9FEG+"`D=&AI<RT^7V]P=&EO;G,L#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V-H86YN96PG(#T^("1C
M:&%N;F5L+"`G<&%C:V%G92<@/3X@)'!A8VMA9V4I+"`D=&AI<RT^7W-T871E
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("1D97`@/2`D9%LG9&5P)UT[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D<F5Q=6ER960@/2`D9%LG='EP
M92==(#T]("=R97%U:7)E9"<[#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M<F5T(#T@)&-H96-K97(M/E]V86QI9&%T95!A8VMA9V55;FEN<W1A;&PH)&1E
M<"P@)')E<75I<F5D+"`D<&%R86US+"`D9&PI.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*&ES7V%R<F%Y*"1R970I*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&1L+3YL;V<H,"P@)')E=%LP72D[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!](&5L<V5I9B`H4$5!4CHZ:7-%<G)O<B@D<F5T
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D;"T^;&]G*#`L
M("1R970M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&9A:6P@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@D9F%I;"D@
M>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;F]D
M97!S)UTI('Q\(&ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9F]R8V4G72DI('L-
M"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G=A<FYI;F<H#0H@("`@
M("`@("`@("`@("`@("`@("=W87)N:6YG.B`E<R!S:&]U;&0@;F]T(&)E('5N
M:6YS=&%L;&5D+"!O=&AE<B!I;G-T86QL960@<&%C:V%G97,@9&5P96YD("<@
M+@T*("`@("`@("`@("`@("`@("`@("`G;VX@=&AI<R!P86-K86=E)RD[#0H@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@-"B`@("`@("`@("`@("`@("`@("`@)R5S(&-A
M;FYO="!B92!U;FEN<W1A;&QE9"P@;W1H97(@:6YS=&%L;&5D('!A8VMA9V5S
M(&1E<&5N9"!O;B!T:&ES('!A8VMA9V4G*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!?=F%L:61A=&5086-K86=E56YI;G-T86QL*"1D97`L("1R97%U
M:7)E9"P@)'!A<F%M<RP@)B1D;"D-"B`@("![#0H@("`@("`@("1D97!;)W!A
M8VMA9V4G72`]("1D97!;)VYA;64G73L-"B`@("`@("`@)&1E<&YA;64@/2`D
M=&AI<RT^7W)E9VES=')Y+3YP87)S961086-K86=E3F%M951O4W1R:6YG*"1D
M97`L('1R=64I.PT*("`@("`@("`D9F]U;F0@/2!F86QS93L-"B`@("`@("`@
M9F]R96%C:"`H)'!A<F%M<R!A<R`D<&%R86TI('L-"B`@("`@("`@("`@(&EF
M("@D<&%R86TM/FES17%U86PH)'1H:7,M/E]C=7)R96YT4&%C:V%G92DI('L-
M"B`@("`@("`@("`@("`@("`D9F]U;F0@/2!T<G5E.PT*("`@("`@("`@("`@
M("`@(&)R96%K.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M("1V97)S:6]N(#T@)'1H:7,M/E]R96=I<W1R>2T^<&%C:V%G96EN9F\H)&1E
M<%LG;F%M92==+"`G=F5R<VEO;B<L#0H@("`@("`@("`@("`D9&5P6R=C:&%N
M;F5L)UTI.PT*("`@("`@("!I9B`H(21V97)S:6]N*2![#0H@("`@("`@("`@
M("!R971U<FX@=')U93L-"B`@("`@("`@?0T*("`@("`@("`D97AT<F$@/2`D
M=&AI<RT^7V=E=$5X=')A4W1R:6YG*"1D97`I.PT*("`@("`@("!I9B`H:7-S
M970H)&1E<%LG97AC;'5D92==*2D@>PT*("`@("`@("`@("`@:68@*"%I<U]A
M<G)A>2@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("`@("`@)&1E
M<%LG97AC;'5D92==(#T@87)R87DH)&1E<%LG97AC;'5D92==*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&1E<%LG
M8V]N9FQI8W1S)UTI*2![#0H@("`@("`@("`@("!R971U<FX@=')U93L@+R\@
M=6YI;G-T86QL($]+("T@=&AE<V4@<&%C:V%G97,@8V]N9FQI8W0@*'!R;V)A
M8FQY(&EN<W1A;&QE9"!W:71H("TM9F]R8V4I#0H@("`@("`@('T-"B`@("`@
M("`@:68@*"%I<W-E="@D9&5P6R=M:6XG72D@)B8@(6ES<V5T*"1D97!;)VUA
M>"==*2D@>PT*("`@("`@("`@("`@:68@*"1R97%U:7)E9"D@>PT*("`@("`@
M("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N;V1E<',G
M72D@)B8@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9F]R8V4G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"<E
M<R<@+B`D97AT<F$@+B`G(&ES(')E<75I<F5D(&)Y(&EN<W1A;&QE9"!P86-K
M86=E("(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("1D97!N86UE("X@
M)R(G*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G=A<FYI;F<H)W=A<FYI;F<Z("5S)R`N
M("1E>'1R82`N#0H@("`@("`@("`@("`@("`@("`@("`@("`G(&ES(')E<75I
M<F5D(&)Y(&EN<W1A;&QE9"!P86-K86=E("(G("X@)&1E<&YA;64@+B`G(B<I
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YW87)N:6YG*"<E<R<@+B`D
M97AT<F$@+@T*("`@("`@("`@("`@("`@("`@("`G(&-A;B!B92!O<'1I;VYA
M;&QY('5S960@8GD@:6YS=&%L;&5D('!A8VMA9V4@(B<@+B`D9&5P;F%M92`N
M("<B)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)&9A
M:6P@/2!F86QS93L-"B`@("`@("`@:68@*&ES<V5T*"1D97!;)VUI;B==*2D@
M>PT*("`@("`@("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92@D=F5R<VEO;BP@
M)&1E<%LG;6EN)UTL("<^/2<I*2![#0H@("`@("`@("`@("`@("`@)&9A:6P@
M/2!T<G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF
M("AI<W-E="@D9&5P6R=M87@G72DI('L-"B`@("`@("`@("`@(&EF("AV97)S
M:6]N7V-O;7!A<F4H)'9E<G-I;VXL("1D97!;)VUA>"==+"`G/#TG*2D@>PT*
M("`@("`@("`@("`@("`@("1F86EL(#T@=')U93L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H)&9A:6PI('L-"B`@("`@("`@("`@
M(&EF("@D9F]U;F0I('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1D
M;"T^7U]?8VAE8VME9%LD=&AI<RT^7V-U<G)E;G1086-K86=E6R=C:&%N;F5L
M)UU=#0H@("`@("`@("`@("`@("`@("`@("`@6R1T:&ES+3Y?8W5R<F5N=%!A
M8VMA9V5;)W!A8VMA9V4G75TI*2![#0H@("`@("`@("`@("`@("`@("`@("1D
M;"T^7U]?8VAE8VME9%LD=&AI<RT^7V-U<G)E;G1086-K86=E6R=C:&%N;F5L
M)UU=#0H@("`@("`@("`@("`@("`@("`@("`@6R1T:&ES+3Y?8W5R<F5N=%!A
M8VMA9V5;)W!A8VMA9V4G75T@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@
M("`D9&5P<R`]("1T:&ES+3Y?9&5P96YD96YC>61B+3YG971$97!E;F1E;G10
M86-K86=E1&5P96YD96YC:65S*`T*("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]C=7)R96YT4&%C:V%G92D[#0H@("`@("`@("`@("`@("`@("`@
M(&EF("@D9&5P<RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)&1E<',@87,@)&-H86YN96P@/3X@)&EN9F\I('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!F;W)E86-H("@D:6YF;R!A<R`D<&%C:V%G92`]
M/B`D9',I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R
M96%C:"`H)&1S(&%S("1D*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D9%LG9&5P)UU;)W!A8VMA9V4G72`]("1D6R=D97`G75LG
M;F%M92==.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&-H96-K97(@/2`F;F5W(%!%05)?1&5P96YD96YC>3(H)'1H:7,M/E]C;VYF
M:6<L("1T:&ES+3Y?;W!T:6]N<RP-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@G8VAA;FYE;"<@/3X@)&-H86YN96PL
M("=P86-K86=E)R`]/B`D<&%C:V%G92DL#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S=&%T92D[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P(#T@)&1;)V1E<"==
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E<75I
M<F5D(#T@)&1;)W1Y<&4G72`]/2`G<F5Q=6ER960G.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)')E="`]("1C:&5C:V5R+3Y?=F%L
M:61A=&5086-K86=E56YI;G-T86QL*"1D97`L("1R97%U:7)E9"P@)'!A<F%M
M<RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M9&PI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)')E="DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9F%I;"`]('1R=64[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L@,SL-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9F%I;"`]
M(&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"$D9F%I;"D@>PT*
M("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@:68@*"1R97%U:7)E9"D@>PT*("`@("`@("`@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N;V1E<',G72D@)B8@(6ES
M<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9F]R8V4G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1D97!N86UE("X@
M)&5X=')A("X@)R!I<R!R97%U:7)E9"!B>2!I;G-T86QL960@<&%C:V%G92<@
M+@T*("`@("`@("`@("`@("`@("`@("`@("`@)R`B)7,B)RD[#0H@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YW87)N:6YG*"=W87)N:6YG.B`G("X@)&1E<&YA;64@+B`D97AT
M<F$@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)R!I<R!R97%U:7)E9"!B
M>2!I;G-T86QL960@<&%C:V%G92`B)7,B)RD[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G=A<FYI;F<H)&1E<&YA;64@+B`D97AT<F$@+B`G(&-A;B!B
M92!O<'1I;VYA;&QY('5S960@8GD@:6YS=&%L;&5D('!A8VMA9V4G("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("<@(B5S(B<I.PT*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*
M("`@("\J*@T*("`@("`J('9A;&ED871E(&$@9&]W;FQO861E9"!P86-K86=E
M(&%G86EN<W0@:6YS=&%L;&5D('!A8VMA9V5S#0H@("`@("H@#0H@("`@("H@
M07,@;V8@4$5!4B`Q+C0N,RP@=&AI<R!W:6QL(&]N;'D@=F%L:61A=&4-"B`@
M("`@*@T*("`@("`J($!P87)A;2!A<G)A>7Q014%27T1O=VYL;V%D97)?4&%C
M:V%G97Q014%27U!A8VMA9V5&:6QE7W8Q?%!%05)?4&%C:V%G949I;&5?=C(-
M"B`@("`@*B`@("`@("`@("`@("`@)'!K9R!P86-K86=E(&ED96YT:69I97(@
M*&5I=&AE<@T*("`@("`J("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=P86-K
M86=E)R`]/B!B;&%H+"`G8VAA;FYE;"<@/3X@8FQA:"D@;W(@86X@87)R87D@
M=VET:`T*("`@("`J("`@("`@("`@("`@("`@("`@(&EN9&5X("=I;F9O)R!R
M969E<F5N8VEN9R!A;B!O8FIE8W0I#0H@("`@("H@0'!A<F%M(%!%05)?1&]W
M;FQO861E<B`D9&P-"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R!F=6QL
M(&QI<W0@;V8@<&%C:V%G97,@=&\@:6YS=&%L;`T*("`@("`J($!R971U<FX@
M=')U97Q014%27T5R<F]R#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=F%L:61A
M=&5086-K86=E*"1P:V<L("8D9&PL("1P87)A;7,@/2!A<G)A>2@I*0T*("`@
M('L-"B`@("`@("`@:68@*&ES7V%R<F%Y*"1P:V<I("8F(&ES<V5T*"1P:V=;
M)VEN9F\G72DI('L-"B`@("`@("`@("`@("1D97!S(#T@)'1H:7,M/E]D97!E
M;F1E;F-Y9&(M/F=E=$1E<&5N9&5N=%!A8VMA9V5$97!E;F1E;F-I97,H)'!K
M9ULG:6YF;R==*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1D
M97!S(#T@)'1H:7,M/E]D97!E;F1E;F-Y9&(M/F=E=$1E<&5N9&5N=%!A8VMA
M9V5$97!E;F1E;F-I97,H)'!K9RD[#0H@("`@("`@('T-"B`@("`@("`@)&9A
M:6P@/2!F86QS93L-"B`@("`@("`@:68@*"1D97!S*2![#0H@("`@("`@("`@
M("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]$;W=N;&]A9&5R7U!A8VMA9V4G
M*2D@>PT*("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]$;W=N
M;&]A9&5R+U!A8VMA9V4N<&AP)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("1D<"`]("9N97<@4$5!4E]$;W=N;&]A9&5R7U!A8VMA9V4H)&1L*3L-
M"B`@("`@("`@("`@(&EF("AI<U]O8FIE8W0H)'!K9RDI('L-"B`@("`@("`@
M("`@("`@("`D9'`M/G-E=%!A8VMA9V5&:6QE*"1P:V<I.PT*("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D9'`M/G-E=$1O=VYL;V%D
M55),*"1P:V<I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@4$5!4CHZ
M<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@
M("`@("`@9F]R96%C:"`H)&1E<',@87,@)&-H86YN96P@/3X@)&EN9F\I('L-
M"B`@("`@("`@("`@("`@("!F;W)E86-H("@D:6YF;R!A<R`D<&%C:V%G92`]
M/B`D9',I('L-"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!A<F%M
M<R!A<R`D<&%C:V0I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AS
M=')T;VQO=V5R*"1P86-K9"T^9V5T4&%C:V%G92@I*2`]/2!S=')T;VQO=V5R
M*"1P86-K86=E*2`F)@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!A8VMD+3YG971#:&%N;F5L*"D@/3T@)&-H86YN96PI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9&PM/FQO9R@S+"`G<VMI<'!I;F<@:6YS
M=&%L;&5D('!A8VMA9V4@8VAE8VL@;V8@(B<@+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5G:7-T<GDM/G!A
M<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=C:&%N;F5L)R`]/B`D
M8VAA;FYE;"P@)W!A8VMA9V4G(#T^("1P86-K86=E*2P-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=')U92D@+@T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<B+"!V97)S
M:6]N("(G("X@)'!A8VMD+3YG971697)S:6]N*"D@+B`G(B!W:6QL(&)E("<@
M+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D
M;W=N;&]A9&5D(&%N9"!I;G-T86QL960G*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!C;VYT:6YU92`R.R`O+R!J=6UP('1O(&YE>'0@<&%C:V%G
M90T*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1D<R!A<R`D
M9"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&-H96-K97(@/2`F;F5W
M(%!%05)?1&5P96YD96YC>3(H)'1H:7,M/E]C;VYF:6<L("1T:&ES+3Y?;W!T
M:6]N<RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G8VAA
M;FYE;"<@/3X@)&-H86YN96PL("=P86-K86=E)R`]/B`D<&%C:V%G92DL("1T
M:&ES+3Y?<W1A=&4I.PT*("`@("`@("`@("`@("`@("`@("`@("`@)&1E<"`]
M("1D6R=D97`G73L-"B`@("`@("`@("`@("`@("`@("`@("`@("1R97%U:7)E
M9"`]("1D6R=T>7!E)UT@/3T@)W)E<75I<F5D)SL-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1R970@/2`D8VAE8VME<BT^7W9A;&ED871E4&%C:V%G941O
M=VYL;V%D*"1D97`L("1R97%U:7)E9"P@87)R87DH)B1D<"DI.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1R970I*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&1L+3YL;V<H,"P@)')E=%LP72D[
M#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H4$5!4CHZ:7-%
M<G)O<B@D<F5T*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D
M;"T^;&]G*#`L("1R970M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&9A:6P@/2!T<G5E.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@4$5!4CHZ<&]P
M17)R;W)(86YD;&EN9R@I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D9F%I
M;"D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*`T*
M("`@("`@("`@("`@("`@("<E<R!C86YN;W0@8F4@:6YS=&%L;&5D+"!C;VYF
M;&EC=',@=VET:"!I;G-T86QL960@<&%C:V%G97,G*3L-"B`@("`@("`@?0T*
M("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!V86QI9&%T92!A('!A8VMA9V4N>&UL(#$N,"!D97!E;F1E;F-Y#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@=F%L:61A=&5$97!E;F1E;F-Y,2@D9&5P+"`D
M<&%R86US(#T@87)R87DH*2D-"B`@("![#0H@("`@("`@(&EF("@A:7-S970H
M)&1E<%LG;W!T:6]N86PG72DI('L-"B`@("`@("`@("`@("1D97!;)V]P=&EO
M;F%L)UT@/2`G;F\G.PT*("`@("`@("!]#0H@("`@("`@(&QI<W0H)&YE=V1E
M<"P@)'1Y<&4I(#T@)'1H:7,M/FYO<FUA;&EZ941E<"@D9&5P*3L-"B`@("`@
M("`@:68@*"$D;F5W9&5P*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H(DEN=F%L:60@1&5P96YD96YC>2(I.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("AM971H;V1?97AI<W1S*"1T:&ES+"`B=F%L:61A=&5[
M)'1Y<&5]1&5P96YD96YC>2(I*2![#0H@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/GLB=F%L:61A=&5[)'1Y<&5]1&5P96YD96YC>2)]*"1N97=D97`L("1D
M97!;)V]P=&EO;F%L)UT@/3T@)VYO)RP-"B`@("`@("`@("`@("`@("`D<&%R
M86US+"!T<G5E*3L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@
M("`J($-O;G9E<G0@82`Q+C`@9&5P(&EN=&\@82`R+C`@9&5P#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@;F]R;6%L:7IE1&5P*"1D97`I#0H@("`@>PT*("`@
M("`@("`D='EP97,@/2!A<G)A>2@-"B`@("`@("`@("`@("=P:V<G(#T^("=0
M86-K86=E)RP-"B`@("`@("`@("`@("=E>'0G(#T^("=%>'1E;G-I;VXG+`T*
M("`@("`@("`@("`@)V]S)R`]/B`G3W,G+`T*("`@("`@("`@("`@)W!H<"<@
M/3X@)U!H<"<-"B`@("`@("`@*3L-"B`@("`@("`@:68@*&ES<V5T*"1T>7!E
M<ULD9&5P6R=T>7!E)UU=*2D@>PT*("`@("`@("`@("`@)'1Y<&4@/2`D='EP
M97-;)&1E<%LG='EP92==73L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@(')E='5R;B!A<G)A>2AF86QS92P@9F%L<V4I.PT*("`@("`@("!]#0H@
M("`@("`@("1N97=D97`@/2!A<G)A>2@I.PT*("`@("`@("!S=VET8V@@*"1T
M>7!E*2![#0H@("`@("`@("`@("!C87-E("=086-K86=E)R`Z#0H@("`@("`@
M("`@("`@("`@)&YE=V1E<%LG8VAA;FYE;"==(#T@)W!E87(N<&AP+FYE="<[
M#0H@("`@("`@("`@("!C87-E("=%>'1E;G-I;VXG(#H-"B`@("`@("`@("`@
M(&-A<V4@)T]S)R`Z#0H@("`@("`@("`@("`@("`@)&YE=V1E<%LG;F%M92==
M(#T@)&1E<%LG;F%M92==.PT*("`@("`@("`@("`@8G)E86L[#0H@("`@("`@
M('T-"B`@("`@("`@)&1E<%LG<F5L)UT@/2!014%27T1E<&5N9&5N8WDR.CIS
M:6=N3W!E<F%T;W(H)&1E<%LG<F5L)UTI.PT*("`@("`@("!S=VET8V@@*"1D
M97!;)W)E;"==*2![#0H@("`@("`@("`@("!C87-E("=H87,G(#H-"B`@("`@
M("`@("`@("`@("!R971U<FX@87)R87DH)&YE=V1E<"P@)'1Y<&4I.PT*("`@
M("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=N;W0G(#H-"B`@
M("`@("`@("`@("`@("`D;F5W9&5P6R=C;VYF;&EC=',G72`]('1R=64[#0H@
M("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)SX])R`Z#0H@
M("`@("`@("`@("!C87-E("<^)R`Z#0H@("`@("`@("`@("`@("`@)&YE=V1E
M<%LG;6EN)UT@/2`D9&5P6R=V97)S:6]N)UT[#0H@("`@("`@("`@("`@("`@
M:68@*"1D97!;)W)E;"==(#T]("<^)RD@>PT*("`@("`@("`@("`@("`@("`@
M("`D;F5W9&5P6R=E>&-L=61E)UT@/2`D9&5P6R=V97)S:6]N)UT[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@
M("!C87-E("<\/2<@.@T*("`@("`@("`@("`@8V%S92`G/"<@.@T*("`@("`@
M("`@("`@("`@("1N97=D97!;)VUA>"==(#T@)&1E<%LG=F5R<VEO;B==.PT*
M("`@("`@("`@("`@("`@(&EF("@D9&5P6R=R96PG72`]/2`G/"<I('L-"B`@
M("`@("`@("`@("`@("`@("`@)&YE=V1E<%LG97AC;'5D92==(#T@)&1E<%LG
M=F5R<VEO;B==.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@8V%S92`G;F4G(#H-"B`@("`@("`@("`@(&-A
M<V4@)R$])R`Z#0H@("`@("`@("`@("`@("`@)&YE=V1E<%LG;6EN)UT@/2`G
M,"<[#0H@("`@("`@("`@("`@("`@)&YE=V1E<%LG;6%X)UT@/2`G,3`P,#`P
M)SL-"B`@("`@("`@("`@("`@("`D;F5W9&5P6R=E>&-L=61E)UT@/2`D9&5P
M6R=V97)S:6]N)UT[#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@
M(&-A<V4@)ST])R`Z#0H@("`@("`@("`@("`@("`@)&YE=V1E<%LG;6EN)UT@
M/2`D9&5P6R=V97)S:6]N)UT[#0H@("`@("`@("`@("`@("`@)&YE=V1E<%LG
M;6%X)UT@/2`D9&5P6R=V97)S:6]N)UT[#0H@("`@("`@("`@("!B<F5A:SL-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H)'1Y<&4@/3T@)U!H<"<I('L-"B`@
M("`@("`@("`@(&EF("@A:7-S970H)&YE=V1E<%LG;6EN)UTI*2![#0H@("`@
M("`@("`@("`@("`@)&YE=V1E<%LG;6EN)UT@/2`G-"XR+C`G.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@:68@*"%I<W-E="@D;F5W9&5P6R=M87@G
M72DI('L-"B`@("`@("`@("`@("`@("`D;F5W9&5P6R=M87@G72`]("<V+C`N
M,"<[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N
M(&%R<F%Y*"1N97=D97`L("1T>7!E*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!#;VYV97)T<R!T97AT(&-O;7!A<FEN9R!O<&5R871O<G,@=&\@=&AE
M;2!S:6=N(&5Q=6EV86QE;G1S#0H@("`@("H-"B`@("`@*B!%>&%M<&QE.B`G
M9V4G('1O("<^/2<-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@
M("`@("H@0'!A<F%M("!S=')I;F<@3W!E<F%T;W(-"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R!3:6=N(&5Q=6EV86QE;G0-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!S:6=N3W!E<F%T;W(H)&]P97)A=&]R*0T*("`@('L-"B`@("`@("`@<W=I
M=&-H*"1O<&5R871O<BD@>PT*("`@("`@("`@("`@8V%S92`G;'0G.B!R971U
M<FX@)SPG.PT*("`@("`@("`@("`@8V%S92`G;&4G.B!R971U<FX@)SP])SL-
M"B`@("`@("`@("`@(&-A<V4@)V=T)SH@<F5T=7)N("<^)SL-"B`@("`@("`@
M("`@(&-A<V4@)V=E)SH@<F5T=7)N("<^/2<[#0H@("`@("`@("`@("!C87-E
M("=E<2<Z(')E='5R;B`G/3TG.PT*("`@("`@("`@("`@8V%S92`G;F4G.B!R
M971U<FX@)R$])SL-"B`@("`@("`@("`@(&1E9F%U;'0Z#0H@("`@("`@("`@
M("`@("`@<F5T=7)N("1O<&5R871O<CL-"B`@("`@("`@?0T*("`@('T-"@T*
M("`@(&9U;F-T:6]N(')A:7-E17)R;W(H)&US9RD-"B`@("![#0H@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^7V]P=&EO;G-;)VEG;F]R92UE<G)O<G,G72DI
M('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^=V%R;FEN9R@D;7-G*3L-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS
M<')I;G1F*"1M<V<L("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA9V5.
M86UE5&]3=')I;F<H#0H@("`@("`@("`@("`D=&AI<RT^7V-U<G)E;G1086-K
M86=E+"!T<G5E*2DI.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('=A<FYI;F<H
M)&US9RD-"B`@("![#0H@("`@("`@(')E='5R;B!A<G)A>2AS<')I;G1F*"1M
M<V<L("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I
M;F<H#0H@("`@("`@("`@("`D=&AI<RT^7V-U<G)E;G1086-K86=E+"!T<G5E
M*2DI.PT*("`@('T-"GT-"C\^````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O3U,`````````````````````````````````````
M```````````````````````````````````````````````````````P,#`W
M-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<S,B`P
M,38W,C<`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]/4R]'=65S<RYP:'``
M````````````````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#(U
M-S4W(#$P-3$U-#,S-S,R(#`R,#8R-0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`T*+RHJ#0H@*B!4:&4@3U-?1W5E
M<W,@8VQA<W,-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J
M($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S
M:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA
M8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I
M;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@
M4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U
M9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E
M0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L
M>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!0
M14%2#0H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^
M#0H@*B!`875T:&]R("`@("!'<F5G;W)Y($)E879E<B`\8V5L;&]G0'!H<"YN
M970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`T*
M("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)
M9#H@1W5E<W,N<&AP+'8@,2XR,"`R,#`U+S$P+S(V(#$Y.C,S.C`S(&-E;&QO
M9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P
M86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I
M;F-E(%!%05(@,"XQ#0H@*B\-"@T*+R\@>WM[('5N86UE(&5X86UP;&5S#0H-
M"B\O('!H<%]U;F%M92@I('=I=&AO=70@87)G<R!R971U<FYS('1H92!S86UE
M(&%S("=U;F%M92`M82<L(&]R(&$@4$A0+6-U<W1O;0T*+R\@<W1R:6YG(&9O
M<B!7:6YD;W=S+@T*+R\@4$A0('9E<G-I;VYS('!R:6]R('1O(#0N,R!R971U
M<FX@=&AE('5N86UE(&]F('1H92!H;W-T('=H97)E(%!(4"!W87,@8G5I;'0L
M#0HO+R!A<R!O9B`T+C,@:70@<F5T=7)N<R!T:&4@=6YA;64@;V8@=&AE(&AO
M<W0@<G5N;FEN9R!T:&4@4$A0(&-O9&4N#0HO+PT*+R\@4$,@4F5D2&%T($QI
M;G5X(#<N,3H-"B\O($QI;G5X(&AO<W0N97AA;7!L92YC;VT@,BXT+C(M,B`C
M,2!3=6X@07!R(#@@,C`Z-#$Z,S`@1414(#(P,#$@:38X-B!U;FMN;W=N#0HO
M+PT*+R\@4$,@1&5B:6%N(%!O=&%T;SH-"B\O($QI;G5X(&AO<W0@,BXT+C$W
M(",R(%--4"!4=64@1F5B(#$R(#$U.C$P.C`T($-%5"`R,#`R(&DV.#8@=6YK
M;F]W;@T*+R\-"B\O(%!#($9R965"4T0@,RXS.@T*+R\@1G)E94)31"!H;W-T
M+F5X86UP;&4N8V]M(#,N,RU35$%"3$4@1G)E94)31"`S+C,M4U1!0DQ%(",P
M.B!-;VX@1F5B(#(Q(#`P.C0R.C,Q($-%5"`R,#`P("`@("!R;V]T0&5X86UP
M;&4N8V]M.B]U<W(O<W)C+W-Y<R]C;VUP:6QE+T-/3D9)1R`@:3,X-@T*+R\-
M"B\O(%!#($9R965"4T0@-"XS.@T*+R\@1G)E94)31"!H;W-T+F5X86UP;&4N
M8V]M(#0N,RU214Q%05-%($9R965"4T0@-"XS+5)%3$5!4T4@(S$Z($UO;B!*
M=6X@,C4@,3$Z,3DZ-#,@1414(#(P,#$@("`@(')O;W1`97AA;7!L92YC;VTZ
M+W5S<B]S<F,O<WES+V-O;7!I;&4O0T].1DE'("!I,S@V#0HO+PT*+R\@4$,@
M1G)E94)31"`T+C4Z#0HO+R!&<F5E0E-$(&AO<W0N97AA;7!L92YC;VT@-"XU
M+5-404),12!&<F5E0E-$(#0N-2U35$%"3$4@(S`Z(%=E9"!&96(@(#8@,C,Z
M-3DZ,C,@0T54(#(P,#(@("`@(')O;W1`97AA;7!L92YC;VTZ+W5S<B]S<F,O
M<WES+V-O;7!I;&4O0T].1DE'("!I,S@V#0HO+PT*+R\@4$,@1G)E94)31"`T
M+C4@=R]U;F%M92!F<F]M($=.52!S:&5L;'5T:6QS.@T*+R\@1G)E94)31"!H
M;W-T+F5X86UP;&4N8V]M(#0N-2U35$%"3$4@1G)E94)31"`T+C4M4U1!0DQ%
M(",P.B!7960@1F5B("!I,S@V('5N:VYO=VX-"B\O#0HO+R!(4"`Y,#`P+S<Q
M,B!(4"U56"`Q,#H-"B\O($A0+558(&EQ($(N,3`N,3`@02`Y,#`P+S<Q,B`R
M,#`X-#(Y,3$S('1W;RUU<V5R(&QI8V5N<V4-"B\O#0HO+R!(4"`Y,#`P+S<Q
M,B!(4"U56"`Q,"!W+W5N86UE(&9R;VT@1TY5('-H96QL=71I;',Z#0HO+R!(
M4"U56"!H;W-T($(N,3`N,3`@02`Y,#`P+S<Q,B!U;FMN;W=N#0HO+PT*+R\@
M24)-(%)3-C`P,"\U-3`@04E8(#0N,SH-"B\O($%)6"!H;W-T(#,@-"`P,#`P
M,#,U,S%#,#`-"B\O#0HO+R!!25@@-"XS('<O=6YA;64@9G)O;2!'3E4@<VAE
M;&QU=&EL<SH-"B\O($%)6"!H;W-T(#,@-"`P,#`P,#,U,S%#,#`@=6YK;F]W
M;@T*+R\-"B\O(%-'22!/;GEX($E225@@-BXU('<O=6YA;64@9G)O;2!'3E4@
M<VAE;&QU=&EL<SH-"B\O($E225@V-"!H;W-T(#8N-2`P,3`Y,3@R,"!)4#$Y
M(&UI<',-"B\O#0HO+R!31TD@3VYY>"!)4DE8(#8N-3H-"B\O($E225@V-"!H
M;W-T(#8N-2`P,3`Y,3@R,"!)4#$Y#0HO+PT*+R\@4W!A<F-3=&%T:6]N(#(P
M(%-O;&%R:7,@."!W+W5N86UE(&9R;VT@1TY5('-H96QL=71I;',Z#0HO+R!3
M=6Y/4R!H;W-T+F5X86UP;&4N8V]M(#4N."!'96YE<FEC7S$P.#4R."TQ,B!S
M=6XT;2!S<&%R8PT*+R\-"B\O(%-P87)C4W1A=&EO;B`R,"!3;VQA<FES(#@Z
M#0HO+R!3=6Y/4R!H;W-T+F5X86UP;&4N8V]M(#4N."!'96YE<FEC7S$P.#4R
M."TQ,B!S=6XT;2!S<&%R8R!354Y7+%-005)#<W1A=&EO;BTR,`T*+R\-"B\O
M($UA8R!/4R!8("A$87)W:6XI#0HO+R!$87)W:6X@:&]M92UE9&5N+FQO8V%L
M(#<N-2XP($1A<G=I;B!+97)N96P@5F5R<VEO;B`W+C4N,#H@5&AU($%U9R`@
M-2`Q.3HR-CHQ-B!01%0@,C`P-#L@<F]O=#IX;G4O>&YU+34Q-RXW+C(Q+F]B
M:GXS+U)%3$5!4T5?4%!#("!0;W=E<B!-86-I;G1O<V@-"B\O#0HO+R!-86,@
M3U,@6"!E87)L>2!V97)S:6]N<PT*+R\@#0H-"B\O('U]?0T*#0HO*B!43T1/
M.@T*("H@+2!D969I;F4@96YD:6%N;F5S<RP@=&\@86QL;W<@;6%T8VA3:6=N
M871U<F4H(F)I9V5N9"(I(&5T8RX-"B`J+PT*#0HO*BH-"B`J(%)E=')I979E
M<R!I;F9O<FUA=&EO;B!A8F]U="!T:&4@8W5R<F5N="!O<&5R871I;F<@<WES
M=&5M#0H@*@T*("H@5&AI<R!C;&%S<R!U<V5S('!H<%]U;F%M92@I('1O(&=R
M;VL@:6YF;W)M871I;VX@86)O=70@=&AE(&-U<G)E;G0@3U,-"B`J#0H@*B!`
M8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T
M:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R
M("`@("!'<F5G;W)Y($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P
M>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@
M("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI
M8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@
M0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-
M"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E
M(#`N,0T*("HO#0IC;&%S<R!/4U]'=65S<PT*>PT*("`@('9A<B`D<WES;F%M
M93L-"B`@("!V87(@)&YO9&5N86UE.PT*("`@('9A<B`D8W!U.PT*("`@('9A
M<B`D<F5L96%S93L-"B`@("!V87(@)&5X=')A.PT*#0H@("`@9G5N8W1I;VX@
M3U-?1W5E<W,H)'5N86UE(#T@;G5L;"D-"B`@("![#0H@("`@("`@(&QI<W0H
M)'1H:7,M/G-Y<VYA;64L#0H@("`@("`@("`@("`@)'1H:7,M/G)E;&5A<V4L
M#0H@("`@("`@("`@("`@)'1H:7,M/F-P=2P-"B`@("`@("`@("`@("`D=&AI
M<RT^97AT<F$L#0H@("`@("`@("`@("`@)'1H:7,M/FYO9&5N86UE*2`]("1T
M:&ES+3YP87)S95-I9VYA='5R92@D=6YA;64I.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N('!A<G-E4VEG;F%T=7)E*"1U;F%M92`](&YU;&PI#0H@("`@>PT*
M("`@("`@("!S=&%T:6,@)'-Y<VUA<"`](&%R<F%Y*`T*("`@("`@("`@("`@
M)TA0+558)R`]/B`G:'!U>"<L#0H@("`@("`@("`@("`G25))6#8T)R`]/B`G
M:7)I>"<L#0H@("`@("`@("D[#0H@("`@("`@('-T871I8R`D8W!U;6%P(#T@
M87)R87DH#0H@("`@("`@("`@("`G:34X-B<@/3X@)VDS.#8G+`T*("`@("`@
M("`@("`@)VDV.#8G(#T^("=I,S@V)RP-"B`@("`@("`@("`@("=P<&,G(#T^
M("=P;W=E<G!C)RP-"B`@("`@("`@*3L-"B`@("`@("`@:68@*"1U;F%M92`]
M/3T@;G5L;"D@>PT*("`@("`@("`@("`@)'5N86UE(#T@<&AP7W5N86UE*"D[
M#0H@("`@("`@('T-"B`@("`@("`@)'!A<G1S(#T@<W!L:70H)UM;.G-P86-E
M.EU=*R<L('1R:6TH)'5N86UE*2D[#0H@("`@("`@("1N(#T@8V]U;G0H)'!A
M<G1S*3L-"@T*("`@("`@("`D<F5L96%S92`]("1M86-H:6YE(#T@)&-P=2`]
M("<G.PT*("`@("`@("`D<WES;F%M92`]("1P87)T<ULP73L-"B`@("`@("`@
M)&YO9&5N86UE(#T@)'!A<G1S6S%=.PT*("`@("`@("`D8W!U(#T@)'!A<G1S
M6R1N+3%=.PT*("`@("`@("`D97AT<F$@/2`G)SL-"B`@("`@("`@:68@*"1C
M<'4@/3T@)W5N:VYO=VXG*2![#0H@("`@("`@("`@("`D8W!U(#T@)'!A<G1S
M6R1N+3)=.PT*("`@("`@("!]#0H-"B`@("`@("`@<W=I=&-H("@D<WES;F%M
M92D@>PT*("`@("`@("`@("`@8V%S92`G04E8)R`Z#0H@("`@("`@("`@("`@
M("`@)')E;&5A<V4@/2`B)'!A<G1S6S-=+B1P87)T<ULR72([#0H@("`@("`@
M("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=7:6YD;W=S)R`Z
M#0H@("`@("`@("`@("`@("`@<W=I=&-H("@D<&%R='-;,5TI('L-"B`@("`@
M("`@("`@("`@("`@("`@8V%S92`G.34O.3@G.@T*("`@("`@("`@("`@("`@
M("`@("`@("`@)')E;&5A<V4@/2`G.7@G.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@(&1E9F%U;'0Z#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D<F5L96%S92`]("1P87)T<ULQ73L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`D8W!U(#T@)VDS.#8G.PT*("`@("`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G3&EN=7@G(#H-
M"B`@("`@("`@("`@("`@("`D97AT<F$@/2`D=&AI<RT^7V1E=&5C=$=L:6)C
M5F5R<VEO;B@I.PT*("`@("`@("`@("`@("`@("\O('5S92!O;FQY('1H92!F
M:7)S="!T=V\@9&EG:71S(&9R;VT@=&AE(&ME<FYE;"!V97)S:6]N#0H@("`@
M("`@("`@("`@("`@)')E;&5A<V4@/2!E<F5G7W)E<&QA8V4H)UXH6ULZ9&EG
M:70Z75TK7"Y;6SID:6=I=#I=72LI+BHG+"`G7#$G+"`D<&%R='-;,ETI.PT*
M("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G36%C
M)R`Z#0H@("`@("`@("`@("`@("`@)'-Y<VYA;64@/2`G9&%R=VEN)SL-"B`@
M("`@("`@("`@("`@("`D;F]D96YA;64@/2`D<&%R='-;,ET[#0H@("`@("`@
M("`@("`@("`@)')E;&5A<V4@/2`D<&%R='-;,UT[#0H@("`@("`@("`@("`@
M("`@:68@*"1C<'4@/3T@)TUA8VEN=&]S:"<I('L-"B`@("`@("`@("`@("`@
M("`@("`@:68@*"1P87)T<ULD;B`M(#)=(#T]("=0;W=E<B<I('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1C<'4@/2`G<&]W97)P8R<[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=$87)W:6XG(#H-"B`@
M("`@("`@("`@("`@("!I9B`H)&-P=2`]/2`G36%C:6YT;W-H)RD@>PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H)'!A<G1S6R1N("T@,ET@/3T@)U!O=V5R
M)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&-P=2`]("=P;W=E<G!C
M)SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`D<F5L96%S92`](&5R96=?<F5P;&%C92@G7BA;
M6SID:6=I=#I=72M<+EM;.F1I9VET.EU=*RDN*B<L("=<,2<L("1P87)T<ULR
M72D[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!D969A
M=6QT.@T*("`@("`@("`@("`@("`@("1R96QE87-E(#T@97)E9U]R97!L86-E
M*"<M+BHG+"`G)RP@)'!A<G1S6S)=*3L-"B`@("`@("`@("`@("`@("!B<F5A
M:SL-"B`@("`@("`@?0T*#0H-"B`@("`@("`@:68@*&ES<V5T*"1S>7-M87!;
M)'-Y<VYA;65=*2D@>PT*("`@("`@("`@("`@)'-Y<VYA;64@/2`D<WES;6%P
M6R1S>7-N86UE73L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1S
M>7-N86UE(#T@<W1R=&]L;W=E<B@D<WES;F%M92D[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*&ES<V5T*"1C<'5M87!;)&-P=5TI*2![#0H@("`@("`@("`@
M("`D8W!U(#T@)&-P=6UA<%LD8W!U73L-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@87)R87DH)'-Y<VYA;64L("1R96QE87-E+"`D8W!U+"`D97AT<F$L
M("1N;V1E;F%M92D[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7V1E=&5C=$=L
M:6)C5F5R<VEO;B@I#0H@("`@>PT*("`@("`@("!S=&%T:6,@)&=L:6)C(#T@
M9F%L<V4[#0H@("`@("`@(&EF("@D9VQI8F,@(3T](&9A;'-E*2![#0H@("`@
M("`@("`@("!R971U<FX@)&=L:6)C.R`O+R!N;R!N965D('1O(')U;B!T:&ES
M(&UU;'1I<&QE('1I;65S#0H@("`@("`@('T-"B`@("`@("`@:6YC;'5D95]O
M;F-E(")3>7-T96TN<&AP(CL-"B`@("`@("`@:68@*"%F:6QE7V5X:7-T<R@G
M+W5S<B]B:6XO8W!P)RD@?'P@(6ES7V5X96-U=&%B;&4H)R]U<W(O8FEN+V-P
M<"<I*2![#0H@("`@("`@("`@("`O+R!5<V4@9VQI8F,G<R`\9F5A='5R97,N
M:#X@:&5A9&5R(&9I;&4@=&\-"B`@("`@("`@("`@("\O(&=E="!M86IO<B!A
M;F0@;6EN;W(@=F5R<VEO;B!N=6UB97(Z#0H@("`@("`@("`@("!I9B`H)&9E
M871U<F5S7V9I;&4@/2!`9F]P96XH)R]U<W(O:6YC;'5D92]F96%T=7)E<RYH
M)RP@)W)B)RD@*2![#0H@("`@("`@("`@("`@("`@=VAI;&4@*"%F96]F*"1F
M96%T=7)E<U]F:6QE*2D@>PT*("`@("`@("`@("`@("`@("`@("`D;&EN92`]
M(&9G971S*"1F96%T=7)E<U]F:6QE+"`X,3DR*3L-"B`@("`@("`@("`@("`@
M("`@("`@:68@*"$D;&EN92!\?"`H<W1R<&]S*"1L:6YE+"`G(V1E9FEN92<I
M(#T]/2!F86QS92DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@(&EF("AS=')P;W,H)&QI;F4L("=?7T=,24)#7U\G*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@;6%J;W(@=F5R<VEO;B!N=6UB97(@(V1E
M9FEN92!?7T=,24)#7U\@=F5R<VEO;@T*("`@("`@("`@("`@("`@("`@("`@
M("`@)&QI;F4@/2!P<F5G7W-P;&ET*"<O7',K+R<L("1L:6YE*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1G;&EB8U]M86IO<B`]('1R:6TH)&QI;F5;
M,ETI.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1G;&EB
M8U]M:6YO<BDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@(&EF("AS=')P;W,H)&QI;F4L("=?7T=,24)#
M7TU)3D]27U\G*2D@('L-"B`@("`@("`@("`@("`@("`@("`@("`@("\O(&=O
M="!T:&4@;6EN;W(@=F5R<VEO;B!N=6UB97(-"B`@("`@("`@("`@("`@("`@
M("`@("`@("\O("-D969I;F4@7U]'3$E"0U]-24Y/4E]?('9E<G-I;VX-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1L:6YE(#T@<')E9U]S<&QI="@G+UQS
M*R\G+"`D;&EN92D[#0H@("`@("`@("`@("`@("`@("`@("`@("`D9VQI8F-?
M;6EN;W(@/2!T<FEM*"1L:6YE6S)=*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D9VQI8F-?;6%J;W(I*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!F8VQO<V4H)&9E871U<F5S7V9I;&4I.PT*("`@("`@("`@("`@
M("`@(&EF("@A:7-S970H)&=L:6)C7VUA:F]R*2!\?"`A:7-S970H)&=L:6)C
M7VUI;F]R*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)&=L:6)C
M(#T@)R<[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(')E
M='5R;B`D9VQI8F,@/2`G9VQI8F,G("X@=')I;2@D9VQI8F-?;6%J;W(I("X@
M(BXB("X@=')I;2@D9VQI8F-?;6EN;W(I(#L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(')E='5R;B`D9VQI8F,@/2`G)SL-"B`@("`@("`@?0T*("`@
M("`@("`D=&UP9FEL92`](%-Y<W1E;3HZ;6MT96UP*")G;&EB8W1E<W0B*3L-
M"B`@("`@("`@)&9P(#T@9F]P96XH)'1M<&9I;&4L(")W(BD[#0H@("`@("`@
M(&9W<FET92@D9G`L("(C:6YC;'5D92`\9F5A='5R97,N:#Y<;E]?1TQ)0D-?
M7R!?7T=,24)#7TU)3D]27U]<;B(I.PT*("`@("`@("!F8VQO<V4H)&9P*3L-
M"B`@("`@("`@)&-P<"`]('!O<&5N*"(O=7-R+V)I;B]C<'`@)'1M<&9I;&4B
M+"`B<B(I.PT*("`@("`@("`D;6%J;W(@/2`D;6EN;W(@/2`P.PT*("`@("`@
M("!W:&EL92`H)&QI;F4@/2!F9V5T<R@D8W!P+"`Q,#(T*2D@>PT*("`@("`@
M("`@("`@:68@*"1L:6YE>S!](#T]("<C)R!\?"!T<FEM*"1L:6YE*2`]/2`G
M)RD@>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@:68@*&QI<W0H)&UA:F]R+"`D;6EN;W(I(#T@97AP
M;&]D92@G("<L('1R:6TH)&QI;F4I*2D@>PT*("`@("`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@('!C;&]S
M92@D8W!P*3L-"B`@("`@("`@=6YL:6YK*"1T;7!F:6QE*3L-"B`@("`@("`@
M:68@*"$H)&UA:F]R("8F("1M:6YO<BD@)B8@:7-?;&EN:R@G+VQI8B]L:6)C
M+G-O+C8G*2D@>PT*("`@("`@("`@("`@+R\@3&5T)W,@=')Y(')E861I;F<@
M=&AE(&QI8F,N<V\N-B!S>6UL:6YK#0H@("`@("`@("`@("!I9B`H97)E9R@G
M7FQI8F,M*%LN*ETI7"YS;R0G+"!B87-E;F%M92AR96%D;&EN:R@G+VQI8B]L
M:6)C+G-O+C8G*2DL("1M871C:&5S*2D@>PT*("`@("`@("`@("`@("`@(&QI
M<W0H)&UA:F]R+"`D;6EN;W(I(#T@97AP;&]D92@G+B<L("1M871C:&5S*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H(2@D;6%J
M;W(@)B8@)&UI;F]R*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1G;&EB8R`]
M("<G.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D9VQI8F,@/2`B9VQI
M8F-[)&UA:F]R?2Y[)&UI;F]R?2([#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M9V5T4VEG;F%T=7)E*"D-"B`@("![#0H@("`@("`@(&EF("AE;7!T>2@D=&AI
M<RT^97AT<F$I*2![#0H@("`@("`@("`@("!R971U<FX@(GLD=&AI<RT^<WES
M;F%M97TM>R1T:&ES+3YR96QE87-E?2U[)'1H:7,M/F-P=7TB.PT*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B`B>R1T:&ES+3YS>7-N86UE?2U[)'1H:7,M
M/G)E;&5A<V5]+7LD=&AI<RT^8W!U?2U[)'1H:7,M/F5X=')A?2([#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@9V5T4WES;F%M92@I#0H@("`@>PT*("`@("`@
M("!R971U<FX@)'1H:7,M/G-Y<VYA;64[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@9V5T3F]D96YA;64H*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES
M+3YN;V1E;F%M93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971#<'4H*0T*
M("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3YC<'4[#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@9V5T4F5L96%S92@I#0H@("`@>PT*("`@("`@("!R971U
M<FX@)'1H:7,M/G)E;&5A<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T
M17AT<F$H*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3YE>'1R83L-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!M871C:%-I9VYA='5R92@D;6%T8V@I
M#0H@("`@>PT*("`@("`@("!I9B`H:7-?87)R87DH)&UA=&-H*2D@>PT*("`@
M("`@("`@("`@)&9R86=M96YT<R`]("1M871C:#L-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("1F<F%G;65N=',@/2!E>'!L;V1E*"<M)RP@)&UA
M=&-H*3L-"B`@("`@("`@?0T*("`@("`@("`D;B`](&-O=6YT*"1F<F%G;65N
M=',I.PT*("`@("`@("`D;6%T8VAE<R`](#`[#0H@("`@("`@(&EF("@D;B`^
M(#`I('L-"B`@("`@("`@("`@("1M871C:&5S("L]("1T:&ES+3Y?;6%T8VA&
M<F%G;65N="@D9G)A9VUE;G1S6S!=+"`D=&AI<RT^<WES;F%M92D[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"1N(#X@,2D@>PT*("`@("`@("`@("`@)&UA
M=&-H97,@*ST@)'1H:7,M/E]M871C:$9R86=M96YT*"1F<F%G;65N='-;,5TL
M("1T:&ES+3YR96QE87-E*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&X@
M/B`R*2![#0H@("`@("`@("`@("`D;6%T8VAE<R`K/2`D=&AI<RT^7VUA=&-H
M1G)A9VUE;G0H)&9R86=M96YT<ULR72P@)'1H:7,M/F-P=2D[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"1N(#X@,RD@>PT*("`@("`@("`@("`@)&UA=&-H
M97,@*ST@)'1H:7,M/E]M871C:$9R86=M96YT*"1F<F%G;65N='-;,UTL("1T
M:&ES+3YE>'1R82D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("@D;6%T
M8VAE<R`]/2`D;BD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7VUA=&-H1G)A
M9VUE;G0H)&9R86=M96YT+"`D=F%L=64I#0H@("`@>PT*("`@("`@("!I9B`H
M<W1R8W-P;B@D9G)A9VUE;G0L("<J/R<I(#P@<W1R;&5N*"1F<F%G;65N="DI
M('L-"B`@("`@("`@("`@("1R96<@/2`G7B<@+B!S=')?<F5P;&%C92AA<G)A
M>2@G*B<L("<_)RP@)R\G*2P@87)R87DH)RXJ)RP@)RXG+"`G7%PO)RDL("1F
M<F%G;65N="D@+B`G)"<[#0H@("`@("`@("`@("!R971U<FX@97)E9VDH)')E
M9RP@)'9A;'5E*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@*"1F<F%G
M;65N="`]/2`G*B<@?'P@(7-T<F-A<V5C;7`H)&9R86=M96YT+"`D=F%L=64I
M*3L-"B`@("!]#0H-"GT-"B\J#0H@*B!,;V-A;"!687)I86)L97,Z#0H@*B!I
M;F1E;G0M=&%B<RUM;V1E.B!N:6P-"B`J(&,M8F%S:6,M;V9F<V5T.B`T#0H@
M*B!%;F0Z#0H@*B\-"C\^#0H``````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O=&5S=',`````````````````````````````
M```````````````````````````````````````````````````````````P
M,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<S
M,R`P,3<U-3$`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]834Q?
M4&%R<V5R````````````````````````````````````````````````````
M`````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P,#`P(#$P-3$U-#,S-S,R(#`R,34R-``@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+W1E<W1S+UA-3%]087)S97(O=&5S=',`````````````````````
M````````````````````````````````````````````,#`P-S4U(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S(@,#(R-C8V`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O6$U,7U!A<G-E<B]T97-T
M<R\P,#4N<&AP=```````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S8W-2`Q,#4Q
M-30S,S<S,B`P,C0Q-C$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+2U415-4+2T*6$U,(%!A<G-E<CH@;6EX:6YG(&-H87)A
M8W1E<B!E;F-O9&EN9W,*+2U32TE0248M+0H\/W!H<"!I9B`H(65X=&5N<VEO
M;E]L;V%D960H(GAM;"(I*2!E8VAO("=S:VEP)SL@/SX*+2U&24Q%+2T*/#]P
M:'`@+R\@+2HM($,K*R`M*BT*+R\*+R\@5&5S="!F;W(Z(%A-3"]087)S97(N
M<&AP"B\O(%!A<G1S('1E<W1E9#H@+2!M:7AI;F<@8VAA<F%C=&5R(&5N8V]D
M:6YG<PHO+PHO+R!4:&ES(&ES('=H870@=V4@=&5S=#H*+R\@,2!55$8M."`@
M("`@("T^($E33RTX.#4Y+3$*+R\@,B!55$8M."`@("`@("T^(%53+4%30TE)
M"B\O(#,@25-/+3@X-3DM,2`M/B!55$8M.`HO+R`T($E33RTX.#4Y+3$@+3X@
M55,M05-#24D*+R\@-2!54RU!4T-)22`@("T^(%541BTX"B\O(#8@55,M05-#
M24D@("`M/B!)4T\M.#@U.2TQ"B\O"@IR97%U:7)E7V]N8V4@(BXN+U!A<G-E
M<BYP:'`B.PH*8VQA<W,@5&5S=$5N8V]D:6YG<S$@97AT96YD<R!834Q?4&%R
M<V5R('L*("`@('9A<B`D;W5T<'5T(#T@)R<["@H@("`@9G5N8W1I;VX@5&5S
M=$5N8V]D:6YG<S$H)'1O+"`D9G)O;2D@>PH@("`@("`@("1T:&ES+3Y834Q?
M4&%R<V5R*"1F<F]M+"`G979E;G0G+"`D=&\I.PH@("`@?0H@("`@9G5N8W1I
M;VX@<W1A<G1(86YD;&5R*"1X<"P@)&5L96TL("1A='1R:6)S*2!["B`@("`@
M("`@)'1H:7,M/F]U='!U="`N/2`B/"1E;&5M/B(["B`@("!]"B`@("!F=6YC
M=&EO;B!E;F1(86YD;&5R*"1X<"P@)&5L96TI('L*("`@("`@("`D=&AI<RT^
M;W5T<'5T("X]("(\+R1E;&5M/B(["B`@("!]"B`@("!F=6YC=&EO;B!C9&%T
M84AA;F1L97(H)'AP+"`D9&%T82D@>PH@("`@("`@("1T:&ES+3YO=71P=70@
M+CT@)&1A=&$["B`@("!]"B`@("!F=6YC=&EO;B!T97-T*"1D871A*2!["B`@
M("`@("`@+R\@)'1H:7,M/F]U='!U="`]("<G.PH@("`@("`@("1T:&ES+3YP
M87)S95-T<FEN9R@D9&%T82P@=')U92D["B`@("`@("`@<F5T=7)N("1T:&ES
M+3YO=71P=70["B`@("!]"GT*"B1X;6P@/2`B/#]X;6P@=F5R<VEO;CTG,2XP
M)R`_/B(["B1I;G!U="`](&%R<F%Y*`H@("`@(E541BTX(B`@("`@(#T^("(\
M83YA8F/#IL.XPZ4\+V$^(BP*("`@("))4T\M.#@U.2TQ(B`]/B`B/&$^86)C
MYOCE/"]A/B(L"B`@("`B55,M05-#24DB("`@/3X@(CQA/F%B8V%O83PO83XB
M"BD["@HD96YC;V1I;F=S(#T@87)R87E?:V5Y<R@D:6YP=70I.PIF;W)E86-H
M("@D:6YP=70@87,@)'-R8V5N8R`]/B`D<W1R:6YG*2!["B`@("!F;W)E86-H
M("@D96YC;V1I;F=S(&%S("1T9W1E;F,I('L*("`@("`@("!I9B`H)'-R8V5N
M8R`]/2`D=&=T96YC*2!["B`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@
M('T*("`@("`@("!P<FEN="`B5&5S=&EN9R`D<W)C96YC("T^("1T9W1E;F,Z
M("(["B`@("`@("`@)'`@/28@;F5W(%1E<W1%;F-O9&EN9W,Q*"1T9W1E;F,L
M("1S<F-E;F,I.PH@("`@("`@("1E(#T@)'`M/G1E<W0H)&EN<'5T6R1S<F-E
M;F-=*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92DI('L*("`@("`@
M("`@("`@<')I;G1F*")/3U!3.B`E<UQN(BP@)&4M/F=E=$UE<W-A9V4H*2D[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@=F%R7V1U;7`H)&4I.PH@
M("`@("`@('T*("`@('T*?0H*/SX*+2U%6%!%0U0M+0I497-T:6YG(%541BTX
M("T^($E33RTX.#4Y+3$Z('-T<FEN9R@Q,RD@(CQ!/F%B8^;XY3PO03XB"E1E
M<W1I;F<@551&+3@@+3X@55,M05-#24DZ('-T<FEN9R@Q,RD@(CQ!/F%B8S\_
M/SPO03XB"E1E<W1I;F<@25-/+3@X-3DM,2`M/B!55$8M.#H@<W1R:6YG*#$V
M*2`B/$$^86)CPZ;#N,.E/"]!/B(*5&5S=&EN9R!)4T\M.#@U.2TQ("T^(%53
M+4%30TE).B!S=')I;F<H,3,I("(\03YA8F,_/S\\+T$^(@I497-T:6YG(%53
M+4%30TE)("T^(%541BTX.B!S=')I;F<H,3,I("(\03YA8F-A;V$\+T$^(@I4
M97-T:6YG(%53+4%30TE)("T^($E33RTX.#4Y+3$Z('-T<FEN9R@Q,RD@(CQ!
M/F%B8V%O83PO03XB"@``````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+UA-3%]087)S97(O=&5S=',O,#`S
M+G!H<'0`````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(T,C(@,3`U,34T,S,W
M,S(@,#(T,30T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"TM5$535"TM"EA-3"!087)S97(Z('!A<G-E(&9R;VT@9FEL92!R
M97-O=7)C90HM+5-+25!)1BTM"CP_<&AP(&EF("@A97AT96YS:6]N7VQO861E
M9"@B>&UL(BDI(&5C:&\@)W-K:7`G.R`_/@HM+49)3$4M+0H\/W!H<"`O+R`M
M*BT@0RLK("TJ+0HO+PHO+R!497-T(&9O<CH@6$U,+U!A<G-E<BYP:'`*+R\@
M4&%R=',@=&5S=&5D.B`M('!A<G-E<B!C<F5A=&EO;@HO+R`@("`@("`@("`@
M("`@("T@<V]M92!H86YD;&5R<PHO+R`@("`@("`@("`@("`@("T@<&%R<V4@
M9G)O;2!F:6QE(')E<V]U<F-E"B\O"F-H9&ER("AD:7)N86UE*%]?1DE,15]?
M*2D["@IR97%U:7)E7V]N8V4@(BXN+U!A<G-E<BYP:'`B.PH*8VQA<W,@7U]4
M97-T4&%R<V5R,R!E>'1E;F1S(%A-3%]087)S97(@>PH@("`@9G5N8W1I;VX@
M7U]497-T4&%R<V5R,R@I('L*("`@("`@("`D=&AI<RT^6$U,7U!A<G-E<B@I
M.PH@("`@?0H@("`@9G5N8W1I;VX@<W1A<G1(86YD;&5R*"1X<"P@)&5L96UE
M;G0L("1A='1R:6)S*2!["B`@("`@("`@<')I;G0@(CPD96QE;65N="(["B`@
M("`@("`@<F5S970H)&%T=')I8G,I.PH@("`@("`@('=H:6QE("AL:7-T*"1K
M97DL("1V86PI(#T@96%C:"@D871T<FEB<RDI('L*("`@("`@("`@("`@)&5N
M8R`](&AT;6QE;G1I=&EE<R@D=F%L*3L*("`@("`@("`@("`@<')I;G0@(B`D
M:V5Y/5PB)&5N8UPB(CL*("`@("`@("!]"B`@("`@("`@<')I;G0@(CXB.PH@
M("`@?0H@("`@9G5N8W1I;VX@96YD2&%N9&QE<B@D>'`L("1E;&5M96YT*2![
M"B`@("`@("`@<')I;G0@(CPO)&5L96UE;G0^7&XB.PH@("`@?0H@("`@9G5N
M8W1I;VX@8V1A=&%(86YD;&5R*"1X<"P@)&-D871A*2!["B`@("`@("`@<')I
M;G0@(CPA6T-$051!6R1C9&%T85U=/B(["B`@("!]"B`@("!F=6YC=&EO;B!D
M969A=6QT2&%N9&QE<B@D>'`L("1C9&%T82D@>PH*("`@('T*?0IP<FEN="`B
M;F5W(%]?5&5S=%!A<G-E<C,@(CL*=F%R7V1U;7`H9V5T7V-L87-S*"1O(#T@
M;F5W(%]?5&5S=%!A<G-E<C,H*2DI.PIP<FEN="`B9F]P96X@(CL*<')I;G0@
M:7-?<F5S;W5R8V4H)&9P(#T@9F]P96XH(G1E<W0S+GAM;"(L(")R(BDI+B)<
M;B(["G!R:6YT(")S971);G!U="`B.PIV87)?9'5M<"@D;RT^<V5T26YP=70H
M)&9P*2D["G!R:6YT(")P87)S92`B.PIV87)?9'5M<"@D;RT^<&%R<V4H*2D[
M"@H_/@HM+4584$5#5"TM"FYE=R!?7U1E<W1087)S97(S('-T<FEN9R@Q,RD@
M(E]?=&5S='!A<G-E<C,B"F9O<&5N(#$*<V5T26YP=70@8F]O;"AT<G5E*0IP
M87)S92`\4D]/5#X\(5M#1$%405MF;V]=73X\+U)/3U0^"F)O;VPH=')U92D*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S
M=',O6$U,7U!A<G-E<B]T97-T<R\P,#0N<&AP=```````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,3$R,2`Q,#4Q-30S,S<S,B`P,C0Q-#``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+2U415-4+2T*6$U,(%!A
M<G-E<CH@97)R;W(@8VQA<W,*+2U32TE0248M+0H\/W!H<"!I9B`H(65X=&5N
M<VEO;E]L;V%D960H(GAM;"(I*2!E8VAO("=S:VEP)SL@/SX*+2U&24Q%+2T*
M/#]P:'`@+R\@+2HM($,K*R`M*BT*+R\*+R\@5&5S="!F;W(Z(%A-3"]087)S
M97(N<&AP"B\O(%!A<G1S('1E<W1E9#H@+2!P87)S97(@97)R;W(@8VQA<W,*
M+R\*"G)E<75I<F5?;VYC92`B+BXO4&%R<V5R+G!H<"(["@IP<FEN="`B;F5W
M(%A-3%]087)S97(@(CL*=F%R7V1U;7`H9V5T7V-L87-S*"1P(#T@;F5W(%A-
M3%]087)S97(H*2DI.PHD92`]("1P+3YP87)S95-T<FEN9R@B/#]X;6P@=F5R
M<VEO;CTG,2XP)R`_/CQF;V\^/"]B87(^(BP@=')U92D["FEF("A014%2.CII
M<T5R<F]R*"1E*2D@>PH@("`@<')I;G1F*")E<G)O<B!M97-S86=E.B`E<UQN
M(BP@)&4M/F=E=$UE<W-A9V4H*2D["GT@96QS92!["B`@("!P<FEN="`B;F\@
M97)R;W)<;B(["GT*"C\^"BTM15A014-4+2T*;F5W(%A-3%]087)S97(@<W1R
M:6YG*#$P*2`B>&UL7W!A<G-E<B(*97)R;W(@;65S<V%G93H@6$U,7U!A<G-E
M<CH@;6ES;6%T8VAE9"!T86<@870@6$U,(&EN<'5T(&QI;F4@,0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O=&5S=',O6$U,7U!A<G-E<B]T97-T<R\P,#(N<&AP=```````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,C,Q,B`Q,#4Q-30S,S<S,B`P,C0Q-#$`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+2U415-4+2T*
M6$U,(%!A<G-E<CH@<&%R<V4@9G)O;2!F:6QE"BTM4TM)4$E&+2T*/#]P:'`@
M:68@*"%E>'1E;G-I;VY?;&]A9&5D*")X;6PB*2D@96-H;R`G<VMI<"<[(#\^
M"BTM1DE,12TM"CP_<&AP("\O("TJ+2!#*RL@+2HM"B\O"B\O(%1E<W0@9F]R
M.B!834PO4&%R<V5R+G!H<`HO+R!087)T<R!T97-T960Z("T@<&%R<V5R(&-R
M96%T:6]N"B\O("`@("`@("`@("`@("`@+2!S;VUE(&AA;F1L97)S"B\O("`@
M("`@("`@("`@("`@+2!P87)S92!F<F]M(&9I;&4*+R\*8VAD:7(@*&1I<FYA
M;64H7U]&24Q%7U\I*3L*"G)E<75I<F5?;VYC92`B+BXO4&%R<V5R+G!H<"([
M"@IC;&%S<R!?7U1E<W1087)S97(R(&5X=&5N9',@6$U,7U!A<G-E<B!["B`@
M("!F=6YC=&EO;B!?7U1E<W1087)S97(R*"D@>PH@("`@("`@("1T:&ES+3Y8
M34Q?4&%R<V5R*"D["B`@("!]"B`@("!F=6YC=&EO;B!S=&%R=$AA;F1L97(H
M)'AP+"`D96QE;65N="P@)&%T=')I8G,I('L*("`@("`@("!P<FEN="`B/"1E
M;&5M96YT(CL*("`@("`@("!R97-E="@D871T<FEB<RD["B`@("`@("`@=VAI
M;&4@*&QI<W0H)&ME>2P@)'9A;"D@/2!E86-H*"1A='1R:6)S*2D@>PH@("`@
M("`@("`@("`D96YC(#T@:'1M;&5N=&ET:65S*"1V86PI.PH@("`@("`@("`@
M("!P<FEN="`B("1K97D]7"(D96YC7"(B.PH@("`@("`@('T*("`@("`@("!P
M<FEN="`B/B(["B`@("!]"B`@("!F=6YC=&EO;B!E;F1(86YD;&5R*"1X<"P@
M)&5L96UE;G0I('L*("`@("`@("!P<FEN="`B/"\D96QE;65N=#Y<;B(["B`@
M("!]"B`@("!F=6YC=&EO;B!C9&%T84AA;F1L97(H)'AP+"`D8V1A=&$I('L*
M("`@("`@("!P<FEN="`B/"%;0T1!5$%;)&-D871A75T^(CL*("`@('T*("`@
M(&9U;F-T:6]N(&1E9F%U;'1(86YD;&5R*"1X<"P@)&-D871A*2!["@H@("`@
M?0I]"G!R:6YT(")N97<@7U]497-T4&%R<V5R,B`B.PIV87)?9'5M<"AG971?
M8VQA<W,H)&\@/2!N97<@7U]497-T4&%R<V5R,B@I*2D["G!R:6YT(")S971)
M;G!U=$9I;&4@(CL*<')I;G0@:7-?<F5S;W5R8V4H)&\M/G-E=$EN<'5T1FEL
M92@B=&5S=#(N>&UL(BDI+B)<;B(["G!R:6YT(")P87)S92`B.PIV87)?9'5M
M<"@D;RT^<&%R<V4H*2D["@H_/@HM+4584$5#5"TM"FYE=R!?7U1E<W1087)S
M97(R('-T<FEN9R@Q,RD@(E]?=&5S='!A<G-E<C(B"G-E=$EN<'5T1FEL92`Q
M"G!A<G-E(#Q23T]4/CPA6T-$051!6V9O;UU=/CPO4D]/5#X*8F]O;"AT<G5E
M*0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]834Q?4&%R<V5R+W1E
M<W1S+W1E<W0R+GAM;```````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#0W(#$P
M-3$U-#,S-S,R(#`R-#4S,0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/WAM;"!V97)S:6]N/2<Q+C`G(#\^"CQR;V]T/F9O
M;SPO<F]O=#X`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O=&5S=',O6$U,7U!A<G-E<B]T97-T<R]T97-T,RYX
M;6P````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`T-R`Q,#4Q-30S,S<S,B`P
M,C0U,S(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]X;6P@=F5R<VEO;CTG,2XP)R`_/@H\<F]O=#YF;V\\+W)O;W0^````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+W1E<W1S+UA-3%]087)S97(O=&5S=',O,#`Q+G!H<'0`````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#(R,S<@,3`U,34T,S,W,S(@,#(T,30V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"TM5$535"TM
M"EA-3"!087)S97(Z('!A<G-E('-I;7!L92!S=')I;F<*+2U32TE0248M+0H\
M/W!H<"!I9B`H(65X=&5N<VEO;E]L;V%D960H(GAM;"(I*2!E8VAO("=S:VEP
M)SL@/SX*+2U&24Q%+2T*/#]P:'`*+R\*+R\@5&5S="!F;W(Z(%A-3"]087)S
M97(N<&AP"B\O(%!A<G1S('1E<W1E9#H@+2!P87)S97(@8W)E871I;VX*+R\@
M("`@("`@("`@("`@("`M('-O;64@:&%N9&QE<G,*+R\@("`@("`@("`@("`@
M("`M('!A<G-E('-I;7!L92!S=')I;F<*+R\*"G)E<75I<F5?;VYC92`B+BXO
M4&%R<V5R+G!H<"(["@IC;&%S<R!?7U1E<W1087)S97(Q(&5X=&5N9',@6$U,
M7U!A<G-E<B!["B`@("!F=6YC=&EO;B!?7U1E<W1087)S97(Q*"D@>PH@("`@
M("`@("1T:&ES+3Y834Q?4&%R<V5R*"D["B`@("!]"B`@("!F=6YC=&EO;B!S
M=&%R=$AA;F1L97(H)'AP+"`D96QE;65N="P@)&%T=')I8G,I('L*("`@("`@
M("!P<FEN="`B/"1E;&5M96YT(CL*("`@("`@("!R97-E="@D871T<FEB<RD[
M"B`@("`@("`@=VAI;&4@*&QI<W0H)&ME>2P@)'9A;"D@/2!E86-H*"1A='1R
M:6)S*2D@>PH@("`@("`@("`@("`D96YC(#T@:'1M;&5N=&ET:65S*"1V86PI
M.PH@("`@("`@("`@("!P<FEN="`B("1K97D]7"(D96YC7"(B.PH@("`@("`@
M('T*("`@("`@("!P<FEN="`B/B(["B`@("!]"B`@("!F=6YC=&EO;B!E;F1(
M86YD;&5R*"1X<"P@)&5L96UE;G0I('L*("`@("`@("!P<FEN="`B/"\D96QE
M;65N=#Y<;B(["B`@("!]"B`@("!F=6YC=&EO;B!C9&%T84AA;F1L97(H)'AP
M+"`D8V1A=&$I('L*("`@("`@("!P<FEN="`B/"%;0T1!5$%;)&-D871A75T^
M(CL*("`@('T*("`@(&9U;F-T:6]N(&1E9F%U;'1(86YD;&5R*"1X<"P@)&-D
M871A*2!["@H@("`@?0I]"F5R<F]R7W)E<&]R=&EN9R@Q,#(S*3L*<')I;G0@
M(FYE=R!?7U1E<W1087)S97(Q("(["G9A<E]D=6UP*&=E=%]C;&%S<R@D;R`]
M(&YE=R!?7U1E<W1087)S97(Q*"DI*3L*<')I;G0@(G!A<G-E4W1R:6YG("([
M"G9A<E]D=6UP*"1O+3YP87)S95-T<FEN9R@B/#]X;6P@=F5R<VEO;CTG,2XP
M)R`_/CQR;V]T/F9O;SPO<F]O=#XB+"`Q*2D["@H_/@HM+4584$5#5"TM"FYE
M=R!?7U1E<W1087)S97(Q('-T<FEN9R@Q,RD@(E]?=&5S='!A<G-E<C$B"G!A
M<G-E4W1R:6YG(#Q23T]4/CPA6T-$051!6V9O;UU=/CPO4D]/5#X*8F]O;"AT
M<G5E*0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(`````````````
M````````````````````````````````````````````````````````````
M```````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q
M,#4Q-30S,S<S,B`P,C`P,S4`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T
M97-T<R]$0B]T97-T<P``````````````````````````````````````````
M`````````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S,S(#`R,3(P,``@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<@``````````
M````````````````````````````````````````````````````````,#`P
M-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S(@
M,#(R-#<R`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S
M=',O9')I=F5R+W-E='5P+FEN8RYC=G,N;W)I9P``````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M-S4V,B`Q,#4Q-30S,S<S,B`P,C8Q-#<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*"B\J*@H@*B!%<W1A8FQI<VAE
M<R!T:&4@:6YC;'5D95]P871H+"!$4TXG<R!A;F0@8V]N;F5C=&EO;B`D;W!T
M:6]N<PH@*@H@*B!)9B!T:&ES(&9I;&4@:7,@;F%M960@(G-E='5P+FEN8RYC
M=G,L(B!I="!I<R!T:&4@;W)I9VEN86P@;VYE(&9R;VT@0U93+@H@*B!0;&5A
M<V4@9&\@=&AE(&9O;&QO=VEN9SH*("H@("`Q*2!-86ME(&$@8V]P>2!O9B!T
M:&ES(&9I;&4@;F%M960@(G-E='5P+FEN8R(N"B`J("`@,BD@5&AE;BP@:6X@
M=&AE(&-O<'DL(&5D:70@=&AE("1D<VYS(&%R<F%Y(&%S(&%P<')O<')I871E
M(&9O<B!Y;W5R"B`J("`@("`@96YV:7)O;FUE;G0N"B`J("`@,RD@070@;&5A
M<W0@;VYE(&5L96UE;G0@;V8@=&AE("1D<VYS(&%R<F%Y(&YE961S('1O(&)E
M('5N8V]M;65N=&5D+@H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@
M*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R
M<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA
M8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I
M;F<@55)).@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT
M+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(
M4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H
M('1H92!W96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H
M<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*
M("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*
M("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N
M;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@
M*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N
M='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@)$ED.B!S971U
M<"YI;F,N8W9S+'8@,2XV(#(P,#4O,#(O,30@,C,Z,S,Z,C`@9&%N:65L8R!%
M>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA
M9V4O1$(*("HO"@II9B`H(61E9FEN960H)U!!5$A?4T5005)!5$]2)RDI('L*
M("`@(&EF("AS=')I<W1R*%!(4%]/4RP@)U=)3B<I*2!["B`@("`@("`@+RHJ
M"B`@("`@("`@("H@5&AE('-T<FEN9R!U<V5D('1O(&1E;&EM:70@96QE;65N
M=',@;V8@=&AE('!A=&@N"B`@("`@("`@("HO"B`@("`@("`@9&5F:6YE*"=0
M051(7U-%4$%2051/4B<L("<[)RD["B`@("!](&5L<V4@>PH@("`@("`@("\J
M*@H@("`@("`@("`J(%1H92!S=')I;F<@=7-E9"!T;R!D96QI;6ET(&5L96UE
M;G1S(&]F('1H92!P871H+@H@("`@("`@("`J+PH@("`@("`@(&1E9FEN92@G
M4$%42%]315!!4D%43U(G+"`G.B<I.PH@("`@?0I]"@HO*@H@*B!)9B!T:&4@
M<&%T:"!T;R!Y;W5R(%!%05(@:6YS=&%L;&%T:6]N(&ES(&9O=6YD(&EN('1H
M92!L969T(&AA;F0*("H@<&]R=&EO;B!O9B!T:&4@:68H*2!E>'!R97-S:6]N
M(&)E;&]W+"!T:&%T(&UE86YS('1H:7,@9FEL92!H87,*("H@8V]M92!F<F]M
M('1H92!014%2(&EN<W1A;&QE<BX@(%1H97)E9F]R92P@;&5T)W,@=7-E('1H
M90H@*B!I;G-T86QL960@=F5R<VEO;B!O9B!$0BP@=VAI8V@@<VAO=6QD(&)E
M(&9O=6YD('9I82!T:&4*("H@8V]M<'5T97(G<R!D969A=6QT(&EN8VQU9&5?
M<&%T:"X@($%D9"`G+B<@=&\@=&AE(&EN8VQU9&5?<&%T:`H@*B!T;R!E;G-U
M<F4@)RXG(&ES(&EN('1H97)E+@H@*B`*("H@268@=&AE('!A=&@@:&%S(&YO
M="!B965N('-U8G-T:71U=&5D(&EN('1H92!I9B@I(&5X<')E<W-I;VXL"B`J
M('1H:7,@9FEL92!H87,@;&EK96QY(&-O;64@9G)O;2!A($-64R!C:&5C:V]U
M="!O<B!A("YT87(@9FEL92X*("H@5&AE<F5F;W)E+"!W92=L;"!A<W-U;64@
M=&AE('1E<W1S('-H;W5L9"!U<V4@=&AE('9E<G-I;VX@;V8*("H@1$(@=&AA
M="!H87,@8V]M92!F<F]M('1H97)E(&%S('=E;&PN"B`J+PII9B`H)R]H;VUE
M+VQU8V5R+W=O<FLO<&5A<B]S:&%R92]P:'`G("$]("=`)RXG:6YC;'5D95]P
M871H)RXG0"<I('L*("`@(&EN:5]S970H)VEN8VQU9&5?<&%T:"<L(&EN:5]G
M970H)VEN8VQU9&5?<&%T:"<I"B`@("`@("`@("`@("X@4$%42%]315!!4D%4
M3U(@+B`G+B<*("`@("D["GT@96QS92!["B`@("!I;FE?<V5T*"=I;F-L=61E
M7W!A=&@G+"!R96%L<&%T:"AD:7)N86UE*%]?1DE,15]?*2`N("<O+BXO+BXG
M*0H@("`@("`@("`@("`N(%!!5$A?4T5005)!5$]2("X@)RXG("X@4$%42%]3
M15!!4D%43U(*("`@("`@("`@("`@+B!I;FE?9V5T*"=I;F-L=61E7W!A=&@G
M*0H@("`@*3L*?0H*+RHJ"B`J($=R86(@=&AE(%!%05(@1$(@8VQA<W-E<RX*
M("HO"G)E<75I<F5?;VYC92`G1$(N<&AP)SL*"B\O($]P=&EO;G,@=7-E9"!W
M:&5N(&-O;FYE8W1I;F<*)&]P=&EO;G,@/2!A<G)A>2@*("`@("\O)V]P=&EM
M:7IE)R`]/B`G<&]R=&%B:6QI='DG+`H@("`@)W!O<G1A8FEL:71Y)R`]/B!$
M0E]03U)404))3$E465]!3$PL"B`@("`G9&5B=6<G(#T^(#(L"BD["@HD9&)A
M<V5D<VX@/2!A<G)A>2@*("`@("=P:'!T>7!E)R`@/3X@)V1B87-E)RP*("`@
M("=D871A8F%S92<@/3X@)R]P871H+V%N9"]N86UE+V]F+V1B87-E+V9I;&4G
M+`H@("`@)VUO9&4G("`@("`]/B`R+`H@("`@)V9I96QD<R<@("`]/B!A<G)A
M>2@*("`@("`@("!A<G)A>2@G82<L("=.)RP@-2P@,"DL"B`@("`@("`@87)R
M87DH)V(G+"`G0R<L(#0P*2P*("`@("`@("!A<G)A>2@G8R<L("=#)RP@,C4U
M*2P*("`@("`@("!A<G)A>2@G9"<L("=#)RP@,C`I+`H@("`@*2P**3L*"B\J
M"B`J(%5N8V]M;65N="!A="!L96%S="!O;F4@;V8@=&AE(&9O;&QO=VEN9R!E
M;&5M96YT<RX*("H@5VAE;B!R=6YN:6YG('1H92`N<&AP="!T97-T<RP@=&AE
M(&9I<G-T('5N8V]M;65N=&5D(&5L96UE;G0@:7,@=7-E9"X*("H@5VAE;B!R
M=6YN:6YG('1H92!M=6QT:6-O;FYE8W0N<&AP('1E<W0L(&%L;"!U;F-O;6UE
M;G1E9"!E;&5M96YT<R!A<F4@=7-E9"X*("HO"B1D<VYS(#T@87)R87DH"B`@
M("`O+R`G9&)A<V4G("`@(#T^("1D8F%S961S;BP*("`@("\O("=F8G-Q;"<@
M("`@/3X@)V9B<W%L.B\O7W-Y<W1E;3I`+V1B)RP*("`@("\O("=F:7)E8FER
M9"<@/3X@)VEB87-E*&9I<F5B:7)D*3HO+U-94T1"03IM87-T97)K97E`+R]O
M<'0O:6YT97)B87-E+V5X86UP;&5S+V5M<&QO>65E+F=D8C]D:6%L96-T/3,G
M+`H@("`@+R\@)VEF>"<@("`@("`]/B`G:69X.B\O=7-E<CIP=T!L;V-A;&AO
M<W0O9&(G+`H@("`@+R\@)VUS<6PG("`@("`]/B`G;7-Q;#HO+R]D8B<L"@H@
M("`@+R\@270G<R!A9'9I<V%B;&4@=&\@=7-E(&]N;'D@;VYE(&]F('1H92!F
M;VQL;W=I;F<@870@82!T:6UE.@H@("`@+R\@)VUS<W%L)R`@("`]/B`G;7-S
M<6PZ+R]S84!S;VUE:&]S="]P=6)S)RP*("`@("\O("=S>6)A<V4G("`@/3X@
M)W-Y8F%S93HO+W-A0'-O;65H;W-T+W!U8G,G+`H*("`@("\O("=M>7-Q;"<@
M("`@/3X@)VUY<W%L.B\O<F]O=$!L;V-A;&AO<W0O=&5S="<L"B`@("`O+R`G
M;7ES<6QI)R`@(#T^("=M>7-Q;&DZ+R]R;V]T0&QO8V%L:&]S="]T97-T)RP*
M("`@("\O("=O8VDX)R`@("`@/3X@)V]C:3@Z+R]S>7-T96TZ;6%N86=E<D`G
M+`H@("`@+R\@)V%C8V5S<R<@("`]/B`G;V1B8RAA8V-E<W,I.B\O861M:6Y`
M+U-Y<W1E;41S;DYA;64G+`H@("`@+R\@)V1B,B<@("`@("`]/B`G;V1B8RAD
M8C(I.B\O9&(R:6YS=#$Z6%A86$`O4T%-4$Q%)RP*("`@("\O("=P9W-Q;"<@
M("`@/3X@)W!G<W%L.B\O<&]S=&=R97-`;&]C86QH;W-T+W1E<W0G+`H@("`@
M+R\@)W-Q;&ET92<@("`]/B`G<W%L:71E.B\O9'5M;7DZ0&QO8V%L:&]S="\G
M("X@9V5T8W=D*"D@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)W1E<W0N9&(_
M;6]D93TP-C0T)RP**3L*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R+S`S<VEM<&QE<75E<GDN<&AP
M=``````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#,U-R`Q,#4Q-30S,S<S,B`P,C8Q-S4`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+2U415-4
M+2T*1$)?9')I=F5R.CIS:6UP;&51=65R>0HM+4E.22TM"F5R<F]R7W)E<&]R
M=&EN9R`](#(P-#<*+2U32TE0248M+0H\/W!H<"!C:&1I<BAD:7)N86UE*%]?
M1DE,15]?*2D[(')E<75I<F5?;VYC92`G+B]S:VEP:68N:6YC)SL@/SX*+2U&
M24Q%+2T*/#]P:'`*<F5Q=6ER95]O;F-E("<N+VUK=&%B;&4N:6YC)SL*<F5Q
M=6ER95]O;F-E("<N+B]S:6UP;&5Q=65R>2YI;F,G.PH_/@HM+4584$5#5"TM
M"G!A<W-E9`H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S
M+T1"+W1E<W1S+V1R:79E<B\P-&YU;6-O;',N<&AP=```````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`S-3`@,3`U,34T,S,W,S(@,#(U,C<P`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"TM5$535"TM"D1"7V1R:79E
M<CHZ;G5M0V]L<PHM+4E.22TM"F5R<F]R7W)E<&]R=&EN9R`](#(P-#<*+2U3
M2TE0248M+0H\/W!H<"!C:&1I<BAD:7)N86UE*%]?1DE,15]?*2D[(')E<75I
M<F5?;VYC92`G+B]S:VEP:68N:6YC)SL@/SX*+2U&24Q%+2T*/#]P:'`*<F5Q
M=6ER95]O;F-E("<N+VUK=&%B;&4N:6YC)SL*<F5Q=6ER95]O;F-E("<N+B]N
M=6UC;VQS+FEN8R<["C\^"BTM15A014-4+2T*,0HR"C,*-`H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D
M<FEV97(O,#5S97%U96YC97,N<&AP=```````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,#$W
M(#$P-3$U-#,S-S,R(#`R-38P-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````M+51%4U0M+0I$0E]D<FEV97(Z.G-E<75E;F-E
M<PHM+4E.22TM"F5R<F]R7W)E<&]R=&EN9R`](#(P-#<*+2U32TE0248M+0H\
M/W!H<`IE<G)O<E]R97!O<G1I;F<H15]!3$PI.PIC:&1I<BAD:7)N86UE*%]?
M1DE,15]?*2D["G)E<75I<F5?;VYC92`G+B]S:VEP:68N:6YC)SL*)'1A8FQE
M26YF;R`]("1D8BT^9')O<%-E<75E;F-E*"=A:FMD<VQF86IO:6IK861I92<I
M.PII9B`H1$(Z.FES17)R;W(H)'1A8FQE26YF;RD@)B8@)'1A8FQE26YF;RT^
M8V]D92`]/2!$0E]%4E)/4E].3U1?0T%004),12D@>PH@("`@9&EE*")S:VEP
M("1T86)L94EN9F\M/FUE<W-A9V4B*3L*?0H_/@HM+49)3$4M+0H\/W!H<`IR
M97%U:7)E7V]N8V4@)RXO8V]N;F5C="YI;F,G.PIR97%U:7)E7V]N8V4@)RXN
M+W-E<75E;F-E<RYI;F,G.PH_/@HM+4584$5#5"TM"F%N(&5R<F]R(&ES('1H
M92!P<F]P97(@<F5S<&]N<V4@:&5R90IA;B!E<G)O<B!C;W5G:'0@8GD@=&AE
M(&5R<F]R(&AA;F1L97(@:7,@9V]O9`IA/3$*8CTR"F(M83TQ"F,],0ID/3$*
M93TQ"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T
M97-T<R]D<FEV97(O,#9P<F5P97AE8RYP:'!T````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`R,S<U(#$P-3$U-#,S-S,R(#`R-30S-@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````M+51%4U0M+0I$0E]D<FEV97(Z.G!R
M97!A<F4O97AE8W5T90HM+4E.22TM"F5R<F]R7W)E<&]R=&EN9R`](#(P-#<*
M+2U32TE0248M+0H\/W!H<"!C:&1I<BAD:7)N86UE*%]?1DE,15]?*2D[(')E
M<75I<F5?;VYC92`G+B]S:VEP:68N:6YC)SL@/SX*+2U&24Q%+2T*/#]P:'`*
M<F5Q=6ER95]O;F-E("<N+VUK=&%B;&4N:6YC)SL*<F5Q=6ER95]O;F-E("<N
M+B]P<F5P97AE+FEN8R<["C\^"BTM15A014-4+2T*+2TM+2TM+2TM+2TM,2TM
M+2TM+2TM+2TM+0IS=&@Q+'-T:#(L<W1H,RQS=&@T(&-R96%T960*<W1H,3H@
M/R!A<R!P87)A;2P@<&%S<VEN9R!A<R!A<G)A>2XN+B!S=&@Q(&5X96-U=&5D
M"G-T:#(Z("$@86YD(#\@87,@<&%R86US+"!P87-S:6YG(&%S(&%R<F%Y+BXN
M('-T:#(@97AE8W5T960*<W1H,SH@/RP@(2!A;F0@)B!A<R!P87)A;7,L('!A
M<W-I;F<@87,@87)R87DN+BX@<W1H,R!E>&5C=71E9`IS=&@T.B!N;R!P87)A
M;7,N+BX@<W1H-"!E>&5C=71E9`IR97-U;'1S.@I\-S(@+2!A("T@("T@?`I\
M-S(@+2!D:7)E8W0@+2`@+2!\"GPW,B`M(&ET)W,@9V]O9"`M(&]P87%U92!P
M;&%C96AO;&1E<B=S('1E<W0@+2!\"GPW,B`M('1H870G<R!R:6=H="`M("`M
M('P*"BTM+2TM+2TM+2TM+3(M+2TM+2TM+2TM+2T*<F5S=6QT<SH*?#<R("T@
M<V5T,2`M(&]P87%U92!P;&%C96AO;&1E<B=S('1E<W0@+2`Q,C,T+34V+3<X
M?`I\-S(@+2!S970R("T@;W!A<75E('!L86-E:&]L9&5R)W,@=&5S="`M('P*
M?#<R("T@<V5T,R`M(&]P87%U92!P;&%C96AO;&1E<B=S('1E<W0@+2!\"@HM
M+2TM+2TM+2TM+2TS+2TM+2TM+2TM+2TM"E12544*1D%,4T4*"BTM+2TM+2TM
M+2TM+30M+2TM+2TM+2TM+2T*?#<R("T@<V5T,2`M(&]P87%U92!P;&%C96AO
M;&1E<B=S('1E<W0@+2`Q,C,T+34V+3<X?`I\-S(@+2!S970R("T@;W!A<75E
M('!L86-E:&]L9&5R)W,@=&5S="`M('P*?#<R("T@<V5T,R`M(&]P87%U92!P
M;&%C96AO;&1E<B=S('1E<W0@+2!\"GY^"GY^"GPW,B`M('-E=#$@+2!O<&%Q
M=64@<&QA8V5H;VQD97(G<R!T97-T("T@,3(S-"TU-BTW.'P*?GX*?#<R("T@
M<V5T,2`M(&]P87%U92!P;&%C96AO;&1E<B=S('1E<W0@+2`Q,C,T+34V+3<X
M?`I\-S(@+2!S970R("T@;W!A<75E('!L86-E:&]L9&5R)W,@=&5S="`M('P*
M?#<R("T@<V5T,R`M(&]P87%U92!P;&%C96AO;&1E<B=S('1E<W0@+2!\"GY^
M"@HM+2TM+2TM+2TM+2TU+2TM+2TM+2TM+2TM"FEN<V5R=#H@;VMA>0IA(#T@
M,3$L(&(@/2!T:')E92P@9"`](&=O="!E>'!E8W1E9"!O=71C;VUE"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<B\P.&%F9F5C=&5D
M<F]W<RYP:'!T````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(W-S(@,3`U,34T,S,W,S(@,#(V
M,S`R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"TM5$535"TM"D1"7V1R:79E<CHZ869F96-T9612;W=S"BTM24Y)+2T*97)R
M;W)?<F5P;W)T:6YG(#T@,C`T-PHM+5-+25!)1BTM"CP_<&AP(&-H9&ER*&1I
M<FYA;64H7U]&24Q%7U\I*3L@<F5Q=6ER95]O;F-E("<N+W-K:7!I9BYI;F,G
M.R`_/@HM+49)3$4M+0H\/W!H<`IR97%U:7)E7V]N8V4@)RXO;6MT86)L92YI
M;F,G.PH*+RHJ"B`J($QO8V%L(&5R<F]R(&-A;&QB86-K(&AA;F1L97(N"B`J
M"B`J($1R;W!S('1H92!P:'!T97-T('1A8FQE+"!P<FEN=',@;W5T(&%N(&5R
M<F]R(&UE<W-A9V4@86YD(&MI;&QS('1H90H@*B!P<F]C97-S+@H@*@H@*B!`
M<&%R86T@;V)J96-T("`D;R`@4$5!4B!E<G)O<B!O8FIE8W0@875T;VUA=&EC
M86QL>2!P87-S960@=&\@=&AI<R!M971H;V0*("H@0')E='5R;B!V;VED"B`J
M($!S964@4$5!4CHZ<V5T17)R;W)(86YD;&EN9R@I"B`J+PIF=6YC=&EO;B!P
M92@D;RD@>PH@("`@9VQO8F%L("1D8F@["@H@("`@)&1B:"T^<V5T17)R;W)(
M86YD;&EN9RA014%27T524D]27U)%5%523BD["B`@("!D<F]P7W1A8FQE*"1D
M8F@L("=P:'!T97-T)RD["@H@("`@9&EE*"1O+3YT;U-T<FEN9R@I*3L*?0H*
M)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27T-!3$Q"04-++"`G
M<&4G*3L*"@HO+R!#;&5A;B!T86)L90HD9&)H+3YQ=65R>2@B1$5,151%($92
M3TT@<&AP=&5S="(I.PH*+R\@069F96-T960@<F]W<R!B>2!)3E-%4E0@<W1A
M=&5M96YT"B1D8F@M/G%U97)Y*"))3E-%4E0@24Y43R!P:'!T97-T("AA+&(I
M(%9!3%5%4R@Q+"`G=&5S="<I(BD["B1D8F@M/G%U97)Y*"))3E-%4E0@24Y4
M3R!P:'!T97-T("AA+&(I(%9!3%5%4R@R+"`G=&5S="<I(BD["G!R:6YT9B@B
M)60@869T97(@:6YS97)T7&XB+"`D9&)H+3YA9F9E8W1E9%)O=W,H*2D["@HO
M+R!!9F9E8W1E9"!R;W=S(&)Y(%-%3$5#5"!S=&%T96UE;G0*)&1B:"T^<75E
M<GDH(E-%3$5#5"`J($923TT@<&AP=&5S="(I.PIP<FEN=&8H(B5D(&%F=&5R
M('-E;&5C=%QN(BP@)&1B:"T^869F96-T9612;W=S*"DI.PHD9&)H+3YQ=65R
M>2@B1$5,151%($923TT@<&AP=&5S="!72$5212!B(#T@)W1E<W0G(BD["G!R
M:6YT9B@B)60@869T97(@9&5L971E7&XB+"`D9&)H+3YA9F9E8W1E9%)O=W,H
M*2D["@HO+R!!9F9E8W1E9"!R;W=S(&)Y($1%3$5412!S=&%T96UE;G0*)&1B
M:"T^<75E<GDH(DE.4T525"!)3E1/('!H<'1E<W0@*&$L8BD@5D%,5453*#$L
M("=T97-T)RDB*3L*)&1B:"T^<75E<GDH(DE.4T525"!)3E1/('!H<'1E<W0@
M*&$L8BD@5D%,5453*#(L("=T97-T)RDB*3L*)&1B:"T^<75E<GDH(D1%3$54
M12!&4D]-('!H<'1E<W0B*3L*<')I;G1F*"(E9"!A9G1E<B!D96QE=&4@86QL
M7&XB+"`D9&)H+3YA9F9E8W1E9%)O=W,H*2D["@H*)&1B:"T^<V5T17)R;W)(
M86YD;&EN9RA014%27T524D]27U)%5%523BD["F1R;W!?=&%B;&4H)&1B:"P@
M)W!H<'1E<W0G*3L*"C\^"BTM15A014-4+2T*,2!A9G1E<B!I;G-E<G0*,"!A
M9G1E<B!S96QE8W0*,B!A9G1E<B!D96QE=&4*,B!A9G1E<B!D96QE=&4@86QL
M"@```````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O
M=&5S=',O9')I=F5R+S`Y;G5M<F]W<RYP:'!T````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,3`Q,B`Q,#4Q-30S,S<S,B`P,C4S,C,`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+2U415-4+2T*1$)?9')I=F5R.CIN
M=6U2;W=S"BTM24Y)+2T*97)R;W)?<F5P;W)T:6YG(#T@,C`T-PHM+5-+25!)
M1BTM"CP_<&AP(&-H9&ER*&1I<FYA;64H7U]&24Q%7U\I*3L@<F5Q=6ER95]O
M;F-E("<N+W-K:7!I9BYI;F,G.R`_/@HM+49)3$4M+0H\/W!H<`IR97%U:7)E
M7V]N8V4@)RXO;6MT86)L92YI;F,G.PIR97%U:7)E7V]N8V4@)RXN+VYU;7)O
M=W,N:6YC)SL*/SX*+2U%6%!%0U0M+0HH=V%N="`Q*2!G;W0@,2!F<F]M(&9I
M<G-T"BAW86YT(#(I(&=O="`R(&9R;VT@,`HH=V%N="`S*2!G;W0@,R!F<F]M
M(#$**'=A;G0@-"D@9V]T(#0@9G)O;2`R"BAW86YT(#4I(&=O="`U(&9R;VT@
M,PHH=V%N="`V*2!G;W0@-B!F<F]M(#0**'=A;G0@-2D@9V]T(#4@9G)O;2`^
M(#`@*'!A<W-I;F<@<&%R86US('1O('%U97)Y*0HH=V%N="`T*2!G;W0@-"!F
M<F]M(#P@-"`H9&]I;F<@<')E<&%R92]E>&5C=71E*0HH=V%N="`R*2!G;W0@
M,B!F<F]M(#4@86YD(#8@;F]T(&1E;&5T960**'=A;G0@,"D@9V]T(#`@9G)O
M;2`\(#`*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S
M=',O1$(O=&5S=',O9')I=F5R+S$P97)R;W)M87`N<&AP=```````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,S8S,R`Q,#4Q-30S,S<S,B`P,C4T-#,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+2U415-4+2T*1$)?9')I
M=F5R.CIE<G)O<B!M87!P:6YG"BTM24Y)+2T*97)R;W)?<F5P;W)T:6YG(#T@
M,C`T-PHM+5-+25!)1BTM"CP_<&AP(&-H9&ER*&1I<FYA;64H7U]&24Q%7U\I
M*3L@<F5Q=6ER95]O;F-E("<N+W-K:7!I9BYI;F,G.R`_/@HM+49)3$4M+0H\
M/W!H<`IR97%U:7)E7V]N8V4@)RXO;6MT86)L92YI;F,G.PIR97%U:7)E7V]N
M8V4@)RXN+V5R<F]R<RYI;F,G.PH_/@HM+4584$5#5"TM"D1"7T524D]27TY/
M4U5#2%1!0DQ%(&9O<B!S96QE8W0Z("!M871C:&5S(&5X<&5C=&5D(&]U=&-O
M;64*1$)?15)23U)?3D]354-(5$%"3$4@9F]R(&1R;W`Z("!M871C:&5S(&5X
M<&5C=&5D(&]U=&-O;64*1$)?15)23U)?3D]47T9/54Y$(&9O<B!D<F]P(&EN
M9&5X.B`@;6%T8VAE<R!E>'!E8W1E9"!O=71C;VUE"D1"7T524D]27T%,4D5!
M1%E?15A)4U13(&9O<B!C<F5A=&4@=&%B;&4Z("!M871C:&5S(&5X<&5C=&5D
M(&]U=&-O;64*1$)?15)23U)?04Q214%$65]%6$E35%,@9F]R(&-R96%T92!I
M;F1E>#H@(&UA=&-H97,@97AP96-T960@;W5T8V]M90I$0E]%4E)/4E]#3TY3
M5%)!24Y4(&9O<B!P<FEM87)Y(&ME>2!I;G-E<G0@9'5P;&EC871E.B`@;6%T
M8VAE<R!E>'!E8W1E9"!O=71C;VUE"D1"7T524D]27T-/3E-44D%)3E0@9F]R
M('!R:6UA<GD@:V5Y('5P9&%T92!D=7!L:6-A=&4Z("!M871C:&5S(&5X<&5C
M=&5D(&]U=&-O;64*1$)?15)23U)?0T].4U1204E.5"!F;W(@=6YI<75E(&ME
M>2!I;G-E<G0@9'5P;&EC871E.B`@;6%T8VAE<R!E>'!E8W1E9"!O=71C;VUE
M"D1"7T524D]27T-/3E-44D%)3E0@9F]R('5N:7%U92!K97D@=7!D871E(&1U
M<&QI8V%T93H@(&UA=&-H97,@97AP96-T960@;W5T8V]M90I$0E]%4E)/4E]#
M3TY35%)!24Y4(&9O<B!F;W)E:6=N(&ME>2!O;B!I;G-E<G0Z("!M871C:&5S
M(&5X<&5C=&5D(&]U=&-O;64*1$)?15)23U)?0T].4U1204E.5"!F;W(@9F]R
M96EG;B!K97D@;VX@9&5L971E.B`@;6%T8VAE<R!E>'!E8W1E9"!O=71C;VUE
M"D1"7T524D]27T-/3E-44D%)3E1?3D]47TY53$P@;VX@:6YS97)T.B`@;6%T
M8VAE<R!E>'!E8W1E9"!O=71C;VUE"D1"7T524D]27T-/3E-44D%)3E1?3D]4
M7TY53$P@;VX@=7!D871E.B`@;6%T8VAE<R!E>'!E8W1E9"!O=71C;VUE"D1"
M7T524D]27TY/4U5#2$9)14Q$(&IO:6YI;F<@3TX@8F]G=7,@8V]L=6UN.B`@
M;6%T8VAE<R!E>'!E8W1E9"!O=71C;VUE"D1"7T524D]27TY/4U5#2$9)14Q$
M(&IO:6YI;F<@55-)3D<@8F]G=7,@8V]L=6UN.B`@;6%T8VAE<R!E>'!E8W1E
M9"!O=71C;VUE"D1"7T524D]27T1)5EI%4D\Z("!M871C:&5S(&5X<&5C=&5D
M(&]U=&-O;64*1$)?15)23U)?24Y604Q)1%].54U"15(@<'5T=&EN9R!C:&%R
M<R!I;B!)3E0@8V]L=6UN.B`@;6%T8VAE<R!E>'!E8W1E9"!O=71C;VUE"D1"
M7T524D]27TE.5D%,241?3E5-0D52('!U='1I;F<@9FQO870@:6X@24Y4(&-O
M;'5M;CH@(&UA=&-H97,@97AP96-T960@;W5T8V]M90I$0E]%4E)/4E])3E9!
M3$E$7TY534)%4B!P=71T:6YG(&5X8V5S<VEV92!I;G0@:6X@24Y4(&-O;'5M
M;CH@(&UA=&-H97,@97AP96-T960@;W5T8V]M90I$0E]%4E)/4E])3E9!3$E$
M7TY534)%4B!P=71T:6YG(&EN="!I;B!#2$%2(&-O;'5M;CH@(&UA=&-H97,@
M97AP96-T960@;W5T8V]M90I$0E]%4E)/4E].3U-50TA&245,1#H@(&UA=&-H
M97,@97AP96-T960@;W5T8V]M90I$0E]%4E)/4E]364Y405@Z("!M871C:&5S
M(&5X<&5C=&5D(&]U=&-O;64*1$)?15)23U)?5D%,545?0T]53E1?3TY?4D]7
M.B`@;6%T8VAE<R!E>'!E8W1E9"!O=71C;VUE"D1"7T524D]27TE.5D%,240@
M;VX@0TA!4B!C;VQU;6X@9&%T82!T;V\@;&]N9SH@(&UA=&-H97,@97AP96-T
M960@;W5T8V]M90I$0E]%4E)/4E])3E9!3$E$(&]N(%9!4D-(05(@8V]L=6UN
M(&1A=&$@=&]O(&QO;F<Z("!M871C:&5S(&5X<&5C=&5D(&]U=&-O;64*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1"
M+W1E<W1S+V1R:79E<B\Q,71R86YS86-T:6]N<RYP:'!T````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#$T,34@,3`U,34T,S,W,S(@,#(V,S(Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"TM5$535"TM"D1"7V1R:79E<CHZ
M=')A;G-A8W1I;VX@=&5S=`HM+4E.22TM"F5R<F]R7W)E<&]R=&EN9R`](#(P
M-#<*+2U32TE0248M+0H\/W!H<`IC:&1I<BAD:7)N86UE*%]?1DE,15]?*2D[
M(')E<75I<F5?;VYC92`G+B]S:VEP:68N:6YC)SL*:68@*"$D9&(M/F9E871U
M<F5S6R=T<F%N<V%C=&EO;G,G72D@>PH@("`@9&EE*"=S:VEP('1H:7,@9')I
M=F5R(&1O97,@;F]T('-U<'!O<G0@=')A;G-A8W1I;VYS)RD["GT*/SX*+2U&
M24Q%+2T*/#]P:'`*)&YE961I;FYO9&(@/2!T<G5E.PIR97%U:7)E7V]N8V4@
M)RXO;6MT86)L92YI;F,G.PIR97%U:7)E7V]N8V4@)RXN+W1R86YS86-T:6]N
M<RYI;F,G.PH_/@HM+4584$5#5"TM"C$I(&%F=&5R(&%U=&]C;VUM:70Z(&)I
M;F<@;VYE+B`@;W!S/6]K"C(I(&)E9F]R92!C;VUM:70Z(&)I;F<@;VYE('1W
M;R!T:')E92X@(&]P<SUO:PHS*2!A9G1E<B!C;VUM:70Z(&)I;F<@;VYE('1W
M;R!T:')E92X@(&]P<SUO:PHT*2!B969O<F4@<F]L;&)A8VLZ(&)I;F<@;VYE
M('1W;R!T:')E92!F;W5R(&9I=F4N("!O<',];VL*-2D@869T97(@<F]L;&)A
M8VLZ(&)I;F<@;VYE('1W;R!T:')E92X@(&]P<SUO:PHV*2!B969O<F4@875T
M;V-O;6UI="MR;VQL8F%C:SH@8FEN9R!O;F4@='=O('1H<F5E('-I>"!S979E
M;BX@(&]P<SUO:PHW*2!A9G1E<B!A=71O8V]M;6ET*W)O;&QB86-K.B!B:6YG
M(&]N92!T=V\@=&AR964@<VEX('-E=F5N+B`@;W!S/6]K"C@I('1E<W1I;F<@
M=&AA="!S96QE8W0@9&]E<VXG="!D:7-T=7)B92!O<&-O=6YT.B!O:PH`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E
M<W1S+T1"+W1E<W1S+V1R:79E<B\Q,VQI;6ET+G!H<'0`````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#(P-C(@,3`U,34T,S,W,S(@,#(T-S,P`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"TM5$535"TM"D1"7V1R
M:79E<CHZ<F]W(&QI;6ET"BTM24Y)+2T*97)R;W)?<F5P;W)T:6YG(#T@,C`T
M-PHM+5-+25!)1BTM"CP_<&AP(&-H9&ER*&1I<FYA;64H7U]&24Q%7U\I*3L@
M<F5Q=6ER95]O;F-E("<N+W-K:7!I9BYI;F,G.R`_/@HM+49)3$4M+0H\/W!H
M<`IR97%U:7)E7V]N8V4@)RXO8V]N;F5C="YI;F,G.PIR97%U:7)E7V]N8V4@
M)RXO9')O<'1A8FQE+FEN8R<["G)E<75I<F5?;VYC92`G+BXO;&EM:70N:6YC
M)SL*/SX*+2U%6%!%0U0M+0H]/3T]/3T]($9R;VTZ(#`@?'P@3G5M8F5R(&]F
M(')O=W,@=&\@9F5T8V@Z(#$P(#T]/3T]/3T*,2XM(')E<W5L="`P"C(N+2!R
M97-U;'0@,0HS+BT@<F5S=6QT(#(*-"XM(')E<W5L="`S"C4N+2!R97-U;'0@
M-`HV+BT@<F5S=6QT(#4*-RXM(')E<W5L="`V"C@N+2!R97-U;'0@-PHY+BT@
M<F5S=6QT(#@*,3`N+2!R97-U;'0@.0H]/3T]/3T]($9R;VTZ(#$P('Q\($YU
M;6)E<B!O9B!R;W=S('1O(&9E=&-H.B`Q,"`]/3T]/3T]"C$Q+BT@<F5S=6QT
M(#$P"C$R+BT@<F5S=6QT(#$Q"C$S+BT@<F5S=6QT(#$R"C$T+BT@<F5S=6QT
M(#$S"C$U+BT@<F5S=6QT(#$T"C$V+BT@<F5S=6QT(#$U"C$W+BT@<F5S=6QT
M(#$V"C$X+BT@<F5S=6QT(#$W"C$Y+BT@<F5S=6QT(#$X"C(P+BT@<F5S=6QT
M(#$Y"CT]/3T]/3T@1G)O;3H@,C`@?'P@3G5M8F5R(&]F(')O=W,@=&\@9F5T
M8V@Z(#$P(#T]/3T]/3T*,C$N+2!R97-U;'0@,C`*,C(N+2!R97-U;'0@,C$*
M,C,N+2!R97-U;'0@,C(*,C0N+2!R97-U;'0@,C,*,C4N+2!R97-U;'0@,C0*
M,C8N+2!R97-U;'0@,C4*,C<N+2!R97-U;'0@,C8*,C@N+2!R97-U;'0@,C<*
M,CDN+2!R97-U;'0@,C@*,S`N+2!R97-U;'0@,CD*/3T]/3T]/2!&<F]M.B`S
M,"!\?"!.=6UB97(@;V8@<F]W<R!T;R!F971C:#H@,3`@/3T]/3T]/0HS,2XM
M(')E<W5L="`S,`HS,BXM(')E<W5L="`S,0HS,RXM(')E<W5L="`S,@H]/3T]
M/3T](%!A<W-I;F<@)'!A<F%M<R!\?"!&<F]M.B`Q,2!\?"!.=6UB97(@;V8@
M<F]W<R!T;R!F971C:#H@,R`]/3T]/3T]"C$R+BT@<F5S=6QT(#$Q"C$S+BT@
M<F5S=6QT(#$R"C$T+BT@<F5S=6QT(#$S"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R+S$T
M9F5T8VAM;V1E7V]B:F5C="YP:'!T````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3(Q-R`Q,#4Q-30S
M,S<S,B`P,C<Q,#``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+2U415-4+2T*1$)?9')I=F5R.CIF971C:&UO9&4@;V)J96-T
M"BTM24Y)+2T*97)R;W)?<F5P;W)T:6YG(#T@,C`T-PHM+5-+25!)1BTM"CP_
M<&AP(&-H9&ER*&1I<FYA;64H7U]&24Q%7U\I*3L@<F5Q=6ER95]O;F-E("<N
M+W-K:7!I9BYI;F,G.R`_/@HM+49)3$4M+0H\/W!H<`IR97%U:7)E7V]N8V4@
M)RXO;6MT86)L92YI;F,G.PIR97%U:7)E7V]N8V4@)RXN+V9E=&-H;6]D95]O
M8FIE8W0N:6YC)SL*/SX*+2U%6%!%0U0M+0HM+2T@9F5T8V@@=VET:"!P87)A
M;2!$0E]&151#2$U/1$5?3T)*14-4("TM+0IS=&1C;&%S<R`M/B!A(&(@8R!D
M"G-T9&-L87-S("T^(&$@8B!C(&0*+2TM(&9E=&-H('=I=&@@9&5F875L="!F
M971C:&UO9&4@1$)?1D540TA-3T1%7T]"2D5#5"`M+2T*<W1D8VQA<W,@+3X@
M82!B(&,@9`IS=&1C;&%S<R`M/B!A(&(@8R!D"BTM+2!F971C:"!W:71H(&1E
M9F%U;'0@9F5T8VAM;V1E($1"7T9%5$-(34]$15]/0DI%0U0@86YD(&-L87-S
M($1"7W)O=R`M+2T*9&)?<F]W("T^(&$@8B!C(&0*9&)?<F]W("T^(&$@8B!C
M(&0*+2TM(&9E=&-H('=I=&@@9&5F875L="!F971C:&UO9&4@1$)?1D540TA-
M3T1%7T]"2D5#5"!W:71H(&YO(&-L87-S('1H96X@1$)?<F]W("TM+0IS=&1C
M;&%S<R`M/B!A(&(@8R!D"F1B7W)O=R`M/B!A(&(@8R!D"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I
M=F5R+S$U<75O=&4N<&AP=```````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,S8P,2`Q
M,#4Q-30S,S<S,B`P,C0W-3(`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+2U415-4+2T*1$)?9')I=F5R.CIQ=6]T90HM+4E.
M22TM"F5R<F]R7W)E<&]R=&EN9R`](#(P-#<*+2U32TE0248M+0H\/W!H<"!C
M:&1I<BAD:7)N86UE*%]?1DE,15]?*2D[(')E<75I<F5?;VYC92`G+B]S:VEP
M:68N:6YC)SL@/SX*+2U&24Q%+2T*/#]P:'`*<F5Q=6ER95]O;F-E("<N+V-O
M;FYE8W0N:6YC)SL*<F5Q=6ER95]O;F-E("<N+V1R;W!T86)L92YI;F,G.PH*
M"B\J*@H@*B!,;V-A;"!E<G)O<B!C86QL8F%C:R!H86YD;&5R+@H@*@H@*B!$
M<F]P<R!T:&4@<&AP=&5S="!T86)L92P@<')I;G1S(&]U="!A;B!E<G)O<B!M
M97-S86=E(&%N9"!K:6QL<R!T:&4*("H@<')O8V5S<RX*("H*("H@0'!A<F%M
M(&]B:F5C="`@)&\@(%!%05(@97)R;W(@;V)J96-T(&%U=&]M871I8V%L;'D@
M<&%S<V5D('1O('1H:7,@;65T:&]D"B`J($!R971U<FX@=F]I9`H@*B!`<V5E
M(%!%05(Z.G-E=$5R<F]R2&%N9&QI;F<H*0H@*B\*9G5N8W1I;VX@<&4H)&\I
M('L*("`@(&=L;V)A;"`D9&)H.PH*("`@("1D8F@M/G-E=$5R<F]R2&%N9&QI
M;F<H4$5!4E]%4E)/4E]215154DXI.PH@("`@9')O<%]T86)L92@D9&)H+"`G
M<&5A<G%U;W1E)RD["@H@("`@9&EE*"1O+3YT;U-T<FEN9R@I*3L*?0H*+R\@
M1$)-4R!B;V]L96%N(&-O;'5M;B!T>7!E('-I;75L871I;VXN+BX*)&)O;VQE
M86Y?8V]L7W1Y<&4@/2!A<G)A>2@*("`@("=D8F%S92<@(#T^("=,;V=I8V%L
M)RP*("`@("=F8G-Q;"<@(#T^("="3T],14%.)RP*("`@("=I8F%S92<@(#T^
M("=334%,3$E.5"<L"B`@("`G:69X)R`@("`]/B`G4TU!3$Q)3E0G+`H@("`@
M)VUS<6PG("`@/3X@)TE.5$5'15(G+`H@("`@)VUS<W%L)R`@/3X@)T))5"<L
M"B`@("`G;7ES<6PG("`]/B`G5$E.64E.5"@Q*2<L"B`@("`G;7ES<6QI)R`]
M/B`G5$E.64E.5"@Q*2<L"B`@("`G;V-I."<@("`]/B`G3E5-0D52*#$I)RP*
M("`@("=O9&)C)R`@(#T^("=334%,3$E.5"<L"B`@("`G<&=S<6PG("`]/B`G
M0D]/3$5!3B<L"B`@("`G<W%L:71E)R`]/B`G24Y414=%4B<L"B`@("`G<WEB
M87-E)R`]/B`G5$E.64E.5"<L"BD["@HO+R!A9&IU<W0@=&AI;F=S(&9O<B!S
M<&5C:69I8R!$0DU3)W,*"FEF("@D9&)H+3YP:'!T>7!E(#T]("=O9&)C)RD@
M>PH@("`@:68@*"1D8F@M/F1B<WEN=&%X(#T]("=O9&)C)RD@>PH@("`@("`@
M("1T>7!E(#T@)&1B:"T^<&AP='EP93L*("`@('T@96QS92!["B`@("`@("`@
M)'1Y<&4@/2`D9&)H+3YD8G-Y;G1A>#L*("`@('T*?2!E;'-E('L*("`@("1T
M>7!E(#T@)&1B:"T^<&AP='EP93L*?0H*<W=I=&-H("@D='EP92D@>PH@("`@
M8V%S92`G86-C97-S)SH*("`@("`@("`D9&5C:6UA;"`]("=324Y'3$4G.PH@
M("`@("`@("1N=6QL(#T@)R<["B`@("`@("`@)&-H<B`@/2`G5D%20TA!4B@X
M*2<["B`@("`@("`@)&ED96YT:69I97(@/2`G<5QU="`B9&YT)SL*("`@("`@
M("!B<F5A:SL*("`@(&-A<V4@)V1B,B<Z"B`@("!C87-E("=I8F%S92<Z"B`@
M("`@("`@)&1E8VEM86P@/2`G1$5#24U!3"@S+#$I)SL*("`@("`@("`D;G5L
M;"`]("<G.PH@("`@("`@("1C:'(@(#T@)U9!4D-(05(H."DG.PH@("`@("`@
M("1I9&5N=&EF:65R(#T@)W%<=71=(")D;EMT)SL*("`@("`@("!B<F5A:SL*
M("`@(&-A<V4@)VEF>"<Z"B`@("`@("`@+R\@9&]I;F<@=&AI<R!F;W(@:69X
M('1O(&ME97`@8V5R=&%I;B!V97)S:6]N<R!H87!P>0H@("`@("`@("1D96-I
M;6%L(#T@)T1%0TE-04PH,RPQ*2<["B`@("`@("`@)&YU;&P@/2`G)SL*("`@
M("`@("`D8VAR("`]("=#2$%2*#@I)SL*("`@("`@("`D:61E;G1I9FEE<B`]
M("<G.PH@("`@("`@(&)R96%K.PH@("`@8V%S92`G;7-Q;"<Z"B`@("`@("`@
M)&1E8VEM86P@/2`G4D5!3"<["B`@("`@("`@)&YU;&P@/2`G)SL*("`@("`@
M("`D8VAR("`]("=#2$%2*#@I)SL*("`@("`@("`D:61E;G1I9FEE<B`]("<G
M.PH@("`@("`@(&)R96%K.PH@("`@8V%S92`G9F)S<6PG.@H@("`@8V%S92`G
M;V-I."<Z"B`@("`@("`@)&1E8VEM86P@/2`G1$5#24U!3"@S+#$I)SL*("`@
M("`@("`D;G5L;"`]("<G.PH@("`@("`@("1C:'(@(#T@)U9!4D-(05(H."DG
M.PH@("`@("`@("1I9&5N=&EF:65R(#T@)W%<=71=(&1N6W0G.PH@("`@("`@
M(&)R96%K.PH@("`@9&5F875L=#H*("`@("`@("`D9&5C:6UA;"`]("=$14-)
M34%,*#,L,2DG.PH@("`@("`@("1N=6QL(#T@)TY53$PG.PH@("`@("`@("1C
M:'(@(#T@)U9!4D-(05(H."DG.PH@("`@("`@("1I9&5N=&EF:65R(#T@)W%<
M=71=(")D;EMT)SL*?0H*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T52
M4D]27U)%5%523BD["F1R;W!?=&%B;&4H)&1B:"P@)W!E87)Q=6]T92<I.PH*
M"FEF("@D:61E;G1I9FEE<BD@>PH@("`@<W=I=&-H("@D9&)H+3YP:'!T>7!E
M*2!["B`@("`@("`@8V%S92`G<WEB87-E)SH*("`@("`@("`@("`@)')E<R`]
M("1D8F@M/G%U97)Y*"=S970@<75O=&5D7VED96YT:69I97(@;VXG*3L*("`@
M("`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97,I("D@>PH@("`@("`@("`@
M("`@("`@<&4H)')E<RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@9&5F875L=#H*("`@('T*("`@("1C<F5A=&4@/2`D9&)H
M+3YQ=65R>2@B"B`@("`@("`@0U)%051%(%1!0DQ%('!E87)Q=6]T92`H"B`@
M("`@("`@("!N("1D96-I;6%L("1N=6QL+`H@("`@("`@("`@<R`D8VAR("1N
M=6QL+`H@("`@("`@("`@(B`N("1D8F@M/G%U;W1E261E;G1I9FEE<B@D:61E
M;G1I9FEE<BD@+B`B("1D96-I;6%L("1N=6QL+`H@("`@("`@("`@8B![)&)O
M;VQE86Y?8V]L7W1Y<&5;)&1B:"T^<&AP='EP95U]("1N=6QL"B`@("`@("`@
M*0H@("`@(BD["@H@("`@:68@*$1".CII<T5R<F]R*"1C<F5A=&4I("D@>PH@
M("`@("`@('!E*"1C<F5A=&4I.PH@("`@?0H*("`@("1I;F9O(#T@)&1B:"T^
M=&%B;&5);F9O*"=P96%R<75O=&4G*3L*("`@(&EF("A$0CHZ:7-%<G)O<B@D
M:6YF;RD@*2!["B`@("`@("`@:68@*"1I;F9O+3YC;V1E(#T]($1"7T524D]2
M7TY/5%]#05!!0DQ%*2!["B`@("`@("`@("`@('!R:6YT(")';W0@;W5T8V]M
M92!E>'!E8W1E9"!F<F]M(&1E;&EM:71E9"!I9&5N=&EF:65R+EQN(CL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!P<FEN="`B=&%B;&5);F9O*"D@
M9F%I;&5D+EQN(CL*("`@("`@("!]"B`@("!](&5L<V4@>PH@("`@("`@(&EF
M("@D:61E;G1I9FEE<B`]/2`D:6YF;ULR75LG;F%M92==*2!["B`@("`@("`@
M("`@('!R:6YT(")';W0@;W5T8V]M92!E>'!E8W1E9"!F<F]M(&1E;&EM:71E
M9"!I9&5N=&EF:65R+EQN(CL*("`@("`@("`@("`@+R\@<')I;G0@(D-/3%5-
M3B!.04U%($E3.B![)&EN9F];,EU;)VYA;64G77U<;B(["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<')I;G0@(D5X<&5C=&5D(&-O;'5M;B!N86UE
M.B`G)&ED96YT:69I97(G("XN+B`B.PH@("`@("`@("`@("!P<FEN="`B06-T
M=6%L(&-O;'5M;B!N86UE.B`G>R1I;F9O6S)=6R=N86UE)UU])UQN(CL*("`@
M("`@("!]"B`@("!]"@I](&5L<V4@>PH@("`@)&1B:"T^<75E<GDH(@H@("`@
M("`@($-214%412!404),12!P96%R<75O=&4@*`H@("`@("`@("`@;B`D9&5C
M:6UA;"`D;G5L;"P*("`@("`@("`@(',@)&-H<B`D;G5L;"P*("`@("`@("`@
M('!L86EN:61E;G1I9FEE<B`D9&5C:6UA;"`D;G5L;"P*("`@("`@("`@(&(@
M>R1B;V]L96%N7V-O;%]T>7!E6R1D8F@M/G!H<'1Y<&5=?2`D;G5L;`H@("`@
M("`@("D*("`@("(I.PH@("`@<')I;G0@(D=O="!O=71C;VUE(&5X<&5C=&5D
M(&9R;VT@9&5L:6UI=&5D(&ED96YT:69I97(N7&XB.PI]"@H*)&1B:"T^<V5T
M17)R;W)(86YD;&EN9RA014%27T524D]27T-!3$Q"04-++"`G<&4G*3L*"@HD
M<W1R:6YG<R`](&%R<F%Y*`H@("`@(B<B+`H@("`@(EPB(BP*("`@(")<7"(L
M"B`@("`B)2(L"B`@("`B7R(L"B`@("`B)R<B+`H@("`@(EPB7"(B+`H@("`@
M(EQ<7%PB+`H@("`@(EQ<)UQ<)R(L"B`@("`B7%Q<(EQ<7"(B"BD["@HD;G5M
M<R`](&%R<F%Y*`H@("`@,3(N,RP*("`@(#$U+`HI.PH*)&)O;VQS(#T@87)R
M87DH"B`@("!44E5%+`H@("`@1D%,4T4L"BD["@H*96-H;R`B4W1R:6YG(&5S
M8V%P92!T97-T.B`B.PIF;W)E86-H("@D<W1R:6YG<R!A<R`D<RD@>PH@("`@
M)'%U;W1E9"`]("1D8F@M/G%U;W1E4VUA<G0H)',I.PH@("`@)&1B:"T^<75E
M<GDH(DE.4T525"!)3E1/('!E87)Q=6]T92`H<RD@5D%,5453("@D<75O=&5D
M*2(I.PI]"B1D:69F(#T@87)R87E?9&EF9B@D<W1R:6YG<RP@)')E<R`]("1D
M8F@M/F=E=$-O;"@B4T5,14-4(',@1E)/32!P96%R<75O=&4B*2D["FEF("AC
M;W5N="@D9&EF9BD@/B`P*2!["B`@("!E8VAO(")&04E,(CL*("`@('!R:6YT
M7W(H)'-T<FEN9W,I.PH@("`@<')I;G1?<B@D<F5S*3L*?2!E;'-E('L*("`@
M(&5C:&\@(D]+(CL*?0H*)&1B:"T^<75E<GDH(D1%3$5412!&4D]-('!E87)Q
M=6]T92(I.PH*"F5C:&\@(EQN3G5M8F5R(&5S8V%P92!T97-T.B`B.PIF;W)E
M86-H("@D;G5M<R!A<R`D;BD@>PH@("`@)'%U;W1E9"`]("1D8F@M/G%U;W1E
M4VUA<G0H)&XI.PH@("`@)&1B:"T^<75E<GDH(DE.4T525"!)3E1/('!E87)Q
M=6]T92`H;BD@5D%,5453("@D<75O=&5D*2(I.PI]"@HD9&EF9B`](&%R<F%Y
M*"D["B1R97,@/28@)&1B:"T^9V5T0V]L*"=314Q%0U0@;B!&4D]-('!E87)Q
M=6]T92!/4D1%4B!"62!N)RD["F9O<F5A8V@@*"1N=6US(&%S("1K97D@/3X@
M)'9A;"D@>PH@("`@:68@*"1V86P@(3T@)')E<ULD:V5Y72D@>PH@("`@("`@
M("1D:69F6UT@/2`B)'9A;"`A/2![)')E<ULD:V5Y77TB.PH@("`@?0I]"@II
M9B`H8V]U;G0H)&1I9F8I(#X@,"D@>PH@("`@96-H;R`B1D%)3%QN(CL*("`@
M('!R:6YT7W(H)&1I9F8I.PI](&5L<V4@>PH@("`@96-H;R`G3TLG.PI]"@HD
M9&)H+3YQ=65R>2@G1$5,151%($923TT@<&5A<G%U;W1E)RD["@H*96-H;R`B
M7&Y";V]L96%N(&5S8V%P92!T97-T.B`B.PHD:2`](#$["F9O<F5A8V@@*"1B
M;V]L<R!A<R`D8BD@>PH@("`@)'%U;W1E9"`]("1D8F@M/G%U;W1E4VUA<G0H
M)&(I.PH@("`@)&1B:"T^<75E<GDH(DE.4T525"!)3E1/('!E87)Q=6]T92`H
M;BP@8BD@5D%,5453("@D:2P@)'%U;W1E9"DB*3L*("`@("1I*RL["GT*"B1D
M:69F(#T@87)R87DH*3L*)')E<R`])B`D9&)H+3YG971#;VPH)U-%3$5#5"!B
M+"!N($923TT@<&5A<G%U;W1E($]21$52($)9(&XG*3L*9F]R96%C:"`H)&)O
M;VQS(&%S("1K97D@/3X@)'9A;"D@>PH@("`@:68@*"1V86P@/3T]('1R=64I
M('L*("`@("`@("!I9B`H)')E<ULD:V5Y72`]/2`Q('Q\("1R97-;)&ME>5T@
M/3T@=')U92!\?`H@("`@("`@("`@("!S=6)S='(H<W1R=&]L;W=E<B@D<F5S
M6R1K97E=*2P@,"P@,2D@/3T@)W0G*0H@("`@("`@('L*("`@("`@("`@("`@
M+R\@9V]O9`H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1D:69F6UT@
M/2`B:6XZ=')U92`A/2!O=70Z>R1R97-;)&ME>5U](CL*("`@("`@("!]"B`@
M("!](&5L<V4@>PH@("`@("`@(&EF("@D<F5S6R1K97E=(#T](#`@?'P@)')E
M<ULD:V5Y72`]/2!F86QS92!\?`H@("`@("`@("`@("!S=6)S='(H<W1R=&]L
M;W=E<B@D<F5S6R1K97E=*2P@,"P@,2D@/3T@)V8G*0H@("`@("`@('L*("`@
M("`@("`@("`@+R\@9V]O9`H@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1D:69F6UT@/2`B:6XZ9F%L<V4@(3T@;W5T.GLD<F5S6R1K97E=?2(["B`@
M("`@("`@?0H@("`@?0I]"@II9B`H8V]U;G0H)&1I9F8I(#X@,"D@>PH@("`@
M96-H;R`B1D%)3%QN(CL*("`@('!R:6YT7W(H)&1I9F8I.PI](&5L<V4@>PH@
M("`@96-H;R`B3TM<;B(["GT*"@HD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%
M05)?15)23U)?4D5455).*3L*9')O<%]T86)L92@D9&)H+"`G<&5A<G%U;W1E
M)RD["@H_/@HM+4584$5#5"TM"D=O="!O=71C;VUE(&5X<&5C=&5D(&9R;VT@
M9&5L:6UI=&5D(&ED96YT:69I97(N"E-T<FEN9R!E<V-A<&4@=&5S=#H@3TL*
M3G5M8F5R(&5S8V%P92!T97-T.B!/2PI";V]L96%N(&5S8V%P92!T97-T.B!/
M2PH`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O
M,39T86)L96EN9F\N<&AP=```````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,3`V-C(S(#$P-3$U
M-#,S-S,R(#`R-34W,``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````M+51%4U0M+0I$0E]D<FEV97(Z.G1A8FQE26YF;PHM+4E.
M22TM"F5R<F]R7W)E<&]R=&EN9R`](#(P-#<*+2U32TE0248M+0H\/W!H<`H*
M+RHJ"B`J($-A;&QS('1A8FQE26YF;R@I(&EN('9A<FEO=7,@=V%Y<R!A;F0@
M8VAE8VMS('1O('-E92!T:&%T('1H92!O=71P=70*("H@;6%T8VAE<R!W:&%T
M)W,@97AP96-T960N"B`J"B`J(%1H97-E('1E<W1S(&%C8V]U;G0@9F]R(&5A
M8V@@1$)-4R!U<VEN9R!D:69F97)E;G0@8V]L=6UN('1Y<&5S(&%N9`H@*B!R
M97!O<G1I;F<@8F%C:R!D:69F97)E;G0@:6YF;W)M871I;VXN("!4:&5S92!D
M:69F97)E;F-E<R!A<F4@86-C;W5N=&5D"B`J(&9O<B!I;B!T:&4@/'9A<CXD
M<75I<FMS/"]V87(^(&%R<F%Y+"!W:&EC:"!H87,@=&AE(&9O;&QO=VEN9R!F
M;W)M870Z"B`J"B`J(#QP<F4^"B`J("=D<FEV97(G(#T^(&%R<F%Y*`H@*B`@
M("`@)V-L;V(G(#T^($1"35,G<R!C;VQU;6X@='EP92!F;W(@8W)E871I;F<@
M0TQ/0B!F:65L9',*("H@("`@("=D871E)R`]/B!$0DU3)W,@8V]L=6UN('1Y
M<&4@9F]R(&-R96%T:6YG($1!5$4@9FEE;&1S"B`J("`@("`G9&%T96QI=&5R
M86PG(#T^(%1H92!344P@:V5Y=V]R9"!N96-E<W-A<GD@9F]R(&1E9FEN:6YG
M(&1A=&5S"B`J("`@("`G9FEN9'-?=&%B;&4G(#T^($-A;B!T:&ES($1"35,@
M9&5T97)M:6YE('1A8FQE(&YA;65S(&9R;VT@<75E<FEE<S\*("H@("`@("=S
M:7IE7V9R;VU?=&%B;&4G(#T^($1O97,@=&AI<R!$0DU3(&MN;W<@=&AE(&-O
M;'5M;B!S:7IE('9I82!T86)L92!N86UE/PH@*B`@("`@)VAA;F1L97-?<F5S
M=6QT<R<@/3X@0V%N('1H92!$0DU3(&=E="!I;F9O(&9R;VT@<75E<GD@<F5S
M=6QT<S\*("H@("`@("=C;VUM86YD<R<@/3X@87)R87DH"B`J("`@("`@("`@
M17AT<F$@8V]M;6%N9',@=&\@8F4@<&%S<V5D('1O(%!(4"=S(&5V86PH*2!F
M=6YC=&EO;@H@*B`@("`@*0H@*B`@("`@,"`]/B!A<G)A>2@*("H@("`@("`@
M("`O+R`@26YF;R!E>'!E8W1E9"!T;R!B92!R97!O<G1E9"!F;W(@<&AP=&5S
M=%]F:RYA"B`J("`@("`@("`@+R\@("A)3E1%1T52($Y/5"!.54Q,*2`H54Y)
M455%($M%62!W:71H(&0I"B`J("`@("`@("`@)W1Y<&4G(#T^($-O;'5M;B!T
M>7!E(')E<&]R=&5D(&)Y('1H92!$0DU3"B`J("`@("`@("`@)VQE;B<@/3X@
M0V]L=6UN('-I>F4@<F5P;W)T960@8GD@=&AE($1"35,*("H@("`@("`@("`G
M9FQA9W,G(#T^($9L86=S(')E<&]R=&5D(&)Y('1H92!$0DU3"B`J("`@("`I
M"B`J("`@("`Q(#T^(&%R<F%Y*"D@($EN9F\@97AP96-T960@=&\@8F4@<F5P
M;W)T960@9F]R('!H<'1E<W1?9FLN9FL*("H@("`@("`@("`@("`@("`@("`@
M*$E.5$5'15(@3D]4($Y53$PI("A04DE-05)9($M%62D*("H@("`@(#(@/3X@
M87)R87DH*2`@26YF;R!E>'!E8W1E9"!T;R!B92!R97!O<G1E9"!F;W(@<&AP
M=&5S=%]F:RYC"B`J("`@("`@("`@("`@("`@("`@("A#3$]"+T-(05(O5D%2
M0TA!4B!.54Q,*0H@*B`@("`@,R`]/B!A<G)A>2@I("!);F9O(&5X<&5C=&5D
M('1O(&)E(')E<&]R=&5D(&9O<B!P:'!T97-T7V9K+F0*("H@("`@("`@("`@
M("`@("`@("`@*$1!5$4@3D]4($Y53$PI("A53DE1544@2T59('=I=&@@82D*
M("H@("`@(#0@/3X@87)R87DH*2`@26YF;R!E>'!E8W1E9"!T;R!B92!R97!O
M<G1E9"!F;W(@<&AP=&5S=%]F:RYE"B`J("`@("`@("`@("`@("`@("`@("A#
M2$%2*#(I($1%1D%53%0@)R!E)R!.3U0@3E5,3"D*("H@("`@(#4@/3X@87)R
M87DH*2`@26YF;R!E>'!E8W1E9"!T;R!B92!R97!O<G1E9"!F;W(@<&AP=&5S
M=%]F:RYF"B`J("`@("`@("`@("`@("`@("`@("A$14-)34%,*#(L,2D@3E5,
M3"D*("H@("`@(#D@/3X@87)R87DH*2`@26YF;R!E>'!E8W1E9"!T;R!B92!R
M97!O<G1E9"!F;W(@<&AP=&5S="YD"B`J("`@("`@("`@("`@("`@("`@("A6
M05)#2$%2*#(P*2!.54Q,*0H@*B`I"B`J(#PO<')E/@H@*@H@*B!`8V%T96=O
M<GD@1&%T86)A<V4*("H@0'!A8VMA9V4@($1""B`J($!V97)S:6]N("`D260Z
M(#$V=&%B;&5I;F9O+G!H<'0L=B`Q+C,R(#(P,#4O,#(O,30@,3<Z,#0Z,3<@
M9&%N:65L8R!%>'`@)`H@*B!`875T:&]R("`@1&%N:65L($-O;G9I<W-O<B`\
M9&%N:65L8T!A;F%L>7-I<V%N9'-O;'5T:6]N<RYC;VT^"B`J($!S964@("`@
M("!$0E]C;VUM;VXZ.G1A8FQE26YF;R@I"B`J+PH*97)R;W)?<F5P;W)T:6YG
M*$5?04Q,*3L*8VAD:7(H9&ER;F%M92A?7T9)3$5?7RDI.PIR97%U:7)E7V]N
M8V4@)RXO<VMI<&EF+FEN8R<["B1T86)L94EN9F\@/2`D9&(M/G1A8FQE26YF
M;R@G86IK9'-L9F%J;VEJ:V%D:64G*3L*:68@*$1".CII<T5R<F]R*"1T86)L
M94EN9F\I("8F("1T86)L94EN9F\M/F-O9&4@/3T@1$)?15)23U)?3D]47T-!
M4$%"3$4I('L*("`@(&1I92@B<VMI<"`D=&%B;&5);F9O+3YM97-S86=E(BD[
M"GT*"C\^"BTM1DE,12TM"CP_<&AP"@HO+R`@)$ED.B`Q-G1A8FQE:6YF;RYP
M:'!T+'8@,2XS,B`R,#`U+S`R+S$T(#$W.C`T.C$W(&1A;FEE;&,@17AP("0*
M"B\J*@H@*B!#;VYN96-T('1O('1H92!D871A8F%S92!A;F0@;6%K92!T:&4@
M<&AP=&5S="!T86)L92X*("HO"G)E<75I<F5?;VYC92`G+B]M:W1A8FQE+FEN
M8R<["@HO*BH*("H@3&]C86P@97)R;W(@8V%L;&)A8VL@:&%N9&QE<BX*("H*
M("H@26X@9V5N97)A;"P@:70@<')I;G1S(&]U="!A;B!E<G)O<B!M97-S86=E
M(&%N9"!K:6QL<R!T:&4@<')O8V5S<RX*("H@0G5T('-O;64@97)R;W)S(&%R
M92!E>'!E8W1E9"!A;F0@86QL;W=E9"!T;R!E>&ES="X*("H*("H@0'!A<F%M
M(&]B:F5C="`@)&\@(%!%05(@97)R;W(@;V)J96-T(&%U=&]M871I8V%L;'D@
M<&%S<V5D('1O('1H:7,@;65T:&]D"B`J($!R971U<FX@=F]I9`H@*B!`<V5E
M(%!%05(Z.G-E=$5R<F]R2&%N9&QI;F<H*0H@*B\*9G5N8W1I;VX@<&4H)&\I
M>PH@("`@9VQO8F%L("1D8F@L("1Q=6ER:W,["@H@("`@:68@*"1O+3YG971-
M97-S86=E*"D@/3T@(D1"($5R<F]R.B!C86XG="!D:7-T:6YG=6ES:"!D=7!L
M:6-A=&4@9FEE;&0@;F%M97,B*2!["B`@("`@("`@<')I;G0@(DY/5$E#13H@
M)&1B:"T^<&AP='EP92!C86XG="!D:7-T:6YG=6ES:"!D=7!L:6-A=&4@9FEE
M;&0@;F%M97,B.PH@("`@("`@(')E='5R;CL*("`@('T*"B`@("!I9B`H)&\M
M/F=E=$-O9&4H*2`]/2!$0E]%4E)/4E].3U1?0T%004),12`F)@H@("`@("`@
M("$D<75I<FMS6R1D8F@M/G!H<'1Y<&4@+B`G.B<@+B`D9&)H+3YD8G-Y;G1A
M>%U;)VAA;F1L97-?<F5S=6QT<R==*0H@("`@>PH@("`@("`@(')E='5R;CL*
M("`@('T*"B`@("`D9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?
M4D5455).*3L*("`@(&1R;W!?=&%B;&4H)&1B:"P@)W!H<'1E<W0G*3L*("`@
M(&1R;W!?=&%B;&4H)&1B:"P@)W!H<'1E<W1?9FLG*3L*"B`@("!D:64H)&\M
M/G1O4W1R:6YG*"DI.PI]"@HO*BH*("H@3&]O<"!T:')O=6=H(&%N(&%R<F%Y
M(')E='5R;F5D(&9R;VT@=&%B;&5);F9O*"DL(&-O;7!A<F4@=&AE(&%C='5A
M;`H@*B!C;VYT96YT<R!T;R!T:&4@97AP96-T960@8V]N=&5N=',N("!)9B!T
M:&4@86-T=6%L(')E<W5L=',@;6%T8V@@=&AE"B`J(&5X<&5C=&%T:6]N<RP@
M<V%Y('-O+B`@268@;F]T+"!S87D@<V\@86YD('-H;W<@=&AE(&EN9F]R;6%T
M:6]N+@H@*@H@*B!`<&%R86T@87)R87D@("`D87)R87D@("`@('1H92!A<G)A
M>2!T;R!B92!E>&%M:6YE9`H@*B!`<&%R86T@<W1R:6YG("`D97AP96-T960@
M('1H92!E>'!E8W1E9"!C;VYT96YT<R!O9B!T:&4@87)R87D*("H@0'!A<F%M
M('-T<FEN9R`@)&9I96QD("`@("!F:65L9"!I;F1E>"!N=6UB97(@;V8@)'%U
M<FEK<R!A;F0@=&%B;&4*("H@0'!A<F%M(&)O;VQE86X@)'%U97)Y("`@("!T
M<G5E(&EF(&%R<F%Y(&ES(&9R;VT@82!Q=65R>2!O<B!F86QS92!I9B!A<G)A
M>0H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&ES('1A8FQE26YF;R@I
M"B`J($!R971U<FX@=F]I9`H@*B\*9G5N8W1I;VX@97AA;6EN94%R<F%Y1&%T
M82@D87)R87DL("1E>'!E8W1E9"P@)&9I96QD(#T@9F%L<V4L("1Q=65R>2`]
M('1R=64I('L*("`@(&=L;V)A;"`D9&)H+"`D<75I<FMS.PH*("`@("1Q=6ER
M:U]K97D@/2`D9&)H+3YP:'!T>7!E("X@)SHG("X@)&1B:"T^9&)S>6YT87@[
M"@H@("`@:68@*$1".CII<T5R<F]R*"1A<G)A>2D@)B8@)&%R<F%Y+3YG971#
M;V1E*"D@/3T@1$)?15)23U)?3D]47T-!4$%"3$4I('L*("`@("`@("!P<FEN
M="`B;6%T8VAE9"!E>'!E8W1E9"!R97-U;'1<;B(["B`@("`@("`@<F5T=7)N
M.PH@("`@?0H*("`@(&EF("@A:7-?87)R87DH)&%R<F%Y*2D@>PH@("`@("`@
M('!R:6YT(")4:&ES($1-0E,@9&ED;B=T('!R;V1U8V4@<')O<&5R(')E<W5L
M='-<;B(["B`@("`@("`@<F5T=7)N.PH@("`@?0H*("`@(&EF("AI<U]I;G0H
M)&9I96QD*2D@>PH@("`@("`@("1A<G)A>2`]("1A<G)A>5LD9FEE;&1=.PH@
M("`@?0H*("`@("1A8W1U86P@/2`G)SL*("`@(&9O<F5A8V@@*"1A<G)A>2!A
M<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@(&EF("@D9FEE;&0@(3T](&9A
M;'-E("8F"B`@("`@("`@("`@(&ES<V5T*"1Q=6ER:W-;)'%U:7)K7VME>5U;
M)&9I96QD75LD:V5Y72DI"B`@("`@("`@>PH@("`@("`@("`@("!I9B`H)&ME
M>2`]/2`G9FQA9W,G("8F("1V86QU92`]/2`G)R`F)B`D<75E<GD@)B8*("`@
M("`@("`@("`@("`@("$D<75I<FMS6R1Q=6ER:U]K97E=6R=F:6YD<U]T86)L
M92==*0H@("`@("`@("`@("!["B`@("`@("`@("`@("`@("`D86-T=6%L("X]
M("(D:V5Y("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E7&XB.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@:68@*"1Q=6ER:W-;)'%U
M:7)K7VME>5U;)&9I96QD75LD:V5Y72`]/2`D=F%L=64I('L*("`@("`@("`@
M("`@("`@("`@("`D86-T=6%L("X]("(D:V5Y("XN+B!M871C:&5D(&5X<&5C
M=&5D('9A;'5E7&XB.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("!I9B`H)'9A;'5E(#T](#`*("`@("`@("`@("`@("`@
M("`@("`@("`@)B8@(21Q=6ER:W-;)'%U:7)K7VME>5U;)W-I>F5?9G)O;5]T
M86)L92==*0H@("`@("`@("`@("`@("`@("`@('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&%C='5A;"`N/2`B)&ME>2`N+BX@;6%T8VAE9"!E>'!E8W1E
M9"!V86QU95QN(CL*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D86-T=6%L("X]("(D:V5Y("XN+B!W87,@
M)R1V86QU92<@8G5T('=E(&5X<&5C=&5D("(["B`@("`@("`@("`@("`@("`@
M("`@("`@("1A8W1U86P@+CT@(B=[)'%U:7)K<ULD<75I<FM?:V5Y75LD9FEE
M;&1=6R1K97E=?2=<;B(["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@:68@*"1K97D@/3T@)W1A8FQE)RD@>PH@("`@("`@("`@("`@
M("`@:68@*"1F:65L9"`\/2`U*2!["B`@("`@("`@("`@("`@("`@("`@:68@
M*"1V86QU92`]/2`G<&AP=&5S=%]F:R<I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&%C='5A;"`N/2`B)&ME>2`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V
M86QU95QN(CL*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H)'9A;'5E(#T]("<G("8F("1Q=65R>2`F
M)@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(21Q=6ER:W-;)'%U:7)K
M7VME>5U;)V9I;F1S7W1A8FQE)UTI"B`@("`@("`@("`@("`@("`@("`@("`@
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1A8W1U86P@+CT@(B1K
M97D@+BXN(&UA=&-H960@97AP96-T960@=F%L=65<;B(["B`@("`@("`@("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D86-T=6%L("X]("(D:V5Y("XN+B!W87,@)R1V86QU92<@8G5T('=E
M(&5X<&5C=&5D("=P:'!T97-T7V9K)UQN(CL*("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@:68@*"1V86QU92`]/2`G
M<&AP=&5S="<I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&%C='5A;"`N
M/2`B)&ME>2`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU95QN(CL*("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H)'9A;'5E(#T]("<G("8F("1Q=65R>2`F)@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(21Q=6ER:W-;)'%U:7)K7VME>5U;)V9I;F1S7W1A
M8FQE)UTI"B`@("`@("`@("`@("`@("`@("`@("`@('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1A8W1U86P@+CT@(B1K97D@+BXN(&UA=&-H960@
M97AP96-T960@=F%L=65<;B(["B`@("`@("`@("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D86-T=6%L("X]
M("(D:V5Y("XN+B!W87,@)R1V86QU92<@8G5T('=E(&5X<&5C=&5D("=P:'!T
M97-T7V9K)UQN(CL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1A8W1U86P@+CT@(B1K97D@/3X@
M)'9A;'5E7&XB.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H@("`@
M:68@*"1A8W1U86P@/3T@)&5X<&5C=&5D*2!["B`@("`@("`@<')I;G0@(FUA
M=&-H960@97AP96-T960@<F5S=6QT7&XB.PH@("`@?2!E;'-E('L*("`@("`@
M("!P<FEN="`B1$E$3B=4(&UA=&-H(&5X<&5C=&5D('9A;'5E<RXN+EQN(CL*
M("`@("`@("!P<FEN="`B?GY^?GY^?GY<;D5X<&5C=&5D.EQN)&5X<&5C=&5D
M7&XB.PH@("`@("`@('!R:6YT(")^?GY^7&Y!8W1U86PZ7&XD86-T=6%L7&Y^
M?GY^?GY^?EQN7&XB.PH@("`@?0I]"@HO*BH*("H@3&]O<"!T:')O=6=H(&%N
M(&%R<F%Y(&]F('1A8FQE(&EN9F\@9&%T82!A;F0@<F5T=7)N('1H92!R97-U
M;'1S+@H@*@H@*B!`<&%R86T@87)R87D@("1A<G)A>2`@=&AE(&%R<F%Y('1O
M(&)E(&5X86UI;F5D"B`J($!R971U<FX@<W1R:6YG"B`J+PIF=6YC=&EO;B!R
M971U<FY!<G)A>41A=&$H)&%R<F%Y*2!["B`@("!G;&]B86P@)&1B:"P@)'%U
M:7)K<SL*"B`@("`D<75I<FM?:V5Y(#T@)&1B:"T^<&AP='EP92`N("<Z)R`N
M("1D8F@M/F1B<WEN=&%X.PH*("`@(&EF("@A)'%U:7)K<ULD<75I<FM?:V5Y
M75LG:&%N9&QE<U]R97-U;'1S)UTI('L*("`@("`@("!R971U<FX@(EQN(CL*
M("`@('T*"B`@("`D;W5T(#T@)R<["B`@("!F;W)E86-H("@D87)R87D@87,@
M)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`D;W5T("X]("(D:V5Y(#T^("1V
M86QU95QN(CL*("`@('T*("`@(')E='5R;B`D;W5T.PI]"@H*)&1B:"T^<V5T
M17)R;W)(86YD;&EN9RA014%27T524D]27T-!3$Q"04-++"`G<&4G*3L*"@HD
M<75I<FMS(#T@87)R87DH"B`@("`G9F)S<6PZ9F)S<6PG(#T^(&%R<F%Y*`H@
M("`@("`@("=C;&]B)R`]/B`G0TA!4B@R.2DG+`H@("`@("`@("=D871E)R`]
M/B`G1$%412<L"B`@("`@("`@)V1A=&5L:71E<F%L)R`]/B`G($1!5$4@)RP*
M("`@("`@("`G9FEN9'-?=&%B;&4G(#T^(&9A;'-E+`H@("`@("`@("=S:7IE
M7V9R;VU?=&%B;&4G(#T^(&9A;'-E+`H@("`@("`@("=H86YD;&5S7W)E<W5L
M=',G(#T^('1R=64L"B`@("`@("`@)V-O;6UA;F1S)R`]/B!A<G)A>2@*("`@
M("`@("`I+`H@("`@("`@(#`@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E
M)R`]/B`G24Y414=%4B<L"B`@("`@("`@("`@("=L96XG(#T^(#`L"B`@("`@
M("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("`@("`Q(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)TE.5$5'15(G+`H@("`@
M("`@("`@("`G;&5N)R`]/B`P+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=N
M;W1?;G5L;"<L"B`@("`@("`@*2P*("`@("`@("`R(#T^(&%R<F%Y*`H@("`@
M("`@("`@("`G='EP92<@/3X@)T-(05)!0U1%4B<L"B`@("`@("`@("`@("=L
M96XG(#T^(#(Y+`H@("`@("`@("`@("`G9FQA9W,G(#T^("<G+`H@("`@("`@
M("DL"B`@("`@("`@,R`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^
M("=$051%)RP*("`@("`@("`@("`@)VQE;B<@/3X@,"P*("`@("`@("`@("`@
M)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@("`@(#0@/3X@87)R87DH
M"B`@("`@("`@("`@("=T>7!E)R`]/B`G0TA!4D%#5$52)RP*("`@("`@("`@
M("`@)VQE;B<@/3X@,BP*("`@("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@
M("`@("`I+`H@("`@("`@(#4@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E
M)R`]/B`G1$5#24U!3"<L"B`@("`@("`@("`@("=L96XG(#T^(#`L"B`@("`@
M("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("`@("`Y(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)T-(05)!0U1%4B<L"B`@
M("`@("`@("`@("=L96XG(#T^(#(P+`H@("`@("`@("`@("`G9FQA9W,G(#T^
M("<G+`H@("`@("`@("DL"B`@("`I+`H*("`@("=I8F%S93II8F%S92<@/3X@
M87)R87DH"B`@("`@("`@)V-L;V(G(#T^("=605)#2$%2*#4P*2<L"B`@("`@
M("`@)V1A=&4G(#T^("=$051%)RP*("`@("`@("`G9&%T96QI=&5R86PG(#T^
M("<G+`H@("`@("`@("=F:6YD<U]T86)L92<@/3X@9F%L<V4L"B`@("`@("`@
M)W-I>F5?9G)O;5]T86)L92<@/3X@9F%L<V4L"B`@("`@("`@)VAA;F1L97-?
M<F5S=6QT<R<@/3X@=')U92P*("`@("`@("`G8V]M;6%N9',G(#T^(&%R<F%Y
M*`H@("`@("`@("DL"B`@("`@("`@,"`]/B!A<G)A>2@*("`@("`@("`@("`@
M)W1Y<&4G(#T^("=)3E1%1T52)RP*("`@("`@("`@("`@)VQE;B<@/3X@-"P*
M("`@("`@("`@("`@)V9L86=S)R`]/B`G=6YI<75E7VME>2!N;W1?;G5L;"<L
M"B`@("`@("`@*2P*("`@("`@("`Q(#T^(&%R<F%Y*`H@("`@("`@("`@("`G
M='EP92<@/3X@)TE.5$5'15(G+`H@("`@("`@("`@("`G;&5N)R`]/B`T+`H@
M("`@("`@("`@("`G9FQA9W,G(#T^("=P<FEM87)Y7VME>2!N;W1?;G5L;"<L
M"B`@("`@("`@*2P*("`@("`@("`R(#T^(&%R<F%Y*`H@("`@("`@("`@("`G
M='EP92<@/3X@)U9!4D-(05(G+`H@("`@("`@("`@("`G;&5N)R`]/B`U,"P*
M("`@("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@("`@
M(#,@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G1$%412<L"B`@
M("`@("`@("`@("=L96XG(#T^(#0L"B`@("`@("`@("`@("=F;&%G<R<@/3X@
M)W5N:7%U95]K97D@;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@-"`]
M/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=#2$%2)RP*("`@("`@
M("`@("`@)VQE;B<@/3X@,BP*("`@("`@("`@("`@)V9L86=S)R`]/B`G;F]T
M7VYU;&P@9&5F875L="<L"B`@("`@("`@*2P*("`@("`@("`U(#T^(&%R<F%Y
M*`H@("`@("`@("`@("`G='EP92<@/3X@)TY5345224,H.2PQ*2<L"B`@("`@
M("`@("`@("=L96XG(#T^(#0L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L
M"B`@("`@("`@*2P*("`@("`@("`Y(#T^(&%R<F%Y*`H@("`@("`@("`@("`G
M='EP92<@/3X@)U9!4D-(05(G+`H@("`@("`@("`@("`G;&5N)R`]/B`R,"P*
M("`@("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@*2P*
M"B`@("`G:6)A<V4Z9FER96)I<F0G(#T^(&%R<F%Y*`H@("`@("`@("=C;&]B
M)R`]/B`G5D%20TA!4B@U,"DG+`H@("`@("`@("=D871E)R`]/B`G1$%412<L
M"B`@("`@("`@)V1A=&5L:71E<F%L)R`]/B`G)RP*("`@("`@("`G9FEN9'-?
M=&%B;&4G(#T^(&9A;'-E+`H@("`@("`@("=S:7IE7V9R;VU?=&%B;&4G(#T^
M(&9A;'-E+`H@("`@("`@("=H86YD;&5S7W)E<W5L=',G(#T^('1R=64L"B`@
M("`@("`@)V-O;6UA;F1S)R`]/B!A<G)A>2@*("`@("`@("`I+`H@("`@("`@
M(#`@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G24Y414=%4B<L
M"B`@("`@("`@("`@("=L96XG(#T^(#0L"B`@("`@("`@("`@("=F;&%G<R<@
M/3X@)W5N:7%U95]K97D@;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@
M,2`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=)3E1%1T52)RP*
M("`@("`@("`@("`@)VQE;B<@/3X@-"P*("`@("`@("`@("`@)V9L86=S)R`]
M/B`G<')I;6%R>5]K97D@;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@
M,B`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=605)#2$%2)RP*
M("`@("`@("`@("`@)VQE;B<@/3X@-3`L"B`@("`@("`@("`@("=F;&%G<R<@
M/3X@)R<L"B`@("`@("`@*2P*("`@("`@("`S(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`G='EP92<@/3X@)T1!5$4G+`H@("`@("`@("`@("`G;&5N)R`]/B`T
M+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=U;FEQ=65?:V5Y(&YO=%]N=6QL
M)RP*("`@("`@("`I+`H@("`@("`@(#0@/3X@87)R87DH"B`@("`@("`@("`@
M("=T>7!E)R`]/B`G0TA!4B<L"B`@("`@("`@("`@("=L96XG(#T^(#(L"B`@
M("`@("`@("`@("=F;&%G<R<@/3X@)VYO=%]N=6QL(&1E9F%U;'0G+`H@("`@
M("`@("DL"B`@("`@("`@-2`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G
M(#T^("=.54U%4DE#*#DL,2DG+`H@("`@("`@("`@("`G;&5N)R`]/B`T+`H@
M("`@("`@("`@("`G9FQA9W,G(#T^("<G+`H@("`@("`@("DL"B`@("`@("`@
M.2`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=605)#2$%2)RP*
M("`@("`@("`@("`@)VQE;B<@/3X@,C`L"B`@("`@("`@("`@("=F;&%G<R<@
M/3X@)R<L"B`@("`@("`@*2P*("`@("DL"@H@("`@)VEF>#II9G@G(#T^(&%R
M<F%Y*`H@("`@("`@("=C;&]B)R`]/B`G0TA!4B@R.2DG+`H@("`@("`@("=D
M871E)R`]/B`G0TA!4B@Q,"DG+`H@("`@("`@("=D871E;&ET97)A;"<@/3X@
M)R<L"B`@("`@("`@)V9I;F1S7W1A8FQE)R`]/B!F86QS92P*("`@("`@("`G
M<VEZ95]F<F]M7W1A8FQE)R`]/B!F86QS92P*("`@("`@("`G:&%N9&QE<U]R
M97-U;'1S)R`]/B!T<G5E+`H@("`@("`@("=C;VUM86YD<R<@/3X@87)R87DH
M"B`@("`@("`@*2P*("`@("`@("`P(#T^(&%R<F%Y*`H@("`@("`@("`@("`G
M='EP92<@/3X@)U-13$E.5"<L"B`@("`@("`@("`@("=L96XG(#T^(#0L"B`@
M("`@("`@("`@("=F;&%G<R<@/3X@)VYO=%]N=6QL)RP*("`@("`@("`I+`H@
M("`@("`@(#$@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G4U%,
M24Y4)RP*("`@("`@("`@("`@)VQE;B<@/3X@-"P*("`@("`@("`@("`@)V9L
M86=S)R`]/B`G;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@,B`]/B!A
M<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=344Q#2$%2)RP*("`@("`@
M("`@("`@)VQE;B<@/3X@,CDL"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L
M"B`@("`@("`@*2P*("`@("`@("`S(#T^(&%R<F%Y*`H@("`@("`@("`@("`G
M='EP92<@/3X@)U-13$-(05(G+`H@("`@("`@("`@("`G;&5N)R`]/B`Q,"P*
M("`@("`@("`@("`@)V9L86=S)R`]/B`G;F]T7VYU;&PG+`H@("`@("`@("DL
M"B`@("`@("`@-"`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=3
M44Q#2$%2)RP*("`@("`@("`@("`@)VQE;B<@/3X@,BP*("`@("`@("`@("`@
M)V9L86=S)R`]/B`G;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@-2`]
M/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=344Q$14-)34%,)RP*
M("`@("`@("`@("`@)VQE;B<@/3X@-3$S+`H@("`@("`@("`@("`G9FQA9W,G
M(#T^("<G+`H@("`@("`@("DL"B`@("`@("`@.2`]/B!A<G)A>2@*("`@("`@
M("`@("`@)W1Y<&4G(#T^("=344Q#2$%2)RP*("`@("`@("`@("`@)VQE;B<@
M/3X@,C`L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*
M("`@("DL"@H@("`@)VUS<6PZ;7-Q;"<@/3X@87)R87DH"B`@("`@("`@)V-L
M;V(G(#T^("=415A4*#(U-2DG+`H@("`@("`@("=D871E)R`]/B`G0TA!4B@Q
M,"DG+`H@("`@("`@("=D871E;&ET97)A;"<@/3X@)R<L"B`@("`@("`@)V9I
M;F1S7W1A8FQE)R`]/B!T<G5E+`H@("`@("`@("=S:7IE7V9R;VU?=&%B;&4G
M(#T^('1R=64L"B`@("`@("`@)VAA;F1L97-?<F5S=6QT<R<@/3X@=')U92P*
M("`@("`@("`G8V]M;6%N9',G(#T^(&%R<F%Y*`H@("`@("`@("DL"B`@("`@
M("`@,"`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=I;G0G+`H@
M("`@("`@("`@("`G;&5N)R`]/B`T+`H@("`@("`@("`@("`G9FQA9W,G(#T^
M("=N;W1?;G5L;"<L"B`@("`@("`@*2P*("`@("`@("`Q(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`G='EP92<@/3X@)VEN="<L"B`@("`@("`@("`@("=L96XG
M(#T^(#0L"B`@("`@("`@("`@("\O(&9O<B!S;VUE(')E87-O;BP@=&AE('5N
M:7%U92!P<F]P97)T>2!A;'=A>7,@8V]N=&%I;G,@,`H@("`@("`@("`@("`O
M+R`G9FQA9W,G(#T^("=U;FEQ=65?:V5Y(&YO=%]N=6QL)RP*("`@("`@("`@
M("`@)V9L86=S)R`]/B`G;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@
M,B`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=T97AT)RP*("`@
M("`@("`@("`@)VQE;B<@/3X@,C4U+`H@("`@("`@("`@("`G9FQA9W,G(#T^
M("<G+`H@("`@("`@("DL"B`@("`@("`@,R`]/B!A<G)A>2@*("`@("`@("`@
M("`@)W1Y<&4G(#T^("=C:&%R)RP*("`@("`@("`@("`@)VQE;B<@/3X@,3`L
M"B`@("`@("`@("`@("=F;&%G<R<@/3X@)VYO=%]N=6QL)RP*("`@("`@("`I
M+`H@("`@("`@(#0@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G
M8VAA<B<L"B`@("`@("`@("`@("=L96XG(#T^(#(L"B`@("`@("`@("`@("=F
M;&%G<R<@/3X@)VYO=%]N=6QL)RP*("`@("`@("`I+`H@("`@("`@(#4@/3X@
M87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G<F5A;"<L"B`@("`@("`@
M("`@("=L96XG(#T^(#@L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@
M("`@("`@*2P*("`@("`@("`Y(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP
M92<@/3X@)V-H87(G+`H@("`@("`@("`@("`G;&5N)R`]/B`R,"P*("`@("`@
M("`@("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@*2P*"B`@("`G
M;7-S<6PZ;7-S<6PG(#T^(&%R<F%Y*`H@("`@("`@("=C;&]B)R`]/B`G5$58
M5"<L"B`@("`@("`@)V1A=&4G(#T^("=334%,3$1!5$5424U%)RP*("`@("`@
M("`G9&%T96QI=&5R86PG(#T^("<G+`H@("`@("`@("=F:6YD<U]T86)L92<@
M/3X@9F%L<V4L"B`@("`@("`@)W-I>F5?9G)O;5]T86)L92<@/3X@9F%L<V4L
M"B`@("`@("`@)VAA;F1L97-?<F5S=6QT<R<@/3X@=')U92P*("`@("`@("`G
M8V]M;6%N9',G(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:6YI7W-E="@B;7-S
M<6PN9&%T971I;65C;VYV97)T(BP@(D]F9B(I.R<L"B`@("`@("`@("`@("<D
M9&)H+3YQ=65R>2@B4T54($1!5$5&3U)-050@>6UD(BD[)RP*("`@("`@("`I
M+`H@("`@("`@(#`@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G
M:6YT)RP*("`@("`@("`@("`@)VQE;B<@/3X@-"P*("`@("`@("`@("`@)V9L
M86=S)R`]/B`G;75L=&EP;&5?:V5Y('5N:7%U95]K97D@;F]T7VYU;&PG+`H@
M("`@("`@("DL"B`@("`@("`@,2`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y
M<&4G(#T^("=I;G0G+`H@("`@("`@("`@("`G;&5N)R`]/B`T+`H@("`@("`@
M("`@("`G9FQA9W,G(#T^("=P<FEM87)Y7VME>2!N;W1?;G5L;"<L"B`@("`@
M("`@*2P*("`@("`@("`R(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@
M/3X@)W1E>'0G+`H@("`@("`@("`@("`G;&5N)R`]/B`T,#DV+`H@("`@("`@
M("`@("`G9FQA9W,G(#T^("<G+`H@("`@("`@("DL"B`@("`@("`@,R`]/B!A
M<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=D871E=&EM92<L"B`@("`@
M("`@("`@("=L96XG(#T^(#0L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)VUU
M;'1I<&QE7VME>2!U;FEQ=65?:V5Y(&YO=%]N=6QL)RP*("`@("`@("`I+`H@
M("`@("`@(#0@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G8VAA
M<B<L"B`@("`@("`@("`@("=L96XG(#T^(#(L"B`@("`@("`@("`@("=F;&%G
M<R<@/3X@)VYO=%]N=6QL)RP*("`@("`@("`I+`H@("`@("`@(#4@/3X@87)R
M87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G<F5A;"<L"B`@("`@("`@("`@
M("=L96XG(#T^(#$Y+`H@("`@("`@("`@("`G9FQA9W,G(#T^("<G+`H@("`@
M("`@("DL"B`@("`@("`@.2`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G
M(#T^("=C:&%R)RP*("`@("`@("`@("`@)VQE;B<@/3X@,C`L"B`@("`@("`@
M("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("DL"@H@("`@)VUY
M<W%L.FUY<W%L)R`]/B!A<G)A>2@*("`@("`@("`G8VQO8B<@/3X@)U1%6%0G
M+`H@("`@("`@("=D871E)R`]/B`G1$%412<L"B`@("`@("`@)V1A=&5L:71E
M<F%L)R`]/B`G)RP*("`@("`@("`G9FEN9'-?=&%B;&4G(#T^('1R=64L"B`@
M("`@("`@)W-I>F5?9G)O;5]T86)L92<@/3X@=')U92P*("`@("`@("`G:&%N
M9&QE<U]R97-U;'1S)R`]/B!T<G5E+`H@("`@("`@("=C;VUM86YD<R<@/3X@
M87)R87DH"B`@("`@("`@*2P*("`@("`@("`P(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`G='EP92<@/3X@)VEN="<L"B`@("`@("`@("`@("=L96XG(#T^(#$Q
M+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=N;W1?;G5L;"!M=6QT:7!L95]K
M97DG+`H@("`@("`@("DL"B`@("`@("`@,2`]/B!A<G)A>2@*("`@("`@("`@
M("`@)W1Y<&4G(#T^("=I;G0G+`H@("`@("`@("`@("`G;&5N)R`]/B`Q,2P*
M("`@("`@("`@("`@)V9L86=S)R`]/B`G;F]T7VYU;&P@<')I;6%R>5]K97DG
M+`H@("`@("`@("DL"B`@("`@("`@,B`]/B!A<G)A>2@*("`@("`@("`@("`@
M)W1Y<&4G(#T^("=B;&]B)RP*("`@("`@("`@("`@)VQE;B<@/3X@-C4U,S4L
M"B`@("`@("`@("`@("=F;&%G<R<@/3X@)V)L;V(G+`H@("`@("`@("DL"B`@
M("`@("`@,R`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=D871E
M)RP*("`@("`@("`@("`@)VQE;B<@/3X@,3`L"B`@("`@("`@("`@("=F;&%G
M<R<@/3X@)VYO=%]N=6QL(&UU;'1I<&QE7VME>2<L"B`@("`@("`@*2P*("`@
M("`@("`T(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)W-T<FEN
M9R<L"B`@("`@("`@("`@("=L96XG(#T^(#(L"B`@("`@("`@("`@("=F;&%G
M<R<@/3X@)VYO=%]N=6QL)RP*("`@("`@("`I+`H@("`@("`@(#4@/3X@87)R
M87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G<F5A;"<L"B`@("`@("`@("`@
M("=L96XG(#T^(#0L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@
M("`@*2P*("`@("`@("`Y(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@
M/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("=L96XG(#T^(#(P+`H@("`@("`@
M("`@("`G9FQA9W,G(#T^("<G+`H@("`@("`@("DL"B`@("`I+`H*("`@("=M
M>7-Q;&DZ;7ES<6QI)R`]/B!A<G)A>2@*("`@("`@("`G8VQO8B<@/3X@)U1%
M6%0G+`H@("`@("`@("=D871E)R`]/B`G1$%412<L"B`@("`@("`@)V1A=&5L
M:71E<F%L)R`]/B`G)RP*("`@("`@("`G9FEN9'-?=&%B;&4G(#T^('1R=64L
M"B`@("`@("`@)W-I>F5?9G)O;5]T86)L92<@/3X@9F%L<V4L"B`@("`@("`@
M)VAA;F1L97-?<F5S=6QT<R<@/3X@=')U92P*("`@("`@("`G8V]M;6%N9',G
M(#T^(&%R<F%Y*`H@("`@("`@("DL"B`@("`@("`@,"`]/B!A<G)A>2@*("`@
M("`@("`@("`@)W1Y<&4G(#T^("=I;G0G+`H@("`@("`@("`@("`G;&5N)R`]
M/B`R+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=N;W1?;G5L;"!M=6QT:7!L
M95]K97D@9W)O=7!?8GDG+`H@("`@("`@("DL"B`@("`@("`@,2`]/B!A<G)A
M>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=I;G0G+`H@("`@("`@("`@("`G
M;&5N)R`]/B`P+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=N;W1?;G5L;"!P
M<FEM87)Y7VME>2!G<F]U<%]B>2<L"B`@("`@("`@*2P*("`@("`@("`R(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)V)L;V(G+`H@("`@("`@
M("`@("`G;&5N)R`]/B`P+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=B;&]B
M)RP*("`@("`@("`I+`H@("`@("`@(#,@/3X@87)R87DH"B`@("`@("`@("`@
M("=T>7!E)R`]/B`G9&%T92<L"B`@("`@("`@("`@("=L96XG(#T^(#$P+`H@
M("`@("`@("`@("`G9FQA9W,G(#T^("=N;W1?;G5L;"!M=6QT:7!L95]K97DG
M+`H@("`@("`@("DL"B`@("`@("`@-"`]/B!A<G)A>2@*("`@("`@("`@("`@
M)W1Y<&4G(#T^("=C:&%R)RP*("`@("`@("`@("`@)VQE;B<@/3X@,"P*("`@
M("`@("`@("`@)V9L86=S)R`]/B`G;F]T7VYU;&PG+`H@("`@("`@("DL"B`@
M("`@("`@-2`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=D96-I
M;6%L)RP*("`@("`@("`@("`@)VQE;B<@/3X@,"P*("`@("`@("`@("`@)V9L
M86=S)R`]/B`G9W)O=7!?8GDG+`H@("`@("`@("DL"B`@("`@("`@.2`]/B!A
M<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=V87)C:&%R)RP*("`@("`@
M("`@("`@)VQE;B<@/3X@,3`L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L
M"B`@("`@("`@*2P*("`@("DL"@H@("`@)V]C:3@Z;V-I."<@/3X@87)R87DH
M"B`@("`@("`@)V-L;V(G(#T^("=#3$]")RP*("`@("`@("`G9&%T92<@/3X@
M)T1!5$4G+`H@("`@("`@("=D871E;&ET97)A;"<@/3X@)R<L"B`@("`@("`@
M)V9I;F1S7W1A8FQE)R`]/B!F86QS92P*("`@("`@("`G<VEZ95]F<F]M7W1A
M8FQE)R`]/B!F86QS92P*("`@("`@("`G:&%N9&QE<U]R97-U;'1S)R`]/B!T
M<G5E+`H@("`@("`@("=C;VUM86YD<R<@/3X@87)R87DH"B`@("`@("`@("`@
M("<D9&)H+3YQ=65R>2@B04Q415(@4T534TE/3B!3150@3DQ37T1!5$5?1D]2
M34%4(#T@7"=965E9+4U-+41$7"<B*3LG+`H@("`@("`@("DL"B`@("`@("`@
M,"`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=.54U"15(G+`H@
M("`@("`@("`@("`G;&5N)R`]/B`R,BP*("`@("`@("`@("`@)V9L86=S)R`]
M/B`G;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@,2`]/B!A<G)A>2@*
M("`@("`@("`@("`@)W1Y<&4G(#T^("=.54U"15(G+`H@("`@("`@("`@("`G
M;&5N)R`]/B`R,BP*("`@("`@("`@("`@)V9L86=S)R`]/B`G;F]T7VYU;&PG
M+`H@("`@("`@("DL"B`@("`@("`@,B`]/B!A<G)A>2@*("`@("`@("`@("`@
M)W1Y<&4G(#T^("=#3$]")RP*("`@("`@("`@("`@)VQE;B<@/3X@-#`P,"P*
M("`@("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@("`@
M(#,@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G1$%412<L"B`@
M("`@("`@("`@("=L96XG(#T^(#<L"B`@("`@("`@("`@("=F;&%G<R<@/3X@
M)VYO=%]N=6QL)RP*("`@("`@("`I+`H@("`@("`@(#0@/3X@87)R87DH"B`@
M("`@("`@("`@("=T>7!E)R`]/B`G0TA!4B<L"B`@("`@("`@("`@("=L96XG
M(#T^(#(L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)VYO=%]N=6QL)RP*("`@
M("`@("`I+`H@("`@("`@(#4@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E
M)R`]/B`G3E5-0D52)RP*("`@("`@("`@("`@)VQE;B<@/3X@,C(L"B`@("`@
M("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("`@("`Y(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)U9!4D-(05(G+`H@("`@
M("`@("`@("`G;&5N)R`]/B`R,"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G
M)RP*("`@("`@("`I+`H@("`@*2P*"B`@("`G;V1B8SIA8V-E<W,G(#T^(&%R
M<F%Y*`H@("`@("`@("=C;&]B)R`]/B`G5$585"<L"B`@("`@("`@)V1A=&4G
M(#T^("=$051%5$E-12<L"B`@("`@("`@)V1A=&5L:71E<F%L)R`]/B`G)RP*
M("`@("`@("`G9FEN9'-?=&%B;&4G(#T^(&9A;'-E+`H@("`@("`@("=S:7IE
M7V9R;VU?=&%B;&4G(#T^(&9A;'-E+`H@("`@("`@("=H86YD;&5S7W)E<W5L
M=',G(#T^('1R=64L"B`@("`@("`@)V-O;6UA;F1S)R`]/B!A<G)A>2@*("`@
M("`@("`I+`H@("`@("`@(#`@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E
M)R`]/B`G24Y414=%4B<L"B`@("`@("`@("`@("=L96XG(#T^(#$P+`H@("`@
M("`@("`@("`G9FQA9W,G(#T^("=N;W1?;G5L;"<L"B`@("`@("`@*2P*("`@
M("`@("`Q(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)TE.5$5'
M15(G+`H@("`@("`@("`@("`G;&5N)R`]/B`Q,"P*("`@("`@("`@("`@)V9L
M86=S)R`]/B`G;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@,B`]/B!A
M<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=,3TY'0TA!4B<L"B`@("`@
M("`@("`@("=L96XG(#T^(#(U-2P*("`@("`@("`@("`@)V9L86=S)R`]/B`G
M)RP*("`@("`@("`I+`H@("`@("`@(#,@/3X@87)R87DH"B`@("`@("`@("`@
M("=T>7!E)R`]/B`G1$%4151)344G+`H@("`@("`@("`@("`G;&5N)R`]/B`Q
M.2P*("`@("`@("`@("`@)V9L86=S)R`]/B`G;F]T7VYU;&PG+`H@("`@("`@
M("DL"B`@("`@("`@-"`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^
M("=605)#2$%2)RP*("`@("`@("`@("`@)VQE;B<@/3X@,BP*("`@("`@("`@
M("`@)V9L86=S)R`]/B`G;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@
M-2`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=$14-)34%,)RP*
M("`@("`@("`@("`@)VQE;B<@/3X@,34L"B`@("`@("`@("`@("=F;&%G<R<@
M/3X@)R<L"B`@("`@("`@*2P*("`@("`@("`Y(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`G='EP92<@/3X@)U9!4D-(05(G+`H@("`@("`@("`@("`G;&5N)R`]
M/B`R,"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@
M("`@*2P*"B`@("`G;V1B8SID8C(G(#T^(&%R<F%Y*`H@("`@("`@("=C;&]B
M)R`]/B`G0TQ/0B<L"B`@("`@("`@)V1A=&4G(#T^("=$051%)RP*("`@("`@
M("`G9&%T96QI=&5R86PG(#T^("<G+`H@("`@("`@("=F:6YD<U]T86)L92<@
M/3X@9F%L<V4L"B`@("`@("`@)W-I>F5?9G)O;5]T86)L92<@/3X@9F%L<V4L
M"B`@("`@("`@)VAA;F1L97-?<F5S=6QT<R<@/3X@=')U92P*("`@("`@("`G
M8V]M;6%N9',G(#T^(&%R<F%Y*`H@("`@("`@("DL"B`@("`@("`@,"`]/B!A
M<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=)3E1%1T52)RP*("`@("`@
M("`@("`@)VQE;B<@/3X@,3`L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)VYO
M=%]N=6QL)RP*("`@("`@("`I+`H@("`@("`@(#$@/3X@87)R87DH"B`@("`@
M("`@("`@("=T>7!E)R`]/B`G24Y414=%4B<L"B`@("`@("`@("`@("=L96XG
M(#T^(#$P+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=N;W1?;G5L;"<L"B`@
M("`@("`@*2P*("`@("`@("`R(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP
M92<@/3X@)T-,3T(G+`H@("`@("`@("`@("`G;&5N)R`]/B`Q,#0X-3<V+`H@
M("`@("`@("`@("`G9FQA9W,G(#T^("<G+`H@("`@("`@("DL"B`@("`@("`@
M,R`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=$051%)RP*("`@
M("`@("`@("`@)VQE;B<@/3X@,3`L"B`@("`@("`@("`@("=F;&%G<R<@/3X@
M)VYO=%]N=6QL)RP*("`@("`@("`I+`H@("`@("`@(#0@/3X@87)R87DH"B`@
M("`@("`@("`@("=T>7!E)R`]/B`G0TA!4B<L"B`@("`@("`@("`@("=L96XG
M(#T^(#(L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)VYO=%]N=6QL)RP*("`@
M("`@("`I+`H@("`@("`@(#4@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E
M)R`]/B`G1$5#24U!3"<L"B`@("`@("`@("`@("=L96XG(#T^(#(L"B`@("`@
M("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("`@("`Y(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)U9!4D-(05(G+`H@("`@
M("`@("`@("`G;&5N)R`]/B`R,"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G
M)RP*("`@("`@("`I+`H@("`@*2P*"B`@("`G<&=S<6PZ<&=S<6PG(#T^(&%R
M<F%Y*`H@("`@("`@("=C;&]B)R`]/B`G5$585"<L"B`@("`@("`@)V1A=&4G
M(#T^("=$051%)RP*("`@("`@("`G9&%T96QI=&5R86PG(#T^("<G+`H@("`@
M("`@("=F:6YD<U]T86)L92<@/3X@9F%L<V4L"B`@("`@("`@)W-I>F5?9G)O
M;5]T86)L92<@/3X@9F%L<V4L"B`@("`@("`@)VAA;F1L97-?<F5S=6QT<R<@
M/3X@=')U92P*("`@("`@("`G8V]M;6%N9',G(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`G)&1B:"T^<75E<GDH(E-%5"!$051%4U193$4@/2!)4T\B*3LG+`H@
M("`@("`@("DL"B`@("`@("`@,"`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y
M<&4G(#T^("=I;G0T)RP*("`@("`@("`@("`@)VQE;B<@/3X@-"P*("`@("`@
M("`@("`@)V9L86=S)R`]/B`G;F]T7VYU;&P@=6YI<75E7VME>2!M=6QT:7!L
M95]K97DG+`H@("`@("`@("DL"B`@("`@("`@,2`]/B!A<G)A>2@*("`@("`@
M("`@("`@)W1Y<&4G(#T^("=I;G0T)RP*("`@("`@("`@("`@)VQE;B<@/3X@
M-"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G;F]T7VYU;&P@<')I;6%R>5]K
M97DG+`H@("`@("`@("DL"B`@("`@("`@,B`]/B!A<G)A>2@*("`@("`@("`@
M("`@)W1Y<&4G(#T^("=T97AT)RP*("`@("`@("`@("`@)VQE;B<@/3X@+3$L
M"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("`@
M("`S(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)V1A=&4G+`H@
M("`@("`@("`@("`G;&5N)R`]/B`T+`H@("`@("`@("`@("`G9FQA9W,G(#T^
M("=N;W1?;G5L;"!U;FEQ=65?:V5Y(&UU;'1I<&QE7VME>2<L"B`@("`@("`@
M*2P*("`@("`@("`T(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@
M)V)P8VAA<B<L"B`@("`@("`@("`@("=L96XG(#T^("TQ+`H@("`@("`@("`@
M("`G9FQA9W,G(#T^("=N;W1?;G5L;"!D969A=6QT7R4R,&4G+`H@("`@("`@
M("DL"B`@("`@("`@-2`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^
M("=N=6UE<FEC)RP*("`@("`@("`@("`@)VQE;B<@/3X@+3$L"B`@("`@("`@
M("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("`@("`Y(#T^(&%R
M<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)W9A<F-H87(G+`H@("`@("`@
M("`@("`G;&5N)R`]/B`M,2P*("`@("`@("`@("`@)V9L86=S)R`]/B`G)RP*
M("`@("`@("`I+`H@("`@*2P*"B`@("`G<W%L:71E.G-Q;&ET92<@/3X@87)R
M87DH"B`@("`@("`@)V-L;V(G(#T^("=#3$]")RP*("`@("`@("`G9&%T92<@
M/3X@)T1!5$4G+`H@("`@("`@("=D871E;&ET97)A;"<@/3X@)R<L"B`@("`@
M("`@)V9I;F1S7W1A8FQE)R`]/B!F86QS92P*("`@("`@("`G<VEZ95]F<F]M
M7W1A8FQE)R`]/B!F86QS92P*("`@("`@("`G:&%N9&QE<U]R97-U;'1S)R`]
M/B!F86QS92P*("`@("`@("`G8V]M;6%N9',G(#T^(&%R<F%Y*`H@("`@("`@
M("DL"B`@("`@("`@,"`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^
M("=)3E1%1T52)RP*("`@("`@("`@("`@)VQE;B<@/3X@,"P*("`@("`@("`@
M("`@)V9L86=S)R`]/B`G;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@
M,2`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=)3E1%1T52)RP*
M("`@("`@("`@("`@)VQE;B<@/3X@,"P*("`@("`@("`@("`@)V9L86=S)R`]
M/B`G<')I;6%R>5]K97D@;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@
M,B`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=#3$]")RP*("`@
M("`@("`@("`@)VQE;B<@/3X@,"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G
M)RP*("`@("`@("`I+`H@("`@("`@(#,@/3X@87)R87DH"B`@("`@("`@("`@
M("=T>7!E)R`]/B`G1$%412<L"B`@("`@("`@("`@("=L96XG(#T^(#`L"B`@
M("`@("`@("`@("=F;&%G<R<@/3X@)VYO=%]N=6QL)RP*("`@("`@("`I+`H@
M("`@("`@(#0@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G0TA!
M4B<L"B`@("`@("`@("`@("=L96XG(#T^(#(L"B`@("`@("`@("`@("=F;&%G
M<R<@/3X@)VYO=%]N=6QL(&1E9F%U;'1?)3(P92<L"B`@("`@("`@*2P*("`@
M("`@("`U(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)T1%0TE-
M04PG+`H@("`@("`@("`@("`G;&5N)R`]/B`R+`H@("`@("`@("`@("`G9FQA
M9W,G(#T^("<G+`H@("`@("`@("DL"B`@("`@("`@.2`]/B!A<G)A>2@*("`@
M("`@("`@("`@)W1Y<&4G(#T^("=605)#2$%2)RP*("`@("`@("`@("`@)VQE
M;B<@/3X@,C`L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@
M*2P*("`@("DL"@H@("`@)W-Y8F%S93IS>6)A<V4G(#T^(&%R<F%Y*`H@("`@
M("`@("=C;&]B)R`]/B`G5$585"<L"B`@("`@("`@)V1A=&4G(#T^("=334%,
M3$1!5$5424U%)RP*("`@("`@("`G9&%T96QI=&5R86PG(#T^("<G+`H@("`@
M("`@("=F:6YD<U]T86)L92<@/3X@9F%L<V4L"B`@("`@("`@)W-I>F5?9G)O
M;5]T86)L92<@/3X@9F%L<V4L"B`@("`@("`@)VAA;F1L97-?<F5S=6QT<R<@
M/3X@=')U92P*("`@("`@("`G8V]M;6%N9',G(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`G)&1B:"T^<75E<GDH(E-%5"!$051%1D]234%4('EM9"(I.R<L"B`@
M("`@("`@*2P*("`@("`@("`P(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP
M92<@/3X@)VEN="<L"B`@("`@("`@("`@("=L96XG(#T^(#$Q+`H@("`@("`@
M("`@("`G9FQA9W,G(#T^("=M=6QT:7!L95]K97D@=6YI<75E7VME>2<L"B`@
M("`@("`@*2P*("`@("`@("`Q(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP
M92<@/3X@)VEN="<L"B`@("`@("`@("`@("=L96XG(#T^(#$Q+`H@("`@("`@
M("`@("`G9FQA9W,G(#T^("=U;FEQ=65?:V5Y)RP*("`@("`@("`I+`H@("`@
M("`@(#(@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G<W1R:6YG
M)RP*("`@("`@("`@("`@)VQE;B<@/3X@,S(W-C@L"B`@("`@("`@("`@("=F
M;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("`@("`S(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`G='EP92<@/3X@)V1A=&5T:6UE)RP*("`@("`@("`@("`@
M)VQE;B<@/3X@,CDL"B`@("`@("`@("`@("=F;&%G<R<@/3X@)VUU;'1I<&QE
M7VME>2!U;FEQ=65?:V5Y)RP*("`@("`@("`I+`H@("`@("`@(#0@/3X@87)R
M87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G<W1R:6YG)RP*("`@("`@("`@
M("`@)VQE;B<@/3X@,BP*("`@("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@
M("`@("`I+`H@("`@("`@(#4@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E
M)R`]/B`G<F5A;"<L"B`@("`@("`@("`@("=L96XG(#T^(#0L"B`@("`@("`@
M("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("`@("`Y(#T^(&%R
M<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)W-T<FEN9R<L"B`@("`@("`@
M("`@("=L96XG(#T^(#(P+`H@("`@("`@("`@("`G9FQA9W,G(#T^("<G+`H@
M("`@("`@("DL"B`@("`I+`HI.PH*"B1Q=6ER:U]K97D@/2`D9&)H+3YP:'!T
M>7!E("X@)SHG("X@)&1B:"T^9&)S>6YT87@["@II9B`H(6ES<V5T*"1Q=6ER
M:W-;)'%U:7)K7VME>5TI*2!["B`@("!D:64H(E1H:7,@=&5S="!D;V5S(&YO
M="!Y970@<W5P<&]R="`D<75I<FM?:V5Y(BD["GT*"FEF("AC;W5N="@D<75I
M<FMS6R1Q=6ER:U]K97E=6R=C;VUM86YD<R==*2D@>PH@("`@9F]R96%C:"`H
M)'%U:7)K<ULD<75I<FM?:V5Y75LG8V]M;6%N9',G72!A<R`D=F%L=64I('L*
M("`@("`@("!E=F%L*"1V86QU92D["B`@("!]"GT*"@HD9&)H+3YQ=65R>2@G
M1$5,151%($923TT@<&AP=&5S="<I.PHD9&)H+3YQ=65R>2@B24Y315)4($E.
M5$\@<&AP=&5S="!604Q515,@*#$L("=O;F4G+"`G3VYE)RP@)S(P,#$M,#(M
M,38G*2(I.PHD9&)H+3YQ=65R>2@B24Y315)4($E.5$\@<&AP=&5S="!604Q5
M15,@*#(L("=T=V\G+"`G5'=O)RP@)S(P,#$M,#(M,34G*2(I.PHD9&)H+3YQ
M=65R>2@B24Y315)4($E.5$\@<&AP=&5S="!604Q515,@*#,L("=T:')E92<L
M("=4:')E92<L("<R,#`Q+3`R+3$T)RDB*3L*"@HD9&)H+3YS971%<G)O<DAA
M;F1L:6YG*%!%05)?15)23U)?4D5455).*3L*9')O<%]T86)L92@D9&)H+"`G
M<&AP=&5S=%]F:R<I.PHD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)2
M3U)?0T%,3$)!0TLL("=P92<I.PH*"FEF("@D<75I<FM?:V5Y(#T]("=O9&)C
M.F%C8V5S<R<I('L*("`@("1D969A=6QT7V4@/2`G)SL*("`@("1D96-I;6%L
M("`@/2`G3E5-15))0R<["GT@96QS96EF("@D<75I<FM?:V5Y(#T]("=M<W%L
M.FUS<6PG*2!["B`@("`D9&5F875L=%]E(#T@)R<["B`@("`D9&5C:6UA;"`@
M(#T@)U)%04PG.PI](&5L<V4@>PH@("`@)&1E9F%U;'1?92`](")$149!54Q4
M("<@92<B.PH@("`@)&1E8VEM86P@("`]("=$14-)34%,*#(L,2DG.PI]"@HO
M+R`D;G5L;"!I<R!S970@:6X@;6MT86)L92YI;F,*"G-W:71C:"`H)&1B:"T^
M<&AP='EP92D@>PH@("`@8V%S92`G;7-Q;"<Z"B`@("`@("`@)&1B:"T^<75E
M<GDH(@H@("`@("`@("`@("!#4D5!5$4@5$%"3$4@<&AP=&5S=%]F:R`H"B`@
M("`@("`@("`@("`@("!A($E.5$5'15(@3D]4($Y53$PL"B`@("`@("`@("`@
M("`@("!F:R!)3E1%1T52($Y/5"!.54Q,+`H@("`@("`@("`@("`@("`@8R![
M)'%U:7)K<ULD<75I<FM?:V5Y75LG8VQO8B==?2`D;G5L;"P*("`@("`@("`@
M("`@("`@(&0@>R1Q=6ER:W-;)'%U:7)K7VME>5U;)V1A=&4G77T@3D]4($Y5
M3$PL"B`@("`@("`@("`@("`@("!E($-(05(H,BD@)&1E9F%U;'1?92!.3U0@
M3E5,3"P*("`@("`@("`@("`@("`@(&8@)&1E8VEM86P@)&YU;&P*("`@("`@
M("`@("`@*0H@("`@("`@("(I.PH@("`@("`@("1D8F@M/G%U97)Y*"=#4D5!
M5$4@54Y)455%($E.1$58(&9K<&L@3TX@<&AP=&5S=%]F:R`H9FLI)RD["B`@
M("`@("`@)&1B:"T^<75E<GDH)T-214%412!53DE1544@24Y$15@@9FMU:R!/
M3B!P:'!T97-T7V9K("AA+"!D*2<I.PH@("`@("`@(&)R96%K.PH@("`@9&5F
M875L=#H*("`@("`@("`D9&)H+3YQ=65R>2@B"B`@("`@("`@("`@($-214%4
M12!404),12!P:'!T97-T7V9K("@*("`@("`@("`@("`@("`@(&$@24Y414=%
M4B!.3U0@3E5,3"P*("`@("`@("`@("`@("`@(&9K($E.5$5'15(@3D]4($Y5
M3$PL"B`@("`@("`@("`@("`@("!C('LD<75I<FMS6R1Q=6ER:U]K97E=6R=C
M;&]B)UU]("1N=6QL+`H@("`@("`@("`@("`@("`@9"![)'%U:7)K<ULD<75I
M<FM?:V5Y75LG9&%T92==?2!.3U0@3E5,3"P*("`@("`@("`@("`@("`@(&4@
M0TA!4B@R*2`D9&5F875L=%]E($Y/5"!.54Q,+`H@("`@("`@("`@("`@("`@
M9B`D9&5C:6UA;"`D;G5L;"P*("`@("`@("`@("`@("`@(%!224U!4ED@2T59
M("AF:RDL"B`@("`@("`@("`@("`@("!53DE1544@*&$L(&0I"B`@("`@("`@
M("`@("D*("`@("`@("`B*3L*?0H*)&1B:"T^<75E<GDH(D-214%412!)3D1%
M6"!T:&5D:61X($].('!H<'1E<W1?9FL@*&0I(BD["B1D8F@M/G%U97)Y*"))
M3E-%4E0@24Y43R!P:'!T97-T7V9K(%9!3%5%4R`H,3`L(#$L("=/;F4G+"(*
M("`@("`@("`@("`@+B`D<75I<FMS6R1Q=6ER:U]K97E=6R=D871E;&ET97)A
M;"==("X@(B<R,#`Q+3`R+3$V)RP@("=C,2<L(#$N,2DB*3L*)&1B:"T^<75E
M<GDH(DE.4T525"!)3E1/('!H<'1E<W1?9FL@5D%,5453("@R,"P@,BP@)U1W
M;R<L(@H@("`@("`@("`@("`N("1Q=6ER:W-;)'%U:7)K7VME>5U;)V1A=&5L
M:71E<F%L)UT@+B`B)S(P,#$M,#(M,34G+"`G8S(G+"`R+C(I(BD["B1D8F@M
M/G%U97)Y*"))3E-%4E0@24Y43R!P:'!T97-T7V9K(%9!3%5%4R`H,S`L(#,L
M("=4:')E92<L(@H@("`@("`@("`@("`N("1Q=6ER:W-;)'%U:7)K7VME>5U;
M)V1A=&5L:71E<F%L)UT@+B`B)S(P,#$M,#(M,30G+"`G8S,G+"`S+C,I(BD[
M"@IF=6YC=&EO;B`F<G5N475E<GDH*2!["B`@("!G;&]B86P@)&1B:"P@)')E
M<W5L=&]B:CL*"B`@("`D<75I<FM?:V5Y(#T@)&1B:"T^<&AP='EP92`N("<Z
M)R`N("1D8F@M/F1B<WEN=&%X.PH*("`@('-W:71C:"`H)'%U:7)K7VME>2D@
M>PH@("`@("`@(&-A<V4@)V]D8F,Z9&(R)SH*("`@("`@("`@("`@+R\@8V%N
M)W0@97AT<F%C="!B;&]B)W,@=&AI<R!W87D@<V\@;6%K92!A(&9A:V4@8V]L
M=6UN"B`@("`@("`@("`@("1Q=65R>2`](")314Q%0U0@<&AP=&5S=%]F:RYA
M+"!P:'!T97-T7V9K+F9K+"`G=&5M<'AY>B<@05,@8RPB"B`@("`@("`@("`@
M("`@("`@("`N("<@<&AP=&5S=%]F:RYD+"!P:'!T97-T7V9K+F4L('!H<'1E
M<W1?9FLN9BPG"B`@("`@("`@("`@("`@("`@("`N("<@<&AP=&5S="YA+"!P
M:'!T97-T+F(L('!H<'1E<W0N8RP@<&AP=&5S="YD)PH@("`@("`@("`@("`@
M("`@("`@+B`G($923TT@<&AP=&5S=%]F:RP@<&AP=&5S="<*("`@("`@("`@
M("`@("`@("`@("X@)R!72$5212!P:'!T97-T+F$@/2!P:'!T97-T7V9K+F9K
M)SL*("`@("`@("`@("`@8G)E86L["B`@("`@("`@8V%S92`G;7-Q;#IM<W%L
M)SH*("`@("`@("`@("`@)'%U97)Y(#T@)U-%3$5#5"!P:'!T97-T7V9K+F$L
M('!H<'1E<W1?9FLN9FLL('!H<'1E<W1?9FLN8RPG"B`@("`@("`@("`@("`@
M("`@("`N("<@<&AP=&5S=%]F:RYD+"!P:'!T97-T7V9K+F4L('!H<'1E<W1?
M9FLN9BPG"B`@("`@("`@("`@("`@("`@("`N("<@<&AP=&5S="YA+"!P:'!T
M97-T+F(L('!H<'1E<W0N8RP@<&AP=&5S="YD)PH@("`@("`@("`@("`@("`@
M("`@+B`G($923TT@<&AP=&5S=%]F:RP@<&AP=&5S="<*("`@("`@("`@("`@
M("`@("`@("X@)R!72$5212!P:'!T97-T+F$@/2!P:'!T97-T7V9K+F9K)SL*
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@9&5F875L=#H*("`@("`@("`@
M("`@)'%U97)Y(#T@)U-%3$5#5"!P:'!T97-T7V9K+F$L('!H<'1E<W1?9FLN
M9FLL('!H<'1E<W1?9FLN8RPG"B`@("`@("`@("`@("`@("`@("`N("<@<&AP
M=&5S=%]F:RYD+"!P:'!T97-T7V9K+F4L('!H<'1E<W1?9FLN9BPG"B`@("`@
M("`@("`@("`@("`@("`N("<@<&AP=&5S="YA+"!P:'!T97-T+F(L('!H<'1E
M<W0N8RP@<&AP=&5S="YD)PH@("`@("`@("`@("`@("`@("`@+B`G($923TT@
M<&AP=&5S=%]F:RP@<&AP=&5S="<*("`@("`@("`@("`@("`@("`@("X@)R!7
M2$5212!P:'!T97-T+F$@/2!P:'!T97-T7V9K+F9K)SL*("`@('T*("`@("1R
M97-U;'1O8FH@/28@)&1B:"T^<75E<GDH)'%U97)Y*3L*("`@(')E='5R;B`D
M<F5S=6QT;V)J.PI]"@H*)&5X<&5C=&5D,#$@/2`G=&%B;&4@+BXN(&UA=&-H
M960@97AP96-T960@=F%L=64*;F%M92`]/B!A"G1Y<&4@+BXN(&UA=&-H960@
M97AP96-T960@=F%L=64*;&5N("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E
M"F9L86=S("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E"B<["@HD97AP96-T
M960P,B`]("=T86)L92`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU90IN86UE
M(#T^(&9K"G1Y<&4@+BXN(&UA=&-H960@97AP96-T960@=F%L=64*;&5N("XN
M+B!M871C:&5D(&5X<&5C=&5D('9A;'5E"F9L86=S("XN+B!M871C:&5D(&5X
M<&5C=&5D('9A;'5E"B<["@HD97AP96-T960P,R`]("=T86)L92`N+BX@;6%T
M8VAE9"!E>'!E8W1E9"!V86QU90IN86UE(#T^(&,*='EP92`N+BX@;6%T8VAE
M9"!E>'!E8W1E9"!V86QU90IL96X@+BXN(&UA=&-H960@97AP96-T960@=F%L
M=64*9FQA9W,@+BXN(&UA=&-H960@97AP96-T960@=F%L=64*)SL*"B1E>'!E
M8W1E9#`T(#T@)W1A8FQE("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E"FYA
M;64@/3X@9`IT>7!E("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E"FQE;B`N
M+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU90IF;&%G<R`N+BX@;6%T8VAE9"!E
M>'!E8W1E9"!V86QU90HG.PH*)&5X<&5C=&5D,#4@/2`G=&%B;&4@+BXN(&UA
M=&-H960@97AP96-T960@=F%L=64*;F%M92`]/B!E"G1Y<&4@+BXN(&UA=&-H
M960@97AP96-T960@=F%L=64*;&5N("XN+B!M871C:&5D(&5X<&5C=&5D('9A
M;'5E"F9L86=S("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E"B<["@HD97AP
M96-T960P-B`]("=T86)L92`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU90IN
M86UE(#T^(&8*='EP92`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU90IL96X@
M+BXN(&UA=&-H960@97AP96-T960@=F%L=64*9FQA9W,@+BXN(&UA=&-H960@
M97AP96-T960@=F%L=64*)SL*"B1E>'!E8W1E9#$P(#T@)W1A8FQE("XN+B!M
M871C:&5D(&5X<&5C=&5D('9A;'5E"FYA;64@/3X@9`IT>7!E("XN+B!M871C
M:&5D(&5X<&5C=&5D('9A;'5E"FQE;B`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V
M86QU90IF;&%G<R`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU90HG.PH*"@IP
M<FEN="`B7&X]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3U<;B(["G!R:6YT(")087-S:6YG(')E<W5L="!/0DI%0U0@=&\@;65T
M:&]D(&EN($1"7SQT>7!E/BY<;B(["G!R:6YT(")/=71P=70@/2!D969A=6QT
M+EQN(CL*<')I;G0@(BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+5QN(CL*)')E<W5L=&]B:B`])B!R=6Y1=65R>2@I.PHD87)R
M87D@/2`D9&)H+3YT86)L94EN9F\H)')E<W5L=&]B:BD["@IP<FEN="`B7&YC
M;VQU;6X@,#I<;B(["F5X86UI;F5!<G)A>41A=&$H)&%R<F%Y+"`D97AP96-T
M960P,2P@,"D["@IP<FEN="`B7&YC;VQU;6X@.3I<;B(["F5X86UI;F5!<G)A
M>41A=&$H)&%R<F%Y+"`D97AP96-T960Q,"P@.2D["@H*<')I;G0@(EQN/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]7&XB.PIP
M<FEN="`B4&%S<VEN9R!R97-U;'0@240@=&\@;65T:&]D(&EN($1"7SQT>7!E
M/BY<;B(["G!R:6YT(")/=71P=70@/2!$0E]404),14E.1D]?3U)$15(N7&XB
M.PIP<FEN="`B+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM7&XB.PHD<F5S=6QT;V)J(#TF(')U;E%U97)Y*"D["B1A<G)A>2`]
M("1D8F@M/G1A8FQE26YF;R@D<F5S=6QT;V)J+3YR97-U;'0L($1"7U1!0DQ%
M24Y&3U]/4D1%4BD["@IP<FEN="`B7&YC;VQU;6X@,#I<;B(["F5X86UI;F5!
M<G)A>41A=&$H)&%R<F%Y+"`D97AP96-T960P,2P@,"D["@IP<FEN="`B7&YC
M;VQU;6X@,SI<;B(["F5X86UI;F5!<G)A>41A=&$H)&%R<F%Y+"`D97AP96-T
M960P-"P@,RD["@IP<FEN="`B7&YN=6U?9FEE;&1S.B`B.PII9B`H)'%U:7)K
M<ULD<75I<FM?:V5Y75LG:&%N9&QE<U]R97-U;'1S)UT@)B8@)&%R<F%Y6R=N
M=6U?9FEE;&1S)UT@/3T@,3`I('L*("`@('!R:6YT(")M871C:&5D(&5X<&5C
M=&5D(')E<W5L=%QN(CL*?2!E;'-E:68@*$1".CII<T5R<F]R*"1A<G)A>2D@
M)B8@)&%R<F%Y+3YG971#;V1E*"D@/3T@1$)?15)23U)?3D]47T-!4$%"3$4I
M('L*("`@('!R:6YT(")M871C:&5D(&5X<&5C=&5D(')E<W5L=%QN(CL*?2!E
M;'-E('L*("`@('!R:6YT(")4:&ES($1-0E,@9&ED;B=T('!R;V1U8V4@<')O
M<&5R(')E<W5L='-<;B(["GT*"G!R:6YT(")<;F]R9&5R.EQN(CL*:68@*"1Q
M=6ER:W-;)'%U:7)K7VME>5U;)VAA;F1L97-?<F5S=6QT<R==("8F(&ES7V%R
M<F%Y*"1A<G)A>5LG;W)D97(G72DI('L*("`@("1E>'!E8W1E9"`]("=A(#T^
M(#8*8B`]/B`W"F,@/3X@.`ID(#T^(#D*92`]/B`T"F8@/3X@-0IF:R`]/B`Q
M"B<["B`@("!K<V]R="@D87)R87E;)V]R9&5R)UTI.PH@("`@97AA;6EN94%R
M<F%Y1&%T82@D87)R87E;)V]R9&5R)UTL("1E>'!E8W1E9"D["GT@96QS96EF
M("A$0CHZ:7-%<G)O<B@D87)R87DI("8F("1A<G)A>2T^9V5T0V]D92@I(#T]
M($1"7T524D]27TY/5%]#05!!0DQ%*2!["B`@("!P<FEN="`B;6%T8VAE9"!E
M>'!E8W1E9"!R97-U;'1<;B(["GT@96QS92!["B`@("!P<FEN="`B5&AI<R!$
M34)3(&1I9&XG="!P<F]D=6-E('!R;W!E<B!R97-U;'1S7&XB.PI]"@H*"G!R
M:6YT(")<;CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/5QN(CL*<')I;G0@(E!A<W-I;F<@1$)?5$%"3$5)3D9/7T]21$525$%"
M3$4@=&\@;65T:&]D(&EN($1"7W)E<W5L="Y<;B(["G!R:6YT(")/=71P=70@
M/2!$0E]404),14E.1D]?3U)$15)404),12Y<;B(["G!R:6YT("(M+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2U<;B(["B1R97-U
M;'1O8FH@/28@<G5N475E<GDH*3L*)&%R<F%Y(#T@)')E<W5L=&]B:BT^=&%B
M;&5);F9O*$1"7U1!0DQ%24Y&3U]/4D1%4E1!0DQ%*3L*+R\@1G)E92!T:&ES
M('1O(&ME97`@:6YT97)B87-E(&AA<'!Y+@HD<F5S=6QT;V)J+3YF<F5E*"D[
M"@IP<FEN="`B7&YC;VQU;6X@,#I<;B(["F5X86UI;F5!<G)A>41A=&$H)&%R
M<F%Y+"`D97AP96-T960P,2P@,"D["@IP<FEN="`B7&YC;VQU;6X@,SI<;B([
M"F5X86UI;F5!<G)A>41A=&$H)&%R<F%Y+"`D97AP96-T960P-"P@,RD["@IP
M<FEN="`B7&YN=6U?9FEE;&1S.B`B.PII9B`H)'%U:7)K<ULD<75I<FM?:V5Y
M75LG:&%N9&QE<U]R97-U;'1S)UT@)B8@)&%R<F%Y6R=N=6U?9FEE;&1S)UT@
M/3T@,3`I('L*("`@('!R:6YT(")M871C:&5D(&5X<&5C=&5D(')E<W5L=%QN
M(CL*?2!E;'-E:68@*$1".CII<T5R<F]R*"1A<G)A>2D@)B8@)&%R<F%Y+3YG
M971#;V1E*"D@/3T@1$)?15)23U)?3D]47T-!4$%"3$4I('L*("`@('!R:6YT
M(")M871C:&5D(&5X<&5C=&5D(')E<W5L=%QN(CL*?2!E;'-E('L*("`@('!R
M:6YT(")4:&ES($1-0E,@9&ED;B=T('!R;V1U8V4@<')O<&5R(')E<W5L='-<
M;B(["GT*"@IP<FEN="`G;W)D97)T86)L95MP:'!T97-T73H@)SL*)&5X<&5C
M=&5D(#T@)V$@/3X@-@IB(#T^(#<*8R`]/B`X"F0@/3X@.0HG.PII9B`H)'%U
M:7)K<ULD<75I<FM?:V5Y75LG:&%N9&QE<U]R97-U;'1S)UT*("`@("8F(&ES
M<V5T*"1A<G)A>5LG;W)D97)T86)L92==6R=P:'!T97-T)UTI*2!["B`@("`D
M86-T=6%L(#T@<F5T=7)N07)R87E$871A*"1A<G)A>5LG;W)D97)T86)L92==
M6R=P:'!T97-T)UTI.PI](&5L<V4@>PH@("`@)&%C='5A;"`]("<G.PI]"FEF
M("@D86-T=6%L(#T]("1E>'!E8W1E9"D@>PH@("`@<')I;G0@(FUA=&-H960@
M97AP96-T960@<F5S=6QT7&XB.PI](&5L<V4@>PH@("`@:68@*"@D<75I<FMS
M6R1Q=6ER:U]K97E=6R=F:6YD<U]T86)L92==(#T]/2!F86QS92`*("`@("`@
M("!\?"!$0CHZ:7-%<G)O<B@D87)R87DI("8F("1A<G)A>2T^9V5T0V]D92@I
M(#T]($1"7T524D]27TY/5%]#05!!0DQ%*0H@("`@("`@("8F("1A8W1U86P@
M/3T@)R<I('L*("`@("`@("!P<FEN="`B;6%T8VAE9"!E>'!E8W1E9"!R97-U
M;'1<;B(["B`@("!](&5L<V4@>PH@("`@("`@('!R:6YT(")$241.)U0@;6%T
M8V@@97AP96-T960@=F%L=65S+BXN7&XB.PH@("`@("`@('!R:6YT(")^?GY^
M?GY^?EQN17AP96-T960Z7&XD97AP96-T961<;B(["B`@("`@("`@<')I;G0@
M(GY^?GY<;D%C='5A;#I<;B1A8W1U86Q<;GY^?GY^?GY^7&Y<;B(["B`@("!]
M"GT*"@IP<FEN="`G;W)D97)T86)L95MP:'!T97-T7V9K73H@)SL*)&5X<&5C
M=&5D(#T@)V$@/3X@,`IF:R`]/B`Q"F,@/3X@,@ID(#T^(#,*92`]/B`T"F8@
M/3X@-0HG.PII9B`H)'%U:7)K<ULD<75I<FM?:V5Y75LG:&%N9&QE<U]R97-U
M;'1S)UT*("`@("8F(&ES<V5T*"1A<G)A>5LG;W)D97)T86)L92==6R=P:'!T
M97-T7V9K)UTI*2!["B`@("`D86-T=6%L(#T@<F5T=7)N07)R87E$871A*"1A
M<G)A>5LG;W)D97)T86)L92==6R=P:'!T97-T7V9K)UTI.PI](&5L<V4@>PH@
M("`@)&%C='5A;"`]("<G.PI]"FEF("@D86-T=6%L(#T]("1E>'!E8W1E9"D@
M>PH@("`@<')I;G0@(FUA=&-H960@97AP96-T960@<F5S=6QT7&XB.PI](&5L
M<V4@>PH@("`@:68@*"@D<75I<FMS6R1Q=6ER:U]K97E=6R=F:6YD<U]T86)L
M92==(#T]/2!F86QS92`*("`@("`@("!\?"!$0CHZ:7-%<G)O<B@D87)R87DI
M("8F("1A<G)A>2T^9V5T0V]D92@I(#T]($1"7T524D]27TY/5%]#05!!0DQ%
M*0H@("`@("`@("8F("1A8W1U86P@/3T@)R<I('L*("`@("`@("!P<FEN="`B
M;6%T8VAE9"!E>'!E8W1E9"!R97-U;'1<;B(["B`@("!](&5L<V4@>PH@("`@
M("`@('!R:6YT(")$241.)U0@;6%T8V@@97AP96-T960@=F%L=65S+BXN7&XB
M.PH@("`@("`@('!R:6YT(")^?GY^?GY^?EQN17AP96-T960Z7&XD97AP96-T
M961<;B(["B`@("`@("`@<')I;G0@(GY^?GY<;D%C='5A;#I<;B1A8W1U86Q<
M;GY^?GY^?GY^7&Y<;B(["B`@("!]"GT*"@IP<FEN="`B7&X]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3U<;B(["G!R:6YT(")0
M87-S:6YG(%1!0DQ%($Y!344@)W!H<'1E<W1?9FLG('1O(&UE=&AO9"!I;B!$
M0E\\9')I=F5R/BY<;B(["G!R:6YT(")/=71P=70@/2!D969A=6QT+EQN(CL*
M<')I;G0@(BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+5QN(CL*)&%R<F%Y(#T@)&1B:"T^=&%B;&5);F9O*"=P:'!T97-T7V9K
M)RD["@IP<FEN="`B7&YC;VQU;6X@,#I<;B(["F5X86UI;F5!<G)A>41A=&$H
M)&%R<F%Y+"`D97AP96-T960P,2P@,"P@9F%L<V4I.PH*<')I;G0@(EQN8V]L
M=6UN(#$Z7&XB.PIE>&%M:6YE07)R87E$871A*"1A<G)A>2P@)&5X<&5C=&5D
M,#(L(#$L(&9A;'-E*3L*"G!R:6YT(")<;F-O;'5M;B`R.EQN(CL*97AA;6EN
M94%R<F%Y1&%T82@D87)R87DL("1E>'!E8W1E9#`S+"`R+"!F86QS92D["@IP
M<FEN="`B7&YC;VQU;6X@,SI<;B(["F5X86UI;F5!<G)A>41A=&$H)&%R<F%Y
M+"`D97AP96-T960P-"P@,RP@9F%L<V4I.PH*<')I;G0@(EQN8V]L=6UN(#0Z
M7&XB.PIE>&%M:6YE07)R87E$871A*"1A<G)A>2P@)&5X<&5C=&5D,#4L(#0L
M(&9A;'-E*3L*"G!R:6YT(")<;F-O;'5M;B`U.EQN(CL*97AA;6EN94%R<F%Y
M1&%T82@D87)R87DL("1E>'!E8W1E9#`V+"`U+"!F86QS92D["@H*<')I;G0@
M(EQN/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M7&XB.PIP<FEN="`B4&%S<VEN9R!404),12!.04U%("=P:'!T97-T7V9K)R!T
M;R!M971H;V0@:6X@1$)?/&1R:79E<CXN7&XB.PIP<FEN="`B3W5T<'5T(#T@
M1$)?5$%"3$5)3D9/7T953$PN7&XB.PIP<FEN="`B+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM7&XB.PHD87)R87D@/2`D9&)H
M+3YT86)L94EN9F\H)W!H<'1E<W1?9FLG+"!$0E]404),14E.1D]?1E5,3"D[
M"@IP<FEN="`B7&YC;VQU;6X@,#I<;B(["F5X86UI;F5!<G)A>41A=&$H)&%R
M<F%Y+"`D97AP96-T960P,2P@,"P@9F%L<V4I.PH*<')I;G0@(EQN;W)D97(Z
M7&XB.PHD97AP96-T(#TG82`]/B`P"F9K(#T^(#$*8R`]/B`R"F0@/3X@,PIE
M(#T^(#0*9B`]/B`U"B<["F5X86UI;F5!<G)A>41A=&$H)&%R<F%Y6R=O<F1E
M<B==+"`D97AP96-T+"!F86QS92P@9F%L<V4I.PH*<')I;G0@(EQN;W)D97)T
M86)L95MP:'!T97-T7V9K73I<;B(["B1E>'!E8W0@/2=A(#T^(#`*9FL@/3X@
M,0IC(#T^(#(*9"`]/B`S"F4@/3X@-`IF(#T^(#4*)SL*97AA;6EN94%R<F%Y
M1&%T82@D87)R87E;)V]R9&5R=&%B;&4G75LG<&AP=&5S=%]F:R==+"`D97AP
M96-T*3L*"@H*<')I;G0@(EQN/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]7&XB.PIP<FEN="`B4&%S<VEN9R!404),12!.04U%
M("=P:'!T97-T7V9K)R!T;R!M971H;V0@:6X@1$)?/&1R:79E<CX@04=!24XN
M7&XB.PIP<FEN="`B3W5T<'5T(#T@1$)?5$%"3$5)3D9/7T953$PL(&QO=V5R
M8V%S:6YG('1U<FYE9"!O9F8N7&XB.PIP<FEN="`B+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM7&XB.PHD9&)H+3YS971/<'1I
M;VXH)W!O<G1A8FEL:71Y)RP@1$)?4$]25$%"24Q)5%E?04Q,(%X@1$)?4$]2
M5$%"24Q)5%E?3$]715)#05-%*3L*)&%R<F%Y(#T@)&1B:"T^=&%B;&5);F9O
M*"=P:'!T97-T7V9K)RP@1$)?5$%"3$5)3D9/7T953$PI.PH*+R\@=&5S=&EN
M9R!N;VXM;&]W97)C87-I;F<@86)O=F4@=&\@96YS=7)E('!R;V=R86T@9&]E
M<VXG="!D:64N"B\O(&QO=V5R8V%S92!T:&4@;F%M97,@:&5R92!T;R!E;G-U
M<F4@=&5S="!U;FEF;W)M:71Y+@HD87)R87E;,%U;)W1A8FQE)UT@/2!S=')T
M;VQO=V5R*"1A<G)A>5LP75LG=&%B;&4G72D["B1A<G)A>5LP75LG;F%M92==
M(#T@<W1R=&]L;W=E<B@D87)R87E;,%U;)VYA;64G72D["@IP<FEN="`B7&YC
M;VQU;6X@,#I<;B(["F5X86UI;F5!<G)A>41A=&$H)&%R<F%Y+"`P+"!F86QS
M92D["@H*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%52
M3BD["F1R;W!?=&%B;&4H)&1B:"P@)W!H<'1E<W0G*3L*9')O<%]T86)L92@D
M9&)H+"`G<&AP=&5S=%]F:R<I.PH*/SX*+2U%6%!%0U0M+0H]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*4&%S<VEN9R!R97-U
M;'0@3T)*14-4('1O(&UE=&AO9"!I;B!$0E\\='EP93XN"D]U='!U="`](&1E
M9F%U;'0N"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+0H*8V]L=6UN(#`Z"FUA=&-H960@97AP96-T960@<F5S=6QT"@IC;VQU
M;6X@.3H*;6%T8VAE9"!E>'!E8W1E9"!R97-U;'0*"CT]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0I087-S:6YG(')E<W5L="!)
M1"!T;R!M971H;V0@:6X@1$)?/'1Y<&4^+@I/=71P=70@/2!$0E]404),14E.
M1D]?3U)$15(N"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+0H*8V]L=6UN(#`Z"FUA=&-H960@97AP96-T960@<F5S=6QT"@IC
M;VQU;6X@,SH*;6%T8VAE9"!E>'!E8W1E9"!R97-U;'0*"FYU;5]F:65L9',Z
M(&UA=&-H960@97AP96-T960@<F5S=6QT"@IO<F1E<CH*;6%T8VAE9"!E>'!E
M8W1E9"!R97-U;'0*"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/0I087-S:6YG($1"7U1!0DQ%24Y&3U]/4D1%4E1!0DQ%('1O
M(&UE=&AO9"!I;B!$0E]R97-U;'0N"D]U='!U="`]($1"7U1!0DQ%24Y&3U]/
M4D1%4E1!0DQ%+@HM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2T*"F-O;'5M;B`P.@IM871C:&5D(&5X<&5C=&5D(')E<W5L=`H*
M8V]L=6UN(#,Z"FUA=&-H960@97AP96-T960@<F5S=6QT"@IN=6U?9FEE;&1S
M.B!M871C:&5D(&5X<&5C=&5D(')E<W5L=`IO<F1E<G1A8FQE6W!H<'1E<W1=
M.B!M871C:&5D(&5X<&5C=&5D(')E<W5L=`IO<F1E<G1A8FQE6W!H<'1E<W1?
M9FM=.B!M871C:&5D(&5X<&5C=&5D(')E<W5L=`H*/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"E!A<W-I;F<@5$%"3$4@3D%-
M12`G<&AP=&5S=%]F:R<@=&\@;65T:&]D(&EN($1"7SQD<FEV97(^+@I/=71P
M=70@/2!D969A=6QT+@HM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2T*"F-O;'5M;B`P.@IM871C:&5D(&5X<&5C=&5D(')E<W5L
M=`H*8V]L=6UN(#$Z"FUA=&-H960@97AP96-T960@<F5S=6QT"@IC;VQU;6X@
M,CH*;6%T8VAE9"!E>'!E8W1E9"!R97-U;'0*"F-O;'5M;B`S.@IM871C:&5D
M(&5X<&5C=&5D(')E<W5L=`H*8V]L=6UN(#0Z"FUA=&-H960@97AP96-T960@
M<F5S=6QT"@IC;VQU;6X@-3H*;6%T8VAE9"!E>'!E8W1E9"!R97-U;'0*"CT]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0I087-S
M:6YG(%1!0DQ%($Y!344@)W!H<'1E<W1?9FLG('1O(&UE=&AO9"!I;B!$0E\\
M9')I=F5R/BX*3W5T<'5T(#T@1$)?5$%"3$5)3D9/7T953$PN"BTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H*8V]L=6UN(#`Z
M"FUA=&-H960@97AP96-T960@<F5S=6QT"@IO<F1E<CH*;6%T8VAE9"!E>'!E
M8W1E9"!R97-U;'0*"F]R9&5R=&%B;&5;<&AP=&5S=%]F:UTZ"FUA=&-H960@
M97AP96-T960@<F5S=6QT"@H]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T*4&%S<VEN9R!404),12!.04U%("=P:'!T97-T7V9K
M)R!T;R!M971H;V0@:6X@1$)?/&1R:79E<CX@04=!24XN"D]U='!U="`]($1"
M7U1!0DQ%24Y&3U]&54Q,+"!L;W=E<F-A<VEN9R!T=7)N960@;V9F+@HM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*"F-O;'5M
M;B`P.@IM871C:&5D(&5X<&5C=&5D(')E<W5L=`H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T
M<R]D<FEV97(O,3=Q=65R>2YP:'!T````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`W
M,S,T(#$P-3$U-#,S-S,R(#`R-#<W,@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````M+51%4U0M+0I$0E]D<FEV97(Z.G%U97)Y
M"BTM24Y)+2T*97)R;W)?<F5P;W)T:6YG(#T@,C`T-PHM+5-+25!)1BTM"CP_
M<&AP"@HO*BH*("H@0V%L;',@=&AE('%U97)Y*"D@;65T:&]D(&EN('9A<FEO
M=7,@=V%Y<R!A9V%I;G-T(&%N>2!$0DU3+@H@*@H@*B!`<V5E("`@("`@1$)?
M8V]M;6]N.CIQ=65R>2@I"B`J(`H@*B!`<&%C:V%G92`@1$(*("H@0'9E<G-I
M;VX@("1)9#H@,3=Q=65R>2YP:'!T+'8@,2XQ,R`R,#`U+S`R+S$V(#$S.C4T
M.C4R(&1A;FEE;&,@17AP("0*("H@0&-A=&5G;W)Y($1A=&%B87-E"B`J($!A
M=71H;W(@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0&%N86QY<VES86YD
M<V]L=71I;VYS+F-O;3X*("H@0&EN=&5R;F%L"B`J+PH*8VAD:7(H9&ER;F%M
M92A?7T9)3$5?7RDI.PIR97%U:7)E7V]N8V4@)RXO<VMI<&EF+FEN8R<["@H_
M/@HM+49)3$4M+0H\/W!H<`H*+R\@)$ED.B`Q-W%U97)Y+G!H<'0L=B`Q+C$S
M(#(P,#4O,#(O,38@,3,Z-30Z-3(@9&%N:65L8R!%>'`@)`H*+RHJ"B`J($-O
M;FYE8W0@=&\@=&AE(&1A=&%B87-E(&%N9"!M86ME('1H92!P:'!T97-T('1A
M8FQE+@H@*B\*<F5Q=6ER95]O;F-E("<N+VUK=&%B;&4N:6YC)SL*"@HO*BH*
M("H@3&]C86P@97)R;W(@8V%L;&)A8VL@:&%N9&QE<BX*("H*("H@1')O<',@
M=&AE('!H<'1E<W0@=&%B;&4L('!R:6YT<R!O=70@86X@97)R;W(@;65S<V%G
M92!A;F0@:VEL;',@=&AE"B`J('!R;V-E<W,N"B`J"B`J($!P87)A;2!O8FIE
M8W0@("1O("!014%2(&5R<F]R(&]B:F5C="!A=71O;6%T:6-A;&QY('!A<W-E
M9"!T;R!T:&ES(&UE=&AO9`H@*B!`<F5T=7)N('9O:60*("H@0'-E92!014%2
M.CIS971%<G)O<DAA;F1L:6YG*"D*("HO"F9U;F-T:6]N('!E*"1O*2!["B`@
M("!G;&]B86P@)&1B:#L*"B`@("`D9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%
M05)?15)23U)?4D5455).*3L*("`@(&1R;W!?=&%B;&4H)&1B:"P@)W!H<'1E
M<W0G*3L*"B`@("!D:64H)&\M/G1O4W1R:6YG*"DI.PI]"@HD9&)H+3YS971%
M<G)O<DAA;F1L:6YG*%!%05)?15)23U)?0T%,3$)!0TLL("=P92<I.PH*"B1D
M8F@M/G-E=$9E=&-H36]D92A$0E]&151#2$U/1$5?05-33T,I.PH*"B1R97,@
M/28@)&1B:"T^<75E<GDH)T1%3$5412!&4D]-('!H<'1E<W0@5TA%4D4@82`]
M(#$W)RD["G!R:6YT("<Q*2!D96QE=&4Z("<@+B`H)')E<R`]/3T@1$)?3TL@
M/R`G;VMA>2<@.B`G97)R;W(G*2`N(")<;B(["@HD<F5S(#TF("1D8F@M/G%U
M97)Y*"))3E-%4E0@24Y43R!P:'!T97-T("AA+"!B+"!C*2!604Q515,@*#$W
M+"`G;VYE)RP@)T]N92<I(BD["G!R:6YT("<R*2!I;G-E<G0Z("<@+B`H)')E
M<R`]/3T@1$)?3TL@/R`G;VMA>2<@.B`G97)R;W(G*2`N(")<;B(["@HD<F5S
M(#TF("1D8F@M/G%U97)Y*"=)3E-%4E0@24Y43R!P:'!T97-T("AA+"!B+"!C
M*2!604Q515,@*#\L(#\L(#\I)RP@87)R87DH,3<L("=T=V\G+"`G5'=O)RDI
M.PIP<FEN="`G,RD@:6YS97)T.B`G("X@*"1R97,@/3T]($1"7T]+(#\@)V]K
M87DG(#H@)V5R<F]R)RD@+B`B7&XB.PH*"B1R97,@/28@)&1B:"T^<75E<GDH
M)U-%3$5#5"!A+"!B($923TT@<&AP=&5S="!72$5212!A(#T@,3<G*3L*)')O
M=R`]("1R97,M/F9E=&-H4F]W*"D["G!R:6YT("(T*2!A(#T@>R1R;W=;)V$G
M77TL(&(@/2![)')O=ULG8B==?5QN(CL*)')E<RT^9G)E92@I.R`@+R\@:V5E
M<"!F8G-Q;"!H87!P>2X*"B1R97,@/28@)&1B:"T^<75E<GDH)U-%3$5#5"!A
M+"!B($923TT@<&AP=&5S="!72$5212!C(#T@/R<L(&%R<F%Y*"=4=V\G*2D[
M"B1R;W<@/2`D<F5S+3YF971C:%)O=R@I.PIP<FEN="`B-2D@82`]('LD<F]W
M6R=A)UU]+"!B(#T@>R1R;W=;)V(G77U<;B(["@H*)&%R<F%Y(#T@87)R87DH
M"B`@("`G9F]O)R`]/B`Q,2P*("`@("=B87(G(#T^("=T:')E92<L"B`@("`G
M8F%Z)R`]/B!N=6QL+`HI.PHD<F5S(#TF("1D8F@M/G%U97)Y*"=)3E-%4E0@
M24Y43R!P:'!T97-T("AA+"!B+"!D*2!604Q515,@*#\L(#\L(#\I)RP@)&%R
M<F%Y*3L*<')I;G0@)S8I(&EN<V5R=#H@)R`N("@D<F5S(#T]/2!$0E]/2R`_
M("=O:V%Y)R`Z("=E<G)O<B<I("X@(EQN(CL*"B1R97,@/28@)&1B:"T^<75E
M<GDH)U-%3$5#5"!A+"!B+"!D($923TT@<&AP=&5S="!72$5212!A(#T@/R<L
M(#$Q*3L*)')O=R`]("1R97,M/F9E=&-H4F]W*"D["G!R:6YT("(W*2!A(#T@
M>R1R;W=;)V$G77TL(&(@/2![)')O=ULG8B==?2P@9"`]("(["FEF("@D9&)H
M+3YP:'!T>7!E(#T]("=M<W%L)RD@>PH@("`@:68@*&%R<F%Y7VME>5]E>&ES
M=',H)V0G+"`D<F]W*2D@>PH@("`@("`@("1T>7!E(#T@9V5T='EP92@D<F]W
M6R=D)UTI.PH@("`@("`@(&EF("@D='EP92`]/2`G3E5,3"<@?'P@)')O=ULG
M9"==(#T]("<G*2!["B`@("`@("`@("`@('!R:6YT(")G;W0@97AP96-T960@
M=F%L=65<;B(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<')I;G0@
M(D524CH@97AP96-T960@9"=S('1Y<&4@=&\@8F4@3E5,3"!B=70@:70G<R`D
M='EP92!A;F0@=&AE('9A;'5E(&ES("(["B`@("`@("`@("`@('!R:6YT("1R
M;W=;)V0G72`N(")<;B(["B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@("`@
M("`O+R!H='1P.B\O8G5G<RYP:'`N;F5T+S]I9#TS,3DV,`H@("`@("`@('!R
M:6YT(")0<FEO<B!T;R!02%`@-"XS+C$Q(&]R(#4N,"XT+"!02%`G<R!M<W%L
M(&5X=&5N<VEO;B!S:6QE;G1L>2(*("`@("`@("`@("`@("`N("(@9')O<'!E
M9"!C;VQU;6YS('=I=&@@;G5L;"!V86QU97,N(%EO=2!N965D('1O('5P9W)A
M9&4N7&XB.PH@("`@?0I](&5L<V4@>PH@("`@)'1Y<&4@/2!G971T>7!E*"1R
M;W=;)V0G72D["B`@("!I9B`H)'1Y<&4@/3T@)TY53$PG('Q\("1R;W=;)V0G
M72`]/2`G)RD@>PH@("`@("`@('!R:6YT(")G;W0@97AP96-T960@=F%L=65<
M;B(["B`@("!](&5L<V4@>PH@("`@("`@('!R:6YT(")%4E(Z(&5X<&5C=&5D
M(&0G<R!T>7!E('1O(&)E($Y53$P@8G5T(&ET)W,@)'1Y<&4@86YD('1H92!V
M86QU92!I<R`B.PH@("`@("`@('!R:6YT("1R;W=;)V0G72`N(")<;B(["B`@
M("!]"GT*"@HD<F5S(#TF("1D8F@M/G%U97)Y*"=$14Q%5$4@1E)/32!P:'!T
M97-T(%=(15)%(&$@/2`_)RP@87)R87DH,3<I*3L*<')I;G0@)S@I(&1E;&5T
M93H@)R`N("@D<F5S(#T]/2!$0E]/2R`_("=O:V%Y)R`Z("=E<G)O<B<I("X@
M(EQN(CL*"B1R97,@/28@)&1B:"T^<75E<GDH)T1%3$5412!&4D]-('!H<'1E
M<W0@5TA%4D4@82`](#\G+"!A<G)A>2@P*2D["G!R:6YT("<Y*2!D96QE=&4@
M=VET:"!A<G)A>2@P*2!A<R!P87)A;3H@)R`N("@D<F5S(#T]/2!$0E]/2R`_
M("=O:V%Y)R`Z("=E<G)O<B<I("X@(EQN(CL*"B1R97,@/28@)&1B:"T^<75E
M<GDH)T1%3$5412!&4D]-('!H<'1E<W0@5TA%4D4@82`](#\G+"`P*3L*<')I
M;G0@)S$P*2!D96QE=&4@=VET:"`P(&%S('!A<F%M.B`G("X@*"1R97,@/3T]
M($1"7T]+(#\@)V]K87DG(#H@)V5R<F]R)RD@+B`B7&XB.PH*"B1D8F@M/G-E
M=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PID<F]P7W1A8FQE
M*"1D8F@L("=P:'!T97-T)RD["@H_/@HM+4584$5#5"TM"C$I(&1E;&5T93H@
M;VMA>0HR*2!I;G-E<G0Z(&]K87D*,RD@:6YS97)T.B!O:V%Y"C0I(&$@/2`Q
M-RP@8B`](&]N90HU*2!A(#T@,3<L(&(@/2!T=V\*-BD@:6YS97)T.B!O:V%Y
M"C<I(&$@/2`Q,2P@8B`]('1H<F5E+"!D(#T@9V]T(&5X<&5C=&5D('9A;'5E
M"C@I(&1E;&5T93H@;VMA>0HY*2!D96QE=&4@=VET:"!A<G)A>2@P*2!A<R!P
M87)A;3H@;VMA>0HQ,"D@9&5L971E('=I=&@@,"!A<R!P87)A;3H@;VMA>0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O,3AG970N<&AP=```````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#,V-#`U(#$P-3$U-#,S-S,R(#`R-#0P-@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````M+51%4U0M
M+0I$0E]D<FEV97(Z.F=E=`HM+4E.22TM"F5R<F]R7W)E<&]R=&EN9R`](#(P
M-#<*+2U32TE0248M+0H\/W!H<`H*+RHJ"B`J($-A;&QS('1H92!G970J*"D@
M;65T:&]D<R!I;B!V87)I;W5S('=A>7,@86=A:6YS="!A;GD@1$)-4RX*("H*
M("H@0'-E92!$0E]#;VUM;VXZ.F=E=$%L;"@I+"!$0E]#;VUM;VXZ.F=E=$%S
M<V]C*"DL($1"7T-O;6UO;CHZ9V5T0V]L*"D*("H@("`@("!$0E]#;VUM;VXZ
M.F=E=$QI<W1/9B@I+"!$0E]#;VUM;VXZ.F=E=$]N92@I+"!$0E]#;VUM;VXZ
M.F=E=%)O=R@I"B`J"B`J($!P86-K86=E("!$0@H@*B!`=F5R<VEO;B`@)$ED
M.B`Q.&=E="YP:'!T+'8@,2XY(#(P,#4O,#(O,30@,C,Z-#<Z-30@9&%N:65L
M8R!%>'`@)`H@*B!`8V%T96=O<GD@1&%T86)A<V4*("H@0&%U=&AO<B`@($1A
M;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`86YA;'ES:7-A;F1S;VQU=&EO;G,N
M8V]M/@H@*B!`:6YT97)N86P*("HO"@IC:&1I<BAD:7)N86UE*%]?1DE,15]?
M*2D["G)E<75I<F5?;VYC92`G+B]S:VEP:68N:6YC)SL*"C\^"BTM1DE,12TM
M"CP_<&AP"@HO+R`D260Z(#$X9V5T+G!H<'0L=B`Q+CD@,C`P-2\P,B\Q-"`R
M,SHT-SHU-"!D86YI96QC($5X<"`D"@HO*BH*("H@0V]N;F5C="!T;R!T:&4@
M9&%T86)A<V4@86YD(&UA:V4@=&AE(#QK8F0^<&AP=&5S=#PO:V)D/B!T86)L
M92X*("HO"G)E<75I<F5?;VYC92`G+B]M:W1A8FQE+FEN8R<["@H*+RHJ"B`J
M($QO8V%L(&5R<F]R(&-A;&QB86-K(&AA;F1L97(N"B`J"B`J($1R;W!S('1H
M92!P:'!T97-T('1A8FQE+"!P<FEN=',@;W5T(&%N(&5R<F]R(&UE<W-A9V4@
M86YD(&MI;&QS('1H90H@*B!P<F]C97-S+@H@*@H@*B!`<&%R86T@;V)J96-T
M("`D;R`@4$5!4B!E<G)O<B!O8FIE8W0@875T;VUA=&EC86QL>2!P87-S960@
M=&\@=&AI<R!M971H;V0*("H@0')E='5R;B!V;VED"B`J($!S964@4$5!4CHZ
M<V5T17)R;W)(86YD;&EN9R@I"B`J+PIF=6YC=&EO;B!P92@D;RE["B`@("!G
M;&]B86P@)&1B:#L*"B`@("`D9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?
M15)23U)?4D5455).*3L*("`@(&1R;W!?=&%B;&4H)&1B:"P@)W!H<'1E<W0G
M*3L*"B`@("!D:64H)&\M/G1O4W1R:6YG*"DI.PI]"@HD9&)H+3YS971%<G)O
M<DAA;F1L:6YG*%!%05)?15)23U)?0T%,3$)!0TLL("=P92<I.PH*"B1D8F@M
M/G%U97)Y*"))3E-%4E0@24Y43R!P:'!T97-T(%9!3%5%4R`H,BP@)W1W;R<L
M("=4=V\G+"`G,C`P,BTP,BTR,B<I(BD["B1D8F@M/G%U97)Y*"))3E-%4E0@
M24Y43R!P:'!T97-T(%9!3%5%4R`H-#(L("=T:')E92<L("=4:')E92<L("<R
M,#`S+3`S+3(S)RDB*3L*"@IP<FEN="`B/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]7&XB.PIP<FEN="`G=&5S
M=&EN9R!G971/;F4Z("<["B1R970@/28@)&1B:"T^9V5T3VYE*")314Q%0U0@
M*B!&4D]-('!H<'1E<W0@5TA%4D4@8R`]("=4=V\G(BD["G!R:6YT7W(H)')E
M="D["G!R:6YT(")<;B(["@IP<FEN="`G=&5S=&EN9R!G971/;F4@=VET:"!S
M=')I;F<@<&%R86US.B`G.PHD<F5T(#TF("1D8F@M/F=E=$]N92@G4T5,14-4
M("H@1E)/32!P:'!T97-T(%=(15)%(&,@/2`_)RP@)U1H<F5E)RD["G!R:6YT
M7W(H)')E="D["G!R:6YT(")<;B(["@IP<FEN="`G=&5S=&EN9R!G971/;F4@
M=VET:"!A<G)A>2!P87)A;7,Z("<["B1R970@/28@)&1B:"T^9V5T3VYE*"=3
M14Q%0U0@*B!&4D]-('!H<'1E<W0@5TA%4D4@8R`](#\G+"!A<G)A>2@G5'=O
M)RDI.PIP<FEN=%]R*"1R970I.PIP<FEN="`B7&XB.PH*<')I;G0@(EQN/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]7&XB.PIP<FEN="`B=&5S=&EN9R!G9712;W<Z7&XB.PHD<F5T(#TF("1D
M8F@M/F=E=%)O=R@B4T5,14-4("H@1E)/32!P:'!T97-T(%=(15)%(&,@/2`G
M5'=O)R(I.PIP<FEN=%]R*"1R970I.PH*<')I;G0@(G1E<W1I;F<@9V5T4F]W
M('=I=&@@;G5L;"!P87)A;7,L($1"7T9%5$-(34]$15]/4D1%4D5$.EQN(CL*
M)')E="`])B`D9&)H+3YG9712;W<H(E-%3$5#5"`J($923TT@<&AP=&5S="!7
M2$5212!C(#T@)U1W;R<B+`H@("`@("`@(&YU;&PL($1"7T9%5$-(34]$15]/
M4D1%4D5$*3L*<')I;G1?<B@D<F5T*3L*"B\O(%1(25,@1$]%4TXG5"!73U)+
M($1512!43R!"04-+5T%21%,@0T]-4$%424))3$E462!#4D%0"B\O('!R:6YT
M(")T97-T:6YG(&=E=%)O=R!W:71H('-T<FEN9R!P87)A;7,L($1"7T9%5$-(
M34]$15]/4D1%4D5$.EQN(CL*+R\@)')E="`])B`D9&)H+3YG9712;W<H)U-%
M3$5#5"`J($923TT@<&AP=&5S="!72$5212!C(#T@/R<L"B\O("`@("`@("`@
M)U1W;R<L($1"7T9%5$-(34]$15]/4D1%4D5$*3L*+R\@<')I;G1?<B@D<F5T
M*3L*+R\*+R\@=&5S=&EN9R!G9712;W<@=VET:"!S=')I;F<@<&%R86US+"!$
M0E]&151#2$U/1$5?3U)$15)%1#H*+R\@07)R87D*+R\@*`HO+R`@("`@6S!=
M(#T^(#(*+R\@("`@(%LQ72`]/B!T=V\*+R\@("`@(%LR72`]/B!4=V\*+R\@
M("`@(%LS72`]/B`R,#`R+3`R+3(R"B\O("D*"B`@('!R:6YT(")T97-T:6YG
M(&=E=%)O=R!W:71H(%)%5D524T5$(&%R9W,Z($1"7T9%5$-(34]$15]!4U-/
M0RP@87)R87D@<&%R86US.EQN(CL*("`@)')E="`])B`D9&)H+3YG9712;W<H
M)U-%3$5#5"`J($923TT@<&AP=&5S="!72$5212!C(#T@/R<L"B`@("`@("`@
M("`@1$)?1D540TA-3T1%7T%34T]#+"!A<G)A>2@G5'=O)RDI.PH@("!P<FEN
M=%]R*"1R970I.PH@("`*("`@<')I;G0@(G1E<W1I;F<@9V5T4F]W('=I=&@@
M4D5615)3140@87)G<SH@1$)?1D540TA-3T1%7T%34T]#.EQN(CL*("`@)')E
M="`])B`D9&)H+3YG9712;W<H(E-%3$5#5"`J($923TT@<&AP=&5S="!72$52
M12!C(#T@)U1W;R<B+`H@("`@("`@("`@($1"7T9%5$-(34]$15]!4U-/0RD[
M"B`@('!R:6YT7W(H)')E="D["@IP<FEN="`B=&5S=&EN9R!G9712;W<@=VET
M:"!A<G)A>2!P87)A;7,L($1"7T9%5$-(34]$15]!4U-/0SI<;B(["B1R970@
M/28@)&1B:"T^9V5T4F]W*"=314Q%0U0@*B!&4D]-('!H<'1E<W0@5TA%4D4@
M8R`](#\G+`H@("`@("`@(&%R<F%Y*"=4=V\G*2P@1$)?1D540TA-3T1%7T%3
M4T]#*3L*<')I;G1?<B@D<F5T*3L*"G!R:6YT(")T97-T:6YG(&=E=%)O=R!W
M:71H(&%R<F%Y('!A<F%M<RP@1$)?1D540TA-3T1%7T]"2D5#5#I<;B(["B1R
M970@/28@)&1B:"T^9V5T4F]W*"=314Q%0U0@*B!&4D]-('!H<'1E<W0@5TA%
M4D4@8R`](#\G+`H@("`@("`@(&%R<F%Y*"=4=V\G*2P@1$)?1D540TA-3T1%
M7T]"2D5#5"D["G!R:6YT7W(H)')E="D["@H*<')I;G0@(EQN/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]7&XB
M.PIP<FEN="`B=&5S=&EN9R!G971#;VPZ7&XB.PHD<F5T(#TF("1D8F@M/F=E
M=$-O;"@B4T5,14-4("H@1E)/32!P:'!T97-T($]21$52($)9(&(B*3L*<')I
M;G1?<B@D<F5T*3L*"G!R:6YT(")T97-T:6YG(&=E=$-O;"!O;B!Q=65R>2!W
M:71H(&YO(')E8V]R9',Z7&XB.PHD<F5T(#TF("1D8F@M/F=E=$-O;"@G4T5,
M14-4("H@1E)/32!P:'!T97-T(%=(15)%(&$@/B`R,#`G*3L*<')I;G1?<B@D
M<F5T*3L*"G!R:6YT(")T97-T:6YG(&=E=$-O;"!W:71H(&EN=F%L:60@8V]L
M=6UN(&ED.EQN(CL*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]2
M7U)%5%523BD["B1R970@/28@)&1B:"T^9V5T0V]L*"=314Q%0U0@8B!&4D]-
M('!H<'1E<W0@3U)$15(@0ED@8B<L(#$I.PII9B`H1$(Z.FES17)R;W(H)')E
M="DI('L*("`@(&5C:&\@)')E="T^9V5T365S<V%G92@I("X@(EQN(CL*?2!E
M;'-E('L*("`@('!R:6YT("(^/B!3:&]U;&0@:&%V92!P<F]D=6-E9"`G;F\@
M<W5C:"!F:65L9"<@97)R;W)<;B(["GT*)&1B:"T^<V5T17)R;W)(86YD;&EN
M9RA014%27T524D]27T-!3$Q"04-++"`G<&4G*3L*"G!R:6YT(")T97-T:6YG
M(&=E=$-O;"!W:71H(#$@8V]L.EQN(CL*)')E="`])B`D9&)H+3YG971#;VPH
M(E-%3$5#5"`J($923TT@<&AP=&5S="!/4D1%4B!"62!B(BP@,2D["G!R:6YT
M7W(H)')E="D["@IP<FEN="`B=&5S=&EN9R!G971#;VP@=VET:"!B(&-O;#I<
M;B(["B1R970@/28@)&1B:"T^9V5T0V]L*")314Q%0U0@*B!&4D]-('!H<'1E
M<W0@3U)$15(@0ED@8B(L("=B)RD["G!R:6YT7W(H)')E="D["@IP<FEN="`B
M=&5S=&EN9R!G971#;VP@=VET:"!B(&-O;"P@<V-A;&%R('!A<F%M<SI<;B([
M"B1R970@/28@)&1B:"T^9V5T0V]L*")314Q%0U0@*B!&4D]-('!H<'1E<W0@
M5TA%4D4@82`\(#\@3U)$15(@0ED@8B(L"B`@("`@("`@)V(G+"`Q,#`I.PIP
M<FEN=%]R*"1R970I.PH*<')I;G0@(G1E<W1I;F<@9V5T0V]L('=I=&@@8B!C
M;VPL(&%R<F%Y('!A<F%M<SI<;B(["B1R970@/28@)&1B:"T^9V5T0V]L*")3
M14Q%0U0@*B!&4D]-('!H<'1E<W0@5TA%4D4@82`\(#\@3U)$15(@0ED@8B(L
M"B`@("`@("`@)V(G+"!A<G)A>2@Q,#`I*3L*<')I;G1?<B@D<F5T*3L*"@IP
M<FEN="`B7&X]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3U<;B(["G!R:6YT(")T97-T:6YG(&=E=$%S<V]C.EQN
M(CL*)')E="`])B`D9&)H+3YG971!<W-O8R@G4T5,14-4(&$L(&(L(&,@1E)/
M32!P:'!T97-T(%=(15)%(&$@/"`Q,#`@3U)$15(@0ED@8B<I.PIP<FEN=%]R
M*"1R970I.PH*<')I;G0@(G1E<W1I;F<@9V5T07-S;V,@=VET:"!F86QS92!F
M;W)C92P@;G5L;"!P87)A;7,L($1"7T9%5$-(34]$15]/4D1%4D5$.EQN(CL*
M)')E="`])B`D9&)H+3YG971!<W-O8R@B4T5,14-4(&$L(&(L(&,@1E)/32!P
M:'!T97-T(%=(15)%(&$@/"`Q,#`@3U)$15(@0ED@8B(L"B`@("`@("`@("`@
M("`@("`@("`@("`@(&9A;'-E+"!N=6QL+"!$0E]&151#2$U/1$5?3U)$15)%
M1"D["G!R:6YT7W(H)')E="D["@IP<FEN="`B=&5S=&EN9R!G971!<W-O8R!W
M:71H(&9A;'-E(&9O<F-E+"!S8V%L87(@<&%R86US+"!$0E]&151#2$U/1$5?
M05-33T,Z7&XB.PHD<F5T(#TF("1D8F@M/F=E=$%S<V]C*"=314Q%0U0@82P@
M8BP@8R!&4D]-('!H<'1E<W0@5TA%4D4@82`\(#\@3U)$15(@0ED@8B<L"B`@
M("`@("`@("`@("`@("`@("`@("`@(&9A;'-E+"`Q,#`L($1"7T9%5$-(34]$
M15]!4U-/0RD["G!R:6YT7W(H)')E="D["@IP<FEN="`B=&5S=&EN9R!G971!
M<W-O8R!W:71H('1W;R!C;VQS+"!F86QS92!F;W)C92P@<V-A;&%R('!A<F%M
M<RP@1$)?1D540TA-3T1%7T%34T]#.EQN(CL*)')E="`])B`D9&)H+3YG971!
M<W-O8R@G4T5,14-4(&$L(&(@1E)/32!P:'!T97-T(%=(15)%(&$@/"`_($]2
M1$52($)9(&(G+`H@("`@("`@("`@("`@("`@("`@("`@("!F86QS92P@,3`P
M+"!$0E]&151#2$U/1$5?05-33T,I.PIP<FEN=%]R*"1R970I.PH*<')I;G0@
M(G1E<W1I;F<@9V5T07-S;V,@=VET:"!T=V\@8V]L<RP@=')U92!F;W)C92P@
M<V-A;&%R('!A<F%M<RP@1$)?1D540TA-3T1%7T%34T]#.EQN(CL*)')E="`]
M)B`D9&)H+3YG971!<W-O8R@G4T5,14-4(&$L(&(@1E)/32!P:'!T97-T(%=(
M15)%(&$@/"`_($]21$52($)9(&(G+`H@("`@("`@("`@("`@("`@("`@("`@
M("!T<G5E+"`Q,#`L($1"7T9%5$-(34]$15]!4U-/0RD["G!R:6YT7W(H)')E
M="D["@IP<FEN="`B=&5S=&EN9R!G971!<W-O8R!W:71H(&9A;'-E(&9O<F-E
M+"!S8V%L87(@<&%R86US+"!$0E]&151#2$U/1$5?05-33T,L('1R=64@9W)O
M=7`Z7&XB.PHD<F5T(#TF("1D8F@M/F=E=$%S<V]C*"=314Q%0U0@82P@8BP@
M8R!&4D]-('!H<'1E<W0@5TA%4D4@82`\(#\@3U)$15(@0ED@8B<L"B`@("`@
M("`@("`@("`@("`@("`@("`@(&9A;'-E+"`Q,#`L($1"7T9%5$-(34]$15]!
M4U-/0RP@=')U92D["G!R:6YT7W(H)')E="D["@IP<FEN="`B=&5S=&EN9R!G
M971!<W-O8R!W:71H(&9A;'-E(&9O<F-E+"!A<G)A>2!P87)A;7,L($1"7T9%
M5$-(34]$15]/0DI%0U0Z7&XB.PHD<F5T(#TF("1D8F@M/F=E=$%S<V]C*"=3
M14Q%0U0@82P@8BP@8R!&4D]-('!H<'1E<W0@5TA%4D4@82`\(#\@3U)$15(@
M0ED@8B<L"B`@("`@("`@("`@("`@("`@("`@("`@(&9A;'-E+"!A<G)A>2@Q
M,#`I+"!$0E]&151#2$U/1$5?3T)*14-4*3L*<')I;G1?<B@D<F5T*3L*"G!R
M:6YT(")T97-T:6YG(&=E=$%S<V]C('=I=&@@=')U92!F;W)C92P@87)R87D@
M<&%R86US+"!$0E]&151#2$U/1$5?3T)*14-4+"!T<G5E(&=R;W5P.EQN(CL*
M)')E="`])B`D9&)H+3YG971!<W-O8R@G4T5,14-4(&$L(&(L(&,@1E)/32!P
M:'!T97-T(%=(15)%(&$@/"`_($]21$52($)9(&(G+`H@("`@("`@("`@("`@
M("`@("`@("`@("!F86QS92P@87)R87DH,3`P*2P@1$)?1D540TA-3T1%7T]"
M2D5#5"P@=')U92D["G!R:6YT7W(H)')E="D["@H*<')I;G0@(EQN/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M7&XB.PIP<FEN="`B=&5S=&EN9R!G971!;&PZ7&XB.PHD<F5T(#TF("1D8F@M
M/F=E=$%L;"@B4T5,14-4("H@1E)/32!P:'!T97-T(%=(15)%(&,@/2`G5'=O
M)R!/4B!C(#T@)U1H<F5E)R(I.PIP<FEN=%]R*"1R970I.PH*<')I;G0@(G1E
M<W1I;F<@9V5T06QL('=I=&@@;G5L;"!P87)A;7,L($1"7T9%5$-(34]$15]/
M4D1%4D5$.EQN(CL*)')E="`])B`D9&)H+3YG971!;&PH(E-%3$5#5"`J($92
M3TT@<&AP=&5S="!72$5212!C(#T@)U1W;R<@3U(@8R`]("=4:')E92<B+`H@
M("`@("`@(&YU;&PL($1"7T9%5$-(34]$15]/4D1%4D5$*3L*<')I;G1?<B@D
M<F5T*3L*"B\O(%1(25,@1$]%4TXG5"!73U)+($1512!43R!"04-+5T%21%,@
M0T]-4$%424))3$E462!#4D%0"B\O('!R:6YT(")T97-T:6YG(&=E=$%L;"!W
M:71H('-T<FEN9R!P87)A;7,L($1"7T9%5$-(34]$15]/4D1%4D5$.EQN(CL*
M+R\@)')E="`])B`D9&)H+3YG971!;&PH)U-%3$5#5"`J($923TT@<&AP=&5S
M="!72$5212!C(#T@/R<L"B\O("`@("`@("`@)U1W;R<L($1"7T9%5$-(34]$
M15]/4D1%4D5$*3L*+R\@<')I;G1?<B@D<F5T*3L*+R\*+R\@=&5S=&EN9R!G
M971!;&P@=VET:"!S=')I;F<@<&%R86US+"!$0E]&151#2$U/1$5?3U)$15)%
M1#H*+R\@07)R87D*+R\@*`HO+R`@("`@6S!=(#T^(#(*+R\@("`@(%LQ72`]
M/B!T=V\*+R\@("`@(%LR72`]/B!4=V\*+R\@("`@(%LS72`]/B`R,#`R+3`R
M+3(R"B\O("D*"B`@('!R:6YT(")T97-T:6YG(&=E=$%L;"!W:71H(%)%5D52
M4T5$(&%R9W,Z($1"7T9%5$-(34]$15]!4U-/0RP@87)R87D@<&%R86US.EQN
M(CL*("`@)')E="`])B`D9&)H+3YG971!;&PH)U-%3$5#5"`J($923TT@<&AP
M=&5S="!72$5212!C(#T@/R!/4B!C(#T@/R!/4D1%4B!"62!C)RP*("`@("`@
M("`@("!$0E]&151#2$U/1$5?05-33T,L(&%R<F%Y*"=4=V\G+"`G5&AR964G
M*2D["B`@('!R:6YT7W(H)')E="D["B`@(`H@("!P<FEN="`B=&5S=&EN9R!G
M971!;&P@=VET:"!2159%4E-%1"!A<F=S.B!$0E]&151#2$U/1$5?05-33T,Z
M7&XB.PH@("`D<F5T(#TF("1D8F@M/F=E=$%L;"@B4T5,14-4("H@1E)/32!P
M:'!T97-T(%=(15)%(&,@/2`G5'=O)R!/4B!C(#T@)U1H<F5E)R(L"B`@("`@
M("`@("`@1$)?1D540TA-3T1%7T%34T]#*3L*("`@<')I;G1?<B@D<F5T*3L*
M"G!R:6YT(")T97-T:6YG(&=E=$%L;"!W:71H(&%R<F%Y('!A<F%M<RP@1$)?
M1D540TA-3T1%7T%34T]#.EQN(CL*)')E="`])B`D9&)H+3YG971!;&PH)U-%
M3$5#5"`J($923TT@<&AP=&5S="!72$5212!C(#T@/R!/4B!C(#T@/R!/4D1%
M4B!"62!C)RP*("`@("`@("!A<G)A>2@G5'=O)RP@)U1H<F5E)RDL($1"7T9%
M5$-(34]$15]!4U-/0RD["G!R:6YT7W(H)')E="D["@IP<FEN="`B=&5S=&EN
M9R!G971!;&P@=VET:"!A<G)A>2!P87)A;7,L($1"7T9%5$-(34]$15]/0DI%
M0U0Z7&XB.PHD<F5T(#TF("1D8F@M/F=E=$%L;"@G4T5,14-4("H@1E)/32!P
M:'!T97-T(%=(15)%(&,@/2`_($]2(&,@/2`_($]21$52($)9(&,G+`H@("`@
M("`@(&%R<F%Y*"=4=V\G+"`G5&AR964G*2P@1$)?1D540TA-3T1%7T]"2D5#
M5"D["G!R:6YT7W(H)')E="D["@H*<')I;G0@(EQN/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]7&XB.PIP<FEN
M="`G=&5S=&EN9R!G971/;F4@=VET:"!N=6QL('9A;'5E(&EN(&-O;'5M;CH@
M)SL*)&1B:"T^<75E<GDH(DE.4T525"!)3E1/('!H<'1E<W0@5D%,5453("@Y
M+"`G;FEN92<L("<G+"!.54Q,*2(I.PHD<F5T(#TF("1D8F@M/F=E=$]N92@G
M4T5,14-4(&0@1E)/32!P:'!T97-T(%=(15)%(&$@/2`Y)RD["FEF("@D<F5T
M(#T]/2`G)RD@>PH@("`@<')I;G0@(FUA=&-H97,@97AP96-T960@<F5S=6QT
M7&XB.PI](&5L<V4@>PH@("`@:68@*"1D8F@M/G!H<'1Y<&4@/3T@)VUS<6PG
M*2!["B`@("`@("`@:68@*&=E='1Y<&4H)')E="D@/3T@)TY53$PG*2!["B`@
M("`@("`@("`@("\O(&US<6P@9&]E<VXG="!E=F5N(')E='5R;B!T:&4@8V]L
M=6UN+B`@2F]Y(2`Z*0H@("`@("`@("`@("`O+R!H='1P.B\O8G5G<RYP:'`N
M;F5T+S]I9#TS,3DV,`H@("`@("`@("`@("!P<FEN="`B;6%T8VAE<R!E>'!E
M8W1E9"!R97-U;'1<;B(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<')I;G0@(E=/5RP@;5-13"!N;W<@<F5T=7)N<R!C;VQU;6YS('1H870@:&%V
M92!.54Q,4R!I;B!T:&5M7&XB.PH@("`@("`@('T*("`@('T@96QS92!["B`@
M("`@("`@<')I;G0@)W1Y<&4])R`N(&=E='1Y<&4H)')E="D@+B`B+"!V86QU
M93TD<F5T7&XB.PH@("`@?0I]"@IP<FEN="`G=&5S=&EN9R!G971/;F4@=VET
M:"!E;7!T>2!S=')I;F<@:6X@8V]L=6UN.B`G.PHD<F5T(#TF("1D8F@M/F=E
M=$]N92@G4T5,14-4(&,@1E)/32!P:'!T97-T(%=(15)%(&$@/2`Y)RD["FEF
M("@D<F5T(#T]/2`G)RD@>PH@("`@<')I;G0@(F5M<'1Y('-T<FEN9UQN(CL*
M?2!E;'-E('L*("`@('!R:6YT("=T>7!E/2<@+B!G971T>7!E*"1R970I("X@
M(BP@=F%L=64])')E=%QN(CL*?0H*"G!R:6YT(")<;CT]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/5QN(CL*"@ID
M<F]P7W1A8FQE*"1D8F@L("=P:'!T97-T)RD["@H*/SX*+2U%6%!%0U0M+0H]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T*=&5S=&EN9R!G971/;F4Z(#(*=&5S=&EN9R!G971/;F4@=VET:"!S
M=')I;F<@<&%R86US.B`T,@IT97-T:6YG(&=E=$]N92!W:71H(&%R<F%Y('!A
M<F%M<SH@,@H*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]"G1E<W1I;F<@9V5T4F]W.@I!<G)A>0HH"B`@("!;
M,%T@/3X@,@H@("`@6S%=(#T^('1W;PH@("`@6S)=(#T^(%1W;PH@("`@6S-=
M(#T^(#(P,#(M,#(M,C(**0IT97-T:6YG(&=E=%)O=R!W:71H(&YU;&P@<&%R
M86US+"!$0E]&151#2$U/1$5?3U)$15)%1#H*07)R87D**`H@("`@6S!=(#T^
M(#(*("`@(%LQ72`]/B!T=V\*("`@(%LR72`]/B!4=V\*("`@(%LS72`]/B`R
M,#`R+3`R+3(R"BD*=&5S=&EN9R!G9712;W<@=VET:"!2159%4E-%1"!A<F=S
M.B!$0E]&151#2$U/1$5?05-33T,L(&%R<F%Y('!A<F%M<SH*07)R87D**`H@
M("`@6V%=(#T^(#(*("`@(%MB72`]/B!T=V\*("`@(%MC72`]/B!4=V\*("`@
M(%MD72`]/B`R,#`R+3`R+3(R"BD*=&5S=&EN9R!G9712;W<@=VET:"!2159%
M4E-%1"!A<F=S.B!$0E]&151#2$U/1$5?05-33T,Z"D%R<F%Y"B@*("`@(%MA
M72`]/B`R"B`@("!;8ET@/3X@='=O"B`@("!;8UT@/3X@5'=O"B`@("!;9%T@
M/3X@,C`P,BTP,BTR,@HI"G1E<W1I;F<@9V5T4F]W('=I=&@@87)R87D@<&%R
M86US+"!$0E]&151#2$U/1$5?05-33T,Z"D%R<F%Y"B@*("`@(%MA72`]/B`R
M"B`@("!;8ET@/3X@='=O"B`@("!;8UT@/3X@5'=O"B`@("!;9%T@/3X@,C`P
M,BTP,BTR,@HI"G1E<W1I;F<@9V5T4F]W('=I=&@@87)R87D@<&%R86US+"!$
M0E]&151#2$U/1$5?3T)*14-4.@IS=&1#;&%S<R!/8FIE8W0**`H@("`@6V%=
M(#T^(#(*("`@(%MB72`]/B!T=V\*("`@(%MC72`]/B!4=V\*("`@(%MD72`]
M/B`R,#`R+3`R+3(R"BD*"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0IT97-T:6YG(&=E=$-O;#H*07)R87D*
M*`H@("`@6S!=(#T^(#0R"B`@("!;,5T@/3X@-#(*("`@(%LR72`]/B`R"BD*
M=&5S=&EN9R!G971#;VP@;VX@<75E<GD@=VET:"!N;R!R96-O<F1S.@I!<G)A
M>0HH"BD*=&5S=&EN9R!G971#;VP@=VET:"!I;G9A;&ED(&-O;'5M;B!I9#H*
M1$(@17)R;W(Z(&YO('-U8V@@9FEE;&0*=&5S=&EN9R!G971#;VP@=VET:"`Q
M(&-O;#H*07)R87D**`H@("`@6S!=(#T^(&)I;F<*("`@(%LQ72`]/B!T:')E
M90H@("`@6S)=(#T^('1W;PHI"G1E<W1I;F<@9V5T0V]L('=I=&@@8B!C;VPZ
M"D%R<F%Y"B@*("`@(%LP72`]/B!B:6YG"B`@("!;,5T@/3X@=&AR964*("`@
M(%LR72`]/B!T=V\**0IT97-T:6YG(&=E=$-O;"!W:71H(&(@8V]L+"!S8V%L
M87(@<&%R86US.@I!<G)A>0HH"B`@("!;,%T@/3X@8FEN9PH@("`@6S%=(#T^
M('1H<F5E"B`@("!;,ET@/3X@='=O"BD*=&5S=&EN9R!G971#;VP@=VET:"!B
M(&-O;"P@87)R87D@<&%R86US.@I!<G)A>0HH"B`@("!;,%T@/3X@8FEN9PH@
M("`@6S%=(#T^('1H<F5E"B`@("!;,ET@/3X@='=O"BD*"CT]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0IT97-T
M:6YG(&=E=$%S<V]C.@I!<G)A>0HH"B`@("!;-#)=(#T^($%R<F%Y"B`@("`@
M("`@*`H@("`@("`@("`@("!;,%T@/3X@=&AR964*("`@("`@("`@("`@6S%=
M(#T^(%1H<F5E"B`@("`@("`@*0H*("`@(%LR72`]/B!!<G)A>0H@("`@("`@
M("@*("`@("`@("`@("`@6S!=(#T^('1W;PH@("`@("`@("`@("!;,5T@/3X@
M5'=O"B`@("`@("`@*0H**0IT97-T:6YG(&=E=$%S<V]C('=I=&@@9F%L<V4@
M9F]R8V4L(&YU;&P@<&%R86US+"!$0E]&151#2$U/1$5?3U)$15)%1#H*07)R
M87D**`H@("`@6S0R72`]/B!!<G)A>0H@("`@("`@("@*("`@("`@("`@("`@
M6S!=(#T^('1H<F5E"B`@("`@("`@("`@(%LQ72`]/B!4:')E90H@("`@("`@
M("D*"B`@("!;,ET@/3X@07)R87D*("`@("`@("`H"B`@("`@("`@("`@(%LP
M72`]/B!T=V\*("`@("`@("`@("`@6S%=(#T^(%1W;PH@("`@("`@("D*"BD*
M=&5S=&EN9R!G971!<W-O8R!W:71H(&9A;'-E(&9O<F-E+"!S8V%L87(@<&%R
M86US+"!$0E]&151#2$U/1$5?05-33T,Z"D%R<F%Y"B@*("`@(%LT,ET@/3X@
M07)R87D*("`@("`@("`H"B`@("`@("`@("`@(%MB72`]/B!T:')E90H@("`@
M("`@("`@("!;8UT@/3X@5&AR964*("`@("`@("`I"@H@("`@6S)=(#T^($%R
M<F%Y"B`@("`@("`@*`H@("`@("`@("`@("!;8ET@/3X@='=O"B`@("`@("`@
M("`@(%MC72`]/B!4=V\*("`@("`@("`I"@HI"G1E<W1I;F<@9V5T07-S;V,@
M=VET:"!T=V\@8V]L<RP@9F%L<V4@9F]R8V4L('-C86QA<B!P87)A;7,L($1"
M7T9%5$-(34]$15]!4U-/0SH*07)R87D**`H@("`@6S0R72`]/B!T:')E90H@
M("`@6S)=(#T^('1W;PHI"G1E<W1I;F<@9V5T07-S;V,@=VET:"!T=V\@8V]L
M<RP@=')U92!F;W)C92P@<V-A;&%R('!A<F%M<RP@1$)?1D540TA-3T1%7T%3
M4T]#.@I!<G)A>0HH"B`@("!;-#)=(#T^($%R<F%Y"B`@("`@("`@*`H@("`@
M("`@("`@("!;8ET@/3X@=&AR964*("`@("`@("`I"@H@("`@6S)=(#T^($%R
M<F%Y"B`@("`@("`@*`H@("`@("`@("`@("!;8ET@/3X@='=O"B`@("`@("`@
M*0H**0IT97-T:6YG(&=E=$%S<V]C('=I=&@@9F%L<V4@9F]R8V4L('-C86QA
M<B!P87)A;7,L($1"7T9%5$-(34]$15]!4U-/0RP@=')U92!G<F]U<#H*07)R
M87D**`H@("`@6S0R72`]/B!!<G)A>0H@("`@("`@("@*("`@("`@("`@("`@
M6S!=(#T^($%R<F%Y"B`@("`@("`@("`@("`@("`H"B`@("`@("`@("`@("`@
M("`@("`@6V)=(#T^(&)I;F<*("`@("`@("`@("`@("`@("`@("!;8UT@/3X@
M5&AI<R!I<R!A('1E<W0*("`@("`@("`@("`@("`@("D*"B`@("`@("`@("`@
M(%LQ72`]/B!!<G)A>0H@("`@("`@("`@("`@("`@*`H@("`@("`@("`@("`@
M("`@("`@(%MB72`]/B!T:')E90H@("`@("`@("`@("`@("`@("`@(%MC72`]
M/B!4:')E90H@("`@("`@("`@("`@("`@*0H*("`@("`@("`I"@H@("`@6S)=
M(#T^($%R<F%Y"B`@("`@("`@*`H@("`@("`@("`@("!;,%T@/3X@07)R87D*
M("`@("`@("`@("`@("`@("@*("`@("`@("`@("`@("`@("`@("!;8ET@/3X@
M='=O"B`@("`@("`@("`@("`@("`@("`@6V-=(#T^(%1W;PH@("`@("`@("`@
M("`@("`@*0H*("`@("`@("`I"@HI"G1E<W1I;F<@9V5T07-S;V,@=VET:"!F
M86QS92!F;W)C92P@87)R87D@<&%R86US+"!$0E]&151#2$U/1$5?3T)*14-4
M.@I!<G)A>0HH"B`@("!;-#)=(#T^('-T9$-L87-S($]B:F5C=`H@("`@("`@
M("@*("`@("`@("`@("`@6V%=(#T^(#0R"B`@("`@("`@("`@(%MB72`]/B!T
M:')E90H@("`@("`@("`@("!;8UT@/3X@5&AR964*("`@("`@("`I"@H@("`@
M6S)=(#T^('-T9$-L87-S($]B:F5C=`H@("`@("`@("@*("`@("`@("`@("`@
M6V%=(#T^(#(*("`@("`@("`@("`@6V)=(#T^('1W;PH@("`@("`@("`@("!;
M8UT@/3X@5'=O"B`@("`@("`@*0H**0IT97-T:6YG(&=E=$%S<V]C('=I=&@@
M=')U92!F;W)C92P@87)R87D@<&%R86US+"!$0E]&151#2$U/1$5?3T)*14-4
M+"!T<G5E(&=R;W5P.@I!<G)A>0HH"B`@("!;-#)=(#T^($%R<F%Y"B`@("`@
M("`@*`H@("`@("`@("`@("!;,%T@/3X@<W1D0VQA<W,@3V)J96-T"B`@("`@
M("`@("`@("`@("`H"B`@("`@("`@("`@("`@("`@("`@6V%=(#T^(#0R"B`@
M("`@("`@("`@("`@("`@("`@6V)=(#T^(&)I;F<*("`@("`@("`@("`@("`@
M("`@("!;8UT@/3X@5&AI<R!I<R!A('1E<W0*("`@("`@("`@("`@("`@("D*
M"B`@("`@("`@("`@(%LQ72`]/B!S=&1#;&%S<R!/8FIE8W0*("`@("`@("`@
M("`@("`@("@*("`@("`@("`@("`@("`@("`@("!;85T@/3X@-#(*("`@("`@
M("`@("`@("`@("`@("!;8ET@/3X@=&AR964*("`@("`@("`@("`@("`@("`@
M("!;8UT@/3X@5&AR964*("`@("`@("`@("`@("`@("D*"B`@("`@("`@*0H*
M("`@(%LR72`]/B!!<G)A>0H@("`@("`@("@*("`@("`@("`@("`@6S!=(#T^
M('-T9$-L87-S($]B:F5C=`H@("`@("`@("`@("`@("`@*`H@("`@("`@("`@
M("`@("`@("`@(%MA72`]/B`R"B`@("`@("`@("`@("`@("`@("`@6V)=(#T^
M('1W;PH@("`@("`@("`@("`@("`@("`@(%MC72`]/B!4=V\*("`@("`@("`@
M("`@("`@("D*"B`@("`@("`@*0H**0H*/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"G1E<W1I;F<@9V5T06QL
M.@I!<G)A>0HH"B`@("!;,%T@/3X@07)R87D*("`@("`@("`H"B`@("`@("`@
M("`@(%LP72`]/B`R"B`@("`@("`@("`@(%LQ72`]/B!T=V\*("`@("`@("`@
M("`@6S)=(#T^(%1W;PH@("`@("`@("`@("!;,UT@/3X@,C`P,BTP,BTR,@H@
M("`@("`@("D*"B`@("!;,5T@/3X@07)R87D*("`@("`@("`H"B`@("`@("`@
M("`@(%LP72`]/B`T,@H@("`@("`@("`@("!;,5T@/3X@=&AR964*("`@("`@
M("`@("`@6S)=(#T^(%1H<F5E"B`@("`@("`@("`@(%LS72`]/B`R,#`S+3`S
M+3(S"B`@("`@("`@*0H**0IT97-T:6YG(&=E=$%L;"!W:71H(&YU;&P@<&%R
M86US+"!$0E]&151#2$U/1$5?3U)$15)%1#H*07)R87D**`H@("`@6S!=(#T^
M($%R<F%Y"B`@("`@("`@*`H@("`@("`@("`@("!;,%T@/3X@,@H@("`@("`@
M("`@("!;,5T@/3X@='=O"B`@("`@("`@("`@(%LR72`]/B!4=V\*("`@("`@
M("`@("`@6S-=(#T^(#(P,#(M,#(M,C(*("`@("`@("`I"@H@("`@6S%=(#T^
M($%R<F%Y"B`@("`@("`@*`H@("`@("`@("`@("!;,%T@/3X@-#(*("`@("`@
M("`@("`@6S%=(#T^('1H<F5E"B`@("`@("`@("`@(%LR72`]/B!4:')E90H@
M("`@("`@("`@("!;,UT@/3X@,C`P,RTP,RTR,PH@("`@("`@("D*"BD*=&5S
M=&EN9R!G971!;&P@=VET:"!2159%4E-%1"!A<F=S.B!$0E]&151#2$U/1$5?
M05-33T,L(&%R<F%Y('!A<F%M<SH*07)R87D**`H@("`@6S!=(#T^($%R<F%Y
M"B`@("`@("`@*`H@("`@("`@("`@("!;85T@/3X@-#(*("`@("`@("`@("`@
M6V)=(#T^('1H<F5E"B`@("`@("`@("`@(%MC72`]/B!4:')E90H@("`@("`@
M("`@("!;9%T@/3X@,C`P,RTP,RTR,PH@("`@("`@("D*"B`@("!;,5T@/3X@
M07)R87D*("`@("`@("`H"B`@("`@("`@("`@(%MA72`]/B`R"B`@("`@("`@
M("`@(%MB72`]/B!T=V\*("`@("`@("`@("`@6V-=(#T^(%1W;PH@("`@("`@
M("`@("!;9%T@/3X@,C`P,BTP,BTR,@H@("`@("`@("D*"BD*=&5S=&EN9R!G
M971!;&P@=VET:"!2159%4E-%1"!A<F=S.B!$0E]&151#2$U/1$5?05-33T,Z
M"D%R<F%Y"B@*("`@(%LP72`]/B!!<G)A>0H@("`@("`@("@*("`@("`@("`@
M("`@6V%=(#T^(#(*("`@("`@("`@("`@6V)=(#T^('1W;PH@("`@("`@("`@
M("!;8UT@/3X@5'=O"B`@("`@("`@("`@(%MD72`]/B`R,#`R+3`R+3(R"B`@
M("`@("`@*0H*("`@(%LQ72`]/B!!<G)A>0H@("`@("`@("@*("`@("`@("`@
M("`@6V%=(#T^(#0R"B`@("`@("`@("`@(%MB72`]/B!T:')E90H@("`@("`@
M("`@("!;8UT@/3X@5&AR964*("`@("`@("`@("`@6V1=(#T^(#(P,#,M,#,M
M,C,*("`@("`@("`I"@HI"G1E<W1I;F<@9V5T06QL('=I=&@@87)R87D@<&%R
M86US+"!$0E]&151#2$U/1$5?05-33T,Z"D%R<F%Y"B@*("`@(%LP72`]/B!!
M<G)A>0H@("`@("`@("@*("`@("`@("`@("`@6V%=(#T^(#0R"B`@("`@("`@
M("`@(%MB72`]/B!T:')E90H@("`@("`@("`@("!;8UT@/3X@5&AR964*("`@
M("`@("`@("`@6V1=(#T^(#(P,#,M,#,M,C,*("`@("`@("`I"@H@("`@6S%=
M(#T^($%R<F%Y"B`@("`@("`@*`H@("`@("`@("`@("!;85T@/3X@,@H@("`@
M("`@("`@("!;8ET@/3X@='=O"B`@("`@("`@("`@(%MC72`]/B!4=V\*("`@
M("`@("`@("`@6V1=(#T^(#(P,#(M,#(M,C(*("`@("`@("`I"@HI"G1E<W1I
M;F<@9V5T06QL('=I=&@@87)R87D@<&%R86US+"!$0E]&151#2$U/1$5?3T)*
M14-4.@I!<G)A>0HH"B`@("!;,%T@/3X@<W1D0VQA<W,@3V)J96-T"B`@("`@
M("`@*`H@("`@("`@("`@("!;85T@/3X@-#(*("`@("`@("`@("`@6V)=(#T^
M('1H<F5E"B`@("`@("`@("`@(%MC72`]/B!4:')E90H@("`@("`@("`@("!;
M9%T@/3X@,C`P,RTP,RTR,PH@("`@("`@("D*"B`@("!;,5T@/3X@<W1D0VQA
M<W,@3V)J96-T"B`@("`@("`@*`H@("`@("`@("`@("!;85T@/3X@,@H@("`@
M("`@("`@("!;8ET@/3X@='=O"B`@("`@("`@("`@(%MC72`]/B!4=V\*("`@
M("`@("`@("`@6V1=(#T^(#(P,#(M,#(M,C(*("`@("`@("`I"@HI"@H]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T*=&5S=&EN9R!G971/;F4@=VET:"!N=6QL('9A;'5E(&EN(&-O;'5M;CH@
M;6%T8VAE<R!E>'!E8W1E9"!R97-U;'0*=&5S=&EN9R!G971/;F4@=VET:"!E
M;7!T>2!S=')I;F<@:6X@8V]L=6UN.B!E;7!T>2!S=')I;F<*"CT]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R+S$Y9V5T;&ES=&]F+G!H
M<'0````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`Q-C$W,B`Q,#4Q-30S,S<S,B`P,C4V,C<`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+2U4
M15-4+2T*1$)?9')I=F5R.CIG971,:7-T3V8*+2U)3DDM+0IE<G)O<E]R97!O
M<G1I;F<@/2`R,#0W"BTM4TM)4$E&+2T*/#]P:'`@8VAD:7(H9&ER;F%M92A?
M7T9)3$5?7RDI.R!R97%U:7)E7V]N8V4@)RXO<VMI<&EF+FEN8R<[(#\^"BTM
M1DE,12TM"CP_<&AP"@IR97%U:7)E7V]N8V4@)RXO;6MT86)L92YI;F,G.PH*
M+RH*("H@06X@87)R87D@=VET:"!K97ES(&-O;G1A:6YI;F<@=&AE("1T>7!E
M('1O(&)E('!A<W-E9"!T;R!T:&4@9V5T3&ES=$]F*"D*("H@;65T:&]D+B`@
M5&AE('9A;'5E<R!O9B!T:&4@;6%I;B!A<G)A>2!A<F4@82!S=6(M87)R87D@
M=&AA="!H87,@:V5Y<PH@*B!L:7-T:6YG('1H92!P:'!T>7!E(&%N9"!D8G-Y
M;G1A>"!O9B!E86-H(&1R:79E<B!A;F0@=F%L=65S(&]F('1H90H@*B!R97-U
M;'0@97AP96-T960@9G)O;2!T:&4@8V]M8FEN871I;VX@;V8@86QL('1H97-E
M(&9A8W1O<G,N"B`J+PHD=&5S=',@/2!A<G)A>2@*("`@("=T86)L97,G(#T^
M(&%R<F%Y*`H@("`@("`@("=D8F%S93ID8F%S92<@/3X@1$)?15)23U)?54Y3
M55!03U)4140L"B`@("`@("`@)V9B<W%L.F9B<W%L)R`]/B`G87)R87DG+`H@
M("`@("`@("=I8F%S93II8F%S92<@/3X@)V%R<F%Y)RP*("`@("`@("`G:6)A
M<V4Z9FER96)I<F0G(#T^("=A<G)A>2<L"B`@("`@("`@)VEF>#II9G@G(#T^
M("=A<G)A>2<L"B`@("`@("`@)VUS<6PZ;7-Q;"<@/3X@)V%R<F%Y)RP*("`@
M("`@("`G;7-S<6PZ;7-S<6PG(#T^("=A<G)A>2<L"B`@("`@("`@)VUY<W%L
M.FUY<W%L)R`]/B`G87)R87DG+`H@("`@("`@("=M>7-Q;&DZ;7ES<6QI)R`]
M/B`G87)R87DG+`H@("`@("`@("=O8VDX.F]C:3@G(#T^("=A<G)A>2<L"B`@
M("`@("`@)V]D8F,Z86-C97-S)R`]/B`G87)R87DG+`H@("`@("`@("=O9&)C
M.F1B,B<@/3X@)V%R<F%Y)RP*("`@("`@("`G<&=S<6PZ<&=S<6PG(#T^("=A
M<G)A>2<L"B`@("`@("`@)W-Q;&ET93IS<6QI=&4G(#T^("=A<G)A>2<L"B`@
M("`@("`@)W-Y8F%S93IS>6)A<V4G(#T^("=A<G)A>2<L"B`@("`I+`H@("`@
M)W9I97=S)R`]/B!A<G)A>2@*("`@("`@("`G9&)A<V4Z9&)A<V4G(#T^($1"
M7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=F8G-Q;#IF8G-Q;"<@/3X@
M)V%R<F%Y)RP*("`@("`@("`G:6)A<V4Z:6)A<V4G(#T^("=A<G)A>2<L"B`@
M("`@("`@)VEB87-E.F9I<F5B:7)D)R`]/B`G87)R87DG+`H@("`@("`@("=I
M9G@Z:69X)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;7-Q
M;#IM<W%L)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;7-S
M<6PZ;7-S<6PG(#T^("=A<G)A>2<L"B`@("`@("`@)VUY<W%L.FUY<W%L)R`]
M/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;7ES<6QI.FUY<W%L
M:2<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)V]C:3@Z;V-I
M."<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)V]D8F,Z86-C
M97-S)R`]/B`G87)R87DG+`H@("`@("`@("=O9&)C.F1B,B<@/3X@)V%R<F%Y
M)RP*("`@("`@("`G<&=S<6PZ<&=S<6PG(#T^("=A<G)A>2<L"B`@("`@("`@
M)W-Q;&ET93IS<6QI=&4G(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@
M("`@("=S>6)A<V4Z<WEB87-E)R`]/B`G87)R87DG+`H@("`@*2P*("`@("=U
M<V5R<R<@/3X@87)R87DH"B`@("`@("`@)V1B87-E.F1B87-E)R`]/B!$0E]%
M4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G9F)S<6PZ9F)S<6PG(#T^("=A
M<G)A>2<L"B`@("`@("`@)VEB87-E.FEB87-E)R`]/B`G87)R87DG+`H@("`@
M("`@("=I8F%S93IF:7)E8FER9"<@/3X@)V%R<F%Y)RP*("`@("`@("`G:69X
M.FEF>"<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)VUS<6PZ
M;7-Q;"<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)VUS<W%L
M.FUS<W%L)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;7ES
M<6PZ;7ES<6PG(#T^($1"7T524D]27T%#0T534U]624],051)3TXL"B`@("`@
M("`@)VUY<W%L:3IM>7-Q;&DG(#T^($1"7T524D]27T%#0T534U]624],051)
M3TXL"B`@("`@("`@)V]C:3@Z;V-I."<@/3X@1$)?15)23U)?54Y355!03U)4
M140L"B`@("`@("`@)V]D8F,Z86-C97-S)R`]/B!$0E]%4E)/4E]53E-54%!/
M4E1%1"P*("`@("`@("`G;V1B8SID8C(G(#T^($1"7T524D]27U5.4U504$]2
M5$5$+`H@("`@("`@("=P9W-Q;#IP9W-Q;"<@/3X@)V%R<F%Y)RP*("`@("`@
M("`G<W%L:71E.G-Q;&ET92<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@
M("`@("`@)W-Y8F%S93IS>6)A<V4G(#T^($1"7T524D]27U5.4U504$]25$5$
M+`H@("`@*2P*("`@("=D871A8F%S97,G(#T^(&%R<F%Y*`H@("`@("`@("=D
M8F%S93ID8F%S92<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@
M)V9B<W%L.F9B<W%L)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@
M("`G:6)A<V4Z:6)A<V4G(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@
M("`@("=I8F%S93IF:7)E8FER9"<@/3X@1$)?15)23U)?54Y355!03U)4140L
M"B`@("`@("`@)VEF>#II9G@G(#T^($1"7T524D]27U5.4U504$]25$5$+`H@
M("`@("`@("=M<W%L.FUS<6PG(#T^("=A<G)A>2<L"B`@("`@("`@)VUS<W%L
M.FUS<W%L)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;7ES
M<6PZ;7ES<6PG(#T^("=A<G)A>2<L"B`@("`@("`@)VUY<W%L:3IM>7-Q;&DG
M(#T^("=A<G)A>2<L"B`@("`@("`@)V]C:3@Z;V-I."<@/3X@1$)?15)23U)?
M54Y355!03U)4140L"B`@("`@("`@)V]D8F,Z86-C97-S)R`]/B`G87)R87DG
M+`H@("`@("`@("=O9&)C.F1B,B<@/3X@)V%R<F%Y)RP*("`@("`@("`G<&=S
M<6PZ<&=S<6PG(#T^("=A<G)A>2<L"B`@("`@("`@)W-Q;&ET93IS<6QI=&4G
M(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=S>6)A<V4Z<WEB
M87-E)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("DL"B`@("`G9G5N
M8W1I;VYS)R`]/B!A<G)A>2@*("`@("`@("`G9&)A<V4Z9&)A<V4G(#T^($1"
M7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=F8G-Q;#IF8G-Q;"<@/3X@
M)V%R<F%Y)RP*("`@("`@("`G:6)A<V4Z:6)A<V4G(#T^($1"7T524D]27U5.
M4U504$]25$5$+`H@("`@("`@("=I8F%S93IF:7)E8FER9"<@/3X@1$)?15)2
M3U)?54Y355!03U)4140L"B`@("`@("`@)VEF>#II9G@G(#T^($1"7T524D]2
M7U5.4U504$]25$5$+`H@("`@("`@("=M<W%L.FUS<6PG(#T^($1"7T524D]2
M7U5.4U504$]25$5$+`H@("`@("`@("=M<W-Q;#IM<W-Q;"<@/3X@1$)?15)2
M3U)?54Y355!03U)4140L"B`@("`@("`@)VUY<W%L.FUY<W%L)R`]/B!$0E]%
M4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;7ES<6QI.FUY<W%L:2<@/3X@
M1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)V]C:3@Z;V-I."<@/3X@
M1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)V]D8F,Z86-C97-S)R`]
M/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;V1B8SID8C(G(#T^
M($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=P9W-Q;#IP9W-Q;"<@
M/3X@)V%R<F%Y)RP*("`@("`@("`G<W%L:71E.G-Q;&ET92<@/3X@1$)?15)2
M3U)?54Y355!03U)4140L"B`@("`@("`@)W-Y8F%S93IS>6)A<V4G(#T^($1"
M7T524D]27U5.4U504$]25$5$+`H@("`@*2P*("`@("=P<F]C961U<F5S)R`]
M/B!A<G)A>2@*("`@("`@("`G9&)A<V4Z9&)A<V4G(#T^($1"7T524D]27U5.
M4U504$]25$5$+`H@("`@("`@("=F8G-Q;#IF8G-Q;"<@/3X@)V%R<F%Y)RP*
M("`@("`@("`G:6)A<V4Z:6)A<V4G(#T^($1"7T524D]27U5.4U504$]25$5$
M+`H@("`@("`@("=I8F%S93IF:7)E8FER9"<@/3X@1$)?15)23U)?54Y355!0
M3U)4140L"B`@("`@("`@)VEF>#II9G@G(#T^($1"7T524D]27U5.4U504$]2
M5$5$+`H@("`@("`@("=M<W%L.FUS<6PG(#T^($1"7T524D]27U5.4U504$]2
M5$5$+`H@("`@("`@("=M<W-Q;#IM<W-Q;"<@/3X@1$)?15)23U)?54Y355!0
M3U)4140L"B`@("`@("`@)VUY<W%L.FUY<W%L)R`]/B!$0E]%4E)/4E]53E-5
M4%!/4E1%1"P*("`@("`@("`G;7ES<6QI.FUY<W%L:2<@/3X@1$)?15)23U)?
M54Y355!03U)4140L"B`@("`@("`@)V]C:3@Z;V-I."<@/3X@1$)?15)23U)?
M54Y355!03U)4140L"B`@("`@("`@)V]D8F,Z86-C97-S)R`]/B!$0E]%4E)/
M4E]53E-54%!/4E1%1"P*("`@("`@("`G;V1B8SID8C(G(#T^($1"7T524D]2
M7U5.4U504$]25$5$+`H@("`@("`@("=P9W-Q;#IP9W-Q;"<@/3X@)V%R<F%Y
M)RP*("`@("`@("`G<W%L:71E.G-Q;&ET92<@/3X@1$)?15)23U)?54Y355!0
M3U)4140L"B`@("`@("`@)W-Y8F%S93IS>6)A<V4G(#T^($1"7T524D]27U5.
M4U504$]25$5$+`H@("`@*2P*("`@("=S8VAE;6$N=&%B;&5S)R`]/B!A<G)A
M>2@*("`@("`@("`G9&)A<V4Z9&)A<V4G(#T^($1"7T524D]27U5.4U504$]2
M5$5$+`H@("`@("`@("=F8G-Q;#IF8G-Q;"<@/3X@1$)?15)23U)?54Y355!0
M3U)4140L"B`@("`@("`@)VEB87-E.FEB87-E)R`]/B!$0E]%4E)/4E]53E-5
M4%!/4E1%1"P*("`@("`@("`G:6)A<V4Z9FER96)I<F0G(#T^($1"7T524D]2
M7U5.4U504$]25$5$+`H@("`@("`@("=I9G@Z:69X)R`]/B!$0E]%4E)/4E]5
M3E-54%!/4E1%1"P*("`@("`@("`G;7-Q;#IM<W%L)R`]/B!$0E]%4E)/4E]5
M3E-54%!/4E1%1"P*("`@("`@("`G;7-S<6PZ;7-S<6PG(#T^($1"7T524D]2
M7U5.4U504$]25$5$+`H@("`@("`@("=M>7-Q;#IM>7-Q;"<@/3X@1$)?15)2
M3U)?54Y355!03U)4140L"B`@("`@("`@)VUY<W%L:3IM>7-Q;&DG(#T^($1"
M7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=O8VDX.F]C:3@G(#T^($1"
M7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=O9&)C.F%C8V5S<R<@/3X@
M)V%R<F%Y)RP*("`@("`@("`G;V1B8SID8C(G(#T^("=A<G)A>2<L"B`@("`@
M("`@)W!G<W%L.G!G<W%L)R`]/B`G87)R87DG+`H@("`@("`@("=S<6QI=&4Z
M<W%L:71E)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G<WEB
M87-E.G-Y8F%S92<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`I+`H@
M("`@)W-Y;F]N>6US)R`]/B!A<G)A>2@*("`@("`@("`G9&)A<V4Z9&)A<V4G
M(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=F8G-Q;#IF8G-Q
M;"<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)VEB87-E.FEB
M87-E)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G:6)A<V4Z
M9FER96)I<F0G(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=I
M9G@Z:69X)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;7-Q
M;#IM<W%L)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;7-S
M<6PZ;7-S<6PG(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=M
M>7-Q;#IM>7-Q;"<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@
M)VUY<W%L:3IM>7-Q;&DG(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@
M("`@("=O8VDX.F]C:3@G(#T^("=A<G)A>2<L"B`@("`@("`@)V]D8F,Z86-C
M97-S)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;V1B8SID
M8C(G(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=P9W-Q;#IP
M9W-Q;"<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)W-Q;&ET
M93IS<6QI=&4G(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=S
M>6)A<V4Z<WEB87-E)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("DL
M"BD["@HO*BH*("H@1&5T97)M:6YE(&EF('1H92!O=71P=70@9G)O;2!T:&4@
M9')I=F5R(&UA=&-H97,@=VAA="!W92!E>'!E8W0*("H*("H@268@=&AI;F=S
M(&%R92!A<R!W92!E>'!E8W0L(&YO=&AI;F<@:7,@<')I;G1E9"!O=70N"B`J
M"B`J($EF('1H:6YG<R!G;R!W<F]N9RP@<')I;G0@(E5.15A014-4140@3U54
M0T]-12(@86YD(&1I<W!L87D*("H@=VAA="!H87!P96YE9"X*("H*("H@0'!A
M<F%M(&UI>&5D("`D<F5S=6QT("`@('1H92!R97-U;'0@9G)O;2!G971,:7-T
M3V8*("H@0'!A<F%M(&UI>&5D("`D97AP96-T960@('1H92!E>'!E8W1E9"!R
M97-U;'0*("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@('1H92!N86UE(&]F
M('1H92!C=7)R96YT('1E<W0*("H*("H@0')E='5R;B!V;VED"B`J+PIF=6YC
M=&EO;B!C:&5C:U]O=71P=70H)')E<W5L="P@)&5X<&5C=&5D+"`D;F%M92D@
M>PH@("`@:68@*&ES7V]B:F5C="@D<F5S=6QT*2D@>PH@("`@("`@(&EF("@D
M<F5S=6QT+3YG971#;V1E*"D@(3T]("1E>'!E8W1E9"D@>PH@("`@("`@("`@
M("!E8VAO(")53D584$5#5$5$($]55$-/344@1D]2("1N86UE+BXN7&XB.PH@
M("`@("`@("`@("!E8VAO("1R97-U;'0M/F=E=$1E8G5G26YF;R@I("X@(EQN
M(CL*("`@("`@("!]"B`@("!](&5L<V4@>PH@("`@("`@("1T>7!E(#T@9V5T
M='EP92@D<F5S=6QT*3L*("`@("`@("!I9B`H)'1Y<&4@(3T@)&5X<&5C=&5D
M*2!["B`@("`@("`@("`@(&EF("@D97AP96-T960@/3T]($1"7T524D]27T%#
M0T534U]624],051)3TX*("`@("`@("`@("`@("`@("8F("1T>7!E(#T]("=A
M<G)A>2<I"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@("\O(%1H:7,@
M=7-E<B!H87,@86-C97-S('1O('1H92!M>7-Q;"!T86)L92X*("`@("`@("`@
M("`@("`@("\O($YO="!A('!R;V)L96T*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@(&5C:&\@(E5.15A014-4140@3U540T]-12!&3U(@
M)&YA;64N+BY<;B(["B`@("`@("`@("`@("`@("!E8VAO("(@($5X<&5C=&5D
M.B`D97AP96-T961<;B(["B`@("`@("`@("`@("`@("!E8VAO("<@(%)E<W5L
M=#H@)SL*("`@("`@("`@("`@("`@('!R:6YT7W(H)')E<W5L="D["B`@("`@
M("`@("`@("`@("!E8VAO(")<;B(["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("!]"GT*"@HD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?
M4D5455).*3L*9F]R96%C:"`H)'1E<W1S(&%S("1T97-T(#T^("1D8FUS*2![
M"B`@("!C:&5C:U]O=71P=70H)&1B:"T^9V5T3&ES=$]F*"1T97-T*2P*("`@
M("`@("`@("`@("`@("`D9&)M<ULD9&)H+3YP:'!T>7!E("X@)SHG("X@)&1B
M:"T^9&)S>6YT87A=+`H@("`@("`@("`@("`@("`@("1T97-T*3L*?0H*"F1R
M;W!?=&%B;&4H)&1B:"P@)W!H<'1E<W0G*3L*"C\^"BTM15A014-4+2T*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O8V]N;F5C="YI;F,`
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-#`P(#$P-3$U-#,S-S,R(#`R-#8W
M,0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*+RHJ"B`J($-O;FYE8W1S('1O('1H92!D871A8F%S90H@*@H@*B!0
M2%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C
M92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L
M:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@H@*B!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C
M96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA
M8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90H@*B!S
M96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@
M>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@1&%T
M86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@1&%N:65L
M($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q
M.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*
M("H@0'9E<G-I;VX@("`@)$ED.B!C;VYN96-T+FEN8RQV(#$N,3(@,C`P-2\P
M,B\P,B`P,#HT,#HR,R!D86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B\*"F5R<F]R7W)E<&]R
M=&EN9RA%7T%,3"D["@HO+R!3971T:6YG(&]F("1O<'1I;VYS(&%N9"!R97%U
M:7)I;F<@1$(@87)E(&1O;F4@:6X@<V5T=7`N:6YC"@HO*BH*("H@17-T86)L
M:7-H('1H92!I;F-L=61E7W!A=&@L($133B=S(&%N9"!C;VYN96-T:6]N("1O
M<'1I;VYS"B`J+PIR97%U:7)E7V]N8V4@)RXO<V5T=7`N:6YC)SL*"FEF("AE
M;7!T>2@D9'-N<RDI('L*("`@(&1I92@G070@;&5A<W0@;VYE(&5L96UE;G0@
M;V8@)&1S;G,@;75S="!B92!D969I;F5D(&EN('-E='5P+FEN8R<I.PI]"@IL
M:7-T*"1D8FUS+"`D9'-N*2`](&5A8V@H)&1S;G,I.PH*:68@*"1D8FUS(#T]
M("=M<W-Q;"<I('L*("`@(&EN:5]S970H)VUS<W%L+G1E>'1L:6UI="<L(#0P
M.38I.PH@("`@:6YI7W-E="@G;7-S<6PN=&5X='-I>F4G+"`T,#DV*3L*?0H*
M)&1B:"`])B!$0CHZ8V]N;F5C="@D9'-N+"`D;W!T:6]N<RD["FEF("A$0CHZ
M:7-%<G)O<B@D9&)H*2D@>PH@("`@9&EE*"=C;VYN96-T+FEN8SH@)R`N("1D
M8F@M/G1O4W1R:6YG*"DI.PI]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E
M<W1S+V1R:79E<B]M:W1A8FQE+FEN8P``````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,3`Q-C0@,3`U,34T,S,W,S(@,#(T-C8U`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"@HO*BH*("H@0W)E871E<R!T
M:&4@/&MB9#YP:'!T97-T/"]K8F0^('1A8FQE"B`J"B`J(%1R:65S('1O(&1R
M;W`@=&AE('1A8FQE(&9I<G-T+"!I;B!C87-E(&ET(&%L<F5A9'D@97AI<W1S
M+@H@*@H@*B`\<')E/@H@*B!#4D5!5$4@5$%"3$4@<&AP=&5S="`H"B`J("`@
M82!)3E1%1T52($Y53$PL"B`J("`@8B!#2$%2*#0P*2!$149!54Q4("=D968G
M($Y/5"!.54Q,+`H@*B`@(&,@5D%20TA!4B@R-34I($Y53$PL"B`J("`@9"!6
M05)#2$%2*#(P*2!.54Q,*0H@*B`\+W!R93X*("H*("H@3F5E9"`\:V)D/DY/
M5"!.54Q,/"]K8F0^(&]N(#QK8F0^8CPO:V)D/B!T;R!T97-T"B`J(#QK8F0^
M1$)?4$]25$%"24Q)5%E?4E1224T\+VMB9#XN("!-4R!344P@86YD(%-Y8F%S
M92!T<FEM(&]U='!U="!F<F]M"B`J(#QK8F0^5D%20TA!4CPO:V)D/BP@8G5T
M(&YO="!O;B`\:V)D/D-(05(\+VMB9#XN"B`J"B`J($YE960@/&MB9#Y$149!
M54Q4/"]K8F0^('9A;'5E(&]N(#QK8F0^8CPO:V)D/B!B96-A=7-E($]R86-L
M92!C;VYS:61E<G,*("H@86X@96UP='D@<W1R:6YG('1O(&)E(#QK8F0^3E5,
M3#PO:V)D/BX*("H*("H@26X@3W)A8VQE+"!W:&5N('5S:6YG('!L86-E:&]L
M9&5R<R!I;B`\:V)D/E=(15)%/"]K8F0^(&-L875S97,@;VX@"B`J(#QK8F0^
M0TA!4CPO:V)D/B!C;VQU;6YS+"!T:&4@8V]L=6UN(&UU<W0@:&%V92`\:V)D
M/E)44DE-*"D\+VMB9#X@<G5N(&]N"B`J('1H92!C;VQU;6XZ"B`J(#QS86UP
M/@H@*B`@("!314Q%0U0@*B!&4D]-('!H<'1E<W0@5TA%4D4@4E1224TH8BD@
M/2`_"B`J(#PO<V%M<#X*("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*
M("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E
M<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90H@*B!T:&%T(&ES(&%V86EL
M86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W
M:6YG(%5223H*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H92!0
M2%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G
M:"!T:&4@=V5B+"!P;&5A<V4*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P
M:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN
M"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E"B`J($!P86-K86=E("`@($1"
M"B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP
M+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*
M("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@("1)9#H@;6MT
M86)L92YI;F,L=B`Q+C$Y(#(P,#4O,#(O,30@,C,Z,S,Z,C`@9&%N:65L8R!%
M>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA
M9V4O1$(*("HO"@HO*BH*("H@17-T86)L:7-H97,@=&AE($1"(&]B:F5C="!A
M;F0@8V]N;F5C=',@=&\@=&AE(&1A=&%B87-E"B`J+PIR97%U:7)E7V]N8V4@
M)RXO8V]N;F5C="YI;F,G.PH*+RHJ"B`J($=E="!T:&4@9')O<%]T86)L92@I
M(&9U;F-T:6]N"B`J+PIR97%U:7)E7V]N8V4@)RXO9')O<'1A8FQE+FEN8R<[
M"@HO*BH*("H@5&AE(&5R<F]R(&AA;F1L97(@9F]R('1H92!D<F]P('1A8FQE
M('!R;V-E9'5R90H@*@H@*B!0<FEN=',@;W5T(&%N(&5R<F]R(&UE<W-A9V4@
M86YD(&1I97,N"B`J+PIF=6YC=&EO;B!D96)U9U]D:64H)&\I>PH@("`@9&EE
M*"1O+3YT;U-T<FEN9R@I*3L*?0H*"B1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H
M4$5!4E]%4E)/4E]215154DXI.PID<F]P7W1A8FQE*"1D8F@L("=P:'!T97-T
M)RD["@HO+R1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]44DE'
M1T52*3L*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27T-!3$Q"
M04-++"`G9&5B=6=?9&EE)RD["@II9B`H)&1B:"T^<&AP='EP92`]/2`G;V1B
M8R<I('L*("`@(&EF("@D9&)H+3YD8G-Y;G1A>"`]/2`G;V1B8R<I('L*("`@
M("`@("`D='EP92`]("1D8F@M/G!H<'1Y<&4["B`@("!](&5L<V4@>PH@("`@
M("`@("1T>7!E(#T@)&1B:"T^9&)S>6YT87@["B`@("!]"GT@96QS92!["B`@
M("`D='EP92`]("1D8F@M/G!H<'1Y<&4["GT*"@IS=VET8V@@*"1T>7!E*2![
M"B`@("!C87-E("=A8V-E<W,G.@H@("`@("`@("1N=6QL(#T@)TY53$PG.PH@
M("`@("`@("1C:')C(#T@)U9!4D-(05(H,C4U*2<["B`@("`@("`@)&-H<F0@
M/2`G5D%20TA!4B@R,"DG.PH@("`@("`@("1D969A=6QT(#T@)R<["B`@("`@
M("`@)'1A8FQE='EP92`]("<G.PH@("`@("`@(&)R96%K.PH@("`@8V%S92`G
M9&(R)SH*("`@(&-A<V4@)VEB87-E)SH*("`@("`@("`D;G5L;"`]("<G.PH@
M("`@("`@("1C:')C(#T@)U9!4D-(05(H,C4U*2<["B`@("`@("`@)&-H<F0@
M/2`G5D%20TA!4B@R,"DG.PH@("`@("`@("1D969A=6QT(#T@(D1%1D%53%0@
M)V1E9B<@3D]4($Y53$PB.PH@("`@("`@("1T86)L971Y<&4@/2`G)SL*("`@
M("`@("!B<F5A:SL*("`@(&-A<V4@)V9B<W%L)SH*("`@("`@("`D;G5L;"`]
M("<G.PH@("`@("`@("1C:')C(#T@)T-(05(H,C4U*2<["B`@("`@("`@)&-H
M<F0@/2`G0TA!4B@R,"DG.PH@("`@("`@("1D969A=6QT(#T@(D1%1D%53%0@
M)V1E9B<@3D]4($Y53$PB.PH@("`@("`@("1D871E7VQI=&5R86P@/2`G($1!
M5$4@)SL*("`@("`@("`D=&%B;&5T>7!E(#T@)R<["B`@("`@("`@8G)E86L[
M"B`@("!C87-E("=I9G@G.@H@("`@("`@("\O(&1O:6YG('1H:7,@9F]R(&EF
M>"!T;R!K965P(&-E<G1A:6X@=F5R<VEO;G,@:&%P<'D*("`@("`@("`D;G5L
M;"`]("<G.PH@("`@("`@("1C:')C(#T@)T-(05(H,C4U*2<["B`@("`@("`@
M)&-H<F0@/2`G0TA!4B@R,"DG.PH@("`@("`@("1D969A=6QT(#T@(D1%1D%5
M3%0@)V1E9B<@3D]4($Y53$PB.PH@("`@("`@("1T86)L971Y<&4@/2`G)SL*
M("`@("`@("!B<F5A:SL*("`@(&-A<V4@)VUS<6PG.@H@("`@("`@("1N=6QL
M(#T@)R<["B`@("`@("`@)&-H<F,@/2`G0TA!4B@R-34I)SL*("`@("`@("`D
M8VAR9"`]("=#2$%2*#(P*2<["B`@("`@("`@)&1E9F%U;'0@/2`G)SL*("`@
M("`@("`D=&%B;&5T>7!E(#T@)R<["B`@("`@("`@8G)E86L["B`@("!C87-E
M("=M>7-Q;"<Z"B`@("!C87-E("=M>7-Q;&DG.@H@("`@("`@("1N=6QL(#T@
M)TY53$PG.PH@("`@("`@("1C:')C(#T@)U9!4D-(05(H,C4U*2<["B`@("`@
M("`@)&-H<F0@/2`G5D%20TA!4B@R,"DG.PH@("`@("`@("1D969A=6QT(#T@
M(D1%1D%53%0@)V1E9B<@3D]4($Y53$PB.PH@("`@("`@(&EF("@A96UP='DH
M)&YE961I;FYO9&(I*2!["B`@("`@("`@("`@("1T86)L971Y<&4@/2`G5%E0
M13U)3DY/1$(G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T86)L
M971Y<&4@/2`G)SL*("`@("`@("!]"B`@("`@("`@8G)E86L["B`@("!D969A
M=6QT.@H@("`@("`@("1N=6QL(#T@)TY53$PG.PH@("`@("`@("1C:')C(#T@
M)U9!4D-(05(H,C4U*2<["B`@("`@("`@)&-H<F0@/2`G5D%20TA!4B@R,"DG
M.PH@("`@("`@("1D969A=6QT(#T@(D1%1D%53%0@)V1E9B<@3D]4($Y53$PB
M.PH@("`@("`@("1T86)L971Y<&4@/2`G)SL*?0H*<W=I=&-H("@D9&)H+3YP
M:'!T>7!E*2!["B`@("!C87-E("=D8F%S92<Z"B`@("`@("`@+R\@9FEL92!E
M>&ES=',@;W(@=V%S(&-R96%T960@:6X@1$)?9&)A<V4Z.F-O;FYE8W0H*0H@
M("`@("`@(&)R96%K.PH@("`@9&5F875L=#H*("`@("`@("`D=&5S=%]M:W1A
M8FQE7W%U97)Y(#T@(@H@("`@("`@("`@("!#4D5!5$4@5$%"3$4@<&AP=&5S
M="`H"B`@("`@("`@("`@("`@82!)3E1%1T52("1N=6QL+`H@("`@("`@("`@
M("`@(&(@0TA!4B@T,"D@)&1E9F%U;'0L"B`@("`@("`@("`@("`@8R`D8VAR
M8R`D;G5L;"P*("`@("`@("`@("`@("!D("1C:')D("1N=6QL*2`D=&%B;&5T
M>7!E"B`@("`@("`@(CL*?0H*"B1D8F@M/G%U97)Y*"1T97-T7VUK=&%B;&5?
M<75E<GDI.PHD9&)H+3YQ=65R>2@B24Y315)4($E.5$\@<&AP=&5S="!604Q5
M15,H-#(L("=B:6YG)RP@)U1H:7,@:7,@82!T97-T)RP@)S$Y.3DM,3$M,C$G
M*2(I.PH*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%52
M3BD["@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R
M+VUU;'1I8V]N;F5C="YP:'``````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-3$P-R`Q,#4Q
M-30S,S<S,B`P,C4W-S$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*"B\J*@H@*B!497-T<R!T:&4@=F%R:6]U<R!W
M87ES($1")W,@8V]N;F5C="@I(&9U;F-T:6]N(&]P97)A=&5S"B`J"B`J(%!(
M4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E
M(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI
M8V5N<V4*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E
M:79E(&$@8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B
M;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E
M;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y
M;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!$871A
M8F%S90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!$86YI96P@
M0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y
M.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@
M*B!`=F5R<VEO;B`@("`D260Z(&UU;'1I8V]N;F5C="YP:'`L=B`Q+C(@,C`P
M-2\P,B\P,R`P-3HT.3HT-2!D86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B!`<VEN8V4@("`@
M("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-RXP"B`J+PH*+RHJ
M"B`J($5S=&%B;&ES:"!T:&4@:6YC;'5D95]P871H+"!$4TXG<R!A;F0@8V]N
M;F5C=&EO;B`D;W!T:6]N<PH@*B\*<F5Q=6ER95]O;F-E("<N+W-E='5P+FEN
M8R<["@IF;W)E86-H("@D9'-N<R!A<R`D9&)M<R`]/B`D9'-N*2!["B`@("!E
M8VAO("(]/3T]/3T]/2`D9&)M<R`]/3T]/3T]/5QN(CL*("`@("1O<'1I;VYS
M6R=P97)S:7-T96YT)UT@/2!F86QS93L*("`@("1D8F@@/28@1$(Z.F-O;FYE
M8W0H)&1S;BP@)&]P=&EO;G,I.PH@("`@:68@*$1".CII<T5R<F]R*"1D8F@I
M*2!["B`@("`@("`@96-H;R`G4%)/0DQ%33H@)R`N("1D8F@M/F=E=%5S97))
M;F9O*"D@+B`B7&XB.PH@("`@("`@(&-O;G1I;G5E.PH@("`@?0H*("`@(&EF
M("@D9&)H+3YP<F]V:61E<R@G;F5W7VQI;FLG*0H@("`@("`@("8F('9E<G-I
M;VY?8V]M<&%R92AP:'!V97)S:6]N*"DL("1D8F@M/G!R;W9I9&5S*"=N97=?
M;&EN:R<I+"`G/CTG*2D*("`@('L*("`@("`@("`D<')O8G,@/2!F86QS93L*
M("`@("`@("`D9'-N(#T@1$(Z.G!A<G-E1%-.*"1D<VXI.PH@("`@("`@("1D
M<VY;)VYE=U]L:6YK)UT@/2!T<G5E.PH@("`@("`@("1D8F@@/28@1$(Z.F-O
M;FYE8W0H)&1S;BP@)&]P=&EO;G,I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O
M<B@D9&)H*2D@>PH@("`@("`@("`@("!E8VAO("=.15<@3$E.2R!04D]"3$5-
M.B`G("X@)&1B:"T^9V5T57-E<DEN9F\H*2`N(")<;B(["B`@("`@("`@("`@
M("1P<F]B<R`]('1R=64["B`@("`@("`@?0H*("`@("`@("!I9B`H)&1B:"T^
M<')O=FED97,H)W!C;VYN96-T)RDI('L*("`@("`@("`@("`@)&]P=&EO;G-;
M)W!E<G-I<W1E;G0G72`]('1R=64["B`@("`@("`@("`@("1D8F@M/F1I<V-O
M;FYE8W0H*3L*("`@("`@("`@("`@)&1B:"`])B!$0CHZ8V]N;F5C="@D9'-N
M+"`D;W!T:6]N<RD["B`@("`@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D9&)H
M*2D@>PH@("`@("`@("`@("`@("`@96-H;R`G4$524TE35"!.15=#3TX@4%)/
M0DQ%33H@)R`N("1D8F@M/F=E=%5S97));F9O*"D@+B`B7&XB.PH@("`@("`@
M("`@("`@("`@)'!R;V)S(#T@=')U93L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@=6YS970H)&1S;ELG;F5W7VQI;FLG72D["B`@("`@("`@("`@("1D
M8F@M/F1I<V-O;FYE8W0H*3L*("`@("`@("`@("`@)&1B:"`])B!$0CHZ8V]N
M;F5C="@D9'-N+"`D;W!T:6]N<RD["B`@("`@("`@("`@(&EF("A$0CHZ:7-%
M<G)O<B@D9&)H*2D@>PH@("`@("`@("`@("`@("`@96-H;R`G4$524TE35"!/
M3$1#3TX@4%)/0DQ%33H@)R`N("1D8F@M/F=E=%5S97));F9O*"D@+B`B7&XB
M.PH@("`@("`@("`@("`@("`@)'!R;V)S(#T@=')U93L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!I9B`H)'!R;V)S*2!["B`@("`@("`@("`@
M(&-O;G1I;G5E.PH@("`@("`@('T*("`@("`@("`D9&)H+3YD:7-C;VYN96-T
M*"D["@H@("`@?2!E;'-E:68@*"1D8F@M/G!R;W9I9&5S*"=P8V]N;F5C="<I
M*2!["B`@("`@("`@)&]P=&EO;G-;)W!E<G-I<W1E;G0G72`]('1R=64["B`@
M("`@("`@)&1B:"T^9&ES8V]N;F5C="@I.PH@("`@("`@("1D8F@@/28@1$(Z
M.F-O;FYE8W0H)&1S;BP@)&]P=&EO;G,I.PH@("`@("`@(&EF("A$0CHZ:7-%
M<G)O<B@D9&)H*2D@>PH@("`@("`@("`@("!E8VAO("=015)325-4(%!23T),
M14TZ("<@+B`D9&)H+3YG9715<V5R26YF;R@I("X@(EQN(CL*("`@("`@("`@
M("`@8V]N=&EN=64["B`@("`@("`@?0H@("`@("`@("1D8F@M/F1I<V-O;FYE
M8W0H*3L*("`@('T*("`@(&5C:&\@(D=/3T1<;B(["GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O<G5N+F-V<P``````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`Q-C8P(#$P-3$U-#,S-S,R(#`R-#`W-0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````C(2`O
M8FEN+W-H"@HC("1)9#H@<G5N+F-V<RQV(#$N,B`R,#`T+S`R+S(P(#$X.C4W
M.C4R(&1A;FEE;&,@17AP("0*"B,@=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V
M=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G8*(R!014%2($1"(%1%4U0@4U1!
M4E1%4@HC"B,@("!4;R!R=6X@86QL('1E<W1S.B`@+B]R=6X*(R`@(%1O(')U
M;B!O;F4@=&5S=#H@("`N+W)U;B`\=&5S="!F:6QE(&YA;64^"B,@("!%>&%M
M<&QE.B`@("`@("`@("`@+B]R=6X@9&)?<&%R<V5D<VXN<&AP=`HC"B,@0F5F
M;W)E(')U;FYI;F<@=&AE('1E<W1S('EO=2!M=7-T(&%D:G5S="!T:&4*(R!F
M;VQL;W=I;F<@=&AR964@=F%R:6%B;&5S.@H*(R`@(%1H92!F=6QL('!A=&@@
M=&\@>6]U<B!02%`@9&ER96-T;W)Y.@H@("`@1$)?5$535%]02%!?4$%42#UC
M.B]P<F]G<F%^,2]P:'`*"B,@("!4:&4@;F%M92!O9B!Y;W5R(%!(4"!#3$D@
M97AE8W5T86)L90HC("`@*&5X86UP;&5S('!H<"YE>&4L('!H<"UC;&DN97AE
M+"!C;&DO<&AP+F5X92DZ"B`@("!$0E]415-47U!(4%]#3$D]<&AP+F5X90H*
M(R`@(%1H92!F=6QL('!A=&@@=&\@=&AE('!R97-E;G0@9&ER96-T;W)Y"B,@
M("`H;F]T('5S:6YG("105T0@9'5E('1O($-Y9W=I;BDZ"B`@("!$0E]415-4
M7T1)4CUD.B]P96%R=&5S="]P96%R+T1"+W1E<W1S+V1R:79E<@H*(R!>7EY>
M7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>
M7@H*"@I415-47U!(4%]%6$5#551!0DQ%/21$0E]415-47U!(4%]0051(+R1$
M0E]415-47U!(4%]#3$D*97AP;W)T(%1%4U1?4$A07T5814-55$%"3$4*"FEF
M(%L@)",@+6=T(#`@70IT:&5N"B`@("!T97-T/20Q"F5L<V4*("`@('1E<W0]
M*BYP:'!T"F9I"@HD5$535%]02%!?15A%0U5404),12`D1$)?5$535%]02%!?
M4$%42"]R=6XM=&5S=',N<&AP("1$0E]415-47T1)4B\D>W1E<W1]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O<V5T=7`N:6YC
M+F-V<P```````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`W-38P(#$P-3$U-#,S-S,R(#`R
M-3(P-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`H*+RHJ"B`J($5S=&%B;&ES:&5S('1H92!I;F-L=61E7W!A=&@L
M($133B=S(&%N9"!C;VYN96-T:6]N("1O<'1I;VYS"B`J"B`J($EF('1H:7,@
M9FEL92!I<R!N86UE9"`B<V5T=7`N:6YC+F-V<RPB(&ET(&ES('1H92!O<FEG
M:6YA;"!O;F4@9G)O;2!#5E,N"B`J(%!L96%S92!D;R!T:&4@9F]L;&]W:6YG
M.@H@*B`@(#$I($UA:V4@82!C;W!Y(&]F('1H:7,@9FEL92!N86UE9"`B<V5T
M=7`N:6YC(BX*("H@("`R*2!4:&5N+"!I;B!T:&4@8V]P>2P@961I="!T:&4@
M)&1S;G,@87)R87D@87,@87!P<F]P<FEA=&4@9F]R('EO=7(*("H@("`@("!E
M;G9I<F]N;65N="X*("H@("`S*2!!="!L96%S="!O;F4@96QE;65N="!O9B!T
M:&4@)&1S;G,@87)R87D@;F5E9',@=&\@8F4@=6YC;VUM96YT960N"B`J"B`J
M(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U
M<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0
M(&QI8V5N<V4*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R
M96-E:79E(&$@8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U
M;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J
M('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I
M;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!$
M871A8F%S90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!$86YI
M96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@
M(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N
M,`H@*B!`=F5R<VEO;B`@("`D260Z('-E='5P+FEN8RYC=G,L=B`Q+C8@,C`P
M-2\P,B\Q-"`R,SHS,SHR,"!D86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B\*"FEF("@A9&5F
M:6YE9"@G4$%42%]315!!4D%43U(G*2D@>PH@("`@:68@*'-T<FES='(H4$A0
M7T]3+"`G5TE.)RDI('L*("`@("`@("`O*BH*("`@("`@("`@*B!4:&4@<W1R
M:6YG('5S960@=&\@9&5L:6UI="!E;&5M96YT<R!O9B!T:&4@<&%T:"X*("`@
M("`@("`@*B\*("`@("`@("!D969I;F4H)U!!5$A?4T5005)!5$]2)RP@)SLG
M*3L*("`@('T@96QS92!["B`@("`@("`@+RHJ"B`@("`@("`@("H@5&AE('-T
M<FEN9R!U<V5D('1O(&1E;&EM:70@96QE;65N=',@;V8@=&AE('!A=&@N"B`@
M("`@("`@("HO"B`@("`@("`@9&5F:6YE*"=0051(7U-%4$%2051/4B<L("<Z
M)RD["B`@("!]"GT*"B\J"B`J($EF('1H92!P871H('1O('EO=7(@4$5!4B!I
M;G-T86QL871I;VX@:7,@9F]U;F0@:6X@=&AE(&QE9G0@:&%N9`H@*B!P;W)T
M:6]N(&]F('1H92!I9B@I(&5X<')E<W-I;VX@8F5L;W<L('1H870@;65A;G,@
M=&AI<R!F:6QE(&AA<PH@*B!C;VUE(&9R;VT@=&AE(%!%05(@:6YS=&%L;&5R
M+B`@5&AE<F5F;W)E+"!L970G<R!U<V4@=&AE"B`J(&EN<W1A;&QE9"!V97)S
M:6]N(&]F($1"+"!W:&EC:"!S:&]U;&0@8F4@9F]U;F0@=FEA('1H90H@*B!C
M;VUP=71E<B=S(&1E9F%U;'0@:6YC;'5D95]P871H+B`@061D("<N)R!T;R!T
M:&4@:6YC;'5D95]P871H"B`J('1O(&5N<W5R92`G+B<@:7,@:6X@=&AE<F4N
M"B`J(`H@*B!)9B!T:&4@<&%T:"!H87,@;F]T(&)E96X@<W5B<W1I='5T960@
M:6X@=&AE(&EF*"D@97AP<F5S<VEO;BP*("H@=&AI<R!F:6QE(&AA<R!L:6ME
M;'D@8V]M92!F<F]M(&$@0U93(&-H96-K;W5T(&]R(&$@+G1A<B!F:6QE+@H@
M*B!4:&5R969O<F4L('=E)VQL(&%S<W5M92!T:&4@=&5S=',@<VAO=6QD('5S
M92!T:&4@=F5R<VEO;B!O9@H@*B!$0B!T:&%T(&AA<R!C;VUE(&9R;VT@=&AE
M<F4@87,@=V5L;"X*("HO"FEF("@G+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(G("$]("=`)RXG:6YC;'5D95]P871H)RXG0"<I('L*("`@(&EN:5]S
M970H)VEN8VQU9&5?<&%T:"<L(&EN:5]G970H)VEN8VQU9&5?<&%T:"<I"B`@
M("`@("`@("`@("X@4$%42%]315!!4D%43U(@+B`G+B<*("`@("D["GT@96QS
M92!["B`@("!I;FE?<V5T*"=I;F-L=61E7W!A=&@G+"!R96%L<&%T:"AD:7)N
M86UE*%]?1DE,15]?*2`N("<O+BXO+BXG*0H@("`@("`@("`@("`N(%!!5$A?
M4T5005)!5$]2("X@)RXG("X@4$%42%]315!!4D%43U(*("`@("`@("`@("`@
M+B!I;FE?9V5T*"=I;F-L=61E7W!A=&@G*0H@("`@*3L*?0H*+RHJ"B`J($=R
M86(@=&AE(%!%05(@1$(@8VQA<W-E<RX*("HO"G)E<75I<F5?;VYC92`G1$(N
M<&AP)SL*"B\O($]P=&EO;G,@=7-E9"!W:&5N(&-O;FYE8W1I;F<*)&]P=&EO
M;G,@/2!A<G)A>2@*("`@("\O)V]P=&EM:7IE)R`]/B`G<&]R=&%B:6QI='DG
M+`H@("`@)W!O<G1A8FEL:71Y)R`]/B!$0E]03U)404))3$E465]!3$PL"B`@
M("`G9&5B=6<G(#T^(#(L"BD["@HD9&)A<V5D<VX@/2!A<G)A>2@*("`@("=P
M:'!T>7!E)R`@/3X@)V1B87-E)RP*("`@("=D871A8F%S92<@/3X@)R]P871H
M+V%N9"]N86UE+V]F+V1B87-E+V9I;&4G+`H@("`@)VUO9&4G("`@("`]/B`R
M+`H@("`@)V9I96QD<R<@("`]/B!A<G)A>2@*("`@("`@("!A<G)A>2@G82<L
M("=.)RP@-2P@,"DL"B`@("`@("`@87)R87DH)V(G+"`G0R<L(#0P*2P*("`@
M("`@("!A<G)A>2@G8R<L("=#)RP@,C4U*2P*("`@("`@("!A<G)A>2@G9"<L
M("=#)RP@,C`I+`H@("`@*2P**3L*"B\J"B`J(%5N8V]M;65N="!A="!L96%S
M="!O;F4@;V8@=&AE(&9O;&QO=VEN9R!E;&5M96YT<RX*("H@5VAE;B!R=6YN
M:6YG('1H92`N<&AP="!T97-T<RP@=&AE(&9I<G-T('5N8V]M;65N=&5D(&5L
M96UE;G0@:7,@=7-E9"X*("H@5VAE;B!R=6YN:6YG('1H92!M=6QT:6-O;FYE
M8W0N<&AP('1E<W0L(&%L;"!U;F-O;6UE;G1E9"!E;&5M96YT<R!A<F4@=7-E
M9"X*("HO"B1D<VYS(#T@87)R87DH"B`@("`O+R`G9&)A<V4G("`@(#T^("1D
M8F%S961S;BP*("`@("\O("=F8G-Q;"<@("`@/3X@)V9B<W%L.B\O7W-Y<W1E
M;3I`+V1B)RP*("`@("\O("=F:7)E8FER9"<@/3X@)VEB87-E*&9I<F5B:7)D
M*3HO+U-94T1"03IM87-T97)K97E`+R]O<'0O:6YT97)B87-E+V5X86UP;&5S
M+V5M<&QO>65E+F=D8C]D:6%L96-T/3,G+`H@("`@+R\@)VEF>"<@("`@("`]
M/B`G:69X.B\O=7-E<CIP=T!L;V-A;&AO<W0O9&(G+`H@("`@+R\@)VUS<6PG
M("`@("`]/B`G;7-Q;#HO+R]D8B<L"@H@("`@+R\@270G<R!A9'9I<V%B;&4@
M=&\@=7-E(&]N;'D@;VYE(&]F('1H92!F;VQL;W=I;F<@870@82!T:6UE.@H@
M("`@+R\@)VUS<W%L)R`@("`]/B`G;7-S<6PZ+R]S84!S;VUE:&]S="]P=6)S
M)RP*("`@("\O("=S>6)A<V4G("`@/3X@)W-Y8F%S93HO+W-A0'-O;65H;W-T
M+W!U8G,G+`H*("`@("\O("=M>7-Q;"<@("`@/3X@)VUY<W%L.B\O<F]O=$!L
M;V-A;&AO<W0O=&5S="<L"B`@("`O+R`G;7ES<6QI)R`@(#T^("=M>7-Q;&DZ
M+R]R;V]T0&QO8V%L:&]S="]T97-T)RP*("`@("\O("=O8VDX)R`@("`@/3X@
M)V]C:3@Z+R]S>7-T96TZ;6%N86=E<D`G+`H@("`@+R\@)V%C8V5S<R<@("`]
M/B`G;V1B8RAA8V-E<W,I.B\O861M:6Y`+U-Y<W1E;41S;DYA;64G+`H@("`@
M+R\@)V1B,B<@("`@("`]/B`G;V1B8RAD8C(I.B\O9&(R:6YS=#$Z6%A86$`O
M4T%-4$Q%)RP*("`@("\O("=P9W-Q;"<@("`@/3X@)W!G<W%L.B\O<&]S=&=R
M97-`;&]C86QH;W-T+W1E<W0G+`H@("`@+R\@)W-Q;&ET92<@("`]/B`G<W%L
M:71E.B\O9'5M;7DZ0&QO8V%L:&]S="\G("X@9V5T8W=D*"D@+B!$25)%0U1/
M4EE?4T5005)!5$]2("X@)W1E<W0N9&(_;6]D93TP-C0T)RP**3L*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T
M<R]D<FEV97(O<VMI<&EF+FEN8P``````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R
M,3(V(#$P-3$U-#,S-S,R(#`R-#4S,@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`H*+RHJ"B`J($$@=&5S="!T;R!M
M86ME('-U<F4@=&AE(&1A=&%B87-E(&-A;B!B92!C;VYN96-T960@=&\*("H*
M("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S
M;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!0
M2%`@;&EC96YS90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E
M('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*
M("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M
M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@
M($1A=&%B87-E"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@($1A
M;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H
M="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@
M,RXP"B`J($!V97)S:6]N("`@("1)9#H@<VMI<&EF+FEN8RQV(#$N-R`R,#`U
M+S`R+S`R(#`P.C0P.C(S(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@
M:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J+PH*+RHJ"B`J($5S
M=&%B;&ES:"!T:&4@:6YC;'5D95]P871H+"!$4TXG<R!A;F0@8V]N;F5C=&EO
M;B`D;W!T:6]N<PH@*B\*<F5Q=6ER95]O;F-E("<N+W-E='5P+FEN8R<["@II
M9B`H96UP='DH)&1S;G,I*2!["B`@("!D:64H)W-K:7`@070@;&5A<W0@;VYE
M(&5L96UE;G0@;V8@)&1S;G,@;75S="!B92!D969I;F5D(&EN('-E='5P+FEN
M8R<I.PI]"@IL:7-T*"1D8FUS+"`D9'-N*2`](&5A8V@H)&1S;G,I.PH*)&1B
M:"`])B!$0CHZ8V]N;F5C="@D9'-N+"`D;W!T:6]N<RD["FEF("A$0CHZ:7-%
M<G)O<B@D9&)H*2D@>PH@("`@9&EE*"=S:VEP("<@+B`D9&)H+3YM97-S86=E
M*3L*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<B\P,6-O;FYE8W0N<&AP
M=```````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,R-30@,3`U,34T,S,W,S(@,#(U,C0T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"TM
M5$535"TM"D1"7V1R:79E<CHZ8V]N;F5C=`HM+4E.22TM"F5R<F]R7W)E<&]R
M=&EN9R`](#(P-#<*+2U32TE0248M+0H\/W!H<"!C:&1I<BAD:7)N86UE*%]?
M1DE,15]?*2D[(')E<75I<F5?;VYC92`G+B]S:VEP:68N:6YC)SL@/SX*+2U&
M24Q%+2T*/#]P:'`*<F5Q=6ER95]O;F-E("<N+V-O;FYE8W0N:6YC)SL*"B\J
M*@H@*B!$971E<FUI;F4@:68@=&AE(&1A=&%B87-E(&-O;FYE8W1I;VX@;6%T
M8VAE<R!W:&%T)W,@97AP96-T960*("H*("H@0'!A<F%M(&]B:F5C="`D9&)H
M("`@=&AE(%!%05(@1$(@;V)J96-T"B`J($!P87)A;2!S=')I;F<@)&YA;64@
M('1H92!N86UE(&]F('1H92!C=7)R96YT('1E<W0*("H*("H@0')E='5R;B!V
M;VED"B`J+PIF=6YC=&EO;B!C:&5C:U]D8F@H)&1B:"P@)&YA;64I('L*("`@
M(&EF("A$0CHZ:7-%<G)O<B@D9&)H*2D@>PH@("`@("`@(&1I92@G8V]N;F5C
M="YI;F,Z("<@+B`D9&)H+3YT;U-T<FEN9R@I*3L*("`@('T*("`@(&EF("AI
M<U]O8FIE8W0H)&1B:"DI('L*("`@("`@("!P<FEN="`B)&YA;64@:7,@86X@
M;V)J96-T7&XB.PH@("`@?0H@("`@<W=I=&-H("@D9&)H+3YP:'!T>7!E*2![
M"B`@("`@("`@8V%S92`G9&)A<V4G.@H@("`@("`@("`@("!I9B`H:7-?:6YT
M*"1D8F@M/F-O;FYE8W1I;VXI*2!["B`@("`@("`@("`@("`@("!P<FEN="`B
M)&YA;64@:7,@8V]N;F5C=&5D7&XB.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@<')I;G0@(B1N86UE($Y/5"!C;VYN96-T961<;B([
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["B`@("`@("`@8V%S
M92`G;7ES<6QI)SH*("`@("`@("`@("`@:68@*&ES7V$H)&1B:"T^8V]N;F5C
M=&EO;BP@)VUY<W%L:2<I*2!["B`@("`@("`@("`@("`@("!P<FEN="`B)&YA
M;64@:7,@8V]N;F5C=&5D7&XB.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@<')I;G0@(B1N86UE($Y/5"!C;VYN96-T961<;B(["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["B`@("`@("`@9&5F875L
M=#H*("`@("`@("`@("`@:68@*&=E='1Y<&4H)&1B:"T^8V]N;F5C=&EO;BD@
M/3T@)W)E<V]U<F-E)RD@>PH@("`@("`@("`@("`@("`@<')I;G0@(B1N86UE
M(&ES(&-O;FYE8W1E9%QN(CL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@('!R:6YT("(D;F%M92!.3U0@8V]N;F5C=&5D7&XB.PH@("`@
M("`@("`@("!]"B`@("!]"GT*"@IC:&5C:U]D8F@H)&1B:"P@)R1D8F@G*3L*
M"@HD=&5S=%]A<G)A>5]D<VX@/2!$0CHZ<&%R<V5$4TXH)&1S;BD["F9O<F5A
M8V@@*"1T97-T7V%R<F%Y7V1S;B!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@
M:68@*"1V86QU92`]/3T@9F%L<V4I('L*("`@("`@("!U;G-E="@D=&5S=%]A
M<G)A>5]D<VY;)&ME>5TI.PH@("`@?0I]"@HD9&)H82`])B!$0CHZ8V]N;F5C
M="@D=&5S=%]A<G)A>5]D<VXL("1O<'1I;VYS*3L*8VAE8VM?9&)H*"1D8FAA
M+"`G)&1B:&$G*3L*"@HD=&UP("`]('-E<FEA;&EZ92@D9&)H82D["B1D8FAU
M(#T@=6YS97)I86QI>F4H)'1M<"D["F-H96-K7V1B:"@D9&)H=2P@)R1D8FAU
M)RD["@H_/@HM+4584$5#5"TM"B1D8F@@:7,@86X@;V)J96-T"B1D8F@@:7,@
M8V]N;F5C=&5D"B1D8FAA(&ES(&%N(&]B:F5C=`HD9&)H82!I<R!C;VYN96-T
M960*)&1B:'4@:7,@86X@;V)J96-T"B1D8FAU(&ES(&-O;FYE8W1E9`H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O,#)F971C:"YP:'!T````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`R,38P(#$P-3$U-#,S-S,R(#`R-#<P,``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````M+51%4U0M
M+0I$0E]D<FEV97(Z.F9E=&-H"BTM24Y)+2T*97)R;W)?<F5P;W)T:6YG(#T@
M,C`T-PHM+5-+25!)1BTM"CP_<&AP(&-H9&ER*&1I<FYA;64H7U]&24Q%7U\I
M*3L@<F5Q=6ER95]O;F-E("<N+W-K:7!I9BYI;F,G.R`_/@HM+49)3$4M+0H\
M/W!H<`IR97%U:7)E7V]N8V4@)RXO;6MT86)L92YI;F,G.PIR97%U:7)E7V]N
M8V4@)RXN+V9E=&-H;6]D97,N:6YC)SL*/SX*+2U%6%!%0U0M+0IT97-T:6YG
M(&9E=&-H<F]W.@IR;W<@,3H@-#(L(&)I;F<L(%1H:7,@:7,@82!T97-T+"`Q
M.3DY+3$Q+3(Q"G)O=R`R.B`Q+"!O;F4L($]N92P@,C`P,2TP,BTQ-@IR;W<@
M,SH@,BP@='=O+"!4=V\L(#(P,#$M,#(M,34*<F]W(#0Z(#,L('1H<F5E+"!4
M:')E92P@,C`P,2TP,BTQ-`IR;W<@-3H@3E5,3`IT97-T:6YG(&9E=&-H;6]D
M97,Z(&9E=&-H<F]W(&1E9F%U;'0@9&5F875L="P@<&]R=&%B:6QI='D@;6]D
M92!$0E]03U)404))3$E465]!3$P@7B!$0E]03U)404))3$E465]25%))30HP
M(#$@,B`S"F]U='!U="!M871C:&5D(&5X<&5C=&5D(&9O<FUA=`IT97-T:6YG
M(&9E=&-H;6]D97,Z(&9E=&-H:6YT;R!D969A=6QT(&1E9F%U;'0*,"`Q(#(@
M,PHT,B!B:6YG(%1H:7,@:7,@82!T97-T(#$Y.3DM,3$M,C$*=&5S=&EN9R!F
M971C:&UO9&5S.B!F971C:')O=R!O<F1E<F5D(&1E9F%U;'0*,"`Q(#(@,PIT
M97-T:6YG(&9E=&-H;6]D97,Z(&9E=&-H<F]W(&%S<V]C(&1E9F%U;'0*82!B
M(&,@9`IT97-T:6YG(&9E=&-H;6]D97,Z(&9E=&-H<F]W(&]R9&5R960@9&5F
M875L="!W:71H(&%S<V]C('-P96-I9FEE9`IA(&(@8R!D"G1E<W1I;F<@9F5T
M8VAM;V1E<SH@9F5T8VAR;W<@87-S;V,@9&5F875L="!W:71H(&]R9&5R960@
M<W!E8VEF:65D"C`@,2`R(#,*=&5S=&EN9R!F971C:&UO9&5S.B!F971C:&EN
M=&\@;W)D97)E9"!D969A=6QT"C`@,2`R(#,*=&5S=&EN9R!F971C:&UO9&5S
M.B!F971C:&EN=&\@87-S;V,@9&5F875L=`IA(&(@8R!D"G1E<W1I;F<@9F5T
M8VAM;V1E<SH@9F5T8VAI;G1O(&]R9&5R960@9&5F875L="!W:71H(&%S<V]C
M('-P96-I9FEE9`IA(&(@8R!D"G1E<W1I;F<@9F5T8VAM;V1E<SH@9F5T8VAI
M;G1O(&%S<V]C(&1E9F%U;'0@=VET:"!O<F1E<F5D('-P96-I9FEE9`HP(#$@
M,B`S"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1B
M7V9A8W1O<GDN<&AP=```````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(W,3$@
M,3`U,34T,S,W,S(@,#(T,C<P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"TM5$535"TM"D1".CIF86-T;W)Y"BTM4TM)4$E&
M+2T*/#]P:'`@8VAD:7(H9&ER;F%M92A?7T9)3$5?7RDI.R!R97%U:7)E7V]N
M8V4@)RXO<VMI<&EF+FEN8R<[(#\^"BTM1DE,12TM"CP_<&AP("\O("TJ+2!#
M*RL@+2HM"G)E<75I<F5?;VYC92`G+B]I;F-L=61E+FEN8R<["G)E<75I<F5?
M;VYC92`G1$(N<&AP)SL*"B1B86-K96YD<R`](&%R<F%Y*`H@("`@)V1B87-E
M)RP*("`@("=F8G-Q;"<L"B`@("`G:6)A<V4G+`H@("`@)VEF>"<L"B`@("`G
M;7-Q;"<L"B`@("`G;7-S<6PG+`H@("`@)VUY<W%L)RP*("`@("=M>7-Q;&DG
M+`H@("`@)V]C:3@G+`H@("`@)V]D8F,G+`H@("`@)W!G<W%L)RP*("`@("=S
M<6QI=&4G+`H@("`@)W-Y8F%S92<L"BD["@IF;W)E86-H("@D8F%C:V5N9',@
M87,@)&YA;64I('L*("`@("1O8FH@/2!$0CHZ9F%C=&]R>2@D;F%M92D["@H@
M("`@<')I;G0@(G1E<W1I;F<@)&YA;64Z("(["B`@("!I9B`H1$(Z.FES17)R
M;W(H)&]B:BDI('L*"2`@("!P<FEN="`G97)R;W(Z("<@+B`D;V)J+3YG971-
M97-S86=E*"D@+B`B7&XB.PH@("`@?2!E;'-E('L*"2`@("!P<FEN="`G;V)J
M96-T.B`G("X@)&]B:BT^=&]3=')I;F<H*2`N(")<;B(["B`@("!]"GT*"C\^
M"BTM1T54+2T*+2U03U-4+2T*+2U%6%!%0U0M+0IT97-T:6YG(&1B87-E.B!O
M8FIE8W0Z(&1B7V1B87-E.B`H<&AP='EP93UD8F%S92P@9&)S>6YT87@]9&)A
M<V4I"G1E<W1I;F<@9F)S<6PZ(&]B:F5C=#H@9&)?9F)S<6PZ("AP:'!T>7!E
M/69B<W%L+"!D8G-Y;G1A>#UF8G-Q;"D*=&5S=&EN9R!I8F%S93H@;V)J96-T
M.B!D8E]I8F%S93H@*'!H<'1Y<&4]:6)A<V4L(&1B<WEN=&%X/6EB87-E*0IT
M97-T:6YG(&EF>#H@;V)J96-T.B!D8E]I9G@Z("AP:'!T>7!E/6EF>"P@9&)S
M>6YT87@]:69X*0IT97-T:6YG(&US<6PZ(&]B:F5C=#H@9&)?;7-Q;#H@*'!H
M<'1Y<&4];7-Q;"P@9&)S>6YT87@];7-Q;"D*=&5S=&EN9R!M<W-Q;#H@;V)J
M96-T.B!D8E]M<W-Q;#H@*'!H<'1Y<&4];7-S<6PL(&1B<WEN=&%X/6US<W%L
M*0IT97-T:6YG(&UY<W%L.B!O8FIE8W0Z(&1B7VUY<W%L.B`H<&AP='EP93UM
M>7-Q;"P@9&)S>6YT87@];7ES<6PI"G1E<W1I;F<@;7ES<6QI.B!O8FIE8W0Z
M(&1B7VUY<W%L:3H@*'!H<'1Y<&4];7ES<6QI+"!D8G-Y;G1A>#UM>7-Q;&DI
M"G1E<W1I;F<@;V-I.#H@;V)J96-T.B!D8E]O8VDX.B`H<&AP='EP93UO8VDX
M+"!D8G-Y;G1A>#UO8VDX*0IT97-T:6YG(&]D8F,Z(&]B:F5C=#H@9&)?;V1B
M8SH@*'!H<'1Y<&4];V1B8RP@9&)S>6YT87@]<W%L.3(I"G1E<W1I;F<@<&=S
M<6PZ(&]B:F5C=#H@9&)?<&=S<6PZ("AP:'!T>7!E/7!G<W%L+"!D8G-Y;G1A
M>#UP9W-Q;"D*=&5S=&EN9R!S<6QI=&4Z(&]B:F5C=#H@9&)?<W%L:71E.B`H
M<&AP='EP93US<6QI=&4L(&1B<WEN=&%X/7-Q;&ET92D*=&5S=&EN9R!S>6)A
M<V4Z(&]B:F5C=#H@9&)?<WEB87-E.B`H<&AP='EP93US>6)A<V4L(&1B<WEN
M=&%X/7-Y8F%S92D*````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O=&5S=',O1$(O=&5S=',O9&)?:7-M86YI<"YP:'!T````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,C(T-R`Q,#4Q-30S,S<S,B`P,C0R-C4`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+2U415-4
M+2T*1$(Z.FES36%N:7`*+2U32TE0248M+0H\/W!H<"!C:&1I<BAD:7)N86UE
M*%]?1DE,15]?*2D[(')E<75I<F5?;VYC92`G+B]S:VEP:68N:6YC)SL@/SX*
M+2U&24Q%+2T*/#]P:'`@+R\@+2HM($,K*R`M*BT*<F5Q=6ER95]O;F-E("<N
M+VEN8VQU9&4N:6YC)SL*<F5Q=6ER95]O;F-E("=$0BYP:'`G.PH*9G5N8W1I
M;VX@=&5S="@D<75E<GDI('L*("`@('!R:6YT9B@B)7,@.B`E9%QN(BP@<')E
M9U]R97!L86-E*"<O7',K+BHO)RP@)R<L("1Q=65R>2DL"B`@("`@("`@("`@
M1$(Z.FES36%N:7`H)'%U97)Y*2D["GT*"G!R:6YT(")T97-T:6YG($1".CII
M<TUA;FEP+BXN7&XB.PH*=&5S="@B4T5,14-4("H@1E)/32!T86)L92(I.PIT
M97-T*")396QE8W0@*B!F<F]M('1A8FQE(BD["G1E<W0H(G-E;&5C="`J($9R
M;VT@=&%B;&4B*3L*=&5S="@B<T5L14-T("H@9G)/;2!T86)L92(I.PIT97-T
M*")314Q%0U0@1$E35$E.0U0@;F%M92!&4D]-('1A8FQE(BD["G1E<W0H(E50
M1$%412!T86)L92!3150@9F]O(#T@)V)A<B<B*3L*=&5S="@B1$5,151%($92
M3TT@=&%B;&4B*3L*=&5S="@B9&5L971E(&9R;VT@=&%B;&4@=VAE<F4@:60@
M:7,@;G5L;"(I.PIT97-T*")C<F5A=&4@=&%B;&4@*&ED(&EN=&5G97(L(&YA
M;64@=F%R8VAA<B@Q,#`I*2(I.PIT97-T*")#4D5!5$4@4T51545.0T4@9F]O
M(BD["G1E<W0H(EPB0U)%051%(%!23T-%1%5212!F;V]<(B(I.PIT97-T*")'
M4D%.5"!314Q%0U0@3TX@=&%B;&4@5$\@=7-E<B(I.PIT97-T*")2159/2T4@
M4T5,14-4($].('1A8FQE($923TT@=7-E<B(I.PIT97-T*")32$]7($]05$E/
M3E,B*3L*=&5S="@B1%)/4"!404),12!F;V\B*3L*=&5S="@B04Q415(@5$%"
M3$4@9F]O($%$1"!#3TQ534X@*&)A<B!)3E1%1T52*2(I.PIT97-T*"(@(%-%
M3$5#5"`J($923TT@=&%B;&4B*3L*=&5S="@B("!$14Q%5$4@1E)/32!T86)L
M92(I.PH_/@HM+4=%5"TM"BTM4$]35"TM"BTM15A014-4+2T*=&5S=&EN9R!$
M0CHZ:7--86YI<"XN+@I314Q%0U0@.B`P"E-E;&5C="`Z(#`*<V5L96-T(#H@
M,`IS16Q%0W0@.B`P"E-%3$5#5"`Z(#`*55!$051%(#H@,0I$14Q%5$4@.B`Q
M"F1E;&5T92`Z(#$*8W)E871E(#H@,0I#4D5!5$4@.B`Q"B)#4D5!5$4@.B`Q
M"D=204Y4(#H@,0I2159/2T4@.B`Q"E-(3U<@.B`P"D123U`@.B`Q"D%,5$52
M(#H@,0H@.B`P"B`Z(#$*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D
M8E]E<G)O<C(N<&AP=```````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`V,C,V
M(#$P-3$U-#,S-S,R(#`R-#`T,@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````M+51%4U0M+0I$0CHZ17)R;W(@,@HM+5-+25!)
M1BTM"CP_<&AP(&-H9&ER*&1I<FYA;64H7U]&24Q%7U\I*3L@<F5Q=6ER95]O
M;F-E("<N+W-K:7!I9BYI;F,G.R`_/@HM+49)3$4M+0H\/W!H<`IR97%U:7)E
M7V]N8V4@)RXO:6YC;'5D92YI;F,G.PIR97%U:7)E7V]N8V4@)T1"+G!H<"<[
M"@IE<G)O<E]R97!O<G1I;F<H15]!3$PI.PH*9G5N8W1I;VX@;7EF=6YC*"8D
M;V)J*2!["B`@("!P<FEN="`G;7EF=6YC(&AE<F4L(&]B:CTG"B`@("`@("`@
M("`N('-T<G1O;&]W97(H)&]B:BT^=&]3=')I;F<H*2D@+B`B7&XB.PI]"F9U
M;F-T:6]N(&UY9G5N8S(H)B1O8FHI('L*("`@('!R:6YT("=M>69U;F,R(&AE
M<F4L(&]B:CTG"B`@("`@("`@("`N('-T<G1O;&]W97(H)&]B:BT^=&]3=')I
M;F<H*2D@+B`B7&XB.PI]"F-L87-S(&UY8VQA<W,@>PH@("`@9G5N8W1I;VX@
M;7EF=6YC*"8D;V)J*2!["B`@("`@("`@<')I;G0@)VUY8VQA<W,Z.FUY9G5N
M8R!H97)E+"!O8FH])PH@("`@("`@("`@+B!S=')T;VQO=V5R*"1O8FHM/G1O
M4W1R:6YG*"DI("X@(EQN(CL*("`@('T*?0IF=6YC=&EO;B!T97-T7V5R<F]R
M7VAA;F1L97(H)&5R<FYO+"`D97)R;7-G+"`D9FEL92P@)&QI;F4L("1V87)S
M*2!["B`@("!I9B`H9&5F:6YE9"@G15]35%))0U0G*2D@>PH@("`@("`@(&EF
M("@D97)R;F\@)B!%7U-44DE#5`H@("`@("`@("`@("`F)B`H97)R;W)?<F5P
M;W)T:6YG*"D@)B!%7U-44DE#5"D@(3T@15]35%))0U0I('L*("`@("`@("`@
M("`@+R\@26=N;W)E($5?4U1224-4(&YO=&EC97,@=6YL97-S('1H97D@:&%V
M92!B965N('1U<FYE9"!O;@H@("`@("`@("`@("!R971U<FX["B`@("`@("`@
M?0H@("`@?2!E;'-E('L*("`@("`@("!D969I;F4H)T5?4U1224-4)RP@,C`T
M."D["B`@("!]"B`@("`D97)R;W)T>7!E(#T@87)R87D@*`H@("`@("`@($5?
M15)23U(@/3X@)T5R<F]R)RP*("`@("`@("!%7U=!4DY)3D<@/3X@)U=A<FYI
M;F<G+`H@("`@("`@($5?4$%24T4@/3X@)U!A<G-I;F<@17)R;W(G+`H@("`@
M("`@($5?3D]424-%(#T^("=.;W1I8V4G+`H@("`@("`@($5?0T]215]%4E)/
M4B`]/B`G0V]R92!%<G)O<B<L"B`@("`@("`@15]#3U)%7U=!4DY)3D<@/3X@
M)T-O<F4@5V%R;FEN9R<L"B`@("`@("`@15]#3TU024Q%7T524D]2(#T^("=#
M;VUP:6QE($5R<F]R)RP*("`@("`@("!%7T-/35!)3$5?5T%23DE.1R`]/B`G
M0V]M<&EL92!787)N:6YG)RP*("`@("`@("!%7U5315)?15)23U(@/3X@)U5S
M97(@17)R;W(G+`H@("`@("`@($5?55-%4E]705).24Y'(#T^("=5<V5R(%=A
M<FYI;F<G+`H@("`@("`@($5?55-%4E].3U1)0T4@/3X@)U5S97(@3F]T:6-E
M)RP*("`@("`@("!%7U-44DE#5"`]/B`G4W1R:6-T($YO=&EC92<L"B`@("`I
M.PH@("`@)'!R969I>"`]("1E<G)O<G1Y<&5;)&5R<FYO73L*("`@('!R:6YT
M('-T<G1O;&]W97(H(B1P<F5F:7@Z("1E<G)M<V<@:6X@(B`N(&)A<V5N86UE
M*"1F:6QE*0H@("`@("`@("`@("`@("`@("`@("`N("(@;VX@;&EN92!86%A<
M;B(I.PI]"@HD;V)J(#T@;F5W(&UY8VQA<W,["@HD9&)H(#T@1$(Z.F9A8W1O
M<GDH(FUY<W%L(BD["@IP<FEN="`B9&5F875L=#H@(CL*)&4@/2`D9&)H+3YR
M86ES945R<F]R*")R971U<FX@=&5S=&EN9R!E<G)O<B(I.PIP<FEN="!S=')T
M;VQO=V5R*"1E+3YT;U-T<FEN9R@I*2`N(")<;B(["@IP<FEN="`B9VQO8F%L
M(&1E9F%U;'0Z("(["E!%05(Z.G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/
M4E]#04Q,0D%#2RP@(FUY9G5N8S(B*3L*)&4@/2`D9&)H+3YR86ES945R<F]R
M*")G;&]B86P@9&5F875L="!T97-T(BD["@HD9&)H+3YS971%<G)O<DAA;F1L
M:6YG*%!%05)?15)23U)?4%))3E0I.PIP<FEN="`B;6]D93UP<FEN=#H@(CL*
M)&4@/2`D9&)H+3YR86ES945R<F]R*")P<FEN="!T97-T:6YG(&5R<F]R(BD[
M"G!R:6YT(")<;B(["@HD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)2
M3U)?0T%,3$)!0TLL(")M>69U;F,B*3L*<')I;G0@(FUO9&4]9G5N8W1I;VX@
M8V%L;&)A8VLZ("(["B1E(#T@)&1B:"T^<F%I<V5%<G)O<B@B9G5N8W1I;VX@
M8V%L;&)A8VL@=&5S=&EN9R!E<G)O<B(I.PH*)&1B:"T^<V5T17)R;W)(86YD
M;&EN9RA014%27T524D]27T-!3$Q"04-++"!A<G)A>2@D;V)J+"`B;7EF=6YC
M(BDI.PIP<FEN="`B;6]D93UO8FIE8W0@8V%L;&)A8VLZ("(["B1E(#T@)&1B
M:"T^<F%I<V5%<G)O<B@B;V)J96-T(&-A;&QB86-K('1E<W1I;F<@97)R;W(B
M*3L*"G-E=%]E<G)O<E]H86YD;&5R*")T97-T7V5R<F]R7VAA;F1L97(B*3L*
M)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U1224='15(I.PIP
M<FEN="`B;6]D93UT<FEG9V5R.B`B.PHD92`]("1D8F@M/G)A:7-E17)R;W(H
M(G1R:6=G97(@=&5S=&EN9R!E<G)O<B(I.PH*/SX*+2U%6%!%0U0M+0ID969A
M=6QT.B!;9&)?97)R;W(Z(&UE<W-A9V4](F1B(&5R<F]R.B!R971U<FX@=&5S
M=&EN9R!E<G)O<B(@8V]D93TM,2!M;V1E/7)E='5R;B!L979E;#UN;W1I8V4@
M<')E9FEX/2(B(&EN9F\](B!;9&(@97)R;W(Z('5N:VYO=VX@97)R;W)=(ET*
M9VQO8F%L(&1E9F%U;'0Z(&UY9G5N8S(@:&5R92P@;V)J/5MD8E]E<G)O<CH@
M;65S<V%G93TB9&(@97)R;W(Z(&=L;V)A;"!D969A=6QT('1E<W0B(&-O9&4]
M+3$@;6]D93UC86QL8F%C:R!C86QL8F%C:SUM>69U;F,R('!R969I>#TB(B!I
M;F9O/2(@6V1B(&5R<F]R.B!U;FMN;W=N(&5R<F]R72)="FUO9&4]<')I;G0Z
M($1"($5R<F]R.B!P<FEN="!T97-T:6YG(&5R<F]R"FUO9&4]9G5N8W1I;VX@
M8V%L;&)A8VLZ(&UY9G5N8R!H97)E+"!O8FH]6V1B7V5R<F]R.B!M97-S86=E
M/2)D8B!E<G)O<CH@9G5N8W1I;VX@8V%L;&)A8VL@=&5S=&EN9R!E<G)O<B(@
M8V]D93TM,2!M;V1E/6-A;&QB86-K(&-A;&QB86-K/6UY9G5N8R!P<F5F:7@]
M(B(@:6YF;STB(%MD8B!E<G)O<CH@=6YK;F]W;B!E<G)O<ETB70IM;V1E/6]B
M:F5C="!C86QL8F%C:SH@;7EC;&%S<SHZ;7EF=6YC(&AE<F4L(&]B:CU;9&)?
M97)R;W(Z(&UE<W-A9V4](F1B(&5R<F]R.B!O8FIE8W0@8V%L;&)A8VL@=&5S
M=&EN9R!E<G)O<B(@8V]D93TM,2!M;V1E/6-A;&QB86-K(&-A;&QB86-K/6UY
M8VQA<W,Z.FUY9G5N8R!P<F5F:7@](B(@:6YF;STB(%MD8B!E<G)O<CH@=6YK
M;F]W;B!E<G)O<ETB70IM;V1E/71R:6=G97(Z('5S97(@;F]T:6-E.B!D8B!E
M<G)O<CH@=')I9V=E<B!T97-T:6YG(&5R<F]R(&EN('!E87(N<&AP(&]N(&QI
M;F4@>'AX"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O
M97)R;W)S+FEN8P``````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`S,S8Q
M-"`Q,#4Q-30S,S<S,B`P,C,R-S0`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*"B\J*@H@*B!497-T<R!T:&4@9')I
M=F5R<R<@97)R;W(@;6%P<&EN9PH@*@H@*B!%>&5C=71E9"!B>2!D<FEV97(O
M,3!E<G)O<FUA<"YP:'!T"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J
M"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V
M97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA="!I<R!A=F%I
M;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO
M=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT
M>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@H@*B!T:&4@
M4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U
M9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`
M<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY
M+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@("!$
M0@H@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H
M<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P
M"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?
M,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("`D260Z(&5R
M<F]R<RYI;F,L=B`Q+C,U(#(P,#4O,#(O,C@@,#(Z,#(Z-#$@9&%N:65L8R!%
M>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA
M9V4O1$(*("HO"@HO*BH*("H@1&5T97)M:6YE(&EF('1H92!E<G)O<B!F<F]M
M('1H92!D<FEV97(@;6%T8VAE<R!T:&4@97)R;W(@=V4@97AP96-T"B`J"B`J
M($EF('1H:6YG<R!A<F4@87,@=V4@97AP96-T+"!P<FEN="!O=70@(FUA=&-H
M97,@97AP96-T960@;W5T8V]M92(*("H*("H@268@=&AI;F=S(&=O('=R;VYG
M+"!P<FEN="`B54Y%6%!%0U1%1"!/551#3TU%(B!A;F0@9&ES<&QA>2!T:&4*
M("H@97)R;W(G<R!I;F9O<FUA=&EO;BX*("H*("H@0'!A<F%M(&]B:F5C="`@
M)&4@("`@("`@("`@("`@("`@('1H92!$0E]%<G)O<B!O8FIE8W0@9G)O;2!T
M:&4@<75E<GD*("H@0'!A<F%M(&EN="`@("`@)&5X<&5C=&5D7V1B7V-O9&4@
M('1H92!$0E]%4E)/4BH@8V]N<W1A;G0@=&\@97AP96-T"B`J($!P87)A;2!B
M;V]L96%N("1S:&]U;&1?8F5?97)R;W(@("!D;V5S('1H92!$0DU3(&-O;G-I
M9&5R('1H:7,@86X@97)R;W(_"B`J"B`J($!R971U<FX@=F]I9`H@*B\*9G5N
M8W1I;VX@8VAE8VM?97)R;W(H)&4L("1E>'!E8W1E9%]D8E]C;V1E+"`D<VAO
M=6QD7V)E7V5R<F]R(#T@=')U92D@>PH@("`@:68@*"1S:&]U;&1?8F5?97)R
M;W(I('L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)&4I*2!["B`@("`@("`@
M("`@(&EF("@D92T^9V5T0V]D92@I(#T]("1E>'!E8W1E9%]D8E]C;V1E*2![
M"B`@("`@("`@("`@("`@("!P<FEN="`B;6%T8VAE<R!E>'!E8W1E9"!O=71C
M;VUE7&XB.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M<')I;G0@(E5.15A014-4140@3U540T]-12XN+EQN(CL*("`@("`@("`@("`@
M("`@('!R:6YT("<@("`@4$5!4CHZ1$(@97)R;W)C;V1E.B`G("X@)&4M/F=E
M=$-O9&4H*2`N(")<;B(["B`@("`@("`@("`@("`@("!P<FEN="`G("`@("<@
M+B`D92T^9V5T57-E<DEN9F\H*2`N(")<;B(["B`@("`@("`@("`@('T*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!P<FEN="`B7&X@("`@54Y%6%!%
M0U1%1"!/551#3TU%+BXN(&5X<&5C=&5D(&5R<F]R(&)U="!I="!W87-N)W1<
M;B(["B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@("`@("!I9B`H1$(Z.FES
M17)R;W(H)&4I*2!["B`@("`@("`@("`@('!R:6YT(")53D584$5#5$5$($]5
M5$-/344N+BX@9&ED;B=T(&5X<&5C="!E<G)O<B!B=70@:70@=V%S7&XB.PH@
M("`@("`@("`@("!P<FEN="`G("`@(%!%05(Z.D1"(&5R<F]R8V]D93H@)R`N
M("1E+3YG971#;V1E*"D@+B`B7&XB.PH@("`@("`@("`@("!P<FEN="`G("`@
M("<@+B`D92T^9V5T57-E<DEN9F\H*2`N(")<;B(["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@<')I;G0@(FUA=&-H97,@97AP96-T960@;W5T8V]M
M95QN(CL*("`@("`@("!]"B`@("!]"GT*"B\J*@H@*B!,;V-A;"!E<G)O<B!C
M86QL8F%C:R!H86YD;&5R"B`J(`H@*B!`<&%R86T@;V)J96-T("`D;R`@4$5!
M4B!E<G)O<B!O8FIE8W0@875T;VUA=&EC86QL>2!P87-S960@=&\@=&AI<R!M
M971H;V0*("H@0')E='5R;B!V;VED"B`J($!S964@4$5!4CHZ<V5T17)R;W)(
M86YD;&EN9R@I"B`J+PIF=6YC=&EO;B!P92@D;RD@>PH@("`@<')I;G0@(EQN
M+2TM+2TM+2TM+2TM+2TM7&XB.PH@("`@<')I;G0@(DAA=FEN9R!P<F]B;&5M
M<R!C<F5A=&EN9R!A('1A8FQE(&9O<B!T97-T:6YG+BXN7&XB.PH@("`@<')I
M;G0@)&\M/F=E=$1E8G5G26YF;R@I("X@(EQN(CL*("`@('!R:6YT("(M+2TM
M+2TM+2TM+2TM+2U<;B(["GT*"@HD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%
M05)?15)23U)?4D5455).*3L*"@IP<FEN="`G1$)?15)23U)?3D]354-(5$%"
M3$4@9F]R('-E;&5C=#H@("<["B1R97,@/2`D9&)H+3YQ=65R>2@G4T5,14-4
M("H@1E)/32!T86)L951H871S0F]G=7,G*3L*8VAE8VM?97)R;W(H)')E<RP@
M1$)?15)23U)?3D]354-(5$%"3$4I.PH*<')I;G0@)T1"7T524D]27TY/4U5#
M2%1!0DQ%(&9O<B!D<F]P.B`@)SL*)')E<R`](&1R;W!?=&%B;&4H)&1B:"P@
M)W1A8FQE5&AA='-";V=U<R<I.PIC:&5C:U]E<G)O<B@D<F5S+"!$0E]%4E)/
M4E].3U-50TA404),12D["@IP<FEN="`G1$)?15)23U)?3D]47T9/54Y$(&9O
M<B!D<F]P(&EN9&5X.B`@)SL*<W=I=&-H("@D9&)H+3YP:'!T>7!E("X@)SHG
M("X@)&1B:"T^9&)S>6YT87@I('L*("`@(&-A<V4@)V9B<W%L.F9B<W%L)SH*
M("`@(&-A<V4@)VEB87-E.F9I<F5B:7)D)SH*("`@(&-A<V4@)VEB87-E.FEB
M87-E)SH*("`@(&-A<V4@)VEF>#II9G@G.@H@("`@8V%S92`G;V1B8SID8C(G
M.@H@("`@8V%S92`G;V-I.#IO8VDX)SH*("`@(&-A<V4@)W!G<W%L.G!G<W%L
M)SH*("`@(&-A<V4@)W-Q;&ET93IS<6QI=&4G.@H@("`@("`@("1R97,@/2`D
M9&)H+3YQ=65R>2@G1%)/4"!)3D1%6"!F86ME:6YD97@G*3L*("`@("`@("!B
M<F5A:SL*("`@(&-A<V4@)VUS<W%L.FUS<W%L)SH*("`@(&-A<V4@)W-Y8F%S
M93IS>6)A<V4G.@H@("`@("`@("1R97,@/2`D9&)H+3YQ=65R>2@G1%)/4"!)
M3D1%6"!P:'!T97-T+F9A:V5I;F1E>"<I.PH@("`@("`@(&)R96%K.PH@("`@
M8V%S92`G;7-Q;#IM<W%L)SH*("`@("`@("`D<F5S(#T@)&1B:"T^<75E<GDH
M)T123U`@24Y$15@@9F%K96EN9&5X($923TT@<&AP=&5S="<I.PH@("`@("`@
M(&)R96%K.PH@("`@9&5F875L=#H*("`@("`@("`D<F5S(#T@)&1B:"T^<75E
M<GDH)T123U`@24Y$15@@9F%K96EN9&5X($].('!H<'1E<W0G*3L*?0IC:&5C
M:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E].3U1?1D]53D0I.PH*"G!R:6YT("=$
M0E]%4E)/4E]!3%)%04197T5825-44R!F;W(@8W)E871E('1A8FQE.B`@)SL*
M)')E<R`]("1D8F@M/G%U97)Y*"1T97-T7VUK=&%B;&5?<75E<GDI.PIC:&5C
M:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E]!3%)%04197T5825-44RD["@IP<FEN
M="`G1$)?15)23U)?04Q214%$65]%6$E35%,@9F]R(&-R96%T92!I;F1E>#H@
M("<["B1R97,@/2!D<F]P7W1A8FQE*"1D8F@L("=A)RD["B1D8F@M/G!U<VA%
M<G)O<DAA;F1L:6YG*%!%05)?15)23U)?0T%,3$)!0TLL("=P92<I.PHD<F5S
M(#T@)&1B:"T^<75E<GDH)T-214%412!404),12!A("AA($E.5$5'15(I)RD[
M"B1D8F@M/G!O<$5R<F]R2&%N9&QI;F<H*3L*)')E<R`]("1D8F@M/G%U97)Y
M*"=#4D5!5$4@24Y$15@@86%?:61X($].(&$@*&$I)RD["B1R97,@/2`D9&)H
M+3YQ=65R>2@G0U)%051%($E.1$58(&%A7VED>"!/3B!A("AA*2<I.PIS=VET
M8V@@*"1D8F@M/G!H<'1Y<&4I('L*("`@(&-A<V4@)V9B<W%L)SH*("`@("`@
M("`O+R!&<F]N=$)A<V4@9&]E<VXG="!A<W-I9VX@82!S<&5C:69I8R!C;V1E
M(&9O<B!T:&ES('EE="X*("`@("`@("!C:&5C:U]E<G)O<B@D<F5S+"!$0E]%
M4E)/4E]!3%)%04197T5825-44RP@9F%L<V4I.PH@("`@("`@(&)R96%K.PH@
M("`@9&5F875L=#H*("`@("`@("!C:&5C:U]E<G)O<B@D<F5S+"!$0E]%4E)/
M4E]!3%)%04197T5825-44RD["GT*)')E<R`](&1R;W!?=&%B;&4H)&1B:"P@
M)V$G*3L*"@IP<FEN="`G1$)?15)23U)?0T].4U1204E.5"!F;W(@<')I;6%R
M>2!K97D@:6YS97)T(&1U<&QI8V%T93H@("<["B1R97,@/2!D<F]P7W1A8FQE
M*"1D8F@L("=A)RD["B1D8F@M/G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)2
M3U)?0T%,3$)!0TLL("=P92<I.PIS=VET8V@@*"1D8F@M/G!H<'1Y<&4I('L*
M("`@(&-A<V4@)VUS<6PG.@H@("`@("`@("1R97,@/2`D9&)H+3YQ=65R>2@G
M0U)%051%(%1!0DQ%(&$@*&$@24Y414=%4B!.3U0@3E5,3"DG*3L*("`@("`@
M("`D<F5S(#T@)&1B:"T^<75E<GDH)T-214%412!53DE1544@24Y$15@@87!K
M($].(&$@*&$I)RD["B`@("`@("`@8G)E86L["B`@("!D969A=6QT.@H@("`@
M("`@("1R97,@/2`D9&)H+3YQ=65R>2@G0U)%051%(%1!0DQ%(&$@*&$@24Y4
M14=%4B!.3U0@3E5,3"P@4%))34%262!+15D@*&$I*2<I.PI]"B1D8F@M/G!O
M<$5R<F]R2&%N9&QI;F<H*3L*)')E<R`]("1D8F@M/G%U97)Y*"=)3E-%4E0@
M24Y43R!A(%9!3%5%4R`H,2DG*3L*)')E<R`]("1D8F@M/G%U97)Y*"=)3E-%
M4E0@24Y43R!A(%9!3%5%4R`H,2DG*3L*8VAE8VM?97)R;W(H)')E<RP@1$)?
M15)23U)?0T].4U1204E.5"D["@H*<')I;G0@)T1"7T524D]27T-/3E-44D%)
M3E0@9F]R('!R:6UA<GD@:V5Y('5P9&%T92!D=7!L:6-A=&4Z("`G.PHD<F5S
M(#T@)&1B:"T^<75E<GDH)TE.4T525"!)3E1/(&$@5D%,5453("@R*2<I.PHD
M<F5S(#T@)&1B:"T^<75E<GDH)U501$%412!A(%-%5"!A/3$@5TA%4D4@83TR
M)RD["F-H96-K7V5R<F]R*"1R97,L($1"7T524D]27T-/3E-44D%)3E0I.PH*
M"G!R:6YT("=$0E]%4E)/4E]#3TY35%)!24Y4(&9O<B!U;FEQ=64@:V5Y(&EN
M<V5R="!D=7!L:6-A=&4Z("`G.PHD<F5S(#T@9')O<%]T86)L92@D9&)H+"`G
M82<I.PHD9&)H+3YP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27T-!3$Q"
M04-++"`G<&4G*3L*<W=I=&-H("@D9&)H+3YP:'!T>7!E*2!["B`@("!C87-E
M("=M<W%L)SH*("`@("`@("`D<F5S(#T@)&1B:"T^<75E<GDH)T-214%412!4
M04),12!A("AA($E.5$5'15(@3D]4($Y53$PI)RD["B`@("`@("`@)')E<R`]
M("1D8F@M/G%U97)Y*"=#4D5!5$4@54Y)455%($E.1$58(&%U:R!/3B!A("AA
M*2<I.PH@("`@("`@(&)R96%K.PH@("`@9&5F875L=#H*("`@("`@("`D<F5S
M(#T@)&1B:"T^<75E<GDH)T-214%412!404),12!A("AA($E.5$5'15(@3D]4
M($Y53$PL(%5.25%512`H82DI)RD["GT*)&1B:"T^<&]P17)R;W)(86YD;&EN
M9R@I.PHD<F5S(#T@)&1B:"T^<75E<GDH)TE.4T525"!)3E1/(&$@5D%,5453
M("@Q*2<I.PHD<F5S(#T@)&1B:"T^<75E<GDH)TE.4T525"!)3E1/(&$@5D%,
M5453("@Q*2<I.PIC:&5C:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E]#3TY35%)!
M24Y4*3L*"@IP<FEN="`G1$)?15)23U)?0T].4U1204E.5"!F;W(@=6YI<75E
M(&ME>2!U<&1A=&4@9'5P;&EC871E.B`@)SL*)')E<R`]("1D8F@M/G%U97)Y
M*"=)3E-%4E0@24Y43R!A(%9!3%5%4R`H,BDG*3L*)')E<R`]("1D8F@M/G%U
M97)Y*"=54$1!5$4@82!3150@83TQ(%=(15)%(&$],B<I.PIC:&5C:U]E<G)O
M<B@D<F5S+"!$0E]%4E)/4E]#3TY35%)!24Y4*3L*"@IP<FEN="`G1$)?15)2
M3U)?0T].4U1204E.5"!F;W(@9F]R96EG;B!K97D@;VX@:6YS97)T.B`@)SL*
M)')E<R`](&1R;W!?=&%B;&4H)&1B:"P@)V(G*3L*)')E<R`](&1R;W!?=&%B
M;&4H)&1B:"P@)V$G*3L*)&1B:"T^<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%
M4E)/4E]#04Q,0D%#2RP@)W!E)RD["G-W:71C:"`H)&1B:"T^<&AP='EP92D@
M>PH@("`@8V%S92`G;7ES<6PG.@H@("`@8V%S92`G;7ES<6QI)SH*("`@("`@
M("`D<F5S(#T@)&1B:"T^<75E<GDH)T-214%412!404),12!A("AA($E.5"!.
M3U0@3E5,3"P@)PH@("`@("`@("`@("`@("`@("`@("X@)U!224U!4ED@2T59
M("AA*2D@)PH@("`@("`@("`@("`@("`@("`@("X@)U194$4]24Y.3T1")RD[
M"B`@("`@("`@)')E<R`]("1D8F@M/G%U97)Y*"=#4D5!5$4@5$%"3$4@8B`H
M8B!)3E0L("<*("`@("`@("`@("`@("`@("`@("`N("=)3D1%6"!P87)?:6YD
M("AB*2P@)PH@("`@("`@("`@("`@("`@("`@("X@)T9/4D5)1TX@2T59("AB
M*2!2149%4D5.0T53(&$@*&$I*2`G"B`@("`@("`@("`@("`@("`@("`@+B`G
M5%E013U)3DY/1$(G*3L*("`@("`@("`D9&)H+3YP;W!%<G)O<DAA;F1L:6YG
M*"D["B`@("`@("`@8G)E86L["@H@("`@8V%S92`G;7-Q;"<Z"B`@("`@("`@
M+R\@;7-Q;"!D;V5S(&YO="!S=7!P;W)T(&9O<F5I9VX@:V5Y<PH@("`@("`@
M("1R97,@/2`D9&)H+3YQ=65R>2@G0U)%051%(%1!0DQ%(&$@*&$@24Y414=%
M4B!.3U0@3E5,3"DG*3L*("`@("`@("`D<F5S(#T@)&1B:"T^<75E<GDH)T-2
M14%412!53DE1544@24Y$15@@875K($].(&$@*&$I)RD["B`@("`@("`@)&1B
M:"T^<&]P17)R;W)(86YD;&EN9R@I.PH@("`@("`@("1R97,@/2`D9&)H+3YQ
M=65R>2@G0U)%051%(%1!0DQ%(&(@*&(@24Y414=%4B!2149%4D5.0T53(&$@
M*&$I*2<I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S*2D@>PH@("`@
M("`@("`@("!P<FEN="`B;6%T8VAE<R!E>'!E8W1E9"!O=71C;VUE7&XB.PH@
M("`@("`@("`@("!P<FEN="`B1$)?15)23U)?0T].4U1204E.5"!F;W(@9F]R
M96EG;B!K97D@;VX@9&5L971E.B`@;6%T8VAE<R!E>'!E8W1E9"!O=71C;VUE
M7&XB.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@('!R:6YT(")73U<L
M(&ET('-E96US(&U344P@;F]W('-U<'!O<G1S(')E9F5R96YC97-<;B(["B`@
M("`@("`@("`@('!R:6YT(")73U<L(&ET('-E96US(&U344P@;F]W('-U<'!O
M<G1S(')E9F5R96YC97-<;B(["B`@("`@("`@?0H@("`@("`@(&)R96%K.PH*
M("`@(&1E9F%U;'0Z"B`@("`@("`@)')E<R`]("1D8F@M/G%U97)Y*"=#4D5!
M5$4@5$%"3$4@82`H82!)3E1%1T52($Y/5"!.54Q,+"!04DE-05)9($M%62`H
M82DI)RD["B`@("`@("`@)')E<R`]("1D8F@M/G%U97)Y*"=#4D5!5$4@5$%"
M3$4@8B`H8B!)3E1%1T52(%)%1D5214Y#15,@82`H82DI)RD["B`@("`@("`@
M)&1B:"T^<&]P17)R;W)(86YD;&EN9R@I.PI]"@II9B`H)&1B:"T^<&AP='EP
M92`A/2`G;7-Q;"<I('L*("`@("1R97,@/2`D9&)H+3YQ=65R>2@G24Y315)4
M($E.5$\@82`H82D@=F%L=65S("@Q*2<I.PH@("`@)')E<R`]("1D8F@M/G%U
M97)Y*"=)3E-%4E0@24Y43R!B("AB*2!V86QU97,@*#(I)RD["B`@("!S=VET
M8V@@*"1D8F@M/G!H<'1Y<&4I('L*("`@("`@("!C87-E("=S<6QI=&4G.@H@
M("`@("`@("`@("!C:&5C:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E]#3TY35%)!
M24Y4+"!F86QS92D["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@(&1E9F%U
M;'0Z"B`@("`@("`@("`@(&-H96-K7V5R<F]R*"1R97,L($1"7T524D]27T-/
M3E-44D%)3E0I.PH@("`@?2`@(`H*("`@('!R:6YT("=$0E]%4E)/4E]#3TY3
M5%)!24Y4(&9O<B!F;W)E:6=N(&ME>2!O;B!D96QE=&4Z("`G.PH@("`@)')E
M<R`]("1D8F@M/G%U97)Y*"=)3E-%4E0@24Y43R!B("AB*2!V86QU97,@*#$I
M)RD["B`@("`D<F5S(#T@)&1B:"T^<75E<GDH)T1%3$5412!&4D]-(&$@5TA%
M4D4@82`](#$G*3L*("`@('-W:71C:"`H)&1B:"T^<&AP='EP92D@>PH@("`@
M("`@(&-A<V4@)W-Q;&ET92<Z"B`@("`@("`@("`@(&-H96-K7V5R<F]R*"1R
M97,L($1"7T524D]27T-/3E-44D%)3E0L(&9A;'-E*3L*("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@8VAE8VM?97)R
M;W(H)')E<RP@1$)?15)23U)?0T].4U1204E.5"D["B`@("!]"GT*"@IP<FEN
M="`G1$)?15)23U)?0T].4U1204E.5%].3U1?3E5,3"!O;B!I;G-E<G0Z("`G
M.PHD<F5S(#T@9')O<%]T86)L92@D9&)H+"`G<&5A<G1E<W1N=6QL)RD["B1D
M8F@M/G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?0T%,3$)!0TLL("=P
M92<I.PHD<F5S(#T@)&1B:"T^<75E<GDH)T-214%412!404),12!P96%R=&5S
M=&YU;&P@*&$@0TA!4B@S*2!.3U0@3E5,3"DG*3L*)&1B:"T^<&]P17)R;W)(
M86YD;&EN9R@I.PHD<F5S(#T@)&1B:"T^<75E<GDH)TE.4T525"!)3E1/('!E
M87)T97-T;G5L;"!604Q515,@*$Y53$PI)RD["F-H96-K7V5R<F]R*"1R97,L
M($1"7T524D]27T-/3E-44D%)3E1?3D]47TY53$PI.PH*"G!R:6YT("=$0E]%
M4E)/4E]#3TY35%)!24Y47TY/5%].54Q,(&]N('5P9&%T93H@("<["B1R97,@
M/2`D9&)H+3YQ=65R>2@B24Y315)4($E.5$\@<&5A<G1E<W1N=6QL(%9!3%5%
M4R`H)V]N92<I(BD["B1R97,@/2`D9&)H+3YQ=65R>2@B55!$051%('!E87)T
M97-T;G5L;"!3150@82`]($Y53$P@5TA%4D4@82`]("=O;F4G(BD["G-W:71C
M:"`H)&1B:"T^<&AP='EP92D@>PH@("`@8V%S92`G;7ES<6PG.@H@("`@8V%S
M92`G;7ES<6QI)SH*("`@("`@("!C:&5C:U]E<G)O<B@D<F5S+"!$0E]%4E)/
M4E]#3TY35%)!24Y47TY/5%].54Q,+"!F86QS92D["B`@("`@("`@8G)E86L[
M"B`@("!D969A=6QT.@H@("`@("`@(&-H96-K7V5R<F]R*"1R97,L($1"7T52
M4D]27T-/3E-44D%)3E1?3D]47TY53$PI.PI]"@H*<')I;G0@)T1"7T524D]2
M7TY/4U5#2$9)14Q$(&IO:6YI;F<@3TX@8F]G=7,@8V]L=6UN.B`@)SL*)')E
M<R`]("1D8F@M/G%U97)Y*"=314Q%0U0@*B!&4D]-('!H<'1E<W0@2D])3B!A
M($].("AP:'!T97-T+F$@/2!A+F(I)RD["G-W:71C:"`H)&1B:"T^<&AP='EP
M92`N("<Z)R`N("1D8F@M/F1B<WEN=&%X*2!["B`@("!C87-E("=M<W%L.FUS
M<6PG.@H@("`@8V%S92`G;V1B8SIA8V-E<W,G.@H@("`@("`@(&-H96-K7V5R
M<F]R*"1R97,L($1"7T524D]27U-93E1!6"D["B`@("`@("`@8G)E86L["B`@
M("!D969A=6QT.@H@("`@("`@(&-H96-K7V5R<F]R*"1R97,L($1"7T524D]2
M7TY/4U5#2$9)14Q$*3L*?0H*"G!R:6YT("=$0E]%4E)/4E].3U-50TA&245,
M1"!J;VEN:6YG(%5324Y'(&)O9W5S(&-O;'5M;CH@("<["B1R97,@/2`D9&)H
M+3YQ=65R>2@G4T5,14-4("H@1E)/32!P:'!T97-T($I/24X@82!54TE.1R`H
M8BDG*3L*<W=I=&-H("@D9&)H+3YP:'!T>7!E("X@)SHG("X@)&1B:"T^9&)S
M>6YT87@I('L*("`@(&-A<V4@)VEB87-E.FEB87-E)SH*("`@(&-A<V4@)VEB
M87-E.F9I<F5B:7)D)SH*("`@(&-A<V4@)VUS<6PZ;7-Q;"<Z"B`@("!C87-E
M("=O9&)C.F%C8V5S<R<Z"B`@("!C87-E("=O9&)C.F1B,B<Z"B`@("!C87-E
M("=S>6)A<V4Z<WEB87-E)SH*("`@("`@("!C:&5C:U]E<G)O<B@D<F5S+"!$
M0E]%4E)/4E]364Y405@I.PH@("`@("`@(&)R96%K.PH@("`@9&5F875L=#H*
M("`@("`@("!C:&5C:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E].3U-50TA&245,
M1"D["GT*"@IP<FEN="`G1$)?15)23U)?1$E66D523SH@("<["B\O($EN=&5R
M8F%S92!D971E8W1S('1H92!E<G)O<B!O;B!F971C:&EN9PHD<F5S(#T@)&1B
M:"T^9V5T06QL*"=314Q%0U0@,"\P($923TT@<&AP=&5S="<I.PIS=VET8V@@
M*"1D8F@M/G!H<'1Y<&4I('L*("`@(&-A<V4@)V]D8F,G.@H@("`@("`@('-W
M:71C:"`H)&1B:"T^9&)S>6YT87@I('L*("`@("`@("`@("`@8V%S92`G86-C
M97-S)SH*("`@("`@("`@("`@("`@(&-H96-K7V5R<F]R*"1R97,L($1"7T52
M4D]27T1)5EI%4D\L(&9A;'-E*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("!C87-E("=D8C(G.@H@("`@("`@("`@("`@("`@8VAE8VM?
M97)R;W(H)')E<RP@1$)?15)23U)?1$E66D523RD["B`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("!]"B`@("`@("`@8G)E86L["B`@("!C87-E("=I
M8F%S92<Z"B`@("!C87-E("=I9G@G.@H@("`@8V%S92`G9F)S<6PG.@H@("`@
M8V%S92`G;7-S<6PG.@H@("`@8V%S92`G;7ES<6PG.@H@("`@8V%S92`G;7ES
M<6QI)SH*("`@(&-A<V4@)W-Q;&ET92<Z"B`@("!C87-E("=S>6)A<V4G.@H@
M("`@("`@(&-H96-K7V5R<F]R*"1R97,L($1"7T524D]27T1)5EI%4D\L(&9A
M;'-E*3L*("`@("`@("!B<F5A:SL*("`@(&-A<V4@)VUS<6PG.@H@("`@("`@
M(&-H96-K7V5R<F]R*"1R97,L($1"7T524D]27U-93E1!6"D["B`@("`@("`@
M8G)E86L["B`@("!D969A=6QT.@H@("`@("`@(&-H96-K7V5R<F]R*"1R97,L
M($1"7T524D]27T1)5EI%4D\I.PI]"@H*<')I;G0@)T1"7T524D]27TE.5D%,
M241?3E5-0D52('!U='1I;F<@8VAA<G,@:6X@24Y4(&-O;'5M;CH@("<["B1R
M97,@/2`D9&)H+3YQ=65R>2@B55!$051%('!H<'1E<W0@4T54(&$@/2`G86)C
M)R!72$5212!A(#T@-#(B*3L*<W=I=&-H("@D9&)H+3YP:'!T>7!E*2!["B`@
M("!C87-E("=M>7-Q;"<Z"B`@("!C87-E("=M>7-Q;&DG.@H@("`@8V%S92`G
M<W%L:71E)SH*("`@("`@("!C:&5C:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E])
M3E9!3$E$7TY534)%4BP@9F%L<V4I.PH@("`@("`@(&)R96%K.PH@("`@9&5F
M875L=#H*("`@("`@("!C:&5C:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E])3E9!
M3$E$7TY534)%4BD["GT*"@IP<FEN="`G1$)?15)23U)?24Y604Q)1%].54U"
M15(@<'5T=&EN9R!F;&]A="!I;B!)3E0@8V]L=6UN.B`@)SL*)')E<R`]("1D
M8F@M/G%U97)Y*")54$1!5$4@<&AP=&5S="!3150@82`](#@N.2!72$5212!A
M(#T@-#(B*3L*<W=I=&-H("@D9&)H+3YP:'!T>7!E*2!["B`@("!C87-E("=F
M8G-Q;"<Z"B`@("!C87-E("=I8F%S92<Z"B`@("!C87-E("=I9G@G.@H@("`@
M8V%S92`G;7-S<6PG.@H@("`@8V%S92`G;7ES<6PG.@H@("`@8V%S92`G;7ES
M<6QI)SH*("`@(&-A<V4@)V]C:3@G.@H@("`@8V%S92`G;V1B8R<Z"B`@("!C
M87-E("=P9W-Q;"<Z"B`@("!C87-E("=S<6QI=&4G.@H@("`@("`@(&-H96-K
M7V5R<F]R*"1R97,L($1"7T524D]27TE.5D%,241?3E5-0D52+"!F86QS92D[
M"B`@("`@("`@8G)E86L["B`@("!D969A=6QT.@H@("`@("`@(&-H96-K7V5R
M<F]R*"1R97,L($1"7T524D]27TE.5D%,241?3E5-0D52*3L*?0H*"G!R:6YT
M("=$0E]%4E)/4E])3E9!3$E$7TY534)%4B!P=71T:6YG(&5X8V5S<VEV92!I
M;G0@:6X@24Y4(&-O;'5M;CH@("<["B1R97,@/2`D9&)H+3YQ=65R>2@B55!$
M051%('!H<'1E<W0@4T54(&$@/2`Q.#0T-C<T-#`W,S<P.34U,38Q-B!72$52
M12!A(#T@-#(B*3L*<W=I=&-H("@D9&)H+3YP:'!T>7!E("X@)SHG("X@)&1B
M:"T^9&)S>6YT87@I('L*("`@(&-A<V4@)VEB87-E.FEB87-E)SH*("`@(&-A
M<V4@)VEB87-E.F9I<F5B:7)D)SH*("`@("`@("!C:&5C:U]E<G)O<B@D<F5S
M+"!$0E]%4E)/4E]364Y405@I.PH@("`@("`@(&)R96%K.PH@("`@8V%S92`G
M9F)S<6PZ9F)S<6PG.@H@("`@8V%S92`G;7-Q;#IM<W%L)SH*("`@(&-A<V4@
M)VUS<W%L.FUS<W%L)SH*("`@(&-A<V4@)VUY<W%L.FUY<W%L)SH*("`@(&-A
M<V4@)VUY<W%L:3IM>7-Q;&DG.@H@("`@8V%S92`G;V-I.#IO8VDX)SH*("`@
M(&-A<V4@)V]D8F,Z86-C97-S)SH*("`@(&-A<V4@)W-Q;&ET93IS<6QI=&4G
M.@H@("`@("`@(&-H96-K7V5R<F]R*"1R97,L($1"7T524D]27TE.5D%,241?
M3E5-0D52+"!F86QS92D["B`@("`@("`@8G)E86L["B`@("!D969A=6QT.@H@
M("`@("`@(&-H96-K7V5R<F]R*"1R97,L($1"7T524D]27TE.5D%,241?3E5-
M0D52*3L*?0H*"G!R:6YT("=$0E]%4E)/4E])3E9!3$E$7TY534)%4B!P=71T
M:6YG(&EN="!I;B!#2$%2(&-O;'5M;CH@("<["B1R97,@/2`D9&)H+3YQ=65R
M>2@B55!$051%('!H<'1E<W0@4T54(&(@/2`X(%=(15)%(&$@/2`T,B(I.PIS
M=VET8V@@*"1D8F@M/G!H<'1Y<&4@+B`G.B<@+B`D9&)H+3YD8G-Y;G1A>"D@
M>PH@("`@8V%S92`G:6)A<V4Z:6)A<V4G.@H@("`@8V%S92`G:6)A<V4Z9FER
M96)I<F0G.@H@("`@8V%S92`G:69X.FEF>"<Z"B`@("!C87-E("=M<W-Q;#IM
M<W-Q;"<Z"B`@("!C87-E("=M>7-Q;#IM>7-Q;"<Z"B`@("!C87-E("=M>7-Q
M;&DZ;7ES<6QI)SH*("`@(&-A<V4@)V]C:3@Z;V-I."<Z"B`@("!C87-E("=O
M9&)C.F%C8V5S<R<Z"B`@("!C87-E("=P9W-Q;#IP9W-Q;"<Z"B`@("!C87-E
M("=S<6QI=&4Z<W%L:71E)SH*("`@("`@("!C:&5C:U]E<G)O<B@D<F5S+"!$
M0E]%4E)/4E])3E9!3$E$7TY534)%4BP@9F%L<V4I.PH@("`@("`@(&)R96%K
M.PH@("`@9&5F875L=#H*("`@("`@("!C:&5C:U]E<G)O<B@D<F5S+"!$0E]%
M4E)/4E])3E9!3$E$7TY534)%4BD["GT*"@IP<FEN="`G1$)?15)23U)?3D]3
M54-(1DE%3$0Z("`G.PHD<F5S(#T@)&1B:"T^<75E<GDH)U-%3$5#5"!E($92
M3TT@<&AP=&5S="<I.PIC:&5C:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E].3U-5
M0TA&245,1"D["@H*<')I;G0@)T1"7T524D]27U-93E1!6#H@("<["B1R97,@
M/2`D9&)H+3YQ=65R>2@G0U)%051%)RD["F-H96-K7V5R<F]R*"1R97,L($1"
M7T524D]27U-93E1!6"D["@H*<')I;G0@)T1"7T524D]27U9!3%5%7T-/54Y4
M7T].7U)/5SH@("<["B1R97,@/2`D9&)H+3YQ=65R>2@G24Y315)4($E.5$\@
M<&AP=&5S="`H82D@5D%,5453("@V-S@L(#(I)RD["G-W:71C:"`H)&1B:"T^
M<&AP='EP92D@>PH@("`@8V%S92`G;7-Q;"<Z"B`@("`@("`@8VAE8VM?97)R
M;W(H)')E<RP@1$)?15)23U)?5D%,545?0T]53E1?3TY?4D]7+"!F86QS92D[
M"B`@("`@("`@8G)E86L["B`@("!D969A=6QT.@H@("`@("`@(&-H96-K7V5R
M<F]R*"1R97,L($1"7T524D]27U9!3%5%7T-/54Y47T].7U)/5RD["GT*"@IP
M<FEN="`G1$)?15)23U)?24Y604Q)1"!O;B!#2$%2(&-O;'5M;B!D871A('1O
M;R!L;VYG.B`@)SL*)')E<R`]("1D8F@M/G%U97)Y*"))3E-%4E0@24Y43R!P
M:'!T97-T("AB*2!604Q515,@*"<Q,C,T-38W.#DN,3(S-#4V-S@Y+C$R,S0U
M-C<X.2XQ,C,T-38W.#DN,2<I(BD["G-W:71C:"`H)&1B:"T^<&AP='EP92`N
M("<Z)R`N("1D8F@M/F1B<WEN=&%X*2!["B`@("!C87-E("=M<W%L.FUS<6PG
M.@H@("`@8V%S92`G;7-S<6PZ;7-S<6PG.@H@("`@8V%S92`G;7ES<6PZ;7ES
M<6PG.@H@("`@8V%S92`G;7ES<6QI.FUY<W%L:2<Z"B`@("!C87-E("=O9&)C
M.F%C8V5S<R<Z"B`@("!C87-E("=S<6QI=&4Z<W%L:71E)SH*("`@(&-A<V4@
M)W-Y8F%S93IS>6)A<V4G.@H@("`@("`@(&-H96-K7V5R<F]R*"1R97,L($1"
M7T524D]27TE.5D%,240L(&9A;'-E*3L*("`@("`@("!B<F5A:SL*("`@(&-A
M<V4@)V9B<W%L.F9B<W%L)SH*("`@("`@("!C:&5C:U]E<G)O<B@D<F5S+"!$
M0E]%4E)/4E]44E5.0T%4140I.PH@("`@("`@(&)R96%K.PH@("`@9&5F875L
M=#H*("`@("`@("!C:&5C:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E])3E9!3$E$
M*3L*?0H*"G!R:6YT("=$0E]%4E)/4E])3E9!3$E$(&]N(%9!4D-(05(@8V]L
M=6UN(&1A=&$@=&]O(&QO;F<Z("`G.PHD<F5S(#T@)&1B:"T^<75E<GDH(DE.
M4T525"!)3E1/('!H<'1E<W0@*&0I(%9!3%5%4R`H)S$R,S0U-C<X.2XQ,C,T
M-38W.#DN,2<I(BD["G-W:71C:"`H)&1B:"T^<&AP='EP92`N("<Z)R`N("1D
M8F@M/F1B<WEN=&%X*2!["B`@("!C87-E("=M<W%L.FUS<6PG.@H@("`@8V%S
M92`G;7-S<6PZ;7-S<6PG.@H@("`@8V%S92`G;7ES<6PZ;7ES<6PG.@H@("`@
M8V%S92`G;7ES<6QI.FUY<W%L:2<Z"B`@("!C87-E("=O9&)C.F%C8V5S<R<Z
M"B`@("!C87-E("=S<6QI=&4Z<W%L:71E)SH*("`@(&-A<V4@)W-Y8F%S93IS
M>6)A<V4G.@H@("`@("`@(&-H96-K7V5R<F]R*"1R97,L($1"7T524D]27TE.
M5D%,240L(&9A;'-E*3L*("`@("`@("!B<F5A:SL*("`@(&-A<V4@)V9B<W%L
M.F9B<W%L)SH*("`@("`@("!C:&5C:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E]4
M4E5.0T%4140I.PH@("`@("`@(&)R96%K.PH@("`@9&5F875L=#H*("`@("`@
M("!C:&5C:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E])3E9!3$E$*3L*?0H*"@ID
M<F]P7W1A8FQE*"1D8F@L("=P:'!T97-T)RD["F1R;W!?=&%B;&4H)&1B:"P@
M)V(G*3L*9')O<%]T86)L92@D9&)H+"`G82<I.PID<F]P7W1A8FQE*"1D8F@L
M("=P96%R=&5S=&YU;&PG*3L*````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V9E
M=&-H;6]D95]O8FIE8W0N:6YC````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#8R,C<@
M,3`U,34T,S,W,S(@,#(U,C0T`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"@HO*BH*("H@5&5S=',@=&AE(&1R:79E
M<G,G(&]B:F5C="!F971C:"!M;V1E('!R;V-E9'5R97,*("H*("H@17AE8W5T
M960@8GD@9')I=F5R+S$T9F5T8VAM;V1E7V]B:F5C="YP:'!T"B`J"B`J(%!(
M4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E
M(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI
M8V5N<V4*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E
M:79E(&$@8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B
M;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E
M;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y
M;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!$871A
M8F%S90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!$86YI96P@
M0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y
M.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@
M*B!`=F5R<VEO;B`@("`D260Z(&9E=&-H;6]D95]O8FIE8W0N:6YC+'8@,2XQ
M,2`R,#`U+S`R+S`S(#`U.C0Y.C0T(&1A;FEE;&,@17AP("0*("H@0&QI;FL@
M("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J+PH*97)R
M;W)?<F5P;W)T:6YG*$5?04Q,*3L*"B\J*@H@*B!,;V-A;"!E<G)O<B!C86QL
M8F%C:R!H86YD;&5R"B`J"B`J($1R;W!S('1H92!P:'!T97-T('1A8FQE+"!P
M<FEN=',@;W5T(&%N(&5R<F]R(&UE<W-A9V4@86YD(&MI;&QS('1H90H@*B!P
M<F]C97-S+@H@*@H@*B!`<&%R86T@;V)J96-T("`D;R`@4$5!4B!E<G)O<B!O
M8FIE8W0@875T;VUA=&EC86QL>2!P87-S960@=&\@=&AI<R!M971H;V0*("H@
M0')E='5R;B!V;VED"B`J($!S964@4$5!4CHZ<V5T17)R;W)(86YD;&EN9R@I
M"B`J+PIF=6YC=&EO;B!P92@D;RD@>PH@("`@9VQO8F%L("1D8F@["@H@("`@
M)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD["B`@
M("!D<F]P7W1A8FQE*"1D8F@L("=P:'!T97-T)RD["@H@("`@9&EE*"1O+3YT
M;U-T<FEN9R@I*3L*?0H*+RHJ"B`J(%!R:6YT(&]U="!T:&4@;V)J96-T"B`J
M+PIF=6YC=&EO;B!P<FEN=%]O8FHH)B1O8FHI('L*("`@(&EF("@A:7-?;V)J
M96-T*"1O8FHI*2!["B`@("`@("`@96-H;R`B15)23U(Z(&YO(&]B:F5C="%<
M;B(["B`@("!](&5L<V4@>PH@("`@("`@(&5C:&\@<W1R=&]L;W=E<BAG971?
M8VQA<W,H)&]B:BDI("X@)R`M/B`G("X@:6UP;&]D92@G("<L(&%R<F%Y7VME
M>7,H*&%R<F%Y*21O8FHI*2`N(")<;B(["B`@("!]"GT*"@HD9&)H+3YS971%
M<G)O<DAA;F1L:6YG*%!%05)?15)23U)?0T%,3$)!0TLL("=P92<I.PH*96-H
M;R`B+2TM(&9E=&-H('=I=&@@<&%R86T@1$)?1D540TA-3T1%7T]"2D5#5"`M
M+2U<;B(["B1S=&@@/2`D9&)H+3YQ=65R>2@B4T5,14-4("H@1E)/32!P:'!T
M97-T(BD["B1R;W<@/2`D<W1H+3YF971C:%)O=RA$0E]&151#2$U/1$5?3T)*
M14-4*3L*<')I;G1?;V)J*"1R;W<I.PHD<W1H+3YF<F5E*"D[("`O+R!K965P
M(&9B<W%L(&AA<'!Y+@H*)'-T:"`]("1D8F@M/G%U97)Y*")314Q%0U0@*B!&
M4D]-('!H<'1E<W0B*3L*)'-T:"T^9F5T8VA);G1O*"1R;W<L($1"7T9%5$-(
M34]$15]/0DI%0U0I.PIP<FEN=%]O8FHH)')O=RD["B1S=&@M/F9R964H*3L@
M("\O(&ME97`@9F)S<6P@:&%P<'DN"@IE8VAO("(M+2T@9F5T8V@@=VET:"!D
M969A=6QT(&9E=&-H;6]D92!$0E]&151#2$U/1$5?3T)*14-4("TM+5QN(CL*
M)&1B:"T^<V5T1F5T8VA-;V1E*$1"7T9%5$-(34]$15]/0DI%0U0I.PHD<W1H
M(#T@)&1B:"T^<75E<GDH(E-%3$5#5"`J($923TT@<&AP=&5S="(I.PHD<F]W
M(#T@)'-T:"T^9F5T8VA2;W<H*3L*<')I;G1?;V)J*"1R;W<I.PHD<W1H+3YF
M<F5E*"D[("`O+R!K965P(&9B<W%L(&AA<'!Y+@H*)'-T:"`]("1D8F@M/G%U
M97)Y*")314Q%0U0@*B!&4D]-('!H<'1E<W0B*3L*)'-T:"T^9F5T8VA);G1O
M*"1R;W<I.PIP<FEN=%]O8FHH)')O=RD["B1S=&@M/F9R964H*3L@("\O(&ME
M97`@9F)S<6P@:&%P<'DN"@IE8VAO("(M+2T@9F5T8V@@=VET:"!D969A=6QT
M(&9E=&-H;6]D92!$0E]&151#2$U/1$5?3T)*14-4(&%N9"!C;&%S<R!$0E]R
M;W<@+2TM7&XB.PHD9&)H+3YS971&971C:$UO9&4H1$)?1D540TA-3T1%7T]"
M2D5#5"P@)T1"7W)O=R<I.PHD<W1H(#T@)&1B:"T^<75E<GDH(E-%3$5#5"`J
M($923TT@<&AP=&5S="(I.PHD<F]W(#T@)'-T:"T^9F5T8VA2;W<H*3L*<')I
M;G1?;V)J*"1R;W<I.PHD<W1H+3YF<F5E*"D[("`O+R!K965P(&9B<W%L(&AA
M<'!Y+@H*)'-T:"`]("1D8F@M/G%U97)Y*")314Q%0U0@*B!&4D]-('!H<'1E
M<W0B*3L*)'-T:"T^9F5T8VA);G1O*"1R;W<I.PIP<FEN=%]O8FHH)')O=RD[
M"B1S=&@M/F9R964H*3L@("\O(&ME97`@9F)S<6P@:&%P<'DN"@IE8VAO("(M
M+2T@9F5T8V@@=VET:"!D969A=6QT(&9E=&-H;6]D92!$0E]&151#2$U/1$5?
M3T)*14-4('=I=&@@;F\@8VQA<W,@=&AE;B!$0E]R;W<@+2TM7&XB.PHD9&)H
M+3YS971&971C:$UO9&4H1$)?1D540TA-3T1%7T]"2D5#5"D["B1S=&@@/2`D
M9&)H+3YQ=65R>2@G4T5,14-4("H@1E)/32!P:'!T97-T)RD["B1R;W<@/2`D
M<W1H+3YF971C:%)O=R@I.PIP<FEN=%]O8FHH)')O=RD["B1S=&@M/F9R964H
M*3L@("\O(&ME97`@9F)S<6P@:&%P<'DN"@HD9&)H+3YS971&971C:$UO9&4H
M1$)?1D540TA-3T1%7T]"2D5#5"P@)T1"7W)O=R<I.PHD<W1H(#T@)&1B:"T^
M<75E<GDH)U-%3$5#5"`J($923TT@<&AP=&5S="<I.PHD<F]W(#T@)'-T:"T^
M9F5T8VA2;W<H*3L*<')I;G1?;V)J*"1R;W<I.PH*)'-T:"T^9G)E92@I.R`@
M+R\@:V5E<"!F8G-Q;"!H87!P>2X*("`@("`@("`@("`@("`@+R\@:V5E<"!I
M8F%S92!H87!P>3H@8V%N)W0@9')O<"!T8FP@=&AA="!H87,@<F5S=6QT<R!O
M<&5N(&%G86EN<W0@:70N"@HD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?
M15)23U)?4D5455).*3L*9')O<%]T86)L92@D9&)H+"`G<&AP=&5S="<I.PH`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]F
M971C:&UO9&5S+FEN8P``````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$S,S8R
M(#$P-3$U-#,S-S,R(#`R-#`W-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`H*+RHJ"B`J(%1E<W1S('1H92!D<FEV
M97)S)R!V87)I;W5S(&9E=&-H(&UE=&AO9',*("H*("H@17AE8W5T960@8GD@
M9')I=F5R+S`R9F5T8V@N<&AP=`H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@
M-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@
M=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@
M879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F
M;VQL;W=I;F<@55)).@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S
M7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@
M=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T
M:')O=6=H('1H92!W96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E
M;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA
M=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@
M("`@1$(*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L
M8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'
M<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@)$ED
M.B!F971C:&UO9&5S+FEN8RQV(#$N,3$@,C`P-2\P,B\Q-"`Q-SHP-#HQ-"!D
M86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN
M970O<&%C:V%G92]$0@H@*B\*"B\J*@H@*B!,;V-A;"!E<G)O<B!C86QL8F%C
M:R!H86YD;&5R"B`J"B`J($1R;W!S('1H92!P:'!T97-T('1A8FQE+"!P<FEN
M=',@;W5T(&%N(&5R<F]R(&UE<W-A9V4@86YD(&MI;&QS('1H90H@*B!P<F]C
M97-S+@H@*@H@*B!`<&%R86T@;V)J96-T("`D;R`@4$5!4B!E<G)O<B!O8FIE
M8W0@875T;VUA=&EC86QL>2!P87-S960@=&\@=&AI<R!M971H;V0*("H@0')E
M='5R;B!V;VED"B`J($!S964@4$5!4CHZ<V5T17)R;W)(86YD;&EN9R@I"B`J
M+PIF=6YC=&EO;B!P92@D;RD@>PH@("`@9VQO8F%L("1D8F@["@H@("`@)&1B
M:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD["B`@("!D
M<F]P7W1A8FQE*"1D8F@L("=P:'!T97-T)RD["@H@("`@9&EE*"1O+3YT;U-T
M<FEN9R@I*3L*?0H*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]2
M7T-!3$Q"04-++"`G<&4G*3L*)&1B:"T^<V5T3W!T:6]N*"=A=71O9G)E92<L
M('1R=64I.PH*)&1B:"T^<75E<GDH(DE.4T525"!)3E1/('!H<'1E<W0@5D%,
M5453("@Q+"`G;VYE)RP@)T]N92<L("<R,#`Q+3`R+3$V)RDB*3L*)&1B:"T^
M<75E<GDH(DE.4T525"!)3E1/('!H<'1E<W0@5D%,5453("@R+"`G='=O)RP@
M)U1W;R<L("<R,#`Q+3`R+3$U)RDB*3L*)&1B:"T^<75E<GDH(DE.4T525"!)
M3E1/('!H<'1E<W0@5D%,5453("@S+"`G=&AR964G+"`G5&AR964G+"`G,C`P
M,2TP,BTQ-"<I(BD["@IP<FEN="`B=&5S=&EN9R!F971C:')O=SI<;B(["B1S
M=&@@/2`D9&)H+3YQ=65R>2@B4T5,14-4("H@1E)/32!P:'!T97-T(BD["F9O
M<B`H)&D@/2`Q.R`D:2`\/2`U.R`D:2LK*2!["B`@("!P<FEN="`B<F]W("1I
M.B`B.PH@("`@)')O=R`]("1S=&@M/F9E=&-H4F]W*"D["B`@("!I9B`H1$(Z
M.FES17)R;W(H)')O=RDI('L*("`@("`@("!P<FEN="`D<F]W+3YT;U-T<FEN
M9R@I("X@(EQN(CL*("`@("`@("!C;VYT:6YU93L*("`@('T*("`@(&EF("AI
M<U]A<G)A>2@D<F]W*2D@>PH@("`@("`@('!R:6YT(&EM<&QO9&4H)RP@)RP@
M)')O=RD@+B`B7&XB.PH@("`@?2!E;'-E('L*("`@("`@("!V87)?9'5M<"@D
M<F]W*3L*("`@('T*?0HD<W1H+3YF<F5E*"D[("`O+R!K965P(&9B<W%L(&AA
M<'!Y+@H*)&1B:"T^<75E<GDH)T1%3$5412!&4D]-('!H<'1E<W0@5TA%4D4@
M82`\/B`T,B<I.PH*"G!R:6YT(")T97-T:6YG(&9E=&-H;6]D97,Z(&9E=&-H
M<F]W(&1E9F%U;'0@9&5F875L="P@<&]R=&%B:6QI='D@;6]D92!$0E]03U)4
M04))3$E465]!3$P@7B!$0E]03U)404))3$E465]25%))35QN(CL*)&1B:"T^
M<V5T3W!T:6]N*"=P;W)T86)I;&ET>2<L($1"7U!/4E1!0DE,25197T%,3"!>
M($1"7U!/4E1!0DE,25197U)44DE-*3L*)'-T:"`]("1D8F@M/G%U97)Y*")3
M14Q%0U0@*B!&4D]-('!H<'1E<W0B*3L*)')O=R`]("1S=&@M/F9E=&-H4F]W
M*"D["G!R:6YT(&EM<&QO9&4H(B`B+"!A<G)A>5]K97ES*"1R;W<I*2XB7&XB
M.PHD86-T=6%L(#T@:6UP;&]D92@G("<L(&%R<F%Y7W9A;'5E<R@D<F]W*2D[
M"G-W:71C:"`H)&1B:"T^<&AP='EP92D@>PH@("`@8V%S92`G9F)S<6PG.@H@
M("`@8V%S92`G;7-Q;"<Z"B`@("!C87-E("=M>7-Q;"<Z"B`@("!C87-E("=M
M>7-Q;&DG.@H@("`@8V%S92`G<W%L:71E)SH*("`@("`@("`D97AP96-T960@
M/2`G-#(@8FEN9R!4:&ES(&ES(&$@=&5S="`Q.3DY+3$Q+3(Q)SL*("`@("`@
M("!B<F5A:SL*("`@(&-A<V4@)VEF>"<Z"B`@("`@("`@)&5X<&5C=&5D(#T@
M)S0R(&)I;F<@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M5&AI<R!I<R!A('1E<W0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#$Y.3DM,3$M,C$@("`@
M("`@("`@)SL*("`@("`@("!B<F5A:SL*("`@(&1E9F%U;'0Z"B`@("`@("`@
M)&5X<&5C=&5D(#T@)S0R(&)I;F<@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@5&AI<R!I<R!A('1E<W0@,3DY.2TQ,2TR,2<["GT*:68@
M*"1A8W1U86P@/3T@)&5X<&5C=&5D*2!["B`@("!E8VAO(")O=71P=70@;6%T
M8VAE9"!E>'!E8W1E9"!F;W)M871<;B(["GT@96QS92!["B`@("!E8VAO(")$
M241.)U0@34%40T@A("!%>'!E8W1E9"!O=71P=70Z("<D97AP96-T960G+B`@
M06-T=6%L(&]U='!U=#H@)R1A8W1U86PG+EQN(CL*?0HD<W1H+3YF<F5E*"D[
M("`O+R!K965P(&9B<W%L(&AA<'!Y+@H*<')I;G0@(G1E<W1I;F<@9F5T8VAM
M;V1E<SH@9F5T8VAI;G1O(&1E9F%U;'0@9&5F875L=%QN(CL*)&1B:"T^<V5T
M3W!T:6]N*"=P;W)T86)I;&ET>2<L($1"7U!/4E1!0DE,25197T%,3"D["B1S
M=&@@/2`D9&)H+3YQ=65R>2@B4T5,14-4("H@1E)/32!P:'!T97-T(BD["B1R
M;W<@/2!A<G)A>2@I.PHD<W1H+3YF971C:$EN=&\H)')O=RD["G!R:6YT(&EM
M<&QO9&4H(B`B+"!A<G)A>5]K97ES*"1R;W<I*2XB7&XB.PIP<FEN="!I;7!L
M;V1E*"<@)RP@87)R87E?=F%L=65S*"1R;W<I*2XB7&XB.PHD<W1H+3YF<F5E
M*"D[("`O+R!K965P(&9B<W%L(&AA<'!Y+@H*<')I;G0@(G1E<W1I;F<@9F5T
M8VAM;V1E<SH@9F5T8VAR;W<@;W)D97)E9"!D969A=6QT7&XB.PHD9&)H+3YS
M971&971C:$UO9&4H1$)?1D540TA-3T1%7T]21$52140I.PHD<W1H(#T@)&1B
M:"T^<75E<GDH(E-%3$5#5"`J($923TT@<&AP=&5S="(I.PHD<F]W(#T@)'-T
M:"T^9F5T8VA2;W<H*3L*<')I;G0@:6UP;&]D92@B("(L(&%R<F%Y7VME>7,H
M)')O=RDI+B)<;B(["B1S=&@M/F9R964H*3L@("\O(&ME97`@9F)S<6P@:&%P
M<'DN"@IP<FEN="`B=&5S=&EN9R!F971C:&UO9&5S.B!F971C:')O=R!A<W-O
M8R!D969A=6QT7&XB.PHD9&)H+3YS971&971C:$UO9&4H1$)?1D540TA-3T1%
M7T%34T]#*3L*)'-T:"`]("1D8F@M/G%U97)Y*")314Q%0U0@*B!&4D]-('!H
M<'1E<W0B*3L*)')O=R`]("1S=&@M/F9E=&-H4F]W*"D["G!R:6YT(&EM<&QO
M9&4H(B`B+"!A<G)A>5]K97ES*"1R;W<I*2XB7&XB.PHD<W1H+3YF<F5E*"D[
M("`O+R!K965P(&9B<W%L(&AA<'!Y+@H*<')I;G0@(G1E<W1I;F<@9F5T8VAM
M;V1E<SH@9F5T8VAR;W<@;W)D97)E9"!D969A=6QT('=I=&@@87-S;V,@<W!E
M8VEF:65D7&XB.PHD9&)H+3YS971&971C:$UO9&4H1$)?1D540TA-3T1%7T]2
M1$52140I.PHD<W1H(#T@)&1B:"T^<75E<GDH(E-%3$5#5"`J($923TT@<&AP
M=&5S="(I.PHD<F]W(#T@)'-T:"T^9F5T8VA2;W<H1$)?1D540TA-3T1%7T%3
M4T]#*3L*<')I;G0@:6UP;&]D92@B("(L(&%R<F%Y7VME>7,H)')O=RDI+B)<
M;B(["B1S=&@M/F9R964H*3L@("\O(&ME97`@9F)S<6P@:&%P<'DN"@IP<FEN
M="`B=&5S=&EN9R!F971C:&UO9&5S.B!F971C:')O=R!A<W-O8R!D969A=6QT
M('=I=&@@;W)D97)E9"!S<&5C:69I961<;B(["B1D8F@M/G-E=$9E=&-H36]D
M92A$0E]&151#2$U/1$5?05-33T,I.PHD<W1H(#T@)&1B:"T^<75E<GDH(E-%
M3$5#5"`J($923TT@<&AP=&5S="(I.PHD<F]W(#T@)'-T:"T^9F5T8VA2;W<H
M1$)?1D540TA-3T1%7T]21$52140I.PIP<FEN="!I;7!L;V1E*"(@(BP@87)R
M87E?:V5Y<R@D<F]W*2DN(EQN(CL*)'-T:"T^9G)E92@I.R`@+R\@:V5E<"!F
M8G-Q;"!H87!P>2X*"G!R:6YT(")T97-T:6YG(&9E=&-H;6]D97,Z(&9E=&-H
M:6YT;R!O<F1E<F5D(&1E9F%U;'1<;B(["B1D8F@M/G-E=$9E=&-H36]D92A$
M0E]&151#2$U/1$5?3U)$15)%1"D["B1S=&@@/2`D9&)H+3YQ=65R>2@B4T5,
M14-4("H@1E)/32!P:'!T97-T(BD["B1R;W<@/2!A<G)A>2@I.PHD<W1H+3YF
M971C:$EN=&\H)')O=RD["G!R:6YT(&EM<&QO9&4H(B`B+"!A<G)A>5]K97ES
M*"1R;W<I*2XB7&XB.PHD<W1H+3YF<F5E*"D[("`O+R!K965P(&9B<W%L(&AA
M<'!Y+@H*<')I;G0@(G1E<W1I;F<@9F5T8VAM;V1E<SH@9F5T8VAI;G1O(&%S
M<V]C(&1E9F%U;'1<;B(["B1D8F@M/G-E=$9E=&-H36]D92A$0E]&151#2$U/
M1$5?05-33T,I.PHD<W1H(#T@)&1B:"T^<75E<GDH(E-%3$5#5"`J($923TT@
M<&AP=&5S="(I.PHD<F]W(#T@87)R87DH*3L*)'-T:"T^9F5T8VA);G1O*"1R
M;W<I.PIP<FEN="!I;7!L;V1E*"(@(BP@87)R87E?:V5Y<R@D<F]W*2DN(EQN
M(CL*)'-T:"T^9G)E92@I.R`@+R\@:V5E<"!F8G-Q;"!H87!P>2X*"G!R:6YT
M(")T97-T:6YG(&9E=&-H;6]D97,Z(&9E=&-H:6YT;R!O<F1E<F5D(&1E9F%U
M;'0@=VET:"!A<W-O8R!S<&5C:69I961<;B(["B1D8F@M/G-E=$9E=&-H36]D
M92A$0E]&151#2$U/1$5?3U)$15)%1"D["B1S=&@@/2`D9&)H+3YQ=65R>2@B
M4T5,14-4("H@1E)/32!P:'!T97-T(BD["B1R;W<@/2!A<G)A>2@I.PHD<W1H
M+3YF971C:$EN=&\H)')O=RP@1$)?1D540TA-3T1%7T%34T]#*3L*<')I;G0@
M:6UP;&]D92@B("(L(&%R<F%Y7VME>7,H)')O=RDI+B)<;B(["B1S=&@M/F9R
M964H*3L@("\O(&ME97`@9F)S<6P@:&%P<'DN"@IP<FEN="`B=&5S=&EN9R!F
M971C:&UO9&5S.B!F971C:&EN=&\@87-S;V,@9&5F875L="!W:71H(&]R9&5R
M960@<W!E8VEF:65D7&XB.PHD9&)H+3YS971&971C:$UO9&4H1$)?1D540TA-
M3T1%7T%34T]#*3L*)'-T:"`]("1D8F@M/G%U97)Y*")314Q%0U0@*B!&4D]-
M('!H<'1E<W0B*3L*)')O=R`](&%R<F%Y*"D["B1S=&@M/F9E=&-H26YT;R@D
M<F]W+"!$0E]&151#2$U/1$5?3U)$15)%1"D["G!R:6YT(&EM<&QO9&4H(B`B
M+"!A<G)A>5]K97ES*"1R;W<I*2XB7&XB.PH*)'-T:"T^9G)E92@I.R`@+R\@
M:V5E<"!F8G-Q;"!H87!P>2X*("`@("`@("`@("`@("`@+R\@:V5E<"!I8F%S
M92!H87!P>3H@8V%N)W0@9')O<"!T8FP@=&AA="!H87,@<F5S=6QT<R!O<&5N
M(&%G86EN<W0@:70N"@HD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)2
M3U)?4D5455).*3L*9')O<%]T86)L92@D9&)H+"`G<&AP=&5S="<I.PH`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+VEN8VQU
M9&4N:6YC````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#0P-3(@,3`U
M,34T,S,W,S(@,#(S,S<U`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"@HO*BH*("H@4V5T<R!T:&4@:6YC;'5D95]P
M871H+"!E<G)O<E]R97!O<G1I;F<@86YD(%!!5$A?4T5005)!5$]2(&9O<B!T
M97-T<PH@*B!I;B!T:&4@1$(O=&5S=',@9&ER96-T;W)Y"B`J"B`J(%!(4"!V
M97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I
M;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N
M<V4*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED
M92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E
M(&$@8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@
M=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@
M82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@
M82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S
M90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!$86YI96P@0V]N
M=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M
M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`
M=F5R<VEO;B`@("`D260Z(&EN8VQU9&4N:6YC+'8@,2XU(#(P,#4O,#(O,#,@
M,#4Z-#DZ-#0@9&%N:65L8R!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO"@IE<G)O<E]R97!O<G1I;F<H
M15]!3$PI.PH*:68@*"%D969I;F5D*"=0051(7U-%4$%2051/4B<I*2!["B`@
M("!I9B`H<W1R:7-T<BA02%!?3U,L("=724XG*2D@>PH@("`@("`@("\J*@H@
M("`@("`@("`J($1E9FEN92!T:&4@<&%T:"!S97!A<F%T;W(@9F]R('=I;F1O
M=W,*("`@("`@("`@*B\*("`@("`@("!D969I;F4H)U!!5$A?4T5005)!5$]2
M)RP@)SLG*3L*("`@('T@96QS92!["B`@("`@("`@+RHJ"B`@("`@("`@("H@
M1&5F:6YE('1H92!P871H('-E<&%R871O<B!F;W(@;W1H97(@<WES=&5M<PH@
M("`@("`@("`J+PH@("`@("`@(&1E9FEN92@G4$%42%]315!!4D%43U(G+"`G
M.B<I.PH@("`@?0I]"@HO*@H@*B!)9B!T:&4@<&%T:"!T;R!Y;W5R(%!%05(@
M:6YS=&%L;&%T:6]N(&ES(&9O=6YD(&EN('1H92!L969T(&AA;F0*("H@<&]R
M=&EO;B!O9B!T:&4@:68H*2!E>'!R97-S:6]N(&)E;&]W+"!T:&%T(&UE86YS
M('1H:7,@9FEL92!H87,*("H@8V]M92!F<F]M('1H92!014%2(&EN<W1A;&QE
M<BX@(%1H97)E9F]R92P@;&5T)W,@=7-E('1H90H@*B!I;G-T86QL960@=F5R
M<VEO;B!O9B!$0BP@=VAI8V@@<VAO=6QD(&)E(&9O=6YD('9I82!T:&4*("H@
M8V]M<'5T97(G<R!D969A=6QT(&EN8VQU9&5?<&%T:"X@($%D9"`G+B<@=&\@
M=&AE(&EN8VQU9&5?<&%T:`H@*B!T;R!E;G-U<F4@)RXG(&ES(&EN('1H97)E
M+@H@*B`*("H@268@=&AE('!A=&@@:&%S(&YO="!B965N('-U8G-T:71U=&5D
M(&EN('1H92!I9B@I(&5X<')E<W-I;VXL"B`J('1H:7,@9FEL92!H87,@;&EK
M96QY(&-O;64@9G)O;2!A($-64R!C:&5C:V]U="!O<B!A("YT87(@9FEL92X*
M("H@5&AE<F5F;W)E+"!W92=L;"!A<W-U;64@=&AE('1E<W1S('-H;W5L9"!U
M<V4@=&AE('9E<G-I;VX@;V8*("H@1$(@=&AA="!H87,@8V]M92!F<F]M('1H
M97)E(&%S('=E;&PN"B`J+PII9B`H)R]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R)R`A/2`G0"<N)VEN8VQU9&5?<&%T:"<N)T`G*2!["B`@("!I;FE?
M<V5T*"=I;F-L=61E7W!A=&@G+"!I;FE?9V5T*"=I;F-L=61E7W!A=&@G*0H@
M("`@("`@("`@("`N(%!!5$A?4T5005)!5$]2("X@)RXG"B`@("`I.PI](&5L
M<V4@>PH@("`@:6YI7W-E="@G:6YC;'5D95]P871H)RP@<F5A;'!A=&@H9&ER
M;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD*("`@("`@("`@("`@+B!0051(7U-%
M4$%2051/4B`N("<N)R`N(%!!5$A?4T5005)!5$]2"B`@("`@("`@("`@("X@
M:6YI7V=E="@G:6YC;'5D95]P871H)RD*("`@("D["GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1"
M+W1E<W1S+VQI;6ET+FEN8P``````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#0V,C(@,3`U,34T,S,W,S(@,#(S,#<S`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@HO*BH*("H@5&5S=',@
M=&AE(&1R:79E<G,G(&QI;6ET475E<GDH*2!M971H;V0*("H*("H@17AE8W5T
M960@8GD@9')I=F5R+S$S;&EM:70N<&AP=`H@*@H@*B!02%`@=F5R<VEO;G,@
M-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U
M8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H
M870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T
M('1H92!F;VQL;W=I;F<@55)).@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@
M;V8*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I
M;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T
M;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I
M;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A
M8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\
M9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE
M(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@
M("`@)$ED.B!L:6UI="YI;F,L=B`Q+C$Q(#(P,#4O,#(O,#,@,#4Z-#DZ-#0@
M9&%N:65L8R!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N
M;F5T+W!A8VMA9V4O1$(*("HO"@IE<G)O<E]R97!O<G1I;F<H15]!3$PI.PH*
M+RHJ"B`J($QO8V%L(&5R<F]R(&-A;&QB86-K(&AA;F1L97(*("H*("H@1')O
M<',@=&AE('!H<'1E<W0@=&%B;&4L('!R:6YT<R!O=70@86X@97)R;W(@;65S
M<V%G92!A;F0@:VEL;',@=&AE"B`J('!R;V-E<W,N"B`J"B`J($!P87)A;2!O
M8FIE8W0@("1O("!014%2(&5R<F]R(&]B:F5C="!A=71O;6%T:6-A;&QY('!A
M<W-E9"!T;R!T:&ES(&UE=&AO9`H@*B!`<F5T=7)N('9O:60*("H@0'-E92!0
M14%2.CIS971%<G)O<DAA;F1L:6YG*"D*("HO"F9U;F-T:6]N('!E*"1O*2![
M"B`@("!G;&]B86P@)&1B:#L*"B`@("`D9&)H+3YS971%<G)O<DAA;F1L:6YG
M*%!%05)?15)23U)?4D5455).*3L*("`@(&1R;W!?=&%B;&4H)&1B:"P@)W!H
M<'1E<W0G*3L*"B`@("!D:64H)&\M/G1O4W1R:6YG*"DI.PI]"@H*)&1B:"T^
M<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD["F1R;W!?=&%B
M;&4H)&1B:"P@)W!H<%]L:6UI="<I.PH*)&1B:"T^<V5T17)R;W)(86YD;&EN
M9RA014%27T524D]27T-!3$Q"04-++"`G<&4G*3L*"B1D8F@M/G%U97)Y*"=#
M4D5!5$4@5$%"3$4@<&AP7VQI;6ET("AA($-(05(H,C`I*2<I.PH*"B1F<F]M
M("`@(#T@,#L*)&-O=6YT("`@/2`Q,#L*)&YU;7)O=W,@/2`S,#L*"F9O<B`H
M)&D],#L@)&D\/21N=6UR;W=S*S([("1I*RLI('L*("`@("1D8F@M/G%U97)Y
M*"))3E-%4E0@24Y43R!P:'!?;&EM:70@5D%,5453*"=R97-U;'0@)&DG*2(I
M.PI]"F9O<B`H)&D@/2`P.R`D:2`\/2`S.R`D:2LK*2!["B`@("`D9G)O;2`]
M(#$P("H@)&D["B`@("`D<F5S(#T@)&1B:"T^;&EM:711=65R>2@B<V5L96-T
M("H@9G)O;2!P:'!?;&EM:70B+"`D9G)O;2P@)&-O=6YT*3L*("`@(&5C:&\@
M(CT]/3T]/3T@1G)O;3H@)&9R;VT@?'P@3G5M8F5R(&]F(')O=W,@=&\@9F5T
M8V@Z("1C;W5N="`]/3T]/3T]7&XB.PH@("`@=VAI;&4@*"1R;W<@/2`D<F5S
M+3YF971C:%)O=RA$0E]&151#2$U/1$5?05-33T,I*2!["B`@("`@("`@96-H
M;R`D<F5S+3YG9712;W=#;W5N=&5R*"D@+B`G+BT@)R`N("1R;W=;)V$G72`N
M(")<;B(["B`@("!]"B`@("`D<F5S+3YF<F5E*"D[("`O+R!K965P(&9B<W%L
M(&AA<'!Y+@I]"@H*)&9R;VT@(#T@,3$["B1C;W5N="`](#,["@IE8VAO("(]
M/3T]/3T](%!A<W-I;F<@7"1P87)A;7,@?'P@1G)O;3H@)&9R;VT@?'P@3G5M
M8F5R(&]F(')O=W,@=&\@9F5T8V@Z("1C;W5N="`]/3T]/3T]7&XB.PHD<F5S
M(#T@)&1B:"T^;&EM:711=65R>2@G4T5,14-4("H@1E)/32!P:'!?;&EM:70@
M5TA%4D4@82`\(#\G+"`D9G)O;2P@)&-O=6YT+"!A<G)A>2@G<F5S=6QT(#DY
M)RDI.PIW:&EL92`H)')O=R`]("1R97,M/F9E=&-H4F]W*$1"7T9%5$-(34]$
M15]!4U-/0RDI('L*("`@(&5C:&\@)')E<RT^9V5T4F]W0V]U;G1E<B@I("X@
M)RXM("<@+B`D<F]W6R=A)UT@+B`B7&XB.PI]"@HD<F5S+3YF<F5E*"D[("`O
M+R!K965P(&9B<W%L(&AA<'!Y+@H@("`@("`@("`@("`@("`O+R!K965P(&EB
M87-E(&AA<'!Y.B!C86XG="!D<F]P('1B;"!T:&%T(&AA<R!R97-U;'1S(&]P
M96X@86=A:6YS="!I="X*"B1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%
M4E)/4E]215154DXI.PID<F]P7W1A8FQE*"1D8F@L("=P:'!?;&EM:70G*3L*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+W1E<W1S+T1"+W1E<W1S+VYU;6-O;',N:6YC````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#,U,3,@,3`U,34T,S,W,S(@,#(S-#,S`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"@HO
M*BH*("H@5&5S=',@=&AE(&1R:79E<G,G(&YU;4-O;',H*2!M971H;V0*("H*
M("H@17AE8W5T960@8GD@9')I=F5R+S`T;G5M8V]L<RYP:'!T"B`J"B`J(%!(
M4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E
M(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI
M8V5N<V4*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E
M:79E(&$@8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B
M;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E
M;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y
M;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!$871A
M8F%S90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!$86YI96P@
M0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y
M.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@
M*B!`=F5R<VEO;B`@("`D260Z(&YU;6-O;',N:6YC+'8@,2XW(#(P,#4O,#(O
M,#,@,#4Z-#DZ-#0@9&%N:65L8R!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P
M.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO"@HO*BH*("H@3&]C86P@
M97)R;W(@8V%L;&)A8VL@:&%N9&QE<@H@*@H@*B!$<F]P<R!T:&4@<&AP=&5S
M="!T86)L92P@<')I;G1S(&]U="!A;B!E<G)O<B!M97-S86=E(&%N9"!K:6QL
M<R!T:&4*("H@<')O8V5S<RX*("H*("H@0'!A<F%M(&]B:F5C="`@)&\@(%!%
M05(@97)R;W(@;V)J96-T(&%U=&]M871I8V%L;'D@<&%S<V5D('1O('1H:7,@
M;65T:&]D"B`J($!R971U<FX@=F]I9`H@*B!`<V5E(%!%05(Z.G-E=$5R<F]R
M2&%N9&QI;F<H*0H@*B\*9G5N8W1I;VX@<&4H)&\I('L*("`@(&=L;V)A;"`D
M9&)H.PH*("`@("1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]2
M15154DXI.PH@("`@9')O<%]T86)L92@D9&)H+"`G<&AP=&5S="<I.PH*("`@
M(&1I92@D;RT^=&]3=')I;F<H*2D["GT*"B1D8F@M/G-E=$5R<F]R2&%N9&QI
M;F<H4$5!4E]%4E)/4E]#04Q,0D%#2RP@)W!E)RD["@H*)'-T:"`]("1D8F@M
M/G%U97)Y*")314Q%0U0@82!&4D]-('!H<'1E<W0B*3L*<')I;G1F*"(E9%QN
M(BP@)'-T:"T^;G5M0V]L<R@I*3L*)'-T:"`]("1D8F@M/G%U97)Y*")314Q%
M0U0@82QB($923TT@<&AP=&5S="(I.PIP<FEN=&8H(B5D7&XB+"`D<W1H+3YN
M=6U#;VQS*"DI.PHD<W1H(#T@)&1B:"T^<75E<GDH(E-%3$5#5"!A+&(L8R!&
M4D]-('!H<'1E<W0B*3L*<')I;G1F*"(E9%QN(BP@)'-T:"T^;G5M0V]L<R@I
M*3L*)'-T:"`]("1D8F@M/G%U97)Y*")314Q%0U0@*B!&4D]-('!H<'1E<W0B
M*3L*<')I;G1F*"(E9%QN(BP@)'-T:"T^;G5M0V]L<R@I*3L*"@IS=VET8V@@
M*"1D8F@M/G!H<'1Y<&4I('L*("`@(&-A<V4@)VEB87-E)SH*("`@("`@("`O
M*@H@("`@("`@("`J($EN=&5R8F%S92!D;V5S;B=T(&%L;&]W(&1R;W!P:6YG
M('1A8FQE<R!T:&%T(&AA=F4@<F5S=6QT"B`@("`@("`@("H@<V5T<R!S=&EL
M;"!O<&5N+@H@("`@("`@("`J+PH@("`@("`@("1D8F@M/F9R965297-U;'0H
M)'-T:"T^<F5S=6QT*3L*("`@("`@("!B<F5A:SL*?0HD9&)H+3YS971%<G)O
M<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L*9')O<%]T86)L92@D9&)H
M+"`G<&AP=&5S="<I.PH`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T
M97-T<R]$0B]T97-T<R]N=6UR;W=S+FEN8P``````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`V,C,V(#$P-3$U-#,S-S,R(#`R,S0W,@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`H*+RHJ"B`J
M(%1E<W1S('1H92!D<FEV97)S)R!N=6U2;W=S*"D@;65T:&]D"B`J"B`J($5X
M96-U=&5D(&)Y(&1R:79E<B\P.6YU;7)O=W,N<&AP=`H@*@H@*B!02%`@=F5R
M<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE
M(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E
M"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M
M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@H@*B!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A
M(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O
M(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90H@*B!S96YD(&$@
M;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@
M8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*
M("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I
M<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P
M,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E
M<G-I;VX@("`@)$ED.B!N=6UR;W=S+FEN8RQV(#$N,3(@,C`P-2\P,B\P.2`P
M-SHP-SHR-"!D86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P
M96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B\*"B\J*@H@*B!,;V-A;"!E<G)O
M<B!C86QL8F%C:R!H86YD;&5R"B`J"B`J($1R;W!S('1H92!P:'!T97-T('1A
M8FQE+"!P<FEN=',@;W5T(&%N(&5R<F]R(&UE<W-A9V4@86YD(&MI;&QS('1H
M90H@*B!P<F]C97-S+@H@*@H@*B!`<&%R86T@;V)J96-T("`D;R`@4$5!4B!E
M<G)O<B!O8FIE8W0@875T;VUA=&EC86QL>2!P87-S960@=&\@=&AI<R!M971H
M;V0*("H@0')E='5R;B!V;VED"B`J($!S964@4$5!4CHZ<V5T17)R;W)(86YD
M;&EN9R@I"B`J+PIF=6YC=&EO;B!P92@D;RD@>PH@("`@9VQO8F%L("1D8F@[
M"@H@("`@)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%52
M3BD["B`@("!D<F]P7W1A8FQE*"1D8F@L("=P:'!T97-T)RD["@H@("`@<')I
M;G0@(EQN+2TM+2TM+2TM+2TM7&XB.PH@("`@:68@*"1O+3YG971#;V1E*"D@
M/3T@1$)?15)23U)?3D]47T-!4$%"3$4I('L*("`@("`@("!P<FEN="`B5&AI
M<R!$0DU3(&1O97,@;F]T('-U<'!O<G0@;G5M4F]W<R@I+B(["B`@("!](&5L
M<V5I9B`H)&\M/F=E=$-O9&4H*2`]/2!$0E]%4E)/4E]-25--051#2"D@>PH@
M("`@("`@('!R:6YT(")-:7-M871C:"!B971W965N('1H92!N=6UB97(@;V8@
M<&QA8V5H;VQD97)S(&%N9"!P87)A;65T97)S+EQN(CL*("`@("`@("!F;W)E
M86-H("@D;RT^8F%C:W1R86-E(&%S("1I=&5M(#T^("1D971A:6PI('L*("`@
M("`@("`@("`@:68@*"1D971A:6Q;)V9U;F-T:6]N)UT@/3T@)W%U97)Y)RD@
M>PH@("`@("`@("`@("`@("`@96-H;R`G455%4EDZ("<@+B`D9&5T86EL6R=A
M<F=S)UU;,%T@+B`B7&XB.PH@("`@("`@("`@("`@("`@96-H;R`B4$%204U%
M5$524SI<;B(["B`@("`@("`@("`@("`@("!P<FEN=%]R*"1D971A:6Q;)V%R
M9W,G75LQ72D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!](&5L<V4@
M>PH@("`@("`@('!R:6YT("1O+3YG971$96)U9TEN9F\H*2`N(")<;B(["B`@
M("!]"B`@("!E>&ET.PI]"@HD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?
M15)23U)?0T%,3$)!0TLL("=P92<I.PH*"B1R97,@/2`D9&)H+3YQ=65R>2@B
M4T5,14-4(&$@1E)/32!P:'!T97-T(BD["FEF("@A1$(Z.FES17)R;W(H)')O
M=W,@/2`D<F5S+3YN=6U2;W=S*"DI*2!["B`@("!P<FEN="`B*'=A;G0@,2D@
M9V]T("1R;W=S(&9R;VT@9FER<W1<;B(["GT@96QS92!["B`@("!P<FEN="`B
M7&XB.PI]"F9O<B`H)&D@/2`P.R`D:2`\(#4[("1I*RLI('L*("`@("1D8F@M
M/G%U97)Y*"))3E-%4E0@24Y43R!P:'!T97-T("AA*2!604Q515,@*"1I*2(I
M.PH@("`@)')E<R`]("1D8F@M/G%U97)Y*")314Q%0U0@82!&4D]-('!H<'1E
M<W0B*3L*("`@(&EF("@A1$(Z.FES17)R;W(H)')O=W,@/2`D<F5S+3YN=6U2
M;W=S*"DI*2!["B`@("`@("`@<')I;G0@)RAW86YT("<@+B`H)&D@*R`R*2`N
M("(I(&=O="`D<F]W<R!F<F]M("1I7&XB.PH@("`@?2!E;'-E('L*("`@("`@
M("!P<FEN="`B7&XB.PH@("`@?0I]"@HD<F5S(#T@)&1B:"T^<75E<GDH)U-%
M3$5#5"!A($923TT@<&AP=&5S="!72$5212!A(#X@/R<L(#`I.PII9B`H(41"
M.CII<T5R<F]R*"1R;W=S(#T@)')E<RT^;G5M4F]W<R@I*2D@>PH@("`@<')I
M;G0@(BAW86YT(#4I(&=O="`D<F]W<R!F<F]M(#X@,"`H<&%S<VEN9R!P87)A
M;7,@=&\@<75E<GDI7&XB.PI](&5L<V4@>PH@("`@<')I;G0@(EQN(CL*?0H*
M)'-T:"`]("1D8F@M/G!R97!A<F4H)U-%3$5#5"!A($923TT@<&AP=&5S="!7
M2$5212!A(#P@/R<I.PHD<F5S(#T@)&1B:"T^97AE8W5T92@D<W1H+"!A<G)A
M>2@T*2D["FEF("@A1$(Z.FES17)R;W(H)')O=W,@/2`D<F5S+3YN=6U2;W=S
M*"DI*2!["B`@("!P<FEN="`B*'=A;G0@-"D@9V]T("1R;W=S(&9R;VT@/"`T
M("AD;VEN9R!P<F5P87)E+V5X96-U=&4I7&XB.PI](&5L<V4@>PH@("`@<')I
M;G0@(EQN(CL*?0H*)&1B:"T^<75E<GDH(D1%3$5412!&4D]-('!H<'1E<W0@
M5TA%4D4@82`\(#0B*3L*)')E<R`]("1D8F@M/G%U97)Y*")314Q%0U0@82!&
M4D]-('!H<'1E<W0B*3L*:68@*"%$0CHZ:7-%<G)O<B@D<F]W<R`]("1R97,M
M/FYU;5)O=W,H*2DI('L*("`@('!R:6YT("(H=V%N="`R*2!G;W0@)')O=W,@
M9G)O;2`U(&%N9"`V(&YO="!D96QE=&5D7&XB.PI](&5L<V4@>PH@("`@<')I
M;G0@(EQN(CL*?0HD<F5S(#T@)&1B:"T^<75E<GDH(E-%3$5#5"!A($923TT@
M<&AP=&5S="!W:&5R92!A(#P@,"(I.PII9B`H(41".CII<T5R<F]R*"1R;W=S
M(#T@)')E<RT^;G5M4F]W<R@I*2D@>PH@("`@<')I;G0@(BAW86YT(#`I(&=O
M="`D<F]W<R!F<F]M(#P@,%QN(CL*?2!E;'-E('L*("`@('!R:6YT(")<;B([
M"GT*"@HD<F5S+3YF<F5E*"D[("`O+R!K965P(&EB87-E(&AA<'!Y"B1D8F@M
M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PID<F]P7W1A
M8FQE*"1D8F@L("=P:'!T97-T)RD["@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M=&5S=',O1$(O=&5S=',O<')E<&5X92YI;F,`````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`Q-#<R-"`Q,#4Q-30S,S<S,B`P,C,T,S$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"B\J*@H@
M*B!497-T<R!T:&4@9')I=F5R<R<@<')E<&%R92!A;F0@97AE8W5T92!M971H
M;V1S"B`J"B`J($5X96-U=&5D(&)Y(&1R:79E<B\P-G!R97!E>&5C+G!H<'0*
M("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H
M92!02%`@;&EC96YS90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@
M;F]T(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@
M87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A
M<V4*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A
M;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R
M>2`@($1A=&%B87-E"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@
M($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER
M:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N
M<V4@,RXP"B`J($!V97)S:6]N("`@("1)9#H@<')E<&5X92YI;F,L=B`Q+C(U
M(#(P,#4O,#(O,38@,3,Z-30Z-3$@9&%N:65L8R!%>'`@)`H@*B!`;&EN:R`@
M("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO"@HD=&UP
M9FEL92`]('1E;7!N86TH(B]T;7`B+"`B<&AP=&UP(BD["G)E9VES=&5R7W-H
M=71D;W=N7V9U;F-T:6]N*")M>5]S:'5T9&]W;B(I.PHD9G`@/2!F;W!E;B@D
M=&UP9FEL92P@(G<B*3L*)&9I;&5D871A(#T@(F]P87%U92!P;&%C96AO;&1E
M<B=S('1E<W0B.PIF=W)I=&4H)&9P+"`D9FEL961A=&$I.PIF8VQO<V4H)&9P
M*3L*"@HO*BH*("H@3&]C86P@97)R;W(@8V%L;&)A8VL@:&%N9&QE<@H@*@H@
M*B!0<FEN=',@;W5T(&%N(&5R<F]R(&UE<W-A9V4@86YD(&MI;&QS('1H92!P
M<F]C97-S+@H@*@H@*B!`<&%R86T@;V)J96-T("`D;R`@4$5!4B!E<G)O<B!O
M8FIE8W0@875T;VUA=&EC86QL>2!P87-S960@=&\@=&AI<R!M971H;V0*("H@
M0')E='5R;B!V;VED"B`J($!S964@4$5!4CHZ<V5T17)R;W)(86YD;&EN9R@I
M"B`J+PIF=6YC=&EO;B!P92@D;RD@>PH@("`@<')I;G0@(EQN(B`N("1O+3YT
M;U-T<FEN9R@I.PH@("`@97AI=#L*?0H*)&1B:"T^<V5T17)R;W)(86YD;&EN
M9RA014%27T524D]27T-!3$Q"04-++"`G<&4G*3L*"@HO+R`Q*2!-=6QT:7!L
M92!P<F5P87)E+V5X96,@24Y315)4('%U97)I97,*96-H;R`B+2TM+2TM+2TM
M+2TM,2TM+2TM+2TM+2TM+5QN(CL*"B1S=&@Q(#T@)&1B:"T^<')E<&%R92@B
M24Y315)4($E.5$\@<&AP=&5S="`H82P@8BD@5D%,5453("@_+"`G82<I(BD[
M"B1S=&@R(#T@)&1B:"T^<')E<&%R92@B24Y315)4($E.5$\@<&AP=&5S="`H
M82QB*2!604Q515,@*"$L/RDB*3L*)'-T:#,@/2`D9&)H+3YP<F5P87)E*"))
M3E-%4E0@24Y43R!P:'!T97-T("AA+&(L8RD@5D%,5453("@_+"$L)BDB*3L*
M)'-T:#0@/2`D9&)H+3YP<F5P87)E*"))3E-%4E0@24Y43R!P:'!T97-T("AA
M+"!B*2!604Q515,@*#<R+"`G9&ER96-T)RDB*3L*<')I;G0@(G-T:#$L<W1H
M,BQS=&@S+'-T:#0@8W)E871E9%QN(CL*<')I;G0@)W-T:#$Z(#\@87,@<&%R
M86TL('!A<W-I;F<@87,@87)R87DN+BX@)SL*:68@*"@D<F5S(#T@)&1B:"T^
M97AE8W5T92@D<W1H,2P@87)R87DH-S(I*2D@/3T]($1"7T]+*2!["B`@("!P
M<FEN="`B<W1H,2!E>&5C=71E9%QN(CL*?2!E;'-E('L*("`@('!R:6YT(")S
M=&@Q(&9A:6QE9%QN(CL*?0H*<')I;G0@)W-T:#(Z("$@86YD(#\@87,@<&%R
M86US+"!P87-S:6YG(&%S(&%R<F%Y+BXN("<["FEF("@H)')E<R`]("1D8F@M
M/F5X96-U=&4H)'-T:#(L(&%R<F%Y*#<R+"`B=&AA="=S(')I9VAT(BDI*2`]
M/3T@1$)?3TLI('L*("`@('!R:6YT(")S=&@R(&5X96-U=&5D7&XB.PI](&5L
M<V4@>PH@("`@<')I;G0@(G-T:#(@9F%I;&5D7&XB.PI]"@IP<FEN="`G<W1H
M,SH@/RP@(2!A;F0@)B!A<R!P87)A;7,L('!A<W-I;F<@87,@87)R87DN+BX@
M)SL*<W=I=&-H("@D9&)H+3YP:'!T>7!E*2!["B`@("!C87-E("=M<W%L)SH*
M("`@("`@("`D<F5S(#T@)&1B:"T^97AE8W5T92@D<W1H,RP@87)R87DH-S(L
M("(G:71<7"=S(&=O;V0G(BP@)'1M<&9I;&4I*3L*("`@("`@("!B<F5A:SL*
M("`@(&1E9F%U;'0Z"B`@("`@("`@)')E<R`]("1D8F@M/F5X96-U=&4H)'-T
M:#,L(&%R<F%Y*#<R+"`B)VET)R=S(&=O;V0G(BP@)'1M<&9I;&4I*3L*?0II
M9B`H)')E<R`]/3T@1$)?3TLI('L*("`@('!R:6YT(")S=&@S(&5X96-U=&5D
M7&XB.PI](&5L<V4@>PH@("`@<')I;G0@(G-T:#,@9F%I;&5D7&XB.PI]"@IP
M<FEN="`G<W1H-#H@;F\@<&%R86US+BXN("<["FEF("@H)')E<R`]("1D8F@M
M/F5X96-U=&4H)'-T:#0I*2`]/3T@1$)?3TLI('L*("`@('!R:6YT(")S=&@T
M(&5X96-U=&5D7&XB.PI](&5L<V4@>PH@("`@<')I;G0@(G-T:#0@9F%I;&5D
M7&XB.PI]"G!R:6YT7W)E<W5L=',H*3L*"@HO+R`R*2!/;F4@<')E<&%R960L
M(&UU;'1I<&QE('1I;64@97AE8W5T960*96-H;R`B7&XM+2TM+2TM+2TM+2TR
M+2TM+2TM+2TM+2TM7&XB.PH*)&1B:"T^<75E<GDH)T1%3$5412!&4D]-('!H
M<'1E<W0G*3L*)'-T:"`]("1D8F@M/G!R97!A<F4H)TE.4T525"!)3E1/('!H
M<'1E<W0@*&$L(&(L(&,L(&0I(%9!3%5%4R`H/RP@/RP@)BP@/RDG*3L*)&1A
M=&$@/2!A<G)A>2@*("`@(#`@/3X@87)R87DH-S(L("=S970Q)RP@)'1M<&9I
M;&4L("<Q,C,T+34V+3<X)RDL"B`@("`Q(#T^(&%R<F%Y*#<R+"`G<V5T,B<L
M("1T;7!F:6QE+"!N=6QL*2P*("`@(#(@/3X@87)R87DH-S(L("=S970S)RP@
M)'1M<&9I;&4L(&YU;&PI"BD["B1R97,@/2`D9&)H+3YE>&5C=71E375L=&EP
M;&4H)'-T:"P@)&1A=&$I.PIP<FEN=%]R97-U;'1S*"D["@H*+R\@,RD@9G)E
M95!R97!A<F5D*"D@=&5S=`IE8VAO(")<;BTM+2TM+2TM+2TM+3,M+2TM+2TM
M+2TM+2U<;B(["@II9B`H)&1B:"T^9G)E95!R97!A<F5D*"1S=&@I*2!["B`@
M("!E8VAO("=44E5%)SL*?2!E;'-E('L*("`@(&5C:&\@)T9!3%-%)SL*?0IE
M8VAO(")<;B(["FEF("@D9&)H+3YF<F5E4')E<&%R960H-C8V*2D@>PH@("`@
M96-H;R`G5%)512<["GT@96QS92!["B`@("!E8VAO("=&04Q312<["GT*96-H
M;R`B7&XB.PH*"B\O(#0I(%-%3$5#5',@=&5S=',*96-H;R`B7&XM+2TM+2TM
M+2TM+2TT+2TM+2TM+2TM+2TM7&XB.PHD<W1H,2`]("1D8F@M/G!R97!A<F4H
M(E-%3$5#5"`J($923TT@<&AP=&5S="!72$5212!A(#T@/R!/4D1%4B!"62!B
M(BD["G!R:6YT7S0H)'-T:#$L(#<R*3L*<')I;G1?-"@D<W1H,2P@-S$I.PHD
M<W1H,B`]("1D8F@M/G!R97!A<F4H(E-%3$5#5"`J($923TT@<&AP=&5S="!7
M2$5212!D(#T@/R!/4D1%4B!"62!B(BD["G!R:6YT7S0H)'-T:#(L("<Q,C,T
M+34V+3<X)RD["B1S=&@S(#T@)&1B:"T^<')E<&%R92@B4T5,14-4("H@1E)/
M32!P:'!T97-T(%=(15)%(&,@/2`F($]21$52($)9(&(B*3L*<')I;G1?-"@D
M<W1H,RP@)'1M<&9I;&4I.PH*"B\O(#4I($%34T]#24%4259%($%24D%9('%U
M97)I97,*96-H;R`B7&XM+2TM+2TM+2TM+2TU+2TM+2TM+2TM+2TM7&XB.PH*
M)'-T:#4@/2`D9&)H+3YP<F5P87)E*"=)3E-%4E0@24Y43R!P:'!T97-T("AA
M+"!B+"!D*2!604Q515,@*#\L(#\L(#\I)RD["B1A<G)A>2`](&%R<F%Y*`H@
M("`@)V9O;R<@/3X@,3$L"B`@("`G8F%R)R`]/B`G=&AR964G+`H@("`@)V)A
M>B<@/3X@;G5L;"P**3L*)')E<R`]("1D8F@M/F5X96-U=&4H)'-T:#4L("1A
M<G)A>2D["G!R:6YT("=I;G-E<G0Z("<@+B`H)')E<R`]/3T@1$)?3TL@/R`G
M;VMA>2<@.B`G97)R;W(G*2`N(")<;B(["@HD<W1H-B`]("1D8F@M/G!R97!A
M<F4H)U-%3$5#5"!A+"!B+"!D($923TT@<&AP=&5S="!72$5212!A(#T@/R<I
M.PHD<F5S(#T@)&1B:"T^97AE8W5T92@D<W1H-BP@87)R87DH,3$I*3L*)')O
M=R`]("1R97,M/F9E=&-H4F]W*$1"7T9%5$-(34]$15]!4U-/0RD["G!R:6YT
M(")A(#T@>R1R;W=;)V$G77TL(&(@/2![)')O=ULG8B==?2P@9"`]("(["FEF
M("@D9&)H+3YP:'!T>7!E(#T]("=M<W%L)RD@>PH@("`@:68@*&%R<F%Y7VME
M>5]E>&ES=',H)V0G+"`D<F]W*2D@>PH@("`@("`@("1T>7!E(#T@9V5T='EP
M92@D<F]W6R=D)UTI.PH@("`@("`@(&EF("@D='EP92`]/2`G3E5,3"<@?'P@
M)')O=ULG9"==(#T]("<G*2!["B`@("`@("`@("`@('!R:6YT(")G;W0@97AP
M96-T960@;W5T8V]M95QN(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D='EP92`](&=E='1Y<&4H)')O=ULG9"==*3L*("`@("`@("`@("`@<')I
M;G0@(E5.+65X<&5C=&5D(&]U=&-O;64Z("1T>7!E7&XB.PH@("`@("`@('T*
M("`@('T@96QS92!["B`@("`@("`@+R\@:'1T<#HO+V)U9W,N<&AP+FYE="\_
M:60],S$Y-C`*("`@("`@("!P<FEN="`B4')I;W(@=&\@4$A0(#0N,RXQ,2!O
M<B`U+C`N-"P@4$A0)W,@;7-Q;"!E>'1E;G-I;VX@<VEL96YT;'DB"B`@("`@
M("`@("`@("`@+B`B(&1R;W!P960@8V]L=6UN<R!W:71H(&YU;&P@=F%L=65S
M+B!9;W4@;F5E9"!T;R!U<&=R861E+EQN(CL*("`@('T*?2!E;'-E('L*("`@
M("1T>7!E(#T@9V5T='EP92@D<F]W6R=D)UTI.PH@("`@:68@*"1T>7!E(#T]
M("=S=')I;F<G*2!["B`@("`@("`@<')I;G0@(F=O="!E>'!E8W1E9"!O=71C
M;VUE7&XB.PH@("`@?2!E;'-E('L*("`@("`@("!P<FEN="`B54XM97AP96-T
M960@;W5T8V]M93H@)'1Y<&5<;B(["B`@("!]"GT*"B\J*@H@*B!!=71O;6%T
M:6-A;&QY(&9R964@=&AE('!R97!A<F5D('-T871E;65N=',@86YD(')E<W5L
M=',@=VAE;B!T:&4@<V-R:7!T"B`J('1E<FUI;F%T97,*("H*("H@0')E='5R
M;B!V;VED"B`J+PIF=6YC=&EO;B!M>5]S:'5T9&]W;B@I('L*("`@(&=L;V)A
M;"`D=&UP9FEL92P@)&1B:"P@)'-T:#$L("1S=&@R+"`D<W1H,RP@)'-T:#0L
M("1S=&@U+"`D<W1H-BP@)')E<SL*"B`@("!S=VET8V@@*"1D8F@M/G!H<'1Y
M<&4I('L*("`@("`@("!C87-E("=I8F%S92<Z"B`@("`@("`@("`@("\J"B`@
M("`@("`@("`@("`J($EN=&5R8F%S92!D;V5S;B=T(&%L;&]W(&1R;W!P:6YG
M('1A8FQE<R!T:&%T(&AA=F4@<F5S=6QT"B`@("`@("`@("`@("`J('-E=',@
M<W1I;&P@;W!E;BX*("`@("`@("`@("`@("HO"B`@("`@("`@("`@("1D8F@M
M/F9R9650<F5P87)E9"@D<W1H,2D["B`@("`@("`@("`@("1D8F@M/F9R9650
M<F5P87)E9"@D<W1H,BD["B`@("`@("`@("`@("1D8F@M/F9R9650<F5P87)E
M9"@D<W1H,RD["B`@("`@("`@("`@("1D8F@M/F9R9650<F5P87)E9"@D<W1H
M-"D["B`@("`@("`@("`@("1D8F@M/F9R9650<F5P87)E9"@D<W1H-2D["B`@
M("`@("`@("`@("1D8F@M/F9R9650<F5P87)E9"@D<W1H-BD["B`@("`@("`@
M("`@("1D8F@M/F9R965297-U;'0H)')E<RT^<F5S=6QT*3L*("`@("`@("`@
M("`@8G)E86L["B`@("!]"@H@("`@)&1B:"T^<V5T17)R;W)(86YD;&EN9RA0
M14%27T524D]27U)%5%523BD["B`@("!D<F]P7W1A8FQE*"1D8F@L("=P:'!T
M97-T)RD["@H@("`@=6YL:6YK*"1T;7!F:6QE*3L*?0H*+RHJ"B`J(%!R:6YT
M(&]U="!T:&4@9&%T82!I;B!T97-T('1A8FQE"B`J"B`J($!R971U<FX@=F]I
M9`H@*B\*9G5N8W1I;VX@<')I;G1?<F5S=6QT<R@I('L*("`@(&=L;V)A;"`D
M9&)H.PH@("`@<')I;G0@(G)E<W5L=',Z7&XB.PH@("`@)')E<R`]("1D8F@M
M/G%U97)Y*")314Q%0U0@*B!&4D]-('!H<'1E<W0@5TA%4D4@82`](#<R($]2
M1$52($)9(&(B*3L*("`@("1I(#T@,#L*("`@('=H:6QE("@D<F]W(#T@)')E
M<RT^9F5T8VA2;W<H1$)?1D540TA-3T1%7T]21$52140I*2!["B`@("`@("`@
M<')I;G0@)WPG("X@:6UP;&]D92@B("T@(BP@)')O=RD@+B`B?%QN(CL*("`@
M("`@("`D:2LK.PH@("`@?0H@("`@:68@*"$D:2D@>PH@("`@("`@('!R:6YT
M(")4:&4@<F5C;W)D<R!W97)E(&YO="!F;W5N9"X@($1I9"!T:&5Y(&=E="!I
M;G-E<G1E9#]<;B(["B`@("!]"GT*"B\J*@H@*B!%>&5C=71E('1H92!P<F5P
M87)E9"!S=&%T96UE;G0@86YD('!R:6YT(&]U="!T:&4@9&%T82!I;B!T:&4@
M<F5S=6QT"B`J"B`J($!P87)A;2!R97-O=7)C92`@("`@)'-T:"`@('1H92!S
M=&%T96UE;G0@:&%N9&QE('1O('!R;V-E<W,*("H@0'!A<F%M('-T<FEN9WQA
M<G)A>2`D8FEN9"`@=&AE(&1A=&$@=&AA="!W:6QL(')E<&QA8V4@=&AE('!L
M86-E:&]L9&5R<PH@*@H@*B!`<F5T=7)N('9O:60*("HO"F9U;F-T:6]N('!R
M:6YT7S0H)'-T:"P@)&)I;F0I('L*("`@(&=L;V)A;"`D9&)H.PH@("`@)')E
M<R`]("1D8F@M/F5X96-U=&4H)'-T:"P@)&)I;F0I.PH@("`@=VAI;&4@*"1R
M;W<@/2`D<F5S+3YF971C:%)O=RA$0E]&151#2$U/1$5?3U)$15)%1"DI('L*
M("`@("`@("!P<FEN="`G?"<@+B!I;7!L;V1E*"(@+2`B+"`D<F]W*2`N(")\
M7&XB.PH@("`@?0H@("`@96-H;R`B?GY<;B(["GT*````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+W)U;BYC=G,`````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$V-3$@,3`U,34T,S,W,S(@,#(R
M-C`R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`",A("]B:6XO<V@*"B,@)$ED.B!R=6XN8W9S+'8@,2XS(#(P,#0O,#(O,C`@
M,3@Z-3<Z-3$@9&%N:65L8R!%>'`@)`H*(R!V=G9V=G9V=G9V=G9V=G9V=G9V
M=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V=@HC(%!%05(@1$(@5$53
M5"!35$%25$52"B,*(R`@(%1O(')U;B!A;&P@=&5S=',Z("`N+W)U;@HC("`@
M5&\@<G5N(&]N92!T97-T.B`@("XO<G5N(#QT97-T(&9I;&4@;F%M93X*(R`@
M($5X86UP;&4Z("`@("`@("`@("`N+W)U;B!D8E]P87)S961S;BYP:'!T"B,*
M(R!"969O<F4@<G5N;FEN9R!T:&4@=&5S=',@>6]U(&UU<W0@861J=7-T('1H
M90HC(&9O;&QO=VEN9R!T:')E92!V87)I86)L97,Z"@HC("`@5&AE(&9U;&P@
M<&%T:"!T;R!Y;W5R(%!(4"!D:7)E8W1O<GDZ"B`@("!$0E]415-47U!(4%]0
M051(/6,Z+W!R;V=R87XQ+W!H<`H*(R`@(%1H92!N86UE(&]F('EO=7(@4$A0
M($-,22!E>&5C=71A8FQE"B,@("`H97AA;7!L97,@<&AP+F5X92P@<&AP+6-L
M:2YE>&4L(&-L:2]P:'`N97AE*3H*("`@($1"7U1%4U1?4$A07T-,23UP:'`N
M97AE"@HC("`@5&AE(&9U;&P@<&%T:"!T;R!T:&4@<')E<V5N="!D:7)E8W1O
M<GD*(R`@("AN;W0@=7-I;F<@)%!71"!D=64@=&\@0WEG=VEN*3H*("`@($1"
M7U1%4U1?1$E2/60Z+W!E87)T97-T+W!E87(O1$(O=&5S=',*"B,@7EY>7EY>
M7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EX*
M"@H*5$535%]02%!?15A%0U5404),13TD1$)?5$535%]02%!?4$%42"\D1$)?
M5$535%]02%!?0TQ)"F5X<&]R="!415-47U!(4%]%6$5#551!0DQ%"@II9B!;
M("0C("UG="`P(%T*=&AE;@H@("`@=&5S=#TD,0IE;'-E"B`@("!T97-T/2HN
M<&AP=`IF:0H*)%1%4U1?4$A07T5814-55$%"3$4@)$1"7U1%4U1?4$A07U!!
M5$@O<G5N+71E<W1S+G!H<"`D1$)?5$535%]$25(O)'MT97-T?0H`````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+W-E<75E;F-E<RYI
M;F,`````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#<U-C$@,3`U,34T,S,W
M,S(@,#(S-S4U`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"@HO*BH*("H@5&5S=',@=&AE(&1R:79E<G,G('-E<75E
M;F-E("AA:V$@875T;U]I;F-R96UE;G0I(&UE=&AO9',*("H*("H@17AE8W5T
M960@8GD@9')I=F5R+S`U<V5Q=65N8V5S+G!H<'0*("H*("H@4$A0('9E<G-I
M;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I
M<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90H@
M*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C
M;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O
M8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*("H@<V5N9"!A(&YO
M=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O
M<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E"B`J
M($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S
M;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U
M(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S
M:6]N("`@("1)9#H@<V5Q=65N8V5S+FEN8RQV(#$N,3$@,C`P-2\P,B\Q."`R
M,CHS.#HT,R!D86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P
M96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B\*"B\J*@H@*B!,;V-A;"!E<G)O
M<B!H86YD;&5R"B`J+PIF=6YC=&EO;B!E<G)O<E]H86YD;&5R*"8D;V)J*2![
M"B`@("!P<FEN="`B<V5Q=65N8V5S+FEN8R!E<G)O<E]H86YD;&5R.EQN("`@
M("(["B`@("!P<FEN="`D;V)J+3YG971$96)U9TEN9F\H*2`N(")<;EQN(CL*
M?0IO8E]I;7!L:6-I=%]F;'5S:"AT<G5E*3L*"B1D<F]P(#T@)&1B:"T^9')O
M<%-E<75E;F-E*"=T97-T)RD["FEF("A$0CHZ:7-%<G)O<B@D9')O<"D@)B8*
M("`@("1D<F]P+3YG971#;V1E*"D@(3T@1$)?15)23U)?3D]354-(5$%"3$4I
M"GL*("`@('!R:6YT(")#;W5L9"!N;W0@9')O<"!S97%U96YC92XN+EQN(CL*
M("`@('!R:6YT("1D<F]P+3YG971$96)U9TEN9F\H*2`N(")<;EQN(CL*("`@
M(&EF("@D9&)H+3YP:'!T>7!E(#T]("=I8F%S92<@)B8*("`@("`@("`D9')O
M<"T^9V5T0V]D92@I(#T]($1"7T524D]27T%#0T534U]624],051)3TXI"B`@
M("!["B`@("`@("`@<')I;G0@(E5S92!T:&ES('%U97)Y('1O('!R;W9I9&4@
M=&AE('!E<FUI<W-I;VYS(&YE961E9#I<;B(["B`@("`@("`@<')I;G0@)R`@
M(&=R86YT(&%L;"!O;B!21$(D1T5.15)!5$]24R!T;R`\55-%4DY!344^)SL*
M("`@('T*("`@(&5X:70["GT*"B\O(#$I('1E<W0@=&AA="!S97%U96YC97,@
M87)E(&YO="!C<F5A=&5D(&EF(")O;F1E;6%N9"(@:7,@9F%L<V4*"B1E(#T@
M)&1B:"T^;F5X=$ED*")T97-T(BP@9F%L<V4I.PII9B`H1$(Z.FES17)R;W(H
M)&4I("8F("1E+3YG971#;V1E*"D@/3T@1$)?15)23U)?3D]354-(5$%"3$4I
M('L*("`@('!R:6YT(")A;B!E<G)O<B!I<R!T:&4@<')O<&5R(')E<W!O;G-E
M(&AE<F5<;B(["GT@96QS92!["B`@("!I9B`H1$(Z.FES17)R;W(H)&4I*2![
M"B`@("`@("`@:68@*"1D8F@M/G!H<'1Y<&4@/3T@)VEB87-E)R`F)B`D92T^
M9V5T0V]D92@I(#T]($1"7T524D]27U-93E1!6"D@>PH@("`@("`@("`@("!P
M<FEN="`B86X@97)R;W(@:7,@=&AE('!R;W!E<B!R97-P;VYS92!H97)E7&XB
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@('!R:6YT(")T97-T(#$I
M('=E(&5X<&5C=&5D('1O(&=E="!B86-K("=$0B!%<G)O<CH@;F\@<W5C:"!T
M86)L92<N7&XB.PH@("`@("`@("`@("!P<FEN="`B2&5R92!I<R!T:&4@97)R
M;W(@=V4@9V]T.EQN(CL*("`@("`@("`@("`@<')I;G0@)T-O9&4Z("<@+B`D
M92T^9V5T0V]D92@I("X@(EQN(CL*("`@("`@("`@("`@<')I;G0@)TUE<W-A
M9V4Z("<@+B`D92T^9V5T365S<V%G92@I("X@(EQN(CL*("`@("`@("`@("`@
M<')I;G0@)T1E8G5G.B`G("X@)&4M/F=E=$1E8G5G26YF;R@I("X@(EQN7&XB
M.PH@("`@("`@('T*("`@('T@96QS92!["B`@("`@("`@<')I;G0@(G1E<W0@
M,2D@=V4@97AP96-T960@=&\@9V5T(&)A8VL@)T1"($5R<F]R.B!N;R!S=6-H
M('1A8FQE)RY<;B(["B`@("`@("`@<')I;G0@(D)U="!A;B!E<G)O<B!W87-N
M)W0@9V5N97)A=&5D7&Y<;B(["B`@("!]"GT*"B\O(#(I('1E<W0@=&AA="!T
M:&4@<V5Q=65N8V4@:7,@;F]T(&-R96%T960@8G5T('1H92!E<G)O<B!I<PHO
M+R!H86YD;&5D(&)Y('1H92!C;&%S<R!E<G)O<B!H86YD;&5R"B1D8F@M/G-E
M=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]04DE.5"P*("`@("`@("`@("`@
M("`@("`@("`@("`B86X@97)R;W(@8V]U9VAT(&)Y('1H92!E<G)O<B!H86YD
M;&5R(&ES(&=O;V1<;B(I.PHD92`]("1D8F@M/FYE>'1)9"@B=&5S="(L(&9A
M;'-E*3L*:68@*"%$0CHZ:7-%<G)O<B@D92DI('L*("`@('!R:6YT(")T97-T
M(#(I(&9A:6QE9"%<;B(["GT*)&1B:"T^7V1E9F%U;'1?97)R;W)?;6]D92`]
M(&YU;&P["@HO+R`S*2!T97-T('1H870@<V5Q=65N8V5S(&%R92!C<F5A=&5D
M(&EF(")O;F1E;6%N9"(@:7,@=')U92P@86YD('1H870*+R\@='=O('-U8V-E
M<W-I=F4@;F5X=$ED<R!R971U<FX@861J86-E;G0@=F%L=65S"B1A(#T@)&1B
M:"T^;F5X=$ED*")T97-T(BD["B1B(#T@)&1B:"T^;F5X=$ED*")T97-T(BD[
M"FEF("A$0CHZ:7-%<G)O<B@D82DI('L*("`@('!R:6YT("=A.B`G("X@)&$M
M/F=E=$1E8G5G26YF;R@I("X@(EQN7&XB.PI](&5L<V4@>PH@("`@<')I;G0@
M(F$])&%<;B(["GT*:68@*$1".CII<T5R<F]R*"1B*2D@>PH@("`@<')I;G0@
M)V(Z("<@+B`D8BT^9V5T1&5B=6=);F9O*"D@+B`B7&Y<;B(["GT@96QS92![
M"B`@("!P<FEN="`B8CTD8EQN(CL*?0II9B`H(41".CII<T5R<F]R*"1A*2`F
M)B`A1$(Z.FES17)R;W(H)&(I*2!["B`@("!P<FEN="`G8BUA/2<@+B`H)&(M
M)&$I("X@(EQN(CL*?0H*+R\@-"D@=&5S="!T:&%T('1H92!U<V5R+7-P96-I
M9FEE9"!E<G)O<B!H86YD;&5R(&ES(')E86QL>2!D:7-A8FQE9`HO+R!D=7)I
M;F<@;F5X=$ED+"!W:71H('!E<BUO8FIE8W0@:&%N9&QE<B!A<R!W96QL(&%S
M(&=L;V)A;"!H86YD;&5R"B1D8F@M/F1R;W!397%U96YC92@B=&5S="(I.PH*
M)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27T-!3$Q"04-++"`G
M97)R;W)?:&%N9&QE<B<I.PHD8R`]("1D8F@M/FYE>'1)9"@B=&5S="(I.PII
M9B`H(41".CII<T5R<F]R*"1C*2D@>PH@("`@<')I;G0@(F,])&-<;B(["GT*
M)&1B:"T^9')O<%-E<75E;F-E*")T97-T(BD["B1D8F@M/E]D969A=6QT7V5R
M<F]R7VUO9&4@/2!N=6QL.PHD9"`]("1D8F@M/FYE>'1)9"@B=&5S="(I.PII
M9B`H(41".CII<T5R<F]R*"1D*2D@>PH@("`@<')I;G0@(F0])&1<;B(["GT*
M"B\O(#4I('1E<W0@=&AA="!T:&4@<V5Q=65N8V4@:7,@:&%N9&QE9"!R:6=H
M="!W:&5N('1H92!T86)L92!I<R!E;7!T>0H*+R\@0F%C:V5N9"!W:71H(')E
M86P@<V5Q=65N8V5S(&UA>2!D;VXG="!L:6ME('1H870*4$5!4CHZ<'5S:$5R
M<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PHD9&)H+3YQ=65R>2@G
M1$5,151%($923TT@=&5S=%]S97$G*3L*4$5!4CHZ<&]P17)R;W)(86YD;&EN
M9R@I.PHD92`]("1D8F@M/FYE>'1)1"@G=&5S="<I.PII9B`H1$(Z.FES17)R
M;W(H)&0I*2!["B`@("!P<FEN="`G93H@)R`N("1D+3YG971$96)U9TEN9F\H
M*2`N(")<;EQN(CL*?2!E;'-E('L*("`@('!R:6YT(")E/21D7&XB.PI]"@HO
M+R!F:6YA;"!C;&5A;BUU<`HD9&)H+3YD<F]P4V5Q=65N8V4H(G1E<W0B*3L*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1"
M+W1E<W1S+W-I;7!L97%U97)Y+FEN8P``````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#,V,C4@,3`U,34T,S,W,S(@,#(T,S,V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@HO*BH*("H@5&5S=',@
M=&AE(&1R:79E<G,G('-I;7!L95%U97)Y*"D@;65T:&]D"B`J"B`J($5X96-U
M=&5D(&)Y(&1R:79E<B\P,W-I;7!L97%U97)Y+G!H<'0*("H*("H@4$A0('9E
M<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL
M92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS
M90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E
M+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@
M82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T
M;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*("H@<V5N9"!A
M(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A
M(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E
M"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV
M:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR
M,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V
M97)S:6]N("`@("1)9#H@<VEM<&QE<75E<GDN:6YC+'8@,2XX(#(P,#4O,#(O
M,#,@,#4Z-#DZ-#0@9&%N:65L8R!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P
M.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO"@HO*BH*("H@3&]C86P@
M97)R;W(@8V%L;&)A8VL@:&%N9&QE<@H@*@H@*B!$<F]P<R!T:&4@<&AP=&5S
M="!T86)L92P@<')I;G1S(&]U="!A;B!E<G)O<B!M97-S86=E(&%N9"!K:6QL
M<R!T:&4*("H@<')O8V5S<RX*("H*("H@0'!A<F%M(&]B:F5C="`@)&\@(%!%
M05(@97)R;W(@;V)J96-T(&%U=&]M871I8V%L;'D@<&%S<V5D('1O('1H:7,@
M;65T:&]D"B`J($!R971U<FX@=F]I9`H@*B!`<V5E(%!%05(Z.G-E=$5R<F]R
M2&%N9&QI;F<H*0H@*B\*9G5N8W1I;VX@<&4H)&\I('L*("`@(&=L;V)A;"`D
M9&)H.PH*("`@("1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]2
M15154DXI.PH@("`@9')O<%]T86)L92@D9&)H+"`G<&AP=&5S="<I.PH*("`@
M(&1I92@D;RT^=&]3=')I;F<H*2D["GT*"B1D8F@M/G-E=$5R<F]R2&%N9&QI
M;F<H4$5!4E]%4E)/4E]#04Q,0D%#2RP@)W!E)RD["@H*)'-T:"`]("1D8F@M
M/G-I;7!L95%U97)Y*")314Q%0U0@*B!&4D]-('!H<'1E<W0B*3L*"G-W:71C
M:"`H)&1B:"T^<&AP='EP92D@>PH@("`@8V%S92`G;7ES<6QI)SH*("`@("`@
M("!I9B`H:7-?82@D<W1H+"`G;7ES<6QI7W)E<W5L="<I*2!["B`@("`@("`@
M("`@('!R:6YT(")P87-S961<;B(["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@<')I;G0@(E!23T),14U<;B(["B`@("`@("`@?0H@("`@("`@(&)R
M96%K.PH@("`@9&5F875L=#H*("`@("`@("!I9B`H9V5T='EP92@D<W1H*2`]
M/2`G<F5S;W5R8V4G*2!["B`@("`@("`@("`@('!R:6YT(")P87-S961<;B([
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<')I;G0@(E!23T),14U<
M;B(["B`@("`@("`@?0I]"@H*<W=I=&-H("@D9&)H+3YP:'!T>7!E*2!["B`@
M("!C87-E("=I8F%S92<Z"B`@("`@("`@+RH*("`@("`@("`@*B!);G1E<F)A
M<V4@9&]E<VXG="!A;&QO=R!D<F]P<&EN9R!T86)L97,@=&AA="!H879E(')E
M<W5L=`H@("`@("`@("`J('-E=',@<W1I;&P@;W!E;BX*("`@("`@("`@*B\*
M("`@("`@("`D9&)H+3YF<F5E4F5S=6QT*"1S=&@I.PH@("`@("`@(&)R96%K
M.PI]"B1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI
M.PID<F]P7W1A8FQE*"1D8F@L("=P:'!T97-T)RD["@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T
M<R]T<F%N<V%C=&EO;G,N:6YC````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`U
M-C0T(#$P-3$U-#,S-S,R(#`R-#0W,@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`H*+RHJ"B`J(%1E<W1S('1H92!D
M<FEV97)S)R!T<F%N<V%C=&EO;B!H86YD;&EN9R!M971H;V1S"B`J"B`J($5X
M96-U=&5D(&)Y(&1R:79E<B\Q,71R86YS86-T:6]N<RYP:'!T"B`J"B`J(%!(
M4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E
M(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI
M8V5N<V4*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E
M:79E(&$@8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B
M;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E
M;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y
M;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!$871A
M8F%S90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!$86YI96P@
M0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y
M.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@
M*B!`=F5R<VEO;B`@("`D260Z('1R86YS86-T:6]N<RYI;F,L=B`Q+CD@,C`P
M-2\P,B\P,R`P-3HT.3HT-"!D86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B\*"B\O(%1E<W1I
M;F<@:&5R92!D=64@=&\@<VMI<"!N;W0@=V]R:VEN9R!C=7)R96YT;'D@:6X@
M:&5A9`II9B`H(21D8F@M/F9E871U<F5S6R=T<F%N<V%C=&EO;G,G72D@>PH@
M("`@9&EE*"=T:&ES(&1R:79E<B!D;V5S(&YO="!S=7!P;W)T('1R86YS86-T
M:6]N<R<I.PI]"@HO+R!6:65W('1H92!T86)L92!F<F]M(&$@<V5P87)A=&4@
M8V]N;F5C=&EO;B!S;R!W92!D;VXG="!D:7-T=7)B"B\O('1H92!T<F%N<V%C
M=&EO;BX*)&1B:#(@/2!$0CHZ8V]N;F5C="@D9&)H+3YD<VXI.PH*9G5N8W1I
M;VX@97)R;W)?:&%N9&QE<B@F)&]B:BD@>PH@("`@<')I;G0@(EQN(B`N("1O
M8FHM/F=E=$1E8G5G26YF;R@I("X@(EQN(CL*?0H*9G5N8W1I;VX@9'5M<'1A
M8FQE*"1E>'!E8W1E9"D@>PH@("`@9VQO8F%L("1D8F@L("1D8F@R.PH@("`@
M<')I;G0@:6UP;&]D92@G("<L("1D8F@M/F=E=$-O;"@G4T5,14-4(&(@1E)/
M32!P:'!T97-T)RDI.PH*("`@(&EF("AI<W-E="@D9&)H+3YT<F%N<V%C=&EO
M;E]O<&-O=6YT*2D@>PH@("`@("`@(&EF("@D97AP96-T960@/3T@)&1B:"T^
M=')A;G-A8W1I;VY?;W!C;W5N="D@>PH@("`@("`@("`@("!P<FEN="`B+B`@
M;W!S/6]K7&XB.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@('!R:6YT
M("(N("!O<',])&1B:"T^=')A;G-A8W1I;VY?;W!C;W5N=%QN(CL*("`@("`@
M("!]"B`@("!](&5L<V4@>PH@("`@("`@('!R:6YT("(N("!O<',];VM<;B([
M"B`@("!]"GT*"B1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]#
M04Q,0D%#2RP@)V5R<F]R7VAA;F1L97(G*3L*"@HD9&)H+3YA=71O0V]M;6ET
M*'1R=64I.PHD9&)H+3YQ=65R>2@B24Y315)4($E.5$\@<&AP=&5S="!604Q5
M15,H,2P@)V]N92<L("=/;F4G+"`G,C`P,2TP,BTQ.2<I(BD["@IP<FEN="`G
M,2D@869T97(@875T;V-O;6UI=#H@)SL*9'5M<'1A8FQE*#`I.PH*)&1B:"T^
M875T;T-O;6UI="AF86QS92D["B1D8F@M/G%U97)Y*"))3E-%4E0@24Y43R!P
M:'!T97-T(%9!3%5%4R@R+"`G='=O)RP@)U1W;R<L("<R,#`Q+3`R+3(P)RDB
M*3L*)&1B:"T^<75E<GDH(DE.4T525"!)3E1/('!H<'1E<W0@5D%,5453*#,L
M("=T:')E92<L("=4:')E92<L("<R,#`Q+3`R+3(Q)RDB*3L*<')I;G0@)S(I
M(&)E9F]R92!C;VUM:70Z("<["F1U;7!T86)L92@R*3L*"B1D8F@M/F-O;6UI
M="@I.PIP<FEN="`G,RD@869T97(@8V]M;6ET.B`G.PID=6UP=&%B;&4H,"D[
M"@HD9&)H+3YQ=65R>2@B24Y315)4($E.5$\@<&AP=&5S="!604Q515,H-"P@
M)V9O=7(G+"`G1F]U<B<L("<R,#`Q+3`R+3(R)RDB*3L*)&1B:"T^<75E<GDH
M(DE.4T525"!)3E1/('!H<'1E<W0@5D%,5453*#4L("=F:79E)RP@)T9I=F4G
M+"`G,C`P,2TP,BTR,R<I(BD["G!R:6YT("<T*2!B969O<F4@<F]L;&)A8VLZ
M("<["F1U;7!T86)L92@R*3L*"B1D8F@M/G)O;&QB86-K*"D["G!R:6YT("<U
M*2!A9G1E<B!R;VQL8F%C:SH@)SL*9'5M<'1A8FQE*#`I.PHD9&)H+3YR;VQL
M8F%C:R@I.PH*)&1B:"T^875T;T-O;6UI="AT<G5E*3L*)&1B:"T^<75E<GDH
M(DE.4T525"!)3E1/('!H<'1E<W0@5D%,5453*#8L("=S:7@G+"`G4VEX)RP@
M)S(P,#$M,#(M,C0G*2(I.PHD9&)H+3YQ=65R>2@B24Y315)4($E.5$\@<&AP
M=&5S="!604Q515,H-RP@)W-E=F5N)RP@)U-E=F5N)RP@)S(P,#$M,#(M,C4G
M*2(I.PIP<FEN="`G-BD@8F5F;W)E(&%U=&]C;VUM:70K<F]L;&)A8VLZ("<[
M"F1U;7!T86)L92@P*3L*"B1D8F@M/G)O;&QB86-K*"D["G!R:6YT("<W*2!A
M9G1E<B!A=71O8V]M;6ET*W)O;&QB86-K.B`G.PID=6UP=&%B;&4H,"D["@IP
M<FEN="`G."D@=&5S=&EN9R!T:&%T('-E;&5C="!D;V5S;EPG="!D:7-T=7)B
M92!O<&-O=6YT.B`G.PHD9&)H+3YA=71O0V]M;6ET*&9A;'-E*3L*)&1B:"T^
M<VEM<&QE475E<GDH(E-%3$5#5"`J($923TT@<&AP=&5S="(I.PHD9&)H+3YS
M:6UP;&51=65R>2@B4T5,14-4(&$L8R!&4D]-('!H<'1E<W0B*3L*)&1B:"T^
M<VEM<&QE475E<GDH(E-%3$5#5"!B+&0@1E)/32!P:'!T97-T(BD["FEF("AE
M;7!T>2@D9&)H+3YT<F%N<V%C=&EO;E]O<&-O=6YT*2D@>PH@("`@<')I;G0@
M(F]K7&XB.PI](&5L<V4@>PH@("`@<')I;G0@(F9A:6QE9"`H8V]U;G0])&1B
M:"T^=')A;G-A8W1I;VY?;W!C;W5N="E<;B(["GT*````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+W-K:7!I9BYI;F,`````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$V-3<@,3`U,34T,S,W,S,@
M,#(S,C4P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"@HO*BH*("H@02!T97-T('1O(&UA:V4@<W5R92!014%2($1"
M(&-A;B!B92!F;W5N9`H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@
M*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R
M<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA
M8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I
M;F<@55)).@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT
M+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(
M4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H
M('1H92!W96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H
M<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*
M("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*
M("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N
M;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@
M*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N
M='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@)$ED.B!S:VEP
M:68N:6YC+'8@,2XR(#(P,#4O,#(O,#,@,#4Z-#DZ-#0@9&%N:65L8R!%>'`@
M)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O
M1$(*("HO"@HO*BH*("H@4V5T('5P('1H92!I;F-L=61E7W!A=&@L(&5R<F]R
M7W)E<&]R=&EN9R!A;F0@4$%42%]315!!4D%43U(*("HO"G)E<75I<F5?;VYC
M92`G+B]I;F-L=61E+FEN8R<["@II9B`H(6EN8VQU9&5?;VYC92`G1$(N<&AP
M)RD@>PH@("`@<')I;G0@)W-K:7`@8V]U;&0@;F]T(&9I;F0@1$(N<&AP)SL*
M?0H`````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1B7V5R<F]R
M+G!H<'0`````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#8Q-#<@,3`U,34T
M,S,W,S,@,#(S-S8R`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"TM5$535"TM"D1".CI$0E]%<G)O<@HM+5-+25!)1BTM"CP_
M<&AP(&-H9&ER*&1I<FYA;64H7U]&24Q%7U\I*3L@<F5Q=6ER95]O;F-E("<N
M+W-K:7!I9BYI;F,G.R`_/@HM+49)3$4M+0H\/W!H<"`O+R`M*BT@0RLK("TJ
M+0IR97%U:7)E7V]N8V4@)RXO:6YC;'5D92YI;F,G.PIR97%U:7)E7V]N8V4@
M)T1"+G!H<"<["@IF=6YC=&EO;B!T97-T7V5R<F]R7VAA;F1L97(H)&5R<FYO
M+"`D97)R;7-G+"`D9FEL92P@)&QI;F4L("1V87)S*2!["B`@("!I9B`H9&5F
M:6YE9"@G15]35%))0U0G*2D@>PH@("`@("`@(&EF("@D97)R;F\@)B!%7U-4
M4DE#5`H@("`@("`@("`@("`F)B`H97)R;W)?<F5P;W)T:6YG*"D@)B!%7U-4
M4DE#5"D@(3T@15]35%))0U0I('L*("`@("`@("`@("`@+R\@26=N;W)E($5?
M4U1224-4(&YO=&EC97,@=6YL97-S('1H97D@:&%V92!B965N('1U<FYE9"!O
M;@H@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@("`@?2!E;'-E('L*
M("`@("`@("!D969I;F4H)T5?4U1224-4)RP@,C`T."D["B`@("!]"B`@("`D
M97)R;W)T>7!E(#T@87)R87D@*`H@("`@("`@($5?15)23U(@/3X@)T5R<F]R
M)RP*("`@("`@("!%7U=!4DY)3D<@/3X@)U=A<FYI;F<G+`H@("`@("`@($5?
M4$%24T4@/3X@)U!A<G-I;F<@17)R;W(G+`H@("`@("`@($5?3D]424-%(#T^
M("=.;W1I8V4G+`H@("`@("`@($5?0T]215]%4E)/4B`]/B`G0V]R92!%<G)O
M<B<L"B`@("`@("`@15]#3U)%7U=!4DY)3D<@/3X@)T-O<F4@5V%R;FEN9R<L
M"B`@("`@("`@15]#3TU024Q%7T524D]2(#T^("=#;VUP:6QE($5R<F]R)RP*
M("`@("`@("!%7T-/35!)3$5?5T%23DE.1R`]/B`G0V]M<&EL92!787)N:6YG
M)RP*("`@("`@("!%7U5315)?15)23U(@/3X@)U5S97(@17)R;W(G+`H@("`@
M("`@($5?55-%4E]705).24Y'(#T^("=5<V5R(%=A<FYI;F<G+`H@("`@("`@
M($5?55-%4E].3U1)0T4@/3X@)U5S97(@3F]T:6-E)RP*("`@("`@("!%7U-4
M4DE#5"`]/B`G4W1R:6-T($YO=&EC92<L"B`@("`I.PH@("`@)'!R969I>"`]
M("1E<G)O<G1Y<&5;)&5R<FYO73L*("`@('!R:6YT(")<;B1P<F5F:7@Z("1E
M<G)M<V<@:6X@(B`N(&)A<V5N86UE*"1F:6QE*2`N("(@;VX@;&EN92!86%A<
M;B(["GT*"F5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["G-E=%]E<G)O<E]H86YD
M;&5R*"=T97-T7V5R<F]R7VAA;F1L97(G*3L*"G!R:6YT(")T97-T:6YG(&1I
M9F9E<F5N="!E<G)O<B!C;V1E<RXN+EQN(CL*)&4@/2!N97<@1$)?17)R;W(H
M*3L@<')I;G0@<W1R=&]L;W=E<B@D92T^=&]3=')I;F<H*2DN(EQN(CL*)&4@
M/2!N97<@1$)?17)R;W(H(G1E<W0@97)R;W(B*3L@<')I;G0@<W1R=&]L;W=E
M<B@D92T^=&]3=')I;F<H*2DN(EQN(CL*)&4@/2!N97<@1$)?17)R;W(H1$)?
M3TLI.R!P<FEN="!S=')T;VQO=V5R*"1E+3YT;U-T<FEN9R@I*2XB7&XB.PHD
M92`](&YE=R!$0E]%<G)O<BA$0E]%4E)/4BD[('!R:6YT('-T<G1O;&]W97(H
M)&4M/G1O4W1R:6YG*"DI+B)<;B(["B1E(#T@;F5W($1"7T5R<F]R*$1"7T52
M4D]27U-93E1!6"D[('!R:6YT('-T<G1O;&]W97(H)&4M/G1O4W1R:6YG*"DI
M+B)<;B(["B1E(#T@;F5W($1"7T5R<F]R*$1"7T524D]27T1)5EI%4D\I.R!P
M<FEN="!S=')T;VQO=V5R*"1E+3YT;U-T<FEN9R@I*2XB7&XB.PH*<')I;G0@
M(G1E<W1I;F<@9&EF9F5R96YT(&5R<F]R(&UO9&5S+BXN7&XB.PHD92`](&YE
M=R!$0E]%<G)O<BA$0E]%4E)/4BP@4$5!4E]%4E)/4E]04DE.5"D[('!R:6YT
M('-T<G1O;&]W97(H)&4M/G1O4W1R:6YG*"DI+B)<;B(["B1E(#T@;F5W($1"
M7T5R<F]R*$1"7T524D]27U-93E1!6"P@4$5!4E]%4E)/4E]44DE'1T52*3L*
M"G!R:6YT(")T97-T:6YG(&1I9F9E<F5N="!E<G)O<B!S97)V97)I=&EE<RXN
M+EQN(CL*)&4@/2!N97<@1$)?17)R;W(H1$)?15)23U)?4UE.5$%8+"!014%2
M7T524D]27U1224='15(L($5?55-%4E].3U1)0T4I.PHD92`](&YE=R!$0E]%
M<G)O<BA$0E]%4E)/4E]364Y405@L(%!%05)?15)23U)?5%))1T=%4BP@15]5
M4T527U=!4DY)3D<I.PHD92`](&YE=R!$0E]%<G)O<BA$0E]%4E)/4E]364Y4
M05@L(%!%05)?15)23U)?5%))1T=%4BP@15]54T527T524D]2*3L*"C\^"BTM
M1T54+2T*+2U03U-4+2T*+2U%6%!%0U0M+0IT97-T:6YG(&1I9F9E<F5N="!E
M<G)O<B!C;V1E<RXN+@I;9&)?97)R;W(Z(&UE<W-A9V4](F1B(&5R<F]R.B!U
M;FMN;W=N(&5R<F]R(B!C;V1E/2TQ(&UO9&4]<F5T=7)N(&QE=F5L/6YO=&EC
M92!P<F5F:7@](B(@:6YF;STB(ET*6V1B7V5R<F]R.B!M97-S86=E/2)D8B!E
M<G)O<CH@=&5S="!E<G)O<B(@8V]D93TM,2!M;V1E/7)E='5R;B!L979E;#UN
M;W1I8V4@<')E9FEX/2(B(&EN9F\](B)="EMD8E]E<G)O<CH@;65S<V%G93TB
M9&(@97)R;W(Z(&YO(&5R<F]R(B!C;V1E/3$@;6]D93UR971U<FX@;&5V96P]
M;F]T:6-E('!R969I>#TB(B!I;F9O/2(B70I;9&)?97)R;W(Z(&UE<W-A9V4]
M(F1B(&5R<F]R.B!U;FMN;W=N(&5R<F]R(B!C;V1E/2TQ(&UO9&4]<F5T=7)N
M(&QE=F5L/6YO=&EC92!P<F5F:7@](B(@:6YF;STB(ET*6V1B7V5R<F]R.B!M
M97-S86=E/2)D8B!E<G)O<CH@<WEN=&%X(&5R<F]R(B!C;V1E/2TR(&UO9&4]
M<F5T=7)N(&QE=F5L/6YO=&EC92!P<F5F:7@](B(@:6YF;STB(ET*6V1B7V5R
M<F]R.B!M97-S86=E/2)D8B!E<G)O<CH@9&EV:7-I;VX@8GD@>F5R;R(@8V]D
M93TM,3,@;6]D93UR971U<FX@;&5V96P];F]T:6-E('!R969I>#TB(B!I;F9O
M/2(B70IT97-T:6YG(&1I9F9E<F5N="!E<G)O<B!M;V1E<RXN+@I$0B!%<G)O
M<CH@=6YK;F]W;B!E<G)O<EMD8E]E<G)O<CH@;65S<V%G93TB9&(@97)R;W(Z
M('5N:VYO=VX@97)R;W(B(&-O9&4]+3$@;6]D93UP<FEN="!L979E;#UN;W1I
M8V4@<')E9FEX/2(B(&EN9F\](B)="@I5<V5R($YO=&EC93H@1$(@17)R;W(Z
M('-Y;G1A>"!E<G)O<B!I;B!014%2+G!H<"!O;B!L:6YE(%A86`IT97-T:6YG
M(&1I9F9E<F5N="!E<G)O<B!S97)V97)I=&EE<RXN+@H*57-E<B!.;W1I8V4Z
M($1"($5R<F]R.B!S>6YT87@@97)R;W(@:6X@4$5!4BYP:'`@;VX@;&EN92!8
M6%@*"E5S97(@5V%R;FEN9SH@1$(@17)R;W(Z('-Y;G1A>"!E<G)O<B!I;B!0
M14%2+G!H<"!O;B!L:6YE(%A86`H*57-E<B!%<G)O<CH@1$(@17)R;W(Z('-Y
M;G1A>"!E<G)O<B!I;B!014%2+G!H<"!O;B!L:6YE(%A86`H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D8E]P87)S
M961S;BYP:'!T````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#(S,38U(#$P-3$U
M-#,S-S,S(#`R-#0T-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````M+51%4U0M+0I$0CHZ<&%R<V5$4TX*+2U32TE0248M+0H\
M/W!H<"!C:&1I<BAD:7)N86UE*%]?1DE,15]?*2D[(')E<75I<F5?;VYC92`G
M+B]S:VEP:68N:6YC)SL@/SX*+2U&24Q%+2T*/#]P:'`@+R\@+2HM($,K*R`M
M*BT*<F5Q=6ER95]O;F-E("<N+VEN8VQU9&4N:6YC)SL*<F5Q=6ER95]O;F-E
M("=$0BYP:'`G.PH*9G5N8W1I;VX@=&5S="@D9'-N*2!["B`@("!E8VAO(")$
M4TXZ("1D<VY<;B(["B`@("!P<FEN=%]R*$1".CIP87)S94133B@D9'-N*2D[
M"GT*"F9U;F-T:6]N('1E<W1!<G)A>2@D9'-N*2!["B`@("!E8VAO(")$4TXZ
M(&%R<F%Y7&XB.PH@("`@<')I;G1?<BA$0CHZ<&%R<V5$4TXH)&1S;BDI.PI]
M"@IP<FEN="`B=&5S=&EN9R!$0CHZ<&%R<V5$4TXN+BY<;EQN(CL*"G1E<W0H
M(FUY<W%L(BD["G1E<W0H(F]D8F,H;7-S<6PI(BD["G1E<W0H)V]D8F,H9&(R
M*3HO+W5S97(Z<&%S<W=O<F1`+V1A=&%B87-E)RD["G1E<W0H)V]D8F,H86-C
M97-S*3HO+R]D871A8F%S92<I.PIT97-T*"=O9&)C.B\O861M:6Y`+V1A=&%S
M;W5R8V5.86UE)RD["G1E<W0H(FUY<W%L.B\O;&]C86QH;W-T(BD["G1E<W0H
M(FUY<W%L.B\O<F5M;W1E+FAO<W0N8V]M+V1B(BD["G1E<W0H(F]C:3@Z+R]S
M>7-T96TZ;6%N86=E<D`B*3L*=&5S="@B;V-I.#HO+W5S97(Z<&%S<T!T;G,M
M;F%M92(I.PIT97-T*")O9&)C*'-O;&ED*3HO+V9O;SIB87)`=&-P*VQO8V%L
M:&]S="LQ,S$S(BD[("`O+R!D97!R96-A=&5D"G1E<W0H(G!G<W%L.B\O=7-E
M<D!U;FEX*VQO8V%L:&]S="]P96%R(BD[("`@("`@("`@("\O(&1E<')E8V%T
M960*=&5S="@B:6)A<V4Z+R]U<V5R)30P9&]M86EN.G!A<W-W;W)D0&AO<W0B
M*3L*=&5S="@B:6)A<V4Z+R]U<V5R0&1O;6%I;CIP87-S0'=O<F1`+V1A=&%B
M87-E(BD[("`@+R\@86QS;R!S=7!P;W)T960*=&5S="@B:69X.B\O=7-E<D!D
M;VUA:6XZ<&%S<T!W;W)D0&AO<W0N8V]M+R]U<W(O9&(O9V5N97)A;"YD8B(I
M.PIT97-T*"=I9G@Z+R]R96UO=&4N:&]S="YC;VTO8SI<=VEN9&]W<UQM>2YD
M8B<I.PIT97-T*"=O8VDX.B\O4TA/3U1/550Z*BHJ*BHJ0"A$15-#4DE05$E/
M3CTH041$4D534U],25-4/2A!1$1215-3/2A04D]43T-/3#U40U`I*$A/4U0]
M,3DR+C$V."XQ,#$N,38Q*2A03U)4/3$U,C$I*2DH0T].3D5#5%]$051!/2A3
M15)624-%7TY!344]5$E3*2DI)RD["@HO+R!N97<@9F]R;6%T<PIT97-T*")O
M9&)C*'-O;&ED*3HO+V9O;SIB87)`;&]C86QH;W-T.C$S,3,B*3L*=&5S="@B
M<&=S<6PZ+R]U<V5R0'5N:7@H*2]P96%R(BD["G1E<W0H(FUY<W%L.B\O=7-E
M<D!U;FEX*"]P871H+W1O+W-O8VME="DO<&5A<B(I.PIT97-T*")P9W-Q;#HO
M+W5S97)`=&-P*"DO<&5A<B(I.PIT97-T*")P9W-Q;#HO+W5S97)`=&-P*'-O
M;65H;W-T*2]P96%R(BD["G1E<W0H(G!G<W%L.B\O=7-E<CIP87-S0'=O<F1`
M=&-P*'-O;65H;W-T.C<W-S<I+W!E87(B*3L*"B\O('-P96-I86P@8F%C:V5N
M9"!O<'1I;VYS"G1E<W0H)VEB87-E.B\O=7-E<CIP87-S0&QO8V%L:&]S="\O
M=F%R+VQI8B]D8F%S92YD8F8_<F]L93UF;V\G*3L*=&5S="@G9&)A<V4Z+R]`
M+S]R;VQE/69O;R9D:6%L96-T/6)A<B<I.PIT97-T*"=S<6QI=&4Z+R\O+W5N
M:7@O<&%T:"]T;R]D871A8F%S93]O<'1I;VX]=F%L=64F86YO=&AE<F]P=&EO
M;CUA;F]T:&5R=F%L=64G*3L*=&5S="@G<W%L:71E.B\O+V,Z+W=I;B]P871H
M+W1O+V1A=&%B87-E/V]P=&EO;CUV86QU92<I.PH*+R\@<V]M92!E>&%M<&QE
M<R!F<F]M(&UA;G5A;`IT97-T*"=M>7-Q;#HO+W5S97)N86UE0&AO<W1S<&5C
M)RD["G1E<W0H)VUY<W%L.B\O:&]S='-P96,O9&%T86)A<V4G*3L*=&5S="@G
M;7ES<6PZ+R]H;W-T<W!E8R<I.PIT97-T*"=M>7-Q;#HO+R]D871A8F%S92<I
M.PH*+R\@87)R87D@=&5S=',*)&%R<F%Y(#T@87)R87DH"B`@("`G<&AP='EP
M92<@(#T^("=M>7-Q;"<L"B`@("`G:&]S='-P96,G(#T^("=F;V]B87(G+`HI
M.PIT97-T07)R87DH)&%R<F%Y*3L*"C\^"BTM1T54+2T*+2U03U-4+2T*+2U%
M6%!%0U0M+0IT97-T:6YG($1".CIP87)S94133BXN+@H*1%-..B!M>7-Q;`I!
M<G)A>0HH"B`@("!;<&AP='EP95T@/3X@;7ES<6P*("`@(%MD8G-Y;G1A>%T@
M/3X@;7ES<6P*("`@(%MU<V5R;F%M95T@/3X@"B`@("!;<&%S<W=O<F1=(#T^
M(`H@("`@6W!R;W1O8V]L72`]/B`*("`@(%MH;W-T<W!E8UT@/3X@"B`@("!;
M<&]R=%T@/3X@"B`@("!;<V]C:V5T72`]/B`*("`@(%MD871A8F%S95T@/3X@
M"BD*1%-..B!O9&)C*&US<W%L*0I!<G)A>0HH"B`@("!;<&AP='EP95T@/3X@
M;V1B8PH@("`@6V1B<WEN=&%X72`]/B!M<W-Q;`H@("`@6W5S97)N86UE72`]
M/B`*("`@(%MP87-S=V]R9%T@/3X@"B`@("!;<')O=&]C;VQ=(#T^(`H@("`@
M6VAO<W1S<&5C72`]/B`*("`@(%MP;W)T72`]/B`*("`@(%MS;V-K971=(#T^
M(`H@("`@6V1A=&%B87-E72`]/B`**0I$4TXZ(&]D8F,H9&(R*3HO+W5S97(Z
M<&%S<W=O<F1`+V1A=&%B87-E"D%R<F%Y"B@*("`@(%MP:'!T>7!E72`]/B!O
M9&)C"B`@("!;9&)S>6YT87A=(#T^(&1B,@H@("`@6W5S97)N86UE72`]/B!U
M<V5R"B`@("!;<&%S<W=O<F1=(#T^('!A<W-W;W)D"B`@("!;<')O=&]C;VQ=
M(#T^('1C<`H@("`@6VAO<W1S<&5C72`]/B`*("`@(%MP;W)T72`]/B`*("`@
M(%MS;V-K971=(#T^(`H@("`@6V1A=&%B87-E72`]/B!D871A8F%S90HI"D13
M3CH@;V1B8RAA8V-E<W,I.B\O+V1A=&%B87-E"D%R<F%Y"B@*("`@(%MP:'!T
M>7!E72`]/B!O9&)C"B`@("!;9&)S>6YT87A=(#T^(&%C8V5S<PH@("`@6W5S
M97)N86UE72`]/B`*("`@(%MP87-S=V]R9%T@/3X@"B`@("!;<')O=&]C;VQ=
M(#T^('1C<`H@("`@6VAO<W1S<&5C72`]/B`*("`@(%MP;W)T72`]/B`*("`@
M(%MS;V-K971=(#T^(`H@("`@6V1A=&%B87-E72`]/B!D871A8F%S90HI"D13
M3CH@;V1B8SHO+V%D;6EN0"]D871A<V]U<F-E3F%M90I!<G)A>0HH"B`@("!;
M<&AP='EP95T@/3X@;V1B8PH@("`@6V1B<WEN=&%X72`]/B!O9&)C"B`@("!;
M=7-E<FYA;65=(#T^(&%D;6EN"B`@("!;<&%S<W=O<F1=(#T^(`H@("`@6W!R
M;W1O8V]L72`]/B!T8W`*("`@(%MH;W-T<W!E8UT@/3X@"B`@("!;<&]R=%T@
M/3X@"B`@("!;<V]C:V5T72`]/B`*("`@(%MD871A8F%S95T@/3X@9&%T87-O
M=7)C94YA;64**0I$4TXZ(&UY<W%L.B\O;&]C86QH;W-T"D%R<F%Y"B@*("`@
M(%MP:'!T>7!E72`]/B!M>7-Q;`H@("`@6V1B<WEN=&%X72`]/B!M>7-Q;`H@
M("`@6W5S97)N86UE72`]/B`*("`@(%MP87-S=V]R9%T@/3X@"B`@("!;<')O
M=&]C;VQ=(#T^('1C<`H@("`@6VAO<W1S<&5C72`]/B!L;V-A;&AO<W0*("`@
M(%MP;W)T72`]/B`*("`@(%MS;V-K971=(#T^(`H@("`@6V1A=&%B87-E72`]
M/B`**0I$4TXZ(&UY<W%L.B\O<F5M;W1E+FAO<W0N8V]M+V1B"D%R<F%Y"B@*
M("`@(%MP:'!T>7!E72`]/B!M>7-Q;`H@("`@6V1B<WEN=&%X72`]/B!M>7-Q
M;`H@("`@6W5S97)N86UE72`]/B`*("`@(%MP87-S=V]R9%T@/3X@"B`@("!;
M<')O=&]C;VQ=(#T^('1C<`H@("`@6VAO<W1S<&5C72`]/B!R96UO=&4N:&]S
M="YC;VT*("`@(%MP;W)T72`]/B`*("`@(%MS;V-K971=(#T^(`H@("`@6V1A
M=&%B87-E72`]/B!D8@HI"D133CH@;V-I.#HO+W-Y<W1E;3IM86YA9V5R0`I!
M<G)A>0HH"B`@("!;<&AP='EP95T@/3X@;V-I.`H@("`@6V1B<WEN=&%X72`]
M/B!O8VDX"B`@("!;=7-E<FYA;65=(#T^('-Y<W1E;0H@("`@6W!A<W-W;W)D
M72`]/B!M86YA9V5R"B`@("!;<')O=&]C;VQ=(#T^('1C<`H@("`@6VAO<W1S
M<&5C72`]/B`*("`@(%MP;W)T72`]/B`*("`@(%MS;V-K971=(#T^(`H@("`@
M6V1A=&%B87-E72`]/B`**0I$4TXZ(&]C:3@Z+R]U<V5R.G!A<W-`=&YS+6YA
M;64*07)R87D**`H@("`@6W!H<'1Y<&5=(#T^(&]C:3@*("`@(%MD8G-Y;G1A
M>%T@/3X@;V-I.`H@("`@6W5S97)N86UE72`]/B!U<V5R"B`@("!;<&%S<W=O
M<F1=(#T^('!A<W,*("`@(%MP<F]T;V-O;%T@/3X@=&-P"B`@("!;:&]S='-P
M96-=(#T^('1N<RUN86UE"B`@("!;<&]R=%T@/3X@"B`@("!;<V]C:V5T72`]
M/B`*("`@(%MD871A8F%S95T@/3X@"BD*1%-..B!O9&)C*'-O;&ED*3HO+V9O
M;SIB87)`=&-P*VQO8V%L:&]S="LQ,S$S"D%R<F%Y"B@*("`@(%MP:'!T>7!E
M72`]/B!O9&)C"B`@("!;9&)S>6YT87A=(#T^('-O;&ED"B`@("!;=7-E<FYA
M;65=(#T^(&9O;PH@("`@6W!A<W-W;W)D72`]/B!B87(*("`@(%MP<F]T;V-O
M;%T@/3X@=&-P"B`@("!;:&]S='-P96-=(#T^(&QO8V%L:&]S="LQ,S$S"B`@
M("!;<&]R=%T@/3X@"B`@("!;<V]C:V5T72`]/B`*("`@(%MD871A8F%S95T@
M/3X@"BD*1%-..B!P9W-Q;#HO+W5S97)`=6YI>"ML;V-A;&AO<W0O<&5A<@I!
M<G)A>0HH"B`@("!;<&AP='EP95T@/3X@<&=S<6P*("`@(%MD8G-Y;G1A>%T@
M/3X@<&=S<6P*("`@(%MU<V5R;F%M95T@/3X@=7-E<@H@("`@6W!A<W-W;W)D
M72`]/B`*("`@(%MP<F]T;V-O;%T@/3X@=6YI>`H@("`@6VAO<W1S<&5C72`]
M/B`*("`@(%MP;W)T72`]/B`*("`@(%MS;V-K971=(#T^(&QO8V%L:&]S=`H@
M("`@6V1A=&%B87-E72`]/B!P96%R"BD*1%-..B!I8F%S93HO+W5S97(E-#!D
M;VUA:6XZ<&%S<W=O<F1`:&]S=`I!<G)A>0HH"B`@("!;<&AP='EP95T@/3X@
M:6)A<V4*("`@(%MD8G-Y;G1A>%T@/3X@:6)A<V4*("`@(%MU<V5R;F%M95T@
M/3X@=7-E<D!D;VUA:6X*("`@(%MP87-S=V]R9%T@/3X@<&%S<W=O<F0*("`@
M(%MP<F]T;V-O;%T@/3X@=&-P"B`@("!;:&]S='-P96-=(#T^(&AO<W0*("`@
M(%MP;W)T72`]/B`*("`@(%MS;V-K971=(#T^(`H@("`@6V1A=&%B87-E72`]
M/B`**0I$4TXZ(&EB87-E.B\O=7-E<D!D;VUA:6XZ<&%S<T!W;W)D0"]D871A
M8F%S90I!<G)A>0HH"B`@("!;<&AP='EP95T@/3X@:6)A<V4*("`@(%MD8G-Y
M;G1A>%T@/3X@:6)A<V4*("`@(%MU<V5R;F%M95T@/3X@=7-E<D!D;VUA:6X*
M("`@(%MP87-S=V]R9%T@/3X@<&%S<T!W;W)D"B`@("!;<')O=&]C;VQ=(#T^
M('1C<`H@("`@6VAO<W1S<&5C72`]/B`*("`@(%MP;W)T72`]/B`*("`@(%MS
M;V-K971=(#T^(`H@("`@6V1A=&%B87-E72`]/B!D871A8F%S90HI"D133CH@
M:69X.B\O=7-E<D!D;VUA:6XZ<&%S<T!W;W)D0&AO<W0N8V]M+R]U<W(O9&(O
M9V5N97)A;"YD8@I!<G)A>0HH"B`@("!;<&AP='EP95T@/3X@:69X"B`@("!;
M9&)S>6YT87A=(#T^(&EF>`H@("`@6W5S97)N86UE72`]/B!U<V5R0&1O;6%I
M;@H@("`@6W!A<W-W;W)D72`]/B!P87-S0'=O<F0*("`@(%MP<F]T;V-O;%T@
M/3X@=&-P"B`@("!;:&]S='-P96-=(#T^(&AO<W0N8V]M"B`@("!;<&]R=%T@
M/3X@"B`@("!;<V]C:V5T72`]/B`*("`@(%MD871A8F%S95T@/3X@+W5S<B]D
M8B]G96YE<F%L+F1B"BD*1%-..B!I9G@Z+R]R96UO=&4N:&]S="YC;VTO8SI<
M=VEN9&]W<UQM>2YD8@I!<G)A>0HH"B`@("!;<&AP='EP95T@/3X@:69X"B`@
M("!;9&)S>6YT87A=(#T^(&EF>`H@("`@6W5S97)N86UE72`]/B`*("`@(%MP
M87-S=V]R9%T@/3X@"B`@("!;<')O=&]C;VQ=(#T^('1C<`H@("`@6VAO<W1S
M<&5C72`]/B!R96UO=&4N:&]S="YC;VT*("`@(%MP;W)T72`]/B`*("`@(%MS
M;V-K971=(#T^(`H@("`@6V1A=&%B87-E72`]/B!C.EQW:6YD;W=S7&UY+F1B
M"BD*1%-..B!O8VDX.B\O4TA/3U1/550Z*BHJ*BHJ0"A$15-#4DE05$E/3CTH
M041$4D534U],25-4/2A!1$1215-3/2A04D]43T-/3#U40U`I*$A/4U0],3DR
M+C$V."XQ,#$N,38Q*2A03U)4/3$U,C$I*2DH0T].3D5#5%]$051!/2A315)6
M24-%7TY!344]5$E3*2DI"D%R<F%Y"B@*("`@(%MP:'!T>7!E72`]/B!O8VDX
M"B`@("!;9&)S>6YT87A=(#T^(&]C:3@*("`@(%MU<V5R;F%M95T@/3X@4TA/
M3U1/550*("`@(%MP87-S=V]R9%T@/3X@*BHJ*BHJ"B`@("!;<')O=&]C;VQ=
M(#T^('1C<`H@("`@6VAO<W1S<&5C72`]/B`H1$530U))4%1)3TX]*$%$1%)%
M4U-?3$E35#TH041$4D534STH4%)/5$]#3TP]5$-0*2A(3U-4/3$Y,BXQ-C@N
M,3`Q+C$V,2DH4$]25#TQ-3(Q*2DI*$-/3DY%0U1?1$%403TH4T525DE#15].
M04U%/51)4RDI*0H@("`@6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@
M("!;9&%T86)A<V5=(#T^(`HI"D133CH@;V1B8RAS;VQI9"DZ+R]F;V\Z8F%R
M0&QO8V%L:&]S=#HQ,S$S"D%R<F%Y"B@*("`@(%MP:'!T>7!E72`]/B!O9&)C
M"B`@("!;9&)S>6YT87A=(#T^('-O;&ED"B`@("!;=7-E<FYA;65=(#T^(&9O
M;PH@("`@6W!A<W-W;W)D72`]/B!B87(*("`@(%MP<F]T;V-O;%T@/3X@=&-P
M"B`@("!;:&]S='-P96-=(#T^(&QO8V%L:&]S=`H@("`@6W!O<G1=(#T^(#$S
M,3,*("`@(%MS;V-K971=(#T^(`H@("`@6V1A=&%B87-E72`]/B`**0I$4TXZ
M('!G<W%L.B\O=7-E<D!U;FEX*"DO<&5A<@I!<G)A>0HH"B`@("!;<&AP='EP
M95T@/3X@<&=S<6P*("`@(%MD8G-Y;G1A>%T@/3X@<&=S<6P*("`@(%MU<V5R
M;F%M95T@/3X@=7-E<@H@("`@6W!A<W-W;W)D72`]/B`*("`@(%MP<F]T;V-O
M;%T@/3X@=6YI>`H@("`@6VAO<W1S<&5C72`]/B`*("`@(%MP;W)T72`]/B`*
M("`@(%MS;V-K971=(#T^(`H@("`@6V1A=&%B87-E72`]/B!P96%R"BD*1%-.
M.B!M>7-Q;#HO+W5S97)`=6YI>"@O<&%T:"]T;R]S;V-K970I+W!E87(*07)R
M87D**`H@("`@6W!H<'1Y<&5=(#T^(&UY<W%L"B`@("!;9&)S>6YT87A=(#T^
M(&UY<W%L"B`@("!;=7-E<FYA;65=(#T^('5S97(*("`@(%MP87-S=V]R9%T@
M/3X@"B`@("!;<')O=&]C;VQ=(#T^('5N:7@*("`@(%MH;W-T<W!E8UT@/3X@
M"B`@("!;<&]R=%T@/3X@"B`@("!;<V]C:V5T72`]/B`O<&%T:"]T;R]S;V-K
M970*("`@(%MD871A8F%S95T@/3X@<&5A<@HI"D133CH@<&=S<6PZ+R]U<V5R
M0'1C<"@I+W!E87(*07)R87D**`H@("`@6W!H<'1Y<&5=(#T^('!G<W%L"B`@
M("!;9&)S>6YT87A=(#T^('!G<W%L"B`@("!;=7-E<FYA;65=(#T^('5S97(*
M("`@(%MP87-S=V]R9%T@/3X@"B`@("!;<')O=&]C;VQ=(#T^('1C<`H@("`@
M6VAO<W1S<&5C72`]/B`*("`@(%MP;W)T72`]/B`*("`@(%MS;V-K971=(#T^
M(`H@("`@6V1A=&%B87-E72`]/B!P96%R"BD*1%-..B!P9W-Q;#HO+W5S97)`
M=&-P*'-O;65H;W-T*2]P96%R"D%R<F%Y"B@*("`@(%MP:'!T>7!E72`]/B!P
M9W-Q;`H@("`@6V1B<WEN=&%X72`]/B!P9W-Q;`H@("`@6W5S97)N86UE72`]
M/B!U<V5R"B`@("!;<&%S<W=O<F1=(#T^(`H@("`@6W!R;W1O8V]L72`]/B!T
M8W`*("`@(%MH;W-T<W!E8UT@/3X@<V]M96AO<W0*("`@(%MP;W)T72`]/B`*
M("`@(%MS;V-K971=(#T^(`H@("`@6V1A=&%B87-E72`]/B!P96%R"BD*1%-.
M.B!P9W-Q;#HO+W5S97(Z<&%S<T!W;W)D0'1C<"AS;VUE:&]S=#HW-S<W*2]P
M96%R"D%R<F%Y"B@*("`@(%MP:'!T>7!E72`]/B!P9W-Q;`H@("`@6V1B<WEN
M=&%X72`]/B!P9W-Q;`H@("`@6W5S97)N86UE72`]/B!U<V5R"B`@("!;<&%S
M<W=O<F1=(#T^('!A<W-`=V]R9`H@("`@6W!R;W1O8V]L72`]/B!T8W`*("`@
M(%MH;W-T<W!E8UT@/3X@<V]M96AO<W0*("`@(%MP;W)T72`]/B`W-S<W"B`@
M("!;<V]C:V5T72`]/B`*("`@(%MD871A8F%S95T@/3X@<&5A<@HI"D133CH@
M:6)A<V4Z+R]U<V5R.G!A<W-`;&]C86QH;W-T+R]V87(O;&EB+V1B87-E+F1B
M9C]R;VQE/69O;PI!<G)A>0HH"B`@("!;<&AP='EP95T@/3X@:6)A<V4*("`@
M(%MD8G-Y;G1A>%T@/3X@:6)A<V4*("`@(%MU<V5R;F%M95T@/3X@=7-E<@H@
M("`@6W!A<W-W;W)D72`]/B!P87-S"B`@("!;<')O=&]C;VQ=(#T^('1C<`H@
M("`@6VAO<W1S<&5C72`]/B!L;V-A;&AO<W0*("`@(%MP;W)T72`]/B`*("`@
M(%MS;V-K971=(#T^(`H@("`@6V1A=&%B87-E72`]/B`O=F%R+VQI8B]D8F%S
M92YD8F8*("`@(%MR;VQE72`]/B!F;V\**0I$4TXZ(&1B87-E.B\O0"\_<F]L
M93UF;V\F9&EA;&5C=#UB87(*07)R87D**`H@("`@6W!H<'1Y<&5=(#T^(&1B
M87-E"B`@("!;9&)S>6YT87A=(#T^(&1B87-E"B`@("!;=7-E<FYA;65=(#T^
M(`H@("`@6W!A<W-W;W)D72`]/B`*("`@(%MP<F]T;V-O;%T@/3X@=&-P"B`@
M("!;:&]S='-P96-=(#T^(`H@("`@6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@
M/3X@"B`@("!;9&%T86)A<V5=(#T^(`H@("`@6W)O;&5=(#T^(&9O;PH@("`@
M6V1I86QE8W1=(#T^(&)A<@HI"D133CH@<W%L:71E.B\O+R]U;FEX+W!A=&@O
M=&\O9&%T86)A<V4_;W!T:6]N/79A;'5E)F%N;W1H97)O<'1I;VX]86YO=&AE
M<G9A;'5E"D%R<F%Y"B@*("`@(%MP:'!T>7!E72`]/B!S<6QI=&4*("`@(%MD
M8G-Y;G1A>%T@/3X@<W%L:71E"B`@("!;=7-E<FYA;65=(#T^(`H@("`@6W!A
M<W-W;W)D72`]/B`*("`@(%MP<F]T;V-O;%T@/3X@=&-P"B`@("!;:&]S='-P
M96-=(#T^(`H@("`@6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@("!;
M9&%T86)A<V5=(#T^("]U;FEX+W!A=&@O=&\O9&%T86)A<V4*("`@(%MO<'1I
M;VY=(#T^('9A;'5E"B`@("!;86YO=&AE<F]P=&EO;ET@/3X@86YO=&AE<G9A
M;'5E"BD*1%-..B!S<6QI=&4Z+R\O8SHO=VEN+W!A=&@O=&\O9&%T86)A<V4_
M;W!T:6]N/79A;'5E"D%R<F%Y"B@*("`@(%MP:'!T>7!E72`]/B!S<6QI=&4*
M("`@(%MD8G-Y;G1A>%T@/3X@<W%L:71E"B`@("!;=7-E<FYA;65=(#T^(`H@
M("`@6W!A<W-W;W)D72`]/B`*("`@(%MP<F]T;V-O;%T@/3X@=&-P"B`@("!;
M:&]S='-P96-=(#T^(`H@("`@6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@
M"B`@("!;9&%T86)A<V5=(#T^(&,Z+W=I;B]P871H+W1O+V1A=&%B87-E"B`@
M("!;;W!T:6]N72`]/B!V86QU90HI"D133CH@;7ES<6PZ+R]U<V5R;F%M94!H
M;W-T<W!E8PI!<G)A>0HH"B`@("!;<&AP='EP95T@/3X@;7ES<6P*("`@(%MD
M8G-Y;G1A>%T@/3X@;7ES<6P*("`@(%MU<V5R;F%M95T@/3X@=7-E<FYA;64*
M("`@(%MP87-S=V]R9%T@/3X@"B`@("!;<')O=&]C;VQ=(#T^('1C<`H@("`@
M6VAO<W1S<&5C72`]/B!H;W-T<W!E8PH@("`@6W!O<G1=(#T^(`H@("`@6W-O
M8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^(`HI"D133CH@;7ES<6PZ+R]H
M;W-T<W!E8R]D871A8F%S90I!<G)A>0HH"B`@("!;<&AP='EP95T@/3X@;7ES
M<6P*("`@(%MD8G-Y;G1A>%T@/3X@;7ES<6P*("`@(%MU<V5R;F%M95T@/3X@
M"B`@("!;<&%S<W=O<F1=(#T^(`H@("`@6W!R;W1O8V]L72`]/B!T8W`*("`@
M(%MH;W-T<W!E8UT@/3X@:&]S='-P96,*("`@(%MP;W)T72`]/B`*("`@(%MS
M;V-K971=(#T^(`H@("`@6V1A=&%B87-E72`]/B!D871A8F%S90HI"D133CH@
M;7ES<6PZ+R]H;W-T<W!E8PI!<G)A>0HH"B`@("!;<&AP='EP95T@/3X@;7ES
M<6P*("`@(%MD8G-Y;G1A>%T@/3X@;7ES<6P*("`@(%MU<V5R;F%M95T@/3X@
M"B`@("!;<&%S<W=O<F1=(#T^(`H@("`@6W!R;W1O8V]L72`]/B!T8W`*("`@
M(%MH;W-T<W!E8UT@/3X@:&]S='-P96,*("`@(%MP;W)T72`]/B`*("`@(%MS
M;V-K971=(#T^(`H@("`@6V1A=&%B87-E72`]/B`**0I$4TXZ(&UY<W%L.B\O
M+V1A=&%B87-E"D%R<F%Y"B@*("`@(%MP:'!T>7!E72`]/B!M>7-Q;`H@("`@
M6V1B<WEN=&%X72`]/B!M>7-Q;`H@("`@6W5S97)N86UE72`]/B`*("`@(%MP
M87-S=V]R9%T@/3X@"B`@("!;<')O=&]C;VQ=(#T^('1C<`H@("`@6VAO<W1S
M<&5C72`]/B`*("`@(%MP;W)T72`]/B`*("`@(%MS;V-K971=(#T^(`H@("`@
M6V1A=&%B87-E72`]/B!D871A8F%S90HI"D133CH@87)R87D*07)R87D**`H@
M("`@6W!H<'1Y<&5=(#T^(&UY<W%L"B`@("!;9&)S>6YT87A=(#T^(&UY<W%L
M"B`@("!;=7-E<FYA;65=(#T^(`H@("`@6W!A<W-W;W)D72`]/B`*("`@(%MP
M<F]T;V-O;%T@/3X@"B`@("!;:&]S='-P96-=(#T^(&9O;V)A<@H@("`@6W!O
M<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^(`HI
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]I;F-L=61E+FEN
M8RYO<FEG````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`T,#4T(#$P-3$U-#,S
M-S,S(#`R-#,S-P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`H*+RHJ"B`J(%-E=',@=&AE(&EN8VQU9&5?<&%T:"P@
M97)R;W)?<F5P;W)T:6YG(&%N9"!0051(7U-%4$%2051/4B!F;W(@=&5S=',*
M("H@:6X@=&AE($1"+W1E<W1S(&1I<F5C=&]R>0H@*@H@*B!02%`@=F5R<VEO
M;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES
M('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J
M('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B
M(&%T('1H92!F;VQL;W=I;F<@55)).@H@*B!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O
M<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B
M=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90H@*B!S96YD(&$@;F]T
M92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P
M>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@
M0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O
M<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@
M5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I
M;VX@("`@)$ED.B!I;F-L=61E+FEN8RQV(#$N-2`R,#`U+S`R+S`S(#`U.C0Y
M.C0T(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N
M<&AP+FYE="]P86-K86=E+T1""B`J+PH*97)R;W)?<F5P;W)T:6YG*$5?04Q,
M*3L*"FEF("@A9&5F:6YE9"@G4$%42%]315!!4D%43U(G*2D@>PH@("`@:68@
M*'-T<FES='(H4$A07T]3+"`G5TE.)RDI('L*("`@("`@("`O*BH*("`@("`@
M("`@*B!$969I;F4@=&AE('!A=&@@<V5P87)A=&]R(&9O<B!W:6YD;W=S"B`@
M("`@("`@("HO"B`@("`@("`@9&5F:6YE*"=0051(7U-%4$%2051/4B<L("<[
M)RD["B`@("!](&5L<V4@>PH@("`@("`@("\J*@H@("`@("`@("`J($1E9FEN
M92!T:&4@<&%T:"!S97!A<F%T;W(@9F]R(&]T:&5R('-Y<W1E;7,*("`@("`@
M("`@*B\*("`@("`@("!D969I;F4H)U!!5$A?4T5005)!5$]2)RP@)SHG*3L*
M("`@('T*?0H*+RH*("H@268@=&AE('!A=&@@=&\@>6]U<B!014%2(&EN<W1A
M;&QA=&EO;B!I<R!F;W5N9"!I;B!T:&4@;&5F="!H86YD"B`J('!O<G1I;VX@
M;V8@=&AE(&EF*"D@97AP<F5S<VEO;B!B96QO=RP@=&AA="!M96%N<R!T:&ES
M(&9I;&4@:&%S"B`J(&-O;64@9G)O;2!T:&4@4$5!4B!I;G-T86QL97(N("!4
M:&5R969O<F4L(&QE="=S('5S92!T:&4*("H@:6YS=&%L;&5D('9E<G-I;VX@
M;V8@1$(L('=H:6-H('-H;W5L9"!B92!F;W5N9"!V:6$@=&AE"B`J(&-O;7!U
M=&5R)W,@9&5F875L="!I;F-L=61E7W!A=&@N("!!9&0@)RXG('1O('1H92!I
M;F-L=61E7W!A=&@*("H@=&\@96YS=7)E("<N)R!I<R!I;B!T:&5R92X*("H@
M"B`J($EF('1H92!P871H(&AA<R!N;W0@8F5E;B!S=6)S=&ET=71E9"!I;B!T
M:&4@:68H*2!E>'!R97-S:6]N+`H@*B!T:&ES(&9I;&4@:&%S(&QI:V5L>2!C
M;VUE(&9R;VT@82!#5E,@8VAE8VMO=70@;W(@82`N=&%R(&9I;&4N"B`J(%1H
M97)E9F]R92P@=V4G;&P@87-S=6UE('1H92!T97-T<R!S:&]U;&0@=7-E('1H
M92!V97)S:6]N(&]F"B`J($1"('1H870@:&%S(&-O;64@9G)O;2!T:&5R92!A
M<R!W96QL+@H@*B\*:68@*"<O:&]M92]L=6-E<B]W;W)K+W!E87(O<VAA<F4O
M<&AP)R`A/2`G0"<N)VEN8VQU9&5?<&%T:"<N)T`G*2!["B`@("!I;FE?<V5T
M*"=I;F-L=61E7W!A=&@G+"!I;FE?9V5T*"=I;F-L=61E7W!A=&@G*0H@("`@
M("`@("`@("`N(%!!5$A?4T5005)!5$]2("X@)RXG"B`@("`I.PI](&5L<V4@
M>PH@("`@:6YI7W-E="@G:6YC;'5D95]P871H)RP@<F5A;'!A=&@H9&ER;F%M
M92A?7T9)3$5?7RD@+B`G+RXN)RD*("`@("`@("`@("`@+B!0051(7U-%4$%2
M051/4B`N("<N)R`N(%!!5$A?4T5005)!5$]2"B`@("`@("`@("`@("X@:6YI
M7V=E="@G:6YC;'5D95]P871H)RD*("`@("D["GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R].971?4TU4
M4```````````````````````````````````````````````````````````
M`````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M,#`P(#$P-3$U-#,S-S,S(#`R,3$T,@`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+W1E<W1S+TYE=%]33510+W1E<W1S````````````````````````````
M````````````````````````````````````````,#`P-S4U(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S,@,#(R,S`T`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O3F5T7U--5%`O=&5S=',O8F%S
M:6,N<&AP=```````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3,R-"`Q,#4Q-30S
M,S<S,R`P,C0S-#$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+2U415-4+2T*3F5T7U--5%`Z($)A<VEC($9U;F-T:6]N86QI
M='D*+2U&24Q%+2T*/#]P:'`*"G)E<75I<F5?;VYC92`G3F5T+U--5%`N<&AP
M)SL*<F5Q=6ER95]O;F-E("=C;VYF:6<N<&AP)SL*"FEF("@A("@D<VUT<"`]
M(&YE=R!.971?4TU44"A415-47TA/4U1.04U%+"!415-47U!/4E0L(%1%4U1?
M3$]#04Q(3U-4*2DI('L*"61I92@B56YA8FQE('1O(&EN<W1A;G1I871E($YE
M=%]33510(&]B:F5C=%QN(BD["GT*"FEF("A014%2.CII<T5R<F]R*"1E(#T@
M)'-M='`M/F-O;FYE8W0H*2DI('L*"61I92@D92T^9V5T365S<V%G92@I("X@
M(EQN(BD["GT*"FEF("A014%2.CII<T5R<F]R*"1S;71P+3YM86EL1G)O;2A4
M15-47T923TTI*2D@>PH)9&EE*"=5;F%B;&4@=&\@<V5T('-E;F1E<B!T;R`\
M)R`N(%1%4U1?1E)/32`N("(^7&XB*3L*?0H*:68@*%!%05(Z.FES17)R;W(H
M)')E<R`]("1S;71P+3YR8W!T5&\H5$535%]43RDI*2!["@ED:64H)U5N86)L
M92!T;R!A9&0@<F5C:7!I96YT(#PG("X@5$535%]43R`N("<^.B`G("X*"0DD
M<F5S+3YG971-97-S86=E*"D@+B`B7&XB*3L*?0H*:68@*%!%05(Z.FES17)R
M;W(H)'-M='`M/F1A=&$H5$535%]354)*14-4("X@(EQR7&XB("X@5$535%]"
M3T19*2DI('L*"61I92@B56YA8FQE('1O('-E;F0@9&%T85QN(BD["GT*"B1S
M;71P+3YD:7-C;VYN96-T*"D["@IE8VAO("=3=6-C97-S(2<["@HM+4584$5#
M5"TM"E-U8V-E<W,A"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O3F5T7U--5%`O=&5S
M=',O8V]N9FEG+G!H<"YD:7-T````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#<U,"`Q
M,#4Q-30S,S<S,R`P,C4S,#4`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J($-O<'D@=&AI<R!F:6QE('1O
M(&-O;F9I9RYP:'`@86YD(&-U<W1O;6EZ92!T:&4@9F]L;&]W:6YG('9A;'5E
M<R!T;PH@*B!S=6ET('EO=7(@8V]N9FEG=7)A=&EO;BX*("HO"@ID969I;F4H
M)U1%4U1?2$]35$Y!344G+"`@("`@)VQO8V%L:&]S="<I.PID969I;F4H)U1%
M4U1?4$]25"<L("`@("`@("`@,C4I.PID969I;F4H)U1%4U1?3$]#04Q(3U-4
M)RP@("`@)VQO8V%L:&]S="<I.PID969I;F4H)U1%4U1?05542%]54T52)RP@
M("`@)VIO;B<I.PID969I;F4H)U1%4U1?05542%]005-3)RP@("`@)W-E8W)E
M="<I.PID969I;F4H)U1%4U1?1E)/32<L("`@("`@("`@)V9R;VU`97AA;7!L
M92YC;VTG*3L*9&5F:6YE*"=415-47U1/)RP@("`@("`@("`@("=T;T!E>&%M
M<&QE+F-O;2<I.PID969I;F4H)U1%4U1?4U5"2D5#5"<L("`@("`@)U1E<W0@
M4W5B:F5C="<I.PID969I;F4H)U1%4U1?0D]$62<L("`@("`@("`@)U1E<W0@
M0F]D>2<I.PH```````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+W1E<W1S+TYE=%]33510+W1E<W1S+W%U;W1E9&%T
M82YP:'!T````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,T,#,@,3`U,34T,S,W,S,@
M,#(U,C0W`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"TM5$535"TM"DYE=%]33510.B!Q=6]T961A=&$H*2!<;B!\(%QR("`]
M/B!<<EQN(')E<&QA8V5M96YT"BTM1DE,12TM"CP_<&AP"@IE<G)O<E]R97!O
M<G1I;F<H15]!3$PI.PIR97%U:7)E7V]N8V4@)TYE="]33510+G!H<"<["@HD
M=&5S=',@/2!A<G)A>2@*("`@(")<;B(@("`@("`@("`@("`@("`]/B`B7')<
M;B(L"B`@("`B7')<;B(@("`@("`@("`@("`@/3X@(EQR7&XB+`H@("`@(EQN
M>'@B("`@("`@("`@("`@(#T^(")<<EQN>'@B+`H@("`@(GAX7&XB("`@("`@
M("`@("`@(#T^(")X>%QR7&XB+`H@("`@(GAX7&YX>"(@("`@("`@("`@(#T^
M(")X>%QR7&YX>"(L"B`@("`B7&Y<;GAX(B`@("`@("`@("`@/3X@(EQR7&Y<
M<EQN>'@B+`H@("`@(GAX7&Y<;GAX(B`@("`@("`@(#T^(")X>%QR7&Y<<EQN
M>'@B+`H@("`@(GAX7&Y<;B(@("`@("`@("`@(#T^(")X>%QR7&Y<<EQN(BP*
M("`@(")<<EQN>'@B("`@("`@("`@("`]/B`B7')<;GAX(BP*("`@(")X>%QR
M7&XB("`@("`@("`@("`]/B`B>'A<<EQN(BP*("`@(")X>%QR7&YX>"(@("`@
M("`@("`]/B`B>'A<<EQN>'@B+`H@("`@(EQR7&Y<<EQN>'@B("`@("`@(#T^
M(")<<EQN7')<;GAX(BP*("`@(")X>%QR7&Y<<EQN>'@B("`@("`]/B`B>'A<
M<EQN7')<;GAX(BP*("`@(")X>%QR7&Y<<EQN(B`@("`@("`]/B`B>'A<<EQN
M7')<;B(L"B`@("`B7')<;EQN>'@B("`@("`@("`@/3X@(EQR7&Y<<EQN>'@B
M+`H@("`@(EQN7')<;GAX(B`@("`@("`@(#T^(")<<EQN7')<;GAX(BP*("`@
M(")X>%QR7&Y<;GAX(B`@("`@("`]/B`B>'A<<EQN7')<;GAX(BP*("`@(")X
M>%QN7')<;GAX(B`@("`@("`]/B`B>'A<<EQN7')<;GAX(BP*("`@(")X>%QR
M7&Y<;B(@("`@("`@("`]/B`B>'A<<EQN7')<;B(L"B`@("`B>'A<;EQR7&XB
M("`@("`@("`@/3X@(GAX7')<;EQR7&XB+`H@("`@(EQR(B`@("`@("`@("`@
M("`@(#T^(")<<EQN(BP*("`@(")<<GAX(B`@("`@("`@("`@("`]/B`B7')<
M;GAX(BP*("`@(")X>%QR>'@B("`@("`@("`@("`]/B`B>'A<<EQN>'@B+`H@
M("`@(GAX7'(B("`@("`@("`@("`@(#T^(")X>%QR7&XB+`H@("`@(EQR7'(B
M("`@("`@("`@("`@(#T^(")<<EQN7')<;B(L"B`@("`B7')<<GAX(B`@("`@
M("`@("`@/3X@(EQR7&Y<<EQN>'@B+`H@("`@(GAX7')<<GAX(B`@("`@("`@
M(#T^(")X>%QR7&Y<<EQN>'@B+`H@("`@(GAX7')<<B(@("`@("`@("`@(#T^
M(")X>%QR7&Y<<EQN(BP*("`@(")X>%QR>'A<;GAX7')<;GAX(B`]/B`B>'A<
M<EQN>'A<<EQN>'A<<EQN>'@B+`H@("`@(EQR7')<;EQN(B`@("`@("`@(#T^
M(")<<EQN7')<;EQR7&XB+`HI.PH*)&AA9$5R<F]R(#T@9F%L<V4["F9O<F5A
M8V@@*"1T97-T<R!A<R`D:6YP=70@/3X@)&5X<&5C="D@>PH@("`@)&]U='!U
M="`]("1I;G!U=#L*("`@($YE=%]33510.CIQ=6]T961A=&$H)&]U='!U="D[
M"B`@("!I9B`H)&]U='!U="`A/2`D97AP96-T*2!["B`@("`@("`@96-H;R`B
M17)R;W(Z(&EN<'5T("(@+B!P<F5T='EP<FEN="@D:6YP=70I("X@(BP@;W5T
M<'5T("(@+B!P<F5T='EP<FEN="@D;W5T<'5T*2`N("(L(&5X<&5C=&5D("(@
M+B!P<F5T='EP<FEN="@D97AP96-T*2`N(")<;B(["B`@("`@("`@)&AA9$5R
M<F]R(#T@=')U93L*("`@('T*?0H*:68@*"$D:&%D17)R;W(I('L*("`@(&5C
M:&\@(G-U8V-E<W-<;B(["GT*"F9U;F-T:6]N('!R971T>7!R:6YT*"1X*0I[
M"B`@("!R971U<FX@<W1R7W)E<&QA8V4H87)R87DH(EQR(BP@(EQN(BDL(&%R
M<F%Y*"=<<B<L("=<;B<I+"`D>"D["GT*"BTM15A014-4+2T*<W5C8V5S<PH`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]T97-T<R].971?4TU44"]T97-T<R]A=71H+G!H<'0`````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q-#,V(#$P-3$U-#,S-S,S(#`R-#(R
M-0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````M
M+51%4U0M+0I.971?4TU44#H@4TU44"!!=71H96YT:6-A=&EO;@HM+49)3$4M
M+0H\/W!H<`H*<F5Q=6ER95]O;F-E("=.970O4TU44"YP:'`G.PIR97%U:7)E
M7V]N8V4@)V-O;F9I9RYP:'`G.PH*:68@*"$@*"1S;71P(#T@;F5W($YE=%]3
M3510*%1%4U1?2$]35$Y!344L(%1%4U1?4$]25"P@5$535%],3T-!3$A/4U0I
M*2D@>PH)9&EE*")5;F%B;&4@=&\@:6YS=&%N=&EA=&4@3F5T7U--5%`@;V)J
M96-T7&XB*3L*?0H*:68@*%!%05(Z.FES17)R;W(H)&4@/2`D<VUT<"T^8V]N
M;F5C="@I*2D@>PH)9&EE*"1E+3YG971-97-S86=E*"D@+B`B7&XB*3L*?0H*
M:68@*%!%05(Z.FES17)R;W(H)&4@/2`D<VUT<"T^875T:"A415-47T%55$A?
M55-%4BP@5$535%]!551(7U!!4U,I*2D@>PI]"@II9B`H4$5!4CHZ:7-%<G)O
M<B@D<VUT<"T^;6%I;$9R;VTH5$535%]&4D]-*2DI('L*"61I92@G56YA8FQE
M('1O('-E="!S96YD97(@=&\@/"<@+B!415-47T923TT@+B`B/EQN(BD["GT*
M"FEF("A014%2.CII<T5R<F]R*"1R97,@/2`D<VUT<"T^<F-P=%1O*%1%4U1?
M5$\I*2D@>PH)9&EE*"=5;F%B;&4@=&\@861D(')E8VEP:65N="`\)R`N(%1%
M4U1?5$\@+B`G/CH@)R`N"@D))')E<RT^9V5T365S<V%G92@I("X@(EQN(BD[
M"GT*"FEF("A014%2.CII<T5R<F]R*"1S;71P+3YD871A*%1%4U1?4U5"2D5#
M5"`N(")<<EQN(B`N(%1%4U1?0D]$62DI*2!["@ED:64H(E5N86)L92!T;R!S
M96YD(&1A=&%<;B(I.PI]"@HD<VUT<"T^9&ES8V]N;F5C="@I.PH*96-H;R`G
M4W5C8V5S<R$G.PH*+2U%6%!%0U0M+0I3=6-C97-S(0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]T97-T<R]-86EL````````````````````````
M`````````````````````````````````````````````````````````#`P
M,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S,S
M(#`R,#0S,P`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+TUA:6PO
M=&5S=',`````````````````````````````````````````````````````
M````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#`P,#`@,3`U,34T,S,W,S,@,#(Q-3<U`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O=&5S=',O36%I;"]T97-T<R]S;71P7V5R<F]R+G!H<'0`````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,3,R-R`Q,#4Q-30S,S<S,R`P,C0W-3``(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+2U415-4
M+2T*36%I;#H@4TU44"!%<G)O<B!297!O<G1I;F<*+2U32TE0248M+0H\/W!H
M<`H*<F5Q=6ER95]O;F-E("=014%2+U)E9VES=')Y+G!H<"<["B1R96=I<W1R
M>2`]("9N97<@4$5!4E]296=I<W1R>2@I.PH*:68@*"$D<F5G:7-T<GDM/G!A
M8VMA9V5%>&ES=',H)TYE=%]33510)RDI(&1I92@B<VMI<%QN(BD["BTM1DE,
M12TM"CP_<&AP"G)E<75I<F5?;VYC92`G36%I;"YP:'`G.PH*+RH@4F5F97)E
M;F-E(&$@8F]G=7,@4TU44"!S97)V97(@861D<F5S<R!T;R!G=6%R86YT964@
M82!C;VYN96-T:6]N(&9A:6QU<F4N("HO"B1P87)A;7,@/2!A<G)A>2@G:&]S
M="<@/3X@)V)O9W5S+FAO<W0N=&QD)RD["@HO*B!#<F5A=&4@;W5R(%--5%`M
M8F%S960@;6%I;&5R(&]B:F5C="X@*B\*)&UA:6QE<B`]("9-86EL.CIF86-T
M;W)Y*"=S;71P)RP@)'!A<F%M<RD["@HO*B!!='1E;7!T('1O('-E;F0@86X@
M96UP='D@;65S<V%G92!I;B!O<F1E<B!T;R!T<FEG9V5R(&%N(&5R<F]R+B`J
M+PII9B`H4$5!4CHZ:7-%<G)O<B@D92`]("1M86EL97(M/G-E;F0H87)R87DH
M*2P@87)R87DH*2P@)R<I*2D@>PH@("`@9&EE*"1E+3YG971-97-S86=E*"D@
M+B`B7&XB*3L*?0H*+2U%6%!%0U0M+0I&86EL960@=&\@8V]N;F5C="!T;R!B
M;V=U<RYH;W-T+G1L9#HR-2!;4TU44#H@1F%I;&5D('1O(&-O;FYE8W0@<V]C
M:V5T.B!5;FMN;W=N(&5R<F]R.B`P("AC;V1E.B`M,2P@<F5S<&]N<V4Z("E=
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O=&5S=',O36%I;"]T97-T<R]R9F,X,C(N<&AP=```````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-3$Q-2`Q,#4Q-30S,S<S,R`P,C,U
M-C$`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+2U415-4+2T*36%I;%]21D,X,C(Z($%D9')E<W,@4&%R<VEN9PHM+49)3$4M
M+0H\/W!H<`IR97%U:7)E7V]N8V4@)TUA:6PO4D9#.#(R+G!H<"<["@HD<&%R
M<V5R(#T@)FYE=R!-86EL7U)&0S@R,B@I.PH@"B\J($$@<VEM<&QE+"!B87)E
M(&%D9')E<W,N("HO"B1A9&1R97-S(#T@)W5S97)`97AA;7!L92YC;VTG.PIP
M<FEN=%]R*"1P87)S97(M/G!A<G-E061D<F5S<TQI<W0H)&%D9')E<W,L(&YU
M;&PL('1R=64L('1R=64I*3L*"B\J($%D9')E<W,@9W)O=7!S+B`J+PHD861D
M<F5S<R`]("=->2!'<F]U<#H@(E)I8VAA<F0B(#QR:6-H87)D0&QO8V%L:&]S
M=#X@*$$@8V]M;65N="DL('1E9$!E>&%M<&QE+F-O;2`H5&5D($)L;V=G<RDL
M($)A<FYE>3LG.PIP<FEN=%]R*"1P87)S97(M/G!A<G-E061D<F5S<TQI<W0H
M)&%D9')E<W,L(&YU;&PL('1R=64L('1R=64I*3L*"B\J($$@=F%L:60@861D
M<F5S<R!W:71H('-P86-E<R!I;B!T:&4@;&]C86P@<&%R="X@*B\*)&%D9')E
M<W,@/2`G/")*;VX@4&%R:7-E(D!P:'`N;F5T/B<["G!R:6YT7W(H)'!A<G-E
M<BT^<&%R<V5!9&1R97-S3&ES="@D861D<F5S<RP@;G5L;"P@=')U92P@=')U
M92DI.PH*+RH@06X@:6YV86QI9"!A9&1R97-S('=I=&@@<W!A8V5S(&EN('1H
M92!L;V-A;"!P87)T+B`J+PHD861D<F5S<R`]("<\2F]N(%!A<FES94!P:'`N
M;F5T/B<["B1R97-U;'0@/2`D<&%R<V5R+3YP87)S94%D9')E<W-,:7-T*"1A
M9&1R97-S+"!N=6QL+"!T<G5E+"!T<G5E*3L*:68@*%!%05(Z.FES17)R;W(H
M)')E<W5L="DI(&5C:&\@)')E<W5L="T^9V5T365S<V%G92@I("X@(EQN(CL*
M"BTM15A014-4+2T*07)R87D**`H@("`@6S!=(#T^('-T9$-L87-S($]B:F5C
M=`H@("`@("`@("@*("`@("`@("`@("`@6W!E<G-O;F%L72`]/B`*("`@("`@
M("`@("`@6V-O;6UE;G1=(#T^($%R<F%Y"B`@("`@("`@("`@("`@("`H"B`@
M("`@("`@("`@("`@("`I"@H@("`@("`@("`@("!;;6%I;&)O>%T@/3X@=7-E
M<@H@("`@("`@("`@("!;:&]S=%T@/3X@97AA;7!L92YC;VT*("`@("`@("`I
M"@HI"D%R<F%Y"B@*("`@(%LP72`]/B!S=&1#;&%S<R!/8FIE8W0*("`@("`@
M("`H"B`@("`@("`@("`@(%MG<F]U<&YA;65=(#T^($UY($=R;W5P"B`@("`@
M("`@("`@(%MA9&1R97-S97-=(#T^($%R<F%Y"B`@("`@("`@("`@("`@("`H
M"B`@("`@("`@("`@("`@("`@("`@6S!=(#T^('-T9$-L87-S($]B:F5C=`H@
M("`@("`@("`@("`@("`@("`@("`@("`H"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!;<&5R<V]N86Q=(#T^(")2:6-H87)D(@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@6V-O;6UE;G1=(#T^($%R<F%Y"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@*`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!;,%T@/3X@02!C;VUM96YT"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@*0H*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(%MM86EL8F]X72`]/B!R:6-H87)D"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!;:&]S=%T@/3X@;&]C86QH;W-T"B`@("`@("`@("`@("`@("`@
M("`@("`@("D*"B`@("`@("`@("`@("`@("`@("`@6S%=(#T^('-T9$-L87-S
M($]B:F5C=`H@("`@("`@("`@("`@("`@("`@("`@("`H"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!;<&5R<V]N86Q=(#T^(`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@6V-O;6UE;G1=(#T^($%R<F%Y"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@*`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!;,%T@/3X@5&5D($)L;V=G<PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("D*"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!;;6%I;&)O>%T@/3X@=&5D"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!;:&]S=%T@/3X@97AA;7!L92YC;VT*("`@("`@("`@("`@("`@("`@
M("`@("`@*0H*("`@("`@("`@("`@("`@("`@("!;,ET@/3X@<W1D0VQA<W,@
M3V)J96-T"B`@("`@("`@("`@("`@("`@("`@("`@("@*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(%MP97)S;VYA;%T@/3X@"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!;8V]M;65N=%T@/3X@07)R87D*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`H"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@*0H*("`@("`@("`@("`@("`@("`@("`@("`@("`@(%MM86EL
M8F]X72`]/B!"87)N97D*("`@("`@("`@("`@("`@("`@("`@("`@("`@(%MH
M;W-T72`]/B!L;V-A;&AO<W0*("`@("`@("`@("`@("`@("`@("`@("`@*0H*
M("`@("`@("`@("`@("`@("D*"B`@("`@("`@*0H**0I!<G)A>0HH"B`@("!;
M,%T@/3X@<W1D0VQA<W,@3V)J96-T"B`@("`@("`@*`H@("`@("`@("`@("!;
M<&5R<V]N86Q=(#T^(`H@("`@("`@("`@("!;8V]M;65N=%T@/3X@07)R87D*
M("`@("`@("`@("`@("`@("@*("`@("`@("`@("`@("`@("D*"B`@("`@("`@
M("`@(%MM86EL8F]X72`]/B`B2F]N(%!A<FES92(*("`@("`@("`@("`@6VAO
M<W1=(#T^('!H<"YN970*("`@("`@("`I"@HI"E9A;&ED871I;VX@9F%I;&5D
M(&9O<CH@/$IO;B!087)I<V5`<&AP+FYE=#X*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T
M<R]834Q?4E!#````````````````````````````````````````````````
M`````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S,S(#`R,#<Q-0`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+W1E<W1S+UA-3%]24$,O=&5S=',`````````````````
M````````````````````````````````````````````````````,#`P-S4U
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S,@,#(R
M,#4W`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O6$U,7U)00R]T
M97-T<R]T97-T7T1U;7`N<&AP````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S`T
M,B`Q,#4Q-30S,S<S,R`P,C0V,3(`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*"B\J"B`J($EF('1H92!P86-K86=E
M('9E<G-I;VX@;G5M8F5R(&ES(&9O=6YD(&EN('1H92!L969T(&AA;F0*("H@
M<&]R=&EO;B!O9B!T:&4@:68H*2!E>'!R97-S:6]N(&)E;&]W+"!T:&%T(&UE
M86YS('1H:7,@9FEL92!H87,*("H@8V]M92!F<F]M('1H92!014%2(&EN<W1A
M;&QE<BX@(%1H97)E9F]R92P@;&5T)W,@=&5S="!T:&4*("H@:6YS=&%L;&5D
M('9E<G-I;VX@;V8@6$U,7U)00R!W:&EC:"!S:&]U;&0@8F4@:6X@=&AE(&EN
M8VQU9&4@<&%T:"X*("H@"B`J($EF('1H92!V97)S:6]N(&AA<R!N;W0@8F5E
M;B!S=6)S=&ET=71E9"!I;B!T:&4@:68H*2!E>'!R97-S:6]N+`H@*B!T:&ES
M(&9I;&4@:&%S(&QI:V5L>2!C;VUE(&9R;VT@82!#5E,@8VAE8VMO=70@;W(@
M82`N=&%R(&9I;&4N"B`J(%1H97)E9F]R92P@=V4G;&P@87-S=6UE('1H92!T
M97-T<R!S:&]U;&0@=7-E('1H92!V97)S:6]N(&]F"B`J(%A-3%]24$,@=&AA
M="!H87,@8V]M92!F<F]M('1H97)E(&%S('=E;&PN"B`J+PII9B`H)S$N-"XX
M)R`A/2`G0"<N)W!A8VMA9V5?=F5R<VEO;B<N)T`G*2!["B`@("`O*BH*("`@
M("`J($=E="!T:&4@;F5E9&5D(&-L87-S(&9R;VT@=&AE(%!%05(@:6YS=&%L
M;&%T:6]N"B`@("`@*B\*("`@(')E<75I<F5?;VYC92`G6$U,+U)00R]$=6UP
M+G!H<"<["GT@96QS92!["B`@("`O*BH*("`@("`J($=E="!T:&4@;F5E9&5D
M(&-L87-S(&9R;VT@=&AE('!A<F5N="!D:7)E8W1O<GD*("`@("`J+PH@("`@
M<F5Q=6ER95]O;F-E("<N+B]$=6UP+G!H<"<["GT*"B1V86P@/2!N97<@6$U,
M7U)00U]686QU92AA<G)A>2@*("`@("=T:71L92<@("`@/3YN97<@6$U,7U)0
M0U]686QU92@G9&%S(&ES="!D97(@5&ET96PG+"`G<W1R:6YG)RDL"B`@("`G
M<W1A<G1$871E)ST^;F5W(%A-3%]24$-?5F%L=64H;6MT:6UE*#`L,"PP+#$S
M+#$Q+#(P,#0I+"`G9&%T951I;64N:7-O.#8P,2<I+`H@("`@)V5N9$1A=&4G
M("`]/FYE=R!834Q?4E!#7U9A;'5E*&UK=&EM92@P+#`L,"PQ-2PQ,2PR,#`T
M*2P@)V1A=&54:6UE+FES;S@V,#$G*2P*("`@("=E<G)O<B<@("`@/3XG<W1R
M:6YG)RP*("`@("=A<FME>2<@("`@/3X@;F5W(%A-3%]24$-?5F%L=64H(&%R
M<F%Y*`H@("`@("`@(&YE=R!834Q?4E!#7U9A;'5E*"=S:6UP;&4@<W1R:6YG
M)RDL"B`@("`@("`@;F5W(%A-3%]24$-?5F%L=64H,3(S-#4L("=I;G0G*0H@
M("`@("`@("DL("=A<G)A>2<I"B`@("`I"B`@("`L)W-T<G5C="<I.PH*6$U,
M7U)00U]$=6UP*"1V86PI.PH*96-H;R`G/3T]/3T]/3T]/3T]/3TG("X@(EQR
M7&XB.PHD=F%L,B`](&YE=R!834Q?4E!#7U9A;'5E*#0T,S4S+"`G:6YT)RD[
M"EA-3%]24$-?1'5M<"@D=F%L,BD["@IE8VAO("<]/3T]/3T]/3T]/3T]/2<@
M+B`B7')<;B(["B1V86PS(#T@;F5W(%A-3%]24$-?5F%L=64H)W1H:7,@<VAO
M=6QD(&)E(&$@<W1R:6YG)RP@)W-T<FEN9R<I.PI834Q?4E!#7T1U;7`H)'9A
M;#,I.PH*96-H;R`G/3T]/3T]/3T]/3T]/3TG("X@(EQR7&XB.PHD=F%L-"`]
M(&YE=R!834Q?4E!#7U9A;'5E*'1R=64L("=B;V]L96%N)RD["EA-3%]24$-?
M1'5M<"@D=F%L-"D["@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+UA-3%]24$,O=&5S=',O
M97AT<F$M;&EN97,N<&AP````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#8P,30@,3`U
M,34T,S,W,S,@,#(U,3`S`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP#0H-"B\J*@T*("H@5&5S=',@:&]W('1H92!8
M34Q?4E!#('-E<G9E<B!H86YD;&5S('!A<F%M971E<G,@=VET:"!E;7!T>2!V
M86QU97,N#0H@*@T*("H@268@>6]U(&%R92!R=6YN:6YG('1H:7,@=&5S="!F
M<F]M(&$@0U93(&-H96-K;W5T+"!Y;W4@;75S="!R96YA;64@=&AE('=O<FMI
M;F<-"B`J(&1I<F5C=&]R>2!F<F]M(")834Q?4E!#(B!T;R`B6$U,(BX-"B`J
M#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H
M:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T
M:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D
M:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@
M86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@
M<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@
M=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`
M8V%T96=O<GD@("!796(@4V5R=FEC97,-"B`J($!P86-K86=E("`@(%A-3%]2
M4$,-"B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`
M<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#(P,#4@5&AE(%!(4"!'<F]U<`T*
M("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="`@4$A0($QI8V5N<V4-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!E
M>'1R82UL:6YE<RYP:'`L=B`Q+C$@,C`P-B\P-"\P-R`Q-#HT.#HQ-"!D86YI
M96QC($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T
M+W!A8VMA9V4O6$U,7U)00PT*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B
M;&4@<VEN8V4@4F5L96%S92`Q+C0N-`T*("HO#0H-"B\J#0H@*B!)9B!T:&4@
M<&%C:V%G92!V97)S:6]N(&YU;6)E<B!I<R!F;W5N9"!I;B!T:&4@;&5F="!H
M86YD#0H@*B!P;W)T:6]N(&]F('1H92!I9B@I(&5X<')E<W-I;VX@8F5L;W<L
M('1H870@;65A;G,@=&AI<R!F:6QE(&AA<PT*("H@8V]M92!F<F]M('1H92!0
M14%2(&EN<W1A;&QE<BX@(%1H97)E9F]R92P@;&5T)W,@=&5S="!T:&4-"B`J
M(&EN<W1A;&QE9"!V97)S:6]N(&]F(%A-3%]24$,@=VAI8V@@<VAO=6QD(&)E
M(&EN('1H92!I;F-L=61E('!A=&@N#0H@*B`-"B`J($EF('1H92!V97)S:6]N
M(&AA<R!N;W0@8F5E;B!S=6)S=&ET=71E9"!I;B!T:&4@:68H*2!E>'!R97-S
M:6]N+`T*("H@=&AI<R!F:6QE(&AA<R!L:6ME;'D@8V]M92!F<F]M(&$@0U93
M(&-H96-K;W5T(&]R(&$@+G1A<B!F:6QE+@T*("H@5&AE<F5F;W)E+"!W92=L
M;"!A<W-U;64@=&AE('1E<W1S('-H;W5L9"!U<V4@=&AE('9E<G-I;VX@;V8-
M"B`J(%A-3%]24$,@=&AA="!H87,@8V]M92!F<F]M('1H97)E(&%S('=E;&PN
M#0H@*B\-"FEF("@G,2XT+C@G("$]("=`)RXG<&%C:V%G95]V97)S:6]N)RXG
M0"<I('L-"B`@("`O*BH-"B`@("`@*B!'970@=&AE(&YE961E9"!C;&%S<R!F
M<F]M('1H92!014%2(&EN<W1A;&QA=&EO;@T*("`@("`J+PT*("`@(')E<75I
M<F5?;VYC92`G6$U,+U)00RYP:'`G.PT*?2!E;'-E('L-"B`@("!I9B`H<W5B
M<W1R*&1I<FYA;64H7U]&24Q%7U\I+"`M.2P@+38I("$]("=834PG*2![#0H@
M("`@("`@(&5C:&\@(E1H92!P87)E;G0@9&ER96-T;W)Y(&UU<W0@8F4@;F%M
M960@)UA-3"<N7&XB.PT*("`@("`@("!E>&ET.PT*("`@('T-"@T*("`@(&EN
M:5]S970H)VEN8VQU9&5?<&%T:"<L("<N+B\N+B\G#0H@("`@("`@("`@("`N
M(%!!5$A?4T5005)!5$]2("X@)RXG("X@4$%42%]315!!4D%43U(-"B`@("`@
M("`@("`@("X@:6YI7V=E="@G:6YC;'5D95]P871H)RD-"B`@("`I.PT*#0H@
M("`@+RHJ#0H@("`@("H@1V5T('1H92!N965D960@8VQA<W,@9G)O;2!T:&4@
M<&%R96YT(&1I<F5C=&]R>0T*("`@("`J+PT*("`@(')E<75I<F5?;VYC92`G
M+BXO4E!#+G!H<"<[#0I]#0H-"B1I;G!U="`](")&:7)S="!L9G-<;EQN4V5C
M;VYD(&-R;&9S7')<;EQR7&Y4:&ER9"!C<G-<<EQR1F]U<G1H(&QI;F4B.PT*
M#0HD97AP96-T7W)E;6]V960@/2`B/#]X;6P@=F5R<VEO;CU<(C$N,%PB(&5N
M8V]D:6YG/5PB551&+3A<(C\^#0H\;65T:&]D0V%L;#X-"CQM971H;V1.86UE
M/FYA9&$\+VUE=&AO9$YA;64^#0H\<&%R86US/@T*/'!A<F%M/@T*/'9A;'5E
M/CQS=')I;F<^1FER<W0@;&9S#0I396-O;F0@8W)L9G,-"E1H:7)D(&-R<PT*
M1F]U<G1H(&QI;F4\+W-T<FEN9SX\+W9A;'5E/@T*/"]P87)A;3X-"CPO<&%R
M86US/@T*/"]M971H;V1#86QL/@T*(CL-"@T*)&5X<&5C=%]N;W1?<F5M;W9E
M9"`]("(\/WAM;"!V97)S:6]N/5PB,2XP7"(@96YC;V1I;F<]7")55$8M.%PB
M/SX-"CQM971H;V1#86QL/@T*/&UE=&AO9$YA;64^;F%D83PO;65T:&]D3F%M
M93X-"CQP87)A;7,^#0H\<&%R86T^#0H\=F%L=64^/'-T<FEN9SY&:7)S="!L
M9G,-"@T*4V5C;VYD(&-R;&9S#0H-"E1H:7)D(&-R<PT*#0I&;W5R=&@@;&EN
M93PO<W1R:6YG/CPO=F%L=64^#0H\+W!A<F%M/@T*/"]P87)A;7,^#0H\+VUE
M=&AO9$-A;&P^#0HB.PT*#0H-"B1M<V<@/2!N97<@6$U,7U)00U]-97-S86=E
M*"=N861A)RP@87)R87DH6$U,7U)00U]E;F-O9&4H)&EN<'5T*2DI.PT*)&US
M9RT^8W)E871E4&%Y;&]A9"@I.PT*:68@*"1M<V<M/G!A>6QO860@/3T@)&5X
M<&5C=%]R96UO=F5D*2![#0H@("`@96-H;R`B<&%S<V5D7&XB.PT*?2!E;'-E
M('L-"B`@("!E8VAO(")04D]"3$5-7&XB.PT*?0T*#0HD;7-G(#T@;F5W(%A-
M3%]24$-?365S<V%G92@G;F%D82<L(&%R<F%Y*%A-3%]24$-?96YC;V1E*"1I
M;G!U="DI*3L-"B1M<V<M/G)E;6]V95]E>'1R85]L:6YE<R`](&9A;'-E.PT*
M)&US9RT^8W)E871E4&%Y;&]A9"@I.PT*:68@*"1M<V<M/G!A>6QO860@/3T@
M)&5X<&5C=%]N;W1?<F5M;W9E9"D@>PT*("`@(&5C:&\@(G!A<W-E9%QN(CL-
M"GT@96QS92![#0H@("`@96-H;R`B4%)/0DQ%35QN(CL-"GT-"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]834Q?4E!#+W1E<W1S
M+W!R;W1O<&]R="YP:'``````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#(U-30S(#$P
M-3$U-#,S-S,S(#`R-#<S,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`H*+RHJ"B`J(%1E<W1S('1H870@<')O<&5R
M=&EE<R!O9B!834Q?4E!#7T-L:65N="!G970@<')O<&5R;'D@<V5T"B`J"B`J
M($%N>2!I;F1I=FED=6%L('1E<W1S('1H870@9F%I;"!W:6QL(&AA=F4@=&AE
M:7(@;F%M92P@97AP96-T960@<F5S=6QT"B`J(&%N9"!A8W1U86P@<F5S=6QT
M('!R:6YT960@;W5T+B`@4V\@<V5E:6YG(&YO(&]U='!U="!W:&5N(&5X96-U
M=&EN9PH@*B!T:&ES(&9I;&4@:7,@82!G;V]D('1H:6YG+@H@*@H@*B!#86X@
M8F4@<G5N('9I82!#3$D@;W(@82!W96(@<V5R=F5R+@H@*@H@*B!02%`@=F5R
M<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE
M(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E
M"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M
M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@H@*B!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A
M(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O
M(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90H@*B!S96YD(&$@
M;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@
M8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@5V5B(%-E<G9I
M8V5S"B`J($!P86-K86=E("`@(%A-3%]24$,*("H@0&%U=&AO<B`@("`@1&%N
M:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT
M("`R,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4*("H@0'9E
M<G-I;VX@("`@0U93.B`D260Z('!R;W1O<&]R="YP:'`L=B`Q+C0@,C`P-2\P
M,2\R-"`Q-SHT.#HT-R!D86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]834Q?4E!#"B`J($!S:6YC92`@
M("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XR"B`J+PH*+RH*
M("H@268@=&AE('!A8VMA9V4@=F5R<VEO;B!N=6UB97(@:7,@9F]U;F0@:6X@
M=&AE(&QE9G0@:&%N9`H@*B!P;W)T:6]N(&]F('1H92!I9B@I(&5X<')E<W-I
M;VX@8F5L;W<L('1H870@;65A;G,@=&AI<R!F:6QE(&AA<PH@*B!C;VUE(&9R
M;VT@=&AE(%!%05(@:6YS=&%L;&5R+B`@5&AE<F5F;W)E+"!L970G<R!T97-T
M('1H90H@*B!I;G-T86QL960@=F5R<VEO;B!O9B!834Q?4E!#('=H:6-H('-H
M;W5L9"!B92!I;B!T:&4@:6YC;'5D92!P871H+@H@*B`*("H@268@=&AE('9E
M<G-I;VX@:&%S(&YO="!B965N('-U8G-T:71U=&5D(&EN('1H92!I9B@I(&5X
M<')E<W-I;VXL"B`J('1H:7,@9FEL92!H87,@;&EK96QY(&-O;64@9G)O;2!A
M($-64R!C:&5C:V]U="!O<B!A("YT87(@9FEL92X*("H@5&AE<F5F;W)E+"!W
M92=L;"!A<W-U;64@=&AE('1E<W1S('-H;W5L9"!U<V4@=&AE('9E<G-I;VX@
M;V8*("H@6$U,7U)00R!T:&%T(&AA<R!C;VUE(&9R;VT@=&AE<F4@87,@=V5L
M;"X*("HO"FEF("@G,2XT+C@G("$]("=`)RXG<&%C:V%G95]V97)S:6]N)RXG
M0"<I('L*("`@("\J*@H@("`@("H@1V5T('1H92!N965D960@8VQA<W,@9G)O
M;2!T:&4@4$5!4B!I;G-T86QL871I;VX*("`@("`J+PH@("`@<F5Q=6ER95]O
M;F-E("=834PO4E!#+G!H<"<["GT@96QS92!["B`@("`O*BH*("`@("`J($=E
M="!T:&4@;F5E9&5D(&-L87-S(&9R;VT@=&AE('!A<F5N="!D:7)E8W1O<GD*
M("`@("`J+PH@("`@<F5Q=6ER95]O;F-E("<N+B]24$,N<&AP)SL*?0H*+RHJ
M"B`J($-O;7!A<F4@=&AE('1E<W0@<F5S=6QT('1O('1H92!E>'!E8W1E9"!R
M97-U;'0*("H*("H@268@=&AE('1E<W0@9F%I;',L(&5C:&\@;W5T('1H92!R
M97-U;'1S+@H@*@H@*B!`<&%R86T@87)R87D@("1E>'!E8W0@("`@('1H92!A
M<G)A>2!O9B!O8FIE8W0@<')O<&5R=&EE<R!Y;W4@97AP96-T"B`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&9R;VT@=&AE('1E<W0*("H@0'!A<F%M
M(&]B:F5C="`D86-T=6%L("`@("!T:&4@;V)J96-T(')E<W5L=',@9G)O;2!T
M:&4@=&5S=`H@*B!`<&%R86T@<W1R:6YG("1T97-T7VYA;64@('1H92!N86UE
M(&]F('1H92!T97-T"B`J"B`J($!R971U<FX@=F]I9`H@*B\*9G5N8W1I;VX@
M8V]M<&%R92@D97AP96-T+"`D86-T=6%L+"`D=&5S=%]N86UE*2!["B`@("`D
M86-T=6%L(#T@9V5T7V]B:F5C=%]V87)S*"1A8W1U86PI.PH@("`@:68@*&-O
M=6YT*&%R<F%Y7V1I9F8H)&%C='5A;"P@)&5X<&5C="DI*2!["B`@("`@("`@
M96-H;R`B)'1E<W1?;F%M92!F86EL960N7&Y%>'!E8W0Z("(["B`@("`@("`@
M<')I;G1?<B@D97AP96-T*3L*("`@("`@("!E8VAO(")!8W1U86PZ("(["B`@
M("`@("`@<')I;G1?<B@D86-T=6%L*3L*("`@("`@("!E8VAO(")<;B(["B`@
M("!]"GT*"FEF("AP:'!?<V%P:5]N86UE*"D@(3T@)V-L:2<I('L*("`@(&5C
M:&\@(CQP<F4^7&XB.PI]"@H*)'@@/2!A<G)A>2@*("`@("=P871H)R`]/B`G
M=&AE<&%T:"<L"B`@("`G<V5R=F5R)R`]/B`G=&AE<V5R=F5R)RP*("`@("=P
M<F]T;V-O;"<@/3X@)VAT='`Z+R\G+`H@("`@)W!O<G0G(#T^(#@P+`H@("`@
M)W!R;WAY)R`]/B`G)RP*("`@("=P<F]X>5]P<F]T;V-O;"<@/3X@)VAT='`Z
M+R\G+`H@("`@)W!R;WAY7W!O<G0G(#T^(#@P.#`L"B`@("`G<')O>'E?=7-E
M<B<@/3X@)R<L"B`@("`G<')O>'E?<&%S<R<@/3X@)R<L"B`@("`G97)R;F\G
M(#T^(#`L"B`@("`G97)R<W1R:6YG)R`]/B`G)RP*("`@("=D96)U9R<@/3X@
M,"P*("`@("=U<V5R;F%M92<@/3X@)R<L"B`@("`G<&%S<W=O<F0G(#T^("<G
M+`HI.PHD8R`](&YE=R!834Q?4E!#7T-L:65N="@G=&AE<&%T:"<L("=T:&5S
M97)V97(G*3L*8V]M<&%R92@D>"P@)&,L("=D969A=6QT<R<I.PH*)'@@/2!A
M<G)A>2@*("`@("=P871H)R`]/B`G=&AE<&%T:"<L"B`@("`G<V5R=F5R)R`]
M/B`G=&AE<V5R=F5R)RP*("`@("=P<F]T;V-O;"<@/3X@)VAT='`Z+R\G+`H@
M("`@)W!O<G0G(#T^(#@P+`H@("`@)W!R;WAY)R`]/B`G)RP*("`@("=P<F]X
M>5]P<F]T;V-O;"<@/3X@)VAT='`Z+R\G+`H@("`@)W!R;WAY7W!O<G0G(#T^
M(#@P.#`L"B`@("`G<')O>'E?=7-E<B<@/3X@)R<L"B`@("`G<')O>'E?<&%S
M<R<@/3X@)R<L"B`@("`G97)R;F\G(#T^(#`L"B`@("`G97)R<W1R:6YG)R`]
M/B`G)RP*("`@("=D96)U9R<@/3X@,"P*("`@("=U<V5R;F%M92<@/3X@)R<L
M"B`@("`G<&%S<W=O<F0G(#T^("<G+`HI.PHD8R`](&YE=R!834Q?4E!#7T-L
M:65N="@G=&AE<&%T:"<L("=H='1P.B\O=&AE<V5R=F5R)RD["F-O;7!A<F4H
M)'@L("1C+"`G9&5F875L=',@=VET:"!H='1P)RD["@HD>"`](&%R<F%Y*`H@
M("`@)W!A=&@G(#T^("=T:&5P871H)RP*("`@("=S97)V97(G(#T^("=T:&5S
M97)V97(G+`H@("`@)W!R;W1O8V]L)R`]/B`G<W-L.B\O)RP*("`@("=P;W)T
M)R`]/B`T-#,L"B`@("`G<')O>'DG(#T^("<G+`H@("`@)W!R;WAY7W!R;W1O
M8V]L)R`]/B`G:'1T<#HO+R<L"B`@("`G<')O>'E?<&]R="<@/3X@.#`X,"P*
M("`@("=P<F]X>5]U<V5R)R`]/B`G)RP*("`@("=P<F]X>5]P87-S)R`]/B`G
M)RP*("`@("=E<G)N;R<@/3X@,"P*("`@("=E<G)S=')I;F<G(#T^("<G+`H@
M("`@)V1E8G5G)R`]/B`P+`H@("`@)W5S97)N86UE)R`]/B`G)RP*("`@("=P
M87-S=V]R9"<@/3X@)R<L"BD["B1C(#T@;F5W(%A-3%]24$-?0VQI96YT*"=T
M:&5P871H)RP@)VAT='!S.B\O=&AE<V5R=F5R)RD["F-O;7!A<F4H)'@L("1C
M+"`G9&5F875L=',@=VET:"!H='1P<R<I.PH*)'@@/2!A<G)A>2@*("`@("=P
M871H)R`]/B`G=&AE<&%T:"<L"B`@("`G<V5R=F5R)R`]/B`G=&AE<V5R=F5R
M)RP*("`@("=P<F]T;V-O;"<@/3X@)W-S;#HO+R<L"B`@("`G<&]R="<@/3X@
M-#0S+`H@("`@)W!R;WAY)R`]/B`G)RP*("`@("=P<F]X>5]P<F]T;V-O;"<@
M/3X@)VAT='`Z+R\G+`H@("`@)W!R;WAY7W!O<G0G(#T^(#@P.#`L"B`@("`G
M<')O>'E?=7-E<B<@/3X@)R<L"B`@("`G<')O>'E?<&%S<R<@/3X@)R<L"B`@
M("`G97)R;F\G(#T^(#`L"B`@("`G97)R<W1R:6YG)R`]/B`G)RP*("`@("=D
M96)U9R<@/3X@,"P*("`@("=U<V5R;F%M92<@/3X@)R<L"B`@("`G<&%S<W=O
M<F0G(#T^("<G+`HI.PHD8R`](&YE=R!834Q?4E!#7T-L:65N="@G=&AE<&%T
M:"<L("=S<VPZ+R]T:&5S97)V97(G*3L*8V]M<&%R92@D>"P@)&,L("=D969A
M=6QT<R!W:71H('-S;"<I.PH*"B1X(#T@87)R87DH"B`@("`G<&%T:"<@/3X@
M)W1H97!A=&@G+`H@("`@)W-E<G9E<B<@/3X@)W1H97-E<G9E<B<L"B`@("`G
M<')O=&]C;VPG(#T^("=H='1P.B\O)RP*("`@("=P;W)T)R`]/B`V-2P*("`@
M("=P<F]X>2<@/3X@)R<L"B`@("`G<')O>'E?<')O=&]C;VPG(#T^("=H='1P
M.B\O)RP*("`@("=P<F]X>5]P;W)T)R`]/B`X,#@P+`H@("`@)W!R;WAY7W5S
M97(G(#T^("<G+`H@("`@)W!R;WAY7W!A<W,G(#T^("<G+`H@("`@)V5R<FYO
M)R`]/B`P+`H@("`@)V5R<G-T<FEN9R<@/3X@)R<L"B`@("`G9&5B=6<G(#T^
M(#`L"B`@("`G=7-E<FYA;64G(#T^("<G+`H@("`@)W!A<W-W;W)D)R`]/B`G
M)RP**3L*)&,@/2!N97<@6$U,7U)00U]#;&EE;G0H)W1H97!A=&@G+"`G=&AE
M<V5R=F5R)RP@-C4I.PIC;VUP87)E*"1X+"`D8RP@)W!O<G0@-C4G*3L*"B1X
M(#T@87)R87DH"B`@("`G<&%T:"<@/3X@)W1H97!A=&@G+`H@("`@)W-E<G9E
M<B<@/3X@)W1H97-E<G9E<B<L"B`@("`G<')O=&]C;VPG(#T^("=H='1P.B\O
M)RP*("`@("=P;W)T)R`]/B`V-2P*("`@("=P<F]X>2<@/3X@)R<L"B`@("`G
M<')O>'E?<')O=&]C;VPG(#T^("=H='1P.B\O)RP*("`@("=P<F]X>5]P;W)T
M)R`]/B`X,#@P+`H@("`@)W!R;WAY7W5S97(G(#T^("<G+`H@("`@)W!R;WAY
M7W!A<W,G(#T^("<G+`H@("`@)V5R<FYO)R`]/B`P+`H@("`@)V5R<G-T<FEN
M9R<@/3X@)R<L"B`@("`G9&5B=6<G(#T^(#`L"B`@("`G=7-E<FYA;64G(#T^
M("<G+`H@("`@)W!A<W-W;W)D)R`]/B`G)RP**3L*)&,@/2!N97<@6$U,7U)0
M0U]#;&EE;G0H)W1H97!A=&@G+"`G:'1T<#HO+W1H97-E<G9E<B<L(#8U*3L*
M8V]M<&%R92@D>"P@)&,L("=P;W)T(#8U('=I=&@@:'1T<"<I.PH*)'@@/2!A
M<G)A>2@*("`@("=P871H)R`]/B`G=&AE<&%T:"<L"B`@("`G<V5R=F5R)R`]
M/B`G=&AE<V5R=F5R)RP*("`@("=P<F]T;V-O;"<@/3X@)W-S;#HO+R<L"B`@
M("`G<&]R="<@/3X@-C4L"B`@("`G<')O>'DG(#T^("<G+`H@("`@)W!R;WAY
M7W!R;W1O8V]L)R`]/B`G:'1T<#HO+R<L"B`@("`G<')O>'E?<&]R="<@/3X@
M.#`X,"P*("`@("=P<F]X>5]U<V5R)R`]/B`G)RP*("`@("=P<F]X>5]P87-S
M)R`]/B`G)RP*("`@("=E<G)N;R<@/3X@,"P*("`@("=E<G)S=')I;F<G(#T^
M("<G+`H@("`@)V1E8G5G)R`]/B`P+`H@("`@)W5S97)N86UE)R`]/B`G)RP*
M("`@("=P87-S=V]R9"<@/3X@)R<L"BD["B1C(#T@;F5W(%A-3%]24$-?0VQI
M96YT*"=T:&5P871H)RP@)VAT='!S.B\O=&AE<V5R=F5R)RP@-C4I.PIC;VUP
M87)E*"1X+"`D8RP@)W!O<G0@-C4@=VET:"!H='1P<R<I.PH*)'@@/2!A<G)A
M>2@*("`@("=P871H)R`]/B`G=&AE<&%T:"<L"B`@("`G<V5R=F5R)R`]/B`G
M=&AE<V5R=F5R)RP*("`@("=P<F]T;V-O;"<@/3X@)W-S;#HO+R<L"B`@("`G
M<&]R="<@/3X@-C4L"B`@("`G<')O>'DG(#T^("<G+`H@("`@)W!R;WAY7W!R
M;W1O8V]L)R`]/B`G:'1T<#HO+R<L"B`@("`G<')O>'E?<&]R="<@/3X@.#`X
M,"P*("`@("=P<F]X>5]U<V5R)R`]/B`G)RP*("`@("=P<F]X>5]P87-S)R`]
M/B`G)RP*("`@("=E<G)N;R<@/3X@,"P*("`@("=E<G)S=')I;F<G(#T^("<G
M+`H@("`@)V1E8G5G)R`]/B`P+`H@("`@)W5S97)N86UE)R`]/B`G)RP*("`@
M("=P87-S=V]R9"<@/3X@)R<L"BD["B1C(#T@;F5W(%A-3%]24$-?0VQI96YT
M*"=T:&5P871H)RP@)W-S;#HO+W1H97-E<G9E<B<L(#8U*3L*8V]M<&%R92@D
M>"P@)&,L("=P;W)T(#8U('=I=&@@<W-L)RD["@H*)'@@/2!A<G)A>2@*("`@
M("=P871H)R`]/B`G=&AE<&%T:"<L"B`@("`G<V5R=F5R)R`]/B`G=&AE<V5R
M=F5R)RP*("`@("=P<F]T;V-O;"<@/3X@)VAT='`Z+R\G+`H@("`@)W!O<G0G
M(#T^(#@P+`H@("`@)W!R;WAY)R`]/B`G=&AE<')O>'DG+`H@("`@)W!R;WAY
M7W!R;W1O8V]L)R`]/B`G:'1T<#HO+R<L"B`@("`G<')O>'E?<&]R="<@/3X@
M.#`X,"P*("`@("=P<F]X>5]U<V5R)R`]/B`G)RP*("`@("=P<F]X>5]P87-S
M)R`]/B`G)RP*("`@("=E<G)N;R<@/3X@,"P*("`@("=E<G)S=')I;F<G(#T^
M("<G+`H@("`@)V1E8G5G)R`]/B`P+`H@("`@)W5S97)N86UE)R`]/B`G)RP*
M("`@("=P87-S=V]R9"<@/3X@)R<L"BD["B1C(#T@;F5W(%A-3%]24$-?0VQI
M96YT*"=T:&5P871H)RP@)W1H97-E<G9E<B<L(#`L"B`@("`@("`@("`@("`@
M("`@("`@("`@("=T:&5P<F]X>2<I.PIC;VUP87)E*"1X+"`D8RP@)V1E9F%U
M;'1S('!R;WAY)RD["@HD>"`](&%R<F%Y*`H@("`@)W!A=&@G(#T^("=T:&5P
M871H)RP*("`@("=S97)V97(G(#T^("=T:&5S97)V97(G+`H@("`@)W!R;W1O
M8V]L)R`]/B`G:'1T<#HO+R<L"B`@("`G<&]R="<@/3X@.#`L"B`@("`G<')O
M>'DG(#T^("=T:&5P<F]X>2<L"B`@("`G<')O>'E?<')O=&]C;VPG(#T^("=H
M='1P.B\O)RP*("`@("=P<F]X>5]P;W)T)R`]/B`X,#@P+`H@("`@)W!R;WAY
M7W5S97(G(#T^("<G+`H@("`@)W!R;WAY7W!A<W,G(#T^("<G+`H@("`@)V5R
M<FYO)R`]/B`P+`H@("`@)V5R<G-T<FEN9R<@/3X@)R<L"B`@("`G9&5B=6<G
M(#T^(#`L"B`@("`G=7-E<FYA;64G(#T^("<G+`H@("`@)W!A<W-W;W)D)R`]
M/B`G)RP**3L*)&,@/2!N97<@6$U,7U)00U]#;&EE;G0H)W1H97!A=&@G+"`G
M:'1T<#HO+W1H97-E<G9E<B<L(#`L"B`@("`@("`@("`@("`@("`@("`@("`@
M("=H='1P.B\O=&AE<')O>'DG*3L*8V]M<&%R92@D>"P@)&,L("=D969A=6QT
M<R!W:71H(&AT='`@<')O>'DG*3L*"B1X(#T@87)R87DH"B`@("`G<&%T:"<@
M/3X@)W1H97!A=&@G+`H@("`@)W-E<G9E<B<@/3X@)W1H97-E<G9E<B<L"B`@
M("`G<')O=&]C;VPG(#T^("=S<VPZ+R\G+`H@("`@)W!O<G0G(#T^(#0T,RP*
M("`@("=P<F]X>2<@/3X@)W1H97!R;WAY)RP*("`@("=P<F]X>5]P<F]T;V-O
M;"<@/3X@)W-S;#HO+R<L"B`@("`G<')O>'E?<&]R="<@/3X@-#0S+`H@("`@
M)W!R;WAY7W5S97(G(#T^("<G+`H@("`@)W!R;WAY7W!A<W,G(#T^("<G+`H@
M("`@)V5R<FYO)R`]/B`P+`H@("`@)V5R<G-T<FEN9R<@/3X@)R<L"B`@("`G
M9&5B=6<G(#T^(#`L"B`@("`G=7-E<FYA;64G(#T^("<G+`H@("`@)W!A<W-W
M;W)D)R`]/B`G)RP**3L*)&,@/2!N97<@6$U,7U)00U]#;&EE;G0H)W1H97!A
M=&@G+"`G:'1T<',Z+R]T:&5S97)V97(G+"`P+`H@("`@("`@("`@("`@("`@
M("`@("`@("`G:'1T<',Z+R]T:&5P<F]X>2<I.PIC;VUP87)E*"1X+"`D8RP@
M)V1E9F%U;'1S('=I=&@@:'1T<',@<')O>'DG*3L*"B1X(#T@87)R87DH"B`@
M("`G<&%T:"<@/3X@)W1H97!A=&@G+`H@("`@)W-E<G9E<B<@/3X@)W1H97-E
M<G9E<B<L"B`@("`G<')O=&]C;VPG(#T^("=S<VPZ+R\G+`H@("`@)W!O<G0G
M(#T^(#0T,RP*("`@("=P<F]X>2<@/3X@)W1H97!R;WAY)RP*("`@("=P<F]X
M>5]P<F]T;V-O;"<@/3X@)W-S;#HO+R<L"B`@("`G<')O>'E?<&]R="<@/3X@
M-#0S+`H@("`@)W!R;WAY7W5S97(G(#T^("<G+`H@("`@)W!R;WAY7W!A<W,G
M(#T^("<G+`H@("`@)V5R<FYO)R`]/B`P+`H@("`@)V5R<G-T<FEN9R<@/3X@
M)R<L"B`@("`G9&5B=6<G(#T^(#`L"B`@("`G=7-E<FYA;64G(#T^("<G+`H@
M("`@)W!A<W-W;W)D)R`]/B`G)RP**3L*)&,@/2!N97<@6$U,7U)00U]#;&EE
M;G0H)W1H97!A=&@G+"`G<W-L.B\O=&AE<V5R=F5R)RP@,"P*("`@("`@("`@
M("`@("`@("`@("`@("`@)W-S;#HO+W1H97!R;WAY)RD["F-O;7!A<F4H)'@L
M("1C+"`G9&5F875L=',@=VET:"!S<VP@<')O>'DG*3L*"@HD>"`](&%R<F%Y
M*`H@("`@)W!A=&@G(#T^("=T:&5P871H)RP*("`@("=S97)V97(G(#T^("=T
M:&5S97)V97(G+`H@("`@)W!R;W1O8V]L)R`]/B`G:'1T<#HO+R<L"B`@("`G
M<&]R="<@/3X@-C4L"B`@("`G<')O>'DG(#T^("=T:&5P<F]X>2<L"B`@("`G
M<')O>'E?<')O=&]C;VPG(#T^("=H='1P.B\O)RP*("`@("=P<F]X>5]P;W)T
M)R`]/B`V-38U+`H@("`@)W!R;WAY7W5S97(G(#T^("<G+`H@("`@)W!R;WAY
M7W!A<W,G(#T^("<G+`H@("`@)V5R<FYO)R`]/B`P+`H@("`@)V5R<G-T<FEN
M9R<@/3X@)R<L"B`@("`G9&5B=6<G(#T^(#`L"B`@("`G=7-E<FYA;64G(#T^
M("<G+`H@("`@)W!A<W-W;W)D)R`]/B`G)RP**3L*)&,@/2!N97<@6$U,7U)0
M0U]#;&EE;G0H)W1H97!A=&@G+"`G=&AE<V5R=F5R)RP@-C4L"B`@("`@("`@
M("`@("`@("`@("`@("`@("=T:&5P<F]X>2<L(#8U-C4I.PIC;VUP87)E*"1X
M+"`D8RP@)W!O<G0@-C4@<')O>'D@-C4V-2<I.PH*)'@@/2!A<G)A>2@*("`@
M("=P871H)R`]/B`G=&AE<&%T:"<L"B`@("`G<V5R=F5R)R`]/B`G=&AE<V5R
M=F5R)RP*("`@("=P<F]T;V-O;"<@/3X@)VAT='`Z+R\G+`H@("`@)W!O<G0G
M(#T^(#8U+`H@("`@)W!R;WAY)R`]/B`G=&AE<')O>'DG+`H@("`@)W!R;WAY
M7W!R;W1O8V]L)R`]/B`G:'1T<#HO+R<L"B`@("`G<')O>'E?<&]R="<@/3X@
M-C4V-2P*("`@("=P<F]X>5]U<V5R)R`]/B`G)RP*("`@("=P<F]X>5]P87-S
M)R`]/B`G)RP*("`@("=E<G)N;R<@/3X@,"P*("`@("=E<G)S=')I;F<G(#T^
M("<G+`H@("`@)V1E8G5G)R`]/B`P+`H@("`@)W5S97)N86UE)R`]/B`G)RP*
M("`@("=P87-S=V]R9"<@/3X@)R<L"BD["B1C(#T@;F5W(%A-3%]24$-?0VQI
M96YT*"=T:&5P871H)RP@)VAT='`Z+R]T:&5S97)V97(G+"`V-2P*("`@("`@
M("`@("`@("`@("`@("`@("`@)VAT='`Z+R]T:&5P<F]X>2<L(#8U-C4I.PIC
M;VUP87)E*"1X+"`D8RP@)W!O<G0@-C4@=VET:"!H='1P('!R;WAY(#8U-C4G
M*3L*"B1X(#T@87)R87DH"B`@("`G<&%T:"<@/3X@)W1H97!A=&@G+`H@("`@
M)W-E<G9E<B<@/3X@)W1H97-E<G9E<B<L"B`@("`G<')O=&]C;VPG(#T^("=S
M<VPZ+R\G+`H@("`@)W!O<G0G(#T^(#8U+`H@("`@)W!R;WAY)R`]/B`G=&AE
M<')O>'DG+`H@("`@)W!R;WAY7W!R;W1O8V]L)R`]/B`G<W-L.B\O)RP*("`@
M("=P<F]X>5]P;W)T)R`]/B`V-38U+`H@("`@)W!R;WAY7W5S97(G(#T^("<G
M+`H@("`@)W!R;WAY7W!A<W,G(#T^("<G+`H@("`@)V5R<FYO)R`]/B`P+`H@
M("`@)V5R<G-T<FEN9R<@/3X@)R<L"B`@("`G9&5B=6<G(#T^(#`L"B`@("`G
M=7-E<FYA;64G(#T^("<G+`H@("`@)W!A<W-W;W)D)R`]/B`G)RP**3L*)&,@
M/2!N97<@6$U,7U)00U]#;&EE;G0H)W1H97!A=&@G+"`G:'1T<',Z+R]T:&5S
M97)V97(G+"`V-2P*("`@("`@("`@("`@("`@("`@("`@("`@)VAT='!S.B\O
M=&AE<')O>'DG+"`V-38U*3L*8V]M<&%R92@D>"P@)&,L("=P;W)T(#8U('=I
M=&@@:'1T<',@<')O>'D@-C4V-2<I.PH*)'@@/2!A<G)A>2@*("`@("=P871H
M)R`]/B`G=&AE<&%T:"<L"B`@("`G<V5R=F5R)R`]/B`G=&AE<V5R=F5R)RP*
M("`@("=P<F]T;V-O;"<@/3X@)W-S;#HO+R<L"B`@("`G<&]R="<@/3X@-C4L
M"B`@("`G<')O>'DG(#T^("=T:&5P<F]X>2<L"B`@("`G<')O>'E?<')O=&]C
M;VPG(#T^("=S<VPZ+R\G+`H@("`@)W!R;WAY7W!O<G0G(#T^(#8U-C4L"B`@
M("`G<')O>'E?=7-E<B<@/3X@)R<L"B`@("`G<')O>'E?<&%S<R<@/3X@)R<L
M"B`@("`G97)R;F\G(#T^(#`L"B`@("`G97)R<W1R:6YG)R`]/B`G)RP*("`@
M("=D96)U9R<@/3X@,"P*("`@("=U<V5R;F%M92<@/3X@)R<L"B`@("`G<&%S
M<W=O<F0G(#T^("<G+`HI.PHD8R`](&YE=R!834Q?4E!#7T-L:65N="@G=&AE
M<&%T:"<L("=S<VPZ+R]T:&5S97)V97(G+"`V-2P*("`@("`@("`@("`@("`@
M("`@("`@("`@)W-S;#HO+W1H97!R;WAY)RP@-C4V-2D["F-O;7!A<F4H)'@L
M("1C+"`G<&]R="`V-2!W:71H('-S;"!P<F]X>2`V-38U)RD["@H*)'@@/2!A
M<G)A>2@*("`@("=P871H)R`]/B`G=&AE<&%T:"<L"B`@("`G<V5R=F5R)R`]
M/B`G=&AE<V5R=F5R)RP*("`@("=P<F]T;V-O;"<@/3X@)W-S;#HO+R<L"B`@
M("`G<&]R="<@/3X@-#0S+`H@("`@)W!R;WAY)R`]/B`G=&AE<')O>'DG+`H@
M("`@)W!R;WAY7W!R;W1O8V]L)R`]/B`G<W-L.B\O)RP*("`@("=P<F]X>5]P
M;W)T)R`]/B`T-#,L"B`@("`G<')O>'E?=7-E<B<@/3X@)R<L"B`@("`G<')O
M>'E?<&%S<R<@/3X@)R<L"B`@("`G97)R;F\G(#T^(#`L"B`@("`G97)R<W1R
M:6YG)R`]/B`G)RP*("`@("=D96)U9R<@/3X@,"P*("`@("=U<V5R;F%M92<@
M/3X@)R<L"B`@("`G<&%S<W=O<F0G(#T^("<G+`HI.PHD8R`](&YE=R!834Q?
M4E!#7T-L:65N="@G=&AE<&%T:"<L("=T:&5S97)V97(G+"`T-#,L"B`@("`@
M("`@("`@("`@("`@("`@("`@("=T:&5P<F]X>2<L(#0T,RD["F-O;7!A<F4H
M)'@L("1C+"`G<&]R="`T-#,@;F\@<')O=&]C;VP@86YD('!R;WAY('!O<G0@
M-#0S(&YO('!R;W1O8V]L)RD["@HD>"`](&%R<F%Y*`H@("`@)W!A=&@G(#T^
M("=T:&5P871H)RP*("`@("=S97)V97(G(#T^("=T:&5S97)V97(G+`H@("`@
M)W!R;W1O8V]L)R`]/B`G:'1T<#HO+R<L"B`@("`G<&]R="<@/3X@.#`L"B`@
M("`G<')O>'DG(#T^("=T:&5P<F]X>2<L"B`@("`G<')O>'E?<')O=&]C;VPG
M(#T^("=S<VPZ+R\G+`H@("`@)W!R;WAY7W!O<G0G(#T^(#8U-C4L"B`@("`G
M<')O>'E?=7-E<B<@/3X@)R<L"B`@("`G<')O>'E?<&%S<R<@/3X@)R<L"B`@
M("`G97)R;F\G(#T^(#`L"B`@("`G97)R<W1R:6YG)R`]/B`G)RP*("`@("=D
M96)U9R<@/3X@,"P*("`@("=U<V5R;F%M92<@/3X@)R<L"B`@("`G<&%S<W=O
M<F0G(#T^("<G+`HI.PHD8R`](&YE=R!834Q?4E!#7T-L:65N="@G=&AE<&%T
M:"<L("=T:&5S97)V97(G+"`P+`H@("`@("`@("`@("`@("`@("`@("`@("`G
M<W-L.B\O=&AE<')O>'DG+"`V-38U*3L*8V]M<&%R92@D>"P@)&,L("=P;W)T
M(#0T,R!N;R!P<F]T;V-O;"!A;F0@<')O>'D@<&]R="`T-#,@;F\@<')O=&]C
M;VPG*3L*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O=&5S=',O6$U,7U)00R]T97-T<R]E;7!T>2UV86QU92YP
M:'`````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-3`T,B`Q,#4Q-30S,S<S,R`P,C4Q
M,C``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*"B\J*@H@*B!497-T<R!H;W<@=&AE(%A-3%]24$,@<V5R=F5R(&AA
M;F1L97,@<&%R86UE=&5R<R!W:71H(&5M<'1Y('9A;'5E<RX*("H*("H@268@
M>6]U(&%R92!R=6YN:6YG('1H:7,@=&5S="!F<F]M(&$@0U93(&-H96-K;W5T
M+"!Y;W4@;75S="!R96YA;64@=&AE('=O<FMI;F<*("H@9&ER96-T;W)Y(&9R
M;VT@(EA-3%]24$,B('1O(")834PB+@H@*@H@*B!02%`@=F5R<VEO;G,@-"!A
M;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE
M8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@
M:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H
M92!F;VQL;W=I;F<@55)).@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*
M("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I
M="!T:')O=6=H('1H92!W96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L
M:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE
M9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@5V5B(%-E<G9I8V5S"B`J($!P
M86-K86=E("`@(%A-3%]24$,*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I
M<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`R,#`U(%1H
M92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4*("H@0'9E<G-I;VX@("`@
M0U93.B`D260Z(&5M<'1Y+79A;'5E+G!H<"QV(#$N,2`R,#`U+S$P+S$U(#(P
M.C(Y.C0V(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E
M87(N<&AP+FYE="]P86-K86=E+UA-3%]24$,*("H@0'-I;F-E("`@("`@1FEL
M92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N-`H@*B\*"B\J"B`J($EF
M('1H92!P86-K86=E('9E<G-I;VX@;G5M8F5R(&ES(&9O=6YD(&EN('1H92!L
M969T(&AA;F0*("H@<&]R=&EO;B!O9B!T:&4@:68H*2!E>'!R97-S:6]N(&)E
M;&]W+"!T:&%T(&UE86YS('1H:7,@9FEL92!H87,*("H@8V]M92!F<F]M('1H
M92!014%2(&EN<W1A;&QE<BX@(%1H97)E9F]R92P@;&5T)W,@=&5S="!T:&4*
M("H@:6YS=&%L;&5D('9E<G-I;VX@;V8@6$U,7U)00R!W:&EC:"!S:&]U;&0@
M8F4@:6X@=&AE(&EN8VQU9&4@<&%T:"X*("H@"B`J($EF('1H92!V97)S:6]N
M(&AA<R!N;W0@8F5E;B!S=6)S=&ET=71E9"!I;B!T:&4@:68H*2!E>'!R97-S
M:6]N+`H@*B!T:&ES(&9I;&4@:&%S(&QI:V5L>2!C;VUE(&9R;VT@82!#5E,@
M8VAE8VMO=70@;W(@82`N=&%R(&9I;&4N"B`J(%1H97)E9F]R92P@=V4G;&P@
M87-S=6UE('1H92!T97-T<R!S:&]U;&0@=7-E('1H92!V97)S:6]N(&]F"B`J
M(%A-3%]24$,@=&AA="!H87,@8V]M92!F<F]M('1H97)E(&%S('=E;&PN"B`J
M+PII9B`H)S$N-"XX)R`A/2`G0"<N)W!A8VMA9V5?=F5R<VEO;B<N)T`G*2![
M"B`@("`O*BH*("`@("`J($=E="!T:&4@;F5E9&5D(&-L87-S(&9R;VT@=&AE
M(%!%05(@:6YS=&%L;&%T:6]N"B`@("`@*B\*("`@(')E<75I<F5?;VYC92`G
M6$U,+U)00R]397)V97(N<&AP)SL*?2!E;'-E('L*("`@(&EF("AS=6)S='(H
M9&ER;F%M92A?7T9)3$5?7RDL("TY+"`M-BD@(3T@)UA-3"<I('L*("`@("`@
M("!E8VAO(")4:&4@<&%R96YT(&1I<F5C=&]R>2!M=7-T(&)E(&YA;65D("=8
M34PG+EQN(CL*("`@("`@("!E>&ET.PH@("`@?0H*("`@(&EN:5]S970H)VEN
M8VQU9&5?<&%T:"<L("<N+B\N+B\G"B`@("`@("`@("`@("X@4$%42%]315!!
M4D%43U(@+B`G+B<@+B!0051(7U-%4$%2051/4@H@("`@("`@("`@("`N(&EN
M:5]G970H)VEN8VQU9&5?<&%T:"<I"B`@("`I.PH*("`@("\J*@H@("`@("H@
M1V5T('1H92!N965D960@8VQA<W,@9G)O;2!T:&4@<&%R96YT(&1I<F5C=&]R
M>0H@("`@("HO"B`@("!R97%U:7)E7V]N8V4@)RXN+U-E<G9E<BYP:'`G.PI]
M"@HD1TQ/0D%,4ULG2%144%]205=?4$]35%]$051!)UT@/2`\/#Q%3U!/4U0*
M/#]X;6P@=F5R<VEO;CTB,2XP(C\^"CQM971H;V1#86QL/@H@/&UE=&AO9$YA
M;64^86QL9V]T/"]M971H;V1.86UE/@H@(#QP87)A;7,^"B`@(#QP87)A;3X\
M=F%L=64^/'-T<FEN9SX\+W-T<FEN9SX\+W9A;'5E/CPO<&%R86T^"B`@(#QP
M87)A;3X\=F%L=64^9FER<W0\+W9A;'5E/CPO<&%R86T^"B`@(#QP87)A;3X\
M=F%L=64^("`\+W9A;'5E/CPO<&%R86T^"B`@(#QP87)A;3X\=F%L=64^/"]V
M86QU93X\+W!A<F%M/@H@(#PO<&%R86US/@H@/"]M971H;V1#86QL/@I%3U!/
M4U0["@HD97AP96-T(#T@/#P\14]%6%`*/#]X;6P@=F5R<VEO;CTB,2XP(B!E
M;F-O9&EN9STB551&+3@B/SX*/&UE=&AO9%)E<W!O;G-E/@H\<&%R86US/@H\
M<&%R86T^"CQV86QU93X\<W1R:6YG/G!A<F%M(#`Z("<G"G!A<F%M(#$Z("=F
M:7)S="<*<&%R86T@,CH@)R`@)PIP87)A;2`S.B`G)PH\+W-T<FEN9SX\+W9A
M;'5E/@H\+W!A<F%M/@H\+W!A<F%M<SX*/"]M971H;V1297-P;VYS93X*14]%
M6%`["@II;F-L=61E("<N+V%L;&=O="YI;F,G.PH`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T
M<R]834Q?4E!#+W1E<W1S+W1Y<&5S+G!H<```````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`V-#0P(#$P-3$U-#,S-S,S(#`R-#`Q-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`H*+RHJ"B`J(%1E
M<W1S(&AO=R!T:&4@6$U,7U)00R!S97)V97(@:&%N9&QE<R!A(&)U;F-H(&]F
M(&1I9F9E<F5N="!P87)A;65T97(*("H@9&%T82!T>7!E<RX*("H*("H@268@
M>6]U(&%R92!R=6YN:6YG('1H:7,@=&5S="!F<F]M(&$@0U93(&-H96-K;W5T
M+"!Y;W4@;75S="!R96YA;64@=&AE('=O<FMI;F<*("H@9&ER96-T;W)Y(&9R
M;VT@(EA-3%]24$,B('1O(")834PB+@H@*@H@*B!02%`@=F5R<VEO;G,@-"!A
M;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE
M8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@
M:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H
M92!F;VQL;W=I;F<@55)).@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*
M("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I
M="!T:')O=6=H('1H92!W96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L
M:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE
M9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@5V5B(%-E<G9I8V5S"B`J($!P
M86-K86=E("`@(%A-3%]24$,*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I
M<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`R,#`U(%1H
M92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4*("H@0'9E<G-I;VX@("`@
M0U93.B`D260Z('1Y<&5S+G!H<"QV(#$N,2`R,#`U+S$P+S$U(#(P.C(Y.C0V
M(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP
M+FYE="]P86-K86=E+UA-3%]24$,*("H@0'-I;F-E("`@("`@1FEL92!A=F%I
M;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N-`H@*B\*"B\J"B`J($EF('1H92!P
M86-K86=E('9E<G-I;VX@;G5M8F5R(&ES(&9O=6YD(&EN('1H92!L969T(&AA
M;F0*("H@<&]R=&EO;B!O9B!T:&4@:68H*2!E>'!R97-S:6]N(&)E;&]W+"!T
M:&%T(&UE86YS('1H:7,@9FEL92!H87,*("H@8V]M92!F<F]M('1H92!014%2
M(&EN<W1A;&QE<BX@(%1H97)E9F]R92P@;&5T)W,@=&5S="!T:&4*("H@:6YS
M=&%L;&5D('9E<G-I;VX@;V8@6$U,7U)00R!W:&EC:"!S:&]U;&0@8F4@:6X@
M=&AE(&EN8VQU9&4@<&%T:"X*("H@"B`J($EF('1H92!V97)S:6]N(&AA<R!N
M;W0@8F5E;B!S=6)S=&ET=71E9"!I;B!T:&4@:68H*2!E>'!R97-S:6]N+`H@
M*B!T:&ES(&9I;&4@:&%S(&QI:V5L>2!C;VUE(&9R;VT@82!#5E,@8VAE8VMO
M=70@;W(@82`N=&%R(&9I;&4N"B`J(%1H97)E9F]R92P@=V4G;&P@87-S=6UE
M('1H92!T97-T<R!S:&]U;&0@=7-E('1H92!V97)S:6]N(&]F"B`J(%A-3%]2
M4$,@=&AA="!H87,@8V]M92!F<F]M('1H97)E(&%S('=E;&PN"B`J+PII9B`H
M)S$N-"XX)R`A/2`G0"<N)W!A8VMA9V5?=F5R<VEO;B<N)T`G*2!["B`@("`O
M*BH*("`@("`J($=E="!T:&4@;F5E9&5D(&-L87-S(&9R;VT@=&AE(%!%05(@
M:6YS=&%L;&%T:6]N"B`@("`@*B\*("`@(')E<75I<F5?;VYC92`G6$U,+U)0
M0R]397)V97(N<&AP)SL*?2!E;'-E('L*("`@(&EF("AS=6)S='(H9&ER;F%M
M92A?7T9)3$5?7RDL("TY+"`M-BD@(3T@)UA-3"<I('L*("`@("`@("!E8VAO
M(")4:&4@<&%R96YT(&1I<F5C=&]R>2!M=7-T(&)E(&YA;65D("=834PG+EQN
M(CL*("`@("`@("!E>&ET.PH@("`@?0H*("`@(&EN:5]S970H)VEN8VQU9&5?
M<&%T:"<L("<N+B\N+B\G"B`@("`@("`@("`@("X@4$%42%]315!!4D%43U(@
M+B`G+B<@+B!0051(7U-%4$%2051/4@H@("`@("`@("`@("`N(&EN:5]G970H
M)VEN8VQU9&5?<&%T:"<I"B`@("`I.PH*("`@("\J*@H@("`@("H@1V5T('1H
M92!N965D960@8VQA<W,@9G)O;2!T:&4@<&%R96YT(&1I<F5C=&]R>0H@("`@
M("HO"B`@("!R97%U:7)E7V]N8V4@)RXN+U-E<G9E<BYP:'`G.PI]"@HD1TQ/
M0D%,4ULG2%144%]205=?4$]35%]$051!)UT@/2`\/#Q%3U!/4U0*/#]X;6P@
M=F5R<VEO;CTB,2XP(C\^"CQM971H;V1#86QL/@H@/&UE=&AO9$YA;64^86QL
M9V]T/"]M971H;V1.86UE/@H@(#QP87)A;7,^"B`@(#QP87)A;3X\=F%L=64^
M9&5F875L="!T;R!S=')I;F<\+W9A;'5E/CPO<&%R86T^"B`@(#QP87)A;3X\
M=F%L=64^/'-T<FEN9SYI;G-I9&4@<W1R:6YG/"]S=')I;F<^/"]V86QU93X\
M+W!A<F%M/@H@("`\<&%R86T^/'9A;'5E/CQI;G0^.#PO:6YT/CPO=F%L=64^
M/"]P87)A;3X*("`@/'!A<F%M/CQV86QU93X\9&%T971I;64N:7-O.#8P,3XR
M,#`U,#@P.50P,3HS,SHT-#PO9&%T971I;64N:7-O.#8P,3X\+W9A;'5E/CPO
M<&%R86T^"@H@("`\<&%R86T^"B`@("`\=F%L=64^"B`@("`@/&%R<F%Y/@H@
M("`@("`\9&%T83X*("`@("`@(#QV86QU93X*("`@("`@("`\<W1R:6YG/F$\
M+W-T<FEN9SX*("`@("`@(#PO=F%L=64^"B`@("`@("`\=F%L=64^"B`@("`@
M("`@/'-T<FEN9SYB/"]S=')I;F<^"B`@("`@("`\+W9A;'5E/@H@("`@("`\
M+V1A=&$^"B`@("`@/"]A<G)A>3X*("`@(#PO=F%L=64^"B`@(#PO<&%R86T^
M"@H@("`\<&%R86T^"B`@("`\=F%L=64^"B`@("`@/'-T<G5C=#X*("`@("`@
M/&UE;6)E<CX*("`@("`@(#QN86UE/F$\+VYA;64^"B`@("`@("`\=F%L=64^
M"B`@("`@("`@/'-T<FEN9SYA>3PO<W1R:6YG/@H@("`@("`@/"]V86QU93X*
M("`@("`@/"]M96UB97(^"B`@("`@(#QM96UB97(^"B`@("`@("`\;F%M93YB
M/"]N86UE/@H@("`@("`@/'9A;'5E/@H@("`@("`@(#QS=')I;F<^8F4\+W-T
M<FEN9SX*("`@("`@(#PO=F%L=64^"B`@("`@(#PO;65M8F5R/@H@("`@(#PO
M<W1R=6-T/@H@("`@/"]V86QU93X*("`@/"]P87)A;3X*"B`@/"]P87)A;7,^
M"B`\+VUE=&AO9$-A;&P^"D5/4$]35#L*"B1E>'!E8W0@/2`\/#Q%3T584`H\
M/WAM;"!V97)S:6]N/2(Q+C`B(&5N8V]D:6YG/2)55$8M."(_/@H\;65T:&]D
M4F5S<&]N<V4^"CQP87)A;7,^"CQP87)A;3X*/'9A;'5E/CQS=')I;F<^<&%R
M86T@,#H@)V1E9F%U;'0@=&\@<W1R:6YG)PIP87)A;2`Q.B`G:6YS:61E('-T
M<FEN9R<*<&%R86T@,CH@)S@G"G!A<F%M(#,Z("<R,#`U,#@P.50P,3HS,SHT
M-"<*<&%R86T@-#H@87)R87D@*`H@(#`@/29G=#L@)V$G+`H@(#$@/29G=#L@
M)V(G+`HI"G!A<F%M(#4Z(&%R<F%Y("@*("`G82<@/29G=#L@)V%Y)RP*("`G
M8B<@/29G=#L@)V)E)RP**0H\+W-T<FEN9SX\+W9A;'5E/@H\+W!A<F%M/@H\
M+W!A<F%M<SX*/"]M971H;V1297-P;VYS93X*14]%6%`["@II;F-L=61E("<N
M+V%L;&=O="YI;F,G.PH`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S
M=',O6$U,7U)00R]T97-T<R]A;&QG;W0N:6YC````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,S`V,"`Q,#4Q-30S,S<S,R`P,C0Q,3(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*"B\J*@H@*B`*
M("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H
M92!02%`@;&EC96YS90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@
M;F]T(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@
M87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A
M<V4*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A
M;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R
M>2`@(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G92`@("!834Q?4E!#"B`J($!A
M=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*
M("H@0&-O<'ER:6=H="`@,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!A;&QG;W0N:6YC+'8@
M,2XQ(#(P,#4O,3`O,34@,C`Z,CDZ-#8@9&%N:65L8R!%>'`@)`H@*B!`;&EN
M:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O6$U,7U)00PH@
M*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N
M-"XT"B`J+PH*;V)?<W1A<G0H*3L*"F9U;F-T:6]N(')E='5R;D%L;$=O="@D
M<&%R86US*2!["B`@("`D;W5T(#T@)R<["B`@("`D8V]U;G0@/2!C;W5N="@D
M<&%R86US+3YP87)A;7,I.PH@("`@9F]R("@D:2`](#`[("1I(#P@)&-O=6YT
M.R`D:2LK*2!["B`@("`@("`@)'!A<F%M(#T@)'!A<F%M<RT^9V5T4&%R86TH
M)&DI.PH@("`@("`@(&EF("@A6$U,7U)00U]686QU93HZ:7-686QU92@D<&%R
M86TI*2!["B`@("`@("`@("`@("1O=70@+CT@(G!A<F%M971E<B`D:2!W87,@
M97)R;W(Z("1P87)A;5QN(CL*("`@("`@("`@("`@8V]N=&EN=64["B`@("`@
M("`@?0H@("`@("`@("1G;W0@/2!834Q?4E!#7T1E8V]D92@D<&%R86TI.PH@
M("`@("`@("1O=70@+CT@(G!A<F%M("1I.B`B("X@=F%R7V5X<&]R="@D9V]T
M+"!T<G5E*2`N(")<;B(["B`@("!]"B`@("`D=F%L(#T@;F5W(%A-3%]24$-?
M5F%L=64H)&]U="P@)W-T<FEN9R<I.PH@("`@<F5T=7)N(&YE=R!834Q?4E!#
M7U)E<W!O;G-E*"1V86PI.PI]"@HD<V5R=F5R(#T@;F5W(%A-3%]24$-?4V5R
M=F5R*`H@("`@87)R87DH"B`@("`@("`@)V%L;&=O="<@/3X@87)R87DH"B`@
M("`@("`@("`@("=F=6YC=&EO;B<@/3X@)W)E='5R;D%L;$=O="<L"B`@("`@
M("`@*2P*("`@("D**3L*"B1G;W0@/2!O8E]G971?8VQE86XH*3L*"FEF("@D
M9V]T(#T]("1E>'!E8W0I('L*("`@(&5C:&\@(G!A<W-E9%QN(CL*?2!E;'-E
M('L*("`@(&5C:&\@(D9!24Q%1%QN(CL*("`@(&5C:&\@(D5X<&5C=&5D.EQN
M)&5X<&5C=%QN(CL*("`@(&5C:&\@(D=O=#I<;B1G;W1<;B(["GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+UA-
M3%]24$,O=&5S=',O96UP='DM=F%L=64M<W1R=6-T+G!H<```````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#4P-C0@,3`U,34T,S,W,S,@,#(V-#0V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@HO*BH*("H@5&5S=',@
M:&]W('1H92!834Q?4E!#('-E<G9E<B!H86YD;&5S(&$@<&%R86UE=&5R('=I
M=&@@86X@96UP='D@<W1R=6-T('=I=&AO=70*("H@86YY('-P86-E<R!I;B!T
M:&4@6$U,(&%F=&5R('1H92!E;7!T>2!V86QU92X*("H*("H@268@>6]U(&%R
M92!R=6YN:6YG('1H:7,@=&5S="!F<F]M(&$@0U93(&-H96-K;W5T+"!Y;W4@
M;75S="!R96YA;64@=&AE('=O<FMI;F<*("H@9&ER96-T;W)Y(&9R;VT@(EA-
M3%]24$,B('1O(")834PB+@H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@
M*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@
M=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A
M:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL
M;W=I;F<@55)).@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N
M='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE
M(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O
M=6=H('1H92!W96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E
M0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L
M>2X*("H*("H@0&-A=&5G;W)Y("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E
M("`@(%A-3%]24$,*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\
M9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`R,#`U(%1H92!02%`@
M1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,U\P+G1X="`@4$A0($QI8V5N<V4*("H@0'9E<G-I;VX@("`@0U93.B`D
M260Z(&5M<'1Y+79A;'5E+7-T<G5C="YP:'`L=B`Q+C$@,C`P-2\Q,"\Q-2`R
M,#HR.3HT-B!D86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P
M96%R+G!H<"YN970O<&%C:V%G92]834Q?4E!#"B`J($!S:6YC92`@("`@($9I
M;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C0*("HO"@HO*@H@*B!)
M9B!T:&4@<&%C:V%G92!V97)S:6]N(&YU;6)E<B!I<R!F;W5N9"!I;B!T:&4@
M;&5F="!H86YD"B`J('!O<G1I;VX@;V8@=&AE(&EF*"D@97AP<F5S<VEO;B!B
M96QO=RP@=&AA="!M96%N<R!T:&ES(&9I;&4@:&%S"B`J(&-O;64@9G)O;2!T
M:&4@4$5!4B!I;G-T86QL97(N("!4:&5R969O<F4L(&QE="=S('1E<W0@=&AE
M"B`J(&EN<W1A;&QE9"!V97)S:6]N(&]F(%A-3%]24$,@=VAI8V@@<VAO=6QD
M(&)E(&EN('1H92!I;F-L=61E('!A=&@N"B`J(`H@*B!)9B!T:&4@=F5R<VEO
M;B!H87,@;F]T(&)E96X@<W5B<W1I='5T960@:6X@=&AE(&EF*"D@97AP<F5S
M<VEO;BP*("H@=&AI<R!F:6QE(&AA<R!L:6ME;'D@8V]M92!F<F]M(&$@0U93
M(&-H96-K;W5T(&]R(&$@+G1A<B!F:6QE+@H@*B!4:&5R969O<F4L('=E)VQL
M(&%S<W5M92!T:&4@=&5S=',@<VAO=6QD('5S92!T:&4@=F5R<VEO;B!O9@H@
M*B!834Q?4E!#('1H870@:&%S(&-O;64@9G)O;2!T:&5R92!A<R!W96QL+@H@
M*B\*:68@*"<Q+C0N."<@(3T@)T`G+B=P86-K86=E7W9E<G-I;VXG+B=`)RD@
M>PH@("`@+RHJ"B`@("`@*B!'970@=&AE(&YE961E9"!C;&%S<R!F<F]M('1H
M92!014%2(&EN<W1A;&QA=&EO;@H@("`@("HO"B`@("!R97%U:7)E7V]N8V4@
M)UA-3"]24$,O4V5R=F5R+G!H<"<["GT@96QS92!["B`@("!I9B`H<W5B<W1R
M*&1I<FYA;64H7U]&24Q%7U\I+"`M.2P@+38I("$]("=834PG*2!["B`@("`@
M("`@96-H;R`B5&AE('!A<F5N="!D:7)E8W1O<GD@;75S="!B92!N86UE9"`G
M6$U,)RY<;B(["B`@("`@("`@97AI=#L*("`@('T*"B`@("!I;FE?<V5T*"=I
M;F-L=61E7W!A=&@G+"`G+BXO+BXO)PH@("`@("`@("`@("`N(%!!5$A?4T50
M05)!5$]2("X@)RXG("X@4$%42%]315!!4D%43U(*("`@("`@("`@("`@+B!I
M;FE?9V5T*"=I;F-L=61E7W!A=&@G*0H@("`@*3L*"B`@("`O*BH*("`@("`J
M($=E="!T:&4@;F5E9&5D(&-L87-S(&9R;VT@=&AE('!A<F5N="!D:7)E8W1O
M<GD*("`@("`J+PH@("`@<F5Q=6ER95]O;F-E("<N+B]397)V97(N<&AP)SL*
M?0H*)$=,3T)!3%-;)TA45%!?4D%77U!/4U1?1$%402==(#T@/#P\14]03U-4
M"CP_>&UL('9E<G-I;VX](C$N,"(_/@H\;65T:&]D0V%L;#X*(#QM971H;V1.
M86UE/F%L;&=O=#PO;65T:&]D3F%M93X*("`\<&%R86US/@H@("`\<&%R86T^
M"B`@("`\=F%L=64^"B`@("`@/'-T<G5C=#X*("`@("`@/&UE;6)E<CX*("`@
M("`@/&YA;64^9FQD,3PO;F%M93X\=F%L=64^/"]V86QU93X\+VUE;6)E<CX\
M+W-T<G5C=#X\+W9A;'5E/@H@("`\+W!A<F%M/@H@(#PO<&%R86US/@H@/"]M
M971H;V1#86QL/@I%3U!/4U0["@HD97AP96-T(#T@/#P\14]%6%`*/#]X;6P@
M=F5R<VEO;CTB,2XP(B!E;F-O9&EN9STB551&+3@B/SX*/&UE=&AO9%)E<W!O
M;G-E/@H\<&%R86US/@H\<&%R86T^"CQV86QU93X\<W1R:6YG/G!A<F%M(#`Z
M(&%R<F%Y("@*("`G9FQD,2<@/29G=#L@)R<L"BD*/"]S=')I;F<^/"]V86QU
M93X*/"]P87)A;3X*/"]P87)A;7,^"CPO;65T:&]D4F5S<&]N<V4^"D5/15A0
M.PH*:6YC;'5D92`G+B]A;&QG;W0N:6YC)SL*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O3&]G````````````````````
M````````````````````````````````````````````````````````````
M```P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S
M,S<S,R`P,C`R-S(`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R],
M;V<O=&5S=',`````````````````````````````````````````````````
M`````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,#`P(#$P-3$U-#,S-S,S(#`R,30S-``@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+W1E<W1S+TQO9R]T97-T<R]C;VUP;W-I=&4N<&AP=```````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$T-3(@,3`U,34T,S,W,S,@,#(T-#$T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"TM
M5$535"TM"DQO9SH@0V]M<&]S:71E($AA;F1L97(*+2U&24Q%+2T*/#]P:'`*
M"G)E<75I<F5?;VYC92`G3&]G+G!H<"<["@HD8V]N9B`](&%R<F%Y*"=L:6YE
M1F]R;6%T)R`]/B`G)3(D<R!;)3,D<UT@)30D<R<I.PHD8V]N<V]L93$@/2`F
M3&]G.CIS:6YG;&5T;VXH)V-O;G-O;&4G+"`G)RP@)T-/3E-/3$4Q)RP@)&-O
M;F8I.PHD8V]N<V]L93(@/2`F3&]G.CIS:6YG;&5T;VXH)V-O;G-O;&4G+"`G
M)RP@)T-/3E-/3$4R)RP@)&-O;F8I.PH*)&-O;7!O<VET92`]("9,;V<Z.G-I
M;F=L971O;B@G8V]M<&]S:71E)RD["B1C;VUP;W-I=&4M/F%D9$-H:6QD*"1C
M;VYS;VQE,2D["B1C;VUP;W-I=&4M/F%D9$-H:6QD*"1C;VYS;VQE,BD["@HD
M8V]M<&]S:71E+3YL;V<H)U1H:7,@979E;G0@=VEL;"!B92!L;V=G960@=&\@
M8F]T:"!H86YD;&5R<RXG*3L*"B1C;VUP;W-I=&4M/G-E=$ED96YT*"=)1$5.
M5"<I.PIE8VAO("1C;VUP;W-I=&4M/F=E=$ED96YT*"D@+B`B7&XB.PH*)&-O
M;7!O<VET92T^;&]G*"=4:&ES(&5V96YT('=I;&P@8F4@;&]G9V5D('1O(&)O
M=&@@:&%N9&QE<G,N)RD["@HM+4584$5#5"TM"D-/3E-/3$4Q(%MI;F9O72!4
M:&ES(&5V96YT('=I;&P@8F4@;&]G9V5D('1O(&)O=&@@:&%N9&QE<G,N"D-/
M3E-/3$4R(%MI;F9O72!4:&ES(&5V96YT('=I;&P@8F4@;&]G9V5D('1O(&)O
M=&@@:&%N9&QE<G,N"DE$14Y4"DE$14Y4(%MI;F9O72!4:&ES(&5V96YT('=I
M;&P@8F4@;&]G9V5D('1O(&)O=&@@:&%N9&QE<G,N"DE$14Y4(%MI;F9O72!4
M:&ES(&5V96YT('=I;&P@8F4@;&]G9V5D('1O(&)O=&@@:&%N9&QE<G,N"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+W1E<W1S+TQO9R]T97-T<R]D:7-P;&%Y+G!H<'0`
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$P-S(@,3`U,34T,S,W,S,@
M,#(T,#4U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"TM5$535"TM"DQO9SH@1&ES<&QA>2!(86YD;&5R"BTM1DE,12TM"CP_
M<&AP"@IR97%U:7)E7V]N8V4@)TQO9RYP:'`G.PH*)&-O;F8@/2!A<G)A>2@G
M97)R;W)?<')E<&5N9"<@/3X@)SQT=#XG+`H@("`@("`@("`@("`@("=E<G)O
M<E]A<'!E;F0G("`]/B`G/"]T=#XG+`H@("`@("`@("`@("`@("=L:6YE8G)E
M86LG("`@("`]/B`B/&)R("\^/&)R("\^7&XB*3L*)&QO9V=E<B`]("9,;V<Z
M.G-I;F=L971O;B@G9&ES<&QA>2<L("<G+"`G)RP@)&-O;F8I.PIF;W(@*"1I
M(#T@,#L@)&D@/"`S.R`D:2LK*2!["@DD;&]G9V5R+3YL;V<H(DQO9R!E;G1R
M>2`D:2(I.PI]"B1L;V=G97(M/FQO9R@B375L=&E<;DQI;F5<;D5N=')Y(BD[
M"@HM+4584$5#5"TM"CQT=#X\8CY);F9O/"]B/CH@3&]G(&5N=')Y(#`\+W1T
M/CQB<B`O/CQB<B`O/@H\='0^/&(^26YF;SPO8CXZ($QO9R!E;G1R>2`Q/"]T
M=#X\8G(@+SX\8G(@+SX*/'1T/CQB/DEN9F\\+V(^.B!,;V<@96YT<GD@,CPO
M='0^/&)R("\^/&)R("\^"CQT=#X\8CY);F9O/"]B/CH@375L=&D\8G(@+SX*
M3&EN93QB<B`O/@I%;G1R>3PO='0^/&)R("\^/&)R("\^"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+TQO9R]T97-T<R]E<G)O<E]L
M;V<N<&AP=```````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`T,C,@,3`U,34T
M,S,W,S,@,#(T-#`Q`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"TM5$535"TM"DQO9SH@17)R;W)?3&]G($AA;F1L97(*+2U&
M24Q%+2T*/#]P:'`*"G)E<75I<F5?;VYC92`G3&]G+G!H<"<["@HD;&]G9V5R
M(#T@)DQO9SHZ<VEN9VQE=&]N*"=E<G)O<E]L;V<G+"!014%27TQ/1U]465!%
M7U-94U1%32P@)VED96YT)RD["F9O<B`H)&D@/2`P.R`D:2`\(#,[("1I*RLI
M('L*"21L;V=G97(M/FQO9R@B3&]G(&5N=')Y("1I(BD["GT*"BTM15A014-4
M+2T*:61E;G0Z($QO9R!E;G1R>2`P"FED96YT.B!,;V<@96YT<GD@,0II9&5N
M=#H@3&]G(&5N=')Y(#(*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]T97-T<R],;V<O=&5S=',O97AT<F%C="YP:'!T````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,S4Q(#$P-3$U-#,S-S,S(#`R-#`V
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````M
M+51%4U0M+0I,;V<Z(%]E>'1R86-T365S<V%G92@I(%M:96YD($5N9VEN92`Q
M70HM+5-+25!)1BTM"CP_<&AP(&EF("AV97)S:6]N7V-O;7!A<F4H>F5N9%]V
M97)S:6]N*"DL("(R+C`N,"(L("(^/2(I*2!D:64H)W-K:7`G*3L@/SX*+2U&
M24Q%+2T*/#]P:'`*"G)E<75I<F5?;VYC92`G3&]G+G!H<"<["@HD8V]N9B`]
M(&%R<F%Y*"=L:6YE1F]R;6%T)R`]/B`G)3(D<R!;)3,D<UT@)30D<R<I.PHD
M;&]G9V5R(#T@)DQO9SHZ<VEN9VQE=&]N*"=C;VYS;VQE)RP@)R<L("=I9&5N
M="<L("1C;VYF*3L*"B\J($QO9V=I;F<@82!R96=U;&%R('-T<FEN9RX@*B\*
M)&QO9V=E<BT^;&]G*"=3=')I;F<G*3L*"B\J($QO9V=I;F<@82!B87)E(&]B
M:F5C="X@*B\*8VQA<W,@0F%R94]B:F5C="![?0HD;&]G9V5R+3YL;V<H;F5W
M($)A<F5/8FIE8W0H*2D["@HO*B!,;V=G:6YG(&%N(&]B:F5C="!W:71H(&$@
M9V5T365S<V%G92@I(&UE=&AO9"X@*B\*8VQA<W,@1V5T365S<V%G94]B:F5C
M="![(&9U;F-T:6]N(&=E=$UE<W-A9V4H*2![(')E='5R;B`B9V5T365S<V%G
M92([('T@?0HD;&]G9V5R+3YL;V<H;F5W($=E=$UE<W-A9V5/8FIE8W0H*2D[
M"@HO*B!,;V=G:6YG(&%N(&]B:F5C="!W:71H(&$@=&]3=')I;F<H*2!M971H
M;V0N("HO"F-L87-S(%1O4W1R:6YG3V)J96-T('L@9G5N8W1I;VX@=&]3=')I
M;F<H*2![(')E='5R;B`B=&]3=')I;F<B.R!]('T*)&QO9V=E<BT^;&]G*&YE
M=R!4;U-T<FEN9T]B:F5C="@I*3L*"B\J($QO9V=I;F<@82!014%27T5R<F]R
M(&]B:F5C="X@*B\*<F5Q=6ER95]O;F-E("=014%2+G!H<"<["B1L;V=G97(M
M/FQO9RAN97<@4$5!4E]%<G)O<B@G4$5!4E]%<G)O<B!O8FIE8W0G+"`Q,#`I
M*3L*"B\J($QO9V=I;F<@86X@87)R87DN("HO"B1L;V=G97(M/FQO9RAA<G)A
M>2@Q+"`R+"`G=&AR964G(#T^(#,I*3L*"B\J($QO9V=I;F<@86X@87)R87D@
M=VET:"!A("=M97-S86=E)R!K97DN("HO"B1L;V=G97(M/FQO9RAA<G)A>2@G
M;65S<V%G92<@/3X@)TUE<W-A9V4@2V5Y)RDI.PH*+2U%6%!%0U0M+0II9&5N
M="!;:6YF;UT@4W1R:6YG"FED96YT(%MI;F9O72!B87)E;V)J96-T($]B:F5C
M=`HH"BD*"FED96YT(%MI;F9O72!G971-97-S86=E"FED96YT(%MI;F9O72!T
M;U-T<FEN9PII9&5N="!;:6YF;UT@4$5!4E]%<G)O<B!O8FIE8W0*:61E;G0@
M6VEN9F]=($%R<F%Y"B@*("`@(%LP72`]/B`Q"B`@("!;,5T@/3X@,@H@("`@
M6W1H<F5E72`]/B`S"BD*"FED96YT(%MI;F9O72!-97-S86=E($ME>0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+TQO9R]T
M97-T<R]E>'1R86-T,BYP:'!T````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#(V-C$@,3`U,34T,S,W,S,@,#(T,34Q`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"TM5$535"TM"DQO9SH@7V5X=')A8W1-
M97-S86=E*"D@6UIE;F0@16YG:6YE(#)="BTM4TM)4$E&+2T*/#]P:'`@:68@
M*'9E<G-I;VY?8V]M<&%R92AZ96YD7W9E<G-I;VXH*2P@(C(N,"XP(BP@(CPB
M*2D@9&EE*"=S:VEP)RD[(#\^"BTM1DE,12TM"CP_<&AP"@IR97%U:7)E7V]N
M8V4@)TQO9RYP:'`G.PH*)&-O;F8@/2!A<G)A>2@G;&EN949O<FUA="<@/3X@
M)R4R)',@6R4S)'-=("4T)',G*3L*)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O
M;B@G8V]N<V]L92<L("<G+"`G:61E;G0G+"`D8V]N9BD["@HO*B!,;V=G:6YG
M(&$@<F5G=6QA<B!S=')I;F<N("HO"B1L;V=G97(M/FQO9R@G4W1R:6YG)RD[
M"@HO*B!,;V=G:6YG(&$@8F%R92!O8FIE8W0N("HO"F-L87-S($)A<F5/8FIE
M8W0@>WT*)&QO9V=E<BT^;&]G*&YE=R!"87)E3V)J96-T*"DI.PH*+RH@3&]G
M9VEN9R!A;B!O8FIE8W0@=VET:"!A(&=E=$UE<W-A9V4H*2!M971H;V0N("HO
M"F-L87-S($=E=$UE<W-A9V5/8FIE8W0@>R!F=6YC=&EO;B!G971-97-S86=E
M*"D@>R!R971U<FX@(F=E=$UE<W-A9V4B.R!]('T*)&QO9V=E<BT^;&]G*&YE
M=R!'971-97-S86=E3V)J96-T*"DI.PH*+RH@3&]G9VEN9R!A;B!O8FIE8W0@
M=VET:"!A('1O4W1R:6YG*"D@;65T:&]D+B`J+PIC;&%S<R!4;U-T<FEN9T]B
M:F5C="![(&9U;F-T:6]N('1O4W1R:6YG*"D@>R!R971U<FX@(G1O4W1R:6YG
M(CL@?2!]"B1L;V=G97(M/FQO9RAN97<@5&]3=')I;F=/8FIE8W0H*2D["@HO
M*B!,;V=G:6YG(&%N(&]B:F5C="!W:71H(&$@7U]T;U-T<FEN9R@I(&UE=&AO
M9"!U<VEN9R!C87-T:6YG+B`J+PIC;&%S<R!#87-T86)L94]B:F5C="![(&9U
M;F-T:6]N(%]?=&]3=')I;F<H*2![(')E='5R;B`B7U]T;U-T<FEN9R([('T@
M?0HD;&]G9V5R+3YL;V<H;F5W($-A<W1A8FQE3V)J96-T*"DI.PH*+RH@3&]G
M9VEN9R!A(%!%05)?17)R;W(@;V)J96-T+B`J+PIR97%U:7)E7V]N8V4@)U!%
M05(N<&AP)SL*)&QO9V=E<BT^;&]G*&YE=R!014%27T5R<F]R*"=014%27T5R
M<F]R(&]B:F5C="<L(#$P,"DI.PH*+RH@3&]G9VEN9R!A;B!A<G)A>2X@*B\*
M)&QO9V=E<BT^;&]G*&%R<F%Y*#$L(#(L("=T:')E92<@/3X@,RDI.PH*+RH@
M3&]G9VEN9R!A;B!A<G)A>2!W:71H(&$@)VUE<W-A9V4G(&ME>2X@*B\*)&QO
M9V=E<BT^;&]G*&%R<F%Y*"=M97-S86=E)R`]/B`G365S<V%G92!+97DG*2D[
M"@HM+4584$5#5"TM"FED96YT(%MI;F9O72!3=')I;F<*:61E;G0@6VEN9F]=
M($)A<F5/8FIE8W0@3V)J96-T"B@**0H*:61E;G0@6VEN9F]=(&=E=$UE<W-A
M9V4*:61E;G0@6VEN9F]=('1O4W1R:6YG"FED96YT(%MI;F9O72!/8FIE8W0@
M:60@(S(*:61E;G0@6VEN9F]=(%!%05)?17)R;W(@;V)J96-T"FED96YT(%MI
M;F9O72!!<G)A>0HH"B`@("!;,%T@/3X@,0H@("`@6S%=(#T^(#(*("`@(%MT
M:')E95T@/3X@,PHI"@II9&5N="!;:6YF;UT@365S<V%G92!+97D*````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O=&5S=',O3&]G+W1E<W1S+V9A8W1O<GDN<&AP=```````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#8R-2`Q,#4Q-30S,S<S,R`P,C0P
M-C(`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+2U415-4+2T*3&]G.B!&86-T;W)Y"BTM1DE,12TM"CP_<&AP"@IR97%U:7)E
M7V]N8V4@)TQO9RYP:'`G.PH*)&-O;G-O;&4Q(#T@)DQO9SHZ9F%C=&]R>2@G
M8V]N<V]L92<I.PHD8V]N<V]L93(@/2`F3&]G.CIF86-T;W)Y*"=C;VYS;VQE
M)RD["@II9B`H:7-?82@D8V]N<V]L93$L("=,;V=?8V]N<V]L92<I("8F(&ES
M7V$H)&-O;G-O;&4R+"`G3&]G7V-O;G-O;&4G*2D*>PH)96-H;R`B5'=O($QO
M9U]C;VYS;VQE(&]B:F5C=',N7&XB.PI]"@II9B`H)&-O;G-O;&4Q+3Y?:60@
M(3T@)&-O;G-O;&4R+3Y?:60I('L*"65C:&\@(E1H92!O8FIE8W1S(&AA=F4@
M9&EF9F5R96YT($E$<RY<;B(["GT*"BTM15A014-4+2T*5'=O($QO9U]C;VYS
M;VQE(&]B:F5C=',N"E1H92!O8FIE8W1S(&AA=F4@9&EF9F5R96YT($E$<RX*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+W1E<W1S+TQO9R]T97-T<R]F:6QE+G!H<'0`````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#$Q-C(@,3`U,34T,S,W,S,@,#(S,S(W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"TM5$535"TM"DQO
M9SH@1FEL92!(86YD;&5R"BTM1DE,12TM"CP_<&AP"@IR97%U:7)E7V]N8V4@
M)TQO9RYP:'`G.PH*)&9I;&5N86UE(#T@9&ER;F%M92A?7T9)3$5?7RD@+B!$
M25)%0U1/4EE?4T5005)!5$]2("X@)W1E<W0N;&]G)SL*:68@*&9I;&5?97AI
M<W1S*"1F:6QE;F%M92DI('5N;&EN:R@D9FEL96YA;64I.PH*+RH@5W)I=&4@
M<V]M92!E;G1R:65S('1O('1H92!L;V<@9FEL92X@*B\*)&-O;F8@/2!A<G)A
M>2@G;&EN949O<FUA="<@/3X@)R4R)',@6R4S)'-=("4T)',G*3L*)&QO9V=E
M<B`]("9,;V<Z.G-I;F=L971O;B@G9FEL92<L("1F:6QE;F%M92P@)R<L("1C
M;VYF*3L*"F9O<B`H)&D@/2`P.R`D:2`\(#,[("1I*RLI('L*"21L;V=G97(M
M/FQO9R@B3&]G(&5N=')Y("1I(BD["GT*)&QO9V=E<BT^8VQO<V4H*3L*"B\J
M($1U;7`@=&AE(&-O;G1E;G1S(&]F('1H92!L;V<@9FEL92X@*B\*96-H;R!F
M:6QE7V=E=%]C;VYT96YT<R@D9FEL96YA;64I.PH*+RH@0VQE86X@=7`N("HO
M"FEF("AF:6QE7V5X:7-T<R@D9FEL96YA;64I*2!U;FQI;FLH)&9I;&5N86UE
M*3L*"BTM15A014-4+2T*(%MI;F9O72!,;V<@96YT<GD@,`H@6VEN9F]=($QO
M9R!E;G1R>2`Q"B!;:6YF;UT@3&]G(&5N=')Y(#(*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+W1E<W1S+TQO9R]T97-T<R]L979E;',N<&AP=```````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#$U-S0@,3`U,34T,S,W,S,@,#(S-S$Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"TM5$53
M5"TM"DQO9SH@3&5V96QS"BTM1DE,12TM"CP_<&AP"@IR97%U:7)E7V]N8V4@
M)TQO9RYP:'`G.PH*9G5N8W1I;VX@=F5R:69Y*"1E>'`L("1M<V<I"GL*("`@
M(&5C:&\@)&US9R`N("<Z("<["B`@("!E8VAO("@D97AP*2`_("=P87-S)R`Z
M("=F86EL)SL*("`@(&5C:&\@(EQN(CL*?0H*9G5N8W1I;VX@=&5S=$QE=F5L
M<R@D;6%S:RD*>PH@("`@96-H;R`B36%S:SH@)&UA<VM<;B(["@H@("`@9F]R
M("@D<')I;W)I='D@/2!014%27TQ/1U]%34521SL@)'!R:6]R:71Y(#P](%!%
M05)?3$]'7T1%0E5'.R`D<')I;W)I='DK*RD@>PH@("`@("`@("1M87-K960@
M/2`H3&]G.CI-05-+*"1P<FEO<FET>2D@)B`D;6%S:RD["B`@("`@("`@96-H
M;R`B4')I;W)I='D@)'!R:6]R:71Y.B`B.PH@("`@("`@(&5C:&\H)&UA<VME
M9"D@/R`B;6%S:V5D7&XB(#H@(G5N;6%S:V5D7&XB.PH@("`@?0I]"@IT97-T
M3&5V96QS*$QO9SHZ34E.*%!%05)?3$]'7U=!4DY)3D<I*3L*96-H;R`B7&XB
M.PIT97-T3&5V96QS*$QO9SHZ34%8*%!%05)?3$]'7U=!4DY)3D<I*3L*"BTM
M15A014-4+2T*36%S:SH@,C0P"E!R:6]R:71Y(#`Z('5N;6%S:V5D"E!R:6]R
M:71Y(#$Z('5N;6%S:V5D"E!R:6]R:71Y(#(Z('5N;6%S:V5D"E!R:6]R:71Y
M(#,Z('5N;6%S:V5D"E!R:6]R:71Y(#0Z(&UA<VME9`I0<FEO<FET>2`U.B!M
M87-K960*4')I;W)I='D@-CH@;6%S:V5D"E!R:6]R:71Y(#<Z(&UA<VME9`H*
M36%S:SH@,S$*4')I;W)I='D@,#H@;6%S:V5D"E!R:6]R:71Y(#$Z(&UA<VME
M9`I0<FEO<FET>2`R.B!M87-K960*4')I;W)I='D@,SH@;6%S:V5D"E!R:6]R
M:71Y(#0Z(&UA<VME9`I0<FEO<FET>2`U.B!U;FUA<VME9`I0<FEO<FET>2`V
M.B!U;FUA<VME9`I0<FEO<FET>2`W.B!U;FUA<VME9`H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+W1E<W1S+TQO9R]T97-T<R]N=6QL+G!H<'0`````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`R-C$@,3`U,34T,S,W,S,@,#(S
M,S8Q`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"TM5$535"TM"DQO9SH@3G5L;"!(86YD;&5R"BTM1DE,12TM"CP_<&AP"@IR
M97%U:7)E7V]N8V4@)TQO9RYP:'`G.PH*)&QO9V=E<B`]("9,;V<Z.G-I;F=L
M971O;B@G;G5L;"<I.PIF;W(@*"1I(#T@,#L@)&D@/"`S.R`D:2LK*2!["@DD
M;&]G9V5R+3YL;V<H(DQO9R!E;G1R>2`D:2(I.PI]"@HM+4584$5#5"TM"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]T97-T<R],;V<O=&5S=',O<')I;W)I='DN<&AP=```````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`Q,S(W(#$P-3$U-#,S-S,S(#`R-#(W-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````M+51%4U0M+0I,
M;V<Z(%!R:6]R:71I97,*+2U&24Q%+2T*/#]P:'`*"G)E<75I<F5?;VYC92`G
M3&]G+G!H<"<["@HD8V]N9B`](&%R<F%Y*"=L:6YE1F]R;6%T)R`]/B`G6R4S
M)'-=("4T)',G*3L*)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O;B@G8V]N<V]L
M92<L("<G+"`G:61E;G0G+"`D8V]N9BD["@HO*B!,;V<@870@=&AE(&1E9F%U
M;'0@4$5!4E],3T=?24Y&3R!L979E;"X@*B\*)&QO9V=E<BT^;&]G*"=,;V<@
M;65S<V%G92<I.PH*+RH@4V5T('1H92!D969A=6QT('!R:6]R:71Y('1O(%!%
M05)?3$]'7T1%0E5'+B`J+PHD;&]G9V5R+3YS9710<FEO<FET>2A014%27TQ/
M1U]$14)51RD["B1L;V=G97(M/FQO9R@G3&]G(&UE<W-A9V4G*3L*"B\J(%9E
M<FEF>2!T:&%T('1H92!G9710<FEO<FET>2@I(&UE=&AO9"!A;'-O('1H:6YG
M<R!W92=R92!A="!014%27TQ/1U]$14)51RX@*B\*)'!R:6]R:71Y(#T@)&QO
M9V=E<BT^<')I;W)I='E4;U-T<FEN9R@D;&]G9V5R+3YG9710<FEO<FET>2@I
M*3L*96-H;R`B)'!R:6]R:71Y7&XB.PH*+RH@5F5R:69Y('1H870@<W1R:6YG
M5&]0<FEO<FET>2@I(&-A;B!C;VYV97)T(&)A8VL@=&\@82!C;VYS=&%N="X@
M*B\*)'!R:6]R:71Y(#T@)&QO9V=E<BT^<W1R:6YG5&]0<FEO<FET>2@D<')I
M;W)I='DI.PIE8VAO("(D<')I;W)I='E<;B(["@HM+4584$5#5"TM"EMI;F9O
M72!,;V<@;65S<V%G90I;9&5B=6==($QO9R!M97-S86=E"F1E8G5G"C<*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]T97-T<R],;V<O=&5S=',O<VEN9VQE=&]N+G!H<'0`````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`P-C(W(#$P-3$U-#,S-S,S(#`R-#0Q-P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````M+51%
M4U0M+0I,;V<Z(%-I;F=L971O;@HM+49)3$4M+0H\/W!H<`H*<F5Q=6ER95]O
M;F-E("=,;V<N<&AP)SL*"B1C;VYS;VQE,2`]("9,;V<Z.G-I;F=L971O;B@G
M8V]N<V]L92<I.PHD8V]N<V]L93(@/2`F3&]G.CIS:6YG;&5T;VXH)V-O;G-O
M;&4G*3L*"FEF("AI<U]A*"1C;VYS;VQE,2P@)TQO9U]C;VYS;VQE)RD@)B8@
M:7-?82@D8V]N<V]L93(L("=,;V=?8V]N<V]L92<I*0I["@EE8VAO(")4=V\@
M3&]G7V-O;G-O;&4@;V)J96-T<RY<;B(["GT*"FEF("@D8V]N<V]L93$M/E]I
M9"`]/2`D8V]N<V]L93(M/E]I9"D@>PH)96-H;R`B5&AE(&]B:F5C=',@:&%V
M92!T:&4@<V%M92!)1"Y<;B(["GT*"BTM15A014-4+2T*5'=O($QO9U]C;VYS
M;VQE(&]B:F5C=',N"E1H92!O8FIE8W1S(&AA=F4@=&AE('-A;64@240N"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S
M=',O3&]G+W1E<W1S+W-Q;&ET92YP:'!T````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,3(U-R`Q,#4Q-30S,S<S,R`P,C,W,38`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+2U415-4+2T*3&]G.B!3
M<6QI=&4@2&%N9&QE<@HM+5-+25!)1BTM"CP_<&AP(&EF("@A9G5N8W1I;VY?
M97AI<W1S*"=S<6QI=&5?;W!E;B<I*2!D:64H(G-K:7!<;B(I.R`_/@HM+49)
M3$4M+0H\/W!H<`H*<F5Q=6ER95]O;F-E("=,;V<N<&AP)SL*"B1F:6QE;F%M
M92`](&1I<FYA;64H7U]&24Q%7U\I("X@1$E214-43U)97U-%4$%2051/4B`N
M("=S<6QI=&4M;&]G+F1B)SL*:68@*&9I;&5?97AI<W1S*"1F:6QE;F%M92DI
M('5N;&EN:R@D9FEL96YA;64I.PH*)&1B(#T@<W%L:71E7V]P96XH)&9I;&5N
M86UE+"`P-C8V+"`D97)R;W(I.PHD:61E;G0@/2!T:6UE*"D["B1M97-S86=E
M(#T@)VQO9V=I;F<@86X@979E;G0G.PHD;&]G9V5R(#TF($QO9SHZ9F%C=&]R
M>2@G<W%L:71E)RP@)VQO9U]T86)L92<L("1I9&5N="P@)&1B*3L*)&QO9V=E
M<BT^;&]G*"1M97-S86=E+"!014%27TQ/1U]705).24Y'*3L*"B1Q(#T@(E-%
M3$5#5"!M97-S86=E($923TT@;&]G7W1A8FQE(%=(15)%(&ED96YT/2<D:61E
M;G0G(CL*)')E<R`]('-Q;&ET95]Q=65R>2@D9&(L("1Q*3L*:68@*'-Q;&ET
M95]F971C:%]S=')I;F<H)')E<RD@/3T@)&UE<W-A9V4I('L*"65C:&\@)V]K
M)SL*?0H*<W%L:71E7V-L;W-E*"1D8BD["FEF("AF:6QE7V5X:7-T<R@D9FEL
M96YA;64I*2!U;FQI;FLH)&9I;&5N86UE*3L*"BTM15A014-4+2T*;VL*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O=&5S=',O3&]G+W1E<W1S+W-Q;%]I9&5N="YP:'!T````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#<Q,B`Q,#4Q-30S,S<S,R`P,C0S-S(`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+2U415-4+2T*
M3&]G.B!344P@<V5T261E;G0H*0HM+5-+25!)1BTM"CP_<&AP"@IR97%U:7)E
M7V]N8V4@)U!%05(O4F5G:7-T<GDN<&AP)SL*)')E9VES=')Y(#T@)FYE=R!0
M14%27U)E9VES=')Y*"D["@II9B`H(21R96=I<W1R>2T^<&%C:V%G945X:7-T
M<R@G1$(G*2D@9&EE*")S:VEP7&XB*3L*+2U&24Q%+2T*/#]P:'`*"G)E<75I
M<F5?;VYC92`G3&]G+G!H<"<["@HD:61E;G0@/2`G,3(S-#4V-S@Y,#$R,S0U
M-C<X.3`G.PH*)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O;B@G<W%L)RP@)VQO
M9U]T86)L92<L("1I9&5N="P@87)R87DH)V1S;B<@/3X@)R<I*3L*96-H;R`D
M;&]G9V5R+3YG971)9&5N="@I("X@(EQN(CL*"B1L;V=G97(M/G-E=$ED96YT
M*"1I9&5N="D["F5C:&\@)&QO9V=E<BT^9V5T261E;G0H*2`N(")<;B(["@HM
M+4584$5#5"TM"C$R,S0U-C<X.3`Q,C,T-38*,3(S-#4V-S@Y,#$R,S0U-@H`
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+TQO
M9R]T97-T<R]C;VYS;VQE+G!H<'0`````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#(Q-S<@,3`U,34T,S,W,S,@,#(T,#8Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"TM5$535"TM"DQO9SH@0V]N<V]L
M92!(86YD;&5R"BTM1DE,12TM"CP_<&AP"@IR97%U:7)E7V]N8V4@)TQO9RYP
M:'`G.PH*)&-O;F8@/2!A<G)A>2@G;&EN949O<FUA="<@/3X@)R4R)',@6R4S
M)'-=("4T)',G*3L*)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O;B@G8V]N<V]L
M92<L("<G+"`G:61E;G0G+"`D8V]N9BD["F9O<B`H)&D@/2`P.R`D:2`\(#,[
M("1I*RLI('L*"21L;V=G97(M/FQO9R@B3&]G(&5N=')Y("1I(BD["GT*"F5C
M:&\@(EQN6T)U9F9E<FEN9R`O($9L=7-H(%1E<W1=7&XB.PHD8V]N9B`](&%R
M<F%Y*"=L:6YE1F]R;6%T)R`]/B`G)3(D<R!;)3,D<UT@)30D<R<L("=B=69F
M97)I;F<G(#T^('1R=64I.PHD8G5F9F5R961?;&]G9V5R(#T@)DQO9SHZ<VEN
M9VQE=&]N*"=C;VYS;VQE)RP@)R<L("=B=69F97)E9"<L("1C;VYF*3L*9F]R
M("@D:2`](#`[("1I(#P@,SL@)&DK*RD@>PH@("`@)&)U9F9E<F5D7VQO9V=E
M<BT^;&]G*")0<F4M9FQU<V@@8G5F9F5R960@;&]G(&5N=')Y("1I(BD["GT*
M96-H;R`B4')E+69L=7-H7&XB.PHD8G5F9F5R961?;&]G9V5R+3YF;'5S:"@I
M.PIE8VAO(")0;W-T+69L=7-H7&XB.PIF;W(@*"1I(#T@,#L@)&D@/"`S.R`D
M:2LK*2!["B`@("`D8G5F9F5R961?;&]G9V5R+3YL;V<H(E!O<W0M9FQU<V@@
M8G5F9F5R960@;&]G(&5N=')Y("1I(BD["GT*96-H;R`B4VAU=&1O=VY<;B([
M"B1B=69F97)E9%]L;V=G97(M/F-L;W-E*"D["@HM+4584$5#5"TM"FED96YT
M(%MI;F9O72!,;V<@96YT<GD@,`II9&5N="!;:6YF;UT@3&]G(&5N=')Y(#$*
M:61E;G0@6VEN9F]=($QO9R!E;G1R>2`R"@I;0G5F9F5R:6YG("\@1FQU<V@@
M5&5S=%T*4')E+69L=7-H"F)U9F9E<F5D(%MI;F9O72!0<F4M9FQU<V@@8G5F
M9F5R960@;&]G(&5N=')Y(#`*8G5F9F5R960@6VEN9F]=(%!R92UF;'5S:"!B
M=69F97)E9"!L;V<@96YT<GD@,0IB=69F97)E9"!;:6YF;UT@4')E+69L=7-H
M(&)U9F9E<F5D(&QO9R!E;G1R>2`R"E!O<W0M9FQU<V@*4VAU=&1O=VX*8G5F
M9F5R960@6VEN9F]=(%!O<W0M9FQU<V@@8G5F9F5R960@;&]G(&5N=')Y(#`*
M8G5F9F5R960@6VEN9F]=(%!O<W0M9FQU<V@@8G5F9F5R960@;&]G(&5N=')Y
M(#$*8G5F9F5R960@6VEN9F]=(%!O<W0M9FQU<V@@8G5F9F5R960@;&]G(&5N
M=')Y(#(*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O=&5S=',O1&%T90``````````````````````````
M```````````````````````````````````````````````````````P,#`W
M-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<S,R`P
M,C`T,C8`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E
M<W1S````````````````````````````````````````````````````````
M`````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M,#`P(#$P-3$U-#,S-S,S(#`R,34W,``@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+W1E<W1S+T1A=&4O=&5S=',O8V%L8RYP:'`N;W)I9P``````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P-#0T-S`@,3`U,34T,S,W,S,@,#(T,C,R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O
M9G1T86)S=&]P/30Z("HO"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`U($1A;FEE;"!#;VYV
M:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X@("`@("`@("`@('P*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I
M<R!S=6)J96-T('1O('1H92!.97<@0E-$(&QI8V5N<V4L(%1H870@:7,@8G5N
M9&QE9"`@?`HO+R!\('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)
M0T5.4T4L(&%N9"!I<R!A=F%I;&%B;&4@=&AR;W5G:"`@("`@('P*+R\@?"!T
M:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYO<&5N
M<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@("`@("`@("`@
M("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y
M(&]F('1H92!N97<@0E-$;&EC96YS92!A;F0@87)E('5N86)L92`@('P*+R\@
M?"!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L
M96%S92!S96YD(&$@;F]T92!T;R`@("`@("!\"B\O('P@<&5A<BUD979`;&ES
M=',N<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+B`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\@?"!!=71H;W(Z($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE
M=#X@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO*BH*("H@5&5S=',@9F]R('1H92!$871E7T-A
M;&,@8VQA<W,*("H*("H@06YY(&EN9&EV:61U86P@=&5S=',@=&AA="!F86EL
M('=I;&P@:&%V92!T:&5I<B!N86UE+"!E>'!E8W1E9"!R97-U;'0*("H@86YD
M(&%C='5A;"!R97-U;'0@<')I;G1E9"!O=70N("!3;R!S965I;F<@;F\@;W5T
M<'5T('=H96X@97AE8W5T:6YG"B`J('1H:7,@9FEL92!I<R!A(&=O;V0@=&AI
M;F<N"B`J"B`J($-A;B!B92!R=6X@=FEA($-,22!O<B!A('=E8B!S97)V97(N
M"B`J"B`J(%1H:7,@=&5S="!S96YS97,@=VAE=&AE<B!I="!I<R!F<F]M(&%N
M(&EN<W1A;&QA=&EO;B!O9B!014%2.CI$871E(&]R(&EF"B`J(&ET)W,@9G)O
M;2!#5E,@;W(@82`N=&%R(&9I;&4N("!)9B!I="=S(&%N(&EN<W1A;&QE9"!V
M97)S:6]N+"!U<V4@=&AE"B`J(&EN<W1A;&QE9"!V97)S:6]N(&]F($1A=&5?
M0V%L8RX@($]T:&5R=VES92P@=7-E('1H92!L;V-A;"!D979E;&]P;65N=`H@
M*B!C;W!Y(&]F($1A=&5?0V%L8RX*("H*("H@0&-A=&5G;W)Y("`@1&%T92!A
M;F0@5&EM90H@*B!`<&%C:V%G92`@("!$871E"B`J($!A=71H;W(@("`@($1A
M;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H
M="`@,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E"B`J($!V
M97)S:6]N("`@($-64SH@)$ED.B!C86QC+G!H<"QV(#$N."`R,#`U+S$Q+S$U
M(#`P.C$V.C0P('!A:F]Y92!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O1&%T90H@*B!`<VEN8V4@("`@("!&:6QE
M(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-0H@*B\*"FEF("@G+VAO;64O
M;'5C97(O=V]R:R]P96%R+W-H87)E+W!H<"<@(3T@)T`G+B=I;F-L=61E7W!A
M=&@G+B=`)RD@>PH@("`@:6YI7W-E="@G:6YC;'5D95]P871H)RP@:6YI7V=E
M="@G:6YC;'5D95]P871H)RD*("`@("`@("`@("`@+B!0051(7U-%4$%2051/
M4B`N("<N)PH@("`@*3L*?2!E;'-E('L*("`@(&EN:5]S970H)VEN8VQU9&5?
M<&%T:"<L(')E86QP871H*&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B\G*0H@
M("`@("`@("`@("`N(%!!5$A?4T5005)!5$]2("X@)RXG("X@4$%42%]315!!
M4D%43U(*("`@("`@("`@("`@+B!I;FE?9V5T*"=I;F-L=61E7W!A=&@G*0H@
M("`@*3L*?0H*+RHJ"B`J($=E="!T:&4@;F5E9&5D(&-L87-S"B`J+PIR97%U
M:7)E7V]N8V4@)T1A=&4O0V%L8RYP:'`G.PH*+RHJ"B`J($-O;7!A<F4@=&AE
M('1E<W0@<F5S=6QT('1O('1H92!E>'!E8W1E9"!R97-U;'0*("H*("H@268@
M=&AE('1E<W0@9F%I;',L(&5C:&\@;W5T('1H92!R97-U;'1S+@H@*@H@*B!`
M<&%R86T@;6EX960@("1E>'!E8W0@("`@('1H92!S8V%L87(@;W(@87)R87D@
M>6]U(&5X<&5C="!F<F]M('1H92!T97-T"B`J($!P87)A;2!M:7AE9"`@)&%C
M='5A;"`@("`@=&AE('-C86QA<B!O<B!A<G)A>2!R97-U;'1S(&9R;VT@=&AE
M('1E<W0*("H@0'!A<F%M('-T<FEN9R`D=&5S=%]N86UE("!T:&4@;F%M92!O
M9B!T:&4@=&5S=`H@*@H@*B!`<F5T=7)N('9O:60*("HO"F9U;F-T:6]N(&-O
M;7!A<F4H)&5X<&5C="P@)&%C='5A;"P@)'1E<W1?;F%M92D@>PH@("`@:68@
M*&ES7V%R<F%Y*"1E>'!E8W0I*2!["B`@("`@("`@:68@*&-O=6YT*&%R<F%Y
M7V1I9F8H)&%C='5A;"P@)&5X<&5C="DI*2!["B`@("`@("`@("`@(&5C:&\@
M(B1T97-T7VYA;64@9F%I;&5D+B`@17AP96-T.EQN(CL*("`@("`@("`@("`@
M<')I;G1?<B@D97AP96-T*3L*("`@("`@("`@("`@96-H;R`B06-T=6%L.EQN
M(CL*("`@("`@("`@("`@<')I;G1?<B@D86-T=6%L*3L*("`@("`@("!]"B`@
M("!](&5L<V4@>PH@("`@("`@(&EF("@D97AP96-T("$]("1A8W1U86PI('L*
M("`@("`@("`@("`@96-H;R`B)'1E<W1?;F%M92!F86EL960N("!%>'!E8W0Z
M("1E>'!E8W0N("!!8W1U86PZ("1A8W1U86Q<;B(["B`@("`@("`@?0H@("`@
M?0I]"@II9B`H<&AP7W-A<&E?;F%M92@I("$]("=C;&DG*2!["B`@("!E8VAO
M("(\<')E/EQN(CL*?0H*"F-O;7!A<F4H)S(P,#`Q,3(R)RP@1&%T95]#86QC
M.CID871E1F]R;6%T*#(R+"`Q,2P@,C`P,"P@)R59)6TE9"<I+"`G9&%T949O
M<FUA="<I.PIC;VUP87)E*"<R,#`P,3$R,B<L($1A=&5?0V%L8SHZ9&%T949O
M<FUA="@G,C(G+"`G,3$G+"`G,C`P,"<L("<E625M)60G*2P@)V1A=&5&;W)M
M870@<W1R)RD["@IC;VUP87)E*"<R,#`Q)RP@1&%T95]#86QC.CID969A=6QT
M0V5N='5R>2@G,2<I+"`G9&5F875L=$-E;G1U<GD@,2!S='(G*3L*8V]M<&%R
M92@G,C`P,2<L($1A=&5?0V%L8SHZ9&5F875L=$-E;G1U<GDH,2DL("=D969A
M=6QT0V5N='5R>2`Q)RD["F-O;7!A<F4H)S$Y-C`G+"!$871E7T-A;&,Z.F1E
M9F%U;'1#96YT=7)Y*#8P*2P@)V1E9F%U;'1#96YT=7)Y(#(G*3L*8V]M<&%R
M92@G,C`Q,"<L($1A=&5?0V%L8SHZ9&5F875L=$-E;G1U<GDH,3`I+"`G9&5F
M875L=$-E;G1U<GD@,R<I.PH*8V]M<&%R92@R-#4Q.#<Q+"!$871E7T-A;&,Z
M.F1A=&54;T1A>7,H)S(R)RP@)S$Q)RP@)S(P,#`G*2P@)V1A=&54;T1A>7,@
M<W1R)RD["F-O;7!A<F4H,C0U,3@W,2P@1&%T95]#86QC.CID871E5&]$87ES
M*#(R+"`Q,2P@,C`P,"DL("=D871E5&]$87ES)RD["F-O;7!A<F4H)S(P,#`Q
M,3(R)RP@1&%T95]#86QC.CID87ES5&]$871E*#(T-3$X-S$I+"`G9&%Y<U1O
M1&%T92<I.PH*8V]M<&%R92@G,C`P,"TT-RTS)RP@1&%T95]#86QC.CIG<F5G
M;W)I86Y4;TE33R@G,C(G+"`G,3$G+"`G,C`P,"<I+"`G9W)E9V]R:6%N5&])
M4T\@<W1R)RD["F-O;7!A<F4H)S(P,#`M-#<M,R<L($1A=&5?0V%L8SHZ9W)E
M9V]R:6%N5&])4T\H,C(L(#$Q+"`R,#`P*2P@)V=R96=O<FEA;E1O25-/)RD[
M"F-O;7!A<F4H,C0U,3<Q-BXU-C<V-RP@1&%T95]#86QC.CID871E4V5A<V]N
M*"=354U-15)33TQ35$E#12<L(#(P,#`I+"`G9&%T95-E87-O;B<I.PH*8V]M
M<&%R92AD871E*"=9;60G*2P@1&%T95]#86QC.CID871E3F]W*"DL("=D871E
M3F]W)RD["F-O;7!A<F4H9&%T92@G62<I+"!$871E7T-A;&,Z.F=E=%EE87(H
M*2P@)V=E=%EE87(G*3L*8V]M<&%R92AD871E*"=M)RDL($1A=&5?0V%L8SHZ
M9V5T36]N=&@H*2P@)V=E=$UO;G1H)RD["F-O;7!A<F4H9&%T92@G9"<I+"!$
M871E7T-A;&,Z.F=E=$1A>2@I+"`G9V5T1&%Y)RD["@IC;VUP87)E*#,R-RP@
M1&%T95]#86QC.CIJ=6QI86Y$871E*#(R+"`Q,2P@,C`P,"DL("=J=6QI86Y$
M871E)RD["F-O;7!A<F4H)TYO=F5M8F5R)RP@1&%T95]#86QC.CIG971-;VYT
M:$9U;&QN86UE*#$Q*2P@)V=E=$UO;G1H1G5L;&YA;64G*3L*8V]M<&%R92@G
M3F]V)RP@1&%T95]#86QC.CIG971-;VYT:$%B8G)N86UE*#$Q*2P@)V=E=$UO
M;G1H06)B<FYA;64G*3L*8V]M<&%R92@G4V%T=7)D87DG+"!$871E7T-A;&,Z
M.F=E=%=E96MD87E&=6QL;F%M92@Q+"`Q+"`R,#`U*2P@)V=E=%=E96MD87E&
M=6QL;F%M92<I.PIC;VUP87)E*"=3870G+"!$871E7T-A;&,Z.F=E=%=E96MD
M87E!8F)R;F%M92@Q+"`Q+"`R,#`U*2P@)V=E=%=E96MD87E!8F)R;F%M92<I
M.PIC;VUP87)E*#$Q+"!$871E7T-A;&,Z.F=E=$UO;G1H1G)O;49U;&Q.86UE
M*"=.;W9E;6)E<B<I+"`G9V5T36]N=&A&<F]M1G5L;$YA;64G*3L*"F-O;7!A
M<F4H,S(W+"!$871E7T-A;&,Z.FIU;&EA;D1A=&4H)S(R)RP@)S$Q)RP@)S(P
M,#`G*2P@)VIU;&EA;D1A=&4@<W1R)RD["F-O;7!A<F4H)TYO=F5M8F5R)RP@
M1&%T95]#86QC.CIG971-;VYT:$9U;&QN86UE*"<Q,2<I+"`G9V5T36]N=&A&
M=6QL;F%M92!S='(G*3L*8V]M<&%R92@G3F]V)RP@1&%T95]#86QC.CIG971-
M;VYT:$%B8G)N86UE*"<Q,2<I+"`G9V5T36]N=&A!8F)R;F%M92!S='(G*3L*
M8V]M<&%R92@G4V%T=7)D87DG+"!$871E7T-A;&,Z.F=E=%=E96MD87E&=6QL
M;F%M92@G,#$G+"`G,#$G+"`G,C`P-2<I+"`G9V5T5V5E:V1A>49U;&QN86UE
M('-T<B<I.PIC;VUP87)E*"=3870G+"!$871E7T-A;&,Z.F=E=%=E96MD87E!
M8F)R;F%M92@G,#$G+"`G,#$G+"`G,C`P-2<I+"`G9V5T5V5E:V1A>4%B8G)N
M86UE('-T<B<I.PH*)&5X<"`](&%R<F%Y*`H@("`@)TIA;G5A<GDG+`H@("`@
M)T9E8G)U87)Y)RP*("`@("=-87)C:"<L"B`@("`G07!R:6PG+`H@("`@)TUA
M>2<L"B`@("`G2G5N92<L"B`@("`G2G5L>2<L"B`@("`G075G=7-T)RP*("`@
M("=397!T96UB97(G+`H@("`@)T]C=&]B97(G+`H@("`@)TYO=F5M8F5R)RP*
M("`@("=$96-E;6)E<B<**3L*8V]M<&%R92@D97AP+"!$871E7T-A;&,Z.F=E
M=$UO;G1H3F%M97,H*2P@)V=E=$UO;G1H3F%M97,G*3L*"B1E>'`@/2!A<G)A
M>2@*("`@("=-;VYD87DG+`H@("`@)U1U97-D87DG+`H@("`@)U=E9&YE<V1A
M>2<L"B`@("`G5&AU<G-D87DG+`H@("`@)T9R:61A>2<L"B`@("`G4V%T=7)D
M87DG+`H@("`@)U-U;F1A>2<**3L*8V]M<&%R92@D97AP+"!$871E7T-A;&,Z
M.F=E=%=E96M$87ES*"DL("=G9717965K1&%Y<R<I.PH*8V]M<&%R92@S+"!$
M871E7T-A;&,Z.F1A>4]F5V5E:R@R,BP@,3$L(#(P,#`I+"`G9&%Y3V97965K
M)RD["F-O;7!A<F4H-#<L($1A=&5?0V%L8SHZ=V5E:T]F665A<B@R,BP@,3$L
M(#(P,#`I+"`G=V5E:T]F665A<B<I.PIC;VUP87)E*#0L($1A=&5?0V%L8SHZ
M<75A<G1E<D]F665A<B@R,BP@,3$L(#(P,#`I+"`G<75A<G1E<D]F665A<B<I
M.PH*8V]M<&%R92@S+"!$871E7T-A;&,Z.F1A>4]F5V5E:R@G,C(G+"`G,3$G
M+"`G,C`P,"<I+"`G9&%Y3V97965K('-T<B<I.PIC;VUP87)E*#0W+"!$871E
M7T-A;&,Z.G=E96M/9EEE87(H)S(R)RP@)S$Q)RP@)S(P,#`G*2P@)W=E96M/
M9EEE87(@<W1R)RD["F-O;7!A<F4H-"P@1&%T95]#86QC.CIQ=6%R=&5R3V99
M96%R*"<R,B<L("<Q,2<L("<R,#`P)RDL("=Q=6%R=&5R3V9996%R('-T<B<I
M.PH*8V]M<&%R92@R."P@1&%T95]#86QC.CID87ES26Y-;VYT:"@R+"`Q.3`P
M*2P@)V1A>7-);DUO;G1H(#$G*3L*8V]M<&%R92@R.2P@1&%T95]#86QC.CID
M87ES26Y-;VYT:"@R+"`Q.3DV*2P@)V1A>7-);DUO;G1H(#(G*3L*8V]M<&%R
M92@R.2P@1&%T95]#86QC.CID87ES26Y-;VYT:"@R+"`R,#`P*2P@)V1A>7-)
M;DUO;G1H(#,G*3L*8V]M<&%R92@R."P@1&%T95]#86QC.CID87ES26Y-;VYT
M:"@R+"`R,#`Q*2P@)V1A>7-);DUO;G1H(#0G*3L*8V]M<&%R92@S,"P@1&%T
M95]#86QC.CID87ES26Y-;VYT:"@Q,2P@,C`P,"DL("=D87ES26Y-;VYT:"`U
M)RD["@IC;VUP87)E*#(X+"!$871E7T-A;&,Z.F1A>7-);DUO;G1H*"<P,B<L
M(#$Y,#`I+"`G9&%Y<TEN36]N=&@@,2!S='(G*3L*8V]M<&%R92@R.2P@1&%T
M95]#86QC.CID87ES26Y-;VYT:"@G,#(G+"`Q.3DV*2P@)V1A>7-);DUO;G1H
M(#(@<W1R)RD["F-O;7!A<F4H,CDL($1A=&5?0V%L8SHZ9&%Y<TEN36]N=&@H
M)S`R)RP@,C`P,"DL("=D87ES26Y-;VYT:"`S('-T<B<I.PIC;VUP87)E*#(X
M+"!$871E7T-A;&,Z.F1A>7-);DUO;G1H*"<P,B<L(#(P,#$I+"`G9&%Y<TEN
M36]N=&@@-"!S='(G*3L*8V]M<&%R92@S,"P@1&%T95]#86QC.CID87ES26Y-
M;VYT:"@G,3$G+"`G,C`P,"<I+"`G9&%Y<TEN36]N=&@@-2!S='(G*3L*"F-O
M;7!A<F4H-2P@1&%T95]#86QC.CIW965K<TEN36]N=&@H,3$L(#(P,#`I+"`G
M=V5E:W-);DUO;G1H)RD["F-O;7!A<F4H-2P@1&%T95]#86QC.CIW965K<TEN
M36]N=&@H)S$Q)RP@)S(P,#`G*2P@)W=E96MS26Y-;VYT:"!S='(G*3L*"@HD
M97AP(#T@87)R87DH"B`@("`G,3DP,#`R,C8G+`H@("`@)S$Y,#`P,C(W)RP*
M("`@("<Q.3`P,#(R."<L"B`@("`G,3DP,#`S,#$G+`H@("`@)S$Y,#`P,S`R
M)RP*("`@("<Q.3`P,#,P,R<L"B`@("`G,3DP,#`S,#0G+`HI.PIC;VUP87)E
M*"1E>'`L($1A=&5?0V%L8SHZ9V5T0V%L96YD87)7965K*#(W+"`R+"`Q.3`P
M*2P@)V=E=$-A;&5N9&%R5V5E:R`Q)RD["@HD97AP(#T@87)R87DH"B`@("`G
M,C`P,#`R,C@G+`H@("`@)S(P,#`P,C(Y)RP*("`@("<R,#`P,#,P,2<L"B`@
M("`G,C`P,#`S,#(G+`H@("`@)S(P,#`P,S`S)RP*("`@("<R,#`P,#,P-"<L
M"B`@("`G,C`P,#`S,#4G+`HI.PIC;VUP87)E*"1E>'`L($1A=&5?0V%L8SHZ
M9V5T0V%L96YD87)7965K*#(X+"`R+"`R,#`P*2P@)V=E=$-A;&5N9&%R5V5E
M:R`R)RD["@HD97AP(#T@87)R87DH"B`@("`G,C`P,#$Q,C<G+`H@("`@)S(P
M,#`Q,3(X)RP*("`@("<R,#`P,3$R.2<L"B`@("`G,C`P,#$Q,S`G+`H@("`@
M)S(P,#`Q,C`Q)RP*("`@("<R,#`P,3(P,B<L"B`@("`G,C`P,#$R,#,G"BD[
M"F-O;7!A<F4H)&5X<"P@1&%T95]#86QC.CIG971#86QE;F1A<E=E96LH,C<L
M(#$Q+"`R,#`P*2P@)V=E=$-A;&5N9&%R5V5E:R`S)RD["F-O;7!A<F4H)&5X
M<"P@1&%T95]#86QC.CIG971#86QE;F1A<E=E96LH)S(W)RP@)S$Q)RP@)S(P
M,#`G*2P@)V=E=$-A;&5N9&%R5V5E:R`S('-T<B<I.PH*)&5X<"`](&%R<F%Y
M*`H@("`@87)R87DH"B`@("`@("`@)S(P,#`Q,#,P)RP*("`@("`@("`G,C`P
M,#$P,S$G+`H@("`@("`@("<R,#`P,3$P,2<L"B`@("`@("`@)S(P,#`Q,3`R
M)RP*("`@("`@("`G,C`P,#$Q,#,G+`H@("`@("`@("<R,#`P,3$P-"<L"B`@
M("`I+`H@("`@87)R87DH"B`@("`@("`@)S(P,#`Q,3`U)RP*("`@("`@("`G
M,C`P,#$Q,#8G+`H@("`@("`@("<R,#`P,3$P-R<L"B`@("`@("`@)S(P,#`Q
M,3`X)RP*("`@("`@("`G,C`P,#$Q,#DG+`H@("`@("`@("<R,#`P,3$Q,"<L
M"B`@("`@("`@)S(P,#`Q,3$Q)RP*("`@("DL"B`@("!A<G)A>2@*("`@("`@
M("`G,C`P,#$Q,3(G+`H@("`@("`@("<R,#`P,3$Q,R<L"B`@("`@("`@)S(P
M,#`Q,3$T)RP*("`@("`@("`G,C`P,#$Q,34G+`H@("`@("`@("<R,#`P,3$Q
M-B<L"B`@("`@("`@)S(P,#`Q,3$W)RP*("`@("`@("`G,C`P,#$Q,3@G+`H@
M("`@*2P*("`@(&%R<F%Y*`H@("`@("`@("<R,#`P,3$Q.2<L"B`@("`@("`@
M)S(P,#`Q,3(Q)RP*("`@("`@("`G,C`P,#$Q,C(G+`H@("`@("`@("<R,#`P
M,3$R,R<L"B`@("`@("`@)S(P,#`Q,3(T)RP*("`@("`@("`G,C`P,#$Q,C4G
M+`H@("`@("`@("<R,#`P,3$R-B<L"B`@("`I+`H@("`@87)R87DH"B`@("`@
M("`@)S(P,#`Q,3(W)RP*("`@("`@("`G,C`P,#$Q,C@G+`H@("`@("`@("<R
M,#`P,3$R.2<L"B`@("`@("`@)S(P,#`Q,3,P)RP*("`@("`@("`G,C`P,#$R
M,#$G+`H@("`@("`@("<R,#`P,3(P,B<L"B`@("`@("`@)S(P,#`Q,C`S)PH@
M("`@*0HI.PIC;VUP87)E*"1E>'`L($1A=&5?0V%L8SHZ9V5T0V%L96YD87)-
M;VYT:"@Q,2P@,C`P,"DL("=G971#86QE;F1A<DUO;G1H)RD["F-O;7!A<F4H
M)&5X<"P@1&%T95]#86QC.CIG971#86QE;F1A<DUO;G1H*"<Q,2<L("<R,#`P
M)RDL("=G971#86QE;F1A<DUO;G1H('-T<B<I.PH*+R\@22!D;VXG="!F965L
M(&QI:V4@9&5A;&EN9R!W:71H('1H:7,@<FEG:'0@;F]W+BXN"B\O8V]M<&%R
M92@G)RP@1&%T95]#86QC.CIG971#86QE;F1A<EEE87(H,C`P,"DL("=G971#
M86QE;F1A<EEE87(G*3L*"F-O;7!A<F4H)S(P,#`Q,3(Q)RP@1&%T95]#86QC
M.CIP<F5V1&%Y*#(R+"`Q,2P@,C`P,"DL("=P<F5V1&%Y)RD["F-O;7!A<F4H
M)S(P,#`Q,3(S)RP@1&%T95]#86QC.CIN97AT1&%Y*#(R+"`Q,2P@,C`P,"DL
M("=N97AT1&%Y)RD["F-O;7!A<F4H)S(P,#`Q,3(Q)RP@1&%T95]#86QC.CIP
M<F5V1&%Y*#(R+"`Q,2P@,C`P,"DL("=P<F5V1&%Y('-T<B<I.PIC;VUP87)E
M*"<R,#`P,3$R,R<L($1A=&5?0V%L8SHZ;F5X=$1A>2@G,C(G+"`G,3$G+"`G
M,C`P,"<I+"`G;F5X=$1A>2!S='(G*3L*"F-O;7!A<F4H)S(P,#`Q,3$W)RP@
M1&%T95]#86QC.CIP<F5V5V5E:V1A>2@G,3DG+"`G,3$G+"`G,C`P,"<I+"`G
M<')E=E=E96MD87D@,2!S='(G*3L*8V]M<&%R92@G,C`P,#$Q,3<G+"!$871E
M7T-A;&,Z.G!R9797965K9&%Y*#$Y+"`Q,2P@,C`P,"DL("=P<F5V5V5E:V1A
M>2`Q)RD["F-O;7!A<F4H)S(P,#`Q,3(Q)RP@1&%T95]#86QC.CIP<F5V5V5E
M:V1A>2@R,BP@,3$L(#(P,#`I+"`G<')E=E=E96MD87D@,B<I.PIC;VUP87)E
M*"<R,#`P,3$R,R<L($1A=&5?0V%L8SHZ;F5X=%=E96MD87DH,C(L(#$Q+"`R
M,#`P*2P@)VYE>'17965K9&%Y(#$G*3L*8V]M<&%R92@G,C`P,#$Q,C<G+"!$
M871E7T-A;&,Z.FYE>'17965K9&%Y*#(T+"`Q,2P@,C`P,"DL("=N97AT5V5E
M:V1A>2`R)RD["F-O;7!A<F4H)S(P,#`Q,3(W)RP@1&%T95]#86QC.CIN97AT
M5V5E:V1A>2@G,C0G+"`G,3$G+"`G,C`P,"<I+"`G;F5X=%=E96MD87D@,B!S
M='(G*3L*"F-O;7!A<F4H)S(P,#`Q,3(Q)RP@1&%T95]#86QC.CIP<F5V1&%Y
M3V97965K*"<R)RP@)S(R)RP@)S$Q)RP@)S(P,#`G*2P@)W!R979$87E/9E=E
M96L@,2!S='(G*3L*8V]M<&%R92@G,C`P,#$Q,C$G+"!$871E7T-A;&,Z.G!R
M979$87E/9E=E96LH,BP@,C(L(#$Q+"`R,#`P*2P@)W!R979$87E/9E=E96L@
M,2<I.PIC;VUP87)E*"<R,#`P,3$Q-2<L($1A=&5?0V%L8SHZ<')E=D1A>4]F
M5V5E:R@S+"`R,BP@,3$L(#(P,#`I+"`G<')E=D1A>4]F5V5E:R`R)RD["F-O
M;7!A<F4H)S(P,#`Q,3(R)RP@1&%T95]#86QC.CIP<F5V1&%Y3V97965K*#,L
M(#(R+"`Q,2P@,C`P,"P@)R59)6TE9"<L('1R=64I+"`G<')E=D1A>4]F5V5E
M:R`S)RD["F-O;7!A<F4H)S(P,#`Q,3(R)RP@1&%T95]#86QC.CIN97AT1&%Y
M3V97965K*#,L(#(R+"`Q,2P@,C`P,"P@)R59)6TE9"<L('1R=64I+"`G;F5X
M=$1A>4]F5V5E:R`Q)RD["F-O;7!A<F4H)S(P,#`Q,3(Y)RP@1&%T95]#86QC
M.CIN97AT1&%Y3V97965K*#,L(#(R+"`Q,2P@,C`P,"DL("=N97AT1&%Y3V97
M965K(#(G*3L*8V]M<&%R92@G,C`P,#$Q,C,G+"!$871E7T-A;&,Z.FYE>'1$
M87E/9E=E96LH-"P@,C(L(#$Q+"`R,#`P*2P@)VYE>'1$87E/9E=E96L@,R<I
M.PIC;VUP87)E*"<R,#`P,3$R,R<L($1A=&5?0V%L8SHZ;F5X=$1A>4]F5V5E
M:R@G-"<L("<R,B<L("<Q,2<L("<R,#`P)RDL("=N97AT1&%Y3V97965K(#,@
M<W1R)RD["@IC;VUP87)E*"<R,#`P,3$R,2<L($1A=&5?0V%L8SHZ<')E=D1A
M>4]F5V5E:T]N3W)"969O<F4H)S(G+"`G,C(G+"`G,3$G+"`G,C`P,"<I+"`G
M<')E=D1A>4]F5V5E:T]N3W)"969O<F4@,2!S='(G*3L*8V]M<&%R92@G,C`P
M,#$Q,C$G+"!$871E7T-A;&,Z.G!R979$87E/9E=E96M/;D]R0F5F;W)E*#(L
M(#(R+"`Q,2P@,C`P,"DL("=P<F5V1&%Y3V97965K3VY/<D)E9F]R92`Q)RD[
M"F-O;7!A<F4H)S(P,#`Q,3(R)RP@1&%T95]#86QC.CIP<F5V1&%Y3V97965K
M3VY/<D)E9F]R92@S+"`R,BP@,3$L(#(P,#`I+"`G<')E=D1A>4]F5V5E:T]N
M3W)"969O<F4@,B<I.PIC;VUP87)E*"<R,#`P,3$R,B<L($1A=&5?0V%L8SHZ
M;F5X=$1A>4]F5V5E:T]N3W)!9G1E<B@S+"`R,BP@,3$L(#(P,#`I+"`G;F5X
M=$1A>4]F5V5E:T]N3W)!9G1E<B`Q)RD["F-O;7!A<F4H)S(P,#`Q,3(S)RP@
M1&%T95]#86QC.CIN97AT1&%Y3V97965K3VY/<D%F=&5R*#0L(#(R+"`Q,2P@
M,C`P,"DL("=N97AT1&%Y3V97965K3VY/<D%F=&5R(#(G*3L*8V]M<&%R92@G
M,C`P,#$Q,C,G+"!$871E7T-A;&,Z.FYE>'1$87E/9E=E96M/;D]R069T97(H
M)S0G+"`G,C(G+"`G,3$G+"`G,C`P,"<I+"`G;F5X=$1A>4]F5V5E:T]N3W)!
M9G1E<B`R('-T<B<I.PH*8V]M<&%R92@G,C`P,#$Q,C`G+"!$871E7T-A;&,Z
M.F)E9VEN3V97965K*"<R,B<L("<Q,2<L("<R,#`P)RDL("=B96=I;D]F5V5E
M:R!S='(G*3L*8V]M<&%R92@G,C`P,#$Q,C`G+"!$871E7T-A;&,Z.F)E9VEN
M3V97965K*#(R+"`Q,2P@,C`P,"DL("=B96=I;D]F5V5E:R<I.PIC;VUP87)E
M*"<R,#`P,3$R-B<L($1A=&5?0V%L8SHZ96YD3V97965K*#(R+"`Q,2P@,C`P
M,"DL("=E;F1/9E=E96LG*3L*8V]M<&%R92@G,C`P,#$Q,C8G+"!$871E7T-A
M;&,Z.F5N9$]F5V5E:R@G,C(G+"`G,3$G+"`G,C`P,"<I+"`G96YD3V97965K
M('-T<B<I.PH*8V]M<&%R92@G,C`P,#$Q,3,G+"!$871E7T-A;&,Z.F)E9VEN
M3V90<F5V5V5E:R@R,BP@,3$L(#(P,#`I+"`G8F5G:6Y/9E!R9797965K)RD[
M"F-O;7!A<F4H)S(P,#`Q,3(W)RP@1&%T95]#86QC.CIB96=I;D]F3F5X=%=E
M96LH,C(L(#$Q+"`R,#`P*2P@)V)E9VEN3V9.97AT5V5E:R<I.PIC;VUP87)E
M*"<R,#`P,3$Q,R<L($1A=&5?0V%L8SHZ8F5G:6Y/9E!R9797965K*"<R,B<L
M("<Q,2<L("<R,#`P)RDL("=B96=I;D]F4')E=E=E96L@<W1R)RD["F-O;7!A
M<F4H)S(P,#`Q,3(W)RP@1&%T95]#86QC.CIB96=I;D]F3F5X=%=E96LH)S(R
M)RP@)S$Q)RP@)S(P,#`G*2P@)V)E9VEN3V9.97AT5V5E:R!S='(G*3L*"F-O
M;7!A<F4H)S(P,#`Q,3`Q)RP@1&%T95]#86QC.CIB96=I;D]F36]N=&@H,3$L
M(#(P,#`I+"`G8F5G:6Y/9DUO;G1H)RD["F-O;7!A<F4H)S(P,#`Q,3`Q)RP@
M1&%T95]#86QC.CIB96=I;D]F36]N=&@H)S$Q)RP@)S(P,#`G*2P@)V)E9VEN
M3V9-;VYT:"!S='(G*3L*"F-O;7!A<F4H)S(P,#`Q,#`Q)RP@1&%T95]#86QC
M.CIB96=I;D]F4')E=DUO;G1H*#(R+"`Q,2P@,C`P,"DL("=B96=I;D]F4')E
M=DUO;G1H)RD["F-O;7!A<F4H)S(P,#`Q,#,Q)RP@1&%T95]#86QC.CIE;F1/
M9E!R979-;VYT:"@R,BP@,3$L(#(P,#`I+"`G96YD3V90<F5V36]N=&@G*3L*
M8V]M<&%R92@G,C`P,#$P,#$G+"!$871E7T-A;&,Z.F)E9VEN3V90<F5V36]N
M=&@H)S(R)RP@)S$Q)RP@)S(P,#`G*2P@)V)E9VEN3V90<F5V36]N=&@@<W1R
M)RD["F-O;7!A<F4H)S(P,#`Q,#,Q)RP@1&%T95]#86QC.CIE;F1/9E!R979-
M;VYT:"@G,C(G+"`G,3$G+"`G,C`P,"<I+"`G96YD3V90<F5V36]N=&@@<W1R
M)RD["@IC;VUP87)E*"<R,#`P,3(P,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9DYE
M>'1-;VYT:"@R,BP@,3$L(#(P,#`I+"`G8F5G:6Y/9DYE>'1-;VYT:"<I.PIC
M;VUP87)E*"<R,#`P,3(S,2<L($1A=&5?0V%L8SHZ96YD3V9.97AT36]N=&@H
M,C(L(#$Q+"`R,#`P*2P@)V5N9$]F3F5X=$UO;G1H)RD["F-O;7!A<F4H)S(P
M,#`Q,C`Q)RP@1&%T95]#86QC.CIB96=I;D]F3F5X=$UO;G1H*"<R,B<L("<Q
M,2<L("<R,#`P)RDL("=B96=I;D]F3F5X=$UO;G1H('-T<B<I.PIC;VUP87)E
M*"<R,#`P,3(S,2<L($1A=&5?0V%L8SHZ96YD3V9.97AT36]N=&@H)S(R)RP@
M)S$Q)RP@)S(P,#`G*2P@)V5N9$]F3F5X=$UO;G1H('-T<B<I.PH*8V]M<&%R
M92@G,3DY.3$P,#$G+"!$871E7T-A;&,Z.F)E9VEN3V9-;VYT:$)Y4W!A;B@M
M,3,L(#$Q+"`R,#`P*2P@)V)E9VEN3V9-;VYT:$)Y4W!A;B`Q)RD["F-O;7!A
M<F4H)S(P,#`Q,#`Q)RP@1&%T95]#86QC.CIB96=I;D]F36]N=&A">5-P86XH
M+3$L(#$Q+"`R,#`P*2P@)V)E9VEN3V9-;VYT:$)Y4W!A;B`R)RD["F-O;7!A
M<F4H)S(P,#`Q,3`Q)RP@1&%T95]#86QC.CIB96=I;D]F36]N=&A">5-P86XH
M,"P@,3$L(#(P,#`I+"`G8F5G:6Y/9DUO;G1H0GE3<&%N(#,G*3L*8V]M<&%R
M92@G,C`P,#$R,#$G+"!$871E7T-A;&,Z.F)E9VEN3V9-;VYT:$)Y4W!A;B@Q
M+"`Q,2P@,C`P,"DL("=B96=I;D]F36]N=&A">5-P86X@-"<I.PIC;VUP87)E
M*"<R,#`Q,3(P,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9DUO;G1H0GE3<&%N*#$S
M+"`Q,2P@,C`P,"DL("=B96=I;D]F36]N=&A">5-P86X@-2<I.PH*8V]M<&%R
M92@G,3DY.3`Q,#$G+"!$871E7T-A;&,Z.F)E9VEN3V9-;VYT:$)Y4W!A;B@G
M+3$S)RP@)S`R)RP@)S(P,#`G*2P@)V)E9VEN3V9-;VYT:$)Y4W!A;B`V('-T
M<B<I.PIC;VUP87)E*"<Q.3DY,#$P,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9DUO
M;G1H0GE3<&%N*"TQ,RP@,BP@,C`P,"DL("=B96=I;D]F36]N=&A">5-P86X@
M-B<I.PIC;VUP87)E*"<R,#`P,#$P,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9DUO
M;G1H0GE3<&%N*"TQ+"`R+"`R,#`P*2P@)V)E9VEN3V9-;VYT:$)Y4W!A;B`W
M)RD["F-O;7!A<F4H)S(P,#`P,C`Q)RP@1&%T95]#86QC.CIB96=I;D]F36]N
M=&A">5-P86XH,"P@,BP@,C`P,"DL("=B96=I;D]F36]N=&A">5-P86X@."<I
M.PIC;VUP87)E*"<R,#`P,#,P,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9DUO;G1H
M0GE3<&%N*#$L(#(L(#(P,#`I+"`G8F5G:6Y/9DUO;G1H0GE3<&%N(#DG*3L*
M8V]M<&%R92@G,C`P,3`S,#$G+"!$871E7T-A;&,Z.F)E9VEN3V9-;VYT:$)Y
M4W!A;B@Q,RP@,BP@,C`P,"DL("=B96=I;D]F36]N=&A">5-P86X@,3`G*3L*
M8V]M<&%R92@G,C`P,3`S,#$G+"!$871E7T-A;&,Z.F)E9VEN3V9-;VYT:$)Y
M4W!A;B@G,3,G+"`G,#(G+"`G,C`P,"<I+"`G8F5G:6Y/9DUO;G1H0GE3<&%N
M(#$P('-T<B<I.PH*8V]M<&%R92@G,3DY.3$P,S$G+"!$871E7T-A;&,Z.F5N
M9$]F36]N=&A">5-P86XH+3$S+"`Q,2P@,C`P,"DL("=E;F1/9DUO;G1H0GE3
M<&%N(#$G*3L*8V]M<&%R92@G,C`P,#$P,S$G+"!$871E7T-A;&,Z.F5N9$]F
M36]N=&A">5-P86XH+3$L(#$Q+"`R,#`P*2P@)V5N9$]F36]N=&A">5-P86X@
M,B<I.PIC;VUP87)E*"<R,#`P,3$S,"<L($1A=&5?0V%L8SHZ96YD3V9-;VYT
M:$)Y4W!A;B@P+"`Q,2P@,C`P,"DL("=E;F1/9DUO;G1H0GE3<&%N(#,G*3L*
M8V]M<&%R92@G,C`P,#$R,S$G+"!$871E7T-A;&,Z.F5N9$]F36]N=&A">5-P
M86XH,2P@,3$L(#(P,#`I+"`G96YD3V9-;VYT:$)Y4W!A;B`T)RD["F-O;7!A
M<F4H)S(P,#$Q,C,Q)RP@1&%T95]#86QC.CIE;F1/9DUO;G1H0GE3<&%N*#$S
M+"`Q,2P@,C`P,"DL("=E;F1/9DUO;G1H0GE3<&%N(#4G*3L*"F-O;7!A<F4H
M)S$Y.3DP,3,Q)RP@1&%T95]#86QC.CIE;F1/9DUO;G1H0GE3<&%N*"<M,3,G
M+"`G,#(G+"`G,C`P,"<I+"`G96YD3V9-;VYT:$)Y4W!A;B`V('-T<B<I.PIC
M;VUP87)E*"<Q.3DY,#$S,2<L($1A=&5?0V%L8SHZ96YD3V9-;VYT:$)Y4W!A
M;B@M,3,L(#(L(#(P,#`I+"`G96YD3V9-;VYT:$)Y4W!A;B`V)RD["F-O;7!A
M<F4H)S(P,#`P,3,Q)RP@1&%T95]#86QC.CIE;F1/9DUO;G1H0GE3<&%N*"TQ
M+"`R+"`R,#`P*2P@)V5N9$]F36]N=&A">5-P86X@-R<I.PIC;VUP87)E*"<R
M,#`P,#(R.2<L($1A=&5?0V%L8SHZ96YD3V9-;VYT:$)Y4W!A;B@P+"`R+"`R
M,#`P*2P@)V5N9$]F36]N=&A">5-P86X@."<I.PIC;VUP87)E*"<R,#`P,#,S
M,2<L($1A=&5?0V%L8SHZ96YD3V9-;VYT:$)Y4W!A;B@Q+"`R+"`R,#`P*2P@
M)V5N9$]F36]N=&A">5-P86X@.2<I.PIC;VUP87)E*"<R,#`Q,#,S,2<L($1A
M=&5?0V%L8SHZ96YD3V9-;VYT:$)Y4W!A;B@Q,RP@,BP@,C`P,"DL("=E;F1/
M9DUO;G1H0GE3<&%N(#$P)RD["F-O;7!A<F4H)S(P,#$P,S,Q)RP@1&%T95]#
M86QC.CIE;F1/9DUO;G1H0GE3<&%N*"<Q,R<L("<P,B<L("<R,#`P)RDL("=E
M;F1/9DUO;G1H0GE3<&%N(#$P('-T<B<I.PH*8V]M<&%R92@S+"!$871E7T-A
M;&,Z.F9I<G-T3V9-;VYT:%=E96MD87DH,3$L(#(P,#`I+"`G9FER<W1/9DUO
M;G1H5V5E:V1A>2<I.PIC;VUP87)E*#,L($1A=&5?0V%L8SHZ9FER<W1/9DUO
M;G1H5V5E:V1A>2@G,3$G+"`G,C`P,"<I+"`G9FER<W1/9DUO;G1H5V5E:V1A
M>2!S='(G*3L*"F-O;7!A<F4H)S(P,#4P,3`Q)RP@1&%T95]#86QC.CI.5V5E
M:V1A>4]F36]N=&@H,2P@-BP@,2P@,C`P-2DL("=.5V5E:V1A>4]F36]N=&@@
M,38Q)RD["F-O;7!A<F4H)S(P,#4P,3`R)RP@1&%T95]#86QC.CI.5V5E:V1A
M>4]F36]N=&@H,2P@,"P@,2P@,C`P-2DL("=.5V5E:V1A>4]F36]N=&@@,3`Q
M)RD["F-O;7!A<F4H)S(P,#4P,3`S)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F
M36]N=&@H,2P@,2P@,2P@,C`P-2DL("=.5V5E:V1A>4]F36]N=&@@,3$Q)RD[
M"F-O;7!A<F4H)S(P,#4P,3`T)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N
M=&@H,2P@,BP@,2P@,C`P-2DL("=.5V5E:V1A>4]F36]N=&@@,3(Q)RD["F-O
M;7!A<F4H)S(P,#4P,3`U)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H
M,2P@,RP@,2P@,C`P-2DL("=.5V5E:V1A>4]F36]N=&@@,3,Q)RD["F-O;7!A
M<F4H)S(P,#4P,3`V)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H,2P@
M-"P@,2P@,C`P-2DL("=.5V5E:V1A>4]F36]N=&@@,30Q)RD["F-O;7!A<F4H
M)S(P,#4P,3`W)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H,2P@-2P@
M,2P@,C`P-2DL("=.5V5E:V1A>4]F36]N=&@@,34Q)RD["@IC;VUP87)E*"<R
M,#`U,#$P."<L($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H*"<R)RP@)S8G
M+"`G,#$G+"`G,C`P-2<I+"`G3E=E96MD87E/9DUO;G1H(#(V,2<I.PIC;VUP
M87)E*"<R,#`U,#$P.2<L($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H*"<R
M)RP@)S`G+"`G,#$G+"`G,C`P-2<I+"`G3E=E96MD87E/9DUO;G1H(#(P,2<I
M.PIC;VUP87)E*"<R,#`U,#$Q,"<L($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO
M;G1H*"<R)RP@)S$G+"`G,#$G+"`G,C`P-2<I+"`G3E=E96MD87E/9DUO;G1H
M(#(Q,2<I.PIC;VUP87)E*"<R,#`U,#$Q,2<L($1A=&5?0V%L8SHZ3E=E96MD
M87E/9DUO;G1H*"<R)RP@)S(G+"`G,#$G+"`G,C`P-2<I+"`G3E=E96MD87E/
M9DUO;G1H(#(R,2<I.PIC;VUP87)E*"<R,#`U,#$Q,B<L($1A=&5?0V%L8SHZ
M3E=E96MD87E/9DUO;G1H*"<R)RP@)S,G+"`G,#$G+"`G,C`P-2<I+"`G3E=E
M96MD87E/9DUO;G1H(#(S,2<I.PIC;VUP87)E*"<R,#`U,#$Q,R<L($1A=&5?
M0V%L8SHZ3E=E96MD87E/9DUO;G1H*"<R)RP@)S0G+"`G,#$G+"`G,C`P-2<I
M+"`G3E=E96MD87E/9DUO;G1H(#(T,2<I.PIC;VUP87)E*"<R,#`U,#$Q-"<L
M($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H*"<R)RP@)S4G+"`G,#$G+"`G
M,C`P-2<I+"`G3E=E96MD87E/9DUO;G1H(#(U,2<I.PH*8V]M<&%R92@G,C`P
M-3`Q,S$G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@G;&%S="<L(#$L
M(#$L(#(P,#4I+"`G3E=E96MD87E/9DUO;G1H(&PQ,2<I.PIC;VUP87)E*"<R
M,#`U,#$S,"<L($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H*"=L87-T)RP@
M,"P@,2P@,C`P-2DL("=.5V5E:V1A>4]F36]N=&@@;#`Q)RD["F-O;7!A<F4H
M)S(P,#4P,3(Y)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H)VQA<W0G
M+"`V+"`Q+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT:"!L-C$G*3L*8V]M<&%R
M92@G,C`P-3`Q,C@G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@G;&%S
M="<L(#4L(#$L(#(P,#4I+"`G3E=E96MD87E/9DUO;G1H(&PU,2<I.PIC;VUP
M87)E*"<R,#`U,#$R-R<L($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H*"=L
M87-T)RP@-"P@,2P@,C`P-2DL("=.5V5E:V1A>4]F36]N=&@@;#0Q)RD["F-O
M;7!A<F4H)S(P,#4P,3(V)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H
M)VQA<W0G+"`S+"`Q+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT:"!L,S$G*3L*
M8V]M<&%R92@G,C`P-3`Q,C4G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT
M:"@G;&%S="<L(#(L(#$L(#(P,#4I+"`G3E=E96MD87E/9DUO;G1H(&PR,2<I
M.PH*8V]M<&%R92@G,C`P-3`S,S$G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-
M;VYT:"@G;&%S="<L(#0L(#,L(#(P,#4I+"`G3E=E96MD87E/9DUO;G1H(&PT
M,R<I.PIC;VUP87)E*"<R,#`U,#,S,"<L($1A=&5?0V%L8SHZ3E=E96MD87E/
M9DUO;G1H*"=L87-T)RP@,RP@,RP@,C`P-2DL("=.5V5E:V1A>4]F36]N=&@@
M;#,S)RD["F-O;7!A<F4H)S(P,#4P,S(Y)RP@1&%T95]#86QC.CI.5V5E:V1A
M>4]F36]N=&@H)VQA<W0G+"`R+"`S+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT
M:"!L,C,G*3L*8V]M<&%R92@G,C`P-3`S,C@G+"!$871E7T-A;&,Z.DY7965K
M9&%Y3V9-;VYT:"@G;&%S="<L(#$L(#,L(#(P,#4I+"`G3E=E96MD87E/9DUO
M;G1H(&PQ,R<I.PIC;VUP87)E*"<R,#`U,#,R-R<L($1A=&5?0V%L8SHZ3E=E
M96MD87E/9DUO;G1H*"=L87-T)RP@,"P@,RP@,C`P-2DL("=.5V5E:V1A>4]F
M36]N=&@@;#`S)RD["F-O;7!A<F4H)S(P,#4P,S(V)RP@1&%T95]#86QC.CI.
M5V5E:V1A>4]F36]N=&@H)VQA<W0G+"`V+"`S+"`R,#`U*2P@)TY7965K9&%Y
M3V9-;VYT:"!L-C,G*3L*8V]M<&%R92@G,C`P-3`S,C4G+"!$871E7T-A;&,Z
M.DY7965K9&%Y3V9-;VYT:"@G;&%S="<L(#4L(#,L(#(P,#4I+"`G3E=E96MD
M87E/9DUO;G1H(&PU,R<I.PH*"F-O;7!A<F4H9F%L<V4L($1A=&5?0V%L8SHZ
M:7-686QI9$1A=&4H,CDL(#(L(#$Y,#`I+"`G:7-686QI9$1A=&4@,2<I.PIC
M;VUP87)E*'1R=64L($1A=&5?0V%L8SHZ:7-686QI9$1A=&4H,CDL(#(L(#(P
M,#`I+"`G:7-686QI9$1A=&4@,B<I.PIC;VUP87)E*'1R=64L($1A=&5?0V%L
M8SHZ:7-686QI9$1A=&4H)S(Y)RP@)S`R)RP@)S(P,#`G*2P@)VES5F%L:61$
M871E(#(@<W1R)RD["@IC;VUP87)E*&9A;'-E+"!$871E7T-A;&,Z.FES3&5A
M<%EE87(H,3DP,"DL("=I<TQE87!996%R(#$G*3L*8V]M<&%R92AT<G5E+"!$
M871E7T-A;&,Z.FES3&5A<%EE87(H,3DY-BDL("=I<TQE87!996%R(#(G*3L*
M8V]M<&%R92AT<G5E+"!$871E7T-A;&,Z.FES3&5A<%EE87(H,C`P,"DL("=I
M<TQE87!996%R(#,G*3L*8V]M<&%R92AF86QS92P@1&%T95]#86QC.CII<TQE
M87!996%R*#(P,#$I+"`G:7-,96%P665A<B`T)RD["F-O;7!A<F4H9F%L<V4L
M($1A=&5?0V%L8SHZ:7-,96%P665A<B@G,C`P,2<I+"`G:7-,96%P665A<B`T
M('-T<B<I.PH*8V]M<&%R92AF86QS92P@1&%T95]#86QC.CII<T9U='5R941A
M=&4H)S(R)RP@)S$Q)RP@)S(P,#`G*2P@)VES1G5T=7)E1&%T92`Q('-T<B<I
M.PIC;VUP87)E*&9A;'-E+"!$871E7T-A;&,Z.FES1G5T=7)E1&%T92@R,BP@
M,3$L(#(P,#`I+"`G:7-&=71U<F5$871E(#$G*3L*8V]M<&%R92AT<G5E+"!$
M871E7T-A;&,Z.FES1G5T=7)E1&%T92@R,BP@,3$L(&1A=&4H)UDG*2`K(#$I
M+"`G:7-&=71U<F5$871E(#(G*3L*"F-O;7!A<F4H9F%L<V4L($1A=&5?0V%L
M8SHZ:7-087-T1&%T92@R,BP@,3$L(&1A=&4H)UDG*2`K(#$I+"`G:7-087-T
M1&%T92`Q)RD["F-O;7!A<F4H=')U92P@1&%T95]#86QC.CII<U!A<W1$871E
M*#(R+"`Q,2P@,C`P,"DL("=I<U!A<W1$871E(#(G*3L*8V]M<&%R92AT<G5E
M+"!$871E7T-A;&,Z.FES4&%S=$1A=&4H)S(R)RP@)S$Q)RP@)S(P,#`G*2P@
M)VES4&%S=$1A=&4@,B!S='(G*3L*"F-O;7!A<F4H,3`L($1A=&5?0V%L8SHZ
M9&%T941I9F8H,C(L(#$Q+"`R,#`P+"`Q,BP@,3$L(#(P,#`I+"`G9&%T941I
M9F8@,2<I.PIC;VUP87)E*#$P+"!$871E7T-A;&,Z.F1A=&5$:69F*#$R+"`Q
M,2P@,C`P,"P@,C(L(#$Q+"`R,#`P*2P@)V1A=&5$:69F(#(G*3L*8V]M<&%R
M92@V,2P@1&%T95]#86QC.CID871E1&EF9B@R,BP@,3$L(#(P,#`L(#(R+"`Q
M+"`R,#`Q*2P@)V1A=&5$:69F(#,G*3L*8V]M<&%R92@V,2P@1&%T95]#86QC
M.CID871E1&EF9B@G,C(G+"`G,3$G+"`G,C`P,"<L("<R,B<L("<P,2<L("<R
M,#`Q)RDL("=D871E1&EF9B`S('-T<B<I.PH*8V]M<&%R92@M,2P@1&%T95]#
M86QC.CIC;VUP87)E1&%T97,H,3(L(#$Q+"`R,#`P+"`R,BP@,3$L(#(P,#`I
M+"`G8V]M<&%R941A=&5S(#$G*3L*8V]M<&%R92@P+"!$871E7T-A;&,Z.F-O
M;7!A<F5$871E<R@R,BP@,3$L(#(P,#`L(#(R+"`Q,2P@,C`P,"DL("=C;VUP
M87)E1&%T97,@,B<I.PIC;VUP87)E*#$L($1A=&5?0V%L8SHZ8V]M<&%R941A
M=&5S*#(R+"`Q,2P@,C`P,"P@,3(L(#$Q+"`R,#`P*2P@)V-O;7!A<F5$871E
M<R`S)RD["F-O;7!A<F4H,2P@1&%T95]#86QC.CIC;VUP87)E1&%T97,H)S(R
M)RP@)S$Q)RP@)S(P,#`G+"`G,3(G+"`G,3$G+"`G,C`P,"<I+"`G8V]M<&%R
M941A=&5S(#,@<W1R)RD["@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E<W1S+V)U9S<R-U\R
M+G!H<```````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#8P(#$P-3$U-#,S
M-S,S(#`R,S8Q-``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*@H@*B!497-T<R!F;W(@=V5E:W-);DUO;G1H+"!F
M96)R=6%R>2!W:71H(#0@=V5E:W,*("H@4W5N9&%Y(&%S(#%S="!D87D@;V8@
M=V5E:PH@*B\*9&5F:6YE*"=$051%7T-!3$-?0D5'24Y?5T5%2T1!62<L(#`I
M.PIR97%U:7)E7V]N8V4@(D1A=&4O0V%L8RYP:'`B.PH*+RHJ"B`J(%1E<W0@
M9&%T97,@9G)O;2`Q.3<P('1O(#(P,CD*("H@1&%T82!F<F]M.B!H='1P.B\O
M=W=W+FUE<FQY;BYD96UO;BYC;RYU:R]W:VYO=&5S="YT>'0*("H@3W1H97)S
M('5S969U;&P@9&%T87,@879A:6QA8FQE(&9R;VTZ"B`J(&AT='`Z+R]W=W<N
M;65R;'EN+F1E;6]N+F-O+G5K+R-D870*("HO"B1D871A<&%T:"`](&1I<FYA
M;64H(%]?1DE,15]?*3L*"B1F86EL961?=&5S=%]D871A("`@/2!F86QS93L*
M)&1A=&5S("`@/2!F:6QE*"1D871A<&%T:"`N("<O=V5E:W-I;FUO;G1H7S1?
M<W5N9&%Y+G1X="<I.PHD8VYT("`@("`]('-I>F5O9B@D9&%T97,I.PHD=F%L
M:61S(#T@87)R87DH*3L*9F]R*"`D:3TP.R1I/"1C;G0[)&DK*R`I>PH@("`@
M)'!A<G1S("`@("`@/2!E>'!L;V1E*"<O)RPD9&%T97-;)&E=*3L*("`@("1V
M86QI9'-;)'!A<G1S6S!=72`](&%R<F%Y*"1P87)T<ULQ73T^*&EN="ES=')?
M<F5P;&%C92@B7&XB+"<G+"1P87)T<ULR72DI.PI]"G5N<V5T*"1D871E<RD[
M"F9O<F5A8V@H)'9A;&ED<R!A<R`D>65A<B`]/B`D;6]N=&AS*7L*("`@(&9O
M<F5A8V@@*"1M;VYT:',@87,@)&UO;G1H/3XD=F%L:61?=V5E:W,I('L*("`@
M("`@("`D8V%L8U]W965K<R`]($1A=&5?0V%L8SHZ=V5E:W-);DUO;G1H*"1M
M;VYT:"PD>65A<BD["B`@("`@("`@:68H)&-A;&-?=V5E:W,A/21V86QI9%]W
M965K<RE["B`@("`@("`@("`@("1F86EL961?=&5S=%]D871A("`@/2!T<G5E
M.PH@("`@("`@("`@("!E8VAO(")"=6<@(S<R-RP@<&%S<R`S.B`D>65A<B\D
M;6]N=&@@9F%I;&5D+B!%>'!E8W0Z)'9A;&ED7W=E96MS($=O=#HD8V%L8U]W
M965K<UQN(CL*("`@("`@("!]"B`@("!]"GT*:68@*"$D9F%I;&5D7W1E<W1?
M9&%T82D@>PH)96-H;R`B0G5G(",W,C<L('!A<W,@,CH@3TM<;B(["GT*/SX*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E
M<W1S+T1A=&4O=&5S=',O8G5G-S(W7S,N<&AP````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#(P-3`@,3`U,34T,S,W,S,@,#(S-C$T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J"B`J(%1E
M<W1S(&9O<B!W965K<TEN36]N=&@L(")R86YD;VTB"B`J(%-U;F1A>2!A<R`Q
M<W0@9&%Y(&]F('=E96L*("HO"F1E9FEN92@G1$%415]#04Q#7T)%1TE.7U=%
M14M$05DG+"`P*3L*<F5Q=6ER95]O;F-E(")$871E+T-A;&,N<&AP(CL*"B\J
M*@H@*B!497-T(&1A=&5S(&9R;VT@,3DW,"!T;R`R,#(Y"B`J($1A=&$@9G)O
M;3H@:'1T<#HO+W=W=RYM97)L>6XN9&5M;VXN8V\N=6LO=VMN;W1E<W0N='AT
M"B`J($]T:&5R<R!U<V5F=6QL(&1A=&%S(&%V86EL86)L92!F<F]M.@H@*B!H
M='1P.B\O=W=W+FUE<FQY;BYD96UO;BYC;RYU:R\C9&%T"B`J+PHD9&%T87!A
M=&@@/2!D:7)N86UE*"!?7T9)3$5?7RD["@HD9F%I;&5D7W1E<W1?9&%T82`@
M(#T@9F%L<V4["B1D871E<R`@(#T@9FEL92@D9&%T87!A=&@@+B`G+W=E96MS
M:6YM;VYT:%]R9&U?<W5N9&%Y+G1X="<I.PHD8VYT("`@("`]('-I>F5O9B@D
M9&%T97,I.PHD=F%L:61S(#T@87)R87DH*3L*9F]R*"`D:3TP.R1I/"1C;G0[
M)&DK*R`I>PH@("`@)'!A<G1S("`@("`@/2!E>'!L;V1E*"<O)RPD9&%T97-;
M)&E=*3L*("`@("1V86QI9'-;)'!A<G1S6S!=72`](&%R<F%Y*"1P87)T<ULQ
M73T^*&EN="ES=')?<F5P;&%C92@B7&XB+"<G+"1P87)T<ULR72DI.PI]"G5N
M<V5T*"1D871E<RD["F9O<F5A8V@H)'9A;&ED<R!A<R`D>65A<B`]/B`D;6]N
M=&AS*7L*("`@(&9O<F5A8V@@*"1M;VYT:',@87,@)&UO;G1H/3XD=F%L:61?
M=V5E:W,I('L*("`@("`@("`D8V%L8U]W965K<R`]($1A=&5?0V%L8SHZ=V5E
M:W-);DUO;G1H*"1M;VYT:"PD>65A<BD["B`@("`@("`@:68H)&-A;&-?=V5E
M:W,A/21V86QI9%]W965K<RE["B`@("`@("`@("`@("1F86EL961?=&5S=%]D
M871A("`@/2!T<G5E.PH@("`@("`@("`@("!E8VAO(")"=6<@(S<R-RP@<&%S
M<R`S.B`D>65A<B\D;6]N=&@@9F%I;&5D+B!%>'!E8W0Z)'9A;&ED7W=E96MS
M($=O=#HD8V%L8U]W965K<UQN(CL*("`@("`@("!]"B`@("!]"GT*:68@*"$D
M9F%I;&5D7W1E<W1?9&%T82D@>PH@("`@96-H;R`B0G5G(",W,C<L('!A<W,@
M,SH@3TM<;B(["GT*/SX*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1&%T92]T97-T<R]B=6<W,C=?
M-"YP:'``````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`T-R`Q,#4Q-30S
M,S<S,R`P,C,V,C,`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RH*("H@5&5S=',@9F]R('=E96MS26Y-;VYT:"P@
M(G)A;F1O;2(*("H@36]N9&%Y(&%S(#%S="!D87D@;V8@=V5E:PH@*B\*9&5F
M:6YE*"=$051%7T-!3$-?0D5'24Y?5T5%2T1!62<L(#$I.PIR97%U:7)E7V]N
M8V4@(D1A=&4O0V%L8RYP:'`B.PH*+RHJ"B`J(%1E<W0@9&%T97,@9G)O;2`Q
M.3<P('1O(#(P,CD*("H@1&%T82!F<F]M.B!H='1P.B\O=W=W+FUE<FQY;BYD
M96UO;BYC;RYU:R]W:VYO=&5S="YT>'0*("H@3W1H97)S('5S969U;&P@9&%T
M87,@879A:6QA8FQE(&9R;VTZ"B`J(&AT='`Z+R]W=W<N;65R;'EN+F1E;6]N
M+F-O+G5K+R-D870*("HO"B1D871A<&%T:"`](&1I<FYA;64H(%]?1DE,15]?
M*3L*"B1F86EL961?=&5S=%]D871A("`@/2!F86QS93L*)&1A=&5S("`@/2!F
M:6QE*"1D871A<&%T:"`N("<O=V5E:W-I;FUO;G1H7W)D;5]M;VYD87DN='AT
M)RD["B1C;G0@("`@(#T@<VEZ96]F*"1D871E<RD["B1V86QI9',@/2!A<G)A
M>2@I.PIF;W(H("1I/3`[)&D\)&-N=#LD:2LK("E["B`@("`D<&%R=',@("`@
M("`](&5X<&QO9&4H)R\G+"1D871E<ULD:5TI.PH@("`@)'9A;&ED<ULD<&%R
M='-;,%U=(#T@87)R87DH)'!A<G1S6S%=/3XH:6YT*7-T<E]R97!L86-E*")<
M;B(L)R<L)'!A<G1S6S)=*2D["GT*=6YS970H)&1A=&5S*3L*9F]R96%C:"@D
M=F%L:61S(&%S("1Y96%R(#T^("1M;VYT:',I>PH@("`@9F]R96%C:"`H)&UO
M;G1H<R!A<R`D;6]N=&@]/B1V86QI9%]W965K<RD@>PH@("`@("`@("1C86QC
M7W=E96MS(#T@1&%T95]#86QC.CIW965K<TEN36]N=&@H)&UO;G1H+"1Y96%R
M*3L*("`@("`@("!I9B@D8V%L8U]W965K<R$])'9A;&ED7W=E96MS*7L*("`@
M("`@("`@("`@)&9A:6QE9%]T97-T7V1A=&$@("`]('1R=64["B`@("`@("`@
M("`@(&5C:&\@(D)U9R`W,C<L('!A<W,@-#H@)'EE87(O)&UO;G1H(&9A:6QE
M9"X@17AP96-T.B1V86QI9%]W965K<R!';W0Z)&-A;&-?=V5E:W-<;B(["B`@
M("`@("`@?0H@("`@?0I]"FEF("@A)&9A:6QE9%]T97-T7V1A=&$I('L*("`@
M(&5C:&\@(D)U9R`C-S(W+"!P87-S(#0Z($]+7&XB.PI]"C\^"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T
M97-T<R]$871E+W1E<W1S+V)U9SDV-RYP:'``````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P-C$U(#$P-3$U-#,S-S,S(#`R,S0P-0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`IR97%U:7)E
M7V]N8V4@)T1A=&4N<&AP)SL*)%]$051%7U1)345:3TY%7T1%1D%53%0@/2`G
M4&%C:69I8R]#:&%T:&%M)SL*)'1Z(#T@1&%T95]4:6UE6F]N93HZ9V5T1&5F
M875L="@I.PII9B`H)'1Z+3YI9"$])%]$051%7U1)345:3TY%7T1%1D%53%0@
M)B8@)'1Z+3YI9"$])U!A8VEF:6,O0VAA=&AA;2<I('L*("`@(&5C:&\@(G-E
M=$1E9F%U;'0@1F%I;&5D7&XB.PI]"D1A=&5?5&EM95IO;F4Z.G-E=$1E9F%U
M;'0H)T-35"<I.PHD9&5F875L="`]("=%4U0G.PHD='H@/2!$871E7U1I;65:
M;VYE.CIG971$969A=6QT*"D["FEF("@D='HM/FED(3TD7T1!5$5?5$E-15I/
M3D5?1$5&055,5"`F)B`D='HM/FED(3TG15-4)RD@>PH@("`@96-H;R`B<V5T
M1&5F875L="!&86EL961<;B(["GT*/SX*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1&%T92]T
M97-T<R]C86QC+G!H<```````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`T
M-#0V-B`Q,#4Q-30S,S<S,R`P,C,S,#``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RH@=FEM.B!S970@97AP86YD
M=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*
M+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I
M9VAT("AC*2`Q.3DW+3(P,#4@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P
M:'`N;F5T/B`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=&AE
M($YE=R!"4T0@;&EC96YS92P@5&AA="!I<R!B=6YD;&5D("!\"B\O('P@=VET
M:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES(&%V
M86EL86)L92!T:')O=6=H("`@("`@?`HO+R!\('1H92!W;W)L9"UW:61E+7=E
M8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@?"!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N
M<V5S+V)S9"UL:6-E;G-E+G!H<"`@("`@("`@("`@("`@("`@("!\"B\O('P@
M268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(&YE=R!"4T1L
M:6-E;G-E(&%N9"!A<F4@=6YA8FQE("`@?`HO+R!\('1O(&]B=&%I;B!I="!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E
M('1O("`@("`@('P*+R\@?"!P96%R+61E=D!L:7-T<RYP:'`N;F5T('-O('=E
M(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("!\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<CH@1&%N
M:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/B`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\J*@H@*B!497-T<R!F;W(@=&AE($1A=&5?0V%L8R!C;&%S<PH@*@H@*B!!
M;GD@:6YD:79I9'5A;"!T97-T<R!T:&%T(&9A:6P@=VEL;"!H879E('1H96ER
M(&YA;64L(&5X<&5C=&5D(')E<W5L=`H@*B!A;F0@86-T=6%L(')E<W5L="!P
M<FEN=&5D(&]U="X@(%-O('-E96EN9R!N;R!O=71P=70@=VAE;B!E>&5C=71I
M;F<*("H@=&AI<R!F:6QE(&ES(&$@9V]O9"!T:&EN9RX*("H*("H@0V%N(&)E
M(')U;B!V:6$@0TQ)(&]R(&$@=V5B('-E<G9E<BX*("H*("H@5&AI<R!T97-T
M('-E;G-E<R!W:&5T:&5R(&ET(&ES(&9R;VT@86X@:6YS=&%L;&%T:6]N(&]F
M(%!%05(Z.D1A=&4@;W(@:68*("H@:70G<R!F<F]M($-64R!O<B!A("YT87(@
M9FEL92X@($EF(&ET)W,@86X@:6YS=&%L;&5D('9E<G-I;VXL('5S92!T:&4*
M("H@:6YS=&%L;&5D('9E<G-I;VX@;V8@1&%T95]#86QC+B`@3W1H97)W:7-E
M+"!U<V4@=&AE(&QO8V%L(&1E=F5L;W!M96YT"B`J(&-O<'D@;V8@1&%T95]#
M86QC+@H@*@H@*B!`8V%T96=O<GD@("!$871E(&%N9"!4:6UE"B`J($!P86-K
M86=E("`@($1A=&4*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\
M9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`R,#`U(%1H92!02%`@
M1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,U\P+G1X="`@4$A0($QI8V5N<V4*("H@0'9E<G-I;VX@("`@0U93.B`D
M260Z(&-A;&,N<&AP+'8@,2XX(#(P,#4O,3$O,34@,#`Z,38Z-#`@<&%J;WEE
M($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]$871E"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E
M(%)E;&5A<V4@,2XU"B`J+PH*:68@*"<O=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B<@(3T@)T`G+B=I;F-L=61E7W!A=&@G+B=`)RD@>PH@("`@:6YI
M7W-E="@G:6YC;'5D95]P871H)RP@:6YI7V=E="@G:6YC;'5D95]P871H)RD*
M("`@("`@("`@("`@+B!0051(7U-%4$%2051/4B`N("<N)PH@("`@*3L*?2!E
M;'-E('L*("`@(&EN:5]S970H)VEN8VQU9&5?<&%T:"<L(')E86QP871H*&1I
M<FYA;64H7U]&24Q%7U\I("X@)R\N+B\G*0H@("`@("`@("`@("`N(%!!5$A?
M4T5005)!5$]2("X@)RXG("X@4$%42%]315!!4D%43U(*("`@("`@("`@("`@
M+B!I;FE?9V5T*"=I;F-L=61E7W!A=&@G*0H@("`@*3L*?0H*+RHJ"B`J($=E
M="!T:&4@;F5E9&5D(&-L87-S"B`J+PIR97%U:7)E7V]N8V4@)T1A=&4O0V%L
M8RYP:'`G.PH*+RHJ"B`J($-O;7!A<F4@=&AE('1E<W0@<F5S=6QT('1O('1H
M92!E>'!E8W1E9"!R97-U;'0*("H*("H@268@=&AE('1E<W0@9F%I;',L(&5C
M:&\@;W5T('1H92!R97-U;'1S+@H@*@H@*B!`<&%R86T@;6EX960@("1E>'!E
M8W0@("`@('1H92!S8V%L87(@;W(@87)R87D@>6]U(&5X<&5C="!F<F]M('1H
M92!T97-T"B`J($!P87)A;2!M:7AE9"`@)&%C='5A;"`@("`@=&AE('-C86QA
M<B!O<B!A<G)A>2!R97-U;'1S(&9R;VT@=&AE('1E<W0*("H@0'!A<F%M('-T
M<FEN9R`D=&5S=%]N86UE("!T:&4@;F%M92!O9B!T:&4@=&5S=`H@*@H@*B!`
M<F5T=7)N('9O:60*("HO"F9U;F-T:6]N(&-O;7!A<F4H)&5X<&5C="P@)&%C
M='5A;"P@)'1E<W1?;F%M92D@>PH@("`@:68@*&ES7V%R<F%Y*"1E>'!E8W0I
M*2!["B`@("`@("`@:68@*&-O=6YT*&%R<F%Y7V1I9F8H)&%C='5A;"P@)&5X
M<&5C="DI*2!["B`@("`@("`@("`@(&5C:&\@(B1T97-T7VYA;64@9F%I;&5D
M+B`@17AP96-T.EQN(CL*("`@("`@("`@("`@<')I;G1?<B@D97AP96-T*3L*
M("`@("`@("`@("`@96-H;R`B06-T=6%L.EQN(CL*("`@("`@("`@("`@<')I
M;G1?<B@D86-T=6%L*3L*("`@("`@("!]"B`@("!](&5L<V4@>PH@("`@("`@
M(&EF("@D97AP96-T("$]("1A8W1U86PI('L*("`@("`@("`@("`@96-H;R`B
M)'1E<W1?;F%M92!F86EL960N("!%>'!E8W0Z("1E>'!E8W0N("!!8W1U86PZ
M("1A8W1U86Q<;B(["B`@("`@("`@?0H@("`@?0I]"@II9B`H<&AP7W-A<&E?
M;F%M92@I("$]("=C;&DG*2!["B`@("!E8VAO("(\<')E/EQN(CL*?0H*"F-O
M;7!A<F4H)S(P,#`Q,3(R)RP@1&%T95]#86QC.CID871E1F]R;6%T*#(R+"`Q
M,2P@,C`P,"P@)R59)6TE9"<I+"`G9&%T949O<FUA="<I.PIC;VUP87)E*"<R
M,#`P,3$R,B<L($1A=&5?0V%L8SHZ9&%T949O<FUA="@G,C(G+"`G,3$G+"`G
M,C`P,"<L("<E625M)60G*2P@)V1A=&5&;W)M870@<W1R)RD["@IC;VUP87)E
M*"<R,#`Q)RP@1&%T95]#86QC.CID969A=6QT0V5N='5R>2@G,2<I+"`G9&5F
M875L=$-E;G1U<GD@,2!S='(G*3L*8V]M<&%R92@G,C`P,2<L($1A=&5?0V%L
M8SHZ9&5F875L=$-E;G1U<GDH,2DL("=D969A=6QT0V5N='5R>2`Q)RD["F-O
M;7!A<F4H)S$Y-C`G+"!$871E7T-A;&,Z.F1E9F%U;'1#96YT=7)Y*#8P*2P@
M)V1E9F%U;'1#96YT=7)Y(#(G*3L*8V]M<&%R92@G,C`Q,"<L($1A=&5?0V%L
M8SHZ9&5F875L=$-E;G1U<GDH,3`I+"`G9&5F875L=$-E;G1U<GD@,R<I.PH*
M8V]M<&%R92@R-#4Q.#<Q+"!$871E7T-A;&,Z.F1A=&54;T1A>7,H)S(R)RP@
M)S$Q)RP@)S(P,#`G*2P@)V1A=&54;T1A>7,@<W1R)RD["F-O;7!A<F4H,C0U
M,3@W,2P@1&%T95]#86QC.CID871E5&]$87ES*#(R+"`Q,2P@,C`P,"DL("=D
M871E5&]$87ES)RD["F-O;7!A<F4H)S(P,#`Q,3(R)RP@1&%T95]#86QC.CID
M87ES5&]$871E*#(T-3$X-S$I+"`G9&%Y<U1O1&%T92<I.PH*8V]M<&%R92@G
M,C`P,"TT-RTS)RP@1&%T95]#86QC.CIG<F5G;W)I86Y4;TE33R@G,C(G+"`G
M,3$G+"`G,C`P,"<I+"`G9W)E9V]R:6%N5&])4T\@<W1R)RD["F-O;7!A<F4H
M)S(P,#`M-#<M,R<L($1A=&5?0V%L8SHZ9W)E9V]R:6%N5&])4T\H,C(L(#$Q
M+"`R,#`P*2P@)V=R96=O<FEA;E1O25-/)RD["F-O;7!A<F4H,C0U,3<Q-BXU
M-C<V-RP@1&%T95]#86QC.CID871E4V5A<V]N*"=354U-15)33TQ35$E#12<L
M(#(P,#`I+"`G9&%T95-E87-O;B<I.PH*8V]M<&%R92AD871E*"=9;60G*2P@
M1&%T95]#86QC.CID871E3F]W*"DL("=D871E3F]W)RD["F-O;7!A<F4H9&%T
M92@G62<I+"!$871E7T-A;&,Z.F=E=%EE87(H*2P@)V=E=%EE87(G*3L*8V]M
M<&%R92AD871E*"=M)RDL($1A=&5?0V%L8SHZ9V5T36]N=&@H*2P@)V=E=$UO
M;G1H)RD["F-O;7!A<F4H9&%T92@G9"<I+"!$871E7T-A;&,Z.F=E=$1A>2@I
M+"`G9V5T1&%Y)RD["@IC;VUP87)E*#,R-RP@1&%T95]#86QC.CIJ=6QI86Y$
M871E*#(R+"`Q,2P@,C`P,"DL("=J=6QI86Y$871E)RD["F-O;7!A<F4H)TYO
M=F5M8F5R)RP@1&%T95]#86QC.CIG971-;VYT:$9U;&QN86UE*#$Q*2P@)V=E
M=$UO;G1H1G5L;&YA;64G*3L*8V]M<&%R92@G3F]V)RP@1&%T95]#86QC.CIG
M971-;VYT:$%B8G)N86UE*#$Q*2P@)V=E=$UO;G1H06)B<FYA;64G*3L*8V]M
M<&%R92@G4V%T=7)D87DG+"!$871E7T-A;&,Z.F=E=%=E96MD87E&=6QL;F%M
M92@Q+"`Q+"`R,#`U*2P@)V=E=%=E96MD87E&=6QL;F%M92<I.PIC;VUP87)E
M*"=3870G+"!$871E7T-A;&,Z.F=E=%=E96MD87E!8F)R;F%M92@Q+"`Q+"`R
M,#`U*2P@)V=E=%=E96MD87E!8F)R;F%M92<I.PIC;VUP87)E*#$Q+"!$871E
M7T-A;&,Z.F=E=$UO;G1H1G)O;49U;&Q.86UE*"=.;W9E;6)E<B<I+"`G9V5T
M36]N=&A&<F]M1G5L;$YA;64G*3L*"F-O;7!A<F4H,S(W+"!$871E7T-A;&,Z
M.FIU;&EA;D1A=&4H)S(R)RP@)S$Q)RP@)S(P,#`G*2P@)VIU;&EA;D1A=&4@
M<W1R)RD["F-O;7!A<F4H)TYO=F5M8F5R)RP@1&%T95]#86QC.CIG971-;VYT
M:$9U;&QN86UE*"<Q,2<I+"`G9V5T36]N=&A&=6QL;F%M92!S='(G*3L*8V]M
M<&%R92@G3F]V)RP@1&%T95]#86QC.CIG971-;VYT:$%B8G)N86UE*"<Q,2<I
M+"`G9V5T36]N=&A!8F)R;F%M92!S='(G*3L*8V]M<&%R92@G4V%T=7)D87DG
M+"!$871E7T-A;&,Z.F=E=%=E96MD87E&=6QL;F%M92@G,#$G+"`G,#$G+"`G
M,C`P-2<I+"`G9V5T5V5E:V1A>49U;&QN86UE('-T<B<I.PIC;VUP87)E*"=3
M870G+"!$871E7T-A;&,Z.F=E=%=E96MD87E!8F)R;F%M92@G,#$G+"`G,#$G
M+"`G,C`P-2<I+"`G9V5T5V5E:V1A>4%B8G)N86UE('-T<B<I.PH*)&5X<"`]
M(&%R<F%Y*`H@("`@)TIA;G5A<GDG+`H@("`@)T9E8G)U87)Y)RP*("`@("=-
M87)C:"<L"B`@("`G07!R:6PG+`H@("`@)TUA>2<L"B`@("`G2G5N92<L"B`@
M("`G2G5L>2<L"B`@("`G075G=7-T)RP*("`@("=397!T96UB97(G+`H@("`@
M)T]C=&]B97(G+`H@("`@)TYO=F5M8F5R)RP*("`@("=$96-E;6)E<B<**3L*
M8V]M<&%R92@D97AP+"!$871E7T-A;&,Z.F=E=$UO;G1H3F%M97,H*2P@)V=E
M=$UO;G1H3F%M97,G*3L*"B1E>'`@/2!A<G)A>2@*("`@("=-;VYD87DG+`H@
M("`@)U1U97-D87DG+`H@("`@)U=E9&YE<V1A>2<L"B`@("`G5&AU<G-D87DG
M+`H@("`@)T9R:61A>2<L"B`@("`G4V%T=7)D87DG+`H@("`@)U-U;F1A>2<*
M*3L*8V]M<&%R92@D97AP+"!$871E7T-A;&,Z.F=E=%=E96M$87ES*"DL("=G
M9717965K1&%Y<R<I.PH*8V]M<&%R92@S+"!$871E7T-A;&,Z.F1A>4]F5V5E
M:R@R,BP@,3$L(#(P,#`I+"`G9&%Y3V97965K)RD["F-O;7!A<F4H-#<L($1A
M=&5?0V%L8SHZ=V5E:T]F665A<B@R,BP@,3$L(#(P,#`I+"`G=V5E:T]F665A
M<B<I.PIC;VUP87)E*#0L($1A=&5?0V%L8SHZ<75A<G1E<D]F665A<B@R,BP@
M,3$L(#(P,#`I+"`G<75A<G1E<D]F665A<B<I.PH*8V]M<&%R92@S+"!$871E
M7T-A;&,Z.F1A>4]F5V5E:R@G,C(G+"`G,3$G+"`G,C`P,"<I+"`G9&%Y3V97
M965K('-T<B<I.PIC;VUP87)E*#0W+"!$871E7T-A;&,Z.G=E96M/9EEE87(H
M)S(R)RP@)S$Q)RP@)S(P,#`G*2P@)W=E96M/9EEE87(@<W1R)RD["F-O;7!A
M<F4H-"P@1&%T95]#86QC.CIQ=6%R=&5R3V9996%R*"<R,B<L("<Q,2<L("<R
M,#`P)RDL("=Q=6%R=&5R3V9996%R('-T<B<I.PH*8V]M<&%R92@R."P@1&%T
M95]#86QC.CID87ES26Y-;VYT:"@R+"`Q.3`P*2P@)V1A>7-);DUO;G1H(#$G
M*3L*8V]M<&%R92@R.2P@1&%T95]#86QC.CID87ES26Y-;VYT:"@R+"`Q.3DV
M*2P@)V1A>7-);DUO;G1H(#(G*3L*8V]M<&%R92@R.2P@1&%T95]#86QC.CID
M87ES26Y-;VYT:"@R+"`R,#`P*2P@)V1A>7-);DUO;G1H(#,G*3L*8V]M<&%R
M92@R."P@1&%T95]#86QC.CID87ES26Y-;VYT:"@R+"`R,#`Q*2P@)V1A>7-)
M;DUO;G1H(#0G*3L*8V]M<&%R92@S,"P@1&%T95]#86QC.CID87ES26Y-;VYT
M:"@Q,2P@,C`P,"DL("=D87ES26Y-;VYT:"`U)RD["@IC;VUP87)E*#(X+"!$
M871E7T-A;&,Z.F1A>7-);DUO;G1H*"<P,B<L(#$Y,#`I+"`G9&%Y<TEN36]N
M=&@@,2!S='(G*3L*8V]M<&%R92@R.2P@1&%T95]#86QC.CID87ES26Y-;VYT
M:"@G,#(G+"`Q.3DV*2P@)V1A>7-);DUO;G1H(#(@<W1R)RD["F-O;7!A<F4H
M,CDL($1A=&5?0V%L8SHZ9&%Y<TEN36]N=&@H)S`R)RP@,C`P,"DL("=D87ES
M26Y-;VYT:"`S('-T<B<I.PIC;VUP87)E*#(X+"!$871E7T-A;&,Z.F1A>7-)
M;DUO;G1H*"<P,B<L(#(P,#$I+"`G9&%Y<TEN36]N=&@@-"!S='(G*3L*8V]M
M<&%R92@S,"P@1&%T95]#86QC.CID87ES26Y-;VYT:"@G,3$G+"`G,C`P,"<I
M+"`G9&%Y<TEN36]N=&@@-2!S='(G*3L*"F-O;7!A<F4H-2P@1&%T95]#86QC
M.CIW965K<TEN36]N=&@H,3$L(#(P,#`I+"`G=V5E:W-);DUO;G1H)RD["F-O
M;7!A<F4H-2P@1&%T95]#86QC.CIW965K<TEN36]N=&@H)S$Q)RP@)S(P,#`G
M*2P@)W=E96MS26Y-;VYT:"!S='(G*3L*"@HD97AP(#T@87)R87DH"B`@("`G
M,3DP,#`R,C8G+`H@("`@)S$Y,#`P,C(W)RP*("`@("<Q.3`P,#(R."<L"B`@
M("`G,3DP,#`S,#$G+`H@("`@)S$Y,#`P,S`R)RP*("`@("<Q.3`P,#,P,R<L
M"B`@("`G,3DP,#`S,#0G+`HI.PIC;VUP87)E*"1E>'`L($1A=&5?0V%L8SHZ
M9V5T0V%L96YD87)7965K*#(W+"`R+"`Q.3`P*2P@)V=E=$-A;&5N9&%R5V5E
M:R`Q)RD["@HD97AP(#T@87)R87DH"B`@("`G,C`P,#`R,C@G+`H@("`@)S(P
M,#`P,C(Y)RP*("`@("<R,#`P,#,P,2<L"B`@("`G,C`P,#`S,#(G+`H@("`@
M)S(P,#`P,S`S)RP*("`@("<R,#`P,#,P-"<L"B`@("`G,C`P,#`S,#4G+`HI
M.PIC;VUP87)E*"1E>'`L($1A=&5?0V%L8SHZ9V5T0V%L96YD87)7965K*#(X
M+"`R+"`R,#`P*2P@)V=E=$-A;&5N9&%R5V5E:R`R)RD["@HD97AP(#T@87)R
M87DH"B`@("`G,C`P,#$Q,C<G+`H@("`@)S(P,#`Q,3(X)RP*("`@("<R,#`P
M,3$R.2<L"B`@("`G,C`P,#$Q,S`G+`H@("`@)S(P,#`Q,C`Q)RP*("`@("<R
M,#`P,3(P,B<L"B`@("`G,C`P,#$R,#,G"BD["F-O;7!A<F4H)&5X<"P@1&%T
M95]#86QC.CIG971#86QE;F1A<E=E96LH,C<L(#$Q+"`R,#`P*2P@)V=E=$-A
M;&5N9&%R5V5E:R`S)RD["F-O;7!A<F4H)&5X<"P@1&%T95]#86QC.CIG971#
M86QE;F1A<E=E96LH)S(W)RP@)S$Q)RP@)S(P,#`G*2P@)V=E=$-A;&5N9&%R
M5V5E:R`S('-T<B<I.PH*)&5X<"`](&%R<F%Y*`H@("`@87)R87DH"B`@("`@
M("`@)S(P,#`Q,#,P)RP*("`@("`@("`G,C`P,#$P,S$G+`H@("`@("`@("<R
M,#`P,3$P,2<L"B`@("`@("`@)S(P,#`Q,3`R)RP*("`@("`@("`G,C`P,#$Q
M,#,G+`H@("`@("`@("<R,#`P,3$P-"<L"B`@("`I+`H@("`@87)R87DH"B`@
M("`@("`@)S(P,#`Q,3`U)RP*("`@("`@("`G,C`P,#$Q,#8G+`H@("`@("`@
M("<R,#`P,3$P-R<L"B`@("`@("`@)S(P,#`Q,3`X)RP*("`@("`@("`G,C`P
M,#$Q,#DG+`H@("`@("`@("<R,#`P,3$Q,"<L"B`@("`@("`@)S(P,#`Q,3$Q
M)RP*("`@("DL"B`@("!A<G)A>2@*("`@("`@("`G,C`P,#$Q,3(G+`H@("`@
M("`@("<R,#`P,3$Q,R<L"B`@("`@("`@)S(P,#`Q,3$T)RP*("`@("`@("`G
M,C`P,#$Q,34G+`H@("`@("`@("<R,#`P,3$Q-B<L"B`@("`@("`@)S(P,#`Q
M,3$W)RP*("`@("`@("`G,C`P,#$Q,3@G+`H@("`@*2P*("`@(&%R<F%Y*`H@
M("`@("`@("<R,#`P,3$Q.2<L"B`@("`@("`@)S(P,#`Q,3(Q)RP*("`@("`@
M("`G,C`P,#$Q,C(G+`H@("`@("`@("<R,#`P,3$R,R<L"B`@("`@("`@)S(P
M,#`Q,3(T)RP*("`@("`@("`G,C`P,#$Q,C4G+`H@("`@("`@("<R,#`P,3$R
M-B<L"B`@("`I+`H@("`@87)R87DH"B`@("`@("`@)S(P,#`Q,3(W)RP*("`@
M("`@("`G,C`P,#$Q,C@G+`H@("`@("`@("<R,#`P,3$R.2<L"B`@("`@("`@
M)S(P,#`Q,3,P)RP*("`@("`@("`G,C`P,#$R,#$G+`H@("`@("`@("<R,#`P
M,3(P,B<L"B`@("`@("`@)S(P,#`Q,C`S)PH@("`@*0HI.PIC;VUP87)E*"1E
M>'`L($1A=&5?0V%L8SHZ9V5T0V%L96YD87)-;VYT:"@Q,2P@,C`P,"DL("=G
M971#86QE;F1A<DUO;G1H)RD["F-O;7!A<F4H)&5X<"P@1&%T95]#86QC.CIG
M971#86QE;F1A<DUO;G1H*"<Q,2<L("<R,#`P)RDL("=G971#86QE;F1A<DUO
M;G1H('-T<B<I.PH*+R\@22!D;VXG="!F965L(&QI:V4@9&5A;&EN9R!W:71H
M('1H:7,@<FEG:'0@;F]W+BXN"B\O8V]M<&%R92@G)RP@1&%T95]#86QC.CIG
M971#86QE;F1A<EEE87(H,C`P,"DL("=G971#86QE;F1A<EEE87(G*3L*"F-O
M;7!A<F4H)S(P,#`Q,3(Q)RP@1&%T95]#86QC.CIP<F5V1&%Y*#(R+"`Q,2P@
M,C`P,"DL("=P<F5V1&%Y)RD["F-O;7!A<F4H)S(P,#`Q,3(S)RP@1&%T95]#
M86QC.CIN97AT1&%Y*#(R+"`Q,2P@,C`P,"DL("=N97AT1&%Y)RD["F-O;7!A
M<F4H)S(P,#`Q,3(Q)RP@1&%T95]#86QC.CIP<F5V1&%Y*#(R+"`Q,2P@,C`P
M,"DL("=P<F5V1&%Y('-T<B<I.PIC;VUP87)E*"<R,#`P,3$R,R<L($1A=&5?
M0V%L8SHZ;F5X=$1A>2@G,C(G+"`G,3$G+"`G,C`P,"<I+"`G;F5X=$1A>2!S
M='(G*3L*"F-O;7!A<F4H)S(P,#`Q,3$W)RP@1&%T95]#86QC.CIP<F5V5V5E
M:V1A>2@G,3DG+"`G,3$G+"`G,C`P,"<I+"`G<')E=E=E96MD87D@,2!S='(G
M*3L*8V]M<&%R92@G,C`P,#$Q,3<G+"!$871E7T-A;&,Z.G!R9797965K9&%Y
M*#$Y+"`Q,2P@,C`P,"DL("=P<F5V5V5E:V1A>2`Q)RD["F-O;7!A<F4H)S(P
M,#`Q,3(Q)RP@1&%T95]#86QC.CIP<F5V5V5E:V1A>2@R,BP@,3$L(#(P,#`I
M+"`G<')E=E=E96MD87D@,B<I.PIC;VUP87)E*"<R,#`P,3$R,R<L($1A=&5?
M0V%L8SHZ;F5X=%=E96MD87DH,C(L(#$Q+"`R,#`P*2P@)VYE>'17965K9&%Y
M(#$G*3L*8V]M<&%R92@G,C`P,#$Q,C<G+"!$871E7T-A;&,Z.FYE>'17965K
M9&%Y*#(T+"`Q,2P@,C`P,"DL("=N97AT5V5E:V1A>2`R)RD["F-O;7!A<F4H
M)S(P,#`Q,3(W)RP@1&%T95]#86QC.CIN97AT5V5E:V1A>2@G,C0G+"`G,3$G
M+"`G,C`P,"<I+"`G;F5X=%=E96MD87D@,B!S='(G*3L*"F-O;7!A<F4H)S(P
M,#`Q,3(Q)RP@1&%T95]#86QC.CIP<F5V1&%Y3V97965K*"<R)RP@)S(R)RP@
M)S$Q)RP@)S(P,#`G*2P@)W!R979$87E/9E=E96L@,2!S='(G*3L*8V]M<&%R
M92@G,C`P,#$Q,C$G+"!$871E7T-A;&,Z.G!R979$87E/9E=E96LH,BP@,C(L
M(#$Q+"`R,#`P*2P@)W!R979$87E/9E=E96L@,2<I.PIC;VUP87)E*"<R,#`P
M,3$Q-2<L($1A=&5?0V%L8SHZ<')E=D1A>4]F5V5E:R@S+"`R,BP@,3$L(#(P
M,#`I+"`G<')E=D1A>4]F5V5E:R`R)RD["F-O;7!A<F4H)S(P,#`Q,3(R)RP@
M1&%T95]#86QC.CIP<F5V1&%Y3V97965K*#,L(#(R+"`Q,2P@,C`P,"P@)R59
M)6TE9"<L('1R=64I+"`G<')E=D1A>4]F5V5E:R`S)RD["F-O;7!A<F4H)S(P
M,#`Q,3(R)RP@1&%T95]#86QC.CIN97AT1&%Y3V97965K*#,L(#(R+"`Q,2P@
M,C`P,"P@)R59)6TE9"<L('1R=64I+"`G;F5X=$1A>4]F5V5E:R`Q)RD["F-O
M;7!A<F4H)S(P,#`Q,3(Y)RP@1&%T95]#86QC.CIN97AT1&%Y3V97965K*#,L
M(#(R+"`Q,2P@,C`P,"DL("=N97AT1&%Y3V97965K(#(G*3L*8V]M<&%R92@G
M,C`P,#$Q,C,G+"!$871E7T-A;&,Z.FYE>'1$87E/9E=E96LH-"P@,C(L(#$Q
M+"`R,#`P*2P@)VYE>'1$87E/9E=E96L@,R<I.PIC;VUP87)E*"<R,#`P,3$R
M,R<L($1A=&5?0V%L8SHZ;F5X=$1A>4]F5V5E:R@G-"<L("<R,B<L("<Q,2<L
M("<R,#`P)RDL("=N97AT1&%Y3V97965K(#,@<W1R)RD["@IC;VUP87)E*"<R
M,#`P,3$R,2<L($1A=&5?0V%L8SHZ<')E=D1A>4]F5V5E:T]N3W)"969O<F4H
M)S(G+"`G,C(G+"`G,3$G+"`G,C`P,"<I+"`G<')E=D1A>4]F5V5E:T]N3W)"
M969O<F4@,2!S='(G*3L*8V]M<&%R92@G,C`P,#$Q,C$G+"!$871E7T-A;&,Z
M.G!R979$87E/9E=E96M/;D]R0F5F;W)E*#(L(#(R+"`Q,2P@,C`P,"DL("=P
M<F5V1&%Y3V97965K3VY/<D)E9F]R92`Q)RD["F-O;7!A<F4H)S(P,#`Q,3(R
M)RP@1&%T95]#86QC.CIP<F5V1&%Y3V97965K3VY/<D)E9F]R92@S+"`R,BP@
M,3$L(#(P,#`I+"`G<')E=D1A>4]F5V5E:T]N3W)"969O<F4@,B<I.PIC;VUP
M87)E*"<R,#`P,3$R,B<L($1A=&5?0V%L8SHZ;F5X=$1A>4]F5V5E:T]N3W)!
M9G1E<B@S+"`R,BP@,3$L(#(P,#`I+"`G;F5X=$1A>4]F5V5E:T]N3W)!9G1E
M<B`Q)RD["F-O;7!A<F4H)S(P,#`Q,3(S)RP@1&%T95]#86QC.CIN97AT1&%Y
M3V97965K3VY/<D%F=&5R*#0L(#(R+"`Q,2P@,C`P,"DL("=N97AT1&%Y3V97
M965K3VY/<D%F=&5R(#(G*3L*8V]M<&%R92@G,C`P,#$Q,C,G+"!$871E7T-A
M;&,Z.FYE>'1$87E/9E=E96M/;D]R069T97(H)S0G+"`G,C(G+"`G,3$G+"`G
M,C`P,"<I+"`G;F5X=$1A>4]F5V5E:T]N3W)!9G1E<B`R('-T<B<I.PH*8V]M
M<&%R92@G,C`P,#$Q,C`G+"!$871E7T-A;&,Z.F)E9VEN3V97965K*"<R,B<L
M("<Q,2<L("<R,#`P)RDL("=B96=I;D]F5V5E:R!S='(G*3L*8V]M<&%R92@G
M,C`P,#$Q,C`G+"!$871E7T-A;&,Z.F)E9VEN3V97965K*#(R+"`Q,2P@,C`P
M,"DL("=B96=I;D]F5V5E:R<I.PIC;VUP87)E*"<R,#`P,3$R-B<L($1A=&5?
M0V%L8SHZ96YD3V97965K*#(R+"`Q,2P@,C`P,"DL("=E;F1/9E=E96LG*3L*
M8V]M<&%R92@G,C`P,#$Q,C8G+"!$871E7T-A;&,Z.F5N9$]F5V5E:R@G,C(G
M+"`G,3$G+"`G,C`P,"<I+"`G96YD3V97965K('-T<B<I.PH*8V]M<&%R92@G
M,C`P,#$Q,3,G+"!$871E7T-A;&,Z.F)E9VEN3V90<F5V5V5E:R@R,BP@,3$L
M(#(P,#`I+"`G8F5G:6Y/9E!R9797965K)RD["F-O;7!A<F4H)S(P,#`Q,3(W
M)RP@1&%T95]#86QC.CIB96=I;D]F3F5X=%=E96LH,C(L(#$Q+"`R,#`P*2P@
M)V)E9VEN3V9.97AT5V5E:R<I.PIC;VUP87)E*"<R,#`P,3$Q,R<L($1A=&5?
M0V%L8SHZ8F5G:6Y/9E!R9797965K*"<R,B<L("<Q,2<L("<R,#`P)RDL("=B
M96=I;D]F4')E=E=E96L@<W1R)RD["F-O;7!A<F4H)S(P,#`Q,3(W)RP@1&%T
M95]#86QC.CIB96=I;D]F3F5X=%=E96LH)S(R)RP@)S$Q)RP@)S(P,#`G*2P@
M)V)E9VEN3V9.97AT5V5E:R!S='(G*3L*"F-O;7!A<F4H)S(P,#`Q,3`Q)RP@
M1&%T95]#86QC.CIB96=I;D]F36]N=&@H,3$L(#(P,#`I+"`G8F5G:6Y/9DUO
M;G1H)RD["F-O;7!A<F4H)S(P,#`Q,3`Q)RP@1&%T95]#86QC.CIB96=I;D]F
M36]N=&@H)S$Q)RP@)S(P,#`G*2P@)V)E9VEN3V9-;VYT:"!S='(G*3L*"F-O
M;7!A<F4H)S(P,#`Q,#`Q)RP@1&%T95]#86QC.CIB96=I;D]F4')E=DUO;G1H
M*#(R+"`Q,2P@,C`P,"DL("=B96=I;D]F4')E=DUO;G1H)RD["F-O;7!A<F4H
M)S(P,#`Q,#,Q)RP@1&%T95]#86QC.CIE;F1/9E!R979-;VYT:"@R,BP@,3$L
M(#(P,#`I+"`G96YD3V90<F5V36]N=&@G*3L*8V]M<&%R92@G,C`P,#$P,#$G
M+"!$871E7T-A;&,Z.F)E9VEN3V90<F5V36]N=&@H)S(R)RP@)S$Q)RP@)S(P
M,#`G*2P@)V)E9VEN3V90<F5V36]N=&@@<W1R)RD["F-O;7!A<F4H)S(P,#`Q
M,#,Q)RP@1&%T95]#86QC.CIE;F1/9E!R979-;VYT:"@G,C(G+"`G,3$G+"`G
M,C`P,"<I+"`G96YD3V90<F5V36]N=&@@<W1R)RD["@IC;VUP87)E*"<R,#`P
M,3(P,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9DYE>'1-;VYT:"@R,BP@,3$L(#(P
M,#`I+"`G8F5G:6Y/9DYE>'1-;VYT:"<I.PIC;VUP87)E*"<R,#`P,3(S,2<L
M($1A=&5?0V%L8SHZ96YD3V9.97AT36]N=&@H,C(L(#$Q+"`R,#`P*2P@)V5N
M9$]F3F5X=$UO;G1H)RD["F-O;7!A<F4H)S(P,#`Q,C`Q)RP@1&%T95]#86QC
M.CIB96=I;D]F3F5X=$UO;G1H*"<R,B<L("<Q,2<L("<R,#`P)RDL("=B96=I
M;D]F3F5X=$UO;G1H('-T<B<I.PIC;VUP87)E*"<R,#`P,3(S,2<L($1A=&5?
M0V%L8SHZ96YD3V9.97AT36]N=&@H)S(R)RP@)S$Q)RP@)S(P,#`G*2P@)V5N
M9$]F3F5X=$UO;G1H('-T<B<I.PH*8V]M<&%R92@G,3DY.3$P,#$G+"!$871E
M7T-A;&,Z.F)E9VEN3V9-;VYT:$)Y4W!A;B@M,3,L(#$Q+"`R,#`P*2P@)V)E
M9VEN3V9-;VYT:$)Y4W!A;B`Q)RD["F-O;7!A<F4H)S(P,#`Q,#`Q)RP@1&%T
M95]#86QC.CIB96=I;D]F36]N=&A">5-P86XH+3$L(#$Q+"`R,#`P*2P@)V)E
M9VEN3V9-;VYT:$)Y4W!A;B`R)RD["F-O;7!A<F4H)S(P,#`Q,3`Q)RP@1&%T
M95]#86QC.CIB96=I;D]F36]N=&A">5-P86XH,"P@,3$L(#(P,#`I+"`G8F5G
M:6Y/9DUO;G1H0GE3<&%N(#,G*3L*8V]M<&%R92@G,C`P,#$R,#$G+"!$871E
M7T-A;&,Z.F)E9VEN3V9-;VYT:$)Y4W!A;B@Q+"`Q,2P@,C`P,"DL("=B96=I
M;D]F36]N=&A">5-P86X@-"<I.PIC;VUP87)E*"<R,#`Q,3(P,2<L($1A=&5?
M0V%L8SHZ8F5G:6Y/9DUO;G1H0GE3<&%N*#$S+"`Q,2P@,C`P,"DL("=B96=I
M;D]F36]N=&A">5-P86X@-2<I.PH*8V]M<&%R92@G,3DY.3`Q,#$G+"!$871E
M7T-A;&,Z.F)E9VEN3V9-;VYT:$)Y4W!A;B@G+3$S)RP@)S`R)RP@)S(P,#`G
M*2P@)V)E9VEN3V9-;VYT:$)Y4W!A;B`V('-T<B<I.PIC;VUP87)E*"<Q.3DY
M,#$P,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9DUO;G1H0GE3<&%N*"TQ,RP@,BP@
M,C`P,"DL("=B96=I;D]F36]N=&A">5-P86X@-B<I.PIC;VUP87)E*"<R,#`P
M,#$P,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9DUO;G1H0GE3<&%N*"TQ+"`R+"`R
M,#`P*2P@)V)E9VEN3V9-;VYT:$)Y4W!A;B`W)RD["F-O;7!A<F4H)S(P,#`P
M,C`Q)RP@1&%T95]#86QC.CIB96=I;D]F36]N=&A">5-P86XH,"P@,BP@,C`P
M,"DL("=B96=I;D]F36]N=&A">5-P86X@."<I.PIC;VUP87)E*"<R,#`P,#,P
M,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9DUO;G1H0GE3<&%N*#$L(#(L(#(P,#`I
M+"`G8F5G:6Y/9DUO;G1H0GE3<&%N(#DG*3L*8V]M<&%R92@G,C`P,3`S,#$G
M+"!$871E7T-A;&,Z.F)E9VEN3V9-;VYT:$)Y4W!A;B@Q,RP@,BP@,C`P,"DL
M("=B96=I;D]F36]N=&A">5-P86X@,3`G*3L*8V]M<&%R92@G,C`P,3`S,#$G
M+"!$871E7T-A;&,Z.F)E9VEN3V9-;VYT:$)Y4W!A;B@G,3,G+"`G,#(G+"`G
M,C`P,"<I+"`G8F5G:6Y/9DUO;G1H0GE3<&%N(#$P('-T<B<I.PH*8V]M<&%R
M92@G,3DY.3$P,S$G+"!$871E7T-A;&,Z.F5N9$]F36]N=&A">5-P86XH+3$S
M+"`Q,2P@,C`P,"DL("=E;F1/9DUO;G1H0GE3<&%N(#$G*3L*8V]M<&%R92@G
M,C`P,#$P,S$G+"!$871E7T-A;&,Z.F5N9$]F36]N=&A">5-P86XH+3$L(#$Q
M+"`R,#`P*2P@)V5N9$]F36]N=&A">5-P86X@,B<I.PIC;VUP87)E*"<R,#`P
M,3$S,"<L($1A=&5?0V%L8SHZ96YD3V9-;VYT:$)Y4W!A;B@P+"`Q,2P@,C`P
M,"DL("=E;F1/9DUO;G1H0GE3<&%N(#,G*3L*8V]M<&%R92@G,C`P,#$R,S$G
M+"!$871E7T-A;&,Z.F5N9$]F36]N=&A">5-P86XH,2P@,3$L(#(P,#`I+"`G
M96YD3V9-;VYT:$)Y4W!A;B`T)RD["F-O;7!A<F4H)S(P,#$Q,C,Q)RP@1&%T
M95]#86QC.CIE;F1/9DUO;G1H0GE3<&%N*#$S+"`Q,2P@,C`P,"DL("=E;F1/
M9DUO;G1H0GE3<&%N(#4G*3L*"F-O;7!A<F4H)S$Y.3DP,3,Q)RP@1&%T95]#
M86QC.CIE;F1/9DUO;G1H0GE3<&%N*"<M,3,G+"`G,#(G+"`G,C`P,"<I+"`G
M96YD3V9-;VYT:$)Y4W!A;B`V('-T<B<I.PIC;VUP87)E*"<Q.3DY,#$S,2<L
M($1A=&5?0V%L8SHZ96YD3V9-;VYT:$)Y4W!A;B@M,3,L(#(L(#(P,#`I+"`G
M96YD3V9-;VYT:$)Y4W!A;B`V)RD["F-O;7!A<F4H)S(P,#`P,3,Q)RP@1&%T
M95]#86QC.CIE;F1/9DUO;G1H0GE3<&%N*"TQ+"`R+"`R,#`P*2P@)V5N9$]F
M36]N=&A">5-P86X@-R<I.PIC;VUP87)E*"<R,#`P,#(R.2<L($1A=&5?0V%L
M8SHZ96YD3V9-;VYT:$)Y4W!A;B@P+"`R+"`R,#`P*2P@)V5N9$]F36]N=&A"
M>5-P86X@."<I.PIC;VUP87)E*"<R,#`P,#,S,2<L($1A=&5?0V%L8SHZ96YD
M3V9-;VYT:$)Y4W!A;B@Q+"`R+"`R,#`P*2P@)V5N9$]F36]N=&A">5-P86X@
M.2<I.PIC;VUP87)E*"<R,#`Q,#,S,2<L($1A=&5?0V%L8SHZ96YD3V9-;VYT
M:$)Y4W!A;B@Q,RP@,BP@,C`P,"DL("=E;F1/9DUO;G1H0GE3<&%N(#$P)RD[
M"F-O;7!A<F4H)S(P,#$P,S,Q)RP@1&%T95]#86QC.CIE;F1/9DUO;G1H0GE3
M<&%N*"<Q,R<L("<P,B<L("<R,#`P)RDL("=E;F1/9DUO;G1H0GE3<&%N(#$P
M('-T<B<I.PH*8V]M<&%R92@S+"!$871E7T-A;&,Z.F9I<G-T3V9-;VYT:%=E
M96MD87DH,3$L(#(P,#`I+"`G9FER<W1/9DUO;G1H5V5E:V1A>2<I.PIC;VUP
M87)E*#,L($1A=&5?0V%L8SHZ9FER<W1/9DUO;G1H5V5E:V1A>2@G,3$G+"`G
M,C`P,"<I+"`G9FER<W1/9DUO;G1H5V5E:V1A>2!S='(G*3L*"F-O;7!A<F4H
M)S(P,#4P,3`Q)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H,2P@-BP@
M,2P@,C`P-2DL("=.5V5E:V1A>4]F36]N=&@@,38Q)RD["F-O;7!A<F4H)S(P
M,#4P,3`R)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H,2P@,"P@,2P@
M,C`P-2DL("=.5V5E:V1A>4]F36]N=&@@,3`Q)RD["F-O;7!A<F4H)S(P,#4P
M,3`S)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H,2P@,2P@,2P@,C`P
M-2DL("=.5V5E:V1A>4]F36]N=&@@,3$Q)RD["F-O;7!A<F4H)S(P,#4P,3`T
M)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H,2P@,BP@,2P@,C`P-2DL
M("=.5V5E:V1A>4]F36]N=&@@,3(Q)RD["F-O;7!A<F4H)S(P,#4P,3`U)RP@
M1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H,2P@,RP@,2P@,C`P-2DL("=.
M5V5E:V1A>4]F36]N=&@@,3,Q)RD["F-O;7!A<F4H)S(P,#4P,3`V)RP@1&%T
M95]#86QC.CI.5V5E:V1A>4]F36]N=&@H,2P@-"P@,2P@,C`P-2DL("=.5V5E
M:V1A>4]F36]N=&@@,30Q)RD["F-O;7!A<F4H)S(P,#4P,3`W)RP@1&%T95]#
M86QC.CI.5V5E:V1A>4]F36]N=&@H,2P@-2P@,2P@,C`P-2DL("=.5V5E:V1A
M>4]F36]N=&@@,34Q)RD["@IC;VUP87)E*"<R,#`U,#$P."<L($1A=&5?0V%L
M8SHZ3E=E96MD87E/9DUO;G1H*"<R)RP@)S8G+"`G,#$G+"`G,C`P-2<I+"`G
M3E=E96MD87E/9DUO;G1H(#(V,2<I.PIC;VUP87)E*"<R,#`U,#$P.2<L($1A
M=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H*"<R)RP@)S`G+"`G,#$G+"`G,C`P
M-2<I+"`G3E=E96MD87E/9DUO;G1H(#(P,2<I.PIC;VUP87)E*"<R,#`U,#$Q
M,"<L($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H*"<R)RP@)S$G+"`G,#$G
M+"`G,C`P-2<I+"`G3E=E96MD87E/9DUO;G1H(#(Q,2<I.PIC;VUP87)E*"<R
M,#`U,#$Q,2<L($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H*"<R)RP@)S(G
M+"`G,#$G+"`G,C`P-2<I+"`G3E=E96MD87E/9DUO;G1H(#(R,2<I.PIC;VUP
M87)E*"<R,#`U,#$Q,B<L($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H*"<R
M)RP@)S,G+"`G,#$G+"`G,C`P-2<I+"`G3E=E96MD87E/9DUO;G1H(#(S,2<I
M.PIC;VUP87)E*"<R,#`U,#$Q,R<L($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO
M;G1H*"<R)RP@)S0G+"`G,#$G+"`G,C`P-2<I+"`G3E=E96MD87E/9DUO;G1H
M(#(T,2<I.PIC;VUP87)E*"<R,#`U,#$Q-"<L($1A=&5?0V%L8SHZ3E=E96MD
M87E/9DUO;G1H*"<R)RP@)S4G+"`G,#$G+"`G,C`P-2<I+"`G3E=E96MD87E/
M9DUO;G1H(#(U,2<I.PH*8V]M<&%R92@G,C`P-3`Q,S$G+"!$871E7T-A;&,Z
M.DY7965K9&%Y3V9-;VYT:"@G;&%S="<L(#$L(#$L(#(P,#4I+"`G3E=E96MD
M87E/9DUO;G1H(&PQ,2<I.PIC;VUP87)E*"<R,#`U,#$S,"<L($1A=&5?0V%L
M8SHZ3E=E96MD87E/9DUO;G1H*"=L87-T)RP@,"P@,2P@,C`P-2DL("=.5V5E
M:V1A>4]F36]N=&@@;#`Q)RD["F-O;7!A<F4H)S(P,#4P,3(Y)RP@1&%T95]#
M86QC.CI.5V5E:V1A>4]F36]N=&@H)VQA<W0G+"`V+"`Q+"`R,#`U*2P@)TY7
M965K9&%Y3V9-;VYT:"!L-C$G*3L*8V]M<&%R92@G,C`P-3`Q,C@G+"!$871E
M7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@G;&%S="<L(#4L(#$L(#(P,#4I+"`G
M3E=E96MD87E/9DUO;G1H(&PU,2<I.PIC;VUP87)E*"<R,#`U,#$R-R<L($1A
M=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H*"=L87-T)RP@-"P@,2P@,C`P-2DL
M("=.5V5E:V1A>4]F36]N=&@@;#0Q)RD["F-O;7!A<F4H)S(P,#4P,3(V)RP@
M1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H)VQA<W0G+"`S+"`Q+"`R,#`U
M*2P@)TY7965K9&%Y3V9-;VYT:"!L,S$G*3L*8V]M<&%R92@G,C`P-3`Q,C4G
M+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@G;&%S="<L(#(L(#$L(#(P
M,#4I+"`G3E=E96MD87E/9DUO;G1H(&PR,2<I.PH*8V]M<&%R92@G,C`P-3`S
M,S$G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@G;&%S="<L(#0L(#,L
M(#(P,#4I+"`G3E=E96MD87E/9DUO;G1H(&PT,R<I.PIC;VUP87)E*"<R,#`U
M,#,S,"<L($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H*"=L87-T)RP@,RP@
M,RP@,C`P-2DL("=.5V5E:V1A>4]F36]N=&@@;#,S)RD["F-O;7!A<F4H)S(P
M,#4P,S(Y)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H)VQA<W0G+"`R
M+"`S+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT:"!L,C,G*3L*8V]M<&%R92@G
M,C`P-3`S,C@G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@G;&%S="<L
M(#$L(#,L(#(P,#4I+"`G3E=E96MD87E/9DUO;G1H(&PQ,R<I.PIC;VUP87)E
M*"<R,#`U,#,R-R<L($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H*"=L87-T
M)RP@,"P@,RP@,C`P-2DL("=.5V5E:V1A>4]F36]N=&@@;#`S)RD["F-O;7!A
M<F4H)S(P,#4P,S(V)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H)VQA
M<W0G+"`V+"`S+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT:"!L-C,G*3L*8V]M
M<&%R92@G,C`P-3`S,C4G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@G
M;&%S="<L(#4L(#,L(#(P,#4I+"`G3E=E96MD87E/9DUO;G1H(&PU,R<I.PH*
M"F-O;7!A<F4H9F%L<V4L($1A=&5?0V%L8SHZ:7-686QI9$1A=&4H,CDL(#(L
M(#$Y,#`I+"`G:7-686QI9$1A=&4@,2<I.PIC;VUP87)E*'1R=64L($1A=&5?
M0V%L8SHZ:7-686QI9$1A=&4H,CDL(#(L(#(P,#`I+"`G:7-686QI9$1A=&4@
M,B<I.PIC;VUP87)E*'1R=64L($1A=&5?0V%L8SHZ:7-686QI9$1A=&4H)S(Y
M)RP@)S`R)RP@)S(P,#`G*2P@)VES5F%L:61$871E(#(@<W1R)RD["@IC;VUP
M87)E*&9A;'-E+"!$871E7T-A;&,Z.FES3&5A<%EE87(H,3DP,"DL("=I<TQE
M87!996%R(#$G*3L*8V]M<&%R92AT<G5E+"!$871E7T-A;&,Z.FES3&5A<%EE
M87(H,3DY-BDL("=I<TQE87!996%R(#(G*3L*8V]M<&%R92AT<G5E+"!$871E
M7T-A;&,Z.FES3&5A<%EE87(H,C`P,"DL("=I<TQE87!996%R(#,G*3L*8V]M
M<&%R92AF86QS92P@1&%T95]#86QC.CII<TQE87!996%R*#(P,#$I+"`G:7-,
M96%P665A<B`T)RD["F-O;7!A<F4H9F%L<V4L($1A=&5?0V%L8SHZ:7-,96%P
M665A<B@G,C`P,2<I+"`G:7-,96%P665A<B`T('-T<B<I.PH*8V]M<&%R92AF
M86QS92P@1&%T95]#86QC.CII<T9U='5R941A=&4H)S(R)RP@)S$Q)RP@)S(P
M,#`G*2P@)VES1G5T=7)E1&%T92`Q('-T<B<I.PIC;VUP87)E*&9A;'-E+"!$
M871E7T-A;&,Z.FES1G5T=7)E1&%T92@R,BP@,3$L(#(P,#`I+"`G:7-&=71U
M<F5$871E(#$G*3L*8V]M<&%R92AT<G5E+"!$871E7T-A;&,Z.FES1G5T=7)E
M1&%T92@R,BP@,3$L(&1A=&4H)UDG*2`K(#$I+"`G:7-&=71U<F5$871E(#(G
M*3L*"F-O;7!A<F4H9F%L<V4L($1A=&5?0V%L8SHZ:7-087-T1&%T92@R,BP@
M,3$L(&1A=&4H)UDG*2`K(#$I+"`G:7-087-T1&%T92`Q)RD["F-O;7!A<F4H
M=')U92P@1&%T95]#86QC.CII<U!A<W1$871E*#(R+"`Q,2P@,C`P,"DL("=I
M<U!A<W1$871E(#(G*3L*8V]M<&%R92AT<G5E+"!$871E7T-A;&,Z.FES4&%S
M=$1A=&4H)S(R)RP@)S$Q)RP@)S(P,#`G*2P@)VES4&%S=$1A=&4@,B!S='(G
M*3L*"F-O;7!A<F4H,3`L($1A=&5?0V%L8SHZ9&%T941I9F8H,C(L(#$Q+"`R
M,#`P+"`Q,BP@,3$L(#(P,#`I+"`G9&%T941I9F8@,2<I.PIC;VUP87)E*#$P
M+"!$871E7T-A;&,Z.F1A=&5$:69F*#$R+"`Q,2P@,C`P,"P@,C(L(#$Q+"`R
M,#`P*2P@)V1A=&5$:69F(#(G*3L*8V]M<&%R92@V,2P@1&%T95]#86QC.CID
M871E1&EF9B@R,BP@,3$L(#(P,#`L(#(R+"`Q+"`R,#`Q*2P@)V1A=&5$:69F
M(#,G*3L*8V]M<&%R92@V,2P@1&%T95]#86QC.CID871E1&EF9B@G,C(G+"`G
M,3$G+"`G,C`P,"<L("<R,B<L("<P,2<L("<R,#`Q)RDL("=D871E1&EF9B`S
M('-T<B<I.PH*8V]M<&%R92@M,2P@1&%T95]#86QC.CIC;VUP87)E1&%T97,H
M,3(L(#$Q+"`R,#`P+"`R,BP@,3$L(#(P,#`I+"`G8V]M<&%R941A=&5S(#$G
M*3L*8V]M<&%R92@P+"!$871E7T-A;&,Z.F-O;7!A<F5$871E<R@R,BP@,3$L
M(#(P,#`L(#(R+"`Q,2P@,C`P,"DL("=C;VUP87)E1&%T97,@,B<I.PIC;VUP
M87)E*#$L($1A=&5?0V%L8SHZ8V]M<&%R941A=&5S*#(R+"`Q,2P@,C`P,"P@
M,3(L(#$Q+"`R,#`P*2P@)V-O;7!A<F5$871E<R`S)RD["F-O;7!A<F4H,2P@
M1&%T95]#86QC.CIC;VUP87)E1&%T97,H)S(R)RP@)S$Q)RP@)S(P,#`G+"`G
M,3(G+"`G,3$G+"`G,C`P,"<I+"`G8V]M<&%R941A=&5S(#,@<W1R)RD["@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+W1E<W1S+T1A=&4O=&5S=',O=&5S='5N:70N<&AP````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#(W-#,@,3`U,34T,S,W,S,@,#(T,C0U`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT.B`J
M+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@=F5R
M<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`U("!-87)S:&%L;"!2
M;V-H("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I
M<R!S=6)J96-T('1O('1H92!.97<@0E-$(&QI8V5N<V4L(%1H870@:7,@8G5N
M9&QE9"`@?`HO+R!\('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)
M0T5.4T4L(&%N9"!I<R!A=F%I;&%B;&4@=&AR;W5G:"`@("`@('P*+R\@?"!T
M:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYO<&5N
M<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@("`@("`@("`@
M("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y
M(&]F('1H92!N97<@0E-$;&EC96YS92!A;F0@87)E('5N86)L92`@('P*+R\@
M?"!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L
M96%S92!S96YD(&$@;F]T92!T;R`@("`@("!\"B\O('P@<&5A<BUD979`;&ES
M=',N<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+B`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\@?"!!=71H;W)S.B!-87)S:&%L;"!2;V-H(#QM<F]C:$!P:'`N;F5T/B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z('1E<W1U;FET+G!H<"QV(#$N
M,B`R,#`U+S$Q+S$U(#`P.C$V.C0P('!A:F]Y92!%>'`@)`H*+RHJ"B`J($1I
M<W!L87ES(&%L;"!T97-T(&-A<V5S(&]N('1H92!S86UE('!A9V4*("H*("H@
M0'!A8VMA9V4@1&%T90H@*B!`875T:&]R($UA<G-H86QL(%)O8V@@/&UR;V-H
M0'!H<"YN970^"B`J+PH*"F5C:&\@(CQP<F4^(CL*<F5Q=6ER95]O;F-E("=0
M2%!5;FET+G!H<"<["G)E<75I<F5?;VYC92`G=&5S='5N:71?9&%T92YP:'`G
M.PIR97%U:7)E7V]N8V4@)W1E<W1U;FET7V1A=&5?<W!A;BYP:'`G.PIE8VAO
M("(\+W!R93XB.PH_/@H``````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1&%T92]T97-T<R]T
M97-T=6YI=%]D871E+G!H<```````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R,#`U-"`Q
M,#4Q-30S,S<S,R`P,C4R,S4`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+R\@=FEM.B!S970@97AP86YD=&%B('1A
M8G-T;W`]-"!S;V9T=&%B<W1O<#TT('-H:69T=VED=&@]-#H*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#
M;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!-87)S:&%L;"!2;V-H("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T
M;R!T:&4@3F5W($)31"!L:6-E;G-E+"!4:&%T(&ES(&)U;F1L960@('P*+R\@
M?"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@
M:7,@879A:6QA8FQE('1H<F]U9V@@("`@("!\"B\O('P@=&AE('=O<FQD+7=I
M9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O
M;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("`@("`@("`@("`@("`@("`@('P*
M+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@;F5W
M($)31&QI8V5N<V4@86YD(&%R92!U;F%B;&4@("!\"B\O('P@=&\@;V)T86EN
M(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A
M(&YO=&4@=&\@("`@("`@?`HO+R!\('!E87(M9&5V0&QI<W1S+G!H<"YN970@
M<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@
M('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R
M.B!-87)S:&%L;"!2;V-H(#QM<F]C:$!P:'`N;F5T/B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\*+R\@)$ED.B!T97-T=6YI=%]D871E+G!H<"QV(#$N,R`R,#`U
M+S$Q+S$U(#`P.C$V.C0P('!A:F]Y92!%>'`@)`HO+PH*<F5Q=6ER95]O;F-E
M("=$871E+G!H<"<["G)E<75I<F5?;VYC92`G4$A056YI="YP:'`G.PH*8VQA
M<W,@;7E$871E(&5X=&5N9',@1&%T92!["B`@("!F=6YC=&EO;B!M>41A=&4H
M)&1A=&4I"B`@("!["B`@("`@("`@)'1H:7,M/D1A=&4H)&1A=&4I.PH@("`@
M?0I]"@HO*BH*("H@5&5S="!C87-E(&9O<B!$871E"B`J"B`J($!P86-K86=E
M($1A=&4*("H@0&%U=&AO<B!-87)S:&%L;"!2;V-H(#QM<F]C:$!P:'`N;F5T
M/@H@*B\*8VQA<W,@1&%T95]497-T(&5X=&5N9',@4$A056YI=%]497-T0V%S
M92!["@H@("`@=F%R("1T:6UE.PH*("`@(&9U;F-T:6]N($1A=&5?5&5S="@D
M;F%M92D*("`@('L*("`@("`@("`D=&AI<RT^4$A056YI=%]497-T0V%S92@D
M;F%M92D["B`@("!]"@H@("`@9G5N8W1I;VX@<V5T57`H*0H@("`@>PH@("`@
M("`@("1T:&ES+3YT:6UE(#T@;F5W($1A=&4H(C(P,#,M,3`M,#0@,30Z,#,Z
M,C0B*3L*("`@('T*"B`@("!F=6YC=&EO;B!T96%R1&]W;B@I"B`@("!["B`@
M("`@("`@=6YS970H)'1H:7,M/G1I;64I.PH@("`@?0H*("`@(&9U;F-T:6]N
M('1E<W1$871E3G5L;"@I"B`@("!["B`@("`@("`@)'1I;64@/2!N97<@1&%T
M92@I.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H"B`@("`@("`@("`@
M(&1A=&4H)UDM;2UD($@Z:3IS)RDL"B`@("`@("`@("`@('-P<FEN=&8H)R4P
M-&0M)3`R9"TE,#)D("4P,F0Z)3`R9#HE,#)D)RP*("`@("`@("`@("`@("`@
M("1T:6UE+3YY96%R+"`D=&EM92T^;6]N=&@L("1T:6UE+3YD87DL"B`@("`@
M("`@("`@("`@("`D=&EM92T^:&]U<BP@)'1I;64M/FUI;G5T92P@)'1I;64M
M/G-E8V]N9"D*("`@("`@("`I.PH@("`@?0H*("`@(&9U;F-T:6]N('1E<W1!
M8G-T<F%C=&EO;B@I"B`@("!["B`@("`@("`@)&0@/2!N97<@1&%T92@I.PH@
M("`@("`@("1M>2`](&YE=R!M>41A=&4H)&0I.PH@("`@("`@("1T:&ES+3YA
M<W-E<G1%<75A;',H)&0M/F=E=$1A=&4H*2PD;7DM/F=E=$1A=&4H*2D["B`@
M("!]"@H@("`@9G5N8W1I;VX@=&5S=$1A=&5#;W!Y*"D*("`@('L*("`@("`@
M("`D=&5M<"`](&YE=R!$871E*"1T:&ES+3YT:6UE*3L*("`@("`@("`D=&AI
M<RT^87-S97)T17%U86QS*"1T96UP+"`D=&AI<RT^=&EM92D["B`@("!]"@H@
M("`@9G5N8W1I;VX@=&5S=$1A=&5)4T\H*0H@("`@>PH@("`@("`@("1T96UP
M(#T@;F5W($1A=&4H(C(P,#,M,3`M,#0@,30Z,#,Z,C0B*3L*("`@("`@("`D
M=&AI<RT^87-S97)T17%U86QS*`H@("`@("`@("`@("`G,C`P,RTQ,"TP-"`Q
M-#HP,SHR-"<L"B`@("`@("`@("`@('-P<FEN=&8H)R4P-&0M)3`R9"TE,#)D
M("4P,F0Z)3`R9#HE,#)D)RP*("`@("`@("`@("`@("`@("1T96UP+3YY96%R
M+"`D=&5M<"T^;6]N=&@L("1T96UP+3YD87DL"B`@("`@("`@("`@("`@("`D
M=&5M<"T^:&]U<BP@)'1E;7`M/FUI;G5T92P@)'1E;7`M/G-E8V]N9"D*("`@
M("`@("`I.PH@("`@?0H*("`@(&9U;F-T:6]N('1E<W1$871E25-/0F%S:6,H
M*0H@("`@>PH@("`@("`@("1T96UP(#T@;F5W($1A=&4H(C(P,#,Q,#`T5#$T
M,#,R-"(I.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H"B`@("`@("`@
M("`@("<R,#`S+3$P+3`T(#$T.C`S.C(T)RP*("`@("`@("`@("`@<W!R:6YT
M9B@G)3`T9"TE,#)D+24P,F0@)3`R9#HE,#)D.B4P,F0G+`H@("`@("`@("`@
M("`@("`@)'1E;7`M/GEE87(L("1T96UP+3YM;VYT:"P@)'1E;7`M/F1A>2P*
M("`@("`@("`@("`@("`@("1T96UP+3YH;W5R+"`D=&5M<"T^;6EN=71E+"`D
M=&5M<"T^<V5C;VYD*0H@("`@("`@("D["B`@("!]"@H@("`@9G5N8W1I;VX@
M=&5S=$1A=&5)4T]%>'1E;F1E9"@I"B`@("!["B`@("`@("`@)'1E;7`@/2!N
M97<@1&%T92@B,C`P,RTQ,"TP-%0Q-#HP,SHR-"(I.PH@("`@("`@("1T:&ES
M+3YA<W-E<G1%<75A;',H"B`@("`@("`@("`@("<R,#`S+3$P+3`T(#$T.C`S
M.C(T)RP*("`@("`@("`@("`@<W!R:6YT9B@G)3`T9"TE,#)D+24P,F0@)3`R
M9#HE,#)D.B4P,F0G+`H@("`@("`@("`@("`@("`@)'1E;7`M/GEE87(L("1T
M96UP+3YM;VYT:"P@)'1E;7`M/F1A>2P*("`@("`@("`@("`@("`@("1T96UP
M+3YH;W5R+"`D=&5M<"T^;6EN=71E+"`D=&5M<"T^<V5C;VYD*0H@("`@("`@
M("D["B`@("!]"@H@("`@9G5N8W1I;VX@=&5S=$1A=&5)4T]4:6UE<W1A;7`H
M*0H@("`@>PH@("`@("`@("1T96UP(#T@;F5W($1A=&4H(C(P,#,Q,#`T,30P
M,S(T(BD["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@*("`@("`@("`@
M("`@)S(P,#,M,3`M,#0@,30Z,#,Z,C0G+`H@("`@("`@("`@("!S<')I;G1F
M*"<E,#1D+24P,F0M)3`R9"`E,#)D.B4P,F0Z)3`R9"<L"B`@("`@("`@("`@
M("`@("`D=&5M<"T^>65A<BP@)'1E;7`M/FUO;G1H+"`D=&5M<"T^9&%Y+`H@
M("`@("`@("`@("`@("`@)'1E;7`M/FAO=7(L("1T96UP+3YM:6YU=&4L("1T
M96UP+3YS96-O;F0I"B`@("`@("`@*3L*("`@('T*"B`@("!F=6YC=&EO;B!T
M97-T1&%T955N:7AT:6UE*"D*("`@('L*("`@("`@("`D=&5M<"`](&YE=R!$
M871E*'-T<G1O=&EM92@B,C`P,RTQ,"TP-"`Q-#HP,SHR-"(I*3L*("`@("`@
M("`D=&AI<RT^87-S97)T17%U86QS*`H@("`@("`@("`@("`G,C`P,RTQ,"TP
M-"`Q-#HP,SHR-"<L"B`@("`@("`@("`@('-P<FEN=&8H)R4P-&0M)3`R9"TE
M,#)D("4P,F0Z)3`R9#HE,#)D)RP*("`@("`@("`@("`@("`@("1T96UP+3YY
M96%R+"`D=&5M<"T^;6]N=&@L("1T96UP+3YD87DL"B`@("`@("`@("`@("`@
M("`D=&5M<"T^:&]U<BP@)'1E;7`M/FUI;G5T92P@)'1E;7`M/G-E8V]N9"D*
M("`@("`@("`I.PH@("`@?0H*("`@(&9U;F-T:6]N('1E<W13971$871E25-/
M*"D*("`@('L*("`@("`@("`D=&AI<RT^=&EM92T^<V5T1&%T92@B,C`P,RTQ
M,"TP-"`Q-#HP,SHR-"(I.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H
M"B`@("`@("`@("`@("<R,#`S+3$P+3`T(#$T.C`S.C(T)RP*("`@("`@("`@
M("`@<W!R:6YT9B@G)3`T9"TE,#)D+24P,F0@)3`R9#HE,#)D.B4P,F0G+`H@
M("`@("`@("`@("`@("`@)'1H:7,M/G1I;64M/GEE87(L("1T:&ES+3YT:6UE
M+3YM;VYT:"P@)'1H:7,M/G1I;64M/F1A>2P*("`@("`@("`@("`@("`@("1T
M:&ES+3YT:6UE+3YH;W5R+"`D=&AI<RT^=&EM92T^;6EN=71E+"`D=&AI<RT^
M=&EM92T^<V5C;VYD*0H@("`@("`@("D["B`@("!]"@H@("`@9G5N8W1I;VX@
M=&5S=%-E=$1A=&5)4T]"87-I8R@I"B`@("!["B`@("`@("`@)'1H:7,M/G1I
M;64M/G-E=$1A=&4H(C(P,#,Q,#`T5#$T,#,R-"(I.PH@("`@("`@("1T:&ES
M+3YA<W-E<G1%<75A;',H"B`@("`@("`@("`@("<R,#`S+3$P+3`T(#$T.C`S
M.C(T)RP*("`@("`@("`@("`@<W!R:6YT9B@G)3`T9"TE,#)D+24P,F0@)3`R
M9#HE,#)D.B4P,F0G+`H@("`@("`@("`@("`@("`@)'1H:7,M/G1I;64M/GEE
M87(L("1T:&ES+3YT:6UE+3YM;VYT:"P@)'1H:7,M/G1I;64M/F1A>2P*("`@
M("`@("`@("`@("`@("1T:&ES+3YT:6UE+3YH;W5R+"`D=&AI<RT^=&EM92T^
M;6EN=71E+"`D=&AI<RT^=&EM92T^<V5C;VYD*0H@("`@("`@("D["B`@("!]
M"@H@("`@9G5N8W1I;VX@=&5S=%-E=$1A=&5)4T]%>'1E;F1E9"@I"B`@("![
M"B`@("`@("`@)'1H:7,M/G1I;64M/G-E=$1A=&4H(C(P,#,M,3`M,#14,30Z
M,#,Z,C0B*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*`H@("`@("`@
M("`@("`G,C`P,RTQ,"TP-"`Q-#HP,SHR-"<L"B`@("`@("`@("`@('-P<FEN
M=&8H)R4P-&0M)3`R9"TE,#)D("4P,F0Z)3`R9#HE,#)D)RP*("`@("`@("`@
M("`@("`@("1T:&ES+3YT:6UE+3YY96%R+"`D=&AI<RT^=&EM92T^;6]N=&@L
M("1T:&ES+3YT:6UE+3YD87DL"B`@("`@("`@("`@("`@("`D=&AI<RT^=&EM
M92T^:&]U<BP@)'1H:7,M/G1I;64M/FUI;G5T92P@)'1H:7,M/G1I;64M/G-E
M8V]N9"D*("`@("`@("`I.PH@("`@?0H*("`@(&9U;F-T:6]N('1E<W13971$
M871E5&EM97-T86UP*"D*("`@('L*("`@("`@("`D=&AI<RT^=&EM92T^<V5T
M1&%T92@B,C`P,S$P,#0Q-#`S,C0B*3L*("`@("`@("`D=&AI<RT^87-S97)T
M17%U86QS*`H@("`@("`@("`@("`G,C`P,RTQ,"TP-"`Q-#HP,SHR-"<L"B`@
M("`@("`@("`@('-P<FEN=&8H)R4P-&0M)3`R9"TE,#)D("4P,F0Z)3`R9#HE
M,#)D)RP*("`@("`@("`@("`@("`@("1T:&ES+3YT:6UE+3YY96%R+"`D=&AI
M<RT^=&EM92T^;6]N=&@L("1T:&ES+3YT:6UE+3YD87DL"B`@("`@("`@("`@
M("`@("`D=&AI<RT^=&EM92T^:&]U<BP@)'1H:7,M/G1I;64M/FUI;G5T92P@
M)'1H:7,M/G1I;64M/G-E8V]N9"D*("`@("`@("`I.PH@("`@?0H*("`@(&9U
M;F-T:6]N('1E<W13971$871E56YI>'1I;64H*0H@("`@>PH@("`@("`@("1T
M:&ES+3YT:6UE+3YS971$871E*'-T<G1O=&EM92@B,C`P,RTQ,"TP-"`Q-#HP
M,SHR-"(I*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*`H@("`@("`@
M("`@("`G,C`P,RTQ,"TP-"`Q-#HP,SHR-"<L"B`@("`@("`@("`@('-P<FEN
M=&8H)R4P-&0M)3`R9"TE,#)D("4P,F0Z)3`R9#HE,#)D)RP*("`@("`@("`@
M("`@("`@("1T:&ES+3YT:6UE+3YY96%R+"`D=&AI<RT^=&EM92T^;6]N=&@L
M("1T:&ES+3YT:6UE+3YD87DL"B`@("`@("`@("`@("`@("`D=&AI<RT^=&EM
M92T^:&]U<BP@)'1H:7,M/G1I;64M/FUI;G5T92P@)'1H:7,M/G1I;64M/G-E
M8V]N9"D*("`@("`@("`I.PH@("`@?0H*("`@(&9U;F-T:6]N('1E<W1'971$
M871E25-/*"D*("`@('L*("`@("`@("`D9&%T92`]("1T:&ES+3YT:6UE+3YG
M971$871E*$1!5$5?1D]234%47TE33RD["B`@("`@("`@)'1H:7,M/F%S<V5R
M=$5Q=6%L<R@G,C`P,RTQ,"TP-"`Q-#HP,SHR-"<L("1D871E*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!T97-T1V5T1&%T94E33T)A<VEC*"D*("`@('L*("`@
M("`@("`D9&%T92`]("1T:&ES+3YT:6UE+3YG971$871E*$1!5$5?1D]234%4
M7TE33U]"05-)0RD["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@G,C`P
M,S$P,#14,30P,S(T6B<L("1D871E*3L*("`@('T*"B`@("!F=6YC=&EO;B!T
M97-T1V5T1&%T94E33T5X=&5N9&5D*"D*("`@('L*("`@("`@("`D9&%T92`]
M("1T:&ES+3YT:6UE+3YG971$871E*$1!5$5?1D]234%47TE33U]%6%1%3D1%
M1"D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@G,C`P,RTQ,"TP-%0Q
M-#HP,SHR-%HG+"`D9&%T92D["B`@("!]"@H@("`@9G5N8W1I;VX@=&5S=$=E
M=$1A=&54:6UE<W1A;7`H*0H@("`@>PH@("`@("`@("1D871E(#T@)'1H:7,M
M/G1I;64M/F=E=$1A=&4H1$%415]&3U)-051?5$E-15-404U0*3L*("`@("`@
M("`D=&AI<RT^87-S97)T17%U86QS*"<R,#`S,3`P-#$T,#,R-"<L("1D871E
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T1V5T1&%T955N:7AT:6UE*"D*
M("`@('L*("`@("`@("`D9&%T92`]("1T:&ES+3YT:6UE+3YG971$871E*$1!
M5$5?1D]234%47U5.25A424U%*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U
M86QS*'-T<G1O=&EM92@G,C`P,RTQ,"TP-"`Q-#HP,SHR-"<I+"`D9&%T92D[
M"B`@("!]"@H@("`@9G5N8W1I;VX@=&5S=$9O<FUA="@I"B`@("!["B`@("`@
M("`@)&-O9&5S(#T@87)R87DH"B`@("`@("`@("`@("=A)R`]/B`G4V%T)RP*
M("`@("`@("`@("`@)T$G(#T^("=3871U<F1A>2<L"B`@("`@("`@("`@("=B
M)R`]/B`G3V-T)RP*("`@("`@("`@("`@)T(G(#T^("=/8W1O8F5R)RP*("`@
M("`@("`@("`@)T,G(#T^("<R,"<L"B`@("`@("`@("`@("=D)R`]/B`G,#0G
M+`H@("`@("`@("`@("`G1"<@/3X@)S$P+S`T+S(P,#,G+`H@("`@("`@("`@
M("`G92<@/3X@)S0G+`H@("`@("`@("`@("`G2"<@/3X@)S$T)RP*("`@("`@
M("`@("`@)TDG(#T^("<P,B<L"B`@("`@("`@("`@("=J)R`]/B`G,C<W)RP*
M("`@("`@("`@("`@)VTG(#T^("<Q,"<L"B`@("`@("`@("`@("=-)R`]/B`G
M,#,G+`H@("`@("`@("`@("`G;B<@/3X@(EQN(BP*("`@("`@("`@("`@)T\G
M(#T^("<K,#`Z,#`G+`H@("`@("`@("`@("`G;R<@/3X@)RLP,#HP,"<L"B`@
M("`@("`@("`@("=P)R`]/B`G<&TG+`H@("`@("`@("`@("`G4"<@/3X@)U!-
M)RP*("`@("`@("`@("`@)W(G(#T^("<P,CHP,SHR-"!032<L"B`@("`@("`@
M("`@("=2)R`]/B`G,30Z,#,G+`H@("`@("`@("`@("`G4R<@/3X@)S(T)RP*
M("`@("`@("`@("`@)W0G(#T^(")<="(L"B`@("`@("`@("`@("=4)R`]/B`G
M,30Z,#,Z,C0G+`H@("`@("`@("`@("`G=R<@/3X@)S8G+`H@("`@("`@("`@
M("`G52<@/3X@)S0P)RP*("`@("`@("`@("`@)WDG(#T^("<P,R<L"B`@("`@
M("`@("`@("=9)R`]/B`G,C`P,R<L"B`@("`@("`@("`@("<E)R`]/B`G)2<*
M("`@("`@("`I.PH*("`@("`@("!F;W)E86-H("@D8V]D97,@87,@)&-O9&4@
M/3X@)&5X<&5C=&5D*2!["B`@("`@("`@("`@("1T:&ES+3YA<W-E<G1%<75A
M;',H"B`@("`@("`@("`@("`@("`B)&-O9&4Z("1E>'!E8W1E9"(L("1T:&ES
M+3YT:6UE+3YF;W)M870H(B1C;V1E.B`E)&-O9&4B*0H@("`@("`@("`@("`I
M.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!T97-T5&]55$-B>4]F
M9G-E="@I"B`@("!["B`@("`@("`@)'1H:7,M/G1I;64M/G-E=%1:8GE)1"@G
M15-4)RD["B`@("`@("`@)'1H:7,M/G1I;64M/G1O551#*"D["B`@("`@("`@
M)'1E;7`@/2!N97<@1&%T92@B,C`P,RTQ,"TP-"`Q-#HP,SHR-"(I.PH@("`@
M("`@("1T96UP+3YT;U540V)Y3V9F<V5T*"(M,#4Z,#`B*3L*"B`@("`@("`@
M)'1H:7,M/F%S<V5R=$5Q=6%L<R@D=&5M<"P@)'1H:7,M/G1I;64I.PH@("`@
M?0H*?0H*+R\@<G5N<R!T:&4@=&5S=',*)'-U:71E(#T@;F5W(%!(4%5N:71?
M5&5S=%-U:71E*")$871E7U1E<W0B*3L*)')E<W5L="`](%!(4%5N:70Z.G)U
M;B@D<W5I=&4I.PHO+R!P<FEN=',@=&AE('1E<W1S"F5C:&\@)')E<W5L="T^
M=&]3=')I;F<H*3L*"C\^"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1&%T92]T97-T<R]T97-T=6YI=%]D
M871E7W-P86XN<&AP```````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,C<W-2`Q,#4Q-30S,S<S
M,R`P,C8R-S$`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S
M:&EF='=I9'1H/30Z("HO"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P
M,#,@3&5A;F1R;R!,=6-A<F5L;&$@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES
M('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=&AE($YE=R!"4T0@;&EC96YS
M92P@5&AA="!I<R!B=6YD;&5D("!\"B\O('P@=VET:"!T:&ES('!A8VMA9V4@
M:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES(&%V86EL86)L92!T:')O=6=H
M("`@("`@?`HO+R!\('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H
M='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E
M+G!H<"`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@
M<F5C96EV92!A(&-O<'D@;V8@=&AE(&YE=R!"4T1L:6-E;G-E(&%N9"!A<F4@
M=6YA8FQE("`@?`HO+R!\('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L
M9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@('P*+R\@
M?"!P96%R+61E=D!L:7-T<RYP:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A
M(&-O<'D@:6UM961I871E;'DN("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<CH@3&5A;F1R;R!,=6-A<F5L;&$@
M/&QL=6-A>$!P:'`N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@=&5S
M='5N:71?9&%T95]S<&%N+G!H<"QV(#$N-"`R,#`U+S$Q+S$U(#`P.C$V.C0P
M('!A:F]Y92!%>'`@)`HO+PH*<F5Q=6ER95]O;F-E("=$871E+G!H<"<["G)E
M<75I<F5?;VYC92`G1&%T92]3<&%N+G!H<"<["G)E<75I<F5?;VYC92`G4$A0
M56YI="YP:'`G.PH*+RHJ"B`J(%1E<W0@8V%S92!F;W(@1&%T95]3<&%N"B`J
M"B`J($!P86-K86=E($1A=&4*("H@0&%U=&AO<B!,96%N9')O($QU8V%R96QL
M82`\;&QU8V%X0'!H<"YN970^"B`J+PIC;&%S<R!$871E7U-P86Y497-T(&5X
M=&5N9',@4$A056YI=%]497-T0V%S92!["@H@("`@=F%R("1T:6UE.PH*("`@
M(&9U;F-T:6]N($1A=&5?4W!A;E1E<W0H)&YA;64I('L*("`@("`@("`D=&AI
M<RT^4$A056YI=%]497-T0V%S92@D;F%M92D["B`@("!]"@H@("`@9G5N8W1I
M;VX@<V5T57`H*2!["B`@("`@("`@)'1H:7,M/G1I;64@/2!N97<@1&%T95]3
M<&%N*#DW-3,Q*3L*("`@('T*"B`@("!F=6YC=&EO;B!T96%R1&]W;B@I('L*
M("`@("`@("!U;G-E="@D=&AI<RT^=&EM92D["B`@("!]"@H@("`@9G5N8W1I
M;VX@=&5S=%-E=$9R;VU!<G)A>2@I('L*("`@("`@("`D=&AI<RT^=&EM92T^
M<V5T1G)O;4%R<F%Y*&%R<F%Y*#4L(#0X+C4L(#(X+C4L(#,Q*2D["B`@("`@
M("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@*("`@("`@("`@("`@)S<Z,#HU.3HQ
M)RP*("`@("`@("`@("`@<W!R:6YT9B@G)60Z)60Z)60Z)60G+"`D=&AI<RT^
M=&EM92T^9&%Y+"`D=&AI<RT^=&EM92T^:&]U<BP*("`@("`@("`@("`@("`@
M("1T:&ES+3YT:6UE+3YM:6YU=&4L("1T:&ES+3YT:6UE+3YS96-O;F0I"B`@
M("`@("`@*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T4V5T1G)O;5-T<FEN
M9R@I('L*("`@("`@("`D=&AI<RT^=&EM92T^<V5T1G)O;5-T<FEN9R@G-3HP
M,#HU.3HS,2<I.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H"B`@("`@
M("`@("`@("<U.C`Z-3DZ,S$G+`H@("`@("`@("`@("!S<')I;G1F*"<E9#HE
M9#HE9#HE9"<L("1T:&ES+3YT:6UE+3YD87DL("1T:&ES+3YT:6UE+3YH;W5R
M+`H@("`@("`@("`@("`@("`@)'1H:7,M/G1I;64M/FUI;G5T92P@)'1H:7,M
M/G1I;64M/G-E8V]N9"D*("`@("`@("`I.PH@("`@?0H*("`@(&9U;F-T:6]N
M('1E<W13971&<F]M4V5C;VYD<R@I('L*("`@("`@("`D=&AI<RT^=&EM92T^
M<V5T1G)O;5-E8V]N9',H-#,T,S0T*3L*("`@("`@("`D=&AI<RT^87-S97)T
M17%U86QS*`H@("`@("`@("`@("`G-3HP.C,Y.C0G+`H@("`@("`@("`@("!S
M<')I;G1F*"<E9#HE9#HE9#HE9"<L("1T:&ES+3YT:6UE+3YD87DL("1T:&ES
M+3YT:6UE+3YH;W5R+`H@("`@("`@("`@("`@("`@)'1H:7,M/G1I;64M/FUI
M;G5T92P@)'1H:7,M/G1I;64M/G-E8V]N9"D*("`@("`@("`I.PH@("`@?0H*
M("`@(&9U;F-T:6]N('1E<W13971&<F]M36EN=71E<R@I('L*("`@("`@("`D
M=&AI<RT^=&EM92T^<V5T1G)O;4UI;G5T97,H-S@V,"XP,38V-C8V-C8V*3L*
M("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*`H@("`@("`@("`@("`G-3HQ
M,3HP.C$G+`H@("`@("`@("`@("!S<')I;G1F*"<E9#HE9#HE9#HE9"<L("1T
M:&ES+3YT:6UE+3YD87DL("1T:&ES+3YT:6UE+3YH;W5R+`H@("`@("`@("`@
M("`@("`@)'1H:7,M/G1I;64M/FUI;G5T92P@)'1H:7,M/G1I;64M/G-E8V]N
M9"D*("`@("`@("`I.PH@("`@?0H*("`@(&9U;F-T:6]N('1E<W13971&<F]M
M2&]U<G,H*2!["B`@("`@("`@)'1H:7,M/G1I;64M/G-E=$9R;VU(;W5R<R@U
M,"XQ,C,T-2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@*("`@("`@
M("`@("`@)S(Z,CHW.C(T)RP*("`@("`@("`@("`@<W!R:6YT9B@G)60Z)60Z
M)60Z)60G+"`D=&AI<RT^=&EM92T^9&%Y+"`D=&AI<RT^=&EM92T^:&]U<BP*
M("`@("`@("`@("`@("`@("1T:&ES+3YT:6UE+3YM:6YU=&4L("1T:&ES+3YT
M:6UE+3YS96-O;F0I"B`@("`@("`@*3L*("`@('T*"B`@("!F=6YC=&EO;B!T
M97-T4V5T1G)O;41A>7,H*2!["B`@("`@("`@)'1H:7,M/G1I;64M/G-E=$9R
M;VU$87ES*'!I*"DI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H"B`@
M("`@("`@("`@("<S.C,Z,C,Z-30G+`H@("`@("`@("`@("!S<')I;G1F*"<E
M9#HE9#HE9#HE9"<L("1T:&ES+3YT:6UE+3YD87DL("1T:&ES+3YT:6UE+3YH
M;W5R+`H@("`@("`@("`@("`@("`@)'1H:7,M/G1I;64M/FUI;G5T92P@)'1H
M:7,M/G1I;64M/G-E8V]N9"D*("`@("`@("`I.PH@("`@?0H*("`@(&9U;F-T
M:6]N('1E<W13971&<F]M1&%T941I9F8H*2!["B`@("`@("`@)'1H:7,M/G1I
M;64M/G-E=$9R;VU$871E1&EF9B@*("`@("`@("`@("`@;F5W($1A=&4H)S(P
M,#0M,#,M,3`@,#$Z,34Z-3DG*2P*("`@("`@("`@("`@;F5W($1A=&4H)S(P
M,#,M,#,M,3`@,#`Z,3`Z-3`G*0H@("`@("`@("D["B`@("`@("`@)'1H:7,M
M/F%S<V5R=$5Q=6%L<R@*("`@("`@("`@("`@)S,V-CHQ.C4Z.2<L"B`@("`@
M("`@("`@('-P<FEN=&8H)R5D.B5D.B5D.B5D)RP@)'1H:7,M/G1I;64M/F1A
M>2P@)'1H:7,M/G1I;64M/FAO=7(L"B`@("`@("`@("`@("`@("`D=&AI<RT^
M=&EM92T^;6EN=71E+"`D=&AI<RT^=&EM92T^<V5C;VYD*0H@("`@("`@("D[
M"B`@("!]"@H@("`@9G5N8W1I;VX@=&5S=$-O<'DH*2!["B`@("`@("`@)'1I
M;64@/2!N97<@1&%T95]3<&%N*"D["B`@("`@("`@)'1I;64M/F-O<'DH)'1H
M:7,M/G1I;64I.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H"B`@("`@
M("`@("`@('-P<FEN=&8H)R5D.B5D.B5D.B5D)RP@)'1H:7,M/G1I;64M/F1A
M>2P@)'1H:7,M/G1I;64M/FAO=7(L"B`@("`@("`@("`@("`@("`D=&AI<RT^
M=&EM92T^;6EN=71E+"`D=&AI<RT^=&EM92T^<V5C;VYD*2P*("`@("`@("`@
M("`@<W!R:6YT9B@G)60Z)60Z)60Z)60G+"`D=&EM92T^9&%Y+"`D=&EM92T^
M:&]U<BP*("`@("`@("`@("`@("`@("1T:6UE+3YM:6YU=&4L("1T:6UE+3YS
M96-O;F0I"B`@("`@("`@*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T1F]R
M;6%T*"D@>PH@("`@("`@("1C;V1E<R`](&%R<F%Y*`H@("`@("`@("`@("`G
M0R<@/3X@)S$L(#`S.C`U.C,Q)RP*("`@("`@("`@("`@)V0G(#T^("<Q+C$R
M.#@S,3`Q.#4Q.#4G+`H@("`@("`@("`@("`G1"<@/3X@)S$G+`H@("`@("`@
M("`@("`G92<@/3X@)S(W+C`Y,3DT-#0T-#0T-"<L"B`@("`@("`@("`@("=F
M)R`]/B`G,38R-2XU,38V-C8V-C8W)RP*("`@("`@("`@("`@)V<G(#T^("<Y
M-S4S,2<L"B`@("`@("`@("`@("=H)R`]/B`G,R<L"B`@("`@("`@("`@("=(
M)R`]/B`G,#,G+`H@("`@("`@("`@("`G:2<@/3X@)S,G+`H@("`@("`@("`@
M("`G22<@/3X@)S`S)RP*("`@("`@("`@("`@)VTG(#T^("<U)RP*("`@("`@
M("`@("`@)TTG(#T^("<P-2<L"B`@("`@("`@("`@("=N)R`]/B`B7&XB+`H@
M("`@("`@("`@("`G<"<@/3X@)V%M)RP*("`@("`@("`@("`@)U`G(#T^("=!
M32<L"B`@("`@("`@("`@("=R)R`]/B`G,#,Z,#4Z,S$@86TG+`H@("`@("`@
M("`@("`G4B<@/3X@)S`S.C`U)RP*("`@("`@("`@("`@)W,G(#T^("<S,2<L
M"B`@("`@("`@("`@("=3)R`]/B`G,S$G+`H@("`@("`@("`@("`G="<@/3X@
M(EQT(BP*("`@("`@("`@("`@)U0G(#T^("<P,SHP-3HS,2<L"B`@("`@("`@
M("`@("<E)R`]/B`G)2<L"B`@("`@("`@*3L*("`@("`@("!F;W)E86-H("@D
M8V]D97,@87,@)&-O9&4@/3X@)&5X<&5C=&5D*2!["B`@("`@("`@("`@("1T
M:&ES+3YA<W-E<G1%<75A;',H"B`@("`@("`@("`@("`@("`B)&-O9&4Z("1E
M>'!E8W1E9"(L("1T:&ES+3YT:6UE+3YF;W)M870H(B1C;V1E.B`E)&-O9&4B
M*0H@("`@("`@("`@("`I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO
M;B!T97-T061D*"D@>PH@("`@("`@("1T:&ES+3YT:6UE+3YA9&0H;F5W($1A
M=&5?4W!A;B@V,#`P*2D["B`@("`@("`@)')E<W5L="`]("1T:&ES+3YT:6UE
M+3YT;U-E8V]N9',H*3L*("`@("`@("`D97AP96-T960@/2`Q,#,U,S$["B`@
M("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@D97AP96-T960L("1R97-U;'0I
M.PH@("`@?0H*("`@(&9U;F-T:6]N('1E<W13=6)T<F%C="@I('L*("`@("`@
M("`D=&AI<RT^=&EM92T^<W5B=')A8W0H;F5W($1A=&5?4W!A;B@V,#`P*2D[
M"B`@("`@("`@)')E<W5L="`]("1T:&ES+3YT:6UE+3YT;U-E8V]N9',H*3L*
M("`@("`@("`D97AP96-T960@/2`Y,34S,3L*("`@("`@("`D=&AI<RT^87-S
M97)T17%U86QS*"1E>'!E8W1E9"P@)')E<W5L="D["B`@("!]"@I]"@HO+R!R
M=6YS('1H92!T97-T<PHD<W5I=&4@/2!N97<@4$A056YI=%]497-T4W5I=&4H
M(D1A=&5?4W!A;E1E<W0B*3L*)')E<W5L="`](%!(4%5N:70Z.G)U;B@D<W5I
M=&4I.PHO+R!P<FEN=',@=&AE('1E<W1S"F5C:&\@)')E<W5L="T^=&]3=')I
M;F<H*3L*"C\^"@```'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S
M=',O1&%T92]T97-T<R]T97-T7V-A;&,N<&AP````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,C0R-"`Q,#4Q-30S,S<S,R`P,C0S,C,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*<F5Q=6ER95]O
M;F-E(")$871E+T-A;&,N<&AP(CL*"B\J*@H@*B!497-T(&1A=&5S(&9R;VT@
M,3DW,"!T;R`R,#(Y"B`J($1A=&$@9G)O;3H@:'1T<#HO+W=W=RYM97)L>6XN
M9&5M;VXN8V\N=6LO=VMN;W1E<W0N='AT"B`J($]T:&5R<R!U<V5F=6QL(&1A
M=&%S(&%V86EL86)L92!F<F]M.@H@*B!H='1P.B\O=W=W+FUE<FQY;BYD96UO
M;BYC;RYU:R\C9&%T"B`J+PHD9F%I;&5D7W1E<W1?9&%T82`@(#T@9F%L<V4[
M"B1W:VYO("`@/2!F:6QE*"=W:VYO=&5S="YT>'0G*3L*)&-N="`@("`]('-I
M>F5O9B@D=VMN;RD["F9O<B@@)&D],#LD:3PD8VYT.R1I*RL@*7L*("`@("1P
M87)T<R`@("`@(#T@97AP;&]D92@G.B<L)'=K;F];)&E=*3L*("`@("1W965K
M<VYO6R1P87)T<ULP75T@/2!S=')?<F5P;&%C92@B7&XB+"<G+"1P87)T<ULQ
M72D["GT*=6YS970H)'=K;F\I.PIF;W)E86-H*"1W965K<VYO(&%S("1D871E
M/3XD:7-O*7L*("`@("1Y96%R("`@("`@(#T@<W5B<W1R*"1D871E+#`L-"D[
M"B`@("`D;6]N=&@@("`@("`]('-U8G-T<B@D9&%T92PT+#(I.PH@("`@)&1A
M>2`@("`@("`@/2!S=6)S='(H)&1A=&4L-BD["B`@("`D:7-O.38P,2`]($1A
M=&5?0V%L8SHZ9W)E9V]R:6%N5&])4T\H)&1A>2PD;6]N=&@L)'EE87(I.PH@
M("`@:68H)&ES;SDV,#$A/21I<V\I>PH@("`@("`@("1F86EL961?=&5S=%]D
M871A("`@/2!T<G5E.PH@("`@("`@(&5C:&\@)&1A=&4@+B`G*"<@+B`D:7-O
M("X@)RD@/3XG("X@)'EE87(N)RTG+B1M;VYT:"XG+2<N)&1A>2`N)ST^)R`N
M("1I<V\Y-C`Q("X@(B`Z(&9A:6QE9%QN(CL*("`@('T*?0H*+RHJ"B`J($)U
M9W,@(S$Y-S@X"B`J+PHD9F%I;&5D7W1E<W1?,3DW.#@@(#T@9F%L<V4["B1P
M87-S,2`@/2`R/3U$871E7T-A;&,Z.G=E96M/9EEE87(H-2PQ+#$Y.3@I/W1R
M=64Z9F%L<V4["B1P87-S,B`@/2`R/3U$871E7T-A;&,Z.G=E96M/9EEE87(H
M-BPQ+#$Y.3@I/W1R=64Z9F%L<V4["B1P87-S,R`@/2`R/3U$871E7T-A;&,Z
M.G=E96M/9EEE87(H-2PQ+#(P,#0I/W1R=64Z9F%L<V4["B1P87-S-"`@/2`R
M/3U$871E7T-A;&,Z.G=E96M/9EEE87(H-BPQ+#(P,#0I/W1R=64Z9F%L<V4[
M"FEF*"`A*"1P87-S,2`F)B`D<&%S<S(@)B8@)'!A<W,S("8F("1P87-S-"D@
M*7L*("`@("1F86EL961?=&5S=%\Q.3<X."`@(#T@=')U93L*?0H*:68H)&9A
M:6QE9%]T97-T7S$Y-S@X('Q\("1F86EL961?=&5S=%]D871A*7L*("`@(&5C
M:&\@(D)U9R`C,3DW.#@Z(&9A:6QE9%QN(CL*?2!E;'-E('L*("`@(&5C:&\@
M(D)U9R`C,3DW.#@Z($]+7&XB.PI]"C\^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E<W1S+W1E<W1?9&%T
M95]M971H;V1S7W-P86XN<&AP````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`U,C,W(#$P-3$U-#,S
M-S,S(#`R-S$P-P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT
M('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PHO+PHO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M
M,C`P-2`@3&5A;F1R;R!,=6-A<F5L;&$@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H
M:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!T:&4@3F5W($)31"!L:6-E
M;G-E+"!4:&%T(&ES(&)U;F1L960@('P*+R\@?"!W:71H('1H:7,@<&%C:V%G
M92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@879A:6QA8FQE('1H<F]U
M9V@@("`@("!\"B\O('P@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\
M(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N
M<V4N<&AP("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO
M="!R96-E:79E(&$@8V]P>2!O9B!T:&4@;F5W($)31&QI8V5N<V4@86YD(&%R
M92!U;F%B;&4@("!\"B\O('P@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O
M<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@?`HO
M+R!\('!E87(M9&5V0&QI<W1S+G!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U
M(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R.B!,96%N9')O($QU8V%R96QL
M82`\;&QU8V%X0'!H<"YN970^("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!T
M97-T7V1A=&5?;65T:&]D<U]S<&%N+G!H<"QV(#$N,B`R,#`U+S$Q+S$U(#`P
M.C$V.C0P('!A:F]Y92!%>'`@)`HO+PH*"G)E<75I<F5?;VYC92`G1&%T92YP
M:'`G.PIR97%U:7)E7V]N8V4@)T1A=&4O4W!A;BYP:'`G.PH*)&1A=&4@/2!N
M97<@1&%T92@I.PHD=&UP(#T@;F5W($1A=&4H)&1A=&4I.PH*<')I;G1F*")!
M8W1U86P@9&%T93H@)7-<;B(L("1D871E+3YG971$871E*$1!5$5?1D]234%4
M7TE33RDI.PH*)'1M<"T^8V]P>2@D9&%T92D["B1T;7`M/G-U8G1R86-T4W!A
M;BAN97<@1&%T95]3<&%N*"<P.C`P.C`P.C`U)RDI.PIP<FEN=&8H(E-U8G1R
M86-T:6YG(#4@<V5C;VYD<SH@)7-<;B(L("1T;7`M/F=E=$1A=&4H1$%415]&
M3U)-051?25-/*2D["@HD=&UP+3YC;W!Y*"1D871E*3L*)'1M<"T^<W5B=')A
M8W13<&%N*&YE=R!$871E7U-P86XH)S`Z,#`Z,C`Z,#`G*2D["G!R:6YT9B@B
M4W5B=')A8W1I;F<@,C`@;6EN=71E<SH@)7-<;B(L("1T;7`M/F=E=$1A=&4H
M1$%415]&3U)-051?25-/*2D["@HD=&UP+3YC;W!Y*"1D871E*3L*)'1M<"T^
M<W5B=')A8W13<&%N*&YE=R!$871E7U-P86XH)S`Z,3`Z,#`Z,#`G*2D["G!R
M:6YT9B@B4W5B=')A8W1I;F<@,3`@:&]U<G,Z("5S7&XB+"`D=&UP+3YG971$
M871E*$1!5$5?1D]234%47TE33RDI.PH*)'1M<"T^8V]P>2@D9&%T92D["B1T
M;7`M/G-U8G1R86-T4W!A;BAN97<@1&%T95]3<&%N*"<S.C`P.C`P.C`P)RDI
M.PIP<FEN=&8H(E-U8G1R86-T:6YG(#,@9&%Y<SH@)7-<;B(L("1T;7`M/F=E
M=$1A=&4H1$%415]&3U)-051?25-/*2D["@HD=&UP+3YC;W!Y*"1D871E*3L*
M)'1M<"T^<W5B=')A8W13<&%N*&YE=R!$871E7U-P86XH)S,Z,3`Z,C`Z,#4G
M*2D["G!R:6YT9B@B4W5B=')A8W1I;F<@,R!D87ES+"`Q,"!H;W5R<RP@,C`@
M;6EN=71E<R!A;F0@-2!S96-O;F1S.B`E<UQN(BP@)'1M<"T^9V5T1&%T92A$
M051%7T9/4DU!5%])4T\I*3L*"B1T;7`M/F-O<'DH)&1A=&4I.PHD=&UP+3YA
M9&13<&%N*&YE=R!$871E7U-P86XH)S`Z,#`Z,#`Z,#4G*2D["G!R:6YT9B@B
M061D:6YG(#4@<V5C;VYD<SH@)7-<;B(L("1T;7`M/F=E=$1A=&4H1$%415]&
M3U)-051?25-/*2D["@HD=&UP+3YC;W!Y*"1D871E*3L*)'1M<"T^861D4W!A
M;BAN97<@1&%T95]3<&%N*"<P.C`P.C(P.C`P)RDI.PIP<FEN=&8H(D%D9&EN
M9R`R,"!M:6YU=&5S.B`E<UQN(BP@)'1M<"T^9V5T1&%T92A$051%7T9/4DU!
M5%])4T\I*3L*"B1T;7`M/F-O<'DH)&1A=&4I.PHD=&UP+3YA9&13<&%N*&YE
M=R!$871E7U-P86XH)S`Z,3`Z,#`Z,#`G*2D["G!R:6YT9B@B061D:6YG(#$P
M(&AO=7)S.B`E<UQN(BP@)'1M<"T^9V5T1&%T92A$051%7T9/4DU!5%])4T\I
M*3L*"B1T;7`M/F-O<'DH)&1A=&4I.PHD=&UP+3YA9&13<&%N*&YE=R!$871E
M7U-P86XH)S,Z,#`Z,#`Z,#`G*2D["G!R:6YT9B@B061D:6YG(#,@9&%Y<SH@
M)7-<;B(L("1T;7`M/F=E=$1A=&4H1$%415]&3U)-051?25-/*2D["@HD=&UP
M+3YC;W!Y*"1D871E*3L*)'1M<"T^861D4W!A;BAN97<@1&%T95]3<&%N*"<S
M.C$P.C(P.C`U)RDI.PIP<FEN=&8H(D%D9&EN9R`S(&1A>7,L(#$P(&AO=7)S
M+"`R,"!M:6YU=&5S(&%N9"`U('-E8V]N9',Z("5S7&XB+"`D=&UP+3YG971$
M871E*$1!5$5?1D]234%47TE33RDI.PH*/SX*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+W1E<W1S+T1A=&4O=&5S=',O=V5E:W-I;FUO;G1H7S1?;6]N9&%Y+G1X
M=```````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`R-C0@,3`U,34T,S,W,S,@,#(V-S$W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#$Y.3DO,B\T
M"C(P,3`O,B\T"C(P,C$O,B\T"C(P,C<O,B\T"C$Y,S<O,B\T"C$Y-#,O,B\T
M"C$X,#(O,B\T"C$X,3,O,B\T"C$X,3DO,B\T"C$X,S`O,B\T"C$X-#$O,B\T
M"C$X-#<O,B\T"C$X-3@O,B\T"C$X-CDO,B\T"C$X-S4O,B\T"C$X.#8O,B\T
M"C$X.3<O,B\T"C$Y,#DO,B\T"C$Y,34O,B\T"C$Y,C8O,B\T"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$
M871E+W1E<W1S+W=E96MS:6YM;VYT:%\T7W-U;F1A>2YT>'0`````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,C8T(#$P-3$U-#,S-S,S(#`R-C<S,P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````R,#`Y+S(O-`HR,#$U+S(O-`HR
M,#(V+S(O-`HR,#,W+S(O-`HQ.3,Q+S(O-`HQ.30R+S(O-`HQ.#`Q+S(O-`HQ
M.#`W+S(O-`HQ.#$X+S(O-`HQ.#(Y+S(O-`HQ.#,U+S(O-`HQ.#0V+S(O-`HQ
M.#4W+S(O-`HQ.#8S+S(O-`HQ.#<T+S(O-`HQ.#@U+S(O-`HQ.#DQ+S(O-`HQ
M.3`S+S(O-`HQ.3$T+S(O-`HQ.3(U+S(O-`H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1&%T92]T97-T<R]W
M965K<VEN;6]N=&A?<F1M7VUO;F1A>2YT>'0`````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-S(Q-B`Q
M,#4Q-30S,S<S,R`P,C<S-#(`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````,3DY.2\X+S8*,C`P,"\Q,"\V"C(P,#$O,3(O-@HR
M,#`R+S$R+S8*,C`P,R\V+S8*,C`P-"\X+S8*,C`P-2\Q,"\V"C(P,#8O,3`O
M-@HR,#`W+S$R+S8*,C`P."\V+S8*,C`P.2\Q,2\V"C(P,3`O."\V"C(P,3$O
M,3`O-@HR,#$R+S$R+S8*,C`Q,R\Q,B\V"C(P,30O-B\V"C(P,34O,3$O-@HR
M,#$V+S$P+S8*,C`Q-R\Q,"\V"C(P,3@O,3(O-@HR,#$Y+S$R+S8*,C`R,"\Q
M,2\V"C(P,C$O."\V"C(P,C(O,3`O-@HR,#(S+S$P+S8*,C`R-"\Q,B\V"C(P
M,C4O-B\V"C(P,C8O,3$O-@HR,#(W+S@O-@HR,#(X+S$P+S8*,C`R.2\Q,B\V
M"C(P,S`O,3(O-@HR,#,Q+S8O-@HR,#,R+S@O-@HR,#,S+S$P+S8*,C`S-"\Q
M,"\V"C(P,S4O,3(O-@HR,#,V+S8O-@HR,#,W+S$Q+S8*,3DS,"\V+S8*,3DS
M,2\Q,2\V"C$Y,S(O,3`O-@HQ.3,S+S$P+S8*,3DS-"\Q,B\V"C$Y,S4O,3(O
M-@HQ.3,V+S$Q+S8*,3DS-R\X+S8*,3DS."\Q,"\V"C$Y,SDO,3`O-@HQ.30P
M+S$R+S8*,3DT,2\V+S8*,3DT,B\Q,2\V"C$Y-#,O."\V"C$Y-#0O,3`O-@HQ
M.30U+S$R+S8*,3DT-B\Q,B\V"C$Y-#<O-B\V"C$Y-#@O."\V"C$Y-#DO,3`O
M-@HQ.#`P+S8O-@HQ.#`Q+S$Q+S8*,3@P,B\X+S8*,3@P,R\Q,"\V"C$X,#0O
M,3(O-@HQ.#`U+S$R+S8*,3@P-B\V+S8*,3@P-R\Q,2\V"C$X,#@O,3`O-@HQ
M.#`Y+S$P+S8*,3@Q,"\Q,B\V"C$X,3$O,3(O-@HQ.#$R+S$Q+S8*,3@Q,R\X
M+S8*,3@Q-"\Q,"\V"C$X,34O,3`O-@HQ.#$V+S$R+S8*,3@Q-R\V+S8*,3@Q
M."\Q,2\V"C$X,3DO."\V"C$X,C`O,3`O-@HQ.#(Q+S$R+S8*,3@R,B\Q,B\V
M"C$X,C,O-B\V"C$X,C0O."\V"C$X,C4O,3`O-@HQ.#(V+S$P+S8*,3@R-R\Q
M,B\V"C$X,C@O-B\V"C$X,CDO,3$O-@HQ.#,P+S@O-@HQ.#,Q+S$P+S8*,3@S
M,B\Q,B\V"C$X,S,O,3(O-@HQ.#,T+S8O-@HQ.#,U+S$Q+S8*,3@S-B\Q,"\V
M"C$X,S<O,3`O-@HQ.#,X+S$R+S8*,3@S.2\Q,B\V"C$X-#`O,3$O-@HQ.#0Q
M+S@O-@HQ.#0R+S$P+S8*,3@T,R\Q,"\V"C$X-#0O,3(O-@HQ.#0U+S8O-@HQ
M.#0V+S$Q+S8*,3@T-R\X+S8*,3@T."\Q,"\V"C$X-#DO,3(O-@HQ.#4P+S$R
M+S8*,3@U,2\V+S8*,3@U,B\X+S8*,3@U,R\Q,"\V"C$X-30O,3`O-@HQ.#4U
M+S$R+S8*,3@U-B\V+S8*,3@U-R\Q,2\V"C$X-3@O."\V"C$X-3DO,3`O-@HQ
M.#8P+S$R+S8*,3@V,2\Q,B\V"C$X-C(O-B\V"C$X-C,O,3$O-@HQ.#8T+S$P
M+S8*,3@V-2\Q,"\V"C$X-C8O,3(O-@HQ.#8W+S$R+S8*,3@V."\Q,2\V"C$X
M-CDO."\V"C$X-S`O,3`O-@HQ.#<Q+S$P+S8*,3@W,B\Q,B\V"C$X-S,O-B\V
M"C$X-S0O,3$O-@HQ.#<U+S@O-@HQ.#<V+S$P+S8*,3@W-R\Q,B\V"C$X-S@O
M,3(O-@HQ.#<Y+S8O-@HQ.#@P+S@O-@HQ.#@Q+S$P+S8*,3@X,B\Q,"\V"C$X
M.#,O,3(O-@HQ.#@T+S8O-@HQ.#@U+S$Q+S8*,3@X-B\X+S8*,3@X-R\Q,"\V
M"C$X.#@O,3(O-@HQ.#@Y+S$R+S8*,3@Y,"\V+S8*,3@Y,2\Q,2\V"C$X.3(O
M,3`O-@HQ.#DS+S$P+S8*,3@Y-"\Q,B\V"C$X.34O,3(O-@HQ.#DV+S$Q+S8*
M,3@Y-R\X+S8*,3@Y."\Q,"\V"C$X.3DO,3`O-@HQ.3`P+S$R+S8*,3DP,2\Q
M,B\V"C$Y,#(O-B\V"C$Y,#,O,3$O-@HQ.3`T+S$P+S8*,3DP-2\Q,"\V"C$Y
M,#8O,3(O-@HQ.3`W+S$R+S8*,3DP."\Q,2\V"C$Y,#DO."\V"C$Y,3`O,3`O
M-@HQ.3$Q+S$P+S8*,3DQ,B\Q,B\V"C$Y,3,O-B\V"C$Y,30O,3$O-@HQ.3$U
M+S@O-@HQ.3$V+S$P+S8*,3DQ-R\Q,B\V"C$Y,3@O,3(O-@HQ.3$Y+S8O-@HQ
M.3(P+S@O-@HQ.3(Q+S$P+S8*,3DR,B\Q,"\V"C$Y,C,O,3(O-@HQ.3(T+S8O
M-@HQ.3(U+S$Q+S8*,3DR-B\X+S8*,3DR-R\Q,"\V"C$Y,C@O,3(O-@HQ.3(Y
M+S$R+S8*,3DY.2\Q,B\U"C(P,#`O,3(O-0HR,#`Q+S$Q+S4*,C`P,B\Q,2\U
M"C(P,#,O,3(O-0HR,#`T+S$R+S4*,C`P-2\Q,B\U"C(P,#8O,3(O-0HR,#`W
M+S$Q+S4*,C`P."\Q,B\U"C(P,#DO,3(O-0HR,#$P+S$R+S4*,C`Q,2\Q,B\U
M"C(P,3(O,3$O-0HR,#$S+S$Q+S4*,C`Q-"\Q,B\U"C(P,34O,3(O-0HR,#$V
M+S$R+S4*,C`Q-R\Q,B\U"C(P,3@O,3$O-0HR,#$Y+S$Q+S4*,C`R,"\Q,B\U
M"C(P,C$O,3(O-0HR,#(R+S$R+S4*,C`R,R\Q,B\U"C(P,C0O,3$O-0HR,#(U
M+S$R+S4*,C`R-B\Q,B\U"C(P,C<O,3(O-0HR,#(X+S$R+S4*,C`R.2\Q,2\U
M"C(P,S`O,3$O-0HR,#,Q+S$R+S4*,C`S,B\Q,B\U"C(P,S,O,3(O-0HR,#,T
M+S$R+S4*,C`S-2\Q,2\U"C(P,S8O,3(O-0HR,#,W+S$R+S4*,3DS,"\Q,B\U
M"C$Y,S$O,3(O-0HQ.3,R+S$R+S4*,3DS,R\Q,B\U"C$Y,S0O,3$O-0HQ.3,U
M+S$Q+S4*,3DS-B\Q,B\U"C$Y,S<O,3(O-0HQ.3,X+S$R+S4*,3DS.2\Q,B\U
M"C$Y-#`O,3$O-0HQ.30Q+S$R+S4*,3DT,B\Q,B\U"C$Y-#,O,3(O-0HQ.30T
M+S$R+S4*,3DT-2\Q,2\U"C$Y-#8O,3$O-0HQ.30W+S$R+S4*,3DT."\Q,B\U
M"C$Y-#DO,3(O-0HQ.#`P+S$R+S4*,3@P,2\Q,B\U"C$X,#(O,3(O-0HQ.#`S
M+S$R+S4*,3@P-"\Q,2\U"C$X,#4O,3$O-0HQ.#`V+S$R+S4*,3@P-R\Q,B\U
M"C$X,#@O,3(O-0HQ.#`Y+S$R+S4*,3@Q,"\Q,2\U"C$X,3$O,3$O-0HQ.#$R
M+S$R+S4*,3@Q,R\Q,B\U"C$X,30O,3(O-0HQ.#$U+S$R+S4*,3@Q-B\Q,2\U
M"C$X,3<O,3(O-0HQ.#$X+S$R+S4*,3@Q.2\Q,B\U"C$X,C`O,3(O-0HQ.#(Q
M+S$Q+S4*,3@R,B\Q,2\U"C$X,C,O,3(O-0HQ.#(T+S$R+S4*,3@R-2\Q,B\U
M"C$X,C8O,3(O-0HQ.#(W+S$Q+S4*,3@R."\Q,B\U"C$X,CDO,3(O-0HQ.#,P
M+S$R+S4*,3@S,2\Q,B\U"C$X,S(O,3$O-0HQ.#,S+S$Q+S4*,3@S-"\Q,B\U
M"C$X,S4O,3(O-0HQ.#,V+S$R+S4*,3@S-R\Q,B\U"C$X,S@O,3$O-0HQ.#,Y
M+S$Q+S4*,3@T,"\Q,B\U"C$X-#$O,3(O-0HQ.#0R+S$R+S4*,3@T,R\Q,B\U
M"C$X-#0O,3$O-0HQ.#0U+S$R+S4*,3@T-B\Q,B\U"C$X-#<O,3(O-0HQ.#0X
M+S$R+S4*,3@T.2\Q,2\U"C$X-3`O,3$O-0HQ.#4Q+S$R+S4*,3@U,B\Q,B\U
M"C$X-3,O,3(O-0HQ.#4T+S$R+S4*,3@U-2\Q,2\U"C$X-38O,3(O-0HQ.#4W
M+S$R+S4*,3@U."\Q,B\U"C$X-3DO,3(O-0HQ.#8P+S$Q+S4*,3@V,2\Q,2\U
M"C$X-C(O,3(O-0HQ.#8S+S$R+S4*,3@V-"\Q,B\U"C$X-C4O,3(O-0HQ.#8V
M+S$Q+S4*,3@V-R\Q,2\U"C$X-C@O,3(O-0HQ.#8Y+S$R+S4*,3@W,"\Q,B\U
M"C$X-S$O,3(O-0HQ.#<R+S$Q+S4*,3@W,R\Q,B\U"C$X-S0O,3(O-0HQ.#<U
M+S$R+S4*,3@W-B\Q,B\U"C$X-S<O,3$O-0HQ.#<X+S$Q+S4*,3@W.2\Q,B\U
M"C$X.#`O,3(O-0HQ.#@Q+S$R+S4*,3@X,B\Q,B\U"C$X.#,O,3$O-0HQ.#@T
M+S$R+S4*,3@X-2\Q,B\U"C$X.#8O,3(O-0HQ.#@W+S$R+S4*,3@X."\Q,2\U
M"C$X.#DO,3$O-0HQ.#DP+S$R+S4*,3@Y,2\Q,B\U"C$X.3(O,3(O-0HQ.#DS
M+S$R+S4*,3@Y-"\Q,2\U"C$X.34O,3$O-0HQ.#DV+S$R+S4*,3@Y-R\Q,B\U
M"C$X.3@O,3(O-0HQ.#DY+S$R+S4*,3DP,"\Q,2\U"C$Y,#$O,3$O-0HQ.3`R
M+S$R+S4*,3DP,R\Q,B\U"C$Y,#0O,3(O-0HQ.3`U+S$R+S4*,3DP-B\Q,2\U
M"C$Y,#<O,3$O-0HQ.3`X+S$R+S4*,3DP.2\Q,B\U"C$Y,3`O,3(O-0HQ.3$Q
M+S$R+S4*,3DQ,B\Q,2\U"C$Y,3,O,3(O-0HQ.3$T+S$R+S4*,3DQ-2\Q,B\U
M"C$Y,38O,3(O-0HQ.3$W+S$Q+S4*,3DQ."\Q,2\U"C$Y,3DO,3(O-0HQ.3(P
M+S$R+S4*,3DR,2\Q,B\U"C$Y,C(O,3(O-0HQ.3(S+S$Q+S4*,3DR-"\Q,B\U
M"C$Y,C4O,3(O-0HQ.3(V+S$R+S4*,3DR-R\Q,B\U"C$Y,C@O,3$O-0HQ.3(Y
M+S$Q+S4*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M=&5S=',O1&%T92]T97-T<R]W965K<VEN;6]N=&A?<F1M7W-U;F1A>2YT>'0`
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P-S(Q-B`Q,#4Q-30S,S<S,R`P,C<S-38`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````,3DY.2\Q,B\U"C(P
M,#`O,3$O-0HR,#`Q+S$Q+S4*,C`P,B\Q,B\U"C(P,#,O,3(O-0HR,#`T+S$R
M+S4*,C`P-2\Q,B\U"C(P,#8O,3$O-0HR,#`W+S$Q+S4*,C`P."\Q,B\U"C(P
M,#DO,3(O-0HR,#$P+S$R+S4*,C`Q,2\Q,B\U"C(P,3(O,3$O-0HR,#$S+S$R
M+S4*,C`Q-"\Q,B\U"C(P,34O,3(O-0HR,#$V+S$R+S4*,C`Q-R\Q,2\U"C(P
M,3@O,3$O-0HR,#$Y+S$R+S4*,C`R,"\Q,B\U"C(P,C$O,3(O-0HR,#(R+S$R
M+S4*,C`R,R\Q,2\U"C(P,C0O,3(O-0HR,#(U+S$R+S4*,C`R-B\Q,B\U"C(P
M,C<O,3(O-0HR,#(X+S$Q+S4*,C`R.2\Q,2\U"C(P,S`O,3(O-0HR,#,Q+S$R
M+S4*,C`S,B\Q,B\U"C(P,S,O,3(O-0HR,#,T+S$Q+S4*,C`S-2\Q,2\U"C(P
M,S8O,3(O-0HR,#,W+S$R+S4*,3DS,"\Q,B\U"C$Y,S$O,3(O-0HQ.3,R+S$R
M+S4*,3DS,R\Q,2\U"C$Y,S0O,3$O-0HQ.3,U+S$R+S4*,3DS-B\Q,B\U"C$Y
M,S<O,3(O-0HQ.3,X+S$R+S4*,3DS.2\Q,2\U"C$Y-#`O,3(O-0HQ.30Q+S$R
M+S4*,3DT,B\Q,B\U"C$Y-#,O,3(O-0HQ.30T+S$Q+S4*,3DT-2\Q,2\U"C$Y
M-#8O,3(O-0HQ.30W+S$R+S4*,3DT."\Q,B\U"C$Y-#DO,3(O-0HQ.#`P+S$R
M+S4*,3@P,2\Q,B\U"C$X,#(O,3(O-0HQ.#`S+S$R+S4*,3@P-"\Q,2\U"C$X
M,#4O,3(O-0HQ.#`V+S$R+S4*,3@P-R\Q,B\U"C$X,#@O,3(O-0HQ.#`Y+S$Q
M+S4*,3@Q,"\Q,2\U"C$X,3$O,3(O-0HQ.#$R+S$R+S4*,3@Q,R\Q,B\U"C$X
M,30O,3(O-0HQ.#$U+S$Q+S4*,3@Q-B\Q,B\U"C$X,3<O,3(O-0HQ.#$X+S$R
M+S4*,3@Q.2\Q,B\U"C$X,C`O,3$O-0HQ.#(Q+S$Q+S4*,3@R,B\Q,B\U"C$X
M,C,O,3(O-0HQ.#(T+S$R+S4*,3@R-2\Q,B\U"C$X,C8O,3$O-0HQ.#(W+S$Q
M+S4*,3@R."\Q,B\U"C$X,CDO,3(O-0HQ.#,P+S$R+S4*,3@S,2\Q,B\U"C$X
M,S(O,3$O-0HQ.#,S+S$R+S4*,3@S-"\Q,B\U"C$X,S4O,3(O-0HQ.#,V+S$R
M+S4*,3@S-R\Q,2\U"C$X,S@O,3$O-0HQ.#,Y+S$R+S4*,3@T,"\Q,B\U"C$X
M-#$O,3(O-0HQ.#0R+S$R+S4*,3@T,R\Q,2\U"C$X-#0O,3(O-0HQ.#0U+S$R
M+S4*,3@T-B\Q,B\U"C$X-#<O,3(O-0HQ.#0X+S$Q+S4*,3@T.2\Q,2\U"C$X
M-3`O,3(O-0HQ.#4Q+S$R+S4*,3@U,B\Q,B\U"C$X-3,O,3(O-0HQ.#4T+S$Q
M+S4*,3@U-2\Q,2\U"C$X-38O,3(O-0HQ.#4W+S$R+S4*,3@U."\Q,B\U"C$X
M-3DO,3(O-0HQ.#8P+S$Q+S4*,3@V,2\Q,B\U"C$X-C(O,3(O-0HQ.#8S+S$R
M+S4*,3@V-"\Q,B\U"C$X-C4O,3$O-0HQ.#8V+S$Q+S4*,3@V-R\Q,B\U"C$X
M-C@O,3(O-0HQ.#8Y+S$R+S4*,3@W,"\Q,B\U"C$X-S$O,3$O-0HQ.#<R+S$R
M+S4*,3@W,R\Q,B\U"C$X-S0O,3(O-0HQ.#<U+S$R+S4*,3@W-B\Q,2\U"C$X
M-S<O,3$O-0HQ.#<X+S$R+S4*,3@W.2\Q,B\U"C$X.#`O,3(O-0HQ.#@Q+S$R
M+S4*,3@X,B\Q,2\U"C$X.#,O,3$O-0HQ.#@T+S$R+S4*,3@X-2\Q,B\U"C$X
M.#8O,3(O-0HQ.#@W+S$R+S4*,3@X."\Q,2\U"C$X.#DO,3(O-0HQ.#DP+S$R
M+S4*,3@Y,2\Q,B\U"C$X.3(O,3(O-0HQ.#DS+S$Q+S4*,3@Y-"\Q,2\U"C$X
M.34O,3(O-0HQ.#DV+S$R+S4*,3@Y-R\Q,B\U"C$X.3@O,3(O-0HQ.#DY+S$Q
M+S4*,3DP,"\Q,2\U"C$Y,#$O,3(O-0HQ.3`R+S$R+S4*,3DP,R\Q,B\U"C$Y
M,#0O,3(O-0HQ.3`U+S$Q+S4*,3DP-B\Q,2\U"C$Y,#<O,3(O-0HQ.3`X+S$R
M+S4*,3DP.2\Q,B\U"C$Y,3`O,3(O-0HQ.3$Q+S$Q+S4*,3DQ,B\Q,B\U"C$Y
M,3,O,3(O-0HQ.3$T+S$R+S4*,3DQ-2\Q,B\U"C$Y,38O,3$O-0HQ.3$W+S$Q
M+S4*,3DQ."\Q,B\U"C$Y,3DO,3(O-0HQ.3(P+S$R+S4*,3DR,2\Q,B\U"C$Y
M,C(O,3$O-0HQ.3(S+S$Q+S4*,3DR-"\Q,B\U"C$Y,C4O,3(O-0HQ.3(V+S$R
M+S4*,3DR-R\Q,B\U"C$Y,C@O,3$O-0HQ.3(Y+S$R+S4*,3DY.2\Q,"\V"C(P
M,#`O,3(O-@HR,#`Q+S$R+S8*,C`P,B\V+S8*,C`P,R\Q,2\V"C(P,#0O,3`O
M-@HR,#`U+S$P+S8*,C`P-B\Q,B\V"C(P,#<O,3(O-@HR,#`X+S$Q+S8*,C`P
M.2\X+S8*,C`Q,"\Q,"\V"C(P,3$O,3`O-@HR,#$R+S$R+S8*,C`Q,R\V+S8*
M,C`Q-"\Q,2\V"C(P,34O."\V"C(P,38O,3`O-@HR,#$W+S$R+S8*,C`Q."\Q
M,B\V"C(P,3DO-B\V"C(P,C`O."\V"C(P,C$O,3`O-@HR,#(R+S$P+S8*,C`R
M,R\Q,B\V"C(P,C0O-B\V"C(P,C4O,3$O-@HR,#(V+S@O-@HR,#(W+S$P+S8*
M,C`R."\Q,B\V"C(P,CDO,3(O-@HR,#,P+S8O-@HR,#,Q+S$Q+S8*,C`S,B\Q
M,"\V"C(P,S,O,3`O-@HR,#,T+S$R+S8*,C`S-2\Q,B\V"C(P,S8O,3$O-@HR
M,#,W+S@O-@HQ.3,P+S$Q+S8*,3DS,2\X+S8*,3DS,B\Q,"\V"C$Y,S,O,3(O
M-@HQ.3,T+S$R+S8*,3DS-2\V+S8*,3DS-B\X+S8*,3DS-R\Q,"\V"C$Y,S@O
M,3`O-@HQ.3,Y+S$R+S8*,3DT,"\V+S8*,3DT,2\Q,2\V"C$Y-#(O."\V"C$Y
M-#,O,3`O-@HQ.30T+S$R+S8*,3DT-2\Q,B\V"C$Y-#8O-B\V"C$Y-#<O,3$O
M-@HQ.30X+S$P+S8*,3DT.2\Q,"\V"C$X,#`O,3$O-@HQ.#`Q+S@O-@HQ.#`R
M+S$P+S8*,3@P,R\Q,"\V"C$X,#0O,3(O-@HQ.#`U+S8O-@HQ.#`V+S$Q+S8*
M,3@P-R\X+S8*,3@P."\Q,"\V"C$X,#DO,3(O-@HQ.#$P+S$R+S8*,3@Q,2\V
M+S8*,3@Q,B\X+S8*,3@Q,R\Q,"\V"C$X,30O,3`O-@HQ.#$U+S$R+S8*,3@Q
M-B\V+S8*,3@Q-R\Q,2\V"C$X,3@O."\V"C$X,3DO,3`O-@HQ.#(P+S$R+S8*
M,3@R,2\Q,B\V"C$X,C(O-B\V"C$X,C,O,3$O-@HQ.#(T+S$P+S8*,3@R-2\Q
M,"\V"C$X,C8O,3(O-@HQ.#(W+S$R+S8*,3@R."\Q,2\V"C$X,CDO."\V"C$X
M,S`O,3`O-@HQ.#,Q+S$P+S8*,3@S,B\Q,B\V"C$X,S,O-B\V"C$X,S0O,3$O
M-@HQ.#,U+S@O-@HQ.#,V+S$P+S8*,3@S-R\Q,B\V"C$X,S@O,3(O-@HQ.#,Y
M+S8O-@HQ.#0P+S@O-@HQ.#0Q+S$P+S8*,3@T,B\Q,"\V"C$X-#,O,3(O-@HQ
M.#0T+S8O-@HQ.#0U+S$Q+S8*,3@T-B\X+S8*,3@T-R\Q,"\V"C$X-#@O,3(O
M-@HQ.#0Y+S$R+S8*,3@U,"\V+S8*,3@U,2\Q,2\V"C$X-3(O,3`O-@HQ.#4S
M+S$P+S8*,3@U-"\Q,B\V"C$X-34O,3(O-@HQ.#4V+S$Q+S8*,3@U-R\X+S8*
M,3@U."\Q,"\V"C$X-3DO,3`O-@HQ.#8P+S$R+S8*,3@V,2\V+S8*,3@V,B\Q
M,2\V"C$X-C,O."\V"C$X-C0O,3`O-@HQ.#8U+S$R+S8*,3@V-B\Q,B\V"C$X
M-C<O-B\V"C$X-C@O."\V"C$X-CDO,3`O-@HQ.#<P+S$P+S8*,3@W,2\Q,B\V
M"C$X-S(O-B\V"C$X-S,O,3$O-@HQ.#<T+S@O-@HQ.#<U+S$P+S8*,3@W-B\Q
M,B\V"C$X-S<O,3(O-@HQ.#<X+S8O-@HQ.#<Y+S$Q+S8*,3@X,"\Q,"\V"C$X
M.#$O,3`O-@HQ.#@R+S$R+S8*,3@X,R\Q,B\V"C$X.#0O,3$O-@HQ.#@U+S@O
M-@HQ.#@V+S$P+S8*,3@X-R\Q,"\V"C$X.#@O,3(O-@HQ.#@Y+S8O-@HQ.#DP
M+S$Q+S8*,3@Y,2\X+S8*,3@Y,B\Q,"\V"C$X.3,O,3(O-@HQ.#DT+S$R+S8*
M,3@Y-2\V+S8*,3@Y-B\X+S8*,3@Y-R\Q,"\V"C$X.3@O,3`O-@HQ.#DY+S$R
M+S8*,3DP,"\Q,B\V"C$Y,#$O-B\V"C$Y,#(O,3$O-@HQ.3`S+S@O-@HQ.3`T
M+S$P+S8*,3DP-2\Q,B\V"C$Y,#8O,3(O-@HQ.3`W+S8O-@HQ.3`X+S@O-@HQ
M.3`Y+S$P+S8*,3DQ,"\Q,"\V"C$Y,3$O,3(O-@HQ.3$R+S8O-@HQ.3$S+S$Q
M+S8*,3DQ-"\X+S8*,3DQ-2\Q,"\V"C$Y,38O,3(O-@HQ.3$W+S$R+S8*,3DQ
M."\V+S8*,3DQ.2\Q,2\V"C$Y,C`O,3`O-@HQ.3(Q+S$P+S8*,3DR,B\Q,B\V
M"C$Y,C,O,3(O-@HQ.3(T+S$Q+S8*,3DR-2\X+S8*,3DR-B\Q,"\V"C$Y,C<O
M,3`O-@HQ.3(X+S$R+S8*,3DR.2\V+S8*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1&%T92]T97-T<R]W:VYO=&5S="YT
M>'0````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R,#<P-"`Q,#4Q-30S,S<S
M,R`P,C0R-S$`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````,3DY.3$R,C<Z,3DY.2TU,BTQ"C$Y.3DQ,C(X.C$Y.3DM-3(M,@HQ
M.3DY,3(R.3HQ.3DY+34R+3,*,3DY.3$R,S`Z,3DY.2TU,BTT"C$Y.3DQ,C,Q
M.C$Y.3DM-3(M-0HR,#`P,#$P,3HQ.3DY+34R+38*,C`P,#`Q,#(Z,3DY.2TU
M,BTW"C(P,#`P,3`S.C(P,#`M,#$M,0HR,#`P,#$P-#HR,#`P+3`Q+3(*,C`P
M,#`Q,#4Z,C`P,"TP,2TS"C(P,#`P,3`V.C(P,#`M,#$M-`HR,#`P,#$P-SHR
M,#`P+3`Q+34*,C`P,#`Q,#@Z,C`P,"TP,2TV"C(P,#`P,3`Y.C(P,#`M,#$M
M-PHR,#`P,3(R-3HR,#`P+34R+3$*,C`P,#$R,C8Z,C`P,"TU,BTR"C(P,#`Q
M,C(W.C(P,#`M-3(M,PHR,#`P,3(R.#HR,#`P+34R+30*,C`P,#$R,CDZ,C`P
M,"TU,BTU"C(P,#`Q,C,P.C(P,#`M-3(M-@HR,#`P,3(S,3HR,#`P+34R+3<*
M,C`P,3`Q,#$Z,C`P,2TP,2TQ"C(P,#$P,3`R.C(P,#$M,#$M,@HR,#`Q,#$P
M,SHR,#`Q+3`Q+3,*,C`P,3`Q,#0Z,C`P,2TP,2TT"C(P,#$P,3`U.C(P,#$M
M,#$M-0HR,#`Q,#$P-CHR,#`Q+3`Q+38*,C`P,3`Q,#<Z,C`P,2TP,2TW"C(P
M,#$Q,C(T.C(P,#$M-3(M,0HR,#`Q,3(R-3HR,#`Q+34R+3(*,C`P,3$R,C8Z
M,C`P,2TU,BTS"C(P,#$Q,C(W.C(P,#$M-3(M-`HR,#`Q,3(R.#HR,#`Q+34R
M+34*,C`P,3$R,CDZ,C`P,2TU,BTV"C(P,#$Q,C,P.C(P,#$M-3(M-PHR,#`Q
M,3(S,3HR,#`R+3`Q+3$*,C`P,C`Q,#$Z,C`P,BTP,2TR"C(P,#(P,3`R.C(P
M,#(M,#$M,PHR,#`R,#$P,SHR,#`R+3`Q+30*,C`P,C`Q,#0Z,C`P,BTP,2TU
M"C(P,#(P,3`U.C(P,#(M,#$M-@HR,#`R,#$P-CHR,#`R+3`Q+3<*,C`P,C$R
M,C,Z,C`P,BTU,BTQ"C(P,#(Q,C(T.C(P,#(M-3(M,@HR,#`R,3(R-3HR,#`R
M+34R+3,*,C`P,C$R,C8Z,C`P,BTU,BTT"C(P,#(Q,C(W.C(P,#(M-3(M-0HR
M,#`R,3(R.#HR,#`R+34R+38*,C`P,C$R,CDZ,C`P,BTU,BTW"C(P,#(Q,C,P
M.C(P,#,M,#$M,0HR,#`R,3(S,3HR,#`S+3`Q+3(*,C`P,S`Q,#$Z,C`P,RTP
M,2TS"C(P,#,P,3`R.C(P,#,M,#$M-`HR,#`S,#$P,SHR,#`S+3`Q+34*,C`P
M,S`Q,#0Z,C`P,RTP,2TV"C(P,#,P,3`U.C(P,#,M,#$M-PHR,#`S,3(R,CHR
M,#`S+34R+3$*,C`P,S$R,C,Z,C`P,RTU,BTR"C(P,#,Q,C(T.C(P,#,M-3(M
M,PHR,#`S,3(R-3HR,#`S+34R+30*,C`P,S$R,C8Z,C`P,RTU,BTU"C(P,#,Q
M,C(W.C(P,#,M-3(M-@HR,#`S,3(R.#HR,#`S+34R+3<*,C`P,S$R,CDZ,C`P
M-"TP,2TQ"C(P,#,Q,C,P.C(P,#0M,#$M,@HR,#`S,3(S,3HR,#`T+3`Q+3,*
M,C`P-#`Q,#$Z,C`P-"TP,2TT"C(P,#0P,3`R.C(P,#0M,#$M-0HR,#`T,#$P
M,SHR,#`T+3`Q+38*,C`P-#`Q,#0Z,C`P-"TP,2TW"C(P,#0Q,C(P.C(P,#0M
M-3(M,0HR,#`T,3(R,3HR,#`T+34R+3(*,C`P-#$R,C(Z,C`P-"TU,BTS"C(P
M,#0Q,C(S.C(P,#0M-3(M-`HR,#`T,3(R-#HR,#`T+34R+34*,C`P-#$R,C4Z
M,C`P-"TU,BTV"C(P,#0Q,C(V.C(P,#0M-3(M-PHR,#`T,3(R-SHR,#`T+34S
M+3$*,C`P-#$R,C@Z,C`P-"TU,RTR"C(P,#0Q,C(Y.C(P,#0M-3,M,PHR,#`T
M,3(S,#HR,#`T+34S+30*,C`P-#$R,S$Z,C`P-"TU,RTU"C(P,#4P,3`Q.C(P
M,#0M-3,M-@HR,#`U,#$P,CHR,#`T+34S+3<*,C`P-3`Q,#,Z,C`P-2TP,2TQ
M"C(P,#4P,3`T.C(P,#4M,#$M,@HR,#`U,#$P-3HR,#`U+3`Q+3,*,C`P-3`Q
M,#8Z,C`P-2TP,2TT"C(P,#4P,3`W.C(P,#4M,#$M-0HR,#`U,#$P.#HR,#`U
M+3`Q+38*,C`P-3`Q,#DZ,C`P-2TP,2TW"C(P,#4Q,C(V.C(P,#4M-3(M,0HR
M,#`U,3(R-SHR,#`U+34R+3(*,C`P-3$R,C@Z,C`P-2TU,BTS"C(P,#4Q,C(Y
M.C(P,#4M-3(M-`HR,#`U,3(S,#HR,#`U+34R+34*,C`P-3$R,S$Z,C`P-2TU
M,BTV"C(P,#8P,3`Q.C(P,#4M-3(M-PHR,#`V,#$P,CHR,#`V+3`Q+3$*,C`P
M-C`Q,#,Z,C`P-BTP,2TR"C(P,#8P,3`T.C(P,#8M,#$M,PHR,#`V,#$P-3HR
M,#`V+3`Q+30*,C`P-C`Q,#8Z,C`P-BTP,2TU"C(P,#8P,3`W.C(P,#8M,#$M
M-@HR,#`V,#$P.#HR,#`V+3`Q+3<*,C`P-C$R,C4Z,C`P-BTU,BTQ"C(P,#8Q
M,C(V.C(P,#8M-3(M,@HR,#`V,3(R-SHR,#`V+34R+3,*,C`P-C$R,C@Z,C`P
M-BTU,BTT"C(P,#8Q,C(Y.C(P,#8M-3(M-0HR,#`V,3(S,#HR,#`V+34R+38*
M,C`P-C$R,S$Z,C`P-BTU,BTW"C(P,#<P,3`Q.C(P,#<M,#$M,0HR,#`W,#$P
M,CHR,#`W+3`Q+3(*,C`P-S`Q,#,Z,C`P-RTP,2TS"C(P,#<P,3`T.C(P,#<M
M,#$M-`HR,#`W,#$P-3HR,#`W+3`Q+34*,C`P-S`Q,#8Z,C`P-RTP,2TV"C(P
M,#<P,3`W.C(P,#<M,#$M-PHR,#`W,3(R-#HR,#`W+34R+3$*,C`P-S$R,C4Z
M,C`P-RTU,BTR"C(P,#<Q,C(V.C(P,#<M-3(M,PHR,#`W,3(R-SHR,#`W+34R
M+30*,C`P-S$R,C@Z,C`P-RTU,BTU"C(P,#<Q,C(Y.C(P,#<M-3(M-@HR,#`W
M,3(S,#HR,#`W+34R+3<*,C`P-S$R,S$Z,C`P."TP,2TQ"C(P,#@P,3`Q.C(P
M,#@M,#$M,@HR,#`X,#$P,CHR,#`X+3`Q+3,*,C`P.#`Q,#,Z,C`P."TP,2TT
M"C(P,#@P,3`T.C(P,#@M,#$M-0HR,#`X,#$P-3HR,#`X+3`Q+38*,C`P.#`Q
M,#8Z,C`P."TP,2TW"C(P,#@Q,C(R.C(P,#@M-3(M,0HR,#`X,3(R,SHR,#`X
M+34R+3(*,C`P.#$R,C0Z,C`P."TU,BTS"C(P,#@Q,C(U.C(P,#@M-3(M-`HR
M,#`X,3(R-CHR,#`X+34R+34*,C`P.#$R,C<Z,C`P."TU,BTV"C(P,#@Q,C(X
M.C(P,#@M-3(M-PHR,#`X,3(R.3HR,#`Y+3`Q+3$*,C`P.#$R,S`Z,C`P.2TP
M,2TR"C(P,#@Q,C,Q.C(P,#DM,#$M,PHR,#`Y,#$P,3HR,#`Y+3`Q+30*,C`P
M.3`Q,#(Z,C`P.2TP,2TU"C(P,#DP,3`S.C(P,#DM,#$M-@HR,#`Y,#$P-#HR
M,#`Y+3`Q+3<*,C`P.3$R,C$Z,C`P.2TU,BTQ"C(P,#DQ,C(R.C(P,#DM-3(M
M,@HR,#`Y,3(R,SHR,#`Y+34R+3,*,C`P.3$R,C0Z,C`P.2TU,BTT"C(P,#DQ
M,C(U.C(P,#DM-3(M-0HR,#`Y,3(R-CHR,#`Y+34R+38*,C`P.3$R,C<Z,C`P
M.2TU,BTW"C(P,#DQ,C(X.C(P,#DM-3,M,0HR,#`Y,3(R.3HR,#`Y+34S+3(*
M,C`P.3$R,S`Z,C`P.2TU,RTS"C(P,#DQ,C,Q.C(P,#DM-3,M-`HR,#$P,#$P
M,3HR,#`Y+34S+34*,C`Q,#`Q,#(Z,C`P.2TU,RTV"C(P,3`P,3`S.C(P,#DM
M-3,M-PHR,#$P,#$P-#HR,#$P+3`Q+3$*,C`Q,#`Q,#4Z,C`Q,"TP,2TR"C(P
M,3`P,3`V.C(P,3`M,#$M,PHR,#$P,#$P-SHR,#$P+3`Q+30*,C`Q,#`Q,#@Z
M,C`Q,"TP,2TU"C(P,3`P,3`Y.C(P,3`M,#$M-@HR,#$P,#$Q,#HR,#$P+3`Q
M+3<*,C`Q,#$R,C<Z,C`Q,"TU,BTQ"C(P,3`Q,C(X.C(P,3`M-3(M,@HR,#$P
M,3(R.3HR,#$P+34R+3,*,C`Q,#$R,S`Z,C`Q,"TU,BTT"C(P,3`Q,C,Q.C(P
M,3`M-3(M-0HR,#$Q,#$P,3HR,#$P+34R+38*,C`Q,3`Q,#(Z,C`Q,"TU,BTW
M"C(P,3$P,3`S.C(P,3$M,#$M,0HR,#$Q,#$P-#HR,#$Q+3`Q+3(*,C`Q,3`Q
M,#4Z,C`Q,2TP,2TS"C(P,3$P,3`V.C(P,3$M,#$M-`HR,#$Q,#$P-SHR,#$Q
M+3`Q+34*,C`Q,3`Q,#@Z,C`Q,2TP,2TV"C(P,3$P,3`Y.C(P,3$M,#$M-PHR
M,#$Q,3(R-CHR,#$Q+34R+3$*,C`Q,3$R,C<Z,C`Q,2TU,BTR"C(P,3$Q,C(X
M.C(P,3$M-3(M,PHR,#$Q,3(R.3HR,#$Q+34R+30*,C`Q,3$R,S`Z,C`Q,2TU
M,BTU"C(P,3$Q,C,Q.C(P,3$M-3(M-@HR,#$R,#$P,3HR,#$Q+34R+3<*,C`Q
M,C`Q,#(Z,C`Q,BTP,2TQ"C(P,3(P,3`S.C(P,3(M,#$M,@HR,#$R,#$P-#HR
M,#$R+3`Q+3,*,C`Q,C`Q,#4Z,C`Q,BTP,2TT"C(P,3(P,3`V.C(P,3(M,#$M
M-0HR,#$R,#$P-SHR,#$R+3`Q+38*,C`Q,C`Q,#@Z,C`Q,BTP,2TW"C(P,3(Q
M,C(T.C(P,3(M-3(M,0HR,#$R,3(R-3HR,#$R+34R+3(*,C`Q,C$R,C8Z,C`Q
M,BTU,BTS"C(P,3(Q,C(W.C(P,3(M-3(M-`HR,#$R,3(R.#HR,#$R+34R+34*
M,C`Q,C$R,CDZ,C`Q,BTU,BTV"C(P,3(Q,C,P.C(P,3(M-3(M-PHR,#$R,3(S
M,3HR,#$S+3`Q+3$*,C`Q,S`Q,#$Z,C`Q,RTP,2TR"C(P,3,P,3`R.C(P,3,M
M,#$M,PHR,#$S,#$P,SHR,#$S+3`Q+30*,C`Q,S`Q,#0Z,C`Q,RTP,2TU"C(P
M,3,P,3`U.C(P,3,M,#$M-@HR,#$S,#$P-CHR,#$S+3`Q+3<*,C`Q,S$R,C,Z
M,C`Q,RTU,BTQ"C(P,3,Q,C(T.C(P,3,M-3(M,@HR,#$S,3(R-3HR,#$S+34R
M+3,*,C`Q,S$R,C8Z,C`Q,RTU,BTT"C(P,3,Q,C(W.C(P,3,M-3(M-0HR,#$S
M,3(R.#HR,#$S+34R+38*,C`Q,S$R,CDZ,C`Q,RTU,BTW"C(P,3,Q,C,P.C(P
M,30M,#$M,0HR,#$S,3(S,3HR,#$T+3`Q+3(*,C`Q-#`Q,#$Z,C`Q-"TP,2TS
M"C(P,30P,3`R.C(P,30M,#$M-`HR,#$T,#$P,SHR,#$T+3`Q+34*,C`Q-#`Q
M,#0Z,C`Q-"TP,2TV"C(P,30P,3`U.C(P,30M,#$M-PHR,#$T,3(R,CHR,#$T
M+34R+3$*,C`Q-#$R,C,Z,C`Q-"TU,BTR"C(P,30Q,C(T.C(P,30M-3(M,PHR
M,#$T,3(R-3HR,#$T+34R+30*,C`Q-#$R,C8Z,C`Q-"TU,BTU"C(P,30Q,C(W
M.C(P,30M-3(M-@HR,#$T,3(R.#HR,#$T+34R+3<*,C`Q-#$R,CDZ,C`Q-2TP
M,2TQ"C(P,30Q,C,P.C(P,34M,#$M,@HR,#$T,3(S,3HR,#$U+3`Q+3,*,C`Q
M-3`Q,#$Z,C`Q-2TP,2TT"C(P,34P,3`R.C(P,34M,#$M-0HR,#$U,#$P,SHR
M,#$U+3`Q+38*,C`Q-3`Q,#0Z,C`Q-2TP,2TW"C(P,34Q,C(Q.C(P,34M-3(M
M,0HR,#$U,3(R,CHR,#$U+34R+3(*,C`Q-3$R,C,Z,C`Q-2TU,BTS"C(P,34Q
M,C(T.C(P,34M-3(M-`HR,#$U,3(R-3HR,#$U+34R+34*,C`Q-3$R,C8Z,C`Q
M-2TU,BTV"C(P,34Q,C(W.C(P,34M-3(M-PHR,#$U,3(R.#HR,#$U+34S+3$*
M,C`Q-3$R,CDZ,C`Q-2TU,RTR"C(P,34Q,C,P.C(P,34M-3,M,PHR,#$U,3(S
M,3HR,#$U+34S+30*,C`Q-C`Q,#$Z,C`Q-2TU,RTU"C(P,38P,3`R.C(P,34M
M-3,M-@HR,#$V,#$P,SHR,#$U+34S+3<*,C`Q-C`Q,#0Z,C`Q-BTP,2TQ"C(P
M,38P,3`U.C(P,38M,#$M,@HR,#$V,#$P-CHR,#$V+3`Q+3,*,C`Q-C`Q,#<Z
M,C`Q-BTP,2TT"C(P,38P,3`X.C(P,38M,#$M-0HR,#$V,#$P.3HR,#$V+3`Q
M+38*,C`Q-C`Q,3`Z,C`Q-BTP,2TW"C(P,38Q,C(V.C(P,38M-3(M,0HR,#$V
M,3(R-SHR,#$V+34R+3(*,C`Q-C$R,C@Z,C`Q-BTU,BTS"C(P,38Q,C(Y.C(P
M,38M-3(M-`HR,#$V,3(S,#HR,#$V+34R+34*,C`Q-C$R,S$Z,C`Q-BTU,BTV
M"C(P,3<P,3`Q.C(P,38M-3(M-PHR,#$W,#$P,CHR,#$W+3`Q+3$*,C`Q-S`Q
M,#,Z,C`Q-RTP,2TR"C(P,3<P,3`T.C(P,3<M,#$M,PHR,#$W,#$P-3HR,#$W
M+3`Q+30*,C`Q-S`Q,#8Z,C`Q-RTP,2TU"C(P,3<P,3`W.C(P,3<M,#$M-@HR
M,#$W,#$P.#HR,#$W+3`Q+3<*,C`Q-S$R,C4Z,C`Q-RTU,BTQ"C(P,3<Q,C(V
M.C(P,3<M-3(M,@HR,#$W,3(R-SHR,#$W+34R+3,*,C`Q-S$R,C@Z,C`Q-RTU
M,BTT"C(P,3<Q,C(Y.C(P,3<M-3(M-0HR,#$W,3(S,#HR,#$W+34R+38*,C`Q
M-S$R,S$Z,C`Q-RTU,BTW"C(P,3@P,3`Q.C(P,3@M,#$M,0HR,#$X,#$P,CHR
M,#$X+3`Q+3(*,C`Q.#`Q,#,Z,C`Q."TP,2TS"C(P,3@P,3`T.C(P,3@M,#$M
M-`HR,#$X,#$P-3HR,#$X+3`Q+34*,C`Q.#`Q,#8Z,C`Q."TP,2TV"C(P,3@P
M,3`W.C(P,3@M,#$M-PHR,#$X,3(R-#HR,#$X+34R+3$*,C`Q.#$R,C4Z,C`Q
M."TU,BTR"C(P,3@Q,C(V.C(P,3@M-3(M,PHR,#$X,3(R-SHR,#$X+34R+30*
M,C`Q.#$R,C@Z,C`Q."TU,BTU"C(P,3@Q,C(Y.C(P,3@M-3(M-@HR,#$X,3(S
M,#HR,#$X+34R+3<*,C`Q.#$R,S$Z,C`Q.2TP,2TQ"C(P,3DP,3`Q.C(P,3DM
M,#$M,@HR,#$Y,#$P,CHR,#$Y+3`Q+3,*,C`Q.3`Q,#,Z,C`Q.2TP,2TT"C(P
M,3DP,3`T.C(P,3DM,#$M-0HR,#$Y,#$P-3HR,#$Y+3`Q+38*,C`Q.3`Q,#8Z
M,C`Q.2TP,2TW"C(P,3DQ,C(S.C(P,3DM-3(M,0HR,#$Y,3(R-#HR,#$Y+34R
M+3(*,C`Q.3$R,C4Z,C`Q.2TU,BTS"C(P,3DQ,C(V.C(P,3DM-3(M-`HR,#$Y
M,3(R-SHR,#$Y+34R+34*,C`Q.3$R,C@Z,C`Q.2TU,BTV"C(P,3DQ,C(Y.C(P
M,3DM-3(M-PHR,#$Y,3(S,#HR,#(P+3`Q+3$*,C`Q.3$R,S$Z,C`R,"TP,2TR
M"C(P,C`P,3`Q.C(P,C`M,#$M,PHR,#(P,#$P,CHR,#(P+3`Q+30*,C`R,#`Q
M,#,Z,C`R,"TP,2TU"C(P,C`P,3`T.C(P,C`M,#$M-@HR,#(P,#$P-3HR,#(P
M+3`Q+3<*,C`R,#$R,C$Z,C`R,"TU,BTQ"C(P,C`Q,C(R.C(P,C`M-3(M,@HR
M,#(P,3(R,SHR,#(P+34R+3,*,C`R,#$R,C0Z,C`R,"TU,BTT"C(P,C`Q,C(U
M.C(P,C`M-3(M-0HR,#(P,3(R-CHR,#(P+34R+38*,C`R,#$R,C<Z,C`R,"TU
M,BTW"C(P,C`Q,C(X.C(P,C`M-3,M,0HR,#(P,3(R.3HR,#(P+34S+3(*,C`R
M,#$R,S`Z,C`R,"TU,RTS"C(P,C`Q,C,Q.C(P,C`M-3,M-`HR,#(Q,#$P,3HR
M,#(P+34S+34*,C`R,3`Q,#(Z,C`R,"TU,RTV"C(P,C$P,3`S.C(P,C`M-3,M
M-PHR,#(Q,#$P-#HR,#(Q+3`Q+3$*,C`R,3`Q,#4Z,C`R,2TP,2TR"C(P,C$P
M,3`V.C(P,C$M,#$M,PHR,#(Q,#$P-SHR,#(Q+3`Q+30*,C`R,3`Q,#@Z,C`R
M,2TP,2TU"C(P,C$P,3`Y.C(P,C$M,#$M-@HR,#(Q,#$Q,#HR,#(Q+3`Q+3<*
M,C`R,3$R,C<Z,C`R,2TU,BTQ"C(P,C$Q,C(X.C(P,C$M-3(M,@HR,#(Q,3(R
M.3HR,#(Q+34R+3,*,C`R,3$R,S`Z,C`R,2TU,BTT"C(P,C$Q,C,Q.C(P,C$M
M-3(M-0HR,#(R,#$P,3HR,#(Q+34R+38*,C`R,C`Q,#(Z,C`R,2TU,BTW"C(P
M,C(P,3`S.C(P,C(M,#$M,0HR,#(R,#$P-#HR,#(R+3`Q+3(*,C`R,C`Q,#4Z
M,C`R,BTP,2TS"C(P,C(P,3`V.C(P,C(M,#$M-`HR,#(R,#$P-SHR,#(R+3`Q
M+34*,C`R,C`Q,#@Z,C`R,BTP,2TV"C(P,C(P,3`Y.C(P,C(M,#$M-PHR,#(R
M,3(R-CHR,#(R+34R+3$*,C`R,C$R,C<Z,C`R,BTU,BTR"C(P,C(Q,C(X.C(P
M,C(M-3(M,PHR,#(R,3(R.3HR,#(R+34R+30*,C`R,C$R,S`Z,C`R,BTU,BTU
M"C(P,C(Q,C,Q.C(P,C(M-3(M-@HR,#(S,#$P,3HR,#(R+34R+3<*,C`R,S`Q
M,#(Z,C`R,RTP,2TQ"C(P,C,P,3`S.C(P,C,M,#$M,@HR,#(S,#$P-#HR,#(S
M+3`Q+3,*,C`R,S`Q,#4Z,C`R,RTP,2TT"C(P,C,P,3`V.C(P,C,M,#$M-0HR
M,#(S,#$P-SHR,#(S+3`Q+38*,C`R,S`Q,#@Z,C`R,RTP,2TW"C(P,C,Q,C(U
M.C(P,C,M-3(M,0HR,#(S,3(R-CHR,#(S+34R+3(*,C`R,S$R,C<Z,C`R,RTU
M,BTS"C(P,C,Q,C(X.C(P,C,M-3(M-`HR,#(S,3(R.3HR,#(S+34R+34*,C`R
M,S$R,S`Z,C`R,RTU,BTV"C(P,C,Q,C,Q.C(P,C,M-3(M-PHR,#(T,#$P,3HR
M,#(T+3`Q+3$*,C`R-#`Q,#(Z,C`R-"TP,2TR"C(P,C0P,3`S.C(P,C0M,#$M
M,PHR,#(T,#$P-#HR,#(T+3`Q+30*,C`R-#`Q,#4Z,C`R-"TP,2TU"C(P,C0P
M,3`V.C(P,C0M,#$M-@HR,#(T,#$P-SHR,#(T+3`Q+3<*,C`R-#$R,C,Z,C`R
M-"TU,BTQ"C(P,C0Q,C(T.C(P,C0M-3(M,@HR,#(T,3(R-3HR,#(T+34R+3,*
M,C`R-#$R,C8Z,C`R-"TU,BTT"C(P,C0Q,C(W.C(P,C0M-3(M-0HR,#(T,3(R
M.#HR,#(T+34R+38*,C`R-#$R,CDZ,C`R-"TU,BTW"C(P,C0Q,C,P.C(P,C4M
M,#$M,0HR,#(T,3(S,3HR,#(U+3`Q+3(*,C`R-3`Q,#$Z,C`R-2TP,2TS"C(P
M,C4P,3`R.C(P,C4M,#$M-`HR,#(U,#$P,SHR,#(U+3`Q+34*,C`R-3`Q,#0Z
M,C`R-2TP,2TV"C(P,C4P,3`U.C(P,C4M,#$M-PHR,#(U,3(R,CHR,#(U+34R
M+3$*,C`R-3$R,C,Z,C`R-2TU,BTR"C(P,C4Q,C(T.C(P,C4M-3(M,PHR,#(U
M,3(R-3HR,#(U+34R+30*,C`R-3$R,C8Z,C`R-2TU,BTU"C(P,C4Q,C(W.C(P
M,C4M-3(M-@HR,#(U,3(R.#HR,#(U+34R+3<*,C`R-3$R,CDZ,C`R-BTP,2TQ
M"C(P,C4Q,C,P.C(P,C8M,#$M,@HR,#(U,3(S,3HR,#(V+3`Q+3,*,C`R-C`Q
M,#$Z,C`R-BTP,2TT"C(P,C8P,3`R.C(P,C8M,#$M-0HR,#(V,#$P,SHR,#(V
M+3`Q+38*,C`R-C`Q,#0Z,C`R-BTP,2TW"C(P,C8Q,C(Q.C(P,C8M-3(M,0HR
M,#(V,3(R,CHR,#(V+34R+3(*,C`R-C$R,C,Z,C`R-BTU,BTS"C(P,C8Q,C(T
M.C(P,C8M-3(M-`HR,#(V,3(R-3HR,#(V+34R+34*,C`R-C$R,C8Z,C`R-BTU
M,BTV"C(P,C8Q,C(W.C(P,C8M-3(M-PHR,#(V,3(R.#HR,#(V+34S+3$*,C`R
M-C$R,CDZ,C`R-BTU,RTR"C(P,C8Q,C,P.C(P,C8M-3,M,PHR,#(V,3(S,3HR
M,#(V+34S+30*,C`R-S`Q,#$Z,C`R-BTU,RTU"C(P,C<P,3`R.C(P,C8M-3,M
M-@HR,#(W,#$P,SHR,#(V+34S+3<*,C`R-S`Q,#0Z,C`R-RTP,2TQ"C(P,C<P
M,3`U.C(P,C<M,#$M,@HR,#(W,#$P-CHR,#(W+3`Q+3,*,C`R-S`Q,#<Z,C`R
M-RTP,2TT"C(P,C<P,3`X.C(P,C<M,#$M-0HR,#(W,#$P.3HR,#(W+3`Q+38*
M,C`R-S`Q,3`Z,C`R-RTP,2TW"C(P,C<Q,C(W.C(P,C<M-3(M,0HR,#(W,3(R
M.#HR,#(W+34R+3(*,C`R-S$R,CDZ,C`R-RTU,BTS"C(P,C<Q,C,P.C(P,C<M
M-3(M-`HR,#(W,3(S,3HR,#(W+34R+34*,C`R.#`Q,#$Z,C`R-RTU,BTV"C(P
M,C@P,3`R.C(P,C<M-3(M-PHR,#(X,#$P,SHR,#(X+3`Q+3$*,C`R.#`Q,#0Z
M,C`R."TP,2TR"C(P,C@P,3`U.C(P,C@M,#$M,PHR,#(X,#$P-CHR,#(X+3`Q
M+30*,C`R.#`Q,#<Z,C`R."TP,2TU"C(P,C@P,3`X.C(P,C@M,#$M-@HR,#(X
M,#$P.3HR,#(X+3`Q+3<*,C`R.#$R,C4Z,C`R."TU,BTQ"C(P,C@Q,C(V.C(P
M,C@M-3(M,@HR,#(X,3(R-SHR,#(X+34R+3,*,C`R.#$R,C@Z,C`R."TU,BTT
M"C(P,C@Q,C(Y.C(P,C@M-3(M-0HR,#(X,3(S,#HR,#(X+34R+38*,C`R.#$R
M,S$Z,C`R."TU,BTW"C(P,CDP,3`Q.C(P,CDM,#$M,0HR,#(Y,#$P,CHR,#(Y
M+3`Q+3(*,C`R.3`Q,#,Z,C`R.2TP,2TS"C(P,CDP,3`T.C(P,CDM,#$M-`HR
M,#(Y,#$P-3HR,#(Y+3`Q+34*,C`R.3`Q,#8Z,C`R.2TP,2TV"C(P,CDP,3`W
M.C(P,CDM,#$M-P``````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O=&5S=',O1&%T92]T97-T<R]B=6<V-S0N<&AP````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,C,W-"`Q,#4Q-30S,S<S,R`P,C,T,#0`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*<F5Q=6ER95]O;F-E("=$871E+G!H<"<["B1E<G)O<B`](&9A;'-E.PHD
M9&%T97,@/2!A<G)A>2`H"B`@("!A<G)A>2@@87)R87DH,C`P,RPS+#$W*2PG
M,C`P,S`S,C,G+"<R,#`S,#,Q-R<L)S(P,#,P,S(T)RPG,C`P,S`S,3`G*2P*
M("`@(&%R<F%Y*"!A<G)A>2@R,#`S+#,L,C`I+"<R,#`S,#,R,R<L)S(P,#,P
M,S$W)RPG,C`P,S`S,C0G+"<R,#`S,#,Q,"<I+`H@("`@87)R87DH(&%R<F%Y
M*#(P,#,L,RPR,RDL)S(P,#,P,S(S)RPG,C`P,S`S,3<G+"<R,#`S,#,R-"<L
M)S(P,#,P,S$P)RD**3L*9F]R96%C:"`H)&1A=&5S(&%S("1D*2!["B`@("`D
M9&%T92`]("1D6S!=.PH@("`@)')E<R`]($1A=&5?0V%L8SHZ96YD3V97965K
M*"1D871E6S)=+"1D871E6S%=+"1D871E6S!=*3L*("`@(&EF("@D<F5S(3TD
M9%LQ72D@>PH@("`@("`@(&5C:&\@(D)U9R`V-S0@96]W.B`B("X@)&1A=&5;
M,%TN)&1A=&5;,5TN)&1A=&5;,ETN(B!F86EL961<;B(["B`@("`@("`@)&5R
M<F]R(#T@=')U93L*("`@('T*?0H*9F]R96%C:"`H)&1A=&5S(&%S("1D*2![
M"B`@("`D9&%T92`]("1D6S!=.PH@("`@)')E<R`]($1A=&5?0V%L8SHZ8F5G
M:6Y/9E=E96LH)&1A=&5;,ETL)&1A=&5;,5TL)&1A=&5;,%TI.PH@("`@:68@
M*"1R97,A/21D6S)=*2!["B`@("`@("`@96-H;R`B0G5G(#8W-"!B;W<Z("(@
M+B`D9&%T95LP72XD9&%T95LQ72XD9&%T95LR72XB(&9A:6QE9%QN(CL*("`@
M("`@("`D97)R;W(@/2!T<G5E.PH@("`@?0I]"@H*9F]R96%C:"`H)&1A=&5S
M(&%S("1D*2!["B`@("`D9&%T92`]("1D6S!=.PH@("`@)')E<R`]($1A=&5?
M0V%L8SHZ8F5G:6Y/9DYE>'17965K*"1D871E6S)=+"1D871E6S%=+"1D871E
M6S!=*3L*("`@(&EF("@D<F5S(3TD9%LS72D@>PH@("`@("`@(&5C:&\@(D)U
M9R`V-S0@8F]N=SH@(B`N("1D871E6S!=+B1D871E6S%=+B1D871E6S)=+B(@
M9F%I;&5D7&XB.PH@("`@("`@("1E<G)O<B`]('1R=64["B`@("!]"GT*"@IF
M;W)E86-H("@D9&%T97,@87,@)&0I('L*("`@("1D871E(#T@)&1;,%T["B`@
M("`D<F5S(#T@1&%T95]#86QC.CIB96=I;D]F4')E=E=E96LH)&1A=&5;,ETL
M)&1A=&5;,5TL)&1A=&5;,%TI.PH@("`@:68@*"1R97,A/21D6S1=*2!["B`@
M("`@("`@96-H;R`B0G5G(#8W-"!B;W!W.B`B("X@)&1A=&5;,%TN)&1A=&5;
M,5TN)&1A=&5;,ETN(B!F86EL961<;B(["B`@("`@("`@)&5R<F]R(#T@=')U
M93L*("`@('T*?0H*:68@*"$D97)R;W(I('L*("`@(&5C:&\@(D)U9R`V-S0Z
M($]+7&XB.PI]"@H_/@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E
M<W1S+V)U9S<R-U\Q+G!H<```````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R
M,#8P(#$P-3$U-#,S-S,S(#`R,S8Q,P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*@H@*B!497-T<R!F;W(@=V5E
M:W-);DUO;G1H+"!F96)R=6%R>2!W:71H(#0@=V5E:W,*("H@36]N9&%Y(&%S
M(#%S="!D87D@;V8@=V5E:PH@*B\*9&5F:6YE*"=$051%7T-!3$-?0D5'24Y?
M5T5%2T1!62<L(#$I.PIR97%U:7)E7V]N8V4@(D1A=&4O0V%L8RYP:'`B.PH*
M+RHJ"B`J(%1E<W0@9&%T97,@9G)O;2`Q.3<P('1O(#(P,CD*("H@1&%T82!F
M<F]M.B!H='1P.B\O=W=W+FUE<FQY;BYD96UO;BYC;RYU:R]W:VYO=&5S="YT
M>'0*("H@3W1H97)S('5S969U;&P@9&%T87,@879A:6QA8FQE(&9R;VTZ"B`J
M(&AT='`Z+R]W=W<N;65R;'EN+F1E;6]N+F-O+G5K+R-D870*("HO"B1D871A
M<&%T:"`](&1I<FYA;64H(%]?1DE,15]?*3L*"B1F86EL961?=&5S=%]D871A
M("`@/2!F86QS93L*)&1A=&5S("`@/2!F:6QE*"1D871A<&%T:"`N("<O=V5E
M:W-I;FUO;G1H7S1?;6]N9&%Y+G1X="<I.PHD8VYT("`@("`]('-I>F5O9B@D
M9&%T97,I.PHD=F%L:61S(#T@87)R87DH*3L*9F]R*"`D:3TP.R1I/"1C;G0[
M)&DK*R`I>PH@("`@)'!A<G1S("`@("`@/2!E>'!L;V1E*"<O)RPD9&%T97-;
M)&E=*3L*("`@("1V86QI9'-;)'!A<G1S6S!=72`](&%R<F%Y*"1P87)T<ULQ
M73T^*&EN="ES=')?<F5P;&%C92@B7&XB+"<G+"1P87)T<ULR72DI.PI]"G5N
M<V5T*"1D871E<RD["F9O<F5A8V@H)'9A;&ED<R!A<R`D>65A<B`]/B`D;6]N
M=&AS*7L*("`@(&9O<F5A8V@@*"1M;VYT:',@87,@)&UO;G1H/3XD=F%L:61?
M=V5E:W,I('L*("`@("`@("`D8V%L8U]W965K<R`]($1A=&5?0V%L8SHZ=V5E
M:W-);DUO;G1H*"1M;VYT:"PD>65A<BD["B`@("`@("`@:68H)&-A;&-?=V5E
M:W,A/21V86QI9%]W965K<RE["B`@("`@("`@("`@("1F86EL961?=&5S=%]D
M871A("`@/2!T<G5E.PH@("`@("`@("`@("!E8VAO(")"=6<@(S<R-RP@<&%S
M<R`Q.B`D>65A<B\D;6]N=&@@9F%I;&5D+B!%>'!E8W0Z)'9A;&ED7W=E96MS
M($=O=#HD8V%L8U]W965K<UQN(CL*("`@("`@("!]"B`@("!]"GT*:68@*"$D
M9F%I;&5D7W1E<W1?9&%T82D@>PH)96-H;R`B0G5G(",W,C<L('!A<W,@,3H@
M3TM<;B(["GT*/SX*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+W1E<W1S+T9I;&4`````````````````````````````````
M````````````````````````````````````````````````,#`P-S4U(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S,@,#(P-#,P
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1FEL92]T97-T<P``
M````````````````````````````````````````````````````````````
M```````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q
M,#4Q-30S,S<S,R`P,C$U-S(`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T
M97-T<R]&:6QE+W1E<W1S+T-35@``````````````````````````````````
M`````````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S,S(#`R,C(R-0`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+W1E<W1S+T9I;&4O=&5S=',O0U-6+S`P,2YP:'!T
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(Q-3$@,3`U,34T,S,W,S,@
M,#(S-3`P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"TM5$535"TM"D9I;&5?0U-6(%1E<W0@0V%S92`P,#$Z($9I96QD<R!C
M;W5N="!L97-S('1H86X@97AP96-T960*+2U&24Q%+2T*/#]P:'`*+R\@)$ED
M.B`P,#$N<&AP="QV(#$N,B`R,#`U+S`R+S$X(#$Q.C$Y.C,S(&1U9G5Z($5X
M<"`D"B\J*@H@*B!497-T(&9O<CH*("H@+2!&:6QE7T-35CHZ9&ES8V]V97)&
M;W)M870H*0H@*B`M($9I;&5?0U-6.CIR96%D*"D*("HO"@IR97%U:7)E7V]N
M8V4@)T9I;&4O0U-6+G!H<"<["@HD9FEL92`]("<P,#$N8W-V)SL*)&-O;F8@
M/2!&:6QE7T-35CHZ9&ES8V]V97)&;W)M870H)&9I;&4I.PH*<')I;G0@(D9O
M<FUA=#I<;B(["G!R:6YT7W(H)&-O;F8I.PIP<FEN="`B7&XB.PH*)&1A=&$@
M/2!A<G)A>2@I.PIW:&EL92`H)')E<R`]($9I;&5?0U-6.CIR96%D*"1F:6QE
M+"`D8V]N9BDI('L*("`@("1D871A6UT@/2`D<F5S.PI]"@IP<FEN="`B1&%T
M83I<;B(["G!R:6YT7W(H)&1A=&$I.PH_/@HM+4584$5#5"TM"D9O<FUA=#H*
M07)R87D**`H@("`@6V9I96QD<UT@/3X@-`H@("`@6W-E<%T@/3X@+`H@("`@
M6W%U;W1E72`]/B`B"BD*"D1A=&$Z"D%R<F%Y"B@*("`@(%LP72`]/B!!<G)A
M>0H@("`@("`@("@*("`@("`@("`@("`@6S!=(#T^($9I96QD(#$M,0H@("`@
M("`@("`@("!;,5T@/3X@1FEE;&0@,2TR"B`@("`@("`@("`@(%LR72`]/B!&
M:65L9"`Q+3,*("`@("`@("`@("`@6S-=(#T^($9I96QD(#$M-`H@("`@("`@
M("D*"B`@("!;,5T@/3X@07)R87D*("`@("`@("`H"B`@("`@("`@("`@(%LP
M72`]/B!&:65L9"`R+3$*("`@("`@("`@("`@6S%=(#T^($9I96QD(#(M,@H@
M("`@("`@("`@("!;,ET@/3X@1FEE;&0@,BTS"B`@("`@("`@("`@(%LS72`]
M/B`*("`@("`@("`I"@H@("`@6S)=(#T^($%R<F%Y"B`@("`@("`@*`H@("`@
M("`@("`@("!;,%T@/3X@1FEE;&0@,RTQ"B`@("`@("`@("`@(%LQ72`]/B!&
M:65L9"`S+3(*("`@("`@("`@("`@6S)=(#T^(`H@("`@("`@("`@("!;,UT@
M/3X@"B`@("`@("`@*0H*("`@(%LS72`]/B!!<G)A>0H@("`@("`@("@*("`@
M("`@("`@("`@6S!=(#T^($9I96QD(#0M,0H@("`@("`@("`@("!;,5T@/3X@
M"B`@("`@("`@("`@(%LR72`]/B`*("`@("`@("`@("`@6S-=(#T^(`H@("`@
M("`@("D*"BD`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O
M1FEL92]T97-T<R]#4U8O,#`R+G!H<'0`````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,C$V,B`Q,#4Q-30S,S<S,R`P,C,U,#,`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+2U415-4+2T*1FEL95]#4U8@
M5&5S="!#87-E(#`P,CH@1FEE;&1S(&-O=6YT(&UO<F4@=&AA;B!E>'!E8W1E
M9`HM+49)3$4M+0H\/W!H<`HO+R`D260Z(#`P,BYP:'!T+'8@,2XR(#(P,#4O
M,#(O,3@@,3$Z,3DZ,S,@9'5F=7H@17AP("0*+RHJ"B`J(%1E<W0@9F]R.@H@
M*B`M($9I;&5?0U-6.CID:7-C;W9E<D9O<FUA="@I"B`J("T@1FEL95]#4U8Z
M.G)E860H*0H@*B\*"G)E<75I<F5?;VYC92`G1FEL92]#4U8N<&AP)SL*"B1F
M:6QE(#T@)S`P,BYC<W8G.PHD8V]N9B`]($9I;&5?0U-6.CID:7-C;W9E<D9O
M<FUA="@D9FEL92D["@IP<FEN="`B1F]R;6%T.EQN(CL*<')I;G1?<B@D8V]N
M9BD["G!R:6YT(")<;B(["@HD9&%T82`](&%R<F%Y*"D["G=H:6QE("@D<F5S
M(#T@1FEL95]#4U8Z.G)E860H)&9I;&4L("1C;VYF*2D@>PH@("`@)&1A=&%;
M72`]("1R97,["GT*"G!R:6YT(")$871A.EQN(CL*<')I;G1?<B@D9&%T82D[
M"C\^"BTM15A014-4+2T*1F]R;6%T.@I!<G)A>0HH"B`@("!;9FEE;&1S72`]
M/B`T"B`@("!;<V5P72`]/B`L"B`@("!;<75O=&5=(#T^("(**0H*1&%T83H*
M07)R87D**`H@("`@6S!=(#T^($%R<F%Y"B`@("`@("`@*`H@("`@("`@("`@
M("!;,%T@/3X@1FEE;&0@,2TQ"B`@("`@("`@("`@(%LQ72`]/B!&:65L9"`Q
M+3(*("`@("`@("`@("`@6S)=(#T^($9I96QD(#$M,PH@("`@("`@("`@("!;
M,UT@/3X@1FEE;&0@,2TT"B`@("`@("`@*0H*("`@(%LQ72`]/B!!<G)A>0H@
M("`@("`@("@*("`@("`@("`@("`@6S!=(#T^($9I96QD(#(M,0H@("`@("`@
M("`@("!;,5T@/3X@1FEE;&0@,BTR"B`@("`@("`@("`@(%LR72`]/B!&:65L
M9"`R+3,*("`@("`@("`@("`@6S-=(#T^($9I96QD(#(M-`H@("`@("`@("D*
M"B`@("!;,ET@/3X@07)R87D*("`@("`@("`H"B`@("`@("`@("`@(%LP72`]
M/B!&:65L9"`S+3$*("`@("`@("`@("`@6S%=(#T^($9I96QD(#,M,@H@("`@
M("`@("`@("!;,ET@/3X@"B`@("`@("`@("`@(%LS72`]/B`*("`@("`@("`I
M"@H@("`@6S-=(#T^($%R<F%Y"B`@("`@("`@*`H@("`@("`@("`@("!;,%T@
M/3X@1FEE;&0@-"TQ"B`@("`@("`@("`@(%LQ72`]/B`*("`@("`@("`@("`@
M6S)=(#T^(`H@("`@("`@("`@("!;,UT@/3X@"B`@("`@("`@*0H**0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]T97-T<R]&:6QE+W1E<W1S+T-35B\P,#(N8W-V
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,C,R(#$P-3$U-#,S-S,S
M(#`R,S,Q-P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````B1FEE;&0@,2TQ(BP@(D9I96QD(#$M,B(L(")&:65L9"`Q+3,B+"`B
M1FEE;&0@,2TT(@HB1FEE;&0@,BTQ(BP@(D9I96QD(#(M,B(L(")&:65L9"`R
M+3,B+"`B1FEE;&0@,BTT(BP@(D5X=')A($9I96QD(@HB1FEE;&0@,RTQ(BP@
M(D9I96QD(#,M,B(*(D9I96QD(#0M,2(*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O=&5S=',O1FEL92]T97-T<R]#4U8O,#`S+G!H<'0`````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,3<V,B`Q,#4Q-30S,S<S,R`P,C,U,3$`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+2U415-4
M+2T*1FEL95]#4U8@5&5S="!#87-E(#`P,SH@5VEN9&]W<R!%3TP*+2U&24Q%
M+2T*/#]P:'`*+R\@)$ED.B`P,#,N<&AP="QV(#$N,B`R,#`U+S`R+S$X(#$Q
M.C$Y.C,S(&1U9G5Z($5X<"`D"B\J*@H@*B!497-T(&9O<CH*("H@+2!&:6QE
M7T-35CHZ9&ES8V]V97)&;W)M870H*0H@*B`M($9I;&5?0U-6.CIR96%D*"D*
M("HO"@IR97%U:7)E7V]N8V4@)T9I;&4O0U-6+G!H<"<["@HD9FEL92`]("<P
M,#,N8W-V)SL*)&-O;F8@/2!&:6QE7T-35CHZ9&ES8V]V97)&;W)M870H)&9I
M;&4I.PH*<')I;G0@(D9O<FUA=#I<;B(["G!R:6YT7W(H)&-O;F8I.PIP<FEN
M="`B7&XB.PH*)&1A=&$@/2!A<G)A>2@I.PIW:&EL92`H)')E<R`]($9I;&5?
M0U-6.CIR96%D*"1F:6QE+"`D8V]N9BDI('L*("`@("1D871A6UT@/2`D<F5S
M.PI]"@IP<FEN="`B1&%T83I<;B(["G!R:6YT7W(H)&1A=&$I.PH_/@HM+458
M4$5#5"TM"D9O<FUA=#H*07)R87D**`H@("`@6V9I96QD<UT@/3X@-`H@("`@
M6W-E<%T@/3X@+`H@("`@6W%U;W1E72`]/B`B"BD*"D1A=&$Z"D%R<F%Y"B@*
M("`@(%LP72`]/B!!<G)A>0H@("`@("`@("@*("`@("`@("`@("`@6S!=(#T^
M($9I96QD(#$M,0H@("`@("`@("`@("!;,5T@/3X@1FEE;&0@,2TR"B`@("`@
M("`@("`@(%LR72`]/B!&:65L9"`Q+3,*("`@("`@("`@("`@6S-=(#T^($9I
M96QD(#$M-`H@("`@("`@("D*"B`@("!;,5T@/3X@07)R87D*("`@("`@("`H
M"B`@("`@("`@("`@(%LP72`]/B!&:65L9"`R+3$*("`@("`@("`@("`@6S%=
M(#T^($9I96QD(#(M,@H@("`@("`@("`@("!;,ET@/3X@1FEE;&0@,BTS"B`@
M("`@("`@("`@(%LS72`]/B!))VT@;75L=&EL:6YE"D9I96QD"B`@("`@("`@
M*0H*("`@(%LR72`]/B!!<G)A>0H@("`@("`@("@*("`@("`@("`@("`@6S!=
M(#T^($9I96QD(#,M,0H@("`@("`@("`@("!;,5T@/3X@1FEE;&0@,RTR"B`@
M("`@("`@("`@(%LR72`]/B!&:65L9"`S+3,*("`@("`@("`@("`@6S-=(#T^
M(`H@("`@("`@("D*"BD``````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O=&5S=',O1FEL92]T97-T<R]#4U8O,#`S+F-S=@``````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#(R,B`Q,#4Q-30S,S<S,R`P,C,S
M,3<`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M(D9I96QD(#$M,2(L(D9I96QD(#$M,B(L(D9I96QD(#$M,R(L(D9I96QD(#$M
M-"(-"B)&:65L9"`R+3$B+")&:65L9"`R+3(B+")&:65L9"`R+3,B+")))VT@
M;75L=&EL:6YE#0I&:65L9"(-"B)&:65L9"`S+3$B+")&:65L9"`S+3(B+")&
M:65L9"`S+3,B#0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+W1E<W1S+T9I;&4O=&5S=',O0U-6+S`P-"YP:'!T````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#$W-3<@,3`U,34T,S,W,S,@,#(S-3$V`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"TM5$535"TM"D9I
M;&5?0U-6(%1E<W0@0V%S92`P,#0Z(%5N:7@@14],"BTM1DE,12TM"CP_<&AP
M"B\O("1)9#H@,#`T+G!H<'0L=B`Q+C(@,C`P-2\P,B\Q."`Q,3HQ.3HS,R!D
M=69U>B!%>'`@)`HO*BH*("H@5&5S="!F;W(Z"B`J("T@1FEL95]#4U8Z.F1I
M<V-O=F5R1F]R;6%T*"D*("H@+2!&:6QE7T-35CHZ<F5A9"@I"B`J+PH*<F5Q
M=6ER95]O;F-E("=&:6QE+T-35BYP:'`G.PH*)&9I;&4@/2`G,#`T+F-S=B<[
M"B1C;VYF(#T@1FEL95]#4U8Z.F1I<V-O=F5R1F]R;6%T*"1F:6QE*3L*"G!R
M:6YT(")&;W)M870Z7&XB.PIP<FEN=%]R*"1C;VYF*3L*<')I;G0@(EQN(CL*
M"B1D871A(#T@87)R87DH*3L*=VAI;&4@*"1R97,@/2!&:6QE7T-35CHZ<F5A
M9"@D9FEL92P@)&-O;F8I*2!["B`@("`D9&%T85M=(#T@)')E<SL*?0H*<')I
M;G0@(D1A=&$Z7&XB.PIP<FEN=%]R*"1D871A*3L*/SX*+2U%6%!%0U0M+0I&
M;W)M870Z"D%R<F%Y"B@*("`@(%MF:65L9'-=(#T^(#0*("`@(%MS97!=(#T^
M("P*("`@(%MQ=6]T95T@/3X@(@HI"@I$871A.@I!<G)A>0HH"B`@("!;,%T@
M/3X@07)R87D*("`@("`@("`H"B`@("`@("`@("`@(%LP72`]/B!&:65L9"`Q
M+3$*("`@("`@("`@("`@6S%=(#T^($9I96QD(#$M,@H@("`@("`@("`@("!;
M,ET@/3X@1FEE;&0@,2TS"B`@("`@("`@("`@(%LS72`]/B!&:65L9"`Q+30*
M("`@("`@("`I"@H@("`@6S%=(#T^($%R<F%Y"B`@("`@("`@*`H@("`@("`@
M("`@("!;,%T@/3X@1FEE;&0@,BTQ"B`@("`@("`@("`@(%LQ72`]/B!&:65L
M9"`R+3(*("`@("`@("`@("`@6S)=(#T^($9I96QD(#(M,PH@("`@("`@("`@
M("!;,UT@/3X@22=M(&UU;'1I;&EN90I&:65L9`H@("`@("`@("D*"B`@("!;
M,ET@/3X@07)R87D*("`@("`@("`H"B`@("`@("`@("`@(%LP72`]/B!&:65L
M9"`S+3$*("`@("`@("`@("`@6S%=(#T^($9I96QD(#,M,@H@("`@("`@("`@
M("!;,ET@/3X@1FEE;&0@,RTS"B`@("`@("`@("`@(%LS72`]/B`*("`@("`@
M("`I"@HI``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+W1E<W1S+T9I;&4O=&5S=',O0U-6+S`P-"YC<W8`````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`R,38@,3`U,34T,S,W,S,@,#(S,S(S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````")&:65L
M9"`Q+3$B+")&:65L9"`Q+3(B+")&:65L9"`Q+3,B+")&:65L9"`Q+30B"B)&
M:65L9"`R+3$B+")&:65L9"`R+3(B+")&:65L9"`R+3,B+")))VT@;75L=&EL
M:6YE"D9I96QD(@HB1FEE;&0@,RTQ(BPB1FEE;&0@,RTR(BPB1FEE;&0@,RTS
M(@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T
M<R]&:6QE+W1E<W1S+T-35B\P,#4N<&AP=```````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`R-S$R(#$P-3$U-#,S-S,S(#`R,S4P-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````M+51%4U0M+0I&:6QE7T-3
M5B!497-T($-A<V4@,#`U.B!-86,@14],"BTM1DE,12TM"CP_<&AP"B\O("1)
M9#H@,#`U+G!H<'0L=B`Q+C,@,C`P-2\P,B\Q.2`Q,CHR,SHR."!D=69U>B!%
M>'`@)`HO*BH*("H@5&5S="!F;W(Z"B`J("T@1FEL95]#4U8Z.F1I<V-O=F5R
M1F]R;6%T*"D*("H@+2!&:6QE7T-35CHZ<F5A9"@I"B`J+PH*<F5Q=6ER95]O
M;F-E("=&:6QE+T-35BYP:'`G.PH*)&9I;&4@/2`G,#`U+F-S=B<["B1C;VYF
M(#T@1FEL95]#4U8Z.F1I<V-O=F5R1F]R;6%T*"1F:6QE*3L*"G!R:6YT(")&
M;W)M870Z7&XB.PIP<FEN=%]R*"1C;VYF*3L*<')I;G0@(EQN(CL*"B1D871A
M(#T@87)R87DH*3L*=VAI;&4@*"1R97,@/2!&:6QE7T-35CHZ<F5A9"@D9FEL
M92P@)&-O;F8I*2!["B`@("`D9&%T85M=(#T@)')E<SL*?0H*9G5N8W1I;VX@
M7V1B9T)U9F8H)&1A=&$I"GL*("`@(&9O<F5A8V@@*"1D871A(&%S("1K97D@
M/3X@)')O=RD@>PH@("`@("`@(&EF("AS=')P;W,H)')O=RP@(EQR(BD@(3T]
M(&9A;'-E*2!["B`@("`@("`@("`@("1R;W<@/2!S=')?<F5P;&%C92@B7'(B
M+"`B7W)?(BP@)')O=RD["B`@("`@("`@?0H@("`@("`@(&EF("AS=')P;W,H
M)')O=RP@(EQN(BD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("1S='(@/2!S
M=')?<F5P;&%C92@B7&XB+"`B7VY?(BP@)')O=RD["B`@("`@("`@?0H@("`@
M("`@(&EF("AS=')P;W,H)')O=RP@(EQT(BD@(3T](&9A;'-E*2!["B`@("`@
M("`@("`@("1R;W<@/2!S=')?<F5P;&%C92@B7'0B+"`B7W1?(BP@)')O=RD[
M"B`@("`@("`@?0H@("`@("`@("1D871A6R1K97E=(#T@)')O=SL*("`@('T*
M("`@(')E='5R;B`D9&%T83L*?0H*)&1A=&$@/2!A<G)A>5]M87`H)U]D8F="
M=69F)RP@)&1A=&$I.PH*<')I;G0@(D1A=&$Z7&XB.PIP<FEN=%]R*"1D871A
M*3L*/SX*+2U%6%!%0U0M+0I&;W)M870Z"D%R<F%Y"B@*("`@(%MF:65L9'-=
M(#T^(#0*("`@(%MS97!=(#T^("P*("`@(%MQ=6]T95T@/3X@(@HI"@I$871A
M.@I!<G)A>0HH"B`@("!;,%T@/3X@07)R87D*("`@("`@("`H"B`@("`@("`@
M("`@(%LP72`]/B!&:65L9"`Q+3$*("`@("`@("`@("`@6S%=(#T^($9I96QD
M(#$M,@H@("`@("`@("`@("!;,ET@/3X@1FEE;&0@,2TS"B`@("`@("`@("`@
M(%LS72`]/B!&:65L9"`Q+30*("`@("`@("`I"@H@("`@6S%=(#T^($%R<F%Y
M"B`@("`@("`@*`H@("`@("`@("`@("!;,%T@/3X@1FEE;&0@,BTQ"B`@("`@
M("`@("`@(%LQ72`]/B!&:65L9"`R+3(*("`@("`@("`@("`@6S)=(#T^($9I
M96QD(#(M,PH@("`@("`@("`@("!;,UT@/3X@22=M(&UU;'1I;&EN95]R7T9I
M96QD"B`@("`@("`@*0H*("`@(%LR72`]/B!!<G)A>0H@("`@("`@("@*("`@
M("`@("`@("`@6S!=(#T^($9I96QD(#,M,0H@("`@("`@("`@("!;,5T@/3X@
M1FEE;&0@,RTR"B`@("`@("`@("`@(%LR72`]/B!&:65L9"`S+3,*("`@("`@
M("`@("`@6S-=(#T^(`H@("`@("`@("D*"BD`````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T9I;&4O=&5S=',O0U-6+S`P-2YC
M<W8`````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`R,38@,3`U,34T,S,W
M,S,@,#(S,S(T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````")&:65L9"`Q+3$B+")&:65L9"`Q+3(B+")&:65L9"`Q+3,B+")&
M:65L9"`Q+30B#2)&:65L9"`R+3$B+")&:65L9"`R+3(B+")&:65L9"`R+3,B
M+")))VT@;75L=&EL:6YE#49I96QD(@TB1FEE;&0@,RTQ(BPB1FEE;&0@,RTR
M(BPB1FEE;&0@,RTS(@T`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]T97-T<R]&:6QE+W1E<W1S+T-35B\P,#8N<&AP=```````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`P-C(W(#$P-3$U-#,S-S,S(#`R,S4Q,P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````M+51%
M4U0M+0I&:6QE7T-35B!497-T($-A<V4@,#`V.B!/;F4@9FEE;&0@<75O=&4@
M875T;V1I<V-O=F5R>0HM+49)3$4M+0H\/W!H<`HO+R`D260Z(#`P-BYP:'!T
M+'8@,2XQ(#(P,#4O,#4O,C$@,#8Z,C8Z-#@@9'5F=7H@17AP("0*+RHJ"B`J
M(%1E<W0@9F]R.@H@*B`M($9I;&5?0U-6.CID:7-C;W9E<D9O<FUA="@I"B`J
M+PH*<F5Q=6ER95]O;F-E("=&:6QE+T-35BYP:'`G.PH*)&9I;&4@/2`G,#`V
M+F-S=B<["B1C;VYF(#T@1FEL95]#4U8Z.F1I<V-O=F5R1F]R;6%T*"1F:6QE
M*3L*"G!R:6YT(")&;W)M870Z7&XB.PIP<FEN=%]R*"1C;VYF*3L*<')I;G0@
M(EQN(CL*/SX*+2U%6%!%0U0M+0I&;W)M870Z"D%R<F%Y"B@*("`@(%MF:65L
M9'-=(#T^(#$*("`@(%MS97!=(#T^("P*("`@(%MQ=6]T95T@/3X@(@HI"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S
M=',O1FEL92]T97-T<R]#4U8O,#`V+F-S=@``````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#$U,"`Q,#4Q-30S,S<S,R`P,C,S,C(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````(E-A;7!L92!$871A($QI
M;F4@,2(*(E-A;7!L92!$871A($QI;F4@,B(*(E-A;7!L92!$871A($QI;F4@
M,R(*(E-A;7!L92!$871A($QI;F4@-"(*(E-A;7!L92!$871A($QI;F4@-2(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T9I;&4O=&5S
M=',O0U-6+W1E<W1S+G1X=```````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$Q
M,#8@,3`U,34T,S,W,S,@,#(T,C`U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````$9I;&5?0U-6(%1E<W0@0V%S90H]/3T]/3T]
M/3T]/3T]/3T]/3T*"B`@("`@0V%S92`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@0V]V97)E9"`@3F]T97,*+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2T*,#`Q("!&:65L9',@8V]U;G0@;&5S<R!T:&%N
M(&5X<&5C=&5D("`@("`@("!;>%T*,#`R("!&:65L9',@8V]U;G0@;6]R92!T
M:&%N(&5X<&5C=&5D("`@("`@("!;>%T@("`@("!(:6=H(')I<VL@<&]S<VEB
M:6QI='D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!D:7-C;W9E<F5D(&9I96QD<R!C;W5N=`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('=R;VYG"C`P,R`@5VEN9&]W<R!%3TP@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@6WA="C`P-"`@56YI>"!%3TP@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@6WA="C`P-2`@36%C($5/3"`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@6WA="@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T9I
M;&4O=&5S=',O0U-6+S`P,2YC<W8`````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`Q-S8@,3`U,34T,S,W,S,@,#(S,S(U`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````")&:65L9"`Q+3$B+"`B1FEE;&0@
M,2TR(BP@(D9I96QD(#$M,R(L(")&:65L9"`Q+30B"B)&:65L9"`R+3$B+"`B
M1FEE;&0@,BTR(BP@(D9I96QD(#(M,R(*(D9I96QD(#,M,2(L(")&:65L9"`S
M+3(B"B)&:65L9"`T+3$B"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]&:6QE+W1E<W1S+W1E
M<W0N8W-V````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,#,Q(#$P
M-3$U-#,S-S,S(#`R,S,T,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!F,0EF,@EF,PEF-`IG;V]D,0EG;V]D,@EG;V]D,PEG
M;V]D-`H[.SL[.PD[.SL[.PD[.SL[.PD[.SL[.PHZ(#H@.@D[(#L@(@DB+@DB
M"3HZ.CH[.SL[(@IN;R)Q=6]T90EN;R)Q=2)O=&4);B)Q=6]T92();B)Q(G4B
M;R)T(@HB<75O=&4Q(@DB<75O=&4R(@EN;W%U;W1E,R();F]Q=6]T930*=&5S
M=#$)(FQO;F<*=&5S=#(B"2)L;VYG('1E<W0S"7=I=&@)<V5P<R()(DDG;0H)
M"0D)"7-I;&QY"@D)"0D);&]N9R(*;&5S<S$)(FQE<W,R"2XB"6QE<W,S"FES
M=F%L:60Q"6ES=F%L:60R"6ES=F%L:60S"6ES=F%L:60T"FUO<F4R,0DB;6]R
M93(R"0DN(@EM;W)E,C,);6]R93(T"6UO<F4R-0EM;W)E,C8*:7-V86QI9#(Q
M"6ES=F%L:60R,@EI<W9A;&ED,C,):7-V86QI9#(T"FQE<W-N;W$S,0EL97-S
M;F]Q,S();&5S<VYO<3,S"FES=F%L:60S,0EI<W9A;&ED,S():7-V86QI9#,S
M"6ES=F%L:60S-`IM;W)E;F]Q-#$);6]R96YO<30R"6UO<F5N;W$T,PEM;W)E
M;F]Q-#0);6]R96YO<30U"FES=F%L:60T,0EI<W9A;&ED-#():7-V86QI9#0S
M"6ES=F%L:60T-`H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]&:6QE+W1E
M<W1S+T9I;&5497-T+G!H<```````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#(Q
M,3$Q(#$P-3$U-#,S-S,S(#`R-#`W-0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`H*+R\@;F5E9&5D(&9O<B!L;V-K
M:6YG('1E<W0*9&5F:6YE*"=&24Q%7TQ/0TM37T),3T-+)RP@9F%L<V4L('1R
M=64I.PH*<F5Q=6ER95]O;F-E("=02%!5;FET+G!H<"<["G)E<75I<F5?;VYC
M92`G1FEL92YP:'`G.PH*8VQA<W,@1FEL951E<W0@97AT96YD<R!02%!5;FET
M7U1E<W1#87-E(`I["B`@("!F=6YC=&EO;B!&:6QE5&5S="@D;F%M92`]("=&
M:6QE5&5S="<I"B`@("!["B`@("`@("`@)'1H:7,M/E!(4%5N:71?5&5S=$-A
M<V4H)&YA;64I.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%1E<W13=')I;F<H
M*0H@("`@>PH@("`@("`@('-T871I8R`D<W1R.PH@("`@("`@(&ES<V5T*"1S
M='(I(&]R("1S='(@/2!S=')?<F5P96%T*'-T<E]R97!E870H(C`Q,C,T-38W
M.#DB+"`Q,#`P*2XB7&XB+"`Q,#`I.PH@("`@("`@(')E='5R;B`D<W1R.PH@
M("`@?0H@("`@"B`@("!F=6YC=&EO;B!G971497-T3&EN92@I"B`@("!["B`@
M("`@("`@<W1A=&EC("1S='(["B`@("`@("`@:7-S970H)'-T<BD@;W(@)'-T
M<B`]('-T<E]R97!E870H(C`Q,C,T-38W.#DB+"`Q,#`P*3L*("`@("`@("!R
M971U<FX@)'-T<CL*("`@('T*("`@(`H@("`@9G5N8W1I;VX@<V5T57`H*0H@
M("`@>PH@("`@("`@("1T:&ES+3YT96%R1&]W;B@I.PH@("`@("`@(&EF("A0
M14%2.CII<T5R<F]R*"1E(#T@1FEL93HZ=W)I=&4H)W1E<W0N='AT)RP@)'1H
M:7,M/F=E=%1E<W13=')I;F<H*2P@1DE,15]-3T1%7U=2251%*2DI('L*("`@
M("`@("`@("`@9&EE*")#86YN;W0@<W1A<G0@=&5S=#H@(BX@<W1R7W)E<&QA
M8V4H)'1H:7,M/F=E=%1E<W13=')I;F<H*2PG+BXN)RP@)&4M/F=E=$UE<W-A
M9V4H*2DI.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!T96%R1&]W
M;B@I"B`@("!["B`@("`@("`@1FEL93HZ8VQO<V5!;&PH*3L*("`@("`@("!F
M:6QE7V5X:7-T<R@G=&5S="YT>'0G*2!A;F0@=6YL:6YK*"=T97-T+G1X="<I
M.PH@("`@?0H*("`@(&9U;F-T:6]N('1E<W1L;V-K:6YG*"D*("`@('L*("`@
M("`@("`D=&AI<RT^87-S97)T1F%L<V4H4$5!4CHZ:7-%<G)O<BA&:6QE.CIW
M<FET92@G=&5S="YT>'0G+"`G86)C)RP@1DE,15]-3T1%7T%04$5.1"P@=')U
M92DI*3L*("`@("`@("`D=&AI<RT^87-S97)T5')U92A014%2.CII<T5R<F]R
M*$9I;&4Z.G=R:71E*"=T97-T+G1X="<L("=D968G+"!&24Q%7TU/1$5?5U))
M5$4L('1R=64I*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$9A;'-E*%!%05(Z
M.FES17)R;W(H1FEL93HZ=6YL;V-K*"=T97-T+G1X="<L($9)3$5?34]$15]!
M4%!%3D0I*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$9A;'-E*%!%05(Z.FES
M17)R;W(H1FEL93HZ=6YL;V-K*"=T97-T+G1X="<L($9)3$5?34]$15]74DE4
M12DI*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T8VQO<V4H*0H@("`@>PH@
M("`@("`@("1T:&ES+3YA<W-E<G1&86QS92A014%2.CII<T5R<F]R*$9I;&4Z
M.F-L;W-E*"=T97-T+G1X="<L($9)3$5?34]$15]74DE412DI*3L*("`@("`@
M("`D=&AI<RT^87-S97)T1F%L<V4H4$5!4CHZ:7-%<G)O<BA&:6QE.CIC;&]S
M92@G=&5S="YT>'0G+"!&24Q%7TU/1$5?05!014Y$*2DI.PH@("`@("`@("1T
M:&ES+3YA<W-E<G1&86QS92A014%2.CII<T5R<F]R*$9I;&4Z.F-L;W-E*"=T
M97-T+G1X="<L($9)3$5?34]$15]214%$*2DI.PH@("`@?0H*("`@(&9U;F-T
M:6]N('1E<W1R96%D06QL*"D*("`@('L*("`@("`@("`D=&AI<RT^87-S97)T
M17%U86QS*"1T:&ES+3YG971497-T4W1R:6YG*"DL($9I;&4Z.G)E861!;&PH
M)W1E<W0N='AT)RDI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H)'1H
M:7,M/F=E=%1E<W13=')I;F<H*2P@1FEL93HZ<F5A9$%L;"@G=&5S="YT>'0G
M*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@D=&AI<RT^9V5T5&5S
M=%-T<FEN9R@I+"!&:6QE.CIR96%D06QL*"=T97-T+G1X="<I*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!T97-T<F5A9"@I"B`@("!["B`@("`@("`@)'1H:7,M
M/F%S<V5R=$5Q=6%L<R@D=&AI<RT^9V5T5&5S=$QI;F4H*2P@1FEL93HZ<F5A
M9"@G=&5S="YT>'0G+"`Q,#`P,"DI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%
M<75A;',H(EQN(BP@1FEL93HZ<F5A9"@G=&5S="YT>'0G+"`Q*2D["B`@("`@
M("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@G,#$R,S0U-C<X.2<L($9I;&4Z.G)E
M860H)W1E<W0N='AT)RP@,3`I*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T
M=W)I=&4H*0H@("`@>PH@("`@("`@("1T:&ES+3YA<W-E<G1&86QS92A014%2
M.CII<T5R<F]R*"1B>71E<R`]($9I;&4Z.G=R:71E*"=T97-T+G1X="<L("<P
M,3(S-#4V-S@Y)RDI*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*#$P
M+"`D8GET97,I.PH@("`@?0H*("`@(&9U;F-T:6]N('1E<W1R96%D0VAA<B@I
M"B`@("!["B`@("`@("`@)'1H:7,M/F%S<V5R=$9A;'-E*%!%05(Z.FES17)R
M;W(H1FEL93HZ<F5W:6YD*"=T97-T+G1X="<L($9)3$5?34]$15]214%$*2DI
M.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H)S`G+"!&:6QE.CIR96%D
M0VAA<B@G=&5S="YT>'0G*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L
M<R@G,2<L($9I;&4Z.G)E861#:&%R*"=T97-T+G1X="<I*3L*("`@("`@("`D
M=&AI<RT^87-S97)T17%U86QS*"<R)RP@1FEL93HZ<F5A9$-H87(H)W1E<W0N
M='AT)RDI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H)S,G+"!&:6QE
M.CIR96%D0VAA<B@G=&5S="YT>'0G*2D["B`@("`@("`@)'1H:7,M/F%S<V5R
M=$5Q=6%L<R@G-"<L($9I;&4Z.G)E861#:&%R*"=T97-T+G1X="<I*3L*("`@
M("`@("`D=&AI<RT^87-S97)T17%U86QS*"<U)RP@1FEL93HZ<F5A9$-H87(H
M)W1E<W0N='AT)RDI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H)S8G
M+"!&:6QE.CIR96%D0VAA<B@G=&5S="YT>'0G*2D["B`@("`@("`@)'1H:7,M
M/F%S<V5R=$5Q=6%L<R@G-R<L($9I;&4Z.G)E861#:&%R*"=T97-T+G1X="<I
M*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"<X)RP@1FEL93HZ<F5A
M9$-H87(H)W1E<W0N='AT)RDI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A
M;',H)SDG+"!&:6QE.CIR96%D0VAA<B@G=&5S="YT>'0G*2D["B`@("`@("`@
M)'1H:7,M/F%S<V5R=$5Q=6%L<R@G,"<L($9I;&4Z.G)E861#:&%R*"=T97-T
M+G1X="<I*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T=W)I=&5#:&%R*"D*
M("`@('L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*#$L($9I;&4Z.G=R
M:71E0VAA<B@G=&5S="YT>'0G+"`G82<I*3L*("`@("`@("`D=&AI<RT^87-S
M97)T17%U86QS*#$L($9I;&4Z.G=R:71E0VAA<B@G=&5S="YT>'0G+"`G8B<I
M*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*#$L($9I;&4Z.G=R:71E
M0VAA<B@G=&5S="YT>'0G+"`G8R<I*3L*("`@("`@("`D=&AI<RT^87-S97)T
M17%U86QS*#$L($9I;&4Z.G=R:71E0VAA<B@G=&5S="YT>'0G+"`G9"<I*3L*
M("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*#$L($9I;&4Z.G=R:71E0VAA
M<B@G=&5S="YT>'0G+"`G92<I*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U
M86QS*#$L($9I;&4Z.G=R:71E0VAA<B@G=&5S="YT>'0G+"`G9B<I*3L*("`@
M("`@("`D=&AI<RT^87-S97)T17%U86QS*#$L($9I;&4Z.G=R:71E0VAA<B@G
M=&5S="YT>'0G+"`G9R<I*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS
M*#$L($9I;&4Z.G=R:71E0VAA<B@G=&5S="YT>'0G+"`G:"<I*3L*("`@("`@
M("`D=&AI<RT^87-S97)T17%U86QS*#$L($9I;&4Z.G=R:71E0VAA<B@G=&5S
M="YT>'0G+"`G:2<I*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*#$L
M($9I;&4Z.G=R:71E0VAA<B@G=&5S="YT>'0G+"`G:B<I*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!T97-T<F5A9$QI;F4H*0H@("`@>PH@("`@("`@("1T:&ES
M+3YA<W-E<G1&86QS92A014%2.CII<T5R<F]R*$9I;&4Z.G)E=VEN9"@G=&5S
M="YT>'0G+"!&24Q%7TU/1$5?4D5!1"DI*3L*("`@("`@("`D=&AI<RT^87-S
M97)T17%U86QS*"1T:&ES+3YG971497-T3&EN92@I+"!&:6QE.CIR96%D3&EN
M92@G=&5S="YT>'0G*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@D
M=&AI<RT^9V5T5&5S=$QI;F4H*2P@1FEL93HZ<F5A9$QI;F4H)W1E<W0N='AT
M)RDI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H)'1H:7,M/F=E=%1E
M<W1,:6YE*"DL($9I;&4Z.G)E861,:6YE*"=T97-T+G1X="<I*3L*("`@("`@
M("`D=&AI<RT^87-S97)T17%U86QS*"1T:&ES+3YG971497-T3&EN92@I+"!&
M:6QE.CIR96%D3&EN92@G=&5S="YT>'0G*2D["B`@("`@("`@)'1H:7,M/F%S
M<V5R=$5Q=6%L<R@D=&AI<RT^9V5T5&5S=$QI;F4H*2P@1FEL93HZ<F5A9$QI
M;F4H)W1E<W0N='AT)RDI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H
M)'1H:7,M/F=E=%1E<W1,:6YE*"DL($9I;&4Z.G)E861,:6YE*"=T97-T+G1X
M="<I*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"1T:&ES+3YG9714
M97-T3&EN92@I+"!&:6QE.CIR96%D3&EN92@G=&5S="YT>'0G*2D["B`@("`@
M("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@D=&AI<RT^9V5T5&5S=$QI;F4H*2P@
M1FEL93HZ<F5A9$QI;F4H)W1E<W0N='AT)RDI.PH@("`@("`@("1T:&ES+3YA
M<W-E<G1%<75A;',H)'1H:7,M/F=E=%1E<W1,:6YE*"DL($9I;&4Z.G)E861,
M:6YE*"=T97-T+G1X="<I*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS
M*"1T:&ES+3YG971497-T3&EN92@I+"!&:6QE.CIR96%D3&EN92@G=&5S="YT
M>'0G*2D["B`@("!]"@H@("`@9G5N8W1I;VX@=&5S='=R:71E3&EN92@I"B`@
M("!["B`@("`@("`@)&QI;F4@/2`D=&AI<RT^9V5T5&5S=$QI;F4H*3L*("`@
M("`@("`D;&5N9W1H(#T@<W1R;&5N*"1L:6YE*2`K(#$["B`@("`@("`@)'1H
M:7,M/F%S<V5R=$5Q=6%L<R@D;&5N9W1H+"!&:6QE.CIW<FET94QI;F4H)W1E
M<W0N='AT)RP@)&QI;F4I*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS
M*"1L96YG=&@L($9I;&4Z.G=R:71E3&EN92@G=&5S="YT>'0G+"`D;&EN92DI
M.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H)&QE;F=T:"P@1FEL93HZ
M=W)I=&5,:6YE*"=T97-T+G1X="<L("1L:6YE*2D["B`@("`@("`@)'1H:7,M
M/F%S<V5R=$5Q=6%L<R@D;&5N9W1H+"!&:6QE.CIW<FET94QI;F4H)W1E<W0N
M='AT)RP@)&QI;F4I*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"1L
M96YG=&@L($9I;&4Z.G=R:71E3&EN92@G=&5S="YT>'0G+"`D;&EN92DI.PH@
M("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H)&QE;F=T:"P@1FEL93HZ=W)I
M=&5,:6YE*"=T97-T+G1X="<L("1L:6YE*2D["B`@("`@("`@)'1H:7,M/F%S
M<V5R=$5Q=6%L<R@D;&5N9W1H+"!&:6QE.CIW<FET94QI;F4H)W1E<W0N='AT
M)RP@)&QI;F4I*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"1L96YG
M=&@L($9I;&4Z.G=R:71E3&EN92@G=&5S="YT>'0G+"`D;&EN92DI.PH@("`@
M("`@("1T:&ES+3YA<W-E<G1%<75A;',H)&QE;F=T:"P@1FEL93HZ=W)I=&5,
M:6YE*"=T97-T+G1X="<L("1L:6YE*2D["B`@("`@("`@)'1H:7,M/F%S<V5R
M=$5Q=6%L<R@D;&5N9W1H+"!&:6QE.CIW<FET94QI;F4H)W1E<W0N='AT)RP@
M)&QI;F4I*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T<F5W:6YD*"D*("`@
M('L*("`@("`@("`D=&AI<RT^87-S97)T1F%L<V4H4$5!4CHZ:7-%<G)O<BA&
M:6QE.CIR97=I;F0H)W1E<W0N='AT)RP@1DE,15]-3T1%7U=2251%*2DI.PH@
M("`@("`@("1T:&ES+3YA<W-E<G1&86QS92A014%2.CII<T5R<F]R*$9I;&4Z
M.G)E=VEN9"@G=&5S="YT>'0G+"!&24Q%7TU/1$5?4D5!1"DI*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!T97-T8G5I;&10871H*"D*("`@('L*("`@("`@("`D
M<&%T:"`](&%R<F%Y*`H@("`@("`@("`@("`G<V]M92<L"B`@("`@("`@("`@
M($1)4D5#5$]265]315!!4D%43U(L"B`@("`@("`@("`@($1)4D5#5$]265]3
M15!!4D%43U(L"B`@("`@("`@("`@($1)4D5#5$]265]315!!4D%43U(L"B`@
M("`@("`@("`@($1)4D5#5$]265]315!!4D%43U(L"B`@("`@("`@("`@("=W
M96ER9"<N1$E214-43U)97U-%4$%2051/4BP*("`@("`@("`@("`@1$E214-4
M3U)97U-%4$%2051/4BP*("`@("`@("`@("`@1$E214-43U)97U-%4$%2051/
M4BP*("`@("`@("`@("`@1$E214-43U)97U-%4$%2051/4BP*("`@("`@("`@
M("`@1$E214-43U)97U-%4$%2051/4BXG<&%T:"<N1$E214-43U)97U-%4$%2
M051/4BY$25)%0U1/4EE?4T5005)!5$]2+`H@("`@("`@("D["B`@("`@("`@
M)&)U:6QT(#T@:6UP;&]D92A$25)%0U1/4EE?4T5005)!5$]2+"!A<G)A>2@G
M<V]M92<L)W=E:7)D)RPG<&%T:"<L)R<L)R<I*3L*("`@("`@("`D=&AI<RT^
M87-S97)T17%U86QS*"1B=6EL="P@1FEL93HZ8G5I;&10871H*"1P871H*2D[
M"B`@("!]"@H@("`@9G5N8W1I;VX@=&5S='-K:7!2;V]T*"D*("`@('L*("`@
M("`@("!I9B`H3U-?5TE.1$]74RD@>PH@("`@("`@("`@("`D=&AI<RT^87-S
M97)T17%U86QS*"=724Y$3U=3)RP@1FEL93HZ<VMI<%)O;W0H)T,Z7%Q724Y$
M3U=3)RDI.PH@("`@("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"=724Y$
M3U=3)RP@1FEL93HZ<VMI<%)O;W0H)T,Z7%Q<7%=)3D1/5U,G*2D["B`@("`@
M("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H)U=)3D1/5U,G+"!&:6QE.CIS
M:VEP4F]O="@G0SHO5TE.1$]74R<I*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"=U<W(O<VAA<F4O<&5A<B<L
M($9I;&4Z.G-K:7!2;V]T*"<O=7-R+W-H87)E+W!E87(G*2D["B`@("`@("`@
M?0H@("`@?0H*("`@(&9U;F-T:6]N('1E<W1G971496UP1&ER*"D*("`@('L*
M("`@("`@("`D9&ER(#T@1FEL93HZ9V5T5&5M<$1I<B@I.PH@("`@("`@("1T
M:&ES+3YA<W-E<G14<G5E*&ES7V1I<B@D9&ER*2P@(FES7V1I<B@D9&ER*2(I
M.PH@("`@?0H*("`@(&9U;F-T:6]N('1E<W1G971496UP1FEL92@I"B`@("![
M"B`@("`@("`@)'1M<"`]($9I;&4Z.F=E=%1E;7!&:6QE*"D["B`@("`@("`@
M)'1H:7,M/F%S<V5R=%1R=64H9FEL95]E>&ES=',H)'1M<"DI.PH@("`@?0H*
M("`@(&9U;F-T:6]N('1E<W1I<T%B<V]L=71E*"D*("`@('L*("`@("`@("`D
M=&AI<RT^87-S97)T1F%L<V4H1FEL93HZ:7-!8G-O;'5T92@G86)R82\N+B]C
M861A8G)A)RDI.PH@("`@("`@("1T:&ES+3YA<W-E<G1&86QS92A&:6QE.CII
M<T%B<V]L=71E*"=D871A+V1I<B<I*3L*("`@("`@("!I9B`H3U-?5TE.1$]7
M4RD@>PH@("`@("`@("`@("`D=&AI<RT^87-S97)T5')U92A&:6QE.CII<T%B
M<V]L=71E*"=#.EQ<7%QD871A)RDI.PH@("`@("`@("`@("`D=&AI<RT^87-S
M97)T5')U92A&:6QE.CII<T%B<V]L=71E*"=D.B]D871A)RDI.PH@("`@("`@
M("`@("`D=&AI<RT^87-S97)T1F%L<V4H1FEL93HZ:7-!8G-O;'5T92@G7%PG
M*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/F%S<V5R
M=%1R=64H1FEL93HZ:7-!8G-O;'5T92@G+R<I*3L*("`@("`@("`@("`@)'1H
M:7,M/F%S<V5R=$9A;'-E*$9I;&4Z.FES06)S;VQU=&4H)UQ<)RDI.PH@("`@
M("`@("`@("`D=&AI<RT^87-S97)T5')U92A&:6QE.CII<T%B<V]L=71E*"=^
M;6EK92]B:6XG*2D["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N('1E
M<W1R96QA=&EV95!A=&@H*0H@("`@>PH@("`@("`@("1T:&ES+3YA<W-E<G1%
M<75A;',H)W1E<W1S+T9I;&4G+"!&:6QE.CIR96QA=&EV95!A=&@H)R]U<W(O
M<VAA<F4O<&5A<B]T97-T<R]&:6QE)RP@)R]U<W(O<VAA<F4O<&5A<B<L("<O
M)RDI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H)RXN+V5T8R<L($9I
M;&4Z.G)E;&%T:79E4&%T:"@G+V5T8R<L("<O=7-R)RP@)R\G*2D["B`@("`@
M("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@G1#I<7$1A=&$G+"!&:6QE.CIR96QA
M=&EV95!A=&@H)T0Z7%Q$871A)RP@)T,Z7%Q$871A)RP@)UQ<)RDI.PH@("`@
M("`@(&EF("A/4U]724Y$3U=3*2!["B`@("`@("`@("`@("1T:&ES+3YA<W-E
M<G1%<75A;',H)V1A=&%<7&1I<B<L($9I;&4Z.G)E;&%T:79E4&%T:"@G+W9A
M<B]D871A+V1I<B<L("<O=F%R)RDI.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H)V1A=&$O9&ER)RP@1FEL93HZ
M<F5L871I=F50871H*"<O=F%R+V1A=&$O9&ER)RP@)R]V87(G*2D["B`@("`@
M("`@?0H@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H)RXN+R<L($9I;&4Z
M.G)E;&%T:79E4&%T:"@G9&%T82<L("=D871A+V1I<B<L("<O)RDI.PH@("`@
M?0H*("`@(&9U;F-T:6]N('1E<W1R96%L<&%T:"@I"B`@("!["B`@("`@("`@
M)&1R:79E(#T@3U-?5TE.1$]74R`_('-U8G-T<BAG971C=V0H*2PP+"`R*2`Z
M)R<["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@D9')I=F4@+B`G+V$O
M=V5I<F0O<&%T:"]I<R<L($9I;&4Z.G)E86QP871H*"<O85Q<=V5I<F0O+W!A
M=&A<:7,O=&AA="\N+RXN+R<L("<O)RDI.PH@("`@("`@("1T:&ES+3YA<W-E
M<G1%<75A;',H)&1R:79E("X@)R]A+W=E:7)D+W!A=&@O:7,O=&AA="<L($9I
M;&4Z.G)E86QP871H*"<O85Q<=V5I<F0O+W!A=&A<:7,O=&AA="\N+RXN+W1H
M870O+B<L("<O)RDI.PH@("`@?0I]"@HD<F5S=6QT(#T@)E!(4%5N:70Z.G)U
M;BAN97<@4$A056YI=%]497-T4W5I=&4H)T9I;&5497-T)RDI.PIE8VAO("1R
M97-U;'0M/G1O4W1R:6YG*"D["@H_/@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S
M+T9I;&4O=&5S=',O<&%R<V5R+G!H<```````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#$R,#`@,3`U,34T,S,W,S,@,#(S-C0W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B1P871H(#T@:6YI
M7V=E="@G:6YC;'5D95]P871H)RD["FEN:5]S970H)VEN8VQU9&5?<&%T:"<L
M(')E86QP871H*"<N+B\G*2`N("(Z)'!A=&@B*3L*<F5Q=6ER95]O;F-E("=&
M:6QE+T-35BYP:'`G.PH*+RHO17AA;7!L92!C;VYF.@HD8V]N9B`](&%R<F%Y
M*`H@("`@)V9I96QD<R<@/3X@-"P*("`@("=S97`G("`@(#T^(")<="(L"B`@
M("`G<75O=&4G("`]/B`G(B<L"B`@("`G:&5A9&5R)R`]/B!F86QS90HI.PHO
M+RHO"F]B7VEM<&QI8VET7V9L=7-H*'1R=64I.PHD87)G=B`]("1?4T525D52
M6R=A<F=V)UT["B1F:6QE(#T@)&%R9W9;,5T["B1W<FET92`]("AI<W-E="@D
M87)G=ELR72DI(#\@)&%R9W9;,ET@.B!F86QS93L*4$5!4CHZ<V5T17)R;W)(
M86YD;&EN9RA014%27T524D]27U!224Y4+"`B=V%R;FEN9SH@)7-<;B(I.PH*
M)&-O;F8@/2!&:6QE7T-35CHZ9&ES8V]V97)&;W)M870H)&9I;&4I.PIW:&EL
M92`H)&9I96QD<R`]($9I;&5?0U-6.CIR96%D*"1F:6QE+"`D8V]N9BDI('L*
M("`@(&EF("@D=W)I=&4I('L*("`@("`@("!&:6QE7T-35CHZ=W)I=&4H)'=R
M:71E+"`D9FEE;&1S+"`D8V]N9BD["B`@("!]"B`@("!P<FEN=%]R*"1F:65L
M9',I.PI]"@IV87)?9'5M<"@D8V]N9BD["F5C:&\@(EQN(@H*/SX`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+TA45%``````````````````````````````````````````````````````
M````````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S,@,#$W,38V`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O2%144"]297%U97-T````````````````````
M```````````````````````````````````````````````````````````P
M,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<S
M,R`P,C`V,38`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B](5%10+U)E<75E
M<W0O3&ES=&5N97(N<&AP````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`W,C4P(#$P-3$U-#,S-S,S(#`R,S$W-P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`R,#`R+3(P,#,L
M(%)I8VAA<F0@2&5Y97,@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@?"!!;&P@<FEG:'1S(')E<V5R=F5D+B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O('P@4F5D:7-T<FEB=71I;VX@86YD
M('5S92!I;B!S;W5R8V4@86YD(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H
M;W5T("`@('P*+R\@?"!M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@<')O
M=FED960@=&AA="!T:&4@9F]L;&]W:6YG(&-O;F1I=&EO;G,@("`@?`HO+R!\
M(&%R92!M970Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@?"!O(%)E9&ES=')I8G5T:6]N<R!O9B!S;W5R
M8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I9VAT("`@("`@
M?`HO+R!\("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@
M=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R+B`@("`@("!\"B\O('P@;R!2961I
M<W1R:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE
M(&%B;W9E(&-O<'ER:6=H="`@('P*+R\@?"`@(&YO=&EC92P@=&AI<R!L:7-T
M(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I
M;B!T:&4@?`HO+R!\("`@9&]C=6UE;G1A=&EO;B!A;F0O;W(@;W1H97(@;6%T
M97)I86QS('!R;W9I9&5D('=I=&@@=&AE(&1I<W1R:6)U=&EO;BY\"B\O('P@
M;R!4:&4@;F%M97,@;V8@=&AE(&%U=&AO<G,@;6%Y(&YO="!B92!U<V5D('1O
M(&5N9&]R<V4@;W(@<')O;6]T92`@("`@('P*+R\@?"`@('!R;V1U8W1S(&1E
M<FEV960@9G)O;2!T:&ES('-O9G1W87)E('=I=&AO=70@<W!E8VEF:6,@<')I
M;W(@=W)I='1E;B`@?`HO+R!\("`@<&5R;6ES<VEO;BX@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!42$E3(%-/
M1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$524R!!
M3D0@0T].5%))0E543U)3("`@?`HO+R!\(")!4R!)4R(@04Y$($%.62!%6%!2
M15-3($]2($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4
M("`@("!\"B\O('P@3$E-251%1"!43RP@5$A%($E-4$Q)140@5T%24D%.5$E%
M4R!/1B!-15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,@1D]2('P*+R\@?"!!
M(%!!4E1)0U5,05(@4%524$]312!!4D4@1$E30TQ!24U%1"X@24X@3D\@159%
M3E0@4TA!3$P@5$A%($-/4%E224=(5"`@?`HO+R!\($]73D52($]2($-/3E12
M24)55$]24R!"12!,24%"3$4@1D]2($%.62!$25)%0U0L($E.1$E214-4+"!)
M3D-)1$5.5$%,+"!\"B\O('P@4U!%0TE!3"P@15A%35!,05)9+"!/4B!#3TY3
M15%514Y424%,($1!34%'15,@*$E.0TQ51$E.1RP@0E54($Y/5"`@("`@('P*
M+R\@?"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1B!354)35$E4551%($=/
M3T13($]2(%-%4E9)0T53.R!,3U-3($]&(%5312P@?`HO+R!\($1!5$$L($]2
M(%!23T9)5%,[($]2($)54TE.15-3($E.5$524E505$E/3BD@2$]7159%4B!#
M0553140@04Y$($].($%.62!\"B\O('P@5$A%3U)9($]&($Q)04))3$E462P@
M5TA%5$A%4B!)3B!#3TY44D%#5"P@4U1224-4($Q)04))3$E462P@3U(@5$]2
M5"`@('P*+R\@?"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%
M*2!!4DE324Y'($E.($%.62!705D@3U54($]&(%1(12!54T4@?`HO+R!\($]&
M(%1(25,@4T]&5%=!4D4L($5614X@248@041625-%1"!/1B!42$4@4$]34TE"
M24Q)5%D@3T8@4U5#2"!$04U!1T4N("!\"B\O('P@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\($%U=&AO<CH@06QE>&5Y($)O<GIO=B`\879B0'!H<"YN970^("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z($QI<W1E;F5R+G!H<"QV(#$N
M,B`R,#`S+S$P+S(V(#$P.C(X.C(Y(&%V8B!%>'`@)`HO+PH*+RHJ"B`J(%1H
M:7,@8VQA<W,@:6UP;&5M96YT<R!T:&4@3V)S97)V97(@<&%R="!O9B!A(%-U
M8FIE8W0M3V)S97)V97(*("H@9&5S:6=N('!A='1E<FXN($ET(&QI<W1E;G,@
M=&\@=&AE(&5V96YT<R!S96YT(&)Y(&$@"B`J($A45%!?4F5Q=65S="!O<B!(
M5%107U)E<W!O;G-E(&EN<W1A;F-E+@H@*@H@*B!`<&%C:V%G92!(5%107U)E
M<75E<W0*("H@0&%U=&AO<B`@06QE>&5Y($)O<GIO=B`\879B0'!H<"YN970^
M"B`J($!V97)S:6]N("12979I<VEO;CH@,2XR("0*("HO"F-L87-S($A45%!?
M4F5Q=65S=%],:7-T96YE<B`*>PH@("`O*BH*("`@("H@02!L:7-T96YE<B=S
M(&ED96YT:69I97(*("`@("H@0'9A<B!S=')I;F<*("`@("HO"B`@("!V87(@
M)%]I9#L*"B`@("\J*@H@("`@*B!#;VYS=')U8W1O<BP@<V5T<R!T:&4@;V)J
M96-T)W,@:61E;G1I9FEE<@H@("`@*@H@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@*B\*("`@(&9U;F-T:6]N($A45%!?4F5Q=65S=%],:7-T96YE<B@I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]I9"`](&UD-2AU;FEQ:60H)VAT='!?<F5Q
M=65S=%\G+"`Q*2D["B`@("!]"@H*("`@+RHJ"B`@("`J(%)E='5R;G,@=&AE
M(&QI<W1E;F5R)W,@:61E;G1I9FEE<@H@("`@*@H@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@*B!`<F5T=7)N('-T<FEN9PH@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$ED*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]I9#L*("`@
M('T*"@H@("`O*BH*("`@("H@5&AI<R!M971H;V0@:7,@8V%L;&5D('=H96X@
M3&ES=&5N97(@:7,@;F]T:69I960@;V8@86X@979E;G0*("`@("H*("`@("H@
M0&%C8V5S<R`@('!U8FQI8PH@("`@*B!`<&%R86T@("`@;V)J96-T("!A;B!O
M8FIE8W0@=&AE(&QI<W1E;F5R(&ES(&%T=&%C:&5D('1O"B`@("`J($!P87)A
M;2`@("!S=')I;F<@($5V96YT(&YA;64*("`@("H@0'!A<F%M("`@(&UI>&5D
M("`@061D:71I;VYA;"!D871A"B`@("`J($!A8G-T<F%C=`H@("`@*B\*("`@
M(&9U;F-T:6]N('5P9&%T92@F)'-U8FIE8W0L("1E=F5N="P@)&1A=&$@/2!N
M=6QL*0H@("`@>PH@("`@("`@(&5C:&\@(DYO=&EF:65D(&]F(&5V96YT.B`G
M)&5V96YT)UQN(CL*("`@("`@("!I9B`H;G5L;"`A/3T@)&1A=&$I('L*("`@
M("`@("`@("`@96-H;R`B061D:71I;VYA;"!D871A.B`B.PH@("`@("`@("`@
M("!V87)?9'5M<"@D9&%T82D["B`@("`@("`@?0H@("`@?0I]"C\^"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B](5%10+U)E<75E<W0N<&AP````````````````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,3$Q,C<Q(#$P-3$U-#,S-S,S(#`R,30Q,0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I
M9VAT("AC*2`R,#`R+3(P,#,L(%)I8VAA<F0@2&5Y97,@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@?"!!;&P@<FEG:'1S(')E<V5R=F5D
M+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@
M4F5D:7-T<FEB=71I;VX@86YD('5S92!I;B!S;W5R8V4@86YD(&)I;F%R>2!F
M;W)M<RP@=VET:"!O<B!W:71H;W5T("`@('P*+R\@?"!M;V1I9FEC871I;VXL
M(&%R92!P97)M:71T960@<')O=FED960@=&AA="!T:&4@9F]L;&]W:6YG(&-O
M;F1I=&EO;G,@("`@?`HO+R!\(&%R92!M970Z("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!O(%)E9&ES
M=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@86)O
M=F4@8V]P>7)I9VAT("`@("`@?`HO+R!\("`@;F]T:6-E+"!T:&ES(&QI<W0@
M;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R+B`@
M("`@("!\"B\O('P@;R!2961I<W1R:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@
M;75S="!R97!R;V1U8V4@=&AE(&%B;W9E(&-O<'ER:6=H="`@('P*+R\@?"`@
M(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL
M;W=I;F<@9&ES8VQA:6UE<B!I;B!T:&4@?`HO+R!\("`@9&]C=6UE;G1A=&EO
M;B!A;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE(&1I
M<W1R:6)U=&EO;BY\"B\O('P@;R!4:&4@;F%M97,@;V8@=&AE(&%U=&AO<G,@
M;6%Y(&YO="!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92`@("`@('P*
M+R\@?"`@('!R;V1U8W1S(&1E<FEV960@9G)O;2!T:&ES('-O9G1W87)E('=I
M=&AO=70@<W!E8VEF:6,@<')I;W(@=W)I='1E;B`@?`HO+R!\("`@<&5R;6ES
M<VEO;BX@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@?"!42$E3(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#
M3U!94DE'2%0@2$],1$524R!!3D0@0T].5%))0E543U)3("`@?`HO+R!\(")!
M4R!)4R(@04Y$($%.62!%6%!215-3($]2($E-4$Q)140@5T%24D%.5$E%4RP@
M24Y#3%5$24Y'+"!"550@3D]4("`@("!\"B\O('P@3$E-251%1"!43RP@5$A%
M($E-4$Q)140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)5%D@04Y$($9)
M5$Y%4U,@1D]2('P*+R\@?"!!(%!!4E1)0U5,05(@4%524$]312!!4D4@1$E3
M0TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%($-/4%E224=(5"`@?`HO
M+R!\($]73D52($]2($-/3E1224)55$]24R!"12!,24%"3$4@1D]2($%.62!$
M25)%0U0L($E.1$E214-4+"!)3D-)1$5.5$%,+"!\"B\O('P@4U!%0TE!3"P@
M15A%35!,05)9+"!/4B!#3TY315%514Y424%,($1!34%'15,@*$E.0TQ51$E.
M1RP@0E54($Y/5"`@("`@('P*+R\@?"!,24U)5$5$(%1/+"!04D]#55)%345.
M5"!/1B!354)35$E4551%($=/3T13($]2(%-%4E9)0T53.R!,3U-3($]&(%53
M12P@?`HO+R!\($1!5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3($E.5$52
M4E505$E/3BD@2$]7159%4B!#0553140@04Y$($].($%.62!\"B\O('P@5$A%
M3U)9($]&($Q)04))3$E462P@5TA%5$A%4B!)3B!#3TY44D%#5"P@4U1224-4
M($Q)04))3$E462P@3U(@5$]25"`@('P*+R\@?"`H24Y#3%5$24Y'($Y%1TQ)
M1T5.0T4@3U(@3U1(15)725-%*2!!4DE324Y'($E.($%.62!705D@3U54($]&
M(%1(12!54T4@?`HO+R!\($]&(%1(25,@4T]&5%=!4D4L($5614X@248@0416
M25-%1"!/1B!42$4@4$]34TE"24Q)5%D@3T8@4U5#2"!$04U!1T4N("!\"B\O
M('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<CH@4FEC:&%R9"!(97EE<R`\
M<FEC:&%R9$!P:'!G=7)U+F]R9SX@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED
M.B!297%U97-T+G!H<"QV(#$N-#,@,C`P-2\Q,2\P-B`Q.#HR.3HQ-"!A=F(@
M17AP("0*+R\*+R\@2%144%]297%U97-T($-L87-S"B\O"B\O(%-I;7!L92!E
M>&%M<&QE+"`H1F5T8VAE<R!Y86AO;RYC;VT@86YD(&1I<W!L87ES(&ET*3H*
M+R\*+R\@)&$@/2`F;F5W($A45%!?4F5Q=65S="@G:'1T<#HO+W=W=RYY86AO
M;RYC;VTO)RD["B\O("1A+3YS96YD4F5Q=65S="@I.PHO+R!E8VAO("1A+3YG
M971297-P;VYS94)O9'DH*3L*+R\*"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G
M.PIR97%U:7)E7V]N8V4@)TYE="]3;V-K970N<&AP)SL*<F5Q=6ER95]O;F-E
M("=.970O55),+G!H<"<["@ID969I;F4H)TA45%!?4D5154535%]-151(3T1?
M1T54)RP@("`@("='150G+"`@("`@=')U92D["F1E9FEN92@G2%144%]215%5
M15-47TU%5$A/1%](14%$)RP@("`@)TA%040G+"`@("!T<G5E*3L*9&5F:6YE
M*"=(5%107U)%455%4U1?34542$]$7U!/4U0G+"`@("`G4$]35"<L("`@('1R
M=64I.PID969I;F4H)TA45%!?4D5154535%]-151(3T1?4%54)RP@("`@("=0
M550G+"`@("`@=')U92D["F1E9FEN92@G2%144%]215%515-47TU%5$A/1%]$
M14Q%5$4G+"`@)T1%3$5412<L("!T<G5E*3L*9&5F:6YE*"=(5%107U)%455%
M4U1?34542$]$7T]05$E/3E,G+"`G3U!424].4R<L('1R=64I.PID969I;F4H
M)TA45%!?4D5154535%]-151(3T1?5%)!0T4G+"`@("=44D%#12<L("`@=')U
M92D["@ID969I;F4H)TA45%!?4D5154535%](5%107U9%4E\Q7S`G+"`G,2XP
M)RP@=')U92D["F1E9FEN92@G2%144%]215%515-47TA45%!?5D527S%?,2<L
M("<Q+C$G+"!T<G5E*3L*"F-L87-S($A45%!?4F5Q=65S="!["@H@("`@+RHJ
M"B`@("`J($EN<W1A;F-E(&]F($YE=%]54DP*("`@("H@0'9A<B!O8FIE8W0@
M3F5T7U523`H@("`@*B\*("`@('9A<B`D7W5R;#L*"B`@("`O*BH*("`@("H@
M5'EP92!O9B!R97%U97-T"B`@("`J($!V87(@<W1R:6YG"B`@("`J+PH@("`@
M=F%R("1?;65T:&]D.PH*("`@("\J*@H@("`@*B!(5%10(%9E<G-I;VX*("`@
M("H@0'9A<B!S=')I;F<*("`@("HO"B`@("!V87(@)%]H='1P.PH*("`@("\J
M*@H@("`@*B!297%U97-T(&AE861E<G,*("`@("H@0'9A<B!A<G)A>0H@("`@
M*B\*("`@('9A<B`D7W)E<75E<W1(96%D97)S.PH*("`@("\J*@H@("`@*B!"
M87-I8R!!=71H(%5S97)N86UE"B`@("`J($!V87(@<W1R:6YG"B`@("`J+PH@
M("`@=F%R("1?=7-E<CL*("`@(`H@("`@+RHJ"B`@("`J($)A<VEC($%U=&@@
M4&%S<W=O<F0*("`@("H@0'9A<B!S=')I;F<*("`@("HO"B`@("!V87(@)%]P
M87-S.PH*("`@("\J*@H@("`@*B!3;V-K970@;V)J96-T"B`@("`J($!V87(@
M;V)J96-T($YE=%]3;V-K970*("`@("HO"B`@("!V87(@)%]S;V-K.PH@("`@
M"B`@("`O*BH*("`@("H@4')O>'D@<V5R=F5R"B`@("`J($!V87(@<W1R:6YG
M"B`@("`J+PH@("`@=F%R("1?<')O>'E?:&]S=#L*("`@(`H@("`@+RHJ"B`@
M("`J(%!R;WAY('!O<G0*("`@("H@0'9A<B!I;G1E9V5R"B`@("`J+PH@("`@
M=F%R("1?<')O>'E?<&]R=#L*("`@(`H@("`@+RHJ"B`@("`J(%!R;WAY('5S
M97)N86UE"B`@("`J($!V87(@<W1R:6YG"B`@("`J+PH@("`@=F%R("1?<')O
M>'E?=7-E<CL*("`@(`H@("`@+RHJ"B`@("`J(%!R;WAY('!A<W-W;W)D"B`@
M("`J($!V87(@<W1R:6YG"B`@("`J+PH@("`@=F%R("1?<')O>'E?<&%S<SL*
M"B`@("`O*BH*("`@("H@4&]S="!D871A"B`@("`J($!V87(@87)R87D*("`@
M("HO"B`@("!V87(@)%]P;W-T1&%T83L*"B`@("\J*@H@("`@*B!297%U97-T
M(&)O9'D@(`H@("`@*B!`=F%R('-T<FEN9PH@("`@*B\*("`@('9A<B`D7V)O
M9'D["@H@("`O*BH*("`@("H@02!L:7-T(&]F(&UE=&AO9',@=&AA="!-55-4
M($Y/5"!H879E(&$@<F5Q=65S="!B;V1Y+"!P97(@4D9#(#(V,38*("`@("H@
M0'9A<B!A<G)A>0H@("`@*B\*("`@('9A<B`D7V)O9'E$:7-A;&QO=V5D(#T@
M87)R87DH)U1204-%)RD["@H@("`O*BH*("`@("H@1FEL97,@=&\@<&]S="`*
M("`@("H@0'9A<B!A<G)A>0H@("`@*B\*("`@('9A<B`D7W!O<W1&:6QE<R`]
M(&%R<F%Y*"D["@H@("`@+RHJ"B`@("`J($-O;FYE8W1I;VX@=&EM96]U="X*
M("`@("H@0'9A<B!F;&]A=`H@("`@*B\*("`@('9A<B`D7W1I;65O=70["B`@
M("`*("`@("\J*@H@("`@*B!(5%107U)E<W!O;G-E(&]B:F5C=`H@("`@*B!`
M=F%R(&]B:F5C="!(5%107U)E<W!O;G-E"B`@("`J+PH@("`@=F%R("1?<F5S
M<&]N<V4["B`@("`*("`@("\J*@H@("`@*B!7:&5T:&5R('1O(&%L;&]W(')E
M9&ER96-T<PH@("`@*B!`=F%R(&)O;VQE86X*("`@("HO"B`@("!V87(@)%]A
M;&QO=U)E9&ER96-T<SL*("`@(`H@("`@+RHJ"B`@("`J($UA>&EM=6T@<F5D
M:7)E8W1S(&%L;&]W960*("`@("H@0'9A<B!I;G1E9V5R"B`@("`J+PH@("`@
M=F%R("1?;6%X4F5D:7)E8W1S.PH@("`@"B`@("`O*BH*("`@("H@0W5R<F5N
M="!N=6UB97(@;V8@<F5D:7)E8W1S"B`@("`J($!V87(@:6YT96=E<@H@("`@
M*B\*("`@('9A<B`D7W)E9&ER96-T<SL*"B`@("\J*@H@("`@*B!7:&5T:&5R
M('1O(&%P<&5N9"!B<F%C:V5T<R!;72!T;R!A<G)A>2!V87)I86)L97,*("`@
M("H@0'9A<B!B;V]L"B`@("`J+PH@("`@=F%R("1?=7-E0G)A8VME=',@/2!T
M<G5E.PH*("`@+RHJ"B`@("`J($%T=&%C:&5D(&QI<W1E;F5R<PH@("`@*B!`
M=F%R(&%R<F%Y"B`@("`J+PH@("`@=F%R("1?;&ES=&5N97)S(#T@87)R87DH
M*3L*"B`@("\J*@H@("`@*B!7:&5T:&5R('1O('-A=F4@<F5S<&]N<V4@8F]D
M>2!I;B!R97-P;VYS92!O8FIE8W0@<')O<&5R='D@(`H@("`@*B!`=F%R(&)O
M;VP*("`@("HO"B`@("!V87(@)%]S879E0F]D>2`]('1R=64["@H@("`O*BH*
M("`@("H@5&EM96]U="!F;W(@<F5A9&EN9R!F<F]M('-O8VME="`H87)R87DH
M<V5C;VYD<RP@;6EC<F]S96-O;F1S*2D*("`@("H@0'9A<B!A<G)A>0H@("`@
M*B\*("`@('9A<B`D7W)E8614:6UE;W5T(#T@;G5L;#L*"B`@("\J*@H@("`@
M*B!/<'1I;VYS('1O('!A<W,@=&\@3F5T7U-O8VME=#HZ8V]N;F5C="X@4V5E
M('-T<F5A;5]C;VYT97AT7V-R96%T90H@("`@*B!`=F%R(&%R<F%Y"B`@("`J
M+PH@("`@=F%R("1?<V]C:V5T3W!T:6]N<R`](&YU;&P["@H@("`@+RHJ"B`@
M("`J($-O;G-T<G5C=&]R"B`@("`J"B`@("`J(%-E=',@=7`@=&AE(&]B:F5C
M=`H@("`@*B!`<&%R86T@("`@<W1R:6YG("!4:&4@=7)L('1O(&9E=&-H+V%C
M8V5S<PH@("`@*B!`<&%R86T@("`@87)R87D@("!!<W-O8VEA=&EV92!A<G)A
M>2!O9B!P87)A;65T97)S('=H:6-H(&-A;B!H879E('1H92!F;VQL;W=I;F<@
M:V5Y<SH*("`@("H@/'5L/@H@("`@*B`@(#QL:3YM971H;V0@("`@("`@("`M
M($UE=&AO9"!T;R!U<V4L($=%5"P@4$]35"!E=&,@*'-T<FEN9RD\+VQI/@H@
M("`@*B`@(#QL:3YH='1P("`@("`@("`@("`M($A45%`@5F5R<VEO;B!T;R!U
M<V4L(#$N,"!O<B`Q+C$@*'-T<FEN9RD\+VQI/@H@("`@*B`@(#QL:3YU<V5R
M("`@("`@("`@("`M($)A<VEC($%U=&@@=7-E<FYA;64@*'-T<FEN9RD\+VQI
M/@H@("`@*B`@(#QL:3YP87-S("`@("`@("`@("`M($)A<VEC($%U=&@@<&%S
M<W=O<F0@*'-T<FEN9RD\+VQI/@H@("`@*B`@(#QL:3YP<F]X>5]H;W-T("`@
M("`M(%!R;WAY('-E<G9E<B!H;W-T("AS=')I;F<I/"]L:3X*("`@("H@("`\
M;&D^<')O>'E?<&]R="`@("`@+2!0<F]X>2!S97)V97(@<&]R="`H:6YT96=E
M<BD\+VQI/@H@("`@*B`@(#QL:3YP<F]X>5]U<V5R("`@("`M(%!R;WAY(&%U
M=&@@=7-E<FYA;64@*'-T<FEN9RD\+VQI/@H@("`@*B`@(#QL:3YP<F]X>5]P
M87-S("`@("`M(%!R;WAY(&%U=&@@<&%S<W=O<F0@*'-T<FEN9RD\+VQI/@H@
M("`@*B`@(#QL:3YT:6UE;W5T("`@("`@("`M($-O;FYE8W1I;VX@=&EM96]U
M="!I;B!S96-O;F1S("AF;&]A="D\+VQI/@H@("`@*B`@(#QL:3YA;&QO=U)E
M9&ER96-T<R`M(%=H971H97(@=&\@9F]L;&]W(')E9&ER96-T<R!O<B!N;W0@
M*&)O;VPI/"]L:3X*("`@("H@("`\;&D^;6%X4F5D:7)E8W1S("`@+2!-87@@
M;G5M8F5R(&]F(')E9&ER96-T<R!T;R!F;VQL;W<@*&EN=&5G97(I/"]L:3X*
M("`@("H@("`\;&D^=7-E0G)A8VME=',@("`@+2!7:&5T:&5R('1O(&%P<&5N
M9"!;72!T;R!A<G)A>2!V87)I86)L92!N86UE<R`H8F]O;"D\+VQI/@H@("`@
M*B`@(#QL:3YS879E0F]D>2`@("`@("`M(%=H971H97(@=&\@<V%V92!R97-P
M;VYS92!B;V1Y(&EN(')E<W!O;G-E(&]B:F5C="!P<F]P97)T>2`H8F]O;"D\
M+VQI/@H@("`@*B`@(#QL:3YR96%D5&EM96]U="`@("`M(%1I;65O=70@9F]R
M(')E861I;F<@+R!W<FET:6YG(&1A=&$@;W9E<B!T:&4@<V]C:V5T("AA<G)A
M>2`H<V5C;VYD<RP@;6EC<F]S96-O;F1S*2D\+VQI/@H@("`@*B`@(#QL:3YS
M;V-K971/<'1I;VYS("`M($]P=&EO;G,@=&\@<&%S<R!T;R!.971?4V]C:V5T
M(&]B:F5C="`H87)R87DI/"]L:3X*("`@("H@/"]U;#X*("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!(5%107U)E<75E<W0H)'5R
M;"`]("<G+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI
M<RT^7W-O8VL@("`@("`@("`@(#T@)FYE=R!.971?4V]C:V5T*"D["B`@("`@
M("`@)'1H:7,M/E]M971H;V0@("`@("`@("`]("!(5%107U)%455%4U1?3454
M2$]$7T=%5#L*("`@("`@("`D=&AI<RT^7VAT='`@("`@("`@("`@(#T@($A4
M5%!?4D5154535%](5%107U9%4E\Q7S$["B`@("`@("`@)'1H:7,M/E]R97%U
M97-T2&5A9&5R<R`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/E]P;W-T1&%T
M82`@("`@("`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/E]B;V1Y("`@("`@
M("`@("`](&YU;&P["@H@("`@("`@("1T:&ES+3Y?=7-E<B`](&YU;&P["B`@
M("`@("`@)'1H:7,M/E]P87-S(#T@;G5L;#L*"B`@("`@("`@)'1H:7,M/E]P
M<F]X>5]H;W-T(#T@;G5L;#L*("`@("`@("`D=&AI<RT^7W!R;WAY7W!O<G0@
M/2!N=6QL.PH@("`@("`@("1T:&ES+3Y?<')O>'E?=7-E<B`](&YU;&P["B`@
M("`@("`@)'1H:7,M/E]P<F]X>5]P87-S(#T@;G5L;#L*"B`@("`@("`@)'1H
M:7,M/E]A;&QO=U)E9&ER96-T<R`](&9A;'-E.PH@("`@("`@("1T:&ES+3Y?
M;6%X4F5D:7)E8W1S("`@/2`S.PH@("`@("`@("1T:&ES+3Y?<F5D:7)E8W1S
M("`@("`@/2`P.PH*("`@("`@("`D=&AI<RT^7W1I;65O=70@(#T@;G5L;#L*
M("`@("`@("`D=&AI<RT^7W)E<W!O;G-E(#T@;G5L;#L*"B`@("`@("`@9F]R
M96%C:"`H)'!A<F%M<R!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@
M("`D=&AI<RT^>R=?)R`N("1K97E](#T@)'9A;'5E.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"%E;7!T>2@D=7)L*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M<V5T55),*"1U<FPI.PH@("`@("`@('T*"B`@("`@("`@+R\@1&5F875L="!U
M<V5R86=E;G0*("`@("`@("`D=&AI<RT^861D2&5A9&5R*"=5<V5R+4%G96YT
M)RP@)U!%05(@2%144%]297%U97-T(&-L87-S("@@:'1T<#HO+W!E87(N<&AP
M+FYE="\@*2<I.PH*("`@("`@("`O+R!-86ME('-U<F4@:V5E<&%L:79E<R!D
M;VYT(&MN;V)B;&4@=7,*("`@("`@("`D=&AI<RT^861D2&5A9&5R*"=#;VYN
M96-T:6]N)RP@)V-L;W-E)RD["@H@("`@("`@("\O($)A<VEC(&%U=&AE;G1I
M8V%T:6]N"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W5S97(I*2!["B`@
M("`@("`@("`@("1T:&ES+3YA9&1(96%D97(H)T%U=&AO<FEZ871I;VXG+"`G
M0F%S:6,@)R`N(&)A<V4V-%]E;F-O9&4H)'1H:7,M/E]U<V5R("X@)SHG("X@
M)'1H:7,M/E]P87-S*2D["B`@("`@("`@?0H*("`@("`@("`O+R!5<V4@9WII
M<"!E;F-O9&EN9R!I9B!P;W-S:6)L90H@("`@("`@("\O($%V;VED(&=Z:7`@
M96YC;V1I;F<@:68@=7-I;F<@;75L=&EB>71E(&9U;F-T:6]N<R`H<V5E(",Q
M-S@Q*0H@("`@("`@(&EF("A(5%107U)%455%4U1?2%144%]615)?,5\Q(#T]
M("1T:&ES+3Y?:'1T<"`F)B!E>'1E;G-I;VY?;&]A9&5D*"=Z;&EB)RD@)B8*
M("`@("`@("`@("`@,"`]/2`H,B`F(&EN:5]G970H)VUB<W1R:6YG+F9U;F-?
M;W9E<FQO860G*2DI('L*"B`@("`@("`@("`@("1T:&ES+3YA9&1(96%D97(H
M)T%C8V5P="U%;F-O9&EN9R<L("=G>FEP)RD["B`@("`@("`@?0H@("`@?0H@
M("`@"B`@("`O*BH*("`@("H@1V5N97)A=&5S(&$@2&]S="!H96%D97(@9F]R
M($A45%`O,2XQ(')E<75E<W1S"B`@("`J"B`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@*B!`<F5T=7)N('-T<FEN9PH@("`@*B\*("`@(&9U;F-T:6]N(%]G
M96YE<F%T94AO<W1(96%D97(H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^
M7W5R;"T^<&]R="`A/2`X,"!!3D0@<W1R8V%S96-M<"@D=&AI<RT^7W5R;"T^
M<')O=&]C;VPL("=H='1P)RD@/3T@,"D@>PH@("`@("`@("`@("`D:&]S="`]
M("1T:&ES+3Y?=7)L+3YH;W-T("X@)SHG("X@)'1H:7,M/E]U<FPM/G!O<G0[
M"@H@("`@("`@('T@96QS96EF("@D=&AI<RT^7W5R;"T^<&]R="`A/2`T-#,@
M04Y$('-T<F-A<V5C;7`H)'1H:7,M/E]U<FPM/G!R;W1O8V]L+"`G:'1T<',G
M*2`]/2`P*2!["B`@("`@("`@("`@("1H;W-T(#T@)'1H:7,M/E]U<FPM/FAO
M<W0@+B`G.B<@+B`D=&AI<RT^7W5R;"T^<&]R=#L*"B`@("`@("`@?2!E;'-E
M:68@*"1T:&ES+3Y?=7)L+3YP;W)T(#T](#0T,R!!3D0@<W1R8V%S96-M<"@D
M=&AI<RT^7W5R;"T^<')O=&]C;VPL("=H='1P<R<I(#T](#`@04Y$('-T<G!O
M<R@D=&AI<RT^7W5R;"T^=7)L+"`G.C0T,R<I("$]/2!F86QS92D@>PH@("`@
M("`@("`@("`D:&]S="`]("1T:&ES+3Y?=7)L+3YH;W-T("X@)SHG("X@)'1H
M:7,M/E]U<FPM/G!O<G0["B`@("`@("`@"B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&AO<W0@/2`D=&AI<RT^7W5R;"T^:&]S=#L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D:&]S=#L*("`@('T*("`@(`H@("`@+RHJ"B`@
M("`J(%)E<V5T<R!T:&4@;V)J96-T('1O(&ET<R!I;FET:6%L('-T871E("A$
M15!214-!5$5$*2X*("`@("H@5&%K97,@=&AE('-A;64@<&%R86UE=&5R<R!A
M<R!T:&4@8V]N<W1R=6-T;W(N"B`@("`J"B`@("`J($!P87)A;2`@<W1R:6YG
M("1U<FP@("`@5&AE('5R;"!T;R!B92!R97%U97-T960*("`@("H@0'!A<F%M
M("!A<G)A>2`@)'!A<F%M<R!!<W-O8VEA=&EV92!A<G)A>2!O9B!P87)A;65T
M97)S"B`@("`J("`@("`@("`@("`@("`@("`@("`@("`@*'-E92!C;VYS=')U
M8W1O<B!F;W(@9&5T86EL<RD*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H@
M0&1E<')E8V%T960@9&5P<F5C871E9"!S:6YC92`Q+C(L(&-A;&P@=&AE(&-O
M;G-T<G5C=&]R(&EF('1H:7,@:7,@;F5C97-S87)Y"B`@("`J+PH@("`@9G5N
M8W1I;VX@<F5S970H)'5R;"P@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@
M("`@("`@)'1H:7,M/DA45%!?4F5Q=65S="@D=7)L+"`D<&%R86US*3L*("`@
M('T*"B`@("`O*BH*("`@("H@4V5T<R!T:&4@55),('1O(&)E(')E<75E<W1E
M9`H@("`@*@H@("`@*B!`<&%R86T@('-T<FEN9R!4:&4@=7)L('1O(&)E(')E
M<75E<W1E9`H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B\*("`@(&9U;F-T
M:6]N('-E=%523"@D=7)L*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=7)L(#T@
M)FYE=R!.971?55),*"1U<FPL("1T:&ES+3Y?=7-E0G)A8VME=',I.PH*("`@
M("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?=7)L+3YU<V5R*2!\?"`A96UP='DH
M)'1H:7,M/E]U<FPM/G!A<W,I*2!["B`@("`@("`@("`@("1T:&ES+3YS971"
M87-I8T%U=&@H)'1H:7,M/E]U<FPM/G5S97(L("1T:&ES+3Y?=7)L+3YP87-S
M*3L*("`@("`@("!]"@H@("`@("`@(&EF("A(5%107U)%455%4U1?2%144%]6
M15)?,5\Q(#T]("1T:&ES+3Y?:'1T<"D@>PH@("`@("`@("`@("`D=&AI<RT^
M861D2&5A9&5R*"=(;W-T)RP@)'1H:7,M/E]G96YE<F%T94AO<W1(96%D97(H
M*2D["B`@("`@("`@?0H@("`@?0H@("`@"B`@("`O*BH*("`@("H@4V5T<R!A
M('!R;WAY('1O(&)E('5S960*("`@("H*("`@("H@0'!A<F%M('-T<FEN9R`@
M("`@4')O>'D@:&]S=`H@("`@*B!`<&%R86T@:6YT("`@("`@("!0<F]X>2!P
M;W)T"B`@("`J($!P87)A;2!S=')I;F<@("`@(%!R;WAY('5S97)N86UE"B`@
M("`J($!P87)A;2!S=')I;F<@("`@(%!R;WAY('!A<W-W;W)D"B`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`J+PH@("`@9G5N8W1I;VX@<V5T4')O>'DH)&AO
M<W0L("1P;W)T(#T@.#`X,"P@)'5S97(@/2!N=6QL+"`D<&%S<R`](&YU;&PI
M"B`@("!["B`@("`@("`@)'1H:7,M/E]P<F]X>5]H;W-T(#T@)&AO<W0["B`@
M("`@("`@)'1H:7,M/E]P<F]X>5]P;W)T(#T@)'!O<G0["B`@("`@("`@)'1H
M:7,M/E]P<F]X>5]U<V5R(#T@)'5S97(["B`@("`@("`@)'1H:7,M/E]P<F]X
M>5]P87-S(#T@)'!A<W,["@H@("`@("`@(&EF("@A96UP='DH)'5S97(I*2![
M"B`@("`@("`@("`@("1T:&ES+3YA9&1(96%D97(H)U!R;WAY+4%U=&AO<FEZ
M871I;VXG+"`G0F%S:6,@)R`N(&)A<V4V-%]E;F-O9&4H)'5S97(@+B`G.B<@
M+B`D<&%S<RDI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("H@4V5T
M<R!B87-I8R!A=71H96YT:6-A=&EO;B!P87)A;65T97)S"B`@("`J"B`@("`J
M($!P87)A;2!S=')I;F<@("`@(%5S97)N86UE"B`@("`J($!P87)A;2!S=')I
M;F<@("`@(%!A<W-W;W)D"B`@("`J+PH@("`@9G5N8W1I;VX@<V5T0F%S:6-!
M=71H*"1U<V5R+"`D<&%S<RD*("`@('L*("`@("`@("`D=&AI<RT^7W5S97(@
M/2`D=7-E<CL*("`@("`@("`D=&AI<RT^7W!A<W,@/2`D<&%S<SL*"B`@("`@
M("`@)'1H:7,M/F%D9$AE861E<B@G075T:&]R:7IA=&EO;B<L("="87-I8R`G
M("X@8F%S938T7V5N8V]D92@D=7-E<B`N("<Z)R`N("1P87-S*2D["B`@("!]
M"@H@("`@+RHJ"B`@("`J(%-E=',@=&AE(&UE=&AO9"!T;R!B92!U<V5D+"!'
M150L(%!/4U0@971C+@H@("`@*@H@("`@*B!`<&%R86T@<W1R:6YG("`@("!-
M971H;V0@=&\@=7-E+B!5<V4@=&AE(&1E9FEN960@8V]N<W1A;G1S(&9O<B!T
M:&ES"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J+PH@("`@9G5N8W1I;VX@
M<V5T365T:&]D*"1M971H;V0I"B`@("!["B`@("`@("`@)'1H:7,M/E]M971H
M;V0@/2`D;65T:&]D.PH@("`@?0H*("`@("\J*@H@("`@*B!3971S('1H92!(
M5%10('9E<G-I;VX@=&\@=7-E+"`Q+C`@;W(@,2XQ"B`@("`J"B`@("`J($!P
M87)A;2!S=')I;F<@("`@(%9E<G-I;VX@=&\@=7-E+B!5<V4@=&AE(&1E9FEN
M960@8V]N<W1A;G1S(&9O<B!T:&ES"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`J+PH@("`@9G5N8W1I;VX@<V5T2'1T<%9E<B@D:'1T<"D*("`@('L*("`@
M("`@("`D=&AI<RT^7VAT='`@/2`D:'1T<#L*("`@('T*"B`@("`O*BH*("`@
M("H@061D<R!A(')E<75E<W0@:&5A9&5R"B`@("`J"B`@("`J($!P87)A;2!S
M=')I;F<@("`@($AE861E<B!N86UE"B`@("`J($!P87)A;2!S=')I;F<@("`@
M($AE861E<B!V86QU90H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B\*("`@
M(&9U;F-T:6]N(&%D9$AE861E<B@D;F%M92P@)'9A;'5E*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?<F5Q=65S=$AE861E<G-;<W1R=&]L;W=E<B@D;F%M92E=
M(#T@)'9A;'5E.PH@("`@?0H*("`@("\J*@H@("`@*B!296UO=F5S(&$@<F5Q
M=65S="!H96%D97(*("`@("H*("`@("H@0'!A<F%M('-T<FEN9R`@("`@2&5A
M9&5R(&YA;64@=&\@<F5M;W9E"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J
M+PH@("`@9G5N8W1I;VX@<F5M;W9E2&5A9&5R*"1N86UE*0H@("`@>PH@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7W)E<75E<W1(96%D97)S6W-T<G1O;&]W
M97(H)&YA;64I72DI('L*("`@("`@("`@("`@=6YS970H)'1H:7,M/E]R97%U
M97-T2&5A9&5R<UMS=')T;VQO=V5R*"1N86UE*5TI.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("H@061D<R!A('%U97)Y<W1R:6YG('!A<F%M971E
M<@H@("`@*@H@("`@*B!`<&%R86T@<W1R:6YG("`@("!1=65R>7-T<FEN9R!P
M87)A;65T97(@;F%M90H@("`@*B!`<&%R86T@<W1R:6YG("`@("!1=65R>7-T
M<FEN9R!P87)A;65T97(@=F%L=64*("`@("H@0'!A<F%M(&)O;VP@("`@("`@
M5VAE=&AE<B!T:&4@=F%L=64@:7,@86QR96%D>2!U<FQE;F-O9&5D(&]R(&YO
M="P@9&5F875L="`](&YO=`H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B\*
M("`@(&9U;F-T:6]N(&%D9%%U97)Y4W1R:6YG*"1N86UE+"`D=F%L=64L("1P
M<F5E;F-O9&5D(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1H:7,M/E]U<FPM
M/F%D9%%U97)Y4W1R:6YG*"1N86UE+"`D=F%L=64L("1P<F5E;F-O9&5D*3L*
M("`@('T@("`@"B`@("`*("`@("\J*@H@("`@*B!3971S('1H92!Q=65R>7-T
M<FEN9R!T;R!L:71E<F%L;'D@=VAA="!Y;W4@<W5P<&QY"B`@("`J"B`@("`J
M($!P87)A;2!S=')I;F<@("`@(%1H92!Q=65R>7-T<FEN9R!D871A+B!3:&]U
M;&0@8F4@;V8@=&AE(&9O<FUA="!F;V\]8F%R)G@]>2!E=&,*("`@("H@0'!A
M<F%M(&)O;VP@("`@("`@5VAE=&AE<B!D871A(&ES(&%L<F5A9'D@=7)L96YC
M;V1E9"!O<B!N;W0L(&1E9F%U;'0@/2!A;')E861Y(&5N8V]D960*("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!A9&1287=1=65R
M>5-T<FEN9R@D<75E<GES=')I;F<L("1P<F5E;F-O9&5D(#T@=')U92D*("`@
M('L*("`@("`@("`D=&AI<RT^7W5R;"T^861D4F%W475E<GE3=')I;F<H)'%U
M97)Y<W1R:6YG+"`D<')E96YC;V1E9"D["B`@("!]"@H@("`@+RHJ"B`@("`J
M($%D9',@<&]S=&1A=&$@:71E;7,*("`@("H*("`@("H@0'!A<F%M('-T<FEN
M9R`@("`@4&]S="!D871A(&YA;64*("`@("H@0'!A<F%M('-T<FEN9R`@("`@
M4&]S="!D871A('9A;'5E"B`@("`J($!P87)A;2!B;V]L("`@("`@(%=H971H
M97(@9&%T82!I<R!A;')E861Y('5R;&5N8V]D960@;W(@;F]T+"!D969A=6QT
M(#T@;F]T"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J+PH@("`@9G5N8W1I
M;VX@861D4&]S=$1A=&$H)&YA;64L("1V86QU92P@)'!R965N8V]D960@/2!F
M86QS92D*("`@('L*("`@("`@("!I9B`H)'!R965N8V]D960I('L*("`@("`@
M("`@("`@)'1H:7,M/E]P;W-T1&%T85LD;F%M95T@/2`D=F%L=64["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]P;W-T1&%T85LD;F%M
M95T@/2`D=&AI<RT^7V%R<F%Y36%P4F5C=7)S:79E*"=U<FQE;F-O9&4G+"`D
M=F%L=64I.PH@("`@("`@('T*("`@('T*"B`@("\J*@H@("`@*B!296-U<G-I
M=F5L>2!A<'!L:65S('1H92!C86QL8F%C:R!F=6YC=&EO;B!T;R!T:&4@=F%L
M=64*("`@("H@"B`@("`J($!P87)A;2`@("!M:7AE9"`@($-A;&QB86-K(&9U
M;F-T:6]N"B`@("`J($!P87)A;2`@("!M:7AE9"`@(%9A;'5E('1O('!R;V-E
M<W,*("`@("H@0&%C8V5S<R`@('!R:79A=&4*("`@("H@0')E='5R;B`@(&UI
M>&5D("`@4')O8V5S<V5D('9A;'5E"B`@("`J+PH@("`@9G5N8W1I;VX@7V%R
M<F%Y36%P4F5C=7)S:79E*"1C86QL8F%C:RP@)'9A;'5E*0H@("`@>PH@("`@
M("`@(&EF("@A:7-?87)R87DH)'9A;'5E*2D@>PH@("`@("`@("`@("!R971U
M<FX@8V%L;%]U<V5R7V9U;F,H)&-A;&QB86-K+"`D=F%L=64I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1M87`@/2!A<G)A>2@I.PH@("`@("`@
M("`@("!F;W)E86-H("@D=F%L=64@87,@)&L@/3X@)'8I('L*("`@("`@("`@
M("`@("`@("1M87!;)&M=(#T@)'1H:7,M/E]A<G)A>4UA<%)E8W5R<VEV92@D
M8V%L;&)A8VLL("1V*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U
M<FX@)&UA<#L*("`@("`@("!]"B`@("!]"@H@("`O*BH*("`@("H@061D<R!A
M(&9I;&4@=&\@=7!L;V%D"B`@("`J(`H@("`@*B!4:&ES(&%L<V\@8VAA;F=E
M<R!C;VYT96YT+71Y<&4@=&\@)VUU;'1I<&%R="]F;W)M+61A=&$G(&9O<B!P
M<F]P97(@=7!L;V%D"B`@("`J(`H@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M*B!`<&%R86T@('-T<FEN9R`@("!N86UE(&]F(&9I;&4M=7!L;V%D(&9I96QD
M"B`@("`J($!P87)A;2`@;6EX960@("`@(&9I;&4@;F%M92AS*0H@("`@*B!`
M<&%R86T@(&UI>&5D("`@("!C;VYT96YT+71Y<&4H<RD@;V8@9FEL92AS*2!B
M96EN9R!U<&QO861E9`H@("`@*B!`<F5T=7)N(&)O;VP@("`@("!T<G5E(&]N
M('-U8V-E<W,*("`@("H@0'1H<F]W<R!014%27T5R<F]R"B`@("`J+PH@("`@
M9G5N8W1I;VX@861D1FEL92@D:6YP=71.86UE+"`D9FEL94YA;64L("1C;VYT
M96YT5'EP92`]("=A<'!L:6-A=&EO;B]O8W1E="US=')E86TG*0H@("`@>PH@
M("`@("`@(&EF("@A:7-?87)R87DH)&9I;&5.86UE*2`F)B`A:7-?<F5A9&%B
M;&4H)&9I;&5.86UE*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@B1FEL92`G>R1F:6QE3F%M97TG(&ES(&YO="!R96%D86)L92(I
M.PH@("`@("`@('T@96QS96EF("AI<U]A<G)A>2@D9FEL94YA;64I*2!["B`@
M("`@("`@("`@(&9O<F5A8V@@*"1F:6QE3F%M92!A<R`D;F%M92D@>PH@("`@
M("`@("`@("`@("`@:68@*"%I<U]R96%D86)L92@D;F%M92DI('L*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B1FEL92`G
M>R1N86UE?2<@:7,@;F]T(')E861A8FQE(BD["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@)'1H:7,M/F%D9$AE
M861E<B@G0V]N=&5N="U4>7!E)RP@)VUU;'1I<&%R="]F;W)M+61A=&$G*3L*
M("`@("`@("`D=&AI<RT^7W!O<W1&:6QE<ULD:6YP=71.86UE72`](&%R<F%Y
M*`H@("`@("`@("`@("`G;F%M92<@/3X@)&9I;&5.86UE+`H@("`@("`@("`@
M("`G='EP92<@/3X@)&-O;G1E;G14>7!E"B`@("`@("`@*3L*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("H@061D<R!R87<@<&]S
M=&1A=&$@*$1%4%)%0T%4140I"B`@("`J"B`@("`J($!P87)A;2!S=')I;F<@
M("`@(%1H92!D871A"B`@("`J($!P87)A;2!B;V]L("`@("`@(%=H971H97(@
M9&%T82!I<R!P<F5E;F-O9&5D(&]R(&YO="P@9&5F875L="`](&%L<F5A9'D@
M96YC;V1E9`H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B!`9&5P<F5C871E
M9"`@("`@("!D97!R96-A=&5D('-I;F-E(#$N,RXP+"!M971H;V0@861D0F]D
M>2@I('-H;W5L9"!B92!U<V5D(&EN<W1E860*("`@("HO"B`@("!F=6YC=&EO
M;B!A9&1287=0;W-T1&%T82@D<&]S=&1A=&$L("1P<F5E;F-O9&5D(#T@=')U
M92D*("`@('L*("`@("`@("`D=&AI<RT^7V)O9'D@/2`D<')E96YC;V1E9"`_
M("1P;W-T9&%T82`Z('5R;&5N8V]D92@D<&]S=&1A=&$I.PH@("`@?0H*("`@
M+RHJ"B`@("`J(%-E=',@=&AE(')E<75E<W0@8F]D>2`H9F]R(%!/4U0L(%!5
M5"!A;F0@<VEM:6QA<B!R97%U97-T<RD*("`@("H*("`@("H@0'!A<F%M("`@
M('-T<FEN9R`@4F5Q=65S="!B;V1Y"B`@("`J($!A8V-E<W,@("!P=6)L:6,*
M("`@("HO"B`@("!F=6YC=&EO;B!S971";V1Y*"1B;V1Y*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?8F]D>2`]("1B;V1Y.PH@("`@?0H*("`@("\J*@H@("`@
M*B!#;&5A<G,@86YY('!O<W1D871A('1H870@:&%S(&)E96X@861D960@*$1%
M4%)%0T%4140I+B`*("`@("H@"B`@("`J(%5S969U;"!F;W(@;75L=&EP;&4@
M<F5Q=65S="!S8V5N87)I;W,N"B`@("`J"B`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`J($!D97!R96-A=&5D(&1E<')E8V%T960@<VEN8V4@,2XR"B`@("`J
M+PH@("`@9G5N8W1I;VX@8VQE87)0;W-T1&%T82@I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]P;W-T1&%T82`](&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`J
M($%P<&5N9',@82!C;V]K:64@=&\@(D-O;VMI93HB(&AE861E<@H@("`@*B`*
M("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92!C;V]K:64@;F%M90H@("`@*B!`
M<&%R86T@<W1R:6YG("1V86QU92!C;V]K:64@=F%L=64*("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!A9&1#;V]K:64H)&YA;64L
M("1V86QU92D*("`@('L*("`@("`@("`D8V]O:VEE<R`](&ES<V5T*"1T:&ES
M+3Y?<F5Q=65S=$AE861E<G-;)V-O;VMI92==*2`_("1T:&ES+3Y?<F5Q=65S
M=$AE861E<G-;)V-O;VMI92==+B`G.R`G(#H@)R<["B`@("`@("`@)'1H:7,M
M/F%D9$AE861E<B@G0V]O:VEE)RP@)&-O;VMI97,@+B`D;F%M92`N("<])R`N
M("1V86QU92D["B`@("!]"B`@("`*("`@("\J*@H@("`@*B!#;&5A<G,@86YY
M(&-O;VMI97,@=&AA="!H879E(&)E96X@861D960@*$1%4%)%0T%4140I+B`*
M("`@("H@"B`@("`J(%5S969U;"!F;W(@;75L=&EP;&4@<F5Q=65S="!S8V5N
M87)I;W,*("`@("H*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H@0&1E<')E
M8V%T960@9&5P<F5C871E9"!S:6YC92`Q+C(*("`@("HO"B`@("!F=6YC=&EO
M;B!C;&5A<D-O;VMI97,H*0H@("`@>PH@("`@("`@("1T:&ES+3YR96UO=F5(
M96%D97(H)T-O;VMI92<I.PH@("`@?0H*("`@("\J*@H@("`@*B!396YD<R!T
M:&4@<F5Q=65S=`H@("`@*@H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B!`
M<&%R86T@(&)O;VP@("!7:&5T:&5R('1O('-T;W)E(')E<W!O;G-E(&)O9'D@
M:6X@4F5S<&]N<V4@;V)J96-T('!R;W!E<G1Y+`H@("`@*B`@("`@("`@("`@
M("`@("!S970@=&AI<R!T;R!F86QS92!I9B!D;W=N;&]A9&EN9R!A($Q!4D=%
M(&9I;&4@86YD('5S:6YG(&$@3&ES=&5N97(*("`@("H@0')E='5R;B!M:7AE
M9"`@4$5!4B!E<G)O<B!O;B!E<G)O<BP@=')U92!O=&AE<G=I<V4*("`@("HO
M"B`@("!F=6YC=&EO;B!S96YD4F5Q=65S="@D<V%V94)O9'D@/2!T<G5E*0H@
M("`@>PH@("`@("`@(&EF("@A:7-?82@D=&AI<RT^7W5R;"P@)TYE=%]54DPG
M*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G3F\@
M55),(&=I=F5N+B<I.PH@("`@("`@('T*"B`@("`@("`@)&AO<W0@/2!I<W-E
M="@D=&AI<RT^7W!R;WAY7VAO<W0I(#\@)'1H:7,M/E]P<F]X>5]H;W-T(#H@
M)'1H:7,M/E]U<FPM/FAO<W0["B`@("`@("`@)'!O<G0@/2!I<W-E="@D=&AI
M<RT^7W!R;WAY7W!O<G0I(#\@)'1H:7,M/E]P<F]X>5]P;W)T(#H@)'1H:7,M
M/E]U<FPM/G!O<G0["@H@("`@("`@("\O(#0N,RXP('-U<'!O<G1S(%-33"!C
M;VYN96-T:6]N<R!U<VEN9R!/<&5N4U-,+B!4:&4@9G5N8W1I;VX@=&5S="!D
M971E<FUI;F5S"B`@("`@("`@+R\@=V4@<G5N;FEN9R!O;B!A="!L96%S="`T
M+C,N,`H@("`@("`@(&EF("AS=')C87-E8VUP*"1T:&ES+3Y?=7)L+3YP<F]T
M;V-O;"P@)VAT='!S)RD@/3T@,"!!3D0@9G5N8W1I;VY?97AI<W1S*"=F:6QE
M7V=E=%]C;VYT96YT<R<I($%.1"!E>'1E;G-I;VY?;&]A9&5D*"=O<&5N<W-L
M)RDI('L*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<')O>'E?:&]S
M="DI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"=(5%104R!P<F]X:65S(&%R92!N;W0@<W5P<&]R=&5D+B<I.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1H;W-T(#T@)W-S;#HO+R<@+B`D:&]S=#L*
M("`@("`@("!]"@H@("`@("`@("\O(&UA9VEC('%U;W1E<R!M87D@9G5C:R!U
M<"!F:6QE('5P;&]A9',@86YD(&-H=6YK960@<F5S<&]N<V4@<')O8V5S<VEN
M9PH@("`@("`@("1M86=I8U%U;W1E<R`](&EN:5]G970H)VUA9VEC7W%U;W1E
M<U]R=6YT:6UE)RD["B`@("`@("`@:6YI7W-E="@G;6%G:6-?<75O=&5S7W)U
M;G1I;64G+"!F86QS92D["@H@("`@("`@("\O($EF('1H:7,@:7,@82!S96-O
M;F0@<F5Q=65S="P@=V4@;6%Y(&=E="!A=V%Y('=I=&AO=70*("`@("`@("`O
M+R!R92UC;VYN96-T:6YG(&EF('1H97DG<F4@;VX@=&AE('-A;64@<V5R=F5R
M"B`@("`@("`@)&5R<B`]("1T:&ES+3Y?<V]C:RT^8V]N;F5C="@D:&]S="P@
M)'!O<G0L(&YU;&PL("1T:&ES+3Y?=&EM96]U="P@)'1H:7,M/E]S;V-K971/
M<'1I;VYS*3L*("`@("`@("!014%2.CII<T5R<F]R*"1E<G(I(&]R("1E<G(@
M/2`D=&AI<RT^7W-O8VLM/G=R:71E*"1T:&ES+3Y?8G5I;&1297%U97-T*"DI
M.PH*("`@("`@("!I9B`H(5!%05(Z.FES17)R;W(H)&5R<BDI('L*("`@("`@
M("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W)E8614:6UE;W5T*2D@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]S;V-K+3YS9714:6UE;W5T*"1T:&ES+3Y?
M<F5A9%1I;65O=71;,%TL("1T:&ES+3Y?<F5A9%1I;65O=71;,5TI.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^7VYO=&EF>2@G<V5N=%)E
M<75E<W0G*3L*"B`@("`@("`@("`@("\O(%)E860@=&AE(')E<W!O;G-E"B`@
M("`@("`@("`@("1T:&ES+3Y?<F5S<&]N<V4@/2`F;F5W($A45%!?4F5S<&]N
M<V4H)'1H:7,M/E]S;V-K+"`D=&AI<RT^7VQI<W1E;F5R<RD["B`@("`@("`@
M("`@("1E<G(@/2`D=&AI<RT^7W)E<W!O;G-E+3YP<F]C97-S*"1T:&ES+3Y?
M<V%V94)O9'D@)B8@)'-A=F5";V1Y*3L*("`@("`@("!]"@H@("`@("`@(&EN
M:5]S970H)VUA9VEC7W%U;W1E<U]R=6YT:6UE)RP@)&UA9VEC475O=&5S*3L*
M"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<BDI('L*("`@("`@("`@
M("`@<F5T=7)N("1E<G(["B`@("`@("`@?0H*"B`@("`@("`@+R\@0VAE8VL@
M9F]R(')E9&ER96-T:6]N"B`@("`@("`@:68@*"`@("`D=&AI<RT^7V%L;&]W
M4F5D:7)E8W1S"B`@("`@("`@("`@($%.1"`D=&AI<RT^7W)E9&ER96-T<R`\
M/2`D=&AI<RT^7VUA>%)E9&ER96-T<PH@("`@("`@("`@("!!3D0@)'1H:7,M
M/F=E=%)E<W!O;G-E0V]D92@I(#X@,S`P"B`@("`@("`@("`@($%.1"`D=&AI
M<RT^9V5T4F5S<&]N<V5#;V1E*"D@/"`S.3D*("`@("`@("`@("`@04Y$("%E
M;7!T>2@D=&AI<RT^7W)E<W!O;G-E+3Y?:&5A9&5R<ULG;&]C871I;VXG72DI
M('L*"B`@("`@("`@("`@(`H@("`@("`@("`@("`D<F5D:7)E8W0@/2`D=&AI
M<RT^7W)E<W!O;G-E+3Y?:&5A9&5R<ULG;&]C871I;VXG73L*"B`@("`@("`@
M("`@("\O($%B<V]L=71E(%523`H@("`@("`@("`@("!I9B`H<')E9U]M871C
M:"@G+UYH='1P<S\Z7"]<+R]I)RP@)')E9&ER96-T*2D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]U<FP@/2`F;F5W($YE=%]54DPH)')E9&ER96-T*3L*
M("`@("`@("`@("`@("`@("1T:&ES+3YA9&1(96%D97(H)TAO<W0G+"`D=&AI
M<RT^7V=E;F5R871E2&]S=$AE861E<B@I*3L*("`@("`@("`@("`@+R\@06)S
M;VQU=&4@<&%T:`H@("`@("`@("`@("!](&5L<V5I9B`H)')E9&ER96-T>S!]
M(#T]("<O)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]U<FPM/G!A=&@@
M/2`D<F5D:7)E8W0["B`@("`@("`@("`@(`H@("`@("`@("`@("`O+R!296QA
M=&EV92!P871H"B`@("`@("`@("`@('T@96QS96EF("AS=6)S='(H)')E9&ER
M96-T+"`P+"`S*2`]/2`G+BXO)R!/4B!S=6)S='(H)')E9&ER96-T+"`P+"`R
M*2`]/2`G+B\G*2!["B`@("`@("`@("`@("`@("!I9B`H<W5B<W1R*"1T:&ES
M+3Y?=7)L+3YP871H+"`M,2D@/3T@)R\G*2!["B`@("`@("`@("`@("`@("`@
M("`@)')E9&ER96-T(#T@)'1H:7,M/E]U<FPM/G!A=&@@+B`D<F5D:7)E8W0[
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("1R961I<F5C="`](&1I<FYA;64H)'1H:7,M/E]U<FPM/G!A=&@I("X@)R\G
M("X@)')E9&ER96-T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@)')E9&ER96-T(#T@3F5T7U523#HZ<F5S;VQV95!A=&@H)')E9&ER96-T
M*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?=7)L+3YP871H(#T@)')E9&ER
M96-T.PH@("`@("`@("`@("`@("`@"B`@("`@("`@("`@("\O($9I;&5N86UE
M+"!N;R!P871H"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("!I9B`H<W5B<W1R*"1T:&ES+3Y?=7)L+3YP871H+"`M,2D@/3T@)R\G*2![
M"B`@("`@("`@("`@("`@("`@("`@)')E9&ER96-T(#T@)'1H:7,M/E]U<FPM
M/G!A=&@@+B`D<F5D:7)E8W0["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("1R961I<F5C="`](&1I<FYA;64H)'1H:7,M
M/E]U<FPM/G!A=&@I("X@)R\G("X@)')E9&ER96-T.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)'1H:7,M/E]U<FPM/G!A=&@@/2`D<F5D
M:7)E8W0["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?<F5D
M:7)E8W1S*RL["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<V5N9%)E<75E
M<W0H)'-A=F5";V1Y*3L*"B`@("`@("`@+R\@5&]O(&UA;GD@<F5D:7)E8W1S
M"B`@("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?86QL;W=2961I<F5C=',@04Y$
M("1T:&ES+3Y?<F5D:7)E8W1S(#X@)'1H:7,M/E]M87A2961I<F5C=',I('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U1O;R!M86YY
M(')E9&ER96-T<R<I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]S;V-K
M+3YD:7-C;VYN96-T*"D["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@*B!2971U<FYS('1H92!R97-P;VYS92!C;V1E"B`@("`J
M"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J($!R971U<FX@;6EX960@("`@
M(%)E<W!O;G-E(&-O9&4L(&9A;'-E(&EF(&YO="!S970*("`@("HO"B`@("!F
M=6YC=&EO;B!G971297-P;VYS94-O9&4H*0H@("`@>PH@("`@("`@(')E='5R
M;B!I<W-E="@D=&AI<RT^7W)E<W!O;G-E+3Y?8V]D92D@/R`D=&AI<RT^7W)E
M<W!O;G-E+3Y?8V]D92`Z(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@*B!2
M971U<FYS(&5I=&AE<B!T:&4@;F%M960@:&5A9&5R(&]R(&%L;"!I9B!N;R!N
M86UE(&=I=F5N"B`@("`J"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J($!P
M87)A;2!S=')I;F<@("`@(%1H92!H96%D97(@;F%M92!T;R!R971U<FXL(&1O
M(&YO="!S970@=&\@9V5T(&%L;"!H96%D97)S"B`@("`J($!R971U<FX@;6EX
M960@("`@(&5I=&AE<B!T:&4@=F%L=64@;V8@)&AE861E<FYA;64@*&9A;'-E
M(&EF(&AE861E<B!I<R!N;W0@<')E<V5N="D*("`@("H@("`@("`@("`@("`@
M("`@("`@;W(@86X@87)R87D@;V8@86QL(&AE861E<G,*("`@("HO"B`@("!F
M=6YC=&EO;B!G971297-P;VYS94AE861E<B@D:&5A9&5R;F%M92`](&YU;&PI
M"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D:&5A9&5R;F%M92DI('L*("`@
M("`@("`@("`@<F5T=7)N(&ES<V5T*"1T:&ES+3Y?<F5S<&]N<V4M/E]H96%D
M97)S*3\@)'1H:7,M/E]R97-P;VYS92T^7VAE861E<G,Z(&%R<F%Y*"D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&AE861E<FYA;64@/2!S=')T
M;VQO=V5R*"1H96%D97)N86UE*3L*("`@("`@("`@("`@<F5T=7)N(&ES<V5T
M*"1T:&ES+3Y?<F5S<&]N<V4M/E]H96%D97)S6R1H96%D97)N86UE72D@/R`D
M=&AI<RT^7W)E<W!O;G-E+3Y?:&5A9&5R<ULD:&5A9&5R;F%M95T@.B!F86QS
M93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`J(%)E='5R;G,@=&AE
M(&)O9'D@;V8@=&AE(')E<W!O;G-E"B`@("`J"B`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`J($!R971U<FX@;6EX960@("`@(')E<W!O;G-E(&)O9'DL(&9A
M;'-E(&EF(&YO="!S970*("`@("HO"B`@("!F=6YC=&EO;B!G971297-P;VYS
M94)O9'DH*0H@("`@>PH@("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^7W)E
M<W!O;G-E+3Y?8F]D>2D@/R`D=&AI<RT^7W)E<W!O;G-E+3Y?8F]D>2`Z(&9A
M;'-E.PH@("`@?0H*("`@("\J*@H@("`@*B!2971U<FYS(&-O;VMI97,@<V5T
M(&EN(')E<W!O;G-E"B`@("`J(`H@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M*B!`<F5T=7)N(&UI>&5D("`@("!A<G)A>2!O9B!R97-P;VYS92!C;V]K:65S
M+"!F86QS92!I9B!N;VYE(&%R92!P<F5S96YT"B`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T4F5S<&]N<V5#;V]K:65S*"D*("`@('L*("`@("`@("!R971U<FX@
M:7-S970H)'1H:7,M/E]R97-P;VYS92T^7V-O;VMI97,I(#\@)'1H:7,M/E]R
M97-P;VYS92T^7V-O;VMI97,@.B!F86QS93L*("`@('T*"B`@("`O*BH*("`@
M("H@0G5I;&1S('1H92!R97%U97-T('-T<FEN9PH@("`@*@H@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("H@0')E='5R;B!S=')I;F<@5&AE(')E<75E<W0@
M<W1R:6YG"B`@("`J+PH@("`@9G5N8W1I;VX@7V)U:6QD4F5Q=65S="@I"B`@
M("!["B`@("`@("`@)'-E<&%R871O<B`](&EN:5]G970H)V%R9U]S97!A<F%T
M;W(N;W5T<'5T)RD["B`@("`@("`@:6YI7W-E="@G87)G7W-E<&%R871O<BYO
M=71P=70G+"`G)B<I.PH@("`@("`@("1Q=65R>7-T<FEN9R`]("@D<75E<GES
M=')I;F<@/2`D=&AI<RT^7W5R;"T^9V5T475E<GE3=')I;F<H*2D@/R`G/R<@
M+B`D<75E<GES=')I;F<@.B`G)SL*("`@("`@("!I;FE?<V5T*"=A<F=?<V5P
M87)A=&]R+F]U='!U="<L("1S97!A<F%T;W(I.PH*("`@("`@("`D:&]S="`]
M(&ES<V5T*"1T:&ES+3Y?<')O>'E?:&]S="D@/R`D=&AI<RT^7W5R;"T^<')O
M=&]C;VP@+B`G.B\O)R`N("1T:&ES+3Y?=7)L+3YH;W-T(#H@)R<["B`@("`@
M("`@)'!O<G0@/2`H:7-S970H)'1H:7,M/E]P<F]X>5]H;W-T*2!!3D0@)'1H
M:7,M/E]U<FPM/G!O<G0@(3T@.#`I(#\@)SHG("X@)'1H:7,M/E]U<FPM/G!O
M<G0@.B`G)SL*("`@("`@("`D<&%T:"`]("AE;7!T>2@D=&AI<RT^7W5R;"T^
M<&%T:"D_("<O)SH@)'1H:7,M/E]U<FPM/G!A=&@I("X@)'%U97)Y<W1R:6YG
M.PH@("`@("`@("1U<FP@(#T@)&AO<W0@+B`D<&]R="`N("1P871H.PH*("`@
M("`@("`D<F5Q=65S="`]("1T:&ES+3Y?;65T:&]D("X@)R`G("X@)'5R;"`N
M("<@2%144"\G("X@)'1H:7,M/E]H='1P("X@(EQR7&XB.PH*("`@("`@("!I
M9B`H:6Y?87)R87DH)'1H:7,M/E]M971H;V0L("1T:&ES+3Y?8F]D>41I<V%L
M;&]W960I('Q\"B`@("`@("`@("`@("A(5%107U)%455%4U1?34542$]$7U!/
M4U0@(3T@)'1H:7,M/E]M971H;V0@)B8@96UP='DH)'1H:7,M/E]B;V1Y*2D@
M?'P*("`@("`@("`@("`@*$A45%!?4D5154535%]-151(3T1?4$]35"`A/2`D
M=&AI<RT^7VUE=&AO9"`F)B!E;7!T>2@D=&AI<RT^7W!O<W1$871A*2`F)B!E
M;7!T>2@D=&AI<RT^7W!O<W1&:6QE<RDI*2!["@H@("`@("`@("`@("`D=&AI
M<RT^<F5M;W9E2&5A9&5R*"=#;VYT96YT+51Y<&4G*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]R97%U97-T2&5A
M9&5R<ULG8V]N=&5N="UT>7!E)UTI*2!["B`@("`@("`@("`@("`@("`O+R!!
M9&0@9&5F875L="!C;VYT96YT+71Y<&4*("`@("`@("`@("`@("`@("1T:&ES
M+3YA9&1(96%D97(H)T-O;G1E;G0M5'EP92<L("=A<'!L:6-A=&EO;B]X+7=W
M=RUF;W)M+75R;&5N8V]D960G*3L*("`@("`@("`@("`@?2!E;'-E:68@*"=M
M=6QT:7!A<G0O9F]R;2UD871A)R`]/2`D=&AI<RT^7W)E<75E<W1(96%D97)S
M6R=C;VYT96YT+71Y<&4G72D@>PH@("`@("`@("`@("`@("`@)&)O=6YD87)Y
M(#T@)TA45%!?4F5Q=65S=%\G("X@;60U*'5N:7%I9"@G<F5Q=65S="<I("X@
M;6EC<F]T:6UE*"DI.PH@("`@("`@("`@("`@("`@)'1H:7,M/F%D9$AE861E
M<B@G0V]N=&5N="U4>7!E)RP@)VUU;'1I<&%R="]F;W)M+61A=&$[(&)O=6YD
M87)Y/2<@+B`D8F]U;F1A<GDI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("`O+R!297%U97-T($AE861E<G,*("`@("`@("!I9B`H(65M<'1Y
M*"1T:&ES+3Y?<F5Q=65S=$AE861E<G,I*2!["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3Y?<F5Q=65S=$AE861E<G,@87,@)&YA;64@/3X@)'9A;'5E
M*2!["B`@("`@("`@("`@("`@("`D8V%N;VYI8V%L3F%M92`](&EM<&QO9&4H
M)RTG+"!A<G)A>5]M87`H)W5C9FER<W0G+"!E>'!L;V1E*"<M)RP@)&YA;64I
M*2D["B`@("`@("`@("`@("`@("`D<F5Q=65S="`@("`@("X]("1C86YO;FEC
M86Q.86UE("X@)SH@)R`N("1V86QU92`N(")<<EQN(CL*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@+R\@3F\@<&]S="!D871A(&]R('=R;VYG
M(&UE=&AO9"P@<V\@<VEM<&QY(&%D9"!A(&9I;F%L($-23$8*("`@("`@("!I
M9B`H:6Y?87)R87DH)'1H:7,M/E]M971H;V0L("1T:&ES+3Y?8F]D>41I<V%L
M;&]W960I('Q\(`H@("`@("`@("`@("`H2%144%]215%515-47TU%5$A/1%]0
M3U-4("$]("1T:&ES+3Y?;65T:&]D("8F(&5M<'1Y*"1T:&ES+3Y?8F]D>2DI
M*2!["@H@("`@("`@("`@("`D<F5Q=65S="`N/2`B7')<;B(["@H@("`@("`@
M("\O(%!O<W0@9&%T82!I9B!I="=S(&%N(&%R<F%Y"B`@("`@("`@?2!E;'-E
M:68@*$A45%!?4D5154535%]-151(3T1?4$]35"`]/2`D=&AI<RT^7VUE=&AO
M9"`F)B`*("`@("`@("`@("`@("`@("`@*"%E;7!T>2@D=&AI<RT^7W!O<W1$
M871A*2!\?"`A96UP='DH)'1H:7,M/E]P;W-T1FEL97,I*2D@>PH*("`@("`@
M("`@("`@+R\@(FYO<FUA;"(@4$]35"!R97%U97-T"B`@("`@("`@("`@(&EF
M("@A:7-S970H)&)O=6YD87)Y*2D@>PH@("`@("`@("`@("`@("`@)'!O<W1D
M871A(#T@:6UP;&]D92@G)B<L(&%R<F%Y7VUA<"@*("`@("`@("`@("`@("`@
M("`@("!C<F5A=&5?9G5N8W1I;VXH)R1A)RP@)W)E='5R;B`D85LP72`N(%PG
M/5PG("X@)&%;,5T[)RDL(`H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M9FQA='1E;D%R<F%Y*"<G+"`D=&AI<RT^7W!O<W1$871A*0H@("`@("`@("`@
M("`@("`@*2D["@H@("`@("`@("`@("`O+R!M=6QT:7!A<G0@<F5Q=65S="P@
M<')O8F%B;'D@=VET:"!F:6QE('5P;&]A9',*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1P;W-T9&%T82`]("<G.PH@("`@("`@("`@
M("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W!O<W1$871A*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1F;&%T1&%T82`]("1T:&ES+3Y?9FQA='1E;D%R<F%Y
M*"<G+"`D=&AI<RT^7W!O<W1$871A*3L*("`@("`@("`@("`@("`@("`@("!F
M;W)E86-H("@D9FQA=$1A=&$@87,@)&ET96TI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)'!O<W1D871A("X]("<M+2<@+B`D8F]U;F1A<GD@+B`B7')<
M;B(["B`@("`@("`@("`@("`@("`@("`@("`@("1P;W-T9&%T82`N/2`G0V]N
M=&5N="U$:7-P;W-I=&EO;CH@9F]R;2UD871A.R!N86UE/2(G("X@)&ET96U;
M,%T@+B`G(B<["B`@("`@("`@("`@("`@("`@("`@("`@("1P;W-T9&%T82`N
M/2`B7')<;EQR7&XB("X@=7)L9&5C;V1E*"1I=&5M6S%=*2`N(")<<EQN(CL*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7W!O<W1&:6QE<R!A<R`D;F%M
M92`]/B`D=F%L=64I('L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-?87)R
M87DH)'9A;'5E6R=N86UE)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1V87)N86UE("`@("`@(#T@)&YA;64@+B`H)'1H:7,M/E]U<V5"<F%C:V5T
M<S\@)UM=)SH@)R<I.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE("`@("`@(#T@)&YA;64[
M"B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU95LG;F%M92==(#T@87)R
M87DH)'9A;'5E6R=N86UE)UTI.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("!F;W)E86-H("@D=F%L=65;)VYA;64G72!A<R`D
M:V5Y(#T^("1F:6QE;F%M92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M9G`@("`](&9O<&5N*"1F:6QE;F%M92P@)W(G*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&1A=&$@/2!F<F5A9"@D9G`L(&9I;&5S:7IE*"1F:6QE;F%M
M92DI.PH@("`@("`@("`@("`@("`@("`@("`@("!F8VQO<V4H)&9P*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&)A<V5N86UE(#T@8F%S96YA;64H)&9I
M;&5N86UE*3L*("`@("`@("`@("`@("`@("`@("`@("`@)'1Y<&4@("`@(#T@
M:7-?87)R87DH)'9A;'5E6R=T>7!E)UTI/R!`)'9A;'5E6R=T>7!E)UU;)&ME
M>5TZ("1V86QU95LG='EP92==.PH*("`@("`@("`@("`@("`@("`@("`@("`@
M)'!O<W1D871A("X]("<M+2<@+B`D8F]U;F1A<GD@+B`B7')<;B(["B`@("`@
M("`@("`@("`@("`@("`@("`@("1P;W-T9&%T82`N/2`G0V]N=&5N="U$:7-P
M;W-I=&EO;CH@9F]R;2UD871A.R!N86UE/2(G("X@)'9A<FYA;64@+B`G(CL@
M9FEL96YA;64](B<@+B`D8F%S96YA;64@+B`G(B<["B`@("`@("`@("`@("`@
M("`@("`@("`@("1P;W-T9&%T82`N/2`B7')<;D-O;G1E;G0M5'EP93H@(B`N
M("1T>7!E.PH@("`@("`@("`@("`@("`@("`@("`@("`D<&]S=&1A=&$@+CT@
M(EQR7&Y<<EQN(B`N("1D871A("X@(EQR7&XB.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1P;W-T
M9&%T82`N/2`G+2TG("X@)&)O=6YD87)Y("X@(BTM7')<;B(["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)')E<75E<W0@+CT@)T-O;G1E;G0M3&5N9W1H
M.B`G("X@<W1R;&5N*"1P;W-T9&%T82D@+B`B7')<;EQR7&XB.PH@("`@("`@
M("`@("`D<F5Q=65S="`N/2`D<&]S=&1A=&$["@H@("`@("`@("\O($5X<&QI
M8VET;'D@<V5T(')E<75E<W0@8F]D>0H@("`@("`@('T@96QS96EF("@A96UP
M='DH)'1H:7,M/E]B;V1Y*2D@>PH*("`@("`@("`@("`@)')E<75E<W0@+CT@
M)T-O;G1E;G0M3&5N9W1H.B`G("X@<W1R;&5N*"1T:&ES+3Y?8F]D>2D@+B`B
M7')<;EQR7&XB.PH@("`@("`@("`@("`D<F5Q=65S="`N/2`D=&AI<RT^7V)O
M9'D["B`@("`@("`@?0H@("`@("`@(`H@("`@("`@(')E='5R;B`D<F5Q=65S
M=#L*("`@('T*"B`@("\J*@H@("`@*B!(96QP97(@9G5N8W1I;VX@=&\@8VAA
M;F=E('1H92`H<')O8F%B;'D@;75L=&ED:6UE;G-I;VYA;"D@87-S;V-I871I
M=F4@87)R87D*("`@("H@:6YT;R!T:&4@<VEM<&QE(&]N92X*("`@("H*("`@
M("H@0'!A<F%M("`@('-T<FEN9R`@;F%M92!F;W(@:71E;0H@("`@*B!`<&%R
M86T@("`@;6EX960@("!I=&5M)W,@=F%L=65S"B`@("`J($!R971U<FX@("!A
M<G)A>2`@(&%R<F%Y('=I=&@@=&AE(&9O;&QO=VEN9R!I=&5M<SH@87)R87DH
M)VET96T@;F%M92<L("=I=&5M('9A;'5E)RD["B`@("`J+PH@("`@9G5N8W1I
M;VX@7V9L871T96Y!<G)A>2@D;F%M92P@)'9A;'5E<RD*("`@('L*("`@("`@
M("!I9B`H(6ES7V%R<F%Y*"1V86QU97,I*2!["B`@("`@("`@("`@(')E='5R
M;B!A<G)A>2AA<G)A>2@D;F%M92P@)'9A;'5E<RDI.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1R970@/2!A<G)A>2@I.PH@("`@("`@("`@("!F
M;W)E86-H("@D=F%L=65S(&%S("1K(#T^("1V*2!["B`@("`@("`@("`@("`@
M("!I9B`H96UP='DH)&YA;64I*2!["B`@("`@("`@("`@("`@("`@("`@)&YE
M=TYA;64@/2`D:SL*("`@("`@("`@("`@("`@('T@96QS96EF("@D=&AI<RT^
M7W5S94)R86-K971S*2!["B`@("`@("`@("`@("`@("`@("`@)&YE=TYA;64@
M/2`D;F%M92`N("=;)R`N("1K("X@)UTG.PH@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`D;F5W3F%M92`]("1N86UE.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)')E="`](&%R<F%Y
M7VUE<F=E*"1R970L("1T:&ES+3Y?9FQA='1E;D%R<F%Y*"1N97=.86UE+"`D
M=BDI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D<F5T.PH@
M("`@("`@('T*("`@('T*"@H@("`O*BH*("`@("H@061D<R!A($QI<W1E;F5R
M('1O('1H92!L:7-T(&]F(&QI<W1E;F5R<R!T:&%T(&%R92!N;W1I9FEE9"!O
M9@H@("`@*B!T:&4@;V)J96-T)W,@979E;G1S"B`@("`J(`H@("`@*B!`<&%R
M86T@("`@;V)J96-T("`@2%144%]297%U97-T7TQI<W1E;F5R(&EN<W1A;F-E
M('1O(&%T=&%C:`H@("`@*B!`<F5T=7)N("`@8F]O;&5A;B`@=VAE=&AE<B!T
M:&4@;&ES=&5N97(@=V%S('-U8V-E<W-F=6QL>2!A='1A8VAE9`H@("`@*B!`
M86-C97-S("`@<'5B;&EC"B`@("`J+PH@("`@9G5N8W1I;VX@871T86-H*"8D
M;&ES=&5N97(I"B`@("!["B`@("`@("`@:68@*"%I<U]A*"1L:7-T96YE<BP@
M)TA45%!?4F5Q=65S=%],:7-T96YE<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]L:7-T96YE<G-;
M)&QI<W1E;F5R+3YG971)9"@I72`])B`D;&ES=&5N97(["B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H*("`@+RHJ"B`@("`J(%)E;6]V97,@82!,:7-T
M96YE<B!F<F]M('1H92!L:7-T(&]F(&QI<W1E;F5R<R`*("`@("H@"B`@("`J
M($!P87)A;2`@("!O8FIE8W0@("!(5%107U)E<75E<W1?3&ES=&5N97(@:6YS
M=&%N8V4@=&\@9&5T86-H"B`@("`J($!R971U<FX@("!B;V]L96%N("!W:&5T
M:&5R('1H92!L:7-T96YE<B!W87,@<W5C8V5S<V9U;&QY(&1E=&%C:&5D"B`@
M("`J($!A8V-E<W,@("!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!D971A
M8V@H)B1L:7-T96YE<BD*("`@('L*("`@("`@("!I9B`H(6ES7V$H)&QI<W1E
M;F5R+"`G2%144%]297%U97-T7TQI<W1E;F5R)RD@?'P@"B`@("`@("`@("`@
M("%I<W-E="@D=&AI<RT^7VQI<W1E;F5R<ULD;&ES=&5N97(M/F=E=$ED*"E=
M*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@
M("`@('5N<V5T*"1T:&ES+3Y?;&ES=&5N97)S6R1L:7-T96YE<BT^9V5T260H
M*5TI.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*"B`@("\J*@H@("`@
M*B!.;W1I9FEE<R!A;&P@<F5G:7-T97)E9"!L:7-T96YE<G,@;V8@86X@979E
M;G0N"B`@("`J(`H@("`@*B!%=F5N=',@<V5N="!B>2!(5%107U)E<75E<W0@
M;V)J96-T"B`@("`J("=S96YT4F5Q=65S="<Z(&%F=&5R('1H92!R97%U97-T
M('=A<R!S96YT"B`@("`J($5V96YT<R!S96YT(&)Y($A45%!?4F5S<&]N<V4@
M;V)J96-T"B`@("`J("=G;W1(96%D97)S)SH@869T97(@<F5C96EV:6YG(')E
M<W!O;G-E(&AE861E<G,@*&AE861E<G,@87)E('!A<W-E9"!I;B`D9&%T82D*
M("`@("H@)W1I8VLG.B!O;B!R96-E:79I;F<@82!P87)T(&]F(')E<W!O;G-E
M(&)O9'D@*'1H92!P87)T(&ES('!A<W-E9"!I;B`D9&%T82D*("`@("H@)V=Z
M5&EC:R<Z(&]N(')E8V5I=FEN9R!A(&=Z:7`M96YC;V1E9"!P87)T(&]F(')E
M<W!O;G-E(&)O9'D@*&1I='1O*0H@("`@*B`G9V]T0F]D>2<Z(&%F=&5R(')E
M8V5I=FEN9R!T:&4@<F5S<&]N<V4@8F]D>2`H<&%S<V5S('1H92!D96-O9&5D
M(&)O9'D@:6X@)&1A=&$@:68@:70@=V%S(&=Z:7!P960I"B`@("`J(`H@("`@
M*B!`<&%R86T@("`@<W1R:6YG("!%=F5N="!N86UE"B`@("`J($!P87)A;2`@
M("!M:7AE9"`@($%D9&ET:6]N86P@9&%T80H@("`@*B!`86-C97-S("`@<')I
M=F%T90H@("`@*B\*("`@(&9U;F-T:6]N(%]N;W1I9GDH)&5V96YT+"`D9&%T
M82`](&YU;&PI"B`@("!["B`@("`@("`@9F]R96%C:"`H87)R87E?:V5Y<R@D
M=&AI<RT^7VQI<W1E;F5R<RD@87,@)&ED*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?;&ES=&5N97)S6R1I9%TM/G5P9&%T92@D=&AI<RP@)&5V96YT+"`D9&%T
M82D["B`@("`@("`@?0H@("`@?0I]"@H*+RHJ"BH@4F5S<&]N<V4@8VQA<W,@
M=&\@8V]M<&QE;65N="!T:&4@4F5Q=65S="!C;&%S<PHJ+PIC;&%S<R!(5%10
M7U)E<W!O;G-E"GL*("`@("\J*@H@("`@*B!3;V-K970@;V)J96-T"B`@("`J
M($!V87(@;V)J96-T"B`@("`J+PH@("`@=F%R("1?<V]C:SL*"B`@("`O*BH*
M("`@("H@4')O=&]C;VP*("`@("H@0'9A<B!S=')I;F<*("`@("HO"B`@("!V
M87(@)%]P<F]T;V-O;#L*("`@(`H@("`@+RHJ"B`@("`J(%)E='5R;B!C;V1E
M"B`@("`J($!V87(@<W1R:6YG"B`@("`J+PH@("`@=F%R("1?8V]D93L*("`@
M(`H@("`@+RHJ"B`@("`J(%)E<W!O;G-E(&AE861E<G,*("`@("H@0'9A<B!A
M<G)A>0H@("`@*B\*("`@('9A<B`D7VAE861E<G,["@H@("`@+RHJ"B`@("`J
M($-O;VMI97,@<V5T(&EN(')E<W!O;G-E("`*("`@("H@0'9A<B!A<G)A>0H@
M("`@*B\*("`@('9A<B`D7V-O;VMI97,["@H@("`@+RHJ"B`@("`J(%)E<W!O
M;G-E(&)O9'D*("`@("H@0'9A<B!S=')I;F<*("`@("HO"B`@("!V87(@)%]B
M;V1Y(#T@)R<["@H@("`O*BH*("`@("H@57-E9"!B>2!?<F5A9$-H=6YK960H
M*3H@<F5M86EN:6YG(&QE;F=T:"!O9B!T:&4@8W5R<F5N="!C:'5N:PH@("`@
M*B!`=F%R('-T<FEN9PH@("`@*B\*("`@('9A<B`D7V-H=6YK3&5N9W1H(#T@
M,#L*"B`@("\J*@H@("`@*B!!='1A8VAE9"!L:7-T96YE<G,*("`@("H@0'9A
M<B!A<G)A>0H@("`@*B\*("`@('9A<B`D7VQI<W1E;F5R<R`](&%R<F%Y*"D[
M"@H@("`@+RHJ"B`@("`J($-O;G-T<G5C=&]R"B`@("`J"B`@("`J($!P87)A
M;2`@;V)J96-T($YE=%]3;V-K970@("`@('-O8VME="!T;R!R96%D('1H92!R
M97-P;VYS92!F<F]M"B`@("`J($!P87)A;2`@87)R87D@("`@("`@("`@("`@
M("`@(&QI<W1E;F5R<R!A='1A8VAE9"!T;R!R97%U97-T"B`@("`J($!R971U
M<FX@;6EX960@4$5!4B!%<G)O<B!O;B!E<G)O<BP@=')U92!O=&AE<G=I<V4*
M("`@("HO"B`@("!F=6YC=&EO;B!(5%107U)E<W!O;G-E*"8D<V]C:RP@)B1L
M:7-T96YE<G,I"B`@("!["B`@("`@("`@)'1H:7,M/E]S;V-K("`@("`@/28@
M)'-O8VL["B`@("`@("`@)'1H:7,M/E]L:7-T96YE<G,@/28@)&QI<W1E;F5R
M<SL*("`@('T*"@H@("`O*BH*("`@("H@4')O8V5S<V5S(&$@2%144"!R97-P
M;VYS90H@("`@*B`*("`@("H@5&AI<R!E>'1R86-T<R!R97-P;VYS92!C;V1E
M+"!H96%D97)S+"!C;V]K:65S(&%N9"!D96-O9&5S(&)O9'D@:68@:70@"B`@
M("`J('=A<R!E;F-O9&5D(&EN('-O;64@=V%Y"B`@("`J"B`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`J($!P87)A;2`@8F]O;"`@("`@(%=H971H97(@=&\@
M<W1O<F4@<F5S<&]N<V4@8F]D>2!I;B!O8FIE8W0@<')O<&5R='DL('-E=`H@
M("`@*B`@("`@("`@("`@("`@("`@("!T:&ES('1O(&9A;'-E(&EF(&1O=VYL
M;V%D:6YG(&$@3$%21T4@9FEL92!A;F0@=7-I;F<@82!,:7-T96YE<BX*("`@
M("H@("`@("`@("`@("`@("`@("`@5&AI<R!I<R!A<W-U;65D('1O(&)E('1R
M=64@:68@8F]D>2!I<R!G>FEP+65N8V]D960N"B`@("`J($!T:')O=W,@4$5!
M4E]%<G)O<@H@("`@*B!`<F5T=7)N(&UI>&5D("`@("!T<G5E(&]N('-U8V-E
M<W,L(%!%05)?17)R;W(@:6X@8V%S92!O9B!M86QF;W)M960@<F5S<&]N<V4*
M("`@("HO"B`@("!F=6YC=&EO;B!P<F]C97-S*"1S879E0F]D>2`]('1R=64I
M"B`@("!["B`@("`@("`@9&\@>PH@("`@("`@("`@("`D;&EN92`]("1T:&ES
M+3Y?<V]C:RT^<F5A9$QI;F4H*3L*("`@("`@("`@("`@:68@*'-S8V%N9B@D
M;&EN92P@)TA45%`O)7,@)7,G+"`D:'1T<%]V97)S:6]N+"`D<F5T=7)N8V]D
M92D@(3T@,BD@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)TUA;&9O<FUE9"!R97-P;VYS92XG*3L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<')O=&]C;VP@/2`G2%14
M4"\G("X@)&AT='!?=F5R<VEO;CL*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M8V]D92`@("`@/2!I;G1V86PH)')E='5R;F-O9&4I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@('=H:6QE("@G)R`A/3T@*"1H96%D97(@/2`D=&AI<RT^
M7W-O8VLM/G)E861,:6YE*"DI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!R;V-E<W-(96%D97(H)&AE861E<BD["B`@("`@("`@("`@('T*("`@("`@
M("!]('=H:6QE("@Q,#`@/3T@)'1H:7,M/E]C;V1E*3L*"B`@("`@("`@)'1H
M:7,M/E]N;W1I9GDH)V=O=$AE861E<G,G+"`D=&AI<RT^7VAE861E<G,I.PH*
M("`@("`@("`O+R!)9B!R97-P;VYS92!B;V1Y(&ES('!R97-E;G0L(')E860@
M:70@86YD(&1E8V]D90H@("`@("`@("1C:'5N:V5D(#T@:7-S970H)'1H:7,M
M/E]H96%D97)S6R=T<F%N<V9E<BUE;F-O9&EN9R==*2`F)B`H)V-H=6YK960G
M(#T]("1T:&ES+3Y?:&5A9&5R<ULG=')A;G-F97(M96YC;V1I;F<G72D["B`@
M("`@("`@)&=Z:7!P960@/2!I<W-E="@D=&AI<RT^7VAE861E<G-;)V-O;G1E
M;G0M96YC;V1I;F<G72D@)B8@*"=G>FEP)R`]/2`D=&AI<RT^7VAE861E<G-;
M)V-O;G1E;G0M96YC;V1I;F<G72D["B`@("`@("`@)&AA<T)O9'D@/2!F86QS
M93L*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?:&5A9&5R<ULG8V]N=&5N
M="UL96YG=&@G72D@?'P@,"`A/2`D=&AI<RT^7VAE861E<G-;)V-O;G1E;G0M
M;&5N9W1H)UTI('L*("`@("`@("`@("`@=VAI;&4@*"$D=&AI<RT^7W-O8VLM
M/F5O9B@I*2!["B`@("`@("`@("`@("`@("!I9B`H)&-H=6YK960I('L*("`@
M("`@("`@("`@("`@("`@("`D9&%T82`]("1T:&ES+3Y?<F5A9$-H=6YK960H
M*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@)&1A=&$@/2`D=&AI<RT^7W-O8VLM/G)E860H-#`Y-BD["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H)R<@/3T@)&1A=&$I('L*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@)&AA<T)O9'D@/2!T<G5E.PH@
M("`@("`@("`@("`@("`@("`@(&EF("@D<V%V94)O9'D@?'P@)&=Z:7!P960I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]B;V1Y("X]("1D
M871A.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7VYO=&EF>2@D9WII<'!E9#\@)V=Z5&EC:R<Z("=T:6-K)RP@
M)&1A=&$I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@("`@(&EF("@D:&%S0F]D>2D@>PH@("`@("`@("`@("`O+R!5
M;F-O;7!R97-S('1H92!B;V1Y(&EF(&YE961E9`H@("`@("`@("`@("!I9B`H
M)&=Z:7!P960I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?8F]D>2`](&=Z
M:6YF;&%T92AS=6)S='(H)'1H:7,M/E]B;V1Y+"`Q,"DI.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]N;W1I9GDH)V=O=$)O9'DG+"`D=&AI<RT^7V)O9'DI
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]N;W1I9GDH)V=O=$)O9'DG*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"@H@("`O*BH*("`@("H@4')O
M8V5S<V5S('1H92!R97-P;VYS92!H96%D97(*("`@("H*("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`J($!P87)A;2`@<W1R:6YG("`@($A45%`@:&5A9&5R
M"B`@("`J+PH@("`@9G5N8W1I;VX@7W!R;V-E<W-(96%D97(H)&AE861E<BD*
M("`@('L*("`@("`@("!L:7-T*"1H96%D97)N86UE+"`D:&5A9&5R=F%L=64I
M(#T@97AP;&]D92@G.B<L("1H96%D97(L(#(I.PH@("`@("`@("1H96%D97)N
M86UE("`]('-T<G1O;&]W97(H)&AE861E<FYA;64I.PH@("`@("`@("1H96%D
M97)V86QU92`](&QT<FEM*"1H96%D97)V86QU92D["B`@("`@("`@"B`@("`@
M("`@:68@*"=S970M8V]O:VEE)R`A/2`D:&5A9&5R;F%M92D@>PH@("`@("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]H96%D97)S6R1H96%D97)N86UE72DI
M('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?:&5A9&5R<ULD:&5A9&5R;F%M
M95T@+CT@)RPG("X@)&AE861E<G9A;'5E.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]H96%D97)S6R1H96%D97)N86UE
M72`@/2`D:&5A9&5R=F%L=64["B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<G-E0V]O:VEE*"1H96%D97)V
M86QU92D["B`@("`@("`@?0H@("`@?0H*"B`@("\J*@H@("`@*B!087)S92!A
M(%-E="U#;V]K:64@:&5A9&5R('1O(&9I;&P@)%]C;V]K:65S(&%R<F%Y"B`@
M("`J"B`@("`J($!A8V-E<W,@<')I=F%T90H@("`@*B!`<&%R86T@('-T<FEN
M9R`@("!V86QU92!O9B!3970M0V]O:VEE(&AE861E<@H@("`@*B\*("`@(&9U
M;F-T:6]N(%]P87)S94-O;VMI92@D:&5A9&5R=F%L=64I"B`@("!["B`@("`@
M("`@)&-O;VMI92`](&%R<F%Y*`H@("`@("`@("`@("`G97AP:7)E<R<@/3X@
M;G5L;"P*("`@("`@("`@("`@)V1O;6%I;B<@(#T^(&YU;&PL"B`@("`@("`@
M("`@("=P871H)R`@("`]/B!N=6QL+`H@("`@("`@("`@("`G<V5C=7)E)R`@
M/3X@9F%L<V4*("`@("`@("`I.PH*("`@("`@("`O+R!/;FQY(&$@;F%M93UV
M86QU92!P86ER"B`@("`@("`@:68@*"%S=')P;W,H)&AE861E<G9A;'5E+"`G
M.R<I*2!["B`@("`@("`@("`@("1P;W,@/2!S=')P;W,H)&AE861E<G9A;'5E
M+"`G/2<I.PH@("`@("`@("`@("`D8V]O:VEE6R=N86UE)UT@(#T@=')I;2AS
M=6)S='(H)&AE861E<G9A;'5E+"`P+"`D<&]S*2D["B`@("`@("`@("`@("1C
M;V]K:65;)W9A;'5E)UT@/2!T<FEM*'-U8G-T<B@D:&5A9&5R=F%L=64L("1P
M;W,@*R`Q*2D["@H@("`@("`@("\O(%-O;64@;W!T:6]N86P@<&%R86UE=&5R
M<R!A<F4@<W5P<&QI960*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M96QE;65N=',@/2!E>'!L;V1E*"<[)RP@)&AE861E<G9A;'5E*3L*("`@("`@
M("`@("`@)'!O<R`]('-T<G!O<R@D96QE;65N='-;,%TL("<])RD["B`@("`@
M("`@("`@("1C;V]K:65;)VYA;64G72`@/2!T<FEM*'-U8G-T<B@D96QE;65N
M='-;,%TL(#`L("1P;W,I*3L*("`@("`@("`@("`@)&-O;VMI95LG=F%L=64G
M72`]('1R:6TH<W5B<W1R*"1E;&5M96YT<ULP72P@)'!O<R`K(#$I*3L*"B`@
M("`@("`@("`@(&9O<B`H)&D@/2`Q.R`D:2`\(&-O=6YT*"1E;&5M96YT<RD[
M("1I*RLI('L*("`@("`@("`@("`@("`@(&EF("AF86QS92`]/3T@<W1R<&]S
M*"1E;&5M96YT<ULD:5TL("<])RDI('L*("`@("`@("`@("`@("`@("`@("`D
M96Q.86UE("`]('1R:6TH)&5L96UE;G1S6R1I72D["B`@("`@("`@("`@("`@
M("`@("`@)&5L5F%L=64@/2!N=6QL.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("!L:7-T("@D96Q.86UE+"`D96Q686QU
M92D@/2!A<G)A>5]M87`H)W1R:6TG+"!E>'!L;V1E*"<])RP@)&5L96UE;G1S
M6R1I72DI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&5L
M3F%M92`]('-T<G1O;&]W97(H)&5L3F%M92D["B`@("`@("`@("`@("`@("!I
M9B`H)W-E8W5R92<@/3T@)&5L3F%M92D@>PH@("`@("`@("`@("`@("`@("`@
M("1C;V]K:65;)W-E8W5R92==(#T@=')U93L*("`@("`@("`@("`@("`@('T@
M96QS96EF("@G97AP:7)E<R<@/3T@)&5L3F%M92D@>PH@("`@("`@("`@("`@
M("`@("`@("1C;V]K:65;)V5X<&ER97,G72`]('-T<E]R97!L86-E*"<B)RP@
M)R<L("1E;%9A;'5E*3L*("`@("`@("`@("`@("`@('T@96QS96EF("@G<&%T
M:"<@/3T@)&5L3F%M92!\?"`G9&]M86EN)R`]/2`D96Q.86UE*2!["B`@("`@
M("`@("`@("`@("`@("`@)&-O;VMI95LD96Q.86UE72`]('5R;&1E8V]D92@D
M96Q686QU92D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1C;V]K:65;)&5L3F%M95T@/2`D96Q686QU93L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D
M=&AI<RT^7V-O;VMI97-;72`]("1C;V]K:64["B`@("!]"@H*("`@+RHJ"B`@
M("`J(%)E860@82!P87)T(&]F(')E<W!O;G-E(&)O9'D@96YC;V1E9"!W:71H
M(&-H=6YK960@5')A;G-F97(M16YC;V1I;F<*("`@("H@"B`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@*B!`<F5T=7)N('-T<FEN9PH@("`@*B\*("`@(&9U
M;F-T:6]N(%]R96%D0VAU;FME9"@I"B`@("!["B`@("`@("`@+R\@870@<W1A
M<G0@;V8@=&AE(&YE>'0@8VAU;FL_"B`@("`@("`@:68@*#`@/3T@)'1H:7,M
M/E]C:'5N:TQE;F=T:"D@>PH@("`@("`@("`@("`D;&EN92`]("1T:&ES+3Y?
M<V]C:RT^<F5A9$QI;F4H*3L*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H
M)R]>*%LP+3EA+69=*RDO:2<L("1L:6YE+"`D;6%T8VAE<RDI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?8VAU;FM,96YG=&@@/2!H97AD96,H)&UA=&-H
M97-;,5TI.R`*("`@("`@("`@("`@("`@("\O($-H=6YK('=I=&@@>F5R;R!L
M96YG=&@@:6YD:6-A=&5S('1H92!E;F0*("`@("`@("`@("`@("`@(&EF("@P
M(#T]("1T:&ES+3Y?8VAU;FM,96YG=&@I('L*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W-O8VLM/G)E861,:6YE*"D[("\O(&UA:V4@=&AI<R!A;B!E
M;V8H*0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M(')E='5R;B`G)SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D
M9&%T82`]("1T:&ES+3Y?<V]C:RT^<F5A9"@D=&AI<RT^7V-H=6YK3&5N9W1H
M*3L*("`@("`@("`D=&AI<RT^7V-H=6YK3&5N9W1H("T]('-T<FQE;B@D9&%T
M82D["B`@("`@("`@:68@*#`@/3T@)'1H:7,M/E]C:'5N:TQE;F=T:"D@>PH@
M("`@("`@("`@("`D=&AI<RT^7W-O8VLM/G)E861,:6YE*"D[("\O(%1R86EL
M:6YG($-23$8*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1D871A.PH@("`@
M?0H*"B`@("\J*@H@("`@*B!.;W1I9FEE<R!A;&P@<F5G:7-T97)E9"!L:7-T
M96YE<G,@;V8@86X@979E;G0N"B`@("`J(`H@("`@*B!`<&%R86T@("`@<W1R
M:6YG("!%=F5N="!N86UE"B`@("`J($!P87)A;2`@("!M:7AE9"`@($%D9&ET
M:6]N86P@9&%T80H@("`@*B!`86-C97-S("`@<')I=F%T90H@("`@*B!`<V5E
M($A45%!?4F5Q=65S=#HZ7VYO=&EF>2@I"B`@("`J+PH@("`@9G5N8W1I;VX@
M7VYO=&EF>2@D979E;G0L("1D871A(#T@;G5L;"D*("`@('L*("`@("`@("!F
M;W)E86-H("AA<G)A>5]K97ES*"1T:&ES+3Y?;&ES=&5N97)S*2!A<R`D:60I
M('L*("`@("`@("`@("`@)'1H:7,M/E]L:7-T96YE<G-;)&ED72T^=7!D871E
M*"1T:&ES+"`D979E;G0L("1D871A*3L*("`@("`@("!]"B`@("!]"GT@+R\@
M16YD(&-L87-S($A45%!?4F5S<&]N<V4*/SX*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]-86EL````````````````````````
M````````````````````````````````````````````````````````````
M`````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U
M-#,S-S,S(#`Q-S(W,0`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+TUA:6PO
M;6EM941E8V]D92YP:'``````````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P-S0V-38@,3`U,34T,S,W,S,@,#(R,3,V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J('9I;3H@<V5T
M(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P
M/30Z("HO"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#
M;W!Y<FEG:'0@*&,I(#(P,#(M,C`P,R`@4FEC:&%R9"!(97EE<R`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($-O<'ER:6=H="`H8RD@
M,C`P,RTR,#`U("!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O('P@06QL(')I9VAT<R!R97-E<G9E9"X@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(%)E9&ES=')I
M8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I
M=&@@;W(@=VET:&]U="`@("!\"B\O('P@;6]D:69I8V%T:6]N+"!A<F4@<&5R
M;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS
M("`@('P*+R\@?"!A<F4@;65T.B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@;R!2961I<W1R:6)U=&EO
M;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E(&-O<'ER
M:6=H="`@("`@('P*+R\@?"`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I
M=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX@("`@("`@?`HO
M+R!\(&\@4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P
M<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0@("!\"B\O('P@("!N;W1I8V4L
M('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I
M<V-L86EM97(@:6X@=&AE('P*+R\@?"`@(&1O8W5M96YT871I;VX@86YD+V]R
M(&]T:&5R(&UA=&5R:6%L<R!P<F]V:61E9"!W:71H('1H92!D:7-T<FEB=71I
M;VXN?`HO+R!\(&\@5&AE(&YA;65S(&]F('1H92!A=71H;W)S(&UA>2!N;W0@
M8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@("`@("!\"B\O('P@("!P
M<F]D=6-T<R!D97)I=F5D(&9R;VT@=&AI<R!S;V9T=V%R92!W:71H;W5T('-P
M96-I9FEC('!R:6]R('=R:71T96X@('P*+R\@?"`@('!E<FUI<W-I;VXN("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M('P@5$A)4R!33T945T%212!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4
M($A/3$1%4E,@04Y$($-/3E1224)55$]24R`@('P*+R\@?"`B05,@25,B($%.
M1"!!3ED@15A04D534R!/4B!)35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.
M1RP@0E54($Y/5"`@("`@?`HO+R!\($Q)34E4140@5$\L(%1(12!)35!,245$
M(%=!4E)!3E1)15,@3T8@34520TA!3E1!0DE,2519($%.1"!&251.15-3($9/
M4B!\"B\O('P@02!005)424-53$%2(%!54E!/4T4@05)%($1)4T-,04E-140N
M($E.($Y/($5614Y4(%-(04Q,(%1(12!#3U!94DE'2%0@('P*+R\@?"!/5TY%
M4B!/4B!#3TY44DE"551/4E,@0D4@3$E!0DQ%($9/4B!!3ED@1$E214-4+"!)
M3D1)4D5#5"P@24Y#241%3E1!3"P@?`HO+R!\(%-014-)04PL($5814U03$%2
M62P@3U(@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,541)3D<L($)55"!.
M3U0@("`@("!\"B\O('P@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8@4U5"
M4U1)5%5412!'3T]$4R!/4B!315)624-%4SL@3$]34R!/1B!54T4L('P*+R\@
M?"!$051!+"!/4B!04D]&2513.R!/4B!"55-)3D534R!)3E1%4E)54%1)3TXI
M($A/5T5615(@0T%54T5$($%.1"!/3B!!3ED@?`HO+R!\(%1(14]262!/1B!,
M24%"24Q)5%DL(%=(151(15(@24X@0T].5%)!0U0L(%-44DE#5"!,24%"24Q)
M5%DL($]2(%1/4E0@("!\"B\O('P@*$E.0TQ51$E.1R!.14=,24=%3D-%($]2
M($]42$525TE312D@05))4TE.1R!)3B!!3ED@5T%9($]55"!/1B!42$4@55-%
M('P*+R\@?"!/1B!42$E3(%-/1E1705)%+"!%5D5.($E&($%$5DE3140@3T8@
M5$A%(%!/4U-)0DE,2519($]&(%-50T@@1$%-04=%+B`@?`HO+R!\("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!!=71H;W(Z(%)I8VAA<F0@2&5Y97,@/')I8VAA<F1`
M<&AP9W5R=2YO<F<^("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"@IR97%U:7)E7V]N8V4@)U!%
M05(N<&AP)SL*"B\J*@HJ("`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2T@24U03U)404Y4("TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M*B`@?"!5<V%G92!O9B!T:&ES(&-L87-S(&-O;7!A<F5D('1O(&YA=&EV92!P
M:'`@97AT96YS:6]N<R!S=6-H(&%S("`@("`@("!\"BH@('P@;6%I;'!A<G-E
M(&]R(&EM87`L(&ES('-L;W<@86YD(&UA>2!B92!F96%T=7)E(&1E9FEC:65N
M="X@268@879A:6QA8FQE?`HJ("!\('EO=2!A<F4@4U123TY'3%D@<F5C;VUM
M96YD960@=&\@=7-E('1H92!P:'`@97AT96YS:6]N<RX@("`@("`@("`@("`@
M('P**B`@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"BH**B!-:6UE($1E
M8V]D:6YG(&-L87-S"BH**B!4:&ES(&-L87-S('=I;&P@<&%R<V4@82!R87<@
M;6EM92!E;6%I;"!A;F0@<F5T=7)N"BH@=&AE('-T<G5C='5R92X@4F5T=7)N
M960@<W1R=6-T=7)E(&ES('-I;6EL87(@=&\**B!T:&%T(')E='5R;F5D(&)Y
M(&EM87!?9F5T8VAS=')U8W1U<F4H*2X**@HJ(%5304=%.B`H87-S=6UE("1I
M;G!U="!I<R!Y;W5R(')A=R!E;6%I;"D**@HJ("1D96-O9&4@/2!N97<@36%I
M;%]M:6UE1&5C;V1E*"1I;G!U="P@(EQR7&XB*3L**B`D<W1R=6-T=7)E(#T@
M)&1E8V]D92T^9&5C;V1E*"D["BH@<')I;G1?<B@D<W1R=6-T=7)E*3L**@HJ
M($]R('-T871I8V%L;'DZ"BH**B`D<&%R86US6R=I;G!U="==(#T@)&EN<'5T
M.PHJ("1S=')U8W1U<F4@/2!-86EL7VUI;65$96-O9&4Z.F1E8V]D92@D<&%R
M86US*3L**B!P<FEN=%]R*"1S=')U8W1U<F4I.PHJ"BH@5$]$3SH**B`@;R!)
M;7!L96UE;G0@;75L=&EP87)T+V%P<&QE9&]U8FQE"BH@(&\@551&.#H@/S\_
M"@H)"3X@-"X@5V4@:&%V92!A;'-O(&9O=6YD(&$@<V]L=71I;VX@9F]R(&1E
M8V]D:6YG('1H92!55$8M."`*"0D^(&AE861E<G,N(%1H97)E9F]R92!)(&UA
M9&4@=&AE(&9O;&QO=VEN9R!F=6YC=&EO;CH*"0D^(`H)"3X@9G5N8W1I;VX@
M9&5C;V1E7W5T9C@H)'1X="D@>PH)"3X@)'1R86YS/6%R<F%Y*"+%)B,X,C$V
M.R(]/B+#M2(L(L6Q(CT^(L.[(BPBQ9`B/3XBPR8C.#(R-CLB+"+%L"(*"0D]
M/B+#)B,X,C4P.R(I.PH)"3X@)'1X=#US=')T<B@D='AT+"1T<F%N<RD["@D)
M/B!R971U<FXH=71F.%]D96-O9&4H)'1X="DI.PH)"3X@?0H)"3X@"@D)/B!!
M;F0@22!H879E(&EN<V5R=&5D('1H92!F;VQL;W=I;F<@;&EN92!T;R!T:&4@
M8VQA<W,Z"@D)/B`*"0D^(&EF("AS=')T;VQO=V5R*"1C:&%R<V5T*3T](G5T
M9BTX(BD@)'1E>'0]9&5C;V1E7W5T9C@H)'1E>'0I.PH)"3X@"@D)/B`N+BX@
M8F5F;W)E('1H92!F;VQL;W=I;F<@;VYE(&EN('1H92`B7V1E8V]D94AE861E
M<B(@9G5N8W1I;VXZ"@D)/B`*"0D^("1I;G!U="`]('-T<E]R97!L86-E*"1E
M;F-O9&5D+"`D=&5X="P@)&EN<'5T*3L*"0D^(`H)"3X@5&AI<R!W87D@9G)O
M;2!N;W<@;VX@:70@8V%N(&5A<VEL>2!D96-O9&4@=&AE(%541BTX(&AE861E
M<G,@=&]O+@H**@HJ($!A=71H;W(@(%)I8VAA<F0@2&5Y97,@/')I8VAA<F1`
M<&AP9W5R=2YO<F<^"BH@0'9E<G-I;VX@)%)E=FES:6]N.B`Q+C0V("0**B!`
M<&%C:V%G92!-86EL"BHO"F-L87-S($UA:6Q?;6EM941E8V]D92!E>'1E;F1S
M(%!%05(*>PH@("`@+RHJ"B`@("`@*B!4:&4@<F%W(&5M86EL('1O(&1E8V]D
M90H@("`@("H@0'9A<B`@("!S=')I;F<*("`@("`J+PH@("`@=F%R("1?:6YP
M=70["@H@("`@+RHJ"B`@("`@*B!4:&4@:&5A9&5R('!A<G0@;V8@=&AE(&EN
M<'5T"B`@("`@*B!`=F%R("`@('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]H
M96%D97(["@H@("`@+RHJ"B`@("`@*B!4:&4@8F]D>2!P87)T(&]F('1H92!I
M;G!U=`H@("`@("H@0'9A<B`@("!S=')I;F<*("`@("`J+PH@("`@=F%R("1?
M8F]D>3L*"B`@("`O*BH*("`@("`J($EF(&%N(&5R<F]R(&]C8W5R<RP@=&AI
M<R!I<R!U<V5D('1O('-T;W)E('1H92!M97-S86=E"B`@("`@*B!`=F%R("`@
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]E<G)O<CL*"B`@("`O*BH*("`@
M("`J($9L86<@=&\@9&5T97)M:6YE('=H971H97(@=&\@:6YC;'5D92!B;V1I
M97,@:6X@=&AE"B`@("`@*B!R971U<FYE9"!O8FIE8W0N"B`@("`@*B!`=F%R
M("`@(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?:6YC;'5D95]B;V1I97,[
M"@H@("`@+RHJ"B`@("`@*B!&;&%G('1O(&1E=&5R;6EN92!W:&5T:&5R('1O
M(&1E8V]D92!B;V1I97,*("`@("`J($!V87(@("`@8F]O;&5A;@H@("`@("HO
M"B`@("!V87(@)%]D96-O9&5?8F]D:65S.PH*("`@("\J*@H@("`@("H@1FQA
M9R!T;R!D971E<FUI;F4@=VAE=&AE<B!T;R!D96-O9&4@:&5A9&5R<PH@("`@
M("H@0'9A<B`@("!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7V1E8V]D95]H
M96%D97)S.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@
M("`@("H@4V5T<R!U<"!T:&4@;V)J96-T+"!I;FET:6%L:7-E('1H92!V87)I
M86)L97,L(&%N9"!S<&QI=',@86YD"B`@("`@*B!S=&]R97,@=&AE(&AE861E
M<B!A;F0@8F]D>2!O9B!T:&4@:6YP=70N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R!4:&4@:6YP=70@=&\@9&5C;V1E"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!-86EL7VUI;65$96-O9&4H)&EN
M<'5T*0H@("`@>PH@("`@("`@(&QI<W0H)&AE861E<BP@)&)O9'DI("`@/2`D
M=&AI<RT^7W-P;&ET0F]D>4AE861E<B@D:6YP=70I.PH*("`@("`@("`D=&AI
M<RT^7VEN<'5T("`@("`@("`@(#T@)&EN<'5T.PH@("`@("`@("1T:&ES+3Y?
M:&5A9&5R("`@("`@("`@/2`D:&5A9&5R.PH@("`@("`@("1T:&ES+3Y?8F]D
M>2`@("`@("`@("`@/2`D8F]D>3L*("`@("`@("`D=&AI<RT^7V1E8V]D95]B
M;V1I97,@(#T@9F%L<V4["B`@("`@("`@)'1H:7,M/E]I;F-L=61E7V)O9&EE
M<R`]('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!"96=I;G,@=&AE(&1E
M8V]D:6YG('!R;V-E<W,N($EF(&-A;&QE9"!S=&%T:6-A;&QY"B`@("`@*B!I
M="!W:6QL(&-R96%T92!A;B!O8FIE8W0@86YD(&-A;&P@=&AE(&1E8V]D92@I
M(&UE=&AO9`H@("`@("H@;V8@:70N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R
M<F%Y($%N(&%R<F%Y(&]F('9A<FEO=7,@<&%R86UE=&5R<R!T:&%T(&1E=&5R
M;6EN90H@("`@("H@("`@("`@("`@("`@('9A<FEO=7,@=&AI;F=S.@H@("`@
M("H@("`@("`@("`@("`@(&EN8VQU9&5?8F]D:65S("T@5VAE=&AE<B!T;R!I
M;F-L=61E('1H92!B;V1Y(&EN('1H92!R971U<FYE9`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@;V)J96-T+@H@("`@("H@("`@("`@
M("`@("`@(&1E8V]D95]B;V1I97,@("T@5VAE=&AE<B!T;R!D96-O9&4@=&AE
M(&)O9&EE<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M;V8@=&AE('!A<G1S+B`H5')A;G-F97(@96YC;V1I;F<I"B`@("`@*B`@("`@
M("`@("`@("`@9&5C;V1E7VAE861E<G,@+2!7:&5T:&5R('1O(&1E8V]D92!H
M96%D97)S"B`@("`@*B`@("`@("`@("`@("`@:6YP=70@("`@("`@("`@+2!)
M9B!C86QL960@<W1A=&EC86QL>2P@=&AI<R!W:6QL(&)E('1R96%T960*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%S('1H92!I;G!U
M=`H@("`@("H@0')E='5R;B!O8FIE8W0@1&5C;V1E9"!R97-U;'1S"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!D96-O9&4H
M)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@+R\@9&5T97)M:6YE(&EF
M('1H:7,@;65T:&]D(&AA<R!B965N(&-A;&QE9"!S=&%T:6-A;&QY"B`@("`@
M("`@)&ES4W1A=&EC(#T@(2AI<W-E="@D=&AI<RD@)B8@9V5T7V-L87-S*"1T
M:&ES*2`]/2!?7T-,05-37U\I.PH*("`@("`@("`O+R!(879E('=E(&)E96X@
M8V%L;&5D('-T871I8V%L;'D_"@DO+R!)9B!S;RP@8W)E871E(&%N(&]B:F5C
M="!A;F0@<&%S<R!D971A:6QS('1O('1H870N"B`@("`@("`@:68@*"1I<U-T
M871I8R!!3D0@:7-S970H)'!A<F%M<ULG:6YP=70G72DI('L*"B`@("`@("`@
M("`@("1O8FH@/2!N97<@36%I;%]M:6UE1&5C;V1E*"1P87)A;7-;)VEN<'5T
M)UTI.PH@("`@("`@("`@("`D<W1R=6-T=7)E(#T@)&]B:BT^9&5C;V1E*"1P
M87)A;7,I.PH*("`@("`@("`O+R!#86QL960@<W1A=&EC86QL>2!B=70@;F\@
M:6YP=70*("`@("`@("!](&5L<V5I9B`H)&ES4W1A=&EC*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=#86QL960@<W1A=&EC86QL
M>2!A;F0@;F\@:6YP=70@9VEV96XG*3L*"B`@("`@("`@+R\@0V%L;&5D('9I
M82!A;B!O8FIE8W0*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI
M<RT^7VEN8VQU9&5?8F]D:65S(#T@:7-S970H)'!A<F%M<ULG:6YC;'5D95]B
M;V1I97,G72D@/PH)("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%R
M86US6R=I;F-L=61E7V)O9&EE<R==(#H@9F%L<V4["B`@("`@("`@("`@("1T
M:&ES+3Y?9&5C;V1E7V)O9&EE<R`@/2!I<W-E="@D<&%R86US6R=D96-O9&5?
M8F]D:65S)UTI(#\*"2`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A
M<F%M<ULG9&5C;V1E7V)O9&EE<R==("`Z(&9A;'-E.PH@("`@("`@("`@("`D
M=&AI<RT^7V1E8V]D95]H96%D97)S(#T@:7-S970H)'!A<F%M<ULG9&5C;V1E
M7VAE861E<G,G72D@/PH)("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<&%R86US6R=D96-O9&5?:&5A9&5R<R==(#H@9F%L<V4["@H@("`@("`@("`@
M("`D<W1R=6-T=7)E(#T@)'1H:7,M/E]D96-O9&4H)'1H:7,M/E]H96%D97(L
M("1T:&ES+3Y?8F]D>2D["B`@("`@("`@("`@(&EF("@D<W1R=6-T=7)E(#T]
M/2!F86QS92D@>PH@("`@("`@("`@("`@("`@)'-T<G5C='5R92`]("1T:&ES
M+3YR86ES945R<F]R*"1T:&ES+3Y?97)R;W(I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)'-T<G5C='5R93L*("`@('T*"B`@
M("`O*BH*("`@("`J(%!E<F9O<FUS('1H92!D96-O9&EN9RX@1&5C;V1E<R!T
M:&4@8F]D>2!S=')I;F<@<&%S<V5D('1O(&ET"B`@("`@*B!)9B!I="!F:6YD
M<R!C97)T86EN(&-O;G1E;G0M='EP97,@:70@=VEL;"!C86QL(&ET<V5L9B!I
M;B!A"B`@("`@*B!R96-U<G-I=F4@9F%S:&EO;@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@2&5A9&5R('-E8W1I;VX*("`@("`J($!P87)A;2!S=')I
M;F<@0F]D>2!S96-T:6]N"B`@("`@*B!`<F5T=7)N(&]B:F5C="!297-U;'1S
M(&]F(&1E8V]D:6YG('!R;V-E<W,*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("HO"B`@("!F=6YC=&EO;B!?9&5C;V1E*"1H96%D97)S+"`D8F]D>2P@
M)&1E9F%U;'1?8W1Y<&4@/2`G=&5X="]P;&%I;B<I"B`@("!["B`@("`@("`@
M)')E='5R;B`](&YE=R!S=&1#;&%S<SL*("`@("`@("`D<F5T=7)N+3YH96%D
M97)S(#T@87)R87DH*3L*("`@("`@("`D:&5A9&5R<R`]("1T:&ES+3Y?<&%R
M<V5(96%D97)S*"1H96%D97)S*3L*"B`@("`@("`@9F]R96%C:"`H)&AE861E
M<G,@87,@)'9A;'5E*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D<F5T=7)N
M+3YH96%D97)S6W-T<G1O;&]W97(H)'9A;'5E6R=N86UE)UTI72D@04Y$("%I
M<U]A<G)A>2@D<F5T=7)N+3YH96%D97)S6W-T<G1O;&]W97(H)'9A;'5E6R=N
M86UE)UTI72DI('L*("`@("`@("`@("`@("`@("1R971U<FXM/FAE861E<G-;
M<W1R=&]L;W=E<B@D=F%L=65;)VYA;64G72E=("`@/2!A<G)A>2@D<F5T=7)N
M+3YH96%D97)S6W-T<G1O;&]W97(H)'9A;'5E6R=N86UE)UTI72D["B`@("`@
M("`@("`@("`@("`D<F5T=7)N+3YH96%D97)S6W-T<G1O;&]W97(H)'9A;'5E
M6R=N86UE)UTI75M=(#T@)'9A;'5E6R=V86QU92==.PH*("`@("`@("`@("`@
M?2!E;'-E:68@*&ES<V5T*"1R971U<FXM/FAE861E<G-;<W1R=&]L;W=E<B@D
M=F%L=65;)VYA;64G72E=*2D@>PH@("`@("`@("`@("`@("`@)')E='5R;BT^
M:&5A9&5R<UMS=')T;VQO=V5R*"1V86QU95LG;F%M92==*5U;72`]("1V86QU
M95LG=F%L=64G73L*"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D<F5T=7)N+3YH96%D97)S6W-T<G1O;&]W97(H)'9A;'5E6R=N86UE
M)UTI72`]("1V86QU95LG=F%L=64G73L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5S970H)&AE861E<G,I.PH@("`@("`@('=H:6QE("AL
M:7-T*"1K97DL("1V86QU92D@/2!E86-H*"1H96%D97)S*2D@>PH@("`@("`@
M("`@("`D:&5A9&5R<ULD:V5Y75LG;F%M92==(#T@<W1R=&]L;W=E<B@D:&5A
M9&5R<ULD:V5Y75LG;F%M92==*3L*("`@("`@("`@("`@<W=I=&-H("@D:&5A
M9&5R<ULD:V5Y75LG;F%M92==*2!["@H@("`@("`@("`@("`@("`@8V%S92`G
M8V]N=&5N="UT>7!E)SH*("`@("`@("`@("`@("`@("`@("`D8V]N=&5N=%]T
M>7!E(#T@)'1H:7,M/E]P87)S94AE861E<E9A;'5E*"1H96%D97)S6R1K97E=
M6R=V86QU92==*3L*"B`@("`@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T
M8V@H)R\H6S`M.6$M>BLN+5TK*5PO*%LP+3EA+7HK+BU=*RDO:2<L("1C;VYT
M96YT7W1Y<&5;)W9A;'5E)UTL("1R96=S*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D<F5T=7)N+3YC='EP95]P<FEM87)Y("`@/2`D<F5G<ULQ73L*
M("`@("`@("`@("`@("`@("`@("`@("`@)')E='5R;BT^8W1Y<&5?<V5C;VYD
M87)Y(#T@)')E9W-;,ET["B`@("`@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)&-O;G1E;G1?='EP95LG;W1H97(G
M72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@=VAI;&4@*&QI<W0H)'!?
M;F%M92P@)'!?=F%L=64I(#T@96%C:"@D8V]N=&5N=%]T>7!E6R=O=&AE<B==
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E='5R;BT^8W1Y
M<&5?<&%R86UE=&5R<ULD<%]N86UE72`]("1P7W9A;'5E.PH@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)V-O
M;G1E;G0M9&ES<&]S:71I;VXG.@H@("`@("`@("`@("`@("`@("`@("1C;VYT
M96YT7V1I<W!O<VET:6]N(#T@)'1H:7,M/E]P87)S94AE861E<E9A;'5E*"1H
M96%D97)S6R1K97E=6R=V86QU92==*3L*("`@("`@("`@("`@("`@("`@("`D
M<F5T=7)N+3YD:7-P;W-I=&EO;B`@(#T@)&-O;G1E;G1?9&ES<&]S:71I;VY;
M)W9A;'5E)UT["B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1C;VYT
M96YT7V1I<W!O<VET:6]N6R=O=&AE<B==*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("!W:&EL92`H;&ES="@D<%]N86UE+"`D<%]V86QU92D@/2!E86-H
M*"1C;VYT96YT7V1I<W!O<VET:6]N6R=O=&AE<B==*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)')E='5R;BT^9%]P87)A;65T97)S6R1P7VYA
M;65=(#T@)'!?=F%L=64["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("`@("`@8V%S92`G8V]N=&5N="UT<F%N<V9E<BUE;F-O
M9&EN9R<Z"B`@("`@("`@("`@("`@("`@("`@)&-O;G1E;G1?=')A;G-F97)?
M96YC;V1I;F<@/2`D=&AI<RT^7W!A<G-E2&5A9&5R5F%L=64H)&AE861E<G-;
M)&ME>5U;)W9A;'5E)UTI.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)&-O
M;G1E;G1?='EP92DI('L*("`@("`@("`@("`@<W=I=&-H("AS=')T;VQO=V5R
M*"1C;VYT96YT7W1Y<&5;)W9A;'5E)UTI*2!["B`@("`@("`@("`@("`@("!C
M87-E("=T97AT+W!L86EN)SH*("`@("`@("`@("`@("`@("`@("`D96YC;V1I
M;F<@/2!I<W-E="@D8V]N=&5N=%]T<F%N<V9E<E]E;F-O9&EN9RD@/R`D8V]N
M=&5N=%]T<F%N<V9E<E]E;F-O9&EN9ULG=F%L=64G72`Z("<W8FET)SL*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7VEN8VQU9&5?8F]D:65S(#\@)')E
M='5R;BT^8F]D>2`]("@D=&AI<RT^7V1E8V]D95]B;V1I97,@/R`D=&AI<RT^
M7V1E8V]D94)O9'DH)&)O9'DL("1E;F-O9&EN9RD@.B`D8F]D>2D@.B!N=6QL
M.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@
M(&-A<V4@)W1E>'0O:'1M;"<Z"B`@("`@("`@("`@("`@("`@("`@)&5N8V]D
M:6YG(#T@:7-S970H)&-O;G1E;G1?=')A;G-F97)?96YC;V1I;F<I(#\@)&-O
M;G1E;G1?=')A;G-F97)?96YC;V1I;F=;)W9A;'5E)UT@.B`G-V)I="<["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I;F-L=61E7V)O9&EE<R`_("1R
M971U<FXM/F)O9'D@/2`H)'1H:7,M/E]D96-O9&5?8F]D:65S(#\@)'1H:7,M
M/E]D96-O9&5";V1Y*"1B;V1Y+"`D96YC;V1I;F<I(#H@)&)O9'DI(#H@;G5L
M;#L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@
M("!C87-E("=M=6QT:7!A<G0O<&%R86QL96PG.@H@("`@("`@("`@("`@("`@
M8V%S92`G;75L=&EP87)T+W)E<&]R="<Z("\O(%)&0S$X.3(*("`@("`@("`@
M("`@("`@(&-A<V4@)VUU;'1I<&%R="]S:6=N960G.B`O+R!01U`*("`@("`@
M("`@("`@("`@(&-A<V4@)VUU;'1I<&%R="]D:6=E<W0G.@H@("`@("`@("`@
M("`@("`@8V%S92`G;75L=&EP87)T+V%L=&5R;F%T:79E)SH*("`@("`@("`@
M("`@("`@(&-A<V4@)VUU;'1I<&%R="]R96QA=&5D)SH*("`@("`@("`@("`@
M("`@(&-A<V4@)VUU;'1I<&%R="]M:7AE9"<Z"B`@("`@("`@("`@("`@("`@
M("`@:68H(6ES<V5T*"1C;VYT96YT7W1Y<&5;)V]T:&5R)UU;)V)O=6YD87)Y
M)UTI*7L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]E<G)O<B`]
M("=.;R!B;W5N9&%R>2!F;W5N9"!F;W(@)R`N("1C;VYT96YT7W1Y<&5;)W9A
M;'5E)UT@+B`G('!A<G0G.PH@("`@("`@("`@("`@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@("`@("`D9&5F875L=%]C='EP92`]("AS=')T;VQO=V5R*"1C;VYT96YT
M7W1Y<&5;)W9A;'5E)UTI(#T]/2`G;75L=&EP87)T+V1I9V5S="<I(#\@)VUE
M<W-A9V4O<F9C.#(R)R`Z("=T97AT+W!L86EN)SL*"B`@("`@("`@("`@("`@
M("`@("`@)'!A<G1S(#T@)'1H:7,M/E]B;W5N9&%R>5-P;&ET*"1B;V1Y+"`D
M8V]N=&5N=%]T>7!E6R=O=&AE<B==6R=B;W5N9&%R>2==*3L*("`@("`@("`@
M("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D<&%R=',I.R`D
M:2LK*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&QI<W0H)'!A<G1?:&5A
M9&5R+"`D<&%R=%]B;V1Y*2`]("1T:&ES+3Y?<W!L:71";V1Y2&5A9&5R*"1P
M87)T<ULD:5TI.PH@("`@("`@("`@("`@("`@("`@("`@("`D<&%R="`]("1T
M:&ES+3Y?9&5C;V1E*"1P87)T7VAE861E<BP@)'!A<G1?8F]D>2P@)&1E9F%U
M;'1?8W1Y<&4I.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B@D<&%R="`]
M/3T@9F%L<V4I"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%R="`]
M("1T:&ES+3YR86ES945R<F]R*"1T:&ES+3Y?97)R;W(I.PH@("`@("`@("`@
M("`@("`@("`@("`@("`D<F5T=7)N+3YP87)T<UM=(#T@)'!A<G0["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@("`@(&-A<V4@)VUE<W-A9V4O<F9C.#(R)SH*("`@("`@
M("`@("`@("`@("`@("`D;V)J(#T@)FYE=R!-86EL7VUI;65$96-O9&4H)&)O
M9'DI.PH@("`@("`@("`@("`@("`@("`@("1R971U<FXM/G!A<G1S6UT@/2`D
M;V)J+3YD96-O9&4H87)R87DH)VEN8VQU9&5?8F]D:65S)R`]/B`D=&AI<RT^
M7VEN8VQU9&5?8F]D:65S+`H)"0D)"2`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V1E8V]D95]B;V1I97,G("`]/B`D=&AI<RT^7V1E
M8V]D95]B;V1I97,L"@D)"0D)"0D)"0D)"0D)("`G9&5C;V1E7VAE861E<G,G
M(#T^("1T:&ES+3Y?9&5C;V1E7VAE861E<G,I*3L*("`@("`@("`@("`@("`@
M("`@("!U;G-E="@D;V)J*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@("`@
M(&EF*"%I<W-E="@D8V]N=&5N=%]T<F%N<V9E<E]E;F-O9&EN9ULG=F%L=64G
M72DI"B`@("`@("`@("`@("`@("`@("`@("`@("1C;VYT96YT7W1R86YS9F5R
M7V5N8V]D:6YG6R=V86QU92==(#T@)S=B:70G.PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?:6YC;'5D95]B;V1I97,@/R`D<F5T=7)N+3YB;V1Y(#T@
M*"1T:&ES+3Y?9&5C;V1E7V)O9&EE<R`_("1T:&ES+3Y?9&5C;V1E0F]D>2@D
M8F]D>2P@)&-O;G1E;G1?=')A;G-F97)?96YC;V1I;F=;)W9A;'5E)UTI(#H@
M)&)O9'DI(#H@;G5L;#L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@?0H*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D8W1Y
M<&4@/2!E>'!L;V1E*"<O)RP@)&1E9F%U;'1?8W1Y<&4I.PH@("`@("`@("`@
M("`D<F5T=7)N+3YC='EP95]P<FEM87)Y("`@/2`D8W1Y<&5;,%T["B`@("`@
M("`@("`@("1R971U<FXM/F-T>7!E7W-E8V]N9&%R>2`]("1C='EP95LQ73L*
M("`@("`@("`@("`@)'1H:7,M/E]I;F-L=61E7V)O9&EE<R`_("1R971U<FXM
M/F)O9'D@/2`H)'1H:7,M/E]D96-O9&5?8F]D:65S(#\@)'1H:7,M/E]D96-O
M9&5";V1Y*"1B;V1Y*2`Z("1B;V1Y*2`Z(&YU;&P["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)')E='5R;CL*("`@('T*"B`@("`O*BH*("`@("`J($=I
M=F5N('1H92!O=71P=70@;V8@=&AE(&%B;W9E(&9U;F-T:6]N+"!T:&ES('=I
M;&P@<F5T=7)N(&%N"B`@("`@*B!A<G)A>2!O9B!R969E<F5N8V5S('1O('1H
M92!P87)T<RP@:6YD97AE9"!B>2!M:6UE(&YU;6)E<BX*("`@("`J"B`@("`@
M*B!`<&%R86T@(&]B:F5C="`D<W1R=6-T=7)E("`@5&AE('-T<G5C='5R92!T
M;R!G;R!T:')O=6=H"B`@("`@*B!`<&%R86T@('-T<FEN9R`D;6EM95]N=6UB
M97(@26YT97)N86P@=7-E(&]N;'DN"B`@("`@*B!`<F5T=7)N(&%R<F%Y("`@
M("`@("`@("`@("`@36EM92!N=6UB97)S"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9G971-:6UE3G5M8F5R<R@F)'-T<G5C='5R92P@)&YO7W)E9G,@/2!F86QS
M92P@)&UI;65?;G5M8F5R(#T@)R<L("1P<F5P96YD(#T@)R<I"B`@("!["B`@
M("`@("`@)')E='5R;B`](&%R<F%Y*"D["B`@("`@("`@:68@*"%E;7!T>2@D
M<W1R=6-T=7)E+3YP87)T<RDI('L*("`@("`@("`@("`@:68@*"1M:6UE7VYU
M;6)E<B`A/2`G)RD@>PH@("`@("`@("`@("`@("`@)'-T<G5C='5R92T^;6EM
M95]I9"`]("1P<F5P96YD("X@)&UI;65?;G5M8F5R.PH@("`@("`@("`@("`@
M("`@)')E='5R;ELD<')E<&5N9"`N("1M:6UE7VYU;6)E<ET@/2`F)'-T<G5C
M='5R93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!F;W(@*"1I(#T@,#L@
M)&D@/"!C;W5N="@D<W1R=6-T=7)E+3YP87)T<RD[("1I*RLI('L*"B`@("`@
M("`@("`@(`H@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D<W1R=6-T=7)E
M+3YH96%D97)S6R=C;VYT96YT+71Y<&4G72D@04Y$('-U8G-T<BAS=')T;VQO
M=V5R*"1S=')U8W1U<F4M/FAE861E<G-;)V-O;G1E;G0M='EP92==*2P@,"P@
M."D@/3T@)VUE<W-A9V4O)RD@>PH@("`@("`@("`@("`@("`@("`@("1P<F5P
M96YD("`@("`@/2`D<')E<&5N9"`N("1M:6UE7VYU;6)E<B`N("<N)SL*("`@
M("`@("`@("`@("`@("`@("`D7VUI;65?;G5M8F5R(#T@)R<["B`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1?;6EM95]N
M=6UB97(@/2`H)&UI;65?;G5M8F5R(#T]("<G(#\@)&D@*R`Q(#H@<W!R:6YT
M9B@G)7,N)7,G+"`D;6EM95]N=6UB97(L("1I("L@,2DI.PH@("`@("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@("`@("1A<G(@/2`F36%I;%]M:6UE1&5C
M;V1E.CIG971-:6UE3G5M8F5R<R@D<W1R=6-T=7)E+3YP87)T<ULD:5TL("1N
M;U]R969S+"`D7VUI;65?;G5M8F5R+"`D<')E<&5N9"D["B`@("`@("`@("`@
M("`@("!F;W)E86-H("@D87)R(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@
M("`@("`@("`@("`@("1N;U]R969S(#\@)')E='5R;ELD:V5Y72`]("<G(#H@
M)')E='5R;ELD:V5Y72`]("8D87)R6R1K97E=.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M:68@*"1M:6UE7VYU;6)E<B`]/2`G)RD@>PH@("`@("`@("`@("`@("`@)&UI
M;65?;G5M8F5R(#T@)S$G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1S
M=')U8W1U<F4M/FUI;65?:60@/2`D<')E<&5N9"`N("1M:6UE7VYU;6)E<CL*
M("`@("`@("`@("`@)&YO7W)E9G,@/R`D<F5T=7)N6R1P<F5P96YD("X@)&UI
M;65?;G5M8F5R72`]("<G(#H@)')E='5R;ELD<')E<&5N9"`N("1M:6UE7VYU
M;6)E<ET@/2`F)'-T<G5C='5R93L*("`@("`@("!]"B`@("`@("`@"B`@("`@
M("`@<F5T=7)N("1R971U<FX["B`@("!]"@H@("`@+RHJ"B`@("`@*B!':79E
M;B!A('-T<FEN9R!C;VYT86EN:6YG(&$@:&5A9&5R(&%N9"!B;V1Y"B`@("`@
M*B!S96-T:6]N+"!T:&ES(&9U;F-T:6]N('=I;&P@<W!L:70@=&AE;2`H870@
M=&AE(&9I<G-T"B`@("`@*B!B;&%N:R!L:6YE*2!A;F0@<F5T=7)N('1H96TN
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R!);G!U="!T;R!S<&QI="!A
M<&%R=`H@("`@("H@0')E='5R;B!A<G)A>2!#;VYT86EN<R!H96%D97(@86YD
M(&)O9'D@<V5C=&EO;@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]S<&QI=$)O9'E(96%D97(H)&EN<'5T*0H@("`@>PH@
M("`@("`@(&EF("AP<F5G7VUA=&-H*"(O7B@N*C\I7'(_7&Y<<C]<;B@N*BDO
M<R(L("1I;G!U="P@)&UA=&-H*2D@>PH@("`@("`@("`@("!R971U<FX@87)R
M87DH)&UA=&-H6S%=+"`D;6%T8VA;,ETI.PH@("`@("`@('T*("`@("`@("`D
M=&AI<RT^7V5R<F]R(#T@)T-O=6QD(&YO="!S<&QI="!H96%D97(@86YD(&)O
M9'DG.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%!A<G-E(&AE861E<G,@9VEV96X@:6X@)&EN<'5T(&%N9"!R971U<FX*
M("`@("`J(&%S(&%S<V]C(&%R<F%Y+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@2&5A9&5R<R!T;R!P87)S90H@("`@("H@0')E='5R;B!A<G)A>2!#
M;VYT86EN<R!P87)S960@:&5A9&5R<PH@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P87)S94AE861E<G,H)&EN<'5T*0H@
M("`@>PH*("`@("`@("!I9B`H)&EN<'5T("$]/2`G)RD@>PH@("`@("`@("`@
M("`O+R!5;F9O;&0@=&AE(&EN<'5T"B`@("`@("`@("`@("1I;G!U="`@(#T@
M<')E9U]R97!L86-E*"(O7'(_7&XO(BP@(EQR7&XB+"`D:6YP=70I.PH@("`@
M("`@("`@("`D:6YP=70@("`]('!R96=?<F5P;&%C92@B+UQR7&XH7'1\("DK
M+R(L("<@)RP@)&EN<'5T*3L*("`@("`@("`@("`@)&AE861E<G,@/2!E>'!L
M;V1E*")<<EQN(BP@=')I;2@D:6YP=70I*3L*"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1H96%D97)S(&%S("1V86QU92D@>PH@("`@("`@("`@("`@("`@)&AD
M<E]N86UE(#T@<W5B<W1R*"1V86QU92P@,"P@)'!O<R`]('-T<G!O<R@D=F%L
M=64L("<Z)RDI.PH@("`@("`@("`@("`@("`@)&AD<E]V86QU92`]('-U8G-T
M<B@D=F%L=64L("1P;W,K,2D["B`@("`@("`@("`@("`@("!I9B@D:&1R7W9A
M;'5E6S!=(#T]("<@)RD*("`@("`@("`@("`@("`@("`@("`D:&1R7W9A;'5E
M(#T@<W5B<W1R*"1H9')?=F%L=64L(#$I.PH*("`@("`@("`@("`@("`@("1R
M971U<FY;72`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VYA;64G("`]/B`D:&1R7VYA;64L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G=F%L=64G(#T^("1T:&ES+3Y?9&5C;V1E7VAE
M861E<G,@/R`D=&AI<RT^7V1E8V]D94AE861E<B@D:&1R7W9A;'5E*2`Z("1H
M9')?=F%L=64*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R
M971U<FX@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R
M971U<FX["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC=&EO;B!T;R!P87)S
M92!A(&AE861E<B!V86QU92P*("`@("`J(&5X=')A8W0@9FER<W0@<&%R="P@
M86YD(&%N>2!S96-O;F1A<GD*("`@("`J('!A<G1S("AA9G1E<B`[*2!4:&ES
M(&9U;F-T:6]N(&ES(&YO="!A<PH@("`@("H@<F]B=7-T(&%S(&ET(&-O=6QD
M(&)E+B!%9RX@:&5A9&5R(&-O;6UE;G1S"B`@("`@*B!I;B!T:&4@=W)O;F<@
M<&QA8V4@=VEL;"!P<F]B86)L>2!B<F5A:R!I="X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG($AE861E<B!V86QU92!T;R!P87)S90H@("`@("H@0')E
M='5R;B!A<G)A>2!#;VYT86EN<R!P87)S960@<F5S=6QT"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7W!A<G-E2&5A9&5R
M5F%L=64H)&EN<'5T*0H@("`@>PH*("`@("`@("!I9B`H*"1P;W,@/2!S=')P
M;W,H)&EN<'5T+"`G.R<I*2`A/3T@9F%L<V4I('L*"B`@("`@("`@("`@("1R
M971U<FY;)W9A;'5E)UT@/2!T<FEM*'-U8G-T<B@D:6YP=70L(#`L("1P;W,I
M*3L*("`@("`@("`@("`@)&EN<'5T(#T@=')I;2AS=6)S='(H)&EN<'5T+"`D
M<&]S*S$I*3L*"B`@("`@("`@("`@(&EF("AS=')L96XH)&EN<'5T*2`^(#`I
M('L*"B`@("`@("`@("`@("`@("`O+R!4:&ES('-P;&ET<R!O;B!A('-E;6DM
M8V]L;VXL(&EF('1H97)E)W,@;F\@<')E8V5E9&EN9R!B86-K<VQA<V@*("`@
M("`@("`@("`@("`@("\O($YO=R!W;W)K<R!W:71H('%U;W1E9"!V86QU97,[
M(&AA9"!T;R!G;'5E('1H92!<.R!B<F5A:W,@:6X@4$A0"B`@("`@("`@("`@
M("`@("`O+R!T:&4@<F5G97@@:7,@86QR96%D>2!B;W)D97)I;F<@;VX@:6YC
M;VUP<F5H96YS:6)L90H@("`@("`@("`@("`@("`@)'-P;&ET4F5G97@@/2`G
M+RA;7CM<)R)=*EM<)R)=*%M>7"<B72HH6UY<)R)=*BDJ*5M<)R)=6UX[7"<B
M72I\*%M>.UTK*2DH.WPD*2\G.PH@("`@("`@("`@("`@("`@<')E9U]M871C
M:%]A;&PH)'-P;&ET4F5G97@L("1I;G!U="P@)&UA=&-H97,I.PH@("`@("`@
M("`@("`@("`@)'!A<F%M971E<G,@/2!A<G)A>2@I.PH@("`@("`@("`@("`@
M("`@9F]R("@D:3TP.R`D:3QC;W5N="@D;6%T8VAE<ULP72D[("1I*RLI('L*
M("`@("`@("`@("`@("`@("`@("`D<&%R86T@/2`D;6%T8VAE<ULP75LD:5T[
M"B`@("`@("`@("`@("`@("`@("`@=VAI;&4@*'-U8G-T<B@D<&%R86TL("TR
M*2`]/2`G7#LG*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1P87)A;2`N
M/2`D;6%T8VAE<ULP75LK*R1I73L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@)'!A<F%M971E<G-;72`]("1P87)A;3L*("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@
M)&D@/"!C;W5N="@D<&%R86UE=&5R<RD[("1I*RLI('L*("`@("`@("`@("`@
M("`@("`@("`D<&%R86U?;F%M92`@/2!T<FEM*'-U8G-T<B@D<&%R86UE=&5R
M<ULD:5TL(#`L("1P;W,@/2!S=')P;W,H)'!A<F%M971E<G-;)&E=+"`G/2<I
M*2P@(B=<(CM<=%Q<("(I.PH@("`@("`@("`@("`@("`@("`@("1P87)A;5]V
M86QU92`]('1R:6TH<W1R7W)E<&QA8V4H)UP[)RP@)SLG+"!S=6)S='(H)'!A
M<F%M971E<G-;)&E=+"`D<&]S("L@,2DI+"`B)UPB.UQT7%P@(BD["B`@("`@
M("`@("`@("`@("`@("`@:68@*"1P87)A;5]V86QU95LP72`]/2`G(B<I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M7W9A;'5E(#T@<W5B<W1R
M*"1P87)A;5]V86QU92P@,2P@+3$I.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`D<F5T=7)N6R=O=&AE<B==6R1P87)A;5]N
M86UE72`]("1P87)A;5]V86QU93L*("`@("`@("`@("`@("`@("`@("`D<F5T
M=7)N6R=O=&AE<B==6W-T<G1O;&]W97(H)'!A<F%M7VYA;64I72`]("1P87)A
M;5]V86QU93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1R971U<FY;)W9A;'5E)UT@/2!T
M<FEM*"1I;G!U="D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E='5R
M;CL*("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@9G5N8W1I;VX@<W!L:71S
M('1H92!I;G!U="!B87-E9`H@("`@("H@;VX@=&AE(&=I=F5N(&)O=6YD87)Y
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R!);G!U="!T;R!P87)S90H@
M("`@("H@0')E='5R;B!A<G)A>2!#;VYT86EN<R!A<G)A>2!O9B!R97-U;'1I
M;F<@;6EM92!P87)T<PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]B;W5N9&%R>5-P;&ET*"1I;G!U="P@)&)O=6YD87)Y
M*0H@("`@>PH@("`@("`@("1P87)T<R`](&%R<F%Y*"D["@H@("`@("`@("1B
M<U]P;W-S:6)L92`]('-U8G-T<B@D8F]U;F1A<GDL(#(L("TR*3L*("`@("`@
M("`D8G-?8VAE8VL@/2`G7"(G("X@)&)S7W!O<W-I8FQE("X@)UPB)SL*"B`@
M("`@("`@:68@*"1B;W5N9&%R>2`]/2`D8G-?8VAE8VLI('L*("`@("`@("`@
M("`@)&)O=6YD87)Y(#T@)&)S7W!O<W-I8FQE.PH@("`@("`@('T*"B`@("`@
M("`@)'1M<"`](&5X<&QO9&4H)RTM)R`N("1B;W5N9&%R>2P@)&EN<'5T*3L*
M"B`@("`@("`@9F]R("@D:2`](#$[("1I(#P@8V]U;G0H)'1M<"D@+2`Q.R`D
M:2LK*2!["B`@("`@("`@("`@("1P87)T<UM=(#T@)'1M<%LD:5T["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)'!A<G1S.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1VEV96X@82!H96%D97(L('1H:7,@9G5N8W1I;VX@=VEL;"!D96-O
M9&4@:70*("`@("`J(&%C8V]R9&EN9R!T;R!21D,R,#0W+B!0<F]B86)L>2!N
M;W0@*F5X86-T;'DJ"B`@("`@*B!C;VYF;W)M86YT+"!B=70@:70@9&]E<R!P
M87-S(&%L;"!T:&4@9VEV96X*("`@("`J(&5X86UP;&5S("AI;B!21D,R,#0W
M*2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG($EN<'5T(&AE861E<B!V
M86QU92!T;R!D96-O9&4*("`@("`J($!R971U<FX@<W1R:6YG($1E8V]D960@
M:&5A9&5R('9A;'5E"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V1E8V]D94AE861E<B@D:6YP=70I"B`@("!["B`@("`@
M("`@+R\@4F5M;W9E('=H:71E('-P86-E(&)E='=E96X@96YC;V1E9"UW;W)D
M<PH@("`@("`@("1I;G!U="`]('!R96=?<F5P;&%C92@G+R@]7#];7C]=*UP_
M*'%\8BE</UM>/UTJ7#\]*2A<<RDK/5P_+VDG+"`G7#$]/R<L("1I;G!U="D[
M"@H@("`@("`@("\O($9O<B!E86-H(&5N8V]D960M=V]R9"XN+@H@("`@("`@
M('=H:6QE("AP<F5G7VUA=&-H*"<O*#U</RA;7C]=*RE</RAQ?&(I7#\H6UX_
M72HI7#\]*2]I)RP@)&EN<'5T+"`D;6%T8VAE<RDI('L*"B`@("`@("`@("`@
M("1E;F-O9&5D("`]("1M871C:&5S6S%=.PH@("`@("`@("`@("`D8VAA<G-E
M="`@/2`D;6%T8VAE<ULR73L*("`@("`@("`@("`@)&5N8V]D:6YG(#T@)&UA
M=&-H97-;,UT["B`@("`@("`@("`@("1T97AT("`@("`]("1M871C:&5S6S1=
M.PH*("`@("`@("`@("`@<W=I=&-H("AS=')T;VQO=V5R*"1E;F-O9&EN9RDI
M('L*("`@("`@("`@("`@("`@(&-A<V4@)V(G.@H@("`@("`@("`@("`@("`@
M("`@("1T97AT(#T@8F%S938T7V1E8V]D92@D=&5X="D["B`@("`@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G<2<Z"B`@
M("`@("`@("`@("`@("`@("`@)'1E>'0@/2!S=')?<F5P;&%C92@G7R<L("<@
M)RP@)'1E>'0I.PH@("`@("`@("`@("`@("`@("`@('!R96=?;6%T8VA?86QL
M*"<O/2A;82UF,"TY77LR?2DO:2<L("1T97AT+"`D;6%T8VAE<RD["B`@("`@
M("`@("`@("`@("`@("`@9F]R96%C:"@D;6%T8VAE<ULQ72!A<R`D=F%L=64I
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T97AT(#T@<W1R7W)E<&QA8V4H
M)STG+B1V86QU92P@8VAR*&AE>&1E8R@D=F%L=64I*2P@)'1E>'0I.PH@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`D:6YP=70@/2!S=')?<F5P;&%C92@D96YC;V1E9"P@)'1E>'0L("1I
M;G!U="D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EN<'5T.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1VEV96X@82!B;V1Y('-T<FEN9R!A;F0@86X@
M96YC;V1I;F<@='EP92P*("`@("`J('1H:7,@9G5N8W1I;VX@=VEL;"!D96-O
M9&4@86YD(')E='5R;B!I="X*("`@("`J"B`@("`@*B!`<&%R86T@('-T<FEN
M9R!);G!U="!B;V1Y('1O(&1E8V]D90H@("`@("H@0'!A<F%M("!S=')I;F<@
M16YC;V1I;F<@='EP92!T;R!U<V4N"B`@("`@*B!`<F5T=7)N('-T<FEN9R!$
M96-O9&5D(&)O9'D*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@
M("!F=6YC=&EO;B!?9&5C;V1E0F]D>2@D:6YP=70L("1E;F-O9&EN9R`]("<W
M8FET)RD*("`@('L*("`@("`@("!S=VET8V@@*'-T<G1O;&]W97(H)&5N8V]D
M:6YG*2D@>PH@("`@("`@("`@("!C87-E("<W8FET)SH*("`@("`@("`@("`@
M("`@(')E='5R;B`D:6YP=70["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@(&-A<V4@)W%U;W1E9"UP<FEN=&%B;&4G.@H@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?<75O=&5D4')I;G1A8FQE1&5C;V1E*"1I
M;G!U="D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A
M<V4@)V)A<V4V-"<Z"B`@("`@("`@("`@("`@("!R971U<FX@8F%S938T7V1E
M8V]D92@D:6YP=70I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@<F5T=7)N("1I;G!U=#L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!':79E;B!A('%U;W1E
M9"UP<FEN=&%B;&4@<W1R:6YG+"!T:&ES"B`@("`@*B!F=6YC=&EO;B!W:6QL
M(&1E8V]D92!A;F0@<F5T=7)N(&ET+@H@("`@("H*("`@("`J($!P87)A;2`@
M<W1R:6YG($EN<'5T(&)O9'D@=&\@9&5C;V1E"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R!$96-O9&5D(&)O9'D*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("HO"B`@("!F=6YC=&EO;B!?<75O=&5D4')I;G1A8FQE1&5C;V1E*"1I;G!U
M="D*("`@('L*("`@("`@("`O+R!296UO=F4@<V]F="!L:6YE(&)R96%K<PH@
M("`@("`@("1I;G!U="`]('!R96=?<F5P;&%C92@B+SU<<C]<;B\B+"`G)RP@
M)&EN<'5T*3L*"B`@("`@("`@+R\@4F5P;&%C92!E;F-O9&5D(&-H87)A8W1E
M<G,*"0DD:6YP=70@/2!P<F5G7W)E<&QA8V4H)R\]*%MA+68P+3E=>S)]*2]I
M92<L(")C:'(H:&5X9&5C*"=<7#$G*2DB+"`D:6YP=70I.PH*("`@("`@("!R
M971U<FX@)&EN<'5T.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS('1H
M92!I;G!U="!F;W(@=75E;F-O9&5D(&9I;&5S(&%N9"!R971U<FYS"B`@("`@
M*B!A;B!A<G)A>2!O9B!T:&5M+B!#86X@8F4@8V%L;&5D('-T871I8V%L;'DL
M(&5G.@H@("`@("H*("`@("`J("1F:6QE<R`])B!-86EL7VUI;65$96-O9&4Z
M.G5U9&5C;V1E*"1S;VUE7W1E>'0I.PH@("`@("H*("`@("`J($ET('=I;&P@
M8VAE8VL@9F]R('1H92!B96=I;B`V-C8@+BXN(&5N9"!S>6YT87@*("`@("`J
M(&AO=V5V97(@86YD('=O;B=T(&IU<W0@8FQI;F1L>2!D96-O9&4@=VAA=&5V
M97(@>6]U"B`@("`@*B!P87-S(&ET+@H@("`@("H*("`@("`J($!P87)A;2`@
M<W1R:6YG($EN<'5T(&)O9'D@=&\@;&]O:R!F;W(@871T86AC;65N=',@:6X*
M("`@("`J($!R971U<FX@87)R87D@($1E8V]D960@8F]D:65S+"!F:6QE;F%M
M97,@86YD('!E<FUI<W-I;VYS"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("H@0&%U=&AO<B!5;FMN;W=N"B`@("`@*B\*("`@(&9U;F-T:6]N("9U=61E
M8V]D92@D:6YP=70I"B`@("!["B`@("`@("`@+R\@1FEN9"!A;&P@=75E;F-O
M9&5D('-E8W1I;VYS"B`@("`@("`@<')E9U]M871C:%]A;&PH(B]B96=I;B`H
M6S`M-UU[,WTI("@N*RE<<C]<;B@N*RE<<C]<;F5N9"]5<R(L("1I;G!U="P@
M)&UA=&-H97,I.PH*("`@("`@("!F;W(@*"1J(#T@,#L@)&H@/"!C;W5N="@D
M;6%T8VAE<ULS72D[("1J*RLI('L*"B`@("`@("`@("`@("1S='(@("`@("`]
M("1M871C:&5S6S-=6R1J73L*("`@("`@("`@("`@)&9I;&5N86UE(#T@)&UA
M=&-H97-;,EU;)&I=.PH@("`@("`@("`@("`D9FEL97!E<FT@/2`D;6%T8VAE
M<ULQ75LD:ET["@H@("`@("`@("`@("`D9FEL92`]("<G.PH@("`@("`@("`@
M("`D<W1R(#T@<')E9U]S<&QI="@B+UQR/UQN+R(L('1R:6TH)'-T<BDI.PH@
M("`@("`@("`@("`D<W1R;&5N(#T@8V]U;G0H)'-T<BD["@H@("`@("`@("`@
M("!F;W(@*"1I(#T@,#L@)&D@/"`D<W1R;&5N.R`D:2LK*2!["B`@("`@("`@
M("`@("`@("`D<&]S(#T@,3L*("`@("`@("`@("`@("`@("1D(#T@,#L*("`@
M("`@("`@("`@("`@("1L96X]*&EN="DH*"AO<F0H<W5B<W1R*"1S=');)&E=
M+#`L,2DI("TS,BD@+2`G("<I("8@,#<W*3L*"B`@("`@("`@("`@("`@("!W
M:&EL92`H*"1D("L@,R`\/2`D;&5N*2!!3D0@*"1P;W,@*R`T(#P]('-T<FQE
M;B@D<W1R6R1I72DI*2!["B`@("`@("`@("`@("`@("`@("`@)&,P(#T@*&]R
M9"AS=6)S='(H)'-T<ELD:5TL)'!O<RPQ*2D@7B`P>#(P*3L*("`@("`@("`@
M("`@("`@("`@("`D8S$@/2`H;W)D*'-U8G-T<B@D<W1R6R1I72PD<&]S*S$L
M,2DI(%X@,'@R,"D["B`@("`@("`@("`@("`@("`@("`@)&,R(#T@*&]R9"AS
M=6)S='(H)'-T<ELD:5TL)'!O<RLR+#$I*2!>(#!X,C`I.PH@("`@("`@("`@
M("`@("`@("`@("1C,R`]("AO<F0H<W5B<W1R*"1S=');)&E=+"1P;W,K,RPQ
M*2D@7B`P>#(P*3L*("`@("`@("`@("`@("`@("`@("`D9FEL92`N/2!C:'(H
M*"@H)&,P("T@)R`G*2`F(#`W-RD@/#P@,BD@?"`H*"@D8S$@+2`G("<I("8@
M,#<W*2`^/B`T*2D["@H@("`@("`@("`@("`@("`@("`@("1F:6QE("X](&-H
M<B@H*"@D8S$@+2`G("<I("8@,#<W*2`\/"`T*2!\("@H*"1C,B`M("<@)RD@
M)B`P-S<I(#X^(#(I*3L*"B`@("`@("`@("`@("`@("`@("`@)&9I;&4@+CT@
M8VAR*"@H*"1C,B`M("<@)RD@)B`P-S<I(#P\(#8I('P@("@H)&,S("T@)R`G
M*2`F(#`W-RDI.PH*("`@("`@("`@("`@("`@("`@("`D<&]S("L](#0["B`@
M("`@("`@("`@("`@("`@("`@)&0@*ST@,SL*("`@("`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("`@("!I9B`H*"1D("L@,B`\/2`D;&5N*2`F)B`H)'!O
M<R`K(#,@/#T@<W1R;&5N*"1S=');)&E=*2DI('L*("`@("`@("`@("`@("`@
M("`@("`D8S`@/2`H;W)D*'-U8G-T<B@D<W1R6R1I72PD<&]S+#$I*2!>(#!X
M,C`I.PH@("`@("`@("`@("`@("`@("`@("1C,2`]("AO<F0H<W5B<W1R*"1S
M=');)&E=+"1P;W,K,2PQ*2D@7B`P>#(P*3L*("`@("`@("`@("`@("`@("`@
M("`D8S(@/2`H;W)D*'-U8G-T<B@D<W1R6R1I72PD<&]S*S(L,2DI(%X@,'@R
M,"D["B`@("`@("`@("`@("`@("`@("`@)&9I;&4@+CT@8VAR*"@H*"1C,"`M
M("<@)RD@)B`P-S<I(#P\(#(I('P@*"@H)&,Q("T@)R`G*2`F(#`W-RD@/CX@
M-"DI.PH*("`@("`@("`@("`@("`@("`@("`D9FEL92`N/2!C:'(H*"@H)&,Q
M("T@)R`G*2`F(#`W-RD@/#P@-"D@?"`H*"@D8S(@+2`G("<I("8@,#<W*2`^
M/B`R*2D["@H@("`@("`@("`@("`@("`@("`@("1P;W,@*ST@,SL*("`@("`@
M("`@("`@("`@("`@("`D9"`K/2`R.PH@("`@("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@("`@(&EF("@H)&0@*R`Q(#P]("1L96XI("8F("@D<&]S("L@
M,B`\/2!S=')L96XH)'-T<ELD:5TI*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1C,"`]("AO<F0H<W5B<W1R*"1S=');)&E=+"1P;W,L,2DI(%X@,'@R,"D[
M"B`@("`@("`@("`@("`@("`@("`@)&,Q(#T@*&]R9"AS=6)S='(H)'-T<ELD
M:5TL)'!O<RLQ+#$I*2!>(#!X,C`I.PH@("`@("`@("`@("`@("`@("`@("1F
M:6QE("X](&-H<B@H*"@D8S`@+2`G("<I("8@,#<W*2`\/"`R*2!\("@H*"1C
M,2`M("<@)RD@)B`P-S<I(#X^(#0I*3L*"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)&9I;&5S6UT@/2!A<G)A>2@G9FEL
M96YA;64G(#T^("1F:6QE;F%M92P@)V9I;&5P97)M)R`]/B`D9FEL97!E<FTL
M("=F:6QE9&%T82<@/3X@)&9I;&4I.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1F:6QE<SL*("`@('T*"B`@("`O*BH*("`@("`J(&=E=%-E;F1!<G)A
M>2@I(')E='5R;G,@=&AE(&%R9W5M96YT<R!R97%U:7)E9"!F;W(@36%I;#HZ
M<V5N9"@I"B`@("`@*B!U<V5D('1O(&)U:6QD('1H92!A<F=U;65N=',@9F]R
M(&$@;6%I;#HZ<V5N9"@I(&-A;&P@"B`@("`@*@H@("`@("H@57-A9V4Z"B`@
M("`@*B`D;6%I;'1E>'0@/2!&=6QL(&5M86EL("AF;W(@97AA;7!L92!G96YE
M<F%T960@8GD@82!T96UP;&%T92D*("`@("`J("1D96-O9&5R(#T@;F5W($UA
M:6Q?;6EM941E8V]D92@D;6%I;'1E>'0I.PH@("`@("H@)'!A<G1S(#T@("1D
M96-O9&5R+3YG971396YD07)R87DH*3L*("`@("`J(&EF("@A4$5!4CHZ:7-%
M<G)O<B@D<&%R=',I('L*("`@("`J("`@("!L:7-T*"1R96-I<&5N=',L)&AE
M861E<G,L)&)O9'DI(#T@)'!A<G1S.PH@("`@("H@("`@("1M86EL(#T@36%I
M;#HZ9F%C=&]R>2@G<VUT<"<I.PH@("`@("H@("`@("1M86EL+3YS96YD*"1R
M96-I<&5N=',L)&AE861E<G,L)&)O9'DI.PH@("`@("H@?2!E;'-E('L*("`@
M("`J("`@("!E8VAO("1P87)T<RT^;65S<V%G93L*("`@("`J('T*("`@("`J
M($!R971U<FX@;6EX960@("!A<G)A>2!O9B!R96-I<&5I;G0L(&AE861E<G,L
M8F]D>2!O<B!096%R7T5R<F]R"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("H@0&%U=&AO<B!!;&%N($MN;W=L97,@/&%L86Y`86MB:VAO;64N8V]M/@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971396YD07)R87DH*0H@("`@>PH@("`@
M("`@("\O('!R979E;G0@=V%R;FEN9R!I9B!T:&ES(&ES(&YO="!S970*("`@
M("`@("`D=&AI<RT^7V1E8V]D95]H96%D97)S(#T@1D%,4T4["B`@("`@("`@
M)&AE861E<FQI<W0@/21T:&ES+3Y?<&%R<V5(96%D97)S*"1T:&ES+3Y?:&5A
M9&5R*3L*("`@("`@("`D=&\@/2`B(CL*("`@("`@("!I9B`H(21H96%D97)L
M:7-T*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B
M365S<V%G92!D:60@;F]T(&-O;G1A:6X@:&5A9&5R<R(I.PH@("`@("`@('T*
M("`@("`@("!F;W)E86-H*"1H96%D97)L:7-T(&%S("1I=&5M*2!["B`@("`@
M("`@("`@("1H96%D97);)&ET96U;)VYA;64G75T@/2`D:71E;5LG=F%L=64G
M73L*("`@("`@("`@("`@<W=I=&-H("AS=')T;VQO=V5R*"1I=&5M6R=N86UE
M)UTI*2!["B`@("`@("`@("`@("`@("!C87-E(")T;R(Z"B`@("`@("`@("`@
M("`@("!C87-E(")C8R(Z"B`@("`@("`@("`@("`@("!C87-E(")B8V,B.@H@
M("`@("`@("`@("`@("`@("`@("1T;R`]("(L(BXD:71E;5LG=F%L=64G73L*
M("`@("`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H)'1O
M(#T]("(B*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@B365S<V%G92!D:60@;F]T(&-O;G1A:6X@86YY(')E8VEP96YT<R(I.PH@
M("`@("`@('T*("`@("`@("`D=&\@/2!S=6)S='(H)'1O+#$I.PH@("`@("`@
M(')E='5R;B!A<G)A>2@D=&\L)&AE861E<BPD=&AI<RT^7V)O9'DI.PH@("`@
M?2`*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!X;6P@8V]P>2!O9B!T:&4@
M;W5T<'5T(&]F"B`@("`@*B!-86EL7VUI;65$96-O9&4Z.F1E8V]D92X@4&%S
M<R!T:&4@;W5T<'5T(&EN(&%S('1H90H@("`@("H@87)G=6UE;G0N(%1H:7,@
M9G5N8W1I;VX@8V%N(&)E(&-A;&QE9"!S=&%T:6-A;&QY+B!%9SH*("`@("`J
M"B`@("`@*B`D;W5T<'5T(#T@)&]B:BT^9&5C;V1E*"D["B`@("`@*B`D>&UL
M("`@(#T@36%I;%]M:6UE1&5C;V1E.CIG971834PH)&]U='!U="D["B`@("`@
M*@H@("`@("H@5&AE($141"!U<V5D(&9O<B!T:&ES('-H;W5L9"!H879E(&)E
M96X@:6X@=&AE('!A8VMA9V4N($]R"B`@("`@*B!A;'1E<FYA=&EV96QY('EO
M=2!C86X@9V5T(&ET(&9R;VT@8W9S+"!O<B!H97)E.@H@("`@("H@:'1T<#HO
M+W=W=RYP:'!G=7)U+F]R9R]X;6%I;"]X;6%I;"YD=&0N"B`@("`@*@H@("`@
M("H@0'!A<F%M("!O8FIE8W0@26YP=70@=&\@8V]N=F5R="!T;R!X;6PN(%1H
M:7,@<VAO=6QD(&)E('1H90H@("`@("H@("`@("`@("`@("`@("`@;W5T<'5T
M(&]F('1H92!-86EL7VUI;65$96-O9&4Z.F1E8V]D92!F=6YC=&EO;@H@("`@
M("H@0')E='5R;B!S=')I;F<@6$U,('9E<G-I;VX@;V8@:6YP=70*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%A-3"@D
M:6YP=70I"B`@("!["B`@("`@("`@)&-R;&8@("`@/2`@(EQR7&XB.PH@("`@
M("`@("1O=71P=70@(#T@)SP_>&UL('9E<G-I;VX]7"<Q+C!<)S\^)R`N("1C
M<FQF("X*("`@("`@("`@("`@("`@("`@("<\(41/0U194$4@96UA:6P@4UE3
M5$5-(")H='1P.B\O=W=W+G!H<&=U<G4N;W)G+WAM86EL+WAM86EL+F1T9"(^
M)R`N("1C<FQF("X*("`@("`@("`@("`@("`@("`@("<\96UA:6P^)R`N("1C
M<FQF("X*("`@("`@("`@("`@("`@("`@($UA:6Q?;6EM941E8V]D93HZ7V=E
M=%A-3"@D:6YP=70I("X*("`@("`@("`@("`@("`@("`@("<\+V5M86EL/B<[
M"@H@("`@("`@(')E='5R;B`D;W5T<'5T.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1G5N8W1I;VX@=&AA="!D;V5S('1H92!A8W1U86P@8V]N=F5R<VEO;B!T
M;R!X;6PN($1O97,@82!S:6YG;&4*("`@("`J(&UI;65P87)T(&%T(&$@=&EM
M92X*("`@("`J"B`@("`@*B!`<&%R86T@(&]B:F5C="`@26YP=70@=&\@8V]N
M=F5R="!T;R!X;6PN(%1H:7,@:7,@82!M:6UE<&%R="!O8FIE8W0N"B`@("`@
M*B`@("`@("`@("`@("`@("`@270@;6%Y(&]R(&UA>2!N;W0@8V]N=&%I;B!S
M=6)P87)T<RX*("`@("`J($!P87)A;2`@:6YT96=E<B!.=6UB97(@;V8@=&%B
M<R!T;R!I;F1E;G0*("`@("`J($!R971U<FX@<W1R:6YG("!834P@=F5R<VEO
M;B!O9B!I;G!U=`H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]G971834PH)&EN<'5T+"`D:6YD96YT(#T@,2D*("`@('L*
M("`@("`@("`D:'1A8B`@("`]("`B7'0B.PH@("`@("`@("1C<FQF("`@(#T@
M(")<<EQN(CL*("`@("`@("`D;W5T<'5T("`]("`G)SL*("`@("`@("`D:&5A
M9&5R<R`]($`H87)R87DI)&EN<'5T+3YH96%D97)S.PH*("`@("`@("!F;W)E
M86-H("@D:&5A9&5R<R!A<R`D:&1R7VYA;64@/3X@)&AD<E]V86QU92D@>PH*
M("`@("`@("`@("`@+R\@375L=&EP;&4@:&5A9&5R<R!W:71H('1H:7,@;F%M
M90H@("`@("`@("`@("!I9B`H:7-?87)R87DH)&AE861E<G-;)&AD<E]N86UE
M72DI('L*("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT
M*"1H9')?=F%L=64I.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@)&]U
M='!U="`N/2!-86EL7VUI;65$96-O9&4Z.E]G971834Q?:&5L<&5R*"1H9')?
M;F%M92P@)&AD<E]V86QU95LD:5TL("1I;F1E;G0I.PH@("`@("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@+R\@3VYL>2!O;F4@:&5A9&5R(&]F('1H:7,@
M<V]R=`H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&]U
M='!U="`N/2!-86EL7VUI;65$96-O9&4Z.E]G971834Q?:&5L<&5R*"1H9')?
M;F%M92P@)&AD<E]V86QU92P@)&EN9&5N="D["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)&EN<'5T+3YP87)T<RDI('L*
M("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)&EN<'5T+3YP
M87)T<RD[("1I*RLI('L*("`@("`@("`@("`@("`@("1O=71P=70@+CT@)&-R
M;&8@+B!S=')?<F5P96%T*"1H=&%B+"`D:6YD96YT*2`N("<\;6EM97!A<G0^
M)R`N("1C<FQF("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@36%I;%]M
M:6UE1&5C;V1E.CI?9V5T6$U,*"1I;G!U="T^<&%R='-;)&E=+"`D:6YD96YT
M*S$I("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R7W)E<&5A="@D
M:'1A8BP@)&EN9&5N="D@+B`G/"]M:6UE<&%R=#XG("X@)&-R;&8["B`@("`@
M("`@("`@('T*("`@("`@("!](&5L<V5I9B`H:7-S970H)&EN<'5T+3YB;V1Y
M*2D@>PH@("`@("`@("`@("`D;W5T<'5T("X]("1C<FQF("X@<W1R7W)E<&5A
M="@D:'1A8BP@)&EN9&5N="D@+B`G/&)O9'D^/"%;0T1!5$%;)R`N"B`@("`@
M("`@("`@("`@("`@("`@("`@)&EN<'5T+3YB;V1Y("X@)UU=/CPO8F]D>3XG
M("X@)&-R;&8["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&]U='!U=#L*
M("`@('T*"B`@("`O*BH*("`@("`J($AE;'!E<B!F=6YC=&EO;B!T;R!?9V5T
M6$U,*"DN(%)E='5R;G,@>&UL(&]F(&$@:&5A9&5R+@H@("`@("H*("`@("`J
M($!P87)A;2`@<W1R:6YG("!.86UE(&]F(&AE861E<@H@("`@("H@0'!A<F%M
M("!S=')I;F<@(%9A;'5E(&]F(&AE861E<@H@("`@("H@0'!A<F%M("!I;G1E
M9V5R($YU;6)E<B!O9B!T86)S('1O(&EN9&5N=`H@("`@("H@0')E='5R;B!S
M=')I;F<@(%A-3"!V97)S:6]N(&]F(&EN<'5T"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=%A-3%]H96QP97(H)&AD
M<E]N86UE+"`D:&1R7W9A;'5E+"`D:6YD96YT*0H@("`@>PH@("`@("`@("1H
M=&%B("`@/2`B7'0B.PH@("`@("`@("1C<FQF("`@/2`B7')<;B(["B`@("`@
M("`@)')E='5R;B`]("<G.PH*("`@("`@("`D;F5W7VAD<E]V86QU92`]("@D
M:&1R7VYA;64@(3T@)W)E8V5I=F5D)RD@/R!-86EL7VUI;65$96-O9&4Z.E]P
M87)S94AE861E<E9A;'5E*"1H9')?=F%L=64I(#H@87)R87DH)W9A;'5E)R`]
M/B`D:&1R7W9A;'5E*3L*("`@("`@("`D;F5W7VAD<E]N86UE("`]('-T<E]R
M97!L86-E*"<@)RP@)RTG+"!U8W=O<F1S*'-T<E]R97!L86-E*"<M)RP@)R`G
M+"`D:&1R7VYA;64I*2D["@H@("`@("`@("\O(%-O<G0@;W5T(&%N>2!P87)A
M;65T97)S"B`@("`@("`@:68@*"%E;7!T>2@D;F5W7VAD<E]V86QU95LG;W1H
M97(G72DI('L*("`@("`@("`@("`@9F]R96%C:"`H)&YE=U]H9')?=F%L=65;
M)V]T:&5R)UT@87,@)'!A<F%M;F%M92`]/B`D<&%R86UV86QU92D@>PH@("`@
M("`@("`@("`@("`@)'!A<F%M<UM=(#T@<W1R7W)E<&5A="@D:'1A8BP@)&EN
M9&5N="D@+B`D:'1A8B`N("<\<&%R86UE=&5R/B<@+B`D8W)L9B`N"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!S=')?<F5P96%T*"1H=&%B+"`D:6YD
M96YT*2`N("1H=&%B("X@)&AT86(@+B`G/'!A<F%M;F%M93XG("X@:'1M;'-P
M96-I86QC:&%R<R@D<&%R86UN86UE*2`N("<\+W!A<F%M;F%M93XG("X@)&-R
M;&8@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R7W)E<&5A="@D
M:'1A8BP@)&EN9&5N="D@+B`D:'1A8B`N("1H=&%B("X@)SQP87)A;79A;'5E
M/B<@+B!H=&UL<W!E8VEA;&-H87)S*"1P87)A;79A;'5E*2`N("<\+W!A<F%M
M=F%L=64^)R`N("1C<FQF("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('-T<E]R97!E870H)&AT86(L("1I;F1E;G0I("X@)&AT86(@+B`G/"]P87)A
M;65T97(^)R`N("1C<FQF.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M<&%R86US(#T@:6UP;&]D92@G)RP@)'!A<F%M<RD["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'!A<F%M<R`]("<G.PH@("`@("`@('T*"B`@("`@
M("`@)')E='5R;B`]('-T<E]R97!E870H)&AT86(L("1I;F1E;G0I("X@)SQH
M96%D97(^)R`N("1C<FQF("X*("`@("`@("`@("`@("`@("`@<W1R7W)E<&5A
M="@D:'1A8BP@)&EN9&5N="D@+B`D:'1A8B`N("<\:&5A9&5R;F%M93XG("X@
M:'1M;'-P96-I86QC:&%R<R@D;F5W7VAD<E]N86UE*2`N("<\+VAE861E<FYA
M;64^)R`N("1C<FQF("X*("`@("`@("`@("`@("`@("`@<W1R7W)E<&5A="@D
M:'1A8BP@)&EN9&5N="D@+B`D:'1A8B`N("<\:&5A9&5R=F%L=64^)R`N(&AT
M;6QS<&5C:6%L8VAA<G,H)&YE=U]H9')?=F%L=65;)W9A;'5E)UTI("X@)SPO
M:&5A9&5R=F%L=64^)R`N("1C<FQF("X*("`@("`@("`@("`@("`@("`@)'!A
M<F%M<R`N"B`@("`@("`@("`@("`@("`@('-T<E]R97!E870H)&AT86(L("1I
M;F1E;G0I("X@)SPO:&5A9&5R/B<@+B`D8W)L9CL*"B`@("`@("`@<F5T=7)N
M("1R971U<FX["B`@("!]"@I]("\O($5N9"!O9B!C;&%S<PH_/@H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]-86EL+W-E;F1M86EL+G!H<```````````````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$S,S8V(#$P-3$U-#,S-S,S(#`R
M,38V-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H
M92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R
M8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0
M(&QI8V5N<V4L("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H
M:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@
M('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I
M=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T
M;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC
M96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I
M871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!!=71H;W(Z($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/B`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PH*+RHJ"B`J(%-E;F1M86EL(&EM
M<&QE;65N=&%T:6]N(&]F('1H92!014%2($UA:6PZ.B!I;G1E<F9A8V4N"B`J
M($!A8V-E<W,@<'5B;&EC"B`J($!P86-K86=E($UA:6P*("H@0'9E<G-I;VX@
M)%)E=FES:6]N.B`Q+C$S("0*("HO"F-L87-S($UA:6Q?<V5N9&UA:6P@97AT
M96YD<R!-86EL('L*"@DO*BH*("`@("`J(%1H92!L;V-A=&EO;B!O9B!T:&4@
M<V5N9&UA:6P@;W(@<V5N9&UA:6P@=W)A<'!E<B!B:6YA<GD@;VX@=&AE"B`@
M("`@*B!F:6QE<WES=&5M+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@
M("`@=F%R("1S96YD;6%I;%]P871H(#T@)R]U<W(O<V)I;B]S96YD;6%I;"<[
M"@H)+RHJ"B`@("`@*B!!;GD@97AT<F$@8V]M;6%N9"UL:6YE('!A<F%M971E
M<G,@=&\@<&%S<R!T;R!T:&4@<V5N9&UA:6P@;W(*("`@("`J('-E;F1M86EL
M('=R87!P97(@8FEN87)Y+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@
M("`@=F%R("1S96YD;6%I;%]A<F=S(#T@)R<["@H)+RHJ"B`@("`@*B!#;VYS
M=')U8W1O<BX*("`@("`J"B`@("`@*B!);G-T86YT:6%T97,@82!N97<@36%I
M;%]S96YD;6%I;#HZ(&]B:F5C="!B87-E9"!O;B!T:&4@<&%R86UE=&5R<PH@
M("`@("H@<&%S<V5D(&EN+B!)="!L;V]K<R!F;W(@=&AE(&9O;&QO=VEN9R!P
M87)A;65T97)S.@H@("`@("H@("`@('-E;F1M86EL7W!A=&@@("`@5&AE(&QO
M8V%T:6]N(&]F('1H92!S96YD;6%I;"!B:6YA<GD@;VX@=&AE"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("!F:6QE<WES=&5M+B!$969A=6QT<R!T;R`G
M+W5S<B]S8FEN+W-E;F1M86EL)RX*("`@("`J"B`@("`@*B`@("`@<V5N9&UA
M:6Q?87)G<R`@("!!;GD@97AT<F$@<&%R86UE=&5R<R!T;R!P87-S('1O('1H
M92!S96YD;6%I;`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@;W(@<V5N
M9&UA:6P@=W)A<'!E<B!B:6YA<GDN"B`@("`@*@H@("`@("H@268@82!P87)A
M;65T97(@:7,@<')E<V5N="!I;B!T:&4@)'!A<F%M<R!A<G)A>2P@:70@<F5P
M;&%C97,@=&AE"B`@("`@*B!D969A=6QT+@H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US($AA<V@@8V]N=&%I;FEN9R!A;GD@<&%R86UE=&5R
M<R!D:69F97)E;G0@9G)O;2!T:&4*("`@("`J("`@("`@("`@("`@("!D969A
M=6QT<RX*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T
M:6]N($UA:6Q?<V5N9&UA:6PH)'!A<F%M<RD*("`@('L*("`@("`@("!I9B`H
M:7-S970H)'!A<F%M<ULG<V5N9&UA:6Q?<&%T:"==*2D@)'1H:7,M/G-E;F1M
M86EL7W!A=&@@/2`D<&%R86US6R=S96YD;6%I;%]P871H)UT["B`@("`@("`@
M:68@*&ES<V5T*"1P87)A;7-;)W-E;F1M86EL7V%R9W,G72DI("1T:&ES+3YS
M96YD;6%I;%]A<F=S(#T@)'!A<F%M<ULG<V5N9&UA:6Q?87)G<R==.PH*("`@
M("`@("`O*@H@("`@("`@("`J($)E8V%U<V4@=V4@;F5E9"!T;R!P87-S(&UE
M<W-A9V4@:&5A9&5R<R!T;R!T:&4@<V5N9&UA:6P@<')O9W)A;2!O;@H@("`@
M("`@("`J('1H92!C;VUM86YD;&EN92P@=V4@8V%N)W0@9W5A<F%N=&5E('1H
M92!U<V4@;V8@=&AE('-T86YD87)D(")<<EQN(@H@("`@("`@("`J('-E<&%R
M871O<BX@($EN<W1E860L('=E('5S92!T:&4@<WES=&5M)W,@;F%T:79E(&QI
M;F4@<V5P87)A=&]R+@H@("`@("`@("`J+PH@("`@("`@(&EF("AD969I;F5D
M*%!(4%]%3TPI*2!["B`@("`@("`@("`@("1T:&ES+3YS97`@/2!02%!?14],
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YS97`@/2`H
M<W1R<&]S*%!(4%]/4RP@)U=)3B<I(#T]/2!F86QS92D@/R`B7&XB(#H@(EQR
M7&XB.PH@("`@("`@('T*("`@('T*"@DO*BH*("`@("`J($EM<&QE;65N=',@
M36%I;#HZ<V5N9"@I(&9U;F-T:6]N('5S:6YG('1H92!S96YD;6%I;`H@("`@
M("H@8V]M;6%N9"UL:6YE(&)I;F%R>2X*("`@("`J"B`@("`@*B!`<&%R86T@
M;6EX960@)')E8VEP:65N=',@16ET:&5R(&$@8V]M;6$M<V5P97)A=&5D(&QI
M<W0@;V8@<F5C:7!I96YT<PH@("`@("H@("`@("`@("`@("`@("A21D,X,C(@
M8V]M<&QI86YT*2P@;W(@86X@87)R87D@;V8@<F5C:7!I96YT<RP*("`@("`J
M("`@("`@("`@("`@("!E86-H(%)&0S@R,B!V86QI9"X@5&AI<R!M87D@8V]N
M=&%I;B!R96-I<&EE;G1S(&YO=`H@("`@("H@("`@("`@("`@("`@('-P96-I
M9FEE9"!I;B!T:&4@:&5A9&5R<RP@9F]R($)C8SHL(')E<V5N9&EN9PH@("`@
M("H@("`@("`@("`@("`@(&UE<W-A9V5S+"!E=&,N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1H96%D97)S(%1H92!A<G)A>2!O9B!H96%D97)S('1O
M('-E;F0@=VET:"!T:&4@;6%I;"P@:6X@86X*("`@("`J("`@("`@("`@("`@
M("!A<W-O8VEA=&EV92!A<G)A>2P@=VAE<F4@=&AE(&%R<F%Y(&ME>2!I<R!T
M:&4*("`@("`J("`@("`@("`@("`@("!H96%D97(@;F%M92`H:64L("=3=6)J
M96-T)RDL(&%N9"!T:&4@87)R87D@=F%L=64*("`@("`J("`@("`@("`@("`@
M("!I<R!T:&4@:&5A9&5R('9A;'5E("AI92P@)W1E<W0G*2X@5&AE(&AE861E
M<@H@("`@("H@("`@("`@("`@("`@('!R;V1U8V5D(&9R;VT@=&AO<V4@=F%L
M=65S('=O=6QD(&)E("=3=6)J96-T.@H@("`@("H@("`@("`@("`@("`@('1E
M<W0G+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&)O9'D@5&AE(&9U
M;&P@=&5X="!O9B!T:&4@;65S<V%G92!B;V1Y+"!I;F-L=61I;F<@86YY"B`@
M("`@*B`@("`@("`@("`@("`@($UI;64@<&%R=',L(&5T8RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D(%)E='5R;G,@=')U92!O;B!S=6-C97-S+"!O
M<B!A(%!%05)?17)R;W(*("`@("`J("`@("`@("`@("`@("`@8V]N=&%I;FEN
M9R!A(&1E<V-R:7!T:79E(&5R<F]R(&UE<W-A9V4@;VX*("`@("`J("`@("`@
M("`@("`@("`@9F%I;'5R92X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E;F0H)')E8VEP:65N=',L("1H96%D97)S+"`D
M8F]D>2D*("`@('L*("`@("`@("`D<F5C:7!I96YT<R`]("1T:&ES+3YP87)S
M95)E8VEP:65N=',H)')E8VEP:65N=',I.PH@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1R96-I<&EE;G1S*2D@>PH@("`@("`@("`@("!R971U<FX@)')E
M8VEP:65N=',["B`@("`@("`@?0H@("`@("`@("1R96-I<&EE;G1S(#T@97-C
M87!E4VAE;&Q#;60H:6UP;&]D92@G("<L("1R96-I<&EE;G1S*2D["@H@("`@
M("`@("1H96%D97)%;&5M96YT<R`]("1T:&ES+3YP<F5P87)E2&5A9&5R<R@D
M:&5A9&5R<RD["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&AE861E<D5L
M96UE;G1S*2D@>PH@("`@("`@("`@("!R971U<FX@)&AE861E<D5L96UE;G1S
M.PH@("`@("`@('T*("`@("`@("!L:7-T*"1F<F]M+"`D=&5X=%]H96%D97)S
M*2`]("1H96%D97)%;&5M96YT<SL*"B`@("`@("`@:68@*"%I<W-E="@D9G)O
M;2DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TYO
M(&9R;VT@861D<F5S<R!G:79E;BXG*3L*("`@("`@("!](&5L<V5I9B`H<W1R
M<&]S*"1F<F]M+"`G("<I("$]/2!F86QS92!\?`H@("`@("`@("`@("`@("`@
M("!S=')P;W,H)&9R;VTL("<[)RD@(3T](&9A;'-E('Q\"B`@("`@("`@("`@
M("`@("`@('-T<G!O<R@D9G)O;2P@)R8G*2`A/3T@9F%L<V4@?'P*("`@("`@
M("`@("`@("`@("`@<W1R<&]S*"1F<F]M+"`G8"<I("$]/2!F86QS92D@>PH@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G1G)O;2!A9&1R
M97-S('-P96-I9FEE9"!W:71H(&1A;F=E<F]U<R!C:&%R86-T97)S+B<I.PH@
M("`@("`@('T*"B`@("`@("`@)&9R;VT@/2!E<V-A<&53:&5L;$-M9"@D9G)O
M;2D["B`@("`@("`@)&UA:6P@/2!`<&]P96XH)'1H:7,M/G-E;F1M86EL7W!A
M=&@@+B`H(65M<'1Y*"1T:&ES+3YS96YD;6%I;%]A<F=S*2`_("<@)R`N("1T
M:&ES+3YS96YD;6%I;%]A<F=S(#H@)R<I("X@(B`M9B1F<F]M("TM("1R96-I
M<&EE;G1S(BP@)W<G*3L*("`@("`@("!I9B`H(21M86EL*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=&86EL960@=&\@;W!E;B!S
M96YD;6%I;"!;)R`N("1T:&ES+3YS96YD;6%I;%]P871H("X@)UT@9F]R(&5X
M96-U=&EO;BXG*3L*("`@("`@("!]"@H@("`@("`@(&9P=71S*"1M86EL+"`D
M=&5X=%]H96%D97)S*3L*("`@("`@("!F<'5T<R@D;6%I;"P@)'1H:7,M/G-E
M<"D[("`O+R!N97=L:6YE('1O(&5N9"!T:&4@:&5A9&5R<R!S96-T:6]N"B`@
M("`@("`@9G!U=',H)&UA:6PL("1B;V1Y*3L*("`@("`@("`D<F5S=6QT(#T@
M<&-L;W-E*"1M86EL*3L*("`@("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*'!H
M<'9E<G-I;VXH*2P@)S0N,BXS)RD@/3T@+3$I('L*("`@("`@("`@("`@+R\@
M5VET:"!O;&1E<B!P:'`@=F5R<VEO;G,L('=E(&YE960@=&\@<VAI9G0@=&AE
M('!C;&]S90H@("`@("`@("`@("`O+R!R97-U;'0@=&\@9V5T('1H92!E>&ET
M(&-O9&4N"B`@("`@("`@("`@("1R97-U;'0@/2`D<F5S=6QT(#X^(#@@)B`P
M>$9&.PH@("`@("`@('T*"B`@("`@("`@:68@*"1R97-U;'0@(3T@,"D@>PH@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G<V5N9&UA:6P@
M<F5T=7)N960@97)R;W(@8V]D92`G("X@)')E<W5L="P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)')E<W5L="D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+TUA:6PO<VUT<"YP:'``````````````````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,S`P-#8@,3`U,34T,S,W,S,@,#(Q,#0W
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(
M4"!697)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(
M4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F
M:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC
M96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P
M86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO
M+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A
M="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A
M(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@
M?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@
M<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E
M0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L
M>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\($%U=&AO<G,Z($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/B`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@("`@
M("`@("!*;VX@4&%R:7-E(#QJ;VY`<&AP+FYE=#X@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PH*+RHJ($5R<F]R.B!&86EL960@=&\@8W)E871E(&$@3F5T7U--
M5%`@;V)J96-T("HO"F1E9FEN92@G4$5!4E]-04E,7U--5%!?15)23U)?0U)%
M051%)RP@,3`P,#`I.PH*+RHJ($5R<F]R.B!&86EL960@=&\@8V]N;F5C="!T
M;R!33510('-E<G9E<B`J+PID969I;F4H)U!%05)?34%)3%]335107T524D]2
M7T-/3DY%0U0G+"`Q,#`P,2D["@HO*BH@17)R;W(Z(%--5%`@875T:&5N=&EC
M871I;VX@9F%I;'5R92`J+PID969I;F4H)U!%05)?34%)3%]335107T524D]2
M7T%55$@G+"`Q,#`P,BD["@HO*BH@17)R;W(Z($YO($9R;VTZ(&%D9')E<W,@
M:&%S(&)E96X@<')O=FED960@*B\*9&5F:6YE*"=014%27TU!24Q?4TU44%]%
M4E)/4E]&4D]-)RP@,3`P,#,I.PH*+RHJ($5R<F]R.B!&86EL960@=&\@<V5T
M('-E;F1E<B`J+PID969I;F4H)U!%05)?34%)3%]335107T524D]27U-%3D1%
M4B<L(#$P,#`T*3L*"B\J*B!%<G)O<CH@1F%I;&5D('1O(&%D9"!R96-I<&EE
M;G0@*B\*9&5F:6YE*"=014%27TU!24Q?4TU44%]%4E)/4E]214-)4$E%3E0G
M+"`Q,#`P-2D["@HO*BH@17)R;W(Z($9A:6QE9"!T;R!S96YD(&1A=&$@*B\*
M9&5F:6YE*"=014%27TU!24Q?4TU44%]%4E)/4E]$051!)RP@,3`P,#8I.PH*
M+RHJ"B`J(%--5%`@:6UP;&5M96YT871I;VX@;V8@=&AE(%!%05(@36%I;"!I
M;G1E<F9A8V4N(%)E<75I<F5S('1H92!.971?4TU44"!C;&%S<RX*("H@0&%C
M8V5S<R!P=6)L:6,*("H@0'!A8VMA9V4@36%I;`H@*B!`=F5R<VEO;B`D4F5V
M:7-I;VXZ(#$N,C8@)`H@*B\*8VQA<W,@36%I;%]S;71P(&5X=&5N9',@36%I
M;"!["@H@("`@+RHJ"B`@("`@*B!33510(&-O;FYE8W1I;VX@;V)J96-T+@H@
M("`@("H*("`@("`J($!V87(@;V)J96-T"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@=F%R("1?<VUT<"`](&YU;&P["@H@("`@+RHJ"B`@
M("`@*B!4:&4@4TU44"!H;W-T('1O(&-O;FYE8W0@=&\N"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)&AO<W0@/2`G;&]C86QH;W-T)SL*
M"B`@("`O*BH*("`@("`J(%1H92!P;W)T('1H92!33510('-E<G9E<B!I<R!O
M;BX*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)'!O<G0@
M/2`R-3L*"B`@("`O*BH*("`@("`J(%-H;W5L9"!33510(&%U=&AE;G1I8V%T
M:6]N(&)E('5S960_"B`@("`@*@H@("`@("H@5&AI<R!V86QU92!M87D@8F4@
M<V5T('1O('1R=64L(&9A;'-E(&]R('1H92!N86UE(&]F(&$@<W!E8VEF:6,*
M("`@("`J(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"X*("`@("`J"B`@("`@*B!)
M9B!T:&4@=F%L=64@:7,@<V5T('1O('1R=64L('1H92!.971?4TU44"!P86-K
M86=E('=I;&P@871T96UP="!T;R!U<V4*("`@("`J('1H92!B97-T(&%U=&AE
M;G1I8V%T:6]N(&UE=&AO9"!A9'9E<G1I<V5D(&)Y('1H92!R96UO=&4@4TU4
M4"!S97)V97(N"B`@("`@*@H@("`@("H@0'9A<B!M:7AE9`H@("`@("HO"B`@
M("!V87(@)&%U=&@@/2!F86QS93L*"B`@("`O*BH*("`@("`J(%1H92!U<V5R
M;F%M92!T;R!U<V4@:68@=&AE(%--5%`@<V5R=F5R(')E<75I<F5S(&%U=&AE
M;G1I8V%T:6]N+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1U<V5R;F%M92`]("<G.PH*("`@("\J*@H@("`@("H@5&AE('!A<W-W;W)D
M('1O('5S92!I9B!T:&4@4TU44"!S97)V97(@<F5Q=6ER97,@875T:&5N=&EC
M871I;VXN"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)'!A
M<W-W;W)D(#T@)R<["@H@("`@+RHJ"B`@("`@*B!(;W-T;F%M92!O<B!D;VUA
M:6X@=&AA="!W:6QL(&)E('-E;G0@=&\@=&AE(')E;6]T92!33510('-E<G9E
M<B!I;B!T:&4*("`@("`J($A%3$\@+R!%2$Q/(&UE<W-A9V4N"B`@("`@*@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1L;V-A;&AO<W0@
M/2`G;&]C86QH;W-T)SL*"B`@("`O*BH*("`@("`J(%--5%`@8V]N;F5C=&EO
M;B!T:6UE;W5T('9A;'5E+B`@3E5,3"!I;F1I8V%T97,@;F\@=&EM96]U="X*
M("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1T
M:6UE;W5T(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%=H971H97(@=&\@=7-E
M(%9%4E`@;W(@;F]T+B!)9B!N;W0@82!B;V]L96%N+"!T:&4@<W1R:6YG('9A
M;'5E"B`@("`@*B!W:6QL(&)E('5S960@87,@=&AE(%9%4E`@<V5P87)A=&]R
M<RX*("`@("`J"B`@("`@*B!`=F%R(&UI>&5D(&)O;VQE86X@;W(@<W1R:6YG
M"B`@("`@*B\*("`@('9A<B`D=F5R<"`](&9A;'-E.PH*("`@("\J*@H@("`@
M("H@5'5R;B!O;B!.971?4TU44"!D96)U9V=I;F<_"B`@("`@*@H@("`@("H@
M0'9A<B!B;V]L96%N("1D96)U9PH@("`@("HO"B`@("!V87(@)&1E8G5G(#T@
M9F%L<V4["@H@("`@+RHJ"B`@("`@*B!);F1I8V%T97,@=VAE=&AE<B!O<B!N
M;W0@=&AE(%--5%`@8V]N;F5C=&EO;B!S:&]U;&0@<&5R<VES="!O=F5R"B`@
M("`@*B!M=6QT:7!L92!C86QL<R!T;R!T:&4@<V5N9"@I(&UE=&AO9"X*("`@
M("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1P97)S
M:7-T(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@
M("`J"B`@("`@*B!);G-T86YT:6%T97,@82!N97<@36%I;%]S;71P.CH@;V)J
M96-T(&)A<V5D(&]N('1H92!P87)A;65T97)S"B`@("`@*B!P87-S960@:6XN
M($ET(&QO;VMS(&9O<B!T:&4@9F]L;&]W:6YG('!A<F%M971E<G,Z"B`@("`@
M*B`@("`@:&]S="`@("`@("`@5&AE('-E<G9E<B!T;R!C;VYN96-T('1O+B!$
M969A=6QT<R!T;R!L;V-A;&AO<W0N"B`@("`@*B`@("`@<&]R="`@("`@("`@
M5&AE('!O<G0@=&\@8V]N;F5C="!T;RX@1&5F875L=',@=&\@,C4N"B`@("`@
M*B`@("`@875T:"`@("`@("`@4TU44"!A=71H96YT:6-A=&EO;BX@($1E9F%U
M;'1S('1O(&YO;F4N"B`@("`@*B`@("`@=7-E<FYA;64@("`@5&AE('5S97)N
M86UE('1O('5S92!F;W(@4TU44"!A=71H+B!.;R!D969A=6QT+@H@("`@("H@
M("`@('!A<W-W;W)D("`@(%1H92!P87-S=V]R9"!T;R!U<V4@9F]R(%--5%`@
M875T:"X@3F\@9&5F875L="X*("`@("`J("`@("!L;V-A;&AO<W0@("!4:&4@
M;&]C86P@:&]S=&YA;64@+R!D;VUA:6XN($1E9F%U;'1S('1O(&QO8V%L:&]S
M="X*("`@("`J("`@("!T:6UE;W5T("`@("!4:&4@4TU44"!C;VYN96-T:6]N
M('1I;65O=70N($1E9F%U;'1S('1O(&YO;F4N"B`@("`@*B`@("`@=F5R<"`@
M("`@("`@5VAE=&AE<B!T;R!U<V4@5D524"!O<B!N;W0N($1E9F%U;'1S('1O
M(&9A;'-E+@H@("`@("H@("`@(&1E8G5G("`@("`@($%C=&EV871E(%--5%`@
M9&5B=6<@;6]D93\@1&5F875L=',@=&\@9F%L<V4N"B`@("`@*B`@("`@<&5R
M<VES="`@("`@4VAO=6QD('1H92!33510(&-O;FYE8W1I;VX@<&5R<VES=#\*
M("`@("`J"B`@("`@*B!)9B!A('!A<F%M971E<B!I<R!P<F5S96YT(&EN('1H
M92`D<&%R86US(&%R<F%Y+"!I="!R97!L86-E<R!T:&4*("`@("`J(&1E9F%U
M;'0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y($AA<V@@8V]N=&%I;FEN
M9R!A;GD@<&%R86UE=&5R<R!D:69F97)E;G0@9G)O;2!T:&4*("`@("`J("`@
M("`@("`@("`@("!D969A=6QT<RX*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B\*("`@(&9U;F-T:6]N($UA:6Q?<VUT<"@D<&%R86US*0H@("`@>PH@
M("`@("`@(&EF("AI<W-E="@D<&%R86US6R=H;W-T)UTI*2`D=&AI<RT^:&]S
M="`]("1P87)A;7-;)VAO<W0G73L*("`@("`@("!I9B`H:7-S970H)'!A<F%M
M<ULG<&]R="==*2D@)'1H:7,M/G!O<G0@/2`D<&%R86US6R=P;W)T)UT["B`@
M("`@("`@:68@*&ES<V5T*"1P87)A;7-;)V%U=&@G72DI("1T:&ES+3YA=71H
M(#T@)'!A<F%M<ULG875T:"==.PH@("`@("`@(&EF("AI<W-E="@D<&%R86US
M6R=U<V5R;F%M92==*2D@)'1H:7,M/G5S97)N86UE(#T@)'!A<F%M<ULG=7-E
M<FYA;64G73L*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG<&%S<W=O<F0G
M72DI("1T:&ES+3YP87-S=V]R9"`]("1P87)A;7-;)W!A<W-W;W)D)UT["B`@
M("`@("`@:68@*&ES<V5T*"1P87)A;7-;)VQO8V%L:&]S="==*2D@)'1H:7,M
M/FQO8V%L:&]S="`]("1P87)A;7-;)VQO8V%L:&]S="==.PH@("`@("`@(&EF
M("AI<W-E="@D<&%R86US6R=T:6UE;W5T)UTI*2`D=&AI<RT^=&EM96]U="`]
M("1P87)A;7-;)W1I;65O=70G73L*("`@("`@("!I9B`H:7-S970H)'!A<F%M
M<ULG=F5R<"==*2D@)'1H:7,M/G9E<G`@/2`D<&%R86US6R=V97)P)UT["B`@
M("`@("`@:68@*&ES<V5T*"1P87)A;7-;)V1E8G5G)UTI*2`D=&AI<RT^9&5B
M=6<@/2`H8F]O;&5A;BDD<&%R86US6R=D96)U9R==.PH@("`@("`@(&EF("AI
M<W-E="@D<&%R86US6R=P97)S:7-T)UTI*2`D=&AI<RT^<&5R<VES="`]("AB
M;V]L96%N*21P87)A;7-;)W!E<G-I<W0G73L*"B`@("`@("`@<F5G:7-T97)?
M<VAU=&1O=VY?9G5N8W1I;VXH87)R87DH)B1T:&ES+"`G7TUA:6Q?<VUT<"<I
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($1E<W1R=6-T;W(@:6UP;&5M96YT
M871I;VX@=&\@96YS=7)E('1H870@=V4@9&ES8V]N;F5C="!F<F]M(&%N>0H@
M("`@("H@<&]T96YT:6%L;'DM86QI=F4@<&5R<VES=&5N="!33510(&-O;FYE
M8W1I;VYS+@H@("`@("HO"B`@("!F=6YC=&EO;B!?36%I;%]S;71P*"D*("`@
M('L*("`@("`@("`D=&AI<RT^9&ES8V]N;F5C="@I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@26UP;&5M96YT<R!-86EL.CIS96YD*"D@9G5N8W1I;VX@=7-I
M;F<@4TU44"X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)')E8VEP:65N
M=',@16ET:&5R(&$@8V]M;6$M<V5P97)A=&5D(&QI<W0@;V8@<F5C:7!I96YT
M<PH@("`@("H@("`@("`@("`@("`@("A21D,X,C(@8V]M<&QI86YT*2P@;W(@
M86X@87)R87D@;V8@<F5C:7!I96YT<RP*("`@("`J("`@("`@("`@("`@("!E
M86-H(%)&0S@R,B!V86QI9"X@5&AI<R!M87D@8V]N=&%I;B!R96-I<&EE;G1S
M(&YO=`H@("`@("H@("`@("`@("`@("`@('-P96-I9FEE9"!I;B!T:&4@:&5A
M9&5R<RP@9F]R($)C8SHL(')E<V5N9&EN9PH@("`@("H@("`@("`@("`@("`@
M(&UE<W-A9V5S+"!E=&,N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1H
M96%D97)S(%1H92!A<G)A>2!O9B!H96%D97)S('1O('-E;F0@=VET:"!T:&4@
M;6%I;"P@:6X@86X*("`@("`J("`@("`@("`@("`@("!A<W-O8VEA=&EV92!A
M<G)A>2P@=VAE<F4@=&AE(&%R<F%Y(&ME>2!I<R!T:&4*("`@("`J("`@("`@
M("`@("`@("!H96%D97(@;F%M92`H92YG+BP@)U-U8FIE8W0G*2P@86YD('1H
M92!A<G)A>2!V86QU90H@("`@("H@("`@("`@("`@("`@(&ES('1H92!H96%D
M97(@=F%L=64@*&4N9RXL("=T97-T)RDN(%1H92!H96%D97(*("`@("`J("`@
M("`@("`@("`@("!P<F]D=6-E9"!F<F]M('1H;W-E('9A;'5E<R!W;W5L9"!B
M92`G4W5B:F5C=#H*("`@("`J("`@("`@("`@("`@("!T97-T)RX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1B;V1Y(%1H92!F=6QL('1E>'0@;V8@
M=&AE(&UE<W-A9V4@8F]D>2P@:6YC;'5D:6YG(&%N>0H@("`@("H@("`@("`@
M("`@("`@("!-:6UE('!A<G1S+"!E=&,N"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"!2971U<FYS('1R=64@;VX@<W5C8V5S<RP@;W(@82!014%27T5R
M<F]R"B`@("`@*B`@("`@("`@("`@("`@(&-O;G1A:6YI;F<@82!D97-C<FEP
M=&EV92!E<G)O<B!M97-S86=E(&]N"B`@("`@*B`@("`@("`@("`@("`@(&9A
M:6QU<F4N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC
M=&EO;B!S96YD*"1R96-I<&EE;G1S+"`D:&5A9&5R<RP@)&)O9'DI"B`@("![
M"B`@("`@("`@:6YC;'5D95]O;F-E("=.970O4TU44"YP:'`G.PH*("`@("`@
M("`O*B!)9B!W92!D;VXG="!A;')E861Y(&AA=F4@86X@4TU44"!O8FIE8W0L
M(&-R96%T92!O;F4N("HO"B`@("`@("`@:68@*&ES7V]B:F5C="@D=&AI<RT^
M7W-M='`I(#T]/2!F86QS92D@>PH@("`@("`@("`@("`D=&AI<RT^7W-M='`@
M/28@;F5W($YE=%]33510*"1T:&ES+3YH;W-T+"`D=&AI<RT^<&]R="P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M;&]C86QH;W-T*3L*"B`@("`@("`@("`@("\J($EF('=E('-T:6QL(&1O;B=T
M(&AA=F4@86X@4TU44"!O8FIE8W0@870@=&AI<R!P;VEN="P@9F%I;"X@*B\*
M("`@("`@("`@("`@:68@*&ES7V]B:F5C="@D=&AI<RT^7W-M='`I(#T]/2!F
M86QS92D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H)T9A:6QE9"!T;R!C<F5A=&4@82!.971?4TU44"!O8FIE8W0G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E]-04E,
M7U--5%!?15)23U)?0U)%051%*3L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@+RH@0V]N9FEG=7)E('1H92!33510(&-O;FYE8W1I;VXN("HO"B`@("`@
M("`@("`@(&EF("@D=&AI<RT^9&5B=6<I('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<VUT<"T^<V5T1&5B=6<H=')U92D["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("\J($%T=&5M<'0@=&\@8V]N;F5C="!T;R!T:&4@8V]N9FEG
M=7)E9"!33510('-E<G9E<BX@*B\*("`@("`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)')E<R`]("1T:&ES+3Y?<VUT<"T^8V]N;F5C="@D=&AI<RT^=&EM
M96]U="DI*2!["B`@("`@("`@("`@("`@("`D97)R;W(@/2`D=&AI<RT^7V5R
M<F]R*"=&86EL960@=&\@8V]N;F5C="!T;R`G("X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FAO<W0@+B`G.B<@+B`D
M=&AI<RT^<&]R="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)')E<RD["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@D97)R;W(L(%!%05)?34%)3%]335107T524D]27T-/3DY%0U0I
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!!='1E;7!T('1O(&%U
M=&AE;G1I8V%T92!I9B!A=71H96YT:6-A=&EO;B!H87,@8F5E;B!E;F%B;&5D
M+B`J+PH@("`@("`@("`@("!I9B`H)'1H:7,M/F%U=&@I('L*("`@("`@("`@
M("`@("`@("1M971H;V0@/2!I<U]S=')I;F<H)'1H:7,M/F%U=&@I(#\@)'1H
M:7,M/F%U=&@@.B`G)SL*"B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D<F5S(#T@)'1H:7,M/E]S;71P+3YA=71H*"1T:&ES+3YU<V5R;F%M
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G!A<W-W;W)D+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D;65T:&]D*2DI('L*("`@("`@("`@("`@("`@("`@("`D97)R;W(@
M/2`D=&AI<RT^7V5R<F]R*"(D;65T:&]D(&%U=&AE;G1I8V%T:6]N(&9A:6QU
M<F4B+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)')E<RD["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S;71P+3YR
M<V5T*"D["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)&5R<F]R+"!014%27TU!24Q?4TU44%]%4E)/4E]!551(*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@)&AE861E<D5L96UE;G1S(#T@)'1H:7,M/G!R97!A<F5(96%D97)S*"1H
M96%D97)S*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:&5A9&5R16QE
M;65N=',I*2!["B`@("`@("`@("`@("1T:&ES+3Y?<VUT<"T^<G-E="@I.PH@
M("`@("`@("`@("!R971U<FX@)&AE861E<D5L96UE;G1S.PH@("`@("`@('T*
M("`@("`@("!L:7-T*"1F<F]M+"`D=&5X=$AE861E<G,I(#T@)&AE861E<D5L
M96UE;G1S.PH*("`@("`@("`O*B!3:6YC92!F97<@351!<R!A<F4@9V]I;F<@
M=&\@86QL;W<@=&AI<R!H96%D97(@=&\@8F4@9F]R9V5D"B`@("`@("`@("H@
M=6YL97-S(&ET)W,@:6X@=&AE($U!24P@1E)/33H@97AC:&%N9V4L('=E)VQL
M('5S90H@("`@("`@("`J(%)E='5R;BU0871H(&EN<W1E860@;V8@1G)O;3H@
M:68@:70G<R!S970N("HO"B`@("`@("`@:68@*"%E;7!T>2@D:&5A9&5R<ULG
M4F5T=7)N+5!A=&@G72DI('L*("`@("`@("`@("`@)&9R;VT@/2`D:&5A9&5R
M<ULG4F5T=7)N+5!A=&@G73L*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-S
M970H)&9R;VTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<VUT<"T^<G-E="@I
M.PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G3F\@1G)O
M;3H@861D<F5S<R!H87,@8F5E;B!P<F]V:61E9"<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%!%05)?34%)3%]335107T524D]27T92
M3TTI.PH@("`@("`@('T*"B`@("`@("`@)&%R9W-;)W9E<G`G72`]("1T:&ES
M+3YV97)P.PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1R97,@/2`D=&AI
M<RT^7W-M='`M/FUA:6Q&<F]M*"1F<F]M+"`D87)G<RDI*2!["B`@("`@("`@
M("`@("1E<G)O<B`]("1T:&ES+3Y?97)R;W(H(D9A:6QE9"!T;R!S970@<V5N
M9&5R.B`D9G)O;2(L("1R97,I.PH@("`@("`@("`@("`D=&AI<RT^7W-M='`M
M/G)S970H*3L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)&5R<F]R+"!014%27TU!24Q?4TU44%]%4E)/4E]314Y$15(I.PH@("`@("`@
M('T*"B`@("`@("`@)')E8VEP:65N=',@/2`D=&AI<RT^<&%R<V5296-I<&EE
M;G1S*"1R96-I<&EE;G1S*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M<F5C:7!I96YT<RDI('L*("`@("`@("`@("`@)'1H:7,M/E]S;71P+3YR<V5T
M*"D["B`@("`@("`@("`@(')E='5R;B`D<F5C:7!I96YT<SL*("`@("`@("!]
M"@H@("`@("`@(&9O<F5A8V@@*"1R96-I<&EE;G1S(&%S("1R96-I<&EE;G0I
M('L*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<R`]("1T:&ES
M+3Y?<VUT<"T^<F-P=%1O*"1R96-I<&EE;G0I*2D@>PH@("`@("`@("`@("`@
M("`@)&5R<F]R(#T@)'1H:7,M/E]E<G)O<B@B1F%I;&5D('1O(&%D9"!R96-I
M<&EE;G0Z("1R96-I<&EE;G0B+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<F5S*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<VUT<"T^<G-E="@I.PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H)&5R<F]R+"!014%27TU!24Q?4TU44%]%4E)/4E]214-)4$E%
M3E0I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!396YD
M('1H92!M97-S86=E)W,@:&5A9&5R<R!A;F0@=&AE(&)O9'D@87,@4TU44"!D
M871A+B`J+PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1R97,@/2`D=&AI
M<RT^7W-M='`M/F1A=&$H(B1T97AT2&5A9&5R<UQR7&XD8F]D>2(I*2D@>PH@
M("`@("`@("`@("`D97)R;W(@/2`D=&AI<RT^7V5R<F]R*"=&86EL960@=&\@
M<V5N9"!D871A)RP@)')E<RD["B`@("`@("`@("`@("1T:&ES+3Y?<VUT<"T^
M<G-E="@I.PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D
M97)R;W(L(%!%05)?34%)3%]335107T524D]27T1!5$$I.PH@("`@("`@('T*
M"B`@("`@("`@+RH@268@<&5R<VES=&5N="!C;VYN96-T:6]N<R!A<F4@9&ES
M86)L960L(&1E<W1R;WD@;W5R(%--5%`@;V)J96-T+B`J+PH@("`@("`@(&EF
M("@D=&AI<RT^<&5R<VES="`]/3T@9F%L<V4I('L*("`@("`@("`@("`@)'1H
M:7,M/F1I<V-O;FYE8W0H*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@1&ES8V]N;F5C="!A;F0@9&5S
M=')O>2!T:&4@8W5R<F5N="!33510(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N(%1R=64@:68@=&AE(%--5%`@8V]N;F5C=&EO
M;B!N;R!L;VYG97(@97AI<W1S+@H@("`@("H*("`@("`J($!S:6YC92`@,2XQ
M+CD*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&1I<V-O;FYE8W0H*0H@("`@>PH@("`@("`@("\J($EF('=E(&AA=F4@86X@
M4TU44"!O8FIE8W0L(&1I<V-O;FYE8W0@86YD(&1E<W1R;WD@:70N("HO"B`@
M("`@("`@:68@*&ES7V]B:F5C="@D=&AI<RT^7W-M='`I("8F("1T:&ES+3Y?
M<VUT<"T^9&ES8V]N;F5C="@I*2!["B`@("`@("`@("`@("1T:&ES+3Y?<VUT
M<"`](&YU;&P["B`@("`@("`@?0H*("`@("`@("`O*B!792!A<F4@9&ES8V]N
M;F5C=&5D(&EF('=E(&YO(&QO;F=E<B!H879E(&%N(%--5%`@;V)J96-T+B`J
M+PH@("`@("`@(')E='5R;B`H)'1H:7,M/E]S;71P(#T]/2!N=6QL*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($)U:6QD(&$@<W1A;F1A<F1I>F5D('-T<FEN
M9R!D97-C<FEB:6YG('1H92!C=7)R96YT(%--5%`@97)R;W(N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@0W5S=&]M('-T<FEN9R!D97-C
M<FEB:6YG('1H92!E<G)O<B!C;VYT97AT+@H@("`@("H@0'!A<F%M(&]B:F5C
M="`D97)R;W(@4F5F97)E;F-E('1O('1H92!C=7)R96YT(%!%05)?17)R;W(@
M;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("`@("`@($$@
M<W1R:6YG(&1E<V-R:6)I;F<@=&AE(&-U<G)E;G0@4TU44"!E<G)O<BX*("`@
M("`J"B`@("`@*B!`<VEN8V4@(#$N,2XW"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V5R<F]R*"1T97AT+"`F)&5R<F]R
M*0H@("`@>PH@("`@("`@("\J(%-P;&ET('1H92!33510(')E<W!O;G-E(&EN
M=&\@82!C;V1E(&%N9"!A(')E<W!O;G-E('-T<FEN9RX@*B\*("`@("`@("!L
M:7-T*"1C;V1E+"`D<F5S<&]N<V4I(#T@)'1H:7,M/E]S;71P+3YG971297-P
M;VYS92@I.PH*("`@("`@("`O*B!"=6EL9"!O=7(@<W1A;F1A<F1I>F5D(&5R
M<F]R('-T<FEN9RX@*B\*("`@("`@("`D;7-G(#T@)'1E>'0["B`@("`@("`@
M)&US9R`N/2`G(%M33510.B`G("X@)&5R<F]R+3YG971-97-S86=E*"D["B`@
M("`@("`@)&US9R`N/2`B("AC;V1E.B`D8V]D92P@<F5S<&]N<V4Z("1R97-P
M;VYS92E=(CL*"B`@("`@("`@<F5T=7)N("1M<V<["B`@("!]"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]-86EL+U)&0S@R,BYP:'``````````````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#<V-C(S(#$P-3$U-#,S-S,S(#`R,#<T-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC
M*2`R,#`Q+3(P,#(L(%)I8VAA<F0@2&5Y97,@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@?"!!;&P@<FEG:'1S(')E<V5R=F5D+B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@4F5D:7-T
M<FEB=71I;VX@86YD('5S92!I;B!S;W5R8V4@86YD(&)I;F%R>2!F;W)M<RP@
M=VET:"!O<B!W:71H;W5T("`@('P*+R\@?"!M;V1I9FEC871I;VXL(&%R92!P
M97)M:71T960@<')O=FED960@=&AA="!T:&4@9F]L;&]W:6YG(&-O;F1I=&EO
M;G,@("`@?`HO+R!\(&%R92!M970Z("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!O(%)E9&ES=')I8G5T
M:6]N<R!O9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P
M>7)I9VAT("`@("`@?`HO+R!\("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N
M9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R+B`@("`@("!\
M"B\O('P@;R!2961I<W1R:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R
M97!R;V1U8V4@=&AE(&%B;W9E(&-O<'ER:6=H="`@('P*+R\@?"`@(&YO=&EC
M92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@
M9&ES8VQA:6UE<B!I;B!T:&4@?`HO+R!\("`@9&]C=6UE;G1A=&EO;B!A;F0O
M;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE(&1I<W1R:6)U
M=&EO;BY\"B\O('P@;R!4:&4@;F%M97,@;V8@=&AE(&%U=&AO<G,@;6%Y(&YO
M="!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92`@("`@('P*+R\@?"`@
M('!R;V1U8W1S(&1E<FEV960@9G)O;2!T:&ES('-O9G1W87)E('=I=&AO=70@
M<W!E8VEF:6,@<')I;W(@=W)I='1E;B`@?`HO+R!\("`@<&5R;6ES<VEO;BX@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@?"!42$E3(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'
M2%0@2$],1$524R!!3D0@0T].5%))0E543U)3("`@?`HO+R!\(")!4R!)4R(@
M04Y$($%.62!%6%!215-3($]2($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$
M24Y'+"!"550@3D]4("`@("!\"B\O('P@3$E-251%1"!43RP@5$A%($E-4$Q)
M140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,@
M1D]2('P*+R\@?"!!(%!!4E1)0U5,05(@4%524$]312!!4D4@1$E30TQ!24U%
M1"X@24X@3D\@159%3E0@4TA!3$P@5$A%($-/4%E224=(5"`@?`HO+R!\($]7
M3D52($]2($-/3E1224)55$]24R!"12!,24%"3$4@1D]2($%.62!$25)%0U0L
M($E.1$E214-4+"!)3D-)1$5.5$%,+"!\"B\O('P@4U!%0TE!3"P@15A%35!,
M05)9+"!/4B!#3TY315%514Y424%,($1!34%'15,@*$E.0TQ51$E.1RP@0E54
M($Y/5"`@("`@('P*+R\@?"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1B!3
M54)35$E4551%($=/3T13($]2(%-%4E9)0T53.R!,3U-3($]&(%5312P@?`HO
M+R!\($1!5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3($E.5$524E505$E/
M3BD@2$]7159%4B!#0553140@04Y$($].($%.62!\"B\O('P@5$A%3U)9($]&
M($Q)04))3$E462P@5TA%5$A%4B!)3B!#3TY44D%#5"P@4U1224-4($Q)04))
M3$E462P@3U(@5$]25"`@('P*+R\@?"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@
M3U(@3U1(15)725-%*2!!4DE324Y'($E.($%.62!705D@3U54($]&(%1(12!5
M4T4@?`HO+R!\($]&(%1(25,@4T]&5%=!4D4L($5614X@248@041625-%1"!/
M1B!42$4@4$]34TE"24Q)5%D@3T8@4U5#2"!$04U!1T4N("!\"B\O('P@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%)I8VAA<F0@2&5Y97,@/')I8VAA
M<F1`<&AP9W5R=2YO<F<^("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M('P@("`@("`@("`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PH*+RHJ"B`J(%)&0R`X,C(@16UA:6P@861D<F5S
M<R!L:7-T('9A;&ED871I;VX@571I;&ET>0H@*@H@*B!7:&%T(&ES(&ET/PH@
M*@H@*B!4:&ES(&-L87-S('=I;&P@=&%K92!A;B!A9&1R97-S('-T<FEN9RP@
M86YD('!A<G-E(&ET(&EN=&\@:70G<R!C;VYS:71U96YT"B`J('!A<G1S+"!B
M92!T:&%T(&5I=&AE<B!A9&1R97-S97,L(&=R;W5P<RP@;W(@8V]M8FEN871I
M;VYS+B!.97-T960@9W)O=7!S"B`J(&%R92!N;W0@<W5P<&]R=&5D+B!4:&4@
M<W1R=6-T=7)E(&ET(')E='5R;G,@:7,@<')E='1Y('-T<F%I9VAT(&9O<G=A
M<F0L"B`J(&%N9"!I<R!S:6UI;&%R('1O('1H870@<')O=FED960@8GD@=&AE
M(&EM87!?<F9C.#(R7W!A<G-E7V%D<FQI<W0H*2X@57-E"B`J('!R:6YT7W(H
M*2!T;R!V:65W('1H92!S=')U8W1U<F4N"B`J"B`J($AO=R!D;R!)('5S92!I
M=#\*("H*("H@)&%D9')E<W-?<W1R:6YG(#T@)TUY($=R;W5P.B`B4FEC:&%R
M9"(@/')I8VAA<F1`;&]C86QH;W-T/B`H02!C;VUM96YT*2P@=&5D0&5X86UP
M;&4N8V]M("A4960@0FQO9V=S*2P@0F%R;F5Y.R<["B`J("1S=')U8W1U<F4@
M/2!-86EL7U)&0S@R,CHZ<&%R<V5!9&1R97-S3&ES="@D861D<F5S<U]S=')I
M;F<L("=E>&%M<&QE+F-O;2<L('1R=64I"B`J('!R:6YT7W(H)'-T<G5C='5R
M92D["B`J"B`J($!A=71H;W(@(%)I8VAA<F0@2&5Y97,@/')I8VAA<F1`<&AP
M9W5R=2YO<F<^"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/@H@*B!`=F5R<VEO;B`D4F5V:7-I;VXZ(#$N,C(@)`H@*B!`
M;&EC96YS92!"4T0*("H@0'!A8VMA9V4@36%I;`H@*B\*8VQA<W,@36%I;%]2
M1D,X,C(@>PH*("`@("\J*@H@("`@("H@5&AE(&%D9')E<W,@8F5I;F<@<&%R
M<V5D(&)Y('1H92!21D,X,C(@;V)J96-T+@H@("`@("H@0'9A<B!S=')I;F<@
M)&%D9')E<W,*("`@("`J+PH@("`@=F%R("1A9&1R97-S(#T@)R<["@H@("`@
M+RHJ"B`@("`@*B!4:&4@9&5F875L="!D;VUA:6X@=&\@=7-E(&9O<B!U;G%U
M86QI9FEE9"!A9&1R97-S97,N"B`@("`@*B!`=F%R('-T<FEN9R`D9&5F875L
M=%]D;VUA:6X*("`@("`J+PH@("`@=F%R("1D969A=6QT7V1O;6%I;B`]("=L
M;V-A;&AO<W0G.PH*("`@("\J*@H@("`@("H@4VAO=6QD('=E(')E='5R;B!A
M(&YE<W1E9"!A<G)A>2!S:&]W:6YG(&=R;W5P<RP@;W(@9FQA='1E;B!E=F5R
M>71H:6YG/PH@("`@("H@0'9A<B!B;V]L96%N("1N97-T1W)O=7!S"B`@("`@
M*B\*("`@('9A<B`D;F5S=$=R;W5P<R`]('1R=64["@H@("`@+RHJ"B`@("`@
M*B!7:&5T:&5R(&]R(&YO="!T;R!V86QI9&%T92!A=&]M<R!F;W(@;F]N+6%S
M8VEI(&-H87)A8W1E<G,N"B`@("`@*B!`=F%R(&)O;VQE86X@)'9A;&ED871E
M"B`@("`@*B\*("`@('9A<B`D=F%L:61A=&4@/2!T<G5E.PH*("`@("\J*@H@
M("`@("H@5&AE(&%R<F%Y(&]F(')A=R!A9&1R97-S97,@8G5I;'0@=7`@87,@
M=V4@<&%R<V4N"B`@("`@*B!`=F%R(&%R<F%Y("1A9&1R97-S97,*("`@("`J
M+PH@("`@=F%R("1A9&1R97-S97,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@
M("H@5&AE(&9I;F%L(&%R<F%Y(&]F('!A<G-E9"!A9&1R97-S(&EN9F]R;6%T
M:6]N('1H870@=V4@8G5I;&0@=7`N"B`@("`@*B!`=F%R(&%R<F%Y("1S=')U
M8W1U<F4*("`@("`J+PH@("`@=F%R("1S=')U8W1U<F4@/2!A<G)A>2@I.PH*
M("`@("\J*@H@("`@("H@5&AE(&-U<G)E;G0@97)R;W(@;65S<V%G92P@:68@
M86YY+@H@("`@("H@0'9A<B!S=')I;F<@)&5R<F]R"B`@("`@*B\*("`@('9A
M<B`D97)R;W(@/2!N=6QL.PH*("`@("\J*@H@("`@("H@06X@:6YT97)N86P@
M8V]U;G1E<B]P;VEN=&5R+@H@("`@("H@0'9A<B!I;G1E9V5R("1I;F1E>`H@
M("`@("HO"B`@("!V87(@)&EN9&5X(#T@;G5L;#L*"B`@("`O*BH*("`@("`J
M(%1H92!N=6UB97(@;V8@9W)O=7!S('1H870@:&%V92!B965N(&9O=6YD(&EN
M('1H92!A9&1R97-S(&QI<W0N"B`@("`@*B!`=F%R(&EN=&5G97(@)&YU;5]G
M<F]U<',*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@('9A<B`D
M;G5M7V=R;W5P<R`](#`["@H@("`@+RHJ"B`@("`@*B!!('9A<FEA8FQE('-O
M('1H870@=V4@8V%N('1E;&P@=VAE=&AE<B!O<B!N;W0@=V4G<F4@:6YS:61E
M(&$*("`@("`J($UA:6Q?4D9#.#(R(&]B:F5C="X*("`@("`J($!V87(@8F]O
M;&5A;B`D;6%I;%)&0S@R,@H@("`@("HO"B`@("!V87(@)&UA:6Q21D,X,C(@
M/2!T<G5E.PH*("`@("\J*@H@("`@*B!!(&QI;6ET(&%F=&5R('=H:6-H('!R
M;V-E<W-I;F<@<W1O<',*("`@("H@0'9A<B!I;G0@)&QI;6ET"B`@("`J+PH@
M("`@=F%R("1L:6UI="`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!3971S('5P
M('1H92!O8FIE8W0N(%1H92!A9&1R97-S(&UU<W0@96ET:&5R(&)E('-E="!H
M97)E(&]R('=H96X*("`@("`J(&-A;&QI;F<@<&%R<V5!9&1R97-S3&ES="@I
M+B!/;F4@;W(@=&AE(&]T:&5R+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B!`<&%R86T@<W1R:6YG("`D861D<F5S<R`@("`@("`@(%1H
M92!A9&1R97-S*&5S*2!T;R!V86QI9&%T92X*("`@("`J($!P87)A;2!S=')I
M;F<@("1D969A=6QT7V1O;6%I;B`@1&5F875L="!D;VUA:6XO:&]S="!E=&,N
M($EF(&YO="!S=7!P;&EE9"P@=VEL;"!B92!S970@=&\@;&]C86QH;W-T+@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)&YE<W1?9W)O=7!S("`@("!7:&5T:&5R
M('1O(')E='5R;B!T:&4@<W1R=6-T=7)E('=I=&@@9W)O=7!S(&YE<W1E9"!F
M;W(@96%S:65R('9I97=I;F<N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D=F%L
M:61A=&4@("`@("`@(%=H971H97(@=&\@=F%L:61A=&4@871O;7,N(%1U<FX@
M=&AI<R!O9F8@:68@>6]U(&YE960@=&\@<G5N(&%D9')E<W-E<R!T:')O=6=H
M(&)E9F]R92!E;F-O9&EN9R!T:&4@<&5R<V]N86P@;F%M97,L(&9O<B!I;G-T
M86YC92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&]B:F5C="!-86EL7U)&0S@R
M,B!!(&YE=R!-86EL7U)&0S@R,B!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T
M:6]N($UA:6Q?4D9#.#(R*"1A9&1R97-S(#T@;G5L;"P@)&1E9F%U;'1?9&]M
M86EN(#T@;G5L;"P@)&YE<W1?9W)O=7!S(#T@;G5L;"P@)'9A;&ED871E(#T@
M;G5L;"P@)&QI;6ET(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-S970H
M)&%D9')E<W,I*2`@("`@("`@)'1H:7,M/F%D9')E<W,@("`@("`@(#T@)&%D
M9')E<W,["B`@("`@("`@:68@*&ES<V5T*"1D969A=6QT7V1O;6%I;BDI("1T
M:&ES+3YD969A=6QT7V1O;6%I;B`]("1D969A=6QT7V1O;6%I;CL*("`@("`@
M("!I9B`H:7-S970H)&YE<W1?9W)O=7!S*2D@("`@)'1H:7,M/FYE<W1'<F]U
M<',@("`@(#T@)&YE<W1?9W)O=7!S.PH@("`@("`@(&EF("AI<W-E="@D=F%L
M:61A=&4I*2`@("`@("`D=&AI<RT^=F%L:61A=&4@("`@("`@/2`D=F%L:61A
M=&4["B`@("`@("`@:68@*&ES<V5T*"1L:6UI="DI("`@("`@("`@("1T:&ES
M+3YL:6UI="`@("`@("`@("`]("1L:6UI=#L*("`@('T*"B`@("`O*BH*("`@
M("`J(%-T87)T<R!T:&4@=VAO;&4@<')O8V5S<RX@5&AE(&%D9')E<W,@;75S
M="!E:71H97(@8F4@<V5T(&AE<F4*("`@("`J(&]R('=H96X@8W)E871I;F<@
M=&AE(&]B:F5C="X@3VYE(&]R('1H92!O=&AE<BX*("`@("`J"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M('-T<FEN9R`@)&%D9')E<W,@
M("`@("`@("!4:&4@861D<F5S<RAE<RD@=&\@=F%L:61A=&4N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`D9&5F875L=%]D;VUA:6X@($1E9F%U;'0@9&]M86EN
M+VAO<W0@971C+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&YE<W1?9W)O=7!S
M("`@("!7:&5T:&5R('1O(')E='5R;B!T:&4@<W1R=6-T=7)E('=I=&@@9W)O
M=7!S(&YE<W1E9"!F;W(@96%S:65R('9I97=I;F<N"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`D=F%L:61A=&4@("`@("`@(%=H971H97(@=&\@=F%L:61A=&4@
M871O;7,N(%1U<FX@=&AI<R!O9F8@:68@>6]U(&YE960@=&\@<G5N(&%D9')E
M<W-E<R!T:')O=6=H(&)E9F]R92!E;F-O9&EN9R!T:&4@<&5R<V]N86P@;F%M
M97,L(&9O<B!I;G-T86YC92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M($$@<W1R=6-T=7)E9"!A<G)A>2!O9B!A9&1R97-S97,N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('!A<G-E061D<F5S<TQI<W0H)&%D9')E<W,@/2!N=6QL+"`D
M9&5F875L=%]D;VUA:6X@/2!N=6QL+"`D;F5S=%]G<F]U<',@/2!N=6QL+"`D
M=F%L:61A=&4@/2!N=6QL+"`D;&EM:70@/2!N=6QL*0H@("`@>PH@("`@("`@
M(&EF("@A:7-S970H)'1H:7,I('Q\("%I<W-E="@D=&AI<RT^;6%I;%)&0S@R
M,BDI('L*("`@("`@("`@("`@)&]B:B`](&YE=R!-86EL7U)&0S@R,B@D861D
M<F5S<RP@)&1E9F%U;'1?9&]M86EN+"`D;F5S=%]G<F]U<',L("1V86QI9&%T
M92P@)&QI;6ET*3L*("`@("`@("`@("`@<F5T=7)N("1O8FHM/G!A<G-E061D
M<F5S<TQI<W0H*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D861D
M<F5S<RDI("`@("`@("`D=&AI<RT^861D<F5S<R`@("`@("`@/2`D861D<F5S
M<SL*("`@("`@("!I9B`H:7-S970H)&1E9F%U;'1?9&]M86EN*2D@)'1H:7,M
M/F1E9F%U;'1?9&]M86EN(#T@)&1E9F%U;'1?9&]M86EN.PH@("`@("`@(&EF
M("AI<W-E="@D;F5S=%]G<F]U<',I*2`@("`D=&AI<RT^;F5S=$=R;W5P<R`@
M("`@/2`D;F5S=%]G<F]U<',["B`@("`@("`@:68@*&ES<V5T*"1V86QI9&%T
M92DI("`@("`@("1T:&ES+3YV86QI9&%T92`@("`@("`]("1V86QI9&%T93L*
M("`@("`@("!I9B`H:7-S970H)&QI;6ET*2D@("`@("`@("`@)'1H:7,M/FQI
M;6ET("`@("`@("`@(#T@)&QI;6ET.PH*("`@("`@("`D=&AI<RT^<W1R=6-T
M=7)E("`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/F%D9')E<W-E<R`@/2!A
M<G)A>2@I.PH@("`@("`@("1T:&ES+3YE<G)O<B`@("`@(#T@;G5L;#L*("`@
M("`@("`D=&AI<RT^:6YD97@@("`@("`](&YU;&P["@H@("`@("`@("\O(%5N
M9F]L9"!A;GD@;&]N9R!L:6YE<R!I;B`D=&AI<RT^861D<F5S<RX*("`@("`@
M("`D=&AI<RT^861D<F5S<R`]('!R96=?<F5P;&%C92@G+UQR/UQN+R<L(")<
M<EQN(BP@)'1H:7,M/F%D9')E<W,I.PH@("`@("`@("1T:&ES+3YA9&1R97-S
M(#T@<')E9U]R97!L86-E*"<O7')<;BA<='P@*2LO)RP@)R`G+"`D=&AI<RT^
M861D<F5S<RD["@H@("`@("`@('=H:6QE("@D=&AI<RT^861D<F5S<R`]("1T
M:&ES+3Y?<W!L:71!9&1R97-S97,H)'1H:7,M/F%D9')E<W,I*3L*"B`@("`@
M("`@:68@*"1T:&ES+3YA9&1R97-S(#T]/2!F86QS92!\?"!I<W-E="@D=&AI
M<RT^97)R;W(I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4BYP
M:'`G.PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D=&AI
M<RT^97)R;W(I.PH@("`@("`@('T*"B`@("`@("`@+R\@5F%L:61A=&4@96%C
M:"!A9&1R97-S(&EN9&EV:61U86QL>2X@($EF('=E(&5N8V]U;G1E<B!A;B!I
M;G9A;&ED"B`@("`@("`@+R\@861D<F5S<RP@<W1O<"!I=&5R871I;F<@86YD
M(')E='5R;B!A;B!E<G)O<B!I;6UE9&EA=&5L>2X*("`@("`@("!F;W)E86-H
M("@D=&AI<RT^861D<F5S<V5S(&%S("1A9&1R97-S*2!["B`@("`@("`@("`@
M("1V86QI9"`]("1T:&ES+3Y?=F%L:61A=&5!9&1R97-S*"1A9&1R97-S*3L*
M"B`@("`@("`@("`@(&EF("@D=F%L:60@/3T](&9A;'-E('Q\(&ES<V5T*"1T
M:&ES+3YE<G)O<BDI('L*("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G
M4$5!4BYP:'`G.PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)'1H:7,M/F5R<F]R*3L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@:68@*"$D=&AI<RT^;F5S=$=R;W5P<RD@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/G-T<G5C='5R92`](&%R<F%Y7VUE<F=E*"1T:&ES+3YS=')U8W1U
M<F4L("1V86QI9"D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^<W1R=6-T=7)E6UT@/2`D=F%L:60["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^<W1R=6-T=7)E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4W!L:71S(&%N(&%D9')E<W,@:6YT
M;R!S97!A<F%T92!A9&1R97-S97,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*B!`<&%R86T@<W1R:6YG("1A9&1R97-S(%1H92!A9&1R
M97-S97,@=&\@<W!L:70N"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@4W5C8V5S
M<R!O<B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<W!L:71!9&1R
M97-S97,H)&%D9')E<W,I"B`@("!["B`@("`@("`@:68@*"%E;7!T>2@D=&AI
M<RT^;&EM:70I("8F(&-O=6YT*"1T:&ES+3YA9&1R97-S97,I(#T]("1T:&ES
M+3YL:6UI="D@>PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H*
M("`@("`@("!I9B`H)'1H:7,M/E]I<T=R;W5P*"1A9&1R97-S*2`F)B`A:7-S
M970H)'1H:7,M/F5R<F]R*2D@>PH@("`@("`@("`@("`D<W!L:71?8VAA<B`]
M("<[)SL*("`@("`@("`@("`@)&ES7V=R;W5P("`@/2!T<G5E.PH@("`@("`@
M('T@96QS96EF("@A:7-S970H)'1H:7,M/F5R<F]R*2D@>PH@("`@("`@("`@
M("`D<W!L:71?8VAA<B`]("<L)SL*("`@("`@("`@("`@)&ES7V=R;W5P("`@
M/2!F86QS93L*("`@("`@("!](&5L<V5I9B`H:7-S970H)'1H:7,M/F5R<F]R
M*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("`O+R!3<&QI="!T:&4@<W1R:6YG(&)A<V5D(&]N('1H92!A8F]V92!T
M96X@;W(@<V\@;&EN97,N"B`@("`@("`@)'!A<G1S("`](&5X<&QO9&4H)'-P
M;&ET7V-H87(L("1A9&1R97-S*3L*("`@("`@("`D<W1R:6YG(#T@)'1H:7,M
M/E]S<&QI=$-H96-K*"1P87)T<RP@)'-P;&ET7V-H87(I.PH*("`@("`@("`O
M+R!)9B!A(&=R;W5P+BXN"B`@("`@("`@:68@*"1I<U]G<F]U<"D@>PH@("`@
M("`@("`@("`O+R!)9B`D<W1R:6YG(&1O97,@;F]T(&-O;G1A:6X@82!C;VQO
M;B!O=71S:61E(&]F"B`@("`@("`@("`@("\O(&)R86-K971S+W%U;W1E<R!E
M=&,@=&AE;B!S;VUE=&AI;F<G<R!F=6)A<BX*"B`@("`@("`@("`@("\O($9I
M<G-T(&-H96-K('1H97)E)W,@82!C;VQO;B!A="!A;&PZ"B`@("`@("`@("`@
M(&EF("AS=')P;W,H)'-T<FEN9RP@)SHG*2`]/3T@9F%L<V4I('L*("`@("`@
M("`@("`@("`@("1T:&ES+3YE<G)O<B`]("=);G9A;&ED(&%D9')E<W,Z("<@
M+B`D<W1R:6YG.PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`O+R!.;W<@8VAE8VL@:70G<R!O=71S
M:61E(&]F(&)R86-K971S+W%U;W1E<SH*("`@("`@("`@("`@:68@*"$D=&AI
M<RT^7W-P;&ET0VAE8VLH97AP;&]D92@G.B<L("1S=')I;F<I+"`G.B<I*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("\O(%=E(&UU<W0@:&%V92!A(&=R;W5P(&%T('1H:7,@
M<&]I;G0L('-O(&EN8W)E87-E('1H92!C;W5N=&5R.@H@("`@("`@("`@("`D
M=&AI<RT^;G5M7V=R;W5P<RLK.PH@("`@("`@('T*"B`@("`@("`@+R\@)'-T
M<FEN9R!N;W<@8V]N=&%I;G,@=&AE(&9I<G-T(&9U;&P@861D<F5S<R]G<F]U
M<"X*("`@("`@("`O+R!!9&0@=&\@=&AE(&%D9')E<W-E<R!A<G)A>2X*("`@
M("`@("`D=&AI<RT^861D<F5S<V5S6UT@/2!A<G)A>2@*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G861D<F5S<R<@/3X@=')I;2@D<W1R
M:6YG*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9W)O
M=7`G("`@/3X@)&ES7V=R;W5P"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@*3L*"B`@("`@("`@+R\@4F5M;W9E('1H92!N;W<@<W1O<F5D
M(&%D9')E<W,@9G)O;2!T:&4@:6YI=&EA;"!L:6YE+"!T:&4@*S$*("`@("`@
M("`O+R!I<R!T;R!A8V-O=6YT(&9O<B!T:&4@97AP;&]D92!C:&%R86-T97(N
M"B`@("`@("`@)&%D9')E<W,@/2!T<FEM*'-U8G-T<B@D861D<F5S<RP@<W1R
M;&5N*"1S=')I;F<I("L@,2DI.PH*("`@("`@("`O+R!)9B!T:&4@;F5X="!C
M:&%R(&ES(&$@8V]M;6$@86YD('1H:7,@=V%S(&$@9W)O=7`L('1H96X*("`@
M("`@("`O+R!T:&5R92!A<F4@;6]R92!A9&1R97-S97,L(&]T:&5R=VES92P@
M:68@=&AE<F4@87)E(&%N>2!M;W)E"B`@("`@("`@+R\@8VAA<G,L('1H96X@
M=&AE<F4@:7,@86YO=&AE<B!A9&1R97-S+@H@("`@("`@(&EF("@D:7-?9W)O
M=7`@)B8@<W5B<W1R*"1A9&1R97-S+"`P+"`Q*2`]/2`G+"<I>PH@("`@("`@
M("`@("`D861D<F5S<R`]('1R:6TH<W5B<W1R*"1A9&1R97-S+"`Q*2D["B`@
M("`@("`@("`@(')E='5R;B`D861D<F5S<SL*"B`@("`@("`@?2!E;'-E:68@
M*'-T<FQE;B@D861D<F5S<RD@/B`P*2!["B`@("`@("`@("`@(')E='5R;B`D
M861D<F5S<SL*"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M("<G.PH@("`@("`@('T*"B`@("`@("`@+R\@268@>6]U(&=O="!H97)E('1H
M96X@<V]M971H:6YG)W,@;V9F"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@0VAE8VMS(&9O<B!A(&=R;W5P(&%T('1H92!S
M=&%R="!O9B!T:&4@<W1R:6YG+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H@0'!A<F%M('-T<FEN9R`D861D<F5S<R!4:&4@861D<F5S
M<R!T;R!C:&5C:RX*("`@("`J($!R971U<FX@8F]O;&5A;B!7:&5T:&5R(&]R
M(&YO="!T:&5R92!I<R!A(&=R;W5P(&%T('1H92!S=&%R="!O9B!T:&4@<W1R
M:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!?:7-'<F]U<"@D861D<F5S<RD*
M("`@('L*("`@("`@("`O+R!&:7)S="!C;VUM82!N;W0@:6X@<75O=&5S+"!A
M;F=L97,@;W(@97-C87!E9#H*("`@("`@("`D<&%R=',@(#T@97AP;&]D92@G
M+"<L("1A9&1R97-S*3L*("`@("`@("`D<W1R:6YG(#T@)'1H:7,M/E]S<&QI
M=$-H96-K*"1P87)T<RP@)RPG*3L*"B`@("`@("`@+R\@3F]W('=E(&AA=F4@
M=&AE(&9I<G-T(&%D9')E<W,L('=E(&-A;B!R96QI86)L>2!C:&5C:R!F;W(@
M80H@("`@("`@("\O(&=R;W5P(&)Y('-E87)C:&EN9R!F;W(@82!C;VQO;B!T
M:&%T)W,@;F]T(&5S8V%P960@;W(@:6X*("`@("`@("`O+R!Q=6]T97,@;W(@
M86YG;&4@8G)A8VME=',N"B`@("`@("`@:68@*&-O=6YT*"1P87)T<R`](&5X
M<&QO9&4H)SHG+"`D<W1R:6YG*2D@/B`Q*2!["B`@("`@("`@("`@("1S=')I
M;F<R(#T@)'1H:7,M/E]S<&QI=$-H96-K*"1P87)T<RP@)SHG*3L*("`@("`@
M("`@("`@<F5T=7)N("@D<W1R:6YG,B`A/3T@)'-T<FEN9RD["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($$@8V]M;6]N(&9U;F-T:6]N('1H870@
M=VEL;"!C:&5C:R!A;B!E>'!L;V1E9"!S=')I;F<N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@87)R87D@)'!A<G1S(%1H
M92!E>&QO9&5D('-T<FEN9RX*("`@("`J($!P87)A;2!S=')I;F<@)&-H87(@
M(%1H92!C:&%R('1H870@=V%S(&5X<&QO9&5D(&]N+@H@("`@("H@0')E='5R
M;B!M:7AE9"!&86QS92!I9B!T:&4@<W1R:6YG(&-O;G1A:6YS('5N8VQO<V5D
M('%U;W1E<R]B<F%C:V5T<RP@;W(@=&AE('-T<FEN9R!O;B!S=6-C97-S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?<W!L:71#:&5C:R@D<&%R=',L("1C:&%R
M*0H@("`@>PH@("`@("`@("1S=')I;F<@/2`D<&%R='-;,%T["@H@("`@("`@
M(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1P87)T<RD[("1I*RLI('L*("`@
M("`@("`@("`@:68@*"1T:&ES+3Y?:&%S56YC;&]S9611=6]T97,H)'-T<FEN
M9RD*("`@("`@("`@("`@("`@('Q\("1T:&ES+3Y?:&%S56YC;&]S961"<F%C
M:V5T<R@D<W1R:6YG+"`G/#XG*0H@("`@("`@("`@("`@("`@?'P@)'1H:7,M
M/E]H87-5;F-L;W-E9$)R86-K971S*"1S=')I;F<L("=;72<I"B`@("`@("`@
M("`@("`@("!\?"`D=&AI<RT^7VAA<U5N8VQO<V5D0G)A8VME=',H)'-T<FEN
M9RP@)R@I)RD*("`@("`@("`@("`@("`@('Q\('-U8G-T<B@D<W1R:6YG+"`M
M,2D@/3T@)UQ<)RD@>PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P87)T
M<ULD:2`K(#%=*2D@>PH@("`@("`@("`@("`@("`@("`@("1S=')I;F<@/2`D
M<W1R:6YG("X@)&-H87(@+B`D<&%R='-;)&D@*R`Q73L*("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F5R<F]R
M(#T@)TEN=F%L:60@861D<F5S<R!S<&5C+B!5;F-L;W-E9"!B<F%C:V5T(&]R
M('%U;W1E<R<["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/FEN9&5X(#T@)&D["B`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1S=')I;F<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@:68@82!S
M=')I;F<@:&%S(&%N('5N8VQO<V5D('%U;W1E<R!O<B!N;W0N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@<W1R:6YG("1S
M=')I;F<@5&AE('-T<FEN9R!T;R!C:&5C:RX*("`@("`J($!R971U<FX@8F]O
M;&5A;B!4<G5E(&EF('1H97)E(&%R92!U;F-L;W-E9"!Q=6]T97,@:6YS:61E
M('1H92!S=')I;F<L(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@7VAA<U5N8VQO<V5D475O=&5S*"1S=')I;F<I"B`@("!["B`@("`@
M("`@)'-T<FEN9R`@("`@/2!E>'!L;V1E*"<B)RP@)'-T<FEN9RD["B`@("`@
M("`@)'-T<FEN9U]C;G0@/2!C;W5N="@D<W1R:6YG*3L*"B`@("`@("`@9F]R
M("@D:2`](#`[("1I(#P@*&-O=6YT*"1S=')I;F<I("T@,2D[("1I*RLI"B`@
M("`@("`@("`@(&EF("AS=6)S='(H)'-T<FEN9ULD:5TL("TQ*2`]/2`G7%PG
M*0H@("`@("`@("`@("`@("`@)'-T<FEN9U]C;G0M+3L*"B`@("`@("`@<F5T
M=7)N("@D<W1R:6YG7V-N="`E(#(@/3T](#`I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@0VAE8VMS(&EF(&$@<W1R:6YG(&AA<R!A;B!U;F-L;W-E9"!B<F%C
M:V5T<R!O<B!N;W0N($E-4$]25$%.5#H*("`@("`J(%1H:7,@9G5N8W1I;VX@
M:&%N9&QE<R!B;W1H(&%N9VQE(&)R86-K971S(&%N9"!S<75A<F4@8G)A8VME
M=',["B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1S=')I;F<@5&AE('-T<FEN9R!T;R!C:&5C:RX*("`@("`J
M($!P87)A;2!S=')I;F<@)&-H87)S("!4:&4@8VAA<F%C=&5R<R!T;R!C:&5C
M:R!F;W(N"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@5')U92!I9B!T:&5R92!A
M<F4@=6YC;&]S960@8G)A8VME=',@:6YS:61E('1H92!S=')I;F<L(&9A;'-E
M(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@7VAA<U5N8VQO<V5D
M0G)A8VME=',H)'-T<FEN9RP@)&-H87)S*0H@("`@>PH@("`@("`@("1N=6U?
M86YG;&5?<W1A<G0@/2!S=6)S=')?8V]U;G0H)'-T<FEN9RP@)&-H87)S6S!=
M*3L*("`@("`@("`D;G5M7V%N9VQE7V5N9"`@(#T@<W5B<W1R7V-O=6YT*"1S
M=')I;F<L("1C:&%R<ULQ72D["@H@("`@("`@("1T:&ES+3Y?:&%S56YC;&]S
M961"<F%C:V5T<U-U8B@D<W1R:6YG+"`D;G5M7V%N9VQE7W-T87)T+"`D8VAA
M<G-;,%TI.PH@("`@("`@("1T:&ES+3Y?:&%S56YC;&]S961"<F%C:V5T<U-U
M8B@D<W1R:6YG+"`D;G5M7V%N9VQE7V5N9"P@)&-H87)S6S%=*3L*"B`@("`@
M("`@:68@*"1N=6U?86YG;&5?<W1A<G0@/"`D;G5M7V%N9VQE7V5N9"D@>PH@
M("`@("`@("`@("`D=&AI<RT^97)R;W(@/2`G26YV86QI9"!A9&1R97-S('-P
M96,N(%5N;6%T8VAE9"!Q=6]T92!O<B!B<F%C:V5T("@G("X@)&-H87)S("X@
M)RDG.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@<F5T=7)N("@D;G5M7V%N9VQE7W-T87)T(#X@)&YU
M;5]A;F=L95]E;F0I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%-U8B!F=6YC=&EO;B!T:&%T(&ES('5S960@;VYL>2!B>2!H87-5;F-L;W-E
M9$)R86-K971S*"DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1S=')I;F<@5&AE('-T<FEN9R!T;R!C:&5C
M:RX*("`@("`J($!P87)A;2!I;G1E9V5R("8D;G5M("`@(%1H92!N=6UB97(@
M;V8@;V-C=7)E;F-E<RX*("`@("`J($!P87)A;2!S=')I;F<@)&-H87(@("!4
M:&4@8VAA<F%C=&5R('1O(&-O=6YT+@H@("`@("H@0')E='5R;B!I;G1E9V5R
M(%1H92!N=6UB97(@;V8@;V-C=7)E;F-E<R!O9B`D8VAA<B!I;B`D<W1R:6YG
M+"!A9&IU<W1E9"!F;W(@8F%C:W-L87-H97,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]H87-5;F-L;W-E9$)R86-K971S4W5B*"1S=')I;F<L("8D;G5M+"`D
M8VAA<BD*("`@('L*("`@("`@("`D<&%R=',@/2!E>'!L;V1E*"1C:&%R+"`D
M<W1R:6YG*3L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D<&%R
M=',I.R`D:2LK*7L*("`@("`@("`@("`@:68@*'-U8G-T<B@D<&%R='-;)&E=
M+"`M,2D@/3T@)UQ<)R!\?"`D=&AI<RT^7VAA<U5N8VQO<V5D475O=&5S*"1P
M87)T<ULD:5TI*0H@("`@("`@("`@("`@("`@)&YU;2TM.PH@("`@("`@("`@
M("!I9B`H:7-S970H)'!A<G1S6R1I("L@,5TI*0H@("`@("`@("`@("`@("`@
M)'!A<G1S6R1I("L@,5T@/2`D<&%R='-;)&E=("X@)&-H87(@+B`D<&%R='-;
M)&D@*R`Q73L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;G5M.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1G5N8W1I;VX@=&\@8F5G:6X@8VAE8VMI;F<@
M=&AE(&%D9')E<W,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1A9&1R97-S(%1H92!A9&1R97-S('1O('9A
M;&ED871E+@H@("`@("H@0')E='5R;B!M:7AE9"!&86QS92!O;B!F86EL=7)E
M+"!O<B!A('-T<G5C='5R960@87)R87D@;V8@861D<F5S<R!I;F9O<FUA=&EO
M;B!O;B!S=6-C97-S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=F%L:61A=&5!
M9&1R97-S*"1A9&1R97-S*0H@("`@>PH@("`@("`@("1I<U]G<F]U<"`](&9A
M;'-E.PH@("`@("`@("1A9&1R97-S97,@/2!A<G)A>2@I.PH*("`@("`@("!I
M9B`H)&%D9')E<W-;)V=R;W5P)UTI('L*("`@("`@("`@("`@)&ES7V=R;W5P
M(#T@=')U93L*"B`@("`@("`@("`@("\O($=E="!T:&4@9W)O=7`@<&%R="!O
M9B!T:&4@;F%M90H@("`@("`@("`@("`D<&%R=',@("`@(#T@97AP;&]D92@G
M.B<L("1A9&1R97-S6R=A9&1R97-S)UTI.PH@("`@("`@("`@("`D9W)O=7!N
M86UE(#T@)'1H:7,M/E]S<&QI=$-H96-K*"1P87)T<RP@)SHG*3L*("`@("`@
M("`@("`@)'-T<G5C='5R92`](&%R<F%Y*"D["@H@("`@("`@("`@("`O+R!!
M;F0@=F%L:61A=&4@=&AE(&=R;W5P('!A<G0@;V8@=&AE(&YA;64N"B`@("`@
M("`@("`@(&EF("@A)'1H:7,M/E]V86QI9&%T95!H<F%S92@D9W)O=7!N86UE
M*2E["B`@("`@("`@("`@("`@("`D=&AI<RT^97)R;W(@/2`G1W)O=7`@;F%M
M92!D:60@;F]T('9A;&ED871E+B<["B`@("`@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O
M+R!$;VXG="!I;F-L=61E(&=R;W5P<R!I9B!W92!A<F4@;F]T(&YE<W1I;F<*
M("`@("`@("`@("`@("`@("\O('1H96TN(%1H:7,@879O:61S(')E='5R;FEN
M9R!I;G9A;&ED(&%D9')E<W-E<RX*("`@("`@("`@("`@("`@(&EF("@D=&AI
M<RT^;F5S=$=R;W5P<RD@>PH@("`@("`@("`@("`@("`@("`@("1S=')U8W1U
M<F4@/2!N97<@<W1D0VQA<W,["B`@("`@("`@("`@("`@("`@("`@)'-T<G5C
M='5R92T^9W)O=7!N86UE(#T@)&=R;W5P;F%M93L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&%D9')E<W-;)V%D9')E
M<W,G72`](&QT<FEM*'-U8G-T<B@D861D<F5S<ULG861D<F5S<R==+"!S=')L
M96XH)&=R;W5P;F%M92`N("<Z)RDI*3L*("`@("`@("!]"@H@("`@("`@("\O
M($EF(&$@9W)O=7`@=&AE;B!S<&QI="!O;B!C;VUM82!A;F0@<'5T(&EN=&\@
M86X@87)R87DN"B`@("`@("`@+R\@3W1H97)W:7-E+"!*=7-T('!U="!T:&4@
M=VAO;&4@861D<F5S<R!I;B!A;B!A<G)A>2X*("`@("`@("!I9B`H)&ES7V=R
M;W5P*2!["B`@("`@("`@("`@('=H:6QE("AS=')L96XH)&%D9')E<W-;)V%D
M9')E<W,G72D@/B`P*2!["B`@("`@("`@("`@("`@("`D<&%R=',@("`@("`@
M/2!E>'!L;V1E*"<L)RP@)&%D9')E<W-;)V%D9')E<W,G72D["B`@("`@("`@
M("`@("`@("`D861D<F5S<V5S6UT@/2`D=&AI<RT^7W-P;&ET0VAE8VLH)'!A
M<G1S+"`G+"<I.PH@("`@("`@("`@("`@("`@)&%D9')E<W-;)V%D9')E<W,G
M72`]('1R:6TH<W5B<W1R*"1A9&1R97-S6R=A9&1R97-S)UTL('-T<FQE;BAE
M;F0H)&%D9')E<W-E<RD@+B`G+"<I*2D["B`@("`@("`@("`@('T*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D861D<F5S<V5S6UT@/2`D861D<F5S
M<ULG861D<F5S<R==.PH@("`@("`@('T*"B`@("`@("`@+R\@0VAE8VL@=&AA
M="`D861D<F5S<V5S(&ES('-E="P@:68@861D<F5S<R!L:6ME('1H:7,Z"B`@
M("`@("`@+R\@1W)O=7!N86UE.CL*("`@("`@("`O+R!4:&5N(&5R<F]R<R!W
M97)E(&%P<&5A<FEN9RX*("`@("`@("!I9B`H(6-O=6YT*"1A9&1R97-S97,I
M*7L*("`@("`@("`@("`@)'1H:7,M/F5R<F]R(#T@)T5M<'1Y(&=R;W5P+B<[
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@
M("\O(%1R:6T@=&AE('=H:71E<W!A8V4@9G)O;2!A;&P@;V8@=&AE(&%D9')E
M<W,@<W1R:6YG<RX*("`@("`@("!A<G)A>5]M87`H)W1R:6TG+"`D861D<F5S
M<V5S*3L*"B`@("`@("`@+R\@5F%L:61A=&4@96%C:"!M86EL8F]X+@H@("`@
M("`@("\O($9O<FUA="!C;W5L9"!B92!O;F4@;V8Z(&YA;64@/&=E97IE<D!D
M;VUA:6XN8V]M/@H@("`@("`@("\O("`@("`@("`@("`@("`@("`@("`@("`@
M(&=E97IE<D!D;VUA:6XN8V]M"B`@("`@("`@+R\@("`@("`@("`@("`@("`@
M("`@("`@("`@9V5E>F5R"B`@("`@("`@+R\@+BXN(&]R(&%N>2!O=&AE<B!F
M;W)M870@=F%L:60@8GD@4D9#(#@R,BX*("`@("`@("!F;W(@*"1I(#T@,#L@
M)&D@/"!C;W5N="@D861D<F5S<V5S*3L@)&DK*RD@>PH@("`@("`@("`@("!I
M9B`H(21T:&ES+3YV86QI9&%T94UA:6QB;W@H)&%D9')E<W-E<ULD:5TI*2![
M"B`@("`@("`@("`@("`@("!I9B`H96UP='DH)'1H:7,M/F5R<F]R*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YE<G)O<B`]("=686QI9&%T:6]N
M(&9A:6QE9"!F;W(Z("<@+B`D861D<F5S<V5S6R1I73L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@3F5S=&5D(&9O<FUA=`H@("`@
M("`@(&EF("@D=&AI<RT^;F5S=$=R;W5P<RD@>PH@("`@("`@("`@("!I9B`H
M)&ES7V=R;W5P*2!["B`@("`@("`@("`@("`@("`D<W1R=6-T=7)E+3YA9&1R
M97-S97,@/2`D861D<F5S<V5S.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@)'-T<G5C='5R92`]("1A9&1R97-S97-;,%T["B`@("`@
M("`@("`@('T*"B`@("`@("`@+R\@1FQA="!F;W)M870*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!I9B`H)&ES7V=R;W5P*2!["B`@("`@("`@("`@
M("`@("`D<W1R=6-T=7)E(#T@87)R87E?;65R9V4H)'-T<G5C='5R92P@)&%D
M9')E<W-E<RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D<W1R=6-T=7)E(#T@)&%D9')E<W-E<SL*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1S=')U8W1U<F4["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!&=6YC=&EO;B!T;R!V86QI9&%T92!A('!H<F%S92X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!P87)A;2!S=')I
M;F<@)'!H<F%S92!4:&4@<&AR87-E('1O(&-H96-K+@H@("`@("H@0')E='5R
M;B!B;V]L96%N(%-U8V-E<W,@;W(@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@7W9A;&ED871E4&AR87-E*"1P:')A<V4I"B`@("!["B`@("`@("`@
M+R\@4W!L:71S(&]N(&]N92!O<B!M;W)E(%1A8B!O<B!S<&%C92X*("`@("`@
M("`D<&%R=',@/2!P<F5G7W-P;&ET*"<O6R!<7'@P.5TK+R<L("1P:')A<V4L
M("TQ+"!04D5'7U-03$E47TY/7T5-4%19*3L*"B`@("`@("`@)'!H<F%S95]P
M87)T<R`](&%R<F%Y*"D["B`@("`@("`@=VAI;&4@*&-O=6YT*"1P87)T<RD@
M/B`P*7L*("`@("`@("`@("`@)'!H<F%S95]P87)T<UM=(#T@)'1H:7,M/E]S
M<&QI=$-H96-K*"1P87)T<RP@)R`G*3L*("`@("`@("`@("`@9F]R("@D:2`]
M(#`[("1I(#P@)'1H:7,M/FEN9&5X("L@,3L@)&DK*RD*("`@("`@("`@("`@
M("`@(&%R<F%Y7W-H:69T*"1P87)T<RD["B`@("`@("`@?0H*("`@("`@("!F
M;W)E86-H("@D<&AR87-E7W!A<G1S(&%S("1P87)T*2!["B`@("`@("`@("`@
M("\O($EF('%U;W1E9"!S=')I;F<Z"B`@("`@("`@("`@(&EF("AS=6)S='(H
M)'!A<G0L(#`L(#$I(#T]("<B)RD@>PH@("`@("`@("`@("`@("`@:68@*"$D
M=&AI<RT^7W9A;&ED871E475O=&5D4W1R:6YG*"1P87)T*2D@>PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`O+R!/=&AE<G=I<V4@:70G<R!A;B!A=&]M.@H@("`@("`@("`@
M("!I9B`H(21T:&ES+3Y?=F%L:61A=&5!=&]M*"1P87)T*2D@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!&=6YC=&EO;B!T;R!V86QI9&%T92!A;B!A=&]M('=H
M:6-H(&9R;VT@<F9C.#(R(&ES.@H@("`@("H@871O;2`](#$J/&%N>2!#2$%2
M(&5X8V5P="!S<&5C:6%L<RP@4U!!0T4@86YD($-43',^"B`@("`@*@H@("`@
M("H@268@=F%L:61A=&EO;B`H)'1H:7,M/G9A;&ED871E*2!H87,@8F5E;B!T
M=7)N960@;V9F+"!T:&5N"B`@("`@*B!V86QI9&%T94%T;VTH*2!D;V5S;B=T
M(&%C='5A;&QY(&-H96-K(&%N>71H:6YG+B!4:&ES(&ES('-O('1H870@>6]U
M"B`@("`@*B!C86X@<W!L:70@82!L:7-T(&]F(&%D9')E<W-E<R!U<"!B969O
M<F4@96YC;V1I;F<@<&5R<V]N86P@;F%M97,*("`@("`J("AU;6QA=71S+"!E
M=&,N*2P@9F]R(&5X86UP;&4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*B!`<&%R86T@<W1R:6YG("1A=&]M(%1H92!S=')I;F<@=&\@
M8VAE8VLN"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@4W5C8V5S<R!O<B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=F%L:61A=&5!=&]M*"1A=&]M
M*0H@("`@>PH@("`@("`@(&EF("@A)'1H:7,M/G9A;&ED871E*2!["B`@("`@
M("`@("`@("\O(%9A;&ED871I;VX@:&%S(&)E96X@='5R;F5D(&]F9CL@87-S
M=6UE('1H92!A=&]M(&ES(&]K87DN"B`@("`@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@("`@('T*"B`@("`@("`@+R\@0VAE8VL@9F]R(&%N>2!C:&%R(&9R
M;VT@05-#24D@,"`M($%30TE)(#$R-PH@("`@("`@(&EF("@A<')E9U]M871C
M:"@G+UY;7%QX,#`M7%QX-T5=*R0O:2<L("1A=&]M+"`D;6%T8VAE<RDI('L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@
M+R\@0VAE8VL@9F]R('-P96-I86QS.@H@("`@("`@(&EF("AP<F5G7VUA=&-H
M*"<O6UU;*"D\/D`L.UQ<.B(N(%TO)RP@)&%T;VTI*2!["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("\O($-H96-K(&9O
M<B!C;VYT<F]L(&-H87)A8W1E<G,@*$%30TE)(#`M,S$I.@H@("`@("`@(&EF
M("AP<F5G7VUA=&-H*"<O6UQ<>#`P+5Q<>#%&72LO)RP@)&%T;VTI*2!["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@1G5N8W1I;VX@=&\@
M=F%L:61A=&4@<75O=&5D('-T<FEN9RP@=VAI8V@@:7,Z"B`@("`@*B!Q=6]T
M960M<W1R:6YG(#T@/"(^("HH<71E>'0O<75O=&5D+7!A:7(I(#PB/@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<7-T<FEN9R!4:&4@<W1R:6YG('1O(&-H96-K"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@4W5C8V5S<R!O<B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?=F%L:61A=&51=6]T9613=')I;F<H)'%S=')I;F<I"B`@("!["B`@
M("`@("`@+R\@3&5A9&EN9R!A;F0@=')A:6QI;F<@(@H@("`@("`@("1Q<W1R
M:6YG(#T@<W5B<W1R*"1Q<W1R:6YG+"`Q+"`M,2D["@H@("`@("`@("\O(%!E
M<F9O<FT@8VAE8VLL(')E;6]V:6YG('%U;W1E9"!C:&%R86-T97)S(&9I<G-T
M+@H@("`@("`@(')E='5R;B`A<')E9U]M871C:"@G+UM<>#!$7%Q<7")=+R<L
M('!R96=?<F5P;&%C92@G+UQ<7%PN+R<L("<G+"`D<7-T<FEN9RDI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1G5N8W1I;VX@=&\@=F%L:61A=&4@82!M86EL
M8F]X+"!W:&EC:"!I<SH*("`@("`J(&UA:6QB;W@@/2`@(&%D9'(M<W!E8R`@
M("`@("`@(#L@<VEM<&QE(&%D9')E<W,*("`@("`J("`@("`@("`@("`O('!H
M<F%S92!R;W5T92UA9&1R(#L@;F%M92!A;F0@<F]U=&4M861D<@H@("`@("H*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@<W1R:6YG("8D
M;6%I;&)O>"!4:&4@<W1R:6YG('1O(&-H96-K+@H@("`@("H@0')E='5R;B!B
M;V]L96%N(%-U8V-E<W,@;W(@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@=F%L:61A=&5-86EL8F]X*"8D;6%I;&)O>"D*("`@('L*("`@("`@("`O
M+R!!(&-O=7!L92!O9B!D969A=6QT<RX*("`@("`@("`D<&AR87-E("`]("<G
M.PH@("`@("`@("1C;VUM96YT(#T@)R<["B`@("`@("`@)&-O;6UE;G1S(#T@
M87)R87DH*3L*"B`@("`@("`@+R\@0V%T8V@@86YY(%)&0S@R,B!C;VUM96YT
M<R!A;F0@<W1O<F4@=&AE;2!S97!A<F%T96QY+@H@("`@("`@("1?;6%I;&)O
M>"`]("1M86EL8F]X.PH@("`@("`@('=H:6QE("AS=')L96XH=')I;2@D7VUA
M:6QB;W@I*2`^(#`I('L*("`@("`@("`@("`@)'!A<G1S(#T@97AP;&]D92@G
M*"<L("1?;6%I;&)O>"D["B`@("`@("`@("`@("1B969O<F5?8V]M;65N="`]
M("1T:&ES+3Y?<W!L:71#:&5C:R@D<&%R=',L("<H)RD["B`@("`@("`@("`@
M(&EF("@D8F5F;W)E7V-O;6UE;G0@(3T@)%]M86EL8F]X*2!["B`@("`@("`@
M("`@("`@("`O+R!&:7)S="!C:&%R('-H;W5L9"!B92!A("@N"B`@("`@("`@
M("`@("`@("`D8V]M;65N="`@("`]('-U8G-T<BAS=')?<F5P;&%C92@D8F5F
M;W)E7V-O;6UE;G0L("<G+"`D7VUA:6QB;W@I+"`Q*3L*("`@("`@("`@("`@
M("`@("1P87)T<R`@("`@(#T@97AP;&]D92@G*2<L("1C;VUM96YT*3L*("`@
M("`@("`@("`@("`@("1C;VUM96YT("`@(#T@)'1H:7,M/E]S<&QI=$-H96-K
M*"1P87)T<RP@)RDG*3L*("`@("`@("`@("`@("`@("1C;VUM96YT<UM=(#T@
M)&-O;6UE;G0["@H@("`@("`@("`@("`@("`@+R\@*S$@:7,@9F]R('1H92!T
M<F%I;&EN9R`I"B`@("`@("`@("`@("`@("`D7VUA:6QB;W@@("`]('-U8G-T
M<B@D7VUA:6QB;W@L('-T<G!O<R@D7VUA:6QB;W@L("1C;VUM96YT*2MS=')L
M96XH)&-O;6UE;G0I*S$I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(&9O<F5A8V@@*"1C;VUM96YT<R!A<R`D8V]M;65N="D@>PH@("`@("`@
M("`@("`D;6%I;&)O>"`]('-T<E]R97!L86-E*"(H)&-O;6UE;G0I(BP@)R<L
M("1M86EL8F]X*3L*("`@("`@("!]"@H@("`@("`@("1M86EL8F]X(#T@=')I
M;2@D;6%I;&)O>"D["@H@("`@("`@("\O($-H96-K(&9O<B!N86UE("L@<F]U
M=&4M861D<@H@("`@("`@(&EF("AS=6)S='(H)&UA:6QB;W@L("TQ*2`]/2`G
M/B<@)B8@<W5B<W1R*"1M86EL8F]X+"`P+"`Q*2`A/2`G/"<I('L*("`@("`@
M("`@("`@)'!A<G1S("`](&5X<&QO9&4H)SPG+"`D;6%I;&)O>"D["B`@("`@
M("`@("`@("1N86UE("`@/2`D=&AI<RT^7W-P;&ET0VAE8VLH)'!A<G1S+"`G
M/"<I.PH*("`@("`@("`@("`@)'!H<F%S92`@("`@/2!T<FEM*"1N86UE*3L*
M("`@("`@("`@("`@)')O=71E7V%D9'(@/2!T<FEM*'-U8G-T<B@D;6%I;&)O
M>"P@<W1R;&5N*"1N86UE+B<\)RDL("TQ*2D["@H@("`@("`@("`@("!I9B`H
M)'1H:7,M/E]V86QI9&%T95!H<F%S92@D<&AR87-E*2`]/3T@9F%L<V4@?'P@
M*"1R;W5T95]A9&1R(#T@)'1H:7,M/E]V86QI9&%T95)O=71E061D<B@D<F]U
M=&5?861D<BDI(#T]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@("`@("!]"@H@("`@("`@("\O($]N;'D@9V]T(&%D
M9'(M<W!E8PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O($9I<G-T
M('-N:7`@86YG;&4@8G)A8VME=',@:68@<')E<V5N="X*("`@("`@("`@("`@
M:68@*'-U8G-T<B@D;6%I;&)O>"P@,"P@,2D@/3T@)SPG("8F('-U8G-T<B@D
M;6%I;&)O>"P@+3$I(#T]("<^)RD@>PH@("`@("`@("`@("`@("`@)&%D9')?
M<W!E8R`]('-U8G-T<B@D;6%I;&)O>"P@,2P@+3$I.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)&%D9')?<W!E8R`]("1M86EL8F]X
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H*"1A9&1R7W-P96,@
M/2`D=&AI<RT^7W9A;&ED871E061D<E-P96,H)&%D9')?<W!E8RDI(#T]/2!F
M86QS92D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!#;VYS=')U8W0@=&AE(&]B
M:F5C="!T:&%T('=I;&P@8F4@<F5T=7)N960N"B`@("`@("`@)&UB;W@@/2!N
M97<@<W1D0VQA<W,H*3L*"B`@("`@("`@+R\@061D('1H92!P:')A<V4@*&5V
M96X@:68@96UP='DI(&%N9"!C;VUM96YT<PH@("`@("`@("1M8F]X+3YP97)S
M;VYA;"`]("1P:')A<V4["B`@("`@("`@)&UB;W@M/F-O;6UE;G0@(#T@:7-S
M970H)&-O;6UE;G1S*2`_("1C;VUM96YT<R`Z(&%R<F%Y*"D["@H@("`@("`@
M(&EF("AI<W-E="@D<F]U=&5?861D<BDI('L*("`@("`@("`@("`@)&UB;W@M
M/FUA:6QB;W@@/2`D<F]U=&5?861D<ELG;&]C86Q?<&%R="==.PH@("`@("`@
M("`@("`D;6)O>"T^:&]S="`@("`]("1R;W5T95]A9&1R6R=D;VUA:6XG73L*
M("`@("`@("`@("`@)')O=71E7V%D9');)V%D;"==("$]/2`G)R`_("1M8F]X
M+3YA9&P@/2`D<F]U=&5?861D<ELG861L)UT@.B`G)SL*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D;6)O>"T^;6%I;&)O>"`]("1A9&1R7W-P96-;
M)VQO8V%L7W!A<G0G73L*("`@("`@("`@("`@)&UB;W@M/FAO<W0@("`@/2`D
M861D<E]S<&5C6R=D;VUA:6XG73L*("`@("`@("!]"@H@("`@("`@("1M86EL
M8F]X(#T@)&UB;W@["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!4:&ES(&9U;F-T:6]N('9A;&ED871E<R!A(')O=71E+6%D
M9'(@=VAI8V@@:7,Z"B`@("`@*B!R;W5T92UA9&1R(#T@(CPB(%MR;W5T95T@
M861D<BUS<&5C("(^(@H@("`@("H*("`@("`J($%N9VQE(&)R86-K971S(&AA
M=F4@86QR96%D>2!B965N(')E;6]V960@870@=&AE('!O:6YT(&]F"B`@("`@
M*B!G971T:6YG('1O('1H:7,@9G5N8W1I;VXN"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@<W1R:6YG("1R;W5T95]A9&1R
M(%1H92!S=')I;F<@=&\@8VAE8VLN"B`@("`@*B!`<F5T=7)N(&UI>&5D($9A
M;'-E(&]N(&9A:6QU<F4L(&]R(&%N(&%R<F%Y(&-O;G1A:6YI;F<@=F%L:61A
M=&5D(&%D9')E<W,O<F]U=&4@:6YF;W)M871I;VX@;VX@<W5C8V5S<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@7W9A;&ED871E4F]U=&5!9&1R*"1R;W5T95]A
M9&1R*0H@("`@>PH@("`@("`@("\O($-H96-K(&9O<B!C;VQO;BX*("`@("`@
M("!I9B`H<W1R<&]S*"1R;W5T95]A9&1R+"`G.B<I("$]/2!F86QS92D@>PH@
M("`@("`@("`@("`D<&%R=',@/2!E>'!L;V1E*"<Z)RP@)')O=71E7V%D9'(I
M.PH@("`@("`@("`@("`D<F]U=&4@/2`D=&AI<RT^7W-P;&ET0VAE8VLH)'!A
M<G1S+"`G.B<I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R;W5T
M92`]("1R;W5T95]A9&1R.PH@("`@("`@('T*"B`@("`@("`@+R\@268@)')O
M=71E(&ES('-A;64@87,@)')O=71E7V%D9'(@=&AE;B!T:&4@8V]L;VX@=V%S
M(&EN"B`@("`@("`@+R\@<75O=&5S(&]R(&)R86-K971S(&]R+"!O9B!C;W5R
M<V4L(&YO;B!E>&ES=&5N="X*("`@("`@("!I9B`H)')O=71E(#T]/2`D<F]U
M=&5?861D<BE["B`@("`@("`@("`@('5N<V5T*"1R;W5T92D["B`@("`@("`@
M("`@("1A9&1R7W-P96,@/2`D<F]U=&5?861D<CL*("`@("`@("`@("`@:68@
M*"@D861D<E]S<&5C(#T@)'1H:7,M/E]V86QI9&%T94%D9')3<&5C*"1A9&1R
M7W-P96,I*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("\O(%9A;&ED871E(')O=71E('!A<G0N"B`@("`@("`@("`@(&EF("@H
M)')O=71E(#T@)'1H:7,M/E]V86QI9&%T95)O=71E*"1R;W5T92DI(#T]/2!F
M86QS92D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`D861D<E]S<&5C(#T@<W5B<W1R*"1R;W5T
M95]A9&1R+"!S=')L96XH)')O=71E("X@)SHG*2D["@H@("`@("`@("`@("`O
M+R!686QI9&%T92!A9&1R+7-P96,@<&%R="X*("`@("`@("`@("`@:68@*"@D
M861D<E]S<&5C(#T@)'1H:7,M/E]V86QI9&%T94%D9')3<&5C*"1A9&1R7W-P
M96,I*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T
M*"1R;W5T92DI('L*("`@("`@("`@("`@)')E='5R;ELG861L)UT@/2`D<F]U
M=&4["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)')E='5R;ELG861L
M)UT@/2`G)SL*("`@("`@("!]"@H@("`@("`@("1R971U<FX@/2!A<G)A>5]M
M97)G92@D<F5T=7)N+"`D861D<E]S<&5C*3L*("`@("`@("!R971U<FX@)')E
M='5R;CL*("`@('T*"B`@("`O*BH*("`@("`J($9U;F-T:6]N('1O('9A;&ED
M871E(&$@<F]U=&4L('=H:6-H(&ES.@H@("`@("H@<F]U=&4@/2`Q(R@B0"(@
M9&]M86EN*2`B.B(*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J($!P87)A;2!S=')I;F<@)')O=71E(%1H92!S=')I;F<@=&\@8VAE8VLN
M"B`@("`@*B!`<F5T=7)N(&UI>&5D($9A;'-E(&]N(&9A:6QU<F4L(&]R('1H
M92!V86QI9&%T960@)')O=71E(&]N('-U8V-E<W,N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]V86QI9&%T95)O=71E*"1R;W5T92D*("`@('L*("`@("`@("`O
M+R!3<&QI="!O;B!C;VUM82X*("`@("`@("`D9&]M86EN<R`](&5X<&QO9&4H
M)RPG+"!T<FEM*"1R;W5T92DI.PH*("`@("`@("!F;W)E86-H("@D9&]M86EN
M<R!A<R`D9&]M86EN*2!["B`@("`@("`@("`@("1D;VUA:6X@/2!S=')?<F5P
M;&%C92@G0"<L("<G+"!T<FEM*"1D;VUA:6XI*3L*("`@("`@("`@("`@:68@
M*"$D=&AI<RT^7W9A;&ED871E1&]M86EN*"1D;VUA:6XI*2!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')O=71E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1G5N8W1I;VX@=&\@=F%L:61A=&4@82!D;VUA:6XL
M('1H;W5G:"!T:&ES(&ES(&YO="!Q=6ET92!W:&%T"B`@("`@*B!Y;W4@97AP
M96-T(&]F(&$@<W1R:6-T(&EN=&5R;F5T(&1O;6%I;BX*("`@("`J"B`@("`@
M*B!D;VUA:6X@/2!S=6(M9&]M86EN("HH(BXB('-U8BUD;VUA:6XI"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1D;VUA:6X@5&AE('-T<FEN9R!T;R!C:&5C:RX*("`@("`J($!R971U<FX@
M;6EX960@1F%L<V4@;VX@9F%I;'5R92P@;W(@=&AE('9A;&ED871E9"!D;VUA
M:6X@;VX@<W5C8V5S<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W9A;&ED871E
M1&]M86EN*"1D;VUA:6XI"B`@("!["B`@("`@("`@+R\@3F]T92!T:&4@9&EF
M9F5R96YT('5S92!O9B`D<W5B9&]M86EN<R!A;F0@)'-U8E]D;VUA:6YS"B`@
M("`@("`@)'-U8F1O;6%I;G,@/2!E>'!L;V1E*"<N)RP@)&1O;6%I;BD["@H@
M("`@("`@('=H:6QE("AC;W5N="@D<W5B9&]M86EN<RD@/B`P*2!["B`@("`@
M("`@("`@("1S=6)?9&]M86EN<UM=(#T@)'1H:7,M/E]S<&QI=$-H96-K*"1S
M=6)D;VUA:6YS+"`G+B<I.PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@
M/"`D=&AI<RT^:6YD97@@*R`Q.R`D:2LK*0H@("`@("`@("`@("`@("`@87)R
M87E?<VAI9G0H)'-U8F1O;6%I;G,I.PH@("`@("`@('T*"B`@("`@("`@9F]R
M96%C:"`H)'-U8E]D;VUA:6YS(&%S("1S=6)?9&]M86EN*2!["B`@("`@("`@
M("`@(&EF("@A)'1H:7,M/E]V86QI9&%T95-U8F1O;6%I;BAT<FEM*"1S=6)?
M9&]M86EN*2DI"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("`O+R!-86YA9V5D('1O(&=E="!H97)E+"!S;R!R971U
M<FX@:6YP=70N"B`@("`@("`@<F5T=7)N("1D;VUA:6X["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!&=6YC=&EO;B!T;R!V86QI9&%T92!A('-U8F1O;6%I;CH*
M("`@("`J("`@<W5B9&]M86EN(#T@9&]M86EN+7)E9B`O(&1O;6%I;BUL:71E
M<F%L"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1S=6)D;VUA:6X@5&AE('-T<FEN9R!T;R!C:&5C:RX*("`@
M("`J($!R971U<FX@8F]O;&5A;B!3=6-C97-S(&]R(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]V86QI9&%T95-U8F1O;6%I;B@D<W5B9&]M86EN
M*0H@("`@>PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"=\7EQ;*"XJ*5TD?"<L
M("1S=6)D;VUA:6XL("1A<G(I*7L*("`@("`@("`@("`@:68@*"$D=&AI<RT^
M7W9A;&ED871E1&QI=&5R86PH)&%R<ELQ72DI(')E='5R;B!F86QS93L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H(21T:&ES+3Y?=F%L:61A
M=&5!=&]M*"1S=6)D;VUA:6XI*2!R971U<FX@9F%L<V4["B`@("`@("`@?0H*
M("`@("`@("`O+R!';W0@:&5R92P@<V\@<F5T=7)N('-U8V-E<W-F=6PN"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC
M=&EO;B!T;R!V86QI9&%T92!A(&1O;6%I;B!L:71E<F%L.@H@("`@("H@("!D
M;VUA:6XM;&ET97)A;"`]("`B6R(@*BAD=&5X="`O('%U;W1E9"UP86ER*2`B
M72(*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!P87)A
M;2!S=')I;F<@)&1L:71E<F%L(%1H92!S=')I;F<@=&\@8VAE8VLN"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86X@4W5C8V5S<R!O<B!F86EL=7)E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?=F%L:61A=&5$;&ET97)A;"@D9&QI=&5R86PI"B`@
M("!["B`@("`@("`@<F5T=7)N("%P<F5G7VUA=&-H*"<O*"XI6UU;7'@P1%Q<
M7%Q=+R<L("1D;&ET97)A;"P@)&UA=&-H97,I("8F("1M871C:&5S6S%=("$]
M("=<7"<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC=&EO;B!T;R!V86QI
M9&%T92!A;B!A9&1R+7-P96,N"B`@("`@*@H@("`@("H@861D<BUS<&5C(#T@
M;&]C86PM<&%R="`B0"(@9&]M86EN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*B!`<&%R86T@<W1R:6YG("1A9&1R7W-P96,@5&AE('-T
M<FEN9R!T;R!C:&5C:RX*("`@("`J($!R971U<FX@;6EX960@1F%L<V4@;VX@
M9F%I;'5R92P@;W(@=&AE('9A;&ED871E9"!A9&1R+7-P96,@;VX@<W5C8V5S
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W9A;&ED871E061D<E-P96,H)&%D
M9')?<W!E8RD*("`@('L*("`@("`@("`D861D<E]S<&5C(#T@=')I;2@D861D
M<E]S<&5C*3L*"B`@("`@("`@+R\@4W!L:70@;VX@0"!S:6=N(&EF('1H97)E
M(&ES(&]N92X*("`@("`@("!I9B`H<W1R<&]S*"1A9&1R7W-P96,L("=`)RD@
M(3T](&9A;'-E*2!["B`@("`@("`@("`@("1P87)T<R`@("`@(#T@97AP;&]D
M92@G0"<L("1A9&1R7W-P96,I.PH@("`@("`@("`@("`D;&]C86Q?<&%R="`]
M("1T:&ES+3Y?<W!L:71#:&5C:R@D<&%R=',L("=`)RD["B`@("`@("`@("`@
M("1D;VUA:6X@("`@(#T@<W5B<W1R*"1A9&1R7W-P96,L('-T<FQE;B@D;&]C
M86Q?<&%R="`N("=`)RDI.PH*("`@("`@("`O+R!.;R!`('-I9VX@<V\@87-S
M=6UE('1H92!D969A=6QT(&1O;6%I;BX*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D;&]C86Q?<&%R="`]("1A9&1R7W-P96,["B`@("`@("`@("`@
M("1D;VUA:6X@("`@(#T@)'1H:7,M/F1E9F%U;'1?9&]M86EN.PH@("`@("`@
M('T*"B`@("`@("`@:68@*"@D;&]C86Q?<&%R="`]("1T:&ES+3Y?=F%L:61A
M=&5,;V-A;%!A<G0H)&QO8V%L7W!A<G0I*2`]/3T@9F%L<V4I(')E='5R;B!F
M86QS93L*("`@("`@("!I9B`H*"1D;VUA:6X@("`@(#T@)'1H:7,M/E]V86QI
M9&%T941O;6%I;B@D9&]M86EN*2D@/3T](&9A;'-E*2!R971U<FX@9F%L<V4[
M"@H@("`@("`@("\O($=O="!H97)E('-O(')E='5R;B!S=6-C97-S9G5L+@H@
M("`@("`@(')E='5R;B!A<G)A>2@G;&]C86Q?<&%R="<@/3X@)&QO8V%L7W!A
M<G0L("=D;VUA:6XG(#T^("1D;VUA:6XI.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1G5N8W1I;VX@=&\@=F%L:61A=&4@=&AE(&QO8V%L('!A<G0@;V8@86X@
M861D<F5S<SH*("`@("`J("`@;&]C86PM<&%R="`]('=O<F0@*B@B+B(@=V]R
M9"D*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!P87)A
M;2!S=')I;F<@)&QO8V%L7W!A<G0*("`@("`J($!R971U<FX@;6EX960@1F%L
M<V4@;VX@9F%I;'5R92P@;W(@=&AE('9A;&ED871E9"!L;V-A;"!P87)T(&]N
M('-U8V-E<W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]V86QI9&%T94QO8V%L
M4&%R="@D;&]C86Q?<&%R="D*("`@('L*("`@("`@("`D<&%R=',@/2!E>'!L
M;V1E*"<N)RP@)&QO8V%L7W!A<G0I.PH@("`@("`@("1W;W)D<R`](&%R<F%Y
M*"D["@H@("`@("`@("\O(%-P;&ET('1H92!L;V-A;%]P87)T(&EN=&\@=V]R
M9',N"B`@("`@("`@=VAI;&4@*&-O=6YT*"1P87)T<RD@/B`P*7L*("`@("`@
M("`@("`@)'=O<F1S6UT@/2`D=&AI<RT^7W-P;&ET0VAE8VLH)'!A<G1S+"`G
M+B<I.PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D=&AI<RT^:6YD
M97@@*R`Q.R`D:2LK*2!["B`@("`@("`@("`@("`@("!A<G)A>5]S:&EF="@D
M<&%R=',I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!6
M86QI9&%T92!E86-H('=O<F0N"B`@("`@("`@9F]R96%C:"`H)'=O<F1S(&%S
M("1W;W)D*2!["B`@("`@("`@("`@("\O($EF('1H:7,@=V]R9"!C;VYT86EN
M<R!A;B!U;G%U;W1E9"!S<&%C92P@:70@:7,@:6YV86QI9"X@*#8N,BXT*0H@
M("`@("`@("`@("!I9B`H<W1R<&]S*"1W;W)D+"`G("<I("8F("1W;W)D6S!=
M("$]/2`G(B<I"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1T:&ES
M+3Y?=F%L:61A=&50:')A<V4H=')I;2@D=V]R9"DI(#T]/2!F86QS92D@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+R\@36%N86=E9"!T;R!G
M970@:&5R92P@<V\@<F5T=7)N('1H92!I;G!U="X*("`@("`@("!R971U<FX@
M)&QO8V%L7W!A<G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N
M(&%P<')O>&EM871E(&-O=6YT(&]F(&AO=R!M86YY(&%D9')E<W-E<R!A<F4@
M:6X@=&AE"B`@("`@*B!G:79E;B!S=')I;F<N(%1H:7,@:7,@05!04D]824U!
M5$4@87,@:70@;VYL>2!S<&QI=',@8F%S960@;VX@80H@("`@("H@8V]M;6$@
M=VAI8V@@:&%S(&YO('!R96-E9&EN9R!B86-K<VQA<V@N($-O=6QD(&)E('5S
M969U;"!A<PH@("`@("H@;&%R9V4@86UO=6YT<R!O9B!A9&1R97-S97,@=VEL
M;"!E;F0@=7`@<')O9'5C:6YG("IL87)G92H*("`@("`J('-T<G5C='5R97,@
M=VAE;B!U<V5D('=I=&@@<&%R<V5!9&1R97-S3&ES="@I+@H@("`@("H*("`@
M("`J($!P87)A;2`@<W1R:6YG("1D871A($%D9')E<W-E<R!T;R!C;W5N=`H@
M("`@("H@0')E='5R;B!I;G0@("`@("`@("`@07!P<F]X:6UA=&4@8V]U;G0*
M("`@("`J+PH@("`@9G5N8W1I;VX@87!P<F]X:6UA=&5#;W5N="@D9&%T82D*
M("`@('L*("`@("`@("!R971U<FX@8V]U;G0H<')E9U]S<&QI="@G+R@_/"%<
M7%Q<*2PO)RP@)&1A=&$I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@
M:7,@82!E;6%I;"!V86QI9&%T:6YG(&9U;F-T:6]N('-E<&%R871E('1O('1H
M92!R97-T(&]F('1H90H@("`@("H@8VQA<W,N($ET('-I;7!L>2!V86QI9&%T
M97,@=VAE=&AE<B!A;B!E;6%I;"!I<R!O9B!T:&4@8V]M;6]N"B`@("`@*B!I
M;G1E<FYE="!F;W)M.B`\=7-E<CY`/&1O;6%I;CXN(%1H:7,@8V%N(&)E('-U
M9F9I8VEE;G0@9F]R(&UO<W0*("`@("`J('!E;W!L92X@3W!T:6]N86P@<W1R
M:6-T97(@;6]D92!C86X@8F4@=71I;&ES960@=VAI8V@@<F5S=')I8W1S"B`@
M("`@*B!M86EL8F]X(&-H87)A8W1E<G,@86QL;W=E9"!T;R!A;'!H86YU;65R
M:6,L(&9U;&P@<W1O<"P@:'EP:&5N"B`@("`@*B!A;F0@=6YD97)S8V]R92X*
M("`@("`J"B`@("`@*B!`<&%R86T@('-T<FEN9R`@)&1A=&$@("!!9&1R97-S
M('1O(&-H96-K"B`@("`@*B!`<&%R86T@(&)O;VQE86X@)'-T<FEC="!/<'1I
M;VYA;"!S=')I8W1E<B!M;V1E"B`@("`@*B!`<F5T=7)N(&UI>&5D("`@("`@
M("`@("!&86QS92!I9B!I="!F86EL<RP@86X@:6YD97AE9"!A<G)A>0H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@=7-E<FYA;64O9&]M86EN(&EF
M(&ET(&UA=&-H97,*("`@("`J+PH@("`@9G5N8W1I;VX@:7-686QI9$EN971!
M9&1R97-S*"1D871A+"`D<W1R:6-T(#T@9F%L<V4I"B`@("!["B`@("`@("`@
M)')E9V5X(#T@)'-T<FEC="`_("<O7BA;+C`M.6$M>E\K+5TK*4`H*%LP+3EA
M+7HM72M<+BDK6S`M.6$M>EU[,BPT?2DD+VDG(#H@)R]>*%LJ*R$N)B,D?%PG
M7%PE7"\P+3EA+7I>7V![?3T_?CHM72LI0"@H6S`M.6$M>BU=*UPN*2M;,"TY
M82UZ77LR+#1]*20O:2<["B`@("`@("`@:68@*'!R96=?;6%T8V@H)')E9V5X
M+"!T<FEM*"1D871A*2P@)&UA=&-H97,I*2!["B`@("`@("`@("`@(')E='5R
M;B!A<G)A>2@D;6%T8VAE<ULQ72P@)&UA=&-H97-;,ETI.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+TUA:6PO;6EM95!A<G0N<&AP````````````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,S$Q,3`@,3`U,34T,S,W,S,@,#(Q-C,S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\($-O
M<'ER:6=H="`H8RD@,C`P,BTR,#`S("!2:6-H87)D($AE>65S("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@06QL(')I9VAT
M<R!R97-E<G9E9"X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P-"B\O('P@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P-"B\O('P@4F5D:7-T<FEB=71I;VX@86YD('5S92!I;B!S;W5R8V4@
M86YD(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T("`@('P-"B\O('P@
M;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE
M(&9O;&QO=VEN9R!C;VYD:71I;VYS("`@('P-"B\O('P@87)E(&UE=#H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P-"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P-"B\O('P@;R!2961I<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S
M="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H="`@("`@('P-"B\O('P@("!N
M;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W
M:6YG(&1I<V-L86EM97(N("`@("`@('P-"B\O('P@;R!2961I<W1R:6)U=&EO
M;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B;W9E(&-O
M<'ER:6=H="`@('P-"B\O('P@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD
M:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@:6X@=&AE('P-
M"B\O('P@("!D;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE<B!M871E<FEA;',@
M<')O=FED960@=VET:"!T:&4@9&ES=')I8G5T:6]N+GP-"B\O('P@;R!4:&4@
M;F%M97,@;V8@=&AE(&%U=&AO<G,@;6%Y(&YO="!B92!U<V5D('1O(&5N9&]R
M<V4@;W(@<')O;6]T92`@("`@('P-"B\O('P@("!P<F]D=6-T<R!D97)I=F5D
M(&9R;VT@=&AI<R!S;V9T=V%R92!W:71H;W5T('-P96-I9FEC('!R:6]R('=R
M:71T96X@('P-"B\O('P@("!P97)M:7-S:6]N+B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O
M('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@5$A)4R!33T94
M5T%212!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@04Y$
M($-/3E1224)55$]24R`@('P-"B\O('P@(D%3($E3(B!!3D0@04Y9($584%)%
M4U,@3U(@24U03$E%1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.3U0@
M("`@('P-"B\O('P@3$E-251%1"!43RP@5$A%($E-4$Q)140@5T%24D%.5$E%
M4R!/1B!-15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,@1D]2('P-"B\O('P@
M02!005)424-53$%2(%!54E!/4T4@05)%($1)4T-,04E-140N($E.($Y/($56
M14Y4(%-(04Q,(%1(12!#3U!94DE'2%0@('P-"B\O('P@3U=.15(@3U(@0T].
M5%))0E543U)3($)%($Q)04),12!&3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L
M($E.0TE$14Y404PL('P-"B\O('P@4U!%0TE!3"P@15A%35!,05)9+"!/4B!#
M3TY315%514Y424%,($1!34%'15,@*$E.0TQ51$E.1RP@0E54($Y/5"`@("`@
M('P-"B\O('P@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8@4U5"4U1)5%54
M12!'3T]$4R!/4B!315)624-%4SL@3$]34R!/1B!54T4L('P-"B\O('P@1$%4
M02P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,@24Y415)255!424].*2!(3U=%
M5D52($-!55-%1"!!3D0@3TX@04Y9('P-"B\O('P@5$A%3U)9($]&($Q)04))
M3$E462P@5TA%5$A%4B!)3B!#3TY44D%#5"P@4U1224-4($Q)04))3$E462P@
M3U(@5$]25"`@('P-"B\O('P@*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]4
M2$525TE312D@05))4TE.1R!)3B!!3ED@5T%9($]55"!/1B!42$4@55-%('P-
M"B\O('P@3T8@5$A)4R!33T945T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(
M12!03U-324))3$E462!/1B!354-(($1!34%'12X@('P-"B\O('P@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L-"B\O('P@075T:&]R.B!2:6-H87)D($AE>65S(#QR:6-H87)D
M0'!H<&=U<G4N;W)G/B`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"@T*+RHJ#0HJ#0HJ("!2
M87<@;6EM92!E;F-O9&EN9R!C;&%S<PT**@T**B!7:&%T(&ES(&ET/PT**B`@
M(%1H:7,@8VQA<W,@96YA8FQE<R!Y;W4@=&\@;6%N:7!U;&%T92!A;F0@8G5I
M;&0-"BH@("!A(&UI;64@96UA:6P@9G)O;2!T:&4@9W)O=6YD('5P+@T**@T*
M*B!7:'D@=7-E('1H:7,@:6YS=&5A9"!O9B!M:6UE+G!H<#\-"BH@("!M:6UE
M+G!H<"!I<R!A('5S97)F<FEE;F1L>2!A<&D@=&\@=&AI<R!C;&%S<R!F;W(-
M"BH@("!P96]P;&4@=VAO(&%R96XG="!I;G1E<F5S=&5D(&EN('1H92!I;G1E
M<FYA;',@;V8-"BH@("!M:6UE(&UA:6PN(%1H:7,@8VQA<W,@:&]W979E<B!A
M;&QO=W,@9G5L;"!C;VYT<F]L#0HJ("`@;W9E<B!T:&4@96UA:6PN#0HJ#0HJ
M($5G+@T**@T**B`O+R!3:6YC92!M=6QT:7!A<G0O;6EX960@:&%S(&YO(')E
M86P@8F]D>2P@*'1H92!B;V1Y(&ES#0HJ("\O('1H92!S=6)P87)T*2P@=V4@
M<V5T('1H92!B;V1Y(&%R9W5M96YT('1O(&)L86YK+@T**@T**B`D<&%R86US
M6R=C;VYT96YT7W1Y<&4G72`]("=M=6QT:7!A<G0O;6EX960G.PT**B`D96UA
M:6P@/2!N97<@36%I;%]M:6UE4&%R="@G)RP@)'!A<F%M<RD[#0HJ#0HJ("\O
M($AE<F4@=V4@861D(&$@=&5X="!P87)T('1O('1H92!M=6QT:7!A<G0@=V4@
M:&%V90T**B`O+R!A;')E861Y+B!!<W-U;64@)&)O9'D@8V]N=&%I;G,@<&QA
M:6X@=&5X="X-"BH-"BH@)'!A<F%M<ULG8V]N=&5N=%]T>7!E)UT@/2`G=&5X
M="]P;&%I;B<[#0HJ("1P87)A;7-;)V5N8V]D:6YG)UT@("`@(#T@)S=B:70G
M.PT**B`D=&5X="`]("1E;6%I;"T^861D4W5B4&%R="@D8F]D>2P@)'!A<F%M
M<RD[#0HJ#0HJ("\O($YO=R!A9&0@86X@871T86-H;65N="X@07-S=6UE("1A
M='1A8V@@:7,-"BH@=&AE(&-O;G1E;G1S(&]F('1H92!A='1A8VAM96YT#0HJ
M#0HJ("1P87)A;7-;)V-O;G1E;G1?='EP92==(#T@)V%P<&QI8V%T:6]N+WII
M<"<[#0HJ("1P87)A;7-;)V5N8V]D:6YG)UT@("`@(#T@)V)A<V4V-"<[#0HJ
M("1P87)A;7-;)V1I<W!O<VET:6]N)UT@(#T@)V%T=&%C:&UE;G0G.PT**B`D
M<&%R86US6R=D9FEL96YA;64G72`@("`]("=E>&%M<&QE+GII<"<[#0HJ("1A
M='1A8V@@/28@)&5M86EL+3YA9&13=6)087)T*"1B;V1Y+"`D<&%R86US*3L-
M"BH-"BH@+R\@3F]W(&)U:6QD('1H92!E;6%I;"X@3F]T92!T:&%T('1H92!E
M;F-O9&4-"BH@+R\@9G5N8W1I;VX@<F5T=7)N<R!A;B!A<W-O8VEA=&EV92!A
M<G)A>2!C;VYT86EN:6YG('1W;PT**B`O+R!E;&5M96YT<RP@8F]D>2!A;F0@
M:&5A9&5R<RX@66]U('=I;&P@;F5E9"!T;R!A9&0@97AT<F$-"BH@+R\@:&5A
M9&5R<RP@*&5G+B!-:6UE+59E<G-I;VXI(&)E9F]R92!S96YD:6YG+@T**@T*
M*B`D96UA:6P@/2`D;65S<V%G92T^96YC;V1E*"D[#0HJ("1E;6%I;%LG:&5A
M9&5R<R==6UT@/2`G36EM92U697)S:6]N.B`Q+C`G.PT**@T**@T**B!&=7)T
M:&5R(&5X86UP;&5S(&%R92!A=F%I;&%B;&4@870@:'1T<#HO+W=W=RYP:'!G
M=7)U+F]R9PT**@T**B!43T1/.@T**B`@+2!3970@96YC;V1E*"D@=&\@<F5T
M=7)N('1H92`D;V)J+3YE;F-O9&5D(&EF(&5N8V]D92@I#0HJ("`@(&AA<R!A
M;')E861Y(&)E96X@<G5N+B!5;FQE<W,@82!F;&%G(&ES('!A<W-E9"!T;R!S
M<&5C:69I8V%L;'D-"BH@("`@<F4M8G5I;&0@=&AE(&UE<W-A9V4N#0HJ#0HJ
M($!A=71H;W(@(%)I8VAA<F0@2&5Y97,@/')I8VAA<F1`<&AP9W5R=2YO<F<^
M#0HJ($!V97)S:6]N("12979I<VEO;CH@,2XQ,R`D#0HJ($!P86-K86=E($UA
M:6P-"BHO#0H-"F-L87-S($UA:6Q?;6EM95!A<G0@>PT*#0H@("`O*BH-"B`@
M("`J(%1H92!E;F-O9&EN9R!T>7!E(&]F('1H:7,@<&%R=`T*("`@("H@0'9A
M<B!S=')I;F<-"B`@("`J+PT*("`@('9A<B`D7V5N8V]D:6YG.PT*#0H@("`O
M*BH-"B`@("`J($%N(&%R<F%Y(&]F('-U8G!A<G1S#0H@("`@*B!`=F%R(&%R
M<F%Y#0H@("`@*B\-"B`@("!V87(@)%]S=6)P87)T<SL-"@T*("`@+RHJ#0H@
M("`@*B!4:&4@;W5T<'5T(&]F('1H:7,@<&%R="!A9G1E<B!B96EN9R!B=6EL
M=`T*("`@("H@0'9A<B!S=')I;F<-"B`@("`J+PT*("`@('9A<B`D7V5N8V]D
M960[#0H-"B`@("\J*@T*("`@("H@2&5A9&5R<R!F;W(@=&AI<R!P87)T#0H@
M("`@*B!`=F%R(&%R<F%Y#0H@("`@*B\-"B`@("!V87(@)%]H96%D97)S.PT*
M#0H@("`O*BH-"B`@("`J(%1H92!B;V1Y(&]F('1H:7,@<&%R="`H;F]T(&5N
M8V]D960I#0H@("`@*B!`=F%R('-T<FEN9PT*("`@("HO#0H@("`@=F%R("1?
M8F]D>3L-"@T*("`@("\J*@T*("`@("`J($-O;G-T<G5C=&]R+@T*("`@("`J
M#0H@("`@("H@4V5T<R!U<"!T:&4@;V)J96-T+@T*("`@("`J#0H@("`@("H@
M0'!A<F%M("1B;V1Y("`@+2!4:&4@8F]D>2!O9B!T:&4@;6EM92!P87)T(&EF
M(&%N>2X-"B`@("`@*B!`<&%R86T@)'!A<F%M<R`M($%N(&%S<V]C:6%T:79E
M(&%R<F%Y(&]F('!A<F%M971E<G,Z#0H@("`@("H@("`@("`@("`@("`@("`@
M("!C;VYT96YT7W1Y<&4@+2!4:&4@8V]N=&5N="!T>7!E(&9O<B!T:&ES('!A
M<G0@96<@;75L=&EP87)T+VUI>&5D#0H@("`@("H@("`@("`@("`@("`@("`@
M("!E;F-O9&EN9R`@("`@+2!4:&4@96YC;V1I;F<@=&\@=7-E+"`W8FET+"`X
M8FET+"!B87-E-C0L(&]R('%U;W1E9"UP<FEN=&%B;&4-"B`@("`@*B`@("`@
M("`@("`@("`@("`@(&-I9"`@("`@("`@("`M($-O;G1E;G0@240@=&\@87!P
M;'D-"B`@("`@*B`@("`@("`@("`@("`@("`@(&1I<W!O<VET:6]N("`M($-O
M;G1E;G0@9&ES<&]S:71I;VXL(&EN;&EN92!O<B!A='1A8VAM96YT#0H@("`@
M("H@("`@("`@("`@("`@("`@("!D9FEL96YA;64@("`@+2!/<'1I;VYA;"!F
M:6QE;F%M92!P87)A;65T97(@9F]R(&-O;G1E;G0@9&ES<&]S:71I;VX-"B`@
M("`@*B`@("`@("`@("`@("`@("`@(&1E<V-R:7!T:6]N("`M($-O;G1E;G0@
M9&5S8W)I<'1I;VX-"B`@("`@*B`@("`@("`@("`@("`@("`@(&-H87)S970@
M("`@("`M($-H87)A8W1E<B!S970@=&\@=7-E#0H@("`@("H@0&%C8V5S<R!P
M=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!-86EL7VUI;65087)T*"1B
M;V1Y(#T@)R<L("1P87)A;7,@/2!A<G)A>2@I*0T*("`@('L-"B`@("`@("`@
M:68@*"%D969I;F5D*"=-04E,7TU)345005)47T-23$8G*2D@>PT*("`@("`@
M("`@("`@9&5F:6YE*"=-04E,7TU)345005)47T-23$8G+"!D969I;F5D*"=-
M04E,7TU)345?0U),1B<I(#\@34%)3%]-24U%7T-23$8@.B`B7')<;B(L(%12
M544I.PT*("`@("`@("!]#0H-"B`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A
M<R`D:V5Y(#T^("1V86QU92D@>PT*("`@("`@("`@("`@<W=I=&-H("@D:V5Y
M*2![#0H@("`@("`@("`@("`@("`@8V%S92`G8V]N=&5N=%]T>7!E)SH-"B`@
M("`@("`@("`@("`@("`@("`@)&AE861E<G-;)T-O;G1E;G0M5'EP92==(#T@
M)'9A;'5E("X@*&ES<V5T*"1C:&%R<V5T*2`_("<[(&-H87)S970](B<@+B`D
M8VAA<G-E="`N("<B)R`Z("<G*3L-"B`@("`@("`@("`@("`@("`@("`@8G)E
M86L[#0H-"B`@("`@("`@("`@("`@("!C87-E("=E;F-O9&EN9R<Z#0H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?96YC;V1I;F<@/2`D=F%L=64[#0H@
M("`@("`@("`@("`@("`@("`@("1H96%D97)S6R=#;VYT96YT+51R86YS9F5R
M+45N8V]D:6YG)UT@/2`D=F%L=64[#0H@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PT*#0H@("`@("`@("`@("`@("`@8V%S92`G8VED)SH-"B`@("`@("`@
M("`@("`@("`@("`@)&AE861E<G-;)T-O;G1E;G0M240G72`]("<\)R`N("1V
M86QU92`N("<^)SL-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H-"B`@
M("`@("`@("`@("`@("!C87-E("=D:7-P;W-I=&EO;B<Z#0H@("`@("`@("`@
M("`@("`@("`@("1H96%D97)S6R=#;VYT96YT+41I<W!O<VET:6]N)UT@/2`D
M=F%L=64@+B`H:7-S970H)&1F:6QE;F%M92D@/R`G.R!F:6QE;F%M93TB)R`N
M("1D9FEL96YA;64@+B`G(B<@.B`G)RD[#0H@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PT*#0H@("`@("`@("`@("`@("`@8V%S92`G9&9I;&5N86UE)SH-
M"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1H96%D97)S6R=#;VYT
M96YT+41I<W!O<VET:6]N)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D:&5A9&5R<ULG0V]N=&5N="U$:7-P;W-I=&EO;B==("X]("<[(&9I;&5N
M86UE/2(G("X@)'9A;'5E("X@)R(G.PT*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&1F:6QE;F%M92`]
M("1V86QU93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL-"@T*("`@("`@("`@("`@("`@(&-A<V4@)V1E<V-R
M:7!T:6]N)SH-"B`@("`@("`@("`@("`@("`@("`@)&AE861E<G-;)T-O;G1E
M;G0M1&5S8W)I<'1I;VXG72`]("1V86QU93L-"B`@("`@("`@("`@("`@("`@
M("`@8G)E86L[#0H-"B`@("`@("`@("`@("`@("!C87-E("=C:&%R<V5T)SH-
M"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1H96%D97)S6R=#;VYT
M96YT+51Y<&4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1H96%D
M97)S6R=#;VYT96YT+51Y<&4G72`N/2`G.R!C:&%R<V5T/2(G("X@)'9A;'5E
M("X@)R(G.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)&-H87)S970@/2`D=F%L=64[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"@T*("`@("`@("`O+R!$969A=6QT
M(&-O;G1E;G0M='EP90T*("`@("`@("!I9B`H(6ES<V5T*"1H96%D97)S6R=#
M;VYT96YT+51Y<&4G72DI('L-"B`@("`@("`@("`@("1H96%D97)S6R=#;VYT
M96YT+51Y<&4G72`]("=T97AT+W!L86EN)SL-"B`@("`@("`@?0T*#0H@("`@
M("`@("\O1&5F875L="!E;F-O9&EN9PT*("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?96YC;V1I;F<I*2![#0H@("`@("`@("`@("`D=&AI<RT^7V5N8V]D
M:6YG(#T@)S=B:70G.PT*("`@("`@("!]#0H-"B`@("`@("`@+R\@07-S:6=N
M('-T=69F('1O(&UE;6)E<B!V87)I86)L97,-"B`@("`@("`@)'1H:7,M/E]E
M;F-O9&5D("`](&%R<F%Y*"D[#0H@("`@("`@("1T:&ES+3Y?:&5A9&5R<R`@
M/2`D:&5A9&5R<SL-"B`@("`@("`@)'1H:7,M/E]B;V1Y("`@("`]("1B;V1Y
M.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(&5N8V]D92@I#0H@("`@("H-
M"B`@("`@*B!%;F-O9&5S(&%N9"!R971U<FYS('1H92!E;6%I;"X@06QS;R!S
M=&]R97,-"B`@("`@*B!I="!I;B!T:&4@96YC;V1E9"!M96UB97(@=F%R:6%B
M;&4-"B`@("`@*@T*("`@("`J($!R971U<FX@06X@87-S;V-I871I=F4@87)R
M87D@8V]N=&%I;FEN9R!T=V\@96QE;65N=',L#0H@("`@("H@("`@("`@("!B
M;V1Y(&%N9"!H96%D97)S+B!4:&4@:&5A9&5R<R!E;&5M96YT(&ES(&ET<V5L
M9@T*("`@("`J("`@("`@("`@86X@:6YD97AE9"!A<G)A>2X-"B`@("`@*B!`
M86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&5N8V]D92@I
M#0H@("`@>PT*("`@("`@("`D96YC;V1E9"`])B`D=&AI<RT^7V5N8V]D960[
M#0H-"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W-U8G!A<G1S*2D@>PT*
M("`@("`@("`@("`@<W)A;F0H*&1O=6)L92EM:6-R;W1I;64H*2HQ,#`P,#`P
M*3L-"B`@("`@("`@("`@("1B;W5N9&%R>2`]("<]7R<@+B!M9#4H<F%N9"@I
M("X@;6EC<F]T:6UE*"DI.PT*("`@("`@("`@("`@)'1H:7,M/E]H96%D97)S
M6R=#;VYT96YT+51Y<&4G72`N/2`G.R<@+B!-04E,7TU)345005)47T-23$8@
M+B`B7'0B("X@)V)O=6YD87)Y/2(G("X@)&)O=6YD87)Y("X@)R(G.PT*#0H@
M("`@("`@("`@("`O+R!!9&0@8F]D>2!P87)T<R!T;R`D<W5B<&%R=',-"B`@
M("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1T:&ES+3Y?<W5B
M<&%R=',I.R`D:2LK*2![#0H@("`@("`@("`@("`@("`@)&AE861E<G,@/2!A
M<G)A>2@I.PT*("`@("`@("`@("`@("`@("1T;7`@/2`D=&AI<RT^7W-U8G!A
M<G1S6R1I72T^96YC;V1E*"D[#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)'1M<%LG:&5A9&5R<R==(&%S("1K97D@/3X@)'9A;'5E*2![#0H@("`@("`@
M("`@("`@("`@("`@("1H96%D97)S6UT@/2`D:V5Y("X@)SH@)R`N("1V86QU
M93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'-U8G!A
M<G1S6UT@/2!I;7!L;V1E*$U!24Q?34E-15!!4E1?0U),1BP@)&AE861E<G,I
M("X@34%)3%]-24U%4$%25%]#4DQ&("X@34%)3%]-24U%4$%25%]#4DQ&("X@
M)'1M<%LG8F]D>2==.PT*("`@("`@("`@("`@?0T*#0H@("`@("`@("`@("`D
M96YC;V1E9%LG8F]D>2==(#T@)RTM)R`N("1B;W5N9&%R>2`N($U!24Q?34E-
M15!!4E1?0U),1B`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:6UP;&]D92@G+2TG("X@)&)O=6YD87)Y("X@34%)3%]-24U%4$%25%]#4DQ&
M+"`D<W5B<&%R=',I("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G+2TG("X@)&)O=6YD87)Y+B<M+2<@+B!-04E,7TU)345005)47T-23$8[
M#0H-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1E;F-O9&5D6R=B
M;V1Y)UT@/2`D=&AI<RT^7V=E=$5N8V]D961$871A*"1T:&ES+3Y?8F]D>2P@
M)'1H:7,M/E]E;F-O9&EN9RD@+B!-04E,7TU)345005)47T-23$8[#0H@("`@
M("`@('T-"@T*("`@("`@("`O+R!!9&0@:&5A9&5R<R!T;R`D96YC;V1E9`T*
M("`@("`@("`D96YC;V1E9%LG:&5A9&5R<R==(#TF("1T:&ES+3Y?:&5A9&5R
M<SL-"@T*("`@("`@("!R971U<FX@)&5N8V]D960[#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@)F%D9%-U8E!A<G0H*0T*("`@("`J#0H@("`@("H@061D
M<R!A('-U8G!A<G0@=&\@8W5R<F5N="!M:6UE('!A<G0@86YD(')E='5R;G,-
M"B`@("`@*B!A(')E9F5R96YC92!T;R!I=`T*("`@("`J#0H@("`@("H@0'!A
M<F%M("1B;V1Y("`@5&AE(&)O9'D@;V8@=&AE('-U8G!A<G0L(&EF(&%N>2X-
M"B`@("`@*B!`<&%R86T@)'!A<F%M<R!4:&4@<&%R86UE=&5R<R!F;W(@=&AE
M('-U8G!A<G0L('-A;64-"B`@("`@*B`@("`@("`@("`@("`@("!A<R!T:&4@
M)'!A<F%M<R!A<F=U;65N="!F;W(@8V]N<W1R=6-T;W(N#0H@("`@("H@0')E
M='5R;B!!(')E9F5R96YC92!T;R!T:&4@<&%R="!Y;W4@:G5S="!A9&1E9"X@
M270@:7,-"B`@("`@*B`@("`@("`@(&-R=6-I86P@:68@=7-I;F<@;75L=&EP
M87)T+RH@:6X@>6]U<B!S=6)P87)T<R!T:&%T#0H@("`@("H@("`@("`@("!Y
M;W4@=7-E(#TF(&EN('EO=7(@<V-R:7!T('=H96X@8V%L;&EN9R!T:&ES(&9U
M;F-T:6]N+`T*("`@("`J("`@("`@("`@;W1H97)W:7-E('EO=2!W:6QL(&YO
M="!B92!A8FQE('1O(&%D9"!F=7)T:&5R('-U8G!A<G1S+@T*("`@("`J($!A
M8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)F%D9%-U8E!A
M<G0H)&)O9'DL("1P87)A;7,I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-U
M8G!A<G1S6UT@/2!N97<@36%I;%]M:6UE4&%R="@D8F]D>2P@)'!A<F%M<RD[
M#0H@("`@("`@(')E='5R;B`D=&AI<RT^7W-U8G!A<G1S6V-O=6YT*"1T:&ES
M+3Y?<W5B<&%R=',I("T@,5T[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M7V=E=$5N8V]D961$871A*"D-"B`@("`@*@T*("`@("`J(%)E='5R;G,@96YC
M;V1E9"!D871A(&)A<V5D('5P;VX@96YC;V1I;F<@<&%S<V5D('1O(&ET#0H@
M("`@("H-"B`@("`@*B!`<&%R86T@)&1A=&$@("`@(%1H92!D871A('1O(&5N
M8V]D92X-"B`@("`@*B!`<&%R86T@)&5N8V]D:6YG(%1H92!E;F-O9&EN9R!T
M>7!E('1O('5S92P@-V)I="P@8F%S938T+`T*("`@("`J("`@("`@("`@("`@
M("`@("`@;W(@<75O=&5D+7!R:6YT86)L92X-"B`@("`@*B!`86-C97-S('!R
M:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?9V5T16YC;V1E9$1A=&$H
M)&1A=&$L("1E;F-O9&EN9RD-"B`@("![#0H@("`@("`@('-W:71C:"`H)&5N
M8V]D:6YG*2![#0H@("`@("`@("`@("!C87-E("<X8FET)SH-"B`@("`@("`@
M("`@(&-A<V4@)S=B:70G.@T*("`@("`@("`@("`@("`@(')E='5R;B`D9&%T
M83L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"@T*("`@("`@("`@("`@8V%S
M92`G<75O=&5D+7!R:6YT86)L92<Z#0H@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?<75O=&5D4')I;G1A8FQE16YC;V1E*"1D871A*3L-"B`@("`@
M("`@("`@("`@("!B<F5A:SL-"@T*("`@("`@("`@("`@8V%S92`G8F%S938T
M)SH-"B`@("`@("`@("`@("`@("!R971U<FX@<G1R:6TH8VAU;FM?<W!L:70H
M8F%S938T7V5N8V]D92@D9&%T82DL(#<V+"!-04E,7TU)345005)47T-23$8I
M*3L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"@T*("`@("`@("`@("`@9&5F
M875L=#H-"B`@("`@("`@("`@("`@("!R971U<FX@)&1A=&$[#0H@("`@("`@
M('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!Q=6]T96%D4')I;G1A8FQE
M16YC;V1E*"D-"B`@("`@*@T*("`@("`J($5N8V]D97,@9&%T82!T;R!Q=6]T
M960M<')I;G1A8FQE('-T86YD87)D+@T*("`@("`J#0H@("`@("H@0'!A<F%M
M("1I;G!U="`@("!4:&4@9&%T82!T;R!E;F-O9&4-"B`@("`@*B!`<&%R86T@
M)&QI;F5?;6%X($]P=&EO;F%L(&UA>"!L:6YE(&QE;F=T:"X@4VAO=6QD#0H@
M("`@("H@("`@("`@("`@("`@("`@("!N;W0@8F4@;6]R92!T:&%N(#<V(&-H
M87)S#0H@("`@("H-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!?<75O=&5D4')I;G1A8FQE16YC;V1E*"1I;G!U="`L
M("1L:6YE7VUA>"`](#<V*0T*("`@('L-"B`@("`@("`@)&QI;F5S("`]('!R
M96=?<W!L:70H(B]<<C]<;B\B+"`D:6YP=70I.PT*("`@("`@("`D96]L("`@
M(#T@34%)3%]-24U%4$%25%]#4DQ&.PT*("`@("`@("`D97-C87!E(#T@)STG
M.PT*("`@("`@("`D;W5T<'5T(#T@)R<[#0H-"B`@("`@("`@=VAI;&4H;&ES
M="@L("1L:6YE*2`](&5A8V@H)&QI;F5S*2E[#0H-"B`@("`@("`@("`@("1L
M:6YL96X@("`@(#T@<W1R;&5N*"1L:6YE*3L-"B`@("`@("`@("`@("1N97=L
M:6YE(#T@)R<[#0H-"B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1L
M:6YL96X[("1I*RLI('L-"B`@("`@("`@("`@("`@("`D8VAA<B`]('-U8G-T
M<B@D;&EN92P@)&DL(#$I.PT*("`@("`@("`@("`@("`@("1D96,@(#T@;W)D
M*"1C:&%R*3L-"@T*("`@("`@("`@("`@("`@(&EF("@H)&1E8R`]/2`S,BD@
M04Y$("@D:2`]/2`H)&QI;FQE;B`M(#$I*2E[("`@("\O(&-O;G9E<G0@<W!A
M8V4@870@96]L(&]N;'D-"B`@("`@("`@("`@("`@("`@("`@)&-H87(@/2`G
M/3(P)SL-"@T*("`@("`@("`@("`@("`@('T@96QS96EF*"@D9&5C(#T](#DI
M($%.1"`H)&D@/3T@*"1L:6YL96X@+2`Q*2DI('L@("\O(&-O;G9E<G0@=&%B
M(&%T(&5O;"!O;FQY#0H@("`@("`@("`@("`@("`@("`@("1C:&%R(#T@)STP
M.2<[#0H@("`@("`@("`@("`@("`@?2!E;'-E:68H)&1E8R`]/2`Y*2![#0H@
M("`@("`@("`@("`@("`@("`@(#L@+R\@1&\@;F]T:&EN9R!I9B!A('1A8BX-
M"B`@("`@("`@("`@("`@("!](&5L<V5I9B@H)&1E8R`]/2`V,2D@3U(@*"1D
M96,@/"`S,B`I($]2("@D9&5C(#X@,3(V*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`D8VAA<B`]("1E<V-A<&4@+B!S=')T;W5P<&5R*'-P<FEN=&8H)R4P
M,G,G+"!D96-H97@H)&1E8RDI*3L-"B`@("`@("`@("`@("`@("!]#0H-"B`@
M("`@("`@("`@("`@("!I9B`H*'-T<FQE;B@D;F5W;&EN92D@*R!S=')L96XH
M)&-H87(I*2`^/2`D;&EN95]M87@I('L@("`@("`@("\O($U!24Q?34E-15!!
M4E1?0U),1B!I<R!N;W0@8V]U;G1E9`T*("`@("`@("`@("`@("`@("`@("`D
M;W5T<'5T("`N/2`D;F5W;&EN92`N("1E<V-A<&4@+B`D96]L.R`@("`@("`@
M("`@("`@("`@("`@+R\@<V]F="!L:6YE(&)R96%K.R`B(#U<<EQN(B!I<R!O
M:V%Y#0H@("`@("`@("`@("`@("`@("`@("1N97=L:6YE("`]("<G.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D;F5W;&EN92`N/2`D
M8VAA<CL-"B`@("`@("`@("`@('T@+R\@96YD(&]F(&9O<@T*("`@("`@("`@
M("`@)&]U='!U="`N/2`D;F5W;&EN92`N("1E;VP[#0H@("`@("`@('T-"B`@
M("`@("`@)&]U='!U="`]('-U8G-T<B@D;W5T<'5T+"`P+"`M,2`J('-T<FQE
M;B@D96]L*2D[("\O($1O;B=T('=A;G0@;&%S="!C<FQF#0H@("`@("`@(')E
M='5R;B`D;W5T<'5T.PT*("`@('T-"GT@+R\@16YD(&]F(&-L87-S#0H_/@T*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+TUA:6PO;6EM92YP:'``````````````````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-C$P-C,@,3`U,34T,S,W
M,S,@,#(Q,#$V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@
M<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#(P,#(M,C`P
M,R`@4FEC:&%R9"!(97EE<R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R!\($-O<'ER:6=H="`H8RD@,C`P,RTR,#`U("!4:&4@4$A0($=R
M;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@06QL
M(')I9VAT<R!R97-E<G9E9"X@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R!\(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U
M<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U="`@("!\"B\O
M('P@;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@
M=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS("`@('P*+R\@?"!A<F4@;65T.B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O('P@;R!2961I<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S
M="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H="`@("`@('P*+R\@?"`@(&YO
M=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I
M;F<@9&ES8VQA:6UE<BX@("`@("`@?`HO+R!\(&\@4F5D:7-T<FEB=71I;VYS
M(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y
M<FEG:'0@("!\"B\O('P@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I
M;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@:6X@=&AE('P*+R\@
M?"`@(&1O8W5M96YT871I;VX@86YD+V]R(&]T:&5R(&UA=&5R:6%L<R!P<F]V
M:61E9"!W:71H('1H92!D:7-T<FEB=71I;VXN?`HO+R!\(&\@5&AE(&YA;65S
M(&]F('1H92!A=71H;W)S(&UA>2!N;W0@8F4@=7-E9"!T;R!E;F1O<G-E(&]R
M('!R;VUO=&4@("`@("!\"B\O('P@("!P<F]D=6-T<R!D97)I=F5D(&9R;VT@
M=&AI<R!S;V9T=V%R92!W:71H;W5T('-P96-I9FEC('!R:6]R('=R:71T96X@
M('P*+R\@?"`@('!E<FUI<W-I;VXN("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O('P@5$A)4R!33T945T%212!)4R!0
M4D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@04Y$($-/3E1224)5
M5$]24R`@('P*+R\@?"`B05,@25,B($%.1"!!3ED@15A04D534R!/4B!)35!,
M245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5"`@("`@?`HO+R!\
M($Q)34E4140@5$\L(%1(12!)35!,245$(%=!4E)!3E1)15,@3T8@34520TA!
M3E1!0DE,2519($%.1"!&251.15-3($9/4B!\"B\O('P@02!005)424-53$%2
M(%!54E!/4T4@05)%($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(
M12!#3U!94DE'2%0@('P*+R\@?"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4@
M3$E!0DQ%($9/4B!!3ED@1$E214-4+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@
M?`HO+R!\(%-014-)04PL($5814U03$%262P@3U(@0T].4T51545.5$E!3"!$
M04U!1T53("A)3D-,541)3D<L($)55"!.3U0@("`@("!\"B\O('P@3$E-251%
M1"!43RP@4%)/0U5214U%3E0@3T8@4U5"4U1)5%5412!'3T]$4R!/4B!315)6
M24-%4SL@3$]34R!/1B!54T4L('P*+R\@?"!$051!+"!/4B!04D]&2513.R!/
M4B!"55-)3D534R!)3E1%4E)54%1)3TXI($A/5T5615(@0T%54T5$($%.1"!/
M3B!!3ED@?`HO+R!\(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(15(@24X@
M0T].5%)!0U0L(%-44DE#5"!,24%"24Q)5%DL($]2(%1/4E0@("!\"B\O('P@
M*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]42$525TE312D@05))4TE.1R!)
M3B!!3ED@5T%9($]55"!/1B!42$4@55-%('P*+R\@?"!/1B!42$E3(%-/1E17
M05)%+"!%5D5.($E&($%$5DE3140@3T8@5$A%(%!/4U-)0DE,2519($]&(%-5
M0T@@1$%-04=%+B`@?`HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W(Z
M(%)I8VAA<F0@2&5Y97,@/')I8VAA<F1`<&AP9W5R=2YO<F<^("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R!\("`@("`@("`@5&]M87,@5BY6+D-O
M>"`\8V]X0&ED96-N970N8V]M/B`H<&]R="!T;R!014%2*2`@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@
M)$ED.B!M:6UE+G!H<"QV(#$N,SD@,C`P-2\P-B\Q,R`R,3HR-#HQ-B!C:7!R
M:2!%>'`@)`H*<F5Q=6ER95]O;F-E*"=014%2+G!H<"<I.PIR97%U:7)E7V]N
M8V4H)TUA:6PO;6EM95!A<G0N<&AP)RD["@HO*BH*("H@36EM92!M86EL(&-O
M;7!O<V5R(&-L87-S+B!#86X@:&%N9&QE.B!T97AT(&%N9"!H=&UL(&)O9&EE
M<RP@96UB961D960@:'1M;`H@*B!I;6%G97,@86YD(&%T=&%C:&UE;G1S+@H@
M*B!$;V-U;65N=&%T:6]N(&%N9"!E>&%M<&QE<R!O9B!T:&ES(&-L87-S(&%R
M92!A=F%I8FQE(&AE<F4Z"B`J(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L
M+PH@*@H@*B!`;F]T97,@5&AI<R!C;&%S<R!I<R!B87-E9"!O;B!(5$U,($UI
M;64@36%I;"!C;&%S<R!F<F]M"B`J("`@4FEC:&%R9"!(97EE<R`\<FEC:&%R
M9$!P:'!G=7)U+F]R9SX@=VAI8V@@=V%S(&)A<V5D(&%L<V\*("H@("!I;B!T
M:&4@;6EM95]M86EL+F-L87-S(&)Y(%1O8FEA<R!2871S8VAI;&QE<B`\=&]B
M:6%S0&1N970N:70^(&%N9`H@*B`@(%-A<V-H82!38VAU;6%N;B`\<V%S8VAA
M0'-C:'5M86YN+F-X/@H@*@H@*B!`875T:&]R("`@4FEC:&%R9"!(97EE<R`\
M<FEC:&%R9"YH97EE<T!H97EE<RUC;VUP=71I;F<N;F5T/@H@*B!`875T:&]R
M("`@5&]M87,@5BY6+D-O>"`\8V]X0&ED96-N970N8V]M/@H@*B!`<&%C:V%G
M92`@36%I;`H@*B!`86-C97-S("`@<'5B;&EC"B`J+PIC;&%S<R!-86EL7VUI
M;64*>PH@("`@+RHJ"B`@("`@*B!#;VYT86EN<R!T:&4@<&QA:6X@=&5X="!P
M87)T(&]F('1H92!E;6%I;`H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@
M("`@=F%R("1?='AT8F]D>3L*("`@("\J*@H@("`@("H@0V]N=&%I;G,@=&AE
M(&AT;6P@<&%R="!O9B!T:&4@96UA:6P*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D7VAT;6QB;V1Y.PH@("`@+RHJ"B`@("`@*B!C;VYT
M86EN<R!T:&4@;6EM92!E;F-O9&5D('1E>'0*("`@("`J($!V87(@<W1R:6YG
M"B`@("`@*B\*("`@('9A<B`D7VUI;64["B`@("`O*BH*("`@("`J(&-O;G1A
M:6YS('1H92!M=6QT:7!A<G0@8V]N=&5N=`H@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J+PH@("`@=F%R("1?;75L=&EP87)T.PH@("`@+RHJ"B`@("`@*B!L
M:7-T(&]F('1H92!A='1A8VAE9"!I;6%G97,*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1?:'1M;%]I;6%G97,@/2!A<G)A>2@I.PH@("`@
M+RHJ"B`@("`@*B!L:7-T(&]F('1H92!A='1A8VAE;65N=',*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<&%R=',@/2!A<G)A>2@I.PH@
M("`@+RHJ"B`@("`@*B!"=6EL9"!P87)A;65T97)S"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D7V)U:6QD7W!A<F%M<R`](&%R<F%Y*"D[
M"B`@("`O*BH*("`@("`J($AE861E<G,@9F]R('1H92!M86EL"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7VAE861E<G,@/2!A<G)A>2@I
M.PH@("`@+RHJ"B`@("`@*B!%;F0@3V8@3&EN92!S97%U96YC92`H9F]R('-E
M<FEA;&EZ92D*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D
M7V5O;#L*"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<B!F=6YC=&EO;@H@
M("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T
M:6]N($UA:6Q?;6EM92@D8W)L9B`](")<<EQN(BD*("`@('L*("`@("`@("`D
M=&AI<RT^7W-E=$5/3"@D8W)L9BD["B`@("`@("`@)'1H:7,M/E]B=6EL9%]P
M87)A;7,@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=T97AT7V5N8V]D:6YG)R`]/B`G-V)I="<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G:'1M;%]E;F-O9&EN9R<@/3X@
M)W%U;W1E9"UP<FEN=&%B;&4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)S=B:71?=W)A<"<@("`@(#T^(#DY."P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=H=&UL7V-H87)S970G("`]
M/B`G25-/+3@X-3DM,2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G=&5X=%]C:&%R<V5T)R`@/3X@)TE33RTX.#4Y+3$G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAE861?8VAA<G-E
M="<@(#T^("=)4T\M.#@U.2TQ)PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`I.PH@("`@?0H*("`@("\J*@H@("`@("H@5V%K975P("AU
M;G-E<FEA;&EZ92D@+2!R92US971S($5/3"!C;VYS=&%N=`H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?7W=A
M:V5U<"@I"B`@("!["B`@("`@("`@)'1H:7,M/E]S971%3TPH)'1H:7,M/E]E
M;VPI.PH@("`@?0H*("`@("\J*@H@("`@("H@06-C97-S;W(@9G5N8W1I;VX@
M=&\@<V5T('1H92!B;V1Y('1E>'0N($)O9'D@=&5X="!I<R!U<V5D(&EF"B`@
M("`@*B!I="=S(&YO="!A;B!H=&UL(&UA:6P@8F5I;F<@<V5N="!O<B!E;'-E
M(&ES('5S960@=&\@9FEL;"!T:&4*("`@("`J('1E>'0O<&QA:6X@<&%R="!T
M:&%T(&5M86EL<R!C;&EE;G1S('=H;R!D;VXG="!S=7!P;W)T"B`@("`@*B!H
M=&UL('-H;W5L9"!S:&]W+@H@("`@("H*("`@("`J($!P87)A;2`@<W1R:6YG
M("`D9&%T82`@($5I=&AE<B!A('-T<FEN9R!O<@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@=&AE(&9I;&4@;F%M92!W:71H('1H92!C;VYT96YT
M<PH@("`@("H@0'!A<F%M("!B;V]L("`@("1I<V9I;&4@268@=')U92!T:&4@
M9FER<W0@<&%R86T@<VAO=6QD(&)E('1R96%T960*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@(&%S(&$@9FEL92!N86UE+"!E;'-E(&%S(&$@<W1R
M:6YG("AD969A=6QT*0H@("`@("H@0'!A<F%M("!B;V]L("`@("1A<'!E;F0@
M268@=')U92!T:&4@=&5X="!O<B!F:6QE(&ES(&%P<&5N9&5D('1O"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@97AI<W1I;F<@8F]D>2P@
M96QS92!T:&4@;VQD(&)O9'D@:7,*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@(&]V97)W<FET=&5N"B`@("`@*B!`<F5T=7)N(&UI>&5D("`@=')U
M92!O;B!S=6-C97-S(&]R(%!%05)?17)R;W(@;V)J96-T"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!S97146%1";V1Y*"1D
M871A+"`D:7-F:6QE(#T@9F%L<V4L("1A<'!E;F0@/2!F86QS92D*("`@('L*
M("`@("`@("!I9B`H(21I<V9I;&4I('L*("`@("`@("`@("`@:68@*"$D87!P
M96YD*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W1X=&)O9'D@/2`D9&%T
M83L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?='AT8F]D>2`N/2`D9&%T83L*("`@("`@("`@("`@?0H@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1C;VYT(#T@)'1H:7,M/E]F:6QE,G-T<B@D
M9&%T82D["B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1C;VYT*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1C;VYT.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&EF("@A)&%P<&5N9"D@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]T>'1B;V1Y(#T@)&-O;G0["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7W1X=&)O9'D@+CT@)&-O;G0["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@:'1M;"!P87)T('1O('1H92!M
M86EL"B`@("`@*@H@("`@("H@0'!A<F%M("!S=')I;F<@("1D871A("`@16ET
M:&5R(&$@<W1R:6YG(&]R('1H92!F:6QE(&YA;64@=VET:"!T:&4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1E;G1S"B`@("`@*B!`<&%R
M86T@(&)O;VP@("`@)&ES9FEL92!)9B!T<G5E('1H92!F:7)S="!P87)A;2!S
M:&]U;&0@8F4@=')E871E9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@87,@82!F:6QE(&YA;64L(&5L<V4@87,@82!S=')I;F<@*&1E9F%U;'0I
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("`@=')U92!O;B!S=6-C97-S(&]R(%!%
M05)?17)R;W(@;V)J96-T"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!S971(5$U,0F]D>2@D9&%T82P@)&ES9FEL92`](&9A
M;'-E*0H@("`@>PH@("`@("`@(&EF("@A)&ES9FEL92D@>PH@("`@("`@("`@
M("`D=&AI<RT^7VAT;6QB;V1Y(#T@)&1A=&$["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&-O;G0@/2`D=&AI<RT^7V9I;&4R<W1R*"1D871A*3L*
M("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&-O;G0I*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@)&-O;G0["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)'1H:7,M/E]H=&UL8F]D>2`]("1C;VYT.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S
M(&%N(&EM86=E('1O('1H92!L:7-T(&]F(&5M8F5D9&5D(&EM86=E<RX*("`@
M("`J"B`@("`@*B!`<&%R86T@('-T<FEN9R`@)&9I;&4@("`@("`@5&AE(&EM
M86=E(&9I;&4@;F%M92!/4B!I;6%G92!D871A(&ET<V5L9@H@("`@("H@0'!A
M<F%M("!S=')I;F<@("1C7W1Y<&4@("`@(%1H92!C;VYT96YT('1Y<&4*("`@
M("`J($!P87)A;2`@<W1R:6YG("`D;F%M92`@("`@("!4:&4@9FEL96YA;64@
M;V8@=&AE(&EM86=E+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@($]N;'D@=7-E(&EF("1F:6QE(&ES('1H92!I;6%G92!D871A"B`@("`@
M*B!`<&%R86T@(&)O;VP@("`@)&ES9FEL96YA;64@5VAE=&AE<B`D9FEL92!I
M<R!A(&9I;&5N86UE(&]R(&YO=`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@($1E9F%U;'1S('1O('1R=64*("`@("`J($!R971U<FX@;6EX
M960@("!T<G5E(&]N('-U8V-E<W,@;W(@4$5!4E]%<G)O<B!O8FIE8W0*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$A4
M34Q);6%G92@D9FEL92P@)&-?='EP93TG87!P;&EC871I;VXO;V-T970M<W1R
M96%M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`D;F%M92`]("<G+"`D
M:7-F:6QE;F%M92`]('1R=64I"B`@("!["B`@("`@("`@)&9I;&5D871A(#T@
M*"1I<V9I;&5N86UE(#T]/2!T<G5E*2`_("1T:&ES+3Y?9FEL93)S='(H)&9I
M;&4I"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`Z("1F:6QE.PH@("`@("`@(&EF("@D:7-F:6QE;F%M92`]/3T@=')U92D@
M>PH@("`@("`@("`@("`D9FEL96YA;64@/2`H)&YA;64@/3T@)R<@/R!B87-E
M;F%M92@D9FEL92D@.B!B87-E;F%M92@D;F%M92DI.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1F:6QE;F%M92`](&)A<V5N86UE*"1N86UE*3L*
M("`@("`@("!]"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&9I;&5D871A
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&9I;&5D871A.PH@("`@("`@('T*
M("`@("`@("`D=&AI<RT^7VAT;6Q?:6UA9V5S6UT@/2!A<G)A>2@*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8F]D>2<@("`]/B`D
M9FEL961A=&$L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)VYA;64G("`@/3X@)&9I;&5N86UE+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=C7W1Y<&4G(#T^("1C7W1Y<&4L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-I9"<@("`@/3X@
M;60U*'5N:7%I9"AT:6UE*"DI*0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@*3L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O*BH*("`@("`J($%D9',@82!F:6QE('1O('1H92!L:7-T(&]F(&%T=&%C
M:&UE;G1S+@H@("`@("H*("`@("`J($!P87)A;2`@<W1R:6YG("`D9FEL92`@
M("`@("!4:&4@9FEL92!N86UE(&]F('1H92!F:6QE('1O(&%T=&%C:`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@($]2('1H92!F:6QE(&1A
M=&$@:71S96QF"B`@("`@*B!`<&%R86T@('-T<FEN9R`@)&-?='EP92`@("`@
M5&AE(&-O;G1E;G0@='EP90H@("`@("H@0'!A<F%M("!S=')I;F<@("1N86UE
M("`@("`@(%1H92!F:6QE;F%M92!O9B!T:&4@871T86-H;65N=`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@($]N;'D@=7-E(&EF("1F:6QE
M(&ES('1H92!F:6QE(&1A=&$*("`@("`J($!P87)A;2`@8F]O;"`@("`D:7-&
M:6QE;F%M92!7:&5T:&5R("1F:6QE(&ES(&$@9FEL96YA;64@;W(@;F]T"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1&5F875L=',@=&\@
M=')U90H@("`@("H@0')E='5R;B!M:7AE9"!T<G5E(&]N('-U8V-E<W,@;W(@
M4$5!4E]%<G)O<B!O8FIE8W0*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&%D9$%T=&%C:&UE;G0H)&9I;&4L("1C7W1Y<&4@
M/2`G87!P;&EC871I;VXO;V-T970M<W1R96%M)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&YA;64@/2`G)RP@)&ES9FEL96YA;64@/2!T<G5E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D96YC;V1I;F<@/2`G8F%S938T
M)RD*("`@('L*("`@("`@("`D9FEL961A=&$@/2`H)&ES9FEL96YA;64@/3T]
M('1R=64I(#\@)'1H:7,M/E]F:6QE,G-T<B@D9FEL92D*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@)&9I;&4["B`@("`@
M("`@:68@*"1I<V9I;&5N86UE(#T]/2!T<G5E*2!["B`@("`@("`@("`@("\O
M($9O<F-E('1H92!N86UE('1H92!U<V5R('-U<'!L:65D+"!O=&AE<G=I<V4@
M=7-E("1F:6QE"B`@("`@("`@("`@("1F:6QE;F%M92`]("@A96UP='DH)&YA
M;64I*2`_("1N86UE(#H@)&9I;&4["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&9I;&5N86UE(#T@)&YA;64["B`@("`@("`@?0H@("`@("`@(&EF
M("AE;7!T>2@D9FEL96YA;64I*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*`H@("`@("`@("`@("`@("=4:&4@<W5P<&QI960@9FEL
M96YA;64@9F]R('1H92!A='1A8VAM96YT(&-A;EPG="!B92!E;7!T>2<*("`@
M("`@("`@("`@*3L*("`@("`@("!]"B`@("`@("`@)&9I;&5N86UE(#T@8F%S
M96YA;64H)&9I;&5N86UE*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M9FEL961A=&$I*2!["B`@("`@("`@("`@(')E='5R;B`D9FEL961A=&$["B`@
M("`@("`@?0H*("`@("`@("`D=&AI<RT^7W!A<G1S6UT@/2!A<G)A>2@*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8F]D>2<@("`@(#T^("1F
M:6QE9&%T82P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;F%M
M92<@("`@(#T^("1F:6QE;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G8U]T>7!E)R`@(#T^("1C7W1Y<&4L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V5N8V]D:6YG)R`]/B`D96YC;V1I;F<*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE(&-O;G1E;G1S
M(&]F('1H92!G:79E;B!F:6QE(&YA;64@87,@<W1R:6YG"B`@("`@*@H@("`@
M("H@0'!A<F%M("!S=')I;F<@("1F:6QE7VYA;64@('!A=&@@;V8@9FEL92!T
M;R!P<F]C97-S"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@8V]N=&5N=',@;V8@
M)&9I;&5?;F%M90H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9?9FEL93)S='(H)&9I;&5?;F%M92D*("`@('L*("`@("`@
M("!I9B`H(6ES7W)E861A8FQE*"1F:6QE7VYA;64I*2!["B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*"=&:6QE(&ES(&YO="!R96%D86)L
M92`G("X@)&9I;&5?;F%M92D["B`@("`@("`@?0H@("`@("`@(&EF("@A)&9D
M(#T@9F]P96XH)&9I;&5?;F%M92P@)W)B)RDI('L*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H)T-O=6QD(&YO="!O<&5N("<@+B`D9FEL
M95]N86UE*3L*("`@("`@("!]"B`@("`@("`@)&9I;&5S:7IE(#T@9FEL97-I
M>F4H)&9I;&5?;F%M92D["B`@("`@("`@:68@*"1F:6QE<VEZ92`]/2`P*7L*
M("`@("`@("`@("`@)&-O;G0@/2`@(B(["B`@("`@("`@?65L<V5["B`@("`@
M("`@("`@("1C;VYT(#T@9G)E860H)&9D+"`D9FEL97-I>F4I.PH@("`@("`@
M('T*("`@("`@("!F8VQO<V4H)&9D*3L*("`@("`@("!R971U<FX@)&-O;G0[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@=&5X="!S=6)P87)T('1O
M('1H92!M:6UE4&%R="!O8FIE8W0@86YD"B`@("`@*B!R971U<FYS(&ET(&1U
M<FEN9R!T:&4@8G5I;&0@<')O8V5S<RX*("`@("`J"B`@("`@*B!`<&%R86T@
M;6EX960@("`@5&AE(&]B:F5C="!T;R!A9&0@=&AE('!A<G0@=&\L(&]R"B`@
M("`@*B`@("`@("`@("`@("`@("`@;G5L;"!I9B!A(&YE=R!O8FIE8W0@:7,@
M=&\@8F4@8W)E871E9"X*("`@("`J($!P87)A;2!S=')I;F<@("!4:&4@=&5X
M="!T;R!A9&0N"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@5&AE('1E>'0@;6EM
M95!A<G0@;V)J96-T"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@
M("`@9G5N8W1I;VX@)E]A9&1497AT4&%R="@F)&]B:BP@)'1E>'0I"B`@("![
M"B`@("`@("`@)'!A<F%M<ULG8V]N=&5N=%]T>7!E)UT@/2`G=&5X="]P;&%I
M;B<["B`@("`@("`@)'!A<F%M<ULG96YC;V1I;F<G72`@("`@/2`D=&AI<RT^
M7V)U:6QD7W!A<F%M<ULG=&5X=%]E;F-O9&EN9R==.PH@("`@("`@("1P87)A
M;7-;)V-H87)S970G72`@("`@(#T@)'1H:7,M/E]B=6EL9%]P87)A;7-;)W1E
M>'1?8VAA<G-E="==.PH@("`@("`@(&EF("AI<U]O8FIE8W0H)&]B:BDI('L*
M("`@("`@("`@("`@<F5T=7)N("1O8FHM/F%D9%-U8G!A<G0H)'1E>'0L("1P
M87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!N
M97<@36%I;%]M:6UE4&%R="@D=&5X="P@)'!A<F%M<RD["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@061D<R!A(&AT;6P@<W5B<&%R="!T;R!T
M:&4@;6EM95!A<G0@;V)J96-T(&%N9`H@("`@("H@<F5T=7)N<R!I="!D=7)I
M;F<@=&AE(&)U:6QD('!R;V-E<W,N"B`@("`@*@H@("`@("H@0'!A<F%M("!M
M:7AE9"`@(%1H92!O8FIE8W0@=&\@861D('1H92!P87)T('1O+"!O<@H@("`@
M("H@("`@("`@("`@("`@("`@(&YU;&P@:68@82!N97<@;V)J96-T(&ES('1O
M(&)E(&-R96%T960N"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@5&AE(&AT;6P@
M;6EM95!A<G0@;V)J96-T"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M+PH@("`@9G5N8W1I;VX@)E]A9&1(=&UL4&%R="@F)&]B:BD*("`@('L*("`@
M("`@("`D<&%R86US6R=C;VYT96YT7W1Y<&4G72`]("=T97AT+VAT;6PG.PH@
M("`@("`@("1P87)A;7-;)V5N8V]D:6YG)UT@("`@(#T@)'1H:7,M/E]B=6EL
M9%]P87)A;7-;)VAT;6Q?96YC;V1I;F<G73L*("`@("`@("`D<&%R86US6R=C
M:&%R<V5T)UT@("`@("`]("1T:&ES+3Y?8G5I;&1?<&%R86US6R=H=&UL7V-H
M87)S970G73L*("`@("`@("!I9B`H:7-?;V)J96-T*"1O8FHI*2!["B`@("`@
M("`@("`@(')E='5R;B`D;V)J+3YA9&13=6)P87)T*"1T:&ES+3Y?:'1M;&)O
M9'DL("1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B!N97<@36%I;%]M:6UE4&%R="@D=&AI<RT^7VAT;6QB;V1Y+"`D<&%R
M86US*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S
M(&$@;F5W(&UI;65087)T(&]B:F5C="P@=7-I;F<@;75L=&EP87)T+VUI>&5D
M(&%S"B`@("`@*B!T:&4@:6YI=&EA;"!C;VYT96YT+71Y<&4@86YD(')E='5R
M;G,@:70@9'5R:6YG('1H90H@("`@("H@8G5I;&0@<')O8V5S<RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@5&AE(&UU;'1I<&%R="]M:7AE9"!M
M:6UE4&%R="!O8FIE8W0*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO
M"B`@("!F=6YC=&EO;B`F7V%D9$UI>&5D4&%R="@I"B`@("!["B`@("`@("`@
M)'!A<F%M<ULG8V]N=&5N=%]T>7!E)UT@/2`G;75L=&EP87)T+VUI>&5D)SL*
M("`@("`@("!R971U<FX@;F5W($UA:6Q?;6EM95!A<G0H)R<L("1P87)A;7,I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@061D<R!A(&UU;'1I<&%R="]A;'1E
M<FYA=&EV92!P87)T('1O(&$@;6EM95!A<G0*("`@("`J(&]B:F5C="`H;W(@
M8W)E871E<R!O;F4I+"!A;F0@<F5T=7)N<R!I="!D=7)I;F<*("`@("`J('1H
M92!B=6EL9"!P<F]C97-S+@H@("`@("H*("`@("`J($!P87)A;2`@;6EX960@
M("!4:&4@;V)J96-T('1O(&%D9"!T:&4@<&%R="!T;RP@;W(*("`@("`J("`@
M("`@("`@("`@("`@("!N=6QL(&EF(&$@;F5W(&]B:F5C="!I<R!T;R!B92!C
M<F5A=&5D+@H@("`@("H@0')E='5R;B!O8FIE8W0@(%1H92!M=6QT:7!A<G0O
M;6EX960@;6EM95!A<G0@;V)J96-T"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J+PH@("`@9G5N8W1I;VX@)E]A9&1!;'1E<FYA=&EV95!A<G0H)B1O
M8FHI"B`@("!["B`@("`@("`@)'!A<F%M<ULG8V]N=&5N=%]T>7!E)UT@/2`G
M;75L=&EP87)T+V%L=&5R;F%T:79E)SL*("`@("`@("!I9B`H:7-?;V)J96-T
M*"1O8FHI*2!["B`@("`@("`@("`@(')E='5R;B`D;V)J+3YA9&13=6)P87)T
M*"<G+"`D<&%R86US*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@;F5W($UA:6Q?;6EM95!A<G0H)R<L("1P87)A;7,I.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@82!M=6QT:7!A<G0O<F5L
M871E9"!P87)T('1O(&$@;6EM95!A<G0*("`@("`J(&]B:F5C="`H;W(@8W)E
M871E<R!O;F4I+"!A;F0@<F5T=7)N<R!I="!D=7)I;F<*("`@("`J('1H92!B
M=6EL9"!P<F]C97-S+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`@("!4
M:&4@;V)J96-T('1O(&%D9"!T:&4@<&%R="!T;RP@;W(*("`@("`J("`@("`@
M("`@("`@("`@("!N=6QL(&EF(&$@;F5W(&]B:F5C="!I<R!T;R!B92!C<F5A
M=&5D"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@5&AE(&UU;'1I<&%R="]M:7AE
M9"!M:6UE4&%R="!O8FIE8W0*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("HO"B`@("!F=6YC=&EO;B`F7V%D9%)E;&%T961087)T*"8D;V)J*0H@("`@
M>PH@("`@("`@("1P87)A;7-;)V-O;G1E;G1?='EP92==(#T@)VUU;'1I<&%R
M="]R96QA=&5D)SL*("`@("`@("!I9B`H:7-?;V)J96-T*"1O8FHI*2!["B`@
M("`@("`@("`@(')E='5R;B`D;V)J+3YA9&13=6)P87)T*"<G+"`D<&%R86US
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@;F5W($UA
M:6Q?;6EM95!A<G0H)R<L("1P87)A;7,I.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($%D9',@86X@:'1M;"!I;6%G92!S=6)P87)T('1O(&$@
M;6EM95!A<G0@;V)J96-T"B`@("`@*B!A;F0@<F5T=7)N<R!I="!D=7)I;F<@
M=&AE(&)U:6QD('!R;V-E<W,N"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE
M8W0@(%1H92!M:6UE4&%R="!T;R!A9&0@=&AE(&EM86=E('1O"B`@("`@*B!`
M<&%R86T@(&%R<F%Y("`@5&AE(&EM86=E(&EN9F]R;6%T:6]N"B`@("`@*B!`
M<F5T=7)N(&]B:F5C="`@5&AE(&EM86=E(&UI;65087)T(&]B:F5C=`H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N("9?861D
M2'1M;$EM86=E4&%R="@F)&]B:BP@)'9A;'5E*0H@("`@>PH@("`@("`@("1P
M87)A;7-;)V-O;G1E;G1?='EP92==(#T@)'9A;'5E6R=C7W1Y<&4G73L*("`@
M("`@("`D<&%R86US6R=E;F-O9&EN9R==("`@("`]("=B87-E-C0G.PH@("`@
M("`@("1P87)A;7-;)V1I<W!O<VET:6]N)UT@(#T@)VEN;&EN92<["B`@("`@
M("`@)'!A<F%M<ULG9&9I;&5N86UE)UT@("`@/2`D=F%L=65;)VYA;64G73L*
M("`@("`@("`D<&%R86US6R=C:60G72`@("`@("`@("`]("1V86QU95LG8VED
M)UT["B`@("`@("`@)&]B:BT^861D4W5B<&%R="@D=F%L=65;)V)O9'DG72P@
M)'!A<F%M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&%N(&%T=&%C
M:&UE;G0@<W5B<&%R="!T;R!A(&UI;65087)T(&]B:F5C=`H@("`@("H@86YD
M(')E='5R;G,@:70@9'5R:6YG('1H92!B=6EL9"!P<F]C97-S+@H@("`@("H*
M("`@("`J($!P87)A;2`@;V)J96-T("!4:&4@;6EM95!A<G0@=&\@861D('1H
M92!I;6%G92!T;PH@("`@("H@0'!A<F%M("!A<G)A>2`@(%1H92!A='1A8VAM
M96YT(&EN9F]R;6%T:6]N"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@5&AE(&EM
M86=E(&UI;65087)T(&]B:F5C=`H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*B\*("`@(&9U;F-T:6]N("9?861D071T86-H;65N=%!A<G0H)B1O8FHL
M("1V86QU92D*("`@('L*("`@("`@("`D<&%R86US6R=C;VYT96YT7W1Y<&4G
M72`]("1V86QU95LG8U]T>7!E)UT["B`@("`@("`@)'!A<F%M<ULG96YC;V1I
M;F<G72`@("`@/2`D=F%L=65;)V5N8V]D:6YG)UT["B`@("`@("`@)'!A<F%M
M<ULG9&ES<&]S:71I;VXG72`@/2`G871T86-H;65N="<["B`@("`@("`@)'!A
M<F%M<ULG9&9I;&5N86UE)UT@("`@/2`D=F%L=65;)VYA;64G73L*("`@("`@
M("`D;V)J+3YA9&13=6)P87)T*"1V86QU95LG8F]D>2==+"`D<&%R86US*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($)U:6QD<R!T:&4@;75L=&EP87)T(&UE
M<W-A9V4@9G)O;2!T:&4@;&ES="`H)'1H:7,M/E]P87)T<RD@86YD"B`@("`@
M*B!R971U<FYS('1H92!M:6UE(&-O;G1E;G0N"B`@("`@*@H@("`@("H@0'!A
M<F%M("!A<G)A>2`@0G5I;&0@<&%R86UE=&5R<R!T:&%T(&-H86YG92!T:&4@
M=V%Y('1H92!E;6%I;`H@("`@("H@("`@("`@("`@("`@("`@:7,@8G5I;'0N
M(%-H;W5L9"!B92!A<W-O8VEA=&EV92X@0V%N(&-O;G1A:6XZ"B`@("`@*B`@
M("`@("`@("`@("`@("!T97AT7V5N8V]D:6YG("`M("!7:&%T(&5N8V]D:6YG
M('1O('5S92!F;W(@<&QA:6X@=&5X=`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@1&5F875L="!I<R`W8FET"B`@("`@*B`@("`@
M("`@("`@("`@("!H=&UL7V5N8V]D:6YG("`M("!7:&%T(&5N8V]D:6YG('1O
M('5S92!F;W(@:'1M;`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@1&5F875L="!I<R!Q=6]T960M<')I;G1A8FQE"B`@("`@*B`@
M("`@("`@("`@("`@("`W8FET7W=R87`@("`@("`M("!.=6UB97(@;V8@8VAA
M<F%C=&5R<R!B969O<F4@=&5X="!I<PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@=W)A<'!E9"!I;B`W8FET(&5N8V]D:6YG"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!$969A=6QT
M(&ES(#DY.`H@("`@("H@("`@("`@("`@("`@("`@:'1M;%]C:&%R<V5T("`@
M+2`@5&AE(&-H87)A8W1E<B!S970@=&\@=7-E(&9O<B!H=&UL+@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1&5F875L="!I<R!I
M<V\M.#@U.2TQ"B`@("`@*B`@("`@("`@("`@("`@("!T97AT7V-H87)S970@
M("`M("!4:&4@8VAA<F%C=&5R('-E="!T;R!U<V4@9F]R('1E>'0N"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!$969A=6QT(&ES
M(&ES;RTX.#4Y+3$*("`@("`J("`@("`@("`@("`@("`@(&AE861?8VAA<G-E
M="`@("T@(%1H92!C:&%R86-T97(@<V5T('1O('5S92!F;W(@:&5A9&5R<RX*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($1E9F%U
M;'0@:7,@:7-O+3@X-3DM,0H@("`@("H@0')E='5R;B!S=')I;F<@5&AE(&UI
M;64@8V]N=&5N=`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@)F=E="@D8G5I;&1?<&%R86US(#T@;G5L;"D*("`@('L*("`@
M("`@("!I9B`H:7-S970H)&)U:6QD7W!A<F%M<RDI('L*("`@("`@("`@("`@
M=VAI;&4@*&QI<W0H)&ME>2P@)'9A;'5E*2`](&5A8V@H)&)U:6QD7W!A<F%M
M<RDI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?8G5I;&1?<&%R86US6R1K
M97E=(#T@)'9A;'5E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!I9B`H(65M<'1Y*"1T:&ES+3Y?:'1M;%]I;6%G97,I($%.1"!I<W-E="@D
M=&AI<RT^7VAT;6QB;V1Y*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D=&AI
M<RT^7VAT;6Q?:6UA9V5S(&%S("1V86QU92D@>PH@("`@("`@("`@("`@("`@
M)')E9V5X(#T@)R,H7',I*"@_:2ES<F-\8F%C:V=R;W5N9'QH<F5F*#\M:2DI
M7',J/5QS*BA;(EPG73\I)R`N('!R96=?<75O=&4H)'9A;'5E6R=N86UE)UTL
M("<C)RD@+@H@("`@("`@("`@("`@("`@("`@("`@("`@)UPS(R<["B`@("`@
M("`@("`@("`@("`D<F5P(#T@)UPQ7#(]7#-C:60Z)R`N("1V86QU95LG8VED
M)UT@+B=<,R<["B`@("`@("`@("`@("`@("`D=&AI<RT^7VAT;6QB;V1Y(#T@
M<')E9U]R97!L86-E*"1R96=E>"P@)')E<"P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]H=&UL8F]D>0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@("1N=6QL("`@("`@("`](&YU;&P["B`@("`@
M("`@)&%T=&%C:&UE;G1S(#T@(65M<'1Y*"1T:&ES+3Y?<&%R=',I("`@("`@
M("`@("`@("`@(#\@=')U92`Z(&9A;'-E.PH@("`@("`@("1H=&UL7VEM86=E
M<R`]("%E;7!T>2@D=&AI<RT^7VAT;6Q?:6UA9V5S*2`@("`@("`@("`_('1R
M=64@.B!F86QS93L*("`@("`@("`D:'1M;"`@("`@("`@/2`A96UP='DH)'1H
M:7,M/E]H=&UL8F]D>2D@("`@("`@("`@("`@/R!T<G5E(#H@9F%L<V4["B`@
M("`@("`@)'1E>'0@("`@("`@(#T@*"$D:'1M;"!!3D0@(65M<'1Y*"1T:&ES
M+3Y?='AT8F]D>2DI(#\@=')U92`Z(&9A;'-E.PH*("`@("`@("!S=VET8V@@
M*'1R=64I('L*("`@("`@("!C87-E("1T97AT($%.1"`A)&%T=&%C:&UE;G1S
M.@H@("`@("`@("`@("`D;65S<V%G92`])B`D=&AI<RT^7V%D9%1E>'1087)T
M*"1N=6QL+"`D=&AI<RT^7W1X=&)O9'DI.PH@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@8V%S92`A)'1E>'0@04Y$("$D:'1M;"!!3D0@)&%T=&%C:&UE
M;G1S.@H@("`@("`@("`@("`D;65S<V%G92`])B`D=&AI<RT^7V%D9$UI>&5D
M4&%R="@I.PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D
M=&AI<RT^7W!A<G1S*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]A9&1!='1A8VAM96YT4&%R="@D;65S<V%G92P@)'1H:7,M/E]P87)T<ULD
M:5TI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!C87-E("1T97AT($%.1"`D871T86-H;65N=',Z"B`@("`@("`@("`@("1M
M97-S86=E(#TF("1T:&ES+3Y?861D36EX961087)T*"D["B`@("`@("`@("`@
M("1T:&ES+3Y?861D5&5X=%!A<G0H)&UE<W-A9V4L("1T:&ES+3Y?='AT8F]D
M>2D["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1T:&ES
M+3Y?<&%R=',I.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V%D
M9$%T=&%C:&UE;G1087)T*"1M97-S86=E+"`D=&AI<RT^7W!A<G1S6R1I72D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@)&AT;6P@04Y$("$D871T86-H;65N=',@04Y$("$D:'1M;%]I;6%G97,Z
M"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W1X=&)O9'DI*2!["B`@
M("`@("`@("`@("`@("`D;65S<V%G92`])B`D=&AI<RT^7V%D9$%L=&5R;F%T
M:79E4&%R="@D;G5L;"D["B`@("`@("`@("`@("`@("`D=&AI<RT^7V%D9%1E
M>'1087)T*"1M97-S86=E+"`D=&AI<RT^7W1X=&)O9'DI.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]A9&1(=&UL4&%R="@D;65S<V%G92D["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D;65S<V%G92`])B`D=&AI
M<RT^7V%D9$AT;6Q087)T*"1N=6QL*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`D:'1M;"!!3D0@(21A='1A8VAM
M96YT<R!!3D0@)&AT;6Q?:6UA9V5S.@H@("`@("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]T>'1B;V1Y*2D@>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@
M/28@)'1H:7,M/E]A9&1!;'1E<FYA=&EV95!A<G0H)&YU;&PI.PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]A9&1497AT4&%R="@D;65S<V%G92P@)'1H:7,M
M/E]T>'1B;V1Y*3L*("`@("`@("`@("`@("`@("1R96QA=&5D(#TF("1T:&ES
M+3Y?861D4F5L871E9%!A<G0H)&UE<W-A9V4I.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@/28@)'1H:7,M/E]A9&12
M96QA=&5D4&%R="@D;G5L;"D["B`@("`@("`@("`@("`@("`D<F5L871E9"`]
M)B`D;65S<V%G93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^
M7V%D9$AT;6Q087)T*"1R96QA=&5D*3L*("`@("`@("`@("`@9F]R("@D:2`]
M(#`[("1I(#P@8V]U;G0H)'1H:7,M/E]H=&UL7VEM86=E<RD[("1I*RLI('L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?861D2'1M;$EM86=E4&%R="@D<F5L
M871E9"P@)'1H:7,M/E]H=&UL7VEM86=E<ULD:5TI.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("1H=&UL($%.1"`D
M871T86-H;65N=',@04Y$("$D:'1M;%]I;6%G97,Z"B`@("`@("`@("`@("1M
M97-S86=E(#TF("1T:&ES+3Y?861D36EX961087)T*"D["B`@("`@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^7W1X=&)O9'DI*2!["B`@("`@("`@("`@("`@
M("`D86QT(#TF("1T:&ES+3Y?861D06QT97)N871I=F5087)T*"1M97-S86=E
M*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?861D5&5X=%!A<G0H)&%L="P@
M)'1H:7,M/E]T>'1B;V1Y*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?861D
M2'1M;%!A<G0H)&%L="D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V%D9$AT;6Q087)T*"1M97-S86=E*3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D
M=&AI<RT^7W!A<G1S*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]A9&1!='1A8VAM96YT4&%R="@D;65S<V%G92P@)'1H:7,M/E]P87)T<ULD
M:5TI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!C87-E("1H=&UL($%.1"`D871T86-H;65N=',@04Y$("1H=&UL7VEM86=E
M<SH*("`@("`@("`@("`@)&UE<W-A9V4@/28@)'1H:7,M/E]A9&1-:7AE9%!A
M<G0H*3L*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?='AT8F]D>2DI
M('L*("`@("`@("`@("`@("`@("1A;'0@/28@)'1H:7,M/E]A9&1!;'1E<FYA
M=&EV95!A<G0H)&UE<W-A9V4I.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]A
M9&1497AT4&%R="@D86QT+"`D=&AI<RT^7W1X=&)O9'DI.PH@("`@("`@("`@
M("`@("`@)')E;"`])B`D=&AI<RT^7V%D9%)E;&%T961087)T*"1A;'0I.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)')E;"`])B`D
M=&AI<RT^7V%D9%)E;&%T961087)T*"1M97-S86=E*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D=&AI<RT^7V%D9$AT;6Q087)T*"1R96PI.PH@("`@
M("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D=&AI<RT^7VAT;6Q?
M:6UA9V5S*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1(
M=&UL26UA9V5087)T*"1R96PL("1T:&ES+3Y?:'1M;%]I;6%G97-;)&E=*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C
M;W5N="@D=&AI<RT^7W!A<G1S*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]A9&1!='1A8VAM96YT4&%R="@D;65S<V%G92P@)'1H:7,M/E]P
M87)T<ULD:5TI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D;65S<V%G92DI('L*("`@
M("`@("`@("`@)&]U='!U="`]("1M97-S86=E+3YE;F-O9&4H*3L*("`@("`@
M("`@("`@)'1H:7,M/E]H96%D97)S(#T@87)R87E?;65R9V4H)'1H:7,M/E]H
M96%D97)S+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D;W5T<'5T6R=H96%D97)S)UTI.PH@("`@("`@("`@("!R971U<FX@
M)&]U='!U=%LG8F]D>2==.PH*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!A;B!A<G)A>2!W:71H('1H92!H96%D97)S(&YE961E9"!T
M;R!P<F5P96YD('1O('1H92!E;6%I;`H@("`@("H@*$U)344M5F5R<VEO;B!A
M;F0@0V]N=&5N="U4>7!E*2X@1F]R;6%T(&]F(&%R9W5M96YT(&ES.@H@("`@
M("H@)&%R<F%Y6R=H96%D97(M;F%M92==(#T@)VAE861E<BUV86QU92<["B`@
M("`@*@H@("`@("H@0'!A<F%M("!A<G)A>2`D>'1R85]H96%D97)S($%S<V]C
M(&%R<F%Y('=I=&@@86YY(&5X=')A(&AE861E<G,N"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@3W!T:6]N86PN"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y($%S<V]C(&%R<F%Y('=I=&@@=&AE(&UI;64@:&5A9&5R<PH@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@)FAE861E
M<G,H)'AT<F%?:&5A9&5R<R`](&YU;&PI"B`@("!["B`@("`@("`@+R\@0V]N
M=&5N="U4>7!E(&AE861E<B!S:&]U;&0@86QR96%D>2!B92!P<F5S96YT+`H@
M("`@("`@("\O(%-O(&IU<W0@861D(&UI;64@=F5R<VEO;B!H96%D97(*("`@
M("`@("`D:&5A9&5R<ULG34E-12U697)S:6]N)UT@/2`G,2XP)SL*("`@("`@
M("!I9B`H:7-S970H)'AT<F%?:&5A9&5R<RDI('L*("`@("`@("`@("`@)&AE
M861E<G,@/2!A<G)A>5]M97)G92@D:&5A9&5R<RP@)'AT<F%?:&5A9&5R<RD[
M"B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?:&5A9&5R<R`](&%R<F%Y7VUE
M<F=E*"1H96%D97)S+"`D=&AI<RT^7VAE861E<G,I.PH*("`@("`@("!R971U
M<FX@)'1H:7,M/E]E;F-O9&5(96%D97)S*"1T:&ES+3Y?:&5A9&5R<RD["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE('1E>'0@=F5R<VEO;B!O9B!T
M:&4@:&5A9&5R<PH@("`@("H@*'5S969U;&P@:68@>6]U('=A;G0@=&\@=7-E
M('1H92!02%`@;6%I;"@I(&9U;F-T:6]N*0H@("`@("H*("`@("`J($!P87)A
M;2`@87)R87D@("`D>'1R85]H96%D97)S($%S<V]C(&%R<F%Y('=I=&@@86YY
M(&5X=')A(&AE861E<G,N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!/<'1I;VYA;"X*("`@("`J($!R971U<FX@<W1R:6YG("!0;&%I
M;B!T97AT(&AE861E<G,*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N('1X=$AE861E<G,H)'AT<F%?:&5A9&5R<R`](&YU;&PI
M"B`@("!["B`@("`@("`@)&AE861E<G,@/2`D=&AI<RT^:&5A9&5R<R@D>'1R
M85]H96%D97)S*3L*("`@("`@("`D<F5T(#T@)R<["B`@("`@("`@9F]R96%C
M:"`H)&AE861E<G,@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@("1R
M970@+CT@(B1K97DZ("1V86PB("X@34%)3%]-24U%7T-23$8["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D<F5T.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4V5T<R!T:&4@4W5B:F5C="!H96%D97(*("`@("`J"B`@("`@*B!`<&%R86T@
M('-T<FEN9R`D<W5B:F5C="!3=')I;F<@=&\@<V5T('1H92!S=6)J96-T('1O
M"B`@("`@*B!A8V-E<W,@('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!S
M9713=6)J96-T*"1S=6)J96-T*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:&5A
M9&5R<ULG4W5B:F5C="==(#T@)'-U8FIE8W0["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3970@86X@96UA:6P@=&\@=&AE($9R;VT@*'1H92!S96YD97(I(&AE
M861E<@H@("`@("H*("`@("`J($!P87)A;2`@<W1R:6YG("1E;6%I;"!4:&4@
M96UA:6P@9&ER96-T:6]N('1O(&%D9`H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@<V5T1G)O;2@D96UA:6PI"B`@("!["B`@
M("`@("`@)'1H:7,M/E]H96%D97)S6R=&<F]M)UT@/2`D96UA:6P["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!9&0@86X@96UA:6P@=&\@=&AE($-C("AC87)B
M;VX@8V]P>2D@:&5A9&5R"B`@("`@*B`H;75L=&EP;&4@8V%L;',@=&\@=&AI
M<R!M971H;V0@87)E(&%L;&]W960I"B`@("`@*@H@("`@("H@0'!A<F%M("!S
M=')I;F<@)&5M86EL(%1H92!E;6%I;"!D:7)E8W1I;VX@=&\@861D"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!A9&1#8R@D
M96UA:6PI"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?:&5A9&5R
M<ULG0V,G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]H96%D97)S6R=#8R==
M("X]("(L("1E;6%I;"(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'1H:7,M/E]H96%D97)S6R=#8R==(#T@)&5M86EL.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($%D9"!A;B!E;6%I;"!T;R!T:&4@0F-C("AB
M;&%N:R!C87)B;VX@8V]P>2D@:&5A9&5R"B`@("`@*B`H;75L=&EP;&4@8V%L
M;',@=&\@=&AI<R!M971H;V0@87)E(&%L;&]W960I"B`@("`@*@H@("`@("H@
M0'!A<F%M("!S=')I;F<@)&5M86EL(%1H92!E;6%I;"!D:7)E8W1I;VX@=&\@
M861D"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO
M;B!A9&1"8V,H)&5M86EL*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^7VAE861E<G-;)T)C8R==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VAE
M861E<G-;)T)C8R==("X]("(L("1E;6%I;"(["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'1H:7,M/E]H96%D97)S6R="8V,G72`]("1E;6%I;#L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!%;F-O9&5S(&$@:&5A
M9&5R(&%S('!E<B!21D,R,#0W"B`@("`@*@H@("`@("H@0'!A<F%M("!S=')I
M;F<@("1I;G!U="!4:&4@:&5A9&5R(&1A=&$@=&\@96YC;V1E"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@16YC;V1E9"!D871A"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V5N8V]D94AE861E<G,H)&EN
M<'5T*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1I;G!U="!A<R`D:&1R7VYA
M;64@/3X@)&AD<E]V86QU92D@>PH@("`@("`@("`@("!P<F5G7VUA=&-H7V%L
M;"@G+RA<=RI;7'@X,"U<>$9&72M<=RHI+R<L("1H9')?=F%L=64L("1M871C
M:&5S*3L*("`@("`@("`@("`@9F]R96%C:"`H)&UA=&-H97-;,5T@87,@)'9A
M;'5E*2!["B`@("`@("`@("`@("`@("`D<F5P;&%C96UE;G0@/2!P<F5G7W)E
M<&QA8V4H)R\H6UQX.#`M7'A&1ETI+V4G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("<B/2(@+@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-T<G1O=7!P97(H9&5C
M:&5X*&]R9"@B7#$B*2DI)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=F%L=64I.PH@("`@("`@("`@("`@("`@)&AD
M<E]V86QU92`]('-T<E]R97!L86-E*"1V86QU92P@)ST_)R`N"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]B=6EL
M9%]P87)A;7-;)VAE861?8VAA<G-E="==("X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G/U$_)R`N("1R97!L86-E;65N="`N
M("<_/2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&AD<E]V86QU92D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&EN
M<'5T6R1H9')?;F%M95T@/2`D:&1R7W9A;'5E.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1I;G!U=#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T
M:&4@;V)J96-T)W,@96YD+6]F+6QI;F4@86YD(&1E9FEN92!T:&4@8V]N<W1A
M;G0@:68@87!P;&EC86)L90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&5O;"!%;F0@3V8@3&EN92!S97%U96YC90H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S971%3TPH)&5O;"D*("`@('L*
M("`@("`@("`D=&AI<RT^7V5O;"`]("1E;VP["B`@("`@("`@:68@*"%D969I
M;F5D*"=-04E,7TU)345?0U),1B<I*2!["B`@("`@("`@("`@(&1E9FEN92@G
M34%)3%]-24U%7T-23$8G+"`D=&AI<RT^7V5O;"P@=')U92D["B`@("`@("`@
M?0H@("`@?0H*("`@(`H*?2`O+R!%;F0@;V8@8VQA<W,*/SX*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+TUA:6PO;6%I;"YP:'``
M````````````````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3$W
M,S<@,3`U,34T,S,W,S,@,#(Q,#$T`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT
M("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO
M;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I
M<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.
M4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X
M="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@
M>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E
M(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@
M("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@
M>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<CH@0VAU8VL@
M2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O
M"B\O("1)9#H@;6%I;"YP:'`L=B`Q+C$U(#(P,#4O,3`O,3`@,#0Z,38Z,C8@
M:F]N($5X<"`D"@HO*BH*("H@:6YT97)N86P@4$A0+6UA:6PH*2!I;7!L96UE
M;G1A=&EO;B!O9B!T:&4@4$5!4B!-86EL.CH@:6YT97)F86-E+@H@*B!`<&%C
M:V%G92!-86EL"B`J($!V97)S:6]N("12979I<VEO;CH@,2XQ-2`D"B`J+PIC
M;&%S<R!-86EL7VUA:6P@97AT96YD<R!-86EL('L*"B`@("`O*BH*("`@("`J
M($%N>2!A<F=U;65N=',@=&\@<&%S<R!T;R!T:&4@;6%I;"@I(&9U;F-T:6]N
M+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?<&%R86US
M(#T@)R<["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@
M("`@*B!);G-T86YT:6%T97,@82!N97<@36%I;%]M86EL.CH@;V)J96-T(&)A
M<V5D(&]N('1H92!P87)A;65T97)S"B`@("`@*B!P87-S960@:6XN"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@17AT<F$@87)G=6UE;G1S
M(&9O<B!T:&4@;6%I;"@I(&9U;F-T:6]N+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!-86EL7VUA:6PH)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@+RH@
M5&AE(&]T:&5R(&UA:6P@:6UP;&5M96YT871I;VYS(&%C8V5P="!P87)A;65T
M97)S(&%S(&%R<F%Y<RX*("`@("`@("`@*B!);B!T:&4@:6YT97)E<W0@;V8@
M8F5I;F<@8V]N<VES=&5N="P@97AP;&]D92!A;B!A<G)A>2!I;G1O"B`@("`@
M("`@("H@82!S=')I;F<@;V8@<&%R86UE=&5R(&%R9W5M96YT<RX@*B\*("`@
M("`@("!I9B`H:7-?87)R87DH)'!A<F%M<RDI('L*("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7,@/2!J;VEN*"<@)RP@)'!A<F%M<RD["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH@
M("`@("`@('T*"B`@("`@("`@+RH@0F5C875S92!T:&4@;6%I;"@I(&9U;F-T
M:6]N(&UA>2!P87-S(&AE861E<G,@87,@8V]M;6%N9`H@("`@("`@("`J(&QI
M;F4@87)G=6UE;G1S+"!W92!C86XG="!G=6%R86YT964@=&AE('5S92!O9B!T
M:&4@<W1A;F1A<F0*("`@("`@("`@*B`B7')<;B(@<V5P87)A=&]R+B`@26YS
M=&5A9"P@=V4@=7-E('1H92!S>7-T96TG<R!N871I=F4@;&EN90H@("`@("`@
M("`J('-E<&%R871O<BX@*B\*("`@("`@("!I9B`H9&5F:6YE9"A02%!?14],
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^<V5P(#T@4$A07T5/3#L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^<V5P(#T@*'-T<G!O<RA0
M2%!?3U,L("=724XG*2`]/3T@9F%L<V4I(#\@(EQN(B`Z(")<<EQN(CL*("`@
M("`@("!]"B`@("!]"@H)+RHJ"B`@("`@*B!);7!L96UE;G1S($UA:6Q?;6%I
M;#HZ<V5N9"@I(&9U;F-T:6]N('5S:6YG('!H<"=S(&)U:6QT+6EN(&UA:6PH
M*0H@("`@("H@8V]M;6%N9"X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@
M)')E8VEP:65N=',@16ET:&5R(&$@8V]M;6$M<V5P97)A=&5D(&QI<W0@;V8@
M<F5C:7!I96YT<PH@("`@("H@("`@("`@("`@("`@("A21D,X,C(@8V]M<&QI
M86YT*2P@;W(@86X@87)R87D@;V8@<F5C:7!I96YT<RP*("`@("`J("`@("`@
M("`@("`@("!E86-H(%)&0S@R,B!V86QI9"X@5&AI<R!M87D@8V]N=&%I;B!R
M96-I<&EE;G1S(&YO=`H@("`@("H@("`@("`@("`@("`@('-P96-I9FEE9"!I
M;B!T:&4@:&5A9&5R<RP@9F]R($)C8SHL(')E<V5N9&EN9PH@("`@("H@("`@
M("`@("`@("`@(&UE<W-A9V5S+"!E=&,N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1H96%D97)S(%1H92!A<G)A>2!O9B!H96%D97)S('1O('-E;F0@
M=VET:"!T:&4@;6%I;"P@:6X@86X*("`@("`J("`@("`@("`@("`@("!A<W-O
M8VEA=&EV92!A<G)A>2P@=VAE<F4@=&AE(&%R<F%Y(&ME>2!I<R!T:&4*("`@
M("`J("`@("`@("`@("`@("!H96%D97(@;F%M92`H:64L("=3=6)J96-T)RDL
M(&%N9"!T:&4@87)R87D@=F%L=64*("`@("`J("`@("`@("`@("`@("!I<R!T
M:&4@:&5A9&5R('9A;'5E("AI92P@)W1E<W0G*2X@5&AE(&AE861E<@H@("`@
M("H@("`@("`@("`@("`@('!R;V1U8V5D(&9R;VT@=&AO<V4@=F%L=65S('=O
M=6QD(&)E("=3=6)J96-T.@H@("`@("H@("`@("`@("`@("`@('1E<W0G+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&)O9'D@5&AE(&9U;&P@=&5X
M="!O9B!T:&4@;65S<V%G92!B;V1Y+"!I;F-L=61I;F<@86YY"B`@("`@*B`@
M("`@("`@("`@("`@($UI;64@<&%R=',L(&5T8RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D(%)E='5R;G,@=')U92!O;B!S=6-C97-S+"!O<B!A(%!%
M05)?17)R;W(*("`@("`J("`@("`@("`@("`@("`@8V]N=&%I;FEN9R!A(&1E
M<V-R:7!T:79E(&5R<F]R(&UE<W-A9V4@;VX*("`@("`J("`@("`@("`@("`@
M("`@9F%I;'5R92X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("HO"B`@("!F=6YC=&EO;B!S96YD*"1R96-I<&EE;G1S+"`D:&5A9&5R<RP@
M)&)O9'DI"B`@("!["B`@("`@("`@+R\@268@=V4G<F4@<&%S<V5D(&%N(&%R
M<F%Y(&]F(')E8VEP:65N=',L(&EM<&QO9&4@:70N"B`@("`@("`@:68@*&ES
M7V%R<F%Y*"1R96-I<&EE;G1S*2D@>PH@("`@("`@("`@("`D<F5C:7!I96YT
M<R`](&EM<&QO9&4H)RP@)RP@)')E8VEP:65N=',I.PH@("`@("`@('T*"B`@
M("`@("`@+R\@1V5T('1H92!3=6)J96-T(&]U="!O9B!T:&4@:&5A9&5R<R!A
M<G)A>2!S;R!T:&%T('=E(&-A;@H@("`@("`@("\O('!A<W,@:70@87,@82!S
M97!E<F%T92!A<F=U;65N="!T;R!M86EL*"DN"B`@("`@("`@)'-U8FIE8W0@
M/2`G)SL*("`@("`@("!I9B`H:7-S970H)&AE861E<G-;)U-U8FIE8W0G72DI
M('L*("`@("`@("`@("`@)'-U8FIE8W0@/2`D:&5A9&5R<ULG4W5B:F5C="==
M.PH@("`@("`@("`@("!U;G-E="@D:&5A9&5R<ULG4W5B:F5C="==*3L*("`@
M("`@("!]"@H@("`@("`@("\O($9L871T96X@=&AE(&AE861E<G,@;W5T+@H@
M("`@("`@("1H96%D97)%;&5M96YT<R`]("1T:&ES+3YP<F5P87)E2&5A9&5R
M<R@D:&5A9&5R<RD["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&AE861E
M<D5L96UE;G1S*2D@>PH@("`@("`@("`@("!R971U<FX@)&AE861E<D5L96UE
M;G1S.PH@("`@("`@('T*("`@("`@("!L:7-T*"P@)'1E>'1?:&5A9&5R<RD@
M/2`D:&5A9&5R16QE;65N=',["@H@("`@("`@("\J"B`@("`@("`@("H@5V4@
M;VYL>2!U<V4@;6%I;"@I)W,@;W!T:6]N86P@9FEF=&@@<&%R86UE=&5R(&EF
M('1H92!A9&1I=&EO;F%L"B`@("`@("`@("H@<&%R86UE=&5R<R!H879E(&)E
M96X@<')O=FED960@86YD('=E)W)E(&YO="!R=6YN:6YG(&EN('-A9F4@;6]D
M92X*("`@("`@("`@*B\*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)A
M;7,I('Q\(&EN:5]G970H)W-A9F5?;6]D92<I*2!["B`@("`@("`@("`@("1R
M97-U;'0@/2!M86EL*"1R96-I<&EE;G1S+"`D<W5B:F5C="P@)&)O9'DL("1T
M97AT7VAE861E<G,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R
M97-U;'0@/2!M86EL*"1R96-I<&EE;G1S+"`D<W5B:F5C="P@)&)O9'DL("1T
M97AT7VAE861E<G,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%R86US*3L*("`@("`@("!]"@H@("`@("`@("\J"B`@("`@("`@("H@
M268@=&AE(&UA:6PH*2!F=6YC=&EO;B!R971U<FYE9"!F86EL=7)E+"!W92!N
M965D('1O(&-R96%T92!A"B`@("`@("`@("H@4$5!4E]%<G)O<B!O8FIE8W0@
M86YD(')E='5R;B!I="!I;G-T96%D(&]F('1H92!B;V]L96%N(')E<W5L="X*
M("`@("`@("`@*B\*("`@("`@("!I9B`H)')E<W5L="`]/3T@9F%L<V4I('L*
M("`@("`@("`@("`@)')E<W5L="`](%!%05(Z.G)A:7-E17)R;W(H)VUA:6PH
M*2!R971U<FYE9"!F86EL=7)E)RD["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@('T*"GT*````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]-86EL+VYU
M;&PN<&AP````````````````````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`T-S<Q(#$P-3$U-#,S-S,S(#`R,3`T-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO+PHO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O
M<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O
M('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@?`HO+R!\
M('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL
M92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@
M=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@
M;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@
M=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T
M92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A
M;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W(Z
M(%!H:6P@2V5R;FEC:R`\<&AI;&M`<F]T9FPN8V]M+F%U/B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+PHO+R`D260Z(&YU;&PN<&AP+'8@,2XR(#(P,#0O,#0O,#8@,#4Z
M,3DZ,#,@:F]N($5X<"`D"B\O"@HO*BH*("H@3G5L;"!I;7!L96UE;G1A=&EO
M;B!O9B!T:&4@4$5!4B!-86EL.CH@:6YT97)F86-E+@H@*B!`86-C97-S('!U
M8FQI8PH@*B!`<&%C:V%G92!-86EL"B`J($!V97)S:6]N("12979I<VEO;CH@
M,2XR("0*("HO"F-L87-S($UA:6Q?;G5L;"!E>'1E;F1S($UA:6P@>PH*("`@
M("\J*@H@("`@("H@26UP;&5M96YT<R!-86EL7VYU;&PZ.G-E;F0H*2!F=6YC
M=&EO;BX@4VEL96YT;'D@9&ES8V%R9',@86QL"B`@("`@*B!M86EL+@H@("`@
M("H*("`@("`J($!P87)A;2!M:7AE9"`D<F5C:7!I96YT<R!%:71H97(@82!C
M;VUM82US97!E<F%T960@;&ES="!O9B!R96-I<&EE;G1S"B`@("`@*B`@("`@
M("`@("`@("`@*%)&0S@R,B!C;VUP;&EA;G0I+"!O<B!A;B!A<G)A>2!O9B!R
M96-I<&EE;G1S+`H@("`@("H@("`@("`@("`@("`@(&5A8V@@4D9#.#(R('9A
M;&ED+B!4:&ES(&UA>2!C;VYT86EN(')E8VEP:65N=',@;F]T"B`@("`@*B`@
M("`@("`@("`@("`@<W!E8VEF:65D(&EN('1H92!H96%D97)S+"!F;W(@0F-C
M.BP@<F5S96YD:6YG"B`@("`@*B`@("`@("`@("`@("`@;65S<V%G97,L(&5T
M8RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&AE861E<G,@5&AE(&%R
M<F%Y(&]F(&AE861E<G,@=&\@<V5N9"!W:71H('1H92!M86EL+"!I;B!A;@H@
M("`@("H@("`@("`@("`@("`@(&%S<V]C:6%T:79E(&%R<F%Y+"!W:&5R92!T
M:&4@87)R87D@:V5Y(&ES('1H90H@("`@("H@("`@("`@("`@("`@(&AE861E
M<B!N86UE("AI92P@)U-U8FIE8W0G*2P@86YD('1H92!A<G)A>2!V86QU90H@
M("`@("H@("`@("`@("`@("`@(&ES('1H92!H96%D97(@=F%L=64@*&EE+"`G
M=&5S="<I+B!4:&4@:&5A9&5R"B`@("`@*B`@("`@("`@("`@("`@<')O9'5C
M960@9G)O;2!T:&]S92!V86QU97,@=V]U;&0@8F4@)U-U8FIE8W0Z"B`@("`@
M*B`@("`@("`@("`@("`@=&5S="<N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D8F]D>2!4:&4@9G5L;"!T97AT(&]F('1H92!M97-S86=E(&)O9'DL
M(&EN8VQU9&EN9R!A;GD*("`@("`J("`@("`@("`@("`@("`@36EM92!P87)T
M<RP@971C+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@4F5T=7)N<R!T
M<G5E(&]N('-U8V-E<W,L(&]R(&$@4$5!4E]%<G)O<@H@("`@("H@("`@("`@
M("`@("`@("!C;VYT86EN:6YG(&$@9&5S8W)I<'1I=F4@97)R;W(@;65S<V%G
M92!O;@H@("`@("H@("`@("`@("`@("`@("!F86EL=7)E+@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<V5N9"@D<F5C:7!I
M96YT<RP@)&AE861E<G,L("1B;V1Y*0H@("`@>PH@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*?0H`````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B].970`````````````````````````````````````````````````
M`````````````````````````````````````````#`P,#<U-2``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S,S(#`Q-S$S-0`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+TYE="]&5%``````````````````````
M````````````````````````````````````````````````````````````
M````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T
M,S,W,S,@,#$W-38V`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O3F5T+T94
M4"]/8G-E<G9E<BYP:'``````````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P-38R,B`Q,#4Q-30S,S<S,R`P,C(Q-3(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*"B\J('9I;3H@<V5T
M(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P
M/30Z("HO"@HO*BH*("H@3F5T7T944"!O8G-E<G9E<BX*("H*("H@5&AI<R!C
M;&%S<R!I;7!L96UE;G1S('1H92!/8G-E<G9E<B!P87)T(&]F(&$@4W5B:F5C
M="U/8G-E<G9E<@H@*B!D97-I9VX@<&%T=&5R;BX@270@;&ES=&5N<R!T;R!T
M:&4@979E;G1S('-E;G0@8GD@82!.971?1E10(&EN<W1A;F-E+@H@*B!4:&ES
M(&UO9'5L92!H860@;6%N>2!I;F9L=65N8V5S(&9R;VT@=&AE($QO9U]O8G-E
M<G9E<B!C;V1E+@H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,
M24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO
M;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE
M('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@
M55)).@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@
M268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,
M:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H
M92!W96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN
M970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*
M("H@0&-A=&5G;W)Y("`@3F5T=V]R:VEN9PH@*B!`<&%C:V%G92`@("!&5%`*
M("H@0&%U=&AO<B`@("`@5&]B:6%S(%-C:&QI='0@/'1O8GE`<&AP+FYE=#X*
M("H@0&%U=&AO<B`@("`@3&%U<F5N="!,879I;&QE(#QP96%R0&QA=7)E;G0M
M;&%V:6QL92YO<F<^"B`J($!A=71H;W(@("`@($-H=6-K($AA9V5N8G5C:"`\
M8VAU8VM`:&]R9&4N;W)G/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE
M(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@
M("`@0U93.B`D260Z($]B<V5R=F5R+G!H<"QV(#$N,B`R,#`U+S`R+S(S(#$R
M.C$R.C(S('1O8GD@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N
M<&AP+FYE="]P86-K86=E+TYE=%]&5%`*("H@0'-I;F-E("`@("`@1FEL92!A
M=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C`N,0H@*B\*"B\J*@H@*B!4:&ES
M(&-L87-S(&EM<&QE;65N=',@=&AE($]B<V5R=F5R('!A<G0@;V8@82!3=6)J
M96-T+4]B<V5R=F5R"B`J(&1E<VEG;B!P871T97)N+B!)="!L:7-T96YS('1O
M('1H92!E=F5N=',@<V5N="!B>2!A($YE=%]&5%`@:6YS=&%N8V4N"B`J(%1H
M:7,@;6]D=6QE(&AA9"!M86YY(&EN9FQU96YC97,@9G)O;2!T:&4@3&]G7V]B
M<V5R=F5R(&-O9&4N"B`J"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`8V%T
M96=O<GD@("!.971W;W)K:6YG"B`J($!P86-K86=E("`@($944`H@*B!`875T
M:&]R("`@("!,875R96YT($QA=FEL;&4@/'!E87)`;&%U<F5N="UL879I;&QE
M+F]R9SX*("H@0&%U=&AO<B`@("`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H
M;W)D92YO<F<^"B`J($!A=71H;W(@("`@(%1O8FEA<R!38VAL:71T(#QT;V)Y
M0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R
M;W5P"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N,RXQ"B`J($!L:6YK("`@
M("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92].971?1E10"B`J($!S
M:6YC92`@("`@(#$N,RXP+C`*("H@0&%C8V5S<R`@("`@<'5B;&EC"B`J"B`J
M($!E>&%M<&QE("`@(&]B<V5R=F5R7W5P;&]A9"YP:'`@("`@("`@("`@06X@
M97AA;7!L92!O9B!.971?1E107T]B<V5R=F5R(&EM<&QE;65N=&%T:6]N+@H@
M*B\*8VQA<W,@3F5T7T944%]/8G-E<G9E<@I["B`@("`O*BH*("`@("`J($EN
M<W1A;F-E+7-P96-I9FEC('5N:7%U92!I9&5N=&EF:6-A=&EO;B!N=6UB97(N
M"B`@("`@*@H@("`@("H@0'9A<B`@("`@("`@:6YT96=E<@H@("`@("H@0'-I
M;F-E("`@("`@,2XS+C`*("`@("`J($!A8V-E<W,@("`@('!R:79A=&4*("`@
M("`J+PH@("`@=F%R("1?:60["@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&$@
M;F5W(&)A<VEC($YE=%]&5%!?3V)S97)V97(@:6YS=&%N8V4N"B`@("`@*@H@
M("`@("H@0'-I;F-E("`@("`@,2XS+C`*("`@("`J($!A8V-E<W,@("`@('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!.971?1E107T]B<V5R=F5R*"D*
M("`@('L*("`@("`@("`D=&AI<RT^7VED(#T@;60U*&UI8W)O=&EM92@I*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&QI<W1E;F5R)W,@
M:61E;G1I9FEE<@H@("`@("H*("`@("`J($!R971U<FX@("`@('-T<FEN9PH@
M("`@("H@0'-I;F-E("`@("`@,2XS+C`*("`@("`J($!A8V-E<W,@("`@('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!G971)9"@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?:60["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4
M:&ES(&ES(&$@<W1U8B!M971H;V0@=&\@;6%K92!S=7)E('1H870@3F5T7T94
M4%]/8G-E<G9E<B!C;&%S<V5S(&1O"B`@("`@*B!S;VUE=&AI;F<@=VAE;B!T
M:&5Y(&%R92!N;W1I9FEE9"!O9B!A(&UE<W-A9V4N("!4:&4@9&5F875L="!B
M96AA=FEO<@H@("`@("H@:7,@=&\@:G5S="!D;R!N;W1H:6YG+@H@("`@("H@
M66]U('-H;W5L9"!O=F5R<FED92!T:&ES(&UE=&AO9"X*("`@("`J"B`@("`@
M*B!`<&%R86T@("`@("!M:7AE9"`@("`@)&5V96YT("`@("`@("`@02!H87-H
M(&1E<V-R:6)I;F<@=&AE(&YE="!E=F5N="X*("`@("`J"B`@("`@*B!`<VEN
M8V4@("`@("`Q+C,N,`H@("`@("H@0&%C8V5S<R`@("`@<'5B;&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&YO=&EF>2@D979E;G0I"B`@("!["B`@("`@("`@
M<F5T=7)N.PH@("`@?0I]"C\^"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B].970O4V]C:V5T+G!H<```````````
M````````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#,U-S<U(#$P-3$U
M-#,S-S,S(#`R,3$W-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY
M-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP(&]F
M('1H92!02%`@;&EC96YS92P@("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE
M9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@
M:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@
M;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E
M('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\
M"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O
M<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!3=&EG($)A:VME;B`\
M<W-B0'!H<"YN970^("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O('P@("`@("`@("`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D
M92YO<F<^("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!3;V-K970N<&AP+'8@
M,2XR-"`R,#`U+S`R+S`S(#(P.C0P.C$V(&-H86=E;F)U($5X<"`D"@IR97%U
M:7)E7V]N8V4@)U!%05(N<&AP)SL*"F1E9FEN92@G3D547U-/0TM%5%]214%$
M)RP@(#$I.PID969I;F4H)TY%5%]33T-+151?5U))5$4G+"`R*3L*9&5F:6YE
M*"=.151?4T]#2T547T524D]2)RP@,RD["@HO*BH*("H@1V5N97)A;&EZ960@
M4V]C:V5T(&-L87-S+@H@*@H@*B!`=F5R<VEO;B`Q+C$*("H@0&%U=&AO<B!3
M=&EG($)A:VME;B`\<W-B0'!H<"YN970^"B`J($!A=71H;W(@0VAU8VL@2&%G
M96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J+PIC;&%S<R!.971?4V]C:V5T
M(&5X=&5N9',@4$5!4B!["@H@("`@+RHJ"B`@("`@*B!3;V-K970@9FEL92!P
M;VEN=&5R+@H@("`@("H@0'9A<B!R97-O=7)C92`D9G`*("`@("`J+PH@("`@
M=F%R("1F<"`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!7:&5T:&5R('1H92!S
M;V-K970@:7,@8FQO8VMI;F<N($1E9F%U;'1S('1O('1R=64N"B`@("`@*B!`
M=F%R(&)O;VQE86X@)&)L;V-K:6YG"B`@("`@*B\*("`@('9A<B`D8FQO8VMI
M;F<@/2!T<G5E.PH*("`@("\J*@H@("`@("H@5VAE=&AE<B!T:&4@<V]C:V5T
M(&ES('!E<G-I<W1E;G0N($1E9F%U;'1S('1O(&9A;'-E+@H@("`@("H@0'9A
M<B!B;V]L96%N("1P97)S:7-T96YT"B`@("`@*B\*("`@('9A<B`D<&5R<VES
M=&5N="`](&9A;'-E.PH*("`@("\J*@H@("`@("H@5&AE($E0(&%D9')E<W,@
M=&\@8V]N;F5C="!T;RX*("`@("`J($!V87(@<W1R:6YG("1A9&1R"B`@("`@
M*B\*("`@('9A<B`D861D<B`]("<G.PH*("`@("\J*@H@("`@("H@5&AE('!O
M<G0@;G5M8F5R('1O(&-O;FYE8W0@=&\N"B`@("`@*B!`=F%R(&EN=&5G97(@
M)'!O<G0*("`@("`J+PH@("`@=F%R("1P;W)T(#T@,#L*"B`@("`O*BH*("`@
M("`J($YU;6)E<B!O9B!S96-O;F1S('1O('=A:70@;VX@<V]C:V5T(&-O;FYE
M8W1I;VYS(&)E9F]R92!A<W-U;6EN9PH@("`@("H@=&AE<F4G<R!N;R!M;W)E
M(&1A=&$N($1E9F%U;'1S('1O(&YO('1I;65O=70N"B`@("`@*B!`=F%R(&EN
M=&5G97(@)'1I;65O=70*("`@("`J+PH@("`@=F%R("1T:6UE;W5T(#T@9F%L
M<V4["@H@("`@+RHJ"B`@("`@*B!.=6UB97(@;V8@8GET97,@=&\@<F5A9"!A
M="!A('1I;64@:6X@<F5A9$QI;F4H*2!A;F0*("`@("`J(')E861!;&PH*2X@
M1&5F875L=',@=&\@,C`T."X*("`@("`J($!V87(@:6YT96=E<B`D;&EN94QE
M;F=T:`H@("`@("HO"B`@("!V87(@)&QI;F5,96YG=&@@/2`R,#0X.PH*("`@
M("\J*@H@("`@("H@0V]N;F5C="!T;R!T:&4@<W!E8VEF:65D('!O<G0N($EF
M(&-A;&QE9"!W:&5N('1H92!S;V-K970@:7,*("`@("`J(&%L<F5A9'D@8V]N
M;F5C=&5D+"!I="!D:7-C;VYN96-T<R!A;F0@8V]N;F5C=',@86=A:6XN"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&%D9'(@("`@("`@($E0(&%D
M9')E<W,@;W(@:&]S="!N86UE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'!O
M<G0@("`@("`@(%1#4"!P;W)T(&YU;6)E<BX*("`@("`J($!P87)A;2!B;V]L
M96%N("1P97)S:7-T96YT("`H;W!T:6]N86PI(%=H971H97(@=&AE(&-O;FYE
M8W1I;VX@:7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!P
M97)S:7-T96YT("AK97!T(&]P96X@8F5T=V5E;B!R97%U97-T<PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)Y('1H92!W96(@<V5R=F5R
M*2X*("`@("`J($!P87)A;2!I;G1E9V5R("1T:6UE;W5T("`@("`H;W!T:6]N
M86PI($AO=R!L;VYG('1O('=A:70@9F]R(&1A=&$N"B`@("`@*B!`<&%R86T@
M87)R87D@("`D;W!T:6]N<R`@("`@4V5E(&]P=&EO;G,@9F]R('-T<F5A;5]C
M;VYT97AT7V-R96%T92X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B!\(%!%05)?17)R;W(@(%1R
M=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@8V]N;F5C="@D861D<BP@)'!O<G0@/2`P+"`D
M<&5R<VES=&5N="`](&YU;&PL("1T:6UE;W5T(#T@;G5L;"P@)&]P=&EO;G,@
M/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]R97-O=7)C92@D=&AI<RT^
M9G`I*2!["B`@("`@("`@("`@($!F8VQO<V4H)'1H:7,M/F9P*3L*("`@("`@
M("`@("`@)'1H:7,M/F9P(#T@;G5L;#L*("`@("`@("!]"@H@("`@("`@(&EF
M("@A)&%D9'(I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*"<D861D<B!C86YN;W0@8F4@96UP='DG*3L*("`@("`@("!](&5L<V5I
M9B`H<W1R<W!N*"1A9&1R+"`G+C`Q,C,T-38W.#DG*2`]/2!S=')L96XH)&%D
M9'(I('Q\"B`@("`@("`@("`@("`@("`@('-T<G-T<B@D861D<BP@)R\G*2`A
M/3T@9F%L<V4I('L*("`@("`@("`@("`@)'1H:7,M/F%D9'(@/2`D861D<CL*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^861D<B`]($!G
M971H;W-T8GEN86UE*"1A9&1R*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES
M+3YP;W)T(#T@)'!O<G0@)2`V-34S-CL*"B`@("`@("`@:68@*"1P97)S:7-T
M96YT("$]/2!N=6QL*2!["B`@("`@("`@("`@("1T:&ES+3YP97)S:7-T96YT
M(#T@)'!E<G-I<W1E;G0["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1I;65O
M=70@(3T](&YU;&PI('L*("`@("`@("`@("`@)'1H:7,M/G1I;65O=70@/2`D
M=&EM96]U=#L*("`@("`@("!]"@H@("`@("`@("1O<&5N9G5N8R`]("1T:&ES
M+3YP97)S:7-T96YT(#\@)W!F<V]C:V]P96XG(#H@)V9S;V-K;W!E;B<["B`@
M("`@("`@)&5R<FYO(#T@,#L*("`@("`@("`D97)R<W1R(#T@)R<["B`@("`@
M("`@:68@*"1O<'1I;VYS("8F(&9U;F-T:6]N7V5X:7-T<R@G<W1R96%M7V-O
M;G1E>'1?8W)E871E)RDI('L*("`@("`@("`@("`@:68@*"1T:&ES+3YT:6UE
M;W5T*2!["B`@("`@("`@("`@("`@("`D=&EM96]U="`]("1T:&ES+3YT:6UE
M;W5T.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1I
M;65O=70@/2`P.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1C;VYT97AT
M(#T@<W1R96%M7V-O;G1E>'1?8W)E871E*"1O<'1I;VYS*3L*("`@("`@("`@
M("`@)&9P(#T@0"1O<&5N9G5N8R@D=&AI<RT^861D<BP@)'1H:7,M/G!O<G0L
M("1E<G)N;RP@)&5R<G-T<BP@)'1I;65O=70L("1C;VYT97AT*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/G1I;65O=70I('L*
M("`@("`@("`@("`@("`@("1F<"`]($`D;W!E;F9U;F,H)'1H:7,M/F%D9'(L
M("1T:&ES+3YP;W)T+"`D97)R;F\L("1E<G)S='(L("1T:&ES+3YT:6UE;W5T
M*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1F<"`]
M($`D;W!E;F9U;F,H)'1H:7,M/F%D9'(L("1T:&ES+3YP;W)T+"`D97)R;F\L
M("1E<G)S='(I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I
M9B`H(21F<"D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H)&5R<G-T<BP@)&5R<FYO*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES
M+3YF<"`]("1F<#L*"B`@("`@("`@<F5T=7)N("1T:&ES+3YS971";&]C:VEN
M9R@D=&AI<RT^8FQO8VMI;F<I.PH@("`@?0H*("`@("\J*@H@("`@("H@1&ES
M8V]N;F5C=',@9G)O;2!T:&4@<&5E<BP@8VQO<V5S('1H92!S;V-K970N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@;6EX
M960@=')U92!O;B!S=6-C97-S(&]R(&%N(&5R<F]R(&]B:F5C="!O=&AE<G=I
M<V4*("`@("`J+PH@("`@9G5N8W1I;VX@9&ES8V]N;F5C="@I"B`@("!["B`@
M("`@("`@:68@*"%I<U]R97-O=7)C92@D=&AI<RT^9G`I*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G;F]T(&-O;FYE8W1E9"<I
M.PH@("`@("`@('T*"B`@("`@("`@0&9C;&]S92@D=&AI<RT^9G`I.PH@("`@
M("`@("1T:&ES+3YF<"`](&YU;&P["B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!&:6YD(&]U="!I9B!T:&4@<V]C:V5T(&ES
M(&EN(&)L;V-K:6YG(&UO9&4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J($!R971U<FX@8F]O;&5A;B`@5&AE(&-U<G)E;G0@8FQO8VMI
M;F<@;6]D92X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-";&]C:VEN9R@I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YB;&]C:VEN9SL*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E=',@=VAE=&AE<B!T:&4@<V]C:V5T(&-O;FYE8W1I
M;VX@<VAO=6QD(&)E(&)L;V-K:6YG(&]R"B`@("`@*B!N;W0N($$@<F5A9"!C
M86QL('1O(&$@;F]N+6)L;V-K:6YG('-O8VME="!W:6QL(')E='5R;B!I;6UE
M9&EA=&5L>0H@("`@("H@:68@=&AE<F4@:7,@;F\@9&%T82!A=F%I;&%B;&4L
M('=H97)E87,@:70@=VEL;"!B;&]C:R!U;G1I;"!T:&5R90H@("`@("H@:7,@
M9&%T82!F;W(@8FQO8VMI;F<@<V]C:V5T<RX*("`@("`J"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D;6]D92`@5')U92!F;W(@8FQO8VMI;F<@<V]C:V5T<RP@
M9F%L<V4@9F]R(&YO;F)L;V-K:6YG+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J($!R971U<FX@;6EX960@=')U92!O;B!S=6-C97-S(&]R(&%N(&5R
M<F]R(&]B:F5C="!O=&AE<G=I<V4*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T
M0FQO8VMI;F<H)&UO9&4I"B`@("!["B`@("`@("`@:68@*"%I<U]R97-O=7)C
M92@D=&AI<RT^9G`I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@G;F]T(&-O;FYE8W1E9"<I.PH@("`@("`@('T*"B`@("`@("`@
M)'1H:7,M/F)L;V-K:6YG(#T@)&UO9&4["B`@("`@("`@<V]C:V5T7W-E=%]B
M;&]C:VEN9R@D=&AI<RT^9G`L("1T:&ES+3YB;&]C:VEN9RD["B`@("`@("`@
M<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!T
M:6UE;W5T('9A;'5E(&]N('-O8VME="!D97-C<FEP=&]R+`H@("`@("H@97AP
M<F5S<V5D(&EN('1H92!S=6T@;V8@<V5C;VYD<R!A;F0@;6EC<F]S96-O;F1S
M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'-E8V]N9',@(%-E8V]N
M9',N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;6EC<F]S96-O;F1S("!-:6-R
M;W-E8V]N9',N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R
M;B!M:7AE9"!T<G5E(&]N('-U8V-E<W,@;W(@86X@97)R;W(@;V)J96-T(&]T
M:&5R=VES90H@("`@("HO"B`@("!F=6YC=&EO;B!S9714:6UE;W5T*"1S96-O
M;F1S+"`D;6EC<F]S96-O;F1S*0H@("`@>PH@("`@("`@(&EF("@A:7-?<F5S
M;W5R8V4H)'1H:7,M/F9P*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H)VYO="!C;VYN96-T960G*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!S;V-K971?<V5T7W1I;65O=70H)'1H:7,M/F9P+"`D<V5C
M;VYD<RP@)&UI8W)O<V5C;VYD<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS(&EN9F]R;6%T:6]N(&%B;W5T(&%N(&5X:7-T:6YG('-O8VME="!R
M97-O=7)C92X*("`@("`J($-U<G)E;G1L>2!R971U<FYS(&9O=7(@96YT<FEE
M<R!I;B!T:&4@<F5S=6QT(&%R<F%Y.@H@("`@("H*("`@("`J(#QP/@H@("`@
M("H@=&EM961?;W5T("AB;V]L*2`M(%1H92!S;V-K970@=&EM960@;W5T('=A
M:71I;F<@9F]R(&1A=&$\8G(^"B`@("`@*B!B;&]C:V5D("AB;V]L*2`M(%1H
M92!S;V-K970@=V%S(&)L;V-K960\8G(^"B`@("`@*B!E;V8@*&)O;VPI("T@
M26YD:6-A=&5S($5/1B!E=F5N=#QB<CX*("`@("`J('5N<F5A9%]B>71E<R`H
M:6YT*2`M($YU;6)E<B!O9B!B>71E<R!L969T(&EN('1H92!S;V-K970@8G5F
M9F5R/&)R/@H@("`@("H@/"]P/@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B!`<F5T=7)N(&UI>&5D($%R<F%Y(&-O;G1A:6YI;F<@:6YF
M;W)M871I;VX@86)O=70@97AI<W1I;F<@<V]C:V5T(')E<V]U<F-E(&]R(&%N
M(&5R<F]R(&]B:F5C="!O=&AE<G=I<V4*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T4W1A='5S*"D*("`@('L*("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1T
M:&ES+3YF<"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*"=N;W0@8V]N;F5C=&5D)RD["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@<V]C:V5T7V=E=%]S=&%T=7,H)'1H:7,M/F9P*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($=E="!A('-P96-I9FEE9"!L:6YE(&]F(&1A=&$*("`@("`J
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B`D<VEZ92!B
M>71E<R!O9B!D871A(&9R;VT@=&AE('-O8VME="P@;W(@82!014%27T5R<F]R
M(&EF"B`@("`@*B`@("`@("`@(&YO="!C;VYN96-T960N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=',H)'-I>F4I"B`@("!["B`@("`@("`@:68@*"%I<U]R
M97-O=7)C92@D=&AI<RT^9G`I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@G;F]T(&-O;FYE8W1E9"<I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N($!F9V5T<R@D=&AI<RT^9G`L("1S:7IE*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E860@82!S<&5C:69I960@86UO=6YT(&]F(&1A
M=&$N(%1H:7,@:7,@9W5A<F%N=&5E9"!T;R!R971U<FXL"B`@("`@*B!A;F0@
M:&%S('1H92!A9&1E9"!B96YE9FET(&]F(&=E='1I;F<@979E<GET:&EN9R!I
M;B!O;F4@9G)E860H*0H@("`@("H@8VAU;FL[(&EF('EO=2!K;F]W('1H92!S
M:7IE(&]F('1H92!D871A('EO=2=R92!G971T:6YG"B`@("`@*B!B969O<F5H
M86YD+"!T:&ES(&ES(&1E9FEN:71E;'D@=&AE('=A>2!T;R!G;RX*("`@("`J
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<VEZ92`@5&AE(&YU;6)E<B!O9B!B
M>71E<R!T;R!R96%D(&9R;VT@=&AE('-O8VME="X*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B!`<F5T=7)N("1S:7IE(&)Y=&5S(&]F(&1A=&$@9G)O
M;2!T:&4@<V]C:V5T+"!O<B!A(%!%05)?17)R;W(@:68*("`@("`J("`@("`@
M("`@;F]T(&-O;FYE8W1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A9"@D
M<VEZ92D*("`@('L*("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1T:&ES+3YF
M<"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=N
M;W0@8V]N;F5C=&5D)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@0&9R
M96%D*"1T:&ES+3YF<"P@)'-I>F4I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M5W)I=&4@82!S<&5C:69I960@86UO=6YT(&]F(&1A=&$N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@)&1A=&$@("`@("`@1&%T82!T;R!W<FET92X*
M("`@("`J($!P87)A;2!I;G1E9V5R("1B;&]C:W-I>F4@($%M;W5N="!O9B!D
M871A('1O('=R:71E(&%T(&]N8V4N"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!.54Q,(&UE86YS(&%L;"!A="!O;F-E+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N(&UI>&5D('1R=64@
M;VX@<W5C8V5S<R!O<B!A;B!E<G)O<B!O8FIE8W0@;W1H97)W:7-E"B`@("`@
M*B\*("`@(&9U;F-T:6]N('=R:71E*"1D871A+"`D8FQO8VMS:7IE(#T@;G5L
M;"D*("`@('L*("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1T:&ES+3YF<"DI
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=N;W0@
M8V]N;F5C=&5D)RD["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?;G5L;"@D
M8FQO8VMS:7IE*2`F)B`A3U-?5TE.1$]74RD@>PH@("`@("`@("`@("!R971U
M<FX@9G=R:71E*"1T:&ES+3YF<"P@)&1A=&$I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(&EF("AI<U]N=6QL*"1B;&]C:W-I>F4I*2!["B`@("`@
M("`@("`@("`@("`D8FQO8VMS:7IE(#T@,3`R-#L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@)'!O<R`](#`["B`@("`@("`@("`@("1S:7IE(#T@<W1R
M;&5N*"1D871A*3L*("`@("`@("`@("`@=VAI;&4@*"1P;W,@/"`D<VEZ92D@
M>PH@("`@("`@("`@("`@("`@)'=R:71T96X@/2!`9G=R:71E*"1T:&ES+3YF
M<"P@<W5B<W1R*"1D871A+"`D<&]S+"`D8FQO8VMS:7IE*2D["B`@("`@("`@
M("`@("`@("!I9B`H)'=R:71T96X@/3T](&9A;'-E*2!["B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@)'!O<R`K/2`D=W)I='1E;CL*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@<F5T=7)N("1P;W,["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@5W)I=&4@82!L:6YE(&]F(&1A=&$@=&\@=&AE('-O8VME
M="P@9F]L;&]W960@8GD@82!T<F%I;&EN9R`B7')<;B(N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@;6EX960@9G!U=',@
M<F5S=6QT+"!O<B!A;B!E<G)O<@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET
M94QI;F4H)&1A=&$I"B`@("!["B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D
M=&AI<RT^9G`I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@G;F]T(&-O;FYE8W1E9"<I.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N(&9W<FET92@D=&AI<RT^9G`L("1D871A("X@(EQR7&XB*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%1E<W1S(&9O<B!E;F0M;V8M9FEL92!O;B!A('-O
M8VME="!D97-C<FEP=&]R+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B!`<F5T=7)N(&)O;VP*("`@("`J+PH@("`@9G5N8W1I;VX@96]F
M*"D*("`@('L*("`@("`@("!R971U<FX@*&ES7W)E<V]U<F-E*"1T:&ES+3YF
M<"D@)B8@9F5O9B@D=&AI<RT^9G`I*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E861S(&$@8GET92!O9B!D871A"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J($!R971U<FX@,2!B>71E(&]F(&1A=&$@9G)O;2!T:&4@
M<V]C:V5T+"!O<B!A(%!%05)?17)R;W(@:68*("`@("`J("`@("`@("`@;F]T
M(&-O;FYE8W1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A9$)Y=&4H*0H@
M("`@>PH@("`@("`@(&EF("@A:7-?<F5S;W5R8V4H)'1H:7,M/F9P*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)VYO="!C;VYN
M96-T960G*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!O<F0H0&9R96%D
M*"1T:&ES+3YF<"P@,2DI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5A9',@
M82!W;W)D(&]F(&1A=&$*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("H@0')E='5R;B`Q('=O<F0@;V8@9&%T82!F<F]M('1H92!S;V-K970L
M(&]R(&$@4$5!4E]%<G)O<B!I9@H@("`@("H@("`@("`@("!N;W0@8V]N;F5C
M=&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96%D5V]R9"@I"B`@("!["B`@
M("`@("`@:68@*"%I<U]R97-O=7)C92@D=&AI<RT^9G`I*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G;F]T(&-O;FYE8W1E9"<I
M.PH@("`@("`@('T*"B`@("`@("`@)&)U9B`]($!F<F5A9"@D=&AI<RT^9G`L
M(#(I.PH@("`@("`@(')E='5R;B`H;W)D*"1B=69;,%TI("L@*&]R9"@D8G5F
M6S%=*2`\/"`X*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296%D<R!A;B!I
M;G0@;V8@9&%T80H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B!`<F5T=7)N(&EN=&5G97(@(#$@:6YT(&]F(&1A=&$@9G)O;2!T:&4@<V]C
M:V5T+"!O<B!A(%!%05)?17)R;W(@:68*("`@("`J("`@("`@("`@("`@("`@
M("`@;F]T(&-O;FYE8W1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A9$EN
M="@I"B`@("!["B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D=&AI<RT^9G`I
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G;F]T
M(&-O;FYE8W1E9"<I.PH@("`@("`@('T*"B`@("`@("`@)&)U9B`]($!F<F5A
M9"@D=&AI<RT^9G`L(#0I.PH@("`@("`@(')E='5R;B`H;W)D*"1B=69;,%TI
M("L@*&]R9"@D8G5F6S%=*2`\/"`X*2`K"B`@("`@("`@("`@("`@("`H;W)D
M*"1B=69;,ETI(#P\(#$V*2`K("AO<F0H)&)U9ELS72D@/#P@,C0I*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E861S(&$@>F5R;RUT97)M:6YA=&5D('-T
M<FEN9R!O9B!D871A"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J($!R971U<FX@<W1R:6YG+"!O<B!A(%!%05)?17)R;W(@:68*("`@("`J
M("`@("`@("`@;F]T(&-O;FYE8W1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<F5A9%-T<FEN9R@I"B`@("!["B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D
M=&AI<RT^9G`I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@G;F]T(&-O;FYE8W1E9"<I.PH@("`@("`@('T*"B`@("`@("`@)'-T
M<FEN9R`]("<G.PH@("`@("`@('=H:6QE("@H)&-H87(@/2!`9G)E860H)'1H
M:7,M/F9P+"`Q*2D@(3T@(EQX,#`B*2`@>PH@("`@("`@("`@("`D<W1R:6YG
M("X]("1C:&%R.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'-T<FEN9SL*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E861S(&%N($E0($%D9')E<W,@86YD
M(')E='5R;G,@:70@:6X@82!D;W0@9F]R;6%T960@<W1R:6YG"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@1&]T(&9O<FUA
M=&5D('-T<FEN9RP@;W(@82!014%27T5R<F]R(&EF"B`@("`@*B`@("`@("`@
M(&YO="!C;VYN96-T960N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E861)4$%D
M9')E<W,H*0H@("`@>PH@("`@("`@(&EF("@A:7-?<F5S;W5R8V4H)'1H:7,M
M/F9P*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M)VYO="!C;VYN96-T960G*3L*("`@("`@("!]"@H@("`@("`@("1B=68@/2!`
M9G)E860H)'1H:7,M/F9P+"`T*3L*("`@("`@("!R971U<FX@<W!R:6YT9B@B
M)7,N)7,N)7,N)7,B+"!O<F0H)&)U9ELP72DL(&]R9"@D8G5F6S%=*2P*("`@
M("`@("`@("`@("`@("`@("`@("!O<F0H)&)U9ELR72DL(&]R9"@D8G5F6S-=
M*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296%D('5N=&EL(&5I=&AE<B!T
M:&4@96YD(&]F('1H92!S;V-K970@;W(@82!N97=L:6YE+"!W:&EC:&5V97(*
M("`@("`J(&-O;65S(&9I<G-T+B!3=')I<',@=&AE('1R86EL:6YG(&YE=VQI
M;F4@9G)O;2!T:&4@<F5T=7)N960@9&%T82X*("`@("`J"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("H@0')E='5R;B!!;&P@879A:6QA8FQE(&1A=&$@
M=7`@=&\@82!N97=L:6YE+"!W:71H;W5T('1H870*("`@("`J("`@("`@("`@
M;F5W;&EN92P@;W(@=6YT:6P@=&AE(&5N9"!O9B!T:&4@<V]C:V5T+"!O<B!A
M(%!%05)?17)R;W(@:68*("`@("`J("`@("`@("`@;F]T(&-O;FYE8W1E9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<F5A9$QI;F4H*0H@("`@>PH@("`@("`@
M(&EF("@A:7-?<F5S;W5R8V4H)'1H:7,M/F9P*2D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)VYO="!C;VYN96-T960G*3L*("`@
M("`@("!]"@H@("`@("`@("1L:6YE(#T@)R<["B`@("`@("`@)'1I;65O=70@
M/2!T:6UE*"D@*R`D=&AI<RT^=&EM96]U=#L*("`@("`@("!W:&EL92`H(69E
M;V8H)'1H:7,M/F9P*2`F)B`H(21T:&ES+3YT:6UE;W5T('Q\('1I;64H*2`\
M("1T:6UE;W5T*2D@>PH@("`@("`@("`@("`D;&EN92`N/2!`9F=E=',H)'1H
M:7,M/F9P+"`D=&AI<RT^;&EN94QE;F=T:"D["B`@("`@("`@("`@(&EF("AS
M=6)S='(H)&QI;F4L("TQ*2`]/2`B7&XB*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@<G1R:6TH)&QI;F4L(")<<EQN(BD["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("1L:6YE.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5A9"!U;G1I;"!T:&4@<V]C:V5T(&-L;W-E<RP@;W(@=6YT:6P@
M=&AE<F4@:7,@;F\@;6]R92!D871A(&EN"B`@("`@*B!T:&4@:6YN97(@4$A0
M(&)U9F9E<BX@268@=&AE(&EN;F5R(&)U9F9E<B!I<R!E;7!T>2P@:6X@8FQO
M8VMI;F<*("`@("`J(&UO9&4@=V4@=V%I="!F;W(@870@;&5A<W0@,2!B>71E
M(&]F(&1A=&$N(%1H97)E9F]R92P@:6X*("`@("`J(&)L;V-K:6YG(&UO9&4L
M(&EF('1H97)E(&ES(&YO(&1A=&$@870@86QL('1O(&)E(')E860L('1H:7,*
M("`@("`J(&9U;F-T:6]N('=I;&P@;F5V97(@97AI="`H=6YL97-S('1H92!S
M;V-K970@:7,@8VQO<V5D(&]N('1H90H@("`@("H@<F5M;W1E(&5N9"DN"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@06QL(&1A=&$@=6YT:6P@=&AE('-O8VME="!C;&]S97,L
M(&]R(&$@4$5!4E]%<G)O<B!I9@H@("`@("H@("`@("`@("`@("`@("`@(&YO
M="!C;VYN96-T960N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E861!;&PH*0H@
M("`@>PH@("`@("`@(&EF("@A:7-?<F5S;W5R8V4H)'1H:7,M/F9P*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)VYO="!C;VYN
M96-T960G*3L*("`@("`@("!]"@H@("`@("`@("1D871A(#T@)R<["B`@("`@
M("`@=VAI;&4@*"%F96]F*"1T:&ES+3YF<"DI('L*("`@("`@("`@("`@)&1A
M=&$@+CT@0&9R96%D*"1T:&ES+3YF<"P@)'1H:7,M/FQI;F5,96YG=&@I.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)&1A=&$["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2=6YS('1H92!E<75I=F%L96YT(&]F('1H92!S96QE8W0H*2!S
M>7-T96T@8V%L;"!O;B!T:&4@<V]C:V5T"B`@("`@*B!W:71H(&$@=&EM96]U
M="!S<&5C:69I960@8GD@='9?<V5C(&%N9"!T=E]U<V5C+@H@("`@("H*("`@
M("`J($!P87)A;2!I;G1E9V5R("1S=&%T92`@("!7:&EC:"!O9B!R96%D+W=R
M:71E+V5R<F]R('1O(&-H96-K(&9O<BX*("`@("`J($!P87)A;2!I;G1E9V5R
M("1T=E]S96,@("!.=6UB97(@;V8@<V5C;VYD<R!F;W(@=&EM96]U="X*("`@
M("`J($!P87)A;2!I;G1E9V5R("1T=E]U<V5C("!.=6UB97(@;V8@;6EC<F]S
M96-O;F1S(&9O<B!T:6UE;W5T+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B!`<F5T=7)N($9A;'-E(&EF('-E;&5C="!F86EL<RP@:6YT
M96=E<B!D97-C<FEB:6YG('=H:6-H(&]F(')E860O=W)I=&4O97)R;W(*("`@
M("`J("`@("`@("`@87)E(')E861Y+"!O<B!014%27T5R<F]R(&EF(&YO="!C
M;VYN96-T960N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E;&5C="@D<W1A=&4L
M("1T=E]S96,L("1T=E]U<V5C(#T@,"D*("`@('L*("`@("`@("!I9B`H(6ES
M7W)E<V]U<F-E*"1T:&ES+3YF<"DI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*"=N;W0@8V]N;F5C=&5D)RD["B`@("`@("`@?0H*
M("`@("`@("`D<F5A9"`](&YU;&P["B`@("`@("`@)'=R:71E(#T@;G5L;#L*
M("`@("`@("`D97AC97!T(#T@;G5L;#L*("`@("`@("!I9B`H)'-T871E("8@
M3D547U-/0TM%5%]214%$*2!["B`@("`@("`@("`@("1R96%D6UT@/2`D=&AI
M<RT^9G`["B`@("`@("`@?0H@("`@("`@(&EF("@D<W1A=&4@)B!.151?4T]#
M2T547U=2251%*2!["B`@("`@("`@("`@("1W<FET95M=(#T@)'1H:7,M/F9P
M.PH@("`@("`@('T*("`@("`@("!I9B`H)'-T871E("8@3D547U-/0TM%5%]%
M4E)/4BD@>PH@("`@("`@("`@("`D97AC97!T6UT@/2`D=&AI<RT^9G`["B`@
M("`@("`@?0H@("`@("`@(&EF("AF86QS92`]/3T@*"1S<B`]('-T<F5A;5]S
M96QE8W0H)')E860L("1W<FET92P@)&5X8V5P="P@)'1V7W-E8RP@)'1V7W5S
M96,I*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*
M("`@("`@("`D<F5S=6QT(#T@,#L*("`@("`@("!I9B`H8V]U;G0H)')E860I
M*2!["B`@("`@("`@("`@("1R97-U;'0@?#T@3D547U-/0TM%5%]214%$.PH@
M("`@("`@('T*("`@("`@("!I9B`H8V]U;G0H)'=R:71E*2D@>PH@("`@("`@
M("`@("`D<F5S=6QT('P]($Y%5%]33T-+151?5U))5$4["B`@("`@("`@?0H@
M("`@("`@(&EF("AC;W5N="@D97AC97!T*2D@>PH@("`@("`@("`@("`D<F5S
M=6QT('P]($Y%5%]33T-+151?15)23U(["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@?0H*?0H```!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+TYE="]33510+G!H<```````````````````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P-S0R,C4@,3`U,34T,S,W,S,@,#(P-3(R
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!S;V9T=&%B<W1O<#TT('1A8G-T
M;W`]-"!S:&EF='=I9'1H/30Z("HO"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q
M.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R
M(&]F('1H92!02%`@;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B=6YD
M;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N
M9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I
M9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A
M<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@
M('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@
M8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z($-H=6-K($AA9V5N
M8G5C:"`\8VAU8VM`:&]R9&4N;W)G/B`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@?"`@("`@("`@("!*;VX@4&%R:7-E(#QJ;VY`<&AP+FYE=#X@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@
M("`@("`@1&%M:6%N($%L96IA;F1R;R!&97)N86YD97H@4V]S82`\9&%M;&ES
M='-`8VYB82YU8F$N87(^("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\*+R\@)$ED.B!33510+G!H<"QV(#$N-34@,C`P-B\P,B\P
M-B`P-CHP,#HR,B!J;VX@17AP("0*"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G
M.PIR97%U:7)E7V]N8V4@)TYE="]3;V-K970N<&AP)SL*"B\J*@H@*B!0<F]V
M:61E<R!A;B!I;7!L96UE;G1A=&EO;B!O9B!T:&4@4TU44"!P<F]T;V-O;"!U
M<VEN9R!014%2)W,*("H@3F5T7U-O8VME=#HZ(&-L87-S+@H@*@H@*B!`<&%C
M:V%G92!.971?4TU44`H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N0'!H
M<"YN970^"B`J($!A=71H;W(@($1A;6EA;B!!;&5J86YD<F\@1F5R;F%N9&5Z
M(%-O<V$@/&1A;6QI<W1S0&-N8F$N=6)A+F%R/@H@*@H@*B!`97AA;7!L92!B
M87-I8RYP:'`@("!!(&)A<VEC(&EM<&QE;65N=&%T:6]N(&]F('1H92!.971?
M4TU44"!P86-K86=E+@H@*B\*8VQA<W,@3F5T7U--5%`*>PH@("`@+RHJ"B`@
M("`@*B!4:&4@<V5R=F5R('1O(&-O;FYE8W0@=&\N"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@=F%R("1H
M;W-T(#T@)VQO8V%L:&]S="<["@H@("`@+RHJ"B`@("`@*B!4:&4@<&]R="!T
M;R!C;VYN96-T('1O+@H@("`@("H@0'9A<B!I;G0*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B\*("`@('9A<B`D<&]R="`](#(U.PH*("`@("\J*@H@
M("`@("H@5&AE('9A;'5E('1O(&=I=F4@=VAE;B!S96YD:6YG($5(3$\@;W(@
M2$5,3RX*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("HO"B`@("!V87(@)&QO8V%L:&]S="`]("=L;V-A;&AO<W0G.PH*
M("`@("\J*@H@("`@("H@3&ES="!O9B!S=7!P;W)T960@875T:&5N=&EC871I
M;VX@;65T:&]D<RP@:6X@<')E9F5R96YT:6%L(&]R9&5R+@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@=F%R
M("1A=71H7VUE=&AO9',@/2!A<G)A>2@G1$E'15-4+4U$-2<L("=#4D%-+4U$
M-2<L("=,3T=)3B<L("=03$%)3B<I.PH*("`@("\J*@H@("`@("H@4VAO=6QD
M(&1E8G5G9VEN9R!O=71P=70@8F4@96YA8FQE9#\*("`@("`J($!V87(@8F]O
M;&5A;@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D
M7V1E8G5G(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!4:&4@<V]C:V5T(')E
M<V]U<F-E(&)E:6YG('5S960@=&\@8V]N;F5C="!T;R!T:&4@4TU44"!S97)V
M97(N"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@=F%R("1?<V]C:V5T(#T@;G5L;#L*"B`@("`O*BH*
M("`@("`J(%1H92!M;W-T(')E8V5N="!S97)V97(@<F5S<&]N<V4@8V]D92X*
M("`@("`J($!V87(@:6YT"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M+PH@("`@=F%R("1?8V]D92`]("TQ.PH*("`@("\J*@H@("`@("H@5&AE(&UO
M<W0@<F5C96YT('-E<G9E<B!R97-P;VYS92!A<F=U;65N=',N"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@
M=F%R("1?87)G=6UE;G1S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%-T
M;W)E<R!D971E8W1E9"!F96%T=7)E<R!O9B!T:&4@4TU44"!S97)V97(N"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M+PH@("`@=F%R("1?97-M='`@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@
M26YS=&%N=&EA=&5S(&$@;F5W($YE=%]33510(&]B:F5C="P@;W9E<G)I9&EN
M9R!A;GD@9&5F875L=',*("`@("`J('=I=&@@<&%R86UE=&5R<R!T:&%T(&%R
M92!P87-S960@:6XN"B`@("`@*@H@("`@("H@268@>6]U(&AA=F4@4U-,('-U
M<'!O<G0@:6X@4$A0+"!Y;W4@8V%N(&-O;FYE8W0@=&\@82!S97)V97(*("`@
M("`J(&]V97(@4U-,('5S:6YG(&%N("=S<VPZ+R\G('!R969I>#H*("`@("`J
M"B`@("`@*B`@("\O(#0V-2!I<R!A(&-O;6UO;B!S;71P<R!P;W)T+@H@("`@
M("H@("`D<VUT<"`](&YE=R!.971?4TU44"@G<W-L.B\O;6%I;"YH;W-T+F-O
M;2<L(#0V-2D["B`@("`@*B`@("1S;71P+3YC;VYN96-T*"D["B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`@)&AO<W0@("`@("`@5&AE('-E<G9E<B!T
M;R!C;VYN96-T('1O+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'!O<G0@("`@
M("`@5&AE('!O<G0@=&\@8V]N;F5C="!T;RX*("`@("`J($!P87)A;2!S=')I
M;F<@("1L;V-A;&AO<W0@(%1H92!V86QU92!T;R!G:79E('=H96X@<V5N9&EN
M9R!%2$Q/(&]R($A%3$\N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC
M"B`@("`@*B!`<VEN8V4@("`Q+C`*("`@("`J+PH@("`@9G5N8W1I;VX@3F5T
M7U--5%`H)&AO<W0@/2!N=6QL+"`D<&]R="`](&YU;&PL("1L;V-A;&AO<W0@
M/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D:&]S="DI("1T:&ES
M+3YH;W-T(#T@)&AO<W0["B`@("`@("`@:68@*&ES<V5T*"1P;W)T*2D@)'1H
M:7,M/G!O<G0@/2`D<&]R=#L*("`@("`@("!I9B`H:7-S970H)&QO8V%L:&]S
M="DI("1T:&ES+3YL;V-A;&AO<W0@/2`D;&]C86QH;W-T.PH*("`@("`@("`D
M=&AI<RT^7W-O8VME="`]("9N97<@3F5T7U-O8VME="@I.PH*("`@("`@("`O
M*@H@("`@("`@("`J($EN8VQU9&4@=&AE($%U=&A?4T%33"!P86-K86=E+B`@
M268@=&AE('!A8VMA9V4@:7,@;F]T(&%V86EL86)L92P*("`@("`@("`@*B!W
M92!D:7-A8FQE('1H92!A=71H96YT:6-A=&EO;B!M971H;V1S('1H870@9&5P
M96YD('5P;VX@:70N"B`@("`@("`@("HO"B`@("`@("`@:68@*"A`:6YC;'5D
M95]O;F-E("=!=71H+U-!4TPN<&AP)RD@/3T](&9A;'-E*2!["B`@("`@("`@
M("`@("1P;W,@/2!A<G)A>5]S96%R8V@H)T1)1T535"U-1#4G+"`D=&AI<RT^
M875T:%]M971H;V1S*3L*("`@("`@("`@("`@=6YS970H)'1H:7,M/F%U=&A?
M;65T:&]D<ULD<&]S72D["B`@("`@("`@("`@("1P;W,@/2!A<G)A>5]S96%R
M8V@H)T-204TM340U)RP@)'1H:7,M/F%U=&A?;65T:&]D<RD["B`@("`@("`@
M("`@('5N<V5T*"1T:&ES+3YA=71H7VUE=&AO9'-;)'!O<UTI.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@=F%L=64@;V8@=&AE
M(&1E8G5G9VEN9R!F;&%G+@H@("`@("H*("`@("`J($!P87)A;2`@(&)O;VQE
M86X@)&1E8G5G("`@("`@3F5W('9A;'5E(&9O<B!T:&4@9&5B=6=G:6YG(&9L
M86<N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<VEN
M8V4@("`Q+C$N,`H@("`@("HO"B`@("!F=6YC=&EO;B!S971$96)U9R@D9&5B
M=6<I"B`@("!["B`@("`@("`@)'1H:7,M/E]D96)U9R`]("1D96)U9SL*("`@
M('T*"B`@("`O*BH*("`@("`J(%-E;F0@=&AE(&=I=F5N('-T<FEN9R!O9B!D
M871A('1O('1H92!S97)V97(N"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R
M:6YG("`D9&%T82`@("`@("!4:&4@<W1R:6YG(&]F(&1A=&$@=&\@<V5N9"X*
M("`@("`J"B`@("`@*B!`<F5T=7)N("!M:7AE9"`@(%1R=64@;VX@<W5C8V5S
M<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("H@0'-I;F-E("`@,2XQ+C`*
M("`@("`J+PH@("`@9G5N8W1I;VX@7W-E;F0H)&1A=&$I"B`@("!["B`@("`@
M("`@:68@*"1T:&ES+3Y?9&5B=6<I('L*("`@("`@("`@("`@96-H;R`B1$5"
M54<Z(%-E;F0Z("1D871A7&XB.PH@("`@("`@('T*"B`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]S;V-K970M/G=R:71E*"1D
M871A*2DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)T9A:6QE9"!T;R!W<FET92!T;R!S;V-K970Z("<@+@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D97)R;W(M/F=E=$UE<W-A9V4H*2D[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E;F0@82!C;VUM86YD('1O('1H92!S97)V97(@=VET:"!A
M;B!O<'1I;VYA;"!S=')I;F<@;V8*("`@("`J(&%R9W5M96YT<RX@($$@8V%R
M<FEA9V4@<F5T=7)N("\@;&EN969E960@*$-23$8I('-E<75E;F-E('=I;&P*
M("`@("`J(&)E(&%P<&5N9&5D('1O(&5A8V@@8V]M;6%N9"!S=')I;F<@8F5F
M;W)E(&ET(&ES('-E;G0@=&\@=&AE"B`@("`@*B!33510('-E<G9E<B`M(&%N
M(&5R<F]R('=I;&P@8F4@=&AR;W=N(&EF('1H92!C;VUM86YD('-T<FEN9PH@
M("`@("H@86QR96%D>2!C;VYT86EN<R!A;GD@;F5W;&EN92!C:&%R86-T97)S
M+B!5<V4@7W-E;F0H*2!F;W(*("`@("`J(&-O;6UA;F1S('1H870@;75S="!C
M;VYT86EN(&YE=VQI;F5S+@H@("`@("H*("`@("`J($!P87)A;2`@('-T<FEN
M9R`@)&-O;6UA;F0@("`@5&AE(%--5%`@8V]M;6%N9"!T;R!S96YD('1O('1H
M92!S97)V97(N"B`@("`@*B!`<&%R86T@("!S=')I;F<@("1A<F=S("`@("`@
M($$@<W1R:6YG(&]F(&]P=&EO;F%L(&%R9W5M96YT<R!T;R!A<'!E;F0*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&\@=&AE(&-O;6UA
M;F0N"B`@("`@*@H@("`@("H@0')E='5R;B`@;6EX960@("!4:&4@<F5S=6QT
M(&]F('1H92!?<V5N9"@I(&-A;&PN"B`@("`@*@H@("`@("H@0&%C8V5S<R`@
M<')I=F%T90H@("`@("H@0'-I;F-E("`@,2XQ+C`*("`@("`J+PH@("`@9G5N
M8W1I;VX@7W!U="@D8V]M;6%N9"P@)&%R9W,@/2`G)RD*("`@('L*("`@("`@
M("!I9B`H(65M<'1Y*"1A<F=S*2D@>PH@("`@("`@("`@("`D8V]M;6%N9"`N
M/2`G("<@+B`D87)G<SL*("`@("`@("!]"@H@("`@("`@(&EF("AS=')C<W!N
M*"1C;VUM86YD+"`B7')<;B(I("$]/2!S=')L96XH)&-O;6UA;F0I*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=#;VUM86YD<R!C
M86YN;W0@8V]N=&%I;B!N97=L:6YE<R<I.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?<V5N9"@D8V]M;6%N9"`N(")<<EQN(BD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!296%D(&$@<F5P;'D@9G)O;2!T:&4@4TU44"!S
M97)V97(N("!4:&4@<F5P;'D@8V]N<VES=',@;V8@82!R97-P;VYS90H@("`@
M("H@8V]D92!A;F0@82!R97-P;VYS92!M97-S86=E+@H@("`@("H*("`@("`J
M($!P87)A;2`@(&UI>&5D("`@)'9A;&ED("`@("`@5&AE('-E="!O9B!V86QI
M9"!R97-P;VYS92!C;V1E<RX@(%1H97-E"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&UA>2!B92!S<&5C:69I960@87,@86X@87)R87D@
M;V8@:6YT96=E<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!V86QU97,@;W(@87,@82!S:6YG;&4@:6YT96=E<B!V86QU92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N("!M:7AE9"`@(%1R=64@:68@=&AE('-E<G9E<B!R
M971U<FYE9"!A('9A;&ED(')E<W!O;G-E(&-O9&4@;W(*("`@("`J("`@("`@
M("`@("`@("`@("`@82!014%27T5R<F]R(&]B:F5C="!I<R!A;B!E<G)O<B!C
M;VYD:71I;VX@:7,@<F5A8VAE9"X*("`@("`J"B`@("`@*B!`86-C97-S("!P
M<FEV871E"B`@("`@*B!`<VEN8V4@("`Q+C$N,`H@("`@("H*("`@("`J($!S
M964@("`@(&=E=%)E<W!O;G-E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P87)S
M95)E<W!O;G-E*"1V86QI9"D*("`@('L*("`@("`@("`D=&AI<RT^7V-O9&4@
M/2`M,3L*("`@("`@("`D=&AI<RT^7V%R9W5M96YT<R`](&%R<F%Y*"D["@H@
M("`@("`@('=H:6QE("@D;&EN92`]("1T:&ES+3Y?<V]C:V5T+3YR96%D3&EN
M92@I*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^7V1E8G5G*2!["B`@("`@
M("`@("`@("`@("!E8VAO(")$14)51SH@4F5C=CH@)&QI;F5<;B(["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("\J($EF('=E(')E8V5I=F4@86X@96UP
M='D@;&EN92P@=&AE(&-O;FYE8W1I;VX@:&%S(&)E96X@8VQO<V5D+B`J+PH@
M("`@("`@("`@("!I9B`H96UP='DH)&QI;F4I*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^9&ES8V]N;F5C="@I.PH@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H)T-O;FYE8W1I;VX@=V%S('5N97AP96-T961L
M>2!C;&]S960G*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@4F5A
M9"!T:&4@8V]D92!A;F0@<W1O<F4@=&AE(')E<W0@:6X@=&AE(&%R9W5M96YT
M<R!A<G)A>2X@*B\*("`@("`@("`@("`@)&-O9&4@/2!S=6)S='(H)&QI;F4L
M(#`L(#,I.PH@("`@("`@("`@("`D=&AI<RT^7V%R9W5M96YT<UM=(#T@=')I
M;2AS=6)S='(H)&QI;F4L(#0I*3L*"B`@("`@("`@("`@("\J($-H96-K('1H
M92!S>6YT87@@;V8@=&AE(')E<W!O;G-E(&-O9&4N("HO"B`@("`@("`@("`@
M(&EF("AI<U]N=6UE<FEC*"1C;V1E*2D@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]C;V1E(#T@*&EN="DD8V]D93L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]D92`]("TQ.PH@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($EF
M('1H:7,@:7,@;F]T(&$@;75L=&EL:6YE(')E<W!O;G-E+"!W92=R92!D;VYE
M+B`J+PH@("`@("`@("`@("!I9B`H<W5B<W1R*"1L:6YE+"`S+"`Q*2`A/2`G
M+2<I('L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`O*B!#;VUP87)E('1H92!S97)V97(G<R!R97-P
M;VYS92!C;V1E('=I=&@@=&AE('9A;&ED(&-O9&4N("HO"B`@("`@("`@:68@
M*&ES7VEN="@D=F%L:60I("8F("@D=&AI<RT^7V-O9&4@/3T]("1V86QI9"DI
M('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@
M("`O*B!)9B!W92!W97)E(&=I=F5N(&%N(&%R<F%Y(&]F('9A;&ED(')E<W!O
M;G-E(&-O9&5S+"!C:&5C:R!E86-H(&]N92X@*B\*("`@("`@("!I9B`H:7-?
M87)R87DH)'9A;&ED*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D=F%L:60@
M87,@)'9A;&ED7V-O9&4I('L*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^
M7V-O9&4@/3T]("1V86QI9%]C;V1E*2!["B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=)
M;G9A;&ED(')E<W!O;G-E(&-O9&4@<F5C96EV960@9G)O;2!S97)V97(G*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!A(#(M='5P;&4@8V]N=&%I
M;FEN9R!T:&4@;&%S="!R97-P;VYS92!F<F]M('1H92!33510('-E<G9E<BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N("!A<G)A>2`@($$@='=O+65L96UE;G0@
M87)R87DZ('1H92!F:7)S="!E;&5M96YT(&-O;G1A:6YS('1H90H@("`@("H@
M("`@("`@("`@("`@("`@("!R97-P;VYS92!C;V1E(&%S(&%N(&EN=&5G97(@
M86YD('1H92!S96-O;F0@96QE;65N=`H@("`@("H@("`@("`@("`@("`@("`@
M("!C;VYT86EN<R!T:&4@<F5S<&]N<V4G<R!A<F=U;65N=',@87,@82!S=')I
M;F<N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<VEN
M8V4@("`Q+C$N,`H@("`@("HO"B`@("!F=6YC=&EO;B!G971297-P;VYS92@I
M"B`@("!["B`@("`@("`@<F5T=7)N(&%R<F%Y*"1T:&ES+3Y?8V]D92P@:F]I
M;B@B7&XB+"`D=&AI<RT^7V%R9W5M96YT<RDI.PH@("`@?0H*("`@("\J*@H@
M("`@("H@071T96UP="!T;R!C;VYN96-T('1O('1H92!33510('-E<G9E<BX*
M("`@("`J"B`@("`@*B!`<&%R86T@("!I;G0@("`@("1T:6UE;W5T("`@(%1H
M92!T:6UE;W5T('9A;'5E("AI;B!S96-O;F1S*2!F;W(@=&AE"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('-O8VME="!C;VYN96-T:6]N
M+@H@("`@("H@0'!A<F%M("`@8F]O;"`@("`D<&5R<VES=&5N="!3:&]U;&0@
M82!P97)S:7-T96YT('-O8VME="!C;VYN96-T:6]N"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&)E('5S960_"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"!2971U<FYS(&$@4$5!4E]%<G)O<B!W:71H(&%N(&5R
M<F]R(&UE<W-A9V4@;VX@86YY"B`@("`@*B`@("`@("`@("`@("`@(&MI;F0@
M;V8@9F%I;'5R92P@;W(@=')U92!O;B!S=6-C97-S+@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J($!S:6YC92`@,2XP"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&-O;FYE8W0H)'1I;65O=70@/2!N=6QL+"`D<&5R<VES=&5N="`](&9A
M;'-E*0H@("`@>PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7W-O8VME="T^
M8V]N;F5C="@D=&AI<RT^:&]S="P@)'1H:7,M/G!O<G0L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P97)S:7-T96YT+"`D
M=&EM96]U="D["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<W5L="DI
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T9A:6QE
M9"!T;R!C;VYN96-T('-O8VME=#H@)R`N"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1R97-U;'0M/F=E=$UE<W-A9V4H*2D["B`@("`@
M("`@?0H*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI
M<RT^7W!A<G-E4F5S<&]N<V4H,C(P*2DI('L*("`@("`@("`@("`@<F5T=7)N
M("1E<G)O<CL*("`@("`@("!]"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)&5R<F]R(#T@)'1H:7,M/E]N96=O=&EA=&4H*2DI('L*("`@("`@("`@("`@
M<F5T=7)N("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP="!T;R!D:7-C;VYN96-T
M(&9R;VT@=&AE(%--5%`@<V5R=F5R+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@4F5T=7)N<R!A(%!%05)?17)R;W(@=VET:"!A;B!E<G)O<B!M97-S
M86=E(&]N(&%N>0H@("`@("H@("`@("`@("`@("`@("!K:6YD(&]F(&9A:6QU
M<F4L(&]R('1R=64@;VX@<W5C8V5S<RX*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B!`<VEN8V4@(#$N,`H@("`@("HO"B`@("!F=6YC=&EO;B!D:7-C
M;VYN96-T*"D*("`@('L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R
M;W(@/2`D=&AI<RT^7W!U="@G455)5"<I*2D@>PH@("`@("`@("`@("!R971U
M<FX@)&5R<F]R.PH@("`@("`@('T*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D97)R;W(@/2`D=&AI<RT^7W!A<G-E4F5S<&]N<V4H,C(Q*2DI('L*("`@
M("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]S;V-K970M/F1I<V-O
M;FYE8W0H*2DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H)T9A:6QE9"!T;R!D:7-C;VYN96-T('-O8VME=#H@)R`N"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E<G)O<BT^9V5T365S<V%G
M92@I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@071T96UP="!T;R!S96YD('1H92!%2$Q/(&-O;6UA
M;F0@86YD(&]B=&%I;B!A(&QI<W0@;V8@15--5%`*("`@("`J(&5X=&5N<VEO
M;G,@879A:6QA8FQE+"!A;F0@9F%I;&EN9R!T:&%T(&IU<W0@<V5N9"!(14Q/
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@4F5T=7)N<R!A(%!%05)?
M17)R;W(@=VET:"!A;B!E<G)O<B!M97-S86=E(&]N(&%N>0H@("`@("H@("`@
M("`@("`@("`@("!K:6YD(&]F(&9A:6QU<F4L(&]R('1R=64@;VX@<W5C8V5S
M<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!S:6YC
M92`@,2XQ+C`*("`@("`J+PH@("`@9G5N8W1I;VX@7VYE9V]T:6%T92@I"B`@
M("!["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M
M/E]P=70H)T5(3$\G+"`D=&AI<RT^;&]C86QH;W-T*2DI('L*("`@("`@("`@
M("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1T:&ES+3Y?<&%R<V5297-P;VYS92@R-3`I*2D@>PH@("`@
M("`@("`@("`O*B!)9B!W92!R96-E:79E(&$@-3`S(')E<W!O;G-E+"!W92=R
M92!A;')E861Y(&%U=&AE;G1I8V%T960N("HO"B`@("`@("`@("`@(&EF("@D
M=&AI<RT^7V-O9&4@/3T](#4P,RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M('1R=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($EF('1H92!%
M2$Q/(&9A:6QE9"P@=')Y('1H92!S:6UP;&5R($A%3$\@8V]M;6%N9"X@*B\*
M("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M
M/E]P=70H)TA%3$\G+"`D=&AI<RT^;&]C86QH;W-T*2DI('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)'1H:7,M/E]P87)S95)E<W!O;G-E*#(U
M,"DI*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@G2$5,3R!W87,@;F]T(&%C8V5P=&5D.B`G+"`D=&AI<RT^7V-O9&4I.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@
M("!]"@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?87)G=6UE;G1S(&%S("1A
M<F=U;65N="D@>PH@("`@("`@("`@("`D=F5R8B`]('-T<G1O:R@D87)G=6UE
M;G0L("<@)RD["B`@("`@("`@("`@("1A<F=U;65N=',@/2!S=6)S='(H)&%R
M9W5M96YT+"!S=')L96XH)'9E<F(I("L@,2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!S=')L96XH)&%R9W5M96YT*2`M('-T<FQE;B@D=F5R
M8BD@+2`Q*3L*("`@("`@("`@("`@)'1H:7,M/E]E<VUT<%LD=F5R8ET@/2`D
M87)G=6UE;G1S.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!N86UE(&]F('1H92!B
M97-T(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"!T:&%T('1H92!S97)V97(*("`@
M("`J(&AA<R!A9'9E<G1I<V5D+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@("`@4F5T=7)N<R!A('-T<FEN9R!C;VYT86EN:6YG('1H92!N86UE(&]F
M('1H92!B97-T"B`@("`@*B`@("`@("`@("`@("`@("`@('-U<'!O<G1E9"!A
M=71H96YT:6-A=&EO;B!M971H;V0@;W(@82!014%27T5R<F]R(&]B:F5C=`H@
M("`@("H@("`@("`@("`@("`@("`@("!I9B!A(&9A:6QU<F4@8V]N9&ET:6]N
M(&ES(&5N8V]U;G1E<F5D+@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*B!`<VEN8V4@(#$N,2XP"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971"97-T
M075T:$UE=&AO9"@I"B`@("!["B`@("`@("`@)&%V86EL86)L95]M971H;V1S
M(#T@97AP;&]D92@G("<L("1T:&ES+3Y?97-M='!;)T%55$@G72D["@H@("`@
M("`@(&9O<F5A8V@@*"1T:&ES+3YA=71H7VUE=&AO9',@87,@)&UE=&AO9"D@
M>PH@("`@("`@("`@("!I9B`H:6Y?87)R87DH)&UE=&AO9"P@)&%V86EL86)L
M95]M971H;V1S*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1M971H;V0[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*"=.;R!S=7!P;W)T960@875T:&5N=&EC871I;VX@;65T
M:&]D<R<I.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP="!T;R!D;R!3
M3510(&%U=&AE;G1I8V%T:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@5&AE('5S97)I9"!T;R!A=71H96YT:6-A=&4@87,N"B`@("`@*B!`<&%R
M86T@<W1R:6YG(%1H92!P87-S=V]R9"!T;R!A=71H96YT:6-A=&4@=VET:"X*
M("`@("`J($!P87)A;2!S=')I;F<@5&AE(')E<75E<W1E9"!A=71H96YT:6-A
M=&EO;B!M971H;V0N("!)9B!N;VYE(&ES"B`@("`@*B`@("`@("`@("`@("`@
M('-P96-I9FEE9"P@=&AE(&)E<W0@<W5P<&]R=&5D(&UE=&AO9"!W:6QL(&)E
M('5S960N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!2971U<FYS(&$@
M4$5!4E]%<G)O<B!W:71H(&%N(&5R<F]R(&UE<W-A9V4@;VX@86YY"B`@("`@
M*B`@("`@("`@("`@("`@(&MI;F0@;V8@9F%I;'5R92P@;W(@=')U92!O;B!S
M=6-C97-S+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S:6YC92`@
M,2XP"B`@("`@*B\*("`@(&9U;F-T:6]N(&%U=&@H)'5I9"P@)'!W9"`L("1M
M971H;V0@/2`G)RD*("`@('L*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]E
M<VUT<%LG05542"==*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@G4TU44"!S97)V97(@9&]E<R!N;R!S=7!P;W)T(&%U=&AE;G1I
M8V%T:6]N)RD["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!N;R!M971H;V0@
M:&%S(&)E96X@<W!E8VEF:65D+"!G970@=&AE(&YA;64@;V8@=&AE(&)E<W0*
M("`@("`@("`@*B!S=7!P;W)T960@;65T:&]D(&%D=F5R=&ES960@8GD@=&AE
M(%--5%`@<V5R=F5R+B`J+PH@("`@("`@(&EF("AE;7!T>2@D;65T:&]D*2D@
M>PH@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D;65T:&]D(#T@)'1H
M:7,M/E]G971"97-T075T:$UE=&AO9"@I*2D@>PH@("`@("`@("`@("`@("`@
M+RH@4F5T=7)N('1H92!014%27T5R<F]R(&]B:F5C="!F<F]M(%]G971"97-T
M075T:$UE=&AO9"@I+B`J+PH@("`@("`@("`@("`@("`@<F5T=7)N("1M971H
M;V0["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D;65T:&]D(#T@<W1R=&]U<'!E<B@D;65T:&]D*3L*("`@("`@("`@("`@
M:68@*"%I;E]A<G)A>2@D;65T:&]D+"`D=&AI<RT^875T:%]M971H;V1S*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(B1M
M971H;V0@:7,@;F]T(&$@<W5P<&]R=&5D(&%U=&AE;G1I8V%T:6]N(&UE=&AO
M9"(I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!S=VET8V@@
M*"1M971H;V0I('L*("`@("`@("`@("`@8V%S92`G1$E'15-4+4U$-2<Z"B`@
M("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]A=71H1&EG97-T7TU$
M-2@D=6ED+"`D<'=D*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("!C87-E("=#4D%-+4U$-2<Z"B`@("`@("`@("`@("`@("`D<F5S=6QT
M(#T@)'1H:7,M/E]A=71H0U)!35]-1#4H)'5I9"P@)'!W9"D["B`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G3$]'24XG.@H@("`@
M("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?875T:$QO9VEN*"1U:60L
M("1P=V0I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A
M<V4@)U!,04E.)SH*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^
M7V%U=&A0;&%I;B@D=6ED+"`D<'=D*3L*("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@)')E<W5L
M="`](%!%05(Z.G)A:7-E17)R;W(H(B1M971H;V0@:7,@;F]T(&$@<W5P<&]R
M=&5D(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"(I.PH@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!A;B!E<G)O<B!W87,@
M96YC;W5N=&5R960L(')E='5R;B!T:&4@4$5!4E]%<G)O<B!O8FIE8W0N("HO
M"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($%U=&AE;G1I8V%T97,@
M=&AE('5S97(@=7-I;F<@=&AE($1)1T535"U-1#4@;65T:&]D+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@5&AE('5S97)I9"!T;R!A=71H96YT:6-A
M=&4@87,N"B`@("`@*B!`<&%R86T@<W1R:6YG(%1H92!P87-S=V]R9"!T;R!A
M=71H96YT:6-A=&4@=VET:"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M(%)E='5R;G,@82!014%27T5R<F]R('=I=&@@86X@97)R;W(@;65S<V%G92!O
M;B!A;GD*("`@("`J("`@("`@("`@("`@("`@:VEN9"!O9B!F86EL=7)E+"!O
M<B!T<G5E(&]N('-U8V-E<W,N"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J($!S:6YC92`@,2XQ+C`*("`@("`J+PH@("`@9G5N8W1I;VX@7V%U=&A$
M:6=E<W1?340U*"1U:60L("1P=V0I"B`@("!["B`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P=70H)T%55$@G+"`G1$E'15-4
M+4U$-2<I*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@
M('T*("`@("`@("`O*B`S,S0Z($-O;G1I;G5E(&%U=&AE;G1I8V%T:6]N(')E
M<75E<W0@*B\*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D
M=&AI<RT^7W!A<G-E4F5S<&]N<V4H,S,T*2DI('L*("`@("`@("`@("`@+RH@
M-3`S.B!%<G)O<CH@86QR96%D>2!A=71H96YT:6-A=&5D("HO"B`@("`@("`@
M("`@(&EF("@D=&AI<RT^7V-O9&4@/3T](#4P,RD@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T
M=7)N("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@("1C:&%L;&5N9V4@/2!B
M87-E-C1?9&5C;V1E*"1T:&ES+3Y?87)G=6UE;G1S6S!=*3L*("`@("`@("`D
M9&EG97-T(#T@)D%U=&A?4T%33#HZ9F%C=&]R>2@G9&EG97-T;60U)RD["B`@
M("`@("`@)&%U=&A?<W1R(#T@8F%S938T7V5N8V]D92@D9&EG97-T+3YG9712
M97-P;VYS92@D=6ED+"`D<'=D+"`D8VAA;&QE;F=E+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/FAO<W0L(")S;71P(BDI.PH*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D97)R;W(@/2`D=&AI<RT^7W!U="@D875T:%]S='(I*2D@>PH@("`@("`@
M("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*("`@("`@("`O*B`S,S0Z
M($-O;G1I;G5E(&%U=&AE;G1I8V%T:6]N(')E<75E<W0@*B\*("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!A<G-E4F5S<&]N
M<V4H,S,T*2DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@
M("!]"@H@("`@("`@("\J(%=E(&1O;B=T('5S92!T:&4@<')O=&]C;VPG<R!T
M:&ER9"!S=&5P(&)E8V%U<V4@4TU44"!D;V5S;B=T"B`@("`@("`@("H@86QL
M;W<@<W5B<V5Q=65N="!A=71H96YT:6-A=&EO;BP@<V\@=V4@:G5S="!S:6QE
M;G1L>2!I9VYO<F4*("`@("`@("`@*B!I="X@*B\*("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!U="@G("<I*2D@>PH@("`@
M("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*("`@("`@("`O*B`R
M,S4Z($%U=&AE;G1I8V%T:6]N('-U8V-E<W-F=6P@*B\*("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!A<G-E4F5S<&]N<V4H
M,C,U*2DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!=71H96YT:6-A=&5S('1H92!U<V5R
M('5S:6YG('1H92!#4D%-+4U$-2!M971H;V0N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R!4:&4@=7-E<FED('1O(&%U=&AE;G1I8V%T92!A<RX*("`@
M("`J($!P87)A;2!S=')I;F<@5&AE('!A<W-W;W)D('1O(&%U=&AE;G1I8V%T
M92!W:71H+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@4F5T=7)N<R!A
M(%!%05)?17)R;W(@=VET:"!A;B!E<G)O<B!M97-S86=E(&]N(&%N>0H@("`@
M("H@("`@("`@("`@("`@("!K:6YD(&]F(&9A:6QU<F4L(&]R('1R=64@;VX@
M<W5C8V5S<RX*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'-I;F-E
M("`Q+C$N,`H@("`@("HO"B`@("!F=6YC=&EO;B!?875T:$-204U?340U*"1U
M:60L("1P=V0I"B`@("!["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R
M<F]R(#T@)'1H:7,M/E]P=70H)T%55$@G+"`G0U)!32U-1#4G*2DI('L*("`@
M("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"B`@("`@("`@+RH@
M,S,T.B!#;VYT:6YU92!A=71H96YT:6-A=&EO;B!R97%U97-T("HO"B`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P87)S95)E
M<W!O;G-E*#,S-"DI*2!["B`@("`@("`@("`@("\J(#4P,SH@17)R;W(Z(&%L
M<F5A9'D@875T:&5N=&EC871E9"`J+PH@("`@("`@("`@("!I9B`H)'1H:7,M
M/E]C;V1E(#T]/2`U,#,I('L*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@
M("`@("`@?0H*("`@("`@("`D8VAA;&QE;F=E(#T@8F%S938T7V1E8V]D92@D
M=&AI<RT^7V%R9W5M96YT<ULP72D["B`@("`@("`@)&-R86T@/2`F075T:%]3
M05-,.CIF86-T;W)Y*"=C<F%M;60U)RD["B`@("`@("`@)&%U=&A?<W1R(#T@
M8F%S938T7V5N8V]D92@D8W)A;2T^9V5T4F5S<&]N<V4H)'5I9"P@)'!W9"P@
M)&-H86QL96YG92DI.PH*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R
M;W(@/2`D=&AI<RT^7W!U="@D875T:%]S='(I*2D@>PH@("`@("`@("`@("!R
M971U<FX@)&5R<F]R.PH@("`@("`@('T*"B`@("`@("`@+RH@,C,U.B!!=71H
M96YT:6-A=&EO;B!S=6-C97-S9G5L("HO"B`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P87)S95)E<W!O;G-E*#(S-2DI*2![
M"B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@075T:&5N=&EC871E<R!T:&4@=7-E<B!U<VEN9R!T
M:&4@3$]'24X@;65T:&]D+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M5&AE('5S97)I9"!T;R!A=71H96YT:6-A=&4@87,N"B`@("`@*B!`<&%R86T@
M<W1R:6YG(%1H92!P87-S=V]R9"!T;R!A=71H96YT:6-A=&4@=VET:"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%)E='5R;G,@82!014%27T5R<F]R
M('=I=&@@86X@97)R;W(@;65S<V%G92!O;B!A;GD*("`@("`J("`@("`@("`@
M("`@("`@:VEN9"!O9B!F86EL=7)E+"!O<B!T<G5E(&]N('-U8V-E<W,N"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!S:6YC92`@,2XQ+C`*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V%U=&A,;V=I;B@D=6ED+"`D<'=D*0H@("`@
M>PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G)O<B`]("1T:&ES+3Y?
M<'5T*"=!551()RP@)TQ/1TE.)RDI*2!["B`@("`@("`@("`@(')E='5R;B`D
M97)R;W(["B`@("`@("`@?0H@("`@("`@("\J(#,S-#H@0V]N=&EN=64@875T
M:&5N=&EC871I;VX@<F5Q=65S="`J+PH@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1E<G)O<B`]("1T:&ES+3Y?<&%R<V5297-P;VYS92@S,S0I*2D@>PH@
M("`@("`@("`@("`O*B`U,#,Z($5R<F]R.B!A;')E861Y(&%U=&AE;G1I8V%T
M960@*B\*("`@("`@("`@("`@:68@*"1T:&ES+3Y?8V]D92`]/3T@-3`S*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*"B`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P=70H8F%S938T
M7V5N8V]D92@D=6ED*2DI*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W([
M"B`@("`@("`@?0H@("`@("`@("\J(#,S-#H@0V]N=&EN=64@875T:&5N=&EC
M871I;VX@<F5Q=65S="`J+PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E
M<G)O<B`]("1T:&ES+3Y?<&%R<V5297-P;VYS92@S,S0I*2D@>PH@("`@("`@
M("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*"B`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P=70H8F%S938T7V5N8V]D
M92@D<'=D*2DI*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@
M("`@?0H*("`@("`@("`O*B`R,S4Z($%U=&AE;G1I8V%T:6]N('-U8V-E<W-F
M=6P@*B\*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI
M<RT^7W!A<G-E4F5S<&]N<V4H,C,U*2DI('L*("`@("`@("`@("`@<F5T=7)N
M("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@075T:&5N=&EC871E<R!T:&4@=7-E<B!U<VEN
M9R!T:&4@4$Q!24X@;65T:&]D+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@5&AE('5S97)I9"!T;R!A=71H96YT:6-A=&4@87,N"B`@("`@*B!`<&%R
M86T@<W1R:6YG(%1H92!P87-S=V]R9"!T;R!A=71H96YT:6-A=&4@=VET:"X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%)E='5R;G,@82!014%27T5R
M<F]R('=I=&@@86X@97)R;W(@;65S<V%G92!O;B!A;GD*("`@("`J("`@("`@
M("`@("`@("`@:VEN9"!O9B!F86EL=7)E+"!O<B!T<G5E(&]N('-U8V-E<W,N
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!S:6YC92`@,2XQ+C`*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V%U=&A0;&%I;B@D=6ED+"`D<'=D*0H@
M("`@>PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G)O<B`]("1T:&ES
M+3Y?<'5T*"=!551()RP@)U!,04E.)RDI*2!["B`@("`@("`@("`@(')E='5R
M;B`D97)R;W(["B`@("`@("`@?0H@("`@("`@("\J(#,S-#H@0V]N=&EN=64@
M875T:&5N=&EC871I;VX@<F5Q=65S="`J+PH@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1E<G)O<B`]("1T:&ES+3Y?<&%R<V5297-P;VYS92@S,S0I*2D@
M>PH@("`@("`@("`@("`O*B`U,#,Z($5R<F]R.B!A;')E861Y(&%U=&AE;G1I
M8V%T960@*B\*("`@("`@("`@("`@:68@*"1T:&ES+3Y?8V]D92`]/3T@-3`S
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*"B`@("`@
M("`@)&%U=&A?<W1R(#T@8F%S938T7V5N8V]D92AC:'(H,"D@+B`D=6ED("X@
M8VAR*#`I("X@)'!W9"D["@H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E
M<G)O<B`]("1T:&ES+3Y?<'5T*"1A=71H7W-T<BDI*2!["B`@("`@("`@("`@
M(')E='5R;B`D97)R;W(["B`@("`@("`@?0H*("`@("`@("`O*B`R,S4Z($%U
M=&AE;G1I8V%T:6]N('-U8V-E<W-F=6P@*B\*("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!A<G-E4F5S<&]N<V4H,C,U*2DI
M('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5N9"!T
M:&4@2$5,3R!C;VUM86YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M5&AE(&1O;6%I;B!N86UE('1O('-A>2!W92!A<F4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"!2971U<FYS(&$@4$5!4E]%<G)O<B!W:71H(&%N(&5R
M<F]R(&UE<W-A9V4@;VX@86YY"B`@("`@*B`@("`@("`@("`@("`@(&MI;F0@
M;V8@9F%I;'5R92P@;W(@=')U92!O;B!S=6-C97-S+@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J($!S:6YC92`@,2XP"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&AE;&\H)&1O;6%I;BD*("`@('L*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!U="@G2$5,3R<L("1D;VUA:6XI*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!A<G-E4F5S
M<&]N<V4H,C4P*2DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4V5N9"!T:&4@34%)3"!&4D]-.B!C;VUM86YD+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'-E;F1E<B`@("!4:&4@<V5N9&5R("AR979E
M<G-E('!A=&@I('1O('-E="X*("`@("`J($!P87)A;2!S=')I;F<@)'!A<F%M
M<R`@("!3=')I;F<@8V]N=&%I;FEN9R!A9&1I=&EO;F%L($U!24P@<&%R86UE
M=&5R<RP*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!S=6-H(&%S
M('1H92!.3U1)1ED@9FQA9W,@9&5F:6YE9"!B>2!21D,@,3@Y,0H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@(&]R('1H92!615)0('!R;W1O8V]L
M+@H@("`@("H*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!)9B`D
M<&%R86US(&ES(&%N(&%R<F%Y+"!O;FQY('1H92`G=F5R<"<@;W!T:6]N"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@:7,@<W5P<&]R=&5D+B`@
M268@)W9E<G`G(&ES('1R=64L('1H92!85D524`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@('!A<F%M971E<B!I<R!A<'!E;F1E9"!T;R!T:&4@
M34%)3"!C;VUM86YD+B`@268*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("!T:&4@)W9E<G`G('9A;'5E(&ES(&$@<W1R:6YG+"!T:&4@9G5L;`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(%A615)0/79A;'5E('!A
M<F%M971E<B!I<R!A<'!E;F1E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D(%)E='5R;G,@82!014%27T5R<F]R('=I=&@@86X@97)R;W(@;65S<V%G
M92!O;B!A;GD*("`@("`J("`@("`@("`@("`@("`@:VEN9"!O9B!F86EL=7)E
M+"!O<B!T<G5E(&]N('-U8V-E<W,N"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("H@0'-I;F-E("`Q+C`*("`@("`J+PH@("`@9G5N8W1I;VX@;6%I;$9R
M;VTH)'-E;F1E<BP@)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@)&%R
M9W,@/2`B1E)/33H\)'-E;F1E<CXB.PH*("`@("`@("`O*B!3=7!P;W)T('1H
M92!D97!R96-A=&5D(&%R<F%Y(&9O<FT@;V8@)'!A<F%M<RX@*B\*("`@("`@
M("!I9B`H:7-?87)R87DH)'!A<F%M<RD@)B8@:7-S970H)'!A<F%M<ULG=F5R
M<"==*2D@>PH@("`@("`@("`@("`O*B!85D524"`J+PH@("`@("`@("`@("!I
M9B`H)'!A<F%M<ULG=F5R<"==(#T]/2!T<G5E*2!["B`@("`@("`@("`@("`@
M("`D87)G<R`N/2`G(%A615)0)SL*"B`@("`@("`@("`@("\J(%A615)0/7-O
M;65T:&EN9R`J+PH@("`@("`@("`@("!](&5L<V5I9B`H=')I;2@D<&%R86US
M6R=V97)P)UTI*2!["B`@("`@("`@("`@("`@("`D87)G<R`N/2`G(%A615)0
M/2<@+B`D<&%R86US6R=V97)P)UT["B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V5I9B`H:7-?<W1R:6YG*"1P87)A;7,I*2!["B`@("`@("`@("`@("1A
M<F=S("X]("<@)R`N("1P87)A;7,["B`@("`@("`@?0H*("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!U="@G34%)3"<L("1A
M<F=S*2DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]
M"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P
M87)S95)E<W!O;G-E*#(U,"DI*2!["B`@("`@("`@("`@(')E='5R;B`D97)R
M;W(["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E;F0@=&AE(%)#4%0@5$\Z(&-O;6UA;F0N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<F5C:7!I96YT(%1H92!R96-I<&EE
M;G0@*&9O<G=A<F0@<&%T:"D@=&\@861D+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<&%R86US("`@(%-T<FEN9R!C;VYT86EN:6YG(&%D9&ET:6]N86P@4D-0
M5"!P87)A;65T97)S+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M('-U8V@@87,@=&AE($Y/5$E&62!F;&%G<R!D969I;F5D(&)Y(%)&0R`Q.#DQ
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@4F5T=7)N<R!A(%!%05)?
M17)R;W(@=VET:"!A;B!E<G)O<B!M97-S86=E(&]N(&%N>0H@("`@("H@("`@
M("`@("`@("`@("!K:6YD(&]F(&9A:6QU<F4L(&]R('1R=64@;VX@<W5C8V5S
M<RX*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-I;F-E
M("`Q+C`*("`@("`J+PH@("`@9G5N8W1I;VX@<F-P=%1O*"1R96-I<&EE;G0L
M("1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@("`@("1A<F=S(#T@(E1/.CPD
M<F5C:7!I96YT/B(["B`@("`@("`@:68@*&ES7W-T<FEN9R@D<&%R86US*2D@
M>PH@("`@("`@("`@("`D87)G<R`N/2`G("<@+B`D<&%R86US.PH@("`@("`@
M('T*"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M
M/E]P=70H)U)#4%0G+"`D87)G<RDI*2!["B`@("`@("`@("`@(')E='5R;B`D
M97)R;W(["B`@("`@("`@?0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E
M<G)O<B`]("1T:&ES+3Y?<&%R<V5297-P;VYS92AA<G)A>2@R-3`L(#(U,2DI
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!1=6]T
M92!T:&4@9&%T82!S;R!T:&%T(&ET(&UE971S(%--5%`@<W1A;F1A<F1S+@H@
M("`@("H*("`@("`J(%1H:7,@:7,@<')O=FED960@87,@82!S97!A<F%T92!P
M=6)L:6,@9G5N8W1I;VX@=&\@9F%C:6QI=&%T90H@("`@("H@96%S:65R(&]V
M97)L;V%D:6YG(&9O<B!T:&4@8V%S97,@=VAE<F4@:70@:7,@9&5S:7)A8FQE
M('1O"B`@("`@*B!C=7-T;VUI>F4@=&AE('%U;W1I;F<@8F5H879I;W(N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&%T82`@5&AE(&UE<W-A9V4@
M=&5X="!T;R!Q=6]T92X@5&AE('-T<FEN9R!M=7-T(&)E('!A<W-E9`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@8GD@<F5F97)E;F-E+"!A;F0@=&AE
M('1E>'0@=VEL;"!B92!M;V1I9FEE9"!I;B!P;&%C92X*("`@("`J"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-I;F-E("`Q+C(*("`@("`J+PH@
M("`@9G5N8W1I;VX@<75O=&5D871A*"8D9&%T82D*("`@('L*("`@("`@("`O
M*B!#:&%N9V4@56YI>"`H7&XI(&%N9"!-86,@*%QR*2!L:6YE9F5E9',@:6YT
M;PH@("`@("`@("`J($EN=&5R;F5T+7-T86YD87)D($-23$8@*%QR7&XI(&QI
M;F5F965D<RX@*B\*("`@("`@("`D9&%T82`]('!R96=?<F5P;&%C92AA<G)A
M>2@G+R@_/"%<<BE<;B\G+"<O7'(H/R%<;BDO)RDL(")<<EQN(BP@)&1A=&$I
M.PH*("`@("`@("`O*B!"96-A=7-E(&$@<VEN9VQE(&QE861I;F<@<&5R:6]D
M("@N*2!S:6=N:69I97,@86X@96YD('1O('1H90H@("`@("`@("`J(&1A=&$L
M(&QE9VET:6UA=&4@;&5A9&EN9R!P97)I;V1S(&YE960@=&\@8F4@(F1O=6)L
M960B"B`@("`@("`@("H@*&4N9RX@)RXN)RDN("HO"B`@("`@("`@)&1A=&$@
M/2!S=')?<F5P;&%C92@B7&XN(BP@(EQN+BXB+"`D9&%T82D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!396YD('1H92!$051!(&-O;6UA;F0N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D9&%T82`@5&AE(&UE<W-A9V4@8F]D>2!T
M;R!S96YD+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@4F5T=7)N<R!A
M(%!%05)?17)R;W(@=VET:"!A;B!E<G)O<B!M97-S86=E(&]N(&%N>0H@("`@
M("H@("`@("`@("`@("`@("!K:6YD(&]F(&9A:6QU<F4L(&]R('1R=64@;VX@
M<W5C8V5S<RX*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<VEN8V4@
M(#$N,`H@("`@("HO"B`@("!F=6YC=&EO;B!D871A*"1D871A*0H@("`@>PH@
M("`@("`@("\J(%)&0R`Q.#<P+"!S96-T:6]N(#,L('-U8G-E8W1I;VX@,R!S
M=&%T97,@(F$@=F%L=64@;V8@>F5R;PH@("`@("`@("`J(&EN9&EC871E<R!T
M:&%T(&YO(&9I>&5D(&UA>&EM=6T@;65S<V%G92!S:7IE(&ES(&EN(&9O<F-E
M(BX*("`@("`@("`@*B!&=7)T:&5R;6]R92P@:70@<V%Y<R!T:&%T(&EF(")T
M:&4@<&%R86UE=&5R(&ES(&]M:71T960@;F\*("`@("`@("`@*B!I;F9O<FUA
M=&EO;B!I<R!C;VYV97EE9"!A8F]U="!T:&4@<V5R=F5R)W,@9FEX960@;6%X
M:6UU;0H@("`@("`@("`J(&UE<W-A9V4@<VEZ92(N("HO"B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?97-M='!;)U-)6D4G72D@)B8@*"1T:&ES+3Y?97-M
M='!;)U-)6D4G72`^(#`I*2!["B`@("`@("`@("`@(&EF("AS=')L96XH)&1A
M=&$I(#X]("1T:&ES+3Y?97-M='!;)U-)6D4G72D@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/F1I<V-O;FYE8W0H*3L*("`@("`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"=-97-S86=E('-I>F4@97AC961E<R!T:&4@
M<V5R=F5R(&QI;6ET)RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@("\J(%%U;W1E('1H92!D871A(&)A<V5D(&]N('1H92!33510('-T86YD
M87)D<RX@*B\*("`@("`@("`D=&AI<RT^<75O=&5D871A*"1D871A*3L*"B`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P=70H
M)T1!5$$G*2DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@
M("!]"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M
M/E]P87)S95)E<W!O;G-E*#,U-"DI*2!["B`@("`@("`@("`@(')E='5R;B`D
M97)R;W(["B`@("`@("`@?0H*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M<F5S=6QT(#T@)'1H:7,M/E]S96YD*"1D871A("X@(EQR7&XN7')<;B(I*2D@
M>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"B`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P87)S95)E
M<W!O;G-E*#(U,"DI*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*
M("`@("`J(%-E;F0@=&AE(%-%3D0@1E)/33H@8V]M;6%N9"X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG(%1H92!R979E<G-E('!A=&@@=&\@<V5N9"X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%)E='5R;G,@82!014%27T5R
M<F]R('=I=&@@86X@97)R;W(@;65S<V%G92!O;B!A;GD*("`@("`J("`@("`@
M("`@("`@("`@:VEN9"!O9B!F86EL=7)E+"!O<B!T<G5E(&]N('-U8V-E<W,N
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-I;F-E("`Q+C(N-@H@
M("`@("HO"B`@("!F=6YC=&EO;B!S96YD1G)O;2@D<&%T:"D*("`@('L*("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!U="@G
M4T5.1"<L(")&4D]-.CPD<&%T:#XB*2DI('L*("`@("`@("`@("`@<F5T=7)N
M("1E<G)O<CL*("`@("`@("!]"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)&5R<F]R(#T@)'1H:7,M/E]P87)S95)E<W!O;G-E*#(U,"DI*2!["B`@("`@
M("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($)A8VMW87)D<RUC;VUP
M871I8FEL:71Y('=R87!P97(@9F]R('-E;F1&<F]M*"DN"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R!4:&4@<F5V97)S92!P871H('1O('-E;F0N"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!2971U<FYS(&$@4$5!4E]%<G)O
M<B!W:71H(&%N(&5R<F]R(&UE<W-A9V4@;VX@86YY"B`@("`@*B`@("`@("`@
M("`@("`@(&MI;F0@;V8@9F%I;'5R92P@;W(@=')U92!O;B!S=6-C97-S+@H@
M("`@("H*("`@("`J($!A8V-E<W,@("`@("!P=6)L:6,*("`@("`J($!S:6YC
M92`@("`@("`Q+C`*("`@("`J($!D97!R96-A=&5D("`Q+C(N-@H@("`@("HO
M"B`@("!F=6YC=&EO;B!S96YD7V9R;VTH)'!A=&@I"B`@("!["B`@("`@("`@
M<F5T=7)N('-E;F1&<F]M*"1P871H*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%-E;F0@=&AE(%-/34P@1E)/33H@8V]M;6%N9"X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG(%1H92!R979E<G-E('!A=&@@=&\@<V5N9"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D(%)E='5R;G,@82!014%27T5R<F]R('=I
M=&@@86X@97)R;W(@;65S<V%G92!O;B!A;GD*("`@("`J("`@("`@("`@("`@
M("`@:VEN9"!O9B!F86EL=7)E+"!O<B!T<G5E(&]N('-U8V-E<W,N"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-I;F-E("`Q+C(N-@H@("`@("HO
M"B`@("!F=6YC=&EO;B!S;VUL1G)O;2@D<&%T:"D*("`@('L*("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!U="@G4T]-3"<L
M(")&4D]-.CPD<&%T:#XB*2DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O
M<CL*("`@("`@("!]"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R
M(#T@)'1H:7,M/E]P87)S95)E<W!O;G-E*#(U,"DI*2!["B`@("`@("`@("`@
M(')E='5R;B`D97)R;W(["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U
M93L*("`@('T*"B`@("`O*BH*("`@("`J($)A8VMW87)D<RUC;VUP871I8FEL
M:71Y('=R87!P97(@9F]R('-O;6Q&<F]M*"DN"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R!4:&4@<F5V97)S92!P871H('1O('-E;F0N"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"!2971U<FYS(&$@4$5!4E]%<G)O<B!W:71H
M(&%N(&5R<F]R(&UE<W-A9V4@;VX@86YY"B`@("`@*B`@("`@("`@("`@("`@
M(&MI;F0@;V8@9F%I;'5R92P@;W(@=')U92!O;B!S=6-C97-S+@H@("`@("H*
M("`@("`J($!A8V-E<W,@("`@("!P=6)L:6,*("`@("`J($!S:6YC92`@("`@
M("`Q+C`*("`@("`J($!D97!R96-A=&5D("`Q+C(N-@H@("`@("HO"B`@("!F
M=6YC=&EO;B!S;VUL7V9R;VTH)'!A=&@I"B`@("!["B`@("`@("`@<F5T=7)N
M('-O;6Q&<F]M*"1P871H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E;F0@
M=&AE(%-!34P@1E)/33H@8V]M;6%N9"X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG(%1H92!R979E<G-E('!A=&@@=&\@<V5N9"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D(%)E='5R;G,@82!014%27T5R<F]R('=I=&@@86X@
M97)R;W(@;65S<V%G92!O;B!A;GD*("`@("`J("`@("`@("`@("`@("`@:VEN
M9"!O9B!F86EL=7)E+"!O<B!T<G5E(&]N('-U8V-E<W,N"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("H@0'-I;F-E("`Q+C(N-@H@("`@("HO"B`@("!F
M=6YC=&EO;B!S86UL1G)O;2@D<&%T:"D*("`@('L*("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!U="@G4T%-3"<L(")&4D]-
M.CPD<&%T:#XB*2DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@
M("`@("!]"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H
M:7,M/E]P87)S95)E<W!O;G-E*#(U,"DI*2!["B`@("`@("`@("`@(')E='5R
M;B`D97)R;W(["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O*BH*("`@("`J($)A8VMW87)D<RUC;VUP871I8FEL:71Y('=R
M87!P97(@9F]R('-A;6Q&<F]M*"DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R!4:&4@<F5V97)S92!P871H('1O('-E;F0N"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"!2971U<FYS(&$@4$5!4E]%<G)O<B!W:71H(&%N(&5R
M<F]R(&UE<W-A9V4@;VX@86YY"B`@("`@*B`@("`@("`@("`@("`@(&MI;F0@
M;V8@9F%I;'5R92P@;W(@=')U92!O;B!S=6-C97-S+@H@("`@("H*("`@("`J
M($!A8V-E<W,@("`@("!P=6)L:6,*("`@("`J($!S:6YC92`@("`@("`Q+C`*
M("`@("`J($!D97!R96-A=&5D("`Q+C(N-@H@("`@("HO"B`@("!F=6YC=&EO
M;B!S86UL7V9R;VTH)'!A=&@I"B`@("!["B`@("`@("`@<F5T=7)N('-A;6Q&
M<F]M*"1P871H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E;F0@=&AE(%)3
M150@8V]M;6%N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%)E='5R
M;G,@82!014%27T5R<F]R('=I=&@@86X@97)R;W(@;65S<V%G92!O;B!A;GD*
M("`@("`J("`@("`@("`@("`@("`@:VEN9"!O9B!F86EL=7)E+"!O<B!T<G5E
M(&]N('-U8V-E<W,N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-I
M;F-E("`Q+C`*("`@("`J+PH@("`@9G5N8W1I;VX@<G-E="@I"B`@("!["B`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P=70H
M)U)3150G*2DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@
M("!]"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M
M/E]P87)S95)E<W!O;G-E*#(U,"DI*2!["B`@("`@("`@("`@(')E='5R;B`D
M97)R;W(["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*
M"B`@("`O*BH*("`@("`J(%-E;F0@=&AE(%921ED@8V]M;6%N9"X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG(%1H92!S=')I;F<@=&\@=F5R:69Y"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!2971U<FYS(&$@4$5!4E]%<G)O
M<B!W:71H(&%N(&5R<F]R(&UE<W-A9V4@;VX@86YY"B`@("`@*B`@("`@("`@
M("`@("`@(&MI;F0@;V8@9F%I;'5R92P@;W(@=')U92!O;B!S=6-C97-S+@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S:6YC92`@,2XP"B`@("`@
M*B\*("`@(&9U;F-T:6]N('9R9GDH)'-T<FEN9RD*("`@('L*("`@("`@("`O
M*B!.;W1E.B`R-3$@:7,@86QS;R!A('9A;&ED(')E<W!O;G-E(&-O9&4@*B\*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!U
M="@G5E)&62<L("1S=')I;F<I*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R
M<F]R.PH@("`@("`@('T*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R
M;W(@/2`D=&AI<RT^7W!A<G-E4F5S<&]N<V4H87)R87DH,C4P+"`R-3(I*2DI
M('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5N9"!T
M:&4@3D]/4"!C;VUM86YD+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M4F5T=7)N<R!A(%!%05)?17)R;W(@=VET:"!A;B!E<G)O<B!M97-S86=E(&]N
M(&%N>0H@("`@("H@("`@("`@("`@("`@("!K:6YD(&]F(&9A:6QU<F4L(&]R
M('1R=64@;VX@<W5C8V5S<RX*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B!`<VEN8V4@(#$N,`H@("`@("HO"B`@("!F=6YC=&EO;B!N;V]P*"D*("`@
M('L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^
M7W!U="@G3D]/4"<I*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@
M("`@("`@('T*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D
M=&AI<RT^7W!A<G-E4F5S<&]N<V4H,C4P*2DI('L*("`@("`@("`@("`@<F5T
M=7)N("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0F%C:W=A<F1S+6-O;7!A=&EB:6QI='D@
M;65T:&]D+B`@:61E;G1I9GE396YD97(H*2=S(&9U;F-T:6]N86QI='D@:7,*
M("`@("`J(&YO=R!H86YD;&5D(&EN=&5R;F%L;'DN"B`@("`@*@H@("`@("H@
M0')E='5R;B`@8F]O;&5A;B`@("`@5&AI<R!M971H;V0@86QW87ES(')E='5R
M;B!T<G5E+@H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@
M0'-I;F-E("`@,2XP"B`@("`@*B\*("`@(&9U;F-T:6]N(&ED96YT:69Y4V5N
M9&5R*"D*("`@('L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B].970O55),+G!H<```````
M````````````````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#,R-C,T
M(#$P-3$U-#,S-S,S(#`R,#,W-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PT*+R\@?"!#;W!Y<FEG:'0@*&,I(#(P,#(M,C`P-"P@4FEC
M:&%R9"!(97EE<R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*
M+R\@?"!!;&P@<FEG:'1S(')E<V5R=F5D+B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`T*+R\@?"!2961I<W1R:6)U=&EO;B!A;F0@
M=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO
M=70@("`@?`T*+R\@?"!M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@<')O
M=FED960@=&AA="!T:&4@9F]L;&]W:6YG(&-O;F1I=&EO;G,@("`@?`T*+R\@
M?"!A<F4@;65T.B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`T*+R\@?"!O(%)E9&ES=')I8G5T:6]N<R!O9B!S
M;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I9VAT("`@
M("`@?`T*+R\@?"`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@
M86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX@("`@("`@?`T*+R\@?"!O
M(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C
M92!T:&4@86)O=F4@8V]P>7)I9VAT("`@?`T*+R\@?"`@(&YO=&EC92P@=&AI
M<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA
M:6UE<B!I;B!T:&4@?`T*+R\@?"`@(&1O8W5M96YT871I;VX@86YD+V]R(&]T
M:&5R(&UA=&5R:6%L<R!P<F]V:61E9"!W:71H('1H92!D:7-T<FEB=71I;VXN
M?`T*+R\@?"!O(%1H92!N86UE<R!O9B!T:&4@875T:&]R<R!M87D@;F]T(&)E
M('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E("`@("`@?`T*+R\@?"`@('!R
M;V1U8W1S(&1E<FEV960@9G)O;2!T:&ES('-O9G1W87)E('=I=&AO=70@<W!E
M8VEF:6,@<')I;W(@=W)I='1E;B`@?`T*+R\@?"`@('!E<FUI<W-I;VXN("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`T*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*
M+R\@?"!42$E3(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'
M2%0@2$],1$524R!!3D0@0T].5%))0E543U)3("`@?`T*+R\@?"`B05,@25,B
M($%.1"!!3ED@15A04D534R!/4B!)35!,245$(%=!4E)!3E1)15,L($E.0TQ5
M1$E.1RP@0E54($Y/5"`@("`@?`T*+R\@?"!,24U)5$5$(%1/+"!42$4@24U0
M3$E%1"!705)204Y42453($]&($U%4D-(04Y404))3$E462!!3D0@1DE43D53
M4R!&3U(@?`T*+R\@?"!!(%!!4E1)0U5,05(@4%524$]312!!4D4@1$E30TQ!
M24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%($-/4%E224=(5"`@?`T*+R\@
M?"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4@3$E!0DQ%($9/4B!!3ED@1$E2
M14-4+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@?`T*+R\@?"!34$5#24%,+"!%
M6$5-4$Q!4EDL($]2($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'
M+"!"550@3D]4("`@("`@?`T*+R\@?"!,24U)5$5$(%1/+"!04D]#55)%345.
M5"!/1B!354)35$E4551%($=/3T13($]2(%-%4E9)0T53.R!,3U-3($]&(%53
M12P@?`T*+R\@?"!$051!+"!/4B!04D]&2513.R!/4B!"55-)3D534R!)3E1%
M4E)54%1)3TXI($A/5T5615(@0T%54T5$($%.1"!/3B!!3ED@?`T*+R\@?"!4
M2$5/4ED@3T8@3$E!0DE,2519+"!72$542$52($E.($-/3E1204-4+"!35%))
M0U0@3$E!0DE,2519+"!/4B!43U)4("`@?`T*+R\@?"`H24Y#3%5$24Y'($Y%
M1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!4DE324Y'($E.($%.62!705D@3U54
M($]&(%1(12!54T4@?`T*+R\@?"!/1B!42$E3(%-/1E1705)%+"!%5D5.($E&
M($%$5DE3140@3T8@5$A%(%!/4U-)0DE,2519($]&(%-50T@@1$%-04=%+B`@
M?`T*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!!=71H;W(Z(%)I8VAA<F0@
M2&5Y97,@/')I8VAA<F0@870@<&AP(&YE=#X@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*
M+R\-"B\O("1)9#H@55),+G!H<"QV(#$N,S8@,C`P-"\P-B\Q.2`Q.#HU.#HU
M,"!R:6-H87)D($5X<"`D#0HO+PT*+R\@3F5T7U523"!#;&%S<PT*#0IC;&%S
M<R!.971?55),#0I[#0H@("`@+RHJ#0H@("`@*B!&=6QL('5R;`T*("`@("H@
M0'9A<B!S=')I;F<-"B`@("`J+PT*("`@('9A<B`D=7)L.PT*#0H@("`@+RHJ
M#0H@("`@*B!0<F]T;V-O;`T*("`@("H@0'9A<B!S=')I;F<-"B`@("`J+PT*
M("`@('9A<B`D<')O=&]C;VP[#0H-"B`@("`O*BH-"B`@("`J(%5S97)N86UE
M#0H@("`@*B!`=F%R('-T<FEN9PT*("`@("HO#0H@("`@=F%R("1U<V5R;F%M
M93L-"@T*("`@("\J*@T*("`@("H@4&%S<W=O<F0-"B`@("`J($!V87(@<W1R
M:6YG#0H@("`@*B\-"B`@("!V87(@)'!A<W-W;W)D.PT*#0H@("`@+RHJ#0H@
M("`@*B!(;W-T#0H@("`@*B!`=F%R('-T<FEN9PT*("`@("HO#0H@("`@=F%R
M("1H;W-T.PT*#0H@("`@+RHJ#0H@("`@*B!0;W)T#0H@("`@*B!`=F%R(&EN
M=&5G97(-"B`@("`J+PT*("`@('9A<B`D<&]R=#L-"@T*("`@("\J*@T*("`@
M("H@4&%T:`T*("`@("H@0'9A<B!S=')I;F<-"B`@("`J+PT*("`@('9A<B`D
M<&%T:#L-"@T*("`@("\J*@T*("`@("H@475E<GD@<W1R:6YG#0H@("`@*B!`
M=F%R(&%R<F%Y#0H@("`@*B\-"B`@("!V87(@)'%U97)Y<W1R:6YG.PT*#0H@
M("`@+RHJ#0H@("`@*B!!;F-H;W(-"B`@("`J($!V87(@<W1R:6YG#0H@("`@
M*B\-"B`@("!V87(@)&%N8VAO<CL-"@T*("`@("\J*@T*("`@("H@5VAE=&AE
M<B!T;R!U<V4@6UT-"B`@("`J($!V87(@8F]O;`T*("`@("HO#0H@("`@=F%R
M("1U<V5"<F%C:V5T<SL-"@T*("`@("\J*@T*("`@("H@4$A0-"!#;VYS=')U
M8W1O<@T*("`@("H-"B`@("`J($!S964@7U]C;VYS=')U8W0H*0T*("`@("HO
M#0H@("`@9G5N8W1I;VX@3F5T7U523"@D=7)L(#T@;G5L;"P@)'5S94)R86-K
M971S(#T@=')U92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?7V-O;G-T<G5C
M="@D=7)L+"`D=7-E0G)A8VME=',I.PT*("`@('T-"@T*("`@("\J*@T*("`@
M("H@4$A0-2!#;VYS=')U8W1O<@T*("`@("H-"B`@("`J(%!A<G-E<R!T:&4@
M9VEV96X@=7)L(&%N9"!S=&]R97,@=&AE('9A<FEO=7,@<&%R=',-"B`@("`J
M($1E9F%U;'1S(&%R92!U<V5D(&EN(&-E<G1A:6X@8V%S97,-"B`@("`J#0H@
M("`@*B!`<&%R86T@<W1R:6YG("1U<FP@("`@("`@("!/<'1I;VYA;"!54DP-
M"B`@("`J($!P87)A;2!B;V]L("`@)'5S94)R86-K971S(%=H971H97(@=&\@
M=7-E('-Q=6%R92!B<F%C:V5T<R!W:&5N#0H@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!M=6QT:7!L92!Q=65R>7-T<FEN9W,@=VET:"!T:&4@
M<V%M92!N86UE#0H@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!E
M>&ES=`T*("`@("HO#0H@("`@9G5N8W1I;VX@7U]C;VYS=')U8W0H)'5R;"`]
M(&YU;&PL("1U<V5"<F%C:V5T<R`]('1R=64I#0H@("`@>PT*("`@("`@("`D
M2%144%]315)615)?5D%24R`@/2`A96UP='DH)%]315)615(I(#\@)%]315)6
M15(@.B`D1TQ/0D%,4ULG2%144%]315)615)?5D%24R==.PT*#0H@("`@("`@
M("1T:&ES+3YU<V5"<F%C:V5T<R`]("1U<V5"<F%C:V5T<SL-"B`@("`@("`@
M)'1H:7,M/G5R;"`@("`@("`@(#T@)'5R;#L-"B`@("`@("`@)'1H:7,M/G5S
M97(@("`@("`@(#T@)R<[#0H@("`@("`@("1T:&ES+3YP87-S("`@("`@("`]
M("<G.PT*("`@("`@("`D=&AI<RT^:&]S="`@("`@("`@/2`G)SL-"B`@("`@
M("`@)'1H:7,M/G!O<G0@("`@("`@(#T@.#`[#0H@("`@("`@("1T:&ES+3YP
M871H("`@("`@("`]("<G.PT*("`@("`@("`D=&AI<RT^<75E<GES=')I;F<@
M/2!A<G)A>2@I.PT*("`@("`@("`D=&AI<RT^86YC:&]R("`@("`@/2`G)SL-
M"@T*("`@("`@("`O+R!/;FQY('5S92!D969A=6QT<R!I9B!N;W0@86X@86)S
M;VQU=&4@55),(&=I=F5N#0H@("`@("`@(&EF("@A<')E9U]M871C:"@G+UY;
M82UZ,"TY72LZ7"]<+R]I)RP@)'5R;"DI('L-"@T*("`@("`@("`@("`@)'1H
M:7,M/G!R;W1O8V]L("`@(#T@*$`D2%144%]315)615)?5D%24ULG2%144%,G
M72`]/2`G;VXG(#\@)VAT='!S)R`Z("=H='1P)RD[#0H-"B`@("`@("`@("`@
M("\J*@T*("`@("`@("`@("`@*B!&:6=U<F4@;W5T(&AO<W0O<&]R=`T*("`@
M("`@("`@("`@*B\-"B`@("`@("`@("`@(&EF("@A96UP='DH)$A45%!?4T52
M5D527U9!4E-;)TA45%!?2$]35"==*2!!3D0@<')E9U]M871C:"@G+UXH+BHI
M*#HH6S`M.5TK*2D_)"]5)RP@)$A45%!?4T525D527U9!4E-;)TA45%!?2$]3
M5"==+"`D;6%T8VAE<RDI('L-"B`@("`@("`@("`@("`@("`D:&]S="`]("1M
M871C:&5S6S%=.PT*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&UA=&-H
M97-;,UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1P;W)T(#T@)&UA=&-H
M97-;,UT[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@)'!O<G0@/2`D=&AI<RT^9V5T4W1A;F1A<F10;W)T*"1T:&ES
M+3YP<F]T;V-O;"D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M?0T*#0H@("`@("`@("`@("`D=&AI<RT^=7-E<B`@("`@("`@/2`G)SL-"B`@
M("`@("`@("`@("1T:&ES+3YP87-S("`@("`@("`]("<G.PT*("`@("`@("`@
M("`@)'1H:7,M/FAO<W0@("`@("`@(#T@(65M<'1Y*"1H;W-T*2`_("1H;W-T
M(#H@*&ES<V5T*"1(5%107U-%4E9%4E]605)36R=315)615)?3D%-12==*2`_
M("1(5%107U-%4E9%4E]605)36R=315)615)?3D%-12==(#H@)VQO8V%L:&]S
M="<I.PT*("`@("`@("`@("`@)'1H:7,M/G!O<G0@("`@("`@(#T@(65M<'1Y
M*"1P;W)T*2`_("1P;W)T(#H@*&ES<V5T*"1(5%107U-%4E9%4E]605)36R=3
M15)615)?4$]25"==*2`_("1(5%107U-%4E9%4E]605)36R=315)615)?4$]2
M5"==(#H@)'1H:7,M/F=E=%-T86YD87)D4&]R="@D=&AI<RT^<')O=&]C;VPI
M*3L-"B`@("`@("`@("`@("1T:&ES+3YP871H("`@("`@("`]("%E;7!T>2@D
M2%144%]315)615)?5D%24ULG4$A07U-%3$8G72D@/R`D2%144%]315)615)?
M5D%24ULG4$A07U-%3$8G72`Z("<O)SL-"B`@("`@("`@("`@("1T:&ES+3YQ
M=65R>7-T<FEN9R`](&ES<V5T*"1(5%107U-%4E9%4E]605)36R=1545265]3
M5%))3D<G72D@/R`D=&AI<RT^7W!A<G-E4F%W475E<GES=')I;F<H)$A45%!?
M4T525D527U9!4E-;)U%515)97U-44DE.1R==*2`Z(&YU;&P[#0H@("`@("`@
M("`@("`D=&AI<RT^86YC:&]R("`@("`@/2`G)SL-"B`@("`@("`@?0T*#0H@
M("`@("`@("\O(%!A<G-E('1H92!U<FP@86YD('-T;W)E('1H92!V87)I;W5S
M('!A<G1S#0H@("`@("`@(&EF("@A96UP='DH)'5R;"DI('L-"B`@("`@("`@
M("`@("1U<FQI;F9O(#T@<&%R<V5?=7)L*"1U<FPI.PT*#0H@("`@("`@("`@
M("`O+R!$969A=6QT('%U97)Y<W1R:6YG#0H@("`@("`@("`@("`D=&AI<RT^
M<75E<GES=')I;F<@/2!A<G)A>2@I.PT*#0H@("`@("`@("`@("!F;W)E86-H
M("@D=7)L:6YF;R!A<R`D:V5Y(#T^("1V86QU92D@>PT*("`@("`@("`@("`@
M("`@('-W:71C:"`H)&ME>2D@>PT*("`@("`@("`@("`@("`@("`@("!C87-E
M("=S8VAE;64G.@T*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G!R
M;W1O8V]L(#T@)'9A;'5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G!O<G0@("`@(#T@)'1H:7,M/F=E=%-T86YD87)D4&]R="@D=F%L=64I
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@("`@
M("`@("`@("`@("`@8V%S92`G=7-E<B<Z#0H@("`@("`@("`@("`@("`@("`@
M(&-A<V4@)W!A<W,G.@T*("`@("`@("`@("`@("`@("`@("!C87-E("=H;W-T
M)SH-"B`@("`@("`@("`@("`@("`@("`@8V%S92`G<&]R="<Z#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^)&ME>2`]("1V86QU93L-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PT*#0H@("`@("`@("`@("`@("`@
M("`@(&-A<V4@)W!A=&@G.@T*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"1V86QU97LP?2`]/2`G+R<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^<&%T:"`]("1V86QU93L-"B`@("`@("`@("`@("`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!A=&@@/2!D:7)N86UE*"1T:&ES+3YP871H*2`]/2!$25)%0U1/4EE?4T50
M05)!5$]2(#\@)R<@.B!D:7)N86UE*"1T:&ES+3YP871H*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<&%T:"`]('-P<FEN=&8H)R5S
M+R5S)RP@)'!A=&@L("1V86QU92D[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"@T*("`@("`@
M("`@("`@("`@("`@("!C87-E("=Q=65R>2<Z#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^<75E<GES=')I;F<@/2`D=&AI<RT^7W!A<G-E4F%W
M475E<GE3=')I;F<H)'9A;'5E*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PT*#0H@("`@("`@("`@("`@("`@("`@(&-A<V4@)V9R86=M96YT
M)SH-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YA;F-H;W(@/2`D
M=F%L=64[#0H@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`J(%)E='5R;G,@9G5L;"!U<FP-"B`@("`J#0H@
M("`@*B!`<F5T=7)N('-T<FEN9R!&=6QL('5R;`T*("`@("H@0&%C8V5S<R!P
M=6)L:6,-"B`@("`J+PT*("`@(&9U;F-T:6]N(&=E=%523"@I#0H@("`@>PT*
M("`@("`@("`D<75E<GES=')I;F<@/2`D=&AI<RT^9V5T475E<GE3=')I;F<H
M*3L-"@T*("`@("`@("`D=&AI<RT^=7)L(#T@)'1H:7,M/G!R;W1O8V]L("X@
M)SHO+R<-"B`@("`@("`@("`@("`@("`@("`N("1T:&ES+3YU<V5R("X@*"%E
M;7!T>2@D=&AI<RT^<&%S<RD@/R`G.B<@.B`G)RD-"B`@("`@("`@("`@("`@
M("`@("`N("1T:&ES+3YP87-S("X@*"%E;7!T>2@D=&AI<RT^=7-E<BD@/R`G
M0"<@.B`G)RD-"B`@("`@("`@("`@("`@("`@("`N("1T:&ES+3YH;W-T("X@
M*"1T:&ES+3YP;W)T(#T]("1T:&ES+3YG9713=&%N9&%R9%!O<G0H)'1H:7,M
M/G!R;W1O8V]L*2`_("<G(#H@)SHG("X@)'1H:7,M/G!O<G0I#0H@("`@("`@
M("`@("`@("`@("`@+B`D=&AI<RT^<&%T:`T*("`@("`@("`@("`@("`@("`@
M("X@*"%E;7!T>2@D<75E<GES=')I;F<I(#\@)S\G("X@)'%U97)Y<W1R:6YG
M(#H@)R<I#0H@("`@("`@("`@("`@("`@("`@+B`H(65M<'1Y*"1T:&ES+3YA
M;F-H;W(I(#\@)R,G("X@)'1H:7,M/F%N8VAO<B`Z("<G*3L-"@T*("`@("`@
M("!R971U<FX@)'1H:7,M/G5R;#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`J
M($%D9',@82!Q=65R>7-T<FEN9R!I=&5M#0H@("`@*@T*("`@("H@0'!A<F%M
M("!S=')I;F<@)&YA;64@("`@("`@3F%M92!O9B!I=&5M#0H@("`@*B!`<&%R
M86T@('-T<FEN9R`D=F%L=64@("`@("!686QU92!O9B!I=&5M#0H@("`@*B!`
M<&%R86T@(&)O;VP@("`D<')E96YC;V1E9"!7:&5T:&5R('9A;'5E(&ES('5R
M;&5N8V]D960@;W(@;F]T+"!D969A=6QT(#T@;F]T#0H@("`@*B!`86-C97-S
M('!U8FQI8PT*("`@("HO#0H@("`@9G5N8W1I;VX@861D475E<GE3=')I;F<H
M)&YA;64L("1V86QU92P@)'!R965N8V]D960@/2!F86QS92D-"B`@("![#0H@
M("`@("`@(&EF("@D<')E96YC;V1E9"D@>PT*("`@("`@("`@("`@)'1H:7,M
M/G%U97)Y<W1R:6YG6R1N86UE72`]("1V86QU93L-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("1T:&ES+3YQ=65R>7-T<FEN9ULD;F%M95T@/2!I
M<U]A<G)A>2@D=F%L=64I(#\@87)R87E?;6%P*"=R87=U<FQE;F-O9&4G+"`D
M=F%L=64I.B!R87=U<FQE;F-O9&4H)'9A;'5E*3L-"B`@("`@("`@?0T*("`@
M('T-"@T*("`@("\J*@T*("`@("H@4F5M;W9E<R!A('%U97)Y<W1R:6YG(&ET
M96T-"B`@("`J#0H@("`@*B!`<&%R86T@('-T<FEN9R`D;F%M92!.86UE(&]F
M(&ET96T-"B`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@*B\-"B`@("!F=6YC
M=&EO;B!R96UO=F51=65R>5-T<FEN9R@D;F%M92D-"B`@("![#0H@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^<75E<GES=')I;F=;)&YA;65=*2D@>PT*("`@
M("`@("`@("`@=6YS970H)'1H:7,M/G%U97)Y<W1R:6YG6R1N86UE72D[#0H@
M("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`J(%-E=',@=&AE('%U
M97)Y<W1R:6YG('1O(&QI=&5R86QL>2!W:&%T('EO=2!S=7!P;'D-"B`@("`J
M#0H@("`@*B!`<&%R86T@('-T<FEN9R`D<75E<GES=')I;F<@5&AE('%U97)Y
M<W1R:6YG(&1A=&$N(%-H;W5L9"!B92!O9B!T:&4@9F]R;6%T(&9O;SUB87(F
M>#UY(&5T8PT*("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`J+PT*("`@(&9U
M;F-T:6]N(&%D9%)A=U%U97)Y4W1R:6YG*"1Q=65R>7-T<FEN9RD-"B`@("![
M#0H@("`@("`@("1T:&ES+3YQ=65R>7-T<FEN9R`]("1T:&ES+3Y?<&%R<V52
M87=1=65R>5-T<FEN9R@D<75E<GES=')I;F<I.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("H@4F5T=7)N<R!F;&%T('%U97)Y<W1R:6YG#0H@("`@*@T*("`@
M("H@0')E='5R;B!S=')I;F<@475E<GES=')I;F<-"B`@("`J($!A8V-E<W,@
M<'5B;&EC#0H@("`@*B\-"B`@("!F=6YC=&EO;B!G9711=65R>5-T<FEN9R@I
M#0H@("`@>PT*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3YQ=65R>7-T<FEN
M9RDI('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YQ=65R>7-T<FEN
M9R!A<R`D;F%M92`]/B`D=F%L=64I('L-"B`@("`@("`@("`@("`@("!I9B`H
M:7-?87)R87DH)'9A;'5E*2D@>PT*("`@("`@("`@("`@("`@("`@("!F;W)E
M86-H("@D=F%L=64@87,@)&L@/3X@)'8I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1Q=65R>7-T<FEN9UM=(#T@)'1H:7,M/G5S94)R86-K971S(#\@
M<W!R:6YT9B@G)7-;)7-=/25S)RP@)&YA;64L("1K+"`D=BD@.B`H)&YA;64@
M+B`G/2<@+B`D=BD[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!](&5L<V5I9B`H(6ES7VYU;&PH)'9A;'5E*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`D<75E<GES=')I;F=;72`]("1N86UE("X@)STG("X@
M)'9A;'5E.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@("`@("1Q=65R>7-T<FEN9UM=(#T@)&YA;64[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'%U97)Y<W1R
M:6YG(#T@:6UP;&]D92AI;FE?9V5T*"=A<F=?<V5P87)A=&]R+F]U='!U="<I
M+"`D<75E<GES=')I;F<I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@)'%U97)Y<W1R:6YG(#T@)R<[#0H@("`@("`@('T-"@T*("`@("`@("!R
M971U<FX@)'%U97)Y<W1R:6YG.PT*("`@('T-"@T*("`@("\J*@T*("`@("H@
M4&%R<V5S(')A=R!Q=65R>7-T<FEN9R!A;F0@<F5T=7)N<R!A;B!A<G)A>2!O
M9B!I=`T*("`@("H-"B`@("`J($!P87)A;2`@<W1R:6YG("`D<75E<GES=')I
M;F<@5&AE('%U97)Y<W1R:6YG('1O('!A<G-E#0H@("`@*B!`<F5T=7)N(&%R
M<F%Y("`@("`@("`@("`@("`@($%N(&%R<F%Y(&]F('1H92!Q=65R>7-T<FEN
M9R!D871A#0H@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`J+PT*("`@(&9U
M;F-T:6]N(%]P87)S95)A=U%U97)Y<W1R:6YG*"1Q=65R>7-T<FEN9RD-"B`@
M("![#0H@("`@("`@("1P87)T<R`@/2!P<F5G7W-P;&ET*"<O6R<@+B!P<F5G
M7W%U;W1E*&EN:5]G970H)V%R9U]S97!A<F%T;W(N:6YP=70G*2P@)R\G*2`N
M("==+R<L("1Q=65R>7-T<FEN9RP@+3$L(%!214=?4U!,251?3D]?14U05%DI
M.PT*("`@("`@("`D<F5T=7)N(#T@87)R87DH*3L-"@T*("`@("`@("!F;W)E
M86-H("@D<&%R=',@87,@)'!A<G0I('L-"B`@("`@("`@("`@(&EF("AS=')P
M;W,H)'!A<G0L("<])RD@(3T](&9A;'-E*2![#0H@("`@("`@("`@("`@("`@
M)'9A;'5E(#T@<W5B<W1R*"1P87)T+"!S=')P;W,H)'!A<G0L("<])RD@*R`Q
M*3L-"B`@("`@("`@("`@("`@("`D:V5Y("`@/2!S=6)S='(H)'!A<G0L(#`L
M('-T<G!O<R@D<&%R="P@)STG*2D[#0H@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("1V86QU92`](&YU;&P[#0H@("`@("`@("`@("`@
M("`@)&ME>2`@(#T@)'!A<G0[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!I9B`H<W5B<W1R*"1K97DL("TR*2`]/2`G6UTG*2![#0H@("`@("`@("`@
M("`@("`@)&ME>2`]('-U8G-T<B@D:V5Y+"`P+"`M,BD[#0H@("`@("`@("`@
M("`@("`@:68@*$`A:7-?87)R87DH)')E='5R;ELD:V5Y72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@)')E='5R;ELD:V5Y72`@(#T@87)R87DH*3L-"B`@
M("`@("`@("`@("`@("`@("`@)')E='5R;ELD:V5Y75M=(#T@)'9A;'5E.PT*
M("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@
M("1R971U<FY;)&ME>5U;72`]("1V86QU93L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!](&5L<V5I9B`H(21T:&ES+3YU<V5"<F%C:V5T<R!!
M3D0@(65M<'1Y*"1R971U<FY;)&ME>5TI*2![#0H@("`@("`@("`@("`@("`@
M)')E='5R;ELD:V5Y72`@(#T@*&%R<F%Y*21R971U<FY;)&ME>5T[#0H@("`@
M("`@("`@("`@("`@)')E='5R;ELD:V5Y75M=(#T@)'9A;'5E.PT*("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D<F5T=7)N6R1K97E=
M(#T@)'9A;'5E.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H-"B`@("`@
M("`@<F5T=7)N("1R971U<FX[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@*B!2
M97-O;'9E<R`O+RP@+BXO(&%N9"`N+R!F<F]M(&$@<&%T:"!A;F0@<F5T=7)N
M<PT*("`@("H@=&AE(')E<W5L="X@16<Z#0H@("`@*@T*("`@("H@+V9O;R]B
M87(O+BXO8F]O+G!H<"`@("`]/B`O9F]O+V)O;RYP:'`-"B`@("`J("]F;V\O
M8F%R+RXN+RXN+V)O;RYP:'`@/3X@+V)O;RYP:'`-"B`@("`J("]F;V\O8F%R
M+RXN+RXO+V)O;RYP:'`@/3X@+V9O;R]B;V\N<&AP#0H@("`@*@T*("`@("H@
M5&AI<R!M971H;V0@8V%N(&%L<V\@8F4@8V%L;&5D('-T871I8V%L;'DN#0H@
M("`@*@T*("`@("H@0'!A<F%M("!S=')I;F<@)'5R;"!54DP@<&%T:"!T;R!R
M97-O;'9E#0H@("`@*B!`<F5T=7)N('-T<FEN9R`@("`@(%1H92!R97-U;'0-
M"B`@("`J+PT*("`@(&9U;F-T:6]N(')E<V]L=F50871H*"1P871H*0T*("`@
M('L-"B`@("`@("`@)'!A=&@@/2!E>'!L;V1E*"<O)RP@<W1R7W)E<&QA8V4H
M)R\O)RP@)R\G+"`D<&%T:"DI.PT*#0H@("`@("`@(&9O<B`H)&D],#L@)&D\
M8V]U;G0H)'!A=&@I.R`D:2LK*2![#0H@("`@("`@("`@("!I9B`H)'!A=&A;
M)&E=(#T]("<N)RD@>PT*("`@("`@("`@("`@("`@('5N<V5T*"1P871H6R1I
M72D[#0H@("`@("`@("`@("`@("`@)'!A=&@@/2!A<G)A>5]V86QU97,H)'!A
M=&@I.PT*("`@("`@("`@("`@("`@("1I+2T[#0H-"B`@("`@("`@("`@('T@
M96QS96EF("@D<&%T:%LD:5T@/3T@)RXN)R!!3D0@*"1I(#X@,2!/4B`H)&D@
M/3T@,2!!3D0@)'!A=&A;,%T@(3T@)R<I("D@*2![#0H@("`@("`@("`@("`@
M("`@=6YS970H)'!A=&A;)&E=*3L-"B`@("`@("`@("`@("`@("!U;G-E="@D
M<&%T:%LD:2TQ72D[#0H@("`@("`@("`@("`@("`@)'!A=&@@/2!A<G)A>5]V
M86QU97,H)'!A=&@I.PT*("`@("`@("`@("`@("`@("1I("T](#([#0H-"B`@
M("`@("`@("`@('T@96QS96EF("@D<&%T:%LD:5T@/3T@)RXN)R!!3D0@)&D@
M/3T@,2!!3D0@)'!A=&A;,%T@/3T@)R<I('L-"B`@("`@("`@("`@("`@("!U
M;G-E="@D<&%T:%LD:5TI.PT*("`@("`@("`@("`@("`@("1P871H(#T@87)R
M87E?=F%L=65S*"1P871H*3L-"B`@("`@("`@("`@("`@("`D:2TM.PT*#0H@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H-"B`@("`@("`@<F5T=7)N
M(&EM<&QO9&4H)R\G+"`D<&%T:"D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M*B!2971U<FYS('1H92!S=&%N9&%R9"!P;W)T(&YU;6)E<B!F;W(@82!P<F]T
M;V-O;`T*("`@("H-"B`@("`J($!P87)A;2`@<W1R:6YG("`D<V-H96UE(%1H
M92!P<F]T;V-O;"!T;R!L;V]K=7`-"B`@("`J($!R971U<FX@:6YT96=E<B`@
M("`@("`@(%!O<G0@;G5M8F5R(&]R($Y53$P@:68@;F\@<V-H96UE(&UA=&-H
M97,-"B`@("`J#0H@("`@*B!`875T:&]R(%!H:6QI<'!E($IA=7-I;VYS(#Q0
M:&EL:7!P92Y*875S:6]N<T`Q,6%B86-U<RYC;VT^#0H@("`@*B\-"B`@("!F
M=6YC=&EO;B!G9713=&%N9&%R9%!O<G0H)'-C:&5M92D-"B`@("![#0H@("`@
M("`@('-W:71C:"`H<W1R=&]L;W=E<B@D<V-H96UE*2D@>PT*("`@("`@("`@
M("`@8V%S92`G:'1T<"<Z("`@(')E='5R;B`X,#L-"B`@("`@("`@("`@(&-A
M<V4@)VAT='!S)SH@("!R971U<FX@-#0S.PT*("`@("`@("`@("`@8V%S92`G
M9G1P)SH@("`@(')E='5R;B`R,3L-"B`@("`@("`@("`@(&-A<V4@)VEM87`G
M.B`@("!R971U<FX@,30S.PT*("`@("`@("`@("`@8V%S92`G:6UA<',G.B`@
M(')E='5R;B`Y.3,[#0H@("`@("`@("`@("!C87-E("=P;W`S)SH@("`@<F5T
M=7)N(#$Q,#L-"B`@("`@("`@("`@(&-A<V4@)W!O<#-S)SH@("!R971U<FX@
M.3DU.PT*("`@("`@("`@("`@9&5F875L=#H@("`@("`@(')E='5R;B!N=6QL
M.PT*("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`J($9O<F-E<R!T
M:&4@55),('1O(&$@<&%R=&EC=6QA<B!P<F]T;V-O;`T*("`@("H-"B`@("`J
M($!P87)A;2!S=')I;F<@("1P<F]T;V-O;"!0<F]T;V-O;"!T;R!F;W)C92!T
M:&4@55),('1O#0H@("`@*B!`<&%R86T@:6YT96=E<B`D<&]R="`@("`@3W!T
M:6]N86P@<&]R="`H<W1A;F1A<F0@<&]R="!I<R!U<V5D(&)Y(&1E9F%U;'0I
M#0H@("`@*B\-"B`@("!F=6YC=&EO;B!S9710<F]T;V-O;"@D<')O=&]C;VPL
M("1P;W)T(#T@;G5L;"D-"B`@("![#0H@("`@("`@("1T:&ES+3YP<F]T;V-O
M;"`]("1P<F]T;V-O;#L-"B`@("`@("`@)'1H:7,M/G!O<G0@/2!I<U]N=6QL
M*"1P;W)T*2`_("1T:&ES+3YG9713=&%N9&%R9%!O<G0H*2`Z("1P;W)T.PT*
M("`@('T-"@T*?0T*/SX-"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+TYE="]&5%`N<&AP````````````````````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`R,3(Q,C0@,3`U,34T,S,W,S,@,#(P,S8P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T
M:#TT('-O9G1T86)S=&]P/30Z("HO"@HO*BH*("H@3F5T7T944"!M86EN(&9I
M;&4N"B`J"B`J(%1H:7,@9FEL92!M=7-T(&)E(&EN8VQU9&5D('1O('5S92!T
M:&4@3F5T7T944"!P86-K86=E+@H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@
M-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@
M=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@
M879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F
M;VQL;W=I;F<@55)).@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S
M7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@
M=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T
M:')O=6=H('1H92!W96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E
M;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA
M=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@3F5T=V]R:VEN9PH@*B!`<&%C:V%G
M92`@("!&5%`*("H@0&%U=&AO<B`@("`@5&]B:6%S(%-C:&QI='0@/'1O8GE`
M<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O
M=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@($-64SH@
M)$ED.B!&5%`N<&AP+'8@,2XT,B`R,#`U+S`S+S,Q(#(P.C`W.C4X('1O8GD@
M17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K
M86=E+TYE=%]&5%`*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN
M8V4@4F5L96%S92`P+C`N,0H@*B\*"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G
M.PH*+RHJ"B`J($]P=&EO;B!T;R!L970@=&AE(&QS*"D@;65T:&]D(')E='5R
M;B!O;FQY(&9I;&5S+@H@*@H@*B!`<VEN8V4@,2XS"B`J($!N86UE($Y%5%]&
M5%!?1DE,15-?3TY,60H@*B!`<V5E($YE=%]&5%`Z.FQS*"D*("HO"F1E9FEN
M92@G3D547T944%]&24Q%4U]/3DQ9)RP@,"P@=')U92D["@HO*BH*("H@3W!T
M:6]N('1O(&QE="!T:&4@;',H*2!M971H;V0@<F5T=7)N(&]N;'D@9&ER96-T
M;W)I97,N"B`J"B`J($!S:6YC92`Q+C,*("H@0&YA;64@3D547T944%]$25)3
M7T].3%D*("H@0'-E92!.971?1E10.CIL<R@I"B`J+PID969I;F4H)TY%5%]&
M5%!?1$E24U]/3DQ9)RP@,2P@=')U92D["@HO*BH*("H@3W!T:6]N('1O(&QE
M="!T:&4@;',H*2!M971H;V0@<F5T=7)N(&1I<F5C=&]R:65S(&%N9"!F:6QE
M<R`H9&5F875L="DN"B`J"B`J($!S:6YC92`Q+C,*("H@0&YA;64@3D547T94
M4%]$25)37T9)3$53"B`J($!S964@3F5T7T944#HZ;',H*0H@*B\*9&5F:6YE
M*"=.151?1E107T1)4E-?1DE,15,G+"`R+"!T<G5E*3L*"B\J*@H@*B!/<'1I
M;VX@=&\@;&5T('1H92!L<R@I(&UE=&AO9"!R971U<FX@=&AE(')A=R!D:7)E
M8W1O<GD@;&ES=&EN9R!F<F]M(&9T<%]R87=L:7-T*"DN"B`J"B`J($!S:6YC
M92`Q+C,*("H@0&YA;64@3D547T944%]205=,25-4"B`J($!S964@3F5T7T94
M4#HZ;',H*0H@*B\*9&5F:6YE*"=.151?1E107U)!5TQ)4U0G+"`S+"!T<G5E
M*3L*"@HO*BH*("H@17)R;W(@8V]D92!T;R!I;F1I8V%T92!A(&9A:6QE9"!C
M;VYN96-T:6]N"B`J(%1H:7,@97)R;W(@8V]D92!I;F1I8V%T97,L('1H870@
M=&AE(&-O;FYE8W1I;VX@>6]U('1R>65D('1O('-E="!U<`H@*B!C;W5L9"!N
M;W0@8F4@97-T86)L:7-H960N($-H96-K('EO=7(@8V]N;F5C=&EO;B!S971T
M:6YG<R`H:&]S="`F('!O<G0I(0H@*@H@*B!`<VEN8V4@,2XS"B`J($!N86UE
M($Y%5%]&5%!?15)27T-/3DY%0U1?1D%)3$5$"B`J($!S964@3F5T7T944#HZ
M8V]N;F5C="@I"B`J+PID969I;F4H)TY%5%]&5%!?15)27T-/3DY%0U1?1D%)
M3$5$)RP@+3$I.PH*+RHJ"B`J($5R<F]R(&-O9&4@=&\@:6YD:6-A=&4@82!F
M86EL960@;&]G:6X*("H@5&AI<R!E<G)O<B!C;V1E(&EN9&EC871E<RP@=&AA
M="!T:&4@;&]G:6X@=&\@=&AE($944"!S97)V97(@9F%I;&5D+B!#:&5C:PH@
M*B!Y;W5R('5S97(@9&%T82`H=7-E<FYA;64@)B!P87-S=V]R9"DN"B`J"B`J
M($!S:6YC92`Q+C,*("H@0&YA;64@3D547T944%]%4E)?3$]'24Y?1D%)3$5$
M"B`J($!S964@3F5T7T944#HZ;&]G:6XH*0H@*B\*9&5F:6YE*"=.151?1E10
M7T524E],3T=)3E]&04E,140G+"`M,BD["@HO*BH*("H@17)R;W(@8V]D92!T
M;R!I;F1I8V%T92!A(&9A:6QE9"!D:7)E8W1O<GD@8VAA;F=E"B`J(%1H92!C
M9"@I(&UE=&AO9"!F86EL960N($5N<W5R92!T:&%T('1H92!D:7)E8W1O<GD@
M>6]U('=A;G1E9"!T;R!A8V-E<W,@97AI<W1S+@H@*@H@*B!`<VEN8V4@,2XS
M"B`J($!N86UE($Y%5%]&5%!?15)27T1)4D-(04Y'15]&04E,140*("H@0'-E
M92!.971?1E10.CIC9"@I"B`J+PID969I;F4H)TY%5%]&5%!?15)27T1)4D-(
M04Y'15]&04E,140G+"`R*3L@+R\@0V]M<&%T:6)I;&QI='D@<F5A<V]N<R$*
M"B\J*@H@*B!%<G)O<B!C;V1E('1O(&EN9&EC871E('1H870@3F5T7T944"!C
M;W5L9"!N;W0@9&5T97)M:6YE('1H92!C=7)R96YT('!A=&@*("H@5&AE(&-W
M9"@I(&UE=&AO9"!F86EL960@86YD(&-O=6QD(&YO="!D971E<FUI;F4@=&AE
M('!A=&@@>6]U(&-U<G)E;G1L>2!R97-I9&4*("H@:6X@;VX@=&AE($944"!S
M97)V97(N"B`J"B`J($!S:6YC92`Q+C,*("H@0&YA;64@3D547T944%]%4E)?
M1$5415)-24Y%4$%42%]&04E,140*("H@0'-E92!.971?1E10.CIP=V0H*0H@
M*B\*9&5F:6YE*"=.151?1E107T524E]$151%4DU)3D50051(7T9!24Q%1"<L
M(#0I.R`O+R!#;VUP871I8FEL;&ET>2!R96%S;VYS(0H*+RHJ"B`J($5R<F]R
M(&-O9&4@=&\@:6YD:6-A=&4@=&AA="!T:&4@8W)E871I;VX@;V8@82!D:7)E
M8W1O<GD@9F%I;&5D"B`J(%1H92!D:7)E8W1O<GD@>6]U('1R>65D('1O(&-R
M96%T92!C;W5L9"!N;W0@8F4@8W)E871E9"X@0VAE8VL@=&AE"B`J(&%C8V5S
M<R!R:6=H=',@;VX@=&AE('!A<F5N="!D:7)E8W1O<GDA"B`J"B`J($!S:6YC
M92`Q+C,*("H@0&YA;64@3D547T944%]%4E)?0U)%051%1$E27T9!24Q%1`H@
M*B!`<V5E($YE=%]&5%`Z.FUK9&ER*"D*("HO"F1E9FEN92@G3D547T944%]%
M4E)?0U)%051%1$E27T9!24Q%1"<L("TT*3L*"B\J*@H@*B!%<G)O<B!C;V1E
M('1O(&EN9&EC871E('1H870@=&AE($5814,@97AE8W5T:6]N(&9A:6QE9"X*
M("H@5&AE(&5X96-U=&EO;B!O9B!A(&-O;6UA;F0@=7-I;F<@15A%0R!F86EL
M960N($5N<W5R92P@=&AA="!Y;W5R"B`J($944"!S97)V97(@<W5P<&]R=',@
M=&AE($5814,@8V]M;6%N9"X*("H*("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.
M151?1E107T524E]%6$5#7T9!24Q%1`H@*B!`<V5E($YE=%]&5%`Z.F5X96-U
M=&4H*0H@*B\*9&5F:6YE*"=.151?1E107T524E]%6$5#7T9!24Q%1"<L("TU
M*3L*"B\J*@H@*B!%<G)O<B!C;V1E('1O(&EN9&EC871E('1H870@=&AE(%-)
M5$4@8V]M;6%N9"!F86EL960N"B`J(%1H92!E>&5C=71I;VX@;V8@82!C;VUM
M86YD('5S:6YG(%-)5$4@9F%I;&5D+B!%;G-U<F4L('1H870@>6]U<@H@*B!&
M5%`@<V5R=F5R('-U<'!O<G1S('1H92!3251%(&-O;6UA;F0N"B`J"B`J($!S
M:6YC92`Q+C,*("H@0&YA;64@3D547T944%]%4E)?4TE415]&04E,140*("H@
M0'-E92!.971?1E10.CIS:71E*"D*("HO"F1E9FEN92@G3D547T944%]%4E)?
M4TE415]&04E,140G+"`M-BD["@HO*BH*("H@17)R;W(@8V]D92!T;R!I;F1I
M8V%T92!T:&%T('1H92!#2$U/1"!C;VUM86YD(&9A:6QE9"X*("H@5&AE(&5X
M96-U=&EO;B!O9B!#2$U/1"!F86EL960N($5N<W5R92P@=&AA="!Y;W5R"B`J
M($944"!S97)V97(@<W5P<&]R=',@=&AE($-(34]$(&-O;6UA;F0@86YD('1H
M870@>6]U(&AA=F4@=&AE(&%P<')O<')I871E"B`J(&%C8V5S<R!R:6=H=',@
M=&\@=7-E($-(34]$+@H@*@H@*B!`<VEN8V4@,2XS"B`J($!N86UE($Y%5%]&
M5%!?15)27T-(34]$7T9!24Q%1`H@*B!`<V5E($YE=%]&5%`Z.F-H;6]D*"D*
M("HO"F1E9FEN92@G3D547T944%]%4E)?0TA-3T1?1D%)3$5$)RP@+3<I.PH*
M+RHJ"B`J($5R<F]R(&-O9&4@=&\@:6YD:6-A=&4@=&AA="!A(&9I;&4@<F5N
M86UE(&9A:6QE9`H@*B!4:&4@<F5N86UI;F<@;V8@82!F:6QE(&]N('1H92!S
M97)V97(@9F%I;&5D+B!%;G-U<F4@=&AA="!Y;W4@:&%V92!T:&4*("H@87!P
M<F]P<FEA=&4@86-C97-S(')I9VAT<R!T;R!R96YA;64@=&AE(&9I;&4N"B`J
M"B`J($!S:6YC92`Q+C,*("H@0&YA;64@3D547T944%]%4E)?4D5.04U%7T9!
M24Q%1`H@*B!`<V5E($YE=%]&5%`Z.G)E;F%M92@I"B`J+PID969I;F4H)TY%
M5%]&5%!?15)27U)%3D%-15]&04E,140G+"`M."D["@HO*BH*("H@17)R;W(@
M8V]D92!T;R!I;F1I8V%T92!T:&%T('1H92!-1%1-(&-O;6UA;F0@9F%I;&5D
M"B`J(%1H92!-1%1-(&-O;6UA;F0@:7,@;F]T('-U<'!O<G1E9"!F;W(@9&ER
M96-T;W)I97,N($5N<W5R92!T:&%T('EO=2!G879E"B`J(&$@9FEL92!P871H
M('1O('1H92!M9'1M*"D@;65T:&]D+"!N;W0@82!D:7)E8W1O<GD@<&%T:"X*
M("H*("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.151?1E107T524E]-1%1-1$E2
M7U5.4U504$]25$5$"B`J($!S964@3F5T7T944#HZ;61T;2@I"B`J+PID969I
M;F4H)TY%5%]&5%!?15)27TU$5$U$25)?54Y355!03U)4140G+"`M.2D["@HO
M*BH*("H@17)R;W(@8V]D92!T;R!I;F1I8V%T92!T:&%T('1H92!-1%1-(&-O
M;6UA;F0@9F%I;&5D"B`J(%1H92!-1%1-(&-O;6UA;F0@9F%I;&5D+B!%;G-U
M<F4@=&AA="!Y;W5R('-E<G9E<B!S=7!P;W)T<R!T:&4@341432!C;VUM86YD
M+@H@*@H@*B!`<VEN8V4@,2XS"B`J($!N86UE($Y%5%]&5%!?15)27TU$5$U?
M1D%)3$5$"B`J($!S964@3F5T7T944#HZ;61T;2@I"B`J+PID969I;F4H)TY%
M5%]&5%!?15)27TU$5$U?1D%)3$5$)RP@+3$P*3L*"B\J*@H@*B!%<G)O<B!C
M;V1E('1O(&EN9&EC871E('1H870@82!D871E(')E='5R;F5D(&)Y('1H92!S
M97)V97(@=V%S(&UI<V9O<FUA=&5D"B`J($$@9&%T92!S=')I;F<@<F5T=7)N
M960@8GD@>6]U<B!S97)V97(@<V5E;7,@=&\@8F4@;6ES<V9O<FUA=&5D(&%N
M9"!C;W5L9"!N;W0@8F4*("H@<&%R<V5D+B!#:&5C:R!T:&%T('1H92!S97)V
M97(@:7,@8V]N9FEG=7)E9"!C;W)R96-T;'DN($EF('EO=2=R92!S=7)E+"!P
M;&5A<V4*("H@<V5N9"!A;B!E;6%I;"!T;R!T:&4@875H=&]R('=I=&@@82!D
M=6UP960@;W5T<'5T(&]F("1F='`M/FQS*"<N+R<L($Y%5%]&5%!?4D%73$E3
M5"D["B`J('1O(&=E="!T:&4@9&%T92!F;W)M870@<W5P<&]R=&5D+@H@*@H@
M*B!`<VEN8V4@,2XS"B`J($!N86UE($Y%5%]&5%!?15)27T1!5$5&3U)-051?
M1D%)3$5$"B`J($!S964@3F5T7T944#HZ;61T;2@I+"!.971?1E10.CIL<R@I
M"B`J+PID969I;F4H)TY%5%]&5%!?15)27T1!5$5&3U)-051?1D%)3$5$)RP@
M+3$Q*3L*"B\J*@H@*B!%<G)O<B!C;V1E('1O(&EN9&EC871E('1H870@=&AE
M(%-)6D4@8V]M;6%N9"!F86EL960*("H@5&AE(&1E=&5R;6EN871I;VX@;V8@
M=&AE(&9I;&5S:7IE(&]F(&$@9FEL92!F86EL960N($5N<W5R92!T:&%T('EO
M=7(@<V5R=F5R('-U<'!O<G1S('1H90H@*B!325I%(&-O;6UA;F0N"B`J"B`J
M($!S:6YC92`Q+C,*("H@0&YA;64@3D547T944%]%4E)?4TE:15]&04E,140*
M("H@0'-E92!.971?1E10.CIS:7IE*"D*("HO"F1E9FEN92@G3D547T944%]%
M4E)?4TE:15]&04E,140G+"`M,3(I.PH*+RHJ"B`J($5R<F]R(&-O9&4@=&\@
M:6YD:6-A=&4@=&AA="!A(&QO8V%L(&9I;&4@8V]U;&0@;F]T(&)E(&]V97)W
M<FET=&5N"B`J(%EO=2!S<&5C:69I960@;F]T('1O(&]V97)W<FET92!F:6QE
M<RX@5&AE<F5F;W)E('1H92!L;V-A;"!F:6QE(&AA<R!N;W0@8F5E;@H@*B!O
M=F5R=W)I=&5N+B!)9B!Y;W4@=V%N="!T;R!G970@=&AE(&9I;&4@;W9E<G=R
M:71E;BP@<&QE87-E('-E="!T:&4@;W!T:6]N('1O"B`J(&1O('-O+@H@*@H@
M*B!`<VEN8V4@,2XS"B`J($!N86UE($Y%5%]&5%!?15)27T]615)74DE414Q/
M0T%,1DE,15]&3U)"241$14X*("H@0'-E92!.971?1E10.CIG970H*2P@3F5T
M7T944#HZ9V5T4F5C=7)S:79E*"D*("HO"F1E9FEN92@G3D547T944%]%4E)?
M3U9%4E=2251%3$]#04Q&24Q%7T9/4D))1$1%3B<L("TQ,RD["@HO*BH*("H@
M17)R;W(@8V]D92!T;R!I;F1I8V%T92!T:&%T(&$@;&]C86P@9FEL92!C;W5L
M9"!N;W0@8F4@;W9E<G=R:71T96X*("H@06QS;R!Y;W4@<W!E8VEF:65D('1O
M(&]V97)W<FET92!T:&4@;&]C86P@9FEL92!Y;W4@=V%N="!T;R!D;W=N;&]A
M9"!T;RP*("H@:70@:&%S(&YO="!B965N('!O<W-I8FQE('1O(&1O('-O+B!#
M:&5C:R!T:&%T('EO=2!H879E('1H92!A<'!R;W!R:6%T92!A8V-E<W,*("H@
M<FEG:'1S(&]N('1H92!L;V-A;"!F:6QE('1O(&]V97)W<FET92!I="X*("H*
M("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.151?1E107T524E]/5D525U))5$5,
M3T-!3$9)3$5?1D%)3$5$"B`J($!S964@3F5T7T944#HZ9V5T*"DL($YE=%]&
M5%`Z.F=E=%)E8W5R<VEV92@I"B`J+PID969I;F4H)TY%5%]&5%!?15)27T]6
M15)74DE414Q/0T%,1DE,15]&04E,140G+"`M,30I.PH*+RHJ"B`J($5R<F]R
M(&-O9&4@=&\@:6YD:6-A=&4@=&AA="!T:&4@9FEL92!Y;W4@=V%N=&5D('1O
M('5P;&]A9"!D;V5S(&YO="!E>&ES=`H@*B!4:&4@9FEL92!Y;W4@=')I960@
M=&\@=7!L;V%D(&1O97,@;F]T(&5X:7-T+B!%;G-U<F4@=&AA="!I="!E>&ES
M=',N"B`J"B`J($!S:6YC92`Q+C,*("H@0&YA;64@3D547T944%]%4E)?3$]#
M04Q&24Q%3D]415A)4U0*("H@0'-E92!.971?1E10.CIP=70H*2P@3F5T7T94
M4#HZ<'5T4F5C=7)S:79E*"D*("HO"F1E9FEN92@G3D547T944%]%4E)?3$]#
M04Q&24Q%3D]415A)4U0G+"`M,34I.PH*+RHJ"B`J($5R<F]R(&-O9&4@=&\@
M:6YD:6-A=&4@=&AA="!A(')E;6]T92!F:6QE(&-O=6QD(&YO="!B92!O=F5R
M=W)I='1E;@H@*B!9;W4@<W!E8VEF:65D(&YO="!T;R!O=F5R=W)I=&4@9FEL
M97,N(%1H97)E9F]R92!T:&4@<F5M;W1E(&9I;&4@:&%S(&YO="!B965N"B`J
M(&]V97)W<FET96XN($EF('EO=2!W86YT('1O(&=E="!T:&4@9FEL92!O=F5R
M=W)I=&5N+"!P;&5A<V4@<V5T('1H92!O<'1I;VX@=&\*("H@9&\@<V\N"B`J
M"B`J($!S:6YC92`Q+C,*("H@0&YA;64@3D547T944%]%4E)?3U9%4E=2251%
M4D5-3U1%1DE,15]&3U)"241$14X*("H@0'-E92!.971?1E10.CIP=70H*2P@
M3F5T7T944#HZ<'5T4F5C=7)S:79E*"D*("HO"F1E9FEN92@G3D547T944%]%
M4E)?3U9%4E=2251%4D5-3U1%1DE,15]&3U)"241$14XG+"`M,38I.PH*+RHJ
M"B`J($5R<F]R(&-O9&4@=&\@:6YD:6-A=&4@=&AA="!T:&4@=7!L;V%D(&]F
M(&$@9FEL92!F86EL960*("H@5&AE('5P;&]A9"!Y;W4@=')I960@9F%I;&5D
M+B!%;G-U<F4@=&AA="!Y;W4@:&%V92!A<'!R;W!R:6%T92!A8V-E<W,@<FEG
M:'1S"B`J('1O('5P;&]A9"!T:&4@9&5S:7)E9"!F:6QE+@H@*@H@*B!`<VEN
M8V4@,2XS"B`J($!N86UE($Y%5%]&5%!?15)27U503$]!1$9)3$5?1D%)3$5$
M"B`J($!S964@3F5T7T944#HZ<'5T*"DL($YE=%]&5%`Z.G!U=%)E8W5R<VEV
M92@I"B`J+PID969I;F4H)TY%5%]&5%!?15)27U503$]!1$9)3$5?1D%)3$5$
M)RP@+3$W*3L*"B\J*@H@*B!%<G)O<B!C;V1E('1O(&EN9&EC871E('1H870@
M>6]U('-P96-I9FEE9"!A;B!I;F-O<G)E8W0@9&ER96-T;W)Y('!A=&@*("H@
M5&AE(')E;6]T92!P871H('EO=2!S<&5C:69I960@<V5E;7,@;F]T('1O(&)E
M(&$@9&ER96-T;W)Y+B!%;G-U<F4@=&AA=`H@*B!T:&4@<&%T:"!Y;W4@<W!E
M8VEF>2!I<R!A(&1I<F5C=&]R>2!A;F0@=&AA="!T:&4@<&%T:"!S=')I;F<@
M96YD<R!W:71H"B`J(&$@+RX*("H*("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.
M151?1E107T524E]214U/5$50051(3D]$25(*("H@0'-E92!.971?1E10.CIP
M=71296-U<G-I=F4H*2P@3F5T7T944#HZ9V5T4F5C=7)S:79E*"D*("HO"F1E
M9FEN92@G3D547T944%]%4E)?4D5-3U1%4$%42$Y/1$E2)RP@+3$X*3L*"B\J
M*@H@*B!%<G)O<B!C;V1E('1O(&EN9&EC871E('1H870@>6]U('-P96-I9FEE
M9"!A;B!I;F-O<G)E8W0@9&ER96-T;W)Y('!A=&@*("H@5&AE(&QO8V%L('!A
M=&@@>6]U('-P96-I9FEE9"!S965M<R!N;W0@=&\@8F4@82!D:7)E8W1O<GDN
M($5N<W5R92!T:&%T"B`J('1H92!P871H('EO=2!S<&5C:69Y(&ES(&$@9&ER
M96-T;W)Y(&%N9"!T:&%T('1H92!P871H('-T<FEN9R!E;F1S('=I=&@*("H@
M82`O+@H@*@H@*B!`<VEN8V4@,2XS"B`J($!N86UE($Y%5%]&5%!?15)27TQ/
M0T%,4$%42$Y/1$E2"B`J($!S964@3F5T7T944#HZ<'5T4F5C=7)S:79E*"DL
M($YE=%]&5%`Z.F=E=%)E8W5R<VEV92@I"B`J+PID969I;F4H)TY%5%]&5%!?
M15)27TQ/0T%,4$%42$Y/1$E2)RP@+3$Y*3L*"B\J*@H@*B!%<G)O<B!C;V1E
M('1O(&EN9&EC871E('1H870@82!L;V-A;"!D:7)E8W1O<GD@9F%I;&5D('1O
M(&)E(&-R96%T960*("H@66]U('1R:65D('1O(&-R96%T92!A(&QO8V%L(&1I
M<F5C=&]R>2!T:')O=6=H(&=E=%)E8W5R<VEV92@I(&UE=&AO9"P*("H@=VAI
M8V@@:&%S(&9A:6QE9"X@16YS=7)E('1H870@>6]U(&AA=F4@=&AE(&%P<')O
M<')I871E(&%C8V5S<R!R:6=H=',*("H@=&\@8W)E871E(&ET+@H@*@H@*B!`
M<VEN8V4@,2XS"B`J($!N86UE($Y%5%]&5%!?15)27T-214%414Q/0T%,1$E2
M7T9!24Q%1`H@*B!`<V5E($YE=%]&5%`Z.F=E=%)E8W5R<VEV92@I"B`J+PID
M969I;F4H)TY%5%]&5%!?15)27T-214%414Q/0T%,1$E27T9!24Q%1"<L("TR
M,"D["@HO*BH*("H@17)R;W(@8V]D92!T;R!I;F1I8V%T92!T:&%T('1H92!P
M<F]V:61E9"!H;W-T;F%M92!W87,@:6YC;W)R96-T"B`J(%1H92!H;W-T;F%M
M92!Y;W4@<')O=FED960@=V%S(&EN=F%L:60N($5N<W5R92!T;R!P<F]V:61E
M(&5I=&AE<B!A"B`J(&9U;&P@<75A;&EF:65D(&1O;6%I;B!N86UE(&]R(&%N
M($E0(&%D9')E<W,N"B`J"B`J($!S:6YC92`Q+C,*("H@0&YA;64@3D547T94
M4%]%4E)?2$]35$Y!345.3U-44DE.1PH@*B!`<V5E($YE=%]&5%`Z.G-E=$AO
M<W1N86UE*"D*("HO"F1E9FEN92@G3D547T944%]%4E)?2$]35$Y!345.3U-4
M4DE.1R<L("TR,2D["@HO*BH*("H@17)R;W(@8V]D92!T;R!I;F1I8V%T92!T
M:&%T('1H92!P<F]V:61E9"!P;W)T('=A<R!I;F-O<G)E8W0*("H@5&AE('!O
M<G0@;G5M8F5R('EO=2!P<F]V:61E9"!W87,@:6YV86QI9"X@16YS=7)E('1O
M('!R;W9I9&4@96ET:&5R(&$*("H@82!N=6UE<FEC('!O<G0@;G5M8F5R(&=R
M96%T97(@>F5R;RX*("H*("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.151?1E10
M7T524E]03U)43$534UI%4D\*("H@0'-E92!.971?1E10.CIS9710;W)T*"D*
M("HO"F1E9FEN92@G3D547T944%]%4E)?4$]25$Q%4U-:15)/)RP@+3(R*3L*
M"B\J*@H@*B!%<G)O<B!C;V1E('1O(&EN9&EC871E('1H870@>6]U('!R;W9I
M9&5D(&%N(&EN=F%L:60@;6]D92!C;VYS=&%N=`H@*B!4:&4@;6]D92!C;VYS
M=&%N="!Y;W4@<')O=FED960@=V%S(&EN=F%L:60N(%EO=2!M87D@;VYL>2!P
M<F]V:61E"B`J($944%]!4T-)22!O<B!&5%!?0DE.05)9+@H@*@H@*B!`<VEN
M8V4@,2XS"B`J($!N86UE($Y%5%]&5%!?15)27TY/34]$14-/3E-4"B`J($!S
M964@3F5T7T944#HZ<V5T36]D92@I"B`J+PID969I;F4H)TY%5%]&5%!?15)2
M7TY/34]$14-/3E-4)RP@+3(S*3L*"B\J*@H@*B!%<G)O<B!C;V1E('1O(&EN
M9&EC871E('1H870@>6]U('!R;W9I9&5D(&%N(&EN=F%L:60@=&EM96]U=`H@
M*B!4:&4@=&EM96]U="!Y;W4@<')O=FED960@=V%S(&EN=F%L:60N(%EO=2!H
M879E('1O('!R;W9I9&4@82!T:6UE;W5T(&=R96%T97(*("H@;W(@97%U86P@
M=&\@>F5R;RX*("H*("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.151?1E107T52
M4E]424U%3U543$534UI%4D\*("H@0'-E92!.971?1E10.CI.971?1E10*"DL
M($YE=%]&5%`Z.G-E=%1I;65O=70H*0H@*B\*9&5F:6YE*"=.151?1E107T52
M4E]424U%3U543$534UI%4D\G+"`M,C0I.PH*+RHJ"B`J($5R<F]R(&-O9&4@
M=&\@:6YD:6-A=&4@=&AA="!Y;W4@<')O=FED960@86X@:6YV86QI9"!T:6UE
M;W5T"B`J($%N(&5R<F]R(&]C8W5R960@=VAI;&4@<V5T=&EN9R!T:&4@=&EM
M96]U="X@16YS=7)E('1H870@>6]U('!R;W9I9&4@80H@*B!V86QI9"!I;G1E
M9V5R(&9O<B!T:&4@=&EM96]U;G0@86YD('1H870@>6]U<B!02%`@:6YS=&%L
M;&%T:6]N('=O<FMS"B`J(&-O<G)E8W1L>2X*("H*("H@0'-I;F-E(#$N,PH@
M*B!`;F%M92!.151?1E107T524E]3151424U%3U547T9!24Q%1`H@*B!`<V5E
M($YE=%]&5%`Z.DYE=%]&5%`H*2P@3F5T7T944#HZ<V5T5&EM96]U="@I"B`J
M+PID969I;F4H)TY%5%]&5%!?15)27U-%5%1)345/551?1D%)3$5$)RP@+3(U
M*3L*"B\J*@H@*B!%<G)O<B!C;V1E('1O(&EN9&EC871E('1H870@=&AE('!R
M;W9I9&5D(&5X=&5N<VEO;B!F:6QE(&1O97-N)W0@97AI<W0*("H@5&AE('!R
M;W9I9&5D(&5X=&5N<VEO;B!F:6QE(&1O97,@;F]T(&5X:7-T+B!%;G-U<F4@
M=&\@<')O=FED960@86X*("H@97AI<W1A;G0@97AT96YS:6]N(&9I;&4N"B`J
M"B`J($!S:6YC92`Q+C,*("H@0&YA;64@3D547T944%]%4E)?15A41DE,14Y/
M5$5825-4"B`J($!S964@3F5T7T944#HZ9V5T17AT96YS:6]N1FEL92@I"B`J
M+PID969I;F4H)TY%5%]&5%!?15)27T585$9)3$5.3U1%6$E35"<L("TR-BD[
M"@HO*BH*("H@17)R;W(@8V]D92!T;R!I;F1I8V%T92!T:&%T('1H92!P<F]V
M:61E9"!E>'1E;G-I;VX@9FEL92!I<R!N;W0@<F5A9&%B;&4*("H@5&AE('!R
M;W9I9&5D(&5X=&5N<VEO;B!F:6QE(&ES(&YO="!R96%D86)L92X@16YS=7)E
M('1O(&AA=F4@<W5F9FEC:65N=`H@*B!A8V-E<W,@<FEG:'1S(&9O<B!I="X*
M("H*("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.151?1E107T524E]%6%1&24Q%
M4D5!1%]&04E,140*("H@0'-E92!.971?1E10.CIG971%>'1E;G-I;VY&:6QE
M*"D*("HO"F1E9FEN92@G3D547T944%]%4E)?15A41DE,15)%041?1D%)3$5$
M)RP@+3(W*3L*"B\J*@H@*B!%<G)O<B!C;V1E('1O(&EN9&EC871E('1H870@
M=&AE(&1E;&5T:6]N(&]F(&$@9FEL92!F86EL960*("H@5&AE('-P96-I9FEE
M9"!F:6QE(&-O=6QD(&YO="!B92!D96QE=&5D+B!%;G-U<F4@=&\@:&%V92!S
M=69F:6-I96YT"B`J(&%C8V5S<R!R:6=H=',@=&\@9&5L971E('1H92!F:6QE
M+@H@*@H@*B!`<VEN8V4@,2XS"B`J($!N86UE($Y%5%]&5%!?15)27T585$9)
M3$5214%$7T9!24Q%1`H@*B!`<V5E($YE=%]&5%`Z.G)M*"D*("HO"F1E9FEN
M92@G3D547T944%]%4E)?1$5,151%1DE,15]&04E,140G+"`M,C@I.PH*+RHJ
M"B`J($5R<F]R(&-O9&4@=&\@:6YD:6-A=&4@=&AA="!T:&4@9&5L971I;VX@
M;V8@82!D:7)E8W1O<GD@9F%I;&0*("H@5&AE('-P96-I9FEE9"!F:6QE(&-O
M=6QD(&YO="!B92!D96QE=&5D+B!%;G-U<F4@=&\@:&%V92!S=69F:6-I96YT
M"B`J(&%C8V5S<R!R:6=H=',@=&\@9&5L971E('1H92!F:6QE+@H@*@H@*B!`
M<VEN8V4@,2XS"B`J($!N86UE($Y%5%]&5%!?15)27T585$9)3$5214%$7T9!
M24Q%1`H@*B!`<V5E($YE=%]&5%`Z.G)M*"D*("HO"F1E9FEN92@G3D547T94
M4%]%4E)?1$5,151%1$E27T9!24Q%1"<L("TR.2D["@HO*BH*("H@17)R;W(@
M8V]D92!T;R!I;F1I8V%T92!T:&%T('1H92!D:7)E8W1O<GD@;&ES=&EN9R!F
M86EL960*("H@4$A0(&-O=6QD(&YO="!L:7-T('1H92!D:7)E8W1O<GD@8V]N
M=&5N=',@;VX@=&AE('-E<G9E<BX@16YS=7)E"B`J('1H870@>6]U<B!S97)V
M97(@:7,@8V]N9FEG=7)E9"!A<'!R;W!R:6%T92X*("H*("H@0'-I;F-E(#$N
M,PH@*B!`;F%M92!.151?1E107T524E]205=$25),25-47T9!24Q%1`H@*B!`
M<V5E($YE=%]&5%`Z.FQS*"D*("HO"F1E9FEN92@G3D547T944%]%4E)?4D%7
M1$E23$E35%]&04E,140G+"`M,S`I.PH*+RHJ"B`J($5R<F]R(&-O9&4@=&\@
M:6YD:6-A=&4@=&AA="!T:&4@9&ER96-T;W)Y(&QI<W1I;F<@9F%I;&5D"B`J
M(%1H92!D:7)E8W1O<GD@;&ES=&EN9R!F;W)M870@>6]U<B!S97)V97(@=7-E
M<R!S965M<R!N;W0@=&\*("H@8F4@<W5P<&]R=&5D(&)Y($YE=%]&5%`N(%!L
M96%S92!S96YD('1H92!O=71P=70@;V8@=&AE"B`J(&-A;&P@;',H)RXO)RP@
M3D547T944%]205=,25-4*3L@=&\@=&AE(&%U=&AO<B!O9B!T:&ES"B`J(&-L
M87-S('1O(&=E="!I="!S=7!P;W)T960N"B`J"B`J($!S:6YC92`Q+C,*("H@
M0&YA;64@3D547T944%]%4E)?1$E23$E35%]53E-54%!/4E1%1`H@*B!`<V5E
M($YE=%]&5%`Z.FQS*"D*("HO"F1E9FEN92@G3D547T944%]%4E)?1$E23$E3
M5%]53E-54%!/4E1%1"<L("TS,2D["@HO*BH*("H@17)R;W(@8V]D92!T;R!I
M;F1I8V%T92!F86EL960@9&ES8V]N;F5C=&EN9PH@*B!4:&ES(&5R<F]R(&-O
M9&4@:6YD:6-A=&5S+"!T:&%T(&1I<V-O;FYE8W1I;VX@=V%S(&YO="!P;W-S
M:6)L92X*("H*("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.151?1E107T524E]$
M25-#3TY.14-47T9!24Q%1`H@*B!`<V5E($YE=%]&5%`Z.F1I<V-O;FYE8W0H
M*0H@*B\*9&5F:6YE*"=.151?1E107T524E]$25-#3TY.14-47T9!24Q%1"<L
M("TS,BD["@HO*BH*("H@17)R;W(@8V]D92!T;R!I;F1I8V%T92!T:&%T('1H
M92!U<V5R;F%M92!Y;W4@<')O=FED960@=V%S(&EN=F%L:60N"B`J($-H96-K
M('1H870@>6]U('!R;W9I9&5D(&$@;F]N+65M<'1Y('-T<FEN9R!A<R!T:&4@
M=7-E<FYA;64N"B`J"B`J($!S:6YC92`Q+C,*("H@0&YA;64@3D547T944%]%
M4E)?55-%4DY!345.3U-44DE.1PH@*B!`<V5E($YE=%]&5%`Z.G-E=%5S97)N
M86UE*"D*("HO"F1E9FEN92@G3D547T944%]%4E)?55-%4DY!345.3U-44DE.
M1R<L("TS,RD["@HO*BH*("H@17)R;W(@8V]D92!T;R!I;F1I8V%T92!T:&%T
M('1H92!U<V5R;F%M92!Y;W4@<')O=FED960@=V%S(&EN=F%L:60N"B`J($-H
M96-K('1H870@>6]U('!R;W9I9&5D(&$@;F]N+65M<'1Y('-T<FEN9R!A<R!T
M:&4@=7-E<FYA;64N"B`J"B`J($!S:6YC92`Q+C,*("H@0&YA;64@3D547T94
M4%]%4E)?4$%34U=/4D1.3U-44DE.1PH@*B!`<V5E($YE=%]&5%`Z.G-E=%!A
M<W-W;W)D*"D*("HO"F1E9FEN92@G3D547T944%]%4E)?4$%34U=/4D1.3U-4
M4DE.1R<L("TS,RD["@HO*BH*("H@0VQA<W,@9F]R(&-O;69O<G1A8FQE($94
M4"UC;VUM=6YI8V%T:6]N"B`J"B`J(%1H:7,@8VQA<W,@<')O=FED97,@8V]M
M9F]R=&%B;&4@8V]M;75N:6-A=&EO;B!W:71H($944"US97)V97)S+B!9;W4@
M;6%Y(&1O(&5V97)Y=&AI;F<*("H@96YA8FQE9"!B>2!T:&4@4$A0+4944"UE
M>'1E;G-I;VX@86YD(&9U<G1H97(@9G5N8W1I;VYA;&ET:65S+"!L:6ME(')E
M8W5R<VEV92UD96QE=&EO;BP*("H@+75P+2!A;F0@+61O=VYL;V%D+B!!;F]T
M:&5R(&9E871U<F4@:7,@=&\@8W)E871E(&1I<F5C=&]R:65S(')E8W5R<VEV
M96QY+@H@*@H@*B!`;&EC96YS92`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`8V%T96=O<GD@($YE
M='=O<FMI;F<*("H@0'!A8VMA9V4@("!&5%`*("H@0&%U=&AO<B`@("!4;V)I
M87,@4V-H;&ET="`\=&]B>4!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT(#$Y.3<M
M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!V97)S:6]N("`@4F5L96%S93H@,2XS
M+C$*("H@0&QI;FL@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O
M3F5T7T944`H@*B!`<VEN8V4@("`@(#`N,"XQ"B`J($!A8V-E<W,@("`@<'5B
M;&EC"B`J+PIC;&%S<R!.971?1E10(&5X=&5N9',@4$5!4B`*>PH@("`@+RHJ
M"B`@("`@*B!4:&4@:&]S="!T;R!C;VYN96-T('1O"B`@("`@*@H@("`@("H@
M0&%C8V5S<R`@<')I=F%T90H@("`@("H@0'9A<B`@("`@<W1R:6YG"B`@("`@
M*B\*("`@(`H@("`@=F%R("1?:&]S=&YA;64["@H@("`@+RHJ"B`@("`@*B!4
M:&4@<&]R="!F;W(@9G1P+6-O;FYE8W1I;VX@*'-T86YD87)D(&ES(#(Q*0H@
M("`@("H*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J($!V87(@("`@
M(&EN=`H@("`@("HO"B`@("`*("`@('9A<B`D7W!O<G0@/2`R,3L*"B`@("`O
M*BH*("`@("`J(%1H92!U<V5R;F%M92!F;W(@;&]G:6X*("`@("`J"B`@("`@
M*B!`86-C97-S("!P<FEV871E"B`@("`@*B!`=F%R("`@("!S=')I;F<*("`@
M("`J+PH@("`@"B`@("!V87(@)%]U<V5R;F%M93L*"B`@("`O*BH*("`@("`J
M(%1H92!P87-S=V]R9"!F;W(@;&]G:6X*("`@("`J"B`@("`@*B!`86-C97-S
M("!P<FEV871E"B`@("`@*B!`=F%R("`@("!S=')I;F<*("`@("`J+PH@("`@
M"B`@("!V87(@)%]P87-S=V]R9#L*"B`@("`O*BH*("`@("`J($1E=&5R;6EN
M92!W:&5T:&5R('1O('5S92!P87-S:79E+6UO9&4@*'1R=64I(&]R(&%C=&EV
M92UM;V1E("AF86QS92D*("`@("`J"B`@("`@*B!`86-C97-S("!P<FEV871E
M"B`@("`@*B!`=F%R("`@("!B;V]L"B`@("`@*B\*("`@(`H@("`@=F%R("1?
M<&%S<W8["@H@("`@+RHJ"B`@("`@*B!4:&4@<W1A;F1A<F0@;6]D92!F;W(@
M9G1P+71R86YS9F5R"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@
M("`@("H@0'9A<B`@("`@:6YT"B`@("`@*B\*("`@(`H@("`@=F%R("1?;6]D
M92`]($944%]"24Y!4ED["@H@("`@+RHJ"B`@("`@*B!4:&ES(&AO;&1S('1H
M92!H86YD;&4@9F]R('1H92!F='`M8V]N;F5C=&EO;@H@("`@("H*("`@("`J
M($!A8V-E<W,@('!R:79A=&4*("`@("`J($!V87(@("`@(')E<V]U<F-E"B`@
M("`@*B\*("`@(`H@("`@=F%R("1?:&%N9&QE.PH*("`@("\J*@H@("`@("H@
M0V]N=&%I;G,@=&AE('1I;65O=70@9F]R($944"!O<&5R871I;VYS"B`@("`@
M*@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("H@0'9A<B`@("`@:6YT
M"B`@("`@*B!`<VEN8V4@("`Q+C,*("`@("`J+PH@("`@"B`@("!V87(@)%]T
M:6UE;W5T(#T@.3`["B`@("`@("`@"B`@("`O*BH*("`@("`J(%-A=F5S(&9I
M;&4M97AT96YS:6]N<R!F;W(@87-C:6DM(&%N9"!B:6YA<GDM;6]D90H@("`@
M("H*("`@("`J(%1H92!A<G)A>2!C;VYT86EN<R`R('-U8BUA<G)A>7,@*")A
M<V-I:2(@86YD(")B:6YA<GDB*2P@=VAI8V@@8F]T:"!C;VYT86EN"B`@("`@
M*B!F:6QE+65X=&5N<VEO;G,@=VET:&]U="!T:&4@(BXB("@B+G!H<"(@/2`B
M<&AP(BDN"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("H@
M0'9A<B`@("`@87)R87D*("`@("`J+PH@("`@"B`@("!V87(@)%]F:6QE7V5X
M=&5N<VEO;G,["@H@("`@+RHJ"B`@("`@*B!L<R!M871C:`H@("`@("H@36%T
M8VAE<R!T:&4@;',@96YT<FEE<R!A9V%I;G-T(&$@<F5G97@@86YD(&UA<',@
M=&AE(')E<W5L=&EN9R!A<G)A>2!T;R!S<&5A:VEN9R!N86UE<PH@("`@("H*
M("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J($!V87(@("`@(&%R<F%Y
M"B`@("`@*B!`<VEN8V4@("`Q+C,*("`@("`J+PH@("`@"B`@("!V87(@)%]L
M<U]M871C:"`](&%R<F%Y*`H@("`@("`@("=U;FEX)R`@("`]/B!A<G)A>2@*
M("`@("`@("`@("`@)W!A='1E<FXG(#T^("<O*#\Z*&0I?"XI*%MR=WAT+5TK
M*5QS*RA<=RLI7',K*%M<=UQD72LI7',K*%M<=UQD72LI7',K*%QW*RE<<RLH
M7%,K7',K7%,K7',K7%,K*5QS*R@N*RDO)RP*("`@("`@("`@("`@)VUA<"<@
M("`@(#T^(&%R<F%Y*"=N86UE)ST^."PG<VEZ92<]/C8L)W)I9VAT<R<]/C(L
M)W5S97(G/3XT+"=G<F]U<"<]/C4L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=F:6QE<U]I;G-I9&4G/3XS+"=D871E)ST^-RPG:7-?9&ER)ST^
M,2D*("`@("`@("`I+`H@("`@("`@("=W:6YD;W=S)R`]/B!A<G)A>2@*("`@
M("`@("`@("`@)W!A='1E<FXG(#T^("<O*"XK*5QS*R@N*RE<<RLH*#Q$25(^
M*7Q;,"TY72LI7',K*"XK*2\G+`H@("`@("`@("`@("`G;6%P)R`@("`@/3X@
M87)R87DH)VYA;64G/3XU+"=D871E)ST^,2PG:7-?9&ER)ST^,RD*("`@("`@
M("`I"B`@("`I.PH@("`@"B`@("`O*BH*("`@("`J(&UA=&-H97(*("`@("`J
M(%-T;W)E<R!T:&4@;6%T8VAE<B!F;W(@=&AE(&-U<G)E;G0@8V]N;F5C=&EO
M;@H@("`@("H*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J($!V87(@
M("`@(&%R<F%Y"B`@("`@*B!`<VEN8V4@("`Q+C,*("`@("`J+PH@("`@=F%R
M("1?;6%T8VAE<B`](&YU;&P["B`@("`*("`@("\J*@H@("`@("H@2&]L9',@
M86QL($YE=%]&5%!?3V)S97)V97(@;V)J96-T<R`*("`@("`J('1H870@=VES
M:"!T;R!B92!N;W1I9FEE9"!O9B!N97<@;65S<V%G97,N"B`@("`@*@H@("`@
M("H@0'9A<B`@("`@87)R87D*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@
M("`J($!S:6YC92`@(#$N,PH@("`@("HO"B`@("`*("`@('9A<B`D7VQI<W1E
M;F5R<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4:&ES(&=E;F5R871E
M<R!A(&YE=R!&5%`M3V)J96-T+B!4:&4@1E10+6-O;FYE8W1I;VX@=VEL;"!N
M;W0@8F4@97-T86)L:7-H960L('EE="X*("`@("`J(%EO=2!C86X@;&5A=F4@
M)&AO<W0@86YD("1P;W)T(&)L86YK+"!I9B!Y;W4@=V%N="X@5&AE("1H;W-T
M('=I;&P@;F]T(&)E('-E=`H@("`@("H@86YD('1H92`D<&]R="!W:6QL(&)E
M(&QE9G0@870@,C$N(%EO=2!H879E('1O('-E="!T:&4@)&AO<W0@;6%N=6%L
M>2!B969O<F4*("`@("`J('1R>6EN9R!T;R!C;VYN96-T(&]R('=I=&@@=&AE
M(&-O;FYE8W0H*2!M971H;V0N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B
M;&EC"B`@("`@*B!`<&%R86T@("!S=')I;F<@)&AO<W0@("`@*&]P=&EO;F%L
M*2!4:&4@:&]S=&YA;64@"B`@("`@*B!`<&%R86T@("!I;G0@("`@)'!O<G0@
M("`@*&]P=&EO;F%L*2!4:&4@<&]R=`H@("`@("H@0'!A<F%M("`@:6YT("`@
M("1T:6UE;W5T("AO<'1I;VYA;"D@4V5T<R!T:&4@<W1A;F1A<F0@=&EM96]U
M=`H@("`@("H@0')E='5R;B`@=F]I9`H@("`@("H@0'-E92`@("`@3F5T7T94
M4#HZ<V5T2&]S=&YA;64H*2P@3F5T7T944#HZ<V5T4&]R="@I+"!.971?1E10
M.CIC;VYN96-T*"D*("`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!.971?1E10
M*"1H;W-T(#T@;G5L;"P@)'!O<G0@/2!N=6QL+"`D=&EM96]U="`](#DP*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y014%2*"D["B`@("`@("`@:68@*&ES<V5T
M*"1H;W-T*2D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T2&]S=&YA;64H)&AO
M<W0I.PH@("`@("`@('T*("`@("`@("!I9B`H:7-S970H)'!O<G0I*2!["B`@
M("`@("`@("`@("1T:&ES+3YS9710;W)T*"1P;W)T*3L*("`@("`@("!]"B`@
M("`@("`@)'1H:7,M/E]T:6UE;W5T(#T@)'1I;65O=70["B`@("`@("`@)'1H
M:7,M/E]F:6QE7V5X=&5N<VEO;G-;1E107T%30TE)72`](&%R<F%Y*"D["B`@
M("`@("`@)'1H:7,M/E]F:6QE7V5X=&5N<VEO;G-;1E107T))3D%265T@/2!A
M<G)A>2@I.PH@("`@?0H*("`@("\J*@H@("`@("H@5&AI<R!F=6YC=&EO;B!G
M96YE<F%T97,@=&AE($944"UC;VYN96-T:6]N+B!9;W4@8V%N(&]P=&EO;F%L
M;'D@9&5F:6YE(&$*("`@("`J(&AO<W1N86UE(&%N9"]O<B!A('!O<G0N($EF
M('EO=2!D;R!S;RP@=&AI<R!D871A(&ES('-T;W)E9"!I;G-I9&4@=&AE(&]B
M:F5C="X*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!P
M87)A;2`@('-T<FEN9R`D:&]S="`@("`H;W!T:6]N86PI(%1H92!(;W-T;F%M
M90H@("`@("H@0'!A<F%M("`@:6YT("`@("1P;W)T("`@("AO<'1I;VYA;"D@
M5&AE(%!O<G0@"B`@("`@*B!`<F5T=7)N("!M:7AE9"`@("`@("`@("`@5')U
M92!O;B!S=6-C97-S+"!O=&AE<G=I<V4@4$5!4CHZ17)R;W(*("`@("`J($!S
M964@("`@($Y%5%]&5%!?15)27T-/3DY%0U1?1D%)3$5$"B`@("`@*B\*("`@
M(`H@("`@9G5N8W1I;VX@8V]N;F5C="@D:&]S="`](&YU;&PL("1P;W)T(#T@
M;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^7VUA=&-H97(@/2!N=6QL.PH@
M("`@("`@(&EF("AI<W-E="@D:&]S="DI('L*("`@("`@("`@("`@)'1H:7,M
M/G-E=$AO<W1N86UE*"1H;W-T*3L*("`@("`@("!]"B`@("`@("`@:68@*&ES
M<V5T*"1P;W)T*2D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T4&]R="@D<&]R
M="D["B`@("`@("`@?0H@("`@("`@("1H86YD;&4@/2!`9G1P7V-O;FYE8W0H
M)'1H:7,M/F=E=$AO<W1N86UE*"DL("1T:&ES+3YG9710;W)T*"DL("1T:&ES
M+3Y?=&EM96]U="D["B`@("`@("`@:68@*"$D:&%N9&QE*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B0V]N;F5C=&EO;B!T;R!H
M;W-T(&9A:6QE9"(L($Y%5%]&5%!?15)27T-/3DY%0U1?1D%)3$5$*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7VAA;F1L92`])B`D
M:&%N9&QE.PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES(&9U;F-T:6]N(&-L;W-E('1H92!&
M5%`M8V]N;F5C=&EO;@H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@
M("`@("H@0')E='5R;B`@8F]O;'Q014%27T5R<F]R(%)E='5R;G,@=')U92!O
M;B!S=6-C97-S+"!014%27T5R<F]R(&]N(&9A:6QU<F4*("`@("`J+PH@("`@
M"B`@("!F=6YC=&EO;B!D:7-C;VYN96-T*"D*("`@('L*("`@("`@("`D<F5S
M(#T@0&9T<%]C;&]S92@D=&AI<RT^7VAA;F1L92D["B`@("`@("`@:68@*"$D
M<F5S*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=$
M:7-C;VYN96-T(&9A:6QE9"XG+"!.151?1E107T524E]$25-#3TY.14-47T9!
M24Q%1"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@5&AI<R!L;V=G97,@>6]U(&EN=&\@=&AE(&9T<"US
M97)V97(N(%EO=2!A<F4@9G)E92!T;R!S<&5C:69Y('5S97)N86UE(&%N9"!P
M87-S=V]R9`H@("`@("H@:6X@=&AI<R!M971H;V0N($EF('EO=2!S<&5C:69Y
M(&ET+"!T:&4@=F%L=65S('=I;&P@8F4@=&%K96X@:6YT;R!T:&4@8V]R<F5S
M<&]N9&EN9PH@("`@("H@871T<FEB=71E<RP@:68@9&\@;F]T('-P96-I9GDL
M('1H92!A='1R:6)U=&5S(&%R92!T86ME;BX*("`@("`J"B`@("`@*B!`86-C
M97-S("!P=6)L:6,*("`@("`J($!P87)A;2`@('-T<FEN9R`D=7-E<FYA;64@
M("AO<'1I;VYA;"D@5&AE('5S97)N86UE('1O('5S92`*("`@("`J($!P87)A
M;2`@('-T<FEN9R`D<&%S<W=O<F0@("AO<'1I;VYA;"D@5&AE('!A<W-W;W)D
M('1O('5S90H@("`@("H@0')E='5R;B`@;6EX960@("`@("`@("`@("`@5')U
M92!O;B!S=6-C97-S+"!O=&AE<G=I<V4@4$5!4CHZ17)R;W(*("`@("`J($!S
M964@("`@($Y%5%]&5%!?15)27TQ/1TE.7T9!24Q%1`H@("`@("HO"B`@("`*
M("`@(&9U;F-T:6]N(&QO9VEN*"1U<V5R;F%M92`](&YU;&PL("1P87-S=V]R
M9"`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D=7-E<FYA;64I
M*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]("1T:&ES+3YG9715<V5R;F%M
M92@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YS9715
M<V5R;F%M92@D=7-E<FYA;64I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I
M<W-E="@D<&%S<W=O<F0I*2!["B`@("`@("`@("`@("1P87-S=V]R9"`]("1T
M:&ES+3YG971087-S=V]R9"@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1T:&ES+3YS971087-S=V]R9"@D<&%S<W=O<F0I.PH@("`@("`@('T*
M"B`@("`@("`@)')E<R`]($!F='!?;&]G:6XH)'1H:7,M/E]H86YD;&4L("1U
M<V5R;F%M92P@)'!A<W-W;W)D*3L*"B`@("`@("`@:68@*"$D<F5S*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B56YA8FQE('1O
M(&QO9VEN(BP@3D547T944%]%4E)?3$]'24Y?1D%)3$5$*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES(&-H86YG97,@=&AE(&-U<G)E;G1L
M>2!U<V5D(&1I<F5C=&]R>2X@66]U(&-A;B!U<V4@96ET:&5R(&%N(&%B<V]L
M=71E"B`@("`@*B!D:7)E8W1O<GDM<&%T:"`H92YG+B`B+VAO;64O8FQA:"(I
M(&]R(&$@<F5L871I=F4@;VYE("AE+F<N("(N+B]T97-T(BDN"B`@("`@*@H@
M("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<&%R86T@("!S=')I;F<@
M)&1I<B`@5&AE(&1I<F5C=&]R>2!T;R!G;R!T;RX*("`@("`J($!R971U<FX@
M(&UI>&5D("`@("`@("!4<G5E(&]N('-U8V-E<W,L(&]T:&5R=VES92!014%2
M.CI%<G)O<@H@("`@("H@0'-E92`@("`@3D547T944%]%4E)?1$E20TA!3D=%
M7T9!24Q%1`H@("`@("HO"B`@("`*("`@(&9U;F-T:6]N(&-D*"1D:7(I"B`@
M("!["B`@("`@("`@)&5R9R`]($!F='!?8VAD:7(H)'1H:7,M/E]H86YD;&4L
M("1D:7(I.PH@("`@("`@(&EF("@A)&5R9RD@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H(D1I<F5C=&]R>2!C:&%N9V4@9F%I;&5D
M(BP@3D547T944%]%4E)?1$E20TA!3D=%7T9!24Q%1"D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@4VAO=R=S('EO=2!T:&4@86-T=6%L('!A=&@@
M;VX@=&AE('-E<G9E<@H@("`@("H@5&AI<R!F=6YC=&EO;B!Q=65S=&EO;G,@
M=&AE(&9T<"UH86YD;&4@9F]R('1H92!A8W1U86P@<V5L96-T960@<&%T:"!A
M;F0@<F5T=7)N<R!I="X*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*
M("`@("`J($!R971U<FX@(&UI>&5D("`@("`@("!4:&4@86-T=6%L('!A=&@@
M;W(@4$5!4CHZ17)R;W(*("`@("`J($!S964@("`@($Y%5%]&5%!?15)27T1%
M5$5234E.15!!5$A?1D%)3$5$"B`@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@
M<'=D*"D*("`@('L*("`@("`@("`D<F5S(#T@0&9T<%]P=V0H)'1H:7,M/E]H
M86YD;&4I.PH@("`@("`@(&EF("@A)')E<RD@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H(D-O=6QD(&YO="!D971E<FUI;F4@=&AE
M(&%C='5A;"!P871H+B(L($Y%5%]&5%!?15)27T1%5$5234E.15!!5$A?1D%)
M3$5$*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)')E
M<SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES('=O<FMS
M('-I;6EL87(@=&\@=&AE(&UK9&ER+6-O;6UA;F0@;VX@>6]U<B!L;V-A;"!M
M86-H:6YE+B!9;W4@8V%N(&5I=&AE<B!G:79E"B`@("`@*B!I="!A;B!A8G-O
M;'5T92!O<B!R96QA=&EV92!P871H+B!4:&4@<F5L871I=F4@<&%T:"!W:6QL
M(&)E(&-O;7!L971E9"!W:71H('1H92!A8W1U86P*("`@("`J('-E;&5C=&5D
M('-E<G9E<BUP871H+B`H<V5E.B!P=V0H*2D*("`@("`J"B`@("`@*B!`86-C
M97-S("!P=6)L:6,*("`@("`J($!P87)A;2`@('-T<FEN9R`D9&ER("`@("`@
M($%B<V]L=71E(&]R(')E;&%T:79E(&1I<BUP871H"B`@("`@*B!`<&%R86T@
M("!B;V]L("`@)')E8W5R<VEV92`H;W!T:6]N86PI($-R96%T92!A;&P@;F5E
M9&5D(&1I<F5C=&]R:65S"B`@("`@*B!`<F5T=7)N("!M:7AE9"`@("`@("`@
M("`@("!4<G5E(&]N('-U8V-E<W,L(&]T:&5R=VES92!014%2.CI%<G)O<@H@
M("`@("H@0'-E92`@("`@3D547T944%]%4E)?0U)%051%1$E27T9!24Q%1`H@
M("`@("HO"B`@("`*("`@(&9U;F-T:6]N(&UK9&ER*"1D:7(L("1R96-U<G-I
M=F4@/2!F86QS92D*("`@('L*("`@("`@("`D9&ER(#T@)'1H:7,M/E]C;VYS
M=')U8W1?<&%T:"@D9&ER*3L*("`@("`@("`D<V%V961I<B`]("1T:&ES+3YP
M=V0H*3L*("`@("`@("`D=&AI<RT^<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%
M4E)/4E]215154DXI.PH@("`@("`@("1E(#T@)'1H:7,M/F-D*"1D:7(I.PH@
M("`@("`@("1T:&ES+3YP;W!%<G)O<DAA;F1L:6YG*"D["B`@("`@("`@:68@
M*"1E(#T]/2!T<G5E*2!["B`@("`@("`@("`@("1T:&ES+3YC9"@D<V%V961I
M<BD["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*("`@("`@
M("`D=&AI<RT^8V0H)'-A=F5D:7(I.PH@("`@("`@(&EF("@D<F5C=7)S:79E
M(#T]/2!F86QS92E["B`@("`@("`@("`@("1R97,@/2!`9G1P7VUK9&ER*"1T
M:&ES+3Y?:&%N9&QE+"`D9&ER*3L*("`@("`@("`@("`@:68@*"$D<F5S*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D-R
M96%T:6]N(&]F("<D9&ER)R!F86EL960B+"!.151?1E107T524E]#4D5!5$5$
M25)?1D%)3$5$*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@:68H<W1R<&]S*"1D:7(L("<O)RD@/3T](&9A;'-E
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/FUK9&ER*"1D:7(L
M9F%L<V4I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1P;W,@/2`P.PH@
M("`@("`@("`@("`D<F5S(#T@)'1H:7,M/FUK9&ER*&1I<FYA;64H)&1I<BDL
M('1R=64I.PH@("`@("`@("`@("`D<F5S(#T@)'1H:7,M/FUK9&ER*"1D:7(L
M(&9A;'-E*3L*("`@("`@("`@("`@:68@*"1R97,@(3T]('1R=64I('L*("`@
M("`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%1H:7,@;65T:&]D('1R:65S(&5X96-U=&EN9R!A(&-O;6UA;F0@
M;VX@=&AE(&9T<"P@=7-I;F<@4TE412!%6$5#+@H@("`@("H*("`@("`J($!A
M8V-E<W,@('!U8FQI8PH@("`@("H@0'!A<F%M("`@<W1R:6YG("1C;VUM86YD
M(%1H92!C;VUM86YD('1O(&5X96-U=&4*("`@("`J($!R971U<FX@(&UI>&5D
M("`@("`@("`@("!4:&4@<F5S=6QT(&]F('1H92!C;VUM86YD("AI9B!S=6-C
M97-S9G5L;"DL(&]T:&5R=VES92!014%2.CI%<G)O<@H@("`@("H@0'-E92`@
M("`@3D547T944%]%4E)?15A%0U]&04E,140*("`@("`J+PH@("`@"B`@("!F
M=6YC=&EO;B!E>&5C=71E*"1C;VUM86YD*0H@("`@>PH@("`@("`@("1R97,@
M/2!`9G1P7V5X96,H)'1H:7,M/E]H86YD;&4L("1C;VUM86YD*3L*("`@("`@
M("!I9B`H(21R97,I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*")%>&5C=71I;VX@;V8@8V]M;6%N9"`G)&-O;6UA;F0G(&9A:6QE
M9"XB+"!.151?1E107T524E]%6$5#7T9!24Q%1"D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@17AE8W5T92!A(%-)5$4@8V]M;6%N9"!O;B!T:&4@
M<V5R=F5R"B`@("`@*B!4:&ES(&UE=&AO9"!T<FEE<R!T;R!E>&5C=71E(&$@
M4TE412!C;VUM86YD(&]N('1H92!F='`@<V5R=F5R+@H@("`@("H*("`@("`J
M($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'!A<F%M("`@<W1R:6YG("1C;VUM
M86YD("`@5&AE(&-O;6UA;F0@=VET:"!P87)A;65T97)S('1O(&5X96-U=&4*
M("`@("`J($!R971U<FX@(&UI>&5D("`@("`@("`@("`@(%1R=64@:68@<W5C
M8V5S<V9U;"P@;W1H97)W:7-E(%!%05(Z.D5R<F]R"B`@("`@*B!`<V5E("`@
M("!.151?1E107T524E]3251%7T9!24Q%1`H@("`@("HO"B`@("`*("`@(&9U
M;F-T:6]N('-I=&4H)&-O;6UA;F0I"B`@("!["B`@("`@("`@)')E<R`]($!F
M='!?<VET92@D=&AI<RT^7VAA;F1L92P@)&-O;6UA;F0I.PH@("`@("`@(&EF
M("@A)')E<RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H(D5X96-U=&EO;B!O9B!3251%(&-O;6UA;F0@)R1C;VUM86YD)R!F86EL
M960N(BP@3D547T944%]%4E)?4TE415]&04E,140I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J(%1H:7,@;65T:&]D('=I;&P@=')Y('1O(&-H;6]D
M('1H92!F:6QE('-P96-I9FEE9"!O;B!T:&4@<V5R=F5R"B`@("`@*B!#=7)R
M96YT;'DL('EO=2!M=7-T(&=I=F4@82!N=6UB97(@87,@=&AE('1H92!P97)M
M:7-S:6]N(&%R9W5M96YT("@W-S<@;W(*("`@("`J('-I;6EL87(I+B!4:&4@
M9FEL92!C86X@8F4@96ET:&5R(&$@<F5L871I=F4@;W(@86)S;VQU=&4@<&%T
M:"X*("`@("`J($Y/5$4Z(%-O;64@<V5R=F5R<R!D;R!N;W0@<W5P<&]R="!T
M:&ES(&9E871U<F4N($EN('1H870@8V%S92P@>6]U('=I;&P*("`@("`J(&=E
M="!A(%!%05(@97)R;W(@;V)J96-T(')E='5R;F5D+B!)9B!S=6-C97-S9G5L
M+"!T:&4@;65T:&]D(')E='5R;G,@=')U90H@("`@("H*("`@("`J($!A8V-E
M<W,@('!U8FQI8PH@("`@("H@0'!A<F%M("`@;6EX960@("`D=&%R9V5T("`@
M("`@("!4:&4@9FEL92!O<B!A<G)A>2!O9B!F:6QE<R!T;R!S970@<&5R;6ES
M<VEO;G,@9F]R"B`@("`@*B!`<&%R86T@("!I;G1E9V5R("1P97)M:7-S:6]N
M<R`@(%1H92!M;V1E('1O('-E="!T:&4@9FEL92!P97)M:7-S:6]N<R!T;PH@
M("`@("H@0')E='5R;B`@;6EX960@("`@("`@("`@("`@("`@("!4<G5E(&EF
M('-U8V-E<W-F=6PL(&]T:&5R=VES92!014%2.CI%<G)O<@H@("`@("H@0'-E
M92`@("`@3D547T944%]%4E)?0TA-3T1?1D%)3$5$"B`@("`@*B\*("`@(`H@
M("`@9G5N8W1I;VX@8VAM;V0H)'1A<F=E="P@)'!E<FUI<W-I;VYS*0H@("`@
M>PH@("`@("`@("\O($EF("1T87)G970@:7,@86X@87)R87DZ($QO;W`@=&AR
M;W5G:"!I="X*("`@("`@("!I9B`H:7-?87)R87DH)'1A<F=E="DI('L*"B`@
M("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1T87)G970I.R`D
M:2LK*2!["B`@("`@("`@("`@("`@("`D<F5S(#T@)'1H:7,M/F-H;6]D*"1T
M87)G971;)&E=+"`D<&5R;6ES<VEO;G,I.PH@("`@("`@("`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)')E<RDI('L*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)')E<SL*("`@("`@("`@("`@("`@('T@+R\@96YD(&EF(&ES17)R
M;W(*("`@("`@("`@("`@?2`O+R!E;F0@9F]R(&D@/"!C;W5N="@D=&%R9V5T
M*0H*("`@("`@("!](&5L<V4@>PH*("`@("`@("`@("`@)')E<R`]("1T:&ES
M+3YS:71E*")#2$U/1"`B("X@)'!E<FUI<W-I;VYS("X@(B`B("X@)'1A<F=E
M="D["B`@("`@("`@("`@(&EF("@A)')E<RD@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D-(34]$("(@+B`D<&5R;6ES<VEO
M;G,@+B`B("(@+B`D=&%R9V5T("X@(B!F86EL960B+"!.151?1E107T524E]#
M2$U/1%]&04E,140I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1R97,["B`@("`@("`@("`@('T*"B`@("`@("`@?2`O
M+R!E;F0@:68@:7-?87)R87D*"B`@("!]("\O(&5N9"!M971H;V0@8VAM;V0*
M"B`@("`O*BH*("`@("`J(%1H:7,@;65T:&]D('=I;&P@=')Y('1O(&-H;6]D
M(&$@9F]L9&5R(&%N9"!A;&P@;V8@:71S(&-O;G1E;G1S"B`@("`@*B!O;B!T
M:&4@<V5R=F5R+B!4:&4@=&%R9V5T(&%R9W5M96YT(&UU<W0@8F4@82!F;VQD
M97(@;W(@86X@87)R87D@;V8@9F]L9&5R<PH@("`@("H@86YD('1H92!P97)M
M:7-S:6]N<R!A<F=U;65N="!H879E('1O(&)E(&%N(&EN=&5G97(@*&DN92X@
M-S<W*2X*("`@("`J(%1H92!F:6QE(&-A;B!B92!E:71H97(@82!R96QA=&EV
M92!O<B!A8G-O;'5T92!P871H+@H@("`@("H@3D]413H@4V]M92!S97)V97)S
M(&1O(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92X@26X@=&AA="!C87-E+"!Y
M;W4*("`@("`J('=I;&P@9V5T(&$@4$5!4B!E<G)O<B!O8FIE8W0@<F5T=7)N
M960N($EF('-U8V-E<W-F=6PL('1H92!M971H;V0*("`@("`J(')E='5R;G,@
M=')U90H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'!A
M<F%M("`@;6EX960@("`D=&%R9V5T("`@("`@("!4:&4@9F]L9&5R(&]R(&%R
M<F%Y(&]F(&9O;&1E<G,@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<V5T('!E<FUI<W-I;VYS(&9O<@H@("`@("H@0'!A<F%M
M("`@:6YT96=E<B`D<&5R;6ES<VEO;G,@("!4:&4@;6]D92!T;R!S970@=&AE
M(&9O;&1E<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A;F0@9FEL92!P97)M:7-S:6]N<R!T;PH@("`@("H@0')E='5R;B`@;6EX
M960@("`@("`@("`@("`@("`@("!4<G5E(&EF('-U8V-E<W-F=6PL(&]T:&5R
M=VES92!014%2.CI%<G)O<@H@("`@("H@0'-E92`@("`@3D547T944%]%4E)?
M0TA-3T1?1D%)3$5$+"!.151?1E107T524E]$151%4DU)3D50051(7T9!24Q%
M1"P@3D547T944%]%4E)?4D%71$E23$E35%]&04E,140L($Y%5%]&5%!?15)2
M7T1)4DQ)4U1?54Y355!03U)4140*("`@("`J+PH@("`@"B`@("!F=6YC=&EO
M;B!C:&UO9%)E8W5R<VEV92@D=&%R9V5T+"`D<&5R;6ES<VEO;G,I"B`@("![
M"B`@("`@("`@<W1A=&EC("1D:7)?<&5R;6ES<VEO;G,["@H@("`@("`@(&EF
M*"%I<W-E="@D9&ER7W!E<FUI<W-I;VYS*2E[("\O($UA:VEN9R!D:7)E8W1O
M<GD@<W!E8VEF:6,@<&5R;6ES<VEO;G,*("`@("`@("`@("`@)&1I<E]P97)M
M:7-S:6]N<R`]("1T:&ES+3Y?;6%K941I<E!E<FUI<W-I;VYS*"1P97)M:7-S
M:6]N<RD["B`@("`@("`@?0H*("`@("`@("`O+R!)9B`D=&%R9V5T(&ES(&%N
M(&%R<F%Y.B!,;V]P('1H<F]U9V@@:70*("`@("`@("!I9B`H:7-?87)R87DH
M)'1A<F=E="DI('L*"B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O
M=6YT*"1T87)G970I.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D<F5S(#T@
M)'1H:7,M/F-H;6]D4F5C=7)S:79E*"1T87)G971;)&E=+"`D<&5R;6ES<VEO
M;G,I.PH@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<RDI
M('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("`@
M("`@("`@('T@+R\@96YD(&EF(&ES17)R;W(*("`@("`@("`@("`@?2`O+R!E
M;F0@9F]R(&D@/"!C;W5N="@D=&%R9V5T*0H*("`@("`@("!](&5L<V4@>PH*
M("`@("`@("`@("`@)')E;6]T95]P871H(#T@)'1H:7,M/E]C;VYS=')U8W1?
M<&%T:"@D=&%R9V5T*3L*"B`@("`@("`@("`@("\O($-H;6]D('1H92!D:7)E
M8W1O<GD@:71S96QF"B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^8VAM
M;V0H)')E;6]T95]P871H+"`D9&ER7W!E<FUI<W-I;VYS*3L*"B`@("`@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@+R\@268@)')E;6]T95]P871H(&QA<W0@8VAA<F%C=&5R(&ES(&YO="!A
M('-L87-H+"!A9&0@;VYE"B`@("`@("`@("`@(&EF("AS=6)S='(H)')E;6]T
M95]P871H+"!S=')L96XH)')E;6]T95]P871H*2TQ*2`A/2`B+R(I('L*"B`@
M("`@("`@("`@("`@("`D<F5M;W1E7W!A=&@@+CT@(B\B.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`D9&ER7VQI<W0@/2!A<G)A>2@I.PH@("`@("`@
M("`@("`D;6]D92`]($Y%5%]&5%!?1$E24U]/3DQ9.PH@("`@("`@("`@("`D
M9&ER7VQI<W0@/2`D=&AI<RT^;',H)')E;6]T95]P871H+"`D;6]D92D["B`@
M("`@("`@("`@(&9O<F5A8V@@*"1D:7)?;&ES="!A<R`D9&ER7V5N=')Y*2![
M"@H@("`@("`@("`@("`@("`@)')E;6]T95]P871H7VYE=R`]("1R96UO=&5?
M<&%T:"XD9&ER7V5N=')Y6R)N86UE(ETN(B\B.PH*("`@("`@("`@("`@("`@
M("\O($-H;6]D('1H92!D:7)E8W1O<GD@=V4G<F4@86)O=70@=&\@96YT97(*
M("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^8VAM;V0H)')E;6]T
M95]P871H7VYE=RP@)&1I<E]P97)M:7-S:6]N<RD["@H@("`@("`@("`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F-H;6]D4F5C=7)S:79E
M*"1R96UO=&5?<&%T:%]N97<L("1P97)M:7-S:6]N<RD["@H@("`@("`@("`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@('T*
M"B`@("`@("`@("`@('T@+R\@96YD(&9O<F5A8V@@9&ER7VQI<W0@87,@9&ER
M7V5N=')Y"@H@("`@("`@("`@("`D9FEL95]L:7-T(#T@87)R87DH*3L*("`@
M("`@("`@("`@)&UO9&4@/2!.151?1E107T9)3$537T].3%D["B`@("`@("`@
M("`@("1F:6QE7VQI<W0@/2`D=&AI<RT^;',H)')E;6]T95]P871H+"`D;6]D
M92D["@H@("`@("`@("`@("!F;W)E86-H("@D9FEL95]L:7-T(&%S("1F:6QE
M7V5N=')Y*2!["@H@("`@("`@("`@("`@("`@)')E;6]T95]F:6QE(#T@)')E
M;6]T95]P871H+B1F:6QE7V5N=')Y6R)N86UE(ET["@H@("`@("`@("`@("`@
M("`@)')E<W5L="`]("1T:&ES+3YC:&UO9"@D<F5M;W1E7V9I;&4L("1P97)M
M:7-S:6]N<RD["@H@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)')E<W5L="DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@('T@+R\@96YD(&9O
M<F5A8V@@)&9I;&5?;&ES=`H*("`@("`@("!]("\O(&5N9"!I9B!I<U]A<G)A
M>0H*("`@("`@("!R971U<FX@=')U93L@+R\@3F\@97)R;W)S"@H@("`@?2`O
M+R!E;F0@;65T:&]D(&-H;6]D4F5C=7)S:79E"@H@("`@+RHJ"B`@("`@*B!2
M96YA;64@;W(@;6]V92!A(&9I;&4@;W(@82!D:7)E8W1O<GD@9G)O;2!T:&4@
M9G1P+7-E<G9E<@H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@
M("H@0'!A<F%M("`@<W1R:6YG("1R96UO=&5?9G)O;2!4:&4@<F5M;W1E(&9I
M;&4@;W(@9&ER96-T;W)Y(&]R:6=I;F%L('1O(')E;F%M92!O<B!M;W9E"B`@
M("`@*B!`<&%R86T@("!S=')I;F<@)')E;6]T95]T;R!4:&4@<F5M;W1E(&9I
M;&4@;W(@9&ER96-T;W)Y(&9I;F%L('1O(')E;F%M92!O<B!M;W9E"B`@("`@
M*B!`<F5T=7)N("!B;V]L("1R97,@5')U92!O;B!S=6-C97-S+"!O=&AE<G=I
M<V4@4$5!4CHZ17)R;W(*("`@("`J($!S964@("`@($Y%5%]&5%!?15)27U)%
M3D%-15]&04E,140*("`@("`J+PH*("`@(&9U;F-T:6]N(')E;F%M92`H)')E
M;6]T95]F<F]M+"`D<F5M;W1E7W1O*2`*("`@('L*("`@("`@("`D<F5S(#T@
M0&9T<%]R96YA;64H)'1H:7,M/E]H86YD;&4L("1R96UO=&5?9G)O;2P@)')E
M;6]T95]T;RD["B`@("`@("`@:68H(21R97,I('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*")#;W5L9"!N;W0@<F5N86UE("(N)')E
M;6]T95]F<F]M+B(@=&\@(BXD<F5M;W1E7W1O+B(@(2(L($Y%5%]&5%!?15)2
M7U)%3D%-15]&04E,140I.PH@("`@("`@('T*("`@("`@("!R971U<FX@=')U
M93L*("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@=VEL;"!R971U<FX@;&]G
M:6-A;"!P97)M:7-S:6]N<R!M87-K(&9O<B!D:7)E8W1O<GDN"B`@("`@*B!I
M9B!D:7)E8W1O<GD@:&%V92!T;R!B92!W<FET96%B;&4@:70@:&%V92!A;'-O
M(&)E(&5X96-U=&%B;&4*("`@("`J"B`@("`@*B!`86-C97-S("!P<FEV871E
M"B`@("`@*B!`<&%R86T@("!S=')I;F<@)'!E<FUI<W-I;VYS("`@($9I;&4@
M<&5R;6ES<VEO;G,@:6X@9&EG:71S(&9O<B!F:6QE("AI+F4N(#8V-BD*("`@
M("`J($!R971U<FX@('-T<FEN9R`@("`@("`@("`@("`@("`@1FEL92!P97)M
M:7-S:6]N<R!I;B!D:6=I=',@9F]R(&1I<F5C=&]R>2`H:2YE+B`W-S<I"B`@
M("`@*B\*"B`@("!F=6YC=&EO;B!?;6%K941I<E!E<FUI<W-I;VYS*"1P97)M
M:7-S:6]N<RE["B`@("`@("`@)'!E<FUI<W-I;VYS(#T@*'-T<FEN9RDD<&5R
M;6ES<VEO;G,["@H@("`@("`@(&9O<B@D:2`](#`[("1I(#P@<W1R;&5N*"1P
M97)M:7-S:6]N<RD[("1I*RLI>R`O+R!G;VEN9R!T:')O=6=H("AU<V5R+"!G
M<F]U<"P@=V]R;&0I"B`@("`@("`@("`@(&EF*"AI;G0I)'!E<FUI<W-I;VYS
M>R1I?2`F(#0@86YD("$H*&EN="DD<&5R;6ES<VEO;G-[)&E]("8@,2DI>R`O
M+R!296%D('!E<FUI<W-I;VX@:7,@<V5T"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!B=70@97AE8W5T92!N;W0@>65T"B`@("`@("`@("`@
M("`@("`H:6YT*21P97)M:7-S:6]N<WLD:7T@/2`H:6YT*21P97)M:7-S:6]N
M<WLD:7T@*R`Q.R`O+R!!9&1I;F<@97AE8W5T92!F;&%G"B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`H<W1R:6YG*21P97)M:7-S
M:6]N<SL*("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@=VEL;"!R971U<FX@
M=&AE(&QA<W0@;6]D:69I8V%T:6]N+71I;64@;V8@82!F:6QE+B!9;W4@8V%N
M(&5I=&AE<B!G:79E('1H:7,*("`@("`J(&9U;F-T:6]N(&$@<F5L871I=F4@
M;W(@86X@86)S;VQU=&4@<&%T:"!T;R!T:&4@9FEL92!T;R!C:&5C:RX*("`@
M("`J($Y/5$4Z(%-O;64@<V5R=F5R<R!W:6QL(&YO="!S=7!P;W)T('1H:7,@
M9F5A='5R92!A;F0@=&AE(&9U;F-T:6]N('=O<FMS"B`@("`@*B!O;FQY(&]N
M(&9I;&5S+"!N;W0@9&ER96-T;W)I97,A(%=H96X@<W5C8V5S<V9U;"P*("`@
M("`J(&ET('=I;&P@<F5T=7)N('1H92!L87-T(&UO9&EF:6-A=&EO;BUT:6UE
M(&%S(&$@=6YI>"UT:6UE<W1A;7`@;W(L('=H96X@)&9O<FUA="!I<PH@("`@
M("H@<W!E8VEF:65D+"!A('!R969O<FUA=&5D('1I;65S=')I;F<N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<&%R86T@("!S=')I
M;F<@)&9I;&4@("`@5&AE(&9I;&4@=&\@8VAE8VL*("`@("`J($!P87)A;2`@
M('-T<FEN9R`D9F]R;6%T("`H;W!T:6]N86PI(%1H92!F;W)M870@=&\@9VEV
M92!T:&4@9&%T92!B86-K(`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EF(&YO="!S970L(&ET('=I;&P@<F5T=7)N(&$@56YI>"!T:6UE<W1A
M;7`*("`@("`J($!R971U<FX@(&UI>&5D("`@("`@("`@("!5;FEX('1I;65S
M=&%M<"P@82!P<F5F;W)M871E9"!D871E+7-T<FEN9R!O<B!014%2.CI%<G)O
M<@H@("`@("H@0'-E92`@("`@3D547T944%]%4E)?3414341)4E]53E-54%!/
M4E1%1"P@3D547T944%]%4E)?341435]&04E,140L($Y%5%]&5%!?15)27T1!
M5$5&3U)-051?1D%)3$5$"B`@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@;61T
M;2@D9FEL92P@)&9O<FUA="`](&YU;&PI"B`@("!["B`@("`@("`@)&9I;&4@
M/2`D=&AI<RT^7V-O;G-T<G5C=%]P871H*"1F:6QE*3L*("`@("`@("!I9B`H
M)'1H:7,M/E]C:&5C:U]D:7(H)&9I;&4I*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@B1FEL96YA;64@)R1F:6QE)R!S965M<R!T
M;R!B92!A(&1I<F5C=&]R>2XB+"!.151?1E107T524E]-1%1-1$E27U5.4U50
M4$]25$5$*3L*("`@("`@("!]"B`@("`@("`@)')E<R`]($!F='!?;61T;2@D
M=&AI<RT^7VAA;F1L92P@)&9I;&4I.PH@("`@("`@(&EF("@D<F5S(#T]("TQ
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B0V]U
M;&0@;F]T(&=E="!L87-T+6UO9&EF:6-A=&EO;BUD871E(&]F("<D9FEL92<N
M(BP@3D547T944%]%4E)?341435]&04E,140I.PH@("`@("`@('T*("`@("`@
M("!I9B`H:7-S970H)&9O<FUA="DI('L*("`@("`@("`@("`@)')E<R`](&1A
M=&4H)&9O<FUA="P@)')E<RD["B`@("`@("`@("`@(&EF("@A)')E<RD@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")$871E
M+69O<FUA="!F86EL960@;VX@=&EM97-T86UP("<D<F5S)RXB+"!.151?1E10
M7T524E]$051%1D]234%47T9!24Q%1"D["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1R97,["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!4:&ES('=I;&P@<F5T=7)N('1H92!S:7IE(&]F(&$@9VEV96X@9FEL92!I
M;B!B>71E<RX@66]U(&-A;B!E:71H97(@9VEV92!T:&ES(&9U;F-T:6]N"B`@
M("`@*B!A(')E;&%T:79E(&]R(&%N(&%B<V]L=71E(&9I;&4M<&%T:"X@3D]4
M13H@4V]M92!S97)V97)S(&1O(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92$*
M("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!P87)A;2`@
M('-T<FEN9R`D9FEL92`@(%1H92!F:6QE('1O(&-H96-K"B`@("`@*B!`<F5T
M=7)N("!M:7AE9"`@("`@("`@("!3:7IE(&EN(&)Y=&5S(&]R(%!%05(Z.D5R
M<F]R"B`@("`@*B!`<V5E("`@("!.151?1E107T524E]325I%7T9!24Q%1`H@
M("`@("HO"B`@("`*("`@(&9U;F-T:6]N('-I>F4H)&9I;&4I"B`@("!["B`@
M("`@("`@)&9I;&4@/2`D=&AI<RT^7V-O;G-T<G5C=%]P871H*"1F:6QE*3L*
M("`@("`@("`D<F5S(#T@0&9T<%]S:7IE*"1T:&ES+3Y?:&%N9&QE+"`D9FEL
M92D["B`@("`@("`@:68@*"1R97,@/3T@+3$I('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*")#;W5L9"!N;W0@9&5T97)M:6YE(&9I
M;&5S:7IE(&]F("<D9FEL92<N(BP@3D547T944%]%4E)?4TE:15]&04E,140I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D<F5S.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@;65T:&]D(')E
M='5R;G,@82!D:7)E8W1O<GDM;&ES="!O9B!T:&4@8W5R<F5N="!D:7)E8W1O
M<GD@;W(@9VEV96X@;VYE+@H@("`@("H@5&\@9&ES<&QA>2!T:&4@8W5R<F5N
M="!S96QE8W1E9"!D:7)E8W1O<GDL('-I;7!L>2!S970@=&AE(&9I<G-T('!A
M<F%M971E<B!T;R!N=6QL"B`@("`@*B!O<B!L96%V92!I="!B;&%N:RP@:68@
M>6]U(&1O(&YO="!W86YT('1O('5S92!A;GD@;W1H97(@<&%R86UE=&5R<RX*
M("`@("`J(#Q"4CX\0E(^"B`@("`@*B!4:&5R92!A<F4@-"!D:69F97)E;G0@
M;6]D97,@;V8@;&ES=&EN9R!D:7)E8W1O<FEE<RX@16ET:&5R('1O(&QI<W0@
M;VYL>0H@("`@("H@=&AE(&9I;&5S("AU<VEN9R!.151?1E107T9)3$537T].
M3%DI+"!T;R!L:7-T(&]N;'D@9&ER96-T;W)I97,@*'5S:6YG"B`@("`@*B!.
M151?1E107T1)4E-?3TY,62D@;W(@=&\@<VAO=R!B;W1H("AU<VEN9R!.151?
M1E107T1)4E-?1DE,15,L('=H:6-H(&ES(&1E9F%U;'0I+@H@("`@("H@/$)2
M/CQ"4CX*("`@("`J(%1H92`T=&@@;VYE(&ES('1H92!.151?1E107U)!5TQ)
M4U0L('=H:6-H(')E='5R;G,@:G5S="!T:&4@87)R87D@8W)E871E9"!B>2!T
M:&4*("`@("`J(&9T<%]R87=L:7-T*"DM9G5N8W1I;VX@8G5I;&0@:6YT;R!0
M2%`N"B`@("`@*B`\0E(^/$)2/@H@("`@("H@5&AE(&]T:&5R(&9U;F-T:6]N
M+6UO9&5S('=I;&P@<F5T=7)N(&%N(&%R<F%Y(&-O;G1A:6YI;F<@=&AE(')E
M<75E<W1E9"!D871A+@H@("`@("H@5&AE(&9I;&5S(&%N9"!D:7)S(&%R92!L
M:7-T960@:6X@:'5M86XM<V]R=&5D(&]R9&5R+"!B=70@:68@>6]U('-E;&5C
M=`H@("`@("H@3D547T944%]$25)37T9)3$53('1H92!D:7)E8W1O<FEE<R!W
M:6QL(&)E(&%D9&5D(&%B;W9E('1H92!F:6QE<RP*("`@("`J(&)U="!A;'1H
M;W5G:"!B;W1H('-O<G1E9"X*("`@("`J(#Q"4CX\0E(^"B`@("`@*B!!;&P@
M96QE;65N=',@:6X@=&AE(&%R<F%Y<R!A<F4@87-S;V-I871I=F4@87)R87ES
M('1H96US96QV97,N(%1H92!H879E('1H92!F;VQL;W=I;F<*("`@("`J('-T
M<G5C='5R93H*("`@("`J(#Q"4CX\0E(^"B`@("`@*B!$:7)S.CQ"4CX*("`@
M("`J("`@("`@("`@("!;(FYA;64B72`@("`@("`@/3X@('-T<FEN9R!4:&4@
M;F%M92!O9B!T:&4@9&ER96-T;W)Y/$)2/@H@("`@("H@("`@("`@("`@(%LB
M<FEG:'1S(ET@("`@("`]/B`@<W1R:6YG(%1H92!R:6=H=',@;V8@=&AE(&1I
M<F5C=&]R>2`H:6X@<W1Y;&4@(G)W>'(M>'(M>"(I/$)2/@H@("`@("H@("`@
M("`@("`@(%LB=7-E<B)=("`@("`@("`]/B`@<W1R:6YG(%1H92!O=VYE<B!O
M9B!T:&4@9&ER96-T;W)Y/$)2/@H@("`@("H@("`@("`@("`@(%LB9W)O=7`B
M72`@("`@("`]/B`@<W1R:6YG(%1H92!G<F]U<"UO=VYE<B!O9B!T:&4@9&ER
M96-T;W)Y/$)2/@H@("`@("H@("`@("`@("`@(%LB9FEL97-?:6YS:61E(ET]
M/B`@<W1R:6YG(%1H92!N=6UB97(@;V8@9FEL97,O9&ER<R!I;G-I9&4@=&AE
M(&1I<F5C=&]R>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&5X8VQU9&EN9R`B+B(@86YD("(N+B(\0E(^"B`@("`@*B`@
M("`@("`@("`@6R)D871E(ET@("`@("`@(#T^("!I;G0@5&AE(&-R96%T:6]N
M+61A=&4@87,@56YI>"!T:6UE<W1A;7`\0E(^"B`@("`@*B`@("`@("`@("`@
M6R)I<U]D:7(B72`@("`@(#T^("!B;V]L('1R=64L(&-A=7-E('1H:7,@:7,@
M82!D:7(\0E(^"B`@("`@*B`\0E(^/$)2/@H@("`@("H@1FEL97,Z/$)2/@H@
M("`@("H@("`@("`@("`@(%LB;F%M92)=("`@("`@("`]/B`@<W1R:6YG(%1H
M92!N86UE(&]F('1H92!F:6QE/$)2/@H@("`@("H@("`@("`@("`@(%LB<VEZ
M92)=("`@("`@("`]/B`@:6YT(%-I>F4@:6X@8GET97,\0E(^"B`@("`@*B`@
M("`@("`@("`@6R)R:6=H=',B72`@("`@(#T^("!S=')I;F<@5&AE(')I9VAT
M<R!O9B!T:&4@9FEL92`H:6X@<W1Y;&4@(G)W>'(M>'(M>"(I/$)2/@H@("`@
M("H@("`@("`@("`@(%LB=7-E<B)=("`@("`@("`]/B`@<W1R:6YG(%1H92!O
M=VYE<B!O9B!T:&4@9FEL93Q"4CX*("`@("`J("`@("`@("`@("!;(F=R;W5P
M(ET@("`@("`@/3X@('-T<FEN9R!4:&4@9W)O=7`M;W=N97(@;V8@=&AE(&9I
M;&4\0E(^"B`@("`@*B`@("`@("`@("`@6R)D871E(ET@("`@("`@(#T^("!I
M;G0@5&AE(&-R96%T:6]N+61A=&4@87,@56YI>"!T:6UE<W1A;7`\0E(^"B`@
M("`@*B`@("`@("`@("`@6R)I<U]D:7(B72`@("`@(#T^("!B;V]L(&9A;'-E
M+"!C875S92!T:&ES(&ES(&$@9FEL93Q"4CX*("`@("`J"B`@("`@*B!`86-C
M97-S("!P=6)L:6,*("`@("`J($!P87)A;2`@('-T<FEN9R`D9&ER("`@*&]P
M=&EO;F%L*2!4:&4@9&ER96-T;W)Y('1O(&QI<W0@;W(@;G5L;"P@=VAE;B!L
M:7-T:6YG('1H92!C=7)R96YT(&1I<F5C=&]R>2X*("`@("`J($!P87)A;2`@
M(&EN="`@("`D;6]D92`@*&]P=&EO;F%L*2!4:&4@;6]D92!W:&EC:"!T>7!E
M<R!T;R!L:7-T("AF:6QE<RP@9&ER96-T;W)I97,@;W(@8F]T:"DN"B`@("`@
M*B!`<F5T=7)N("!M:7AE9"`@("`@("`@(%1H92!D:7)E8W1O<GD@;&ES="!A
M<R!D97-C<FEB960@86)O=F4@;W(@4$5!4CHZ17)R;W(@;VX@9F%I;'5R92X*
M("`@("`J($!S964@("`@($Y%5%]&5%!?1$E24U]&24Q%4RP@3D547T944%]$
M25)37T].3%DL($Y%5%]&5%!?1DE,15-?3TY,62P@3D547T944%]205=,25-4
M+"!.151?1E107T524E]$151%4DU)3D50051(7T9!24Q%1"P@3D547T944%]%
M4E)?4D%71$E23$E35%]&04E,140L($Y%5%]&5%!?15)27T1)4DQ)4U1?54Y3
M55!03U)4140*("`@("`J+PH@("`@(`H@("`@9G5N8W1I;VX@;',H)&1I<B`]
M(&YU;&PL("1M;V1E(#T@3D547T944%]$25)37T9)3$53*0H@("`@>PH@("`@
M("`@(&EF("@A:7-S970H)&1I<BDI('L*("`@("`@("`@("`@)&1I<B`]($!F
M='!?<'=D*"1T:&ES+3Y?:&%N9&QE*3L*("`@("`@("`@("`@:68@*"$D9&ER
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M(D-O=6QD(&YO="!R971R:65V92!C=7)R96YT(&1I<F5C=&]R>2(L($Y%5%]&
M5%!?15)27T1%5$5234E.15!!5$A?1D%)3$5$*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!I9B`H*"1M;V1E("$]($Y%5%]&5%!?1DE,15-?
M3TY,62D@)B8@*"1M;V1E("$]($Y%5%]&5%!?1$E24U]/3DQ9*2`F)B`H)&UO
M9&4@(3T@3D547T944%]205=,25-4*2D@>PH@("`@("`@("`@("`D;6]D92`]
M($Y%5%]&5%!?1$E24U]&24Q%4SL*("`@("`@("!]"@H@("`@("`@('-W:71C
M:"`H)&UO9&4I('L*("`@("`@("`@("`@8V%S92!.151?1E107T1)4E-?1DE,
M15,Z("`@("1R97,@/2`D=&AI<RT^7VQS7V)O=&@@*"`D9&ER("D["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@8V%S92!.151?1E107T1)4E-?3TY,63H@("`@("1R97,@/2`D
M=&AI<RT^7VQS7V1I<G,@*"`D9&ER("D["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92!.
M151?1E107T9)3$537T].3%DZ("`@("1R97,@/2`D=&AI<RT^7VQS7V9I;&5S
M("@@)&1I<B`I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@3D547T944%]205=,25-4
M.B`@("`@("`D<F5S(#T@0&9T<%]R87=L:7-T*"1T:&ES+3Y?:&%N9&QE+"`D
M9&ER*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R97,["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!4:&ES(&UE=&AO9"!W:6QL(&1E;&5T92!T:&4@
M9VEV96X@9FEL92!O<B!D:7)E8W1O<GD@*"1P871H*2!F<F]M('1H92!S97)V
M97(*("`@("`J("AM87EB92!R96-U<G-I=F4I+@H@("`@("H*("`@("`J(%=H
M971H97(@=&AE(&=I=F5N('-T<FEN9R!I<R!A(&9I;&4@;W(@9&ER96-T;W)Y
M(&ES(&]N;'D@9&5T97)M:6YE9"!B>2!T:&4@;&%S=`H@("`@("H@<VEG;B!I
M;G-I9&4@=&AE('-T<FEN9R`H(B\B(&]R(&YO="DN"B`@("`@*@H@("`@("H@
M268@>6]U('-P96-I9GD@82!D:7)E8W1O<GDL('EO=2!C86X@;W!T:6]N86QL
M>2!S<&5C:69Y("1R96-U<G-I=F4@87,@=')U92P*("`@("`J('1O(&QE="!T
M:&4@9&ER96-T;W)Y(&)E(&1E;&5T960@<F5C=7)S:79E("AW:71H(&%L;"!S
M=6(M9&ER96-T;W)I97,@86YD(&9I;&5S"B`@("`@*B!I;FAE<FET960I+@H@
M("`@("H*("`@("`J(%EO=2!C86X@96ET:&5R(&=I=F4@82!A8G-O;'5T92!O
M<B!R96QA=&EV92!P871H(&9O<B!T:&4@9FEL92`O(&1I<BX@268@>6]U(&-H
M;V]S92!T;PH@("`@("H@=7-E('1H92!R96QA=&EV92!P871H+"!I="!W:6QL
M(&)E(&%U=&]M871I8V%L;'D@8V]M<&QE=&5D('=I=&@@=&AE(&%C='5A;`H@
M("`@("H@<V5L96-T960@9&ER96-T;W)Y+@H@("`@("H*("`@("`J($!A8V-E
M<W,@('!U8FQI8PH@("`@("H@0'!A<F%M("`@<W1R:6YG("1P871H("`@("`@
M5&AE(&%B<V]L=71E(&]R(')E;&%T:79E('!A=&@@=&\@=&AE(&9I;&4@+R!D
M:7)E8W1O<GDN"B`@("`@*B!`<&%R86T@("!B;V]L("`@)')E8W5R<VEV92`H
M;W!T:6]N86PI"B`@("`@*B!`<F5T=7)N("!M:7AE9"`@("`@("`@("`@("!4
M<G5E(&]N('-U8V-E<W,L(&]T:&5R=VES92!014%2.CI%<G)O<@H@("`@("H@
M0'-E92`@("`@3D547T944%]%4E)?1$5,151%1DE,15]&04E,140L($Y%5%]&
M5%!?15)27T1%3$54141)4E]&04E,140L($Y%5%]&5%!?15)27U)%34]415!!
M5$A.3T1)4@H@("`@("HO"B`@("`*("`@(&9U;F-T:6]N(')M*"1P871H+"`D
M<F5C=7)S:79E(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'!A=&@@/2`D=&AI
M<RT^7V-O;G-T<G5C=%]P871H*"1P871H*3L*"B`@("`@("`@:68@*"1T:&ES
M+3Y?8VAE8VM?9&ER*"1P871H*2D@>PH@("`@("`@("`@("!I9B`H)')E8W5R
M<VEV92D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<FU?9&ER
M7W)E8W5R<VEV92@D<&%T:"D["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R;5]D:7(H)'!A=&@I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?<FU?9FEL92@D<&%T:"D["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@5&AI<R!F=6YC=&EO;B!W:6QL(&1O=VYL;V%D(&$@9FEL
M92!F<F]M('1H92!F='`M<V5R=F5R+B!9;W4@8V%N(&5I=&AE<B!S<&-I9GD@
M82!A8G-O;'5T90H@("`@("H@<&%T:"!T;R!T:&4@9FEL92`H8F5G:6YN:6YG
M('=I=&@@(B\B*2!O<B!A(')E;&%T:79E(&]N92P@=VAI8V@@=VEL;"!B92!C
M;VUP;&5T960*("`@("`J('=I=&@@=&AE(&%C='5A;"!D:7)E8W1O<GD@>6]U
M('-E;&5C=&5D(&]N('1H92!S97)V97(N(%EO=2!C86X@<W!E8VEF>0H@("`@
M("H@=&AE('!A=&@@=&\@=VAI8V@@=&AE(&9I;&4@=VEL;"!B92!D;W=N;&]A
M9&5D(&]N('1H92!L;V-A;`H@("`@("H@;6%S8VAI;F4L(&EF('1H92!F:6QE
M('-H;W5L9"!B92!O=F5R=W)I='1E;B!I9B!I="!E>&ES=',@*&]P=&EO;F%L
M;'DL(&1E9F%U;'0@:7,*("`@("`J(&YO(&]V97)W<FET:6YG*2!A;F0@:6X@
M=VAI8V@@;6]D92`H1E107T%30TE)(&]R($944%]"24Y!4EDI('1H92!F:6QE
M('-H;W5L9"!B90H@("`@("H@9&]W;FQO861E9"`H:68@>6]U(&1O(&YO="!S
M<&5C:69Y('1H:7,L('1H92!M971H;V0@=')I97,@=&\@9&5T97)M:6YE(&ET
M(&%U=&]M871I8V%L;'D*("`@("`J(&9R;VT@=&AE(&UO9&4M9&ER96-T;W)Y
M(&]R('5S97,@=&AE(&1E9F%U;'0M;6]D92P@<V5T(&)Y('EO=2DN($EF('EO
M=2!G:79E(&$@<F5L871I=F4*("`@("`J('!A=&@@=&\@=&AE(&QO8V%L+69I
M;&4L('1H92!S8W)I<'0M<&%T:"!I<R!U<V5D(&%S(&)A<V5P871H+@H@("`@
M("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'!A<F%M("`@<W1R
M:6YG("1R96UO=&5?9FEL92!4:&4@86)S;VQU=&4@;W(@<F5L871I=F4@<&%T
M:"!T;R!T:&4@9FEL92!T;R!D;W=N;&]A9`H@("`@("H@0'!A<F%M("`@<W1R
M:6YG("1L;V-A;%]F:6QE("!4:&4@;&]C86P@9FEL92!T;R!P=70@=&AE(&1O
M=VYL;V%D960@:6X*("`@("`J($!P87)A;2`@(&)O;VP@("`D;W9E<G=R:71E
M("`@*&]P=&EO;F%L*2!7:&5T:&5R('1O(&]V97)W<FET92!E>&ES=&EN9R!F
M:6QE"B`@("`@*B!`<&%R86T@("!I;G0@("`@)&UO9&4@("`@("`@("AO<'1I
M;VYA;"D@16ET:&5R($944%]!4T-)22!O<B!&5%!?0DE.05)9"B`@("`@*B!`
M<F5T=7)N("!M:7AE9"`@("`@("`@("`@("`@(%1R=64@;VX@<W5C8V5S<RP@
M;W1H97)W:7-E(%!%05(Z.D5R<F]R"B`@("`@*B!`<V5E("`@("!.151?1E10
M7T524E]/5D525U))5$5,3T-!3$9)3$5?1D]20DE$1$5.+"!.151?1E107T52
M4E]/5D525U))5$5,3T-!3$9)3$5?1D%)3$5$+"!.151?1E107T524E]/5D52
M5U))5$5,3T-!3$9)3$5?1D%)3$5$"B`@("`@*B\*("`@(`H@("`@9G5N8W1I
M;VX@9V5T*"1R96UO=&5?9FEL92P@)&QO8V%L7V9I;&4L("1O=F5R=W)I=&4@
M/2!F86QS92P@)&UO9&4@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-S
M970H)&UO9&4I*2!["B`@("`@("`@("`@("1M;V1E(#T@)'1H:7,M/F-H96-K
M1FEL945X=&5N<VEO;B@D<F5M;W1E7V9I;&4I.PH@("`@("`@('T*"B`@("`@
M("`@)')E;6]T95]F:6QE(#T@)'1H:7,M/E]C;VYS=')U8W1?<&%T:"@D<F5M
M;W1E7V9I;&4I.PH*("`@("`@("!I9B`H0&9I;&5?97AI<W1S*"1L;V-A;%]F
M:6QE*2`F)B`A)&]V97)W<FET92D@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H(DQO8V%L(&9I;&4@)R1L;V-A;%]F:6QE)R!E>&ES
M=',@86YD(&UA>2!N;W0@8F4@;W9E<G=R:71E;BXB+"!.151?1E107T524E]/
M5D525U))5$5,3T-!3$9)3$5?1D]20DE$1$5.*3L*("`@("`@("!]"B`@("`@
M("`@:68@*$!F:6QE7V5X:7-T<R@D;&]C86Q?9FEL92D@)B8@(4!I<U]W<FET
M96%B;&4H)&QO8V%L7V9I;&4I("8F("1O=F5R=W)I=&4I('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"),;V-A;"!F:6QE("<D;&]C
M86Q?9FEL92<@:7,@;F]T('=R:71E86)L92X@0V%N(&YO="!O=F5R=W)I=&4N
M(BP@3D547T944%]%4E)?3U9%4E=2251%3$]#04Q&24Q%7T9!24Q%1"D["B`@
M("`@("`@?0H*("`@("`@("!I9B`H0&9U;F-T:6]N7V5X:7-T<R@G9G1P7VYB
M7V=E="<I*7L*("`@("`@("`@("`@)')E<R`]($!F='!?;F)?9V5T*"1T:&ES
M+3Y?:&%N9&QE+"`D;&]C86Q?9FEL92P@)')E;6]T95]F:6QE+"`D;6]D92D[
M"B`@("`@("`@("`@('=H:6QE("@D<F5S(#T]($944%]-3U)%1$%402D@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]A;FYO=6YC92@G;F)?9V5T)RD["B`@
M("`@("`@("`@("`@("`D<F5S(#T@0&9T<%]N8E]C;VYT:6YU92`H)'1H:7,M
M/E]H86YD;&4I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)')E<R`]($!F='!?9V5T*"1T:&ES+3Y?:&%N9&QE+"`D;&]C
M86Q?9FEL92P@)')E;6]T95]F:6QE+"`D;6]D92D["B`@("`@("`@?0H@("`@
M("`@(&EF("@A)')E<RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H(D9I;&4@)R1R96UO=&5?9FEL92<@8V]U;&0@;F]T(&)E(&1O
M=VYL;V%D960@=&\@)R1L;V-A;%]F:6QE)RXB+"!.151?1E107T524E]/5D52
M5U))5$5,3T-!3$9)3$5?1D%)3$5$*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!4:&ES(&9U;F-T:6]N('=I;&P@=7!L;V%D(&$@9FEL92!T;R!T
M:&4@9G1P+7-E<G9E<BX@66]U(&-A;B!E:71H97(@<W!E8VEF>2!A(&%B<V]L
M=71E"B`@("`@*B!P871H('1O('1H92!R96UO=&4M9FEL92`H8F5G:6YN:6YG
M('=I=&@@(B\B*2!O<B!A(')E;&%T:79E(&]N92P@=VAI8V@@=VEL;"!B92!C
M;VUP;&5T960*("`@("`J('=I=&@@=&AE(&%C='5A;"!D:7)E8W1O<GD@>6]U
M('-E;&5C=&5D(&]N('1H92!S97)V97(N(%EO=2!C86X@<W!E8VEF>0H@("`@
M("H@=&AE('!A=&@@9G)O;2!W:&EC:"!T:&4@9FEL92!W:6QL(&)E('5P;&]A
M9&5D(&]N('1H92!L;V-A;`H@("`@("H@;6%S8VAI;F4L(&EF('1H92!F:6QE
M('-H;W5L9"!B92!O=F5R=W)I='1E;B!I9B!I="!E>&ES=',@*&]P=&EO;F%L
M;'DL(&1E9F%U;'0@:7,*("`@("`J(&YO(&]V97)W<FET:6YG*2!A;F0@:6X@
M=VAI8V@@;6]D92`H1E107T%30TE)(&]R($944%]"24Y!4EDI('1H92!F:6QE
M('-H;W5L9"!B90H@("`@("H@9&]W;FQO861E9"`H:68@>6]U(&1O(&YO="!S
M<&5C:69Y('1H:7,L('1H92!M971H;V0@=')I97,@=&\@9&5T97)M:6YE(&ET
M(&%U=&]M871I8V%L;'D*("`@("`J(&9R;VT@=&AE(&UO9&4M9&ER96-T;W)Y
M(&]R('5S97,@=&AE(&1E9F%U;'0M;6]D92P@<V5T(&)Y('EO=2DN($EF('EO
M=2!G:79E(&$@<F5L871I=F4*("`@("`J('!A=&@@=&\@=&AE(&QO8V%L+69I
M;&4L('1H92!S8W)I<'0M<&%T:"!I<R!U<V5D(&%S(&)A<V5P871H+@H@("`@
M("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'!A<F%M("`@<W1R
M:6YG("1L;V-A;%]F:6QE("!4:&4@;&]C86P@9FEL92!T;R!U<&QO860*("`@
M("`J($!P87)A;2`@('-T<FEN9R`D<F5M;W1E7V9I;&4@5&AE(&%B<V]L=71E
M(&]R(')E;&%T:79E('!A=&@@=&\@=&AE(&9I;&4@=&\@=7!L;V%D('1O"B`@
M("`@*B!`<&%R86T@("!B;V]L("`@)&]V97)W<FET92`@("AO<'1I;VYA;"D@
M5VAE=&AE<B!T;R!O=F5R=W)I=&4@97AI<W1I;F<@9FEL90H@("`@("H@0'!A
M<F%M("`@:6YT("`@("1M;V1E("`@("`@("`H;W!T:6]N86PI($5I=&AE<B!&
M5%!?05-#24D@;W(@1E107T))3D%260H@("`@("H@0')E='5R;B`@;6EX960@
M("`@("`@("`@("`@("!4<G5E(&]N('-U8V-E<W,L(&]T:&5R=VES92!014%2
M.CI%<G)O<@H@("`@("H@0'-E92`@("`@3D547T944%]%4E)?3$]#04Q&24Q%
M3D]415A)4U0L($Y%5%]&5%!?15)27T]615)74DE415)%34]4149)3$5?1D]2
M0DE$1$5.+"!.151?1E107T524E]54$Q/041&24Q%7T9!24Q%1`H@("`@("HO
M"B`@("`*("`@(&9U;F-T:6]N('!U="@D;&]C86Q?9FEL92P@)')E;6]T95]F
M:6QE+"`D;W9E<G=R:71E(#T@9F%L<V4L("1M;V1E(#T@;G5L;"D*("`@('L*
M("`@("`@("!I9B`H(6ES<V5T*"1M;V1E*2D@>PH@("`@("`@("`@("`D;6]D
M92`]("1T:&ES+3YC:&5C:T9I;&5%>'1E;G-I;VXH)&QO8V%L7V9I;&4I.PH@
M("`@("`@('T*("`@("`@("`D<F5M;W1E7V9I;&4@/2`D=&AI<RT^7V-O;G-T
M<G5C=%]P871H*"1R96UO=&5?9FEL92D["@H@("`@("`@(&EF("@A0&9I;&5?
M97AI<W1S*"1L;V-A;%]F:6QE*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H(DQO8V%L(&9I;&4@)R1L;V-A;%]F:6QE)R!D;V5S
M(&YO="!E>&ES="XB+"!.151?1E107T524E],3T-!3$9)3$5.3U1%6$E35"D[
M"B`@("`@("`@?0H@("`@("`@(&EF("@H0&9T<%]S:7IE*"1T:&ES+3Y?:&%N
M9&QE+"`D<F5M;W1E7V9I;&4I("$]("TQ*2`F)B`A)&]V97)W<FET92D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(E)E;6]T92!F
M:6QE("<D<F5M;W1E7V9I;&4G(&5X:7-T<R!A;F0@;6%Y(&YO="!B92!O=F5R
M=W)I=&5N+B(L($Y%5%]&5%!?15)27T]615)74DE415)%34]4149)3$5?1D]2
M0DE$1$5.*3L*("`@("`@("!]"@H@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES
M=',H)V9T<%]N8E]P=70G*2E["B`@("`@("`@("`@("1R97,@/2!`9G1P7VYB
M7W!U="@D=&AI<RT^7VAA;F1L92P@)')E;6]T95]F:6QE+"`D;&]C86Q?9FEL
M92P@)&UO9&4I.PH@("`@("`@("`@("!W:&EL92`H)')E<R`]/2!&5%!?34]2
M141!5$$I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?86YN;W5N8V4H)VYB
M7W!U="<I.PH@("`@("`@("`@("`@("`@)')E<R`]($!F='!?;F)?8V]N=&EN
M=64H)'1H:7,M/E]H86YD;&4I.PH@("`@("`@("`@("!]"@H@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1R97,@/2!`9G1P7W!U="@D=&AI<RT^7VAA
M;F1L92P@)')E;6]T95]F:6QE+"`D;&]C86Q?9FEL92P@)&UO9&4I.PH@("`@
M("`@('T*("`@("`@("!I9B`H(21R97,I('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*")&:6QE("<D;&]C86Q?9FEL92<@8V]U;&0@
M;F]T(&)E('5P;&]A9&5D('1O("<D<F5M;W1E7V9I;&4G+B(L($Y%5%]&5%!?
M15)27U503$]!1$9)3$5?1D%)3$5$*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!4:&ES(&9U;F-T:6]N86QI='D@86QL;W=S('EO=2!T;R!T<F%N
M<V9E<B!A('=H;VQE(&1I<F5C=&]R>2US=')U8W1U<F4@9G)O;2!T:&4*("`@
M("`J(')E;6]T92UF='`@=&\@>6]U<B!L;V-A;"!H;W-T+B!9;W4@:&%V92!T
M;R!G:79E(&$@<F5M;W1E+61I<F5C=&]R>2`H96YD:6YG('=I=&@*("`@("`J
M("<O)RD@86YD('1H92!L;V-A;"!D:7)E8W1O<GD@*&5N9&EN9R!W:71H("<O
M)RD@=VAE<F4@=&\@<'5T('1H92!F:6QE<R!Y;W4@9&]W;FQO860N"B`@("`@
M*B!4:&4@<F5M;W1E('!A=&@@:7,@875T;VUA=&EC86QL>2!C;VUP;&5T960@
M=VET:"!T:&4@8W5R<F5N="UR96UO=&4M9&ER+"!I9B!Y;W4@9VEV90H@("`@
M("H@82!R96QA=&EV92!P871H('1O('1H:7,@9G5N8W1I;VXN(%EO=2!C86X@
M9VEV92!A(')E;&%T:79E('!A=&@@9F]R('1H92`D;&]C86Q?<&%T:"P*("`@
M("`J('1O;RX@5&AE;B!T:&4@<V-R:7!T+6)A<V5D:7(@=VEL;"!B92!U<V5D
M(&9O<B!C;VUL971I;VX@;V8@=&AE('!A=&@N"B`@("`@*B!4:&4@<&%R86UE
M=&5R("1O=F5R=W)I=&4@=VEL;"!D971E<FUI;F4L('=H971H97(@=&\@;W9E
M<G=R:71E(&5X:7-T:6YG(&9I;&5S(&]R(&YO="X*("`@("`J(%-T86YD87)D
M(&9O<B!T:&ES(&ES(&9A;'-E+B!&;W5R=&@@>6]U(&-A;B!E>'!L:6-I=&QY
M('-E="!A(&UO9&4@9F]R(&%L;"!T<F%N<V9E<BT*("`@("`J(&%C=&EO;G,@
M9&]N92X@268@>6]U(&1O(&YO="!S970@=&AI<RP@=&AE(&UE=&AO9"!T<FEE
M<R!T;R!D971E<FUI;F4@=&AE('1R86YS9F5R+0H@("`@("H@;6]D92!B>2!C
M:&5C:VEN9R!Y;W5R(&UO9&4M9&ER96-T;W)Y(&9O<B!T:&4@9FEL92UE>'1E
M;G-I;VXN($EF('1H92!E>'1E;G-I;VX@:7,@;F]T"B`@("`@*B!I;G-I9&4@
M=&AE(&UO9&4M9&ER96-T;W)Y+"!I="!W:6QL(&=E="!Y;W5R(&1E9F%U;'0M
M;6]D92X*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!P
M87)A;2`@('-T<FEN9R`D<F5M;W1E7W!A=&@@5&AE('!A=&@@=&\@9&]W;FQO
M860*("`@("`J($!P87)A;2`@('-T<FEN9R`D;&]C86Q?<&%T:"`@5&AE('!A
M=&@@=&\@9&]W;FQO860@=&\*("`@("`J($!P87)A;2`@(&)O;VP@("`D;W9E
M<G=R:71E("`@*&]P=&EO;F%L*2!7:&5T:&5R('1O(&]V97)W<FET92!E>&ES
M=&EN9R!F:6QE<R`H=')U92D@;W(@;F]T("AF86QS92P@<W1A;F1A<F0I+@H@
M("`@("H@0'!A<F%M("`@:6YT("`@("1M;V1E("`@("`@("`H;W!T:6]N86PI
M(%1H92!T<F%N<V9E<FUO9&4@*&5I=&AE<B!&5%!?05-#24D@;W(@1E107T))
M3D%262DN"B`@("`@*B!`<F5T=7)N("!M:7AE9"`@("`@("`@("`@("`@(%1R
M=64@;VX@<W5C8V5S+"!O=&AE<G=I<V4@4$5!4CHZ17)R;W(*("`@("`J($!S
M964@("`@($Y%5%]&5%!?15)27T]615)74DE414Q/0T%,1DE,15]&3U)"241$
M14XL($Y%5%]&5%!?15)27T]615)74DE414Q/0T%,1DE,15]&04E,140L($Y%
M5%]&5%!?15)27T]615)74DE414Q/0T%,1DE,15]&04E,140L($Y%5%]&5%!?
M15)27U)%34]415!!5$A.3T1)4BP@3D547T944%]%4E)?3$]#04Q0051(3D]$
M25(L3D547T944%]%4E)?0U)%051%3$]#04Q$25)?1D%)3$5$"B`@("`@*B\*
M("`@(`H@("`@9G5N8W1I;VX@9V5T4F5C=7)S:79E*"1R96UO=&5?<&%T:"P@
M)&QO8V%L7W!A=&@L("1O=F5R=W)I=&4@/2!F86QS92P@)&UO9&4@/2!N=6QL
M*0H@("`@>PH@("`@("`@("1R96UO=&5?<&%T:"`]("1T:&ES+3Y?8V]N<W1R
M=6-T7W!A=&@H)')E;6]T95]P871H*3L*("`@("`@("!I9B`H(21T:&ES+3Y?
M8VAE8VM?9&ER*"1R96UO=&5?<&%T:"DI('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*")':79E;B!R96UO=&4M<&%T:"`G)')E;6]T
M95]P871H)R!S965M<R!N;W0@=&\@8F4@82!D:7)E8W1O<GDN(BP@3D547T94
M4%]%4E)?4D5-3U1%4$%42$Y/1$E2*3L*("`@("`@("!]"B`@("`@("`@:68@
M*"$D=&AI<RT^7V-H96-K7V1I<B@D;&]C86Q?<&%T:"DI('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")':79E;B!L;V-A;"UP871H
M("<D;&]C86Q?<&%T:"<@<V5E;7,@;F]T('1O(&)E(&$@9&ER96-T;W)Y+B(L
M($Y%5%]&5%!?15)27TQ/0T%,4$%42$Y/1$E2*3L*("`@("`@("!]"@H@("`@
M("`@(&EF("@A0&ES7V1I<B@D;&]C86Q?<&%T:"DI('L*("`@("`@("`@("`@
M)')E<R`]($!M:V1I<B@D;&]C86Q?<&%T:"D["B`@("`@("`@("`@(&EF("@A
M)')E<RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*")#;W5L9"!N;W0@8W)E871E(&1I<B`G)&QO8V%L7W!A=&@G(BP@3D54
M7T944%]%4E)?0U)%051%3$]#04Q$25)?1D%)3$5$*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("`D9&ER7VQI<W0@/2!A<G)A>2@I.PH@("`@
M("`@("1D:7)?;&ES="`]("1T:&ES+3YL<R@D<F5M;W1E7W!A=&@L($Y%5%]&
M5%!?1$E24U]/3DQ9*3L*("`@("`@("!F;W)E86-H("@D9&ER7VQI<W0@87,@
M)&1I<E]E;G1R>2D@>PH@("`@("`@("`@("!I9B`H)&1I<E]E;G1R>5LG;F%M
M92==("$]("<N)R`F)B`D9&ER7V5N=')Y6R=N86UE)UT@(3T@)RXN)RD@>PH@
M("`@("`@("`@("`@("`@)')E;6]T95]P871H7VYE=R`]("1R96UO=&5?<&%T
M:"XD9&ER7V5N=')Y6R)N86UE(ETN(B\B.PH@("`@("`@("`@("`@("`@)&QO
M8V%L7W!A=&A?;F5W(#T@)&QO8V%L7W!A=&@N)&1I<E]E;G1R>5LB;F%M92)=
M+B(O(CL*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^9V5T4F5C
M=7)S:79E*"1R96UO=&5?<&%T:%]N97<L("1L;V-A;%]P871H7VYE=RP@)&]V
M97)W<FET92P@)&UO9&4I.PH@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YI
M<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("`@("`@)&9I;&5?;&ES="`](&%R<F%Y*"D["B`@("`@("`@
M)&9I;&5?;&ES="`]("1T:&ES+3YL<R@D<F5M;W1E7W!A=&@L($Y%5%]&5%!?
M1DE,15-?3TY,62D["B`@("`@("`@9F]R96%C:"`H)&9I;&5?;&ES="!A<R`D
M9FEL95]E;G1R>2D@>PH@("`@("`@("`@("`D<F5M;W1E7V9I;&4@/2`D<F5M
M;W1E7W!A=&@N)&9I;&5?96YT<GE;(FYA;64B73L*("`@("`@("`@("`@)&QO
M8V%L7V9I;&4@/2`D;&]C86Q?<&%T:"XD9FEL95]E;G1R>5LB;F%M92)=.PH@
M("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F=E="@D<F5M;W1E7V9I;&4L
M("1L;V-A;%]F:6QE+"`D;W9E<G=R:71E+"`D;6]D92D["B`@("`@("`@("`@
M(&EF("@D=&AI<RT^:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES
M(&9U;F-T:6]N86QI='D@86QL;W=S('EO=2!T;R!T<F%N<V9E<B!A('=H;VQE
M(&1I<F5C=&]R>2US=')U8W1U<F4@9G)O;2!Y;W5R"B`@("`@*B!L;V-A;"!H
M;W-T('1O('1H92!R96UO=&4M9G1P+B!9;W4@:&%V92!T;R!G:79E(&$@<F5M
M;W1E+61I<F5C=&]R>2`H96YD:6YG('=I=&@*("`@("`J("<O)RD@86YD('1H
M92!L;V-A;"!D:7)E8W1O<GD@*&5N9&EN9R!W:71H("<O)RD@=VAE<F4@=&\@
M<'5T('1H92!F:6QE<R!Y;W4@9&]W;FQO860N"B`@("`@*B!4:&4@<F5M;W1E
M('!A=&@@:7,@875T;VUA=&EC86QL>2!C;VUP;&5T960@=VET:"!T:&4@8W5R
M<F5N="UR96UO=&4M9&ER+"!I9B!Y;W4@9VEV90H@("`@("H@82!R96QA=&EV
M92!P871H('1O('1H:7,@9G5N8W1I;VXN(%EO=2!C86X@9VEV92!A(')E;&%T
M:79E('!A=&@@9F]R('1H92`D;&]C86Q?<&%T:"P*("`@("`J('1O;RX@5&AE
M;B!T:&4@<V-R:7!T+6)A<V5D:7(@=VEL;"!B92!U<V5D(&9O<B!C;VUL971I
M;VX@;V8@=&AE('!A=&@N"B`@("`@*B!4:&4@<&%R86UE=&5R("1O=F5R=W)I
M=&4@=VEL;"!D971E<FUI;F4L('=H971H97(@=&\@;W9E<G=R:71E(&5X:7-T
M:6YG(&9I;&5S(&]R(&YO="X*("`@("`J(%-T86YD87)D(&9O<B!T:&ES(&ES
M(&9A;'-E+B!&;W5R=&@@>6]U(&-A;B!E>'!L:6-I=&QY('-E="!A(&UO9&4@
M9F]R(&%L;"!T<F%N<V9E<BT*("`@("`J(&%C=&EO;G,@9&]N92X@268@>6]U
M(&1O(&YO="!S970@=&AI<RP@=&AE(&UE=&AO9"!T<FEE<R!T;R!D971E<FUI
M;F4@=&AE('1R86YS9F5R+0H@("`@("H@;6]D92!B>2!C:&5C:VEN9R!Y;W5R
M(&UO9&4M9&ER96-T;W)Y(&9O<B!T:&4@9FEL92UE>'1E;G-I;VXN($EF('1H
M92!E>'1E;G-I;VX@:7,@;F]T"B`@("`@*B!I;G-I9&4@=&AE(&UO9&4M9&ER
M96-T;W)Y+"!I="!W:6QL(&=E="!Y;W5R(&1E9F%U;'0M;6]D92X*("`@("`J
M"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!P87)A;2`@('-T<FEN
M9R`D<F5M;W1E7W!A=&@@5&AE('!A=&@@=&\@9&]W;FQO860@"B`@("`@*B!`
M<&%R86T@("!S=')I;F<@)&QO8V%L7W!A=&@@(%1H92!P871H('1O(&1O=VYL
M;V%D('1O"B`@("`@*B!`<&%R86T@("!B;V]L("`@)&]V97)W<FET92`@("AO
M<'1I;VYA;"D@5VAE=&AE<B!T;R!O=F5R=W)I=&4@97AI<W1I;F<@9FEL97,@
M*'1R=64I(&]R(&YO="`H9F%L<V4L('-T86YD87)D*2X*("`@("`J($!P87)A
M;2`@(&EN="`@("`D;6]D92`@("`@("`@*&]P=&EO;F%L*2!4:&4@=')A;G-F
M97)M;V1E("AE:71H97(@1E107T%30TE)(&]R($944%]"24Y!4EDI+@H@("`@
M("H@0')E='5R;B`@;6EX960@("`@("`@("`@("`@("!4<G5E(&]N('-U8V-E
M<RP@;W1H97)W:7-E(%!%05(Z.D5R<F]R"B`@("`@*B!`<V5E("`@("!.151?
M1E107T524E],3T-!3$9)3$5.3U1%6$E35"P@3D547T944%]%4E)?3U9%4E=2
M251%4D5-3U1%1DE,15]&3U)"241$14XL($Y%5%]&5%!?15)27U503$]!1$9)
M3$5?1D%)3$5$+"!.151?1E107T524E],3T-!3%!!5$A.3T1)4BP@3D547T94
M4%]%4E)?4D5-3U1%4$%42$Y/1$E2"B`@("`@*B\*("`@(`H@("`@9G5N8W1I
M;VX@<'5T4F5C=7)S:79E*"1L;V-A;%]P871H+"`D<F5M;W1E7W!A=&@L("1O
M=F5R=W)I=&4@/2!F86QS92P@)&UO9&4@/2!N=6QL*0H@("`@>PH@("`@("`@
M("1R96UO=&5?<&%T:"`]("1T:&ES+3Y?8V]N<W1R=6-T7W!A=&@H)')E;6]T
M95]P871H*3L*("`@("`@("!I9B`H(21T:&ES+3Y?8VAE8VM?9&ER*"1L;V-A
M;%]P871H*2!\?"`A:7-?9&ER*"1L;V-A;%]P871H*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D=I=F5N(&QO8V%L+7!A=&@@
M)R1L;V-A;%]P871H)R!S965M<R!N;W0@=&\@8F4@82!D:7)E8W1O<GDN(BP@
M3D547T944%]%4E)?3$]#04Q0051(3D]$25(I.PH@("`@("`@('T*("`@("`@
M("!I9B`H(21T:&ES+3Y?8VAE8VM?9&ER*"1R96UO=&5?<&%T:"DI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")':79E;B!R96UO
M=&4M<&%T:"`G)')E;6]T95]P871H)R!S965M<R!N;W0@=&\@8F4@82!D:7)E
M8W1O<GDN(BP@3D547T944%]%4E)?4D5-3U1%4$%42$Y/1$E2*3L*("`@("`@
M("!]"B`@("`@("`@)&]L9%]P871H(#T@)'1H:7,M/G!W9"@I.PH@("`@("`@
M(&EF("@D=&AI<RT^:7-%<G)O<B@D=&AI<RT^8V0H)')E;6]T95]P871H*2DI
M('L*("`@("`@("`@("`@)')E<R`]("1T:&ES+3YM:V1I<B@D<F5M;W1E7W!A
M=&@I.PH@("`@("`@("`@("!I9B`H)'1H:7,M/FES17)R;W(H)')E<RDI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@("1T:&ES+3YC9"@D;VQD7W!A=&@I.PH@("`@("`@
M("1D:7)?;&ES="`]("1T:&ES+3Y?;'-?;&]C86PH)&QO8V%L7W!A=&@I.PH@
M("`@("`@(&9O<F5A8V@@*"1D:7)?;&ES=%LB9&ER<R)=(&%S("1D:7)?96YT
M<GDI('L*("`@("`@("`@("`@)')E;6]T95]P871H7VYE=R`]("1R96UO=&5?
M<&%T:"XD9&ER7V5N=')Y+B(O(CL*("`@("`@("`@("`@)&QO8V%L7W!A=&A?
M;F5W(#T@)&QO8V%L7W!A=&@N)&1I<E]E;G1R>2XB+R(["B`@("`@("`@("`@
M("1R97-U;'0@/2`D=&AI<RT^<'5T4F5C=7)S:79E*"1L;V-A;%]P871H7VYE
M=RP@)')E;6]T95]P871H7VYE=RP@)&]V97)W<FET92P@)&UO9&4I.PH@("`@
M("`@("`@("!I9B`H)'1H:7,M/FES17)R;W(H)')E<W5L="DI('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!F;W)E86-H("@D9&ER7VQI<W1;(F9I;&5S(ET@87,@
M)&9I;&5?96YT<GDI('L*("`@("`@("`@("`@)')E;6]T95]F:6QE(#T@)')E
M;6]T95]P871H+B1F:6QE7V5N=')Y.PH@("`@("`@("`@("`D;&]C86Q?9FEL
M92`]("1L;V-A;%]P871H+B1F:6QE7V5N=')Y.PH@("`@("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/G!U="@D;&]C86Q?9FEL92P@)')E;6]T95]F:6QE+"`D
M;W9E<G=R:71E+"`D;6]D92D["B`@("`@("`@("`@(&EF("@D=&AI<RT^:7-%
M<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES(&-H96-K<RP@=VAE=&AE
M<B!A(&9I;&4@<VAO=6QD(&)E('1R86YS9F5R960@:6X@87-C:6DM(&]R(&)I
M;F%R>2UM;V1E"B`@("`@*B!B>2!I="=S(&9I;&4M97AT96YS:6]N+B!)9B!T
M:&4@9FEL92UE>'1E;G-I;VX@:7,@;F]T('-E="!O<@H@("`@("H@=&AE(&5X
M=&5N<VEO;B!I<R!N;W0@:6YS:61E(&]N92!O9B!T:&4@97AT96YS:6]N+61I
M<G,L('1H92!A8W1U86P@<V5T"B`@("`@*B!T<F%N<V9E<BUM;V1E(&ES(')E
M='5R;F5D+@H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@
M0'!A<F%M("`@<W1R:6YG("1F:6QE;F%M92`@5&AE(&9I;&5N86UE('1O(&)E
M(&-H96-K960*("`@("`J($!R971U<FX@(&EN="`@("`@("`@("`@("`@($5I
M=&AE<B!&5%!?05-#24D@;W(@1E107T))3D%260H@("`@("HO"B`@("`*("`@
M(&9U;F-T:6]N(&-H96-K1FEL945X=&5N<VEO;B@D9FEL96YA;64I"B`@("![
M"B`@("`@("`@)'!A='1E<FX@/2`B+UPN*"XJ*20O(CL*("`@("`@("`D:&%S
M7V5X=&5N<VEO;B`]('!R96=?;6%T8V@H)'!A='1E<FXL("1F:6QE;F%M92P@
M)&5R96=S*3L*("`@("`@("!I9B`H(21H87-?97AT96YS:6]N*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7VUO9&4["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&5X="`]("1E<F5G<ULQ73L*("`@("`@("!]"@H@("`@
M("`@(&EF("@A96UP='DH)'1H:7,M/E]F:6QE7V5X=&5N<VEO;G-;)&5X=%TI
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V9I;&5?97AT96YS:6]N
M<ULD97AT73L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^7VUO
M9&4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE($AO<W1N86UE"B`@
M("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<&%R86T@("!S
M=')I;F<@)&AO<W0@5&AE($AO<W1N86UE('1O('-E=`H@("`@("H@0')E='5R
M;B`@8F]O;"!4<G5E(&]N('-U8V-E<W,L(&]T:&5R=VES92!014%2.CI%<G)O
M<@H@("`@("H@0'-E92`@("`@3D547T944%]%4E)?2$]35$Y!345.3U-44DE.
M1PH@("`@("HO"B`@("`*("`@(&9U;F-T:6]N('-E=$AO<W1N86UE*"1H;W-T
M*0H@("`@>PH@("`@("`@(&EF("@A:7-?<W1R:6YG*"1H;W-T*2D@>PH@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B2&]S=&YA;64@;75S
M="!B92!A('-T<FEN9RXB+"!.151?1E107T524E](3U-43D%-14Y/4U1224Y'
M*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]H;W-T;F%M92`]("1H;W-T
M.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4V5T('1H92!0;W)T"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@
M("`@*B!`<&%R86T@("!I;G0@)'!O<G0@("`@5&AE(%!O<G0@=&\@<V5T"B`@
M("`@*B!`<F5T=7)N("!B;V]L(%1R=64@;VX@<W5C8V5S<RP@;W1H97)W:7-E
M(%!%05(Z.D5R<F]R"B`@("`@*B!`<V5E("`@("!.151?1E107T524E]03U)4
M3$534UI%4D\*("`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!S9710;W)T*"1P
M;W)T*0H@("`@>PH@("`@("`@(&EF("@A:7-?:6YT*"1P;W)T*2!\?"`H)'!O
M<G0@/"`P*2D@>PH@("`@("`@("`@("!014%2.CIR86ES945R<F]R*"));G9A
M;&ED('!O<G0N($AA<R!T;R!B92!I;G1E9V5R(#X](#`B+"!.151?1E107T52
M4E]03U)43$534UI%4D\I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7W!O
M<G0@/2`D<&]R=#L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E="!T:&4@57-E<FYA;64*("`@("`J"B`@("`@*B!`86-C
M97-S("!P=6)L:6,*("`@("`J($!P87)A;2`@('-T<FEN9R`D=7-E<B!4:&4@
M57-E<FYA;64@=&\@<V5T"B`@("`@*B!`<F5T=7)N("!M:7AE9"!4<G5E(&]N
M('-U8V-E<W,L(&]T:&5R=VES92!014%2.CI%<G)O<@H@("`@("H@0'-E92`@
M("`@3D547T944%]%4E)?55-%4DY!345.3U-44DE.1PH@("`@("HO"B`@("`*
M("`@(&9U;F-T:6]N('-E=%5S97)N86UE*"1U<V5R*0H@("`@>PH@("`@("`@
M(&EF("AE;7!T>2@D=7-E<BD@?'P@(6ES7W-T<FEN9R@D=7-E<BDI('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U5S97)N86UE("1U
M<V5R(&EN=F%L:60N)RP@3D547T944%]%4E)?55-%4DY!345.3U-44DE.1RD[
M"B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?=7-E<FYA;64@/2`D=7-E<CL*
M("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@4&%S<W=O<F0*("`@("`J
M"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B!`<&%R86T@("!S=')I
M;F<@)'!A<W-W;W)D("!4:&4@4&%S<W=O<F0@=&\@<V5T"B`@("`@*B!`<F5T
M=7)N("!V;VED"B`@("`@*B!`<V5E("`@("!.151?1E107T524E]005-35T]2
M1$Y/4U1224Y'"B`@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@<V5T4&%S<W=O
M<F0H)'!A<W-W;W)D*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D<&%S<W=O
M<F0I('Q\("%I<U]S=')I;F<H)'!A<W-W;W)D*2D@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4&%S<W=O<F0@>'AX(&EN=F%L:60N
M)RP@3D547T944%]%4E)?4$%34U=/4D1.3U-44DE.1RD["B`@("`@("`@?0H@
M("`@("`@("1T:&ES+3Y?<&%S<W=O<F0@/2`D<&%S<W=O<F0["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!3970@=&AE('1R86YS9F5R+6UO9&4N(%EO=2!C86X@
M=7-E('1H92!P<F5D969I;F5D(&-O;G-T86YT<PH@("`@("H@1E107T%30TE)
M(&]R($944%]"24Y!4EDN(%1H92!M;V1E('=I;&P@8F4@<W1O<F5D(&9O<B!A
M;GD@9G5R=&AE<B!T<F%N<V9E<G,N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@
M<'5B;&EC"B`@("`@*B!`<&%R86T@("!I;G0@("`@)&UO9&4@(%1H92!M;V1E
M('1O('-E=`H@("`@("H@0')E='5R;B`@;6EX960@("`@("`@("!4<G5E(&]N
M('-U8V-E<W,L(&]T:&5R=VES92!014%2.CI%<G)O<@H@("`@("H@0'-E92`@
M("`@3D547T944%]%4E)?3D]-3T1%0T].4U0*("`@("`J+PH@("`@"B`@("!F
M=6YC=&EO;B!S971-;V1E*"1M;V1E*0H@("`@>PH@("`@("`@(&EF("@H)&UO
M9&4@/3T@1E107T%30TE)*2!\?"`H)&UO9&4@/3T@1E107T))3D%262DI('L*
M("`@("`@("`@("`@)'1H:7,M/E]M;V1E(#T@)&UO9&4["B`@("`@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G1E10+4UO9&4@:&%S(&5I=&AE<B!T
M;R!B92!&5%!?05-#24D@;W(@1E107T))3D%262<L($Y%5%]&5%!?15)27TY/
M34]$14-/3E-4*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M970@=&AE('1R86YS9F5R+6UE=&AO9"!T;R!P87-S:79E(&UO9&4*("`@("`J
M"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!R971U<FX@('9O:60*
M("`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!S971087-S:79E*"D*("`@('L*
M("`@("`@("`D=&AI<RT^7W!A<W-V(#T@=')U93L*("`@("`@("!`9G1P7W!A
M<W8H)'1H:7,M/E]H86YD;&4L('1R=64I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4V5T('1H92!T<F%N<V9E<BUM971H;V0@=&\@86-T:79E(&UO9&4*("`@
M("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!R971U<FX@('9O
M:60*("`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!S971!8W1I=F4H*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?<&%S<W8@/2!F86QS93L*("`@("`@("!`9G1P
M7W!A<W8H)'1H:7,M/E]H86YD;&4L(&9A;'-E*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%-E="!T:&4@=&EM96]U="!F;W(@1E10(&]P97)A=&EO;G,*("`@
M("`J(%5S92!T:&ES(&UE=&AO9"!T;R!S970@82!T:6UE;W5T(&9O<B!&5%`@
M;W!E<F%T:6]N+B!4:6UE;W5T(&AA<R!T;R!B92!A;B!I;G1E9V5R+@H@("`@
M("H*("`@("`J($!A8V5S<R`@('!U8FQI8PH@("`@("H@0'!A<F%M("`@:6YT
M("1T:6UE;W5T('1H92!T:6UE;W5T('1O('5S90H@("`@("H@0')E='5R;B`@
M8F]O;"!4<G5E(&]N('-U8V-E<W,L(&]T:&5R=VES92!014%2.CI%<G)O<@H@
M("`@("H@0'-E92`@("`@3D547T944%]%4E)?5$E-14]55$Q%4U-:15)/+"!.
M151?1E107T524E]3151424U%3U547T9!24Q%1`H@("`@("HO"B`@("`@"B`@
M("!F=6YC=&EO;B!S9714:6UE;W5T("@@)'1I;65O=70@/2`P("D@"B`@("![
M"B`@("`@("`@:68@*"%I<U]I;G0H)'1I;65O=70I('Q\("@D=&EM96]U="`\
M(#`I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")4
M:6UE;W5T("1T:6UE;W5T(&ES(&EN=F%L:60L(&AA<R!T;R!B92!A;B!I;G1E
M9V5R(#X](#`B+"!.151?1E107T524E]424U%3U543$534UI%4D\I.PH@("`@
M("`@('T*("`@("`@("`D=&AI<RT^7W1I;65O=70@/2`D=&EM96]U=#L*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]H86YD;&4I("8F(&ES7W)E<V]U<F-E
M*"1T:&ES+3Y?:&%N9&QE*2D@>PH@("`@("`@("`@("`D<F5S(#T@0&9T<%]S
M971?;W!T:6]N*"1T:&ES+3Y?:&%N9&QE+"!&5%!?5$E-14]55%]314,L("1T
M:6UE;W5T*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5S(#T@
M=')U93L*("`@("`@("!]"B`@("`@("`@:68@*"$D<F5S*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")3970@=&EM96]U="!F86EL
M960N(BP@3D547T944%]%4E)?4T545$E-14]55%]&04E,140I.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@=')U93L*("`@('T@("`@("`@(`H@("`@"B`@
M("`O*BH*("`@("`J($%D9',@86X@97AT96YS:6]N('1O(&$@;6]D92UD:7)E
M8W1O<GD*("`@("`J(%1H92!M;V1E+61I<F5C=&]R>2!S879E<R!F:6QE+65X
M=&5N<VEO;G,@8V]R97-P;VYD:6YG('1O(&9I;&5T>7!E<PH@("`@("H@*&%S
M8VEI(&4N9RXZ("=P:'`G+"`G='AT)RP@)VAT;2<L+BXN.R!B:6YA<GD@92YG
M+CH@)VIP9R<L("=G:68G+"`G97AE)RPN+BXI+@H@("`@("H@5&AE(&5X=&5N
M<VEO;G,@:&%V92!T;R!B92!S879E9"!W:71H;W5T('1H92`G+B<N($%N9`H@
M("`@("H@8V%N(&)E('!R961E9FEN960@:6X@86X@97AT97)N86P@9FEL92`H
M<V5E.B!G971%>'1E;G-I;VYS1FEL92@I*2X*("`@("`J"B`@("`@*B!4:&4@
M87)R87D@:7,@8G5I;&0@;&EK92!T:&ES.B`G<&AP)R`]/B!&5%!?05-#24DL
M("=P;F<G(#T^($944%]"24Y!4ED*("`@("`J"B`@("`@*B!4;R!C:&%N9V4@
M=&AE(&UO9&4@;V8@86X@97AT96YS:6]N+"!J=7-T(&%D9"!I="!A9V%I;B!W
M:71H('1H92!N97<@;6]D92$*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L
M:6,*("`@("`J($!P87)A;2`@(&EN="`@("`D;6]D92`@16ET:&5R($944%]!
M4T-)22!O<B!&5%!?0DE.05)9"B`@("`@*B!`<&%R86T@("!S=')I;F<@)&5X
M="`@($5X=&5N<VEO;@H@("`@("H@0')E='5R;B`@=F]I9`H@("`@("HO"B`@
M("`*("`@(&9U;F-T:6]N(&%D9$5X=&5N<VEO;B@D;6]D92P@)&5X="D*("`@
M('L*("`@("`@("`D=&AI<RT^7V9I;&5?97AT96YS:6]N<ULD97AT72`]("1M
M;V1E.PH@("`@?0H*("`@("\J*@H@("`@("H@5&AI<R!F=6YC=&EO;B!R96UO
M=F5S(&%N(&5X=&5N<VEO;B!F<F]M('1H92!M;V1E+61I<F5C=&]R:65S(`H@
M("`@("H@*&1E<V-R:6)E9"!A8F]V92DN"B`@("`@*@H@("`@("H@0&%C8V5S
M<R`@<'5B;&EC"B`@("`@*B!`<&%R86T@("!S=')I;F<@)&5X="`@5&AE(&5X
M=&5N<VEO;B!T;R!R96UO=F4*("`@("`J($!R971U<FX@('9O:60*("`@("`J
M+PH@("`@"B`@("!F=6YC=&EO;B!R96UO=F5%>'1E;G-I;VXH)&5X="D*("`@
M('L*("`@("`@("!U;G-E="@D=&AI<RT^7V9I;&5?97AT96YS:6]N<ULD97AT
M72D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES(&=E="=S(&)O=&@@*&%S
M8VEI+2!A;F0@8FEN87)Y+6UO9&4M9&ER96-T;W)I97,I(&9R;VT@=&AE(&=I
M=F5N(&9I;&4N"B`@("`@*B!"97=A<F4L(&EF('EO=2!R96%D(&$@9FEL92!I
M;G1O('1H92!M;V1E+61I<F5C=&]R>2P@86QL(&9O<FUE<B!S970@=F%L=65S
M(`H@("`@("H@=VEL;"!B92!U;G-E="$*("`@("`J"B`@("`@*B!`86-C97-S
M("!P=6)L:6,*("`@("`J($!P87)A;2`@('-T<FEN9R`D9FEL96YA;64@(%1H
M92!F:6QE('1O(&=E="!F<F]M"B`@("`@*B!`<F5T=7)N("!M:7AE9"`@("`@
M("`@("`@("!4<G5E(&]N('-U8V-E<W,L(&]T:&5R=VES92!014%2.CI%<G)O
M<@H@("`@("H@0'-E92`@("`@3D547T944%]%4E)?15A41DE,14Y/5$5825-4
M+"!.151?1E107T524E]%6%1&24Q%4D5!1%]&04E,140*("`@("`J+PH@("`@
M"B`@("!F=6YC=&EO;B!G971%>'1E;G-I;VYS1FEL92@D9FEL96YA;64I"B`@
M("!["B`@("`@("`@:68@*"%F:6QE7V5X:7-T<R@D9FEL96YA;64I*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B17AT96YS:6]N
M<RUF:6QE("<D9FEL96YA;64G(&1O97,@;F]T(&5X:7-T(BP@3D547T944%]%
M4E)?15A41DE,14Y/5$5825-4*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A
M:7-?<F5A9&%B;&4H)&9I;&5N86UE*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H(D5X=&5N<VEO;G,M9FEL92`G)&9I;&5N86UE
M)R!I<R!N;W0@<F5A9&%B;&4B+"!.151?1E107T524E]%6%1&24Q%4D5!1%]&
M04E,140I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]F:6QE7V5X=&5N
M<VEO;B`]($!P87)S95]I;FE?9FEL92@D9FEL96YA;64I.PH@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M2&]S=&YA;64*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J
M($!R971U<FX@('-T<FEN9R`@5&AE($AO<W1N86UE"B`@("`@*B\*("`@(`H@
M("`@9G5N8W1I;VX@9V5T2&]S=&YA;64H*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7VAO<W1N86UE.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@4&]R=`H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@
M("`@("H@0')E='5R;B`@:6YT("`@("!4:&4@4&]R=`H@("`@("HO"B`@("`*
M("`@(&9U;F-T:6]N(&=E=%!O<G0H*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^7W!O<G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!5<V5R;F%M90H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@
M("H@0')E='5R;B`@<W1R:6YG("!4:&4@57-E<FYA;64*("`@("`J+PH@("`@
M"B`@("!F=6YC=&EO;B!G9715<V5R;F%M92@I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?=7-E<FYA;64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!087-S=V]R9`H@("`@("H*("`@("`J($!A8V-E<W,@('!U
M8FQI8PH@("`@("H@0')E='5R;B`@<W1R:6YG("!4:&4@4&%S<W=O<F0*("`@
M("`J+PH@("`@"B`@("!F=6YC=&EO;B!G971087-S=V]R9"@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?<&%S<W=O<F0["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92!4<F%N<V9E<FUO9&4*("`@("`J"B`@("`@
M*B!`86-C97-S("!P=6)L:6,*("`@("`J($!R971U<FX@(&EN="`@("`@5&AE
M('1R86YS9F5R;6]D92P@96ET:&5R($944%]!4T-)22!O<B!&5%!?0DE.05)9
M+@H@("`@("HO"B`@("`*("`@(&9U;F-T:6]N(&=E=$UO9&4H*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7VUO9&4["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS+"!W:&5T:&5R('1H92!C;VYN96-T:6]N(&ES('-E="!T
M;R!P87-S:79E(&UO9&4@;W(@;F]T"B`@("`@*@H@("`@("H@0&%C8V5S<R`@
M<'5B;&EC"B`@("`@*B!`<F5T=7)N("!B;V]L("`@(%1R=64@:68@<&%S<VEV
M92TL(&9A;'-E(&EF(&%C=&EV92UM;V1E"B`@("`@*B\*("`@(`H@("`@9G5N
M8W1I;VX@:7-087-S:79E*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/E]P87-S=CL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&UO
M9&4@<V5T(&9O<B!A(&9I;&4M97AT96YS:6]N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R`@<'5B;&EC"B`@("`@*B!`<&%R86T@("!S=')I;F<@("`D97AT("`@
M(%1H92!E>'1E;G-I;VX@>6]U('=A;FYA(&%S:R!F;W(*("`@("`J($!R971U
M<FX@(&EN="`@("`@("`@("`@("`@16ET:&5R($944%]!4T-)22P@1E107T))
M3D%262!O<B!.54Q,("AI9B!N;W0@<V5T(&$@;6]D92!F;W(@:70I"B`@("`@
M*B\*("`@(`H@("`@9G5N8W1I;VX@9V5T17AT96YS:6]N36]D92@D97AT*0H@
M("`@>PH@("`@("`@(')E='5R;B!`)'1H:7,M/E]F:6QE7V5X=&5N<VEO;G-;
M)&5X=%T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE(&-U<G)E;G1L
M>2!S970@=&EM96]U="X*("`@("`J(%)E='5R;G,@=&AE(&%C='5A;"!T:6UE
M;W5T('-E="X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@
M0')E='5R;B!I;G0@5&AE(&%C='5A;"!T:6UE;W5T"B`@("`@*B\*("`@(`H@
M("`@9G5N8W1I;VX@9V5T5&EM96]U="`H("D*("`@('L*("`@("`@("!R971U
M<FX@9G1P7V=E=%]O<'1I;VXH)'1H:7,M/E]H86YD;&4L($944%]424U%3U54
M7U-%0RD["B`@("!]("`@(`H*("`@("\J*@H@("`@("H@061D<R!A($YE=%]&
M5%!?3V)S97)V97(@:6YS=&%N8V4@=&\@=&AE(&QI<W0@;V8@;V)S97)V97)S
M(`H@("`@("H@=&AA="!A<F4@;&ES=&5N:6YG(&9O<B!M97-S86=E<R!E;6ET
M=&5D(&)Y('1H:7,@3F5T7T944"!I;G-T86YC92X*("`@("`J"B`@("`@*B!`
M<&%R86T@("!O8FIE8W0@("`D;V)S97)V97(@("`@(%1H92!.971?1E107T]B
M<V5R=F5R(&EN<W1A;F-E('1O(&%T=&%C:"`*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87,@82!L:7-T96YE<BX*("`@("`J($!R
M971U<FX@(&)O;VQE86X@("`@("`@("`@("`@("`@5')U92!I9B!T:&4@;V)S
M97)V97(@:7,@<W5C8V5S<V9U;&QY(&%T=&%C:&5D+@H@("`@("H@0&%C8V5S
M<R`@<'5B;&EC"B`@("`@*B!`<VEN8V4@("`Q+C,*("`@("`J+PH@("`@"B`@
M("!F=6YC=&EO;B!A='1A8V@H)B1O8G-E<G9E<BD*("`@('L*("`@("`@("!I
M9B`H(6ES7V$H)&]B<V5R=F5R+"`G3F5T7T944%]/8G-E<G9E<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1T
M:&ES+3Y?;&ES=&5N97)S6R1O8G-E<G9E<BT^9V5T260H*5T@/2`F)&]B<V5R
M=F5R.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5M;W9E<R!A($YE=%]&5%!?3V)S97)V97(@:6YS=&%N8V4@9G)O;2!T
M:&4@;&ES="!O9B!O8G-E<G9E<G,N"B`@("`@*@H@("`@("H@0'!A<F%M("`@
M;V)J96-T("`@)&]B<V5R=F5R("`@("!4:&4@3F5T7T944%]/8G-E<G9E<B!I
M;G-T86YC92!T;R!D971A8V@@"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&9R;VT@=&AE(&QI<W0@;V8@;&ES=&5N97)S+@H@("`@
M("H@0')E='5R;B`@8F]O;&5A;B`@("`@("`@("`@("`@("!4<G5E(&EF('1H
M92!O8G-E<G9E<B!I<R!S=6-C97-S9G5L;'D@9&5T86-H960N"B`@("`@*B!`
M86-C97-S("!P=6)L:6,*("`@("`J($!S:6YC92`@(#$N,PH@("`@("HO"B`@
M("`*("`@(&9U;F-T:6]N(&1E=&%C:"@D;V)S97)V97(I"B`@("!["B`@("`@
M("`@:68@*"%I<U]A*"1O8G-E<G9E<BP@)TYE=%]&5%!?3V)S97)V97(G*2!\
M?`H@("`@("`@("`@("`A:7-S970H)'1H:7,M/E]L:7-T96YE<G-;)&]B<V5R
M=F5R+3YG971)9"@I72DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@=6YS970H)'1H:7,M/E]L:7-T96YE<G-;)&]B
M<V5R=F5R+3YG971)9"@I72D["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!);F9O<FUS(&5A8V@@<F5G:7-T97)E9"!O8G-E
M<G9E<B!I;G-T86YC92!T:&%T(&$@;F5W(&UE<W-A9V4@:&%S(&)E96X*("`@
M("`J('-E;G0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@"B`@("`@*B!`<&%R86T@("!M:7AE9"`@("`@)&5V
M96YT("`@("`@($$@:&%S:"!D97-C<FEB:6YG('1H92!N970@979E;G0N("`@
M"B`@("`@*B!`86-C97-S("!P<FEV871E("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`*("`@("`J($!S:6YC
M92`@(#$N,R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(`H@("`@("HO("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@"B`@("`*("`@(&9U;F-T:6]N(%]A;FYO=6YC92@D979E;G0I"B`@
M("!["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]L:7-T96YE<G,@87,@)&ED
M(#T^("1L:7-T96YE<BD@>PH@("`@("`@("`@("`D=&AI<RT^7VQI<W1E;F5R
M<ULD:61=+3YN;W1I9GDH)&5V96YT*3L*("`@("`@("!]"B`@("!]"B`@("`*
M("`@("`@("`O*BH*("`@("`J(%)E8G5I;&0@=&AE('!A=&@L(&EF(&=I=F5N
M(')E;&%T:79E"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@
M("H@0'!A<F%M("`@<W1R:6YG("1P871H("`@5&AE('!A=&@@=&\@8VAE8VL@
M86YD(&-O;G-T<G5C=`H@("`@("H@0')E='5R;B`@<W1R:6YG("`@("`@("`@
M5&AE(&)U:6QD('!A=&@*("`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!?8V]N
M<W1R=6-T7W!A=&@H)'!A=&@I"B`@("!["B`@("`@("`@:68@*"AS=6)S='(H
M)'!A=&@L(#`L(#$I("$]("(O(BD@)B8@*'-U8G-T<B@D<&%T:"P@,"P@,BD@
M(3T@(BXO(BDI('L*("`@("`@("`@("`@)&%C='5A;%]D:7(@/2!`9G1P7W!W
M9"@D=&AI<RT^7VAA;F1L92D["B`@("`@("`@("`@(&EF("AS=6)S='(H)&%C
M='5A;%]D:7(L("AS=')L96XH)&%C='5A;%]D:7(I("T@,BDL(#$I("$]("(O
M(BD@>PH@("`@("`@("`@("`@("`@)&%C='5A;%]D:7(@+CT@(B\B.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1P871H(#T@)&%C='5A;%]D:7(N)'!A
M=&@["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<&%T:#L*("`@('T*"B`@
M("`O*BH*("`@("`J($-H96-K<RP@=VAE=&AE<B!A(&=I=F5N('-T<FEN9R!I
M<R!A(&1I<F5C=&]R>2UP871H("AE;F1S('=I=&@@(B\B*2!O<B!N;W0N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("H@0'!A<F%M("`@
M<W1R:6YG("1P871H("!0871H('1O(&-H96-K"B`@("`@*B!`<F5T=7)N("!B
M;V]L("`@("`@("`@(%1R=64@:68@)'!A=&@@:7,@82!D:7)E8W1O<GDL(&]T
M:&5R=VES92!F86QS90H@("`@("HO"B`@("`*("`@(&9U;F-T:6]N(%]C:&5C
M:U]D:7(H)'!A=&@I"B`@("!["B`@("`@("`@:68@*"%E;7!T>2@D<&%T:"D@
M)B8@<W5B<W1R*"1P871H+"`H<W1R;&5N*"1P871H*2`M(#$I+"`Q*2`]/2`B
M+R(I('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J(%1H:7,@=VEL;"!R96UO=F4@82!F:6QE"B`@("`@
M*@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("H@0'!A<F%M("`@<W1R
M:6YG("1F:6QE("`@5&AE(&9I;&4@=&\@9&5L971E"B`@("`@*B!`<F5T=7)N
M("!M:7AE9"`@("`@("`@("!4<G5E(&]N('-U8V-E<W,L(&]T:&5R=VES92!0
M14%2.CI%<G)O<@H@("`@("H@0'-E92`@("`@3D547T944%]%4E)?1$5,151%
M1DE,15]&04E,140*("`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!?<FU?9FEL
M92@D9FEL92D*("`@('L*("`@("`@("!I9B`H<W5B<W1R*"1F:6QE+"`P+"`Q
M*2`A/2`B+R(I('L*("`@("`@("`@("`@)&%C='5A;%]D:7(@/2!`9G1P7W!W
M9"@D=&AI<RT^7VAA;F1L92D["B`@("`@("`@("`@(&EF("AS=6)S='(H)&%C
M='5A;%]D:7(L("AS=')L96XH)&%C='5A;%]D:7(I("T@,BDL(#$I("$]("(O
M(BD@>PH@("`@("`@("`@("`@("`@)&%C='5A;%]D:7(@+CT@(B\B.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1F:6QE(#T@)&%C='5A;%]D:7(N)&9I
M;&4["B`@("`@("`@?0H@("`@("`@("1R97,@/2!`9G1P7V1E;&5T92@D=&AI
M<RT^7VAA;F1L92P@)&9I;&4I.PH@("`@("`@(`H@("`@("`@(&EF("@A)')E
M<RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D-O
M=6QD(&YO="!D96QE=&4@9FEL92`G)&9I;&4G+B(L($Y%5%]&5%!?15)27T1%
M3$54149)3$5?1D%)3$5$*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!R971U<FX@=')U93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!4:&ES('=I;&P@<F5M;W9E(&$@9&ER"B`@("`@*@H@("`@("H@0&%C8V5S
M<R`@<')I=F%T90H@("`@("H@0'!A<F%M("`@<W1R:6YG("1D:7(@(%1H92!D
M:7(@=&\@9&5L971E"B`@("`@*B!`<F5T=7)N("!M:7AE9"`@("`@("`@5')U
M92!O;B!S=6-C97-S+"!O=&AE<G=I<V4@4$5!4CHZ17)R;W(*("`@("`J($!S
M964@("`@($Y%5%]&5%!?15)27U)%34]415!!5$A.3T1)4BP@3D547T944%]%
M4E)?1$5,151%1$E27T9!24Q%1`H@("`@("HO"B`@("`*("`@(&9U;F-T:6]N
M(%]R;5]D:7(H)&1I<BD*("`@('L*("`@("`@("!I9B`H<W5B<W1R*"1D:7(L
M("AS=')L96XH)&1I<BD@+2`Q*2P@,2D@(3T@(B\B*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B1&ER96-T;W)Y(&YA;64@)R1D
M:7(G(&ES(&EN=F%L:60L(&AA<R!T;R!E;F0@=VET:"`G+R<B+"!.151?1E10
M7T524E]214U/5$50051(3D]$25(I.PH@("`@("`@('T*("`@("`@("`D<F5S
M(#T@0&9T<%]R;61I<B@D=&AI<RT^7VAA;F1L92P@)&1I<BD["B`@("`@("`@
M:68@*"$D<F5S*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@B0V]U;&0@;F]T(&1E;&5T92!D:7)E8W1O<GD@)R1D:7(G+B(L($Y%
M5%]&5%!?15)27T1%3$54141)4E]&04E,140I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%1H:7,@=VEL;"!R96UO=F4@82!D:7(@86YD(&%L;"!S
M=6)D:7)S(&%N9"`M9FEL97,*("`@("`J"B`@("`@*B!`86-C97-S("!P<FEV
M871E"B`@("`@*B!`<&%R86T@("!S=')I;F<@)&9I;&4@(%1H92!D:7(@=&\@
M9&5L971E(')E8W5R<VEV96QY"B`@("`@*B!`<F5T=7)N("!M:7AE9"`@("`@
M("`@(%1R=64@;VX@<W5C8V5S<RP@;W1H97)W:7-E(%!%05(Z.D5R<F]R"B`@
M("`@*B!`<V5E("`@("!.151?1E107T524E]214U/5$50051(3D]$25(L($Y%
M5%]&5%!?15)27T1%3$54141)4E]&04E,140*("`@("`J+PH@("`@"B`@("!F
M=6YC=&EO;B!?<FU?9&ER7W)E8W5R<VEV92@D9&ER*0H@("`@>PH@("`@("`@
M(&EF("AS=6)S='(H)&1I<BP@*'-T<FQE;B@D9&ER*2`M(#$I+"`Q*2`A/2`B
M+R(I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")$
M:7)E8W1O<GD@;F%M92`G)&1I<B<@:7,@:6YV86QI9"P@:&%S('1O(&5N9"!W
M:71H("<O)R(L($Y%5%]&5%!?15)27U)%34]415!!5$A.3T1)4BD["B`@("`@
M("`@?0H@("`@("`@("1F:6QE7VQI<W0@/2`D=&AI<RT^7VQS7V9I;&5S*"1D
M:7(I.PH@("`@("`@(&9O<F5A8V@@*"1F:6QE7VQI<W0@87,@)&9I;&4I('L*
M("`@("`@("`@("`@)&9I;&4@/2`D9&ER+B1F:6QE6R)N86UE(ET["B`@("`@
M("`@("`@("1R97,@/2`D=&AI<RT^<FTH)&9I;&4I.PH@("`@("`@("`@("!I
M9B`H)'1H:7,M/FES17)R;W(H)')E<RDI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D<F5S.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1D
M:7)?;&ES="`]("1T:&ES+3Y?;'-?9&ER<R@D9&ER*3L*("`@("`@("!F;W)E
M86-H("@D9&ER7VQI<W0@87,@)&YE=U]D:7(I('L*("`@("`@("`@("`@)&YE
M=U]D:7(@/2`D9&ER+B1N97=?9&ER6R)N86UE(ETN(B\B.PH@("`@("`@("`@
M("`D<F5S(#T@)'1H:7,M/E]R;5]D:7)?<F5C=7)S:79E*"1N97=?9&ER*3L*
M("`@("`@("`@("`@:68@*"1T:&ES+3YI<T5R<F]R*"1R97,I*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("`D<F5S(#T@)'1H:7,M/E]R;5]D:7(H)&1I<BD["B`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)')E<RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1R97,["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M('1R=64["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@3&ES=',@
M=7`@9FEL97,@86YD(&1I<F5C=&]R:65S"B`@("`@*@H@("`@("H@0&%C8V5S
M<R`@<')I=F%T90H@("`@("H@0'!A<F%M("`@<W1R:6YG("1D:7(@(%1H92!D
M:7)E8W1O<GD@=&\@;&ES="!U<`H@("`@("H@0')E='5R;B`@87)R87D@("`@
M("`@($%N(&%R<F%Y(&]F(&1I<G,@86YD(&9I;&5S"B`@("`@*B\*("`@(`H@
M("`@9G5N8W1I;VX@7VQS7V)O=&@H)&1I<BD*("`@('L*("`@("`@("`D;&ES
M=%]S<&QI='1E9"`]("1T:&ES+3Y?;&ES=%]A;F1?<&%R<V4H)&1I<BD["B`@
M("`@("`@:68@*"%I<U]A<G)A>2@D;&ES=%]S<&QI='1E9%LB9FEL97,B72DI
M('L*("`@("`@("`@("`@)&QI<W1?<W!L:71T961;(F9I;&5S(ET@/2!A<G)A
M>2@I.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1L:7-T7W-P
M;&ET=&5D6R)D:7)S(ETI*2!["B`@("`@("`@("`@("1L:7-T7W-P;&ET=&5D
M6R)D:7)S(ET@/2!A<G)A>2@I.PH@("`@("`@('T*("`@("`@("`D<F5S(#T@
M87)R87DH*3L*("`@("`@("!`87)R87E?<W!L:6-E*"1R97,L(#`L(#`L("1L
M:7-T7W-P;&ET=&5D6R)F:6QE<R)=*3L*("`@("`@("!`87)R87E?<W!L:6-E
M*"1R97,L(#`L(#`L("1L:7-T7W-P;&ET=&5D6R)D:7)S(ETI.PH@("`@("`@
M(')E='5R;B`D<F5S.PH@("`@?0H*("`@("\J*@H@("`@("H@3&ES=',@=7`@
M9&ER96-T;W)I97,*("`@("`J"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@
M("`@*B!`<&%R86T@("!S=')I;F<@)&1I<B`@5&AE(&1I<F5C=&]R>2!T;R!L
M:7-T('5P"B`@("`@*B!`<F5T=7)N("!A<G)A>2`@("`@("`@06X@87)R87D@
M;V8@9&ER<PH@("`@("HO"B`@("`*("`@(&9U;F-T:6]N(%]L<U]D:7)S*"1D
M:7(I"B`@("!["B`@("`@("`@)&QI<W0@/2`D=&AI<RT^7VQI<W1?86YD7W!A
M<G-E*"1D:7(I.PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1L:7-T*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&QI<W0["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B`D;&ES=%LB9&ER<R)=.PH@("`@?0H*("`@("\J*@H@("`@("H@
M3&ES=',@=7`@9FEL97,*("`@("`J"B`@("`@*B!`86-C97-S("!P<FEV871E
M"B`@("`@*B!`<&%R86T@("!S=')I;F<@)&1I<B`@5&AE(&1I<F5C=&]R>2!T
M;R!L:7-T('5P"B`@("`@*B!`<F5T=7)N("!A<G)A>2`@("`@("`@06X@87)R
M87D@;V8@9FEL97,*("`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!?;'-?9FEL
M97,H)&1I<BD*("`@('L*("`@("`@("`D;&ES="`]("1T:&ES+3Y?;&ES=%]A
M;F1?<&%R<V4H)&1I<BD["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&QI
M<W0I*2!["B`@("`@("`@("`@(')E='5R;B`D;&ES=#L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N("1L:7-T6R)F:6QE<R)=.PH@("`@?0H*("`@("\J*@H@
M("`@("H@5&AI<R!L:7-T<R!U<"!T:&4@9&ER96-T;W)Y+6-O;G1E;G0@86YD
M('!A<G-E<R!T:&4@:71E;7,@:6YT;R!W96QL+69O<FUA=&5D(&%R<F%Y<PH@
M("`@("H@5&AE(')E<W5L=',@;V8@=&AI<R!A<G)A>2!A<F4@<V]R=&5D("AD
M:7)S(&]N('1O<"P@<V]R=&5D(&)Y(&YA;64["B`@("`@*B!F:6QE<R!B96QO
M=RP@<V]R=&5D(&)Y(&YA;64I+@H@("`@("H*("`@("`J($!A8V-E<W,@('!R
M:79A=&4*("`@("`J($!P87)A;2`@('-T<FEN9R`D9&ER("!4:&4@9&ER96-T
M;W)Y('1O('!A<G-E"B`@("`@*B!`<F5T=7)N("!A<G)A>2`@("`@("`@3&ES
M=',@;V8@9&ER<R!A;F0@9FEL97,*("`@("`J($!S964@("`@($Y%5%]&5%!?
M15)27U)!5T1)4DQ)4U1?1D%)3$5$"B`@("`@*B\*("`@(`H@("`@9G5N8W1I
M;VX@7VQI<W1?86YD7W!A<G-E*"1D:7(I"B`@("!["B`@("`@("`@)&1I<G-?
M;&ES="`](&%R<F%Y*"D["B`@("`@("`@)&9I;&5S7VQI<W0@/2!A<G)A>2@I
M.PH@("`@("`@("1D:7)?;&ES="`]($!F='!?<F%W;&ES="@D=&AI<RT^7VAA
M;F1L92P@)&1I<BD["B`@("`@("`@:68@*"%I<U]A<G)A>2@D9&ER7VQI<W0I
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=#;W5L
M9"!N;W0@9V5T(')A=R!D:7)E8W1O<GD@;&ES=&EN9RXG+"!.151?1E107T52
M4E]205=$25),25-47T9!24Q%1"D["B`@("`@("`@?0H@("`@("`@("\O($AA
M;F1L92!E;7!T>2!D:7)E8W1O<FEE<PH@("`@("`@(&EF("AC;W5N="@D9&ER
M7VQI<W0I(#T](#`I('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"=D:7)S
M)R`]/B`D9&ER<U]L:7-T+"`G9FEL97,G(#T^("1F:6QE<U]L:7-T*3L*("`@
M("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7VUA=&-H97(I('Q\
M(%!%05(Z.FES17)R;W(H)'1H:7,M/E]M871C:&5R*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7VUA=&-H97(@/2`D=&AI<RT^7V1E=&5R;6EN95]O<U]M871C
M:"@D9&ER7VQI<W0I.PH@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M=&AI<RT^7VUA=&-H97(I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]M871C:&5R.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@
M(&9O<F5A8V@@*"1D:7)?;&ES="!A<R`D96YT<GDI('L*("`@("`@("`@("`@
M:68@*"%P<F5G7VUA=&-H*"1T:&ES+3Y?;6%T8VAE<ELG<&%T=&5R;B==+"`D
M96YT<GDL("1M*2D@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)&5N=')Y(#T@87)R87DH*3L*("`@("`@
M("`@("`@9F]R96%C:"`H)'1H:7,M/E]M871C:&5R6R=M87`G72!A<R`D:V5Y
M/3XD=F%L*2!["B`@("`@("`@("`@("`@("`D96YT<GE;)&ME>5T@/2`D;5LD
M=F%L73L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D96YT<GE;)W-T86UP
M)UT@/2`D=&AI<RT^7W!A<G-E7T1A=&4H)&5N=')Y6R=D871E)UTI.PH*("`@
M("`@("`@("`@:68@*"1E;G1R>5LG:7-?9&ER)UTI('L*("`@("`@("`@("`@
M("`@("1D:7)S7VQI<W1;72`]("1E;G1R>3L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1F:6QE<U]L:7-T6UT@/2`D96YT<GD["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@0'5S;W)T*"1D:7)S7VQI
M<W0L(&%R<F%Y*").971?1E10(BP@(E]N871?<V]R="(I*3L*("`@("`@("!`
M=7-O<G0H)&9I;&5S7VQI<W0L(&%R<F%Y*").971?1E10(BP@(E]N871?<V]R
M="(I*3L*("`@("`@("`D<F5S6R)D:7)S(ET@/2`H:7-?87)R87DH)&1I<G-?
M;&ES="DI(#\@)&1I<G-?;&ES="`Z(&%R<F%Y*"D["B`@("`@("`@)')E<ULB
M9FEL97,B72`]("AI<U]A<G)A>2@D9FEL97-?;&ES="DI(#\@)&9I;&5S7VQI
M<W0@.B!A<G)A>2@I.PH@("`@("`@(')E='5R;B`D<F5S.PH@("`@?0H@("`@
M"B`@("`O*BH*("`@("`J($1E=&5R;6EN92!S97)V97(@3U,*("`@("`J(%1H
M:7,@9&5T97)M:6YE<R!T:&4@<V5R=F5R($]3(&%N9"!R971U<FYS(&$@=F%L
M:60@<F5G97@@=&\@<&%R<V4*("`@("`J(&QS*"D@;W5T<'5T+@H@("`@("H*
M("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J($!P87)A;2`@(&%R<F%Y
M("1D:7)?;&ES="!4:&4@<F%W(&1I<B!L:7-T('1O('!A<G-E"B`@("`@*B!`
M<F5T=7)N("!M:7AE9"!!;B!A<G)A>2!O9B`G<&%T=&5R;B<@86YD("=M87`G
M(&]N('-U8V-E<W,L(&]T:&5R=VES92!014%2.CI%<G)O<@H@("`@("H@0'-E
M92`@("`@3D547T944%]%4E)?1$E23$E35%]53E-54%!/4E1%1`H@("`@("HO
M"B`@("`*("`@(&9U;F-T:6]N(%]D971E<FUI;F5?;W-?;6%T8V@H)B1D:7)?
M;&ES="D@>PH@("`@9F]R96%C:"`H)&1I<E]L:7-T(&%S("1E;G1R>2D@>PH@
M("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?;'-?;6%T8V@@87,@)&]S(#T^("1M
M871C:"D@>PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@D;6%T8VA;)W!A
M='1E<FXG72P@)&5N=')Y*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D;6%T8V@["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M('T*("`@("`@("`D97)R;W(@/2`G5&AE(&QI<W0@<W1Y;&4@;V8@>6]U<B!S
M97)V97(@<V5E;7,@;F]T('1O(&)E('-U<'!O<G1E9"X@4&QE87-E(&5M86EL
M(&$@(B1F='`M/FQS*$Y%5%]&5%!?4D%73$E35"D[(B!O=71P=70@<&QU<R!I
M;F9O(&]N('1H92!S97)V97(@=&\@=&AE(&UA:6YT86EN97(@;V8@=&AI<R!P
M86-K86=E('1O(&=E="!I="!S=7!P;W)T960A(%1H86YK<R!F;W(@>6]U<B!H
M96QP(2<["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)&5R<F]R
M+"!.151?1E107T524E]$25),25-47U5.4U504$]25$5$*3L*("`@('T*("`@
M("\J*@H@("`@("H@3&ES=',@82!L;V-A;"!D:7)E8W1O<GD*("`@("`J"B`@
M("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B!`<&%R86T@("!S=')I;F<@
M)&1I<E]P871H("!4:&4@9&ER('1O(&QI<W0*("`@("`J($!R971U<FX@(&%R
M<F%Y("`@("`@("`@("`@(%1H92!L:7-T(&]F(&1I<G,@86YD(&9I;&5S"B`@
M("`@*B\*("`@(`H@("`@9G5N8W1I;VX@7VQS7VQO8V%L*"1D:7)?<&%T:"D*
M("`@('L*("`@("`@("`D9&ER(#T@9&ER*"1D:7)?<&%T:"D["B`@("`@("`@
M)&1I<E]L:7-T(#T@87)R87DH*3L*("`@("`@("`D9FEL95]L:7-T(#T@87)R
M87DH*3L*("`@("`@("!W:&EL92`H9F%L<V4@(3T]("@D96YT<GD@/2`D9&ER
M+3YR96%D*"DI*2!["B`@("`@("`@("`@(&EF("@H)&5N=')Y("$]("<N)RD@
M)B8@*"1E;G1R>2`A/2`G+BXG*2D@>PH@("`@("`@("`@("`@("`@:68@*&ES
M7V1I<B@D9&ER7W!A=&@N)&5N=')Y*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1D:7)?;&ES=%M=(#T@)&5N=')Y.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`D9FEL95]L:7-T6UT@/2`D96YT<GD[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("`@("`@)&1I<BT^8VQO<V4H*3L*("`@("`@("`D<F5S6R=D:7)S)UT@/2`D
M9&ER7VQI<W0["B`@("`@("`@)')E<ULG9FEL97,G72`]("1F:6QE7VQI<W0[
M"B`@("`@("`@<F5T=7)N("1R97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&
M=6YC=&EO;B!F;W(@=7-E('=I=&@@=7-O<G0H*2X*("`@("`J($-O;7!A<F5S
M('1H92!L:7-T+6%R<F%Y+65L96UE;G1S(&)Y(&YA;64N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("`*("`@(&9U;F-T:6]N
M(%]N871?<V]R="@D:71E;5\Q+"`D:71E;5\R*0H@("`@>PH@("`@("`@(')E
M='5R;B!S=')N871C;7`H)&ET96U?,5LG;F%M92==+"`D:71E;5\R6R=N86UE
M)UTI.PH@("`@?0H*("`@("\J*@H@("`@("H@4&%R<V4@9&%T97,@=&\@=&EM
M97-T86UP<PH@("`@("H*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J
M($!P87)A;2`@('-T<FEN9R`D9&%T92`@1&%T90H@("`@("H@0')E='5R;B`@
M:6YT("`@("`@("`@("!4:6UE<W1A;7`*("`@("`J($!S964@("`@($Y%5%]&
M5%!?15)27T1!5$5&3U)-051?1D%)3$5$"B`@("`@*B\*("`@(`H@("`@9G5N
M8W1I;VX@7W!A<G-E7T1A=&4H)&1A=&4I"B`@("!["B`@("`@("`@+R\@4V5P
M(#$P(#(R.C`V(#T^(%-E<"`Q,"P@/'EE87(^(#(R.C`V"B`@("`@("`@:68@
M*'!R96=?;6%T8V@H)R\H6T$M6F$M>ETK*5L@72LH6S`M.5TK*5L@72LH6S`M
M.5TK*3HH6S`M.5TK*2\G+"`D9&%T92P@)')E<RDI('L*("`@("`@("`@("`@
M)'EE87(@/2!D871E*"=9)RD["B`@("`@("`@("`@("1M;VYT:"`]("1R97-;
M,5T["B`@("`@("`@("`@("1D87D@/2`D<F5S6S)=.PH@("`@("`@("`@("`D
M:&]U<B`]("1R97-;,UT["B`@("`@("`@("`@("1M:6YU=&4@/2`D<F5S6S1=
M.PH@("`@("`@("`@("`D9&%T92`]("(D;6]N=&@@)&1A>2P@)'EE87(@)&AO
M=7(Z)&UI;G5T92(["B`@("`@("`@("`@("1T;7!$871E(#T@<W1R=&]T:6UE
M*"1D871E*3L*("`@("`@("`@("`@:68@*"1T;7!$871E(#X@=&EM92@I*2![
M"B`@("`@("`@("`@("`@("`D>65A<BTM.PH@("`@("`@("`@("`@("`@)&1A
M=&4@/2`B)&UO;G1H("1D87DL("1Y96%R("1H;W5R.B1M:6YU=&4B.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("\O(#`Y+3$P+3`T(#T^(#`Y
M+S$P+S`T"B`@("`@("`@96QS96EF("AP<F5G7VUA=&-H*"<O7EQD7&0M7&1<
M9"U<9%QD+R<L)&1A=&4I*2!["B`@("`@("`@("`@("1D871E(#T@<W1R7W)E
M<&QA8V4H)RTG+"<O)RPD9&%T92D["B`@("`@("`@?0H@("`@("`@("1R97,@
M/2!S=')T;W1I;64H)&1A=&4I.PH@("`@("`@(&EF("@A)')E<RD@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)T1A=&5C;VYV97)S
M:6]N(&9A:6QE9"XG+"!.151?1E107T524E]$051%1D]234%47T9!24Q%1"D[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5S.PH@("`@?0I]"C\^"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]P96-L8VUD+G!H<"YO<FEG````````````````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`S-3(U(#$P-3$U-#,S-S,S(#`R,34U,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`T*
M+R\-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!02%`@
M5F5R<VEO;B`U("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L-"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#0@5&AE(%!(
M4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\(%1H:7,@<V]U<F-E
M(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI
M8V5N<V4L("`@("`@('P-"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI
M<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@
M?`T*+R\@?"!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@
M870@=&AE(&9O;&QO=VEN9R!U<FPZ("`@("`@("`@("!\#0HO+R!\(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P-"B\O('P@268@>6]U(&1I9"!N;W0@<F5C
M96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE
M('1O("`@?`T*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED
M92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\#0HO+R!\
M(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM
M;65D:6%T96QY+B`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PT*+R\@?"!!=71H;W)S.B!3=&EG($)A:VME;B`\<W-B
M0'!H<"YN970^("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M#0HO+R!\("`@("`@("`@(%1O;6%S(%8N5BY#;W@@/&-O>$!I9&5C;F5T+F-O
M;3X@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK#0HO+PT*+R\@)$ED.B!P96-L8VUD+G!H<"QV(#$N,2`R,#`U+S`R
M+S(Q(#`U.C,P.C4V(&-E;&QO9R!%>'`@)`T*#0HO*BH-"B`J($!N;V1E<"!'
M=&L-"B`J+PT*:68@*"<O:&]M92]L=6-E<B]W;W)K+W!E87(O<VAA<F4O<&AP
M)R`A/2`G0"<N)VEN8VQU9&5?<&%T:"<N)T`G*2![#0H@("`@:6YI7W-E="@G
M:6YC;'5D95]P871H)RP@)R]H;VUE+VQU8V5R+W=O<FLO<&5A<B]S:&%R92]P
M:'`G*3L-"B`@("`D<F%W(#T@9F%L<V4[#0I](&5L<V4@>PT*("`@("\O('1H
M:7,@:7,@82!R87<L('5N:6YS=&%L;&5D('!E87(L(&5I=&AE<B!A(&-V<R!C
M:&5C:V]U="P@;W(@<&AP(&1I<W1R;PT*("`@("1R87<@/2!T<G5E.PT*?0T*
M9&5F:6YE*"=014%27U)53E194$4G+"`G<&5C;"<I.PT*<F5Q=6ER95]O;F-E
M("=P96%R8VUD+G!H<"<[#0HO*@T*("H@3&]C86P@=F%R:6%B;&5S.@T*("H@
M=&%B+7=I9'1H.B`T#0H@*B!C+6)A<VEC+6]F9G-E=#H@-`T*("H@:6YD96YT
M+71A8G,M;6]D93H@;FEL#0H@*B!M;V1E.B!P:'`-"B`J($5N9#H-"B`J+PT*
M+R\@=FEM-C`P.G-Y;CUP:'`-"@T*/SX-"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M36%I;"YP:'``````````````````````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`Q-S8P,2`Q,#4Q-30S,S<S,R`P,C`P-C8`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+R\*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@
M-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B
M:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@
M('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@
M=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA
M8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L
M:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T
M:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T
M86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N
M9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S
M;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M075T:&]R.B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!-86EL+G!H<"QV(#$N,3(@,C`P-2\P
M."\R,B`P,3HQ.3HR-R!J;VX@17AP("0*"G)E<75I<F5?;VYC92`G4$5!4BYP
M:'`G.PH*+RHJ"B`J(%!%05(G<R!-86EL.CH@:6YT97)F86-E+B!$969I;F5S
M('1H92!I;G1E<F9A8V4@9F]R(&EM<&QE;65N=&EN9PH@*B!M86EL97)S('5N
M9&5R('1H92!014%2(&AI97)A<F-H>2P@86YD('!R;W9I9&5S('-U<'!O<G1I
M;F<@9G5N8W1I;VYS"B`J('5S969U;"!I;B!M=6QT:7!L92!M86EL97(@8F%C
M:V5N9',N"B`J"B`J($!A8V-E<W,@<'5B;&EC"B`J($!V97)S:6]N("12979I
M<VEO;CH@,2XQ,B`D"B`J($!P86-K86=E($UA:6P*("HO"F-L87-S($UA:6P*
M>PH@("`@+RHJ"B`@("`@*B!,:6YE('1E<FUI;F%T;W(@=7-E9"!F;W(@<V5P
M87)A=&EN9R!H96%D97(@;&EN97,N"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)'-E<"`](")<<EQN(CL*"B`@("`O*BH*("`@("`J(%!R
M;W9I9&5S(&%N(&EN=&5R9F%C92!F;W(@9V5N97)A=&EN9R!-86EL.CH@;V)J
M96-T<R!O9B!V87)I;W5S"B`@("`@*B!T>7!E<PH@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&1R:79E<B!4:&4@:VEN9"!O9B!-86EL.CH@;V)J96-T
M('1O(&EN<W1A;G1I871E+@H@("`@("H@0'!A<F%M(&%R<F%Y("`D<&%R86US
M(%1H92!P87)A;65T97)S('1O('!A<W,@=&\@=&AE($UA:6PZ.B!O8FIE8W0N
M"B`@("`@*B!`<F5T=7)N(&]B:F5C="!-86EL(&$@:6YS=&%N8V4@;V8@=&AE
M(&1R:79E<B!C;&%S<R!O<B!I9B!F86EL<R!A(%!%05(@17)R;W(*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y
M*"1D<FEV97(L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1D
M<FEV97(@/2!S=')T;VQO=V5R*"1D<FEV97(I.PH@("`@("`@($!I;F-L=61E
M7V]N8V4@)TUA:6PO)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@)&-L
M87-S(#T@)TUA:6Q?)R`N("1D<FEV97(["B`@("`@("`@:68@*&-L87-S7V5X
M:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1M86EL97(@/2!N97<@)&-L
M87-S*"1P87)A;7,I.PH@("`@("`@("`@("!R971U<FX@)&UA:6QE<CL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@G56YA8FQE('1O(&9I;F0@8VQA<W,@9F]R(&1R:79E<B`G("X@)&1R
M:79E<BD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@26UP;&5M
M96YT<R!-86EL.CIS96YD*"D@9G5N8W1I;VX@=7-I;F<@<&AP)W,@8G5I;'0M
M:6X@;6%I;"@I"B`@("`@*B!C;VUM86YD+@H@("`@("H*("`@("`J($!P87)A
M;2!M:7AE9"`D<F5C:7!I96YT<R!%:71H97(@82!C;VUM82US97!E<F%T960@
M;&ES="!O9B!R96-I<&EE;G1S"B`@("`@*B`@("`@("`@("`@("`@*%)&0S@R
M,B!C;VUP;&EA;G0I+"!O<B!A;B!A<G)A>2!O9B!R96-I<&EE;G1S+`H@("`@
M("H@("`@("`@("`@("`@(&5A8V@@4D9#.#(R('9A;&ED+B!4:&ES(&UA>2!C
M;VYT86EN(')E8VEP:65N=',@;F]T"B`@("`@*B`@("`@("`@("`@("`@<W!E
M8VEF:65D(&EN('1H92!H96%D97)S+"!F;W(@0F-C.BP@<F5S96YD:6YG"B`@
M("`@*B`@("`@("`@("`@("`@;65S<V%G97,L(&5T8RX*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@)&AE861E<G,@5&AE(&%R<F%Y(&]F(&AE861E<G,@
M=&\@<V5N9"!W:71H('1H92!M86EL+"!I;B!A;@H@("`@("H@("`@("`@("`@
M("`@(&%S<V]C:6%T:79E(&%R<F%Y+"!W:&5R92!T:&4@87)R87D@:V5Y(&ES
M('1H90H@("`@("H@("`@("`@("`@("`@(&AE861E<B!N86UE("AI92P@)U-U
M8FIE8W0G*2P@86YD('1H92!A<G)A>2!V86QU90H@("`@("H@("`@("`@("`@
M("`@(&ES('1H92!H96%D97(@=F%L=64@*&EE+"`G=&5S="<I+B!4:&4@:&5A
M9&5R"B`@("`@*B`@("`@("`@("`@("`@<')O9'5C960@9G)O;2!T:&]S92!V
M86QU97,@=V]U;&0@8F4@)U-U8FIE8W0Z"B`@("`@*B`@("`@("`@("`@("`@
M=&5S="<N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8F]D>2!4:&4@
M9G5L;"!T97AT(&]F('1H92!M97-S86=E(&)O9'DL(&EN8VQU9&EN9R!A;GD*
M("`@("`J("`@("`@("`@("`@("`@36EM92!P87)T<RP@971C+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@4F5T=7)N<R!T<G5E(&]N('-U8V-E<W,L
M(&]R(&$@4$5!4E]%<G)O<@H@("`@("H@("`@("`@("`@("`@("!C;VYT86EN
M:6YG(&$@9&5S8W)I<'1I=F4@97)R;W(@;65S<V%G92!O;@H@("`@("H@("`@
M("`@("`@("`@("!F86EL=7)E+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J($!D97!R96-A=&5D('5S92!-86EL7VUA:6PZ.G-E;F0@:6YS=&5A9`H@
M("`@("HO"B`@("!F=6YC=&EO;B!S96YD*"1R96-I<&EE;G1S+"`D:&5A9&5R
M<RP@)&)O9'DI"B`@("!["B`@("`@("`@+R\@:68@=V4G<F4@<&%S<V5D(&%N
M(&%R<F%Y(&]F(')E8VEP:65N=',L(&EM<&QO9&4@:70N"B`@("`@("`@:68@
M*&ES7V%R<F%Y*"1R96-I<&EE;G1S*2D@>PH@("`@("`@("`@("`D<F5C:7!I
M96YT<R`](&EM<&QO9&4H)RP@)RP@)')E8VEP:65N=',I.PH@("`@("`@('T*
M"B`@("`@("`@+R\@9V5T('1H92!3=6)J96-T(&]U="!O9B!T:&4@:&5A9&5R
M<R!A<G)A>2!S;R!T:&%T('=E(&-A;@H@("`@("`@("\O('!A<W,@:70@87,@
M82!S97!E<F%T92!A<F=U;65N="!T;R!M86EL*"DN"B`@("`@("`@)'-U8FIE
M8W0@/2`G)SL*("`@("`@("!I9B`H:7-S970H)&AE861E<G-;)U-U8FIE8W0G
M72DI('L*("`@("`@("`@("`@)'-U8FIE8W0@/2`D:&5A9&5R<ULG4W5B:F5C
M="==.PH@("`@("`@("`@("!U;G-E="@D:&5A9&5R<ULG4W5B:F5C="==*3L*
M("`@("`@("!]"@H@("`@("`@("\O(&9L871T96X@=&AE(&AE861E<G,@;W5T
M+@H@("`@("`@(&QI<W0H+"1T97AT7VAE861E<G,I(#T@36%I;#HZ<')E<&%R
M94AE861E<G,H)&AE861E<G,I.PH*("`@("`@("!R971U<FX@;6%I;"@D<F5C
M:7!I96YT<RP@)'-U8FIE8W0L("1B;V1Y+"`D=&5X=%]H96%D97)S*3L*"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!486ME(&%N(&%R<F%Y(&]F(&UA:6P@:&5A
M9&5R<R!A;F0@<F5T=7)N(&$@<W1R:6YG(&-O;G1A:6YI;F<*("`@("`J('1E
M>'0@=7-A8FQE(&EN('-E;F1I;F<@82!M97-S86=E+@H@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>2`D:&5A9&5R<R!4:&4@87)R87D@;V8@:&5A9&5R<R!T
M;R!P<F5P87)E+"!I;B!A;B!A<W-O8VEA=&EV90H@("`@("H@("`@("`@("`@
M("`@(&%R<F%Y+"!W:&5R92!T:&4@87)R87D@:V5Y(&ES('1H92!H96%D97(@
M;F%M92`H:64L"B`@("`@*B`@("`@("`@("`@("`@)U-U8FIE8W0G*2P@86YD
M('1H92!A<G)A>2!V86QU92!I<R!T:&4@:&5A9&5R"B`@("`@*B`@("`@("`@
M("`@("`@=F%L=64@*&EE+"`G=&5S="<I+B!4:&4@:&5A9&5R('!R;V1U8V5D
M(&9R;VT@=&AO<V4*("`@("`J("`@("`@("`@("`@("!V86QU97,@=V]U;&0@
M8F4@)U-U8FIE8W0Z('1E<W0G+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@4F5T=7)N<R!F86QS92!I9B!I="!E;F-O=6YT97)S(&$@8F%D(&%D9')E
M<W,L"B`@("`@*B`@("`@("`@("`@("`@(&]T:&5R=VES92!R971U<FYS(&%N
M(&%R<F%Y(&-O;G1A:6YI;F<@='=O"B`@("`@*B`@("`@("`@("`@("`@(&5L
M96UE;G1S.B!!;GD@1G)O;3H@861D<F5S<R!F;W5N9"!I;B!T:&4@:&5A9&5R
M<RP*("`@("`J("`@("`@("`@("`@("`@86YD('1H92!P;&%I;B!T97AT('9E
M<G-I;VX@;V8@=&AE(&AE861E<G,N"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J+PH@("`@9G5N8W1I;VX@<')E<&%R94AE861E<G,H)&AE861E<G,I
M"B`@("!["B`@("`@("`@)&QI;F5S(#T@87)R87DH*3L*("`@("`@("`D9G)O
M;2`](&YU;&P["@H@("`@("`@(&9O<F5A8V@@*"1H96%D97)S(&%S("1K97D@
M/3X@)'9A;'5E*2!["B`@("`@("`@("`@(&EF("AS=')C87-E8VUP*"1K97DL
M("=&<F]M)RD@/3T](#`I('L*("`@("`@("`@("`@("`@(&EN8VQU9&5?;VYC
M92`G36%I;"]21D,X,C(N<&AP)SL*("`@("`@("`@("`@("`@("1P87)S97(@
M/2`F;F5W($UA:6Q?4D9#.#(R*"D["B`@("`@("`@("`@("`@("`D861D<F5S
M<V5S(#T@)'!A<G-E<BT^<&%R<V5!9&1R97-S3&ES="@D=F%L=64L("=L;V-A
M;&AO<W0G+"!F86QS92D["B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D861D<F5S<V5S*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D861D<F5S<V5S.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@("1F<F]M(#T@)&%D9')E<W-E<ULP72T^;6%I;&)O>"`N("=`)R`N("1A
M9&1R97-S97-;,%TM/FAO<W0["@H@("`@("`@("`@("`@("`@+R\@4F5J96-T
M(&5N=F5L;W!E($9R;VTZ(&%D9')E<W-E<R!W:71H('-P86-E<RX*("`@("`@
M("`@("`@("`@(&EF("AS=')S='(H)&9R;VTL("<@)RDI('L*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`@("`@)&QI;F5S6UT@/2`D:V5Y("X@)SH@)R`N("1V86QU
M93L*("`@("`@("`@("`@?2!E;'-E:68@*'-T<F-A<V5C;7`H)&ME>2P@)U)E
M8V5I=F5D)RD@/3T](#`I('L*("`@("`@("`@("`@("`@("1R96-E:79E9"`]
M(&%R<F%Y*"D["B`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)'9A;'5E
M*2D@>PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1V86QU92!A<R`D
M;&EN92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<F5C96EV961;72`]
M("1K97D@+B`G.B`G("X@)&QI;F4["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@)')E8V5I=F5D6UT@/2`D:V5Y("X@)SH@)R`N("1V
M86QU93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("\O(%!U
M="!296-E:79E9#H@:&5A9&5R<R!A="!T:&4@=&]P+B`@4W!A;2!D971E8W1O
M<G,@;V9T96X*("`@("`@("`@("`@("`@("\O(&9L86<@;65S<V%G97,@=VET
M:"!296-E:79E9#H@:&5A9&5R<R!A9G1E<B!T:&4@4W5B:F5C=#H*("`@("`@
M("`@("`@("`@("\O(&%S('-P86TN"B`@("`@("`@("`@("`@("`D;&EN97,@
M/2!A<G)A>5]M97)G92@D<F5C96EV960L("1L:6YE<RD["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`O+R!)9B`D=F%L=64@:7,@86X@
M87)R87D@*&DN92XL(&$@;&ES="!O9B!A9&1R97-S97,I+"!C;VYV97)T"B`@
M("`@("`@("`@("`@("`O+R!I="!T;R!A(&-O;6UA+61E;&EM:71E9"!S=')I
M;F<@;V8@:71S(&5L96UE;G1S("AA9&1R97-S97,I+@H@("`@("`@("`@("`@
M("`@:68@*&ES7V%R<F%Y*"1V86QU92DI('L*("`@("`@("`@("`@("`@("`@
M("`D=F%L=64@/2!I;7!L;V1E*"<L("<L("1V86QU92D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`D;&EN97-;72`]("1K97D@+B`G.B`G
M("X@)'9A;'5E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@87)R87DH)&9R;VTL(&IO:6XH)'1H:7,M/G-E<"P@)&QI;F5S*2`N
M("1T:&ES+3YS97`I.PH@("`@?0H*("`@("\J*@H@("`@("H@5&%K92!A('-E
M="!O9B!R96-I<&EE;G1S(&%N9"!P87)S92!T:&5M+"!R971U<FYI;F<@86X@
M87)R87D@;V8*("`@("`J(&)A<F4@861D<F5S<V5S("AF;W)W87)D('!A=&AS
M*2!T:&%T(&-A;B!B92!P87-S960@=&\@<V5N9&UA:6P*("`@("`J(&]R(&%N
M('-M='`@<V5R=F5R('=I=&@@=&AE(')C<'0@=&\Z(&-O;6UA;F0N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&UI>&5D($5I=&AE<B!A(&-O;6UA+7-E<&5R871E
M9"!L:7-T(&]F(')E8VEP:65N=',*("`@("`J("`@("`@("`@("`@("`H4D9#
M.#(R(&-O;7!L:6%N="DL(&]R(&%N(&%R<F%Y(&]F(')E8VEP:65N=',L"B`@
M("`@*B`@("`@("`@("`@("`@96%C:"!21D,X,C(@=F%L:60N"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>2!!;B!A<G)A>2!O9B!F;W)W87)D('!A=&AS
M("AB87)E(&%D9')E<W-E<RDN"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J+PH@("`@9G5N8W1I;VX@<&%R<V5296-I<&EE;G1S*"1R96-I<&EE;G1S
M*0H@("`@>PH@("`@("`@(&EN8VQU9&5?;VYC92`G36%I;"]21D,X,C(N<&AP
M)SL*"B`@("`@("`@+R\@:68@=V4G<F4@<&%S<V5D(&%N(&%R<F%Y+"!A<W-U
M;64@861D<F5S<V5S(&%R92!V86QI9"!A;F0*("`@("`@("`O+R!I;7!L;V1E
M('1H96T@8F5F;W)E('!A<G-I;F<N"B`@("`@("`@:68@*&ES7V%R<F%Y*"1R
M96-I<&EE;G1S*2D@>PH@("`@("`@("`@("`D<F5C:7!I96YT<R`](&EM<&QO
M9&4H)RP@)RP@)')E8VEP:65N=',I.PH@("`@("`@('T*"B`@("`@("`@+R\@
M4&%R<V4@<F5C:7!I96YT<RP@;&5A=FEN9R!O=70@86QL('!E<G-O;F%L(&EN
M9F\N(%1H:7,@:7,*("`@("`@("`O+R!F;W(@<VUT<"!R96-I<&EE;G1S+"!E
M=&,N($%L;"!R96QE=F%N="!P97)S;VYA;"!I;F9O<FUA=&EO;@H@("`@("`@
M("\O('-H;W5L9"!A;')E861Y(&)E(&EN('1H92!H96%D97)S+@H@("`@("`@
M("1A9&1R97-S97,@/2!-86EL7U)&0S@R,CHZ<&%R<V5!9&1R97-S3&ES="@D
M<F5C:7!I96YT<RP@)VQO8V%L:&]S="<L(&9A;'-E*3L*("`@("`@("`D<F5C
M:7!I96YT<R`](&%R<F%Y*"D["B`@("`@("`@:68@*&ES7V%R<F%Y*"1A9&1R
M97-S97,I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1A9&1R97-S97,@87,@
M)&]B*2!["B`@("`@("`@("`@("`@("`D<F5C:7!I96YT<UM=(#T@)&]B+3YM
M86EL8F]X("X@)T`G("X@)&]B+3YH;W-T.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)')E8VEP:65N=',["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+T9I;&4N<&AP````````````````````````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-#`Q,#(@,3`U,34T,S,W
M,S,@,#(P,#4S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@
M<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO"@HO*BH*("H@1FEL90H@
M*B`*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H
M92!02%`@;&EC96YS90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@
M;F]T(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@
M87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A
M<V4*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A
M;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R
M>2`@("!&:6QE"B`J($!P86-K86=E("`@("!&:6QE"B`J($!A=71H;W(@("`@
M("!2:6-H87)D($AE>65S(#QR:6-H87)D0'!H<"YN970^"B`J($!A=71H;W(@
M("`@("!486P@4&5E<B`\=&%L0'!H<"YN970^"B`J($!A=71H;W(@("`@("!-
M:6-H865L(%=A;&QN97(@/&UI:V5`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@
M(#(P,#(M,C`P-2!4:&4@075T:&]R<PH@*B!`;&EC96YS92`@("`@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP
M"B`J($!V97)S:6]N("`@("!#5E,Z("1)9#H@1FEL92YP:'`L=B`Q+C,Q(#(P
M,#4O,#<O,C$@,#<Z-3,Z,#D@;6EK92!%>'`@)`H@*B!`;&EN:R`@("`@("`@
M:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T9I;&4*("HO"@HO*BH*("H@
M4F5Q=6ER97,@4$5!4@H@*B\*<F5Q=6ER95]O;F-E("=014%2+G!H<"<["@HO
M*BH*("H@5&AE(&1E9F%U;'0@;G5M8F5R(&]F(&)Y=&5S(&9O<B!R96%D:6YG
M"B`J+PII9B`H(61E9FEN960H)T9)3$5?1$5&055,5%]214%$4TE:12<I*2![
M"B`@("!D969I;F4H)T9)3$5?1$5&055,5%]214%$4TE:12<L(#$P,C0L('1R
M=64I.PI]"@HO*BH*("H@5&AE(&UA>&EM=6T@;G5M8F5R(&]F(&)Y=&5S(&9O
M<B!R96%D:6YG(&QI;F5S"B`J+PII9B`H(61E9FEN960H)T9)3$5?34%87TQ)
M3D5?4D5!1%-)6D4G*2D@>PH@("`@9&5F:6YE*"=&24Q%7TU!6%],24Y%7U)%
M041325I%)RP@-#`Y-C`L('1R=64I.PI]"@HO*BH*("H@5VAE=&AE<B!F:6QE
M(&QO8VMS('-H;W5L9"!B;&]C:PH@*B\*:68@*"%D969I;F5D*"=&24Q%7TQ/
M0TM37T),3T-+)RDI('L*("`@(&1E9FEN92@G1DE,15],3T-+4U]"3$]#2R<L
M('1R=64L('1R=64I.PI]"@HO*BH*("H@36]D92!T;R!U<V4@9F]R(')E861I
M;F<@9G)O;2!F:6QE<PH@*B\*9&5F:6YE*"=&24Q%7TU/1$5?4D5!1"<L("=R
M8B<L('1R=64I.PH*+RHJ"B`J($UO9&4@=&\@=7-E(&9O<B!T<G5N8V%T:6YG
M(&9I;&5S+"!T:&5N('=R:71I;F<*("HO"F1E9FEN92@G1DE,15]-3T1%7U=2
M251%)RP@)W=B)RP@=')U92D["@HO*BH*("H@36]D92!T;R!U<V4@9F]R(&%P
M<&5N9&EN9R!T;R!F:6QE<PH@*B\*9&5F:6YE*"=&24Q%7TU/1$5?05!014Y$
M)RP@)V%B)RP@=')U92D["@HO*BH*("H@57-E('1H:7,@=VAE;B!A('-H87)E
M9"`H<F5A9"D@;&]C:R!I<R!R97%U:7)E9`H@*B\*9&5F:6YE*"=&24Q%7TQ/
M0TM?4TA!4D5$)RP@3$]#2U]32"!\("A&24Q%7TQ/0TM37T),3T-+(#\@,"`Z
M($Q/0TM?3D(I+"!T<G5E*3L*"B\J*@H@*B!5<V4@=&AI<R!W:&5N(&%N(&5X
M8VQU<VEV92`H=W)I=&4I(&QO8VL@:7,@<F5Q=6ER960*("HO"F1E9FEN92@G
M1DE,15],3T-+7T580TQ54TE612<L($Q/0TM?15@@?"`H1DE,15],3T-+4U]"
M3$]#2R`_(#`@.B!,3T-+7TY"*2P@=')U92D["@HO*BH*("H@0VQA<W,@9F]R
M(&AA;F1L:6YG(&9I;&5S"B`J(`H@*B!!(&-L87-S('=I=&@@8V]M;6]N(&9U
M;F-T:6]N<R!F;W(@=W)I=&EN9RP*("H@<F5A9&EN9R!A;F0@:&%N9&QI;F<@
M9FEL97,@86YD(&1I<F5C=&]R:65S"B`J(`H@*B!`875T:&]R("!2:6-H87)D
M($AE>65S(#QR:6-H87)D0'!H<"YN970^"B`J($!A=71H;W(@(%1A;"!0965R
M(#QT86Q`<&AP+FYE=#X*("H@0&%U=&AO<B`@36EC:&%E;"!786QL;F5R(#QM
M:6ME0'!H<"YN970^"B`J($!A8V-E<W,@('!U8FQI8R`*("H@0'!A8VMA9V4@
M1FEL90H@*B`*("H@0'-T871I8PH@*B\*8VQA<W,@1FEL92!E>'1E;F1S(%!%
M05(@"GL*("`@("\J*@H@("`@("H@1&5S=')U8W1O<@H@("`@("H@"B`@("`@
M*B!5;FQO8VMS(&%N>2!L;V-K960@9FEL92!P;VEN=&5R<R!A;F0@8VQO<V5S
M(&%L;"!F:6QE<&]I;G1E<G,*("`@("`J(`H@("`@("H@0&%C8V5S<R!P<FEV
M871E(`H@("`@("HO"B`@("!F=6YC=&EO;B!?1FEL92@I"B`@("!["B`@("`@
M("`@1FEL93HZ8VQO<V5!;&PH*3L*("`@('T*("`@(`H@("`@+RHJ"B`@("`@
M*B!(86YD;&5S(&9I;&4@<&]I;G1E<G,N($EF(&$@9FEL92!P;VEN=&5R(&YE
M961S('1O(&)E(&]P96YE9"P*("`@("`J(&ET('=I;&P@8F4N($EF(&ET(&%L
M<F5A9'D@97AI<W1S("AB87-E9"!O;B!F:6QE;F%M92!A;F0@;6]D92D*("`@
M("`J('1H96X@=&AE(&5X:7-T:6YG(&]N92!W:6QL(&)E(')E='5R;F5D+@H@
M("`@("H@"B`@("`@*B!`86-C97-S("!P<FEV871E(`H@("`@("H@0'!A<F%M
M("`@<W1R:6YG("`D9FEL96YA;64@1FEL96YA;64@=&\@8F4@=7-E9`H@("`@
M("H@0'!A<F%M("`@<W1R:6YG("`D;6]D92!-;V1E('1O(&]P96X@=&AE(&9I
M;&4@:6X*("`@("`J($!P87)A;2`@(&UI>&5D("`@)&QO8VL@5'EP92!O9B!L
M;V-K('1O('5S90H@("`@("H@0')E='5R;B`@;6EX960@("!014%27T5R<F]R
M(&]N(&5R<F]R(&]R(&9I;&4@<&]I;G1E<B!R97-O=7)C92!O;B!S=6-C97-S
M"B`@("`@*B\*("`@(&9U;F-T:6]N("9?9V5T1FEL95!O:6YT97(H)&9I;&5N
M86UE+"`D;6]D92P@)&QO8VL@/2!F86QS92D*("`@('L*("`@("`@("`D9FEL
M95!O:6YT97)S(#T@)E!%05(Z.F=E=%-T871I8U!R;W!E<G1Y*"=&:6QE)RP@
M)V9I;&50;VEN=&5R<R<I.PH@("`@("`@(`H@("`@("`@("\O(%=I;C,R(&ES
M(&-A<V4M:6YS96YS:71I=F4*("`@("`@("!I9B`H3U-?5TE.1$]74RD@>PH@
M("`@("`@("`@("`D9FEL96YA;64@/2!S=')4;TQO=V5R*"1F:6QE;F%M92D[
M"B`@("`@("`@?0H@("`@("`@(`H@("`@("`@("\O(&-H96-K(&EF(&9I;&4@
M<&]I;G1E<B!A;')E861Y(&5X:7-T<PH@("`@("`@(&EF("@@("`@(6ES<V5T
M*"1F:6QE4&]I;G1E<G-;)&9I;&5N86UE75LD;6]D95TI('Q\(`H@("`@("`@
M("`@("`@("`@(6ES7W)E<V]U<F-E*"1F:6QE4&]I;G1E<G-;)&9I;&5N86UE
M75LD;6]D95TI*2!["B`@("`@("`@("`@(`H@("`@("`@("`@("`O+R!C:&5C
M:R!I9B!W92!C86X@;W!E;B!T:&4@9FEL92!I;B!T:&4@9&5S:7)E9"!M;V1E
M"B`@("`@("`@("`@('-W:71C:"`H)&UO9&4I"B`@("`@("`@("`@('L*("`@
M("`@("`@("`@("`@(&-A<V4@1DE,15]-3T1%7U)%040Z"B`@("`@("`@("`@
M("`@("`@("`@:68@*"`@("`A<')E9U]M871C:"@G+UXN*R@_/"%F:6QE*3I<
M+UPO+VDG+"`D9FEL96YA;64I("8F"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`A9FEL95]E>&ES=',H)&9I;&5N86UE*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B1FEL92!D;V5S
M(&YO="!E>&ES=#H@)&9I;&5N86UE(BD["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`*("`@
M("`@("`@("`@("`@(&-A<V4@1DE,15]-3T1%7T%04$5.1#H*("`@("`@("`@
M("`@("`@(&-A<V4@1DE,15]-3T1%7U=2251%.@H@("`@("`@("`@("`@("`@
M("`@(&EF("AF:6QE7V5X:7-T<R@D9FEL96YA;64I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("@A:7-?=W)I=&%B;&4H)&9I;&5N86UE*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H(D9I;&4@:7,@;F]T('=R:71A8FQE.B`D9FEL96YA;64B*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T@
M96QS96EF("@A:7-?=W)I=&%B;&4H)&1I<B`](&1I<FYA;64H)&9I;&5N86UE
M*2DI('L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H(D-A;FYO="!C<F5A=&4@9FEL92!I;B!D:7)E8W1O<GDZ("1D
M:7(B*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@(`H@("`@("`@("`@("`@("`@9&5F875L
M=#H*("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@B26YV86QI9"!A8V-E<W,@;6]D93H@)&UO9&4B*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`*("`@("`@("`@("`@+R\@;W!E;B!F:6QE"B`@("`@
M("`@("`@("1F:6QE4&]I;G1E<G-;)&9I;&5N86UE75LD;6]D95T@/2!`9F]P
M96XH)&9I;&5N86UE+"`D;6]D92D["B`@("`@("`@("`@(&EF("@A:7-?<F5S
M;W5R8V4H)&9I;&50;VEN=&5R<ULD9FEL96YA;65=6R1M;V1E72DI('L*("`@
M("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=&86EL960@
M=&\@;W!E;B!F:6QE.B`G("X@)&9I;&5N86UE*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("`*("`@("`@("`O+R!L;V-K(&9I;&4*("`@("`@
M("!I9B`H)&QO8VLI('L*("`@("`@("`@("`@)&QO8VL@/2`D;6]D92`]/2!&
M24Q%7TU/1$5?4D5!1"`_($9)3$5?3$]#2U]32$%2140@.B!&24Q%7TQ/0TM?
M15A#3%53259%.PH@("`@("`@("`@("`D;&]C:W,@/2`F4$5!4CHZ9V5T4W1A
M=&EC4')O<&5R='DH)T9I;&4G+"`G;&]C:W,G*3L*("`@("`@("`@("`@:68@
M*$!F;&]C:R@D9FEL95!O:6YT97)S6R1F:6QE;F%M95U;)&UO9&5=+"`D;&]C
M:RDI('L*("`@("`@("`@("`@("`@("1L;V-K<UM=(#T@)B1F:6QE4&]I;G1E
M<G-;)&9I;&5N86UE75LD;6]D95T["B`@("`@("`@("`@('T@96QS96EF("A&
M24Q%7TQ/0TM37T),3T-+*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@B1FEL92!A;')E861Y(&QO8VME9#H@)&9I;&5N86UE
M(BD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@B0V]U;&0@;F]T(&QO8VL@9FEL93H@)&9I
M;&5N86UE(BD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@"B`@
M("`@("`@<F5T=7)N("1F:6QE4&]I;G1E<G-;)&9I;&5N86UE75LD;6]D95T[
M"B`@("!](`H*("`@("\J*@H@("`@("H@4F5A9',@86X@96YT:7)E(&9I;&4@
M86YD(')E='5R;G,@:70N"B`@("`@*B!5<V5S(&9I;&5?9V5T7V-O;G1E;G1S
M(&EF(&%V86EL86)L92X*("`@("`J(`H@("`@("H@0&%C8V5S<R`@<'5B;&EC
M(`H@("`@("H@0'!A<F%M("`@<W1R:6YG("`D9FEL96YA;64@3F%M92!O9B!F
M:6QE('1O(')E860@9G)O;0H@("`@("H@0'!A<F%M("`@;6EX960@("`D;&]C
M:R!4>7!E(&]F(&QO8VL@=&\@=7-E"B`@("`@*B!`<F5T=7)N("!M:7AE9"`@
M(%!%05)?17)R;W(@:68@86X@97)R;W(@:&%S(&]C8W5R960@;W(@82!S=')I
M;F<@=VET:"!T:&4@8V]N=&5N=',@;V8@=&AE('1H92!F:6QE"B`@("`@*B\*
M("`@(&9U;F-T:6]N(')E861!;&PH)&9I;&5N86UE+"`D;&]C:R`](&9A;'-E
M*0H@("`@>PH@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V9I;&5?9V5T
M7V-O;G1E;G1S)RDI('L*("`@("`@("`@("`@:68@*&9A;'-E(#T]/2`D9FEL
M92`]($!F:6QE7V=E=%]C;VYT96YT<R@D9FEL96YA;64I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B0V%N;F]T(')E860@
M9FEL93H@)&9I;&5N86UE(BD["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M<F5T=7)N("1F:6QE.PH@("`@("`@('T*("`@("`@("`*("`@("`@("`D9FEL
M92`]("<G.PH@("`@("`@('=H:6QE("AF86QS92`A/3T@)&)U9B`]($9I;&4Z
M.G)E860H)&9I;&5N86UE+"!&24Q%7T1%1D%53%1?4D5!1%-)6D4L("1L;V-K
M*2D@>PH@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8G5F*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N("1B=68["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)&9I;&4@+CT@)&)U9CL*("`@("`@("!]"B`@("`@("`@"B`@
M("`@("`@+R\@8VQO<V4@=&AE(&9I;&4@<&]I;G1E<@H@("`@("`@($9I;&4Z
M.F-L;W-E*"1F:6QE;F%M92P@1DE,15]-3T1%7U)%040I.PH@("`@("`@(`H@
M("`@("`@(')E='5R;B`D9FEL93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@82!S<&5C:69I960@;G5M8F5R(&]F(&)Y=&5S(&]F(&$@9FEL92X@
M"B`@("`@*B!$969A=6QT<R!T;R!&24Q%7T1%1D%53%1?4D5!1%-)6D4N("!)
M9B`D<VEZ92!I<R`P+"!A;&P@9FEL92!W:6QL(&)E(')E860N"B`@("`@*B`*
M("`@("`J($!A8V-E<W,@('!U8FQI8R`*("`@("`J($!P87)A;2`@('-T<FEN
M9R`@)&9I;&5N86UE($YA;64@;V8@9FEL92!T;R!R96%D(&9R;VT*("`@("`J
M($!P87)A;2`@(&EN=&5G97(@)'-I>F4@0GET97,@=&\@<F5A9`H@("`@("H@
M0'!A<F%M("`@;6EX960@("`D;&]C:R!4>7!E(&]F(&QO8VL@=&\@=7-E"B`@
M("`@*B!`<F5T=7)N("!M:7AE9"`@(%!%05)?17)R;W(@;VX@97)R;W(@;W(@
M82!S=')I;F<@=VAI8V@@8V]N=&%I;G,@=&AE(&1A=&$@<F5A9`H@("`@("H@
M("`@("`@("`@("`@("`@("!7:6QL(&%L<V\@<F5T=7)N(&9A;'-E('5P;VX@
M14]&"B`@("`@*B\*("`@(&9U;F-T:6]N(')E860H)&9I;&5N86UE+"`D<VEZ
M92`]($9)3$5?1$5&055,5%]214%$4TE:12P@)&QO8VL@/2!F86QS92D*("`@
M('L*("`@("`@("!S=&%T:6,@)&9I;&50;VEN=&5R<SL*("`@("`@("`*("`@
M("`@("!I9B`H,"`]/2`D<VEZ92D@>PH@("`@("`@("`@("!R971U<FX@1FEL
M93HZ<F5A9$%L;"@D9FEL96YA;64L("1L;V-K*3L*("`@("`@("!](`H*("`@
M("`@("!I9B`H("`@("%I<W-E="@D9FEL95!O:6YT97)S6R1F:6QE;F%M95TI
M('Q\(`H@("`@("`@("`@("`@("`@(6ES7W)E<V]U<F-E*"1F:6QE4&]I;G1E
M<G-;)&9I;&5N86UE72DI('L*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&9P(#T@)D9I;&4Z.E]G971&:6QE4&]I;G1E<B@D9FEL96YA;64L($9)
M3$5?34]$15]214%$+"`D;&]C:RDI*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)&9P.PH@("`@("`@("`@("!](`H*("`@("`@("`@("`@)&9I;&50;VEN
M=&5R<ULD9FEL96YA;65=(#T@)B1F<#L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D9G`@/2`F)&9I;&50;VEN=&5R<ULD9FEL96YA;65=.PH@("`@
M("`@('T@"@H@("`@("`@(')E='5R;B`A9F5O9B@D9G`I(#\@9G)E860H)&9P
M+"`D<VEZ92D@.B!F86QS93L*("`@('T@"@H@("`@+RHJ"B`@("`@*B!7<FET
M97,@=&AE(&=I=F5N(&1A=&$@=&\@=&AE(&=I=F5N(&9I;&5N86UE+B`*("`@
M("`J($1E9F%U;'1S('1O(&YO(&QO8VLL(&%P<&5N9"!M;V1E+@H@("`@("H@
M"B`@("`@*B!`86-C97-S("!P=6)L:6,@"B`@("`@*B!`<&%R86T@("!S=')I
M;F<@("1F:6QE;F%M92!.86UE(&]F(&9I;&4@=&\@=W)I=&4@=&\*("`@("`J
M($!P87)A;2`@('-T<FEN9R`@)&1A=&$@1&%T82!T;R!W<FET92!T;R!F:6QE
M"B`@("`@*B!`<&%R86T@("!S=')I;F<@("1M;V1E($UO9&4@=&\@;W!E;B!F
M:6QE(&EN"B`@("`@*B!`<&%R86T@("!M:7AE9"`@("1L;V-K(%1Y<&4@;V8@
M;&]C:R!T;R!U<V4*("`@("`J($!R971U<FX@(&UI>&5D("`@4$5!4E]%<G)O
M<B!O;B!E<G)O<B!O<B!N=6UB97(@;V8@8GET97,@=W)I='1E;B!T;R!F:6QE
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET92@D9FEL96YA;64L("1D871A
M+"`D;6]D92`]($9)3$5?34]$15]!4%!%3D0L("1L;V-K(#T@9F%L<V4I"B`@
M("!["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&9P(#T@)D9I;&4Z.E]G
M971&:6QE4&]I;G1E<B@D9FEL96YA;64L("1M;V1E+"`D;&]C:RDI*2!["B`@
M("`@("`@("`@(')E='5R;B`D9G`["B`@("`@("`@?0H@("`@("`@(&EF("@M
M,2`]/3T@)&)Y=&5S(#T@0&9W<FET92@D9G`L("1D871A+"!S=')L96XH)&1A
M=&$I*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B
M0V%N;F]T('=R:71E(&1A=&$Z("<D9&%T82<@=&\@9FEL93H@)R1F:6QE;F%M
M92<B*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1B>71E<SL*("`@('T@
M"@H@("`@+RHJ"B`@("`@*B!296%D<R!A;F0@<F5T=7)N<R!A('-I;F=L92!C
M:&%R86-T97(@9G)O;2!G:79E;B!F:6QE;F%M90H@("`@("H@"B`@("`@*B!`
M86-C97-S("!P=6)L:6,@"B`@("`@*B!`<&%R86T@("!S=')I;F<@("1F:6QE
M;F%M92!.86UE(&]F(&9I;&4@=&\@<F5A9"!F<F]M"B`@("`@*B!`<&%R86T@
M("!M:7AE9"`@("1L;V-K(%1Y<&4@;V8@;&]C:R!T;R!U<V4*("`@("`J($!R
M971U<FX@(&UI>&5D("`@4$5!4E]%<G)O<B!O;B!E<G)O<B!O<B!O;F4@8VAA
M<F%C=&5R(&]F('1H92!S<&5C:69I960@9FEL90H@("`@("HO"B`@("!F=6YC
M=&EO;B!R96%D0VAA<B@D9FEL96YA;64L("1L;V-K(#T@9F%L<V4I"B`@("![
M"B`@("`@("`@<F5T=7)N($9I;&4Z.G)E860H)&9I;&5N86UE+"`Q+"`D;&]C
M:RD["B`@("!](`H*("`@("\J*@H@("`@("H@5W)I=&5S(&$@<VEN9VQE(&-H
M87)A8W1E<B!T;R!A(&9I;&4*("`@("`J(`H@("`@("H@0&%C8V5S<R`@<'5B
M;&EC(`H@("`@("H@0'!A<F%M("`@<W1R:6YG("`D9FEL96YA;64@3F%M92!O
M9B!F:6QE('1O('=R:71E('1O"B`@("`@*B!`<&%R86T@("!S=')I;F<@("1C
M:&%R($-H87)A8W1E<B!T;R!W<FET90H@("`@("H@0'!A<F%M("`@<W1R:6YG
M("`D;6]D92!-;V1E('1O('5S92!W:&5N('=R:71I;F<*("`@("`J($!P87)A
M;2`@(&UI>&5D("`@)&QO8VL@5'EP92!O9B!L;V-K('1O('5S90H@("`@("H@
M0')E='5R;B`@;6EX960@("!014%27T5R<F]R(&]N(&5R<F]R+"!O<B`Q(&]N
M('-U8V-E<W,*("`@("`J+PH@("`@9G5N8W1I;VX@=W)I=&5#:&%R*"1F:6QE
M;F%M92P@)&-H87(L("1M;V1E(#T@1DE,15]-3T1%7T%04$5.1"P@)&QO8VL@
M/2!F86QS92D*("`@('L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D9G`@
M/2`F1FEL93HZ7V=E=$9I;&50;VEN=&5R*"1F:6QE;F%M92P@)&UO9&4L("1L
M;V-K*2DI('L*("`@("`@("`@("`@<F5T=7)N("1F<#L*("`@("`@("!]"B`@
M("`@("`@:68@*"TQ(#T]/2!`9G=R:71E*"1F<"P@)&-H87(L(#$I*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")#86YN;W0@=W)I
M=&4@9&%T83H@)R1D871A)R!T;R!F:6QE.B`G)&9I;&5N86UE)R(I.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@,3L*("`@('T@"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&$@;&EN92!O9B!T:&4@9FEL92`H=VET:&]U="!T<F%I;&EN
M9R!#4DQ&*2X*("`@("`J($UA>&EM=6T@<F5A9"!L:6YE(&QE;F=T:"!I<R!&
M24Q%7TU!6%],24Y%7U)%041325I%+@H@("`@("H@"B`@("`@*B!`86-C97-S
M("!P=6)L:6,@"B`@("`@*B!`<&%R86T@("!S=')I;F<@("1F:6QE;F%M92!.
M86UE(&]F(&9I;&4@=&\@<F5A9"!F<F]M"B`@("`@*B!`<&%R86T@("!B;V]L
M96%N("1L;V-K(%=H971H97(@9FEL92!S:&]U;&0@8F4@;&]C:V5D"B`@("`@
M*B!`<F5T=7)N("!M:7AE9"`@(%!%05)?17)R;W(@;VX@97)R;W(@;W(@82!S
M=')I;F<@8V]N=&%I;FEN9R!T:&4@;&EN92!R96%D(&9R;VT@9FEL90H@("`@
M("HO"B`@("!F=6YC=&EO;B!R96%D3&EN92@D9FEL96YA;64L("1L;V-K(#T@
M9F%L<V4I"B`@("!["B`@("`@("`@<W1A=&EC("1F:6QE4&]I;G1E<G,[("\O
M(%5S960@=&\@<')E=F5N="!U;FYE8V5S<V%R>2!C86QL<R!T;R!?9V5T1FEL
M95!O:6YT97(H*0H@("`@("`@(`H@("`@("`@(&EF("@@("`@(6ES<V5T*"1F
M:6QE4&]I;G1E<G-;)&9I;&5N86UE72D@?'P@"B`@("`@("`@("`@("`@("`A
M:7-?<F5S;W5R8V4H)&9I;&50;VEN=&5R<ULD9FEL96YA;65=*2D@>PH@("`@
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D9G`@/2`F1FEL93HZ7V=E=$9I
M;&50;VEN=&5R*"1F:6QE;F%M92P@1DE,15]-3T1%7U)%040L("1L;V-K*2DI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D9G`["B`@("`@("`@("`@('T@
M"@H@("`@("`@("`@("`D9FEL95!O:6YT97)S6R1F:6QE;F%M95T@/2`F)&9P
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1F<"`]("8D9FEL95!O
M:6YT97)S6R1F:6QE;F%M95T["B`@("`@("`@?2`*"B`@("`@("`@:68@*&9E
M;V8H)&9P*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?2`*("`@("`@("`*("`@("`@("!R971U<FX@<G1R:6TH9F=E=',H)&9P+"!&
M24Q%7TU!6%],24Y%7U)%041325I%*2P@(EQR7&XB*3L*("`@('T@"@H@("`@
M+RHJ"B`@("`@*B!7<FET97,@82!S:6YG;&4@;&EN92P@87!P96YD:6YG(&$@
M3$8@*&)Y(&1E9F%U;'0I"B`@("`@*B`*("`@("`J($!A8V-E<W,@('!U8FQI
M8R`*("`@("`J($!P87)A;2`@('-T<FEN9R`@)&9I;&5N86UE($YA;64@;V8@
M9FEL92!T;R!W<FET92!T;PH@("`@("H@0'!A<F%M("`@<W1R:6YG("`D;&EN
M92!,:6YE(&]F(&1A=&$@=&\@8F4@=W)I='1E;B!T;R!F:6QE"B`@("`@*B!`
M<&%R86T@("!S=')I;F<@("1M;V1E(%=R:71E(&UO9&4L(&-A;B!B92!E:71H
M97(@1DE,15]-3T1%7U=2251%(&]R($9)3$5?34]$15]!4%!%3D0*("`@("`J
M($!P87)A;2`@('-T<FEN9R`@)&-R;&8@5&AE($-23$8@>6]U<B!S>7-T96T@
M:7,@=7-I;F<N(%5.25@@/2!<;B!7:6YD;W=S(#T@7')<;B!-86,@/2!<<@H@
M("`@("H@0'!A<F%M("`@;6EX960@("`D;&]C:R!7:&5T:&5R('1O(&QO8VL@
M=&AE(&9I;&4*("`@("`J($!R971U<FX@(&UI>&5D("`@4$5!4E]%<G)O<B!O
M;B!E<G)O<B!O<B!N=6UB97(@;V8@8GET97,@=W)I='1E;B!T;R!F:6QE("AI
M;F-L=61I;F<@87!P96YD960@8W)L9BD*("`@("`J+PH@("`@9G5N8W1I;VX@
M=W)I=&5,:6YE*"1F:6QE;F%M92P@)&QI;F4L("1M;V1E(#T@1DE,15]-3T1%
M7T%04$5.1"P@)&-R;&8@/2`B7&XB+"`D;&]C:R`](&9A;'-E*0H@("`@>PH@
M("`@("`@(&EF("A014%2.CII<T5R<F]R*"1F<"`]("9&:6QE.CI?9V5T1FEL
M95!O:6YT97(H)&9I;&5N86UE+"`D;6]D92P@)&QO8VLI*2D@>PH@("`@("`@
M("`@("!R971U<FX@)&9P.PH@("`@("`@('T*("`@("`@("!I9B`H+3$@/3T]
M("1B>71E<R`](&9W<FET92@D9G`L("1L:6YE("X@)&-R;&8I*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")#86YN;W0@=W)I=&4@
M9&%T83H@)R1D871A)R!T;R!F:6QE.B`G)&9I;&4G(BD["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B`D8GET97,["B`@("!](`H*("`@("\J*@H@("`@("H@
M5&AI<R!R97=I;F1S(&$@9FEL97!O:6YT97(@=&\@=&AE('-T87)T(&]F(&$@
M9FEL90H@("`@("H@"B`@("`@*B!`86-C97-S("!P=6)L:6,@"B`@("`@*B!`
M<&%R86T@("!S=')I;F<@("1F:6QE;F%M92!4:&4@9FEL96YA;64*("`@("`J
M($!P87)A;2`@('-T<FEN9R`@)&UO9&4@36]D92!T:&4@9FEL92!W87,@;W!E
M;F5D(&EN"B`@("`@*B!`<F5T=7)N("!M:7AE9"`@(%!%05(@17)R;W(@;VX@
M97)R;W(L('1R=64@;VX@<W5C8V5S<PH@("`@("HO"B`@("!F=6YC=&EO;B!R
M97=I;F0H)&9I;&5N86UE+"`D;6]D92D*("`@('L*("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D9G`@/2`F1FEL93HZ7V=E=$9I;&50;VEN=&5R*"1F:6QE
M;F%M92P@)&UO9&4I*2D@>PH@("`@("`@("`@("!R971U<FX@)&9P.PH@("`@
M("`@('T*("`@("`@("!I9B`H(4!R97=I;F0H)&9P*2D@>PH@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B0V%N;F]T(')E=VEN9"!F:6QE
M.B`D9FEL96YA;64B*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!](`H*("`@("\J*@H@("`@("H@0VQO<V5S(&%L;"!O<&5N(&9I;&4@
M<&]I;G1E<G,*("`@("`J(`H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@
M*B!`<F5T=7)N("!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L;W-E06QL
M*"D*("`@('L*("`@("`@("`D;&]C:W,@/2`F4$5!4CHZ9V5T4W1A=&EC4')O
M<&5R='DH)T9I;&4G+"`G;&]C:W,G*3L*("`@("`@("`D9FEL95!O:6YT97)S
M(#T@)E!%05(Z.F=E=%-T871I8U!R;W!E<G1Y*"=&:6QE)RP@)V9I;&50;VEN
M=&5R<R<I.PH@("`@("`@(`H@("`@("`@("\O('5N;&]C:R!F:6QE<PH@("`@
M("`@(&9O<B`H)&D@/2`P+"`D8R`](&-O=6YT*"1L;V-K<RD[("1I(#P@)&,[
M("1I*RLI('L*("`@("`@("`@("`@:7-?<F5S;W5R8V4H)&QO8VMS6R1I72D@
M86YD($!F;&]C:R@D;&]C:W-;)&E=+"!,3T-+7U5.*3L*("`@("`@("!]"B`@
M("`@("`@"B`@("`@("`@+R\@8VQO<V4@9FEL97,*("`@("`@("!I9B`H(65M
M<'1Y*"1F:6QE4&]I;G1E<G,I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1F
M:6QE4&]I;G1E<G,@87,@)&9N86UE(#T^("1M;V1E<RD@>PH@("`@("`@("`@
M("`@("`@9F]R96%C:"`H87)R87E?:V5Y<R@D;6]D97,I(&%S("1M;V1E*2![
M"B`@("`@("`@("`@("`@("`@("`@:68@*&ES7W)E<V]U<F-E*"1F:6QE4&]I
M;G1E<G-;)&9N86UE75LD;6]D95TI*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@($!F8VQO<V4H)&9I;&50;VEN=&5R<ULD9FYA;65=6R1M;V1E72D["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('5N<V5T
M*"1F:6QE4&]I;G1E<G-;)&9N86UE75LD;6]D95TI.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H@("`@"B`@("`O
M*BH*("`@("`J(%1H:7,@8VQO<V5S(&%N(&]P96X@9FEL92!P;VEN=&5R"B`@
M("`@*B`*("`@("`J($!A8V-E<W,@('!U8FQI8R`*("`@("`J($!P87)A;2`@
M('-T<FEN9R`@)&9I;&5N86UE(%1H92!F:6QE;F%M92!T:&%T('=A<R!O<&5N
M960*("`@("`J($!P87)A;2`@('-T<FEN9R`@)&UO9&4@36]D92!T:&4@9FEL
M92!W87,@;W!E;F5D(&EN"B`@("`@*B!`<F5T=7)N("!M:7AE9"`@(%!%05(@
M17)R;W(@;VX@97)R;W(L('1R=64@;W1H97)W:7-E"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&-L;W-E*"1F:6QE;F%M92P@)&UO9&4I"B`@("!["B`@("`@("`@
M)&9I;&50;VEN=&5R<R`]("9014%2.CIG9713=&%T:6-0<F]P97)T>2@G1FEL
M92<L("=F:6QE4&]I;G1E<G,G*3L*("`@("`@("`*("`@("`@("!I9B`H3U-?
M5TE.1$]74RD@>PH@("`@("`@("`@("`D9FEL96YA;64@/2!S=')4;TQO=V5R
M*"1F:6QE;F%M92D["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)&9I
M;&50;VEN=&5R<ULD9FEL96YA;65=6R1M;V1E72DI('L*("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@?0H@("`@("`@(`H@("`@("`@("1F<"`]
M("1F:6QE4&]I;G1E<G-;)&9I;&5N86UE75LD;6]D95T["B`@("`@("`@=6YS
M970H)&9I;&50;VEN=&5R<ULD9FEL96YA;65=6R1M;V1E72D["B`@("`@("`@
M"B`@("`@("`@:68@*&ES7W)E<V]U<F-E*"1F<"DI('L*("`@("`@("`@("`@
M+R\@=6YL;V-K(&9I;&4*("`@("`@("`@("`@0&9L;V-K*"1F<"P@3$]#2U]5
M3BD["B`@("`@("`@("`@("\O(&-L;W-E(&9I;&4*("`@("`@("`@("`@:68@
M*"%`9F-L;W-E*"1F<"DI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*")#86YN;W0@8VQO<V4@9FEL93H@)&9I;&5N86UE(BD[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!](`H*("`@("\J*@H@("`@("H@5&AI<R!U;FQO8VMS
M(&$@;&]C:V5D(&9I;&4@<&]I;G1E<BX*("`@("`J(`H@("`@("H@0&%C8V5S
M<R`@<'5B;&EC(`H@("`@("H@0'!A<F%M("`@<W1R:6YG("`D9FEL96YA;64@
M5&AE(&9I;&5N86UE('1H870@=V%S(&]P96YE9`H@("`@("H@0'!A<F%M("`@
M<W1R:6YG("`D;6]D92!-;V1E('1H92!F:6QE('=A<R!O<&5N960@:6X*("`@
M("`J($!R971U<FX@(&UI>&5D("`@4$5!4B!%<G)O<B!O;B!E<G)O<BP@=')U
M92!O=&AE<G=I<V4*("`@("`J+PH@("`@9G5N8W1I;VX@=6YL;V-K*"1F:6QE
M;F%M92P@)&UO9&4I"B`@("!["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)&9P(#T@)D9I;&4Z.E]G971&:6QE4&]I;G1E<B@D9FEL96YA;64L("1M;V1E
M*2DI('L*("`@("`@("`@("`@<F5T=7)N("1F<#L*("`@("`@("!]"B`@("`@
M("`@:68@*"%`9FQO8VLH)&9P+"!,3T-+7U5.*2D@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B0V%C;FYO="!U;FQO8VL@9FEL93H@
M)&9I;&5N86UE(BD["B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?2`*"B`@("`O*BH*("`@("`J($!D97!R96-A=&5D"B`@("`@*B\*("`@
M(&9U;F-T:6]N('-T<FEP5')A:6QI;F=397!A<F%T;W)S*"1P871H+"`D<V5P
M87)A=&]R(#T@1$E214-43U)97U-%4$%2051/4BD*("`@('L*("`@("`@("!R
M971U<FX@<G1R:6TH)'!A=&@L("1S97!A<F%T;W(I.PH@("`@?2`*"B`@("`O
M*BH*("`@("`J($!D97!R96-A=&5D"B`@("`@*B\*("`@(&9U;F-T:6]N('-T
M<FEP3&5A9&EN9U-E<&%R871O<G,H)'!A=&@L("1S97!A<F%T;W(@/2!$25)%
M0U1/4EE?4T5005)!5$]2*0H@("`@>PH@("`@("`@(')E='5R;B!L=')I;2@D
M<&%T:"P@)'-E<&%R871O<BD["B`@("!](`H*("`@("\J*@H@("`@("H@0&1E
M<')E8V%T960@("`@("!5<V4@1FEL95]5=&EL.CIB=6EL9%!A=&@H*2!I;G-T
M96%D+@H@("`@("HO"B`@("!F=6YC=&EO;B!B=6EL9%!A=&@H)'!A<G1S+"`D
M<V5P87)A=&]R(#T@1$E214-43U)97U-%4$%2051/4BD*("`@('L*("`@("`@
M("!R97%U:7)E7V]N8V4@)T9I;&4O571I;"YP:'`G.PH@("`@("`@(')E='5R
M;B!&:6QE7U5T:6PZ.F)U:6QD4&%T:"@D<&%R=',L("1S97!A<F%T;W(I.PH@
M("`@?2`*"B`@("`O*BH*("`@("`J($!D97!R96-A=&5D("`@("`@57-E($9I
M;&5?571I;#HZ<VMI<%)O;W0H*2!I;G-T96%D+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!S:VEP4F]O="@D<&%T:"D*("`@('L*("`@("`@("!R97%U:7)E7V]N
M8V4@)T9I;&4O571I;"YP:'`G.PH@("`@("`@(')E='5R;B!&:6QE7U5T:6PZ
M.G-K:7!2;V]T*"1P871H*3L*("`@('T@"@H@("`@+RHJ"B`@("`@*B!`9&5P
M<F5C871E9"`@("`@(%5S92!&:6QE7U5T:6PZ.G1M<$1I<B@I(&EN<W1E860N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1E;7!$:7(H*0H@("`@>PH@("`@
M("`@(')E<75I<F5?;VYC92`G1FEL92]5=&EL+G!H<"<["B`@("`@("`@<F5T
M=7)N($9I;&5?571I;#HZ=&UP1&ER*"D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!`9&5P<F5C871E9"`@("`@(%5S92!&:6QE7U5T:6PZ.G1M<$9I;&4H*2!I
M;G-T96%D+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971496UP1FEL92@D9&ER
M;F%M92`](&YU;&PI"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=&:6QE
M+U5T:6PN<&AP)SL*("`@("`@("!R971U<FX@1FEL95]5=&EL.CIT;7!&:6QE
M*"1D:7)N86UE*3L*("`@('T@"@H@("`@+RHJ"B`@("`@*B!`9&5P<F5C871E
M9"`@("`@(%5S92!&:6QE7U5T:6PZ.FES06)S;VQU=&4H*2!I;G-T96%D+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!I<T%B<V]L=71E*"1P871H*0H@("`@>PH@
M("`@("`@(')E<75I<F5?;VYC92`G1FEL92]5=&EL+G!H<"<["B`@("`@("`@
M<F5T=7)N($9I;&5?571I;#HZ:7-!8G-O;'5T92@D<&%T:"D["B`@("!](`H*
M("`@("\J*@H@("`@("H@0&1E<')E8V%T960@("`@("!5<V4@1FEL95]5=&EL
M.CIR96QA=&EV95!A=&@H*2!I;G-T96%D+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!R96QA=&EV95!A=&@H)'!A=&@L("1R;V]T+"`D<V5P87)A=&]R(#T@1$E2
M14-43U)97U-%4$%2051/4BD*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@
M)T9I;&4O571I;"YP:'`G.PH@("`@("`@(')E='5R;B!&:6QE7U5T:6PZ.G)E
M;&%T:79E4&%T:"@D<&%T:"P@)')O;W0L("1S97!A<F%T;W(I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0&1E<')E8V%T960@("`@("!5<V4@1FEL95]5=&EL
M.CIR96%L<&%T:"@I(&EN<W1E860N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E
M86QP871H*"1P871H+"`D<V5P87)A=&]R(#T@1$E214-43U)97U-%4$%2051/
M4BD*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)T9I;&4O571I;"YP:'`G
M.PH@("`@("`@(')E='5R;B!&:6QE7U5T:6PZ.G)E86QP871H*"1P871H+"`D
M<V5P87)A=&]R*3L*("`@('T*?0H*4$5!4CHZ<F5G:7-T97)3:'5T9&]W;D9U
M;F,H87)R87DH)T9I;&4G+"`G7T9I;&4G*2D["@H_/@H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O4$5!4BYP:'``````````````````````````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#$P-3`T-2`Q,#4Q-30S,S<S,R`P,3<W
M,S,`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`-"B\J*@T*("H@4$5!4BP@=&AE(%!(4"!%>'1E;G-I;VX@86YD($%P
M<&QI8V%T:6]N(%)E<&]S:71O<GD-"B`J#0H@*B!014%2(&-L87-S(&%N9"!0
M14%27T5R<F]R(&-L87-S#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-
M"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@
M=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES
M(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@
M9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*
M("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I
M="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@
M;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM
M961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA
M9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@4W1E<FQI;F<@2'5G:&5S(#QS
M=&5R;&EN9T!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@
M/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@5&]M87,@5BY6+D-O>"`\
M8V]X0&ED96-N970N8V]M/@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@
M/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H
M92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I
M;VX@("`@0U93.B`D260Z(%!%05(N<&AP+'8@,2XY."`R,#`V+S`Q+S(S(#`U
M.C,X.C`U(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E
M87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@
M879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,"XQ#0H@*B\-"@T*+RHJ(T`K#0H@
M*B!%4E)/4B!C;VYS=&%N=',-"B`J+PT*9&5F:6YE*"=014%27T524D]27U)%
M5%523B<L("`@("`Q*3L-"F1E9FEN92@G4$5!4E]%4E)/4E]04DE.5"<L("`@
M("`@,BD[#0ID969I;F4H)U!%05)?15)23U)?5%))1T=%4B<L("`@(#0I.PT*
M9&5F:6YE*"=014%27T524D]27T1)12<L("`@("`@("`X*3L-"F1E9FEN92@G
M4$5!4E]%4E)/4E]#04Q,0D%#2R<L("`Q-BD[#0HO*BH-"B`J(%=!4DY)3D<Z
M(&]B<V]L971E#0H@*B!`9&5P<F5C871E9`T*("HO#0ID969I;F4H)U!%05)?
M15)23U)?15A#15!424].)RP@,S(I.PT*+RHJ(T`M*B\-"F1E9FEN92@G4$5!
M4E]:13(G+"`H9G5N8W1I;VY?97AI<W1S*"=V97)S:6]N7V-O;7!A<F4G*2`F
M)@T*("`@("`@("`@("`@("`@("`@("!V97)S:6]N7V-O;7!A<F4H>F5N9%]V
M97)S:6]N*"DL("(R+61E=B(L(")G92(I*2D[#0H-"FEF("AS=6)S='(H4$A0
M7T]3+"`P+"`S*2`]/2`G5TE.)RD@>PT*("`@(&1E9FEN92@G3U-?5TE.1$]7
M4R<L('1R=64I.PT*("`@(&1E9FEN92@G3U-?54Y)6"<L("`@(&9A;'-E*3L-
M"B`@("!D969I;F4H)U!%05)?3U,G+"`@("`G5VEN9&]W<R<I.PT*?2!E;'-E
M('L-"B`@("!D969I;F4H)T]37U=)3D1/5U,G+"!F86QS92D[#0H@("`@9&5F
M:6YE*"=/4U]53DE8)RP@("`@=')U92D[#0H@("`@9&5F:6YE*"=014%27T]3
M)RP@("`@)U5N:7@G*3L@+R\@8FQA=&%N="!A<W-U;7!T:6]N#0I]#0H-"B\O
M(&EN<W1A;G0@8F%C:W=A<F1S(&-O;7!A=&EB:6QI='D-"FEF("@A9&5F:6YE
M9"@G4$%42%]315!!4D%43U(G*2D@>PT*("`@(&EF("A/4U]724Y$3U=3*2![
M#0H@("`@("`@(&1E9FEN92@G4$%42%]315!!4D%43U(G+"`G.R<I.PT*("`@
M('T@96QS92![#0H@("`@("`@(&1E9FEN92@G4$%42%]315!!4D%43U(G+"`G
M.B<I.PT*("`@('T-"GT-"@T*)$=,3T)!3%-;)U]014%27V1E9F%U;'1?97)R
M;W)?;6]D92==("`@("`](%!%05)?15)23U)?4D5455)..PT*)$=,3T)!3%-;
M)U]014%27V1E9F%U;'1?97)R;W)?;W!T:6]N<R==("`]($5?55-%4E].3U1)
M0T4[#0HD1TQ/0D%,4ULG7U!%05)?9&5S=')U8W1O<E]O8FIE8W1?;&ES="==
M(#T@87)R87DH*3L-"B1'3$]"04Q36R=?4$5!4E]S:'5T9&]W;E]F=6YC<R==
M("`@("`@("`@/2!A<G)A>2@I.PT*)$=,3T)!3%-;)U]014%27V5R<F]R7VAA
M;F1L97)?<W1A8VLG72`@("`](&%R<F%Y*"D[#0H-"D!I;FE?<V5T*"=T<F%C
M:U]E<G)O<G,G+"!T<G5E*3L-"@T*+RHJ#0H@*B!"87-E(&-L87-S(&9O<B!O
M=&AE<B!014%2(&-L87-S97,N("!0<F]V:61E<R!R=61I;65N=&%R>0T*("H@
M96UU;&%T:6]N(&]F(&1E<W1R=6-T;W)S+@T*("H-"B`J($EF('EO=2!W86YT
M(&$@9&5S=')U8W1O<B!I;B!Y;W5R(&-L87-S+"!I;FAE<FET(%!%05(@86YD
M(&UA:V4@80T*("H@9&5S=')U8W1O<B!M971H;V0@8V%L;&5D(%]Y;W5R8VQA
M<W-N86UE("AS86UE(&YA;64@87,@=&AE#0H@*B!C;VYS=')U8W1O<BP@8G5T
M('=I=&@@82`B7R(@<')E9FEX*2X@($%L<V\L(&EN('EO=7(@8V]N<W1R=6-T
M;W(@>6]U#0H@*B!H879E('1O(&-A;&P@=&AE(%!%05(@8V]N<W1R=6-T;W(Z
M("1T:&ES+3Y014%2*"D[+@T*("H@5&AE(&1E<W1R=6-T;W(@;65T:&]D('=I
M;&P@8F4@8V%L;&5D('=I=&AO=70@<&%R86UE=&5R<RX@($YO=&4@=&AA=`T*
M("H@870@:6X@<V]M92!305!)(&EM<&QE;65N=&%T:6]N<R`H<W5C:"!A<R!!
M<&%C:&4I+"!A;GD@;W5T<'5T(&1U<FEN9PT*("H@=&AE(')E<75E<W0@<VAU
M=&1O=VX@*&EN('=H:6-H(&1E<W1R=6-T;W)S(&%R92!C86QL960I('-E96US
M('1O(&)E#0H@*B!D:7-C87)D960N("!)9B!Y;W4@;F5E9"!T;R!G970@86YY
M(&1E8G5G(&EN9F]R;6%T:6]N(&9R;VT@>6]U<@T*("H@9&5S=')U8W1O<BP@
M=7-E(&5R<F]R7VQO9R@I+"!S>7-L;V<H*2!O<B!S;VUE=&AI;F<@<VEM:6QA
M<BX-"B`J#0H@*B!)35!/4E1!3E0A(%1O('5S92!T:&4@96UU;&%T960@9&5S
M=')U8W1O<G,@>6]U(&YE960@=&\@8W)E871E('1H90T*("H@;V)J96-T<R!B
M>2!R969E<F5N8V4Z("1O8FH@/28@;F5W(%!%05)?8VAI;&0[#0H@*@T*("H@
M0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U
M=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO
M<B`@("`@5&]M87,@5BY6+B!#;W@@/&-O>$!I9&5C;F5T+F-O;3X-"B`J($!A
M=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C
M;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS
M92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@
M3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@
M*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!
M4@T*("H@0'-E92`@("`@("`@4$5!4E]%<G)O<@T*("H@0'-I;F-E("`@("`@
M0VQA<W,@879A:6QA8FQE('-I;F-E(%!(4"`T+C`N,@T*("H@0&QI;FL@("`@
M("`@(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+V-O<F4N<&5A<BYP
M:'`C8V]R92YP96%R+G!E87(-"B`J+PT*8VQA<W,@4$5!4@T*>PT*("`@("\O
M('M[>R!P<F]P97)T:65S#0H-"B`@("`O*BH-"B`@("`@*B!7:&5T:&5R('1O
M(&5N86)L92!I;G1E<FYA;"!D96)U9R!M97-S86=E<RX-"B`@("`@*@T*("`@
M("`J($!V87(@("`@(&)O;VP-"B`@("`@*B!`86-C97-S("!P<FEV871E#0H@
M("`@("HO#0H@("`@=F%R("1?9&5B=6<@/2!F86QS93L-"@T*("`@("\J*@T*
M("`@("`J($1E9F%U;'0@97)R;W(@;6]D92!F;W(@=&AI<R!O8FIE8W0N#0H@
M("`@("H-"B`@("`@*B!`=F%R("`@("!I;G0-"B`@("`@*B!`86-C97-S("!P
M<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?9&5F875L=%]E<G)O<E]M;V1E
M(#T@;G5L;#L-"@T*("`@("\J*@T*("`@("`J($1E9F%U;'0@97)R;W(@;W!T
M:6]N<R!U<V5D(&9O<B!T:&ES(&]B:F5C="!W:&5N(&5R<F]R(&UO9&4-"B`@
M("`@*B!I<R!014%27T524D]27U1224='15(N#0H@("`@("H-"B`@("`@*B!`
M=F%R("`@("!I;G0-"B`@("`@*B!`86-C97-S("!P<FEV871E#0H@("`@("HO
M#0H@("`@=F%R("1?9&5F875L=%]E<G)O<E]O<'1I;VYS(#T@;G5L;#L-"@T*
M("`@("\J*@T*("`@("`J($1E9F%U;'0@97)R;W(@:&%N9&QE<B`H8V%L;&)A
M8VLI(&9O<B!T:&ES(&]B:F5C="P@:68@97)R;W(@;6]D92!I<PT*("`@("`J
M(%!%05)?15)23U)?0T%,3$)!0TLN#0H@("`@("H-"B`@("`@*B!`=F%R("`@
M("!S=')I;F<-"B`@("`@*B!`86-C97-S("!P<FEV871E#0H@("`@("HO#0H@
M("`@=F%R("1?9&5F875L=%]E<G)O<E]H86YD;&5R(#T@)R<[#0H-"B`@("`O
M*BH-"B`@("`@*B!7:&EC:"!C;&%S<R!T;R!U<V4@9F]R(&5R<F]R(&]B:F5C
M=',N#0H@("`@("H-"B`@("`@*B!`=F%R("`@("!S=')I;F<-"B`@("`@*B!`
M86-C97-S("!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?97)R;W)?8VQA
M<W,@/2`G4$5!4E]%<G)O<B<[#0H-"B`@("`O*BH-"B`@("`@*B!!;B!A<G)A
M>2!O9B!E>'!E8W1E9"!E<G)O<G,N#0H@("`@("H-"B`@("`@*B!`=F%R("`@
M("!A<G)A>0T*("`@("`J($!A8V-E<W,@('!R:79A=&4-"B`@("`@*B\-"B`@
M("!V87(@)%]E>'!E8W1E9%]E<G)O<G,@/2!A<G)A>2@I.PT*#0H@("`@+R\@
M?7U]#0H-"B`@("`O+R![>WL@8V]N<W1R=6-T;W(-"@T*("`@("\J*@T*("`@
M("`J($-O;G-T<G5C=&]R+B`@4F5G:7-T97)S('1H:7,@;V)J96-T(&EN#0H@
M("`@("H@)%]014%27V1E<W1R=6-T;W)?;V)J96-T7VQI<W0@9F]R(&1E<W1R
M=6-T;W(@96UU;&%T:6]N(&EF(&$-"B`@("`@*B!D97-T<G5C=&]R(&]B:F5C
M="!E>&ES=',N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("1E<G)O
M<E]C;&%S<R`@*&]P=&EO;F%L*2!W:&EC:"!C;&%S<R!T;R!U<V4@9F]R#0H@
M("`@("H@("`@("`@(&5R<F]R(&]B:F5C=',L(&1E9F%U;'1S('1O(%!%05)?
M17)R;W(N#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`<F5T=7)N
M('9O:60-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!014%2*"1E<G)O<E]C;&%S
M<R`](&YU;&PI#0H@("`@>PT*("`@("`@("`D8VQA<W-N86UE(#T@<W1R=&]L
M;W=E<BAG971?8VQA<W,H)'1H:7,I*3L-"B`@("`@("`@:68@*"1T:&ES+3Y?
M9&5B=6<I('L-"B`@("`@("`@("`@('!R:6YT(")014%2(&-O;G-T<G5C=&]R
M(&-A;&QE9"P@8VQA<W,])&-L87-S;F%M95QN(CL-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H)&5R<F]R7V-L87-S("$]/2!N=6QL*2![#0H@("`@("`@("`@
M("`D=&AI<RT^7V5R<F]R7V-L87-S(#T@)&5R<F]R7V-L87-S.PT*("`@("`@
M("!]#0H@("`@("`@('=H:6QE("@D8VQA<W-N86UE("8F('-T<F-A<V5C;7`H
M)&-L87-S;F%M92P@(G!E87(B*2D@>PT*("`@("`@("`@("`@)&1E<W1R=6-T
M;W(@/2`B7R1C;&%S<VYA;64B.PT*("`@("`@("`@("`@:68@*&UE=&AO9%]E
M>&ES=',H)'1H:7,L("1D97-T<G5C=&]R*2D@>PT*("`@("`@("`@("`@("`@
M(&=L;V)A;"`D7U!%05)?9&5S=')U8W1O<E]O8FIE8W1?;&ES=#L-"B`@("`@
M("`@("`@("`@("`D7U!%05)?9&5S=')U8W1O<E]O8FIE8W1?;&ES=%M=(#T@
M)B1T:&ES.PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)$=,3T)!3%-;
M)U]014%27U-(551$3U=.7U)%1TE35$52140G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@<F5G:7-T97)?<VAU=&1O=VY?9G5N8W1I;VXH(E]014%27V-A
M;&Q?9&5S=')U8W1O<G,B*3L-"B`@("`@("`@("`@("`@("`@("`@)$=,3T)!
M3%-;)U]014%27U-(551$3U=.7U)%1TE35$52140G72`]('1R=64[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D8VQA<W-N86UE(#T@
M9V5T7W!A<F5N=%]C;&%S<R@D8VQA<W-N86UE*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!D
M97-T<G5C=&]R#0H-"B`@("`O*BH-"B`@("`@*B!$97-T<G5C=&]R("AT:&4@
M96UU;&%T960@='EP92!O9BXN+BDN("!$;V5S(&YO=&AI;F<@<FEG:'0@;F]W
M+`T*("`@("`J(&)U="!I<R!I;F-L=61E9"!F;W(@9F]R=V%R9"!C;VUP871I
M8FEL:71Y+"!S;R!S=6)C;&%S<PT*("`@("`J(&1E<W1R=6-T;W)S('-H;W5L
M9"!A;'=A>7,@8V%L;"!I="X-"B`@("`@*@T*("`@("`J(%-E92!T:&4@;F]T
M92!I;B!T:&4@8VQA<W,@9&5S8VEP=&EO;B!A8F]U="!O=71P=70@9G)O;0T*
M("`@("`J(&1E<W1R=6-T;W)S+@T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P
M=6)L:6,-"B`@("`@*B!`<F5T=7)N('9O:60-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!?4$5!4B@I('L-"B`@("`@("`@:68@*"1T:&ES+3Y?9&5B=6<I('L-
M"B`@("`@("`@("`@('!R:6YT9B@B4$5!4B!D97-T<G5C=&]R(&-A;&QE9"P@
M8VQA<W,])7-<;B(L('-T<G1O;&]W97(H9V5T7V-L87-S*"1T:&ES*2DI.PT*
M("`@("`@("!]#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&=E
M=%-T871I8U!R;W!E<G1Y*"D-"@T*("`@("\J*@T*("`@("H@268@>6]U(&AA
M=F4@82!C;&%S<R!T:&%T)W,@;6]S=&QY+V5N=&ER96QY('-T871I8RP@86YD
M('EO=2!N965D('-T871I8PT*("`@("H@<')O<&5R=&EE<RP@>6]U(&-A;B!U
M<V4@=&AI<R!M971H;V0@=&\@<VEM=6QA=&4@=&AE;2X@16<N(&EN('EO=7(@
M;65T:&]D*',I#0H@("`@*B!D;R!T:&ES.B`D;7E687(@/2`F4$5!4CHZ9V5T
M4W1A=&EC4')O<&5R='DH)VUY8VQA<W,G+"`G;7E687(G*3L-"B`@("`J(%EO
M=2!-55-4('5S92!A(')E9F5R96YC92P@;W(@=&AE>2!W:6QL(&YO="!P97)S
M:7-T(0T*("`@("H-"B`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@*B!`<&%R
M86T@('-T<FEN9R`D8VQA<W,@(%1H92!C86QL:6YG(&-L87-S;F%M92P@=&\@
M<')E=F5N="!C;&%S:&5S#0H@("`@*B!`<&%R86T@('-T<FEN9R`D=F%R("`@
M(%1H92!V87)I86)L92!T;R!R971R:65V92X-"B`@("`J($!R971U<FX@;6EX
M960@("!!(')E9F5R96YC92!T;R!T:&4@=F%R:6%B;&4N($EF(&YO="!S970@
M:70@=VEL;"!B90T*("`@("H@("`@("`@("`@("`@("`@(&%U=&\@:6YI=&EA
M;&ES960@=&\@3E5,3"X-"B`@("`J+PT*("`@(&9U;F-T:6]N("9G9713=&%T
M:6-0<F]P97)T>2@D8VQA<W,L("1V87(I#0H@("`@>PT*("`@("`@("!S=&%T
M:6,@)'!R;W!E<G1I97,[#0H@("`@("`@(')E='5R;B`D<')O<&5R=&EE<ULD
M8VQA<W-=6R1V87)=.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[
M>R!R96=I<W1E<E-H=71D;W=N1G5N8R@I#0H-"B`@("`O*BH-"B`@("`J(%5S
M92!T:&ES(&9U;F-T:6]N('1O(')E9VES=&5R(&$@<VAU=&1O=VX@;65T:&]D
M(&9O<B!S=&%T:6,-"B`@("`J(&-L87-S97,N#0H@("`@*@T*("`@("H@0&%C
M8V5S<R!P=6)L:6,-"B`@("`J($!P87)A;2`@;6EX960@)&9U;F,@(%1H92!F
M=6YC=&EO;B!N86UE("AO<B!A<G)A>2!O9B!C;&%S<R]M971H;V0I('1O(&-A
M;&P-"B`@("`J($!P87)A;2`@;6EX960@)&%R9W,@(%1H92!A<F=U;65N=',@
M=&\@<&%S<R!T;R!T:&4@9G5N8W1I;VX-"B`@("`J($!R971U<FX@=F]I9`T*
M("`@("HO#0H@("`@9G5N8W1I;VX@<F5G:7-T97)3:'5T9&]W;D9U;F,H)&9U
M;F,L("1A<F=S(#T@87)R87DH*2D-"B`@("![#0H@("`@("`@("\O(&EF('=E
M(&%R92!C86QL960@<W1A=&EC86QL>2P@=&AE<F4@:7,@82!P;W1E;G1I86P-
M"B`@("`@("`@+R\@=&AA="!N;R!S:'5T9&]W;B!F=6YC(&ES(')E9VES=&5R
M960N("!"=6<@(S8T-#4-"B`@("`@("`@:68@*"%I<W-E="@D1TQ/0D%,4ULG
M7U!%05)?4TA55$1/5TY?4D5'25-415)%1"==*2D@>PT*("`@("`@("`@("`@
M<F5G:7-T97)?<VAU=&1O=VY?9G5N8W1I;VXH(E]014%27V-A;&Q?9&5S=')U
M8W1O<G,B*3L-"B`@("`@("`@("`@("1'3$]"04Q36R=?4$5!4E]32%541$]7
M3E]214=)4U1%4D5$)UT@/2!T<G5E.PT*("`@("`@("!]#0H@("`@("`@("1'
M3$]"04Q36R=?4$5!4E]S:'5T9&]W;E]F=6YC<R==6UT@/2!A<G)A>2@D9G5N
M8RP@)&%R9W,I.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!I
M<T5R<F]R*"D-"@T*("`@("\J*@T*("`@("`J(%1E;&P@=VAE=&AE<B!A('9A
M;'5E(&ES(&$@4$5!4B!E<G)O<BX-"B`@("`@*@T*("`@("`J($!P87)A;2`@
M(&UI>&5D("1D871A("`@=&AE('9A;'5E('1O('1E<W0-"B`@("`@*B!`<&%R
M86T@("!I;G0@("`D8V]D92`@(&EF("1D871A(&ES(&%N(&5R<F]R(&]B:F5C
M="P@<F5T=7)N('1R=64-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M(&]N;'D@:68@)&-O9&4@:7,@82!S=')I;F<@86YD#0H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`D;V)J+3YG971-97-S86=E*"D@/3T@)&-O9&4@
M;W(-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("1C;V1E(&ES(&%N
M(&EN=&5G97(@86YD("1O8FHM/F=E=$-O9&4H*2`]/2`D8V]D90T*("`@("`J
M($!A8V-E<W,@('!U8FQI8PT*("`@("`J($!R971U<FX@(&)O;VP@("`@=')U
M92!I9B!P87)A;65T97(@:7,@86X@97)R;W(-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!I<T5R<F]R*"1D871A+"`D8V]D92`](&YU;&PI#0H@("`@>PT*("`@
M("`@("!I9B`H:7-?82@D9&%T82P@)U!%05)?17)R;W(G*2D@>PT*("`@("`@
M("`@("`@:68@*&ES7VYU;&PH)&-O9&4I*2![#0H@("`@("`@("`@("`@("`@
M<F5T=7)N('1R=64[#0H@("`@("`@("`@("!](&5L<V5I9B`H:7-?<W1R:6YG
M*"1C;V1E*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D9&%T82T^9V5T
M365S<V%G92@I(#T]("1C;V1E.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("!R971U<FX@)&1A=&$M/F=E=$-O9&4H*2`]/2`D8V]D
M93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[('-E=$5R
M<F]R2&%N9&QI;F<H*0T*#0H@("`@+RHJ#0H@("`@("H@4V5T<R!H;W<@97)R
M;W)S(&=E;F5R871E9"!B>2!T:&ES(&]B:F5C="!S:&]U;&0@8F4@:&%N9&QE
M9"X-"B`@("`@*B!#86X@8F4@:6YV;VME9"!B;W1H(&EN(&]B:F5C=',@86YD
M('-T871I8V%L;'DN("!)9B!C86QL960-"B`@("`@*B!S=&%T:6-A;&QY+"!S
M971%<G)O<DAA;F1L:6YG('-E=',@=&AE(&1E9F%U;'0@8F5H879I;W5R(&9O
M<B!A;&P-"B`@("`@*B!014%2(&]B:F5C=',N("!)9B!C86QL960@:6X@86X@
M;V)J96-T+"!S971%<G)O<DAA;F1L:6YG('-E=',-"B`@("`@*B!T:&4@9&5F
M875L="!B96AA=FEO=7(@9F]R('1H870@;V)J96-T+@T*("`@("`J#0H@("`@
M("H@0'!A<F%M(&EN="`D;6]D90T*("`@("`J("`@("`@("!/;F4@;V8@4$5!
M4E]%4E)/4E]215154DXL(%!%05)?15)23U)?4%))3E0L#0H@("`@("H@("`@
M("`@(%!%05)?15)23U)?5%))1T=%4BP@4$5!4E]%4E)/4E]$244L#0H@("`@
M("H@("`@("`@(%!%05)?15)23U)?0T%,3$)!0TL@;W(@4$5!4E]%4E)/4E]%
M6$-%4%1)3TXN#0H@("`@("H-"B`@("`@*B!`<&%R86T@;6EX960@)&]P=&EO
M;G,-"B`@("`@*B`@("`@("`@5VAE;B`D;6]D92!I<R!014%27T524D]27U12
M24='15(L('1H:7,@:7,@=&AE(&5R<F]R(&QE=F5L("AO;F4-"B`@("`@*B`@
M("`@("`@;V8@15]54T527TY/5$E#12P@15]54T527U=!4DY)3D<@;W(@15]5
M4T527T524D]2*2X-"B`@("`@*@T*("`@("`J("`@("`@("!7:&5N("1M;V1E
M(&ES(%!%05)?15)23U)?0T%,3$)!0TLL('1H:7,@<&%R86UE=&5R(&ES(&5X
M<&5C=&5D#0H@("`@("H@("`@("`@('1O(&)E('1H92!C86QL8F%C:R!F=6YC
M=&EO;B!O<B!M971H;V0N("!!(&-A;&QB86-K#0H@("`@("H@("`@("`@(&9U
M;F-T:6]N(&ES(&$@<W1R:6YG('=I=&@@=&AE(&YA;64@;V8@=&AE(&9U;F-T
M:6]N+"!A#0H@("`@("H@("`@("`@(&-A;&QB86-K(&UE=&AO9"!I<R!A;B!A
M<G)A>2!O9B!T=V\@96QE;65N=',Z('1H92!E;&5M96YT#0H@("`@("H@("`@
M("`@(&%T(&EN9&5X(#`@:7,@=&AE(&]B:F5C="P@86YD('1H92!E;&5M96YT
M(&%T(&EN9&5X(#$@:7,-"B`@("`@*B`@("`@("`@=&AE(&YA;64@;V8@=&AE
M(&UE=&AO9"!T;R!C86QL(&EN('1H92!O8FIE8W0N#0H@("`@("H-"B`@("`@
M*B`@("`@("`@5VAE;B`D;6]D92!I<R!014%27T524D]27U!224Y4(&]R(%!%
M05)?15)23U)?1$E%+"!T:&ES(&ES#0H@("`@("H@("`@("`@(&$@<')I;G1F
M(&9O<FUA="!S=')I;F<@=7-E9"!W:&5N('!R:6YT:6YG('1H92!E<G)O<@T*
M("`@("`J("`@("`@("!M97-S86=E+@T*("`@("`J#0H@("`@("H@0&%C8V5S
M<R!P=6)L:6,-"B`@("`@*B!`<F5T=7)N('9O:60-"B`@("`@*B!`<V5E(%!%
M05)?15)23U)?4D5455).#0H@("`@("H@0'-E92!014%27T524D]27U!224Y4
M#0H@("`@("H@0'-E92!014%27T524D]27U1224='15(-"B`@("`@*B!`<V5E
M(%!%05)?15)23U)?1$E%#0H@("`@("H@0'-E92!014%27T524D]27T-!3$Q"
M04-+#0H@("`@("H@0'-E92!014%27T524D]27T580T505$E/3@T*("`@("`J
M#0H@("`@("H@0'-I;F-E(%!(4"`T+C`N-0T*("`@("`J+PT*#0H@("`@9G5N
M8W1I;VX@<V5T17)R;W)(86YD;&EN9R@D;6]D92`](&YU;&PL("1O<'1I;VYS
M(#T@;G5L;"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RD@)B8@
M:7-?82@D=&AI<RP@)U!%05(G*2D@>PT*("`@("`@("`@("`@)'-E=&UO9&4@
M("`@(#T@)B1T:&ES+3Y?9&5F875L=%]E<G)O<E]M;V1E.PT*("`@("`@("`@
M("`@)'-E=&]P=&EO;G,@(#T@)B1T:&ES+3Y?9&5F875L=%]E<G)O<E]O<'1I
M;VYS.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'-E=&UO9&4@
M("`@(#T@)B1'3$]"04Q36R=?4$5!4E]D969A=6QT7V5R<F]R7VUO9&4G73L-
M"B`@("`@("`@("`@("1S971O<'1I;VYS("`]("8D1TQ/0D%,4ULG7U!%05)?
M9&5F875L=%]E<G)O<E]O<'1I;VYS)UT[#0H@("`@("`@('T-"@T*("`@("`@
M("!S=VET8V@@*"1M;V1E*2![#0H@("`@("`@("`@("!C87-E(%!%05)?15)2
M3U)?15A#15!424]..@T*("`@("`@("`@("`@8V%S92!014%27T524D]27U)%
M5%523CH-"B`@("`@("`@("`@(&-A<V4@4$5!4E]%4E)/4E]04DE.5#H-"B`@
M("`@("`@("`@(&-A<V4@4$5!4E]%4E)/4E]44DE'1T52.@T*("`@("`@("`@
M("`@8V%S92!014%27T524D]27T1)13H-"B`@("`@("`@("`@(&-A<V4@;G5L
M;#H-"B`@("`@("`@("`@("`@("`D<V5T;6]D92`]("1M;V1E.PT*("`@("`@
M("`@("`@("`@("1S971O<'1I;VYS(#T@)&]P=&EO;G,[#0H@("`@("`@("`@
M("`@("`@8G)E86L[#0H-"B`@("`@("`@("`@(&-A<V4@4$5!4E]%4E)/4E]#
M04Q,0D%#2SH-"B`@("`@("`@("`@("`@("`D<V5T;6]D92`]("1M;V1E.PT*
M("`@("`@("`@("`@("`@("\O(&-L87-S+V]B:F5C="!M971H;V0@8V%L;&)A
M8VL-"B`@("`@("`@("`@("`@("!I9B`H:7-?8V%L;&%B;&4H)&]P=&EO;G,I
M*2![#0H@("`@("`@("`@("`@("`@("`@("1S971O<'1I;VYS(#T@)&]P=&EO
M;G,[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@=')I9V=E<E]E<G)O<B@B:6YV86QI9"!E<G)O<B!C86QL8F%C:R(L
M($5?55-%4E]705).24Y'*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@8G)E86L[#0H-"B`@("`@("`@("`@(&1E9F%U;'0Z#0H@("`@
M("`@("`@("`@("`@=')I9V=E<E]E<G)O<B@B:6YV86QI9"!E<G)O<B!M;V1E
M(BP@15]54T527U=!4DY)3D<I.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*
M("`@("`@("!]#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&5X
M<&5C=$5R<F]R*"D-"@T*("`@("\J*@T*("`@("`J(%1H:7,@;65T:&]D(&ES
M('5S960@=&\@=&5L;"!W:&EC:"!E<G)O<G,@>6]U(&5X<&5C="!T;R!G970N
M#0H@("`@("H@17AP96-T960@97)R;W)S(&%R92!A;'=A>7,@<F5T=7)N960@
M=VET:"!E<G)O<B!M;V1E#0H@("`@("H@4$5!4E]%4E)/4E]215154DXN("!%
M>'!E8W1E9"!E<G)O<B!C;V1E<R!A<F4@<W1O<F5D(&EN(&$@<W1A8VLL#0H@
M("`@("H@86YD('1H:7,@;65T:&]D('!U<VAE<R!A(&YE=R!E;&5M96YT(&]N
M=&\@:70N("!4:&4@;&ES="!O9@T*("`@("`J(&5X<&5C=&5D(&5R<F]R<R!A
M<F4@:6X@969F96-T('5N=&EL('1H97D@87)E('!O<'!E9"!O9F8@=&AE#0H@
M("`@("H@<W1A8VL@=VET:"!T:&4@<&]P17AP96-T*"D@;65T:&]D+@T*("`@
M("`J#0H@("`@("H@3F]T92!T:&%T('1H:7,@;65T:&]D(&-A;B!N;W0@8F4@
M8V%L;&5D('-T871I8V%L;'D-"B`@("`@*@T*("`@("`J($!P87)A;2!M:7AE
M9"`D8V]D92!A('-I;F=L92!E<G)O<B!C;V1E(&]R(&%N(&%R<F%Y(&]F(&5R
M<F]R(&-O9&5S('1O(&5X<&5C=`T*("`@("`J#0H@("`@("H@0')E='5R;B!I
M;G0@("`@('1H92!N97<@9&5P=&@@;V8@=&AE(")E>'!E8W1E9"!E<G)O<G,B
M('-T86-K#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!E>'!E8W1%<G)O<B@D8V]D92`]("<J)RD-"B`@("![#0H@("`@
M("`@(&EF("AI<U]A<G)A>2@D8V]D92DI('L-"B`@("`@("`@("`@(&%R<F%Y
M7W!U<V@H)'1H:7,M/E]E>'!E8W1E9%]E<G)O<G,L("1C;V1E*3L-"B`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@(&%R<F%Y7W!U<V@H)'1H:7,M/E]E
M>'!E8W1E9%]E<G)O<G,L(&%R<F%Y*"1C;V1E*2D[#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N('-I>F5O9B@D=&AI<RT^7V5X<&5C=&5D7V5R<F]R<RD[
M#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[('!O<$5X<&5C="@I
M#0H-"B`@("`O*BH-"B`@("`@*B!4:&ES(&UE=&AO9"!P;W!S(&]N92!E;&5M
M96YT(&]F9B!T:&4@97AP96-T960@97)R;W(@8V]D97,-"B`@("`@*B!S=&%C
M:RX-"B`@("`@*@T*("`@("`J($!R971U<FX@87)R87D@("!T:&4@;&ES="!O
M9B!E<G)O<B!C;V1E<R!T:&%T('=E<F4@<&]P<&5D#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@<&]P17AP96-T*"D-"B`@("![#0H@("`@("`@(')E='5R;B!A
M<G)A>5]P;W`H)'1H:7,M/E]E>'!E8W1E9%]E<G)O<G,I.PT*("`@('T-"@T*
M("`@("\O('U]?0T*("`@("\O('M[>R!?8VAE8VM$96Q%>'!E8W0H*0T*#0H@
M("`@+RHJ#0H@("`@("H@5&AI<R!M971H;V0@8VAE8VMS('5N<V5T<R!A;B!E
M<G)O<B!C;V1E(&EF(&%V86EL86)L90T*("`@("`J#0H@("`@("H@0'!A<F%M
M(&UI>&5D(&5R<F]R(&-O9&4-"B`@("`@*B!`<F5T=7)N(&)O;VP@=')U92!I
M9B!T:&4@97)R;W(@8V]D92!W87,@=6YS970L(&9A;'-E(&]T:&5R=VES90T*
M("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J($!S:6YC92!02%`@-"XS
M+C`-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?8VAE8VM$96Q%>'!E8W0H)&5R
M<F]R7V-O9&4I#0H@("`@>PT*("`@("`@("`D9&5L971E9"`](&9A;'-E.PT*
M#0H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?97AP96-T961?97)R;W)S($%3
M("1K97D@/3X@)&5R<F]R7V%R<F%Y*2![#0H@("`@("`@("`@("!I9B`H:6Y?
M87)R87DH)&5R<F]R7V-O9&4L("1E<G)O<E]A<G)A>2DI('L-"B`@("`@("`@
M("`@("`@("!U;G-E="@D=&AI<RT^7V5X<&5C=&5D7V5R<F]R<ULD:V5Y75MA
M<G)A>5]S96%R8V@H)&5R<F]R7V-O9&4L("1E<G)O<E]A<G)A>2E=*3L-"B`@
M("`@("`@("`@("`@("`D9&5L971E9"`]('1R=64[#0H@("`@("`@("`@("!]
M#0H-"B`@("`@("`@("`@("\O(&-L96%N('5P(&5M<'1Y(&%R<F%Y<PT*("`@
M("`@("`@("`@:68@*#`@/3T@8V]U;G0H)'1H:7,M/E]E>'!E8W1E9%]E<G)O
M<G-;)&ME>5TI*2![#0H@("`@("`@("`@("`@("`@=6YS970H)'1H:7,M/E]E
M>'!E8W1E9%]E<G)O<G-;)&ME>5TI.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B`D9&5L971E9#L-"B`@("!]#0H-"B`@("`O
M+R!]?7T-"B`@("`O+R![>WL@9&5L17AP96-T*"D-"@T*("`@("\J*@T*("`@
M("`J(%1H:7,@;65T:&]D(&1E;&5T97,@86QL(&]C8W5R96YC97,@;V8@=&AE
M('-P96-I9FEE9"!E;&5M96YT(&9R;VT-"B`@("`@*B!T:&4@97AP96-T960@
M97)R;W(@8V]D97,@<W1A8VLN#0H@("`@("H-"B`@("`@*B!`<&%R86T@(&UI
M>&5D("1E<G)O<E]C;V1E(&5R<F]R(&-O9&4@=&AA="!S:&]U;&0@8F4@9&5L
M971E9`T*("`@("`J($!R971U<FX@;6EX960@;&ES="!O9B!E<G)O<B!C;V1E
M<R!T:&%T('=E<F4@9&5L971E9"!O<B!E<G)O<@T*("`@("`J($!A8V-E<W,@
M<'5B;&EC#0H@("`@("H@0'-I;F-E(%!(4"`T+C,N,`T*("`@("`J+PT*("`@
M(&9U;F-T:6]N(&1E;$5X<&5C="@D97)R;W)?8V]D92D-"B`@("![#0H@("`@
M("`@("1D96QE=&5D(#T@9F%L<V4[#0H-"B`@("`@("`@:68@*"AI<U]A<G)A
M>2@D97)R;W)?8V]D92D@)B8@*#`@(3T@8V]U;G0H)&5R<F]R7V-O9&4I*2DI
M('L-"B`@("`@("`@("`@("\O("1E<G)O<E]C;V1E(&ES(&$@;F]N+65M<'1Y
M(&%R<F%Y(&AE<F4[#0H@("`@("`@("`@("`O+R!W92!W86QK('1H<F]U9V@@
M:70@=')Y:6YG('1O('5N<V5T(&%L;`T*("`@("`@("`@("`@+R\@=F%L=65S
M#0H@("`@("`@("`@("!F;W)E86-H*"1E<G)O<E]C;V1E(&%S("1K97D@/3X@
M)&5R<F]R*2![#0H@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?8VAE8VM$
M96Q%>'!E8W0H)&5R<F]R*2D@>PT*("`@("`@("`@("`@("`@("`@("`D9&5L
M971E9"`]("!T<G5E.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@("`@("1D96QE=&5D(#T@9F%L<V4[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N("1D
M96QE=&5D(#\@=')U92`Z(%!%05(Z.G)A:7-E17)R;W(H(E1H92!E>'!E8W1E
M9"!E<G)O<B!Y;W4@<W5B;6ET=&5D(&1O97,@;F]T(&5X:7-T(BD[("\O($E-
M4%)/5D4@344-"B`@("`@("`@?2!E;'-E:68@*"%E;7!T>2@D97)R;W)?8V]D
M92DI('L-"B`@("`@("`@("`@("\O("1E<G)O<E]C;V1E(&-O;65S(&%L;VYE
M+"!T<GEI;F<@=&\@=6YS970@:70-"B`@("`@("`@("`@(&EF("@D=&AI<RT^
M7V-H96-K1&5L17AP96-T*"1E<G)O<E]C;V1E*2D@>PT*("`@("`@("`@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B5&AE(&5X<&5C
M=&5D(&5R<F]R('EO=2!S=6)M:71T960@9&]E<R!N;W0@97AI<W0B*3L@+R\@
M24U04D]612!-10T*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@+R\@)&5R<F]R7V-O9&4@:7,@96UP='D-"B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")4:&4@97AP96-T960@97)R
M;W(@>6]U('-U8FUI='1E9"!I<R!E;7!T>2(I.R`O+R!)35!23U9%($U%#0H@
M("`@("`@('T-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@<F%I
M<V5%<G)O<B@I#0H-"B`@("`O*BH-"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!A
M('=R87!P97(@=&AA="!R971U<FYS(&%N(&EN<W1A;F-E(&]F('1H90T*("`@
M("`J(&-O;F9I9W5R960@97)R;W(@8VQA<W,@=VET:"!T:&ES(&]B:F5C="=S
M(&1E9F%U;'0@97)R;W(-"B`@("`@*B!H86YD;&EN9R!A<'!L:65D+B`@268@
M=&AE("1M;V1E(&%N9"`D;W!T:6]N<R!P87)A;65T97)S(&%R92!N;W0-"B`@
M("`@*B!S<&5C:69I960L('1H92!O8FIE8W0G<R!D969A=6QT<R!A<F4@=7-E
M9"X-"B`@("`@*@T*("`@("`J($!P87)A;2!M:7AE9"`D;65S<V%G92!A('1E
M>'0@97)R;W(@;65S<V%G92!O<B!A(%!%05(@97)R;W(@;V)J96-T#0H@("`@
M("H-"B`@("`@*B!`<&%R86T@:6YT("1C;V1E("`@("`@82!N=6UE<FEC(&5R
M<F]R(&-O9&4@*&ET(&ES('5P('1O('EO=7(@8VQA<W,-"B`@("`@*B`@("`@
M("`@("`@("`@("`@('1O(&1E9FEN92!T:&5S92!I9B!Y;W4@=V%N="!T;R!U
M<V4@8V]D97,I#0H@("`@("H-"B`@("`@*B!`<&%R86T@:6YT("1M;V1E("`@
M("`@3VYE(&]F(%!%05)?15)23U)?4D5455).+"!014%27T524D]27U!224Y4
M+`T*("`@("`J("`@("`@("`@("`@("`@("`@4$5!4E]%4E)/4E]44DE'1T52
M+"!014%27T524D]27T1)12P-"B`@("`@*B`@("`@("`@("`@("`@("`@(%!%
M05)?15)23U)?0T%,3$)!0TLL(%!%05)?15)23U)?15A#15!424].+@T*("`@
M("`J#0H@("`@("H@0'!A<F%M(&UI>&5D("1O<'1I;VYS($EF("1M;V1E(&ES
M(%!%05)?15)23U)?5%))1T=%4BP@=&AI<R!P87)A;65T97(-"B`@("`@*B`@
M("`@("`@("`@("`@("`@('-P96-I9FEE<R!T:&4@4$A0+6EN=&5R;F%L(&5R
M<F]R(&QE=F5L("AO;F4@;V8-"B`@("`@*B`@("`@("`@("`@("`@("`@($5?
M55-%4E].3U1)0T4L($5?55-%4E]705).24Y'(&]R($5?55-%4E]%4E)/4BDN
M#0H@("`@("H@("`@("`@("`@("`@("`@("!)9B`D;6]D92!I<R!014%27T52
M4D]27T-!3$Q"04-++"!T:&ES#0H@("`@("H@("`@("`@("`@("`@("`@("!P
M87)A;65T97(@<W!E8VEF:65S('1H92!C86QL8F%C:R!F=6YC=&EO;B!O<@T*
M("`@("`J("`@("`@("`@("`@("`@("`@;65T:&]D+B`@26X@;W1H97(@97)R
M;W(@;6]D97,@=&AI<R!P87)A;65T97(-"B`@("`@*B`@("`@("`@("`@("`@
M("`@(&ES(&EG;F]R960N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1U<V5R:6YF;R!)9B!Y;W4@;F5E9"!T;R!P87-S(&%L;VYG(&9O<B!E>&%M
M<&QE(&1E8G5G#0H@("`@("H@("`@("`@("`@("`@("`@("!I;F9O<FUA=&EO
M;BP@=&AI<R!P87)A;65T97(@:7,@;65A;G0@9F]R('1H870N#0H@("`@("H-
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1E<G)O<E]C;&%S<R!4:&4@<F5T=7)N
M960@97)R;W(@;V)J96-T('=I;&P@8F4-"B`@("`@*B`@("`@("`@("`@("`@
M("`@(&EN<W1A;G1I871E9"!F<F]M('1H:7,@8VQA<W,L(&EF('-P96-I9FEE
M9"X-"B`@("`@*@T*("`@("`J($!P87)A;2!B;V]L("1S:VEP;7-G($EF('1R
M=64L(')A:7-E17)R;W(@=VEL;"!O;FQY('!A<W,@97)R;W(@8V]D97,L#0H@
M("`@("H@("`@("`@("`@("`@("`@("!T:&4@97)R;W(@;65S<V%G92!P87)A
M;65T97(@=VEL;"!B92!D<F]P<&5D+@T*("`@("`J#0H@("`@("H@0&%C8V5S
M<R!P=6)L:6,-"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@(&$@4$5!4B!E<G)O
M<B!O8FIE8W0-"B`@("`@*B!`<V5E(%!%05(Z.G-E=$5R<F]R2&%N9&QI;F<-
M"B`@("`@*B!`<VEN8V4@4$A0(#0N,"XU#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@)G)A:7-E17)R;W(H)&UE<W-A9V4@/2!N=6QL+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("1C;V1E(#T@;G5L;"P-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`D;6]D92`](&YU;&PL#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@)&]P=&EO;G,@/2!N=6QL+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("1U<V5R:6YF;R`](&YU;&PL#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M)&5R<F]R7V-L87-S(#T@;G5L;"P-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`D<VMI<&US9R`](&9A;'-E*0T*("`@('L-"B`@("`@("`@+R\@5&AE(&5R
M<F]R(&ES('EE="!A(%!%05(@97)R;W(@;V)J96-T#0H@("`@("`@(&EF("AI
M<U]O8FIE8W0H)&UE<W-A9V4I*2![#0H@("`@("`@("`@("`D8V]D92`@("`@
M("`@/2`D;65S<V%G92T^9V5T0V]D92@I.PT*("`@("`@("`@("`@)'5S97)I
M;F9O("`@(#T@)&UE<W-A9V4M/F=E=%5S97));F9O*"D[#0H@("`@("`@("`@
M("`D97)R;W)?8VQA<W,@/2`D;65S<V%G92T^9V5T5'EP92@I.PT*("`@("`@
M("`@("`@)&UE<W-A9V4M/F5R<F]R7VUE<W-A9V5?<')E9FEX(#T@)R<[#0H@
M("`@("`@("`@("`D;65S<V%G92`@("`@/2`D;65S<V%G92T^9V5T365S<V%G
M92@I.PT*("`@("`@("!]#0H-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES*2`F
M)B!I<W-E="@D=&AI<RT^7V5X<&5C=&5D7V5R<F]R<RD@)B8@<VEZ96]F*"1T
M:&ES+3Y?97AP96-T961?97)R;W)S*2`^(#`@)B8@<VEZ96]F*"1E>'`@/2!E
M;F0H)'1H:7,M/E]E>'!E8W1E9%]E<G)O<G,I*2D@>PT*("`@("`@("`@("`@
M:68@*"1E>'!;,%T@/3T@(BHB('Q\#0H@("`@("`@("`@("`@("`@*&ES7VEN
M="AR97-E="@D97AP*2D@)B8@:6Y?87)R87DH)&-O9&4L("1E>'`I*2!\?`T*
M("`@("`@("`@("`@("`@("AI<U]S=')I;F<H<F5S970H)&5X<"DI("8F(&EN
M7V%R<F%Y*"1M97-S86=E+"`D97AP*2DI('L-"B`@("`@("`@("`@("`@("`D
M;6]D92`](%!%05)?15)23U)?4D5455)..PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@("\O($YO(&UO9&4@9VEV96XL('1R>2!G;&]B86P@
M;VYE<PT*("`@("`@("!I9B`H)&UO9&4@/3T](&YU;&PI('L-"B`@("`@("`@
M("`@("\O($-L87-S(&5R<F]R(&AA;F1L97(-"B`@("`@("`@("`@(&EF("AI
M<W-E="@D=&AI<RD@)B8@:7-S970H)'1H:7,M/E]D969A=6QT7V5R<F]R7VUO
M9&4I*2![#0H@("`@("`@("`@("`@("`@)&UO9&4@("`@/2`D=&AI<RT^7V1E
M9F%U;'1?97)R;W)?;6]D93L-"B`@("`@("`@("`@("`@("`D;W!T:6]N<R`]
M("1T:&ES+3Y?9&5F875L=%]E<G)O<E]O<'1I;VYS.PT*("`@("`@("`@("`@
M+R\@1VQO8F%L(&5R<F]R(&AA;F1L97(-"B`@("`@("`@("`@('T@96QS96EF
M("AI<W-E="@D1TQ/0D%,4ULG7U!%05)?9&5F875L=%]E<G)O<E]M;V1E)UTI
M*2![#0H@("`@("`@("`@("`@("`@)&UO9&4@("`@/2`D1TQ/0D%,4ULG7U!%
M05)?9&5F875L=%]E<G)O<E]M;V1E)UT[#0H@("`@("`@("`@("`@("`@)&]P
M=&EO;G,@/2`D1TQ/0D%,4ULG7U!%05)?9&5F875L=%]E<G)O<E]O<'1I;VYS
M)UT[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"@T*("`@("`@("!I9B`H
M)&5R<F]R7V-L87-S("$]/2!N=6QL*2![#0H@("`@("`@("`@("`D96,@/2`D
M97)R;W)?8VQA<W,[#0H@("`@("`@('T@96QS96EF("AI<W-E="@D=&AI<RD@
M)B8@:7-S970H)'1H:7,M/E]E<G)O<E]C;&%S<RDI('L-"B`@("`@("`@("`@
M("1E8R`]("1T:&ES+3Y?97)R;W)?8VQA<W,[#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`D96,@/2`G4$5!4E]%<G)O<B<[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"1S:VEP;7-G*2![#0H@("`@("`@("`@("`D82`]("9N
M97<@)&5C*"1C;V1E+"`D;6]D92P@)&]P=&EO;G,L("1U<V5R:6YF;RD[#0H@
M("`@("`@("`@("!R971U<FX@)&$[#0H@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`D82`]("9N97<@)&5C*"1M97-S86=E+"`D8V]D92P@)&UO9&4L
M("1O<'1I;VYS+"`D=7-E<FEN9F\I.PT*("`@("`@("`@("`@<F5T=7)N("1A
M.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[
M('1H<F]W17)R;W(H*0T*#0H@("`@+RHJ#0H@("`@("H@4VEM<&QE<B!F;W)M
M(&]F(')A:7-E17)R;W(@=VET:"!F97=E<B!O<'1I;VYS+B`@26X@;6]S="!C
M87-E<PT*("`@("`J(&UE<W-A9V4L(&-O9&4@86YD('5S97)I;F9O(&%R92!E
M;F]U9V@N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("1M97-S86=E
M#0H@("`@("H-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F=&AR;W=%<G)O<B@D
M;65S<V%G92`](&YU;&PL#0H@("`@("`@("`@("`@("`@("`@("`@("`@)&-O
M9&4@/2!N=6QL+`T*("`@("`@("`@("`@("`@("`@("`@("`@("1U<V5R:6YF
M;R`](&YU;&PI#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,I("8F
M(&ES7V$H)'1H:7,L("=014%2)RDI('L-"B`@("`@("`@("`@("1A(#T@)B1T
M:&ES+3YR86ES945R<F]R*"1M97-S86=E+"`D8V]D92P@;G5L;"P@;G5L;"P@
M)'5S97)I;F9O*3L-"B`@("`@("`@("`@(')E='5R;B`D83L-"B`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("1A(#T@)E!%05(Z.G)A:7-E17)R;W(H
M)&UE<W-A9V4L("1C;V1E+"!N=6QL+"!N=6QL+"`D=7-E<FEN9F\I.PT*("`@
M("`@("`@("`@<F5T=7)N("1A.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@
M+R\@?7U]#0H@("`@9G5N8W1I;VX@<W1A=&EC4'5S:$5R<F]R2&%N9&QI;F<H
M)&UO9&4L("1O<'1I;VYS(#T@;G5L;"D-"B`@("![#0H@("`@("`@("1S=&%C
M:R`]("8D1TQ/0D%,4ULG7U!%05)?97)R;W)?:&%N9&QE<E]S=&%C:R==.PT*
M("`@("`@("`D9&5F7VUO9&4@("`@/2`F)$=,3T)!3%-;)U]014%27V1E9F%U
M;'1?97)R;W)?;6]D92==.PT*("`@("`@("`D9&5F7V]P=&EO;G,@/2`F)$=,
M3T)!3%-;)U]014%27V1E9F%U;'1?97)R;W)?;W!T:6]N<R==.PT*("`@("`@
M("`D<W1A8VM;72`](&%R<F%Y*"1D969?;6]D92P@)&1E9E]O<'1I;VYS*3L-
M"B`@("`@("`@<W=I=&-H("@D;6]D92D@>PT*("`@("`@("`@("`@8V%S92!0
M14%27T524D]27T580T505$E/3CH-"B`@("`@("`@("`@(&-A<V4@4$5!4E]%
M4E)/4E]215154DXZ#0H@("`@("`@("`@("!C87-E(%!%05)?15)23U)?4%))
M3E0Z#0H@("`@("`@("`@("!C87-E(%!%05)?15)23U)?5%))1T=%4CH-"B`@
M("`@("`@("`@(&-A<V4@4$5!4E]%4E)/4E]$244Z#0H@("`@("`@("`@("!C
M87-E(&YU;&PZ#0H@("`@("`@("`@("`@("`@)&1E9E]M;V1E(#T@)&UO9&4[
M#0H@("`@("`@("`@("`@("`@)&1E9E]O<'1I;VYS(#T@)&]P=&EO;G,[#0H@
M("`@("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@("`@("`@(&-A<V4@4$5!
M4E]%4E)/4E]#04Q,0D%#2SH-"B`@("`@("`@("`@("`@("`D9&5F7VUO9&4@
M/2`D;6]D93L-"B`@("`@("`@("`@("`@("`O+R!C;&%S<R]O8FIE8W0@;65T
M:&]D(&-A;&QB86-K#0H@("`@("`@("`@("`@("`@:68@*&ES7V-A;&QA8FQE
M*"1O<'1I;VYS*2D@>PT*("`@("`@("`@("`@("`@("`@("`D9&5F7V]P=&EO
M;G,@/2`D;W!T:6]N<SL-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("`@("!T<FEG9V5R7V5R<F]R*")I;G9A;&ED(&5R<F]R
M(&-A;&QB86-K(BP@15]54T527U=!4DY)3D<I.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!B<F5A:SL-"@T*("`@("`@("`@("`@9&5F
M875L=#H-"B`@("`@("`@("`@("`@("!T<FEG9V5R7V5R<F]R*")I;G9A;&ED
M(&5R<F]R(&UO9&4B+"!%7U5315)?5T%23DE.1RD[#0H@("`@("`@("`@("`@
M("`@8G)E86L[#0H@("`@("`@('T-"B`@("`@("`@)'-T86-K6UT@/2!A<G)A
M>2@D;6]D92P@)&]P=&EO;G,I.PT*("`@("`@("!R971U<FX@=')U93L-"B`@
M("!]#0H-"B`@("!F=6YC=&EO;B!S=&%T:6-0;W!%<G)O<DAA;F1L:6YG*"D-
M"B`@("![#0H@("`@("`@("1S=&%C:R`]("8D1TQ/0D%,4ULG7U!%05)?97)R
M;W)?:&%N9&QE<E]S=&%C:R==.PT*("`@("`@("`D<V5T;6]D92`@("`@/2`F
M)$=,3T)!3%-;)U]014%27V1E9F%U;'1?97)R;W)?;6]D92==.PT*("`@("`@
M("`D<V5T;W!T:6]N<R`@/2`F)$=,3T)!3%-;)U]014%27V1E9F%U;'1?97)R
M;W)?;W!T:6]N<R==.PT*("`@("`@("!A<G)A>5]P;W`H)'-T86-K*3L-"B`@
M("`@("`@;&ES="@D;6]D92P@)&]P=&EO;G,I(#T@)'-T86-K6W-I>F5O9B@D
M<W1A8VLI("T@,5T[#0H@("`@("`@(&%R<F%Y7W!O<"@D<W1A8VLI.PT*("`@
M("`@("!S=VET8V@@*"1M;V1E*2![#0H@("`@("`@("`@("!C87-E(%!%05)?
M15)23U)?15A#15!424]..@T*("`@("`@("`@("`@8V%S92!014%27T524D]2
M7U)%5%523CH-"B`@("`@("`@("`@(&-A<V4@4$5!4E]%4E)/4E]04DE.5#H-
M"B`@("`@("`@("`@(&-A<V4@4$5!4E]%4E)/4E]44DE'1T52.@T*("`@("`@
M("`@("`@8V%S92!014%27T524D]27T1)13H-"B`@("`@("`@("`@(&-A<V4@
M;G5L;#H-"B`@("`@("`@("`@("`@("`D<V5T;6]D92`]("1M;V1E.PT*("`@
M("`@("`@("`@("`@("1S971O<'1I;VYS(#T@)&]P=&EO;G,[#0H@("`@("`@
M("`@("`@("`@8G)E86L[#0H-"B`@("`@("`@("`@(&-A<V4@4$5!4E]%4E)/
M4E]#04Q,0D%#2SH-"B`@("`@("`@("`@("`@("`D<V5T;6]D92`]("1M;V1E
M.PT*("`@("`@("`@("`@("`@("\O(&-L87-S+V]B:F5C="!M971H;V0@8V%L
M;&)A8VL-"B`@("`@("`@("`@("`@("!I9B`H:7-?8V%L;&%B;&4H)&]P=&EO
M;G,I*2![#0H@("`@("`@("`@("`@("`@("`@("1S971O<'1I;VYS(#T@)&]P
M=&EO;G,[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@=')I9V=E<E]E<G)O<B@B:6YV86QI9"!E<G)O<B!C86QL8F%C
M:R(L($5?55-%4E]705).24Y'*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@("`@("`@(&1E9F%U;'0Z#0H@
M("`@("`@("`@("`@("`@=')I9V=E<E]E<G)O<B@B:6YV86QI9"!E<G)O<B!M
M;V1E(BP@15]54T527U=!4DY)3D<I.PT*("`@("`@("`@("`@("`@(&)R96%K
M.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*
M("`@("\O('M[>R!P=7-H17)R;W)(86YD;&EN9R@I#0H-"B`@("`O*BH-"B`@
M("`@*B!0=7-H(&$@;F5W(&5R<F]R(&AA;F1L97(@;VX@=&]P(&]F('1H92!E
M<G)O<B!H86YD;&5R(&]P=&EO;G,@<W1A8VLN(%=I=&@@=&AI<PT*("`@("`J
M('EO=2!C86X@96%S:6QY(&]V97)R:61E('1H92!A8W1U86P@97)R;W(@:&%N
M9&QE<B!F;W(@<V]M92!C;V1E(&%N9"!R97-T;W)E#0H@("`@("H@:70@;&%T
M97(@=VET:"!P;W!%<G)O<DAA;F1L:6YG+@T*("`@("`J#0H@("`@("H@0'!A
M<F%M(&UI>&5D("1M;V1E("AS86UE(&%S('-E=$5R<F]R2&%N9&QI;F<I#0H@
M("`@("H@0'!A<F%M(&UI>&5D("1O<'1I;VYS("AS86UE(&%S('-E=$5R<F]R
M2&%N9&QI;F<I#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&)O;VP@06QW87ES
M('1R=64-"B`@("`@*@T*("`@("`J($!S964@4$5!4CHZ<V5T17)R;W)(86YD
M;&EN9PT*("`@("`J+PT*("`@(&9U;F-T:6]N('!U<VA%<G)O<DAA;F1L:6YG
M*"1M;V1E+"`D;W!T:6]N<R`](&YU;&PI#0H@("`@>PT*("`@("`@("`D<W1A
M8VL@/2`F)$=,3T)!3%-;)U]014%27V5R<F]R7VAA;F1L97)?<W1A8VLG73L-
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES*2`F)B!I<U]A*"1T:&ES+"`G4$5!
M4B<I*2![#0H@("`@("`@("`@("`D9&5F7VUO9&4@("`@/2`F)'1H:7,M/E]D
M969A=6QT7V5R<F]R7VUO9&4[#0H@("`@("`@("`@("`D9&5F7V]P=&EO;G,@
M/2`F)'1H:7,M/E]D969A=6QT7V5R<F]R7V]P=&EO;G,[#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`D9&5F7VUO9&4@("`@/2`F)$=,3T)!3%-;
M)U]014%27V1E9F%U;'1?97)R;W)?;6]D92==.PT*("`@("`@("`@("`@)&1E
M9E]O<'1I;VYS(#T@)B1'3$]"04Q36R=?4$5!4E]D969A=6QT7V5R<F]R7V]P
M=&EO;G,G73L-"B`@("`@("`@?0T*("`@("`@("`D<W1A8VM;72`](&%R<F%Y
M*"1D969?;6]D92P@)&1E9E]O<'1I;VYS*3L-"@T*("`@("`@("!I9B`H:7-S
M970H)'1H:7,I("8F(&ES7V$H)'1H:7,L("=014%2)RDI('L-"B`@("`@("`@
M("`@("1T:&ES+3YS971%<G)O<DAA;F1L:6YG*"1M;V1E+"`D;W!T:6]N<RD[
M#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!014%2.CIS971%<G)O
M<DAA;F1L:6YG*"1M;V1E+"`D;W!T:6]N<RD[#0H@("`@("`@('T-"B`@("`@
M("`@)'-T86-K6UT@/2!A<G)A>2@D;6]D92P@)&]P=&EO;G,I.PT*("`@("`@
M("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![
M>WL@<&]P17)R;W)(86YD;&EN9R@I#0H-"B`@("`O*BH-"B`@("`J(%!O<"!T
M:&4@;&%S="!E<G)O<B!H86YD;&5R('5S960-"B`@("`J#0H@("`@*B!`<F5T
M=7)N(&)O;VP@06QW87ES('1R=64-"B`@("`J#0H@("`@*B!`<V5E(%!%05(Z
M.G!U<VA%<G)O<DAA;F1L:6YG#0H@("`@*B\-"B`@("!F=6YC=&EO;B!P;W!%
M<G)O<DAA;F1L:6YG*"D-"B`@("![#0H@("`@("`@("1S=&%C:R`]("8D1TQ/
M0D%,4ULG7U!%05)?97)R;W)?:&%N9&QE<E]S=&%C:R==.PT*("`@("`@("!A
M<G)A>5]P;W`H)'-T86-K*3L-"B`@("`@("`@;&ES="@D;6]D92P@)&]P=&EO
M;G,I(#T@)'-T86-K6W-I>F5O9B@D<W1A8VLI("T@,5T[#0H@("`@("`@(&%R
M<F%Y7W!O<"@D<W1A8VLI.PT*("`@("`@("!I9B`H:7-S970H)'1H:7,I("8F
M(&ES7V$H)'1H:7,L("=014%2)RDI('L-"B`@("`@("`@("`@("1T:&ES+3YS
M971%<G)O<DAA;F1L:6YG*"1M;V1E+"`D;W!T:6]N<RD[#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("!014%2.CIS971%<G)O<DAA;F1L:6YG*"1M
M;V1E+"`D;W!T:6]N<RD[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&QO861%>'1E
M;G-I;VXH*0T*#0H@("`@+RHJ#0H@("`@*B!/4R!I;F1E<&5N9&%N="!02%`@
M97AT96YS:6]N(&QO860N(%)E;65M8F5R('1O('1A:V4@8V%R90T*("`@("H@
M;VX@=&AE(&-O<G)E8W0@97AT96YS:6]N(&YA;64@9F]R(&-A<V4@<V5N<VET
M:79E($]397,N#0H@("`@*@T*("`@("H@0'!A<F%M('-T<FEN9R`D97AT(%1H
M92!E>'1E;G-I;VX@;F%M90T*("`@("H@0')E='5R;B!B;V]L(%-U8V-E<W,@
M;W(@;F]T(&]N('1H92!D;"@I(&-A;&P-"B`@("`J+PT*("`@(&9U;F-T:6]N
M(&QO861%>'1E;G-I;VXH)&5X="D-"B`@("![#0H@("`@("`@(&EF("@A97AT
M96YS:6]N7VQO861E9"@D97AT*2D@>PT*("`@("`@("`@("`@+R\@:68@96ET
M:&5R(')E='5R;G,@=')U92!D;"@I('=I;&P@<')O9'5C92!A($9!5$%,(&5R
M<F]R+"!S=&]P('1H870-"B`@("`@("`@("`@(&EF("@H:6YI7V=E="@G96YA
M8FQE7V1L)RD@(3T@,2D@?'P@*&EN:5]G970H)W-A9F5?;6]D92<I(#T](#$I
M*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@:68@*$]37U=)3D1/5U,I('L-"B`@("`@("`@
M("`@("`@("`D<W5F9FEX(#T@)RYD;&PG.PT*("`@("`@("`@("`@?2!E;'-E
M:68@*%!(4%]/4R`]/2`G2%`M55@G*2![#0H@("`@("`@("`@("`@("`@)'-U
M9F9I>"`]("<N<VPG.PT*("`@("`@("`@("`@?2!E;'-E:68@*%!(4%]/4R`]
M/2`G04E8)RD@>PT*("`@("`@("`@("`@("`@("1S=69F:7@@/2`G+F$G.PT*
M("`@("`@("`@("`@?2!E;'-E:68@*%!(4%]/4R`]/2`G3U-8)RD@>PT*("`@
M("`@("`@("`@("`@("1S=69F:7@@/2`G+F)U;F1L92<[#0H@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1S=69F:7@@/2`G+G-O)SL-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B!`9&PH)W!H<%\G
M+B1E>'0N)'-U9F9I>"D@?'P@0&1L*"1E>'0N)'-U9F9I>"D[#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0I]#0H-"B\O('M[>R!?4$5!4E]C86QL7V1E<W1R=6-T;W)S*"D-"@T*9G5N
M8W1I;VX@7U!%05)?8V%L;%]D97-T<G5C=&]R<R@I#0I[#0H@("`@9VQO8F%L
M("1?4$5!4E]D97-T<G5C=&]R7V]B:F5C=%]L:7-T.PT*("`@(&EF("AI<U]A
M<G)A>2@D7U!%05)?9&5S=')U8W1O<E]O8FIE8W1?;&ES="D@)B8-"B`@("`@
M("`@<VEZ96]F*"1?4$5!4E]D97-T<G5C=&]R7V]B:F5C=%]L:7-T*2D-"B`@
M("![#0H@("`@("`@(')E<V5T*"1?4$5!4E]D97-T<G5C=&]R7V]B:F5C=%]L
M:7-T*3L-"B`@("`@("`@:68@*$!014%2.CIG9713=&%T:6-0<F]P97)T>2@G
M4$5!4B<L("=D97-T<G5C=&QI9F\G*2D@>PT*("`@("`@("`@("`@)%]014%2
M7V1E<W1R=6-T;W)?;V)J96-T7VQI<W0@/2!A<G)A>5]R979E<G-E*"1?4$5!
M4E]D97-T<G5C=&]R7V]B:F5C=%]L:7-T*3L-"B`@("`@("`@?0T*("`@("`@
M("!W:&EL92`H;&ES="@D:RP@)&]B:G)E9BD@/2!E86-H*"1?4$5!4E]D97-T
M<G5C=&]R7V]B:F5C=%]L:7-T*2D@>PT*("`@("`@("`@("`@)&-L87-S;F%M
M92`](&=E=%]C;&%S<R@D;V)J<F5F*3L-"B`@("`@("`@("`@('=H:6QE("@D
M8VQA<W-N86UE*2![#0H@("`@("`@("`@("`@("`@)&1E<W1R=6-T;W(@/2`B
M7R1C;&%S<VYA;64B.PT*("`@("`@("`@("`@("`@(&EF("AM971H;V1?97AI
M<W1S*"1O8FIR968L("1D97-T<G5C=&]R*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`D;V)J<F5F+3XD9&5S=')U8W1O<B@I.PT*("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("`D8VQA<W-N86UE(#T@9V5T7W!A<F5N=%]C;&%S<R@D
M8VQA<W-N86UE*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@+R\@16UP='D@=&AE(&]B:F5C="!L:7-T
M('1O(&5N<W5R92!T:&%T(&1E<W1R=6-T;W)S(&%R90T*("`@("`@("`O+R!N
M;W0@8V%L;&5D(&UO<F4@=&AA;B!O;F-E+@T*("`@("`@("`D7U!%05)?9&5S
M=')U8W1O<E]O8FIE8W1?;&ES="`](&%R<F%Y*"D[#0H@("`@?0T*#0H@("`@
M+R\@3F]W(&-A;&P@=&AE('-H=71D;W=N(&9U;F-T:6]N<PT*("`@(&EF("AI
M<U]A<G)A>2@D1TQ/0D%,4ULG7U!%05)?<VAU=&1O=VY?9G5N8W,G72D@04Y$
M("%E;7!T>2@D1TQ/0D%,4ULG7U!%05)?<VAU=&1O=VY?9G5N8W,G72DI('L-
M"B`@("`@("`@9F]R96%C:"`H)$=,3T)!3%-;)U]014%27W-H=71D;W=N7V9U
M;F-S)UT@87,@)'9A;'5E*2![#0H@("`@("`@("`@("!C86QL7W5S97)?9G5N
M8U]A<G)A>2@D=F%L=65;,%TL("1V86QU95LQ72D[#0H@("`@("`@('T-"B`@
M("!]#0I]#0H-"B\O('U]?0T*+RHJ#0H@*B!3=&%N9&%R9"!014%2(&5R<F]R
M(&-L87-S(&9O<B!02%`@-`T*("H-"B`J(%1H:7,@8VQA<W,@:7,@<W5P<V5R
M<V5D960@8GD@>T!L:6YK(%!%05)?17AC97!T:6]N?2!I;B!02%`@-0T*("H-
M"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J
M($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X-"B`J($!A
M=71H;W(@("`@(%1O;6%S(%8N5BX@0V]X(#QC;WA`:61E8VYE="YC;VT^#0H@
M*B!`875T:&]R("`@("!'<F5G;W)Y($)E879E<B`\8V5L;&]G0'!H<"YN970^
M#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@
M0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q
M+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU
M86PO96XO8V]R92YP96%R+G!E87(M97)R;W(N<&AP#0H@*B!`<V5E("`@("`@
M("!014%2.CIR86ES945R<F]R*"DL(%!%05(Z.G1H<F]W17)R;W(H*0T*("H@
M0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%!(4"`T+C`N,@T*
M("HO#0IC;&%S<R!014%27T5R<F]R#0I[#0H@("`@+R\@>WM[('!R;W!E<G1I
M97,-"@T*("`@('9A<B`D97)R;W)?;65S<V%G95]P<F5F:7@@/2`G)SL-"B`@
M("!V87(@)&UO9&4@("`@("`@("`@("`@("`@(#T@4$5!4E]%4E)/4E]21515
M4DX[#0H@("`@=F%R("1L979E;"`@("`@("`@("`@("`@("`]($5?55-%4E].
M3U1)0T4[#0H@("`@=F%R("1C;V1E("`@("`@("`@("`@("`@("`]("TQ.PT*
M("`@('9A<B`D;65S<V%G92`@("`@("`@("`@("`@/2`G)SL-"B`@("!V87(@
M)'5S97)I;F9O("`@("`@("`@("`@(#T@)R<[#0H@("`@=F%R("1B86-K=')A
M8V4@("`@("`@("`@("`](&YU;&P[#0H-"B`@("`O+R!]?7T-"B`@("`O+R![
M>WL@8V]N<W1R=6-T;W(-"@T*("`@("\J*@T*("`@("`J(%!%05)?17)R;W(@
M8V]N<W1R=6-T;W(-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@)&UE
M<W-A9V4@(&UE<W-A9V4-"B`@("`@*@T*("`@("`J($!P87)A;2!I;G0@)&-O
M9&4@("`@("AO<'1I;VYA;"D@97)R;W(@8V]D90T*("`@("`J#0H@("`@("H@
M0'!A<F%M(&EN="`D;6]D92`@("`@*&]P=&EO;F%L*2!E<G)O<B!M;V1E+"!O
M;F4@;V8Z(%!%05)?15)23U)?4D5455).+`T*("`@("`J(%!%05)?15)23U)?
M4%))3E0L(%!%05)?15)23U)?1$E%+"!014%27T524D]27U1224='15(L#0H@
M("`@("H@4$5!4E]%4E)/4E]#04Q,0D%#2R!O<B!014%27T524D]27T580T50
M5$E/3@T*("`@("`J#0H@("`@("H@0'!A<F%M(&UI>&5D("1O<'1I;VYS("`@
M*&]P=&EO;F%L*2!E<G)O<B!L979E;"P@7T]27R!I;B!T:&4@8V%S92!O9@T*
M("`@("`J(%!%05)?15)23U)?0T%,3$)!0TLL('1H92!C86QL8F%C:R!F=6YC
M=&EO;B!O<B!O8FIE8W0O;65T:&]D#0H@("`@("H@='5P;&4N#0H@("`@("H-
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R:6YF;R`H;W!T:6]N86PI(&%D
M9&ET:6]N86P@=7-E<B]D96)U9R!I;F9O#0H@("`@("H-"B`@("`@*B!`86-C
M97-S('!U8FQI8PT*("`@("`J#0H@("`@("HO#0H@("`@9G5N8W1I;VX@4$5!
M4E]%<G)O<B@D;65S<V%G92`]("=U;FMN;W=N(&5R<F]R)RP@)&-O9&4@/2!N
M=6QL+`T*("`@("`@("`@("`@("`@("`@("`@("`@)&UO9&4@/2!N=6QL+"`D
M;W!T:6]N<R`](&YU;&PL("1U<V5R:6YF;R`](&YU;&PI#0H@("`@>PT*("`@
M("`@("!I9B`H)&UO9&4@/3T](&YU;&PI('L-"B`@("`@("`@("`@("1M;V1E
M(#T@4$5!4E]%4E)/4E]215154DX[#0H@("`@("`@('T-"B`@("`@("`@)'1H
M:7,M/FUE<W-A9V4@("`]("1M97-S86=E.PT*("`@("`@("`D=&AI<RT^8V]D
M92`@("`@(#T@)&-O9&4[#0H@("`@("`@("1T:&ES+3YM;V1E("`@("`@/2`D
M;6]D93L-"B`@("`@("`@)'1H:7,M/G5S97)I;F9O("`]("1U<V5R:6YF;SL-
M"B`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@B9&5B=6=?8F%C:W1R86-E
M(BDI('L-"B`@("`@("`@("`@(&EF("A`(5!%05(Z.F=E=%-T871I8U!R;W!E
M<G1Y*"=014%27T5R<F]R)RP@)W-K:7!T<F%C92<I*2![#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/F)A8VMT<F%C92`](&1E8G5G7V)A8VMT<F%C92@I.PT*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@D;6]D92`F
M(%!%05)?15)23U)?0T%,3$)!0TLI('L-"B`@("`@("`@("`@("1T:&ES+3YL
M979E;"`]($5?55-%4E].3U1)0T4[#0H@("`@("`@("`@("`D=&AI<RT^8V%L
M;&)A8VL@/2`D;W!T:6]N<SL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@(&EF("@D;W!T:6]N<R`]/3T@;G5L;"D@>PT*("`@("`@("`@("`@("`@
M("1O<'1I;VYS(#T@15]54T527TY/5$E#13L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("1T:&ES+3YL979E;"`]("1O<'1I;VYS.PT*("`@("`@("`@
M("`@)'1H:7,M/F-A;&QB86-K(#T@;G5L;#L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H)'1H:7,M/FUO9&4@)B!014%27T524D]27U!224Y4*2![#0H@("`@
M("`@("`@("!I9B`H:7-?;G5L;"@D;W!T:6]N<RD@?'P@:7-?:6YT*"1O<'1I
M;VYS*2D@>PT*("`@("`@("`@("`@("`@("1F;W)M870@/2`B)7,B.PT*("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D9F]R;6%T(#T@
M)&]P=&EO;G,[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!P<FEN=&8H
M)&9O<FUA="P@)'1H:7,M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"1T:&ES+3YM;V1E("8@4$5!4E]%4E)/4E]44DE'1T52*2![
M#0H@("`@("`@("`@("!T<FEG9V5R7V5R<F]R*"1T:&ES+3YG971-97-S86=E
M*"DL("1T:&ES+3YL979E;"D[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1T
M:&ES+3YM;V1E("8@4$5!4E]%4E)/4E]$244I('L-"B`@("`@("`@("`@("1M
M<V<@/2`D=&AI<RT^9V5T365S<V%G92@I.PT*("`@("`@("`@("`@:68@*&ES
M7VYU;&PH)&]P=&EO;G,I('Q\(&ES7VEN="@D;W!T:6]N<RDI('L-"B`@("`@
M("`@("`@("`@("`D9F]R;6%T(#T@(B5S(CL-"B`@("`@("`@("`@("`@("!I
M9B`H<W5B<W1R*"1M<V<L("TQ*2`A/2`B7&XB*2![#0H@("`@("`@("`@("`@
M("`@("`@("1M<V<@+CT@(EQN(CL-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1F;W)M870@/2`D
M;W!T:6]N<SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&1I92AS<')I
M;G1F*"1F;W)M870L("1M<V<I*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M)'1H:7,M/FUO9&4@)B!014%27T524D]27T-!3$Q"04-+*2![#0H@("`@("`@
M("`@("!I9B`H:7-?8V%L;&%B;&4H)'1H:7,M/F-A;&QB86-K*2D@>PT*("`@
M("`@("`@("`@("`@(&-A;&Q?=7-E<E]F=6YC*"1T:&ES+3YC86QL8F%C:RP@
M)'1H:7,I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF
M("@D=&AI<RT^;6]D92`F(%!%05)?15)23U)?15A#15!424].*2![#0H@("`@
M("`@("`@("!T<FEG9V5R7V5R<F]R*")014%27T524D]27T580T505$E/3B!I
M<R!O8G-O;&5T92P@=7-E(&-L87-S(%!%05)?17AC97!T:6]N(&9O<B!E>&-E
M<'1I;VYS(BP@15]54T527U=!4DY)3D<I.PT*("`@("`@("`@("`@979A;"@G
M)&4@/2!N97<@17AC97!T:6]N*"1T:&ES+3YM97-S86=E+"`D=&AI<RT^8V]D
M92D[=&AR;W<H)&4I.R<I.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+R\@
M?7U]#0H@("`@+R\@>WM[(&=E=$UO9&4H*0T*#0H@("`@+RHJ#0H@("`@("H@
M1V5T('1H92!E<G)O<B!M;V1E(&9R;VT@86X@97)R;W(@;V)J96-T+@T*("`@
M("`J#0H@("`@("H@0')E='5R;B!I;G0@97)R;W(@;6]D90T*("`@("`J($!A
M8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T36]D92@I
M('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3YM;V1E.PT*("`@('T-"@T*("`@
M("\O('U]?0T*("`@("\O('M[>R!G971#86QL8F%C:R@I#0H-"B`@("`O*BH-
M"B`@("`@*B!'970@=&AE(&-A;&QB86-K(&9U;F-T:6]N+VUE=&AO9"!F<F]M
M(&%N(&5R<F]R(&]B:F5C="X-"B`@("`@*@T*("`@("`J($!R971U<FX@;6EX
M960@8V%L;&)A8VL@9G5N8W1I;VX@;W(@;V)J96-T+VUE=&AO9"!A<G)A>0T*
M("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M9V5T0V%L;&)A8VLH*2![#0H@("`@("`@(')E='5R;B`D=&AI<RT^8V%L;&)A
M8VL[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&=E=$UE<W-A
M9V4H*0T*#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE(&5R<F]R(&UE<W-A
M9V4@9G)O;2!A;B!E<G)O<B!O8FIE8W0N#0H@("`@("H-"B`@("`@*B!`<F5T
M=7)N("!S=')I;F<@(&9U;&P@97)R;W(@;65S<V%G90T*("`@("`J($!A8V-E
M<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T365S<V%G92@I
M#0H@("`@>PT*("`@("`@("!R971U<FX@*"1T:&ES+3YE<G)O<E]M97-S86=E
M7W!R969I>"`N("1T:&ES+3YM97-S86=E*3L-"B`@("!]#0H-"@T*("`@("\O
M('U]?0T*("`@("\O('M[>R!G971#;V1E*"D-"@T*("`@("\J*@T*("`@("`J
M($=E="!E<G)O<B!C;V1E(&9R;VT@86X@97)R;W(@;V)J96-T#0H@("`@("H-
M"B`@("`@*B!`<F5T=7)N(&EN="!E<G)O<B!C;V1E#0H@("`@("H@0&%C8V5S
M<R!P=6)L:6,-"B`@("`@*B\-"B`@("`@9G5N8W1I;VX@9V5T0V]D92@I#0H@
M("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3YC;V1E.PT*("`@("!]#0H-
M"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T5'EP92@I#0H-"B`@("`O*BH-
M"B`@("`@*B!'970@=&AE(&YA;64@;V8@=&AI<R!E<G)O<B]E>&-E<'1I;VXN
M#0H@("`@("H-"B`@("`@*B!`<F5T=7)N('-T<FEN9R!E<G)O<B]E>&-E<'1I
M;VX@;F%M92`H='EP92D-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J
M+PT*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0T*("`@('L-"B`@("`@("`@<F5T
M=7)N(&=E=%]C;&%S<R@D=&AI<RD[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[(&=E=%5S97));F9O*"D-"@T*("`@("\J*@T*("`@("`J($=E
M="!A9&1I=&EO;F%L('5S97(M<W5P<&QI960@:6YF;W)M871I;VXN#0H@("`@
M("H-"B`@("`@*B!`<F5T=7)N('-T<FEN9R!U<V5R+7-U<'!L:65D(&EN9F]R
M;6%T:6]N#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!G9715<V5R26YF;R@I#0H@("`@>PT*("`@("`@("!R971U<FX@
M)'1H:7,M/G5S97)I;F9O.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O
M('M[>R!G971$96)U9TEN9F\H*0T*#0H@("`@+RHJ#0H@("`@("H@1V5T(&%D
M9&ET:6]N86P@9&5B=6<@:6YF;W)M871I;VX@<W5P<&QI960@8GD@=&AE(&%P
M<&QI8V%T:6]N+@T*("`@("`J#0H@("`@("H@0')E='5R;B!S=')I;F<@9&5B
M=6<@:6YF;W)M871I;VX-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J
M+PT*("`@(&9U;F-T:6]N(&=E=$1E8G5G26YF;R@I#0H@("`@>PT*("`@("`@
M("!R971U<FX@)'1H:7,M/F=E=%5S97));F9O*"D[#0H@("`@?0T*#0H@("`@
M+R\@?7U]#0H@("`@+R\@>WM[(&=E=$)A8VMT<F%C92@I#0H-"B`@("`O*BH-
M"B`@("`@*B!'970@=&AE(&-A;&P@8F%C:W1R86-E(&9R;VT@=VAE<F4@=&AE
M(&5R<F]R('=A<R!G96YE<F%T960N#0H@("`@("H@4W5P<&]R=&5D('=I=&@@
M4$A0(#0N,RXP(&]R(&YE=V5R+@T*("`@("`J#0H@("`@("H@0'!A<F%M(&EN
M="`D9G)A;64@*&]P=&EO;F%L*2!W:&%T(&9R86UE('1O(&9E=&-H#0H@("`@
M("H@0')E='5R;B!A<G)A>2!"86-K=')A8V4L(&]R($Y53$P@:68@;F]T(&%V
M86EL86)L92X-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@
M(&9U;F-T:6]N(&=E=$)A8VMT<F%C92@D9G)A;64@/2!N=6QL*0T*("`@('L-
M"B`@("`@("`@:68@*&1E9FEN960H)U!%05)?24=.3U)%7T)!0TM44D%#12<I
M*2![#0H@("`@("`@("`@("!R971U<FX@;G5L;#L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H)&9R86UE(#T]/2!N=6QL*2![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/F)A8VMT<F%C93L-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@)'1H:7,M/F)A8VMT<F%C95LD9G)A;65=.PT*("`@('T-"@T*("`@("\O
M('U]?0T*("`@("\O('M[>R!A9&15<V5R26YF;R@I#0H-"B`@("!F=6YC=&EO
M;B!A9&15<V5R26YF;R@D:6YF;RD-"B`@("![#0H@("`@("`@(&EF("AE;7!T
M>2@D=&AI<RT^=7-E<FEN9F\I*2![#0H@("`@("`@("`@("`D=&AI<RT^=7-E
M<FEN9F\@/2`D:6YF;SL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("1T:&ES+3YU<V5R:6YF;R`N/2`B("HJ("1I;F9O(CL-"B`@("`@("`@?0T*
M("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!T;U-T<FEN9R@I#0H-
M"B`@("`O*BH-"B`@("`@*B!-86ME(&$@<W1R:6YG(')E<')E<V5N=&%T:6]N
M(&]F('1H:7,@;V)J96-T+@T*("`@("`J#0H@("`@("H@0')E='5R;B!S=')I
M;F<@82!S=')I;F<@=VET:"!A;B!O8FIE8W0@<W5M;6%R>0T*("`@("`J($!A
M8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=&]3=')I;F<H
M*2![#0H@("`@("`@("1M;V1E<R`](&%R<F%Y*"D[#0H@("`@("`@("1L979E
M;',@/2!A<G)A>2A%7U5315)?3D]424-%("`]/B`G;F]T:6-E)RP-"B`@("`@
M("`@("`@("`@("`@("`@("`@($5?55-%4E]705).24Y'(#T^("=W87)N:6YG
M)RP-"B`@("`@("`@("`@("`@("`@("`@("`@($5?55-%4E]%4E)/4B`@(#T^
M("=E<G)O<B<I.PT*("`@("`@("!I9B`H)'1H:7,M/FUO9&4@)B!014%27T52
M4D]27T-!3$Q"04-+*2![#0H@("`@("`@("`@("!I9B`H:7-?87)R87DH)'1H
M:7,M/F-A;&QB86-K*2D@>PT*("`@("`@("`@("`@("`@("1C86QL8F%C:R`]
M("AI<U]O8FIE8W0H)'1H:7,M/F-A;&QB86-K6S!=*2`_#0H@("`@("`@("`@
M("`@("`@("`@('-T<G1O;&]W97(H9V5T7V-L87-S*"1T:&ES+3YC86QL8F%C
M:ULP72DI(#H-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-A;&QB86-K
M6S!=*2`N("<Z.B<@+@T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8V%L
M;&)A8VM;,5T[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("1C86QL8F%C:R`]("1T:&ES+3YC86QL8F%C:SL-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(')E='5R;B!S<')I;G1F*"=;)7,Z(&UE<W-A9V4]
M(B5S(B!C;V1E/25D(&UO9&4]8V%L;&)A8VL@)RX-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=C86QL8F%C:STE<R!P<F5F:7@](B5S(B!I;F9O/2(E
M<R)=)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@('-T<G1O;&]W97(H
M9V5T7V-L87-S*"1T:&ES*2DL("1T:&ES+3YM97-S86=E+"`D=&AI<RT^8V]D
M92P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1C86QL8F%C:RP@)'1H
M:7,M/F5R<F]R7VUE<W-A9V5?<')E9FEX+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/G5S97)I;F9O*3L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H)'1H:7,M/FUO9&4@)B!014%27T524D]27U!224Y4*2![#0H@("`@
M("`@("`@("`D;6]D97-;72`]("=P<FEN="<[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*"1T:&ES+3YM;V1E("8@4$5!4E]%4E)/4E]44DE'1T52*2![#0H@
M("`@("`@("`@("`D;6]D97-;72`]("=T<FEG9V5R)SL-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H)'1H:7,M/FUO9&4@)B!014%27T524D]27T1)12D@>PT*
M("`@("`@("`@("`@)&UO9&5S6UT@/2`G9&EE)SL-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H)'1H:7,M/FUO9&4@)B!014%27T524D]27U)%5%523BD@>PT*
M("`@("`@("`@("`@)&UO9&5S6UT@/2`G<F5T=7)N)SL-"B`@("`@("`@?0T*
M("`@("`@("!R971U<FX@<W!R:6YT9B@G6R5S.B!M97-S86=E/2(E<R(@8V]D
M93TE9"!M;V1E/25S(&QE=F5L/25S("<N#0H@("`@("`@("`@("`@("`@("`@
M("`@("=P<F5F:7@](B5S(B!I;F9O/2(E<R)=)RP-"B`@("`@("`@("`@("`@
M("`@("`@("`@<W1R=&]L;W=E<BAG971?8VQA<W,H)'1H:7,I*2P@)'1H:7,M
M/FUE<W-A9V4L("1T:&ES+3YC;V1E+`T*("`@("`@("`@("`@("`@("`@("`@
M("!I;7!L;V1E*")\(BP@)&UO9&5S*2P@)&QE=F5L<ULD=&AI<RT^;&5V96Q=
M+`T*("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^97)R;W)?;65S<V%G
M95]P<F5F:7@L#0H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU<V5R
M:6YF;RD[#0H@("`@?0T*#0H@("`@+R\@?7U]#0I]#0H-"B\J#0H@*B!,;V-A
M;"!687)I86)L97,Z#0H@*B!M;V1E.B!P:'`-"B`J('1A8BUW:61T:#H@-`T*
M("H@8RUB87-I8RUO9F9S970Z(#0-"B`J($5N9#H-"B`J+PT*/SX-"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+T1A=&4N<&AP````````````````````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`Q,3,P,#`@,3`U,34T,S,W,S,@,#(P,#0W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O
M9G1T86)S=&]P/30Z("HO"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`U($)A8F$@0G5E:&QE
M<BP@4&EE<G)E+4%L86EN($IO>64@("`@("`@("`@("`@('P*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I
M<R!S=6)J96-T('1O('1H92!.97<@0E-$(&QI8V5N<V4L(%1H870@:7,@8G5N
M9&QE9"`@?`HO+R!\('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)
M0T5.4T4L(&%N9"!I<R!A=F%I;&%B;&4@=&AR;W5G:"`@("`@('P*+R\@?"!T
M:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYO<&5N
M<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@("`@("`@("`@
M("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y
M(&]F('1H92!N97<@0E-$;&EC96YS92!A;F0@87)E('5N86)L92`@('P*+R\@
M?"!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L
M96%S92!S96YD(&$@;F]T92!T;R`@("`@("!\"B\O('P@<&5A<BUD979`;&ES
M=',N<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+B`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\@?"!!=71H;W(Z($)A8F$@0G5E:&QE<B`\8F%B84!B86)A>BYC;VT^("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("!0
M:65R<F4M06QA:6X@2F]Y92`\<&%J;WEE0'!H<"YN970^("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*"B\J*@H@*B!'96YE<FEC(&1A=&4@:&%N9&QI;F<@8VQA<W,@9F]R(%!%
M05(*("H*("H@1V5N97)I8R!D871E(&AA;F1L:6YG(&-L87-S(&9O<B!014%2
M+B`@071T96UP=',@=&\@8F4@=&EM92!Z;VYE(&%W87)E"B`J('1H<F]U9V@@
M=&AE($1A=&4Z.E1I;65:;VYE(&-L87-S+B`@4W5P<&]R=',@<V5V97)A;"!O
M<&5R871I;VYS(&9R;VT*("H@1&%T93HZ0V%L8R!O;B!$871E(&]B:F5C=',N
M"B`J"B`J($!C871E9V]R>2`@($1A=&4@86YD(%1I;64*("H@0'!A8VMA9V4@
M("`@1&%T90H@*B!`875T:&]R("`@("!"86)A($)U96AL97(@/&)A8F%`8F%B
M87HN8V]M/@H@*B!`875T:&]R("`@("!0:65R<F4M06QA:6X@2F]Y92`\<&%J
M;WEE0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0
M($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO
M<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!.97<@0E-$($QI8V5N<V4*
M("H@0'9E<G-I;VX@("`@0U93.B`D260Z($1A=&4N<&AP+'8@,2XS-2`R,#`U
M+S$Q+S$U(#`P.C$V.C,X('!A:F]Y92!%>'`@)`H@*B!`;&EN:R`@("`@("!H
M='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1&%T90H@*B\*"B\J*D`C*PH@
M*B!);F-L=61E('-U<'!O<G1I;F<@8VQA<W-E<PH@*B\*<F5Q=6ER95]O;F-E
M("=$871E+U1I;65:;VYE+G!H<"<["G)E<75I<F5?;VYC92`G1&%T92]#86QC
M+G!H<"<["G)E<75I<F5?;VYC92`G1&%T92]3<&%N+G!H<"<["B\J*D`C+2HO
M"@HO*BI`(RL*("H@3W5T<'5T(&9O<FUA=',N("!087-S('1H:7,@=&\@9V5T
M1&%T92@I+@H@*B\*+RHJ"B`J(")965E9+4U-+41$($A(.DU-.E-3(@H@*B\*
M9&5F:6YE*"=$051%7T9/4DU!5%])4T\G+"`Q*3L*+RHJ"B`J(")965E934U3
M4U1(2$U-4U,H6GPH*R\M*4A(34TI/R(*("HO"F1E9FEN92@G1$%415]&3U)-
M051?25-/7T)!4TE#)RP@,BD["B\J*@H@*B`B65E962U-32U34U1(2#I-33I3
M4RA:?"@K+RTI2$@Z34TI/R(*("HO"F1E9FEN92@G1$%415]&3U)-051?25-/
M7T585$5.1$5$)RP@,RD["B\J*@H@*B`B65E962U-32U34U1(2#I-33I34R@N
M4RHI/RA:?"@K+RTI2$@Z34TI/R(*("HO"F1E9FEN92@G1$%415]&3U)-051?
M25-/7T585$5.1$5$7TU)0U)/5$E-12<L(#8I.PHO*BH*("H@(EE965E-341$
M2$A-35-3(@H@*B\*9&5F:6YE*"=$051%7T9/4DU!5%]424U%4U1!35`G+"`T
M*3L*+RHJ"B`J(&QO;F<@:6YT+"!S96-O;F1S('-I;F-E('1H92!U;FEX(&5P
M;V-H"B`J+PID969I;F4H)T1!5$5?1D]234%47U5.25A424U%)RP@-2D["B\J
M*D`C+2HO"@HO*BH*("H@1V5N97)I8R!D871E(&AA;F1L:6YG(&-L87-S(&9O
M<B!014%2"B`J"B`J($=E;F5R:6,@9&%T92!H86YD;&EN9R!C;&%S<R!F;W(@
M4$5!4BX@($%T=&5M<'1S('1O(&)E('1I;64@>F]N92!A=V%R90H@*B!T:')O
M=6=H('1H92!$871E.CI4:6UE6F]N92!C;&%S<RX@(%-U<'!O<G1S('-E=F5R
M86P@;W!E<F%T:6]N<R!F<F]M"B`J($1A=&4Z.D-A;&,@;VX@1&%T92!O8FIE
M8W1S+@H@*@H@*B!`875T:&]R("`@("!"86)A($)U96AL97(@/&)A8F%`8F%B
M87HN8V]M/@H@*B!`875T:&]R("`@("!0:65R<F4M06QA:6X@2F]Y92`\<&%J
M;WEE0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0
M($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO
M<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!.97<@0E-$($QI8V5N<V4*
M("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+C8*("H@0&QI;FL@("`@("`@
M:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1A=&4*("HO"F-L87-S($1A
M=&4*>PH@("`@+RHJ"B`@("`@*B!T:&4@>65A<@H@("`@("H@0'9A<B!I;G0*
M("`@("`J+PH@("`@=F%R("1Y96%R.PH@("`@+RHJ"B`@("`@*B!T:&4@;6]N
M=&@*("`@("`J($!V87(@:6YT"B`@("`@*B\*("`@('9A<B`D;6]N=&@["B`@
M("`O*BH*("`@("`J('1H92!D87D*("`@("`J($!V87(@:6YT"B`@("`@*B\*
M("`@('9A<B`D9&%Y.PH@("`@+RHJ"B`@("`@*B!T:&4@:&]U<@H@("`@("H@
M0'9A<B!I;G0*("`@("`J+PH@("`@=F%R("1H;W5R.PH@("`@+RHJ"B`@("`@
M*B!T:&4@;6EN=71E"B`@("`@*B!`=F%R(&EN=`H@("`@("HO"B`@("!V87(@
M)&UI;G5T93L*("`@("\J*@H@("`@("H@=&AE('-E8V]N9`H@("`@("H@0'9A
M<B!I;G0*("`@("`J+PH@("`@=F%R("1S96-O;F0["B`@("`O*BH*("`@("`J
M('1H92!P87)T<R!O9B!A('-E8V]N9`H@("`@("H@0'9A<B!F;&]A=`H@("`@
M("HO"B`@("!V87(@)'!A<G1S96-O;F0["@H@("`@+RHJ"B`@("`@*B!T:6UE
M>F]N92!F;W(@=&AI<R!D871E"B`@("`@*B!`=F%R(&]B:F5C="!$871E7U1I
M;65:;VYE"B`@("`@*B\*("`@('9A<B`D='H["@H@("`@+RHJ"B`@("`@*B!D
M969I;F4@=&AE(&1E9F%U;'0@=V5E:V1A>2!A8F)R979I871I;VX@;&5N9W1H
M"B`@("`@*B!U<V5D(&)Y(#HZ9F]R;6%T*"D*("`@("`J($!V87(@:6YT"B`@
M("`@*B\*("`@('9A<B`D9V5T5V5E:V1A>4%B8G)N86UE3&5N9W1H(#T@,SL*
M"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("H*("`@("`J($-R
M96%T97,@82!N97<@1&%T92!/8FIE8W0@:6YI=&EA;&EZ960@=&\@=&AE(&-U
M<G)E;G0@9&%T92]T:6UE(&EN('1H90H@("`@("H@<WES=&5M+61E9F%U;'0@
M=&EM97IO;F4@8GD@9&5F875L="X@($$@9&%T92!O<'1I;VYA;&QY"B`@("`@
M*B!P87-S960@:6X@;6%Y(&)E(&EN('1H92!)4T\@.#8P,2P@5$E-15-404U0
M(&]R(%5.25A424U%(&9O<FUA="P*("`@("`J(&]R(&%N;W1H97(@1&%T92!O
M8FIE8W0N("!)9B!N;R!D871E(&ES('!A<W-E9"P@=&AE(&-U<G)E;G0@9&%T
M92]T:6UE"B`@("`@*B!I<R!U<V5D+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B!`<V5E('-E=$1A=&4H*0H@("`@("H@0'!A<F%M(&UI
M>&5D("1D871E(&]P=&EO;F%L("T@9&%T92]T:6UE('1O(&EN:71I86QI>F4*
M("`@("`J($!R971U<FX@;V)J96-T($1A=&4@=&AE(&YE=R!$871E(&]B:F5C
M=`H@("`@("HO"B`@("!F=6YC=&EO;B!$871E*"1D871E(#T@;G5L;"D*("`@
M('L*("`@("`@("`D=&AI<RT^='H@/2!$871E7U1I;65:;VYE.CIG971$969A
M=6QT*"D["B`@("`@("`@:68@*&ES7VYU;&PH)&1A=&4I*2!["B`@("`@("`@
M("`@("1T:&ES+3YS971$871E*&1A=&4H(EDM;2UD($@Z:3IS(BDI.PH@("`@
M("`@('T@96QS96EF("AI<U]A*"1D871E+"`G1&%T92<I*2!["B`@("`@("`@
M("`@("1T:&ES+3YC;W!Y*"1D871E*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=&AI<RT^<V5T1&%T92@D9&%T92D["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@4V5T('1H92!F:65L9',@;V8@82!$871E(&]B
M:F5C="!B87-E9"!O;B!T:&4@:6YP=70@9&%T92!A;F0@9F]R;6%T"B`@("`@
M*@H@("`@("H@4V5T('1H92!F:65L9',@;V8@82!$871E(&]B:F5C="!B87-E
M9"!O;B!T:&4@:6YP=70@9&%T92!A;F0@9F]R;6%T+`H@("`@("H@=VAI8V@@
M:7,@<W!E8VEF:65D(&)Y('1H92!$051%7T9/4DU!5%\J(&-O;G-T86YT<RX*
M("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M('-T
M<FEN9R`D9&%T92!I;G!U="!D871E"B`@("`@*B!`<&%R86T@:6YT("1F;W)M
M870@3W!T:6]N86P@9F]R;6%T(&-O;G-T86YT("A$051%7T9/4DU!5%\J*2!O
M9B!T:&4@:6YP=70@9&%T92X*("`@("`J("`@("`@("`@("`@("`@("`@("!4
M:&ES('!A<F%M971E<B!I<VXG="!R96%L;'D@;F5E9&5D(&%N>6UO<F4L(&)U
M="!Y;W4@8V]U;&0*("`@("`J("`@("`@("`@("`@("`@("`@("!U<V4@:70@
M=&\@9F]R8V4@1$%415]&3U)-051?54Y)6%1)344N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-E=$1A=&4H)&1A=&4L("1F;W)M870@/2!$051%7T9/4DU!5%])
M4T\I"B`@("!["@H@("`@("`@(&EF("@*("`@("`@("`@("`@<')E9U]M871C
M:"@G+UXH7&1[-'TI+3\H7&1[,GTI+3\H7&1[,GTI*%M47'-=/RA<9'LR?2DZ
M/RA<9'LR?2DZ/RA<9'LR?2DH7"Y<9"LI/RA:?%M<*UPM75QD>S)].C]<9'LR
M?2D_*3\D+VDG+"`D9&%T92P@)')E9W,I"B`@("`@("`@("`@("8F("1F;W)M
M870@(3T@1$%415]&3U)-051?54Y)6%1)344I('L*("`@("`@("`@("`@+R\@
M1$%415]&3U)-051?25-/+"!)4T]?0D%324,L($E33U]%6%1%3D1%1"P@86YD
M(%1)34535$%-4`H@("`@("`@("`@("`O+R!4:&5S92!F;W)M871S(&%R92!E
M>'1R96UE;'D@8VQO<V4@=&\@96%C:"!O=&AE<BX@(%1H:7,@<F5G97@*("`@
M("`@("`@("`@+R\@:7,@=F5R>2!L;V]S92!A;F0@86-C97!T<R!A;&UO<W0@
M86YY(&)U=&-H97)E9"!F;W)M870@>6]U(&-O=6QD"B`@("`@("`@("`@("\O
M('1H<F]W(&%T(&ET+B`@92YG+B`R,#`S+3$P+3`W(#$Y.C0U.C$U(&%N9"`R
M,#`S+3$P,#<Q.30U.C$U"B`@("`@("`@("`@("\O(&%R92!T:&4@<V%M92!T
M:&EN9R!I;B!T:&4@97EE<R!O9B!T:&ES(')E9V5X+"!E=F5N('1H;W5G:"!T
M:&4*("`@("`@("`@("`@+R\@;&%T=&5R(&ES(&YO="!A('9A;&ED($E33R`X
M-C`Q(&1A=&4N"B`@("`@("`@("`@("1T:&ES+3YY96%R("`@("`@(#T@)')E
M9W-;,5T["B`@("`@("`@("`@("1T:&ES+3YM;VYT:"`@("`@(#T@)')E9W-;
M,ET["B`@("`@("`@("`@("1T:&ES+3YD87D@("`@("`@(#T@)')E9W-;,UT[
M"B`@("`@("`@("`@("1T:&ES+3YH;W5R("`@("`@(#T@:7-S970H)')E9W-;
M-5TI/R1R96=S6S5=.C`["B`@("`@("`@("`@("1T:&ES+3YM:6YU=&4@("`@
M(#T@:7-S970H)')E9W-;-ETI/R1R96=S6S9=.C`["B`@("`@("`@("`@("1T
M:&ES+3YS96-O;F0@("`@(#T@:7-S970H)')E9W-;-UTI/R1R96=S6S==.C`[
M"B`@("`@("`@("`@("1T:&ES+3YP87)T<V5C;VYD(#T@:7-S970H)')E9W-;
M.%TI/RAF;&]A="DD<F5G<ULX73HH9FQO870I,#L*"B`@("`@("`@("`@("\O
M(&EF(&%N(&]F9G-E="!I<R!D969I;F5D+"!C;VYV97)T('1I;64@=&\@551#
M"B`@("`@("`@("`@("\O($1A=&4@8W5R<F5N=&QY(&-A;B=T('-E="!A('1I
M;65Z;VYE(&]N;'D@8GD@;V9F<V5T+`H@("`@("`@("`@("`O+R!S;R!I="!H
M87,@=&\@<W1O<F4@:70@87,@551#"B`@("`@("`@("`@(&EF("AI<W-E="@D
M<F5G<ULY72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3YT;U540V)Y3V9F
M<V5T*"1R96=S6SE=*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS96EF
M("AI<U]N=6UE<FEC*"1D871E*2D@>PH@("`@("`@("`@("`O+R!53DE85$E-
M10H@("`@("`@("`@("`D=&AI<RT^<V5T1&%T92AD871E*")9+6TM9"!(.FDZ
M<R(L("1D871E*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@
M=6YK;F]W;B!F;W)M870*("`@("`@("`@("`@)'1H:7,M/GEE87(@("`@("`@
M/2`P.PH@("`@("`@("`@("`D=&AI<RT^;6]N=&@@("`@("`](#$["B`@("`@
M("`@("`@("1T:&ES+3YD87D@("`@("`@(#T@,3L*("`@("`@("`@("`@)'1H
M:7,M/FAO=7(@("`@("`@/2`P.PH@("`@("`@("`@("`D=&AI<RT^;6EN=71E
M("`@("`](#`["B`@("`@("`@("`@("1T:&ES+3YS96-O;F0@("`@(#T@,#L*
M("`@("`@("`@("`@)'1H:7,M/G!A<G1S96-O;F0@/2`H9FQO870I,#L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!S=')I;F<@*&]R
M(&]T:&5R*2!R97!R97-E;G1A=&EO;B!O9B!T:&ES(&1A=&4*("`@("`J"B`@
M("`@*B!'970@82!S=')I;F<@*&]R(&]T:&5R*2!R97!R97-E;G1A=&EO;B!O
M9B!T:&ES(&1A=&4@:6X@=&AE"B`@("`@*B!F;W)M870@<W!E8VEF:65D(&)Y
M('1H92!$051%7T9/4DU!5%\J(&-O;G-T86YT<RX*("`@("`J"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M(&EN="`D9F]R;6%T(&9O<FUA
M="!C;VYS=&%N="`H1$%415]&3U)-051?*BD@;V8@=&AE(&]U='!U="!D871E
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R!T:&4@9&%T92!I;B!T:&4@<F5Q=65S
M=&5D(&9O<FUA=`H@("`@("HO"B`@("!F=6YC=&EO;B!G971$871E*"1F;W)M
M870@/2!$051%7T9/4DU!5%])4T\I"B`@("!["B`@("`@("`@<W=I=&-H("@D
M9F]R;6%T*2!["B`@("`@("`@8V%S92!$051%7T9/4DU!5%])4T\Z"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^9F]R;6%T*"(E62TE;2TE9"`E5"(I.PH@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("!C87-E($1!5$5?1D]234%47TE3
M3U]"05-)0SH*("`@("`@("`@("`@)&9O<FUA="`]("(E625M)614)4@E3253
M(CL*("`@("`@("`@("`@:68@*"1T:&ES+3YT>BT^9V5T240H*2`]/2`G551#
M)RD@>PH@("`@("`@("`@("`@("`@)&9O<FUA="`N/2`B6B(["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YF;W)M870H)&9O<FUA
M="D["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@(&-A<V4@1$%415]&3U)-
M051?25-/7T585$5.1$5$.@H@("`@("`@("`@("`D9F]R;6%T(#T@(B59+25M
M+25D5"5(.B5-.B53(CL*("`@("`@("`@("`@:68@*"1T:&ES+3YT>BT^9V5T
M240H*2`]/2`G551#)RD@>PH@("`@("`@("`@("`@("`@)&9O<FUA="`N/2`B
M6B(["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YF
M;W)M870H)&9O<FUA="D["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@(&-A
M<V4@1$%415]&3U)-051?25-/7T585$5.1$5$7TU)0U)/5$E-13H*("`@("`@
M("`@("`@)&9O<FUA="`]("(E62TE;2TE9%0E2#HE33HE<R(["B`@("`@("`@
M("`@(&EF("@D=&AI<RT^='HM/F=E=$E$*"D@/3T@)U540R<I('L*("`@("`@
M("`@("`@("`@("1F;W)M870@+CT@(EHB.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^9F]R;6%T*"1F;W)M870I.PH@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("!C87-E($1!5$5?1D]234%47U1)34535$%-
M4#H*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YF;W)M870H(B59)6TE9"5(
M)4TE4R(I.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!C87-E($1!5$5?
M1D]234%47U5.25A424U%.@H@("`@("`@("`@("!R971U<FX@;6MT:6UE*"1T
M:&ES+3YH;W5R+"`D=&AI<RT^;6EN=71E+"`D=&AI<RT^<V5C;VYD+"`D=&AI
M<RT^;6]N=&@L("1T:&ES+3YD87DL("1T:&ES+3YY96%R*3L*("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0V]P
M>2!V86QU97,@9G)O;2!A;F]T:&5R($1A=&4@;V)J96-T"B`@("`@*@H@("`@
M("H@36%K97,@=&AI<R!$871E(&$@8V]P>2!O9B!A;F]T:&5R($1A=&4@;V)J
M96-T+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R
M86T@;V)J96-T($1A=&4@)&1A=&4@1&%T92!T;R!C;W!Y(&9R;VT*("`@("`J
M+PH@("`@9G5N8W1I;VX@8V]P>2@D9&%T92D*("`@('L*("`@("`@("`D=&AI
M<RT^>65A<B`]("1D871E+3YY96%R.PH@("`@("`@("1T:&ES+3YM;VYT:"`]
M("1D871E+3YM;VYT:#L*("`@("`@("`D=&AI<RT^9&%Y(#T@)&1A=&4M/F1A
M>3L*("`@("`@("`D=&AI<RT^:&]U<B`]("1D871E+3YH;W5R.PH@("`@("`@
M("1T:&ES+3YM:6YU=&4@/2`D9&%T92T^;6EN=71E.PH@("`@("`@("1T:&ES
M+3YS96-O;F0@/2`D9&%T92T^<V5C;VYD.PH@("`@("`@("1T:&ES+3YT>B`]
M("1D871E+3YT>CL*("`@('T*"B`@("`O*BH*("`@("`J("!$871E('!R971T
M>2!P<FEN=&EN9RP@<VEM:6QA<B!T;R!S=')F=&EM92@I"B`@("`@*@H@("`@
M("H@($9O<FUA=',@=&AE(&1A=&4@:6X@=&AE(&=I=F5N(&9O<FUA="P@;75C
M:"!L:6ME"B`@("`@*B`@<W1R9G1I;64H*2X@($UO<W0@<W1R9G1I;64H*2!O
M<'1I;VYS(&%R92!S=7!P;W)T960N/&)R/CQB<CX*("`@("`J"B`@("`@*B`@
M9F]R;6%T=&EN9R!O<'1I;VYS.CQB<CX\8G(^"B`@("`@*@H@("`@("H@(#QC
M;V1E/B5A("`\+V-O9&4^("!A8F)R979I871E9"!W965K9&%Y(&YA;64@*%-U
M;BP@36]N+"!4=64I(#QB<CX*("`@("`J("`\8V]D93XE02`@/"]C;V1E/B`@
M9G5L;"!W965K9&%Y(&YA;64@*%-U;F1A>2P@36]N9&%Y+"!4=65S9&%Y*2`\
M8G(^"B`@("`@*B`@/&-O9&4^)6(@(#PO8V]D93X@(&%B8G)E=FEA=&5D(&UO
M;G1H(&YA;64@*$IA;BP@1F5B+"!-87(I(#QB<CX*("`@("`J("`\8V]D93XE
M0B`@/"]C;V1E/B`@9G5L;"!M;VYT:"!N86UE("A*86YU87)Y+"!&96)R=6%R
M>2P@36%R8V@I(#QB<CX*("`@("`J("`\8V]D93XE0R`@/"]C;V1E/B`@8V5N
M='5R>2!N=6UB97(@*'1H92!Y96%R(&1I=FED960@8GD@,3`P(&%N9"!T<G5N
M8V%T960@=&\@86X@:6YT96=E<BP@<F%N9V4@,#`@=&\@.3DI(#QB<CX*("`@
M("`J("`\8V]D93XE9"`@/"]C;V1E/B`@9&%Y(&]F(&UO;G1H("AR86YG92`P
M,"!T;R`S,2D@/&)R/@H@("`@("H@(#QC;V1E/B5$("`\+V-O9&4^("!S86UE
M(&%S("(E;2\E9"\E>2(@/&)R/@H@("`@("H@(#QC;V1E/B5E("`\+V-O9&4^
M("!D87D@;V8@;6]N=&@L('-I;F=L92!D:6=I="`H<F%N9V4@,"!T;R`S,2D@
M/&)R/@H@("`@("H@(#QC;V1E/B5%("`\+V-O9&4^("!N=6UB97(@;V8@9&%Y
M<R!S:6YC92!U;G-P96-I9FEE9"!E<&]C:"`H:6YT96=E<BP@1&%T95]#86QC
M.CID871E5&]$87ES*"DI(#QB<CX*("`@("`J("`\8V]D93XE2"`@/"]C;V1E
M/B`@:&]U<B!A<R!D96-I;6%L(&YU;6)E<B`H,#`@=&\@,C,I(#QB<CX*("`@
M("`J("`\8V]D93XE22`@/"]C;V1E/B`@:&]U<B!A<R!D96-I;6%L(&YU;6)E
M<B!O;B`Q,BUH;W5R(&-L;V-K("@P,2!T;R`Q,BD@/&)R/@H@("`@("H@(#QC
M;V1E/B5J("`\+V-O9&4^("!D87D@;V8@>65A<B`H<F%N9V4@,#`Q('1O(#,V
M-BD@/&)R/@H@("`@("H@(#QC;V1E/B5M("`\+V-O9&4^("!M;VYT:"!A<R!D
M96-I;6%L(&YU;6)E<B`H<F%N9V4@,#$@=&\@,3(I(#QB<CX*("`@("`J("`\
M8V]D93XE32`@/"]C;V1E/B`@;6EN=71E(&%S(&$@9&5C:6UA;"!N=6UB97(@
M*#`P('1O(#4Y*2`\8G(^"B`@("`@*B`@/&-O9&4^)6X@(#PO8V]D93X@(&YE
M=VQI;F4@8VAA<F%C=&5R("A<;BD@/&)R/@H@("`@("H@(#QC;V1E/B5/("`\
M+V-O9&4^("!D<W0M8V]R<F5C=&5D('1I;65Z;VYE(&]F9G-E="!E>'!R97-S
M960@87,@(BLO+4A(.DU-(B`\8G(^"B`@("`@*B`@/&-O9&4^)6\@(#PO8V]D
M93X@(')A=R!T:6UE>F]N92!O9F9S970@97AP<F5S<V5D(&%S("(K+RU(2#I-
M32(@/&)R/@H@("`@("H@(#QC;V1E/B5P("`\+V-O9&4^("!E:71H97(@)V%M
M)R!O<B`G<&TG(&1E<&5N9&EN9R!O;B!T:&4@=&EM92`\8G(^"B`@("`@*B`@
M/&-O9&4^)5`@(#PO8V]D93X@(&5I=&AE<B`G04TG(&]R("=032<@9&5P96YD
M:6YG(&]N('1H92!T:6UE(#QB<CX*("`@("`J("`\8V]D93XE<B`@/"]C;V1E
M/B`@=&EM92!I;B!A;2]P;2!N;W1A=&EO;BP@<V%M92!A<R`B)4DZ)4TZ)5,@
M)7`B(#QB<CX*("`@("`J("`\8V]D93XE4B`@/"]C;V1E/B`@=&EM92!I;B`R
M-"UH;W5R(&YO=&%T:6]N+"!S86UE(&%S("(E2#HE32(@/&)R/@H@("`@("H@
M(#QC;V1E/B5S("`\+V-O9&4^("!S96-O;F1S(&EN8VQU9&EN9R!T:&4@9&5C
M:6UA;"!R97!R97-E;G1A=&EO;B!S;6%L;&5R('1H86X@;VYE('-E8V]N9"`\
M8G(^"B`@("`@*B`@/&-O9&4^)5,@(#PO8V]D93X@('-E8V]N9',@87,@82!D
M96-I;6%L(&YU;6)E<B`H,#`@=&\@-3DI(#QB<CX*("`@("`J("`\8V]D93XE
M="`@/"]C;V1E/B`@=&%B(&-H87)A8W1E<B`H7'0I(#QB<CX*("`@("`J("`\
M8V]D93XE5"`@/"]C;V1E/B`@8W5R<F5N="!T:6UE+"!S86UE(&%S("(E2#HE
M33HE4R(@/&)R/@H@("`@("H@(#QC;V1E/B5W("`\+V-O9&4^("!W965K9&%Y
M(&%S(&1E8VEM86P@*#`@/2!3=6YD87DI(#QB<CX*("`@("`J("`\8V]D93XE
M52`@/"]C;V1E/B`@=V5E:R!N=6UB97(@;V8@8W5R<F5N="!Y96%R+"!F:7)S
M="!S=6YD87D@87,@9FER<W0@=V5E:R`\8G(^"B`@("`@*B`@/&-O9&4^)7D@
M(#PO8V]D93X@('EE87(@87,@9&5C:6UA;"`H<F%N9V4@,#`@=&\@.3DI(#QB
M<CX*("`@("`J("`\8V]D93XE62`@/"]C;V1E/B`@>65A<B!A<R!D96-I;6%L
M(&EN8VQU9&EN9R!C96YT=7)Y("AR86YG92`P,#`P('1O(#DY.3DI(#QB<CX*
M("`@("`J("`\8V]D93XE)2`@/"]C;V1E/B`@;&ET97)A;"`G)2<@/&)R/@H@
M("`@("H@/&)R/@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B!`<&%R86T@<W1R:6YG(&9O<FUA="!T:&4@9F]R;6%T('-T<FEN9R!F;W(@
M<F5T=7)N960@9&%T92]T:6UE"B`@("`@*B!`<F5T=7)N('-T<FEN9R!D871E
M+W1I;64@:6X@9VEV96X@9F]R;6%T"B`@("`@*B\*("`@(&9U;F-T:6]N(&9O
M<FUA="@D9F]R;6%T*0H@("`@>PH@("`@("`@("1O=71P=70@/2`B(CL*"B`@
M("`@("`@9F]R*"1S=')P;W,@/2`P.R`D<W1R<&]S(#P@<W1R;&5N*"1F;W)M
M870I.R`D<W1R<&]S*RLI('L*("`@("`@("`@("`@)&-H87(@/2!S=6)S='(H
M)&9O<FUA="PD<W1R<&]S+#$I.PH@("`@("`@("`@("!I9B`H)&-H87(@/3T@
M(B4B*2!["B`@("`@("`@("`@("`@("`D;F5X=&-H87(@/2!S=6)S='(H)&9O
M<FUA="PD<W1R<&]S("L@,2PQ*3L*("`@("`@("`@("`@("`@('-W:71C:"`H
M)&YE>'1C:&%R*2!["B`@("`@("`@("`@("`@("!C87-E(")A(CH*("`@("`@
M("`@("`@("`@("`@("`D;W5T<'5T("X]($1A=&5?0V%L8SHZ9V5T5V5E:V1A
M>4%B8G)N86UE*"1T:&ES+3YD87DL)'1H:7,M/FUO;G1H+"1T:&ES+3YY96%R
M+"`D=&AI<RT^9V5T5V5E:V1A>4%B8G)N86UE3&5N9W1H*3L*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@(D$B.@H@
M("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@1&%T95]#86QC.CIG9717
M965K9&%Y1G5L;&YA;64H)'1H:7,M/F1A>2PD=&AI<RT^;6]N=&@L)'1H:7,M
M/GEE87(I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("`@("`@8V%S92`B8B(Z"B`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N
M/2!$871E7T-A;&,Z.F=E=$UO;G1H06)B<FYA;64H)'1H:7,M/FUO;G1H*3L*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A
M<V4@(D(B.@H@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@1&%T95]#
M86QC.CIG971-;VYT:$9U;&QN86UE*"1T:&ES+3YM;VYT:"D["B`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E(")#(CH*
M("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]('-P<FEN=&8H(B4P,F0B
M+&EN='9A;"@D=&AI<RT^>65A<B\Q,#`I*3L*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@(F0B.@H@("`@("`@("`@
M("`@("`@("`@("1O=71P=70@+CT@<W!R:6YT9B@B)3`R9"(L)'1H:7,M/F1A
M>2D["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("!C87-E(")$(CH*("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]('-P
M<FEN=&8H(B4P,F0O)3`R9"\E,#)D(BPD=&AI<RT^;6]N=&@L)'1H:7,M/F1A
M>2PD=&AI<RT^>65A<BD["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@("`@("!C87-E(")E(CH*("`@("`@("`@("`@("`@("`@("`D
M;W5T<'5T("X]("1T:&ES+3YD87D@*B`Q.R`O+R!G970@<FED(&]F(&QE861I
M;F<@>F5R;PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("`@("`@8V%S92`B12(Z"B`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N
M/2!$871E7T-A;&,Z.F1A=&54;T1A>7,H)'1H:7,M/F1A>2PD=&AI<RT^;6]N
M=&@L)'1H:7,M/GEE87(I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@8V%S92`B2"(Z"B`@("`@("`@("`@("`@("`@("`@
M)&]U='!U="`N/2!S<')I;G1F*"(E,#)D(BP@)'1H:7,M/FAO=7(I.PH@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`G
M:"<Z"B`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2!S<')I;G1F*"(E
M9"(L("1T:&ES+3YH;W5R*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@("`@(&-A<V4@(DDB.@H@("`@("`@("`@("`@("`@("`@
M("1H;W5R(#T@*"1T:&ES+3YH;W5R("L@,2D@/B`Q,B`_("1T:&ES+3YH;W5R
M("T@,3(@.B`D=&AI<RT^:&]U<CL*("`@("`@("`@("`@("`@("`@("`D;W5T
M<'5T("X]('-P<FEN=&8H(B4P,F0B+"`D:&]U<CT],"`_(#$R(#H@)&AO=7(I
M.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M8V%S92`B:2(Z"B`@("`@("`@("`@("`@("`@("`@)&AO=7(@/2`H)'1H:7,M
M/FAO=7(@*R`Q*2`^(#$R(#\@)'1H:7,M/FAO=7(@+2`Q,B`Z("1T:&ES+3YH
M;W5R.PH@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@<W!R:6YT9B@B
M)60B+"`D:&]U<CT],"`_(#$R(#H@)&AO=7(I.PH@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`B:B(Z"B`@("`@("`@
M("`@("`@("`@("`@)&]U='!U="`N/2!$871E7T-A;&,Z.FIU;&EA;D1A=&4H
M)'1H:7,M/F1A>2PD=&AI<RT^;6]N=&@L)'1H:7,M/GEE87(I.PH@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`B;2(Z
M"B`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2!S<')I;G1F*"(E,#)D
M(BPD=&AI<RT^;6]N=&@I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@8V%S92`B32(Z"B`@("`@("`@("`@("`@("`@("`@
M)&]U='!U="`N/2!S<')I;G1F*"(E,#)D(BPD=&AI<RT^;6EN=71E*3L*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@
M(FXB.@H@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@(EQN(CL*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@
M(D\B.@H@("`@("`@("`@("`@("`@("`@("1O9F9M<R`]("1T:&ES+3YT>BT^
M9V5T3V9F<V5T*"1T:&ES*3L*("`@("`@("`@("`@("`@("`@("`D9&ER96-T
M:6]N(#T@)&]F9FUS(#X](#`@/R`B*R(@.B`B+2(["B`@("`@("`@("`@("`@
M("`@("`@)&]F9FUI;G,@/2!A8G,H)&]F9FUS*2`O(#$P,#`@+R`V,#L*("`@
M("`@("`@("`@("`@("`@("`D:&]U<G,@/2`D;V9F;6EN<R`O(#8P.PH@("`@
M("`@("`@("`@("`@("`@("1M:6YU=&5S(#T@)&]F9FUI;G,@)2`V,#L*("`@
M("`@("`@("`@("`@("`@("`D;W5T<'5T("X]('-P<FEN=&8H(B5S)3`R9#HE
M,#)D(BP@)&1I<F5C=&EO;BP@)&AO=7)S+"`D;6EN=71E<RD["B`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E(")O(CH*
M("`@("`@("`@("`@("`@("`@("`D;V9F;7,@/2`D=&AI<RT^='HM/F=E=%)A
M=T]F9G-E="@D=&AI<RD["B`@("`@("`@("`@("`@("`@("`@)&1I<F5C=&EO
M;B`]("1O9F9M<R`^/2`P(#\@(BLB(#H@(BTB.PH@("`@("`@("`@("`@("`@
M("`@("1O9F9M:6YS(#T@86)S*"1O9F9M<RD@+R`Q,#`P("\@-C`["B`@("`@
M("`@("`@("`@("`@("`@)&AO=7)S(#T@)&]F9FUI;G,@+R`V,#L*("`@("`@
M("`@("`@("`@("`@("`D;6EN=71E<R`]("1O9F9M:6YS("4@-C`["B`@("`@
M("`@("`@("`@("`@("`@)&]U='!U="`N/2!S<')I;G1F*"(E<R4P,F0Z)3`R
M9"(L("1D:7)E8W1I;VXL("1H;W5R<RP@)&UI;G5T97,I.PH@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`B<"(Z"B`@
M("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2`D=&AI<RT^:&]U<B`^/2`Q
M,B`_(")P;2(@.B`B86TB.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@8V%S92`B4"(Z"B`@("`@("`@("`@("`@("`@("`@
M)&]U='!U="`N/2`D=&AI<RT^:&]U<B`^/2`Q,B`_(")032(@.B`B04TB.PH@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S
M92`B<B(Z"B`@("`@("`@("`@("`@("`@("`@)&AO=7(@/2`H)'1H:7,M/FAO
M=7(@*R`Q*2`^(#$R(#\@)'1H:7,M/FAO=7(@+2`Q,B`Z("1T:&ES+3YH;W5R
M.PH@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@<W!R:6YT9B@B)3`R
M9#HE,#)D.B4P,F0@)7,B+"`D:&]U<CT],"`_("`Q,B`Z("1H;W5R+"`D=&AI
M<RT^;6EN=71E+"`D=&AI<RT^<V5C;VYD+"`D=&AI<RT^:&]U<B`^/2`Q,B`_
M(")032(@.B`B04TB*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@("`@(&-A<V4@(E(B.@H@("`@("`@("`@("`@("`@("`@("1O
M=71P=70@+CT@<W!R:6YT9B@B)3`R9#HE,#)D(BP@)'1H:7,M/FAO=7(L("1T
M:&ES+3YM:6YU=&4I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@8V%S92`B<R(Z"B`@("`@("`@("`@("`@("`@("`@)&]U
M='!U="`N/2!S=')?<F5P;&%C92@G+"<L("<N)RP@<W!R:6YT9B@B)3`Y9B(L
M("AF;&]A="DH*&9L;V%T*21T:&ES+3YS96-O;F0@*R`D=&AI<RT^<&%R='-E
M8V]N9"DI*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@(&-A<V4@(E,B.@H@("`@("`@("`@("`@("`@("`@("1O=71P=70@
M+CT@<W!R:6YT9B@B)3`R9"(L("1T:&ES+3YS96-O;F0I.PH@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`B="(Z"B`@
M("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2`B7'0B.PH@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`B5"(Z"B`@
M("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2!S<')I;G1F*"(E,#)D.B4P
M,F0Z)3`R9"(L("1T:&ES+3YH;W5R+"`D=&AI<RT^;6EN=71E+"`D=&AI<RT^
M<V5C;VYD*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@(&-A<V4@(G<B.@H@("`@("`@("`@("`@("`@("`@("1O=71P=70@
M+CT@1&%T95]#86QC.CID87E/9E=E96LH)'1H:7,M/F1A>2PD=&AI<RT^;6]N
M=&@L)'1H:7,M/GEE87(I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@8V%S92`B52(Z"B`@("`@("`@("`@("`@("`@("`@
M)&]U='!U="`N/2!$871E7T-A;&,Z.G=E96M/9EEE87(H)'1H:7,M/F1A>2PD
M=&AI<RT^;6]N=&@L)'1H:7,M/GEE87(I.PH@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`B>2(Z"B`@("`@("`@("`@
M("`@("`@("`@)&]U='!U="`N/2!S=6)S='(H)'1H:7,M/GEE87(L,BPR*3L*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A
M<V4@(EDB.@H@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@)'1H:7,M
M/GEE87(["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("!C87-E("):(CH*("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]
M("1T:&ES+3YT>BT^:6Y$87EL:6=H=%1I;64H)'1H:7,I(#\@)'1H:7,M/G1Z
M+3YG971$4U13:&]R=$YA;64H*2`Z("1T:&ES+3YT>BT^9V5T4VAO<G1.86UE
M*"D["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("!C87-E("(E(CH*("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]("(E
M(CL*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2`D8VAA
M<BXD;F5X=&-H87(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D<W1R<&]S*RL["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D;W5T<'5T("X]("1C:&%R.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D;W5T<'5T.PH*("`@('T*"B`@("`O*BH*("`@
M("`J($=E="!T:&ES(&1A=&4O=&EM92!I;B!5;FEX('1I;64H*2!F;W)M870*
M("`@("`J"B`@("`@*B!'970@82!R97!R97-E;G1A=&EO;B!O9B!T:&ES(&1A
M=&4@:6X@56YI>"!T:6UE*"D@9F]R;6%T+B`@5&AI<R!M87D@;VYL>2!B90H@
M("`@("H@=F%L:60@9F]R(&1A=&5S(&9R;VT@,3DW,"!T;R!^,C`S."X*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!I;G0@
M;G5M8F5R(&]F('-E8V]N9',@<VEN8V4@=&AE('5N:7@@97!O8V@*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T5&EM92@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3YG971$871E*$1!5$5?1D]234%47U5.25A424U%*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%-E=',@=&AE('1I;64@>F]N92!O9B!T:&ES($1A
M=&4*("`@("`J"B`@("`@*B!3971S('1H92!T:6UE('IO;F4@;V8@=&AI<R!D
M871E('=I=&@@=&AE(&=I=F5N"B`@("`@*B!$871E7U1I;65:;VYE(&]B:F5C
M="X@($1O97,@;F]T(&%L=&5R('1H92!D871E+W1I;64L"B`@("`@*B!O;FQY
M(&%S<VEG;G,@82!N97<@=&EM92!Z;VYE+B`@1F]R(&-O;G9E<G-I;VXL('5S
M90H@("`@("H@8V]N=F5R=%1:*"DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J($!P87)A;2!O8FIE8W0@1&%T95]4:6UE6F]N92`D='H@
M=&AE($1A=&5?5&EM95IO;F4@;V)J96-T('1O('5S92P@:68@8V%L;&5D"B`@
M("`@*B!W:71H(&$@<&%R86UA=&5R('1H870@:7,@;F]T(&$@1&%T95]4:6UE
M6F]N92!O8FIE8W0L('=I;&P@9F%L;"!T:')O=6=H('1O"B`@("`@*B!S9714
M6F)Y240H*2X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T5%HH)'1Z*0H@("`@
M>PH@("`@"6EF*&ES7V$H)'1Z+"`G1&%T95]4:6UE>F]N92<I*2!["B`@("`@
M("`@"21T:&ES+3YT>B`]("1T>CL*("`@(`E](&5L<V4@>PH@("`@"0DD=&AI
M<RT^<V5T5%IB>4E$*"1T>BD["B`@("`)?0H@("`@?0H*("`@("\J*@H@("`@
M("H@4V5T<R!T:&4@=&EM92!Z;VYE(&]F('1H:7,@9&%T92!W:71H('1H92!G
M:79E;B!T:6UE('IO;F4@:60*("`@("`J"B`@("`@*B!3971S('1H92!T:6UE
M('IO;F4@;V8@=&AI<R!D871E('=I=&@@=&AE(&=I=F5N"B`@("`@*B!T:6UE
M('IO;F4@:60L(&]R('1O('1H92!S>7-T96T@9&5F875L="!I9B!T:&4*("`@
M("`J(&=I=F5N(&ED(&ES(&EN=F%L:60N($1O97,@;F]T(&%L=&5R('1H92!D
M871E+W1I;64L"B`@("`@*B!O;FQY(&%S<VEG;G,@82!N97<@=&EM92!Z;VYE
M+B`@1F]R(&-O;G9E<G-I;VXL('5S90H@("`@("H@8V]N=F5R=%1:*"DN"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2!S=')I
M;F<@:60@82!T:6UE('IO;F4@:60*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T
M5%IB>4E$*"1I9"D*("`@('L*("`@("`@("!I9B`H1&%T95]4:6UE6F]N93HZ
M:7-686QI9$E$*"1I9"DI('L*("`@("`@("`@("`@)'1H:7,M/G1Z(#T@;F5W
M($1A=&5?5&EM95IO;F4H)&ED*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D=&AI<RT^='H@/2!$871E7U1I;65:;VYE.CIG971$969A=6QT*"D[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@5&5S=',@:68@=&AI
M<R!D871E+W1I;64@:7,@:6X@1%-4"B`@("`@*@H@("`@("H@4F5T=7)N<R!T
M<G5E(&EF(&1A>6QI9VAT('-A=FEN9W,@=&EM92!I<R!I;B!E9F9E8W0@9F]R
M"B`@("`@*B!T:&ES(&1A=&4@:6X@=&AI<R!D871E)W,@=&EM92!Z;VYE+B`@
M4V5E($1A=&5?5&EM95IO;F4Z.FEN1&%Y;&EG:'14:6UE*"D*("`@("`J(&9O
M<B!C;VUP871A8FEL:71Y(&EN9F]R;6%T:6]N+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@=')U92!I9B!$
M4U0@:7,@:6X@969F96-T(&9O<B!T:&ES(&1A=&4*("`@("`J+PH@("`@9G5N
M8W1I;VX@:6Y$87EL:6=H=%1I;64H*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^='HM/FEN1&%Y;&EG:'14:6UE*"1T:&ES*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($-O;G9E<G1S('1H:7,@9&%T92!T;R!55$,@86YD('-E=',@
M=&AI<R!D871E)W,@=&EM97IO;F4@=&\@551#"B`@("`@*@H@("`@("H@0V]N
M=F5R=',@=&AI<R!D871E('1O(%540R!A;F0@<V5T<R!T:&ES(&1A=&4G<R!T
M:6UE>F]N92!T;R!55$,*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("HO"B`@("!F=6YC=&EO;B!T;U540R@I"B`@("!["B`@("`@("`@:68@
M*"1T:&ES+3YT>BT^9V5T3V9F<V5T*"1T:&ES*2`^(#`I('L*("`@("`@("`@
M("`@)'1H:7,M/G-U8G1R86-T4V5C;VYD<RAI;G1V86PH)'1H:7,M/G1Z+3YG
M971/9F9S970H)'1H:7,I("\@,3`P,"DI.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1T:&ES+3YA9&1396-O;F1S*&EN='9A;"AA8G,H)'1H:7,M
M/G1Z+3YG971/9F9S970H)'1H:7,I*2`O(#$P,#`I*3L*("`@("`@("!]"B`@
M("`@("`@)'1H:7,M/G1Z(#T@;F5W($1A=&5?5&EM95IO;F4H)U540R<I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R=',@=&AI<R!D871E('1O(&$@
M;F5W('1I;64@>F]N90H@("`@("H*("`@("`J($-O;G9E<G1S('1H:7,@9&%T
M92!T;R!A(&YE=R!T:6UE('IO;F4N"B`@("`@*B!705).24Y'.B!4:&ES(&UA
M>2!N;W0@=V]R:R!C;W)R96-T;'D@:68@>6]U<B!S>7-T96T@9&]E<R!N;W0@
M86QL;W<*("`@("`J('!U=&5N=B@I(&]R(&EF(&QO8V%L=&EM92@I(&1O97,@
M;F]T('=O<FL@:6X@>6]U<B!E;G9I<F]N;65N="X@(%-E90H@("`@("H@1&%T
M93HZ5&EM95IO;F4Z.FEN1&%Y;&EG:'14:6UE*"D@9F]R(&UO<F4@:6YF;W)M
M871I;VXN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P
M87)A;2!O8FIE8W0@1&%T95]4:6UE6F]N92`D='H@=&AE($1A=&4Z.E1I;65:
M;VYE(&]B:F5C="!F;W(@=&AE(&-O;G9E<G-I;VX@=&EM92!Z;VYE"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-O;G9E<G146B@D='HI"B`@("!["B`@("`@("`@
M+R\@8V]N=F5R="!T;R!55$,*("`@("`@("!I9B`H)'1H:7,M/G1Z+3YG971/
M9F9S970H)'1H:7,I(#X@,"D@>PH@("`@("`@("`@("`D=&AI<RT^<W5B=')A
M8W1396-O;F1S*&EN='9A;"AA8G,H)'1H:7,M/G1Z+3YG971/9F9S970H)'1H
M:7,I*2`O(#$P,#`I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M=&AI<RT^861D4V5C;VYD<RAI;G1V86PH86)S*"1T:&ES+3YT>BT^9V5T3V9F
M<V5T*"1T:&ES*2D@+R`Q,#`P*2D["B`@("`@("`@?0H@("`@("`@("\O(&-O
M;G9E<G0@551#('1O(&YE=R!T:6UE>F]N90H@("`@("`@(&EF("@D='HM/F=E
M=$]F9G-E="@D=&AI<RD@/B`P*2!["B`@("`@("`@("`@("1T:&ES+3YA9&13
M96-O;F1S*&EN='9A;"AA8G,H)'1Z+3YG971/9F9S970H)'1H:7,I*2`O(#$P
M,#`I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^<W5B
M=')A8W1396-O;F1S*&EN='9A;"AA8G,H)'1Z+3YG971/9F9S970H)'1H:7,I
M*2`O(#$P,#`I*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/G1Z(#T@)'1Z
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R=',@=&AI<R!D871E('1O
M(&$@;F5W('1I;64@>F]N92P@9VEV96X@82!V86QI9"!T:6UE('IO;F4@240*
M("`@("`J"B`@("`@*B!#;VYV97)T<R!T:&ES(&1A=&4@=&\@82!N97<@=&EM
M92!Z;VYE+"!G:79E;B!A('9A;&ED('1I;64@>F]N92!)1`H@("`@("H@5T%2
M3DE.1SH@5&AI<R!M87D@;F]T('=O<FL@8V]R<F5C=&QY(&EF('EO=7(@<WES
M=&5M(&1O97,@;F]T(&%L;&]W"B`@("`@*B!P=71E;G8H*2!O<B!I9B!L;V-A
M;'1I;64H*2!D;V5S(&YO="!W;W)K(&EN('EO=7(@96YV:7)O;FUE;G0N("!3
M964*("`@("`J($1A=&4Z.E1I;65:;VYE.CII;D1A>6QI9VAT5&EM92@I(&9O
M<B!M;W)E(&EN9F]R;6%T:6]N+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B!`<&%R86T@<W1R:6YG(&ED(&$@=&EM92!Z;VYE(&ED"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&-O;G9E<G146F)Y240H)&ED*0H@("`@>PH@
M("`@("`@:68@*$1A=&5?5&EM95IO;F4Z.FES5F%L:61)1"@D:60I*2!["B`@
M("`@("`@("`D='H@/2!N97<@1&%T95]4:6UE6F]N92@D:60I.PH@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("1T>B`]($1A=&5?5&EM95IO;F4Z.F=E=$1E
M9F%U;'0H*3L*("`@("`@('T*("`@("`@("1T:&ES+3YC;VYV97)T5%HH)'1Z
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!T;U540V)Y3V9F<V5T*"1O9F9S970I
M"B`@("!["B`@("`@("`@:68@*"1O9F9S970@/3T@(EHB('Q\("1O9F9S970@
M/3T@(BLP,#HP,"(@?'P@)&]F9G-E="`]/2`B*S`P,#`B*2!["B`@("`@("`@
M("`@("1T:&ES+3YT;U540R@I.PH@("`@("`@("`@("!R971U<FX@=')U93L*
M("`@("`@("!]"@H@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O*%M<*UPM72DH
M7&1[,GTI.C\H7&1[,GTI+R<L("1O9F9S970L("1R96=S*2D@>PH@("`@("`@
M("`@("`O+R!C;VYV97)T(&]F9G-E="!T;R!S96-O;F1S"B`@("`@("`@("`@
M("1H;W5R<R`@/2`H:6YT*2!I<W-E="@D<F5G<ULR72D_)')E9W-;,ETZ,#L*
M("`@("`@("`@("`@)&UI;G,@("`]("AI;G0I(&ES<V5T*"1R96=S6S-=*3\D
M<F5G<ULS73HP.PH@("`@("`@("`@("`D;V9F<V5T(#T@*"1H;W5R<R`J(#,V
M,#`I("L@*"1M:6YS("H@-C`I.PH*("`@("`@("`@("`@:68@*&ES<V5T*"1R
M96=S6S%=*2`F)B`D<F5G<ULQ72`]/2`B+2(I('L*("`@("`@("`@("`@("`@
M("1O9F9S970@*CT@+3$["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF
M("@D;V9F<V5T(#X@,"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-U8G1R
M86-T4V5C;VYD<RAI;G1V86PH)&]F9G-E="DI.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/F%D9%-E8V]N9',H:6YT=F%L
M*&%B<R@D;V9F<V5T*2DI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M=&AI<RT^='H@/2!N97<@1&%T95]4:6UE6F]N92@G551#)RD["B`@("`@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@061D<R!A(&=I=F5N(&YU;6)E
M<B!O9B!S96-O;F1S('1O('1H92!D871E"B`@("`@*@H@("`@("H@061D<R!A
M(&=I=F5N(&YU;6)E<B!O9B!S96-O;F1S('1O('1H92!D871E"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2!I;G0@)'-E8R!T
M:&4@;G5M8F5R(&]F('-E8V]N9',@=&\@861D"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%D9%-E8V]N9',H)'-E8RD*("`@('L*("`@("`@("`D=&AI<RT^861D
M4W!A;BAN97<@1&%T95]3<&%N*"AI;G1E9V5R*21S96,I*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($%D9',@82!T:6UE('-P86X@=&\@=&AE(&1A=&4*("`@
M("`J"B`@("`@*B!!9&1S(&$@=&EM92!S<&%N('1O('1H92!D871E"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2!O8FIE8W0@
M1&%T95]3<&%N("1S<&%N('1H92!T:6UE('-P86X@=&\@861D"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&%D9%-P86XH)'-P86XI"B`@("!["B`@("`@("`@:68@
M*"%I<U]A*"1S<&%N+"`G1&%T95]3<&%N)RDI('L*("`@("`@("`@("`@<F5T
M=7)N.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/G-E8V]N9"`K/2`D<W!A
M;BT^<V5C;VYD.PH@("`@("`@(&EF("@D=&AI<RT^<V5C;VYD(#X](#8P*2![
M"B`@("`@("`@("`@("1T:&ES+3YM:6YU=&4K*SL*("`@("`@("`@("`@)'1H
M:7,M/G-E8V]N9"`M/2`V,#L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YM
M:6YU=&4@*ST@)'-P86XM/FUI;G5T93L*("`@("`@("!I9B`H)'1H:7,M/FUI
M;G5T92`^/2`V,"D@>PH@("`@("`@("`@("`D=&AI<RT^:&]U<BLK.PH@("`@
M("`@("`@("!I9B`H)'1H:7,M/FAO=7(@/CT@,C0I('L*("`@("`@("`@("`@
M("`@(&QI<W0H)'1H:7,M/GEE87(L("1T:&ES+3YM;VYT:"P@)'1H:7,M/F1A
M>2D@/0H@("`@("`@("`@("`@("`@("`@('-S8V%N9BA$871E7T-A;&,Z.FYE
M>'1$87DH)'1H:7,M/F1A>2P@)'1H:7,M/FUO;G1H+"`D=&AI<RT^>65A<BDL
M("(E,#1S)3`R<R4P,G,B*3L*("`@("`@("`@("`@("`@("1T:&ES+3YH;W5R
M("T](#(T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3YM:6YU
M=&4@+3T@-C`["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^:&]U<B`K/2`D
M<W!A;BT^:&]U<CL*("`@("`@("!I9B`H)'1H:7,M/FAO=7(@/CT@,C0I('L*
M("`@("`@("`@("`@;&ES="@D=&AI<RT^>65A<BP@)'1H:7,M/FUO;G1H+"`D
M=&AI<RT^9&%Y*2`]"B`@("`@("`@("`@("`@("!S<V-A;F8H1&%T95]#86QC
M.CIN97AT1&%Y*"1T:&ES+3YD87DL("1T:&ES+3YM;VYT:"P@)'1H:7,M/GEE
M87(I+"`B)3`T<R4P,G,E,#)S(BD["B`@("`@("`@("`@("1T:&ES+3YH;W5R
M("T](#(T.PH@("`@("`@('T*"B`@("`@("`@)&0@/2!$871E7T-A;&,Z.F1A
M=&54;T1A>7,H)'1H:7,M/F1A>2P@)'1H:7,M/FUO;G1H+"`D=&AI<RT^>65A
M<BD["B`@("`@("`@)&0@*ST@)'-P86XM/F1A>3L*"B`@("`@("`@;&ES="@D
M=&AI<RT^>65A<BP@)'1H:7,M/FUO;G1H+"`D=&AI<RT^9&%Y*2`]"B`@("`@
M("`@("`@('-S8V%N9BA$871E7T-A;&,Z.F1A>7-4;T1A=&4H)&0I+"`B)3`T
M<R4P,G,E,#)S(BD["B`@("`@("`@)'1H:7,M/GEE87(@(#T@:6YT=F%L*"1T
M:&ES+3YY96%R*3L*("`@("`@("`D=&AI<RT^;6]N=&@@/2!I;G1V86PH)'1H
M:7,M/FUO;G1H*3L*("`@("`@("`D=&AI<RT^9&%Y("`@/2!I;G1V86PH)'1H
M:7,M/F1A>2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3=6)T<F%C=',@82!G
M:79E;B!N=6UB97(@;V8@<V5C;VYD<R!F<F]M('1H92!D871E"B`@("`@*@H@
M("`@("H@4W5B=')A8W1S(&$@9VEV96X@;G5M8F5R(&]F('-E8V]N9',@9G)O
M;2!T:&4@9&%T90H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B!`<&%R86T@:6YT("1S96,@=&AE(&YU;6)E<B!O9B!S96-O;F1S('1O('-U
M8G1R86-T"B`@("`@*B\*("`@(&9U;F-T:6]N('-U8G1R86-T4V5C;VYD<R@D
M<V5C*0H@("`@>PH@("`@("`@("1T:&ES+3YS=6)T<F%C=%-P86XH;F5W($1A
M=&5?4W!A;B@D<V5C*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3=6)T<F%C
M=',@82!T:6UE('-P86X@=&\@=&AE(&1A=&4*("`@("`J"B`@("`@*B!3=6)T
M<F%C=',@82!T:6UE('-P86X@=&\@=&AE(&1A=&4*("`@("`J"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M(&]B:F5C="!$871E7U-P86X@
M)'-P86X@=&AE('1I;64@<W!A;B!T;R!S=6)T<F%C=`H@("`@("HO"B`@("!F
M=6YC=&EO;B!S=6)T<F%C=%-P86XH)'-P86XI"B`@("!["B`@("`@("`@:68@
M*"%I<U]A*"1S<&%N+"`G1&%T95]3<&%N)RDI('L*("`@("`@("`@("`@<F5T
M=7)N.PH@("`@("`@('T*("`@("`@("!I9B`H)'-P86XM/FES16UP='DH*2D@
M>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`D=&AI
M<RT^<V5C;VYD("T]("1S<&%N+3YS96-O;F0["B`@("`@("`@:68@*"1T:&ES
M+3YS96-O;F0@/"`P*2!["B`@("`@("`@("`@("1T:&ES+3YM:6YU=&4M+3L*
M("`@("`@("`@("`@)'1H:7,M/G-E8V]N9"`K/2`V,#L*("`@("`@("!]"@H@
M("`@("`@("1T:&ES+3YM:6YU=&4@+3T@)'-P86XM/FUI;G5T93L*("`@("`@
M("!I9B`H)'1H:7,M/FUI;G5T92`\(#`I('L*("`@("`@("`@("`@)'1H:7,M
M/FAO=7(M+3L*("`@("`@("`@("`@:68@*"1T:&ES+3YH;W5R(#P@,"D@>PH@
M("`@("`@("`@("`@("`@;&ES="@D=&AI<RT^>65A<BP@)'1H:7,M/FUO;G1H
M+"`D=&AI<RT^9&%Y*2`]"B`@("`@("`@("`@("`@("`@("`@<W-C86YF*$1A
M=&5?0V%L8SHZ<')E=D1A>2@D=&AI<RT^9&%Y+"`D=&AI<RT^;6]N=&@L("1T
M:&ES+3YY96%R*2P@(B4P-',E,#)S)3`R<R(I.PH@("`@("`@("`@("`@("`@
M)'1H:7,M/FAO=7(@*ST@,C0["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)'1H:7,M/FUI;G5T92`K/2`V,#L*("`@("`@("!]"@H@("`@("`@("1T:&ES
M+3YH;W5R("T]("1S<&%N+3YH;W5R.PH@("`@("`@(&EF("@D=&AI<RT^:&]U
M<B`\(#`I('L*("`@("`@("`@("`@;&ES="@D=&AI<RT^>65A<BP@)'1H:7,M
M/FUO;G1H+"`D=&AI<RT^9&%Y*2`]"B`@("`@("`@("`@("`@("!S<V-A;F8H
M1&%T95]#86QC.CIP<F5V1&%Y*"1T:&ES+3YD87DL("1T:&ES+3YM;VYT:"P@
M)'1H:7,M/GEE87(I+"`B)3`T<R4P,G,E,#)S(BD["B`@("`@("`@("`@("1T
M:&ES+3YH;W5R("L](#(T.PH@("`@("`@('T*"B`@("`@("`@)&0@/2!$871E
M7T-A;&,Z.F1A=&54;T1A>7,H)'1H:7,M/F1A>2P@)'1H:7,M/FUO;G1H+"`D
M=&AI<RT^>65A<BD["B`@("`@("`@)&0@+3T@)'-P86XM/F1A>3L*"B`@("`@
M("`@;&ES="@D=&AI<RT^>65A<BP@)'1H:7,M/FUO;G1H+"`D=&AI<RT^9&%Y
M*2`]"B`@("`@("`@("`@('-S8V%N9BA$871E7T-A;&,Z.F1A>7-4;T1A=&4H
M)&0I+"`B)3`T<R4P,G,E,#)S(BD["B`@("`@("`@)'1H:7,M/GEE87(@(#T@
M:6YT=F%L*"1T:&ES+3YY96%R*3L*("`@("`@("`D=&AI<RT^;6]N=&@@/2!I
M;G1V86PH)'1H:7,M/FUO;G1H*3L*("`@("`@("`D=&AI<RT^9&%Y("`@/2!I
M;G1V86PH)'1H:7,M/F1A>2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VUP
M87)E<R!T=V\@9&%T97,*("`@("`J"B`@("`@*B!#;VUP87)E<R!T=V\@9&%T
M97,N("!3=6ET86)L92!F;W(@=7-E"B`@("`@*B!I;B!S;W)T:6YG(&9U;F-T
M:6]N<RX*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A
M<F%M(&]B:F5C="!$871E("1D,2!T:&4@9FER<W0@9&%T90H@("`@("H@0'!A
M<F%M(&]B:F5C="!$871E("1D,B!T:&4@<V5C;VYD(&1A=&4*("`@("`J($!R
M971U<FX@:6YT(#`@:68@=&AE(&1A=&5S(&%R92!E<75A;"P@+3$@:68@9#$@
M:7,@8F5F;W)E(&0R+"`Q(&EF(&0Q(&ES(&%F=&5R(&0R"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-O;7!A<F4H)&0Q+"`D9#(I"B`@("!["B`@("`@("`@)&0Q
M+3YC;VYV97)T5%HH;F5W($1A=&5?5&EM95IO;F4H)U540R<I*3L*("`@("`@
M("`D9#(M/F-O;G9E<G146BAN97<@1&%T95]4:6UE6F]N92@G551#)RDI.PH@
M("`@("`@("1D87ES,2`]($1A=&5?0V%L8SHZ9&%T951O1&%Y<R@D9#$M/F1A
M>2P@)&0Q+3YM;VYT:"P@)&0Q+3YY96%R*3L*("`@("`@("`D9&%Y<S(@/2!$
M871E7T-A;&,Z.F1A=&54;T1A>7,H)&0R+3YD87DL("1D,BT^;6]N=&@L("1D
M,BT^>65A<BD["B`@("`@("`@:68@*"1D87ES,2`\("1D87ES,BD@<F5T=7)N
M("TQ.PH@("`@("`@(&EF("@D9&%Y<S$@/B`D9&%Y<S(I(')E='5R;B`Q.PH@
M("`@("`@(&EF("@D9#$M/FAO=7(@/"`D9#(M/FAO=7(I(')E='5R;B`M,3L*
M("`@("`@("!I9B`H)&0Q+3YH;W5R(#X@)&0R+3YH;W5R*2!R971U<FX@,3L*
M("`@("`@("!I9B`H)&0Q+3YM:6YU=&4@/"`D9#(M/FUI;G5T92D@<F5T=7)N
M("TQ.PH@("`@("`@(&EF("@D9#$M/FUI;G5T92`^("1D,BT^;6EN=71E*2!R
M971U<FX@,3L*("`@("`@("!I9B`H)&0Q+3YS96-O;F0@/"`D9#(M/G-E8V]N
M9"D@<F5T=7)N("TQ.PH@("`@("`@(&EF("@D9#$M/G-E8V]N9"`^("1D,BT^
M<V5C;VYD*2!R971U<FX@,3L*("`@("`@("!R971U<FX@,#L*("`@('T*"B`@
M("`O*BH*("`@("`J(%1E<W0@:68@=&AI<R!D871E+W1I;64@:7,@8F5F;W)E
M(&$@8V5R=&%I;B!D871E+W1I;64*("`@("`J"B`@("`@*B!497-T(&EF('1H
M:7,@9&%T92]T:6UE(&ES(&)E9F]R92!A(&-E<G1A:6X@9&%T92]T:6UE"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2!O8FIE
M8W0@1&%T92`D=VAE;B!T:&4@9&%T92!T;R!T97-T(&%G86EN<W0*("`@("`J
M($!R971U<FX@8F]O;&5A;B!T<G5E(&EF('1H:7,@9&%T92!I<R!B969O<F4@
M)'=H96X*("`@("`J+PH@("`@9G5N8W1I;VX@8F5F;W)E*"1W:&5N*0H@("`@
M>PH@("`@("`@(&EF("A$871E.CIC;VUP87)E*"1T:&ES+"1W:&5N*2`]/2`M
M,2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@5&5S="!I9B!T:&ES(&1A=&4O=&EM92!I<R!A9G1E
M<B!A(&-E<G1I86X@9&%T92]T:6UE"B`@("`@*@H@("`@("H@5&5S="!I9B!T
M:&ES(&1A=&4O=&EM92!I<R!A9G1E<B!A(&-E<G1I86X@9&%T92]T:6UE"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2!O8FIE
M8W0@1&%T92`D=VAE;B!T:&4@9&%T92!T;R!T97-T(&%G86EN<W0*("`@("`J
M($!R971U<FX@8F]O;&5A;B!T<G5E(&EF('1H:7,@9&%T92!I<R!A9G1E<B`D
M=VAE;@H@("`@("HO"B`@("!F=6YC=&EO;B!A9G1E<B@D=VAE;BD*("`@('L*
M("`@("`@("!I9B`H1&%T93HZ8V]M<&%R92@D=&AI<RPD=VAE;BD@/3T@,2D@
M>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@5&5S="!I9B!T:&ES(&1A=&4O=&EM92!I<R!E>&%C=&QY
M(&5Q=6%L('1O(&$@8V5R=&EA;B!D871E+W1I;64*("`@("`J"B`@("`@*B!4
M97-T(&EF('1H:7,@9&%T92]T:6UE(&ES(&5X86-T;'D@97%U86P@=&\@82!C
M97)T:6%N(&1A=&4O=&EM90H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B!`<&%R86T@;V)J96-T($1A=&4@)'=H96X@=&AE(&1A=&4@=&\@
M=&5S="!A9V%I;G-T"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@=')U92!I9B!T
M:&ES(&1A=&4@:7,@97AA8W1L>2!E<75A;"!T;R`D=VAE;@H@("`@("HO"B`@
M("!F=6YC=&EO;B!E<75A;',H)'=H96XI"B`@("!["B`@("`@("`@:68@*$1A
M=&4Z.F-O;7!A<F4H)'1H:7,L)'=H96XI(#T](#`I('L*("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1E
M=&5R;6EN92!I9B!T:&ES(&1A=&4@:7,@:6X@=&AE(&9U='5R90H@("`@("H*
M("`@("`J($1E=&5R;6EN92!I9B!T:&ES(&1A=&4@:7,@:6X@=&AE(&9U='5R
M90H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@=')U92!I9B!T:&ES(&1A=&4@:7,@:6X@=&AE(&9U='5R90H@
M("`@("HO"B`@("!F=6YC=&EO;B!I<T9U='5R92@I"B`@("!["B`@("`@("`@
M)&YO=R`](&YE=R!$871E*"D["B`@("`@("`@:68@*"1T:&ES+3YA9G1E<B@D
M;F]W*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE(&EF('1H:7,@9&%T92!I<R!I
M;B!T:&4@<&%S=`H@("`@("H*("`@("`J($1E=&5R;6EN92!I9B!T:&ES(&1A
M=&4@:7,@:6X@=&AE('!A<W0*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("H@0')E='5R;B!B;V]L96%N('1R=64@:68@=&AI<R!D871E(&ES
M(&EN('1H92!P87-T"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES4&%S="@I"B`@
M("!["B`@("`@("`@)&YO=R`](&YE=R!$871E*"D["B`@("`@("`@:68@*"1T
M:&ES+3YB969O<F4H)&YO=RDI('L*("`@("`@("`@("`@<F5T=7)N('1R=64[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1E=&5R;6EN92!I9B!T
M:&4@>65A<B!I;B!T:&ES(&1A=&4@:7,@82!L96%P('EE87(*("`@("`J"B`@
M("`@*B!$971E<FUI;F4@:68@=&AE('EE87(@:6X@=&AI<R!D871E(&ES(&$@
M;&5A<"!Y96%R"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M($!R971U<FX@8F]O;&5A;B!T<G5E(&EF('1H:7,@>65A<B!I<R!A(&QE87`@
M>65A<@H@("`@("HO"B`@("!F=6YC=&EO;B!I<TQE87!996%R*"D*("`@('L*
M("`@("`@("!R971U<FX@1&%T95]#86QC.CII<TQE87!996%R*"1T:&ES+3YY
M96%R*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@2G5L:6%N(&1A
M=&4@9F]R('1H:7,@9&%T90H@("`@("H*("`@("`J($=E="!T:&4@2G5L:6%N
M(&1A=&4@9F]R('1H:7,@9&%T90H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B!`<F5T=7)N(&EN="!T:&4@2G5L:6%N(&1A=&4*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T2G5L:6%N1&%T92@I"B`@("!["B`@("`@("`@
M<F5T=7)N($1A=&5?0V%L8SHZ:G5L:6%N1&%T92@D=&AI<RT^9&%Y+"`D=&AI
M<RT^;6]N=&@L("1T:&ES+3YY96%R*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($=E=',@=&AE(&1A>2!O9B!T:&4@=V5E:R!F;W(@=&AI<R!D871E"B`@("`@
M*@H@("`@("H@1V5T<R!T:&4@9&%Y(&]F('1H92!W965K(&9O<B!T:&ES(&1A
M=&4@*#`]4W5N9&%Y*0H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B!`<F5T=7)N(&EN="!T:&4@9&%Y(&]F('1H92!W965K("@P/5-U;F1A
M>2D*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&%Y3V97965K*"D*("`@('L*
M("`@("`@("!R971U<FX@1&%T95]#86QC.CID87E/9E=E96LH)'1H:7,M/F1A
M>2P@)'1H:7,M/FUO;G1H+"`D=&AI<RT^>65A<BD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'971S('1H92!W965K(&]F('1H92!Y96%R(&9O<B!T:&ES(&1A
M=&4*("`@("`J"B`@("`@*B!'971S('1H92!W965K(&]F('1H92!Y96%R(&9O
M<B!T:&ES(&1A=&4*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("H@0')E='5R;B!I;G0@=&AE('=E96L@;V8@=&AE('EE87(*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T5V5E:T]F665A<B@I"B`@("!["B`@("`@("`@<F5T
M=7)N($1A=&5?0V%L8SHZ=V5E:T]F665A<B@D=&AI<RT^9&%Y+"`D=&AI<RT^
M;6]N=&@L("1T:&ES+3YY96%R*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E
M=',@=&AE('%U87)T97(@;V8@=&AE('EE87(@9F]R('1H:7,@9&%T90H@("`@
M("H*("`@("`J($=E=',@=&AE('%U87)T97(@;V8@=&AE('EE87(@9F]R('1H
M:7,@9&%T90H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`
M<F5T=7)N(&EN="!T:&4@<75A<G1E<B!O9B!T:&4@>65A<B`H,2TT*0H@("`@
M("HO"B`@("!F=6YC=&EO;B!G9711=6%R=&5R3V9996%R*"D*("`@('L*("`@
M("`@("!R971U<FX@1&%T95]#86QC.CIQ=6%R=&5R3V9996%R*"1T:&ES+3YD
M87DL("1T:&ES+3YM;VYT:"P@)'1H:7,M/GEE87(I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1V5T<R!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@@9F]R
M('1H:7,@9&%T90H@("`@("H*("`@("`J($=E=',@;G5M8F5R(&]F(&1A>7,@
M:6X@=&AE(&UO;G1H(&9O<B!T:&ES(&1A=&4*("`@("`J"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("H@0')E='5R;B!I;G0@;G5M8F5R(&]F(&1A>7,@
M:6X@=&AI<R!M;VYT:`H@("`@("HO"B`@("!F=6YC=&EO;B!G971$87ES26Y-
M;VYT:"@I"B`@("!["B`@("`@("`@<F5T=7)N($1A=&5?0V%L8SHZ9&%Y<TEN
M36]N=&@H)'1H:7,M/FUO;G1H+"`D=&AI<RT^>65A<BD["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!'971S('1H92!N=6UB97(@;V8@=V5E:W,@:6X@=&AE(&UO
M;G1H(&9O<B!T:&ES(&1A=&4*("`@("`J"B`@("`@*B!'971S('1H92!N=6UB
M97(@;V8@=V5E:W,@:6X@=&AE(&UO;G1H(&9O<B!T:&ES(&1A=&4*("`@("`J
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!I;G0@;G5M
M8F5R(&]F('=E96MS(&EN('1H:7,@;6]N=&@*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T5V5E:W-);DUO;G1H*"D*("`@('L*("`@("`@("!R971U<FX@1&%T
M95]#86QC.CIW965K<TEN36]N=&@H)'1H:7,M/FUO;G1H+"`D=&AI<RT^>65A
M<BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!F=6QL(&YA;64@
M;W(@86)B<FEV:6%T960@;F%M92!O9B!T:&ES('=E96MD87D*("`@("`J"B`@
M("`@*B!'971S('1H92!F=6QL(&YA;64@;W(@86)B<FEV:6%T960@;F%M92!O
M9B!T:&ES('=E96MD87D*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("H@0'!A<F%M(&)O;VQE86X@)&%B8G(@86)B<FEV871E('1H92!N86UE
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R!N86UE(&]F('1H:7,@9&%Y"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$1A>4YA;64H)&%B8G(@/2!F86QS92P@)&QE
M;F=T:"`](#,I"B`@("!["B`@("`@("`@:68@*"1A8F)R*2!["B`@("`@("`@
M("`@(')E='5R;B!$871E7T-A;&,Z.F=E=%=E96MD87E!8F)R;F%M92@D=&AI
M<RT^9&%Y+"`D=&AI<RT^;6]N=&@L("1T:&ES+3YY96%R+"`D;&5N9W1H*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@1&%T95]#86QC
M.CIG9717965K9&%Y1G5L;&YA;64H)'1H:7,M/F1A>2P@)'1H:7,M/FUO;G1H
M+"`D=&AI<RT^>65A<BD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@1V5T<R!T:&4@9G5L;"!N86UE(&]R(&%B8G)I=FEA=&5D(&YA;64@;V8@
M=&AI<R!M;VYT:`H@("`@("H*("`@("`J($=E=',@=&AE(&9U;&P@;F%M92!O
M<B!A8F)R:79I871E9"!N86UE(&]F('1H:7,@;6]N=&@*("`@("`J"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M(&)O;VQE86X@)&%B8G(@
M86)B<FEV871E('1H92!N86UE"B`@("`@*B!`<F5T=7)N('-T<FEN9R!N86UE
M(&]F('1H:7,@;6]N=&@*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T36]N=&A.
M86UE*"1A8F)R(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"1A8F)R*2![
M"B`@("`@("`@("`@(')E='5R;B!$871E7T-A;&,Z.F=E=$UO;G1H06)B<FYA
M;64H)'1H:7,M/FUO;G1H*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!R971U<FX@1&%T95]#86QC.CIG971-;VYT:$9U;&QN86UE*"1T:&ES+3YM
M;VYT:"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1V5T(&$@
M1&%T92!O8FIE8W0@9F]R('1H92!D87D@869T97(@=&AI<R!O;F4*("`@("`J
M"B`@("`@*B!'970@82!$871E(&]B:F5C="!F;W(@=&AE(&1A>2!A9G1E<B!T
M:&ES(&]N92X*("`@("`J(%1H92!T:6UE(&]F('1H92!R971U<FYE9"!$871E
M(&]B:F5C="!I<R!T:&4@<V%M92!A<R!T:&ES('1I;64N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@;V)J96-T($1A=&4@
M1&%T92!R97!R97-E;G1I;F<@=&AE(&YE>'0@9&%Y"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=$YE>'1$87DH*0H@("`@>PH@("`@("`@("1D87D@/2!$871E
M7T-A;&,Z.FYE>'1$87DH)'1H:7,M/F1A>2P@)'1H:7,M/FUO;G1H+"`D=&AI
M<RT^>65A<BP@(B59+25M+25D(BD["B`@("`@("`@)&1A=&4@/2!S<')I;G1F
M*"(E<R`E,#)D.B4P,F0Z)3`R9"(L("1D87DL("1T:&ES+3YH;W5R+"`D=&AI
M<RT^;6EN=71E+"`D=&AI<RT^<V5C;VYD*3L*("`@("`@("`D;F5W1&%T92`]
M(&YE=R!$871E*"D["B`@("`@("`@)&YE=T1A=&4M/G-E=$1A=&4H)&1A=&4I
M.PH@("`@("`@(')E='5R;B`D;F5W1&%T93L*("`@('T*"B`@("`O*BH*("`@
M("`J($=E="!A($1A=&4@;V)J96-T(&9O<B!T:&4@9&%Y(&)E9F]R92!T:&ES
M(&]N90H@("`@("H*("`@("`J($=E="!A($1A=&4@;V)J96-T(&9O<B!T:&4@
M9&%Y(&)E9F]R92!T:&ES(&]N92X*("`@("`J(%1H92!T:6UE(&]F('1H92!R
M971U<FYE9"!$871E(&]B:F5C="!I<R!T:&4@<V%M92!A<R!T:&ES('1I;64N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@
M;V)J96-T($1A=&4@1&%T92!R97!R97-E;G1I;F<@=&AE('!R979I;W5S(&1A
M>0H@("`@("HO"B`@("!F=6YC=&EO;B!G9710<F5V1&%Y*"D*("`@('L*("`@
M("`@("`D9&%Y(#T@1&%T95]#86QC.CIP<F5V1&%Y*"1T:&ES+3YD87DL("1T
M:&ES+3YM;VYT:"P@)'1H:7,M/GEE87(L("(E62TE;2TE9"(I.PH@("`@("`@
M("1D871E(#T@<W!R:6YT9B@B)7,@)3`R9#HE,#)D.B4P,F0B+"`D9&%Y+"`D
M=&AI<RT^:&]U<BP@)'1H:7,M/FUI;G5T92P@)'1H:7,M/G-E8V]N9"D["B`@
M("`@("`@)&YE=T1A=&4@/2!N97<@1&%T92@I.PH@("`@("`@("1N97=$871E
M+3YS971$871E*"1D871E*3L*("`@("`@("!R971U<FX@)&YE=T1A=&4["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!$871E(&]B:F5C="!F;W(@=&AE
M('=E96MD87D@869T97(@=&AI<R!O;F4*("`@("`J"B`@("`@*B!'970@82!$
M871E(&]B:F5C="!F;W(@=&AE('=E96MD87D@869T97(@=&AI<R!O;F4N"B`@
M("`@*B!4:&4@=&EM92!O9B!T:&4@<F5T=7)N960@1&%T92!O8FIE8W0@:7,@
M=&AE('-A;64@87,@=&AI<R!T:6UE+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B!`<F5T=7)N(&]B:F5C="!$871E($1A=&4@<F5P<F5S
M96YT:6YG('1H92!N97AT('=E96MD87D*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T3F5X=%=E96MD87DH*0H@("`@>PH@("`@("`@("1D87D@/2!$871E7T-A
M;&,Z.FYE>'17965K9&%Y*"1T:&ES+3YD87DL("1T:&ES+3YM;VYT:"P@)'1H
M:7,M/GEE87(L("(E62TE;2TE9"(I.PH@("`@("`@("1D871E(#T@<W!R:6YT
M9B@B)7,@)3`R9#HE,#)D.B4P,F0B+"`D9&%Y+"`D=&AI<RT^:&]U<BP@)'1H
M:7,M/FUI;G5T92P@)'1H:7,M/G-E8V]N9"D["B`@("`@("`@)&YE=T1A=&4@
M/2!N97<@1&%T92@I.PH@("`@("`@("1N97=$871E+3YS971$871E*"1D871E
M*3L*("`@("`@("!R971U<FX@)&YE=T1A=&4["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!'970@82!$871E(&]B:F5C="!F;W(@=&AE('=E96MD87D@8F5F;W)E
M('1H:7,@;VYE"B`@("`@*@H@("`@("H@1V5T(&$@1&%T92!O8FIE8W0@9F]R
M('1H92!W965K9&%Y(&)E9F]R92!T:&ES(&]N92X*("`@("`J(%1H92!T:6UE
M(&]F('1H92!R971U<FYE9"!$871E(&]B:F5C="!I<R!T:&4@<V%M92!A<R!T
M:&ES('1I;64N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M($!R971U<FX@;V)J96-T($1A=&4@1&%T92!R97!R97-E;G1I;F<@=&AE('!R
M979I;W5S('=E96MD87D*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4')E=E=E
M96MD87DH*0H@("`@>PH@("`@("`@("1D87D@/2!$871E7T-A;&,Z.G!R9797
M965K9&%Y*"1T:&ES+3YD87DL("1T:&ES+3YM;VYT:"P@)'1H:7,M/GEE87(L
M("(E62TE;2TE9"(I.PH@("`@("`@("1D871E(#T@<W!R:6YT9B@B)7,@)3`R
M9#HE,#)D.B4P,F0B+"`D9&%Y+"`D=&AI<RT^:&]U<BP@)'1H:7,M/FUI;G5T
M92P@)'1H:7,M/G-E8V]N9"D["B`@("`@("`@)&YE=T1A=&4@/2!N97<@1&%T
M92@I.PH@("`@("`@("1N97=$871E+3YS971$871E*"1D871E*3L*("`@("`@
M("!R971U<FX@)&YE=T1A=&4["B`@("!]"@H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@>65A<B!F:65L9"!O9B!T:&4@9&%T92!O8FIE8W0*("`@("`J
M"B`@("`@*B!2971U<FYS('1H92!Y96%R(&9I96QD(&]F('1H92!D871E(&]B
M:F5C=`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T
M=7)N(&EN="!T:&4@>65A<@H@("`@("HO"B`@("!F=6YC=&EO;B!G971996%R
M*"D*("`@('L*("`@("`@("!R971U<FX@*&EN="DD=&AI<RT^>65A<CL*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&UO;G1H(&9I96QD(&]F
M('1H92!D871E(&]B:F5C=`H@("`@("H*("`@("`J(%)E='5R;G,@=&AE(&UO
M;G1H(&9I96QD(&]F('1H92!D871E(&]B:F5C=`H@("`@("H*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N(&EN="!T:&4@;6]N=&@*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T36]N=&@H*0H@("`@>PH@("`@("`@(')E
M='5R;B`H:6YT*21T:&ES+3YM;VYT:#L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=&AE(&1A>2!F:65L9"!O9B!T:&4@9&%T92!O8FIE8W0*("`@
M("`J"B`@("`@*B!2971U<FYS('1H92!D87D@9FEE;&0@;V8@=&AE(&1A=&4@
M;V)J96-T"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R
M971U<FX@:6YT('1H92!D87D*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&%Y
M*"D*("`@('L*("`@("`@("!R971U<FX@*&EN="DD=&AI<RT^9&%Y.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@:&]U<B!F:65L9"!O9B!T
M:&4@9&%T92!O8FIE8W0*("`@("`J"B`@("`@*B!2971U<FYS('1H92!H;W5R
M(&9I96QD(&]F('1H92!D871E(&]B:F5C=`H@("`@("H*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N(&EN="!T:&4@:&]U<@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971(;W5R*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/FAO=7(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!M:6YU=&4@9FEE;&0@;V8@=&AE(&1A=&4@;V)J96-T"B`@("`@*@H@("`@
M("H@4F5T=7)N<R!T:&4@;6EN=71E(&9I96QD(&]F('1H92!D871E(&]B:F5C
M=`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N
M(&EN="!T:&4@;6EN=71E"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$UI;G5T
M92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YM:6YU=&4["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!S96-O;F0@9FEE;&0@;V8@
M=&AE(&1A=&4@;V)J96-T"B`@("`@*@H@("`@("H@4F5T=7)N<R!T:&4@<V5C
M;VYD(&9I96QD(&]F('1H92!D871E(&]B:F5C=`H@("`@("H*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N(&EN="!T:&4@<V5C;VYD"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=%-E8V]N9"@I"B`@("!["B`@("`@("`@
M(')E='5R;B`D=&AI<RT^<V5C;VYD.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4V5T('1H92!Y96%R(&9I96QD(&]F('1H92!D871E(&]B:F5C=`H@("`@("H*
M("`@("`J(%-E="!T:&4@>65A<B!F:65L9"!O9B!T:&4@9&%T92!O8FIE8W0L
M(&EN=F%L:60@>65A<G,@*&YO="`P+3DY.3DI(&%R92!S970@=&\@,"X*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M(&EN="`D
M>2!T:&4@>65A<@H@("`@("HO"B`@("!F=6YC=&EO;B!S971996%R*"1Y*0H@
M("`@>PH@("`@("`@(&EF("@D>2`\(#`@?'P@)'D@/B`Y.3DY*2!["B`@("`@
M("`@("`@("1T:&ES+3YY96%R(#T@,#L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=&AI<RT^>65A<B`]("1Y.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E="!T:&4@;6]N=&@@9FEE;&0@;V8@=&AE(&1A=&4@
M;V)J96-T"B`@("`@*@H@("`@("H@4V5T('1H92!M;VYT:"!F:65L9"!O9B!T
M:&4@9&%T92!O8FIE8W0L(&EN=F%L:60@;6]N=&AS("AN;W0@,2TQ,BD@87)E
M('-E="!T;R`Q+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B!`<&%R86T@:6YT("1M('1H92!M;VYT:`H@("`@("HO"B`@("!F=6YC=&EO
M;B!S971-;VYT:"@D;2D*("`@('L*("`@("`@("!I9B`H)&T@/"`Q('Q\("1M
M(#X@,3(I('L*("`@("`@("`@("`@)'1H:7,M/FUO;G1H(#T@,3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^;6]N=&@@/2`D;3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&1A>2!F:65L
M9"!O9B!T:&4@9&%T92!O8FIE8W0*("`@("`J"B`@("`@*B!3970@=&AE(&1A
M>2!F:65L9"!O9B!T:&4@9&%T92!O8FIE8W0L(&EN=F%L:60@9&%Y<R`H;F]T
M(#$M,S$I(&%R92!S970@=&\@,2X*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("H@0'!A<F%M(&EN="`D9"!T:&4@9&%Y"B`@("`@*B\*("`@
M(&9U;F-T:6]N('-E=$1A>2@D9"D*("`@('L*("`@("`@("!I9B`H)&0@/B`S
M,2!\?"`D9"`\(#$I('L*("`@("`@("`@("`@)'1H:7,M/F1A>2`](#$["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/F1A>2`]("1D.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@:&]U<B!F
M:65L9"!O9B!T:&4@9&%T92!O8FIE8W0*("`@("`J"B`@("`@*B!3970@=&AE
M(&AO=7(@9FEE;&0@;V8@=&AE(&1A=&4@;V)J96-T(&EN(#(T+6AO=7(@9F]R
M;6%T+@H@("`@("H@26YV86QI9"!H;W5R<R`H;F]T(#`M,C,I(&%R92!S970@
M=&\@,"X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A
M<F%M(&EN="`D:"!T:&4@:&]U<@H@("`@("HO"B`@("!F=6YC=&EO;B!S971(
M;W5R*"1H*0H@("`@>PH@("`@("`@(&EF("@D:"`^(#(S('Q\("1H(#P@,"D@
M>PH@("`@("`@("`@("`D=&AI<RT^:&]U<B`](#`["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'1H:7,M/FAO=7(@/2`D:#L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&UI;G5T92!F:65L9"!O9B!T
M:&4@9&%T92!O8FIE8W0*("`@("`J"B`@("`@*B!3970@=&AE(&UI;G5T92!F
M:65L9"!O9B!T:&4@9&%T92!O8FIE8W0L(&EN=F%L:60@;6EN=71E<R`H;F]T
M(#`M-3DI(&%R92!S970@=&\@,"X*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("H@0'!A<F%M(&EN="`D;2!T:&4@;6EN=71E"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-E=$UI;G5T92@D;2D*("`@('L*("`@("`@("!I9B`H
M)&T@/B`U.2!\?"`D;2`\(#`I('L*("`@("`@("`@("`@)'1H:7,M/FUI;G5T
M92`](#`["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/FUI
M;G5T92`]("1M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-E
M="!T:&4@<V5C;VYD(&9I96QD(&]F('1H92!D871E(&]B:F5C=`H@("`@("H*
M("`@("`J(%-E="!T:&4@<V5C;VYD(&9I96QD(&]F('1H92!D871E(&]B:F5C
M="P@:6YV86QI9"!S96-O;F1S("AN;W0@,"TU.2D@87)E('-E="!T;R`P+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@:6YT
M("1S('1H92!S96-O;F0*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T4V5C;VYD
M*"1S*2!["B`@("`@("`@:68@*"1S(#X@-3D@?'P@)',@/"`P*2!["B`@("`@
M("`@("`@("1T:&ES+3YS96-O;F0@/2`P.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1T:&ES+3YS96-O;F0@/2`D<SL*("`@("`@("!]"B`@("!]
M"GT*"C\^"G5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$A056YI="YP
M:'``````````````````````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`Q,#`Q,"`Q,#4Q-30S,S<S,R`P,C`T-38`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RH@=FEM.B!S970@97AP
M86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A8G-T;W`]-#H@
M*B\*"B\J*@H@*B!02%`@5F5R<VEO;B`T"B`J"B`J($-O<'ER:6=H="`H8RD@
M,C`P,BTR,#`U+"!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB
M97)G;6%N;BYD93XN"B`J($%L;"!R:6=H=',@<F5S97)V960N"B`J"B`J(%)E
M9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B:6YA<GD@9F]R
M;7,L('=I=&@@;W(@=VET:&]U=`H@*B!M;V1I9FEC871I;VXL(&%R92!P97)M
M:71T960@<')O=FED960@=&AA="!T:&4@9F]L;&]W:6YG(&-O;F1I=&EO;G,*
M("H@87)E(&UE=#H*("H*("H@("`J(%)E9&ES=')I8G5T:6]N<R!O9B!S;W5R
M8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I9VAT"B`J("`@
M("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L
M;&]W:6YG(&1I<V-L86EM97(N"B`J(`H@*B`@("H@4F5D:7-T<FEB=71I;VYS
M(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y
M<FEG:'0*("H@("`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@
M86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;@H@*B`@("`@=&AE(&1O
M8W5M96YT871I;VX@86YD+V]R(&]T:&5R(&UA=&5R:6%L<R!P<F]V:61E9"!W
M:71H('1H90H@*B`@("`@9&ES=')I8G5T:6]N+@H@*@H@*B`@("H@3F5I=&AE
M<B!T:&4@;F%M92!O9B!396)A<W1I86X@0F5R9VUA;FX@;F]R('1H92!N86UE
M<R!O9B!H:7,*("H@("`@(&-O;G1R:6)U=&]R<R!M87D@8F4@=7-E9"!T;R!E
M;F1O<G-E(&]R('!R;VUO=&4@<')O9'5C=',@9&5R:79E9`H@*B`@("`@9G)O
M;2!T:&ES('-O9G1W87)E('=I=&AO=70@<W!E8VEF:6,@<')I;W(@=W)I='1E
M;B!P97)M:7-S:6]N+@H@*@H@*B!42$E3(%-/1E1705)%($E3(%!23U9)1$5$
M($)9(%1(12!#3U!94DE'2%0@2$],1$524R!!3D0@0T].5%))0E543U)3"B`J
M(")!4R!)4R(@04Y$($%.62!%6%!215-3($]2($E-4$Q)140@5T%24D%.5$E%
M4RP@24Y#3%5$24Y'+"!"550@3D]4"B`J($Q)34E4140@5$\L(%1(12!)35!,
M245$(%=!4E)!3E1)15,@3T8@34520TA!3E1!0DE,2519($%.1"!&251.15-3
M"B`J($9/4B!!(%!!4E1)0U5,05(@4%524$]312!!4D4@1$E30TQ!24U%1"X@
M24X@3D\@159%3E0@4TA!3$P@5$A%"B`J($-/4%E224=(5"!/5TY%4B!/4B!#
M3TY44DE"551/4E,@0D4@3$E!0DQ%($9/4B!!3ED@1$E214-4+"!)3D1)4D5#
M5"P*("H@24Y#241%3E1!3"P@4U!%0TE!3"P@15A%35!,05)9+"!/4B!#3TY3
M15%514Y424%,($1!34%'15,@*$E.0TQ51$E.1RP*("H@0E54($Y/5"!,24U)
M5$5$(%1/+"!04D]#55)%345.5"!/1B!354)35$E4551%($=/3T13($]2(%-%
M4E9)0T53.PH@*B!,3U-3($]&(%5312P@1$%402P@3U(@4%)/1DE44SL@3U(@
M0E5324Y%4U,@24Y415)255!424].*2!(3U=%5D52"B`J($-!55-%1"!!3D0@
M3TX@04Y9(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(15(@24X@0T].5%)!
M0U0L(%-44DE#"B`J($Q)04))3$E462P@3U(@5$]25"`H24Y#3%5$24Y'($Y%
M1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!4DE324Y'($E."B`J($%.62!705D@
M3U54($]&(%1(12!54T4@3T8@5$A)4R!33T945T%212P@159%3B!)1B!!1%9)
M4T5$($]&(%1(10H@*B!03U-324))3$E462!/1B!354-(($1!34%'12X*("H*
M("H@0&-A=&5G;W)Y("`@5&5S=&EN9PH@*B!`<&%C:V%G92`@("!02%!5;FET
M"B`J($!A=71H;W(@("`@(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T
M:6%N+6)E<F=M86YN+F1E/@H@*B!`8V]P>7)I9VAT("`R,#`R+3(P,#4@4V5B
M87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^"B`J
M($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS
M97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@
M("!#5E,Z("1)9#H@4$A056YI="YP:'`L=B`Q+C$W(#(P,#4O,3$O,3`@,#DZ
M-#<Z,3$@<V5B87-T:6%N($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P
M96%R+G!H<"YN970O<&%C:V%G92]02%!5;FET"B`J($!S:6YC92`@("`@($9I
M;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XP+C`*("HO"@IR97%U:7)E
M7V]N8V4@)U!(4%5N:70O5&5S=$-A<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=0
M2%!5;FET+U1E<W1297-U;'0N<&AP)SL*<F5Q=6ER95]O;F-E("=02%!5;FET
M+U1E<W13=6ET92YP:'`G.PH*+RHJ"B`J(%!(4%5N:70@<G5N<R!A(%1E<W13
M=6ET92!A;F0@<F5T=7)N<R!A(%1E<W1297-U;'0@;V)J96-T+@H@*@H@*B!(
M97)E(&ES(&%N(&5X86UP;&4Z"B`J"B`J(#QC;V1E/@H@*B`\/W!H<`H@*B!R
M97%U:7)E7V]N8V4@)U!(4%5N:70N<&AP)SL*("H*("H@8VQA<W,@36%T:%1E
M<W0@97AT96YD<R!02%!5;FET7U1E<W1#87-E('L*("H@("`@('9A<B`D9E9A
M;'5E,3L*("H@("`@('9A<B`D9E9A;'5E,CL*("H*("H@("`@(&9U;F-T:6]N
M($UA=&A497-T*"1N86UE*2!["B`J("`@("`@("1T:&ES+3Y02%!5;FET7U1E
M<W1#87-E*"1N86UE*3L*("H@("`@('T*("H*("H@("`@(&9U;F-T:6]N('-E
M=%5P*"D@>PH@*B`@("`@("`D=&AI<RT^9E9A;'5E,2`](#(["B`J("`@("`@
M("1T:&ES+3YF5F%L=64R(#T@,SL*("H@("`@('T*("H*("H@("`@(&9U;F-T
M:6]N('1E<W1!9&0H*2!["B`J("`@("`@("1T:&ES+3YA<W-E<G14<G5E*"1T
M:&ES+3YF5F%L=64Q("L@)'1H:7,M/F9686QU93(@/3T@-2D["B`J("`@("!]
M"B`J('T*("H*("H@)'-U:71E(#T@;F5W(%!(4%5N:71?5&5S=%-U:71E*"D[
M"B`J("1S=6ET92T^861D5&5S="AN97<@36%T:%1E<W0H)W1E<W1!9&0G*2D[
M"B`J"B`J("1R97-U;'0@/2!02%!5;FET.CIR=6XH)'-U:71E*3L*("H@<')I
M;G0@)')E<W5L="T^=&](5$U,*"D["B`J(#\^"B`J(#PO8V]D93X*("H*("H@
M06QT97)N871I=F5L>2P@>6]U(&-A;B!P87-S(&$@8VQA<W,@;F%M92!T;R!T
M:&4@4$A056YI=%]497-T4W5I=&4H*0H@*B!C;VYS=')U8W1O<B!A;F0@;&5T
M(&ET(&%U=&]M871I8V%L;'D@861D(&%L;"!M971H;V1S(&]F('1H870@8VQA
M<W,*("H@=&AA="!S=&%R="!W:71H("=T97-T)R!T;R!T:&4@<W5I=&4Z"B`J
M"B`J(#QC;V1E/@H@*B`\/W!H<`H@*B`D<W5I=&4@(#T@;F5W(%!(4%5N:71?
M5&5S=%-U:71E*"=-871H5&5S="<I.PH@*B`D<F5S=6QT(#T@4$A056YI=#HZ
M<G5N*"1S=6ET92D["B`J('!R:6YT("1R97-U;'0M/G1O2%1-3"@I.PH@*B`_
M/@H@*B`\+V-O9&4^"B`J"B`J($!C871E9V]R>2`@(%1E<W1I;F<*("H@0'!A
M8VMA9V4@("`@4$A056YI=`H@*B!`875T:&]R("`@("!396)A<W1I86X@0F5R
M9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X*("H@0&-O<'ER:6=H
M="`@,C`P,BTR,#`U(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N
M+6)E<F=M86YN+F1E/@H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+F]P96YS
M;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N
M<V4*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XS+C(*("H@0&QI;FL@("`@
M("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!(4%5N:70*("H@0'-I
M;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XP+C`*
M("HO"F-L87-S(%!(4%5N:70@>PH@("`@+RHJ"B`@("`@*B!2=6YS(&$@=&5S
M="AS=6ET92DN"B`@("`@*@H@("`@("H@0'!A<F%M("!M:7AE9`H@("`@("H@
M0')E='5R;B!02%!5;FET7U1E<W1297-U;'0*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N("9R=6XH)B1S=6ET92D@>PH@("`@
M("`@("1R97-U;'0@/2!N97<@4$A056YI=%]497-T4F5S=6QT*"D["B`@("`@
M("`@)'-U:71E+3YR=6XH)')E<W5L="D["@H@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@?0I]"@HO*@H@*B!,;V-A;"!V87)I86)L97,Z"B`J('1A8BUW
M:61T:#H@-`H@*B!C+6)A<VEC+6]F9G-E=#H@-`H@*B!C+6AA;F=I;F<M8V]M
M;65N="UE;F1E<BUP.B!N:6P*("H@16YD.@H@*B\*/SX*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]$0BYP:'``````````````````
M````````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,3$T,#,Q(#$P
M-3$U-#,S-S,S(#`Q-S0V-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`H*+RH@=FEM.B!S970@97AP86YD=&%B('1A
M8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*"B\J*@H@
M*B!$871A8F%S92!I;F1E<&5N9&5N="!Q=65R>2!I;G1E<F9A8V4*("H*("H@
M4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R
M8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@
M;&EC96YS90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L
M9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E
M8V5I=F4@82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N
M86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*("H@
M<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL
M('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@($1A
M=&%B87-E"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@(%-T:6<@
M0F%K:V5N(#QS<V)`<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@5&]M87,@5BY6
M+D-O>"`\8V]X0&ED96-N970N8V]M/@H@*B!`875T:&]R("`@("!$86YI96P@
M0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y
M.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@
M*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@1$(N<&AP+'8@,2XX,"`R,#`U+S`R
M+S$V(#`R.C$V.C`P(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T
M<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J+PH*+RHJ"B`J($]B=&%I
M;B!T:&4@4$5!4B!C;&%S<R!S;R!I="!C86X@8F4@97AT96YD960@9G)O;0H@
M*B\*<F5Q=6ER95]O;F-E("=014%2+G!H<"<["@H*+R\@>WM[(&-O;G-T86YT
M<PHO+R![>WL@97)R;W(@8V]D97,*"B\J*B-`*PH@*B!/;F4@;V8@4$5!4B!$
M0B=S('!O<G1A8FQE(&5R<F]R(&-O9&5S+@H@*B!`<V5E($1"7V-O;6UO;CHZ
M97)R;W)#;V1E*"DL($1".CIE<G)O<DUE<W-A9V4H*0H@*@H@*B![0&EN=&5R
M;F%L($EF('EO=2!A9&0@86X@97)R;W(@8V]D92!H97)E+"!M86ME('-U<F4@
M>6]U(&%L<V\@861D(&$@=&5X='5A;`H@*B!V97)S:6]N(&]F(&ET(&EN($1"
M.CIE<G)O<DUE<W-A9V4H*2Y]?0H@*B\*"B\J*@H@*B!4:&4@8V]D92!R971U
M<FYE9"!B>2!M86YY(&UE=&AO9',@=7!O;B!S=6-C97-S"B`J+PID969I;F4H
M)T1"7T]+)RP@,2D["@HO*BH*("H@56YK;W=N(&5R<F]R"B`J+PID969I;F4H
M)T1"7T524D]2)RP@+3$I.PH*+RHJ"B`J(%-Y;G1A>"!E<G)O<@H@*B\*9&5F
M:6YE*"=$0E]%4E)/4E]364Y405@G+"`M,BD["@HO*BH*("H@5')I960@=&\@
M:6YS97)T(&$@9'5P;&EC871E('9A;'5E(&EN=&\@82!P<FEM87)Y(&]R('5N
M:7%U92!I;F1E>`H@*B\*9&5F:6YE*"=$0E]%4E)/4E]#3TY35%)!24Y4)RP@
M+3,I.PH*+RHJ"B`J($%N(&ED96YT:69I97(@:6X@=&AE('%U97)Y(')E9F5R
M<R!T;R!A(&YO;BUE>&ES=&%N="!O8FIE8W0*("HO"F1E9FEN92@G1$)?15)2
M3U)?3D]47T9/54Y$)RP@+30I.PH*+RHJ"B`J(%1R:65D('1O(&-R96%T92!A
M(&1U<&QI8V%T92!O8FIE8W0*("HO"F1E9FEN92@G1$)?15)23U)?04Q214%$
M65]%6$E35%,G+"`M-2D["@HO*BH*("H@5&AE(&-U<G)E;G0@9')I=F5R(&1O
M97,@;F]T('-U<'!O<G0@=&AE(&%C=&EO;B!Y;W4@871T96UP=&5D"B`J+PID
M969I;F4H)T1"7T524D]27U5.4U504$]25$5$)RP@+38I.PH*+RHJ"B`J(%1H
M92!N=6UB97(@;V8@<&%R86UE=&5R<R!D;V5S(&YO="!M871C:"!T:&4@;G5M
M8F5R(&]F('!L86-E:&]L9&5R<PH@*B\*9&5F:6YE*"=$0E]%4E)/4E]-25--
M051#2"<L("TW*3L*"B\J*@H@*B!!(&QI=&5R86P@<W5B;6ET=&5D(&1I9"!N
M;W0@;6%T8V@@=&AE(&1A=&$@='EP92!E>'!E8W1E9`H@*B\*9&5F:6YE*"=$
M0E]%4E)/4E])3E9!3$E$)RP@+3@I.PH*+RHJ"B`J(%1H92!C=7)R96YT($1"
M35,@9&]E<R!N;W0@<W5P<&]R="!T:&4@86-T:6]N('EO=2!A='1E;7!T960*
M("HO"F1E9FEN92@G1$)?15)23U)?3D]47T-!4$%"3$4G+"`M.2D["@HO*BH*
M("H@02!L:71E<F%L('-U8FUI='1E9"!W87,@=&]O(&QO;F<@<V\@=&AE(&5N
M9"!O9B!I="!W87,@<F5M;W9E9`H@*B\*9&5F:6YE*"=$0E]%4E)/4E]44E5.
M0T%4140G+"`M,3`I.PH*+RHJ"B`J($$@;&ET97)A;"!N=6UB97(@<W5B;6ET
M=&5D(&1I9"!N;W0@;6%T8V@@=&AE(&1A=&$@='EP92!E>'!E8W1E9`H@*B\*
M9&5F:6YE*"=$0E]%4E)/4E])3E9!3$E$7TY534)%4B<L("TQ,2D["@HO*BH*
M("H@02!L:71E<F%L(&1A=&4@<W5B;6ET=&5D(&1I9"!N;W0@;6%T8V@@=&AE
M(&1A=&$@='EP92!E>'!E8W1E9`H@*B\*9&5F:6YE*"=$0E]%4E)/4E])3E9!
M3$E$7T1!5$4G+"`M,3(I.PH*+RHJ"B`J($%T=&5M<'0@=&\@9&EV:61E('-O
M;65T:&EN9R!B>2!Z97)O"B`J+PID969I;F4H)T1"7T524D]27T1)5EI%4D\G
M+"`M,3,I.PH*+RHJ"B`J($$@9&%T86)A<V4@;F5E9',@=&\@8F4@<V5L96-T
M960*("HO"F1E9FEN92@G1$)?15)23U)?3D]$0E-%3$5#5$5$)RP@+3$T*3L*
M"B\J*@H@*B!#;W5L9"!N;W0@8W)E871E('1H92!O8FIE8W0@<F5Q=65S=&5D
M"B`J+PID969I;F4H)T1"7T524D]27T-!3DY/5%]#4D5!5$4G+"`M,34I.PH*
M+RHJ"B`J($-O=6QD(&YO="!D<F]P('1H92!D871A8F%S92!R97%U97-T960@
M8F5C875S92!I="!D;V5S(&YO="!E>&ES=`H@*B\*9&5F:6YE*"=$0E]%4E)/
M4E]#04Y.3U1?1%)/4"<L("TQ-RD["@HO*BH*("H@06X@:61E;G1I9FEE<B!I
M;B!T:&4@<75E<GD@<F5F97)S('1O(&$@;F]N+65X:7-T86YT('1A8FQE"B`J
M+PID969I;F4H)T1"7T524D]27TY/4U5#2%1!0DQ%)RP@+3$X*3L*"B\J*@H@
M*B!!;B!I9&5N=&EF:65R(&EN('1H92!Q=65R>2!R969E<G,@=&\@82!N;VXM
M97AI<W1A;G0@8V]L=6UN"B`J+PID969I;F4H)T1"7T524D]27TY/4U5#2$9)
M14Q$)RP@+3$Y*3L*"B\J*@H@*B!4:&4@9&%T82!S=6)M:71T960@=&\@=&AE
M(&UE=&AO9"!W87,@:6YA<'!R;W!R:6%T90H@*B\*9&5F:6YE*"=$0E]%4E)/
M4E].145$7TU/4D5?1$%402<L("TR,"D["@HO*BH*("H@5&AE(&%T=&5M<'0@
M=&\@;&]C:R!T:&4@=&%B;&4@9F%I;&5D"B`J+PID969I;F4H)T1"7T524D]2
M7TY/5%],3T-+140G+"`M,C$I.PH*+RHJ"B`J(%1H92!N=6UB97(@;V8@8V]L
M=6UN<R!D;V5S;B=T(&UA=&-H('1H92!N=6UB97(@;V8@=F%L=65S"B`J+PID
M969I;F4H)T1"7T524D]27U9!3%5%7T-/54Y47T].7U)/5R<L("TR,BD["@HO
M*BH*("H@5&AE($133B!S=6)M:71T960@:&%S('!R;V)L96US"B`J+PID969I
M;F4H)T1"7T524D]27TE.5D%,241?1%-.)RP@+3(S*3L*"B\J*@H@*B!#;W5L
M9"!N;W0@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4*("HO"F1E9FEN92@G1$)?
M15)23U)?0T].3D5#5%]&04E,140G+"`M,C0I.PH*+RHJ"B`J(%1H92!02%`@
M97AT96YS:6]N(&YE961E9"!F;W(@=&AI<R!$0DU3(&-O=6QD(&YO="!B92!F
M;W5N9`H@*B\*9&5F:6YE*"=$0E]%4E)/4E]%6%1%3E-)3TY?3D]47T9/54Y$
M)RPM,C4I.PH*+RHJ"B`J(%1H92!P<F5S96YT('5S97(@:&%S(&EN861E<75A
M=&4@<&5R;6ES<VEO;G,@=&\@<&5R9F]R;2!T:&4@=&%S:R!R97%U97-T9`H@
M*B\*9&5F:6YE*"=$0E]%4E)/4E]!0T-%4U-?5DE/3$%424].)RP@+3(V*3L*
M"B\J*@H@*B!4:&4@9&%T86)A<V4@<F5Q=65S=&5D(&1O97,@;F]T(&5X:7-T
M"B`J+PID969I;F4H)T1"7T524D]27TY/4U5#2$1")RP@+3(W*3L*"B\J*@H@
M*B!4<FEE9"!T;R!I;G-E<G0@82!N=6QL('9A;'5E(&EN=&\@82!C;VQU;6X@
M=&AA="!D;V5S;B=T(&%L;&]W(&YU;&QS"B`J+PID969I;F4H)T1"7T524D]2
M7T-/3E-44D%)3E1?3D]47TY53$PG+"TR.2D["B\J*B-`+2HO"@H*+R\@?7U]
M"B\O('M[>R!P<F5P87)E9"!S=&%T96UE;G0M<F5L871E9`H*"B\J*B-`*PH@
M*B!)9&5N=&EF:65R<R!F;W(@=&AE('!L86-E:&]L9&5R<R!U<V5D(&EN('!R
M97!A<F5D('-T871E;65N=',N"B`J($!S964@1$)?8V]M;6]N.CIP<F5P87)E
M*"D*("HO"@HO*BH*("H@26YD:6-A=&5S(&$@<V-A;&%R("@\:V)D/C\\+VMB
M9#XI('!L86-E:&]L9&5R('=A<R!U<V5D"B`J"B`J(%%U;W1E(&%N9"!E<V-A
M<&4@=&AE('9A;'5E(&%S(&YE8V5S<V%R>2X*("HO"F1E9FEN92@G1$)?4$%2
M04U?4T-!3$%2)RP@,2D["@HO*BH*("H@26YD:6-A=&5S(&%N(&]P87%U92`H
M/&MB9#XF/"]K8F0^*2!P;&%C96AO;&1E<B!W87,@=7-E9`H@*@H@*B!4:&4@
M=F%L=64@<')E<V5N=&5D(&ES(&$@9FEL92!N86UE+B`@17AT<F%C="!T:&4@
M8V]N=&5N=',@;V8@=&AA="!F:6QE"B`J(&%N9"!P;&%C92!T:&5M(&EN('1H
M:7,@8V]L=6UN+@H@*B\*9&5F:6YE*"=$0E]005)!35]/4$%1544G+"`R*3L*
M"B\J*@H@*B!);F1I8V%T97,@82!M:7-C("@\:V)D/B$\+VMB9#XI('!L86-E
M:&]L9&5R('=A<R!U<V5D"B`J"B`J(%1H92!V86QU92!S:&]U;&0@;F]T(&)E
M('%U;W1E9"!O<B!E<V-A<&5D+@H@*B\*9&5F:6YE*"=$0E]005)!35]-25-#
M)RP@("`S*3L*+RHJ(T`M*B\*"@HO+R!]?7T*+R\@>WM[(&)I;F%R>2!D871A
M+7)E;&%T960*"@HO*BHC0"L*("H@5&AE(&1I9F9E<F5N="!W87ES(&]F(')E
M='5R;FEN9R!B:6YA<GD@9&%T82!F<F]M('%U97)I97,N"B`J+PH*+RHJ"B`J
M(%-E;F1S('1H92!F971C:&5D(&1A=&$@<W1R86EG:'0@=&AR;W5G:"!T;R!O
M=71P=70*("HO"F1E9FEN92@G1$)?0DE.34]$15]005-35$A252<L(#$I.PH*
M+RHJ"B`J($QE=',@>6]U(')E='5R;B!D871A(&%S('5S=6%L"B`J+PID969I
M;F4H)T1"7T))3DU/1$5?4D5455).)RP@,BD["@HO*BH*("H@0V]N=F5R=',@
M=&AE(&1A=&$@=&\@:&5X(&9O<FUA="!B969O<F4@<F5T=7)N:6YG(&ET"B`J
M"B`J($9O<B!E>&%M<&QE('1H92!S=')I;F<@(C$R,R(@=V]U;&0@8F5C;VUE
M("(S,3,R,S,B+@H@*B\*9&5F:6YE*"=$0E]"24Y-3T1%7T-/3E9%4E0G+"`S
M*3L*+RHJ(T`M*B\*"@HO+R!]?7T*+R\@>WM[(&9E=&-H(&UO9&5S"@H*+RHJ
M(T`K"B`J($9E=&-H($UO9&5S+@H@*B!`<V5E($1"7V-O;6UO;CHZ<V5T1F5T
M8VA-;V1E*"D*("HO"@HO*BH*("H@26YD:6-A=&5S('1H92!C=7)R96YT(&1E
M9F%U;'0@9F5T8V@@;6]D92!S:&]U;&0@8F4@=7-E9`H@*B!`<V5E($1"7V-O
M;6UO;CHZ)&9E=&-H;6]D90H@*B\*9&5F:6YE*"=$0E]&151#2$U/1$5?1$5&
M055,5"<L(#`I.PH*+RHJ"B`J($-O;'5M;B!D871A(&EN9&5X960@8GD@;G5M
M8F5R<RP@;W)D97)E9"!F<F]M(#`@86YD('5P"B`J+PID969I;F4H)T1"7T9%
M5$-(34]$15]/4D1%4D5$)RP@,2D["@HO*BH*("H@0V]L=6UN(&1A=&$@:6YD
M97AE9"!B>2!C;VQU;6X@;F%M97,*("HO"F1E9FEN92@G1$)?1D540TA-3T1%
M7T%34T]#)RP@,BD["@HO*BH*("H@0V]L=6UN(&1A=&$@87,@;V)J96-T('!R
M;W!E<G1I97,*("HO"F1E9FEN92@G1$)?1D540TA-3T1%7T]"2D5#5"<L(#,I
M.PH*+RHJ"B`J($9O<B!M=6QT:2UD:6UE;G-I;VYA;"!R97-U;'1S+"!M86ME
M('1H92!C;VQU;6X@;F%M92!T:&4@9FER<W0@;&5V96P*("H@;V8@=&AE(&%R
M<F%Y(&%N9"!P=70@=&AE(')O=R!N=6UB97(@:6X@=&AE('-E8V]N9"!L979E
M;"!O9B!T:&4@87)R87D*("H*("H@5&AI<R!I<R!F;&EP<&5D(&9R;VT@=&AE
M(&YO<FUA;"!B96AA=FEO<BP@=VAI8V@@<'5T<R!T:&4@<F]W(&YU;6)E<G,*
M("H@:6X@=&AE(&9I<G-T(&QE=F5L(&]F('1H92!A<G)A>2!A;F0@=&AE(&-O
M;'5M;B!N86UE<R!I;B!T:&4@<V5C;VYD(&QE=F5L+@H@*B\*9&5F:6YE*"=$
M0E]&151#2$U/1$5?1DQ)4%!%1"<L(#0I.PHO*BHC0"TJ+PH*+RHJ(T`K"B`J
M($]L9"!F971C:"!M;V1E<RX@($QE9G0@:&5R92!F;W(@8V]M<&%T:6)I;&ET
M>2X*("HO"F1E9FEN92@G1$)?1T5434]$15]/4D1%4D5$)RP@1$)?1D540TA-
M3T1%7T]21$52140I.PID969I;F4H)T1"7T=%5$U/1$5?05-33T,G+"`@($1"
M7T9%5$-(34]$15]!4U-/0RD["F1E9FEN92@G1$)?1T5434]$15]&3$E04$5$
M)RP@1$)?1D540TA-3T1%7T9,25!0140I.PHO*BHC0"TJ+PH*"B\O('U]?0HO
M+R![>WL@=&%B;&5);F9O*"D@)B8@875T;U!R97!A<F4H*2UR96QA=&5D"@H*
M+RHJ(T`K"B`J(%1H92!T>7!E(&]F(&EN9F]R;6%T:6]N('1O(')E='5R;B!F
M<F]M('1H92!T86)L94EN9F\H*2!M971H;V0N"B`J"B`J($)I='=I<V5D(&-O
M;G-T86YT<RP@<V\@=&AE>2!C86X@8F4@8V]M8FEN960@=7-I;F<@/&MB9#Y\
M/"]K8F0^"B`J(&%N9"!R96UO=F5D('5S:6YG(#QK8F0^7CPO:V)D/BX*("H*
M("H@0'-E92!$0E]C;VUM;VXZ.G1A8FQE26YF;R@I"B`J"B`J('M`:6YT97)N
M86P@4VEN8V4@=&AE(%1!0DQ%24Y&3R!C;VYS=&%N=',@87)E(&)I='=I<V5D
M+"!I9B!M;W)E(&]F('1H96T@87)E"B`J(&%D9&5D(&EN('1H92!F=71U<F4L
M(&UA:V4@<W5R92!T;R!A9&IU<W0@1$)?5$%"3$5)3D9/7T953$P@86-C;W)D
M:6YG;'DN?7T*("HO"F1E9FEN92@G1$)?5$%"3$5)3D9/7T]21$52)RP@,2D[
M"F1E9FEN92@G1$)?5$%"3$5)3D9/7T]21$525$%"3$4G+"`R*3L*9&5F:6YE
M*"=$0E]404),14E.1D]?1E5,3"<L(#,I.PHO*BHC0"TJ+PH*"B\J*B-`*PH@
M*B!4:&4@='EP92!O9B!Q=65R>2!T;R!C<F5A=&4@=VET:"!T:&4@875T;VUA
M=&EC('%U97)Y(&)U:6QD:6YG(&UE=&AO9',N"B`J($!S964@1$)?8V]M;6]N
M.CIA=71O4')E<&%R92@I+"!$0E]C;VUM;VXZ.F%U=&]%>&5C=71E*"D*("HO
M"F1E9FEN92@G1$)?05543U%515)97TE.4T525"<L(#$I.PID969I;F4H)T1"
M7T%55$]1545265]54$1!5$4G+"`R*3L*+RHJ(T`M*B\*"@HO+R!]?7T*+R\@
M>WM[('!O<G1A8FEL:71Y(&UO9&5S"@H*+RHJ(T`K"B`J(%!O<G1A8FEL:71Y
M($UO9&5S+@H@*@H@*B!":71W:7-E9"!C;VYS=&%N=',L('-O('1H97D@8V%N
M(&)E(&-O;6)I;F5D('5S:6YG(#QK8F0^?#PO:V)D/@H@*B!A;F0@<F5M;W9E
M9"!U<VEN9R`\:V)D/EX\+VMB9#XN"B`J"B`J($!S964@1$)?8V]M;6]N.CIS
M971/<'1I;VXH*0H@*@H@*B![0&EN=&5R;F%L(%-I;F-E('1H92!03U)404))
M3$E462!C;VYS=&%N=',@87)E(&)I='=I<V5D+"!I9B!M;W)E(&]F('1H96T@
M87)E"B`J(&%D9&5D(&EN('1H92!F=71U<F4L(&UA:V4@<W5R92!T;R!A9&IU
M<W0@1$)?4$]25$%"24Q)5%E?04Q,(&%C8V]R9&EN9VQY+GU]"B`J+PH*+RHJ
M"B`J(%1U<FX@;V9F(&%L;"!P;W)T86)I;&ET>2!F96%T=7)E<PH@*B\*9&5F
M:6YE*"=$0E]03U)404))3$E465].3TY%)RP@,"D["@HO*BH*("H@0V]N=F5R
M="!N86UE<R!O9B!T86)L97,@86YD(&9I96QD<R!T;R!L;W=E<B!C87-E"B`J
M('=H96X@=7-I;F<@=&AE(&=E="HH*2P@9F5T8V@J*"D@86YD('1A8FQE26YF
M;R@I(&UE=&AO9',*("HO"F1E9FEN92@G1$)?4$]25$%"24Q)5%E?3$]715)#
M05-%)RP@,2D["@HO*BH*("H@4FEG:'0@=')I;2!T:&4@9&%T82!O=71P=70@
M8GD@9V5T*B@I(&%N9"!F971C:"HH*0H@*B\*9&5F:6YE*"=$0E]03U)404))
M3$E465]25%))32<L(#(I.PH*+RHJ"B`J($9O<F-E(')E<&]R=&EN9R!T:&4@
M;G5M8F5R(&]F(')O=W,@9&5L971E9`H@*B\*9&5F:6YE*"=$0E]03U)404))
M3$E465]$14Q%5$5?0T]53E0G+"`T*3L*"B\J*@H@*B!%;F%B;&4@:&%C:R!T
M:&%T(&UA:V5S(&YU;5)O=W,H*2!W;W)K(&EN($]R86-L90H@*B\*9&5F:6YE
M*"=$0E]03U)404))3$E465].54U23U=3)RP@."D["@HO*BH*("H@36%K97,@
M8V5R=&%I;B!E<G)O<B!M97-S86=E<R!I;B!C97)T86EN(&1R:79E<G,@8V]M
M<&%T:6)L90H@*B!W:71H('1H;W-E(&9R;VT@;W1H97(@1$)-4R=S"B`J"B`J
M("L@;7ES<6PL(&UY<W%L:3H@(&-H86YG92!U;FEQ=64O<')I;6%R>2!K97D@
M8V]N<W1R86EN=',*("H@("!$0E]%4E)/4E]!3%)%04197T5825-44R`M/B!$
M0E]%4E)/4E]#3TY35%)!24Y4"B`J"B`J("L@;V1B8RAA8V-E<W,I.B`@35,G
M<R!/1$)#(&1R:79E<B!R97!O<G1S("=N;R!S=6-H(&9I96QD)R!A<R!C;V1E
M"B`J("`@,#<P,#$L('=H:6-H(&UE86YS("=T;V\@9F5W('!A<F%M971E<G,N
M)R`@5VAE;B!T:&ES(&]P=&EO;B!I<R!O;@H@*B`@('1H870@8V]D92!G971S
M(&UA<'!E9"!T;R!$0E]%4E)/4E].3U-50TA&245,1"X*("HO"F1E9FEN92@G
M1$)?4$]25$%"24Q)5%E?15)23U)3)RP@,38I.PH*+RHJ"B`J($-O;G9E<G0@
M;G5L;"!V86QU97,@=&\@96UP='D@<W1R:6YG<R!I;B!D871A(&]U='!U="!B
M>0H@*B!G970J*"D@86YD(&9E=&-H*B@I"B`J+PID969I;F4H)T1"7U!/4E1!
M0DE,25197TY53$Q?5$]?14U05%DG+"`S,BD["@HO*BH*("H@5'5R;B!O;B!A
M;&P@<&]R=&%B:6QI='D@9F5A='5R97,*("HO"F1E9FEN92@G1$)?4$]25$%"
M24Q)5%E?04Q,)RP@-C,I.PHO*BHC0"TJ+PH*+R\@?7U]"@H*+R\@?7U]"B\O
M('M[>R!C;&%S<R!$0@H*+RHJ"B`J($1A=&%B87-E(&EN9&5P96YD96YT('%U
M97)Y(&EN=&5R9F%C90H@*@H@*B!4:&4@;6%I;B`B1$(B(&-L87-S(&ES('-I
M;7!L>2!A(&-O;G1A:6YE<B!C;&%S<R!W:71H('-O;64@<W1A=&EC"B`J(&UE
M=&AO9',@9F]R(&-R96%T:6YG($1"(&]B:F5C=',@87,@=V5L;"!A<R!S;VUE
M('5T:6QI='D@9G5N8W1I;VYS"B`J(&-O;6UO;B!T;R!A;&P@<&%R=',@;V8@
M1$(N"B`J"B`J(%1H92!O8FIE8W0@;6]D96P@;V8@1$(@:7,@87,@9F]L;&]W
M<R`H:6YD96YT871I;VX@;65A;G,@:6YH97)I=&%N8V4I.@H@*B`\<')E/@H@
M*B!$0B`@("`@("`@("`@5&AE(&UA:6X@1$(@8VQA<W,N("!4:&ES(&ES('-I
M;7!L>2!A('5T:6QI='D@8VQA<W,*("H@("`@("`@("`@("`@('=I=&@@<V]M
M92`B<W1A=&EC(B!M971H;V1S(&9O<B!C<F5A=&EN9R!$0B!O8FIE8W1S(&%S
M"B`J("`@("`@("`@("`@("!W96QL(&%S(&-O;6UO;B!U=&EL:71Y(&9U;F-T
M:6]N<R!F;W(@;W1H97(@1$(@8VQA<W-E<RX*("H*("H@1$)?8V]M;6]N("`@
M(%1H92!B87-E(&9O<B!E86-H($1"(&EM<&QE;65N=&%T:6]N+B`@4')O=FED
M97,@9&5F875L=`H@*B!\("`@("`@("`@("`@:6UP;&5M96YT871I;VYS("AI
M;B!/3R!L:6YG;R!V:7)T=6%L(&UE=&AO9',I(&9O<@H@*B!\("`@("`@("`@
M("`@=&AE(&%C='5A;"!$0B!I;7!L96UE;G1A=&EO;G,@87,@=V5L;"!A<R!A
M(&)U;F-H(&]F"B`J('P@("`@("`@("`@("!Q=65R>2!U=&EL:71Y(&9U;F-T
M:6]N<RX*("H@?`H@*B`K+41"7VUY<W%L("`@5&AE($1"(&EM<&QE;65N=&%T
M:6]N(&9O<B!->5-13"X@($EN:&5R:71S($1"7V-O;6UO;BX*("H@("`@("`@
M("`@("`@(%=H96X@8V%L;&EN9R!$0CHZ9F%C=&]R>2!O<B!$0CHZ8V]N;F5C
M="!F;W(@37E344P*("H@("`@("`@("`@("`@(&-O;FYE8W1I;VYS+"!T:&4@
M;V)J96-T(')E='5R;F5D(&ES(&%N(&EN<W1A;F-E(&]F('1H:7,*("H@("`@
M("`@("`@("`@(&-L87-S+@H@*B`\+W!R93X*("H*("H@0&-A=&5G;W)Y("`@
M1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@4W1I
M9R!"86MK96X@/'-S8D!P:'`N;F5T/@H@*B!`875T:&]R("`@("!4;VUA<R!6
M+E8N0V]X(#QC;WA`:61E8VYE="YC;VT^"B`J($!A=71H;W(@("`@($1A;FEE
M;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@
M,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP
M"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-RXV"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B\*8VQA<W,@1$(*
M>PH@("`@+R\@>WM[("9F86-T;W)Y*"D*"B`@("`O*BH*("`@("`J($-R96%T
M92!A(&YE=R!$0B!O8FIE8W0@9F]R('1H92!S<&5C:69I960@9&%T86)A<V4@
M='EP92!B=70@9&]N)W0*("`@("`J(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@("`@=&AE(&1A
M=&%B87-E('1Y<&4@*&5G(")M>7-Q;"(I"B`@("`@*B!`<&%R86T@87)R87D@
M("1O<'1I;VYS("!A;B!A<W-O8VEA=&EV92!A<G)A>2!O9B!O<'1I;VX@;F%M
M97,@86YD('9A;'5E<PH@("`@("H*("`@("`J($!R971U<FX@;V)J96-T("!A
M(&YE=R!$0B!O8FIE8W0N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIS971/<'1I;VXH*0H@
M("`@("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D='EP92P@)&]P=&EO;G,@
M/2!F86QS92D*("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1O<'1I;VYS
M*2D@>PH@("`@("`@("`@("`D;W!T:6]N<R`](&%R<F%Y*"=P97)S:7-T96YT
M)R`]/B`D;W!T:6]N<RD["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H
M)&]P=&EO;G-;)V1E8G5G)UTI("8F("1O<'1I;VYS6R=D96)U9R==(#X](#(I
M('L*("`@("`@("`@("`@+R\@97AP;W-E('!H<"!E<G)O<G,@=VET:"!S=69F
M:6-I96YT(&1E8G5G(&QE=F5L"B`@("`@("`@("`@(&EN8VQU9&5?;VYC92`B
M1$(O>R1T>7!E?2YP:'`B.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M($!I;F-L=61E7V]N8V4@(D1"+WLD='EP97TN<&AP(CL*("`@("`@("!]"@H@
M("`@("`@("1C;&%S<VYA;64@/2`B1$)?)'MT>7!E?2(["@H@("`@("`@(&EF
M("@A8VQA<W-?97AI<W1S*"1C;&%S<VYA;64I*2!["B`@("`@("`@("`@("1T
M;7`@/2!014%2.CIR86ES945R<F]R*&YU;&PL($1"7T524D]27TY/5%]&3U5.
M1"P@;G5L;"P@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(E5N86)L92!T;R!I;F-L=61E('1H92!$0B][)'1Y<&5]+G!H<"(*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`B(&9I;&4@
M9F]R("<D9'-N)R(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=$0E]%<G)O<B<L('1R=64I.PH@("`@("`@("`@("!R971U<FX@)'1M
M<#L*("`@("`@("!]"@H@("`@("`@($`D;V)J(#TF(&YE=R`D8VQA<W-N86UE
M.PH*("`@("`@("!F;W)E86-H("@D;W!T:6]N<R!A<R`D;W!T:6]N(#T^("1V
M86QU92D@>PH@("`@("`@("`@("`D=&5S="`]("1O8FHM/G-E=$]P=&EO;B@D
M;W!T:6]N+"`D=F%L=64I.PH@("`@("`@("`@("!I9B`H1$(Z.FES17)R;W(H
M)'1E<W0I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1E<W0["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;V)J.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[("9C;VYN96-T*"D*"B`@("`O*BH*
M("`@("`J($-R96%T92!A(&YE=R!$0B!O8FIE8W0@:6YC;'5D:6YG(&$@8V]N
M;F5C=&EO;B!T;R!T:&4@<W!E8VEF:65D(&1A=&%B87-E"B`@("`@*@H@("`@
M("H@17AA;7!L92`Q+@H@("`@("H@/&-O9&4^"B`@("`@*B!R97%U:7)E7V]N
M8V4@)T1"+G!H<"<["B`@("`@*@H@("`@("H@)&1S;B`]("=P9W-Q;#HO+W5S
M97(Z<&%S<W=O<F1`:&]S="]D871A8F%S92<["B`@("`@*B`D;W!T:6]N<R`]
M(&%R<F%Y*`H@("`@("H@("`@("=D96)U9R<@("`@("`@/3X@,BP*("`@("`J
M("`@("`G<&]R=&%B:6QI='DG(#T^($1"7U!/4E1!0DE,25197T%,3"P*("`@
M("`J("D["B`@("`@*@H@("`@("H@)&1B(#TF($1".CIC;VYN96-T*"1D<VXL
M("1O<'1I;VYS*3L*("`@("`J(&EF("A014%2.CII<T5R<F]R*"1D8BDI('L*
M("`@("`J("`@("!D:64H)&1B+3YG971-97-S86=E*"DI.PH@("`@("H@?0H@
M("`@("H@/"]C;V1E/@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D9'-N
M("`@("`@=&AE('-T<FEN9R`B9&%T82!S;W5R8V4@;F%M92(@;W(@87)R87D@
M:6X@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!F;W)M870@
M<F5T=7)N960@8GD@1$(Z.G!A<G-E1%-.*"D*("`@("`J($!P87)A;2!A<G)A
M>2`D;W!T:6]N<R`@86X@87-S;V-I871I=F4@87)R87D@;V8@;W!T:6]N(&YA
M;65S(&%N9"!V86QU97,*("`@("`J"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@
M82!N97<@1$(@;V)J96-T+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M92X*("`@("`J"B`@("`@*B!`=7-E<R!$0E]D8F%S93HZ8V]N;F5C="@I+"!$
M0E]F8G-Q;#HZ8V]N;F5C="@I+"!$0E]I8F%S93HZ8V]N;F5C="@I+`H@("`@
M("H@("`@("`@1$)?:69X.CIC;VYN96-T*"DL($1"7VUS<6PZ.F-O;FYE8W0H
M*2P@1$)?;7-S<6PZ.F-O;FYE8W0H*2P*("`@("`J("`@("`@($1"7VUY<W%L
M.CIC;VYN96-T*"DL($1"7VUY<W%L:3HZ8V]N;F5C="@I+"!$0E]O8VDX.CIC
M;VYN96-T*"DL"B`@("`@*B`@("`@("!$0E]O9&)C.CIC;VYN96-T*"DL($1"
M7W!G<W%L.CIC;VYN96-T*"DL($1"7W-Q;&ET93HZ8V]N;F5C="@I+`H@("`@
M("H@("`@("`@1$)?<WEB87-E.CIC;VYN96-T*"D*("`@("`J"B`@("`@*B!`
M=7-E<R!$0CHZ<&%R<V5$4TXH*2P@1$)?8V]M;6]N.CIS971/<'1I;VXH*2P@
M4$5!4CHZ:7-%<G)O<B@I"B`@("`@*B\*("`@(&9U;F-T:6]N("9C;VYN96-T
M*"1D<VXL("1O<'1I;VYS(#T@87)R87DH*2D*("`@('L*("`@("`@("`D9'-N
M:6YF;R`]($1".CIP87)S94133B@D9'-N*3L*("`@("`@("`D='EP92`]("1D
M<VYI;F9O6R=P:'!T>7!E)UT["@H@("`@("`@(&EF("@A:7-?87)R87DH)&]P
M=&EO;G,I*2!["B`@("`@("`@("`@("\J"B`@("`@("`@("`@("`J($9O<B!B
M86-K=V%R9',@8V]M<&%T:6)I;&ET>2X@("1O<'1I;VYS('5S960@=&\@8F4@
M8F]O;&5A;BP*("`@("`@("`@("`@("H@:6YD:6-A=&EN9R!W:&5T:&5R('1H
M92!C;VYN96-T:6]N('-H;W5L9"!B92!P97)S:7-T96YT+@H@("`@("`@("`@
M("`@*B\*("`@("`@("`@("`@)&]P=&EO;G,@/2!A<G)A>2@G<&5R<VES=&5N
M="<@/3X@)&]P=&EO;G,I.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T
M*"1O<'1I;VYS6R=D96)U9R==*2`F)B`D;W!T:6]N<ULG9&5B=6<G72`^/2`R
M*2!["B`@("`@("`@("`@("\O(&5X<&]S92!P:'`@97)R;W)S('=I=&@@<W5F
M9FEC:65N="!D96)U9R!L979E;`H@("`@("`@("`@("!I;F-L=61E7V]N8V4@
M(D1"+R1[='EP97TN<&AP(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!`:6YC;'5D95]O;F-E(")$0B\D>W1Y<&5]+G!H<"(["B`@("`@("`@?0H*
M("`@("`@("`D8VQA<W-N86UE(#T@(D1"7R1[='EP97TB.PH@("`@("`@(&EF
M("@A8VQA<W-?97AI<W1S*"1C;&%S<VYA;64I*2!["B`@("`@("`@("`@("1T
M;7`@/2!014%2.CIR86ES945R<F]R*&YU;&PL($1"7T524D]27TY/5%]&3U5.
M1"P@;G5L;"P@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(E5N86)L92!T;R!I;F-L=61E('1H92!$0B][)'1Y<&5]+G!H<"(*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`B(&9I;&4@
M9F]R("<D9'-N)R(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=$0E]%<G)O<B<L('1R=64I.PH@("`@("`@("`@("!R971U<FX@)'1M
M<#L*("`@("`@("!]"@H@("`@("`@($`D;V)J(#TF(&YE=R`D8VQA<W-N86UE
M.PH*("`@("`@("!F;W)E86-H("@D;W!T:6]N<R!A<R`D;W!T:6]N(#T^("1V
M86QU92D@>PH@("`@("`@("`@("`D=&5S="`]("1O8FHM/G-E=$]P=&EO;B@D
M;W!T:6]N+"`D=F%L=64I.PH@("`@("`@("`@("!I9B`H1$(Z.FES17)R;W(H
M)'1E<W0I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1E<W0["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1E<G(@/2`D;V)J+3YC;VYN
M96-T*"1D<VYI;F9O+"`D;V)J+3YG971/<'1I;VXH)W!E<G-I<W1E;G0G*2D[
M"B`@("`@("`@:68@*$1".CII<T5R<F]R*"1E<G(I*2!["B`@("`@("`@("`@
M("1E<G(M/F%D9%5S97));F9O*"1D<VXI.PH@("`@("`@("`@("!R971U<FX@
M)&5R<CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;V)J.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(&%P:59E<G-I;VXH*0H*("`@("\J*@H@
M("`@("H@4F5T=7)N('1H92!$0B!!4$D@=F5R<VEO;@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!T:&4@1$(@05!)('9E<G-I;VX@;G5M8F5R"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&%P:59E<G-I;VXH*0H@("`@>PH@("`@("`@
M(')E='5R;B`G,2XW+C8G.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&ES17)R;W(H*0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE<R!I9B!A('9A
M<FEA8FQE(&ES(&$@1$)?17)R;W(@;V)J96-T"B`@("`@*@H@("`@("H@0'!A
M<F%M(&UI>&5D("1V86QU92`@=&AE('9A<FEA8FQE('1O(&-H96-K"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L("!W:&5T:&5R("1V86QU92!I<R!$0E]%
M<G)O<B!O8FIE8W0*("`@("`J+PH@("`@9G5N8W1I;VX@:7-%<G)O<B@D=F%L
M=64I"B`@("!["B`@("`@("`@<F5T=7)N(&ES7V$H)'9A;'5E+"`G1$)?17)R
M;W(G*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!I<T-O;FYE8W1I
M;VXH*0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE<R!I9B!A('9A;'5E(&ES
M(&$@1$)?/&1R:79E<CX@;V)J96-T"B`@("`@*@H@("`@("H@0'!A<F%M(&UI
M>&5D("1V86QU92`@=&AE('9A;'5E('1O('1E<W0*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VP@('=H971H97(@)'9A;'5E(&ES(&$@1$)?/&1R:79E<CX@
M;V)J96-T"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES0V]N;F5C=&EO;B@D=F%L
M=64I"B`@("!["B`@("`@("`@<F5T=7)N("AI<U]O8FIE8W0H)'9A;'5E*2`F
M)@H@("`@("`@("`@("`@("`@:7-?<W5B8VQA<W-?;V8H)'9A;'5E+"`G9&)?
M8V]M;6]N)RD@)B8*("`@("`@("`@("`@("`@(&UE=&AO9%]E>&ES=',H)'9A
M;'5E+"`G<VEM<&QE475E<GDG*2D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@:7--86YI<"@I"@H@("`@+RHJ"B`@("`@*B!496QL('=H971H97(@
M82!Q=65R>2!I<R!A(&1A=&$@;6%N:7!U;&%T:6]N(&]R(&1A=&$@9&5F:6YI
M=&EO;B!Q=65R>0H@("`@("H*("`@("`J($5X86UP;&5S(&]F(&1A=&$@;6%N
M:7!U;&%T:6]N('%U97)I97,@87)E($E.4T525"P@55!$051%(&%N9"!$14Q%
M5$4N"B`@("`@*B!%>&%M<&QE<R!O9B!D871A(&1E9FEN:71I;VX@<75E<FEE
M<R!A<F4@0U)%051%+"!$4D]0+"!!3%1%4BP@1U)!3E0L"B`@("`@*B!2159/
M2T4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<75E<GD@('1H92!Q
M=65R>0H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@=VAE=&AE<B`D
M<75E<GD@:7,@82!D871A(&UA;FEP=6QA=&EO;B!Q=65R>0H@("`@("HO"B`@
M("!F=6YC=&EO;B!I<TUA;FEP*"1Q=65R>2D*("`@('L*("`@("`@("`D;6%N
M:7!S(#T@)TE.4T525'Q54$1!5$5\1$5,151%?%)%4$Q!0T5\)PH@("`@("`@
M("`@("`@("`@+B`G0U)%051%?$123U!\)PH@("`@("`@("`@("`@("`@+B`G
M3$]!1"!$051!?%-%3$5#5"`N*B!)3E1/?$-/4%E\)PH@("`@("`@("`@("`@
M("`@+B`G04Q415)\1U)!3E1\4D563TM%?"<*("`@("`@("`@("`@("`@("X@
M)TQ/0TM\54Y,3T-+)SL*("`@("`@("!I9B`H<')E9U]M871C:"@G+UY<<RHB
M/R@G("X@)&UA;FEP<R`N("<I7',K+VDG+"`D<75E<GDI*2!["B`@("`@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@97)R;W)-97-S86=E
M*"D*"B`@("`O*BH*("`@("`J(%)E='5R;B!A('1E>'1U86P@97)R;W(@;65S
M<V%G92!F;W(@82!$0B!E<G)O<B!C;V1E"B`@("`@*@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)'9A;'5E("!T:&4@1$(@97)R;W(@8V]D90H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!T:&4@97)R;W(@;65S<V%G92!O<B!F86QS
M92!I9B!T:&4@97)R;W(@8V]D92!W87,*("`@("`J("`@("`@("`@("`@("`@
M("`@;F]T(')E8V]G;FEZ960*("`@("`J+PH@("`@9G5N8W1I;VX@97)R;W)-
M97-S86=E*"1V86QU92D*("`@('L*("`@("`@("!S=&%T:6,@)&5R<F]R365S
M<V%G97,["B`@("`@("`@:68@*"%I<W-E="@D97)R;W)-97-S86=E<RDI('L*
M("`@("`@("`@("`@)&5R<F]R365S<V%G97,@/2!A<G)A>2@*("`@("`@("`@
M("`@("`@($1"7T524D]2("`@("`@("`@("`@("`@("`@("`]/B`G=6YK;F]W
M;B!E<G)O<B<L"B`@("`@("`@("`@("`@("!$0E]%4E)/4E]!0T-%4U-?5DE/
M3$%424].("`@/3X@)VEN<W5F9FEC:65N="!P97)M:7-S:6]N<R<L"B`@("`@
M("`@("`@("`@("!$0E]%4E)/4E]!3%)%04197T5825-44R`@("`@/3X@)V%L
M<F5A9'D@97AI<W1S)RP*("`@("`@("`@("`@("`@($1"7T524D]27T-!3DY/
M5%]#4D5!5$4@("`@("`]/B`G8V%N(&YO="!C<F5A=&4G+`H@("`@("`@("`@
M("`@("`@1$)?15)23U)?0T%.3D]47T123U`@("`@("`@(#T^("=C86X@;F]T
M(&1R;W`G+`H@("`@("`@("`@("`@("`@1$)?15)23U)?0T].3D5#5%]&04E,
M140@("`@(#T^("=C;VYN96-T(&9A:6QE9"<L"B`@("`@("`@("`@("`@("!$
M0E]%4E)/4E]#3TY35%)!24Y4("`@("`@("`@/3X@)V-O;G-T<F%I;G0@=FEO
M;&%T:6]N)RP*("`@("`@("`@("`@("`@($1"7T524D]27T-/3E-44D%)3E1?
M3D]47TY53$P]/B`G;G5L;"!V86QU92!V:6]L871E<R!N;W0M;G5L;"!C;VYS
M=')A:6YT)RP*("`@("`@("`@("`@("`@($1"7T524D]27T1)5EI%4D\@("`@
M("`@("`@("`]/B`G9&EV:7-I;VX@8GD@>F5R;R<L"B`@("`@("`@("`@("`@
M("!$0E]%4E)/4E]%6%1%3E-)3TY?3D]47T9/54Y$/3X@)V5X=&5N<VEO;B!N
M;W0@9F]U;F0G+`H@("`@("`@("`@("`@("`@1$)?15)23U)?24Y604Q)1"`@
M("`@("`@("`@(#T^("=I;G9A;&ED)RP*("`@("`@("`@("`@("`@($1"7T52
M4D]27TE.5D%,241?1$%412`@("`@("`]/B`G:6YV86QI9"!D871E(&]R('1I
M;64G+`H@("`@("`@("`@("`@("`@1$)?15)23U)?24Y604Q)1%]$4TX@("`@
M("`@(#T^("=I;G9A;&ED($133B<L"B`@("`@("`@("`@("`@("!$0E]%4E)/
M4E])3E9!3$E$7TY534)%4B`@("`@/3X@)VEN=F%L:60@;G5M8F5R)RP*("`@
M("`@("`@("`@("`@($1"7T524D]27TU)4TU!5$-(("`@("`@("`@("`]/B`G
M;6ES;6%T8V@G+`H@("`@("`@("`@("`@("`@1$)?15)23U)?3D5%1%]-3U)%
M7T1!5$$@("`@(#T^("=I;G-U9F9I8VEE;G0@9&%T82!S=7!P;&EE9"<L"B`@
M("`@("`@("`@("`@("!$0E]%4E)/4E].3T1"4T5,14-4140@("`@("`@/3X@
M)VYO(&1A=&%B87-E('-E;&5C=&5D)RP*("`@("`@("`@("`@("`@($1"7T52
M4D]27TY/4U5#2$1"("`@("`@("`@("`]/B`G;F\@<W5C:"!D871A8F%S92<L
M"B`@("`@("`@("`@("`@("!$0E]%4E)/4E].3U-50TA&245,1"`@("`@("`@
M/3X@)VYO('-U8V@@9FEE;&0G+`H@("`@("`@("`@("`@("`@1$)?15)23U)?
M3D]354-(5$%"3$4@("`@("`@(#T^("=N;R!S=6-H('1A8FQE)RP*("`@("`@
M("`@("`@("`@($1"7T524D]27TY/5%]#05!!0DQ%("`@("`@("`]/B`G1$(@
M8F%C:V5N9"!N;W0@8V%P86)L92<L"B`@("`@("`@("`@("`@("!$0E]%4E)/
M4E].3U1?1D]53D0@("`@("`@("`@/3X@)VYO="!F;W5N9"<L"B`@("`@("`@
M("`@("`@("!$0E]%4E)/4E].3U1?3$]#2T5$("`@("`@("`@/3X@)VYO="!L
M;V-K960G+`H@("`@("`@("`@("`@("`@1$)?15)23U)?4UE.5$%8("`@("`@
M("`@("`@(#T^("=S>6YT87@@97)R;W(G+`H@("`@("`@("`@("`@("`@1$)?
M15)23U)?54Y355!03U)4140@("`@("`@(#T^("=N;W0@<W5P<&]R=&5D)RP*
M("`@("`@("`@("`@("`@($1"7T524D]27U1254Y#051%1"`@("`@("`@("`]
M/B`G=')U;F-A=&5D)RP*("`@("`@("`@("`@("`@($1"7T524D]27U9!3%5%
M7T-/54Y47T].7U)/5R`]/B`G=F%L=64@8V]U;G0@;VX@<F]W)RP*("`@("`@
M("`@("`@("`@($1"7T]+("`@("`@("`@("`@("`@("`@("`@("`]/B`G;F\@
M97)R;W(G+`H@("`@("`@("`@("`I.PH@("`@("`@('T*"B`@("`@("`@:68@
M*$1".CII<T5R<F]R*"1V86QU92DI('L*("`@("`@("`@("`@)'9A;'5E(#T@
M)'9A;'5E+3YG971#;V1E*"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M:7-S970H)&5R<F]R365S<V%G97-;)'9A;'5E72D@/R`D97)R;W)-97-S86=E
M<ULD=F%L=65="B`@("`@("`@("`@("`@("`@("`@(#H@)&5R<F]R365S<V%G
M97-;1$)?15)23U)=.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('!A
M<G-E1%-.*"D*"B`@("`O*BH*("`@("`J(%!A<G-E(&$@9&%T82!S;W5R8V4@
M;F%M90H@("`@("H*("`@("`J($%D9&ET:6]N86P@:V5Y<R!C86X@8F4@861D
M960@8GD@87!P96YD:6YG(&$@55))('%U97)Y('-T<FEN9R!T;R!T:&4*("`@
M("`J(&5N9"!O9B!T:&4@1%-.+@H@("`@("H*("`@("`J(%1H92!F;W)M870@
M;V8@=&AE('-U<'!L:65D($133B!I<R!I;B!I=',@9G5L;&5S="!F;W)M.@H@
M("`@("H@/&-O9&4^"B`@("`@*B`@<&AP='EP92AD8G-Y;G1A>"DZ+R]U<V5R
M;F%M93IP87-S=V]R9$!P<F]T;V-O;"MH;W-T<W!E8R]D871A8F%S93]O<'1I
M;VX]."9A;F]T:&5R/71R=64*("`@("`J(#PO8V]D93X*("`@("`J"B`@("`@
M*B!-;W-T('9A<FEA=&EO;G,@87)E(&%L;&]W960Z"B`@("`@*B`\8V]D93X*
M("`@("`J("!P:'!T>7!E.B\O=7-E<FYA;64Z<&%S<W=O<F1`<')O=&]C;VPK
M:&]S='-P96,Z,3$P+R]U<W(O9&)?9FEL92YD8C]M;V1E/3`V-#0*("`@("`J
M("!P:'!T>7!E.B\O=7-E<FYA;64Z<&%S<W=O<F1`:&]S='-P96,O9&%T86)A
M<V5?;F%M90H@("`@("H@('!H<'1Y<&4Z+R]U<V5R;F%M93IP87-S=V]R9$!H
M;W-T<W!E8PH@("`@("H@('!H<'1Y<&4Z+R]U<V5R;F%M94!H;W-T<W!E8PH@
M("`@("H@('!H<'1Y<&4Z+R]H;W-T<W!E8R]D871A8F%S90H@("`@("H@('!H
M<'1Y<&4Z+R]H;W-T<W!E8PH@("`@("H@('!H<'1Y<&4H9&)S>6YT87@I"B`@
M("`@*B`@<&AP='EP90H@("`@("H@/"]C;V1E/@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&1S;B!$871A(%-O=7)C92!.86UE('1O(&)E('!A<G-E
M9`H@("`@("H*("`@("`J($!R971U<FX@87)R87D@86X@87-S;V-I871I=F4@
M87)R87D@=VET:"!T:&4@9F]L;&]W:6YG(&ME>7,Z"B`@("`@*B`@*R!P:'!T
M>7!E.B`@1&%T86)A<V4@8F%C:V5N9"!U<V5D(&EN(%!(4"`H;7ES<6PL(&]D
M8F,@971C+BD*("`@("`J("`K(&1B<WEN=&%X.B!$871A8F%S92!U<V5D('=I
M=&@@<F5G87)D<R!T;R!344P@<WEN=&%X(&5T8RX*("`@("`J("`K('!R;W1O
M8V]L.B!#;VUM=6YI8V%T:6]N('!R;W1O8V]L('1O('5S92`H=&-P+"!U;FEX
M(&5T8RXI"B`@("`@*B`@*R!H;W-T<W!E8SH@2&]S="!S<&5C:69I8V%T:6]N
M("AH;W-T;F%M95LZ<&]R=%TI"B`@("`@*B`@*R!D871A8F%S93H@1&%T86)A
M<V4@=&\@=7-E(&]N('1H92!$0DU3('-E<G9E<@H@("`@("H@("L@=7-E<FYA
M;64Z(%5S97(@;F%M92!F;W(@;&]G:6X*("`@("`J("`K('!A<W-W;W)D.B!0
M87-S=V]R9"!F;W(@;&]G:6X*("`@("`J+PH@("`@9G5N8W1I;VX@<&%R<V5$
M4TXH)&1S;BD*("`@('L*("`@("`@("`D<&%R<V5D(#T@87)R87DH"B`@("`@
M("`@("`@("=P:'!T>7!E)R`@/3X@9F%L<V4L"B`@("`@("`@("`@("=D8G-Y
M;G1A>"<@/3X@9F%L<V4L"B`@("`@("`@("`@("=U<V5R;F%M92<@/3X@9F%L
M<V4L"B`@("`@("`@("`@("=P87-S=V]R9"<@/3X@9F%L<V4L"B`@("`@("`@
M("`@("=P<F]T;V-O;"<@/3X@9F%L<V4L"B`@("`@("`@("`@("=H;W-T<W!E
M8R<@/3X@9F%L<V4L"B`@("`@("`@("`@("=P;W)T)R`@("`@/3X@9F%L<V4L
M"B`@("`@("`@("`@("=S;V-K970G("`@/3X@9F%L<V4L"B`@("`@("`@("`@
M("=D871A8F%S92<@/3X@9F%L<V4L"B`@("`@("`@*3L*"B`@("`@("`@:68@
M*&ES7V%R<F%Y*"1D<VXI*2!["B`@("`@("`@("`@("1D<VX@/2!A<G)A>5]M
M97)G92@D<&%R<V5D+"`D9'-N*3L*("`@("`@("`@("`@:68@*"$D9'-N6R=D
M8G-Y;G1A>"==*2!["B`@("`@("`@("`@("`@("`D9'-N6R=D8G-Y;G1A>"==
M(#T@)&1S;ELG<&AP='EP92==.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(')E='5R;B`D9'-N.PH@("`@("`@('T*"B`@("`@("`@+R\@1FEN9"!P:'!T
M>7!E(&%N9"!D8G-Y;G1A>`H@("`@("`@(&EF("@H)'!O<R`]('-T<G!O<R@D
M9'-N+"`G.B\O)RDI("$]/2!F86QS92D@>PH@("`@("`@("`@("`D<W1R(#T@
M<W5B<W1R*"1D<VXL(#`L("1P;W,I.PH@("`@("`@("`@("`D9'-N(#T@<W5B
M<W1R*"1D<VXL("1P;W,@*R`S*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D<W1R(#T@)&1S;CL*("`@("`@("`@("`@)&1S;B`](&YU;&P["B`@
M("`@("`@?0H*("`@("`@("`O+R!'970@<&AP='EP92!A;F0@9&)S>6YT87@*
M("`@("`@("`O+R`D<W1R(#T^('!H<'1Y<&4H9&)S>6YT87@I"B`@("`@("`@
M:68@*'!R96=?;6%T8V@H)WQ>*"XK/RE<*"@N*C\I7"DD?"<L("1S='(L("1A
M<G(I*2!["B`@("`@("`@("`@("1P87)S961;)W!H<'1Y<&4G72`@/2`D87)R
M6S%=.PH@("`@("`@("`@("`D<&%R<V5D6R=D8G-Y;G1A>"==(#T@(21A<G);
M,ET@/R`D87)R6S%=(#H@)&%R<ELR73L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D<&%R<V5D6R=P:'!T>7!E)UT@(#T@)'-T<CL*("`@("`@("`@
M("`@)'!A<G-E9%LG9&)S>6YT87@G72`]("1S='(["B`@("`@("`@?0H*("`@
M("`@("!I9B`H(6-O=6YT*"1D<VXI*2!["B`@("`@("`@("`@(')E='5R;B`D
M<&%R<V5D.PH@("`@("`@('T*"B`@("`@("`@+R\@1V5T("AI9B!F;W5N9"DZ
M('5S97)N86UE(&%N9"!P87-S=V]R9`H@("`@("`@("\O("1D<VX@/3X@=7-E
M<FYA;64Z<&%S<W=O<F1`<')O=&]C;VPK:&]S='-P96,O9&%T86)A<V4*("`@
M("`@("!I9B`H*"1A="`]('-T<G)P;W,H)&1S;BPG0"<I*2`A/3T@9F%L<V4I
M('L*("`@("`@("`@("`@)'-T<B`]('-U8G-T<B@D9'-N+"`P+"`D870I.PH@
M("`@("`@("`@("`D9'-N(#T@<W5B<W1R*"1D<VXL("1A="`K(#$I.PH@("`@
M("`@("`@("!I9B`H*"1P;W,@/2!S=')P;W,H)'-T<BP@)SHG*2D@(3T](&9A
M;'-E*2!["B`@("`@("`@("`@("`@("`D<&%R<V5D6R=U<V5R;F%M92==(#T@
M<F%W=7)L9&5C;V1E*'-U8G-T<B@D<W1R+"`P+"`D<&]S*2D["B`@("`@("`@
M("`@("`@("`D<&%R<V5D6R=P87-S=V]R9"==(#T@<F%W=7)L9&5C;V1E*'-U
M8G-T<B@D<W1R+"`D<&]S("L@,2DI.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)'!A<G-E9%LG=7-E<FYA;64G72`](')A=W5R;&1E
M8V]D92@D<W1R*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M+R\@1FEN9"!P<F]T;V-O;"!A;F0@:&]S='-P96,*"B`@("`@("`@:68@*'!R
M96=?;6%T8V@H)WQ>*%M>*%TK*5PH*"XJ/RE<*2\_*"XJ/RDD?"<L("1D<VXL
M("1M871C:"DI('L*("`@("`@("`@("`@+R\@)&1S;B`]/B!P<F]T;RAP<F]T
M;U]O<'1S*2]D871A8F%S90H@("`@("`@("`@("`D<')O=&\@("`@("`@/2`D
M;6%T8VA;,5T["B`@("`@("`@("`@("1P<F]T;U]O<'1S("`]("1M871C:%LR
M72`_("1M871C:%LR72`Z(&9A;'-E.PH@("`@("`@("`@("`D9'-N("`@("`@
M("`@/2`D;6%T8VA;,UT["@H@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("\O("1D<VX@/3X@<')O=&]C;VPK:&]S='-P96,O9&%T86)A<V4@*&]L9"!F
M;W)M870I"B`@("`@("`@("`@(&EF("AS=')P;W,H)&1S;BP@)RLG*2`A/3T@
M9F%L<V4I('L*("`@("`@("`@("`@("`@(&QI<W0H)'!R;W1O+"`D9'-N*2`]
M(&5X<&QO9&4H)RLG+"`D9'-N+"`R*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!I9B`H<W1R<&]S*"1D<VXL("<O)RD@(3T](&9A;'-E*2!["B`@("`@
M("`@("`@("`@("!L:7-T*"1P<F]T;U]O<'1S+"`D9'-N*2`](&5X<&QO9&4H
M)R\G+"`D9'-N+"`R*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1P<F]T;U]O<'1S(#T@)&1S;CL*("`@("`@("`@("`@("`@("1D
M<VX@/2!N=6QL.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O
M+R!P<F]C97-S('1H92!D:69F97)E;G0@<')O=&]C;VP@;W!T:6]N<PH@("`@
M("`@("1P87)S961;)W!R;W1O8V]L)UT@/2`H(65M<'1Y*"1P<F]T;RDI(#\@
M)'!R;W1O(#H@)W1C<"<["B`@("`@("`@)'!R;W1O7V]P=',@/2!R87=U<FQD
M96-O9&4H)'!R;W1O7V]P=',I.PH@("`@("`@(&EF("@D<&%R<V5D6R=P<F]T
M;V-O;"==(#T]("=T8W`G*2!["B`@("`@("`@("`@(&EF("AS=')P;W,H)'!R
M;W1O7V]P=',L("<Z)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("!L
M:7-T*"1P87)S961;)VAO<W1S<&5C)UTL"B`@("`@("`@("`@("`@("`@("`@
M("1P87)S961;)W!O<G0G72D@/2!E>'!L;V1E*"<Z)RP@)'!R;W1O7V]P=',I
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'!A<G-E
M9%LG:&]S='-P96,G72`]("1P<F]T;U]O<'1S.PH@("`@("`@("`@("!]"B`@
M("`@("`@?2!E;'-E:68@*"1P87)S961;)W!R;W1O8V]L)UT@/3T@)W5N:7@G
M*2!["B`@("`@("`@("`@("1P87)S961;)W-O8VME="==(#T@)'!R;W1O7V]P
M=',["B`@("`@("`@?0H*("`@("`@("`O+R!'970@9&%B87-E(&EF(&%N>0H@
M("`@("`@("\O("1D<VX@/3X@9&%T86)A<V4*("`@("`@("!I9B`H)&1S;BD@
M>PH@("`@("`@("`@("!I9B`H*"1P;W,@/2!S=')P;W,H)&1S;BP@)S\G*2D@
M/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`O+R`O9&%T86)A<V4*("`@
M("`@("`@("`@("`@("1P87)S961;)V1A=&%B87-E)UT@/2!R87=U<FQD96-O
M9&4H)&1S;BD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`O+R`O9&%T86)A<V4_<&%R86TQ/79A;'5E,29P87)A;3(]=F%L=64R"B`@
M("`@("`@("`@("`@("`D<&%R<V5D6R=D871A8F%S92==(#T@<F%W=7)L9&5C
M;V1E*'-U8G-T<B@D9'-N+"`P+"`D<&]S*2D["B`@("`@("`@("`@("`@("`D
M9'-N(#T@<W5B<W1R*"1D<VXL("1P;W,@*R`Q*3L*("`@("`@("`@("`@("`@
M(&EF("AS=')P;W,H)&1S;BP@)R8G*2`A/3T@9F%L<V4I('L*("`@("`@("`@
M("`@("`@("`@("`D;W!T<R`](&5X<&QO9&4H)R8G+"`D9'-N*3L*("`@("`@
M("`@("`@("`@('T@96QS92![("\O(&1A=&%B87-E/W!A<F%M,3UV86QU93$*
M("`@("`@("`@("`@("`@("`@("`D;W!T<R`](&%R<F%Y*"1D<VXI.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&]P=',@
M87,@)&]P="D@>PH@("`@("`@("`@("`@("`@("`@(&QI<W0H)&ME>2P@)'9A
M;'5E*2`](&5X<&QO9&4H)STG+"`D;W!T*3L*("`@("`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1P87)S961;)&ME>5TI*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("\O(&1O;B=T(&%L;&]W('!A<F%M<R!O=F5R=W)I=&4*("`@
M("`@("`@("`@("`@("`@("`@("`@)'!A<G-E9%LD:V5Y72`](')A=W5R;&1E
M8V]D92@D=F%L=64I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1P87)S960["B`@("!]"@H@("`@+R\@?7U]"GT*"B\O('U]?0HO+R![
M>WL@8VQA<W,@1$)?17)R;W(*"B\J*@H@*B!$0E]%<G)O<B!I;7!L96UE;G1S
M(&$@8VQA<W,@9F]R(')E<&]R=&EN9R!P;W)T86)L92!D871A8F%S92!E<G)O
M<@H@*B!M97-S86=E<PH@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@*B!`
M<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B
M0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R
M;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("!296QE
M87-E.B`Q+C<N-@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T
M+W!A8VMA9V4O1$(*("HO"F-L87-S($1"7T5R<F]R(&5X=&5N9',@4$5!4E]%
M<G)O<@I["B`@("`O+R![>WL@8V]N<W1R=6-T;W(*"B`@("`O*BH*("`@("`J
M($1"7T5R<F]R(&-O;G-T<G5C=&]R"B`@("`@*@H@("`@("H@0'!A<F%M(&UI
M>&5D("1C;V1E("`@("`@($1"(&5R<F]R(&-O9&4L(&]R('-T<FEN9R!W:71H
M(&5R<F]R(&UE<W-A9V4*("`@("`J($!P87)A;2!I;G0@("`D;6]D92`@("`@
M("!W:&%T(")E<G)O<B!M;V1E(B!T;R!O<&5R871E(&EN"B`@("`@*B!`<&%R
M86T@:6YT("`@)&QE=F5L("`@("`@=VAA="!E<G)O<B!L979E;"!T;R!U<V4@
M9F]R("1M;V1E("8*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M4$5!4E]%4E)/4E]44DE'1T52"B`@("`@*B!`<&%R86T@;6EX960@)&1E8G5G
M:6YF;R`@861D:71I;VYA;"!D96)U9R!I;F9O+"!S=6-H(&%S('1H92!L87-T
M('%U97)Y"B`@("`@*@H@("`@("H@0'-E92!014%27T5R<F]R"B`@("`@*B\*
M("`@(&9U;F-T:6]N($1"7T5R<F]R*"1C;V1E(#T@1$)?15)23U(L("1M;V1E
M(#T@4$5!4E]%4E)/4E]215154DXL"B`@("`@("`@("`@("`@("`@("`@("`D
M;&5V96P@/2!%7U5315)?3D]424-%+"`D9&5B=6=I;F9O(#T@;G5L;"D*("`@
M('L*("`@("`@("!I9B`H:7-?:6YT*"1C;V1E*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^4$5!4E]%<G)O<B@G1$(@17)R;W(Z("<@+B!$0CHZ97)R;W)-97-S
M86=E*"1C;V1E*2P@)&-O9&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1M;V1E+"`D;&5V96PL("1D96)U9VEN9F\I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1T:&ES+3Y014%27T5R<F]R*")$0B!%<G)O<CH@
M)&-O9&4B+"!$0E]%4E)/4BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&UO9&4L("1L979E;"P@)&1E8G5G:6YF;RD["B`@("`@("`@?0H@("`@
M?0H*("`@("\O('U]?0I]"@HO+R!]?7T*+R\@>WM[(&-L87-S($1"7W)E<W5L
M=`H*+RHJ"B`J(%1H:7,@8VQA<W,@:6UP;&5M96YT<R!A('=R87!P97(@9F]R
M(&$@1$(@<F5S=6QT('-E=`H@*@H@*B!!(&YE=R!I;G-T86YC92!O9B!T:&ES
M(&-L87-S('=I;&P@8F4@<F5T=7)N960@8GD@=&AE($1"(&EM<&QE;65N=&%T
M:6]N"B`J(&%F=&5R('!R;V-E<W-I;F<@82!Q=65R>2!T:&%T(')E='5R;G,@
M9&%T82X*("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@
M("`@1$(*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T
M/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`
M;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT
M("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XW
M+C8*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E
M+T1""B`J+PIC;&%S<R!$0E]R97-U;'0*>PH@("`@+R\@>WM[('!R;W!E<G1I
M97,*"B`@("`O*BH*("`@("`J(%-H;W5L9"!R97-U;'1S(&)E(&9R965D(&%U
M=&]M871I8V%L;'D@=VAE;B!T:&5R92!A<F4@;F\@;6]R92!R;W=S/PH@("`@
M("H@0'9A<B!B;V]L96%N"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ)&]P=&EO
M;G,*("`@("`J+PH@("`@=F%R("1A=71O9G)E93L*"B`@("`O*BH*("`@("`J
M($$@<F5F97)E;F-E('1O('1H92!$0E\\9')I=F5R/B!O8FIE8W0*("`@("`J
M($!V87(@;V)J96-T"B`@("`@*B\*("`@('9A<B`D9&)H.PH*("`@("\J*@H@
M("`@("H@5&AE(&-U<G)E;G0@9&5F875L="!F971C:"!M;V1E"B`@("`@*B!`
M=F%R(&EN=&5G97(*("`@("`J($!S964@1$)?8V]M;6]N.CHD9F5T8VAM;V1E
M"B`@("`@*B\*("`@('9A<B`D9F5T8VAM;V1E.PH*("`@("\J*@H@("`@("H@
M5&AE(&YA;64@;V8@=&AE(&-L87-S(&EN=&\@=VAI8V@@<F5S=6QT<R!S:&]U
M;&0@8F4@9F5T8VAE9"!W:&5N"B`@("`@*B!$0E]&151#2$U/1$5?3T)*14-4
M(&ES(&EN(&5F9F5C=`H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B!`<V5E($1"7V-O;6UO;CHZ)&9E=&-H;6]D95]O8FIE8W1?8VQA<W,*("`@
M("`J+PH@("`@=F%R("1F971C:&UO9&5?;V)J96-T7V-L87-S.PH*("`@("\J
M*@H@("`@("H@5&AE(&YU;6)E<B!O9B!R;W=S('1O(&9E=&-H(&9R;VT@82!L
M:6UI="!Q=65R>0H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A
M<B`D;&EM:71?8V]U;G0@/2!N=6QL.PH*("`@("\J*@H@("`@("H@5&AE(')O
M=R!T;R!S=&%R="!F971C:&EN9R!F<F]M(&EN(&QI;6ET('%U97)I97,*("`@
M("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)&QI;6ET7V9R;VT@
M/2!N=6QL.PH*("`@("\J*@H@("`@("H@5&AE(&5X96-U=&4@<&%R86UE=&5R
M<R!T:&%T(&-R96%T960@=&AI<R!R97-U;'0*("`@("`J($!V87(@87)R87D*
M("`@("`J($!S:6YC92!0<F]P97)T>2!A=F%I;&%B;&4@<VEN8V4@4F5L96%S
M92`Q+C<N,`H@("`@("HO"B`@("!V87(@)'!A<F%M971E<G,["@H@("`@+RHJ
M"B`@("`@*B!4:&4@<75E<GD@<W1R:6YG('1H870@8W)E871E9"!T:&ES(')E
M<W5L=`H@("`@("H*("`@("`J($-O<&EE9"!H97)E(&EN8V%S92!I="!C:&%N
M9V5S(&EN("1D8F@L('=H:6-H(&ES(')E9F5R96YC960*("`@("`J"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("H@0'-I;F-E(%!R;W!E<G1Y(&%V86EL86)L
M92!S:6YC92!296QE87-E(#$N-RXP"B`@("`@*B\*("`@('9A<B`D<75E<GD[
M"@H@("`@+RHJ"B`@("`@*B!4:&4@<75E<GD@<F5S=6QT(')E<V]U<F-E(&ED
M(&-R96%T960@8GD@4$A0"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*
M("`@('9A<B`D<F5S=6QT.PH*("`@("\J*@H@("`@("H@5&AE('!R97-E;G0@
M<F]W(&)E:6YG(&1E86QT('=I=&@*("`@("`J($!V87(@:6YT96=E<@H@("`@
M("HO"B`@("!V87(@)')O=U]C;W5N=&5R(#T@;G5L;#L*"B`@("`O*BH*("`@
M("`J(%1H92!P<F5P87)E9"!S=&%T96UE;G0@<F5S;W5R8V4@:60@8W)E871E
M9"!B>2!02%`@:6X@)&1B:`H@("`@("H*("`@("`J(%1H:7,@<F5S;W5R8V4@
M:7,@;VYL>2!A=F%I;&%B;&4@=VAE;B!T:&4@<F5S=6QT('-E="!W87,@8W)E
M871E9"!U<VEN9PH@("`@("H@82!D<FEV97(G<R!N871I=F4@97AE8W5T92@I
M(&UE=&AO9"P@;F]T(%!%05(@1$(G<R!E;75L871E9"!O;F4N"B`@("`@*@H@
M("`@("H@0V]P:65D(&AE<F4@:6YC87-E(&ET(&-H86YG97,@:6X@)&1B:"P@
M=VAI8V@@:7,@<F5F97)E;F-E9`H@("`@("H*("`@("`J('M`:6YT97)N86P@
M($UA:6YL>2!H97)E(&)E8V%U<V4@=&AE($EN=&5R0F%S92]&:7)E8FER9"!!
M4$D@:7,@;VYL>0H@("`@("H@86)L92!T;R!R971R:65V92!D871A(&9R;VT@
M<F5S=6QT('-E=',@:68@=&AE('-T871E;6YT(&AA;F1L92!I<PH@("`@("H@
M<W1I;&P@:6X@<V-O<&4N?7T*("`@("`J"B`@("`@*B!`=F%R(')E<V]U<F-E
M"B`@("`@*B!`<VEN8V4@4')O<&5R='D@879A:6QA8FQE('-I;F-E(%)E;&5A
M<V4@,2XW+C`*("`@("`J+PH@("`@=F%R("1S=&%T96UE;G0["@H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R"@H@("`@+RHJ"B`@("`@*B!4
M:&ES(&-O;G-T<G5C=&]R('-E=',@=&AE(&]B:F5C="=S('!R;W!E<G1I97,*
M("`@("`J"B`@("`@*B!`<&%R86T@;V)J96-T("`@)B1D8F@@("`@('1H92!$
M0B!O8FIE8W0@<F5F97)E;F-E"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E
M<W5L="`@('1H92!R97-U;'0@<F5S;W5R8V4@:60*("`@("`J($!P87)A;2!A
M<G)A>2`@("`D;W!T:6]N<R`@86X@87-S;V-I871I=F4@87)R87D@=VET:"!R
M97-U;'0@;W!T:6]N<PH@("`@("H*("`@("`J($!R971U<FX@=F]I9`H@("`@
M("HO"B`@("!F=6YC=&EO;B!$0E]R97-U;'0H)B1D8F@L("1R97-U;'0L("1O
M<'1I;VYS(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^875T;V9R
M964@("`@/2`D9&)H+3YO<'1I;VYS6R=A=71O9G)E92==.PH@("`@("`@("1T
M:&ES+3YD8F@@("`@("`@("`]("8D9&)H.PH@("`@("`@("1T:&ES+3YF971C
M:&UO9&4@("`]("1D8F@M/F9E=&-H;6]D93L*("`@("`@("`D=&AI<RT^9F5T
M8VAM;V1E7V]B:F5C=%]C;&%S<R`]("1D8F@M/F9E=&-H;6]D95]O8FIE8W1?
M8VQA<W,["B`@("`@("`@)'1H:7,M/G!A<F%M971E<G,@(#T@)&1B:"T^;&%S
M=%]P87)A;65T97)S.PH@("`@("`@("1T:&ES+3YQ=65R>2`@("`@("`]("1D
M8F@M/FQA<W1?<75E<GD["B`@("`@("`@)'1H:7,M/G)E<W5L="`@("`@(#T@
M)')E<W5L=#L*("`@("`@("`D=&AI<RT^<W1A=&5M96YT("`@/2!E;7!T>2@D
M9&)H+3YL87-T7W-T;70I(#\@;G5L;"`Z("1D8F@M/FQA<W1?<W1M=#L*("`@
M("`@("!F;W)E86-H("@D;W!T:6]N<R!A<R`D:V5Y(#T^("1V86QU92D@>PH@
M("`@("`@("`@("`D=&AI<RT^<V5T3W!T:6]N*"1K97DL("1V86QU92D["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4V5T(&]P=&EO;G,@9F]R
M('1H92!$0E]R97-U;'0@;V)J96-T"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D:V5Y("`@('1H92!O<'1I;VX@=&\@<V5T"B`@("`@*B!`<&%R86T@
M;6EX960@("1V86QU92`@=&AE('9A;'5E('1O('-E="!T:&4@;W!T:6]N('1O
M"B`@("`@*@H@("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T
M:6]N('-E=$]P=&EO;B@D:V5Y+"`D=F%L=64@/2!N=6QL*0H@("`@>PH@("`@
M("`@('-W:71C:"`H)&ME>2D@>PH@("`@("`@("`@("!C87-E("=L:6UI=%]F
M<F]M)SH*("`@("`@("`@("`@("`@("1T:&ES+3YL:6UI=%]F<F]M(#T@)'9A
M;'5E.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@
M)VQI;6ET7V-O=6YT)SH*("`@("`@("`@("`@("`@("1T:&ES+3YL:6UI=%]C
M;W5N="`]("1V86QU93L*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@9F5T8VA2;W<H*0H*("`@("\J*@H@("`@("H@1F5T8V@@82!R
M;W<@;V8@9&%T82!A;F0@<F5T=7)N(&ET(&)Y(')E9F5R96YC92!I;G1O(&%N
M(&%R<F%Y"B`@("`@*@H@("`@("H@5&AE('1Y<&4@;V8@87)R87D@<F5T=7)N
M960@8V%N(&)E(&-O;G1R;VQL960@96ET:&5R(&)Y('-E='1I;F<@=&AI<PH@
M("`@("H@;65T:&]D)W,@/'9A<CXD9F5T8VAM;V1E/"]V87(^('!A<F%M971E
M<B!O<B!B>2!C:&%N9VEN9R!T:&4@9&5F875L=`H@("`@("H@9F5T8V@@;6]D
M92!S971&971C:$UO9&4H*2!B969O<F4@8V%L;&EN9R!T:&ES(&UE=&AO9"X*
M("`@("`J"B`@("`@*B!4:&5R92!A<F4@='=O(&]P=&EO;G,@9F]R('-T86YD
M87)D:7II;F<@=&AE(&EN9F]R;6%T:6]N(')E='5R;F5D"B`@("`@*B!F<F]M
M(&1A=&%B87-E<RP@96YS=7)I;F<@=&AE:7(@=F%L=65S(&%R92!C;VYS:7-T
M96YT('=H96X@8VAA;F=I;F<*("`@("`J($1"35,G<RX@(%1H97-E('!O<G1A
M8FEL:71Y(&]P=&EO;G,@8V%N(&)E('1U<FYE9"!O;B!W:&5N(&-R96%T:6YG
M(&$*("`@("`J(&YE=R!$0B!O8FIE8W0@;W(@8GD@=7-I;F<@<V5T3W!T:6]N
M*"DN"B`@("`@*@H@("`@("H@("`K(#QV87(^1$)?4$]25$%"24Q)5%E?3$]7
M15)#05-%/"]V87(^"B`@("`@*B`@("`@8V]N=F5R="!N86UE<R!O9B!F:65L
M9',@=&\@;&]W97(@8V%S90H@("`@("H*("`@("`J("`@*R`\=F%R/D1"7U!/
M4E1!0DE,25197U)44DE-/"]V87(^"B`@("`@*B`@("`@<FEG:'0@=')I;2!T
M:&4@9&%T80H@("`@("H*("`@("`J($!P87)A;2!I;G0@)&9E=&-H;6]D92`@
M=&AE(&-O;G-T86YT(&EN9&EC871I;F<@:&]W('1O(&9O<FUA="!T:&4@9&%T
M80H@("`@("H@0'!A<F%M(&EN="`D<F]W;G5M("`@("!T:&4@<F]W(&YU;6)E
M<B!T;R!F971C:"`H:6YD97@@<W1A<G1S(&%T(#`I"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@86X@87)R87D@;W(@;V)J96-T(&-O;G1A:6YI;F<@
M=&AE(')O=R=S(&1A=&$L"B`@("`@*B`@("`@("`@("`@("`@("`@3E5,3"!W
M:&5N('1H92!E;F0@;V8@=&AE(')E<W5L="!S970@:7,@<F5A8VAE9`H@("`@
M("H@("`@("`@("`@("`@("`@(&]R(&$@1$)?17)R;W(@;V)J96-T(&]N(&9A
M:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G-E=$]P=&EO
M;B@I+"!$0E]C;VUM;VXZ.G-E=$9E=&-H36]D92@I"B`@("`@*B\*("`@(&9U
M;F-T:6]N("9F971C:%)O=R@D9F5T8VAM;V1E(#T@1$)?1D540TA-3T1%7T1%
M1D%53%0L("1R;W=N=6T@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@D9F5T
M8VAM;V1E(#T]/2!$0E]&151#2$U/1$5?1$5&055,5"D@>PH@("`@("`@("`@
M("`D9F5T8VAM;V1E(#T@)'1H:7,M/F9E=&-H;6]D93L*("`@("`@("!]"B`@
M("`@("`@:68@*"1F971C:&UO9&4@/3T]($1"7T9%5$-(34]$15]/0DI%0U0I
M('L*("`@("`@("`@("`@)&9E=&-H;6]D92`]($1"7T9%5$-(34]$15]!4U-/
M0SL*("`@("`@("`@("`@)&]B:F5C=%]C;&%S<R`]("1T:&ES+3YF971C:&UO
M9&5?;V)J96-T7V-L87-S.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M
M/FQI;6ET7V9R;VT@(3T](&YU;&PI('L*("`@("`@("`@("`@:68@*"1T:&ES
M+3YR;W=?8V]U;G1E<B`]/3T@;G5L;"D@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/G)O=U]C;W5N=&5R(#T@)'1H:7,M/FQI;6ET7V9R;VT["B`@("`@("`@
M("`@("`@("`O+R!3:VEP(')O=W,*("`@("`@("`@("`@("`@(&EF("@D=&AI
M<RT^9&)H+3YF96%T=7)E<ULG;&EM:70G72`]/3T@9F%L<V4I('L*("`@("`@
M("`@("`@("`@("`@("`D:2`](#`["B`@("`@("`@("`@("`@("`@("`@=VAI
M;&4@*"1I*RL@/"`D=&AI<RT^;&EM:71?9G)O;2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^9&)H+3YF971C:$EN=&\H)'1H:7,M/G)E<W5L
M="P@)&%R<BP@)&9E=&-H;6]D92D["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("@D=&AI<RT^<F]W7V-O=6YT97(@/CT@*"1T:&ES+3YL:6UI=%]F<F]M("L@
M)'1H:7,M/FQI;6ET7V-O=6YT*2D*("`@("`@("`@("`@>PH@("`@("`@("`@
M("`@("`@:68@*"1T:&ES+3YA=71O9G)E92D@>PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YF<F5E*"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`D=&UP(#T@;G5L;#L*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&UP.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D=&AI<RT^9&)H
M+3YF96%T=7)E<ULG;&EM:70G72`]/3T@)V5M=6QA=&4G*2!["B`@("`@("`@
M("`@("`@("`D<F]W;G5M(#T@)'1H:7,M/G)O=U]C;W5N=&5R.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1T:&ES+3YR;W=?8V]U;G1E<BLK.PH@("`@
M("`@('T*("`@("`@("`D<F5S(#T@)'1H:7,M/F1B:"T^9F5T8VA);G1O*"1T
M:&ES+3YR97-U;'0L("1A<G(L("1F971C:&UO9&4L("1R;W=N=6TI.PH@("`@
M("`@(&EF("@D<F5S(#T]/2!$0E]/2RD@>PH@("`@("`@("`@("!I9B`H:7-S
M970H)&]B:F5C=%]C;&%S<RDI('L*("`@("`@("`@("`@("`@("\O(%1H92!D
M969A=6QT(&UO9&4@:7,@<W!E8VEF:65D(&EN('1H90H@("`@("`@("`@("`@
M("`@+R\@1$)?8V]M;6]N.CIF971C:&UO9&5?;V)J96-T7V-L87-S('!R;W!E
M<G1Y"B`@("`@("`@("`@("`@("!I9B`H)&]B:F5C=%]C;&%S<R`]/2`G<W1D
M0VQA<W,G*2!["B`@("`@("`@("`@("`@("`@("`@)&%R<B`]("AO8FIE8W0I
M("1A<G(["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("1A<G(@/2`F;F5W("1O8FIE8W1?8VQA<W,H)&%R<BD["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N
M("1A<G(["B`@("`@("`@?0H@("`@("`@(&EF("@D<F5S(#T](&YU;&P@)B8@
M)'1H:7,M/F%U=&]F<F5E*2!["B`@("`@("`@("`@("1T:&ES+3YF<F5E*"D[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5S.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&9E=&-H26YT;R@I"@H@("`@+RHJ"B`@("`@*B!&
M971C:"!A(')O=R!O9B!D871A(&EN=&\@86X@87)R87D@=VAI8V@@:7,@<&%S
M<V5D(&)Y(')E9F5R96YC90H@("`@("H*("`@("`J(%1H92!T>7!E(&]F(&%R
M<F%Y(')E='5R;F5D(&-A;B!B92!C;VYT<F]L;&5D(&5I=&AE<B!B>2!S971T
M:6YG('1H:7,*("`@("`J(&UE=&AO9"=S(#QV87(^)&9E=&-H;6]D93PO=F%R
M/B!P87)A;65T97(@;W(@8GD@8VAA;F=I;F<@=&AE(&1E9F%U;'0*("`@("`J
M(&9E=&-H(&UO9&4@<V5T1F5T8VA-;V1E*"D@8F5F;W)E(&-A;&QI;F<@=&AI
M<R!M971H;V0N"B`@("`@*@H@("`@("H@5&AE<F4@87)E('1W;R!O<'1I;VYS
M(&9O<B!S=&%N9&%R9&EZ:6YG('1H92!I;F9O<FUA=&EO;B!R971U<FYE9`H@
M("`@("H@9G)O;2!D871A8F%S97,L(&5N<W5R:6YG('1H96ER('9A;'5E<R!A
M<F4@8V]N<VES=&5N="!W:&5N(&-H86YG:6YG"B`@("`@*B!$0DU3)W,N("!4
M:&5S92!P;W)T86)I;&ET>2!O<'1I;VYS(&-A;B!B92!T=7)N960@;VX@=VAE
M;B!C<F5A=&EN9R!A"B`@("`@*B!N97<@1$(@;V)J96-T(&]R(&)Y('5S:6YG
M('-E=$]P=&EO;B@I+@H@("`@("H*("`@("`J("`@*R`\=F%R/D1"7U!/4E1!
M0DE,25197TQ/5T520T%313PO=F%R/@H@("`@("H@("`@(&-O;G9E<G0@;F%M
M97,@;V8@9FEE;&1S('1O(&QO=V5R(&-A<V4*("`@("`J"B`@("`@*B`@("L@
M/'9A<CY$0E]03U)404))3$E465]25%))33PO=F%R/@H@("`@("H@("`@(')I
M9VAT('1R:6T@=&AE(&1A=&$*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)B1A<G(@("`@("`@=&AE('9A<FEA8FQE('=H97)E('1H92!D871A('-H;W5L
M9"!B92!P;&%C960*("`@("`J($!P87)A;2!I;G0@("`D9F5T8VAM;V1E("!T
M:&4@8V]N<W1A;G0@:6YD:6-A=&EN9R!H;W<@=&\@9F]R;6%T('1H92!D871A
M"B`@("`@*B!`<&%R86T@:6YT("`@)')O=VYU;2`@("`@=&AE(')O=R!N=6UB
M97(@=&\@9F5T8V@@*&EN9&5X('-T87)T<R!A="`P*0H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@($1"7T]+(&EF(&$@<F]W(&ES('!R;V-E<W-E9"P@
M3E5,3"!W:&5N('1H92!E;F0@;V8@=&AE"B`@("`@*B`@("`@("`@("`@("`@
M("`@<F5S=6QT('-E="!I<R!R96%C:&5D(&]R(&$@1$)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ<V5T
M3W!T:6]N*"DL($1"7V-O;6UO;CHZ<V5T1F5T8VA-;V1E*"D*("`@("`J+PH@
M("`@9G5N8W1I;VX@9F5T8VA);G1O*"8D87)R+"`D9F5T8VAM;V1E(#T@1$)?
M1D540TA-3T1%7T1%1D%53%0L("1R;W=N=6T@/2!N=6QL*0H@("`@>PH@("`@
M("`@(&EF("@D9F5T8VAM;V1E(#T]/2!$0E]&151#2$U/1$5?1$5&055,5"D@
M>PH@("`@("`@("`@("`D9F5T8VAM;V1E(#T@)'1H:7,M/F9E=&-H;6]D93L*
M("`@("`@("!]"B`@("`@("`@:68@*"1F971C:&UO9&4@/3T]($1"7T9%5$-(
M34]$15]/0DI%0U0I('L*("`@("`@("`@("`@)&9E=&-H;6]D92`]($1"7T9%
M5$-(34]$15]!4U-/0SL*("`@("`@("`@("`@)&]B:F5C=%]C;&%S<R`]("1T
M:&ES+3YF971C:&UO9&5?;V)J96-T7V-L87-S.PH@("`@("`@('T*("`@("`@
M("!I9B`H)'1H:7,M/FQI;6ET7V9R;VT@(3T](&YU;&PI('L*("`@("`@("`@
M("`@:68@*"1T:&ES+3YR;W=?8V]U;G1E<B`]/3T@;G5L;"D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/G)O=U]C;W5N=&5R(#T@)'1H:7,M/FQI;6ET7V9R
M;VT["B`@("`@("`@("`@("`@("`O+R!3:VEP(')O=W,*("`@("`@("`@("`@
M("`@(&EF("@D=&AI<RT^9&)H+3YF96%T=7)E<ULG;&EM:70G72`]/3T@9F%L
M<V4I('L*("`@("`@("`@("`@("`@("`@("`D:2`](#`["B`@("`@("`@("`@
M("`@("`@("`@=VAI;&4@*"1I*RL@/"`D=&AI<RT^;&EM:71?9G)O;2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9&)H+3YF971C:$EN=&\H
M)'1H:7,M/G)E<W5L="P@)&%R<BP@)&9E=&-H;6]D92D["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&EF("@D=&AI<RT^<F]W7V-O=6YT97(@/CT@*`H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YL:6UI=%]F<F]M("L@)'1H:7,M/FQI;6ET
M7V-O=6YT*2D*("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@:68@*"1T
M:&ES+3YA=71O9G)E92D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YF
M<F5E*"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!R971U
M<FX@;G5L;#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)'1H:7,M
M/F1B:"T^9F5A='5R97-;)VQI;6ET)UT@/3T]("=E;75L871E)RD@>PH@("`@
M("`@("`@("`@("`@)')O=VYU;2`]("1T:&ES+3YR;W=?8V]U;G1E<CL*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M/G)O=U]C;W5N=&5R*RL[
M"B`@("`@("`@?0H@("`@("`@("1R97,@/2`D=&AI<RT^9&)H+3YF971C:$EN
M=&\H)'1H:7,M/G)E<W5L="P@)&%R<BP@)&9E=&-H;6]D92P@)')O=VYU;2D[
M"B`@("`@("`@:68@*"1R97,@/3T]($1"7T]+*2!["B`@("`@("`@("`@(&EF
M("AI<W-E="@D;V)J96-T7V-L87-S*2D@>PH@("`@("`@("`@("`@("`@+R\@
M9&5F875L="!M;V1E('-P96-I9FEE9"!I;B!T:&4*("`@("`@("`@("`@("`@
M("\O($1"7V-O;6UO;CHZ9F5T8VAM;V1E7V]B:F5C=%]C;&%S<R!P<F]P97)T
M>0H@("`@("`@("`@("`@("`@:68@*"1O8FIE8W1?8VQA<W,@/3T@)W-T9$-L
M87-S)RD@>PH@("`@("`@("`@("`@("`@("`@("1A<G(@/2`H;V)J96-T*2`D
M87)R.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`D87)R(#T@;F5W("1O8FIE8W1?8VQA<W,H)&%R<BD["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N($1"
M7T]+.PH@("`@("`@('T*("`@("`@("!I9B`H)')E<R`]/2!N=6QL("8F("1T
M:&ES+3YA=71O9G)E92D@>PH@("`@("`@("`@("`D=&AI<RT^9G)E92@I.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)')E<SL*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!N=6U#;VQS*"D*"B`@("`O*BH*("`@("`J($=E="!T
M:&4@=&AE(&YU;6)E<B!O9B!C;VQU;6YS(&EN(&$@<F5S=6QT('-E=`H@("`@
M("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F(&-O;'5M;G,N
M("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!N=6U#;VQS*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/F1B:"T^;G5M0V]L<R@D=&AI<RT^<F5S=6QT*3L*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!N=6U2;W=S*"D*"B`@("`O*BH*("`@("`J($=E="!T
M:&4@;G5M8F5R(&]F(')O=W,@:6X@82!R97-U;'0@<V5T"B`@("`@*@H@("`@
M("H@0')E='5R;B!I;G0@('1H92!N=6UB97(@;V8@<F]W<RX@($$@1$)?17)R
M;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&YU
M;5)O=W,H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^9&)H+3YF96%T=7)E
M<ULG;G5M<F]W<R==(#T]/2`G96UU;&%T92<*("`@("`@("`@("`@)B8@)'1H
M:7,M/F1B:"T^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,
M25197TY535)/5U,I"B`@("`@("`@>PH@("`@("`@("`@("!I9B`H)'1H:7,M
M/F1B:"T^9F5A='5R97-;)W!R97!A<F4G72D@>PH@("`@("`@("`@("`@("`@
M)')E<R`]("1T:&ES+3YD8F@M/G%U97)Y*"1T:&ES+3YQ=65R>2P@)'1H:7,M
M/G!A<F%M971E<G,I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)')E<R`]("1T:&ES+3YD8F@M/G%U97)Y*"1T:&ES+3YQ=65R>2D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*$1".CII<T5R<F]R*"1R
M97,I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D:2`](#`["B`@("`@("`@("`@('=H:6QE("@D
M<F5S+3YF971C:$EN=&\H)'1M<"P@1$)?1D540TA-3T1%7T]21$52140I*2![
M"B`@("`@("`@("`@("`@("`D:2LK.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(')E='5R;B`D:3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/F1B:"T^;G5M4F]W<R@D=&AI<RT^<F5S=6QT*3L*("`@
M("`@("!]"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;F5X=%)E<W5L
M="@I"@H@("`@+RHJ"B`@("`@*B!'970@=&AE(&YE>'0@<F5S=6QT(&EF(&$@
M8F%T8V@@;V8@<75E<FEE<R!W87,@97AE8W5T960*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VP@('1R=64@:68@82!N97<@<F5S=6QT(&ES(&%V86EL86)L
M92!O<B!F86QS92!I9B!N;W0*("`@("`J+PH@("`@9G5N8W1I;VX@;F5X=%)E
M<W5L="@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YD8F@M/FYE>'12
M97-U;'0H)'1H:7,M/G)E<W5L="D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@9G)E92@I"@H@("`@+RHJ"B`@("`@*B!&<F5E<R!T:&4@<F5S;W5R
M8V5S(&%L;&]C871E9"!F;W(@=&AI<R!R97-U;'0@<V5T"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L("!T<G5E(&]N('-U8V-E<W,N("!!($1"7T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!F<F5E
M*"D*("`@('L*("`@("`@("`D97)R(#T@)'1H:7,M/F1B:"T^9G)E95)E<W5L
M="@D=&AI<RT^<F5S=6QT*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)&5R
M<BDI('L*("`@("`@("`@("`@<F5T=7)N("1E<G(["B`@("`@("`@?0H@("`@
M("`@("1T:&ES+3YR97-U;'0@/2!F86QS93L*("`@("`@("`D=&AI<RT^<W1A
M=&5M96YT(#T@9F%L<V4["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@=&%B;&5);F9O*"D*"B`@("`O*BH*("`@
M("`J($!S964@1$)?8V]M;6]N.CIT86)L94EN9F\H*0H@("`@("H@0&1E<')E
M8V%T960@365T:&]D(&1E<')E8V%T960@<V]M92!T:6UE(&)E9F]R92!296QE
M87-E(#$N,@H@("`@("HO"B`@("!F=6YC=&EO;B!T86)L94EN9F\H)&UO9&4@
M/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]S=')I;F<H)&UO9&4I*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9&)H+3YR86ES945R<F]R*$1"
M7T524D]27TY%141?34]215]$051!*3L*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N("1T:&ES+3YD8F@M/G1A8FQE26YF;R@D=&AI<RP@)&UO9&4I.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&=E=%%U97)Y*"D*"B`@("`O*BH*
M("`@("`J($1E=&5R;6EN92!T:&4@<75E<GD@<W1R:6YG('1H870@8W)E871E
M9"!T:&ES(')E<W5L=`H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T
M:&4@<75E<GD@<W1R:6YG"B`@("`@*@H@("`@("H@0'-I;F-E($UE=&AO9"!A
M=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C<N,`H@("`@("HO"B`@("!F=6YC
M=&EO;B!G9711=65R>2@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YQ
M=65R>3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G9712;W=#;W5N
M=&5R*"D*"B`@("`O*BH*("`@("`J(%1E;&QS('=H:6-H(')O=R!N=6UB97(@
M:7,@8W5R<F5N=&QY(&)E:6YG('!R;V-E<W-E9`H@("`@("H*("`@("`J($!R
M971U<FX@:6YT96=E<B`@=&AE(&-U<G)E;G0@<F]W(&)E:6YG(&QO;VME9"!A
M="X@(%-T87)T<R!A="`Q+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9712;W=#
M;W5N=&5R*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G)O=U]C;W5N
M=&5R.PH@("`@?0H*("`@("\O('U]?0I]"@HO+R!]?7T*+R\@>WM[(&-L87-S
M($1"7W)O=PH*+RHJ"B`J(%!%05(@1$(@4F]W($]B:F5C=`H@*@H@*B!4:&4@
M;V)J96-T(&-O;G1A:6YS(&$@<F]W(&]F(&1A=&$@9G)O;2!A(')E<W5L="!S
M970N("!%86-H(&-O;'5M;B=S(&1A=&$*("H@:7,@<&QA8V5D(&EN(&$@<')O
M<&5R='D@;F%M960@9F]R('1H92!C;VQU;6XN"B`J"B`J($!C871E9V]R>2`@
M($1A=&%B87-E"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@(%-T
M:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR
M,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V
M97)S:6]N("`@(%)E;&5A<V4Z(#$N-RXV"B`J($!L:6YK("`@("`@(&AT='`Z
M+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B!`<V5E("`@("`@("!$0E]C
M;VUM;VXZ.G-E=$9E=&-H36]D92@I"B`J+PIC;&%S<R!$0E]R;W<*>PH@("`@
M+R\@>WM[(&-O;G-T<G5C=&]R"@H@("`@+RHJ"B`@("`@*B!4:&4@8V]N<W1R
M=6-T;W(@<&QA8V5S(&$@<F]W)W,@9&%T82!I;G1O('!R;W!E<G1I97,@;V8@
M=&AI<R!O8FIE8W0*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@('1H92!A
M<G)A>2!C;VYT86EN:6YG('1H92!R;W<G<R!D871A"B`@("`@*@H@("`@("H@
M0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N($1"7W)O=R@F)&%R
M<BD*("`@('L*("`@("`@("!F;W)E86-H("@D87)R(&%S("1K97D@/3X@)'9A
M;'5E*2!["B`@("`@("`@("`@("1T:&ES+3XD:V5Y(#T@)B1A<G);)&ME>5T[
M"B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0I]"@HO+R!]?7T*"B\J"B`J
M($QO8V%L('9A<FEA8FQE<SH*("H@=&%B+7=I9'1H.B`T"B`J(&,M8F%S:6,M
M;V9F<V5T.B`T"B`J($5N9#H*("HO"@H_/@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]3>7-T96TN<&AP````````````````````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#0V-S8T(#$P-3$U-#,S-S,S(#`R,#4P-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`T*+RHJ
M#0H@*B!&:6QE+T1I<F5C=&]R>2!M86YI<'5L871I;VX-"B`J#0H@*B!02%`@
M=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E
M(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI
M8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E
M8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U
M;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@
M*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA
M:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@
M("!P96%R#0H@*B!`<&%C:V%G92`@("!3>7-T96T-"B`J($!A=71H;W(@("`@
M(%1O;6%S(%8N5BY#;W@@/&-O>$!I9&5C;F5T+F-O;3X-"B`J($!C;W!Y<FEG
M:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS
M92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!3>7-T96TN<&AP+'8@
M,2XU,R`R,#`V+S`Q+S`V(#`T.C0W.C,V(&-E;&QO9R!%>'`@)`T*("H@0&QI
M;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J
M($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,"XQ
M#0H@*B\-"@T*+RHJ#0H@*B!B87-E(&-L87-S#0H@*B\-"G)E<75I<F5?;VYC
M92`G4$5!4BYP:'`G.PT*<F5Q=6ER95]O;F-E("=#;VYS;VQE+T=E=&]P="YP
M:'`G.PT*#0HD1TQ/0D%,4ULG7U-Y<W1E;5]T96UP7V9I;&5S)UT@/2!A<G)A
M>2@I.PT*#0HO*BH-"BH@4WES=&5M(&]F9F5R<R!C<F]S<R!P;&%T=&9O<FT@
M8V]M<&%T:6)L92!S>7-T96T@9G5N8W1I;VYS#0HJ#0HJ(%-T871I8R!F=6YC
M=&EO;G,@9F]R(&1I9F9E<F5N="!O<&5R871I;VYS+B!3:&]U;&0@=V]R:R!U
M;F1E<@T**B!5;FEX(&%N9"!7:6YD;W=S+B!4:&4@;F%M97,@86YD('5S86=E
M(&AA<R!B965N('1A:V5N(&9R;VT@:71S(')E<W!E8W1I=F5L>0T**B!'3E4@
M8V]M;6%N9',N(%1H92!F=6YC=&EO;G,@=VEL;"!R971U<FX@*&)O;VPI(&9A
M;'-E(&]N(&5R<F]R(&%N9"!W:6QL#0HJ('1R:6=G97(@=&AE(&5R<F]R('=I
M=&@@=&AE(%!(4"!T<FEG9V5R7V5R<F]R*"D@9G5N8W1I;VX@*'EO=2!C86X@
M<VEL96YC90T**B!T:&4@97)R;W(@8GD@<')E9FEX:6YG(&$@)T`G('-I9VX@
M869T97(@=&AE(&9U;F-T:6]N(&-A;&PI+@T**@T**B!$;V-U;65N=&%T:6]N
M(&]N('1H:7,@8VQA<W,@>6]U(&-A;B!F:6YD(&EN.@T**B!H='1P.B\O<&5A
M<BYP:'`N;F5T+VUA;G5A;"\-"BH-"BH@17AA;7!L92!U<V%G93H-"BH@:68@
M*"%`4WES=&5M.CIR;2@G+7(@9FEL93$@9&ER,2<I*2![#0HJ("`@('!R:6YT
M(")C;W5L9"!N;W0@9&5L971E(&9I;&4Q(&]R(&1I<C$B.PT**B!]#0HJ#0HJ
M($EN(&-A<V4@>6]U(&YE960@=&\@=&\@<&%S<R!F:6QE(&YA;65S('=I=&@@
M<W!A8V5S+`T**B!P87-S('1H92!P87)A;7,@87,@86X@87)R87DZ#0HJ#0HJ
M(%-Y<W1E;3HZ<FTH87)R87DH)RUR)RP@)&9I;&4Q+"`D9&ER,2DI.PT**@T*
M*B!`8V%T96=O<GD@("!P96%R#0HJ($!P86-K86=E("`@(%-Y<W1E;0T**B!`
M875T:&]R("`@("!4;VUA<R!6+E8N($-O>"`\8V]X0&ED96-N970N8V]M/@T*
M*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T**B!`;&EC
M96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!0
M2%`@3&EC96YS92`S+C`-"BH@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-
M"BH@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%
M05(-"BH@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A
M<V4@,"XQ#0HJ+PT*8VQA<W,@4WES=&5M#0I[#0H@("`@+RHJ#0H@("`@*B!R
M971U<FYS('1H92!C;VUM86YD;&EN92!A<F=U;65N=',@;V8@82!F=6YC=&EO
M;@T*("`@("H-"B`@("`J($!P87)A;2`@("!S=')I;F<@("1A<F=V("`@("`@
M("`@("!T:&4@8V]M;6%N9&QI;F4-"B`@("`J($!P87)A;2`@("!S=')I;F<@
M("1S:&]R=%]O<'1I;VYS("!T:&4@86QL;W=E9"!O<'1I;VX@<VAO<G0M=&%G
M<PT*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)&QO;F=?;W!T:6]N<R`@('1H
M92!A;&QO=V5D(&]P=&EO;B!L;VYG+71A9W,-"B`@("`J($!R971U<FX@("!A
M<G)A>2`@('1H92!G:79E;B!O<'1I;VYS(&%N9"!T:&5R92!V86QU97,-"B`@
M("`J($!A8V-E<W,@<')I=F%T90T*("`@("HO#0H@("`@9G5N8W1I;VX@7W!A
M<G-E07)G<R@D87)G=BP@)'-H;W)T7V]P=&EO;G,L("1L;VYG7V]P=&EO;G,@
M/2!N=6QL*0T*("`@('L-"B`@("`@("`@:68@*"%I<U]A<G)A>2@D87)G=BD@
M)B8@)&%R9W8@(3T](&YU;&PI('L-"B`@("`@("`@("`@("1A<F=V(#T@<')E
M9U]S<&QI="@G+UQS*R\G+"`D87)G=BP@+3$L(%!214=?4U!,251?3D]?14U0
M5%DI.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!#;VYS;VQE7T=E=&]P
M=#HZ9V5T;W!T,B@D87)G=BP@)'-H;W)T7V]P=&EO;G,I.PT*("`@('T-"@T*
M("`@("\J*@T*("`@("H@3W5T<'5T(&5R<F]R<R!W:71H(%!(4"!T<FEG9V5R
M7V5R<F]R*"DN(%EO=2!C86X@<VEL96YC92!T:&4@97)R;W)S#0H@("`@*B!W
M:71H('!R969I>&EN9R!A(")`(B!S:6=N('1O('1H92!F=6YC=&EO;B!C86QL
M.B!`4WES=&5M.CIM:V1I<B@N+BD[#0H@("`@*@T*("`@("H@0'!A<F%M(&UI
M>&5D("1E<G)O<B!A(%!%05(@97)R;W(@;W(@82!S=')I;F<@=VET:"!T:&4@
M97)R;W(@;65S<V%G90T*("`@("H@0')E='5R;B!B;V]L(&9A;'-E#0H@("`@
M*B!`86-C97-S('!R:79A=&4-"B`@("`J+PT*("`@(&9U;F-T:6]N(')A:7-E
M17)R;W(H)&5R<F]R*0T*("`@('L-"B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&5R<F]R*2D@>PT*("`@("`@("`@("`@)&5R<F]R(#T@)&5R<F]R+3YG
M971-97-S86=E*"D[#0H@("`@("`@('T-"B`@("`@("`@=')I9V=E<E]E<G)O
M<B@D97)R;W(L($5?55-%4E]705).24Y'*3L-"B`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@("H@0W)E871E<R!A(&YE<W1E
M9"!A<G)A>2!R97!R97-E;G1I;F<@=&AE('-T<G5C='5R92!O9B!A(&1I<F5C
M=&]R>0T*("`@("H-"B`@("`J(%-Y<W1E;3HZ7V1I<E1O4W1R=6-T*"=D:7(Q
M)RP@,"D@/3X-"B`@("`J("`@07)R87D-"B`@("`J("`@("@-"B`@("`J("`@
M(%MD:7)S72`]/B!!<G)A>0T*("`@("H@("`@("`@("@-"B`@("`J("`@("`@
M("`@("`@6S!=(#T^(&1I<C$-"B`@("`J("`@("`@("`I#0H@("`@*@T*("`@
M("H@("`@6V9I;&5S72`]/B!!<G)A>0T*("`@("H@("`@("`@("@-"B`@("`J
M("`@("`@("`@("`@6S!=(#T^(&1I<C$O9FEL93(-"B`@("`J("`@("`@("`@
M("`@6S%=(#T^(&1I<C$O9FEL93,-"B`@("`J("`@("`@("`I#0H@("`@*B`@
M("`I#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D<U!A=&@@("`@("!.86UE
M(&]F('1H92!D:7)E8W1O<GD-"B`@("`J($!P87)A;2`@("!I;G1E9V5R("1M
M87AI;G-T("`@(&UA>"X@9&5E<"!O9B!T:&4@;&]O:W5P#0H@("`@*B!`<&%R
M86T@("`@:6YT96=E<B`D86MT:6YS="`@("!S=&%R=&EN9R!D965P(&]F('1H
M92!L;V]K=7`-"B`@("`J($!R971U<FX@("!A<G)A>2`@('1H92!S=')U8W1U
M<F4@;V8@=&AE(&1I<@T*("`@("H@0&%C8V5S<R`@('!R:79A=&4-"B`@("`J
M+PT*#0H@("`@9G5N8W1I;VX@7V1I<E1O4W1R=6-T*"1S4&%T:"P@)&UA>&EN
M<W0L("1A:W1I;G-T(#T@,"D-"B`@("![#0H@("`@("`@("1S=')U8W0@/2!A
M<G)A>2@G9&ER<R<@/3X@87)R87DH*2P@)V9I;&5S)R`]/B!A<G)A>2@I*3L-
M"B`@("`@("`@:68@*"@D9&ER(#T@0&]P96YD:7(H)'-0871H*2D@/3T](&9A
M;'-E*2![#0H@("`@("`@("`@("!3>7-T96TZ.G)A:7-E17)R;W(H(D-O=6QD
M(&YO="!O<&5N(&1I<B`D<U!A=&@B*3L-"B`@("`@("`@("`@(')E='5R;B`D
M<W1R=6-T.R`O+R!86%@@8V]U;&0@;F]T(&]P96X@97)R;W(-"B`@("`@("`@
M?0T*("`@("`@("`D<W1R=6-T6R=D:7)S)UU;72`]("1S4&%T:"`](')E86QP
M871H*"1S4&%T:"D[("\O(%A86"!D;VXG="!A9&0@:68@)RXG(&]R("<N+B<@
M/PT*("`@("`@("`D;&ES="`](&%R<F%Y*"D[#0H@("`@("`@('=H:6QE("AF
M86QS92`A/3T@*"1F:6QE(#T@<F5A9&1I<B@D9&ER*2DI('L-"B`@("`@("`@
M("`@(&EF("@D9FEL92`A/2`G+B<@)B8@)&9I;&4@(3T@)RXN)RD@>PT*("`@
M("`@("`@("`@("`@("1L:7-T6UT@/2`D9FEL93L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("!C;&]S961I<B@D9&ER*3L-"B`@("`@("`@
M<V]R="@D;&ES="D[#0H@("`@("`@(&EF("@D86MT:6YS="`\("1M87AI;G-T
M('Q\("1M87AI;G-T(#T](#`I('L-"B`@("`@("`@("`@(&9O<F5A8V@H)&QI
M<W0@87,@)'9A;"D@>PT*("`@("`@("`@("`@("`@("1P871H(#T@)'-0871H
M("X@1$E214-43U)97U-%4$%2051/4B`N("1V86P[#0H@("`@("`@("`@("`@
M("`@:68@*&ES7V1I<B@D<&%T:"D@)B8@(6ES7VQI;FLH)'!A=&@I*2![#0H@
M("`@("`@("`@("`@("`@("`@("1T;7`@/2!3>7-T96TZ.E]D:7)4;U-T<G5C
M="@D<&%T:"P@)&UA>&EN<W0L("1A:W1I;G-T*S$I.PT*("`@("`@("`@("`@
M("`@("`@("`D<W1R=6-T(#T@87)R87E?;65R9V5?<F5C=7)S:79E*"1T;7`L
M("1S=')U8W0I.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@("`@("1S=')U8W1;)V9I;&5S)UU;72`]("1P871H.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!R971U<FX@)'-T<G5C=#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`J
M($-R96%T97,@82!N97-T960@87)R87D@<F5P<F5S96YT:6YG('1H92!S=')U
M8W1U<F4@;V8@82!D:7)E8W1O<GD@86YD(&9I;&5S#0H@("`@*@T*("`@("H@
M0'!A<F%M("`@(&%R<F%Y("1F:6QE<R!!<G)A>2!L:7-T:6YG(&9I;&5S(&%N
M9"!D:7)S#0H@("`@*B!`<F5T=7)N("`@87)R87D-"B`@("`J($!S964@4WES
M=&5M.CI?9&ER5&]3=')U8W0H*0T*("`@("HO#0H@("`@9G5N8W1I;VX@7VUU
M;'1I<&QE5&]3=')U8W0H)&9I;&5S*0T*("`@('L-"B`@("`@("`@)'-T<G5C
M="`](&%R<F%Y*"=D:7)S)R`]/B!A<G)A>2@I+"`G9FEL97,G(#T^(&%R<F%Y
M*"DI.PT*("`@("`@("!S971T>7!E*"1F:6QE<RP@)V%R<F%Y)RD[#0H@("`@
M("`@(&9O<F5A8V@@*"1F:6QE<R!A<R`D9FEL92D@>PT*("`@("`@("`@("`@
M:68@*&ES7V1I<B@D9FEL92D@)B8@(6ES7VQI;FLH)&9I;&4I*2![#0H@("`@
M("`@("`@("`@("`@)'1M<"`](%-Y<W1E;3HZ7V1I<E1O4W1R=6-T*"1F:6QE
M+"`P*3L-"B`@("`@("`@("`@("`@("`D<W1R=6-T(#T@87)R87E?;65R9V5?
M<F5C=7)S:79E*"1T;7`L("1S=')U8W0I.PT*("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`D<W1R=6-T6R=F:6QE<R==6UT@/2`D9FEL
M93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M)'-T<G5C=#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`J(%1H92!R;2!C;VUM
M86YD(&9O<B!R96UO=FEN9R!F:6QE<RX-"B`@("`J(%-U<'!O<G1S(&UU;'1I
M<&QE(&9I;&5S(&%N9"!D:7)S(&%N9"!A;'-O(')E8W5R<VEV92!D96QE=&5S
M#0H@("`@*@T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)&%R9W,@("!T:&4@
M87)G=6UE;G1S(&9O<B!R;0T*("`@("H@0')E='5R;B`@(&UI>&5D("`@4$5!
M4E]%<G)O<B!O<B!T<G5E(&9O<B!S=6-C97-S#0H@("`@*B!`86-C97-S("`@
M<'5B;&EC#0H@("`@*B\-"B`@("!F=6YC=&EO;B!R;2@D87)G<RD-"B`@("![
M#0H@("`@("`@("1O<'1S(#T@4WES=&5M.CI?<&%R<V5!<F=S*"1A<F=S+"`G
M<F8G*3L@+R\@(F8B(&1O(&YO=&AI;F<@8G5T(&QI:V4@:70@.BTI#0H@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1O<'1S*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N(%-Y<W1E;3HZ<F%I<V5%<G)O<B@D;W!T<RD[#0H@("`@("`@('T-
M"B`@("`@("`@9F]R96%C:"@D;W!T<ULP72!A<R`D;W!T*2![#0H@("`@("`@
M("`@("!I9B`H)&]P=%LP72`]/2`G<B<I('L-"B`@("`@("`@("`@("`@("`D
M9&]?<F5C=7)S:79E(#T@=')U93L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("`D<F5T(#T@=')U93L-"B`@("`@("`@:68@*&ES<V5T*"1D
M;U]R96-U<G-I=F4I*2![#0H@("`@("`@("`@("`D<W1R=6-T(#T@4WES=&5M
M.CI?;75L=&EP;&54;U-T<G5C="@D;W!T<ULQ72D[#0H@("`@("`@("`@("!F
M;W)E86-H*"1S=')U8W1;)V9I;&5S)UT@87,@)&9I;&4I('L-"B`@("`@("`@
M("`@("`@("!I9B`H(4!U;FQI;FLH)&9I;&4I*2![#0H@("`@("`@("`@("`@
M("`@("`@("1R970@/2!F86QS93L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!F;W)E86-H*"1S=')U8W1;)V1I<G,G
M72!A<R`D9&ER*2![#0H@("`@("`@("`@("`@("`@:68@*"%`<FUD:7(H)&1I
M<BDI('L-"B`@("`@("`@("`@("`@("`@("`@)')E="`](&9A;'-E.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1O<'1S6S%=(&%S("1F:6QE*2![
M#0H@("`@("`@("`@("`@("`@)&1E;&5T92`]("AI<U]D:7(H)&9I;&4I*2`_
M("=R;61I<B<@.B`G=6YL:6YK)SL-"B`@("`@("`@("`@("`@("!I9B`H(4`D
M9&5L971E*"1F:6QE*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<F5T(#T@
M9F%L<V4[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("H@36%K92!D:7)E8W1O<FEE<RX-"B`@("`J#0H@("`@*B!4:&4@
M+7`@;W!T:6]N('=I;&P@8W)E871E('!A<F5N="!D:7)E8W1O<FEE<PT*("`@
M("H@0'!A<F%M("`@('-T<FEN9R`@)&%R9W,@("`@=&AE(&YA;64@;V8@=&AE
M(&1I<F5C=&]R*'E\:65S*2!T;R!C<F5A=&4-"B`@("`J($!R971U<FX@("!B
M;V]L("`@(%1R=64@9F]R('-U8V-E<W,-"B`@("`J($!A8V-E<W,@("!P=6)L
M:6,-"B`@("`J+PT*("`@(&9U;F-T:6]N(&UK1&ER*"1A<F=S*0T*("`@('L-
M"B`@("`@("`@)&]P=',@/2!3>7-T96TZ.E]P87)S94%R9W,H)&%R9W,L("=P
M;3HG*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&]P=',I*2![#0H@
M("`@("`@("`@("!R971U<FX@4WES=&5M.CIR86ES945R<F]R*"1O<'1S*3L-
M"B`@("`@("`@?0T*("`@("`@("`D;6]D92`](#`W-S<[("\O(&1E9F%U;'0@
M;6]D90T*("`@("`@("!F;W)E86-H*"1O<'1S6S!=(&%S("1O<'0I('L-"B`@
M("`@("`@("`@(&EF("@D;W!T6S!=(#T]("=P)RD@>PT*("`@("`@("`@("`@
M("`@("1C<F5A=&5?<&%R96YT<R`]('1R=64[#0H@("`@("`@("`@("!](&5L
M<V5I9B@D;W!T6S!=(#T]("=M)RD@>PT*("`@("`@("`@("`@("`@("\O(&EF
M('1H92!M;V1E(&ES(&-L96%R;'D@86X@;V-T86P@;G5M8F5R("AS=&%R=',@
M=VET:"`P*0T*("`@("`@("`@("`@("`@("\O(&-O;G9E<G0@:70@=&\@9&5C
M:6UA;`T*("`@("`@("`@("`@("`@(&EF("AS=')L96XH)&]P=%LQ72D@)B8@
M)&]P=%LQ77LP?2`]/2`G,"<I('L-"B`@("`@("`@("`@("`@("`@("`@)&]P
M=%LQ72`](&]C=&1E8R@D;W!T6S%=*3L-"B`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`O+R!C;VYV97)T('1O(&EN=`T*
M("`@("`@("`@("`@("`@("`@("`D;W!T6S%=("L](#`[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("1M;V1E(#T@)&]P=%LQ73L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D<F5T(#T@=')U93L-
M"B`@("`@("`@:68@*&ES<V5T*"1C<F5A=&5?<&%R96YT<RDI('L-"B`@("`@
M("`@("`@(&9O<F5A8V@H)&]P='-;,5T@87,@)&1I<BD@>PT*("`@("`@("`@
M("`@("`@("1D:7)S=&%C:R`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@
M=VAI;&4@*"%`:7-?9&ER*"1D:7(I("8F("1D:7(@(3T@1$E214-43U)97U-%
M4$%2051/4BD@>PT*("`@("`@("`@("`@("`@("`@("!A<G)A>5]U;G-H:69T
M*"1D:7)S=&%C:RP@)&1I<BD[#0H@("`@("`@("`@("`@("`@("`@("1D:7(@
M/2!D:7)N86UE*"1D:7(I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!W:&EL92`H)&YE=V1I<B`](&%R<F%Y7W-H:69T*"1D:7)S=&%C
M:RDI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<U]W<FET96%B;&4H
M9&ER;F%M92@D;F5W9&ER*2DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1R970@/2!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M(&EF("@A;6MD:7(H)&YE=V1I<BP@)&UO9&4I*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D<F5T(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("!F;W)E86-H*"1O<'1S6S%=(&%S("1D
M:7(I('L-"B`@("`@("`@("`@("`@("!I9B`H(4!I<U]D:7(H)&1I<BD@)B8@
M(6UK9&ER*"1D:7(L("1M;V1E*2D@>PT*("`@("`@("`@("`@("`@("`@("`D
M<F5T(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*
M("`@("\J*@T*("`@("H@0V]N8V%T96YA=&4@9FEL97,-"B`@("`J#0H@("`@
M*B!5<V%G93H-"B`@("`J(#$I("1V87(@/2!3>7-T96TZ.F-A="@G<V%M<&QE
M+G1X="!T97-T+G1X="<I.PT*("`@("H@,BD@4WES=&5M.CIC870H)W-A;7!L
M92YT>'0@=&5S="YT>'0@/B!F:6YA;"YT>'0G*3L-"B`@("`J(#,I(%-Y<W1E
M;3HZ8V%T*"=S86UP;&4N='AT('1E<W0N='AT(#X^(&9I;F%L+G1X="<I.PT*
M("`@("H-"B`@("`J($YO=&4Z(&%S('1H92!C;&%S<R!U<V4@9F]P96XL('5R
M;',@<VAO=6QD('=O<FL@86QS;R`H=&5S="!T:&%T*0T*("`@("H-"B`@("`J
M($!P87)A;2`@("!S=')I;F<@("1A<F=S("`@=&AE(&%R9W5M96YT<PT*("`@
M("H@0')E='5R;B`@(&)O;VQE86X@=')U92!O;B!S=6-C97-S#0H@("`@*B!`
M86-C97-S("`@<'5B;&EC#0H@("`@*B\-"B`@("!F=6YC=&EO;B`F8V%T*"1A
M<F=S*0T*("`@('L-"B`@("`@("`@)')E="`](&YU;&P[#0H@("`@("`@("1F
M:6QE<R`](&%R<F%Y*"D[#0H@("`@("`@(&EF("@A:7-?87)R87DH)&%R9W,I
M*2![#0H@("`@("`@("`@("`D87)G<R`]('!R96=?<W!L:70H)R]<<RLO)RP@
M)&%R9W,L("TQ+"!04D5'7U-03$E47TY/7T5-4%19*3L-"B`@("`@("`@?0T*
M("`@("`@("!F;W(H)&D],#L@)&D@/"!C;W5N="@D87)G<RD[("1I*RLI('L-
M"B`@("`@("`@("`@(&EF("@D87)G<ULD:5T@/3T@)SXG*2![#0H@("`@("`@
M("`@("`@("`@)&UO9&4@/2`G=V(G.PT*("`@("`@("`@("`@("`@("1O=71P
M=71F:6QE(#T@)&%R9W-;)&DK,5T[#0H@("`@("`@("`@("`@("`@8G)E86L[
M#0H@("`@("`@("`@("!](&5L<V5I9B`H)&%R9W-;)&E=(#T]("<^/B<I('L-
M"B`@("`@("`@("`@("`@("`D;6]D92`]("=A8BLG.PT*("`@("`@("`@("`@
M("`@("1O=71P=71F:6QE(#T@)&%R9W-;)&DK,5T[#0H@("`@("`@("`@("`@
M("`@8G)E86L[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("1F:6QE<UM=(#T@)&%R9W-;)&E=.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D;6]D92DI('L-"B`@("`@("`@
M("`@(&EF("@A)&]U='!U=&9D(#T@9F]P96XH)&]U='!U=&9I;&4L("1M;V1E
M*2D@>PT*("`@("`@("`@("`@("`@("1E<G(@/2!3>7-T96TZ.G)A:7-E17)R
M;W(H(D-O=6QD(&YO="!O<&5N("1O=71P=71F:6QE(BD[#0H@("`@("`@("`@
M("`@("`@<F5T=7)N("1E<G([#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`D<F5T(#T@=')U93L-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D
M9FEL97,@87,@)&9I;&4I('L-"B`@("`@("`@("`@(&EF("@A)&9D(#T@9F]P
M96XH)&9I;&4L("=R)RDI('L-"B`@("`@("`@("`@("`@("!3>7-T96TZ.G)A
M:7-E17)R;W(H(D-O=6QD(&YO="!O<&5N("1F:6QE(BD[#0H@("`@("`@("`@
M("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!W
M:&EL92`H)&-O;G0@/2!F<F5A9"@D9F0L(#(P-#@I*2![#0H@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1O=71P=71F9"DI('L-"B`@("`@("`@("`@("`@
M("`@("`@9G=R:71E*"1O=71P=71F9"P@)&-O;G0I.PT*("`@("`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1R970@+CT@)&-O
M;G0[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@9F-L;W-E*"1F9"D[#0H@("`@("`@('T-"B`@("`@("`@:68@*$!I
M<U]R97-O=7)C92@D;W5T<'5T9F0I*2![#0H@("`@("`@("`@("!F8VQO<V4H
M)&]U='!U=&9D*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)')E=#L-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`J($-R96%T97,@=&5M<&]R87)Y(&9I
M;&5S(&]R(&1I<F5C=&]R:65S+B!4:&ES(&9U;F-T:6]N('=I;&P@<F5M;W9E
M#0H@("`@*B!T:&4@8W)E871E9"!F:6QE<R!W:&5N('1H92!S8W)I<'1S(&9I
M;FES:"!I=',@97AE8W5T:6]N+@T*("`@("H-"B`@("`J(%5S86=E.@T*("`@
M("H@("`Q*2`D=&5M<&9I;&4@/2!3>7-T96TZ.FUK=&5M<"@B<')E9FEX(BD[
M#0H@("`@*B`@(#(I("1T96UP9&ER("`](%-Y<W1E;3HZ;6MT96UP*"(M9"!P
M<F5F:7@B*3L-"B`@("`J("`@,RD@)'1E;7!F:6QE(#T@4WES=&5M.CIM:W1E
M;7`H*3L-"B`@("`J("`@-"D@)'1E;7!F:6QE(#T@4WES=&5M.CIM:W1E;7`H
M(BUT("]V87(O=&UP('!R969I>"(I.PT*("`@("H-"B`@("`J('!R969I>"`M
M/B!4:&4@<W1R:6YG('1H870@=VEL;"!B92!P<F5P96YD960@=&\@=&AE('1E
M;7`@;F%M90T*("`@("H@("`@("`@("`@("AD969A=6QT<R!T;R`B=&UP(BDN
M#0H@("`@*B`M9"`@("`@+3X@02!T96UP;W)A<GD@9&ER('=I;&P@8F4@8W)E
M871E9"!I;G-T96%D(&]F(&$@9FEL92X-"B`@("`J("UT("`@("`M/B!4:&4@
M=&%R9V5T(&1I<B!W:&5R92!T:&4@=&5M<&]R87)Y("AF:6QE?&1I<BD@=VEL
M;"!B92!C<F5A=&5D+B!)9@T*("`@("H@("`@("`@("`@('1H:7,@<&%R86T@
M:7,@;6ES<VEN9R!B>2!D969A=6QT('1H92!E;G8@=F%R<R!435`@;VX@5VEN
M9&]W<R!O<@T*("`@("H@("`@("`@("`@(%1-4$1)4B!I;B!5;FEX('=I;&P@
M8F4@=7-E9"X@268@=&AE<V4@=F%R<R!A<F4@86QS;R!M:7-S:6YG#0H@("`@
M*B`@("`@("`@("`@8SI<=VEN9&]W<UQT96UP(&]R("]T;7`@=VEL;"!B92!U
M<V5D+@T*("`@("H-"B`@("`J($!P87)A;2`@('-T<FEN9R`@)&%R9W,@(%1H
M92!A<F=U;65N=',-"B`@("`J($!R971U<FX@(&UI>&5D("`@=&AE(&9U;&P@
M<&%T:"!O9B!T:&4@8W)E871E9"`H9FEL97QD:7(I(&]R(&9A;'-E#0H@("`@
M*B!`<V5E(%-Y<W1E;3HZ=&UP9&ER*"D-"B`@("`J($!A8V-E<W,@('!U8FQI
M8PT*("`@("HO#0H@("`@9G5N8W1I;VX@;6MT96UP*"1A<F=S(#T@;G5L;"D-
M"B`@("![#0H@("`@("`@('-T871I8R`D9FER<W1?=&EM92`]('1R=64[#0H@
M("`@("`@("1O<'1S(#T@4WES=&5M.CI?<&%R<V5!<F=S*"1A<F=S+"`G=#ID
M)RD[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1O<'1S*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N(%-Y<W1E;3HZ<F%I<V5%<G)O<B@D;W!T<RD[#0H@
M("`@("`@('T-"B`@("`@("`@9F]R96%C:"@D;W!T<ULP72!A<R`D;W!T*2![
M#0H@("`@("`@("`@("!I9B@D;W!T6S!=(#T]("=D)RD@>PT*("`@("`@("`@
M("`@("`@("1T;7!?:7-?9&ER(#T@=')U93L-"B`@("`@("`@("`@('T@96QS
M96EF*"1O<'1;,%T@/3T@)W0G*2![#0H@("`@("`@("`@("`@("`@)'1M<&1I
M<B`]("1O<'1;,5T[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@)'!R969I>"`]("AI<W-E="@D;W!T<ULQ75LP72DI(#\@)&]P='-;,5U;
M,%T@.B`G=&UP)SL-"B`@("`@("`@:68@*"%I<W-E="@D=&UP9&ER*2D@>PT*
M("`@("`@("`@("`@)'1M<&1I<B`](%-Y<W1E;3HZ=&UP9&ER*"D[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"%3>7-T96TZ.FUK1&ER*&%R<F%Y*"<M<"<L
M("1T;7!D:7(I*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M("`@("!]#0H@("`@("`@("1T;7`@/2!T96UP;F%M*"1T;7!D:7(L("1P<F5F
M:7@I.PT*("`@("`@("!I9B`H:7-S970H)'1M<%]I<U]D:7(I*2![#0H@("`@
M("`@("`@("!U;FQI;FLH)'1M<"D[("\O(&)E(&-A<F5F=6P@<&]S<VEB;&4@
M<F%C92!C;VYD:71I;VX@:&5R90T*("`@("`@("`@("`@:68@*"%M:V1I<B@D
M=&UP+"`P-S`P*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B!3>7-T96TZ
M.G)A:7-E17)R;W(H(E5N86)L92!T;R!C<F5A=&4@=&5M<&]R87)Y(&1I<F5C
M=&]R>2`D=&UP9&ER(BD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@)$=,3T)!3%-;)U]3>7-T96U?=&5M<%]F:6QE<R==6UT@/2`D=&UP
M.PT*("`@("`@("!I9B`H)&9I<G-T7W1I;64I('L-"B`@("`@("`@("`@(%!%
M05(Z.G)E9VES=&5R4VAU=&1O=VY&=6YC*&%R<F%Y*"=3>7-T96TG+"`G7W)E
M;6]V951M<$9I;&5S)RDI.PT*("`@("`@("`@("`@)&9I<G-T7W1I;64@/2!F
M86QS93L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'1M<#L-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`J(%)E;6]V92!T96UP;W)A<GD@9FEL97,@8W)E
M871E9"!M>2!M:U1E;7`N(%1H:7,@9G5N8W1I;VX@:7,@97AE8W5T960-"B`@
M("`J(&%T('-C<FEP="!S:'5T9&]W;B!T:6UE#0H@("`@*@T*("`@("H@0&%C
M8V5S<R!P<FEV871E#0H@("`@*B\-"B`@("!F=6YC=&EO;B!?<F5M;W9E5&UP
M1FEL97,H*0T*("`@('L-"B`@("`@("`@:68@*&-O=6YT*"1'3$]"04Q36R=?
M4WES=&5M7W1E;7!?9FEL97,G72DI('L-"B`@("`@("`@("`@("1D96QE=&4@
M/2`D1TQ/0D%,4ULG7U-Y<W1E;5]T96UP7V9I;&5S)UT[#0H@("`@("`@("`@
M("!A<G)A>5]U;G-H:69T*"1D96QE=&4L("<M<B<I.PT*("`@("`@("`@("`@
M4WES=&5M.CIR;2@D9&5L971E*3L-"B`@("`@("`@("`@("1'3$]"04Q36R=?
M4WES=&5M7W1E;7!?9FEL97,G72`](&%R<F%Y*"D[#0H@("`@("`@('T-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`J($=E="!T:&4@<&%T:"!O9B!T:&4@=&5M
M<&]R86P@9&ER96-T;W)Y('-E="!I;B!T:&4@<WES=&5M#0H@("`@*B!B>2!L
M;V]K:6YG(&EN(&ET<R!E;G9I<F]N;65N=',@=F%R:6%B;&5S+@T*("`@("H@
M3F]T93H@<&AP+FEN:2UR96-O;6UE;F1E9"!R96UO=F5S('1H92`B12(@9G)O
M;2!T:&4@=F%R:6%B;&5S7V]R9&5R('-E='1I;F<L#0H@("`@*B!M86MI;F<@
M=6YA=F%I8FQE('1H92`D7T5.5B!A<G)A>2P@=&AA="!S('=H>2!W92!D;R!T
M97-T<R!W:71H(%]%3E8-"B`@("`J#0H@("`@*B!`<F5T=7)N('-T<FEN9R!4
M:&4@=&5M<&]R86P@9&ER96-T;W)Y(&]N('1H92!S>7-T96T-"B`@("`J+PT*
M("`@(&9U;F-T:6]N('1M<&1I<B@I#0H@("`@>PT*("`@("`@("!I9B`H3U-?
M5TE.1$]74RD@>PT*("`@("`@("`@("`@:68@*"1V87(@/2!I<W-E="@D7T5.
M5ELG5$5-4"==*2`_("1?14Y66R=414U0)UT@.B!G971E;G8H)U1%35`G*2D@
M>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=F%R.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@:68@*"1V87(@/2!I<W-E="@D7T5.5ELG5$U0)UTI
M(#\@)%]%3E9;)U1-4"==(#H@9V5T96YV*"=435`G*2D@>PT*("`@("`@("`@
M("`@("`@(')E='5R;B`D=F%R.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@:68@*"1V87(@/2!I<W-E="@D7T5.5ELG=VEN9&ER)UTI(#\@)%]%3E9;
M)W=I;F1I<B==(#H@9V5T96YV*"=W:6YD:7(G*2D@>PT*("`@("`@("`@("`@
M("`@(')E='5R;B`D=F%R.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M<F5T=7)N(&=E=&5N=B@G4WES=&5M4F]O="<I("X@)UQT96UP)SL-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H)'9A<B`](&ES<V5T*"1?14Y66R=435!$25(G
M72D@/R`D7T5.5ELG5$U01$E2)UT@.B!G971E;G8H)U1-4$1)4B<I*2![#0H@
M("`@("`@("`@("!R971U<FX@)'9A<CL-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@)R]T;7`G.PT*("`@('T-"@T*("`@("\J*@T*("`@("H@5&AE(")W
M:&EC:"(@8V]M;6%N9"`H<VAO=R!T:&4@9G5L;"!P871H(&]F(&$@8V]M;6%N
M9"D-"B`@("`J#0H@("`@*B!`<&%R86T@<W1R:6YG("1P<F]G<F%M(%1H92!C
M;VUM86YD('1O('-E87)C:"!F;W(-"B`@("`J($!P87)A;2!M:7AE9"`@)&9A
M;&QB86-K(%9A;'5E('1O(')E='5R;B!I9B`D<')O9W)A;2!I<R!N;W0@9F]U
M;F0-"B`@("`J#0H@("`@*B!`<F5T=7)N(&UI>&5D($$@<W1R:6YG('=I=&@@
M=&AE(&9U;&P@<&%T:"!O<B!F86QS92!I9B!N;W0@9F]U;F0-"B`@("`J($!A
M=71H;W(@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("`@("HO#0H@("`@
M9G5N8W1I;VX@=VAI8V@H)'!R;V=R86TL("1F86QL8F%C:R`](&9A;'-E*0T*
M("`@('L-"B`@("`@("`@+R\@96YF;W)C92!!4$D-"B`@("`@("`@:68@*"%I
M<U]S=')I;F<H)'!R;V=R86TI('Q\("<G(#T]("1P<F]G<F%M*2![#0H@("`@
M("`@("`@("!R971U<FX@)&9A;&QB86-K.PT*("`@("`@("!]#0H-"B`@("`@
M("`@+R\@879A:6QA8FQE('-I;F-E(#0N,RXP4D,R#0H@("`@("`@(&EF("AD
M969I;F5D*"=0051(7U-%4$%2051/4B<I*2![#0H@("`@("`@("`@("`D<&%T
M:%]D96QI;2`](%!!5$A?4T5005)!5$]2.PT*("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@)'!A=&A?9&5L:6T@/2!/4U]724Y$3U=3(#\@)SLG(#H@
M)SHG.PT*("`@("`@("!]#0H@("`@("`@("\O(&9U;&P@<&%T:"!G:79E;@T*
M("`@("`@("!I9B`H8F%S96YA;64H)'!R;V=R86TI("$]("1P<F]G<F%M*2![
M#0H@("`@("`@("`@("`D<&%T:%]E;&5M96YT<UM=(#T@9&ER;F%M92@D<')O
M9W)A;2D[#0H@("`@("`@("`@("`D<')O9W)A;2`](&)A<V5N86UE*"1P<F]G
M<F%M*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("\O($AO;F]R
M('-A9F4@;6]D90T*("`@("`@("`@("`@:68@*"%I;FE?9V5T*"=S869E7VUO
M9&4G*2!\?"`A)'!A=&@@/2!I;FE?9V5T*"=S869E7VUO9&5?97AE8U]D:7(G
M*2D@>PT*("`@("`@("`@("`@("`@("1P871H(#T@9V5T96YV*"=0051()RD[
M#0H@("`@("`@("`@("`@("`@:68@*"$D<&%T:"D@>PT*("`@("`@("`@("`@
M("`@("`@("`D<&%T:"`](&=E=&5N=B@G4&%T:"<I.R`O+R!S;VUE($]397,@
M87)E(&IU<W0@<W1U<&ED(&5N;W5G:"!T;R!D;R!T:&ES#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'!A=&A?96QE
M;65N=',@/2!E>'!L;V1E*"1P871H7V1E;&EM+"`D<&%T:"D[#0H@("`@("`@
M('T-"@T*("`@("`@("!I9B`H3U-?5TE.1$]74RD@>PT*("`@("`@("`@("`@
M)&5X95]S=69F:7AE<R`](&=E=&5N=B@G4$%42$585"<I#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#\@97AP;&]D92@D<&%T:%]D96QI;2P@
M9V5T96YV*"=0051(15A4)RDI#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#H@87)R87DH)RYE>&4G+"<N8F%T)RPG+F-M9"<L)RYC;VTG*3L-
M"B`@("`@("`@("`@("\O(&%L;&]W('!A<W-I;F<@82!C;VUM86YD+F5X92!P
M87)A;0T*("`@("`@("`@("`@:68@*'-T<G!O<R@D<')O9W)A;2P@)RXG*2`A
M/3T@9F%L<V4I('L-"B`@("`@("`@("`@("`@("!A<G)A>5]U;G-H:69T*"1E
M>&5?<W5F9FEX97,L("<G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("\O(&ES7V5X96-U=&%B;&4H*2!I<R!N;W0@879A:6QA8FQE(&]N('=I;F1O
M=W,@9F]R(%!(4#0-"B`@("`@("`@("`@("1P96%R7VES7V5X96-U=&%B;&4@
M/2`H9G5N8W1I;VY?97AI<W1S*"=I<U]E>&5C=71A8FQE)RDI(#\@)VES7V5X
M96-U=&%B;&4G(#H@)VES7V9I;&4G.PT*("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@)&5X95]S=69F:7AE<R`](&%R<F%Y*"<G*3L-"B`@("`@("`@
M("`@("1P96%R7VES7V5X96-U=&%B;&4@/2`G:7-?97AE8W5T86)L92<[#0H@
M("`@("`@('T-"@T*("`@("`@("!F;W)E86-H("@D97AE7W-U9F9I>&5S(&%S
M("1S=69F*2![#0H@("`@("`@("`@("!F;W)E86-H("@D<&%T:%]E;&5M96YT
M<R!A<R`D9&ER*2![#0H@("`@("`@("`@("`@("`@)&9I;&4@/2`D9&ER("X@
M1$E214-43U)97U-%4$%2051/4B`N("1P<F]G<F%M("X@)'-U9F8[#0H@("`@
M("`@("`@("`@("`@:68@*"1P96%R7VES7V5X96-U=&%B;&4H)&9I;&4I*2![
M#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D9FEL93L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N("1F86QL8F%C:SL-"B`@("!]#0H-"B`@("`O*BH-"B`@("`J(%1H
M92`B9FEN9"(@8V]M;6%N9`T*("`@("H-"B`@("`J(%5S86=E.@T*("`@("H-
M"B`@("`J(%-Y<W1E;3HZ9FEN9"@D9&ER*3L-"B`@("`J(%-Y<W1E;3HZ9FEN
M9"@B)&1I<B`M='EP92!D(BD[#0H@("`@*B!3>7-T96TZ.F9I;F0H(B1D:7(@
M+71Y<&4@9B(I.PT*("`@("H@4WES=&5M.CIF:6YD*"(D9&ER("UN86UE("HN
M<&AP(BD[#0H@("`@*B!3>7-T96TZ.F9I;F0H(B1D:7(@+6YA;64@*BYP:'`@
M+6YA;64@*BYH=&TJ(BD[#0H@("`@*B!3>7-T96TZ.F9I;F0H(B1D:7(@+6UA
M>&1E<'1H(#$B*3L-"B`@("`J#0H@("`@*B!087)A;7,@:6UP;&UE;G1E9#H-
M"B`@("`J("1D:7(@("`@("`@("`@("`M/B!3=&%R="!T:&4@<V5A<F-H(&%T
M('1H:7,@9&ER96-T;W)Y#0H@("`@*B`M='EP92!D("`@("`@("`@+3X@<F5T
M=7)N(&]N;'D@9&ER96-T;W)I97,-"B`@("`J("UT>7!E(&8@("`@("`@("`M
M/B!R971U<FX@;VYL>2!F:6QE<PT*("`@("H@+6UA>&1E<'1H(#QN/B`@("T^
M(&UA>"!D97!T:"!O9B!R96-U<G-I;VX-"B`@("`J("UN86UE(#QP871T97)N
M/B`M/B!S96%R8V@@<&%T=&5R;B`H8F%S:"!S='EL92DN($UU;'1I<&QE("UN
M86UE('!A<F%M(&%L;&]W960-"B`@("`J#0H@("`@*B!`<&%R86T@(&UI>&5D
M($5I=&AE<B!A<G)A>2!O<B!S=')I;F<@=VET:"!T:&4@8V]M;6%N9"!L:6YE
M#0H@("`@*B!`<F5T=7)N(&%R<F%Y($%R<F%Y(&]F(&9O=6YD(&9I;&5S#0H@
M("`@*@T*("`@("HO#0H@("`@9G5N8W1I;VX@9FEN9"@D87)G<RD-"B`@("![
M#0H@("`@("`@(&EF("@A:7-?87)R87DH)&%R9W,I*2![#0H@("`@("`@("`@
M("`D87)G<R`]('!R96=?<W!L:70H)R]<<RLO)RP@)&%R9W,L("TQ+"!04D5'
M7U-03$E47TY/7T5-4%19*3L-"B`@("`@("`@?0T*("`@("`@("`D9&ER(#T@
M87)R87E?<VAI9G0H)&%R9W,I.PT*("`@("`@("`D<&%T=&5R;G,@/2!A<G)A
M>2@I.PT*("`@("`@("`D9&5P=&@@/2`P.PT*("`@("`@("`D9&]?9FEL97,@
M/2`D9&]?9&ER<R`]('1R=64[#0H@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M(&-O=6YT*"1A<F=S*3L@)&DK*RD@>PT*("`@("`@("`@("`@<W=I=&-H("@D
M87)G<ULD:5TI('L-"B`@("`@("`@("`@("`@("!C87-E("<M='EP92<Z#0H@
M("`@("`@("`@("`@("`@("`@(&EF("AI;E]A<G)A>2@D87)G<ULD:2LQ72P@
M87)R87DH)V0G+"`G9B<I*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"1A<F=S6R1I*S%=(#T]("=D)RD@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1D;U]F:6QE<R`](&9A;'-E.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9&]?9&ER<R`](&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("1I*RL[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@
M("`@("`@(&-A<V4@)RUN86UE)SH-"B`@("`@("`@("`@("`@("`@("`@:68@
M*$]37U=)3D1/5U,I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D
M87)G<ULD:2LQ77LP?2`]/2`G7%PG*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+R\@<')E<&5N9"!D<FEV90T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1A<F=S6R1I*S%=(#T@861D<VQA<VAE<RAS=6)S='(H9V5T
M8W=D*"DL(#`L(#(I("X@)&%R9W-;)&D@*R`Q72D[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`O+R!E<V-A
M<&4@<&%T:"!S97!A<F%T;W)S('1O(&%V;VED(%!#4D4@<')O8FQE;7,-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1A<F=S6R1I*S%=(#T@<W1R7W)E<&QA
M8V4H)UQ<)RP@)UQ<7%PG+"`D87)G<ULD:2LQ72D[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)'!A='1E<FYS6UT@/2`B
M*"(@+B!P<F5G7W)E<&QA8V4H87)R87DH)R]<+B\G+"`G+UPJ+R<I+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@G7"XG+"`G+BHG+"`I+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D87)G<ULD:2LQ
M72D-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`B
M*2([#0H@("`@("`@("`@("`@("`@("`@("1I*RL[#0H@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@(&-A<V4@)RUM87AD97!T
M:"<Z#0H@("`@("`@("`@("`@("`@("`@("1D97!T:"`]("1A<F=S6R1I*S%=
M.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("`D<&%T:"`](%-Y<W1E;3HZ7V1I<E1O4W1R
M=6-T*"1D:7(L("1D97!T:"D[#0H@("`@("`@(&EF("@D9&]?9FEL97,@)B8@
M)&1O7V1I<G,I('L-"B`@("`@("`@("`@("1F:6QE<R`](&%R<F%Y7VUE<F=E
M*"1P871H6R=F:6QE<R==+"`D<&%T:%LG9&ER<R==*3L-"B`@("`@("`@?2!E
M;'-E:68@*"1D;U]D:7)S*2![#0H@("`@("`@("`@("`D9FEL97,@/2`D<&%T
M:%LG9&ER<R==.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&9I
M;&5S(#T@)'!A=&A;)V9I;&5S)UT[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*&-O=6YT*"1P871T97)N<RDI('L-"B`@("`@("`@("`@("1P871T97)N<R`]
M(&EM<&QO9&4H)WPG+"`D<&%T=&5R;G,I.PT*("`@("`@("`@("`@)')E="`]
M(&%R<F%Y*"D[#0H@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N
M="@D9FEL97,I.R`D:2LK*2![#0H@("`@("`@("`@("`@("`@:68@*'!R96=?
M;6%T8V@H(B->)'!A='1E<FYS7"0C(BP@)&9I;&5S6R1I72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@)')E=%M=(#T@)&9I;&5S6R1I73L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@
M)')E=#L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)&9I;&5S.PT*("`@
M('T-"GT-"C\^#0H```````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+W!E87)C;60N<&AP````````````````````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,S4V,3,@,3`U,34T,S,W,S,@,#(P-C(R`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M#0HO+PT*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\(%!(
M4"!697)S:6]N(#4@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PT*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P-"!4:&4@
M4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@5&AI<R!S;W5R
M8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@
M;&EC96YS92P@("`@("`@?`T*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T
M:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@
M("!\#0HO+R!\(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8B!A="!T:&4@9F]L;&]W:6YG('5R;#H@("`@("`@("`@('P-"B\O('P@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"!)9B!Y;W4@9&ED(&YO="!R
M96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B
M;&4@=&\@("!\#0HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P-"B\O
M('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@
M:6UM961I871E;'DN("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK#0HO+R!\($%U=&AO<G,Z(%-T:6<@0F%K:V5N(#QS
M<V)`<&AP+FYE=#X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P-"B\O('P@("`@("`@("`@5&]M87,@5BY6+D-O>"`\8V]X0&ED96-N970N
M8V]M/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L-"B\O#0HO+R`D260Z('!E87)C;60N<&AP+'8@,2XS,R`R,#`V
M+S`Q+S`R(#$X.C`U.C4S(&-E;&QO9R!%>'`@)`T*#0IO8E]E;F1?8VQE86XH
M*3L-"FEF("@A9&5F:6YE9"@G4$5!4E]254Y465!%)RDI('L-"B`@("`O+R!T
M:&ES(&ES(&1E9FEN960@:6X@<&5C;&-M9"YP:'`@87,@)W!E8VPG#0H@("`@
M9&5F:6YE*"=014%27U)53E194$4G+"`G<&5A<B<I.PT*?0T*9&5F:6YE*"=0
M14%27TE'3D]215]"04-+5%)!0T4G+"`Q*3L-"FEF("@A9G5N8W1I;VY?97AI
M<W1S*"=F:6QE7V=E=%]C;VYT96YT<R<I*2![#0H@("`@9G5N8W1I;VX@9FEL
M95]G971?8V]N=&5N=',H)&9I;&5N86UE*0T*("`@('L-"B`@("`@("`@)&9P
M(#T@9F]P96XH)&9I;&5N86UE+"`G<F(G*3L-"B`@("`@("`@)')E="`]("<G
M.PT*("`@("`@("!W:&EL92`H(69E;V8H)&9P*2D@>PT*("`@("`@("`@("`@
M)')E="`N/2!F<F5A9"@D9G`L(#@P.3(I.SL-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@)')E=#L-"B`@("!]#0I]#0HO*BH-"B`J($!N;V1E<"!'=&L-
M"B`J+PT*:68@*"<O=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B<@(3T@
M)T`G+B=I;F-L=61E7W!A=&@G+B=`)RD@>PT*("`@(&EN:5]S970H)VEN8VQU
M9&5?<&%T:"<L("<O=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B<I.PT*
M("`@("1R87<@/2!F86QS93L-"GT@96QS92![#0H@("`@+R\@=&AI<R!I<R!A
M(')A=RP@=6YI;G-T86QL960@<&5A<BP@96ET:&5R(&$@8W9S(&-H96-K;W5T
M+"!O<B!P:'`@9&ES=')O#0H@("`@)')A=R`]('1R=64[#0I]#0I`:6YI7W-E
M="@G86QL;W=?=7)L7V9O<&5N)RP@=')U92D[#0II9B`H(6EN:5]G970H)W-A
M9F5?;6]D92<I*2![#0H@("`@0'-E=%]T:6UE7VQI;6ET*#`I.PT*?0T*;V)?
M:6UP;&EC:71?9FQU<V@H=')U92D[#0I`:6YI7W-E="@G=')A8VM?97)R;W)S
M)RP@=')U92D[#0I`:6YI7W-E="@G:'1M;%]E<G)O<G,G+"!F86QS92D[#0I`
M:6YI7W-E="@G;6%G:6-?<75O=&5S7W)U;G1I;64G+"!F86QS92D[#0HD7U!%
M05)?4$A01$E2(#T@)R,D)5XF*B<[#0IS971?97)R;W)?:&%N9&QE<B@G97)R
M;W)?:&%N9&QE<B<I.PT*#0HD<&5A<E]P86-K86=E7W9E<G-I;VX@/2`B,2XT
M+CDB.PT*#0IR97%U:7)E7V]N8V4@)U!%05(N<&AP)SL-"G)E<75I<F5?;VYC
M92`G4$5!4B]&<F]N=&5N9"YP:'`G.PT*<F5Q=6ER95]O;F-E("=014%2+T-O
M;F9I9RYP:'`G.PT*<F5Q=6ER95]O;F-E("=014%2+T-O;6UA;F0N<&AP)SL-
M"G)E<75I<F5?;VYC92`G0V]N<V]L92]'971O<'0N<&AP)SL-"@T*#0I014%2
M7T-O;6UA;F0Z.G-E=$9R;VYT96YD5'EP92@G0TQ))RD[#0HD86QL7V-O;6UA
M;F1S(#T@4$5!4E]#;VUM86YD.CIG971#;VUM86YD<R@I.PT*#0HO+R!R96UO
M=F4@=&AI<R!N97AT('!A<G0@=VAE;B!W92!S=&]P('-U<'!O<G1I;F<@=&AA
M="!C<F%P+6%S<R!02%`@-"XR#0II9B`H(6ES<V5T*"1?4T525D526R=A<F=V
M)UTI("8F("%I<W-E="@D87)G=BD@)B8@(6ES<V5T*"1(5%107U-%4E9%4E]6
M05)36R=A<F=V)UTI*2![#0H@("`@9&EE*"=%4E)/4CH@96ET:&5R('5S92!T
M:&4@0TQ)('!H<"!E>&5C=71A8FQE+"!O<B!S970@<F5G:7-T97)?87)G8U]A
M<F=V/4]N(&EN('!H<"YI;FDG*3L-"GT-"B1A<F=V(#T@0V]N<V]L95]'971O
M<'0Z.G)E86102%!!<F=V*"D[#0HO+R!F:7@@0T=)('-A<&D@;V1D:71Y("T@
M=&AE("TM(&EN('!E87(N8F%T+W!E87(@:7,@;F]T(')E;6]V960-"FEF("AP
M:'!?<V%P:5]N86UE*"D@(3T@)V-L:2<@)B8@:7-S970H)&%R9W9;,5TI("8F
M("1A<F=V6S%=(#T]("<M+2<I('L-"B`@("!U;G-E="@D87)G=ELQ72D[#0H@
M("`@)&%R9W8@/2!A<G)A>5]V86QU97,H)&%R9W8I.PT*?0T*)'!R;V=N86UE
M(#T@4$5!4E]254Y465!%.PT*:68@*&EN7V%R<F%Y*"=G971O<'0R)RP@9V5T
M7V-L87-S7VUE=&AO9',H)T-O;G-O;&5?1V5T;W!T)RDI*2![#0H@("`@87)R
M87E?<VAI9G0H)&%R9W8I.PT*("`@("1O<'1I;VYS(#T@0V]N<V]L95]'971O
M<'0Z.F=E=&]P=#(H)&%R9W8L(")C.D,Z9#I$.D=H/W-3<74Z=E8B*3L-"GT@
M96QS92![#0H@("`@)&]P=&EO;G,@/2!#;VYS;VQE7T=E=&]P=#HZ9V5T;W!T
M*"1A<F=V+"`B8SI#.F0Z1#I':#]S4W%U.G96(BD[#0I]#0II9B`H4$5!4CHZ
M:7-%<G)O<B@D;W!T:6]N<RDI('L-"B`@("!U<V%G92@D;W!T:6]N<RD[#0I]
M#0H-"B1O<'1S(#T@)&]P=&EO;G-;,%T[#0H-"B1F971Y<&4@/2`G0TQ))SL-
M"FEF("@D<')O9VYA;64@/3T@)V=P96%R)R!\?"`D<')O9VYA;64@/3T@)W!E
M87(M9W1K)RD@>PT*("`@("1F971Y<&4@/2`G1W1K)SL-"GT@96QS92![#0H@
M("`@9F]R96%C:"`H)&]P=',@87,@)&]P="D@>PT*("`@("`@("!I9B`H)&]P
M=%LP72`]/2`G1R<I('L-"B`@("`@("`@("`@("1F971Y<&4@/2`G1W1K)SL-
M"B`@("`@("`@?0T*("`@('T-"GT-"B\O0VAE8VL@:68@1W1K(&%N9"!02%`@
M/CT@-2XQ+C`-"FEF("@D9F5T>7!E(#T]("='=&LG("8F('9E<G-I;VY?8V]M
M<&%R92AP:'!V97)S:6]N*"DL("<U+C$N,"<L("<^/2<I*2![#0H@("`@)&9E
M='EP92`]("='=&LR)SL-"GT-"@T*)'!E87)?=7-E<E]C;VYF:6<@/2`G)SL-
M"B1P96%R7W-Y<W1E;5]C;VYF:6<@/2`G)SL-"B1S=&]R95]U<V5R7V-O;F9I
M9R`](&9A;'-E.PT*)'-T;W)E7W-Y<W1E;5]C;VYF:6<@/2!F86QS93L-"B1V
M97)B;W-E(#T@,3L-"@T*9F]R96%C:"`H)&]P=',@87,@)&]P="D@>PT*("`@
M('-W:71C:"`H)&]P=%LP72D@>PT*("`@("`@("!C87-E("=C)SH-"B`@("`@
M("`@("`@("1P96%R7W5S97)?8V]N9FEG(#T@)&]P=%LQ73L-"B`@("`@("`@
M("`@(&)R96%K.PT*("`@("`@("!C87-E("=#)SH-"B`@("`@("`@("`@("1P
M96%R7W-Y<W1E;5]C;VYF:6<@/2`D;W!T6S%=.PT*("`@("`@("`@("`@8G)E
M86L[#0H@("`@?0T*?0T*#0I014%27T-O;6UA;F0Z.G-E=$9R;VYT96YD5'EP
M92@D9F5T>7!E*3L-"B1U:2`]("9014%27T-O;6UA;F0Z.F=E=$9R;VYT96YD
M3V)J96-T*"D[#0HD8V]N9FEG(#T@)E!%05)?0V]N9FEG.CIS:6YG;&5T;VXH
M)'!E87)?=7-E<E]C;VYF:6<L("1P96%R7W-Y<W1E;5]C;VYF:6<I.PT*#0II
M9B`H4$5!4CHZ:7-%<G)O<B@D8V]N9FEG*2D@>PT*("`@("1?9FEL92`]("<G
M.PT*("`@(&EF("@D<&5A<E]U<V5R7V-O;F9I9R`A/3T@9F%L<V4I('L-"B`@
M("`@("`D7V9I;&4@+CT@)'!E87)?=7-E<E]C;VYF:6<[#0H@("`@?0T*("`@
M(&EF("@D<&5A<E]S>7-T96U?8V]N9FEG("$]/2!F86QS92D@>PT*("`@("`@
M("1?9FEL92`N/2`G+R<@+B`D<&5A<E]S>7-T96U?8V]N9FEG.PT*("`@('T-
M"B`@("!I9B`H)%]F:6QE(#T]("<O)RD@>PT*("`@("`@("`D7V9I;&4@/2`G
M5&AE(&1E9F%U;'0@8V]N9FEG(&9I;&4G.PT*("`@('T-"B`@("`D8V]N9FEG
M+3YG971-97-S86=E*"D[#0H@("`@)'5I+3YO=71P=71$871A*")%4E)/4CH@
M)%]F:6QE(&ES(&YO="!A('9A;&ED(&-O;F9I9R!F:6QE(&]R(&ES(&-O<G)U
M<'1E9"XB*3L-"B`@("`O+R!792!S=&]P+"!W92!H879E(&YO(&ED96$@=VAE
M<F4@=V4@87)E(#HI#0H@("`@97AI="@I.R`@("`-"GT-"@T*+R\@=&AI<R!I
M<R!U<V5D(&EN('1H92!E<G)O<B!H86YD;&5R('1O(')E=')I979E(&$@<F5L
M871I=F4@<&%T:`T*)%]014%27U!(4$1)4B`]("1C;VYF:6<M/F=E="@G<&AP
M7V1I<B<I.PT*)'5I+3YS971#;VYF:6<H)&-O;F9I9RD[#0I014%2.CIS971%
M<G)O<DAA;F1L:6YG*%!%05)?15)23U)?0T%,3$)!0TLL(&%R<F%Y*"1U:2P@
M(F1I<W!L87E&871A;$5R<F]R(BDI.PT*:68@*&EN:5]G970H)W-A9F5?;6]D
M92<I*2![#0H@("`@)'5I+3YO=71P=71$871A*"=705).24Y'.B!R=6YN:6YG
M(&EN('-A9F4@;6]D92!R97%U:7)E<R!T:&%T(&%L;"!F:6QE<R!C<F5A=&5D
M("<@+@T*("`@("`@("`G8F4@=&AE('-A;64@=6ED(&%S('1H92!C=7)R96YT
M('-C<FEP="X@(%!(4"!R97!O<G1S('1H:7,@<V-R:7!T(&ES('5I9#H@)R`N
M#0H@("`@("`@($!G971M>75I9"@I("X@)RP@86YD(&-U<G)E;G0@=7-E<B!I
M<SH@)R`N($!G971?8W5R<F5N=%]U<V5R*"DI.PT*?0T*#0HD=F5R8F]S92`]
M("1C;VYF:6<M/F=E="@B=F5R8F]S92(I.PT*)&-M9&]P=',@/2!A<G)A>2@I
M.PT*#0II9B`H)')A=RD@>PT*("`@(&EF("@A)&-O;F9I9RT^:7-$969I;F5D
M3&%Y97(H)W5S97(G*2`F)B`A)&-O;F9I9RT^:7-$969I;F5D3&%Y97(H)W-Y
M<W1E;2<I*2![#0H@("`@("`@("1F;W5N9"`](&9A;'-E.PT*("`@("`@("!F
M;W)E86-H("@D;W!T<R!A<R`D;W!T*2![#0H@("`@("`@("`@("!I9B`H)&]P
M=%LP72`]/2`G9"<@?'P@)&]P=%LP72`]/2`G1"<I('L-"B`@("`@("`@("`@
M("`@("`D9F]U;F0@/2!T<G5E.R`O+R!T:&4@=7-E<B!K;F]W<R!W:&%T('1H
M97D@87)E(&1O:6YG+"!A;F0@87)E('-E='1I;F<@8V]N9FEG('9A;'5E<PT*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@A)&9O=6YD
M*2![#0H@("`@("`@("`@("`O+R!N;R!P<FEO<B!R=6YS+"!T<GD@=&\@:6YS
M=&%L;"!014%2#0H@("`@("`@("`@("!I9B`H<W1R<&]S*&1I<FYA;64H7U]&
M24Q%7U\I+"`G<V-R:7!T<R<I*2![#0H@("`@("`@("`@("`@("`@)'!A8VMA
M9V5X;6P@/2!D:7)N86UE*&1I<FYA;64H7U]&24Q%7U\I*2`N($1)4D5#5$]2
M65]315!!4D%43U(@+B`G<&%C:V%G93(N>&UL)SL-"B`@("`@("`@("`@("`@
M("`D<&5A<F)A<V4@/2!D:7)N86UE*&1I<FYA;64H7U]&24Q%7U\I*3L-"B`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)'!A8VMA9V5X
M;6P@/2!D:7)N86UE*%]?1DE,15]?*2`N($1)4D5#5$]265]315!!4D%43U(@
M+B`G<&%C:V%G93(N>&UL)SL-"B`@("`@("`@("`@("`@("`D<&5A<F)A<V4@
M/2!D:7)N86UE*%]?1DE,15]?*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(&EF("AF:6QE7V5X:7-T<R@D<&%C:V%G97AM;"DI('L-"B`@("`@("`@
M("`@("`@("`D;W!T:6]N<ULQ72`](&%R<F%Y*`T*("`@("`@("`@("`@("`@
M("`@("`G:6YS=&%L;"<L#0H@("`@("`@("`@("`@("`@("`@("1P86-K86=E
M>&UL#0H@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@("`@("`@("`D8V]N
M9FEG+3YS970H)W!H<%]D:7(G+"`D<&5A<F)A<V4@+B!$25)%0U1/4EE?4T50
M05)!5$]2("X@)W!H<"<I.PT*("`@("`@("`@("`@("`@("1C;VYF:6<M/G-E
M="@G9&%T85]D:7(G+"`D<&5A<F)A<V4@+B!$25)%0U1/4EE?4T5005)!5$]2
M("X@)V1A=&$G*3L-"B`@("`@("`@("`@("`@("`D8V]N9FEG+3YS970H)V1O
M8U]D:7(G+"`D<&5A<F)A<V4@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)V1O
M8W,G*3L-"B`@("`@("`@("`@("`@("`D8V]N9FEG+3YS970H)W1E<W1?9&ER
M)RP@)'!E87)B87-E("X@1$E214-43U)97U-%4$%2051/4B`N("=T97-T<R<I
M.PT*("`@("`@("`@("`@("`@("1C;VYF:6<M/G-E="@G97AT7V1I<B<L("1P
M96%R8F%S92`N($1)4D5#5$]265]315!!4D%43U(@+B`G97AT96YS:6]N<R<I
M.PT*("`@("`@("`@("`@("`@("1C;VYF:6<M/G-E="@G8FEN7V1I<B<L("1P
M96%R8F%S92D[#0H@("`@("`@("`@("`@("`@)&-O;F9I9RT^;65R9V5#;VYF
M:6=&:6QE*"1P96%R8F%S92`N("=P96%R+FEN:2<L(&9A;'-E*3L-"B`@("`@
M("`@("`@("`@("`D8V]N9FEG+3YS=&]R92@I.PT*("`@("`@("`@("`@("`@
M("1C;VYF:6<M/G-E="@G875T;U]D:7-C;W9E<B<L(#$I.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@?0T*?0T*9F]R96%C:"`H)&]P=',@87,@
M)&]P="D@>PT*("`@("1P87)A;2`]("%E;7!T>2@D;W!T6S%=*2`_("1O<'1;
M,5T@.B!T<G5E.PT*("`@('-W:71C:"`H)&]P=%LP72D@>PT*("`@("`@("!C
M87-E("=D)SH-"B`@("`@("`@("`@(&QI<W0H)&ME>2P@)'9A;'5E*2`](&5X
M<&QO9&4H)STG+"`D<&%R86TI.PT*("`@("`@("`@("`@)&-O;F9I9RT^<V5T
M*"1K97DL("1V86QU92P@)W5S97(G*3L-"B`@("`@("`@("`@(&)R96%K.PT*
M("`@("`@("!C87-E("=$)SH-"B`@("`@("`@("`@(&QI<W0H)&ME>2P@)'9A
M;'5E*2`](&5X<&QO9&4H)STG+"`D<&%R86TI.PT*("`@("`@("`@("`@)&-O
M;F9I9RT^<V5T*"1K97DL("1V86QU92P@)W-Y<W1E;2<I.PT*("`@("`@("`@
M("`@8G)E86L[#0H@("`@("`@(&-A<V4@)W,G.@T*("`@("`@("`@("`@)'-T
M;W)E7W5S97)?8V]N9FEG(#T@=')U93L-"B`@("`@("`@("`@(&)R96%K.PT*
M("`@("`@("!C87-E("=3)SH-"B`@("`@("`@("`@("1S=&]R95]S>7-T96U?
M8V]N9FEG(#T@=')U93L-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("!C
M87-E("=U)SH-"B`@("`@("`@("`@("1C;VYF:6<M/G)E;6]V92@D<&%R86TL
M("=U<V5R)RD[#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@8V%S92`G
M=B<Z#0H@("`@("`@("`@("`D8V]N9FEG+3YS970H)W9E<F)O<V4G+"`D8V]N
M9FEG+3YG970H)W9E<F)O<V4G*2`K(#$I.PT*("`@("`@("`@("`@8G)E86L[
M#0H@("`@("`@(&-A<V4@)W$G.@T*("`@("`@("`@("`@)&-O;F9I9RT^<V5T
M*"=V97)B;W-E)RP@)&-O;F9I9RT^9V5T*"=V97)B;W-E)RD@+2`Q*3L-"B`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("!C87-E("=6)SH-"B`@("`@("`@
M("`@('5S86=E*&YU;&PL("=V97)S:6]N)RD[#0H@("`@("`@(&-A<V4@)V,G
M.@T*("`@("`@("!C87-E("=#)SH-"B`@("`@("`@("`@(&)R96%K.PT*("`@
M("`@("!D969A=6QT.@T*("`@("`@("`@("`@+R\@86QL(&YO;B!P96%R('!A
M<F%M<R!G;V5S('1O('1H92!C;VUM86YD#0H@("`@("`@("`@("`D8VUD;W!T
M<ULD;W!T6S!=72`]("1P87)A;3L-"B`@("`@("`@("`@(&)R96%K.PT*("`@
M('T-"GT-"@T*:68@*"1S=&]R95]S>7-T96U?8V]N9FEG*2![#0H@("`@)&-O
M;F9I9RT^<W1O<F4H)W-Y<W1E;2<I.PT*?0T*#0II9B`H)'-T;W)E7W5S97)?
M8V]N9FEG*2![#0H@("`@)&-O;F9I9RT^<W1O<F4H)W5S97(G*3L-"GT-"@T*
M)&-O;6UA;F0@/2`H:7-S970H)&]P=&EO;G-;,5U;,%TI*2`_("1O<'1I;VYS
M6S%=6S!=(#H@;G5L;#L-"@T*:68@*&5M<'1Y*"1C;VUM86YD*2`F)B`H)'-T
M;W)E7W5S97)?8V]N9FEG('Q\("1S=&]R95]S>7-T96U?8V]N9FEG*2D@>PT*
M("`@(&5X:70[#0I]#0H-"FEF("@D9F5T>7!E(#T]("='=&LG('Q\("1F971Y
M<&4@/3T@)T=T:S(G*2![#0H@("`@:68@*"$D8V]N9FEG+3YV86QI9$-O;F9I
M9W5R871I;VXH*2D@>PT*("`@("`@("!014%2.CIR86ES945R<F]R*"=#4DE4
M24-!3"!%4E)/4CH@;F\@97AI<W1I;F<@=F%L:60@8V]N9FEG=7)A=&EO;B!F
M:6QE<R!F;W5N9"!I;B!F:6QE<R`G("X-"B`@("`@("`@("`@("(G)'!E87)?
M=7-E<E]C;VYF:6<G(&]R("<D<&5A<E]S>7-T96U?8V]N9FEG)RP@<&QE87-E
M(&-O<'D@86X@97AI<W1I;F<@8V]N9FEG=7)A=&EO;B(@+@T*("`@("`@("`@
M("`@)V9I;&4@=&\@;VYE(&]F('1H97-E(&QO8V%T:6]N<RP@;W(@=7-E('1H
M92`M8R!A;F0@+7,@;W!T:6]N<R!T;R!C<F5A=&4@;VYE)RD[#0H@("`@?0T*
M("`@($=T:SHZ;6%I;B@I.PT*?2!E;'-E(&1O('L-"B`@("!I9B`H)&-O;6UA
M;F0@/3T@)VAE;'`G*2![#0H@("`@("`@('5S86=E*&YU;&PL($`D;W!T:6]N
M<ULQ75LQ72D[#0H@("`@?0T*("`@(&EF("@A)&-O;F9I9RT^=F%L:61#;VYF
M:6=U<F%T:6]N*"DI('L-"B`@("`@("`@4$5!4CHZ<F%I<V5%<G)O<B@G0U))
M5$E#04P@15)23U(Z(&YO(&5X:7-T:6YG('9A;&ED(&-O;F9I9W5R871I;VX@
M9FEL97,@9F]U;F0@:6X@9FEL97,@)R`N#0H@("`@("`@("`@("`B)R1P96%R
M7W5S97)?8V]N9FEG)R!O<B`G)'!E87)?<WES=&5M7V-O;F9I9R<L('!L96%S
M92!C;W!Y(&%N(&5X:7-T:6YG(&-O;F9I9W5R871I;VXB("X-"B`@("`@("`@
M("`@("=F:6QE('1O(&]N92!O9B!T:&5S92!L;V-A=&EO;G,L(&]R('5S92!T
M:&4@+6,@86YD("US(&]P=&EO;G,@=&\@8W)E871E(&]N92<I.PT*("`@('T-
M"@T*("`@(%!%05(Z.G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D54
M55).*3L-"B`@("`D8VUD(#T@4$5!4E]#;VUM86YD.CIF86-T;W)Y*"1C;VUM
M86YD+"`D8V]N9FEG*3L-"B`@("!014%2.CIP;W!%<G)O<DAA;F1L:6YG*"D[
M#0H@("`@:68@*%!%05(Z.FES17)R;W(H)&-M9"DI('L-"B`@("`@("`@=7-A
M9V4H;G5L;"P@0"1O<'1I;VYS6S%=6S!=*3L-"B`@("!]#0H-"B`@("`D<VAO
M<G1?87)G<R`]("1L;VYG7V%R9W,@/2!N=6QL.PT*("`@(%!%05)?0V]M;6%N
M9#HZ9V5T1V5T;W!T07)G<R@D8V]M;6%N9"P@)'-H;W)T7V%R9W,L("1L;VYG
M7V%R9W,I.PT*("`@(&EF("AI;E]A<G)A>2@G9V5T;W!T,B<L(&=E=%]C;&%S
M<U]M971H;V1S*"=#;VYS;VQE7T=E=&]P="<I*2D@>PT*("`@("`@("!A<G)A
M>5]S:&EF="@D;W!T:6]N<ULQ72D[#0H@("`@("`@("1T;7`@/2!#;VYS;VQE
M7T=E=&]P=#HZ9V5T;W!T,B@D;W!T:6]N<ULQ72P@)'-H;W)T7V%R9W,L("1L
M;VYG7V%R9W,I.PT*("`@('T@96QS92![#0H@("`@("`@("1T;7`@/2!#;VYS
M;VQE7T=E=&]P=#HZ9V5T;W!T*"1O<'1I;VYS6S%=+"`D<VAO<G1?87)G<RP@
M)&QO;F=?87)G<RD[#0H@("`@?0T*("`@(&EF("A014%2.CII<T5R<F]R*"1T
M;7`I*2![#0H@("`@("`@(&)R96%K.PT*("`@('T-"B`@("!L:7-T*"1T;7!O
M<'0L("1P87)A;7,I(#T@)'1M<#L-"B`@("`D;W!T<R`](&%R<F%Y*"D[#0H@
M("`@9F]R96%C:"`H)'1M<&]P="!A<R`D9F]O(#T^("1T;7`R*2![#0H@("`@
M("`@(&QI<W0H)&]P="P@)'9A;'5E*2`]("1T;7`R.PT*("`@("`@("!I9B`H
M)'9A;'5E(#T]/2!N=6QL*2![#0H@("`@("`@("`@("`D=F%L=64@/2!T<G5E
M.R`O+R!O<'1I;VYS('=I=&AO=70@87)G<PT*("`@("`@("!]#0H@("`@("`@
M(&EF("AS=')L96XH)&]P="D@/3T@,2D@>PT*("`@("`@("`@("`@)&-M9&]P
M=&EO;G,@/2`D8VUD+3YG971/<'1I;VYS*"1C;VUM86YD*3L-"B`@("`@("`@
M("`@(&9O<F5A8V@@*"1C;61O<'1I;VYS(&%S("1O(#T^("1D*2![#0H@("`@
M("`@("`@("`@("`@:68@*$`D9%LG<VAO<G1O<'0G72`]/2`D;W!T*2![#0H@
M("`@("`@("`@("`@("`@("`@("1O<'1S6R1O72`]("1V86QU93L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("!I9B`H<W5B<W1R*"1O<'0L(#`L(#(I(#T]("<M+2<I
M('L-"B`@("`@("`@("`@("`@("`D;W!T<UMS=6)S='(H)&]P="P@,BE=(#T@
M)'9A;'5E.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*("`@
M("1O:R`]("1C;60M/G)U;B@D8V]M;6%N9"P@)&]P=',L("1P87)A;7,I.PT*
M("`@(&EF("@D;VL@/3T](&9A;'-E*2![#0H@("`@("`@(%!%05(Z.G)A:7-E
M17)R;W(H(G5N:VYO=VX@8V]M;6%N9"!@)&-O;6UA;F0G(BD[#0H@("`@?0T*
M("`@(&EF("A014%2.CII<T5R<F]R*"1O:RDI('L-"B`@("`@("`@4$5!4CHZ
M<V5T17)R;W)(86YD;&EN9RA014%27T524D]27T-!3$Q"04-++"!A<G)A>2@D
M=6DL(")D:7-P;&%Y1F%T86Q%<G)O<B(I*3L-"B`@("`@("`@4$5!4CHZ<F%I
M<V5%<G)O<B@D;VLI.PT*("`@('T-"GT@=VAI;&4@*&9A;'-E*3L-"@T*+R\@
M>WM[('5S86=E*"D-"@T*9G5N8W1I;VX@=7-A9V4H)&5R<F]R(#T@;G5L;"P@
M)&AE;'!S=6)J96-T(#T@;G5L;"D-"GL-"B`@("!G;&]B86P@)'!R;V=N86UE
M+"`D86QL7V-O;6UA;F1S.PT*("`@("1S=&1E<G(@/2!F;W!E;B@G<&AP.B\O
M<W1D97)R)RP@)W<G*3L-"B`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(I
M*2![#0H@("`@("`@(&9P=71S*"1S=&1E<G(L("1E<G)O<BT^9V5T365S<V%G
M92@I("X@(EQN(BD[#0H@("`@?2!E;'-E:68@*"1E<G)O<B`A/3T@;G5L;"D@
M>PT*("`@("`@("!F<'5T<R@D<W1D97)R+"`B)&5R<F]R7&XB*3L-"B`@("!]
M#0H@("`@:68@*"1H96QP<W5B:F5C="`A/2!N=6QL*2![#0H@("`@("`@("1P
M=70@/2!C;61(96QP*"1H96QP<W5B:F5C="D[#0H@("`@?2!E;'-E('L-"B`@
M("`@("`@)'!U="`]#0H@("`@("`@("`@("`B0V]M;6%N9',Z7&XB.PT*("`@
M("`@("`D;6%X;&5N(#T@;6%X*&%R<F%Y7VUA<"@B<W1R;&5N(BP@)&%L;%]C
M;VUM86YD<RDI.PT*("`@("`@("`D9F]R;6%T<W1R(#T@(B4M>R1M87AL96Y]
M<R`@)7-<;B([#0H@("`@("`@(&MS;W)T*"1A;&Q?8V]M;6%N9',I.PT*("`@
M("`@("!F;W)E86-H("@D86QL7V-O;6UA;F1S(&%S("1C;60@/3X@)&-L87-S
M*2![#0H@("`@("`@("`@("`D<'5T("X]('-P<FEN=&8H)&9O<FUA='-T<BP@
M)&-M9"P@4$5!4E]#;VUM86YD.CIG971$97-C<FEP=&EO;B@D8VUD*2D[#0H@
M("`@("`@('T-"B`@("`@("`@)'!U="`N/0T*("`@("`@("`@("`@(E5S86=E
M.B`D<')O9VYA;64@6V]P=&EO;G-=(&-O;6UA;F0@6V-O;6UA;F0M;W!T:6]N
M<UT@/'!A<F%M971E<G,^7&XB+@T*("`@("`@("`@("`@(E1Y<&4@7"(D<')O
M9VYA;64@:&5L<"!O<'1I;VYS7"(@=&\@;&ES="!A;&P@;W!T:6]N<RY<;B(N
M#0H@("`@("`@("`@("`B5'EP92!<(B1P<F]G;F%M92!H96QP('-H;W)T8W5T
M<UPB('1O(&QI<W0@86QL(&-O;6UA;F0@<VAO<G1C=71S+EQN(BX-"B`@("`@
M("`@("`@(")4>7!E(%PB)'!R;V=N86UE(&AE;'`@/&-O;6UA;F0^7"(@=&\@
M9V5T('1H92!H96QP(&9O<B!T:&4@<W!E8VEF:65D(&-O;6UA;F0N(CL-"B`@
M("!]#0H@("`@9G!U=',H)'-T9&5R<BP@(B1P=71<;B(I.PT*("`@(&9C;&]S
M92@D<W1D97)R*3L-"B`@("!E>&ET.PT*?0T*#0IF=6YC=&EO;B!C;61(96QP
M*"1C;VUM86YD*0T*>PT*("`@(&=L;V)A;"`D<')O9VYA;64L("1A;&Q?8V]M
M;6%N9',L("1C;VYF:6<[#0H@("`@:68@*"1C;VUM86YD(#T](")O<'1I;VYS
M(BD@>PT*("`@("`@("!R971U<FX-"B`@("`@("`@(D]P=&EO;G,Z7&XB+@T*
M("`@("`@("`B("`@("`M=B`@("`@("`@(&EN8W)E87-E('9E<F)O<VET>2!L
M979E;"`H9&5F875L="`Q*5QN(BX-"B`@("`@("`@(B`@("`@+7$@("`@("`@
M("!B92!Q=6EE="P@9&5C<F5A<V4@=F5R8F]S:71Y(&QE=F5L7&XB+@T*("`@
M("`@("`B("`@("`M8R!F:6QE("`@(&9I;F0@=7-E<B!C;VYF:6=U<F%T:6]N
M(&EN(&!F:6QE)UQN(BX-"B`@("`@("`@(B`@("`@+4,@9FEL92`@("!F:6YD
M('-Y<W1E;2!C;VYF:6=U<F%T:6]N(&EN(&!F:6QE)UQN(BX-"B`@("`@("`@
M(B`@("`@+60@9F]O/6)A<B!S970@=7-E<B!C;VYF:6<@=F%R:6%B;&4@8&9O
M;R<@=&\@8&)A<B=<;B(N#0H@("`@("`@("(@("`@("U$(&9O;SUB87(@<V5T
M('-Y<W1E;2!C;VYF:6<@=F%R:6%B;&4@8&9O;R<@=&\@8&)A<B=<;B(N#0H@
M("`@("`@("(@("`@("U'("`@("`@("`@<W1A<G0@:6X@9W)A<&AI8V%L("A'
M=&LI(&UO9&5<;B(N#0H@("`@("`@("(@("`@("US("`@("`@("`@<W1O<F4@
M=7-E<B!C;VYF:6=U<F%T:6]N7&XB+@T*("`@("`@("`B("`@("`M4R`@("`@
M("`@('-T;W)E('-Y<W1E;2!C;VYF:6=U<F%T:6]N7&XB+@T*("`@("`@("`B
M("`@("`M=2!F;V\@("`@('5N<V5T(&!F;V\G(&EN('1H92!U<V5R(&-O;F9I
M9W5R871I;VY<;B(N#0H@("`@("`@("(@("`@("UH+"`M/R`@("`@9&ES<&QA
M>2!H96QP+W5S86=E("AT:&ES(&UE<W-A9V4I7&XB+@T*("`@("`@("`B("`@
M("`M5B`@("`@("`@('9E<G-I;VX@:6YF;W)M871I;VY<;B([#0H@("`@?2!E
M;'-E:68@*"1C;VUM86YD(#T](")S:&]R=&-U=',B*2![#0H@("`@("`@("1S
M8R`](%!%05)?0V]M;6%N9#HZ9V5T4VAO<G1C=71S*"D[#0H@("`@("`@("1R
M970@/2`B4VAO<G1C=71S.EQN(CL-"B`@("`@("`@9F]R96%C:"`H)'-C(&%S
M("1S(#T^("1C*2![#0H@("`@("`@("`@("`D<F5T("X]('-P<FEN=&8H(B`@
M("`@)2TX<R`E<UQN(BP@)',L("1C*3L-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@)')E=#L-"@T*("`@('T@96QS96EF("@D8V]M;6%N9"`]/2`B=F5R
M<VEO;B(I('L-"B`@("`@("`@<F5T=7)N(")014%2(%9E<G-I;VXZ("(N)$=,
M3T)!3%-;)W!E87)?<&%C:V%G95]V97)S:6]N)UTN#0H@("`@("`@("`@("`@
M("`B7&Y02%`@5F5R<VEO;CH@(BYP:'!V97)S:6]N*"DN#0H@("`@("`@("`@
M("`@("`B7&Y:96YD($5N9VEN92!697)S:6]N.B`B+GIE;F1?=F5R<VEO;B@I
M+@T*("`@("`@("`@("`@("`@(EQN4G5N;FEN9R!O;CH@(BYP:'!?=6YA;64H
M*3L-"@T*("`@('T@96QS96EF("@D:&5L<"`](%!%05)?0V]M;6%N9#HZ9V5T
M2&5L<"@D8V]M;6%N9"DI('L-"B`@("`@("`@:68@*&ES7W-T<FEN9R@D:&5L
M<"DI('L-"B`@("`@("`@("`@(')E='5R;B`B)'!R;V=N86UE("1C;VUM86YD
M(%MO<'1I;VYS72`D:&5L<%QN(CL-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M)&AE;'!;,5T@/3T](&YU;&PI('L-"B`@("`@("`@("`@(')E='5R;B`B)'!R
M;V=N86UE("1C;VUM86YD("1H96QP6S!=(CL-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@(')E='5R;B`B)'!R;V=N86UE("1C;VUM86YD(%MO<'1I
M;VYS72`D:&5L<%LP75QN)&AE;'!;,5TB.PT*("`@("`@("!]#0H@("`@?0T*
M("`@(')E='5R;B`B0V]M;6%N9"`G)&-O;6UA;F0G(&ES(&YO="!V86QI9"P@
M=')Y("=P96%R(&AE;'`G(CL-"GT-"@T*+R\@?7U]#0H-"F9U;F-T:6]N(&5R
M<F]R7VAA;F1L97(H)&5R<FYO+"`D97)R;7-G+"`D9FEL92P@)&QI;F4L("1V
M87)S*2![#0H@("`@:68@*"AD969I;F5D*"=%7U-44DE#5"<I("8F("1E<G)N
M;R`F($5?4U1224-4*2!\?"`A97)R;W)?<F5P;W)T:6YG*"DI('L-"B`@("`@
M("`@:68@*&1E9FEN960H)T5?4U1224-4)RD@)B8@)&5R<FYO("8@15]35%))
M0U0I('L-"B`@("`@("`@("`@(')E='5R;CL@+R\@15]35%))0U0-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H)$=,3T)!3%-;)V-O;F9I9R==+3YG970H)W9E
M<F)O<V4G*2`\(#0I('L-"B`@("`@("`@("`@(')E='5R;CL@+R\@0'-I;&5N
M8V5D(&5R<F]R+"!S:&]W(&%L;"!I9B!D96)U9R!I<R!H:6=H(&5N;W5G:`T*
M("`@("`@("!]#0H@("`@?0T*("`@("1E<G)O<G1Y<&4@/2!A<G)A>2`H#0H@
M("`@("`@($5?15)23U(@("`]/B`@(D5R<F]R(BP-"B`@("`@("`@15]705).
M24Y'("`@/3X@(")787)N:6YG(BP-"B`@("`@("`@15]005)312`@(#T^("`B
M4&%R<VEN9R!%<G)O<B(L#0H@("`@("`@($5?3D]424-%("`@/3X@(").;W1I
M8V4B+`T*("`@("`@("!%7T-/4D5?15)23U(@(#T^("`B0V]R92!%<G)O<B(L
M#0H@("`@("`@($5?0T]215]705).24Y'("`]/B`@(D-O<F4@5V%R;FEN9R(L
M#0H@("`@("`@($5?0T]-4$E,15]%4E)/4B`@/3X@(")#;VUP:6QE($5R<F]R
M(BP-"B`@("`@("`@15]#3TU024Q%7U=!4DY)3D<@/3X@(")#;VUP:6QE(%=A
M<FYI;F<B+`T*("`@("`@("!%7U5315)?15)23U(@/3X@(")5<V5R($5R<F]R
M(BP-"B`@("`@("`@15]54T527U=!4DY)3D<@/3X@(")5<V5R(%=A<FYI;F<B
M+`T*("`@("`@("!%7U5315)?3D]424-%(#T^("`B57-E<B!.;W1I8V4B#0H@
M("`@*3L-"B`@("`D<')E9FEX(#T@)&5R<F]R='EP95LD97)R;F]=.PT*("`@
M(&=L;V)A;"`D7U!%05)?4$A01$E2.PT*("`@(&EF("AS=')I<W1R*"1F:6QE
M+"`D7U!%05)?4$A01$E2*2D@>PT*("`@("`@("`D9FEL92`]('-U8G-T<B@D
M9FEL92P@<W1R;&5N*"1?4$5!4E]02%!$25(I("L@,2D[#0H@("`@?2!E;'-E
M('L-"B`@("`@("`@)&9I;&4@/2!B87-E;F%M92@D9FEL92D[#0H@("`@?0T*
M("`@('!R:6YT(")<;B1P<F5F:7@Z("1E<G)M<V<@:6X@)&9I;&4@;VX@;&EN
M92`D;&EN95QN(CL-"GT-"@T*#0HO*@T*("H@3&]C86P@=F%R:6%B;&5S.@T*
M("H@=&%B+7=I9'1H.B`T#0H@*B!C+6)A<VEC+6]F9G-E=#H@-`T*("H@:6YD
M96YT+71A8G,M;6]D93H@;FEL#0H@*B!M;V1E.B!P:'`-"B`J($5N9#H-"B`J
M+PT*+R\@=FEM-C`P.G-Y;CUP:'`-"@T*/SX-"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O0V%C:&4N
M<&AP````````````````````````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`R-3(U-B`Q,#4Q-30S,S<S,R`P,C`R,30`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$5!4B`Z.B!#86-H92`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y
M<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V
M97)S:6]N(#(N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P*+R\@?"!T
M:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@
M3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?
M,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI
M8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@
M=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@
M;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@
M56QF(%=E;F1E;"`\=6QF+G=E;F1E;$!P:'!D;V,N9&4^("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R!\("`@("`@("`@(%-E8F%S=&EA;B!"97)G
M;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/B`@("`@("`@("`@("`@
M('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@
M0V%C:&4N<&AP+'8@,2XU(#(P,#,O,#$O,#0@,3$Z-30Z-#4@;6H@17AP("0*
M"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PIR97%U:7)E7V]N8V4@)T-A8VAE
M+T5R<F]R+G!H<"<["@HO*BH**B!#86-H92!I<R!A(&)A<V4@8VQA<W,@9F]R
M(&-A8VAE(&EM<&QE;65N=&%T:6]N<RX**@HJ(%1H92!P96%R(&-A8VAE(&UO
M9'5L92!I<R!A(&=E;F5R:6,@9&%T82!C86-H92!W:&EC:"!C86X@8F4@=7-E
M9"!T;R`**B!C86-H92!S8W)I<'0@<G5N<RX@5&AE(&ED96$@8F5H:6YD('1H
M92!C86-H92!I<R!Q=6ET92!S:6UP;&4N($EF('EO=2!H879E"BH@=&AE('-A
M;64@:6YP=70@<&%R86UE=&5R<R!F;W(@=VAA=&5V97(@=&%S:W,O86QG;W)I
M=&AM('EO=2!U<V4@>6]U)VQL"BH@=7-U86QL>2!G970@=&AE('-A;64@;W5T
M<'5T+B!3;R!W:'D@;F]T(&-A8VAI;F<@=&5M<&QA=&5S+"!F=6YC=&EO;G,@
M8V%L;',L"BH@9W)A<&AI8R!G96YE<F%T:6]N(&5T8RX@0V%C:&EN9R!C97)T
M86EN(&%C=&EO;G,@92YG+B!84TQ4('1R86YF;W)M871I;VYS"BH@<V%V97,@
M>6]U(&QO=',@;V8@=&EM92X@"BH**B!4:&4@9&5S:6=N(&]F('1H92!C86-H
M92!R96UI;F1S(&]F(%!(4$QI8G,@<V5S<VEO;B!I;7!L96UE;G1A=&EO;BX@
M02`**B`H4$A03&EB.B!S97-S:6]N*2!C;VYT<F]L;&5R('5S97,@<W1O<F%G
M92!C;VYT86EN97(@*%!(4$QI8CH@8W1?*BYI;F,I('1O('-A=F4@"BH@8V5R
M=&%I;B!D871A("A02%!,:6(Z('-E<W-I;VX@9&%T82DN($EN(&-O;G1R87-T
M('1O('1H92!S97-S:6]N('-T=69F(&ET)W,@=7`@=&\@"BH@>6]U('1O(&=E
M;F5R871E(&%N($E$(&9O<B!T:&4@9&%T82!T;R!C86-H92X@268@>6]U)W)E
M('5S:6YG('1H92!O=71P=70@8V%C:&4**B!Y;W4@;6EG:'0@=7-E('1H92!S
M8W)I<'0@;F%M92!A<R!A('-E960@9F]R(&-A8VAE.CIG96YE<F%T94E$*"DL
M(&EF('EO=7(@=7-I;F<@=&AE"BH@9G5N8W1I;VX@8V%C:&4@>6]U)V0@=7-E
M(&%N(&%R<F%Y('=I=&@@86QL(&9U;F-T:6]N('!A<F%M971E<G,N"BH**B!5
M<V%G92!E>&%M<&QE(&]F('1H92!G96YE<FEC(&1A=&$@8V%C:&4Z"BH**B!R
M97%U:7)E7V]N8V4H)T-A8VAE+G!H<"<I.PHJ"BH@)&-A8VAE(#T@;F5W($-A
M8VAE*"=F:6QE)RP@87)R87DH)V-A8VAE7V1I<B<@/3X@)V-A8VAE+R<I("D[
M"BH@)&ED(#T@)&-A8VAE+3YG96YE<F%T94E$*"=T97-T96YT<GDG*3L**@HJ
M(&EF("@D9&%T82`]("1C86-H92T^9V5T*"1I9"DI('L**B`@("!P<FEN="`B
M0V%C:&4@:&ET+CQB<CY$871A.B`D9&%T82(["BH**B!](&5L<V4@>PHJ("`@
M)&1A=&$@/2`G9&%T82!O9B!A;GD@:VEN9"<["BH@("`D8V%C:&4M/G-A=F4H
M)&ED+"`D9&%T82D["BH@("!P<FEN="`G0V%C:&4@;6ES<RX\8G(^)SL**B!]
M"BH**B!705).24Y'.B!.;R!&:6QE+T1"+51A8FQE+5)O=R!L;V-K:6YG(&ES
M(&EM<&QE;65N=&5D('EE="P**B`@("`@("`@("!I="=S('!O<W-I8FQE+"!T
M:&%T('EO=2!G970@8V]R<G5P=&5D(&1A=&$M96YT<FEE<R!U;F1E<@HJ("`@
M("`@("`@(&)A9"!C:7)C=6US=&%N8V5S("`H97-P96-I86QL>2!W:71H('1H
M92!F:6QE(&-O;G1A:6YE<BD**@HJ($!A=71H;W(@("!5;&8@5V5N9&5L(#QU
M;&8N=V5N9&5L0'!H<&1O8RYD93X**B!`=F5R<VEO;B`@)$ED.B!#86-H92YP
M:'`L=B`Q+C4@,C`P,R\P,2\P-"`Q,3HU-#HT-2!M:B!%>'`@)`HJ($!P86-K
M86=E("!#86-H90HJ($!A8V-E<W,@("!P=6)L:6,**B\*8VQA<W,@0V%C:&4@
M97AT96YD<R!014%2('L*"B`@("`O*BH*("`@("H@16YA8FQE<R`O(&1I<V%B
M;&5S(&-A8VAI;F<N"B`@("`J"B`@("`J(%1/1$\Z($%D9"!E>'!L86YA=&EO
M;B!W:&%T('1H:7,@:7,@9V]O9"!F;W(N"B`@("`J"B`@("`J($!V87(@("`@
M("!B;V]L96%N"B`@("`J($!A8V-E<W,@("!P<FEV871E"B`@("`J+PH@("`@
M=F%R("1C86-H:6YG(#T@=')U93L*"B`@("`O*BH*("`@("H@1V%R8F%G92!C
M;VQL96-T:6]N.B!P<F]B86)I;&ET>2!I;B!S96-O;F1S"B`@("`J"B`@("`J
M($EF('-E="!T;R!A('9A;'5E(&%B;W9E(#`@82!G87)B86=E(&-O;&QE8W1I
M;VX@=VEL;`H@("`@*B!F;'5S:"!A;&P@8V%C:&4@96YT<FEE<R!O;&1E<B!T
M:&%N('1H92!S<&5C:69I960@;G5M8F5R"B`@("`J(&]F('-E8V]N9',N"B`@
M("`J"B`@("`J($!V87(@("`@("!I;G1E9V5R"B`@("`J($!S964@("`@("`D
M9V-?<')O8F%B:6QI='DL("1G8U]M87AL:69E=&EM90H@("`@*B!`86-C97-S
M("`@<'5B;&EC"B`@("`J+PH@("`@=F%R("1G8U]T:6UE("`](#$["@H@("`@
M+RHJ"B`@("`J($=A<F)A9V4@8V]L;&5C=&EO;CH@<')O8F%B:6QI='D@:6X@
M<&5R8V5N=`H@("`@*@H@("`@*B!43T1/.B!!9&0@86X@97AP;&%N871I;VXN
M"B`@("`J"B`@("`J($!V87(@("`@("!I;G1E9V5R("`@("`P(#T^(&YE=F5R
M"B`@("`J($!S964@("`@("`D9V-?=&EM92P@)&=C7VUA>&QI9F5T:6UE"B`@
M("`J($!A8V-E<W,@("!P=6)L:6,*("`@("HO"B`@("!V87(@)&=C7W!R;V)A
M8FEL:71Y(#T@,3L*("`@(`H@("`@+RHJ"B`@("`J($=A<F)A9V4@8V]L;&5C
M=&EO;CH@9&5L971E(&%L;"!E;G1R:65S(&YO="!U<V4@9F]R(&X@<V5C;VYD
M<RX*("`@("H*("`@("H@1&5F875L="!I<R!O;F4@9&%Y+"`V,"`J(#8P("H@
M,C0@/2`X-C0P,"!S96-O;F1S+@H@("`@*@H@("`@*B!`=F%R("!I;G1E9V5R
M"B`@("`J($!S964@("1G8U]P<F]B86)I;&ET>2P@)&=C7W1I;64*("`@("HO
M"B`@("!V87(@)&=C7VUA>&QI9F5T:6UE(#T@.#8T,#`["@H@("`@+RHJ"B`@
M("`J(%-T;W)A9V4@8V]N=&%I;F5R(&]B:F5C="X*("`@("H*("`@("H@0'9A
M<B`@;V)J96-T($-A8VAE7T-O;G1A:6YE<@H@("`@*B\*("`@('9A<B`D8V]N
M=&%I;F5R.PH*("`@("\O"B`@("`O+R!P=6)L:6,@;65T:&]D<PH@("`@+R\*
M"B`@("`O*BH*("`@("H*("`@("H@0'!A<F%M("`@('-T<FEN9R`@3F%M92!O
M9B!C;VYT86EN97(@8VQA<W,*("`@("H@0'!A<F%M("`@(&%R<F%Y("`@07)R
M87D@=VET:"!C;VYT86EN97(@8VQA<W,@;W!T:6]N<PH@("`@*B\*("`@(&9U
M;F-T:6]N($-A8VAE*"1C;VYT86EN97(L("1C;VYT86EN97)?;W!T:6]N<R`]
M("<G*0H@("`@>PH@("`@("`@("1T:&ES+3Y014%2*"D["B`@("`@("`@)&-O
M;G1A:6YE<B`]('-T<G1O;&]W97(H)&-O;G1A:6YE<BD["B`@("`@("`@)&-O
M;G1A:6YE<E]C;&%S<R`]("=#86-H95]#;VYT86EN97)?)R`N("1C;VYT86EN
M97(["B`@("`@("`@)&-O;G1A:6YE<E]C;&%S<V9I;&4@/2`G0V%C:&4O0V]N
M=&%I;F5R+R<@+B`D8V]N=&%I;F5R("X@)RYP:'`G.PH*("`@("`@("!I;F-L
M=61E7V]N8V4@)&-O;G1A:6YE<E]C;&%S<V9I;&4["B`@("`@("`@)'1H:7,M
M/F-O;G1A:6YE<B`](&YE=R`D8V]N=&%I;F5R7V-L87-S*"1C;VYT86EN97)?
M;W!T:6]N<RD["B`@("!]"@H@("`@+R]D96-O;G-T<G5C=&]R"B`@("!F=6YC
M=&EO;B!?0V%C:&4H*0H@("`@>PH@("`@("`@("1T:&ES+3YG87)B86=E0V]L
M;&5C=&EO;B@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M8W5R<F5N="!C86-H:6YG('-T871E+@H@("`@("H*("`@("`J($!R971U<FX@
M(&)O;VQE86X@("`@(%1H92!C=7)R96YT(&-A8VAI;F<@<W1A=&4N"B`@("`@
M*B!`86-C97-S("!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0V%C
M:&EN9R@I"B`@("!["B`@("`@("`@<F5T=7)N("@D=&AI<RT^8V%C:&EN9RD[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!%;F%B;&5S(&]R(&1I<V%B;&5S(&-A
M8VAI;F<N"B`@("`@*@H@("`@("H@0'!A<F%M("`@8F]O;&5A;B`@("`@5&AE
M(&YE=R!C86-H:6YG('-T871E+@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@
M("`@*B\*("`@(&9U;F-T:6]N('-E=$-A8VAI;F<H)'-T871E*0H@("`@>PH@
M("`@("`@("1T:&ES+3YC86-H:6YG(#T@)'-T871E.PH@("`@?0H*("`@("\J
M*@H@("`@*B!2971U<FYS('1H92!R97%U97-T960@9&%T87-E="!I="!I9B!E
M>&ES=',@86YD(&ES(&YO="!E>'!I<F5D"B`@("`J"B`@("`J($!P87)A;2`@
M("!S=')I;F<@(&1A=&%S970@240*("`@("H@0'!A<F%M("`@('-T<FEN9R`@
M8V%C:&4@9W)O=7`*("`@("H@0')E='5R;B`@(&UI>&5D("`@8V%C:&5D(&1A
M=&$@;W(@3E5,3"!O;B!F86EL=7)E"B`@("`J($!A8V-E<W,@("!P=6)L:6,*
M("`@("HO"B`@("!F=6YC=&EO;B!G970H)&ED+"`D9W)O=7`@/2`G9&5F875L
M="<I('L*("`@("`@("!I9B`H(21T:&ES+3YC86-H:6YG*0H@("`@("`@("`@
M("!R971U<FX@)R<["@H@("`@("`@(&EF("@D=&AI<RT^:7-#86-H960H)&ED
M+"`D9W)O=7`I("8F("$D=&AI<RT^:7-%>'!I<F5D*"1I9"P@)&=R;W5P*2D*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YL;V%D*"1I9"P@)&=R;W5P*3L*
M"B`@("`@("`@<F5T=7)N($Y53$P["B`@("!]("\O(&5N9"!F=6YC(&=E=`H*
M("`@("\J*@H@("`@*B!3=&]R97,@=&AE(&=I=F5N(&1A=&$@:6X@=&AE(&-A
M8VAE+@H@("`@*@H@("`@*B!`<&%R86T@("`@<W1R:6YG("!D871A<V5T($E$
M('5S960@87,@8V%C:&4@:61E;G1I9FEE<@H@("`@*B!`<&%R86T@("`@;6EX
M960@("!D871A('1O(&-A8VAE"B`@("`J($!P87)A;2`@("!I;G1E9V5R(&QI
M9F5T:6UE(&]F('1H92!C86-H960@9&%T82!I;B!S96-O;F1S("T@,"!F;W(@
M96YD;&5S<PH@("`@*B!`<&%R86T@("`@<W1R:6YG("!C86-H92!G<F]U<`H@
M("`@*B!`<F5T=7)N("`@8F]O;&5A;@H@("`@*B!`86-C97-S("`@<'5B;&EC
M"B`@("`J+PH@("`@9G5N8W1I;VX@<V%V92@D:60L("1D871A+"`D97AP:7)E
M<R`](#`L("1G<F]U<"`]("=D969A=6QT)RD@>PH@("`@("`@(&EF("@A)'1H
M:7,M/F-A8VAI;F<I"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH*("`@("`@
M("!R971U<FX@)'1H:7,M/F5X=%-A=F4H)&ED+"`D9&%T82P@)R<L)&5X<&ER
M97,L("1G<F]U<"D["B`@("!]("\O(&5N9"!F=6YC('-A=F4*"B`@("`O*BH*
M("`@("H@4W1O<F5S(&$@9&%T87-E="!W:71H(&%D9&ET:6]N86P@=7-E<F1E
M9FEN960@9&%T82X*("`@("H*("`@("H@0'!A<F%M("`@('-T<FEN9R`@9&%T
M87-E="!)1`H@("`@*B!`<&%R86T@("`@;6EX960@("!D871A('1O('-T;W)E
M"B`@("`J($!P87)A;2`@("!S=')I;F<@(&%D9&ET:6]N86P@=7-E<F1E9FEN
M960@9&%T80H@("`@*B!`<&%R86T@("`@;6EX960@("!U<V5R9&5F:6YE9"!E
M>'!I<F4@9&%T90H@("`@*B!`<&%R86T@("`@<W1R:6YG("!C86-H92!G<F]U
M<`H@("`@*B!`<F5T=7)N("`@8F]O;&5A;@H@("`@*B!`=&AR;W=S("`@0V%C
M:&5?17)R;W(*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B!`<V5E("`@
M("`@9V5T57-E<F1A=&$H*0H@("`@*B\*("`@(&9U;F-T:6]N(&5X=%-A=F4H
M)&ED+"`D8V%C:&5D871A+"`D=7-E<F1A=&$L("1E>'!I<F5S(#T@,"P@)&=R
M;W5P(#T@)V1E9F%U;'0G*2!["B`@("`@("`@:68@*"$D=&AI<RT^8V%C:&EN
M9RD*("`@("`@("`@("`@<F5T=7)N('1R=64["@H@("`@("`@(')E='5R;B`D
M=&AI<RT^8V]N=&%I;F5R+3YS879E*"1I9"P@)&-A8VAE9&%T82P@)&5X<&ER
M97,L("1G<F]U<"P@)'5S97)D871A*3L*("`@('T@+R\@96YD(&9U;F,@97AT
M4V%V90H*("`@("\J*@H@("`@*B!,;V%D<R!T:&4@9VEV96X@240@9G)O;2!T
M:&4@8V%C:&4N"B`@("`J"B`@("`J($!P87)A;2`@("!S=')I;F<@(&1A=&%S
M970@240*("`@("H@0'!A<F%M("`@('-T<FEN9R`@8V%C:&4@9W)O=7`*("`@
M("H@0')E='5R;B`@(&UI>&5D("`@8V%C:&5D(&1A=&$@;W(@3E5,3"!O;B!F
M86EL=7)E"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("HO"B`@("!F=6YC
M=&EO;B!L;V%D*"1I9"P@)&=R;W5P(#T@)V1E9F%U;'0G*2!["B`@("`@("`@
M:68@*"$D=&AI<RT^8V%C:&EN9RD*("`@("`@("`@("`@<F5T=7)N("<G.PH*
M("`@("`@("!R971U<FX@)'1H:7,M/F-O;G1A:6YE<BT^;&]A9"@D:60L("1G
M<F]U<"D["B`@("!]("\O(&5N9"!F=6YC(&QO860*"B`@("`O*BH*("`@("H@
M4F5T=7)N<R!T:&4@=7-E<F1A=&$@9FEE;&0@;V8@82!C86-H960@9&%T82!S
M970N"B`@("`J"B`@("`J($!P87)A;2`@("!S=')I;F<@(&1A=&%S970@240*
M("`@("H@0'!A<F%M("`@('-T<FEN9R`@8V%C:&4@9W)O=7`*("`@("H@0')E
M='5R;B`@('-T<FEN9R`@=7-E<F1A=&$*("`@("H@0&%C8V5S<R`@('!U8FQI
M8PH@("`@*B!`<V5E("`@("`@97AT4V%V92@I"B`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T57-E<F1A=&$H)&ED+"`D9W)O=7`@/2`G9&5F875L="<I('L*("`@
M("`@("!I9B`H(21T:&ES+3YC86-H:6YG*0H@("`@("`@("`@("!R971U<FX@
M)R<["@H@("`@("`@(')E='5R;B`D=&AI<RT^8V]N=&%I;F5R+3YG9715<V5R
M9&%T82@D:60L("1G<F]U<"D["B`@("!]("\O(&5N9"!F=6YC(&=E=%5S97)D
M871A"@H@("`@+RHJ"B`@("`J(%)E;6]V97,@=&AE('-P96-I9FEE9"!D871A
M<V5T(&9R;VT@=&AE(&-A8VAE+@H@("`@*@H@("`@*B!`<&%R86T@("`@<W1R
M:6YG("!D871A<V5T($E$"B`@("`J($!P87)A;2`@("!S=')I;F<@(&-A8VAE
M(&=R;W5P"B`@("`J($!R971U<FX@("!B;V]L96%N"B`@("`J($!A8V-E<W,@
M("!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F4H)&ED+"`D9W)O
M=7`@/2`G9&5F875L="<I('L*("`@("`@("!I9B`H(21T:&ES+3YC86-H:6YG
M*0H@("`@("`@("`@("!R971U<FX@=')U93L*"B`@("`@("`@<F5T=7)N("1T
M:&ES+3YC;VYT86EN97(M/G)E;6]V92@D:60L("1G<F]U<"D["B`@("!]("\O
M(&5N9"!F=6YC(')E;6]V90H*("`@("\J*@H@("`@*B!&;'5S:&5S('1H92!C
M86-H92`M(')E;6]V97,@86QL(&1A=&$@9G)O;2!I=`H@("`@*@H@("`@*B!`
M<&%R86T@("`@<W1R:6YG("!C86-H92!G<F]U<"P@:68@96UP='D@86QL(&=R
M;W5P<R!W:6QL(&)E(&9L87-H960*("`@("H@0')E='5R;B`@(&EN=&5G97(@
M;G5M8F5R(&]F(')E;6]V960@9&%T87-E=',*("`@("HO"B`@("!F=6YC=&EO
M;B!F;'5S:"@D9W)O=7`@/2`G9&5F875L="<I('L*("`@("`@("!I9B`H(21T
M:&ES+3YC86-H:6YG*0H@("`@("`@("`@("!R971U<FX@=')U93L*"B`@("`@
M("`@<F5T=7)N("1T:&ES+3YC;VYT86EN97(M/F9L=7-H*"1G<F]U<"D["B`@
M("!]("\O(&5N9"!F=6YC(&9L=7-H"@H@("`@+RHJ"B`@("`J($-H96-K<R!I
M9B!A(&1A=&%S970@97AI<W1S+@H@("`@*@H@("`@*B!.;W1E.B!T:&ES(&1O
M97,@;F]T('-A>2!T:&%T('1H92!C86-H960@9&%T82!I<R!N;W0@97AP:7)E
M9"$*("`@("H*("`@("H@0'!A<F%M("`@('-T<FEN9R`@9&%T87-E="!)1`H@
M("`@*B!`<&%R86T@("`@<W1R:6YG("!C86-H92!G<F]U<`H@("`@*B!`<F5T
M=7)N("`@8F]O;&5A;@H@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J+PH@
M("`@9G5N8W1I;VX@:7-#86-H960H)&ED+"`D9W)O=7`@/2`G9&5F875L="<I
M('L*("`@("`@("!I9B`H(21T:&ES+3YC86-H:6YG*0H@("`@("`@("`@("!R
M971U<FX@9F%L<V4["@H@("`@("`@(')E='5R;B`D=&AI<RT^8V]N=&%I;F5R
M+3YI<T-A8VAE9"@D:60L("1G<F]U<"D["B`@("!]("\O(&5N9"!F=6YC(&ES
M0V%C:&5D"@H@("`@+RHJ"B`@("`J($-H96-K<R!I9B!A(&1A=&%S970@:7,@
M97AP:7)E9`H@("`@*@H@("`@*B!`<&%R86T@("`@<W1R:6YG("!D871A<V5T
M($E$"B`@("`J($!P87)A;2`@("!S=')I;F<@(&-A8VAE(&=R;W5P"B`@("`J
M($!P87)A;2`@("!I;G1E9V5R(&UA>&EM=6T@86=E(&9O<B!T:&4@8V%C:&5D
M(&1A=&$@:6X@<V5C;VYD<R`M(#`@9F]R(&5N9&QE<W,*("`@("H@("`@("`@
M("`@("`@("`@("`@268@=&AE(&-A8VAE9"!D871A(&ES(&]L9&5R(&)U="!T
M:&4@9VEV96X@;&EF971I;64@:70@=VEL;`H@("`@*B`@("`@("`@("`@("`@
M("`@("!B92!R96UO=F5D(&9R;VT@=&AE(&-A8VAE+B!9;W4@9&]N)W0@:&%V
M92!T;R!P<F]V:61E('1H:7,*("`@("H@("`@("`@("`@("`@("`@("`@87)G
M=6UE;G0@:68@>6]U(&-A;&P@:7-%>'!I<F5D*"DN($5V97)Y(&1A=&%S970@
M:VYO=W,*("`@("H@("`@("`@("`@("`@("`@("`@:70G<R!E>'!I<F4@9&%T
M92!A;F0@=VEL;"!B92!R96UO=F5D(&%U=&]M871I8V%L;'DN(%5S90H@("`@
M*B`@("`@("`@("`@("`@("`@("!T:&ES(&]N;'D@:68@>6]U(&MN;W<@=VAA
M="!Y;W4G<F4@9&]I;F<N+BX*("`@("H@0')E='5R;B`@(&)O;VQE86X*("`@
M("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N(&ES17AP
M:7)E9"@D:60L("1G<F]U<"`]("=D969A=6QT)RP@)&UA>%]A9V4@/2`P*2![
M"B`@("`@("`@:68@*"$D=&AI<RT^8V%C:&EN9RD*("`@("`@("`@("`@<F5T
M=7)N('1R=64["@H@("`@("`@(')E='5R;B`D=&AI<RT^8V]N=&%I;F5R+3YI
M<T5X<&ER960H)&ED+"`D9W)O=7`L("1M87A?86=E*3L*("`@('T@+R\@96YD
M(&9U;F,@:7-%>'!I<F5D"@H@("`@+RHJ"B`@("`J($=E;F5R871E<R!A(")U
M;FEQ=64B($E$(&9O<B!T:&4@9VEV96X@=F%L=64*("`@("H*("`@("H@5&AI
M<R!I<R!A('%U:6-K(&)U="!D:7)T>2!H86-K('1O(&=E="!A(")U;FEQ=64B
M($E$(&9O<B!A(&%N>2!K:6YD(&]F('9A<FEA8FQE+@H@("`@*B!)1"!C;&%S
M:&5S(&UI9VAT(&]C8W5R(&9R;VT@=&EM92!T;R!T:6UE(&%L=&AO=6=H('1H
M97D@87)E(&5X=')E;64@=6YL:6ME;'DA"B`@("`J"B`@("`J($!P87)A;2`@
M("!M:7AE9"`@('9A<FEA8FQE('1O(&=E;F5R871E(&$@240@9F]R"B`@("`J
M($!R971U<FX@("!S=')I;F<@(")U;FEQ=64B($E$"B`@("`J($!A8V-E<W,@
M("!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!G96YE<F%T94E$*"1V87)I
M86)L92D@>PH@("`@("`@("\O(%=!4DY)3D<Z($E$(&-L87-H97,@87)E('!O
M<W-I8FQE(&%L=&AO=6=H('5N;&EK96QY"B`@("`@("`@<F5T=7)N(&UD-2AS
M97)I86QI>F4H)'9A<FEA8FQE*2D["B`@("!]"@H@("`@+RHJ"B`@("`J($-A
M;&QS('1H92!G87)B86=E(&-O;&QE8W1O<B!O9B!T:&4@<W1O<F%G92!O8FIE
M8W0@=VET:"!A(&-E<G1A:6X@<')O8F%B:6QI='D*("`@("H*("`@("H@0'!A
M<F%M("`@(&)O;VQE86X@1F]R8V4@82!G87)B86=E(&-O;&QE8W1I;VX@<G5N
M/PH@("`@*B!`<V5E("`D9V-?<')O8F%B:6QI='DL("1G8U]T:6UE"B`@("`J
M+PH@("`@9G5N8W1I;VX@9V%R8F%G94-O;&QE8W1I;VXH)&9O<F-E(#T@9F%L
M<V4I('L*("`@("`@("!S=&%T:6,@)&QA<W1?<G5N(#T@,#L*"B`@("`@("`@
M:68@*"$D=&AI<RT^8V%C:&EN9RD*("`@("`@("`@("`@<F5T=7)N.PH*("`@
M("`@("!S<F%N9"@H9&]U8FQE*2!M:6-R;W1I;64H*2`J(#$P,#`P,#`I.PH*
M("`@("`@("`O+R!T:6UE(&%N9"!P<F]B86)I;&ET>2!B87-E9`H@("`@("`@
M(&EF("@H)&9O<F-E*2!\?"`H)&QA<W1?<G5N("8F("1L87-T7W)U;B`\('1I
M;64H*2`K("1T:&ES+3YG8U]T:6UE*2!\?"`H<F%N9"@Q+"`Q,#`I(#P@)'1H
M:7,M/F=C7W!R;V)A8FEL:71Y*2D@>PH@("`@("`@("`@("`D=&AI<RT^8V]N
M=&%I;F5R+3YG87)B86=E0V]L;&5C=&EO;B@D=&AI<RT^9V-?;6%X;&EF971I
M;64I.PH@("`@("`@("`@("`D;&%S=%]R=6X@/2!T:6UE*"D["B`@("`@("`@
M?0H@("`@?2`O+R!E;F0@9G5N8R!G87)B86=E0V]L;&5C=&EO;@H*?2`O+R!E
M;F0@8VQA<W,@8V%C:&4*/SX*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W!E87)C;60N<&AP+F]R:6<`````
M````````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,S4V,3<@,3`U
M,34T,S,W,S,@,#(Q-38U`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP#0HO+PT*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK#0HO+R!\(%!(4"!697)S:6]N(#4@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!#;W!Y<FEG:'0@
M*&,I(#$Y.3<M,C`P-"!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L-"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I
M;VX@,RXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`T*+R\@?"!T:&%T
M(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#
M14Y312P@86YD(&ES("`@("`@("!\#0HO+R!\(&%V86EL86)L92!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG('5R;#H@("`@
M("`@("`@('P-"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@
M?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI
M8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\#0HO+R!\(&]B=&%I;B!I="!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E
M('1O("`@("`@("`@('P-"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A
M;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@
M?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\($%U=&AO
M<G,Z(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P-"B\O('P@("`@("`@("`@5&]M87,@5BY6
M+D-O>"`\8V]X0&ED96-N970N8V]M/B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`T*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O#0HO+R`D260Z('!E87)C
M;60N<&AP+'8@,2XS,R`R,#`V+S`Q+S`R(#$X.C`U.C4S(&-E;&QO9R!%>'`@
M)`T*#0IO8E]E;F1?8VQE86XH*3L-"FEF("@A9&5F:6YE9"@G4$5!4E]254Y4
M65!%)RDI('L-"B`@("`O+R!T:&ES(&ES(&1E9FEN960@:6X@<&5C;&-M9"YP
M:'`@87,@)W!E8VPG#0H@("`@9&5F:6YE*"=014%27U)53E194$4G+"`G<&5A
M<B<I.PT*?0T*9&5F:6YE*"=014%27TE'3D]215]"04-+5%)!0T4G+"`Q*3L-
M"FEF("@A9G5N8W1I;VY?97AI<W1S*"=F:6QE7V=E=%]C;VYT96YT<R<I*2![
M#0H@("`@9G5N8W1I;VX@9FEL95]G971?8V]N=&5N=',H)&9I;&5N86UE*0T*
M("`@('L-"B`@("`@("`@)&9P(#T@9F]P96XH)&9I;&5N86UE+"`G<F(G*3L-
M"B`@("`@("`@)')E="`]("<G.PT*("`@("`@("!W:&EL92`H(69E;V8H)&9P
M*2D@>PT*("`@("`@("`@("`@)')E="`N/2!F<F5A9"@D9G`L(#@P.3(I.SL-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)')E=#L-"B`@("!]#0I]#0HO
M*BH-"B`J($!N;V1E<"!'=&L-"B`J+PT*:68@*"<O:&]M92]L=6-E<B]W;W)K
M+W!E87(O<VAA<F4O<&AP)R`A/2`G0"<N)VEN8VQU9&5?<&%T:"<N)T`G*2![
M#0H@("`@:6YI7W-E="@G:6YC;'5D95]P871H)RP@)R]H;VUE+VQU8V5R+W=O
M<FLO<&5A<B]S:&%R92]P:'`G*3L-"B`@("`D<F%W(#T@9F%L<V4[#0I](&5L
M<V4@>PT*("`@("\O('1H:7,@:7,@82!R87<L('5N:6YS=&%L;&5D('!E87(L
M(&5I=&AE<B!A(&-V<R!C:&5C:V]U="P@;W(@<&AP(&1I<W1R;PT*("`@("1R
M87<@/2!T<G5E.PT*?0T*0&EN:5]S970H)V%L;&]W7W5R;%]F;W!E;B<L('1R
M=64I.PT*:68@*"%I;FE?9V5T*"=S869E7VUO9&4G*2D@>PT*("`@($!S971?
M=&EM95]L:6UI="@P*3L-"GT-"F]B7VEM<&QI8VET7V9L=7-H*'1R=64I.PT*
M0&EN:5]S970H)W1R86-K7V5R<F]R<R<L('1R=64I.PT*0&EN:5]S970H)VAT
M;6Q?97)R;W)S)RP@9F%L<V4I.PT*0&EN:5]S970H)VUA9VEC7W%U;W1E<U]R
M=6YT:6UE)RP@9F%L<V4I.PT*)%]014%27U!(4$1)4B`]("<C)"5>)BHG.PT*
M<V5T7V5R<F]R7VAA;F1L97(H)V5R<F]R7VAA;F1L97(G*3L-"@T*)'!E87)?
M<&%C:V%G95]V97)S:6]N(#T@(C$N-"XY(CL-"@T*<F5Q=6ER95]O;F-E("=0
M14%2+G!H<"<[#0IR97%U:7)E7V]N8V4@)U!%05(O1G)O;G1E;F0N<&AP)SL-
M"G)E<75I<F5?;VYC92`G4$5!4B]#;VYF:6<N<&AP)SL-"G)E<75I<F5?;VYC
M92`G4$5!4B]#;VUM86YD+G!H<"<[#0IR97%U:7)E7V]N8V4@)T-O;G-O;&4O
M1V5T;W!T+G!H<"<[#0H-"@T*4$5!4E]#;VUM86YD.CIS971&<F]N=&5N9%1Y
M<&4H)T-,22<I.PT*)&%L;%]C;VUM86YD<R`](%!%05)?0V]M;6%N9#HZ9V5T
M0V]M;6%N9',H*3L-"@T*+R\@<F5M;W9E('1H:7,@;F5X="!P87)T('=H96X@
M=V4@<W1O<"!S=7!P;W)T:6YG('1H870@8W)A<"UA<W,@4$A0(#0N,@T*:68@
M*"%I<W-E="@D7U-%4E9%4ELG87)G=B==*2`F)B`A:7-S970H)&%R9W8I("8F
M("%I<W-E="@D2%144%]315)615)?5D%24ULG87)G=B==*2D@>PT*("`@(&1I
M92@G15)23U(Z(&5I=&AE<B!U<V4@=&AE($-,22!P:'`@97AE8W5T86)L92P@
M;W(@<V5T(')E9VES=&5R7V%R9V-?87)G=CU/;B!I;B!P:'`N:6YI)RD[#0I]
M#0HD87)G=B`]($-O;G-O;&5?1V5T;W!T.CIR96%D4$A007)G=B@I.PT*+R\@
M9FEX($-'22!S87!I(&]D9&ET>2`M('1H92`M+2!I;B!P96%R+F)A="]P96%R
M(&ES(&YO="!R96UO=F5D#0II9B`H<&AP7W-A<&E?;F%M92@I("$]("=C;&DG
M("8F(&ES<V5T*"1A<F=V6S%=*2`F)B`D87)G=ELQ72`]/2`G+2TG*2![#0H@
M("`@=6YS970H)&%R9W9;,5TI.PT*("`@("1A<F=V(#T@87)R87E?=F%L=65S
M*"1A<F=V*3L-"GT-"B1P<F]G;F%M92`](%!%05)?4E5.5%E013L-"FEF("AI
M;E]A<G)A>2@G9V5T;W!T,B<L(&=E=%]C;&%S<U]M971H;V1S*"=#;VYS;VQE
M7T=E=&]P="<I*2D@>PT*("`@(&%R<F%Y7W-H:69T*"1A<F=V*3L-"B`@("`D
M;W!T:6]N<R`]($-O;G-O;&5?1V5T;W!T.CIG971O<'0R*"1A<F=V+"`B8SI#
M.F0Z1#I':#]S4W%U.G96(BD[#0I](&5L<V4@>PT*("`@("1O<'1I;VYS(#T@
M0V]N<V]L95]'971O<'0Z.F=E=&]P="@D87)G=BP@(F,Z0SID.D0Z1V@_<U-Q
M=3IV5B(I.PT*?0T*:68@*%!%05(Z.FES17)R;W(H)&]P=&EO;G,I*2![#0H@
M("`@=7-A9V4H)&]P=&EO;G,I.PT*?0T*#0HD;W!T<R`]("1O<'1I;VYS6S!=
M.PT*#0HD9F5T>7!E(#T@)T-,22<[#0II9B`H)'!R;V=N86UE(#T]("=G<&5A
M<B<@?'P@)'!R;V=N86UE(#T]("=P96%R+6=T:R<I('L-"B`@("`D9F5T>7!E
M(#T@)T=T:R<[#0I](&5L<V4@>PT*("`@(&9O<F5A8V@@*"1O<'1S(&%S("1O
M<'0I('L-"B`@("`@("`@:68@*"1O<'1;,%T@/3T@)T<G*2![#0H@("`@("`@
M("`@("`D9F5T>7!E(#T@)T=T:R<[#0H@("`@("`@('T-"B`@("!]#0I]#0HO
M+T-H96-K(&EF($=T:R!A;F0@4$A0(#X](#4N,2XP#0II9B`H)&9E='EP92`]
M/2`G1W1K)R`F)B!V97)S:6]N7V-O;7!A<F4H<&AP=F5R<VEO;B@I+"`G-2XQ
M+C`G+"`G/CTG*2D@>PT*("`@("1F971Y<&4@/2`G1W1K,B<[#0I]#0H-"B1P
M96%R7W5S97)?8V]N9FEG(#T@)R<[#0HD<&5A<E]S>7-T96U?8V]N9FEG(#T@
M)R<[#0HD<W1O<F5?=7-E<E]C;VYF:6<@/2!F86QS93L-"B1S=&]R95]S>7-T
M96U?8V]N9FEG(#T@9F%L<V4[#0HD=F5R8F]S92`](#$[#0H-"F9O<F5A8V@@
M*"1O<'1S(&%S("1O<'0I('L-"B`@("!S=VET8V@@*"1O<'1;,%TI('L-"B`@
M("`@("`@8V%S92`G8R<Z#0H@("`@("`@("`@("`D<&5A<E]U<V5R7V-O;F9I
M9R`]("1O<'1;,5T[#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@8V%S
M92`G0R<Z#0H@("`@("`@("`@("`D<&5A<E]S>7-T96U?8V]N9FEG(#T@)&]P
M=%LQ73L-"B`@("`@("`@("`@(&)R96%K.PT*("`@('T-"GT-"@T*4$5!4E]#
M;VUM86YD.CIS971&<F]N=&5N9%1Y<&4H)&9E='EP92D[#0HD=6D@/2`F4$5!
M4E]#;VUM86YD.CIG971&<F]N=&5N9$]B:F5C="@I.PT*)&-O;F9I9R`]("90
M14%27T-O;F9I9SHZ<VEN9VQE=&]N*"1P96%R7W5S97)?8V]N9FEG+"`D<&5A
M<E]S>7-T96U?8V]N9FEG*3L-"@T*:68@*%!%05(Z.FES17)R;W(H)&-O;F9I
M9RDI('L-"B`@("`D7V9I;&4@/2`G)SL-"B`@("!I9B`H)'!E87)?=7-E<E]C
M;VYF:6<@(3T](&9A;'-E*2![#0H@("`@("`@)%]F:6QE("X]("1P96%R7W5S
M97)?8V]N9FEG.PT*("`@('T-"B`@("!I9B`H)'!E87)?<WES=&5M7V-O;F9I
M9R`A/3T@9F%L<V4I('L-"B`@("`@("`D7V9I;&4@+CT@)R\G("X@)'!E87)?
M<WES=&5M7V-O;F9I9SL-"B`@("!]#0H@("`@:68@*"1?9FEL92`]/2`G+R<I
M('L-"B`@("`@("`@)%]F:6QE(#T@)U1H92!D969A=6QT(&-O;F9I9R!F:6QE
M)SL-"B`@("!]#0H@("`@)&-O;F9I9RT^9V5T365S<V%G92@I.PT*("`@("1U
M:2T^;W5T<'5T1&%T82@B15)23U(Z("1?9FEL92!I<R!N;W0@82!V86QI9"!C
M;VYF:6<@9FEL92!O<B!I<R!C;W)R=7!T960N(BD[#0H@("`@+R\@5V4@<W1O
M<"P@=V4@:&%V92!N;R!I9&5A('=H97)E('=E(&%R92`Z*0T*("`@(&5X:70H
M*3L@("`@#0I]#0H-"B\O('1H:7,@:7,@=7-E9"!I;B!T:&4@97)R;W(@:&%N
M9&QE<B!T;R!R971R:65V92!A(')E;&%T:79E('!A=&@-"B1?4$5!4E]02%!$
M25(@/2`D8V]N9FEG+3YG970H)W!H<%]D:7(G*3L-"B1U:2T^<V5T0V]N9FEG
M*"1C;VYF:6<I.PT*4$5!4CHZ<V5T17)R;W)(86YD;&EN9RA014%27T524D]2
M7T-!3$Q"04-++"!A<G)A>2@D=6DL(")D:7-P;&%Y1F%T86Q%<G)O<B(I*3L-
M"FEF("AI;FE?9V5T*"=S869E7VUO9&4G*2D@>PT*("`@("1U:2T^;W5T<'5T
M1&%T82@G5T%23DE.1SH@<G5N;FEN9R!I;B!S869E(&UO9&4@<F5Q=6ER97,@
M=&AA="!A;&P@9FEL97,@8W)E871E9"`G("X-"B`@("`@("`@)V)E('1H92!S
M86UE('5I9"!A<R!T:&4@8W5R<F5N="!S8W)I<'0N("!02%`@<F5P;W)T<R!T
M:&ES('-C<FEP="!I<R!U:60Z("<@+@T*("`@("`@("!`9V5T;7EU:60H*2`N
M("<L(&%N9"!C=7)R96YT('5S97(@:7,Z("<@+B!`9V5T7V-U<G)E;G1?=7-E
M<B@I*3L-"GT-"@T*)'9E<F)O<V4@/2`D8V]N9FEG+3YG970H(G9E<F)O<V4B
M*3L-"B1C;61O<'1S(#T@87)R87DH*3L-"@T*:68@*"1R87<I('L-"B`@("!I
M9B`H(21C;VYF:6<M/FES1&5F:6YE9$QA>65R*"=U<V5R)RD@)B8@(21C;VYF
M:6<M/FES1&5F:6YE9$QA>65R*"=S>7-T96TG*2D@>PT*("`@("`@("`D9F]U
M;F0@/2!F86QS93L-"B`@("`@("`@9F]R96%C:"`H)&]P=',@87,@)&]P="D@
M>PT*("`@("`@("`@("`@:68@*"1O<'1;,%T@/3T@)V0G('Q\("1O<'1;,%T@
M/3T@)T0G*2![#0H@("`@("`@("`@("`@("`@)&9O=6YD(#T@=')U93L@+R\@
M=&AE('5S97(@:VYO=W,@=VAA="!T:&5Y(&%R92!D;VEN9RP@86YD(&%R92!S
M971T:6YG(&-O;F9I9R!V86QU97,-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H(21F;W5N9"D@>PT*("`@("`@("`@("`@+R\@;F\@
M<')I;W(@<G5N<RP@=')Y('1O(&EN<W1A;&P@4$5!4@T*("`@("`@("`@("`@
M:68@*'-T<G!O<RAD:7)N86UE*%]?1DE,15]?*2P@)W-C<FEP=',G*2D@>PT*
M("`@("`@("`@("`@("`@("1P86-K86=E>&UL(#T@9&ER;F%M92AD:7)N86UE
M*%]?1DE,15]?*2D@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)W!A8VMA9V4R
M+GAM;"<[#0H@("`@("`@("`@("`@("`@)'!E87)B87-E(#T@9&ER;F%M92AD
M:7)N86UE*%]?1DE,15]?*2D[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("1P86-K86=E>&UL(#T@9&ER;F%M92A?7T9)3$5?7RD@
M+B!$25)%0U1/4EE?4T5005)!5$]2("X@)W!A8VMA9V4R+GAM;"<[#0H@("`@
M("`@("`@("`@("`@)'!E87)B87-E(#T@9&ER;F%M92A?7T9)3$5?7RD[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H9FEL95]E>&ES=',H)'!A
M8VMA9V5X;6PI*2![#0H@("`@("`@("`@("`@("`@)&]P=&EO;G-;,5T@/2!A
M<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)VEN<W1A;&PG+`T*("`@("`@
M("`@("`@("`@("`@("`D<&%C:V%G97AM;`T*("`@("`@("`@("`@("`@("D[
M#0H@("`@("`@("`@("`@("`@)&-O;F9I9RT^<V5T*"=P:'!?9&ER)RP@)'!E
M87)B87-E("X@1$E214-43U)97U-%4$%2051/4B`N("=P:'`G*3L-"B`@("`@
M("`@("`@("`@("`D8V]N9FEG+3YS970H)V1A=&%?9&ER)RP@)'!E87)B87-E
M("X@1$E214-43U)97U-%4$%2051/4B`N("=D871A)RD[#0H@("`@("`@("`@
M("`@("`@)&-O;F9I9RT^<V5T*"=D;V-?9&ER)RP@)'!E87)B87-E("X@1$E2
M14-43U)97U-%4$%2051/4B`N("=D;V-S)RD[#0H@("`@("`@("`@("`@("`@
M)&-O;F9I9RT^<V5T*"=T97-T7V1I<B<L("1P96%R8F%S92`N($1)4D5#5$]2
M65]315!!4D%43U(@+B`G=&5S=',G*3L-"B`@("`@("`@("`@("`@("`D8V]N
M9FEG+3YS970H)V5X=%]D:7(G+"`D<&5A<F)A<V4@+B!$25)%0U1/4EE?4T50
M05)!5$]2("X@)V5X=&5N<VEO;G,G*3L-"B`@("`@("`@("`@("`@("`D8V]N
M9FEG+3YS970H)V)I;E]D:7(G+"`D<&5A<F)A<V4I.PT*("`@("`@("`@("`@
M("`@("1C;VYF:6<M/FUE<F=E0V]N9FEG1FEL92@D<&5A<F)A<V4@+B`G<&5A
M<BYI;FDG+"!F86QS92D[#0H@("`@("`@("`@("`@("`@)&-O;F9I9RT^<W1O
M<F4H*3L-"B`@("`@("`@("`@("`@("`D8V]N9FEG+3YS970H)V%U=&]?9&ES
M8V]V97(G+"`Q*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@('T-
M"GT-"F9O<F5A8V@@*"1O<'1S(&%S("1O<'0I('L-"B`@("`D<&%R86T@/2`A
M96UP='DH)&]P=%LQ72D@/R`D;W!T6S%=(#H@=')U93L-"B`@("!S=VET8V@@
M*"1O<'1;,%TI('L-"B`@("`@("`@8V%S92`G9"<Z#0H@("`@("`@("`@("!L
M:7-T*"1K97DL("1V86QU92D@/2!E>'!L;V1E*"<])RP@)'!A<F%M*3L-"B`@
M("`@("`@("`@("1C;VYF:6<M/G-E="@D:V5Y+"`D=F%L=64L("=U<V5R)RD[
M#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@8V%S92`G1"<Z#0H@("`@
M("`@("`@("!L:7-T*"1K97DL("1V86QU92D@/2!E>'!L;V1E*"<])RP@)'!A
M<F%M*3L-"B`@("`@("`@("`@("1C;VYF:6<M/G-E="@D:V5Y+"`D=F%L=64L
M("=S>7-T96TG*3L-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("!C87-E
M("=S)SH-"B`@("`@("`@("`@("1S=&]R95]U<V5R7V-O;F9I9R`]('1R=64[
M#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@8V%S92`G4R<Z#0H@("`@
M("`@("`@("`D<W1O<F5?<WES=&5M7V-O;F9I9R`]('1R=64[#0H@("`@("`@
M("`@("!B<F5A:SL-"B`@("`@("`@8V%S92`G=2<Z#0H@("`@("`@("`@("`D
M8V]N9FEG+3YR96UO=F4H)'!A<F%M+"`G=7-E<B<I.PT*("`@("`@("`@("`@
M8G)E86L[#0H@("`@("`@(&-A<V4@)W8G.@T*("`@("`@("`@("`@)&-O;F9I
M9RT^<V5T*"=V97)B;W-E)RP@)&-O;F9I9RT^9V5T*"=V97)B;W-E)RD@*R`Q
M*3L-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("!C87-E("=Q)SH-"B`@
M("`@("`@("`@("1C;VYF:6<M/G-E="@G=F5R8F]S92<L("1C;VYF:6<M/F=E
M="@G=F5R8F]S92<I("T@,2D[#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@
M("`@8V%S92`G5B<Z#0H@("`@("`@("`@("!U<V%G92AN=6QL+"`G=F5R<VEO
M;B<I.PT*("`@("`@("!C87-E("=C)SH-"B`@("`@("`@8V%S92`G0R<Z#0H@
M("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@9&5F875L=#H-"B`@("`@("`@
M("`@("\O(&%L;"!N;VX@<&5A<B!P87)A;7,@9V]E<R!T;R!T:&4@8V]M;6%N
M9`T*("`@("`@("`@("`@)&-M9&]P='-;)&]P=%LP75T@/2`D<&%R86T[#0H@
M("`@("`@("`@("!B<F5A:SL-"B`@("!]#0I]#0H-"FEF("@D<W1O<F5?<WES
M=&5M7V-O;F9I9RD@>PT*("`@("1C;VYF:6<M/G-T;W)E*"=S>7-T96TG*3L-
M"GT-"@T*:68@*"1S=&]R95]U<V5R7V-O;F9I9RD@>PT*("`@("1C;VYF:6<M
M/G-T;W)E*"=U<V5R)RD[#0I]#0H-"B1C;VUM86YD(#T@*&ES<V5T*"1O<'1I
M;VYS6S%=6S!=*2D@/R`D;W!T:6]N<ULQ75LP72`Z(&YU;&P[#0H-"FEF("AE
M;7!T>2@D8V]M;6%N9"D@)B8@*"1S=&]R95]U<V5R7V-O;F9I9R!\?"`D<W1O
M<F5?<WES=&5M7V-O;F9I9RDI('L-"B`@("!E>&ET.PT*?0T*#0II9B`H)&9E
M='EP92`]/2`G1W1K)R!\?"`D9F5T>7!E(#T]("='=&LR)RD@>PT*("`@(&EF
M("@A)&-O;F9I9RT^=F%L:61#;VYF:6=U<F%T:6]N*"DI('L-"B`@("`@("`@
M4$5!4CHZ<F%I<V5%<G)O<B@G0U))5$E#04P@15)23U(Z(&YO(&5X:7-T:6YG
M('9A;&ED(&-O;F9I9W5R871I;VX@9FEL97,@9F]U;F0@:6X@9FEL97,@)R`N
M#0H@("`@("`@("`@("`B)R1P96%R7W5S97)?8V]N9FEG)R!O<B`G)'!E87)?
M<WES=&5M7V-O;F9I9R<L('!L96%S92!C;W!Y(&%N(&5X:7-T:6YG(&-O;F9I
M9W5R871I;VXB("X-"B`@("`@("`@("`@("=F:6QE('1O(&]N92!O9B!T:&5S
M92!L;V-A=&EO;G,L(&]R('5S92!T:&4@+6,@86YD("US(&]P=&EO;G,@=&\@
M8W)E871E(&]N92<I.PT*("`@('T-"B`@("!'=&LZ.FUA:6XH*3L-"GT@96QS
M92!D;R![#0H@("`@:68@*"1C;VUM86YD(#T]("=H96QP)RD@>PT*("`@("`@
M("!U<V%G92AN=6QL+"!`)&]P=&EO;G-;,5U;,5TI.PT*("`@('T-"B`@("!I
M9B`H(21C;VYF:6<M/G9A;&ED0V]N9FEG=7)A=&EO;B@I*2![#0H@("`@("`@
M(%!%05(Z.G)A:7-E17)R;W(H)T-2251)0T%,($524D]2.B!N;R!E>&ES=&EN
M9R!V86QI9"!C;VYF:6=U<F%T:6]N(&9I;&5S(&9O=6YD(&EN(&9I;&5S("<@
M+@T*("`@("`@("`@("`@(B<D<&5A<E]U<V5R7V-O;F9I9R<@;W(@)R1P96%R
M7W-Y<W1E;5]C;VYF:6<G+"!P;&5A<V4@8V]P>2!A;B!E>&ES=&EN9R!C;VYF
M:6=U<F%T:6]N(B`N#0H@("`@("`@("`@("`G9FEL92!T;R!O;F4@;V8@=&AE
M<V4@;&]C871I;VYS+"!O<B!U<V4@=&AE("UC(&%N9"`M<R!O<'1I;VYS('1O
M(&-R96%T92!O;F4G*3L-"B`@("!]#0H-"B`@("!014%2.CIP=7-H17)R;W)(
M86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@)&-M9"`](%!%05)?
M0V]M;6%N9#HZ9F%C=&]R>2@D8V]M;6%N9"P@)&-O;F9I9RD[#0H@("`@4$5!
M4CHZ<&]P17)R;W)(86YD;&EN9R@I.PT*("`@(&EF("A014%2.CII<T5R<F]R
M*"1C;60I*2![#0H@("`@("`@('5S86=E*&YU;&PL($`D;W!T:6]N<ULQ75LP
M72D[#0H@("`@?0T*#0H@("`@)'-H;W)T7V%R9W,@/2`D;&]N9U]A<F=S(#T@
M;G5L;#L-"B`@("!014%27T-O;6UA;F0Z.F=E=$=E=&]P=$%R9W,H)&-O;6UA
M;F0L("1S:&]R=%]A<F=S+"`D;&]N9U]A<F=S*3L-"B`@("!I9B`H:6Y?87)R
M87DH)V=E=&]P=#(G+"!G971?8VQA<W-?;65T:&]D<R@G0V]N<V]L95]'971O
M<'0G*2DI('L-"B`@("`@("`@87)R87E?<VAI9G0H)&]P=&EO;G-;,5TI.PT*
M("`@("`@("`D=&UP(#T@0V]N<V]L95]'971O<'0Z.F=E=&]P=#(H)&]P=&EO
M;G-;,5TL("1S:&]R=%]A<F=S+"`D;&]N9U]A<F=S*3L-"B`@("!](&5L<V4@
M>PT*("`@("`@("`D=&UP(#T@0V]N<V]L95]'971O<'0Z.F=E=&]P="@D;W!T
M:6]N<ULQ72P@)'-H;W)T7V%R9W,L("1L;VYG7V%R9W,I.PT*("`@('T-"B`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D=&UP*2D@>PT*("`@("`@("!B<F5A:SL-
M"B`@("!]#0H@("`@;&ES="@D=&UP;W!T+"`D<&%R86US*2`]("1T;7`[#0H@
M("`@)&]P=',@/2!A<G)A>2@I.PT*("`@(&9O<F5A8V@@*"1T;7!O<'0@87,@
M)&9O;R`]/B`D=&UP,BD@>PT*("`@("`@("!L:7-T*"1O<'0L("1V86QU92D@
M/2`D=&UP,CL-"B`@("`@("`@:68@*"1V86QU92`]/3T@;G5L;"D@>PT*("`@
M("`@("`@("`@)'9A;'5E(#T@=')U93L@+R\@;W!T:6]N<R!W:71H;W5T(&%R
M9W,-"B`@("`@("`@?0T*("`@("`@("!I9B`H<W1R;&5N*"1O<'0I(#T](#$I
M('L-"B`@("`@("`@("`@("1C;61O<'1I;VYS(#T@)&-M9"T^9V5T3W!T:6]N
M<R@D8V]M;6%N9"D[#0H@("`@("`@("`@("!F;W)E86-H("@D8VUD;W!T:6]N
M<R!A<R`D;R`]/B`D9"D@>PT*("`@("`@("`@("`@("`@(&EF("A`)&1;)W-H
M;W)T;W!T)UT@/3T@)&]P="D@>PT*("`@("`@("`@("`@("`@("`@("`D;W!T
M<ULD;UT@/2`D=F%L=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@:68@*'-U8G-T
M<B@D;W!T+"`P+"`R*2`]/2`G+2TG*2![#0H@("`@("`@("`@("`@("`@)&]P
M='-;<W5B<W1R*"1O<'0L(#(I72`]("1V86QU93L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@('T-"B`@("`D;VL@/2`D8VUD+3YR=6XH)&-O;6UA
M;F0L("1O<'1S+"`D<&%R86US*3L-"B`@("!I9B`H)&]K(#T]/2!F86QS92D@
M>PT*("`@("`@("!014%2.CIR86ES945R<F]R*")U;FMN;W=N(&-O;6UA;F0@
M8"1C;VUM86YD)R(I.PT*("`@('T-"B`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M;VLI*2![#0H@("`@("`@(%!%05(Z.G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%
M4E)/4E]#04Q,0D%#2RP@87)R87DH)'5I+"`B9&ES<&QA>49A=&%L17)R;W(B
M*2D[#0H@("`@("`@(%!%05(Z.G)A:7-E17)R;W(H)&]K*3L-"B`@("!]#0I]
M('=H:6QE("AF86QS92D[#0H-"B\O('M[>R!U<V%G92@I#0H-"F9U;F-T:6]N
M('5S86=E*"1E<G)O<B`](&YU;&PL("1H96QP<W5B:F5C="`](&YU;&PI#0I[
M#0H@("`@9VQO8F%L("1P<F]G;F%M92P@)&%L;%]C;VUM86YD<SL-"B`@("`D
M<W1D97)R(#T@9F]P96XH)W!H<#HO+W-T9&5R<B<L("=W)RD[#0H@("`@:68@
M*%!%05(Z.FES17)R;W(H)&5R<F]R*2D@>PT*("`@("`@("!F<'5T<R@D<W1D
M97)R+"`D97)R;W(M/F=E=$UE<W-A9V4H*2`N(")<;B(I.PT*("`@('T@96QS
M96EF("@D97)R;W(@(3T](&YU;&PI('L-"B`@("`@("`@9G!U=',H)'-T9&5R
M<BP@(B1E<G)O<EQN(BD[#0H@("`@?0T*("`@(&EF("@D:&5L<'-U8FIE8W0@
M(3T@;G5L;"D@>PT*("`@("`@("`D<'5T(#T@8VUD2&5L<"@D:&5L<'-U8FIE
M8W0I.PT*("`@('T@96QS92![#0H@("`@("`@("1P=70@/0T*("`@("`@("`@
M("`@(D-O;6UA;F1S.EQN(CL-"B`@("`@("`@)&UA>&QE;B`](&UA>"AA<G)A
M>5]M87`H(G-T<FQE;B(L("1A;&Q?8V]M;6%N9',I*3L-"B`@("`@("`@)&9O
M<FUA='-T<B`]("(E+7LD;6%X;&5N?7,@("5S7&XB.PT*("`@("`@("!K<V]R
M="@D86QL7V-O;6UA;F1S*3L-"B`@("`@("`@9F]R96%C:"`H)&%L;%]C;VUM
M86YD<R!A<R`D8VUD(#T^("1C;&%S<RD@>PT*("`@("`@("`@("`@)'!U="`N
M/2!S<')I;G1F*"1F;W)M871S='(L("1C;60L(%!%05)?0V]M;6%N9#HZ9V5T
M1&5S8W)I<'1I;VXH)&-M9"DI.PT*("`@("`@("!]#0H@("`@("`@("1P=70@
M+CT-"B`@("`@("`@("`@(")5<V%G93H@)'!R;V=N86UE(%MO<'1I;VYS72!C
M;VUM86YD(%MC;VUM86YD+6]P=&EO;G-=(#QP87)A;65T97)S/EQN(BX-"B`@
M("`@("`@("`@(")4>7!E(%PB)'!R;V=N86UE(&AE;'`@;W!T:6]N<UPB('1O
M(&QI<W0@86QL(&]P=&EO;G,N7&XB+@T*("`@("`@("`@("`@(E1Y<&4@7"(D
M<')O9VYA;64@:&5L<"!S:&]R=&-U='-<(B!T;R!L:7-T(&%L;"!C;VUM86YD
M('-H;W)T8W5T<RY<;B(N#0H@("`@("`@("`@("`B5'EP92!<(B1P<F]G;F%M
M92!H96QP(#QC;VUM86YD/EPB('1O(&=E="!T:&4@:&5L<"!F;W(@=&AE('-P
M96-I9FEE9"!C;VUM86YD+B([#0H@("`@?0T*("`@(&9P=71S*"1S=&1E<G(L
M("(D<'5T7&XB*3L-"B`@("!F8VQO<V4H)'-T9&5R<BD[#0H@("`@97AI=#L-
M"GT-"@T*9G5N8W1I;VX@8VUD2&5L<"@D8V]M;6%N9"D-"GL-"B`@("!G;&]B
M86P@)'!R;V=N86UE+"`D86QL7V-O;6UA;F1S+"`D8V]N9FEG.PT*("`@(&EF
M("@D8V]M;6%N9"`]/2`B;W!T:6]N<R(I('L-"B`@("`@("`@<F5T=7)N#0H@
M("`@("`@(")/<'1I;VYS.EQN(BX-"B`@("`@("`@(B`@("`@+78@("`@("`@
M("!I;F-R96%S92!V97)B;W-I='D@;&5V96P@*&1E9F%U;'0@,2E<;B(N#0H@
M("`@("`@("(@("`@("UQ("`@("`@("`@8F4@<75I970L(&1E8W)E87-E('9E
M<F)O<VET>2!L979E;%QN(BX-"B`@("`@("`@(B`@("`@+6,@9FEL92`@("!F
M:6YD('5S97(@8V]N9FEG=7)A=&EO;B!I;B!@9FEL92=<;B(N#0H@("`@("`@
M("(@("`@("U#(&9I;&4@("`@9FEN9"!S>7-T96T@8V]N9FEG=7)A=&EO;B!I
M;B!@9FEL92=<;B(N#0H@("`@("`@("(@("`@("UD(&9O;SUB87(@<V5T('5S
M97(@8V]N9FEG('9A<FEA8FQE(&!F;V\G('1O(&!B87(G7&XB+@T*("`@("`@
M("`B("`@("`M1"!F;V\]8F%R('-E="!S>7-T96T@8V]N9FEG('9A<FEA8FQE
M(&!F;V\G('1O(&!B87(G7&XB+@T*("`@("`@("`B("`@("`M1R`@("`@("`@
M('-T87)T(&EN(&=R87!H:6-A;"`H1W1K*2!M;V1E7&XB+@T*("`@("`@("`B
M("`@("`M<R`@("`@("`@('-T;W)E('5S97(@8V]N9FEG=7)A=&EO;EQN(BX-
M"B`@("`@("`@(B`@("`@+5,@("`@("`@("!S=&]R92!S>7-T96T@8V]N9FEG
M=7)A=&EO;EQN(BX-"B`@("`@("`@(B`@("`@+74@9F]O("`@("!U;G-E="!@
M9F]O)R!I;B!T:&4@=7-E<B!C;VYF:6=U<F%T:6]N7&XB+@T*("`@("`@("`B
M("`@("`M:"P@+3\@("`@(&1I<W!L87D@:&5L<"]U<V%G92`H=&AI<R!M97-S
M86=E*5QN(BX-"B`@("`@("`@(B`@("`@+58@("`@("`@("!V97)S:6]N(&EN
M9F]R;6%T:6]N7&XB.PT*("`@('T@96QS96EF("@D8V]M;6%N9"`]/2`B<VAO
M<G1C=71S(BD@>PT*("`@("`@("`D<V,@/2!014%27T-O;6UA;F0Z.F=E=%-H
M;W)T8W5T<R@I.PT*("`@("`@("`D<F5T(#T@(E-H;W)T8W5T<SI<;B([#0H@
M("`@("`@(&9O<F5A8V@@*"1S8R!A<R`D<R`]/B`D8RD@>PT*("`@("`@("`@
M("`@)')E="`N/2!S<')I;G1F*"(@("`@("4M.',@)7-<;B(L("1S+"`D8RD[
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1R970[#0H-"B`@("!](&5L
M<V5I9B`H)&-O;6UA;F0@/3T@(G9E<G-I;VXB*2![#0H@("`@("`@(')E='5R
M;B`B4$5!4B!697)S:6]N.B`B+B1'3$]"04Q36R=P96%R7W!A8VMA9V5?=F5R
M<VEO;B==+@T*("`@("`@("`@("`@("`@(EQN4$A0(%9E<G-I;VXZ("(N<&AP
M=F5R<VEO;B@I+@T*("`@("`@("`@("`@("`@(EQN6F5N9"!%;F=I;F4@5F5R
M<VEO;CH@(BYZ96YD7W9E<G-I;VXH*2X-"B`@("`@("`@("`@("`@(")<;E)U
M;FYI;F<@;VXZ("(N<&AP7W5N86UE*"D[#0H-"B`@("!](&5L<V5I9B`H)&AE
M;'`@/2!014%27T-O;6UA;F0Z.F=E=$AE;'`H)&-O;6UA;F0I*2![#0H@("`@
M("`@(&EF("AI<U]S=')I;F<H)&AE;'`I*2![#0H@("`@("`@("`@("!R971U
M<FX@(B1P<F]G;F%M92`D8V]M;6%N9"!;;W!T:6]N<UT@)&AE;'!<;B([#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"1H96QP6S%=(#T]/2!N=6QL*2![#0H@
M("`@("`@("`@("!R971U<FX@(B1P<F]G;F%M92`D8V]M;6%N9"`D:&5L<%LP
M72([#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!R971U<FX@(B1P
M<F]G;F%M92`D8V]M;6%N9"!;;W!T:6]N<UT@)&AE;'!;,%U<;B1H96QP6S%=
M(CL-"B`@("`@("`@?0T*("`@('T-"B`@("!R971U<FX@(D-O;6UA;F0@)R1C
M;VUM86YD)R!I<R!N;W0@=F%L:60L('1R>2`G<&5A<B!H96QP)R([#0I]#0H-
M"B\O('U]?0T*#0IF=6YC=&EO;B!E<G)O<E]H86YD;&5R*"1E<G)N;RP@)&5R
M<FUS9RP@)&9I;&4L("1L:6YE+"`D=F%R<RD@>PT*("`@(&EF("@H9&5F:6YE
M9"@G15]35%))0U0G*2`F)B`D97)R;F\@)B!%7U-44DE#5"D@?'P@(65R<F]R
M7W)E<&]R=&EN9R@I*2![#0H@("`@("`@(&EF("AD969I;F5D*"=%7U-44DE#
M5"<I("8F("1E<G)N;R`F($5?4U1224-4*2![#0H@("`@("`@("`@("!R971U
M<FX[("\O($5?4U1224-4#0H@("`@("`@('T-"B`@("`@("`@:68@*"1'3$]"
M04Q36R=C;VYF:6<G72T^9V5T*"=V97)B;W-E)RD@/"`T*2![#0H@("`@("`@
M("`@("!R971U<FX[("\O($!S:6QE;F-E9"!E<G)O<BP@<VAO=R!A;&P@:68@
M9&5B=6<@:7,@:&EG:"!E;F]U9V@-"B`@("`@("`@?0T*("`@('T-"B`@("`D
M97)R;W)T>7!E(#T@87)R87D@*`T*("`@("`@("!%7T524D]2("`@/3X@(")%
M<G)O<B(L#0H@("`@("`@($5?5T%23DE.1R`@(#T^("`B5V%R;FEN9R(L#0H@
M("`@("`@($5?4$%24T4@("`]/B`@(E!A<G-I;F<@17)R;W(B+`T*("`@("`@
M("!%7TY/5$E#12`@(#T^("`B3F]T:6-E(BP-"B`@("`@("`@15]#3U)%7T52
M4D]2("`]/B`@(D-O<F4@17)R;W(B+`T*("`@("`@("!%7T-/4D5?5T%23DE.
M1R`@/3X@(")#;W)E(%=A<FYI;F<B+`T*("`@("`@("!%7T-/35!)3$5?15)2
M3U(@(#T^("`B0V]M<&EL92!%<G)O<B(L#0H@("`@("`@($5?0T]-4$E,15]7
M05).24Y'(#T^("`B0V]M<&EL92!787)N:6YG(BP-"B`@("`@("`@15]54T52
M7T524D]2(#T^("`B57-E<B!%<G)O<B(L#0H@("`@("`@($5?55-%4E]705).
M24Y'(#T^("`B57-E<B!787)N:6YG(BP-"B`@("`@("`@15]54T527TY/5$E#
M12`]/B`@(E5S97(@3F]T:6-E(@T*("`@("D[#0H@("`@)'!R969I>"`]("1E
M<G)O<G1Y<&5;)&5R<FYO73L-"B`@("!G;&]B86P@)%]014%27U!(4$1)4CL-
M"B`@("!I9B`H<W1R:7-T<B@D9FEL92P@)%]014%27U!(4$1)4BDI('L-"B`@
M("`@("`@)&9I;&4@/2!S=6)S='(H)&9I;&4L('-T<FQE;B@D7U!%05)?4$A0
M1$E2*2`K(#$I.PT*("`@('T@96QS92![#0H@("`@("`@("1F:6QE(#T@8F%S
M96YA;64H)&9I;&4I.PT*("`@('T-"B`@("!P<FEN="`B7&XD<')E9FEX.B`D
M97)R;7-G(&EN("1F:6QE(&]N(&QI;F4@)&QI;F5<;B([#0I]#0H-"@T*+RH-
M"B`J($QO8V%L('9A<FEA8FQE<SH-"B`J('1A8BUW:61T:#H@-`T*("H@8RUB
M87-I8RUO9F9S970Z(#0-"B`J(&EN9&5N="UT86)S+6UO9&4Z(&YI;`T*("H@
M;6]D93H@<&AP#0H@*B!%;F0Z#0H@*B\-"B\O('9I;38P,#IS>6X]<&AP#0H-
M"C\^#0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O<&5C;&-M9"YP:'``````````````````````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S4R,2`Q,#4Q-30S,S<S,R`P,C`V
M,#<`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`-"B\O#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O
M('P@4$A0(%9E<G-I;VX@-2`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK#0HO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`T
M(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!4:&ES
M('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE
M(%!(4"!L:6-E;G-E+"`@("`@("!\#0HO+R!\('1H870@:7,@8G5N9&QE9"!W
M:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@
M("`@("`@('P-"B\O('P@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I
M9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@=7)L.B`@("`@("`@("`@?`T*+R\@
M?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\($EF('EO=2!D:60@
M;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E
M('5N86)L92!T;R`@('P-"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O
M<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@
M?`T*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@
M8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@075T:&]R<SH@4W1I9R!"86MK
M96X@/'-S8D!P:'`N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`T*+R\@?"`@("`@("`@("!4;VUA<R!6+E8N0V]X(#QC;WA`:61E
M8VYE="YC;VT^("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PT*+R\-"B\O("1)9#H@<&5C;&-M9"YP:'`L=B`Q+C$@
M,C`P-2\P,B\R,2`P-3HS,#HU-B!C96QL;V<@17AP("0-"@T*+RHJ#0H@*B!`
M;F]D97`@1W1K#0H@*B\-"FEF("@G+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(G("$]("=`)RXG:6YC;'5D95]P871H)RXG0"<I('L-"B`@("!I;FE?
M<V5T*"=I;F-L=61E7W!A=&@G+"`G+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(G*3L-"B`@("`D<F%W(#T@9F%L<V4[#0I](&5L<V4@>PT*("`@("\O
M('1H:7,@:7,@82!R87<L('5N:6YS=&%L;&5D('!E87(L(&5I=&AE<B!A(&-V
M<R!C:&5C:V]U="P@;W(@<&AP(&1I<W1R;PT*("`@("1R87<@/2!T<G5E.PT*
M?0T*9&5F:6YE*"=014%27U)53E194$4G+"`G<&5C;"<I.PT*<F5Q=6ER95]O
M;F-E("=P96%R8VUD+G!H<"<[#0HO*@T*("H@3&]C86P@=F%R:6%B;&5S.@T*
M("H@=&%B+7=I9'1H.B`T#0H@*B!C+6)A<VEC+6]F9G-E=#H@-`T*("H@:6YD
M96YT+71A8G,M;6]D93H@;FEL#0H@*B!M;V1E.B!P:'`-"B`J($5N9#H-"B`J
M+PT*+R\@=FEM-C`P.G-Y;CUP:'`-"@T*/SX-"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+TQO9RYP:'``````````````````````````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P-C`T-C,@,3`U,34T,S,W,S,@,#$W-S,Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B`D2&5A9&5R.B`O<F5P;W-I=&]R>2]P96%R+TQO9R],;V<N<&AP
M+'8@,2XU.2`R,#`V+S`T+S(U(#`V.C`R.C(S(&IO;B!%>'`@)`H@*B`D2&]R
M9&4Z(&AO<F1E+VQI8B],;V<N<&AP+'8@,2XQ-2`R,#`P+S`V+S(Y(#(S.C,Y
M.C0U(&IO;B!%>'`@)`H@*@H@*B!`=F5R<VEO;B`D4F5V:7-I;VXZ(#$N-3D@
M)`H@*B!`<&%C:V%G92!,;V<*("HO"@ID969I;F4H)U!%05)?3$]'7T5-15)'
M)RP@("`@,"D[("`@("`O*BH@4WES=&5M(&ES('5N=7-A8FQE("HO"F1E9FEN
M92@G4$5!4E],3T=?04Q%4E0G+"`@("`Q*3L@("`@("\J*B!);6UE9&EA=&4@
M86-T:6]N(')E<75I<F5D("HO"F1E9FEN92@G4$5!4E],3T=?0U))5"<L("`@
M("`R*3L@("`@("\J*B!#<FET:6-A;"!C;VYD:71I;VYS("HO"F1E9FEN92@G
M4$5!4E],3T=?15)2)RP@("`@("`S*3L@("`@("\J*B!%<G)O<B!C;VYD:71I
M;VYS("HO"F1E9FEN92@G4$5!4E],3T=?5T%23DE.1R<L("`T*3L@("`@("\J
M*B!787)N:6YG(&-O;F1I=&EO;G,@*B\*9&5F:6YE*"=014%27TQ/1U].3U1)
M0T4G+"`@(#4I.R`@("`@+RHJ($YO<FUA;"!B=70@<VEG;FEF:6-A;G0@*B\*
M9&5F:6YE*"=014%27TQ/1U])3D9/)RP@("`@(#8I.R`@("`@+RHJ($EN9F]R
M;6%T:6]N86P@*B\*9&5F:6YE*"=014%27TQ/1U]$14)51R<L("`@(#<I.R`@
M("`@+RHJ($1E8G5G+6QE=F5L(&UE<W-A9V5S("HO"@ID969I;F4H)U!%05)?
M3$]'7T%,3"<L("`@("`@8FEN9&5C*"<Q,3$Q,3$Q,2<I*3L@("\J*B!!;&P@
M;65S<V%G97,@*B\*9&5F:6YE*"=014%27TQ/1U].3TY%)RP@("`@(&)I;F1E
M8R@G,#`P,#`P,#`G*2D[("`O*BH@3F\@;65S<V%G92`J+PH*+RH@3&]G('1Y
M<&5S(&9O<B!02%`G<R!N871I=F4@97)R;W)?;&]G*"D@9G5N8W1I;VXN("HO
M"F1E9FEN92@G4$5!4E],3T=?5%E015]365-414TG+"`@,"D[("\J*B!5<V4@
M4$A0)W,@<WES=&5M(&QO9V=E<B`J+PID969I;F4H)U!%05)?3$]'7U194$5?
M34%)3"<L("`@(#$I.R`O*BH@57-E(%!(4"=S(&UA:6PH*2!F=6YC=&EO;B`J
M+PID969I;F4H)U!%05)?3$]'7U194$5?1$5"54<G+"`@(#(I.R`O*BH@57-E
M(%!(4"=S(&1E8G5G9VEN9R!C;VYN96-T:6]N("HO"F1E9FEN92@G4$5!4E],
M3T=?5%E015]&24Q%)RP@("`@,RD[("\J*B!!<'!E;F0@=&\@82!F:6QE("HO
M"@HO*BH*("H@5&AE($QO9SHZ(&-L87-S(&EM<&QE;65N=',@8F]T:"!A;B!A
M8G-T<F%C=&EO;B!F;W(@=F%R:6]U<R!L;V=G:6YG"B`J(&UE8VAA;FES;7,@
M86YD('1H92!3=6)J96-T(&5N9"!O9B!A(%-U8FIE8W0M3V)S97)V97(@<&%T
M=&5R;BX*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H
M;W)D92YO<F<^"B`J($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!P:'`N;F5T
M/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@3&]G"B`J+PIC
M;&%S<R!,;V<*>PH@("`@+RHJ"B`@("`@*B!);F1I8V%T97,@=VAE=&AE<B!O
M<B!N;W0@=&AE(&QO9R!C86X@8F5E;B!O<&5N960@+R!C;VYN96-T960N"B`@
M("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@=F%R("1?;W!E;F5D(#T@9F%L<V4["@H@("`@+RHJ
M"B`@("`@*B!);G-T86YC92US<&5C:69I8R!U;FEQ=64@:61E;G1I9FEC871I
M;VX@;G5M8F5R+@H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7VED(#T@,#L*"B`@
M("`O*BH*("`@("`J(%1H92!L86)E;"!T:&%T('5N:7%U96QY(&ED96YT:69I
M97,@=&AI<R!S970@;V8@;&]G(&UE<W-A9V5S+@H@("`@("H*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@
M=F%R("1?:61E;G0@/2`G)SL*"B`@("`O*BH*("`@("`J(%1H92!D969A=6QT
M('!R:6]R:71Y('1O('5S92!W:&5N(&QO9V=I;F<@86X@979E;G0N"B`@("`@
M*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J+PH@("`@=F%R("1?<')I;W)I='D@/2!014%27TQ/1U])3D9/.PH*
M("`@("\J*@H@("`@("H@5&AE(&)I=&UA<VL@;V8@86QL;W=E9"!L;V<@;&5V
M96QS+@H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7VUA<VL@/2!014%27TQ/1U]!
M3$P["@H@("`@+RHJ"B`@("`@*B!(;VQD<R!A;&P@3&]G7V]B<V5R=F5R(&]B
M:F5C=',@=&AA="!W:7-H('1O(&)E(&YO=&EF:65D(&]F(&YE=R!M97-S86=E
M<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J+PH@("`@=F%R("1?;&ES=&5N97)S(#T@87)R87DH*3L*
M"B`@("`O*BH*("`@("`J($UA<',@8V%N;VYI8V%L(&9O<FUA="!K97ES('1O
M('!O<VET:6]N(&%R9W5M96YT<R!F;W(@=7-E(&EN(&)U:6QD:6YG"B`@("`@
M*B`B;&EN92!F;W)M870B('-T<FEN9W,N"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D
M7V9O<FUA=$UA<"`](&%R<F%Y*"<E>W1I;65S=&%M<'TG("`]/B`G)3$D<R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G)7MI9&5N='TG("`@("`@
M/3X@)R4R)',G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R5[<')I
M;W)I='E])R`@(#T^("<E,R1S)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("<E>VUE<W-A9V5])R`@("`]/B`G)30D<R<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G)7MF:6QE?2<@("`@("`@/3X@)R4U)',G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)R5[;&EN97TG("`@("`@(#T^("<E
M-B1S)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("<E>V9U;F-T:6]N
M?2<@("`]/B`G)3<D<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M)5Q[)R`@("`@("`@("`@/3X@)R4E>R<I.PH*"B`@("`O*BH*("`@("`J($%T
M=&5M<'1S('1O(')E='5R;B!A(&-O;F-R971E($QO9R!I;G-T86YC92!O9B!T
M>7!E("1H86YD;&5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&AA
M;F1L97(@("!4:&4@='EP92!O9B!C;VYC<F5T92!,;V<@<W5B8VQA<W,@=&\@
M<F5T=7)N+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@($%T=&5M
M<'0@=&\@9'EN86UI8V%L;'D@:6YC;'5D92!T:&4@8V]D92!F;W(*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("!T:&ES('-U8F-L87-S+B!#=7)R
M96YT;'DL('9A;&ED('9A;'5E<R!A<F4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`G8V]N<V]L92<L("=S>7-L;V<G+"`G<W%L)RP@)V9I;&4G
M+"!A;F0@)VUC86PG+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA
M;64@("`@("!4:&4@;F%M92!O9B!T:&4@86-T=6%L;'D@;&]G(&9I;&4L('1A
M8FQE+"!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&]T:&5R
M('-P96-I9FEC('-T;W)E('1O('5S92X@1&5F875L=',@=&\@86X*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("!E;7!T>2!S=')I;F<L('=I=&@@
M=VAI8V@@=&AE('-U8F-L87-S('=I;&P*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("!A='1E;7!T('1O(&1O('-O;65T:&EN9R!I;G1E;&QI9V5N
M="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9&5N="`@("`@5&AE
M(&ED96YT:71Y(')E<&]R=&5D('1O('1H92!L;V<@<WES=&5M+@H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`@)&-O;F8@("`@("!!(&AA<V@@8V]N=&%I
M;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@:6YF;W)M871I;VX@=&AA="!A('-U8F-L
M87-S(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`D;&5V
M96P@("`@("`@($QO9R!M97-S86=E<R!U<"!T;R!A;F0@:6YC;'5D:6YG('1H
M:7,@;&5V96PN"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE8W0@3&]G("`@
M("`@(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R971E($QO9R!I;G-T86YC92P@
M;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!N=6QL(&]N(&%N
M(&5R<F]R+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S:6YC92!,
M;V<@,2XP"B`@("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1H86YD;&5R
M+"`D;F%M92`]("<G+"`D:61E;G0@/2`G)RP@)&-O;F8@/2!A<G)A>2@I+`H@
M("`@("`@("`@("`@("`@("`@("`@)&QE=F5L(#T@4$5!4E],3T=?1$5"54<I
M"B`@("!["B`@("`@("`@)&AA;F1L97(@/2!S=')T;VQO=V5R*"1H86YD;&5R
M*3L*("`@("`@("`D8VQA<W,@/2`G3&]G7R<@+B`D:&%N9&QE<CL*("`@("`@
M("`D8VQA<W-F:6QE(#T@)TQO9R\G("X@)&AA;F1L97(@+B`G+G!H<"<["@H@
M("`@("`@("\J"B`@("`@("`@("H@071T96UP="!T;R!I;F-L=61E(&]U<B!V
M97)S:6]N(&]F('1H92!N86UE9"!C;&%S<RP@8G5T(&1O;B=T('1R96%T"B`@
M("`@("`@("H@82!F86EL=7)E(&%S(&9A=&%L+B`@5&AE(&-A;&QE<B!M87D@
M:&%V92!A;')E861Y(&EN8VQU9&5D('1H96ER(&]W;@H@("`@("`@("`J('9E
M<G-I;VX@;V8@=&AE(&YA;65D(&-L87-S+@H@("`@("`@("`J+PH@("`@("`@
M(&EF("@A8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@:6YC
M;'5D95]O;F-E("1C;&%S<V9I;&4["B`@("`@("`@?0H*("`@("`@("`O*B!)
M9B!T:&4@8VQA<W,@97AI<W1S+"!R971U<FX@82!N97<@:6YS=&%N8V4@;V8@
M:70N("HO"B`@("`@("`@:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@
M("`@("`@("`@("1O8FH@/2`F;F5W("1C;&%S<R@D;F%M92P@)&ED96YT+"`D
M8V]N9BP@)&QE=F5L*3L*("`@("`@("`@("`@<F5T=7)N("1O8FH["B`@("`@
M("`@?0H*("`@("`@("`D;G5L;"`](&YU;&P["B`@("`@("`@<F5T=7)N("1N
M=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N
M(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@3&]G(&EN<W1A;F-E(&]F('1Y
M<&4*("`@("`J("1H86YD;&5R+"!O;FQY(&-R96%T:6YG(&$@;F5W(&EN<W1A
M;F-E(&EF(&YO(&QO9R!I;G-T86YC92!W:71H('1H92!S86UE"B`@("`@*B!P
M87)A;65T97)S(&-U<G)E;G1L>2!E>&ES=',N"B`@("`@*@H@("`@("H@66]U
M('-H;W5L9"!U<V4@=&AI<R!I9B!T:&5R92!A<F4@;75L=&EP;&4@<&QA8V5S
M('EO=2!M:6=H="!C<F5A=&4@80H@("`@("H@;&]G9V5R+"!Y;W4@9&]N)W0@
M=V%N="!T;R!C<F5A=&4@;75L=&EP;&4@;&]G9V5R<RP@86YD('EO=2!D;VXG
M="!W86YT('1O"B`@("`@*B!C:&5C:R!F;W(@=&AE(&5X:7-T86YC92!O9B!O
M;F4@96%C:"!T:6UE+B!4:&4@<VEN9VQE=&]N('!A='1E<FX@9&]E<R!A;&P*
M("`@("`J('1H92!C:&5C:VEN9R!W;W)K(&9O<B!Y;W4N"B`@("`@*@H@("`@
M("H@/&(^66]U($U54U0@8V%L;"!T:&ES(&UE=&AO9"!W:71H('1H92`D=F%R
M(#T@)DQO9SHZ<VEN9VQE=&]N*"D@<WEN=&%X+@H@("`@("H@5VET:&]U="!T
M:&4@86UP97)S86YD("@F*2!I;B!F<F]N="!O9B!T:&4@;65T:&]D(&YA;64L
M('EO=2!W:6QL(&YO="!G970*("`@("`J(&$@<F5F97)E;F-E+"!Y;W4@=VEL
M;"!G970@82!C;W!Y+CPO8CX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1H86YD;&5R("`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@3&]G('-U8F-L87-S
M('1O(')E='5R;BX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!!
M='1E;7!T('1O(&1Y;F%M:6-A;&QY(&EN8VQU9&4@=&AE(&-O9&4@9F]R"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@=&AI<R!S=6)C;&%S<RX@
M0W5R<F5N=&QY+"!V86QI9"!V86QU97,@87)E"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V-O;G-O;&4G+"`G<WES;&]G)RP@)W-Q;"<L("=F
M:6QE)RP@86YD("=M8V%L)RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N86UE("`@("`@5&AE(&YA;64@;V8@=&AE(&%C='5A;&QY(&QO9R!F:6QE
M+"!T86)L92P@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!O
M=&AE<B!S<&5C:69I8R!S=&]R92!T;R!U<V4N("!$969A=6QT<R!T;R!A;@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&5M<'1Y('-T<FEN9RP@
M=VET:"!W:&EC:"!T:&4@<W5B8VQA<W,@=VEL;`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%T=&5M<'0@=&\@9&\@<V]M971H:6YG(&EN=&5L
M;&EG96YT+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED96YT("`@
M("!4:&4@:61E;G1I='D@<F5P;W)T960@=&\@=&AE(&QO9R!S>7-T96TN"B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1C;VYF("`@("`@($$@:&%S:"!C
M;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("!I;F9O<FUA=&EO;B!T:&%T(&$@
M<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M("1L979E;"`@("`@("`@3&]G(&UE<W-A9V5S('5P('1O(&%N9"!I;F-L=61I
M;F<@=&AI<R!L979E;"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&]B:F5C="!,
M;V<@("`@("`@5&AE(&YE=VQY(&-R96%T960@8V]N8W)E=&4@3&]G(&EN<W1A
M;F-E+"!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&YU;&P@
M;VX@86X@97)R;W(N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-I
M;F-E($QO9R`Q+C`*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@D
M:&%N9&QE<BP@)&YA;64@/2`G)RP@)&ED96YT(#T@)R<L("1C;VYF(#T@87)R
M87DH*2P*("`@("`@("`@("`@("`@("`@("`@("`@)&QE=F5L(#T@4$5!4E],
M3T=?1$5"54<I"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T86YC97,["B`@
M("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S*2D@)&EN<W1A;F-E<R`](&%R
M<F%Y*"D["@H@("`@("`@("1S:6=N871U<F4@/2!S97)I86QI>F4H87)R87DH
M)&AA;F1L97(L("1N86UE+"`D:61E;G0L("1C;VYF+"`D;&5V96PI*3L*("`@
M("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97-;)'-I9VYA='5R95TI*2!["B`@
M("`@("`@("`@("1I;G-T86YC97-;)'-I9VYA='5R95T@/2`F3&]G.CIF86-T
M;W)Y*"1H86YD;&5R+"`D;F%M92P@)&ED96YT+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]N9BP@)&QE
M=F5L*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6YS=&%N8V5S6R1S
M:6=N871U<F5=.PH@("`@?0H*("`@("\J*@H@("`@("H@06)S=')A8W0@:6UP
M;&5M96YT871I;VX@;V8@=&AE(&]P96XH*2!M971H;V0N"B`@("`@*B!`<VEN
M8V4@3&]G(#$N,`H@("`@("HO"B`@("!F=6YC=&EO;B!O<&5N*"D*("`@('L*
M("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!
M8G-T<F%C="!I;7!L96UE;G1A=&EO;B!O9B!T:&4@8VQO<V4H*2!M971H;V0N
M"B`@("`@*B!`<VEN8V4@3&]G(#$N,`H@("`@("HO"B`@("!F=6YC=&EO;B!C
M;&]S92@I"B`@("!["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@06)S=')A8W0@:6UP;&5M96YT871I;VX@;V8@=&AE(&9L
M=7-H*"D@;65T:&]D+@H@("`@("H@0'-I;F-E($QO9R`Q+C@N,@H@("`@("HO
M"B`@("!F=6YC=&EO;B!F;'5S:"@I"B`@("!["B`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@06)S=')A8W0@:6UP;&5M96YT
M871I;VX@;V8@=&AE(&QO9R@I(&UE=&AO9"X*("`@("`J($!S:6YC92!,;V<@
M,2XP"B`@("`@*B\*("`@(&9U;F-T:6]N(&QO9R@D;65S<V%G92P@)'!R:6]R
M:71Y(#T@;G5L;"D*("`@('L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!(&-O;G9E;FEE;F-E(&9U;F-T:6]N(&9O<B!L
M;V=G:6YG(&$@96UE<F=E;F-Y(&5V96YT+B`@270@=VEL;"!L;V<@80H@("`@
M("H@;65S<V%G92!A="!T:&4@4$5!4E],3T=?14U%4D<@;&]G(&QE=F5L+@H@
M("`@("H*("`@("`J($!P87)A;2`@(&UI>&5D("`@)&UE<W-A9V4@("`@4W1R
M:6YG(&]R(&]B:F5C="!C;VYT86EN:6YG('1H92!M97-S86=E"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('1O(&QO9RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N("!B;V]L96%N(%1R=64@:68@=&AE(&UE<W-A9V4@=V%S
M('-U8V-E<W-F=6QL>2!L;V=G960N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@
M<'5B;&EC"B`@("`@*B!`<VEN8V4@("!,;V<@,2XW+C`*("`@("`J+PH@("`@
M9G5N8W1I;VX@96UE<F<H)&UE<W-A9V4I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3YL;V<H)&UE<W-A9V4L(%!%05)?3$]'7T5-15)'*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($$@8V]N=F5N:65N8V4@9G5N8W1I;VX@9F]R(&QO
M9V=I;F<@86X@86QE<G0@979E;G0N("!)="!W:6QL(&QO9R!A"B`@("`@*B!M
M97-S86=E(&%T('1H92!014%27TQ/1U]!3$525"!L;V<@;&5V96PN"B`@("`@
M*@H@("`@("H@0'!A<F%M("`@;6EX960@("`D;65S<V%G92`@("!3=')I;F<@
M;W(@;V)J96-T(&-O;G1A:6YI;F<@=&AE(&UE<W-A9V4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@=&\@;&]G+@H@("`@("H*("`@("`J
M($!R971U<FX@(&)O;VQE86X@5')U92!I9B!T:&4@;65S<V%G92!W87,@<W5C
M8V5S<V9U;&QY(&QO9V=E9"X*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L
M:6,*("`@("`J($!S:6YC92`@($QO9R`Q+C<N,`H@("`@("HO"B`@("!F=6YC
M=&EO;B!A;&5R="@D;65S<V%G92D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/FQO9R@D;65S<V%G92P@4$5!4E],3T=?04Q%4E0I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@02!C;VYV96YI96YC92!F=6YC=&EO;B!F;W(@;&]G9VEN
M9R!A(&-R:71I8V%L(&5V96YT+B`@270@=VEL;"!L;V<@80H@("`@("H@;65S
M<V%G92!A="!T:&4@4$5!4E],3T=?0U))5"!L;V<@;&5V96PN"B`@("`@*@H@
M("`@("H@0'!A<F%M("`@;6EX960@("`D;65S<V%G92`@("!3=')I;F<@;W(@
M;V)J96-T(&-O;G1A:6YI;F<@=&AE(&UE<W-A9V4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=&\@;&]G+@H@("`@("H*("`@("`J($!R
M971U<FX@(&)O;VQE86X@5')U92!I9B!T:&4@;65S<V%G92!W87,@<W5C8V5S
M<V9U;&QY(&QO9V=E9"X*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*
M("`@("`J($!S:6YC92`@($QO9R`Q+C<N,`H@("`@("HO"B`@("!F=6YC=&EO
M;B!C<FET*"1M97-S86=E*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M;&]G*"1M97-S86=E+"!014%27TQ/1U]#4DE4*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($$@8V]N=F5N:65N8V4@9G5N8W1I;VX@9F]R(&QO9V=I;F<@82!E
M<G)O<B!E=F5N="X@($ET('=I;&P@;&]G(&$*("`@("`J(&UE<W-A9V4@870@
M=&AE(%!%05)?3$]'7T524B!L;V<@;&5V96PN"B`@("`@*@H@("`@("H@0'!A
M<F%M("`@;6EX960@("`D;65S<V%G92`@("!3=')I;F<@;W(@;V)J96-T(&-O
M;G1A:6YI;F<@=&AE(&UE<W-A9V4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@=&\@;&]G+@H@("`@("H*("`@("`J($!R971U<FX@(&)O
M;VQE86X@5')U92!I9B!T:&4@;65S<V%G92!W87,@<W5C8V5S<V9U;&QY(&QO
M9V=E9"X*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!S
M:6YC92`@($QO9R`Q+C<N,`H@("`@("HO"B`@("!F=6YC=&EO;B!E<G(H)&UE
M<W-A9V4I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YL;V<H)&UE<W-A
M9V4L(%!%05)?3$]'7T524BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!(&-O
M;G9E;FEE;F-E(&9U;F-T:6]N(&9O<B!L;V=G:6YG(&$@=V%R;FEN9R!E=F5N
M="X@($ET('=I;&P@;&]G(&$*("`@("`J(&UE<W-A9V4@870@=&AE(%!%05)?
M3$]'7U=!4DY)3D<@;&]G(&QE=F5L+@H@("`@("H*("`@("`J($!P87)A;2`@
M(&UI>&5D("`@)&UE<W-A9V4@("`@4W1R:6YG(&]R(&]B:F5C="!C;VYT86EN
M:6YG('1H92!M97-S86=E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('1O(&QO9RX*("`@("`J"B`@("`@*B!`<F5T=7)N("!B;V]L96%N
M(%1R=64@:68@=&AE(&UE<W-A9V4@=V%S('-U8V-E<W-F=6QL>2!L;V=G960N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<VEN8V4@
M("!,;V<@,2XW+C`*("`@("`J+PH@("`@9G5N8W1I;VX@=V%R;FEN9R@D;65S
M<V%G92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/FQO9R@D;65S<V%G
M92P@4$5!4E],3T=?5T%23DE.1RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!
M(&-O;G9E;FEE;F-E(&9U;F-T:6]N(&9O<B!L;V=G:6YG(&$@;F]T:6-E(&5V
M96YT+B`@270@=VEL;"!L;V<@80H@("`@("H@;65S<V%G92!A="!T:&4@4$5!
M4E],3T=?3D]424-%(&QO9R!L979E;"X*("`@("`J"B`@("`@*B!`<&%R86T@
M("!M:7AE9"`@("1M97-S86=E("`@(%-T<FEN9R!O<B!O8FIE8W0@8V]N=&%I
M;FEN9R!T:&4@;65S<V%G90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!T;R!L;V<N"B`@("`@*@H@("`@("H@0')E='5R;B`@8F]O;&5A
M;B!4<G5E(&EF('1H92!M97-S86=E('=A<R!S=6-C97-S9G5L;'D@;&]G9V5D
M+@H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'-I;F-E
M("`@3&]G(#$N-RXP"B`@("`@*B\*("`@(&9U;F-T:6]N(&YO=&EC92@D;65S
M<V%G92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/FQO9R@D;65S<V%G
M92P@4$5!4E],3T=?3D]424-%*3L*("`@('T*"B`@("`O*BH*("`@("`J($$@
M8V]N=F5N:65N8V4@9G5N8W1I;VX@9F]R(&QO9V=I;F<@82!I;F9O<FUA=&EO
M;B!E=F5N="X@($ET('=I;&P@;&]G(&$*("`@("`J(&UE<W-A9V4@870@=&AE
M(%!%05)?3$]'7TE.1D\@;&]G(&QE=F5L+@H@("`@("H*("`@("`J($!P87)A
M;2`@(&UI>&5D("`@)&UE<W-A9V4@("`@4W1R:6YG(&]R(&]B:F5C="!C;VYT
M86EN:6YG('1H92!M97-S86=E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('1O(&QO9RX*("`@("`J"B`@("`@*B!`<F5T=7)N("!B;V]L
M96%N(%1R=64@:68@=&AE(&UE<W-A9V4@=V%S('-U8V-E<W-F=6QL>2!L;V=G
M960N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<VEN
M8V4@("!,;V<@,2XW+C`*("`@("`J+PH@("`@9G5N8W1I;VX@:6YF;R@D;65S
M<V%G92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/FQO9R@D;65S<V%G
M92P@4$5!4E],3T=?24Y&3RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!(&-O
M;G9E;FEE;F-E(&9U;F-T:6]N(&9O<B!L;V=G:6YG(&$@9&5B=6<@979E;G0N
M("!)="!W:6QL(&QO9R!A"B`@("`@*B!M97-S86=E(&%T('1H92!014%27TQ/
M1U]$14)51R!L;V<@;&5V96PN"B`@("`@*@H@("`@("H@0'!A<F%M("`@;6EX
M960@("`D;65S<V%G92`@("!3=')I;F<@;W(@;V)J96-T(&-O;G1A:6YI;F<@
M=&AE(&UE<W-A9V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@=&\@;&]G+@H@("`@("H*("`@("`J($!R971U<FX@(&)O;VQE86X@5')U
M92!I9B!T:&4@;65S<V%G92!W87,@<W5C8V5S<V9U;&QY(&QO9V=E9"X*("`@
M("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!S:6YC92`@($QO
M9R`Q+C<N,`H@("`@("HO"B`@("!F=6YC=&EO;B!D96)U9R@D;65S<V%G92D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/FQO9R@D;65S<V%G92P@4$5!
M4E],3T=?1$5"54<I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&4@<W1R:6YG(')E<')E<V5N=&%T:6]N(&]F('1H92!M97-S86=E(&1A=&$N
M"B`@("`@*@H@("`@("H@268@)&UE<W-A9V4@:7,@86X@;V)J96-T+"!?97AT
M<F%C=$UE<W-A9V4H*2!W:6QL(&%T=&5M<'0@=&\@97AT<F%C=`H@("`@("H@
M=&AE(&UE<W-A9V4@=&5X="!U<VEN9R!A(&MN;W=N(&UE=&AO9"`H<W5C:"!A
M<R!A(%!%05)?17)R;W(@;V)J96-T)W,*("`@("`J(&=E=$UE<W-A9V4H*2!M
M971H;V0I+B`@268@82!K;F]W;B!M971H;V0L(&-A;FYO="!B92!F;W5N9"P@
M=&AE"B`@("`@*B!S97)I86QI>F5D(')E<')E<V5N=&%T:6]N(&]F('1H92!O
M8FIE8W0@=VEL;"!B92!R971U<FYE9"X*("`@("`J"B`@("`@*B!)9B!T:&4@
M;65S<V%G92!D871A(&ES(&%L<F5A9'D@82!S=')I;F<L(&ET('=I;&P@8F4@
M<F5T=7)N960@=6YC:&%N9V5D+@H@("`@("H*("`@("`J($!P87)A;2`@;6EX
M960@)&UE<W-A9V4@("!4:&4@;W)I9VEN86P@;65S<V%G92!D871A+B`@5&AI
M<R!M87D@8F4@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('-T
M<FEN9R!O<B!A;GD@;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("`@("`@("`@("!4:&4@<W1R:6YG(')E<')E<V5N=&%T:6]N(&]F('1H
M92!M97-S86=E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("HO"B`@("!F=6YC=&EO;B!?97AT<F%C=$UE<W-A9V4H)&UE<W-A9V4I"B`@
M("!["B`@("`@("`@+RH*("`@("`@("`@*B!)9B!W92=V92!B965N(&=I=F5N
M(&%N(&]B:F5C="P@871T96UP="!T;R!E>'1R86-T('1H92!M97-S86=E('5S
M:6YG"B`@("`@("`@("H@82!K;F]W;B!M971H;V0N("!)9B!W92!C86XG="!F
M:6YD('-U8V@@82!M971H;V0L(&1E9F%U;'0@=&\@=&AE"B`@("`@("`@("H@
M(FAU;6%N+7)E861A8FQE(B!V97)S:6]N(&]F('1H92!O8FIE8W0N"B`@("`@
M("`@("H*("`@("`@("`@*B!792!A;'-O('5S92!T:&4@:'5M86XM<F5A9&%B
M;&4@9F]R;6%T(&9O<B!A<G)A>7,N"B`@("`@("`@("HO"B`@("`@("`@:68@
M*&ES7V]B:F5C="@D;65S<V%G92DI('L*("`@("`@("`@("`@:68@*&UE=&AO
M9%]E>&ES=',H)&UE<W-A9V4L("=G971M97-S86=E)RDI('L*("`@("`@("`@
M("`@("`@("1M97-S86=E(#T@)&UE<W-A9V4M/F=E=$UE<W-A9V4H*3L*("`@
M("`@("`@("`@?2!E;'-E(&EF("AM971H;V1?97AI<W1S*"1M97-S86=E+"`G
M=&]S=')I;F<G*2D@>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2`D;65S
M<V%G92T^=&]3=')I;F<H*3L*("`@("`@("`@("`@?2!E;'-E(&EF("AM971H
M;V1?97AI<W1S*"1M97-S86=E+"`G7U]T;W-T<FEN9R<I*2!["B`@("`@("`@
M("`@("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*%!(4%]615)324].+"`G-2XP
M+C`G+"`G9V4G*2D@>PH@("`@("`@("`@("`@("`@("`@("1M97-S86=E(#T@
M*'-T<FEN9RDD;65S<V%G93L*("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2`D;65S<V%G92T^7U]T;U-T
M<FEN9R@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2!P<FEN=%]R*"1M97-S86=E
M+"!T<G5E*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!I9B`H:7-?
M87)R87DH)&UE<W-A9V4I*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D;65S
M<V%G95LG;65S<V%G92==*2D@>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@
M/2`D;65S<V%G95LG;65S<V%G92==.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)&UE<W-A9V4@/2!P<FEN=%]R*"1M97-S86=E+"!T
M<G5E*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@3W1H
M97)W:7-E+"!W92!A<W-U;64@=&AE(&UE<W-A9V4@:7,@82!S=')I;F<N("HO
M"B`@("`@("`@<F5T=7)N("1M97-S86=E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@57-I;F<@9&5B=6=?8F%C:W1R86-E*"DL(')E='5R;G,@=&AE(&9I;&4L
M(&QI;F4L(&%N9"!E;F-L;W-I;F<@9G5N8W1I;VX*("`@("`J(&YA;64@;V8@
M=&AE('-O=7)C92!C;V1E(&-O;G1E>'0@9G)O;2!W:&EC:"!L;V<H*2!W87,@
M:6YV;VMV960N"B`@("`@*@H@("`@("H@0'!A<F%M("`@:6YT("`@("`D9&5P
M=&@@(%1H92!I;FET:6%L(&YU;6)E<B!O9B!F<F%M97,@=V4@<VAO=6QD('-T
M97`*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!B86-K(&EN=&\@
M=&AE('1R86-E+@H@("`@("H*("`@("`J($!R971U<FX@(&%R<F%Y("`@07)R
M87D@8V]N=&%I;FEN9R!T:')E92!S=')I;F=S.B!T:&4@9FEL96YA;64L('1H
M92!L:6YE+`H@("`@("H@("`@("`@("`@("`@("`@("!A;F0@=&AE(&9U;F-T
M:6]N(&YA;64@9G)O;2!W:&EC:"!L;V<H*2!W87,@8V%L;&5D+@H@("`@("H*
M("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J($!S:6YC92`@($QO9R`Q
M+CDN-`H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T0F%C:W1R86-E5F%R<R@D
M9&5P=&@I"B`@("!["B`@("`@("`@+RH@4W1A<G0@8GD@9V5N97)A=&EN9R!A
M(&)A8VMT<F%C92!F<F]M('1H92!C=7)R96YT(&-A;&P@*&AE<F4I+B`J+PH@
M("`@("`@("1B86-K=')A8V4@/2!D96)U9U]B86-K=')A8V4H*3L*"B`@("`@
M("`@+RH*("`@("`@("`@*B!792=R92!I;G1E<F5S=&5D(&EN('1H92!F<F%M
M92!W:&EC:"!I;G9O:V5D('1H92!L;V<H*2!F=6YC=&EO;BP@<V\*("`@("`@
M("`@*B!W92!N965D('1O('=A;&L@8F%C:R!S;VUE(&YU;6)E<B!O9B!F<F%M
M97,@:6YT;R!T:&4@8F%C:W1R86-E+B`@5&AE"B`@("`@("`@("H@)&1E<'1H
M('!A<F%M971E<B!T96QL<R!U<R!W:&5R92!T;R!S=&%R="!L;V]K:6YG+B`@
M(%=E(&=O(&]N92!S=&5P"B`@("`@("`@("H@9G5R=&AE<B!B86-K('1O(&9I
M;F0@=&AE(&YA;64@;V8@=&AE(&5N8V%P<W5L871I;F<@9G5N8W1I;VX@9G)O
M;0H@("`@("`@("`J('=H:6-H(&QO9R@I('=A<R!C86QL960N"B`@("`@("`@
M("HO"B`@("`@("`@)&9I;&4@/2!`)&)A8VMT<F%C95LD9&5P=&A=6R=F:6QE
M)UT["B`@("`@("`@)&QI;F4@/2!`)&)A8VMT<F%C95LD9&5P=&A=6R=L:6YE
M)UT["B`@("`@("`@)&9U;F,@/2!`)&)A8VMT<F%C95LD9&5P=&@@*R`Q75LG
M9G5N8W1I;VXG73L*"B`@("`@("`@+RH*("`@("`@("`@*B!(;W=E=F5R+"!I
M9B!L;V<H*2!W87,@8V%L;&5D(&9R;VT@;VYE(&]F(&]U<B`B<VAO<G1C=70B
M(&9U;F-T:6]N<RP*("`@("`@("`@*B!W92=R92!G;VEN9R!T;R!N965D('1O
M(&=O(&)A8VL@86X@861D:71I;VYA;"!S=&5P+@H@("`@("`@("`J+PH@("`@
M("`@(&EF("AI;E]A<G)A>2@D9G5N8RP@87)R87DH)V5M97)G)RP@)V%L97)T
M)RP@)V-R:70G+"`G97)R)RP@)W=A<FYI;F<G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)VYO=&EC92<L("=I;F9O)RP@)V1E8G5G)RDI
M*2!["B`@("`@("`@("`@("1F:6QE(#T@0"1B86-K=')A8V5;)&1E<'1H("L@
M,5U;)V9I;&4G73L*("`@("`@("`@("`@)&QI;F4@/2!`)&)A8VMT<F%C95LD
M9&5P=&@@*R`Q75LG;&EN92==.PH@("`@("`@("`@("`D9G5N8R`]($`D8F%C
M:W1R86-E6R1D97!T:"`K(#)=6R=F=6YC=&EO;B==.PH@("`@("`@('T*"B`@
M("`@("`@+RH*("`@("`@("`@*B!)9B!W92!C;W5L9&XG="!E>'1R86-T(&$@
M9G5N8W1I;VX@;F%M92`H<&5R:&%P<R!B96-A=7-E('=E('=E<F4*("`@("`@
M("`@*B!E>&5C=71E9"!F<F]M('1H92`B;6%I;B(@8V]N=&5X="DL('!R;W9I
M9&4@82!D969A=6QT('9A;'5E+@H@("`@("`@("`J+PH@("`@("`@(&EF("AI
M<U]N=6QL*"1F=6YC*2D@>PH@("`@("`@("`@("`D9G5N8R`]("<H;F]N92DG
M.PH@("`@("`@('T*"B`@("`@("`@+RH@4F5T=7)N(&$@,RUT=7!L92!C;VYT
M86EN:6YG("AF:6QE+"!L:6YE+"!F=6YC=&EO;BDN("HO"B`@("`@("`@<F5T
M=7)N(&%R<F%Y*"1F:6QE+"`D;&EN92P@)&9U;F,I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4')O9'5C97,@82!F;W)M871T960@;&]G(&QI;F4@8F%S960@
M;VX@82!F;W)M870@<W1R:6YG(&%N9"!A('-E="!O9@H@("`@("H@=F%R:6%B
M;&5S(')E<')E<V5N=&EN9R!T:&4@8W5R<F5N="!L;V<@<F5C;W)D(&%N9"!S
M=&%T92X*("`@("`J"B`@("`@*B!`<F5T=7)N("!S=')I;F<@($9O<FUA='1E
M9"!L;V<@<W1R:6YG+@H@("`@("H*("`@("`J($!A8V-E<W,@('!R:79A=&4*
M("`@("`J($!S:6YC92`@($QO9R`Q+CDN-`H@("`@("HO"B`@("!F=6YC=&EO
M;B!?9F]R;6%T*"1F;W)M870L("1T:6UE<W1A;7`L("1P<FEO<FET>2P@)&UE
M<W-A9V4I"B`@("!["B`@("`@("`@+RH*("`@("`@("`@*B!)9B!T:&4@9F]R
M;6%T('-T<FEN9R!R969E<F5N8V5S(&%N>2!O9B!T:&4@8F%C:W1R86-E+61R
M:79E;@H@("`@("`@("`J('9A<FEA8FQE<R`H)34L("4V+"`E-RDL(&=E;F5R
M871E('1H92!B86-K=')A8V4@86YD(&9E=&-H('1H96TN"B`@("`@("`@("HO
M"B`@("`@("`@:68@*'!R96=?;6%T8V@H)R\E6S4V-UTO)RP@)&9O<FUA="DI
M('L*("`@("`@("`@("`@;&ES="@D9FEL92P@)&QI;F4L("1F=6YC*2`]("1T
M:&ES+3Y?9V5T0F%C:W1R86-E5F%R<R@R*3L*("`@("`@("!]"@H@("`@("`@
M("\J"B`@("`@("`@("H@0G5I;&0@=&AE(&9O<FUA='1E9"!S=')I;F<N("!7
M92!U<V4@=&AE('-P<FEN=&8H*2!F=6YC=&EO;B=S"B`@("`@("`@("H@(F%R
M9W5M96YT('-W87!P:6YG(B!C87!A8FEL:71Y('1O(&1Y;F%M:6-A;&QY('-E
M;&5C="!A;F0@<&]S:71I;VX*("`@("`@("`@*B!T:&4@=F%R:6%B;&5S('=H
M:6-H('=I;&P@=6QT:6UA=&5L>2!A<'!E87(@:6X@=&AE(&QO9R!S=')I;F<N
M"B`@("`@("`@("HO"B`@("`@("`@<F5T=7)N('-P<FEN=&8H)&9O<FUA="P*
M("`@("`@("`@("`@("`@("`@("`@("`D=&EM97-T86UP+`H@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?:61E;G0L"B`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G!R:6]R:71Y5&]3=')I;F<H)'!R:6]R:71Y*2P*("`@
M("`@("`@("`@("`@("`@("`@("`D;65S<V%G92P*("`@("`@("`@("`@("`@
M("`@("`@("!I<W-E="@D9FEL92D@/R`D9FEL92`Z("<G+`H@("`@("`@("`@
M("`@("`@("`@("`@(&ES<V5T*"1L:6YE*2`_("1L:6YE(#H@)R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@:7-S970H)&9U;F,I(#\@)&9U;F,@.B`G)RD[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!S=')I;F<@<F5P
M<F5S96YT871I;VX@;V8@82!014%27TQ/1U\J(&EN=&5G97(@8V]N<W1A;G0N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`D<')I;W)I='D@("`@($$@4$5!
M4E],3T=?*B!I;G1E9V5R(&-O;G-T86YT+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("`@("`@("`@("!4:&4@<W1R:6YG(')E<')E<V5N=&%T:6]N
M(&]F("1L979E;"X*("`@("`J"B`@("`@*B!`<VEN8V4@("!,;V<@,2XP"B`@
M("`@*B\*("`@(&9U;F-T:6]N('!R:6]R:71Y5&]3=')I;F<H)'!R:6]R:71Y
M*0H@("`@>PH@("`@("`@("1L979E;',@/2!A<G)A>2@*("`@("`@("`@("`@
M4$5!4E],3T=?14U%4D<@("`]/B`G96UE<F=E;F-Y)RP*("`@("`@("`@("`@
M4$5!4E],3T=?04Q%4E0@("`]/B`G86QE<G0G+`H@("`@("`@("`@("!014%2
M7TQ/1U]#4DE4("`@(#T^("=C<FET:6-A;"<L"B`@("`@("`@("`@(%!%05)?
M3$]'7T524B`@("`@/3X@)V5R<F]R)RP*("`@("`@("`@("`@4$5!4E],3T=?
M5T%23DE.1R`]/B`G=V%R;FEN9R<L"B`@("`@("`@("`@(%!%05)?3$]'7TY/
M5$E#12`@/3X@)VYO=&EC92<L"B`@("`@("`@("`@(%!%05)?3$]'7TE.1D\@
M("`@/3X@)VEN9F\G+`H@("`@("`@("`@("!014%27TQ/1U]$14)51R`@(#T^
M("=D96)U9R<*("`@("`@("`I.PH*("`@("`@("!R971U<FX@)&QE=F5L<ULD
M<')I;W)I='E=.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M=&AE(%!%05)?3$]'7RH@:6YT96=E<B!C;VYS=&%N="!F;W(@=&AE(&=I=F5N
M('-T<FEN9PH@("`@("H@<F5P<F5S96YT871I;VX@;V8@82!P<FEO<FET>2!N
M86UE+B`@5&AI<R!F=6YC=&EO;B!P97)F;W)M<R!A"B`@("`@*B!C87-E+6EN
M<V5N<VET:79E('-E87)C:"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N86UE("`@("`@4W1R:6YG(&-O;G1A:6YI;F<@82!P<FEO<FET>2!N86UE
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("`@("`@("`@("!4:&4@
M4$5!4E],3T=?*B!I;G1E9V5R(&-O;G1S=&%N="!C;W)R97-P;VYD:6YG"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE('1H92!S<&5C:69I
M960@<')I;W)I='D@;F%M92X*("`@("`J"B`@("`@*B!`<VEN8V4@("!,;V<@
M,2XY+C`*("`@("`J+PH@("`@9G5N8W1I;VX@<W1R:6YG5&]0<FEO<FET>2@D
M;F%M92D*("`@('L*("`@("`@("`D;&5V96QS(#T@87)R87DH"B`@("`@("`@
M("`@("=E;65R9V5N8WDG(#T^(%!%05)?3$]'7T5-15)'+`H@("`@("`@("`@
M("`G86QE<G0G("`@("`]/B!014%27TQ/1U]!3$525"P*("`@("`@("`@("`@
M)V-R:71I8V%L)R`@/3X@4$5!4E],3T=?0U))5"P*("`@("`@("`@("`@)V5R
M<F]R)R`@("`@/3X@4$5!4E],3T=?15)2+`H@("`@("`@("`@("`G=V%R;FEN
M9R<@("`]/B!014%27TQ/1U]705).24Y'+`H@("`@("`@("`@("`G;F]T:6-E
M)R`@("`]/B!014%27TQ/1U].3U1)0T4L"B`@("`@("`@("`@("=I;F9O)R`@
M("`@(#T^(%!%05)?3$]'7TE.1D\L"B`@("`@("`@("`@("=D96)U9R<@("`@
M(#T^(%!%05)?3$]'7T1%0E5'"B`@("`@("`@*3L*"B`@("`@("`@<F5T=7)N
M("1L979E;'-;<W1R=&]L;W=E<B@D;F%M92E=.PH@("`@?0H*("`@("\J*@H@
M("`@("H@0V%L8W5L871E('1H92!L;V<@;6%S:R!F;W(@=&AE(&=I=F5N('!R
M:6]R:71Y+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&UA>2!B92!C86QL
M960@<W1A=&EC86QL>2X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`@
M("1P<FEO<FET>2`@(%1H92!P<FEO<FET>2!W:&]S92!M87-K('=I;&P@8F4@
M8V%L8W5L871E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H
M92!C86QC=6QA=&5D(&QO9R!M87-K+@H@("`@("H*("`@("`J($!A8V-E<W,@
M('!U8FQI8PH@("`@("H@0'-I;F-E("`@3&]G(#$N-RXP"B`@("`@*B\*("`@
M(&9U;F-T:6]N($U!4TLH)'!R:6]R:71Y*0H@("`@>PH@("`@("`@(')E='5R
M;B`H,2`\/"`D<')I;W)I='DI.PH@("`@?0H*("`@("\J*@H@("`@("H@0V%L
M8W5L871E('1H92!L;V<@;6%S:R!F;W(@86QL('!R:6]R:71I97,@=7`@=&\@
M=&AE(&=I=F5N('!R:6]R:71Y+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D
M(&UA>2!B92!C86QL960@<W1A=&EC86QL>2X*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`@("1P<FEO<FET>2`@(%1H92!M87AI;75M('!R:6]R:71Y
M(&-O=F5R960@8GD@=&AI<R!M87-K+@H@("`@("H*("`@("`J($!R971U<FX@
M:6YT96=E<B`@5&AE(')E<W5L=&EN9R!L;V<@;6%S:RX*("`@("`J"B`@("`@
M*B!`86-C97-S("!P=6)L:6,*("`@("`J($!S:6YC92`@($QO9R`Q+C<N,`H@
M("`@("H*("`@("`J($!D97!R96-A=&5D(&1E<')E8V%T960@<VEN8V4@3&]G
M(#$N.2XT.R!U<V4@3&]G.CI-05@H*2!I;G-T96%D"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%505$\H)'!R:6]R:71Y*0H@("`@>PH@("`@("`@(')E='5R;B!,
M;V<Z.DU!6"@D<')I;W)I='DI.PH@("`@?0H*("`@("\J*@H@("`@("H@0V%L
M8W5L871E('1H92!L;V<@;6%S:R!F;W(@86QL('!R:6]R:71I97,@9W)E871E
M<B!T:&%N(&]R(&5Q=6%L('1O('1H90H@("`@("H@9VEV96X@<')I;W)I='DN
M("!);B!O=&AE<B!W;W)D<RP@)'!R:6]R:71Y('=I;&P@8F4@=&AE(&QO=V5S
M="!P<FEO<FET>0H@("`@("H@;6%T8VAE9"!B>2!T:&4@<F5S=6QT:6YG(&UA
M<VLN"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@;6%Y(&)E(&-A;&QE9"!S
M=&%T:6-A;&QY+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("`@)'!R
M:6]R:71Y("`@5&AE(&UI;FEM=6T@<')I;W)I='D@8V]V97)E9"!B>2!T:&ES
M(&UA<VLN"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@<F5S
M=6QT:6YG(&QO9R!M87-K+@H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI
M8PH@("`@("H@0'-I;F-E("`@3&]G(#$N.2XT"B`@("`@*B\*("`@(&9U;F-T
M:6]N($U)3B@D<')I;W)I='DI"B`@("!["B`@("`@("`@<F5T=7)N(%!%05)?
M3$]'7T%,3"!>("@H,2`\/"`D<')I;W)I='DI("T@,2D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#86QC=6QA=&4@=&AE(&QO9R!M87-K(&9O<B!A;&P@<')I
M;W)I=&EE<R!L97-S('1H86X@;W(@97%U86P@=&\@=&AE"B`@("`@*B!G:79E
M;B!P<FEO<FET>2X@($EN(&]T:&5R('=O<F1S+"`D<')I;W)I='D@=VEL;"!B
M92!T:&4@:&EG:&5S=',@<')I;W)I='D*("`@("`J(&UA=&-H960@8GD@=&AE
M(')E<W5L=&EN9R!M87-K+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&UA
M>2!B92!C86QL960@<W1A=&EC86QL>2X*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`@("1P<FEO<FET>2`@(%1H92!M87AI;75M('!R:6]R:71Y(&-O
M=F5R960@8GD@=&AI<R!M87-K+@H@("`@("H*("`@("`J($!R971U<FX@:6YT
M96=E<B`@5&AE(')E<W5L=&EN9R!L;V<@;6%S:RX*("`@("`J"B`@("`@*B!`
M86-C97-S("!P=6)L:6,*("`@("`J($!S:6YC92`@($QO9R`Q+CDN-`H@("`@
M("HO"B`@("!F=6YC=&EO;B!-05@H)'!R:6]R:71Y*0H@("`@>PH@("`@("`@
M(')E='5R;B`H*#$@/#P@*"1P<FEO<FET>2`K(#$I*2`M(#$I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4V5T(&%N9"!R971U<FX@=&AE(&QE=F5L(&UA<VL@
M9F]R('1H92!C=7)R96YT($QO9R!I;G-T86YC92X*("`@("`J"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D;6%S:R`@("`@02!B:71W:7-E(&UA<VL@;V8@;&]G
M(&QE=F5L<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@("`@("`@
M("`@5&AE(&-U<G)E;G0@;&5V96P@;6%S:RX*("`@("`J"B`@("`@*B!`86-C
M97-S("!P=6)L:6,*("`@("`J($!S:6YC92`@($QO9R`Q+C<N,`H@("`@("HO
M"B`@("!F=6YC=&EO;B!S971-87-K*"1M87-K*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?;6%S:R`]("1M87-K.PH*("`@("`@("!R971U<FX@)'1H:7,M/E]M
M87-K.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8W5R<F5N
M="!L979E;"!M87-K+@H@("`@("H*("`@("`J($!R971U<FX@:6YT97)G97(@
M("`@("`@("!4:&4@8W5R<F5N="!L979E;"!M87-K+@H@("`@("H*("`@("`J
M($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'-I;F-E("`@3&]G(#$N-RXP"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$UA<VLH*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7VUA<VL["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C
M:R!I9B!T:&4@9VEV96X@<')I;W)I='D@:7,@:6YC;'5D960@:6X@=&AE(&-U
M<G)E;G0@;&5V96P@;6%S:RX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`@("1P<FEO<FET>2`@(%1H92!P<FEO<FET>2!T;R!C:&5C:RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE(&=I=F5N('!R
M:6]R:71Y(&ES(&EN8VQU9&5D(&EN('1H92!C=7)R96YT"B`@("`@*B`@("`@
M("`@("`@("`@("`@(&QO9R!M87-K+@H@("`@("H*("`@("`J($!A8V-E<W,@
M('!R:79A=&4*("`@("`J($!S:6YC92`@($QO9R`Q+C<N,`H@("`@("HO"B`@
M("!F=6YC=&EO;B!?:7--87-K960H)'!R:6]R:71Y*0H@("`@>PH@("`@("`@
M(')E='5R;B`H3&]G.CI-05-+*"1P<FEO<FET>2D@)B`D=&AI<RT^7VUA<VLI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8W5R<F5N="!D
M969A=6QT('!R:6]R:71Y+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E
M<B`@5&AE(&-U<G)E;G0@9&5F875L="!P<FEO<FET>2X*("`@("`J"B`@("`@
M*B!`86-C97-S("!P=6)L:6,*("`@("`J($!S:6YC92`@($QO9R`Q+C@N-`H@
M("`@("HO"B`@("!F=6YC=&EO;B!G9710<FEO<FET>2@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?<')I;W)I='D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3971S('1H92!D969A=6QT('!R:6]R:71Y('1O('1H92!S<&5C:69I
M960@=F%L=64N"B`@("`@*@H@("`@("H@0'!A<F%M("`@:6YT96=E<B`D<')I
M;W)I='D@("!4:&4@;F5W(&1E9F%U;'0@<')I;W)I='DN"B`@("`@*@H@("`@
M("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<VEN8V4@("!,;V<@,2XX+C0*
M("`@("`J+PH@("`@9G5N8W1I;VX@<V5T4')I;W)I='DH)'!R:6]R:71Y*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?<')I;W)I='D@/2`D<')I;W)I='D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@3&]G7V]B<V5R=F5R(&EN<W1A
M;F-E('1O('1H92!L:7-T(&]F(&]B<V5R=F5R<R!T:&%T(&%R92!L:7-T96YI
M;F<*("`@("`J(&9O<B!M97-S86=E<R!E;6ET=&5D(&)Y('1H:7,@3&]G(&EN
M<W1A;F-E+@H@("`@("H*("`@("`J($!P87)A;2!O8FIE8W0@("`@)&]B<V5R
M=F5R("`@5&AE($QO9U]O8G-E<G9E<B!I;G-T86YC92!T;R!A='1A8V@@87,@
M80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!L:7-T96YE
M<BX*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`@(%1R=64@:68@=&AE
M(&]B<V5R=F5R(&ES('-U8V-E<W-F=6QL>2!A='1A8VAE9"X*("`@("`J"B`@
M("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!S:6YC92`@($QO9R`Q+C`*
M("`@("`J+PH@("`@9G5N8W1I;VX@871T86-H*"8D;V)S97)V97(I"B`@("![
M"B`@("`@("`@:68@*"%I<U]A*"1O8G-E<G9E<BP@)TQO9U]O8G-E<G9E<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@
M("`@("1T:&ES+3Y?;&ES=&5N97)S6R1O8G-E<G9E<BT^7VED72`]("8D;V)S
M97)V97(["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5M;W9E<R!A($QO9U]O8G-E<G9E<B!I;G-T86YC92!F<F]M('1H
M92!L:7-T(&]F(&]B<V5R=F5R<RX*("`@("`J"B`@("`@*B!`<&%R86T@;V)J
M96-T("`@("1O8G-E<G9E<B`@(%1H92!,;V=?;V)S97)V97(@:6YS=&%N8V4@
M=&\@9&5T86-H(&9R;VT*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@=&AE(&QI<W0@;V8@;&ES=&5N97)S+@H@("`@("H*("`@("`J($!P
M87)A;2!B;V]L96%N("`@5')U92!I9B!T:&4@;V)S97)V97(@:7,@<W5C8V5S
M<V9U;&QY(&1E=&%C:&5D+@H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI
M8PH@("`@("H@0'-I;F-E("`@3&]G(#$N,`H@("`@("HO"B`@("!F=6YC=&EO
M;B!D971A8V@H)&]B<V5R=F5R*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D
M;V)S97)V97(L("=,;V=?;V)S97)V97(G*2!\?`H@("`@("`@("`@("`A:7-S
M970H)'1H:7,M/E]L:7-T96YE<G-;)&]B<V5R=F5R+3Y?:61=*2D@>PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!U;G-E
M="@D=&AI<RT^7VQI<W1E;F5R<ULD;V)S97)V97(M/E]I9%TI.PH*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($EN9F]R;7,@
M96%C:"!R96=I<W1E<F5D(&]B<V5R=F5R(&EN<W1A;F-E('1H870@82!N97<@
M;65S<V%G92!H87,@8F5E;@H@("`@("H@;&]G9V5D+@H@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>2`@("`@)&5V96YT("`@("`@02!H87-H(&1E<V-R:6)I
M;F<@=&AE(&QO9R!E=F5N="X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V%N;F]U;F-E*"1E=F5N="D*("`@
M('L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7VQI<W1E;F5R<R!A<R`D:60@
M/3X@)&QI<W1E;F5R*2!["B`@("`@("`@("`@(&EF("@D979E;G1;)W!R:6]R
M:71Y)UT@/#T@)'1H:7,M/E]L:7-T96YE<G-;)&ED72T^7W!R:6]R:71Y*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7VQI<W1E;F5R<ULD:61=+3YN;W1I
M9GDH)&5V96YT*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($EN9&EC871E<R!W:&5T:&5R('1H:7,@:7,@82!C;VUP
M;W-I=&4@8VQA<W,N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("`@
M("`@("`@(%1R=64@:68@=&AI<R!I<R!A(&-O;7!O<VET92!C;&%S<RX*("`@
M("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!S:6YC92`@($QO
M9R`Q+C`*("`@("`J+PH@("`@9G5N8W1I;VX@:7-#;VUP;W-I=&4H*0H@("`@
M>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J
M(%-E=',@=&AI<R!,;V<@:6YS=&%N8V4G<R!I9&5N=&EF:6-A=&EO;B!S=')I
M;F<N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@("`D:61E;G0@("`@
M("!4:&4@;F5W(&ED96YT:69I8V%T:6]N('-T<FEN9RX*("`@("`J"B`@("`@
M*B!`86-C97-S("!P=6)L:6,*("`@("`J($!S:6YC92`@($QO9R`Q+C8N,PH@
M("`@("HO"B`@("!F=6YC=&EO;B!S971)9&5N="@D:61E;G0I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]I9&5N="`]("1I9&5N=#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE(&-U<G)E;G0@:61E;G1I9FEC871I;VX@<W1R
M:6YG+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("`@5&AE(&-U<G)E
M;G0@3&]G(&EN<W1A;F-E)W,@:61E;G1I9FEC871I;VX@<W1R:6YG+@H@("`@
M("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'-I;F-E("`@3&]G
M(#$N-BXS"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$ED96YT*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]I9&5N=#L*("`@('T*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O9&]C
M<P``````````````````````````````````````````````````````````
M`````````````````````````````````````#`P,#<U-2``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S,T(#`Q-C0Q,0`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]D;V-S+T-/4%E)3D<`````````````````````````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-C$R-S,@,3`U,34T,S,W
M,S,@,#$W-3,S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````D)("!'3E4@3$E"4D%262!'14Y%4D%,(%!50DQ)0R!,24-%3E-%
M"@D)("`@("`@(%9E<G-I;VX@,BP@2G5N92`Q.3DQ"@H@0V]P>7)I9VAT("A#
M*2`Q.3DQ($9R964@4V]F='=A<F4@1F]U;F1A=&EO;BP@26YC+@H@("`@"0D@
M("`@-3D@5&5M<&QE(%!L86-E+"!3=6ET92`S,S`L($)O<W1O;BP@34$@(#`R
M,3$Q+3$S,#<@(%5300H@179E<GEO;F4@:7,@<&5R;6ET=&5D('1O(&-O<'D@
M86YD(&1I<W1R:6)U=&4@=F5R8F%T:6T@8V]P:65S"B!O9B!T:&ES(&QI8V5N
M<V4@9&]C=6UE;G0L(&)U="!C:&%N9VEN9R!I="!I<R!N;W0@86QL;W=E9"X*
M"EM4:&ES(&ES('1H92!F:7)S="!R96QE87-E9"!V97)S:6]N(&]F('1H92!L
M:6)R87)Y($=03"X@($ET(&ES"B!N=6UB97)E9"`R(&)E8V%U<V4@:70@9V]E
M<R!W:71H('9E<G-I;VX@,B!O9B!T:&4@;W)D:6YA<GD@1U!,+ET*"@D)"2`@
M("!0<F5A;6)L90H*("!4:&4@;&EC96YS97,@9F]R(&UO<W0@<V]F='=A<F4@
M87)E(&1E<VEG;F5D('1O('1A:V4@87=A>2!Y;W5R"F9R965D;VT@=&\@<VAA
M<F4@86YD(&-H86YG92!I="X@($)Y(&-O;G1R87-T+"!T:&4@1TY5($=E;F5R
M86P@4'5B;&EC"DQI8V5N<V5S(&%R92!I;G1E;F1E9"!T;R!G=6%R86YT964@
M>6]U<B!F<F5E9&]M('1O('-H87)E(&%N9"!C:&%N9V4*9G)E92!S;V9T=V%R
M92TM=&\@;6%K92!S=7)E('1H92!S;V9T=V%R92!I<R!F<F5E(&9O<B!A;&P@
M:71S('5S97)S+@H*("!4:&ES(&QI8V5N<V4L('1H92!,:6)R87)Y($=E;F5R
M86P@4'5B;&EC($QI8V5N<V4L(&%P<&QI97,@=&\@<V]M90IS<&5C:6%L;'D@
M9&5S:6=N871E9"!&<F5E(%-O9G1W87)E($9O=6YD871I;VX@<V]F='=A<F4L
M(&%N9"!T;R!A;GD*;W1H97(@;&EB<F%R:65S('=H;W-E(&%U=&AO<G,@9&5C
M:61E('1O('5S92!I="X@(%EO=2!C86X@=7-E(&ET(&9O<@IY;W5R(&QI8G)A
M<FEE<RP@=&]O+@H*("!7:&5N('=E('-P96%K(&]F(&9R964@<V]F='=A<F4L
M('=E(&%R92!R969E<G)I;F<@=&\@9G)E961O;2P@;F]T"G!R:6-E+B`@3W5R
M($=E;F5R86P@4'5B;&EC($QI8V5N<V5S(&%R92!D97-I9VYE9"!T;R!M86ME
M('-U<F4@=&AA="!Y;W4*:&%V92!T:&4@9G)E961O;2!T;R!D:7-T<FEB=71E
M(&-O<&EE<R!O9B!F<F5E('-O9G1W87)E("AA;F0@8VAA<F=E(&9O<@IT:&ES
M('-E<G9I8V4@:68@>6]U('=I<V@I+"!T:&%T('EO=2!R96-E:79E('-O=7)C
M92!C;V1E(&]R(&-A;B!G970@:70*:68@>6]U('=A;G0@:70L('1H870@>6]U
M(&-A;B!C:&%N9V4@=&AE('-O9G1W87)E(&]R('5S92!P:65C97,@;V8@:70*
M:6X@;F5W(&9R964@<')O9W)A;7,[(&%N9"!T:&%T('EO=2!K;F]W('EO=2!C
M86X@9&\@=&AE<V4@=&AI;F=S+@H*("!4;R!P<F]T96-T('EO=7(@<FEG:'1S
M+"!W92!N965D('1O(&UA:V4@<F5S=')I8W1I;VYS('1H870@9F]R8FED"F%N
M>6]N92!T;R!D96YY('EO=2!T:&5S92!R:6=H=',@;W(@=&\@87-K('EO=2!T
M;R!S=7)R96YD97(@=&AE(')I9VAT<RX*5&AE<V4@<F5S=')I8W1I;VYS('1R
M86YS;&%T92!T;R!C97)T86EN(')E<W!O;G-I8FEL:71I97,@9F]R('EO=2!I
M9@IY;W4@9&ES=')I8G5T92!C;W!I97,@;V8@=&AE(&QI8G)A<GDL(&]R(&EF
M('EO=2!M;V1I9GD@:70N"@H@($9O<B!E>&%M<&QE+"!I9B!Y;W4@9&ES=')I
M8G5T92!C;W!I97,@;V8@=&AE(&QI8G)A<GDL('=H971H97(@9W)A=&ES"F]R
M(&9O<B!A(&9E92P@>6]U(&UU<W0@9VEV92!T:&4@<F5C:7!I96YT<R!A;&P@
M=&AE(')I9VAT<R!T:&%T('=E(&=A=F4*>6]U+B`@66]U(&UU<W0@;6%K92!S
M=7)E('1H870@=&AE>2P@=&]O+"!R96-E:79E(&]R(&-A;B!G970@=&AE('-O
M=7)C90IC;V1E+B`@268@>6]U(&QI;FL@82!P<F]G<F%M('=I=&@@=&AE(&QI
M8G)A<GDL('EO=2!M=7-T('!R;W9I9&4*8V]M<&QE=&4@;V)J96-T(&9I;&5S
M('1O('1H92!R96-I<&EE;G1S('-O('1H870@=&AE>2!C86X@<F5L:6YK('1H
M96T*=VET:"!T:&4@;&EB<F%R>2P@869T97(@;6%K:6YG(&-H86YG97,@=&\@
M=&AE(&QI8G)A<GD@86YD(')E8V]M<&EL:6YG"FET+B`@06YD('EO=2!M=7-T
M('-H;W<@=&AE;2!T:&5S92!T97)M<R!S;R!T:&5Y(&MN;W<@=&AE:7(@<FEG
M:'1S+@H*("!/=7(@;65T:&]D(&]F('!R;W1E8W1I;F<@>6]U<B!R:6=H=',@
M:&%S('1W;R!S=&5P<SH@*#$I(&-O<'ER:6=H=`IT:&4@;&EB<F%R>2P@86YD
M("@R*2!O9F9E<B!Y;W4@=&AI<R!L:6-E;G-E('=H:6-H(&=I=F5S('EO=2!L
M96=A;`IP97)M:7-S:6]N('1O(&-O<'DL(&1I<W1R:6)U=&4@86YD+V]R(&UO
M9&EF>2!T:&4@;&EB<F%R>2X*"B`@06QS;RP@9F]R(&5A8V@@9&ES=')I8G5T
M;W(G<R!P<F]T96-T:6]N+"!W92!W86YT('1O(&UA:V4@8V5R=&%I;@IT:&%T
M(&5V97)Y;VYE('5N9&5R<W1A;F1S('1H870@=&AE<F4@:7,@;F\@=V%R<F%N
M='D@9F]R('1H:7,@9G)E90IL:6)R87)Y+B`@268@=&AE(&QI8G)A<GD@:7,@
M;6]D:69I960@8GD@<V]M96]N92!E;'-E(&%N9"!P87-S960@;VXL('=E"G=A
M;G0@:71S(')E8VEP:65N=',@=&\@:VYO=R!T:&%T('=H870@=&AE>2!H879E
M(&ES(&YO="!T:&4@;W)I9VEN86P*=F5R<VEO;BP@<V\@=&AA="!A;GD@<')O
M8FQE;7,@:6YT<F]D=6-E9"!B>2!O=&AE<G,@=VEL;"!N;W0@<F5F;&5C="!O
M;@IT:&4@;W)I9VEN86P@875T:&]R<R<@<F5P=71A=&EO;G,N"@P*("!&:6YA
M;&QY+"!A;GD@9G)E92!P<F]G<F%M(&ES('1H<F5A=&5N960@8V]N<W1A;G1L
M>2!B>2!S;V9T=V%R90IP871E;G1S+B`@5V4@=VES:"!T;R!A=F]I9"!T:&4@
M9&%N9V5R('1H870@8V]M<&%N:65S(&1I<W1R:6)U=&EN9R!F<F5E"G-O9G1W
M87)E('=I;&P@:6YD:79I9'5A;&QY(&]B=&%I;B!P871E;G0@;&EC96YS97,L
M('1H=7,@:6X@969F96-T"G1R86YS9F]R;6EN9R!T:&4@<')O9W)A;2!I;G1O
M('!R;W!R:65T87)Y('-O9G1W87)E+B`@5&\@<')E=F5N="!T:&ES+`IW92!H
M879E(&UA9&4@:70@8VQE87(@=&AA="!A;GD@<&%T96YT(&UU<W0@8F4@;&EC
M96YS960@9F]R(&5V97)Y;VYE)W,*9G)E92!U<V4@;W(@;F]T(&QI8V5N<V5D
M(&%T(&%L;"X*"B`@36]S="!'3E4@<V]F='=A<F4L(&EN8VQU9&EN9R!S;VUE
M(&QI8G)A<FEE<RP@:7,@8V]V97)E9"!B>2!T:&4@;W)D:6YA<GD*1TY5($=E
M;F5R86P@4'5B;&EC($QI8V5N<V4L('=H:6-H('=A<R!D97-I9VYE9"!F;W(@
M=71I;&ET>2!P<F]G<F%M<RX@(%1H:7,*;&EC96YS92P@=&AE($=.52!,:6)R
M87)Y($=E;F5R86P@4'5B;&EC($QI8V5N<V4L(&%P<&QI97,@=&\@8V5R=&%I
M;@ID97-I9VYA=&5D(&QI8G)A<FEE<RX@(%1H:7,@;&EC96YS92!I<R!Q=6ET
M92!D:69F97)E;G0@9G)O;2!T:&4@;W)D:6YA<GD*;VYE.R!B92!S=7)E('1O
M(')E860@:70@:6X@9G5L;"P@86YD(&1O;B=T(&%S<W5M92!T:&%T(&%N>71H
M:6YG(&EN(&ET(&ES"G1H92!S86UE(&%S(&EN('1H92!O<F1I;F%R>2!L:6-E
M;G-E+@H*("!4:&4@<F5A<V]N('=E(&AA=F4@82!S97!A<F%T92!P=6)L:6,@
M;&EC96YS92!F;W(@<V]M92!L:6)R87)I97,@:7,@=&AA=`IT:&5Y(&)L=7(@
M=&AE(&1I<W1I;F-T:6]N('=E('5S=6%L;'D@;6%K92!B971W965N(&UO9&EF
M>6EN9R!O<B!A9&1I;F<@=&\@80IP<F]G<F%M(&%N9"!S:6UP;'D@=7-I;F<@
M:70N("!,:6YK:6YG(&$@<')O9W)A;2!W:71H(&$@;&EB<F%R>2P@=VET:&]U
M=`IC:&%N9VEN9R!T:&4@;&EB<F%R>2P@:7,@:6X@<V]M92!S96YS92!S:6UP
M;'D@=7-I;F<@=&AE(&QI8G)A<GDL(&%N9"!I<PIA;F%L;V=O=7,@=&\@<G5N
M;FEN9R!A('5T:6QI='D@<')O9W)A;2!O<B!A<'!L:6-A=&EO;B!P<F]G<F%M
M+B`@2&]W979E<BP@:6X*82!T97AT=6%L(&%N9"!L96=A;"!S96YS92P@=&AE
M(&QI;FME9"!E>&5C=71A8FQE(&ES(&$@8V]M8FEN960@=V]R:RP@80ID97)I
M=F%T:79E(&]F('1H92!O<FEG:6YA;"!L:6)R87)Y+"!A;F0@=&AE(&]R9&EN
M87)Y($=E;F5R86P@4'5B;&EC($QI8V5N<V4*=')E871S(&ET(&%S('-U8V@N
M"@H@($)E8V%U<V4@;V8@=&AI<R!B;'5R<F5D(&1I<W1I;F-T:6]N+"!U<VEN
M9R!T:&4@;W)D:6YA<GD@1V5N97)A;`I0=6)L:6,@3&EC96YS92!F;W(@;&EB
M<F%R:65S(&1I9"!N;W0@969F96-T:79E;'D@<')O;6]T92!S;V9T=V%R90IS
M:&%R:6YG+"!B96-A=7-E(&UO<W0@9&5V96QO<&5R<R!D:60@;F]T('5S92!T
M:&4@;&EB<F%R:65S+B`@5V4*8V]N8VQU9&5D('1H870@=V5A:V5R(&-O;F1I
M=&EO;G,@;6EG:'0@<')O;6]T92!S:&%R:6YG(&)E='1E<BX*"B`@2&]W979E
M<BP@=6YR97-T<FEC=&5D(&QI;FMI;F<@;V8@;F]N+69R964@<')O9W)A;7,@
M=V]U;&0@9&5P<FEV92!T:&4*=7-E<G,@;V8@=&AO<V4@<')O9W)A;7,@;V8@
M86QL(&)E;F5F:70@9G)O;2!T:&4@9G)E92!S=&%T=7,@;V8@=&AE"FQI8G)A
M<FEE<R!T:&5M<V5L=F5S+B`@5&AI<R!,:6)R87)Y($=E;F5R86P@4'5B;&EC
M($QI8V5N<V4@:7,@:6YT96YD960@=&\*<&5R;6ET(&1E=F5L;W!E<G,@;V8@
M;F]N+69R964@<')O9W)A;7,@=&\@=7-E(&9R964@;&EB<F%R:65S+"!W:&EL
M90IP<F5S97)V:6YG('EO=7(@9G)E961O;2!A<R!A('5S97(@;V8@<W5C:"!P
M<F]G<F%M<R!T;R!C:&%N9V4@=&AE(&9R964*;&EB<F%R:65S('1H870@87)E
M(&EN8V]R<&]R871E9"!I;B!T:&5M+B`@*%=E(&AA=F4@;F]T('-E96X@:&]W
M('1O(&%C:&EE=F4*=&AI<R!A<R!R96=A<F1S(&-H86YG97,@:6X@:&5A9&5R
M(&9I;&5S+"!B=70@=V4@:&%V92!A8VAI979E9"!I="!A<R!R96=A<F1S"F-H
M86YG97,@:6X@=&AE(&%C='5A;"!F=6YC=&EO;G,@;V8@=&AE($QI8G)A<GDN
M*2`@5&AE(&AO<&4@:7,@=&AA="!T:&ES"G=I;&P@;&5A9"!T;R!F87-T97(@
M9&5V96QO<&UE;G0@;V8@9G)E92!L:6)R87)I97,N"@H@(%1H92!P<F5C:7-E
M('1E<FUS(&%N9"!C;VYD:71I;VYS(&9O<B!C;W!Y:6YG+"!D:7-T<FEB=71I
M;VX@86YD"FUO9&EF:6-A=&EO;B!F;VQL;W<N("!087D@8VQO<V4@871T96YT
M:6]N('1O('1H92!D:69F97)E;F-E(&)E='=E96X@80HB=V]R:R!B87-E9"!O
M;B!T:&4@;&EB<F%R>2(@86YD(&$@(G=O<FL@=&AA="!U<V5S('1H92!L:6)R
M87)Y(BX@(%1H90IF;W)M97(@8V]N=&%I;G,@8V]D92!D97)I=F5D(&9R;VT@
M=&AE(&QI8G)A<GDL('=H:6QE('1H92!L871T97(@;VYL>0IW;W)K<R!T;V=E
M=&AE<B!W:71H('1H92!L:6)R87)Y+@H*("!.;W1E('1H870@:70@:7,@<&]S
M<VEB;&4@9F]R(&$@;&EB<F%R>2!T;R!B92!C;W9E<F5D(&)Y('1H92!O<F1I
M;F%R>0I'96YE<F%L(%!U8FQI8R!,:6-E;G-E(')A=&AE<B!T:&%N(&)Y('1H
M:7,@<W!E8VEA;"!O;F4N"@P*"0D@($=.52!,24)205)9($=%3D5204P@4%5"
M3$E#($Q)0T5.4T4*("`@5$5235,@04Y$($-/3D1)5$E/3E,@1D]2($-/4%E)
M3D<L($1)4U1224)55$E/3B!!3D0@34]$249)0T%424]."@H@(#`N(%1H:7,@
M3&EC96YS92!!9W)E96UE;G0@87!P;&EE<R!T;R!A;GD@<V]F='=A<F4@;&EB
M<F%R>2!W:&EC:`IC;VYT86EN<R!A(&YO=&EC92!P;&%C960@8GD@=&AE(&-O
M<'ER:6=H="!H;VQD97(@;W(@;W1H97(@875T:&]R:7IE9`IP87)T>2!S87EI
M;F<@:70@;6%Y(&)E(&1I<W1R:6)U=&5D('5N9&5R('1H92!T97)M<R!O9B!T
M:&ES($QI8G)A<GD*1V5N97)A;"!0=6)L:6,@3&EC96YS92`H86QS;R!C86QL
M960@(G1H:7,@3&EC96YS92(I+B`@16%C:"!L:6-E;G-E92!I<PIA9&1R97-S
M960@87,@(GEO=2(N"@H@($$@(FQI8G)A<GDB(&UE86YS(&$@8V]L;&5C=&EO
M;B!O9B!S;V9T=V%R92!F=6YC=&EO;G,@86YD+V]R(&1A=&$*<')E<&%R960@
M<V\@87,@=&\@8F4@8V]N=F5N:65N=&QY(&QI;FME9"!W:71H(&%P<&QI8V%T
M:6]N('!R;V=R86US"BAW:&EC:"!U<V4@<V]M92!O9B!T:&]S92!F=6YC=&EO
M;G,@86YD(&1A=&$I('1O(&9O<FT@97AE8W5T86)L97,N"@H@(%1H92`B3&EB
M<F%R>2(L(&)E;&]W+"!R969E<G,@=&\@86YY('-U8V@@<V]F='=A<F4@;&EB
M<F%R>2!O<B!W;W)K"G=H:6-H(&AA<R!B965N(&1I<W1R:6)U=&5D('5N9&5R
M('1H97-E('1E<FUS+B`@02`B=V]R:R!B87-E9"!O;B!T:&4*3&EB<F%R>2(@
M;65A;G,@96ET:&5R('1H92!,:6)R87)Y(&]R(&%N>2!D97)I=F%T:79E('=O
M<FL@=6YD97(*8V]P>7)I9VAT(&QA=SH@=&AA="!I<R!T;R!S87DL(&$@=V]R
M:R!C;VYT86EN:6YG('1H92!,:6)R87)Y(&]R(&$*<&]R=&EO;B!O9B!I="P@
M96ET:&5R('9E<F)A=&EM(&]R('=I=&@@;6]D:69I8V%T:6]N<R!A;F0O;W(@
M=')A;G-L871E9`IS=')A:6=H=&9O<G=A<F1L>2!I;G1O(&%N;W1H97(@;&%N
M9W5A9V4N("`H2&5R96EN869T97(L('1R86YS;&%T:6]N(&ES"FEN8VQU9&5D
M('=I=&AO=70@;&EM:71A=&EO;B!I;B!T:&4@=&5R;2`B;6]D:69I8V%T:6]N
M(BXI"@H@(")3;W5R8V4@8V]D92(@9F]R(&$@=V]R:R!M96%N<R!T:&4@<')E
M9F5R<F5D(&9O<FT@;V8@=&AE('=O<FL@9F]R"FUA:VEN9R!M;V1I9FEC871I
M;VYS('1O(&ET+B`@1F]R(&$@;&EB<F%R>2P@8V]M<&QE=&4@<V]U<F-E(&-O
M9&4@;65A;G,*86QL('1H92!S;W5R8V4@8V]D92!F;W(@86QL(&UO9'5L97,@
M:70@8V]N=&%I;G,L('!L=7,@86YY(&%S<V]C:6%T960*:6YT97)F86-E(&1E
M9FEN:71I;VX@9FEL97,L('!L=7,@=&AE('-C<FEP=',@=7-E9"!T;R!C;VYT
M<F]L(&-O;7!I;&%T:6]N"F%N9"!I;G-T86QL871I;VX@;V8@=&AE(&QI8G)A
M<GDN"@H@($%C=&EV:71I97,@;W1H97(@=&AA;B!C;W!Y:6YG+"!D:7-T<FEB
M=71I;VX@86YD(&UO9&EF:6-A=&EO;B!A<F4@;F]T"F-O=F5R960@8GD@=&AI
M<R!,:6-E;G-E.R!T:&5Y(&%R92!O=71S:61E(&ET<R!S8V]P92X@(%1H92!A
M8W0@;V8*<G5N;FEN9R!A('!R;V=R86T@=7-I;F<@=&AE($QI8G)A<GD@:7,@
M;F]T(')E<W1R:6-T960L(&%N9"!O=71P=70@9G)O;0IS=6-H(&$@<')O9W)A
M;2!I<R!C;W9E<F5D(&]N;'D@:68@:71S(&-O;G1E;G1S(&-O;G-T:71U=&4@
M82!W;W)K(&)A<V5D"F]N('1H92!,:6)R87)Y("AI;F1E<&5N9&5N="!O9B!T
M:&4@=7-E(&]F('1H92!,:6)R87)Y(&EN(&$@=&]O;"!F;W(*=W)I=&EN9R!I
M="DN("!7:&5T:&5R('1H870@:7,@=')U92!D97!E;F1S(&]N('=H870@=&AE
M($QI8G)A<GD@9&]E<PIA;F0@=VAA="!T:&4@<')O9W)A;2!T:&%T('5S97,@
M=&AE($QI8G)A<GD@9&]E<RX*("`*("`Q+B!9;W4@;6%Y(&-O<'D@86YD(&1I
M<W1R:6)U=&4@=F5R8F%T:6T@8V]P:65S(&]F('1H92!,:6)R87)Y)W,*8V]M
M<&QE=&4@<V]U<F-E(&-O9&4@87,@>6]U(')E8V5I=F4@:70L(&EN(&%N>2!M
M961I=6TL('!R;W9I9&5D('1H870*>6]U(&-O;G-P:6-U;W5S;'D@86YD(&%P
M<')O<')I871E;'D@<'5B;&ES:"!O;B!E86-H(&-O<'D@86X*87!P<F]P<FEA
M=&4@8V]P>7)I9VAT(&YO=&EC92!A;F0@9&ES8VQA:6UE<B!O9B!W87)R86YT
M>3L@:V5E<"!I;G1A8W0*86QL('1H92!N;W1I8V5S('1H870@<F5F97(@=&\@
M=&AI<R!,:6-E;G-E(&%N9"!T;R!T:&4@86)S96YC92!O9B!A;GD*=V%R<F%N
M='D[(&%N9"!D:7-T<FEB=71E(&$@8V]P>2!O9B!T:&ES($QI8V5N<V4@86QO
M;F<@=VET:"!T:&4*3&EB<F%R>2X*"B`@66]U(&UA>2!C:&%R9V4@82!F964@
M9F]R('1H92!P:'ES:6-A;"!A8W0@;V8@=')A;G-F97)R:6YG(&$@8V]P>2P*
M86YD('EO=2!M87D@870@>6]U<B!O<'1I;VX@;V9F97(@=V%R<F%N='D@<')O
M=&5C=&EO;B!I;B!E>&-H86YG92!F;W(@80IF964N"@P*("`R+B!9;W4@;6%Y
M(&UO9&EF>2!Y;W5R(&-O<'D@;W(@8V]P:65S(&]F('1H92!,:6)R87)Y(&]R
M(&%N>2!P;W)T:6]N"F]F(&ET+"!T:'5S(&9O<FUI;F<@82!W;W)K(&)A<V5D
M(&]N('1H92!,:6)R87)Y+"!A;F0@8V]P>2!A;F0*9&ES=')I8G5T92!S=6-H
M(&UO9&EF:6-A=&EO;G,@;W(@=V]R:R!U;F1E<B!T:&4@=&5R;7,@;V8@4V5C
M=&EO;B`Q"F%B;W9E+"!P<F]V:61E9"!T:&%T('EO=2!A;'-O(&UE970@86QL
M(&]F('1H97-E(&-O;F1I=&EO;G,Z"@H@("`@82D@5&AE(&UO9&EF:65D('=O
M<FL@;75S="!I='-E;&8@8F4@82!S;V9T=V%R92!L:6)R87)Y+@H*("`@(&(I
M(%EO=2!M=7-T(&-A=7-E('1H92!F:6QE<R!M;V1I9FEE9"!T;R!C87)R>2!P
M<F]M:6YE;G0@;F]T:6-E<PH@("`@<W1A=&EN9R!T:&%T('EO=2!C:&%N9V5D
M('1H92!F:6QE<R!A;F0@=&AE(&1A=&4@;V8@86YY(&-H86YG92X*"B`@("!C
M*2!9;W4@;75S="!C875S92!T:&4@=VAO;&4@;V8@=&AE('=O<FL@=&\@8F4@
M;&EC96YS960@870@;F\*("`@(&-H87)G92!T;R!A;&P@=&AI<F0@<&%R=&EE
M<R!U;F1E<B!T:&4@=&5R;7,@;V8@=&AI<R!,:6-E;G-E+@H*("`@(&0I($EF
M(&$@9F%C:6QI='D@:6X@=&AE(&UO9&EF:65D($QI8G)A<GD@<F5F97)S('1O
M(&$@9G5N8W1I;VX@;W(@80H@("`@=&%B;&4@;V8@9&%T82!T;R!B92!S=7!P
M;&EE9"!B>2!A;B!A<'!L:6-A=&EO;B!P<F]G<F%M('1H870@=7-E<PH@("`@
M=&AE(&9A8VEL:71Y+"!O=&AE<B!T:&%N(&%S(&%N(&%R9W5M96YT('!A<W-E
M9"!W:&5N('1H92!F86-I;&ET>0H@("`@:7,@:6YV;VME9"P@=&AE;B!Y;W4@
M;75S="!M86ME(&$@9V]O9"!F86ET:"!E9F9O<G0@=&\@96YS=7)E('1H870L
M"B`@("!I;B!T:&4@979E;G0@86X@87!P;&EC871I;VX@9&]E<R!N;W0@<W5P
M<&QY('-U8V@@9G5N8W1I;VX@;W(*("`@('1A8FQE+"!T:&4@9F%C:6QI='D@
M<W1I;&P@;W!E<F%T97,L(&%N9"!P97)F;W)M<R!W:&%T979E<B!P87)T(&]F
M"B`@("!I=',@<'5R<&]S92!R96UA:6YS(&UE86YI;F=F=6PN"@H@("`@*$9O
M<B!E>&%M<&QE+"!A(&9U;F-T:6]N(&EN(&$@;&EB<F%R>2!T;R!C;VUP=71E
M('-Q=6%R92!R;V]T<R!H87,*("`@(&$@<'5R<&]S92!T:&%T(&ES(&5N=&ER
M96QY('=E;&PM9&5F:6YE9"!I;F1E<&5N9&5N="!O9B!T:&4*("`@(&%P<&QI
M8V%T:6]N+B`@5&AE<F5F;W)E+"!3=6)S96-T:6]N(#)D(')E<75I<F5S('1H
M870@86YY"B`@("!A<'!L:6-A=&EO;BUS=7!P;&EE9"!F=6YC=&EO;B!O<B!T
M86)L92!U<V5D(&)Y('1H:7,@9G5N8W1I;VX@;75S=`H@("`@8F4@;W!T:6]N
M86PZ(&EF('1H92!A<'!L:6-A=&EO;B!D;V5S(&YO="!S=7!P;'D@:70L('1H
M92!S<75A<F4*("`@(')O;W0@9G5N8W1I;VX@;75S="!S=&EL;"!C;VUP=71E
M('-Q=6%R92!R;V]T<RXI"@I4:&5S92!R97%U:7)E;65N=',@87!P;'D@=&\@
M=&AE(&UO9&EF:65D('=O<FL@87,@82!W:&]L92X@($EF"FED96YT:69I86)L
M92!S96-T:6]N<R!O9B!T:&%T('=O<FL@87)E(&YO="!D97)I=F5D(&9R;VT@
M=&AE($QI8G)A<GDL"F%N9"!C86X@8F4@<F5A<V]N86)L>2!C;VYS:61E<F5D
M(&EN9&5P96YD96YT(&%N9"!S97!A<F%T92!W;W)K<R!I;@IT:&5M<V5L=F5S
M+"!T:&5N('1H:7,@3&EC96YS92P@86YD(&ET<R!T97)M<RP@9&\@;F]T(&%P
M<&QY('1O('1H;W-E"G-E8W1I;VYS('=H96X@>6]U(&1I<W1R:6)U=&4@=&AE
M;2!A<R!S97!A<F%T92!W;W)K<RX@($)U="!W:&5N('EO=0ID:7-T<FEB=71E
M('1H92!S86UE('-E8W1I;VYS(&%S('!A<G0@;V8@82!W:&]L92!W:&EC:"!I
M<R!A('=O<FL@8F%S960*;VX@=&AE($QI8G)A<GDL('1H92!D:7-T<FEB=71I
M;VX@;V8@=&AE('=H;VQE(&UU<W0@8F4@;VX@=&AE('1E<FUS(&]F"G1H:7,@
M3&EC96YS92P@=VAO<V4@<&5R;6ES<VEO;G,@9F]R(&]T:&5R(&QI8V5N<V5E
M<R!E>'1E;F0@=&\@=&AE"F5N=&ER92!W:&]L92P@86YD('1H=7,@=&\@96%C
M:"!A;F0@979E<GD@<&%R="!R96=A<F1L97-S(&]F('=H;R!W<F]T90II="X*
M"E1H=7,L(&ET(&ES(&YO="!T:&4@:6YT96YT(&]F('1H:7,@<V5C=&EO;B!T
M;R!C;&%I;2!R:6=H=',@;W(@8V]N=&5S=`IY;W5R(')I9VAT<R!T;R!W;W)K
M('=R:71T96X@96YT:7)E;'D@8GD@>6]U.R!R871H97(L('1H92!I;G1E;G0@
M:7,@=&\*97AE<F-I<V4@=&AE(')I9VAT('1O(&-O;G1R;VP@=&AE(&1I<W1R
M:6)U=&EO;B!O9B!D97)I=F%T:79E(&]R"F-O;&QE8W1I=F4@=V]R:W,@8F%S
M960@;VX@=&AE($QI8G)A<GDN"@I);B!A9&1I=&EO;BP@;65R92!A9V=R96=A
M=&EO;B!O9B!A;F]T:&5R('=O<FL@;F]T(&)A<V5D(&]N('1H92!,:6)R87)Y
M"G=I=&@@=&AE($QI8G)A<GD@*&]R('=I=&@@82!W;W)K(&)A<V5D(&]N('1H
M92!,:6)R87)Y*2!O;B!A('9O;'5M92!O9@IA('-T;W)A9V4@;W(@9&ES=')I
M8G5T:6]N(&UE9&EU;2!D;V5S(&YO="!B<FEN9R!T:&4@;W1H97(@=V]R:R!U
M;F1E<@IT:&4@<V-O<&4@;V8@=&AI<R!,:6-E;G-E+@H*("`S+B!9;W4@;6%Y
M(&]P="!T;R!A<'!L>2!T:&4@=&5R;7,@;V8@=&AE(&]R9&EN87)Y($=.52!'
M96YE<F%L(%!U8FQI8PI,:6-E;G-E(&EN<W1E860@;V8@=&AI<R!,:6-E;G-E
M('1O(&$@9VEV96X@8V]P>2!O9B!T:&4@3&EB<F%R>2X@(%1O(&1O"G1H:7,L
M('EO=2!M=7-T(&%L=&5R(&%L;"!T:&4@;F]T:6-E<R!T:&%T(')E9F5R('1O
M('1H:7,@3&EC96YS92P@<V\*=&AA="!T:&5Y(')E9F5R('1O('1H92!O<F1I
M;F%R>2!'3E4@1V5N97)A;"!0=6)L:6,@3&EC96YS92P@=F5R<VEO;B`R+`II
M;G-T96%D(&]F('1O('1H:7,@3&EC96YS92X@("A)9B!A(&YE=V5R('9E<G-I
M;VX@=&AA;B!V97)S:6]N(#(@;V8@=&AE"F]R9&EN87)Y($=.52!'96YE<F%L
M(%!U8FQI8R!,:6-E;G-E(&AA<R!A<'!E87)E9"P@=&AE;B!Y;W4@8V%N('-P
M96-I9GD*=&AA="!V97)S:6]N(&EN<W1E860@:68@>6]U('=I<V@N*2`@1&\@
M;F]T(&UA:V4@86YY(&]T:&5R(&-H86YG92!I;@IT:&5S92!N;W1I8V5S+@H,
M"B`@3VYC92!T:&ES(&-H86YG92!I<R!M861E(&EN(&$@9VEV96X@8V]P>2P@
M:70@:7,@:7)R979E<G-I8FQE(&9O<@IT:&%T(&-O<'DL('-O('1H92!O<F1I
M;F%R>2!'3E4@1V5N97)A;"!0=6)L:6,@3&EC96YS92!A<'!L:65S('1O(&%L
M;`IS=6)S97%U96YT(&-O<&EE<R!A;F0@9&5R:79A=&EV92!W;W)K<R!M861E
M(&9R;VT@=&AA="!C;W!Y+@H*("!4:&ES(&]P=&EO;B!I<R!U<V5F=6P@=VAE
M;B!Y;W4@=VES:"!T;R!C;W!Y('!A<G0@;V8@=&AE(&-O9&4@;V8*=&AE($QI
M8G)A<GD@:6YT;R!A('!R;V=R86T@=&AA="!I<R!N;W0@82!L:6)R87)Y+@H*
M("`T+B!9;W4@;6%Y(&-O<'D@86YD(&1I<W1R:6)U=&4@=&AE($QI8G)A<GD@
M*&]R(&$@<&]R=&EO;B!O<@ID97)I=F%T:79E(&]F(&ET+"!U;F1E<B!396-T
M:6]N(#(I(&EN(&]B:F5C="!C;V1E(&]R(&5X96-U=&%B;&4@9F]R;0IU;F1E
M<B!T:&4@=&5R;7,@;V8@4V5C=&EO;G,@,2!A;F0@,B!A8F]V92!P<F]V:61E
M9"!T:&%T('EO=2!A8V-O;7!A;GD*:70@=VET:"!T:&4@8V]M<&QE=&4@8V]R
M<F5S<&]N9&EN9R!M86-H:6YE+7)E861A8FQE('-O=7)C92!C;V1E+"!W:&EC
M:`IM=7-T(&)E(&1I<W1R:6)U=&5D('5N9&5R('1H92!T97)M<R!O9B!396-T
M:6]N<R`Q(&%N9"`R(&%B;W9E(&]N(&$*;65D:75M(&-U<W1O;6%R:6QY('5S
M960@9F]R('-O9G1W87)E(&EN=&5R8VAA;F=E+@H*("!)9B!D:7-T<FEB=71I
M;VX@;V8@;V)J96-T(&-O9&4@:7,@;6%D92!B>2!O9F9E<FEN9R!A8V-E<W,@
M=&\@8V]P>0IF<F]M(&$@9&5S:6=N871E9"!P;&%C92P@=&AE;B!O9F9E<FEN
M9R!E<75I=F%L96YT(&%C8V5S<R!T;R!C;W!Y('1H90IS;W5R8V4@8V]D92!F
M<F]M('1H92!S86UE('!L86-E('-A=&ES9FEE<R!T:&4@<F5Q=6ER96UE;G0@
M=&\*9&ES=')I8G5T92!T:&4@<V]U<F-E(&-O9&4L(&5V96X@=&AO=6=H('1H
M:7)D('!A<G1I97,@87)E(&YO=`IC;VUP96QL960@=&\@8V]P>2!T:&4@<V]U
M<F-E(&%L;VYG('=I=&@@=&AE(&]B:F5C="!C;V1E+@H*("`U+B!!('!R;V=R
M86T@=&AA="!C;VYT86EN<R!N;R!D97)I=F%T:79E(&]F(&%N>2!P;W)T:6]N
M(&]F('1H90I,:6)R87)Y+"!B=70@:7,@9&5S:6=N960@=&\@=V]R:R!W:71H
M('1H92!,:6)R87)Y(&)Y(&)E:6YG(&-O;7!I;&5D(&]R"FQI;FME9"!W:71H
M(&ET+"!I<R!C86QL960@82`B=V]R:R!T:&%T('5S97,@=&AE($QI8G)A<GDB
M+B`@4W5C:"!A"G=O<FLL(&EN(&ES;VQA=&EO;BP@:7,@;F]T(&$@9&5R:79A
M=&EV92!W;W)K(&]F('1H92!,:6)R87)Y+"!A;F0*=&AE<F5F;W)E(&9A;&QS
M(&]U='-I9&4@=&AE('-C;W!E(&]F('1H:7,@3&EC96YS92X*"B`@2&]W979E
M<BP@;&EN:VEN9R!A(")W;W)K('1H870@=7-E<R!T:&4@3&EB<F%R>2(@=VET
M:"!T:&4@3&EB<F%R>0IC<F5A=&5S(&%N(&5X96-U=&%B;&4@=&AA="!I<R!A
M(&1E<FEV871I=F4@;V8@=&AE($QI8G)A<GD@*&)E8V%U<V4@:70*8V]N=&%I
M;G,@<&]R=&EO;G,@;V8@=&AE($QI8G)A<GDI+"!R871H97(@=&AA;B!A(")W
M;W)K('1H870@=7-E<R!T:&4*;&EB<F%R>2(N("!4:&4@97AE8W5T86)L92!I
M<R!T:&5R969O<F4@8V]V97)E9"!B>2!T:&ES($QI8V5N<V4N"E-E8W1I;VX@
M-B!S=&%T97,@=&5R;7,@9F]R(&1I<W1R:6)U=&EO;B!O9B!S=6-H(&5X96-U
M=&%B;&5S+@H*("!7:&5N(&$@(G=O<FL@=&AA="!U<V5S('1H92!,:6)R87)Y
M(B!U<V5S(&UA=&5R:6%L(&9R;VT@82!H96%D97(@9FEL90IT:&%T(&ES('!A
M<G0@;V8@=&AE($QI8G)A<GDL('1H92!O8FIE8W0@8V]D92!F;W(@=&AE('=O
M<FL@;6%Y(&)E(&$*9&5R:79A=&EV92!W;W)K(&]F('1H92!,:6)R87)Y(&5V
M96X@=&AO=6=H('1H92!S;W5R8V4@8V]D92!I<R!N;W0N"E=H971H97(@=&AI
M<R!I<R!T<G5E(&ES(&5S<&5C:6%L;'D@<VEG;FEF:6-A;G0@:68@=&AE('=O
M<FL@8V%N(&)E"FQI;FME9"!W:71H;W5T('1H92!,:6)R87)Y+"!O<B!I9B!T
M:&4@=V]R:R!I<R!I='-E;&8@82!L:6)R87)Y+B`@5&AE"G1H<F5S:&]L9"!F
M;W(@=&AI<R!T;R!B92!T<G5E(&ES(&YO="!P<F5C:7-E;'D@9&5F:6YE9"!B
M>2!L87<N"@H@($EF('-U8V@@86X@;V)J96-T(&9I;&4@=7-E<R!O;FQY(&YU
M;65R:6-A;"!P87)A;65T97)S+"!D871A"G-T<G5C='5R92!L87EO=71S(&%N
M9"!A8V-E<W-O<G,L(&%N9"!S;6%L;"!M86-R;W,@86YD('-M86QL(&EN;&EN
M90IF=6YC=&EO;G,@*'1E;B!L:6YE<R!O<B!L97-S(&EN(&QE;F=T:"DL('1H
M96X@=&AE('5S92!O9B!T:&4@;V)J96-T"F9I;&4@:7,@=6YR97-T<FEC=&5D
M+"!R96=A<F1L97-S(&]F('=H971H97(@:70@:7,@;&5G86QL>2!A(&1E<FEV
M871I=F4*=V]R:RX@("A%>&5C=71A8FQE<R!C;VYT86EN:6YG('1H:7,@;V)J
M96-T(&-O9&4@<&QU<R!P;W)T:6]N<R!O9B!T:&4*3&EB<F%R>2!W:6QL('-T
M:6QL(&9A;&P@=6YD97(@4V5C=&EO;B`V+BD*"B`@3W1H97)W:7-E+"!I9B!T
M:&4@=V]R:R!I<R!A(&1E<FEV871I=F4@;V8@=&AE($QI8G)A<GDL('EO=2!M
M87D*9&ES=')I8G5T92!T:&4@;V)J96-T(&-O9&4@9F]R('1H92!W;W)K('5N
M9&5R('1H92!T97)M<R!O9B!396-T:6]N(#8N"D%N>2!E>&5C=71A8FQE<R!C
M;VYT86EN:6YG('1H870@=V]R:R!A;'-O(&9A;&P@=6YD97(@4V5C=&EO;B`V
M+`IW:&5T:&5R(&]R(&YO="!T:&5Y(&%R92!L:6YK960@9&ER96-T;'D@=VET
M:"!T:&4@3&EB<F%R>2!I='-E;&8N"@P*("`V+B!!<R!A;B!E>&-E<'1I;VX@
M=&\@=&AE(%-E8W1I;VYS(&%B;W9E+"!Y;W4@;6%Y(&%L<V\@8V]M<&EL92!O
M<@IL:6YK(&$@(G=O<FL@=&AA="!U<V5S('1H92!,:6)R87)Y(B!W:71H('1H
M92!,:6)R87)Y('1O('!R;V1U8V4@80IW;W)K(&-O;G1A:6YI;F<@<&]R=&EO
M;G,@;V8@=&AE($QI8G)A<GDL(&%N9"!D:7-T<FEB=71E('1H870@=V]R:PIU
M;F1E<B!T97)M<R!O9B!Y;W5R(&-H;VEC92P@<')O=FED960@=&AA="!T:&4@
M=&5R;7,@<&5R;6ET"FUO9&EF:6-A=&EO;B!O9B!T:&4@=V]R:R!F;W(@=&AE
M(&-U<W1O;65R)W,@;W=N('5S92!A;F0@<F5V97)S90IE;F=I;F5E<FEN9R!F
M;W(@9&5B=6=G:6YG('-U8V@@;6]D:69I8V%T:6]N<RX*"B`@66]U(&UU<W0@
M9VEV92!P<F]M:6YE;G0@;F]T:6-E('=I=&@@96%C:"!C;W!Y(&]F('1H92!W
M;W)K('1H870@=&AE"DQI8G)A<GD@:7,@=7-E9"!I;B!I="!A;F0@=&AA="!T
M:&4@3&EB<F%R>2!A;F0@:71S('5S92!A<F4@8V]V97)E9"!B>0IT:&ES($QI
M8V5N<V4N("!9;W4@;75S="!S=7!P;'D@82!C;W!Y(&]F('1H:7,@3&EC96YS
M92X@($EF('1H92!W;W)K"F1U<FEN9R!E>&5C=71I;VX@9&ES<&QA>7,@8V]P
M>7)I9VAT(&YO=&EC97,L('EO=2!M=7-T(&EN8VQU9&4@=&AE"F-O<'ER:6=H
M="!N;W1I8V4@9F]R('1H92!,:6)R87)Y(&%M;VYG('1H96TL(&%S('=E;&P@
M87,@82!R969E<F5N8V4*9&ER96-T:6YG('1H92!U<V5R('1O('1H92!C;W!Y
M(&]F('1H:7,@3&EC96YS92X@($%L<V\L('EO=2!M=7-T(&1O(&]N90IO9B!T
M:&5S92!T:&EN9W,Z"@H@("`@82D@06-C;VUP86YY('1H92!W;W)K('=I=&@@
M=&AE(&-O;7!L971E(&-O<G)E<W!O;F1I;F<*("`@(&UA8VAI;F4M<F5A9&%B
M;&4@<V]U<F-E(&-O9&4@9F]R('1H92!,:6)R87)Y(&EN8VQU9&EN9R!W:&%T
M979E<@H@("`@8VAA;F=E<R!W97)E('5S960@:6X@=&AE('=O<FL@*'=H:6-H
M(&UU<W0@8F4@9&ES=')I8G5T960@=6YD97(*("`@(%-E8W1I;VYS(#$@86YD
M(#(@86)O=F4I.R!A;F0L(&EF('1H92!W;W)K(&ES(&%N(&5X96-U=&%B;&4@
M;&EN:V5D"B`@("!W:71H('1H92!,:6)R87)Y+"!W:71H('1H92!C;VUP;&5T
M92!M86-H:6YE+7)E861A8FQE(")W;W)K('1H870*("`@('5S97,@=&AE($QI
M8G)A<GDB+"!A<R!O8FIE8W0@8V]D92!A;F0O;W(@<V]U<F-E(&-O9&4L('-O
M('1H870@=&AE"B`@("!U<V5R(&-A;B!M;V1I9GD@=&AE($QI8G)A<GD@86YD
M('1H96X@<F5L:6YK('1O('!R;V1U8V4@82!M;V1I9FEE9`H@("`@97AE8W5T
M86)L92!C;VYT86EN:6YG('1H92!M;V1I9FEE9"!,:6)R87)Y+B`@*$ET(&ES
M('5N9&5R<W1O;V0*("`@('1H870@=&AE('5S97(@=VAO(&-H86YG97,@=&AE
M(&-O;G1E;G1S(&]F(&1E9FEN:71I;VYS(&9I;&5S(&EN('1H90H@("`@3&EB
M<F%R>2!W:6QL(&YO="!N96-E<W-A<FEL>2!B92!A8FQE('1O(')E8V]M<&EL
M92!T:&4@87!P;&EC871I;VX*("`@('1O('5S92!T:&4@;6]D:69I960@9&5F
M:6YI=&EO;G,N*0H*("`@(&(I($%C8V]M<&%N>2!T:&4@=V]R:R!W:71H(&$@
M=W)I='1E;B!O9F9E<BP@=F%L:60@9F]R(&%T"B`@("!L96%S="!T:')E92!Y
M96%R<RP@=&\@9VEV92!T:&4@<V%M92!U<V5R('1H92!M871E<FEA;',*("`@
M('-P96-I9FEE9"!I;B!3=6)S96-T:6]N(#9A+"!A8F]V92P@9F]R(&$@8VAA
M<F=E(&YO(&UO<F4*("`@('1H86X@=&AE(&-O<W0@;V8@<&5R9F]R;6EN9R!T
M:&ES(&1I<W1R:6)U=&EO;BX*"B`@("!C*2!)9B!D:7-T<FEB=71I;VX@;V8@
M=&AE('=O<FL@:7,@;6%D92!B>2!O9F9E<FEN9R!A8V-E<W,@=&\@8V]P>0H@
M("`@9G)O;2!A(&1E<VEG;F%T960@<&QA8V4L(&]F9F5R(&5Q=6EV86QE;G0@
M86-C97-S('1O(&-O<'D@=&AE(&%B;W9E"B`@("!S<&5C:69I960@;6%T97)I
M86QS(&9R;VT@=&AE('-A;64@<&QA8V4N"@H@("`@9"D@5F5R:69Y('1H870@
M=&AE('5S97(@:&%S(&%L<F5A9'D@<F5C96EV960@82!C;W!Y(&]F('1H97-E
M"B`@("!M871E<FEA;',@;W(@=&AA="!Y;W4@:&%V92!A;')E861Y('-E;G0@
M=&AI<R!U<V5R(&$@8V]P>2X*"B`@1F]R(&%N(&5X96-U=&%B;&4L('1H92!R
M97%U:7)E9"!F;W)M(&]F('1H92`B=V]R:R!T:&%T('5S97,@=&AE"DQI8G)A
M<GDB(&UU<W0@:6YC;'5D92!A;GD@9&%T82!A;F0@=71I;&ET>2!P<F]G<F%M
M<R!N965D960@9F]R"G)E<')O9'5C:6YG('1H92!E>&5C=71A8FQE(&9R;VT@
M:70N("!(;W=E=F5R+"!A<R!A('-P96-I86P@97AC97!T:6]N+`IT:&4@<V]U
M<F-E(&-O9&4@9&ES=')I8G5T960@;F5E9"!N;W0@:6YC;'5D92!A;GET:&EN
M9R!T:&%T(&ES(&YO<FUA;&QY"F1I<W1R:6)U=&5D("AI;B!E:71H97(@<V]U
M<F-E(&]R(&)I;F%R>2!F;W)M*2!W:71H('1H92!M86IO<@IC;VUP;VYE;G1S
M("AC;VUP:6QE<BP@:V5R;F5L+"!A;F0@<V\@;VXI(&]F('1H92!O<&5R871I
M;F<@<WES=&5M(&]N"G=H:6-H('1H92!E>&5C=71A8FQE(')U;G,L('5N;&5S
M<R!T:&%T(&-O;7!O;F5N="!I='-E;&8@86-C;VUP86YI97,*=&AE(&5X96-U
M=&%B;&4N"@H@($ET(&UA>2!H87!P96X@=&AA="!T:&ES(')E<75I<F5M96YT
M(&-O;G1R861I8W1S('1H92!L:6-E;G-E"G)E<W1R:6-T:6]N<R!O9B!O=&AE
M<B!P<F]P<FEE=&%R>2!L:6)R87)I97,@=&AA="!D;R!N;W0@;F]R;6%L;'D*
M86-C;VUP86YY('1H92!O<&5R871I;F<@<WES=&5M+B`@4W5C:"!A(&-O;G1R
M861I8W1I;VX@;65A;G,@>6]U(&-A;FYO=`IU<V4@8F]T:"!T:&5M(&%N9"!T
M:&4@3&EB<F%R>2!T;V=E=&AE<B!I;B!A;B!E>&5C=71A8FQE('1H870@>6]U
M"F1I<W1R:6)U=&4N"@P*("`W+B!9;W4@;6%Y('!L86-E(&QI8G)A<GD@9F%C
M:6QI=&EE<R!T:&%T(&%R92!A('=O<FL@8F%S960@;VX@=&AE"DQI8G)A<GD@
M<VED92UB>2US:61E(&EN(&$@<VEN9VQE(&QI8G)A<GD@=&]G971H97(@=VET
M:"!O=&AE<B!L:6)R87)Y"F9A8VEL:71I97,@;F]T(&-O=F5R960@8GD@=&AI
M<R!,:6-E;G-E+"!A;F0@9&ES=')I8G5T92!S=6-H(&$@8V]M8FEN960*;&EB
M<F%R>2P@<')O=FED960@=&AA="!T:&4@<V5P87)A=&4@9&ES=')I8G5T:6]N
M(&]F('1H92!W;W)K(&)A<V5D(&]N"G1H92!,:6)R87)Y(&%N9"!O9B!T:&4@
M;W1H97(@;&EB<F%R>2!F86-I;&ET:65S(&ES(&]T:&5R=VES90IP97)M:71T
M960L(&%N9"!P<F]V:61E9"!T:&%T('EO=2!D;R!T:&5S92!T=V\@=&AI;F=S
M.@H*("`@(&$I($%C8V]M<&%N>2!T:&4@8V]M8FEN960@;&EB<F%R>2!W:71H
M(&$@8V]P>2!O9B!T:&4@<V%M92!W;W)K"B`@("!B87-E9"!O;B!T:&4@3&EB
M<F%R>2P@=6YC;VUB:6YE9"!W:71H(&%N>2!O=&AE<B!L:6)R87)Y"B`@("!F
M86-I;&ET:65S+B`@5&AI<R!M=7-T(&)E(&1I<W1R:6)U=&5D('5N9&5R('1H
M92!T97)M<R!O9B!T:&4*("`@(%-E8W1I;VYS(&%B;W9E+@H*("`@(&(I($=I
M=F4@<')O;6EN96YT(&YO=&EC92!W:71H('1H92!C;VUB:6YE9"!L:6)R87)Y
M(&]F('1H92!F86-T"B`@("!T:&%T('!A<G0@;V8@:70@:7,@82!W;W)K(&)A
M<V5D(&]N('1H92!,:6)R87)Y+"!A;F0@97AP;&%I;FEN9PH@("`@=VAE<F4@
M=&\@9FEN9"!T:&4@86-C;VUP86YY:6YG('5N8V]M8FEN960@9F]R;2!O9B!T
M:&4@<V%M92!W;W)K+@H*("`X+B!9;W4@;6%Y(&YO="!C;W!Y+"!M;V1I9GDL
M('-U8FQI8V5N<V4L(&QI;FL@=VET:"P@;W(@9&ES=')I8G5T90IT:&4@3&EB
M<F%R>2!E>&-E<'0@87,@97AP<F5S<VQY('!R;W9I9&5D('5N9&5R('1H:7,@
M3&EC96YS92X@($%N>0IA='1E;7!T(&]T:&5R=VES92!T;R!C;W!Y+"!M;V1I
M9GDL('-U8FQI8V5N<V4L(&QI;FL@=VET:"P@;W(*9&ES=')I8G5T92!T:&4@
M3&EB<F%R>2!I<R!V;VED+"!A;F0@=VEL;"!A=71O;6%T:6-A;&QY('1E<FUI
M;F%T92!Y;W5R"G)I9VAT<R!U;F1E<B!T:&ES($QI8V5N<V4N("!(;W=E=F5R
M+"!P87)T:65S('=H;R!H879E(')E8V5I=F5D(&-O<&EE<RP*;W(@<FEG:'1S
M+"!F<F]M('EO=2!U;F1E<B!T:&ES($QI8V5N<V4@=VEL;"!N;W0@:&%V92!T
M:&5I<B!L:6-E;G-E<PIT97)M:6YA=&5D('-O(&QO;F<@87,@<W5C:"!P87)T
M:65S(')E;6%I;B!I;B!F=6QL(&-O;7!L:6%N8V4N"@H@(#DN(%EO=2!A<F4@
M;F]T(')E<75I<F5D('1O(&%C8V5P="!T:&ES($QI8V5N<V4L('-I;F-E('EO
M=2!H879E(&YO=`IS:6=N960@:70N("!(;W=E=F5R+"!N;W1H:6YG(&5L<V4@
M9W)A;G1S('EO=2!P97)M:7-S:6]N('1O(&UO9&EF>2!O<@ID:7-T<FEB=71E
M('1H92!,:6)R87)Y(&]R(&ET<R!D97)I=F%T:79E('=O<FMS+B`@5&AE<V4@
M86-T:6]N<R!A<F4*<')O:&EB:71E9"!B>2!L87<@:68@>6]U(&1O(&YO="!A
M8V-E<'0@=&AI<R!,:6-E;G-E+B`@5&AE<F5F;W)E+"!B>0IM;V1I9GEI;F<@
M;W(@9&ES=')I8G5T:6YG('1H92!,:6)R87)Y("AO<B!A;GD@=V]R:R!B87-E
M9"!O;B!T:&4*3&EB<F%R>2DL('EO=2!I;F1I8V%T92!Y;W5R(&%C8V5P=&%N
M8V4@;V8@=&AI<R!,:6-E;G-E('1O(&1O('-O+"!A;F0*86QL(&ET<R!T97)M
M<R!A;F0@8V]N9&ET:6]N<R!F;W(@8V]P>6EN9RP@9&ES=')I8G5T:6YG(&]R
M(&UO9&EF>6EN9PIT:&4@3&EB<F%R>2!O<B!W;W)K<R!B87-E9"!O;B!I="X*
M"B`@,3`N($5A8V@@=&EM92!Y;W4@<F5D:7-T<FEB=71E('1H92!,:6)R87)Y
M("AO<B!A;GD@=V]R:R!B87-E9"!O;B!T:&4*3&EB<F%R>2DL('1H92!R96-I
M<&EE;G0@875T;VUA=&EC86QL>2!R96-E:79E<R!A(&QI8V5N<V4@9G)O;2!T
M:&4*;W)I9VEN86P@;&EC96YS;W(@=&\@8V]P>2P@9&ES=')I8G5T92P@;&EN
M:R!W:71H(&]R(&UO9&EF>2!T:&4@3&EB<F%R>0IS=6)J96-T('1O('1H97-E
M('1E<FUS(&%N9"!C;VYD:71I;VYS+B`@66]U(&UA>2!N;W0@:6UP;W-E(&%N
M>2!F=7)T:&5R"G)E<W1R:6-T:6]N<R!O;B!T:&4@<F5C:7!I96YT<R<@97AE
M<F-I<V4@;V8@=&AE(')I9VAT<R!G<F%N=&5D(&AE<F5I;BX*66]U(&%R92!N
M;W0@<F5S<&]N<VEB;&4@9F]R(&5N9F]R8VEN9R!C;VUP;&EA;F-E(&)Y('1H
M:7)D('!A<G1I97,@=&\*=&AI<R!,:6-E;G-E+@H,"B`@,3$N($EF+"!A<R!A
M(&-O;G-E<75E;F-E(&]F(&$@8V]U<G0@:G5D9VUE;G0@;W(@86QL96=A=&EO
M;B!O9B!P871E;G0*:6YF<FEN9V5M96YT(&]R(&9O<B!A;GD@;W1H97(@<F5A
M<V]N("AN;W0@;&EM:71E9"!T;R!P871E;G0@:7-S=65S*2P*8V]N9&ET:6]N
M<R!A<F4@:6UP;W-E9"!O;B!Y;W4@*'=H971H97(@8GD@8V]U<G0@;W)D97(L
M(&%G<F5E;65N="!O<@IO=&AE<G=I<V4I('1H870@8V]N=')A9&EC="!T:&4@
M8V]N9&ET:6]N<R!O9B!T:&ES($QI8V5N<V4L('1H97D@9&\@;F]T"F5X8W5S
M92!Y;W4@9G)O;2!T:&4@8V]N9&ET:6]N<R!O9B!T:&ES($QI8V5N<V4N("!)
M9B!Y;W4@8V%N;F]T"F1I<W1R:6)U=&4@<V\@87,@=&\@<V%T:7-F>2!S:6UU
M;'1A;F5O=7-L>2!Y;W5R(&]B;&EG871I;VYS('5N9&5R('1H:7,*3&EC96YS
M92!A;F0@86YY(&]T:&5R('!E<G1I;F5N="!O8FQI9V%T:6]N<RP@=&AE;B!A
M<R!A(&-O;G-E<75E;F-E('EO=0IM87D@;F]T(&1I<W1R:6)U=&4@=&AE($QI
M8G)A<GD@870@86QL+B`@1F]R(&5X86UP;&4L(&EF(&$@<&%T96YT"FQI8V5N
M<V4@=V]U;&0@;F]T('!E<FUI="!R;WEA;'1Y+69R964@<F5D:7-T<FEB=71I
M;VX@;V8@=&AE($QI8G)A<GD@8GD*86QL('1H;W-E('=H;R!R96-E:79E(&-O
M<&EE<R!D:7)E8W1L>2!O<B!I;F1I<F5C=&QY('1H<F]U9V@@>6]U+"!T:&5N
M"G1H92!O;FQY('=A>2!Y;W4@8V]U;&0@<V%T:7-F>2!B;W1H(&ET(&%N9"!T
M:&ES($QI8V5N<V4@=V]U;&0@8F4@=&\*<F5F<F%I;B!E;G1I<F5L>2!F<F]M
M(&1I<W1R:6)U=&EO;B!O9B!T:&4@3&EB<F%R>2X*"DEF(&%N>2!P;W)T:6]N
M(&]F('1H:7,@<V5C=&EO;B!I<R!H96QD(&EN=F%L:60@;W(@=6YE;F9O<F-E
M86)L92!U;F1E<B!A;GD*<&%R=&EC=6QA<B!C:7)C=6US=&%N8V4L('1H92!B
M86QA;F-E(&]F('1H92!S96-T:6]N(&ES(&EN=&5N9&5D('1O(&%P<&QY+`IA
M;F0@=&AE('-E8W1I;VX@87,@82!W:&]L92!I<R!I;G1E;F1E9"!T;R!A<'!L
M>2!I;B!O=&AE<B!C:7)C=6US=&%N8V5S+@H*270@:7,@;F]T('1H92!P=7)P
M;W-E(&]F('1H:7,@<V5C=&EO;B!T;R!I;F1U8V4@>6]U('1O(&EN9G)I;F=E
M(&%N>0IP871E;G1S(&]R(&]T:&5R('!R;W!E<G1Y(')I9VAT(&-L86EM<R!O
M<B!T;R!C;VYT97-T('9A;&ED:71Y(&]F(&%N>0IS=6-H(&-L86EM<SL@=&AI
M<R!S96-T:6]N(&AA<R!T:&4@<V]L92!P=7)P;W-E(&]F('!R;W1E8W1I;F<@
M=&AE"FEN=&5G<FET>2!O9B!T:&4@9G)E92!S;V9T=V%R92!D:7-T<FEB=71I
M;VX@<WES=&5M('=H:6-H(&ES"FEM<&QE;65N=&5D(&)Y('!U8FQI8R!L:6-E
M;G-E('!R86-T:6-E<RX@($UA;GD@<&5O<&QE(&AA=F4@;6%D90IG96YE<F]U
M<R!C;VYT<FEB=71I;VYS('1O('1H92!W:61E(')A;F=E(&]F('-O9G1W87)E
M(&1I<W1R:6)U=&5D"G1H<F]U9V@@=&AA="!S>7-T96T@:6X@<F5L:6%N8V4@
M;VX@8V]N<VES=&5N="!A<'!L:6-A=&EO;B!O9B!T:&%T"G-Y<W1E;3L@:70@
M:7,@=7`@=&\@=&AE(&%U=&AO<B]D;VYO<B!T;R!D96-I9&4@:68@:&4@;W(@
M<VAE(&ES('=I;&QI;F<*=&\@9&ES=')I8G5T92!S;V9T=V%R92!T:')O=6=H
M(&%N>2!O=&AE<B!S>7-T96T@86YD(&$@;&EC96YS964@8V%N;F]T"FEM<&]S
M92!T:&%T(&-H;VEC92X*"E1H:7,@<V5C=&EO;B!I<R!I;G1E;F1E9"!T;R!M
M86ME('1H;W)O=6=H;'D@8VQE87(@=VAA="!I<R!B96QI979E9"!T;PIB92!A
M(&-O;G-E<75E;F-E(&]F('1H92!R97-T(&]F('1H:7,@3&EC96YS92X*"B`@
M,3(N($EF('1H92!D:7-T<FEB=71I;VX@86YD+V]R('5S92!O9B!T:&4@3&EB
M<F%R>2!I<R!R97-T<FEC=&5D(&EN"F-E<G1A:6X@8V]U;G1R:65S(&5I=&AE
M<B!B>2!P871E;G1S(&]R(&)Y(&-O<'ER:6=H=&5D(&EN=&5R9F%C97,L('1H
M90IO<FEG:6YA;"!C;W!Y<FEG:'0@:&]L9&5R('=H;R!P;&%C97,@=&AE($QI
M8G)A<GD@=6YD97(@=&AI<R!,:6-E;G-E(&UA>2!A9&0*86X@97AP;&EC:70@
M9V5O9W)A<&AI8V%L(&1I<W1R:6)U=&EO;B!L:6UI=&%T:6]N(&5X8VQU9&EN
M9R!T:&]S92!C;W5N=')I97,L"G-O('1H870@9&ES=')I8G5T:6]N(&ES('!E
M<FUI='1E9"!O;FQY(&EN(&]R(&%M;VYG(&-O=6YT<FEE<R!N;W0@=&AU<PIE
M>&-L=61E9"X@($EN('-U8V@@8V%S92P@=&AI<R!,:6-E;G-E(&EN8V]R<&]R
M871E<R!T:&4@;&EM:71A=&EO;B!A<R!I9@IW<FET=&5N(&EN('1H92!B;V1Y
M(&]F('1H:7,@3&EC96YS92X*"B`@,3,N(%1H92!&<F5E(%-O9G1W87)E($9O
M=6YD871I;VX@;6%Y('!U8FQI<V@@<F5V:7-E9"!A;F0O;W(@;F5W"G9E<G-I
M;VYS(&]F('1H92!,:6)R87)Y($=E;F5R86P@4'5B;&EC($QI8V5N<V4@9G)O
M;2!T:6UE('1O('1I;64N"E-U8V@@;F5W('9E<G-I;VYS('=I;&P@8F4@<VEM
M:6QA<B!I;B!S<&ER:70@=&\@=&AE('!R97-E;G0@=F5R<VEO;BP*8G5T(&UA
M>2!D:69F97(@:6X@9&5T86EL('1O(&%D9')E<W,@;F5W('!R;V)L96US(&]R
M(&-O;F-E<FYS+@H*16%C:"!V97)S:6]N(&ES(&=I=F5N(&$@9&ES=&EN9W5I
M<VAI;F<@=F5R<VEO;B!N=6UB97(N("!)9B!T:&4@3&EB<F%R>0IS<&5C:69I
M97,@82!V97)S:6]N(&YU;6)E<B!O9B!T:&ES($QI8V5N<V4@=VAI8V@@87!P
M;&EE<R!T;R!I="!A;F0*(F%N>2!L871E<B!V97)S:6]N(BP@>6]U(&AA=F4@
M=&AE(&]P=&EO;B!O9B!F;VQL;W=I;F<@=&AE('1E<FUS(&%N9`IC;VYD:71I
M;VYS(&5I=&AE<B!O9B!T:&%T('9E<G-I;VX@;W(@;V8@86YY(&QA=&5R('9E
M<G-I;VX@<'5B;&ES:&5D(&)Y"G1H92!&<F5E(%-O9G1W87)E($9O=6YD871I
M;VXN("!)9B!T:&4@3&EB<F%R>2!D;V5S(&YO="!S<&5C:69Y(&$*;&EC96YS
M92!V97)S:6]N(&YU;6)E<BP@>6]U(&UA>2!C:&]O<V4@86YY('9E<G-I;VX@
M979E<B!P=6)L:7-H960@8GD*=&AE($9R964@4V]F='=A<F4@1F]U;F1A=&EO
M;BX*#`H@(#$T+B!)9B!Y;W4@=VES:"!T;R!I;F-O<G!O<F%T92!P87)T<R!O
M9B!T:&4@3&EB<F%R>2!I;G1O(&]T:&5R(&9R964*<')O9W)A;7,@=VAO<V4@
M9&ES=')I8G5T:6]N(&-O;F1I=&EO;G,@87)E(&EN8V]M<&%T:6)L92!W:71H
M('1H97-E+`IW<FET92!T;R!T:&4@875T:&]R('1O(&%S:R!F;W(@<&5R;6ES
M<VEO;BX@($9O<B!S;V9T=V%R92!W:&EC:"!I<PIC;W!Y<FEG:'1E9"!B>2!T
M:&4@1G)E92!3;V9T=V%R92!&;W5N9&%T:6]N+"!W<FET92!T;R!T:&4@1G)E
M90I3;V9T=V%R92!&;W5N9&%T:6]N.R!W92!S;VUE=&EM97,@;6%K92!E>&-E
M<'1I;VYS(&9O<B!T:&ES+B`@3W5R"F1E8VES:6]N('=I;&P@8F4@9W5I9&5D
M(&)Y('1H92!T=V\@9V]A;',@;V8@<')E<V5R=FEN9R!T:&4@9G)E92!S=&%T
M=7,*;V8@86QL(&1E<FEV871I=F5S(&]F(&]U<B!F<F5E('-O9G1W87)E(&%N
M9"!O9B!P<F]M;W1I;F<@=&AE('-H87)I;F<*86YD(')E=7-E(&]F('-O9G1W
M87)E(&=E;F5R86QL>2X*"@D)"2`@("!.3R!705)204Y460H*("`Q-2X@0D5#
M055312!42$4@3$E"4D%262!)4R!,24-%3E-%1"!&4D5%($]&($-(05)'12P@
M5$A%4D4@25,@3D\*5T%24D%.5%D@1D]2(%1(12!,24)205)9+"!43R!42$4@
M15A414Y4(%!%4DU)5%1%1"!"62!!4%!,24-!0DQ%($Q!5RX*15A#15!4(%=(
M14X@3U1(15)725-%(%-4051%1"!)3B!74DE424Y'(%1(12!#3U!94DE'2%0@
M2$],1$524R!!3D0O3U(*3U1(15(@4$%25$E%4R!04D]6241%(%1(12!,24)2
M05)9(")!4R!)4R(@5TE42$]55"!705)204Y462!/1B!!3ED*2TE.1"P@14E4
M2$52($584%)%4U-%1"!/4B!)35!,245$+"!)3D-,541)3D<L($)55"!.3U0@
M3$E-251%1"!43RP@5$A%"DE-4$Q)140@5T%24D%.5$E%4R!/1B!-15)#2$%.
M5$%"24Q)5%D@04Y$($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!4@I055)03U-%
M+B`@5$A%($5.5$E212!225-+($%3(%1/(%1(12!154%,2519($%.1"!015)&
M3U)-04Y#12!/1B!42$4*3$E"4D%262!)4R!7251((%E/52X@(%-(3U5,1"!4
M2$4@3$E"4D%262!04D]612!$149%0U1)5D4L(%E/52!!4U-5344*5$A%($-/
M4U0@3T8@04Q,($Y%0T534T%262!315)624-)3D<L(%)%4$%)4B!/4B!#3U)2
M14-424].+@H*("`Q-BX@24X@3D\@159%3E0@54Y,15-3(%)%455)4D5$($)9
M($%04$Q)0T%"3$4@3$%7($]2($%'4D5%1"!43R!)3@I74DE424Y'(%=)3$P@
M04Y9($-/4%E224=(5"!(3TQ$15(L($]2($%.62!/5$A%4B!005)462!72$\@
M34%9($U/1$E&60I!3D0O3U(@4D5$25-44DE"551%(%1(12!,24)205)9($%3
M(%!%4DU)5%1%1"!!0D]612P@0D4@3$E!0DQ%(%1/(%E/50I&3U(@1$%-04=%
M4RP@24Y#3%5$24Y'($%.62!'14Y%4D%,+"!34$5#24%,+"!)3D-)1$5.5$%,
M($]2"D-/3E-%455%3E1)04P@1$%-04=%4R!!4DE324Y'($]55"!/1B!42$4@
M55-%($]2($E.04))3$E462!43R!54T4@5$A%"DQ)0E)!4ED@*$E.0TQ51$E.
M1R!"550@3D]4($Q)34E4140@5$\@3$]34R!/1B!$051!($]2($1!5$$@0D5)
M3D<*4D5.1$52140@24Y!0T-54D%412!/4B!,3U-315,@4U535$%)3D5$($)9
M(%E/52!/4B!42$E21"!005)42453($]2($$*1D%)3%5212!/1B!42$4@3$E"
M4D%262!43R!/4$52051%(%=)5$@@04Y9($]42$52(%-/1E1705)%*2P@159%
M3B!)1@I354-(($A/3$1%4B!/4B!/5$A%4B!005)462!(05,@0D5%3B!!1%9)
M4T5$($]&(%1(12!03U-324))3$E462!/1B!354-("D1!34%'15,N"@H)"2`@
M("`@14Y$($]&(%1%4DU3($%.1"!#3TY$251)3TY3"@P*("`@("`@("`@("!(
M;W<@=&\@07!P;'D@5&AE<V4@5&5R;7,@=&\@66]U<B!.97<@3&EB<F%R:65S
M"@H@($EF('EO=2!D979E;&]P(&$@;F5W(&QI8G)A<GDL(&%N9"!Y;W4@=V%N
M="!I="!T;R!B92!O9B!T:&4@9W)E871E<W0*<&]S<VEB;&4@=7-E('1O('1H
M92!P=6)L:6,L('=E(')E8V]M;65N9"!M86MI;F<@:70@9G)E92!S;V9T=V%R
M92!T:&%T"F5V97)Y;VYE(&-A;B!R961I<W1R:6)U=&4@86YD(&-H86YG92X@
M(%EO=2!C86X@9&\@<V\@8GD@<&5R;6ET=&EN9PIR961I<W1R:6)U=&EO;B!U
M;F1E<B!T:&5S92!T97)M<R`H;W(L(&%L=&5R;F%T:79E;'DL('5N9&5R('1H
M92!T97)M<R!O9B!T:&4*;W)D:6YA<GD@1V5N97)A;"!0=6)L:6,@3&EC96YS
M92DN"@H@(%1O(&%P<&QY('1H97-E('1E<FUS+"!A='1A8V@@=&AE(&9O;&QO
M=VEN9R!N;W1I8V5S('1O('1H92!L:6)R87)Y+B`@270@:7,*<V%F97-T('1O
M(&%T=&%C:"!T:&5M('1O('1H92!S=&%R="!O9B!E86-H('-O=7)C92!F:6QE
M('1O(&UO<W0@969F96-T:79E;'D*8V]N=F5Y('1H92!E>&-L=7-I;VX@;V8@
M=V%R<F%N='D[(&%N9"!E86-H(&9I;&4@<VAO=6QD(&AA=F4@870@;&5A<W0@
M=&AE"B)C;W!Y<FEG:'0B(&QI;F4@86YD(&$@<&]I;G1E<B!T;R!W:&5R92!T
M:&4@9G5L;"!N;W1I8V4@:7,@9F]U;F0N"@H@("`@/&]N92!L:6YE('1O(&=I
M=F4@=&AE(&QI8G)A<GDG<R!N86UE(&%N9"!A(&)R:65F(&ED96$@;V8@=VAA
M="!I="!D;V5S+CX*("`@($-O<'ER:6=H="`H0RD@/'EE87(^("`\;F%M92!O
M9B!A=71H;W(^"@H@("`@5&AI<R!L:6)R87)Y(&ES(&9R964@<V]F='=A<F4[
M('EO=2!C86X@<F5D:7-T<FEB=71E(&ET(&%N9"]O<@H@("`@;6]D:69Y(&ET
M('5N9&5R('1H92!T97)M<R!O9B!T:&4@1TY5($QI8G)A<GD@1V5N97)A;"!0
M=6)L:6,*("`@($QI8V5N<V4@87,@<'5B;&ES:&5D(&)Y('1H92!&<F5E(%-O
M9G1W87)E($9O=6YD871I;VX[(&5I=&AE<@H@("`@=F5R<VEO;B`R(&]F('1H
M92!,:6-E;G-E+"!O<B`H870@>6]U<B!O<'1I;VXI(&%N>2!L871E<B!V97)S
M:6]N+@H*("`@(%1H:7,@;&EB<F%R>2!I<R!D:7-T<FEB=71E9"!I;B!T:&4@
M:&]P92!T:&%T(&ET('=I;&P@8F4@=7-E9G5L+`H@("`@8G5T(%=)5$A/550@
M04Y9(%=!4E)!3E19.R!W:71H;W5T(&5V96X@=&AE(&EM<&QI960@=V%R<F%N
M='D@;V8*("`@($U%4D-(04Y404))3$E462!O<B!&251.15-3($9/4B!!(%!!
M4E1)0U5,05(@4%524$]312X@(%-E92!T:&4@1TY5"B`@("!,:6)R87)Y($=E
M;F5R86P@4'5B;&EC($QI8V5N<V4@9F]R(&UO<F4@9&5T86EL<RX*"B`@("!9
M;W4@<VAO=6QD(&AA=F4@<F5C96EV960@82!C;W!Y(&]F('1H92!'3E4@3&EB
M<F%R>2!'96YE<F%L(%!U8FQI8PH@("`@3&EC96YS92!A;&]N9R!W:71H('1H
M:7,@;&EB<F%R>3L@:68@;F]T+"!W<FET92!T;R!T:&4@1G)E90H@("`@1F]U
M;F1A=&EO;BP@26YC+BP@-3D@5&5M<&QE(%!L86-E+"!3=6ET92`S,S`L($)O
M<W1O;BP@34$@(#`R,3$Q+3$S,#<@(%5300H*06QS;R!A9&0@:6YF;W)M871I
M;VX@;VX@:&]W('1O(&-O;G1A8W0@>6]U(&)Y(&5L96-T<F]N:6,@86YD('!A
M<&5R(&UA:6PN"@I9;W4@<VAO=6QD(&%L<V\@9V5T('EO=7(@96UP;&]Y97(@
M*&EF('EO=2!W;W)K(&%S(&$@<')O9W)A;6UE<BD@;W(@>6]U<@IS8VAO;VPL
M(&EF(&%N>2P@=&\@<VEG;B!A(")C;W!Y<FEG:'0@9&ES8VQA:6UE<B(@9F]R
M('1H92!L:6)R87)Y+"!I9@IN96-E<W-A<GDN("!(97)E(&ES(&$@<V%M<&QE
M.R!A;'1E<B!T:&4@;F%M97,Z"@H@(%EO>6]D>6YE+"!);F,N+"!H97)E8GD@
M9&ES8VQA:6US(&%L;"!C;W!Y<FEG:'0@:6YT97)E<W0@:6X@=&AE"B`@;&EB
M<F%R>2!@1G)O8B<@*&$@;&EB<F%R>2!F;W(@='=E86MI;F<@:VYO8G,I('=R
M:71T96X@8GD@2F%M97,@4F%N9&]M($AA8VME<BX*"B`@/'-I9VYA='5R92!O
M9B!4>2!#;V]N/BP@,2!!<')I;"`Q.3DP"B`@5'D@0V]O;BP@4')E<VED96YT
M(&]F(%9I8V4*"E1H870G<R!A;&P@=&AE<F4@:7,@=&\@:70A"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]D;V-S+U)%041-10``````````
M````````````````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#8W
M,S(@,3`U,34T,S,W,S,@,#$W,S4W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````%=H870@:7,@2&]R9&4_"CT]/3T]/3T]/3T]
M/3T]"@HZ3&%S="!U<&1A=&4Z("`@)$1A=&4Z(#(P,#4O,3`O,3@@,3$Z,S,Z
M,S4@)`HZ4F5V:7-I;VXZ("`@("`@)%)E=FES:6]N.B`R+C$S+C$P+C$@)`HZ
M0V]N=&%C=#H@("`@("`@:&]R9&5`;&ES=',N:&]R9&4N;W)G"@HN+B!C;VYT
M96YT<SHZ($-O;G1E;G1S"BXN('-E8W1I;VXM;G5M8F5R:6YG.CH*"E1H92!(
M;W)D92!0<F]J96-T(&ES(&$@9W)O=7`@;V8@9&5V96QO<&5R<R!W:&\@=W)I
M=&4@5V5B(&%P<&QI8V%T:6]N<R!U<VEN9PIT:&4@2&]R9&4@07!P;&EC871I
M;VX@1G)A;65W;W)K+"!I='-E;&8@82!P<F]D=6-T(&]F('1H92!0<F]J96-T
M+@H*5&AE($AO<F1E($%P<&QI8V%T:6]N($9R86UE=V]R:R!I<R!W<FET=&5N
M(&EN(%!(4"P@86YD('!R;W9I9&5S('1H92!C;VUM;VX*=&]O;',@82!796(@
M87!P;&EC871I;VX@<F5Q=6ER97,Z(&-L87-S97,@9F]R(&1E86QI;F<@=VET
M:"!P<F5F97)E;F-E<RP*8V]M<')E<W-I;VXL(&)R;W=S97(@9&5T96-T:6]N
M+"!C;VYN96-T:6]N('1R86-K:6YG+"!-24U%+"!A;F0@;6]R92X*"E1H92!(
M;W)D92!&<F%M97=O<FLL(&)Y(&ET<V5L9BP@9&]E<R!N;W0@<')O=FED92!A
M;GD@<VEG;FEF:6-A;G0@96YD('5S97(*9G5N8W1I;VYA;&ET>3L@:70@<')O
M=FED97,@82!B87-E(&9O<B!O=&AE<B!A<'!L:6-A=&EO;G,@86YD('1O;VQS
M(&9O<@ID979E;&]P97)S+B!9;W4@=VEL;"!P<F]B86)L>2!W86YT('1O(&EN
M<W1A;&P@<V]M92!O9B!T:&4@879A:6QA8FQE($AO<F1E"F%P<&QI8V%T:6]N
M<RP@<W5C:"!A<R!)35`@*&$@=V5B;6%I;"!C;&EE;G0I+"!O<B!+<F]N;VQI
M=&@@*&$@8V%L96YD87(I+B!4:&5R90II<R!A(&QI<W0@;V8@2&]R9&4@87!P
M;&EC871I;VYS(&%N9"!P<F]J96-T<R!A=`IH='1P.B\O=W=W+FAO<F1E+F]R
M9R]P<F]J96-T<RYP:'`N"@I4:&ES('-O9G1W87)E(&ES($]322!#97)T:69I
M960@3W!E;B!3;W5R8V4@4V]F='=A<F4N("!/4TD@0V5R=&EF:65D(&ES(&$*
M8V5R=&EF:6-A=&EO;B!M87)K(&]F('1H92!@3W!E;B!3;W5R8V4@26YI=&EA
M=&EV96!?+@H*+BX@7V!/<&5N(%-O=7)C92!);FET:6%T:79E8#H@:'1T<#HO
M+W=W=RYO<&5N<V]U<F-E+F]R9R\*"@I/8G1A:6YI;F<@2&]R9&4*+2TM+2TM
M+2TM+2TM+2TM"@I&=7)T:&5R(&EN9F]R;6%T:6]N(&]N($AO<F1E(&%N9"!T
M:&4@;&%T97-T('9E<G-I;VX@8V%N(&)E(&]B=&%I;F5D(&%T"@H@(&AT='`Z
M+R]W=W<N:&]R9&4N;W)G+VAO<F1E+PH*26YF;W)M871I;VX@;VX@87!P;&EC
M871I;VYS('1H870@=7-E('1H92!(;W)D92!F<F%M97=O<FL@8V%N(&)E(&9O
M=6YD(&%T"@H@(&AT='`Z+R]W=W<N:&]R9&4N;W)G+W!R;VIE8W1S+G!H<`H*
M"D1O8W5M96YT871I;VX*+2TM+2TM+2TM+2TM+0H*5&AE(&9O;&QO=VEN9R!D
M;V-U;65N=&%T:6]N(&ES(&%V86EL86)L92!I;B!T:&4@2&]R9&4@9&ES=')I
M8G5T:6]N.@H*.E)%041-15\Z("`@("`@("`@("`@("`@("`@(%1H:7,@9FEL
M90HZ0T]064E.1U\Z("`@("`@("`@("`@("`@("`@0V]P>7)I9VAT(&%N9"!L
M:6-E;G-E(&EN9F]R;6%T:6]N"CI@9&]C<R]#2$%.1T538%\Z("`@("`@("`@
M("!#:&%N9V5S(&)Y(')E;&5A<V4*.F!D;V-S+T-/1$E.1U]35$%.1$%21%-@
M7SH@($-O9&EN9R!S=&%N9&%R9',@9F]R($AO<F1E('!R;VIE8W1S"CI@9&]C
M<R]#3TY44DE"551)3D=@7SH@("`@("!(;W<@=&\@8V]N=')I8G5T92!T;R!(
M;W)D90HZ8&1O8W,O0U)%1$E44V!?.B`@("`@("`@("`@4')O:F5C="!D979E
M;&]P97)S"CI@9&]C<R](04-+24Y'8%\Z("`@("`@("`@("!(;W<@=&\@9V5T
M($AO<F1E('9I82!#5E,*.F!D;V-S+TE.4U1!3$Q@7SH@("`@("`@("`@($EN
M<W1A;&QA=&EO;B!I;G-T<G5C=&EO;G,@86YD(&YO=&5S"CI@9&]C<R]015)&
M3U)-04Y#16!?.B`@("`@("!097)F;W)M86YC92!G=6ED90HZ8&1O8W,O4D5,
M14%316!?.B`@("`@("`@("`@4F5L96%S92!P<F]C97-S(&YO=&5S"CI@9&]C
M<R]314-54DE466!?.B`@("`@("`@("!396-U<FET>2!N;W1E<PHZ8&1O8W,O
M5$]$3V!?.B`@("`@("`@("`@("`@1&5V96QO<&UE;G0@5$]$3R!L:7-T"CI@
M9&]C<R]54$=2041)3D=@7SH@("`@("`@("!0;VEN=&5R<R!O;B!U<&=R861I
M;F<@9G)O;2!P<F5V:6]U<R!(;W)D92!V97)S:6]N<PH*"DEN<W1A;&QA=&EO
M;@HM+2TM+2TM+2TM+2T*"DEN<W1R=6-T:6]N<R!F;W(@:6YS=&%L;&EN9R!(
M;W)D92!C86X@8F4@9F]U;F0@:6X@=&AE(&9I;&4@24Y35$%,3%\@:6X@=&AE
M"F!@9&]C<R]@8"!D:7)E8W1O<GD@;V8@=&AE($AO<F1E(&1I<W1R:6)U=&EO
M;BX*"@I!<W-I<W1A;F-E"BTM+2TM+2TM+2T*"DEF('EO=2!E;F-O=6YT97(@
M<')O8FQE;7,@=VET:"!(;W)D92P@:&5L<"!I<R!A=F%I;&%B;&4A(`H*5&AE
M($AO<F1E($9R97%U96YT;'D@07-K960@475E<W1I;VYS($QI<W0@*$9!42DL
M(&%V86EL86)L92!O;B!T:&4@5V5B(&%T"B`*("!H='1P.B\O=W=W+FAO<F1E
M+F]R9R]F87$O"@I4:&4@2&]R9&4@4')O:F5C="!R=6YS(&$@;G5M8F5R(&]F
M(&UA:6QI;F<@;&ES=',L(&9O<B!I;F1I=FED=6%L(&%P<&QI8V%T:6]N<PIA
M;F0@9F]R(&ES<W5E<R!R96QA=&EN9R!T;R!T:&4@<')O:F5C="!A<R!A('=H
M;VQE+B`@26YF;W)M871I;VXL(&%R8VAI=F5S+"!A;F0*<W5B<V-R:7!T:6]N
M(&EN9F]R;6%T:6]N(&-A;B!B92!F;W5N9"!A=`H*("!H='1P.B\O=W=W+FAO
M<F1E+F]R9R]M86EL+PH*3&%S=&QY+"!(;W)D92!D979E;&]P97)S+"!C;VYT
M<FEB=71O<G,@86YD('5S97)S(&%L<V\@;6%K92!O8V-A<VEO;F%L"F%P<&5A
M<F%N8V5S(&]N($E20RP@;VX@=&AE(&-H86YN96P@(VAO<F1E(&]N('1H92!F
M<F5E;F]D92!.971W;W)K"BAI<F,N9G)E96YO9&4N;F5T*2X*"@I,:6-E;G-I
M;F<*+2TM+2TM+2TM"@I&;W(@;&EC96YS:6YG(&%N9"!C;W!Y<FEG:'0@:6YF
M;W)M871I;VXL('!L96%S92!S964@=&AE(&9I;&4@0T]064E.1U\@:6X@=&AE
M"DAO<F1E(&1I<W1R:6)U=&EO;BX*"E1H86YK<RP*"E1H92!(;W)D92!T96%M
M"@H*+BX@7U)%041-13H@/V8]4D5!1$U%+FAT;6P*+BX@7T-/4%E)3D<Z(&AT
M='`Z+R]W=W<N:&]R9&4N;W)G+VQI8V5N<V5S+VQG<&PN<&AP"BXN(%]D;V-S
M+T-(04Y'15,Z(#]F/4-(04Y'15,N:'1M;`HN+B!?9&]C<R]#3T1)3D=?4U1!
M3D1!4D13.B`_9CU#3T1)3D=?4U1!3D1!4D13+FAT;6P*+BX@7V1O8W,O0T].
M5%))0E5424Y'.B`_9CU#3TY44DE"551)3D<N:'1M;`HN+B!?9&]C<R]#4D5$
M2513.B`_9CU#4D5$2513+FAT;6P*+BX@7V1O8W,O2$%#2TE.1SH@/V8]2$%#
M2TE.1RYH=&UL"BXN(%])3E-404Q,.@HN+B!?9&]C<R])3E-404Q,.B`_9CU)
M3E-404Q,+FAT;6P*+BX@7V1O8W,O4$521D]234%.0T4Z(#]F/5!%4D9/4DU!
M3D-%+FAT;6P*+BX@7V1O8W,O4D5,14%313H@/V8]4D5,14%312YH=&UL"BXN
M(%]D;V-S+U-%0U522519.B`_9CU314-54DE462YH=&UL"BXN(%]D;V-S+U1/
M1$\Z(#]F/51/1$\N:'1M;`HN+B!?9&]C<R]54$=2041)3D<Z(#]F/5501U)!
M1$E.1RYH=&UL"@``````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O9&]C<R]#2$%.1T53````````
M````````````````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,C(U
M-S<S(#$P-3$U-#,S-S,S(#`Q-S4P,@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````M+2TM+2T*=C,N,2XS"BTM+2TM+0H*6V-J
M:%T@4T5#55))5%DZ(%9A;&ED871E($=%5"UB87-E9"!54DP@<&%R86UE=&5R
M<R!P<F]V:61E9"!T;R!(;W)D92=S"B`@("`@(&EN9&5X+G!H<"X*6VIA;ET@
M4W5P<&]R="!I;7!O<G1I;F<@;V8@8V]M8FEN960@9&%T92]T:6UE(&9I96QD
M<R`H0G5G(",S,3$V*2X*6VIA;ET@3&]G(&$@=V%R;FEN9R!I9B!U<VEN9R!S
M971T:6YG<R!T:&%T(&)R96%K('-E<W-I;VYS+@I;:F%N72!&:7@@<&%R<V4@
M97)R;W(@=&AA="!B<F]K92!3>6YC34P@<WEN8VAR;VYI>F%T:6]N("A"=6<@
M(S0Q-C@I+@I;:F%N72!3=7!P;W)T($MO;&%B(&=R;W5P($%#3',@*&-S86-C
M84!T:&5C<VPN;W)G+"!297%U97-T(",R,C<P*2X*6VIA;ET@1FEX('5N<V5R
M:6%L:7IE*"D@97)R;W)S(&EN('-E<W-I;VX@=FEE=V5R("A"=6<@(S,U.#8I
M+@H*"BTM+2TM+0IV,RXQ+C(*+2TM+2TM"@I;8VIH72!314-54DE463H@4F5M
M;W9E('5N=7-E9"!I;6%G92!P<F]X>2!C;V1E(&9R;VT@9&5R969E<G)E<BX*
M6V-J:%T@4T5#55))5%DZ($-L;W-E(%A34R!P<F]B;&5M<R!I;B!D97)E9F5R
M<F5R("A)12!O;FQY*2P@:&5L<"!V:65W97(@86YD"B`@("`@('!R;V)L96T@
M<F5P;W)T:6YG('-C<F5E;BX*6V-J:%T@2&%N9&QE(&5R<F]R<R!G96YE<F%T
M960@9'5R:6YG(%A-3"U24$,@8V%L;',@<')O<&5R;'D*("`@("`@*$)E;B!+
M;&%N9R`\8F5N0&%L:V%L;VED+FYE=#XL($)U9R`C-#`Y-RDN"EMJ86Y=($%D
M9"!A9&1I=&EO;F%L(&EN9&5X97,@=&\@<')E9F5R96YC92!T86)L92`H:BYB
M96YO:71`9G)E92YF<BP@0G5G(",T,#<Y*2X*6VIA;ET@1FEX('!R969E<F5N
M8V4@8V%C:&4@*$)U9R`C-#`W.2DN"EMJ86Y=($%D9"!C;VYF:6=U<F%T:6]N
M(&]P=&EO;B!T;R!D:7-A8FQE($=%5"UB87-E9"!S97-S:6]N<RX*6VIA;ET@
M1FEX('!R969E<F5N8V5S(&%C8V5S<R!F;W(@<W!E8VEA;"!+;VQA8B!U<V5R
M<R`H=W)O8F5L0&=E;G1O;RYO<F<L"B`@("`@($)U9R`C-#`T.2DN"EMM;7-=
M($9I>"!S971T:6YG(&1E9F%U;'0@8VAA<G-E="!F;W(@;F]N+4U)344@;65S
M<V%G97,@*$)U9R`C,S@P-"DN"EMJ86Y=($%D9"!S979E<F%L(&UE=&AO9',@
M=&\@;6%N:7!U;&%T92!G<F]U<',@86YD('-H87)E<R!T;R!(;W)D92=S($%0
M22X*6VIA;ET@4F5T=7)N('-E<FEA;&EZ960@4$A0('9A;'5E<R!T:')O=6=H
M('1H92!215-4(&EN=&5R9F%C92!I9B!P87-S:6YG(&$*("`@("`@<F5S=$-O
M;G1E;G14>7!E('!A<F%M971E<B!O9B`G87!P;&EC871I;VXO>"UH='1P9"UP
M:'`G+@I;8VIH72!/;FQY(&%L;&]W('5S97)S('1O(&%S<VEG;B!3:&%R92!P
M97)M:7-S:6]N<R!F;W(@9W)O=7!S('1H97D@87)E"B`@("`@(&UE;6)E<G,@
M;V8N"EMJ86Y=($%L;&]W('1O(&1I<V%B;&4@5D93(&)A8VME;F1S(&EN('1H
M92!A<'!L:6-A=&EO;G,G(&-O;F9I9W5R871I;VYS+@I;;6US72!5<&1A=&4@
M=&AE($U)344@0V]N=&5N="U4>7!E(&-H87)S970@<&%R86UE=&5R(&EN(&$@
M34E-12!M97-S86=E('=H96X@=V4*("`@("`@8V]N=F5R="!T:&4@8V]N=&5N
M=',@9F]R('9I97=I;F<@:6X@=&AE(&)R;W=S97(@*$)U9R`C,S<R.2DN"EMC
M:FA=($9I>"!(;W)D95]&;W)M7U1Y<&5?87-S:6=N(&IA=F%S8W)I<'0@*$)U
M9R`C,S<T,"DN"EMJ86Y=($%D9"!U<&=R861E('-C<FEP=',@9F]R($]R86-L
M92X*6V-J:%T@26YC;'5D92!0051(7TE.1D\@=VAE;F5V97(@455%4EE?4U12
M24Y'(&ES(')E<75E<W1E9"!I;B!(;W)D93HZ<V5L9E5R;"@I"B`@("`@("A"
M=6<@(S,W,#,I+@I;:F%N72!!9&0@9V5N97)I8R!344P@=7!G<F%D92!S8W)I
M<'0@*$1A;FEE;"!!+B!286UA;&5Y"B`@("`@(#QD86YI96PN<F%M86QE>4!D
M<F%K92YE9'4^*2X*"@HM+2TM+2T*=C,N,2XQ"BTM+2TM+0H*6V-J:%T@4T5#
M55))5%DZ($9I>"!R96UO=&4@8V]D92!E>&5C=71I;VX@=G5L;F5R86)I;&ET
M>2!F;W5N9"!B>2!*86X@4V-H;F5I9&5R+@I;8VIH72!&:7@@97AP;W)T(&%N
M9"!S>6YC:')O;FEZ871I;VX@;V8@979E;G1S(&%C<F]S<R!D87EL:6=H="!S
M879I;F<@=&EM90H@("`@("!C:&%N9V5S+@I;:F%N72!!9&0@<')O<&5R(&QO
M8VMI;F<@=&\@;7ES<6P@<V5S<VEO;B!H86YD;&5R("A"=6<@(S,V-C`I+@I;
M8VIH72!I92YC<W,@:7,@;F]T(&YE8V5S<V%R>2!F;W(@244W+"!S;R!R96YA
M;64@87!P<F]P<FEA=&5L>2`H0G5G(",S-C<Q*2X*6VIA;ET@1FEX('%U;W1A
M('-U<'!O<G0@9F]R('-O;64@5D93(&1R:79E<G,@*$)U9R`C,S8T-RDN"EMC
M:FA=($)E='1E<B!/<&5R82!-:6YI(&1E=&5C=&EO;B`H0G5G(",R.38Q*2X*
M6VIA;ET@1FEX(&UE;G4@=W)A<'!I;F<@=VET:"!+;VQA8B!A;F0@4'5R<&QE
M('1H96UE("A"=6<@(S,U.30I+@H*"BTM+2T*=C,N,0HM+2TM"@I;8VIH72!2
M96UO=F4@8F]G=7,@0V]N=&5N="U,;V-A=&EO;B!H96%D97(@:6X@=&AE(%=-
M3"!-;V)I;&4@<F5N9&5R97(*("`@("`@*$)U9R`C,S0W-BDN"EMJ86Y=($%D
M9"!O<'1I;VX@=&\@8FQO8VL@2V]L86(@875T:&5N=&EC871I;VX@869T97(@
M9F%I;&5D(&QO9VEN<PH@("`@("`H=&]K;V5`:V1E+F]R9RP@4F5Q=65S="`C
M,S0W-"DN"EMJ86Y=($%L;&]W('1O('-E="!H96EG:'0@;V8@:69R86UE('!O
M<G1A;"!B;&]C:R`H=&5V86YS0'1A8VAO;65T<GDN8V]M+`H@("`@("!297%U
M97-T(",S-3`T*2X*6V-J:%T@57!D871E(%1O;VQ4:7!S($IA=F%38W)I<'0@
M;V)J96-T('1O(&%L;&]W('1O;VQT:7!S(&]N(&YO;BT\83X@96QE;65N=',N
M"EMM;7-=(%-O<G0@86X@24U!4%]4<F5E(&]B:F5C="!B>2!D:7-P;&%Y(&YA
M;64L(&YO="!F=6QL(&UA:6QB;W@@;F%M92X*6VUA<UT@36%K92!S=7)E(&1A
M=&%B87-E('!O<G1A8FEL:71Y(&]P=&EO;G,@87)E(&%P<&QI960@:6X@2&ES
M=&]R>2!M;V1U;&4N"B`@("`@("A"=6<@(S,T.#(I"@H*+2TM+2TM+2T*=C,N
M,2U20S,*+2TM+2TM+2T*"EMJ86Y=($UA:V4@<W5R92!T:&%T($MO;&%B('5S
M97)S(&%L=V%Y<R!H879E('1H92!S86UE('5S97(@;F%M92`H0G5G(",Q,S$W
M*2X*6VIA;ET@1FEX(&UO=FEN9R!O8FIE8W1S('=I=&@@2V]L86(@9')I=F5R
M<R`H=&]K;V5`:V1E+F]R9RP@0G5G(",R.#$Q*2X*6VIA;ET@061D(')E<V5T
M(&)U='1O;B!T;R!I;6%G92!F;W)M(&9I96QD<RX*6VIA;ET@1FEX('-E;&5C
M=&EO;B!O9B!D969A=6QT(&ED96YT:71Y("A"=6<@(S,T,38I+@I;;6%S72!!
M9&0@2&5B<F5W('1R86YS;&%T:6]N+@I;;6%S72!!9&0@<W5P<&]R="!F;W(@
M4D9#(#0S,30M<W1Y;&4@24U!4"!!0TQS+@I;;6US72!#;W)R96-T;'D@96YC
M;V1E(#<M8FET($U)344@;65S<V%G97,@=VET:"!.54Q,(&-H87)A8W1E<G,@
M*$)U9R`C,S,Y-2DN"EMJ86Y=($AI9&4@87!P;&EC871I;VYS('=I=&@@<W1A
M='5S("=N;W1O;VQB87(G(&9R;VT@;W!T:6]N<R!M96YU("A"=6<@(S,S.#,I
M+@H*"BTM+2TM+2TM"G8S+C$M4D,R"BTM+2TM+2TM"@I;:F%N72!!9&0@2VAM
M97(@=')A;G-L871I;VX@*$QE86YG($-H=6US;V)E;B`\<V]B96Y`:VAM97)O
M<RYI;F9O/BDN"EMM;7-=($AA;F1L92!Q=6]T960@=&5X="!W:&5N('!A<G-I
M;F<@341.(')E<75E<W1S("A"=6<@(S,S-#`I+@I;8F5N72!"971T97(@<W5P
M<&]R="!F;W(@35,M4U%,+@I;:F%N72!3:&]W(&-O<G)E8W0@861D<F5S<R!I
M;B!L87-T+6QO9VEN(&UE<W-A9V4@:68@8V]N;F5C=&EN9R!T:')O=6=H(&$@
M<')O>'D*("`@("`@*$)U9R`C,S(X."DN"EMM;7-=($%L;&]W(&%D;6EN('1O
M(&1I<V%B;&4@8G)O=W-E<B!S=')I;F<@8VAE8VMS("A"=6<@(S,R.#(I+@I;
M:F%N72!#;W)R96-T;'D@96YC;V1E(&5M86EL(&=R;W5P(&YA;65S("A"=6<@
M(S,R,S0I+@I;8VIH72!!9&0@82!D:7-P;&%Y(&UE=&AO9"!F;W(@:&]U<DUI
M;G5T95-E8V]N9"!F;W)M(&9I96QD<R`H0G5G(",S,38U*2X*6V-J:%T@2&]R
M9&4G<R!P<F5F97)E;F-E<R!N;W<@87)E(')E9F5R<F5D('1O(&%S($=L;V)A
M;"!/<'1I;VYS('-O('1H92!U<V5R"B`@("`@(&1O97-N)W0@;F5E9"!T;R!K
M;F]W('=H870@2&]R9&4@:7,L(&%N9"!A;'=A>7,@87!P96%R(&%T('1H92!T
M;W`@;V8*("`@("`@;&ES=',@;V8@87!P<R!F;W(@=VAI8V@@<')E9F5R96YC
M97,@87)E(&%V86EL86)L92X*6VIA;ET@061D('5P9W)A9&4@:6YS=')U8W1I
M;VYS("A+979I;B!->65R(&ME=FEN7VUY97)`:74Q,RYO<F<L($)U9R`C,S(R
M,BDN"EMC:FA=($%P<&QI8V%T:6]N<R!W:&EC:"!D;R!N;W0@:&%V92!A(&-O
M;F9I9R]P<F5F<RYP:'`@9FEL92!N;R!L;VYG97(*("`@("`@87!P96%R(&EN
M(&QI<W1S(&]F(&%P<&QI8V%T:6]N<R!T;R!S970@;W!T:6]N<R!F;W(@=&\@
M879O:60@8V]N9G5S:6]N+@H*"BTM+2TM+2TM"G8S+C$M4D,Q"BTM+2TM+2TM
M"@I;8VIH72!-86ME('1H92!L;V-K(&1I<F5C=&]R>2!F;W(@=&AE(&UE;6-A
M8VAE9"!397-S:6]N2&%N9&QE<B!C;VYF:6=U<F%B;&4*("`@("`@*$)U9R`C
M,S$R,"DN"EMM;7-=(%5P9&%T92!497AT7T9L;W=E9#HZ('1O('-U<'!O<G0@
M4D9#(#,V-S8N"EMC:FA=($9I>"!O=71P=70@97-C87!I;F<@;V8@2&]R9&5?
M1F]R;5]4>7!E7V-E;&QP:&]N92!I;B!525]687)296YD97)E<E]H=&UL+@I;
M8VIH72!!;&QO=R!C:&]O<VEN9R!;3F]N95T@87,@82!D871A8F%S92!F;W(@
M)&-O;F9;)W-Q;"==("A"=6<@(S(W-30I+@I;:F%N72!!9&0@26-E;&%N9&EC
M('1R86YS;&%T:6]N("A":F]R;B!$879I9'-S;VX@/&)J;W-S:4!S;F5R<&$N
M:7,^*2X*6VUM<UT@5V]R:R!A<F]U;F0@8G)O:V5N(&EM87!?.&)I="@I(&EM
M<&QE;65N=&%T:6]N(&EN"B`@("`@($U)344Z.G%U;W1E9%!R:6YT86)L945N
M8V]D92`H0G5G(",R.3<U*2X*6VUM<UT@061D(&=A<F)A9V4@8V]L;&5C=&EO
M;B!T;R!(;W)D95]#86-H92X*6V-J:%T@1FEX($=R;W5P.CIL:7-T06QL57-E
M<G,@*$-A<FQO<R!0961R:6YA8VDL($)U9R`C,CDS-RDN"EMJ86Y=($%D9"!H
M:6=H(&-O;G1R87-T('1H96UE("AT;65R<FET=$!E;6%I;"YA<FEZ;VYA+F5D
M=2P@4F5Q=65S="`C,34Y."DN"EMJ86Y=($ME97!S('-I9&5B87(@97AP86YS
M:6]N('-T871E(&%C<F]S<R!S97-S:6]N<R`H4F5Q=65S="`C,34V-"DN"EMJ
M86Y=($%D9"!C;VYF:6=U<F%T:6]N(&9O<B!M86EL(&1O;6%I;B!U<V5D(&9O
M<B!P<F]B;&5M(')E<&]R=',*("`@("`@*&1U<W1I;D!Y=VQC<RYO<F<L(%)E
M<75E<W0@(S$S-S8I+@I;8VIH72!!9&0@9'EN86UI8R!T86)L92!R92US;W)T
M:6YG('1H<F]U9V@@:F%V87-C<FEP="X*6V-J:%T@26YS<&5C="!M971H;V0@
M<VEG;F%T=7)E<R!S;R!T:&%T('1H92!215-4(&1R:79E<B!I<VXG="!D97!E
M;F1E;G0@;VX*("`@("`@=&AE(&]R9&5R(&]F($=%5"!P87)A;65T97)S+@I;
M8VIH72!!9&0@:&]R9&4O9V5T4')E9F5R96YC92!A;F0@:&]R9&4O<V5T4')E
M9F5R96YC92!!4$D@;65T:&]D<RX*6V-J:%T@061D(&$@;&ES="!O9B!A8W1I
M=F4@=7-E<G,@86YD(&%C=&EV92!S97-S:6]N<R!T;R!T:&4@861M:6X@87)E
M82X*6V-J:%T@061D('5N;V)T<G5S:79E(&IA=F%S8W)I<'0@=&]O;'1I<',@
M8F%S960@;VX@=&AE('1I=&QE(&%T=')I8G5T92X*6VIA;ET@36]V92!S:61E
M8F%R(&-O;&QA<'-E+V5X<&%N9"!B=71T;VX@8F5L;W<@=&AE(&UE;G4@8F%R
M("A/;&EV97(@2W5H;`H@("`@("`\;VMU:&Q`;F5T8V]L;V=N92YD93XI+@I;
M:F%N72!!9&0@261E87,@=&AE;64@*%)O96P@1VQO=61E;6%N<R`\<F]E;$!G
M;&]U9&5M86YS+FEN9F\^*2X*6V-J:%T@36]V92!(;W)D95](:7-T;W)Y(&1A
M=&$@=&\@:71S(&]W;B!344P@=&%B;&4@*$)U9R`C,C(Y."DN"EMJ86Y=($%D
M9"!(;W)D95]&;W)M7W1Y<&5?9FEG;&5T(&9O<B!#05!40TA!(&9I96QD<R!W
M:71H(&9I9VQE="!F;VYT<RX*6VIA;ET@061D($AO<F1E7T9O<FU?5'EP95]D
M8FQO;VMU<"!F;W(@9F]R;2!F:65L9',@=VET:"!D871A8F%S92!L;V]K=7!S
M"B`@("`@("A297%U97-T(",S,C(I+@I;:F%N72!!9&0@8V]N9FEG=7)A=&EO
M;B!T;R!D:7-A8FQE(")!8F]U="(@;&EN:W,@:6X@:&5L<"!W:6YD;W=S("@B
M36%T=&AE=PH@("`@("!-+B!'86UB;&4B(#QH;W)D92UD979`;6=A;6)L92YC
M83XI+@I;8VIH72!!;&QO=R!S96YD:6YG('!R;V)L96T@<F5P;W)T<R!T;R!A
M('1I8VME="!S>7-T96T@=7-I;F<@=&AE"B`@("`@('1I8VME=',O861D5&EC
M:V5T($%022!C86QL("A"=6<@(S$Y,3<I+@I;8VIH72!$969I;F4@4E1,('-T
M>6QE<R!V:6$@86X@861D:71I;VYA;"!S='EL97-H965T+@I;8VIH72!5<V%B
M:6QI='D@:6UP<F]V96UE;G1S('1O('1H92!I9&5N=&ET:65S(&UA;F%G96UE
M;G0@<&%G92`H0G5G(",Q.#0V*2X*6V)E;ET@061D($Q$05`@<W5P<&]R="!T
M;R!'<F]U<"!P86-K86=E+@I;8VIH72!!9&0@4TU"(&1R:79E<B!T;R!61E,@
M<&%C:V%G92X*6V-J:%T@06QL;W<@8W)E871I;VX@;V8@97AP:7)I;F<@86-C
M;W5N=',@:6X@3$1!4`H@("`@("`H4F]E;"!';&]U9&5M86YS(#QR;V5L0&=L
M;W5D96UA;G,N:6YF;SXI+@I;8VIH72!!9&0@8V]N9FEG=7)A=&EO;B!O<'1I
M;VX@=&\@<V5A<F-H(&9O<B!T:&4@=7-E<B=S($1.(&EN('1H92!0<F5F<U]L
M9&%P"B`@("`@(&1R:79E<B`H0G5G(",Q-S@V*2X*6VIA;ET@06QL;W<@=&\@
M<W!E8VEF>2!T:&4@;V)J96-T8VQA<W,@9F]R(&YE=R!U<V5R<R!A9&1E9"!T
M:')O=6=H($Q$05`*("`@("`@*%)O96P@1VQO=61E;6%N<R`\<F]E;$!G;&]U
M9&5M86YS+FEN9F\^*2X*6VIA;ET@061D('!A<W-W;W)D(&5X<&ER871I;VX@
M86YD('!A<W-W;W)D(&5N8W)Y<'1I;VX@=&\@3$1!4"!A=71H96YT:6-A=&EO
M;@H@("`@("!D<FEV97(@*%)O96P@1VQO=61E;6%N<R`\<F]E;$!G;&]U9&5M
M86YS+FEN9F\^*2X*6VIA;ET@061D('!E<FUI<W-I;VYS('1O(')E<W1R:6-T
M(&YU;6)E<B!O9B!P;W)T86P@8FQO8VMS+@I;:F%N72!!9&0@8V]N9FEG=7)A
M=&EO;B!F;W(@9FEX960@<&]R=&%L(&)L;V-K<RX*6VIM9ET@061D(&%U9&EO
M(&YO=&EF:6-A=&EO;B!L:7-T96YE<BP@;6%K92!P;W)T86P@:&%N9&QE(&%U
M9&EO(&YO=&EF:6-A=&EO;G,*("`@("`@8GD@8FQO8VMS("AE+F<N('1H92!)
M35`@9F]L9&5R('-U;6UA<GDI+@I;;6US72!#86-H92!C97)T86EN(')E9VES
M=')Y(&1A=&$@=&\@<')E=F5N="!U;FYE961E9"!F:6QE(&QO861I;F<O<&%R
M<VEN9PH@("`@("!A9G1E<B!T:&4@:6YI=&EA;"!L;V=I;BX*6VUA<UT@061D
M('-U<'!O<G0@9F]R(&-O=6YT:6YG(&%U=&AE;G1I8V%T960@<V5S<VEO;G,@
M=FEA(%-E<W-I;VY(86YD;&5R<RX*6V-J:%T@4F4M=V]R:R!486)S('-O('1H
M870@8F%C:V=R;W5N9"!I;6%G97,@8V%N(&)E('5S960@:6X@8W)E871I=F4@
M=V%Y<RX*6VIA;ET@061D(")->2!!8V-O=6YT($EN9F]R;6%T:6]N(B!B;&]C
M:R!T:&%T(&UI;6EC<R!T:&4@06-C;W5N=',@;6]D=6QE+@I;:F%N72!);7!R
M;W9E(')E;F1E<FEN9R!F;W(@<FEG:'0M=&\M;&5F="!L86YG=6%G97,@*$%M
M:7)K86)I<B!-971A3D54($QT9"XI+@I;:F%N72!!9&0@<W5P<&]R="!F;W(@
M87)B:71R87)Y+"!N;VXM8F]O;&5A;B!P97)M:7-S:6]N('9A;'5E<RX*6V)E
M;ET@061D(&%L=&5R;F%T95]L;V=I;B!A;F0@<F5D:7)E8W1?;VY?;&]G;W5T
M(&9E871U<F5S+@I;:F%N72!!9&0@9V5N97)I8R!33510(&1R:79E<B!T;R!.
M971?4TU3('!A8VMA9V4@*$EA;B!%=7)E(#QI975R94!P:'`N;F5T/BDN"EMM
M:G)=($YE=%])35-0('=I;&P@;F]W(&%U=&]M871I8V%L;'D@8W)E871E('5S
M97(G<R!D969A=6QT(&%D9')E<W-B;V]K(&EF"B`@("`@(&ET(&1O97,@;F]T
M(&%L<F5A9'D@97AI<W0@:6YS=&5A9"!O9B!J=7-T(&-O;7!L86EN:6YG(&%B
M;W5T(&ET+@I;8VIH72!!9&0@<V5L96-T(&%L;"P@;F]N92P@86YD(&EN=F5R
M="!O<'1I;VYA;&QY('1O($AO<F1E7T9O<FU?5'EP95]S970*("`@("`@9FEE
M;&1S("A$=6-K(#QD=6-K0&]B86QA+FYE=#XI+@I;8VIH72!0<F5F97)E;F-E
M<R!O=F5R=FEE=R!I<R!N;W<@8G5I;'0@=VET:"!A(&1E9FEN:71I;VX@;&ES
M="`H/&1L/BD@<W1Y;&5D"B`@("`@('=I=&@@0U-3+@I;:F%N72!!9&0@<V]R
M="@I(&UE=&AO9"!T;R!(;W)D95]4<F5E(&-L87-S+@I;;61J72!#:&%N9V4@
M86YY(&]U='!U="!O9B`\8CX@86YD(#QI/B!T86=S('1O(#QS=')O;F<^(&%N
M9"`\96T^(&9O<B!B971T97(*("`@("`@86-C97-S:6)I;&ET>2!S=7!P;W)T
M+@I;:FUF72!!;&QO=R!(;W)D92!T96UP;&%T97,@=&\@:6YC;'5D92!A<'!L
M:6-A=&EO;B!B;&]C:W,N"EMJ86Y=($%D9"!E>'1E;F1E9"!F;W)E8V%S=',@
M=&\@=V5A=&AE<F1O=&-O;2!";&]C:R`H4FEC:R!%;65R>0H@("`@("`\<FEC
M:T!E;65R>2YH;VUE;&EN=7@N;F5T/BDN"EMC:FA=($%L;&]W(&9O<B!A<F)I
M=')A<GD@871T<FEB=71E(&9I;'1E<G,@=VAE;B!L:7-T:6YG(&]R(&-O=6YT
M:6YG(%-H87)E"B`@("`@(&]B:F5C=',@*$1U8VL@/&1U8VM`;V)A;&$N;F5T
M/BDN"EMC:FA=($%D9"!$871A5')E93HZ9V5T4V]R=&5D5')E92@I("A$=6-K
M(#QD=6-K0&]B86QA+FYE=#XI+@I;;6IR72!3=7!P;W)T(&9O<B!I;71E<W0@
M875T:&5N=&EC871I;VX@861D960@=&\@4')E9G-?:6US<"X*6V-J:%T@061D
M(%)%4U0@4E!#(&1R:79E<B`H<W)R869A0'5S8RYE<RP@0G5G(",Q-3`P*2X*
M6V-J:%T@061D('-U<'!O<G0@9F]R(&9E=&-H:6YG('1H92!H:6=H97-T(&%N
M9"!L;W=E<W0@:61S(&EN(&%N>2!$871A5')E90H@("`@("!G<F]U<"`H1'5C
M:R`\9'5C:T!O8F%L82YN970^*2X*6V-J:%T@061D($1A=&%4<F5E.CIS;W)T
M0GE!='1R:6)U=&5S*"D@9F]R('-O<G1I;F<@1&%T851R965/8FIE8W1S(&)A
M<V5D(&]N"B`@("`@('1H96ER(&%T=')I8G5T97,@*$1U8VL@/&1U8VM`;V)A
M;&$N;F5T/BDN"EMM:G)=($EN:71I86P@<W5P<&]R="!A9&1E9"!T;R!.971?
M24U34"!F;W(@:6UT97-T(&1R:79E<B`H<')O=FED97,@<&5R<VES=&5N=`H@
M("`@("!)35-0(&-O;FYE8W1I;VYS('5S:6YG($-Y<G5S(&EM=&5S="!U=&EL
M:71Y*2X*6VIA;ET@061D(&UA<"!L:6YK<R!T;R!52R!A;F0@075S=')A;&EA
M;B!A9&1R97-S(&9I96QD<PH@("`@("`H='5R8F$N;&ES=$!S=6)O<F)I="YC
M;VTL($)U9R`C,30V,2DN"EMM;7-=($1E=&5C=&EO;B!O9B`B<&AI<VAI;F<B
M('1A8W1I8W,@:6X@=&AE($A434P@34E-15]6:65W97(@*%1O9&0@365R<FET
M=`H@("`@("`\=&UE<G)I='1`96UA:6PN87)I>F]N82YE9'4^+"!"=6<@(S$T
M,S0I+@I;;6US72!497AT7T9L;W=E9"!P86-K86=E(&YO=R!C;W)R96-T;'D@
M:&%N9&QE<R!M=6QT:6)Y=&4@8VAA<F%C=&5R<RX*6VUM<UT@36%I;G1E;F%N
M8V4@8V]N9FER;6%T:6]N('!A9V5S(&YO=R!R96YD97)E9"!V:6$@2&]R9&5?
M5&5M<&QA=&4@*%9I;&EU<PH@("`@("!3=6US:V%S(#QV:6QI=7-`;&YK+FQT
M/BDN"EMJ86Y=($%L;&]W('1O('-P96-I9GD@8VAA<G-E="!O9B!I;7!O<G1E
M9"!#4U8@9FEL97,N"EMJ86Y=($%D9"!&:6QE7T-35B!P86-K86=E+@I;:F%N
M72!3:&]W(&%P<&QI8V%T:6]N(&YA;65S(&EN('!E<FUI<W-I;VYS(&%D;6EN
M:7-T<F%T:6]N+@I;:FUF72!!;&QO=R!T:&4@875T:"!B86-K96YD('1O(')E
M<75E<W0@82!P87-S=V]R9"!C:&%N9V4L('-U<'!O<G0@97AP:7)I;F<*("`@
M("`@<&%S<W=O<F0@:6X@=&AE(%-13"!B86-K96YD+@I;8VIH72!3:&]W(&UE
M;G4@8VAI;&1R96X@9F]R(&5V97)Y(&%P<&QI8V%T:6]N('=I=&@@<')E9F5R
M96YC97,@=6YD97(@3W!T:6]N<PH@("`@("!I;B!T:&4@<VED96)A<B!M96YU
M("A"=6<@(S$P-3@I+@I;;6US72!!;&QO=R!I;F1I=FED=6%L($U)345?5FEE
M=V5R<R!T;R!O=F5R<FED92!T:&4@0V]N=&5N="U$:7-P;W-I=&EO;B!-24U%
M"B`@("`@('!A<F%M971E<B!A;F0@9F]R8V4@=FEE=VEN9R!I;FQI;F4N"@H*
M+2TM+2TM+0IV,RXP+C$Q"BTM+2TM+2T*"EMC:FA=(%-%0U522519.B!296UO
M=F4@=6YU<V5D(&EM86=E('!R;WAY(&-O9&4@9G)O;2!D97)E9F5R<F5R+@I;
M8VIH72!314-54DE463H@0VQO<V4@6%-3('!R;V)L96US(&EN(&1E<F5F97)R
M97(@*$E%(&]N;'DI+"!H96QP('9I97=E<B!A;F0*("`@("`@<')O8FQE;2!R
M97!O<G1I;F<@<V-R965N+@H*"BTM+2TM+2T*=C,N,"XQ,`HM+2TM+2TM"@I;
M8VIH72!314-54DE463H@1FEX(')E;6]T92!C;V1E(&5X96-U=&EO;B!V=6QN
M97)A8FEL:71Y(&9O=6YD(&)Y($IA;B!38VAN96ED97(N"@H*+2TM+2TM"G8S
M+C`N.0HM+2TM+2T*"EMC:FA=($9I>"!S:&]W<W1O<'!E<B!B=6<@:6X@2&]R
M9&5?1F]R;2!S96QE8W0@9FEE;&1S("A"=6<@(S,Q,C,I+@H*"BTM+2TM+0IV
M,RXP+C@*+2TM+2TM"@I;8VIH72!7:&5N(&1E;&5T:6YG(&%N(&ED96YT:71Y
M+"!D;VXG="!S:&]W('1H92!D96QE=&5D(&ED96YT:71Y"B`@("`@(&EN('1H
M92!D969A=6QT(&ED96YT:71Y('-E;&5C="!D<F]P9&]W;B!O;B!T:&4@;F5X
M="!P86=E(&QO860N"EMC:FA=($9I>"!E<V-A<&EN9R!O9B!D871A(&EN('1H
M92!P<F5F97)E;F-E<R!T96UP;&%T97,N"EMC:FA=($9I>"!E<V-A<&EN9R!O
M9B!D871A(&EN('1H92!D871A(&EM<&]R="!T96UP;&%T97,N"EMC:FA=($9I
M>"!O=71P=70@97-C87!I;F<@;V8@2&]R9&5?1F]R;5]4>7!E7V-E;&QP:&]N
M92!I;B!525]687)296YD97)E<E]H=&UL+@I;8VIH72!314-54DE463H@0VQO
M<V4@<V5V97)A;"!84U,@<')O8FQE;7,@:6X@=&AE('-H87)E(&5D:70@=VEN
M9&]W+@I;:F%N72!&:7@@=V5A=&AE<BYC;VT@<&]R=&%L(&)L;V-K+@H*"BTM
M+2TM+0IV,RXP+C<*+2TM+2TM"@I;:F%N72!314-54DE463H@1FEX(%A34R!V
M=6QN97)A8FEL:71I97,@:6X@9WII<"]T87(@86YD(&-S<R!-24U%('9I97=E
M<G,N"EMC:FA=($%D9"!M:7-S:6YG($-/34U)5"!I;B!->5-13"!397-S:6]N
M2&%N9&QE<B!D<FEV97(*("`@("`@*&1G96AL0&EN=F5R<V4N8V$L($)U9R`C
M,C<S,2DN"@H*+2TM+2TM"G8S+C`N-@HM+2TM+2T*"EMJ86Y=(%!A<W,@86QL
M(%523"!P87)A;65T97)S('=H97)E(&QI;FMI;F<@96UA:6P@861D<F5S<V5S
M("A297%U97-T(",Q-3,P*2X*6VIA;ET@4VAO=R!7;W)D('9I97=E<B!C;VYT
M96YT('=I=&@@8V]R<F5C="!C:&%R<V5T("AS9W)O;F1I;D!C<V)F+G%C+F-A
M+`H@("`@("!"=6<@(S(W,S<I+@H*"BTM+2TM+2TM+2T*=C,N,"XV+5)#,0HM
M+2TM+2TM+2TM"@I;8VIH72!&:7@@=')A;G-A8W1I;VYS(&%N9"!B:6YA<GD@
M9&%T82!I;B!0;W-T9W)E4U%,('-E<W-I;VX@:&%N9&QE<@H@("`@("`H8V)S
M0&-T<RYU8VQA+F5D=2P@0G5G(",R-S0Y+"`C,C<X.2DN"EMJ86Y=($9I>"!S
M:61E8F%R(&UE;G4@;&%Y;W5T(&9O<B!/<&5R82`H0G5G(",R-S(R*2X*6V-J
M:%T@061D(#QP<F4^('1O('-U<'!O<G1E9"!H96QP('1A9W,@*'9I:F%Y+FUA
M:')R84!E<RYE87-Y;F5T+FYE="P*("`@("`@0G5G(",R-C,S*2X*6V-J:%T@
M1FEX('9A;&ED871I;VX@;VX@:7!A9&1R97-S($AO<F1E7T9O<FT@9FEE;&1S
M("A"=6<@(S(U.#,I+@I;8VIH72!!9&0@075T:#HZ9V5T075T:$1O;6%I;B@I
M("A"=6<@(S(U-S,I+@I;;6IR72!!9&0@86)I;&ET>2!T;R!E;F%B;&4O9&ES
M86)L92!)35-0(&=L;V)A;&QY('9I82!C;VYF:6=U<F%T:6]N('-E='1I;F=S
M+@I;:F%N72!&:7@@8V%L96YD87(@<&]P=7`@=VET:"!3869A<FD@8G)O=W-E
M<G,@*'0N>F5L;$!G;7@N9&4L($)U9R`C,C0T."DN"EMC:FA=(%=H96X@=7-I
M;F<@0T=)(%!(4"P@4T-225!47TY!344@;6%Y(&-O;G1A:6X@=&AE('!A=&@@
M=&\@=&AE(%!(4"!B:6YA<GD*("`@("`@:6YS=&5A9"!O9B!T:&4@<V-R:7!T
M(&)E:6YG(')U;CL@=7-E(%!(4%]314Q&(&EN<W1E860@*$)U9R`C,C0P,2DN
M"EMJ86Y=($9I>"!S:&%R:6YG('=I=&@@9W)O=7!S(&EF('5S:6YG(&=R;W5P
M(&AO;VMS("A"=6<@(S(R.3(I+@H*"BTM+2TM+0IV,RXP+C4*+2TM+2TM"@I;
M;6US72!&:7@@5D93)W,@875T;V-R96%T95!A=&@H*2!F;W(@9&ER96-T;W)Y
M('!A=&AS(&-O;G1A:6YI;F<@=&AE(')O;W0*("`@("`@9&ER96-T;W)Y+@I;
M:F%N72!&:7@@8WER<W%L(&%U=&AE;G1I8V%T:6]N(&1R:79E<B!W:71H('5N
M:7AH:65R87)C:'ES97`@96YA8FQE9`H@("`@("`H<V=R;VYD:6Y`8W-B9BYQ
M8RYC82P@0G5G(",R,S8W*2X*6VUM<UT@1FEX(&YE<W1E9"!)34%0($%.1"!S
M96%R8VAE<RX*6VUM<UT@26X@<W%L(%9&4R!D<FEV97(L(&%L;&]W('1H92!U
M<V4@;V8@)R\G(&%T('1H92!B96=I;FYI;F<@;V8@82!P871H('1O"B`@("`@
M(&EN9&EC871E('1H92!B87-E(&1I<F5C=&]R>2X*6VIA;ET@1FEX(')E='5R
M;FEN9R!T;R!L87-T('!A9V4@869T97(@<V5N9&EN9R!P<F]B;&5M(')E<&]R
M="`H0G5G(",R,S4P*2X*6VUM<UT@1FEX(&$@8G5G('1H870@8V%U<V5D(&AO
M;VL@8V]D92!T;R!B92!R=6X@=6YN96-E<W-A<FEL>2!A9G1E<B!A('5S97(*
M("`@("`@:7,@86QR96%D>2!L;V=G960@:6XN"@H*+2TM+2TM+2TM+0IV,RXP
M+C4M4D,R"BTM+2TM+2TM+2T*"EMC:FA=($9I>"!A(&9A<BUR96%C:&EN9R!$
M871A5')E92!B=6<@:6X@;&]A9&EN9R!P87)E;G0@:61S("A"=6<@(S(R,#,I
M+@H*"BTM+2TM+2TM+2T*=C,N,"XU+5)#,0HM+2TM+2TM+2TM"@I;:F%N72!!
M9&0@0F]S;FEA;B!T<F%N<VQA=&EO;B`H5F5D<F%N($QJ=6)O=FEC(#QV;&IU
M8F]V:6-`<VUA<G1N970N8F$^*2X*6V-J:%T@3&5T($AO<F1E7U1R964@:&%N
M9&QE(&%L;"!I;F1E;G0@8V%L8W5L871I;VX@8F%S960@;VX@<&%R96YT+V-H
M:6QD"B`@("`@(')E;&%T:6]N<VAI<',@*$)U9R`C,C$Y."DN"EMC:FA=($%D
M9"!I;FET:6%L($Q$05`@4V5S<VEO;DAA;F1L97(@9')I=F5R+@I;8VIH72!5
M<V4@<F]W+6QE=F5L(&QO8VMI;F<@;W(@=')A;G-A8W1I;VYS('=H97)E('!O
M<W-I8FQE('1O(&%V;VED"B`@("`@('-E<W-I;VX@8V]R<G5P=&EO;B!I;B!3
M97-S:6]N2&%N9&QE<B`H0G5G(",Q-3@P*2X*6VUM<UT@061D('1H92!M96UC
M86-H960@4V5S<VEO;DAA;F1L97(Z.B!D<FEV97(@*%)O;F<M16X@1F%N(#QR
M869A;D!C<VEE+F]R9SXI+@I;;6US72!&:7@@=F5R:69I8V%T:6]N(&]F($U)
M344@<W1R:6YG<R!W:71H(&5S8V%P960@<75O=&5S("A"=6<@(S(Q-C@I+@I;
M:F%N72!&:7@@9V5N97)A=&EO;B!O9B!F<F5E('!E<FEO9',@:6X@9G)E92]B
M=7-Y(&-O9&4@=VET:"!O=F5R;&%P<&EN9R!E=F5N=',N"EMJ86Y=($1O;B=T
M('-H;W<@3W!T:6]N<R!B=71T;VX@:6X@<')O8FQE;2!R97!O<G1I;F<@<&%G
M92X*6VIA;ET@061D(%5T:6PZ.G)E86Q0871H*"D@;65T:&]D+@I;;6%S72!)
M;F-L=61E('9E<G-I;VX@;G5M8F5R<R!F;W(@87!P;&EC871I;VYS(&]N($%D
M;6EN(%-E='5P('-C<F5E;BX@*$)U9PH@("`@("`C,30R,"D*6VUA<UT@0VAA
M;F=E($E-05`@075T:"!D<FEV97(@=&\@=7-E(&EM87`O;F]T;',@8GD@9&5F
M875L="!I;B!N;VXM1%-.(&UO9&4@=&\*("`@("`@;6%T8V@@1%-.(&UO9&4N
M"EMM87-=($%D9"!T;',@86YD('-E;&8M<VEG;F5D(&-E<G1I9FEC871E(&-O
M;F9I9W5R871I;VX@;W!T:6]N<R!T;R!)34%0($%U=&@*("`@("`@9')I=F5R
M+B`H0G5G(",Q,S4W*0I;8VIH72!296-O9VYI>F4@3W!E<F$@."L@87,@<')O
M=FED:6YG(&%D=F%N8V5D(&9E871U<F5S("A"=6<@(S(P-C8I+@I;8VIH72!&
M:7@@<F5A9&EN9R!O9B!B:6YA<GD@9FEL97,@;VX@5VEN9&]W<R!I;B!60U]S
M=FX@*$)U9R`C,C`S-BDN"EMM87-=($9I>"!344P@)TQ)2T4G(&-A<V4M:6YS
M96YS:71I=F4@8V]M<&%R:7-O;BX@*$)U9R`C,C`S,"D*6VIA;ET@06QL;W<@
M8VAA<G-E="!A=V%R92!)34%0('-E87)C:&5S+@I;:F%N72!&:7@@1V]O9VQE
M('-E87)C:"!B;&]C:R!F;W(@;F]N+6%S8VEI(&-H87)A8W1E<G,@*$)U9R`C
M,3,R.2DN"EMJ86Y=($%D9"!Q=6EC:RUI;G-T86QL(&EN<W1R=6-T:6]N<RX*
M6VIA;ET@26UP<F]V92!P97)F;W)M86YC92!O9B!S979E<F%L(&9R86UE=V]R
M:R!P86-K86=E<RX*6VUM<UT@1FEX($U)345?0V]N=&5N=',Z.B!C86-H:6YG
M(&EN(%!(4"`U("A"=6<@(S$T,3`I+@I;:F%N72!&:7@@5D,@4U9.(&)A8VME
M;F0@=&\@<W5P<&]R="!U<V5R(&YA;65S('=I=&@@<W!A8V5S"B`@("`@("AS
M:&EM;6%N;FEN9T!G;6%I;"YC;VTL($)U9R`C,3DQ.2DN"EMC:FA=($5S8V%P
M92!(5$U,(&EN(&ED96YT:71Y(&YA;65S("A"=6<@(S$Y,3`I+@I;;6%S72!5
M<V4@=7!D871E9"!0;W-T9W)E4U%,(&9U;F-T:6]N(&YA;65S+@I;8F5N72!5
M<&1A=&4@87!P;&EC871I;VX@;&ES="!I;B!H;W)D92=S($Q$05`@<V-H96UA
M"EMC:FA=($5N9F]R8V4@;6%X;&5N9W1H(')E<W1R:6-T:6]N<R!I;B!(;W)D
M95]&;W)M('9A;&ED871I;VX@*$)U9R`C,3@Y-2DN"EMJ86Y=($1I<V%B;&4@
M=V5A=&AE<BYC;VT@0FQO8VL@:68@;F]T(&-O;F9I9W5R960N"EMC:FA=($EN
M8VQU9&4@<V]U<F-E<F]O="!I;B!60R!C86-H92!K97ES("A"=6<@(S$W.#,I
M+@I;:F%N72!!9&0@4U%,('-C<FEP="!A;F0@:6YS=')U8W1I;VYS(&9O<B!-
M4T1%(&1A=&%B87-E<R`H0G5G<R`C,3@V,BP@(S$X-S`L"B`@("`@(&IE9F9`
M:6UA9V4M<W)C+F-O;2DN"EMJ86Y=($%L;&]W('!O<G1A;"!B;&]C:W,@=&\@
M8F4@;&%R9V5R('1H86X@='=O(&-O;'5M;B]R;W=S("A"=6=S(",Q,3@Y+"`Q
M-C,R*2X*6VIA;ET@061D(%--5%`@875T:&5N=&EC871I;VX@=&\@<')O8FQE
M;2!R97!O<G1I;F<@*$)U9R`C,3$R."DN"EMJ86Y=(%-U<'!O<G0@:&5L<"!F
M:6QE<R!I;B!A9&UI;B!D:7)E8W1O<GD@=VET:"!T<F%N<VQA=&EO;G,N<&AP
M("A"=6<@(S$S-#0I+@I;:F%N72!&:7AE9"!344P@8FEN9&EN9R!F;W(@3T1"
M0R!A;F0@35-344P@9')I=F5R<R`H0G5G(",Q.#$V*2X*6VIA;ET@061D(&-O
M;F9I9W5R871I;VX@;W!T:6]N('1O('-E="!L;V-A=&EO;B!O9B!-24U%(&UA
M9VEC(&1A=&%B87-E+@I;;6US72!-86ME('-U<F4@:&5A9&5R<R!I;B!A($U)
M345?4&%R="!A<F4@96YC;V1E9"!W:71H('1H92!S86UE(&-H87)A8W1E<@H@
M("`@("!S970@=7-E9"!I;B!T:&%T($U)345?4&%R="`H0G5G(",Q-3DQ*2X*
M6VUM<UT@061D($QI<W0M2&5A9&5R<R!L:7-T960@:6X@4D9#(#(S-CD@=&\@
M=&AE(&QI<W0@;V8@34E-12!(96%D97)S('1H870*("`@("`@8V%N(&]N;'D@
M87!P96%R(&]N8V4@:6X@82!S:6YG;&4@:&5A9&5R("A"=6<@(S$W-C8I+@I;
M8VIH72!&:7@@='EP;R!I;B!P87)S:6YG(&]F($92145"55-9(&1A=&$@*$)U
M9R`C,34Y,"DN"EMJ86Y=(%-U<'!O<G0@4U%,:71E(&%N9"!/<F%C;&4@:6X@
M86QL(%-13"!B86-K96YD(&-O;F9I9W5R871I;VYS+@I;8VIH72!5<V4@8FEN
M9"!V87)I86)L97,@:6X@=&AE($%U=&@L(%9&4RP@86YD(%-E<W-I;VY(86YD
M;&5R(%-13"!D<FEV97)S+`H@("`@("!A;F0@:6X@<V-R:7!T<R]R96UO=F5?
M<')E9G,N<&AP("AS96QS:WE`8V]L=6UB:6$N961U+"!"=6=S(",Q-C8U+`H@
M("`@("`C,38V-BP@(S$V-C<L(",Q-C8X+"`C,38W-RDN"EMC:FA=('-E<W-I
M;VY?<V5T7V-O;VMI95]P87)A;7,H*2!E>'!E8W1S(&$@<F5L871I=F4@=&EM
M96]U=#L@<V5T8V]O:VEE('=A;G1S"B`@("`@(&%B<V]L=71E+B!';R!B86-K
M('1O(&$@8V]N9FEG:6YT96=E<B!F;W(@)&-O;F9;)W-E<W-I;VXG75LG=&EM
M96]U="==(&%N9`H@("`@("!A9&0@=&EM92@I('1O('1H870@=F%L=64@:6X@
M<V5T8V]O:VEE*"D@8V%L;',@*$)U9W,@(S$S,#(L(",Q-C4X*2X*("`@("`@
M5$A)4R!-05D@0E)%04L@0T].1DE'55)!5$E/3E,@4T54(%1/(%5312!02%`@
M0T]$12X@34%+12!355)%(%1/(%501$%410H@("`@("!93U52("1C;VYF6R=S
M97-S:6]N)UU;)W1I;65O=70G72!3151424Y'($%&5$52(%501U)!1$E.1RX*
M6V-J:%T@57-E(&)I;F0@=F%R:6%B;&5S(&EN('1H92!0<F5F<R!A;F0@5&]K
M96X@4U%,(&1R:79E<G,*("`@("`@*'-E;'-K>4!C;VQU;6)I82YE9'4L($)U
M9W,@(S$V-3(L(",Q-C4S*2X*6VUM<UT@4')U;F4@97AP86YD960@9F]L9&5R
M<R!T:&%T(&YO(&QO;F=E<B!E>&ES="!I;B!)34%07U1R964@*$)U9R`C,34Q
M-RDN"EMC:FA=($1O;B=T('1R>2!T;R!C;VUP<F5S<R!O=71P=70@:68@6E!3
M(&-O;7!R97-S:6]N(&ES(&]N("A"=6<@(S$V,C8I+@I;8VIH72!)9B!A;B!A
M<'`@;VYL>2!H87,@;VYE('!R969'<F]U<"P@86QW87ES('-H;W<@=&AA="!P
M<F5F1W)O=7`@:6YS=&5A9`H@("`@("!O9B!S:&]W:6YG(&%N(&]V97)V:65W
M('-C<F5E;B!W:71H(&]N;'D@;VYE(&5N=')Y+@H*"BTM+2TM+0IV,RXP+C0*
M+2TM+2TM"@I;8VIH72!5<V4@9G5L;'D@<75A;&EF:65D(%523',@:6X@=&AE
M($%N<V5L26UA9V4@2%1-3$%R96$@<&QU9VEN("A"=6<@(S$R-3DI+@I;8VIH
M72!314-54DE463H@0VQO<V4@6%-3('=H96X@<V5T=&EN9R!T:&4@<&%R96YT
M(&9R86UE)W,@<&%G92!T:71L92!B>0H@("`@("!J879A<V-R:7!T+@I;8FQC
M72!!9&0@4&]S=&=R95-13"!U<&=R861E('-C<FEP="`H0G)A9"!7:71T92`\
M8G)A9$!D:7-T86YT:&%Z92YC;VTI"EMC:FA=($%V;VED(&1I=FES:6]N(&)Y
M('IE<F\@:68@86QL('!R969E<F5N8V5S(&%R92!L;V-K960@*$)U9R`C,38R
M-RDN"EMJ86Y=($9I>"!S:61E8F%R(')E9G)E<VAI;F<@=VET:"!/<&5R82X*
M"@HM+2TM+2TM+2TM"G8S+C`N-"U20S(*+2TM+2TM+2TM+0H*6VIA;ET@26UP
M<F]V92`B;&]G:6XB(&%U=&AE;G1I8V%T:6]N(&1R:79E<B`H0G5G(",Q-3<Q
M*2X*6VIA;ET@4VAO=R!D871A8F%S92!S<&5C:69I8R!C;VYN96-T:6]N('!A
M<F%M971E<G,@:6X@9VQO8F%L(%-13"!C;VYF:6=U<F%T:6]N"B`@("`@('1O
M;RX*6VIA;ET@1FEX(&QE9G0@;65N=2!O=F5R9FQO=R!I;B!)12!A;F0@4V%F
M87)I("A"=6<@(S$U,C8I+@I;:F%N72!&:7@@875T;V-R96%T:6YG(&]F(&1I
M<F5C=&]R:65S(&%N9"!U<&1A=&EN9R!O9B!E>&ES=&EN9R!F:6QE<R!I;B!T
M:&4*("`@("`@<W%L7V9I;&4@5D93(&1R:79E<B`H961D:65`;VUE9V%W87)E
M+F-O;2P@0G5G<R`C,34U,B!A;F0@(S$U-3,I+@I;:F%N72!-86ME('=R87!P
M:6YG(&UE;G5S('9I<VEB;&4@=VET:"!'96-K;R`Q+C0@8G)O=W-E<G,@*&4N
M9RX@3F5T<V-A<&4@-RXQ*2X*6VIA;ET@57-E(%-13"!B:6YD:6YG(&9O<B!S
M;VUE($1A=&%4<F5E(&]P97)A=&EO;G,N"EMJ86Y=($9I>"!$871A5')E92!3
M44P@<W5P<&]R="!F;W(@3W)A8VQE+@I;:F%N72!&:7@@4U%,(&-O;F9I9W5R
M871I;VX@9F]R($]R86-L92X*6VUM<UT@36%K92!S=7)E(%9&4R!G87)B86=E
M(&-O;&QE8W1I;VX@:7,@9&]N92!R96-U<G-I=F5L>2X*"@HM+2TM+2TM+2TM
M"G8S+C`N-"U20S$*+2TM+2TM+2TM+0H*6VIA;ET@061D($AO<F1E7U1R965?
M<V5L96-T(&-L87-S("A"96X@0VAA=F5T(#QB96Y`:&]R9&4N;W)G/BDN"EMM
M:G)=($9I>"!.971?24U34"!T;R!P<F]P97)L>2!H86YD;&4@;75L=&EP;&4@
M;&EN97,@:6X@861D<F5S<V)O;VL@9FEE;&1S+@I;:F%N72!&:7@@34E-12!D
M96-O9&EN9R!O9B!S=')I;F=S('1H870@8V]N=&%I;B`B)2(@:6X@;75L=&EB
M>71E('-E<75E;F-E<PH@("`@("`H0G5G(",Q-#(S*2X*6V-J:%T@0V]N=')O
M;"!S<&%C92!U;F1E<B!T:&4@;65N=2!B87(@=VET:"!A('1H96UE86)L92!S
M='EL92`H0G5G(",Q-#(Q*2X*6V-J:%T@1FEX($AO<F1E7U1R964@=VET:"!T
M:&4@;75L=&EL:6YE(&]P=&EO;B!S;R!T:&%T(')O=R!S='EL97,@97AT96YD
M(&]V97(*("`@("`@=&AE('=H;VQE(&AE:6=H="!O9B!T:&4@<F]W+@I;8VIH
M72!)9B!C;VYF:6=U<F%T:6]N(&9I;&5S('1H870@:&%V92!A("YD:7-T('9E
M<G-I;VX@87)E(&UI<W-I;F<L"B`@("`@($AO<F1E7U1E<W0Z.F-O;F9I9T9I
M;&5S36ES<VEN9R@I('=I;&P@8V]P>2!T:&4@9&5F875L=',@;W9E<B!I9B!(
M;W)D90H@("`@("!C86X@=W)I=&4@=&\@=&AE(&9I;&5S>7-T96T@*$)U9R`C
M,3`Q-2DN"EMC:FA=($9I>"!!;G-E;$EM86=E($A434Q!<F5A('!L=6=I;B`H
M0G5G(",Q-#<P*2X*6V-J:%T@2G5S="!R971R:65V92!U:60@=VAE;B!L:7-T
M:6YG('5S97)S(&EN('1H92!,1$%0($%U=&AE;G1I8V%T:6]N(&1R:79E<BX*
M6V-J:%T@061D(&-H;W)A4')E9G,@=&\@=&AE(&AO<F1E4&5R<V]N($Q$05`@
M<V-H96UA("A"=6<@(S$T-3(I+@I;8VIH72`G<F]O=&1N)R!I<R!N;W0@<F5Q
M=6ER960@9F]R($Q$05`@<')E9F5R96YC97,@*$)U9R`C,30U,RDN"EMM;7-=
M($9I>"!)34%0('1H<F5A9"!C<F5A=&EO;B!W:&5N('1H92!B87-E(&QE=F5L
M(&-O;G1A:6YS(&UO<F4@=&AA;B!O;F4*("`@("`@;65S<V%G92X*6VIA;ET@
M06QL;W<@=D-A<F1S('=I=&@@;&]W97)C87-E(&9I96QD(&1E<V-R:7!T;W)S
M+@I;:F%N72!);7!R;W9E('1A<B]G>FEP($U)344@=FEE=V5R('1O(&)E='1E
M<B!S:&]W('5N>FEP<&5D(&-O;G1E;G0N"EMM:G)=($)E='1E<B!E<G)O<B!H
M86YD;&EN9R!I;B!.971?24U34"X*6VUM<UT@4W!E960@:6UP<F]V96UE;G1S
M(&%N9"!S;W)T:6YG(&9I>&5S(&9O<B!)34%07U1R964N"EMM;7-=($E-05!?
M5')E92!N;W<@:&%N9&QE<R!N;VXM=7!P97)C87-E9"`G24Y"3U@G('-T<FEN
M9W,@<F5T=7)N960@9G)O;2!T:&4*("`@("`@;6%I;"!S97)V97(@*$)U9R`C
M,3DY*2X*6VUM<UT@4F5B=6EL9"!C97)T86EN(&EN=&5R;F%L($U)345?4&%R
M="!D871A('=H96X@<F5T<FEE=FEN9R!F<F]M(&$@8V%C:&4N"EMJ86Y=(%-H
M;W<@9&%T86)A<V4@<W!E8VEF:6,@8V]N;F5C=&EO;B!P87)A;65T97)S(&EN
M(&-O;F9I9W5R871I;VX@<V-R965N+@I;;6US72!)34%07U1R964@;F]W(&-O
M<G)E8W1L>2!U<&1A=&5D('=H96X@<W5B<V-R:6)I;F<O=6YS=6)S8W)I8FEN
M9R!F<F]M(&$*("`@("`@;6%I;&)O>"`H0G5G(",Q,3$Q*2X*6VUM<UT@36%K
M92!)34%0('-E87)C:&5S(&]F(&YO;BTB<W1A;F1A<F0B(&AE861E<G,@=V]R
M:R!W:71H('1H92!.3U0@9&ER96-T:79E"B`@("`@("A"=6<@(S$S-C@I+@I;
M:F%N72!&:7AE9"!D;W5B;&4@;&EN92!N=6UB97)S(&EN(%-O=7)C92UH:6=H
M;&EG:'0@34E-12!V:65W97(@*$)U9R`C,3,X,RDN"EMM;7-=($9I>"!)34%0
M7U1H<F5A9"!W:&5N(&1E86QI;F<@=VET:"!T:&4@9FER<W0@;65S<V%G92!I
M;B!T:&4@;6%I;&)O>`H@("`@("`H0G5G(",Q,C4W*2X*6V-J:%T@1FEX(&UE
M;G4@:&5I9VAT<R!I;B!3869A<FDN"EMJ86Y=($-A=&-H(&5R<F]R<R!F<F]M
M(&-O;F9I9W5R871I;VX@9FEL97,@=&\@879O:60@8FQA;FL@<&%G97,N"EMJ
M86Y=(%-U<'!O<G0@;6EM95]M86=I8R!E>'1E;G-I;VX@86=A:6X@:68@9FEL
M96EN9F\@:7,@;F]T('!R97-E;G0N"@H*+2TM+2TM"G8S+C`N,PHM+2TM+2T*
M"EMM:G)=($YE=%])35-0(&YO=R!C;W)R96-T;'D@:&%N9&QE<R!A9&1R97-S
M8F]O:R!N86UE<R!C;VYT86EN:6YG('-P86-E<PH@("`@("`H0G5G(",Q,C@V
M*2X*6V-J:%T@26UP;&5M96YT(&-L96%R*"D@:6X@=&AE($Q$05`@<')E9G,@
M9')I=F5R("A"=6<@(S$S,S4I+@I;8VIH72!$;VXG="!L:7-T('5N:6YS=&%L
M;&5D(&%P<&QI8V%T:6]N<R!A<R!I;FET:6%L7V%P<&QI8V%T:6]N(&]P=&EO
M;G,*("`@("`@*$)U9R`C,3,R-"DN"EMJ86Y=($9I>"!P;W-T875T:&5N=&EC
M871E(&AO;VLL(&YO="!C;VUP;&5T96QY(&1E;GEI;F<@86-C97-S(&%F=&5R
M(&$@9F%I;&5D"B`@("`@(&QO9VEN("A"=6<@(S$S,C`I+@I;:F%N72!#:&5C
M:V)O>&5S(&EN('!O<G1A;"!B;&]C:R!S971U<"!F;W)M<R!A<F4@8V]R<F5C
M=&QY(&-H96-K960@;F]W"B`@("`@("A"=6<@(S$R-#<I+@I;;6US72!!;&QO
M=R!)34%0('-E87)C:&5S('1O('=O<FL@;VX@:&5A9&5R<R!W:71H(&UU;'1I
M<&QE(&5N=')I97,*("`@("`@*&MO;&)`8FET;&%B+FAU*2`H0G5G(",Q,S,P
M*2X*6VUM<UT@0V]R<F5C=&QY('-O<G0@24Y"3U@@<W5B9F]L9&5R<R!I;B!)
M34%07U-O<G0@*$)U9R`C,3(Y,2DN"EMC:FA=(%1U<FX@;V9F($9O<FT@5&]K
M96YS(&EN('1H92!C;VYF:6=U<F%T:6]N(&EN=&5R9F%C92X*6VIA;ET@4V]R
M="!U<V5R(&%N9"!G<F]U<"!L:7-T<R!I;B!P97)M:7-S:6]N<R!I;G1E<F9A
M8V4@*$)U9R`C,3,P-2DN"EMJ86Y=($%L;&]W('1O(&5N=&5R(%!(4"!C;V1E
M(&EN('1H92!S97-S:6]N('1I;65O=70@8V]N9FEG=7)A=&EO;B`H0G5G(",Q
M,S`R*2X*"@HM+2TM+2TM+2TM"G8S+C`N,RU20S$*+2TM+2TM+2TM+0H*6VUM
M<UT@1FEX(&)U9R!I;B!497AT7T9L;W=E9"!W:&5R92!U;G%U;W1E9"!L:6YE
M<R!C;W5L9"!N;W0@8F4@9FQO=V5D+@I;8VIH72!&:7@@;&]G:6,@<')O8FQE
M;7,@=VET:"!T:&4@37E344P@86YD($]#23@@<V5S<VEO;B!H86YD;&5R<R!T
M:&%T"B`@("`@('!R979E;G1E9"!T:&5M(&9R;VT@:&%N9&QI;F<@<F5S=&%R
M=&EN9R!A('-E<W-I;VX@8VQE86YL>2`H0G5G(",Q,#DW*2X*6V-J:%T@1FEX
M('!E<G-I<W1E;F-E(&]F("1C;VYF6R=M86EL97(G75LG<&%R86US)UU;)V%U
M=&@G72!I;B!T:&4@4V5T=7`@54D*("`@("`@*$)U9R`C,3(X-RDN"EMJ86Y=
M($EM<')O=F4@<&5R9F]R;6%N8V4@;V8@1&%T851R964@;W!E<F%T:6]N<R!L
M:6ME(')E861I;F<@96UA:6P@;65S<V%G90H@("`@("!H:7-T;W)I97,N"EMJ
M86Y=($QO9R!S=6-C97-S9G5L(&QO9VEN<R!A;F0@;&]G;W5T<R!W:71H('1H
M92!.3U1)0T4@;&5V96P@*%9I;&EU<R!3=6US:V%S"B`@("`@(#QV:6QI=7-`
M;&YK+FQT/BDN"EMC:FA=($5N8V]D92!(5$U,(&5N=&ET:65S(&EN($AO<F1E
M7T9O<FU?5'EP95]L;VYG=&5X="!D:7-P;&%Y("A"=6<@(S$R-C<I+@I;;6US
M72!&:7@@<V5S<VEO;B!H86YD;&EN9R!T;R!E;G-U<F4@=F%R:6%B;&5S(&%R
M92!P97)S:7-T96YT(&%C<F]S<R!F=6YC=&EO;@H@("`@("!C86QL<R`H1V%R
M>2!7:6YD:&%M(#QW:6YD:&%M9T!E;6%I;"YA<FEZ;VYA+F5D=3XI+@I;;6US
M72!);7!R;W9E;65N=',@=&\@5V5B0U!0($U)345?5FEE=V5R(')E;F1E<F5D
M(&]U='!U="X*6VUM<UT@36]R92!F:7AE<R!F;W(@55),<R!W:71H("<F86UP
M)R!W:&5N('!A<W-I;F<@=&AR;W5G:"!T:&4@<V%N:71I>F5R+@I;:F%N72!-
M86ME('=R87!P:6YG(&UE;G5S(&QO;VMI;F<@;FEC97(@:6X@1V5C:V\@86YD
M($M(5$U,(&)A<V5D(&)R;W=S97)S+@I;:F%N72!&:7@@34E-12!V:65W97(@
M9F]R(&=Z:7`@9FEL97,@=&AA="!D;VXG="!C;VYT86EN('1A<B!F:6QE<RX*
M6V-J:%T@1FEX('9I<VEB:6QI='D@;V8@/&$@/B!T86=S(&EN<VED92!S;6%L
M;&AE861E<B!B;&]C:W,@9F]R('1H92!#;W)N9FQO=V5R"B`@("`@('1H96UE
M("A"=6<@(S$R,#8I+@I;8VIH72!$;R!N;W0@8V%C:&4@:F%V87-C<FEP="!S
M97)V960@=FEA('-E<G9I8V5S+VIA=F%S8W)I<'0N<&AP("A"=6<@(S$Q-#`I
M+@I;8VIH72!&:7@@;6%N86=E;65N="!O9B!C871E9V]R:65S('1H870@8V]N
M=&%I;B!Q=6]T97,@*$)U9R`C,3(P,BDN"EMC:FA=($AA;F1L92!A9&1R97-S
M97,@=&AA="!A<F4@86QR96%D>2!S=7)R;W5N9&5D(&)Y('%U;W1E<R!I;@H@
M("`@("!-24U%.CI?<F9C.#(R16YC;V1E*"D@*$)U9R`C,3$T,RDN"EMC:FA=
M($9I>"!60U]S=FXG<R!H86YD;&EN9R!O9B!D:7)E8W1O<GD@;F%M97,@=VET
M:"!S<&%C97,@*$)U9R`C,3$R,RDN"EMC:FA=($9I>"!C86-H:6YG(&QO9VEC
M('1H870@=V%S(&-A=7-I;F<@5D,@=&\@;F]T('!R;W!E<FQY(')E9G)E<V@@
M;V)J96-T<R!I;@H@("`@("!A('1I;65L>2!M86YN97(N"EMJ86Y=($%L;&]W
M('1O('-E="!F:7AE9"!T86)L92!C96QL('=I9'1H<R!I;B!765-)5UE'(&5D
M:71O<BX*"@HM+2TM+2T*=C,N,"XR"BTM+2TM+0H*6V-J:%T@36%K92!S=7)E
M(&YO="!T;R!T:')O=R!E<G)O<G,@=VAE;B!B860@96UA:6QS(&%R92!S=7!P
M;&EE9"!I;@H@("`@("!S97)V:6-E<R]P<F]B;&5M+G!H<"`H0G5G(",Q,#<P
M*2X*6VIA;ET@1FEX('=R;VYG(&-H87)S970@;V8@<F5F<F5S:&5D(&UE;G4@
M9G)A;64@:68@;F]T('5S:6YG(%541BTX("A"=6=S"B`@("`@(",Q,#4R+"`C
M,3`U-2DN"EMJ86Y=($9I>"!L969T(&UE;G4@=')E92!C;VQL87!S:6YG(&%F
M=&5R(&5A8V@@<F5F<F5S:"`H0G5G(",Q,#<R*2X*6VIA;ET@1FEX('-I9&5B
M87(@8F5I;F<@;&]A9&5D('1W:6-E(&EF(&YO="!U<VEN9R!C;V]K:65S("A"
M=6<@(S$P-S8I+@H*"BTM+2TM+0IV,RXP+C$*+2TM+2TM"@I;:F%N72!497-T
M(&9O<B!S97-S:6]N+F%U=&]?<W1A<G0N"EMM;7-=($9I>"!P87)S:6YG(&]F
M(&AE861E<B!W:71H('5N9&ES8VQO<V5D+7)E8VEP:65N=',@*$)U9R`C,3`U
M-RDN"EMC:FA=($%D9"!A(&)R;W=S97(@<75I<FL@9F]R(&)R;W=S97)S('1H
M870@9&]N)W0@<W5P<&]R="!O=F5R9FQO=SIH:61D96X@:6X*("`@("`@=&%B
M;&4@8V5L;',@*$M(5$U,*2X*6VIA;ET@1FEX(&%P<&QI8V%T:6]N(&QI;FMS
M(&EF(&YO="!U<VEN9R!C;V]K:65S("A"=6<@(S$P,CDI+@I;;6US72!&:7@@
M9&ES86)L:6YG(&]F(&UA:6YT96YA;F-E(&-O;F9I<FUA=&EO;G,@*$)U9R`C
M,3`R-RDN"EMC:FA=($9I>"!A;&EG;FUE;G0@;V8@2&5L<"!W:6YD;W<@:&5A
M9&5R(&EN($U3244@*$)U9R`C,3`R,RDN"EMC:FA=($9I>"!T:&4@2&]R9&5?
M0FQO8VL@9W)A<&AI8W,@=&\@8F4@:6YD97AE9"P@;F]T(&=R87ES8V%L92`H
M0G5G(",Q,#4Q*2X*6V-J:%T@4T5#55))5%DZ($-L;W-E('-E=F5R86P@6%-3
M('9U;&YE<F%B:6QI=&EE<RX*6VUM<UT@36%K92!S=7)E(&5X=&5R;F%L(%52
M3"=S('=O<FL@8V]R<F5C=&QY('=H96X@=&AE(%523"!C;VYT86EN<R`G)F%M
M<"<@87,*("`@("`@=&AE(&1E;&EM:71E<BX*6V-J:%T@1FEX(&EN9FEN:71E
M(&QO;W`@=VET:"!!=71H7V%P<&QI8V%T:6]N(&1R:79E<B`H0G5G(",Q,#`T
M*2X*6V-J:%T@3F5V97(@<V5T(&%N(&5M<'1Y($AO<F1E7U1R964@8V]O:VEE
M("A"=6<@(S$P,C(I+@I;;6US72!&:7@@9&ES<&QA>6EN9R!O9B!F;VQD97)S
M(&EN($E-05!?5')E93HZ(&9O<B!)34%0('-E<G9E<G,@=&AA="!D;VXG="!U
M<V4*("`@("`@)TE.0D]8)R!A<R!T:&5I<B!D96QI;6ET97(@*$)U9R`C,3`Q
M-"DN"EMC:FA=($A/4D1%7TU%3E5?34%32U].3TY%(&YO=R!R96%L;'D@;65A
M;G,@;VYL>2!E>'!L:6-I=&QY(&%D9&5D(&UE;G4@:71E;7,*("`@("`@87)E
M(&1I<W!L87EE9"X*6V-J:%T@26=N;W)E($@S(&EN('9E<G-I;VX@8V]M<&%R
M:7-O;G,@*$)U9R`C,3`Q-RDN"EMC:FA=($1A=&%4<F5E7VYU;&P@;F]W('-T
M=6)S(&]U="!T:&4@9G5L;"!$871A5')E92!!4$D@=&\@879O:60@9F%T86P@
M97)R;W)S"B`@("`@('=H96X@;F]T('5S:6YG(&$@<&5R;6%N96YT(&)A8VME
M;F0N"EMJ86Y=($9I>"!D96QE=&EN9R!O9B!I9&5N=&ET:65S("A"=6<@(S$P
M,3@I+@H*"BTM+2T*=C,N,`HM+2TM"@I;8VIH72!4<GD@=&\@8V%T8V@@9&%N
M9V5R;W5S(%523',@:6X@=&AE(&1E<F5F97)R97(@*&=O+G!H<"DN"EMC:FA=
M($EM<')O=F4@=')E92!G<F%P:&EC<R!F;W(@<FEG:'0M=&\M;&5F="!L86YG
M=6%G97,@*%9A:&ED($=H869A<G!O=7(*("`@("`@/'9A:&ED0&=H869A<G!O
M=7(N8V]M/BDN"EMM;7-=($9I>"!)34%07U1R964@9&ES<&QA>2!I9B!F;VQD
M97(@8V]N=&%I;G,@=&AE('1E>'0@)W!O<#,G+@I;8VIH72!&:7@@=&AE($AO
M<F1E7T9O<FT@9&%T92!P:6-K97(@<&]P=7`@:6X@2V]N<75E<F]R+U-A9F%R
M:2`H0G5G(",Y-C,I+@I;:F%N72!3<&%C97,@:6X@=')E92!V:65W<R!W:71H
M($EN=&5R;F5T($5X<&QO<F5R(&AA=F4@8F5E;B!F:7AE9"X*"@HM+2TM+2TM
M+0IV,RXP+5)#,PHM+2TM+2TM+0H*6V-J:%T@06QW87ES(')E;&]A9"!F<F%M
M97-E="!A9G1E<B!L;V=G:6YG(&EN("A"=6<@(S@Q-"DN"EMC:FA=($9I>"!M
M96YU(')E;F1E<FEN9R!F;W(@244@-2XP+TUA8RX*6V-J:%T@5'5R;B!O9F8@
M4$Y'('1R86YS<&%R96YC>2!F;W(@244@8GD@9&5F875L="X*6V-J:%T@06QL
M;W<@=&\@<&%S<R!A;B!A<G)A>2!O9B!A='1R:6)U=&5S('1O($AO<F1E.CII
M;6<H*2X*6V-J:%T@06QL;W<@=&\@<V5T(&$@<&%S<W=O<F0@9F]R('1H92!A
M=71O(&%U=&AE;G1I8V%T:6]N(&1R:79E<BX*6VIA;ET@061D(&]P=&EO;B!F
M;W(@;G5L;"!D<FEV97(@=&\@;6%I;&5R(&-O;F9I9W5R871I;VXN"EMJ86Y=
M($9I>"!C;VYF:6=U<F%T:6]N(&]F(%I04R!C86-H92X*6VIA;ET@1FEX('-O
M;64@:F%V87-C<FEP="!E<G)O<G,@=VET:"!)12`U+C`N"EMC:FA=(%1H92`B
M2&]R9&4@4'5R<&QE(B!T:&5M92!I<R!N;W<@<VEM<&QY(&%N;W1H97(@=&AE
M;64@=&AA="!I;FAE<FET<R!F<F]M"B`@("`@('1H92!G;&]B86P@0U-3('-E
M='1I;F=S+"!I;G-T96%D(&]F(&)E:6YG(&)O=&@@=&AE('!A<F5N="!T:&5M
M92!A<R!W96QL"B`@("`@(&%S(&$@=7-E<BUC:&]O<V5A8FQE(&]P=&EO;BX@
M(%1H92!D969A=6QT(&=R87!H:6-S(&%R92!N;W<@:6X@80H@("`@("!T;W`M
M;&5V96P@=&AE;65S+V=R87!H:6-S(&1I<F5C=&]R>2!A<R!W96QL(&9O<B!U
M<V4@8GD@86QL('1H96UE<RX*"@HM+2TM+2TM+0IV,RXP+5)#,@HM+2TM+2TM
M+0H*6VIA;ET@4VAO=R!T86(@=VET:"!T:&4@9FEE;&0@=&AA="!D:61N)W0@
M=F%L:61A=&4@;VX@<W5B;6ET=&5D(&9O<FUS+@I;;6US72!!9&0@82!G96YE
M<FEC($U)345?5FEE=V5R('1H870@=VEL;"!D:7-P;&%Y('1H92!R87<@=&5X
M="!O9B!T97AT+RH*("`@("`@<&%R=',@=&AA="!W92!D;R!N;W0@:&%V92!A
M('-P96-I9FEC('9I97=E<B!F;W(N"@H*+2TM+2TM+2T*=C,N,"U20S$*+2TM
M+2TM+2T*"EMC:FA=(%5S92!(3U)$15]-14Y57TU!4TM?*B!C;VYS=&%N=',@
M9F]R(&1E=&5R;6EN:6YG('=H870@;&EN:W,@87)E('-H;W=N"B`@("`@(&]N
M(&UE;G5S+@I;:F%N72!#<F5A=&4@9&5F875L="!P87)A;65T97)S('=H96X@
M861D:6YG(&$@;F5W(&)L;V-K('1O('1H92!P;W)T86PN"EMM;7-=($%U=&]D
M971E8W0@97AA8W0@=F5R<VEO;B!O9B!)12`H-2XP*RD@;VX@;&]G:6X@86YD
M('1U<FX@;V9F(&-O;7!R97-S:6]N"B`@("`@(&]N;'D@9F]R(&)U9V=Y('9E
M<G-I;VYS+@I;8VIH72!5<V4@86X@244@8F5H879I;W(@9F]R(&AA;F1L:6YG
M(&%L<&AA('1R86YS<&%R96YC>2!W:71H(%!.1R!I;6%G97,*("`@("`@:6YS
M=&5A9"!O9B!A;B!O;FQO860@:&%N9&QE<BX*6VUM<UT@06QL;W<@86QL(&9O
M;&1E<G,@=&\@8F4@<')E+69E=&-H960@=VAE;B!I;G1I86QI>FEN9R!)34%0
M7U1R964Z.BX*6VUM<UT@061D960@97AT96YS:6]N<R!T;R!T:&4@9F]R;2!R
M96YD97)E<B!F;W(@=&AE(&9I;&4@<V5L96-T:6]N($%022X*6V-J:%T@4F5N
M9&5R(&%L;"!M96YU<R!A<R`\=6P^('1A9W,L(&9O<FUA='1E9"!W:71H($-3
M4RX*6VUM<UT@061D960@97AA;7!L92!O9B!?:6UP7VAO;VM?<W!A;5]B;W5N
M8V4@=&\@8V]N9FEG+VAO;VMS+G!H<"YD:7-T+@H*"BTM+2TM+2TM+0IV,RXP
M+4)%5$$*+2TM+2TM+2TM"@I;8VIH72!!;&QO=R!T;R!I;G-E<G0@:6UA9V5S
M(&9R;VT@9V%L;&5R:65S(&EN('1H92!765-)5UE'($A434P@961I=&]R("A$
M=6-K"B`@("`@(#QD=6-K0&]B86QA+FYE=#XL(%)O96P@1VQO=61E;6%N<R`\
M<F]E;$!G;&]U9&5M86YS+FEN9F\^*2X*6VUD:ET@06QL($AO<F1E(&EC;VYS
M(&-H86YG960@9G)O;2!'248@=&\@4$Y'+@I;;61J72!!9&0@+W1H96UE<R!D
M:7)E8W1O<GD@86YD(&=R;W5P(&%L;"!O9B!E86-H('1H96UE)W,@9FEL97,@
M=6YD97(@82!S=6)D:7(*("`@("`@;V8@=&AI<R!D:7)E8W1O<GDN"EMJ86Y=
M(%-W:71C:"!F<F]M(&1Y;F%M:6,@=&\@<W1A=&EC($-34R!F:6QE<RX*6VUM
M<UT@061D('-U<'!O<G0@9F]R($UE<W-A9V4@1&ES<&]S:71I;VX@3F]T:69I
M8V%T:6]N<R`H4D9#(#(R.3@I+@I;:F%N72!!9&0@5&%B;&5/<&5R871I;VYS
M+"!#;VYT97AT365N=2!A;F0@3&ES=%1Y<&4@<&QU9VEN<R!T;R!R:6-H('1E
M>'0*("`@("`@961I=&]R+@I;:F%N72!!9&0@1&%T851R964@8G)O=W-E<B!T
M;R!A9&UI;B!I;G1E<F9A8V4N"EMC:FA=(%1H92!(;W)D95]#86-H93HZ($%0
M22!H87,@8F5E;B!C;VUP;&5T96QY(')E=W)I='1E;B!T;R!T86ME"B`@("`@
M(&%D=F%N=&%G92!O9B!T:&4@;F5W(%I04S0@87!I(&9O<B!C;VYT96YT(&-A
M8VAI;F<L('=H:6-H(&%L;&]W<PH@("`@("!A(&UO<F4@9F%M:6QI87(@8V%C
M:&EN9R!!4$D@;W9E<F%L;"X@5&AE(&]L9"!Z<',@9')I=F5R(&AA<R!B965N
M"B`@("`@(&1R;W!P960@8F5C875S92!O9B!T:&ES+@I;:F%N72!!9&0@4&5R
M<VEA;B`H5V5S=&5R;BD@=')A;G-L871I;VX@*%9A:&ED($=H869A<G!O=7(*
M("`@("`@/'9A:&ED0&=H869A<G!O=7(N8V]M/BDN"EMJ86Y=($1R;W`@=7-A
M9V4@;V8@87)G7W-E<&%R871O<BYO=71P=70N"EMJ86Y=($UA:V4@<VED96)A
M<B!W:61T:"!A('!R969E<F5N8V4@*%)I8VL@16UE<GD@/')I8VM`96UE<GDN
M:&]M96QI;G5X+FYE=#XI+@I;8VIH72!4:&4@4')E9G-?<W%L(&1R:79E<B!N
M;W<@=7-E<R!$0CHZ<')E<&%R92]$0CHZ97AE8W5T92!F;W(@8F5T=&5R('-U
M<'!O<G0*("`@("`@;V8@;&%R9V4@9FEE;&1S(&]N(&1A=&%B87-E(&)A8VME
M;F1S('-U8V@@87,@3W)A8VQE+@I;8VIH72!3=7!P;W)T(&-U<W1O;2!F:65L
M9"!M87!P:6YG<R!I;B!#4U8@97AP;W)T<RP@86YD(&%D9"!A;B!/=71L;V]K
M(&5X<&]R=`H@("`@("!T>7!E+@I;8VIH72!4:&4@2&]R9&4@<VED96)A<B!M
M96YU(&ES(&YO=R!B=6EL="!W:71H($AO<F1E7U1R964N"EMJ86Y=(%-%0U52
M2519.B!#;&]S92!A;B!84U,@:&]L92!I;B!T:&4@2%1-3"!V:65W97(L(&$@
M=F%R:6%T:6]N('1O('1H92!O;F4*("`@("`@<F5P;W)T960@:6X@:'1T<#HO
M+W=W=RYG<F5Y;6%G:6,N8V]M+W-E8W5R:71Y+V%D=FES;W)I97,O9VTP,#4M
M;6,O+@I;:F%N72!!9&0@8V]N9FEG=7)A=&EO;B!O<'1I;VX@=&\@96YA8FQE
M(%-33"!F;W(@;&]G:6YS(&]N;'DN"EMJ86Y=(%)E;6]V92!S:&%R92!T>7!E
M("AP<FEV871E+W!U8FQI8RDN"EMJ86Y=($%D9"!F<F%M97=O<FL@=&\@8VQE
M87(@;W5T('5S97(@9&%T82P@92YG+B!W:&5N(')E;6]V:6YG('5S97)S+@I;
M:F%N72!!9&0@86-C97-S(&ME>7,N"EMJ86Y=($1O;B=T(')E<75I<F4@8FQO
M8VMS('1O(&)E(')E9VES=&5R960@:6X@=&AE(&%P<&QI8V%T:6]N<R<@05!)
M<RX*6V-J:%T@26YT<F]D=6-E(&$@)U]D969A=6QT7R<@8V]L;W(@86YD(&)E
M='1E<B!H86YD;&EN9R!O9B!U<V5R+7-P96-I9FEE9`H@("`@("!5;F9I;&5D
M(&-O;&]R<RX*6VIA;ET@06QL;W<@=&AE;65S('1O('5S92!T:&5I<B!O=VX@
M:6-O;B!S971S+@I;8VIH72!#871E9V]R:65S(&%N9"!C871E9V]R>2!C;VQO
M<B!L86)E;',@87)E(&YO=R!H86YD;&5D(&=L;V)A;&QY(&)Y($AO<F1E+`H@
M("`@("!A;F0@<')O=FED960@=&\@86QL(&%P<&QI8V%T:6]N<R!T:&%T('5S
M92!T:&5M+@I;:F%N72!)9&5N=&ET:65S(&%R92!N;W<@;6%N86=E9"!W:71H
M('1H92!P<F5F97)E;F-E<R!C;V1E(&%N9"!C86X@8F4@86-C97-S960*("`@
M("`@9G)O;2!E=F5R>2!A<'!L:6-A=&EO;BX*6VUM<UT@2&%N9&QE(%)&0R`R
M,C,Q(&5N8V]D960@<&%R86UE=&5R('9A;'5E<RX*6VUM<UT@061D($E-05!?
M4V]R="!C;&%S<R!T;R!P<F]V:61E('-O<G1I;F<@9F]R($E-05`@;6%I;&)O
M>"!L:7-T<RX*6VIA;ET@061D('5S97(@;6%N86=E;65N="!T;R!)34%0(&%U
M=&AE;G1I8V%T:6]N(&1R:79E<BX*6VIA;ET@061D($E-05!?061M:6X@8VQA
M<W,@=&\@;6%N86=E($E-05`@;6%I;&)O>&5S+@I;;6US72!!9&1E9"!A(&=E
M;F5R:6,@=&5X="]H=&UL($U)345?5FEE=V5R(&1R:79E<B!F;W(@86QL($AO
M<F1E(&%P<&QI8V%T:6]N<PH@("`@("!T:&%T(&%T=&5M<'1S('1O('-A;FET
M:7IE(&UA;&EC:6]U<R!C;V1E(&AI9&1E;B!I;B!(5$U,+@I;;6US72!!9&1E
M9"!A(&=E;F5R:6,@;65S<V%G92]R9F,X,C(@34E-15]6:65W97(@9')I=F5R
M+@I;8VIH72!296UO=F4@2$]21$5?3$E"4R!C;VYS=&%N="!A;F0@87-S=6UE
M(&QI8G)A<FEE<R!A<F4@:6X@=&AE(&EN8VQU9&5?<&%T:"X*6VIA;ET@061D
M('-E87)C:&EN9R!A;F0@<&%G:6YG('1O('1H92!U<V5R(&%D;6EN:7-T<F%T
M:6]N(&EN=&5R9F%C92`H2F]E;`H@("`@("!686YD86P@/&IV86YD86Q`:6YF
M;W1E8VLN<6,N8V$^*2X*"@HM+2TM+2TM+2TM"G8S+C`M04Q02$$*+2TM+2TM
M+2TM+0H*6VIA;ET@06-C97-S(&ME>7,@87)E(&YO(&QO;F=E<B!G96YE<F%T
M960@875T;VUA=&EC86QL>2!B=70@9&5F:6YE9"!B>2!T:&4*("`@("`@9&5V
M96QO<&5R<R!A;F0@=')A;G-L871O<G,N"EMC:FA=(%1H92!N97<@<V5R=FEC
M97,O<')E9G,N<&AP(&9I;&4@:7,@;F]W('1H92!O;FQY(%5)('!A9V4@;F5C
M97-S87)Y"B`@("`@(&9O<B!P<F5F97)E;F-E<R!F;W(@86QL(&%P<&QI8V%T
M:6]N<R`M(&%L;"!A<'`O<')E9G,N<&AP(&9I;&5S"B`@("`@(&%R92!N;W<@
M;V)S;VQE=&4N"EMC:FA=(%!R969S.CIG9710<F5F*"D@:&%S(&)E96X@9&5P
M<F5C871E9"!A;F0@:7,@;F\@;&]N9V5R('!R97-E;G0N"EMC:FA=($AO<F1E
M.CHL(%)E9VES=')Y.CHL(&%N9"!T:&4@;&%S="!O9B!T:&4@;&EB<R!T:&%T
M(&%R92!M;W9I;F<@<VAO=6QD(&)E"B`@("`@(&UO=F5D('1O(&9R86UE=V]R
M:R!P86-K86=E<R!N;W<N"EMC:FA=($5D:71O<CHZ+"!-96YU+G!H<"P@3DQ3
M.CHL(&%N9"!3:6=N=7`N<&AP(&AA=F4@86QL(&)E96X@;6]V960@=&\*("`@
M("`@9G)A;65W;W)K('!A8VMA9V5S+@I;;6US72!-;W9E9"!T:&4@24U!4"!4
M<F5E(&=E;F5R871I;VX@8VQA<W,@9G)O;2!)35`@=&\@9G)A;65W;W)K('-O
M(&ET(&-A;@H@("`@("!B92!U<V5D(&)Y(&]T:&5R(&%P<&QI8V%T:6]N<RX*
M6VUD:ET@4V5T=7`@;F]W(&AA<R!A(&UO<F4@:6YF;W)M871I=F4@9F]R;6%T
M+B!4:&4@0U93('9E<G-I;VX@=&%G(&ES(&-O<&EE9`H@("`@("!F<F]M('1H
M92!C;VYF+GAM;"!F:6QE(&EN=&\@=&AE(&-O;F8N<&AP(&9I;&4@<V\@=&AA
M="!I="!B92!U<V5D('1O('=A<FX*("`@("`@=VAI8V@@87!P;&EC871I;VYS
M(&YE960@=&AE:7(@8V]N9B!U<&1A=&5D+@I;8VIH72!5<V4@:F%V87-C<FEP
M="!T;R!A=71O9&5T96-T('=H971H97(@;W(@;F]T('1H92!F<F%M97-E="!I
M<R!P<F5S96YT+@I;8VIH72!(;W)D95](:7-T;W)Y+"!(;W)D95],:6YK<RP@
M86YD($AO<F1E7U-E87)C:"!H879E(&)E96X@;6]V960@=&\*("`@("`@9G)A
M;65W;W)K('!A8VMA9V5S+@I;8VIH72!!;&QO=R!A<'!S(&EN8VQU9&EN9R!H
M;W)D92]L:6(O8F%S92YP:'`@=&\@<W!E8VEF>2!T:&%T(&$@9&EF9F5R96YT
M"B`@("`@(')E9VES=')Y(&%P<&QI8V%T:6]N('-H;W5L9"!A8W1U86QL>2!B
M92!P=7-H960@;VYT;R!T:&4@4F5G:7-T<GD*("`@("`@87!P;&EC871I;VX@
M<W1A8VLN(%1H:7,@;&5T<R!T:&4@9FEC=&EO;B!O9B!P<F]B;&5M+G!H<"!B
M96EN9R!I=',*("`@("`@;W=N(&%P<&QI8V%T:6]N('!L87D@;FEC96QY('=I
M=&@@=&AE(&YE=R!P97)M:7-S:6]N<R!C:&5C:VEN9RX*6V-J:%T@5&AE(&YE
M=R!A<'!L:6-A=&EO;B!P97)M:7-S:6]N<R!C:&5C:VEN9R!H87,@8F5E;B!M
M;V1I9FEE9"!T;PH@("`@("!A;&QO=R!A8V-E<W,@=&\@86QL(&%U=&AE;G1I
M8V%T960@=7-E<G,@8GD@9&5F875L="P@86YD('1O(&1E;GD*("`@("`@9W5E
M<W0@86-C97-S(&)Y(&1E9F%U;'0N($%L;"!V87)I871I;VYS(&]N('1H870@
M;75S="!B92!S970*("`@("`@97AP;&EC:71L>2X*6V-J:%T@4F5M;W9E('1H
M92!'=65S="!397)V:6-E<R!L:6YK.R!I="=S(&)E96X@;V)S;VQE=&5D(&)Y
M"B`@("`@("1C;VYF6R=M96YU)UU;)V%L=V%Y<R==+@I;8VIH72!687)I;W5S
M("1N;U]A=71H(&%N9"`D<V5L9E]C;VYT86EN961?875T:"!F;&%G<R!H879E
M(&)E96X@<W1A;F1A<F1I>F5D"B`@("`@(&EN=&\@86X@05542%](04Y$3$52
M(&-O;G-T86YT+"!W:&EC:"!I9B!D969I;F5D('-I9VYA;',@=&AE(&%P<&QI
M8V%T:6]N"B`@("`@('1H870@:70@<VAO=6QD(&YO="!C:&5C:R!P97)M:7-S
M:6]N<R!U<&]N(&-A;&QI;F<@)')E9VES=')Y+3YP=7-H07!P*"DL"B`@("`@
M(&%S('1H92!C86QL:6YG('-C<FEP="!W:6QL(&AA;F1L92!T:&%T(&ET<V5L
M9BP@;W(@:7,@82!S>7-T96TM;&5V96P@8W)O;@H@("`@("!J;V(O<V-R:7!T
M+V5T8RX*6V-J:%T@061D(&%N(&]P=&EO;B!T;R`D<F5G:7-T<GDM/G!U<VA!
M<'`H*2!T;R!S<&5C:69Y('=H971H97(@;W(@;F]T('1O(&-H96-K"B`@("`@
M(&%P<&QI8V%T:6]N('!E<FUI<W-I;VYS+@I;8VIH72!4:&4@)V%L;&]W7V=U
M97-T<R<@<V5T=&EN9RP@86YD("1R96=I<W1R>2T^86QL;W='=65S=',H*2P@
M:&%V92!B965N"B`@("`@(')E;6]V960@:6X@9F%V;W(@;V8@2&]R9&5?4&5R
M;7,@87!P;&EC871I;VX@<&5R;6ES<VEO;G,N"EMM;7-=($%D9&5D('1H92!T
M97AT+W)I8VAT97AT($U)345?5FEE=V5R+@I;:F%N72!);G-T86YT:6%T92!T
M:&4@9VQO8F%L(%!E<FUS(&]B:F5C="!I;B!296=I<W1R>2YP:'`N"EMC:FA=
M($-A=&5G;W)Y(&AA<R!B965N(&UO=F5D('1O(&$@9G)A;65W;W)K('!A8VMA
M9V4L(&%N9"!A;'-O(')E;F%M960*("`@("`@=&\@1&%T851R964@<V\@=&AA
M="!I="!H87,@82!M;W)E(&EN='5I=&EV92!N86UE(&9O<B!T:&4@05!)+@I;
M:F%N72!!9&0@26YD;VYE<VEA;B!L86YG=6%G92`H4VQA;6EN(#QS;&%M:6Y`
M=6YE:BYA8RYI9#XI+@I;:F%N72!!9&0@075T:%]L;V=I;B!C;&%S<RX*6VIA
M;ET@061D($AO<F1E.CIE>'1E<FYA;%5R;"@I+@I;;61J72!097)M<R!I<R!N
M;W<@82!G;&]B86QL>2!A=F%I;&%B;&4@;V)J96-T+"!S970@8GD@=&AE(')E
M9VES=')Y)W,*("`@("`@;&]A9%!E<FUS*"DN"EMJ86Y=($%D9"`B06)O=70B
M('!A9V4@9F]R('1H92!H96QP('-Y<W1E;2X*6VIA;ET@061D(%-/05`@<V5R
M=F5R('1O(%)00R!F<F%M97=O<FLN"EMC:FA=($UO=F4@4')E9G-522!T;R!0
M<F5F<R]522YP:'`@9F]R('!A8VMA9V4@8V]N<VES=&5N8WDN"EMM;7-=($%D
M9&5D($Y,4U]'96])4#HZ('1O(&1O($AO<W1N86UE("T^($-O=6YT<GD@;&]O
M:W5P<RX@($Y,4SHZ('=I;&P@9&\*("`@("`@;&]O:W5P<R!B>2!D969A=6QT
M(&YO=R!U<VEN9R!C;W5N=')Y(%1,1"!C;V1E<RX*6VUI<ET@061D('!R97!R
M;V-E<W,@:&]O:R!F;W(@4VEG;G5P('-Y<W1E;2X*6VIA;ET@36]V92!(;W)D
M95]#3$DL($AO<F1E7T-A8VAE+"!(;W)D95]#:7!H97(L($AO<F1E7T-O;7!R
M97-S+`H@("`@("!(;W)D95]4;VME;B!A;F0@2&]R9&5?571I;"!P86-K86=E
M<R!T;R!T:&4@9G)A;65W;W)K(&UO9'5L92X*6V-J:%T@4F5O<F=A;FEZ92!A
M(&YU;6)E<B!O9B!F:6QE<R!F<F]M('1H92!T;W`@;&5V96P@86YD(&9R;VT@
M=71I;"\@:6YT;R!A"B`@("`@(&YE=R!S97)V:6-E<R\@9&ER96-T;W)Y(&%N
M9"!A(&YU;6)E<B!O9B!S97)V:6-E<R\J('-U8F1I<F5C=&]R:65S+@H@("`@
M("!4:&ES('-H;W5L9"!G:79E('5S(&$@8F5T=&5R(&)A<V4@9F]R(&5X<&%N
M9&EN9R!T:&4@<V5R=FEC97,@<')O=FED960*("`@("`@8GD@=&AE(&-O<F4@
M2&]R9&4@;6]D=6QE(&EN('1H92!F=71U<F4N"EMM87A=($%D9"!S=7!P;W)T
M(&9O<B`\8CX@86YD(#QI/B!T86=S('1O('1H92!(96QP('AM;"!P87)S97(N
M"EMC:FA=($%D9"!T:&4@2&]R9&5?2&ES=&]R>2!!4$DL(&9O<B!S=&]R:6YG
M('1I;65S=&%M<&5D(&5V96YT<R!F;W(*("`@("`@87)B:71R87)Y(&]B:F5C
M=',N"EMC:FA=($AO<F1E7U1E;7!L871E(&YO=R!A;&QO=W,@:68Z(&-O;F1I
M=&EO;G,@;VX@87)R87D@=F%L=65S"B`@("`@("A.=6YO($QO=7)E:7)O(#QN
M=6YO0&-O+G-A<&\N<'0^*2X*6VIA;ET@5&AE(&%D;6EN:7-T<F%T;W(@8V%N
M(&YO=R!F;W)C92!T:&4@9&5F875L="!L86YG=6%G92!I;B!N;',N<&AP"B`@
M("`@("A%=&EE;FYE($=O>65R(#QE=&EE;FYE+F=O>65R0&QI;G5X<75E8F5C
M+F-O;3XI+@I;;61J72!(;W)D95]&;W)M(&YO=R!S=7!P;W)T<R!S971T:6YG
M(&]F(&$@:&5L<"!I8V]N(&QI;FME9"!T;R!H96QP+GAM;"X*6V-J:%T@;6EM
M95]M87!P:6YG+G!H<"!I<R!N;R!L;VYG97(@82!C;VYF:6<@9FEL93L@<F5P
M;&%C960@=VET:`H@("`@("!M:6UE+FUA<'!I;F<N<&AP(&EN<VED92!T:&4@
M34E-12!P86-K86=E+@I;8VIH72!!9&0@1V]O9VQE('-E87)C:"!A<'!L970@
M*$IO92!7:6QS;VX@/&IO92YW:6QS;VY`;6EN9&-A;F1Y+F]R9SXI+@I;:F%N
M72!55$8M."!S=7!P;W)T(&ES(&5N86)L960@8GD@9&5F875L="!N;W<N"EMJ
M86Y=(%1H96UE<R!A<F4@;F]W(&%U=&]M871I8V%L;'D@<F5A9"!F<F]M('1H
M92!C;VYF:6<O=&AE;65S(&1I<F5C=&]R>2X*6V-J:%T@061D('-U<'!O<G0@
M9F]R(&]T:&5R(&MI;F1S(&]F('-E<G9E<G,@86YD(&]T:&5R(&MI;F1S(&]F
M(')E<W!O;G-E<R!T;PH@("`@("!R<&,N<&AP(&%N9"!T:&4@4E!#.CH@05!)
M+@I;:G=M72!!9&0@<W5P<&]R="!F;W(@87!P<F]V:6YG('%U975E9"!S:6=N
M=7`@87!P;&EC871I;VYS+@I;8VIH72!'<F]U<',@8V%N(&YO=R!H879E(&%N
M(&5M86EL(&%D9')E<W,@87-S;V-I871E9"!W:71H('1H96TN"EMC:FA=($UA
M:V4@2&]R9&4M;&5V96P@0FQO8VMS(&-O;F9I9W5R86)L92!T:')O=6=H('1H
M92!R96=I<W1R>2P@86QL;W=I;F<*("`@("`@96%S:65R(&%D9&EN9R!O9B!N
M97<@8FQO8VMS("A*;V4@5VEL<V]N(#QJ;V4N=VEL<V]N0&UI;F1C86YD>2YO
M<F<^*2X*6V-J:%T@0V%T96=O<GE4<F5E(&ES(&YO=R!D97!R96-A=&5D(&EN
M(&9A=F]R(&]F($AO<F1E7U1R964N"EMC:FA=($UO=F4@=&AE(&%D;6EN('!E
M<FUI<W-I;VYS(&%N9"!G<F]U<',@<&%G97,@=&\@=7-E($AO<F1E7U1R964N
M"EMM87A=($%D9"!?8V]M<&%R95!A<W-W;W)D<R@I(&9U;F-T:6]N('1O($%U
M=&A?<W%L('1O(&-O<G)E8W1L>2!C;VUP87)E"B`@("`@(&%L;"!C<GEP=&5D
M('!A<W-W;W)D<R!S:6UI;&%R('1O('1H92!087-S=V0@;6]D=6QE+@I;;6%X
M72!!9&0@8W)Y<'0M9&5S("AW:&EC:"!I<R!T:&4@<V%M92!A<R!C<GEP="DL
M(&-R>7!T+6UD-2P@86YD(&-R>7!T+6)L;W=F:7-H"B`@("`@(&5N8W)Y<'1I
M;VX@='EP97,L('1O(&UA=&-H(%!A<W-W9"!M;V1U;&4N"EMM87A=($%D9"!O
M<'1I;VYA;"!S:&]W7V5N8W)Y<'1I;VX@<&%R86T@=&\@075T:%]S<6PL('1O
M(&UA=&-H(%!A<W-W9"!M;V1U;&4N"EMM;7-=($%D9&5D($E0($%D9')E<W,@
M8VAE8VL@=&\@075T:#HZ875T:&5N=&EC871E*"D@=&\@:6YC<F5A<V4@<V5C
M=7)I='DN"EMJ86Y=(%)E;6]V92!.3%,Z.F1E8VEM86Q&<F]M3&]C86QE*"D@
M86YD($Y,4SHZ9&5C:6UA;%1O3&]C86QE*"DN"EMC:FA=($AO<F1E7U9&4SHZ
M(&ES(&YO=R!61E,Z.B!A9V%I;BP@86YD(&AA<R!N;R!E>'1E<FYA;"!(;W)D
M92!D97!E;F1A;F-I97,N"EMC:FA=(%)O=6YD(&]U="!T:&4@=F%R:6]U<R!S
M:&5L;"!T;V]L<R!W:71H(&$@8V]M;6%N9"!S:&5L;"X*6V-J:%T@061D('-I
M9&5B87(N<&AP(&%N9"!A<'!R;W!R:6%T92!P<F5F<R!E;G1R:65S(&9O<B!U
M<VEN9R!(;W)D92!W:71H('1H90H@("`@("!M96YU(&%S(&$@36]Z:6QL82!S
M:61E8F%R+@I;;6US72!!9&0@24U!4%]#86-H93HZ(&-L87-S('1O(&AA;F1L
M92!C86-H960@24U!4"!S97)V97(@9&%T82X*6V-J:%T@36%K92!G971#871E
M9V]R:65S0GE!='1R:6)U=&5S*"D@;75C:"!M;W)E('-O<&AI<W1I8V%T960@
M+2!I="!C86X*("`@("`@;F]W(&AA;F1L92!A('!R971T>2!M=6-H(&%R8FET
M<F%R>2!L;V=I8R!T<F5E("T@86YD('5S92!I="!T;R!O<'1I;6EZ90H@("`@
M("!(;W)D95]3:&%R93HZ;&ES=%-H87)E<R@I+@I;8VIH72!!9&0@9V5T0V%T
M96=O<FEE<T)Y071T<FEB=71E<R@I+"!A;F0@=7-E(&ET(&EN"B`@("`@($=R
M;W5P.CIG971'<F]U<$UE;6)E<G-H:7!S*"DN"EMC:FA=($%D9"!C;V1E('1H
M870@;&5T<R!A($-A=&5G;W)Y3V)J96-T('-U8F-L87-S(&1E9FEN92!A(&UA
M<'!I;F<@9G)O;2!I=',*("`@("`@:6YT97)N86P@9&%T82!T;R!T:&4@;F5W
M(&AO<F1E7V-A=&5G;W)Y7V%T=')I8G5T97,@=&%B;&4N"EMM;7-=($E-05!?
M4V5A<F-H.CH@;F]W('5S97,@82!)34%07U-E87)C:%]1=65R>3HZ(&]B:F5C
M="!T;R!B=6EL9"!T:&4*("`@("`@86-T=6%L($E-05`@<V5A<F-H+@I;;6US
M72!!9&1E9"!A('-E8W5R92!D96QE=&4@=&5M<"!F:6QE(&]P=&EO;B!T:&%T
M('=I;&P@;W9E<G=R:71E(&%N>2!T96UP(&9I;&4*("`@("`@=VET:"!R86YD
M;VT@9&%T82!B969O<F4@=6YL:6YK:6YG+@I;:F%N72!!9&0@3&%V96YD97(@
M=&AE;64@*%II875R(%)A:&UA;B`\>FEA0'%A;&%C;VTN8V]M/BDN"EMC:FA=
M($AO<F1E7U1E;7!L871E.CH@:7,@;F]W(&-A<&%B;&4@;V8@=')A;G-L871I
M;F<@=&5X="!I;G-I9&4*("`@("`@/&=E='1E>'0^/"]G971T97AT/B!T86=S
M+@I;8VIH72!(;W)D95]-;V)I;&4Z.B!N;W<@<')O<&5R;'D@<W5P<&]R=',@
M;75L=&EP;&4@<W5B;6ET(&5L96UE;G1S(&EN(&9O<FUS+@I;;6%C72!!9&0@
M9V5N97)I8R!#>7)U<R!A=71H(&1R:79E<BP@075T:%]C>7)U<RX*6VUA8UT@
M061D(&]P=&EO;F%L(&5N8W)Y<'1I;VX@<&%R86T@=&\@075T:%]S<6PL('1O
M(&UA=&-H(%!A<W-W9"!M;V1U;&4N"EMJ86Y=($%D9"!N97<@:&]O:W,@*')E
M<&QA8VEN9R!?:&]R9&5?:&]O:U]U<V5R;F%M92D@=&\@8V]N=F5R="!U<V5R
M(&YA;65S"B`@("`@(&9R;VT@=&AE(&)A8VME;F0@=&\@2&]R9&4@86YD(&)A
M8VLN"EMC:FA=($%D9"!A(&YE=R!!4$D@8V%L;"P@075T:#HZ:7-!=71H96YT
M:6-A=&5D*"1R96%L;2`](&YU;&PI+"!F;W(*("`@("`@9&5T97)M:6YI;F<@
M=VAE=&AE<B!O<B!N;W0@82!U<V5R(&ES(&QO9V=E9"!I;B!T;R!T:&4@8W5R
M<F5N=`H@("`@("!R96%L;2`H8GD@9&5F875L="!N=6QL*2X@075T:#HZ9V5T
M075T:"@I(&ES('-T:6QL('5S960@=&\@9V5T"B`@("`@('1H92!C=7)R96YT
M('5S97(L(&)U="!N;W<@>6]U(&1O;B=T(&YE960@=&\@:VYO=R!T:&4@875T
M:"!R96%L;0H@("`@("!T;R!G970@=&AE(&-U<G)E;G0@=7-E<B`M(&IU<W0@
M=&\@8VAE8VL@875T:&5N=&EC871I;VXN"EMC:FA=($1(5$U,(&1A=&4@<&EC
M:V5R(&YO=R!O<&5N<R!R:6=H="!O=F5R('1H92!I;6%G92!U<V5D('1O(&%N
M8VAO<B!I="X*6V-J:%T@5&AE(&QA<W1?;&]G:6X@<')E9F5R96YC92!I<R!N
M;W<@96YT:7)E;'D@:&%N9&QE9"!B>2!(;W)D92X*6VUM<UT@061D($AO<F1E
M7U1E<W0Z.B!C;&%S<R]T96UP;&%T97,@=&\@86ED(&EN(&-R96%T:6YG('1E
M<W0N<&AP('-C<FEP=',N"EMM;7-=($UO=F4@8V]M<&QE>"!)34%0('-E87)C
M:&EN9R!C;V1E(&9R;VT@24U07U-E87)C:#HZ('1O($E-05!?4V5A<F-H.CHN
M"EMC:FA=(%)E+7=O<FL@=&AE($AO<F1E($Q$05`@<V-H96UA(&)I=',@=&\@
M8F4@;6]R92!C;W)R96-T(&%N9`H@("`@("!C;VYS:7-T96YT("A!9&%M(%1A
M=6YO(%=I;&QI86US(#QA9&%M0&UO<G)I<V]N+6EN9"YC;VT^*2X*6VUM<UT@
M061D($1/32!T;V]L=&EP(&-A<&%B:6QI='D@=FEA($AO<F1E.CIL:6YK5&]O
M;'1I<"@I+@I;;6US72!!9&0@9V%R8F%G92!C;VQL96-T:6]N(&-L87-S("A(
M;W)D95]61E-?1T,Z.BD@9F]R(%9&4RX*6VUM<UT@061D('1I;65O=70@=&\@
M4$=0(&ME>7-E<G9E<B!L;V]K=7`N"EMC:FA=($%D9"!N879I9V%T:6]N(&9O
M<B!P<F5V:6]U<R]N97AT('!R969E<F5N8V5S(&)L;V-K(&EN(%!R969S54D*
M("`@("`@*$UA=&AI974@0TQ!0D%55"`\;6%T:&EE=2YC;&%B875T0&9R964N
M9G(^*2X*6V-J:%T@061D($AO<F1E7TQI;FMS($%022`H:BYH=6EN:6YK0'=A
M;F%D;V\N;FPI+@I;8VIH72!!9&0@;6]R92!I;G1R;W-P96-T:6]N+"!I;B!T
M:&4@9F]R;2!O9B!G971#;VYT96YT5'EP92@I(&%N9`H@("`@("!G971,:6YK
M*"DL('1O('1H92!(;W)D95]);6%G93HZ($%022X*6V-J:%T@061D('5T:6PO
M8V%C:&5V:65W+G!H<"!F;W(@=FEE=VEN9R!A;GD@9&%T82!W:71H(&$@0V]N
M=&5N="UT>7!E"B`@("`@('!U="!I;G1O('1H92!C86-H92X*6V-J:%T@061D
M($AO<F1E7T-A8VAE.CIC86-H94]B:F5C="@I(&9O<B!U<V4@:6X@8V%C:&EN
M9R!T:&4@<F5S=6QT<R!O9@H@("`@("!N;VXM<W1A=&EC(&]B:F5C="!M971H
M;V1S+@I;8VIH72!296YA;64@0V%C:&4Z.B!T;R!(;W)D95]#86-H93HZ+@I;
M8VIH72!-;W9E($-A8VAE7W-E<W-I;VXZ.B!T;R!(;W)D95]397-S:6]N3V)J
M96-T<SHZ+@I;;6US72!!9&1E9"!(;W)D93HZ97AT96YS:6]N17AI<W1S*"D@
M=&\@8V%C:&4@97AT96YS:6]N7VQO861E9"@I(&-A;&QS+@I;8VIH72!!9&0@
M3DQ3.CID96-I;6%L5&],;V-A;&4H*2!A;F0@3DQ3.CID96-I;6%L1G)O;4QO
M8V%L92@I('1O(&AA;F1L90H@("`@("!C;VYV97)T:6YG(&)E='=E96X@9&EF
M9F5R96YT(&1E8VEM86P@<&]I;G0@<V5P87)A=&]R<RX*6V-J:%T@061D960@
M34E-15](96%D97)S.CHN"EMM;7-=($UO=F5D(&=Z:7`@86YD('1A<B!F:6QE
M(&AA;F1L:6YG('1O($AO<F1E7T-O;7!R97-S7RHZ.B!M;V1U;&5S+@I;;6US
M72!-;W9E9"!:25`@:&%N9&QI;F<@=&\@=&AE($AO<F1E7T-O;7!R97-S7WII
M<#HZ(&UO9'5L92X*6VUM<UT@36]V960@5$Y%1B!H86YD;&EN9R!T;R!T:&4@
M2&]R9&5?0V]M<')E<W-?=&YE9CHZ(&UO9'5L92X*6VUM<UT@061D960@2&]R
M9&5?0V]M<')E<W,Z.B!!4$D@+2!U<V5D('1O(&-O;7!R97-S+V1E8V]M<')E
M<W,@9&%T82X*6VUD:ET@061D960@=&AE($1/32!C86QE;F1A<B!D871E('!I
M8VME<B!T;R!(;W)D95]&;W)M+"!B87-E9"!O;B!W;W)K(&)Y"B`@("`@($UI
M:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^(&%N9"!"<FEA
M;B!+96EF97(*("`@("`@/&)R:6%N0'9A;&EN;W(N;F5T/BX*6VUM<UT@061D
M960@;75L=&EP87)T+W)E<&]R="!-24U%7U9I97=E<CHZ+@I;;6US72!!9&1E
M9"!-24U%.CIG96YE<F%T94UE<W-A9V5)1"@I('1O(&=E;F5R871E($U)344M
M8V]M<&QI86YT(&UE<W-A9V4@241S+@I;8VIH72!!9&0@8V]M;6%N9"UL:6YE
M('-E='5P+G!H<"!S8W)I<'0N(%)I9VAT(&YO=RP@=&AI<R!O;FQY(&=E;F5R
M871E<R]U<&1A=&5S"B`@("`@(&-O;F9I9W5R871I;VYS.R!Y;W4@8V%N;F]T
M("IE9&ET*B!A(&-O;F9I9W5R871I;VX@=VET:"!I="X*6VIA;ET@061D(%-T
M<FEN9SHZ(&-L87-S('=I=&@@;&]C86QE+V-H87)S970@<V%F92!S=')I;F<@
M9G5N8W1I;VYS+@I;;6US72!!9&1E9"!(;W)D93HZ875T:&5N=&EC871I;VY&
M86EL=7)E4F5D:7)E8W0H*2X*6VUM<UT@061D960@0G)O=W-E<CHZ97-C87!E
M2E-#;V1E*"D@=&\@97-C87!E(&-E<G1A:6X@8VAA<F%C=&5R<R!I;@H@("`@
M("!J879A<V-R:7!T(&-O9&4@9&5P96YD:6YG(&]N('1H92!B<F]W<V5R('1Y
M<&4N"EMJ86Y=($%D9"!.3%,Z.G-T<G1O;&]W97(H*2!A;F0@=7-E(&ET(&5V
M97)Y=VAE<F4@=VAE<F4@;&]C86QE(&EN9&5P96YD86YC90H@("`@("!I<R!N
M96-E<W-A<GDN"EMJ86Y=($%D9"!4=7)K:7-H('1R86YS;&%T:6]N("A'96YC
M;R!9:6QM87H@/&=E;F-O>6EL;6%Z0'EA:&]O+F-O;3XI+@I;;6US72!!9&0@
M)VQI;FLG('!A<F%M971E<B!T;R!T:&4@<')E9F5R96YC97,@8V]N9FEG('1O
M(&%L;&]W(&9O<B!H96QP(&QI;FMS"B`@("`@('1O(&)E(&%D9&5D('1O('1H
M92!P<F5F97)E;F-E<R!P86=E<RX*6VUM<UT@06YO=&AE<B!-86EN=&5N86YC
M93HZ(')E=W)I=&4@+2!N;W<@<W1O<F4@86QL(&1A=&$@:6X@=&AE(&-A8VAE
M9`H@("`@("!-86EN=&5N86YC95]487-K;&ES="!O8FIE8W0N"EMM;7-=($%D
M9&5D(&-H96-K('1O(%!R969S.CH@=&\@96YS=7)E('1H92!D871A('-T;W)E
M9"!D;V5S(&YO="!E>&-E960@=&AE"B`@("`@(&UA>&EM=6T@<W1O<F%G92!S
M:7IE(&]F('1H92!P<F5F97)E;F-E<R!S=&]R86=E('-Y<W1E;2X*6VIA;ET@
M061D(%541BTX('-U<'!O<G0N($%N>2!C;VYT96YT('=I=&@@86YY(&-H87)S
M970@8V%N(&YO=R!B92!D:7-P;&%Y960@=VET:`H@("`@("!A;GD@=')A;G-L
M871I;VXN"EMM;7-=($%D9"!.3%,Z.F-H96-K0VAA<G-E="@I('1O(&1E=&5R
M;6EN92!W:&5T:&5R(&$@9VEV96X@8VAA<F%C=&5R('-E="!I<PH@("`@("!V
M86QI9"!O;B!T:&4@8W5R<F5N="!S>7-T96TN"EMC:FA=($1E<')E8V%T960@
M4F5G:7-T<GDZ.FEN8VQU9&5&:6QE<R@I(&%N9"!296=I<W1R>3HZ<VAU=&1O
M=VXH*2X*6VUM<UT@061D('-U<'!O<G0@:6X@34E-15]-86=I8SHZ('1O('5S
M92!T:&4@54Y)6"!F:6QE(&9U;F-T:6]N('1O(&1E=&5R;6EN90H@("`@("!T
M:&4@34E-12!T>7!E(&]F('5N:VYO=VX@9FEL97,N"EMM;7-=($%D9&5D(&%N
M(&5X86UP;&4@8W)O;B!S8W)I<'0@=&\@9&5L971E(&]L9"!T96UP;W)A<GD@
M9FEL97,N"EMM;7-=($-O<G)E8W1L>2!G970@8VAA<G-E="!I;F9O<FUA=&EO
M;B!F;W(@34E-15]087)T<R!I;B!-24U%7U-T<G5C='5R92X*6VUM<UT@4F5W
M<F]T92!-24U%7TUE<W-A9V4@=&\@97AT96YD($U)345?4&%R="X*6V-J:%T@
M061D(&]R9&5R:6YG(&5X=&5N<VEO;G,@=&\@=&AE($-A=&5G;W)Y.CH@9G)A
M;65W;W)K"B`@("`@("A-87)K;R`\;6%R:V]`;V)L;RYC;VT^*2X*6V-J:%T@
M061D(&$@<VEM<&QE('1E;7!L871E(&5N9VEN92P@9&5R:79E9"!F<F]M(&)4
M96UP;&%T92P*("`@("`@9F]R($AO<F1E(&%P<&QI8V%T:6]N<R!T;R!U<V4N
M"EMC:FA=($%D9"!!=71H7WEA:&]O.CH@=VAI8V@@;&5T<R!Y;W4@:&%V92!N
M;R!L;V-A;"!A=71H(&%N9"!R96QY(&]N"B`@("`@(%EA:&]O(2!M86EL('5S
M97)N86UE<RX*6VUM<UT@36]V960@4V5R=F5R(&-O;F9I9W5R871I;VX@8VAE
M8VMI;F<@9G5N8W1I;VYS('1O(%-E<G9E<CHZ+@I;8VIH72!4:&4@=7-E<B!A
M9&UI;B!P86=E(&-A;B!N;W<@<V5T(&9U;&QN86UE(&%N9"!F<F]M7V%D9'(@
M<')E9F5R96YC97,*("`@("`@9F]R(&%N>2!U<V5R(&%S(&QO;F<@87,@=&AE
M($%U=&@@8F%C:V5N9"!I<R!C87!A8FQE(&]F(&%T(&QE87-T"B`@("`@(&QI
M<W1I;F<@=7-E<G,@*&1O97-N)W0@:&%V92!T;R!B92!A8FQE('1O('5P9&%T
M92!T:&5M*2X*6V-J:%T@4VAA<F4Z.B!I<R!N;W<@2&]R9&5?4VAA<F4Z.BP@
M86YD(&ES(')E=V]R:V5D('1O(&AO;&0@<&5R;6ES<VEO;G,*("`@("`@:6YT
M97)N86QL>2X@5V4@8V%N(&YO=R!A<W-I9VX@9W)O=7`O9&5F875L="]G=65S
M="!P97)M:7-S:6]N<PH@("`@("!M;W)E(&5A<VEL>2X*6VIA;ET@061D(%)0
M0SHZ<&%R<V55<FPH*2X*6VIA;ET@061D(%)00R!B87-E9"!R96UO=&4@<W5M
M;6%R:65S+@I;8VIH72!!9&0@82!344P@4VAE;&P@=&\@=&AE($AO<F1E(&%D
M;6EN('-E8W1I;VXN"EMC:FA=($1O;B=T('!R969I>"!(;W)D92!A9&UI;B!M
M96YU:71E;7,@=VET:"`B2&]R9&4B('1O('-A=F4@<W!A8V4N"EMC:FA=($AO
M<F1E7T9O<FTZ.B!F;W)M<R!N;W<@=7-E('1H92!(;W)D95]4;VME;CHZ($%0
M22!B>2!D969A=6QT('1O"B`@("`@(&UA:V4@<W5R92!T:&%T('1H97D@8V%N
M;F]T(&)E(')E;&]A9&5D+@I;8VIH72!296YA;64@5&]K96XZ.B!T;R!(;W)D
M95]4;VME;CHZ(&9O<B!F=71U<F4@<&%C:V%G:6YG+@I;:F%N72!!9&0@4F5G
M:7-T<GDZ.FQI<W1!4$ES*"D@86YD(%)E9VES=')Y.CIL:7-T365T:&]D<R@I
M+@I;8VIH72!4:&4@4&5R;7,Z.B!S>7-T96T@;F]W('-U<'!O<G1S(&1E9F%U
M;'0@86YD(&=U97-T('!E<FUI<W-I;VYS+@I;8VIH72!!<'!L:6-A=&EO;G,@
M8V%N(&YO=R!P<F]V:61E(&EN9&EV:61U86P@<F5G:7-T<GD@;65T:&]D<RP@
M;F]T(&IU<W0@=VAO;&4*("`@("`@:6YT97)F86-E<RX@07!P;&EC871I;VYS
M(&-A;B!O=F5R<FED92!A('-I;F=L92!M971H;V0@;W5T(&]F(&%N(&EN=&5R
M9F%C90H@("`@("!A<R!W96QL("T@86X@87!P('!R;W9I9&EN9R!A(&UA:6PO
M9FEL=&5R('=H:6QE($E-4"!P<F]V:61E<R!M86EL+RHL(&4N9RX*6V-J:%T@
M4F5N86UE9"!&;W)M4W!R;V-K970Z.B!T;R!(;W)D95]&;W)M.CH@86YD($=R
M87!H4W!R;V-K970Z.B!T;PH@("`@("!(;W)D95]'<F%P:#HZ(&9O<B!C;VYS
M:7-T96YC>2!A;F0@9G5T=7)E(%!%05(@<&%C:V%G:6YG+@I;;6ER72!!9&1E
M9"!E>&%M<&QE(&]F(%]I;7!?:&]O:W-?9F5T8VAM86EL7V9I;'1E<B!T;R!C
M;VYF:6<O:&]O:W,N<&AP+F1I<W0*6VUM<UT@061D960@=&AE($U)345?0V]N
M=&5N=',Z.B!C;&%S<SL@9G5N8W1I;VYS('1O(&AE;'`@:6X@=&AE(&]U='!U
M=`H@("`@("!O9B!-24U%(&-O;G1E;G0N"EMC:FA=(%)E=W)I=&4@=&AE($-A
M=&5G;W)Y.CH@<WES=&5M('1O(&%L;&]W(&UU;'1I<&QE(&QE879E<R!W:71H
M('1H92!S86UE"B`@("`@(&YA;64@*&%S(&QO;F<@87,@=&AE>2!H879E(&1I
M9F9E<F5N="!P87)E;G1S*2!A;F0@<F5W<FET92!E=F5R>71H:6YG"B`@("`@
M("A097)M<SHZ+"!'<F]U<#HZ+"!3:&%R93HZ+"!E=&,N*2!T;R!U<V4@:70N
M"EMC:FA=($UO=F4@7V9I;&5#;&5A;G5P*"D@:6YT;R!(;W)D93HZ(&%S($AO
M<F1E.CID96QE=&5!=%-H=71D;W=N*"DL"B`@("`@(&%N9"!A9&0@2&]R9&4Z
M.E]D96QE=&5!=%-H=71D;W=N*"D@=&\@9&\@=&AE(&%C='5A;"!D96QE=&EN
M9RX*6V-J:%T@26YI=&EA;"!S=7!P;W)T(&9O<B!C;VYF:6=U<FEN9R!T:&4@
M<W5M;6%R>2!S8W)E96X*("`@("`@*$5R:6,@4F5C:&QI;B`\97)I8T!H<&-A
M;&,N;W)G/BDN"EMC:FA=($%D9"!A('-Y<W1E;2!F;W(@9&5F:6YI;F<@9V5N
M97)I8R!H;V]K<R!F;W(@86YY('!R969E<F5N8V4N"B`@("`@(%-E92!H;W)D
M92]C;VYF:6<O:&]O:W,N<&AP+F1I<W0@9F]R(&QO=',@;V8@97AA;7!L97,@
M86YD(&1O8W,N"EMC:FA=($%D9"!A(&-O;&]R<&EC:V5R('5T:6QI='D@=&\@
M2&]R9&4*("`@("`@*$UI8VAA96P@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA
M;&PN8V\N;GH^*2X*6V-J:%T@061D(&$@9W5E<W0@<V5R=FEC97,@96YT<GD@
M<&%G92!A;F0@;&EN:W,@=&\@:70@9G)O;2!A;&P*("`@("`@;&]G:6X@<&%G
M97,N"EMJ86Y=($%D9"!T<F%N<VQA=&EO;B!H96QP97(@<V-R:7!T+@I;;6US
M72!3='EL97-H965T(&QI;FL@9V5N97)A=&EO;B!H86YD;&5D(&)Y($AO<F1E
M.CIS='EL97-H965T3&EN:R@I+@I;8VIH72!!9&0@=&AE(&YE=R!#;VYF:6<Z
M.B!!4$D@86YD('-E='5P+G!H<"P@82!S>7-T96T@=VAI8V@@<F5A9',*("`@
M("`@8V]N9FEG=7)A=&EO;G,@9G)O;2!834P@9FEL97,@86YD(&5X:7-T:6YG
M(&-O;F8N<&AP(&9I;&5S+`H@("`@("!T86MI;F<@8V%R92!O9B!M97)G97,@
M86YD(&%D9&EN9R!N97<@<&%R86UE=&5R<RX@0W5R<F5N=&QY('=E"B`@("`@
M(&AA=F4@82!W96(@=VEZ87)D+@I;8VIH72!C<W,N<&AP(&YO=R!S=7!P;W)T
M<R!L;V%D:6YG($-34R!C;&%S<V5S(&9O<B!M=6QT:7!L92!A<'!L:6-A=&EO
M;G,N"EMM;7-=(%)E;6]V960@=&AE(%-E<W-I;VY#86-H92!C;&%S<RX@17%U
M:79A;&5N="!C;V1E(&ES(&YO=R!A=F%I;&%B;&4@:6X*("`@("`@=&AE($-A
M8VAE7W-E<W-I;VXZ.B!C;&%S<RX*6VUM<UT@061D960@244@8G)O:V5N+6)R
M;W=S97(@9&]W;FQO861I;F<@8V]D92!T;R!"<F]W<V5R.CHN"EMM;7-=($%D
M9&5D(&$@<V5S<VEO;B!D<FEV97(@=&\@0V%C:&4Z.BX*6V-J:%T@4F5N86UE
M(&-O;F9I9R]H;W)D92YP:'`@=&\@8V]N9FEG+V-O;F8N<&AP+@I;8VIH72!-
M;W9E(&-O;VMI95]D;VUA:6XL(&-O;VMI95]P871H+"!S97)V97)?;F%M92P@
M86YD('-E<G9E<E]P;W)T(&EN=&\*("`@("`@:&]R9&4O8V]N9BYP:'`N"EMC
M:FA=($%D9"!A('!A<F%M971E<B!F;W(@<V5T=&EN9R!T:&4@<V5S<VEO;B!C
M86-H95]L:6UI=&5R+@I;8VIH72!!9&0@34E-15]6:65W97)?=&5X="!T;R!(
M;W)D92X*6V-J:%T@4F5W<FET92!A;&P@9F%C=&]R>2]S:6YG;&5T;VX@;65T
M:&]D<R!T;R!A;&QO=R!I;F1I=FED=6%L(&%P<&QI8V%T:6]N<PH@("`@("!T
M;R!P<F]V:61E(&$@8W5S=&]M(&)A8VME;F0L(&%N9"!T;R!A;&QO=R!S:71E
M<R!T;R!P<F]V:61E(&-U<W1O;0H@("`@("!B86-K96YD<R!I;B!T:&5I<B!I
M;F-L=61E7W!A=&@@<V5T=&EN9W,N"EMM;7-=($AA;F1L:6YG(&]F($-O;G1E
M;G0M5'EP92!P87)A;65T97)S(&UO=F5D('1O($U)345?4&%R="!F<F]M($U)
M345?365S<V%G92X*6VUM<UT@0W)Y<'1?<&=P.CH@8V%N(&YO=R!U<&QO860@
M:V5Y<R!T;R!A('!U8FQI8R!K97ES97)V97(N"EMM;7-=(%)E;F%M960@=&AE
M($QA;F<Z.B!C;&%S<R!T;R!.3%,Z.B!A;F0@;6]V960@=&AE('1I;65Z;VYE
M('-E='1I;F<*("`@("`@;65T:&]D(&EN=&\@:70N"EMM;7-=(%1H92!L;V-A
M;"!T:6UE>F]N92!C86X@;F]W(&)E('-E="!V:6$@=&AE($AO<F1E.CIS9714
M:6UE>F]N92@I(&-A;&PN"EMM;7-=($%L;"!B<F]W<V5R(&AE861E<G,@9F]R
M(&1O=VYL;V%D:6YG(&$@9FEL92!H879E(&)E96X@;6]V960@=&\@=&AE"B`@
M("`@($)R;W=S97(Z.B!C;&%S<RX*6V-J:%T@061D(&9I;&5S('1O('5T:6P@
M=&\@<W5P<&]R="!E;6)E9&1I;F<@82!'54D@961I=&]R(&EN=&\@;W5R('!A
M9V5S+@I;;6US72!-24U%.CH@;F\@;&]N9V5R(&5X<&]R=',@)&UI;65?='EP
M97,@86YD("1M:6UE7V5N8V]D:6YG<R!A<R!G;&]B86P*("`@("`@=F%R:6%B
M;&5S("T@<F%T:&5R+"!-24U%.CIT>7!E*"D@86YD($U)344Z.F5N8V]D:6YG
M*"D@<VAO=6QD(&)E('5S960N"EMM;7-=(%1H92!T9WH@34E-15]6:65W97(@
M;F]W(&QI<W1S(&%L;"!F:6QE<R!W:71H;W5T('5S:6YG(&%N(&5X=&5R;F%L
M(&AE;'!E<@H@("`@("!P<F]G<F%M("A-:6-H865L($-O8VAR86YE(#QM:6ME
M0&=R869T;VYH86QL+F-O+FYZ/BDN"EMM;7-=(%1H92!R87(@34E-15]6:65W
M97(@;F]W(&QI<W1S(&%L;"!F:6QE<R!W:71H;W5T('5S:6YG(&%N(&5X=&5R
M;F%L(&AE;'!E<@H@("`@("!P<F]G<F%M("A-:6-H865L($-O8VAR86YE(#QM
M:6ME0&=R869T;VYH86QL+F-O+FYZ/BDN"EMM;7-=(%1H92!Z:7`@34E-15]6
M:65W97(@;F]W(&QI<W1S(&%L;"!F:6QE<R!W:71H;W5T('5S:6YG(&%N(&5X
M=&5R;F%L(&AE;'!E<@H@("`@("!P<F]G<F%M("A-:6-H865L($-O8VAR86YE
M(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/BDN"EMM;7-=($UA:6YT96YA;F-E
M.CH@;F]W('5S97,@<V5S<VEO;B!V87)I86)L97,@=&\@<')O=FED92!M=6-H
M(&-L96%N97(@86YD(&UO<F4*("`@("`@<F]B=7-T('!E<F9O<FUA;F-E+@I;
M;6US72!-4RU43D5&(&%T=&%C:&UE;G1S(&%R92!N;W<@:&%N9&QE9"!C;VUP
M;&5T96QY('9I82!02%`@<F%T:&5R('1H86X@=VET:`H@("`@("!A;B!E>'1E
M<FYA;"!P<F]G<F%M+@I;;6US72!!9&1E9"!A<'!L:6-A=&EO;B]M<RUT;F5F
M($U)345?5FEE=V5R+@I;;6US72!(;W)D95]#<GEP=%]P9W`@8VQA<W,@8V%N
M('%U97)Y('!U8FQI8R!K97ES97)V97)S+@I;;6US72!-24U%7U-T<G5C='5R
M93HZ<&%R<V5-24U%2&5A9&5R<R@I(&-A;B!N;W<@<&%R<V4@86QL(&AE861E
M<G,@;V8@82!-24U%"B`@("`@(&UE<W-A9V4@86YD(')E='5R;B!A;B!O8FIE
M8W0N"EMJ86Y=($%D9"!-24U%.CIR9F,X,C)7<FET94%D9')E<W,H*2!T;R!R
M97!L86-E(&EM87!?<F9C.#(R7W=R:71E7V%D9')E<W,H*2X*6VUM<UT@061D
M960@4R]-24U%($U)345?5FEE=V5R+@I;:F]N72!3=7!P;W)T(')E9F5R<F%L
M<R!B971W965N($Q$05`@<V5R=F5R<R!I;B!T:&4@3$1!4"!P<F5F97)E;F-E
M<R!D<FEV97(*("`@("`@*$ME=FEN($AI;&1E8G)A;F0@/&ME=FEN0&AQ+F5N
M<V]P;W)T+F-O;3XI+@I;8VIH72!-24U%7U-T<G5C='5R93HZ<&%R<V4H*2!N
M;W<@<F5T=7)N<R!A($U)345?365S<V%G92!O8FIE8W0*("`@("`@*$UI8VAA
M96P@32!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/BDN
M"EMC:FA=($-O;F9I9W5R92!A9&UI;FES=')A=&EO;B!S97)V:6-E<R!I;B!T
M:&4@4F5G:7-T<GD*("`@("`@*$UA<F-U<R!)+B!2>6%N(#QM87)C=7-`<FEB
M;V9L879I;BYN970^*2X*6V-J:%T@061D($%022!M971H;V1S(&9O<B!G971T
M:6YG('1H92!P<F5F97)E;F-E<R!A;F0@:61E;G1I=&EE<R!O9B!U<V5R<PH@
M("`@("!O=&AE<B!T:&%N('1H92!L;V=G960M:6X@=7-E<BX*6V-J:%T@06QL
M;W<@<V5T=&EN9R!T:&4@0V]N=&5N="U$:7-P;W-I=&EO;B!O9B!-24U%7U!A
M<G0@;V)J96-T<RX*6V-J:%T@061D($-R>7!T.CH@9G)A;65W;W)K("A-:6-H
M865L($T@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3XI
M+@I;;6%X72!!9&0@0G)O=VX@2&]R9&4@=&AE;64@*$UA<F-O($]B86ED(#QM
M87)C;T!M=7<N961U/BDN"EMJ;VY=($%L;&]W('1H92!,1$%0('9E<G-I;VX@
M=&\@8F4@<W!E8VEF:65D(&9O<B!T:&4@3$1!4"!P<F5F97)E;F-E<R!D<FEV
M97(N"EMJ86Y=($%D9"!T:&5M92!P<F5F97)E;F-E+@I;:F%N72!!9&0@8V%L
M;&)A8VL@9G5N=&EO;B!F;W(@<')E9F5R96YC97,N"EMJ;VY=(%)E;6]V92!T
M:&4@)&-O;F9;)VUE;G4G75LG9FQO871I;F=?8F%R)UT@9G5N8W1I;VYA;&ET
M>2X*6VIA;ET@3&]A9"!O;FQY(&QO9VEN('!A9V4@;VX@<W1A<G1U<"!A;F0@
M<F5D:7)E8W0@=&\@9G)A;65S970@869T97(@;&]G:6XN"EMC:FA=($1O;B=T
M(&%L;&]W(&%N;VYY;6]U<R!A8V-E<W,@=&\@<')O8FQE;2YP:'`N"EMC:FA=
M($%D9"!E;E]'0B!L;V-A;&4N"EMC:FA=(%)E;6]V92!E>'1E;G-I;VYS(&]N
M('1E;7!O<F%R>2!F:6QE<SL@=&AI<R!I<R!A('1E;7`@<F%C92!H;VQE+@I;
M8VIH72!!;&QO=R!F;W(@875T;RUC<F5A=&EO;B!O9B!P97)M:7-S:6]N<R`H
M;75L=&EP;&4@;&5V96QS(&]F(&AI97)A<F-H>2DN"EMC:FA=($%D9"!A9&1I
M;F<O<F5M;W9I;F<@;V8@=7-E<G,@9G)O;2!G<F]U<',N"EMC:FA=($-R96%T
M92!T96UP(&9I;&5S('=I=&@@=&AE(')I9VAT(&5X=&5N<VEO;B!I;B!-24U%
M7U9I97=E<E]E;G-C<FEP=#HZ('-O"B`@("`@(&5N<V-R:7!T(&AA<R!M;W)E
M(&-L=65S('1O(&=U97-S(&9I;&4@='EP92X*6V-J:%T@5&AE(&%D;6EN:6YS
M=')A=&EO;B!I;G1E<F9A8V4@9F]R($=R;W5P<R!A;F0@4&5R;6ES<VEO;G,@
M:7,@;F]W"B`@("`@(&UO<W1L>2!F=6YC=&EO;F%L+@I;8VIH72!-86ME(&%P
M<&QI8V%T:6]N(&%U=&AE;G1I8V%T:6]N(&%N($%U=&@Z.B!D<FEV97(L(&EN
M<W1E860@;V8@82!S<&5C:6%L"B`@("`@(%)E9VES=')Y(&-A<V4N"EMC:FA=
M($9I>"!P<F]B;&5M<R!W:71H('1H92!.;W1I9FEC871I;VX@<W1A8VL@86YD
M(')E9VES=&5R7V=L;V)A;',@8F5I;F<@;V9F+@I;:F]N72!!;'1E<B!(;W)D
M93HZ:6UG*"D@=&\@97AP;&EC:71L>2!A8V-E<'0@86X@86QT/2(B(&%T=')I
M8G5T92X*("`@("`@2&]R9&4Z.FEM9R@I(&YO=R!G96YE<F%T97,@=&ET;&4]
M(B(@871T<FEB=71E<R!B87-E9"!O;B!T:&4@86QT/2(B('1E>'0L"B`@("`@
M('1O;RX*6V-J:%T@3F]T:69I8V%T:6]N.CIN;W1I9GDH*2!P87-S97,@=&AE
M(&UE<W-A9V4@<W1A8VL@=&\@86QL(&QI<W1E;F5R<RP@<V\@=&AA=`H@("`@
M("!L:7-T96YE<G,@9&]N)W0@:&%V92!T;R!K;F]W(&%B;W5T('1H92!M97-S
M86=E('-T86-K+"!A;F0@87!P('=R:71E<G,*("`@("`@9&]N)W0@:&%V92!T
M;R!K;F]W(&%B;W5T(&%L;"!P;W-S:6)L92!L:7-T96YE<G,N"EMC:FA=(%)E
M<&QA8V4@=&AE($A/4D1%7RH@;65S<V%G92!C;VYS=&%N=',@=VET:"`G:&]R
M9&4N97)R;W(G+"!E=&,N(&9O<@H@("`@("!G<F5A=&5R(&9L97AI8FEL:71Y
M+@I;8VIH72!296UO=F4@2&]R9&4Z.G)A:7-E365S<V%G92@I(&YO=R!T:&%T
M('1H92!.;W1I9FEC871I;VX@<WES=&5M"B`@("`@('!R;W9I9&5S('1H870@
M9G5N8W1I;VYA;&ET>2X*6V-J:%T@57-E('1H92!N97<@3F]T:69I8V%T:6]N
M('-Y<W1E;2X*6V-J:%T@4F5M;W9E(&]T:&5R(%)E9VES=')Y(&=E="@I(&UE
M=&AO9',N"EMJ;VY=(%)E;6]V92!S=7!P;W)T(&9O<B!T:&4@:&]R9&5?;&%N
M9W5A9V4@8V]O:VEE+@I;:F%N72!-;W9E('1H92!M86EN=&5N86-E(&9R86UE
M=V]R:R!F<F]M($E-4"!T;R!(;W)D92`H36EC:&%E;"!-(%-L=7-A<GH*("`@
M("`@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^*2X*"@HM+2TM+2T*
M=C(N,BXY"BTM+2TM+0H*6VIA;ET@4T5#55))5%DZ($9I>"!P;W1E;G1I86P@
M6%-3('9U;&YE<F%B:6QI='D@9'5E('1O(&YO="!P<F]P97)L>2!E<V-A<&5D
M"B`@("`@(&5R<F]R(&UE<W-A9V5S+@H*"BTM+2TM+0IV,BXR+C@*+2TM+2TM
M"@I;:F%N72!314-54DE463H@0VQO<V4@6%-3('=H96X@<V5T=&EN9R!T:&4@
M<&%R96YT(&9R86UE)W,@<&%G92!T:71L92!B>0H@("`@("!J879A<V-R:7!T
M("AC:F@I+@H*"BTM+2TM+0IV,BXR+C<*+2TM+2TM"@I;8VIH72!297-T;W)E
M(&-O;7!A=&EB:6QI='D@=VET:"!02%`@-"XQ+@I;:F%N72!314-54DE463H@
M1FEX('!O=&5N=&EA;"!84U,@=G5L;F5R86)I;&ET>2!I;B!T:&4@:&5L<"!W
M:6YD;W<N"EMJ86Y=($9I>"!C:&%R<V5T(&9O<B!,871V:6%N('1R86YS;&%T
M:6]N("A"=6<@(S8U-BDN"@H*+2TM+2TM"G8R+C(N-@HM+2TM+2T*"EMJ86Y=
M(%5S92!$0CHZ<')E<&%R92]$0CHZ97AE8W5T92!/3DQ9(&9O<B!/<F%C;&4@
M=&\@879O:60@:6UP;&EC:71L>2!R97%U:7)I;F<*("`@("`@4$A0(#0N,B!F
M;W(@86QL(&]T:&5R(%)$0DUS+@I;8VIH72!&:7@@3W)A8VQE('-E<W-I;VX@
M:&%N9&QE<BX*6V-J:%T@061D(%-13"!S8W)I<'1S(&9O<B!/<F%C;&4@86YD
M(%!O<W1G<F5344P@<V5S<VEO;B!H86YD;&5R<RX*6VIA;ET@1&]N)W0@<W1R
M:7`@=')A:6QI;F<@<W!A8V5S(&9R;VT@<VEG;F%T=7)E(&1A<VAE<R!I;B!)
M35`N"@H*+2TM+2TM+2TM+0IV,BXR+C8M4D,Q"BTM+2TM+2TM+2T*"EMC:FA=
M($9I>"!S=7!P;W)T(&9O<B!C=7-T;VT@<V5S<VEO;B!H86YD;&5R<RX*6V-J
M:%T@57-E($1".CIP<F5P87)E+T1".CIE>&5C=71E(&EN('1H92!0<F5F<U]S
M<6P@9')I=F5R(&9O<B!B971T97(@<W5P<&]R=`H@("`@("!O9B!L87)G92!F
M:65L9',@;VX@9&%T86)A<V5S('-U8V@@87,@3W)A8VQE+@I;:F%N72!3:&]W
M('1H92!U<V5R)W,@9G5L;"!N86UE(&]N('1H92!S=6UM87)Y('-C<F5E;B!D
M:7)E8W1L>2!A9G1E<B!L;V=G:6YG"B`@("`@(&EN("A$+B!!9&%M($MA<FEM
M(#QA9&%M0&%K87)S;V9T+F-O;3XI+@I;:F%N72!&:7@@:F%V87-C<FEP="!E
M<G)O<B!I;B`B4')O8FQE;2(@<&%G92!W:71H('-O;64@=')A;G-L871I;VYS
M("A"=6<@(S8Q*2X*6V-J:%T@1FEX(&AA;F1L:6YG(&]F(%!O<W1G<F5344P@
M8FQO8G,@*$)U9R`C-#0I+@H*"BTM+2TM+0IV,BXR+C4*+2TM+2TM"@I;:F%N
M72!!9&0@26YD;VYE<VEA;B!L86YG=6%G92`H4VQA;6EN(#QS;&%M:6Y`=6YE
M:BYA8RYI9#XI+@I;:F%N72!!9&0@1V%L:6-I86X@=')A;G-L871I;VX@*%)A
M9F%E;"!687)E;&$@4&5T(#QS<G)A9F%`=7-C+F5S/BP@1W5I;&QE<FUO"B`@
M("`@($UE;F1E>B`\9W5I;&QE0'5S8RYE<SXI+@I;;6US72!&:7@@9&]W;FQO
M861I;F<@;V8@9FEL97,@=VET:"!S<&%C97,@:6X@36]Z:6QL82X*"@HM+2TM
M+2T*=C(N,BXT"BTM+2TM+0H*6VUD:ET@4T5#55))5%DZ($%D9"!D97)E9F5R
M97(@=&\@<W1R:7`@;V9F('-E<W-I;VX@:6YF;W)M871I;VX@9G)O;2!L:6YK
M<R!T;PH@("`@("!T:&4@;W5T<VED92!O9B!T:&4@2&]R9&4@<WES=&5M('1O
M('!R;W1E8W0@86=A:6YS="!S97-S:6]N(&AI:F%C:VEN9RX*6VUM<UT@4T5#
M55))5%DZ($%D9"!C;V1E('1O('!R;W1E8W0@86=A:6YS="!S97-S:6]N(&9I
M>&%T:6]N(&ES<W5E<RX*6VIA;ET@1FEX(&$@8G5G('=I=&@@:6UP;W)T:6YG
M('9#87)D(#(N,2!D871A+@I;:F%N72!!9&0@07)A8FEC("A3>7)I82D@=')A
M;G-L871I;VX@*%!L871I;G5M($1E=F5L;W!M96YT(%1E86T*("`@("`@/&1E
M=G1E86U`<&QA=&EN=6TM<WDN;F5T/BDN"EMJ86Y=($%D9"!-86-E9&]N:6%N
M('1R86YS;&%T:6]N("A3=&]J86X@4&5S;W8@/'-S<$!E=7)E:V$N8V]M+FUK
M/BDN"EMM:7)=($9I>"!A(&)U9R!T:&%T(&EN8V]R<F5C=&QY('%U;W1E<R!P
M<F5F('9A;'5E<R`H0G5G(",Q,C(T*0I;8VIH72!&:7@@82!B=6<@=&AA="!P
M<F5V96YT960@;&]G9VEN9RX*6VUM<UT@1$(@<V5S<VEO;B!H86YD;&5R<R!D
M;R!N;W0@=7-E('!E<G-I<W1E;G0@8V]N;F5C=&EO;G,@8GD@9&5F875L="X*
M"@HM+2TM+2T*=C(N,BXS"BTM+2TM+0H*6VUM<UT@1FEX('!A<G-E(&5R<F]R
M(&EN($AO<F1E7T-I<&AE<E]";&]C:TUO9&5?;V9B-C0Z.BX*"@HM+2TM+2T*
M=C(N,BXR"BTM+2TM+0H*6VUM<UT@3W!T:6UI>F%T:6]N(&]F(%-E8W)E=#HZ
M(&%N9"!(;W)D95]#:7!H97(Z.B!D<FEV97)S+@I;:F%N72!!9&0@0V%T86QA
M;B!T<F%N<VQA=&EO;B`H06YG96QS($=U:6UE<N`@/&%N9V5L<RY'=6EM97)A
M0'5A8BYE<SXI+@I;;6US72!!9&1E9"!A(%)!1$E54R!!=71H.CH@9')I=F5R
M+@I;;6ER72!!9&1E9"!A(%-A;6)A($%U=&@Z.B!D<FEV97(N"EMC:FA=($%D
M9&5D('1H92!(;W)D95]);6%G93HZ(&-L87-S+@H*"BTM+2TM+0IV,BXR+C$*
M+2TM+2TM"@I;:F%N72!&:7@@:6YC;VUP871I8FEL:71Y('=I=&@@4$A0(#P@
M-"XR+C`@:6X@=&AE(%-13"!61E,@9')I=F5R+@I;:F%N72!&:7@@=6YD969I
M;F5D('9A<FEA8FQE(&EN($-I<&AE<BYP:'`@*&-J:"DN"EMM;7-=($-O;7!L
M971E(&UE<F=I;F<@;V8@4U%,('-E<W-I;VX@:&%N9&QE<BX*"@HM+2TM"G8R
M+C(*+2TM+0H*6V-J:%T@061D('-U<'!O<G0@9F]R('5S97(M9&5F:6YE9"!S
M97-S:6]N(&AA;F1L97)S"B`@("`@("A-:6ME($-O8VAR86YE(#QM:6ME0&=R
M869T;VYH86QL+F-O+FYZ/BDN"EMM86-=($-H86YG92!396-R970Z.B!F<F]M
M('5S:6YG(%!%05(@0W)Y<'1?2$-%340U('1O('1H92!(;W)D95]#:7!H97(@
M8VQA<W,N"EMM86-=($%D9"!(;W)D95]#:7!H97(Z.B!C;&%S<R!T;R!P<F]V
M:61E(&$@8V]M;6]N(&%B<W1R86-T960@:6YT97)F86-E('1O"B`@("`@('9A
M<FEO=7,@0VEP:&5R<R!F;W(@96YC<GEP=&EO;B!O9B!A<F)I=')A<GD@;&5N
M9W1H('!I96-E<R!O9B!D871A+@I;;6US72!#;W)R96-T;'D@9V5T(&-H87)S
M970@:6YF;W)M871I;VX@9F]R($U)345?4&%R=',@:6X@34E-15]3=')U8W1U
M<F4N"EMJ86Y=($%D9"!,871V:6%N('1R86YS;&%T:6]N("A+87-P87)S($MA
M<&5N:65K<R`\:V%S<&%R<T!R8V,N;'8^*2X*6VIA;ET@061D(%)O;6%N:6%N
M('1R86YS;&%T:6]N("A#;W)N96QI=2!-55-!5"`\8VUU<V%T0'1I86UA="YK
M97ES>7,N<F\^*2X*6VIO;ET@061D960@<W5P<&]R="!F;W(@86X@/&5R968^
M(&5N=&ET>2!T;R!T:&4@:&5L<"!S>7-T96TN("!4:&ES(&%L;&]W<R!A;@H@
M("`@("!E>'1E<FYA;"!L:6YK('1O(&)E(&5M8F5D9&5D(&EN(&$@:&5L<"!E
M;G1R>2X@*#QG+FAO<G1`=6YS=RYE9'4N874^*0I;8VIH72!296YA;64@5D93
M.CH@=&\@2&]R9&5?5D93.CH@9F]R(%!%05(@<&%C:V%G:6YG+@I;8VIH72!6
M1E,Z.B!I<R!N;W<@<&%C:V%G960@<V\@=&AA="!I="!C86X@8F4@97AP;W)T
M960@87,@82!014%2(&-O;7!O;F5N="X*6V-J:%T@061D(&$@;75L=&DM=7-E
M<B!344P@5D93(&)A8VME;F0@*$UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O
M;FAA;&PN8V\N;GH^*2X*6V-J:%T@5&AE(%9&4R!A<&D@;F]W(&-O;G-I<W1E
M;G1L>2!T86ME<R!A('1E;7`@9FEL92!I;B!T:&4@=W)I=&4H*2!M971H;V0*
M("`@("`@86-R;W-S(&%L;"!B86-K96YD<R`H36EC:&%E;"!687)G:&5S92`\
M;6EK92YV87)G:&5S94!A<V-E;&QA=&5C:"YC;VT^*2X*6V-J:%T@061D(&$@
M5D93($%022!F;W(@<W1O<F%G92!O9B!F:6QE<R!I;B!A;B!A8G-T<F%C=&5D
M(&9I;&5S>7-T96TN"EMC:FA=($%D9"!A('!R969E<F5N8V4@=&\@86QL;W<@
M;6%I;G1E;F%N8V4@;W!S('=I=&@@;F\@8V]N9FER;6%T:6]N('-C<F5E;@I;
M8VIH72!297!L86-E("=S:&]W)R!A='1R:6)U=&4@:6X@=&AE(')E9VES=')Y
M('=I=&@@82!M;W)E(&9L97AI8FQE("=S=&%T92<*("`@("`@871T<FEB=71E
M+@I;:F%N72!!;&QO=R!S971T:6YG('1H92!N=6UB97(@;V8@8V]L=6UN<R!I
M;B!T:&4@<W5M;6%R>2!S8W)E96X@87,@82!U<V5R"B`@("`@('!R969E<F5N
M8V4@*$)R:6%N($ME:69E<B`\8G)I86Y`=F%L:6YO<BYN970^*2X*6V-J:%T@
M061D($AO<F1E.CIG971'970H*2!A;F0@2&]R9&4Z.F=E=%!O<W0H*2X*6V-J
M:%T@061D(&%N(&EN:71I86Q?87!P;&EC871I;VX@<')E9F5R96YC92!S;R!U
M<V5R<R!C86X@<V5L96-T(&%N(&%P<`H@("`@("!T;R!B92!T86ME;B!T;R!I
M;G-T96%D(&]F('1H92!(;W)D92!3=6UM87)Y(&]N(&QO9VEN+@I;8VIH72!-
M86ME('1E>'0L(&EC;VXL(&]R(&)O=&@@;65N=7,@82!U<V5R('!R969E<F5N
M8V4*("`@("`@*$MA86Q((2`\:V%A;&A`<VUO;"YO<F<^*2X*6V-J:%T@061D
M(&$@<&%R86UE=&5R(&9O<B!S971T:6YG('1H92!S97-S:6]N('1I;65O=70N
M"EMC:FA=($%D9"!A('!A<F%M971E<B!F;W(@<V5T=&EN9R!T:&4@<V5S<VEO
M;B!D96QI;6ET97(N"EMM;7-=($%D9"!-24U%7TUA9VEC.CIF:6QE;F%M951O
M34E-12@I+@I;:F%N72!5<V4@87)G7W-E<&%R871O<BYO=71P=70@:6YS=&5A
M9"!O9B!H87)D8V]D:6YG("<F)R`H1&%V:60@56QE=FET8V@*("`@("`@/&1A
M=FED=4!E=F5R>61N<RYN970^*2X*6VIA;ET@061D($YO=&EF:6-A=&EO;CHZ
M8V]U;G0H*2`H1&%V:60@56QE=FET8V@@/&1A=FED=4!E=F5R>61N<RYN970^
M*2X*6V-J:%T@061D($%U=&@Z.FES061M:6XH*2X*6V-J:%T@06QL;W<@;&]A
M9&EN9R!O9B!S=6(M8VQA<W-E<R!F<F]M('-E=F5R86P@861D:71I;VYA;"!S
M;W5R8V5S+@I;:F%N72!296UO=F4@<F5F97)E;F-E<R!T;R!N;W0@>65T(')E
M;&5A<V5D(&%P<&QI8V%T:6]N<R`H1V]L;&5M+"!4<F]L;"DN"EMC:FA=(%)E
M=W)I=&4@0V%T96=O<GE?<W%L(&EM<&QE;65N=&%T:6]N('1O(&)E(&UU8V@@
M;6]R92!E9F9I8VEE;G0N"EMJ86Y=($%D9"!,:71H=6%N:6%N('1R86YS;&%T
M:6]N("A$87)I=7,@36%T=6QI875S:V%S(#QD87)I=7-`;&YK+FQT/BDN"EMM
M;7-=($%D9"!(;W)D93HZ8V]M<')E<W-/=71P=70H*2X*6VUM<UT@061D(&$@
M:V5R8F5R;W,@075T:#HZ(&1R:79E<BX*6VIA;ET@061D($)U;&=A<FEA;B!T
M<F%N<VQA=&EO;B`H36ER;W-L878@4&5N9&5V(#QP96YD979`:&]T;6%I;"YC
M;VT^*2X*6VIA;ET@4F5M;W9E(&1E<')E8V%T960@1$(Z.FES5V%R;FEN9R@I
M(&-A;&QS+@I;;6US72!!9&0@2&]R9&4Z.F-R96%T951E;7!$:7(H*2X*6V-J
M:%T@061D($AO<F1E.CIU<VEN9U-33$-O;FYE8W1I;VXH*2X*6V-J:%T@4F5P
M;&%C92`\/ST@=VET:"`\/W!H<"!E8VAO('1O(')E;6]V92!T:&4@<VAO<G1?
M;W!E;E]T86=S(')E<75I<F5M96YT+@I;:F%N72!!9&0@5&5X=#HZ=&](5$U,
M*"DL(%1E>'0Z.FAI9VAL:6=H=%%U;W1E<R@I(&%N9"!497AT.CID:6U3:6=N
M871U<F4H*2X*6V-J:%T@061D(%)E9VES=')Y.CIL:7-T07!P<R@I+@I;8VIH
M72!!9&0@4')E9G,Z.F=E=%!R968H*2!F;W(@9V5T=&EN9R!P<F5F97)E;F-E
M<R!F;W(@<V]M96]N92!O=&AE<B!T:&%N('1H90H@("`@("!L;V=G960M:6X@
M=7-E<BX*6V-J:%T@061D('1H92!A8FEL:71Y('1O(&QO860@:61E;G1I=&EE
M<R!F;W(@<V]M96]N92!O=&AE<B!T:&%N('1H92!L;V=G960M:6X*("`@("`@
M=7-E<BX*6VUM<UT@061D($AO<F1E.CIR96UO=F5087)A;65T97(H*2X*6VUM
M<UT@06QL(&)R;W=S97(@:&5A9&5R<R!F;W(@9&]W;FQO861I;F<@82!F:6QE
M(&AA=F4@8F5E;B!M;W9E9"!T;R!T:&4*("`@("`@0G)O=W-E<CHZ(&-L87-S
M+@I;:F%N72!!9&0@9&5T96-T:6]N(&9O<B!55$8@8V%P86)I;&ET>2!T;R!"
M<F]W<V5R(&-L87-S+@I;;6US72!!9&1E9"!I;6%G97,@34E-15]6:65W97(N
M"EMB:FY=($%D9"!0;W-T9W)E4U%,(&-O;6UA;F0@9FQA9R`H4FEC:&%R9"!'
M($MO;FQO;B`\4D=+;VYL;VY`,4UA:6Q0;&%C92YC;VT^*2X*"@HM+2TM"G8R
M+C$*+2TM+0H*6VIA;ET@061D($AU;F=A<FEA;B!T<F%N<VQA=&EO;B`H3&%S
M>FQO($PN(%1O<FYO8VD@/'1O<FQA<WI`>&5N:6$N<V]T92YH=3XI+@I;:F%N
M72!!9&0@3F]R=V5G:6%N($YY;F]R<VL@=')A;G-L871I;VX@*%!E<BU3=&EA
M;B!6871N92`\<'-V0&]R<W1A+F]R9SXI+@I;:F]N72!-86IO<B!O=F5R:&%U
M;"!T;R!T:&4@3$1!4"!P<F5F97)E;F-E<R!D<FEV97(N($YO=&4@=&AE(&-H
M86YG97,@=&\*("`@("`@8V]N9FEG+VAO<F1E+G!H<"!A;F0@<V-R:7!T<R]L
M9&%P+VAO<F1E+G-C:&5M82!W:&5N('5P9W)A9&EN9RX*6VIA;ET@061D(%-L
M;W9E;FEA;B!T<F%N<VQA=&EO;B`H2G5R92!+<F%S;W9I8R`\:G5R96M`<F-C
M+6ER8RYS:3XI+@I;8VIH72!!9&0@82!(;W)D92!P<F5F97)E;F-E<R!S8W)E
M96XL(&%N9"!A('!R969E<F5N8V4@=&\@<F5F<F5S:"!T:&4@<W5M;6%R>0H@
M("`@("!S8W)E96XN"EMC:FA=($%D9"!T97AT+V5N<FEC:&5D($U)345?5FEE
M=V5R"B`@("`@("A%<FEC(%)O<W1E='1E<B`\97)I8RYR;W-T971T97)`<&AY
M<VEC<RYU=&5X87,N961U/BDN"EMJ86Y=($EM<')O=F4@;&%N9W5A9V4@<V5L
M96-T:6]N+@I;:F%N72!!9&0@2F%P86YE<V4@=')A;G-L871I;VX@*$(N2BX@
M0FQA8VL@/'=I;&QI86TN8FQA8VM`<W5N+F-O;3XI+@I;8VIH72!#;&]S92!A
M('!O=&5N=&EA;"!P<F]B;&5M('=I=&@@<F5G:7-T97)?9VQO8F%L<R!/;B!A
M;F0@)&IS7V]N3&]A9"X*6VIA;ET@061D(%!R969S.CII<T1E9F%U;'0H*2!M
M971H;V0@=&\@9&5T97)M:6YE(&EF(&$@<')E9F5R96YC92=S('9A;'5E(&ES
M"B`@("`@('-E="!B>2!T:&4@=7-E<B!O<B!T:&4@9&5F875L="!V86QU92!F
M<F]M('!R969S+G!H<"X*6VIO;ET@3W9E<FAA=6QE9"!,1$%0('!R969E<F5N
M8V5S(&1R:79E<BX*6V-J:%T@36%K92!(;W)D93HZ9&ES<&5L36%G:6-1=6]T
M97,H*2!R96-U<G-I=F4L('-O('1H870@:70@:&%N9&QE<R!A<G)A>7,N"EMC
M:FA=($AA=F4@4V5C<F5T.CIS971+97DH*2!C:&5C:R!F;W(@=&AE('-E<W-I
M;VX@8V]O:VEE(&5X<&QI8VET;'DL('1O(&%V;VED"B`@("`@('!R;V)L96US
M('=I=&@@;VQD(&-O;VMI97,@8F5I;F<@<V5N="!T;R!A('-I=&4@=VAE;B!T
M:&5Y(&%R92!R96%L;'D*("`@("`@9&ES86)L960N"EMC:FA=($%D9"!A(%!R
M969S54D@8VQA<W,@9F]R(&AA;F1L:6YG('1H92!F;W)M('!R;V-E<W-I;F<@
M86YD(%5)(&=E;F5R871I;VX*("`@("`@9F]R('5S97(@<')E9F5R96YC97,[
M('1H:7,@8V]D92!W87,@9'5P;&EC871E9"!A;&P@=&AR;W5G:"!(;W)D92X*
M6V-J:%T@061D(&$@;6%P<&EN9R!F=6YC=&EO;B!T;R!T:&4@96YS8W)I<'0@
M9')I=F5R('=H:6-H(&UA<',@9FEL90H@("`@("!E>'1E;G-I;VYS('1O(&5N
M<V-R:7!T(&QA;F=U86=E(&-O9&5S+"!A;F0@<&%S<R!T:&4@;&%N9W5A9V4*
M("`@("`@9&ER96-T;'D@=&\@96YS8W)I<'0L('1O(&%V;VED(&AA=FEN9R!T
M;R!U<V4@82!F:6QE(&5X=&5N<VEO;BX*6V-J:%T@1FEX($U)345?36%G:6,Z
M.DU)3454;T5X="@I('1O('=O<FL@=VET:"!X+65X=&5N<VEO;B]E>'0@='EP
M97,N"EMC:FA=($%D9"!-24U%7TUA9VEC.CI-24U%5&]%>'0H*2!T;R!M87`@
M34E-12!T>7!E<R!T;R!F:6QE(&5X=&5N<VEO;G,N"EMC:FA=(%)E=W)I=&4@
M4&5R;7,Z.B!T;R!U<V4@=&AE($-A=&5G;W)I97,@8F%C:V5N9"X*6VIA;ET@
M0VAA;F=E('1H92!.;W)W96=I86X@0F]K;6%L(&QO8V%L92!F<F]M(&YO7T)/
M2R!T;R!N8E].3R!A;F0@;6%K92!I="!T:&4*("`@("`@9&5F875L="!L86YG
M=6%G92!F;W(@3F]R=V5G:6%N('5S97)S+@I;8VIH72!-86ME($AO<F1E)W,@
M;&]G:6X@<V-R965N(&YI8V5R.R!I;F-L=61E(')E87-O;G,@:6X@:70N"EMC
M:FA=(%5S92!(3U)$15]414U03$%415,@9F]R(&%L;"!T96UP;&%T92!P871H
M<RX*6V-J:%T@57-E("1R96=I<W1R>2T^9V5T*"D@9F]R(&%L;"!296=I<W1R
M>2!I;F9O<FUA=&EO;BX*6V-J:%T@4F5M;W9E9"!A9&UI;FES=')A=&EO;B!C
M;V1E('=H:6-H(&ES(&EN8V]M<&QE=&4@86YD(&-O;F9U<VEN9R!T;R!U<V5R
M<RX*6VIA;ET@061D($5S=&]N:6%N('1R86YS;&%T:6]N("A4;V]M87,@06%S
M(#QT;V]M87,N86%S0')A860N=&%R='4N964^*2X*6VIA;ET@061D(%-L;W9A
M:R!T<F%N<VQA=&EO;B`H3&5O($UR869K;R`\;&5O0&]E;"YS:SXI+@I;:F]N
M72!%;F%B;&4@=&AE(")P;W)T86)I;&ET>2(@;W!T:6]N(&EN('1H92!014%2
M($1"("AS<6PI(&1R:79E<G,N"EMC:FA=(%5S92!(;W)D92=S("=I;FET:6%L
M7W!A9V4G(&-O;F9I9W5R871I;VX@=F%L=64@:6X@=&AE($AO<F1E(&9R86UE
M<V5T+@I;:F%N72!!9&0@4&]R='5G=65S('1R86YS;&%T:6]N("A.=6YO($QO
M=7)E:7)O(#QN=6YO0&5T:"YP=#XI+@I;:F%N72!296)U:6QD('1H92!L86YG
M=6%G92!S96QE8W1I;VX@;&]G:6,N(%1H92!L86YG=6%G92!S96QE8W1E9"!O
M;B!T:&4@;&]G:6X*("`@("`@<V-R965N(&ES(&YO=R!R97-P96-T960@86YD
M('1H92!S:71E)W,@<W1A;F1A<F0@;&%N9W5A9V4@:7,@9&5F:6YE9"!I;@H@
M("`@("!L86YG+G!H<"!I;G-T96%D(&]F(&5A8V@@87!P;&EC871I;VXG<R!P
M<F5F97)E;F-E<RX*6VIA;ET@061D(&IA=F%S8W)I<'0@=&\@<V5T('1H92!F
M<F%M97-E="=S('!A9V4@=&ET;&4@*$UI8VAA96P@0V]C:')A;F4*("`@("`@
M/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^*2X*6VIA;ET@061D(%5K<F%I;FEA
M;B!T<F%N<VQA=&EO;B`H06YD<FEY($MO<'ES='EA;G-K>2`\86YR:4!P;VQY
M;F5T+FQV:78N=6$^*2X*6VIA;ET@57!D871E(&=E='1E>'0@9&]C=6UE;G1A
M=&EO;B!A;F0@36%K969I;&5S(&9O<B!3;VQA<FES(&%N9"!$96)I86XN"EMJ
M;VY=($UA:6YT96YA;F-E(&9I>&5S(&9R;VT@36EC:&%E;"!-(%-L=7-A<GH@
M/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^+@I;:F%N72!!9&0@1&%N
M:7-H('1R86YS;&%T:6]N("A-87)T:6X@3&ES="U0971E<G-E;B`\;6%R=&EN
M0&QI<W0M<&5T97)S96XN9&L^*2X*"@HM+2TM"G8R+C`*+2TM+0H*6VIA;ET@
M061D($YO<G=E9VEA;B!";V]K;6%L('1R86YS;&%T:6]N("A/>7-T96EN(%-T
M96EM;&5R(#QO>7-T96EN0')E>'1A+FYE=#XI+@I;879S;5T@061D("YH=&%C
M8V5S<R!F:6QE<R!T;R!D96YY(&%C8V5S<R!T;R!D871A(&1I<F5C=&]R:65S
M+@I;:F%N72!!9&0@1FEN;FES:"!T<F%N<VQA=&EO;B`H3&5E;F$@2&5I;F\@
M/&QI:6YU0'5T82YF:3XI+@I;8VIH72!&:7@@;VYE(&QA<W0@<')O8FQE;2!W
M:71H(%!/4#,@86YD(&UU;'1I<&%R="]A;'1E<FYA=&EV92!A='1A8VAM96YT
M<RX*"@HM+2TM+2TM+0IV,BXP+5)#-`HM+2TM+2TM+0H*6W)I8VA=($EN8VQU
M9&4@<F5W<FET=&5N(&%N9"!R96]R9V%N:7IE9"!D;V-U;65N=&%T:6]N+@I;
M8VIH72!!9&0@86X@35-0;W=E<G!O:6YT($U)345?5FEE=V5R+@I;:F%N72!4
M:&4@;&%N9W5A9V4@8V]O:VEE('=A<R!R96UO=F5D(&EN(&9A=F]R(&]F(&YE
M=R!M971H;V1S(&EN('1H92!,86YG.CH*("`@("`@8VQA<W,@=&AA="!S96QE
M8W0@=&AE(&QA;F=U86=E(&%N9"!S970@=&AE(&=E='1E>'0@9&]M86EN+@I;
M879S;5T@26YC;'5D92!#:&]R82!I;B!T:&ES(')E;&5A<V4@8WEC;&4L(&)U
M="!N;W0@<VAO=VEN9R!I;B!T:&4@=&]O;&)A<BX*6V-J:%T@061D($U)345?
M5FEE=V5R7WII<"X*6V-J:%T@5')I;2!R96=I<W1R>2YP:'`N9&ES="!T;R!O
M;FQY(&QI<W0@87!P<R!I;B!T:&ES(')E;&5A<V4@8WEC;&4N"EMJ86Y=($%D
M9"!D96QE=&5/8FIE8W0H*2!M971H;V0@=&\@=&AE(%-E<W-I;VY#86-H92!C
M;&%S<RX*6V)J;ET@0VAA;F=E("=E;B<@86YD("=E;E]%3B<@;&]C86QE<R!T
M;R`G96Y?55,G("AD969A=6QT*2X*"@HM+2TM+2TM+0IV,BXP+5)#,PHM+2TM
M+2TM+0H*6V-J:%T@4F5C;V=N:7IE(&$@9F5W(%!A;&TN;F5T(&)R;W=S97)S
M(&%N9"!S970@<75I<FMS+V9E871U<F5S(&%C8V]R9&EN9VQY+@I;8VIH72!3
M=7!P;W)T(&9O<B!A9&1I;F<@86YD(&QI<W1I;F<@3$1!4"!U<V5R<R!G:79E
M;B!A('-E="!S8VAE;6$N"EMC:FA=(%-E="!T:&4@<V5S<VEO;B!C;V]K:64@
M<&%R86UE=&5R<R!W:71H(&]U<B!C;V]K:65?<&%T:"]C;V]K:65?9&]M86EN
M"B`@("`@('-E='1I;F=S+B!4:&ES(&UE86YS('1H870@>6]U(&-A;B!B92!L
M;V=G960@:6YT;R!M=6QT:7!L92!(;W)D90H@("`@("!I;G-T86QL871I;VYS
M(&]N('1H92!S86UE('-E<G9E<B`H9&EF9F5R96YT('!A=&AS*2!A;F0@;F]T
M(&AA=F4@=&AE"B`@("`@('-E<W-I;VYS(&EN=&5R9F5R92X*6V-J:%T@57-E
M("=H;W-T<W!E8R<@8V]N<VES=&5N=&QY(&EN($%U=&@@9')I=F5R<RX*"@HM
M+2TM+2TM+0IV,BXP+5)#,0HM+2TM+2TM+0H*6VIA;ET@061D($)R87II;&EA
M;B!0;W)T=6=U97-E('1R86YS;&%T:6]N("A#87)L;W,@1&%N:65L($MI8G)I
M="`\:VEB<FET0'1E<G)A+F-O;2YB<CXI+@I;:F%N72!!9&0@1W)E96L@=')A
M;G-L871I;VX@*%-T969A;F]S($DN($1I;6ET<FEO=2`\<V1I;6ET<FE`=&5I
M871H+F=R/BDN"EMJ86Y=($%D9"!V0V%R9"!-24U%(&1R:79E<BX@0VAA;F=E
M9"!C;VYF:6<O;6EM95]D<FEV97)S+G!H<"YD:7-T+@I;:F%N72!!9&0@4W=E
M9&ES:"!T<F%N<VQA=&EO;B`H06YD<F5A<R!$86ALZ6X@/&%N9')E87-`9&%H
M;&5N+G=S/BDN"EMJ86Y=($%D9"!+;W)E86X@=')A;G-L871I;VX@*$HN22!+
M:6T@/&%P;W)I94!N971I86XN8V]M/BDN"@H*+2TM+2TM"G8Q+C,N-0HM+2TM
M+2T*"EMJ;VY=($%D9&5D("1F:6QE(&%N9"`D;&EN92!P87)A;65T97)S('1O
M($AO<F1E.CIF871A;"@I+@I;:F]N72!296UO=F5D('1H92!04D5&4U\J(&%N
M9"!!551(7RH@8V]N<W1A;G1S(&EN(&9A=F]R(&]F(%!%05)?17)R;W(@;V)J
M96-T<RX*6V%V<VU=($1O;B=T(&1E<&5N9"!O;B!T:&4@<F5G:7-T<GD@8F5I
M;F<@879A:6QA8FQE('=H96X@9&ES<&QA>6EN9PH@("`@("!T:&4@)TAO<F1E
M(&ES(&YO="!C;VYF:6=U<F5D)R!M97-S86=E+@I;8VIH72!#;&5A;B!U<"!T
M:&4@261E;G1I='D@8VQA<W,@=&\@8F4@82!G96YE<F%L:7IE9"P@8VQE86X@
M<&EE8V4@;V8@=&AE"B`@("`@(&9R86UE=V]R:R!T:&%T(&-A;B!B92!U<V5D
M(&EN(&]T:&5R(&%P<',@86YD('-U8F-L87-S960@:68@;F5C97-S87)Y+@I;
M8VIH72!-86ME(&9A:6QU<F4@=&\@8V]N;F5C="!T;R!T:&4@<')E9F5R96YC
M97,@9&%T87-O=7)C92!A(&9A=&%L(&5R<F]R+@I;8VIH72!!9&1E9"!T:&4@
M4V5R:6%L:7IE.CH@8VQA<W,@9F]R('9A<FEO=7,@;65T:&]D<R!O9B!E;F-A
M<'-U;&%T:6YG(&1A=&$*("`@("`@*'-T97!H(#QS:'5T:&5R0'EA:&]O+F9R
M/BDN"EMC:FA=($%D9&5D('1H92!C87!A8FEL:71Y('1O(&=E="!A=71H96YT
M:6-A=&EO;B!C<F5D96YT:6%L<R!O=&AE<B!T:&%N"B`@("`@('5S97)N86UE
M(&)A8VL@9G)O;2!T:&4@075T:"!F<F%M97=O<FLL(&%N9"!C;VUP;&5T960@
M=&AE"B`@("`@(&%U=&AE;G1I8V%T:6]N(')E86QM(&9U;F-T:6]N86QI='DN
M"EMJ;VY=($%L;&]W('1H92!T86)L92!C96QL(&%N9"!L:6YK($-34R!C;&%S
M<V5S('1O(&)E('-P96-I9FEE9"!W:&5N(&-R96%T:6YG"B`@("`@(&UE;G4@
M:71E;7,N"EMJ86Y=($%D9"!R96=I<W1R>2!M971H;V0@9F]R(&QI;FMI;F<@
M=&\@82!N86<@=&%S:RX*6VIA;ET@061D(&ED96YT:71Y(&-L87-S+@I;;6%X
M72!!9&0@4F5G:7-T<GDZ.F=E=$YA;64H*2!F;W(@<75E<GEI;F<@87!P;&EC
M871I;VX@;F%M97,N"EMC:FA=($AO<F1E(&YO=R!P<F]V:61E<R!T:&4@2&]R
M9&4Z.FQO9TUE<W-A9V4H*2!M971H;V0@9F]R(&QO9V=I;F<@;V8*("`@("`@
M:6YF;W)M871I;VX@86-C;W)D:6YG('1O(&-O;F9I9W5R86)L92!P<FEO<FET
M:65S+"!E=&,N"EMJ86Y=($%D9"!F=6YC=&EO;F%L:71Y('1O(&UA<"!D871E
M(&%N9"!T:6UE(&9I96QD<R!T;R!T:&4@1&%T82!C;&%S<RX*6V-J:%T@061D
M('1H92!B96=I;FYI;F=S(&]F(&$@=7-E<B!A9&UI;FES=')A=&EO;B!S>7-T
M96TN"EMC:FA=($%D9"!#:&EN97-E("A4<F%D:71I;VYA;"D@=')A;G-L871I
M;VX@*$1A=FED($-H86YG"B`@("`@(#QD879I9$!T:&)U;RYG;W8N='<^*2X*
M6VIA;ET@061D($ET86QI86X@=')A;G-L871I;VX@*$=I;W9A;FYI($UE;F5G
M:&5T=&D@/&=M96YE9VAE='1I0&EN9G9I8RYI=#XI+@I;:F%N72!!9&0@1&%T
M82!C;&%S<R!F;W(@:6UP;W)T:6YG(&%N9"!E>'!O<G1I;F<@9&%T82X*6VIO
M;ET@0VQE86YE9"!U<"!T:&4@:&5L<"!S>7-T96T@82!B:70N"EMC:FA=($%D
M9"!(;W)D93HZ9F%T86PH*2!F;W(@9&ES<&QA>6EN9R!014%27T5R<F]R(&]B
M:F5C=',@86YD(&%B;W)T:6YG+@I;879S;5T@17AT96YD($AO<F1E.CIG9714
M96UP1FEL92@I('1O(&%L;&]W(&1I<F5C=&]R>2!T;R!B92!O=F5R<FED9&5N
M+@I;879S;5T@06QL;W<@=&5M<&]R87)Y(&9I;&5S('1O(&)E('5N<F5G:7-T
M97)E9"!F<F]M(&1E;&5T:6]N+@I;879S;5T@061D(&$@0V%C:&4@9G)A;65W
M;W)K(&9O<B!P97)S:7-T96YT;'D@<W1O<FEN9R!O8FIE8W1S+"!A;&]N9PH@
M("`@("`@=VET:"!A(&9I;&5S>7-T96T@9')I=F5R+@I;:F%N72!!9&0@4&]L
M:7-H('1R86YS;&%T:6]N+@I;8VIH72!&:7@@82!P<F]B;&5M('=I=&@@)')E
M9VES=')Y+3YC86QL*"D@86YD('-W:71C:&EN9R!A<'!L:6-A=&EO;@H@("`@
M("!C;VYT97AT<RX*6V-J:%T@1V5T(')I9"!O9B!T:&4@:6YV;VME*"D@;65T
M:&]D<R!I;B!T:&4@<F5G:7-T<GDN"EMC:FA=($1O;B=T(')E+6EN8VQU9&4@
M87!P;&EC871I;VX@8V]N9FEG(&9I;&5S.R!S879E(&-O;F9I9W,@:6X@82!C
M86-H92!S;PH@("`@("!T:&%T('=E(&-A;B!J=7-T('!O:6YT("1'3$]"04Q3
M6R=C;VYF)UT@870@=&AE(&]L9"!C;VYF:6<@;VX*("`@("`@)')E9VES=')Y
M+3YP;W!!<'`H*2P@971C+@I;:F%N72!!9&0@1G)E;F-H('1R86YS;&%T:6]N
M("A&<F5D97)I8R!4<G5D96%U(#QF=')U9&5A=4!#04TN3U)'/BDN"EMC:FA=
M($%D9"!#>F5C:"!T<F%N<VQA=&EO;B`H<&-H>71I;$!A<W`N;V=I+F5D=2DN
M"EMJ86Y=($%D9"!N97<@=&EM97IO;F4@:&%N9&QI;F<@=VET:"!C;&5A<G1E
M>'0@=&EM97IO;F4@;F%M97,@:6X@;&%N9RYP:'`N"EMC:FA=($%D9"!2=7-S
M:6%N('1R86YS;&%T:6]N("A)9VYA="!):W)Y86YO=B`\:6=N871`:6)D+G)U
M/BDN"EMJ;VY=($YE=R!M971H;V1S(&EN($)R;W=S97(N<&AP(&9O<B!R971R
M:65V:6YG('9E<G-I;VYS+B`\:7IZ>4!Q=6UR86XN;W)G/@I;:F]N72!"<F]W
M<V5R+G!H<"!N;W<@9&5T96-T<R!/<&5R82X@/&EZ>GE`<75M<F%N+F]R9SX*
M6V-J:%T@36]V92!T:&4@;&%N9W5A9V4@86YD(&-H87)S970@9&5F875L=',@
M:6YT;R!C;VYF:6<O;&%N9RYP:'`L(&%N9"!A9&0@80H@("`@("!296=I<W1R
M>2!M971H;V0@=&\@9V5T('1H92!C=7)R96YT(&-H87)S970N"EMC:FA=($UA
M<"!B<F]W<V5R(&-O9&5S('-U8V@@87,@)VYL)R!T;R!T:&4@9G5L;"!C;V1E
M("@G;FQ?3DPG+"!E=&,N*2X*6V%V<VU=(%)E<&QA8V4@)&-O;F9;)W!A=&AS
M)UT@=VET:"!T:&4@)')E9VES=')Y(&5Q=6EV86QE;G1S+@I;879S;5T@061D
M(&9O=7(@<F5G:7-T<GD@9G5N8W1I;VYS('1O('%U97)Y('=E8G)O;W1S(&%N
M9"!P871H<RX*6V%V<VU=($UA;GD@34E-15]6:65W97(@8VAA;F=E<SH@05!)
M('1W96%K<RP@;F5W(&1R:79E<G,L('=O<FMS('=I=&@@24U0+@I;8VIH72`D
M8V]N9ELG=7-E<B==6R=O;FQI;F5?:&5L<"==(&ES(&YO=R!A($AO<F1E+6QE
M=F5L('-E='1I;F<N"EMA=G-M72!%;F%B;&4@87!P;&EC871I;VYS('1O(&AA
M=F4@;&]C86P@34E-15]6:65W97(@9')I=F5R<R!I;B!A9&1I=&EO;@H@("`@
M("`@=&\@=&AE(&=L;V)A;"!(;W)D92!O;F5S+@I;879S;5T@4VAU9F9L92!A
M<F]U;F0@=&AE($U)345?5FEE=V5R($%023H@9V5T1')I=F5R*"D@:7,@;F]W
M('!R:79A=&4*6V%V<VU=($%D9"!A;B`G:6YI=&EA;%]P86=E)R!O<'1I;VX@
M=&\@=&AE(')E9VES=')Y+"!T;R!L970@=7,@;&EN:R!I;G1O"B`@("`@(&%N
M>2!P86=E(&EN<VED92!A;B!A<'!L:6-A=&EO;BX*6V-J:%T@061D(&$@9G)A
M;65W;W)K+6QE=F5L(&)A<V4N<&AP(&9I;&4@86YD(&UA:V4@9G)A;65W;W)K
M('-C<FEP=',@=7-E(&ET+@I;8VIH72!!9&0@<F4M;W)G86YI>F5D(&)U="!S
M=&EL;"!M;W-T;'D@;W5T(&]F(&1A=&4@2$5,4"],25-44R]33U520T4@9FEL
M97,*("`@("`@*$IO<V@@36EL;&5R(#QJ;W-H;&ES='-`;F5B;VYE="YC;VT^
M*2X*6V-J:%T@061D(&$@<&%R86UE=&5R('1H870@9&5T97)M:6YE<R!W:&5T
M:&5R(&]R(&YO="!A<'!S(&%R92!L:6YK960@;VX@=&AE"B`@("`@($AO<F1E
M(&UE;G5B87(N"EMC:FA=($-L96%R('1H92!W:&]L92!S97-S:6]N('=H96X@
M=&AE('5S97(@;&]G<R!O=70@;V8@2&]R9&4N"EMJ;VY=($%D9&5D(%!R969S
M.CII<T5M<'1Y*"D@9F]R(&1E=&5R;6EN:6YG('=H971H97(@82!P<F5F97)E
M;F-E(&ES(&5M<'1Y+@I;:F]N72!!9&1E9"!A;B`D;VYC;&EC:R!P87)A;65T
M97(@=&\@2&]R9&4Z.FQI;FLH*2!F;W(@<W!E8VEF>6EN9R!A;B!A;F-H;W(G
M<PH@("`@("`G;VYC;&EC:R<@2F%V85-C<FEP="!E=F5N="X*6V-J:%T@57-E
M('1H92`J=7)L*"D@9G5N8W1I;VYS(&UO<F4@8V]N<VES=&5N=&QY('1O(&UA
M:V4@<W5R92!T:&%T"B`@("`@(&-O;VMI92UL97-S('-E<W-I;VYS('=O<FLN
M"EMC:FA=($UO9&EF>2!C<W,N<&AP('1O('5S92!T:&4@4F5G:7-T<GD@=&\@
M9V5T(&%P<&QI8V%T:6]N(&9I;&4@<&%T:',N"EMC:FA=($%D9"!C;V]K:65?
M<&%T:"!A;F0@8V]O:VEE7V1O;6%I;B!S971T:6YG<R!F;W(@<&5O<&QE('=H
M;R!K965P(&%P<',*("`@("`@;W5T<VED92!O9B!T:&4@2&]R9&4@=V5B<F]O
M="!O<B!O;B!M=6QT:7!L92!S97)V97)S+@H*"BTM+2TM+0IV,2XS+C0*+2TM
M+2TM"@I;8VIH72!!9&0@82!(;W)D92!S=6UM87)Y(&9R86UE=V]R:RP@=VAI
M8V@@=7-E<R!T:&4@4F5G:7-T<GD@=&\@9V5T"B`@("`@('-U;6UA<FEE<R!O
M9B!A=F%I;&%B;&4@9&%T82`M('1A<VMS+"!E=F5N=',L(&5T8RX@+2!F;W(@
M=&AE($AO<F1E"B`@("`@(&QO9VEN('-C<F5E;BX*6V-J:%T@5&AE('!R969E
M<F5N8V5S('-E='1I;F=S('-H;W5L9"!B92!(;W)D92UW:61E+"!A;F0@<V\@
M:&%V92!B965N(&UO=F5D('1O"B`@("`@(&AO<F1E+V-O;F9I9R]H;W)D92YP
M:'`N"EMC:FA=($UO=F4@<')E9G,N9VEF(&%N9"!G96YE<FEC('!R969S('1E
M;7!L871E<R!I;G1O($AO<F1E+@I;8VIH72!-;W9E('-E='1I;F<@;V8@=&AE
M(&=E='1E>'0@9&]M86EN(&EN=&\@=&AE(%)E9VES=')Y+@I;:F]N72!3:6UP
M;&EF:65D('1H92!P<F5F97)E;F-E('-Y<W1E;2=S(&-L96%N=7`@9G5N8W1I
M;VYS+@I;:F]N72!-97)G92!D;V-T>7!E+FEN8R!I;G1O(&-O;6UO;BUH96%D
M97(N:6YC+@I;:F]N72!!9&1E9"!497AT.CIH=&UL<W!A8V5S*"D@86YD(%1E
M>'0Z.FAT;6QA;&QS<&%C97,H*2X*6V-J:%T@061D(&%N(&]P=&EO;B!T;R!(
M;W)D93HZ9V5T5&5M<$9I;&4H*2!T;R!N;W0@9&5L971E('1H92!F:6QE(&%T
M('1H90H@("`@("!E;F0@;V8@=&AE(')E<75E<W0N"EMC:FA=($%D9"!A("9S
M:6YG;&5T;VXH*2!M971H;V0@=&\@=&AE(%)E9VES=')Y(&-L87-S+@I;:F]N
M72!!9&1E9"!.86<@:6YT97)F86-E('1O('1H92!R96=I<W1R>2X*6VIO;ET@
M17AP86YD960@=&AE(')E9VES=')Y('1O(&AA;F1L92!I;7!O<G1I;F<@87!P
M;&EC871I;VXM<W!E8VEF:6,*("`@("`@8V]N9FEG=7)A=&EO;B!V86QU97,N
M"EMM87A=($%D9"!A=71H+VQO9VEN(&%N9"!A=71H+VQO9V]U="!O<'1I;VYS
M(&9O<B!';VQL96T@:6X@=&AE(')E9VES=')Y+@I;;6%X72!!9&0@4F5G:7-T
M<GDZ.F=E=$UE=&AO9"!F=6YC=&EO;BX*6VUA>%T@061D(&-O;G1A8W1S+W-O
M=7)C97,@<V5R=FEC92!T;R!T:&4@<F5G:7-T<GDN"EMC:FA=(%)E;F%M92!T
M:&4@0V]N;F5C=&EO;B!C;&%S<V5S('1O(%1O:V5N+@I;8VIH72!296YA;64@
M=&AE($]B:F5C=%-T;W)E(&-L87-S('1O(%-E<W-I;VY#86-H92X*6VIO;ET@
M061D:6YG($1U=&-H(&QA;F=U86=E+@I;879S;5T@061D(&EC;VX@<W5P<&]R
M="!T;R!T:&4@34E-15]6:65W97(@9G)A;65W;W)K"EMA=G-M72!5<&1A=&4@
M=&AE($U)345?5FEE=V5R($%022!T;R!I;F-L=61E(&=E=$1R:79E<B@I(&%N
M9"!G971)8V]N*"D*6VIO;ET@3W9E<FAA=6QE9"!T:&4@<')E9F5R96YC97,@
M8V%C:&EN9R!S>7-T96T@82!B:70N"EMC:FA=(%5P9&%T92!"<F]W<V5R.CH@
M=&\@<F5C;V=N:7IE($E%-BX*6VIO;ET@061D960@2&]R9&4M=VED92!A;F0@
M9')I=F5R+7-P96-I9FEC(&-L96%N=7`@;65T:&]D<R!T;R!T:&4@<')E9F5R
M96YC97,*("`@("`@<WES=&5M+@I;8VIH72!296UO=F4@=&AE('-T<G1O;&]W
M97(H*2!F<F]M($QA;F<Z.G-E;&5C="@I('=H:6-H('=A<R!P<F5V96YT:6YG
M"B`@("`@('!R;W!E<B!L;V-A;&4@;F%M97,@*&QI:V4@<'1?0E(I(&9R;VT@
M=V]R:VEN9R!C;W)R96-T;'DN"EMM87A=($%D9&5D(&%U=&AE;G1I8V%T:6]N
M(&AA;F1L97(@=&\@=&AE(%)E9VES=')Y+@I;:F]N72!4:&4@)W-E<W-I;VXG
M('!R969E<F5N8V5S(&1R:79E<B!N;W<@:&]N;W)S('!R969E<F5N8V4@<V-O
M<&4N"EMM87A=($UA9&4@<VET96YA;64@=&ET;&4@8V]N9FEG=7)A8FQE+@I;
M:F]N72!297=O<FME9"!T:&4@365N=3HZ8W5S=&]M271E;2@I('1O(&%C8V5P
M="!02%`@9&%T82!S=')U8W1U<F5S(&EN<W1E860*("`@("`@;V8@82!S=')I
M;F<@;V8@96YC;V1E9"!P87)A;65T97)S+@I;879S;5T@061D960@34E-15]6
M:65W97(@9G)A;65W;W)K('1O(&AA;F1L92!R96YD97)I;F<@9FEL97,@:6YT
M;R!(5$U,"B`@("`@("`H86YD(&]T:&5R*2!F;W)M871S(&EN(&$@=7-E<BUE
M>'1E;G-I8FQE(&9A<VAI;VX@*&5X<&5R:6UE;G1A;"D*6V%V<VU=($YE=R!-
M24U%7TUA9VEC(&%N9"!M:6UE7VUA<'!I;F<N<&AP(&-O;F9I9R!F:6QE("AE
M>'!E<FEM96YT86PI"EMA=G-M72!4=V\@;F5W('1E;7!O<F%R>2!F:6QE(&AA
M;F1L:6YG(&9U;F-T:6]N<RP@2&]R9&4Z.F=E=%1E;7!&:6QE*"D@86YD"B`@
M("`@($AO<F1E.CIG971496UP1&ER*"D@=&\@=&%K92!C87)E(&]F('1H92!H
M;W5S96ME97!I;F<@;V8@=&5M<"!F:6QE<RX*6VUA>%T@061D960@8V]N=&%C
M=',O861D('-E<G9I8V4@=&\@<F5G:7-T<GDN"EMC:FA=(%)E9VES=')Y.CIC
M86QL*"D@:7,@;F]W(%)E9VES=')Y.CIL:6YK*"DN(%1H97)E(&ES(&$@;F5W
M"B`@("`@(%)E9VES=')Y.CIC86QL*"D@=VAI8V@@86-T=6%L;'D@<F5T=7)N
M<R!T:&4@<F5S=6QT(&]F(&$@9G5N8W1I;VX@8V%L;`H@("`@("!M861E('1O
M(&%N;W1H97(@87!P;&EC871I;VXN"EMC:FA=($9I>"!$0B!Q=65R>2!R97-U
M;'0@8VAE8VMI;F<@:6X@<W%L(&1R:79E<G,N"EMC:FA=($9I>"!H96QP('-O
M('1H870@9V5N97)I8R!H96QP(&QI;FMS("AO;B!M96YU(&)A<G,I('-H;W<@
M=&AE('1O<&EC(&QI<W0*("`@("`@8V]R<F5C=&QY+@I;8VIH72!-86ME('1H
M92!L;V=I;B!F;W)M(&YI8V5R+"!A;F0@861D(&$@;&]G;W5T(&QI;FLN"EMC
M:FA=($UA:V4@<W5R92!A;&P@;V8@=&AE('-Q;"!D<FEV97)S('5S92!$0CHZ
M<75O=&53=')I;F<H*2!O;B!A;&P@<W1R:6YG<RX*6V-J:%T@4F5P;&%C92!A
M($!M>7-Q;%]Q=65R>2@I('1H870@=V%S(&AI9&EN9R!I;B!#;VYN96-T:6]N
M+W-Q;"YP:'`@=VET:`H@("`@("`D=&AI<RT^9&(M/G%U97)Y*"DN"EMC:FA=
M(%)E='5R;B!B87-E;F%M92@D;&%N9W5A9V4I(&9R;VT@3&%N9SHZ4V5L96-T
M*"D@=&\@879O:60@<&]S<VEB;&4*("`@("`@97AP;&]I=',N"EMC:FA=($%D
M9"!296=I<W1R>3HZ:&%S365T:&]D*"D@9F]R(&-H96-K:6YG(&EF(&$@<&EE
M8V4@;V8@9G5N8W1I;VYA;&ET>2!H87,*("`@("`@8F5E;B!R96=I<W1E<F5D
M('=I=&@@2&]R9&4N"EMJ;VY=($%N;W1H97(@;&%R9V4@;W9E<FAA=6P@=&\@
M=&AE('!R969E<F5N8V5S('-Y<W1E;2X@($YO=&4@=&AA="!T:&4*("`@("`@
M:7-#:&%N9V5A8FQE*"D@9G5N8W1I;VX@:&%S(&)E96X@<F5N86UE9"!I<TQO
M8VME9"@I+B`@5&AE<F4@:7,@86QS;PH@("`@("!S=7!P;W)T(&9O<B!P<F5F
M97)E;F-E('-C;W!E("AV:6$@:7-3:&%R960H*2!A;F0@<V5T4VAA<F5D*"DI
M+@I;:F]N72!!9&1E9"!C87!A:6)L:71Y('1E<W1S('1O('1H;W-E(&1R:79E
M<G,@=&AA="!R97%U:7)E(&YO;BUS=&%N9&%R9"!02%`*("`@("`@97AT96YS
M:6]N<R`H:&%N9&QE9"!B>2!(;W)D93HZ9G5N8W1I;VY#:&5C:R@I*2X*6VIO
M;ET@061D960@86X@075T:%],1$%0($AO<F1E(&%U=&AE;G1I8V%T:6]N(&1R
M:79E<BX*6V-J:%T@061D(&QI='1L92!S;FEP<&5T+71E;7!L871E<R!F;W(@
M9'EN86UI8V%L;'D@8G5I;&1I;F<@<')E9F5R96YC92!'54ES+@I;8VIH72!2
M96YA;64@=&AE($%U=&@@:6YT97)F86-E)W,@875T:"@I(&UE=&AO9"!T;R!A
M=71H96YT:6-A=&4H*2!T;R!A=F]I9`H@("`@("!O=F5R;&%P<&EN9R!T:&4@
M;F%M92!O9B!T:&4@8V]N<W1R=6-T;W(@9F]R('1H92!!=71H('!A<F5N="!C
M;&%S<RX*6V-J:%T@5&AE(&-O;F9I9W5R871I;VX@87)R87D@:7,@;F]W('-I
M;7!L>2`D8V]N9BX@06YY('-E='1I;F=S('1H870@;75S="!B90H@("`@("!A
M8V-E<W-I8FQE('5N8VAA;F=E9"`H;F]T(&]V97)R:61D96XI('-H;W5L9"!B
M92!P=70@:6YT;R`D8V]N9ELG:&]R9&4G72X*("`@("`@179E<GET:&EN9R!E
M;'-E(&ES(&9A:7(@9V%M92!F;W(@87!P;&EC871I;VYS('1O(&]V97)R:61E
M+@I;8VIH72!!9&0@82!W;6PO=V%P(&QO9VEN(&9O<FTN"EMM87A=($%D9"!A
M;B!!=71H7T944"!(;W)D92!A=71H96YT:6-A=&EO;B!D<FEV97(N"EMC:FA=
M($%D9"!A;B!!=71H7TU#04P@2&]R9&4@875T:&5N=&EC871I;VX@9')I=F5R
M+@I;8VIH72!4:&4@2&]R9&4@;&]G:6X@9F]R;2!N;W<@86-T=6%L;'D@9&]E
M<R!S;VUE=&AI;F<N($QO9V=I;F<@:6X@=&\@:70*("`@("`@9V5T<R!Y;W4@
M82!T;VME;B!I;B!Y;W5R('-E<W-I;VX@<V%Y:6YG('1H870@>6]U)W9E(&%U
M=&AE;G1I8V%T960@86YD"B`@("`@('=H;R!Y;W4@87)E+B!!<'!S(&-A;B!T
M:&5N('5S92!T:&ES(&EN9F]R;6%T:6]N('1O(&%L;&]W(&]R(&1E;GD*("`@
M("`@86-C97-S+"!A;F0@=&\@:61E;G1I9GD@=7-E<G,N"EMC:FA=(%1H92!F
M;W)M870@;V8@=&AE(&-O;F9I9R]R96=I<W1R>2YP:'`@9FEL92!H87,@8VAA
M;F=E9"!D<F%S=&EC86QL>2!T;PH@("`@("!B92!M;W)E(')E861A8FQE(&%N
M9"!L97-S(&EN9&ER96-T+B!4:&5R92!I<R!A;'-O(&$@;F5W(&%P<"!P87)A
M;65T97(L"B`@("`@("=A;&QO=U]G=65S=',G+"!W:&EC:"!D969I;F5S('=H
M971H97(@;W(@;F]T(&$@=7-E<B!I<R!A;&QO=V5D('1O"B`@("`@(&%C8V5S
M<R!T:&4@87!P;&EC871I;VX@=VET:&]U="!L;V=G:6YG(&EN('1O($AO<F1E
M+@I;8VIH72!4:&4@075T:#HZ(&-L87-S97,@;F]W(&5X<&5C="!T;R!R96-E
M:79E(&$@=7-E<FED(&%N9"!A;B!A<G)A>2!O9@H@("`@("!C<F5D96YT:6%L
M<RX@4FEG:'0@;F]W(&%L;"!B86-K96YD<R!A<W-U;64@=&AA="!T:&]S92!C
M<F5D96YT:6%L<PH@("`@("!C;VYT86EN(&$@<&%S<W=O<F0L(&)U="!T:&4@
M=V%Y(&ES(&-L96%R('1O(&AA=F4@;W1H97(@:VEN9',@;V8@875T:`H@("`@
M("`H25`L('1I;64M8F%S960L('=H871E=F5R*2X*6VIO;ET@061D960@82!N
M97<@<&%R86UE=&5R('1O('1H92!,1$%0('!R969E<F5N8V5S(&1R:79E<CH@
M)V%L=V%Y<U]B:6YD)RX*6V-J:%T@061D960@82!-96YU.CH@8VQA<W,@=&AA
M="!A;&P@;6]D=6QE<R!C86X@=7-E('1O(&=E;F5R871E(&UE;G4@:71E;7,N
M"EMJ;VY=($-L96%N960@=7`@=&AE($Q$05`@<')E9F5R96YC97,@9')I=F5R
M(&$@8FET+@I;:F]N72!!9&1E9"!S97-S:6]N+6QE=F5L('!R969E<F5N8V5S
M(&-A8VAI;F<@=&\@=&AE('!R969E<F5N8V5S('-Y<W1E;2X*6V-J:%T@2&%V
M92!(;W)D93HZ;&EN:R@I(&UA:V4@<W5R92!T:&%T('1H92!S=&%T=7,@=&5X
M="!I<R!S869E(&9O<@H@("`@("!J879A<V-R:7!T("AH=&UL96YT:71I97,L
M(&%D9'-L87-H97,I+@I;8VIH72!&:7@@3V)J96-T4W1O<F4@=&\@=V]R:R!W
M:&5N(')E9VES=&5R7V=L;V)A;',@/2!/;BX*6VIO;ET@061D960@82!397-S
M:6]N+6)A<V5D('!R969E<F5N8V5S(&1R:79E<BX*"@HM+2TM+2T*=C$N,RXS
M"BTM+2TM+0H*6V-J:%T@1G5R=&AE<B!R979A;7`@=&AE($U)344@:6YT97)F
M86-E+B!"92!C;VYS:7-T96YT(&EN(&-A<&ET86QI>F%T:6]N"B`@("`@("AA
M8W)O;GEM<R!A<F4@8V%P:71A;&EZ960I+"!B<F5A:R!O=70@34E-15]3=')U
M8W1U<F4@86YD($U)345?365S<V%G90H@("`@("!I;G1O('-E<&5R871E(&9I
M;&5S+"!A;F0@<'5T(&%L;"!M971H;V1S(&EN=&\@8VQA<W-E<RX*6V-J:%T@
M061D($AO<F1E.CIG971&;W)M1&%T82@I('1O(&9E=&-H(&$@=F%R:6%B;&4@
M9G)O;2!E:71H97(*("`@("`@)$A45%!?4$]35%]605)3(&]R("1(5%107T=%
M5%]605)3("AA;F0@=&\@8VQE86X@;6%G:6,@<75O=&5S+"!I9@H@("`@("!N
M96-E<W-A<GDI+@I;8VIH72!296UO=F4@=&AE($QO9SHZ(&-L87-S+B!4:&ES
M(&ES('!A<G0@;V8@4$5!4B!N;W<N"EMC:FA=($%D9"!A(%-E<W-I;VY#86-H
M93HZ(&-L87-S+B!4:&ES(&ES(&EN=&5N9&5D(&9O<B!S=&]R:6YG(&]B:F5C
M=',@:6X*("`@("`@=&AE('-E<W-I;VX@:6YT96YD960@9F]R(&YE87(M=&5R
M;2!U<V4L(&%N9"!W:6QL(&-U<G)E;G1L>2!S=&%R=`H@("`@("!T:')O=VEN
M9R!O=70@;V)J96-T<R!W:&5N(&UO<F4@=&AA;B`R,"!A<F4@<'5T(&EN+B!4
M:&ES('=I;&P@:&]P969U;&QY"B`@("`@(&ME97`@86YY(&]N92!S97-S:6]N
M(&9R;VT@9W)O=VEN9R!T;V\@;&%R9V4N"EMC:FA=(%5S92!T:&4@;F5W(%!%
M05(@8VQA<W,@36%I;%]R9F,X,C(Z.B!T;R!P87)S92!A9&1R97-S(&QI<W1S
M+"!S;R!T:&%T"B`@("`@('=E(&=E="!R9F,@.#(R(&=R;W5P('-U<'!O<G0@
M*&UY+6)U9&1I97,Z(&IO;D!H;W)D92QO<F<L"B`@("`@(&UA>$!H;W)D92YO
M<F<[*2P@=VAI8V@@:6UA<%]R9F,X,C)?<&%R<V5?861R;&ES="@I(&1O97-N
M)W0@:&%V92X*6VUA>%T@36%K92!(;W)D92!82%1-3"`Q+C`@8V]M<&QI86YT
M+@I;8VIH72!!9&0@82!F97<@9FEE;&1S('1O('1H92!P<F]B;&5M(')E<&]R
M="!A;F0@=')Y('1O(&UA:V4@:70@;6]R92!F<FEE;F1L>2X*6V-J:%T@1FQE
M<V@@;W5T('1H92!-:6UE.CH@8VQA<W,N"EMC:FA=($UO=F4@=')I;45M86EL
M061D<F5S<R@I(&EN=&\@=&AE(&YE=R!-:6UE.CH@8VQA<W,N"EMC:FA=($UO
M=F4@<V5T7V5N=E]I;E]S=')I;F<H*2!T;R!497AT.CIE>'!A;F1%;G9I<F]N
M;65N="@I+@I;8VIH72!296YA;64@:&]R9&5?8VQE86YU<"@I('1O(%]F:6QE
M0VQE86YU<"@I+@I;8VIH72!4:&4@>FQI8B!M;V1U;&4@;F]W('-U<'!L:65S
M(&$@9WIE;F-O9&4H*2!F=6YC=&EO;B!T:&%T(&]B<V]L971E<PH@("`@("!(
M5%107T-A8VAE.CIG>D5N8V]D92@I+@I;8VIH72!-;V1I9GD@2&]R9&4Z.G5R
M;"@I('-O('1H870@:70@9&5F875L=',@)&-O;F9;)W5S95]S<VPG72!T;R`R
M"B`@("`@("AA=71O+61E=&5C="!C=7)R96YT(&UO9&4I+@I;8VIH72!-;V1E
M<FYI>F4@<V]M92!O9B!T:&4@2&]R9&4@9G)O;G1E;F0@*'-T:6QL(&QO=',@
M=&\@9&\@:&5R92D[(&=E="!R:60*("`@("`@;V8@<&%C:V%G92Y(5$U,1&]C
M=6UE;G0N<&AP(&]N8V4@86YD(&9O<B!A;&PN"EMA=G-M72!"<F5A:V1O=VX@
M86QL('-P96-I86P@8VAA<F%C=&5R<R!I;B!54DQS('1O(&5N=&ET:65S+"!T
M;R!A=F]I9`H@("`@("!A;6)I9W5I='D@:6X@:&]W('9A<FEO=7,@8G)O=W-E
M<G,@<&%R<V4@=&AE;2X*6V-J:%T@061D($AO<F1E.CIR86ES94UE<W-A9V4H
M*2!F;W(@8W)E871I;F<@2&]R9&4@;65S<V%G97,@=&\@8F4@9&ES<&QA>65D
M"B`@("`@('1O('1H92!U<V5R+@I;8VIH72!3;VUE(&=E;F5R86P@54D@='=E
M86MS("T@9F]N="!S:7IE+"!E=&,N"EMC:FA=(%)E;6]V92!R9F-D871E*"D@
M:6X@9F%V;W(@;V8@=&AE(&YE=R`G<B<@<&%R86UE=&5R('1O(&1A=&4N"EMC
M:FA=($%D9&5D(&%P<&QI8V%T:6]N("=W96)R;V]T)R!A;F0@)V9I;&5R;V]T
M)R!P<F]P97)T:65S('1O('1H92!R96=I<W1R>0H@("`@("!C;VYF:6<@9FEL
M92X@5&AE<V4@86QL;W<@;6]R92!F;&5X:6)I;&ET>2!I;B!P;&%C:6YG(&%P
M<',L(&%N9"!L970@=&AE"B`@("`@(')E9VES=')Y('=O<FL@9G)O;2!M;W)E
M('!L86-E<RX*6V-J:%T@36]V960@<&%C:V%G92Y296=I<W1R>2YP:'`@=&\@
M4F5G:7-T<GDN<&AP+@I;8VIH72!#;VUM96YT960@8V]N9FEG+VAO<F1E+G!H
M<"YD:7-T(&AE879I;'DN"EMC:FA=($%D9"!A(%-E8W)E=#HZ(&-L87-S('1O
M($AO<F1E+G!H<"!T:&%T('!R;W9I9&5S(&$@=')A;G-P87)E;G0*("`@("`@
M:6YT97)F86-E('1O(&5I=&AE<B!T:&4@;6-R>7!T(&5X=&5N<VEO;B`H<')E
M9F5R<F5D*2!O<B!T:&4@4$5!4@H@("`@("!#<GEP=%](0T5-1#4Z.B!C;&%S
M<RX*6VIO;ET@06-C97!T(&$@=7-E<BUD969I;F5D(&9U;F-T:6]N(&9O<B!P
M97)F;W)M:6YG('5S97)N86UE(&QO;VMU<',@:6X@=&AE"B`@("`@('!R969E
M<F5N8V5S(&-O9&4N("!4:&4@<')E9F5R96YC97,@8V]N<W1R=6-T;W(@;&]O
M:W,@9F]R('1H92!F=6YC=&EO;@H@("`@("!I;B`D<&%R86US6R=U<V5R7VAO
M;VLG72X*6V-J:%T@0VAE8VL@2%144%]%3E9?5D%24R!F;W(@=&AE('5S97(M
M86=E;G0@87,@=V5L;"!A<R!(5%107U-%4E9%4E]605)3+@I;8VIH72!296UO
M=F4@;6%I;&9R;VTH*2!I;B!F879O<B!O9B!T:&4@4$5!4B!-86EL.CH@:6YT
M97)F86-E+B!!9&IU<W0@=&AE"B`@("`@(&-O;F8@9FEL97,@86YD('!R;V)L
M96TN<&AP(&%C8V]R9&EN9VQY+@I;8VIH72!!9&0@82!S970@;V8@:6YV;VME
M*"D@;65T:&]D<R!T;R!T:&4@4F5G:7-T<GDZ.B!C;&%S<R!F;W(@9&ER96-T
M;'D*("`@("`@:6YV;VMI;F<@<V5R=FEC97,@*&EE+"!A8W1U86QL>2!P;W!P
M:6YG('5P(&$@=VEN9&]W*2!I;G-T96%D(&]F"B`@("`@('!R:6YT:6YG(&QI
M;FMS('1O(&EN=F]K92!T:&5M+@I;8VIH72!#;&5A;B!U<"!P86-K86=E+DUI
M;64N<&AP(&$@8FET.R!D;VXG="!S970@82!C:&%R<V5T(&]N($U)344@<&%R
M=',*("`@("`@=&AA="!A<F5N)W0@=&5X="X*6V-J:%T@061D960@82!F:6QE
M(&1R:79E<B!F;W(@=&AE($-O;FYE8W1I;VXZ.B!C;&%S<RX*6V-J:%T@061D
M960@82!705`@:6YD97@@=&\@<')O=FED92!Q=6EC:R!L:6YK<R!T;R!A;&P@
M2&]R9&4@=VER96QE<W,@<&%G97,N"EMC:FA=($%D9"!B87-I8R!705`@8G)O
M=W-E<B!D971E8W1I;VX@=&\@0G)O=W-E<CHZ+B!#=7)R96YT;'D@=&AI<R!I
M<R!O9B!T:&4*("`@("`@(FET(&1E=&5C=',@=&AE('!H;VYE($D@:&%V92!A
M;F0@=&AE('-I;75L871O<B!)('5S92(@=F%R:65T>3L@:70@:7,*("`@("`@
M7W9E<GE?(&9A<B!F<F]M(&-O;7!L971E+@I;8VIH72!!9&1E9"!-87@@2V%L
M:6MA)W,@0V]N;F5C=&EO;CHZ(&-L87-S(&9O<B!C;VYN96-T:6]N('1R86-K
M:6YG+@I;8VIH72!(5%107T-A8VAE.CH@;F]W(&-O;7!R97-S97,@8V]N=&5N
M="!W:71H;W5T('1H92!U<V4@;V8@82!T96UP(&9I;&4N"EMC:FA=($9L97-H
M960@;W5T('1H92!!=71H.CH@8VQA<W,@=VET:"!T:&4@86)I;&ET>2!T;R!C
M86-H92!A=71H;W)I>F%T:6]N"B`@("`@(&EN('1H92!S97-S:6]N+@I;:F]N
M72!296UO=F5D('1H92!S8W)I<'1E9"!W;W)D=W)A<"!I;B!F879O<B!O9B!T
M:&4@;F%T:79E(&9U;F-T:6]N+B`@36]V960*("`@("`@=&AE('=R87!?;65S
M<V%G92@I(&9U;F-T:6]N('1O(%1E>'0Z.G=R87`H*2X*6VIO;ET@4W1A;F1A
M<F1I>F4@;VX@=&AE(')F8V1A=&4H*2!F=6YC=&EO;B!I;B!L:6(O2&]R9&4N
M<&AP+@I;8VIH72!4:&4@<')E9G,@9')I=F5R<R!N;W<@97AP96-T("1P87)A
M;7-;)VAO<W1S<&5C)UTL(&9O<B!C;VYS:7-T96YC>2!W:71H"B`@("`@(%!%
M05(N"EMC:FA=(%1H92!014%2('-Q;"!P<F5F<R!D<FEV97(@;F]W('=O<FMS
M+@I;8VIH72!-;W9E(&AO<F1E(&-O;F9I9W5R871I;VX@=F%L=65S('1H870@
M<VAO=6QD(&YO="!B92!O=F5R<FED9&5D(&)Y"B`@("`@(&UO9'5L97,@:6YT
M;R`D:&]R9&5;)VAO<F1E)UU;72!T;R!A;&QO=R!M;V1U;&5S('1O(&1O"B`@
M("`@(&]V97)R:61I;F<O:6YH97)I=&%N8V4@;V8@;W1H97(@;W!T:6]N<RX*
M6V-J:%T@061D('1H92!(5%107T-A8VAE.CH@8VQA<W,@=&\@2&]R9&4N<&AP
M(&9O<B!%5&%G(&=E;F5R871I;VXL(&=Z:7`*("`@("`@8V]M<')E<W-I;VX@
M;V8@:'1T<"!C;VYT96YT+"!E=&,N"EMC:FA=(%)E<&QA8V4@)&AO<F1E6R=L
M;V-A;&AO<W0G72!W:71H("1(5%107U-%4E9%4E]605)36R=315)615)?3D%-
M12==+@I;8VIH72!296IE8W0@;W5T<FEG:'0@96YV96QO<&4@1G)O;2!A9&1R
M97-S97,@=VET:"!S<&%C97,@:6X@=&AE;2X*6V-J:%T@475O=&4@=&AE(&9R
M;VT@861D<F5S<R!P87-S960@=&\@<V5N9&UA:6P@=&\@<')E=F5N="!S:&5L
M;"!E>'!L;VET<RX*6V-J:%T@57!D871E($)R;W=S97(N<&AP('1O('5S92!(
M5%107U-%4E9%4E]605)3+"!C;VYS;VQI9&%T92!T:&4@:F%V87-C<FEP=`H@
M("`@("!V97)S:6]N(&EN9F]R;6%T:6]N+"!A;F0@861D('-S;%]D;W=N;&]A
M9%]H86-K(&9O<B!B<F]W<V5R<R!T:&%T(&YE960*("`@("`@9&]W;FQO861S
M('1O(&)E(&-A8VAE86)L92X*6VIO;ET@061D(%1E>'0Z.F9I;'1E<B!T;R!L
M:6(O2&]R9&4N<&AP+@I;8VIH72!#:&5C:R!T:&4@<F5T=7)N('9A;'5E(&]F
M('!C;&]S92@I(&-O<G)E8W1L>2!I;B!M86EL9G)O;2@I+@I;:F]N72!396-U
M<FET>2!F:7@@9F]R("1F<F]M('9A;'5E(&EN(&UA:6QF<F]M*"DN(#QC=T!C
M;V,M86<N;F5T/@I;:F]N72!3:6QE;F-E('-E<W-I;VY?<W1A<G0@=V%R;FEN
M9W,N"EMJ;VY=($%D9&5D(&YE=R!\97AT<F%\('-U8G-T:71U=&EO;B!T;R!C
M;VYF:6<O<F5G:7-T<GDN<&AP(&9O<B!E>'1R82P*("`@("`@;F]N+7-T86YD
M87)D('!A<F%M971E<B!P87-S:6YG+@I;:F]N72!296UO=F4@8G5I;&154DPH
M*2X@($ET)W,@8F5E;B!R97!L86-E9"!B>2!(;W)D93HZ=7)L*"DN"EMJ;VY=
M(%)E<W1R=6-T=7)E9"!T:&4@4U%,('!R969E<F5N8V5S('-C:&5M82X*6V-J
M:%T@061D960@)&AO<F1E6R=S97-S:6]N7VYA;64G72!T;R!C;VYT<F]L('1H
M92!S97-S:6]N(&YA;64@9VQO8F%L;'DN"EMC:FA=(%-E<W-I;VXZ.B!D;V5S
M;B=T(')E86QL>2!B=7D@=7,@86YY=&AI;F<L('-O('=E)W9E(&UO=F5D('1H
M92!U=&EL:71Y"B`@("`@(&UE=&AO9',@=&AA="!D;R!I;G1O($AO<F1E.CHL
M(&%N9"!A<F4@:G5S="!U<VEN9R!P:'`T('-E<W-I;VX@8V%L;',*("`@("`@
M96QS97=H97)E+@I;8VIH72!!9&1E9"!T:&4@8F5G:6YN:6YG<R!O9B!5<V5R
M(&%N9"!!=71H(&EN=&5R9F%C97,L('=I=&@@82!B87)E+6)O;F5S"B`@("`@
M('=O<FMI;F<@075T:%]S<6P@:6UP;&5M96YT871I;VXN"EMJ;VY=(%)E=W)O
M=&4@=&AE(%-E<W-I;VX@8VQA<W,@9F]R(&EN<W1A;G1I871I;VX@=VET:"!H
M;V]K<R!F;W(*("`@("`@=7-E<BUD969I;F5D('-E<W-I;VX@:&%N9&QE<G,N
M"EMC:FA=(%1H92!B87)E+6)O;F5S(&EM<&QE;65N=&%T:6]N(&]F('1H92!0
M97)M<R!S8VAE;64L('=I=&@@82!S<6P@9')I=F5R+`H@("`@("!W;W)K<RX@
M268@>6]U('!A<W,@:70@82!F=6QL('!A=&@@:70@=VEL;"!T<F%V97)S92!U
M<"!I="P@<F5T=7)N:6YG"B`@("`@('1H92!F:7)S="!P97)M:7-S:6]N(&ET
M(&9I;F1S+@I;:F]N72!-;W9E9"!T:&4@;&%N9W5A9V4@:&%N9&QI;F<@9G5N
M8W1I;VYS(&EN($AO<F1E+G!H<"!I;G1O('1H96ER(&]W;@H@("`@("!C;&%S
M<V5D(&YA;65D($QA;F<N"EMC:FA=($UO<F4@8V]N<VES=&5N="]C<W,M8F%S
M960@;&]O:R!F;W(@=&AE(&AE;'`@<WES=&5M+@I;8VIH72!3=&%R=&EN9R!T
M;R!R96UO=F4@86QL('5S97,@;V8@8V%L;"UT:6UE('!A<W,M8GDM<F5F97)E
M;F-E+@I;8VIH72!!9&1E9"!C<W,N<&AP(&9O<B!A=71O;6%G:6-A;"!G96YE
M<F%T:6]N(&]F('-T>6QE<VAE971S(&9O<B!A<'!S+@I;:F]N72!0<F]M;W1E
M9"!T:&4@5V5B0VQI96YT(&-L87-S(&9R;VT@;&EB+TAO<F1E+G!H<"!T;R!I
M=',@;W=N(&-O;7!O;F5N=`H@("`@("!N86UE9"!"<F]W<V5R+G!H<"X*6V-J
M:%T@57-E('=O<F1W<F%P(&EN(&$@<VQI9VAT;'D@9&EF9F5R96YT('=A>2P@
M=VAI8V@@<V5E;7,@=&\@<')O9'5C92!M=6-H"B`@("`@('!R971T:65R('%U
M;W1I;F<@;V8@;65S<V%G97,N"EMJ;VY=($%D9&5D(%!R969S+VUY<W%L+G!H
M<"!D<FEV97(@9G)O;2!-87@@2V%L:6MA(#QM87A`=&AE+71R:75M=FER871E
M+FYE=#XN"EMJ;VY=($YE=R!834PM8F%S960@:&5L<"!S=6)S>7-T96TN"EMC
M:FA=(%)E;F%M960@<&%C:V%G92YH;W)D92YP:'`@=&\@2&]R9&4N<&AP+@I;
M8VIH72!!9&0@:6UG*"D@86YD('!I;6<H*2!F=6YC=&EO;G,@=&\@=&AE($AO
M<F1E.CH@8VQA<W,@<V\@=&AA="!M;V1U;&5S"B`@("`@('5S:6YG(&]N;'D@
M<W1Y;&5S:&5E=',@9&]N)W0@;F5E9"!T:&4@2%1-3$1O8W5M96YT('!A8VMA
M9V4N"EMC:FA=($]M:70@=&AE('-E<W-I;VX@;F%M92]I9"!F<F]M('1H92!5
M4DP@:68@=V4@8V%N('9E<FEF>2!T:&%T(&-O;VMI97,*("`@("`@87)E(&)E
M:6YG(&%C8V5P=&5D+@I;:F]N72!.97<@=W)A<%]M97-S86=E(&9U;F-T:6]N
M('1H870@=7-E<R!T:&4@;F%T:79E('=O<F1W<F%P(&9U;F-T:6]N(&EF(&ET
M"B`@("`@(&5X:7-T<RX*6VIO;ET@57!D871I;F<@:&5A9&5R(&-O;6UE;G0@
M8V]P>7)I9VAT(&EN9F]R;6%T:6]N+@I;:F]N72!297!O<G0@;6]D=6QE('9E
M<G-I;VYS(&EN('1E<W0N<&AP(&]U='!U="X*6V-J:%T@;6EM95]E;F-A<'-U
M;&%T92@I(&YO=R!U<V5S(&%N(&%R<F%Y(&EN<W1E860@;V8@86X@;V)J96-T
M+@I;:F]N72!296UO=F5D('1H92`D7VAT;6Q;)V-O;7!O<V4J)UT@<VEZ:6YG
M('!A<F%M971E<G,@9G)O;2!C;VYF:6<O:'1M;"YP:'`N"EMC:FA=($QE879E
M($)C8SH@;W5T(&]F('1H92!H96%D97)S('1H870@87)E('!A<W-E9"!T;R!S
M96YD;6%I;"X*6VIO;ET@4F5W<FET92!A(&=O;V0@<&]R=&EO;B!O9B!T:&4@
M<V-R:7!T<R]S971?<&5R;7,N<V@@<V-R:7!T('-O"B`@("`@('1H870@:70@
M96YF;W)C97,@86X@97AT<F5M96QY(&AI9V@@;&5V96P@;V8@<V5C=7)I='DN
M"EMC:FA=(%1H92!V86QI9%]L86YG*"D@9G5N8W1I;VX@;F]W(')E<75I<F5S
M("1N;'-;)VQA;F=U86=E<R==6SQL86YG=6%G93Y="B`@("`@('1O(&)E('-E
M="!F;W(@82!L86YG=6%G92!T;R!B92!C;VYS:61E<F5D('9A;&ED("AI;G-T
M96%D(&]F(&IU<W0@=&AE"B`@("`@(&QO8V%L92!D:7)E8W1O<GD@97AI<W1I
M;F<I+@I;8VIH72!!9&1E9"!A("9S:6YG;&5T;VXH*2!M971H;V0@=&\@;6%K
M92!I="!E87-I97(@=&\@;VYL>2!C<F5A=&4@;VYE(&QO9PH@("`@("!I;G-T
M86YC92P@;F\@;6%T=&5R('=H96X@>6]U(&YE960@:70N"EMC:FA=($YO=R!M
M86EL9G)O;2@I('=O<FMS(&9O<B!R96-I<&EE;G0@861D<F5S<V5S('=I=&@@
M<VEN9VQE('%U;W1E<R!O<@H@("`@("!O=&AE<B!C:&%R86-T97)S('1H870@
M;F5E9"!T;R!B92!E<V-A<&5D(&EN('1H96TN"EMC:FA=($QO9R!C;&%S<R!N
M;W<@:&%S(&%N(&UC86P@:6YS=&%N8V4L(&$@8V]M<&]S:71E("AF;W(@9W)O
M=7!I;F<@;75L=&EP;&4*("`@("`@;&]G(&)A8VME;F1S*2P@86YD(&]B<V5R
M=F5R<R!R96=I<W1E<B!T:&4@;&5V96P@;V8@979E;G1S('1H97D@=V%N="!T
M;PH@("`@("!H96%R(&%B;W5T+"!A;F0@;VYL>2!G970@;F]T:69I960@;V8@
M979E;G1S(&%S(&EM<&]R=&%N="!O<B!M;W)E"B`@("`@(&EM<&]R=&%N="!T
M:&%N('1H870@;&5V96PN"EMC:FA=($%D9&5D(&$@3&]G.CH@9G)A;65W;W)K
M(&%N9"!S>7-L;V<@:6UP;&5M96YT871I;VXL(&EN8VQU9&EN9R!A"B`@("`@
M($QO9U]O8G-E<G9E<B!C;&%S<R!I;G1E;F1E9"!T;R!S:70@;VX@=&]P(&]F
M($QO8B!O8FIE8W1S(&%N9"!T86ME"B`@("`@(&%C=&EO;B!I;B!E>&-E<'1I
M;VYA;"!C:7)C=6US=&%N8V5S+@I;8VIH72!-86ME('-U<F4@=&\@86QW87ES
M('-E;F0@82!C:&%R<V5T('=I=&@@96UA:6QS+@I;8VIH72!);7!R;W9E9"!T
M:&4@;6EM95]D96-O9&4H*2!A;F0@;6EM95]E;F-O9&4H*2!F=6YC=&EO;G,N
M"EMC:FA=(%5P9&%T960@=&5S="YP:'`@=&\@<F5C;V=N:7IE('!H<#0@<W1A
M8FQE(')E;&5A<V5S+@I;:F]N72!296UO=F5D(&%L;"!O9B!T:&4@;&]C86QE
M+RHN;&%N9R!D97!E;F1E;F-I97,N"EMJ;VY=($%S<W5M92!T:&4@8G)O=W-E
M<B!I<R!F<F%M97,M8V%P86)L92!B>2!D969A=6QT+@I;8VIH72!!9&0@:&]R
M9&5?8VQE86YU<"@D9FEL96YA;64I+"!W:&EC:"!T86ME<R!C87)E(&]F(&1E
M;&5T:6YG(&9I;&5S('1H870*("`@("`@<VAO=6QD(&)E('5N;&EN:V5D(')E
M9V%R9&QE<W,@;V8@=VAE=&AE<B!O<B!N;W0@=&AE(')E<75E<W0@:7,*("`@
M("`@8V%N8V5L960@8GD@=&AE('5S97(@8F5F;W)E('=E(&9I;FES:"!E>&5C
M=71I;F<N"EMC:FA=(%)E;6]V92!P:'!L:6(@9&5P96YD86YC>2!I;B!F879O
M<B!O9B!P:'`T('-E<W-I;VYS+U!%05(N"EMC:FA=(%)E<&QA8V4@=7-E('=I
M=&@@<F5Q=6ER95]O;F-E+@I;8VIH72!&:7AE9"!U<"!S96QE8W1?;&%N9R@I
M('1O('=O<FL@*&ED96YT:6-A;"!T;R`Q+C(@;F]W*0I;8VIH72!(;W)D92!I
M<R!N;W<@=6YD97(@=&AE($Q'4$PN"EMC:FA=($9I>"!M86EL9G)O;2@I('-O
M(&ET(&1O97-N)W0@<V5N9"!E>'1R82!H96%D97)S('=H96X@=7-I;F<@;6%I
M;"@I"EMC:FA=($%D9&EN9R!A("=M87)G:6YS)R!A='1R:6)U=&4@=&\@2%1-
M3$1O8W5M96YT('1O(&5N86)L92!T=7)N:6YG(&]F9@H@("`@("!D;V-U;65N
M="!M87)G:6YS+@H*"BTM+2TM+0IV,2XS+C(*+2TM+2TM"@I;8VIH72!297!L
M86-E9"!M;V1U;&4N6$U,7U)$1BYP:'`@=VET:"!A('=O<FMI;F<@8V]P>2X*
M"@HM+2TM+2T*=C$N,RXQ"BTM+2TM+0H*6V-J:%T@4F5V86UP960@=&AE($UI
M;65-97-S86=E(&-L87-S('1O(&)E(&UU8V@@<VUA;&QE<B!A;F0@<VEM<&QE
M<BX*6V-J:%T@4F5P;&%C960@=&AE($UI;65087)T1&%T82!C;&%S<R!W:71H
M(&$@<V5T(&]F(&9U;F-T:6]N<R!T:&%T(&UO<F4*("`@("`@8VQE86YL>2!A
M;F0@8V]R<F5C=&QY(&EM<&QE;65N="!T:&4@34E-12!S=&%N9&%R9"X*6V-J
M:%T@<V5L96-T7VQA;F<H*2!N;W<@8VAE8VMS(&9O<B!E;B!W:&5N('1H92!B
M<F]W<V5R(')E<75E<W1S(&5N7T="+"!E=&,N"EMC:FA=(%)E<&QA8V5D(&%L
M;"!C86QL<R!T;R!E<F5G*B!F=6YC=&EO;G,@=VET:"!P<F5G*B!F=6YC=&EO
M;G,L(&9O<B!S<&5E9"X*("`@("`@0F5C875S92!O9B!T:&ES('=E(&YO=R!R
M97%U:7)E('!H<"`S+C`N,3(@;W(@;&%T97(N"@H*+2TM+2TM"G8Q+C,N,`HM
M+2TM+2T*"EL@("!=($=E<FUA;B!U<&1A=&5D"EL@("!=($9I>&5D('1H92!B
M<F]K96X@)V)A8VLG(&QI;FL@:6X@<V5T=7`N<&AP,R!F;W(@;F]N+45N9VQI
M<V@@=7-E<G,*6R`@(%T@;6%N86=E<BYP:'`S+"!D8BYL:6(L(&%N9"!C;VAO
M<G1S(&%R92!N;W<@9V]N92X@5&AE>2!W97)E(&%L;"!U;FUA:6YT86EN960L
M(&]U="!O9B!D871E+"!A;F0@;F]T('9E<GD@=7-E9G5L+@H@("`@("!687)I
M;W5S(&)U:6QD('-C<FEP=',@87)E('5P9&%T960@=&\@<F5F;&5C="!T:&ES
M+@I;:F]N72!296UO=F5D(&-O;F9I9R]D969A=6QT<RYP:'`S(&EN('!R969E
M<F5N8V4@;V8@:&]R9&4N<&AP,PI;("`@72!&:7AE9"!A('-E='5P+G!H<#,@
M8G5G('=H97)E("(@=V%S('5S960@:6YS=&5A9"!O9B`G(&9O<B`D9&5F875L
M="!V86QU97,@*&UI:V4I"EL@("!=($YE=R!&:6YN:7-H('1R86YS;&%T:6]N
M<R`H5&AA;FMS('1O.B!L96\N:F%A<VME;&%I;F5N0&MO;'5M8G5S+F9I*0I;
M("`@72!&:7AE9"!L>6YX('-U<'!O<G0@:7-S=64@=VET:"!L;V=I;BYP:'`S
M"EL@("!=($9I>&5D('-I9VYU<"YP:'`S('!R;V)L96US"EL@("!=($9I>&5D
M('!R;V)L96TN<&AP,R!P<F]B;&5M<R`H;'EN>"!S=7!P;W)T*0I;("`@72!!
M9&1E9"!D871A8F%S92!C<F5A=&EO;B!S8W)I<'1S(&9O<B!B=6EL9&EN9R!P
M:'!L:6(@8V]M<&QI86X@=&%B;&5S"EL@("!=($UO=F5D(&%L;"!D;V-U;65N
M=&%T:6]N("AE>&-E<'0@4D5!1$U%(&%N9"!#3U!924Y'*2!I;G1O(&1O8W,O
M('-U8F1I<@I;("`@72!!9&1E9"!A(&-A8VAI;F<@8VQA<W,@<V\@=&AA="!C
M86-H:6YG(&-A;B!B92!T=7)N960@;VX@<&5R('!A9V4@:68@;F5E9&5D"@H*
M+2TM+2TM"G8Q+C$N,0HM+2TM+2T*"EL@("!=($AO<F1E('5N9&5R<W1A;F1S
M($9R96YC:"`H=&AA;FMS('1O($UA=&AI974@0VQA8F%U=`H@("`@("`\8VQA
M8F%U;'1`;75L=&EM86YI82YC;VT^*0I;("`@72!-86IO<B!F<F%M97-E="!R
M961E<VEG;@I;("`@72!!=71O(')E9VES=')A=&EO;B]C;VYG:7)U871I;VX@
M;V8@;6]D=6QE<PH*"BTM+2TM+0IV,2XP+C,*+2TM+2TM"@I;("`@72!(;W)D
M92!I<R!N;W<@=V5B('-U<F9A8FQE+@I;("`@72!(;W)D92!H86YD;&5S(&QY
M;G@@*'!S975D;VQY*0I;("`@72!%>'1E;F1A8FQE(&UE;G5S+B`H;65N=2YT
M>'0@:6X@:&]R9&4O8V]N9FEG*0I;("`@72!3:6=N=7`L('!R;V)L96T@<F5P
M;W)T:6YG+"!H96QP(&9U;F-T:6]N<R!A<F4@;F]W('!A<G0@;V8@:&]R9&4*
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]D;V-S+T-/1$E.1U]35$%.
M1$%21%,`````````````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M-C$U,#8@,3`U,34T,S,W,S,@,#(P-S<P`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/0H@2&]R9&4@0V]D:6YG(%-T86YD87)D<PH]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T*"CI,87-T('5P9&%T93H@("`D1&%T93H@,C`P-B\P,R\Q-R`P-CHQ
M.#HP-R`D"CI2979I<VEO;CH@("`@("`D4F5V:7-I;VXZ(#$N.#0N,3`N,34@
M)`HZ075T:&]R<SH@("`@("`@2F]N(%!A<FES92P@0VAU8VL@2&%G96YB=6-H
M"CI#;VYT86-T.B`@("`@("!D979`;&ES=',N:&]R9&4N;W)G"@HN+B!C;VYT
M96YT<SHZ($-O;G1E;G1S"BXN('-E8W1I;VXM;G5M8F5R:6YG.CH*"DEN9&5N
M=&EN9PH]/3T]/3T]/3T*"E5S92!A;B!I;F1E;G0@;V8@-"!S<&%C97,L('=I
M=&@@;F\@=&%B<RX*"@I#;VYT<F]L(%-T<G5C='5R97,*/3T]/3T]/3T]/3T]
M/3T]/3T]"@I4:&5S92!I;F-L=61E(&!@:69@8"P@8&!F;W)@8"P@8&!W:&EL
M96!@+"!@8'-W:71C:&!@+"!E=&,N("!(97)E(&ES(&%N(&5X86UP;&4*8&!I
M9F!@('-T871E;65N="P@<VEN8V4@:70@:7,@=&AE(&UO<W0@8V]M<&QI8V%T
M960@;V8@=&AE;3HZ"@H@(&EF("@H8V]N9&ET:6]N,2D@?'P@*&-O;F1I=&EO
M;C(I*2!["B`@("`@(&%C=&EO;C$["B`@?2!E;'-E:68@*"AC;VYD:71I;VXS
M*2`F)B`H8V]N9&ET:6]N-"DI('L*("`@("`@86-T:6]N,CL*("!](&5L<V4@
M>PH@("`@("!D969A=6QT86-T:6]N.PH@('T*"DUU;'1I+6QI;F4@:68@8V]N
M9&ET:6]N<R!A<F4@8G)A8V5D('1H:7,@=V%Y.CH*"B`@:68@*"AC;VYD:71I
M;VXQ*2!\?"`H8V]N9&ET:6]N,BD@?'P@*&-O;F1I=&EO;C,I('Q\"B`@("`@
M("AC;VYD:71I;VXT*2D@>PH@("`@("!A8W1I;VXQ.PH@('T*"D-O;G1R;VP@
M<W1A=&5M96YT<R!S:&]U;&0@:&%V92!O;F4@<W!A8V4@8F5T=V5E;B!T:&4@
M8V]N=')O;"!K97EW;W)D(&%N9`IO<&5N:6YG('!A<F5N=&AE<VES+"!T;R!D
M:7-T:6YG=6ES:"!T:&5M(&9R;VT@9G5N8W1I;VX@8V%L;',N"@I$;R!N;W0@
M;VUI="!T:&4@8W5R;'D@8G)A8V5S('5N9&5R(&%N>2!C:7)C=6US=&%N8V4N
M("!);B!T:&4@8V%S92!O9B!A(&QA<F=E"FYU;6)E<B!O9B!S:&]R="!T97-T
M<R!A;F0@86-T:6]N<RP@=&AE(&9O;&QO=VEN9R!I<R!A8V-E<'1A8FQE.CH*
M"B`@:68@*&-O;F1I=&EO;BD@("![(&%C=&EO;CL@?0H@(&EF("AC;VYD:71I
M;VX@,BD@>R!A8W1I;VX@,CL@?0H@("XN+@H*1F]R('-W:71C:"!S=&%T96UE
M;G1S.CH*"B`@<W=I=&-H("AC;VYD:71I;VXI('L*("!C87-E(#$Z"B`@("`@
M(&%C=&EO;C$["B`@("`@(&)R96%K.PH*("!C87-E(#(Z"B`@("`@(&%C=&EO
M;C(["B`@("`@(&)R96%K.PH*("!D969A=6QT.@H@("`@("!D969A=6QT86-T
M:6]N.PH@("`@("!B<F5A:SL*("!]"@H*1G5N8W1I;VX@0V%L;',*/3T]/3T]
M/3T]/3T]/3T*"D9U;F-T:6]N<R!S:&]U;&0@8F4@8V%L;&5D('=I=&@@;F\@
M<W!A8V5S(&)E='=E96X@=&AE(&9U;F-T:6]N(&YA;64L('1H90IO<&5N:6YG
M('!A<F5N=&AE<VES+"!A;F0@=&AE(&9I<G-T('!A<F%M971E<CL@<W!A8V5S
M(&)E='=E96X@8V]M;6%S(&%N9"!E86-H"G!A<F%M971E<BP@86YD(&YO('-P
M86-E(&)E='=E96X@=&AE(&QA<W0@<&%R86UE=&5R+"!T:&4@8VQO<VEN9R!P
M87)E;G1H97-I<RP*86YD('1H92!S96UI8V]L;VXN("!(97)E)W,@86X@97AA
M;7!L93HZ"@H@("1V87(@/2!F;V\H)&)A<BP@)&)A>BP@)'%U=7@I.PH*07,@
M9&ES<&QA>65D(&%B;W9E+"!T:&5R92!S:&]U;&0@8F4@;VYE('-P86-E(&]N
M(&5I=&AE<B!S:61E(&]F(&%N(&5Q=6%L<R!S:6=N"G5S960@=&\@87-S:6=N
M('1H92!R971U<FX@=F%L=64@;V8@82!F=6YC=&EO;B!T;R!A('9A<FEA8FQE
M+B`@26X@=&AE(&-A<V4@;V8@80IB;&]C:R!O9B!R96QA=&5D(&%S<VEG;FUE
M;G1S+"!M;W)E('-P86-E(&UA>2!B92!I;G-E<G1E9"!T;R!P<F]M;W1E"G)E
M861A8FEL:71Y.CH*"B`@)'-H;W)T("`@("`@("`@/2!F;V\H)&)A<BD["B`@
M)&QO;F=?=F%R:6%B;&4@/2!F;V\H)&)A>BD["@H*1G5N8W1I;VX@1&5F:6YI
M=&EO;G,*/3T]/3T]/3T]/3T]/3T]/3T]/3T*"D9U;F-T:6]N(&1E8VQA<F%T
M:6]N<R!F;VQL;W<@=&AE(")"4T0O06QL;6%N(B!C;VYV96YT:6]N.CH*"B`@
M9G5N8W1I;VX@9F]O1G5N8W1I;VXH)&%R9S$L("1A<F<R(#T@)R<I"B`@>PH@
M("`@("!I9B`H8V]N9&ET:6]N*2!["B`@("`@("`@("!S=&%T96UE;G0["B`@
M("`@('T*("`@("`@<F5T=7)N("1V86P["B`@?0H*07)G=6UE;G1S('=I=&@@
M9&5F875L="!V86QU97,@9V\@870@=&AE(&5N9"!O9B!T:&4@87)G=6UE;G0@
M;&ES="X@($%L=V%Y<PIA='1E;7!T('1O(')E='5R;B!A(&UE86YI;F=F=6P@
M=F%L=64@9G)O;2!A(&9U;F-T:6]N(&EF(&]N92!I<R!A<'!R;W!R:6%T92X*
M"D9U;F-T:6]N<R!U<V5D(&]N;'D@:6X@=&AE(&-U<G)E;G0@<V-R:7!T+V-L
M87-S("AE+F<N('!R:79A=&4@;65M8F5R(&UE=&AO9',I"G-H;W5L9"!B96=I
M;B!W:71H(&$@8&!?8&`@8VAA<F%C=&5R("AE+F<N(&!@7V5X86UP;&5,:6)R
M87)Y8&`I+B`@5&AI<R!H96QP<PID:7-T:6YG=6ES:"!T:&5S92!P<FEV871E
M(&9U;F-T:6]N(&-A;&QS(&9R;VT@;W1H97(L('!U8FQI8R!F=6YC=&EO;B!C
M86QL<RX*"@I#;&%S<R!$969I;FET:6]N<PH]/3T]/3T]/3T]/3T]/3T]/0H*
M0VQA<W,@9&5F:6YI=&EO;G,@9F]L;&]W('1H92`B2R92+TME<FYE;"(@8V]N
M=F5N=&EO;CHZ"@H@(&-L87-S(%-O;65?0VQA<W,@>PH*("`@("`@=F%R("1?
M=F%R:6%B;&4["@H@("`@("!F=6YC=&EO;B!F;V]&=6YC=&EO;B@I"B`@("`@
M('L*("`@("`@("`@('-T871E;65N=#L*("`@("`@?0H*("!]"@I.;W1E('1H
M92!B;&%N:R!L:6YE<R!A="!T:&4@8F5G:6YN:6YG(&%N9"!E;F0@;V8@=&AE
M(&-L87-S(&1E9FEN:71I;VXN"@H*3F%M:6YG($QI8G)A<FEE<PH]/3T]/3T]
M/3T]/3T]/3T]"@I,:6)R87)I97,@*&%N>2!F:6QE(&QO8V%T960@:6X@=&AE
M(&!@;&EB+V!@(&1I<F5C=&]R>2!O9B!T:&4@87!P;&EC871I;VXI"G-H;W5L
M9"!B92!N86UE9"!W:71H(&-A<&ET86P@;&5T=&5R<R!A="!T:&4@8F5G:6YN
M:6YG(&]F(&5A8V@@=V]R9"X@(%5S90IS='5D;'EC87!S(&9O<B!N86UI;F<[
M(&$@<V5S<VEO;B!C86-H92!C;&%S<R!W;W5L9"!B92!S=&]R960@:6X*8&!L
M:6(O4V5S<VEO;D-A8VAE+G!H<&!@+@H*268@=&AE(&QI8G)A<GDO8VQA<W,@
M:7,@97AT96YD960L('1H92!E>'1E;F1I;F<@9FEL97,@<VAO=6QD(&)E('-T
M;W)E9"!I;B!A"F1I<F5C=&]R>2!U;F1E<B!@8&QI8B]@8"!W:71H('1H92!S
M86UE(&YA;64@87,@=&AE(&]R:6=I;F%L(&QI8G)A<GDN"E-U8F-L87-S97,@
M9F]L;&]W('1H92!E>&%C="!S86UE(&YA;6EN9R!R97%U:7)E;65N=',L(&5X
M8V5P="!T:&%T(&EF('1H90IS=6)C;&%S<R!I<R!I;G-T86YT:6%T960@8GD@
M82!F86-T;W)Y(&UE=&AO9"P@:70@<VAO=6QD(&)E(&%L;"!L;W=E<F-A<V4N
M"@I%>&%M<&QE"BTM+2TM+2T*"E1H92`B17AA;7!L92!,:6)R87)Y(B!L:6)R
M87)Y('-H;W5L9"!B92!S879E9"!A<R!@8&QI8B]%>&%M<&QE3&EB<F%R>2YP
M:'!@8"X*06YY(&9I;&4@97AT96YD:6YG('1H92!L:6)R87)Y+V-L87-S('-H
M;W5L9"!B92!S=&]R960@:6X@=&AE(&1I<F5C=&]R>0I@8&QI8B]%>&%M<&QE
M3&EB<F%R>2]@8"X*"@I#;VUM96YT<PH]/3T]/3T]/0H*26YL:6YE(&1O8W5M
M96YT871I;VX@9F]R(&-L87-S97,@<VAO=6QD(&9O;&QO=R!T:&4@8$IA=F%D
M;V,@8V]N=F5N=&EO;F!?+@H*+BX@7TIA=F%D;V,@8V]N=F5N=&EO;CH@:'1T
M<#HO+VIA=F$N<W5N+F-O;2]P<F]D=6-T<R]J9&LO:F%V861O8R]W<FET:6YG
M9&]C8V]M;65N=',O:6YD97@N:'1M;`H*475I8VL@97AA;7!L92!F;W(@<')I
M=F%T92!V87)I86)L92!D969I;FET:6]N(&9O<B!(;W)D93HZ"@H@("`@+RHJ
M"B`@("`@*B!687)I86)L92!D97-C<FEP=&EO;BX*("`@("`J"B`@("`@*B!`
M=F%R(&1A=&%T>7!E"B`@("`@*B\*"E%U:6-K(&5X86UP;&4@9G5N8W1I;VX@
M9&5F:6YI=&EO;B!F;W(@2&]R9&4Z.@H*("`@("\J*@H@("`@("H@5&AE(&1E
M<V-R:7!T:6]N(&]F('1H92!F=6YC=&EO;B!G;V5S(&AE<F4N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!;<')I=F%T92!\('!R;W1E8W1E9%T*("`@("`J(%M$
M;VXG="!B;W1H97(@=VET:"`B<'5B;&EC(B!S:6YC92!I="!I<R!T:&4@9&5F
M875L="!I9B!N;W0@<W!E8VEF:65D+ET*("`@("`J"B`@("`@*B!`<&%R86T@
M9&%T871Y<&4@)'9A<FEA8FQE;F%M92`@($1E<V-R:7!T:6]N(&]F('9A<FEA
M8FQE+@H@("`@("H@0'!A<F%M(&1A=&%T>7!E("1V87)I86)L93)N86UE("!$
M97-C<FEP=&EO;B!O9B!V87)I86)L93(N"B`@("`@*B`N+BX*("`@("`J(%M)
M;G-E<G0@,B!S<&%C97,@869T97(@=&AE(&QO;F=E<W0@)'9A<FEA8FQE(&1E
M9FEN:71I;VXL(&%N9"!T:&5N(&QI;F4*("`@("`J("!U<"!A;&P@9&5S8W)I
M<'1I;VYS('=I=&@@=&AI<R!D97-C<FEP=&EO;ET*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&1A=&%T>7!E("!$97-C<FEP=&EO;B!O9B!R971U<FX@=F%L=64N
M"B`@("`@*B!;3VYC92!A9V%I;BP@:6YS97)T(#(@<W!A8V5S(&%F=&5R('1H
M92!D871A='EP92P@86YD(&QI;F4@=7`@86QL"B`@("`@*B`@<W5B<V5Q=65N
M="!L:6YE<RP@:68@86YY+"!W:71H('1H:7,@8VAA<F%C=&5R+ET*("`@("`J
M"B`@("`@*B!`86)S=')A8W0@6T]N;'D@:68@;F5C97-S87)Y70H@("`@("H*
M("`@("`J($!S:6YC92!(;W)D92!X+G@@6T]N;'D@:68@;F5C97-S87)Y("T@
M=7-E(&EF(&9U;F-T:6]N(&ES(&%D9&5D('1O('1H90H@("`@("H@8W5R<F5N
M="!R96QE87-E('9E<G-I;VYS('1O(&EN9&EC871E('1H870@=&AE(&9U;F-T
M:6]N(&AA<R!N;W0@8F5E;@H@("`@("H@879A:6QA8FQE(&EN('!R979I;W5S
M('9E<G-I;VYS+ET*("`@("`J+PH*"DEN8VQU9&EN9R!#;V1E"CT]/3T]/3T]
M/3T]/3T]"@I)9B!Y;W4@87)E(&EN8VQU9&EN9R!A(&-L87-S+"!F=6YC=&EO
M;B!L:6)R87)Y+"!O<B!A;GET:&EN9R!E;'-E('=H:6-H('=O=6QD"F-A=7-E
M(&$@<&%R<V4@97)R;W(@:68@:6YC;'5D960@='=I8V4L(&%L=V%Y<R!U<V4@
M8&EN8VQU9&5?;VYC96!?+B`@5&AI<R!W:6QL"F5N<W5R92!T:&%T(&YO(&UA
M='1E<B!H;W<@;6%N>2!F86-T;W)Y(&UE=&AO9',@=V4@=7-E(&]R(&AO=R!M
M=6-H(&1Y;F%M:6,*:6YC;'5S:6]N('=E(&1O+"!T:&4@;&EB<F%R>2!W:6QL
M(&]N;'D@8F4@:6YC;'5D960@;VYC92X*"DEF('EO=2!A<F4@:6YC;'5D:6YG
M(&$@<W1A=&EC(&9I;&5N86UE+"!S=6-H(&%S(&$@8V]N9B!F:6QE(&]R(&$@
M=&5M<&QA=&4@=&AA=`II<R`J86QW87ES*B!U<V5D+"!U<V4@8')E<75I<F5@
M7RX*"DEF('EO=2!A<F4@9'EN86UI8V%L;'D@:6YC;'5D:6YG(&$@9FEL96YA
M;64L(&]R('=A;G0@=&AE(&-O9&4@=&\@;VYL>2!B92!U<V5D"F-O;F1I=&EO
M;F%L;'D@*&%N(&]P=&EO;F%L('1E;7!L871E*2P@=7-E(&!I;F-L=61E8%\N
M"@HN+B!?:6YC;'5D95]O;F-E.B!H='1P.B\O=W=W+G!H<"YN970O;6%N=6%L
M+V5N+V9U;F-T:6]N+FEN8VQU9&4M;VYC92YP:'`*+BX@7W)E<75I<F4Z(&AT
M='`Z+R]W=W<N<&AP+FYE="]M86YU86PO96XO9G5N8W1I;VXN<F5Q=6ER92YP
M:'`*+BX@7VEN8VQU9&4Z(&AT='`Z+R]W=W<N<&AP+FYE="]M86YU86PO96XO
M9G5N8W1I;VXN:6YC;'5D92YP:'`*"@I02%`@0V]D92!486=S"CT]/3T]/3T]
M/3T]/3T*"D%L=V%Y<R!U<V4@8&`\/W!H<"`_/F!@('1O(&1E;&EM:70@4$A0
M(&-O9&4L(&YO="!T:&4@8&`\/R`_/F!@('-H;W)T:&%N9"X*5&AI<R!I<R!R
M97%U:7)E9"!F;W(@4$5!4B!C;VUP;&EA;F-E(&%N9"!I<R!A;'-O('1H92!M
M;W-T('!O<G1A8FQE('=A>2!T;PII;F-L=61E(%!(4"!C;V1E(&]N(&1I9F9E
M<FEN9R!O<&5R871I;F<@<WES=&5M<R!A;F0@<V5T=7!S+@H*26X@=&5M<&QA
M=&5S+"!M86ME('-U<F4@=&\@=7-E('1H:7,@87,@=V5L;"`H8&`\/W!H<"!E
M8VAO("1V87)N86UE(#\^8&`I+"!A<PIT:&4@<VAO<G1C=70@=F5R<VEO;B`H
M8&`\/ST@)'9A<B`_/F!@*2!D;V5S(&YO="!W;W)K('=I=&@@8'-H;W)T7V]P
M96Y?=&%G8%\*='5R;F5D(&]F9BX*"BXN(%]S:&]R=%]O<&5N7W1A9SH@:'1T
M<#HO+W=W=RYP:'`N;F5T+VUA;G5A;"]E;B]C;VYF:6=U<F%T:6]N+F1I<F5C
M=&EV97,N<&AP(VEN:2YS:&]R="UO<&5N+71A9PH*"DAE861E<B!#;VUM96YT
M($)L;V-K<PH]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"D%L;"!S;W5R8V4@8V]D
M92!F:6QE<R!I;B!T:&4@2&]R9&4@9&ES=')I8G5T:6]N('-H;W5L9"!C;VYT
M86EN('1H92!F;VQL;W=I;F<*8V]M;65N="!B;&]C:R!A<R!T:&4@:&5A9&5R
M.@H*17AA;7!L92!F;W(@8$Q'4$Q@7R=E9"!(;W)D92!C;V1E.CH*"B`@("`O
M*BH*("`@("`J(%1H92!(;W)D95]&;V\Z.B!C;&%S<R!P<F]V:61E<R!A;B!!
M4$D@9F]R('9A<FEO=7,@9F]O"B`@("`@*B!T96-H;FEQ=65S('1H870@8V%N
M(&)E('5S960@8GD@2&]R9&4@87!P;&EC871I;VYS+@H@("`@("H*("`@("`J
M("1(;W)D90H@("`@("H*("`@("`J($-O<'ER:6=H="`Q.3DY+3(P,#$@3W)I
M9VEN86P@075T:&]R(#QA=71H;W)`97AA;7!L92YC;VT^"B`@("`@*B!#;W!Y
M<FEG:'0@,C`P,2!9;W5R($YA;64@/'EO=4!E>&%M<&QE+F-O;3X*("`@("`J
M"B`@("`@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@("`@("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`@("`@*@H@("`@("H@0&%U=&AO<B`@3W)I
M9VEN86P@075T:&]R(#QA=71H;W)`97AA;7!L92YC;VT^"B`@("`@*B!`875T
M:&]R("!9;W5R($YA;64@/'EO=4!E>&%M<&QE+F-O;3X*("`@("`J($!S:6YC
M92`@($AO<F1E(#,N,`H@("`@("H@0'!A8VMA9V4@2&]R9&5?4&%C:V%G90H@
M("`@("HO"@HN+B!?3$=03#H@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L
M:6-E;G-E<R]L9W!L+6QI8V5N<V4N<&AP"@I%>&%M<&QE(&9O<B!@1U!,8%\G
M960@87!P;&EC871I;VX@8V]D93HZ"@H@("`@+RHJ"B`@("`@*B!4:&4@07!P
M7T)A<CHZ(&-L87-S(&-O;G1A:6YS(&%L;"!F=6YC=&EO;G,@<F5L871E9"!T
M;R!H86YD;&EN9PH@("`@("H@8F%R<R!I;B!!<'`N"B`@("`@*@H@("`@("H@
M)$AO<F1E"B`@("`@*@H@("`@("H@0V]P>7)I9VAT(#$Y.3DM,C`P,2!/<FEG
M:6YA;"!!=71H;W(@/&%U=&AO<D!E>&%M<&QE+F-O;3X*("`@("`J($-O<'ER
M:6=H="`R,#`Q(%EO=7(@3F%M92`\>6]U0&5X86UP;&4N8V]M/@H@("`@("H*
M("`@("`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A'4$PI+B!)9B!Y;W4*("`@("`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O9W!L+FAT;6PN"B`@("`@*@H@("`@("H@0&%U=&AO<B`@3W)I9VEN
M86P@075T:&]R(#QA=71H;W)`97AA;7!L92YC;VT^"B`@("`@*B!`875T:&]R
M("!9;W5R($YA;64@/'EO=4!E>&%M<&QE+F-O;3X*("`@("`J($!S:6YC92`@
M($%P<"`Q+C`*("`@("`J($!P86-K86=E(&%P<`H@("`@("HO"@H*+BX@7T=0
M3#H@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]G<&PM;&EC
M96YS92YP:'`*"E1H97)E)W,@;F\@:&%R9"!R=6QE('1O(&1E=&5R;6EN92!W
M:&5N(&$@;F5W(&-O9&4@8V]N=')I8G5T97(@<VAO=6QD(&)E(&%D9&5D"G1O
M('1H92!L:7-T(&]F(&%U=&AO<G,@9F]R(&$@9VEV96X@<V]U<F-E(&9I;&4N
M("!);B!G96YE<F%L+"!T:&5I<B!C:&%N9V5S"G-H;W5L9"!F86QL(&EN=&\@
M=&AE(")S=6)S=&%N=&EA;"(@8V%T96=O<GD@*&UE86YI;F<@<V]M97=H97)E
M(&%R;W5N9"`Q,"4@=&\*,C`E(&]F(&-O9&4@8VAA;F=E<RDN("!%>&-E<'1I
M;VYS(&-O=6QD(&)E(&UA9&4@9F]R(')E=W)I=&EN9R!F=6YC=&EO;G,@;W(*
M8V]N=')I8G5T:6YG(&YE=R!L;V=I8RX*"E-I;7!L92!C;V1E(')E;W)G86YI
M>F%T:6]N(&]R(&)U9R!F:7AE<R!W;W5L9"!N;W0@:G5S=&EF>2!T:&4@861D
M:71I;VX@;V8@80IN97<@:6YD:79I9'5A;"!T;R!T:&4@;&ES="!O9B!A=71H
M;W)S+@H*"D-64R!486=S"CT]/3T]/3T]"@I);F-L=61E('1H92`\9&]L;&%R
M/DAO<F1E.B`\9&]L;&%R/B!#5E,@=F5N9&]R('1A9R!I;B!E86-H(&9I;&4N
M("!!<R!E86-H(&9I;&4*:7,@961I=&5D+"!A9&0@=&AI<R!T86<@:68@:70G
M<R!N;W0@>65T('!R97-E;G0@*&]R(')E<&QA8V4@97AI<W1I;F<@9F]R;7,*
M<W5C:"!A<R`\9&]L;&%R/DED/&1O;&QA<CXL("),87-T($UO9&EF:65D.B(L
M(&5T8RXI+@H*15A#15!424]..B!$;VXG="!I;F-L=61E('1H97-E(&EN('1E
M;7!L871E<RX*"@I%>&%M<&QE(%523',*/3T]/3T]/3T]/3T]"@I5<V4@8&!E
M>&%M<&QE+F-O;6!@(&9O<B!A;&P@97AA;7!L92!54DQS+"!P97(@8%)&0R`R
M-C`V8%\N"@HN+B!?4D9#(#(V,#8Z(&AT='`Z+R]W=W<N9F%Q<RYO<F<O<F9C
M<R]R9F,R-C`V+FAT;6P*"@IP:'`N:6YI('-E='1I;F=S"CT]/3T]/3T]/3T]
M/3T]/3T*"D%L;"!(;W)D92!C;V1E('-H;W5L9"!W;W)K('=I=&@@8')E9VES
M=&5R7V=L;V)A;'-@7R!D:7-A8FQE9"X@(%1H:7,@;65A;G,*=7-I;F<@8&`D
M7T-/3TM)16!@+"!@8"1?4T534TE/3F!@+"!@8"1?4T525D528&`@86YD(&!@
M)%]%3E9@8"!T;R!A8V-E<W,@86QL"F-O;VMI92P@<V5S<VEO;BP@<V5R=F5R
M(&%N9"!E;G9I<F]N;65N="!D871A+"!R97-P96-T:79E;'DN"@I4;R!R971R
M:65V92!P;W-T960@9&%T82`H:6X@=&AE(&=L;V)A;"!@8"1?1T548&`@86YD
M(&!@)%]03U-48&`@=F%R:6%B;&5S*2P*>6]U('-H;W5L9"!N;W)M86QL>2!U
M<V4@8%5T:6PZ.F=E=$9O<FU$871A*"E@7R!W:&EC:"!W:6QL(&%U=&]M871I
M8V%L;'D@<G5N"F!5=&EL.CID:7-P96Q-86=I8U%U;W1E<R@I8%\N(%1H:7,@
M=VEL;"!E;G-U<F4@=&AA="!A;&P@2&]R9&4@8V]D92!W:6QL('=O<FL*<F5G
M87)D;&5S<R!O9B!T:&4@<V5T=&EN9R!O9B!@;6%G:6-?<75O=&5S7V=P8V!?
M+B!4:&4@;VYL>2!T:6UE('EO=2!S:&]U;&0@;F]T"G5S92!@571I;#HZ9V5T
M1F]R;41A=&$H*6!?(&ES(&EF('EO=2!W86YT('1O(&1I<F5C=&QY(&%C8V5S
M<R!A($=%5"!O<B!03U-4"G9A<FEA8FQE(&EN<W1E860[(&EN('1H:7,@8V%S
M92P@>6]U('-H;W5L9"!U<V4@8%5T:6PZ.F=E=$=E="@I8%\@;W(*8%5T:6PZ
M.F=E=%!O<W0H*6!?(')E<W!E8W1I=F5L>2X*"D%L;"!(;W)D92!C;V1E('-H
M;W5L9"!W;W)K('=I=&@@8&5R<F]R7W)E<&]R=&EN9V!?(#T@15]!3$PN($9A
M:6QU<F4@=&\@9&\@<V\*=V]U;&0@<F5S=6QT(&EN('5G;'D@;W5T<'5T+"!E
M<G)O<B!L;V=S(&=E='1I;F<@9FEL;&5D('=I=&@@;&]T<R!O9B!W87)N:6YG
M"FUE<W-A9V5S+"!O<B!E=F5N(&1O=VYR:6=H="!B<F]K96X@<V-R:7!T<RX*
M"DYO($AO<F1E(&-O9&4@<VAO=6QD(&%S<W5M92!T:&%T("<N)R!I<R!I;B!T
M:&4@:6YC;'5D92!P871H+B!!;'=A>7,@<W!E8VEF>0HG+B\G(&EN(&9R;VYT
M(&]F(&$@9FEL96YA;64@=VAE;B!Y;W4@87)E(&EN8VQU9&EN9R!A(&9I;&4@
M:6X@=&AE('-A;64*9&ER96-T;W)Y+@H*+BX@7W)E9VES=&5R7V=L;V)A;',Z
M(&AT='`Z+R]W=W<N<&AP+FYE="]M86YU86PO96XO<V5C=7)I='DN<F5G:7-T
M97)G;&]B86QS+G!H<`HN+B!?;6%G:6-?<75O=&5S7V=P8SH@:'1T<#HO+W=W
M=RYP:'`N;F5T+VUA;G5A;"]E;B]R968N:6YF;RYP:'`C:6YI+FUA9VEC+7%U
M;W1E<RUG<&,*+BX@7V5R<F]R7W)E<&]R=&EN9SH@:'1T<#HO+W=W=RYP:'`N
M;F5T+VUA;G5A;"]E;B]R968N97)R;W)F=6YC+G!H<"-I;FDN97)R;W(M<F5P
M;W)T:6YG"BXN(%]5=&EL.CIG971&;W)M1&%T82@I.B!H='1P.B\O9&5V+FAO
M<F1E+F]R9R]A<&DO9G)A;65W;W)K+TAO<F1E7U5T:6PO571I;"YH=&UL(VUE
M=&AO9&=E=$9O<FU$871A"BXN(%]5=&EL.CID:7-P96Q-86=I8U%U;W1E<R@I
M.B!H='1P.B\O9&5V+FAO<F1E+F]R9R]A<&DO9G)A;65W;W)K+TAO<F1E7U5T
M:6PO571I;"YH=&UL(VUE=&AO9&1I<W!E;$UA9VEC475O=&5S"BXN(%]5=&EL
M.CIG971'970H*3H@:'1T<#HO+V1E=BYH;W)D92YO<F<O87!I+V9R86UE=V]R
M:R](;W)D95]5=&EL+U5T:6PN:'1M;"-M971H;V1G971'970*+BX@7U5T:6PZ
M.F=E=%!O<W0H*3H@:'1T<#HO+V1E=BYH;W)D92YO<F<O87!I+V9R86UE=V]R
M:R](;W)D95]5=&EL+U5T:6PN:'1M;"-M971H;V1G9710;W-T"@H*6$A434P@
M,2XP($-O;7!L:6%N8V4*/3T]/3T]/3T]/3T]/3T]/3T]/3T*"D%L;"!T86<@
M;F%M97,@86YD('!A<F%M971E<G,@;75S="!B92!L;W=E<B!C87-E(&EN8VQU
M9&EN9R!J879A<V-R:7!T(&5V96YT"FAA;F1L97)S.CH*"B`@("`\9F]N="!C
M;VQO<CTB(T9&1D9&1B(^+BXN/"]F;VYT/@H@("`@/&$@:')E9CTB:'1T<#HO
M+V5X86UP;&4N8V]M(B!O;FUO=7-E;W9E<CTB<W1A='5S/2<G(B!O;FUO=7-E
M;W5T/2)S=&%T=7,])R<B/BXN+CPO83X*"D%L;"!T86<@<&%R86UE=&5R<R!M
M=7-T(&)E(&]F(&$@=F%L:60@<&%R86UE=&5R/2)V86QU92(@9F]R;2`H;G5M
M97)I8R!V86QU97,*;75S="!A;'-O(&)E('-U<G)O=6YD960@8GD@<75O=&5S
M*2X@($9O<B!P87)A;65T97)S('1H870@:&%D(&YO('9A;'5E(&EN($A434PL
M"G1H92!P87)A;65T97(@;F%M92!I<R!T:&4@=F%L=64N("!&;W(@97AA;7!L
M93HZ"@H@("`@/&EN<'5T('1Y<&4](F-H96-K8F]X(B!C:&5C:V5D/2)C:&5C
M:V5D(CX*("`@(#QS96QE8W0@;F%M93TB97AA;7!L92(^"B`@("`@("`@/&]P
M=&EO;B!S96QE8W1E9#TB<V5L96-T960B('9A;'5E/2(Q(CY%>&%M<&QE/"]O
M<'1I;VX^"B`@("`\+W-E;&5C=#X*("`@(#QT9"!N;W=R87`](FYO=W)A<"(^
M17AA;7!L93PO=&0^"@I!;&P@=&%G<R!M=7-T(&)E('!R;W!E<FQY(&-L;W-E
M9"X@(%1A9W,@=VAE<F4@8VQO<VEN9R!I<R!F;W)B:61D96X@;75S="!E;F0*
M=VET:"!A('-P86-E(&%N9"!A('-L87-H.CH*"B`@("`\8G(@+SX*("`@(#QH
M<B`O/@H@("`@/&EM9R!S<F,](F5X86UP;&4N9VEF(B!A;'0](D5X86UP;&4B
M("\^"B`@("`\:6YP=70@='EP93TB<W5B;6ET(B!V86QU93TB17AA;7!L92(@
M+SX*"D%L;"!F;W)M(&1E9FEN:71I;VYS(&UU<W0@8F4@;VX@=&AE:7(@;W=N
M(&QI;F4@86YD(&5I=&AE<B!F=6QL>2!D969I;F5D('=I=&AI;@IA(&!@/'1D
M/CPO=&0^8&`@<&%I<B!O<B!B92!O=71S:61E('1A8FQE('1A9W,N("!&;W)M
M<R!M=7-T(&%L<V\@86QW87ES(&AA=F4@86X*86-T:6]N('!A<F%M971E<CHZ
M"@H@("`@/&9O<FT@;65T:&]D/2)P;W-T(B!A8W1I;VX](FAT='`Z+R]E>&%M
M<&QE+F-O;2]E>&%M<&QE+F-G:2(^"B`@("`\=&%B;&4^"B`@("`@("`@/'1R
M/CQT9#YE>&%M<&QE/"]T9#X\+W1R/@H@("`@/"]T86)L93X*("`@(#PO9F]R
M;3X*"B`@("`\=&%B;&4^"B`@("`@("`@/'1R/CQT9#X*("`@("`@("`@("`@
M/&9O<FT@86-T:6]N/2)J879A<V-R:7!T.G9O:60H,"DB(&]N<W5B;6ET/2)R
M971U<FX@9F%L<V4[(CX*("`@("`@("`@("`@/"]F;W)M/@H@("`@("`@(#PO
M=&0^/"]T<CX*("`@(#PO=&%B;&4^"@I!;&P@2F%V85-C<FEP="!T86=S(&UU
M<W0@:&%V92!A('9A;&ED('1Y<&4@<&%R86UE=&5R.CH*"B`@("`\<V-R:7!T
M('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"B`@("`\(2TM"B`@("`N+BX*("`@
M("\O("TM/@H@("`@/"]S8W)I<'0^"@I.;W1H:6YG(&UA>2!A<'!E87(@869T
M97(@8&`\+VAT;6P^8&`L('1H97)E9F]R92!I;F-L=61E(&%N>2!C;VUM;VX@
M9F]O=&5R<PIA9G1E<B!A;&P@;W1H97(@;W5T<'5T+@H*06QL(&EM86=E<R!M
M=7-T(&AA=F4@86X@8&!A;'1@8"!A='1R:6)U=&4Z.@H*("`@(#QI;6<@<W)C
M/2)E>&%M<&QE+F=I9B(@86QT/2(\/W!H<"!E8VAO(%\H(D5X86UP;&4B*2`_
M/B(@+SX*("`@(#P_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G97AA;7!L92YG:68G
M+"!?*")%>&%M<&QE(BDI(#\^("`@("`@("`@("`@("`@("`@*$]N('1H92!(
M14%$(&)R86YC:"D*("`@(#P_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G97AA;7!L
M92YG:68G+"`G86QT/2(G("X@7R@B17AA;7!L92(I("X@)R(G*2`_/B`@*$]N
M('1H92!214Q%3D=?,B!B<F%N8V@I"@I);G!U="!F:65L9',@;V8@='EP92`B
M:6UA9V4B(&1O(&YO="!A;&QO=R!T:&4@8F]R9&5R(&%T=')I8G5T92!A;F0@
M;6%Y(')E;F1E<@IW:71H(&$@8F]R9&5R(&]N('-O;64@8G)O=W-E<G,N("!5
M<V4@=&AE(&9O;&QO=VEN9R!I;G-T96%D.CH*"B`@(#QA(&AR968](B(@;VYC
M;&EC:STB9&]C=6UE;G0N9F]R;6YA;64N<W5B;6ET*"D[(')E='5R;B!F86QS
M93LB/CP_<&AP(&5C:&\@2&]R9&4Z.FEM9R@B97AA;7!L92YG:68B+"!?*")%
M>&%M<&QE(BDI(#\^/"]A/@H*"D1A=&%B87-E($YA;6EN9R!#;VYV96YT:6]N
M<PH]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"D%L;"!D871A8F%S92!T
M86)L97,@=7-E9"!B>2!(;W)D92!R97-O=7)C97,@86YD($AO<F1E(&%P<&QI
M8V%T:6]N<R!N965D('1O"FUA:V4@<W5R92!T:&%T('1H96ER('1A8FQE(&%N
M9"!F:65L9"!N86UE<R!W;W)K(&EN(&%L;"!D871A8F%S97,N("!-86YY"F1A
M=&%B87-E<R!R97-E<G9E('=O<F1S(&QI:V4@)W5I9"<L("=U<V5R)RP@971C
M+B!F;W(@:6YT97)N86P@=7-E+"!A;F0@9F]R8FED"G=O<F1S('1H870@87)E
M(%-13"!K97EW;W)D<R`H<V5L96-T+"!W:&5R92P@971C+BDN("!!;'-O+"!A
M;&P@;F%M97,@<VAO=6QD(&)E"FQO=V5R8V%S92P@=VET:"!U;F1E<G-C;W)E
M<R`H)U\G*2!T;R!S97!A<F%T92!W;W)D<RP@=&\@879O:60@8V%S92!S96YS
M:71I=FET>0II<W-U97,N"@I!(&=O;V0@=V%Y('1O(&1O('1H:7,@9F]R(&9I
M96QD(&YA;65S(&ES('1O(&UA:V4@=&AE(&9I96QD(&YA;64*=&%B;&5N86UE
M7V9I96QD;F%M92X*"D]T:&5R(&=E;F5R86P@9W5I9&5L:6YE<SH@5&%B;&4@
M;F%M97,@<VAO=6QD(&)E('!L=7)A;"`H=7-E<G,I.R!F:65L9"!N86UE<PIS
M:&]U;&0@8F4@<VEN9W5L87(@*'5S97)?;F%M92DN"@H*4F5G=6QA<B!%>'!R
M97-S:6]N(%5S90H]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"@I!;'=A>7,@=7-E
M('1H92!@<')E9U]@7R!F=6YC=&EO;G,@:68@<&]S<VEB;&4@:6YS=&5A9"!O
M9B!@97)E9U]@7R`H86YD"F!P<F5G7W-P;&ET*"E@7R!I;G-T96%D(&]F(&!S
M<&QI="@I8%\I.R!T:&5Y(&%R92!I;F-L=61E9"!I;B!02%`@8GD@9&5F875L
M=`IA;F0@;75C:"!M;W)E(&5F9FEC:65N="!A;F0@;75C:"!F87-T97(@=&AA
M;B!@97)E9U]@7RX*"BHJ3D5615(J*B!U<V4@82!R96=U;&%R(&5X<')E<W-I
M;VX@=&\@;6%T8V@@;W(@<F5P;&%C92!A('-T871I8R!S=')I;F<N"F!E>'!L
M;V1E*"E@7R`H:6X@<&QA8V4@;V8@8'-P;&ET*"E@7RDL(&!S=')?<F5P;&%C
M92@I8%\L(&!S=')P;W,H*6!?+"!O<@I@<W1R='(H*6!?(&1O('1H92!J;V(@
M;75C:"!M;W)E(&5F9FEC:65N=&QY+@H*+BX@7W!R96=?.B!H='1P.B\O=W=W
M+G!H<"YN970O;6%N=6%L+V5N+W)E9BYP8W)E+G!H<`HN+B!?97)E9U\Z(&AT
M='`Z+R]W=W<N<&AP+FYE="]M86YU86PO96XO<F5F+G)E9V5X+G!H<`HN+B!?
M<')E9U]S<&QI="@I.B!H='1P.B\O=W=W+G!H<"YN970O;6%N=6%L+V5N+V9U
M;F-T:6]N+G!R96<M<W!L:70N<&AP"BXN(%]S<&QI="@I.B!H='1P.B\O=W=W
M+G!H<"YN970O;6%N=6%L+V5N+V9U;F-T:6]N+G-P;&ET+G!H<`HN+B!?97AP
M;&]D92@I.B!H='1P.B\O=W=W+G!H<"YN970O;6%N=6%L+V5N+V9U;F-T:6]N
M+F5X<&QO9&4N<&AP"BXN(%]S=')?<F5P;&%C92@I.B!H='1P.B\O=W=W+G!H
M<"YN970O;6%N=6%L+V5N+V9U;F-T:6]N+G-T<BUR97!L86-E+G!H<`HN+B!?
M<W1R<&]S*"DZ(&AT='`Z+R]W=W<N<&AP+FYE="]M86YU86PO96XO9G5N8W1I
M;VXN<W1R<&]S+G!H<`HN+B!?<W1R='(H*3H@:'1T<#HO+W=W=RYP:'`N;F5T
M+VUA;G5A;"]E;B]F=6YC=&EO;BYS=')T<BYP:'`*"@I087)A;65T97(@4&%S
M<VEN9PH]/3T]/3T]/3T]/3T]/3T]/0H*3V)J96-T<R!S:&]U;&0@8F4@<&%S
M<V5D(&)Y(')E9F5R96YC92X@($5V97)Y=&AI;F<@96QS92P@:6YC;'5D:6YG
M(&%R<F%Y<RP*<VAO=6QD(&)E('!A<W-E9"!B>2!V86QU92!W:&5R979E<B!S
M96UA;G1I8V%L;'D@<&]S<VEB;&4N"@I;6F5N9"!%;F=I;F4@,CH@;V)J96-T
M<R!S:&]U;&0@86QS;R!B92!P87-S960@8GD@=F%L=65="@I4:&ES('!R86-T
M:6-E('1A:V5S(&9U;&P@861V86YT86=E(&]F(')E9F5R96YC92!C;W5N=&EN
M9RX*"BXN($YO=&4Z.B!4:&4@8'1E<FYA<GD@;W!E<F%T;W)@7R!A=71O;6%T
M:6-A;&QY(')E='5R;G,@82!C;W!Y(&]F(&ET<PH@("`@("`@("`@;W!E<F%N
M9',L('-O(&1O;B=T('5S92!I="!W:71H(&]B:F5C=',L(&]R(&EF('EO=2!A
M<F4@<W5R92!Y;W4@=V%N=`H@("`@("`@("`@=&\@<F5T=7)N(&%N(&]B:F5C
M="!C;W!Y+@H*+BX@7V!T97)N87)Y(&]P97)A=&]R8#H@:'1T<#HO+W=W=RYP
M:'`N;F5T+VUA;G5A;"]E;B]L86YG=6%G92YO<&5R871O<G,N8V]M<&%R:7-O
M;BYP:'`C;&%N9W5A9V4N;W!E<F%T;W)S+F-O;7!A<FES;VXN=&5R;F%R>0H*
M"DQO;F<@3&EN97,*/3T]/3T]/3T]/0H*5W)A<"!L:6YE<R!A="`X,"!C:&%R
M86-T97)S+"!I;F-L=61I;F<@8V]M;65N=',L('5N;&5S<R!T:&ES('-E=F5R
M96QY(&EM<&%C=',*=&AE(&-L87)I='D@;V8@=&AE(&-O9&4N("!!;'=A>7,@
M=W)A<"!C;VUM96YT<RX*"@I,:6YE($)R96%K<PH]/3T]/3T]/3T]/0H*3VYL
M>2!U<V4@54Y)6"!S='EL92!O9B!L:6YE8G)E86L@*&!@7&Y@8"DL(&YO="!7
M:6YD;W=S+T1/4R]-86,@<W1Y;&4**&!@7')<;F!@*2X*"E5S:6YG('9I;2P@
M=&\@8V]N=F5R="!F<F]M($1/4R!S='EL92!T>7!E.CH*"B`@("`Z<V5T(&9F
M/75N:7@*"E5S:6YG('9I+"!T;R!C;VYV97)T(&9R;VT@1$]3('-T>6QE('1Y
M<&4Z.@H*("`@(#IG+UY-+W,O+R]G"@HH3F]T92!T:&%T('1H92!@8%Y-8&`@
M:7,@82!C;VYT<F]L(&-H87)A8W1E<BP@86YD('1O(')E<')O9'5C92!I="!W
M:&5N('EO=0IT>7!E(&EN('1H92!V:2!C;VUM86YD('EO=2!H879E('1O('!A
M9"!I="!F:7)S="!U<VEN9R!T:&4@<W!E8VEA;"!@8%Y68&`*8VAA<F%C=&5R
M+BD*"@I0<FEV871E(%9A<FEA8FQE<PH]/3T]/3T]/3T]/3T]/3T]/0H*5F%R
M:6%B;&5S('5S960@97AC;'5S:79E;'D@=VET:&EN(&$@8VQA<W,@<VAO=6QD
M(&)E9VEN('=I=&@@82!U;F1E<G-C;W)E("@G7R<I"F-H87)A8W1E<BX@($%N
M(&5X86UP;&4@8VQA<W,@=F%R:6%B;&4@9&5F:6YI=&EO;CH@(&!@=F%R("1?
M=F%R:6%B;&5N86UE.V!@"@H*07)R87D@1&5F:6YI=&EO;G,*/3T]/3T]/3T]
M/3T]/3T]/3T*"E=H96X@9&5F:6YI;F<@87)R87ES+"!O<B!N97-T960@87)R
M87ES+"!U<V4@=&AE(&9O;&QO=VEN9R!F;W)M870L('=H97)E"FEN9&5N=&%T
M:6]N(&ES(&YO=&5D('9I82!T:&4@8VQO<VEN9R!P87)E;G1H97-I<R!C:&%R
M86-T97)S.CH*"B`@("`D87)R87EN86UE6R=I;F1E>"==(#T@87)R87DH"B`@
M("`@("`@)VYA;64Q)R`]/B`G=F%L=64Q)RP*("`@("`@("`G;F%M93(G(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`G<W5B;F%M93$G(#T^("=S=6)V86QU93$G
M+`H@("`@("`@("`@("`G<W5B;F%M93(G(#T^("=S=6)V86QU93(G"B`@("`@
M("`@*0H@("`@*3L*"E1H92!O;FQY(&5X8V5P=&EO;B!S:&]U;&0@8F4@9F]R
M(&5M<'1Y(&]R('-H;W)T(&%R<F%Y<R!T:&%T(&9I="!O;B!O;F4@;&EN92P*
M=VAI8V@@;6%Y(&)E('=R:71T96X@87,Z.@H*("`@("1A<G)A>6YA;65;)VEN
M9&5X)UT@/2!A<G)A>2@I.PH*"DEN=&5R;F%T:6]N86QI>F%T:6]N("A),3AN
M*0H]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"DUA<FL@86QL('-T<FEN
M9W,@<')E<V5N=&5D('1O('1H92!U<V5R(&%S(&=E='1E>'0@<W1R:6YG<R!B
M>2!C86QL:6YG('1H90IG971T97AT('-H;W)T8W5T(&9U;F-T:6]N("A@8%\H
M*6!@*3HZ"@H@("`@96-H;R!?*")(96QL;R!W;W)L9"(I.PH*1&]N)W0@=7-E
M('1H92!G971T97AT(&9U;F-T:6]N<R!F;W(@<W1R:6YG<R!T:&%T('=I;&P@
M8F4@=W)I='1E;B!T;R!A(&QO9R!F:6QE"F]R(&]T:&5R=VES92!P<F5S96YT
M960@=&\@=&AE(&%D;6EN:7-T<F%T;W(N"@I4:&4@4W1R:6YG.CH@8VQA<W,@
M8V]N=&%I;G,@<V5V97)A;"!S=')I;F<@;6%N:7!U;&%T:6]N(&UE=&AO9',@
M=&AA="!A<F4L(&%S"F]P<&]S960@=&\@=&AE:7(@4$A0(&5Q=6EV86QE;G1S
M+"!L;V-A;&4@86YD(&-H87)S970@<V%F92X*"E5S92!3=')I;F<Z.F-O;G9E
M<G1#:&%R<V5T*"D@:68@>6]U(&YE960@=&\@8V]N=F5R="!B971W965N(&1I
M9F9E<F5N=`IC:&%R86-T97(@<V5T(&5N8V]D:6YG<R`H9F]R(&5X86UP;&4L
M(&)E='=E96X@=7-E<B!I;G!U="!A;F0@82!S=&]R86=E(&)A8VME;F0*;W(@
M9&%T82!F<F]M(&%N(&5X=&5R;F%L('-O=7)C92!A;F0@=&AE('5S97(@:6YT
M97)F86-E*2X@(%EO=2!D;VXG="!N965D('1O"F-A<F4@:68@=&AE(&-H87)A
M8W1E<B!S971S(&%R92!R96%L;'D@9&EF9F5R96YT+@H*57-E('1H92!3=')I
M;F<Z.FQO=V5R*"D@86YD(%-T<FEN9SHZ=7!P97(H*2!M971H;V1S('=I=&AO
M=70@82!S96-O;F0*<&%R86UE=&5R(&EF('EO=2!N965D('1O('!E<F9O<FT@
M82!L;V-A;&4M:6YD97!E;F1E;G0@<W1R:6YG(&-O;G9E<G-I;VXN"E1H870G
M<R!T:&4@8V%S92!F;W(@86QL('-T<FEN9W,@=&AA="!A<F4@9G5R=&AE<B!P
M<F]C97-S960@;W(@:6YT97)P<F5T960@8GD*8V]D92X@(%5S92!T:&5S92!M
M971H;V1S('=I=&@@=&AE('-E8V]N9"!P87)A;65T97(@<V5T('1O('1R=64@
M9F]R('-T<FEN9W,*=&AA="!N965D('1O(&)E(&-O;G9E<G1E9"!C;W)R96-T
M;'D@86-C;W)D:6YG('1O('1H92!C=7)R96YT("AO<B!S<&5C:69I960I"F-H
M87)A8W1E<B!S970N"@I5<V4@=&AE(&]T:&5R(%-T<FEN9SHZ(&5Q=6EV86QE
M;G1S(&]F(%!(4"!S=')I;F<@9G5N8W1I;VYS('1O(&UA;FEP=6QA=&4*<W1R
M:6YG<R!C;W)R96-T;'D@86-C;W)D:6YG('1O('1H92!C=7)R96YT("AO<B!S
M<&5C:69I960I(&-H87)A8W1E<B!S970@8G5T"G5S92!T:&4@4$A0(&9U;F-T
M:6]N<R!F;W(@8V]D92]M86-H:6YE('!R;V-E<W-E9"!S=')I;F=S+@H*"D5R
M<F]R(&-H96-K:6YG"CT]/3T]/3T]/3T]/3T]"@I(;W)D92!C;V1E('-H;W5L
M9"!U<V4@8%!%05)?17)R;W)@7R!O8FIE8W1S('1O(')E='5R;B!M;W-T(&5R
M<F]R(&-O;F1I=&EO;G,*9G)O;2!L:6)R87)Y(&-A;&QS+"!A;F0@;6%N>2!T
M:6UE<R!W92!W:6QL('-I;7!L>2!P87-S(&)A8VL@82!@4$5!4E]%<G)O<F!?
M"F]B:F5C="!G96YE<F%T960@8GD@86X@=6YD97)L>6EN9R!L:6)R87)Y("AS
M=6-H(&%S($UA:6P@;W(@4$5!4B!$0BDN"@I&;W(@=&AE<V4@8V%S97,L('5S
M92!T:&4@9F]L;&]W:6YG('-T>6QE(&]F(&-O9&4@8FQO8VL@=&\@8VAE8VL@
M9F]R('-U8V-E<W,*869T97(@86YY(&-A;&P@=VAI8V@@8V]U;&0@9V5N97)A
M=&4@86X@97)R;W(@8V]N9&ET:6]N.CH*"B`@("`D<F5S=6QT(#T@)'-O;65T
M:&EN9RT^8V%L;"@G;6%Y(&5R<F]R)RD["B`@("!I9B`H:7-?82@D<F5S=6QT
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@+R\@2&%N9&QE(&5R<F]R(&-O
M;F1I=&EO;BX*("`@('T@96QS92!["B`@("`@("`@+R\@4W5C8V5E9&5D+@H@
M("`@?0H*3F]T92!T:&%T(&!I<U]A*"E@7R!C:&5C:W,@9F]R('-U8F-L87-S
M97,@;V8@=&AE(&YA;65D(&-L87-S+"!A<R!W96QL+"!S;R!I9@IT:&4@;V)J
M96-T('EO=2!G970@8F%C:R!I<R!R96%L;'D@82!@1$)?17)R;W)@7R!O8FIE
M8W0L('1H:7,@=VEL;"!S=&EL;"!C871C:`II="`H<VEN8V4@8$1"7T5R<F]R
M8%\@97AT96YD<R!@4$5!4E]%<G)O<F!?*2X*"D-A;&QI;F<@4$5!4CHZ:7-%
M<G)O<B@I(')E<W5L=',@:6X@=&AE('-A;64@8F5H879I;W(L(&)U="!I<U]A
M*"D*86-C;VUP;&ES:&5S('1H92!S86UE(')E<W5L="!W:71H(&$@<VEN9VQE
M(&YA=&EV92!02%`@9G5N8W1I;VX@8V%L;"X*"BXN(%]014%27T5R<F]R.B!H
M='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]C;W)E+G!E87(N<&5A<BUE
M<G)O<BYP:'`*+BX@7T1"7T5R<F]R.B!H='1P.B\O<&5A<BYP:'`N;F5T+VUA
M;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+F1B+65R<F]R+G!H<`HN+B!?
M:7-?82@I.B!H='1P.B\O=W=W+G!H<"YN970O;6%N=6%L+V5N+V9U;F-T:6]N
M+FES+6$N<&AP"@H*17AI<W1E;F-E(&-H96-K:6YG"CT]/3T]/3T]/3T]/3T]
M/3T]/0H*3V9T96X@>6]U)VQL(&YE960@=&\@8VAE8VL@=VAE=&AE<B!O<B!N
M;W0@82!V87)I86)L92!O<B!P<F]P97)T>2!E>&ES=',N"E1H97)E(&%R92!S
M979E<F%L(&-A<V5S(&AE<F4Z"@IA+B!)9B!Y;W4@;F5E9"!T;R!K;F]W(&EF
M(&$@=F%R:6%B;&4@97AI<W1S(&%T(&%L;"!A;F0@:7,@;F]T(&!@;G5L;&!@
M+"!U<V4*8&ES<V5T*"E@7SHZ"@H@("`@+R\@0VAE8VL@=&\@<V5E(&EF("1P
M87)A;2!I<R!D969I;F5D+@H@("`@:68@*&ES<V5T*"1P87)A;2DI('L*("`@
M("`@("`O+R`D<&%R86T@;6%Y(&)E(&9A;'-E+"!B=70@:70G<R!T:&5R92X*
M("`@('T*"F(N($EF('EO=2!N965D('1O(&MN;W<@:68@82!V87)I86)L92!E
M>&ES=',@04Y$(&AA<R!A(&YO;BUE;7!T>2!V86QU92`H;F]T"F!@;G5L;&!@
M+"`P+"!@8&9A;'-E8&`L(&5M<'1Y('-T<FEN9R!O<B!U;F1E9FEN960I+"!U
M<V4@(6!E;7!T>2@I8%\Z.@H*("`@("\O($UA:V4@<W5R92!T:&%T("1A;G-W
M97(@97AI<W1S+"!I<R!N;W0@86X@96UP='D@<W1R:6YG+"!A;F0@:7,*("`@
M("\O(&YO="`P.@H@("`@:68@*"%E;7!T>2@D86YS=V5R*2D@>PH@("`@("`@
M("\O("1A;G-W97(@:&%S('-O;64@;F]N+69A;'-E(&-O;G1E;G0N"B`@("!]
M(&5L<V4@>PH@("`@("`@("\O("AB;V]L*21A;G-W97(@=V]U;&0@8F4@9F%L
M<V4N"B`@("!]"@I!<R!P;VEN=&5D(&]U="!I;B!T:&4@8V]M;65N="!O9B!T
M:&4@96QS92!C;&%U<V4L(&!E;7!T>2@I8%\@97-S96YT:6%L;'D@9&]E<PIT
M:&4@<V%M92!C:&5C:R!A<R!@:7-S970H*6!?("TM(&ES('1H:7,@=F%R:6%B
M;&4@9&5F:6YE9"!I;B!T:&4@8W5R<F5N="!S8V]P93\*+2T@86YD('1H96XL
M(&EF(&ET(&ES+"!R971U<FYS('=H870@=&AE('9A<FEA8FQE('=O=6QD(&5V
M86QU871E('1O(&%S(&$*8F]O;&5A;BX@5&AI<R!M96%N<R!T:&%T(#`L('=H
M:6QE('!O=&5N=&EA;&QY('9A;&ED(&EN<'5T+"!I<R`B96UP='DB("T@<V\@
M:68*,"!I<R!V86QI9"!D871A(&9O<B!Y;W5R(&-A<V4L(&1O;B=T('5S92`A
M8&5M<'1Y*"E@7RX*"F,N($EF('EO=2!K;F]W('EO=2!A<F4@=V]R:VEN9R!W
M:71H(&$@;6EX960@=F%R:6%B;&4@=&AE;B!U<VEN9R!J=7-T"F!I<W-E="@I
M8%\@86YD(&!E;7!T>2@I8%\@8V]U;&0@8V%U<V4@=6YE>'!E8W1E9"!R97-U
M;'1S+"!F;W(@97AA;7!L92!I9@IT97-T:6YG(&9O<B!A(&ME>2!A;F0@=&AE
M('9A<FEA8FQE(&ES(&%C='5A;&QY(&$@<W1R:6YG.CH*"B`@("`D9F]O(#T@
M)V)A<B<["B`@("!I9B`H:7-S970H)&9O;ULG<V]M96ME>2==*2D@>PH@("`@
M("`@("\O(%1H:7,@=VEL;"!E=F%L=6%T92!T;R!44E5%(0H@("`@?0H*268@
M>6]U(&MN;W<@=&AA="!T:&5R92!I<R!A('!O<W-I8FEL:71Y(&]F(&$@;6EX
M960@='EP92!V87)I86)L92!T:&4@<V]L=71I;VX*:6X@=&AI<R!C87-E('=O
M=6QD(&)E('1O(&%D9"!A;B!@:7-?87)R87DH*6!?(&-H96-K(&EN('1H92!@
M8&EF*"E@8"!S=&%T96UE;G0N"@ID+B!5<V4@8&%R<F%Y7VME>5]E>&ES=',H
M*6!?('=H96X@>6]U('=A;G0@=&\@8VAE8VL@:68@86X@87)R87D@:V5Y(&ES
M(&1E9FEN960*979E;B!I9B!I="!H87,@82!V86QU92!O9B!@8&YU;&Q@8#HZ
M"@H@("`@+R\@36%K92!S=7)E('=E(&AA=F4@82!C:&%R<V5T('!A<F%M971E
M<BX@5F%L=64@8V]U;&0@86QS;R!B92!N=6QL+@H@("`@:68@*"%A<G)A>5]K
M97E?97AI<W1S*"=C:&%R<V5T)RP@)'!A<F%M<RDI('L*("`@("`@("!(;W)D
M93HZ9F%T86PH)TEN8V]M<&QE=&4@8V]N9FEG=7)A=&EO;BXG*3L*("`@('T*
M"E!L96%S92!N;W1E('1H870@8&%R<F%Y7VME>5]E>&ES=',H*6!?(&ES(&$@
M<&5R9F]R;6%N8V4@:&ET("@R-24M,3`P)2D@86YD"G-H;W5L9"!O;FQY(&)E
M('5S960@=VAE;B!N96-E<W-A<GDN($EN<W1E860@=')Y('1O('5S92`A8&5M
M<'1Y*"E@7R!O<@I@:7-S970H*6!?(&EN<W1E860N"@HN+B!?:7-S970H*3H@
M:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A;"]E;B]F=6YC=&EO;BYI<W-E="YP
M:'`*+BX@7V5M<'1Y*"DZ(&AT='`Z+R]W=W<N<&AP+FYE="]M86YU86PO96XO
M9G5N8W1I;VXN96UP='DN<&AP"BXN(%]I<U]A<G)A>2@I.B!H='1P.B\O=W=W
M+G!H<"YN970O;6%N=6%L+V5N+V9U;F-T:6]N+FES+6%R<F%Y+G!H<`HN+B!?
M87)R87E?:V5Y7V5X:7-T<R@I.B!H='1P.B\O=W=W+G!H<"YN970O;6%N=6%L
M+V5N+V9U;F-T:6]N+F%R<F%Y+6ME>2UE>&ES=',N<&AP"@H*475O=&5S"CT]
M/3T]/0H*66]U('-H;W5L9"!A;'=A>7,@=7-E('-I;F=L92!Q=6]T92`H)RD@
M8VAA<F%C=&5R<R!A<F]U;F0@<W1R:6YG<RP@97AC97!T('=H97)E"F1O=6)L
M92!Q=6]T92`H(BD@8VAA<F%C=&5R<R!A<F4@<F5Q=6ER960N("!!;&P@;&ET
M97)A;"!S=')I;F=S('-H;W5L9"!B92!I;@IS:6YG;&4@<75O=&5S+B`@02!C
M;VUP87)I<V]N(&]F('-I;F=L92!A;F0@9&]U8FQE('%U;W1E('5S86=E(&9O
M;&QO=W,Z"@I3:6YG;&4@475O=&5S.@H@("H@5F%R:6%B;&5S(&EN('1H92!S
M=')I;F<@87)E(&YO="!P87)S960@;W(@97AP86YD960N"B`@*B!.97<@;&EN
M92!S>6UB;VQS(&-A;B!B92!I;F-L=61E9"!A<R!L:71E<F%L(&QI;F4@96YD
M<R`H;F]T(')E8V]M;65N9&5D*2X*("`J(%1O(&EN8VQU9&4@82!S:6YG;&4@
M<75O=&4@8VAA<F%C=&5R+"!E<V-A<&4@:70@=VET:"!A(&!@7&!@("AB86-K
M<VQA<V@I"B`@("!C:&%R86-T97(L(&%S(&EN.B!@8&5C:&\@)TAE<F5<)W,@
M86X@97AA;7!L92<[8&`*("`J(%1O('-P96-I9GD@82!@8%Q@8"`H8F%C:W-L
M87-H*2!C:&%R86-T97(L(&1O=6)L92!I=#H@8&!E8VAO("=C.EQ<=&5M<"<[
M8&`*"D1O=6)L92!1=6]T97,Z"B`@*B!087)S97,@86YD(&5X<&%N9',@=F%R
M:6%B;&5S(&EN('1H92!S=')I;F<N"B`@*B!5<V5S(&%D=F%N8V5D("A@<W!R
M:6YT9F!?+7-T>6QE*2!E<V-A<&4@<V5Q=65N8V5S(&QI:V4@8&!<;F!@+"!@
M8%PD8&`L"B`@("!@8%QT8&`L(&5T8RX*("`J(%-H;W5L9"!B92!U<V5D(&EN
M('1H92!G971T97AT('-H;W)T8W5T(&!@7R@B(BE@8"!F;W)M870N"B`@*B!5
M<V4@=VET:"!C87)E+"!A<R!M86YY(&-O<G)E8W0@;&]O:VEN9R!S=')I;F=S
M(&%R92!R96%L;'D@:6YV86QI9"X*"E1H92!F;VQL;W=I;F<@87)E(&%L;"!I
M;F-O<G)E8W0Z.@H*("`@(&5C:&\@(E1O9&%Y(&ES('1H92`D9&%T95LG9&%Y
M)UT@;V8@)&1A=&5;)VUO;G1H)UTB"B`@("`D7U-%4U-)3TY;:6YD97A=(#T@
M)%]315-324].6R)O;&1?:6YD97@B73L*"BXN(%]S<')I;G1F.B!H='1P.B\O
M=W=W+G!H<"YN970O<W!R:6YT9@H*"F1E9FEN92@I"CT]/3T]/3T]"@I3=7)P
M<FES:6YG;'D@96YO=6=H+"!@9&5F:6YE*"E@7R!I<R!A('-O;65W:&%T('-L
M;W<@9G5N8W1I;VX@:6X@4$A0("AA<R!O9B!02%`*-"XS+G@I('-O(&5X8V5S
M<VEV92!U<V4@:7,@9&ES8V]U<F%G960N"@I5<VEN9R!@9&5F:6YE*"E@7R!I
M;B!C;&%S<V5S('-H;W5L9"!B92!/2R`M('=E('=I;&P@<V%C<FEF:6-E(&$@
M=&EN>2!B:70@;V8*<W!E960@9F]R(')E861A8FEL:71Y(&]F(&-O9&4N("!@
M9&5F:6YE*"E@7R!S:&]U;&0@3D]4(&)E('5S960@9F]R(&%C=&EO;DE$<R`M
M"G5S92!A('!L86EN(&]L9"!S=')I;F<@:6YS=&5A9"X@($9O<B!A;GET:&EN
M9R!E;'-E+"!U<V4@>6]U<B!B97-T(&IU9&=M96YT+@H*061D:71I;VYA;&QY
M+"!E=F5R>2!C;VYS=&%N="!S:&]U;&0@8F4@<')E9FEX960@=VET:"!@8$A/
M4D1%7V!@+"!I=',@<&%C:V%G90IN86UE+"!O<B!T:&4@87!P;&EC871I;VX@
M;F%M92X*"BXN(%]D969I;F4H*3H@:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A
M;"]E;B]F=6YC=&EO;BYD969I;F4N<&AP"@H*4V5C=7)I='D@0V]N<VED97)A
M=&EO;G,*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"E1H92!F;VQL;W=I;F<@
M87)E(&$@;F]N+65X:&%U<W1I=F4@;&ES="!O9B!F96%T=7)E<R]F=6YC=&EO
M;G,@=&\@=&%K90IS<&5C:6%L(&-A<F4@=VET:#H*"E!(4"!#;V1E($5X96-U
M=&EO;CH*+2TM+2TM+2TM+2TM+2TM+2TM+0H*<F5Q=6ER92P@:6YC;'5D92P@
M<F5Q=6ER95]O;F-E+"!I;F-L=61E7V]N8V4@+2!#87)E9G5L;'D@875D:70@
M86YY"G9A<FEA8FQE<R!U<V5D(&EN('1H97-E(&9U;F-T:6]N<RP@86YD(&-H
M96-K('1H92!S;W5R8V4@;V8@86YY"F-O;G-T86YT<R!A<R!W96QL+@H*979A
M;"`M($]B=FEO=7,@9&%N9V5R(&EF('5S97(@:6YP=70@:7,@<W5P<&QI960@
M=&\@:70@:6X@=6YC;VYT<F]L;&5D(&-O;F1I=&EO;G,N"@IP<F5G7W)E<&QA
M8V4@+2!4:&4@+V4@;6]D:69I97(@8V%U<V5S('1H92!R97!L86-E;65N="!S
M=')I;F<@=&\@8F4*979A;'5A=&5D(&%S(%!(4"!C;V1E+@H*0V]M;6%N9"!%
M>&5C=71I;VXZ"BTM+2TM+2TM+2TM+2TM+2TM+0H*97AE8R`M($5X96-U=&5S
M(&$@<W!E8VEF:65D(&-O;6UA;F0@86YD(')E='5R;G,@=&AE(&QA<W0@;&EN
M92!O9B!O=71P=70N"@IP87-S=&AR=2`M($5X96-U=&5S(&$@<W!E8VEF:65D
M(&-O;6UA;F0@86YD('=R:71E<R!T:&4@;W5T<'5T('1O(%-41$]55"X*"F!@
M("AB86-K=&EC:W,I("T@17AE8W5T97,@=&AE('-P96-I9FEE9"!C;VUM86YD
M(&%N9"!R971U<FYS(&%L;"!T:&4*;W5T<'5T(&EN(&%N(&%R<F%Y+@H*<WES
M=&5M("T@3&EK92!P87-S=&AR=2@I(&)U="!D;V5S;B=T(&AA;F1L92!B:6YA
M<GD@9&%T82X*"G!O<&5N("T@17AE8W5T97,@82!S<&5C:69I960@8V]M;6%N
M9"!A;F0@8V]N;F5C=',@:71S(&]U='!U="!O<B!I;G!U=`IS=')E86T@=&\@
M82!02%`@9FEL92!D97-C<FEP=&]R+@H*1FEL92!$:7-C;&]S=7)E.@HM+2TM
M+2TM+2TM+2TM+2TM"@I&:6QE(&9U;F-T:6]N<R!W:&EC:"!C86X@8F4@<&]T
M96YT:6%L;'D@=7-E9"!T;R!O<&5N(')E;6]T92!O<@IU;FEN=&5N9&5D(&9I
M;&5S.B!F;W!E;BP@<F5A9&9I;&4L(&9I;&4L(&9I;&5?9V5T7V-O;G1E;G1S
M+@H*"D]P=&EM:7IA=&EO;G,*/3T]/3T]/3T]/3T]/0H*5&AE(&9O;&QO=VEN
M9R!O<'1I;6EZ871I;VYS('-H;W5L9"!B92!U<V5D+"!I9B!P;W-S:6)L93H*
M"F5X=&5N<VEO;E]L;V%D960H*0HM+2TM+2TM+2TM+2TM+2TM+2T*5&AI<R!A
M<'!E87)S('1O(&)E(&%N(&5X<&5N<VEV92!02%`@8V%L;"X@(%5S92!5=&EL
M.CIE>'1E;G-I;VY%>&ES=',H*0II;G-T96%D+"!W:&EC:"!W:6QL(&-A8VAE
M('1H92!R97-U;'1S(&]F('1H92!C86QL+@H*0V]N8V%T96YA=&4@<W1R:6YG
M<PHM+2TM+2TM+2TM+2TM+2TM+2TM"D)U:6QD:6YG(&$@<W1R:6YG('=I=&@@
M8V]N8V%T96YA=&EO;B`H=&AE("(N(B!O<&5R871O<BD@=7-I;F<*<VEN9VQE
M+7%U;W1E9"!S=')I;F=S(&%N9"!V87)I86)L97,@:7,@9F%S=&5R('1H86X@
M=7-I;F<@86X*:6YT97)P;VQA=&5D('-T<FEN9R`H82!S=')I;F<@:6YS:61E
M(&1O=6)L92!Q=6]T97,@=VET:"!V87)I86)L97,*:6YS:61E('1H92!S=')I
M;F<@:71S96QF*2X@($EN(&%D9&ET:6]N+"!C;VYC871E;F%T:6]N(&ES(&5A
M<VEE<B!T;PIR96%D(&%N9"!A=61I="!F;W(@;&]G:6,@86YD('-E8W5R:71Y
M('!R;V)L96US+@H*4')E+6EN8W)E;65N="]D96-R96UE;G0*+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2T*0F5C875S92!O9B!T:&4@=V%Y(&-O;7!I;&5R<R]I
M;G1E<G!R971E<G,@=V]R:RP@<&]S="UI;F-R96UE;G1I;F<**"1V87(K*RD@
M<F5Q=6ER97,@<W1O<FEN9R!B;W1H('1H92!O<FEG:6YA;"!A;F0@;F5W('9A
M;'5E<R!O9B!T:&4*=F%R:6%B;&4@:6X@;65M;W)Y(&)E8V%U<V4@=&AE(&]L
M9"!V86QU92!M87D@8F4@=7-E9"!A9G1E<B!T:&4*;W!E<F%T:6]N(&EN('%U
M97-T:6]N(&ES(&-O;7!L971E+B`@0GD@8V]M<&%R:7-O;BP@<')E+6EN8W)E
M;65N=&EN9PHH*RLD=F%R*2!A;&UO<W0@;F5V97(@;F5E9',@=&\@<W1O<F4@
M8F]T:"!V86QU97,N("!)="=S(&$@;6%R9VEN86P*<W!E961U<"!B=70@:70G
M<R!A;'-O('-I;7!L>2!C:&%N9VEN9R!T:&4@;W)D97(@;V8@82!F97<@8VAA
M<F%C=&5R<RX*"DQO;W!S"BTM+2TM"DUA:V4@<W5R92!T:&%T('EO=2!D;R!N
M;W0@8V]N=&EN=64@=&\@9&5F:6YE('1H92!S86UE('9A<FEA8FQE('=I=&AI
M;B!A"FQO;W`N("!);G-T96%D+"!D96-L87)E('1H92!V87)I86)L92!A('-I
M;F=L92!T:6UE(&)E9F]R92!T:&4@;&]O<"!I<R!R=6XN"@I!<G)A>0HM+2TM
M+0I!=F]I9"!F<F5Q=65N="!A<G)A>2!A8V-E<W-E<RX@($EF('EO=2!U<V4@
M86X@87)R87D@;W(@86X@87)R87D@;65M8F5R(&EN(&$*;&]O<"P@87-S:6=N
M(&ET('1O(&$@=F%R:6%B;&4@9FER<W0Z.@H*("`@("1A(#T@87)R87DH)W@G
M(#T^("=Y)RD["B`@("`D96YT<FEE<R`](&%R<F%Y*"XN+BD["@H@("`@)&QE
M;F=T:"`](&-O=6YT*"1E;G1R:65S*3L*("`@("1X(#T@)&%;)W@G73L*("`@
M(&9O<B`H)&D@/2`P.R`D:2`\("1L96YG=&@[("LK)&DI('L*("`@("`@("!E
M8VAO("1X.PH@("`@?0H*57-E<B!D969I;F5D(&9U;F-T:6]N<PHM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM"E5S97(@9&5F:6YE9"!F=6YC=&EO;G,@87)E(&UO
M<F4@97AP96YS:79E('1H86X@(G)E9W5L87(B(&9U;F-T:6]N<RX@(%5S92!T
M:&5M"F]N;'D@:68@=&AE>2!I;7!R;W9E('1H92!C;V1E(')E861A8FEL:71Y
M(&UO<F4@=&AE;B!R96=U;&%R(&9U;F-T:6]N<RX*"D1I<VL@22]/"BTM+2TM
M+2TM"D1I<VL@<F5A9"!A;F0@=W)I=&4@;W!E<F%T:6]N<R!A<F4@<VQO=RX@
M($EF('!O<W-I8FQE(')E860@86YD('=R:71E(&9I;&5S(&EN"FQA<F=E(&-H
M=6YK<RX@($%C8V]R9&EN9R!T;R!02%`@9&]C=6UE;G1A=&EO;BP@9FEL95]G
M971?8V]N=&5N=',H*2!I<PIP;W1E;G1I86QL>2!M=6-H(&9A<W1E<B!T:&%N
M('5S:6YG(&9O<&5N*"DO9G)E860H*2]F8VQO<V4H*2X*"@I35$1)3B]35$1/
M550O4U1$15)2"CT]/3T]/3T]/3T]/3T]/3T]/3T*"E1O(&%C8V5S<R!E:71H
M97(@4U1$24XL(%-41$]55"P@;W(@4U1$15)2+"!T:&4@9F]L;&]W:6YG(&-O
M9&4@<VAO=6QD(&)E('5S960Z.@H*("`@('=H:6QE("@A9F5O9BA;4U1$24Y\
M4U1$3U54?%-41$524ETI*2!["B`@("`@("`@)&QI;F4@/2!F9V5T<RA;4U1$
M24Y\4U1$3U54?%-41$524ETI.PH@("`@("`@("\O('!R;V-E<W,@)&QI;F4@
M:&5R90H@("`@?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]D;V-S
M+T-/3E1224)55$E.1P``````````````````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#,Q-#0@,3`U,34T,S,W,S,@,#(P,S(S`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#T]/3T]/3T]/3T]
M/3T]/3T]/3T]"B!(;W)D93H@2&]W('1O($AE;'`*/3T]/3T]/3T]/3T]/3T]
M/3T]/3T*"CI,87-T('5P9&%T93H@("`D1&%T93H@,C`P-"\P.2\R-"`R,3HP
M,CHP,2`D"CI2979I<VEO;CH@("`@("`D4F5V:7-I;VXZ(#$N-"`D"CI#;VYT
M86-T.B`@("`@("!C;W)E0&AO<F1E+F]R9PH*5&AE<F4@87)E(&UA;GD@=V%Y
M<R!I;B!W:&EC:"!Y;W4@8V%N(&AE;'`@;W5T(&EN('1H92!D979E;&]P;65N
M="!O9B!A;GD@;V8@=&AE"DAO<F1E('!R;VIE8W1S+B!4:&4@9FER<W0@86YD
M(&)E<W0@=V%Y('EO=2!A<F4@86QR96%D>2!D;VEN9SH@>6]U)W)E('5S:6YG
M"G1H96TN($]N92!O9B!T:&4@:V5Y<R!T;R!A(&=R96%T('!R;V1U8W0@:7,@
M:71S('5S97)S+B!7:71H;W5T('5S97)S('=E(&-A;B=T"F9I;F0@8G5G<R!O
M<B!G970@9F5E9&)A8VL@;VX@=VAA="=S(&=O;V0@86YD('=H870G<R!B860N
M"@I)="!I<R!D87)N(&YE87(@:6UP;W-S:6)L92!F;W(@=&AE(&1E=F5L;W!E
M<G,@=&\@=&5S="!T:&4@8V]D92!O;B!E=F5R>0I/<&5R871I;F<@4WES=&5M
M(&%N9"!E=F5R>2!D:69F97)E;G0@=F5R<VEO;B!O9B!796(@0G)O=W-E<B!A
M=F%I;&%B;&4@=&\@;6%K90IS=7)E('1H92!C;V1E(')U;G,@<VUO;W1H;'D@
M979E<GEW:&5R92X@($QI;G5X(&ES(&YO="!7:6YD;W=S+"!A;F0@244@:7,@
M;F]T"DUO>FEL;&$L(&%N9"!I="!I<R`H9G)E<75E;G1L>2D@9&EF9FEC=6QT
M('1O('1O('!R961I8W0@8F5H879I;W(@8F5T=V5E;@IP;&%T9F]R;7,O8G)O
M=W-E<G,N"@I7:71H('1H:7,@<V%I9"P@;VYE(&]F('1H92!B97-T('=A>7,@
M>6]U(&-A;B!H96QP(&ES('1O('1E<W0N($EF('EO=2!C86X@:&5L<`IU<R!S
M;6]O=&@@;W5T('1H92!C;V1E(&%C<F]S<R!A;&P@*&]R(&5V96X@86YY*2!P
M;&%T9F]R;7,L('EO=2=R92!D;VEN9R!A"F=R96%T('-E<G9I8V4@=&\@=&AE
M('!R;VIE8W0N"@I.;W<L(&EF('1H870G<R!N;W0@96YO=6=H(&%N9"!Y;W4@
M=V%N="!T;R!D:6<@:6X@86YD(&AE;'`@8V]D92P@>6]U('-H;W5L9`IF:7)S
M="!S=6)S8W)I8F4@=&\@=&AE('!R;VIE8W0@;&ES=',L('!A<G1I8W5L87)L
M>2!T:&4@9V5N97)A;"!(;W)D90ID979E;&]P97)S(&QI<W0@9&5V0&QI<W1S
M+FAO<F1E+F]R9R`H<V5E(&AT='`Z+R]W=W<N:&]R9&4N;W)G+VUA:6PO(&9O
M<@II;F9O<FUA=&EO;B!O;B!S=6)S8W)I8FEN9R!T;R!T:&4@;6%I;&EN9R!L
M:7-T<RDN("!!9&1I=&EO;F%L;'DL('EO=2`J*DU54U0J*@IR96%D('1H92!@
M2&]R9&4@0V]D:6YG(%-T86YD87)D<V!?('1O(&5N<W5R92!T:&%T('1H92!C
M;V1E('EO=7(@<W5B;6ET=&EN9PIW:6QL('=A;G0@=&\@8F4@86YA;'EZ960@
M86YD('!O=&5N=&EA;&QY(&-O;6UI='1E9"!B>2!T:&4@9&5V96QO<&5R<RX@
M(%EO=0IS:&]U;&0@<')O8F%B;'D@<F5A9"!T:&4@=F%R:6]U<R!214%$344@
M9FEL97,@*&9O<B!T:&%T(&UA='1E<BP@86QL('1H90ID;V-U;65N=&%T:6]N
M(&EN('1H92!@8&1O8W,O8&`@9&ER96-T;W)Y*2!F;W(@=&AE('!A<G1I8W5L
M87(@87!P;&EC871I;VX@>6]U"F%R92!W;W)K:6YG(&]N(&%L<V\N"@HN+B!?
M8$AO<F1E($-O9&EN9R!3=&%N9&%R9'-@.B`_9CU#3T1)3D=?4U1!3D1!4D13
M+FAT;6P`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O9&]C<R]#4D5$
M2513````````````````````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#$T,S,P(#$P-3$U-#,S-S,S(#`Q-S4Q,``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T*($AO<F1E($1E=F5L;W!M96YT(%1E86T*/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]"@H*0V]R92!$979E;&]P97)S"CT]/3T]/3T]/3T]/3T]
M/0H*0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"DIA;B!38VAN
M96ED97(@/&IA;D!H;W)D92YO<F<^"DUI8VAA96P@4VQU<V%R>B`\<VQU<V%R
M>D!H;W)D92YO<F<^"@H*3&]C86QI>F%T:6]N"CT]/3T]/3T]/3T]/0H*/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]("`@/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"D%R86)I8R`H4WER:6$I
M("`@("`@("`@(%!L871I;G5M($1E=F5L;W!M96YT(%1E86T@/&1E=G1E86U`
M<&QA=&EN=6TM<WDN;F5T/@I";W-N:6%N("`@("`@("`@("`@("`@("!!;&5N
M(%-A<FMI;F]V:6,@/&%L96Y`;&EN=7@N;W)G+F)A/@H@("`@("`@("`@("`@
M("`@("`@("`@("!6961R86X@3&IU8F]V:6,@/'9L:G5B;W9I8T!S;6%R=&YE
M="YB83X*0G)A>FEL:6%N(%!O<G1U9W5E<V4@("`@0V%R;&]S($1A;FEE;"!+
M:6)R:70@/&MI8G)I=$!T97)R82YC;VTN8G(^"B`@("`@("`@("`@("`@("`@
M("`@("`@($9A8FEO($=O;65S(#QF;&=O;7-`=6]L+F-O;2YB<CX*0G5L9V%R
M:6%N("`@("`@("`@("`@("`@36ER;W-L878@4&5N9&5V(#QP96YD979`:&]T
M;6%I;"YC;VT^"D-A=&%L86X@("`@("`@("`@("`@("`@($%N9V5L<R!'=6EM
M97+@(#QA;F=E;',N1W5I;65R84!U86(N97,^"B`@("`@("`@("`@("`@("`@
M("`@("`@($IO<F1I($=I<F%L="`\<')O:F5C=&4N:S)`=7!C;F5T+F5S/@I#
M:&EN97-E("A3:6UP;&EF:65D*2`@("!786YG2&5N9U=E;B`\=VAW0&UY,38Y
M+F-O;3X*("`@("`@("`@("`@("`@("`@("`@("`@3&EA;V)I;B`\;&EA;V)I
M;D!J:71E+FYE=#X*0VAI;F5S92`H5')A9&ET:6]N86PI("`@1&%V:60@0VAA
M;F<@/&1A=FED0'1M=BYG;W8N='<^"D-Z96-H("`@("`@("`@("`@("`@("`@
M(%!A=F5L($-H>71I;"`\<&%J84!A<W`N;V=I+F5D=3X*1&%N:7-H("`@("`@
M("`@("`@("`@("`@36%R=&EN($QI<W0M4&5T97)S96X@/&UA<G1I;D!L:7-T
M+7!E=&5R<V5N+F1K/@H@("`@("`@("`@("`@("`@("`@("`@("!"<FEA;B!4
M<G5E;'-E;B`\:&]R9&4K:3$X;D!B<FEA;G1R=65L<V5N+F1K/@I$=71C:"`@
M("`@("`@("`@("`@("`@("!*86X@2W5I<&5R<R`\:G)K=6EP97)S0&QA=7=E
M<G-C;VQL96=E+FYL/@H@("`@("`@("`@("`@("`@("`@("`@("!0971E<B!!
M<FEE;B`\<&5T97(N87)I96Y`8V,N:W5L975V96XN86,N8F4^"B`@("`@("`@
M("`@("`@("`@("`@("`@($AA;B!3<')U>70@/&AA;BYS<')U>71`:6IS<V5L
M9W)O97`N;FP^"D5S=&]N:6%N("`@("`@("`@("`@("`@(%1O;VUA<R!!87,@
M/'1O;VUA<RYA87-`<F%A9"YT87)T=2YE93X*1FEN;FES:"`@("`@("`@("`@
M("`@("`@3&5E;F$@2&5I;F\@/&QI:6YU0'5T82YF:3X*1G)E;F-H("`@("`@
M("`@("`@("`@("`@1G)E9&5R:6,@5')U9&5A=2`\9G1R=61E875`8V%M+F]R
M9SX*("`@("`@("`@("`@("`@("`@("`@("`@5&AI97)R>2!4:&]M87,@/'1H
M:65R<GE`<&]M<&\N;F5T/@H@("`@("`@("`@("`@("`@("`@("`@("!"96YO
M:70@4W0M06YD<ND@/&)E;D!B96YO:71S="UA;F1R92YN970^"B`@("`@("`@
M("`@("`@("`@("`@("`@(%!I97)R92!,86-H86YC92`\<&Q`<&EE<G)E;&%C
M:&%N8V4N;F5T/@H@("`@("`@("`@("`@("`@("`@("`@("!'<F5G;W)Y($-O
M;'!A<G0@/&=C;VQP87)T0&5V;VQI>"YN970^"D=A;&EC:6%N("`@("`@("`@
M("`@("`@(%)A9F%E;"!687)E;&$@/')A9F%E;"YV87)E;&%`=7-C+F5S/@H@
M("`@("`@("`@("`@("`@("`@("`@("!'=6EL;&5R;6\@365N9&5Z(#QG=6EL
M;&5`=7-C+F5S/@I'97)M86X@("`@("`@("`@("`@("`@("!*86X@4V-H;F5I
M9&5R(#QJ86Y`:&]R9&4N;W)G/@I'<F5E:R`@("`@("`@("`@("`@("`@("!3
M=&5F86YO<R!)+B!$:6UI=')I;W4@/'-U<'!O<G1`=&5I871H+F=R/@H@("`@
M("`@("`@("`@("`@("`@("`@("!3:6QL:6=A<F1O<R!8<FES=&]F;W)O<PH@
M("`@("`@("`@("`@("`@("`@("`@("!!;F%G;F]S=&]P;W5L;W,@07!O<W1O
M;&ES"B`@("`@("`@("`@("`@("`@("`@("`@($MO;G-T86YT:6YO<R!#+B!-
M:6QO<VES(#QK;6EL;W-I<T!Y86AO;RYC;VT^"DAE8G)E=R`@("`@("`@("`@
M("`@("`@($UA='0@4V5L<VMY(#QS96QS:WE`8V]L=6UB:6$N961U/@I(=6YG
M87)I86X@("`@("`@("`@("`@("!,87-Z;&\@3"X@5&]R;F]C:2`\=&]R;&%S
M>D!X96YI82YS;W1E+FAU/@I)8V5L86YD:6,@("`@("`@("`@("`@("!":F]R
M;B!$879I9'-S;VX@/&)J;W-S:4!S;F5R<&$N:7,^"DEN9&]N97-I86X@("`@
M("`@("`@("`@(%-L86UI;B`\<VQA;6EN0'5N96HN86,N:60^"B`@("`@("`@
M("`@("`@("`@("`@("`@($IA;65S($1O92`\:F%M97-`86-T:6]N;65S<V%G
M92YC;VT^"DET86QI86X@("`@("`@("`@("`@("`@(%!A;VQA($-A<G!E;G1E
M<B`\<&-A<G!E;G1E<D!I;F9V:6,N:70^"B`@("`@("`@("`@("`@("`@("`@
M("`@($=I;W9A;FYI($UE;F5G:&5T=&D@/&=M96YE9VAE='1I0&EN9G9I8RYI
M=#X*("`@("`@("`@("`@("`@("`@("`@("`@1F5D97)I8V\@1VEA;FYI8VD@
M/&=I86YN:6-I0&YE;VUE9&EA+FET/@H@("`@("`@("`@("`@("`@("`@("`@
M("!-87)C;R!0:7)O=F%N;R`\;6%R8V\N<&ER;W9A;F]`=6YI8F]C8V]N:2YI
M=#X*("`@("`@("`@("`@("`@("`@("`@("`@0W)I<W1I86X@36%N;VYI(#QC
M<FES=&EA;BYM86YO;FE`;F5T:&5S:7,N:70^"DIA<&%N97-E("`@("`@("`@
M("`@("`@($(N2BX@0FQA8VL@/'=I;&QI86TN8FQA8VM`<W5N+F-O;3X*("`@
M("`@("`@("`@("`@("`@("`@("`@5&%K97-H:2!-;W)I<VAI;6$@/'1M0&]N
M97!O<W0N;F5T/@H@("`@("`@("`@("`@("`@("`@("`@("!(:7)O;6D@2VEM
M=7)A(#QH:7)O;6E`=&%C+G1S=6MU8F$N86,N:G`^"DMH;65R("`@("`@("`@
M("`@("`@("`@($QE86YG($-H=6US;V)E;B`\<V]B96Y`:VAM97)O<RYI;F9O
M/@I+;W)E86X@("`@("`@("`@("`@("`@("!*+DD@2VEM(#QA<&]R:65`;F5T
M:6%N+F-O;3X*("`@("`@("`@("`@("`@("`@("`@("`@2FEN:'EO:R!(96\@
M/&YO=F5M8G)E0&]U<FYA='5R92YO<F<^"DQA='9I86X@("`@("`@("`@("`@
M("`@($MA<W!A<G,@2V%P96YI96MS(#QK87-P87)S0')C8RYL=CX*3&ET:'5A
M;FEA;B`@("`@("`@("`@("`@1&%R:75S($UA='5L:6%U<VMA<R`\9&%R:75S
M0&QN:RYL=#X*("`@("`@("`@("`@("`@("`@("`@("`@5FEL:75S(%-U;7-K
M87,@/'9I;&EU<T!L;FLN;'0^"DUA8V5D;VYI86X@("`@("`@("`@("`@(%-T
M;VIA;B!097-O=B`\<W-P0&5U<F5K82YC;VTN;6L^"DYO<G=E9VEA;B!";VMM
M86%L("`@("`@($]Y<W1E:6X@4W1E:6UL97(@/&]Y<W1E:6Y`<F5X=&$N;F5T
M/@H@("`@("`@("`@("`@("`@("`@("`@("!4;W)S=&5I;B!3+B!(86YS96X@
M/&AU;&5B;V5R0'1E8VAB964N;F\^"B`@("`@("`@("`@("`@("`@("`@("`@
M($%N9')E87,@1W5N;&5I:W-K86%S(#QA;F1R96%S0&=U;FQE:6MS:V%A<RYN
M;SX*("`@("`@("`@("`@("`@("`@("`@("`@5')O;F0@0FKX<G-T860@/'1R
M8D!N9&XN;F\^"B`@("`@("`@("`@("`@("`@("`@("`@(%1H;VUA<R!#:'(N
M($1A:&P@/'1C9$!N9&XN;F\^"B`@("`@("`@("`@("`@("`@("`@("`@($=E
M:7(@3RX@2&]G8F5R9R`\:&]R9&5`<VMY9&EV97(N;F\^"DYO<G=E9VEA;B!.
M>6YO<G-K("`@("`@(%!E<BU3=&EA;B!6871N92`\<'-V0&]R<W1A+F]R9SX*
M4&5R<VEA;B`@("`@("`@("`@("`@("`@365T84Y%5"!!;6ER:V%B:7(@/'!E
M<G-I86XM:&]R9&5`;65T86YE='=O<FMI;F<N8V]M/@I0;VQI<V@@("`@("`@
M("`@("`@("`@("!-87)I=7-Z(%IY;F5L(#QM87)I=7-Z0&UA=&@N=7=B+F5D
M=2YP;#X*("`@("`@("`@("`@("`@("`@("`@("`@2W)Z>7-Z=&]F($MO>FQO
M=W-K:2`\:V]Z:6LQ0&\R+G!L/@I0;W)T=6=U97-E("`@("`@("`@("`@("!.
M=6YO($QO=7)E:7)O(#QN=6YO0&5T:"YP=#X*("`@("`@("`@("`@("`@("`@
M("`@("`@36%N=65L($UE;F5Z97,@9&4@4V5Q=65I<F$@/$UA;G5E;"Y397%U
M96ER83X*4F]M86YI86X@("`@("`@("`@("`@("`@0V]R;F5L:74@375S870@
M/&-M=7-A=$!T:6%M870N:V5Y<WES+G)O/@I2=7-S:6%N("`@("`@("`@("`@
M("`@("!)9VYA="!):W)Y86YO=B`\:6=N871`:6)D+G)U/@H@("`@("`@("`@
M("`@("`@("`@("`@("!&961O<B!!+B!&971I<V]V(#QF869`<W-C+G)U/@H@
M("`@("`@("`@("`@("`@("`@("`@("!!;&5X97D@6F%K:&%R;W8@/&%L97A`
M8FMS+F)Y/@I3;&]V86L@("`@("`@("`@("`@("`@("!,96\@37)A9FMO(#QL
M96]`;V5L+G-K/@H@("`@("`@("`@("`@("`@("`@("`@("!)=F%N($YO<FES
M(#QN;W)I<T!B9W,N<VL^"E-L;W9E;FEA;B`@("`@("`@("`@("`@($IU<F4@
M2W)A<V]V:6,@/&IU<F5K0')C8RUI<F,N<VD^"B`@("`@("`@("`@("`@("`@
M("`@("`@($UA=&EC($1O;&%R(#QM871I8T!M961I=6TN<VD^"E-P86YI<V@@
M("`@("`@("`@("`@("`@(%)A^FP@06QV87)E>B!696YE9V%S(#QR879`=&5C
M;VUA;BYU8V]L+FUX/@H@("`@("`@("`@("`@("`@("`@("`@("!-86YU96P@
M4&5R97H@07EA;&$@/&UP97)A>6%`86QC87IA8F$N=6YE>"YE<SX*4W=E9&ES
M:"`@("`@("`@("`@("`@("`@06YD<F5A<R!$86ALZ6X@/&%N9')E87-`9&%H
M;&5N+G=S/@H@("`@("`@("`@("`@("`@("`@("`@("!*;V%Q=6EM($AO;7)I
M9VAA=7-E;B`\:F]H;T!W96)B<&QA='-E;BYS93X*5'5R:VES:"`@("`@("`@
M("`@("`@("`@1V5N8V\@66EL;6%Z(#QG96YC;WEI;&UA>D!Y86AO;RYC;VT^
M"B`@("`@("`@("`@("`@("`@("`@("`@($ES=&%N8G5L(%1E8VAN:6-A;"!5
M;FEV97)S:71Y($E4($1E<&%R=&UE;G0*("`@("`@("`@("`@("`@("`@("`@
M("`@/&ET=6)I;4!I='4N961U+G1R/@H@("`@("`@("`@("`@("`@("`@("`@
M("!397)V970@1_QN97D@/'-G=6YE>4!M971U+F5D=2YT<CX*("`@("`@("`@
M("`@("`@("`@("`@("`@06AM970@UGIT_')K(#QO86AM971`;65T=2YE9'4N
M='(^"E5K<F%I;FEA;B`@("`@("`@("`@("`@($%N9')I>2!+;W!Y<W1Y86YS
M:WD@/&%N<FE`<&]L>6YE="YL=FEV+G5A/@H]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T@("`]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T*"@I4:&5M97,*/3T]/3T]"@H]/3T]/3T]/3T]/3T]
M("`@/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*
M0F%R8FEE("`@("`@("`@($%T:68@1VAA9F9A<B`\86=H869F87)`9&5V96QO
M<&5R+F-H/@I"<F]W;B`@("`@("`@("`@36%R8V\@3V)A:60@/&UA<F-O0&UU
M=RYE9'4^"D-A;6]U9FQA9V4@("`@("!!=&EF($=H869F87(@/&%G:&%F9F%R
M0&1E=F5L;W!E<BYC:#X*0VAE<G)Y("`@("`@("`@($-H<FES=&]P:&4@1W5I
M;&QO=7@@/')O;W1I>$!B;V]T:7@N;F5T/@I'<F5E;B`@("`@("`@("`@3F%C
M97(@3&%R861J:2`\;&%R861J:4!T=7AF86UI;'DN;W)G/@I'<F5Y("`@("`@
M("`@("`@3F%C97(@3&%R861J:2`\;&%R861J:4!T=7AF86UI;'DN;W)G/@I,
M879E;F1E<B`@("`@("`@6FEA=7(@4F%H;6%N(#QZ:6%`<6%L86-O;2YC;VT^
M"DQI9VAT+4)L=64@("`@("!!=&EF($=H869F87(@/&%G:&%F9F%R0&1E=F5L
M;W!E<BYC:#X*36]Z:6QL82`@("`@("`@($UI8VAA96P@0V]C:')A;F4@/&UI
M:V5`9W)A9G1O;FAA;&PN8V\N;GH^"D]R86YG92`@("`@("`@("!2;VYN:64@
M1V%R8VEA(#QR;VYN:65`;6LR+FYE=#X*4VEM<&QE>"`@("`@("`@($-A<FEA
M9"!);&W@<F$@/&-A<FEA9$!A9&YX+FYE=#X*4W5N("`@("`@("`@("`@($-H
M<FES=&]P:&4@1W5I;&QO=7@@/')O;W1I>$!B;V]T:7@N;F5T/@H]/3T]/3T]
M/3T]/3T]("`@/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T*"@I#;VYT<FEB=71I;VYS"CT]/3T]/3T]/3T]/3T*"DA434P@=&\@
M5&5X="!#;VYV97)T97(Z($IO;B!!8F5R;F%T:'D@/&IO;D!C:'5G9VYU='0N
M8V]M/@H*"DEN86-T:79E($1E=F5L;W!E<G,*/3T]/3T]/3T]/3T]/3T]/3T]
M/0H*+2!)=F%N($4N($UO;W)E($E)(#QR:W)U<W1Y0'1D>6,N8V]M/@HM($UI
M:V4@2&%R9'D@/&UI:V5`:71S<')O:F5C=',N8V]M/@HM($IO;B!087)I<V4@
M/&IO;D!C<V@N<FET+F5D=3X*+2!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R
M96-O:6PN;W)G/@HM(%)I8V@@3&%F9F5R='D@/')I8VA`:&]R9&4N;W)G/@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+V1O8W,O2$%#2TE.1P``````````````````````````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`Q-C<R,B`Q,#4Q-30S,S<S-"`P,3<T-C<`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*($AO<F1E($1E=F5L;W!M96YT
M(%)E<V]U<F-E<PH]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*.DQA
M<W0@=7!D871E.B`@("1$871E.B`R,#`V+S`R+S`Q(#`Y.C(P.C(Y("0*.E)E
M=FES:6]N.B`@("`@("12979I<VEO;CH@,2XW+C$P+C$@)`HZ075T:&]R.B`@
M("`@("`@279A;B!%+B!-;V]R92!)22`\<FMR=7-T>4!T9'EC+F-O;3XL($UI
M:V4@2&%R9'D*("`@("`@("`@("`@("`@(#QM:6ME:$!S<&%R:RYC;VT^"CI#
M;VYT86-T.B`@("`@("!H;W)D94!L:7-T<RYH;W)D92YO<F<*"BXN(&-O;G1E
M;G1S.CH@0V]N=&5N=',*+BX@<V5C=&EO;BUN=6UB97)I;F<Z.@H*3VYL:6YE
M(')E<V]U<F-E<R!F;W(@9&5V96QO<&EN9R!W:71H($AO<F1E("AI;F-L=61I
M;F<@2&]R9&4@1G)A;65W;W)K($%020ID;V-U;65N=&%T:6]N*2!A<F4@879A
M:6QA8FQE(&%T.@H*("`@:'1T<#HO+V1E=BYH;W)D92YO<F<O("`@"@H*2&%C
M:VEN9R!O;B!(;W)D92!F<F]M($-64PH]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]"@I(;W)D92!A;F0@:71S(&UO9'5L97,@=7-E($-64R!F;W(@<V]U<F-E
M(&-O;G1R;VPN("!#5E,@:7,@=V5L;"UD;V-U;65N=&5D+"!B=70*=&AE(&UA
M;G5A;"!P86=E(&%S<W5M97,@>6]U(&%L<F5A9'D@:VYO=R!H;W<@:70@=V]R
M:W,N("!!;B!E>&-E;&QE;G0@9W5I9&4@=&\*9V5T=&EN9R!S=&%R=&5D('=I
M=&@@0U93(&ES(")/<&5N(%-O=7)C92!$979E;&]P;65N="!W:71H($-64R(@
M8GD@2V%R;"!&;V=E;"X*270G<R!P=6)L:7-H960@8GD@0V]R:6]L:7,L(&%N
M9"!T:&4@=&5C:&YI8V%L('!A<G0@;V8@=&AE(&)O;VL@:7,@879A:6QA8FQE
M"F9O<B!F<F5E(&]N('1H92!796(@870*"B`@(&AT='`Z+R]C=G-B;V]K+G)E
M9"UB96%N+F-O;2\*"E1H92!P87!E<B!V97)S:6]N(&EN8VQU9&5S(&-H87!T
M97)S(&]N(&]R9V%N:7II;F<@86YD(&UA;F%G:6YG($]P96X@4V]U<F-E"F1E
M=F5L;W!M96YT+B`@66]U(&-A;B!O8G1A:6X@82!#5E,@8VQI96YT(&9O<B!Y
M;W5R(&]P97)A=&EN9R!S>7-T96T@870*0U932$]-12P@870*"B`@(&AT='`Z
M+R]W=W<N8W9S:&]M92YO<F<O9&]W;FQO861S+FAT;6P*"F]F('1H96T@;6%Y
M(&)E(&9O=6YD(&%T(&AT='`Z+R]W=W<N8WEC;&EC+F-O;2`M('1H97D@<W5P
M<&]R="!#5E,@8V]M;65R8VEA;&QY+`IE=F5N('1H;W5G:"!I="!I<R!A;B!O
M<&5N('-O=7)C92!P<F]G<F%M+@H*66]U('=I;&P@;F5E9"!A($-64R!C;&EE
M;G0@=&\@9&\@86YY(&]F('1H92!F;VQL;W=I;F<@*&-H96-K(&]U="!T:&4@
M0WEC;&EC"FAO;65P86=E(&EF('EO=2!D;VXG="!H879E(&]N92DN"@I&;W(@
M=&AO<V4@86QR96%D>2!F86UI;&EA<B!W:71H($-64RP@=&AE(&%N;VYY;6]U
M<R!#5E-23T]4(&ES.CH*"B`@(#IP<V5R=F5R.F-V<W)E861`86YO;F-V<RYH
M;W)D92YO<F<Z+W)E<&]S:71O<GD*"@I$;W=N;&]A9&EN9R!(;W)D92!M;V1U
M;&5S(&9R;VT@0U93"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2T*"EEO=2!W:6QL('=A;G0@=&\@9&\@=&AI<R!I9B!Y;W4@=V%N="!B;&5E
M9&EN9R!E9&=E(&-O9&4N"@HQ+B!';R!T;R!T:&4@9&ER96-T;W)Y('EO=2!W
M86YT('1O(&1O=VYL;V%D('1H92!C;V1E('1O.CH*"B`@("`@(&-D('XO=V]R
M:PH*,BX@4V5T(&!@0U934D]/5&!@('1O('1H92!L;V-A=&EO;B!O9B!T:&4@
M0U93(')E<&]S:71O<GDN("!9;W4@8V]U;&0@86QS;R!P87-S"B`@(&-V<R!T
M:&4@;F%M92!O9B!T:&4@0U93(')O;W0@=VET:"!T:&4@8&`M9&!@(&]P=&EO
M;BX@($)E('-U<F4@=&\@;F]T92!T:&4*("`@8V]L;VX@8&`Z8&`@:6X@9G)O
M;G0@;V8@8&!P<V5R=F5R8&`N"@H@("`H:6X@<V@L(&MS:"P@8F%S:"P@>G-H
M*3HZ"@H@("`@("!#5E-23T]4/3IP<V5R=F5R.F-V<W)E861`86YO;F-V<RYH
M;W)D92YO<F<Z+W)E<&]S:71O<GD*("`@("`@97AP;W)T($-64U)/3U0*"B`@
M("AI;B!C<V@L('1C<V@I.CH*"B`@("`@('-E=&5N=B!#5E-23T]4(#IP<V5R
M=F5R.F-V<W)E861`86YO;F-V<RYH;W)D92YO<F<Z+W)E<&]S:71O<GD*"C,N
M($QO9VEN('1O('1H92!A;F]N>6UO=7,@0U93(')E<&]S:71O<GDN("!7:&5N
M('!R;VUP=&5D(&9O<B!A('!A<W-W;W)D+"!E;G1E<@H@("!@8&AO<F1E8&`Z
M.@H@("`@("`*("`@("`@8W9S(&QO9VEN"@HT+B!#:&5C:R!O=70@=&AE(&UO
M9'5L92!Y;W4@=V%N="!T;R!D;W=N;&]A9"!F<F]M('1H92!R97!O<VET;W)Y
M+B`@4F5P;&%C90H@("!@8$U/1%5,16!@('=I=&@@:&]R9&4L(&EM<"P@='5R
M8F$L('1R;VQL+"!A;F0@<V\@9F]R=&@N("`H5&AE(&!@+7HS8&`@=&5L;',*
M("`@8W9S('1O(&-O;7!R97-S('1H92!D871A(&ET('-E;F1S(&]V97(@=&AE
M(&YE='=O<FLL('5N8V]M<')E<W-I;F<@:70@=VAE;@H@("!Y;W4@/S\_/SHZ
M"@H@("`@("!C=G,@+7HS(&-O($U/1%5,10H*("`@268@>6]U('=A;G0@=&\@
M8VAE8VL@;W5T(&$@<&%R=&EC=6QA<B!B<F%N8V@@;V8@82!M;V1U;&4@*&9O
M<B!E>&%M<&QE+"!T:&4*("`@8&!214Q%3D=?,V!@(&)R86YC:"!O9B!)35`I
M+"!I;F-L=61E('1H92!B<F%N8V@@=&%G(&QI:V4@<V\L(')E<&QA8VEN9PH@
M("!@8%1!1V!@('=I=&@@=&AE(&YA;64@;V8@=&AE(&)R86YC:#HZ"@H@("`@
M("!C=G,@+7HS(&-O("UR(%1!1R!-3T153$4*"C4N($%S('EO=2!W;W)K('=I
M=&@@=&AE('-O9G1W87)E+"!Y;W4@8V%N('!E<FEO9&EC86QL>2!U<&1A=&4@
M>6]U<B!T<F5E('1O"B`@(&UA=&-H('1H92!M87-T97(@=')E92!A="!A;GD@
M=&EM92P@9G)O;2!T:&4@=&]P(&1I<F5C=&]R>2!O9B!T:&4*("`@;6]D=6QE
M+B`@57-I;F<@8&!H;W)D96!@(&%S(&%N(&5X86UP;&4@;6]D=6QE.CH*"B`@
M("`@(&-D('XO=V]R:R]H;W)D90H@("`@("!C=G,@+7HS('5P9&%T90H*"D]B
M=&%I;FEN9R!A($-64R!A8V-O=6YT"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M"@I)9B!Y;W4G<F4@9V]I;F<@=&\@8F4@82!R96=U;&%R(&-O;G1R:6)U=&]R
M('1O($AO<F1E+"!T:&5N('EO=2!C86X@<F5Q=65S="!A"D-64R!A8V-O=6YT
M(&EN(&]R9&5R('1O(&-O;6UI="!Y;W5R(&-H86YG97,@=&\@=&AE(')E<&]S
M:71O<GD@>6]U<G-E;&8N("`H268*>6]U)W)E(&]N;'D@9V]I;F<@=&\@8F4@
M8V]N=')I8G5T:6YG(&]N8V4@:6X@82!W:&EL92P@=&AE<F4@=')U;'D@:7,@
M;F\@;F5E9`IF;W(@>6]U('1O(&AA=F4@;VYE+"!A<R!P;W-T:6YG('EO=7(@
M8VAA;F=E<R!T;R!T:&4@87!P;&EC871I;VXG<R!M86EL:6YG(&QI<W0*=VEL
M;"!S=69F:6-E('1O(&=E="!Y;W5R(&-H86YG97,@<F5V:65W960@86YD(&EN
M8VQU9&5D+BD*"DEF('EO=2!D;R!G970@8V]M;6ET(&%C8V5S<R!T;R!T:&4@
M0U93('1R964L('EO=2!W:6QL(&AA=F4@=&AE(&%B:6QI='D@=&\@;65S<PIS
M;VUE('1H:6YG<R!U<"X@($YO="!F;W(@9V]O9"P@;6EN9"!Y;W4L(&%S($-6
M4R!A;&QO=W,@=7!D871E<R!T;R!B92!B86-K960*;V9F+"!B=70@>6]U('-T
M:6QL(&YE960@=&\@<F5M96UB97(@=VAA="!Y;W4G<F4@9&]I;F<@86YD(&)E
M(&-A<F5F=6P@=VAA="!Y;W4*8V]M;6ET(&%N9"!W:&5N('EO=2!C;VUM:70@
M:70N("!"96-A=7-E(&]F('1H:7,L('=E('!R969E<B!T:&%T('EO=2!S=6)M
M:70*>6]U<B!W;W)K('1O('1H92!M86EL:6YG(&QI<W0@9F]R(&$@=VAI;&4@
M<V\@=V4@8V%N('1E;&P@>6]U(&MN;W<@=VAA="!Y;W4G<F4*9&]I;F<N"@I)
M9B!Y;W4G<F4@;F]T(&$@8V]M;6ET=&5R+"!T:&4@8F5S="!W87D@=&\@<W5B
M;6ET(&$@<&%T8V@@:7,@=&\@<V5N9"!I="!E:71H97(*=&\@=&AE(&%P<&QI
M8V%T:6]N)W,@;6%I;&EN9R!L:7-T(&]R('1O(&1E=D!L:7-T<RYH;W)D92YO
M<F<N("!&;W(@;6]R90II;F9O<FUA=&EO;B!O;B!(;W)D92!M86EL:6YG(&QI
M<W1S+"!S964*"B`@(&AT='`Z+R]W=W<N:&]R9&4N;W)G+VUA:6PO"@H*0V]M
M;6ET=&EN9R!C:&%N9V5S('1O($-64PHM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM"@I/;F-E('EO=2!H879E(&$@0U93(&%C8V]U;G0L('EO=2!W:6QL(&YE
M960@=&\@;&]G(&EN=&\@=&AE($-64R!S97)V97(@<V\@:70*:VYO=W,@=VAO
M('EO=2!A<F4@86YD(&-A;B!G<F%N="!Y;W4@=&AE(&%P<')O<')I871E(')I
M9VAT<R!T;R!W;W)K(&]N('1H90IS;W5R8V5S+@H*5&AE(&!@0U934D]/5&!@
M(&ES(&1I9F9E<F5N="!F;W(@8V]M;6ET=&5R<SL@:6YS=&5A9"!O9B!T:&4@
M<F5P;W-I=&]R>2!L:7-T960*86)O=F4L('-E="!@8$-64U)/3U1@8"!T;SHZ
M"@H@("`Z97AT.E5315).04U%0&-V<RYH;W)D92YO<F<Z+W)E<&]S:71O<GD*
M"G)E<&QA8VEN9R!@8%5315).04U%8&`@=VET:"!Y;W5R(&-V<R!U<V5R;F%M
M92X*"E1H92!C;VUM:71T97)S)R!R97!O<VET;W)Y(&1O97,@;F]T('5S92!P
M<V5R=F5R+B`@66]U('=I;&P@;F5E9"!T;R!H879E('-S:`II;G-T86QL960@
M;VX@>6]U<B!S>7-T96TL(&%N9"!H879E(&%R<F%N9V5D('=I=&@@;VYE(&]F
M('1H92!C;W)E(&1E=F5L;W!E<G,@=&\*<'5T('EO=7(@4U-((&ME>2!O;B!T
M:&4@<WES=&5M+B`@268@>6]U(&AA=F4@;F]T(&1O;F4@=&AI<RP@=&%L:R!T
M;R!O;F4@;V8@=&AE"F-O<F4@9&5V96QO<&5R<RX*"E1O(&=E="!C=G,@=&\@
M=7-E('-S:"P@>6]U('=I;&P@;F5E9"!T;R!S970@=&AE(&5N=FER;VYM96YT
M('9A<FEA8FQE"F!@0U937U)32&!@('1O(&!@<W-H8&`@:6X@>6]U<B!S:&5L
M;"X*"EEO=2!D;R!N;W0@;F5E9"!T;R!D;R!@8&-V<R!L;V=I;F!@.R!Y;W4@
M=VEL;"!B92!P<F]M<'1E9"!F;W(@=&AE('!A<W-P:')A<V4*9F]R('EO=7(@
M4U-((&ME>2!W:&5N979E<B!Y;W4@86-C97-S('1H92!R97!O<VET;W)Y+@H*
M66]U(&UA>2!A;'-O('=I<V@@=&\@<V5T('1H92!E;G9I<F]N;65N="!V87)I
M86)L92!@8$5$251/4F!@('1O('!O:6YT('1O('EO=7(*9F%V;W)I=&4@=&5X
M="!E9&ET;W(N(%1H:7,@=V%Y('=H96X@>6]U(&-O;6UI="!S;V9T=V%R92!C
M:&%N9V5S(&%N9"!I="!A<VMS"GEO=2!T;R!E;G1E<B!A(&-H86YG92!D97-C
M<FEP=&EO;BP@>6]U(&-A;B!D;R!S;R!I;B!Y;W5R(&9A=F]R:71E(&5D:71O
M<BX*"E1H96XL(&9O<B!W;W)K(&]N(&1E=F5L;W!M96YT86PL(&)L965D:6YG
M+65D9V4@=F5R<VEO;G,Z"@HQ*2!#:&5C:R!O=70@=&AE(&-O9&4@8GD@='EP
M:6YG(&!@8W9S(&-O($U/1%5,16!@"C(I(%=O<FL@;VX@=&AE(&-O9&4@/&AA
M8VLL(&AA8VLL(&AA8VL^"C,I($-O;6UI="!A;GD@8VAA;F=E<R!W:71H(&!@
M8W9S(&-O;6UI="!&24Q%3D%-15-@8"!I;B!T:&4@9&ER96-T;W)Y('1H92!F
M:6QE<PH@("!A<F4@:6XN"@I3;VUE=&EM97,L(&]T:&5R<R!W:6QL(&UA:V4@
M8VAA;F=E<R!A;F0@>6]U('=I;&P@;F5E9"!T;R!U<&1A=&4@>6]U<B!T<F5E
M('-O"G1H92!C:&%N9V5S('-H;W<@=7`@:6X@>6]U<B!L;V-A;"!S;W5R8V5S
M+B`@66]U(&1O('1H:7,@=VET:"!T:&4@8&!C=G,*=7!D871E8&`@8V]M;6%N
M9"!I;B!T:&4@:&]R9&4@9&ER96-T;W)Y+B`@4&QE87-E(&)E('-U<F4@=&\@
M=7!D871E('EO=7(@=')E90IR96=U;&%R;'D[(&UE<F=I;F<@8VAA;F=E<R!I
M<R!C;VYS:61E<F%B;'D@;6]R92!W;W)K('1H86X@<G5N;FEN9R!@8&-V<PIU
M<&1A=&5@8"X*"E1O('=O<FL@=VET:"!A;GD@=&%G9V5D(&)R86YC:"`H=&\@
M<&%T8V@@82!S=&%B;&4@<F5L96%S92P@9F]R(&EN<W1A;F-E*3H*"C$I($-H
M96-K(&]U="!T:&4@8V]D92!W:71H(&!@8W9S(&-O("UR(%1!1R!-3T153$5@
M8`HR*2!7;W)K(&]N('1H92!C;V1E(#QH86-K+"!H86-K+"!H86-K/@HS*2!#
M;VUM:70@86YY(&-H86YG97,@=VET:"!@8&-V<R!C;VUM:70@1DE,14Y!3453
M8&`@:6X@=&AE(&1I<F5C=&]R>2!T:&4@9FEL97,*("`@87)E(&EN+@H*268@
M<V]M96)O9'D@96QS92!A;'-O(&UA:V5S(&-H86YG97,@=&\@=&AE(&QA8F5L
M960@=F5R<VEO;BP@>6]U(&-A;B!G970@=&AE;0II;B!Y;W5R(&QO8V%L('-O
M=7)C92!T<F5E('=I=&@@=&AE(&!@8W9S('5P9&%T96!@(&-O;6UA;F0@:7-S
M=65D(&EN('1H92!M;V1U;&4*9&ER96-T;W)Y+@H*268@>6]U(&%R92!D;VYE
M('=O<FMI;F<@=VET:"!T:&4@;&%B96QE9"!S;W5R8V4@8G)A;F-H+"!A;F0@
M=V]U;&0@;&EK92!T;R!M;W9E"F)A8VL@:6YT;R!T:&4@8FQE961I;F<M961G
M92!D979E;&]P;65N="!S;W5R8V4@=')E92P@>6]U(&-A;B!I<W-U92!T:&4@
M8V]M;6%N9`I@8&-V<R!U<&1A=&4@+4%@8"!T;R!U<&1A=&4@979E<GET:&EN
M9R!T;R!T:&4@8W5R<F5N="!@8$A%041@8"!V97)S:6]N+@H**%=E('5S960@
M=&\@9&]C=6UE;G0@:&]W('1O(&UE<F=E(&-O9&4@9G)O;2!(14%$(&EN=&\@
M82!L86)E;&5D(&)R86YC:"!H97)E+`IB=70@<VEN8V4@:70@=V%S(&AE879I
M;'D@<&5P<&5R960@=VET:"`B=&%L:R!T;R!C;W)E(&1E=F5L;W!E<G,@9FER
M<W0B+"!I="=S"F)E96X@96QI9&5D('1O('!R979E;G0@97)R;W)S(&]F(&5X
M<&5R:6UE;G1A=&EO;BX@($EF('EO=2!T:&EN:R!Y;W4@;F5E9"!T;R!D;PIT
M:&%T+"!Y;W4@:&%V92!T;R!T86QK('1O(&-O<F4@9&5V96QO<&5R<R!A;GEH
M;W<@+2T@=&AE>2=L;"!E>'!L86EN(&AO=RXI"@H*3W1H97(@0U93($YO=&5S
M"BTM+2TM+2TM+2TM+2TM+0H*268@>6]U(&1O(&5N9"!U<"!G971T:6YG(&$@
M0U93(&%C8V]U;G0L(&AE<F4@87)E('-O;64@=&EP<R!T;R!H96QP(&ME97`@
M=&AI;F=S"F=O:6YG('-M;V]T:&QY.@H*,2X@4W5B<V-R:6)E('1O('1H92!C
M=G-`;&ES=',N:&]R9&4N;W)G(&%N9"!D979`;&ES=',N:&]R9&4N;W)G(&UA
M:6QI;F<@;&ES=',N"@HR+B!"92!S=7)E('1O(&UO9&EF>2!T:&4@9FEL92!@
M8&1O8W,O0TA!3D=%4V!@('1O(')E9FQE8W0@=&AE(&-H86YG97,@=&\@=&AE
M"B`@(&-O9&4@>6]U(&%R92!C;VUM:71T:6YG+@H*,RX@268@>6]U)W)E('!L
M86YN:6YG(&]N(&1O:6YG(&%N>71H:6YG(&UA:F]R+"!P;&5A<V4@;&5T('!E
M;W!L92!K;F]W(&EN"B`@(&%D=F%N8V4@;VX@=&AE(&1E=D`@;W(@87!P;&EC
M871I;VX@;6%I;&EN9R!L:7-T<R!A<R!A<'!R;W!R:6%T92X*"B`@($1E=F5L
M;W!E<G,@;F5E9"!T;R!C;VUM=6YI8V%T92!E>'1E;G-I=F5L>2!I;B!O<F1E
M<B!T;R!M86ME('-U<F4@979E<GEO;F4*("`@:VYO=W,@=VAA="=S(&=O:6YG
M(&]N+B`@5&AI<R!I<R!E>'1R96UE;'D@:6UP;W)T86YT('=H96X@>6]U('=O
M<FL@;VX@:V5Y"B`@(&-O;7!O;F5N=',N"@HT+B!5<V4@=&AE($)U9R!4<F%C
M:VEN9R!3>7-T96T@;VX@:'1T<#HO+V)U9W,N:&]R9&4N;W)G+B`@06QL(&YE
M=R!S=6)M:7-S:6]N<PH@("!A<F4@8F5I;F<@8V,G9"!T;R!T:&4@8G5G<T!L
M:7-T<RYH;W)D92YO<F<@;6%I;&EN9R!L:7-T('-O('1H870@:68@=V4@87)E
M;B=T"B`@('!A>6EN9R!A='1E;G1I;VXL('=E)VQL(&%T(&QE87-T(&=E="!M
M86EL(&%B;W5T(&ET+B`@57-I;F<@=&AE($)U9W,*("`@9&%T86)A<V4@:&5L
M<',@=7,@:V5E<"!T<F%C:R!O9B!I<W-U97,@=V4@87)E(&AA=FEN9R!A;F0@
M=VAE<F4@=V4@<W1A;F0*("`@=VET:"!T:&4@<')O9'5C="X*"C4N(%)E;65M
M8F5R('1O(&%D=F%N8V4@=&AE(&QI8G)A<GD@=F5R<VEO;B!W:&5N979E<B!A
M;GET:&EN9R!M86IO<B!I<R!C:&%N9V5D+@H`````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O9&]C<R])3E-404Q,````````````````````````````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#8U,C,R(#$P-3$U-#,S-S,T(#`Q-S4S
M,0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*($EN<W1A;&QI
M;F<@=&AE($AO<F1E(#,N,2!&<F%M97=O<FL*/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]"@HZ3&%S="!U<&1A=&4Z("`@)$1A=&4Z(#(P
M,#8O,#@O,34@,#DZ,S`Z-#,@)`HZ4F5V:7-I;VXZ("`@("`@)%)E=FES:6]N
M.B`Q+CDP+C8N,38@)`HZ0V]N=&%C=#H@("`@("`@:&]R9&5`;&ES=',N:&]R
M9&4N;W)G"@HN+B!C;VYT96YT<SHZ($-O;G1E;G1S"BXN('-E8W1I;VXM;G5M
M8F5R:6YG.CH*"E1H:7,@9&]C=6UE;G0@8V]N=&%I;G,@:6YS=')U8W1I;VYS
M(&9O<B!I;G-T86QL:6YG('1H92!(;W)D92!&<F%M97=O<FL@;VX@>6]U<@IS
M>7-T96TN"@I4:&4@2&]R9&4@1G)A;65W;W)K+"!B>2!I='-E;&8L(&1O97,@
M;F]T('!R;W9I9&4@86YY('-I9VYI9FEC86YT(&5N9"!U<V5R"F9U;F-T:6]N
M86QI='D[(&ET('!R;W9I9&5S(&$@8F%S92!F;W(@;W1H97(@87!P;&EC871I
M;VYS(&%N9"!T;V]L<R!F;W(*9&5V96QO<&5R<RX@5VAE;B!Y;W4@:&%V92!I
M;G-T86QL960@2&]R9&4@87,@9&5S8W)I8F5D(&)E;&]W+"!Y;W4@=VEL;`IP
M<F]B86)L>2!W86YT('1O(&EN<W1A;&P@<V]M92!O9B!T:&4@879A:6QA8FQE
M($AO<F1E(&%P<&QI8V%T:6]N<RP@<W5C:"!A<PI)35!?("AA('=E8FUA:6P@
M8VQI96YT*2P@;W(@2W)O;F]L:71H7R`H82!C86QE;F1A<BDN(%1H97)E(&ES
M(&$@;&ES="!O9B!(;W)D90IA<'!L:6-A=&EO;G,@86YD('!R;VIE8W1S(&%T
M(&AT='`Z+R]W=W<N:&]R9&4N;W)G+W!R;VIE8W1S+G!H<"X*"DEF('EO=2!A
M<F4@:6YT97)E<W1E9"!I;B!D979E;&]P:6YG(&%P<&QI8V%T:6]N<R!F;W(@
M2&]R9&4L('1H97)E(&ES(&1E=F5L;W!E<@ID;V-U;65N=&%T:6]N(&%N9"!R
M969E<F5N8V5S(&%V86EL86)L92!A="!H='1P.B\O9&5V+FAO<F1E+F]R9R\L
M(&%N9"!S;VUE"G1U=&]R:6%L<R!A;F0@<&%P97)S(&]N($AO<F1E(&%V86EL
M86)L92!A="!H='1P.B\O=W=W+FAO<F1E+F]R9R]P87!E<G,O+@H*1F]R(&EN
M9F]R;6%T:6]N(&]N('1H92!C87!A8FEL:71I97,@86YD(&9E871U<F5S(&]F
M($AO<F1E+"!S964@=&AE(&9I;&4*4D5!1$U%7R!I;B!T:&4@=&]P+6QE=F5L
M(&1I<F5C=&]R>2!O9B!T:&4@2&]R9&4@9&ES=')I8G5T:6]N+@H*+BX@7TE-
M4#H@:'1T<#HO+W=W=RYH;W)D92YO<F<O:6UP+PHN+B!?2W)O;F]L:71H.B!H
M='1P.B\O=W=W+FAO<F1E+F]R9R]K<F]N;VQI=&@O"@H*3V)T86EN:6YG($AO
M<F1E"CT]/3T]/3T]/3T]/3T]/0H*5&AE($AO<F1E($9R86UE=V]R:R!C86X@
M8F4@;V)T86EN960@9G)O;2!T:&4@2&]R9&4@=V5B<VET92!A;F0@1E10('-E
M<G9E<BP@870*"B`@(&AT='`Z+R]W=W<N:&]R9&4N;W)G+VAO<F1E+PH*("`@
M9G1P.B\O9G1P+FAO<F1E+F]R9R]P=6(O:&]R9&4O"@I/<BP@8F5T=&5R('EE
M="P@=7-E(&$@;6ER<F]R('1H870@:7,@8VQO<V5R('1O('EO=2X@(%1H92!M
M:7)R;W(@;&ES="!C86X@8F4*9F]U;F0@870Z"@H@("!H='1P.B\O=W=W+FAO
M<F1E+F]R9R]M:7)R;W)S+G!H<`H*5&AE($944"!D:7)E8W1O<GD@8V]N=&%I
M;G,@=&AE($AO<F1E(%!(4"!F:6QE<R!W:&EC:"!C86X@8F4@=6YP86-K960@
M=7-I;F<*8&!T87)@8"!A;F0@8&!G=6YZ:7!@8"`H<V5E(&!);G-T86QL:6YG
M($AO<F1E8%\L(&)E;&]W*2X*"D)L965D:6YG+65D9V4@9&5V96QO<&UE;G0@
M=F5R<VEO;G,@;V8@2&]R9&4@86YD(&ET<R!A<'!L:6-A=&EO;G,@87)E(&%V
M86EL86)L90IV:6$@0U93.R!S964@=&AE(&9I;&4@8&1O8W,O2$%#2TE.1V!?
M+"!O<B!V:7-I="!T:&4@=V5B<VET90IH='1P.B\O=W=W+FAO<F1E+F]R9R]S
M;W5R8V4O+"!F;W(@:6YF;W)M871I;VX@;VX@86-C97-S:6YG('1H92!(;W)D
M92!#5E,*<F5P;W-I=&]R>2X*"EEO=2!W:6QL('!R;V)A8FQY(&%L<V\@=V%N
M="!O;F4@;W(@;6]R92!(;W)D92!A<'!L:6-A=&EO;G,L('-I;F-E($AO<F1E
M"F1O97-N)W0@9&\@;75C:"!B>2!I='-E;&8[(&$@;&ES="!O9B!A=F%I;&%B
M;&4@87!P;&EC871I;VYS+"!W:71H(&QI;FMS('1O"F1E<V-R:7!T:6]N<R!A
M;F0@9&]W;FQO861S+"!C86X@8F4@9F]U;F0@870*"B`@(&AT='`Z+R]W=W<N
M:&]R9&4N;W)G+W!R;VIE8W1S+G!H<`H*5VAI;&4@<')E=FEO=7,@=F5R<VEO
M;G,@;V8@2&]R9&4@=V5R92!N=6UB97)E9"!T;R!C;W)R97-P;VYD('=I=&@@
M82!P87)T:6-U;&%R"G9E<G-I;VX@;V8@=&AE($E-4"!W96)M86EL(&%P<&QI
M8V%T:6]N+"!T:&%T(&ES(&YO(&QO;F=E<B!T<G5E(&%S(&]F($AO<F1E"G9E
M<G-I;VX@,BXP+B!4:&4@8W5R<F5N="!V97)S:6]N(&]F($AO<F1E('=I;&P@
M=V]R:R!W:71H('1H92!C=7)R96YT('9E<G-I;VX*;V8@2&]R9&4@87!P;&EC
M871I;VYS+B!&;W(@;6]R92!I;F9O<FUA=&EO;B!A8F]U="!W:&EC:"!V97)S
M:6]N<R!A<F4*8V]M<&%T:6)L92!S964@:'1T<#HO+W=W=RYH;W)D92YO<F<O
M<V]U<F-E+W9E<G-I;VYS+G!H<"X*"@I1=6EC:R!);G-T86QL"CT]/3T]/3T]
M/3T]/3T*"E1H97-E(&%R92!V97)Y('1E<G-E(&EN<W1R=6-T:6]N<R!H;W<@
M=&\@:6YS=&%L;"!(;W)D92!A;F0@:71S('!R97)E<75I<VET97,*;VX@82!,
M04U0('-Y=&5M+B`@5&AE>2!A<F4@861D<F5S<V5D('1O(&5X<&5R:65N8V5D
M(&%D;6EN:7-T<F%T;W)S('=H;R!K;F]W"F5X86-T;'D@=VAA="!T:&5Y(&%R
M92!D;VEN9RX@($9O<B!M;W)E(&1E=&%I;&5D(&EN<W1R=6-T:6]N<RP@<W1A
M<G0@<F5A9&EN9PIB96QO=R!A="!0<F5R97%U:7-I=&5S7RX*"C$N($-O;7!I
M;&EN9R!02%`@9F]R($%P86-H93HZ"@H@("`@(&-D('!H<"UX+G@N>"\*("`@
M("`N+V-O;F9I9W5R92`M+7=I=&@M87!X<STO=7-R+W-B:6XO87!X<R!<"B`@
M("`@("`@("`@("`@("`@+2UW:71H+6=E='1E>'0@+2UW:71H+61O;2`M+7=I
M=&@M;6-R>7!T(%P*("`@("`@("`@("`@("`@("`M+7=I=&@M:6-O;G8@+2UE
M;F%B;&4M;6)S=')I;F<]86QL("TM96YA8FQE+6UB<F5G97@@7`H@("`@("`@
M("`@("`@("`@("TM=VET:"UG9"`M+7=I=&@M<&YG+61I<CTO=7-R("TM=VET
M:"UJ<&5G+61I<CTO=7-R(%P*("`@("`@("`@("`@("`@("`M+7=I=&@M;6EM
M92UM86=I8STO=7-E<B]S:&%R92]M:7-C+VUA9VEC+FUI;64@7`H@("`@("`@
M("`@("`@("`@(%LM+7=I=&@M;7ES<6Q\+2UW:71H+7!G<W%L?"TM=VET:"UO
M8VDX?"TM=VET:"UL9&%P70H@("`@(&UA:V4*("`@("!M86ME(&EN<W1A;&P*
M"C(N(%)E<W1A<G0@07!A8VAE+@H*,RX@26YS=&%L;"!014%2('!A8VMA9V5S
M.CH*"B`@("`@<&5A<B!I;G-T86QL("UO($QO9R!-86EL($UA:6Q?36EM92!$
M0B!$871E($9I;&4*("`@("!P96%R("UD('!R969E<G)E9%]S=&%T93UB971A
M(&EN<W1A;&P@+6$@4V5R=FEC97-?5V5A=&AE<@H*-"X@17AT<F%C="!T87)B
M86QL.CH*"B`@("`@8V0@+W5S<B]L;V-A;"]A<&%C:&4O:'1D;V-S"B`@("`@
M=&%R('IX=F8@+W!A=&@O=&\O:&]R9&4M>"YY+GHN=&%R+F=Z"B`@("`@;78@
M:&]R9&4M>"YY+GH@:&]R9&4*"C4N($-O;F9I9W5R92!(;W)D93HZ"@H@("`@
M(&-D(&-O;F9I9R\*("`@("!F;W(@9B!I;B`J+F1I<W0[(&1O(&-P("1F(&!B
M87-E;F%M92`D9B`N9&ES=&`[(&1O;F4*"C8N($-R96%T92!D871A8F%S92!T
M86)L97,Z.@H*("`@("!C9"`N+B]S8W)I<'1S+W-Q;`H@("`@('9I(&-R96%T
M92YM>7-Q;"YS<6P*("`@("!M>7-Q;"`M=2!R;V]T("UP(#P@8W)E871E+FUY
M<W%L+G-Q;`H*-RX@5&5S="!(;W)D93HZ"@H@("`@(&AT='`Z+R]Y;W5R+7-E
M<G9E<B]H;W)D92]T97-T+G!H<`H*."X@1FEN:7-H(&-O;F9I9W5R871I;VXZ
M.@H*("`@("!H='1P.B\O>6]U<BUS97)V97(O:&]R9&4O"@H@("!';R!T;R!!
M9&UI;G-T<F%T:6]N(#T^(%-E='5P(#T^($AO<F1E"@H*4')E<F5Q=6ES:71E
M<PH]/3T]/3T]/3T]/3T]"@I4:&4@9F]L;&]W:6YG('!R97)E<75I<VET97,@
M87)E("HJ4D5154E2140J*B!F;W(@2&]R9&4@=&\@9G5N8W1I;VX@<')O<&5R
M;'DN"@HQ+B!!('=E8G-E<G9E<B!T:&%T('-U<'!O<G1S(%!(4"X*"B`@($AO
M<F1E(&%N9"!I=',@87!P;&EC871I;VYS(&%R92!D979E;&]P960@=6YD97(@
M=&AE($%P86-H92!W96)S97)V97(L('=H:6-H"B`@('=E(')E8V]M;65N9"X@
M07!A8VAE(&ES(&%V86EL86)L92!F<F]M"@H@("`@("!H='1P.B\O:'1T<&0N
M87!A8VAE+F]R9R\*"B`@($AO<F1E(&AA<R!A;'-O(&)E96X@<F5P;W)T961L
M>2!U<V5D('-U8V-E<W-F=6QL>2!U;F1E<B!-:6-R;W-O9G0@24E3+"!A;6]N
M9PH@("!O=&AE<G,N"@HR+B!02%`@-"XS+C`@;W(@86)O=F4N"@H@("!02%`@
M:7,@=&AE(&EN=&5R<')E=&5D(&QA;F=U86=E(&EN('=H:6-H($AO<F1E(&ES
M('=R:71T96XN"B`@(%EO=2!C86X@;V)T86EN(%!(4"!A=`H*("`@("`@:'1T
M<#HO+W=W=RYP:'`N;F5T+PH*("`@1F]L;&]W('1H92!I;G-T<G5C=&EO;G,@
M:6X@=&AE(%!(4"!P86-K86=E('1O(&)U:6QD(%!(4"!F;W(@>6]U<B!S>7-T
M96TN($EF"B`@('EO=2!U<V4@07!A8VAE+"!B92!S=7)E('1O(&)U:6QD(%!(
M4"!A<R!A(&QI8G)A<GD@=VET:"!O;F4@;V8@=&AE(&9O;&QO=VEN9PH@("!O
M<'1I;VYS.CH*"B`@("`@("`M+7=I=&@M87!A8VAE"B`@("`@("`M+7=I=&@M
M87!X<PH@("`@("`@+2UW:71H+6%P>',R"@H@("!O<'1I;VYS('1O(&!@+B]C
M;VYF:6=U<F5@8"P@86YD(&YO="!A<R!A('-T86YD86QO;F4@97AE8W5T86)L
M92X*"B`@(%1H92!F;VQL;W=I;F<@4$A0(&]P=&EO;G,@87)E("HJ4D5154E2
M140J*B!B>2!(;W)D92`H;&ES=&5D('=I=&@@=&AE:7(@;W=N"B`@('!R97)E
M<75I<VET97,@86YD(&-O;F9I9W5R92!O<'1I;VYS*2X@26X@;6%N>2!C87-E
M<RP@=&AE(')E<75I<F5D(&QI8G)A<FEE<PH@("!A;F0@=&]O;',@8V%N(&)E
M(&]B=&%I;F5D(&%S('!A8VMA9V5S(&9R;VT@>6]U<B!O<&5R871I;F<@<WES
M=&5M('9E;F1O<BX*"B`@(&$N($=E='1E>'0@<W5P<&]R="X@8&`M+7=I=&@M
M9V5T=&5X=&!@"@H@("`@("!'971T97AT(&ES('1H92!'3E4@5')A;G-L871I
M;VX@4')O:F5C="=S(&QO8V%L:7IA=&EO;B!L:6)R87)Y+@H@("`@("!(;W)D
M92!U<V5S(&=E='1E>'0@=&\@<')O=FED92!L;V-A;"!T<F%N<VQA=&EO;G,@
M;V8@=&5X="!D:7-P;&%Y960@8GD*("`@("`@87!P;&EC871I;VYS+B!);F9O
M<FUA=&EO;B!O;B!O8G1A:6YI;F<@=&AE(&=E='1E>'0@<&%C:V%G92!I<R!A
M=F%I;&%B;&4*("`@("`@870*"B`@("`@("`@(&AT='`Z+R]W=W<N9VYU+F]R
M9R]S;V9T=V%R92]G971T97AT+V=E='1E>'0N:'1M;`H*("`@("`@4V5E(&%L
M<V\@;F]T92!B96QO=R!O;B!C;VYF:6=U<FEN9R!4<F%N<VQA=&EO;G-?+@H*
M("`@8BX@6$U,(&%N9"!$3TU834P@<W5P<&]R="X@8&`M+7=I=&@M9&]M8&`*
M"B`@("`@($AO<F1E)W,@:&5L<"!E;F=I;F4@86YD(&-O;7!O;F5N="!S971U
M<"!R97%U:7)E(%A-3"!S=7!P;W)T+B!7:&EL92!S;VUE"B`@("`@('=E8G-E
M<G9E<G,@*&EN8VQU9&EN9R!R96-E;G0@07!A8VAE('9E<G-I;VYS*2!H879E
M(%A-3"!L:6)R87)I97,*("`@("`@8G5I;'0M:6XL(&]T:&5R<R!W:6QL(')E
M<75I<F4@=&AE(&5X<&%T(%A-3"!P87)S97(@;&EB<F%R:65S+"!A=F%I;&%B
M;&4*("`@("`@9G)O;0H*("`@("`@("!H='1P.B\O97AP870N<V]U<F-E9F]R
M9V4N;F5T+PH*("`@("`@+BX@26UP;W)T86YT.CH@66]U(&UU<W0@:&%V92`J
M*F)O=&@J*B!834P@;&EB<F%R:65S(&EN<W1A;&QE9"!F;W(@2&]R9&4*("`@
M("`@("`@("`@("`@("`@("`@=&\@=V]R:R!P<F]P97)L>2$*"B`@("`@($]L
M9&5R('9E<G-I;VYS(&]F(%!(4"!A;'-O(')E<75I<F4@8&`M+7=I=&@M>&UL
M8&`@=&\@96YA8FQE('1H90H@("`@("!305@@6$U,(&9U;F-T:6]N<RX@5VET
M:"!R96-E;G0@=F5R<VEO;G,@;V8@4$A0+"!T:&ES(&ES(&5N86)L960*("`@
M("`@8GD@9&5F875L="X*"B`@(%1H92!F;VQL;W=I;F<@4$A0(&]P=&EO;G,@
M87)E("HJ4D5#3TU-14Y$140J*B!T;R!E;F%B;&4@861V86YC960@9F5A='5R
M97,@:6X*("`@2&]R9&4Z"@H@("!A+B!!('!R969E<F5N8V5S(&-O;G1A:6YE
M<BX*"B`@("`@($AO<F1E(&%P<&QI8V%T:6]N<R!C86X@<W1O<F4@=7-E<B!P
M<F5F97)E;F-E<R!I;B!A;B!344P@9&%T86)A<V4L(&%N"B`@("`@($Q$05`@
M9&ER96-T;W)Y+"!A;B!)35-0('-E<G9E<BP@82!+;VQA8B!S97)V97(L(&]R
M(&EN(%!(4"!S97-S:6]N<RX*"B`@("`@($9O<B!344P@9&%T86)A<V4@<')E
M9F5R96YC97,@<W1O<F%G92P@2&]R9&4@:7,@=&AO<F]U9VAL>2!T97-T960@
M;VX*("`@("`@37E344P@*&!@+2UW:71H+6UY<W%L8&`I(&%N9"!0;W-T9W)E
M4U%,("A@8"TM=VET:"UP9W-Q;&!@*2!A;F0@:&%S(&)E96X*("`@("`@<F5P
M;W)T960@=&\@=V]R:R!W:71H($]R86-L92`H8&`M+7=I=&@M;V-I.&!@*2!A
M;F0@4U%,(%-E<G9E<@H@("`@("`H8&`M+7=I=&@M;7-S<6Q@8"DN("!)="!M
M87D@86QS;R!W;W)K('=I=&@@86YY(&]T:&5R(&1A=&%B87-E('-U<'!O<G1E
M9`H@("`@("!B>2!014%2+"!B=70@=&AE>2!A<F4@=6YT97-T960N"@H@("`@
M("!0<F5F97)E;F-E<R!C86X@86QS;R!B92!S=&]R960@=FEA($Q$05`@*&!@
M+2UW:71H+6QD87!@8"DL($MO;&%B"B`@("`@("A@8"TM=VET:"UL9&%P8&`I
M+"!A;F0@24U34"X*"B`@("`@($%L=&5R;F%T:79E;'DL('!R969E<F5N8V5S
M(&-A;B!B92!S=&]R960@:6X@4$A0('-E<W-I;VYS+"!W:&EC:`H@("`@("!R
M97%U:7)E<R!N;R!E>'1E<FYA;"!P<F]G<F%M<R!O<B!C;VYF:6=U<F4@;W!T
M:6]N<RP@8G5T('=H:6-H('=I;&P@;F]T"B`@("`@(&UA:6YT86EN('!R969E
M<F5N8V5S(&)E='=E96X@<V5S<VEO;G,N"@H@("`@("!7:&EL92!T:&4@3$1!
M4"P@9&%T86)A<V4L($MO;&%B+"!O<B!)35-0('-E<G9E<B!N965D(&YO="!B
M92!R=6YN:6YG(&]N"B`@("`@('1H92!M86-H:6YE(&]N=&\@=VAI8V@@>6]U
M(&%R92!I;G-T86QL:6YG($AO<F1E+"!T:&4@87!P<F]P<FEA=&4*("`@("`@
M8VQI96YT(&QI8G)A<FEE<R!T;R!A8V-E<W,@=&AE('-E<G9E<B!M=7-T(&)E
M(&%V86EL86)L92!L;V-A;&QY+@H*("`@("`@268@82!P<F5F97)E;F-E(&-O
M;G1A:6YE<B!I<R!N;W0@8V]N9FEG=7)E9"P@;F\@<')E9F5R96YC92!O<'1I
M;VYS"B`@("`@('=I;&P@8F4@8V]N9FEG=7)A8FQE('9I82!(;W)D92=S('=E
M8B!I;G1E<F9A8V4@+2!T:&4@9&5F875L="!V86QU97,*("`@("`@<W1O<F5D
M(&EN(&5A8V@@87!P;&EC871I;VYS(&!@8V]N9FEG+W!R969S+G!H<&!@(&9I
M;&4@=VEL;"!B92!U<V5D+@H*("`@8BX@36-R>7!T('-U<'!O<G0@8&`M+7=I
M=&@M;6-R>7!T8&`*"B`@("`@($UC<GEP="!I<R!A(&=E;F5R86PM<'5R<&]S
M92!C<GEP=&]G<F%P:'D@;&EB<F%R>2!W:&EC:"!I<R!B<F]A9&5R(&%N9`H@
M("`@("!S:6=N:69I8V%N=&QY(&UO<F4@969F:6-I96YT("A&05-415(A*2!T
M:&%N(%!(4"=S(&]W;B!C<GEP=&]G<F%P:&EC"B`@("`@(&-O9&4N(%EO=2!C
M86X@;V)T86EN(&UC<GEP="!F<F]M"@H@("`@("`@("!H='1P.B\O;6-R>7!T
M+G-O=7)C969O<F=E+FYE="\*"B`@("`@($)U:6QD:6YG(%!(4"!W:71H;W5T
M(&UC<GEP="!S=7!P;W)T('=I;&P@;F]T('-T;W`@2&]R9&4@9G)O;2!W;W)K
M:6YG+`H@("`@("!B=70@=VEL;"!F;W)C92!I="!T;R!U<V4@=V5A:V5R("AA
M;F0@;75C:"!S;&]W97(I(&5N8W)Y<'1I;VXN"@H@("!C+B!55$8M."!S=7!P
M;W)T(&!@+2UW:71H+6EC;VYV("TM96YA8FQE+6UB<W1R:6YG/6%L;"`M+65N
M86)L92UM8G)E9V5X8&`*"B`@("`@($EF('1H97-E(&5X=&5N<VEO;G,@87)E
M(&5N86)L960L($AO<F1E(&-A;B!S=7!P;W)T(&UU;'1I8GET92!C:&%R86-T
M97(*("`@("`@<V5T<R!L:6ME(%541BTX("AM96%N:6YG('1H870@8V]N=&5N
M="!W:71H(&%N>2!C:&%R<V5T(&-A;B!B92!V:65W960*("`@("`@=VET:"!A
M;GD@=')A;G-L871I;VXI+@H*("`@9"X@1T0@<W5P<&]R="!@8"TM=VET:"UG
M9&!@"@H@("`@("!(;W)D92!W:6QL('5S92!T:&4@1T0@97AT96YS:6]N('1O
M('!E<F9O<FT@;6%N:7!U;&%T:6]N<R!O;B!I;6%G92!D871A"B`@("`@('1H
M<F]U9V@@=&AE($AO<F1E7TEM86=E(&QI8G)A<GDN"@H@("`@("!)9B!Y;W4@
M=V%N="!'1"!T;R!B92!A8FQE('1O('=O<FL@=VET:"!03D<@:6UA9V5S+"!Y
M;W4@<VAO=6QD('5S92!T:&4*("`@("`@8&`M+7=I=&@M<&YG+61I<F!@(&]P
M=&EO;B!T;R!M86ME('-U<F4@4$A0(&-A;B!F:6YD('1H92!03D<@;&EB<F%R
M:65S"B`@("`@(&ET(&YE961S('1O(&-O;7!I;&4N"@H@("`@("!)9B!Y;W4@
M=V%N="!'1"!T;R!B92!A8FQE('1O('=O<FL@=VET:"!*4$5'(&EM86=E<RP@
M>6]U('-H;W5L9"!U<V4@=&AE"B`@("`@(&!@+2UW:71H+6IP96<M9&ER8&`@
M;W!T:6]N('1O(&UA:V4@<W5R92!02%`@8V%N(&9I;F0@=&AE($I014<@;&EB
M<F%R:65S"B`@("`@(&ET(&YE961S('1O(&-O;7!I;&4N"@H@("`@("!9;W4@
M8V%N(&%L<V\@=7-E('1H92!);6%G94UA9VEC:U\@<&%C:V%G92!T;R!D;R!T
M:&5S92!M86YI<'5L871I;VYS"B`@("`@(&EN<W1E860N("!3964@=&AE(&!@
M26UA9V4@36%N:7!U;&%T:6]N8&`@=&%B(&]F('1H92!(;W)D92!S971U<"!F
M;W(@;6]R90H@("`@("!D971A:6QS+@H*("`@("`@+BX@7TEM86=E36%G:6-K
M.B!H='1P.B\O=W=W+FEM86=E;6%G:6-K+F]R9PH*("`@92X@34E-12!-86=I
M8R!S=7!P;W)T(&!@+2UW:71H+6UI;64M;6%G:6-@8`H*("`@("`@2&]R9&4@
M=VEL;"!U<V4@=&AE($U)344@36%G:6,@97AT96YS:6]N('1O(&=U97-S('1H
M92!-24U%('1Y<&4@;V8@9FEL97,*("`@("`@8GD@86YA;'EZ:6YG('1H96ER
M(&-O;G1E;G1S+@H*("`@("`@+BX@3F]T93HZ(%1H:7,@97AT96YS:6]N(&ES
M(')E<&]R=&5D('1O(&)E(&1E<')E8V%T961?(&EN(&9A=F]R(&]F('1H90H@
M("`@("`@("`@("`@("`@9FEL96EN9F\@4$5#3"!E>'1E;G-I;VX@*'-E92!B
M96QO=RDN("!(;W=E=F5R+"!S;VUE('5S97)S(&AA=F4*("`@("`@("`@("`@
M("`@(')E<&]R=&5D('1H870@=&AE(&9I;&5I;F9O(&5X=&5N<VEO;B!W:6QL
M(&YO="!B=6EL9"!C;W)R96-T;'D*("`@("`@("`@("`@("`@(&]N('1H96ER
M('-Y<W1E;2X@268@<V\L('1H96X@=&AE($U)344@36%G:6,@97AT96YS:6]N
M('-H;W5L9`H@("`@("`@("`@("`@("`@8F4@=7-E9"!I;G-T96%D+B!0:6-K
M(&]N92!O<B!T:&4@;W1H97(@+2!T:&5R92!I<R!N;R!N965D('1O"B`@("`@
M("`@("`@("`@("!C;VUP:6QE(&)O=&@N"@H@("`@("!)9B!U<VEN9R!02%`@
M-"XS+C`@+3X@-"XS+C$L('EO=2!S:&]U;&0@=7-E(&!@+2UE;F%B;&4M;6EM
M92UM86=I8V!@"B`@("`@(&EN<W1E860@;V8@8&`M+7=I=&@M;6EM92UM86=I
M8V!@+@H*("`@("`@+BX@7V1E<')E8V%T960Z(&AT='`Z+R]W=W<N<&AP+FYE
M="]M:6UE7VUA9VEC"@H@("`N+B!);7!O<G1A;G0Z.B!!9&1I=&EO;F%L;'DL
M(&EN9&EV:61U86P@2&]R9&4@87!P;&EC871I;VYS(&UA>2`J*E)%455)4D4J
M*@H@("`@("`@("`@("`@("`@("!O<B`J*E)%0T]-345.1"HJ(&]T:&5R(&]P
M=&EO;G,@=&\@8F4@8G5I;'0@:6YT;R!02%`*("`@("`@("`@("`@("`@("`@
M86QS;RX@4&QE87-E(&-H96-K(&!@9&]C<R])3E-404Q,8&`@9F]R(&%L;"!A
M<'!L:6-A=&EO;G,@>6]U"B`@("`@("`@("`@("`@("`@('=I<V@@=&\@=7-E
M('1O('-E92!I9B!O=&AE<B!02%`@;W!T:6]N<R!A<F4@;F5E9&5D+@H*,RX@
M061D:71I;VYA;"!014%2($UO9'5L97,*"B`@(%!%05(@:7,@<VAO<G0@9F]R
M(")02%`@17AT96YS:6]N(&%N9"!!<'!L:6-A=&EO;B!297!O<VET;W)Y(BX@
M(%1H92!G;V%L(&]F"B`@(%!%05(@:7,@=&\@<')O=FED92!A(&UE86YS(&]F
M(&1I<W1R:6)U=&EN9R!R975S86)L92!C;V1E+@H*("`@1F]R(&UO<F4@:6YF
M;W)M871I;VXL('-E92!H='1P.B\O<&5A<BYP:'`N;F5T+PH*("`@+BX@26UP
M;W)T86YT.CH@36%K92!S=7)E('EO=2!A<F4@<G5N;FEN9R!A('-U<'!O<G1E
M9"`H:2YE+B!N97<@96YO=6=H*0H@("`@("`@("`@("`@("`@("!V97)S:6]N
M(&]F(%!%05(Z('5S92!T:&4@=&5S="!S8W)I<'0@9&5S8W)I8F5D(&)E;&]W
M('5N9&5R"B`@("`@("`@("`@("`@("`@(")@0V]N9FEG=7)I;F<@2&]R9&5@
M7R(N("!$;R`J*FYO="HJ('5S92!T:&4@4$5!4B!V97)S:6]N"B`@("`@("`@
M("`@("`@("`@(&9R;VT@9G1P+FAO<F1E+F]R9RX*"B`@($-H96-K('1H870@
M=&AE('!A=&@@=VAE<F4@=&AE(%!%05(@<&%C:V%G97,@87)E(&EN<W1A;&QE
M9"!A<F4@<&%R="!O9B!T:&4*("`@8&!I;F-L=61E7W!A=&A@8"!P87)A;65T
M97(@=&AA="!02%`@=7-E<R!T;R!F:6YD(%!%05(@<&%C:V%G97,N"@H@("!2
M=6X@=&AE(&-O;6UA;F0Z.@H*("`@("!P96%R(&-O;F9I9RUS:&]W"@H@("!9
M;W4@=VEL;"!S964@<V]M971H:6YG(&QI:V4Z.@H*("`@("!014%2(&1I<F5C
M=&]R>2`@("`@("`@("`@("`@("`@<&AP7V1I<B`@("`@("`@("]U<W(O<VAA
M<F4O<&AP"@H@("!.;W<@;W!E;B!T:&4@<&AP+FEN:2!F:6QE(&]F('EO=7(@
M<WES=&5M+"!F;W(@97AA;7!L92!@8"]E=&,O<&AP+FEN:6!@+`H@("!F:6YD
M('1H92!@8&EN8VQU9&5?<&%T:&!@(&%N9"!M86ME('-U<F4@=&AA="!@8"]U
M<W(O<VAA<F4O<&AP8&`@:7,@<&%R="!O9@H@("!T:&4@;&ES="X@($EF('EO
M=2!H860@=&\@8VAA;F=E('1H870@=F%L=64L(')E<W1A<G0@=&AE('=E8B!S
M97)V97(@869T97(*("`@<V%V:6YG(&!@<&AP+FEN:6!@+@H*("`@5&AE<V4@
M4$5!4B!M;V1U;&5S(&%R92`J*E)%455)4D5$*BH@=&\@8F4@:6YS=&%L;&5D
M(&9O<B!C;VUP;&5T92!(;W)D90H@("!F=6YC=&EO;F%L:71Y.@H*("`@82X@
M3&]G"B`@(&(N($UA:6P*("`@8RX@36%I;%]-:6UE"@H@("`@("!4;R!I;G-T
M86QL+"!E;G1E<B!T:&4@9F]L;&]W:6YG(&%T('1H92!C;VUM86YD('!R;VUP
M=#HZ"@H@("`@("`@('!E87(@:6YS=&%L;"!,;V<@36%I;"!-86EL7TUI;64*
M"B`@(%1H97-E(%!%05(@;6]D=6QE<R!A<F4@*BI214-/34U%3D1%1"HJ('1O
M(&)E(&EN<W1A;&QE9#H*"B`@(&$N($1"("@^/2`Q+C8N,"D*"B`@("`@("HJ
M4D5154E2140J*B!A<R!S;V]N(&%S('EO=2!W86YT(&]R(&YE960@=&\@<W1O
M<F4@86YY=&AI;F<@:6X@82!D871A8F%S92X*("`@("`@5&\@:6YS=&%L;"P@
M96YT97(@=&AE(&9O;&QO=VEN9R!A="!T:&4@8V]M;6%N9"!P<F]M<'0Z.@H*
M("`@("`@("!P96%R(&EN<W1A;&P@1$(*"B`@("`@(%1O('5P9W)A9&4L(&5N
M=&5R('1H92!F;VQL;W=I;F<@870@=&AE(&-O;6UA;F0@<')O;7!T.CH*"B`@
M("`@("`@<&5A<B!U<&=R861E($1""@H@("!B+B!&:6QE"@H@("`@("`J*E)%
M455)4D5$*BH@;VYL>2!I9B!Y;W4@=VES:"!T;R!I;7!O<G0@0U-6(&9I;&5S
M+@H@("`@("!4;R!I;G-T86QL+"!E;G1E<B!T:&4@9F]L;&]W:6YG(&%T('1H
M92!C;VUM86YD('!R;VUP=#HZ"@H@("`@("`@('!E87(@:6YS=&%L;"!&:6QE
M"@H@("!C+B!$871E"@H@("`@("`J*E)%455)4D5$*BH@;VYL>2!I9B!Y;W4@
M87)E(&1E86QI;F<@=VET:"!C86QE;F1A<B!D871A+@H@("`@("!4;R!I;G-T
M86QL+"!E;G1E<B!T:&4@9F]L;&]W:6YG(&%T('1H92!C;VUM86YD('!R;VUP
M=#HZ"@H@("`@("`@('!E87(@:6YS=&%L;"!$871E"@H@("!D+B!397)V:6-E
M<U]796%T:&5R("@^/2`Q+C,N,2D*"B`@("`@("HJ4D5154E2140J*B!O;FQY
M(&EF('EO=2!W:7-H('1O('5S92!T:&4@=V5A=&AE<BYC;VT@8FQO8VL@;VX*
M("`@("`@=&AE('!O<G1A;"!P86=E+@H@("`@("!4;R!I;G-T86QL+"!E;G1E
M<B!T:&4@9F]L;&]W:6YG(&%T('1H92!C;VUM86YD('!R;VUP=#HZ"@H@("`@
M("`@('!E87(@+60@<')E9F5R<F5D7W-T871E/6)E=&$@:6YS=&%L;"`M82!3
M97)V:6-E<U]796%T:&5R"@H@("`@("!!9&1I=&EO;F%L('-T97!S(&%R92!R
M97%U:7)E9"!I9B!Y;W4@=V%N="!U<V4@=&AE($U%5$%2('=E871H97(@8FQO
M8VL@;VX*("`@("`@=&AE('!O<G1A;"!P86=E+B!3964@=&AE(&9I;&4@8&!D
M871A+U-E<G9I8V5S7U=E871H97(O8G5I;&1-971A<D1"+G!H<&!@"B`@("`@
M(&EN('EO=7(@4$5!4B!D:7)E8W1O<GD@9F]R(&1E=&%I;',N"@H@("!4:&ES
M(&UE=&AO9"!O9B!I;G-T86QL:6YG(%!%05(@;6]D=6QE<R!R97%U:7)E<R!T
M:&%T('EO=2!H879E(&$@4$A0('9E<G-I;VX*("`@=&AA="!H87,@8F5E;B!C
M;VUP:6QE9"!A<R!A('-T871I8R!B:6YA<GDN("!!;&P@=F5R<VEO;G,@;V8@
M4$A0(#0N,RXP*PH@("!B=6EL9"!B;W1H(&$@4T%022!M;V1U;&4@*$%P86-H
M92P@0T=)+"!E=&,N*2!A;F0@82!C;VUM86YD+6QI;F4@*$-,22D*("`@8FEN
M87)Y(&%T('1H92!S86UE('1I;64N("!#:&5C:R!I9B!Y;W4@:&%V92!A('!H
M<"!B:6YA<GD@:6X*("`@8&`O=7-R+VQO8V%L+V)I;F!@("A@8"]U<W(O8FEN
M8&`@:68@:68@>6]U(&EN<W1A;&QE9"!F<F]M(&%N(&]P97)A=&EN9PH@("!S
M>7-T96T@<&%C:V%G92D@8F5F;W)E(')E8V]M<&EL:6YG+@H*("`@268@>6]U
M(')E8V5I=F4@=&AE(&5R<F]R(&!@0V]U;&0@;F]T(')E860@8VUD(&%R9W-@
M8"!Y;W4@<VAO=6QD(')U;B!T:&4@<&5A<@H@("!S8W)I<'0@=&AI<R!W87DZ
M.@H*("`@("!P:'`@+60@<F5G:7-T97)?87)G8U]A<F=V/3$@7U!%05)?(&EN
M<W1A;&P@7TU/1%5,15\*"B`@(%]014%27R!I<R!T:&4@8V]M<&QE=&4@<&%T
M:"!O9B!T:&4@<&5A<B!S8W)I<'0@:6YS=&%L;&5D(&)Y(%!(4"!D=7)I;F<*
M("`@:6YS=&%L;&%T:6]N("AE+F<N(&!@+W5S<B]L;V-A;"]B:6XO<&5A<F!@
M*2X@($UA:V4@<W5R92!T:&4@8&!P96%R8&`@<V-R:7!T"B`@(&%P<&5A<G,@
M:6X@>6]U<B!P871H+B!4:&4@9&5F875L="!I;G-T86QL871I;VX@<&%T:"!F
M;W(@<&5A<B!I<PH@("!@8"]U<W(O;&]C86PO8FEN+W!E87)@8"X*"B`@(%]-
M3T153$5?(&ES('1H92!014%2(&UO9'5L92P@;&ES=&5D(&%B;W9E+"!W:&EC
M:"!Y;W4@=VES:"!T;R!I;G-T86QL+@H*("`@1F]R(&UO<F4@9&5T86EL960@
M9&ER96-T:6]N<R!O;B!I;G-T86QL:6YG(%!%05(@;6]D=6QE<RP@<V5E('1H
M92!014%2"B`@(&1O8W5M96YT871I;VX@870@:'1T<#HO+W!E87(N<&AP+FYE
M="]M86YU86PO"@HT+B!!9&1I=&EO;F%L(%!%0TP@36]D=6QE<PH*("`@4$5#
M3"!I<R!S:&]R="!F;W(@(E!(4"!%>'1E;G-I;VX@0V]M;75N:71Y($QI8G)A
M<GDB+B`@5&AE(&=O86P@;V8@4$5#3"!I<PH@("!T;R!P<F]V:61E(&$@;65A
M;G,@;V8@96%S:6QY(&1I<W1R:6)U=&EN9R!02%`@97AT96YS:6]N<RX*"B`@
M($9O<B!M;W)E(&EN9F]R;6%T:6]N+"!S964@:'1T<#HO+W!E8VPN<&AP+FYE
M="\*"B`@(%!%0TP@:7,@=&AE(")S:7-T97(B(&]F(%!%05(@86YD('5S97,@
M=&AE('-A;64@<&%C:V%G:6YG(&%N9"!D:7-T<FEB=71I;VX*("`@<WES=&5M
M(&%S(%!%05(L('-O('1H92!C;VYF:6=U<F%T:6]N+W-E='5P(&ES(&5S<V5N
M=&EA;&QY(&ED96YT:6-A;"!T;R!T:&4*("`@4$5!4B!I;G-T<G5C=&EO;G,@
M86)O=F4N"@H@("!7:&5N('EO=2!I;G-T86QL(&$@4$5#3"!E>'1E;G-I;VXL
M('EO=2!H879E('1O(&%D9"!I="!T;R!Y;W5R(&!@<&AP+FEN:6!@"B`@('-O
M(&ET(&=E=',@;&]A9&5D+B`@061D('1H92!F;VQL;W=I;F<@;&EN92!T;R!Y
M;W5R(&!@<&AP+FEN:6!@(&9I;&4@=&\@;&]A9`H@("!T:&4@97AT96YS:6]N
M("AT:&4@97AT96YS:6]N('-H;W5L9"!B92!I;G-T86QL960@:6X@=&AE(&1I
M<F5C=&]R>2!S<&5C:69I960*("`@8GD@=&AE(&!@97AT96YS:6]N7V1I<F!@
M(&]P=&EO;B!I;B!@8'!H<"YI;FE@8"DZ.@H*("`@("!E>'1E;G-I;VX]9FEL
M96EN9F\N<V\*"B`@($]R(&]N(%=I;F1O=W,Z.@H*("`@("!E>'1E;G-I;VX]
M9FEL96EN9F\N9&QL"@H@("!!9G1E<B!T:&%T+"!R97-T87)T('EO=7(@=V5B
M<V5R=F5R+@H*("`@5&AE<V4@4$5#3"!M;V1U;&5S(&%R92`J*E)%0T]-345.
M1$5$*BH@=&\@8F4@:6YS=&%L;&5D.@H*("`@82X@9FEL96EN9F\*"B`@("`@
M($%L;&]W<R!(;W)D92!M;V1U;&5S('1O(&=U97-S('1H92!-24U%('1Y<&4@
M;V8@9FEL97,@8GD@86YA;'EZ:6YG"B`@("`@('1H96ER(&-O;G1E;G1S+@H*
M("`@("`@268@;F]T(&5N86)L960L($AO<F1E('=I;&P@=7-E(&ET<R!O=VX@
M4$A0(&-O9&4@=&\@<&5R9F]R;2!-24U%(&UA9VEC"B`@("`@(&QO;VMU<',N
M("!(;W=E=F5R+"!T:&ES(&QO;VMU<"!I<R!S;&]W97(L(&QE<W,@86-C=7)A
M=&4L(&%N9"!D971E8W1S"B`@("`@(&9E=V5R($U)344@='EP97,@=&AA;B!T
M:&4@4$5#3"!E>'1E;G-I;VX@=VEL;"X*"B`@("`@(%1O(&EN<W1A;&PL(&5N
M=&5R('1H92!F;VQL;W=I;F<@870@=&AE(&-O;6UA;F0@<')O;7!T.CH*"B`@
M("`@("`@<&5A<B!I;G-T86QL(&9I;&5I;F9O"@H@("!4:&5S92!014-,(&UO
M9'5L97,@87)E("HJ4D5#3TU-14Y$140J*B!T;R!B92!I;G-T86QL960@:68@
M>6]U(&YE960*("`@861V86YC960@9G5N8W1I;VYA;&ET>3H*"B`@(&$N(&UE
M;6-A8VAE"@H@("`@("!)9B!U<VEN9R!T:&4@;65M8V%C:&5D(%-E<W-I;VY(
M86YD;&5R+"!T:&4@;65M8V%C:&4@4$5#3"!E>'1E;G-I;VX@;75S=`H@("`@
M("!B92!I;G-T86QL960N"@H@("`@("!4;R!I;G-T86QL+"!E;G1E<B!T:&4@
M9F]L;&]W:6YG(&%T('1H92!C;VUM86YD('!R;VUP=#HZ"@H@("`@("`@('!E
M87(@:6YS=&%L;"!M96UC86-H90H*("`@1F]R(&%D9&ET:6]N86P@:&5L<"!O
M;B!U<VEN9R!T:&4@<&5A<B!C;VUM86YD+6QI;F4@<')O9W)A;2!T;R!I;G-T
M86QL(%!%0TP*("`@97AT96YS:6]N<RP@<V5E('1H92!014%2(&EN<W1A;&QA
M=&EO;B!S96-T:6]N(&%B;W9E+@H*"E1H92!F;VQL;W=I;F<@;F]N+5!(4"!P
M<F5R97%U:7-I=&5S(&%R92`J*E)%0T]-345.1$5$*BHL(&]R(&%R92`J*E)%
M455)4D5$*BH*:68@>6]U('5S92!A('-P96-I9FEC($AO<F1E(&%P<&QI8V%T
M:6]N("AA<R!N;W1E9"!I;B!;8G)A8VME='-=*3H*"C$N(%-E;F1M86EL(&]R
M(&5Q=6EV86QE;G0N"@H@("!(;W)D92!U<V5S('-E;F1M86EL+"!O<B!A('!R
M;V=R86T@=&AA="!I;7!L96UE;G1S('1H92!@8'-E;F1M86EL*#@I8&`@05!)
M"B`@("AA<R!I;F-L=61E9"!W:71H('!O<W1F:7@L('%M86EL+"!A;F0@97AI
M;2P@86UO;F<@;W1H97)S*2X@268@>6]U<B!S>7-T96T*("`@9&]E<R!N;W0@
M86QR96%D>2!H879E(&$@9G5L;"!M86EL('1R86YS<&]R="!W:71H(&$@<V5N
M9&UA:6P@:6YT97)F86-E+"!Y;W4*("`@8V%N(&-O;F9I9W5R92!(;W)D92!T
M;R!S<&5A:R!D:7)E8W1L>2!W:71H(&$@<F5M;W1E(%--5%`@<V5R=F5R+"!B
M=70@=&AI<PH@("!M87D@:6YC=7(@82!P97)F;W)M86YC92!P96YA;'1Y+@H*
M"DEN<W1A;&QI;F<@2&]R9&4*/3T]/3T]/3T]/3T]/3T]/0H*2&]R9&4@:7,@
M=W)I='1E;B!I;B!02%`L(&%N9"!M=7-T(&)E(&EN<W1A;&QE9"!I;B!A('=E
M8BUA8V-E<W-I8FQE(&1I<F5C=&]R>2X*5&AE('!R96-I<V4@;&]C871I;VX@
M;V8@=&AI<R!D:7)E8W1O<GD@=VEL;"!D:69F97(@9G)O;2!S>7-T96T@=&\@
M<WES=&5M+B!)9@IY;W4@:&%V92!N;R!I9&5A('=H97)E('EO=2!S:&]U;&0@
M8F4@:6YS=&%L;&EN9R!(;W)D92P@:6YS=&%L;"!I="!D:7)E8W1L>0IU;F1E
M<B!T:&4@<F]O="!O9B!Y;W5R('=E8G-E<G9E<B=S(&1O8W5M96YT('1R964N
M"@H*26YS=&%L;&EN9R!F<F]M(%)E;&5A<V4@5&%R8F%L;',*?GY^?GY^?GY^
M?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GX*"E-I;F-E($AO<F1E(&ES('=R:71T
M96X@:6X@4$A0+"!T:&5R92!I<R!N;R!C;VUP:6QA=&EO;B!N96-E<W-A<GD[
M('-I;7!L>0IE>'!A;F0@=&AE(&1I<W1R:6)U=&EO;B!W:&5R92!Y;W4@=V%N
M="!I="!T;R!R97-I9&4@86YD(')E;F%M92!T:&4@<F]O=`ID:7)E8W1O<GD@
M;V8@=&AE(&1I<W1R:6)U=&EO;B!T;R!W:&%T979E<B!Y;W4@=VES:"!T;R!A
M<'!E87(@:6X@=&AE"E523"X@4&QE87-E(&YO=&4@=&AA="!T:&4@9&5F875L
M="!C;VYF:6=U<F%T:6]N(&5X<&5C=',@2&]R9&4@=&\@8F4@:6YS=&%L;&5D
M"FEN('1H92!D:7)E8W1O<GD@8&`O:&]R9&5@8"!T:&]U9V@N($9O<B!E>&%M
M<&QE+"!W:71H('1H92!!<&%C:&4@=V5B<V5R=F5R)W,*9&5F875L="!D;V-U
M;65N="!R;V]T(&]F(&!@+W5S<B]L;V-A;"]A<&%C:&4O:'1D;V-S8&`L('EO
M=2!W;W5L9"!T>7!E.CH*"B`@(&-D("]U<W(O;&]C86PO87!A8VAE+VAT9&]C
M<PH@("!T87(@>GAV9B`O<&%T:"]T;R]H;W)D92UX+GDN>BYT87(N9WH*("`@
M;78@:&]R9&4M>"YY+GH@:&]R9&4*"EEO=2!W;W5L9"!T:&5N(&9I;F0@2&]R
M9&4@870@=&AE(%523#HZ"@H@("!H='1P.B\O>6]U<BUS97)V97(O:&]R9&4O
M"@I3:VEP('1H92!N97AT('!A<F%G<F%P:"!I9B!Y;W4@:6YS=&%L;&5D($AO
M<F1E(&9R;VT@82!R96QE87-E('1A<F)A;&PN"@H*26YS=&%L;&EN9R!F<F]M
M($-64R!O<B!3;F%P:&]T<PI^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^
M?GY^"@I!="!T:&ES('!O:6YT+"!T:&4@2&]R9&4@9G)A;65W;W)K(&UO9'5L
M97,@;F5E9"!T;R!B92!C:&5C:V5D(&]U="!F<F]M($-64R!A;F0*:6YS=&%L
M;&5D+B!4:&ES(&UU<W0@8F4@9&]N92!A<R!R;V]T("AO<B!A;F]T:&5R('5S
M97(@=VET:"!S=69F:6-I96YT"F%D;6EN:7-T<F%T;W(@<')I=FEL961G97,I
M.CH*"B`@(&-D(&AO<F1E"B`@(&-V<R!C;R!F<F%M97=O<FL*("`@8V0@9G)A
M;65W;W)K"B`@('!H<"`M<2!I;G-T86QL+7!A8VMA9V5S+G!H<`H*1F]R(%=I
M;F1O=W,@<WES=&5M<R`M('5S92!T:&4@8&!I;G-T86QL+7!A8VMA9V5S+F)A
M=&!@(&9I;&4@:6YS=&5A9"X*1F]R($1E8FEA;B!S>7-T96US("T@=&AE(&-O
M;6UA;F0M;&EN92!02%`@:6YT97)P<F5T97(@;6EG:'0@8F4@8V%L;&5D(&!@
M<&AP-&!@"FEN<W1E860@;V8@8&!P:'!@8"X*"@I#;VYF:6=U<FEN9R!(;W)D
M90H]/3T]/3T]/3T]/3T]/3T]/0H*,2X@0V]N9FEG=7)I;F<@=&AE('=E8B!S
M97)V97(*"B`@($AO<F1E(')E<75I<F5S('1H92!F;VQL;W=I;F<@=V5B<V5R
M=F5R('-E='1I;F=S+B!%>&%M<&QE<R!S:&]W;B!A<F4@9F]R"B`@($%P86-H
M93L@;W1H97(@=V5B<V5R=F5R<R<@8V]N9FEG=7)A=&EO;G,@=VEL;"!D:69F
M97(N"@H@("!A+B!02%`@:6YT97)P<F5T871I;VX@9F]R(&9I;&5S(&UA=&-H
M:6YG(&!@*BYP:'!@8#HZ"@H@("`@("`@("!!9&14>7!E(&%P<&QI8V%T:6]N
M+W@M:'1T<&0M<&AP("YP:'`*"B`@("`@("XN($YO=&4Z.B!4:&4@86)O=F4@
M:6YS=')U8W1I;VYS(&UA>2!N;W0@=V]R:R!I9B!Y;W4@:&%V92!S<&5C:69I
M960@4$A0"B`@("`@("`@("`@("`@("!A<R!A;B!O=71P=70@9FEL=&5R('=I
M=&@@8&!3971/=71P=71&:6QT97)@8"!D:7)E8W1I=F4@:6X*("`@("`@("`@
M("`@("`@($%P86-H92`R+G@@=F5R<VEO;G,N("!);B!P87)T:6-U;&%R+"!2
M960@2&%T(#@N,"!A;F0@86)O=F4*("`@("`@("`@("`@("`@($%P86-H92`R
M+G@@4E!-4R!H879E('1H92!O=71P=70@9FEL=&5R('-E="P@86YD("HJ3553
M5"!.3U0J*@H@("`@("`@("`@("`@("`@:&%V92!T:&4@86)O=F4@8&!!9&14
M>7!E8&`@9&ER96-T:79E(&%D9&5D+@H*("`@8BX@8&!I;F1E>"YP:'!@8"!A
M<R!A;B!I;F1E>"!F:6QE("AB<F]U9VAT('5P('=H96X@82!U<V5R(')E<75E
M<W1S(&$@55),(&9O<@H@("`@("!A(&1I<F5C=&]R>2DZ.@H*("`@("`@("`@
M1&ER96-T;W)Y26YD97@@:6YD97@N<&AP"@HR+B!#<F5A=&EN9R!D871A8F%S
M97,*"B`@(%1H92!S<&5C:69I8R!S=&5P<R!T;R!C<F5A=&4@82!P<F5F97)E
M;F-E<R!S=&]R86=E(&-O;G1A:6YE<B!D97!E;F0@;VX*("`@=VAI8V@@9&%T
M86)A<V4@>6]U)W9E(&-H;W-E;B!T;R!U<V4N"@H@("!&:7)S="P@;&]O:R!I
M;B!@8'-C<FEP=',O<W%L+V!@('1O('-E92!I9B!A(&!@8W)E871E+F!@('-C
M<FEP="!A;')E861Y"B`@(&5X:7-T<R!F;W(@>6]U<B!D871A8F%S92X@($EF
M('-O+"!Y;W4@<VAO=6QD(&)E(&%B;&4@=&\@<VEM<&QY(&5X96-U=&4@=&AA
M=`H@("!S8W)I<'0@87,@<W5P97)U<V5R(&EN('EO=7(@9&%T86)A<V4N("!#
M;VYS=6QT('1H92!@8'-C<FEP=',O<W%L+U)%041-16!@"B`@(&9I;&4@9F]R
M(&UO<F4@:6YF;W)M871I;VXN"@H@("!"92!S=7)E('1O(&-H86YG92!T:&4@
M9&5F875L="!P87-S=V]R9"P@8&!H;W)D96!@+"!T;R!S;VUE=&AI;F<@96QS
M92!B969O<F4*("`@8W)E871I;F<@=&AE('1A8FQE<R$@*%)E;65M8F5R('1O
M('5S92!T:&ES('!A<W-W;W)D('=H96X@>6]U(&-O;F9I9W5R90H@("!(;W)D
M92!I;B!T:&4@;F5X="!S=&5P+BD*"B`@($EF('-U8V@@82!S8W)I<'0@9&]E
M<R!N;W0@97AI<W0L('EO=2=L;"!N965D('1O(&)U:6QD('EO=7(@;W=N+"!U
M<VEN9R!T:&4*("`@9FEL97,@8&!H;W)D95]U<V5R<RYS<6Q@8"P@8&!H;W)D
M95]P<F5F<RYS<6Q@8"P@86YD(&!@:&]R9&5?9&%T871R964N<W%L8&`*("`@
M87,@82!S=&%R=&EN9R!P;VEN="X@($EF('EO=2!N965D(&%S<VES=&%N8V4@
M:6X@8W)E871I;F<@9&%T86)A<V5S(&9O<B!A"B`@(&1A=&%B87-E(&9O<B!W
M:&EC:"!N;R!@8&-R96%T92Y@8"!S8W)I<'0@97AI<W1S+"!Y;W4@;6%Y('=I
M<V@@=&\@;&5T('5S"B`@(&MN;W<@;VX@=&AE(&!(;W)D92!M86EL:6YG(&QI
M<W1@7RX*"B`@($EF('EO=2!A<F4@9V]I;F<@=&\@=7-E(&1A=&%B87-E(&)A
M<V5D('-E<W-I;VYS+"!C<F5A=&4@82!T86)L92!U<VEN9R!T:&4*("`@9FEL
M97,@8&!S8W)I<'1S+W-Q;"]H;W)D95]S97-S:6]N:&%N9&QE<BHN<W%L8&`@
M87,@82!S=&%R=&EN9R!P;VEN="X*"B`@("XN(%]@2&]R9&4@;6%I;&EN9R!L
M:7-T8#H@:&]R9&5`;&ES=',N:&]R9&4N;W)G"@HS+B!#;VYF:6=U<FEN9R!(
M;W)D90H*("`@5&\@8V]N9FEG=7)E($AO<F1E+"!C:&%N9V4@=&\@=&AE(&!@
M8V]N9FEG+V!@(&1I<F5C=&]R>2!O9B!T:&4@:6YS=&%L;&5D"B`@(&1I<W1R
M:6)U=&EO;BP@86YD(&UA:V4@8V]P:65S(&]F(&%L;"!O9B!T:&4@8V]N9FEG
M=7)A=&EO;B!@8"YD:7-T8&`@9FEL97,*("`@=VET:&]U="!T:&4@8&`N9&ES
M=&!@('-U9F9I>#HZ"@H@("`@("!C9"!C;VYF:6<O"B`@("`@(&9O<B!F(&EN
M("HN9&ES=#L@9&\@8W`@)&8@8&)A<V5N86UE("1F("YD:7-T8#L@9&]N90H*
M("`@3W(@:68@>6]U(&%R92!I;G-T86QL:6YG($AO<F1E(&%N(&$@5VEN9&]W
M<R!S>7-T96TZ.@H*("`@("`@8V0@8V]N9FEG"B`@("`@(&-O<'D@*BYD:7-T
M("HN"@H@("`N+B!.;W1E.CH@66]U(&]N;'D@;F5E9"!T:&4@8&!H;V]K<RYP
M:'!@8"!F:6QE(&EF('EO=2!W86YT('1O(&-R96%T92!C=7-T;VT*("`@("`@
M("`@("`@(&AO;VMS(&9O<B!S;VUE(&]F($AO<F1E)W,@9F5A='5R97,@86YD
M(&1E9F%U;'0@=F%L=65S+B!"97-I9&4*("`@("`@("`@("`@('1H870L('1H
M:7,@9FEL92!O;FQY(&-O;G1A:6YS(&5X86UP;&5S('1H870@>6]U('-H;W5L
M9"!N;W0@=7-E(&%S"B`@("`@("`@("`@("!T:&5Y(&%R92X@268@>6]U(&1O
M;B=T(&YE960@:&]O:W,@:70G<R!A(&=O;V0@:61E82!T;R!R96UO=F4@=&AI
M<PH@("`@("`@("`@("`@9FEL92!N;W<Z.@H*("`@("`@("`@("`@("`@("`@
M(')M(&AO;VMS+G!H<`H*("`@1&]C=6UE;G1A=&EO;B!O;B!T:&4@9F]R;6%T
M(&]F('1H;W-E(&9I;&5S(&-A;B!B92!F;W5N9"!I;B!E86-H(&9I;&4N"@H@
M("`N+B!787)N:6YG.CH@06QL(&-O;F9I9W5R871I;VX@9FEL97,@:6X@2&]R
M9&4@87)E(%!(4"!S8W)I<'1S('1H870@87)E"B`@("`@("`@("`@("`@("!E
M>&5C=71E9"!B>2!T:&4@=V5B('-E<G9E<BX@268@>6]U(&UA:V4@86X@97)R
M;W(@:6X@;VYE(&]F"B`@("`@("`@("`@("`@("!T:&5S92!F:6QE<RP@2&]R
M9&4@;6EG:'0@<W1O<"!W;W)K:6YG+B!4:'5S(&ET(&ES(&%L=V%Y<R!A"B`@
M("`@("`@("`@("`@("!G;V]D(&ED96$@=&\@=&5S="!T:&4@8V]N9FEG=7)A
M=&EO;B!F:6QE<R!A9G1E<B!Y;W4@961I=&5D"B`@("`@("`@("`@("`@("!T
M:&5M+B!)9B!Y;W4@=V%N="!T;R!T97-T(&UI;65?9')I=F5R<RYP:'`@9F]R
M(&5X86UP;&4@<G5N.CH*"B`@("`@("`@("`@("`@("`@("!P:'`@+6P@;6EM
M95]D<FEV97)S+G!H<`H*-"X@5&5S=&EN9R!(;W)D90H*("`@3VYC92!Y;W4@
M:&%V92!C;VYF:6=U<F5D('EO=7(@=V5B<V5R=F5R+"!02%`L(&%N9"!(;W)D
M92P@8G)I;F<@=7`@=&AE"B`@(&EN8VQU9&5D('1E<W0@<&%G92!I;B!Y;W5R
M(%=E8B!B<F]W<V5R('1O(&5N<W5R92!T:&%T(&%L;"!N96-E<W-A<GD*("`@
M<')E<F5Q=6ES:71E<R!H879E(&)E96X@;65T+B!)9B!Y;W4@:6YS=&%L;&5D
M($AO<F1E(&%S(&1E<V-R:6)E9"!A8F]V92P@=&AE"B`@(%523"!T;R!T:&4@
M=&5S="!P86=E('=O=6QD(&)E.CH*"B`@("`@(&AT='`Z+R]Y;W5R+7-E<G9E
M<B]H;W)D92]T97-T+G!H<`H*("`@0VAE8VL@=&AA="!Y;W5R(%!(4"!A;F0@
M4$5!4B!V97)S:6]N<R!A<F4@86-C97!T86)L>2!R96-E;G0L('1H870@86QL
M"B`@(')E<75I<F5D(&UO9'5L92!C87!A8FEL:71I97,@87)E('!R97-E;G0L
M(&%N9"!T:&%T(&!@;6%G:6-?<75O=&5S7W)U;G1I;65@8`H@("!I<R!S970@
M=&\@8&!/9F9@8"X@5&AE;B!N;W1E('1H92!@8%-E<W-I;VX@8V]U;G1E<CH@
M,6!@(&QI;F4@=6YD97(@8&!02%`*("`@4V5S<VEO;G-@8"P@86YD(')E;&]A
M9"!T:&4@<&%G92X@5&AE('-E<W-I;VX@8V]U;G1E<B!S:&]U;&0@:6YC<F5M
M96YT+@H*("`@268@>6]U(&=E="!A('=A<FYI;F<@;&EK92!@8$9A:6QE9"!O
M<&5N:6YG("<O<&%T:"]T;R]T97-T+G!H<"<@9F]R"B`@(&EN8VQU<VEO;F!@
M+"!M86ME('-U<F4@=&AA="!T:&4@=V5B('-E<G9E<B!H87,@=&AE('!E<FUI
M<W-I;VX@=&\@<F5A9"!T:&4*("`@8&!T97-T+G!H<&!@(&9I;&4N"@HU+B!#
M;VUP;&5T:6YG($-O;F9I9W5R871I;VX*"B`@(%EO=2!C86X@;F]W(&%C8V5S
M<R!(;W)D92!W:71H;W5T(&$@<&%S<W=O<F0L(&%N9"!Y;W4@=VEL;"!B92!L
M;V=G960@:6X@87,*("`@86X@861M:6YI<W1R871O<BX@66]U('-H;W5L9"!F
M:7)S="!C;VYF:6=U<F4@82!R96%L(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0N
M"B`@($-L:6-K(&]N(&!@4V5T=7!@8"!I;B!T:&4@8&!!9&UI;FES=')A=&EO
M;F!@(&UE;G4@86YD(&-O;F9I9W5R90H@("!(;W)D92X@(%-T87)T(&EN('1H
M92!@8$%U=&AE;G1I8V%T:6]N8&`@=&%B+@H*("`@2&5R92!I<R!A;B!E>&%M
M<&QE(&9O<B!C;VYF:6=U<FEN9R!A=71H96YT:6-A=&EO;B!A9V%I;G-T(&$@
M<F5M;W1E($E-05`*("`@<V5R=F5R+B`@4VEM:6QA<B!S=&5P<R!A<'!L>2!F
M;W(@875T:&5N=&EC871I;F<@86=A:6YS="!A(&1A=&%B87-E+"!A;B!,1$%0
M"B`@('-E<G9E<BP@971C+@H*("`@82X@26X@=&AE(&!@5VAI8V@@=7-E<G,@
M<VAO=6QD(&)E('1R96%T960@87,@861M:6YI<W1R871O<G-@8"!F:65L9"!E
M;G1E<B!A"B`@("`@(&-O;6UA('-E<&%R871E9"!L:7-T(&]F('5S97(@;F%M
M97,@;V8@>6]U<B!C:&]O<VEN9RX@5&AI<R!W:6QL(&-O;G1R;VP*("`@("`@
M=VAO(&ES(&%L;&]W960@=&\@;6%K92!C;VYF:6=U<F%T:6]N(&-H86YG97,L
M('-E92!P87-S=V]R9',L('!O=&5N=&EA;&QY"B`@("`@(&%D9"!U<V5R<RP@
M971C+@H*("`@8BX@26X@=&AE(&!@5VAA="!B86-K96YD('-H;W5L9"!W92!U
M<V4@9F]R(&%U=&AE;G1I8V%T:6YG('5S97)S('1O($AO<F1E8&`*("`@("`@
M<'5L;&1O=VX@;65N=2!S96QE8W0@8&!)34%0(&%U=&AE;G1I8V%T:6]N8&`N
M(%1H92!P86=E('=I;&P@<F5L;V%D(&%N9`H@("`@("!Y;W4@=VEL;"!H879E
M('-P96-I9FEC(&]P=&EO;G,@9F]R($E-05`@875T:&5N=&EC871I;VXN"@H@
M("!C+B!);B!T:&4@8&!#;VYF:6=U<F%T:6]N('1Y<&5@8"!P=6QL9&]W;B!M
M96YU('-E;&5C="!@8%-E<&%R871E('9A;'5E<V!@+@H@("`@("!4:&4@<&%G
M92!W:6QL(')E;&]A9"!W:71H(&%D9&ET:6]N86P@;W!T:6]N<RX@1FEL;"!I
M;B!T:&4@<F5M86EN:6YG"B`@("`@('1H<F5E(&9I96QD<R!A<'!R;W!R:6%T
M96QY.@H*("`@("`@+2!)4"!N86UE+VYU;6)E<B!O9B!T:&4@24U!4"!S97)V
M97(*("`@("`@+2!&;W(@82!S96-U<F4@8V]N;F5C=&EO;BP@<V5L96-T('!O
M<G0@.3DS+@H@("`@("`M(%-E;&5C="!T:&4@<')O=&]C;VP[(&9O<B!A('-E
M8W5R92!C;VYN96-T:6]N(&5I=&AE<B!@8&EM87`O<W-L8&`@;W(*("`@("`@
M("!@8&EM87`O<W-L+VYO=F%L:61A=&4M8V5R=&!@("AF;W(@<V5L9BUS:6=N
M960@8V5R=&EF:6-A=&5S*2X*"B`@($-O;G1I;G5E('1O(&-O;F9I9W5R92!(
M;W)D92!T:')O=6=H(&%L;"!T:&4@=&%B<R!O9B!T:&4@<V5T=7`@:6YT97)F
M86-E(&%N9`H@("!C;&EC:R!O;B!@8$=E;F5R871E($AO<F1E($-O;F9I9W5R
M871I;VY@8"X@26UP;W)T86YT(&ET96US('1H870@>6]U"B`@('!R;V)A8FQY
M('=A;G0@=&\@8V]N9FEG=7)E(&%R92!T:&4@8&!0<F5F97)E;F-E(%-Y<W1E
M;6!@('1H870@;&5T<R!U<V5R<PH@("!S879E('1H96ER('!E<G-O;F%L(&]P
M=&EO;G,L(&%N9"!T:&4@8&!$871A5')E92!3>7-T96U@8"!T:&%T(&ES(')E
M<75I<F5D"B`@(&9O<B!S;VUE(&%P<&QI8V%T:6]N<R!T;R!W;W)K(&%T(&%L
M;"X*"B`@($-O;F9I9W5R871I;VX@;V8@87!P;&EC871I;VYS(&EN(&!@<F5G
M:7-T<GDN<&AP8&`@:7,@9&]C=6UE;G1E9"!I;B!T:&4*("`@8&!)3E-404Q,
M8&`@9FEL92!O9B!E86-H(&%P<&QI8V%T:6]N+B`@36]S="!A<'!L:6-A=&EO
M;G,@<F5Q=6ER92!Y;W4@=&\*("`@8V]N9FEG=7)E('1H96T@=VET:"!A(")(
M;W)D92!A9&UI;FES=')A=&]R(B!A8V-O=6YT+B`@02!(;W)D92!A9&UI;FES
M=')A=&]R"B`@(&%C8V]U;G0@:7,@86YY(&YO<FUA;"!(;W)D92!A8V-O=6YT
M('1H870@:&%S(&)E96X@861D960@=&\@=&AE"B`@(&%D;6EN:7-T<F%T;W(@
M;&ES="!I;B!T:&4@8&!!=71H96YT:6-A=&EO;F!@('1A8B!O9B!T:&4@2&]R
M9&4@<V5T=7`N"@H@("!4:&4@;W1H97(@9FEL97,@:6X@=&AA="!D:7)E8W1O
M<GD@;F5E9"!O;FQY(&)E(&UO9&EF:65D(&EF('EO=2!W:7-H('1O"B`@(&-U
M<W1O;6EZ92!(;W)D92=S(&%P<&5A<F%N8V4@;W(@8F5H879I;W5R("TM('1H
M92!D969A=6QT<R!W:6QL('=O<FL@870@;6]S=`H@("!S:71E<RX*"C8N(%-E
M8W5R:6YG($AO<F1E"@H@("!A+B!087-S=V]R9',*"B`@("`@(%-O;64@;V8@
M2&]R9&4G<R!C;VYF:6=U<F%T:6]N(&9I;&5S(&-O;G1A:6X@<&%S<W=O<F1S
M('=H:6-H(&QO8V%L('5S97)S"B`@("`@(&-O=6QD('5S92!T;R!A8V-E<W,@
M>6]U<B!D871A8F%S92X@($ET(&ES(')E8V]M;65N9&5D('1O(&5N<W5R92!T
M:&%T(&%T"B`@("`@(&QE87-T('1H92!(;W)D92!C;VYF:6=U<F%T:6]N(&9I
M;&5S("AI;B!@8&-O;F9I9R]@8"D@87)E(&YO="!R96%D86)L92!T;PH@("`@
M("!S>7-T96T@=7-E<G,N("!4:&5R92!A<F4@8&`N:'1A8V-E<W-@8"!F:6QE
M<R!R97-T<FEC=&EN9R!A8V-E<W,@=&\*("`@("`@9&ER96-T;W)I97,@=&AA
M="!D;R!N;W0@;F5E9"!T;R!B92!A8V-E<W-E9"!D:7)E8W1L>3L@8F5F;W)E
M(')E;'EI;F<@;VX*("`@("`@=&AO<V4L(&5N<W5R92!T:&%T('EO=7(@=V5B
M<V5R=F5R('-U<'!O<G1S(&!@+FAT86-C97-S8&`@86YD(&ES"B`@("`@(&-O
M;F9I9W5R960@=&\@=7-E('1H96TL(&%N9"!T:&%T('1H92!F:6QE<R!I;B!T
M:&]S92!D:7)E8W1O<FEE<R!A<F4@:6X*("`@("`@9F%C="!I;F%C8V5S<VEB
M;&4@=FEA('1H92!B<F]W<V5R+@H*("`@("`@06X@861D:71I;VYA;"!A<'!R
M;V%C:"!I<R!T;R!M86ME($AO<F1E)W,@8V]N9FEG=7)A=&EO;B!F:6QE<R!O
M=VYE9"!B>0H@("`@("!T:&4@=7-E<B!@8')O;W1@8"!A;F0@8GD@82!G<F]U
M<"!W:&EC:"!O;FQY('1H92!W96)S97)V97(@=7-E<B!B96QO;F=S"B`@("`@
M('1O+"!A;F0@=&AE;B!M86MI;F<@=&AE;2!R96%D86)L92!O;FQY('1O(&]W
M;F5R(&%N9"!G<F]U<"X@($9O<B!E>&%M<&QE+`H@("`@("!I9B!Y;W5R('=E
M8G-E<G9E<B!R=6YS(&%S(&!@=W=W+G=W=V!@+"!D;R!A<R!F;VQL;W=S.CH*
M"B`@("`@("`@(&-H;W=N(')O;W0N=W=W(&-O;F9I9R\J"B`@("`@("`@(&-H
M;6]D(#`T-#`@8V]N9FEG+RH*"B`@(&(N(%-E<W-I;VYS"@H@("`@("!397-S
M:6]N(&1A=&$@+2T@:6YC;'5D:6YG(&AA<VAE9"!V97)S:6]N<R!O9B!Y;W5R
M('5S97)S)R!P87-S=V]R9',L(&EN"B`@("`@('-O;64@87!P;&EC871I;VYS
M("TM(&UA>2!N;W0@8F4@<W1O<F5D(&%S('-E8W5R96QY(&%S(&YE8V5S<V%R
M>2X*"B`@("`@($EF('EO=2!A<F4@=7-I;F<@9FEL92UB87-E9"!02%`@<V5S
M<VEO;G,@*'=H:6-H(&%R92!T:&4@9&5F875L="DL(&)E"B`@("`@('-U<F4@
M=&AA="!S97-S:6]N(&9I;&5S(&%R92!N;W0@8F5I;F<@=W)I='1E;B!I;G1O
M(&!@+W1M<&!@('=I=&@*("`@("`@<&5R;6ES<VEO;G,@=&AA="!A;&QO=R!O
M=&AE<B!U<V5R<R!T;R!R96%D('1H96TN($ED96%L;'DL(&-H86YG92!T:&4*
M("`@("`@8&!S97-S:6]N+G-A=F5?<&%T:&!@('-E='1I;F<@:6X@8&!P:'`N
M:6YI8&`@=&\@82!D:7)E8W1O<GD@;VYL>0H@("`@("!R96%D86)L92!A;F0@
M=W)I=&5A8FQE(&)Y('EO=7(@=V5B<V5R=F5R+@H*("`@("`@061D:71I;VYA
M;&QY+"!Y;W4@8V%N(&-H86YG92!T:&4@<V5S<VEO;B!H86YD;&5R(&]F(%!(
M4"!T;R!U<V4@86YY"B`@("`@('-T;W)A9V4@8F%C:V5N9"!R97%U97-T960@
M*&4N9RX@4U%,(&1A=&%B87-E*2!V:6$@=&AE(&!@0W5S=&]M(%-E<W-I;VX*
M("`@("`@2&%N9&QE<F!@('1A8B!I;B!T:&4@2&]R9&4@<V5T=7`N"@H@("!&
M;W(@;6]R92!I;F9O<FUA=&EO;B!A8F]U="!S96-U<FEN9R!Y;W5R('=E8G-E
M<G9E<BP@4$A0(&%N9"!(;W)D92P@<V5E('1H90H@("!@9&]C<R]314-54DE4
M66!?(&9I;&4N"@HW+B!%;G1E<FEN9R!T:&4@<W5R=F5Y"@H@("!)9B!Y;W4@
M;&EK92P@9V\@=&\@:'1T<#HO+W=W=RYH;W)D92YO<F<O<W5R=F5Y+R!A;F0@
M96YT97(@=&AE(&1E=&%I;',@;V8*("`@>6]U<B!S>7-T96TN"@H*0V]N9FEG
M=7)I;F<@07!P;&EC871I;VYS"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*
M02!L:7-T(&]F(&%V86EL86)L92!(;W)D92!A<'!L:6-A=&EO;G,@8V%N(&)E
M(&9O=6YD(&%T"@H@("!H='1P.B\O=W=W+FAO<F1E+F]R9R]P<F]J96-T<RYP
M:'`*"DEN<W1R=6-T:6]N<R!O;B!C;VYF:6=U<FEN9R!(;W)D92!A<'!L:6-A
M=&EO;G,@8V%N(&)E(&9O=6YD(&EN('1H92!@8$E.4U1!3$Q@8`IF:6QE(&EN
M('1H92!A<'!L:6-A=&EO;B=S(&!@9&]C<R]@8"!D:7)E8W1O<GDN"@H*5&5M
M<&]R87)Y($9I;&5S"CT]/3T]/3T]/3T]/3T]/0H*5F%R:6]U<R!(;W)D92!A
M<'!L:6-A=&EO;G,@=VEL;"!G96YE<F%T92!T96UP;W)A<GD@9FEL97,@:6X@
M4$A0)W,@=&5M<&]R87)Y"F1I<F5C=&]R>2`H<V5E('1H92!@8$=E;F5R86Q@
M8"!T86(@:6X@=&AE($AO<F1E('-E='5P*2X@($9O<B!V87)I;W5S(')E87-O
M;G,L"G-O;64@;V8@=&AE<V4@9FEL97,@;6%Y(&YO="!B92!R96UO=F5D('=H
M96X@=&AE('5S97(G<R!S97-S:6]N(&5N9',N(%1O"G)E8VQA:6T@=&AI<R!D
M:7-K('-P86-E+"!I="!M87D@8F4@;F5C97-S87)Y('1O('!E<FEO9&EC86QL
M>2!D96QE=&4@=&AE<V4@;VQD"G1E;7!O<F%R>2!F:6QE<RX*"D%N(&5X86UP
M;&4@8W)O;BUB87-E9"!S;VQU=&EO;B!C86X@8F4@9F]U;F0@870@8&!S8W)I
M<'1S+W1E;7`M8VQE86YU<"YC<F]N8&`N"D%N;W1H97(@<&]S<VEB;&4@<V]L
M=71I;VX@:7,@=&\@=7-E(%)E9"!(870G<R!@8'1M<'=A=&-H8&`@=71I;&ET
M>2!O<B!A;GET:&EN9PIS:6UI;&%R('1O(')E;6]V92!O;&0@9FEL97,@*'-E
M92!H='1P.B\O=W=W+G)E9&AA="YC;VTO*2X*"@I4<F%N<VQA=&EO;G,*/3T]
M/3T]/3T]/3T]"@I.;W1E(&9O<B!I;G1E<FYA=&EO;F%L('5S97)S.B!(;W)D
M92!U<V5S($=.52!G971T97AT('1O('!R;W9I9&4@;&]C86P*=')A;G-L871I
M;VYS(&]F('1E>'0@9&ES<&QA>65D(&)Y(&%P<&QI8V%T:6]N<SL@=&AE('1R
M86YS;&%T:6]N<R!A<F4@9F]U;F0@:6X*=&AE('!O+R!D:7)E8W1O<GDN("!)
M9B!A('1R86YS;&%T:6]N(&ES(&YO="!Y970@879A:6QA8FQE(&9O<B!Y;W5R
M(&QO8V%L92`H86YD"GEO=2!W:7-H('1O(&-R96%T92!O;F4I+"!S964@=&AE
M(&!@:&]R9&4O<&\O4D5!1$U%8&`@9FEL92P@;W(@:68@>6]U)W)E(&AA=FEN
M9PIT<F]U8FQE('5S:6YG(&$@<')O=FED960@=')A;G-L871I;VXL('!L96%S
M92!S964@=&AE"F!H;W)D92]D;V-S+U1204Y33$%424].4V!?(&9I;&4@9F]R
M(&EN<W1R=6-T:6]N<RX*"@I/8G1A:6YI;F<@4W5P<&]R=`H]/3T]/3T]/3T]
M/3T]/3T]/0H*268@>6]U(&5N8V]U;G1E<B!P<F]B;&5M<R!W:71H($AO<F1E
M+"!H96QP(&ES(&%V86EL86)L92$*"E1H92!(;W)D92!&<F5Q=65N=&QY($%S
M:V5D(%%U97-T:6]N<R!,:7-T("A&05$I+"!A=F%I;&%B;&4@;VX@=&AE(%=E
M8B!A=`H*("!H='1P.B\O=W=W+FAO<F1E+F]R9R]F87$O"@I4:&4@2&]R9&4@
M4')O:F5C="!R=6YS(&$@;G5M8F5R(&]F(&UA:6QI;F<@;&ES=',L(&9O<B!I
M;F1I=FED=6%L(&%P<&QI8V%T:6]N<PIA;F0@9F]R(&ES<W5E<R!R96QA=&EN
M9R!T;R!T:&4@<')O:F5C="!A<R!A('=H;VQE+B!);F9O<FUA=&EO;BP@87)C
M:&EV97,L(&%N9`IS=6)S8W)I<'1I;VX@:6YF;W)M871I;VX@8V%N(&)E(&9O
M=6YD(&%T"@H@(&AT='`Z+R]W=W<N:&]R9&4N;W)G+VUA:6PO"@I&:6YA;&QY
M+"!(;W)D92!D979E;&]P97)S+"!C;VYT<FEB=71O<G,@86YD('5S97)S(&%L
M<V\@;6%K92!O8V-A<VEO;F%L"F%P<&5A<F%N8V5S(&]N($E20RP@;VX@=&AE
M(&-H86YN96P@(VAO<F1E(&]N('1H92!F<F5E;F]D92!.971W;W)K"BAI<F,N
M9G)E96YO9&4N;F5T*2X*"E!L96%S92!K965P(&EN(&UI;F0@=&AA="!(;W)D
M92!I<R!F<F5E('-O9G1W87)E('=R:71T96X@8GD@=F]L=6YT965R<RX*1F]R
M(&EN9F]R;6%T:6]N(&]N(')E87-O;F%B;&4@<W5P<&]R="!E>'!E8W1A=&EO
M;G,L('!L96%S92!R96%D"@H@(&AT='`Z+R]W=W<N:&]R9&4N;W)G+W-U<'!O
M<G0N<&AP"@I4:&%N:W,@9F]R('5S:6YG($AO<F1E(0H*5&AE($AO<F1E(%1E
M86T*"@HN+B!?4D5!1$U%.B`_9CU214%$344N:'1M;`HN+B!?9&]C<R](04-+
M24Y'.B`_9CU(04-+24Y'+FAT;6P*+BX@7V1O8W,O4T5#55))5%DZ(#]F/5-%
M0U522519+FAT;6P*+BX@7V!H;W)D92]D;V-S+U1204Y33$%424].4V`Z(#]F
M/51204Y33$%424].4RYH=&UL"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]D;V-S
M+U!%4D9/4DU!3D-%````````````````````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,34Q,S(@,3`U,34T,S,W,S0@,#(P,34V`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T*($AO<F1E(%!E<F9O<FUA;F-E($=U:61E"CT]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T*"CI,87-T('5P9&%T93H@("`D1&%T93H@
M,C`P-B\P-2\S,2`Q.3HQ-#HQ-"`D"CI2979I<VEO;CH@("`@("`D4F5V:7-I
M;VXZ(#$N.2XQ,"XQ,R`D"CI#;VYT86-T.B`@("`@("!H;W)D94!L:7-T<RYH
M;W)D92YO<F<*"BXN(&-O;G1E;G1S.CH@0V]N=&5N=',*"@I3;VUE('1I<',@
M;VX@<&5R9F]R;6%N8V4@='5N:6YG('-Y<W1E;7,@9F]R($AO<F1E+B`@5&AI
M<R!D;V5S(&YO="!C;W9E<@IH87)D=V%R92!T=6YI;F<@;W(@979E;B!L;W<@
M;&5V96P@<WES=&5M("AN971W;W)K+"!F:6QE<WES=&5M+"!E=&,I('1U;FEN
M9RX*"D1O;B=T(&%P<&QY('1H92!F;VQL;W=I;F<@='5N:6YG(&AI;G1S(&)L
M:6YD;'DN("!497-T('EO=7(@87!P;&EC871I;VYS(&)E9F]R90IA;F0@869T
M97(@=&AE(&-H86YG97,@=6YD97(@=&AE(&-O;F1I=&EO;G,@=&AA="!A<F4@
M:6UP;W)T86YT(&9O<B!Y;W4N("!&;W(*<V]M92!P96]P;&4@:70G<R!M;W)E
M(&EM<&]R=&%N="!T;R!M86ME('1H96T@87,@9F%S="!A<R!P;W-S:6)L92!F
M;W(@82!S;6%L;`IU<V5R(&)A<V4L(&]T:&5R<R!R97%U:7)E('1H92!A<'!L
M:6-A=&EO;G,@=&\@<V-A;&4@=V5L;"!U;F1E<B!A(&AI9V@@;&]A9"X*4V]M
M92!O9B!T:&5S92!H:6YT<R!M:6=H="!E=F5N(&UA:V4@=&AE(&%P<&QI8V%T
M:6]N<R!S;&]W97(@=6YD97(@8V5R=&%I;@IC;VYD:71I;VYS(&]R('5S:6YG
M(&$@8V5R=&%I;B!H87)D=V%R92X*"@I,:6YU>"!4=6YI;F<*/3T]/3T]/3T]
M/3T]"@HJ(%)E8V]M<&EL92!24$U3(&9O<B!Y;W5R(&%R8VAI=&5C='5R92`H
M92YG+B!I-3@V+"!I-C@V+"!A=&AL;VXL(&5T8RDN"B`@5&AI<R!A<'!L:65S
M(&UO<W0@=&\@>6]U<B!!<&%C:&4L(%!(4"P@24U!4"P@86YD(%!/4#,@<&%C
M:V%G97,N"@H*07!A8VAE+U!(4"!T=6YI;F<*/3T]/3T]/3T]/3T]/3T]/3T*
M"BH@0V]N<VED97(@82!02%`@86-C96QE<F%T;W(@<')O9W)A;2X@(%-E92!F
M;W(@97AA;7!L92!@5&AE(%IE;F0@4&5R9F]R;6%N8V4*("!3=6ET96!?+"!4
M:&4@8&EO;D-U8F4@4$A0($%C8V5L97)A=&]R8%\L(&!4=7)C:R!-34-A8VAE
M(&9O<B!02%!@7RP@;W(*("!E06-C96QE<F%T;W)?+B`@5&AE<V4@86-C96QE
M<F%T;W)S('-P965D('5P(&%C8V5S<R!B>2!C86-H:6YG('1H92!C;VUP:6QE
M9`H@(%!(4"!C;V1E+"!E;&EM:6YA=&EN9R!T:&4@;F5E9"!T;R!R96-O;7!I
M;&4@=&AE(&-O9&4@9F]R(&5V97)Y('-I;F=L92!P86=E"B`@;&]A9"X@("HJ
M5&AI<R!I<R!P<F]B86)L>2!T:&4@96%S:65S="!W87D@=&\@:6UP<F]V92!T
M:&4@<&5R9F]R;6%N8V4@;V8*("!(;W)D92HJ+B`@268@=7-I;F<@5'5R8VL@
M34U#86-H92P@*BI03$5!4T4J*B!R96%D(&!4=7)C:R!-34-A8VAE"B`@5')O
M=6)L97-H;V]T:6YG8%\N"@HJ($-O;7!I;&4@4$A0('=I=&@@=&AE(&!@+2UE
M;F%B;&4M:6YL:6YE+6]P=&EM:7IA=&EO;F!@(&]P=&EO;B!T;R!G96YE<F%T
M92!T:&4*("!F87-T97-T('!O<W-I8FQE(%!(4"!E>&5C=71A8FQE+@H**B!5
M<V4@;V8@=&AE(&UC<GEP="!02%`@97AT96YS:6]N('-H;W5L9"!S:6=N:69I
M8V%N=&QY(&EN8W)E87-E('!E<F9O<FUA;F-E"B`@=VAI;&4@86QS;R!I;F-R
M96%S:6YG('-E8W5R:71Y+@H**B!%;F%B;&4@4$A0(&]U='!U="!C;VUP<F5S
M<VEO;B`H96ET:&5R(&EN(&!@<&AP+FEN:6!@(&]R"B`@8&!H;W)D92]C;VYF
M:6<O8V]N9BYP:'!@8"DN"@HJ($1I<V%B;&4@=&AE(&UE;6]R>2!L:6UI="!I
M;B!@8'!H<"YI;FE@8"X*"BH@2V5E<"!T:&4@:6YC;'5D92!P871H(&1E9FEN
M960@:6X@8&!P:'`N:6YI8&`@87,@<VAO<G0@87,@<&]S<VEB;&4L('=I=&@@
M=&AE"B`@;6]S="!F<F5Q=65N=&QY('5S960@;&EB<F%R>2!P871H<R!F:7)S
M="X@(%EO=2!D;VXG="!N965D('1O(&EN8VQU9&4@=&AE"B`@;&]C86P@9&ER
M96-T;W)Y(&!@+F!@(&)E8V%U<V4@2&]R9&4@86QW87ES('5S97,@9G5L;"!P
M871H<R!I;G-T96%D(&]F"B`@<F5L871I=F4@<&%T:',N"@HJ(%5S92!A;B!O
M<'1I;6EZ960@8&!P:'`N:6YI8&`L('-T87)T(&9R;VT@8&!P:'`N:6YI+7)E
M8V]M;65N9&5D8&`@;V8@>6]U<B!02%`*("!D<VET<FEB=71I;VXN"@HJ($1O
M;B=T(')U;B!02%`@<V5S<VEO;B!G87)B86=E(&-O;&QE8W1I;VX@=&]O(&]F
M=&5N(&EF('5S:6YG(&$@<VQO=R!S=&]R86=E"B`@;65D:75M("AL:6ME(%-1
M3"DN("A3964@8&!S97-S:6]N+F=C7W!R;V)A8FEL:71Y8&`@:6X@8&!P:'`N
M:6YI8&`I"@HJ($EF('EO=2!H879E(&$@;&%R9V4@;G5M8F5R(&]F('-E<W-I
M;VYS+"!C;VYS:61E<B!S=&]R:6YG('1H96T@:6X@:&%S:&5D"B`@9&ER96-T
M;W)Y(&QE=F5L<RX@*%-E92!@8'-E<W-I;VXN<V%V95]P871H8&`@870@:'1T
M<#HO+W=W=RYP:'`N;F5T+W-E<W-I;VXI"@HJ($-O;G-I9&5R('5S:6YG(&$@
M9F%S=&5R('-T;W)A9V4@;65D:75M(&9O<B!S97-S:6]N<RP@<W5C:"!A<R!A
M('1M<&9S(&]R"B`@;W1H97(@;65M;W)Y(&)A<V5D(&9I;&4@<WES=&5M+B`@
M268@>6]U(&%R92!S=7)E('EO=7(@87!A8VAE('-E='5P(&ES(')O8VL*("!S
M;VQI9"!A;F0@>6]U(&1O;B=T(')E<W1A<G0@:70@=&AE<F4@:7,@82!M;2!S
M97-S:6]N(&1R:79E<BX@($AO=V5V97(L(&)E"B`@87=A<F4@=&AA="!C97)T
M86EN($AO<F1E(&%P<&QI8V%T:6]N<R`H;&EK92!)35`I(&UA:V4@:&5A=GD@
M=7-E(&]F(&-A8VAI;F<*("!D871A(&EN('-E<W-I;VYS('-O(&UE;6]R>2!B
M87-E9"!S;VQU=&EO;G,@;6%Y(&)E(&5X:&%U<W1E9"!Q=6EC:VQY+`H@('!A
M<G1I8W5L87)L>2!I9B!T:&5R92!W:6QL(&)E(&UO<F4@=&AA;B!A('-I;F=L
M92!U<V5R+@H**B!/;FQY(&QO860@87,@;6%N>2!!<&%C:&4@86YD(%!(4"!E
M>'1E;G-I;VYS(&%S(&YE961E9"`H=&\@<F5D=6-E(&UE;6]R>0H@('5S86=E
M*2X*"BH@57-E('-T871I8V%L;'D@8V]M<&EL960@07!A8VAE(&UO9'5L97,L
M(&EN8VQU9&EN9R!T:&4@4$A0(&UO9'5L92X*"BH@57-E(&-O;7!I;&5R(&]P
M=&EM:7IA=&EO;G,@*"TM<')E9F5R+6YO;BUP:6,L("U/,RP@+6UA<F-H("UM
M8W!U+"`M;7-S92P*("`M;6UM>"P@+6UF<&UA=&@]<W-E+"!E=&,N*0H**B!)
M9B!U<VEN9R!34TP@=VET:"!A(&QA<F=E('-I=&4L(&-O;G-I9&5R(&$@:&%R
M9'=A<F4@4U-,(&%C8V5L97)A=&]R+@H**B!5<V4@<VAA<F5D(&UE;6]R>2!F
M;W(@=&AE($%P86-H92!34TP@8V%C:&4@:68@<&]S<VEB;&4N"@HJ(%1O(&EM
M<')O=F4@8V%C:&EN9R!O9B!S=&%T:6,@8V]N=&5N="!I9B!A8V-E<W-I;F<@
M07!A8VAE(%-33"!W:71H($EN=&5R;F5T"B`@17AP;&]R97(L('1R>2!S971T
M:6YG(&QO;F=E<B!E>'!I<F%T:6]N('!E<FEO9',Z.@H*("`@($5X<&ER97-!
M8W1I=F4@3VX*("`@($5X<&ER97-">51Y<&4@:6UA9V4O<&YG(")N;W<@<&QU
M<R`Q(&UO;G1H(@H@("`@17AP:7)E<T)Y5'EP92!I;6%G92]G:68@(FYO=R!P
M;'5S(#$@;6]N=&@B"B`@("!%>'!I<F5S0GE4>7!E('1E>'0O:F%V87-C<FEP
M="`B;F]W('!L=7,@,2!M;VYT:"(*("`@($5X<&ER97-">51Y<&4@87!P;&EC
M871I;VXO>"UJ879A<V-R:7!T(")N;W<@<&QU<R`Q(&UO;G1H(@H@("`@17AP
M:7)E<T)Y5'EP92!T97AT+V-S<R`B;F]W('!L=7,@,2!M;VYT:"(*"B`@+BX@
M3F]T93HZ(%EO=2!M=7-T(&-O;7!I;&4@=&AE(&!@;6]D7V5X<&ER97-@8"!E
M>'1E;G-I;VX@:6YT;R!!<&%C:&4@:6X*("`@("`@("`@("`@;W)D97(@=&\@
M=7-E('1H97-E(&1I<F5C=&EV97,N"@H@("XN(%=A<FYI;F<Z.B!4:&ES(&UI
M9VAT(&-A=7-E('!R;V)L96US(&EF('EO=2!U<&=R861E($AO<F1E(&%N9"!T
M:&4@=7-E<G,G"B`@("`@("`@("`@("`@(&)R;W=S97)S('-T:6QL('5S92!T
M:&4@;VQD(&9I;&4@=F5R<VEO;G,N"@HJ($1I<V%B;&4@1$Y3(&QO;VMU<',@
M:6X@>6]U<B!!<&%C:&4@;&]G9VEN9RP@;W(@=7-E(&$@8V%C:&EN9R!$3E,@
M<V5R=F5R(&]N"B`@=&AE('=E8B!S97)V97(@:&]S="X*"BH@16YA8FQE($%P
M86-H92!K965P86QI=F5S+@H*+BX@7V!4:&4@6F5N9"!097)F;W)M86YC92!3
M=6ET96`Z(&AT='`Z+R]W=W<N>F5N9"YC;VTO:&]R9&4N<&AP"BXN(%]@:6]N
M0W5B92!02%`@06-C96QE<F%T;W)@.B!H='1P.B\O=W=W+G!H<"UA8V-E;&5R
M871O<BYC;RYU:PHN+B!?8%1U<F-K($U-0V%C:&4@9F]R(%!(4&`Z(&AT='`Z
M+R]T=7)C:RUM;6-A8VAE+G-O=7)C969O<F=E+FYE=`HN+B!?94%C8V5L97)A
M=&]R.B!H='1P.B\O96%C8V5L97)A=&]R+FYE=`HN+B!?8%1U<F-K($U-0V%C
M:&4@5')O=6)L97-H;V]T:6YG8#H@:'1T<#HO+W=I:VDN:&]R9&4N;W)G+U1U
M<F-K34U#86-H951R;W5B;&5S:&]O=&EN9PH*"E-E;F1I;F<@36%I;`H]/3T]
M/3T]/3T]/3T*"BH@1V5N97)A;&QY('5S:6YG(&$@;&]C86P@<V5N9&UA:6P@
M8V]M;6%N9"!T;R!S96YD(&UA:6P@=VEL;"!R97-U;'0@:6X@8F5T=&5R"B`@
M<&5F;W)M86YC92!T:&%N('5S:6YG(&$@4TU44"!C;VYN96-T:6]N+@H**B!3
M;VUE($U402!S97)V97)S(&UA>2!B92!F87-T97(@;W(@;6]R92!E9F9I8VEE
M;G0@=&AA;B!O=&AE<G,N("!#;VYS:61E<@H@('-W:71C:&EN9R!T;R!A(&9A
M<W1E<B!F;W)M870@:68@;F5E9&5D+@H*"DE-05`@='5N:6YG"CT]/3T]/3T]
M/3T]"@HJ($-O;G-I9&5R(&%N($E-05`@<')O>'D@9F]R(&UO<F4@<&5R<VES
M=&5N="!C;VYN96-T:6]N<RX@(%-O;64@24U!4"!P<F]X:65S"B`@87)E('5P
M+6EM87!P<F]X>5\@86YD(%!E<F1I=&EO;E\N("!4;R!M86ME('-E;G-E+"!T
M:&4@<')O>'D*("!S:&]U;&0@8F4@:6YS=&%L;&5D(&]N('1H92!S97)V97(@
M<G5N;FEN9R!(;W)D92P@86YD('1H:7,@<V5R=F5R(&YE961S"B`@96YO=6=H
M($-052!P;W=E<B!T;R!H86YD;&4@=&AE(&%D9&ET:6]N86P@;&]A9"X*"BH@
M4V]M92!)34%0('-E<G9E<G,@*&]R($E-05`@;6%I;&)O>"!S=&]R92!F;W)M
M871S*2!P97)F;W)M(&)E='1E<B!T:&%N"B`@;W1H97)S+B`@0V]N<VED97(@
M<W=I=&-H:6YG('1O(&$@9F%S=&5R(&9O<FUA="!I9B!N965D960N"@HJ($9O
M;&QO=R!T:&4@24U!4"!S97)V97)S)R!P97)F;W)M86YC92!H:6YT<SH*"B`@
M+2!#>7)U<SH@:'1T<#HO+V%S9RYW96(N8VUU+F5D=2]C>7)U<R]D;W=N;&]A
M9"]I;6%P9"]I;G-T86QL+7!E<F8N:'1M;`H*+BX@7W5P+6EM87!P<F]X>3H@
M:'1T<#HO+W=W=RYI;6%P<')O>'DN;W)G+PHN+B!?4&5R9&ET:6]N.B!H='1P
M.B\O=W=W+G9E<F=E;F5T+FYE="]L:6YU>"]P97)D:71I;VXO"@H*4&]S=&=R
M97-Q;"!T=6YI;F<*/3T]/3T]/3T]/3T]/3T]/3T*"BH@1&\@82!V86-U=6T@
M8V]M;6%N9"!P97)I;V1I8V%L;'D@=&\@='5N92!Y;W5R(&1A=&%B87-E"@HJ
M($EN8W)E87-E(&!@<VAA<F5D7V)U9F9E<G-@8"!A;F0@8&!S;W)T7VUE;6!@
M(&UE;6]R>2!S971T:6YG<RX*"BH@268@=V5B('-E<G9E<B!A;F0@9&%T86)A
M<V4@:7,@;VX@=&AE('-A;64@=6YI>"!H;W-T+"!U<V4@=6YI>"!S;V-K971S
M"B`@:6YS=&5A9"!O9B!N971W;W)K(&-O;FYE8W1I;VYS(&9O<B!D871A8F%S
M92!A8V-E<W,N"@H*37E344P@='5N:6YG"CT]/3T]/3T]/3T]/0H**B!)9B!W
M96(@<V5R=F5R(&%N9"!D871A8F%S92!I<R!O;B!T:&4@<V%M92!U;FEX(&AO
M<W0L('5S92!U;FEX('-O8VME=',*("!I;G-T96%D(&]F(&YE='=O<FL@8V]N
M;F5C=&EO;G,@9F]R(&1A=&%B87-E(&%C8V5S<RX*"BH@16YA8FQE(&UY<W%L
M('%U97)Y(&-A8VAE(&EF('EO=2!H879E('-U9F9I8VEE;G0@4D%-+B`@161I
M="!Y;W5R(&!@;7DN8VYF8&`*("!F:6QE(&%N9"!A9&0@=&AE(&9O;&QO=VEN
M9R!T;R!T:&4@8&!;;7ES<6QD76!@('-E8W1I;VX@*&-H86YG92!T:&4@;65M
M;W)Y"B`@<VEZ92!T;R!M965T('EO=7(@;F5E9',I.CH*"B`@("!S970M=F%R
M:6%B;&4@/2!Q=65R>5]C86-H95]S:7IE/3$R.$T*"@I(;W)D92!T=6YI;F<*
M/3T]/3T]/3T]/3T]"@HJ(%EO=2!C86X@8V]N9FEG=7)E($AO<F1E('1O('-E
M<G9E(&%L;"!I;6%G97,@86YD('-T>6QE('-H965T<R!F<F]M(&$*("!D:69F
M97)E;G0@<V5R=F5R+B!4:&ES(&-O=6QD(&)E(&$@=F5R>2!L:6=H='=E:6=H
M="!S97)V97(@=VET:&]U="!A;&P@=&AE"B`@;W9E<FAE860@9F]R('!R;V-E
M<W-I;F<@4$A0(&9I;&5S+"!L:6ME(&QI9VAT='!D+B!9;W4@;F5E9"!T;R!S
M970@=&AE"B`@8&!T:&5M97-U<FE@8"!P87)A;65T97(@:6X@8&!C;VYF:6<O
M<F5G:7-T<GDN<&AP8&`@9F]R(&%L;"!A<'!L:6-A=&EO;G,@86YD"B`@8V]P
M>2!A;&P@8&!T:&5M97-@8"!D:7)E8W1O<FEE<R!I;B!T:&4@<V%M92!D:7)E
M8W1O<GD@;&%Y;W5T('1O('1H92!O=&AE<@H@('-E<G9E<BX*"BXN(%]L:6=H
M='1P9#H@:'1T<#HO+W=W=RYL:6=H='1P9"YN970O"@H*07!P;&EC871I;VX@
M='5N:6YG"CT]/3T]/3T]/3T]/3T]/3T]/0H**B!3;VUE(&%P<&QI8V%T:6]N
M<R!C;VYT86EN(&%D=F%N8V5D(&9E871U<F5S('1H870@;6EG:'0@:&%V92!A
M(&-E<G1A:6X@:6UP86-T"B`@;VX@=&AE('!E<F9O<FUA;F-E+B`@5&AE<V4@
M9F5A='5R97,@8V%N('5S=6%L;'D@8F4@='5R;F5D(&]F9B!I;B!T:&4*("!A
M<'!L:6-A=&EO;B=S(&-O;F9I9W5R871I;VX@86YD(&%R92!E>'!L:6-I=&QY
M(&1E<V-R:6)E9"!A<R!B96EN9R!A"B`@<&5R9F]R;6%N8V4@:&ET(&EN('1H
M92!C;VYF:6=U<F%T:6]N('=E8B!F<F]N=&5N9"X*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]D;V-S+U-%0U522519````````
M````````````````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,C0T
M-#8@,3`U,34T,S,W,S0@,#$W-C<T`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*($AO
M<F1E(%-E8W5R:71Y($YO=&5S"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"CI,
M87-T('5P9&%T93H@("`D1&%T93H@,C`P-"\P.2\R-B`R,SHS,SHP-R`D"CI2
M979I<VEO;CH@("`@("`D4F5V:7-I;VXZ(#$N.2`D"CI#;VYT86-T.B`@("`@
M("!H;W)D94!L:7-T<RYH;W)D92YO<F<*"BXN(&-O;G1E;G1S.CH@0V]N=&5N
M=',*+BX@<V5C=&EO;BUN=6UB97)I;F<Z.@H*"E1E;7!O<F%R>2!F:6QE<PH]
M/3T]/3T]/3T]/3T]/3T*"DAO<F1E(&%P<&QI8V%T:6]N<R!M86ME(&5X=&5N
M<VEV92!U<V4@;V8@=&5M<&]R87)Y(&9I;&5S+B`@26X@;W)D97(@=&\@;6%K
M90IS=7)E('1H97-E(&9I;&5S(&%R92!S96-U<F4L('EO=2!S:&]U;&0@;6%K
M92!S=7)E('EO=7(@:6YS=&%L;&%T:6]N(&UE971S('1H90IF;VQL;W=I;F<@
M8W)I=&5R:6$N"@I3:71E<R!M87D@9V%I;B!I;F-R96%S960@<V5C=7)I='D@
M8GD@9&5F:6YI;F<@82!T96UP;W)A<GD@9&ER96-T;W)Y(&EN('1H90I(;W)D
M92!C;VYF:6=U<F%T:6]N('=H:6-H(&ES('=R:71A8FQE(&)Y('1H92!W96(@
M<V5R=F5R+"!B=70@;F]T('=R:71A8FQE(&)Y"F]T:&5R('5S97)S+B`@4VEN
M8V4@=&AE('1E;7!O<F%R>2!F:6QE<R!M87D@8V]N=&%I;B!S96YS:71I=F4@
M:6YF;W)M871I;VX@:70*:7,@8F5S="!T;R!A;'-O(&UA:V4@=&AE<V4@9FEL
M92!U;G)E861A8FQE(&)Y(&]T:&5R('5S97)S+B`@5&AA="!I<RP@=&AE>2!C
M86X*8F4@;6%D92!R96%D86)L92!A;F0@=W)I=&%B;&4@;VYL>2!B>2!T:&4@
M=V5B('-E<G9E<B!U<V5R+@H*"E!(4"!397-S:6]N<PH]/3T]/3T]/3T]/3T*
M"D9O<B!T:&4@;6]S="!S96-U<FET>2P@>6]U('-H;W5L9"!E;F%B;&4@4$A0
M('-E<W-I;VX@8V]O:VEE<R!B>2!E;F%B;&EN9R!T:&4*<&AP('-E='1I;F<@
M8&!S97-S:6]N+G5S95]C;V]K:65S8&`N("!7:&5N(&1O:6YG('-O+"!B92!S
M=7)E('1O('-E="!A;@IA<'!R;W!R:6%T92!@8'-E<W-I;VXN8V]O:VEE7W!A
M=&A@8"!A;F0@8&!S97-S:6]N+F-O;VMI95]D;VUA:6Y@8"!A;'-O('1O"G-E
M8W5R92!Y;W5R(&-O;VMI97,N"@I)9B!02%`@<V5S<VEO;G,@87)E('-E="!T
M;R!U<V4@=&AE(&!@9FEL97-@8"!S879E7VAA;F1L97(L('1H96X@=&AE<V4@
M9FEL97,*<VAO=6QD(&)E('-E8W5R960@<')O<&5R;'DN("!3:71E<R!C86X@
M:6YC<F5A<V4@<V5C=7)I='D@8GD@<V5T=&EN9R!T:&4@<&AP"G-E='1I;F<@
M8&!S97-S:6]N+G-A=F5?<&%T:&!@('1O(&$@9&ER96-T;W)Y('1H870@:7,@
M;VYL>2!R96%D86)L92!A;F0*=W)I=&%B;&4@8GD@=&AE('=E8B!S97)V97(@
M<')O8V5S<RX*"E-I=&5S('=I=&@@82!L87)G92!U<V5R(&)A<V4@<VAO=6QD
M(&-O;G-I9&5R('-E='1I;F<@=&AE"F!@<V5S<VEO;BYE;G1R;W!Y7V9I;&5@
M8"!A;F0@8&!S97-S:6]N+F5N=')O<'E?;&5N9W1H8&`@=&\@87!P<F]P<FEA
M=&4@=F%L=65S+@H*2&]R9&4@=VEL;"!E;F-R>7!T('1H92!U<V5R(&-R961E
M;G1I86QS(&)E9F]R92!S=&]R:6YG('1H96T@:6X@=&AE('-E<W-I;VXN"DAO
M=V5V97(L('1H:7,@96YC<GEP=&EO;B!C86X@8F4@:6UP<F]V960@:68@>6]U
M(&AA=F4@86YD(&5N86)L92!T:&4@<&AP"F5X=&5N<VEO;B`B;6-R>7!T(B!W
M:&EC:"!A;&QO=W,@9F]R('-T<F]N9V5R(&5N8W)Y<'1I;VX@=&AA;B!I<R!O
M=&AE<G=I<V4*<')O=FED960@8GD@2&]R9&4N"@H*1&5F875L="!D871A8F%S
M92!P87-S=V]R9',*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"E1H92!(
M;W)D92!D;V-U;65N=&%T:6]N(&%N9"!S86UP;&4@9&%T86)A<V4@8W)E871I
M;VX@<V-R:7!T<R!C<F5A=&4@82!D969A=6QT"G5S97(@86YD('!A<W-W;W)D
M(&9O<B!A8V-E<W-I;F<@=&AE(&AO<F1E(&1A=&%B87-E+B`@57-I;F<@=&AI
M<R!P87-S=V]R9"!I;B!A"G!R;V1U8W1I;VX@96YV:7)O;FUE;G0@:7,@82!S
M96-U<FET>2!H;VQE+"!S:6YC92!A;B!A='1A8VME<B!W:6QL(&5A<VEL>2!G
M=65S<PII="X*"DET(&ES('9E<GD@:6UP;W)T86YT('1H870@<VET97,@8VAA
M;F=E(&%T(&QE87-T('1H92!P87-S=V]R9"!T;R!S;VUE=&AI;F<*<V5C=7)E
M+@H*"E!R979E;G0@8V]N9FEG=7)A=&EO;B!F:6QE(')E861I;F<@86YD('=R
M:71I;F<@"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T*"E1H92!C;VYF:6=U<F%T:6]N(&9I;&5S(&UA>2!C;VYT86EN
M('-E;G-I=&EV92!D871A("AS=6-H(&%S(&1A=&%B87-E"G!A<W-W;W)D<RD@
M=&AA="!S:&]U;&0@;F]T(&)E(')E860@;W(@=W)I='1E;B!B>2!L;V-A;"!S
M>7-T96T@=7-E<G,@;W(@<F5M;W1E"G=E8B!U<V5R<RX*"DEF('EO=2!U<V4@
M82!5;FEX('-Y<W1E;2P@;VYE('=A>2!T;R!M86ME('1H92!C;VYF:6=U<F%T
M:6]N(&9I;&5S(&%N9`ID:7)E8W1O<FEE<R!A8V-E<W-I8FQE(&]N;'D@=&\@
M=&AE('=E8B!S97)V97(@:7,@87,@9F]L;&]W<RX@($AE<F4@=V4@87-S=6UE
M"G1H870@=&AE('=E8B!S97)V97(@<G5N<R!A<R!T:&4@=7-E<B!@8&%P86-H
M96!@(&%N9"!T:&4@9FEL97,@87)E(&QO8V%T960@:6X*8&`O:&]M92]H='1P
M9"]H=&UL8&`@+2T@<W5B<W1I='5T92!T:&4@8V]R<F5C="!U<V5R(&]R(&9I
M;&4@<&%T:"!I9B!N965D960Z.@H*)"!C:&]W;B`M4B!A<&%C:&4@+VAO;64O
M:'1T<&0O:'1M;"]H;W)D92]C;VYF:6<*)"!C:&]W;B`M4B!A<&%C:&4@+VAO
M;64O:'1T<&0O:'1M;"]H;W)D92\J+V-O;F9I9PHD(&-H;6]D("U2(&=O+7)W
M>"`O:&]M92]H='1P9"]H=&UL+VAO<F1E+V-O;F9I9PHD(&-H;6]D("U2(&=O
M+7)W>"`O:&]M92]H='1P9"]H=&UL+VAO<F1E+RHO8V]N9FEG"@I&;W(@8V]M
M<&QE=&5L>2!F87-C:7-T('!E<FUI<W-I;VYS+"!Y;W4@8V%N(&UA:V4@=&AE
M(&5N=&ER92!(;W)D92!T<F5E"FEN86-C97-S:6)L92!B>2!A;GEO;F4@97AC
M97!T('1H92!W96(@<V5R=F5R('5S97(@*&%N9"!R;V]T*3HZ"@HD(&-H;W=N
M("U2(&%P86-H92`O:&]M92]H='1P9"]H=&UL+VAO<F1E"B0@8VAM;V0@+5(@
M9V\M<G=X("`O:&]M92]H='1P9"]H=&UL+VAO<F1E"B0@8VAM;V0@+5(@82UW
M("`@+VAO;64O:'1T<&0O:'1M;"]H;W)D92\*"DYO=&4@=&AA="!T:&4@;&%S
M="!L:6YE(&UA:V5S(&%L;"!F:6QE<R!U;G=R:71A8FQE(&)Y(&%N>2!U<V5R
M("AO;FQY(')O;W0@8V%N"F]V97)R:61E('1H:7,I+B`@5&AI<R!M86ME<R!T
M:&4@<VET92!S96-U<F4L(&)U="!M87D@;6%K92!I="!M;W)E(&1I9F9I8W5L
M="!T;PIA9&UI;FES=')A=&4N("!);B!P87)T:6-U;&%R+"!I="!W:6QL(&1E
M9F5A="!T:&4@2&]R9&4@861M:6YI<W1R871I=F4*8V]N9FEG=7)A=&EO;B!I
M;G1E<F9A8V4L(&9O<F-I;F<@>6]U('1O('5P9&%T92!T:&4@2&]R9&4@8V]N
M9FEG=7)A=&EO;B!F:6QE<PIM86YU86QL>2`H87,@<&5R('1H92!)3E-404Q,
M7R!I;G-T<G5C=&EO;G,I+@H*5&AE(&%B;W9E('=I;&P@;F]T('-E8W5R92!T
M:&4@9FEL97,@:68@;W1H97(@=7-E<B=S(&]N('1H92!S86UE(&UA8VAI;F4@
M8V%N"G)U;B!S8W)I<'1S(&%S('1H92!A<&%C:&4@=7-E<BX@($EF('EO=2!N
M965D('1O('!R;W1E8W0@86=A:6YS="!T:&ES('EO=0IS:&]U;&0@;6%K92!O
M=&AE<B!U<V5R)W,@<V-R:7!T<R!R=6X@=6YD97(@=&AE:7(@;W=N(&%C8V]U
M;G0@=VET:"!S;VUE"F9A8VEL:71Y('-U8V@@87,@87!A8VAE)W,@<W5E>&5C
M(&UO9'5L92X@(%EO=2!N965D('1O('=A=&-H(&]U="!N;W0@;VYL>2!F;W(*
M8V=I('-C<FEP=',L(&)U="!A;'-O(&9O<B!O=&AE<B!M;V1U;&5S(&QI:V4@
M;6]D7W!H<"P@;6]D7W!E<FPL(&UO9%]P>71H;VXL"F5T8RX@=&AA="!M87D@
M8F4@:6X@=7-E(&]N('EO=7(@<V5R=F5R+@H*+BX@7TE.4U1!3$PZ(#]F/4E.
M4U1!3$PN:'1M;`H*"E)E<W1R:6-T:6YG('1E<W0N<&AP(&9I;&5S"CT]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]"@I4:&4@8&!T97-T+G!H<&!@(&9I;&5S
M('!R;W9I9&4@82!W96%L=&@@;V8@:6YF;W)M871I;VX@=&AA="!C86X@8F4@
M=7-E9`IA9V%I;G-T('1H92!S:71E(&)Y(&%T=&%C:V5R<RX@($]N92!Y;W4@
M:&%V92!C;VYF:7)M960@=&AA="!E=F5R>71H:6YG(&ES"G=O<FMI;F<L('EO
M=2!S:&]U;&0@9&ES86)L92!A8V-E<W,@=&\@=&AE('1E<W0N<&AP(&9I;&5S
M+B`@66]U(&-A;B!D;R!T:&ES('9I80IT:&4@=V5B('-E<G9E<BP@;W(@=FEA
M('-Y<W1E;2!F:6QE('!E<FUI<W-I;VYS+B`@3VX@82!U;FEX('-Y<W1E;2P@
M>6]U(&UI9VAT"FES<W5E(&$@8V]M;6%N9"!S=6-H(&%S.CH*"B0@8VAM;V0@
M82UR=W@@+VAO;64O:'1T<&0O:'1M;"]H;W)D92]T97-T+G!H<`HD(&-H;6]D
M(&$M<G=X("]H;VUE+VAT='!D+VAT;6PO:&]R9&4O*B]T97-T+G!H<`H*"E!R
M979E;G1I;F<@07!A8VAE(&9R;VT@<V5R=FEN9R!C;VYF:6=U<F%T:6]N(&%N
M9"!S;W5R8V4@9FEL97,*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"E1H92!(;W)D92!C
M;VYF:6=U<F%T:6]N(&9I;&5S(&UA>2!C;VYT86EN('-E;G-I=&EV92!D871A
M("AS=6-H(&%S(&1A=&%B87-E"G!A<W-W;W)D<RD@=&AA="!S:&]U;&0@;F]T
M(&)E('-E<G9E9"!B>2!T:&4@=V5B('-E<G9E<BX@3W1H97(@9&ER96-T;W)I
M97,*8V]N=&%I;B!02%`@<V]U<F-E(&-O9&4@=&AA="!I<VXG="!I;G1E;F1E
M9"!F;W(@=FEE=VEN9R!B>2!E;F0M=7-E<G,N(%1H90I(;W)D92!G<F]U<"!H
M87,@<')O=FED960@8&`N:'1A8V-E<W-@8"!F:6QE<R!I;B!V87)I;W5S(&1I
M<F5C=&]R:65S('1O(&AE;'`*<')O=&5C="!T:&5S92!F:6QE<RX@($AO=V5V
M97(L('1H870@9&5P96YD<R!O;B!Y;W5R('=E8B!S97)V97(@:&]N;W)I;F<*
M8&`N:'1A8V5S<V!@(&9I;&5S("AW:&EC:"!I<R!A('!E<F9O<FUA;F-E(&AI
M="P@86YD(&UA>2!N;W0@8F4@879A:6QA8FQE(&EN"F%L;"!W96(@<V5R=F5R
M<RDN"@I!;B!!<&%C:&4@<VET92!C86X@86QS;R!P<F5V96YT('1H92!W96(@
M<V5R=F5R(&9R;VT@<V5R=FEN9R!T:&5S90IF:6QE<R!B>2!A9&1I;F<@<V5C
M=&EO;G,@=&\@8&!H='1P9"YC;VYF8&`@<W5C:"!A<R!T:&4@9F]L;&]W:6YG
M.CH*"B`@(#Q$:7)E8W1O<GD@(B]H;VUE+VAT='!D+VAT;6PO:&]R9&4O8V]N
M9FEG(CX*("`@("`@(&]R9&5R(&1E;GDL86QL;W<*("`@("`@(&1E;GD@9G)O
M;2!A;&P*("`@/"]$:7)E8W1O<GD^"B`@(#Q$:7)E8W1O<GD@(B]H;VUE+VAT
M='!D+VAT;6PO:&]R9&4O;&EB(CX*("`@("`@(&]R9&5R(&1E;GDL86QL;W<*
M("`@("`@(&1E;GD@9G)O;2!A;&P*("`@/"]$:7)E8W1O<GD^"B`@(#Q$:7)E
M8W1O<GD@(B]H;VUE+VAT='!D+VAT;6PO:&]R9&4O;&]C86QE(CX*("`@("`@
M(&]R9&5R(&1E;GDL86QL;W<*("`@("`@(&1E;GD@9G)O;2!A;&P*("`@/"]$
M:7)E8W1O<GD^"B`@(#Q$:7)E8W1O<GD@(B]H;VUE+VAT='!D+VAT;6PO:&]R
M9&4O<&\B/@H@("`@("`@;W)D97(@9&5N>2QA;&QO=PH@("`@("`@9&5N>2!F
M<F]M(&%L;`H@("`\+T1I<F5C=&]R>3X*("`@/$1I<F5C=&]R>2`B+VAO;64O
M:'1T<&0O:'1M;"]H;W)D92]S8W)I<'1S(CX*("`@("`@(&]R9&5R(&1E;GDL
M86QL;W<*("`@("`@(&1E;GD@9G)O;2!A;&P*("`@/"]$:7)E8W1O<GD^"B`@
M(#Q$:7)E8W1O<GD@(B]H;VUE+VAT='!D+VAT;6PO:&]R9&4O=&5M<&QA=&5S
M(CX*("`@("`@(&]R9&5R(&1E;GDL86QL;W<*("`@("`@(&1E;GD@9G)O;2!A
M;&P*("`@/"]$:7)E8W1O<GD^"@I297!E870@=&AI<R!P871T97)N(&9O<B!E
M86-H($AO<F1E(&%P<&QI8V%T:6]N+B`@1F]R(&5X86UP;&4L(&9O<B!)35`@
M>6]U"G=O=6QD('1H96X@861D.CH*"B`@(#Q$:7)E8W1O<GD@(B]H;VUE+VAT
M='!D+VAT;6PO:&]R9&4O:6UP+V-O;F9I9R(^"B`@("`@("!O<F1E<B!D96YY
M+&%L;&]W"B`@("`@("!D96YY(&9R;VT@86QL"B`@(#PO1&ER96-T;W)Y/@H@
M("`\1&ER96-T;W)Y("(O:&]M92]H='1P9"]H=&UL+VAO<F1E+VEM<"]L:6(B
M/@H@("`@("`@;W)D97(@9&5N>2QA;&QO=PH@("`@("`@9&5N>2!F<F]M(&%L
M;`H@("`\+T1I<F5C=&]R>3X*("`@/$1I<F5C=&]R>2`B+VAO;64O:'1T<&0O
M:'1M;"]H;W)D92]I;7`O;&]C86QE(CX*("`@("`@(&]R9&5R(&1E;GDL86QL
M;W<*("`@("`@(&1E;GD@9G)O;2!A;&P*("`@/"]$:7)E8W1O<GD^"B`@(#Q$
M:7)E8W1O<GD@(B]H;VUE+VAT='!D+VAT;6PO:&]R9&4O:6UP+W!O(CX*("`@
M("`@(&]R9&5R(&1E;GDL86QL;W<*("`@("`@(&1E;GD@9G)O;2!A;&P*("`@
M/"]$:7)E8W1O<GD^"B`@(#Q$:7)E8W1O<GD@(B]H;VUE+VAT='!D+VAT;6PO
M:&]R9&4O:6UP+W-C<FEP=',B/@H@("`@("`@;W)D97(@9&5N>2QA;&QO=PH@
M("`@("`@9&5N>2!F<F]M(&%L;`H@("`\+T1I<F5C=&]R>3X*("`@/$1I<F5C
M=&]R>2`B+VAO;64O:'1T<&0O:'1M;"]H;W)D92]I;7`O=&5M<&QA=&5S(CX*
M("`@("`@(&]R9&5R(&1E;GDL86QL;W<*("`@("`@(&1E;GD@9G)O;2!A;&P*
M("`@/"]$:7)E8W1O<GD^"@H*4V5T=7`@<V-R:7!T<PH]/3T]/3T]/3T]/3T]
M"@I4:&5R92!A<F4@=F%R:6]U<R!S8W)I<'1S('5S92!T;R!S971U<"!O<B!C
M;VYF:6=U<F4@2&]R9&4N("!)9B!Y;W4@86QL;W<@;W1H97(*=7-E<G,@;VX@
M=&AE('=E8B!S97)V97(@;6%C:&EN92P@>6]U('-H;W5L9"!P<F]T96-T('1H
M97-E(&9I;&5S(&9R;VT@8F5I;F<*86-C97-S960@8GD@=&AE;2X@($]N(&$@
M=6YI>"!S>7-T96TL('EO=2!M:6=H="!R97-T<FEC="!T:&5S92!F:6QE<R!T
M;R!R;V]T"F%C8V5S<R!B>2!U<VEN9R!T:&4@9F]L;&]W:6YG('1Y<&4@;V8@
M8V]M;6%N9',Z.@H*)"!C:&]W;B`M4B!R;V]T("]H;VUE+VAT='!D+VAT;6PO
M:&]R9&4O<V-R:7!T<PHD(&-H;W=N("U2(')O;W0@+VAO;64O:'1T<&0O:'1M
M;"]H;W)D92\J+W-C<FEP=',*)"!C:&UO9"`M4B!G;RUR=W@@+VAO;64O:'1T
M<&0O:'1M;"]H;W)D92]S8W)I<'1S"B0@8VAM;V0@+5(@9V\M<G=X("]H;VUE
M+VAT='!D+VAT;6PO:&]R9&4O*B]S8W)I<'1S"@H*57-I;F<@82!C:')O;W0@
M=V5B('-E<G9E<B!S971U<`H]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]"@I5;FEX('5S97)S(&UA>2!W86YT('1O(&-O;G-I9&5R('5S:6YG(&$@
M8VAR;V]T(&5N=FER;VYM96YT(&9O<B!T:&5I<B!W96(*<V5R=F5R+B`@2&]W
M('1O(&1O('1H:7,@:7,@8F5Y;VYD('1H92!S8V]P92!O9B!T:&ES(&1O8W5M
M96YT+"!B=70@<W5F9FEC:65N=`II;F9O<FUA=&EO;B!E>&ES=',@;VX@=&AE
M('=O<FQD('=I9&4@=V5B(&%N9"]O<B!I;B!Y;W5R('-E<G9E<B!D;V-U;65N
M=&%T:6]N"G1O(&-O;7!L971E('1H:7,@=&%S:RX*"@I(:61I;F<@4$A0(&EN
M9F\@9G)O;2!T:&4@=7-E<@H]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/0H*66]U('-H;W5L9"!C;VYS:61E<B!S971T:6YG('1H92!F;VQL;W=I;F<@
M4$A0('9A<FEA8FQE<R!I;B!Y;W5R(&!@<&AP+FEN:6!@"F9I;&4@=&\@<')E
M=F5N="!I;F9O<FUA=&EO;B!L96%K('1O('1H92!U<V5R+"!O<B!G;&]B86P@
M:6YS97)T:6]N(&)Y('1H90IU<V5R.CH*"B`@(&5X<&]S95]P:'`@/2!/9F8*
M("`@9&ES<&QA>5]E<G)O<G,@/2!/9F8*("`@;&]G7V5R<F]R<R`]($]N"B`@
M(')E9VES=&5R7V=L;V)A;',@/2!/9F8*"EEO=2!S:&]U;&0@86QS;R!S970@
M=7`@97)R;W(@;&]G9VEN9R`H=7-I;F<@=&AE(%!(4"!@8&5R<F]R7VQO9V!@
M('9A<FEA8FQE*0IT;R!L;V<@=&\@82!F:6QE+"!S>7-L;V<L(&]R(&]T:&5R
M(&QO9R!D97-T:6YA=&EO;BX*"@I5<VEN9R!A('-E8W5R92!W96(@<V5R=F5R
M"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"DAO<F1E(&1E<&5N9',@;VX@
M<&%S<VEN9R!S96YS:71I=F4@:6YF;W)M871I;VX@*'-U8V@@87,@<&%S<W=O
M<F1S(&%N9"!S97-S:6]N"FEN9F]R;6%T:6]N*2!B971W965N('1H92!W96(@
M<V5R=F5R(&%N9"!T:&4@=V5B(&-L:65N="X@(%5S:6YG(&$@<V5C=7)E"BA3
M4TPM96YA8FQE9"D@=V5B('-E<G9E<B!W:6QL(&AE;'`@<')O=&5C="!T:&ES
M(&EN9F]R;6%T:6]N(&%S(&ET('1R879E<G-I;F<*=&AE(&YE='=O<FLN"@H*
M57-I;F<@82!S96-U<F4@4$]0,R])34%0('-E<G9E<@H]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]"@I)9B!Y;W4@87)E('5S:6YG(&$@4$]0,R])
M34%0('-E<G9E<B!W:71H($AO<F1E("AE+F<N(&9O<B!A=71H96YT:6-A=&EO
M;B!O<B!F;W(*24U0*2!T:&5N($AO<F1E(&ES('!A<W-I;F<@=&AE('5S97(G
M<R!L;V=I;B!C<F5D96YT:6%L<R!B971W965N('1H92!W96(@<V5R=F5R"F%N
M9"!T:&4@;6%I;"!S97)V97(N"@I)9B!Y;W5R('=E8B!S97)V97(@86YD($E-
M05`@<V5R=F5R(&%R92!O;B!T:&4@<V%M92!H;W-T+"!Y;W4@8V%N(&EN8W)E
M87-E"G-E8W5R:71Y(&)Y(&9O<F-I;F<@86QL('1R869F:6,@;W9E<B!T:&4@
M;&]O<&)A8VL@;W(@;&]C86QH;W-T(&EN=&5R9F%C92!S;PIT:&%T(&ET(&ES
M(&YO="!E>'!O<V5D('1O('EO=7(@;F5T=V]R:RX*"DEN(&-A<V5S('=H97)E
M('1H870@:7,@;F]T('!O<W-I8FQE+"!W92!R96-O;6UE;F0@=7-I;F<@82!S
M96-U<F4@;6%I;`IC;VYN96-T:6]N('-U8V@@87,@24U!4"U34TP@;W(@4$]0
M,RU34TP@=&\@96YS=7)E('1H870@<&%S<W=O<F1S(')E;6%I;B!S869E+@H*
M"DQ$05`@4V5C=7)I='D*/3T]/3T]/3T]/3T]/0H*3$1!4"!S96-U<FET>2!I
M<R!S:6UI;&%R('1O('1H92!A8F]V92!03U`S+TE-05`@<V5R=F5R('-E8W5R
M:71Y(&ES<W5E+B`@268@>6]U"F%R92!U<VEN9R!,1$%0+"!Y;W4@<VAO=6QD
M(&UA:V4@<W5R92!T:&%T('EO=2!A<F4@;F]T(&5X<&]S:6YG(&QD87`@<&%S
M<W=O<F1S"F]R(&%N>2!S96YS:71I=F4@9&%T82!I;B!Y;W5R($Q$05`@9&%T
M86)A<V4N"@H*1&%T86)A<V4@<V]C:V5T('-E8W5R:71Y"CT]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/0H*268@>6]U<B!D871A8F%S92`H92YG+B!->5-13"!O
M<B!0;W-T9W)E4U%,*2!I<R!O;B!T:&4@<V%M92!H;W-T(&%S('EO=7(@=V5B
M"G-E<G9E<BP@>6]U(&UA>2!U<V4@=6YI>"!S;V-K971S(')A=&AE<B!T:&%N
M('1C<"!C;VYN96-T:6]N<R!T;R!H96QP(&EM<')O=F4*>6]U<B!S96-U<FET
M>2`H86YD('!E<F9O<FUA;F-E*2X@($EF(&ET(&1O97-N)W0@<W5P<&]R="!U
M;FEX('-O8VME=',L('EO=2!C86X*86-H:65V92!S;VUE(&)E='1E<B!S96-U
M<FET>2!B>2!R97-T<FEC=&EN9R!T:&4@=&-P('-U<'!O<G0@=&\@=&AE(&QO
M;W!B86-K(&]R"FQO8V%L:&]S="!I;G1E<F9A8V4N"@I)9B!T:&4@9&%T86)A
M<V4@:V5E<',@:71S('-O8VME="!F:6QE("AE+F<N(&!@;7ES<6PN<V]C:V!@
M*2!I;B!A(&1I<F5C=&]R>0IL:6ME(&!@+W1M<&!@(&]R(&!@+W9A<B]T;7!@
M8"P@>6]U('-H;W5L9"!S970@<&5R;6ES<VEO;G,@8V%R969U;&QY('1O(&5N
M<W5R90IT:&%T(&QO8V%L('5S97)S("AI9B!Y;W4@:&%V92!A;GDI(&-A;B=T
M(&1E;&5T92!T:&4@<V]C:V5T+B`@5&AE('5N:7@@(G-T:6-K>2(*8FET('-H
M;W5L9"!A;')E861Y(&)E('-E;G0@;VX@=&AE('1E;7!O<F%R>2!D:7)E8W1O
M<GD@:71S96QF+"!B=70@>6]U(&%L<V\*;F5E9"!T;R!M86ME('-U<F4@=&AE
M('-O8VME="!I='-E;&8@:7-N)W0@=W)I=&%B;&4@8GD@(F]T:&5R(B!O<B!U
M<V5R<R!C86X*9&5L971E(&ET+@H*66]U(&UI9VAT(&-O;G-I9&5R(&UO=FEN
M9R!T:&4@<V]C:V5T(&9I;&4@=&\@86YO=&AE<B!L;V-A=&EO;B!S=6-H(&%S
M"F!@+W9A<B]R=6Y@8"!O<B!T:&4@=&]P+6QE=F5L(&1I<F5C=&]R>2!O9B!Y
M;W5R(&1A=&%B87-E('!R;V=R86T@*&4N9RX*8&`O=F%R+VQI8B]M>7-Q;&!@
M(&]R(&!@+W9A<B]L:6(O<&=S<6Q@8"DN"@H*4V5N9&UA:6P@;W(@4TU44"!C
M;VYS:61E<F%T:6]N<PH]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M"@I);B!S;VUE(&-A<V5S+"!Y;W4@8V%N(&EN8W)E87-E('-E8W5R:71Y(&)Y
M('-E;F1I;F<@;6%I;"!V:6$@=&AE(&QO8V%L"F-O;6UA;F0M;&EN92!S96YD
M;6%I;"!P<F]G<F%M(&]N('EO=7(@=V5B('-E<G9E<BP@<F%T:&5R('1H86X@
M=7-I;F<@4TU44"X*2&]W979E<BP@=&AE<F4@;6%Y(&)E(')E87-O;G,@=&\@
M=7-E(%--5%`@:6YS=&5A9"P@<W5C:"!A<R!I9B!Y;W5R('-M='`@<V5R=F5R
M"F1O97,@<W!A;2!O<B!V:7)U<R!C:&5C:VEN9R!W:&EC:"!W;W5L9"!B92!S
M:VEP<&5D('5S:6YG('1H92!L;V-A;"!S96YD;6%I;`IP<F]G<F%M+@H*"D%D
M9&ET:6]N86P@3F]T97,*/3T]/3T]/3T]/3T]/3T]/0H*5&AI<R!I<R!B>2!F
M87(@;F]T(&$@8V]M<&QE=&4@<V5C=7)I='D@2$]75$\N(%1H:7,@:7,@:G5S
M="!A(&-O;7!I;&5D(&QI<W0@;V8*=VAA="!P96]P;&4@:&%V92!C;VYT<FEB
M=71E9"!S;R!F87(N($EF('EO=2!H879E('1I<',L(&ED96%S+"!S=6=G97-T
M:6]N<R!O<@IA;GET:&EN9R!E;'-E('1H870@>6]U('1H:6YK(&-O=6QD(&AE
M;'`@;W1H97)S(&EN('-E8W5R:6YG('1H96ER($AO<F1E"FEN<W1A;&QA=&EO
M;BP@<&QE87-E(&QE="!U<R!K;F]W+@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V1O8W,O
M5$]$3P``````````````````````````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,S<R,2`Q,#4Q-30S,S<S-"`P,3<Q-C,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T*($AO<F1E($1E=F5L;W!M96YT(%1/1$\@3&ES
M=`H]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*.DQA<W0@=7!D871E
M.B`@("1$871E.B`R,#`T+S$R+S$X(#$Y.C4W.C,R("0*.E)E=FES:6]N.B`@
M("`@("12979I<VEO;CH@,2XR-R`D"CI#;VYT86-T.B`@("`@("!H;W)D94!L
M:7-T<RYH;W)D92YO<F<*"DEN(&YO('!A<G1I8W5L87(@;W)D97(Z"@HM("A/
M<'1I;VYA;&QY*2!"=6YD;&4@4$5!4B!P86-K86=E<R!W:71H('1H92!T87)B
M86QL<RX@1VEV96X@82!P86-K86=E(&QI<W0L"B`@;6%K92UR96QE87-E+G!H
M<"!S:&]U;&0@9V5T('1H92!P86-K86=E<R!A;F0@=6YP86-K('1H96T@:6YT
M;R!L:6(O('=H97)E('=E"B`@:6YS=&%L;"!O=7(@;W=N('!A8VMA9V5S(&%N
M>7=A>2X@5&]G971H97(@=VET:"!P96%R+FAO<F1E+F]R9R!T:&ES('-H;W5L
M9`H@(&QE860@=&\@(FQI=&4B('1A<F)A;&QS(&]N;'D@8V]N=&%I;FEN9R!A
M<'!L:6-A=&EO;B!C;V1E(&%N9"`B9G5L;"(@=&%R8F%L;',*("!T:&%T(&1O
M;B=T(&YE960@86YY(&5X=&5R;F%L(&1E<&5N8V5N8VEE<R!A;GEM;W)E+@H*
M+2`B8G)O=W-E(B!D<FEV97(@9F]R(%9&4R!T:&%T('5S97,@2&]R9&4G<R!B
M<F]W<V4@05!)+@H*+2!#86-H92!T:&4@4F5G:7-T<GD@;V)J96-T('-O('1H
M870@9FEL92!O=F5R:&5A9"!O9B!R96%D:6YG(&EN(&5N=')I97,@9G)O;2!A
M"B`@9&ER96-T;W)Y("AR96=I<W1R>2YD*2!I<R!M:71I9V%T960N"@HM($EM
M<&QE;65N="!A9&UI;B]D96QE=&55<V5R(&UE=&AO9',@:6X@87!P;&EC871I
M;VYS)R!!4$ES('1O(&1E;&5T92!U<V5R"B`@<W!E8VEF:6,@9&%T82X*"BT@
M061D(&$@+W-E<G9I8V5S+V=R;W5P<R\@<V5C=&EO;BX@26YC;'5D92!P=6)L
M:6,@9W)O=7`@:&]M97!A9V5S+"!I;F-L=61I;F<*("!A;GD@:6YF;W)M871I
M;VX@;6%R:V5D('!U8FQI8R!F;W(@=&AE(&=R;W5P("AL970@=&AE(&UE;6)E
M<G,@;&ES="!B92!M87)K960*("!P=6)L:6,O9W)O=7`@;VYL>2]A9&UI;B!O
M;FQY*2P@861D(&=R;W5P(&%D;6EN:7-T<F%T;W)S("AJ=7-T(&$@9FQA9R!F
M;W(*("!U<V5R<RDL(&%D9"!T:&4@86)I;&ET>2!T;R!S:&]W(&%L;"!C86QE
M;F1A<G,O;W1H97(@<VAA<F5S('1H870@82!G<F]U<"!H87,*("!P97)M:7-S
M:6]N<R!T;RP@86QL;W<@8W)E871I;F<@82!N97<@8V%L96YD87(O<&]L;"]E
M=&,N(&9O<B!A(&=R;W5P+@H*+2!!9&0@=&AE(&%B:6QI='D@=&\@8G)E86L@
M;W5T($1A=&%4<F5E(&=R;W5P7W5I9',@:6YT;R!T:&5I<B!O=VX@=&%B;&5S
M("AO;F4*("!T86)L92!P97(@9W)O=7`I+@H*+2!5<V4@=&AE(&9R965D97-K
M=&]P('-H87)E9"UM:6UE+6EN9F]?(%A-3"!F:6QE('1O(&)U:6QD(&]U<B!-
M24U%7TUA9VEC(&UA9VEC"B`@9&%T82!F:6QE<RX*"BT@061D('-U<'!O<G0@
M9F]R('1H92!34DT@87!P;&EC871I;VX@<V5R=F5R("AH='1P.B\O=W=W+G9L
M+7-R;2YN970O*2X*"BT@061D(%5)('-U<'!O<G0@9F]R(&UO<F4@8V]N9FEG
M=7)A=&EO;B!F:6QE<RX*"BT@4VEN8V4@0V]N=&5N="U$:7-P;W-I=&EO;B`H
M4D9#(#(Q.#,I(&ES(&YO="!A($U54U0@:6UP;&5M96YT+"!A;&QO=PH@(&EN
M9&EV:61U86P@34E-12!6:65W97)S('1O(&%L;&]W(&5X<&QI8VET(&]V97)R
M:61E("AI+F4N('1O(&%U=&\@:6YL:6YE(`H@(&1I<W!L87D@82!P87)T(&EN
M<W1E860@;V8@<F5N9&5R:6YG(&%S(&%N(&%T=&%C:&UE;G0@+2!U<V5F=6P@
M9F]R(%,O34E-10H@(&5N8W)Y<'1E9"!P87)T<RP@9F]R(&5X86UP;&4I+@H*
M+2!3:&]W('-H87)E9"!P<F5F97)E;F-E<R!O;B!A;&P@<')E9G,@<W5M;6%R
M>2!S8W)E96YS('1O(&UA:V4@:70*("!E87-I97(@9F]R('5S97(@=&\@9FEN
M9"!G;&]B86P@<')E9F5R96YC97,N"@H*+BX@7W-H87)E9"UM:6UE+6EN9F\Z
M(&AT='`Z+R]W=W<N9G)E961E<VMT;W`N;W)G+U-O9G1W87)E+W-H87)E9"UM
M:6UE+6EN9F\*````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]D;V-S+U1204Y3
M3$%424].4P``````````````````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,3(U-S$@,3`U,34T,S,W,S0@,#(P,S0R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T*($AO<F1E(%1R86YS;&%T:6]N($=U:61E"CT]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T*"CI,87-T('5P9&%T93H@("`D1&%T93H@,C`P-2\Q
M,"\Q."`Q,3HS,SHS."`D"CI2979I<VEO;CH@("`@("`D4F5V:7-I;VXZ(#$N
M."XQ,"XR("0*.D%U=&AO<CH@("`@("`@($IO<FES($)R86%K;6%N(#QJ8G)A
M86MM86Y`>6%H;V\N8V]M/@HZ075T:&]R.B`@("`@("`@0VAU8VL@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"CI!=71H;W(Z("`@("`@("!*86X@4V-H
M;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@HZ0V]N=&%C=#H@("`@("`@:&]R9&5`
M;&ES=',N:&]R9&4N;W)G"@HN+B!C;VYT96YT<SHZ($-O;G1E;G1S"@H*1TY5
M(&=E='1E>'0L(%!(4"!A;F0@2&]R9&4*/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T*"DAO<F1E('5S97,@1TY5(&=E='1E>'0@9F]R(&EN=&5R;F%T:6]N
M86QI>F%T:6]N("AI,3AN*2!A;F0@;&]C86QI>F%T:6]N"BAL,3!N*2X@(%1H
M92!M86YU86P@870@:'1T<#HO+W=W=RYG;G4N;W)G+VUA;G5A;"]G971T97AT
M+VEN9&5X+FAT;6P@:7,@8FEA<V5D"F%G86EN<W0@0R!A;F0@=7-I;F<@16UA
M8W,N("!4:&ES(&ES(&UO<F4@9F]R($AO<F1E+@H*5&AE<F4@:7,@82!G;V]D
M(&5X<&QA;F%T:6]N(&9O<B!02%`@86YD(&=E='1E>'0@870Z"FAT='`Z+R]W
M=W<N9F%Q=',N8V]M+VMN;W=L961G92UB87-E+W9I97<N<&AT;6PO86ED+S(Y
M-3,O9FED+S0R,@H*4&5O<&QE('-E96T@=&\@;&EK92!L96%R;FEN9R!F<F]M
M(&5X86UP;&5S(&)E='1E<BP@<V\@22!H879E('5S960@9'5T8V@**&YL7TY,
M*2!A<R!A;B!E>&%M<&QE(&5V97)Y=VAE<F4N"@I4:&5R92!I<R!A(&-O;6UA
M;F0@;&EN92!T;V]L('=R:71T96X@:6X@4$A0(&9O<B!C<F5A=&EN9R!A;F0@
M;6%N86=I;F<*=')A;G-L871I;VYS(&EN('1H92!@8&AO<F1E+W!O+V!@(&1I
M<F5C=&]R>2X@(%5S86=E(&EN<W1R=6-T:6]N<R!C86X@8F4@9F]U;F0*:6X@
M8&!H;W)D92]P;R]214%$345@8"!A<R!W96QL(&%S(&EN<W1R=6-T:6]N<R!O
M;B!H;W<@=&\@<W1A<G0@86YD(&UA:6YT86EN"G1R86YS;&%T:6]N<RX*"@I4
M<F%N<VQA=&EO;G,@9&]N)W0@=V]R:PH]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/0H*268@86QL(&]R('-O;64@=')A;G-L871I;VYS(&1O;B=T('=O<FL@;VX@
M>6]U<B!S>7-T96TL('!L96%S92!F;VQL;W<@=&AE('-T97!S"F1E<V-R:6)E
M9"!B96QO=RX@($EF('EO=2!W86YT('1O(&%S:R!F;W(@:&5L<"!E:71H97(@
M;VX@=&AE(&!I,3AN(&UA:6QI;F<*;&ES=&!?(&]R(&]N(&!(;W)D92=S(&)U
M9R!S>7-T96U@7RP@<&QE87-E(&5X<&QA:6X@=VAI8V@@<W1E<',@>6]U('1R
M:65D(&%N9`IW:&EC:"!F86EL960N"@I9;W4@;6EG:'0@86QS;R!F:6YD('-O
M;64@;6]R92!I;F9O<FUA=&EO;B!I;B!T:&4@1D%17RX*"E!L96%S92!N;W1E
M('1H870@1'5T8V@@*&YL7TY,*2!I<R!O;FQY('5S960@87,@86X@97AA;7!L
M92!H97)E+B`@268@>6]U(&AA=F4*<')O8FQE;7,@=VET:"!A(&-E<G1A:6X@
M=')A;G-L871I;VX@=7-E('1H:7,@=')A;G-L871I;VXG<R!L86YG=6%G92!C
M;V1E"FEN<W1E860N"@HQ+B!)<R!T:&ES(&QO8V%L92`H;FQ?3DPI(&EN<W1A
M;&QE9"!A="!A;&P_"@H@("!@8&QO8V%L92`M86!@('-H;W5L9"!L:7-T(&%L
M;"!L;V-A;&5S(&EN<W1A;&QE9"!O;B!Y;W5R('-Y<W1E;2X*"B`@($]N($1E
M8FEA;B!N;W0@86QL(&QO8V%L97,@;6%Y(&)E(&5N86)L960@8GD@9&5F875L
M="X@($5D:70*("`@8&`O971C+VQO8V%L92YG96Y@8"!A;F0@<G5N(&!@;&]C
M86QE+6=E;F!@(&EF('EO=2!C:&%N9V5D('1H92!L:7-T(&]F"B`@(&5N86)L
M960@;&]C86QE<RX*"C(N($1O('EO=2!H879E(&%N>2`N;6\@9FEL97,_"@H@
M("!5<W5A;&QY(&EN(&!@+W5S<B]S:&%R92]L;V-A;&4O8&`*("`@92YG+B!@
M8"]U<W(O<VAA<F4O;&]C86QE+VYL+TQ#7TU%4U-!1T53+W1A<BYM;V!@"@HS
M+B!$;V5S(&=E='1E>'0@979E;B!W;W)K/PH*("`@1V5T(&$@<W1R:6YG('1O
M('1R86YS;&%T93HZ"@H@("`@("`D('-T<FEN9W,@+V)I;B]T87(@?"!G<F5P
M($UE;6]R>0H@("`@("!-96UO<GD@97AH875S=&5D"B`@("`@("0@*$Q!3D<]
M;FQ?3DP[($Q!3D=504=%/6YL7TY,.R!,0U]-15-304=%4SUN;%].3#L@9V5T
M=&5X="!T87(@(DUE;6]R>2!E>&AA=7-T960B("D*("`@("`@1V5H975G96X@
M=6ET9V5P=70*"C0N($1O97,@=&AE(&QO8V%L($AO<F1E(&9I;&4@=V]R:S\*
M"B`@($%S<W5M:6YG('1H870@>6]U(&AA=F4@<'5T('1H92!T<F%N<VQA=&5D
M($AO<F1E(&9I;&4@:6X*("`@8&`O9&%T82]W=W<O:&]R9&4O;&]C86QE+VYL
M7TY,+TQ#7TU%4U-!1T53+VAO<F1E+FUO8&`Z.@H*("`@("`@)"!E>'!O<G0@
M5$585$1/34%)3D1)4CTO9&%T82]W=W<O:&]R9&4O;&]C86QE"B`@("`@("0@
M*$Q!3D<];FQ?3DP[($Q!3D=504=%/6YL7TY,.R!,0U]-15-304=%4SUN;%].
M3#L@9V5T=&5X="!H;W)D92`B365S<V%G92(@*0H@("`@("!"97)I8VAT"@H@
M("!#<F5A=&4@82!F:6QE(&EN('1H92!H;W)D92!D:7)E8W1O<GDL(&QA;F=T
M97-T+G!H<#HZ"@H@("`@("`\/W!H<`H*("`@("`@<V5T;&]C86QE*$Q#7TU%
M4U-!1T53+"`G;FQ?3DPG*3L*("`@("`@<'5T96YV*"=,04Y'/6YL7TY,)RD[
M"B`@("`@('!U=&5N=B@G3$%.1U5!1T4];FQ?3DPG*3L*("`@("`@+R\@=7-E
M('1H92!T87(@=&5S="X*("`@("`@96-H;R!D9V5T=&5X="@G=&%R)RP@)TUE
M;6]R>2!E>&AA=7-T960G*3L*("`@("`@96-H;R`G/&)R("\^)SL*"B`@("`@
M("\O(%-P96-I9GD@;&]C871I;VX@;V8@=')A;G-L871I;VX@=&%B;&5S"B`@
M("`@(&)I;F1T97AT9&]M86EN*"=H;W)D92<L("<N+VQO8V%L92<I.PH*("`@
M("`@+R\@0VAO;W-E(&1O;6%I;@H@("`@("!T97AT9&]M86EN*"=H;W)D92<I
M.PH*("`@("`@+R\@4')I;G0@=&AE(&%L<F5A9'D@=&5S=&5D(&UE<W-A9V4*
M("`@("`@96-H;R!?*")-97-S86=E(BD["B`@("`@(&5C:&\@)SQB<B`O/B<[
M"@H@("`@("`O+R!T:&ES('-H;W5L9"!P<FEN="!T:&4@<V%M92X*("`@("`@
M96-H;R!D9V5T=&5X="@G:&]R9&4G+"`G365S<V%G92<I.PH*("`@("`@/SX*
M"B`@($]U='!U="!W96(@8G)O=W-E<CHZ"@H@("`@("!'96AE=6=E;B!U:71G
M97!U=`H@("`@("!"97)I8VAT"B`@("`@($)E<FEC:'0*"@HN+B!?8&DQ.&X@
M;6%I;&EN9R!L:7-T8#H@:'1T<#HO+VAO<F1E+F]R9R]M86EL+PHN+B!?8$AO
M<F1E)W,@8G5G('-Y<W1E;6`Z(&AT='`Z+R]B=6=S+FAO<F1E+F]R9PHN+B!?
M1D%1.B!H='1P.B\O:&]R9&4N;W)G+V9A<2\*"@I3;VQA<FES"CT]/3T]/3T*
M"E-I;F-E('1H92`N;6\@9FEL97,@87)E(&)I;F%R>2P@=&AE>2!A<F4@<&QA
M=&9O<FT@<W!E8VEF:6,N("!9;W4@:&%V92!T;R!R97)U;@IM86ME(&EN(&%L
M;"!P;R!D:7)E8W1O<FEE<RX*"D]N(%-O;&%R:7,@-RP@>6]U(&1O;B=T(&AA
M=F4@=&AE(&!@4&%R=&EA;"!,;V-A;&5S("A354Y7<&QO8RE@8"!A;F0*8&!3
M=7!P;&5M96YT87)Y(%!A<G1I86P@3&]C86QE<R`H4U5.5W!L;V,Q*6!@('!A
M8VMA9V5S(&EN<W1A;&QE9"!I9B!Y;W4@9V5T.CH*"B`@("0@3$%.1SUN;%].
M3`H@("!C;W5L9&XG="!S970@;&]C86QE(&-O<G)E8W1L>0H*3VX@4V]L87)I
M<R`X+"!Y;W4@;75S="!I;G-T86QL('1H92!L;V-A;"!P86-K86=E<R!R97%U
M:7)E9"!F;W(@=&AE(&QO8V%L97,@>6]U"F1E<VER92`H9F]R(&5X86UP;&4L
M('EO=2!M87D@;F5E9"!T;R!I;G-T86QL(&!@4U5.5W=E=6]S8&`@9F]R(%=E
M<W1E<FX*175R;W!E86X@;&]C86QE<R!O<B!@8%-53E=M96%O<V!@(&9O<B!-
M:61D;&4@16%S=&5R;B!L;V-A;&5S*2X@(%1H92!P86-K86=E<PIA<F4@;&]C
M871E9"!O;B!3;V9T=V%R92!$:7-K(#$@;V8@,B!I;B!T:&4@9&ER96-T;W)Y
M.@I@8'-O;%\X7S$P,#%?<W!A<F,O<S`O4V]L87)I<U\X+U!R;V1U8W1@8`H*
M5&AI<R!I<R!W:&%T(&ET('-H;W5L9"!S87DZ"@I3;VQA<FES(#<Z.@H*("`@
M)"!P:V=I;F9O('P@9W)E<"!P;&]C"B`@('-Y<W1E;2`@("`@(%-53E=P;&]C
M("`@("`@(%!A<G1I86P@3&]C86QE<PH@("!S>7-T96T@("`@("!354Y7<&QO
M8S$@("`@("!3=7!P;&5M96YT87)Y(%!A<G1I86P@3&]C86QE<PH*4V]L87)I
M<R`X.CH*"B`@("0@<&MG:6YF;R!\(&=R97`@975O"B`@('-Y<W1E;2`@("`@
M(%-53E=C975O<R`@("`@($-E;G1R86P@175R;W!E($]3(%-U<'!O<G0*("`@
M<WES=&5M("`@("`@4U5.5V-E=6]X("`@("`@0V5N=')A;"!%=7)O<&4@-C0M
M8FET($]3(%-U<'!O<G0*("`@<WES=&5M("`@("`@4U5.5V5E=6]S("`@("`@
M16%S=&5R;B!%=7)O<&4@3U,@4W5P<&]R=`H@("!S>7-T96T@("`@("!354Y7
M965U;W@@("`@("!%87-T97)N($5U<F]P92`V-"UB:70@3U,@4W5P<&]R=`H@
M("!S>7-T96T@("`@("!354Y7;F5U;W,@("`@("!.;W)T:&5R;B!%=7)O<&4@
M3U,@4W5P<&]R=`H@("!S>7-T96T@("`@("!354Y7;F5U;W@@("`@("!.;W)T
M:&5R;B!%=7)O<&4@-C0M8FET($]3(%-U<'!O<G0*("`@<WES=&5M("`@("`@
M4U5.5W-E=6]S("`@("`@4V]U=&AE<FX@175R;W!E($]3(%-U<'!O<G0*("`@
M<WES=&5M("`@("`@4U5.5W-E=6]X("`@("`@4V]U=&AE<FX@175R;W!E(#8T
M+6)I="!/4R!3=7!P;W)T"B`@('-Y<W1E;2`@("`@(%-53E=W975O<R`@("`@
M(%=E<W1E<FX@175R;W!E($]3(%-U<'!O<G0*("`@<WES=&5M("`@("`@4U5.
M5W=E=6]X("`@("`@5V5S=&5R;B!%=7)O<&4@-C0M8FET($]3(%-U<'!O<G0*
M"E1H92!S='5F9B!I<R!I;G-T86QL960@:6X@8&`O=7-R+VQI8B]L;V-A;&5@
M8#HZ"@H@("`D(&QS("]U<W(O;&EB+VQO8V%L92]N;`H@("!,0U]#3TQ,051%
M("`@3$-?0U194$4@("`@($Q#7TU%4U-!1T53("!,0U]-3TY%5$%262`@3$-?
M3E5-15))0R`@($Q#7U1)344@("`@("!N;"YS;RXQ"@I)="!W87,@<F5P;W)T
M960@=&AA="!T:&4@2%144"!S97)V97(@:&%S('1O(&)E(&QI;FME9"!T;R!T
M:&4@<V%M92!L:6)I;G1L+G-O"F9I;&4@87,@4$A0(&]N(%-O;&%R:7,N("!!
M;'-O+"!I="!M87D@8F4@<F5Q=6ER960@=&AA="!L:6)I;G1L+G-O(&)E(&QO
M861E9`IB969O<F4@;&EB8R!I<R!L;V%D960N("!)9B!Y;W4@87)E(&AA=FEN
M9R!C;VYF;&EC=',L('EO=2!M87D@8F4@86)L92!T;R!R97-I9&4*=&AE;2!B
M>2!S=&%R=&EN9R!A<&%C:&4@=VET:"!O;F4@;V8@=&AE(&9O;&QO=VEN9R!C
M;VUM86YD<SHZ"@H@("`D($Q$7U!214Q/040];&EB:6YT;"YS;R!A<&%C:&5C
M=&P@<W1A<G0*"@I&<F5E0E-$"CT]/3T]/3T*"E1O(&5N86)L92!55$8M."!S
M=7!P;W)T(&EN($AO<F1E+"!Y;W4@86QS;R!N965D(%541BTX('-U<'!O<G0@
M:6X*1G)E94)31"X@(%1H:7,@:7,@;F]T(&EN<W1A;&QE9"!B>2!D969A=6QT
M+"!Y;W4@;F5E9"!T;R!I;G-T86QL('1H90I@8'5T9CAL;V-A;&4M=VET:&]U
M="US=VED=&@M,#0P,S$Y8&`@<&%C:V%G92!O<B!P;W)T+@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]D;V-S+U501U)!1$E.1P``````````````````````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3`S,#4@,3`U,34T,S,W
M,S0@,#$W-S,R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#T]/3T]/3T]/3T]/3T]/3T]"B!5<&=R861I;F<@2&]R9&4*/3T]
M/3T]/3T]/3T]/3T]/3T*"CI,87-T('5P9&%T93H@("`D1&%T93H@,C`P-B\P
M-B\R.2`Q-CHR.3HP,B`D"CI2979I<VEO;CH@("`@("`D4F5V:7-I;VXZ(#$N
M-"XT+C$Q("0*.D-O;G1A8W0Z("`@("`@(&AO<F1E0&QI<W1S+FAO<F1E+F]R
M9PH*"E1H97-E(&%R92!I;G-T<G5C=&EO;G,@=&\@=7!G<F%D92!F<F]M(&5A
M<FQI97(@2&]R9&4@=F5R<VEO;G,N(%!L96%S92!B86-K=7`*>6]U<B!E>&ES
M=&EN9R!D871A(&)E9F]R92!R=6YN:6YG(&%N>2!O9B!T:&4@<W1E<',@9&5S
M8W)I8F5D(&)E;&]W+B!9;W4@8V%N)W0*=7-E('1H92!U<&1A=&5D(&1A=&$@
M=VET:"!Y;W5R(&]L9"!(;W)D92!V97)S:6]N(&%N>6UO<F4N"@I!9G1E<B!U
M<&1A=&EN9R!T;R!A(&YE=V5R($AO<F1E('9E<G-I;VXL(&]R(&$@;F5W97(@
M=F5R<VEO;B!O9B`J*F%N>2HJ($AO<F1E"F%P<&QI8V%T:6]N+"!Y;W4@*BIA
M;'=A>7,J*B!N965D('1O('5P9&%T92`J*F%L;"HJ(&-O;F9I9W5R871I;VX@
M9FEL97,N"@H*57!G<F%D:6YG($AO<F1E(&9R;VT@,RXQ+C$@=&\@,RXQ+C(*
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"@I397-S:6]N
M($-O;F9I9W5R871I;VX*+2TM+2TM+2TM+2TM+2TM+2TM+2TM"@I!(&YE=R!C
M;VYF:6=U<F%T:6]N('-E='1I;F<@:&%S(&)E96X@861D960@=&\@9&ES86)L
M92!'150M8F%S960*<V5S<VEO;G,N("!)9B!T:&ES('-E='1I;F<@:7,@96YA
M8FQE9"P@<V5S<VEO;B!)1',@=VEL;"!O;FQY(&)E('-T;W)E9`II;B!S97-S
M:6]N(&-O;VMI97,L(')E<75I<FEN9R!T:&4@=7-E<G,@=&\@96YA8FQE(&-O
M;VMI97,@:6X@=&AE:7(*8G)O=W-E<B!A;F0@=&AE(&-O;VMI92!S971T:6YG
M<R!I;B!(;W)D92=S(&-O;F9I9W5R871I;VX@=&\@8F4@8V]R<F5C="X*"E5S
M:6YG('-E<W-I;VX@8V]O:VEE<R!I<R!M=6-H('-A9F5R('-I;F-E(&YO('-E
M<W-I;VX@:6YF;W)M871I;VX@8V%N"F)E('-T;W)E9"!I;B!A;GD@=V5B('-E
M<G9E<B!O<B!P<F]X>2!L;V<@9FEL97,L(')E9F5R<F5R(&AE861E<G,L"F)R
M;W=S97(@8V%C:&5S+"!O<B!B<F]W<V5R(&)O;VMM87)K<RX*"BXN(%=A<FYI
M;F<Z.B!4:&ES('-E='1I;F<@:6X@96YA8FQE9"!B>2!D969A=6QT+@H*"D%D
M9&ET:6]N86P@26YD97AE<R!F;W(@=&AE(%!R969E<F5N8V4@5&%B;&4*+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H*3W!T
M:6]N86QL>2!E>&5C=71E('1H92!P<F]V:61E9"!344P@<V-R:7!T(#(P,#8M
M,#8M,CE?:&]R9&5?<')E9G-?:6YD97AE<RYS<6P*=&\@8W)E871E('1W;R!A
M9&1I=&EO;F%L(&EN9&5X97,@:6X@=&AE('!R969E<F5N8V4@=&%B;&4L(&4N
M9RXZ.@H*("`@;7ES<6P@+2UU<V5R/7)O;W0@+2UP87-S=V]R9#T\37E344PM
M<F]O="UP87-S=V]R9#X@/&1B(&YA;64^(#P@<V-R:7!T<R]U<&=R861E<R\R
M,#`V+3`V+3(Y7VAO<F1E7W!R969S7VEN9&5X97,N<W%L"@I4:&ES(&EN8W)E
M87-E<R!D871A8F%S92!P97)F;W)M86YC92!F;W(@<V]M92!D871A8F%S92!S
M>7-T96US+"!E+F<N(%!O<W1G<F5344P*:68@>6]U(&AA=F4@;&%R9V4@<')E
M9F5R96YC92!T86)L97,N"@H*57!G<F%D:6YG($AO<F1E(&9R;VT@,RXQ('1O
M(#,N,2XQ"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*"DUY
M4U%,(%-E<W-I;VX@2&%N9&QE<@HM+2TM+2TM+2TM+2TM+2TM+2TM+2T*"E1H
M92!M>7-Q;"!S97-S:6]N(&AA;F1L97(@:&%S(&)E96X@:6UP<F]V960@=&\@
M8V]R<F5C=&QY(&QO8VL@8V]N8W5R<F5N=`IA8V-E<W-E<R!T;R!T:&4@<V%M
M92!S97-S:6]N+B!9;W4@;F5E9"!T;R!S970@:6X@=&AE($AO<F1E(&-O;F9I
M9W5R871I;VX@:68*>6]U('=A;G0@=&\@=7-E(')O=RUL979E;"!L;V-K:6YG
M(&%N9"!T<F%N<V%C=&EO;G,@;W(@=&%B;&4M;&5V96P*;&]C:VEN9RX@4F]W
M+6QE=F5L(&QO8VMI;F<@86YD('1R86YS86-T:6]N<R!A<F4@;VYL>2!S=7!P
M;W)T960@8GD@<V]M92!T86)L90IE;F=I;F5S(&QI:V4@26YN;T1"+"!A;F0@
M:7,@<F5C;VUM96YD960@9F]R('-E<W-I;VX@=&%B;&5S+B!4:&4@9&5F875L
M="!T86)L90IT>7!E(&9O<B!->5-13"!I<R!->4E304T@=&AO=6=H+"!T:&%T
M(&]N;'D@<W5P<&]R=',@=&%B;&4M;&5V96P@;&]C:VEN9RX@268*>6]U('5S
M960@=&AE(%-13"!S8W)I<'1S(&9R;VT@2&]R9&4@,RXQ(&]R(&5A<FQI97(@
M=&\@8W)E871E('1H92!S97-S:6]N"G1A8FQE+"!T:&ES(&ES('!R;V)A8FQY
M('1H92!C=7)R96YT(&5N9VEN92!O9B!Y;W4@<V5S<VEO;B!T86)L92X@268@
M>6]U('=A;G0*=&\@8VAA;F=E('1H92!T86)L92!T>7!E('1O($EN;F]$0BP@
M97AE8W5T92!T:&4@9F]L;&]W:6YG(%-13"!S=&%T96UE;G0Z.@H*("`@04Q4
M15(@5$%"3$4@:&]R9&5?<V5S<VEO;FAA;F1L97(@14Y'24Y%(#T@26YN;T1"
M"@H*"E5P9W)A9&EN9R!(;W)D92!F<F]M(#,N,"YX('1O(#,N,2YX"CT]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"@H*4U%,($)A8VME;F1S
M"BTM+2TM+2TM+2TM+0H*02!F97<@;F5W('1A8FQE<R!H879E(&)E96X@861D
M960@=&\@2&]R9&4N"@I%>&5C=71E(&]N92!O9B!T:&4@<')O=FED960@4U%,
M('-C<FEP=',@=&\@=7!D871E('EO=7(@9&%T82!T;R!T:&4@;F5W($AO<F1E
M"G9E<G-I;VXL(&4N9RXZ.@H*("`@;7ES<6P@+2UU<V5R/7)O;W0@+2UP87-S
M=V]R9#T\37E344PM<F]O="UP87-S=V]R9#X@/&1B(&YA;64^(#P@<V-R:7!T
M<R]U<&=R861E<R\S+C!?=&]?,RXQ+FUY<W%L+G-Q;`H*"D=R;W5P<PHM+2TM
M+2T*"E1H92!(;W)D95]'<F]U<"!!4$D@=7-E<R!G<F]U<"!)1',@:6YS=&5A
M9"!O9B!G<F]U<"!N86UE<R!T;R!A=F]I9"!A;6)I9W5I='DN"D)E('-U<F4@
M=&\@=7!D871E(&%N>2!C=7-T;VT@8V]D92!T:&%T('5S97,@2&]R9&5?1W)O
M=7`N"@H*2&ES=&]R>0HM+2TM+2TM"@I4:&4@2&]R9&5?2&ES=&]R>2!S=&]R
M86=E(&AA<R!B965N(&UO=F5D(&]U="!T;R!A('-E<&%R871E(&1A=&%B87-E
M('1A8FQE('1O"F1R87-T:6-A;&QY(&EM<')O=F4@<&5R9F]R;6%N8V4N"@HN
M+B!787)N:6YG.CH@36EG<F%T:6]N(&]F('1H92!(;W)D95](:7-T;W)Y(&1A
M=&$@;6%Y('1A:V4@82!V97)Y(&QO;F<@=&EM92P*("`@("`@("`@("`@('!O
M<W-I8FQY(&1A>7,L(&1E<&5N9&EN9R!O;B!T:&4@;G5M8F5R(&]F(&5N=')I
M97,N("!"92!S=7)E('1O"B`@("`@("`@("`@("!E>&5C=71E('1H:7,@<V-R
M:7!T(&9R;VT@82!L;V-A=&EO;B!W:&5R92!I="!W:6QL(&YO="!B92!T:6UE
M9`H@("`@("`@("`@("`@;W5T(&)Y(&9I<F5W86QL(&]R('1E<FUI;F%L('1I
M;65O=71S+@H*17AE8W5T92!T:&4@<')O=FED960@4$A0('-C<FEP="!T;R!M
M:6=R871E('EO=7(@:&ES=&]R:65S('1O('1H92!N97<@=&%B;&4Z.@H*("`@
M<&AP('-C<FEP=',O=7!G<F%D97,O;6]V95]H:7-T;W)Y7V]U=%]O9E]D871A
M=')E92YP:'`*"@H*57!G<F%D:6YG($AO<F1E(&9R;VT@,BYX('1O(#,N,"YX
M"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*"D-O;F9I9W5R
M871I;VX@9FEL97,*+2TM+2TM+2TM+2TM+2TM+2TM+0H*5&AE(&-O;F9I9W5R
M871I;VX@9FEL97,@:&%V92!B965N(&-H86YG960@=&\@6$U,(&9O<FUA="X@
M(%1O(&=E;F5R871E(&$@=F%L:60*8V]N9FEG=7)A=&EO;B!F:6QE(&9R;VT@
M=&AE(%A-3"!F:6QE+"!F;VQL;W<@=&AE(&-O;F9I9W5R871I;VX@:6YS=')U
M8W1I;VYS"FEN('1H92!A<'!L:6-A=&EO;G,G(&!@9&]C<R])3E-404Q,8&`@
M9FEL92X*"@I0<F5F97)E;F-E<PHM+2TM+2TM+2TM+0H*5&AE(&!@;&%S=%]L
M;V=I;F!@(&%N9"!@8&1A=&5?9F]R;6%T8&`@<')E9F5R96YC97,@:&%V92!C
M:&%N9V5D('1H96ER(&9O<FUA=`IA;F0O;W(@<V-O<&4N("!*=7-T(')E;6]V
M92!A;&P@8&!L87-T7VQO9VEN8&`@86YD(&!@9&%T95]F;W)M871@8"!P<F5F
M97)E;F-E<PIF<F]M('1H92!P<F5F97)E;F-E<R!B86-K96YD+@H*"E-13"!"
M86-K96YD<PHM+2TM+2TM+2TM+2T*"D$@9F5W(&YE=R!T86)L97,@:&%V92!B
M965N(&%D9&5D('1O($AO<F1E+@H*17AE8W5T92!T:&4@<')O=FED960@4U%,
M('-C<FEP="!T;R!U<&1A=&4@>6]U<B!D871A('1O('1H92!N97<@2&]R9&4@
M=F5R<VEO;CHZ"@H@("!M>7-Q;"`M+75S97(]<F]O="`M+7!A<W-W;W)D/3Q-
M>5-13"UR;V]T+7!A<W-W;W)D/B`\9&(@;F%M93X@/"!S8W)I<'1S+W5P9W)A
M9&5S+S(N,E]T;U\S+C`N;7ES<6PN<W%L"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1E<W0N<&AP````````````````````````````````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`S-3(S-2`Q,#4Q-30S,S<S-"`P,3<R-#``
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O=&5S="YP:'`L=B`Q+C$R,BXV+C$W
M(#(P,#8O,#8O,3`@,C,Z,38Z-3$@8VAU8VL@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#(M,C`P-B!"<F5N="!*+B!.;W)D<75I<W0@/&)J;D!H;W)D92YO
M<F<^"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAA<FQE<R!*+B!(86=E;F)U
M8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!*
M;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*
M+RH@4F5G:7-T97(@82!S97-S:6]N+B`J+PIS97-S:6]N7W-T87)T*"D["FEF
M("@A:7-S970H)%]315-324].6R=H;W)D95]T97-T7V-O=6YT)UTI*2!["B`@
M("`D7U-%4U-)3TY;)VAO<F1E7W1E<W1?8V]U;G0G72`](#`["GT*"B\J($EN
M8VQU9&4@2&]R9&4G<R!C;W)E+G!H<"!F:6QE+B`J+PII;F-L=61E7V]N8V4@
M)VQI8B]C;W)E+G!H<"<["@HO*B!792!S:&]U;&0@:&%V92!L;V%D960@=&AE
M(%-T<FEN9R!C;&%S<RP@9G)O;2!T:&4@2&]R9&5?571I;"!P86-K86=E+"!I
M;@H@*B!C;W)E+G!H<"X@268@4W1R:6YG.CH@:7-N)W0@9&5F:6YE9"P@=&AE
M;B!W92=R92!N;W0@9FEN9&EN9R!S;VUE(&-R:71I8V%L"B`J(&QI8G)A<FEE
M<RX@*B\*:68@*"%C;&%S<U]E>&ES=',H)U-T<FEN9R<I*2!["B`@("!E8VAO
M("<\8G(@+SX\<W!A;B!S='EL93TB8V]L;W(Z(')E9#L@9F]N="US:7IE.B`Q
M.'!X.R!F;VYT+7=E:6=H=#H@8F]L9#LB/E1H92!(;W)D95]5=&EL('!A8VMA
M9V4@=V%S(&YO="!F;W5N9"X@268@4$A07"=S(&5R<F]R7W)E<&]R=&EN9R!S
M971T:6YG(&ES(&AI9V@@96YO=6=H+"!T:&5R92!S:&]U;&0@8F4@97)R;W(@
M;65S<V%G97,@<')I;G1E9"!A8F]V92!T:&%T(&UA>2!H96QP('EO=2!I;B!D
M96)U9V=I;F<@=&AE('!R;V)L96TN($EF('EO=2!A<F4@<VEM<&QY(&UI<W-I
M;F<@=&AE<V4@9FEL97,@04Y$(&%R92!I;G-T86QL:6YG(&$@0U93(&-H96-K
M;W5T+"!T:&5N('EO=2!N965D('1O(&=E="!T:&4@/&$@:')E9CTB:'1T<#HO
M+V-V<RYH;W)D92YO<F<O8W9S+G!H<"]F<F%M97=O<FLB/F9R86UE=V]R:SPO
M83X@;6]D=6QE(&9R;VT@/&$@:')E9CTB:'1T<#HO+VAO<F1E+F]R9R]S;W5R
M8V4O(CY(;W)D92!#5E,\+V$^+"!A;F0@:6YS=&%L;"!T:&4@<&%C:V%G97,@
M:6X@:70@=VET:"!T:&4@:6YS=&%L;"UP86-K86=E<RYP:'`@<V-R:7!T+CPO
M<W!A;CXG.PH@("`@97AI=#L*?0H*+RH@26YI=&EA;&EZ92!T:&4@2&]R9&5?
M5&5S=#HZ(&-L87-S+B`J+PII9B`H(6EN8VQU9&5?;VYC92`G;&EB+U1E<W0N
M<&AP)RD@>PH@("`@+RH@5')Y(&%N9"!P<F]V:61E(&5N;W5G:"!I;F9O<FUA
M=&EO;B!T;R!D96)U9R!T:&4@;6ES<VEN9R!F:6QE+B`J+PH@("`@96-H;R`G
M/&)R("\^/'-P86X@<W1Y;&4](F-O;&]R.B!R960[(&9O;G0M<VEZ93H@,3AP
M>#L@9F]N="UW96EG:'0Z(&)O;&0[(CY5;F%B;&4@=&\@9FEN9"!H;W)D92]L
M:6(O5&5S="YP:'`N(%EO=7(@2&]R9&4@:6YS=&%L;&%T:6]N(&UA>2!B92!M
M:7-S:6YG(&-R:71I8V%L(&9I;&5S+"!O<B!02%`@;6%Y(&YO="!H879E('-U
M9F9I8VEE;G0@<&5R;6ES<VEO;G,@=&\@:6YC;'5D92!F:6QE<RX@5&AE<F4@
M;6%Y(&)E(&5R<F]R(&UE<W-A9V5S('!R:6YT960@86)O=F4@=&AI<R!M97-S
M86=E('1H870@=VEL;"!H96QP('EO=2!I;B!D96)U9V=I;F<@=&AE('!R;V)L
M96TN/"]S<&%N/B<["B`@("!E>&ET.PI]"@HO*B!)9B!W92=V92!G;W1T96X@
M=&AI<R!F87(L('=E('-H;W5L9"!H879E(&9O=6YD(&5N;W5G:"!O9B!(;W)D
M92!T;R!R=6X*("H@=&5S=',N($-R96%T92!T:&4@=&5S=&EN9R!O8FIE8W0N
M("HO"B1H;W)D95]T97-T(#T@)FYE=R!(;W)D95]497-T*"D["@HO*B!(;W)D
M92!D969I;FET:6]N<RX@*B\*)&UO9'5L92`]("=(;W)D92<["G)E<75I<F5?
M;VYC92`G+B]L:6(O=F5R<VEO;BYP:'`G.PHD;6]D=6QE7W9E<G-I;VX@/2!(
M3U)$15]615)324]..PH*+RH@4$A0(&UO9'5L92!C87!A8FEL:71I97,N("HO
M"B1M;V1U;&5?;&ES="`](&%R<F%Y*`H@("`@)V-T>7!E)R`]/B`G0W1Y<&4@
M4W5P<&]R="<L"B`@("`H=F5R<VEO;E]C;VUP87)E*'!H<'9E<G-I;VXH*2P@
M)S4G*2`\(#`@/R`G9&]M>&UL)R`Z("=D;VTG*2`]/B`G1$]-(%A-3"!3=7!P
M;W)T)RP*("`@("=F='`G(#T^("=&5%`@4W5P<&]R="<L"B`@("`G9V0G(#T^
M("='1"!3=7!P;W)T)RP*("`@("=G971T97AT)R`]/B!A<G)A>2@*("`@("`@
M("`G9&5S8W)I<"<@/3X@)T=E='1E>'0@4W5P<&]R="<L"B`@("`@("`@)V5R
M<F]R)R`]/B`G2&]R9&4@=VEL;"!N;W0@<G5N('=I=&AO=70@9V5T=&5X="!S
M=7!P;W)T+B!#;VUP:6QE(%!(4"!W:71H(#QC;V1E/BTM=VET:"UG971T97AT
M/"]C;V1E/B!B969O<F4@8V]N=&EN=6EN9RXG+`H@("`@("`@("=F871A;"<@
M/3X@=')U90H@("`@*2P*("`@("=I8V]N=B<@/3X@87)R87DH"B`@("`@("`@
M)V1E<V-R:7`G(#T^("=)8V]N=B!3=7!P;W)T)RP*("`@("`@("`G97)R;W(G
M(#T^("=)9B!Y;W4@=V%N="!T;R!T86ME(&9U;&P@861V86YT86=E(&]F($AO
M<F1E7"=S(&QO8V%L:7IA=&EO;B!F96%T=7)E<R!A;F0@8VAA<F%C=&5R('-E
M="!S=7!P;W)T+"!Y;W4@=VEL;"!N965D('1H92!I8V]N=B!E>'1E;G-I;VXN
M)PH@("`@*2P*("`@("=I;6%P)R`]/B`G24U!4"!3=7!P;W)T)RP*("`@("=L
M9&%P)R`]/B`G3$1!4"!3=7!P;W)T)RP*("`@("=M8G-T<FEN9R<@/3X@87)R
M87DH"B`@("`@("`@)V1E<V-R:7`G(#T^("=-8G-T<FEN9R!3=7!P;W)T)RP*
M("`@("`@("`G97)R;W(G(#T^("=)9B!Y;W4@=V%N="!T;R!T86ME(&9U;&P@
M861V86YT86=E(&]F($AO<F1E7"=S(&QO8V%L:7IA=&EO;B!F96%T=7)E<R!A
M;F0@8VAA<F%C=&5R('-E="!S=7!P;W)T+"!Y;W4@=VEL;"!N965D('1H92!M
M8G-T<FEN9R!E>'1E;G-I;VXN)PH@("`@*2P*("`@("=M8W)Y<'0G(#T^(&%R
M<F%Y*`H@("`@("`@("=D97-C<FEP)R`]/B`G36-R>7!T(%-U<'!O<G0G+`H@
M("`@("`@("=E<G)O<B<@/3X@)TUC<GEP="!I<R!A(&=E;F5R86PM<'5R<&]S
M92!C<GEP=&]G<F%P:'D@;&EB<F%R>2!W:&EC:"!I<R!B<F]A9&5R(&%N9"!S
M:6=N:69I8V%N=&QY(&UO<F4@969F:6-I96YT("A&05-415(A*2!T:&%N(%!(
M4%PG<R!O=VX@8W)Y<'1O9W)A<&AI8R!C;V1E(&%N9"!W:6QL('!R;W9I9&5R
M(&9A<W1E<B!L;V=I;G,N)PH@("`@*2P*("`@("=F:6QE:6YF;R<@/3X@87)R
M87DH"B`@("`@("`@)V1E<V-R:7`G(#T^("=-24U%($UA9VEC(%-U<'!O<G0@
M*&9I;&5I;F9O*2<L"B`@("`@("`@)V5R<F]R)R`]/B`G5&AE(&9I;&5I;F9O
M(%!%0TP@;6]D=6QE(&]R('1H92!M:6UE7VUA9VEC(%!(4"!E>'1E;G-I;VX@
M*'-E92!B96QO=RD@=VEL;"!M;W-T(&QI:V5L>2!P<F]V:61E(&9A<W1E<B!-
M24U%($UA9VEC(&QO;VMU<',@=&AA;B!T:&4@8G5I;'0M:6X@2&]R9&4@4$A0
M(&UA9VEC(&-O9&4N(%-E92!H;W)D92]D;V-S+TE.4U1!3$P@9F]R(&EN9F]R
M;6%T:6]N(&]N(&AO=R!T;R!I;G-T86QL(%!%0TPO4$A0(&5X=&5N<VEO;G,N
M)PH@("`@*2P*("`@("=M96UC86-H92<@/3X@87)R87DH"B`@("`@("`@)V1E
M<V-R:7`G(#T^("=M96UC86-H960@4W5P<&]R="`H;65M8V%C:&4I)RP*("`@
M("`@("`G97)R;W(G(#T^("=4:&4@;65M8V%C:&4@4$5#3"!M;V1U;&4@:7,@
M;F5E9&5D(&]N;'D@:68@>6]U(&%R92!U<VEN9R!T:&4@;65M8V%C:&5D(%-E
M<W-I;VY(86YD;&5R+B!3964@:&]R9&4O9&]C<R])3E-404Q,(&9O<B!I;F9O
M<FUA=&EO;B!O;B!H;W<@=&\@:6YS=&%L;"!014-,+U!(4"!E>'1E;G-I;VYS
M+B<*("`@("DL"B`@("`G;6EM95]M86=I8R<@/3X@87)R87DH"B`@("`@("`@
M)V1E<V-R:7`G(#T^("=-24U%($UA9VEC(%-U<'!O<G0@*&UI;65?;6%G:6,I
M)RP*("`@("`@("`G97)R;W(G(#T^("=4:&4@9FEL96EN9F\@4$5#3"!M;V1U
M;&4@*'-E92!A8F]V92D@;W(@=&AE(&UI;65?;6%G:6,@4$A0(&5X=&5N<VEO
M;B!W:6QL(&UO<W0@;&EK96QY('!R;W9I9&4@9F%S=&5R($U)344@36%G:6,@
M;&]O:W5P<R!T:&%N('1H92!B=6EL="UI;B!(;W)D92!02%`@;6%G:6,@8V]D
M92X@4V5E(&AO<F1E+V1O8W,O24Y35$%,3"!F;W(@:6YF;W)M871I;VX@;VX@
M:&]W('1O(&EN<W1A;&P@4$5#3"]02%`@97AT96YS:6]N<RXG"B`@("`I+`H@
M("`@)VUY<W%L)R`]/B`G37E344P@4W5P<&]R="<L"B`@("`G;W!E;G-S;"<@
M/3X@)T]P96Y34TP@4W5P<&]R="<L"B`@("`G<&=S<6PG(#T^("=0;W-T9W)E
M4U%,(%-U<'!O<G0G+`H@("`@)W-E<W-I;VXG(#T^(&%R<F%Y*`H@("`@("`@
M("=D97-C<FEP)R`]/B`G4V5S<VEO;B!3=7!P;W)T)RP*("`@("`@("`G9F%T
M86PG(#T^('1R=64I+`H@("`@)WAM;"<@/3X@)UA-3"!3=7!P;W)T)RP*("`@
M("=Z;&EB)R`]/B!A<G)A>2@*("`@("`@("`G9&5S8W)I<"<@/3X@)UIL:6(@
M4W5P<&]R="<L"B`@("`@("`@)V5R<F]R)R`]/B`G5&AE('IL:6(@;6]D=6QE
M(&ES(&AI9VAL>2!R96-O;6UE;F1E9"!F;W(@=7-E('=I=&@@2&]R9&4N("!)
M="!A;&QO=W,@<&%G92!C;VUP<F5S<VEO;B!A;F0@:&%N9&QI;F<@;V8@6DE0
M(&%N9"!'6B!D871A+B!#;VUP:6QE(%!(4"!W:71H(#QC;V1E/BTM=VET:"UZ
M;&EB/"]C;V1E/B!T;R!A8W1I=F%T92XG+`H@("`@("`@("=F871A;"<@/3X@
M9F%L<V4*("`@("DL"BD["@H*+RH@4$A0(%-E='1I;F=S+B`J+PHD<V5T=&EN
M9U]L:7-T(#T@87)R87DH"B`@("`G;6%G:6-?<75O=&5S7W)U;G1I;64G(#T^
M(&%R<F%Y*`H@("`@("`@("=S971T:6YG)R`]/B!F86QS92P*("`@("`@("`G
M97)R;W(G(#T^("=M86=I8U]Q=6]T97-?<G5N=&EM92!M87D@8V%U<V4@<')O
M8FQE;7,@=VET:"!D871A8F%S92!I;G-E<G1S+"!E=&,N(%1U<FX@:70@;V9F
M+B<*("`@("DL"B`@("`G;65M;W)Y7VQI;6ET)R`]/B!A<G)A>2@*("`@("`@
M("`G<V5T=&EN9R<@/3X@9F%L<V4L"B`@("`@("`@)V5R<F]R)R`]/B`G268@
M4$A07"=S(&EN=&5R;F%L(&UE;6]R>2!L:6UI="!I<R!T=7)N960@;VX@86YD
M(&EF(&YO="!S970@:&EG:"!E;F]U9V@@2&]R9&4@=VEL;"!N;W0@8F4@86)L
M92!T;R!H86YD;&4@;&%R9V4@9&%T82!I=&5M<R`H92YG+B!L87)G92!M86EL
M(&%T=&%C:&UE;G1S(&EN($E-4"DN($EF('!O<W-I8FQE+"!Y;W4@<VAO=6QD
M(&1I<V%B;&4@=&AE(%!(4"!M96UO<GD@;&EM:70@8GD@<F5C;VUP:6QI;F<@
M4$A0(#QE;3YW:71H;W5T/"]E;3X@=&AE("(M+65N86)L92UM96UO<GDM;&EM
M:70B(&9L86<N($EF('1H:7,@:7,@;F]T('!O<W-I8FQE+"!T:&5N('EO=2!S
M:&]U;&0@<V5T('1H92!V86QU92!O9B!M96UO<GE?;&EM:70@:6X@<&AP+FEN
M:2!T;R!A('-U9F9I8VEE;G1L>2!H:6=H('9A;'5E("A#=7)R96YT('9A;'5E
M(&]F(&UE;6]R>5]L:6UI=#H@)R`N(&EN:5]G970H)VUE;6]R>5]L:6UI="<I
M("X@)RDN)PH@("`@*2P*("`@("=S869E7VUO9&4G(#T^(&%R<F%Y*`H@("`@
M("`@("=S971T:6YG)R`]/B!F86QS92P*("`@("`@("`G97)R;W(G(#T^("=)
M9B!S869E7VUO9&4@:7,@96YA8FQE9"P@2&]R9&4@8V%N;F]T('-E="!E;G9I
M<F]M96YT('9A<FEA8FQE<RP@=VAI8V@@;65A;G,@2&]R9&4@=VEL;"!B92!U
M;F%B;&4@=&\@=')A;G-L871E('1H92!U<V5R(&EN=&5R9F%C92!I;G1O(&1I
M9F9E<F5N="!L86YG=6%G97,N)PH@("`@*2P*("`@("=S97-S:6]N+G5S95]T
M<F%N<U]S:60G(#T^(&%R<F%Y*`H@("`@("`@("=S971T:6YG)R`]/B!F86QS
M92P*("`@("`@("`G97)R;W(G(#T^("=(;W)D92!W:6QL('=O<FL@=VET:"!S
M97-S:6]N+G5S95]T<F%N<U]S:60@='5R;F5D(&]N+"!B=70@>6]U(&UA>2!S
M964@9&]U8FQE('-E<W-I;VXM:61S(&EN('EO=7(@55),<RP@86YD(&EF('1H
M92!S97-S:6]N(&YA;64@:6X@<&AP+FEN:2!D:69F97)S(&9R;VT@=&AE('-E
M<W-I;VX@;F%M92!C;VYF:6=U<F5D(&EN($AO<F1E+"!Y;W4@;6%Y(&=E="!T
M=V\@<V5S<VEO;B!I9',@86YD('-E92!O=&AE<B!O9&0@8F5H879I;W(N(%1H
M92!54DPM<F5W<FET:6YG('1H870@=7-E7W1R86YS7W-I9"!D;V5S(&%L<V\@
M=&5N9',@=&\@8G)E86L@6$A434P@8V]M<&QI86YC92X@26X@<VAO<G0L('EO
M=2!S:&]U;&0@<F5A;&QY(&1I<V%B;&4@=&AI<RXG"B`@("`I+`H@("`@)W-E
M<W-I;VXN875T;U]S=&%R="<@/3X@87)R87DH"B`@("`@("`@)W-E='1I;F<G
M(#T^(&9A;'-E+`H@("`@("`@("=E<G)O<B<@/3X@)TAO<F1E('=O;EPG="!W
M;W)K('=I=&@@875T;VUA=&EC86QL>2!S=&%R=&5D('-E<W-I;VYS+"!B96-A
M=7-E(&ET(&5X<&QI8VET;'D@8W)E871E<R!N97<@<V5S<VEO;B!W:&5N(&YE
M8V5S<V%R>2!T;R!P<F]T96-T(&%G86EN<W0@<V5S<VEO;B!F:7AA=&EO;G,N
M)PH@("`@*0HI.PH*"B\J(%!%05(@*B\*)'!E87)?;&ES="`](&%R<F%Y*`H@
M("`@)TUA:6PG(#T^(&%R<F%Y*`H@("`@("`@("=P871H)R`]/B`G36%I;"]2
M1D,X,C(N<&AP)RP*("`@("`@("`G97)R;W(G(#T^("=9;W4@9&\@;F]T(&AA
M=F4@=&AE($UA:6P@<&%C:V%G92!I;G-T86QL960@;VX@>6]U<B!S>7-T96TN
M(%-E92!T:&4@24Y35$%,3"!F:6QE(&9O<B!I;G-T<G5C=&EO;G,@;VX@:&]W
M('1O(&EN<W1A;&P@=&AE('!A8VMA9V4N)PH@("`@*2P*("`@("=-86EL7TUI
M;64G(#T^(&%R<F%Y*`H@("`@("`@("=P871H)R`]/B`G36%I;"]M:6UE1&5C
M;V1E+G!H<"<L"B`@("`@("`@)V5R<F]R)R`]/B`G66]U(&1O(&YO="!H879E
M('1H92!-86EL7TUI;64@<&%C:V%G92!I;G-T86QL960@;VX@>6]U<B!S>7-T
M96TN(%-E92!T:&4@24Y35$%,3"!F:6QE(&9O<B!I;G-T<G5C=&EO;G,@;VX@
M:&]W('1O(&EN<W1A;&P@=&AE('!A8VMA9V4N)RP*("`@("`@("`G<F5Q=6ER
M960G(#T^('1R=64*("`@("DL"B`@("`G3&]G)R`]/B!A<G)A>2@*("`@("`@
M("`G<&%T:"<@/3X@)TQO9RYP:'`G+`H@("`@("`@("=E<G)O<B<@/3X@)TUA
M:V4@<W5R92!Y;W4@87)E('5S:6YG(&$@=F5R<VEO;B!O9B!014%2('=H:6-H
M(&EN8VQU9&5S('1H92!,;V<@8VQA<W-E<RP@;W(@=&AA="!Y;W4@:&%V92!I
M;G-T86QL960@=&AE($QO9R!P86-K86=E('-E<&5R871E;'DN(%-E92!T:&4@
M24Y35$%,3"!F:6QE(&9O<B!I;G-T<G5C=&EO;G,@;VX@:6YS=&%L;&EN9R!,
M;V<N)RP*("`@("`@("`G<F5Q=6ER960G(#T^('1R=64L"B`@("`@("`@)V9U
M;F-T:6]N)R`]/B`G7V-H96-K7W!E87)?;&]G7W9E<G-I;VXG"B`@("`I+`H@
M("`@)T1")R`]/B!A<G)A>2@*("`@("`@("`G<&%T:"<@/3X@)T1"+G!H<"<L
M"B`@("`@("`@)V5R<F]R)R`]/B`G66]U('=I;&P@;F5E9"!$0B!I9B!Y;W4@
M87)E('5S:6YG(%-13"!D<FEV97)S(&9O<B!P<F5F97)E;F-E<RP@8V]N=&%C
M=',@*%1U<F)A*2P@971C+B<L"B`@("`@("`@)V9U;F-T:6]N)R`]/B`G7V-H
M96-K7W!E87)?9&)?=F5R<VEO;B<*("`@("DL"B`@("`G3F5T7U-O8VME="<@
M/3X@87)R87DH"B`@("`@("`@)W!A=&@G(#T^("=.970O4V]C:V5T+G!H<"<L
M"B`@("`@("`@)V5R<F]R)R`]/B`G36%K92!S=7)E('EO=2!A<F4@=7-I;F<@
M82!V97)S:6]N(&]F(%!%05(@=VAI8V@@:6YC;'5D97,@=&AE($YE=%]3;V-K
M970@8VQA<W,L(&]R('1H870@>6]U(&AA=F4@:6YS=&%L;&5D('1H92!.971?
M4V]C:V5T('!A8VMA9V4@<V5P97)A=&5L>2X@4V5E('1H92!)3E-404Q,(&9I
M;&4@9F]R(&EN<W1R=6-T:6]N<R!O;B!I;G-T86QL:6YG($YE=%]3;V-K970N
M)PH@("`@*2P*("`@("=$871E)R`]/B!A<G)A>2@*("`@("`@("`G<&%T:"<@
M/3X@)T1A=&4O0V%L8RYP:'`G+`H@("`@("`@("=E<G)O<B<@/3X@)TAO<F1E
M(')E<75I<F5S('1H92!$871E7T-A;&,@8VQA<W,@9F]R($MR;VYO;&ET:"!T
M;R!C86QC=6QA=&4@9&%T97,N)PH@("`@*2P*("`@("=!=71H7U-!4TPG(#T^
M(&%R<F%Y*`H@("`@("`@("=P871H)R`]/B`G075T:"]305-,+G!H<"<L"B`@
M("`@("`@)V5R<F]R)R`]/B`G2&]R9&4@=VEL;"!W;W)K('=I=&AO=70@=&AE
M($%U=&A?4T%33"!C;&%S<RP@8G5T(&EF('EO=2!U<V4@06-C97-S($-O;G1R
M;VP@3&ES=',@:6X@24U0('EO=2!S:&]U;&0@8F4@87=A<F4@=&AA="!W:71H
M;W5T('1H:7,@8VQA<W,@<&%S<W=O<F1S('=I;&P@8F4@<V5N="!T;R!T:&4@
M24U!4"!S97)V97(@:6X@<&QA:6X@=&5X="!W:&5N(')E=')I979I;F<@04-,
M<RXG"B`@("`I+`H@("`@)TA45%!?4F5Q=65S="<@/3X@87)R87DH"B`@("`@
M("`@)W!A=&@G(#T^("=(5%10+U)E<75E<W0N<&AP)RP*("`@("`@("`G97)R
M;W(G(#T^("=087)T<R!O9B!(;W)D92`H2%1-3"!C;VUP;W-I=&EO;B!I;B!)
M35`L($IO;F%H+"!T:&4@6$U,+5)00R!C;&EE;G0O<V5R=F5R*2!U<V4@=&AE
M($A45%!?4F5Q=65S="!L:6)R87)Y('1O(')E=')I979E(%523',@86YD(&1O
M(&]T:&5R($A45%`@<F5Q=65S=',N)PH@("`@*2P*("`@("=&:6QE)R`]/B!A
M<G)A>2@*("`@("`@("`G<&%T:"<@/3X@)T9I;&4N<&AP)RP*("`@("`@("`G
M97)R;W(G(#T^("=(;W)D92!W:6QL(')E<75I<F4@=&AE($9I;&4@8VQA<W,@
M=VAE;B!I;7!O<G1I;F<@0U-6(&9I;&5S+B<*("`@("DL"B`@("`G3F5T7U--
M5%`G(#T^(&%R<F%Y*`H@("`@("`@("=P871H)R`]/B`G3F5T+U--5%`N<&AP
M)RP*("`@("`@("`G97)R;W(G(#T^("=-86ME('-U<F4@>6]U(&%R92!U<VEN
M9R!T:&4@3F5T7U--5%`@;6]D=6QE(&EF('EO=2!W86YT(")S;71P(B!T;R!W
M;W)K(&%S(&$@;6%I;&5R(&]P=&EO;BXG"B`@("`I+`H@("`@)U-E<G9I8V5S
M7U=E871H97(G(#T^(&%R<F%Y*`H@("`@("`@("=P871H)R`]/B`G4V5R=FEC
M97,O5V5A=&AE<BYP:'`G+`H@("`@("`@("=E<G)O<B<@/3X@)U-E<G9I8V5S
M7U=E871H97(@:7,@=7-E9"!B>2!T:&4@=V5A=&AE<B!A<'!L970O8FQO8VL@
M;VX@=&AE('!O<G1A;"!P86=E+B<*("`@("DL"B`@("`G0V%C:&4G(#T^(&%R
M<F%Y*`H@("`@("`@("=P871H)R`]/B`G0V%C:&4N<&AP)RP*("`@("`@("`G
M97)R;W(G(#T^("=#86-H92!I<R!U<V5D(&)Y('1H92!397)V:6-E<U]796%T
M:&5R(&UO9'5L92!O;B!T:&4@=V5A=&AE<B!A<'!L970O8FQO8VL@;VX@=&AE
M('!O<G1A;"!P86=E+B<*("`@("DL"B`@("`G6$U,7U-E<FEA;&EZ97(G(#T^
M(&%R<F%Y*`H@("`@("`@("=P871H)R`]/B`G6$U,+U-E<FEA;&EZ97(N<&AP
M)RP*("`@("`@("`G97)R;W(G(#T^("=834Q?4V5R:6%L:7IE<B!I<R!U<V5D
M(&)Y('1H92!397)V:6-E<U]796%T:&5R(&UO9'5L92!O;B!T:&4@=V5A=&AE
M<B!A<'!L970O8FQO8VL@;VX@=&AE('!O<G1A;"!P86=E+B<*("`@("D**3L*
M"B\J($%D9&ET:6]N86P@8VAE8VL@9F]R(%!%05(@3&]G(&UO9'5L92!F;W(@
M:71S('9E<G-I;VXN("HO"F9U;F-T:6]N(%]C:&5C:U]P96%R7VQO9U]V97)S
M:6]N*"D*>PH@("`@:68@*"%D969I;F5D*"=014%27TQ/1U])3D9/)RDI('L*
M("`@("`@("!R971U<FX@)UEO=7(@=F5R<VEO;B!O9B!,;V<@:7,@;F]T(')E
M8V5N="!E;F]U9V@N)SL*("`@('T*?0H*+RH@061D:71I;VYA;"!C:&5C:R!F
M;W(@4$5!4B!$0B!M;V1U;&4@9F]R(&ET<R!V97)S:6]N+B`J+PIF=6YC=&EO
M;B!?8VAE8VM?<&5A<E]D8E]V97)S:6]N*"D*>PH@("`@:68@*"%D969I;F5D
M*"=$0E]03U)404))3$E465],3U=%4D-!4T4G*2D@>PH@("`@("`@(')E='5R
M;B`G66]U<B!V97)S:6]N(&]F($1"(&ES(&YO="!R96-E;G0@96YO=6=H+B<[
M"B`@("!]"GT*"B\J(%1H97)E(&ES(&$@=F5R<VEO;B!O9B!T:&4@1FEL92YP
M:'`@=&AA="!W86YT<R!A(%!%05(Z.G)E9VES=&5R4VAU=&1O=VY&=6YC"B`J
M('=H:6-H(&ES('=H870@;F5W<&5A<B!T97-T<R!F;W(N("!4:&ES(&9U;F-T
M:6]N('-E96US('1O(&]N;'D@:&%V92!E>&ES=&5D"B`J(&9O<B!A(&QI='1L
M92!W:&EL92P@8G5T('1H92!014%2(&=R;W5P(&AA<VXG="!F:7AE9"!T:&ES
M('EE="P@<V\@<V]M90H@*B!P96]P;&4@9V5T(&%N(&5R<F]R(&EF('1H97D@
M:&%V92!A(&-E<G1A:6X@*')E;&5A<V4I('9E<G-I;VX@;V8@4$5!4BX@(%=E
M"B`J('1E<W0@9F]R(&ET(&AE<F4N("!)9B!I="=S(&$@<V%F92!V97)S:6]N
M+"!T97-T(&%S(&YO<FUA;"P@;W1H97)W:7-E('1R>2!A"B`J(&QE<W,@969F
M96-T:79E(&)U="!N;VXM97)R;W)I;F<@=&5S="!F;W(@1FEL93HZ0U-6+B`J
M+PII9B`H(21H;W)D95]T97-T+3YI<U)E8V5N=%!%05(H*2D@>PH@("`@)'!A
M=&@@/2!I;FE?9V5T*"=I;F-L=61E7W!A=&@G*3L*("`@(&EF("AE;7!T>2@D
M<&%T:"DI('L*("`@("`@("`D<&%T:"`]("<N)SL*("`@('T*("`@("1P96%R
M7VQI<W1;)T9I;&5?0U-6)UU;)W!A=&@G72`]("=86%A86%@N<&AP)SL*("`@
M(&9O<F5A8V@@*&5X<&QO9&4H)SHG+"`D<&%T:"D@87,@)&1I<BD@>PH@("`@
M("`@(&EF("AS=6)S='(H)&1I<BP@+3$I("$]("<O)RD@>PH@("`@("`@("`@
M("`D9&ER("X]("<O)SL*("`@("`@("!]"B`@("`@("`@)&9I;&4Q(#T@)&1I
M<B`N("=&:6QE+T-35BYP:'`G.PH@("`@("`@("1F:6QE,B`]("1D:7(@+B`G
M1FEL92YP:'`G.PH@("`@("`@("1F:6QE,R`]("1D:7(@+B`G4$5!4BYP:'`G
M.PH@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D9FEL93$I("8F(&9I;&5?97AI
M<W1S*"1F:6QE,BD@)B8@9FEL95]E>&ES=',H)&9I;&4S*2D@>PH@("`@("`@
M("`@("`O*B!#:&%N9V4@=&AE(&9I;&5N86UE('1O('-O;65T:&EN9R!W92!K
M;F]W('=I;&P@8F4@9F]U;F0N("HO"B`@("`@("`@("`@("1P96%R7VQI<W1;
M)T9I;&5?0U-6)UU;)W!A=&@G72`]("=014%2+G!H<"<["B`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@('T*("`@('T*?0H*+RH@4F5Q=6ER960@8V]N9FEG
M=7)A=&EO;B!F:6QE<RX@*B\*)&9I;&5?;&ES="`](&%R<F%Y*`H@("`@)V-O
M;F9I9R]C;VYF+G!H<"<@/3X@;G5L;"P*("`@("=C;VYF:6<O;6EM95]D<FEV
M97)S+G!H<"<@/3X@;G5L;"P*("`@("=C;VYF:6<O;FQS+G!H<"<@/3X@;G5L
M;"P*("`@("=C;VYF:6<O<')E9G,N<&AP)R`]/B!N=6QL+`H@("`@)V-O;F9I
M9R]R96=I<W1R>2YP:'`G(#T^(&YU;&P**3L*"@HO*B!'970@=&AE('-T871U
M<R!O=71P=70@;F]W+B`J+PHD;6]D=6QE7V]U='!U="`]("1H;W)D95]T97-T
M+3YP:'!-;V1U;&5#:&5C:R@D;6]D=6QE7VQI<W0I.PHD<V5T=&EN9U]O=71P
M=70@/2`D:&]R9&5?=&5S="T^<&AP4V5T=&EN9T-H96-K*"1S971T:6YG7VQI
M<W0I.PHD<&5A<E]O=71P=70@/2`D:&]R9&5?=&5S="T^4$5!4DUO9'5L94-H
M96-K*"1P96%R7VQI<W0I.PHD8V]N9FEG7V]U='!U="`]("1H;W)D95]T97-T
M+3YR97%U:7)E9$9I;&5#:&5C:R@D9FEL95]L:7-T*3L*"@HO*B!(86YD;&4@
M<W!E8VEA;"!M;V1E<RX@*B\*:68@*"%E;7!T>2@D7T=%5%LG;6]D92==*2D@
M>PH@("`@)'5R;"`]("%E;7!T>2@D7T=%5%LG=7)L)UTI(#\@)%]'151;)W5R
M;"==(#H@)W1E<W0N<&AP)SL*("`@(&5C:&\@)SPA1$]#5%E012!H=&UL(%!5
M0DQ)0R`B+2\O5S-#+R]$5$0@6$A434P@,2XP(%1R86YS:71I;VYA;"\O14XB
M(")$5$0O>&AT;6PQ+71R86YS:71I;VYA;"YD=&0B/B<["B`@("!S=VET8V@@
M*"1?1T546R=M;V1E)UTI('L*("`@(&-A<V4@)V5X=&5N<VEO;G,G.@H@("`@
M("`@(')E<75I<F4@5$535%]414U03$%415,@+B`G97AT96YS:6]N<RYI;F,G
M.PH@("`@("`@(&5X:70["@H@("`@8V%S92`G<&AP:6YF;R<Z"B`@("`@("`@
M96-H;R`G/&$@:')E9CTB)R`N(&AT;6QS<&5C:6%L8VAA<G,H)'5R;"D@+B`G
M/VUO9&4]=&5S="(^)FQT.R9L=#L@0F%C:R!T;R!T97-T+G!H<#PO83XG.PH@
M("`@("`@('!H<&EN9F\H*3L*("`@("`@("!E>&ET.PH*("`@(&-A<V4@)V9I
M;&5T97-T)SH*("`@("`@("!E8VAO("<\82!H<F5F/2(G("X@:'1M;'-P96-I
M86QC:&%R<R@D=7)L*2`N("<_;6]D93UT97-T(CXF;'0[)FQT.R!"86-K('1O
M('1E<W0N<&AP/"]A/B<["B`@("`@("`@/SX*("`@("`@("`\:'1M;#X*("`@
M("`@("`\8F]D>2!B9V-O;&]R/2)W:&ET92(@=&5X=#TB8FQA8VLB/@H@("`@
M("`@(#QP/CQF;VYT(&9A8V4](DAE;'9E=&EC82P@07)I86PL('-A;G,M<V5R
M:68B('-I>F4](C(B/@H@("`@("`@(%1H97)E(&%R92!S;VUE('9E<G-I;VYS
M(&]F(%!%05(@=&AA="!W97)E(')E;&5A<V5D(&%T('1I;65S('1H870*("`@
M("`@("!D:60@;F]T(&-O;G1A:6X@82!F=6YC=&EO;B!T:&%T($9I;&4N<&AP
M(&5X<&5C=',N("!4:&ES(&1O97,@;F]T"B`@("`@("`@<V5E;2!T;R!H879E
M(&-A=7-E9"!P<F]B;&5M<R!F;W(@86YY;VYE(&5X8V5P="!W:&5N(')U;FYI
M;F<@;W5R"B`@("`@("`@=&5S="!S8W)I<'0L(&)U="!Y;W4@;F5E9"!T;R!B
M92!A=V%R92!O9B!I="X@($EF('EO=2!S964@82!F871A;`H@("`@("`@(&5R
M<F]R(&EN($9I;&4N<&AP(&QI<W1E9"!B96QO=R!T:&ES('1E>'0L('EO=2!H
M879E(&]N92!O9B!T:&4*("`@("`@("!C;VUB:6YA=&EO;G,@;V8@<')O8FQE
M;2!F:6QE<RX@($UA:V4@<W5R92!Y;W4@:&%V92!T:&4@;&%T97-T"B`@("`@
M("`@4$5!4B!A;F0@1FEL92!P86-K86=E<R!A=F%I;&%B;&4@*#QA(&AR968]
M(FAT='`Z+R]P96%R+G!H<"YN970O(CX*("`@("`@("!S964@:'1T<#HO+W!E
M87(N<&AP+FYE=#PO83XI+B`@268@>6]U(&1O(&YO="!G970@=&AE(&5R<F]R
M+"!Y;W4@87)E"B`@("`@("`@:6X@9FEN92!S:&%P92X\+W`^"B`@("`@("`@
M/#]P:'`@:6YC;'5D95]O;F-E("=&:6QE+T-35BYP:'`G.PH@("`@("`@(&5X
M:70["@H@("`@8V%S92`G=6YR96=I<W1E<B<Z"B`@("`@("`@=6YS970H)%]3
M15-324].6R=H;W)D95]T97-T7V-O=6YT)UTI.PH@("`@("`@(#\^"B`@("`@
M("`@/&AT;6P^"B`@("`@("`@/&)O9'D@8F=C;VQO<CTB=VAI=&4B('1E>'0]
M(F)L86-K(CX*("`@("`@("`\9F]N="!F86-E/2)(96QV971I8V$L($%R:6%L
M+"!S86YS+7-E<FEF(B!S:7IE/2(R(CX*("`@("`@("!4:&4@=&5S="!S97-S
M:6]N(&AA<R!B965N('5N<F5G:7-T97)E9"X\8G(^"B`@("`@("`@/&$@:')E
M9CTB=&5S="YP:'`B/D=O(&)A8VL\+V$^('1O('1H92!T97-T+G!H<"!P86=E
M+CQB<CX*("`@("`@("`\/W!H<`H@("`@("`@(&5X:70["B`@("!]"GT*"G)E
M<75I<F4@5$535%]414U03$%415,@+B`G:&5A9&5R+FEN8R<["G)E<75I<F4@
M5$535%]414U03$%415,@+B`G=F5R<VEO;BYI;F,G.PH*/SX*"CQH,3Y(;W)D
M92!!<'!L:6-A=&EO;G,\+V@Q/@H\=6P^"CP_<&AP"@HO*B!'970@2&]R9&4@
M;6]D=6QE('9E<G-I;VX@:6YF;W)M871I;VXN("HO"B1M;V1U;&5S(#T@)&AO
M<F1E7W1E<W0M/F%P<&QI8V%T:6]N3&ES="@I.PIF;W)E86-H("@D;6]D=6QE
M<R!A<R`D87!P(#T^("1V86PI('L*("`@("1A<'`@/2!U8V9I<G-T*"1A<'`I
M.PH@("`@96-H;R`G/&QI/B<@+B`D87!P("X@)SH@)R`N("1V86PM/G9E<G-I
M;VX["B`@("!I9B`H:7-S970H)'9A;"T^=&5S="DI('L*("`@("`@("!E8VAO
M("<@*#QA(&AR968](B<@+B`D=F%L+3YT97-T("X@)R(^<G5N("<@+B`D87!P
M("X@)R!T97-T<SPO83XI)SL*("`@('T*("`@(&5C:&\@(CPO;&D^7&XB.PI]
M"@H_/@H\+W5L/@H*/#]P:'`*"B\J($1I<W!L87D@4$A0(%9E<G-I;VX@:6YF
M;W)M871I;VXN("HO"B1P:'!?:6YF;R`]("1H;W)D95]T97-T+3YG9710:'!6
M97)S:6]N26YF;W)M871I;VXH*3L*<F5Q=6ER92!415-47U1%35!,051%4R`N
M("=P:'!?=F5R<VEO;BYI;F,G.PH*/SX*"CQH,3Y02%`@36]D=6QE($-A<&%B
M:6QI=&EE<SPO:#$^"CQU;#X*("`@(#P_<&AP(&5C:&\@)&UO9'5L95]O=71P
M=70@/SX*/"]U;#X*"CQH,3Y-:7-C96QL86YE;W5S(%!(4"!3971T:6YG<SPO
M:#$^"CQU;#X*("`@(#P_<&AP(&5C:&\@)'-E='1I;F=?;W5T<'5T(#\^"CPO
M=6P^"@H\:#$^1FEL92!5<&QO861S/"]H,3X*/'5L/@H@("`@/#]P:'`@96-H
M;R`D:&]R9&5?=&5S="T^<&AP4V5T=&EN9T-H96-K*&%R<F%Y*"=F:6QE7W5P
M;&]A9',G(#T^(&%R<F%Y*"=S971T:6YG)R`]/B!T<G5E+"`G97)R;W(G(#T^
M("=F:6QE7W5P;&]A9',@;75S="!B92!E;F%B;&5D(&9O<B!S;VUE(&9E871U
M<F5S(&QI:V4@<V5N9&EN9R!E;6%I;',@=VET:"!)35`N)R`I*2D@/SX*/#]P
M:'`@:68@*"1D:7(@/2!I;FE?9V5T*"=U<&QO861?=&UP7V1I<B<I*3H@/SX*
M("`@(#QL:3YU<&QO861?=&UP7V1I<CH@/&9O;G0@8V]L;W(](CP_<&AP(&5C
M:&\@:7-?=W)I=&%B;&4H)&1I<BD@/R`G9W)E96XG(#H@)W)E9"<@/SXB/CQS
M=')O;F<^/#]P:'`@96-H;R`D9&ER(#\^/"]S=')O;F<^/"]F;VYT/CPO;&D^
M"CP_<&AP(&5N9&EF.R`_/@H@("`@/&QI/G5P;&]A9%]M87A?9FEL97-I>F4Z
M(#P_<&AP(&5C:&\@:6YI7V=E="@G=7!L;V%D7VUA>%]F:6QE<VEZ92<I(#\^
M/"]L:3X*("`@(#QL:3YP;W-T7VUA>%]S:7IE.B`\/W!H<"!E8VAO(&EN:5]G
M970H)W!O<W1?;6%X7W-I>F4G*2`_/CPO;&D^"CPO=6P^"@H\:#$^4F5Q=6ER
M960@2&]R9&4@0V]N9FEG=7)A=&EO;B!&:6QE<SPO:#$^"CQU;#X*("`@(#P_
M<&AP(&5C:&\@)&-O;F9I9U]O=71P=70@/SX*/"]U;#X*"CQH,3Y02%`@4V5S
M<VEO;G,\+V@Q/@H\/W!H<"`D7U-%4U-)3TY;)VAO<F1E7W1E<W1?8V]U;G0G
M72LK.R`_/@H\=6P^"B`@("`\;&D^4V5S<VEO;B!C;W5N=&5R.B`\/W!H<"!E
M8VAO("1?4T534TE/3ELG:&]R9&5?=&5S=%]C;W5N="==.R`_/CPO;&D^"B`@
M("`\;&D^5&\@=6YR96=I<W1E<B!T:&4@<V5S<VEO;CH@/&$@:')E9CTB=&5S
M="YP:'`_;6]D93UU;G)E9VES=&5R(CYC;&EC:R!H97)E/"]A/CPO;&D^"CPO
M=6P^"@H\:#$^4$5!4CPO:#$^"CQU;#X*("`@(#P_<&AP(&5C:&\@)'!E87)?
M;W5T<'5T(#\^"CPO=6P^"@H\/W!H<`IR97%U:7)E(%1%4U1?5$5-4$Q!5$53
M("X@)V9O;W1E<BYI;F,G.PH`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<VEG;G5P+G!H
M<```````````````````````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`T-S`W(#$P-3$U-#,S-S,T(#`Q-S4V-@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@)$AO
M<F1E.B!H;W)D92]S:6=N=7`N<&AP+'8@,2XQ-RXQ,"XX(#(P,#8O,#$O,#$@
M,C$Z,C@Z,#0@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@
M36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M+PH*0&1E9FEN92@G05542%](04Y$3$52)RP@=')U92D["D!D969I;F4H)TA/
M4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2D["G)E<75I<F5?;VYC92!(
M3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO
M<F1E+T%U=&@O4VEG;G5P+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O5F%R
M:6%B;&5S+G!H<"<["@HD875T:"`]("9!=71H.CIS:6YG;&5T;VXH)&-O;F9;
M)V%U=&@G75LG9')I=F5R)UTI.PH*+R\@36%K92!S=7)E('-I9VYU<',@87)E
M(&5N86)L960@8F5F;W)E('!R;V-E961I;F<*:68@*"1C;VYF6R=S:6=N=7`G
M75LG86QL;W<G72`A/3T@=')U92!\?`H@("`@(21A=71H+3YH87-#87!A8FEL
M:71Y*"=A9&0G*2D@>PH@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")5<V5R
M(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E
M+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@(&AE861E<B@G3&]C871I;VXZ("<@
M+B!!=71H.CIG971,;V=I;E-C<F5E;B@I*3L*("`@(&5X:70["GT*"B1V87)S
M(#T@)E9A<FEA8FQE<SHZ9V5T1&5F875L=%9A<FEA8FQE<R@I.PHD<VEG;G5P
M(#T@)D%U=&A?4VEG;G5P.CIS:6YG;&5T;VXH*3L*)')E;F1E<F5R(#T@)FYE
M=R!(;W)D95]&;W)M7U)E;F1E<F5R*"D["@HD9F]R;7-I9VYU<"`]("9(;W)D
M95]&;W)M.CIS:6YG;&5T;VXH)TAO<F1E4VEG;G5P1F]R;2<L("1V87)S*3L*
M)&9O<FUS:6=N=7`M/G9A;&ED871E*"1V87)S*3L*"FEF("@D=F%R<RT^9V5T
M*"=F;W)M;F%M92<I("$]("=H;W)D97-I9VYU<&9O<FTG*2!["B`@("`O*B!.
M;W0@>65T('-U8FUI='1E9"X@*B\*("`@("1F;W)M<VEG;G5P+3YC;&5A<E9A
M;&ED871I;VXH*3L*?0H*:68@*"1F;W)M<VEG;G5P+3YI<U9A;&ED*"D@)B8@
M)'9A<G,M/F=E="@G9F]R;6YA;64G*2`]/2`G:&]R9&5S:6=N=7!F;W)M)RD@
M>PH@("`@)&9O<FUS:6=N=7`M/F=E=$EN9F\H)'9A<G,L("1I;F9O*3L*"B`@
M("!I9B`H(21C;VYF6R=S:6=N=7`G75LG87!P<F]V92==*2!["B`@("`@("`@
M+RH@57-E<B!C86X@<VEG;B!U<"!D:7)E8W1L>2P@;F\@:6YT97)V96YT:6]N
M(&YE8V5S<V%R>2X@*B\*("`@("`@("`D<W5C8V5S<R`]("1S:6=N=7`M/F%D
M9%-I9VYU<"@D:6YF;RD["B`@("`@("`@)'-U8V-E<W-?;65S<V%G92`]('-P
M<FEN=&8H7R@B061D960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@
M;&]G(&EN(&YO=RXB*2P@)&EN9F];)W5S97)?;F%M92==*3L*("`@('T@96QS
M96EF("@D8V]N9ELG<VEG;G5P)UU;)V%P<')O=F4G72D@>PH@("`@("`@("\J
M($EN<V5R="!T:&ES('5S97(@:6YT;R!A('%U975E(&9O<B!A9&UI;B!A<'!R
M;W9A;"X@*B\*("`@("`@("`D<W5C8V5S<R`]("1S:6=N=7`M/G%U975E4VEG
M;G5P*"1I;F9O*3L*("`@("`@("`D<W5C8V5S<U]M97-S86=E(#T@<W!R:6YT
M9BA?*")3=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O('1H92!S
M>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@<F5Q=65S="!H
M87,@8F5E;B!A<'!R;W9E9"XB*2P@)&EN9F];)W5S97)?;F%M92==*3L*("`@
M('T*"B`@("!I9B`H:7-?82@D<W5C8V5S<RP@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")4:&5R92!W
M87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B
M*2P@)&EN9F];)W5S97)?;F%M92==+"`D<W5C8V5S<RT^9V5T365S<V%G92@I
M*2P@)VAO<F1E+F5R<F]R)RD["B`@("!](&5L<V4@>PH@("`@("`@("1N;W1I
M9FEC871I;VXM/G!U<V@H)'-U8V-E<W-?;65S<V%G92P@)VAO<F1E+G-U8V-E
M<W,G*3L*("`@("`@("`D=7)L(#T@075T:#HZ9V5T3&]G:6Y38W)E96XH)R<L
M("1I;F9O6R=U<FPG72D["B`@("`@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N
M("1U<FPI.PH@("`@("`@(&5X:70["B`@("!]"GT*"B1T:71L92`](%\H(E5S
M97(@4F5G:7-T<F%T:6]N(BD["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@
M)R]C;VUM;VXM:&5A9&5R+FEN8R<["B1N;W1I9FEC871I;VXM/FYO=&EF>2AA
M<G)A>2@G;&ES=&5N97)S)R`]/B`G<W1A='5S)RDI.PHD9F]R;7-I9VYU<"T^
M<F5N9&5R06-T:79E*"1R96YD97)E<BP@)'9A<G,L("=S:6=N=7`N<&AP)RP@
M)W!O<W0G*3L*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUF
M;V]T97(N:6YC)SL*````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<G!C+G!H<```````````````````````````````````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`U-34S(#$P-3$U-#,S-S,T(#`Q-S`T-0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@)$AO<F1E.B!H;W)D92]R<&,N<&AP+'8@,2XS,"XQ,"XS(#(P
M,#8O,#$O,#$@,C$Z,C@Z,#0@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`R+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J+PH*0&1E9FEN92@G05542%](04Y$3$52)RP@=')U92D["D!D
M969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2D["G)E<75I
M<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8V]R92YP:'`G.PIR97%U:7)E
M7V]N8V4@)TAO<F1E+U)00RYP:'`G.PH*+RH@3&]O:R!A="!T:&4@0V]N=&5N
M="UT>7!E(&]F('1H92!R97%U97-T+"!I9B!I="!I<R!A=F%I;&%B;&4L('1O
M('1R>0H@*B!A;F0@9&5T97)M:6YE('=H870@:VEN9"!O9B!R97%U97-T('1H
M:7,@:7,N("HO"B1I;G!U="`](&YU;&P["B1P87)A;7,@/2!N=6QL.PH*:68@
M*"%E;7!T>2@D7U-%4E9%4ELG4$%42%])3D9/)UTI('Q\"B`@("!I;E]A<G)A
M>2@D7U-%4E9%4ELG4D5154535%]-151(3T0G72P@87)R87DH)U!23U!&24Y$
M)RDI*2!["B`@("`D<V5R=F5R5'EP92`]("=W96)D878G.PI](&5L<V5I9B`H
M:7-S970H)%]315)615);)U)%455%4U1?34542$]$)UTI("8F"B`@("`@("`@
M("`D7U-%4E9%4ELG4D5154535%]-151(3T0G72`]/2`G1T54)R`F)@H@("`@
M("`@("`@571I;#HZ9V5T1V5T*"=R97-T0V%L;"<I*2!["B`@("`D<V5R=F5R
M5'EP92`]("=R97-T)SL*?2!E;'-E:68@*"%E;7!T>2@D7U-%4E9%4ELG0T].
M5$5.5%]465!%)UTI*2!["B`@("!I9B`H<W1R<&]S*"1?4T525D526R=#3TY4
M14Y47U194$4G72P@)V%P<&QI8V%T:6]N+W9N9"YS>6YC;6PK>&UL)RD@(3T]
M(&9A;'-E*2!["B`@("`@("`@)'-E<G9E<E1Y<&4@/2`G<WEN8VUL)SL*("`@
M("`@("`O*B!3>6YC;6P@9&]E<R!I=',@;W=N('-E<W-I;VX@:&%N9&QI;F<N
M("HO"B`@("`@("`@)'-E<W-I;VY?8V]N=')O;"`]("=N;VYE)SL*("`@('T@
M96QS96EF("AS=')P;W,H)%]315)615);)T-/3E1%3E1?5%E012==+"`G87!P
M;&EC871I;VXO=FYD+G-Y;F-M;"MW8GAM;"<I("$]/2!F86QS92D@>PH@("`@
M("`@("1S97)V97)4>7!E(#T@)W-Y;F-M;%]W8GAM;"<["B`@("`@("`@+RH@
M4WEN8VUL(&1O97,@:71S(&]W;B!S97-S:6]N(&AA;F1L:6YG+B`J+PH@("`@
M("`@("1S97-S:6]N7V-O;G1R;VP@/2`G;F]N92<["B`@("!](&5L<V5I9B`H
M<W1R<&]S*"1?4T525D526R=#3TY414Y47U194$4G72P@)W1E>'0O>&UL)RD@
M(3T](&9A;'-E*2!["B`@("`@("`@)&EN<'5T(#T@2&]R9&5?4E!#.CIG971)
M;G!U="@I.PH@("`@("`@("\J($-H96-K(&9O<B!33T%0(&YA;65S<&%C92!5
M4DDN("HO"B`@("`@("`@:68@*'-T<G!O<R@D:6YP=70L("=H='1P.B\O<V-H
M96UA<RYX;6QS;V%P+F]R9R]S;V%P+V5N=F5L;W!E+R<I("$]/2!F86QS92D@
M>PH@("`@("`@("`@("`D<V5R=F5R5'EP92`]("=S;V%P)SL*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D<V5R=F5R5'EP92`]("=X;6QR<&,G.PH@
M("`@("`@('T*("`@('T@96QS92!["B`@("`@("`@:&5A9&5R*"=(5%10+S$N
M,"`U,#$@3F]T($EM<&QE;65N=&5D)RD["B`@("`@("`@97AI=#L*("`@('T*
M?2!E;'-E('L*("`@("1S97)V97)4>7!E(#T@)W-O87`G.PI]"@II9B`H)'-E
M<G9E<E1Y<&4@/3T@)W-O87`G("8F"B`@("`H(6ES<V5T*"1?4T525D526R=2
M15%515-47TU%5$A/1"==*2!\?`H@("`@("1?4T525D526R=215%515-47TU%
M5$A/1"==("$]("=03U-4)RDI('L*("`@("1S97-S:6]N7V-O;G1R;VP@/2`G
M;F]N92<["B`@("!I9B`H:7-S970H)%]'151;)W=S9&PG72DI('L*("`@("`@
M("`D<&%R86US(#T@)W=S9&PG.PH@("`@?2!E;'-E('L*("`@("`@("`D<&%R
M86US(#T@)V1I<V-O)SL*("`@('T*?0H*+RH@3&]A9"!B87-E(&QI8G)A<FEE
M<RX@*B\*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H
M<"<["@HO*B!,;V%D('1H92!24$,@8F%C:V5N9"!B87-E9"!O;B`D<V5R=F5R
M5'EP92X@*B\*)'-E<G9E<B`]("9(;W)D95]24$,Z.G-I;F=L971O;B@D<V5R
M=F5R5'EP92P@)'!A<F%M<RD["@HO*B!,970@=&AE(&)A8VME;F0@8VAE8VL@
M875T:&5N=&EC871I;VXN($)Y(&1E9F%U;'0L('=E(&QO;VL@9F]R($A45%`*
M("H@8F%S:6,@875T:&5N=&EC871I;VX@86=A:6YS="!(;W)D92P@8G5T(&)A
M8VME;F1S(&-A;B!O=F5R<FED92!T:&ES"B`J(&%S(&YE961E9"X@*B\*)'-E
M<G9E<BT^875T:&]R:7IE*"D["@HO*B!'970@=&AE('-E<G9E<B=S(')E<W!O
M;G-E+B!792!C86QL("1S97)V97(M/F=E=$EN<'5T*"D@=&\@86QL;W<*("H@
M8F%C:V5N9',@=&\@:&%N9&QE(&EN<'5T('!R;V-E<W-I;F<@9&EF9F5R96YT
M;'DN("HO"FEF("@D:6YP=70@/3T](&YU;&PI('L*("`@("1I;G!U="`]("1S
M97)V97(M/F=E=$EN<'5T*"D["GT*"B1O=70@/2`D<V5R=F5R+3YG971297-P
M;VYS92@D:6YP=70L("1P87)A;7,I.PH*:68@*&ES7V$H)&]U="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@:&5A9&5R*"=(5%10+S$N,"`U,#`@26YT97)N86P@
M4V5R=F5R($5R<F]R)RD["B`@("!E>&ET.PI]"@HO*B!2971U<FX@=&AE(')E
M<W!O;G-E('1O('1H92!C;&EE;G0N("HO"FAE861E<B@G0V]N=&5N="U4>7!E
M.B`G("X@)'-E<G9E<BT^9V5T4F5S<&]N<V5#;VYT96YT5'EP92@I*3L*:&5A
M9&5R*"=#;VYT96YT+6QE;F=T:#H@)R`N('-T<FQE;B@D;W5T*2D["FAE861E
M<B@G06-C97!T+4-H87)S970Z(%541BTX)RD["F5C:&\@)&]U=#L*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V=I;BYP:'``````
M````````````````````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,38Q,C<@,3`U,34T,S,W,S0@,#$W,S<P`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z
M(&AO<F1E+VQO9VEN+G!H<"QV(#(N,3<U+C(N,3$@,C`P-B\P,2\Q-B`Q-3HU
M-SHU,R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:&%R
M;&5S($HN($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG
M:'0@,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*B\*"D!D969I;F4H)T%55$A?2$%.1$Q%4B<L('1R=64I.PI`
M9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RDI.PIR97%U
M:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*<F5Q=6ER
M95]O;F-E("=(;W)D92]-96YU+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O
M4V5C<F5T+G!H<"<["@HO*B!);FET:6%L:7IE('1H92!!=71H(&-R961E;G1I
M86QS(&ME>2X@*B\*4V5C<F5T.CIS971+97DH)V%U=&@G*3L*"B\J($=E="!A
M;B!!=71H(&]B:F5C="X@*B\*)&%U=&@@/2`F075T:#HZ<VEN9VQE=&]N*"1C
M;VYF6R=A=71H)UU;)V1R:79E<B==*3L*:68@*&ES7V$H)&%U=&@L("=014%2
M7T5R<F]R)RDI('L*("`@($AO<F1E.CIF871A;"@D875T:"P@7U]&24Q%7U\L
M(%]?3$E.15]?*3L*?0H*+RH@1V5T('!A<F%M971E<G,N("HO"B1L;V=O=71?
M<F5A<V]N(#T@)&%U=&@M/F=E=$QO9V]U=%)E87-O;B@I.PHD=7)L7W!A<F%M
M(#T@571I;#HZ9V5T1F]R;41A=&$H)W5R;"<I.PHD:65?=F5R<VEO;B`](%5T
M:6PZ.F=E=$9O<FU$871A*"=I95]V97)S:6]N)RD["@II9B`H)&QO9V]U=%]R
M96%S;VXI('L*("`@("1L;V=I;E]S8W)E96X@/2`D875T:"T^9V5T3&]G:6Y3
M8W)E96XH*3L*("`@(&EF("A5=&EL.CIG971&;W)M1&%T82@G;F]S:61E8F%R
M)RD@)B8*("`@("`@("!I<W-E="@D1TQ/0D%,4ULG;F]T:69I8V%T:6]N)UTI
M*2!["B`@("`@("`@)'5R;"`]($%U=&@Z.F%D9$QO9V]U=%!A<F%M971E<G,H
M)&QO9VEN7W-C<F5E;BD["B`@("`@("`@:68@*"1U<FQ?<&%R86TI('L*("`@
M("`@("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`G=7)L
M)RP@)'5R;%]P87)A;2D["B`@("`@("`@?0H@("`@("`@("1N;W1I9FEC871I
M;VXM/G!U<V@H)W=I;F1O=RYP87)E;G0N;&]C871I;VXN:')E9B`](%PG)R`N
M("1U<FP@+B`G7"<[)RP@)VIA=F%S8W)I<'0G*3L*("`@("`@("!E8VAO("<\
M:'1M;#X\8F]D>3XG("X@)$=,3T)!3%-;)VYO=&EF:6-A=&EO;B==+3YN;W1I
M9GDH87)R87DH)VQI<W1E;F5R<R<@/3X@87)R87DH)VIA=F%S8W)I<'0G*2DI
M("X@)SPO8F]D>3X\+VAT;6P^)SL*("`@("`@("!E>&ET.PH@("`@?0H*("`@
M(&EF("A5=&EL.CIR96UO=F5087)A;65T97(H)&QO9VEN7W-C<F5E;BP@87)R
M87DH)W5R;"<L("=N;V-A8VAE)RDI("$]"B`@("`@("`@571I;#HZ<F5M;W9E
M4&%R86UE=&5R*$AO<F1E.CIS96QF57)L*&9A;'-E+"!F86QS92P@=')U92DL
M(&%R<F%Y*"=U<FPG+"`G;F]C86-H92<I*2D@>PH@("`@("`@("1U<FP@/2!!
M=71H.CIA9&1,;V=O=71087)A;65T97)S*"1L;V=I;E]S8W)E96XI.PH@("`@
M("`@(&EF("@D=7)L7W!A<F%M*2!["B`@("`@("`@("`@("1U<FP@/2!5=&EL
M.CIA9&1087)A;65T97(H)'5R;"P@)W5R;"<L("1U<FQ?<&%R86TI.PH@("`@
M("`@('T*("`@("`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@)'5R;"D["B`@
M("`@("`@97AI=#L*("`@('T*"B`@("`D;&%N9W5A9V4@/2!I<W-E="@D<')E
M9G,I(#\@)'!R969S+3YG971686QU92@G;&%N9W5A9V4G*2`Z($Y,4SHZ<V5L
M96-T*"D["@H@("`@)&5N=')Y(#T@<W!R:6YT9B@G57-E<B`E<R!;)7-=(&QO
M9V=E9"!O=70@;V8@2&]R9&4G+`H@("`@("`@("`@("`@("`@("`@("!!=71H
M.CIG971!=71H*"DL("1?4T525D526R=214U/5$5?041$4B==*3L*("`@($AO
M<F1E.CIL;V=-97-S86=E*"1E;G1R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!0
M14%27TQ/1U].3U1)0T4I.PH@("`@075T:#HZ8VQE87)!=71H*"D["B`@("!`
M<V5S<VEO;E]D97-T<F]Y*"D["@H@("`@+RH@4F5D:7)E8W0@=&AE('5S97(@
M;VX@;&]G;W5T(&EF(')E9&ER96-T:6]N(&ES(&5N86)L960N("HO"B`@("!I
M9B`H(65M<'1Y*"1C;VYF6R=A=71H)UU;)W)E9&ER96-T7V]N7VQO9V]U="==
M*2D@>PH@("`@("`@("1L;V=O=71?=7)L(#T@)&-O;F9;)V%U=&@G75LG<F5D
M:7)E8W1?;VY?;&]G;W5T)UT["B`@("`@("`@:68@*"%I<W-E="@D7T-/3TM)
M15MS97-S:6]N7VYA;64H*5TI*2!["B`@("`@("`@("`@("1L;V=O=71?=7)L
M(#T@571I;#HZ861D4&%R86UE=&5R*"1L;V=O=71?=7)L+"!S97-S:6]N7VYA
M;64H*2P@<V5S<VEO;E]I9"@I*3L*("`@("`@("!]"B`@("`@("`@:&5A9&5R
M*"=,;V-A=&EO;CH@)R`N("1L;V=O=71?=7)L*3L*("`@("`@("!E>&ET.PH@
M("`@?0H*("`@($AO<F1E.CIS971U<%-E<W-I;VY(86YD;&5R*"D["B`@("!`
M<V5S<VEO;E]S=&%R="@I.PH*("`@($Y,4SHZ<V5T3&%N9R@D;&%N9W5A9V4I
M.PH*("`@("\J($AO;VL@=&\@<')E<V5L96-T('1H92!C;W)R96-T(&QA;F=U
M86=E(&EN('1H92!W:61G970N("HO"B`@("`D7T=%5%LG;F5W7VQA;F<G72`]
M("1L86YG=6%G93L*?0H*:68@*&ES<V5T*"1?4$]35%LG:&]R9&5?=7-E<B==
M*2`F)B!I<W-E="@D7U!/4U1;)VAO<F1E7W!A<W,G72DI('L*("`@("\J($1E
M<W1R;WD@86YY(&5X:7-T:6YG('-E<W-I;VX@;VX@;&]G:6X@86YD(&UA:V4@
M<W5R92!T;R!U<V4@80H@("`@("H@;F5W('-E<W-I;VX@240L('1O(&%V;VED
M('-E<W-I;VX@9FEX871I;VX@:7-S=65S+B`J+PH@("`@2&]R9&4Z.F=E=$-L
M96%N4V5S<VEO;B@I.PH@("`@:68@*"1A=71H+3YA=71H96YT:6-A=&4H571I
M;#HZ9V5T4&]S="@G:&]R9&5?=7-E<B<I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@87)R87DH)W!A<W-W;W)D)R`]/B!5=&EL.CIG9710;W-T*"=H
M;W)D95]P87-S)RDI*2D@>PH@("`@("`@("1E;G1R>2`]('-P<FEN=&8H)TQO
M9VEN('-U8V-E<W,@9F]R("5S(%LE<UT@=&\@2&]R9&4G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@075T:#HZ9V5T075T:"@I+"`D7U-%4E9%4ELG4D5-
M3U1%7T%$1%(G72D["B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)&5N=')Y
M+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7TY/5$E#12D["@H@("`@
M("`@(&EF("@D:65?=F5R<VEO;BD@>PH@("`@("`@("`@("`D8G)O=W-E<BT^
M<V5T245697)S:6]N*"1I95]V97)S:6]N*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("@D=7)L7W!A<F%M*2!["B`@("`@("`@("`@("1U<FP@/2!(;W)D93HZ
M=7)L*%5T:6PZ.G)E;6]V95!A<F%M971E<B@D=7)L7W!A<F%M+"!S97-S:6]N
M7VYA;64H*2DL('1R=64I.PH@("`@("`@("`@("`D:&]R9&5?=7)L(#T@)')E
M9VES=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O:6YD97@N<&AP
M)SL*("`@("`@("`@("`@)&AO<F1E7W5R;"`](%5T:6PZ.F%D9%!A<F%M971E
M<B@D:&]R9&5?=7)L+"`G=7)L)RP@)'5R;"D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&AO<F1E7W5R;"`]($AO<F1E.CIU<FPH)')E9VES=')Y
M+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O:6YD97@N<&AP)RD["B`@
M("`@("`@?0H*("`@("`@("`D=7)L(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L
M*"1H;W)D95]U<FPL('1R=64I.PH@("`@("`@(&EF("@D8G)O=W-E<BT^:7-"
M<F]W<V5R*"=M<VEE)RD@)B8*("`@("`@("`@("`@)&-O;F9;)W5S95]S<VPG
M72`]/2`S("8F"B`@("`@("`@("`@('-T<FQE;B@D=7)L*2`\(#$V,"D@>PH@
M("`@("`@("`@("!H96%D97(H)U)E9G)E<V@Z(#`[(%523#TG("X@)'5R;"D[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:&5A9&5R*"=,;V-A=&EO
M;CH@)R`N("1U<FPI.PH@("`@("`@('T*("`@("`@("!E>&ET.PH@("`@?2!E
M;'-E('L*("`@("`@("`D96YT<GD@/2!S<')I;G1F*"=&04E,140@3$]'24X@
M9F]R("5S(%LE<UT@=&\@2&]R9&4G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@571I;#HZ9V5T1F]R;41A=&$H)VAO<F1E7W5S97(G*2P@)%]315)615);
M)U)%34]415]!1$12)UTI.PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1E
M;G1R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@
M("`@(&EF("@D8V]N9ELG;65N=2==6R=A;'=A>7,G72D@>PH@("`@("`@("`@
M("`D;6%I;E]P86=E(#T@571I;#HZ861D4&%R86UE=&5R*$AO<F1E.CIS96QF
M57)L*"DL("=R96%S;VXG+"`D875T:"T^9V5T3&]G;W5T4F5A<V]N4W1R:6YG
M*"DI.PH@("`@("`@("`@("!I9B`H)&)R;W=S97(M/FAA<U%U:7)K*"=S8W)O
M;&QB87)?:6Y?=V%Y)RDI('L*("`@("`@("`@("`@("`@("1S8W)O;&QB87(@
M/2`G>65S)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1S8W)O;&QB87(@/2`G875T;R<["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+VEN9&5X+V9R86UE<U]I
M;F1E>"YI;F,G.PH@("`@("`@("`@("!E>&ET.PH@("`@("`@('T*("`@('T*
M?0H*:68@*$%U=&@Z.F=E=$%U=&@H*2D@>PH@("`@:68@*"1B<F]W<V5R+3YI
M<TUO8FEL92@I*2!["B`@("`@("`@)'5R;"`]("=S97)V:6-E<R]P;W)T86PO
M;6]B:6QE+G!H<"<["B`@("!](&5L<V4@>PH@("`@("`@("1U<FP@/2`G<V5R
M=FEC97,O<&]R=&%L+VEN9&5X+G!H<"<["B`@("!]"B`@("!R97%U:7)E($A/
M4D1%7T)!4T4@+B`G+R<@+B`D=7)L.PH@("`@97AI=#L*?0H*+RH@5')Y('1R
M86YS<&%R96YT(&%U=&AE;G1I8V%T:6]N+B`J+PII9B`H075T:#HZ:7-!=71H
M96YT:6-A=&5D*"DI('L*("`@(')E<75I<F4@2$]21$5?0D%312`N("<O:6YD
M97@N<&AP)SL*("`@(&5X:70["GT*"B\J(%)E9&ER96-T('1H92!U<V5R(&EF
M(&%N(&%L=&5R;F%T92!L;V=I;B!P86=E(&AA<R!B965N('-P96-I9FEE9"X@
M*B\*:68@*"%E;7!T>2@D8V]N9ELG875T:"==6R=A;'1E<FYA=&5?;&]G:6XG
M72DI('L*("`@("1U<FP@/2!!=71H.CIA9&1,;V=O=71087)A;65T97)S*"1C
M;VYF6R=A=71H)UU;)V%L=&5R;F%T95]L;V=I;B==*3L*("`@(&EF("@A:7-S
M970H)%]#3T]+245;<V5S<VEO;E]N86UE*"E=*2D@>PH@("`@("`@("1U<FP@
M/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@<V5S<VEO;E]N86UE*"DL('-E
M<W-I;VY?:60H*2P@9F%L<V4I.PH@("`@?0H@("`@:68@*"1U<FQ?<&%R86TI
M('L*("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1U<FPL("=U
M<FPG+"`D=7)L7W!A<F%M+"!F86QS92D["B`@("!]"B`@("!H96%D97(H)TQO
M8V%T:6]N.B`G("X@)'5R;"D["B`@("!E>&ET.PI]"@HD;&]G:6Y?<V-R965N
M(#T@)&%U=&@M/E]G971,;V=I;E-C<F5E;B@I.PII9B`H571I;#HZ<F5M;W9E
M4&%R86UE=&5R*"1L;V=I;E]S8W)E96XL(&%R<F%Y*"=U<FPG+"`G;F]C86-H
M92<I*2`A/0H@("`@2&]R9&4Z.G-E;&95<FPH9F%L<V4L(&9A;'-E+"!T<G5E
M*2D@>PH@("`@:68@*"1U<FQ?<&%R86TI('L*("`@("`@("`D;&]G:6Y?<V-R
M965N(#T@571I;#HZ861D4&%R86UE=&5R*"1L;V=I;E]S8W)E96XL("=U<FPG
M+"`D=7)L7W!A<F%M+"!F86QS92D["B`@("!]"B`@("!I9B`H)&EE7W9E<G-I
M;VXI('L*("`@("`@("`D;&]G:6Y?<V-R965N(#T@571I;#HZ861D4&%R86UE
M=&5R*"1L;V=I;E]S8W)E96XL("=I95]V97)S:6]N)RP@)&EE7W9E<G-I;VXL
M(&9A;'-E*3L*("`@('T*("`@(&AE861E<B@G3&]C871I;VXZ("<@+B`D;&]G
M:6Y?<V-R965N*3L*("`@(&5X:70["GT*"FEF("@D8G)O=W-E<BT^:7--;V)I
M;&4H*2D@>PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-;V)I;&4N<&AP)SL*
M("`@(')E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]L;V=I;B]M;V)I;&4N
M:6YC)SL*("`@(&5X:70["GT*"B\J($)U:6QD('1H92`\<V5L96-T/B!W:61G
M970@8V]N=&%I;FEN9R!T:&4@879A:6QA8FQE(&QA;F=U86=E<RX@*B\*:68@
M*"$D<')E9G,M/FES3&]C:V5D*"=L86YG=6%G92<I*2!["B`@("`D7U-%4U-)
M3TY;)VAO<F1E7VQA;F=U86=E)UT@/2!.3%,Z.G-E;&5C="@I.PH@("`@)&QA
M;F=S(#T@)SQS96QE8W0@;F%M93TB;F5W7VQA;F<B(&]N8VAA;F=E/2)S96QE
M8W1,86YG*"DB/B<["B`@("!F;W)E86-H("@D;FQS6R=L86YG=6%G97,G72!A
M<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`D<V5L(#T@*"1K97D@/3T@)%]3
M15-324].6R=H;W)D95]L86YG=6%G92==*2`_("<@<V5L96-T960](G-E;&5C
M=&5D(B<@.B`G)SL*("`@("`@("`D;&%N9W,@+CT@(CQO<'1I;VX@=F%L=64]
M7"(D:V5Y7"(D<V5L/B1V86P\+V]P=&EO;CXB.PH@("`@?0H@("`@)&QA;F=S
M("X]("<\+W-E;&5C=#XG.PI]"@HD=&ET;&4@/2!?*"),;V<@:6XB*3L*)&YO
M=&EF:6-A=&EO;BT^<'5S:"@G<V5T1F]C=7,H*2<L("=J879A<V-R:7!T)RD[
M"FEF("@D;&]G;W5T7W)E87-O;B`F)B`D8V]N9ELG;65N=2==6R=A;'=A>7,G
M72D@>PH@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@G:68@*'=I;F1O=RYP87)E
M;G0N9G)A;65S+FAO<F1E7VUE;G4I('=I;F1O=RYP87)E;G0N9G)A;65S+FAO
M<F1E7VUE;G4N;&]C871I;VXN:')E9B`](%PG)R`N($AO<F1E.CIA<'!L:6-A
M=&EO;E5R;"@G<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP)RD@+B`G7"<[
M)RP@)VIA=F%S8W)I<'0G*3L*?0H*)')E87-O;B`]("1A=71H+3YG971,;V=O
M=71296%S;VY3=')I;F<H*3L*"B\J($%D9"!S;VUE(&IA=F%S8W)I<'0N("HO
M"DAO<F1E.CIA9&138W)I<'1&:6QE*"=E;G1E<E]K97E?=')A<"YJ<R<L("=H
M;W)D92<L('1R=64I.PH*+RH@1&\@=V4@;F5E9"!T;R!D;R!)12!V97)S:6]N
M(&1E=&5C=&EO;C\@*B\*:68@*"@D8G)O=W-E<BT^9V5T0G)O=W-E<B@I(#T]
M("=M<VEE)RD@)B8@*"1B<F]W<V5R+3YG971-86IO<B@I(#X](#4I*2!["B`@
M("`D:65?8VQI96YT8V%P<R`]('1R=64["GT*"G)E<75I<F4@2$]21$5?5$5-
M4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["G)E<75I<F4@2$]21$5?
M5$5-4$Q!5$53("X@)R]L;V=I;B]L;V=I;BYI;F,G.PIR97%U:7)E($A/4D1%
M7U1%35!,051%4R`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9&5X+G!H<```
M````````````````````````````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P-S$W-2`Q,#4Q-30S,S<S-"`P,3<S-S(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D
M93H@:&]R9&4O:6YD97@N<&AP+'8@,BXQ,#4N-"XX(#(P,#8O,#<O,CD@,38Z
M-#DZ,3D@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAA
M<FQE<R!*+B!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I
M9VAT(#$Y.3DM,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G05542%](04Y$3$52)RP@=')U92D[
M"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2D["B1H
M;W)D95]C;VYF:6=U<F5D(#T@*$!F:6QE7V5X:7-T<RA(3U)$15]"05-%("X@
M)R]C;VYF:6<O8V]N9BYP:'`G*2`F)@H@("`@("`@("`@("`@("`@("`@("!`
M9FEL95]E>&ES=',H2$]21$5?0D%312`N("<O8V]N9FEG+VUI;65?9')I=F5R
M<RYP:'`G*2`F)@H@("`@("`@("`@("`@("`@("`@("!`9FEL95]E>&ES=',H
M2$]21$5?0D%312`N("<O8V]N9FEG+VYL<RYP:'`G*2`F)@H@("`@("`@("`@
M("`@("`@("`@("!`9FEL95]E>&ES=',H2$]21$5?0D%312`N("<O8V]N9FEG
M+W!R969S+G!H<"<I("8F"B`@("`@("`@("`@("`@("`@("`@($!F:6QE7V5X
M:7-T<RA(3U)$15]"05-%("X@)R]C;VYF:6<O<F5G:7-T<GDN<&AP)RDI.PH*
M:68@*"$D:&]R9&5?8V]N9FEG=7)E9"D@>PH@("`@<F5Q=6ER92!(3U)$15]"
M05-%("X@)R]L:6(O5&5S="YP:'`G.PH@("`@2&]R9&5?5&5S=#HZ8V]N9FEG
M1FEL97--:7-S:6YG*"=(;W)D92<L($A/4D1%7T)!4T4L("=P<F5F<RYP:'`G
M+`H@("`@("`@(&%R<F%Y*"=C;VYF+G!H<"<@/3X@)U1H:7,@:7,@=&AE(&UA
M:6X@2&]R9&4@8V]N9FEG=7)A=&EO;B!F:6QE+B!)="!C;VYT86EN<R!P871H
M<R!A;F0@8F%S:6,@:71E;7,@=&AA="!A<'!L>2!T;R!T:&4@8V]R92!F<F%M
M97=O<FL@86YD(&%L;"!(;W)D92!A<'!L:6-A=&EO;G,N)RP*("`@("`@("`@
M("`@("`G;6EM95]D<FEV97)S+G!H<"<@/3X@)U1H:7,@9FEL92!C;VYT<F]L
M<R!T:&4@9VQO8F%L('-E="!O9B!-24U%(&1R:79E<G,@9F]R('1H92!(;W)D
M92!F<F%M97=O<FLL(&%L;&]W:6YG(&%P<&QI8V%T:6]N<R!T;R!M86ME('5S
M92!O9B!P<F]G<F%M<R!S=6-H(&%S(&5N<V-R:7!T(&]R(&US=V]R9'9I97<@
M=&\@<F5N9&5R(&-O;G1E;G0@:6YT;R!(5$U,(&9O<B!V:65W:6YG(&EN(&$@
M8G)O=W-E<BXG+`H@("`@("`@("`@("`@("=N;',N<&AP)R`]/B`G5&AI<R!F
M:6QE('!R;W9I9&5S(&QO8V%L:7-A=&EO;B!S=7!P;W)T(&9O<B!T:&4@2&]R
M9&4@9G)A;65W;W)K+B<L"B`@("`@("`@("`@("`@)W)E9VES=')Y+G!H<"<@
M/3X@)U1H92!R96=I<W1R>2!I<R!H;W<@2&]R9&4@87!P;&EC871I;VYS(&9I
M;F0@;W5T(&AO=R!T;R!T86QK('1O(&5A8V@@;W1H97(N(%EO=2!S:&]U;&0@
M;&ES="!A;GD@:6YS=&%L;&5D($AO<F1E(&%P<&QI8V%T:6]N<R!T:&%T('EO
M=2!H879E(&AE<F4N)RDI.PI]"@IR97%U:7)E7V]N8V4@2$]21$5?0D%312`N
M("<O;&EB+V)A<V4N<&AP)SL*"FEF("@D8G)O=W-E<BT^:7--;V)I;&4H*2D@
M>PH@("`@<F5Q=6ER92!(3U)$15]"05-%("X@)R]S97)V:6-E<R]P;W)T86PO
M;6]B:6QE+G!H<"<["B`@("!E>&ET.PI]"@HD;6%I;E]P86=E(#T@571I;#HZ
M9V5T1F]R;41A=&$H)W5R;"<I.PH*+R\@0G)E86L@=7`@=&AE(')E<75E<W1E
M9"!54DP@:6X@)&UA:6Y?<&%G92!A;F0@<G5N('-O;64@<V%N:71Y(&-H96-K
M<PHO+R!O;B!I="!T;R!P<F5V96YT('!H:7-H:6YG(&%N9"!84U,@871T86-K
M<RX@268@86YY(&]F('1H92!C:&5C:W,*+R\@9F%I;"P@)&UA:6Y?<&%G92!W
M:6QL(&)E('-E="!T;R!N=6QL+@II9B`H(65M<'1Y*"1M86EN7W!A9V4I*2![
M"B`@("`O+R!-=71E(&5R<F]R<R!I;B!C87-E(&]F('5N<&%R<V5A8FQE(%52
M3',*("`@("1R97$@/2!`<&%R<V5?=7)L*"1M86EN7W!A9V4I.PH*("`@("\O
M(%=E(&%S<W5M92!T:&%T(&%N>2!V86QI9"!R961I<F5C="!54DP@=VEL;"!B
M92!I;B!T:&4@<V%M90H@("`@+R\@8V]O:VEE(&1O;6%I;BX@5&AI<R!H96QP
M<R!P<F5V96YT(')O9W5E(&]F9BUS:71E($AO<F1E(&EN<W1A;&QS"B`@("`O
M+R!F<F]M(&UI;6EC:VEN9R!T:&4@<F5A;"!S97)V97(N"B`@("!I9B`H:7-S
M970H)')E<5LG:&]S="==*2D@>PH@("`@("`@("1Q8V]O:VEE9&]M(#T@<')E
M9U]Q=6]T92@D8V]N9ELG8V]O:VEE)UU;)V1O;6%I;B==*3L*("`@("`@("!I
M9B`H(7!R96=?;6%T8V@H)R\G("X@)'%C;V]K:65D;VT@+B`G)"\G+"`D<F5Q
M6R=H;W-T)UTI*2!["B`@("`@("`@("`@("1M86EN7W!A9V4@/2!N=6QL.PH@
M("`@("`@('T*("`@('T*"B`@("`O+R!0<F]T;V-O;"!W:&ET96QI<W0Z($EF
M('1H92!54DP@:7,@9G5L;'D@<75A;&EF:65D+"!M86ME('-U<F4@:70*("`@
M("\O(&ES(&5I=&AE<B!H='1P(&]R(&AT='!S+@H@("`@)&%L;&]W961?<')O
M=&]C;VQS(#T@87)R87DH)VAT='`G+"`G:'1T<',G*3L*("`@(&EF("AE;7!T
M>2@D<F5Q6R=S8VAE;64G72D@?'P*("`@("`@("`A:6Y?87)R87DH)')E<5LG
M<V-H96UE)UTL("1A;&QO=V5D7W!R;W1O8V]L<RDI('L*("`@("`@("`D;6%I
M;E]P86=E(#T@;G5L;#L*("`@('T*?0H*:68@*"$D;6%I;E]P86=E*2!["B`@
M("`D:6YI=&EA;%]A<'`@/2`D<')E9G,M/F=E=%9A;'5E*"=I;FET:6%L7V%P
M<&QI8V%T:6]N)RD["B`@("!I9B`H(65M<'1Y*"1I;FET:6%L7V%P<"D@)B8@
M)')E9VES=')Y+3YH87-097)M:7-S:6]N*"1I;FET:6%L7V%P<"DI('L*("`@
M("`@("`D;6%I;E]P86=E(#T@2&]R9&4Z.G5R;"@D<F5G:7-T<GDM/F=E=$EN
M:71I86Q086=E*"1I;FET:6%L7V%P<"DL('1R=64I.PH@("`@?2!E;'-E:68@
M*&ES<V5T*"1R96=I<W1R>2T^87!P;&EC871I;VYS6R=H;W)D92==6R=I;FET
M:6%L7W!A9V4G72DI('L*("`@("`@("`D;6%I;E]P86=E(#T@2&]R9&4Z.F%P
M<&QI8V%T:6]N57)L*"1R96=I<W1R>2T^87!P;&EC871I;VYS6R=H;W)D92==
M6R=I;FET:6%L7W!A9V4G72P@=')U92D["B`@("!](&5L<V5I9B`H075T:#HZ
M9V5T075T:"@I*2!["B`@("`@("`@)&UA:6Y?<&%G92`]($AO<F1E.CIA<'!L
M:6-A=&EO;E5R;"@G<V5R=FEC97,O<&]R=&%L+R<L('1R=64I.PH@("`@?2!E
M;'-E('L*("`@("`@("`D;6%I;E]P86=E(#T@2&]R9&4Z.F%P<&QI8V%T:6]N
M57)L*"=L;V=I;BYP:'`G+"!T<G5E*3L*("`@('T*?0H*:68@*"%5=&EL.CIG
M971&;W)M1&%T82@G9G)A;65S971?;&]A9&5D)RD@)B8*("`@("@D8V]N9ELG
M;65N=2==6R=A;'=A>7,G72!\?`H@("`@("A!=71H.CIG971!=71H*"D@)B8@
M)'!R969S+3YG971686QU92@G<VAO=U]S:61E8F%R)RDI*2D@>PH@("`@:68@
M*"1B<F]W<V5R+3YH87-1=6ER:R@G<V-R;VQL8F%R7VEN7W=A>2<I*2!["B`@
M("`@("`@)'-C<F]L;&)A<B`]("=Y97,G.PH@("`@?2!E;'-E('L*("`@("`@
M("`D<V-R;VQL8F%R(#T@)V%U=&\G.PH@("`@?0H@("`@<F5Q=6ER92!(3U)$
M15]414U03$%415,@+B`G+VEN9&5X+V9R86UE<U]I;F1E>"YI;F,G.PI](&5L
M<V4@>PH@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N("1M86EN7W!A9V4I.PI]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+V%D;6EN````````````````````````````````````````````
M```````````````````````````````````````````````````P,#`W-34@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<S-"`P,38U
M-3$`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O861M:6XO;&]C86QE````````````
M````````````````````````````````````````````````````````````
M`````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P
M(#$P-3$U-#,S-S,T(#`R,#`Q,``@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]A9&UI
M;B]L;V-A;&4O96Y?55,`````````````````````````````````````````
M````````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S0@,#(Q,#(Q`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+V%D;6EN+VQO8V%L92]E;E]54R]H96QP+GAM;```````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S(Q-B`Q,#4Q-30S,S<S
M-"`P,C(U-30`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]X;6P@=F5R<VEO;CTG,2XP)S\^"CPA+2T@)$AO<F1E.B!H;W)D
M92]A9&UI;B]L;V-A;&4O96Y?55,O:&5L<"YX;6PL=B`Q+C,@,C`P,R\P-B\Q
M-"`P-#HR.#HR,2!C:'5C:R!%>'`@)"`M+3X*/&AE;'`^"@H\96YT<GD@:60]
M(F%D;6EN+7!H<'-H96QL(CX*("`@(#QT:71L93Y!9&UI;B!4;V]L<SH@4$A0
M(%-H96QL/"]T:71L93X*("`@(#QH96%D:6YG/DAO=R!T;R!U<V4@=&AE(%!(
M4"!3:&5L;#PO:&5A9&EN9SX*("`@(#QP87)A/E1H92!02%`@8V]M;6%N9"!S
M:&5L;"!L971S('EO=2!E>&5C=71E(&%R8FET<F%R>2!02%`*("`@("`@("`@
M('-T871E;65N=',@;VX@=&AE('-E<G9E<BX@5&AE<V4@8V]M;6%N9',@87)E
M(&5X96-U=&5D('5S:6YG"B`@("`@("`@("!T:&4@/&-O9&4^979A;"@I/"]C
M;V1E/B!F=6YC=&EO;BP@86YD(&5X96-U=&4@:6X@=&AE(&-O;G1E>'0*("`@
M("`@("`@(&]F('1H92!C=7)R96YT('-E<W-I;VXN(%1H:7,@<VAE;&P@:7,@
M:6YT96YD960@=&\@=')Y(&]U=`H@("`@("`@("`@<WEN=&%X(&%N9"!E>&5C
M=71E('-O;64@<VEM<&QE(&%R8FET<F%R>2!C;V1E+B!.;W1E('1H870@=&\*
M("`@("`@("`@(&=E="!A;GD@;W5T<'5T+"!Y;W4@;75S="!E8VAO(&]R('!R
M:6YT('-O;65T:&EN9R!I;B!Y;W5R"B`@("`@("`@("!C;V1E(&9R86=M96YT
M+CPO<&%R83X*/"]E;G1R>3X*"CQE;G1R>2!I9#TB861M:6XM<W%L<VAE;&PB
M/@H@("`@/'1I=&QE/D%D;6EN(%1O;VQS.B!344P@4VAE;&P\+W1I=&QE/@H@
M("`@/&AE861I;F<^2&]W('1O('5S92!T:&4@4U%,(%-H96QL/"]H96%D:6YG
M/@H@("`@/'!A<F$^5&AE(%-13"!Q=65R>2!S:&5L;"!L971S('EO=2!E>&5C
M=71E(&%R8FET<F%R>2!344P*("`@("`@("`@('-T871E;65N=',@;VX@>6]U
M<B!D871A8F%S92X@5&AE<V4@8V]M;6%N9',@87)E(&5X96-U=&5D"B`@("`@
M("`@("!A9V%I;G-T('1H92!D871A8F%S92!D969I;F5D(&EN("1C;VYF6R=S
M<6PG72!U<VEN9R!T:&4*("`@("`@("`@(%!%05(Z.D1"(&-L87-S97,N(%EO
M=2!C86X@=7-E('1H:7,@=&]O;"!T;R!D;R!Q=65R:65S(&EN=&\*("`@("`@
M("`@('1H92!D871A8F%S92P@=&\@9&\@8V]M<&QI8V%T960@4U%,('5P9&%T
M97,L(&1E;&5T97,L(&5T8RXL"B`@("`@("`@("!O<B!T;R!D;R!S:6UP;&4@
M9&%T82!C;VQL96-T:6]N+B!)="!S96YD<R!344P@<75E<FEE<R!T;R!T:&4*
M("`@("`@("`@(&1A=&%B87-E(&1I<F5C=&QY+"!A;F0@=VEL;"!R97!O<G0@
M<F5T=7)N(&-O9&5S(&%N9"!C;VUP;&5T90H@("`@("`@("`@<F5S=6QT('-E
M=',N/"]P87)A/@H\+V5N=')Y/@H*/&5N=')Y(&ED/2)A9&UI;BUC;61S:&5L
M;"(^"B`@("`\=&ET;&4^061M:6X@5&]O;',Z($-O;6UA;F0@4VAE;&P\+W1I
M=&QE/@H@("`@/&AE861I;F<^2&]W('1O('5S92!T:&4@0V]M;6%N9"!3:&5L
M;#PO:&5A9&EN9SX*("`@(#QP87)A/E1H92!C;VUM86YD('-H96QL(&QE=',@
M>6]U(&5X96-U=&4@87)B:71R87)Y('-H96QL"B`@("`@("`@("!C;VUM86YD
M<R!O;B!Y;W5R('-E<G9E<BX@66]U(&-A;B!U<V4@=&AI<R!T;R!D;R!Q=6EC
M:PH@("`@("`@("`@<VAE;&P@;W!E<F%T:6]N<R!O<B!W:&5N(&$@<VAE;&P@
M:7,@;F]T(&]T:&5R=VES92!A=F%I;&%B;&4N"B`@("`@("`@("`\+W!A<F$^
M"CPO96YT<GD^"@H\+VAE;'`^"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]A9&UI;B]L;V-A;&4O9FE?1DD`````````````````````````
M````````````````````````````````````````````````````,#`P-S4U
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S0@,#(P
M-S8T`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V%D;6EN+VQO8V%L92]F:5]&22]H
M96QP+GAM;```````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-#(V
M,2`Q,#4Q-30S,S<S-"`P,C(U,C``(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]X;6P@=F5R<VEO;CTB,2XP(C\^"CPA+2T@
M)$AO<F1E.B!H;W)D92]A9&UI;B]L;V-A;&4O9FE?1DDO:&5L<"YX;6PL=B`Q
M+C$N,3(N,B`R,#`V+S`R+S(X(#$T.C`R.C,U(&IA;B!%>'`@)"`M+3X*/&AE
M;'`^"B`@/&5N=')Y(&ED/2)A9&UI;BUP:'!S:&5L;"(@;60U/2)D-3`Q-S4Y
M,65F-&$S9C,Y9#DW.#=B-3@Q83!A8F)A-2(@<W1A=&4](G5P=&]D871E(CX*
M("`@(#QT:71L93Y9;&PF(WA%-#MP:61O;B!T>28C>$8V.VMA;'5T.B!02%`M
M:V]M96YT;W1U;&MK:3PO=&ET;&4^"B`@("`\:&5A9&EN9SY-:71E;B!02%`M
M:V]M96YT;W1U;&MK:6$@:R8C>$4T.WET970F(WA%-#LF(WA%-#MN/"]H96%D
M:6YG/@H@("`@/'!A<F$^"B`@("!02%`M:V]M96YT;W1U;&MK:7-S82!V;VD@
M<W5O<FET=&%A('!A;'9E;&EM96QL82!M:70F(WA%-#L@=&%H86YS80H@("`@
M4$A0+6MO;65N=&]J82X@3B8C>$4T.VTF(WA%-#L@:V]M96YN;W0@<W5O<FET
M971A86X@/&-O9&4^979A;"@I/"]C;V1E/@H@("`@9G5N:W1I;VX@<VES)B-X
M130[;&PF(WA%-#L@:F$@;GEK>6ES96X@:7-T=6YN;VX@:V]N=&5K<W1I<W-A
M+B!4)B-X130[;28C>$4T.PH@("`@:V]M96YT;W1U;&MK:2!O;B!E;G-I<VEJ
M86ES97-T:2!T87)K;VET971T=2!S>6YT86MS:6X*("`@('1A<FMI<W1U:W-E
M96X@:F$@>6MS:6YK97)T86ES96X@:V]O9&EN('-U;W)I='5K<V5E;BX@2'5O
M;6%A+`H@("`@971T)B-X130[('1U;&]S=&%A:W-E<VD@:F]T86MI;BP@;FEI
M;B!S:6YU;B!P:70F(WA%-#LF(WA%-#L@:R8C>$4T.WET="8C>$4T.R8C>$4T
M.R!E8VAO(&IA"B`@("!P<FEN="!K;VUE;G1O:F$N"B`@("`\+W!A<F$^"CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)A9&UI;BUS<6QS:&5L;"(@;60U/2(U8F0R
M9F-B.6,Y-C<X938R8V$Q-#$U-C9A8CAF-&,T9B(@<W1A=&4](G5P=&]D871E
M(CX*("`@(#QT:71L93Y9;&PF(WA%-#MP:61O;B!T>28C>$8V.VMA;'5T.B!3
M44PM:V]M96YT;W1U;&MK:3PO=&ET;&4^"B`@("`\:&5A9&EN9SY-:71E;B!3
M44PM:V]M96YT;W1U;&MK:6$@:R8C>$4T.WET970F(WA%-#LF(WA%-#MN/"]H
M96%D:6YG/@H@("`@/'!A<F$^"B`@("!344PM:V]M96YT;W1U;&MI<W-A('9O
M:2!S=6]R:71T86$@;6ET)B-X130[('1A:&%N<V$@4U%,+6QA=7-E:VME:71A
M+"!J;W1K80H@("`@<W5O<FET971A86X@=&EE=&]K86YN87-S82X@2R8C>$4T
M.WET971T)B-X130[=B8C>$4T.R!T:65T;VMA;G1A(&]N"B`@("!M)B-X130[
M)B-X130[<FET96QT>2`D8V]N9ELG<W%L)UT@:F$@<VET)B-X130[(&LF(WA%
M-#MY=&5T)B-X130[)B-X130[;B!014%2.D1"+6QU;VMA;@H@("`@879U;&QA
M+B`@5F]I="!K)B-X130[>71T)B-X130[)B-X130[('0F(WA%-#MT)B-X130[
M('1Y)B-X1C8[:V%L=6IA('1E:&0F(WA%-#MK<V5S:2!K>7-E;'EJ)B-X130[
M"B`@("!T:65T;VMA;G1A86XL('`F(WA%-#MI=FET="8C>$4T.R8C>$4T.VMS
M97-I('1I971O:F$@=&EE=&]K86YN87-S82P*("`@('!O:7-T86%K<V5S:2!T
M:65T;VIA('1I971O:V%N;F%S=&$@:FYE+B!T86D@:&%K96$@=&EE=&]J80H@
M("`@=&EE=&]K86YN87-T82X@4U%,+6MO;65N;F]T(&PF(WA%-#MH971E="8C
M>$4T.R8C>$4T.VX@<W5O<F%A;B!T:65T;VMA;FYA;&QE"B`@("!J82!P86QU
M=6%R=F]N82!T=6QE92!S=&%T=7-K;V]D:2!J82!K>7-E;'EN('!A;&%U='1A
M;6$*("`@(&%R=F\N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)A9&UI;BUC;61S:&5L;"(@;60U/2(Y9&)B934Y,S<S-65E8F)B,S1D93DY
M,6$U-V(Y.&(Y9B(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y9;&PF
M(WA%-#MP:61O;B!T>28C>$8V.VMA;'5T.B!+;VUE;G1O='5L:VMI/"]T:71L
M93X*("`@(#QH96%D:6YG/DUI=&5N(&MO;65N=&]T=6QK:VEA(&LF(WA%-#MY
M=&5T)B-X130[)B-X130[;CPO:&5A9&EN9SX*("`@(#QP87)A/@H@("`@2V]M
M96YT;W1U;&MI;B!A=G5L;&$@=F]I="!S=6]R:71T86$@:V]M96YT;VIA('=W
M=RUP86QV96QI;65L;&$N(%9O:70@:R8C>$4T.WET="8C>$4T.R8C>$4T.R!T
M)B-X130[="8C>$4T.R!T;VEM:6YT;V$@:W5N(&AA;'5A="!N;W!E87-T:2!S
M=6]R:71T86$@:F]N:W5N(&MO;65N;F]N('!A;'9E;&EM96QL82!J82!K;VUE
M;G1O='5L:VMI(&5I(&]L92!M=75T96X@:R8C>$4T.WET971T)B-X130[=FES
M<R8C>$4T.RX*("`@(#PO<&%R83X*/"]E;G1R>3X*/"]H96QP/@H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V%D;6EN+VQO
M8V%L92]H=5](50``````````````````````````````````````````````
M```````````````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<S-"`P,C$P,C``(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O861M:6XO;&]C86QE+VAU7TA5+VAE;'`N>&UL````````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S-S8S(#$P-3$U-#,S-S,T(#`R
M,C4V,@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/WAM;"!V97)S:6]N/2(Q+C`B(&5N8V]D:6YG/2)I<V\M.#@U.2TR(C\^
M"CPA+2T@2&]R9&4@,RXQ($%D;6EN(&AE;'`Z(&AU7TA5("1(;W)D93H@:&]R
M9&4O861M:6XO;&]C86QE+VAU7TA5+VAE;'`N>&UL+'8@,2XQ+C(N,2`R,#`V
M+S`S+S`S(#$S.C0T.C$Q(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y
M(&ED/2)A9&UI;BUP:'!S:&5L;"(@<W1A=&4](G5P=&]D871E(B!M9#4](F0U
M,#$W-3DQ968T83-F,SED.3<X-V(U.#%A,&%B8F$U(CX*("`@(#QT:71L93Y!
M9&UI;FES>G1RX6-I\W,@97-Z:_9Z]FLZ(&$@4$A0(%-H96QL/"]T:71L93X*
M("`@(#QH96%D:6YG/D$@4$A0(%-H96QL(&AA<WINX6QA=&$\+VAE861I;F<^
M"B`@("`\<&%R83Y!(%!(4"!P87)A;F-SZ7)T96QM97KU('-E9^UT<^EGZ79E
M;"!T971S>O5L96=E<R!02%`@<&%R86YC<V]K870*("`@("`@("`@(&AA:G1H
M870@=NEG<F4@82!S>F5R=F5R96XN($5Z96ME="!A('!A<F%N8W-O:V%T(&$@
M9^EP(&%Z(`H@("`@("`@("`@/&-O9&4^979A;"@I/"]C;V1E/B!F_&=G=NEN
M>2!S96?M='/I9^EV96PL(&%Z(&%K='7A;&ES86X@Z7)VZ6YY97,*("`@("`@
M("`@('-E<W-I;VX@:V5R973I8F5N(&AA:G1J82!VZ6=R92X@12!P87)A;F-S
MZ7)T96QM97KU(&/I;&IA+"!H;V=Y"B`@("`@("`@("!K:2!T=61J=6YK('!R
M\V+A;&YI('1E='-Z]6QE9V5S+"!E9WES>F5R^V)B(&OS9'+I<WIL971E:V5T
M+B`*("`@("`@("`@($%H:&]Z(&%Z;VYB86XL(&AO9WD@8N%R;6EL>65N(&]U
M='!U=&]T(&SA<W-U;FLL(&$@:_-D;F%K(&5C:&\*("`@("`@("`@('9A9WD@
M<')I;G0@<&%R86YC<V]K870@:V5L;"!T87)T86QM87IN:6$N"B`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)A9&UI;BUS<6QS:&5L;"(@<W1A
M=&4](G5P=&]D871E(B!M9#4](C5B9#)F8V(Y8SDV-SAE-C)C83$T,34V-F%B
M.&8T8S1F(CX*("`@(#QT:71L93Y!9&UI;FES>G1RX6-I\W,@97-Z:_9Z]FLZ
M(&%Z(%-13"!3:&5L;#PO=&ET;&4^"B`@("`\:&5A9&EN9SY!>B!344P@4VAE
M;&P@:&%S>F[A;&%T83PO:&5A9&EN9SX*("`@(#QP87)A/D%Z(%-13"!P87)A
M;F-SZ7)T96QM97KU('-E9^UT<^EGZ79E;"!T971S>O5L96=E<R!344P@<&%R
M86YC<V]T"B`@("`@("`@("!H86IT:&%T(';I9W)E(&%Z(&%D871BX7II<V]N
M+B!%>F5K970@82!P87)A;F-S;VMA="!A(&?I<"!A(%!%05(Z.D1""B`@("`@
M("`@("!RZ7;I;B!H86IT:F$@=NEG<F4@82`D8V]N9ELG<W%L)UTM8F5N(&UE
M9V%D;W1T(&%D871B87II<V]N+@H@("`@("`@("`@17IZ96P@87H@97-Z:_9Z
M>F5L(&QE:^ER9&5ZZ7-E:V5T+"!B;VYY;VQU;'0@4U%,(&WS9&]S[73A<V]K
M870L"B`@("`@("`@("!T]G)LZ7-E:V5T(&AA:G1H870@=NEG<F4L('9A9WD@
M861A=&]K870@9WG[:G1H970N($%Z(%-13"!P87)A;F-S;VMA=`H@("`@("`@
M("`@:_9Z=F5T;&5N_&P@87H@861A=&+A>FES;F%K(&O\;&1I+"!M86ID('9I
M<W-Z86%D:F$@87H@97)E9&WI;GEK\V1O:V%T"B`@("`@("`@("!I;&PN(&$@
M:V%P;W1T(&%D871O:V%T+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB861M:6XM8VUD<VAE;&PB('-T871E/2)U<'1O9&%T92(@;60U/2(Y
M9&)B934Y,S<S-65E8F)B,S1D93DY,6$U-V(Y.&(Y9B(^"B`@("`\=&ET;&4^
M061M:6YI<WIT<N%C:?-S(&5S>FOV>O9K.B!A('!A<F%N8W-S;W(\+W1I=&QE
M/@H@("`@/&AE861I;F<^02!P87)A;F-S<V]R(&AA<WINX6QA=&$\+VAE861I
M;F<^"B`@("`\<&%R83Y!('!A<F%N8W-S;W(@<V5G[71SZ6?I=F5L('!A<F%N
M8W-O:V%T(&AA:G1H870@=NEG<F4@82!S>F5R=F5R96XN"B`@("`@("`@("!%
M>B!E9WDM96=Y('!A<F%N8W,@9WEO<G,@=NEG<F5H86ITX7/A<F$@:O,L('9A
M9WD@87)R82!A>B!E<V5T<F4L(&AA"B`@("`@("`@("!MX7,@;?-D;VX@;F5M
M(&OI<&5S(&$@<WIE<G9E<B!P87)A;F-SZ7)T96QM97KU:NEH97H@*$-O;6UA
M;F0@4VAE;&PI"B`@("`@("`@("!J=71N:6$N"B`@("`\+W!A<F$^"CPO96YT
M<GD^"CPO:&5L<#X*`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+V%D;6EN+W!E<FUS````````````````````````````````````````
M```````````````````````````````````````````````P,#`W-34@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<S-"`P,3<V-S<`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O861M:6XO<&5R;7,O961I="YP:'``````
M````````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$P-C4V(#$P
M-3$U-#,S-S,T(#`R,30R-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]A9&UI
M;B]P97)M<R]E9&ET+G!H<"QV(#$N,S@N,BXU(#(P,#8O,#$O,#$@,C$Z,C@Z
M,#4@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@
M2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`R,#`U
M+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%
M7U\I("X@)R\N+B\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O
M;&EB+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]-96YU+G!H<"<[
M"@II9B`H(4%U=&@Z.FES061M:6XH*2D@>PH@("`@2&]R9&4Z.F%U=&AE;G1I
M8V%T:6]N1F%I;'5R95)E9&ER96-T*"D["GT*"B\J(%-E="!U<"!T:&4@9F]R
M;2!V87)I86)L97,N("HO"G)E<75I<F5?;VYC92`G2&]R9&4O5F%R:6%B;&5S
M+G!H<"<["B1V87)S(#T@)E9A<FEA8FQE<SHZ9V5T1&5F875L=%9A<FEA8FQE
M<R@I.PHD<&5R;5]I9"`]("1V87)S+3YG970H)W!E<FU?:60G*3L*)&-A=&5G
M;W)Y(#T@)'9A<G,M/F=E="@G8V%T96=O<GDG*3L*"B\J(%-E92!I9B!W92!N
M965D('1O("AA;F0@87)E('-U<'!O<V5D('1O*2!A=71O8W)E871E('1H92!P
M97)M:7-S:6]N+B`J+PII9B`H)&-A=&5G;W)Y("$]/2!N=6QL*2!["B`@("`D
M<&5R;6ES<VEO;B`]("8D<&5R;7,M/F=E=%!E<FUI<W-I;VXH)&-A=&5G;W)Y
M*3L*("`@(&EF("AI<U]A*"1P97)M:7-S:6]N+"`G4$5!4E]%<G)O<B<I("8F
M(%5T:6PZ.F=E=$9O<FU$871A*"=A=71O8W)E871E)RDI('L*"B`@("`@("`@
M+RH@0VAE8VL@=&\@<V5E(&EF('1H92!P97)M:7-S:6]N('=E(&%R92!C;W!Y
M:6YG(&9R;VT@97AI<W1S(&)E9F]R92!W90H@("`@("`@("`J(&%U=&]C<F5A
M=&4N("HO"B`@("`@("`@)&-O<'E&<F]M(#T@571I;#HZ9V5T1F]R;41A=&$H
M)V%U=&]C<F5A=&5?8V]P>2<I.PH@("`@("`@(&EF("@D8V]P>49R;VT@)B8@
M(21P97)M<RT^97AI<W1S*"1C;W!Y1G)O;2DI('L*("`@("`@("`@("`@)&-O
M<'E&<F]M(#T@;G5L;#L*("`@("`@("!]"@H@("`@("`@("1P87)E;G0@/2`D
M=F%R<RT^9V5T*"=P87)E;G0G*3L*("`@("`@("`D<&5R;6ES<VEO;B`]("8D
M<&5R;7,M/FYE=U!E<FUI<W-I;VXH)&-A=&5G;W)Y*3L*("`@("`@("`D<F5S
M=6QT(#T@)'!E<FUS+3YA9&1097)M:7-S:6]N*"1P97)M:7-S:6]N+"`D<&%R
M96YT*3L*("`@("`@("!I9B`H(6ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`D9F]R;2`]("=E9&ET+FEN8R<["B`@("`@("`@
M("`@("1P97)M7VED(#T@)'!E<FUS+3YG971097)M:7-S:6]N260H)'!E<FUI
M<W-I;VXI.PH@("`@("`@('T*"B`@("`@("`@:68@*"1C;W!Y1G)O;2D@>PH@
M("`@("`@("`@("`O*B!792!H879E(&%U=&]C<F5A=&5D('1H92!P97)M:7-S
M:6]N(&%N9"!W92!H879E(&)E96X@=&]L9"!T;PH@("`@("`@("`@("`@*B!C
M;W!Y(&%N(&5X:7-T:6YG('!E<FUI<W-I;VX@9F]R('1H92!D969A=6QT<RX@
M*B\*("`@("`@("`@("`@)&-O<'E&<F]M3V)J(#T@)B1P97)M<RT^9V5T4&5R
M;6ES<VEO;B@D8V]P>49R;VTI.PH@("`@("`@("`@("`D<&5R;6ES<VEO;BT^
M861D1W5E<W1097)M:7-S:6]N*"1C;W!Y1G)O;4]B:BT^9V5T1W5E<W1097)M
M:7-S:6]N<R@I+"!F86QS92D["B`@("`@("`@("`@("1P97)M:7-S:6]N+3YA
M9&1$969A=6QT4&5R;6ES<VEO;B@D8V]P>49R;VU/8FHM/F=E=$1E9F%U;'10
M97)M:7-S:6]N<R@I+"!F86QS92D["B`@("`@("`@("`@("1P97)M:7-S:6]N
M+3YA9&1#<F5A=&]R4&5R;6ES<VEO;B@D8V]P>49R;VU/8FHM/F=E=$-R96%T
M;W)097)M:7-S:6]N<R@I+"!F86QS92D["B`@("`@("`@("`@(&9O<F5A8V@@
M*"1C;W!Y1G)O;4]B:BT^9V5T57-E<E!E<FUI<W-I;VYS*"D@87,@)'5S97(@
M/3X@)'5P97)M*2!["B`@("`@("`@("`@("`@("`D<&5R;6ES<VEO;BT^861D
M57-E<E!E<FUI<W-I;VXH)'5S97(L("1U<&5R;2P@9F%L<V4I.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&9O<F5A8V@@*"1C;W!Y1G)O;4]B:BT^9V5T
M1W)O=7!097)M:7-S:6]N<R@I(&%S("1G<F]U<"`]/B`D9W!E<FTI('L*("`@
M("`@("`@("`@("`@("1P97)M:7-S:6]N+3YA9&1'<F]U<%!E<FUI<W-I;VXH
M)&=R;W5P+"`D9W!E<FTL(&9A;'-E*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("\J(%=E(&AA=F4@875T;V-R96%T960@
M=&AE('!E<FUI<W-I;VX@86YD('=E(&1O;B=T(&AA=F4@86X*("`@("`@("`@
M("`@("H@97AI<W1I;F<@<&5R;6ES<VEO;B!T;R!C;W!Y+B`@4V5E(&EF('-O
M;64@9&5F875L=',@=V5R90H@("`@("`@("`@("`@*B!S=7!P;&EE9"X@*B\*
M("`@("`@("`@("`@)&%D9%!E<FUS(#T@571I;#HZ9V5T1F]R;41A=&$H)V%U
M=&]C<F5A=&5?9W5E<W0G*3L*("`@("`@("`@("`@:68@*"1A9&1097)M<RD@
M>PH@("`@("`@("`@("`@("`@)'!E<FUI<W-I;VXM/F%D9$=U97-T4&5R;6ES
M<VEO;B@D861D4&5R;7,L(&9A;'-E*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D861D4&5R;7,@/2!5=&EL.CIG971&;W)M1&%T82@G875T;V-R96%T
M95]D969A=6QT)RD["B`@("`@("`@("`@(&EF("@D861D4&5R;7,I('L*("`@
M("`@("`@("`@("`@("1P97)M:7-S:6]N+3YA9&1$969A=6QT4&5R;6ES<VEO
M;B@D861D4&5R;7,L(&9A;'-E*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D861D4&5R;7,@/2!5=&EL.CIG971&;W)M1&%T82@G875T;V-R96%T95]C
M<F5A=&]R)RD["B`@("`@("`@("`@(&EF("@D861D4&5R;7,I('L*("`@("`@
M("`@("`@("`@("1P97)M:7-S:6]N+3YA9&1#<F5A=&]R4&5R;6ES<VEO;B@D
M861D4&5R;7,L(&9A;'-E*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M("`@("`D<&5R;6ES<VEO;BT^<V%V92@I.PH@("`@?2!E;'-E('L*("`@("`@
M("`D<&5R;5]I9"`]("1P97)M<RT^9V5T4&5R;6ES<VEO;DED*"1P97)M:7-S
M:6]N*3L*("`@('T*("`@("1V87)S+3YS970H)W!E<FU?:60G+"`D<&5R;5]I
M9"D["GT@96QS92!["B`@("`D<&5R;6ES<VEO;B`]("8D<&5R;7,M/F=E=%!E
M<FUI<W-I;VY">4ED*"1P97)M7VED*3L*?0H*+RH@268@=&AE('!E<FUI<W-I
M;VX@9F5T8VAE9"!I<R!A;B!E<G)O<B!R971U<FX@=&\@=&AE('!E<FUI<W-I
M;VYS(&QI<W0N("HO"FEF("AI<U]A*"1P97)M:7-S:6]N+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(D%T=&5M<'0@=&\@
M961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(I+"`G:&]R9&4N97)R
M;W(G*3L*("`@("1U<FP@/2!(;W)D93HZ87!P;&EC871I;VY5<FPH)V%D;6EN
M+W!E<FUS+VEN9&5X+G!H<"<L('1R=64I.PH@("`@:&5A9&5R*"=,;V-A=&EO
M;CH@)R`N("1U<FPI.PH@("`@97AI=#L*?0H*<F5Q=6ER95]O;F-E("=(;W)D
M92]097)M<R]522YP:'`G.PHD=6D@/2`F;F5W(%!E<FUS7U5)*"1P97)M<RD[
M"B1U:2T^<V5T5F%R<R@D=F%R<RD["B1U:2T^<V5T=7!%9&ET1F]R;2@D<&5R
M;6ES<VEO;BD["@II9B`H)'5I+3YV86QI9&%T945D:71&;W)M*"1I;F9O*2D@
M>PH@("`@+RH@57!D871E(&%N9"!S879E('1H92!P97)M:7-S:6]N<RX@*B\*
M("`@("1P97)M:7-S:6]N+3YU<&1A=&5097)M:7-S:6]N<R@D:6YF;RD["B`@
M("`D<&5R;6ES<VEO;BT^<V%V92@I.PH@("`@)&YO=&EF:6-A=&EO;BT^<'5S
M:"AS<')I;G1F*%\H(E5P9&%T960@7"(E<UPB+B(I+"`D<&5R;7,M/F=E=%1I
M=&QE*"1P97)M:7-S:6]N+3YG971.86UE*"DI*2P@)VAO<F1E+G-U8V-E<W,G
M*3L*("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)V%D;6EN+W!E<FUS
M+V5D:70N<&AP)RP@)W!E<FU?:60G+"`D<&5R;6ES<VEO;BT^9V5T260H*2D[
M"B`@("`D=7)L(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"1U<FPL('1R=64I
M.PH@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N("1U<FPI.PH@("`@97AI=#L*
M?0H*)'1I=&QE(#T@7R@B4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VXB*3L*
M<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUH96%D97(N:6YC
M)SL*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V%D;6EN+V-O;6UO;BUH
M96%D97(N:6YC)SL*)&YO=&EF:6-A=&EO;BT^;F]T:69Y*&%R<F%Y*"=L:7-T
M96YE<G,G(#T^("=S=&%T=7,G*2D["@HO*B!296YD97(@=&AE(&9O<FT@86YD
M('1R964N("HO"B1U:2T^<F5N9&5R1F]R;2@G961I="YP:'`G*3L*96-H;R`G
M/&)R("\^)SL*)'5I+3YR96YD97)4<F5E*"1P97)M7VED*3L*"G)E<75I<F4@
M2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'``````````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#0V,S,@,3`U,34T,S,W,S0@
M,#(R,C,Q`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+V%D;6EN+W!E<FUS+V%D
M9&-H:6QD+G!H<"QV(#$N,C<N,BXT(#(P,#8O,#$O,#$@,C$Z,C@Z,#4@:F%N
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@
M2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@
M)R\N+B\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A
M<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]-96YU+G!H<"<["@II9B`H
M(4%U=&@Z.FES061M:6XH*2D@>PH@("`@2&]R9&4Z.F%U=&AE;G1I8V%T:6]N
M1F%I;'5R95)E9&ER96-T*"D["GT*"B\J(%-E="!U<"!T:&4@9F]R;2!V87)I
M86)L97,N("HO"G)E<75I<F5?;VYC92`G2&]R9&4O5F%R:6%B;&5S+G!H<"<[
M"B1V87)S(#T@)E9A<FEA8FQE<SHZ9V5T1&5F875L=%9A<FEA8FQE<R@I.PHD
M<&5R;5]I9"`]("1V87)S+3YG970H)W!E<FU?:60G*3L*"B1P97)M:7-S:6]N
M(#T@)B1P97)M<RT^9V5T4&5R;6ES<VEO;D)Y260H)'!E<FU?:60I.PII9B`H
M:7-?82@D<&5R;6ES<VEO;BP@)U!%05)?17)R;W(G*2D@>PH@("`@)&YO=&EF
M:6-A=&EO;BT^<'5S:"A?*"));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(I
M+"`G:&]R9&4N97)R;W(G*3L*("`@("1U<FP@/2!(;W)D93HZ87!P;&EC871I
M;VY5<FPH)V%D;6EN+W!E<FUS+VEN9&5X+G!H<"<L('1R=64I.PH@("`@:&5A
M9&5R*"=,;V-A=&EO;CH@)R`N("1U<FPI.PH@("`@97AI=#L*?0H*+RH@4V5T
M('5P(&9O<FTN("HO"G)E<75I<F5?;VYC92`G2&]R9&4O4&5R;7,O54DN<&AP
M)SL*)'5I(#T@)FYE=R!097)M<U]522@D<&5R;7,I.PHD=6DM/G-E=%9A<G,H
M)'9A<G,I.PHD=6DM/G-E='5P061D1F]R;2@D<&5R;6ES<VEO;BD["@II9B`H
M)'5I+3YV86QI9&%T94%D9$9O<FTH)&EN9F\I*2!["B`@("!I9B`H)&EN9F];
M)W!E<FU?:60G72`]/2!$051!5%)%15]23T]4*2!["B`@("`@("`@)&-H:6QD
M(#T@)B1P97)M<RT^;F5W4&5R;6ES<VEO;B@D:6YF;ULG8VAI;&0G72D["B`@
M("`@("`@)')E<W5L="`]("1P97)M<RT^861D4&5R;6ES<VEO;B@D8VAI;&0I
M.PH@("`@?2!E;'-E('L*("`@("`@("`D<$]B(#T@)B1P97)M<RT^9V5T4&5R
M;6ES<VEO;D)Y260H)&EN9F];)W!E<FU?:60G72D["B`@("`@("`@)&YA;64@
M/2`D<$]B+3YG971.86UE*"D@+B`G.B<@+B!$871A5')E93HZ96YC;V1E3F%M
M92@D:6YF;ULG8VAI;&0G72D["B`@("`@("`@)&-H:6QD(#T@)B1P97)M<RT^
M;F5W4&5R;6ES<VEO;B@D;F%M92D["B`@("`@("`@)')E<W5L="`]("1P97)M
M<RT^861D4&5R;6ES<VEO;B@D8VAI;&0I.PH@("`@?0H@("`@:68@*&ES7V$H
M)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("1N;W1I9FEC871I
M;VXM/G!U<V@H<W!R:6YT9BA?*")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E
M<RXB*2P@)'!E<FUS+3YG9714:71L92@D8VAI;&0M/F=E=$YA;64H*2DL("1R
M97-U;'0M/F=E=$UE<W-A9V4H*2DL("=H;W)D92YE<G)O<B<I.PH@("`@?2!E
M;'-E('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B
M7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(I
M+"`D<&5R;7,M/F=E=%1I=&QE*"1C:&EL9"T^9V5T3F%M92@I*2DL("=H;W)D
M92YS=6-C97-S)RD["B`@("`@("`@)'5R;"`]($AO<F1E.CIA<'!L:6-A=&EO
M;E5R;"@G861M:6XO<&5R;7,O961I="YP:'`G+"!T<G5E*3L*("`@("`@("`D
M=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1U<FPL("=P97)M7VED)RP@)&-H
M:6QD+3YG971)9"@I+"!F86QS92D["B`@("`@("`@:&5A9&5R*"=,;V-A=&EO
M;CH@)R`N("1U<FPI.PH@("`@("`@(&5X:70["B`@("!]"GT*"B1T:71L92`]
M(%\H(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(BD["G)E<75I<F4@2$]2
M1$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["G)E<75I<F4@
M2$]21$5?5$5-4$Q!5$53("X@)R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8R<[
M"B1N;W1I9FEC871I;VXM/FYO=&EF>2AA<G)A>2@G;&ES=&5N97)S)R`]/B`G
M<W1A='5S)RDI.PH*+RH@4F5N9&5R('1H92!F;W)M(&%N9"!T<F5E+B`J+PHD
M=6DM/G)E;F1E<D9O<FTH)V%D9&-H:6QD+G!H<"<I.PIE8VAO("<\8G(@+SXG
M.PHD=6DM/G)E;F1E<E1R964H)'!E<FU?:60I.PH*<F5Q=6ER92!(3U)$15]4
M14U03$%415,@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]A9&UI;B]P97)M<R]I;F1E>"YP:'``
M````````````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$V-3(@
M,3`U,34T,S,W,S0@,#(Q-C`R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+V%D
M;6EN+W!E<FUS+VEN9&5X+G!H<"QV(#$N,3`N,3`N,R`R,#`V+S`Q+S`Q(#(Q
M.C(X.C`U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H
M=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@
M,C`P-2TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9`H@*B!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*B\*"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?
M1DE,15]?*2`N("<O+BXO+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@
M+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O365N=2YP
M:'`G.PH*:68@*"%!=71H.CII<T%D;6EN*"DI('L*("`@($AO<F1E.CIA=71H
M96YT:6-A=&EO;D9A:6QU<F52961I<F5C="@I.PI]"@HD<&5R;5]I9"`](%5T
M:6PZ.F=E=$9O<FU$871A*"=P97)M7VED)RD["@HD=&ET;&4@/2!?*")097)M
M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(I.PIR97%U:7)E($A/4D1%7U1%35!,
M051%4R`N("<O8V]M;6]N+6AE861E<BYI;F,G.PIR97%U:7)E($A/4D1%7U1%
M35!,051%4R`N("<O861M:6XO8V]M;6]N+6AE861E<BYI;F,G.PHD;F]T:69I
M8V%T:6]N+3YN;W1I9GDH87)R87DH)VQI<W1E;F5R<R<@/3X@)W-T871U<R<I
M*3L*"G)E<75I<F5?;VYC92`G2&]R9&4O4&5R;7,O54DN<&AP)SL*)'5I(#T@
M)FYE=R!097)M<U]522@D<&5R;7,I.PHD=6DM/G)E;F1E<E1R964H)'!E<FU?
M:60I.PH*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUF;V]T
M97(N:6YC)SL*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]A9&UI;B]P97)M<R]D96QE
M=&4N<&AP````````````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#0V,38@,3`U,34T,S,W,S0@,#(Q-S0P`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO
M<F1E+V%D;6EN+W!E<FUS+V1E;&5T92YP:'`L=B`Q+C$Y+C@N-"`R,#`V+S`Q
M+S`Q(#(Q.C(X.C`U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR
M,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y
M<FEG:'0@,C`P-2TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9`H@*B!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N
M86UE*%]?1DE,15]?*2`N("<O+BXO+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%
M7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O
M365N=2YP:'`G.PH*:68@*"%!=71H.CII<T%D;6EN*"DI('L*("`@($AO<F1E
M.CIA=71H96YT:6-A=&EO;D9A:6QU<F52961I<F5C="@I.PI]"@HO*B!3970@
M=7`@=&AE(&9O<FT@=F%R:6%B;&5S+B`J+PIR97%U:7)E7V]N8V4@)TAO<F1E
M+U9A<FEA8FQE<RYP:'`G.PHD=F%R<R`]("9687)I86)L97,Z.F=E=$1E9F%U
M;'1687)I86)L97,H*3L*)'!E<FU?:60@/2`D=F%R<RT^9V5T*"=P97)M7VED
M)RD["B1C871E9V]R>2`]("1V87)S+3YG970H)V-A=&5G;W)Y)RD["B1P97)M
M:7-S:6]N(#T@)B1P97)M<RT^9V5T4&5R;6ES<VEO;D)Y260H)'!E<FU?:60I
M.PH*+RH@268@=&AE('!E<FUI<W-I;VX@9F5T8VAE9"!I<R!A;B!E<G)O<B!R
M971U<FX@=&\@<&5R;6ES<VEO;G,@;&ES="X@*B\*:68@*&ES7V$H)'!E<FUI
M<W-I;VXL("=014%27T5R<F]R)RDI('L*("`@("1N;W1I9FEC871I;VXM/G!U
M<V@H7R@B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES
M<VEO;BXB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`D=7)L(#T@2&]R9&4Z.F%P
M<&QI8V%T:6]N57)L*"=A9&UI;B]P97)M<R]I;F1E>"YP:'`G+"!T<G5E*3L*
M("`@(&AE861E<B@G3&]C871I;VXZ("<@+B`D=7)L*3L*("`@(&5X:70["GT*
M"B\J(%-E="!U<"!F;W)M+B`J+PIR97%U:7)E7V]N8V4@)TAO<F1E+U!E<FUS
M+U5)+G!H<"<["B1U:2`]("9N97<@4&5R;7-?54DH)'!E<FUS*3L*)'5I+3YS
M971687)S*"1V87)S*3L*)'5I+3YS971U<$1E;&5T949O<FTH)'!E<FUI<W-I
M;VXI.PH*:68@*"1C;VYF:7)M960@/2`D=6DM/G9A;&ED871E1&5L971E1F]R
M;2@D:6YF;RDI('L*("`@("1R97-U;'0@/2`D<&5R;7,M/G)E;6]V95!E<FUI
M<W-I;VXH)'!E<FUI<W-I;VXL('1R=64I.PH@("`@:68@*&ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U
M<V@H<W!R:6YT9BA?*")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(BDL
M("1P97)M<RT^9V5T5&ET;&4H)'!E<FUI<W-I;VXM/F=E=$YA;64H*2DL("1R
M97-U;'0M/F=E=$UE<W-A9V4H*2DL("=H;W)D92YE<G)O<B<I.PH@("`@?2!E
M;'-E('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B
M4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(I+"`D<&5R;7,M/F=E=%1I
M=&QE*"1P97)M:7-S:6]N+3YG971.86UE*"DI*2P@)VAO<F1E+G-U8V-E<W,G
M*3L*("`@("`@("`D=7)L(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=A9&UI
M;B]P97)M<R]I;F1E>"YP:'`G+"!T<G5E*3L*("`@("`@("!H96%D97(H)TQO
M8V%T:6]N.B`G("X@)'5R;"D["B`@("`@("`@97AI=#L*("`@('T*?2!E;'-E
M:68@*"1C;VYF:7)M960@/3T](&9A;'-E*2!["B`@("`D;F]T:69I8V%T:6]N
M+3YP=7-H*'-P<FEN=&8H7R@B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T
M960N(BDL("1P97)M<RT^9V5T5&ET;&4H)'!E<FUI<W-I;VXM/F=E=$YA;64H
M*2DI+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@)'5R;"`]($AO<F1E.CIA<'!L
M:6-A=&EO;E5R;"@G861M:6XO<&5R;7,O:6YD97@N<&AP)RP@=')U92D["B`@
M("!H96%D97(H)TQO8V%T:6]N.B`G("X@)'5R;"D["B`@("!E>&ET.PI]"@HD
M=&ET;&4@/2!?*")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(I.PIR97%U
M:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+6AE861E<BYI;F,G.PIR
M97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O861M:6XO8V]M;6]N+6AE861E
M<BYI;F,G.PHD;F]T:69I8V%T:6]N+3YN;W1I9GDH87)R87DH)VQI<W1E;F5R
M<R<@/3X@)W-T871U<R<I*3L*"B\J(%)E;F1E<B!T:&4@9F]R;2!A;F0@=')E
M92X@*B\*)'5I+3YR96YD97)&;W)M*"=D96QE=&4N<&AP)RD["F5C:&\@)SQB
M<B`O/B<["B1U:2T^<F5N9&5R5')E92@D<&5R;5]I9"D["@IR97%U:7)E($A/
M4D1%7U1%35!,051%4R`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]A9&UI
M;B]S971U<```````````````````````````````````````````````````
M````````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S0@,#$W-S$Q`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+V%D;6EN+W-E='5P+V1I9F8N<&AP````````````````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-C4P-R`Q,#4Q-30S,S<S
M-"`P,C$T,C$`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J(%-C<FEP="!T;R!S:&]W('1H92!D:69F97)E
M;F-E<R!B971W965N('1H92!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L
M>0H@*B!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX*("H*("H@)$AO<F1E.B!H
M;W)D92]A9&UI;B]S971U<"]D:69F+G!H<"QV(#$N-"XQ,"XU(#(P,#8O,#4O
M,C,@,#(Z,3,Z-#(@<V5L<VMY($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T
M+3(P,#8@5&AE($AO<F1E(%!R;VIE8W0@*&AT='`Z+R]W=W<N:&]R9&4N;W)G
M+RD*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*B\*"F1E9FEN92@G2$]21$5?0D%312<L(&1I
M<FYA;64H7U]&24Q%7U\I("X@)R\N+B\N+B<I.PIR97%U:7)E7V]N8V4@2$]2
M1$5?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D
M92]&;W)M+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O0V]N9FEG+G!H<"<[
M"G)E<75I<F5?;VYC92`G2&]R9&4O5&5M<&QA=&4N<&AP)SL*:6YC;'5D95]O
M;F-E("=497AT+T1I9F8N<&AP)SL*:6YC;'5D95]O;F-E("=497AT+T1I9F8O
M4F5N9&5R97(N<&AP)SL*"FEF("@A075T:#HZ:7-!9&UI;B@I*2!["B`@("!(
M;W)D93HZ9F%T86PH)T9O<F)I9&1E;BXG+"!?7T9)3$5?7RP@7U],24Y%7U\I
M.PI]"@HO*B!3970@=7`@=&AE(&1I9F8@<F5N9&5R97(N("HO"B1R96YD97)?
M='EP92`](%5T:6PZ.F=E=$9O<FU$871A*"=R96YD97(G+"`G:6YL:6YE)RD[
M"FEN8VQU9&5?;VYC92`G5&5X="]$:69F+U)E;F1E<F5R+R<@+B`D<F5N9&5R
M7W1Y<&4@+B`G+G!H<"<["B1C;&%S<R`]("=497AT7T1I9F9?4F5N9&5R97)?
M)R`N("1R96YD97)?='EP93L*)')E;F1E<F5R(#T@)FYE=R`D8VQA<W,H*3L*
M"B\J*@H@*B!0<FEV871E(&9U;F-T:6]N('1O(')E;F1E<B!T:&4@9&EF9F5R
M96YC97,@9F]R(&$@<W!E8VEF:6,@87!P+@H@*B\*9G5N8W1I;VX@7V=E=$1I
M9F8H)&%P<"D*>PH@("`@9VQO8F%L("1R96YD97)E<BP@)')E9VES=')Y.PH*
M("`@("\J(%)E860@=&AE(&5X:7-T:6YG(&-O;F9I9W5R871I;VXN("HO"B`@
M("`D8W5R<F5N=%]C;VYF:6<@/2`G)SL*("`@("1P871H(#T@)')E9VES=')Y
M+3YG970H)V9I;&5R;V]T)RP@)&%P<"D@+B`G+V-O;F9I9R<["B`@("`D8W5R
M<F5N=%]C;VYF:6<@/2!`9FEL95]G971?8V]N=&5N=',H)'!A=&@@+B`G+V-O
M;F8N<&AP)RD["@H@("`@+RH@0V%L8W5L871E('1H92!D:69F97)E;F-E<RX@
M*B\*("`@("1D:69F(#T@)FYE=R!497AT7T1I9F8H97AP;&]D92@B7&XB+"`D
M8W5R<F5N=%]C;VYF:6<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("!E
M>'!L;V1E*")<;B(L("1?4T534TE/3ELG7V-O;F9I9R==6R1A<'!=*2D["B`@
M("`D9&EF9B`]("1R96YD97)E<BT^<F5N9&5R*"1D:69F*3L*("`@(&EF("@A
M96UP='DH)&1I9F8I*2!["B`@("`@("`@<F5T=7)N("1D:69F.PH@("`@?2!E
M;'-E('L*("`@("`@("!R971U<FX@7R@B3F\@8VAA;F=E+B(I.PH@("`@?0I]
M"@HD9&EF9G,@/2!A<G)A>2@I.PHO*B!/;FQY(&)O=&AE<B!T;R!D;R!A;GET
M:&EN9R!I9B!T:&5R92!I<R!A;GD@8V]N9FEG+B`J+PII9B`H(65M<'1Y*"1?
M4T534TE/3ELG7V-O;F9I9R==*2D@>PH@("`@+RH@4V5T('5P('1H92!T;V=G
M;&4@8G5T=&]N(&9O<B!I;FQI;F4O=6YI9FEE9"X@*B\*("`@("1U<FP@/2!(
M;W)D93HZ87!P;&EC871I;VY5<FPH)V%D;6EN+W-E='5P+V1I9F8N<&AP)RD[
M"B`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1U<FPL("=R96YD97(G
M+"`H)')E;F1E<E]T>7!E(#T]("=I;FQI;F4G*2`_("=U;FEF:65D)R`Z("=I
M;FQI;F4G*3L*"B`@("!I9B`H)&%P<"`](%5T:6PZ.F=E=$9O<FU$871A*"=A
M<'`G*2D@>PH@("`@("`@("\J($AA;F1L92!A('-I;F=L92!A<'`@<F5Q=65S
M="X@*B\*("`@("`@("`D=&]G9VQE7W)E;F1E<F5R(#T@2&]R9&4Z.FQI;FLH
M)'5R;"`N("<C)R`N("1A<'`I("X@*"@D<F5N9&5R7W1Y<&4@/3T@)VEN;&EN
M92<I(#\@7R@B=6YI9FEE9"(I(#H@7R@B:6YL:6YE(BDI("X@)SPO83XG.PH@
M("`@("`@("1D:69F(#T@7V=E=$1I9F8H)&%P<"D["B`@("`@("`@:68@*"1R
M96YD97)?='EP92`A/2`G:6YL:6YE)RD@>PH@("`@("`@("`@("`D9&EF9B`]
M(&AT;6QS<&5C:6%L8VAA<G,H)&1I9F8I.PH@("`@("`@('T*("`@("`@("`D
M9&EF9G-;72`](&%R<F%Y*"=A<'`G("`]/B`D87!P+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@)V1I9F8G(#T^("1D:69F+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@)W1O9V=L95]R96YD97)E<B<@/3X@)'1O9V=L95]R96YD97)E
M<BD["B`@("!](&5L<V4@>PH@("`@("`@("\J($QI<W0@86QL('1H92!A<'!S
M('=I=&@@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN("HO"B`@("`@("`@:W-O
M<G0H)%]315-324].6R=?8V]N9FEG)UTI.PH@("`@("`@(&9O<F5A8V@@*"1?
M4T534TE/3ELG7V-O;F9I9R==(&%S("1A<'`@/3X@)&-O;F9I9RD@>PH@("`@
M("`@("`@("`D=&]G9VQE7W)E;F1E<F5R(#T@2&]R9&4Z.FQI;FLH)'5R;"`N
M("<C)R`N("1A<'`I("X@*"@D<F5N9&5R7W1Y<&4@/3T@)VEN;&EN92<I(#\@
M7R@B=6YI9FEE9"(I(#H@7R@B:6YL:6YE(BDI("X@)SPO83XG.PH@("`@("`@
M("`@("`D9&EF9B`](%]G971$:69F*"1A<'`I.PH@("`@("`@("`@("!I9B`H
M)')E;F1E<E]T>7!E("$]("=I;FQI;F4G*2!["B`@("`@("`@("`@("`@("`D
M9&EF9B`](&AT;6QS<&5C:6%L8VAA<G,H)&1I9F8I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1D:69F<UM=(#T@87)R87DH)V%P<"<@(#T^("1A<'`L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1I9F8G(#T^("1D:69F
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T;V=G;&5?<F5N9&5R
M97(G(#T^("1T;V=G;&5?<F5N9&5R97(I.PH@("`@("`@('T*("`@('T*?0H*
M+RH@4V5T('5P('1H92!T96UP;&%T92X@*B\*)'1E;7!L871E(#T@)FYE=R!(
M;W)D95]496UP;&%T92@I.PHD=&5M<&QA=&4M/G-E=$]P=&EO;B@G9V5T=&5X
M="<L('1R=64I.PHD=&5M<&QA=&4M/G-E="@G9&EF9G,G+"`D9&EF9G,L('1R
M=64I.PH*)'1I=&QE(#T@7R@B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<R(I
M.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+6AE861E<BYI
M;F,G.PIE8VAO("1T96UP;&%T92T^9F5T8V@H2$]21$5?5$5-4$Q!5$53("X@
M)R]A9&UI;B]S971U<"]D:69F+FAT;6PG*3L*<F5Q=6ER92!(3U)$15]414U0
M3$%415,@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]A9&UI;B]S971U<"]C;VYF:6<N<&AP````````````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3$V-S$@,3`U,34T,S,W
M,S0@,#(Q-S4T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+V%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`L=B`Q+C(T+C0N,3`@,C`P-B\P,R\S,"`Q,#HQ-3HS,"!S
M96QS:WD@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:&%R;&5S
M($HN($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@
M,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("HO"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)
M3$5?7RD@+B`G+RXN+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@
M)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T9O<FTN<&AP
M)SL*<F5Q=6ER95]O;F-E("=(;W)D92]&;W)M+T%C=&EO;BYP:'`G.PIR97%U
M:7)E7V]N8V4@)TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP)SL*<F5Q=6ER95]O
M;F-E("=(;W)D92]#;VYF:6<N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]6
M87)I86)L97,N<&AP)SL*"FEF("@A075T:#HZ:7-!9&UI;B@I*2!["B`@("!(
M;W)D93HZ9F%T86PH)T9O<F)I9&1E;BXG+"!?7T9)3$5?7RP@7U],24Y%7U\I
M.PI]"@II9B`H(55T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G9&]M>&UL)RD@)B8@
M(55T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G9&]M)RDI('L*("`@($AO<F1E.CIF
M871A;"@G66]U(&YE960@=&AE(&1O;7AM;"!O<B!D;VT@4$A0(&5X=&5N<VEO
M;B!T;R!U<V4@=&AE(&-O;F9I9W5R871I;VX@=&]O;"XG+"!?7T9)3$5?7RP@
M7U],24Y%7U\I.PI]"@HD87!P(#T@571I;#HZ9V5T1F]R;41A=&$H)V%P<"<I
M.PHD87!P;F%M92`]("1R96=I<W1R>2T^9V5T*"=N86UE)RP@)&%P<"D["B1T
M:71L92`]('-P<FEN=&8H7R@B)7,@4V5T=7`B*2P@)&%P<&YA;64I.PH*:68@
M*"1A<'`@/3T](&YU;&P@)B8*("`@(&EN7V%R<F%Y*"1A<'`L("1R96=I<W1R
M>2T^;&ES=$%P<',H87)R87DH)VEN86-T:79E)RP@)VAI9&1E;B<L("=N;W1O
M;VQB87(G+"`G86-T:79E)RP@)V%D;6EN)RDI*2D@>PH@("`@)&YO=&EF:6-A
M=&EO;BT^<'5S:"A?*"));G9A;&ED(&%P<&QI8V%T:6]N+B(I+"`G:&]R9&4N
M97)R;W(G*3L*("`@("1U<FP@/2!(;W)D93HZ87!P;&EC871I;VY5<FPH)V%D
M;6EN+W-E='5P+VEN9&5X+G!H<"<L('1R=64I.PH@("`@:&5A9&5R*"=,;V-A
M=&EO;CH@)R`N("1U<FPI.PH@("`@97AI=#L*?0H*)'9A<G,@/2!687)I86)L
M97,Z.F=E=$1E9F%U;'1687)I86)L97,H*3L*)&9O<FT@/2`F;F5W($-O;F9I
M9T9O<FTH)'9A<G,L("1A<'`I.PHD9F]R;2T^<V5T0G5T=&]N<RAS<')I;G1F
M*%\H(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB*2P@)&%P<&YA;64I*3L*
M:68@*&9I;&5?97AI<W1S*"1R96=I<W1R>2T^9V5T*"=F:6QE<F]O="<L("1A
M<'`I("X@)R]C;VYF:6<O8V]N9BYP:'`N8F%K)RDI('L*("`@("1F;W)M+3YA
M<'!E;F1"=71T;VYS*%\H(E)E=F5R="!#;VYF:6=U<F%T:6]N(BDI.PI]"@HD
M<&AP(#T@)R<["FEF("A5=&EL.CIG971&;W)M1&%T82@G<W5B;6ET8G5T=&]N
M)RD@/3T@7R@B4F5V97)T($-O;F9I9W5R871I;VXB*2D@>PH@("`@)'!A=&@@
M/2`D<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G+"`D87!P*2`N("<O8V]N9FEG
M)SL*("`@(&EF("A`8V]P>2@D<&%T:"`N("<O8V]N9BYP:'`N8F%K)RP@)'!A
M=&@@+B`G+V-O;F8N<&AP)RDI('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP
M=7-H*%\H(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!2
M96QO860@=&\@<V5E(&-H86YG97,N(BDL("=H;W)D92YS=6-C97-S)RD["B`@
M("`@("`@0'5N;&EN:R@D<&%T:"`N("<O8V]N9BYP:'`N8F%K)RD["B`@("!]
M(&5L<V4@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B0V]U;&0@
M;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(I+"`G:&]R9&4N97)R;W(G*3L*
M("`@('T*?2!E;'-E:68@*"1F;W)M+3YV86QI9&%T92@D=F%R<RDI('L*("`@
M("1C;VYF:6<@/2`F;F5W($AO<F1E7T-O;F9I9R@D87!P*3L*("`@("1P:'`@
M/2`D8V]N9FEG+3YG96YE<F%T95!(4$-O;F9I9R@D=F%R<RD["B`@("`D<&%T
M:"`]("1R96=I<W1R>2T^9V5T*"=F:6QE<F]O="<L("1A<'`I("X@)R]C;VYF
M:6<G.PH@("`@:68@*&9I;&5?97AI<W1S*"1P871H("X@)R]C;VYF+G!H<"<I
M*2!["B`@("`@("`@:68@*$!C;W!Y*"1P871H("X@)R]C;VYF+G!H<"<L("1P
M871H("X@)R]C;VYF+G!H<"YB86LG*2D@>PH@("`@("`@("`@("`D;F]T:69I
M8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B4W5C8V5S<V9U;&QY('-A=F5D('1H
M92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(I+"!5=&EL.CIR96%L
M4&%T:"@D<&%T:"`N("<O8V]N9BYP:'`N8F%K)RDI+"`G:&]R9&4N<W5C8V5S
M<R<I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1N;W1I9FEC871I
M;VXM/G!U<V@H<W!R:6YT9BA?*")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P
M(&-O;F9I9W5R871I;VX@9FEL92`E<RXB*2P@571I;#HZ<F5A;%!A=&@H)'!A
M=&@@+B`G+V-O;F8N<&AP+F)A:R<I*2P@)VAO<F1E+G=A<FYI;F<G*3L*("`@
M("`@("!]"B`@("!]"B`@("!I9B`H)&9P(#T@0&9O<&5N*"1P871H("X@)R]C
M;VYF+G!H<"<L("=W)RDI('L*("`@("`@("`O*B!#86X@=W)I=&4L('-O(&]U
M='!U="!T;R!F:6QE+B`J+PH@("`@("`@(&9W<FET92@D9G`L(%-T<FEN9SHZ
M8V]N=F5R=$-H87)S970H)'!H<"P@3DQ3.CIG971#:&%R<V5T*"DL("=I<V\M
M.#@U.2TQ)RDI.PH@("`@("`@(&9C;&]S92@D9G`I.PH@("`@("`@("1N;W1I
M9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")3=6-C97-S9G5L;'D@=W)O=&4@
M)7,B*2P@571I;#HZ<F5A;%!A=&@H)'!A=&@@+B`G+V-O;F8N<&AP)RDI+"`G
M:&]R9&4N<W5C8V5S<R<I.PH@("`@("`@("1R96=I<W1R>2T^8VQE87)#86-H
M92@I.PH@("`@("`@(&AE861E<B@G3&]C871I;VXZ("<@+B!(;W)D93HZ87!P
M;&EC871I;VY5<FPH)V%D;6EN+W-E='5P+VEN9&5X+G!H<"<L('1R=64I*3L*
M("`@("`@("!E>&ET.PH@("`@?2!E;'-E('L*("`@("`@("`O*B!#86YN;W0@
M=W)I=&4N("HO"B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F
M*%\H(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N
M(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V
M92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O
M9&4@8F5L;W<@=&\@)7,N(BDL(%5T:6PZ.G)E86Q0871H*"1P871H("X@)R]C
M;VYF+G!H<"<I+"!(;W)D93HZ;&EN:RA(;W)D93HZ=7)L*"=I;F1E>"YP:'`G
M*2`N("<C=7!D871E)RP@7R@B4V5T=7`B*2D@+B!?*")3971U<"(I("X@)SPO
M83XG+"!5=&EL.CIR96%L4&%T:"@D<&%T:"`N("<O8V]N9BYP:'`G*2DL("=H
M;W)D92YW87)N:6YG)RP@87)R87DH)V-O;G1E;G0N<F%W)RDI.PH@("`@("`@
M("\J(%-A=F4@=&\@<V5S<VEO;BX@*B\*("`@("`@("`D7U-%4U-)3TY;)U]C
M;VYF:6<G75LD87!P72`]("1P:'`["B`@("!]"GT@96QS96EF("@D9F]R;2T^
M:7-3=6)M:71T960H*2D@>PH@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")4
M:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@
M4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L9"XB*2P@)VAO
M<F1E+F5R<F]R)RD["GT*"B\J(%)E;F1E<B!T:&4@8V]N9FEG=7)A=&EO;B!F
M;W)M+B`J+PIR97%U:7)E7V]N8V4@)TAO<F1E+U5)+U9A<E)E;F1E<F5R+G!H
M<"<["B1R96YD97)E<B`]("9N97<@2&]R9&5?1F]R;5]296YD97)E<B@I.PHD
M<F5N9&5R97(M/G-E=$%T=')#;VQU;6Y7:61T:"@G-3`E)RD["B1F;W)M(#T@
M571I;#HZ8G5F9F5R3W5T<'5T*&%R<F%Y*"1F;W)M+"`G<F5N9&5R06-T:79E
M)RDL("1R96YD97)E<BP@)'9A<G,L("=C;VYF:6<N<&AP)RP@)W!O<W0G*3L*
M"@HO*B!3970@=7`@=&AE('1E;7!L871E+B`J+PIR97%U:7)E7V]N8V4@)TAO
M<F1E+U1E;7!L871E+G!H<"<["B1T96UP;&%T92`]("9N97<@2&]R9&5?5&5M
M<&QA=&4H*3L*)'1E;7!L871E+3YS970H)W!H<"<L(&AT;6QS<&5C:6%L8VAA
M<G,H)'!H<"DL('1R=64I.PHO*B!#<F5A=&4@=&AE(&QI;FL@9F]R('1H92!D
M:69F('!O<'5P(&]N;'D@:68@<W1O<F5D(&EN('-E<W-I;VXN("HO"FEF("@A
M96UP='DH)%]315-324].6R=?8V]N9FEG)UU;)&%P<%TI*2!["B`@("!(;W)D
M93HZ861D4V-R:7!T1FEL92@G<&]P=7`N:G,G+"`G:&]R9&4G+"!T<G5E*3L*
M("`@("1U<FP@/2!(;W)D93HZ87!P;&EC871I;VY5<FPH)V%D;6EN+W-E='5P
M+V1I9F8N<&AP)RD["B`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1U
M<FPL("=A<'`G+"`D87!P*3L*("`@("1L:6YK(#T@2&]R9&4Z.FQI;FLH)R,G
M+"`G)RP@)R<L("<G+"`G<&]P=7`H7"<G("X@)'5R;"`N("=<)RP@-C0P+"`T
M.#`I.R!R971U<FX@9F%L<V4[)RD@+B!?*")S:&]W(&1I9F9E<F5N8V5S(BD@
M+B`G/"]A/B<["B`@("`D=&5M<&QA=&4M/G-E="@G9&EF9E]P;W!U<"<L("1L
M:6YK*3L*?0HD=&5M<&QA=&4M/G-E="@G9F]R;2<L("1F;W)M*3L*)'1E;7!L
M871E+3YS970H)VYO=&EF>2<L(%5T:6PZ.F)U9F9E<D]U='!U="AA<G)A>2@D
M;F]T:69I8V%T:6]N+"`G;F]T:69Y)RDI*3L*)'1E;7!L871E+3YS971/<'1I
M;VXH)V=E='1E>'0G+"!T<G5E*3L*"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53
M("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["G)E<75I<F4@2$]21$5?5$5-4$Q!
M5$53("X@)R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8R<["F5C:&\@)'1E;7!L
M871E+3YF971C:"A(3U)$15]414U03$%415,@+B`G+V%D;6EN+W-E='5P+V-O
M;F9I9RYH=&UL)RD["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM
M;VXM9F]O=&5R+FEN8R<["@``````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O861M:6XO<V5T=7`O:6YD97@N<&AP````
M````````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#(R,C4Q(#$P
M-3$U-#,S-S,T(#`R,38Q,@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]A9&UI
M;B]S971U<"]I;F1E>"YP:'`L=B`Q+C(X+C0N,3(@,C`P-B\P,R\R."`Q,CHS
M,3HP."!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:&%R
M;&5S($HN($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG
M:'0@,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?
M7T9)3$5?7RD@+B`G+RXN+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%
M("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+U1E;7!L
M871E+G!H<"<["@II9B`H(4%U=&@Z.FES061M:6XH*2D@>PH@("`@2&]R9&4Z
M.F9A=&%L*"=&;W)B:61D96XN)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*?0H*
M+RHJ"B`J(%)E='5R;G,@=&AE($-64R!V97)S:6]N(&9O<B!A(&=I=F5N(&9I
M;&4N"B`J+PIF=6YC=&EO;B!?9V5T5F5R<VEO;B@D9FEL92D*>PH@("`@)'-I
M>F4@/2!`9FEL97-I>F4H)&9I;&4I.PH@("`@:68@*"$D<VEZ92!\?"`A:7-?
M<F5S;W5R8V4H)&9P(#T@0&9O<&5N*"1F:6QE+"`G<B<I*2D@>PH@("`@("`@
M(')E='5R;B!F86QS93L*("`@('T*("`@("1D871A(#T@0&9R96%D*"1F<"P@
M)'-I>F4I.PH@("`@:68@*'!R96=?;6%T8V@H)R]<)"XJ/V-O;F9<+GAM;"QV
M("@N*C\I("XJ7"0O)RP@)&1A=&$L("1M871C:"DI('L*("`@("`@("!R971U
M<FX@)&UA=&-H6S%=.PH@("`@?2!E;'-E('L*("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"GT*"B\J*@H@*B!$;V5S(&%N($944"!U<&QO860@=&\@<V%V
M92!T:&4@8V]N9FEG=7)A=&EO;BX*("HO"F9U;F-T:6]N(%]U<&QO861&5%`H
M)'!A<F%M<RD*>PH@("`@9VQO8F%L("1R96=I<W1R>2P@)&YO=&EF:6-A=&EO
M;CL*"B`@("!R97%U:7)E7V]N8V4@)U9&4RYP:'`G.PH@("`@)'!A<F%M<ULG
M:&]S='-P96,G72`]("=L;V-A;&AO<W0G.PH@("`@)'9F<R`]("961E,Z.G-I
M;F=L971O;B@G9G1P)RP@)'!A<F%M<RD["B`@("!I9B`H:7-?82@D=F9S+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS
M<')I;G1F*%\H(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@
M=7-I;F<@1E10.B`E<R(I+"`D<&%R86US6R=H;W-T<W!E8R==+"`D=F9S+3YG
M971-97-S86=E*"DI+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!R971U<FX@
M9F%L<V4["B`@("!]"@H@("`@+RH@3&]O<"!T:')O=6=H('1H92!C;VYF:6<@
M86YD('=R:71E('1O($944"X@*B\*("`@("1N;U]E<G)O<G,@/2!T<G5E.PH@
M("`@9F]R96%C:"`H)%]315-324].6R=?8V]N9FEG)UT@87,@)&%P<"`]/B`D
M8V]N9FEG*2!["B`@("`@("`@)'!A=&@@/2`D<F5G:7-T<GDM/F=E="@G9FEL
M97)O;W0G+"`D87!P*2`N("<O8V]N9FEG)SL*("`@("`@("`O*B!4<GD@=&\@
M8F%C:R!U<"!T:&4@8W5R<F5N="!C;VYF+G!H<"X@*B\*("`@("`@("!I9B`H
M)'9F<RT^97AI<W1S*"1P871H+"`G8V]N9BYP:'`G*2D@>PH@("`@("`@("`@
M("!I9B`H*"1R97-U;'0@/2`D=F9S+3YR96YA;64H)'!A=&@L("=C;VYF+G!H
M<"<L("1P871H+"`G+V-O;F8N<&AP+F)A:R<I*2`]/3T@=')U92D@>PH@("`@
M("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")3=6-C97-S9G5L
M;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN(BDL("=H;W)D92YS=6-C
M97-S)RD["B`@("`@("`@("`@('T@96QS96EF("AI<U]A*"1R97-U;'0L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM
M/G!U<V@H<W!R:6YT9BA?*")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF
M:6=U871I;VXZ("5S(BDL("1R97-U;'0M/F=E=$UE<W-A9V4H*2DL("=H;W)D
M92YE<G)O<B<I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")#;W5L9"!N;W0@<V%V92!A(&)A
M8VMU<"!C;VYF:6=U871I;VXN(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`D=W)I=&4@/2`D=F9S+3YW<FET
M941A=&$H)'!A=&@L("=C;VYF+G!H<"<L("1C;VYF:6<I.PH@("`@("`@(&EF
M("AI<U]A*"1W<FET92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D
M;F]?97)R;W)S(#T@9F%L<V4["B`@("`@("`@("`@("1N;W1I9FEC871I;VXM
M/G!U<V@H<W!R:6YT9BA?*")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO
M;B!F;W(@7"(E<UPB.B`E<R(I+"`D87!P+"`D=W)I=&4M/F=E=$UE<W-A9V4H
M*2DL("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")3=6-C97-S9G5L
M;'D@=W)O=&4@)7,B*2P@571I;#HZ<F5A;%!A=&@H)'!A=&@@+B`G+V-O;F8N
M<&AP)RDI+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@("`@("`@("!U;G-E="@D
M7U-%4U-)3TY;)U]C;VYF:6<G75LD87!P72D["B`@("`@("`@?0H@("`@?0H@
M("`@)')E9VES=')Y+3YC;&5A<D-A8VAE*"D["B`@("!R971U<FX@)&YO7V5R
M<F]R<SL*?0H*+RH@4V5T('5P('-O;64@:6-O;G,N("HO"B1S=6-C97-S(#T@
M2&]R9&4Z.FEM9R@G86QE<G1S+W-U8V-E<W,N<&YG)RP@)R<L("<G+"`D<F5G
M:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*3L*)'=A<FYI;F<@/2!(;W)D
M93HZ:6UG*"=A;&5R=',O=V%R;FEN9RYP;F<G+"`G)RP@)R<L("1R96=I<W1R
M>2T^9V5T26UA9V5$:7(H)VAO<F1E)RDI.PHD97)R;W(@/2!(;W)D93HZ:6UG
M*"=A;&5R=',O97)R;W(N<&YG)RP@)R<L("<G+"`D<F5G:7-T<GDM/F=E=$EM
M86=E1&ER*"=H;W)D92<I*3L*"B1C;VYF7W5R;"`]($AO<F1E.CIA<'!L:6-A
M=&EO;E5R;"@G861M:6XO<V5T=7`O8V]N9FEG+G!H<"<I.PHD82`]("1R96=I
M<W1R>2T^;&ES=$%P<',H87)R87DH)VEN86-T:79E)RP@)VAI9&1E;B<L("=N
M;W1O;VQB87(G+"`G86-T:79E)RP@)V%D;6EN)RDI.PHD87!P<R`](&%R<F%Y
M*"D["B1I(#T@+3$["F9O<F5A8V@@*"1A(&%S("1A<'`I('L*("`@("\J(%-K
M:7`@87!P(&EF(&YO(&-O;F8N>&UL(&9I;&4N("HO"B`@("`D<&%T:"`]("1R
M96=I<W1R>2T^9V5T*"=F:6QE<F]O="<L("1A<'`I("X@)R]C;VYF:6<G.PH@
M("`@:68@*"%F:6QE7V5X:7-T<R@D<&%T:"`N("<O8V]N9BYX;6PG*2D@>PH@
M("`@("`@(&-O;G1I;G5E.PH@("`@?0H*("`@("1I*RL["B`@("`D<&%T:"`]
M("1R96=I<W1R>2T^9V5T*"=F:6QE<F]O="<L("1A<'`I("X@)R]C;VYF:6<G
M.PH*("`@("1C;VYF7VQI;FL@/2!5=&EL.CIA9&1087)A;65T97(H)&-O;F9?
M=7)L+"`G87!P)RP@)&%P<"D["B`@("`D8V]N9E]L:6YK(#T@2&]R9&4Z.FQI
M;FLH)&-O;F9?;&EN:RP@<W!R:6YT9BA?*")#;VYF:6=U<F4@)7,B*2P@)&%P
M<"DI.PH@("`@)&%P<'-;)&E=6R=S;W)T)UT@/2`D<F5G:7-T<GDM/F=E="@G
M;F%M92<L("1A<'`I("X@)R`H)R`N("1A<'`@+B`G*2<["B`@("`D87!P<ULD
M:5U;)VYA;64G72`]("1C;VYF7VQI;FL@+B`D87!P<ULD:5U;)W-O<G0G72`N
M("<\+V$^)SL*("`@("1A<'!S6R1I75LG=F5R<VEO;B==(#T@)R<["B`@("!I
M9B`H:7-?<F5A9&%B;&4H)')E9VES=')Y+3YG970H)V9I;&5R;V]T)RP@)&%P
M<"D@+B`G+VQI8B]V97)S:6]N+G!H<"<I*2!["B`@("`@("`@<F5Q=6ER92`D
M<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G+"`D87!P*2`N("<O;&EB+W9E<G-I
M;VXN<&AP)SL*("`@("`@("`D=F5R<VEO;E]C;VYS=&%N="`](%-T<FEN9SHZ
M=7!P97(H)&%P<"D@+B`G7U9%4E-)3TXG.PH@("`@("`@(&EF("AD969I;F5D
M*"1V97)S:6]N7V-O;G-T86YT*2D@>PH@("`@("`@("`@("`D87!P<ULD:5U;
M)W9E<G-I;VXG72`](&-O;G-T86YT*"1V97)S:6]N7V-O;G-T86YT*3L*("`@
M("`@("!]"B`@("!]"B`@("!I9B`H(69I;&5?97AI<W1S*"1P871H("X@)R]C
M;VYF+G!H<"<I*2!["B`@("`@("`@+RH@3F\@8V]N9BYP:'`@97AI<W1S+B`J
M+PH@("`@("`@("1A<'!S6R1I75LG8V]N9B==(#T@)&-O;F9?;&EN:R`N("1E
M<G)O<B`N("<\+V$^)SL*("`@("`@("`D87!P<ULD:5U;)W-T871U<R==(#T@
M7R@B36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T
M92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC871I;VXN
M(BD["B`@("!](&5L<V4@>PH@("`@("`@("\J($$@8V]N9BYP:'`@97AI<W1S
M+"!G970@=&AE('AM;"!V97)S:6]N+B`J+PH@("`@("`@(&EF("@H)'AM;%]V
M97(@/2!?9V5T5F5R<VEO;B@D<&%T:"`N("<O8V]N9BYX;6PG*2D@/3T](&9A
M;'-E*2!["B`@("`@("`@("`@("1A<'!S6R1I75LG8V]N9B==(#T@)&-O;F9?
M;&EN:R`N("1W87)N:6YG("X@)SPO83XG.PH@("`@("`@("`@("`D87!P<ULD
M:5U;)W-T871U<R==(#T@7R@B3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA
M;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(BD[
M"B`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@('T*("`@("`@("`O*B!'
M970@=&AE(&=E;F5R871E9"!P:'`@=F5R<VEO;BX@*B\*("`@("`@("!I9B`H
M*"1P:'!?=F5R(#T@7V=E=%9E<G-I;VXH)'!A=&@@+B`G+V-O;F8N<&AP)RDI
M(#T]/2!F86QS92D@>PH@("`@("`@("`@("`O*B!.;R!V97)S:6]N(&9O=6YD
M(&EN(&=E;F5R871E9"!P:'`L('-U9V=E<W0@<F5G96YA<F%T:6YG"B`@("`@
M("`@("`@("`J(&IU<W0@:6X@8V%S92X@*B\*("`@("`@("`@("`@)&%P<'-;
M)&E=6R=C;VYF)UT@/2`D8V]N9E]L:6YK("X@)'=A<FYI;F<@+B`G/"]A/B<[
M"B`@("`@("`@("`@("1A<'!S6R1I75LG<W1A='5S)UT@/2!?*").;R!V97)S
M:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C
M;VYF:6=U<F%T:6]N+B(I.PH@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@
M("!]"@H@("`@("`@(&EF("@D>&UL7W9E<B`A/2`D<&AP7W9E<BD@>PH@("`@
M("`@("`@("`O*B!697)S:6]N<R!A<F4@;F]T('1H92!S86UE+"!C;VYF:6=U
M<F%T:6]N(&ES(&]U="!O9B!D871E+B`J+PH@("`@("`@("`@("`D87!P<ULD
M:5U;)V-O;F8G72`]("1C;VYF7VQI;FL@+B`D97)R;W(@+B`G/"]A/B<["B`@
M("`@("`@("`@("1A<'!S6R1I75LG<W1A='5S)UT@/2!?*")#;VYF:6=U<F%T
M:6]N(&ES(&]U="!O9B!D871E+B(I.PH@("`@("`@("`@("!C;VYT:6YU93L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!#;VYF:6=U<F%T:6]N
M(&ES(&]K+B`J+PH@("`@("`@("`@("`D87!P<ULD:5U;)V-O;F8G72`]("1C
M;VYF7VQI;FL@+B`D<W5C8V5S<R`N("<\+V$^)SL*("`@("`@("`@("`@)&%P
M<'-;)&E=6R=S=&%T=7,G72`](%\H(D%P<&QI8V%T:6]N(&ES(')E861Y+B(I
M.PH@("`@("`@('T*("`@('T*?0H*+RH@4V]R="!T:&4@87!P<R!B>2!N86UE
M+B`J+PIR97%U:7)E7V]N8V4@)TAO<F1E+T%R<F%Y+G!H<"<["DAO<F1E7T%R
M<F%Y.CIA<G)A>5-O<G0H)&%P<',L("=S;W)T)RD["@HO*B!3970@=7`@86YY
M(&%C=&EO;G,@=&AA="!M87D@8F4@;V9F97)E9"X@*B\*)&%C=&EO;G,@/2!A
M<G)A>2@I.PHD9G1P9F]R;2`]("<G.PII9B`H(65M<'1Y*"1?4T534TE/3ELG
M7V-O;F9I9R==*2D@>PH@("`@2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)W!O<'5P
M+FIS)RP@)VAO<F1E)RP@=')U92D["B`@("`D=7)L(#T@2&]R9&4Z.F%P<&QI
M8V%T:6]N57)L*"=A9&UI;B]S971U<"]D:69F+G!H<"<I.PH@("`@)&%C=&EO
M;B`](%\H(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V
M960@86YD('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A=&EO;BXB*3L*
M("`@("1A8W1I;VYS6UT@/2!A<G)A>2@G:6-O;B<@/3X@2&]R9&4Z.FEM9R@G
M<V5A<F-H+G!N9R<L("<G+"`G86QI9VX](FUI9&1L92(G+"`D<F5G:7-T<GDM
M/F=E=$EM86=E1&ER*"=H;W)D92<I*2P*("`@("`@("`@("`@("`@("`@("`@
M("`G;&EN:R<@/3X@2&]R9&4Z.FQI;FLH)R,G+"`G)RP@)R<L("<G+"`G<&]P
M=7`H7"<G("X@)'5R;"`N("=<)RPV-#`L(#0X,"D[(')E='5R;B!F86QS93LG
M*2`N("1A8W1I;VX@+B`G/"]A/B<I.PH*("`@("1U<FP@/2!(;W)D93HZ87!P
M;&EC871I;VY5<FPH)V%D;6EN+W-E='5P+W-C<FEP=',N<&AP)RD["B`@("`O
M*B!!8W1I;VX@=&\@9&]W;FQO860@=&AE(&-O;F9I9W5R871I;VX@=7!G<F%D
M92!02%`@<V-R:7!T+B`J+PH@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E
M<B@D=7)L+"!A<G)A>2@G<V5T=7`G(#T^("=C;VYF)RP@)W1Y<&4G(#T^("=P
M:'`G*2D["B`@("`D86-T:6]N(#T@7R@B1&]W;FQO860@9V5N97)A=&5D(&-O
M;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB*3L*("`@("1A8W1I;VYS6UT@
M/2!A<G)A>2@G:6-O;B<@/3X@2&]R9&4Z.FEM9R@G9&]W;FQO860N<&YG)RP@
M)R<L("=A;&EG;CTB;6ED9&QE(B<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H
M)VAO<F1E)RDI+`H@("`@("`@("`@("`@("`@("`@("`@("=L:6YK)R`]/B!(
M;W)D93HZ;&EN:R@D=7)L*2`N("1A8W1I;VX@+B`G/"]A/B<I.PH@("`@+RH@
M06-T:6]N('1O('-A=F4@=&AE(&-O;F9I9W5R871I;VX@=7!G<F%D92!02%`@
M<V-R:7!T+B`J+PH@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L
M+"`G<V%V92<L("=T;7`G*3L*("`@("1A8W1I;VX@/2!?*")3879E(&=E;F5R
M871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E
M<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(BD["B`@("`D86-T:6]N<UM=
M(#T@87)R87DH)VEC;VXG(#T^($AO<F1E.CII;6<H)W-A=F4N<&YG)RP@)R<L
M("=A;&EG;CTB;6ED9&QE(B<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO
M<F1E)RDI+`H@("`@("`@("`@("`@("`@("`@("`@("=L:6YK)R`]/B!(;W)D
M93HZ;&EN:R@D=7)L*2`N("1A8W1I;VX@+B`G/"]A/B<I.PH*("`@("\J(%-E
M="!U<"!T:&4@9F]R;2!F;W(@1E10('5P;&]A9"!O9B!S8W)I<'1S+B`J+PH@
M("`@<F5Q=6ER95]O;F-E("=(;W)D92]&;W)M+G!H<"<["B`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+U9A<FEA8FQE<RYP:'`G.PH*("`@("1V87)S(#T@)E9A
M<FEA8FQE<SHZ9V5T1&5F875L=%9A<FEA8FQE<R@I.PH@("`@)&9T<&9O<FT@
M/2`F2&]R9&5?1F]R;3HZ<VEN9VQE=&]N*"<G+"`D=F%R<RD["B`@("`D9G1P
M9F]R;2T^<V5T5&ET;&4H7R@B1E10('5P;&]A9"!O9B!S971U<"(I*3L*("`@
M("1F='!F;W)M+3YS971"=71T;VYS*%\H(E5P;&]A9"(I+"!T<G5E*3L*("`@
M("1F='!F;W)M+3YA9&1687)I86)L92A?*")5<V5R;F%M92(I+"`G=7-E<FYA
M;64G+"`G=&5X="<L('1R=64L(&9A;'-E+"!N=6QL+"!A<G)A>2@G)RP@,C`I
M*3L*("`@("1F='!F;W)M+3YA9&1687)I86)L92A?*")087-S=V]R9"(I+"`G
M<&%S<W=O<F0G+"`G<&%S<W=O<F0G+"!F86QS92D["@H@("`@:68@*"1F='!F
M;W)M+3YV86QI9&%T92@D=F%R<RDI('L*("`@("`@("`D9G1P9F]R;2T^9V5T
M26YF;R@D=F%R<RP@)&EN9F\I.PH@("`@("`@("1U<&QO860@/2!?=7!L;V%D
M1E10*"1I;F9O*3L*("`@("`@("!I9B`H)'5P;&]A9"D@>PH@("`@("`@("`@
M("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(E5P;&]A9&5D(&%L;"!A<'!L:6-A
M=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(I+"`G:&]R9&4N<W5C
M8V5S<R<I.PH@("`@("`@("`@("`D=7)L(#T@2&]R9&4Z.F%P<&QI8V%T:6]N
M57)L*"=A9&UI;B]S971U<"]I;F1E>"YP:'`G+"!T<G5E*3L*("`@("`@("`@
M("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N("1U<FPI.PH@("`@("`@("`@("!E
M>&ET.PH@("`@("`@('T*("`@('T*("`@("\J(%)E;F1E<B!T:&4@9F]R;2X@
M*B\*("`@(')E<75I<F5?;VYC92`G2&]R9&4O1F]R;2]296YD97)E<BYP:'`G
M.PH@("`@)')E;F1E<F5R(#T@)FYE=R!(;W)D95]&;W)M7U)E;F1E<F5R*"D[
M"B`@("`D9G1P9F]R;2`](%5T:6PZ.F)U9F9E<D]U='!U="AA<G)A>2@D9G1P
M9F]R;2P@)W)E;F1E<D%C=&EV92<I+"`D<F5N9&5R97(L("1V87)S+"`G:6YD
M97@N<&AP)RP@)W!O<W0G*3L*?0H*:68@*&9I;&5?97AI<W1S*$AO<F1E.CIG
M971496UP1&ER*"D@+B`G+VAO<F1E7W-E='5P7W5P9W)A9&4N<&AP)RDI('L*
M("`@("\J($%C=&EO;B!T;R!R96UO=F4@=&AE(&-O;F9I9W5R871I;VX@=7!G
M<F%D92!02%`@<V-R:7!T+B`J+PH@("`@)'5R;"`]($AO<F1E.CIA<'!L:6-A
M=&EO;E5R;"@G861M:6XO<V5T=7`O<V-R:7!T<RYP:'`G*3L*("`@("1U<FP@
M/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@)V-L96%N)RP@)W1M<"<I.PH@
M("`@)&%C=&EO;B`](%\H(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V
M97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(I.PH@("`@)&%C=&EO;G-;72`]
M(&%R<F%Y*"=I8V]N)R`]/B!(;W)D93HZ:6UG*"=D96QE=&4N<&YG)RP@)R<L
M("=A;&EG;CTB;6ED9&QE(B<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO
M<F1E)RDI+`H@("`@("`@("`@("`@("`@("`@("`@("=L:6YK)R`]/B!(;W)D
M93HZ;&EN:R@D=7)L*2`N("1A8W1I;VX@+B`G/"]A/B<I.PI]"@HO*B!3970@
M=7`@=&AE('1E;7!L871E+B`J+PHD=&5M<&QA=&4@/2`F;F5W($AO<F1E7U1E
M;7!L871E*"D["B1T96UP;&%T92T^<V5T*"=A<'!S)RP@)&%P<',I.PHD=&5M
M<&QA=&4M/G-E="@G86-T:6]N<R<L("1A8W1I;VYS+"!T<G5E*3L*)'1E;7!L
M871E+3YS970H)V9T<&9O<FTG+"`D9G1P9F]R;2P@=')U92D["B1T96UP;&%T
M92T^<V5T*"=N;W1I9GDG+"!5=&EL.CIB=69F97)/=71P=70H87)R87DH)&YO
M=&EF:6-A=&EO;BP@)VYO=&EF>2<I*2D["B1T96UP;&%T92T^<V5T3W!T:6]N
M*"=G971T97AT)RP@=')U92D["@HD=&ET;&4@/2!S<')I;G1F*%\H(B5S(%-E
M='5P(BDL("1R96=I<W1R>2T^9V5T*"=N86UE)RP@)VAO<F1E)RDI.PI(;W)D
M93HZ861D4V-R:7!T1FEL92@G<W1R:7!E+FIS)RP@)VAO<F1E)RP@=')U92D[
M"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN
M8R<["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]A9&UI;B]C;VUM;VXM
M:&5A9&5R+FEN8R<["F5C:&\@)'1E;7!L871E+3YF971C:"A(3U)$15]414U0
M3$%415,@+B`G+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PG*3L*<F5Q=6ER92!(
M3U)$15]414U03$%415,@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+V%D;6EN+W-E='5P+W-C<FEP=',N<&AP````````````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`Q,#4Q,B`Q,#4Q-30S,S<S-"`P,C(Q-C<`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J($=E;F5R871E<R!U<&=R861E('-C<FEP=',@9F]R($AO<F1E)W,@
M<V5T=7`N($-U<G)E;G1L>2!A;&QO=W,@=&AE(&=E;F5R871I;VX*("H@;V8@
M4$A0('5P9W)A9&4@<V-R:7!T<R!F;W(@8V]N9BYP:'`@9FEL97,@96ET:&5R
M(&%S(&1O=VYL;V%D(&]R('-A=F5D('1O('1H90H@*B!S97)V97(G<R!T96UP
M;W)A<GD@9&ER96-T;W)Y+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+V%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP+'8@,2XY+C$P+C8@,C`P-B\P-B\Q-B`P.#HR-#HR
M-R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:&%R;&5S
M($HN($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@
M,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("HO"@ID969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,
M15]?*2`N("<O+BXO+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G
M+VQI8B]B87-E+G!H<"<["@II9B`H(4%U=&@Z.FES061M:6XH*2D@>PH@("`@
M2&]R9&4Z.F9A=&%L*"=&;W)B:61D96XN)RP@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*?0H*+RH@1V5T(&9O<FT@9&%T82X@*B\*)'-E='5P(#T@571I;#HZ9V5T
M1F]R;41A=&$H)W-E='5P)RD["B1T>7!E(#T@571I;#HZ9V5T1F]R;41A=&$H
M)W1Y<&4G*3L*)'-A=F4@/2!5=&EL.CIG971&;W)M1&%T82@G<V%V92<I.PHD
M8VQE86X@/2!5=&EL.CIG971&;W)M1&%T82@G8VQE86XG*3L*"B1F:6QE;F%M
M92`]("=H;W)D95]S971U<%]U<&=R861E+G!H<"<["@HO*B!#:&5C:R!I9B!T
M:&ES(&ES(&]N;'D@82!R97%U97-T('1O(&-L96%N('5P+B`J+PII9B`H)&-L
M96%N(#T]("=T;7`G*2!["B`@("`D=&UP7V1I<B`]($AO<F1E.CIG971496UP
M1&ER*"D["B`@("`D<&%T:"`](%5T:6PZ.G)E86Q0871H*"1T;7!?9&ER("X@
M)R\G("X@)&9I;&5N86UE*3L*("`@(&EF("AU;FQI;FLH)'1M<%]D:7(@+B`G
M+R<@+B`D9FEL96YA;64I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S
M:"AS<')I;G1F*%\H(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E
M<UPB+B(I+"`D<&%T:"DL("=H;W)D92YS=6-C97-S)RD["B`@("!](&5L<V4@
M>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")#;W5L
M9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB*2P@
M571I;#HZ<F5A;%!A=&@H)'!A=&@I*2P@)VAO<F1E+F5R<F]R)RD["B`@("!]
M"B`@("`D<F5G:7-T<GDM/F-L96%R0V%C:&4H*3L*("`@("1U<FP@/2!(;W)D
M93HZ87!P;&EC871I;VY5<FPH)V%D;6EN+W-E='5P+VEN9&5X+G!H<"<L('1R
M=64I.PH@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N("1U<FPI.PH@("`@97AI
M=#L*?0H*)&1A=&$@/2`G)SL*:68@*"1S971U<"`]/2`G8V]N9B<@)B8@)'1Y
M<&4@/3T@)W!H<"<I('L*("`@("\J($$@8FET('5G;'D@:&5R92P@<V%V92!0
M2%`@8V]D92!I;G1O(&$@<W1R:6YG(&9O<B!C<F5A=&EN9R!T:&4@<V-R:7!T
M"B`@("`@*B!T;R!B92!R=6X@870@=&AE(&-O;6UA;F0@<')O;7!T+B`J+PH@
M("`@)&1A=&$@/2`G(R$O=7-R+V)I;B]P:'`G("X@(EQN(CL*("`@("1D871A
M("X]("<\/W!H<"<@+B`B7&XB.PH@("`@9F]R96%C:"`H)%]315-324].6R=?
M8V]N9FEG)UT@87,@)&%P<"`]/B`D<&AP*2!["B`@("`@("`@)'!A=&@@/2`D
M<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G+"`D87!P*2`N("<O8V]N9FEG)SL*
M("`@("`@("`O*B!!9&0@8V]D92!T;R!S879E(&)A8VMU<"X@*B\*("`@("`@
M("`D9&%T82`N/2`G:68@*&9I;&5?97AI<W1S*%PG)R`N("1P871H("X@)R]C
M;VYF+G!H<%PG*2D@>R<@+B`B7&XB.PH@("`@("`@("1D871A("X]("<@("`@
M:68@*$!C;W!Y*%PG)R`N("1P871H("X@)R]C;VYF+G!H<%PG+"!<)R<@+B`D
M<&%T:"`N("<O8V]N9BYP:'`N8F%K7"<I*2![)R`N(")<;B(["B`@("`@("`@
M)&1A=&$@+CT@)R`@("`@("`@96-H;R!<)R<@+B!?*")3=6-C97-S9G5L;'D@
M<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN(BD@+B`G7"<@+B`B7&XB.R<@
M+B`B7&XB.PH@("`@("`@("1D871A("X]("<@("`@?2!E;'-E('LG("X@(EQN
M(CL*("`@("`@("`D9&%T82`N/2`G("`@("`@("!E8VAO(%PG)R`N(%\H(D-O
M=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB*2`N("=<)R`N
M(")<;B([)R`N(")<;B(["B`@("`@("`@)&1A=&$@+CT@)R`@("!])R`N(")<
M;B(["B`@("`@("`@)&1A=&$@+CT@)WTG("X@(EQN(CL*"B`@("`@("`@)&1A
M=&$@+CT@)VEF("@D9G`@/2!`9F]P96XH7"<G("X@)'!A=&@@+B`G+V-O;F8N
M<&AP7"<L(%PG=UPG*2D@>R<@+B`B7&XB.PH@("`@("`@("1D871A("X]("<@
M("`@9G=R:71E*"1F<"P@7"<G.PH@("`@("`@("1D871A("X](%-T<FEN9SHZ
M8V]N=F5R=$-H87)S970H<W1R7W)E<&QA8V4H87)R87DH)UQ<)RP@)UPG)RDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A<G)A>2@G7%Q<7"<L("=<7%PG)RDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&AP*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($Y,4SHZ
M9V5T0VAA<G-E="@I+"`G:7-O+3@X-3DM,2<I.PH@("`@("`@("1D871A("X]
M("=<)RD[)R`N(")<;B(["B`@("`@("`@)&1A=&$@+CT@)R`@("!F8VQO<V4H
M)&9P*3LG("X@(EQN(CL*("`@("`@("`D9&%T82`N/2`G("`@(&5C:&\@7"<G
M("X@<W!R:6YT9BA?*")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(I+"`D87!P
M*2`N("=<)R`N(")<;B([)R`N(")<;B(["B`@("`@("`@)&1A=&$@+CT@)WT@
M96QS92![)R`N(")<;B(["B`@("`@("`@)&1A=&$@+CT@)R`@("!E8VAO(%PG
M)R`N('-P<FEN=&8H7R@B0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO
M;BXB*2P@)&%P<"D@+B`G7"<@+B`B7&XB.R<@+B`B7&XB.PH@("`@("`@("1D
M871A("X]("=])R`N(")<;EQN(CL*("`@('T*?0H*:68@*"1S879E(#T]("=T
M;7`G*2!["B`@("`D=&UP7V1I<B`]($AO<F1E.CIG971496UP1&ER*"D["B`@
M("`O*B!!9&0@<V5L9BUD97-T<G5C="!C;V1E+B`J+PH@("`@)&1A=&$@+CT@
M)V5C:&\@7"=396QF+61E<W1R=6-T:6YG+BXN7"<@+B`B7&XB.R<@+B`B7&XB
M.PH@("`@)&1A=&$@+CT@)VEF("AU;FQI;FLH7U]&24Q%7U\I*2![)R`N(")<
M;B(["B`@("`D9&%T82`N/2`G("`@(&5C:&\@7"<G("X@7R@B57!G<F%D92!S
M8W)I<'0@9&5L971E9"XB*2`N("=<)R`N(")<;B([)R`N(")<;B(["B`@("`D
M9&%T82`N/2`G?2!E;'-E('LG("X@(EQN(CL*("`@("1D871A("X]("<@("`@
M96-H;R!<)R<@+B!S<')I;G1F*%\H(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE0
M5"!-04Y504Q,62!&4D]-("5S+B(I+"`D=&UP7V1I<BD@+B`G7"<@+B`B7&XB
M.R<@+B`B7&XB.PH@("`@)&1A=&$@+CT@)WTG("X@(EQN(CL*("`@("\J(%1H
M92!S8W)I<'0@<VAO=6QD(&)E('-A=F5D('1O('-E<G9E<B=S('1E;7!O<F%R
M>2!D:7)E8W1O<GDN("HO"B`@("`D<&%T:"`](%5T:6PZ.G)E86Q0871H*"1T
M;7!?9&ER("X@)R\G("X@)&9I;&5N86UE*3L*("`@(&EF("@D9G`@/2!`9F]P
M96XH)'1M<%]D:7(@+B`G+R<@+B`D9FEL96YA;64L("=W)RDI('L["B`@("`@
M("`@9G=R:71E*"1F<"P@)&1A=&$I.PH@("`@("`@(&9C;&]S92@D9G`I.PH@
M("`@("`@(&-H;6]D*"1T;7!?9&ER("X@)R\G("X@)&9I;&5N86UE+"`P-S<W
M*3L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B4V%V
M960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB*2P@)'!A=&@I
M+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@?2!E;'-E('L*("`@("`@("`D;F]T
M:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B0V]U;&0@;F]T('-A=F4@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB*2P@)'!A=&@I+"`G:&]R
M9&4N97)R;W(G*3L*("`@('T*("`@("1U<FP@/2!(;W)D93HZ87!P;&EC871I
M;VY5<FPH)V%D;6EN+W-E='5P+VEN9&5X+G!H<"<L('1R=64I.PH@("`@:&5A
M9&5R*"=,;V-A=&EO;CH@)R`N("1U<FPI.PH@("`@97AI=#L*?2!E;'-E('L*
M("`@("\J($]U='!U="!S8W)I<'0@=&\@8G)O=W-E<B!F;W(@9&]W;FQO860N
M("HO"B`@("`D8G)O=W-E<BT^9&]W;FQO861(96%D97)S*"1F:6QE;F%M92P@
M)W1E>'0O<&QA:6XG+"!F86QS92P@<W1R;&5N*"1D871A*2D["B`@("!E8VAO
M("1D871A.PI]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O861M:6XO<&AP
M<VAE;&PN<&AP````````````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`U-30S(#$P-3$U-#,S-S,T(#`R,3$V-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@)$AO
M<F1E.B!H;W)D92]A9&UI;B]P:'!S:&5L;"YP:'`L=B`Q+C(T+C$P+C@@,C`P
M-B\P,B\R-"`R,CHT.#HR.2!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M
M92A?7T9)3$5?7RD@+B`G+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%
M("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TUE;G4N
M<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92](96QP+G!H<"<["@II9B`H(4%U
M=&@Z.FES061M:6XH*2D@>PH@("`@2&]R9&4Z.F%U=&AE;G1I8V%T:6]N1F%I
M;'5R95)E9&ER96-T*"D["GT*"B1T:71L92`](%\H(E!(4"!3:&5L;"(I.PIR
M97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+6AE861E<BYI;F,G
M.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O861M:6XO8V]M;6]N+6AE
M861E<BYI;F,G.PH*)&%P<'-?=&UP(#T@)')E9VES=')Y+3YL:7-T07!P<R@I
M.PHD87!P<R`](&%R<F%Y*"D["F9O<F5A8V@@*"1A<'!S7W1M<"!A<R`D87!P
M*2!["B`@("`D87!P<ULD87!P72`]("1R96=I<W1R>2T^9V5T*"=N86UE)RP@
M)&%P<"D["GT*87-O<G0H)&%P<',I.PHD87!P;&EC871I;VX@/2!5=&EL.CIG
M971&;W)M1&%T82@G87!P)RP@)VAO<F1E)RD["C\^"CQD:78@<W1Y;&4](G!A
M9&1I;F<Z,3!P>"(^"CQF;W)M(&%C=&EO;CTB/#]P:'`@96-H;R`D7U-%4E9%
M4ELG4$A07U-%3$8G72`_/B(@;65T:&]D/2)P;W-T(CX*/#]P:'`@571I;#HZ
M<&9O<FU);G!U="@I(#\^"@H\:#$@8VQA<W,](FAE861E<B(^/#]P:'`@96-H
M;R!?*")!<'!L:6-A=&EO;B(I(#\^/"]H,3X\8G(@+SX*/'-E;&5C="!N86UE
M/2)A<'`B/@H\/W!H<"!F;W)E86-H("@D87!P<R!A<R`D87!P(#T^("1N86UE
M*3H@/SX*("`\;W!T:6]N('9A;'5E/2(\/W!H<"!E8VAO("1A<'`@/SXB/#]P
M:'`@:68@*"1A<'!L:6-A=&EO;B`]/2`D87!P*2!E8VAO("<@<V5L96-T960]
M(G-E;&5C=&5D(B<@/SX^/#]P:'`@96-H;R`D;F%M92`_/CPO;W!T:6]N/@H\
M/W!H<"!E;F1F;W)E86-H.R`_/@H\+W-E;&5C=#X\8G(@+SX\8G(@+SX*/#]P
M:'`*"FEF("@D8V]M;6%N9"`]('1R:6TH571I;#HZ9V5T1F]R;41A=&$H)W!H
M<"<I*2D@>PH@("`@:68@*$!F:6QE7V5X:7-T<R@D<F5G:7-T<GDM/F=E="@G
M9FEL97)O;W0G+"`D87!P;&EC871I;VXI("X@)R]L:6(O8F%S92YP:'`G*2D@
M>PH@("`@("`@(&EN8VQU9&4@)')E9VES=')Y+3YG970H)V9I;&5R;V]T)RP@
M)&%P<&QI8V%T:6]N*2`N("<O;&EB+V)A<V4N<&AP)SL*("`@('T@96QS92![
M"B`@("`@("`@)')E9VES=')Y+3YP=7-H07!P*"1A<'!L:6-A=&EO;BD["B`@
M("!]"@H@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+U9I97=E<BYP:'`G
M.PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+U9I97=E<B]S;W5R8V4N
M<&AP)SL*("`@("1P<F5T='D@/2!H:6=H;&EG:'1?<W1R:6YG*"<\/W!H<"`G
M("X@)&-O;6UA;F0L('1R=64I.PH@("`@)'!R971T>2`]('-T<E]R97!L86-E
M*&%R<F%Y*"<F;'0[/W!H<"`G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("<\9F]N="!C;VQO<CTB(S`P,#`P,"(^/&9O;G0@8V]L;W(](B,P
M,#<W,#`B/B9L=#L_/"]F;VYT/CQF;VYT(&-O;&]R/2(C,#`P,$)"(CYP:'`@
M/"]F;VYT/B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(EQR
M7&XB+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(")<<B(L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(EQN(BP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G/&)R("\^)RDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87DH)R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(EQN(BDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!R971T>2D["B`@("`D<')E='1Y(#T@34E-15]6:65W97)?
M4V]U<F-E.CIL:6YE3G5M8F5R*'1R:6TH)'!R971T>2DI.PH*("`@(&5C:&\@
M)SQH,2!C;&%S<STB:&5A9&5R(CXG("X@7R@B4$A0($-O9&4B*2`N("<\+V@Q
M/CQB<B`O/B<["B`@("!E8VAO("1P<F5T='D["@H@("`@96-H;R`G/&)R("\^
M/&@Q(&-L87-S/2)H96%D97(B/B<@+B!?*")297-U;'1S(BD@+B`G/"]H,3X\
M8G(@+SXG.PH@("`@96-H;R`G/'!R92!C;&%S<STB=&5X="(^)SL*("`@(&5V
M86PH)&-O;6UA;F0I.PH@("`@96-H;R`G/"]P<F4^/&)R("\^)SL*?0H_/@H*
M/'1E>'1A<F5A(&-L87-S/2)F:7AE9"(@;F%M93TB<&AP(B!R;W=S/2(Q,"(@
M8V]L<STB-C`B/@H\/W!H<"!I9B`H(65M<'1Y*"1C;VUM86YD*2D@96-H;R!H
M=&UL<W!E8VEA;&-H87)S*"1C;VUM86YD*2`_/CPO=&5X=&%R96$^"CQB<B`O
M/@H\:6YP=70@='EP93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!V86QU93TB
M/#]P:'`@96-H;R!?*")%>&5C=71E(BD@/SXB("\^"CP_<&AP(&5C:&\@2&5L
M<#HZ;&EN:R@G861M:6XG+"`G861M:6XM<&AP<VAE;&PG*2`_/@H*/"]F;W)M
M/@H\+V1I=CX*/#]P:'`*"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C
M;VUM;VXM9F]O=&5R+FEN8R<["@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]A9&UI;B]I;F1E>"YP:'``````````````
M````````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$R-3<@,3`U
M,34T,S,W,S0@,#(P-#4U`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+V%D;6EN
M+VEN9&5X+G!H<"QV(#$N,34N."XS(#(P,#8O,#$O,#$@,C$Z,C@Z,#4@:F%N
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAA<FQE<R!*+B!(
M86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*
M"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O
M+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H
M<"<["G)E<75I<F5?;VYC92`G2&]R9&4O365N=2YP:'`G.PH*:68@*"%!=71H
M.CII<T%D;6EN*"DI('L*("`@($AO<F1E.CIF871A;"@G1F]R8FED9&5N+B<L
M(%]?1DE,15]?+"!?7TQ)3D5?7RD["GT*"B1T:71L92`](%\H(D%D;6EN:7-T
M<F%T:6]N(BD["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM
M:&5A9&5R+FEN8R<["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]A9&UI
M;B]C;VUM;VXM:&5A9&5R+FEN8R<["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53
M("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]A9&UI;B]U<V5R+G!H<```````
M````````````````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,C,W
M-S<@,3`U,34T,S,W,S0@,#(P,S,W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E
M+V%D;6EN+W5S97(N<&AP+'8@,2XT-RXQ,"XW(#(P,#8O,#$O,#$@,C$Z,C@Z
M,#4@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@
M2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO
M"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G
M+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP
M:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TUE;G4N<&AP)SL*<F5Q=6ER95]O
M;F-E("=(;W)D92]&;W)M+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O5F%R
M:6%B;&5S+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O1F]R;2]296YD97)E
M<BYP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+U9A<FEA8FQE<RYP:'`G.PH*
M:68@*"%!=71H.CII<T%D;6EN*"DI('L*("`@($AO<F1E.CIF871A;"@G1F]R
M8FED9&5N+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["GT*)&%U=&@@/2`F075T
M:#HZ<VEN9VQE=&]N*"1C;VYF6R=A=71H)UU;)V1R:79E<B==*3L*"FEF("@D
M8V]N9ELG<VEG;G5P)UU;)V%L;&]W)UT@)B8@)&-O;F9;)W-I9VYU<"==6R=A
M<'!R;W9E)UTI('L*("`@(')E<75I<F5?;VYC92`G2&]R9&4O075T:"]3:6=N
M=7`N<&AP)SL*("`@("1S:6=N=7`@/2`F075T:%]3:6=N=7`Z.G-I;F=L971O
M;B@I.PI]"@HD=F%R<R`]("9687)I86)L97,Z.F=E=$1E9F%U;'1687)I86)L
M97,H*3L*)&%D9$9O<FT@/2`F;F5W($AO<F1E7T9O<FTH)'9A<G,L(%\H(D%D
M9"!A(&YE=R!U<V5R.B(I+"`G861D=7-E<B<I.PHD861D1F]R;2T^<V5T0G5T
M=&]N<RA?*")!9&0@=7-E<B(I+"!?*")297-E="(I*3L*"B1V87)S+3YS970H
M)V9O<FTG+"`G861D)RD["B1A9&1&;W)M+3YA9&1(:61D96XH)R<L("=F;W)M
M)RP@)W1E>'0G+"!T<G5E+"!T<G5E*3L*)&%D9$9O<FTM/F%D9%9A<FEA8FQE
M*%\H(E5S97)N86UE(BDL("=U<V5R7VYA;64G+"`G=&5X="<L('1R=64I.PHD
M861D1F]R;2T^861D5F%R:6%B;&4H7R@B4&%S<W=O<F0B*2P@)W!A<W-W;W)D
M)RP@)W!A<W-W;W)D8V]N9FER;2<L(&9A;'-E+"!F86QS92P@7R@B='EP92!T
M:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(I*3L*"B\J(%5S92!H;V]K
M<R!G970@86YY(&5X=')A(&9I96QD<R!F;W(@;F5W(&%C8V]U;G1S+B`J+PHD
M97AT<F$@/2!(;W)D93HZ8V%L;$AO;VLH)U]H;W)D95]H;V]K7W-I9VYU<%]G
M971E>'1R82<I.PII9B`H(6ES7V$H)&5X=')A+"`G4$5!4E]%<G)O<B<I("8F
M("%E;7!T>2@D97AT<F$I*2!["B`@("!F;W)E86-H("@D97AT<F$@87,@)&9I
M96QD7VYA;64@/3X@)&9I96QD*2!["B`@("`@("`@)')E861O;FQY(#T@:7-S
M970H)&9I96QD6R=R96%D;VYL>2==*2`_("1F:65L9%LG<F5A9&]N;'DG72`Z
M(&YU;&P["B`@("`@("`@)&1E<V,@/2!I<W-E="@D9FEE;&1;)V1E<V,G72D@
M/R`D9FEE;&1;)V1E<V,G72`Z(&YU;&P["B`@("`@("`@)&9I96QD7W!A<F%M
M<R`](&ES<V5T*"1F:65L9%LG<&%R86US)UTI(#\@)&9I96QD6R=P87)A;7,G
M72`Z(&%R<F%Y*"D["@H@("`@("`@("1A9&1&;W)M+3YA9&1687)I86)L92@D
M9FEE;&1;)VQA8F5L)UTL("=E>'1R85LG("X@)&9I96QD7VYA;64@+B`G72<L
M("1F:65L9%LG='EP92==+"`D9FEE;&1;)W)E<75I<F5D)UTL("1R96%D;VYL
M>2P@)&1E<V,L("1F:65L9%]P87)A;7,I.PH@("`@?0I]"@H*+R\@4')O8V5S
M<R!F;W)M<RX@57-E(%5T:6PZ.F=E=%!O<W0H*2!I;G-T96%D(&]F(%5T:6PZ
M.F=E=$9O<FU$871A*"D*+R\@9F]R(&$@;&]T(&]F('1H92!D871A(&)E8V%U
M<V4@=V4@=V%N="!T;R!A8W1I=F5L>2!I9VYO<F4@1T54(&1A=&$*+R\@:6X@
M<V]M92!C87-E<R`M(&%D9&EN9R]M;V1I9GEI;F<@=7-E<G,@+2!A<R!A('-E
M8W5R:71Y('!R96-A=71I;VXN"G-W:71C:"`H571I;#HZ9V5T1F]R;41A=&$H
M)V9O<FTG*2D@>PIC87-E("=A9&0G.@H@("`@)&%D9$9O<FTM/G9A;&ED871E
M*"1V87)S*3L*"B`@("!I9B`H)&%D9$9O<FTM/FES5F%L:60H*2`F)B`D=F%R
M<RT^9V5T*"=F;W)M;F%M92<I(#T]("=A9&1U<V5R)RD@>PH@("`@("`@("1A
M9&1&;W)M+3YG971);F9O*"1V87)S+"`D:6YF;RD["@H@("`@("`@(&EF("AE
M;7!T>2@D:6YF;ULG=7-E<E]N86UE)UTI*2!["B`@("`@("`@("`@("1N;W1I
M9FEC871I;VXM/G!U<V@H7R@B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA
M;64@=&\@861D+B(I+"`G:&]R9&4N97)R;W(G*3L*"B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)&-R961E;G1I86QS(#T@87)R87DH)W!A<W-W;W)D
M)R`]/B`D:6YF;ULG<&%S<W=O<F0G72D["B`@("`@("`@("`@(&EF("AI<W-E
M="@D:6YF;ULG97AT<F$G72DI('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1I;F9O6R=E>'1R82==(&%S("1F:65L9"`]/B`D=F%L=64I('L*("`@("`@
M("`@("`@("`@("`@("`D8W)E9&5N=&EA;'-;)&9I96QD72`]("1V86QU93L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M:68@*&ES7V$H)')E="`]("1A=71H+3YA9&15<V5R*"1I;F9O6R=U<V5R7VYA
M;64G72P@)&-R961E;G1I86QS*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E1H97)E
M('=A<R!A('!R;V)L96T@861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E
M<R(I+"`D:6YF;ULG=7-E<E]N86UE)UTL("1R970M/F=E=$UE<W-A9V4H*2DL
M("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1I;F9O6R=E>'1R82==*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1R97-U;'0@/2!(;W)D93HZ8V%L;$AO;VLH)U]H;W)D
M95]H;V]K7W-I9VYU<%]A9&1E>'1R82<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@D:6YF;ULG=7-E<E]N
M86UE)UTL("1I;F9O6R=E>'1R82==*2D["B`@("`@("`@("`@("`@("`@("`@
M:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B
M061D960@7"(E<UPB('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D
M(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`E<RXB*2P@)&EN9F];
M)W5S97)?;F%M92==+"`D<F5S=6QT+3YG971-97-S86=E*"DI+"`G:&]R9&4N
M=V%R;FEN9R<I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&EF("A5=&EL.CIG971&;W)M1&%T82@G
M<F5M;W9E475E=65D4VEG;G5P)RDI('L*("`@("`@("`@("`@("`@("`@("`D
M<VEG;G5P+3YR96UO=F51=65U9613:6=N=7`H)&EN9F];)W5S97)?;F%M92==
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1N;W1I9FEC
M871I;VXM/G!U<V@H<W!R:6YT9BA?*")3=6-C97-S9G5L;'D@861D960@7"(E
M<UPB('1O('1H92!S>7-T96TN(BDL("1I;F9O6R=U<V5R7VYA;64G72DL("=H
M;W)D92YS=6-C97-S)RD["B`@("`@("`@("`@("`@("`D861D1F]R;2T^=6YS
M971687)S*"1V87)S*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*
M("`@(&)R96%K.PH*8V%S92`G<F5M;W9E7V8G.@H@("`@)&9?=7-E<E]N86UE
M(#T@571I;#HZ9V5T1F]R;41A=&$H)W5S97)?;F%M92<I.PH@("`@)')E;6]V
M95]F;W)M(#T@=')U93L*("`@(&)R96%K.PH*8V%S92`G<F5M;W9E)SH*("`@
M("1F7W5S97)?;F%M92`](%5T:6PZ.F=E=$9O<FU$871A*"=U<V5R7VYA;64G
M*3L*("`@(&EF("AE;7!T>2@D9E]U<V5R7VYA;64I*2!["B`@("`@("`@)&YO
M=&EF:6-A=&EO;BT^<'5S:"A?*")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA
M;64@=&\@<F5M;W9E+B(I+"`G:&]R9&4N;65S<V%G92<I.PH@("`@?2!E;'-E
M:68@*%5T:6PZ.F=E=$9O<FU$871A*"=S=6)M:70G*2`A/3T@7R@B0V%N8V5L
M(BDI('L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT(#T@)&%U=&@M/G)E;6]V
M955S97(H)&9?=7-E<E]N86UE*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B5&AE<F4@=V%S
M(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B
M*2`N("1R97-U;'0M/F=E=$UE<W-A9V4H*2P@)&9?=7-E<E]N86UE*2P@)VAO
M<F1E+F5R<F]R)RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&YO
M=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E-U8V-E<W-F=6QL>2!R96UO
M=F5D(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(BDL("1F7W5S97)?;F%M92DL
M("=H;W)D92YS=6-C97-S)RD["B`@("`@("`@?0H@("`@?0H@("`@)'9A<G,M
M/G)E;6]V92@G=7-E<E]N86UE)RD["B`@("!B<F5A:SL*"F-A<V4@)V-L96%R
M7V8G.@H@("`@)&9?=7-E<E]N86UE(#T@571I;#HZ9V5T1F]R;41A=&$H)W5S
M97)?;F%M92<I.PH@("`@)&-L96%R7V9O<FT@/2!T<G5E.PH@("`@8G)E86L[
M"@IC87-E("=C;&5A<B<Z"B`@("`D9E]U<V5R7VYA;64@/2!5=&EL.CIG971&
M;W)M1&%T82@G=7-E<E]N86UE)RD["B`@("!I9B`H96UP='DH)&9?=7-E<E]N
M86UE*2D@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B66]U(&UU
M<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB*2P@)VAO<F1E
M+FUE<W-A9V4G*3L*("`@('T@96QS96EF("A5=&EL.CIG971&;W)M1&%T82@G
M<W5B;6ET)RD@(3T](%\H(D-A;F-E;"(I*2!["B`@("`@("`@:68@*&ES7V$H
M)')E<W5L="`]("1A=71H+3YR96UO=F55<V5R1&%T82@D9E]U<V5R7VYA;64I
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1N;W1I9FEC871I;VXM
M/G!U<V@H<W!R:6YT9BA?*")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG
M(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(BD@+B`D
M<F5S=6QT+3YG971-97-S86=E*"DL("1F7W5S97)?;F%M92DL("=H;W)D92YE
M<G)O<B<I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1N;W1I9FEC
M871I;VXM/G!U<V@H<W!R:6YT9BA?*")3=6-C97-S9G5L;'D@8VQE87)E9"!D
M871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(BDL("1F7W5S
M97)?;F%M92DL("=H;W)D92YS=6-C97-S)RD["B`@("`@("`@?0H@("`@?0H@
M("`@)'9A<G,M/G)E;6]V92@G=7-E<E]N86UE)RD["B`@("!B<F5A:SL*"F-A
M<V4@)W5P9&%T95]F)SH*("`@("1F7W5S97)?;F%M92`](%5T:6PZ.F=E=$9O
M<FU$871A*"=U<V5R7VYA;64G*3L*("`@("1U<&1A=&5?9F]R;2`]('1R=64[
M"B`@("!B<F5A:SL*"F-A<V4@)W5P9&%T92<Z"B`@("`D=7-E<E]N86UE7S$@
M/2!5=&EL.CIG9710;W-T*"=U<V5R7VYA;64G*3L*("`@("1U<V5R7VYA;65?
M,B`](%5T:6PZ.F=E=%!O<W0H)W5S97)?;F%M93(G+"`D=7-E<E]N86UE7S$I
M.PH@("`@)&9U;&QN86UE(#T@571I;#HZ9V5T4&]S="@G=7-E<E]F=6QL;F%M
M92<I.PH@("`@)&5M86EL(#T@571I;#HZ9V5T4&]S="@G=7-E<E]E;6%I;"<I
M.PH*("`@(&EF("@D875T:"T^:&%S0V%P86)I;&ET>2@G=7!D871E)RDI('L*
M("`@("`@("`D=7-E<E]P87-S7S$@/2!5=&EL.CIG9710;W-T*"=U<V5R7W!A
M<W-?,2<I.PH@("`@("`@("1U<V5R7W!A<W-?,B`](%5T:6PZ.F=E=%!O<W0H
M)W5S97)?<&%S<U\R)RD["@H@("`@("`@(&EF("AE;7!T>2@D=7-E<E]N86UE
M7S$I*2!["B`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B66]U
M(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(I+"`G:&]R
M9&4N97)R;W(G*3L*("`@("`@("!](&5L<V5I9B`H96UP='DH)'5S97)?<&%S
M<U\Q*2!\?"!E;7!T>2@D=7-E<E]P87-S7S(I*2!["B`@("`@("`@("`@("\O
M($1O;B=T('5P9&%T92P@8G5T(&1O;B=T(&-O;7!L86EN+@H@("`@("`@('T@
M96QS96EF("@D=7-E<E]P87-S7S$@(3T@)'5S97)?<&%S<U\R*2!["B`@("`@
M("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B4&%S<W=O<F1S(&UU<W0@
M;6%T8V@N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1R97-U;'0@/2`D875T:"T^=7!D871E57-E<B@D=7-E<E]N
M86UE7S$L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=7-E<E]N86UE7S(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@G<&%S<W=O<F0G(#T^("1U<V5R7W!A<W-?,2DI
M.PH@("`@("`@('T*("`@('T*"B`@("!I9B`H:7-S970H)')E<W5L="D@)B8@
M:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@)&YO=&EF
M:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E1H97)E('=A<R!A('!R;V)L96T@
M=7!D871I;F<@7"(E<UPB.B`E<R(I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=7-E<E]N86UE7S$L("1R97-U;'0M/F=E=$UE<W-A
M9V4H*2DL("=H;W)D92YE<G)O<B<I.PH@("`@?2!E;'-E('L*("`@("`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+TED96YT:71Y+G!H<"<["B`@("`@("`@)&ED
M96YT:71Y(#T@)DED96YT:71Y.CIS:6YG;&5T;VXH)VYO;F4G+"`D=7-E<E]N
M86UE7S$I.PH@("`@("`@("1I9&5N=&ET>2T^<V5T5F%L=64H)V9U;&QN86UE
M)RP@)&9U;&QN86UE*3L*("`@("`@("`D:61E;G1I='DM/G-E=%9A;'5E*"=F
M<F]M7V%D9'(G+"`D96UA:6PI.PH@("`@("`@("1I9&5N=&ET>2T^<V%V92@I
M.PH*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B4W5C
M8V5S<V9U;&QY('5P9&%T960@7"(E<UPB(BDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1U<V5R7VYA;65?,BDL("=H;W)D92YS=6-C
M97-S)RD["B`@("!]"B`@("`D=F%R<RT^<F5M;W9E*"=U<V5R7VYA;64G*3L*
M("`@(&)R96%K.PH*8V%S92`G87!P<F]V95]F)SH*("`@("1T:&ES4VEG;G5P
M(#T@)'-I9VYU<"T^9V5T475E=65D4VEG;G5P*%5T:6PZ.F=E=$9O<FU$871A
M*"=U<V5R7VYA;64G*2D["B`@("`D:6YF;R`]("1T:&ES4VEG;G5P+3YG971$
M871A*"D["@H@("`@)'9A<G,M/G-E="@G<&%S<W=O<F0G+`H@("`@("`@("`@
M("`@("!A<G)A>2@G;W)I9VEN86PG(#T^("1I;F9O6R=P87-S=V]R9"==+`H@
M("`@("`@("`@("`@("`@("`@("`G8V]N9FER;2<@/3X@)&EN9F];)W!A<W-W
M;W)D)UTI*3L*("`@('5N<V5T*"1I;F9O6R=P87-S=V]R9"==*3L*("`@("1V
M87)S+3YS970H)V5X=')A)RP@)&EN9F\I.PH*("`@("1V87)S+3YS970H)W)E
M;6]V95%U975E9%-I9VYU<"<L('1R=64I.PH@("`@)&%D9$9O<FTM/F%D9$AI
M9&1E;B@G)RP@)W)E;6]V95%U975E9%-I9VYU<"<L("=B;V]L96%N)RP@=')U
M92D["B`@("!B<F5A:SL*"F-A<V4@)W)E;6]V97%U975E9%]F)SH*("`@("1F
M7W5S97)?;F%M92`](%5T:6PZ.F=E=$9O<FU$871A*"=U<V5R7VYA;64G*3L*
M("`@("1R96UO=F5Q=65U961?9F]R;2`]('1R=64["B`@("!B<F5A:SL*"F-A
M<V4@)W)E;6]V97%U975E9"<Z"B`@("`D<F5S=6QT(#T@)'-I9VYU<"T^<F5M
M;W9E475E=65D4VEG;G5P*%5T:6PZ.F=E=$9O<FU$871A*"=U<V5R7VYA;64G
M*2D["B`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D<F5S=6QT*3L*("`@('T@96QS
M92!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E1H
M92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB*2P@
M571I;#HZ9V5T1F]R;41A=&$H)W5S97)?;F%M92<I*2D["B`@("!]"B`@("!B
M<F5A:SL*?0H*)'1I=&QE(#T@7R@B57-E<B!!9&UI;FES=')A=&EO;B(I.PI(
M;W)D93HZ861D4V-R:7!T1FEL92@G<W1R:7!E+FIS)RP@)VAO<F1E)RP@=')U
M92D["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R
M+FEN8R<["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]A9&UI;B]C;VUM
M;VXM:&5A9&5R+FEN8R<["B1N;W1I9FEC871I;VXM/FYO=&EF>2AA<G)A>2@G
M;&ES=&5N97)S)R`]/B`G<W1A='5S)RDI.PH*:68@*&ES<V5T*"1U<&1A=&5?
M9F]R;2D@)B8@)&%U=&@M/FAA<T-A<&%B:6QI='DH)VQI<W0G*2D@>PH@("`@
M<F5Q=6ER95]O;F-E("=(;W)D92])9&5N=&ET>2YP:'`G.PH@("`@)&ED96YT
M:71Y(#T@)DED96YT:71Y.CIS:6YG;&5T;VXH)VYO;F4G+"`D9E]U<V5R7VYA
M;64I.PH@("`@<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V%D;6EN+W5S
M97(O=7!D871E+FEN8R<["GT@96QS96EF("AI<W-E="@D<F5M;W9E7V9O<FTI
M("8F("1A=71H+3YH87-#87!A8FEL:71Y*"=L:7-T)RD@)B8@)&%U=&@M/FAA
M<T-A<&%B:6QI='DH)W)E;6]V92<I*2!["B`@("!R97%U:7)E($A/4D1%7U1%
M35!,051%4R`N("<O861M:6XO=7-E<B]R96UO=F4N:6YC)SL*?2!E;'-E:68@
M*&ES<V5T*"1C;&5A<E]F;W)M*2D@>PH@("`@<F5Q=6ER92!(3U)$15]414U0
M3$%415,@+B`G+V%D;6EN+W5S97(O8VQE87(N:6YC)SL*?2!E;'-E:68@*&ES
M<V5T*"1R96UO=F5Q=65U961?9F]R;2DI('L*("`@(')E<75I<F4@2$]21$5?
M5$5-4$Q!5$53("X@)R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,G.PI]
M(&5L<V5I9B`H)&%U=&@M/FAA<T-A<&%B:6QI='DH)V%D9"<I*2!["B`@("!R
M97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O861M:6XO=7-E<B]A9&0N:6YC
M)SL*("`@(&EF("@D8V]N9ELG<VEG;G5P)UU;)V%L;&]W)UT@)B8@)&-O;F9;
M)W-I9VYU<"==6R=A<'!R;W9E)UTI('L*("`@("`@("!R97%U:7)E($A/4D1%
M7U1%35!,051%4R`N("<O861M:6XO=7-E<B]A<'!R;W9E+FEN8R<["B`@("!]
M"GT@96QS92!["B`@("!R97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O861M
M:6XO=7-E<B]N;V%D9"YI;F,G.PI]"@II9B`H)&%U=&@M/FAA<T-A<&%B:6QI
M='DH)VQI<W0G*2D@>PH*("`@("\J($EF('=E(&%R96XG="!S=7!P;&EE9"!W
M:71H(&$@<&%G92!N=6UB97(L(&1E9F%U;'0@=&\@<&%G92`P+B`J+PH@("`@
M)'!A9V4@/2!5=&EL.CIG971&;W)M1&%T82@G<&%G92<L(#`I.PH@("`@)'-E
M87)C:%]P871T97)N(#T@571I;#HZ9V5T1F]R;41A=&$H)W-E87)C:%]P871T
M97)N)RP@)R<I.PH*("`@("1U<V5R<R`]("1A=71H+3YL:7-T57-E<G,H*3L*
M("`@(&EF("AI<U]A*"1U<V5R<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M($AO<F1E.CIF871A;"@D=7-E<G,L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@
M("!]"@H@("`@+RH@4F5T=7)N<R!O;FQY('5S97)S('1H870@;6%T8V@@=&AE
M('-P96-I9FEE9"!P871T97)N+B`J+PH@("`@<F5Q=6ER95]O;F-E("=(;W)D
M92]!<G)A>2YP:'`G.PH@("`@)'5S97)S(#T@<')E9U]G<F5P*"<O)R`N("1S
M96%R8VA?<&%T=&5R;B`N("<O)RP@)'5S97)S*3L*("`@('-O<G0H)'5S97)S
M*3L*"B`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U5)+U!A9V5R+G!H<"<["B`@
M("`D=FEE=W5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@G861M:6XO=7-E<BYP
M:'`G+"`G<V5A<F-H7W!A='1E<FXG+"`D<V5A<F-H7W!A='1E<FXI.PH*("`@
M("1N=6UI=&5M(#T@8V]U;G0H)'5S97)S*3L*("`@("1P97)P86=E(#T@,C`[
M"@H@("`@)&UI;B`]("1P86=E("H@)'!E<G!A9V4["B`@("!W:&EL92`H)&UI
M;B`^("1N=6UI=&5M*2!["B`@("`@("`@)'!A9V4M+3L*("`@("`@("`D;6EN
M(#T@)'!A9V4@*B`D<&5R<&%G93L*("`@('T*("`@("1M87@@/2`D;6EN("L@
M)'!E<G!A9V4["@H@("`@)'-T87)T(#T@*"1P86=E("H@)'!E<G!A9V4I("L@
M,3L*("`@("1E;F0@/2!M:6XH)&YU;6ET96TL("1S=&%R="`K("1P97)P86=E
M("T@,2D["@H@("`@<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V%D;6EN
M+W5S97(O;&ES="YI;F,G.PI](&5L<V4@>PH@("`@<F5Q=6ER92!(3U)$15]4
M14U03$%415,@+B`G+V%D;6EN+W5S97(O;F]L:7-T+FEN8R<["GT*"G)E<75I
M<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]A9&UI;B]C;61S:&5L;"YP:'``````
M````````````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,R-3,@
M,3`U,34T,S,W,S0@,#(Q,3,W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+V%D
M;6EN+V-M9'-H96QL+G!H<"QV(#$N.2XQ,"XV(#(P,#8O,#(O,C0@,C(Z-#@Z
M,CD@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C
M:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@
M)R\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A<V4N
M<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]-96YU+G!H<"<["G)E<75I<F5?
M;VYC92`G2&]R9&4O2&5L<"YP:'`G.PH*:68@*"%!=71H.CII<T%D;6EN*"DI
M('L*("`@($AO<F1E.CIF871A;"@G1F]R8FED9&5N+B<L(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["GT*"B1T:71L92`](%\H(D-O;6UA;F0@4VAE;&PB*3L*<F5Q
M=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*
M<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V%D;6EN+V-O;6UO;BUH96%D
M97(N:6YC)SL*"F5C:&\@)SQD:78@<W1Y;&4](G!A9&1I;F<Z,3!P>"(^)SL*
M:68@*"1C;VUM86YD(#T@=')I;2A5=&EL.CIG971&;W)M1&%T82@G8VUD)RDI
M*2!["B`@("!E8VAO("<\:#$@8VQA<W,](FAE861E<B(^)R`N(%\H(D-O;6UA
M;F0B*2`N("<Z/"]H,3X\8G(@+SXG.PH@("`@96-H;R`G/'`@8VQA<W,](G1E
M>'0B/CQC;V1E/B<@+B!N;#)B<BAH=&UL<W!E8VEA;&-H87)S*"1C;VUM86YD
M*2D@+B`G/"]C;V1E/CPO<#XG.PH*("`@(&5C:&\@)SQB<B`O/CQH,2!C;&%S
M<STB:&5A9&5R(CXG("X@7R@B4F5S=6QT<R(I("X@)SH\+V@Q/CQB<B`O/B<[
M"B`@("!E8VAO("<\<')E(&-L87-S/2)T97AT(CXG.PH*("`@("1C;61S(#T@
M97AP;&]D92@B7&XB+"`D8V]M;6%N9"D["B`@("!F;W)E86-H("@D8VUD<R!A
M<R`D8VUD*2!["B`@("`@("`@)&-M9"`]('1R:6TH)&-M9"D["B`@("`@("`@
M:68@*'-T<FQE;B@D8VUD*2D@>PH@("`@("`@("`@("!U;G-E="@D<F5S=6QT
M<RD["B`@("`@("`@("`@(&9L=7-H*"D["B`@("`@("`@("`@(&5C:&\@:'1M
M;'-P96-I86QC:&%R<RAS:&5L;%]E>&5C*"1C;60I*3L*("`@("`@("!]"B`@
M("!]"@H@("`@96-H;R`G/"]P<F4^/&)R("\^)SL*?0H_/@H*/&9O<FT@86-T
M:6]N/2(\/W!H<"!E8VAO("1?4T525D526R=02%!?4T5,1B==(#\^(B!M971H
M;V0](G!O<W0B/@H\/W!H<"!5=&EL.CIP9F]R;4EN<'5T*"D@/SX*/'1E>'1A
M<F5A(&-L87-S/2)F:7AE9"(@;F%M93TB8VUD(B!R;W=S/2(Q,"(@8V]L<STB
M-C`B/@H\/W!H<"!I9B`H(65M<'1Y*"1C;VUM86YD*2D@96-H;R!H=&UL<W!E
M8VEA;&-H87)S*"1C;VUM86YD*2`_/CPO=&5X=&%R96$^"CQB<B`O/@H\:6YP
M=70@='EP93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/#]P:'`@
M96-H;R!?*")%>&5C=71E(BD@/SXB("\^"CP_<&AP(&5C:&\@2&5L<#HZ;&EN
M:R@G861M:6XG+"`G861M:6XM8VUD<VAE;&PG*2`_/@H*/"]F;W)M/@H\+V1I
M=CX*/#]P:'`*"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM
M9F]O=&5R+FEN8R<["@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O861M:6XO9&%T871R964N<&AP````````````
M````````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`T-S(S(#$P-3$U
M-#,S-S,T(#`R,3$T,``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]A9&UI;B]D
M871A=')E92YP:'`L=B`Q+C<N,BXT(#(P,#8O,#(O,#$@,#DZ,S`Z-#8@<V5L
M<VMY($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@2F%N(%-C:&YE
M:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*9G5N8W1I
M;VX@861D5')E92@D<&%R96YT+"`D<&%R96YT7VED+"`D:6YD96YT(#T@,2D*
M>PH@("`@9VQO8F%L("1D871A=')E92P@)'1R964["@H@("`@)&YO9&5S(#T@
M)&1A=&%T<F5E+3YG971">4ED*$1!5$%44D5%7T9/4DU!5%]&3$%4+"`D<&%R
M96YT7VED+"!T<G5E+"`D<&%R96YT+"`Q*3L*("`@("1E>'!A;F1E9"`]("1T
M<F5E+3YI<T5X<&%N9&5D*"1P87)E;G0I.PH@("`@)'5R;"`]($AO<F1E.CIU
M<FPH)V1A=&%T<F5E+G!H<"<I.PH@("`@9F]R96%C:"`H)&YO9&5S(&%S("1I
M9"`]/B`D;F]D92D@>PH@("`@("`@(&EF("@D:60@/3T@)'!A<F5N=%]I9"D@
M>PH@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("!]"B`@("`@("`@)'1R
M964M/F%D9$YO9&4H)'!A<F5N="`N("<Z)R`N("1I9"P@)'!A<F5N="P@)&1A
M=&%T<F5E+3YG9713:&]R=$YA;64H)&YO9&4I+"`D:6YD96YT+"!F86QS92P@
M87)R87DH)W5R;"<@/3X@571I;#HZ861D4&%R86UE=&5R*"1U<FPL("=S:&]W
M)RP@)&1A=&%T<F5E+3YG971087)A;2@G9W)O=7`G*2`N("<Z)R`N("1I9"D@
M+B`G(W-H;W<G*2D["B`@("`@("`@:68@*"1E>'!A;F1E9"D@>PH@("`@("`@
M("`@("!A9&14<F5E*"1P87)E;G0@+B`G.B<@+B`D:60L("1I9"P@)&EN9&5N
M="`K(#$I.PH@("`@("`@('T*("`@('T*?0H*0&1E9FEN92@G2$]21$5?0D%3
M12<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B<I.PIR97%U:7)E7V]N8V4@
M2$]21$5?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=(
M;W)D92]-96YU+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O2&5L<"YP:'`G
M.PIR97%U:7)E7V]N8V4@)TAO<F1E+U1R964N<&AP)SL*<F5Q=6ER95]O;F-E
M("=(;W)D92]$871A5')E92YP:'`G.PH*:68@*"%!=71H.CII<T%D;6EN*"DI
M('L*("`@($AO<F1E.CIA=71H96YT:6-A=&EO;D9A:6QU<F52961I<F5C="@I
M.PI]"@HD=')E92`]("9(;W)D95]4<F5E.CIF86-T;W)Y*"=D871A=')E92<L
M("=H=&UL)RD["B1T<F5E+3YS971/<'1I;VXH)V%L=&5R;F%T92<L('1R=64I
M.PH*)&1R:79E<B`]("1C;VYF6R=D871A=')E92==6R=D<FEV97(G73L*)&-O
M;F9I9R`]($AO<F1E.CIG971$<FEV97)#;VYF:6<H)V1A=&%T<F5E)RP@)&-O
M;F9;)V1A=&%T<F5E)UU;)V1R:79E<B==*3L*)&1A=&%T<F5E(#T@)D1A=&%4
M<F5E.CIS:6YG;&5T;VXH)&-O;F9;)V1A=&%T<F5E)UU;)V1R:79E<B==*3L*
M)')O;W1S(#T@)&1A=&%T<F5E+3YG971'<F]U<',H*3L*"FEF("AI<U]A*"1R
M;V]T<RP@)U!%05)?17)R;W(G*2D@>PH@("`@)&YO=&EF:6-A=&EO;BT^<'5S
M:"@D<F]O=',I.PI](&5L<V4@>PH@("`@9F]R96%C:"`H)')O;W1S(&%S("1R
M;V]T*2!["B`@("`@("`@)'1R964M/F%D9$YO9&4H)')O;W0L(&YU;&PL("1R
M;V]T+"`P+"!F86QS92D["B`@("`@("`@)&1A=&%T<F5E(#T@)D1A=&%4<F5E
M.CIS:6YG;&5T;VXH)&1R:79E<BP@87)R87E?;65R9V4H)&-O;F9I9RP@87)R
M87DH)V=R;W5P)R`]/B`D<F]O="DI*3L*("`@("`@("!A9&14<F5E*"1R;V]T
M+"!$051!5%)%15]23T]4*3L*("`@('T*?0H*:68@*"1S:&]W(#T@571I;#HZ
M9V5T1F]R;41A=&$H)W-H;W<G*2D@>PH@("`@;&ES="@D<F]O="P@)&ED*2`]
M(&5X<&QO9&4H)SHG+"`D<VAO=RD["B`@("`D9&%T871R964@/2`F1&%T851R
M964Z.G-I;F=L971O;B@D9')I=F5R+"!A<G)A>5]M97)G92@D8V]N9FEG+"!A
M<G)A>2@G9W)O=7`G(#T^("1R;V]T*2DI.PH@("`@)&1A=&$@/2`D9&%T871R
M964M/F=E=$1A=&$H)&ED*3L*("`@("1A='1R:6)U=&5S(#T@)&1A=&%T<F5E
M+3YG971!='1R:6)U=&5S*"1I9"D["GT*"B1T:71L92`](%\H(D1A=&%4<F5E
M($)R;W=S97(B*3L*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO
M;BUH96%D97(N:6YC)SL*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V%D
M;6EN+V-O;6UO;BUH96%D97(N:6YC)SL*)&YO=&EF:6-A=&EO;BT^;F]T:69Y
M*"D["B1T<F5E+3YR96YD97)4<F5E*"D["FEF("@D<VAO=RD@>PH@("`@96-H
M;R`G/&)R("\^/&1I=B!C;&%S<STB=&5X="(@<W1Y;&4](G=H:71E+7-P86-E
M.G!R92(^/&$@:60](G-H;W<B/CPO83XG.PH@("`@<')I;G1?<B@D9&%T82D[
M"B`@("!P<FEN=%]R*"1A='1R:6)U=&5S*3L*("`@(&5C:&\@)SPO9&EV/B<[
M"GT*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUF;V]T97(N
M:6YC)SL*````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O861M:6XO<V5S<VEO;G,N
M<&AP````````````````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`T,#(T(#$P-3$U-#,S-S,T(#`R,3(P-P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H
M;W)D92]A9&UI;B]S97-S:6]N<RYP:'`L=B`Q+C(N,BXS(#(P,#8O,#$O,#$@
M,C$Z,C@Z,#4@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*B\*"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?
M*2`N("<O+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B
M87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O365N=2YP:'`G.PIR97%U
M:7)E7V]N8V4@)TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<"<["@II9B`H(4%U
M=&@Z.FES061M:6XH*2D@>PH@("`@2&]R9&4Z.F%U=&AE;G1I8V%T:6]N1F%I
M;'5R95)E9&ER96-T*"D["GT*"B1T>7!E(#T@(65M<'1Y*"1C;VYF6R=S97-S
M:6]N:&%N9&QE<B==6R=T>7!E)UTI(#\@)&-O;F9;)W-E<W-I;VYH86YD;&5R
M)UU;)W1Y<&4G72`Z("=N;VYE)SL*:68@*"1T>7!E(#T]("=E>'1E<FYA;"<I
M('L*("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B0V%N)W0@861M:6YI<W1E
M<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+B(I+"`G:&]R9&4N97)R;W(G
M*3L*?2!E;'-E('L*("`@("1S:"`]("9397-S:6]N2&%N9&QE<CHZ<VEN9VQE
M=&]N*"1T>7!E*3L*?0H*)'1I=&QE(#T@7R@B4V5S<VEO;B!!9&UI;B(I.PIR
M97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+6AE861E<BYI;F,G
M.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O861M:6XO8V]M;6]N+6AE
M861E<BYI;F,G.PHD;F]T:69I8V%T:6]N+3YN;W1I9GDH87)R87DH)VQI<W1E
M;F5R<R<@/3X@)W-T871U<R<I*3L*"FEF("@A96UP='DH)'-H*2D@>PH@("`@
M)'5S97)S(#T@)'-H+3YL:7-T075T:&5N=&EC871E9%5S97)S*"D["B`@("`D
M8V]U;G0@/2`D<V@M/F-O=6YT075T:&5N=&EC871E9%5S97)S*"D["B`@("!E
M8VAO("<\:#$@8VQA<W,](FAE861E<B(^)R`N(%\H(D-U<G)E;G0@57-E<G,B
M*3L*("`@(&EF("AI<U]A*"1U<V5R<RP@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@(&5C:&\@)SPO:#$^/'`@8VQA<W,](FAE861E<F)O>"(^/&5M/B<@+B!S
M<')I;G1F*%\H(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(I+"`D=7-E<G,M
M/F=E=$UE<W-A9V4H*2D@+B`G/"]E;3X\+W`^)SL*("`@('T@96QS92!["B`@
M("`@("`@96-H;R`G("@G("X@)&-O=6YT("X@)RD\+V@Q/B<["B`@("`@("`@
M96-H;R`G/'5L(&-L87-S/2)H96%D97)B;W@@;&EN9612;W<B/B<["B`@("`@
M("`@9F]R96%C:"`H)'5S97)S(&%S("1U<V5R*2!["B`@("`@("`@("`@(&5C
M:&\@)SQL:3XG("X@:'1M;'-P96-I86QC:&%R<R@D=7-E<BD@+B`G/"]L:3XG
M.PH@("`@("`@('T*("`@("`@("!E8VAO("<\+W5L/B<["B`@("!]"@H@("`@
M96-H;R`G/&)R("\^)SL*"B`@("`D:61S(#T@)'-H+3YG971397-S:6]N241S
M*"D["B`@("!E8VAO("<\:#$@8VQA<W,](FAE861E<B(^)R`N(%\H(D-U<G)E
M;G0@4V5S<VEO;G,B*2`N("<\+V@Q/B<["B`@("!I9B`H:7-?82@D:61S+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@96-H;R`G/'`@8VQA<W,](FAE861E
M<F)O>"(^/&5M/B<@+B!S<')I;G1F*%\H(DQI<W1I;F<@<V5S<VEO;G,@9F%I
M;&5D.B`E<R(I+"`D:61S+3YG971-97-S86=E*"DI("X@)SPO96T^/"]P/B<[
M"B`@("!](&5L<V4@>PH@("`@("`@(&5C:&\@)SQU;"!C;&%S<STB:&5A9&5R
M8F]X(&QI;F5D4F]W(CXG.PH@("`@("`@(&9O<F5A8V@@*"1I9',@87,@)'5S
M97(I('L*("`@("`@("`@("`@96-H;R`G/&QI/B<@+B!H=&UL<W!E8VEA;&-H
M87)S*"1U<V5R*2`N("<\+VQI/B<["B`@("`@("`@?0H@("`@("`@(&5C:&\@
M)SPO=6P^)SL*("`@('T*?0H*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G
M+V-O;6UO;BUF;V]T97(N:6YC)SL*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O861M
M:6XO<W%L<VAE;&PN<&AP````````````````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#$S,S$R(#$P-3$U-#,S-S,T(#`R,3$W,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@)$AO<F1E.B!H;W)D92]A9&UI;B]S<6QS:&5L;"YP:'`L=B`Q+C$X+C$P
M+CD@,C`P-B\P,B\R-"`R,CHT.#HR.2!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@
M9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD["G)E<75I<F5?;VYC92!(3U)$
M15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E
M+TUE;G4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92](96QP+G!H<"<["G)E
M<75I<F5?;VYC92`G1$(N<&AP)SL*"FEF("@A075T:#HZ:7-!9&UI;B@I*2![
M"B`@("!(;W)D93HZ9F%T86PH)T9O<F)I9&1E;BXG+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PI]"@HD=&ET;&4@/2!?*")344P@4VAE;&PB*3L*2&]R9&4Z.F%D
M9%-C<FEP=$9I;&4H)W-T<FEP92YJ<R<L("=H;W)D92<L('1R=64I.PIR97%U
M:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+6AE861E<BYI;F,G.PIR
M97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O861M:6XO8V]M;6]N+6AE861E
M<BYI;F,G.PH*/SX*/&1I=B!S='EL93TB<&%D9&EN9SHQ,'!X(CX*/&9O<FT@
M;F%M93TB<W%L<VAE;&PB(&%C=&EO;CTB/#]P:'`@96-H;R`D7U-%4E9%4ELG
M4$A07U-%3$8G72`_/B(@;65T:&]D/2)P;W-T(CX*/#]P:'`@571I;#HZ<&9O
M<FU);G!U="@I(#\^"@H\/W!H<`H*)&1B:"`]("9$0CHZ8V]N;F5C="@D8V]N
M9ELG<W%L)UTI.PII9B`H:7-?82@D9&)H+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("!(;W)D93HZ9F%T86PH)&1B:"P@7U]&24Q%7U\L(%]?3$E.15]?*3L*?0HD
M9&)H+3YS971/<'1I;VXH)W!O<G1A8FEL:71Y)RP@1$)?4$]25$%"24Q)5%E?
M3$]715)#05-%('P@1$)?4$]25$%"24Q)5%E?15)23U)3*3L*"FEF("A5=&EL
M.CIG971&;W)M1&%T82@G;&ES="UT86)L97,G*2D@>PH@("`@)&1E<V-R:7!T
M:6]N(#T@)TQ)4U0@5$%"3$53)SL*("`@("1R97-U;'0@/2`D9&)H+3YG971,
M:7-T3V8H)W1A8FQE<R<I.PI](&5L<V5I9B`H571I;#HZ9V5T1F]R;41A=&$H
M)VQI<W0M9&)S)RDI('L*("`@("1D97-C<FEP=&EO;B`]("=,25-4($1!5$%"
M05-%4R<["B`@("`D<F5S=6QT(#T@)&1B:"T^9V5T3&ES=$]F*"=D871A8F%S
M97,G*3L*?2!E;'-E:68@*"1C;VUM86YD(#T@=')I;2A5=&EL.CIG971&;W)M
M1&%T82@G<W%L)RDI*2!["B`@("`O+R!+965P(&$@8V%C:&4@;V8@<')I;W(@
M<75E<FEE<R!F;W(@8V]N=F5N:65N8V4N"B`@("!I9B`H(6ES<V5T*"1?4T53
M4TE/3ELG7W-Q;%]Q=65R>5]C86-H92==*2D@>PH@("`@("`@("1?4T534TE/
M3ELG7W-Q;%]Q=65R>5]C86-H92==(#T@87)R87DH*3L*("`@('T*("`@(&EF
M("@H)&ME>2`](&%R<F%Y7W-E87)C:"@D8V]M;6%N9"P@)%]315-324].6R=?
M<W%L7W%U97)Y7V-A8VAE)UTI*2`A/3T@9F%L<V4I('L*("`@("`@("!U;G-E
M="@D7U-%4U-)3TY;)U]S<6Q?<75E<GE?8V%C:&4G75LD:V5Y72D["B`@("!]
M"B`@("!A<G)A>5]U;G-H:69T*"1?4T534TE/3ELG7W-Q;%]Q=65R>5]C86-H
M92==+"`D8V]M;6%N9"D["B`@("!W:&EL92`H8V]U;G0H)%]315-324].6R=?
M<W%L7W%U97)Y7V-A8VAE)UTI(#X@,C`I('L*("`@("`@("!A<G)A>5]P;W`H
M)%]315-324].6R=?<W%L7W%U97)Y7V-A8VAE)UTI.PH@("`@?0H*("`@("\O
M(%!A<G-E(&]U="!T:&4@<75E<GD@<F5S=6QT<RX*("`@("1R97-U;'0@/2`D
M9&)H+3YQ=65R>2A3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1C;VUM86YD+"!.
M3%,Z.F=E=$-H87)S970H*2P@)&-O;F9;)W-Q;"==6R=C:&%R<V5T)UTI*3L*
M?0H*:68@*&ES<V5T*"1R97-U;'0I*2!["B`@("!I9B`H:7-S970H)&-O;6UA
M;F0I*2!["B`@("`@("`@96-H;R`G/&@Q(&-L87-S/2)H96%D97(B/B<@+B!?
M*")1=65R>2(I("X@)SPO:#$^/&)R("\^/'!R92!C;&%S<STB=&5X="(^)R`N
M(&AT;6QS<&5C:6%L8VAA<G,H)&-O;6UA;F0I("X@)SPO<')E/B<["B`@("!]
M"@H@("`@96-H;R`G/&@Q(&-L87-S/2)H96%D97(B/B<@+B!?*")297-U;'1S
M(BD@+B`G/"]H,3X\8G(@+SXG.PH*("`@(&EF("AI<U]A*"1R97-U;'0L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("!E8VAO("<\<')E(&-L87-S/2)T97AT
M(CXG.R!V87)?9'5M<"@D<F5S=6QT*3L@96-H;R`G/"]P<F4^)SL*("`@('T@
M96QS92!["B`@("`@("`@:68@*&ES7V]B:F5C="@D<F5S=6QT*2D@>PH@("`@
M("`@("`@("!E8VAO("<\=&%B;&4@8V5L;'-P86-I;F<](C$B(&-L87-S/2)I
M=&5M('-T<FEP960B/B<["B`@("`@("`@("`@("1F:7)S="`]('1R=64["B`@
M("`@("`@("`@("1I(#T@,#L*("`@("`@("`@("`@=VAI;&4@*"1R;W<@/2`D
M<F5S=6QT+3YF971C:%)O=RA$0E]&151#2$U/1$5?05-33T,I*2!["B`@("`@
M("`@("`@("`@("!I9B`H)&9I<G-T*2!["B`@("`@("`@("`@("`@("`@("`@
M96-H;R`G/'1R/B<["B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)')O
M=R!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M96-H;R`G/'1H(&%L:6=N/2)L969T(CXG("X@*&5M<'1Y*"1K97DI(#\@)R9N
M8G-P.R<@.B!H=&UL<W!E8VEA;&-H87)S*%-T<FEN9SHZ8V]N=F5R=$-H87)S
M970H)&ME>2P@)&-O;F9;)W-Q;"==6R=C:&%R<V5T)UTI*2D@+B`G/"]T:#XG
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!E
M8VAO("<\+W1R/B<["B`@("`@("`@("`@("`@("`@("`@)&9I<G-T(#T@9F%L
M<V4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E8VAO("<\
M='(^)SL*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1R;W<@87,@)'9A;"D@
M>PH@("`@("`@("`@("`@("`@("`@(&5C:&\@)SQT9"!C;&%S<STB9FEX960B
M/B<@+B`H96UP='DH)'9A;"D@/R`G)FYB<W`[)R`Z(&AT;6QS<&5C:6%L8VAA
M<G,H4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D=F%L+"`D8V]N9ELG<W%L)UU;
M)V-H87)S970G72DI*2`N("<\+W1D/B<["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!E8VAO("<\+W1R/B<["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@96-H;R`G/"]T86)L93XG.PH@("`@("`@('T@96QS96EF("AI
M<U]A<G)A>2@D<F5S=6QT*2D@>PH@("`@("`@("`@("!E8VAO("<\=&%B;&4@
M8V5L;'-P86-I;F<](C$B(&-L87-S/2)I=&5M('-T<FEP960B/B<["B`@("`@
M("`@("`@("1F:7)S="`]('1R=64["B`@("`@("`@("`@("1I(#T@,#L*("`@
M("`@("`@("`@9F]R96%C:"`H)')E<W5L="!A<R`D=F%L*2!["B`@("`@("`@
M("`@("`@("!I9B`H)&9I<G-T*2!["B`@("`@("`@("`@("`@("`@("`@96-H
M;R`G/'1R/CQT:"!A;&EG;CTB;&5F="(^)R`N("AI<W-E="@D9&5S8W)I<'1I
M;VXI(#\@:'1M;'-P96-I86QC:&%R<R@D9&5S8W)I<'1I;VXI(#H@)R9N8G-P
M.R<I("X@)SPO=&@^/"]T<CXG.PH@("`@("`@("`@("`@("`@("`@("1F:7)S
M="`](&9A;'-E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M96-H;R`G/'1R/CQT9"!C;&%S<STB9FEX960B/B<@+B`H96UP='DH)'9A;"D@
M/R`G)FYB<W`[)R`Z(&AT;6QS<&5C:6%L8VAA<G,H4W1R:6YG.CIC;VYV97)T
M0VAA<G-E="@D=F%L+"`D8V]N9ELG<W%L)UU;)V-H87)S970G72DI*2`N("<\
M+W1D/CPO='(^)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E8VAO("<\
M+W1A8FQE/B<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@96-H;R`G
M/'-T<F]N9SXG("X@7R@B4W5C8V5S<R(I("X@)SPO<W1R;VYG/B<["B`@("`@
M("`@?0H@("`@?0H*("`@(&5C:&\@)SQB<B`O/B<["GT*/SX*"CP_<&AP(&EF
M("AI<W-E="@D7U-%4U-)3TY;)U]S<6Q?<75E<GE?8V%C:&4G72D@)B8*("`@
M("`@("`@(&-O=6YT*"1?4T534TE/3ELG7W-Q;%]Q=65R>5]C86-H92==*2DZ
M(#\^"B`@/'-E;&5C="!N86UE/2)Q=65R>5]C86-H92(@;VYC:&%N9V4](F1O
M8W5M96YT+G-Q;'-H96QL+G-Q;"YV86QU92`](&1O8W5M96YT+G-Q;'-H96QL
M+G%U97)Y7V-A8VAE6V1O8W5M96YT+G-Q;'-H96QL+G%U97)Y7V-A8VAE+G-E
M;&5C=&5D26YD97A=+G9A;'5E.R(^"B`@/#]P:'`@9F]R96%C:"`H)%]315-3
M24].6R=?<W%L7W%U97)Y7V-A8VAE)UT@87,@)'%U97)Y*3H@/SX*("`@(#QO
M<'1I;VX@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D<75E
M<GDI(#\^(CX\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'%U97)Y*2`_
M/CPO;W!T:6]N/@H@(#P_<&AP(&5N9&9O<F5A8V@[(#\^"B`@/"]S96QE8W0^
M"B`@/&EN<'5T('1Y<&4](F)U='1O;B(@=F%L=64](CP_<&AP(&5C:&\@7R@B
M4&%S=&4B*2`_/B(@8VQA<W,](F)U='1O;B(@;VYC;&EC:STB9&]C=6UE;G0N
M<W%L<VAE;&PN<W%L+G9A;'5E(#T@9&]C=6UE;G0N<W%L<VAE;&PN<75E<GE?
M8V%C:&5;9&]C=6UE;G0N<W%L<VAE;&PN<75E<GE?8V%C:&4N<V5L96-T961)
M;F1E>%TN=F%L=64[(B`O/@H@(#QI;G!U="!T>7!E/2)B=71T;VXB('9A;'5E
M/2(\/W!H<"!E8VAO(%\H(E)U;B(I(#\^(B!C;&%S<STB8G5T=&]N(B!O;F-L
M:6-K/2)D;V-U;65N="YS<6QS:&5L;"YS<6PN=F%L=64@/2!D;V-U;65N="YS
M<6QS:&5L;"YQ=65R>5]C86-H95MD;V-U;65N="YS<6QS:&5L;"YQ=65R>5]C
M86-H92YS96QE8W1E9$EN9&5X72YV86QU93L@9&]C=6UE;G0N<W%L<VAE;&PN
M<W5B;6ET*"D[(B`O/@H@(#QB<B`O/@H\/W!H<"!E;F1I9CL@/SX*"CQT97AT
M87)E82!C;&%S<STB9FEX960B(&YA;64](G-Q;"(@<F]W<STB,3`B(&-O;',]
M(C8P(CX*/#]P:'`@:68@*"%E;7!T>2@D8V]M;6%N9"DI(&5C:&\@:'1M;'-P
M96-I86QC:&%R<R@D8V]M;6%N9"D@/SX\+W1E>'1A<F5A/@H\8G(@+SX*/&EN
M<'5T('1Y<&4](G-U8FUI="(@8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP
M(&5C:&\@7R@B17AE8W5T92(I(#\^(B`O/@H\:6YP=70@='EP93TB8G5T=&]N
M(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/#]P:'`@96-H;R!?*")#;&5A<B!1
M=65R>2(I(#\^(B!O;F-L:6-K/2)D;V-U;65N="YS<6QS:&5L;"YS<6PN=F%L
M=64])R<B("\^"CP_<&AP(&EF("@A96UP='DH)&-O;6UA;F0I*3H@/SX*/&EN
M<'5T('1Y<&4](G)E<V5T(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/#]P:'`@
M96-H;R!?*")297-T;W)E($QA<W0@475E<GDB*2`_/B(@+SX*/#]P:'`@96YD
M:68[(#\^"CP_<&AP(&EF("@D9&)H+3YG9713<&5C:6%L475E<GDH)W1A8FQE
M<R<I("$]/2!N=6QL*3H@/SX\:6YP=70@='EP93TB<W5B;6ET(B!C;&%S<STB
M8G5T=&]N(B!N86UE/2)L:7-T+71A8FQE<R(@=F%L=64](CP_<&AP(&5C:&\@
M7R@B3&ES="!486)L97,B*2`_/B(@+SX@/#]P:'`@96YD:68[(#\^"CP_<&AP
M(&EF("@D9&)H+3YG9713<&5C:6%L475E<GDH)V1A=&%B87-E<R<I("$]/2!N
M=6QL*3H@/SX\:6YP=70@='EP93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!N
M86UE/2)L:7-T+61B<R(@=F%L=64](CP_<&AP(&5C:&\@7R@B3&ES="!$871A
M8F%S97,B*2`_/B(@+SX@/#]P:'`@96YD:68[(#\^"CP_<&AP(&5C:&\@2&5L
M<#HZ;&EN:R@G861M:6XG+"`G861M:6XM<W%L<VAE;&PG*2`_/@H*/"]F;W)M
M/@H\+V1I=CX*/#]P:'`*"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C
M;VUM;VXM9F]O=&5R+FEN8R<["@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]A9&UI;B]T
M96UP;&%T97,N<&AP````````````````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,34Q,S8@,3`U,34T,S,W,S0@,#(Q,S0U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B!(
M;W)D92!496UP;&%T92!!9&UI;@H@*@H@*B`D2&]R9&4Z(&AO<F1E+V%D;6EN
M+W1E;7!L871E<RYP:'`L=B`Q+C$U+C$P+C,@,C`P-B\P,2\P,2`R,3HR.#HP
M-2!J86X@17AP("0*("H*("H@1FER<W0@<W1A8B!A="!A('1E;7!L871E(&QO
M861E<B!F;W(@:&]R9&4L('1O(&)E('5S960@8GD@=&AE(&AO<F1E"B`J(&%D
M;6EN('1O(&QO860@86QT97)N871E(&EN9&EV:61U86P@=&5M<&QA=&5S(&]R
M(&5N=&ER92!T:&5M97,@9F]R('1H90H@*B!(;W)D95]496UP;&%T92!S>7-T
M96TN"B`J("T@9VEV97,@82!L:7-T(&]F(&%C=&EV92!H;W)D92!A<'!S(&%N
M9"!T:&5I<B`O=&5M<&QA=&5S(&1I<F5C=&]R>0H@*B`@(&-O;G1E;G1S('1O
M(&-H;V]S92!F<F]M"B`J("T@=7-E<B!C86X@9')I;&P@9&]W;B!T;R!A('-P
M96-I9FEC(&9I;&4@86YD(&QO860@87,@;6%N>2!A;'1E<FYA=&4*("H@("!T
M96UP;&%T97,@87,@<F5Q=6ER960*("H@+2!I="!A;&QO=W,@<V%V:6YG(&]F
M('1E;7!L871E<R!O;FQY(&]N(&%C='5A;"!F:6QE<R`H86YD(&YO=`H@*B`@
M(&1I<F5C=&]R:65S*2!A;F0@9&]E<R!N;W0@<VAO=R!H:61D96X@9FEL97,N
M"B`J("T@=&AE(&%L=&5R;F%T92!T96UP;&%T97,@87)E('-T;W)E9"!I;B!T
M:&4@5D93('5N9&5R('1H92!D:7)E8W1O<GD*("H@("!P871H.@H@*B`@("`@
M("YH;W)D95]T96UP;&%T97,O)&%P<"]S;VUE=&5M<&QA=&5D:7(O=&5M<&QA
M=&5F:6QE"B`J("`@<V\@=&AA="!D:7)E8W1O<GD@=V]U;&0@8V]N=&%I;B!A
M;&P@=&AE(&%L=&5R;F%T:79E<R!F;W(@=&AA=`H@*B`@('1E;7!L871E+@H@
M*B`M(%1/1$\Z(&1O;B=T('-H;W<@8V5R=&%I;B!O=&AE<B!F:6QE<RP@;&EK
M92!#5E,@9&ER96-T;W)I97,[(&-O;6UE;G1S.PH@*B`@('1H96UE('-E;&5C
M=&EO;B!A;F0@<W1O<FEN9R!I;B!T:&4@5D93('5N9&5R.@H@*B`@("`@("YH
M;W)D95]T96UP;&%T97,O)&%P<"]?=&AE;65S+R1T:&5M92]S;VUE=&5M<&QA
M=&5D:7(O=&5M<&QA=&5F:6QE"B`J("`@=&\@8F4@86)L92!T;R!C86QL('5P
M(&%N(&5N=&ER92!T:&5M92!G<F]U<"!O9B!T96UP;&%T97,_(&)E='1E<B!E
M<G)O<@H@*B`@(&-H96-K:6YG.R!D;W=N;&]A9&EN9R!O9B!O<FEG:6YA;"!T
M96UP;&%T97,[('1H92!A<'!L:6-A=&EO;B!S:61E(&]F"B`J("`@86QL;W=I
M;F<@82!D:69F97)E;G0@=&5M<&QA=&4@=&\@8F4@8VAO<V5N+W!R969S+V5T
M8RX*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-87)K;R!$:G5K:6,@/&UA
M<FMO0&]B;&\N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G2$]2
M1$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B<I.PIR97%U:7)E
M7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*<F5Q=6ER95]O
M;F-E("=(;W)D92]-96YU+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O5F%R
M:6%B;&5S+G!H<"<["@II9B`H(4%U=&@Z.FES061M:6XH*2D@>PH@("`@2&]R
M9&4Z.F9A=&%L*"=&;W)B:61D96XN)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M?0HD875T:"`]("9!=71H.CIS:6YG;&5T;VXH)&-O;F9;)V%U=&@G75LG9')I
M=F5R)UTI.PH*9G5N8W1I;VX@7W-E=%9A;'5E<U1O2V5Y<R@D:6XI('L*("`@
M("1O=70@/2!A<G)A>2@I.PH@("`@9F]R96%C:"`H)&EN(&%S("1V86QU92D@
M>PH@("`@("`@("1O=71;)'9A;'5E72`]("1V86QU93L*("`@('T*("`@(&%S
M;W)T*"1O=70I.PH@("`@<F5T=7)N("1O=70["GT*"B\J(%-E="!U<"!61E,N
M("HO"G)E<75I<F5?;VYC92`G5D93+G!H<"<["B1V9G-?='EP92`]("1C;VYF
M6R=V9G,G75LG='EP92==.PHD=F9S7V%R9W,@/2!(;W)D93HZ9V5T1')I=F5R
M0V]N9FEG*"=V9G,G+"`D=F9S7W1Y<&4I.PHD=F9S7V%R9W-;)W5S97(G72`]
M($%U=&@Z.F=E=$%U=&@H*3L*)'9F<R`]("961E,Z.G-I;F=L971O;B@D=F9S
M7W1Y<&4L("1V9G-?87)G<RD["@I`9&5F:6YE*"=414U03$%415-?5D937U!!
M5$@G+"`G+FAO<F1E7W1E;7!L871E<R<I.PH*+RH@4F5Q=6ER92!(;W)D95]&
M;W)M(&QI8G,N("HO"G)E<75I<F5?;VYC92`G2&]R9&4O1F]R;2YP:'`G.PIR
M97%U:7)E7V]N8V4@)TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP)SL*<F5Q=6ER
M95]O;F-E("=(;W)D92]&;W)M+T%C=&EO;BYP:'`G.PH*+RH@4V5T('5P($AO
M<F1E7T9O<FTN("HO"B1V87)S(#T@)E9A<FEA8FQE<SHZ9V5T1&5F875L=%9A
M<FEA8FQE<R@I.PHD9F]R;2`]("9(;W)D95]&;W)M.CIS:6YG;&5T;VXH)U1E
M;7!L871E<T9O<FTG+"`D=F%R<RD["B1A8W1I;VX@/2`F2&]R9&5?1F]R;5]!
M8W1I;VXZ.F9A8W1O<GDH)W-U8FUI="<I.PH*+RH@4V5T('5P(&9O<FT@9FEE
M;&1S+B`J+PHD87!P<R`](%]S971686QU97-4;TME>7,H)')E9VES=')Y+3YL
M:7-T07!P<R@I*3L*)'-E;&5C=%]A<'`@/2`F)&9O<FTM/F%D9%9A<FEA8FQE
M*%\H(D%P<&QI8V%T:6]N(BDL("=A<'`G+"`G96YU;2<L('1R=64L(&9A;'-E
M+"!N=6QL+"!A<G)A>2@D87!P<RDI.PHD<V5L96-T7V%P<"T^<V5T06-T:6]N
M*"1A8W1I;VXI.PHD9F]R;2T^861D2&ED9&5N*"<G+"`G;VQD7V%P<"<L("=T
M97AT)RP@9F%L<V4L(&9A;'-E*3L*"B\J(%-E="!U<"!S;VUE('9A<FEA8FQE
M<RX@*B\*)&9O<FUN86UE(#T@)'9A<G,M/F=E="@G9F]R;6YA;64G*3L*)&%P
M<"`]("1V87)S+3YG970H)V%P<"<I.PHD;VQD7V%P<"`]("1V87)S+3YG970H
M)V]L9%]A<'`G*3L*)'1E;7!L871E7W!A=&@@/2`D=F%R<RT^9V5T*"=T96UP
M;&%T95]P871H)RD["B1T96UP;&%T95]O<FEG(#T@)'9A<G,M/F=E="@G=&5M
M<&QA=&5?;W)I9R<I.PHD;VQD7W1E;7!L871E7V]R:6<@/2`D=F%R<RT^9V5T
M*"=O;&1?=&5M<&QA=&5?;W)I9R<I.PHD:&%S7V-H86YG960@/2!F86QS93L*
M"FEF("@D87!P("$]("1O;&1?87!P*2!["B`@("`D:&%S7V-H86YG960@/2!T
M<G5E.PH@("`@)'1E;7!L871E7W!A=&@@/2`G)SL*("`@("1T96UP;&%T95]O
M<FEG(#T@)R<["B`@("`D;VQD7W1E;7!L871E7V]R:6<@/2`G)SL*?0HD=F%R
M<RT^<V5T*"=O;&1?87!P)RP@)&%P<"D["FEF("@D=&5M<&QA=&5?;W)I9R`A
M/2`D;VQD7W1E;7!L871E7V]R:6<I('L*("`@("1H87-?8VAA;F=E9"`]('1R
M=64["GT*)'9A<G,M/G-E="@G;VQD7W1E;7!L871E7V]R:6<G+"`D=&5M<&QA
M=&5?;W)I9RD["@II9B`H(6ES7VYU;&PH)&%P<"DI('L*("`@(&EF("@D=&5M
M<&QA=&5?;W)I9R`]/2`G+BXG*2!["B`@("`@("`@)'!A=&A?<&%R=',@/2!E
M>'!L;V1E*"<O)RP@)'1E;7!L871E7W!A=&@I.PH@("`@("`@(&%R<F%Y7W!O
M<"@D<&%T:%]P87)T<RD["B`@("`@("`@)'1E;7!L871E7W!A=&@@/2!I;7!L
M;V1E*"<O)RP@)'!A=&A?<&%R=',I.PH@("`@("`@("1T96UP;&%T95]O<FEG
M(#T@)R<["B`@("!]"@H@("`@+RH@1V5T('1H92!F=6QL('1E;7!L871E('!A
M=&@@;VX@=&AE(&9I;&4@<WES=&5M+B`J+PH@("`@)'1E;7!L871E7W!A=&A?
M9G5L;"`]("1R96=I<W1R>2T^9V5T*"=T96UP;&%T97,G+"`D87!P*2`N("<O
M)R`N("1T96UP;&%T95]P871H.PH*("`@("\J($EF('-E;&5C=&5D('1E;7!L
M871E(&ES(&1I<F5C=&]R>2!A9&0@=&\@=&5M<&QA=&4@<&%T:"X@*B\*("`@
M(&EF("@A96UP='DH)'1E;7!L871E7V]R:6<I("8F"B`@("`@("`@:7-?9&ER
M*"1T96UP;&%T95]P871H7V9U;&P@+B`G+R<@+B`D=&5M<&QA=&5?;W)I9RDI
M('L*("`@("`@("`D=&5M<&QA=&5?<&%T:"`N/2`G+R<@+B`D=&5M<&QA=&5?
M;W)I9SL*("`@("`@("`D=&5M<&QA=&5?<&%T:%]F=6QL("X]("<O)R`N("1T
M96UP;&%T95]O<FEG.PH@("`@?0H*("`@("1F;W)M+3YA9&1687)I86)L92AS
M<')I;G1F*%\H(D]R:6=I;F%L('1E;7!L871E<R!I;B`E<SHB*2P@)'1E;7!L
M871E7W!A=&@I+"`G;W)I9U]T96UP;&%T97-?:&5A9&5R)RP@)VAE861E<B<L
M(&9A;'-E+"!F86QS92D["@H@("`@+RH@061D('1H92!P871H('1O('1H92!H
M:61D96X@=F%R(&EN('1H92!F;W)M+B`J+PH@("`@)&9O<FTM/F%D9$AI9&1E
M;B@G)RP@)W1E;7!L871E7W!A=&@G+"`G=&5X="<L(&9A;'-E+"!F86QS92D[
M"B`@("`D=F%R<RT^<V5T*"=T96UP;&%T95]P871H)RP@)'1E;7!L871E7W!A
M=&@I.PH*("`@("\J($=E="!D:7)E8W1O<GD@;&ES="!F;W(@8VAO<V5N(&1I
M<F5C=&]R>2!I;B!T96UP;&%T97,N("HO"B`@("!I9B`H)'1E;7!L871E<U]D
M:7(@/2!O<&5N9&ER*"1T96UP;&%T95]P871H7V9U;&PI*2!["B`@("`@("`@
M=VAI;&4@*&9A;'-E("$]/2`H)&9I;&4@/2!R96%D9&ER*"1T96UP;&%T97-?
M9&ER*2DI('L*("`@("`@("`@("`@+RH@1&]N)W0@<VAO=R!C=7)R96YT(&1I
M<BP@:&ED9&5N(&9I;&5S(&%N9"!O;FQY('-H;W<@)RXN)PH@("`@("`@("`@
M("`@*B!I9B!N;W0@:6X@<F]O="!D:7(@;V8@86X@87!P)W,@=&5M<&QA=&5S
M+B`J+PH@("`@("`@("`@("!I9B`H)&9I;&4@(3T@(BXB("8F("$H)&9I;&4@
M/3T@)RXN)R`F)B!E;7!T>2@D=&5M<&QA=&5?<&%T:"DI("8F"B`@("`@("`@
M("`@("`@("`A*"1F:6QE("$]("<N+B<@)B8@<W5B<W1R*"1F:6QE+"`P+"`Q
M*2`]/2`G+B<I*2!["B`@("`@("`@("`@("`@("`D=&5M<&QA=&5S6UT@/2`D
M9FEL93L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!C;&]S961I
M<B@D=&5M<&QA=&5S7V1I<BD["B`@("`@("`@)'1E;7!L871E<R`](%]S9716
M86QU97-4;TME>7,H)'1E;7!L871E<RD["B`@("`@("`@)'8@/2`F)&9O<FTM
M/F%D9%9A<FEA8FQE*%\H(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E
M(BDL("=T96UP;&%T95]O<FEG)RP@)V5N=6TG+"!T<G5E+"!F86QS92P@;G5L
M;"P@87)R87DH)'1E;7!L871E<RDI.PH@("`@("`@("1V+3YS971!8W1I;VXH
M)&%C=&EO;BD["B`@("`@("`@)&9O<FTM/F%D9$AI9&1E;B@G)RP@)V]L9%]T
M96UP;&%T95]O<FEG)RP@)W1E>'0G+"!F86QS92P@9F%L<V4I.PH@("`@?0H*
M("`@("\J($]N;'D@<V5T('5P('1H97-E('9A<G,@:68@=&AE(&-H;W-E;B!T
M96UP;&%T92!I<R!A(&9I;&4N("HO"B`@("!I9B`H:7-?9FEL92@D=&5M<&QA
M=&5?<&%T:%]F=6QL("X@)R\G("X@)'1E;7!L871E7V]R:6<I*2!["B`@("`@
M("`@)&9O<FTM/F%D9%9A<FEA8FQE*%\H(D%L=&5R;F%T92!T96UP;&%T97,B
M*2P@)V%L=%]T96UP;&%T97-?:&5A9&5R)RP@)VAE861E<B<L(&9A;'-E+"!F
M86QS92D["@H@("`@("`@("\J($=E="!T:&4@86QR96%D>2!S879E9"!A;'1E
M<FYA=&4@=&5M<&QA=&5S+B`J+PH@("`@("`@("1V9G-?<&%T:"`](%1%35!,
M051%4U]61E-?4$%42"`N("<O)R`N("1A<'`@+B`D=&5M<&QA=&5?<&%T:"`N
M("<O)R`N("1T96UP;&%T95]O<FEG.PH@("`@("`@("1T96UP;&%T97-?86QT
M(#T@87)R87E?:V5Y<R@D=F9S+3YL:7-T1F]L9&5R*"1V9G-?<&%T:"P@;G5L
M;"P@9F%L<V4I*3L*("`@("`@("`D=&5M<&QA=&5S7V%L="`](&%R<F%Y*"<G
M(#T^("<G*2`K(%]S971686QU97-4;TME>7,H)'1E;7!L871E<U]A;'0I.PH@
M("`@("`@("1F;W)M+3YA9&1687)I86)L92A?*")$96QE=&4@97AI<W1I;F<@
M86QT97)N871E('1E;7!L871E(BDL("=D96QE=&5?=&5M<&QA=&5?86QT)RP@
M)V5N=6TG+"!F86QS92P@9F%L<V4L(&YU;&PL(&%R<F%Y*"1T96UP;&%T97-?
M86QT*2D["@H@("`@("`@("1F;W)M+3YA9&1687)I86)L92A?*"));G-E<G0@
M86QT97)N871E('1E;7!L871E(BDL("=T96UP;&%T95]A;'0G+"`G9FEL92<L
M(&9A;'-E+"!F86QS92D["B`@("!]"GT*"FEF("@D9F]R;6YA;64@)B8@(21H
M87-?8VAA;F=E9"D@>PH@("`@+RH@26YS97)T:6YG(&$@;F5W(&%L=&5R;F%T
M92!T96UP;&%T92X@*B\*("`@("1F;W)M+3YV86QI9&%T92@D=F%R<RD["@H@
M("`@:68@*"1F;W)M+3YI<U9A;&ED*"DI('L*("`@("`@("`D9F]R;2T^9V5T
M26YF;R@D=F%R<RP@)&EN9F\I.PH@("`@("`@(&EF("@A96UP='DH)&EN9F];
M)V1E;&5T95]T96UP;&%T95]A;'0G72DI('L*("`@("`@("`@("`@)'9F<RT^
M9&5L971E1FEL92@D=F9S7W!A=&@L("1I;F9O6R=D96QE=&5?=&5M<&QA=&5?
M86QT)UTI.PH@("`@("`@('T*("`@("`@("!I9B`H(65M<'1Y*"1I;F9O6R=T
M96UP;&%T95]A;'0G75LG<VEZ92==*2D@>PH@("`@("`@("`@("`D=F9S+3YW
M<FET92@D=F9S7W!A=&@L("1I;F9O6R=T96UP;&%T95]A;'0G75LG;F%M92==
M+"`D:6YF;ULG=&5M<&QA=&5?86QT)UU;)W1M<%]N86UE)UTL('1R=64I.PH@
M("`@("`@('T*("`@('T*?0H*)'1I=&QE(#T@7R@B5&5M<&QA=&4@061M:6YI
M<W1R871I;VXB*3L*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO
M;BUH96%D97(N:6YC)SL*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V%D
M;6EN+V-O;6UO;BUH96%D97(N:6YC)SL*)&YO=&EF:6-A=&EO;BT^;F]T:69Y
M*&%R<F%Y*"=L:7-T96YE<G,G(#T^("=S=&%T=7,G*2D["@HO*B!296YD97(@
M=&AE(&9O<FTN("HO"B1R96YD97)E<B`]("9N97<@2&]R9&5?1F]R;5]296YD
M97)E<B@I.PHD9F]R;2T^<F5N9&5R06-T:79E*"1R96YD97)E<BP@)'9A<G,L
M("=T96UP;&%T97,N<&AP)RP@)W!O<W0G*3L*"G)E<75I<F4@2$]21$5?5$5-
M4$Q!5$53("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]A9&UI;B]G<F]U<',N<&AP````````
M````````````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,C`Q-#(@
M,3`U,34T,S,W,S0@,#(P-C4W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+V%D
M;6EN+V=R;W5P<RYP:'`L=B`Q+C4P+C(N-B`R,#`V+S`W+S$S(#`Y.C`Q.C4S
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*
M0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N
M+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A<V4N<&AP
M)SL*<F5Q=6ER95]O;F-E("=(;W)D92]-96YU+G!H<"<["G)E<75I<F5?;VYC
M92`G2&]R9&4O1W)O=7`N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]4<F5E
M+G!H<"<["@II9B`H(4%U=&@Z.FES061M:6XH*2D@>PH@("`@2&]R9&4Z.F%U
M=&AE;G1I8V%T:6]N1F%I;'5R95)E9&ER96-T*"D["GT*"B1G<F]U<',@/2`F
M1W)O=7`Z.G-I;F=L971O;B@I.PHD875T:"`]("9!=71H.CIS:6YG;&5T;VXH
M)&-O;F9;)V%U=&@G75LG9')I=F5R)UTI.PH*)&9O<FT@/2!N=6QL.PHD<F5L
M;V%D(#T@9F%L<V4["B1A8W1I;VY)1"`](%5T:6PZ.F=E=$9O<FU$871A*"=A
M8W1I;VY)1"<I.PHD8VED(#T@571I;#HZ9V5T1F]R;41A=&$H)V-I9"<I.PH*
M<W=I=&-H("@D86-T:6]N240I('L*8V%S92`G861D8VAI;&0G.@H@("`@:68@
M*"1C:60@/3T@1$%40512145?4D]/5"D@>PH@("`@("`@("1F;W)M(#T@)V%D
M9&-H:6QD+FEN8R<["B`@("`@("`@)&=N86UE(#T@7R@B06QL($=R;W5P<R(I
M.PH@("`@?2!E;'-E('L*("`@("`@("`D9W)O=7`@/2`F)&=R;W5P<RT^9V5T
M1W)O=7!">4ED*"1C:60I.PH@("`@("`@(&EF("@A:7-?82@D9W)O=7`L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@)&=N86UE(#T@)&=R;W5P+3YG
M9713:&]R=$YA;64H*3L*("`@("`@("`@("`@)&9O<FT@/2`G861D8VAI;&0N
M:6YC)SL*("`@("`@("!]"B`@("!]"B`@("!B<F5A:SL*"F-A<V4@)V%D9&-H
M:6QD9F]R;2<Z"B`@("`D<&%R96YT(#T@)&-I9#L*("`@(&EF("@D<&%R96YT
M(#T]($1!5$%44D5%7U)/3U0I('L*("`@("`@("`D8VAI;&0@/2`F)&=R;W5P
M<RT^;F5W1W)O=7`H571I;#HZ9V5T1F]R;41A=&$H)V-H:6QD)RDI.PH@("`@
M("`@("1R97-U;'0@/2`D9W)O=7!S+3YA9&1'<F]U<"@D8VAI;&0I.PH@("`@
M?2!E;'-E('L*("`@("`@("`D8VAI;&0@/2`F)&=R;W5P<RT^;F5W1W)O=7`H
M571I;#HZ9V5T1F]R;41A=&$H)V-H:6QD)RDL("1P87)E;G0I.PH@("`@("`@
M("1R97-U;'0@/2`D9W)O=7!S+3YA9&1'<F]U<"@D8VAI;&0I.PH@("`@?0H@
M("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M($AO<F1E.CIL;V=-97-S86=E*"1R97-U;'0L(%]?1DE,15]?+"!?7TQ)3D5?
M7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H
M*'-P<FEN=&8H7R@B7"(E<UPB('=A<R!N;W0@8W)E871E9#H@)7,N(BDL("1C
M:&EL9"T^9V5T4VAO<G1.86UE*"DL("1R97-U;'0M/F=E=$UE<W-A9V4H*2DL
M("=H;W)D92YE<G)O<B<I.PH@("`@?2!E;'-E('L*("`@("`@("`D;F]T:69I
M8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B7"(E<UPB('=A<R!A9&1E9"!T;R!T
M:&4@9W)O=7!S('-Y<W1E;2XB*2P@)&-H:6QD+3YG9713:&]R=$YA;64H*2DL
M("=H;W)D92YS=6-C97-S)RD["B`@("`@("`@)&=R;W5P(#T@)&-H:6QD.PH@
M("`@("`@("1F;W)M(#T@)V5D:70N:6YC)SL*("`@("`@("`D<F5L;V%D(#T@
M=')U93L*("`@('T*("`@(&)R96%K.PH*8V%S92`G9&5L971E)SH*("`@("1G
M<F]U<"`]("8D9W)O=7!S+3YG971'<F]U<$)Y260H)&-I9"D["B`@("!I9B`H
M(6ES7V$H)&=R;W5P+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@)&9O<FT@
M/2`G9&5L971E+FEN8R<["B`@("!]"B`@("!B<F5A:SL*"F-A<V4@)V1E;&5T
M969O<FTG.@H@("`@:68@*%5T:6PZ.F=E=$9O<FU$871A*"=C;VYF:7)M)RD@
M/3T@7R@B1&5L971E(BDI('L*("`@("`@("`D9W)O=7`@/2`F)&=R;W5P<RT^
M9V5T1W)O=7!">4ED*"1C:60I.PH@("`@("`@(&EF("AI<U]A*"1G<F]U<"P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP
M=7-H*%\H(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P
M+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D<F5S=6QT(#T@)&=R;W5P<RT^<F5M;W9E1W)O=7`H)&=R;W5P+"!T
M<G5E*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS
M<')I;G1F*%\H(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB*2P@)&=R
M;W5P+3YG9713:&]R=$YA;64H*2P@)')E<W5L="T^9V5T365S<V%G92@I*2P@
M)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E-U8V-E
M<W-F=6QL>2!D96QE=&5D(%PB)7-<(BXB*2P@)&=R;W5P+3YG9713:&]R=$YA
M;64H*2DL("=H;W)D92YS=6-C97-S)RD["B`@("`@("`@("`@("`@("`D8VED
M(#T@;G5L;#L*("`@("`@("`@("`@("`@("1R96QO860@/2!T<G5E.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@?0H@("`@8G)E86L["@IC87-E("=E
M9&ET)SH*("`@("1G<F]U<"`]("8D9W)O=7!S+3YG971'<F]U<$)Y260H)&-I
M9"D["B`@("!I9B`H(6ES7V$H)&=R;W5P+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@)&9O<FT@/2`G961I="YI;F,G.PH@("`@?2!E;'-E:68@*"@D8V%T
M96=O<GD@/2!5=&EL.CIG971&;W)M1&%T82@G8V%T96=O<GDG*2D@(3T](&YU
M;&PI('L*("`@("`@("`D9W)O=7`@/2`F)&=R;W5P<RT^9V5T1W)O=7`H)&-A
M=&5G;W)Y*3L*("`@("`@("!I9B`H(6ES7V$H)&=R;W5P+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("1F;W)M(#T@)V5D:70N:6YC)SL*("`@("`@
M("!](&5L<V5I9B`H571I;#HZ9V5T1F]R;41A=&$H)V%U=&]C<F5A=&4G*2D@
M>PH@("`@("`@("`@("`D<&%R96YT(#T@571I;#HZ9V5T1F]R;41A=&$H)W!A
M<F5N="<I.PH@("`@("`@("`@("`D9W)O=7`@/2`F)&=R;W5P<RT^;F5W1W)O
M=7`H)&-A=&5G;W)Y*3L*("`@("`@("`@("`@)')E<W5L="`]("1G<F]U<',M
M/F%D9$=R;W5P*"1G<F]U<"P@)'!A<F5N="D["B`@("`@("`@("`@(&EF("@A
M:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@
M("`D9F]R;2`]("=E9&ET+FEN8R<["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("!]"B`@("!B<F5A:SL*"F-A<V4@)V5D:71F;W)M)SH*("`@("1G<F]U
M<"`]("8D9W)O=7!S+3YG971'<F]U<$)Y260H)&-I9"D["@H@("`@+R\@;6%K
M92!A(&-O<'D@;V8@=&AE(&=R;W5P('-O('=E(&-A;B!R97-T;W)E(&ET(&EF
M('1H97)E(&ES(&%N(&5R<F]R+@H@("`@)')E<W1O<F4@/2`D9W)O=7`["@H@
M("`@+R\@061D(&%N>2!N97<@=7-E<G,N"B`@("`D;F5W=7-E<B`](%5T:6PZ
M.F=E=$9O<FU$871A*"=N97=?=7-E<B<I.PH@("`@:68@*"%E;7!T>2@D;F5W
M=7-E<BDI('L*("`@("`@("!I9B`H:7-?87)R87DH)&YE=W5S97(I*2!["B`@
M("`@("`@("`@(&9O<F5A8V@@*"1N97=U<V5R(&%S("1N97<I('L*("`@("`@
M("`@("`@("`@("1G<F]U<"T^861D57-E<B@D;F5W+"!F86QS92D["B`@("`@
M("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9W)O=7`M
M/F%D9%5S97(H)&YE=W5S97(L(&9A;'-E*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+R\@4F5M;W9E(&%N>2!U<V5R<R!M87)K960@9F]R('!U<F=I;F<N"B`@
M("`D<F5M;W9E<R`](%5T:6PZ.F=E=$9O<FU$871A*"=R96UO=F4G*3L*("`@
M(&EF("@A96UP='DH)')E;6]V97,I("8F(&ES7V%R<F%Y*"1R96UO=F5S*2D@
M>PH@("`@("`@(&9O<F5A8V@@*"1R96UO=F5S(&%S("1U<V5R(#T^("1J=6YK
M*2!["B`@("`@("`@("`@("1G<F]U<"T^<F5M;W9E57-E<B@D=7-E<BP@9F%L
M<V4I.PH@("`@("`@('T*("`@('T*"B`@("`O+R!3970@=&AE(&5M86EL(&%D
M9')E<W,@;V8@=&AE(&=R;W5P+@H@("`@)&=R;W5P+3YS970H)V5M86EL)RP@
M571I;#HZ9V5T1F]R;41A=&$H)V5M86EL)RDI.PH*("`@("\O(%-A=F4@=&AE
M(&=R;W5P('1O('1H92!B86-K96YD+@H@("`@)')E<W5L="`]("1G<F]U<"T^
M<V%V92@I.PH*("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*"1R97-U;'0M/F=E=$UE
M<W-A9V4H*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@+R\@<F5S=&]R92!B
M86-K=7`@8V]P>0H@("`@("`@("1G<F]U<"`]("1R97-T;W)E.PH@("`@?2!E
M;'-E('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B
M57!D871E9"!<(B5S7"(N(BDL("1G<F]U<"T^9V5T4VAO<G1.86UE*"DI+"`G
M:&]R9&4N<W5C8V5S<R<I.PH@("`@?0H*("`@("1F;W)M(#T@)V5D:70N:6YC
M)SL*("`@("1R96QO860@/2!T<G5E.PH@("`@8G)E86L["GT*"G-W:71C:"`H
M)&9O<FTI('L*8V%S92`G861D8VAI;&0N:6YC)SH*("`@("1N;W1I9FEC871I
M;VXM/G!U<V@H)V1O8W5M96YT+F%D9%]C:&EL9"YC:&EL9"YF;V-U<R@I)RP@
M)VIA=F%S8W)I<'0G*3L*("`@(&)R96%K.PH*8V%S92`G961I="YI;F,G.@H@
M("`@+RH@4V5T('5P('1H92!L:7-T<RX@*B\*("`@("1U<V5R<R`]("1G<F]U
M<"T^;&ES=%5S97)S*"D["B`@("!I9B`H:7-?82@D=7-E<G,L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*"1U<V5R<RP@
M)VAO<F1E+F5R<F]R)RD["B`@("`@("`@)'5S97)S(#T@87)R87DH*3L*("`@
M('T*("`@("1A;&Q?=7-E<G,@/2`D9W)O=7`M/FQI<W1!;&Q5<V5R<R@I.PH@
M("`@:68@*&ES7V$H)&%L;%]U<V5R<RP@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("1N;W1I9FEC871I;VXM/G!U<V@H)&%L;%]U<V5R<RP@)VAO<F1E+F5R
M<F]R)RD["B`@("`@("`@)&%L;%]U<V5R<R`](&%R<F%Y*"D["B`@("!]"B`@
M("`D:6YH97)I=&5D7W5S97)S(#T@87)R87E?9&EF9B@D86QL7W5S97)S+"`D
M=7-E<G,I.PH*("`@(&EF("@D875T:"T^:&%S0V%P86)I;&ET>2@G;&ES="<I
M*2!["B`@("`@("`@)'5S97)?;&ES="`]("1A=71H+3YL:7-T57-E<G,H*3L*
M("`@("`@("!I9B`H:7-?82@D=7-E<E]L:7-T+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)'5S97)?;&ES="P@
M)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@("1U<V5R7VQI<W0@/2!A<G)A
M>2@I.PH@("`@("`@('T*("`@("`@("!S;W)T*"1U<V5R7VQI<W0I.PH@("`@
M?2!E;'-E('L*("`@("`@("`D=7-E<E]L:7-T(#T@87)R87DH*3L*("`@('T*
M("`@(&)R96%K.PH*?0H*)'1I=&QE(#T@7R@B1W)O=7`@061M:6YI<W1R871I
M;VXB*3L*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUH96%D
M97(N:6YC)SL*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V%D;6EN+V-O
M;6UO;BUH96%D97(N:6YC)SL*)&YO=&EF:6-A=&EO;BT^;F]T:69Y*&%R<F%Y
M*"=L:7-T96YE<G,G(#T^("=S=&%T=7,G*2D["FEF("@A96UP='DH)&9O<FTI
M*2!["B`@("!R97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O861M:6XO9W)O
M=7!S+R<@+B`D9F]R;3L*?0H*+RH@1V5T('1H92!P97)M<R!T<F5E+B`J+PHD
M;F]D97,@/2`D9W)O=7!S+3YL:7-T1W)O=7!S*'1R=64I.PHD;F]D97-;1$%4
M0512145?4D]/5%T@/2!$051!5%)%15]23T]4.PH*+RH@4V5T('5P('-O;64@
M;F]D92!P87)A;7,N("HO"B1S<&%C97(@/2`G)FYB<W`[)FYB<W`[)FYB<W`[
M)FYB<W`[)SL*)&EC;VYD:7(@/2!A<G)A>2@G:6-O;F1I<B<@/3X@)')E9VES
M=')Y+3YG971);6%G941I<B@I*3L*)&=R;W5P7VYO9&4@/2`D:6-O;F1I<B`K
M(&%R<F%Y*"=I8V]N)R`]/B`G9W)O=7`N<&YG)RD["B1A9&0@/2!(;W)D93HZ
M87!P;&EC871I;VY5<FPH)V%D;6EN+V=R;W5P<RYP:'`_86-T:6]N240]861D
M8VAI;&0G*3L*)&5D:70@/2!(;W)D93HZ87!P;&EC871I;VY5<FPH)V%D;6EN
M+V=R;W5P<RYP:'`_86-T:6]N240]961I="<I.PHD9&5L971E(#T@2&]R9&4Z
M.F%P<&QI8V%T:6]N57)L*"=A9&UI;B]G<F]U<',N<&AP/V%C=&EO;DE$/61E
M;&5T92<I.PHD961I=%]I;6<@/2!(;W)D93HZ:6UG*"=E9&ET+G!N9R<L(%\H
M(D5D:70@1W)O=7`B*2D["B1D96QE=&5?:6UG(#T@2&]R9&4Z.FEM9R@G9&5L
M971E+G!N9R<L(%\H(D1E;&5T92!'<F]U<"(I*3L*"B\J(%-E="!U<"!T:&4@
M=')E92X@*B\*)'1R964@/2!(;W)D95]4<F5E.CIF86-T;W)Y*"=A9&UI;E]G
M<F]U<',G+"`G:F%V87-C<FEP="<I.PHD=')E92T^<V5T3W!T:6]N*&%R<F%Y
M*"=A;'1E<FYA=&4G(#T^('1R=64L("=H:61E2&5A9&5R<R<@/3X@=')U92DI
M.PHD=')E92T^<V5T2&5A9&5R*&%R<F%Y*&%R<F%Y*"=W:61T:"<@/3X@)S4P
M)2<I*2D["@HO*B!%>'!L:6-I=&QY(&-H96-K(&9O<B`^(#`@<VEN8V4@=V4@
M8V%N(&)E(&-A;&QE9"!W:71H(&-U<G)E;G0@/2`M,0H@*B!F;W(@=&AE(')O
M;W0@;F]D92X@*B\*:68@*"1C:60@/B`P*2!["B`@("`D8VED7W!A<F5N=',@
M/2`D9W)O=7!S+3YG971'<F]U<%!A<F5N=$QI<W0H)&-I9"D["B`@("!I9B`H
M:7-?82@D8VED7W!A<F5N=',L("=014%27T52<F]R)RDI('L*("`@("`@("!(
M;W)D93HZ9F%T86PH)&-I9%]P87)E;G1S+"!?7T9)3$5?7RP@7U],24Y%7U\I
M.PH@("`@?0I]"@IF;W)E86-H("@D;F]D97,@87,@)&ED(#T^("1N;V1E*2![
M"B`@("`D;F]D95]P87)A;7,@/2`H)&-I9"`]/2`D:60I(#\@87)R87DH)V-L
M87-S)R`]/B`G<V5L96-T960G*2`Z(&%R<F%Y*"D["B`@("!I9B`H)&ED(#T]
M($1!5$%44D5%7U)/3U0I('L*("`@("`@("`D861D7VEM9R`]($AO<F1E.CII
M;6<H)V=R;W5P+G!N9R<L(%\H(D%D9"!.97<@1W)O=7`B*2D["B`@("`@("`@
M)&%D9%]L:6YK(#T@2&]R9&4Z.FQI;FLH571I;#HZ861D4&%R86UE=&5R*"1A
M9&0L("=C:60G+"`D:60I+"!?*")!9&0@3F5W($=R;W5P(BDI("X@)&%D9%]I
M;6<@+B`G/"]A/B<["@H@("`@("`@("1B87-E7VYO9&5?<&%R86US(#T@)&EC
M;VYD:7(@*R!A<G)A>2@G:6-O;B<@/3X@)V%D;6EN:7-T<F%T:6]N+G!N9R<I
M.PH@("`@("`@("1T<F5E+3YA9&1.;V1E*"1I9"P@;G5L;"P@7R@B06QL($=R
M;W5P<R(I+"`P+"!T<G5E+"`D8F%S95]N;V1E7W!A<F%M<R`K("1N;V1E7W!A
M<F%M<RP@87)R87DH)'-P86-E<BP@)&%D9%]L:6YK*2D["B`@("!](&5L<V4@
M>PH@("`@("`@("1N;V1E7W!A<F%M<ULG=7)L)UT@/2!5=&EL.CIA9&1087)A
M;65T97(H)&5D:70L("=C:60G+"`D:60I.PH@("`@("`@("1A9&1?:6UG(#T@
M2&]R9&4Z.FEM9R@G9W)O=7`N<&YG)RP@7R@B061D($-H:6QD($=R;W5P(BDI
M.PH@("`@("`@("1A9&1?;&EN:R`]($AO<F1E.CIL:6YK*%5T:6PZ.F%D9%!A
M<F%M971E<B@D861D+"`G8VED)RP@)&ED*2P@7R@B061D($-H:6QD($=R;W5P
M(BDI("X@)&%D9%]I;6<@+B`G/"]A/B<["B`@("`@("`@)&1E;&5T95]L:6YK
M(#T@2&]R9&4Z.FQI;FLH571I;#HZ861D4&%R86UE=&5R*"1D96QE=&4L("=C
M:60G+"`D:60I+"!?*")$96QE=&4@1W)O=7`B*2D@+B`D9&5L971E7VEM9R`N
M("<\+V$^)SL*"B`@("`@("`@)'!A<F5N=%]I9"`]("1G<F]U<',M/F=E=$=R
M;W5P4&%R96YT*"1I9"D["B`@("`@("`@)&=R;W5P7V5X=')A(#T@87)R87DH
M)'-P86-E<BP@)&%D9%]L:6YK+"`D9&5L971E7VQI;FLI.PH@("`@("`@("1T
M<F5E+3YA9&1.;V1E*"1I9"P@)'!A<F5N=%]I9"P@)&=R;W5P<RT^9V5T1W)O
M=7!3:&]R=$YA;64H)&YO9&4I+"`D9W)O=7!S+3YG971,979E;"@D:60I("L@
M,2P@*&ES<V5T*"1C:61?<&%R96YT<ULD:61=*2D@/R!T<G5E(#H@9F%L<V4L
M("1G<F]U<%]N;V1E("L@)&YO9&5?<&%R86US+"`D9W)O=7!?97AT<F$I.PH@
M("`@?0I]"@IE8VAO("<\:#$@8VQA<W,](FAE861E<B(^)R`N($AO<F1E.CII
M;6<H)V=R;W5P+G!N9R<I("X@)R`G("X@7R@B1W)O=7!S(BD@+B`G/"]H,3XG
M.PHD=')E92T^<F5N9&5R5')E92@I.PIR97%U:7)E($A/4D1%7U1%35!,051%
M4R`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]J<P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W
M,S0@,#$V,#<U`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VIS+W1A8FQE<RYJ<P``
M````````````````````````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`R,C8R-R`Q,#4Q-30S,S<S-"`P,3<W-S4`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+RHJ"B`J($IA=F%S8W)I<'0@8V]D
M92!F;W(@9FEN9&EN9R!A;&P@=&%B;&5S('=I=&@@8VQA<W-N86UE(")S=')I
M<&5D(B!A;F0*("H@9'EN86UI8V%L;'D@<W1R:7!I;F<@=&AE:7(@<F]W(&-O
M;&]R<RP@86YD(&9I;F1I;F<@86QL('1A8FQE<R!W:71H"B`J(&-L87-S;F%M
M92`B<V]R=&%B;&4B(&%N9"!M86MI;F<@=&AE;2!D>6YA;6EC86QL>2!S;W)T
M86)L92X*("H*("H@)$AO<F1E.B!H;W)D92]J<R]T86)L97,N:G,L=B`Q+C0N
M,BXS(#(P,#4O,3(O,#$@,C(Z-3@Z,C8@8VAU8VL@17AP("0*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J+PH*+RH@5V4@9&\@979E<GET:&EN9R!O;FQO860@<V\@=&AA="!T
M:&4@96YT:7)E(&1O8W5M96YT(&ES('!R97-E;G0*("H@8F5F;W)E('=E('-T
M87)T('-E87)C:&EN9R!I="!F;W(@=&%B;&5S+B`J+PII9B`H=VEN9&]W+F%D
M9$5V96YT3&ES=&5N97(I('L*("`@('=I;F1O=RYA9&1%=F5N=$QI<W1E;F5R
M*"=L;V%D)RP@=&%B;&5?:6YI="P@9F%L<V4I.PI](&5L<V4@:68@*'=I;F1O
M=RYA='1A8VA%=F5N="D@>PH@("`@=VEN9&]W+F%T=&%C:$5V96YT*"=O;FQO
M860G+"!T86)L95]I;FET*3L*?2!E;'-E(&EF("AW:6YD;W<N;VYL;V%D("$]
M(&YU;&PI('L*("`@('9A<B!O;&1?;VYL;V%D(#T@=VEN9&]W+F]N;&]A9#L*
M("`@('=I;F1O=RYO;FQO860@/2!F=6YC=&EO;BAE*0H@("`@>PH@("`@("`@
M(&]L9%]O;FQO860H92D["B`@("`@("`@=&%B;&5?:6YI="@I.PH@("`@?3L*
M?2!E;'-E('L*("`@('=I;F1O=RYO;FQO860@/2!T86)L95]I;FET.PI]"@IV
M87(@4T]25%]#3TQ534Y?24Y$15@["@IF=6YC=&EO;B!T86)L95]I;FET*"D*
M>PH@("`@:68@*"%D;V-U;65N="YG971%;&5M96YT<T)Y5&%G3F%M92D@>PH@
M("`@("`@(')E='5R;CL*("`@('T*("`@('1A8FQE<R`](&1O8W5M96YT+F=E
M=$5L96UE;G1S0GE486=.86UE*"=T86)L92<I.PH@("`@9F]R("AI(#T@,#L@
M:2`\('1A8FQE<RYL96YG=&@[(&DK*RD@>PH@("`@("`@(&EF("AH87-#;&%S
M<RAT86)L97-;:5TL("=S=')I<&5D)RDI('L*("`@("`@("`@("`@=&%B;&5?
M<W1R:7!E*'1A8FQE<UMI72D["B`@("`@("`@?0H@("`@("`@(&EF("AH87-#
M;&%S<RAT86)L97-;:5TL("=S;W)T86)L92<I("8F('1A8FQE<UMI72YI9"D@
M>PH@("`@("`@("`@("!T86)L95]M86ME4V]R=&%B;&4H=&%B;&5S6VE=*3L*
M("`@("`@("!]"B`@("!]"GT*"F9U;F-T:6]N('1A8FQE7W-T<FEP92AT86)L
M92D*>PH@("`@+R\@5&AE(&9L86<@=V4G;&P@=7-E('1O(&ME97`@=')A8VL@
M;V8@=VAE=&AE<B!T:&4@8W5R<F5N="!R;W<@:7,*("`@("\O(&]D9"!O<B!E
M=F5N+@H@("`@=F%R(&5V96X@/2!F86QS93L*"B`@("`O+R!486)L97,@8V%N
M(&AA=F4@;6]R92!T:&%N(&]N92!T8F]D>2!E;&5M96YT.R!G970@86QL(&-H
M:6QD"B`@("`O+R!T8F]D>2!T86=S(&%N9"!I;G1E<F%T92!T:')O=6=H('1H
M96TN"B`@("!V87(@=&)O9&EE<R`]('1A8FQE+F-H:6QD3F]D97,["B`@("!F
M;W(@*'9A<B!C(#T@,#L@8R`\('1B;V1I97,N;&5N9W1H.R!C*RLI('L*("`@
M("`@("!I9B`H=&)O9&EE<UMC72YT86=.86UE("$]("=40D]$62<I('L*("`@
M("`@("`@("`@8V]N=&EN=64["B`@("`@("`@?0H*("`@("`@("!V87(@=')S
M(#T@=&)O9&EE<UMC72YC:&EL9$YO9&5S.PH@("`@("`@(&9O<B`H=F%R(&D@
M/2`P.R!I(#P@=')S+FQE;F=T:#L@:2LK*2!["B`@("`@("`@("`@(&EF("AT
M<G-;:5TN=&%G3F%M92`]/2`G5%(G*2!["B`@("`@("`@("`@("`@("!R96UO
M=F5#;&%S<RAT<G-;:5TL("=R;W=%=F5N)RD["B`@("`@("`@("`@("`@("!R
M96UO=F5#;&%S<RAT<G-;:5TL("=R;W=/9&0G*3L*("`@("`@("`@("`@("`@
M(&%D9$-L87-S*'1R<UMI72P@979E;B`_("=R;W=%=F5N)R`Z("=R;W=/9&0G
M*3L*"B`@("`@("`@("`@("`@("`O+R!&;&EP(&9R;VT@;V1D('1O(&5V96XL
M(&]R('9I8V4M=F5R<V$N"B`@("`@("`@("`@("`@("!E=F5N(#T@(65V96X[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"GT*"F9U;F-T:6]N('1A
M8FQE7VUA:V53;W)T86)L92AT86)L92D*>PH@("`@:68@*'1A8FQE+G)O=W,@
M)B8@=&%B;&4N<F]W<RYL96YG=&@@/B`P*2!["B`@("`@("`@=F%R(&9I<G-T
M4F]W(#T@=&%B;&4N<F]W<ULP73L*("`@('T*("`@(&EF("@A9FER<W12;W<I
M('L*("`@("`@("!R971U<FX["B`@("!]"@H@("`@+R\@5V4@:&%V92!A(&9I
M<G-T(')O=SH@87-S=6UE(&ET)W,@=&AE(&AE861E<BP@86YD(&UA:V4@:71S
M"B`@("`O+R!C;VYT96YT<R!C;&EC:V%B;&4@;&EN:W,N"B`@("!F;W(@*'9A
M<B!I(#T@,#L@:2`\(&9I<G-T4F]W+F-E;&QS+FQE;F=T:#L@:2LK*2!["B`@
M("`@("`@=F%R(&-E;&P@/2!F:7)S=%)O=RYC96QL<UMI73L*("`@("`@("!I
M9B`H:&%S0VQA<W,H8V5L;"P@)VYO<V]R="<I*2!["B`@("`@("`@("`@(&-O
M;G1I;G5E.PH@("`@("`@('T*"B`@("`@("`@8V5L;"YC;VQU;6Y);F1E>"`]
M(&D["B`@("`@("`@8V5L;"YS='EL92YC=7)S;W(@/2`G<&]I;G1E<B<["B`@
M("`@("`@8V5L;"YO;F-L:6-K(#T@9G5N8W1I;VXH92D*("`@("`@("!["B`@
M("`@("`@("`@('9A<B!E(#T@92!\?"!W:6YD;W<N979E;G0["@H@("`@("`@
M("`@("!I9B`H92YT87)G970I('L*("`@("`@("`@("`@("`@(&EF("AE+G1A
M<F=E="YN;V1E5'EP92`]/2`S*2!["B`@("`@("`@("`@("`@("`@("`@92YT
M87)G970@/2!E+G1A<F=E="YP87)E;G1.;V1E.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!](&5L<V4@:68@*&4N<W)C16QE;65N="D@>PH@("`@
M("`@("`@("`@("`@92YT87)G970@/2!E+G-R8T5L96UE;G0["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@(&5L(#T@:&%S4&%R96YT*&4N=&%R9V5T+"`G
M02<L("=42"<I.PH@("`@("`@("`@("!I9B`H96P@)B8@(6AA<T-L87-S*&5L
M+"`G<V]R=&QI;FLG*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@('1A8FQE7W)E<V]R=%1A8FQE
M*&=E=%!A<F5N="AE+G1A<F=E="P@)U1()RDI.PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0I]"@IF=6YC=&EO;B!T86)L95]G
M971);FYE<E1E>'0H96PI"GL*("`@(&EF("AT>7!E;V8@96P@/3T@)W-T<FEN
M9R<I('L*("`@("`@("!R971U<FX@96P["B`@("!]"B`@("!I9B`H='EP96]F
M(&5L(#T]("=U;F1E9FEN960G*2!["B`@("`@("`@<F5T=7)N(&5L.PH@("`@
M?0H@("`@:68@*&5L+FEN;F5R5&5X="D@>PH@("`@("`@("\O($YO="!N965D
M960@8G5T(&ET(&ES(&9A<W1E<BX*("`@("`@("!R971U<FX@96PN:6YN97)4
M97AT.PH@("`@?0H*("`@('9A<B!S='(@/2`B(CL*("`@('9A<B!C<R`](&5L
M+F-H:6QD3F]D97,["B`@("!V87(@;"`](&-S+FQE;F=T:#L*("`@(&9O<B`H
M=F%R(&D@/2`P.R!I(#P@;#L@:2LK*2!["B`@("`@("`@<W=I=&-H("AC<UMI
M72YN;V1E5'EP92D@>PH@("`@("`@(&-A<V4@,3H*("`@("`@("`@("`@+R\@
M14Q%345.5%].3T1%"B`@("`@("`@("`@('-T<B`K/2!T86)L95]G971);FYE
M<E1E>'0H8W-;:5TI.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S
M92`S.@H@("`@("`@("`@("`O+R!415A47TY/1$4*("`@("`@("`@("`@<W1R
M("L](&-S6VE=+FYO9&5686QU93L*("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@?0H@("`@?0H*("`@(')E='5R;B!S='(["GT*"F9U;F-T:6]N('1A8FQE
M7W)E<V]R=%1A8FQE*'1H*0I["B`@("!T86)L92`](&=E=%!A<F5N="AT:"P@
M)U1!0DQ%)RD["B`@("!S;W)T0V]L=6UN(#T@=&@N8V]L=6UN26YD97@["B`@
M("!S;W)T1&]W;B`](#`["@H@("`@+R\@3&]O<"!T:')O=6=H(#QT:&5A9#X@
M=&\@9FEN9"!T:&4@8W5R<F5N="!S;W)T(&-O;'5M;B!A;F0*("`@("\O(&1I
M<F5C=&EO;BX*("`@('1H96%D<R`]('1A8FQE+G1(96%D+F=E=$5L96UE;G1S
M0GE486=.86UE*"=T:"<I.PH@("`@9F]R("AI(#T@,#L@:2`\('1H96%D<RYL
M96YG=&@[(&DK*RD@>PH@("`@("`@(&EF("AT:"`]/2!T:&5A9'-;:5TI('L*
M("`@("`@("`@("`@:68@*&AA<T-L87-S*'1H96%D<UMI72P@)W-O<G1U<"<I
M*2!["B`@("`@("`@("`@("`@("!R96UO=F5#;&%S<RAT:&5A9'-;:5TL("=S
M;W)T=7`G*3L*("`@("`@("`@("`@("`@(&%D9$-L87-S*'1H96%D<UMI72P@
M)W-O<G1D;W=N)RD["B`@("`@("`@("`@('T@96QS92!I9B`H:&%S0VQA<W,H
M=&AE861S6VE=+"`G<V]R=&1O=VXG*2D@>PH@("`@("`@("`@("`@("`@<F5M
M;W9E0VQA<W,H=&AE861S6VE=+"`G<V]R=&1O=VXG*3L*("`@("`@("`@("`@
M("`@(&%D9$-L87-S*'1H96%D<UMI72P@)W-O<G1U<"<I.PH@("`@("`@("`@
M("`@("`@<V]R=$1O=VX@/2`Q.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@861D0VQA<W,H=&AE861S6VE=+"`G<V]R=&1O=VXG*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M;6]V94-L87-S*'1H96%D<UMI72P@)W-O<G1U<"<I.PH@("`@("`@("`@("!R
M96UO=F5#;&%S<RAT:&5A9'-;:5TL("=S;W)T9&]W;B<I.PH@("`@("`@('T*
M("`@('T*"B`@("`O+R!7;W)K(&]U="!A('1Y<&4@9F]R('1H92!C;VQU;6X*
M("`@(&EF("AT86)L92YR;W=S+FQE;F=T:"`\/2`Q*2!["B`@("`@("`@<F5T
M=7)N.PH@("`@?0H*("`@('9A<B!I=&T@/2!T86)L95]G971);FYE<E1E>'0H
M=&%B;&4N<F]W<ULQ72YC96QL<UMS;W)T0V]L=6UN72D["B`@("!S;W)T9FX@
M/2!T86)L95]S;W)T7V-A<V5I;G-E;G-I=&EV93L*("`@(&EF("AI=&TN;6%T
M8V@H+UY<9%QD6UPO+5U<9%QD6UPO+5U<9%QD7&1<9"0O*2D@>PH@("`@("`@
M('-O<G1F;B`]('1A8FQE7W-O<G1?9&%T93L*("`@('T*("`@(&EF("AI=&TN
M;6%T8V@H+UY<9%QD6UPO+5U<9%QD6UPO+5U<9%QD)"\I*2!["B`@("`@("`@
M<V]R=&9N(#T@=&%B;&5?<V]R=%]D871E.PH@("`@?0H@("`@:68@*&ET;2YM
M871C:"@O7ENC)%TO*2D@>PH@("`@("`@('-O<G1F;B`]('1A8FQE7W-O<G1?
M8W5R<F5N8WD["B`@("!]"B`@("!I9B`H:71M+FUA=&-H*"]>6UQD7"Y=*R0O
M*2D@>PH@("`@("`@('-O<G1F;B`]('1A8FQE7W-O<G1?;G5M97)I8SL*("`@
M('T*"B`@("!33U)47T-/3%5-3E])3D1%6"`]('-O<G1#;VQU;6X["@H@("`@
M+R\@1&]N)W0@;6EX('5P('-E<&5R871E('1B;V1I97,[('-O<G0@96%C:"!I
M;B!T=7)N+@H@("`@9F]R("AI(#T@,#L@:2`\('1A8FQE+G1";V1I97,N;&5N
M9W1H.R!I*RLI('L*("`@("`@("!T<G,@/2!T86)L92YT0F]D:65S6VE=+F=E
M=$5L96UE;G1S0GE486=.86UE*"=T<B<I.PH@("`@("`@(&YE=U)O=W,@/2!N
M97<@07)R87DH*3L*("`@("`@("!F;W(@*&H@/2`P.R!J(#P@=')S+FQE;F=T
M:#L@:BLK*2!["B`@("`@("`@("`@(&YE=U)O=W-;:ET@/2!T<G-;:ET["B`@
M("`@("`@?0H*("`@("`@("!N97=2;W=S+G-O<G0H<V]R=&9N*3L*("`@("`@
M("!I9B`H<V]R=$1O=VXI('L*("`@("`@("`@("`@;F5W4F]W<RYR979E<G-E
M*"D["B`@("`@("`@?0H*("`@("`@("`O+R!792!A<'!E;F1#:&EL9"!R;W=S
M('1H870@86QR96%D>2!E>&ES="!T;R!T:&4@=&)O9'DL('-O(&ET"B`@("`@
M("`@+R\@;6]V97,@=&AE;2!R871H97(@=&AA;B!C<F5A=&EN9R!N97<@;VYE
M<RX@1&]N)W0@9&\*("`@("`@("`O+R!S;W)T8F]T=&]M(')O=W,N"B`@("`@
M("`@9F]R("AJ(#T@,#L@:B`\(&YE=U)O=W,N;&5N9W1H.R!J*RLI('L*("`@
M("`@("`@("`@:68@*"%H87-#;&%S<RAN97=2;W=S6VI=+"`G<V]R=&)O='1O
M;2<I*2!["B`@("`@("`@("`@("`@("!T86)L92YT0F]D:65S6VE=+F%P<&5N
M9$-H:6QD*&YE=U)O=W-;:ETI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("`O+R!$;R!S;W)T8F]T=&]M(')O=W,@;VYL>2X*("`@("`@("!F
M;W(@*&H@/2`P.R!J(#P@;F5W4F]W<RYL96YG=&@[(&HK*RD@>PH@("`@("`@
M("`@("!I9B`H:&%S0VQA<W,H;F5W4F]W<UMJ72P@)W-O<G1B;W1T;VTG*2D@
M>PH@("`@("`@("`@("`@("`@=&%B;&4N=$)O9&EE<UMI72YA<'!E;F1#:&EL
M9"AN97=2;W=S6VI=*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*
M"B`@("`O+R!)9B!W92!J=7-T(')E<V]R=&5D(&$@<W1R:7!E9"!T86)L92P@
M<F4M<W1R:7!E(&ET+@H@("`@:68@*&AA<T-L87-S*'1A8FQE+"`G<W1R:7!E
M9"<I*2!["B`@("`@("`@=&%B;&5?<W1R:7!E*'1A8FQE*3L*("`@('T*"B`@
M("`O+R!&:6YA;&QY+"!S964@:68@=V4@:&%V92!A(&-A;&QB86-K(&9U;F-T
M:6]N('1O('1R:6=G97(N"B`@("!I9B`H='EP96]F*'1A8FQE7W-O<G1#86QL
M8F%C:RD@/3T@)V9U;F-T:6]N)RD@>PH@("`@("`@('1A8FQE7W-O<G1#86QL
M8F%C:RAT86)L92YI9"P@=&@N:60L('-O<G1$;W=N*3L*("`@('T*?0H*9G5N
M8W1I;VX@9V5T4&%R96YT*&5L+"!P5&%G3F%M92D*>PH@("`@:68@*&5L(#T]
M(&YU;&PI('L*("`@("`@("!R971U<FX@;G5L;#L*("`@('T@96QS92!I9B`H
M<%1A9TYA;64@/3T@;G5L;"D@>PH@("`@("`@(')E='5R;B!E;"YP87)E;G1.
M;V1E.PH@("`@?2!E;'-E(&EF("AE;"YN;V1E5'EP92`]/2`Q("8F(&5L+G1A
M9TYA;64N=&],;W=E<D-A<V4H*2`]/2!P5&%G3F%M92YT;TQO=V5R0V%S92@I
M*2!["B`@("`@("`@+R\@1V5C:V\@8G5G+"!S=7!P;W-E9"!T;R!B92!U<'!E
M<F-A<V4N"B`@("`@("`@<F5T=7)N(&5L.PH@("`@?2!E;'-E('L*("`@("`@
M("!R971U<FX@9V5T4&%R96YT*&5L+G!A<F5N=$YO9&4L('!486=.86UE*3L*
M("`@('T*?0H*9G5N8W1I;VX@=&%B;&5?<V]R=%]D871E*&$L(&(I"GL*("`@
M("\O(%1W;R!D:6=I="!Y96%R<R!L97-S('1H86X@-3`@87)E('1R96%T960@
M87,@,C!86"P@9W)E871E<B!T:&%N"B`@("`O+R`U,"!A<F4@=')E871E9"!A
M<R`Q.5A8+@H@("`@86$@/2!T86)L95]G971);FYE<E1E>'0H82YC96QL<UM3
M3U)47T-/3%5-3E])3D1%6%TI.PH@("`@8F(@/2!T86)L95]G971);FYE<E1E
M>'0H8BYC96QL<UM33U)47T-/3%5-3E])3D1%6%TI.PH@("`@:68@*&%A+FQE
M;F=T:"`]/2`Q,"D@>PH@("`@("`@(&1T,2`](&%A+G-U8G-T<B@V+"`T*2`K
M(&%A+G-U8G-T<B@S+"`R*2`K(&%A+G-U8G-T<B@P+"`R*3L*("`@('T@96QS
M92!["B`@("`@("`@>7(@/2!A82YS=6)S='(H-BP@,BD["B`@("`@("`@:68@
M*'!A<G-E26YT*'ER*2`\(#4P*2!["B`@("`@("`@("`@('ER(#T@)S(P)R`K
M('ER.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@('ER(#T@)S$Y)R`K
M('ER.PH@("`@("`@('T*("`@("`@("!D=#$@/2!Y<BMA82YS=6)S='(H,RP@
M,BD@*R!A82YS=6)S='(H,"P@,BD["B`@("!]"B`@("!I9B`H8F(N;&5N9W1H
M(#T](#$P*2!["B`@("`@("`@9'0R(#T@8F(N<W5B<W1R*#8L(#0I("L@8F(N
M<W5B<W1R*#,L(#(I("L@8F(N<W5B<W1R*#`L(#(I.PH@("`@?2!E;'-E('L*
M("`@("`@("!Y<B`](&)B+G-U8G-T<B@V+"`R*3L*("`@("`@("!I9B`H<&%R
M<V5);G0H>7(I(#P@-3`I('L*("`@("`@("`@("`@>7(@/2`G,C`G("L@>7([
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@>7(@/2`G,3DG("L@>7([
M"B`@("`@("`@?0H@("`@("`@(&1T,B`]('ER("L@8F(N<W5B<W1R*#,L(#(I
M("L@8F(N<W5B<W1R*#`L(#(I.PH@("`@?0H@("`@:68@*&1T,2`]/2!D=#(I
M('L*("`@("`@("!R971U<FX@,#L*("`@('T@96QS92!I9B`H9'0Q(#P@9'0R
M*2!["B`@("`@("`@<F5T=7)N("TQ.PH@("`@?0H@("`@<F5T=7)N(#$["GT*
M"F9U;F-T:6]N('1A8FQE7W-O<G1?8W5R<F5N8WDH82P@8BD*>PH@("`@86$@
M/2!T86)L95]G971);FYE<E1E>'0H82YC96QL<UM33U)47T-/3%5-3E])3D1%
M6%TI+G)E<&QA8V4H+UM>,"TY+ETO9RP@)R<I.PH@("`@8F(@/2!T86)L95]G
M971);FYE<E1E>'0H8BYC96QL<UM33U)47T-/3%5-3E])3D1%6%TI+G)E<&QA
M8V4H+UM>,"TY+ETO9RP@)R<I.PH@("`@<F5T=7)N('!A<G-E1FQO870H86$I
M("T@<&%R<V5&;&]A="AB8BD["GT*"F9U;F-T:6]N('1A8FQE7W-O<G1?;G5M
M97)I8RAA+"!B*0I["B`@("!A82`]('!A<G-E1FQO870H=&%B;&5?9V5T26YN
M97)497AT*&$N8V5L;'-;4T]25%]#3TQ534Y?24Y$15A=*2D["B`@("!I9B`H
M:7-.84XH86$I*2!["B`@("`@("`@86$@/2`P.PH@("`@?0H@("`@8F(@/2!P
M87)S949L;V%T*'1A8FQE7V=E=$EN;F5R5&5X="AB+F-E;&QS6U-/4E1?0T],
M54U.7TE.1$5872DI.PH@("`@:68@*&ES3F%.*&)B*2D@>PH@("`@("`@(&)B
M(#T@,#L*("`@('T*("`@(')E='5R;B!A82`M(&)B.PI]"@IF=6YC=&EO;B!T
M86)L95]S;W)T7V-A<V5I;G-E;G-I=&EV92AA+"!B*0I["B`@("!A82`]('1A
M8FQE7V=E=$EN;F5R5&5X="AA+F-E;&QS6U-/4E1?0T],54U.7TE.1$5872DN
M=&],;W=E<D-A<V4H*3L*("`@(&)B(#T@=&%B;&5?9V5T26YN97)497AT*&(N
M8V5L;'-;4T]25%]#3TQ534Y?24Y$15A=*2YT;TQO=V5R0V%S92@I.PH@("`@
M:68@*&%A(#T](&)B*2!["B`@("`@("`@<F5T=7)N(#`["B`@("!](&5L<V4@
M:68@*&%A(#P@8F(I('L*("`@("`@("!R971U<FX@+3$["B`@("!]"B`@("!R
M971U<FX@,3L*?0H*9G5N8W1I;VX@=&%B;&5?<V]R=%]D969A=6QT*&$L8BD*
M>PH@("`@86$@/2!T86)L95]G971);FYE<E1E>'0H82YC96QL<UM33U)47T-/
M3%5-3E])3D1%6%TI.PH@("`@8F(@/2!T86)L95]G971);FYE<E1E>'0H8BYC
M96QL<UM33U)47T-/3%5-3E])3D1%6%TI.PH@("`@:68@*&%A(#T](&)B*2![
M"B`@("`@("`@<F5T=7)N(#`["B`@("!](&5L<V4@:68@*&%A(#P@8F(I('L*
M("`@("`@("!R971U<FX@+3$["B`@("!]"B`@("!R971U<FX@,3L*?0H*+RHJ
M"B`J($1/32!U=&EL:71Y(&9U;F-T:6]N<RX*("HO"F9U;F-T:6]N(&AA<U!A
M<F5N="AE;"P@=&%G3F%M92P@=&%G4W1O<"D*>PH@("`@:68@*&5L+G1A9TYA
M;64@/3T@=&%G3F%M92D@>PH@("`@("`@(')E='5R;B!E;#L*("`@('T@96QS
M92!I9B`H=&%G4W1O<"`A/2!N=6QL("8F(&5L+G1A9TYA;64@/3T@=&%G4W1O
M<"D@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T@96QS92!["B`@("`@
M("`@<F5T=7)N(&AA<U!A<F5N="AG971087)E;G0H96PI+"!T86=.86UE+"!T
M86=3=&]P*3L*("`@('T*?0H*9G5N8W1I;VX@861D0VQA<W,H96PL(&-L87-S
M3F%M92D*>PH@("`@96PN8VQA<W-.86UE("L](&5L+F-L87-S3F%M92`_("<@
M)R`K(&-L87-S3F%M92`Z(&-L87-S3F%M93L*?0H*9G5N8W1I;VX@<F5M;W9E
M0VQA<W,H96PL(&-L87-S3F%M92D*>PH@("`@96PN8VQA<W-.86UE(#T@96PN
M8VQA<W-.86UE+G)E<&QA8V4H;F5W(%)E9T5X<"@G(#\G("L@8VQA<W-.86UE
M("L@)R`_)RDL("<G*3L*?0H*9G5N8W1I;VX@:&%S0VQA<W,H96PL(&-L87-S
M3F%M92D*>PH@("`@<F5T=7)N("AE;"YC;&%S<TYA;64N:6YD97A/9BAC;&%S
M<TYA;64I("$]("TQ*3L*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]J<R]S=')I<&4N:G,`````````````````````````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#0Q,#$@,3`U,34T,S,W,S0@
M,#(P,#$T`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"\J*@H@*B!*879A<V-R:7!T(&-O9&4@9F]R(&9I;F1I;F<@86QL('1A
M8FQE<R!W:71H(&-L87-S;F%M92`B<W1R:7!E9"(@86YD"B`J(&1Y;F%M:6-A
M;&QY('-T<FEP:6YG('1H96ER(')O=R!C;VQO<G,N"B`J"B`J("1(;W)D93H@
M:&]R9&4O:G,O<W1R:7!E+FIS+'8@,2XS+C(N,B`R,#`U+S$P+S$X(#$Q.C,S
M.C,X(&IA;B!%>'`@)`H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D
M:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@HO*B!792!D;R!E=F5R
M>71H:6YG(&]N;&]A9"!S;R!T:&%T('1H92!E;G1I<F4@9&]C=6UE;G0@:7,@
M<')E<V5N=`H@*B!B969O<F4@=V4@<W1A<G0@<V5A<F-H:6YG(&ET(&9O<B!T
M86)L97,N("HO"FEF("AW:6YD;W<N861D179E;G1,:7-T96YE<BD@>PH@("`@
M=VEN9&]W+F%D9$5V96YT3&ES=&5N97(H)VQO860G+"!F:6YD4W1R:7!E9%1A
M8FQE<RP@9F%L<V4I.PI](&5L<V4@:68@*'=I;F1O=RYA='1A8VA%=F5N="D@
M>PH@("`@=VEN9&]W+F%T=&%C:$5V96YT*"=O;FQO860G+"!F:6YD4W1R:7!E
M9%1A8FQE<RD["GT@96QS92!I9B`H=VEN9&]W+F]N;&]A9"`A/2!N=6QL*2![
M"B`@("!V87(@;VQD3VY,;V%D(#T@=VEN9&]W+F]N;&]A9#L*("`@('=I;F1O
M=RYO;FQO860@/2!F=6YC=&EO;BAE*0H@("`@>PH@("`@("`@(&]L9$]N3&]A
M9"AE*3L*("`@("`@("!F:6YD4W1R:7!E9%1A8FQE<R@I.PH@("`@?3L*?2!E
M;'-E('L*("`@('=I;F1O=RYO;FQO860@/2!F:6YD4W1R:7!E9%1A8FQE<SL*
M?0H*9G5N8W1I;VX@9FEN9%-T<FEP961486)L97,H*0I["B`@("!I9B`H(61O
M8W5M96YT+F=E=$5L96UE;G1S0GE486=.86UE*2!["B`@("`@("`@<F5T=7)N
M.PH@("`@?0H@("`@=&%B;&5S(#T@9&]C=6UE;G0N9V5T16QE;65N='-">51A
M9TYA;64H)W1A8FQE)RD["B`@("!F;W(@*&D@/2`P.R!I(#P@=&%B;&5S+FQE
M;F=T:#L@:2LK*2!["B`@("`@("`@:68@*'1A8FQE<UMI72YC;&%S<TYA;64N
M:6YD97A/9B@G<W1R:7!E9"<I("$]("TQ*2!["B`@("`@("`@("`@('-T<FEP
M92AT86)L97-;:5TI.PH@("`@("`@('T*("`@('T*?0H*9G5N8W1I;VX@<W1R
M:7!E*'1A8FQE*0I["B`@("`O+R!4:&4@9FQA9R!W92=L;"!U<V4@=&\@:V5E
M<"!T<F%C:R!O9B!W:&5T:&5R('1H92!C=7)R96YT(')O=R!I<PH@("`@+R\@
M;V1D(&]R(&5V96XN"B`@("!V87(@979E;B`](&9A;'-E.PH*("`@("\O(%1A
M8FQE<R!C86X@:&%V92!M;W)E('1H86X@;VYE('1B;V1Y(&5L96UE;G0[(&=E
M="!A;&P@8VAI;&0*("`@("\O('1B;V1Y('1A9W,@86YD(&EN=&5R871E('1H
M<F]U9V@@=&AE;2X*("`@('9A<B!T8F]D:65S(#T@=&%B;&4N8VAI;&1.;V1E
M<SL*("`@(&9O<B`H=F%R(&,@/2`P.R!C(#P@=&)O9&EE<RYL96YG=&@[(&,K
M*RD@>PH@("`@("`@(&EF("AT8F]D:65S6V-=+G1A9TYA;64@/3T@)U1"3T19
M)RD@>PH@("`@("`@("`@("!V87(@=')S(#T@=&)O9&EE<UMC72YC:&EL9$YO
M9&5S.PH@("`@("`@("`@("!F;W(@*'9A<B!I(#T@,#L@:2`\('1R<RYL96YG
M=&@[(&DK*RD@>PH@("`@("`@("`@("`@("`@:68@*'1R<UMI72YT86=.86UE
M(#T]("=44B<I('L*("`@("`@("`@("`@("`@("`@("!T<G-;:5TN8VQA<W-.
M86UE(#T@=')S6VE=+F-L87-S3F%M92YR97!L86-E*"\@/W)O=T5V96X@/R\L
M("<G*2YR97!L86-E*"\@/W)O=T]D9"`_+RP@)R<I.PH@("`@("`@("`@("`@
M("`@("`@(&EF("AT<G-;:5TN8VQA<W-.86UE*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@('1R<UMI72YC;&%S<TYA;64@*ST@)R`G.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!T<G-;:5TN8VQA<W-.
M86UE("L](&5V96X@/R`G<F]W179E;B<@.B`G<F]W3V1D)SL*"B`@("`@("`@
M("`@("`@("`@("`@+R\@1FQI<"!F<F]M(&]D9"!T;R!E=F5N+"!O<B!V:6-E
M+79E<G-A+@H@("`@("`@("`@("`@("`@("`@(&5V96X@/2`A979E;CL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]J<R]H;W)D92YI92YJ<P``````````
M````````````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$R,3`@
M,3`U,34T,S,W,S0@,#(P,C`Q`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"\J*@H@*B!'96YE<F%L($AO<F1E(%5)(&5F9F5C
M=',@:F%V87-C<FEP="`M(&9I>&5S(&9O<B!)12!T:&%T(&-A;B=T"B`J(&5A
M<VEL>2!B92!D;VYE('=I=&AO=70@8G)O=W-E<B!D971E8W1I;VXN"B`J"B`J
M("1(;W)D93H@:&]R9&4O:G,O:&]R9&4N:64N:G,L=B`Q+C$N,BXR(#(P,#8O
M,#$O,CD@,3`Z,3@Z,C`@8VAU8VL@17AP("0*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*
M5&]O;%1I<'-?3W!T:6]N7U=I;F1O=V5D7T-O;G1R;VQS(#T@,3L*"FEF("AT
M>7!E;V8@07)R87DN<')O=&]T>7!E+G!U<V@@/3T@)W5N9&5F:6YE9"<I('L*
M("`@("!!<G)A>2YP<F]T;W1Y<&4N<'5S:"`](&9U;F-T:6]N*"D@>PH@("`@
M("`@("!V87(@;"`]('1H:7,N;&5N9W1H.PH@("`@("`@("!F;W(@*'9A<B!I
M(#T@,#L@:2`\(&%R9W5M96YT<RYL96YG=&@[(&DK*RD@>PH@("`@("`@("`@
M("`@=&AI<UML("L@:5T@/2!A<F=U;65N='-;:5T["B`@("`@("`@('T*("`@
M("`@("`@<F5T=7)N('1H:7,N;&5N9W1H"B`@("`@?0I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]J<R]S;W)T97(N:G,`````
M````````````````````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#8U,S8@,3`U,34T,S,W,S0@,#(P,#0R`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"\J*@H@*B!(;W)D92!&;W)M(%-O<G1E
M<B!&:65L9"!*879A<V-R:7!T($-L87-S"B`J"B`J(%!R;W9I9&5S('1H92!J
M879A<V-R:7!T(&-L87-S('1O(&%C8V]M<&%N>2!T:&4@2&]R9&5?1F]R;2!S
M;W)T97(*("H@9FEE;&0N"B`J"B`J("1(;W)D93H@:&]R9&4O:G,O<V]R=&5R
M+FIS+'8@,2XR+C$P+C,@,C`P-B\P,2\P,2`R,3HR.3HP,B!J86X@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-87)K;R!$:G5K:6,@/&UA<FMO
M0&]B;&\N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*9G5N8W1I;VX@2&]R9&5?
M1F]R;5]3;W)T97(H:6YS=&%N8V5.86UE+"!V87).86UE+"!H96%D97(I"GL*
M("`@("\J(%-E="!U<"!T:&ES(&-L87-S(&EN<W1A;F-E(&9O<B!F=6YC=&EO
M;B!C86QL<R!F<F]M('1H92!P86=E+B`J+PH@("`@=&AI<RY?:6YS=&%N8V5.
M86UE(#T@:6YS=&%N8V5.86UE.PH*("`@('1H:7,N7W9A<DYA;64@/2!V87).
M86UE.PH*("`@("\J(%-O<G1E<B!V87)I86)L97,N("HO"B`@("!T:&ES+E]H
M96%D97(@/2`G)SL*("`@('1H:7,N;6EN3&5N9W1H(#T@,#L*("`@(&EF("AH
M96%D97(@(3T@)R<I('L*("`@("`@("!T:&ES+E]H96%D97(@/2!H96%D97([
M"B`@("`@("`@=&AI<RYM:6Y,96YG=&@@/2`Q.PH@("`@?0H@("`@=&AI<RYS
M;W)T97),:7-T(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H=&AI<RY?=F%R
M3F%M92`K("=;;&ES=%TG*3L*("`@('1H:7,N<V]R=&5R07)R87D@/2!D;V-U
M;65N="YG971%;&5M96YT0GE)9"AT:&ES+E]V87).86UE("L@)UMA<G)A>5TG
M*3L*"B`@("!T:&ES+F1E<V5L96-T2&5A9&5R(#T@9G5N8W1I;VXH*0H@("`@
M>PH@("`@("`@(&EF("AT:&ES+E]H96%D97(@(3T@)R<I('L*("`@("`@("`@
M("`@=&AI<RYS;W)T97),:7-T6S!=+G-E;&5C=&5D(#T@9F%L<V4["B`@("`@
M("`@?0H@("`@?0H*("`@('1H:7,N<V5T2&ED9&5N(#T@9G5N8W1I;VXH*0H@
M("`@>PH@("`@("`@('9A<B!T;7!!<G)A>2`](&YE=R!!<G)A>2@I.PH*("`@
M("`@("!F;W(@*'9A<B!I(#T@=&AI<RYM:6Y,96YG=&@[(&D@/"!T:&ES+G-O
M<G1E<DQI<W0N;&5N9W1H.R!I*RLI('L*("`@("`@("`@("`@:68@*'1H:7,N
M<V]R=&5R3&ES=%MI72YV86QU92D@>PH@("`@("`@("`@("`@("`@=&UP07)R
M87E;:2`M('1H:7,N;6EN3&5N9W1H72`]('1H:7,N<V]R=&5R3&ES=%MI72YV
M86QU93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@=&AI<RYS
M;W)T97)!<G)A>2YV86QU92`]('1M<$%R<F%Y+FIO:6XH(EQT(BD["B`@("!]
M"@H@("`@=&AI<RYM;W9E0V]L=6UN57`@/2!F=6YC=&EO;B@I"B`@("!["B`@
M("`@("`@=F%R('-E;"`]('1H:7,N<V]R=&5R3&ES="YS96QE8W1E9$EN9&5X
M.PH*("`@("`@("!I9B`H<V5L(#P]('1H:7,N;6EN3&5N9W1H('Q\('1H:7,N
M<V]R=&5R3&ES="YL96YG=&@@/#T@=&AI<RYM:6Y,96YG=&@@*R`Q*2!R971U
M<FX["@H@("`@("`@("\J($1E<V5L96-T(&5V97)Y=&AI;F<@8G5T('1H92!F
M:7)S="!S96QE8W1E9"!I=&5M+B`J+PH@("`@("`@('1H:7,N<V]R=&5R3&ES
M="YS96QE8W1E9$EN9&5X(#T@<V5L.PH@("`@("`@('9A<B!U<"`]('1H:7,N
M<V]R=&5R3&ES=%MS96Q=+G9A;'5E.PH*("`@("`@("!T;7`@/2!N97<@07)R
M87DH*3L*("`@("`@("!F;W(@*&D@/2!T:&ES+FUI;DQE;F=T:#L@:2`\('1H
M:7,N<V]R=&5R3&ES="YL96YG=&@[(&DK*RD@>PH@("`@("`@("`@("!T;7!;
M:2`M('1H:7,N;6EN3&5N9W1H72`](&YE=R!/<'1I;VXH=&AI<RYS;W)T97),
M:7-T6VE=+G1E>'0L('1H:7,N<V]R=&5R3&ES=%MI72YV86QU92D*("`@("`@
M("!]"@H@("`@("`@(&9O<B`H:2`](#`[(&D@/"!T;7`N;&5N9W1H.R!I*RLI
M('L*("`@("`@("`@("`@:68@*&D@*R!T:&ES+FUI;DQE;F=T:"`]/2!S96P@
M+2`Q*2!["B`@("`@("`@("`@("`@("!T:&ES+G-O<G1E<DQI<W1;:2`K('1H
M:7,N;6EN3&5N9W1H72`]('1M<%MI("L@,5T["B`@("`@("`@("`@('T@96QS
M92!I9B`H:2`K('1H:7,N;6EN3&5N9W1H(#T]('-E;"D@>PH@("`@("`@("`@
M("`@("`@=&AI<RYS;W)T97),:7-T6VD@*R!T:&ES+FUI;DQE;F=T:%T@/2!T
M;7!;:2`M(#%=.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@=&AI<RYS;W)T97),:7-T6VD@*R!T:&ES+FUI;DQE;F=T:%T@/2!T;7!;
M:5T["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@('1H:7,N<V]R
M=&5R3&ES="YS96QE8W1E9$EN9&5X(#T@<V5L("T@,3L*"B`@("`@("`@=&AI
M<RYS971(:61D96XH*3L*("`@('T*"B`@("!T:&ES+FUO=F5#;VQU;6Y$;W=N
M(#T@9G5N8W1I;VXH*0H@("`@>PH@("`@("`@('9A<B!S96P@/2!T:&ES+G-O
M<G1E<DQI<W0N<V5L96-T961);F1E>#L*"B`@("`@("`@:68@*'-E;"`]/2`M
M,2!\?"!S96P@/3T@=&AI<RYS;W)T97),:7-T+FQE;F=T:"`M(#$I(')E='5R
M;CL*"B`@("`@("`@+RH@1&5S96QE8W0@979E<GET:&EN9R!B=70@=&AE(&9I
M<G-T('-E;&5C=&5D(&ET96TN("HO"B`@("`@("`@=&AI<RYS;W)T97),:7-T
M+G-E;&5C=&5D26YD97@@/2!S96P["B`@("`@("`@=F%R(&1O=VX@/2!T:&ES
M+G-O<G1E<DQI<W1;<V5L72YV86QU93L*"B`@("`@("`@=&UP(#T@;F5W($%R
M<F%Y*"D["B`@("`@("`@9F]R("AI(#T@=&AI<RYM:6Y,96YG=&@[(&D@/"!T
M:&ES+G-O<G1E<DQI<W0N;&5N9W1H.R!I*RLI('L*("`@("`@("`@("`@=&UP
M6VD@+2!T:&ES+FUI;DQE;F=T:%T@/2!N97<@3W!T:6]N*'1H:7,N<V]R=&5R
M3&ES=%MI72YT97AT+"!T:&ES+G-O<G1E<DQI<W1;:5TN=F%L=64I"B`@("`@
M("`@?0H*("`@("`@("!F;W(@*&D@/2`P.R!I(#P@=&UP+FQE;F=T:#L@:2LK
M*2!["B`@("`@("`@("`@(&EF("AI("L@=&AI<RYM:6Y,96YG=&@@/3T@<V5L
M*2!["B`@("`@("`@("`@("`@("!T:&ES+G-O<G1E<DQI<W1;:2`K('1H:7,N
M;6EN3&5N9W1H72`]('1M<%MI("L@,5T["B`@("`@("`@("`@('T@96QS92!I
M9B`H:2`K('1H:7,N;6EN3&5N9W1H(#T]('-E;"`K(#$I('L*("`@("`@("`@
M("`@("`@('1H:7,N<V]R=&5R3&ES=%MI("L@=&AI<RYM:6Y,96YG=&A=(#T@
M=&UP6VD@+2`Q73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@('1H:7,N<V]R=&5R3&ES=%MI("L@=&AI<RYM:6Y,96YG=&A=(#T@=&UP
M6VE=.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!T:&ES+G-O
M<G1E<DQI<W0N<V5L96-T961);F1E>"`]('-E;"`K(#$["@H@("`@("`@('1H
M:7,N<V5T2&ED9&5N*"D["B`@("!]"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:G,O9F]R;5]H96QP97)S
M+FIS````````````````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#$Q-34T(#$P-3$U-#,S-S,T(#`R,3(P-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````O*BH*("H@2F%V87-C<FEP="!T;R!A
M9&0@979E;G1S('1O(&9O<FT@96QE;65N=',*("H*("H@)$AO<F1E.B!H;W)D
M92]J<R]F;W)M7VAE;'!E<G,N:G,L=B`Q+C,N-"XV(#(P,#8O,#,O,C0@,#4Z
M,3<Z-3D@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!-
M871T($MY;F%S=&]N(#QM871T0&MY;G@N;W)G/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO
M"@HO*BH*("H@061D<R!T:&4@9VEV96X@979E;G0@=&\@86X@96QE;65N="X@
M268@=&AE(&5L96UE;G0@86QR96%D>2!H87,*("H@<V-R:7!T(&9O<B!T:&4@
M979E;G0L('1H92!N97<@979E;G0@:7,@87!P96YD960N"B`J"B`J($!P87)A
M;2!O8FIE8W0@96QE;65N="`@(%1H92!E;&5M96YT('1O(&%D9"!T:&4@979E
M;G0@=&\N"B`J($!P87)A;2!S=')I;F<@979E;G0@("`@(%1H92!N86UE(&]F
M('1H92!E=F5N="X*("H@0'!A<F%M('-T<FEN9WQF=6YC=&EO;B!F=6YC=&EO
M;B`@5&AE(&IA=F%S8W)I<'0@=&\@97AE8W5T92X*("HO"F9U;F-T:6]N(&%D
M9$5V96YT*&5L96UE;G0L(&5V96YT+"!C;V1E*0I["B`@("!I9B`H(65L96UE
M;G0I('L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+R\@07-S
M:6=N(&YE=R!A;F]N>6UO=7,@9G5N8W1I;VX@:68@=V4G<F4@<&%S<V5D(&$@
M:G,@<W1R:6YG"B`@("`O+R!I;G-T96%D(&]F(&$@9G5N8W1I;VX@<F5F97)E
M;F-E+@H@("`@:68@*'1Y<&5O9B!C;V1E(#T]("=S=')I;F<G*2!["B`@("`@
M("`@8V]D92`](&YE=R!&=6YC=&EO;BAC;V1E*3L*("`@('T*"B`@("!I9B`H
M96QE;65N="YA9&1%=F5N=$QI<W1E;F5R*2!["B`@("`@("`@96QE;65N="YA
M9&1%=F5N=$QI<W1E;F5R*&5V96YT+G)E<&QA8V4H+V]N+RP@)R<I+"!C;V1E
M+"!F86QS92D["B`@("!](&5L<V4@:68@*&5L96UE;G0N871T86-H179E;G0I
M('L*("`@("`@("!E;&5M96YT+F%T=&%C:$5V96YT*&5V96YT+"!C;V1E*3L*
M("`@('T@96QS92!I9B`H96QE;65N="YO;FQO860@(3T@;G5L;"D@>PH@("`@
M("`@('9A<B!/;&1%=F5N="`](&5L96UE;G1;979E;G1=.PH@("`@("`@(&YE
M=T-O9&4@/2!&=6YC=&EO;BAE*0H@("`@("`@('L*("`@("`@("`@("`@;VQD
M179E;G0H92D["B`@("`@("`@("`@(&-O9&4H*3L*("`@("`@("!].PH@("`@
M("`@(&5L96UE;G1;979E;G1=(#T@;F5W0V]D93L*("`@('T@96QS92!["B`@
M("`@("`@96QE;65N=%ME=F5N=%T@/2!C;V1E.PH@("`@?0H*("`@(')E='5R
M;B!T<G5E.PI]"@HO*BH*("H@4F5T=7)N<R!G:79E;B!V86QU92!A<R!A(&YU
M;6)E<BP@;W(@>F5R;R!I9B!.84XN"B`J"B`J($!P87)A;2!M:7AE9"`@=F%L
M"B`J"B`J($!R971U<FX@;G5M8F5R"B`J+PIF=6YC=&EO;B!T;TYU;6)E<BAV
M86PI"GL*("`@(&EF("AI<TYA3BAV86PI*2!["B`@("`@("`@<F5T=7)N(#`[
M"B`@("!](&5L<V4@>PH@("`@("`@(')E='5R;B!.=6UB97(H=F%L*3L*("`@
M('T*?0H*+RHJ"B`J(%-E=',@=&AE(&5N86)L960@<W1A=&4@;V8@;VYE(&5L
M96UE;G0@8F%S960@;VX@=&AE('9A;'5E<R!O9B!A;F]T:&5R+@H@*@H@*B!4
M86ME<R!F;W5R(&]R(&UO<F4@87)G=6UE;G1S+"!I;B!T:&4@9F]R;3H*("H@
M("!C:&5C:T5N86)L960H<V]U<F-E+"!T87)G970L('1R=64L('9A;'5E,2P@
M=F%L=64R+"!V86QU93,N+BXI"B`J"B`J($!P87)A;2!O8FIE8W0@("!4:&4@
M96QE;65N="!T;R!C:&5C:PH@*B!`<&%R86T@<W1R:6YG("`@5&AE(&5L96UE
M;G0@=&\@96YA8FQE+V1I<V%B;&4*("H@0'!A<F%M(&)O;VQE86X@(%=H971H
M97(@=&\@96YA8FQE(&]R(&1I<V%B;&4@=&AE('1A<F=E=`H@*B!`<&%R86T@
M;6EX960@("`@5&AE('9A;'5E('1O(&-H96-K(&%G86EN<W0*("HO"F9U;F-T
M:6]N(&-H96-K16YA8FQE9"@I"GL*("`@(&EF("AA<F=U;65N=',N;&5N9W1H
M(#X@,BD@>PH@("`@("`@(&]B:E-R8R`](&%R9W5M96YT<ULP73L*("`@("`@
M("!O8FI487)G970@/2!O8FI3<F,N9F]R;2YE;&5M96YT<UMA<F=U;65N='-;
M,5U=.PH@("`@("`@(&5N86)L960@/2!A<F=U;65N='-;,ET["B`@("`@("`@
M=&]G9VQE(#T@9F%L<V4["B`@("`@("`@:68@*&]B:E1A<F=E="D@>PH@("`@
M("`@("`@("!S=VET8V@@*&]B:E-R8RYT>7!E+G1O3&]W97)#87-E*"DI('L*
M("`@("`@("`@("`@8V%S92`G<V5L96-T+6]N92<@.@H@("`@("`@("`@("`@
M("`@=F%L(#T@;V)J4W)C+F]P=&EO;G-;;V)J4W)C+G-E;&5C=&5D26YD97A=
M+G9A;'5E.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C
M87-E("=S96QE8W0M;75L=&EP;&4G(#H*("`@("`@("`@("`@("`@('9A;"`]
M(&YE=R!!<G)A>2@I.PH@("`@("`@("`@("`@("`@8V]U;G0@/2`P.PH@("`@
M("`@("`@("`@("`@9F]R("AV87(@:2`](#`[(&D@/"!O8FI3<F,N;&5N9W1H
M.R`K*VDI('L*("`@("`@("`@("`@("`@("`@("!I9B`H;V)J4W)C+F]P=&EO
M;G-;:5TN<V5L96-T960I('L*("`@("`@("`@("`@("`@("`@("`@("`@=F%L
M6V-O=6YT72`](&]B:E-R8RYO<'1I;VYS6VE=+G9A;'5E.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G8VAE8VMB;W@G(#H*("`@("`@
M("`@("`@("`@(&EF("AO8FI3<F,N8VAE8VME9"D@>PH@("`@("`@("`@("`@
M("`@("`@('9A;"`](&]B:E-R8RYV86QU93L*("`@("`@("`@("`@("`@("`@
M("!T;V=G;&4@/2!T<G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("!D969A=6QT(#H*("`@("`@("`@
M("`@("`@('9A;"`](&]B:E-R8RYV86QU93L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@9F]R("AV87(@:2`](#,[(&D@/"!A<F=U;65N=',N;&5N9W1H
M.R`K*VDI('L*("`@("`@("`@("`@("`@(&EF("AT>7!E;V8H=F%L*2`]/2`G
M;V)J96-T)R`F)B`H87)G=6UE;G1S6VE=(&EN('9A;"DI('L*("`@("`@("`@
M("`@("`@("`@("!T;V=G;&4@/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@?2!E;'-E(&EF("AA<F=U;65N='-;
M:5T@/3T@=F%L*2!["B`@("`@("`@("`@("`@("`@("`@=&]G9VQE(#T@=')U
M93L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@;V)J5&%R9V5T+F1I<V%B
M;&5D(#T@=&]G9VQE(#\@(65N86)L960@.B!E;F%B;&5D.PH@("`@("`@("`@
M("!I9B`H(6]B:E1A<F=E="YD:7-A8FQE9"D@>PH@("`@("`@("`@("`@("`@
M;V)J5&%R9V5T+F9O8W5S*"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("!]"GT*"B\J*@H@*B!3971S('1H92!T87)G970@9FEE;&0@=&\@=&AE('-U
M;2!O9B!A(')A;F=E(&]F(&9I96QD<RX*("H*("H@5&%K97,@=&AR964@;W(@
M;6]R92!A<F=U;65N=',L(&EN('1H92!F;W)M.@H@*B`@("!S=6U&:65L9',H
M9F]R;2P@=&%R9V5T+"!F:65L9#$L(&9I96QD,BP@9FEE;&0S+BXN*0H@*@H@
M*B!`<&%R86T@;V)J96-T("!4:&4@9F]R;2!T;R!C:&5C:PH@*B!`<&%R86T@
M<W1R:6YG("!4:&4@;F%M92!O9B!T:&4@=&%R9V5T(&5L96UE;G0*("H@0'!A
M<F%M('-T<FEN9R`@3VYE(&]R(&UO<F4@9FEE;&0@;F%M97,@=&\@<W5M"B`J
M+PIF=6YC=&EO;B!S=6U&:65L9',H*0I["B`@("!I9B`H87)G=6UE;G1S+FQE
M;F=T:"`^(#(I('L*("`@("`@("!O8FI&<FT@/2!A<F=U;65N='-;,%T["B`@
M("`@("`@;V)J5&%R9V5T(#T@;V)J1G)M+F5L96UE;G1S6V%R9W5M96YT<ULQ
M75T["B`@("`@("`@<W5M(#T@,#L*("`@("`@("!I9B`H;V)J5&%R9V5T*2![
M"B`@("`@("`@("`@(&9O<B`H=F%R(&D@/2`R.R!I(#P@87)G=6UE;G1S+FQE
M;F=T:#L@*RMI*2!["B`@("`@("`@("`@("`@("!O8FI3<F,@/2!O8FI&<FTN
M96QE;65N='-;87)G=6UE;G1S6VE=73L*("`@("`@("`@("`@("`@(&EF("AO
M8FI3<F,I('L*("`@("`@("`@("`@("`@("`@("!S=VET8V@@*&]B:E-R8RYT
M>7!E+G1O3&]W97)#87-E*"DI('L*("`@("`@("`@("`@("`@("`@("!C87-E
M("=S96QE8W0M;VYE)SH*("`@("`@("`@("`@("`@("`@("`@("`@<W5M("L]
M('1O3G5M8F5R*&]B:E-R8RYO<'1I;VYS6V]B:E-R8RYS96QE8W1E9$EN9&5X
M72YV86QU92D["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@("`@("`@("!C87-E("=S96QE8W0M;75L=&EP;&4G(#H*("`@
M("`@("`@("`@("`@("`@("`@("`@9F]R("AV87(@:B`](#`[(&H@/"!O8FI3
M<F,N;&5N9W1H.R`K*VHI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('-U;2`K/2!T;TYU;6)E<BAO8FI3<F,N;W!T:6]N<UMJ72YV86QU92D["B`@
M("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("`@("`@("`@(&-A<V4@)V-H96-K8F]X
M)R`Z"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AO8FI3<F,N8VAE8VME
M9"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W5M("L]('1O3G5M
M8F5R*&]B:E-R8RYV86QU92D["B`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@
M("`@("`@(&1E9F%U;'0@.@H@("`@("`@("`@("`@("`@("`@("`@("!S=6T@
M*ST@=&].=6UB97(H;V)J4W)C+G9A;'5E*3L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@(&]B:E1A<F=E="YV86QU92`]('-U;3L*("`@("`@("!]"B`@("!]"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VIS+VAT='!C
M;&EE;G0N:G,`````````````````````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`Q,3`W-B`Q,#4Q-30S,S<S-"`P,C`V-S4`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+RHJ"B`J($IA=F%S8W)I
M<'0@;&EB<F%R>2!F;W(@=V]R:VEN9R!W:71H(%AM;$AT='!297%U97-T(&]B
M:F5C=',@86YD"B`J($AO<F1E+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VIS+VAT
M='!C;&EE;G0N:G,L=B`Q+C(N,3`N,R`R,#`U+S$P+S$X(#$Q.C,S.C,X(&IA
M;B!%>'`@)`H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60@;F]T
M"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@HO+R!#;VYS=')U8W1O<B!F;W(@
M9V5N97)I8R!(5%10(&-L:65N="X*9G5N8W1I;VX@2%144$-L:65N="@I('M]
M.PH*+R\@061D(&UE=&AO9',@86YD('!R;W!E<G1I97,@87,@87)R87DN"DA4
M5%!#;&EE;G0N<')O=&]T>7!E(#T@>PH@("`@=7)L.B!N=6QL+`H*("`@("\O
M($EN<W1A;F-E(&]F(%A-3$AT='!297%U97-T+@H@("`@<F5Q=65S=#H@;G5L
M;"P*"B`@("`O+R!5<V5D('1O(&UA:V4@<W5R92!M=6QT:7!L92!C86QL<R!A
M<F4@;F]T('!L86-E9"!W:71H('1H92!S86UE"B`@("`O+R!C;&EE;G0@;V)J
M96-T('=H:6QE(&%N;W1H97(@:6X@<')O9W)E<W,N"B`@("!C86QL26Y0<F]G
M<F5S<SH@9F%L<V4L"@H@("`@+R\@5&AE('5S97(@9&5F:6YE9"!H86YD;&5R
M("T@<V5E($UY2&%N9&QE<B!B96QO=RX*("`@('5S97)H86YD;&5R.B!N=6QL
M+`H*("`@(&EN:70Z(&9U;F-T:6]N*'5R;"D*("`@('L*("`@("`@("!T:&ES
M+G5R;"`]('5R;#L*"B`@("`@("`@=')Y('L*("`@("`@("`@("`@+R\@36]Z
M:6QL82P@4V%F87)I+@H@("`@("`@("`@("!T:&ES+G)E<75E<W0@/2!N97<@
M6$U,2'1T<%)E<75E<W0H*3L*("`@("`@("!](&-A=&-H("AE*2!["B`@("`@
M("`@("`@("\O($E%+@H@("`@("`@("`@("!V87(@35-834Q?6$U,2%144%]0
M4D]'2413(#T@;F5W($%R<F%Y*`H@("`@("`@("`@("`@("`@(DU36$U,,BY8
M34Q(5%10+C0N,"(L"B`@("`@("`@("`@("`@("`B35-834PR+EA-3$A45%`N
M,RXP(BP*("`@("`@("`@("`@("`@(")-4UA-3#(N6$U,2%144"(L"B`@("`@
M("`@("`@("`@("`B36EC<F]S;V9T+EA-3$A45%`B"B`@("`@("`@("`@("`@
M("`I.PH@("`@("`@("`@("!V87(@<W5C8V5S<R`](&9A;'-E.PH@("`@("`@
M("`@("!F;W(@*'9A<B!I(#T@,#L@:2`\($U36$U,7UA-3$A45%!?4%)/1TE$
M4RYL96YG=&@@)B8@(7-U8V-E<W,[(&DK*RD@>PH@("`@("`@("`@("`@("`@
M=')Y('L*("`@("`@("`@("`@("`@("`@("!T:&ES+G)E<75E<W0@/2!N97<@
M06-T:79E6$]B:F5C="A-4UA-3%]834Q(5%107U!23T=)1%-;:5TI.PH@("`@
M("`@("`@("`@("`@("`@('-U8V-E<W,@/2!T<G5E.PH@("`@("`@("`@("`@
M("`@?2!C871C:"`H92D@>WT*("`@("`@("`@("`@?0H@("`@("`@("`@("!I
M9B`H(7-U8V-E<W,I('L*("`@("`@("`@("`@("`@('1H<F]W(")5;F%B;&4@
M=&\@8W)E871E(%A-3$AT='!297%U97-T+B(["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("!]+`H*("`@("\O($AA;F1L97(@87)G=6UE;G0@:7,@82!U
M<V5R(&1E9FEN960@;V)J96-T('1O(&)E(&-A;&QE9"X*("`@(&%S>6YC1T54
M.B!F=6YC=&EO;BAH86YD;&5R*0H@("`@>PH@("`@("`@("\O($1E9W)A9&4@
M;W(@<V]M92!S=6-H+@H@("`@("`@(&EF("@A=&AI<RYR97%U97-T*2!["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!].PH*("`@("`@("`O
M+R!0<F5V96YT(&UU;'1I<&QE(&-A;&QS"B`@("`@("`@:68@*'1H:7,N8V%L
M;$EN4')O9W)E<W,I('L*("`@("`@("`@("`@=&AR;W<@(D-A;&P@:6X@<')O
M9W)E<W,B.PH@("`@("`@('T["@H@("`@("`@('1H:7,N8V%L;$EN4')O9W)E
M<W,@/2!T<G5E.PH*("`@("`@("!T:&ES+G5S97)H86YD;&5R(#T@:&%N9&QE
M<CL*"B`@("`@("`@+R\@3W!E;B!A;B!A<WEN8R!R97%U97-T("T@=&AI<F0@
M87)G=6UE;G0@;6%K97,@:70*("`@("`@("`O+R!A<WEN8VAR;VYO=7,N"B`@
M("`@("`@=&AI<RYR97%U97-T+F]P96XH)T=%5"<L('1H:7,N=7)L+"!T<G5E
M*3L*"B`@("`@("`@+R\@2&%V92!T;R!A<W-I9VX@(G1H:7,B('1O(&$@=F%R
M:6%B;&4N"B`@("`@("`@=F%R('-E;&8@/2!T:&ES.PH*("`@("`@("`O+R!!
M<W-I9VX@82!C;&]S=7)E('1O('1H92!O;G)E861Y<W1A=&5C:&%N9V4@8V%L
M;&)A8VLN"B`@("`@("`@=&AI<RYR97%U97-T+F]N<F5A9'ES=&%T96-H86YG
M92`](&9U;F-T:6]N*"D*("`@("`@("!["B`@("`@("`@("`@('-E;&8N<W1A
M=&5#:&%N9V5#86QL8F%C:RAS96QF*3L*("`@("`@("!]"@H@("`@("`@('1H
M:7,N<F5Q=65S="YS96YD*&YU;&PI.PH@("`@?2P*"B`@("!S=&%T94-H86YG
M94-A;&QB86-K.B!F=6YC=&EO;BAC;&EE;G0I"B`@("!["B`@("`@("`@<W=I
M=&-H("AC;&EE;G0N<F5Q=65S="YR96%D>5-T871E*2!["B`@("`@("`@("`@
M("\O(%)E<75E<W0@;F]T('EE="!M861E+@H@("`@("`@("`@("!C87-E(#$Z
M"B`@("`@("`@("`@('1R>2!["B`@("`@("`@("`@("`@("!C;&EE;G0N=7-E
M<FAA;F1L97(N;VY);FET*"D["B`@("`@("`@("`@('T@8V%T8V@@*&4I('L@
M+RH@2&%N9&QE<B!M971H;V0@;F]T(&1E9FEN960N("HO('T*("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("`O+R!#;VYT86-T(&5S=&%B;&ES:&5D
M('=I=&@@<V5R=F5R(&)U="!N;W1H:6YG(&1O=VYL;V%D960*("`@("`@("`@
M("`@+R\@>65T+@H@("`@("`@("`@("!C87-E(#(Z"B`@("`@("`@("`@('1R
M>2!["B`@("`@("`@("`@("`@("!S=&%T=7,@/2!C;&EE;G0N<F5Q=65S="YS
M=&%T=7,["B`@("`@("`@("`@("`@("`O+R!#:&5C:R!F;W(@2%144"!S=&%T
M=7,@,C`P+@H@("`@("`@("`@("`@("`@:68@*'-T871U<R`A/2`R,#`I('L*
M("`@("`@("`@("`@("`@("`@("!C;&EE;G0N=7-E<FAA;F1L97(N;VY%<G)O
M<B@*("`@("`@("`@("`@("`@("`@("`@("`@<W1A='5S+`H@("`@("`@("`@
M("`@("`@("`@("`@("!C;&EE;G0N<F5Q=65S="YS=&%T=7-497AT"B`@("`@
M("`@("`@("`@("`@("`@("`@("D["@H@("`@("`@("`@("`@("`@("`@("\O
M($%B;W)T('1H92!R97%U97-T+@H@("`@("`@("`@("`@("`@("`@(&-L:65N
M="YR97%U97-T+F%B;W)T*"D["@H@("`@("`@("`@("`@("`@("`@("\O($-A
M;&P@;F\@;&]N9V5R(&EN('!R;V=R97-S+@H@("`@("`@("`@("`@("`@("`@
M(&-L:65N="YC86QL26Y0<F]G<F5S<R`](&9A;'-E.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!](&-A=&-H("AE*2!["B`@("`@("`@("`@("`@
M("`O*B!-4UA-3$A45%`@,RYX*R!D;V5S;B=T('!O<'5L871E('-T871U<R!U
M;G1I;`H@("`@("`@("`@("`@("`@("H@<F5A9'E3=&%T92`T+B`J+PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@+R\@
M0V%L;&5D(&UU;'1I<&QE('1I;65S('=H:6QE(&1O=VYL;V%D(&ES(&EN('!R
M;V=R97-S+@H@("`@("`@("`@("!C87-E(#,Z"B`@("`@("`@("`@("\O($YO
M=&EF>2!U<V5R(&AA;F1L97(@;V8@9&]W;FQO860@<')O9W)E<W,N"B`@("`@
M("`@("`@('1R>2!["B`@("`@("`@("`@("`@("`O+R!'970@=&AE('1O=&%L
M(&-O;G1E;G0@;&5N9W1H("AU<V5F=6P@=&\@=V]R:PH@("`@("`@("`@("`@
M("`@+R\@;W5T(&AO=R!M=6-H(&AA<R!B965N(&1O=VYL;V%D960I+@H@("`@
M("`@("`@("`@("`@=')Y('L*("`@("`@("`@("`@("`@("`@("!V87(@8V]N
M=&5N=$QE;F=T:"`]"B`@("`@("`@("`@("`@("`@("`@("`@(&-L:65N="YR
M97%U97-T+F=E=%)E<W!O;G-E2&5A9&5R*")#;VYT96YT+4QE;F=T:"(I.PH@
M("`@("`@("`@("`@("`@?2!C871C:"`H92D@>PH@("`@("`@("`@("`@("`@
M("`@('9A<B!C;VYT96YT3&5N9W1H(#T@3F%..PH@("`@("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@("`@("\O($-A;&P@=&AE('!R;V=R97-S(&AA;F1L
M97(@=VET:"!W:&%T('=E)W9E(&=O="X*("`@("`@("`@("`@("`@(&-L:65N
M="YU<V5R:&%N9&QE<BYO;E!R;V=R97-S*`H@("`@("`@("`@("`@("`@("`@
M(&-L:65N="YR97%U97-T+G)E<W!O;G-E5&5X="P*("`@("`@("`@("`@("`@
M("`@("!C;VYT96YT3&5N9W1H"B`@("`@("`@("`@("`@("`@("`@*3L*"B`@
M("`@("`@("`@('T@8V%T8V@@*&4I('L@+RH@2&%N9&QE<B!M971H;V0@;F]T
M(&1E9FEN960N("HO('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("`O+R!$;W=N;&]A9"!C;VUP;&5T92X*("`@("`@("`@("`@8V%S92`T.@H@
M("`@("`@("`@("!T<GD@>PH@("`@("`@("`@("`@("`@8VQI96YT+G5S97)H
M86YD;&5R+F]N3&]A9"AC;&EE;G0N<F5Q=65S="YR97-P;VYS951E>'0I.PH@
M("`@("`@("`@("!](&-A=&-H("AE*2!["B`@("`@("`@("`@("`@("`O*B!(
M86YD;&5R(&UE=&AO9"!N;W0@9&5F:6YE9"X@*B\*("`@("`@("`@("`@?2!F
M:6YA;&QY('L*("`@("`@("`@("`@("`@("\O($-A;&P@;F\@;&]N9V5R(&EN
M('!R;V=R97-S+@H@("`@("`@("`@("`@("`@8VQI96YT+F-A;&Q);E!R;V=R
M97-S(#T@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@?0H@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]J
M<R]I945S8T=U87)D+FIS````````````````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#,T-#$@,3`U,34T,S,W,S0@,#(P-3(W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"\J*@H@*B!*
M879A<V-R:7!T(&-O9&4@9F]R(&%T=&%C:&EN9R!A;B!O;FME>61O=VX@;&ES
M=&5N97(@=&\@=&5X=&%R96$@86YD"B`J('1E>'0@:6YP=70@96QE;65N=',@
M=&\@<')E=F5N="!L;W-S(&]F(&1A=&$@=VAE;B!T:&4@=7-E<B!H:71S('1H
M90H@*B!%4T,@:V5Y+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VIS+VEE17-C1W5A
M<F0N:G,L=B`Q+C$N,BXS(#(P,#4O,3`O,3@@,3$Z,S,Z,S@@:F%N($5X<"`D
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9"!N;W0*("H@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*B\*"B\J(%1H:7,@8V]D92!I<R!O;FQY(')E;&5V
M86YT(&9O<B!)12X@5&AE<F5F;W)E('1R>2!N;W0@=&\@9&\@86YY=&AI;F<*
M("H@:68@=&AE('5S97(@:7-N)W0@=7-I;F<@244L(&5V96X@:68@=&AI<R!S
M8W)I<'0@:7,@:6YC;'5D960N(%1H:7,*("H@8VAE8VL@=VEL;"!C871C:"!S
M;VUE(&)R;W=S97)S('1H870@87)E(&YO="!)12!B=70@:61E;G1I9GD*("H@
M=&AE;7-E;'9E<R!A<R!)12X@2&]P969U;&QY(&EF('1H97D@<&%S<R!T:')O
M=6=H('1H97D@<W5P<&]R="!W:&%T"B`J($E%('-U<'!O<G1S+B`J+PII9B`H
M;F%V:6=A=&]R+F%P<%9E<G-I;VXN:6YD97A/9B@G35-)12<I("$]("TQ("8F
M(&1O8W5M96YT+F%L;"D@>PH@("`@+RH@5V4@9&\@979E<GET:&EN9R!O;FQO
M860@<V\@=&AA="!T:&4@96YT:7)E(&1O8W5M96YT(&ES('!R97-E;G0*("`@
M("`J(&)E9F]R92!W92!S=&%R="!S96%R8VAI;F<@:70N("HO"B`@("!W:6YD
M;W<N871T86-H179E;G0H)V]N;&]A9"<L(&=U87)D*3L*?0H*+RHJ"B`J($9I
M;F1S(&%L;"!T97AT(&EN<'5T<R`H:6YP=70@='EP93TB=&5X="(I(&%N9"!T
M97AT87)E82!T86=S+"!A;F0*("H@871T86-H97,@=&AE(&]N:V5Y9&]W;B!L
M:7-T96YE<B!T;R!T:&5M('1O(&%V;VED($530R!C;&5A<FEN9R!T:&4*("H@
M=&5X="X*("HO"F9U;F-T:6]N(&=U87)D*"D*>PH@("`@+RH@1FEN9',@86QL
M('1E>'1A<F5A<RX@*B\*("`@('9A<B!T97AT87)E87,@/2!D;V-U;65N="YA
M;&PN=&%G<R@G5$585$%214$G*3L*("`@(&9O<B`H=F%R(&D@/2`P.R!I(#P@
M=&5X=&%R96%S+FQE;F=T:#L@:2LK*2!["B`@("`@("`@=&5X=&%R96%S6VE=
M+F%T=&%C:$5V96YT*"=O;FME>61O=VXG+"!D:7-A8FQE17-C87!E*3L*("`@
M('T*"B`@("`O*B!&:6YD<R!?86QL7R`\:6YP=70^('1A9W,N("HO"B`@("!V
M87(@:6YP=71S(#T@9&]C=6UE;G0N86QL+G1A9W,H)TE.4%54)RD["B`@("!F
M;W(@*'9A<B!I(#T@,#L@:2`\(&EN<'5T<RYL96YG=&@[(&DK*RD@>PH@("`@
M("`@("\J($]N;'D@871T86-H('1O(#QI;G!U="!T>7!E/2)T97AT(CX@=&%G
M<RX@*B\*("`@("`@("!I9B`H:6YP=71S6VE=+G1Y<&4@/3T@)W1E>'0G*2![
M"B`@("`@("`@("`@(&EN<'5T<UMI72YA='1A8VA%=F5N="@G;VYK97ED;W=N
M)RP@9&ES86)L945S8V%P92D["B`@("`@("`@?0H@("`@?0I]"@HO*BH*("H@
M4F5T=7)N<R!F86QS92!I9B!T:&4@=7-E<B!H:70@=&AE($530R!K97DL('!R
M979E;G1I;F<@244@9G)O;0H@*B!B;&%N:VEN9R!T:&4@9FEE;&0N($]T:&5R
M=VES92!R971U<FYS('1R=64N"B`J"B`J(')E='5R;B!B;V]L96%N("!7:&5T
M:&5R(&]R(&YO="!T;R!A;&QO=R!T:&4@:V5Y(&5V96YT+@H@*B\*9G5N8W1I
M;VX@9&ES86)L945S8V%P92@I"GL*("`@(')E='5R;B!W:6YD;W<N979E;G0N
M:V5Y0V]D92`A/2`R-SL*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:G,O9F]R
M;5]S96-T:6]N<RYJ<P``````````````````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`S-3(T(#$P-3$U-#,S-S,T(#`R,3,W,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````O*BH*("H@2&]R9&4@
M1F]R;2!396-T:6]N<R!*879A<V-R:7!T($-L87-S"B`J"B`J(%!R;W9I9&5S
M('1H92!J879A<V-R:7!T(&-L87-S(&9O<B!H86YD;&EN9R!T86)B960@<V5C
M=&EO;G,@:6X@2&]R9&4@1F]R;7,N"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P
M,#8@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J("1(;W)D93H@:&]R9&4O:G,O9F]R;5]S96-T:6]N<RYJ<RQV(#$N
M,2XR+C(@,C`P-B\P-"\Q-2`R,CHR,SHS-B!C:'5C:R!%>'`@)`H@*@H@*B!`
M875T:&]R("!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*B!`<&%C
M:V%G92!(;W)D95]&;W)M"B`J+PIF=6YC=&EO;B!(;W)D95]&;W)M7U-E8W1I
M;VYS*&EN<W1A;F-E3F%M92P@;W!E;E-E8W1I;VXI"GL*("`@("\J(%-E="!U
M<"!T:&ES(&-L87-S(&EN<W1A;F-E(&9O<B!F=6YC=&EO;B!C86QL<R!F<F]M
M('1H92!P86=E+B`J+PH@("`@=&AI<RY?:6YS=&%N8V5.86UE(#T@:6YS=&%N
M8V5.86UE.PH*("`@("\J(%1H92!C=7)R96YT;'D@<VAO=V5D('-E8W1I;VXN
M("HO"B`@("!V87(@7V]P96Y396-T:6]N.PH*("`@('1H:7,N=&]G9VQE(#T@
M9G5N8W1I;VXH<V5C=&EO;DED*0H@("`@>PH@("`@("`@("\J($=E="!T:&4@
M8W5R<F5N=&QY(&]P96X@<V5C=&EO;B!O8FIE8W0N("HO"B`@("`@("`@;W!E
M;E-E8W1I;VY)9"`]('1H:7,N7V=E="@I.PH@("`@("`@(&EF("AD;V-U;65N
M="YG971%;&5M96YT0GE)9"@G7W-E8W1I;VY?)R`K(&]P96Y396-T:6]N260I
M*2!["B`@("`@("`@("`@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=?<V5C
M=&EO;E\G("L@;W!E;E-E8W1I;VY)9"DN<W1Y;&4N9&ES<&QA>2`]("=N;VYE
M)SL*("`@("`@("!]"B`@("`@("`@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H
M)U]T86)?)R`K(&]P96Y396-T:6]N260I+F-L87-S3F%M92`](&YU;&P["@H@
M("`@("`@("\J($=E="!T:&4@;F5W;'D@;W!E;F5D('-E8W1I;VX@;V)J96-T
M+B`J+PH@("`@("`@(&EF("AD;V-U;65N="YG971%;&5M96YT0GE)9"@G7W-E
M8W1I;VY?)R`K('-E8W1I;VY)9"DI('L*("`@("`@("`@("`@9&]C=6UE;G0N
M9V5T16QE;65N=$)Y260H)U]S96-T:6]N7R<@*R!S96-T:6]N260I+G-T>6QE
M+F1I<W!L87D@/2`G8FQO8VLG.PH@("`@("`@('T*("`@("`@("!D;V-U;65N
M="YG971%;&5M96YT0GE)9"@G7W1A8E\G("L@<V5C=&EO;DED*2YC;&%S<TYA
M;64@/2`G86-T:79E5&%B)SL*"B`@("`@("`@+RH@4W1O<F4@=&AE(&YE=VQY
M(&]P96YE9"!S96-T:6]N+B`J+PH@("`@("`@('1H:7,N7W-E="AS96-T:6]N
M260I.PH@("`@?0H*("`@('1H:7,N7V=E="`](&9U;F-T:6]N*"D*("`@('L*
M("`@("`@("!R971U<FX@=&AI<RY?;W!E;E-E8W1I;VX["B`@("!]"@H@("`@
M=&AI<RY?<V5T(#T@9G5N8W1I;VXH<V5C=&EO;DED*0H@("`@>PH@("`@("`@
M('9A<B!F;W)M(#T@979A;"@G9&]C=6UE;G0N)R`K('1H:7,N7VEN<W1A;F-E
M3F%M92D["B`@("`@("`@:68@*&9O<FT@(3T@;G5L;"`F)@H@("`@("`@("`@
M("!T>7!E;V8@9F]R;2Y?7V9O<FU/<&5N4V5C=&EO;B`A/2`G=6YD969I;F5D
M)RD@>PH@("`@("`@("`@("!F;W)M+E]?9F]R;4]P96Y396-T:6]N+G9A;'5E
M(#T@97-C87!E*'-E8W1I;VY)9"D["B`@("`@("`@?0H@("`@("`@('1H:7,N
M7V]P96Y396-T:6]N(#T@<V5C=&EO;DED.PH@("`@?0H*("`@('1H:7,N7W-E
M="AO<&5N4V5C=&EO;BD["GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VIS+V5N=&5R7VME
M>5]T<F%P+FIS````````````````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,3`P-R`Q,#4Q-30S,S<S-"`P,C$U,C,`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+RHJ"B`J($IA=F%S8W)I<'0@
M=&\@=')A<"!F;W(@=&AE(&5N=&5R(&ME>2X*("H*("H@)$AO<F1E.B!H;W)D
M92]J<R]E;G1E<E]K97E?=')A<"YJ<RQV(#$N,BXQ,"XS(#(P,#8O,#4O,#4@
M,34Z,S,Z,S0@8VAU8VL@17AP("0*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PIF=6YC=&EO
M;B!E;G1E<E]K97E?=')A<"AE=F5N="D*>PH@("`@=F%R(&ME>3L*("`@(&EF
M("AE=F5N="YK97E#;V1E*2!["B`@("`@("`@:V5Y(#T@979E;G0N:V5Y0V]D
M93L*("`@('T@96QS92!I9B`H979E;G0N=VAI8V@I('L*("`@("`@("!K97D@
M/2!E=F5N="YW:&EC:#L*("`@('T@96QS92!["B`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@?0H*("`@(')E='5R;B`H:V5Y(#T](#$P('Q\(&ME>2`]/2`Q
M,RD["GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VIS+VAI
M9&5A8FQE+FIS````````````````````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,C8R-R`Q,#4Q-30S,S<S-"`P,C`R-38`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+RHJ"B`J($IA=F%S
M8W)I<'0@;V)J96-T(&9O<B!H:61I;F<@)B!S:&]W:6YG($1/32!E;&5M96YT
M<RX*("H*("H@)$AO<F1E.B!H;W)D92]J<R]H:61E86)L92YJ<RQV(#$N,B`R
M,#`T+S$P+S$Y(#$Y.C`X.C4S(&-H=6-K($5X<"`D"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U(&1I9"!N;W0*("H@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*B\*"B\J*@H@*B!#;VYS=')U8W1O<B!F;W(@2&]R9&4@2&ED96%B;&4@1$]-
M(&5L96UE;G1S+@H@*@H@*B!`<&%R86T@:60@("`@("`@("`@("!4:&4@1$]-
M(&ED(&]F('1H92!E;&5M96YT('=E('=A;G0@=&\@=V]R:R!W:71H+@H@*B!`
M<&%R86T@9&ES<&QA>5-T>6QE("!7:&%T(&1I<W!L87D@<W1Y;&4@<VAO=W,@
M=&AI<R!E;&5M96YT/R!$969A=6QT<PH@*B`@("`@("`@("`@("`@("`@("`@
M("!T;R`G8FQO8VLG+@H@*B\*9G5N8W1I;VX@2&]R9&5?2&ED96%B;&4H*0I[
M"B`@("!T:&ES+FED(#T@87)G=6UE;G1S6S!=.PH@("`@=&AI<RYE;&5M96YT
M(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H=&AI<RYI9"D["@H@("`@:68@
M*&%R9W5M96YT<RYL96YG=&@@/3T@,BD@>PH@("`@("`@('1H:7,N9&ES<&QA
M>5-T>6QE(#T@87)G=6UE;G1S6S%=.PH@("`@?0I].PH*2&]R9&5?2&ED96%B
M;&4N<')O=&]T>7!E(#T@>PH*("`@("\J*@H@("`@("H@260@;V8@=&AE($1/
M32!E;&5M96YT+@H@("`@("H@0'9A<B!I9`H@("`@("HO"B`@("!I9#H@;G5L
M;"P*"B`@("`O*BH*("`@("`J($1/32!E;&5M96YT(')E9F5R96YC92X*("`@
M("`J($!V87(@96QE;65N=`H@("`@("HO"B`@("!E;&5M96YT.B!N=6QL+`H*
M("`@("\J*@H@("`@("H@5&AE(&1I<W!L87D@<W1Y;&4@=&\@=7-E+B!$969A
M=6QT(&ES("=B;&]C:R<N"B`@("`@*B!`=F%R(&1I<W!L87E3='EL90H@("`@
M("HO"B`@("!D:7-P;&%Y4W1Y;&4Z("=B;&]C:R<L"@H@("`@<VAO=VXZ(&9U
M;F-T:6]N*"D*("`@('L*("`@("`@("!R971U<FX@=&AI<RYE;&5M96YT+G-T
M>6QE+F1I<W!L87D@(3T@)VYO;F4G.PH@("`@?2P*"B`@("!H:61E.B!F=6YC
M=&EO;B@I"B`@("!["B`@("`@("`@=&AI<RYE;&5M96YT+G-T>6QE+F1I<W!L
M87D@/2`G;F]N92<["B`@("`@("`@<F5T=7)N('1H:7,["B`@("!]+`H*("`@
M('-H;W<Z(&9U;F-T:6]N*"D*("`@('L*("`@("`@("!T:&ES+F5L96UE;G0N
M<W1Y;&4N9&ES<&QA>2`]('1H:7,N9&ES<&QA>5-T>6QE.PH@("`@("`@(')E
M='5R;B!T:&ES.PH@("`@?2P*"B`@("!T;V=G;&4Z(&9U;F-T:6]N*"D*("`@
M('L*("`@("`@("!R971U<FX@=&AI<RYS:&]W;B@I(#\@=&AI<RYH:61E*"D@
M.B!T:&ES+G-H;W<H*3L*("`@('T*"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O:G,O=&]O;'1I<"YJ<P``````````````````
M````````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`T,C<T(#$P-3$U
M-#,S-S,T(#`R,#(Q,P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````O*BH*("H@2&]R9&4@5&]O;'1I<"!*879A<V-R:7!T"B`J
M"B`J(%!R;W9I9&5S('1H92!J879A<V-R:7!T('1O(&1I<W!L87D@=&]O;'1I
M<',N"B`J"B`J("1(;W)D93H@:&]R9&4O:G,O=&]O;'1I<"YJ<RQV(#$N,BXQ
M,"XR(#(P,#4O,#4O,#$@,38Z-3,Z,S`@8VAU8VL@17AP("0*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*B\*"G9A<B!A8W1I=F54:6UE;W5T.PH*:68@*'1Y<&5O9B!D;V-U
M;65N="YC87!T=7)E179E;G1S("$]("=U;F1E9FEN960G*2!["B`@("!D;V-U
M;65N="YC87!T=7)E179E;G1S*$5V96YT+DU/55-%34]612D["B`@("!D;V-U
M;65N="YO;FUO=7-E;6]V92`](&UO=7-E4&]S.PH@("`@=F%R(&YE=%@L(&YE
M=%D["GT*"F9U;F-T:6]N('!O<U@H*0I["B`@("!T96UP6"`](&1O8W5M96YT
M+F)O9'DN<V-R;VQL3&5F="`K(&5V96YT+F-L:65N=%@["B`@("!I9B`H=&5M
M<%@@/"`P*2!["B`@("`@("`@=&5M<%@@/2`P.PH@("`@?0H@("`@<F5T=7)N
M('1E;7!8.PI]"@IF=6YC=&EO;B!P;W-9*"D*>PH@("`@=&5M<%D@/2!D;V-U
M;65N="YB;V1Y+G-C<F]L;%1O<"`K(&5V96YT+F-L:65N=%D["B`@("!I9B`H
M=&5M<%D@/"`P*2!["B`@("`@("`@=&5M<%D@/2`P.PH@("`@?0H@("`@<F5T
M=7)N('1E;7!9.PI]"@IF=6YC=&EO;B!M;W5S95!O<RAE*0I["B`@("!N9718
M(#T@92YP86=E6#L*("`@(&YE=%D@/2!E+G!A9V59.PI]"@IF=6YC=&EO;B!T
M;V]L=&EP4VAO=RAP6"P@<%DL('-R8RD*>PH@("`@:68@*'!8(#P@,2D@>PH@
M("`@("`@('!8(#T@,3L*("`@('T*("`@(&EF("AP62`\(#$I('L*("`@("`@
M("!P62`](#$["B`@("!]"B`@("!I9B`H9&]C=6UE;G0N9V5T16QE;65N=$)Y
M260I('L*("`@("`@("!T="`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=T
M;V]L=&EP)RD["B`@("`@("`@='0N<W1Y;&4N;&5F="`]('!8("L@)W!X)SL*
M("`@("`@("!T="YS='EL92YT;W`@/2!P62`K("=P>"<["B`@("`@("`@='0N
M<W1Y;&4N=FES:6)I;&ET>2`]("=V:7-I8FQE)SL*("`@("`@("!T="YI;FYE
M<DA434P@/2!S<F,["B`@("!](&5L<V4@>PH@("`@("`@(&1O8W5M96YT+F%L
M;"YT;V]L=&EP+G-T>6QE+FQE9G0@/2!P6"`K("=P>"<["B`@("`@("`@9&]C
M=6UE;G0N86QL+G1O;VQT:7`N<W1Y;&4N=&]P(#T@<%D@*R`G<'@G.PH@("`@
M("`@(&1O8W5M96YT+F%L;"YT;V]L=&EP+G-T>6QE+G9I<VEB:6QI='D@/2`G
M=FES:6)L92<["B`@("`@("`@9&]C=6UE;G0N86QL+G1O;VQT:7`N:6YN97)(
M5$U,(#T@<W)C.PH@("`@?0I]"@IF=6YC=&EO;B!T;V]L=&EP0VQO<V4H*0I[
M"B`@("!I9B`H9&]C=6UE;G0N9V5T16QE;65N=$)Y260I('L*("`@("`@("!T
M="`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=T;V]L=&EP)RD["B`@("`@
M("`@='0N<W1Y;&4N=FES:6)I;&ET>2`]("=H:61D96XG.PH@("`@("`@('1T
M+FEN;F5R2%1-3"`]("<G.PH@("`@?2!E;'-E('L*("`@("`@("!D;V-U;65N
M="YA;&PN=&]O;'1I<"YS='EL92YV:7-I8FEL:71Y(#T@)VAI9&1E;B<["B`@
M("`@("`@9&]C=6UE;G0N86QL+G1O;VQT:7`N:6YN97)(5$U,(#T@)R<["B`@
M("!]"B`@("!C;&5A<E1I;65O=70H86-T:79E5&EM96]U="D["B`@("!W:6YD
M;W<N<W1A='5S(#T@)R<["GT*"F9U;F-T:6]N('1O;VQT:7!,:6YK*'1O;VQT
M97AT+"!S=&%T=7-L:6YE*0I["B`@("!T97AT(#T@)SQD:78@8VQA<W,](G1O
M;VQT:7`B/B<@*R!T;V]L=&5X="`K("<\+V1I=CXG.PH@("`@:68@*'1Y<&5O
M9B!D;V-U;65N="YC87!T=7)E179E;G1S("$]("=U;F1E9FEN960G*2!["B`@
M("`@("`@>'!O<R`](&YE=%@["B`@("`@("`@>7!O<R`](&YE=%D["B`@("!]
M(&5L<V4@>PH@("`@("`@('AP;W,@/2!P;W-8*"D["B`@("`@("`@>7!O<R`]
M('!O<UDH*3L*("`@('T*("`@(&%C=&EV951I;65O=70@/2!S9714:6UE;W5T
M*"=T;V]L=&EP4VAO=RAX<&]S("T@,3$P+"!Y<&]S("L@,34L('1E>'0I.R<L
M(#,P,"D["B`@("!W:6YD;W<N<W1A='5S(#T@<W1A='5S;&EN93L*?0H*9&]C
M=6UE;G0N=W)I=&4H)SQD:78@:60](G1O;VQT:7`B('-T>6QE/2)P;W-I=&EO
M;CIA8G-O;'5T93L@=FES:6)I;&ET>3IH:61D96X[(CX\+V1I=CXG*3L*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:G,O<&]P=7`N:G,`````
M````````````````````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`Q-S4R(#$P-3$U-#,S-S,T(#`Q-S8V,@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````O*BH*("H@2&]R9&4@4&]P=7`@2F%V
M85-C<FEP="X*("H*("H@4')O=FED97,@=&AE(&IA=F%S8W)I<'0@=&\@;W!E
M;B!P;W!U<"!W:6YD;W=S+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VIS+W!O<'5P
M+FIS+'8@,2XR+C$P+C0@,C`P-B\P,B\Q,"`Q.#HQ-#HU-"!C:'5C:R!%>'`@
M)`H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("HO"F9U;F-T:6]N('!O<'5P*'5R;"P@=VED=&@L
M(&AE:6=H="D*>PH@("`@:68@*"%W:61T:"D@>PH@("`@("`@('=I9'1H(#T@
M-C`P.PH@("`@?0H@("`@:68@*"%H96EG:'0I('L*("`@("`@("!H96EG:'0@
M/2`U,#`["B`@("!]"@H@("`@=F%R(&YA;64@/2`H;F5W($1A=&4H*2DN9V5T
M5&EM92@I.PH@("`@=F%R('!A<F%M(#T@(G1O;VQB87(];F\L;&]C871I;VX]
M;F\L<W1A='5S/7EE<RQS8W)O;&QB87)S/7EE<RQR97-I>F%B;&4]>65S+'=I
M9'1H/2(@*R!W:61T:"`K("(L:&5I9VAT/2(@*R!H96EG:'0@*R`B+&QE9G0]
M,"QT;W`],"(["B`@("!V87(@=VEN(#T@=VEN9&]W+F]P96XH=7)L+"!N86UE
M+"!P87)A;2D["B`@("!I9B`H(7=I;BD@>PH@("`@("`@(&%L97)T*")!('!O
M<'5P('=I;F1O=R!C;W5L9"!N;W0@8F4@;W!E;F5D+B!9;W5R(&)R;W=S97(@
M;6%Y(&)E(&)L;V-K:6YG('!O<'5P<R!F;W(@=&AI<R!A<'!L:6-A=&EO;BXB
M*3L*("`@('T@96QS92!["B`@("`@("`@:68@*'1Y<&5O9B!W:6XN;F%M92`]
M/2`G=6YD969I;F5D)RD@>PH@("`@("`@("`@("!W:6XN;F%M92`](&YA;64[
M"B`@("`@("`@?0H@("`@("`@(&EF("AT>7!E;V8@=VEN+F]P96YE<B`]/2`G
M=6YD969I;F5D)RD@>PH@("`@("`@("`@("!W:6XN;W!E;F5R(#T@<V5L9CL*
M("`@("`@("!]"B`@("!]"@H@("`@<F5T=7)N('=I;CL*?0H`````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:G,O9F]R;5]A
M<W-I9VXN:G,`````````````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`T,3,P(#$P-3$U-#,S-S,T(#`R,3`Q-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````O*BH*("H@2&]R9&4@1F]R
M;2!!<W-I9VX@1FEE;&0@2F%V87-C<FEP="!#;&%S<PH@*@H@*B!0<F]V:61E
M<R!T:&4@:F%V87-C<FEP="!C;&%S<R!T;R!A8V-O;7!A;GD@=&AE($AO<F1E
M7T9O<FT@87-S:6=N(&9I96QD+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VIS+V9O
M<FU?87-S:6=N+FIS+'8@,2XR+C$P+C0@,C`P-B\P,R\R-"`P-3HQ-SHU.2!C
M:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($IA;B!38VAN
M96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@I(;W)D
M95]&;W)M7T%S<VEG;B`](&YE=R!/8FIE8W0H*3L*"DAO<F1E7T9O<FU?07-S
M:6=N+F1E<V5L96-T2&5A9&5R<R`](&9U;F-T:6]N*&YA;64L('-I9&4I"GL*
M("`@(&EF("AS:61E*2!["B`@("`@("`@9&]C=6UE;G1;;F%M92`K("=?7W)I
M9VAT)UU;,%TN<V5L96-T960@/2!F86QS93L*("`@('T@96QS92!["B`@("`@
M("`@9&]C=6UE;G1;;F%M92`K("=?7VQE9G0G75LP72YS96QE8W1E9"`](&9A
M;'-E.PH@("`@?0I]"@I(;W)D95]&;W)M7T%S<VEG;BYM;W9E(#T@9G5N8W1I
M;VXH;F%M92P@9&ER96-T:6]N*0I["B`@("!V87(@;&5F="`](&1O8W5M96YT
M6VYA;64@*R`G7U]L969T)UT["B`@("!V87(@<FEG:'0@/2!D;V-U;65N=%MN
M86UE("L@)U]?<FEG:'0G73L*"B`@("!I9B`H9&ER96-T:6]N*2!["B`@("`@
M("`@=F%R(&9R;VT@/2!R:6=H=#L*("`@("`@("!V87(@=&\@/2!L969T.PH@
M("`@?2!E;'-E('L*("`@("`@("!V87(@9G)O;2`](&QE9G0["B`@("`@("`@
M=F%R('1O(#T@<FEG:'0["B`@("!]"@H@("`@9F]R("AV87(@:2`](#`[(&D@
M/"!F<F]M+FQE;F=T:#L@*RMI*2!["B`@("`@("`@:68@*&9R;VU;:5TN<V5L
M96-T960I('L*("`@("`@("`@("`@=&];=&\N;&5N9W1H72`](&YE=R!/<'1I
M;VXH9G)O;5MI72YT97AT+"!F<F]M6VE=+G9A;'5E*3L*("`@("`@("`@("`@
M=&];=&\N;&5N9W1H("T@,5TN;VYD8FQC;&EC:R`](&9U;F-T:6]N*"D*("`@
M("`@("`@("`@>PH@("`@("`@("`@("`@("`@2&]R9&5?1F]R;5]!<W-I9VXN
M;6]V92AN86UE+"`Q("T@9&ER96-T:6]N*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!F<F]M6VE=(#T@;G5L;#L*("`@("`@("`@("`@+2UI.PH@("`@
M("`@('T*("`@('T*"B`@("!T:&ES+G-E=$9I96QD*&YA;64I.PI]"@I(;W)D
M95]&;W)M7T%S<VEG;BYS971&:65L9"`](&9U;F-T:6]N*&YA;64I"GL*("`@
M('9A<B!L969T(#T@9&]C=6UE;G1;;F%M92`K("=?7VQE9G0G73L*("`@('9A
M<B!R:6=H="`](&1O8W5M96YT6VYA;64@*R`G7U]R:6=H="==.PH*("`@('9A
M<B!V86QU97,@/2`G)SL*("`@('9A<B!H:70@/2!F86QS93L*("`@(&9O<B`H
M=F%R(&D@/2`P.R!I(#P@;&5F="YO<'1I;VYS+FQE;F=T:#L@*RMI*2!["B`@
M("`@("`@:68@*&D@/3T@,"`F)B`A;&5F=%MI72YV86QU92D@>PH@("`@("`@
M("`@("!C;VYT:6YU93L*("`@("`@("!]"B`@("`@("`@=F%L=65S("L](&QE
M9G0N;W!T:6]N<UMI72YV86QU92`K("=<="<["B`@("`@("`@:&ET(#T@=')U
M93L*("`@('T*("`@(&EF("AH:70I('L*("`@("`@("!V86QU97,@/2!V86QU
M97,N<W5B<W1R:6YG*#`L('9A;'5E<RYL96YG=&@@+2`Q*3L*("`@('T*("`@
M('9A;'5E<R`K/2`G7'1<="<["B`@("!H:70@/2!F86QS93L*("`@(&9O<B`H
M=F%R(&D@/2`P.R!I(#P@<FEG:'0N;W!T:6]N<RYL96YG=&@[("LK:2D@>PH@
M("`@("`@(&EF("AI(#T](#`@)B8@(7)I9VAT6VE=+G9A;'5E*2!["B`@("`@
M("`@("`@(&-O;G1I;G5E.PH@("`@("`@('T*("`@("`@("!V86QU97,@*ST@
M<FEG:'0N;W!T:6]N<UMI72YV86QU92`K("=<="<["B`@("`@("`@:&ET(#T@
M=')U93L*("`@('T*("`@(&EF("AH:70I('L*("`@("`@("!V86QU97,@/2!V
M86QU97,N<W5B<W1R:6YG*#`L('9A;'5E<RYL96YG=&@@+2`Q*3L*("`@('T*
M("`@(&1O8W5M96YT6VYA;64@*R`G7U]V86QU97,G72YV86QU92`]('9A;'5E
M<SL*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O:G,O86QP:&%);6%G94QO861E<BYP:'``````````````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`R-S<W(#$P-3$U-#,S-S,T(#`R,C`V,0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@)$AO<F1E.B!H;W)D92]J<R]A;'!H84EM86=E3&]A9&5R+G!H
M<"QV(#$N,BXX+C0@,C`P-B\P,2\P,2`R,3HR.3HP,B!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!#:&%R;&5S($HN($AA9V5N8G5C:"`\
M8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=(
M3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD["G)E<75I
M<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8V]R92YP:'`G.PH*)')E9VES
M=')Y(#T@)E)E9VES=')Y.CIS:6YG;&5T;VXH2$]21$5?4T534TE/3E].3TY%
M*3L*"B\J(%1H:7,@<VAO=6QD(&)E(&-A8VAE9"X@*B\*)&UO9%]G;70@/2!G
M;61A=&4H)T0L(&0@32!9($@Z:3IS)RP@9FEL96UT:6UE*%]?1DE,15]?*2D@
M+B`G($=-5"<["FAE861E<B@G3&%S="U-;V1I9FEE9#H@)R`N("1M;V1?9VUT
M*3L*:&5A9&5R*"=#86-H92U#;VYT<F]L.B!P=6)L:6,L(&UA>"UA9V4].#8T
M,#`G*3L*:&5A9&5R*"=#;VYT96YT+51Y<&4Z('1E>'0O>"UC;VUP;VYE;G0G
M*3L*"C\^"CQP=6)L:6,Z8V]M<&]N96YT/@H\<'5B;&EC.F%T=&%C:"!E=F5N
M=#TB;VYP<F]P97)T>6-H86YG92(@9F]R/2)E;&5M96YT(B!O;D5V96YT/2)P
M<F]P97)T>4-H86YG960H*2(@+SX*/'-C<FEP=#X*"G9A<B!T<F%N<W!A<F5N
M=$EM86=E(#T@(CP_<&AP(&5C:&\@)')E9VES=')Y+3YG971);6%G941I<B@G
M:&]R9&4G*2`_/B]B;&%N:RYG:68B.PH*<&YG2&%C:R@I.PH*9G5N8W1I;VX@
M<')O<&5R='E#:&%N9V5D*"D*>PH@("`@:68@*&5V96YT+G!R;W!E<G1Y3F%M
M92`]/2`B<W)C(BD@>PH@("`@("`@('!N9TAA8VLH*3L*("`@('T*?0H*9G5N
M8W1I;VX@<&YG2&%C:R@I"GL*("`@('9A<B!W(#T@96QE;65N="YW:61T:#L*
M("`@('9A<B!H(#T@96QE;65N="YH96EG:'0["B`@("!V87(@<W)C(#T@96QE
M;65N="YS<F,["B`@("!I9B`H<W)C+FEN9&5X3V8H=')A;G-P87)E;G1);6%G
M92D@(3T@+3$I('L*("`@("`@("`O+R!!;')E861Y(&9I>&5D+@H@("`@("`@
M(')E='5R;CL*("`@('T*"B`@("!I9B`H<W)C+FEN9&5X3V8H(G!N9R(I(#T]
M("TQ*2!["B`@("`@("`@96QE;65N="YR=6YT:6UE4W1Y;&4N9FEL=&5R(#T@
M(B(["B`@("`@("`@<F5T=7)N.PH@("`@?0H*("`@(&5L96UE;G0N<W)C(#T@
M=')A;G-P87)E;G1);6%G93L*("`@(&5L96UE;G0N=VED=&@@/2!W.PH@("`@
M96QE;65N="YH96EG:'0@/2!H.PH@("`@96QE;65N="YR=6YT:6UE4W1Y;&4N
M9FEL=&5R(#T@(G!R;V=I9#I$6$EM86=E5')A;G-F;W)M+DUI8W)O<V]F="Y!
M;'!H84EM86=E3&]A9&5R*'-R8STG(B`K('-R8R`K("(G+'-I>FEN9TUE=&AO
M9#TG<V-A;&4G*2(["GT*"CPO<V-R:7!T/@H\+W!U8FQI8SIC;VUP;VYE;G0^
M"@!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]J<R]H;W)D92YJ<P``````````
M````````````````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,34V
M,S8@,3`U,34T,S,W,S0@,#$W-C(V`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"\J*@H@*B!'96YE<F%L($AO<F1E(%5)(&5F
M9F5C=',@:F%V87-C<FEP="X*("H*("H@)$AO<F1E.B!H;W)D92]J<R]H;W)D
M92YJ<RQV(#$N,30N,BXU(#(P,#8O,#4O,C4@,3@Z,#<Z,C8@<VQU<V%R>B!%
M>'`@)`H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60@;F]T"B`J
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("HO"@IV87(@5&]O;%1I<',@/2!["B`@("!#
M55)214Y4.B!N=6QL+`H@("`@5$E-14]55#H@;G5L;"P*("`@($Q)3DLZ(&YU
M;&PL"@H@("`@871T86-H0F5H879I;W(Z(&9U;F-T:6]N*"D*("`@('L*("`@
M("`@("!L:6YK<R`](&1O8W5M96YT+F=E=$5L96UE;G1S0GE486=.86UE*"=A
M)RD["B`@("`@("`@9F]R("AI(#T@,#L@:2`\(&QI;FMS+FQE;F=T:#L@:2LK
M*2!["B`@("`@("`@("`@(&EF("AL:6YK<UMI72YT:71L92D@>PH@("`@("`@
M("`@("`@("`@;&EN:W-;:5TN<V5T071T<FEB=71E*"=N:6-E=&ET;&4G+"!L
M:6YK<UMI72YT:71L92D["B`@("`@("`@("`@("`@("!L:6YK<UMI72YR96UO
M=F5!='1R:6)U=&4H)W1I=&QE)RD["@H@("`@("`@("`@("`@("`@861D179E
M;G0H;&EN:W-;:5TL("=M;W5S96]V97(G+"!4;V]L5&EP<RYO=F5R*3L*("`@
M("`@("`@("`@("`@(&%D9$5V96YT*&QI;FMS6VE=+"`G;6]U<V5O=70G+"!4
M;V]L5&EP<RYO=70I.PH@("`@("`@("`@("`@("`@861D179E;G0H;&EN:W-;
M:5TL("=F;V-U<R<L(%1O;VQ4:7!S+F]V97(I.PH@("`@("`@("`@("`@("`@
M861D179E;G0H;&EN:W-;:5TL("=B;'5R)RP@5&]O;%1I<',N;W5T*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@('TL"@H@("`@;W9E<CH@9G5N8W1I
M;VXH92D*("`@('L*("`@("`@("!I9B`H='EP96]F(%1O;VQ4:7!S(#T]("=U
M;F1E9FEN960G*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@
M("`@("`@(&EF("A4;V]L5&EP<RY424U%3U54*2!["B`@("`@("`@("`@('=I
M;F1O=RYC;&5A<E1I;65O=70H5&]O;%1I<',N5$E-14]55"D["B`@("`@("`@
M?0H*("`@("`@("!I9B`H=VEN9&]W+F5V96YT("8F('=I;F1O=RYE=F5N="YS
M<F-%;&5M96YT*2!["B`@("`@("`@("`@(%1O;VQ4:7!S+DQ)3DL@/2!W:6YD
M;W<N979E;G0N<W)C16QE;65N=#L*("`@("`@("!](&5L<V4@:68@*&4@)B8@
M92YT87)G970I('L*("`@("`@("`@("`@5&]O;%1I<',N3$E.2R`](&4N=&%R
M9V5T.PH@("`@("`@('T*"B`@("`@("`@5&]O;%1I<',N5$E-14]55"`]('=I
M;F1O=RYS9714:6UE;W5T*"=4;V]L5&EP<RYS:&]W*"DG+"`S,#`I"B`@("!]
M+`H*("`@(&]U=#H@9G5N8W1I;VXH*0H@("`@>PH@("`@("`@(&EF("AT>7!E
M;V8@5&]O;%1I<',@/3T@)W5N9&5F:6YE9"<I('L*("`@("`@("`@("`@<F5T
M=7)N.PH@("`@("`@('T*"B`@("`@("`@:68@*%1O;VQ4:7!S+E1)345/550I
M('L*("`@("`@("`@("`@=VEN9&]W+F-L96%R5&EM96]U="A4;V]L5&EP<RY4
M24U%3U54*3L*("`@("`@("!]"@H@("`@("`@(&EF("A4;V]L5&EP<RY#55)2
M14Y4*2!["B`@("`@("`@("`@(&1O8W5M96YT+F=E=$5L96UE;G1S0GE486=.
M86UE*"=B;V1Y)RE;,%TN<F5M;W9E0VAI;&0H5&]O;%1I<',N0U524D5.5"D[
M"B`@("`@("`@("`@(%1O;VQ4:7!S+D-54E)%3E0@/2!N=6QL.PH*("`@("`@
M("`@("`@=F%R(&EF<F%M92`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=I
M9G)A;65?='0G*3L*("`@("`@("`@("`@:68@*&EF<F%M92`A/2!N=6QL*2![
M"B`@("`@("`@("`@("`@("!I9G)A;64N<W1Y;&4N9&ES<&QA>2`]("=N;VYE
M)SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('TL"@H@("`@<VAO=SH@
M9G5N8W1I;VXH*0H@("`@>PH@("`@("`@(&EF("AT>7!E;V8@5&]O;%1I<',@
M/3T@)W5N9&5F:6YE9"<@?'P@(51O;VQ4:7!S+DQ)3DLI('L*("`@("`@("`@
M("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@:68@*%1O;VQ4:7!S+D-5
M4E)%3E0I('L*("`@("`@("`@("`@5&]O;%1I<',N;W5T*"D["B`@("`@("`@
M?0H*("`@("`@("!L:6YK(#T@5&]O;%1I<',N3$E.2SL*("`@("`@("!W:&EL
M92`H(6QI;FLN9V5T071T<FEB=71E*"=N:6-E=&ET;&4G*2`F)B!L:6YK+FYO
M9&5.86UE+G1O3&]W97)#87-E*"D@(3T@)V)O9'DG*2!["B`@("`@("`@("`@
M(&QI;FL@/2!L:6YK+G!A<F5N=$YO9&4["B`@("`@("`@?0H@("`@("`@(&YI
M8V5T:71L92`](&QI;FLN9V5T071T<FEB=71E*"=N:6-E=&ET;&4G*3L*("`@
M("`@("!I9B`H(6YI8V5T:71L92D@>PH@("`@("`@("`@("!R971U<FX["B`@
M("`@("`@?0H*("`@("`@("!D(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G
M9&EV)RD["B`@("`@("`@9"YC;&%S<TYA;64@/2`G;FEC971I=&QE)SL*("`@
M("`@("!D+FEN;F5R2%1-3"`](&YI8V5T:71L93L*"B`@("`@("`@4U1$7U=)
M1%1((#T@,3`P.PH@("`@("`@($U!6%]724142"`](#8P,#L*("`@("`@("!I
M9B`H=VEN9&]W+FEN;F5R5VED=&@I('L*("`@("`@("`@("`@34%87U=)1%1(
M(#T@36%T:"YM:6XH34%87U=)1%1(+"!W:6YD;W<N:6YN97)7:61T:"`M(#(P
M*3L*("`@("`@("!]"B`@("`@("`@:68@*&1O8W5M96YT+F)O9'D@)B8@9&]C
M=6UE;G0N8F]D>2YS8W)O;&Q7:61T:"D@>PH@("`@("`@("`@("!-05A?5TE$
M5$@@/2!-871H+FUI;BA-05A?5TE$5$@L(&1O8W5M96YT+F)O9'DN<V-R;VQL
M5VED=&@@+2`R,"D["B`@("`@("`@?0H*("`@("`@("!N:6-E=&ET;&5?;&5N
M9W1H(#T@,#L*("`@("`@("!L:6YE<R`](&YI8V5T:71L92YR97!L86-E*"\\
M8G(@/UPO/B]G+"`B7&XB*2YS<&QI="@B7&XB*3L*("`@("`@("!F;W(@*&D@
M/2`P.R!I(#P@;&EN97,N;&5N9W1H.R!I*RLI('L*("`@("`@("`@("`@;FEC
M971I=&QE7VQE;F=T:"`]($UA=&@N;6%X*&YI8V5T:71L95]L96YG=&@L(&QI
M;F5S6VE=+FQE;F=T:"D["B`@("`@("`@?0H*("`@("`@("!H7W!I>&5L<R`]
M(&YI8V5T:71L95]L96YG=&@@*B`W.PH@("`@("`@('1?<&EX96QS(#T@;FEC
M971I=&QE7VQE;F=T:"`J(#$P.PH*("`@("`@("!I9B`H:%]P:7AE;',@/B!3
M5$1?5TE$5$@I('L*("`@("`@("`@("`@=R`](&A?<&EX96QS.PH@("`@("`@
M('T@96QS92!I9B`H4U1$7U=)1%1((#X@=%]P:7AE;',I('L*("`@("`@("`@
M("`@=R`]('1?<&EX96QS.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M('<@/2!35$1?5TE$5$@["B`@("`@("`@?0H*("`@("`@("!M<&]S(#T@9FEN
M9%!O<RAL:6YK*3L*("`@("`@("!M>"`](&UP;W-;,%T["B`@("`@("`@;7D@
M/2!M<&]S6S%=.PH*("`@("`@("!L969T(#T@;7@@*R`R,#L*("`@("`@("!I
M9B`H=VEN9&]W+FEN;F5R5VED=&@@)B8@*"AL969T("L@=RD@/B!W:6YD;W<N
M:6YN97)7:61T:"DI('L*("`@("`@("`@("`@;&5F="`]('=I;F1O=RYI;FYE
M<E=I9'1H("T@=R`M(#0P.PH@("`@("`@('T*("`@("`@("!I9B`H9&]C=6UE
M;G0N8F]D>2`F)B!D;V-U;65N="YB;V1Y+G-C<F]L;%=I9'1H("8F("@H;&5F
M="`K('<I(#X@9&]C=6UE;G0N8F]D>2YS8W)O;&Q7:61T:"DI('L*("`@("`@
M("`@("`@;&5F="`](&1O8W5M96YT+F)O9'DN<V-R;VQL5VED=&@@+2!W("T@
M,C4["B`@("`@("`@?0H*("`@("`@("!D+FED(#T@)W1O;VQ4:7`G.PH@("`@
M("`@(&0N<W1Y;&4N;&5F="`]($UA=&@N;6%X*&QE9G0L(#4I("L@)W!X)SL*
M("`@("`@("!D+G-T>6QE+G=I9'1H(#T@36%T:"YM:6XH=RP@34%87U=)1%1(
M*2`K("=P>"<["B`@("`@("`@9"YS='EL92YT;W`@/2`H;7D@*R`R,"D@*R`G
M<'@G.PH@("`@("`@(&0N<W1Y;&4N9&ES<&QA>2`](")B;&]C:R(["@H@("`@
M("`@('1R>2!["B`@("`@("`@("`@(&1O8W5M96YT+F=E=$5L96UE;G1S0GE4
M86=.86UE*"=B;V1Y)RE;,%TN87!P96YD0VAI;&0H9"D["B`@("`@("`@("`@
M(%1O;VQ4:7!S+D-54E)%3E0@/2!D.PH*("`@("`@("`@("`@:68@*'1Y<&5O
M9B!4;V]L5&EP<U]/<'1I;VY?5VEN9&]W961?0V]N=')O;',@(3T@)W5N9&5F
M:6YE9"<I('L*("`@("`@("`@("`@("`@('9A<B!I9G)A;64@/2!D;V-U;65N
M="YG971%;&5M96YT0GE)9"@G:69R86UE7W1T)RD["B`@("`@("`@("`@("`@
M("!I9B`H:69R86UE(#T](&YU;&PI('L*("`@("`@("`@("`@("`@("`@("!I
M9G)A;64@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"(\:69R86UE('-R8STG
M:F%V87-C<FEP=#IF86QS93LG(&YA;64])VEF<F%M95]T="<@:60])VEF<F%M
M95]T="<@<V-R;VQL:6YG/2=N;R<@9G)A;65B;W)D97(])S`G('-T>6QE/2=P
M;W-I=&EO;CIA8G-O;'5T93L@=&]P.C!P>#L@;&5F=#HP<'@[(&1I<W!L87DZ
M;F]N93LG/CPO:69R86UE/B(I.PH@("`@("`@("`@("`@("`@("`@(&1O8W5M
M96YT+F=E=$5L96UE;G1S0GE486=.86UE*"=B;V1Y)RE;,%TN87!P96YD0VAI
M;&0H:69R86UE*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&EF<F%M92YS='EL92YW:61T:"`](&0N;V9F<V5T5VED=&@["B`@("`@("`@
M("`@("`@("!I9G)A;64N<W1Y;&4N:&5I9VAT(#T@9"YO9F9S971(96EG:'0[
M"B`@("`@("`@("`@("`@("!I9G)A;64N<W1Y;&4N=&]P(#T@9"YS='EL92YT
M;W`["B`@("`@("`@("`@("`@("!I9G)A;64N<W1Y;&4N;&5F="`](&0N<W1Y
M;&4N;&5F=#L*("`@("`@("`@("`@("`@(&EF<F%M92YS='EL92YP;W-I=&EO
M;B`](")A8G-O;'5T92(["B`@("`@("`@("`@("`@("!I9G)A;64N<W1Y;&4N
M9&ES<&QA>2`](")B;&]C:R(["B`@("`@("`@("`@("`@("!D+G-T>6QE+GI)
M;F1E>"`](#$P,#L*("`@("`@("`@("`@("`@(&EF<F%M92YS='EL92YZ26YD
M97@@/2`Y.3L*("`@("`@("`@("`@?0H@("`@("`@('T@8V%T8V@@*&4I('L*
M("`@("`@("!]"B`@("!]"@I].PH*+RHJ"B`J(%)E='5R;B!T:&4@6W@L>5T@
M<&]S:71I;VX@;V8@86X@;V)J96-T+@H@*B\*9G5N8W1I;VX@9FEN9%!O<RAO
M8FHI"GL*("`@(&EF("AO8FHN;V9F<V5T4&%R96YT*2!["B`@("`@("`@9F]R
M("AP;W-8(#T@,"P@<&]S62`](#`[(&]B:BYO9F9S971087)E;G0[(&]B:B`]
M(&]B:BYO9F9S971087)E;G0I('L*("`@("`@("`@("`@<&]S6"`K/2!O8FHN
M;V9F<V5T3&5F=#L*("`@("`@("`@("`@<&]S62`K/2!O8FHN;V9F<V5T5&]P
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@6W!O<U@L('!O<UE=.PH@("`@
M?2!E;'-E('L*("`@("`@("!R971U<FX@6V]B:BYX+"!O8FHN>5T["B`@("!]
M"GT*"B\J*@H@*B!!9&0@86X@979E;G0@;&ES=&5N97(@87,@;&]N9R!A<R!T
M:&4@8G)O=W-E<B!S=7!P;W)T<R!I="X@1&EF9F5R96YT"B`J(&)R;W=S97)S
M('-T:6QL(&AA;F1L92!T:&5S92!E=F5N=',@<VQI9VAT;'D@9&EF9F5R96YT
M;'D[(&EN"B`J('!A<G1I8W5L87(@879O:60@=7-I;F<@(G1H:7,B(&EN(&5V
M96YT(&9U;F-T:6]N<RX*("H*("H@0&%U=&AO<B!38V]T="!!;F1R97<*("H@
M0&%U=&AO<B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("HO
M"F9U;F-T:6]N(&%D9$5V96YT*&]B:BP@9794>7!E+"!F;BD*>PH@("`@:68@
M*&]B:BYA9&1%=F5N=$QI<W1E;F5R*2!["B`@("`@("`@;V)J+F%D9$5V96YT
M3&ES=&5N97(H9794>7!E+"!F;BP@=')U92D["B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!](&5L<V4@:68@*&]B:BYA='1A8VA%=F5N="D@>PH@("`@("`@
M('9A<B!R(#T@;V)J+F%T=&%C:$5V96YT*"=O;B<@*R!E=E1Y<&4L(&9N*3L*
M("`@("`@("!%=F5N=$-A8VAE+F%D9"AO8FHL(&5V5'EP92P@9FXI.PH@("`@
M("`@(')E='5R;B!R.PH@("`@?2!E;'-E('L*("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"GT*"G9A<B!%=F5N=$-A8VAE(#T@9G5N8W1I;VXH*0I["B`@
M("!V87(@;&ES=$5V96YT<R`](%M=.PH*("`@(')E='5R;B!["B`@("`@("`@
M;&ES=$5V96YT<SH@;&ES=$5V96YT<RP*"B`@("`@("`@861D.B!F=6YC=&EO
M;BAN;V1E+"!S179E;G1.86UE+"!F2&%N9&QE<BP@8D-A<'1U<F4I"B`@("`@
M("`@>PH@("`@("`@("`@("!L:7-T179E;G1S+G!U<V@H87)G=6UE;G1S*3L*
M("`@("`@("!]+`H*("`@("`@("!F;'5S:#H@9G5N8W1I;VXH*0H@("`@("`@
M('L*("`@("`@("`@("`@=F%R(&DL(&ET96T["B`@("`@("`@("`@(&9O<B`H
M:2`](&QI<W1%=F5N=',N;&5N9W1H("T@,3L@:2`^/2`P.R!I(#T@:2`M(#$I
M('L*("`@("`@("`@("`@("`@(&ET96T@/2!L:7-T179E;G1S6VE=.PH*("`@
M("`@("`@("`@("`@(&EF("AI=&5M6S!=+G)E;6]V945V96YT3&ES=&5N97(I
M('L*("`@("`@("`@("`@("`@("`@("!I=&5M6S!=+G)E;6]V945V96YT3&ES
M=&5N97(H:71E;5LQ72P@:71E;5LR72P@:71E;5LS72D["B`@("`@("`@("`@
M("`@("!].PH*("`@("`@("`@("`@("`@("\J($9R;VT@=&AI<R!P;VEN="!O
M;B!W92!N965D('1H92!E=F5N="!N86UE<R!T;R!B90H@("`@("`@("`@("`@
M("`@("H@<')E9FEX960@=VET:"`G;VXG+B`J+PH@("`@("`@("`@("`@("`@
M:68@*&ET96U;,5TN<W5B<W1R:6YG*#`L(#(I("$]("=O;B<I('L*("`@("`@
M("`@("`@("`@("`@("!I=&5M6S%=(#T@)V]N)R`K(&ET96U;,5T["B`@("`@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*&ET96U;,%TN9&5T
M86-H179E;G0I('L*("`@("`@("`@("`@("`@("`@("!I=&5M6S!=+F1E=&%C
M:$5V96YT*&ET96U;,5TL(&ET96U;,ETI.PH@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@(&ET96U;,%U;:71E;5LQ75T@/2!N=6QL.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@?3L*?2@I.PH*:68@*&1O8W5M96YT
M+F-R96%T945L96UE;G0@)B8@9&]C=6UE;G0N9V5T16QE;65N='-">51A9TYA
M;64I('L*("`@(&%D9$5V96YT*'=I;F1O=RP@)VQO860G+"!4;V]L5&EP<RYA
M='1A8VA"96AA=FEO<BD["B`@("!A9&1%=F5N="AW:6YD;W<L("=U;FQO860G
M+"!4;V]L5&EP<RYO=70I.PH@("`@861D179E;G0H=VEN9&]W+"`G=6YL;V%D
M)RP@179E;G1#86-H92YF;'5S:"D["GT*````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]J<R]O<&5N7V-O;&]R<&EC:V5R+FIS````````````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#4U-3`@,3`U,34T,S,W,S0@
M,#(R,#4T`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"\J*@H@*B!(;W)D92!#;VQO<G!I8VME<B!*879A4V-R:7!T+@H@*@H@
M*B!0<F]V:61E<R!T:&4@:F%V87-C<FEP="!T;R!C<F5A=&4@82!C;VQO<G!I
M8VME<BX*("H*("H@)$AO<F1E.B!H;W)D92]J<R]O<&5N7V-O;&]R<&EC:V5R
M+FIS+'8@,2XR(#(P,#0O,3`O,3D@,3DZ,#@Z-3,@8VAU8VL@17AP("0*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J+PH*9G5N8W1I;VX@;W!E;D-O;&]R4&EC:V5R*'1A<F=E
M="D*>PH@("`@=F%R(&QA>2`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=C
M;VQO<G!I8VME<E\G("L@=&%R9V5T*3L*("`@(&EF("AL87DN<W1Y;&4N9&ES
M<&QA>2`]/2`G8FQO8VLG*2!["B`@("`@("`@;&%Y+G-T>6QE+F1I<W!L87D@
M/2`G;F]N92<["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@(&EF
M("AL87DN9FER<W1#:&EL9"D@>PH@("`@("`@(&EF("AL87DN9FER<W1#:&EL
M9"YN;V1E5'EP92`]/2`Q*2!["B`@("`@("`@("`@(&QA>2YS='EL92YD:7-P
M;&%Y(#T@)V)L;V-K)SL*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@;&%Y+G)E;6]V94-H
M:6QD*&QA>2YF:7)S=$-H:6QD*3L*("`@("`@("!]"B`@("!]"@H@("`@=F%R
M('1A8FQE(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G=&%B;&4G*3L*("`@
M('9A<B!T8F]D>2`](&1O8W5M96YT+F-R96%T945L96UE;G0H)W1B;V1Y)RD[
M"B`@("!T86)L92YA<'!E;F1#:&EL9"AT8F]D>2D["B`@("!T86)L92YC96QL
M4W!A8VEN9R`](#`["B`@("!T86)L92YB;W)D97(@/2`P.PH@("`@=&%B;&4N
M<W1Y;&4N8W5R<V]R(#T@)V-R;W-S:&%I<B<["B`@("!T86)L92YO;FUO=7-E
M;W5T(#T@9G5N8W1I;VXH*2!["B`@("`@("`@9&]C=6UE;G0N9V5T16QE;65N
M=$)Y260H)V-O;&]R9&5M;U\G("L@=&%R9V5T*2YS='EL92YB86-K9W)O=6YD
M0V]L;W(@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"AT87)G970I+G9A;'5E
M.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O+R!4:&4@<&%L
M971T90H@("`@<B`](#`[(&<@/2`P.R!B(#T@,#L*("`@(&9O<B`H8B`](#`[
M(&(@/"`V.R!B*RLI('L*("`@("`@("!R;W<@/2!D;V-U;65N="YC<F5A=&5%
M;&5M96YT*"=T<B<I.PH@("`@("`@(&-O;&]R(#T@;6%K94-O;&]R*&(@*B`U
M,2P@8B`J(#4Q+"!B("H@-3$I.PH@("`@("`@(&-E;&P@/2!M86ME0V5L;"AT
M87)G970L(&-O;&]R*3L*("`@("`@("!R;W<N87!P96YD0VAI;&0H8V5L;"D[
M"B`@("`@("`@9F]R("AG(#T@,#L@9R`\(#8[(&<K*RD@>PH@("`@("`@("`@
M("!F;W(@*'(@/2`P.R!R(#P@-CL@<BLK*2!["B`@("`@("`@("`@("`@("!I
M9B`H<B`A/2!B("8F(&(@(3T@9RD@>PH@("`@("`@("`@("`@("`@("`@(&-O
M;&]R(#T@;6%K94-O;&]R*'(@*B`U,2P@9R`J(#4Q+"!B("H@-3$I.PH@("`@
M("`@("`@("`@("`@("`@(&-E;&P@/2!M86ME0V5L;"AT87)G970L(&-O;&]R
M*3L*("`@("`@("`@("`@("`@("`@("!R;W<N87!P96YD0VAI;&0H8V5L;"D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("`@("`@=&)O9'DN87!P96YD0VAI;&0H<F]W*3L*("`@('T*"B`@("!T86)L
M92YA<'!E;F1#:&EL9"AT8F]D>2D["B`@("!L87DN87!P96YD0VAI;&0H=&%B
M;&4I.PH@("`@;&%Y+G-T>6QE+F1I<W!L87D@/2`G8FQO8VLG.PI]"@IF=6YC
M=&EO;B!M86ME0V5L;"AT87)G970L(&-O;&]R*0I["B`@("!C96QL(#T@9&]C
M=6UE;G0N8W)E871E16QE;65N="@G=&0G*3L*("`@(&-E;&PN:&5I9VAT(#T@
M,SL*("`@(&-E;&PN=VED=&@@/2`V.PH@("`@8V5L;"YI9"`](&-O;&]R.PH@
M("`@8V5L;"YS='EL92YB86-K9W)O=6YD0V]L;W(@/2!C;VQO<CL*("`@(&-E
M;&PN;VYM;W5S96]V97(@/2!F=6YC=&EO;B@I('L*("`@("`@("!D;V-U;65N
M="YG971%;&5M96YT0GE)9"@G8V]L;W)D96UO7R<@*R!T87)G970I+G-T>6QE
M+F)A8VMG<F]U;F1#;VQO<B`]('1H:7,N<W1Y;&4N8F%C:V=R;W5N9$-O;&]R
M.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*("`@(&-E;&PN;VYC;&EC
M:R`](&9U;F-T:6]N*"D@>PH@("`@("`@(&1O8W5M96YT+F=E=$5L96UE;G1"
M>4ED*"=C;VQO<F1E;6]?)R`K('1A<F=E="DN<W1Y;&4N8F%C:V=R;W5N9$-O
M;&]R(#T@=&AI<RYS='EL92YB86-K9W)O=6YD0V]L;W(["B`@("`@("`@9&]C
M=6UE;G0N9V5T16QE;65N=$)Y260H=&%R9V5T*2YV86QU92`]('1H:7,N:60[
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@(')E='5R;B!C96QL
M.PI]"@IF=6YC=&EO;B!M86ME0V]L;W(H<BP@9RP@8BD*>PH@("`@8V]L;W(@
M/2`B(R(["B`@("!C;VQO<B`K/2!H97@H36%T:"YF;&]O<BAR("\@,38I*3L*
M("`@(&-O;&]R("L](&AE>"AR("4@,38I.PH@("`@8V]L;W(@*ST@:&5X*$UA
M=&@N9FQO;W(H9R`O(#$V*2D["B`@("!C;VQO<B`K/2!H97@H9R`E(#$V*3L*
M("`@(&-O;&]R("L](&AE>"A-871H+F9L;V]R*&(@+R`Q-BDI.PH@("`@8V]L
M;W(@*ST@:&5X*&(@)2`Q-BD["B`@("!R971U<FX@8V]L;W(["GT*"F9U;F-T
M:6]N(&AE>"A$96,I"GL*("`@(&EF("A$96,@/3T@,3`I(')E='5R;B`B82([
M"B`@("!I9B`H1&5C(#T](#$Q*2!R971U<FX@(F(B.PH@("`@:68@*$1E8R`]
M/2`Q,BD@<F5T=7)N(")C(CL*("`@(&EF("A$96,@/3T@,3,I(')E='5R;B`B
M9"(["B`@("!I9B`H1&5C(#T](#$T*2!R971U<FX@(F4B.PH@("`@:68@*$1E
M8R`]/2`Q-2D@<F5T=7)N(")F(CL*("`@(')E='5R;B`B(B`K($1E8SL*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VIS+VEM
M86=E+FIS````````````````````````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,S0T,B`Q,#4Q-30S,S<S-"`P,3<U-S<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+RHJ"B`J($AO<F1E
M($EM86=E($IA=F%S8W)I<'0*("H*("H@4')O=FED97,@=&AE(&IA=F%S8W)I
M<'0@=&\@:&5L<"!D=7)I;F<@=&AE('5P;&]A9&EN9R!O9B!I;6%G97,@:6X@
M2&]R9&5?1F]R;2X*("H*("H@)$AO<F1E.B!H;W)D92]J<R]I;6%G92YJ<RQV
M(#$N,RXT+C,@,C`P-B\P,2\P,2`R,3HR.3HP,B!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#(P,#,M,C`P-B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N
M8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60@;F]T"B`J
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("HO"@HO*BH*("H@0VAA;F=E<R!T:&4@<W)C
M(&]F(&%N(&EM86=E('1A<F=E="P@;W!T:6]N86QL>2!A='1A8VAI;F<@82!T
M:6UE('9A;'5E('1O('1H90H@*B!54DP@=&\@;6%K92!S=7)E('1H870@=&AE
M(&EM86=E(&1O97,@=7!D871E(&%N9"!N;W0@=7-E('1H92!B<F]W<V5R(&-A
M8VAE+@H@*@H@*B!`<&%R86T@<W1R:6YG('-R8R`@("`@("`@("`@("`@5&AE
M('-R;W5C92!T;R!I;G-E<G1E9"!I;G1O('1H92!I;6%G92!E;&5M96YT+@H@
M*B!`<&%R86T@<W1R:6YG('1A<F=E="`@("`@("`@("`@5&AE('1A<F=E="!E
M;&5M96YT+@H@*B!`<&%R86T@;W!T:6]N86P@8F]O;"!N;U]C86-H92`@268@
M<V5T('1O('1R=64@=VEL;"!A<'!E;F0@=&AE('1I;64N"B`J"B`J($!R971U
M<FX@8F]O;"`@1F%L<V4@=&\@<W1O<"!T:&4@8G)O=W-E<B!L;V%D:6YG(&%N
M>71H:6YG+@H@*B\*9G5N8W1I;VX@<VAO=TEM86=E*'-R8RP@=&%R9V5T+"!N
M;U]C86-H92D*>PH@("`@=F%R(&EM9R`](&1O8W5M96YT+F=E=$5L96UE;G1"
M>4ED*'1A<F=E="D["B`@("!I9B`H='EP96]F(&YO7V-A8VAE(#T]("=U;F1E
M9FEN960G*2!["B`@("`@("`@=F%R(&YO7V-A8VAE(#T@9F%L<V4["B`@("!]
M"@H@("`@:68@*&YO7V-A8VAE*2!["B`@("`@("`@=F%R(&YO=R`](&YE=R!$
M871E*"D["B`@("`@("`@<W)C(#T@<W)C("L@)R8G("L@;F]W+F=E=%1I;64H
M*3L*("`@('T*"B`@("!I;6<N<W)C(#T@<W)C.PH*("`@(')E='5R;B!F86QS
M93L*?0H*+RHJ"B`J($%D9',@=&\@=&AE(&=I=F5N('-O=7)C92!T:&4@:&5I
M9VAT+W=I9'1H(&9I96QD('9A;'5E<R!F;W(@=&AE(&=I=F5N('1A<F=E="X*
M("H*("H@0'!A<F%M('-T<FEN9R!S<F,@("`@("`@("`@(%1H92!S<F]U8V4@
M=&\@87!P96YD('1O('1H92!R97-I>F4@<&%R86US+@H@*B!`<&%R86T@<W1R
M:6YG('1A<F=E="`@("`@("`@5&AE('1A<F=E="!E;&5M96YT+@H@*B!`<&%R
M86T@;W!T:6]N86P@8F]O;"!R871I;R`@268@<V5T('1O('1R=64@=VEL;"!A
M<'!E;F0@9FEX('1H92!R871I;RX*("H*("H@0')E='5R;B!S=')I;F<@(%1H
M92!M;V1I9FEE9"!S;W5R8V4@=&\@:6YC;'5D92!T:&4@<F5S:7IE(&1A=&$N
M"B`J+PIF=6YC=&EO;B!G971297-I>F53<F,H<W)C+"!T87)G970L(')A=&EO
M*0I["B`@("!V87(@=VED=&@@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"@G
M7W=?)R`K('1A<F=E="DN=F%L=64["B`@("!V87(@:&5I9VAT(#T@9&]C=6UE
M;G0N9V5T16QE;65N=$)Y260H)U]H7R<@*R!T87)G970I+G9A;'5E.PH@("`@
M:68@*'1Y<&5O9B!R871I;R`]/2`G=6YD969I;F5D)RD@>PH@("`@("`@('9A
M<B!R871I;R`](#`["B`@("!]"@H@("`@<W)C(#T@<W)C("L@)R8G("L@)W8]
M)R`K('=I9'1H("L@)RXG("L@:&5I9VAT("L@)RXG("L@<F%T:6\["@H@("`@
M<F5T=7)N('-R8SL*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]J<R]A9&1%=F5N
M="YP:'``````````````````````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#(V-#(@,3`U,34T,S,W,S0@,#(P-#(S`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"\J*@H@*B!'96YE<FEC(&9U
M;F-T:6]N('1O(&%D9"!A;B!E=F5N="!H86YD;&5R('1O(&%N>2!$3TT@96QE
M;65N="X*("H*("H@)$AO<F1E.B!H;W)D92]J<R]A9&1%=F5N="YP:'`L=B`Q
M+C$N,BXR(#(P,#8O,#$O,#$@,C$Z,CDZ,#(@:F%N($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`R,#`U+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D
M92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"B\J*@H@*B!!9&1S('1H92!G:79E
M;B!E=F5N="!T;R!A;B!E;&5M96YT+B!)9B!T:&4@96QE;65N="!A;')E861Y
M(&AA<PH@*B!H86YD;&5R<R!F;W(@=&AE(&5V96YT+"!T:&4@;F5W(&5V96YT
M(&ES(&%P<&5N9&5D+@H@*@H@*B!`<&%R86T@;V)J96-T(&5L96UE;G0@("!4
M:&4@96QE;65N="!T;R!A9&0@=&AE(&5V96YT('1O+@H@*B!`<&%R86T@<W1R
M:6YG(&5V96YT("`@("!4:&4@;F%M92!O9B!T:&4@979E;G0N"B`J($!P87)A
M;2!S=')I;F=\9G5N8W1I;VX@9G5N8W1I;VX@(%1H92!J879A<V-R:7!T('1O
M(&5X96-U=&4N"B`J+PIF=6YC=&EO;B!A9&1%=F5N="AE;&5M96YT+"!E=F5N
M="P@8V]D92D*>PH@("`@:68@*"%E;&5M96YT*2!["B`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@?0H*("`@("\O($%S<VEG;B!N97<@86YO;GEM;W5S(&9U
M;F-T:6]N(&EF('=E)W)E('!A<W-E9"!A(&IS('-T<FEN9PH@("`@+R\@:6YS
M=&5A9"!O9B!A(&9U;F-T:6]N(')E9F5R96YC92X*("`@(&EF("AT>7!E;V8@
M8V]D92`]/2`G<W1R:6YG)RD@>PH@("`@("`@(&-O9&4@/2!N97<@1G5N8W1I
M;VXH8V]D92D["B`@("!]"@H@("`@:68@*&5L96UE;G0N861D179E;G1,:7-T
M96YE<BD@>PH@("`@("`@(&5L96UE;G0N861D179E;G1,:7-T96YE<BAE=F5N
M="YR97!L86-E*"]O;B\L("<G*2P@8V]D92P@9F%L<V4I.PH@("`@?2!E;'-E
M(&EF("AE;&5M96YT+F%T=&%C:$5V96YT*2!["B`@("`@("`@96QE;65N="YA
M='1A8VA%=F5N="AE=F5N="P@8V]D92D["B`@("!](&5L<V4@:68@*&5L96UE
M;G0N;VYL;V%D("$](&YU;&PI('L*("`@("`@("!E=F%L*"=V87(@3VQD179E
M;G0@/2!E;&5M96YT+B<@*R!E=F5N="D["B`@("`@("`@;F5W0V]D92`]($9U
M;F-T:6]N*&4I"B`@("`@("`@>PH@("`@("`@("`@("!O;&1%=F5N="AE*3L*
M("`@("`@("`@("`@8V]D92@I.PH@("`@("`@('T["B`@("`@("`@979A;"@G
M96QE;65N="XG("L@979E;G0@*R`G(#T@;F5W0V]D92<I.PH@("`@?2!E;'-E
M('L*("`@("`@("!E=F%L*"=E;&5M96YT+B<@*R!E=F5N="`K("<@/2!C;V1E
M)RD["B`@("!]"@H@("`@<F5T=7)N('1R=64["GT*````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8@``````````````````````````````````````
M```````````````````````````````````````````````````````````P
M,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<T
M,"`P,38R,C0`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U-Y;F--3```````
M````````````````````````````````````````````````````````````
M`````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P,#`P(#$P-3$U-#,S-S,T(#`Q-S,W-``@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O4WEN8TU,+T1E=FEC90``````````````````````````````````
M````````````````````````````````````````````,#`P-S4U(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S0@,#(P-3<S`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]3>6YC34PO1&5V:6-E+U-Y;F,T:BYP
M:'``````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`U-#4V,R`Q,#4Q
M-30S,S<S-"`P,C(U-3(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O:4-A;&5N
M9&%R+G!H<"<["@HO*BH*("H@4WEN8S1J("AW=W<N<WEN8S1J+F]R9RD*("H*
M("H@5&AE(%-Y;F,T2B!O=71L;V]K(&-O;G9E<G1E<B!U<V5S(&ET<R!N871I
M=F4@4TE&(&9O<FUA="!F;W(@9&%T80H@*B!E>&-H86YG92X@0V]N=F5R<VEO
M;B!T;R!T97AT+W9C86QE;F1A<B!E=&,N(&ES(&1O;F4@8GD*("H@4VEF0V]N
M=F5R=&5R+G!H<"!4:&4@8V]N;F5C=&]R('-E96US(&YO="!S=7!P;W)T($1E
M=DEN9@H@*B!I;F9O<FUA=&EO;BP@<V\@4WEN8TU,7T1E=FEC92!C86X@;VYL
M>2!D971E8W0@:70@8GD@=&AE(&1E8VEC92!)1#H*("H@<V\@:6X@=&AE(&-O
M;FYE8W1O<B!C;VYF:6=U<F%T:6]N('1H92!D979I8V4@240@;75S="!B92!S
M970@=&\*("H@)W-C+7!I;2T\='EP93XG('=H:6-H('-H;W5L9"!B92!T:&4@
M9&5F875L="!A;GEH;W<N"B`J"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@2V%R
M<W1E;B!&;W5R;6]N="`\:V%R<W1E;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U(&1I9"!N;W0*("H@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]3>6YC34PO4WEN8TU,+T1E=FEC
M92]3>6YC-&HN<&AP+'8@,2XX+C(N-"`R,#`V+S`Q+S`Q(#(Q.C(X.C,W(&IA
M;B!%>'`@)`H@*@H@*B!`875T:&]R("!+87)S=&5N($9O=7)M;VYT(#QK87)S
M=&5N0&AO<F1E+F]R9SX*("H@0'!A8VMA9V4@4WEN8TU,"B`J+PIC;&%S<R!3
M>6YC34Q?1&5V:6-E7W-Y;F,T:B!E>'1E;F1S(%-Y;F--3%]$979I8V4@>PH*
M("`@("\J*@H@("`@("H@0V]N=F5R="!T:&4@8V]N=&5N="X*("`@("`J"B`@
M("`@*B!#=7)R96YT;'D@<W1R:7!S('5I9"`H<')I;6%R>2!K97DI(&EN9F]R
M;6%T:6]N(&%S(&-L:65N="!A;F0*("`@("`J('-E<G9E<B!M:6=H="!U<V4@
M9&EF9F5R96YT(&]N97,N"B`@("`@*@H@("`@("H@0VAA<G-E="!C;VYV97)S
M:6]N<R!M:6=H="!B92!A9&1E9"!H97)E('1O;RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@8V]N=F5R=$-L:65N=#)397)V97(H)&-O;G1E;G0L("1C;VYT96YT
M5'EP92D*("`@('L*("`@("`@("!L:7-T*"1C;VYT96YT+"`D8V]N=&5N=%1Y
M<&4I(#T*("`@("`@("`@("`@<&%R96YT.CIC;VYV97)T0VQI96YT,E-E<G9E
M<B@D8V]N=&5N="P@)&-O;G1E;G14>7!E*3L*"B`@("`@("`@<W=I=&-H("@D
M8V]N=&5N=%1Y<&4I('L*("`@("`@("!C87-E("=S:68O;F]T92<@.@H@("`@
M("`@(&-A<V4@)W1E>'0O>"US-&HM<VEF;B<@.@H@("`@("`@("`@("`D8V]N
M=&5N="`]("1T:&ES+3YS:68R=FYO=&4H8F%S938T7V1E8V]D92@D8V]N=&5N
M="DI.PH@("`@("`@("`@("`D8V]N=&5N=%1Y<&4@/2`G=&5X="]X+79N;W1E
M)SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)W-I9B]C;VYT
M86-T)R`Z"B`@("`@("`@8V%S92`G=&5X="]X+7,T:BUS:69C)R`Z"B`@("`@
M("`@("`@("1C;VYT96YT(#T@)'1H:7,M/G-I9C)V8V%R9"AB87-E-C1?9&5C
M;V1E*"1C;VYT96YT*2D["B`@("`@("`@("`@("1C;VYT96YT5'EP92`]("=T
M97AT+W@M=F-A<F0G.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S
M92`G<VEF+V-A;&5N9&%R)R`Z"B`@("`@("`@8V%S92`G=&5X="]X+7,T:BUS
M:69E)R`Z"B`@("`@("`@("`@("1C;VYT96YT(#T@)'1H:7,M/G-I9C)V979E
M;G0H8F%S938T7V1E8V]D92@D8V]N=&5N="DI.PH@("`@("`@("`@("`D8V]N
M=&5N=%1Y<&4@/2`G=&5X="]X+79E=F5N="<["B`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("!C87-E("=S:68O=&%S:R<@.@H@("`@("`@(&-A<V4@)W1E
M>'0O>"US-&HM<VEF="<@.@H@("`@("`@("`@("`D8V]N=&5N="`]("1T:&ES
M+3YS:68R=G1O9&\H8F%S938T7V1E8V]D92@D8V]N=&5N="DI.PH@("`@("`@
M("`@("`D8V]N=&5N=%1Y<&4@/2`G=&5X="]X+79T;V1O)SL*("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("!I9B`H1$5"54=,3T=?24-!
M3$5.1$%21$%402D@>PH@("`@("`@("`@("`D9G`@/2!`9F]P96XH)R]T;7`O
M<WEN8R]L;V<N='AT)RP@)V$G*3L*("`@("`@("`@("`@:68@*"1F<"D@>PH@
M("`@("`@("`@("`@("`@0&9W<FET92@D9G`L(")<;FEN<'5T(&-O;G9E<G1E
M9"!F;W(@<V5R=F5R.B`D8V]N=&5N=%1Y<&5<;B(I.PH@("`@("`@("`@("`@
M("`@0&9W<FET92@D9G`L)&-O;G1E;G0@+B`B7&XB*3L*("`@("`@("`@("`@
M("`@($!F8VQO<V4H)&9P*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N(&%R<F%Y*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R=',@=&AE(&-O;G1E;G0@9G)O
M;2!T:&4@8F%C:V5N9"!T;R!A(&9O<FUA="!S=6ET86)L92!F;W(@=&AE"B`@
M("`@*B!C;&EE;G0@9&5V:6-E+@H@("`@("H*("`@("`J(%-T<FEP<R!T:&4@
M=6ED("AP<FEM87)Y(&ME>2D@:6YF;W)M871I;VX@87,@8VQI96YT(&%N9"!S
M97)V97(@;6EG:'0@=7-E"B`@("`@*B!D:69F97)E;G0@;VYE<RX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VYT96YT("`@("`@(%1H92!C;VYT
M96YT('1O(&-O;G9E<G0*("`@("`J($!P87)A;2!S=')I;F<@)&-O;G1E;G14
M>7!E("`@5&AE(&-O;G1E;G14>7!E(&]F(&-O;G1E;G0@87,@<F5T=7)N960@
M9G)O;0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@
M8F%C:V5N9`H@("`@("H@0')E='5R;B!A<G)A>2`@("`@("`@("`@("`@("!A
M<G)A>2@D;F5W8V]N=&5N="P@)&YE=V-O;G1E;G14>7!E*3H*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&-O;G9E<G1E9"!C;VYT
M96YT(&%N9"!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@*'!O<W-I8FQY(&-H86YG960I(&YE=R!#;VYT96YT5'EP92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@8V]N=F5R=%-E<G9E<C)#;&EE;G0H)&-O;G1E;G0L
M("1C;VYT96YT5'EP92D*("`@('L*("`@("`@("!G;&]B86P@)&)A8VME;F0[
M"@H@("`@("`@(&QI<W0H)&-O;G1E;G0L("1C;VYT96YT5'EP92D@/0H@("`@
M("`@("`@("!P87)E;G0Z.F-O;G9E<G1397)V97(R0VQI96YT*"1C;VYT96YT
M+"`D8V]N=&5N=%1Y<&4I.PH*("`@("`@("!S=VET8V@@*"1C;VYT96YT5'EP
M92D@>PH@("`@("`@(&-A<V4@)W1E>'0O8V%L96YD87(G(#H*("`@("`@("!C
M87-E("=T97AT+W@M:6-A;&5N9&%R)R`Z"B`@("`@("`@8V%S92`G=&5X="]X
M+79C86QE;F1A<B<@.@H@("`@("`@(&-A<V4@)W1E>'0O>"UV979E;G0G(#H*
M("`@("`@("`@("`@)&-O;G1E;G0@/2`D=&AI<RT^=F5V96YT,G-I9B@D8V]N
M=&5N="D["B`@("`@("`@("`@("1C;VYT96YT(#T@8F%S938T7V5N8V]D92@D
M8V]N=&5N="D["B`@("`@("`@("`@("1C;VYT96YT5'EP92`]("=S:68O8V%L
M96YD87(G.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G=&5X
M="]X+79T;V1O)R`Z"B`@("`@("`@("`@("1C;VYT96YT(#T@)'1H:7,M/G9T
M;V1O,G-I9B@D8V]N=&5N="D["B`@("`@("`@("`@("1C;VYT96YT(#T@8F%S
M938T7V5N8V]D92@D8V]N=&5N="D["B`@("`@("`@("`@("1C;VYT96YT5'EP
M92`]("=S:68O=&%S:R<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C
M87-E("=T97AT+W@M=F-A<F0G(#H*("`@("`@("`@("`@)&-O;G1E;G0@/2`D
M=&AI<RT^=F-A<F0R<VEF*"1C;VYT96YT*3L*("`@("`@("`@("`@)&-O;G1E
M;G0@/2!B87-E-C1?96YC;V1E*"1C;VYT96YT*3L*("`@("`@("`@("`@)&-O
M;G1E;G14>7!E(#T@)W-I9B]C;VYT86-T)SL*("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@(&-A<V4@)W1E>'0O>"UV;F]T92<Z"B`@("`@("`@("`@("1C
M;VYT96YT(#T@)'1H:7,M/G9N;W1E,G-I9B@D8V]N=&5N="D["B`@("`@("`@
M("`@("1C;VYT96YT(#T@8F%S938T7V5N8V]D92@D8V]N=&5N="D["B`@("`@
M("`@("`@("1C;VYT96YT5'EP92`]("=S:68O;F]T92<["B`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@:68@*$1%0E5'3$]'7TE#04Q%
M3D1!4D1!5$$I('L*("`@("`@("`@("`@)&9P(#T@0&9O<&5N*"<O=&UP+W-Y
M;F,O;&]G+G1X="<L("=A)RD["B`@("`@("`@("`@(&EF("@D9G`I('L*("`@
M("`@("`@("`@("`@($!F=W)I=&4H)&9P+"!S97)I86QI>F4H)&-O;G1E;G14
M>7!E*2D["B`@("`@("`@("`@("`@("!`9G=R:71E*"1F<"P@(EQN8V]N=F5R
M=&5D(&9O<B!S>6YC-&H@8VQI96YT.B`D8V]N=&5N=%1Y<&5<;B(I.PH@("`@
M("`@("`@("`@("`@0&9W<FET92@D9G`L(&)A<V4V-%]D96-O9&4H)&-O;G1E
M;G0I("X@(EQN(BD["B`@("`@("`@("`@("`@("!`9F-L;W-E*"1F<"D["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A>2@D
M8V]N=&5N="P@)&-O;G1E;G14>7!E*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($1E8V]D97,@82!S:68@>&UL('-T<FEN9R!T;R!A;B!A<W-O8VEA=&EV92!A
M<G)A>2X*("`@("`J"B`@("`@*B!1=6EC:R!H86-K('1O(&-O;G9E<G0@9G)O
M;2!T97AT+W9C87)D(&%N9"!T97AT+W9C86QE;F1A<B!T;PH@("`@("H@4WEN
M8S1*)W,@<')O<')I971E<GD@<VEF(&1A=&%T>7!E<R!A;F0@=FEC92!V97)S
M82X@($9O<B!D971A:6QS"B`@("`@*B!A8F]U="!T:&4@<VEF(&9O<FUA="!S
M964@=&AE(&%P<&5N9&EX(&]F('1H92!D979E;&]P97(@9W5I9&4@;VX*("`@
M("`J('=W=RYS>6YC-&HN;W)G+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-I9B`@02!S:68@
M<W1R:6YG(&QI:V4@/&LQ/G8Q)F=T.SPO:S$^/&LR/G8R/"]K,CX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!<W-O8R!A<G)A>2!I;B!U=&8X(&QI
M:V4@87)R87D@*"=K,2<@/3X@)W8Q/B<L("=K,B<@/3X@)W8R)RD["B`@("`@
M*B\*("`@(&9U;F-T:6]N('-I9C)A<G)A>2@D<VEF*0H@("`@>PH@("`@("`@
M("1R(#T@87)R87DH*3L*("`@("`@("!I9B`H<')E9U]M871C:%]A;&PH)R\\
M*%M>/ETJ*3XH6UX\72HI/%PO7#$^+W-I)RP@)'-I9BP@)&UA=&-H97,L(%!2
M14=?4T547T]21$52*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D;6%T8VAE
M<R!A<R`D;6%T8V@I('L*("`@("`@("`@("`@("`@("1R6R1M871C:%LQ75T@
M/2!H=&UL7V5N=&ET>5]D96-O9&4H)&UA=&-H6S)=*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!R971U<FX@)'(["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!%;F-O9&5S(&%N(&%S<V]C+B!A<G)A>2!T;R!S:68@>&UL"B`@
M("`@*@H@("`@("H@475I8VL@:&%C:R!T;R!C;VYV97)T(&9R;VT@=&5X="]V
M8V%R9"!A;F0@=&5X="]V8V%L96YD87(@=&\*("`@("`J(%-Y;F,T2B=S('!R
M;W!R:65T97)Y('-I9B!D871A='EP97,@86YD('9I8V4@=F5R<V$N("!&;W(@
M9&5T86EL<PH@("`@("H@86)O=70@=&AE('-I9B!F;W)M870@<V5E('1H92!A
M<'!E;F1I>"!O9B!T:&4@9&5V96QO<&5R(&=U:61E(&]N"B`@("`@*B!W=W<N
M<WEN8S1J+F]R9RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@87)R87D@)&%R<F%Y("!!;B!A<W-O8R!A<G)A
M>2X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E<W5L=&EN
M9R!834P@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!A<G)A>3)S:68H
M)&%R<F%Y+"`D<')E/2<G+"`D<&]S=#TG)RD*("`@('L*("`@("`@("`D<V5A
M<F-H(#T@87)R87DH)SPG+"`G/B<I.PH@("`@("`@("1R97!L86-E(#T@87)R
M87DH)R9L=#LG+"`G)F=T.R<I.PH*("`@("`@("`D<B`]("1P<F4["B`@("`@
M("`@9F]R96%C:"`H)&%R<F%Y(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@
M("`@("`@("1R("X]("<\)R`N("1K97D@+B`G/B<@+@H@("`@("`@("`@("`@
M("`@<W1R7W)E<&QA8V4H)'-E87)C:"P@)')E<&QA8V4L("1V86QU92D@+@H@
M("`@("`@("`@("`@("`@)SPO)R`N("1K97D@+B`G/B<["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)'(@+B`D<&]S=#L*("`@('T*"B`@("!F=6YC=&EO
M;B!S:68R=FYO=&4H)'-I9BD*("`@('L*("`@("`@("`D82`]("1T:&ES+3YS
M:68R87)R87DH)'-I9BD["@H@("`@("`@("1I0V%L(#T@)FYE=R!(;W)D95]I
M0V%L96YD87(H*3L*("`@("`@("`D:4-A;"T^<V5T071T<FEB=71E*"=615)3
M24].)RP@)S$N,2<I.PH@("`@("`@("1I0V%L+3YS971!='1R:6)U=&4H)U!2
M3T1)1"<L("<M+R]4:&4@2&]R9&4@4')O:F5C="\O36YE;6\@+R]%3B<I.PH@
M("`@("`@("1I0V%L+3YS971!='1R:6)U=&4H)TU%5$A/1"<L("=054),25-(
M)RD["@H@("`@("`@("1V;F]T92`]("9(;W)D95]I0V%L96YD87(Z.FYE=T-O
M;7!O;F5N="@G=FYO=&4G+"`D:4-A;"D["B`@("`@("`@)'9N;W1E+3YS971!
M='1R:6)U=&4H)T)/1%DG+"!I<W-E="@D85LG0F]D>2==*2`_("1A6R=";V1Y
M)UT@.B`G)RD["@H@("`@("`@(')E='5R;B`D=FYO=&4M/F5X<&]R='9#86QE
M;F1A<B@I.PH@("`@?0H*("`@(&9U;F-T:6]N('-I9C)V8V%R9"@D<VEF*0H@
M("`@>PH@("`@("`@("1A(#T@)'1H:7,M/G-I9C)A<G)A>2@D<VEF*3L*"B`@
M("`@("`@)&E#86P@/2`F;F5W($AO<F1E7VE#86QE;F1A<B@I.PH@("`@("`@
M("1I0V%L+3YS971!='1R:6)U=&4H)U9%4E-)3TXG+"`G,BXQ)RD["B`@("`@
M("`@)&E#86PM/G-E=$%T=')I8G5T92@G4%)/1$E$)RP@)RTO+U1H92!(;W)D
M92!0<F]J96-T+R]-;F5M;R`O+T5.)RD["B`@("`@("`@)&E#86PM/G-E=$%T
M=')I8G5T92@G34542$]$)RP@)U!50DQ)4T@G*3L*"B`@("`@("`@)'9C87)D
M(#T@)DAO<F1E7VE#86QE;F1A<CHZ;F5W0V]M<&]N96YT*"=V8V%R9"<L("1I
M0V%L*3L*"B`@("`@("`@)'9C87)D+3YS971!='1R:6)U=&4H)T9.)RP@)&%;
M)T9I;&5!<R==*3L*("`@("`@("`D=F-A<F0M/G-E=$%T=')I8G5T92@G3DE#
M2TY!344G+"`D85LG3FEC:TYA;64G72D["B`@("`@("`@)'9C87)D+3YS971!
M='1R:6)U=&4H)U1%3"<L("1A6R=(;VUE5&5L97!H;VYE3G5M8F5R)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)U194$4G/3XG2$]-
M12<I*3L*("`@("`@("`D=F-A<F0M/G-E=$%T=')I8G5T92@G5$5,)RP@)&%;
M)T)U<VEN97-S5&5L97!H;VYE3G5M8F5R)UTL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)U194$4G/3XG5T]22R<I*3L*("`@("`@("`D
M=F-A<F0M/G-E=$%T=')I8G5T92@G5$5,)RP@)&%;)TUO8FEL951E;&5P:&]N
M94YU;6)E<B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"=465!%)ST^)T-%3$PG*2D["B`@("`@("`@)'9C87)D+3YS971!='1R:6)U
M=&4H)U1%3"<L("1A6R="=7-I;F5S<T9A>$YU;6)E<B==+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=465!%)ST^)T9!6"<I*3L*("`@
M("`@("`D=F-A<F0M/G-E=$%T=')I8G5T92@G14U!24PG+"`D85LG16UA:6PQ
M061D<F5S<R==*3L*("`@("`@("`D=F-A<F0M/G-E=$%T=')I8G5T92@G5$E4
M3$4G+"`D85LG2F]B5&ET;&4G72D["B`@("`@("`@)'9C87)D+3YS971!='1R
M:6)U=&4H)T]21R<L("1A6R=#;VUP86YY3F%M92==*3L*("`@("`@("`D=F-A
M<F0M/G-E=$%T=')I8G5T92@G3D]412<L("1A6R=";V1Y)UTI.PH@("`@("`@
M("1V8V%R9"T^<V5T071T<FEB=71E*"=54DPG+"`D85LG5V5B4&%G92==*3L*
M"B`@("`@("`@)'8@/2!A<G)A>2@*("`@("`@("`@("`@5D-!4D1?3E]&04U)
M3%D@("`@("`]/B`D85LG3&%S=$YA;64G72P*("`@("`@("`@("`@5D-!4D1?
M3E]'259%3B`@("`@("`]/B`D85LG1FER<W1.86UE)UTL"B`@("`@("`@("`@
M(%9#05)$7TY?041$3"`@("`@("`@/3X@)&%;)TUI9&1L94YA;64G72P*("`@
M("`@("`@("`@5D-!4D1?3E]04D5&25@@("`@("`]/B`D85LG5&ET;&4G72P*
M("`@("`@("`@("`@5D-!4D1?3E]3549&25@@("`@("`]/B`D85LG4W5F9FEX
M)UT*("`@("`@("`I.PH@("`@("`@("1V8V%R9"T^<V5T071T<FEB=71E*"=.
M)RP@:6UP;&]D92@G.R<L("1V*2P@87)R87DH*2P@9F%L<V4L("1V*3L*"B`@
M("`@("`@)'8@/2!A<G)A>2@*("`@("`@("`@("`@5D-!4D1?04127U!/0B`@
M("`@("`@("`@/3X@)&%;)TAO;65!9&1R97-S4&]S=$]F9FEC94)O>"==+`H@
M("`@("`@("`@("!60T%21%]!1%)?15A414Y$("`@("`@("`]/B`G)RP*("`@
M("`@("`@("`@5D-!4D1?04127U-44D5%5"`@("`@("`@/3X@)&%;)TAO;65!
M9&1R97-S4W1R965T)UTL"B`@("`@("`@("`@(%9#05)$7T%$4E],3T-!3$E4
M62`@("`@(#T^("1A6R=(;VUE061D<F5S<T-I='DG72P*("`@("`@("`@("`@
M5D-!4D1?04127U)%1TE/3B`@("`@("`@/3X@)&%;)TAO;65!9&1R97-S4W1A
M=&4G72P*("`@("`@("`@("`@5D-!4D1?04127U!/4U1#3T1%("`@("`@/3X@
M)&%;)TAO;65!9&1R97-S4&]S=&%L0V]D92==+`H@("`@("`@("`@("!60T%2
M1%]!1%)?0T]53E1262`@("`@("`]/B`D85LG2&]M94%D9')E<W-#;W5N=')Y
M)UTL"B`@("`@("`@*3L*("`@("`@("`D=F-A<F0M/G-E=$%T=')I8G5T92@G
M0412)RP@:6UP;&]D92@G.R<L("1V*2P@87)R87DH)U194$4G(#T^("=(3TU%
M)R`I+"!T<G5E+"`D=BD["@H@("`@("`@("1V(#T@87)R87DH"B`@("`@("`@
M("`@(%9#05)$7T%$4E]03T(@("`@("`@("`@(#T^("1A6R="=7-I;F5S<T%D
M9')E<W-0;W-T3V9F:6-E0F]X)UTL"B`@("`@("`@("`@(%9#05)$7T%$4E]%
M6%1%3D0@("`@("`@(#T^("<G+`H@("`@("`@("`@("!60T%21%]!1%)?4U12
M1454("`@("`@("`]/B`D85LG0G5S:6YE<W-!9&1R97-S4W1R965T)UTL"B`@
M("`@("`@("`@(%9#05)$7T%$4E],3T-!3$E462`@("`@(#T^("1A6R="=7-I
M;F5S<T%D9')E<W-#:71Y)UTL"B`@("`@("`@("`@(%9#05)$7T%$4E]214=)
M3TX@("`@("`@(#T^("1A6R="=7-I;F5S<T%D9')E<W-3=&%T92==+`H@("`@
M("`@("`@("!60T%21%]!1%)?4$]35$-/1$4@("`@("`]/B`D85LG0G5S:6YE
M<W-!9&1R97-S4&]S=&%L0V]D92==+`H@("`@("`@("`@("!60T%21%]!1%)?
M0T]53E1262`@("`@("`]/B`D85LG0G5S:6YE<W-!9&1R97-S0V]U;G1R>2==
M+`H@("`@("`@("D["@H@("`@("`@("1V8V%R9"T^<V5T071T<FEB=71E*"=!
M1%(G+"!I;7!L;V1E*"<[)RP@)'8I+"!A<G)A>2@G5%E012<@/3X@)U=/4DLG
M("DL('1R=64L("1V*3L*"B`@("`@("`@<F5T=7)N("1V8V%R9"T^97AP;W)T
M=D-A;&5N9&%R*"D["B`@("!]"@H@("`@9G5N8W1I;VX@<VEF,G9E=F5N="@D
M<VEF*0H@("`@>PH@("`@("`@("1A(#T@)'1H:7,M/G-I9C)A<G)A>2@D<VEF
M*3L*"B`@("`@("`@)&E#86P@/2`F;F5W($AO<F1E7VE#86QE;F1A<B@I.PH@
M("`@("`@("1I0V%L+3YS971!='1R:6)U=&4H)U9%4E-)3TXG+"`G,2XP)RD[
M"B`@("`@("`@)&E#86PM/G-E=$%T=')I8G5T92@G4%)/1$E$)RP@)RTO+U1H
M92!(;W)D92!0<F]J96-T+R]-;F5M;R`O+T5.)RD["B`@("`@("`@)&E#86PM
M/G-E=$%T=')I8G5T92@G34542$]$)RP@)U!50DQ)4T@G*3L*"B`@("`@("`@
M)'9%=F5N="`]("9(;W)D95]I0V%L96YD87(Z.FYE=T-O;7!O;F5N="@G=F5V
M96YT)RP@)&E#86PI.PH*("`@("`@("!I9B`H)&%;)T%L;$1A>45V96YT)UT@
M/3T@)U1R=64G*2!["B`@("`@("`@("`@("1T(#T@)&E#86PM/E]P87)S941A
M=&54:6UE*"1A6R=3=&%R="==*3L*("`@("`@("`@("`@)'9%=F5N="T^<V5T
M071T<FEB=71E*"=$5%-405)4)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*"=Y96%R)R`]/B!D871E*"=9)RP@)'0I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VUO;G1H)R`]
M/B!D871E*"=M)RP@)'0I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)VUD87DG(#T^(&1A=&4H)V0G+"1T*2DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G5D%,544G(#T^("=$
M051%)RDI.PH@("`@("`@("`@("`D="`]("1I0V%L+3Y?<&%R<V5$871E5&EM
M92@D85LG16YD)UTI.PH@("`@("`@("`@("`D=D5V96YT+3YS971!='1R:6)U
M=&4H)T1414Y$)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*"=Y96%R)R`]/B!D871E*"=9)RP@)'0I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)VUO;G1H)R`]/B!D871E*"=M
M)RP@)'0I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)VUD87DG(#T^(&1A=&4H)V0G+"1T*2DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@G5D%,544G(#T^("=$051%)RDI.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1V179E;G0M/G-E=$%T=')I
M8G5T92@G1%135$%25"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D:4-A;"T^7W!A<G-E1&%T951I;64H)&%;)U-T87)T)UTI*3L*("`@
M("`@("`@("`@)'9%=F5N="T^<V5T071T<FEB=71E*"=$5$5.1"<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:4-A;"T^7W!A<G-E1&%T
M951I;64H)&%;)T5N9"==*2D["B`@("`@("`@?0H*("`@("`@("`D=D5V96YT
M+3YS971!='1R:6)U=&4H)T144U1!35`G+"!T:6UE*"DI.PH@("`@("`@("1V
M179E;G0M/G-E=$%T=')I8G5T92@G4U5-34%262<L("1A6R=3=6)J96-T)UTI
M.PH@("`@("`@("1V179E;G0M/G-E=$%T=')I8G5T92@G1$530U))4%1)3TXG
M+"`D85LG0F]D>2==*3L*("`@("`@("`O+R`D=D5V96YT+3YS971!='1R:6)U
M=&4H)T-!5$5'3U))15,G+"`D85LG)UTI.PH@("`@("`@("1V179E;G0M/G-E
M=$%T=')I8G5T92@G3$]#051)3TXG+"`D85LG3&]C871I;VXG72D["@H@("`@
M("`@(')E='5R;B`D=D5V96YT+3YE>'!O<G1V0V%L96YD87(H*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!S:68R=G1O9&\H)'-I9BD*("`@('L*("`@("`@("`D
M82`]("1T:&ES+3YS:68R87)R87DH)'-I9BD["@H@("`@("`@("1I0V%L(#T@
M)FYE=R!(;W)D95]I0V%L96YD87(H*3L*("`@("`@("`D:4-A;"T^<V5T071T
M<FEB=71E*"=615)324].)RP@)S$N,"<I.PH@("`@("`@("1I0V%L+3YS971!
M='1R:6)U=&4H)U!23T1)1"<L("<M+R]4:&4@2&]R9&4@4')O:F5C="\O36YE
M;6\@+R]%3B<I.PH@("`@("`@("1I0V%L+3YS971!='1R:6)U=&4H)TU%5$A/
M1"<L("=054),25-()RD["@H@("`@("`@("1V=&]D;R`]("9(;W)D95]I0V%L
M96YD87(Z.FYE=T-O;7!O;F5N="@G=G1O9&\G+"`D:4-A;"D["@H@("`@("`@
M("1V=&]D;RT^<V5T071T<FEB=71E*"=354U-05)9)RP@)&%;)U-U8FIE8W0G
M72D["B`@("`@("`@)'9T;V1O+3YS971!='1R:6)U=&4H)T1%4T-225!424].
M)RP@)&%;)T)O9'DG72D["B`@("`@("`@:68@*"1A6R=);7!O<G1A;F-E)UT@
M/3T@,"D@>PH@("`@("`@("`@("`D=G1O9&\M/G-E=$%T=')I8G5T92@G4%))
M3U))5%DG+"`U*3L*("`@("`@("!](&5L<V5I9B`H)&%;)TEM<&]R=&%N8V4G
M72`]/2`R*2!["B`@("`@("`@("`@("1V=&]D;RT^<V5T071T<FEB=71E*"=0
M4DE/4DE462<L(#$I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1V
M=&]D;RT^<V5T071T<FEB=71E*"=04DE/4DE462<L(#,I.PH@("`@("`@('T*
M("`@("`@("!I9B`H)&%;)T1U941A=&4G72`A/2`G-#4P,#$R,S%4,C,P,#`P
M6B<I('L*("`@("`@("`@("`@)'9T;V1O+3YS971!='1R:6)U=&4H)T1512<L
M("1I0V%L+3Y?<&%R<V5$871E5&EM92@D85LG1'5E1&%T92==*2D["B`@("`@
M("`@?0H@("`@("`@("1V=&]D;RT^<V5T071T<FEB=71E*"=#3TU03$54140G
M+"`D85LG0V]M<&QE=&4G72`]/2`G5')U92<@/R`Q(#H@,"D["@H@("`@("`@
M(')E='5R;B`D=G1O9&\M/F5X<&]R='9#86QE;F1A<B@I.PH@("`@?0H*("`@
M(&9U;F-T:6]N('9N;W1E,G-I9B@D=FYO=&4I"B`@("!["B`@("`@("`@)&E#
M86P@/2`F;F5W($AO<F1E7VE#86QE;F1A<B@I.PH@("`@("`@(&EF("@A)&E#
M86PM/G!A<G-E=D-A;&5N9&%R*"1V;F]T92DI('L*("`@("`@("`@("`@9&EE
M*")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!D871A+B(I.PH@
M("`@("`@('T*"B`@("`@("`@)&-O;7!O;F5N=',@/2`D:4-A;"T^9V5T0V]M
M<&]N96YT<R@I.PH*("`@("`@("!S=VET8V@@*&-O=6YT*"1C;VUP;VYE;G1S
M*2D@>PH@("`@("`@(&-A<V4@,#H*("`@("`@("`@("`@9&EE*").;R!D871A
M('=A<R!F;W5N9"XB*3L*"B`@("`@("`@8V%S92`Q.@H@("`@("`@("`@("`D
M8V]N=&5N="`]("1C;VUP;VYE;G1S6S!=.PH@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@9&EE*")-=6QT:7!L92!C
M;VUP;VYE;G1S(&9O=6YD.R!O;FQY(&]N92!I<R!S=7!P;W)T960N(BD["B`@
M("`@("`@?0H*("`@("`@("`D82`](&%R<F%Y*"=";V1Y)R`]/B`D8V]N=&5N
M="T^9V5T071T<FEB=71E*"="3T19)RDI.PH*("`@("`@("!R971U<FX@)'1H
M:7,M/F%R<F%Y,G-I9B@*("`@("`@("`@("`@)&$L"B`@("`@("`@("`@("<\
M/WAM;"!V97)S:6]N/2(Q+C`B/SX\;F]T93XG+`H@("`@("`@("`@("`G/$-A
M=&5G;W)I97,^/"]#871E9V]R:65S/B<*("`@("`@("`@("`@+B`G/%-U8FIE
M8W0^/"]3=6)J96-T/CQ#;VQO<CX\+T-O;&]R/CQ(96EG:'0^/"](96EG:'0^
M/%=I9'1H/CPO5VED=&@^/$QE9G0^/"],969T/CQ4;W`^/"]4;W`^)PH@("`@
M("`@("`@("`N("<\+VYO=&4^)RD["B`@("!]"@H@("`@9G5N8W1I;VX@=F-A
M<F0R<VEF*"1V8V%R9"D*("`@('L*("`@("`@("`D:4-A;"`]("9N97<@2&]R
M9&5?:4-A;&5N9&%R*"D["B`@("`@("`@:68@*"$D:4-A;"T^<&%R<V5V0V%L
M96YD87(H)'9C87)D*2D@>PH@("`@("`@("`@("!D:64H(E1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&1A=&$N(BD["B`@("`@("`@?0H*("`@
M("`@("`D8V]M<&]N96YT<R`]("1I0V%L+3YG971#;VUP;VYE;G1S*"D["@H@
M("`@("`@('-W:71C:"`H8V]U;G0H)&-O;7!O;F5N=',I*2!["B`@("`@("`@
M8V%S92`P.@H@("`@("`@("`@("!D:64H(DYO(&1A=&$@=V%S(&9O=6YD+B(I
M.PH*("`@("`@("!C87-E(#$Z"B`@("`@("`@("`@("1C;VYT96YT(#T@)&-O
M;7!O;F5N='-;,%T["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!D969A
M=6QT.@H@("`@("`@("`@("!D:64H(DUU;'1I<&QE(&-O;7!O;F5N=',@9F]U
M;F0[(&]N;'D@;VYE(&ES('-U<'!O<G1E9"XB*3L*("`@("`@("!]"@H@("`@
M("`@("\O(&9R;VT@:&5R92!O;BP@=&AE(&-O9&4@:7,@=&%K96X@9G)O;0H@
M("`@("`@("\O(%1U<F)A7T1R:79E<CHZ=&](87-H+"!V(#$N-C4@,C`P-2\P
M,R\Q,@H@("`@("`@("\O(&%N9"!M;V1I9FEE9"!F;W(@=&AE(%-Y;F,T2B!A
M='1R:6)U=&4@;F%M97,N"B`@("`@("`@)&%T='(@/2`D8V]N=&5N="T^9V5T
M06QL071T<FEB=71E<R@I.PH@("`@("`@(&9O<F5A8V@@*"1A='1R(&%S("1I
M=&5M*2!["B`@("`@("`@("`@('-W:71C:"`H)&ET96U;)VYA;64G72D@>PH@
M("`@("`@("`@("!C87-E("=&3B<Z"B`@("`@("`@("`@("`@("`D:&%S:%LG
M1FEL94%S)UT@/2`D:71E;5LG=F%L=64G73L*("`@("`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("`@("`@8V%S92`G3B<Z"B`@("`@("`@("`@("`@("`D
M;F%M92`]("1I=&5M6R=V86QU97,G73L*("`@("`@("`@("`@("`@("1H87-H
M6R=,87-T3F%M92==(#T@)&YA;65;5D-!4D1?3E]&04U)3%E=.PH@("`@("`@
M("`@("`@("`@)&AA<VA;)T9I<G-T3F%M92==(#T@)&YA;65;5D-!4D1?3E]'
M259%3ET["B`@("`@("`@("`@("`@("`D:&%S:%LG36ED9&QE3F%M92==(#T@
M)&YA;65;5D-!4D1?3E]!1$1,73L*("`@("`@("`@("`@("`@("1H87-H6R=4
M:71L92==(#T@)&YA;65;5D-!4D1?3E]04D5&25A=.PH@("`@("`@("`@("`@
M("`@)&AA<VA;)U-U9F9I>"==(#T@)&YA;65;5D-!4D1?3E]3549&25A=.PH@
M("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=.24-+
M3D%-12<Z"B`@("`@("`@("`@("`@("`D:&%S:%LG3FEC:TYA;64G72`]("1I
M=&5M6R=V86QU92==.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("`O+R!&;W(@=D-A<F0@,RXP+@H@("`@("`@("`@("!C87-E("=!1%(G
M.@H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I=&5M6R=P87)A;7,G75LG
M5%E012==*2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?87)R87DH
M)&ET96U;)W!A<F%M<R==6R=465!%)UTI*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1I=&5M6R=P87)A;7,G75LG5%E012==(#T@87)R87DH)&ET96U;
M)W!A<F%M<R==6R=465!%)UTI.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&ET
M96U;)W!A<F%M<R==6R=465!%)UT@/2!A<G)A>2@I.PH@("`@("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D:71E;5LG<&%R86US)UU;)U=/4DLG72DI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&ET96U;)W!A<F%M<R==6R=465!%
M)UU;72`]("=73U)+)SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1I=&5M6R=P87)A;7,G75LG2$]-12==
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D:71E;5LG<&%R86US)UU;
M)U194$4G75M=(#T@)TA/344G.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D861D<F5S<R`]("1I
M=&5M6R=V86QU97,G73L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1I=&5M
M6R=P87)A;7,G75LG5%E012==(&%S("1A9'(I('L*("`@("`@("`@("`@("`@
M("`@("!S=VET8V@@*%-T<FEN9SHZ=7!P97(H)&%D<BDI('L*("`@("`@("`@
M("`@("`@("`@("!C87-E("=(3TU%)SH*("`@("`@("`@("`@("`@("`@("`@
M("`@)'!R969I>"`]("=(;VUE061D<F5S<R<["B`@("`@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@("`@("!C87-E("=73U)+
M)SH*("`@("`@("`@("`@("`@("`@("`@("`@)'!R969I>"`]("=7;W)K061D
M<F5S<R<["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@("`@("`@
M("`D<')E9FEX(#T@)TAO;65!9&1R97-S)SL*("`@("`@("`@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`@("`@("`@(&EF("@D<')E9FEX*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1H87-H6R1P<F5F:7@@+B`G4W1R965T)UT@
M/2!I<W-E="@D861D<F5S<UM60T%21%]!1%)?4U12145472D@/R`D861D<F5S
M<UM60T%21%]!1%)?4U12145472`Z(&YU;&P["B`@("`@("`@("`@("`@("`@
M("`@("`@("1H87-H6R1P<F5F:7@@+B`G0VET>2==(#T@:7-S970H)&%D9')E
M<W-;5D-!4D1?04127TQ/0T%,251972D@/R`D861D<F5S<UM60T%21%]!1%)?
M3$]#04Q)5%E=(#H@;G5L;#L*("`@("`@("`@("`@("`@("`@("`@("`@)&AA
M<VA;)'!R969I>"`N("=3=&%T92==(#T@:7-S970H)&%D9')E<W-;5D-!4D1?
M04127U)%1TE/3ETI(#\@)&%D9')E<W-;5D-!4D1?04127U)%1TE/3ET@.B!N
M=6QL.PH@("`@("`@("`@("`@("`@("`@("`@("`D:&%S:%LD<')E9FEX("X@
M)U!O<W1A;$-O9&4G72`](&ES<V5T*"1A9&1R97-S6U9#05)$7T%$4E]03U-4
M0T]$15TI(#\@)&%D9')E<W-;5D-!4D1?04127U!/4U1#3T1%72`Z(&YU;&P[
M"B`@("`@("`@("`@("`@("`@("`@("`@("1H87-H6R1P<F5F:7@@+B`G0V]U
M;G1R>2==(#T@:7-S970H)&%D9')E<W-;5D-!4D1?04127T-/54Y44EE=*2`_
M("1A9&1R97-S6U9#05)$7T%$4E]#3U5.5%)972`Z(&YU;&P["B`@("`@("`@
M("`@("`@("`@("`@("`@("1H87-H6R1P<F5F:7@@+B`G4&]S=$]F9FEC94)O
M>"==(#T@:7-S970H)&%D9')E<W-;5D-!4D1?04127U!/0ETI(#\@)&%D9')E
M<W-;5D-!4D1?04127U!/0ET@.B!N=6QL.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@8V%S92`G5$5,)SH*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D:71E;5LG<&%R86US)UU;)T9!6"==*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1H87-H6R="=7-I;F5S<T9A>$YU;6)E<B==(#T@)&ET96U;)W9A
M;'5E)UT["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H:7-S970H)&ET96U;
M)W!A<F%M<R==6R=465!%)UTI*2!["B`@("`@("`@("`@("`@("`@("`@:68@
M*"%I<U]A<G)A>2@D:71E;5LG<&%R86US)UU;)U194$4G72DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&ET96U;)W!A<F%M<R==6R=465!%)UT@/2!A
M<G)A>2@D:71E;5LG<&%R86US)UU;)U194$4G72D["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("\O($9O<B!V0V%R9"`S+C`N
M"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&ET96U;)W!A<F%M<R==
M6R=465!%)UT@87,@)'1E;"D@>PH@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H4W1R:6YG.CIU<'!E<B@D=&5L*2`]/2`G5T]22R<I('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1H87-H6R="=7-I;F5S<U1E;&5P:&]N94YU
M;6)E<B==(#T@)&ET96U;)W9A;'5E)UT["B`@("`@("`@("`@("`@("`@("`@
M("`@('T@96QS96EF("A3=')I;F<Z.G5P<&5R*"1T96PI(#T]("=(3TU%)RD@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&AA<VA;)TAO;65496QE
M<&AO;F5.=6UB97(G72`]("1I=&5M6R=V86QU92==.PH@("`@("`@("`@("`@
M("`@("`@("`@("!](&5L<V5I9B`H4W1R:6YG.CIU<'!E<B@D=&5L*2`]/2`G
M0T5,3"<I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1H87-H6R=-
M;V)I;&5496QE<&AO;F5.=6UB97(G72`]("1I=&5M6R=V86QU92==.PH@("`@
M("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H4W1R:6YG.CIU<'!E<B@D
M=&5L*2`]/2`G1D%8)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&AA<VA;)T)U<VEN97-S1F%X3G5M8F5R)UT@/2`D:71E;5LG=F%L=64G73L*
M("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1I=&5M6R=P87)A;7,G75LG2$]-12==*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D:&%S:%LG2&]M951E;&5P:&]N94YU;6)E
M<B==(#T@)&ET96U;)W9A;'5E)UT["B`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E:68@*&ES<V5T*"1I=&5M6R=P87)A;7,G75LG5T]22R==*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D:&%S:%LG0G5S:6YE<W-496QE<&AO;F5.
M=6UB97(G72`]("1I=&5M6R=V86QU92==.PH@("`@("`@("`@("`@("`@("`@
M('T@96QS96EF("AI<W-E="@D:71E;5LG<&%R86US)UU;)T-%3$PG72DI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&AA<VA;)TUO8FEL951E;&5P:&]N
M94YU;6)E<B==(#T@)&ET96U;)W9A;'5E)UT["B`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)&AA<VA;)TAO
M;65496QE<&AO;F5.=6UB97(G72`]("1I=&5M6R=V86QU92==.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G14U!24PG.@H@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1I=&5M6R=P87)A;7,G75LG4%)%1B==*2!\
M?"`A:7-S970H)&AA<VA;)V5M86EL)UTI*2!["B`@("`@("`@("`@("`@("`@
M("`@)&AA<VA;)T5M86EL,4%D9')E<W,G72`]($AO<F1E7VE#86QE;F1A<E]V
M8V%R9#HZ9V5T0F%R945M86EL*"1I=&5M6R=V86QU92==*3L*("`@("`@("`@
M("`@("`@("`@("`D:&%S:%LG16UA:6PQ061D<F5S<U1Y<&4G72`]("=33510
M)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@8V%S92`G5$E43$4G.@H@("`@("`@("`@("`@("`@)&AA
M<VA;)TIO8E1I=&QE)UT@/2`D:71E;5LG=F%L=64G73L*("`@("`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G3U)')SH*("`@("`@("`@
M("`@("`@("1H87-H6R=#;VUP86YY3F%M92==(#T@)&ET96U;)W9A;'5E)UT[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)TY/
M5$4G.@H@("`@("`@("`@("`@("`@)&AA<VA;)T)O9'DG72`]("1I=&5M6R=V
M86QU92==.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C
M87-E("=54DPG.@H@("`@("`@("`@("`@("`@)&AA<VA;)U=E8E!A9V4G72`]
M("1I=&5M6R=V86QU92==.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^87)R
M87DR<VEF*`H@("`@("`@("`@("`D:&%S:"P*("`@("`@("`@("`@)SP_>&UL
M('9E<G-I;VX](C$N,"(_/CQC;VYT86-T/B<L"B`@("`@("`@("`@("<\+V-O
M;G1A8W0^)RD["B`@("!]"@H@("`@9G5N8W1I;VX@=F5V96YT,G-I9B@D=F-A
M<F0I"B`@("!["B`@("`@("`@)&E#86P@/2`F;F5W($AO<F1E7VE#86QE;F1A
M<B@I.PH@("`@("`@(&EF("@A)&E#86PM/G!A<G-E=D-A;&5N9&%R*"1V8V%R
M9"DI('L*("`@("`@("`@("`@9&EE*")4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!D871A+B(I.PH@("`@("`@('T*"B`@("`@("`@)&-O;7!O
M;F5N=',@/2`D:4-A;"T^9V5T0V]M<&]N96YT<R@I.PH*("`@("`@("!S=VET
M8V@@*&-O=6YT*"1C;VUP;VYE;G1S*2D@>PH@("`@("`@(&-A<V4@,#H*("`@
M("`@("`@("`@9&EE*").;R!D871A('=A<R!F;W5N9"XB*3L*"B`@("`@("`@
M8V%S92`Q.@H@("`@("`@("`@("`D8V]N=&5N="`]("1C;VUP;VYE;G1S6S!=
M.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@
M("`@("`@9&EE*")-=6QT:7!L92!C;VUP;VYE;G1S(&9O=6YD.R!O;FQY(&]N
M92!I<R!S=7!P;W)T960N(BD["B`@("`@("`@?0H*("`@("`@("`O+R!)<R!T
M:&5R92!A(')E86P@;F5E9"!T;R!P<F]V:61E('1H92!C;W)R96-T('9A;'5E
M/PH@("`@("`@("1D=7)A=&EO;B`](#`["@H@("`@("`@("1A='1R(#T@)&-O
M;G1E;G0M/F=E=$%L;$%T=')I8G5T97,H*3L*("`@("`@("!F;W)E86-H("@D
M871T<B!A<R`D:71E;2D@>PH@("`@("`@("`@("!S=VET8V@@*"1I=&5M6R=N
M86UE)UTI('L*("`@("`@("`@("`@8V%S92`G1%135$%25"<Z"B`@("`@("`@
M("`@("`@("!I9B`H(65M<'1Y*"1I=&5M6R=P87)A;7,G75LG5D%,544G72D@
M)B8@)&ET96U;)W!A<F%M<R==6R=604Q512==(#T](")$051%(BD@>PH@("`@
M("`@("`@("`@("`@("`@("1H87-H6R=!;&Q$87E%=F5N="==(#T@(E1R=64B
M.PH@("`@("`@("`@("`@("`@("`@("1H87-H6R=3=&%R="==(#T@2&]R9&5?
M:4-A;&5N9&%R.CI?97AP;W)T1&%T951I;64H)&ET96U;)W9A;'5E)UTI.PH@
M("`@("`@("`@("`@("`@("`@("1D=7)A=&EO;B`](#$T-#`["B`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1H87-H6R=!
M;&Q$87E%=F5N="==(#T@(D9A;'-E(CL*("`@("`@("`@("`@("`@("`@("`D
M:&%S:%LG4W1A<G0G72`]($AO<F1E7VE#86QE;F1A<CHZ7V5X<&]R=$1A=&54
M:6UE*"1I=&5M6R=V86QU92==*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G1%1%3D0G.@H@
M("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D:71E;5LG<&%R86US)UU;)U9!
M3%5%)UTI("8F("1I=&5M6R=P87)A;7,G75LG5D%,544G72`]/2`B1$%412(I
M('L*("`@("`@("`@("`@("`@("`@("`D:&%S:%LG06QL1&%Y179E;G0G72`]
M(")4<G5E(CL*("`@("`@("`@("`@("`@("`@("`D:&%S:%LG16YD)UT@/2!(
M;W)D95]I0V%L96YD87(Z.E]E>'!O<G1$871E5&EM92@D:71E;5LG=F%L=64G
M72D["B`@("`@("`@("`@("`@("`@("`@)&1U<F%T:6]N(#T@,30T,#L*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&AA
M<VA;)T%L;$1A>45V96YT)UT@/2`B1F%L<V4B.PH@("`@("`@("`@("`@("`@
M("`@("1H87-H6R=%;F0G72`]($AO<F1E7VE#86QE;F1A<CHZ7V5X<&]R=$1A
M=&54:6UE*"1I=&5M6R=V86QU92==*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G4U5-34%2
M62<Z"B`@("`@("`@("`@("`@("`D:&%S:%LG4W5B:F5C="==(#T@)&ET96U;
M)W9A;'5E)UT["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M(&-A<V4@)T1%4T-225!424].)SH*("`@("`@("`@("`@("`@("1H87-H6R="
M;V1Y)UT@/2`D:71E;5LG=F%L=64G73L*("`@("`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("`@("`@8V%S92`G3$]#051)3TXG.@H@("`@("`@("`@("`@
M("`@)&AA<VA;)TQO8V%T:6]N)UT@/2`D:71E;5LG=F%L=64G73L*("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)'1H:7,M/F%R<F%Y,G-I9B@*("`@("`@("`@("`@)&AA
M<V@L"B`@("`@("`@("`@("<\/WAM;"!V97)S:6]N/2(Q+C`B/SX\87!P;VEN
M=&UE;G0^/$1U<F%T:6]N/B<*("`@("`@("`@("`@+B`D9'5R871I;VX@+B`G
M/"]$=7)A=&EO;CXG+`H@("`@("`@("`@("`G/$ES4F5C=7)R:6YG/D9A;'-E
M/"])<U)E8W5R<FEN9SX\365E=&EN9U-T871U<SXP/"]-965T:6YG4W1A='5S
M/CQ"=7-Y4W1A='5S/C(\+T)U<WE3=&%T=7,^/"]A<'!O:6YT;65N=#XG*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!V=&]D;S)S:68H)'9C87)D*0H@("`@>PH@
M("`@("`@("1I0V%L(#T@)FYE=R!(;W)D95]I0V%L96YD87(H*3L*("`@("`@
M("!I9B`H(21I0V%L+3YP87)S979#86QE;F1A<B@D=F-A<F0I*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!D871A+B<I.PH@("`@("`@('T*"B`@("`@
M("`@)&-O;7!O;F5N=',@/2`D:4-A;"T^9V5T0V]M<&]N96YT<R@I.PH*("`@
M("`@("!S=VET8V@@*&-O=6YT*"1C;VUP;VYE;G1S*2D@>PH@("`@("`@(&-A
M<V4@,#H*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TYO
M(&1A=&$@=V%S(&9O=6YD)RD["@H@("`@("`@(&-A<V4@,3H*("`@("`@("`@
M("`@)&-O;G1E;G0@/2`D8V]M<&]N96YT<ULP73L*("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*"=-=6QT:7!L92!C;VUP;VYE;G1S(&9O=6YD.R!O;FQY
M(&]N92!I<R!S=7!P;W)T960N)RD["B`@("`@("`@?0H*("`@("`@("`D:&%S
M:%LG0V]M<&QE=&4G72`]("=&86QS92<["B`@("`@("`@+R\@3W5T;&]O:R=S
M(&1E9F%U;'0@9F]R(&YO(&1U92!D871E"B`@("`@("`@)&AA<VA;)T1U941A
M=&4G72`]("<T-3`P,3(S,50R,S`P,#!:)SL*"B`@("`@("`@)&%T='(@/2`D
M8V]N=&5N="T^9V5T06QL071T<FEB=71E<R@I.PH@("`@("`@(&9O<F5A8V@@
M*"1A='1R(&%S("1I=&5M*2!["B`@("`@("`@("`@('-W:71C:"`H)&ET96U;
M)VYA;64G72D@>PH@("`@("`@("`@("!C87-E("=$544G.@H@("`@("`@("`@
M("`@("`@)&AA<VA;)T1U941A=&4G72`]($AO<F1E7VE#86QE;F1A<CHZ7V5X
M<&]R=$1A=&54:6UE*"1I=&5M6R=V86QU92==*3L*("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G4U5-34%262<Z"B`@("`@("`@
M("`@("`@("`D:&%S:%LG4W5B:F5C="==(#T@)&ET96U;)W9A;'5E)UT["B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)T1%4T-2
M25!424].)SH*("`@("`@("`@("`@("`@("1H87-H6R=";V1Y)UT@/2`D:71E
M;5LG=F%L=64G73L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@8V%S92`G4%))3U))5%DG.@H@("`@("`@("`@("`@("`@:68@*"1I=&5M
M6R=V86QU92==(#T](#$I('L*("`@("`@("`@("`@("`@("`@("`D:&%S:%LG
M26UP;W)T86YC92==(#T@,CL*("`@("`@("`@("`@("`@('T@96QS96EF("@D
M:71E;5LG=F%L=64G72`]/2`U*2!["B`@("`@("`@("`@("`@("`@("`@)&AA
M<VA;)TEM<&]R=&%N8V4G72`](#`["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("1H87-H6R=);7!O<G1A;F-E)UT@/2`Q
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@("`@("!C87-E("=#3TU03$54140G.@H@("`@("`@("`@("`@("`@
M)&AA<VA;)T-O;7!L971E)UT@/2`D:71E;5LG=F%L=64G72`_("=4<G5E)R`Z
M("=&86QS92<["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3YA<G)A>3)S:68H
M"B`@("`@("`@("`@("1H87-H+`H@("`@("`@("`@("`G/#]X;6P@=F5R<VEO
M;CTB,2XP(C\^/'1A<VL^)RP*("`@("`@("`@("`@)SPO=&%S:SXG*3L*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U-Y;F--
M3"]$979I8V4O4#@P,"YP:'``````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#$S-#4R(#$P-3$U-#,S-S,T(#`R,C`Q-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@4#@P
M,"]0.3`P+U`Y,3`Z"B`J("TM+2TM+2TM+2TM+2TM+0H@*B!#:&%R<V5T.@H@
M*B!4:&ES(&1E=FEC92!I<R!A8FQE('1O(&AA;F1L92!55$8M."!A;F0@<V5N
M9',@:71S(%A-3"!P86-K86=E<R!I;B!55$8X+@H@*B!(;W=E=F5R(&5V96X@
M=&AO=6=H('1H92!834P@:71S96QF(&ES(%541BTX+"!I="!E>'!E8W1S('1H
M92!E;F-L;W-E9`H@*B!V8V%R9"UD871A('1O(&)E($E33RTX.#4Y+3$@=6YL
M97-S(&5X<&QI8VET;'D@<W1A=&5D(&]T:&5R=VES92`H=7-I;F<@=&AE"B`J
M($-(05)3150@;W!T:6]N+"!W:&EC:"!I<R!D97!R96-A=&5D(&9O<B!60T%2
M1"`S+C`I"B`J"B`J($5N8V]D:6YG.@H@*B!3=')I;F<@=F%L=65S(&%R92!E
M;F-O9&5D(")154]4140M4%))3E1!0DQ%(@H@*@H@*B!/=&AE<CH*("H@5&AI
M<R!D979I8V5S(&AA;F1L97,@=&%S:W,@86YD(&5V96YT<R!I;B!O;F4@9&%T
M86)A<V4N"B`J"B`J($%S('1H92!0.#`P('=A<R!T:&4@9FER<W0@9&5V:6-E
M('1O('=O<FL@=VET:"!P86-K86=E+"!M;W-T(&]F('1H90H@*B!R97%U:7)E
M9"!C;VYV97)S:6]N<R!A<F4@:6X@1&5V:6-E+G!H<"=S(&1E9F%U;'0@:&%N
M9&QI;F<N"B`J"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@2V%R<W1E;B!&;W5R
M;6]N="`\:V%R<W1E;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,
M*2X@268@>6]U(&1I9"!N;W0*("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B`D
M2&]R9&4Z(&9R86UE=V]R:R]3>6YC34PO4WEN8TU,+T1E=FEC92]0.#`P+G!H
M<"QV(#$N-RXR+C4@,C`P-B\P-2\P,2`Q,CHP-3HQ-"!J86X@17AP("0*("H*
M("H@0&%U=&AO<B`@2V%R<W1E;B!&;W5R;6]N="`\:V%R<W1E;D!H;W)D92YO
M<F<^"B`J($!P86-K86=E(%-Y;F--3`H@*B\*8VQA<W,@4WEN8TU,7T1E=FEC
M95]0.#`P(&5X=&5N9',@4WEN8TU,7T1E=FEC92!["@H@("`@+RHJ"B`@("`@
M*B!#;VYV97)T('1H92!C;VYT96YT+@H@("`@("H*("`@("`J($-U<G)E;G1L
M>2!S=')I<',@=6ED("AP<FEM87)Y(&ME>2D@:6YF;W)M871I;VX@87,@8VQI
M96YT(&%N9`H@("`@("H@<V5R=F5R(&UI9VAT('5S92!D:69F97)E;G0@;VYE
M<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VYT96YT("`@("`@
M(%1H92!C;VYT96YT('1O(&-O;G9E<G0N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1C;VYT96YT5'EP92`@(%1H92!C;VYT96YT5'EP92!O9B!T:&4@8V]N=&5N
M="X*("`@("`J($!R971U<FX@87)R87D@("`@("`@("`@("`@("`@87)R87DH
M)&YE=V-O;G1E;G0L("1N97=C;VYT96YT5'EP92DZ"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('1H92!C;VYV97)T960@8V]N=&5N="!A
M;F0@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("AP
M;W-S:6)L>2!C:&%N9V5D*2!N97<@0V]N=&5N=%1Y<&4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-O;G9E<G1#;&EE;G0R4V5R=F5R*"1C;VYT96YT+"`D8V]N
M=&5N=%1Y<&4I"B`@("!["B`@("`@("`@;&ES="@D8V]N=&5N="P@)&-O;G1E
M;G14>7!E*2`]"B`@("`@("`@("`@('!A<F5N=#HZ8V]N=F5R=$-L:65N=#)3
M97)V97(H)&-O;G1E;G0L("1C;VYT96YT5'EP92D["@H@("`@("`@("\J(%`X
M,#`@<V5N9',@8V%T96=O<FEE<R!A<R`B6"U#871E9V]R>2(N(%)E;6]V92!T
M:&4@(E@M(CH@*B\*("`@("`@("`D8V]N=&5N="`]('!R96=?<F5P;&%C92@G
M+RA<<EQN?%QR?%QN*4-!5$5'3U))15,Z6"TO)RP@)UPQ0T%414=/4DE%4SHG
M+"`D8V]N=&5N="P@,2D["@H@("`@("`@("\J(%`X,#`@<V5N9',@86QL(&1A
M>2!E=F5N=',@87,@<RYT:"X@;&EK90H@("`@("`@("`J($144U1!4E0Z,C`P
M-3`U,#54,#`P,#`P6EY-"B`@("`@("`@("H@1%1%3D0Z,C`P-3`U,#54,C0P
M,#`P6EY-"B`@("`@("`@("H@5&AI<R!I<R!N;R!L;VYG97(@86X@86QL(&1A
M>2!E=F5N="!W:&5N(&-O;G9E<G1E9"!T;R!L;V-A;"!T:6UE>F]N92X*("`@
M("`@("`@*B!3;R!M86YU86QL>2!H86YD;&4@=&AI<RX*("`@("`@("`@*B`J
M+PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O*%QR7&Y\7')\7&XI1%135$%2
M5#HN*E0P,#`P,#!:*%QR7&Y\7')\7&XI+R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@)&-O;G1E;G0I"B`@("`@("`@("`@("8F('!R96=?;6%T8V@H)R\H
M7')<;GQ<<GQ<;BE$5$5.1#HH7&1<9%QD7&0I*%QD7&0I*%QD7&0I5#(T,#`P
M,%HH7')<;GQ<<GQ<;BDO)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`D
M8V]N=&5N="P@)&TI*2!["B`@("`@("`@("`@("1C;VYT96YT(#T@<')E9U]R
M97!L86-E*"<O*%QR7&Y\7')\7&XI1%135$%25#HH+BHI5#`P,#`P,%HH7')<
M;GQ<<GQ<;BDO)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(B0Q1%135$%25#M604Q513U$051%.B0R)#,B+"`D8V]N=&5N="D["B`@
M("`@("`@("`@("\J($5N9"!T:6UE<W1A;7`@;75S="!B92!C;VYV97)T960@
M=&\@;F5X="!D87DG<R!D871E+B`J+PH@("`@("`@("`@("`D<R`](&1A=&4H
M)UEM9"<L(&UK=&EM92@P+"`P+"`P+"`D;5LS72P@)&U;-%TL("1M6S)=*2`K
M(#(T*C,V,#`I.PH@("`@("`@("`@("`D8V]N=&5N="`]('!R96=?<F5P;&%C
M92@G+RA<<EQN?%QR?%QN*41414Y$.B@N*BE4,C0P,#`P6BA<<EQN?%QR?%QN
M*2\G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B)#%$
M5$5.1#M604Q513U$051%.B1S)#,B+"`D8V]N=&5N="D["B`@("`@("`@?0H*
M("`@("`@("!I9B`H1$5"54=,3T=?24-!3$5.1$%21$%402D@>PH@("`@("`@
M("`@("`D9G`@/2!`9F]P96XH)R]T;7`O<WEN8R]L;V<N='AT)RP@)V$G*3L*
M("`@("`@("`@("`@:68@*"1F<"D@>PH@("`@("`@("`@("`@("`@0&9W<FET
M92@D9G`L(")<;FEN<'5T(&-O;G9E<G1E9"!F;W(@<V5R=F5R.B`D8V]N=&5N
M=%1Y<&5<;B(I.PH@("`@("`@("`@("`@("`@0&9W<FET92@D9G`L)&-O;G1E
M;G0@+B`B7&XB*3L*("`@("`@("`@("`@("`@($!F8VQO<V4H)&9P*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&%R<F%Y*"1C
M;VYT96YT+"`D8V]N=&5N=%1Y<&4I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0V]N=F5R=',@=&AE(&-O;G1E;G0@9G)O;2!T:&4@8F%C:V5N9"!T;R!A(&9O
M<FUA="!S=6ET86)L92!F;W(@=&AE"B`@("`@*B!C;&EE;G0@9&5V:6-E+@H@
M("`@("H*("`@("`J(%-T<FEP<R!T:&4@=6ED("AP<FEM87)Y(&ME>2D@:6YF
M;W)M871I;VX@87,@8VQI96YT(&%N9"!S97)V97(@;6EG:'0@=7-E"B`@("`@
M*B!D:69F97)E;G0@;VYE<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1C;VYT96YT("`@("`@(%1H92!C;VYT96YT('1O(&-O;G9E<G0N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1C;VYT96YT5'EP92`@(%1H92!C;VYT96YT5'EP
M92!O9B!C;VYT96YT(&%S(')E='5R;F5D(&9R;VT*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=&AE(&)A8VME;F0N"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("`@("`@("`@("`@("`@(&%R<F%Y*"1N97=C;VYT96YT+"`D
M;F5W8V]N=&5N=%1Y<&4I.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!T:&4@8V]N=F5R=&5D(&-O;G1E;G0@86YD('1H90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`H<&]S<VEB;'D@8VAA;F=E
M9"D@;F5W($-O;G1E;G14>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VYV
M97)T4V5R=F5R,D-L:65N="@D8V]N=&5N="P@)&-O;G1E;G14>7!E*0H@("`@
M>PH@("`@("`@(&=L;V)A;"`D8F%C:V5N9#L*"B`@("`@("`@;&ES="@D8V]N
M=&5N="P@)&-O;G1E;G14>7!E*2`]"B`@("`@("`@("`@('!A<F5N=#HZ8V]N
M=F5R=%-E<G9E<C)#;&EE;G0H)&-O;G1E;G0L("1C;VYT96YT5'EP92D["@H@
M("`@("`@("\J($-O;G9E<G0@86QL(&1A>2!E=F5N=',N("HO"B`@("`@("`@
M:68@*'!R96=?;6%T8V@H)R\H7')<;GQ<<GQ<;BE$5%-405)4.U9!3%5%/41!
M5$4Z*%QD>SA]*2\G+`H@("`@("`@("`@("`@("`@("`@("`@("1C;VYT96YT
M*0H@("`@("`@("`@("`F)B!P<F5G7VUA=&-H*"<O*%QR7&Y\7')\7&XI1%1%
M3D0[5D%,544]1$%413HH7&1<9%QD7&0I*%QD7&0I*%QD7&0I+R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&-O;G1E;G0L("1M*2D@>PH@("`@("`@
M("`@("`D8V]N=&5N="`]('!R96=?<F5P;&%C92@G+RA<<EQN?%QR?%QN*414
M4U1!4E0[5D%,544]1$%413HH7&1[.'TI+R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("(D,4144U1!4E0Z)#)4,#`P,#`P6B(L("1C
M;VYT96YT*3L*("`@("`@("`@("`@+RH@16YD(&1A=&4@;75S="!B92!C;VYV
M97)T960@=&\@=&EM97-T86UP+B`J+PH@("`@("`@("`@("`D<R`](&1A=&4H
M)UEM9"<L(&UK=&EM92@P+"`P+"`P+"`D;5LS72P@)&U;-%TL("1M6S)=*2`M
M(#(T*C,V,#`I.PH@("`@("`@("`@("`D8V]N=&5N="`]('!R96=?<F5P;&%C
M92@G+RA<<EQN?%QR?%QN*41414Y$.U9!3%5%/41!5$4Z*%QD>SA]*2\G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B)#%$5$5.1#LZ
M)'MS?50R-#`P,#!:(BP@)&-O;G1E;G0I.PH@("`@("`@('T*"B`@("`@("`@
M:68@*$1%0E5'3$]'7TE#04Q%3D1!4D1!5$$I('L*("`@("`@("`@("`@)&9P
M(#T@0&9O<&5N*"<O=&UP+W-Y;F,O;&]G+G1X="<L("=A)RD["B`@("`@("`@
M("`@(&EF("@D9G`I('L*("`@("`@("`@("`@("`@($!F=W)I=&4H)&9P+"`B
M7&YO=71P=70@8V]N=F5R=&5D(&9O<B!C;&EE;G0@*"1C;VYT96YT5'EP92DZ
M7&XB*3L*("`@("`@("`@("`@("`@($!F=W)I=&4H)&9P+"`D8V]N=&5N="`N
M(")<;B(I.PH@("`@("`@("`@("`@("`@0&9C;&]S92@D9G`I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@87)R87DH)&-O;G1E
M;G0L("1C;VYT96YT5'EP92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3;VUE
M(&1E=FEC97,@;&EK92!T:&4@4V]N>2!%<FEC<W-O;B!0.#`P+U`Y,#`O4#DQ
M,"!H86YD;&4@=G1O9&]S("AT87-K<RD*("`@("`J(&%N9"!V979E;G1S(&EN
M('1H92!S86UE(")C86QE;F1A<B(@<WEN8RX*("`@("`J(%1H:7,@<F5Q=6ER
M97,@<W!E8VEA;"!A8W1I;VYS(&]N(&]U<B!S:61E(&%S('=E('-T;W)E('1H
M:7,@:6X@9&EF9F5R96YT"B`@("`@*B!D871A8F%S97,@*&YA9R!A;F0@:W)O
M;F]L:71H*2X*("`@("`J(%1H:7,@9G5N8W1I;VX@8V]U;&0@9&ER96-T;'D@
M<F5T=7)N('1R=64@8G5T('1R:65S('1O(&)E(&$@8FET(&UO<F4*("`@("`J
M(&=E;F5R:6,@<V\@:70@;6EG:'0@=V]R:R!F;W(@;W1H97(@<&AO;F5S(&%S
M('=E;&PN"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA;F1L951A<VMS26Y#86QE
M;F1A<B@I"B`@("!["B`@("`@("`@)&1I(#T@)'1H:7,M/F1E=FEC94EN9F\H
M*3L*"B`@("`@("`@:68@*"%E;7!T>2@D9&DM/E]#5$-A<%LG=&5X="]X+79C
M86QE;F1A<B==6R="14=)3B==+3Y?5F%L16YU;5LG5D5614Y4)UTI("8F"B`@
M("`@("`@("`@("%E;7!T>2@D9&DM/E]#5$-A<%LG=&5X="]X+79C86QE;F1A
M<B==6R="14=)3B==+3Y?5F%L16YU;5LG5E1/1$\G72DI('L*("`@("`@("`@
M("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("!R971U<FX@<&%R
M96YT.CIH86YD;&5487-K<TEN0V%L96YD87(H*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!N965D<T-A=&5G;W)Y36%P<&EN9R@I"B`@("!["B`@("`@("`@+R\@
M4#@P,"!U<V5S(&YU;65R:6,@8V%T96=O<GD@8V]D97,N"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O4WEN8TU,+T1E
M=FEC92]3>6YT:&5S:7,N<&AP````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,3`V-#<@,3`U,34T,S,W,S0@,#(S,S8T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@4WEN
M8TU,7T1E=FEC95]3>6YT:&5S:7,Z.B!C;&%S<R!P<F]V:61E<R!F=6YC=&EO
M;F%L:71Y('1H870@:7,*("H@<W!E8VEF:6,@=&\@=&AE(%-Y;G1H97-I<RYC
M:"!3>6YC34P@8VQI96YT<RX*("H*("H@0V]P>7)I9VAT(#(P,#4M,C`P-B!+
M87)S=&5N($9O=7)M;VYT(#QK87)S=&5N0&AO<F1E+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U-Y;F--3"]3>6YC34PO1&5V
M:6-E+U-Y;G1H97-I<RYP:'`L=B`Q+C(N,BXU(#(P,#8O,#4O,#$@,3(Z,#4Z
M,30@:F%N($5X<"`D"B`J"B`J($!A=71H;W(@($MA<G-T96X@1F]U<FUO;G0@
M/&MA<G-T96Y`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!3>6YC34P*("HO"F-L
M87-S(%-Y;F--3%]$979I8V5?4WEN=&AE<VES(&5X=&5N9',@4WEN8TU,7T1E
M=FEC92!["@H@("`@+RHJ"B`@("`@*B!#;VYV97)T<R!T:&4@8V]N=&5N="!F
M<F]M('1H92!B86-K96YD('1O(&$@9F]R;6%T('-U:71A8FQE(&9O<B!T:&4*
M("`@("`J(&-L:65N="!D979I8V4N"B`@("`@*@H@("`@("H@4W1R:7!S('1H
M92!U:60@*'!R:6UA<GD@:V5Y*2!I;F9O<FUA=&EO;B!A<R!C;&EE;G0@86YD
M('-E<G9E<B!M:6=H="!U<V4*("`@("`J(&1I9F9E<F5N="!O;F5S+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&-O;G1E;G0@("`@("`@5&AE(&-O
M;G1E;G0@=&\@8V]N=F5R=`H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]N=&5N
M=%1Y<&4@("!4:&4@8V]N=&5N=%1Y<&4@;V8@8V]N=&5N="!A<R!R971U<FYE
M9"!F<F]M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H
M92!B86-K96YD"B`@("`@*B!`<F5T=7)N(&%R<F%Y("`@("`@("`@("`@("`@
M(&%R<F%Y*"1N97=C;VYT96YT+"`D;F5W8V]N=&5N=%1Y<&4I.@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@8V]N=F5R=&5D(&-O
M;G1E;G0@86YD('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`H<&]S<VEB;'D@8VAA;F=E9"D@;F5W($-O;G1E;G14>7!E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!C;VYV97)T4V5R=F5R,D-L:65N="@D8V]N=&5N
M="P@)&-O;G1E;G14>7!E*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8F%C:V5N
M9#L*"B`@("`@("`@;&ES="@D8V]N=&5N="P@)&-O;G1E;G14>7!E*2`]"B`@
M("`@("`@("`@('!A<F5N=#HZ8V]N=F5R=%-E<G9E<C)#;&EE;G0H)&-O;G1E
M;G0L("1C;VYT96YT5'EP92D["@H*("`@("`@("`O+R!3;VUE('-P96-I86P@
M<')I;W)I='D@:&%N9&QI;F<@:7,@<F5Q=6ER960N(%-Y;G1H97-I<R!U<V5S
M"B`@("`@("`@+R\@,2`H:&EG:"DL(#(@*&UE9&EU;2DL(#,H;&]W*2P@870@
M;&5A<W0@9F]R(&UY('=I;F1O=W,@;6]B:6QE(&1E=FEC92X*("`@("`@("`O
M+R!C;VYV97)T('1H97-E('1O('9A;&ED('!R:6]R:71Y('-E='1I;F=S.@H@
M("`@("`@("1C;VYT96YT(#T@<')E9U]R97!L86-E*"<O*%QR7&Y\7')\7&XI
M4%))3U))5%DZ6S$M,ETH7')<;GQ<<GQ<;BDO)RP@)UPQ4%))3U))5%DZ,5PR
M)RP@)&-O;G1E;G0L(#$I.PH@("`@("`@("1C;VYT96YT(#T@<')E9U]R97!L
M86-E*"<O*%QR7&Y\7')\7&XI4%))3U))5%DZ6S-=*%QR7&Y\7')\7&XI+R<L
M("=<,5!224]22519.C)<,B<L("1C;VYT96YT+"`Q*3L*("`@("`@("`D8V]N
M=&5N="`]('!R96=?<F5P;&%C92@G+RA<<EQN?%QR?%QN*5!224]22519.ELT
M+3E=*%QR7&Y\7')\7&XI+R<L("=<,5!224]22519.C-<,B<L("1C;VYT96YT
M+"`Q*3L*("`@("`@"@H@("`@("`@("\O(%=I;F1O=W,@36]B:6QE(&%L<V\@
M97AP96-T<R!$544@1$%415,@;&EK92!$544Z,C`P-C`T,3E4,#`P,#`P"B`@
M("`@("`@:68@*'!R96=?;6%T8V@H)R\H7')<;GQ<<GQ<;BE$544Z*"XN+BXN
M+BXN5"XN+BXN+EHI*%QR7&Y\7')\7&XI+R<L"B`@("`@("`@("`@("`@("`D
M8V]N=&5N="PD;2DI('L*("`@("`@("`@("`@)&U;,ET@/2`D=&AI<RT^551#
M,DQO8V%L1&%T92@D;5LR72D["B`@("`@("`@("`@("1C;VYT96YT(#T@<')E
M9U]R97!L86-E*"<O*%QR7&Y\7')\7&XI1%5%.B@N+BXN+BXN+E0N+BXN+BY:
M*2A<<EQN?%QR?%QN*2\G+`H@("`@("`@("`@("`@("`@)UPQ1%5%.B<@+B`D
M;5LR72`N("=<,R<L("1C;VYT96YT+"`Q*3L*("`@("`@("!]"@H@("`@("`@
M(`H@("`@("`@(&EF("A$14)51TQ/1U])0T%,14Y$05)$051!*2!["B`@("`@
M("`@("`@("1F<"`]($!F;W!E;B@G+W1M<"]S>6YC+VQO9RYT>'0G+"`G82<I
M.PH@("`@("`@("`@("!I9B`H)&9P*2!["B`@("`@("`@("`@("`@("!`9G=R
M:71E*"1F<"P@(EQN;W5T<'5T(&-O;G9E<G1E9"!F;W(@8VQI96YT("@D8V]N
M=&5N=%1Y<&4I.EQN(BD["B`@("`@("`@("`@("`@("!`9G=R:71E*"1F<"P@
M)&-O;G1E;G0@+B`B7&XB*3L*("`@("`@("`@("`@("`@($!F8VQO<V4H)&9P
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&%R
M<F%Y*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@0V]N=F5R="!T:&4@8V]N=&5N="X*("`@("`J"B`@("`@*B!#=7)R
M96YT;'D@<W1R:7!S('5I9"`H<')I;6%R>2!K97DI(&EN9F]R;6%T:6]N(&%S
M(&-L:65N="!A;F0*("`@("`J('-E<G9E<B!M:6=H="!U<V4@9&EF9F5R96YT
M(&]N97,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]N=&5N="`@
M("`@("!4:&4@8V]N=&5N="!T;R!C;VYV97)T+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D8V]N=&5N=%1Y<&4@("!4:&4@8V]N=&5N=%1Y<&4@;V8@=&AE(&-O
M;G1E;G0N"B`@("`@*B!`<F5T=7)N(&%R<F%Y("`@("`@("`@("`@("`@(&%R
M<F%Y*"1N97=C;VYT96YT+"`D;F5W8V]N=&5N=%1Y<&4I.@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@8V]N=F5R=&5D(&-O;G1E
M;G0@86YD('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`H<&]S<VEB;'D@8VAA;F=E9"D@;F5W($-O;G1E;G14>7!E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!C;VYV97)T0VQI96YT,E-E<G9E<B@D8V]N=&5N="P@
M)&-O;G1E;G14>7!E*0H@("`@>PH@("`@("`@(&QI<W0H)&-O;G1E;G0L("1C
M;VYT96YT5'EP92D@/0H@("`@("`@("`@("!P87)E;G0Z.F-O;G9E<G1#;&EE
M;G0R4V5R=F5R*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4I.PH*("`@("`@("`O
M+R!3;VUE('-P96-I86P@<')I;W)I='D@:&%N9&QI;F<@:7,@<F5Q=6ER960N
M(%-Y;G1H97-I<R!U<V5S"B`@("`@("`@+R\@,2`H:&EG:"DL(#(@*&UE9&EU
M;2DL(#,H;&]W*2P@870@;&5A<W0@9F]R(&UY('=I;F1O=W,@;6]B:6QE(&1E
M=FEC92X*("`@("`@("`O+R!C;VYV97)T('1H97-E('1O('9A;&ED('!R:6]R
M:71Y('-E='1I;F=S.@H@("`@("`@("1C;VYT96YT(#T@<')E9U]R97!L86-E
M*"<O*%QR7&Y\7')\7&XI4%))3U))5%DZ,RA<<EQN?%QR?%QN*2\G+"`G7#%0
M4DE/4DE463HU7#(G+"`D8V]N=&5N="P@,2D["B`@("`@("`@)&-O;G1E;G0@
M/2!P<F5G7W)E<&QA8V4H)R\H7')<;GQ<<GQ<;BE04DE/4DE463HR*%QR7&Y\
M7')\7&XI+R<L("=<,5!224]22519.C-<,B<L("1C;VYT96YT+"`Q*3L*"B`@
M("`@("!I9B`H1$5"54=,3T=?24-!3$5.1$%21$%402D@>PH@("`@("`@("`@
M("`D9G`@/2!`9F]P96XH)R]T;7`O<WEN8R]L;V<N='AT)RP@)V$G*3L*("`@
M("`@("`@("`@:68@*"1F<"D@>PH@("`@("`@("`@("`@("`@0&9W<FET92@D
M9G`L(")<;FEN<'5T(&-O;G9E<G1E9"!F;W(@<V5R=F5R.B`D8V]N=&5N=%1Y
M<&5<;B(I.PH@("`@("`@("`@("`@("`@0&9W<FET92@D9G`L)&-O;G1E;G0@
M+B`B7&XB*3L*("`@("`@("`@("`@("`@($!F8VQO<V4H)&9P*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&%R<F%Y*"1C;VYT
M96YT+"`D8V]N=&5N=%1Y<&4I.PH@(`H@("`@?0H@("`@"B`@("`*("`@("\J
M(%-T871I8R!H96QP97(@9G5N8W1I;VXZ(&-O;G9E<G1S(&$@551#(%1I;65S
M=&%M<"!L:6ME(#(P,#8P-#$X5#(R,#`P,%H*("`@("`J(&EN=&\@82!L;V-A
M;"!D871E(&QI:V4@,C`P-C`T,3E4,#`P,#`P+B!4:&ES(&ES(&%C='5A;&QY
M(&UO<F4@=&AA;@H@("`@("H@<W1R:7!P:6YG('1H92!T:6UE('!A<G0Z('=E
M(&YE960@=&\@8V]N=F5R="!T;R!L;V-A;"!T:6UE(&9I<G-T('1O(&5N<W5R
M90H@("`@("H@=V4@9V5T('1H92!R:6=H="!D871E(0H@("`@("HO"B`@("!F
M=6YC=&EO;B!55$,R3&]C86Q$871E*"1S*0H@("`@>PH@("`@("`@("1T(#T@
M2&]R9&5?:4-A;&5N9&%R.CI?<&%R<V5$871E5&EM92@D<RD["B`@("`@("`@
M<F5T=7)N(&1A=&4H)UEM9"<L("1T*2`N("=4,#`P,#`P)SL*("`@('T*?0H`
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]3>6YC34PO1&5V:6-E+TYO:VEA
M+G!H<```````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-#4U-2`Q
M,#4Q-30S,S<S-"`P,C(T,S4`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J(%1H92!3>6YC34Q?1&5V:6-E
M7TYO:VEA.CH@8VQA<W,@<')O=FED97,@9G5N8W1I;VYA;&ET>2!T:&%T(&ES
M"B`J('-P96-I9FEC('1O('1H92!.;VMI82!3>6YC34P@8VQI96YT<RX*("H*
M("H@0V]P>7)I9VAT(#(P,#4M,C`P-B!+87)S=&5N($9O=7)M;VYT(#QK87)S
M=&5N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@
M9&ED(&YO=`H@*B!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+U-Y;F--3"]3>6YC34PO1&5V:6-E+TYO:VEA+G!H<"QV(#$N,BXR
M+C,@,C`P-B\P-2\P,2`Q,CHP-3HQ-"!J86X@17AP("0*("H*("H@0&%U=&AO
M<B`@2V%R<W1E;B!&;W5R;6]N="`\:V%R<W1E;D!H;W)D92YO<F<^"B`J($!P
M86-K86=E(%-Y;F--3`H@*B\*8VQA<W,@4WEN8TU,7T1E=FEC95].;VMI82!E
M>'1E;F1S(%-Y;F--3%]$979I8V4@>PH*("`@("\J*@H@("`@("H@0V]N=F5R
M=',@=&AE(&-O;G1E;G0@9G)O;2!T:&4@8F%C:V5N9"!T;R!A(&9O<FUA="!S
M=6ET86)L92!F;W(@=&AE"B`@("`@*B!C;&EE;G0@9&5V:6-E+@H@("`@("H*
M("`@("`J(%-T<FEP<R!T:&4@=6ED("AP<FEM87)Y(&ME>2D@:6YF;W)M871I
M;VX@87,@8VQI96YT(&%N9"!S97)V97(@;6EG:'0@=7-E"B`@("`@*B!D:69F
M97)E;G0@;VYE<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VYT
M96YT("`@("`@(%1H92!C;VYT96YT('1O(&-O;G9E<G0*("`@("`J($!P87)A
M;2!S=')I;F<@)&-O;G1E;G14>7!E("`@5&AE(&-O;G1E;G14>7!E(&]F(&-O
M;G1E;G0@87,@<F5T=7)N960@9G)O;0H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!T:&4@8F%C:V5N9`H@("`@("H@0')E='5R;B!A<G)A
M>2`@("`@("`@("`@("`@("!A<G)A>2@D;F5W8V]N=&5N="P@)&YE=V-O;G1E
M;G14>7!E*3H*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M=&AE(&-O;G9E<G1E9"!C;VYT96YT(&%N9"!T:&4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@*'!O<W-I8FQY(&-H86YG960I(&YE=R!#
M;VYT96YT5'EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]N=F5R=%-E<G9E
M<C)#;&EE;G0H)&-O;G1E;G0L("1C;VYT96YT5'EP92D*("`@('L*("`@("`@
M("!G;&]B86P@)&)A8VME;F0["@H@("`@("`@(&QI<W0H)&-O;G1E;G0L("1C
M;VYT96YT5'EP92D@/0H@("`@("`@("`@("!P87)E;G0Z.F-O;G9E<G1397)V
M97(R0VQI96YT*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4I.PH*("`@("`@("`O
M+R!&25A-13H@:G5S="!S=V%P<&EN9R!O=70@=&AE('9E<G-I;VX@;G5M8F5R
M(&EN('1H92!H96%D97(*("`@("`@("`O+R!S;R!T:&%T('1H92!C;&EE;G0@
M9&]E<VXG="!I;6UE9&EA=&5L>2!D96YY('=I=&@@82`B1F]R;6%T"B`@("`@
M("`@+R\@;F]T('-U<'!O<G1E9"(N(%-E92!H='1P.B\O8G5G<RYH;W)D92YO
M<F<O=&EC:V5T+S]I9#TQ.#@Q+@H@("`@("`@("1C;VYT96YT(#T@<')E9U]R
M97!L86-E*"<O*%QR7&Y\7')\7&XI5D524TE/3CHR+C`O)RP@)UPQ5D524TE/
M3CHQ+C`G+"`D8V]N=&5N="P@,2D["@H@("`@("`@(&EF("A$14)51TQ/1U])
M0T%,14Y$05)$051!*2!["B`@("`@("`@("`@("1F<"`]($!F;W!E;B@G+W1M
M<"]S>6YC+VQO9RYT>'0G+"`G82<I.PH@("`@("`@("`@("!I9B`H)&9P*2![
M"B`@("`@("`@("`@("`@("!`9G=R:71E*"1F<"P@(EQN;W5T<'5T(&-O;G9E
M<G1E9"!F;W(@8VQI96YT("@D8V]N=&5N=%1Y<&4I.EQN(BD["B`@("`@("`@
M("`@("`@("!`9G=R:71E*"1F<"P@)&-O;G1E;G0@+B`B7&XB*3L*("`@("`@
M("`@("`@("`@($!F8VQO<V4H)&9P*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N(&%R<F%Y*"1C;VYT96YT+"`D8V]N=&5N=%1Y
M<&4I.PH@("`@?0H*("`@("\J($YO:VEA(&-U<G)E;G1L>2!E>'!E8W1S(&YO
M=&5S(&%S('1E>'0O<&QA:6XN($UA>6)E('=E(&-A;B!E>'1R86-T"B`@("`@
M*B!T:&ES(&9R;VT@1&5V26YF(')A=&AE<B!T:&%N(&AA<F1C;V1E(&ET+@H@
M("`@("HO"@H@("!F=6YC=&EO;B!G9710<F5F97)R961#;VYT96YT5'EP92@D
M='EP92D*("`@('L*("`@("`@("`@:68@*"1T>7!E(#T]("=N;W1E<R<I('L*
M("`@("`@("`@("`@<F5T=7)N("=T97AT+W!L86EN)SL*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N('!A<F5N=#HZ9V5T4')E9F5R<F5D0V]N=&5N=%1Y<&4H
M)'1Y<&4I.PH@("`@?0H*("`@9G5N8W1I;VX@:&%N9&QE5&%S:W-);D-A;&5N
M9&%R*"D*("`@>PH@("`@("!R971U<FX@=')U93L@("`@("`*("`@?0I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]3>6YC34PO
M0V]M;6%N9```````````````````````````````````````````````````
M```````````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#`P,"`Q,#4Q-30S,S<S-"`P,C`W-3(`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+U-Y;F--3"]#;VUM86YD+T9I;F%L+G!H<```````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`W-3$Q(#$P-3$U-#,S-S,T(#`R,C4W
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*:6YC;'5D95]O;F-E("=3>6YC34PO0V]M;6%N9"YP:'`G.PH*+RHJ
M"B`J(%1H92!3>6YC34Q?0V]M;6%N9%]&:6YA;"!C;&%S<RX*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO4WEN8TU,+U-Y;F--3"]#;VUM86YD+T9I;F%L+G!H
M<"QV(#$N,3`N,3`N-2`R,#`V+S`Q+S`Q(#(Q.C(X.C,V(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($%N=&AO;GD@36EL;',@/&%M:6QL
M<T!P>7)A;6ED-BYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!!
M;G1H;VYY($UI;&QS(#QA;6EL;'-`<'ER86UI9#8N8V]M/@H@*B!`<VEN8V4@
M("!(;W)D92`S+C`*("H@0'!A8VMA9V4@4WEN8TU,"B`J+PIC;&%S<R!3>6YC
M34Q?0V]M;6%N9%]&:6YA;"!E>'1E;F1S(%-Y;F--3%]#;VUM86YD('L*"B`@
M("`O*BH*("`@("`J($-R96%T92!T:&4@<F5S<&]N<V4@9F]R(&$@9FEN86P@
M=&%G"B`@("`@*B\*("`@(&9U;F-T:6]N(&]U='!U="@D8W5R<F5N=$-M9$E$
M+"`F)&]U='!U="D*("`@('L*("`@("`@("`D<W1A=&4@/2`F)%]315-324].
M6R=3>6YC34PN<W1A=&4G73L*("`@("`@("`D871T<G,@/2!A<G)A>2@I.PH*
M("`@("`@("`O+R!)9B!T:&4@8VQI96YT(&AA<VXG="!S96YT('5S(&1E=FEC
M92!I;F9O+"!R97%U97-T(&ET(&YO=RX*("`@("`@("`D9&D@/2!3>6YC34Q?
M1&5V:6-E.CID979I8V5);F9O*"D["B`@("`@("`@:68@*&5M<'1Y*"1D:2T^
M7TUA;BDI('L*("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S
M=&%T92T^9V5T55))*"DL("='970G+"`D871T<G,I.PH*("`@("`@("`@("`@
M)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=#;61)
M1"<L("1A='1R<RD["B`@("`@("`@("`@("1C:&%R<R`]("1C=7)R96YT0VUD
M240["B`@("`@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)&-H87)S*3L*
M("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%52
M22@I+"`G0VUD240G*3L*"B`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE
M;65N="@D<W1A=&4M/F=E=%5222@I+"`G365T82<L("1A='1R<RD["B`@("`@
M("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5224UE
M=&$H*2P@)U1Y<&4G+"`D871T<G,I.PH@("`@("`@("`@("`D871T<G,@/2!A
M<G)A>2@I.PH@("`@("`@("`@("!I9B`H:7-?82@D;W5T<'5T+"`G6$U,7U="
M6$U,7T5N8V]D97(G*2D@>PH@("`@("`@("`@("`@("`@)&-H87)S(#T@34E-
M15]364Y#34Q?1$5624-%7TE.1D]?5T)834P["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D8VAA<G,@/2!-24U%7U-93D--3%]$159)
M0T5?24Y&3U]834P["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&]U='!U
M="T^8VAA<F%C=&5R<R@D8VAA<G,I.PH@("`@("`@("`@("`D;W5T<'5T+3YE
M;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=4>7!E)RD["B`@("`@("`@
M("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)TUE
M=&$G*3L*"B`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A
M=&4M/F=E=%5222@I+"`G271E;2<L("1A='1R<RD["B`@("`@("`@("`@("1O
M=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G5&%R9V5T
M)RP@)&%T=')S*3L*("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT
M*"1S=&%T92T^9V5T55))*"DL("=,;V-54DDG+"`D871T<G,I.PH@("`@("`@
M("`@("`D8VAA<G,@/2`H)'-T871E+3YG971697)S:6]N*"D@/3T@,"D@/R`G
M+B]D979I;F8Q,"<@.B`G+B]D979I;F8Q,2<["B`@("`@("`@("`@("1O=71P
M=70M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@("`@("`@("`@)&]U='!U="T^
M96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G3&]C55)))RD["B`@("`@
M("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@
M)U1A<F=E="<I.PH@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S
M=&%T92T^9V5T55))*"DL("=)=&5M)RD["@H@("`@("`@("`@("`D;W5T<'5T
M+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("='970G*3L*"B`@("`@
M("`@("`@("\O($UA<FL@=&AI<R!I9"!D;W=N(&%S(&YE961I;F<@82!R97-U
M;'1S('!A8VME="!R;W5T960@=&\*("`@("`@("`@("`@+R\@=&AE(%!U="!C
M;VUM86YD+@H@("`@("`@("`@("`D<W1A=&4M/G-E=$5X<&5C=&5D4F5S=6QT
M5'EP92@D8W5R<F5N=$-M9$E$+"`G4'5T)RD["@H@("`@("`@("`@("`D8W5R
M<F5N=$-M9$E$*RL["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D8W5R<F5N
M=$-M9$E$.PH@("`@?0H@("`@+RHJ"B`@("`@*B!#<F5A=&4@82`F;'0[1FEN
M86PF9W0[(&]U='!U="X*("`@("`J($)E9F]R92!T:&%T(&-O;G1I;G5E(&$@
M<WEN8R!I9B!T:&5R92!A<F4@<&5N9&EN9R!E;G1R:65S+@H@("`@("H@4W1A
M=&EC(&UE=&AO9`H@("`@("HO"B`@("!F=6YC=&EO;B!O=71P=71&:6YA;"@D
M8W5R<F5N=$-M9$E$+"`F)&]U='!U="D*("`@('L*("`@("`@("`D<W1A=&4@
M/2`F)%]315-324].6R=3>6YC34PN<W1A=&4G73L*("`@("`@("`D871T<G,@
M/2!A<G)A>2@I.PH*("`@("`@("!G;&]B86P@)&UE<W-A9V5&=6QL.PH@("`@
M("`@("\J($EF('1H97)E)W,@<&5N9&EN9R!S>6YC(&1A=&$@86YD('-P86-E
M(&QE9G0@:6X@=&AE(&UE<W-A9V4Z"B`@("`@("`@("H@<V5N9"!D871A(&YO
M=RX@*B\*("`@("`@("!I9B`H(21M97-S86=E1G5L;"`F)@H@("`@("`@("`@
M("`@("`@8V]U;G0H)'`@/2`D<W1A=&4M/F=E=%!E;F1I;F=3>6YC<R@I*2`^
M(#`I('L*("`@("`@("`@("`@9F]R96%C:"`H)'`@87,@)'!E;F1I;F=3>6YC
M*2!["B`@("`@("`@("`@("`@("!I9B`H(21M97-S86=E1G5L;"D@>PH@("`@
M("`@("`@("`@("`@("`@)$=,3T)!3%-;)V)A8VME;F0G72T^;&]G365S<V%G
M92@G8V]N=&EN=64@<WEN8R!F;W(@<WEN8U1Y<&4])R`N("1P96YD:6YG4WEN
M8RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,
M15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("`@
M("`@("`@("1S>6YC(#T@)B`D<W1A=&4M/F=E=%-Y;F,H)'!E;F1I;F=3>6YC
M*3L*("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=$-M9$E$(#T@)'-Y;F,M
M/F-R96%T95-Y;F-/=71P=70H)&-U<G)E;G1#;61)1"P@)&]U='!U="D["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]("`@("`@
M("\J"B`@("`@("`@("H@1&]N)W0@<V5N9"!T:&4@9FEN86P@=&%G(&EF('=E
M(&AA=F5N)W0@<V5N="!A;&P@<WEN8R!D871A('EE="X*("`@("`@("`@*B\*
M("`@("`@("!I9B`H(21S=&%T92T^:&%S4&5N9&EN9T5L96UE;G1S*"DI('L*
M("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T
M55))*"DL("=&:6YA;"<L("1A='1R<RD["B`@("`@("`@("`@("1O=71P=70M
M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)T9I;F%L)RD["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)$=,3T)!3%-;)V)A8VME;F0G72T^
M;&]G365S<V%G92@G<&5N9&EN9R!E;&5M96YT<RP@;F]T('-E;F1I;F<@9FEN
M86P@=&%G)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)&-U<G)E;G1#;61)1#L*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U-Y;F--3"]#;VUM86YD+U!U
M="YP:'``````````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#(Q,#`Q
M(#$P-3$U-#,S-S,T(#`R,C,P-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`H*:6YC;'5D95]O;F-E("=3>6YC34PO
M0V]M;6%N9"YP:'`G.PH*+RHJ"B`J("1(;W)D93H@9G)A;65W;W)K+U-Y;F--
M3"]3>6YC34PO0V]M;6%N9"]0=70N<&AP+'8@,2XQ,BXQ,"XW(#(P,#8O,#4O
M,S$@,3<Z,#8Z,S8@<V5L<VMY($5X<"`D"B`J"B`J(%1H92!3>6YC34Q?0V]M
M;6%N9%]0=70Z.B!C;&%S<R!H86YD;&5S($1E=DEN9B!D979I8V4@:6YF;W)M
M871I;VX*("H@<V5N="!B>2!T:&4@8VQI96YT+B!4:&4@9&%T82!I<R!S=&]R
M960@:6X@82!3>6YC34Q?1&5V:6-E26YF;PH@*B!O8FIE8W0@=VAI8V@@:7,@
M9&5F:6YE9"!I;B!$979I8V4N<&AP(&%N9"!T:&5N('-T;W)E9"!I;@H@*B!3
M>6YC34Q?1&5V:6-E(&%S(&%N(&%T=')I8G5T92X*("H*("H@0V]P>7)I9VAT
M(#(P,#4M,C`P-B!#=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2V%R<W1E;B!&;W5R;6]N="`\
M:V%R<W1E;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`
M<&%C:V%G92!3>6YC34P*("HO"F-L87-S(%-Y;F--3%]#;VUM86YD7U!U="!E
M>'1E;F1S(%-Y;F--3%]#;VUM86YD('L*"B`@("!V87(@)%]D979I;F8["@H@
M("`@+RHJ"B`@("`@*B!,;V-A;"!V87)S('1O(')E;65M8F5R('-T871E+@H@
M("`@("HO"B`@("!V87(@)%]C=7)R96YT1%,["B`@("!V87(@)%]#5%1Y<&4[
M"B`@("!V87(@)%]697)#5#L*"B`@("!V87(@)%]C=7)R96YT4')O<$YA;64[
M"B`@("!V87(@)%]C=7)R96YT4&%R86U.86UE.PH@("`@=F%R("1?8W5R<F5N
M=$-45'EP93L*"B`@("!V87(@)%]C=7)R96YT6$YA;3L*"B`@("!F=6YC=&EO
M;B!S=&%R=$5L96UE;G0H)'5R:2P@)&5L96UE;G0L("1A='1R<RD*("`@('L*
M("`@("`@("!P87)E;G0Z.G-T87)T16QE;65N="@D=7)I+"`D96QE;65N="P@
M)&%T=')S*3L*("`@("`@("!S=VET8V@@*&-O=6YT*"1T:&ES+3Y?4W1A8VLI
M*2!["B`@("`@("`@8V%S92`Q.@H@("`@("`@("`@("`D=&AI<RT^7V1E=FEN
M9B`]("9N97<@4WEN8TU,7T1E=FEC94EN9F\H*3L*("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@(&-A<V4@-3H*("`@("`@("`@("`@:68@*"1E;&5M96YT
M(#T]("=$871A4W1O<F4G*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-U
M<G)E;G1$4R`]("9N97<@4WEN8TU,7T1A=&%3=&]R92@I.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@('T*"B`@("!F
M=6YC=&EO;B!E;F1%;&5M96YT*"1U<FDL("1E;&5M96YT*0H@("`@>PH@("`@
M("`@(&=L;V)A;"`D8F%C:V5N9#L*"B`@("`@("`@)&1I(#T@)B1T:&ES+3Y?
M9&5V:6YF.PH@("`@("`@('-W:71C:"`H8V]U;G0H)'1H:7,M/E]3=&%C:RDI
M('L*("`@("`@("!C87-E(#$Z"B`@("`@("`@("`@("1?4T534TE/3ELG4WEN
M8TU,+G-T871E)UTM/G-E=$1E=FEC94EN9F\H)&1I*3L*("`@("`@("`@("`@
M:68@*$1%0E5'3$]'7T1%5DE.1BD@>PH@("`@("`@("`@("`@("`@)&9P(#T@
M0&9O<&5N*"<O=&UP+W-Y;F,O9&5V:6YF+G1X="<L("=A)RD["B`@("`@("`@
M("`@("`@("!I9B`H)&9P*2!["B`@("`@("`@("`@("`@("`@("`@0&9W<FET
M92@D9G`L('9A<E]E>'!O<G0H)&1I+"!T<G5E*2D["B`@("`@("`@("`@("`@
M("`@("`@0&9C;&]S92@D9G`I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"@H@("`@("`@(&-A<V4@-3H*("`@("`@("`@("`@<W=I=&-H("@D
M96QE;65N="D@>PH@("`@("`@("`@("!C87-E("=697)$5$0G.@H@("`@("`@
M("`@("`@("`@)&1I+3Y?5F5R1%1$(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G36%N
M)SH*("`@("`@("`@("`@("`@("1D:2T^7TUA;B`]('1R:6TH)'1H:7,M/E]C
M:&%R<RD["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A
M<V4@)TUO9"<Z"B`@("`@("`@("`@("`@("`D9&DM/E]-;V0@/2!T<FEM*"1T
M:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("!C87-E("=/14TG.@H@("`@("`@("`@("`@("`@)&1I+3Y?3T5-(#T@
M=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@8V%S92`G1G=6)SH*("`@("`@("`@("`@("`@("1D:2T^
M7T9W5B`]('1R:6TH)'1H:7,M/E]C:&%R<RD["B`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)U-W5B<Z"B`@("`@("`@("`@("`@
M("`D9&DM/E]3=U8@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=(=U8G.@H@("`@("`@
M("`@("`@("`@)&1I+3Y?2'=6(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G1&5V240G
M.@H@("`@("`@("`@("`@("`@)&1I+3Y?1&5V240@/2!T<FEM*"1T:&ES+3Y?
M8VAA<G,I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C
M87-E("=$9794>7`G.@H@("`@("`@("`@("`@("`@)&1I+3Y?1&5V5'EP(#T@
M=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@8V%S92`G551#)SH*("`@("`@("`@("`@("`@("1D:2T^
M7U540R`]('1R=64["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&-A<V4@)U-U<'!O<G1,87)G94]B:G,G.@H@("`@("`@("`@("`@("`@
M)&1I+3Y?4W5P<&]R=$QA<F=E3V)J<R`]('1R=64["B`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)U-U<'!O<G1.=6UB97)/9D-H
M86YG97,G.@H@("`@("`@("`@("`@("`@)&1I+3Y?4W5P<&]R=$YU;6)E<D]F
M0VAA;F=E<R`]('1R=64["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@(&-A<V4@)T1A=&%3=&]R92<Z"B`@("`@("`@("`@("`@("`D9&DM
M/E]$871A4W1O<F5;72`]("1T:&ES+3Y?8W5R<F5N=$13.PH@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=#5$-A<"<Z"B`@("`@
M("`@("`@(&-A<V4@)T5X="<Z"B`@("`@("`@("`@("`@("`O+R!!=71O;6%T
M:6-A;&QY(&AA;F1L960@8GD@<W5B96QE;65N=',N"B`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@8V%S92`V.@H@("`@("`@("`@("!I9B`H)'1H:7,M/E]3=&%C:ULT
M72`]/2`G1&%T85-T;W)E)RD@>PH@("`@("`@("`@("`@("`@<W=I=&-H("@D
M96QE;65N="D@>PH@("`@("`@("`@("`@("`@8V%S92`G4V]U<F-E4F5F)SH*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-U<G)E;G1$4RT^7U-O=7)C
M95)E9B`]('1R:6TH)'1H:7,M/E]C:&%R<RD["B`@("`@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G1&ES<&QA>4YA;64G
M.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=$13+3Y?1&ES
M<&QA>4YA;64@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)TUA>$=52413
M:7IE)SH*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-U<G)E;G1$4RT^
M7TUA>$=52413:7IE(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=$4TUE
M;2<Z"B`@("`@("`@("`@("`@("`@("`@+R\@0W5R<F5N=&QY(&EG;F]R960L
M('1O(&)E(&1O;F4N"B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("`@("`@8V%S92`G4WEN8T-A<"<Z"B`@("`@("`@("`@("`@("`@
M("`@+R\@075T;VUA=&EC86QL>2!H86YD;&5D(&)Y(%-Y;F-4>7!E('-U8F5L
M96UE;G0N"B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("`@("`@8V%S92`G4G@M4')E9B<Z"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]C=7)R96YT1%,M/E]2>%]0<F5F6R1T:&ES+3Y?0U14>7!E72`]("1T
M:&ES+3Y?5F5R0U0["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("`@("`@8V%S92`G4G@G.@H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?8W5R<F5N=$13+3Y?4GA;)'1H:7,M/E]#5%1Y<&5=(#T@)'1H:7,M
M/E]697)#5#L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@("`@("!C87-E("=4>"U0<F5F)SH*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7V-U<G)E;G1$4RT^7U1X7U!R969;)'1H:7,M/E]#5%1Y<&5=(#T@
M)'1H:7,M/E]697)#5#L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@("`@("!C87-E("=4>"<Z"B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]C=7)R96YT1%,M/E]4>%LD=&AI<RT^7T-45'EP95T@/2`D=&AI
M<RT^7U9E<D-4.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)'1H
M:7,M/E]3=&%C:ULT72`]/2`G0U1#87`G*2!["B`@("`@("`@("`@("`@("!S
M=VET8V@@*"1E;&5M96YT*2!["B`@("`@("`@("`@("`@("!C87-E("=#5%1Y
M<&4G.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=$-45'EP
M92`]('1R:6TH)'1H:7,M/E]C:&%R<RD["B`@("`@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G4')O<$YA;64G.@H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=%!R;W!.86UE(#T@=')I
M;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@("`@("`@("`O+R!297-E
M="!P87)A;2!S=&%T92X*("`@("`@("`@("`@("`@("`@("!U;G-E="@D=&AI
M<RT^7V-U<G)E;G1087)A;4YA;64I.PH@("`@("`@("`@("`@("`@("`@("1D
M:2T^7T-40V%P6R1T:&ES+3Y?8W5R<F5N=$-45'EP95U;)'1H:7,M/E]C=7)R
M96YT4')O<$YA;65=(#T@)FYE=R!3>6YC34Q?4')O<&5R='DH*3L*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=0
M87)A;4YA;64G.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N
M=%!A<F%M3F%M92`]('1R:6TH)'1H:7,M/E]C:&%R<RD["B`@("`@("`@("`@
M("`@("`@("`@)&1I+3Y?0U1#87!;)'1H:7,M/E]C=7)R96YT0U14>7!E75LD
M=&AI<RT^7V-U<G)E;G10<F]P3F%M95TM/E]P87)A;7-;)'1H:7,M/E]C=7)R
M96YT4&%R86U.86UE72`]("9N97<@4WEN8TU,7U!R;W!E<G1Y4&%R86UE=&5R
M*"D["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@
M("`@8V%S92`G5F%L16YU;2<Z"B`@("`@("`@("`@("`@("`@("`@:68@*"%E
M;7!T>2@D=&AI<RT^7V-U<G)E;G1087)A;4YA;64I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("\O(%=E)W)E(&EN('!A<F%M971E<B!M;V1E+@H@("`@
M("`@("`@("`@("`@("`@("`@("`D9&DM/E]#5$-A<%LD=&AI<RT^7V-U<G)E
M;G1#5%1Y<&5=6R1T:&ES+3Y?8W5R<F5N=%!R;W!.86UE72T^7W!A<F%M<ULD
M=&AI<RT^7V-U<G)E;G1087)A;4YA;65=+3Y?5F%L16YU;5MT<FEM*"1T:&ES
M+3Y?8VAA<G,I72`]('1R=64["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)&1I+3Y?0U1#87!;)'1H:7,M
M/E]C=7)R96YT0U14>7!E75LD=&AI<RT^7V-U<G)E;G10<F]P3F%M95TM/E]6
M86Q%;G5M6W1R:6TH)'1H:7,M/E]C:&%R<RE=(#T@=')U93L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("`@("`@8V%S92`G1&%T851Y<&4G.@H@("`@("`@("`@("`@("`@
M("`@(&EF("@A96UP='DH)'1H:7,M/E]C=7)R96YT4&%R86U.86UE*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`O+R!792=R92!I;B!P87)A;65T97(@
M;6]D92X*("`@("`@("`@("`@("`@("`@("`@("`@)&1I+3Y?0U1#87!;)'1H
M:7,M/E]C=7)R96YT0U14>7!E75LD=&AI<RT^7V-U<G)E;G10<F]P3F%M95TM
M/E]P87)A;7-;)'1H:7,M/E]C=7)R96YT4&%R86U.86UE72T^7T1A=&%4>7!E
M(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D9&DM/E]#5$-A<%LD
M=&AI<RT^7V-U<G)E;G1#5%1Y<&5=6R1T:&ES+3Y?8W5R<F5N=%!R;W!.86UE
M72T^7T1A=&%4>7!E(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("`@("`@8V%S92`G4VEZ92<Z"B`@("`@("`@("`@("`@("`@("`@
M:68@*"%E;7!T>2@D=&AI<RT^7V-U<G)E;G1087)A;4YA;64I*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("\O(%=E)W)E(&EN('!A<F%M971E<B!M;V1E
M+@H@("`@("`@("`@("`@("`@("`@("`@("`D9&DM/E]#5$-A<%LD=&AI<RT^
M7V-U<G)E;G1#5%1Y<&5=6R1T:&ES+3Y?8W5R<F5N=%!R;W!.86UE72T^7W!A
M<F%M<ULD=&AI<RT^7V-U<G)E;G1087)A;4YA;65=+3Y?4VEZ92`]('1R:6TH
M)'1H:7,M/E]C:&%R<RD["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&1I+3Y?0U1#87!;)'1H:7,M/E]C
M=7)R96YT0U14>7!E75LD=&AI<RT^7V-U<G)E;G10<F]P3F%M95TM/E]3:7IE
M(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@
M8V%S92`G1&ES<&QA>4YA;64G.@H@("`@("`@("`@("`@("`@("`@(&EF("@A
M96UP='DH)'1H:7,M/E]C=7)R96YT4&%R86U.86UE*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!792=R92!I;B!P87)A;65T97(@;6]D92X*("`@
M("`@("`@("`@("`@("`@("`@("`@)&1I+3Y?0U1#87!;)'1H:7,M/E]C=7)R
M96YT0U14>7!E75LD=&AI<RT^7V-U<G)E;G10<F]P3F%M95TM/E]P87)A;7-;
M)'1H:7,M/E]C=7)R96YT4&%R86U.86UE72T^7T1I<W!L87E.86UE(#T@=')I
M;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D9&DM/E]#5$-A<%LD=&AI<RT^
M7V-U<G)E;G1#5%1Y<&5=6R1T:&ES+3Y?8W5R<F5N=%!R;W!.86UE72T^7T1I
M<W!L87E.86UE(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D=&AI
M<RT^7U-T86-K6S1=(#T]("=%>'0G("8F("1E;&5M96YT(#T]("=83F%M)RD@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C=7)R96YT6$YA;2`]('1R:6TH
M)'1H:7,M/E]C:&%R<RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@
M*"1T:&ES+3Y?4W1A8VM;-%T@/3T@)T5X="<@)B8@)&5L96UE;G0@/3T@)UA6
M86PG*2!["B`@("`@("`@("`@("`@("`D9&DM/E]%>'1;)'1H:7,M/E]C=7)R
M96YT6$YA;5U;72`]('1R:6TH)'1H:7,M/E]C:&%R<RD["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@-SH*("`@("`@
M("`@("`@:68@*"1E;&5M96YT(#T]("=697)#5"<I('L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?5F5R0U0@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@
M("`@("`@("!](&5L<V5I9B`H)&5L96UE;G0@/3T@)T-45'EP92<I('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?0U14>7!E(#T@=')I;2@D=&AI<RT^7V-H
M87)S*3L*("`@("`@("`@("`@?2!E;'-E:68@*"1E;&5M96YT(#T]("=3>6YC
M5'EP92<I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=$13+3Y?
M4WEN8T-A<%MT<FEM*"1T:&ES+3Y?8VAA<G,I72`]('1R=64["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("!P
M87)E;G0Z.F5N9$5L96UE;G0H)'5R:2P@)&5L96UE;G0I.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&]U='!U="@D8W5R<F5N=$-M9$E$+"`F)&]U='!U="D*("`@
M('L*("`@("`@("`D<W1A=&4@/2`F)%]315-324].6R=3>6YC34PN<W1A=&4G
M73L*"B`@("`@("`@)'-T871U<R`]("9N97<@4WEN8TU,7T-O;6UA;F1?4W1A
M='5S*"@H)'-T871E+3YI<T%U=&AO<FEZ960H*2D@/R!215-03TY315]/2R`Z
M(%)%4U!/3E-%7TE.5D%,241?0U)%1$5.5$E!3%,I+"`G4'5T)RD["B`@("`@
M("`@)'-T871U<RT^<V5T0VUD4F5F*"1T:&ES+3Y?8VUD240I.PH*("`@("`@
M("`D<F5F(#T@*"1S=&%T92T^9V5T5F5R<VEO;B@I(#T](#`I(#\@)RXO9&5V
M:6YF,3`G(#H@)RXO9&5V:6YF,3$G.PH*("`@("`@("`D<W1A='5S+3YS9713
M;W5R8V52968H)')E9BD["@H@("`@("`@(')E='5R;B`D<W1A='5S+3YO=71P
M=70H)&-U<G)E;G1#;61)1"P@)&]U='!U="D["B`@("!]"@I]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O4WEN8TU,+T-O
M;6UA;F0O4F5S=6QT<RYP:'``````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#8W,#4@,3`U,34T,S,W,S0@,#(S,C$S`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@II;F-L=61E7V]N8V4@
M)U-Y;F--3"]#;VUM86YD+G!H<"<["@HO*BH*("H@)$AO<F1E.B!F<F%M97=O
M<FLO4WEN8TU,+U-Y;F--3"]#;VUM86YD+U)E<W5L=',N<&AP+'8@,2XQ,2XQ
M,"XV(#(P,#8O,#<O,#(@,3`Z-#@Z,C`@:V%R<W1E;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,RTR,#`V($%N=&AO;GD@36EL;',@/&%M:6QL<T!P>7)A
M;6ED-BYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!.871H86X@
M4"!3:&%R<`H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@4WEN
M8TU,"B`J+PIC;&%S<R!3>6YC34Q?0V]M;6%N9%]297-U;'1S(&5X=&5N9',@
M4WEN8TU,7T-O;6UA;F0@>PH*("`@('9A<B`D7W-U8D-O;6UA;F0["B`@("!V
M87(@)%]S879E9%5R:3L*("`@('9A<B`D7W-A=F5D16QE;65N=#L*("`@('9A
M<B`D7W-A=F5D071T<G,["B`@("!V87(@)%]S879E9$-M9$E$.PH@("`@=F%R
M("1?8VAA<G,["@H@("`@9G5N8W1I;VX@<W1A<G1%;&5M96YT*"1U<FDL("1E
M;&5M96YT+"`D871T<G,I"B`@("!["B`@("`@("`@<&%R96YT.CIS=&%R=$5L
M96UE;G0H)'5R:2P@)&5L96UE;G0L("1A='1R<RD["@H@("`@("`@('-W:71C
M:"`H8V]U;G0H)'1H:7,M/E]3=&%C:RDI('L*("`@("`@("!C87-E(#$Z"B`@
M("`@("`@("`@("\O(%-A=F4@=&AE(&EN9F\L('=E(&UA>2!H879E('1O(')E
M+7-E;F0@=&AI<R!S=&%R=$5L96UE;G0*("`@("`@("`@("`@+R\@=&\@=&AE
M('-U8BUC;VUM86YD(&QA=&5R+@H@("`@("`@("`@("`D=&AI<RT^7W-A=F5D
M57)I(#T@)'5R:3L*("`@("`@("`@("`@)'1H:7,M/E]S879E9$5L96UE;G0@
M/2`D96QE;65N=#L*("`@("`@("`@("`@)'1H:7,M/E]S879E9$%T=')S(#T@
M)&%T=')S.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^7W-U8D-O;6UA;F0I*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?<W5B0V]M;6%N9"T^<W1A<G1%;&5M96YT*"1U<FDL("1E;&5M
M96YT+"`D871T<G,I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!E
M;F1%;&5M96YT*"1U<FDL("1E;&5M96YT*0H@("`@>PH@("`@("`@('-W:71C
M:"`H8V]U;G0H)'1H:7,M/E]3=&%C:RDI('L*("`@("`@("!C87-E(#(Z"B`@
M("`@("`@("`@(&EF("@D96QE;65N="`]/2`G0VUD240G("8F("%I<W-E="@D
M=&AI<RT^7W-U8D-O;6UA;F0I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7W-A=F5D0VUD240@/2!I;G1V86PH=')I;2@D=&AI<RT^7V-H87)S*2D["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D96QE;65N="`]/2`G0VUD
M4F5F)RD@>PH@("`@("`@("`@("`@("`@)&-M9%)E9B`](&EN='9A;"AT<FEM
M*"1T:&ES+3Y?8VAA<G,I*3L*("`@("`@("`@("`@("`@("1S=&%T92`]("8D
M7U-%4U-)3TY;)U-Y;F--3"YS=&%T92==.PH*("`@("`@("`@("`@("`@("\O
M($EF('1H:7,@<F5S=6QT('!A8VME="!I<R!R96QA=&5D('1O('-O;65T:&EN
M9R!A;F0*("`@("`@("`@("`@("`@("\O(&YE961S('1O(&)E(')O=71E9"!T
M;R!A('!A<G1I8W5L87(@8V]M;6%N9"!O8FIE8W0L"B`@("`@("`@("`@("`@
M("`O+R!D;R!I="!N;W<N"B`@("`@("`@("`@("`@("`D8VUD5'EP92`]("1S
M=&%T92T^9V5T17AP96-T961297-U;'14>7!E*"1C;612968I.PH@("`@("`@
M("`@("`@("`@:68@*"%E;7!T>2@D8VUD5'EP92DI('L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W-U8D-O;6UA;F0@/2`F4WEN8TU,7T-O;6UA;F0Z
M.F9A8W1O<GDH)&-M9%1Y<&4I.PH@("`@("`@("`@("`@("`@("`@("\O(%1H
M:7,@:7-N)W0@=&]T86QL>2!T96-H;FEC86QL>2!C;W)R96-T(&)E8V%U<V4*
M("`@("`@("`@("`@("`@("`@("`O+R!T:&4@6$U,(&-O=6QD(&AA=F4@8F5E
M;B!O=70@;V8@;W)D97(@86YD('=E"B`@("`@("`@("`@("`@("`@("`@+R\@
M;6EG:'0@:&%V92!M:7-S960@<V]M92!S='5F9BP@8G5T(&EN(')E86QI='DL
M"B`@("`@("`@("`@("`@("`@("`@+R\@:70@<')O8F%B;'D@=V]N)W0@:&%P
M<&5N+@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<W5B0V]M;6%N9"T^
M<W1A<G1%;&5M96YT*`H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W-A=F5D57)I+`H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-A
M=F5D16QE;65N="P*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S
M879E9$%T=')S*3L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]S879E9$-M9$E$*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!&25A-13H@4VAO=6QD;B=T(&)E(&%C8V5S<VEN9R!T:&ES('!R:79A=&4*
M("`@("`@("`@("`@("`@("`@("`@("`@+R\@;65M8F5R+@H@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W-U8D-O;6UA;F0M/E]C;61)1"`]("1T
M:&ES+3Y?<V%V961#;61)1#L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@("`@("\O($9A;&P@=&AR;W5G:"!T;R!T
M:&4@9&5F875L="!C87-E+@H*("`@("`@("!D969A=6QT.@H@("`@("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]S=6)#;VUM86YD*2D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]S=6)#;VUM86YD+3YE;F1%;&5M96YT*"1U<FDL("1E
M;&5M96YT*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("!]"@H@("`@("`@('!A<F5N=#HZ96YD16QE;65N="@D=7)I+"`D96QE
M;65N="D["B`@("!]"@H@("`@9G5N8W1I;VX@8VAA<F%C=&5R<R@D<W1R*0H@
M("`@>PH@("`@("`@('!A<F5N=#HZ8VAA<F%C=&5R<R@D<W1R*3L*("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]S=6)#;VUM86YD*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7W-U8D-O;6UA;F0M/F-H87)A8W1E<G,H)'-T<BD["B`@("`@
M("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&]U='!U="@D8W5R<F5N=$-M9$E$
M+"`F)&]U='!U="D*("`@('L*("`@("`@("`D<W1A=&4@/2`F)%]315-324].
M6R=3>6YC34PN<W1A=&4G73L*"B`@("`@("`@)'-T871U<R`]("9N97<@4WEN
M8TU,7T-O;6UA;F1?4W1A='5S*%)%4U!/3E-%7T]++"`G4F5S=6QT<R<I.PH@
M("`@("`@("1S=&%T=7,M/G-E=$-M9%)E9B@D=&AI<RT^7V-M9$E$*3L*"B`@
M("`@("`@)')E9B`]("@D<W1A=&4M/F=E=%9E<G-I;VXH*2`]/2`P*2`_("<N
M+V1E=FEN9C$P)R`Z("<N+V1E=FEN9C$Q)SL*("`@("`@("`D<W1A='5S+3YS
M9713;W5R8V52968H)')E9BD["@H@("`@("`@(')E='5R;B`D<W1A='5S+3YO
M=71P=70H)&-U<G)E;G1#;61)1"P@)&]U='!U="D["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U-Y;F--3"]#
M;VUM86YD+TUA<"YP:'``````````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#$P-3(R(#$P-3$U-#,S-S,T(#`R,C(U-P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`H*:6YC;'5D95]O;F-E
M("=3>6YC34PO0V]M;6%N9"YP:'`G.PH*+RHJ"B`J(%1H92!3>6YC34Q?36%P
M(&-L87-S('!R;W9I9&5S(&$@4WEN8TU,(&EM<&QE;65N=&%T:6]N(&]F"B`J
M('1H92!-87`@8V]M;6%N9"!A<R!D969I;F5D(&EN(%-Y;F--3"!297!R97-E
M;G1A=&EO;B!0<F]T;V-O;"P*("H@=F5R<VEO;B`Q+C`N,2`U+C4N."X*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO4WEN8TU,+U-Y;F--3"]#;VUM86YD+TUA
M<"YP:'`L=B`Q+C$N,3`N-B`R,#`V+S`Q+S`Q(#(Q.C(X.C,V(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($MA<G-T96X@1F]U<FUO;G0@
M/&MA<G-T96Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@2V%R<W1E;B!&;W5R;6]N="`\:V%R<W1E;D!H;W)D92YO<F<^"B`J($!S
M:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!3>6YC34P*("HO"F-L87-S
M(%-Y;F--3%]#;VUM86YD7TUA<"!E>'1E;F1S(%-Y;F--3%]#;VUM86YD('L*
M"B`@("`O*BH*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D
M7W-O=7)C94QO8U5223L*"B`@("`O*BH*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D7W1A<F=E=$QO8U5223L*"B`@("!V87(@)%]M87!4
M87)G970["B`@("!V87(@)%]M87!3;W5R8V4["@H@("`@9G5N8W1I;VX@;W5T
M<'5T*"1C=7)R96YT0VUD240L("8D;W5T<'5T*0H@("`@>PH@("`@("`@("1A
M='1R<R`](&%R<F%Y*"D["@H@("`@("`@("1S=&%T92`]("8D7U-%4U-)3TY;
M)U-Y;F--3"YS=&%T92==.PH*("`@("`@("`D<W1A='5S(#T@)FYE=R!3>6YC
M34Q?0V]M;6%N9%]3=&%T=7,H)'-T871E+3YI<T%U=&AO<FEZ960H*2`_(%)%
M4U!/3E-%7T]+(#H@4D534$].4T5?24Y604Q)1%]#4D5$14Y424%,4RP@)TUA
M<"<I.PH@("`@("`@("1S=&%T=7,M/G-E=$-M9%)E9B@D=&AI<RT^7V-M9$E$
M*3L*("`@("`@("!I9B`H)'1H:7,M/E]S;W5R8V5,;V-54DD@(3T@;G5L;"D@
M>PH@("`@("`@("`@("`D<W1A='5S+3YS9713;W5R8V52968H)'1H:7,M/E]S
M;W5R8V5,;V-54DDI.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/E]T
M87)G971,;V-54DD@(3T@;G5L;"D@>PH@("`@("`@("`@("`D<W1A='5S+3YS
M971487)G9712968H)'1H:7,M/E]T87)G971,;V-54DDI.PH@("`@("`@('T*
M"B`@("`@("`@)&-U<G)E;G1#;61)1"`]("1S=&%T=7,M/F]U='!U="@D8W5R
M<F5N=$-M9$E$+"`D;W5T<'5T*3L*"B`@("`@("`@<F5T=7)N("1C=7)R96YT
M0VUD240["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971T97(@9F]R('!R;W!E
M<G1Y('-O=7)C955222X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S
M;W5R8V554DD@($YE=R!V86QU92!O9B!P<F]P97)T>2!S;W5R8V554DDN"B`@
M("`@*B\*("`@(&9U;F-T:6]N('-E=%-O=7)C94QO8U5222@D<V]U<F-E55))
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<V]U<F-E55))(#T@)'-O=7)C9552
M23L*("`@('T*"B`@("!F=6YC=&EO;B!G971487)G971,;V-54DDH*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W1A<F=E=%5223L*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E='1E<B!F;W(@<')O<&5R='D@=&%R9V5T55))+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1A<F=E=%5222`@3F5W('9A
M;'5E(&]F('!R;W!E<G1Y('1A<F=E=%5222X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<V5T5&%R9V5T55))*"1T87)G97154DDI"B`@("!["B`@("`@("`@)'1H
M:7,M/E]T87)G97154DD@/2`D=&%R9V5T55)).PH@("`@?0H*("`@(&9U;F-T
M:6]N('-T87)T16QE;65N="@D=7)I+"`D96QE;65N="P@)&%T=')S*0H@("`@
M>PH@("`@("`@('!A<F5N=#HZ<W1A<G1%;&5M96YT*"1U<FDL("1E;&5M96YT
M+"`D871T<G,I.PH*("`@("`@("!S=VET8V@@*&-O=6YT*"1T:&ES+3Y?4W1A
M8VLI*2!["B`@("`@("`@8V%S92`R.@H@("`@("`@("`@("!I9B`H)&5L96UE
M;G0@/3T@)TUA<$ET96TG*2!["B`@("`@("`@("`@("`@("!U;G-E="@D=&AI
M<RT^7VUA<%1A<F=E="D["B`@("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^
M7VUA<%-O=7)C92D["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&5N9$5L96UE;G0H)'5R
M:2P@)&5L96UE;G0I"B`@("!["B`@("`@("`@9VQO8F%L("1B86-K96YD.PH*
M("`@("`@("!S=VET8V@@*&-O=6YT*"1T:&ES+3Y?4W1A8VLI*2!["B`@("`@
M("`@8V%S92`Q.@H@("`@("`@("`@("`D<W1A=&4@/2`F)%]315-324].6R=3
M>6YC34PN<W1A=&4G73L*("`@("`@("`@("`@)'-Y;F,@/2`F("1S=&%T92T^
M9V5T4WEN8R@D=&AI<RT^7W1A<F=E=$QO8U5222D["B`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("!C87-E(#(Z"B`@("`@("`@("`@(&EF("@D96QE;65N
M="`]/2`G36%P271E;2<I('L*("`@("`@("`@("`@("`@("1S=&%T92`]("8D
M7U-%4U-)3TY;)U-Y;F--3"YS=&%T92==.PH@("`@("`@("`@("`@("`@)'-Y
M;F,@/2`F("1S=&%T92T^9V5T4WEN8R@D=&AI<RT^7W1A<F=E=$QO8U5222D[
M"B`@("`@("`@("`@("`@("!I9B`H(21S=&%T92T^:7-!=71H;W)I>F5D*"DI
M('L*("`@("`@("`@("`@("`@("`@("`D8F%C:V5N9"T^;&]G365S<V%G92@G
M3F]T($%U=&AO<FEZ960@:6X@36%P271E;2$G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@+R\@3W9E<G=R:71E(&5X:7-T:6YG(&1A=&$@8GD@
M<F5M;W9I;F<@:70@9FER<W0N"B`@("`@("`@("`@("`@("`@("`@)&)A8VME
M;F0M/F-R96%T955I9$UA<"@D<W1A=&4M/F=E=%-Y;F-)9&5N=&EF:65R*"DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W1A<F=E=$QO8U5222P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;6%P4V]U<F-E+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]M
M87!487)G970I.PH*("`@("`@("`@("`@("`@("`@("`D8F%C:V5N9"T^;&]G
M365S<V%G92@G8W)E871E9"!-87`@9F]R('-O=7)C93TG"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`D=&AI<RT^7VUA<%-O
M=7)C90H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("X@)R!A;F0@=&%R9V5T/2<@+B`D=&AI<RT^7VUA<%1A<F=E=`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)R!I;B!D8B`G
M("X@)'1H:7,M/E]T87)G971,;V-54DDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%2
M7TQ/1U]$14)51RD["@H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(#,Z"B`@("`@("`@
M("`@(&EF("@D96QE;65N="`]/2`G3&]C55)))RD@>PH@("`@("`@("`@("`@
M("`@:68@*"1T:&ES+3Y?4W1A8VM;,5T@/3T@)U-O=7)C92<I('L*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W-O=7)C94QO8U5222`]('1R:6TH)'1H
M:7,M/E]C:&%R<RD["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)'1H:7,M
M/E]3=&%C:ULQ72`]/2`G5&%R9V5T)RD@>PH@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?=&%R9V5T3&]C55))(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@8V%S92`T.@H@("`@("`@("`@("!I9B`H)&5L96UE
M;G0@/3T@)TQO8U5222<I('L*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^
M7U-T86-K6S)=(#T]("=3;W5R8V4G*2!["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]M87!3;W5R8V4@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@
M("`@("`@("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?4W1A8VM;,ET@/3T@)U1A
M<F=E="<I('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VUA<%1A<F=E
M="`]('1R:6TH)'1H:7,M/E]C:&%R<RD["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@
M("`@("!P87)E;G0Z.F5N9$5L96UE;G0H)'5R:2P@)&5L96UE;G0I.PH@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O4WEN8TU,+T-O;6UA;F0O4WEN
M8T5L96UE;G0N<&AP````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3$V,S0@
M,3`U,34T,S,W,S0@,#(S-S<U`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"@II;F-L=61E7V]N8V4@)U-Y;F--3"]#
M;VUM86YD+G!H<"<["@HO*BH*("H@5&AE(&-L87-S(%-Y;F--3%]#;VUM86YD
M7U-Y;F-%;&5M96YT('-T;W)E<R!I;F9O<FUA=&EO;B!F<F]M('1H92!!9&0L
M"B`J($1E;&5T92!A;F0@4F5P;&%C92!E;&5M96YT<R!F;W5N9"!I;G-I9&4@
M82!S>6YC(&-O;6UA;F0N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U-Y;F--
M3"]3>6YC34PO0V]M;6%N9"]3>6YC16QE;65N="YP:'`L=B`Q+C,N,BXS(#(P
M,#8O,#$O,#$@,C$Z,C@Z,S8@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`U+3(P,#8@5&AE(&AO<F1E('!R;VIE8W0@*'=W=RYH;W)D92YO<F<I"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!+87)S=&5N($9O=7)M;VYT(#QK
M87)S=&5N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P
M86-K86=E(%-Y;F--3`H@*B\*8VQA<W,@4WEN8TU,7T-O;6UA;F1?4WEN8T5L
M96UE;G0@97AT96YD<R!3>6YC34Q?0V]M;6%N9"!["@H@("`@+RHJ"B`@("`@
M*B!!9&0L($1E;&5T92!O<B!297!L86-E+@H@("`@("HO"B`@("!V87(@)%]E
M;&5M96YT5'EP93L*"B`@("`O*BH*("`@("`J($%R<F%Y(&]F(%-Y;F--3%]3
M>6YC271E;2!E;G1R:65S+@H@("`@("HO"B`@("!V87(@)%]I=&5M<R`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!-:6UE='EP92!F;W(@86QL(&ET96US
M+@H@("`@("HO"B`@("!V87(@)%]C;VYT96YT5'EP93L*"B`@("`O*BH*("`@
M("`J(%1E;7`@9&%T82!F;W(@8W)E871I;VX@;V8@:6YD:79I9'5A;"!I=&5M
M<RX*("`@("`J+PH@("`@=F%R("1?8V]N=&5N=#L*"B`@("!V87(@)%]C=6ED
M.PH*("`@("\J*@H@("`@("H@36EM971Y<&4@9F]R(&EN9&EV:61U86P@:71E
M;2X*("`@("`J+PH@("`@=F%R("1?:71E;4-O;F5N=%1Y<&4["@H@("`@+RHJ
M"B`@("`@*B!#<F5A=&5S(&$@4WEN8R!%;&5M96YT+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@96QE;65N=%1Y<&4@96ET:&5R($%D9"P@1&5L971E
M(&]R(%)E<&QA8V4*("`@("`J+PH@("`@9G5N8W1I;VX@4WEN8TU,7T-O;6UA
M;F1?4WEN8T5L96UE;G0H)&5L96UE;G14>7!E*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?96QE;65N=%1Y<&4@/2`D96QE;65N=%1Y<&4["B`@("!]"@H@("`@
M9G5N8W1I;VX@;W5T<'5T*"1C=7)R96YT0VUD240L("8D;W5T<'5T*0H@("`@
M>PH@("`@("`@('-W:71C:"`H)'1H:7,M/E]E;&5M96YT5'EP92D@>PH@("`@
M("`@(&-A<V4@)T%D9"<Z"B`@("`@("`@("`@("1R97-P;VYS92`](%)%4U!/
M3E-%7TE414U?041$140["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C
M87-E("=$96QE=&4G.@H@("`@("`@("`@("`D<F5S<&]N<V4@/2!215-03TY3
M15]/2SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)U)E<&QA
M8V4G.@H@("`@("`@("`@("`D<F5S<&]N<V4@/2!215-03TY315]/2SL*("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("`D<W1A='5S(#T@
M)FYE=R!3>6YC34Q?0V]M;6%N9%]3=&%T=7,H)')E<W!O;G-E+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V5L96UE;G14>7!E*3L*("`@("`@("`D<W1A='5S+3YS971#;612968H)'1H
M:7,M/E]C;61)1"D["@H@("`@("`@(')E='5R;B`D<W1A='5S+3YO=71P=70H
M)&-U<G)E;G1#;61)1"P@)&]U='!U="D["B`@("!]"@H@("`@9G5N8W1I;VX@
M<W1A<G1%;&5M96YT*"1U<FDL("1E;&5M96YT+"`D871T<G,I"B`@("!["B`@
M("`@("`@<&%R96YT.CIS=&%R=$5L96UE;G0H)'5R:2P@)&5L96UE;G0L("1A
M='1R<RD["B`@("`@("`@<W=I=&-H("AC;W5N="@D=&AI<RT^7U-T86-K*2D@
M>PH@("`@("`@(&-A<V4@,CH*("`@("`@("`@("`@)'1H:7,M/E]C=6ED(#T@
M;G5L;#L*("`@("`@("`@("`@)'1H:7,M/E]C;VYT96YT(#T@;G5L;#L*("`@
M("`@("`@("`@)'1H:7,M/E]I=&5M0V]N=&5N=%1Y<&4@/2!N=6QL.PH@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@
M96YD16QE;65N="@D=7)I+"`D96QE;65N="D*("`@('L*("`@("`@("!S=VET
M8V@@*&-O=6YT*"1T:&ES+3Y?4W1A8VLI*2!["B`@("`@("`@8V%S92`Q.@H@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`R.@H@("`@("`@("`@
M("!I9B`H)&5L96UE;G0@/3T@)TET96TG*2!["B`@("`@("`@("`@("`@("!I
M9B`H96UP='DH)'1H:7,M/E]I=&5M0V]N=&5N=%1Y<&4I"B`@("`@("`@("`@
M("`@("`@("`@)B8@(65M<'1Y*"1T:&ES+3Y?8V]N=&5N=%1Y<&4I*2!["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I=&5M0V]N=&5N=%1Y<&4@/2`D
M=&AI<RT^7V-O;G1E;G14>7!E.PH@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?:71E;7-;72`]("9N97<@4WEN8TU,7U-Y;F-)
M=&5M*"1T:&ES+3Y?96QE;65N=%1Y<&4L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-O
M;G1E;G0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7VET96U#;VYT96YT5'EP92P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?8W5I9"D["B`@("`@("`@("`@('T*"B`@("`@("`@
M8V%S92`S.@H@("`@("`@("`@("!I9B`H)&5L96UE;G0@/3T@)U1Y<&4G*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7V-O;G1E;G14>7!E(#T@=')I;2@D
M=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@?2!E;'-E:68@*"1E;&5M96YT
M(#T]("=$871A)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C;VYT96YT
M(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`T.@H@("`@("`@("`@("!I9B`H
M)&5L96UE;G0@/3T@)TQO8U5222<I('L*("`@("`@("`@("`@("`@(&EF("@D
M=&AI<RT^7U-T86-K6S)=(#T]("=3;W5R8V4G*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]C=6ED(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@
M("`@("`@("`@("`@('T@96QS96EF("@D=&AI<RT^7U-T86-K6S)=(#T]("=4
M87)G970G*2!["B`@("`@("`@("`@("`@("`@("`@+R\@3F]T('5S960Z('=E
M(&EG;F]R92`B<W5I9"!P<F]P;W-A;',B(&9R;VT*("`@("`@("`@("`@("`@
M("`@("`O+R!C;&EE;G0N"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@-3H*("`@("`@
M("`@("`@:68@*"1E;&5M96YT(#T]("=4>7!E)RD@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]I=&5M0V]N=&5N=%1Y<&4@/2!T<FEM*"1T:&ES+3Y?8VAA
M<G,I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M('T*"B`@("`@("`@<&%R96YT.CIE;F1%;&5M96YT*"1U<FDL("1E;&5M96YT
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!G971)=&5M<R@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?:71E;7,["B`@("!]"@H@("`@9G5N8W1I;VX@
M9V5T0V]N=&5N=%1Y<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M7V-O;G1E;G14>7!E.PH@("`@?0H*?0H*+RHJ"B`J(%1H92!C;&%S<R!3>6YC
M34Q?0V]M;6%N9%]3>6YC16QE;65N="!S=&]R97,@:6YF;W)M871I;VX@86)O
M=70*("H@=&AE(&ET96US(&EN<VED92!A('-Y;F,@96QE;65N="`H061D?$1E
M;&5T97Q297!L86-E*2X*("H*("H@02!S:6YG;&4@4WEN8T5L96UE;G0@8V%N
M(&-O;G1A:6X@;75L=&EP;&4@:71E;7,N"B`J"B`J($EN<W1A;F-E<R!O9B!T
M:&ES(&-L87-S(&%R92!C<F5A=&5D(&1U<FEN9R!T:&4@6$U,('!A<G-I;F<@
M8GD*("H@4WEN8TU,7T-O;6UA;F1?4WEN8T5L96UE;G0N"B`J"B`J($!P86-K
M86=E(%-Y;F--3`H@*B\*8VQA<W,@4WEN8TU,7U-Y;F-)=&5M('L*"B`@("`O
M*BH*("`@("`J($%D9"P@1&5L971E(&]R(%)E<&QA8V4L(&EN:&5R:71E9"!F
M<F]M"B`@("`@*B!3>6YC34Q?0V]M;6%N9%]3>6YC16QE;65N="X*("`@("`J
M+PH@("`@=F%R("1?96QE;65N=%1Y<&4["@H@("`@=F%R("1?8W5I9#L*"B`@
M("`O*BH*("`@("`J($]P=&EO;F%L+"!M87D@8F4@<')O=FED960@8GD@<&%R
M96YT(&5L96UE;G0@;W(@979E;B!N;W0@870@86QL+@H@("`@("HO"B`@("!V
M87(@)%]C;VYT96YT5'EP93L*"B`@("!V87(@)%]C;VYT96YT.PH*("`@(&9U
M;F-T:6]N(%-Y;F--3%]3>6YC271E;2@D96QE;65N=%1Y<&4L("1C;VYT96YT
M(#T@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]N=&5N
M=%1Y<&4@/2!N=6QL+"`D8W5I9"`](&YU;&PI"B`@("!["B`@("`@("`@)'1H
M:7,M/E]E;&5M96YT5'EP92`]("1E;&5M96YT5'EP93L*("`@("`@("`D=&AI
M<RT^7V-U:60@/2`D8W5I9#L*("`@("`@("`D=&AI<RT^7V-O;G1E;G14>7!E
M(#T@)&-O;G1E;G14>7!E.PH@("`@("`@("1T:&ES+3Y?8V]N=&5N="`]("1C
M;VYT96YT.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$-U:60H*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7V-U:60["B`@("!]"@H@("`@9G5N8W1I
M;VX@9V5T0V]N=&5N="@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M8V]N=&5N=#L*("`@('T*"B`@("!F=6YC=&EO;B!G971#;VYT96YT5'EP92@I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8V]N=&5N=%1Y<&4["B`@
M("!]"@H@("`@9G5N8W1I;VX@9V5T16QE;65N=%1Y<&4H*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^7V5L96UE;G14>7!E.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U-Y;F--3"]#;VUM
M86YD+U-T871U<RYP:'``````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#$V,3$P(#$P-3$U-#,S-S,T(#`R,S`R-``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=3
M>6YC34PO0V]M;6%N9"YP:'`G.PIR97%U:7)E7V]N8V4@)U-Y;F--3"]#;VYS
M=&%N=',N<&AP)SL*"B\J*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]3>6YC34PO
M4WEN8TU,+T-O;6UA;F0O4W1A='5S+G!H<"QV(#$N,34N,3`N-B`R,#`V+S`Q
M+S,Q(#$W.C4U.C$Y(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR
M,#`V($%N=&AO;GD@36EL;',@/&%M:6QL<T!P>7)A;6ED-BYC;VT^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!!;G1H;VYY($UI;&QS(#QA;6EL;'-`
M<'ER86UI9#8N8V]M/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA
M9V4@4WEN8TU,"B`J+PIC;&%S<R!3>6YC34Q?0V]M;6%N9%]3=&%T=7,@97AT
M96YD<R!3>6YC34Q?0V]M;6%N9"!["@H@("`@=F%R("1?<F5S<&]N<V4["@H@
M("`@=F%R("1?8VUD4F5F.PH*("`@("\J*@H@("`@("H@375S="!B92!P<F5S
M96YT+@H@("`@("HO"B`@("!V87(@)%]C;60["@H@("`@=F%R("1?<V]U<F-E
M4F5F.PH*("`@('9A<B`D7W1A<F=E=%)E9CL*"B`@("!V87(@)%]C:&%L365T
M849O<FUA=#L*"B`@("!V87(@)%]C:&%L365T851Y<&4["@H@("`@=F%R("1?
M8VAA;$UE=&%.97AT3F]N8V4["@H@("`@=F%R("1?:71E;41A=&%!;F-H;W).
M97AT.PH*("`@('9A<B`D7VET96U$871A06YC:&]R3&%S=#L*"B`@("!F=6YC
M=&EO;B!3>6YC34Q?0V]M;6%N9%]3=&%T=7,H)')E<W!O;G-E(#T@;G5L;"P@
M)&-M9"`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"1R97-P;VYS92`A/2!N
M=6QL*2!["B`@("`@("`@("`@("1T:&ES+3Y?<F5S<&]N<V4@/2`D<F5S<&]N
M<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H)&-M9"`A/2!N=6QL*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?8VUD(#T@)&-M9#L*("`@("`@("!]"B`@("!]
M"@H@("`@9G5N8W1I;VX@;W5T<'5T*"1C=7)R96YT0VUD240L("8D;W5T<'5T
M*0H@("`@>PH@("`@("`@("1A='1R<R`](&%R<F%Y*"D["@H@("`@("`@("1S
M=&%T92`]("8D7U-%4U-)3TY;)U-Y;F--3"YS=&%T92==.PH*("`@("`@("!I
M9B`H)'1H:7,M/E]C;60@(3T@;G5L;"D@>PH@("`@("`@("`@("`D871T<G,@
M/2!A<G)A>2@I.PH@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H
M)'-T871E+3YG97154DDH*2P@)U-T871U<R<L("1A='1R<RD["@H@("`@("`@
M("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@
M)T-M9$E$)RP@)&%T=')S*3L*("`@("`@("`@("`@)&-H87)S(#T@)&-U<G)E
M;G1#;61)1#L*("`@("`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D8VAA
M<G,I.PH@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^
M9V5T55))*"DL("=#;61)1"<I.PH*("`@("`@("`@("`@)&]U='!U="T^<W1A
M<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=-<V=2968G+"`D871T<G,I
M.PH@("`@("`@("`@("`D8VAA<G,@/2`D<W1A=&4M/F=E=$US9TE$*"D["B`@
M("`@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@("`@
M("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G
M37-G4F5F)RD["@H@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H
M)'-T871E+3YG97154DDH*2P@)T-M9%)E9B<L("1A='1R<RD["B`@("`@("`@
M("`@("1C:&%R<R`]("1T:&ES+3Y?8VUD4F5F.PH@("`@("`@("`@("`D;W5T
M<'5T+3YC:&%R86-T97)S*"1C:&%R<RD["B`@("`@("`@("`@("1O=71P=70M
M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)T-M9%)E9B<I.PH*("`@
M("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))
M*"DL("=#;60G+"`D871T<G,I.PH@("`@("`@("`@("`D8VAA<G,@/2`D=&AI
M<RT^7V-M9#L*("`@("`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D8VAA
M<G,I.PH@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^
M9V5T55))*"DL("=#;60G*3L*"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^7W1A<F=E=%)E9BDI('L*("`@("`@("`@("`@("`@("1O=71P=70M/G-T
M87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G5&%R9V5T4F5F)RP@)&%T
M=')S*3L*("`@("`@("`@("`@("`@("1C:&%R<R`]("1T:&ES+3Y?=&%R9V5T
M4F5F.PH@("`@("`@("`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D8VAA
M<G,I.PH@("`@("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A
M=&4M/F=E=%5222@I+"`G5&%R9V5T4F5F)RD["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W-O=7)C95)E9BDI('L*("`@
M("`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E
M=%5222@I+"`G4V]U<F-E4F5F)RP@)&%T=')S*3L*("`@("`@("`@("`@("`@
M("1C:&%R<R`]("1T:&ES+3Y?<V]U<F-E4F5F.PH@("`@("`@("`@("`@("`@
M)&]U='!U="T^8VAA<F%C=&5R<R@D8VAA<G,I.PH@("`@("`@("`@("`@("`@
M)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G4V]U<F-E
M4F5F)RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O($EF('=E(&%R
M92!R97-P;VYD:6YG('1O('1H92!3>6YC2&1R(&%N9"!W92!A<F4@;F]T"B`@
M("`@("`@("`@("\O(&%U=&AO<FEZ960@=&AE;B!R97%U97-T(&)A<VEC(&%U
M=&AO<FEZ871I;VXN"B`@("`@("`@("`@("\O"B`@("`@("`@("`@("\O($9)
M6$U%.B!2:6=H="!N;W<@=V4@86QW87ES('-E;F0@=&AI<RP@:6=N;W)I;F<@
M=&AE"B`@("`@("`@("`@("\O(&ES075T:&]R:7IE9"@I('1E<W0N($ES('1H
M870@8V]R<F5C=#\*("`@("`@("`@("`@:68@*"1T:&ES+3Y?8VUD(#T]("=3
M>6YC2&1R)R`F)B`A)'-T871E+3YI<T%U=&AO<FEZ960H*2D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]C:&%L365T849O<FUA="`]("=B-C0G.PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]C:&%L365T851Y<&4@/2`G<WEN8VUL.F%U
M=&@M8F%S:6,G.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]R97-P;VYS92`]
M(%)%4U!/3E-%7T-2141%3E1)04Q37TU)4U-)3D<["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-H86Q-971A1F]R;6%T
M*2`F)B!I<W-E="@D=&AI<RT^7V-H86Q-971A5'EP92DI('L*("`@("`@("`@
M("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I
M+"`G0VAA;"<L("1A='1R<RD["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YS
M=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)TUE=&$G+"`D871T<G,I
M.PH*("`@("`@("`@("`@("`@("1M971A:6YF=7)I(#T@)'-T871E+3YG9715
M4DE-971A*"D["@H@("`@("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M
M96YT*"1M971A:6YF=7)I+"`G5'EP92<L("1A='1R<RD["B`@("`@("`@("`@
M("`@("`D8VAA<G,@/2`D=&AI<RT^7V-H86Q-971A5'EP93L*("`@("`@("`@
M("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@("`@("`@
M("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)&UE=&%I;F9U<FDL("=4>7!E
M)RD["@H@("`@("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1M
M971A:6YF=7)I+"`G1F]R;6%T)RP@)&%T=')S*3L*("`@("`@("`@("`@("`@
M("1C:&%R<R`]("1T:&ES+3Y?8VAA;$UE=&%&;W)M870["B`@("`@("`@("`@
M("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1C:&%R<RD["B`@("`@("`@("`@
M("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1M971A:6YF=7)I+"`G1F]R;6%T
M)RD["@H@("`@("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A
M=&4M/F=E=%5222@I+"`G365T82<I.PH@("`@("`@("`@("`@("`@)&]U='!U
M="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G0VAA;"<I.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H
M)'-T871E+3YG97154DDH*2P@)T1A=&$G+"`D871T<G,I.PH@("`@("`@("`@
M("`D8VAA<G,@/2`D=&AI<RT^7W)E<W!O;G-E.PH@("`@("`@("`@("`D;W5T
M<'5T+3YC:&%R86-T97)S*"1C:&%R<RD["B`@("`@("`@("`@("1O=71P=70M
M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)T1A=&$G*3L*"B`@("`@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VET96U$871A06YC:&]R3F5X="D@
M?'P@:7-S970H)'1H:7,M/E]I=&5M1&%T84%N8VAO<DQA<W0I*2!["B`@("`@
M("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG9715
M4DDH*2P@)TET96TG+"`D871T<G,I.PH@("`@("`@("`@("`@("`@)&]U='!U
M="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=$871A)RP@)&%T
M=')S*3L*"B`@("`@("`@("`@("`@("`D;65T86EN9G5R:2`]("1S=&%T92T^
M9V5T55))365T82@I.PH@("`@("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%
M;&5M96YT*"1M971A:6YF=7)I+"`G06YC:&]R)RP@)&%T=')S*3L*"B`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]I=&5M1&%T84%N8VAO<DQA
M<W0I*2!["@H@("`@("`@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE
M;G0H)&UE=&%I;F9U<FDL("=,87-T)RP@)&%T=')S*3L*("`@("`@("`@("`@
M("`@("`@)&-H87)S(#T@)'1H:7,M/E]I=&5M1&%T84%N8VAO<DQA<W0["B`@
M("`@("`@("`@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)&-H87)S*3L*
M("`@("`@("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D;65T86EN
M9G5R:2P@)TQA<W0G*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]I=&5M1&%T84%N8VAO<DYE>'0I*2![
M"@H@("`@("`@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)&UE
M=&%I;F9U<FDL("=.97AT)RP@)&%T=')S*3L*("`@("`@("`@("`@("`@("`@
M)&-H87)S(#T@)'1H:7,M/E]I=&5M1&%T84%N8VAO<DYE>'0["B`@("`@("`@
M("`@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@("`@
M("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D;65T86EN9G5R:2P@
M)TYE>'0G*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D
M;W5T<'5T+3YE;F1%;&5M96YT*"1M971A:6YF=7)I+"`G06YC:&]R)RD["@H@
M("`@("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E
M=%5222@I+"`G1&%T82<I.PH@("`@("`@("`@("`@("`@)&]U='!U="T^96YD
M16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G271E;2<I.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^
M9V5T55))*"DL("=3=&%T=7,G*3L*"B`@("`@("`@("`@("1C=7)R96YT0VUD
M240K*SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D8W5R<F5N=$-M9$E$
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T=&5R(&9O<B!P<F]P97)T>2!R
M97-P;VYS92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1R97-P;VYS
M92`@3F5W('9A;'5E(&]F('!R;W!E<G1Y(')E<W!O;G-E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!S971297-P;VYS92@D<F5S<&]N<V4I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]R97-P;VYS92`]("1R97-P;VYS93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E='1E<B!F;W(@<')O<&5R='D@8VUD+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&-M9"`@3F5W('9A;'5E(&]F('!R;W!E<G1Y
M(&-M9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T0VUD*"1C;60I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]C;60@/2`D8VUD.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4V5T=&5R(&9O<B!P<F]P97)T>2!C;612968N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D8VUD4F5F("!.97<@=F%L=64@;V8@<')O<&5R
M='D@8VUD4F5F+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971#;612968H)&-M
M9%)E9BD*("`@('L*("`@("`@("`D=&AI<RT^7V-M9%)E9B`]("1C;612968[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971T97(@9F]R('!R;W!E<G1Y('-O
M=7)C95)E9BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S;W5R8V52
M968@($YE=R!V86QU92!O9B!P<F]P97)T>2!S;W5R8V52968N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-E=%-O=7)C95)E9B@D<V]U<F-E4F5F*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?<V]U<F-E4F5F(#T@)'-O=7)C95)E9CL*("`@('T*
M"B`@("`O*BH*("`@("`J(%-E='1E<B!F;W(@<')O<&5R='D@=&%R9V5T4F5F
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1A<F=E=%)E9B`@3F5W
M('9A;'5E(&]F('!R;W!E<G1Y('1A<F=E=%)E9BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5T5&%R9V5T4F5F*"1T87)G9712968I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]T87)G9712968@/2`D=&%R9V5T4F5F.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4V5T=&5R(&9O<B!P<F]P97)T>2!I=&5M1&%T84%N8VAO<DYE
M>'0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:71E;41A=&%!;F-H
M;W).97AT("!.97<@=F%L=64@;V8@<')O<&5R='D@:71E;41A=&%!;F-H;W).
M97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971)=&5M1&%T84%N8VAO<DYE
M>'0H)&ET96U$871A06YC:&]R3F5X="D*("`@('L*("`@("`@("`D=&AI<RT^
M7VET96U$871A06YC:&]R3F5X="`]("1I=&5M1&%T84%N8VAO<DYE>'0["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!3971T97(@9F]R('!R;W!E<G1Y(&ET96U$
M871A06YC:&]R3&%S="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I
M=&5M1&%T84%N8VAO<DQA<W0@($YE=R!V86QU92!O9B!P<F]P97)T>2!I=&5M
M1&%T84%N8VAO<DQA<W0N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$ET96U$
M871A06YC:&]R3&%S="@D:71E;41A=&%!;F-H;W),87-T*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?:71E;41A=&%!;F-H;W),87-T(#T@)&ET96U$871A06YC
M:&]R3&%S=#L*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O4WEN8TU,+T-O
M;6UA;F0O06QE<G0N<&AP````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,C4P,C4@,3`U,34T,S,W,S0@,#(R-C$U`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@II;F-L=61E7V]N8V4@
M)U-Y;F--3"]#;VUM86YD+G!H<"<["@HO*BH*("H@5&AE(%-Y;F--3%]!;&5R
M="!C;&%S<R!P<F]V:61E<R!A(%-Y;F--3"!I;7!L96UE;G1A=&EO;B!O9@H@
M*B!T:&4@06QE<G0@8V]M;6%N9"!A<R!D969I;F5D(&EN(%-Y;F--3"!297!R
M97-E;G1A=&EO;B!0<F]T;V-O;"P*("H@=F5R<VEO;B`Q+C$@-2XU+C(N"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+U-Y;F--3"]3>6YC34PO0V]M;6%N9"]!
M;&5R="YP:'`L=B`Q+C$X+C$P+CD@,C`P-B\P,2\S,2`Q-SHU-3HS,2!J86X@
M17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!!;G1H;VYY($UI;&QS
M(#QA;6EL;'-`<'ER86UI9#8N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@06YT:&]N>2!-:6QL<R`\86UI;&QS0'!Y<F%M:60V+F-O;3X*("H@
M0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E(%-Y;F--3`H@*B\*8VQA
M<W,@4WEN8TU,7T-O;6UA;F1?06QE<G0@97AT96YD<R!3>6YC34Q?0V]M;6%N
M9"!["@H@("`@+RHJ"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@
M=F%R("1?86QE<G0["@H@("`@+RHJ"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)%]S;W5R8V5,;V-54DD["@H@("`@+RHJ"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]T87)G971,;V-54DD["@H@
M("`@+RHJ"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]M
M971A06YC:&]R3F5X=#L*"B`@("`O*BH*("`@("`J($!V87(@:6YT96=E<@H@
M("`@("HO"B`@("!V87(@)%]M971A06YC:&]R3&%S=#L*"B`@("`O*BH*("`@
M("`J($-R96%T97,@82!N97<@:6YS=&%N8V4@;V8@06QE<G0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%-Y;F--3%]#;VUM86YD7T%L97)T*"1A;&5R="`](&YU
M;&PI"B`@("!["B`@("`@("`@:68@*"1A;&5R="`A/2!N=6QL*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?86QE<G0@/2`D86QE<G0["B`@("`@("`@?0H@("`@
M?0H*("`@(&9U;F-T:6]N(&]U='!U="@D8W5R<F5N=$-M9$E$+"`F)&]U='!U
M="D*("`@('L*("`@("`@("!G;&]B86P@)&)A8VME;F0["@H@("`@("`@("1A
M='1R<R`](&%R<F%Y*"D["B`@("`@("`@)'-T871E(#T@)B1?4T534TE/3ELG
M4WEN8TU,+G-T871E)UT["@H@("`@("`@("\O($AA;F1L92!U;F%U=&AO<FEZ
M960@9FER<W0N"B`@("`@("`@:68@*"$D<W1A=&4M/FES075T:&]R:7IE9"@I
M*2!["B`@("`@("`@("`@("1S=&%T=7,@/2`F;F5W(%-Y;F--3%]#;VUM86YD
M7U-T871U<RA215-03TY315])3E9!3$E$7T-2141%3E1)04Q3+"`G06QE<G0G
M*3L*("`@("`@("`@("`@)'-T871U<RT^<V5T0VUD4F5F*"1T:&ES+3Y?8VUD
M240I.PH@("`@("`@("`@("`D8W5R<F5N=$-M9$E$(#T@)'-T871U<RT^;W5T
M<'5T*"1C=7)R96YT0VUD240L("1O=71P=70I.PH@("`@("`@("`@("!R971U
M<FX@)&-U<G)E;G1#;61)1#L*("`@("`@("!]"@H@("`@("`@("1D871A8F%S
M92`]("1T:&ES+3Y?=&%R9V5T3&]C55)).PH*("`@("`@("`O+R!3=&]R92!C
M;&EE;G0G<R!.97AT($%N8VAO<B!I;B!3=&%T92X@($%F=&5R('-U8V-E<W-F
M=6P@<WEN8PH@("`@("`@("\O('1H:7,@:7,@=&AE;B!W<FET=&5N('1O('!E
M<G-I<W1E;F-E(&9O<B!N96=O=&EA=&EO;B!O9@H@("`@("`@("\O(&9U<G1H
M97(@<WEN8W,N"B`@("`@("`@)'-T871E+3YS971#;&EE;G1!;F-H;W).97AT
M*"1D871A8F%S92P@)'1H:7,M/E]M971A06YC:&]R3F5X="D["@H@("`@("`@
M("1I;F9O(#T@)&)A8VME;F0M/F=E=%-Y;F-3=6UM87)Y*"1S=&%T92T^9V5T
M4WEN8TED96YT:69I97(H*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W1A<F=E=$QO8U5222D["@H@("`@("`@
M(&EF("AI<U]A*"1I;F9O+"`G1&%T851R965/8FIE8W0G*2D@>PH@("`@("`@
M("`@("`D>"`]("1I;F9O+3YG970H)T-L:65N=$%N8VAO<B<I.PH@("`@("`@
M("`@("`D8VQI96YT;&%S="`]("1X6R1D871A8F%S95T["B`@("`@("`@("`@
M("1B86-K96YD+3YL;V=-97-S86=E*'-P<FEN=&8H)W!R979I;W5S('-Y;F,@
M9F]U;F0@9F]R(&1A=&%B87-E.B`E<SL@8VQI96YT+71S.B`E<R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&%B87-E
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C
M;&EE;G1L87-T*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@
M("`@("1X(#T@)&EN9F\M/F=E="@G4V5R=F5R06YC:&]R)RD["B`@("`@("`@
M("`@("1S=&%T92T^<V5T4V5R=F5R06YC:&]R3&%S="@D9&%T86)A<V4L("1X
M6R1D871A8F%S95TI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1B
M86-K96YD+3YL;V=-97-S86=E*'-P<FEN=&8H)U-Y;F--3#H@3F\@:6YF;R!A
M8F]U="!P<F5V:6]U<R!S>6YC<R!F;W5N9"!F;W(@:60@)7,@86YD(&1A=&%B
M87-E("5S)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<W1A=&4M/F=E=%-Y;F-)9&5N=&EF:65R*"DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&%B87-E*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@("`@("1C;&EE;G1L87-T
M(#T@,#L*("`@("`@("`@("`@)'-T871E+3YS971397)V97)!;F-H;W),87-T
M*"1D871A8F%S92P@,"D["B`@("`@("`@?0H*("`@("`@("`O+R!3970@4V5R
M=F5R($%N8VAO<B!F;W(@=&AI<R!S>6YC('1O(&-U<G)E;G0@=&EM92X*("`@
M("`@("`D<W1A=&4M/G-E=%-E<G9E<D%N8VAO<DYE>'0H)&1A=&%B87-E+"!T
M:6UE*"DI.PH@("`@("`@(&EF("@H)&-L:65N=&QA<W0@?'P@)&-L:65N=&QA
M<W0@/3T]("<P)RD*("`@("`@("`@("`@("`@("`F)B`D8VQI96YT;&%S="`]
M/2`D=&AI<RT^7VUE=&%!;F-H;W),87-T*2!["B`@("`@("`@("`@("\O($QA
M<W0@4WEN8R!!;F-H;W(@;6%T8VAE<RP@5'=O5V%Y4WEN8R!W:6QL(&1O+@H@
M("`@("`@("`@("`D8V]D92`](%)%4U!/3E-%7T]+.PH@("`@("`@("`@("`D
M8F%C:V5N9"T^;&]G365S<V%G92@B4WEN8TU,.B!!;F-H;W(@;6%T8V@L(%1W
M;U=A>5-Y;F,@<VEN8V4@(@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("X@)&-L:65N=&QA<W0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H)&-L:65N=&QA<W0I('L*
M("`@("`@("`@("`@("`@("1B86-K96YD+3YL;V=-97-S86=E*"=C;&EE;G0@
M<F5Q=65S=&5D('-Y;F,@=VET:"!A;F-H;W(@=',@)R`N"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VUE=&%!;F-H;W),
M87-T("X@)R!B=70@<V5R=F5R("<@+@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)VAA<R!T:6UE<W1A;7`G("X@)&-L:65N=&QA<W0@
M+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R!O;B!F
M:6QE)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?24Y&3RD["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)&)A8VME;F0M/FQO9TUE<W-A9V4H(E-Y;F--3#H@
M06YC:&]R(&UI<VUA=&-H+"!E;F9O<F-I;F<@4VQO=U-Y;F,B+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L
M(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@)&-L:65N=&QA<W0@/2`P
M.PH@("`@("`@("`@("`D<W1A=&4M/G-E=%-E<G9E<D%N8VAO<DQA<W0H)&1A
M=&%B87-E+"`P*3L*("`@("`@("`@("`@:68@*"1T:&ES+3Y?86QE<G0@/3T@
M,C`Q*2!["B`@("`@("`@("`@("`@("`O*B!3;&]W<WEN8R!R97%U97-T960@
M9G)O;2!C;&EE;G0@86YY=V%Y.B!J=7-T(&%C:VYO=VQE9&=E+B`J+PH@("`@
M("`@("`@("`@("`@)&-O9&4@/2!215-03TY315]/2SL*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("\J($UI<VUA=&-H+"!E;F9O<F-E
M('-L;W<@<WEN8RX@*B\*("`@("`@("`@("`@("`@("1T:&ES+3Y?86QE<G0@
M/2`R,#$["B`@("`@("`@("`@("`@("`D8V]D92`](#4P.#L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@)'-T871U<R`]("9N97<@4WEN8TU,
M7T-O;6UA;F1?4W1A='5S*"1C;V1E+"`G06QE<G0G*3L*("`@("`@("`D<W1A
M='5S+3YS971#;612968H)'1H:7,M/E]C;61)1"D["B`@("`@("`@:68@*"1T
M:&ES+3Y?<V]U<F-E3&]C55))("$](&YU;&PI('L*("`@("`@("`@("`@)'-T
M871U<RT^<V5T4V]U<F-E4F5F*"1T:&ES+3Y?<V]U<F-E3&]C55))*3L*("`@
M("`@("!]"B`@("`@("`@:68@*"1T:&ES+3Y?=&%R9V5T3&]C55))("$](&YU
M;&PI('L*("`@("`@("`@("`@)'-T871U<RT^<V5T5&%R9V5T4F5F*"1T:&ES
M+3Y?=&%R9V5T3&]C55))*3L*("`@("`@("!]"@H@("`@("`@("\O($UI<G)O
M<B!.97AT($%N8VAO<B!F<F]M(&-L:65N="!B86-K('1O(&-L:65N="X*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]M971A06YC:&]R3F5X="DI('L*("`@
M("`@("`@("`@)'-T871U<RT^<V5T271E;41A=&%!;F-H;W).97AT*"1T:&ES
M+3Y?;65T84%N8VAO<DYE>'0I.PH@("`@("`@('T*"B`@("`@("`@+R\@36ER
M<F]R($QA<W0@06YC:&]R(&9R;VT@8VQI96YT(&)A8VL@=&\@8VQI96YT+@H@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VUE=&%!;F-H;W),87-T*2D@>PH@
M("`@("`@("`@("`D<W1A='5S+3YS971)=&5M1&%T84%N8VAO<DQA<W0H)'1H
M:7,M/E]M971A06YC:&]R3&%S="D["B`@("`@("`@?0H*("`@("`@("`D8W5R
M<F5N=$-M9$E$(#T@)'-T871U<RT^;W5T<'5T*"1C=7)R96YT0VUD240L("1O
M=71P=70I.PH*("`@("`@("!I9B`H)'-T871E+3YI<T%U=&AO<FEZ960H*2D@
M>PH@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG
M97154DDH*2P@)T%L97)T)RP@)&%T=')S*3L*"B`@("`@("`@("`@("1O=71P
M=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G0VUD240G+"`D
M871T<G,I.PH@("`@("`@("`@("`D8VAA<G,@/2`D8W5R<F5N=$-M9$E$.PH@
M("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1C:&%R<RD["B`@("`@
M("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@
M)T-M9$E$)RD["@H@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H
M)'-T871E+3YG97154DDH*2P@)T1A=&$G+"`D871T<G,I.PH@("`@("`@("`@
M("`D8VAA<G,@/2`D=&AI<RT^7V%L97)T.PH@("`@("`@("`@("`D;W5T<'5T
M+3YC:&%R86-T97)S*"1C:&%R<RD["B`@("`@("`@("`@("1O=71P=70M/F5N
M9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)T1A=&$G*3L*"B`@("`@("`@
M("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G
M271E;2<L("1A='1R<RD["@H@("`@("`@("`@("!I9B`H)'1H:7,M/E]S;W5R
M8V5,;V-54DD@(3T@;G5L;"D@>PH@("`@("`@("`@("`@("`@)&]U='!U="T^
M<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=487)G970G+"`D871T
M<G,I.PH@("`@("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S
M=&%T92T^9V5T55))*"DL("=,;V-54DDG+"`D871T<G,I.PH@("`@("`@("`@
M("`@("`@)&-H87)S(#T@)'1H:7,M/E]S;W5R8V5,;V-54DD["B`@("`@("`@
M("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1C:&%R<RD["B`@("`@("`@
M("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL
M("=,;V-54DDG*3L*("`@("`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE
M;G0H)'-T871E+3YG97154DDH*2P@)U1A<F=E="<I.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!I9B`H)'1H:7,M/E]T87)G971,;V-54DD@(3T@;G5L
M;"D@>PH@("`@("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S
M=&%T92T^9V5T55))*"DL("=3;W5R8V4G+"`D871T<G,I.PH@("`@("`@("`@
M("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL
M("=,;V-54DDG+"`D871T<G,I.PH@("`@("`@("`@("`@("`@)&-H87)S(#T@
M)'1H:7,M/E]T87)G971,;V-54DD["B`@("`@("`@("`@("`@("`D;W5T<'5T
M+3YC:&%R86-T97)S*"1C:&%R<RD["B`@("`@("`@("`@("`@("`D;W5T<'5T
M+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=,;V-54DDG*3L*("`@
M("`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG9715
M4DDH*2P@)U-O=7)C92<I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)TUE=&$G
M+"`D871T<G,I.PH*("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT
M*"1S=&%T92T^9V5T55))365T82@I+"`G06YC:&]R)RP@)&%T=')S*3L*"B`@
M("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%52
M24UE=&$H*2P@)TQA<W0G+"`D871T<G,I.PH@("`@("`@("`@("`D8VAA<G,@
M/2`D<W1A=&4M/F=E=%-E<G9E<D%N8VAO<DQA<W0H)&1A=&%B87-E*3L*("`@
M("`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D8VAA<G,I.PH@("`@("`@
M("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))365T82@I
M+"`G3&%S="<I.PH*("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT
M*"1S=&%T92T^9V5T55))365T82@I+"`G3F5X="<L("1A='1R<RD["B`@("`@
M("`@("`@("1C:&%R<R`]("1S=&%T92T^9V5T4V5R=F5R06YC:&]R3F5X="@D
M9&%T86)A<V4I.PH@("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1C
M:&%R<RD["B`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E
M+3YG97154DE-971A*"DL("=.97AT)RD["@H@("`@("`@("`@("`D;W5T<'5T
M+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))365T82@I+"`G06YC:&]R)RD[
M"B`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG9715
M4DDH*2P@)TUE=&$G*3L*("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N
M="@D<W1A=&4M/F=E=%5222@I+"`G271E;2<I.PH@("`@("`@("`@("`D;W5T
M<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=!;&5R="<I.PH*
M("`@("`@("`@("`@)&-U<G)E;G1#;61)1"LK.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1C=7)R96YT0VUD240["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!3971T97(@9F]R('!R;W!E<G1Y('-O=7)C955222X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1S;W5R8V554DD@($YE=R!V86QU92!O9B!P<F]P
M97)T>2!S;W5R8V554DDN"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%-O=7)C
M94QO8U5222@D<V]U<F-E55))*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<V]U
M<F-E55))(#T@)'-O=7)C955223L*("`@('T*"B`@("!F=6YC=&EO;B!G9714
M87)G971,;V-54DDH*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W1A
M<F=E=%5223L*("`@('T*"B`@("`O*BH*("`@("`J(%-E='1E<B!F;W(@<')O
M<&5R='D@=&%R9V5T55))+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'1A<F=E=%5222`@3F5W('9A;'5E(&]F('!R;W!E<G1Y('1A<F=E=%5222X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<V5T5&%R9V5T55))*"1T87)G97154DDI
M"B`@("!["B`@("`@("`@)'1H:7,M/E]T87)G97154DD@/2`D=&%R9V5T55))
M.PH@("`@?0H*("`@(&9U;F-T:6]N('-T87)T16QE;65N="@D=7)I+"`D96QE
M;65N="P@)&%T=')S*0H@("`@>PH@("`@("`@('!A<F5N=#HZ<W1A<G1%;&5M
M96YT*"1U<FDL("1E;&5M96YT+"`D871T<G,I.PH*("`@('T*"B`@("!F=6YC
M=&EO;B!E;F1%;&5M96YT*"1U<FDL("1E;&5M96YT*0H@("`@>PH@("`@("`@
M(&=L;V)A;"`D8F%C:V5N9#L*"B`@("`@("`@<W=I=&-H("AC;W5N="@D=&AI
M<RT^7U-T86-K*2D@>PH@("`@("`@(&-A<V4@,3H*("`@("`@("`@("`@)'-T
M871E(#T@)B1?4T534TE/3ELG4WEN8TU,+G-T871E)UT["B`@("`@("`@("`@
M(&EF("@D=&AI<RT^7W1A<F=E=$QO8U5222`A/2`G=&%S:W,G"B`@("`@("`@
M("`@("`@("`F)B`D=&AI<RT^7W1A<F=E=$QO8U5222`A/2`G8V%L96YD87(G
M"B`@("`@("`@("`@("`@("`F)B`D=&AI<RT^7W1A<F=E=$QO8U5222`A/2`G
M;F]T97,G"B`@("`@("`@("`@("`@("`F)B`D=&AI<RT^7W1A<F=E=$QO8U52
M22`A/2`G8V]N=&%C=',G*2!["B`@("`@("`@("`@("`@("`D8F%C:V5N9"T^
M;&]G365S<V%G92@G17)R;W(A($EN=F%L:60@9&%T86)A<V4Z("<*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)'1H:7,M/E]T87)G
M971,;V-54DD*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("X@)RX@3VYL>2!T87-K<RP@8V%L96YD87(L(&YO=&5S+"<*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)R!A;F0@8V]N=&%C=',@
M86QL;W=E9"$G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@
M("`@("`@("`@9&EE*")E<G)O<CH@:6YV86QI9"!D871A8F%S92$B*3L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)&)A8VME;F0M/FQO9TUE<W-A9V4H
M)VQO;VMI;F<@9F]R('-Y;F,@9F]R("<@+@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W1A<F=E=$QO8U5222P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!0
M14%27TQ/1U]$14)51RD["B`@("`@("`@("`@("1S>6YC(#T@)B`D<W1A=&4M
M/F=E=%-Y;F,H)'1H:7,M/E]T87)G971,;V-54DDI.PH*("`@("`@("`@("`@
M:68@*"$D<WEN8RD@>PH@("`@("`@("`@("`@("`@)&)A8VME;F0M/FQO9TUE
M<W-A9V4H)T-R96%T92!N97<@<WEN8R!F;W(@)R`N"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W1A<F=E=$QO8U5222P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?
M+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`@("`@("`@
M("1S>6YC(#T@)FYE=R!3>6YC34Q?4WEN8R@D=&AI<RT^7V%L97)T+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M=&%R9V5T3&]C55))+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<V]U<F-E3&]C55))*3L*("`@("`@("`@("`@
M("`@("1S=&%T92T^<V5T4WEN8R@D=&AI<RT^7W1A<F=E=$QO8U5222P@)'-Y
M;F,I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!C87-E(#(Z"B`@("`@("`@("`@(&EF("@D96QE;65N="`]/2`G1&%T82<I
M('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?86QE<G0@/2!I;G1V86PH=')I
M;2@D=&AI<RT^7V-H87)S*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@(&-A<V4@-#H*("`@("`@("`@("`@:68@*"1E;&5M
M96YT(#T]("=,;V-54DDG*2!["B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M
M/E]3=&%C:ULR72`]/2`G4V]U<F-E)RD@>PH@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<V]U<F-E3&]C55))(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*
M("`@("`@("`@("`@("`@('T@96QS96EF("@D=&AI<RT^7U-T86-K6S)=(#T]
M("=487)G970G*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T87)G
M971,;V-54DD@/2!B87-E;F%M92AP<F5G7W)E<&QA8V4H)R]</RXJ)"\G+"`G
M)RP@=')I;2@D=&AI<RT^7V-H87)S*2DI.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E
M(#4Z"B`@("`@("`@("`@(&EF("@D96QE;65N="`]/2`G3F5X="<I('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?;65T84%N8VAO<DYE>'0@/2!T<FEM*"1T
M:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("!](&5L<V5I9B`H)&5L96UE;G0@
M/3T@)TQA<W0G*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VUE=&%!;F-H
M;W),87-T(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@('!A<F5N=#HZ
M96YD16QE;65N="@D=7)I+"`D96QE;65N="D["B`@("!]"@H@("`@9G5N8W1I
M;VX@9V5T06QE<G0H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V%L
M97)T.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=$%L970H)&%L97)T*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?86QE<G0@/2`D86QE<G0["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+U-Y;F--3"]#;VUM86YD+T=E="YP:'``
M````````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#(Q-C$V(#$P-3$U
M-#,S-S,T(#`R,C(V-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=3>6YC34PO0V]M;6%N
M9"YP:'`G.PH*+RHJ"B`J(%1H92!3>6YC34Q?0V]M;6%N9%]'970@8VQA<W,N
M"B`J"B`J(%1H:7,@8VQA<W,@<F5S<&]N9',@=&\@82!C;&EE;G0@9V5T(')E
M<75E<W0@86YD(')E='5R;G,@=&AE($1E=DEN9@H@*B!I;F9O<FUA=&EO;B!F
M;W(@=&AE(%-Y;F--3"!S97)V97(N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+U-Y;F--3"]3>6YC34PO0V]M;6%N9"]'970N<&AP+'8@,2XQ-"XQ,"XQ,"`R
M,#`V+S`U+S(Y(#$V.C0P.C,W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,C`P,RTR,#`V($%N=&AO;GD@36EL;',@/&%M:6QL<T!P>7)A;6ED-BYC;VT^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!+87)S=&5N($9O=7)M;VYT
M(#QF;W5R;6]N=$!G;7@N9&4^"B`J($!A=71H;W(@($%N=&AO;GD@36EL;',@
M/&%M:6QL<T!P>7)A;6ED-BYC;VT^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@
M*B!`<&%C:V%G92!3>6YC34P*("HO"F-L87-S(%-Y;F--3%]#;VUM86YD7T=E
M="!E>'1E;F1S(%-Y;F--3%]#;VUM86YD('L*"B`@("!F=6YC=&EO;B!O=71P
M=70H)&-U<G)E;G1#;61)1"P@)B1O=71P=70I"B`@("!["B`@("`@("`@)'-T
M871E(#T@)B1?4T534TE/3ELG4WEN8TU,+G-T871E)UT["@H@("`@("`@("1R
M968@/2`H)'-T871E+3YG971697)S:6]N*"D@/3T@,"D@/R`G+B]D979I;F8Q
M,"<@.B`G+B]D979I;F8Q,2<["@H@("`@("`@("1S=&%T=7,@/2`F;F5W(%-Y
M;F--3%]#;VUM86YD7U-T871U<R@H)'-T871E+3YI<T%U=&AO<FEZ960H*2`_
M(%)%4U!/3E-%7T]+(#H@4D534$].4T5?24Y604Q)1%]#4D5$14Y424%,4RDL
M("='970G*3L*("`@("`@("`D<W1A='5S+3YS971#;612968H)'1H:7,M/E]C
M;61)1"D["B`@("`@("`@)'-T871U<RT^<V5T5&%R9V5T4F5F*"1R968I.PH@
M("`@("`@("1C=7)R96YT0VUD240@/2`D<W1A='5S+3YO=71P=70H)&-U<G)E
M;G1#;61)1"P@)&]U='!U="D["@H@("`@("`@(&EF("@D<W1A=&4M/FES075T
M:&]R:7IE9"@I*2!["B`@("`@("`@("`@("1A='1R<R`](&%R<F%Y*"D["B`@
M("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%52
M22@I+"`G4F5S=6QT<R<L("1A='1R<RD["@H@("`@("`@("`@("`D;W5T<'5T
M+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)T-M9$E$)RP@)&%T
M=')S*3L*("`@("`@("`@("`@)&-H87)S(#T@)&-U<G)E;G1#;61)1#L*("`@
M("`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D8VAA<G,I.PH@("`@("`@
M("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=#
M;61)1"<I.PH*("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S
M=&%T92T^9V5T55))*"DL("=-<V=2968G+"`D871T<G,I.PH@("`@("`@("`@
M("`D8VAA<G,@/2`D<W1A=&4M/F=E=$US9TE$*"D["B`@("`@("`@("`@("1O
M=71P=70M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@("`@("`@("`@)&]U='!U
M="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G37-G4F5F)RD["@H@
M("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG9715
M4DDH*2P@)T-M9%)E9B<L("1A='1R<RD["B`@("`@("`@("`@("1C:&%R<R`]
M("1T:&ES+3Y?8VUD240["B`@("`@("`@("`@("1O=71P=70M/F-H87)A8W1E
M<G,H)&-H87)S*3L*("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D
M<W1A=&4M/F=E=%5222@I+"`G0VUD4F5F)RD["@H@("`@("`@("`@("`D;W5T
M<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)TUE=&$G+"`D
M871T<G,I.PH@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T
M871E+3YG97154DE-971A*"DL("=4>7!E)RP@)&%T=')S*3L*("`@("`@("`@
M("`@:68@*&ES7V$H)&]U='!U="P@)UA-3%]70EA-3%]%;F-O9&5R)RDI('L*
M("`@("`@("`@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H34E-15]364Y#
M34Q?1$5624-%7TE.1D]?5T)834PI.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<RA-24U%7U-93D--
M3%]$159)0T5?24Y&3U]834PI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))365T82@I+"`G
M5'EP92<I.PH@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T
M92T^9V5T55))*"DL("=-971A)RD["@H@("`@("`@("`@("`D;W5T<'5T+3YS
M=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)TET96TG+"`D871T<G,I
M.PH@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG
M97154DDH*2P@)U-O=7)C92<L("1A='1R<RD["B`@("`@("`@("`@("1O=71P
M=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G3&]C55)))RP@
M)&%T=')S*3L*("`@("`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D<F5F
M*3L*("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E
M=%5222@I+"`G3&]C55)))RD["B`@("`@("`@("`@("1O=71P=70M/F5N9$5L
M96UE;G0H)'-T871E+3YG97154DDH*2P@)U-O=7)C92<I.PH*("`@("`@("`@
M("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=$
M871A)RP@)&%T=')S*3L*"B`@("`@("`@("`@("\J($1E=DEN9B!D871A(&ES
M('-T;W)E9"!I;B!W8GAM;"!N;W0@87,@82!S97!E<F%T92!C;V1E<&%G92!B
M=70*("`@("`@("`@("`@("H@<F%T:&5R(&%S(&$@8V]M<&QE=&4@=V)X;6P@
M<W1R96%M(&%S(&]P87%U92!D871A+B`@4V\@=V4@;F5E9"!A"B`@("`@("`@
M("`@("`J(&YE=R!(86YD;&5R+B`J+PH@("`@("`@("`@("`D9&5V:6YF;W5T
M<'5T(#T@)&]U='!U="T^8W)E871E4W5B2&%N9&QE<B@I.PH@("`@("`@("`@
M("`*("`@("`@("`@("`@)&1E=FEN9F]U='!U="T^<W1A<G1%;&5M96YT*"1S
M=&%T92T^9V5T55))1&5V26YF*"D@+"`G1&5V26YF)RP@)&%T=')S*3L*("`@
M("`@("`@("`@)&1E=FEN9F]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^
M9V5T55))1&5V26YF*"D@+"`G5F5R1%1$)RP@)&%T=')S*3L*("`@("`@("`@
M("`@)&1E=FEN9F]U='!U="T^8VAA<F%C=&5R<R@H)'-T871E+3YG971697)S
M:6]N*"D@/3T@,"D@/R`G,2XP)R`Z("<Q+C$G*3L*("`@("`@("`@("`@)&1E
M=FEN9F]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%52241E=DEN9B@I
M("P@)U9E<D141"<L("1A='1R<RD["B`@("`@("`@("`@("1D979I;F9O=71P
M=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%52241E=DEN9B@I("P@)TUA
M;B<L("1A='1R<RD["B`@("`@("`@("`@("1D979I;F9O=71P=70M/F-H87)A
M8W1E<G,H)U1H92!(;W)D92!0<F]J96-T("AH='1P.B\O=W=W+FAO<F1E+F]R
M9RDG*3L*("`@("`@("`@("`@)&1E=FEN9F]U='!U="T^96YD16QE;65N="@D
M<W1A=&4M/F=E=%52241E=DEN9B@I("P@)TUA;B<L("1A='1R<RD["B`@("`@
M("`@("`@("1D979I;F9O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E
M=%52241E=DEN9B@I("P@)T1E=DE$)RP@)&%T=')S*3L*("`@("`@("`@("`@
M)&1E=FEN9F]U='!U="T^8VAA<F%C=&5R<R@D7U-%4E9%4ELG2%144%](3U-4
M)UTI.PH@("`@("`@("`@("`D9&5V:6YF;W5T<'5T+3YE;F1%;&5M96YT*"1S
M=&%T92T^9V5T55))1&5V26YF*"D@+"`G1&5V240G+"`D871T<G,I.PH@("`@
M("`@("`@("`D9&5V:6YF;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG
M97154DE$979);F8H*2`L("=$9794>7`G+"`D871T<G,I.PH@("`@("`@("`@
M("`D9&5V:6YF;W5T<'5T+3YC:&%R86-T97)S*"=S97)V97(G*3L*("`@("`@
M("`@("`@)&1E=FEN9F]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%52
M241E=DEN9B@I("P@)T1E=E1Y<"<L("1A='1R<RD["B`@("`@("`@("`@("1T
M:&ES+3Y?=W)I=&5$871A4W1O<F4H)VYO=&5S)RP@)W1E>'0O>"UV;F]T92<L
M("<Q+C$G+"`D9&5V:6YF;W5T<'5T+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*"=T97AT+W!L86EN)R`]/B`G,2XP)RDI.PH@
M("`@("`@("`@("`D=&AI<RT^7W=R:71E1&%T85-T;W)E*"=C;VYT86-T<R<L
M("=T97AT+W@M=F-A<F0G+"`G,RXP)RP@)&1E=FEN9F]U='!U="P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G=&5X="]X+79C
M87)D)R`]/B`G,BXQ)RDI.PH@("`@("`@("`@("`D=&AI<RT^7W=R:71E1&%T
M85-T;W)E*"=T87-K<R<L("=T97AT+V-A;&5N9&%R)RP@)S(N,"<L("1D979I
M;F9O=71P=70L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH)W1E>'0O>"UV8V%L96YD87(G(#T^("<Q+C`G*2D["B`@("`@("`@
M("`@("1T:&ES+3Y?=W)I=&5$871A4W1O<F4H)V-A;&5N9&%R)RP@)W1E>'0O
M8V%L96YD87(G+"`G,BXP)RP@)&1E=FEN9F]U='!U="P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G=&5X="]X+79C86QE;F1A
M<B<@/3X@)S$N,"<I*3L*("`@("`@("`@("`@)&1E=FEN9F]U='!U="T^96YD
M16QE;65N="@D<W1A=&4M/F=E=%52241E=DEN9B@I("P@)T1E=DEN9B<L("1A
M='1R<RD["@H@("`@("`@("`@("`D;W5T<'5T+3YO<&%Q=64H)&1E=FEN9F]U
M='!U="T^9V5T3W5T<'5T*"DI.PH@("`@("`@("`@("`D;W5T<'5T+3YE;F1%
M;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=$871A)RD["B`@("`@("`@("`@
M("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)TET96TG
M*3L*("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E
M=%5222@I+"`G4F5S=6QT<R<I.PH*("`@("`@("`@("`@)&-U<G)E;G1#;61)
M1"LK.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1C=7)R96YT0VUD240[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!7<FET97,@1&5V26YF(&1A=&$@9F]R
M(&]N92!$871A4W1O<F4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<V]U<F-E<F5F.B!D871A(&9O<B!3;W5R8V52968@96QE;65N="X*("`@("`J
M($!P87)A;2!S=')I;F<@)&UI;65T>7!E.B!D871A(&9O<B`F;'0[*%)\5"EX
M+5!R968F9W0[)FQT.T-45'EP929G=#L*("`@("`J($!P87)A;2!S=')I;F<@
M)'9E<G-I;VXZ(&1A=&$@9F]R("9L=#LH4GQ4*7@M4')E9B9G=#LF;'0[5F5R
M0U0F9W0["B`@("`@*B!`<&%R86T@<W1R:6YG("8D;W5T<'5T(&-O;G1E;G1H
M86YD;&5R('1H870@=VEL;"!R96-E:79E9"!T:&4@;W5T<'5T+@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1A9&1I=&EO;F%L='EP97,Z(&%R<F%Y(&]F(&%D9&ET
M:6]N86P@='EP97,@9F]R(%1X(&%N9"!2>#L*("`@("`J("`@("`@("`@("`@
M("!F;W)M870@87)R87DH)W1E>'0O=F-A<F0G(#T^("<R+C`G*0H@("`@("HO
M"B`@("!F=6YC=&EO;B!?=W)I=&5$871A4W1O<F4H)'-O=7)C97)E9BP@)&UI
M;65T>7!E+"`D=F5R<VEO;BP@)B1O=71P=70L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&%D9&ET:6]N86QT>7!E<R`](&9A;'-E*0H@("`@>PH@
M("`@("`@("1A='1R<R`](&%R<F%Y*"D["@H@("`@("`@("1S=&%T92`]("8D
M7U-%4U-)3TY;)U-Y;F--3"YS=&%T92==.PH*("`@("`@("`D;W5T<'5T+3YS
M=&%R=$5L96UE;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=$871A4W1O
M<F4G+"`D871T<G,I.PH@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D
M<W1A=&4M/F=E=%52241E=DEN9B@I("P@)U-O=7)C95)E9B<L("1A='1R<RD[
M"B`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D<V]U<F-E<F5F*3L*("`@
M("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF
M*"D@+"`G4V]U<F-E4F5F)RP@)&%T=')S*3L*"B`@("`@("`@)&]U='!U="T^
M<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G4G@M4')E
M9B<L("1A='1R<RD["B`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S
M=&%T92T^9V5T55))1&5V26YF*"D@+"`G0U14>7!E)RP@)&%T=')S*3L*("`@
M("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1M:6UE='EP92D["B`@("`@("`@
M)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%52241E=DEN9B@I("P@
M)T-45'EP92<L("1A='1R<RD["B`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M
M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G5F5R0U0G+"`D871T<G,I
M.PH@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)'9E<G-I;VXI.PH@("`@
M("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DE$979);F8H
M*2`L("=697)#5"<L("1A='1R<RD["B`@("`@("`@)&]U='!U="T^96YD16QE
M;65N="@D<W1A=&4M/F=E=%52241E=DEN9B@I("P@)U)X+5!R968G+"`D871T
M<G,I.PH*("`@("`@("!I9B`H:7-?87)R87DH)&%D9&ET:6]N86QT>7!E<RDI
M('L*("`@("`@("`@("`@9F]R96%C:"`H)&%D9&ET:6]N86QT>7!E<R!A<R`D
M8W0@/3X@)&-T=F5R*7L*("`@("`@("`@("`@("`@("1O=71P=70M/G-T87)T
M16QE;65N="@D<W1A=&4M/F=E=%52241E=DEN9B@I("P@)U)X)RP@)&%T=')S
M*3L*("`@("`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A
M=&4M/F=E=%52241E=DEN9B@I("P@)T-45'EP92<L("1A='1R<RD["B`@("`@
M("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1C="D["B`@("`@("`@
M("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V
M26YF*"D@+"`G0U14>7!E)RP@)&%T=')S*3L*("`@("`@("`@("`@("`@("1O
M=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%52241E=DEN9B@I("P@
M)U9E<D-4)RP@)&%T=')S*3L*("`@("`@("`@("`@("`@("1O=71P=70M/F-H
M87)A8W1E<G,H)&-T=F5R*3L*("`@("`@("`@("`@("`@("1O=71P=70M/F5N
M9$5L96UE;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=697)#5"<L("1A
M='1R<RD["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S
M=&%T92T^9V5T55))1&5V26YF*"D@+"`G4G@G+"`D871T<G,I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE
M;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=4>"U0<F5F)RP@)&%T=')S
M*3L*("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG9715
M4DE$979);F8H*2`L("=#5%1Y<&4G+"`D871T<G,I.PH@("`@("`@("1O=71P
M=70M/F-H87)A8W1E<G,H)&UI;65T>7!E*3L*("`@("`@("`D;W5T<'5T+3YE
M;F1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G0U14>7!E)RP@
M)&%T=')S*3L*("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E
M+3YG97154DE$979);F8H*2`L("=697)#5"<L("1A='1R<RD["B`@("`@("`@
M)&]U='!U="T^8VAA<F%C=&5R<R@D=F5R<VEO;BD["B`@("`@("`@)&]U='!U
M="T^96YD16QE;65N="@D<W1A=&4M/F=E=%52241E=DEN9B@I("P@)U9E<D-4
M)RP@)&%T=')S*3L*("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T
M92T^9V5T55))1&5V26YF*"D@+"`G5'@M4')E9B<L("1A='1R<RD["@H@("`@
M("`@(&EF("AI<U]A<G)A>2@D861D:71I;VYA;'1Y<&5S*2D@>PH@("`@("`@
M("`@("!F;W)E86-H("@D861D:71I;VYA;'1Y<&5S(&%S("1C="`]/B`D8W1V
M97(I>PH@("`@("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S
M=&%T92T^9V5T55))1&5V26YF*"D@+"`G5'@G+"`D871T<G,I.PH@("`@("`@
M("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))
M1&5V26YF*"D@+"`G0U14>7!E)RP@)&%T=')S*3L*("`@("`@("`@("`@("`@
M("1O=71P=70M/F-H87)A8W1E<G,H)&-T*3L*("`@("`@("`@("`@("`@("1O
M=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=#
M5%1Y<&4G+"`D871T<G,I.PH@("`@("`@("`@("`@("`@)&]U='!U="T^<W1A
M<G1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G5F5R0U0G+"`D
M871T<G,I.PH@("`@("`@("`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D
M8W1V97(I.PH@("`@("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D
M<W1A=&4M/F=E=%52241E=DEN9B@I("P@)U9E<D-4)RP@)&%T=')S*3L*("`@
M("`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG9715
M4DE$979);F8H*2`L("=4>"<L("1A='1R<RD["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M
M/F=E=%52241E=DEN9B@I("P@)U-Y;F-#87`G+"`D871T<G,I.PH@("`@("`@
M("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%52241E=DEN9B@I
M("P@)U-Y;F-4>7!E)RP@)&%T=')S*3L*("`@("`@("`D;W5T<'5T+3YC:&%R
M86-T97)S*"<Q)RD["B`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A
M=&4M/F=E=%52241E=DEN9B@I("P@)U-Y;F-4>7!E)RP@)&%T=')S*3L*("`@
M("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DE$979)
M;F8H*2`L("=3>6YC5'EP92<L("1A='1R<RD["B`@("`@("`@)&]U='!U="T^
M8VAA<F%C=&5R<R@G,B<I.PH@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H
M)'-T871E+3YG97154DE$979);F8H*2`L("=3>6YC5'EP92<L("1A='1R<RD[
M"B`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%52241E
M=DEN9B@I("P@)U-Y;F-#87`G+"`D871T<G,I.PH@("`@("`@("1O=71P=70M
M/F5N9$5L96UE;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=$871A4W1O
M<F4G+"`D871T<G,I.PH@("`@?0H*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O4WEN8TU,+T-O;6UA;F0O
M4WEN8RYP:'``````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3$R
M,C8@,3`U,34T,S,W,S0@,#(R-#8P`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"@II;F-L=61E7V]N8V4@)U-Y;F--
M3"]#;VUM86YD+G!H<"<["FEN8VQU9&5?;VYC92`G4WEN8TU,+T-O;6UA;F0O
M4WEN8T5L96UE;G0N<&AP)SL*"B\J*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]3
M>6YC34PO4WEN8TU,+T-O;6UA;F0O4WEN8RYP:'`L=B`Q+C$W+C$P+C@@,C`P
M-B\P,2\Q,2`Q.#HS.3HR."!S96QS:WD@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#4M,C`P-B!+87)S=&5N($9O=7)M;VYT(#QK87)S=&5N0&AO<F1E+F]R
M9SX*("H*("H@5&AE(&-O;6UA;F0@:&%N9&QE<B!F;W(@=&AE("9G=#M3>6YC
M)FQT.R!C;VUM86YD(&ES('1H92!C96YT<F%L"B`J(&-L87-S('1O(&1I<W!A
M=&-H('-Y;F,@;65S<V%G97,N"B`J"B`J($1U<FEN9R!P87)S:6YG(&]F('1H
M92!R96-E:79E9"!834PL('1H92!A8W1U86P@<WEN8R!C;VUM86YD<R`H061D
M+`H@*B!297!L86-E+"!$96QE=&4I(&9R;VT@=&AE(&-L:65N="!A<F4@<W1O
M<F5D(&EN('1H92!?<WEN8T5L96UE;G1S"B`J(&%T=')I8G5T92X@(%=H96X@
M=&AE(&]U='!U="!M971H;V0@;V8@4WEN8TU,7T-O;6UA;F1?4WEN8R!I<PH@
M*B!C86QL960L('1H97-E(&5L96UE;G1S(&%R92!P<F]C97-S960@86YD('1H
M92!R97-U;'1I;F<@<W1A='5S"B`J(&UE<W-A9V5S(&-R96%T960N"B`J"B`J
M(%1H96X@=&AE('-E<G9E<B!M;V1I9FEC871I;VYS(&%R92!S96YT(&)A8VL@
M=&\@=&AE(&-L:65N="!B>2!T:&4*("H@:&%N9&QE4WEN8R!M971H;V0@=VAI
M8V@@:7,@8V%L;&5D(&9R;VT@=VET:&EN('1H92!O=71P=70@;65T:&]D+@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2V%R<W1E;B!&;W5R;6]N="`\
M:V%R<W1E;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`
M<&%C:V%G92!3>6YC34P*("HO"F-L87-S(%-Y;F--3%]#;VUM86YD7U-Y;F,@
M97AT96YD<R!3>6YC;6Q?0V]M;6%N9`I["B`@("`O*BH*("`@("`J($!V87(@
M4WEN8TU,7T-O;6UA;F1?4WEN8T5L96UE;G0*("`@("`J+PH@("`@=F%R("1?
M8W5R<F5N=%-Y;F-%;&5M96YT.PH*("`@("\J*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)%]S>6YC16QE;65N=',@/2!A<G)A>2@I.PH*
M("`@("\J*@H@("`@("H@8V]N=&%C=',L(&-A;&5N9&%R+"!T87-K<R!O<B!N
M;W1E<PH@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D7W1A<F=E=%5223L*"B`@("`O*BH*("`@("`J($-R96%T97,@82!R97-P
M;VYS92!T;R!A('-Y;F,@8V]M;6%N9"X*("`@("`J($-U<G)E;G1L>2!T:&%T
M)W,@=&AE('!L86-E('=H97)E('=E(&%L<V\@8W)E871E"B`@("`@*B!T:&4@
M)FQT.W-Y;F,F9W0[('=I=&@@=&AE('-E<G9E<B!C:&%N9V5S('1H870*("`@
M("`J(&YE961S('1O(&)E('-E;F0@=&\@=&AE(&-L:65N="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@;W5T<'5T*"1C=7)R96YT0VUD240L("8D;W5T<'5T*0H@
M("`@>PH@("`@("`@("1S=&%T92`])B`D7U-%4U-)3TY;)U-Y;F--3"YS=&%T
M92==.PH@("`@("`@("1S>6YC(#TF("1S=&%T92T^9V5T4WEN8R@D=&AI<RT^
M7W1A<F=E=%5222D["B`@("`@("`@:68@*"%I<U]O8FIE8W0H)'-Y;F,I*2![
M"B`@("`@("`@("`@("1'3$]"04Q36R=B86-K96YD)UTM/FQO9TUE<W-A9V4H
M)TYO('-Y;F,@;V)J96-T(&9O=6YD(&9O<B!54DD@/2`G("X@)'1H:7,M/E]T
M87)G97154DDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@
M("`@("`@("`@("`O+R!`5$]$3SH@8W)E871E(&UE86YI;F=F=6P@<W1A='5S
M(&-O9&4@:&5R92X*("`@("`@("!]"@H@("`@("`@("\O($AE<F4G<R!W:&5R
M92!C;&EE;G0@;6]D:69I8V%T:6]N<R!A<F4@<')O8V5S<V5D.@H@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3Y?<WEN8T5L96UE;G1S(&%S("1E;&5M96YT*2![
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1E;&5M96YT+3YG971)=&5M<R@I(&%S
M("1I=&5M*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'-Y;F,M/FAA
M;F1L95-Y;F-)=&5M*"1I=&5M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D8W5R<F5N=$-M9$E$(#T@)&5L96UE;G0M/F]U='!U="@D8W5R<F5N=$-M
M9$E$+"`D;W5T<'5T*3L*("`@("`@("!]"@H@("`@("`@("\J($YO=R!S96YD
M(&-L:65N="!C:&%N9V5S('1O('-E<G9E<CH@=&AI<R!W:6QL('!R96-E9&4@
M=&AE"B`@("`@("`@("H@/'-Y;F,^(')E<W!O;G-E.B`J+PH@("`@("`@("1C
M=7)R96YT0VUD240@/2`D<WEN8RT^8W)E871E4WEN8T]U='!U="@D8W5R<F5N
M=$-M9$E$+"`D;W5T<'5T*3L*"B`@("`@("`@)'-T871U<R`]("9N97<@4WEN
M8TU,7T-O;6UA;F1?4W1A='5S*%)%4U!/3E-%7T]++"`G4WEN8R<I.PH@("`@
M("`@("1S=&%T=7,M/G-E=$-M9%)E9B@D=&AI<RT^7V-M9$E$*3L*"B`@("`@
M("`@:68@*"1T:&ES+3Y?=&%R9V5T55))("$](&YU;&PI('L*("`@("`@("`@
M("`@)'-T871U<RT^<V5T5&%R9V5T4F5F*"1T:&ES+3Y?=&%R9V5T55))*3L*
M("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^7W-O=7)C955222`A/2!N
M=6QL*2!["B`@("`@("`@("`@("1S=&%T=7,M/G-E=%-O=7)C95)E9B@D=&AI
M<RT^7W-O=7)C955222D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'-T
M871U<RT^;W5T<'5T*"1C=7)R96YT0VUD240L("1O=71P=70I.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&=E=%1A<F=E=%5222@I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?=&%R9V5T55)).PH@("`@?0H*("`@(&9U;F-T:6]N('-T
M87)T16QE;65N="@D=7)I+"`D96QE;65N="P@)&%T=')S*0H@("`@>PH@("`@
M("`@('!A<F5N=#HZ<W1A<G1%;&5M96YT*"1U<FDL("1E;&5M96YT+"`D871T
M<G,I.PH*("`@("`@("!S=VET8V@@*&-O=6YT*"1T:&ES+3Y?4W1A8VLI*2![
M"B`@("`@("`@8V%S92`R.@H@("`@("`@("`@("!I9B`H)&5L96UE;G0@/3T@
M)U)E<&QA8V4G('Q\("1E;&5M96YT(#T]("=!9&0G('Q\("1E;&5M96YT(#T]
M("=$96QE=&4G*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-U<G)E;G13
M>6YC16QE;65N="`]("9N97<@4WEN8TU,7T-O;6UA;F1?4WEN8T5L96UE;G0H
M)&5L96UE;G0I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8W5R<F5N=%-Y
M;F-%;&5M96YT*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V-U<G)E;G13>6YC
M16QE;65N="T^<W1A<G1%;&5M96YT*"1U<FDL("1E;&5M96YT+"`D871T<G,I
M.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!E;F1%;&5M96YT*"1U
M<FDL("1E;&5M96YT*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M7V-U<G)E;G13>6YC16QE;65N="DI('L*("`@("`@("`@("`@)'1H:7,M/E]C
M=7)R96YT4WEN8T5L96UE;G0M/F5N9$5L96UE;G0H)'5R:2P@)&5L96UE;G0I
M.PH@("`@("`@('T*"B`@("`@("`@<W=I=&-H("AC;W5N="@D=&AI<RT^7U-T
M86-K*2D@>PH@("`@("`@(&-A<V4@,CH*("`@("`@("`@("`@:68@*"1E;&5M
M96YT(#T]("=297!L86-E)R!\?"`D96QE;65N="`]/2`G061D)R!\?"`D96QE
M;65N="`]/2`G1&5L971E)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]S
M>6YC16QE;65N='-;72`]("1T:&ES+3Y?8W5R<F5N=%-Y;F-%;&5M96YT.PH@
M("`@("`@("`@("`@("`@=6YS970H)'1H:7,M/E]C=7)R96YT4WEN8T5L96UE
M;G0I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!C87-E(#,Z"B`@("`@("`@("`@(&EF("@D96QE;65N="`]("=,;V-54DDG
M("8F("%I<W-E="@D=&AI<RT^7V-U<G)E;G13>6YC16QE;65N="DI('L*("`@
M("`@("`@("`@("`@(&EF("@D=&AI<RT^7U-T86-K6S%=(#T]("=3;W5R8V4G
M*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S;W5R8V554DD@/2!T
M<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@
M*"1T:&ES+3Y?4W1A8VM;,5T@/3T@)U1A<F=E="<I('L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W1A<F=E=%5222`](&)A<V5N86UE*'!R96=?<F5P
M;&%C92@G+UP_+BHD+R<L("<G+"!T<FEM*"1T:&ES+3Y?8VAA<G,I*2D["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@?0H*("`@("`@("!P87)E;G0Z.F5N9$5L96UE;G0H)'5R
M:2P@)&5L96UE;G0I.PH@("`@?0H*("`@(&9U;F-T:6]N(&-H87)A8W1E<G,H
M)'-T<BD*("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]C=7)R96YT
M4WEN8T5L96UE;G0I*2!["B`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=%-Y
M;F-%;&5M96YT+3YC:&%R86-T97)S*"1S='(I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-H87)S*2D@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]C:&%R<R`]("1T:&ES+3Y?8VAA<G,@+B`D
M<W1R.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]C:&%R<R`]("1S='(["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U-Y;F--3"]3
M=&%T92YP:'``````````````````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#(T,3$T(#$P-3$U-#,S-S,T(#`R,3(T-@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E
M("=3>6YC34PO1&5V:6-E26YF;RYP:'`G.PIR97%U:7)E7V]N8V4@)U-Y;F--
M3"]$979I8V4N<&AP)SL*<F5Q=6ER95]O;F-E("=3>6YC34PO0V]N<W1A;G1S
M+G!H<"<["@HO*BH*("H@5&AE(%-Y;F--3%]3=&%T92!C;&%S<R!P<F]V:61E
M<R!A(%-Y;F--3"!S=&%T92!O8FIE8W0N"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+U-Y;F--3"]3>6YC34PO4W1A=&4N<&AP+'8@,2XQ-RXR+C@@,C`P-B\P
M,2\P,2`R,3HR.#HS-B!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M
M,C`P-B!!;G1H;VYY($UI;&QS(#QA;6EL;'-`<'ER86UI9#8N8V]M/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@06YT:&]N>2!-:6QL<R`\86UI;&QS
M0'!Y<F%M:60V+F-O;3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K
M86=E(%-Y;F--3`H@*B\*8VQA<W,@4WEN8TU,7U-T871E('L*"B`@("`O*BH*
M("`@("`J(%-E<W-I;VX@:60@;V8@=&AI<R!S97-S:6]N+@H@("`@("HO"B`@
M("!V87(@)%]S97-S:6]N240["@H@("`@+RHJ"B`@("`@*B!)9"!O9B!C=7)R
M96YT(&UE<W-A9V4N"B`@("`@*B\*("`@('9A<B`D7VUS9TE$.PH*("`@("\J
M*@H@("`@("H@5&AE('1A<F=E="!54DD@87,@<V5N="!B>2!T:&4@8VQI96YT
M+B!4:&ES(&ES(&YO<FUA;&QY('1H92!54DP*("`@("`J(&]F('1H92!(;W)D
M92!R<&,@<V5R=F5R+B!(;W=E=F5R('1H92!C;&EE;G0@:7,@9G)E92!T;R!S
M96YD"B`@("`@*B!A;GET:&EN9SH@<WEN8S1J(&9O<B!E>&%M<&QE(&1O97,@
M;F]T('-E;F0@=&AE('!A=&@@<&%R="X*("`@("`J+PH@("`@=F%R("1?=&%R
M9V5T55)).PH*("`@("\J*@H@("`@("H@5&AE('-O=7)C92!54DD@87,@<V5N
M="!B>2!T:&4@8VQI96YT+B!#86X@8F4@=7-E9"!T;R!I9&5N=&EF>0H@("`@
M("H@=&AE(&-L:65N=#L@=&AE('-E<W-I;VX@:60@:7,@8V]N<W1R=6-T960@
M;6%I;FQY(&9R;VT@=&AI<PH@("`@("H@9&%T82X*("`@("`J+PH@("`@=F%R
M("1?<V]U<F-E55)).PH*("`@("\J*@H@("`@("H@,"!F;W(@<WEN8VUL(#$N
M,"P@,2!F;W(@<WEN8VUL(#$N,2X*("`@("`J+PH@("`@=F%R("1?=F5R<VEO
M;CL*"B`@("`O*BH*("`@("`J(%5S97)N86UE('5S960@=&\@875T:"!W:71H
M('1H92!B86-K96YD+@H@("`@("HO"B`@("!V87(@)%]L;V-.86UE.PH*("`@
M("\J*@H@("`@("H@4&%S<W=O<F0@=7-E9"!T;R!A=71H('=I=&@@=&AE(&)A
M8VME;F0N"B`@("`@*B\*("`@('9A<B`D7W!A<W-W;W)D.PH*("`@("\J*@H@
M("`@("H@5')U92!M96%N<R!T:&%T('1H:7,@<V5S<VEO;B!H87,@875T:&5N
M=&EC871E9"!S=6-C97-S9G5L;'DN"B`@("`@*B\*("`@('9A<B`D7VES075T
M:&]R:7IE9#L*"B`@("`O*BH*("`@("`J($YA;65S<&%C92!I;F9O<FUA=&EO
M;BX*("`@("`J+PH@("`@=F%R("1?=7)I.PH*("`@("\J*@H@("`@("H@3F%M
M97-P86-E(&EN9F]R;6%T:6]N+@H@("`@("HO"B`@("!V87(@)%]U<FE-971A
M.PH*("`@("\J*@H@("`@("H@3F%M97-P86-E(&EN9F]R;6%T:6]N+@H@("`@
M("HO"B`@("!V87(@)%]U<FE$979);F8["@H@("`@=F%R("1?=V)X;6P[("\O
M(&)O;VQE86X*"B`@("!V87(@)%]M87A-<V=3:7IE.PH*("`@('9A<B`D7W-Y
M;F-S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%=R:71T96X@=&\@9&(@
M869T97(@<W5C8V5S<V9U;"!S>6YC+@H@("`@("HO"B`@("!V87(@)%]C;&EE
M;G1!;F-H;W).97AT(#T@87)R87DH*3L*"B`@("!V87(@)%]S97)V97)!;F-H
M;W),87-T(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%=R:71T96X@=&\@
M9&(@869T97(@<W5C8V5S<V9U;"!S>6YC+@H@("`@("HO"B`@("!V87(@)%]S
M97)V97)!;F-H;W).97AT(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%-M
M86QL(&AA<V@@=&\@<W1O<F4@=&AE(&YU;6)E<B!O9B!A9&1S+"!D96QE=&5S
M+"!E=&,N(&1U<FEN9R!A"B`@("`@*B!S97-S:6]N(&9O<B!C<F5A=&EO;B!O
M9B!S=6UM87)Y(&9O<B!L;V=F:6QE+@H@("`@("HO"B`@("!V87(@)%]L;V<@
M/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@5&AE(%-Y;F--3%]$979I8V4@
M8VQA<W,@9&5F:6YE9"!I;B!$979I8V4N<&AP+B!4:&ES(&-L87-S"B`@("`@
M*B!H86YD;&5S(&1E8VEC92!S<&5C:69I8R!S='5F9BX*("`@("`J+PH@("`@
M=F%R("1?9&5V:6-E.PH*("`@("\J*@H@("`@("H@1&5V:6-E(&EN9F\@<')O
M=FED960@8GD@=&AE(%-Y;F--3"!$979);F8@9&%T82X@36%I;FQY('5S960@
M8GD*("`@("`J('1H92!3>6YC34Q?1&5V:6-E(&-L87-S+@H@("`@("HO"B`@
M("!V87(@)%]D979I8V5);F9O.PH*("`@("\J*@H@("`@("H@268@=V4@87)E
M(&5X<&5C=&EN9R!A(%)E<W5L="!P86-K970L('1H:7,@<W1O<F5S('=H97)E
M('1O"B`@("`@*B!R;W5T92!I="X*("`@("`J+PH@("`@=F%R("1?97AP96-T
M961297-U;'0@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0W)E871E<R!A
M(&YE=R!I;G-T86YC92!O9B!3>6YC34Q?4W1A=&4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%-Y;F--3%]3=&%T92@D<V]U<F-E55))+"`D;&]C3F%M92P@)'-E
M<W-I;VY)1"P@)'!A<W-W;W)D(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1H
M:7,M/G-E=%-O=7)C955222@D<V]U<F-E55))*3L*("`@("`@("`D=&AI<RT^
M<V5T3&]C3F%M92@D;&]C3F%M92D["B`@("`@("`@)'1H:7,M/G-E=%-E<W-I
M;VY)1"@D<V5S<VEO;DE$*3L*("`@("`@("!I9B`H)'!A<W-W;W)D*2!["B`@
M("`@("`@("`@("1T:&ES+3YS971087-S=V]R9"@D<&%S<W=O<F0I.PH@("`@
M("`@('T*"B`@("`@("`@)'1H:7,M/FES075T:&]R:7IE9"`](&9A;'-E.PH*
M("`@("`@("`O+R!#<F5A=&4@96UP='D@9'5M;7D@9&5V:6-E(&EN9F\N(%=I
M;&P@8F4@<F5P;&%C960@=VET:"!R96%L"B`@("`@("`@+R\@1&5V26YF(&EN
M9F]R;6%T:6]N(&EF('1H97D@87)E('1R86YS9F5R<F5D+@H@("`@("`@("1T
M:&ES+3Y?9&5V:6-E26YF;R`]("9N97<@4WEN8TU,7T1E=FEC94EN9F\H*3L*
M"B`@("`@("`@+RH@86QL;W<@=F5R>2!B:6<@;65S<V%G97,@=6YL97-S('1O
M;&0@;W1H97)W:7-E.B`J+PH@("`@("`@("1T:&ES+3YS971-87A-<V=3:7IE
M*#$P,#`P,#`P,#`I.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=$1E=FEC94EN
M9F\H)&1I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9&5V:6-E26YF;R`]("1D
M:3L*("`@('T*"B`@("!F=6YC=&EO;B!G971$979I8V5);F9O*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]D979I8V5);F9O.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&=E=$QO8TYA;64H*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^7VQO8TYA;64["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T4V]U<F-E
M55))*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]S;W5R8V554DD[
M"B`@("!]"@H@("`@9G5N8W1I;VX@9V5T5&%R9V5T55))*"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/E]T87)G97154DD["B`@("!]"@H@("`@9G5N
M8W1I;VX@9V5T5F5R<VEO;B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?=F5R<VEO;CL*("`@('T*"B`@("!F=6YC=&EO;B!G971-<V=)1"@I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;7-G240["B`@("!]"@H@("`@
M9G5N8W1I;VX@<V5T5T)834PH)'=B>&UL*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?=V)X;6P@/2`D=V)X;6P["B`@("!]"@H@("`@9G5N8W1I;VX@:7-70EA-
M3"@I"B`@("!["B`@("`@("`@<F5T=7)N("%E;7!T>2@D=&AI<RT^7W=B>&UL
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!S971-87A-<V=3:7IE*"1S*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?;6%X37-G4VEZ92`]("1S.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&=E=$UA>$US9U-I>F4H*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7VUA>$US9U-I>F4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M971T97(@9F]R('!R;W!E<G1Y(&US9TE$+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&US9TE$("!.97<@=F%L=64@;V8@<')O<&5R='D@;7-G240N
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$US9TE$*"1M<V=)1"D*("`@('L*
M("`@("`@("`D=&AI<RT^7VUS9TE$(#T@)&US9TE$.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4V5T=&5R(&9O<B!P<F]P97)T>2!L;V-.86UE+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&QO8TYA;64@($YE=R!V86QU92!O9B!P
M<F]P97)T>2!L;V-.86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971,;V-.
M86UE*"1L;V-.86UE*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;&]C3F%M92`]
M("1L;V-.86UE.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=%!A<W-W;W)D*"1P
M87-S=V]R9"D*("`@('L*("`@("`@("`D=&AI<RT^7W!A<W-W;W)D(#T@)'!A
M<W-W;W)D.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=%-O=7)C955222@D<V]U
M<F-E55))*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<V]U<F-E55))(#T@)'-O
M=7)C955223L*("`@('T*"B`@("!F=6YC=&EO;B!S971487)G97154DDH)'1A
M<F=E=%5222D*("`@('L*("`@("`@("`D=&AI<RT^7W1A<F=E=%5222`]("1T
M87)G97154DD["B`@("!]"@H@("`@9G5N8W1I;VX@<V5T5F5R<VEO;B@D=F5R
M<VEO;BD*("`@('L*("`@("`@("`D=&AI<RT^7W9E<G-I;VX@/2`D=F5R<VEO
M;CL*"B`@("`@("`@:68@*"1V97)S:6]N(#T](#`I('L*("`@("`@("`@("`@
M)'1H:7,M/E]U<FD@/2!.04U%7U-004-%7U5225]364Y#34P["B`@("`@("`@
M("`@("1T:&ES+3Y?=7)I365T82`]($Y!345?4U!!0T5?55))7TU%5$E.1CL*
M("`@("`@("`@("`@)'1H:7,M/E]U<FE$979);F8@/2!.04U%7U-004-%7U52
M25]$159)3D8["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M
M/E]U<FD@/2!.04U%7U-004-%7U5225]364Y#34Q?,5\Q.PH@("`@("`@("`@
M("`D=&AI<RT^7W5R:4UE=&$@/2!.04U%7U-004-%7U5225]-151)3D9?,5\Q
M.PH@("`@("`@("`@("`D=&AI<RT^7W5R:41E=DEN9B`]($Y!345?4U!!0T5?
M55))7T1%5DE.1E\Q7S$["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N
M('-E=%-E<W-I;VY)1"@D<V5S<VEO;DE$*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?<V5S<VEO;DE$(#T@)'-E<W-I;VY)1#L*("`@('T*"B`@("!F=6YC=&EO
M;B!I<T%U=&AO<FEZ960H*0H@("`@>PH@("`@("`@(&EF("@A)'1H:7,M/E]I
M<T%U=&AO<FEZ960@)B8@(65M<'1Y*"1T:&ES+3Y?<&%S<W=O<F0I*2!["B`@
M("`@("`@("`@("1'3$]"04Q36R=B86-K96YD)UTM/FQO9TUE<W-A9V4H)V-H
M96-K:6YG(&%U=&@@9F]R('5S97(])PH@("`@("`@("`@("`N("1T:&ES+3Y?
M;&]C3F%M92P*("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!
M4E],3T=?1$5"54<I.PH*("`@("`@("`@("`@)&%U=&@@/2`F075T:#HZ<VEN
M9VQE=&]N*"1'3$]"04Q36R=C;VYF)UU;)V%U=&@G75LG9')I=F5R)UTI.PH@
M("`@("`@("`@("`D=&AI<RT^7VES075T:&]R:7IE9"`]("1A=71H+3YA=71H
M96YT:6-A=&4H)'1H:7,M/E]L;V-.86UE+"!A<G)A>2@G<&%S<W=O<F0G(#T^
M("1T:&ES+3Y?<&%S<W=O<F0I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D=&AI<RT^7VES075T:&]R:7IE9#L*("`@('T*"B`@("!F=6YC=&EO;B!S
M9713>6YC*"1T87)G970L("8D<WEN8RD*("`@('L*("`@("`@("`D=&AI<RT^
M7W-Y;F-S6R1T87)G971=(#T@)B1S>6YC.PH@("`@?0H*("`@(&9U;F-T:6]N
M("9G9713>6YC*"1T87)G970I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T
M:&ES+3Y?<WEN8W-;)'1A<F=E=%TI*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7W-Y;F-S6R1T87)G971=.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1F86QS92`](&9A;'-E.PH@("`@("`@("`@("!R971U<FX@)&9A
M;'-E.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!G97154DDH*0H@
M("`@>PH@("`@("`@("\J"B`@("`@("`@("H@5&AE(&YO;B!70EA-3"!D979I
M8V5S("AN;W1A8FQY(%`Y,#`@86YD(%-Y;F,T:B!S965M('1O(&=E="!C;VYF
M=7-E9`H@("`@("`@("`J(&)Y(&$@/%-Y;F--3"!X;6QN<STB<WEN8VUL.E-9
M3D--3#$N,2(^(&5L96UE;G0N(%1H97D@<F5Q=6ER90H@("`@("`@("`J(&IU
M<W0@/%-Y;F--3#XN(%-O(&1O;B=T('5S92!A;B!N<R!F;W(@;F]N('=B>&UL
M(&1E=FEC97,N"B`@("`@("`@("HO"B`@("`@("`@:68@*"1T:&ES+3YI<U="
M6$U,*"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?=7)I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("!]
M"B`@("!]"B`@("!F=6YC=&EO;B!G97154DE-971A*"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]U<FE-971A.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&=E=%52241E=DEN9B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M=7)I1&5V26YF.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=$-L:65N=$%N8VAO
M<DYE>'0H)'1Y<&4L("1A*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8VQI96YT
M06YC:&]R3F5X=%LD='EP95T@/2`D83L*("`@('T*"B`@("!F=6YC=&EO;B!S
M971397)V97)!;F-H;W),87-T*"1T>7!E+"`D82D*("`@('L*("`@("`@("`D
M=&AI<RT^7W-E<G9E<D%N8VAO<DQA<W1;)'1Y<&5=(#T@)&$["B`@("!]"@H@
M("`@9G5N8W1I;VX@<V5T4V5R=F5R06YC:&]R3F5X="@D='EP92P@)&$I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]S97)V97)!;F-H;W).97AT6R1T>7!E72`]
M("1A.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$-L:65N=$%N8VAO<DYE>'0H
M)'1Y<&4I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8VQI96YT06YC
M:&]R3F5X=%LD='EP95T["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T4V5R=F5R
M06YC:&]R3F5X="@D='EP92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/E]S97)V97)!;F-H;W).97AT6R1T>7!E73L*("`@('T*"B`@("!F=6YC=&EO
M;B!G971397)V97)!;F-H;W),87-T*"1T>7!E*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7W-E<G9E<D%N8VAO<DQA<W1;)'1Y<&5=.PH@("`@?0H*
M("`@("\J*@H@("`@("H@5&AE(&QO9R!S:6UP;'D@8V]U;G1S('1H92!E;G1R
M:65S(&9O<B!E86-H('1O<&EC+@H@("`@("HO"B`@("!F=6YC=&EO;B!L;V<H
M)'1O<&EC*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VQO9ULD
M=&]P:6-=*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VQO9ULD=&]P:6-=("L]
M(#$["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]L;V=;
M)'1O<&EC72`](#$["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M5&AE($QO9R!I<R!A;B!A<G)A>2!W:&5R92!T:&4@:V5Y(&ES('1H92!E=F5N
M="!N86UE(&%N9"!T:&4*("`@("`J('9A;'5E('-A>7,@:&]W(&]F=&5N('1H
M:7,@979E;G0@;V-C=7)E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3&]G
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]L;V<["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&ED96YT:69I97(@=7-E9"!T;R!I
M9&5N=&EF>2!T:&4@<WEN8R!D979I8V4@:6X@=&AE"B`@("`@*B!M87`N($-U
M<G)E;G1L>2`B;&]C;F%M93IS;W5R8V554DDB+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G9713>6YC261E;G1I9FEE<B@I"B`@("!["B`@("`@("`@<F5T=7)N
M('-T<E]R97!L86-E*"<Z)RP@)U\G+"`D=&AI<RT^7VQO8TYA;64I"B`@("`@
M("`@("`@("`@("`N("<Z)PH@("`@("`@("`@("`@("`@+B!S=')?<F5P;&%C
M92@G.B<L("=?)RP@)'1H:7,M/E]S;W5R8V554DDI.PH@("`@?0H*("`@(&9U
M;F-T:6]N("9G971$979I8V4H*0H@("`@>PH@("`@("`@(')E='5R;B!3>6YC
M34Q?1&5V:6-E.CIS:6YG;&5T;VXH*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=&AE(&5X<&5C=&5D(')E<W5L="!T>7!E(&9O<B!A(%)E<W5L
M=',@=&%G+"!U<V5D('1O(')E9&ER96-T('1H90H@("`@("H@:6YC;VUI;F<@
M8V]M;6%N9"!S;VUE=VAE<F4@<W!E8VEA;"X@($9O<B!E>&%M<&QE+"!I9B!W
M92!H879E(')E<75E<W1E9`H@("`@("H@9&5V:6-E(&EN9F\L('1H92!297-U
M;'1S('1A9R!S:&]U;&0@8F4@<V5N="!T;R!T:&4@4'5T(&-O;6UA;F0@<V\@
M=V4@8V%N"B`@("`@*B!R96%D(&ET(&EN+@H@("`@("H*("`@("`J($-L96%R
M<R!T:&4@:&%S:"!O9B!T:&ES($-O;6UA;F0@4F5F97)E;F-E(&)E9F]R92!R
M971U<FYI;F<@82!V86QU92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D8VUD4F5F("!4:&4@0VUD4F5F(&]F('1H92!I;F-O;6EN9R!C;VUM86YD
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8V]M;6%N9"!T
M>7!E('1O(')E9&ER96-T('1O+"!O<@H@("`@("H@("`@("`@("`@("`@("`@
M('5N9&5F:6YE9"!I9B!N;R!R961I<F5C="!R96=I<W1E<F5D+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971%>'!E8W1E9%)E<W5L=%1Y<&4H)&-M9%)E9BD*
M("`@('L*("`@("`@("!I9B`H(&ES<V5T*"1T:&ES+3Y?97AP96-T961297-U
M;'1;)&-M9%)E9ETI("D@>PH@("`@("`@("`@("`D8VUD5'EP92`]("1T:&ES
M+3Y?97AP96-T961297-U;'1;)&-M9%)E9ET["B`@("`@("`@("`@('5N<V5T
M*"1T:&ES+3Y?97AP96-T961297-U;'1;)&-M9%)E9ETI.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@)&-M9%1Y<&4["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!3971S('5P(&$@8V]M;6%N9"!R961I<F5C=&EO;B!F;W(@82!F=71U<F4@
M4F5S=6QT(&-O;6UA;F0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)&-M9$E$("`@(%1H92!#;61)1"!O9B!T:&4@8V]M;6%N9"!W92!A<F4@<V5N
M9&EN9R!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('1H92!C
M;&EE;G0N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D8VUD5'EP92`@5&AE('1Y
M<&4@;V8@8V]M;6%N9"!T;R!R961I<F5C="!T;R!W:&5N"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@=&AE(%)E<W5L=',@8V]M;6%N9"!I<R!R
M96-E:79E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T17AP96-T961297-U
M;'14>7!E*"1C;61)1"P@)&-M9%1Y<&4I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]E>'!E8W1E9%)E<W5L=%LD8VUD241=(#T@)&-M9%1Y<&4["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#:&5C:R!I9B!T:&5R92!A<F4@86YY('!E;F1I;F<@
M96QE;65N=',@=&AA="!H879E(&YO="!B965N('-E;G0@=&\@9'5E"B`@("`@
M*B!T;R!M97-S86=E('-I='IE(')E<W1R:6-T:6]N<RX@5&AE<V4@=VEL;"!B
M92!S96YT(&EN="!T:&4@;F5X="!M<V<N"B`@("`@*@H@("`@("HO"B`@("!F
M=6YC=&EO;B!H87-096YD:6YG16QE;65N=',H*0H@("`@>PH*("`@("`@("!I
M9B`H:7-?87)R87DH)'1H:7,M/E]S>6YC<RDI('L*("`@("`@("`@("`@9F]R
M96%C:"`H)'1H:7,M/E]S>6YC<R!A<R`D<WEN8RD@>PH@("`@("`@("`@("`@
M("`@:68@*"1S>6YC+3YH87-096YD:6YG16QE;65N=',H*2D@>PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!F86QS93L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86QL('-Y;F-S('=H:6-H
M(&AA=F4@<&5N9&EN9R!E;&5M96YT<R!L969T+@H@("`@("H@4F5T=7)N<R!A
M;B!A<G)A>2!O9B!487)G971,;V-54DES('=H:6-H(&-A;B!B92!U<V5D"B`@
M("`@*B!A<R!A(&ME>2!I;B!G9713>6YC(&-A;&QS+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971096YD:6YG4WEN8W,H*0H@("`@>PH@("`@("`@("1R(#T@
M87)R87DH*3L*("`@("`@("!I9B`H:7-?87)R87DH)'1H:7,M/E]S>6YC<RDI
M('L*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]S>6YC<R!A<R`D=&%R
M9V5T(#T^("1S>6YC*2!["B`@("`@("`@("`@("`@("!I9B`H)'-Y;F,M/FAA
M<U!E;F1I;F=%;&5M96YT<R@I*2!["B`@("`@("`@("`@("`@("`@("`@)');
M72`]("1T87)G970["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R.PH@("`@?0I]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O4WEN8TU,+T)A8VME;F0N<&AP````````````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P-3<T-30@,3`U,34T,S,W,S0@,#(Q-3,R`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B!3>6YC34P@0F%C:V5N9"!F;W(@=&AE($AO<F1E($%P<&QI8V%T
M:6]N(&9R86UE=V]R:RX*("H*("H@5&AE(&)A8VME;F0@<')O=FED97,@=&AE
M(&9O;&QO=VEN9R!F=6YC=&EO;F%L:71Y.@H@*@H@*B`Q*2!H86YD;&EN9R!O
M9B!T:&4@86-T=6%L(&1A=&$L(&DN92X*("H@("`@82D@861D+W)E<&QA8V4O
M9&5L971E(&5N=')I97,@=&\@86YD(')E=')I979E(&5N=')I97,@9G)O;2!T
M:&4*("H@("`@("`@8F%C:V5N9`H@*B`@("!B*2!R971R:65V92!H:7-T;W)Y
M('1O(&9I;F0@;W5T('=H870@96YT<FEE<R!H879E(&)E96X@8VAA;F=E9`H@
M*B`R*2!M86YA9VEN9R!O9B!T:&4@;6%P(&)E='=E96X@8VQI96YD($E$<R!A
M;F0@<V5R=F5R($E$<PH@*B`S*2!S=&]R92!I;F9O<FUA=&EO;B!A8F]U="!S
M>6YC(&%N8VAO<G,@*'1I;65S=&%M<',I(&]F('!R979I;W5S"B`J("`@('-U
M8V-E<W-F=6QS('-Y;F,@<V5S<VEO;G,*("H@-"D@<V5S<VEO;B!H86YD;&EN
M9R`H;F]T('EE="P@<W1I;&P@=&\@8F4@9&]N92D*("H@-2D@875T:&]R:7-A
M=&EO;B`H;F]T('EE="P@<W1I;&P@=&\@8F4@9&]N92D*("H@-BD@;&]G9VEN
M9PH@*@H@*B!#;W!Y<FEG:'0@,C`P-2TR,#`V($MA<G-T96X@1F]U<FUO;G0@
M/&MA<G-T96Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO4WEN8TU,+U-Y;F--3"]"86-K96YD+G!H<"QV(#$N."XR
M+C@@,C`P-B\P-R\Q."`Q,CHP,#HU-B!J86X@17AP("0*("H*("H@0&%U=&AO
M<B`@2V%R<W1E;B!&;W5R;6]N="`\:V%R<W1E;D!H;W)D92YO<F<^"B`J($!P
M86-K86=E(%-Y;F--3`H@*B\*8VQA<W,@4WEN8TU,7T)A8VME;F1?2&]R9&4@
M>PH*("`@("\J*@H@("`@("H@06X@87)R87D@87,@=F%L=64@:6YD:6-A=&5S
M('1H870@9F]R('1H:7,@8VQI96YT(&-A=&5G;W)Y(&YO"B`@("`@*B!S97)V
M97(@8V%T96=O<GD@:7,@9&5F:6YE9"!Y970N(%1H92!A<G)A>2!C;VYT96YT
M(&ES('1H90H@("`@("H@<W5M;6%R>2!T97AT(&]F('1H92!L87-T(&5N8V]U
M;G1E<F5D(&-L:65N="!E;G1R>2!T:&%T('5S960*("`@("`J('1H:7,@8V%T
M96=O<GDN"B`@("`@*@H@("`@("H@("!K97DZ("`@8VQI96YT0V%T96=O<GD*
M("`@("`J("`@=F%L=64Z('-E<G9E<D-A=&5G;W)Y"B`@("`@*B\*("`@('9A
M<B`D7V-A=&5G;W)I97--87`["@H@("`@+RHJ"B`@("`@*B!397)V97(@8V%T
M96=O<FEE<R!M:7-S:6YG(&]N('1H92!C;&EE;G0N"B`@("`@*@H@("`@("H@
M("!K97DZ("`@<V5R=F5R0V%T96=O<GD*("`@("`J("`@=F%L=64Z('-U;6UA
M<GD@;V8@;&%S="!E;G1R>2!W:71H('1H:7,@8V%T96=O<GD*("`@("`J+PH@
M("`@=F%R("1?;6ES<VEN9U-E<G9E<D-A=&5G;W)I97,["@H@("`@=F%R("1?
M9&%T871R964["@H@("`@+RHJ"B`@("`@*B!#86-H92!F;W(@1&%T871R964@
M=F%L=65S"B`@("`@*B\*("`@("`*("`@('9A<B`D7V-A8VAE.PH@("`@"B`@
M("!F=6YC=&EO;B!3>6YC34Q?0F%C:V5N9%](;W)D92@I"B`@("!["B`@("`@
M("`@)&1R:79E<B`]("1'3$]"04Q36R=C;VYF)UU;)V1A=&%T<F5E)UU;)V1R
M:79E<B==.PH@("`@("`@("1P87)A;7,@/2!(;W)D93HZ9V5T1')I=F5R0V]N
M9FEG*"=D871A=')E92<L("1D<FEV97(I.PH@("`@("`@("1P87)A;7,@/2!A
M<G)A>5]M97)G92@D<&%R86US+"!A<G)A>2@G9W)O=7`G(#T^("=S>6YC;6PG
M*2D["@H@("`@("`@("1T:&ES+3Y?9&%T871R964@/28@1&%T851R964Z.G-I
M;F=L971O;B@D9')I=F5R+"`D<&%R86US*3L*("`@("`@("`D=&AI<RT^7V-A
M8VAE(#T@87)R87DH*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E
M<R!A;B!E;G1R>2!F<F]M('1H92!B86-K96YD+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&1A=&%B87-E("`@1&%T86)A<V4@=&\@<V-A;BX@:2YE
M+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!C86QE;F1A<B]T
M87-K<R]C;VYT86-T<R]N;W1E<PH@("`@("H@0'!A<F%M('-T<FEN9R`D<W5I
M9"`@("`@("!397)V97(@=6YI<75E(&ED(&]F('1H92!E;G1R>3H@9F]R(&AO
M<F1E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@('1H:7,@:7,@
M=&AE(&=U:60N"B`@("`@*B!`<&%R86T@<W1R:6YG(&-O;G1E;G14>7!E($-O
M;G1E;G0M5'EP93H@=&AE(&UI;64@='EP92!I;B!W:&EC:"!T:&4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@9G5N8W1I;VX@<VAA;&P@<F5T
M=7)N('1H92!D871A"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@("`@
M("`@("`@("!!('-T<FEN9R!W:71H('1H92!D871A(&5N=')Y(&]R"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&]R(&$@4$5!4E]%<G)O<B!O
M8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E=')I979E16YT<GDH)&1A
M=&%B87-E+"`D<W5I9"P@)&-O;G1E;G14>7!E*0H@("`@>PH@("`@("`@(')E
M='5R;B`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^8V%L;"@D9&%T86)A<V4@+B`G
M+V5X<&]R="<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"=G=6ED)R`]/B`D<W5I9"P@)V-O;G1E;G14>7!E)R`]
M/B`D8V]N=&5N=%1Y<&4I*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!E
M;G1R:65S('1H870@:&%V92!B965N(&UO9&EF:65D(&EN('1H92!S97)V97(@
M9&%T86)A<V4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<WEN8TED
M96YT:69I97(@($ED96YT:69I97,@=&AE(&-L:65N="!D979I8V4@=&\@86QL
M;W<@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M=7-E<B!T;R!S>6YC('=I=&@@9&EF9F5R96YT(&1E=FEC97,N"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@3F]R;6%L;'D@=&AE(%-O
M=7)C955222!F<F]M('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%-Y;F-(96%D97(*("`@("`J($!P87)A;2!S=')I;F<@)&1A
M=&%B87-E("`@("`@("!$871A8F%S92!T;R!S8V%N+B!I+F4N"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V%L96YD87(O=&%S:W,O
M8V]N=&%C=',O;F]T97,*("`@("`J($!P87)A;2!I;G1E9V5R("1F<F]M7W1S
M("`@("`@("!3=&%R="!T:6UE<W1A;7`N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D=&]?=',@("`@("`@("`@17AC;'5S:79E(&5N9"!T:6UE<W1A;7`N($YO
M="!Y970*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M;7!L96UE;G1E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!014%2
M7T5R<F]R(&]R(&%S<V]C(&%R<F%Y(&]F(&-H86YG97,@=VET:"!K97D]<W5I
M9"P*("`@("`J("`@("`@("`@("`@("`@('9A;'5E/6-U:60N($EF(&YO(&-U
M:60@8V%N(&)E(&9O=6YD(&9O<B!A('-U:60L('9A;'5E(&ES"B`@("`@*B`@
M("`@("`@("`@("`@("!N=6QL+B!4:&5N(&$@4WEN8R!!9&0@8V]M;6%N9"!H
M87,@=&\@8F4@8W)E871E9"!T;R!A9&0*("`@("`J("`@("`@("`@("`@("`@
M('1H:7,@96YT<GD@:6X@=&AE(&-L:65N="!D871A8F%S92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T4V5R=F5R36]D:69I8V%T:6]N<R@D<WEN8TED96YT
M:69I97(L("1D871A8F%S92P@)&9R;VU?=',L("1T;U]T<RD*("`@('L*("`@
M("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("!I9B`H)&9R;VU?=',@
M/3T@,"D@>PH@("`@("`@("`@("`O+R!#;VUP;&5T92!S>6YC.B!E=F5R>71H
M:6YG(&ES('-E;G0@9'5R:6YG"B`@("`@("`@("`@("\O(&=E=%-E<G9E<D%D
M9&ET:6]N<RX@3F\@;F5E9"!T;R!S96YD(&UO9&EF:6-A=&EO;G,N"B`@("`@
M("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@+R\@
M1V5T(&-H86YG97,N"B`@("`@("`@)&-H86YG97,@/2`D<F5G:7-T<GDM/F-A
M;&PH)&1A=&%B87-E+B`G+VQI<W1">2<L(&%R<F%Y*"=A8W1I;VXG(#T^("=M
M;V1I9GDG+"`G=&EM97-T86UP)R`]/B`D9G)O;5]T<RDI.PH@("`@("`@(&EF
M("AI<U]A*"1C:&%N9V5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("1T:&ES+3YL;V=-97-S86=E*")3>6YC34PZ("1D871A8F%S92]L:7-T0GD@
M9F%I;&5D(&9O<B!M;V1I9GDZ(@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`N("1C:&%N9V5S+3YG971-97-S86=E*"DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?
M5T%23DE.1RD["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@("`@
M('T*"B`@("`@("`@)'(@/2!A<G)A>2@I.PH*("`@("`@("!F;W)E86-H("@D
M8VAA;F=E<R!A<R`D<W5I9"D@>PH@("`@("`@("`@("`D<W5I9%]T<R`]("1R
M96=I<W1R>2T^8V%L;"@D9&%T86)A<V4@+B`G+V=E=$%C=&EO;E1I;65S=&%M
M<"<L(&%R<F%Y*"1S=6ED+"`G;6]D:69Y)RDI.PH@("`@("`@("`@("`D<WEN
M8U]T<R`]("1T:&ES+3YG971#:&%N9V544R@D<WEN8TED96YT:69I97(L("1D
M871A8F%S92P@)'-U:60I.PH@("`@("`@("`@("!I9B`H)'-Y;F-?=',@)B8@
M)'-Y;F-?=',@/CT@)'-U:61?=',I('L*("`@("`@("`@("`@("`@("\O($-H
M86YG92!W87,@9&]N92!B>2!U<R!U<&]N(')E<75E<W0@;V8@8VQI96YT+@H@
M("`@("`@("`@("`@("`@+R\@1&]N)W0@;6ER<F]R('1H870@8F%C:R!T;R!T
M:&4@8VQI96YT+@H@("`@("`@("`@("`@("`@)'1H:7,M/FQO9TUE<W-A9V4H
M(F-H86YG93H@)'-U:60@:6=N;W)E9"P@8V%M92!F<F]M(&-L:65N="(L(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@
M("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&-U
M:60@/2`D=&AI<RT^9V5T0W5I9"@D<WEN8TED96YT:69I97(L("1D871A8F%S
M92P@)'-U:60I.PH@("`@("`@("`@("!I9B`H(21C=6ED*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^;&]G365S<V%G92@B56YA8FQE('1O(&-R96%T92!C
M:&%N9V4@9F]R("1S=6ED.B!C;&EE;G0M:60@;F]T(&9O=6YD(&EN(&UA<"X@
M5')Y:6YG(&%D9"!I;G-T96%D+B(L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7U=!4DY)
M3D<I.PH@("`@("`@("`@("`@("`@)');)'-U:61=(#T@;G5L;#L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1R6R1S=6ED72`]("1C
M=6ED.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)'(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@96YT<FEE<R!T:&%T(&AA
M=F4@8F5E;B!D96QE=&5D(&9R;VT@=&AE('-E<G9E<B!D871A8F%S92X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A8F%S92`@1&%T86)A<V4@
M=&\@<V-A;BX@:2YE+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M(&-A;&5N9&%R+W1A<VMS+V-O;G1A8W1S+VYO=&5S"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D9G)O;5]T<PH@("`@("H@0'!A<F%M(&EN=&5G97(@)'1O7W1S
M("`@($5X8VQU<VEV90H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%!%
M05)?17)R;W(@;W(@87-S;V,@87)R87D@;V8@9&5L971I;VYS('=I=&@@:V5Y
M/7-U:60L"B`@("`@*B`@("`@("`@("`@("`@("!V86QU93UC=6ED+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971397)V97)$96QE=&EO;G,H)'-Y;F-)9&5N
M=&EF:65R+"`D9&%T86)A<V4L("1F<F]M7W1S+"`D=&]?=',I"B`@("!["B`@
M("`@("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@:68@*"1F<F]M7W1S
M(#T](#`I('L*("`@("`@("`@("`@+R\@0V]M<&QE=&4@<WEN8SH@979E<GET
M:&EN9R!I<R!S96YT(&1U<FEN9PH@("`@("`@("`@("`O+R!G971397)V97)!
M9&1I=&EO;G,N("!.;R!N965D('1O('-E;F0@9&5L971I;VYS+@H@("`@("`@
M("`@("!R971U<FX@87)R87DH*3L*("`@("`@("!]"@H@("`@("`@("\O($=E
M="!D96QE=&EO;G,N"B`@("`@("`@)&1E;&5T97,@/2`D<F5G:7-T<GDM/F-A
M;&PH)&1A=&%B87-E+B`G+VQI<W1">2<L(&%R<F%Y*"=A8W1I;VXG(#T^("=D
M96QE=&4G+"`G=&EM97-T86UP)R`]/B`D9G)O;5]T<RDI.PH*("`@("`@("!I
M9B`H:7-?82@D9&5L971E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^;&]G365S<V%G92@B4WEN8TU,.B`D9&%T86)A<V4O;&ES=$)Y
M(&9A:6QE9"!F;W(@9&5L971E.B(*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+B`D9&5L971E<RT^9V5T365S<V%G92@I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'
M7U=!4DY)3D<I.PH@("`@("`@("`@("!R971U<FX@87)R87DH*3L*("`@("`@
M("!]"@H@("`@("`@("1R(#T@87)R87DH*3L*"B`@("`@("`@9F]R96%C:"`H
M)&1E;&5T97,@87,@)'-U:60I('L*("`@("`@("`@("`@)'-U:61?=',@/2`D
M<F5G:7-T<GDM/F-A;&PH)&1A=&%B87-E+B`G+V=E=$%C=&EO;E1I;65S=&%M
M<"<L(&%R<F%Y*"1S=6ED+"`G9&5L971E)RDI.PH@("`@("`@("`@("`D<WEN
M8U]T<R`]("1T:&ES+3YG971#:&%N9V544R@D<WEN8TED96YT:69I97(L("1D
M871A8F%S92P@)'-U:60I.PH@("`@("`@("`@("!I9B`H)'-Y;F-?=',@)B8@
M)'-Y;F-?=',@/CT@)'-U:61?=',I('L*("`@("`@("`@("`@("`@("\O($-H
M86YG92!W87,@9&]N92!B>2!U<R!U<&]N(')E<75E<W0@;V8@8VQI96YT+@H@
M("`@("`@("`@("`@("`@+R\@1&]N)W0@;6ER<F]R('1H870@8F%C:R!T;R!T
M:&4@8VQI96YT+@H@("`@("`@("`@("`@("`@)'1H:7,M/FQO9TUE<W-A9V4H
M(E-Y;F--3#H@9&5L971E("1S=6ED(&EG;F]R960L(&-A;64@9G)O;2!C;&EE
M;G0B+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@
M("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1C=6ED(#T@)'1H:7,M/F=E=$-U:60H)'-Y;F-)9&5N=&EF:65R+"`D
M9&%T86)A<V4L("1S=6ED*3L*("`@("`@("`@("`@:68@*"$D8W5I9"D@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/FQO9TUE<W-A9V4H(E5N86)L92!T;R!C
M<F5A=&4@9&5L971E(&9O<B`D<W5I9#H@;&]C:60@;F]T(&9O=6YD(&EN(&UA
M<"(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?
M7RP@7U],24Y%7U\L(%!%05)?3$]'7U=!4DY)3D<I.PH@("`@("`@("`@("`@
M("`@8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1R6R1S
M=6ED72`]("1C=6ED.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1V5T(&5N=')I97,@=&AA="!H879E(&)E
M96X@861D960@=&\@=&AE('-E<G9E<B!D871A8F%S92X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1D871A8F%S92`@1&%T86)A<V4@=&\@<V-A;BX@
M:2YE+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&-A;&5N9&%R
M+W1A<VMS+V-O;G1A8W1S+VYO=&5S"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M9G)O;5]T<PH@("`@("H@0'!A<F%M(&EN=&5G97(@)'1O7W1S("`@($5X8VQU
M<VEV90H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%!%05)?17)R;W(@
M;W(@87-S;V,@87)R87D@;V8@9&5L971I;VYS('=I=&@@:V5Y/7-U:60L"B`@
M("`@*B`@("`@("`@("`@("`@("!V86QU93TP+B`H87)R87D@<W1Y;&4@:7,@
M8VAO<V5N('1O(&UA=&-H(&-H86YG92`F(&1E;"D*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T4V5R=F5R061D:71I;VYS*"1S>6YC261E;G1I9FEE<BP@)&1A
M=&%B87-E+"`D9G)O;5]T<RP@)'1O7W1S*0H@("`@>PH@("`@("`@(&=L;V)A
M;"`D<F5G:7-T<GD["@H@("`@("`@(&EF("@D9G)O;5]T<R`]/2`P*2!["B`@
M("`@("`@("`@("\O(%)E='5R;B!A;&P@9&(@96YT<FEE<R!D:7)E8W1L>2!R
M871H97(@=&AA;B!B;W1H97(*("`@("`@("`@("`@+R\@:&ES=&]R>3H*("`@
M("`@("`@("`@)&%D9',@/2`D<F5G:7-T<GDM/F-A;&PH)&1A=&%B87-E+B`G
M+VQI<W0G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D861D<R`]
M("1R96=I<W1R>2T^8V%L;"@D9&%T86)A<V4N("<O;&ES=$)Y)RP@87)R87DH
M)V%C=&EO;B<@/3X@)V%D9"<L("=T:6UE<W1A;7`G(#T^("1F<F]M7W1S*2D[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?82@D861D<RP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`D=&AI<RT^;&]G365S<V%G92@B4WEN8TU,
M.B`D9&%T86)A<V4O;&ES=$)Y(&9A:6QE9"!F;W(@861D.B(*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@+B`D861D<RT^9V5T365S<V%G92@I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%
M7U\L(%!%05)?3$]'7U=!4DY)3D<I.PH@("`@("`@("`@("!R971U<FX@87)R
M87DH*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YL;V=-97-S86=E*"=A
M9&0@;6]D:69I8V%T:6]N<R!R971R:65V960N(&-O=6YT/2<*("`@("`@("`@
M("`@("`@("`@("`@("`@("`N(&-O=6YT*"1A9&1S*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%
M0E5'*3L*"B`@("`@("`@)'(@/2!A<G)A>2@I.PH*("`@("`@("!F;W)E86-H
M("@D861D<R!A<R`D<W5I9"D@>PH@("`@("`@("`@("`D<W5I9%]T<R`]("1R
M96=I<W1R>2T^8V%L;"@D9&%T86)A<V4@+B`G+V=E=$%C=&EO;E1I;65S=&%M
M<"<L(&%R<F%Y*"1S=6ED+"`G861D)RDI.PH@("`@("`@("`@("`D<WEN8U]T
M<R`]("1T:&ES+3YG971#:&%N9V544R@D<WEN8TED96YT:69I97(L("1D871A
M8F%S92P@)'-U:60I.PH@("`@("`@("`@("!I9B`H)'-Y;F-?=',@)B8@)'-Y
M;F-?=',@/CT@)'-U:61?=',I('L*("`@("`@("`@("`@("`@("\O($-H86YG
M92!W87,@9&]N92!B>2!U<R!U<&]N(')E<75E<W0@;V8@8VQI96YT+@H@("`@
M("`@("`@("`@("`@+R\@1&]N)W0@;6ER<F]R('1H870@8F%C:R!T;R!T:&4@
M8VQI96YT+@H@("`@("`@("`@("`@("`@)'1H:7,M/FQO9TUE<W-A9V4H(F%D
M9#H@)'-U:60@:6=N;W)E9"P@8V%M92!F<F]M(&-L:65N="(L(%]?1DE,15]?
M+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("`@("`@
M8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1C=6ED(#T@
M)'1H:7,M/F=E=$-U:60H)'-Y;F-)9&5N=&EF:65R+"`D9&%T86)A<V4L("1S
M=6ED*3L*"B`@("`@("`@("`@(&EF("@D8W5I9"`F)B`D9G)O;5]T<R`]/2`P
M*2!["B`@("`@("`@("`@("`@("`O+R!&;W(@<VQO=R!S>6YC("AT<R`](#`I
M+"!D;R!N;W0@861D(&1A=&$@9F]R('=H:6-H"B`@("`@("`@("`@("`@("`O
M+R!W92!H879E(&$@;&]C:60@86=A:6XN(%1H:7,@:7,@82!H975R:7-T:6,@
M=&\*("`@("`@("`@("`@("`@("\O(&%V;VED(&1U<&QI8V%T:6]N(&]F(&5N
M=')I97,N"B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G365S<V%G92@B<VMI
M<'!I;F<@861D(&]F(&=U:60@)'-U:60@87,@=&AE<F4@86QR96%D>2!I<R!A
M(&-U:60@)&-U:60B+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%
M0E5'*3L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1R6R1S=6ED72`](#`["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)'(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&%N(&5N
M=')Y(&EN=&\@=&AE('-E<G9E<B!D871A8F%S92X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1D871A8F%S92`@("`@1&%T86)A<V4@=VAE<F4@=&\@
M861D+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-A;&5N
M9&%R+W1A<VMS+V-O;G1A8W1S+VYO=&5S"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1C;VYT96YT("`@("`@5&AE(&%C='5A;"!D871A"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1C;VYT96YT5'EP92`@36EM971Y<&4@;V8@)&-O;G1E;G0*("`@
M("`J($!P87)A;2!S=')I;F<@)&-U:60@("`@("`@("!#;&EE;G0@240@;V8@
M=&AI<R!E;G1R>2`H9F]R(&UA<"D*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!014%27T5R<F]R(&]R('-U:60@*$AO<F1E(&=U:60I(&]F(&YE=R!E
M;G1R>0H@("`@("HO"B`@("!F=6YC=&EO;B!I;7!O<G1%;G1R>2@D<WEN8TED
M96YT:69I97(L("1D871A8F%S92P@)&-O;G1E;G0L("1C;VYT96YT5'EP92P@
M)&-U:60I"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@
M("`@)'1A<VMS86YD8V%L96YD87)C;VUB:6YE9"`](&9A;'-E.PH*("`@("`@
M("`O+R!#:&5C:W,@:68@=&AE(&-L:65N="!S96YD<R!U<R!A('9T;V1O(&EN
M(&$@8V%L96YD87(@<WEN8SH*("`@("`@("!I9B`H)&1A=&%B87-E(#T]("=C
M86QE;F1A<B<*("`@("`@("`@("`@("8F('!R96=?;6%T8V@H)R\H7')<;GQ<
M<GQ<;BE"14=)3EM>.ETJ.E943T1/+R<L(")<;B(@+B`D8V]N=&5N="DI('L*
M("`@("`@("`@("`@)'-E<G9E<F1A=&%B87-E(#T@)W1A<VMS)SL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D<V5R=F5R9&%T86)A<V4@/2`D9&%T
M86)A<V4["B`@("`@("`@?0H*("`@("`@("`D<W5I9"`]("1R96=I<W1R>2T^
M8V%L;"@D<V5R=F5R9&%T86)A<V4@+B`G+VEM<&]R="<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)&-O;G1E;G0L("1C;VYT96YT
M5'EP92DI.PH*("`@("`@("`D=&AI<RT^;&]G365S<V%G92@B861D('1O('-E
M<G9E<B!D8B`D<V5R=F5R9&%T86)A<V4@8W5I9"`D8W5I9"`M/B!S=6ED("1S
M=6ED(BP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@
M("`@("`@(&EF("@A:7-?82@D<W5I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`D=',@/2`D<F5G:7-T<GDM/F-A;&PH)'-E<G9E<F1A=&%B87-E
M+B`G+V=E=$%C=&EO;E1I;65S=&%M<"<L(&%R<F%Y*"1S=6ED+"`G861D)RDI
M.PH@("`@("`@("`@("!I9B`H(21T<RD@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/FQO9TUE<W-A9V4H)U5N86)L92!T;R!F:6YD(&%D9"UT<R!F;W(@)R`N
M("1S=6ED("X@)R!A="`G("X@)'1S+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%
M05)?3$]'7T524BD["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M
M/F-R96%T955I9$UA<"@D<WEN8TED96YT:69I97(L("1D871A8F%S92P@)&-U
M:60L("1S=6ED+"`D=',I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1S
M=6ED.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E<R!A;B!E;G1R>2!F
M<F]M('1H92!S97)V97(@9&%T86)A<V4N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D9&%T86)A<V4@($1A=&%B87-E('=H97)E('1O(&%D9"X*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("!C86QE;F1A<B]T87-K<R]C
M;VYT86-T<R]N;W1E<PH@("`@("H@0'!A<F%M('-T<FEN9R`D8W5I9"`@("`@
M($-L:65N="!)1"!O9B!T:&4@96YT<GD*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("!014%27T5R<F]R(&]R('-U:60@*$AO<F1E(&=U:60I(&]F(&1E
M;&5T960@96YT<GDN"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T945N=')Y
M*"1S>6YC261E;G1I9FEE<BP@)&1A=&%B87-E+"`D8W5I9"D*("`@('L*("`@
M("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("`O+R!&:6YD('-E<G9E
M<B!)1"!F;W(@=&AI<R!E;G1R>3H*("`@("`@("`D<W5I9"`]("1T:&ES+3YG
M9713=6ED*"1S>6YC261E;G1I9FEE<BP@)&1A=&%B87-E+"`D8W5I9"D["B`@
M("`@("`@:68@*"%I<U]A*"1S=6ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("1R96=I<W1R>2T^8V%L;"@D9&%T86)A<V4N("<O9&5L971E)RP@
M87)R87DH)'-U:60I*3L*("`@("`@("`@("`@)'1S(#T@)')E9VES=')Y+3YC
M86QL*"1D871A8F%S92`N("<O9V5T06-T:6]N5&EM97-T86UP)RP@87)R87DH
M)'-U:60L("=D96QE=&4G*2D["B`@("`@("`@("`@("\O(%=E(&-A;B=T(')E
M;6]V92!T:&4@;6%P<&EN9R!E;G1R>2!A<R!W92!N965D('1O(&ME97`*("`@
M("`@("`@("`@+R\@=&AE('1I;65S=&%M<"!I;F9O<FUA=&EO;BX*("`@("`@
M("`@("`@)'1H:7,M/F-R96%T955I9$UA<"@D<WEN8TED96YT:69I97(L("1D
M871A8F%S92P@)&-U:60L("1S=6ED+"`D=',I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1S=6ED.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5P;&%C
M97,@86X@96YT<GD@:6X@=&AE('-E<G9E<B!D871A8F%S92X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1D871A8F%S92`@("`@1&%T86)A<V4@=VAE
M<F4@=&\@<F5P;&%C92X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!C86QE;F1A<B]T87-K<R]C;VYT86-T<R]N;W1E<PH@("`@("H@0'!A
M<F%M('-T<FEN9R`D8V]N=&5N="`@("`@(%1H92!A8W1U86P@9&%T80H@("`@
M("H@0'!A<F%M('-T<FEN9R`D8V]N=&5N=%1Y<&4@($UI;65T>7!E(&]F("1C
M;VYT96YT"B`@("`@*B!`<&%R86T@<W1R:6YG("1C=6ED("`@("`@("`@0VQI
M96YT($E$(&]F('1H:7,@96YT<GD*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!014%27T5R<F]R(&]R('-U:60@*$AO<F1E(&=U:60I(&]F(&UO9&EF
M:65D(&5N=')Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!R97!L86-E16YT<GDH
M)'-Y;F-)9&5N=&EF:65R+"`D9&%T86)A<V4L("1C;VYT96YT+"`D8V]N=&5N
M=%1Y<&4L("1C=6ED*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD[
M"@H@("`@("`@("\O($-H96-K<R!I9B!T:&4@8VQI96YT('-E;F1S('5S(&$@
M=G1O9&\@:6X@82!C86QE;F1A<B!S>6YC.@H@("`@("`@(&EF("@D9&%T86)A
M<V4@/3T@)V-A;&5N9&%R)PH@("`@("`@("`@("`@)B8@<')E9U]M871C:"@G
M+RA<<EQN?%QR?%QN*4)%1TE.6UXZ72HZ5E1/1$\O)RP@(EQN(B`N("1C;VYT
M96YT*2D@>PH@("`@("`@("`@("`D<V5R=F5R9&%T86)A<V4@/2`G=&%S:W,G
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1S97)V97)D871A8F%S
M92`]("1D871A8F%S93L*("`@("`@("!]"@H@("`@("`@("1S=6ED(#T@)'1H
M:7,M/F=E=%-U:60H)'-Y;F-)9&5N=&EF:65R+"`D9&%T86)A<V4L("1C=6ED
M*3L*"B`@("`@("`@)'1H:7,M/FQO9TUE<W-A9V4H(G)E<&QA8V4@:6X@9&(@
M)'-E<G9E<F1A=&%B87-E(&-U:60@)&-U:60@<W5I9"`D<W5I9"(L(%]?1DE,
M15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("!I9B`H
M)'-U:60I('L*("`@("`@("`@("`@+R\@16YT<GD@97AI<W1S.B!R97!L86-E
M(&-U<G)E;G0@;VYE+@H@("`@("`@("`@("`D;VL@/2`D<F5G:7-T<GDM/F-A
M;&PH)'-E<G9E<F1A=&%B87-E("X@)R]R97!L86-E)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1S=6ED+"`D8V]N=&5N="P@
M)&-O;G1E;G14>7!E*2D["B`@("`@("`@("`@(&EF("AI<U]A*"1O:RP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1O:SL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D=',@/2`D<F5G:7-T<GDM/F-A;&PH
M)'-E<G9E<F1A=&%B87-E("X@)R]G971!8W1I;VY4:6UE<W1A;7`G+"!A<G)A
M>2@D<W5I9"P@)VUO9&EF>2<I*3L*("`@("`@("`@("`@)'1H:7,M/F-R96%T
M955I9$UA<"@D<WEN8TED96YT:69I97(L("1D871A8F%S92P@)&-U:60L("1S
M=6ED+"`D=',I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"=.;R!M87`@96YT<GD@9F]U;F0G*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D<W5I9#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E=')I979E<R!I;F9O<FUA=&EO;B!A8F]U="!T:&4@<')E=FEO
M=7,@<WEN8R!I9B!A;GDN(%)E='5R;G,*("`@("`J(&9A;'-E(&EF(&YO(&EN
M9F\@9F]U;F0@;W(@82!$871E5')E94]B:F5C="!W:71H(&%T(&QE87-T('1H
M90H@("`@("H@9F]L;&]W:6YG(&%T=')I8G5T97,Z"B`@("`@*@H@("`@("H@
M0VQI96YT06YC:&]R.B!T:&4@8VQI96YT<R!.97AT($%N8VAO<B!O9B!T:&4@
M<')E=FEO=7,@<WEN8RX*("`@("`J(%-E<G9E<D%N8VAO<CH@=&AE(%-E<G9E
M<B!.97AT($%N8VAO<B!O9B!T:&4@<')E=FEO=7,@<WEN8RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@)F=E=%-Y;F-3=6UM87)Y*"1S>6YC261E;G1I9FEE<BP@
M)'1Y<&4I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9V5T3V(H)'-Y
M;F-)9&5N=&EF:65R("X@)SIS=6UM87)Y.B<@+B`D='EP92D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!!9G1E<B!A('-U8V-E<W-F=6P@<WEN8RP@=&AE(&-L
M:65N="!A;F0@<V5R=F5R)W,@3F5X="!!;F-H;W)S"B`@("`@*B!A<F4@=W)I
M='1E;B!T;R!T:&4@9&%T86)A<V4@<V\@=&AE>2!C86X@8F4@=7-E9"!T;R!N
M96=O=&EA=&4*("`@("`J('5P8V]M:6YG('-Y;F-S+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!W<FET95-Y;F-3=6UM87)Y*"1S>6YC261E;G1I9FEE<BP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-L:65N=$%N8VAO<DYE>'0L
M("1S97)V97)!;F-H;W).97AT*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H
M)'-E<G9E<D%N8VAO<DYE>'0I('Q\("%I<U]A<G)A>2@D<V5R=F5R06YC:&]R
M3F5X="DI('L*("`@("`@("`@("`@)'1H:7,M/FQO9TUE<W-A9V4H)U-Y;F--
M3"!I;G1E<FYA;"!E<G)O<CH@;F\@86YC:&]R('!R;W9I9&5D("<*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@+B`G:6X@=W)I=&53>6YC4W5M;6%R
M>2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?
M7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@9&EE*"=3>6YC
M34P@:6YT97)N86P@97)R;W(Z(&YO(&%N8VAO<B!P<F]V:61E9"!I;B!W<FET
M95-Y;F-3=6UM87)Y)RD["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("AA
M<G)A>5]K97ES*"1S97)V97)!;F-H;W).97AT*2!A<R`D='EP92D@>PH@("`@
M("`@("`@("`D<R`]("1S>6YC261E;G1I9FEE<B`N("<Z<W5M;6%R>3HG("X@
M)'1Y<&4["@H@("`@("`@("`@("`O+R!3970@)&QO8VED+@H@("`@("`@("`@
M("`D:6YF;R`]("9N97<@1&%T851R965/8FIE8W0H)',I.PH@("`@("`@("`@
M("`D:6YF;RT^<V5T*"=#;&EE;G1!;F-H;W(G+"`D8VQI96YT06YC:&]R3F5X
M="D["B`@("`@("`@("`@("1I;F9O+3YS970H)U-E<G9E<D%N8VAO<B<L("1S
M97)V97)!;F-H;W).97AT*3L*("`@("`@("`@("`@)'(@/2`D=&AI<RT^7V1A
M=&%T<F5E+3YA9&0H)&EN9F\I.PH@("`@("`@("`@("!I9B`H:7-?82@D<BP@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@+R\@3V)J96-T(&%L
M<F5A9'D@97AI<W1S.B!U<&1A=&4@:6YS=&5A9"X*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?9&%T871R964M/G5P9&%T941A=&$H)&EN9F\I.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?8V%C:&5;)&EN9F\M/F=E=$YA
M;64H*5T@/2`D:6YF;SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#<F5A=&4@82!M87`@96YT<FEE<R!T;R!M87`@8F5T=V5E;B!S97)V97(@
M86YD(&-L:65N="!)1',N"B`@("`@*@H@("`@("H@4'5T<R!A(&=I=F5N(&-L
M:65N="`D8W5I9"!A;F0@2&]R9&4@<V5R=F5R("1S=6ED('!A:7(@:6YT;R!T
M:&4*("`@("`J(&UA<"!T86)L92!T;R!A;&QO=R!M87!P:6YG(&)E='=E96X@
M=&AE(&-L:65N="=S(&%N9"!S97)V97(G<PH@("`@("H@241S+B`@06-T=6%L
M;'D@=&AE<F4@87)E('1W;R!M87!S.B!F<F]M('1H92!S=6ED('1O('1H92!C
M=6ED"B`@("`@*B!A;F0@=FEC92!V97)S82X*("`@("`J($EF(&%N(&5N=')Y
M(&%L<F5A9'D@97AI<W1S+"!I="!I<R!O=F5R=W)I='1E;BX*("`@("`J+PH@
M("`@9G5N8W1I;VX@8W)E871E56ED36%P*"1S>6YC261E;G1I9FEE<BP@)'1Y
M<&4L("1C=6ED+"`D<W5I9"P@)'1S/3`I"B`@("!["B`@("`@("`@+R\@4V5T
M("1C=6ED+@H@("`@("`@("1G:60@/2`F;F5W($1A=&%4<F5E3V)J96-T*"1S
M>6YC261E;G1I9FEE<B`N("<Z)R`N("1T>7!E"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+B`G.G-U:60R8W5I9#HG("X@)'-U:60I.PH@
M("`@("`@("1G:60M/G-E="@G9&%T87-T;W)E)RP@)'1Y<&4I.PH@("`@("`@
M("1G:60M/G-E="@G8W5I9"<L("1C=6ED*3L*("`@("`@("`D9VED+3YS970H
M)W1S)RP@)'1S*3L*"B`@("`@("`@)'(@/2`D=&AI<RT^7V1A=&%T<F5E+3YA
M9&0H)&=I9"D["B`@("`@("`@:68@*&ES7V$H)'(L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@+R\@3V)J96-T(&%L<F5A9'D@97AI<W1S.B!U<&1A
M=&4@:6YS=&5A9"X*("`@("`@("`@("`@)'(@/2`D=&AI<RT^7V1A=&%T<F5E
M+3YU<&1A=&5$871A*"1G:60I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^
M7V-A8VAE6R1G:60M/F=E=$YA;64H*5T@/2`D9VED.PH@("`@("`@("1T:&ES
M+3YD:65/;D5R<F]R*"1R+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@("`@
M("`O+R!3970@)&=L;V)A;'5I9`H@("`@("`@("1L:60@/2`F;F5W($1A=&%4
M<F5E3V)J96-T*"1S>6YC261E;G1I9FEE<B`N("<Z)R`N("1T>7!E"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G.F-U:60R<W5I9#HG
M("X@)&-U:60I.PH@("`@("`@("1L:60M/G-E="@G<W5I9"<L("1S=6ED*3L*
M("`@("`@("`D<B`]("1T:&ES+3Y?9&%T871R964M/F%D9"@D;&ED*3L*("`@
M("`@("!I9B`H:7-?82@D<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`O+R!/8FIE8W0@86QR96%D>2!E>&ES=',Z('5P9&%T92!I;G-T96%D+@H@
M("`@("`@("`@("`D<B`]("1T:&ES+3Y?9&%T871R964M/G5P9&%T941A=&$H
M)&QI9"D["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?8V%C:&5;)&QI9"T^
M9V5T3F%M92@I72`]("1L:60["B`@("`@("`@)'1H:7,M/F1I94]N17)R;W(H
M)'(L(%]?1DE,15]?+"!?7TQ)3D5?7RD["@H@("`@("`@("\O($EF('1A<VMS
M(&%N9"!E=F5N=',@87)E(&AA;F1L960@870@;VYC92P@=V4@;F5E9"!T;R!S
M=&]R90H@("`@("`@("\O('1H92!M87`@96YT<GD@:6X@8F]T:"!D871A8F%S
M97,Z"B`@("`@("`@)'-E<W-I;VX@/28@)%]315-324].6R=3>6YC34PN<W1A
M=&4G73L*("`@("`@("`D9&5V:6-E(#TF("1S97-S:6]N+3YG971$979I8V4H
M*3L*"B`@("`@("`@:68@*"1D979I8V4M/FAA;F1L951A<VMS26Y#86QE;F1A
M<B@I"B`@("`@("`@("`@("8F("@D='EP92`]/2`G=&%S:W,G('Q\("1T>7!E
M(#T]("=C86QE;F1A<B<I("D@>PH@("`@("`@("`@("`D='EP92`]("1T>7!E
M(#T]("=T87-K<R<@/R`G8V%L96YD87(G(#H@)W1A<VMS)R`[("\O('1H92!O
M=&AE<B!O;F4*"B`@("`@("`@("`@("\O(%-E="`D8W5I9"X*("`@("`@("`@
M("`@)&=I9"`]("9N97<@1&%T851R965/8FIE8W0H)'-Y;F-)9&5N=&EF:65R
M("X@)SHG("X@)'1Y<&4*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+B`G.G-U:60R8W5I9#HG("X@)'-U:60I.PH@("`@("`@("`@
M("`D9VED+3YS970H)V1A=&%S=&]R92<L("1T>7!E*3L*("`@("`@("`@("`@
M)&=I9"T^<V5T*"=C=6ED)RP@)&-U:60I.PH@("`@("`@("`@("`D9VED+3YS
M970H)W1S)RP@)'1S*3L*"B`@("`@("`@("`@("1R(#T@)'1H:7,M/E]D871A
M=')E92T^861D*"1G:60I.PH@("`@("`@("`@("!I9B`H:7-?82@D<BP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@+R\@3V)J96-T(&%L<F5A
M9'D@97AI<W1S.B!U<&1A=&4@:6YS=&5A9"X*("`@("`@("`@("`@("`@("1R
M(#T@)'1H:7,M/E]D871A=')E92T^=7!D871E1&%T82@D9VED*3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7V-A8VAE6R1G:60M/F=E=$YA
M;64H*5T@/2`D9VED.PH@("`@("`@("`@("`D=&AI<RT^9&EE3VY%<G)O<B@D
M<BP@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@("`@("`@("\O(%-E="`D
M9VQO8F%L=6ED"B`@("`@("`@("`@("1L:60@/2`F;F5W($1A=&%4<F5E3V)J
M96-T*"1S>6YC261E;G1I9FEE<B`N("<Z)R`N("1T>7!E"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)SIC=6ED,G-U:60Z)R`N
M("1C=6ED*3L*("`@("`@("`@("`@)&QI9"T^<V5T*"=S=6ED)RP@)'-U:60I
M.PH@("`@("`@("`@("`D<B`]("1T:&ES+3Y?9&%T871R964M/F%D9"@D;&ED
M*3L*("`@("`@("`@("`@:68@*&ES7V$H)'(L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@("`@("\O($]B:F5C="!A;')E861Y(&5X:7-T<SH@=7!D
M871E(&EN<W1E860N"B`@("`@("`@("`@("`@("`D<B`]("1T:&ES+3Y?9&%T
M871R964M/G5P9&%T941A=&$H)&QI9"D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)'1H:7,M/E]C86-H95LD;&ED+3YG971.86UE*"E=(#T@)&QI9#L*
M("`@("`@("`@("`@)'1H:7,M/F1I94]N17)R;W(H)'(L(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@=&EM97-T86UP("AI9B!S970I(&]F('1H92!L87-T(&-H86YG
M92!T;R!T:&4*("`@("`J(&]B:CIG=6ED+"!T:&%T('=A<R!C875S960@8GD@
M=&AE(&-L:65N="X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!4:&ES(&ES('-T;W)E9"!T;PH@("`@("H@879O:60@;6ER
M<F]R:6YG('1H97-E(&-H86YG97,@8F%C:R!T;R!T:&4@8VQI96YT+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971#:&%N9V544R@D<WEN8TED96YT:69I97(L
M("1D871A8F%S92P@)'-U:60I"B`@("!["B`@("`@("`@)&=I9"`])B`D=&AI
M<RT^7V=E=$]B*"1S>6YC261E;G1I9FEE<B`N("<Z)R`N("1D871A8F%S92`N
M("<Z<W5I9#)C=6ED.B<@+B`D<W5I9"D["B`@("`@("`@:68@*&ES7V$H)&=I
M9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&=I9"T^9V5T*"=T<R<I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S('1H92!(;W)D92!S97)V
M97(@9W5I9"`H;&EK90H@("`@("H@:W)O;F]L:71H.C!D,6(T,35F8S$R-&0S
M-#(W-S(R93DU9C!E.3(V8C<U*2!F;W(@82!G:79E;B!C;&EE;G0*("`@("`J
M(&-U:60N(%)E='5R;G,@9F%L<V4@:68@;F\@<W5C:"!I9"!I<R!S=&]R960@
M>65T+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($]P<&]S:71E(&]F(&=E=$QO8TED('=H:6-H(')E='5R;G,@=&AE(&QO
M8VED(&9O<B!A(&=I=F5N(&=U:60N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%-U:60H)'-Y;F-)9&5N=&EF:65R+"`D='EP92P@)&-U:60I"B`@("!["B`@
M("`@("`@)&QI9"`])B`D=&AI<RT^7V=E=$]B*"1S>6YC261E;G1I9FEE<B`N
M("<Z)R`N("1T>7!E("X@)SIC=6ED,G-U:60Z)R`N("1C=6ED*3L*("`@("`@
M("!I9B`H:7-?82@D;&ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;&ED
M+3YG970H)W-U:60G*3L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E<G1S
M(&$@<W5I9"!S97)V97(@:60@*&DN92X@2&]R9&4@1U5)1"D@=&\@82!C=6ED
M(&-L:65N="!)1`H@("`@("H@87,@=7-E9"!B>2!T:&4@<WEN8R!C;&EE;G0@
M*&QI:V4@,3(I(')E='5R;G,@9F%L<V4@:68@;F\@<W5C:`H@("`@("H@:60@
M:7,@<W1O<F5D('EE="X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0W5I9"@D<WEN8TED96YT:69I97(L
M("1D871A8F%S92P@)'-U:60I"B`@("!["B`@("`@("`@)&=I9"`])B`D=&AI
M<RT^7V=E=$]B*"1S>6YC261E;G1I9FEE<B`N("<Z)R`N("1D871A8F%S92`@
M+B`G.G-U:60R8W5I9#HG("X@)'-U:60I.PH@("`@("`@(&EF("AI<U]A*"1G
M:60L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1G:60M/F=E="@G8W5I9"<I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@3&]G<R!A(&UE<W-A9V4@:6X@=&AE
M(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1M97-S86=E
M("`@("!%:71H97(@82!S=')I;F<@;W(@82!014%27T5R<F]R(&]B:F5C="X*
M("`@("`J($!P87)A;2!S=')I;F<@)&9I;&4@("`@("`@5VAA="!F:6QE('=A
M<R!T:&4@;&]G(&9U;F-T:6]N(&-A;&QE9"!F<F]M"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("AE+F<N(%]?1DE,15]?*3\*("`@("`J($!P
M87)A;2!I;G1E9V5R("1L:6YE("`@("`@5VAA="!L:6YE('=A<R!T:&4@;&]G
M(&9U;F-T:6]N(&-A;&QE9"!F<F]M"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("AE+F<N(%]?3$E.15]?*3\*("`@("`J($!P87)A;2!I;G1E
M9V5R("1P<FEO<FET>2`@5&AE('!R:6]R:71Y(&]F('1H92!M97-S86=E+B!/
M;F4@;V8Z"B`@("`@*B`\<')E/@H@("`@("H@4$5!4E],3T=?14U%4D<*("`@
M("`J(%!%05)?3$]'7T%,15)4"B`@("`@*B!014%27TQ/1U]#4DE4"B`@("`@
M*B!014%27TQ/1U]%4E(*("`@("`J(%!%05)?3$]'7U=!4DY)3D<*("`@("`J
M(%!%05)?3$]'7TY/5$E#10H@("`@("H@4$5!4E],3T=?24Y&3PH@("`@("H@
M4$5!4E],3T=?1$5"54<*("`@("`J(#PO<')E/@H@("`@("HO"B`@("!F=6YC
M=&EO;B!L;V=-97-S86=E*"1M97-S86=E+"`D9FEL92`](%]?1DE,15]?+"`D
M;&EN92`](%]?3$E.15]?+`H@("`@("`@("`@("`@("`@("`@("`@("`D<')I
M;W)I='D@/2!014%27TQ/1U])3D9/*0H@("`@>PH@("`@("`@(&EF("AI<U]S
M=')I;F<H)&UE<W-A9V4I*2!["B`@("`@("`@("`@("1M97-S86=E(#T@(E-Y
M;F--3#H@(B`N("1M97-S86=E.PH@("`@("`@('T*("`@("`@("!(;W)D93HZ
M;&]G365S<V%G92@D;65S<V%G92P@)&9I;&4L("1L:6YE+"`D<')I;W)I='DI
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&UA<$-L:65N=$-A=&5G;W)Y,E-E<G9E
M<B@D8VQI96YT0V%T96=O<GDL("1S=6UM87)Y("`]("=U;FMN;W=N)RD@>PH*
M("`@("`@("!I9B`H96UP='DH)&-L:65N=$-A=&5G;W)Y*2D@>PH@("`@("`@
M("`@("!R971U<FX@)R<["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?;&]A
M9$-A=&5G;W)I97--87`H*3L*"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^
M7V-A=&5G;W)I97--87!;)&-L:65N=$-A=&5G;W)Y72D@)B8*("`@("`@("`@
M("`@(6ES7V%R<F%Y*"1T:&ES+3Y?8V%T96=O<FEE<TUA<%LD8VQI96YT0V%T
M96=O<GE=*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]C871E9V]R
M:65S36%P6R1C;&EE;G1#871E9V]R>5T["B`@("`@("`@?0H*("`@("`@("`O
M*B!S=&]R92!T:&4@8VQI96YT0V%T96=O<GD@87,@;&%C:VEN9R!A(&UA<"X@
M*B\*("`@("`@("`D=&AI<RT^7V-A=&5G;W)I97--87!;)&-L:65N=$-A=&5G
M;W)Y72`](&%R<F%Y*"1S=6UM87)Y*3L*("`@("`@("`D=&AI<RT^7W-T;W)E
M0V%T96=O<FEE<TUA<"@I.PH@("`@("`@(')E='5R;B`D8VQI96YT0V%T96=O
M<GD["B`@("!]"@H@("`@9G5N8W1I;VX@;6%P4V5R=F5R0V%T96=O<GDR0VQI
M96YT*"1S97)V97)#871E9V]R>2P@)'-U;6UA<GD@/2`G=6YK;F]W;B<I('L*
M"B`@("`@("`@:68@*&5M<'1Y*"1S97)V97)#871E9V]R>2DI('L*("`@("`@
M("`@("`@<F5T=7)N("<G.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]L
M;V%D0V%T96=O<FEE<TUA<"@I.PH*("`@("`@("`D8R`](&%R<F%Y7W-E87)C
M:"@D<V5R=F5R0V%T96=O<GDL("1T:&ES+3Y?8V%T96=O<FEE<TUA<"D["B`@
M("`@("`@:68@*"%E;7!T>2@D8RD@)B8@(6ES7V%R<F%Y*"1C*2D@>PH@("`@
M("`@("`@("!R971U<FX@)&,["B`@("`@("`@?0H*("`@("`@("`O*B!3=&]R
M92!T:&4@<V5R=F5R0V%T96=O<GD@87,@;&%C:VEN9R!A(&UA<"X@*B\*("`@
M("`@("`D=&AI<RT^7VUI<W-I;F=397)V97)#871E9V]R:65S6R1S97)V97)#
M871E9V]R>5T@/2`D<W5M;6%R>3L*("`@("`@("`D=&AI<RT^7W-T;W)E0V%T
M96=O<FEE<TUA<"@I.PH*("`@("`@("!R971U<FX@)'-E<G9E<D-A=&5G;W)Y
M.PH@("`@?0H*("`@(&9U;F-T:6]N(%]L;V%D0V%T96=O<FEE<TUA<"@I"B`@
M("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3Y?8V%T96=O<FEE<TUA
M<"DI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@
M)&UA<"`])B`D=&AI<RT^7V=E=$]B*"1?4T534TE/3ELG4WEN8TU,+G-T871E
M)UTM/F=E=%-Y;F-)9&5N=&EF:65R*"D@+B`G.F-A=&5G;W)I97,G*3L*("`@
M("`@("!I9B`H:7-?82@D;6%P+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?8V%T96=O<FEE<TUA<"`](&%R<F%Y*"D["B`@("`@("`@
M("`@("1T:&ES+3Y?;6ES<VEN9U-E<G9E<D-A=&5G;W)I97,@/2!A<G)A>2@I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?8V%T96=O
M<FEE<TUA<"`]("1M87`M/F=E="@G;6%P)RD["B`@("`@("`@("`@("1T:&ES
M+3Y?;6ES<VEN9U-E<G9E<D-A=&5G;W)I97,@/2`D;6%P+3YG970H)VUI<W-I
M;F=397)V97)#871E9V]R:65S)RD["B`@("`@("`@?0H@("`@?0H*("`@(&9U
M;F-T:6]N(%]S=&]R94-A=&5G;W)I97--87`H*0H@("`@>PH@("`@("`@(&EF
M("@A:7-?87)R87DH)'1H:7,M/E]C871E9V]R:65S36%P*2D@>PH@("`@("`@
M("`@("!R971U<FX[("\O(&YO=&AI;F<@=&\@9&\*("`@("`@("!]"@H@("`@
M("`@("1M87`@/2`F;F5W($1A=&%4<F5E3V)J96-T*"1?4T534TE/3ELG4WEN
M8TU,+G-T871E)UTM/F=E=%-Y;F-)9&5N=&EF:65R*"D*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`N("<Z8V%T96=O<FEE<R<I.PH@("`@
M("`@("1M87`M/G-E="@G;6%P)RP@)'1H:7,M/E]C871E9V]R:65S36%P*3L*
M("`@("`@("`D;6%P+3YS970H)VUI<W-I;F=397)V97)#871E9V]R:65S)RP@
M)'1H:7,M/E]M:7-S:6YG4V5R=F5R0V%T96=O<FEE<RD["@H@("`@("`@("1R
M(#T@)'1H:7,M/E]D871A=')E92T^861D*"1M87`I.PH@("`@("`@(&EF("AI
M<U]A*"1R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("\O($]B:F5C
M="!A;')E861Y(&5X:7-T<SH@=7!D871E(&EN<W1E860N"B`@("`@("`@("`@
M("1R(#T@)'1H:7,M/E]D871A=')E92T^=7!D871E1&%T82@D;6%P*3L*("`@
M("`@("!]"B`@("`@("`@)'1H:7,M/E]C86-H95LD;6%P+3YG971.86UE*"E=
M(#T@)&UA<#L*("`@("`@("`D=&AI<RT^9&EE3VY%<G)O<B@D<BP@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@:7,@
M82!S;6%L;"!H96QP97(@9G5N8W1I;VX@=&AA="!C86X@8F4@:6YC;'5D960@
M=&\@8VAE8VL*("`@("`J('=H971H97(@82!G:79E;B`D;V)J(&ES(&$@4$5!
M4E]%<G)O<B!O<B!N;W0N($EF('-O+"!I="!L;V=S"B`@("`@*B!T;R!D96)U
M9RP@=F%R7V1U;7!S('1H92`D;V)J(&%N9"!E>&ET<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@9&EE3VY%<G)O<B@D;V)J+"`D9FEL92`](%]?1DE,15]?+"`D
M;&EN92`](%]?3$E.15]?*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D;V)J
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@
M("!]"@H@("`@("`@("1T:&ES+3YL;V=-97-S86=E*"=3>6YC34PZ(%!%05(@
M17)R;W(Z("<@+B`D;V)J+3YG971-97-S86=E*"DL("1F:6QE+"`D;&EN92P@
M4$5!4E],3T=?15)2*3L*("`@("`@("!P<FEN="`B4$5!4B!%4E)/4EQN7&XB
M.PH@("`@("`@('9A<E]D=6UP*"1O8FHI.PH@("`@?0H*("`@(&9U;F-T:6]N
M("9?9V5T3V(H)&YA;64I"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D=&AI
M<RT^7V-A8VAE6R1N86UE72DI('L*("`@("`@("`@("`@)'1H:7,M/E]C86-H
M95LD;F%M95T@/28@)'1H:7,M/E]D871A=')E92T^9V5T3V)J96-T*"1N86UE
M*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8V%C:&5;)&YA
M;65=.PH@("`@?0H*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]3>6YC34PO1&5V:6-E+G!H
M<```````````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`S,S(P
M-R`Q,#4Q-30S,S<S-"`P,C$S-S``(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*"@HO*BH*("H@5&AE(%-Y;F--3%]$
M979I8V4Z.B!C;&%S<R!P<F]V:61E<R!F=6YC=&EO;F%L:71Y('1H870@:7,*
M("H@<&]T96YT:6%L;'D@*&-L:65N="D@9&5V:6-E(&1E<&5N9&%N="X*("H*
M("H@4V\@:68@82!S>6YC(&-L:65N="!N965D<R!A;GD@:VEN9"!O9B!S<&5C
M:6%L(&1A=&$@;V8@=&AE(&1A=&$@<V5N=`H@*B!T;R!I="!O<B!R96-E:79E
M9"!F<F]M(&ET+"!T:&ES(&ES(&1O;F4@:&5R92X@5&AE<F4@87)E('1W;R!S
M;W5R8V4*("H@;V8@:6YF;W)M871I;VX@=&\@:61E;G1I9GD@86X@9&5V:6-E
M.B!4:&4@9FER<W0@*&%N9"!B971T97(I(&]N92!I<PH@*B!T:&4@1&5V26YF
M(&1E=FEC92!I;F9O('-E;G0@8GD@=&AE(&1E=FEC92!U<&]N(&$@9V5T(')E
M<75E<W0N($EF"B`J($1E=DEN9B!I<R!N;W0@<W5P<&]R=&5D(&]R('-E;G0@
M8GD@=&AE(&-L:65N="P@=&AE(%-O=7)C955222!O9B!T:&4*("H@9&5V:6-E
M(&UA>2!B92!S=69F:6-E;G0@=&\@:61E;G1I9GD@:70N"B`J"B`J($EN9F]R
M;6%T:6]N(&%B;W5T(&$@9F5W(&1E=FEC97,@86QR96%D>2!W;W)K:6YG('=I
M=&@@4WEN8TU,.CH*("H*("H@4#@P,"]0.3`P+U`Y,3`Z"B`J("TM+2TM+2TM
M+2TM+2TM+0H@*B!#:&%R<V5T.@H@*B!4:&ES(&1E=FEC92!I<R!A8FQE('1O
M(&AA;F1L92!55$8M."!A;F0@<V5N9',@:71S(%A-3"!P86-K86=E<R!I;B!5
M5$8X+@H@*B!(;W=E=F5R(&5V96X@=&AO=6=H('1H92!834P@:71S96QF(&ES
M(%541BTX+"!I="!E>'!E8W1S('1H92!E;F-L;W-E9`H@*B!V8V%R9"UD871A
M('1O(&)E($E33RTX.#4Y+3$@=6YL97-S(&5X<&QI8VET;'D@<W1A=&5D(&]T
M:&5R=VES92`H=7-I;F<@=&AE"B`J($-(05)3150@;W!T:6]N+"!W:&EC:"!I
M<R!D97!R96-A=&5D(&9O<B!60T%21"`S+C`I"B`J"B`J($5N8V]D:6YG.@H@
M*B!3=')I;F<@=F%L=65S(&%R92!E;F-O9&5D(")154]4140M4%))3E1!0DQ%
M(@H@*@H@*B!/=&AE<CH*("H@5&AI<R!D979I8V5S(&AA;F1L97,@=&%S:W,@
M86YD(&5V96YT<R!I;B!O;F4@9&%T86)A<V4N"B`J"B`J($-O<'ER:6=H="`R
M,#`U+3(P,#8@2V%R<W1E;B!&;W5R;6]N="`\:V%R<W1E;D!H;W)D92YO<F<^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9"!N;W0*("H@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]3>6YC34PO
M4WEN8TU,+T1E=FEC92YP:'`L=B`Q+C<N,BXX(#(P,#8O,#4O,#,@,C$Z-#(Z
M-30@:F%N($5X<"`D"B`J"B`J($!A=71H;W(@($MA<G-T96X@1F]U<FUO;G0@
M/&MA<G-T96Y`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!3>6YC34P*("HO"F-L
M87-S(%-Y;F--3%]$979I8V4@>PH*("`@(&9U;F-T:6]N("9F86-T;W)Y*"D*
M("`@('L*("`@("`@("`D<VD@/2!3>6YC34Q?1&5V:6-E.CIS;W5R8V554DDH
M*3L*("`@("`@("`D9&D@/2!3>6YC34Q?1&5V:6-E.CID979I8V5);F9O*"D[
M"@H@("`@("`@(&EF("AS=')I<W1R*"1S:2P@)W-Y;F,T:B<I("$]/2!F86QS
M92!\?"!S=')I<W1R*"1S:2P@)W-C+7!I;2<I("$]/2!F86QS92D@>PH@("`@
M("`@("`@("!I;F-L=61E7V]N8V4@)U-Y;F--3"]$979I8V4O4WEN8S1J+G!H
M<"<["B`@("`@("`@("`@("1D979I8V4@/2`F;F5W(%-Y;F--3%]$979I8V5?
M<WEN8S1J*"D["B`@("`@("`@?2!E;'-E:68@*"%E;7!T>2@D9&DM/E]-86XI
M("8F('-T<FES='(H)&1I+3Y?36%N+"`G4V]N>2!%<FEC<W-O;B<I("$]/2!F
M86QS92D@>PH@("`@("`@("`@("!I;F-L=61E7V]N8V4@)U-Y;F--3"]$979I
M8V4O4#@P,"YP:'`G.PH@("`@("`@("`@("`D9&5V:6-E(#T@)FYE=R!3>6YC
M34Q?1&5V:6-E7U`X,#`H*3L*("`@("`@("!](&5L<V5I9B`H(65M<'1Y*"1D
M:2T^7TUA;BD@)B8@<W1R:7-T<B@D9&DM/E]-86XL("=S>6YT:&5S:7,G*2`A
M/3T@9F%L<V4I('L*("`@("`@("`@("`@:6YC;'5D95]O;F-E("=3>6YC34PO
M1&5V:6-E+U-Y;G1H97-I<RYP:'`G.PH@("`@("`@("`@("`D9&5V:6-E(#T@
M)FYE=R!3>6YC34Q?1&5V:6-E7U-Y;G1H97-I<R@I.PH@("`@("`@('T@96QS
M96EF("@A96UP='DH)&1I+3Y?36%N*2`F)B!S=')I<W1R*"1D:2T^7TUA;BP@
M)VYO:VEA)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@(&EN8VQU9&5?;VYC
M92`G4WEN8TU,+T1E=FEC92].;VMI82YP:'`G.PH@("`@("`@("`@("`D9&5V
M:6-E(#T@)FYE=R!3>6YC34Q?1&5V:6-E7TYO:VEA*"D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)&1E=FEC92`]("9N97<@4WEN8TU,7T1E=FEC
M92@I.PH@("`@("`@('T*"B`@("`@("`@)$=,3T)!3%-;)V)A8VME;F0G72T^
M;&]G365S<V%G92@G57-I;F<@9&5V:6-E(&-L87-S("<@+B!G971?8VQA<W,H
M)&1E=FEC92DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@
M("`@("`@<F5T=7)N("1D979I8V4["B`@("!]"@H@("`@9G5N8W1I;VX@)G-I
M;F=L971O;B@I"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T86YC93L*"B`@
M("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V4I*2!["B`@("`@("`@("`@("1I
M;G-T86YC92`](%-Y;F--3%]$979I8V4Z.F9A8W1O<GDH*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D:6YS=&%N8V4["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!3;W5R8V554DD@9G)O;2!S=&%T92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V]U<F-E55))*"D*("`@('L*("`@("`@("!R971U
M<FX@)%]315-324].6R=3>6YC34PN<W1A=&4G72T^9V5T4V]U<F-E55))*"D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!$979);F8@8VQA
M<W,@9G)O;2!S=&%T92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5V:6-E26YF
M;R@I"B`@("!["B`@("`@("`@<F5T=7)N("1?4T534TE/3ELG4WEN8TU,+G-T
M871E)UTM/F=E=$1E=FEC94EN9F\H*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%=H96X@82!C;&EE;G0@<V5N9',@9&%T82!D=7)I;F<@82!S>6YC(&)U="!D
M;V5S(&YO="!P<F]V:61E"B`@("`@*B!I;F9O<FUA=&EO;B!A8F]U="!T:&4@
M8V]N=&5N='1Y<&4@=VET:"!T:&ES(&EN9&EV:61U86P@:71E;2P*("`@("`J
M('1H:7,@9G5N8W1I;VX@<F5T=7)N<R!T:&4@8V]N=&5N='1Y<&4@=&AE(&ET
M96T@:7,@<W5P<&]S960@=&\@8F4@:6XN"B`@("`@*@H@("`@("H@07,@=&AI
M<R!I<R!O;FQY('5S960@=&\@<&%R<V4@=&\@=&AE(&AO<F1E)W,@:6UP;W)T
M9&%T82!A<&D@9G5N8W1I;VYS+`H@("`@("H@<V]M92!S:6UP;&4@9W5E<W-E
M<R!F;W(@=&AE(&-O;G1E;G1T>7!E(&%R92!C;VUP;&5T96QY('-U9F9I8VEE
M;G0Z"B`@("`@*B!(;W)D92!D;V5S(&YO="!C87)E('=H971H97(@9&%T82!I
M<R!T97AT+W@M=F-A;&5N9&%R(&]R('1E>'0O8V%L96YD87(N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=%!R969E<G)E9$-O;G1E;G14>7!E*"1T>7!E*0H@
M("`@>PH@("`@("`@(&EF("@D='EP92`]/2`G8V]N=&%C=',G*2!["B`@("`@
M("`@("`@(')E='5R;B`G=&5X="]X+79C87)D)SL*("`@("`@("!](&5L<V5I
M9B`H)'1Y<&4@/3T@)VYO=&5S)RD@>PH@("`@("`@("`@("!R971U<FX@)W1E
M>'0O>"UV;F]T92<["B`@("`@("`@?2!E;'-E:68@*"1T>7!E(#T]("=T87-K
M<R<I('L*("`@("`@("`@("`@<F5T=7)N("=T97AT+V-A;&5N9&%R)SL*("`@
M("`@("!](&5L<V5I9B`H)'1Y<&4@/3T@)V-A;&5N9&%R)RD@>PH@("`@("`@
M("`@("!R971U<FX@)W1E>'0O8V%L96YD87(G.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('!R969E<G)R960@8V]N=&5N
M='1Y<&4@;V8@=&AE(&-L:65N="!F;W(@=&AE(&=I=F5N"B`@("`@*B!S>6YC
M(&1A=&$@='EP92`H8V]N=&%C=',O=&%S:W,O;F]T97,O8V%L96YD87(I+@H@
M("`@("H*("`@("`J(%1H92!R97-U;'0@:7,@<&%S<V5D(&%S(&%N(&]P=&EO
M;B!T;R!T:&4@2&]R9&4@05!)(&5X<&]R="!F=6YC=&EO;G,N"B`@("`@*B!0
M;&5A<V4@;F]T92!T:&%T('1H:7,@:7,@;F]T('1H92!C;VYT96YT5'EP92!U
M;'1I;6%T96QY('!A<W-E9"!T;R!T:&4*("`@("`J(&-L:65N="!B=70@<F%T
M:&5R('1H92!C;VYT96YT5'EP92!P<F5S96YT960@=&\@=&AE($AO<F1E($%0
M22!E>'!O<G0*("`@("`J(&9U;F-T:6]N<RX@1F]R(&5X86UP;&4@=&AE(&-O
M;G1A8W0@87!I('-U<'!O<G1S(&$@8V]N=&5N='1Y<&4@"B`@("`@*B!T97AT
M+W@M=F-A<F0[=F5R<VEO;CTR+C$@=&\@8W)E871E(&$@=F-A<F0@:6X@=F-A
M<F0@,BXQ(&9O<FUA="X*("`@("`J"B`@("`@*B!!9G1E<B!T:&4@9&%T82!I
M<R!R971R:65V960@9G)O;2!H;W)D92P@8V]N=F5R=%-E<G9E<C)#;&EE;G0@
M8V%N(&1O"B`@("`@*B!S;VUE('!O<W0M<')O8V5S<VEN9R!A;F0@<V5T('1H
M92!C;W)R96-T(&-O;G1E;G14>7!E(&%C8V5P=&%B;&4@9F]R"B`@("`@*B!T
M:&4@8VQI96YT(&EF(&YE8V5S<V%R>2X*("`@("`J"B`@("`@*B!4:&4@9&5F
M875L="!I;7!L96UE;G1A=&EO;B!T<FEE<R!T;R!E>'1R86-T('1H92!C;VYT
M96YT='EP92!F<F]M('1H90H@("`@("H@<')E<V5N=&5D(&1E=FEC92!I;F9O
M+B!)9B!T:&ES(&1O97,@;F]T('=O<FLL('-O;64@9&5F875L="!A<F4@=7-E
M9"X*("`@("`J"B`@("`@*B!)9B!T:&4@8VQI96YT(&1O97,@;F]T('!R;W9I
M8V4@<')O<&5R($1E=DEN9B!D871A+"!T:&ES(&9U;F-T:6]N(&UA>0H@("`@
M("H@:&%V92!T;R!B92!O=F5R=W)I='1E;B!T;R!R971U<FX@=&AE(&-O<G)E
M8W0@=F%L=65S+@H@("`@("H*("`@("`J(%-E<G9E<E-Y;F-54DDZ(%1H92!S
M97)V97(@9&%T86)A<V4@;V8@=&AE('-Y;F,Z"B`@("`@*B`@("`@("`@("`@
M("`@("!C;VYT86-T<WQN;W1E<WQC86QE;F1A<GQT87-K<PH@("`@("H@<V]U
M<F-E4WEN8U5223H@5&AE(%5222!F;W(@=&AE(&-L:65N="!D871A8F%S92X@
M5&AI<R!I<R!N965D960@87,*("`@("`J("`@("`@("`@("`@("`@('1H92!$
M979);F8@:7,@87)R86YG960@8GD@<V]U<F-E4WEN8U5227,*("`@("`J+PH@
M("`@(`H@("`@9G5N8W1I;VX@9V5T4')E9F5R<F5D0V]N=&5N=%1Y<&5#;&EE
M;G0H)'-E<G9E<E-Y;F-54DDL("1S;W5R8V53>6YC55))*0H@("`@>PH@("`@
M("`@("1D:2`]("1T:&ES+3YD979I8V5);F9O*"D["B`@("`@("`@)&1S(#T@
M)&1I+3YG971$871A4W1O<F4H)'-O=7)C95-Y;F-54DDI.PH@("`@("`@(&EF
M("@A96UP='DH)&1S*2D@>PH@("`@("`@("`@("`D<B`]("1D<RT^9V5T4')E
M9F5R<F5D4EA#;VYT96YT5'EP92@I.PH@("`@("`@("`@("!I9B`H(65M<'1Y
M*"1D<RDI('L*("`@("`@("`@("`@("`@(&EF("@D<B`]/2`G=&5X="]X+79C
M87)D)R`F)@H@("`@("`@("`@("`@("`@("`@("`@("`D9',M/F=E=%!R969E
M<G)E9%)80V]N=&5N=%1Y<&5697)S:6]N*"D@/3T@)S(N,2<I('L*("`@("`@
M("`@("`@("`@("`@("`O*B!3<&5C:6%L(&-U<W1O;2!M:6UE='EP92!W:&EC
M:"!M86ME<R!T:&4@:&]R9&4@='5R8F$@05!)"B`@("`@("`@("`@("`@("`@
M("`@("H@<F5T=7)N(&$@=F5R<VEO;B`R+C$@<F%T:&5R('1H86X@,RXP('9C
M87)D+@H@("`@("`@("`@("`@("`@("`@("`J+PH@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`G=&5X="]X+79C87)D.W9E<G-I;VX],BXQ)SL*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@(')E='5R;B`D<CL*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@3F\@26YF;R!I;B!$979)
M;F8N(%5S92!D969A=6QT<SH@*B\*("`@("`@("!I9B`H)'-E<G9E<E-Y;F-5
M4DD@/3T@)V-O;G1A8W1S)RD@>PH@("`@("`@("`@("!R971U<FX@)W1E>'0O
M>"UV8V%R9"<["B`@("`@("`@?2!E;'-E:68@*"1S97)V97)3>6YC55))(#T]
M("=N;W1E<R<I('L*("`@("`@("`@("`@<F5T=7)N("=T97AT+W@M=FYO=&4G
M.PH@("`@("`@('T@96QS96EF("@D<V5R=F5R4WEN8U5222`]/2`G=&%S:W,G
M*2!["B`@("`@("`@("`@(')E='5R;B`G=&5X="]X+79T;V1O)SL*("`@("`@
M("!](&5L<V5I9B`H)'-E<G9E<E-Y;F-54DD@/3T@)V-A;&5N9&%R)RD@>PH@
M("`@("`@("`@("!R971U<FX@)W1E>'0O8V%L96YD87(G.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E<G0@=&AE(&-O;G1E;G0@<F5C
M96EV960@9G)O;2!T:&4@8VQI96YT(&9O<B!T:&4@:&]R9&4@8F%C:V5N9"X*
M("`@("`J"B`@("`@*B!#=7)R96YT;'D@<W1R:7!S('5I9"`H<')I;6%R>2!K
M97DI(&EN9F]R;6%T:6]N(&%S(&-L:65N="!A;F0*("`@("`J('-E<G9E<B!M
M:6=H="!U<V4@9&EF9F5R96YT(&]N97,N"B`@("`@*@H@("`@("H@0VAA<G-E
M="!C;VYV97)S:6]N<R!M:6=H="!B92!A9&1E9"!H97)E('1O;RX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VYT96YT("`@("`@(%1H92!C;VYT
M96YT('1O(&-O;G9E<G0*("`@("`J($!P87)A;2!S=')I;F<@)&-O;G1E;G14
M>7!E("`@5&AE(&-O;G1E;G14>7!E(&]F('1H92!C;VYT96YT"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>2`@("`@("`@("`@("`@("!A<G)A>2@D;F5W
M8V]N=&5N="P@)&YE=V-O;G1E;G14>7!E*3H*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@=&AE(&-O;G9E<G1E9"!C;VYT96YT(&%N9"!T
M:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*'!O<W-I
M8FQY(&-H86YG960I(&YE=R!#;VYT96YT5'EP92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@8V]N=F5R=$-L:65N=#)397)V97(H)&-O;G1E;G0L("1C;VYT96YT
M5'EP92D*("`@('L*("`@("`@("!G;&]B86P@)&)A8VME;F0["B`@("`@("`@
M:68@*$1%0E5'3$]'7TE#04Q%3D1!4D1!5$$I('L*("`@("`@("`@("`@)&9P
M(#T@0&9O<&5N*"<O=&UP+W-Y;F,O;&]G+G1X="<L("=A)RD["B`@("`@("`@
M("`@(&EF("@D9G`I('L*("`@("`@("`@("`@("`@($!F=W)I=&4H)&9P+"`B
M7&YI;G!U="!R96-E:79E9"!F<F]M(&-L:65N="`H)&-O;G1E;G14>7!E*5QN
M(BD["B`@("`@("`@("`@("`@("!I9B`H<W1R<W1R*"1C;VYT96YT5'EP92PG
M<VEF+R<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@("\O('-Y
M;F,T9FH@<VEF+RH@9&%T82!I<R!B87-E-C1?96YC;V1E9"X*("`@("`@("`@
M("`@("`@("`@("!`9G=R:71E*"1F<"P@8F%S938T7V1E8V]D92@D8V]N=&5N
M="D@+B`B7&XB*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@0&9W<FET92@D9G`L("1C;VYT96YT("X@(EQN(BD["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!`9F-L;W-E*"1F<"D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O($%L=V%Y<R!R
M96UO=F4@8VQI96YT(%5)1"X@54E$('=I;&P@8F4@<V5P97)A=&5L>2!P87-S
M960@:6X*("`@("`@("`O+R!834PN"B`@("`@("`@)&-O;G1E;G0@/2!P<F5G
M7W)E<&QA8V4H)R\H7')<;GQ<<GQ<;BE5240Z+BH_*%QR7&Y\7')\7&XI+R<L
M("=<,2<L("1C;VYT96YT+"`Q*3L*"B`@("`@("`@:68@*"1T:&ES+3YN965D
M<T-A=&5G;W)Y36%P<&EN9R@I("8F"B`@("`@("`@("`@('!R96=?;6%T8V@H
M)R\H7')<;GQ<<GQ<;BE#051%1T]224536UY<.ETJ.B@N*C\I*%QR7&Y\7')\
M7&XI+R<L"B`@("`@("`@("`@("`@("`@("`@("`@)&-O;G1E;G0L("1M*2D@
M>PH@("`@("`@("`@("`D8V%T<R`](&5X<&QO9&4H)RPG+"`D;5LR72D["B`@
M("`@("`@("`@(&EF*"!P<F5G7VUA=&-H*"<O*%QR7&Y\7')\7&XI4U5-34%2
M65M>7#I=*CHH+BH_*2A<<EQN?%QR?%QN*2\G+`H@("`@("`@("`@("`@("`@
M("`@("`@("1C;VYT96YT+"`D;2DI('L*("`@("`@("`@("`@("`@("1S=6UM
M87)Y(#T@)&U;,ET["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D<W5M;6%R>2`]("=U;FMN;W=N)SL*("`@("`@("`@("`@?0H*"B`@
M("`@("`@("`@(&9O<F5A8V@@*"1C871S(&%S("1C870I('L*("`@("`@("`@
M("`@("`@("1R97-U;'1S6UT@/2`D8F%C:V5N9"T^;6%P0VQI96YT0V%T96=O
M<GDR4V5R=F5R*"1C870L("1S=6UM87)Y*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D8V]N=&5N="`]('!R96=?<F5P;&%C92@G+RA<<EQN?%QR?%QN
M0T%414=/4DE%4UM>7#I=*CHI*"XJ/RDH7')<;GQ<<GQ<;BDO)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R0Q)R`N(&EM<&QO9&4H
M)RPG+"1R97-U;'1S*2`N("<D,R<L("1C;VYT96YT*3L*"B`@("`@("`@?0H@
M("`@("`@("\O($5N<W5R92!V86QI9"!N97=L:6YE('1E<FUI;F%T:6]N+@H@
M("`@("`@(&EF("AS=6)S='(H)&-O;G1E;G0L("TQ*2`A/2`B7&XB("8F('-U
M8G-T<B@D8V]N=&5N="P@+3$I("$](")<<B(I('L*("`@("`@("`@("`@)&-O
M;G1E;G0@+CT@(EQR7&XB.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&%R
M<F%Y*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@0V]N=F5R=',@=&AE(&-O;G1E;G0@9G)O;2!T:&4@8F%C:V5N9"!T
M;R!A(&9O<FUA="!S=6ET86)L92!F;W(@=&AE"B`@("`@*B!C;&EE;G0@9&5V
M:6-E+@H@("`@("H*("`@("`J(%-T<FEP<R!T:&4@=6ED("AP<FEM87)Y(&ME
M>2D@:6YF;W)M871I;VX@87,@8VQI96YT(&%N9"!S97)V97(@;6EG:'0@=7-E
M"B`@("`@*B!D:69F97)E;G0@;VYE<RX*("`@("`J"B`@("`@*B!#:&%R<V5T
M(&-O;G9E<G-I;VYS(&UI9VAT(&)E(&%D9&5D(&AE<F4@=&]O+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&-O;G1E;G0@("`@("`@5&AE(&-O;G1E
M;G0@=&\@8V]N=F5R=`H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]N=&5N=%1Y
M<&4@("!4:&4@8V]N=&5N=%1Y<&4@;V8@8V]N=&5N="!A<R!R971U<FYE9"!F
M<F]M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H92!B
M86-K96YD"B`@("`@*B!`<F5T=7)N(&%R<F%Y("`@("`@("`@("`@("`@(&%R
M<F%Y*"1N97=C;VYT96YT+"`D;F5W8V]N=&5N=%1Y<&4I.@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@8V]N=F5R=&5D(&-O;G1E
M;G0@86YD('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`H<&]S<VEB;'D@8VAA;F=E9"D@;F5W($-O;G1E;G14>7!E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!C;VYV97)T4V5R=F5R,D-L:65N="@D8V]N=&5N="P@
M)&-O;G1E;G14>7!E*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8F%C:V5N9#L*
M("`@("`@("!I9B`H:7-?87)R87DH)&-O;G1E;G14>7!E*2D@>PH@("`@("`@
M("`@("`D8V]N=&5N=%1Y<&4@/2`D8V]N=&5N=%1Y<&5;)T-O;G1E;G14>7!E
M)UT["B`@("`@("`@?0H*("`@("`@("!I9B`H1$5"54=,3T=?24-!3$5.1$%2
M1$%402D@>PH@("`@("`@("`@("`D9G`@/2!`9F]P96XH)R]T;7`O<WEN8R]L
M;V<N='AT)RP@)V$G*3L*("`@("`@("`@("`@:68@*"1F<"D@>PH@("`@("`@
M("`@("`@("`@0&9W<FET92@D9G`L(")<;F]U='!U="!R96-E:79E9"!F<F]M
M(&AO<F1E(&)A8VME;F0@(B`N"B`@("`@("`@("`@("`@("`@("`@("`@("(H
M)&-O;G1E;G14>7!E*3I<;B(I.PH@("`@("`@("`@("`@("`@0&9W<FET92@D
M9G`L)&-O;G1E;G0@+B`B7&XB*3L*("`@("`@("`@("`@("`@($!F8VQO<V4H
M)&9P*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@4F5M
M;W9E('-P96-I86P@=F5R<VEO;CTR+C$@:6YD:6-A=&]R('5S960@9F]R(&AO
M<F1E(&%P:2X@*B\*("`@("`@("!I9B`H)&-O;G1E;G14>7!E(#T]("=T97AT
M+W@M=F-A<F0[=F5R<VEO;CTR+C$G*2!["B`@("`@("`@("`@("1C;VYT96YT
M5'EP92`]("=T97AT+W@M=F-A<F0G.PH@("`@("`@('T*"B`@("`@("`@+RH@
M06QW87ES(')E;6]V92!S97)V97(@54E$+B!5240@=VEL;"!B92!S97!E<F%T
M96QY('!A<W-E9"!I;B!834PN("HO"B`@("`@("`@)&-O;G1E;G0@/2!P<F5G
M7W)E<&QA8V4H)R\H7')<;GQ<<GQ<;BE5240Z+BH_*%QR7&Y\7')\7&XI+R<L
M("=<,2<L("1C;VYT96YT+"`Q*3L*"B`@("`@("`@)&1I(#T@)'1H:7,M/F1E
M=FEC94EN9F\H*3L*"B`@("`@("`@:68@*"1T:&ES+3YN965D<T-A=&5G;W)Y
M36%P<&EN9R@I("8F"B`@("`@("`@("`@('!R96=?;6%T8V@H)R\H7')<;GQ<
M<GQ<;BE#051%1T]224536UY<.ETJ.B@N*C\I*%QR7&Y\7')\7&XI+R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@)&-O;G1E;G0L("1M*2D@>PH@("`@("`@
M("`@("`D8V%T<R`](&5X<&QO9&4H)RPG+"`D;5LR72D["@H@("`@("`@("`@
M("!I9B@@<')E9U]M871C:"@G+RA<<EQN?%QR?%QN*5-534U!4EE;7EPZ72HZ
M*"XJ/RDH7')<;GQ<<GQ<;BDO)RP*("`@("`@("`@("`@("`@("`@("`@("`D
M8V]N=&5N="P@)&TI*2!["B`@("`@("`@("`@("`@("`D<W5M;6%R>2`]("1M
M6S)=.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'-U
M;6UA<GD@/2`G=6YK;F]W;B<["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M(&9O<F5A8V@@*"1C871S(&%S("1C870I('L*("`@("`@("`@("`@("`@("1R
M97-U;'1S6UT@/2`D8F%C:V5N9"T^;6%P4V5R=F5R0V%T96=O<GDR0VQI96YT
M*"1C870L("1S=6UM87)Y*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!P
M<F5G7W)E<&QA8V4H)R\H7')<;GQ<<GQ<;D-!5$5'3U))15-;7EPZ72HZ*2@N
M*C\I*%QR7&Y\7')\7&XI+R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`G
M)#$G("X@:6UP;&]D92@G+"<L)')E<W5L=',I("X@)R0R)RP@)&-O;G1E;G0I
M.PH@("`@("`@('T*"B`@("`@("`@<W=I=&-H("@D8V]N=&5N=%1Y<&4I('L*
M("`@("`@("!C87-E("=T97AT+V-A;&5N9&%R)R`Z"B`@("`@("`@8V%S92`G
M=&5X="]X+6EC86QE;F1A<B<@.@H@("`@("`@(&-A<V4@)W1E>'0O>"UV8V%L
M96YD87(G(#H*("`@("`@("!C87-E("=T97AT+W@M=F5V96YT)R`Z"B`@("`@
M("`@8V%S92`G=&5X="]X+79T;V1O)R`Z"B`@("`@("`@8V%S92`G=&5X="]X
M+79N;W1E)SH*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)W1E
M>'0O>"UV8V%R9"<@.@H@("`@("`@("`@("`O+R!)9B!W92!C86X@97AT<F%C
M="!F<F]M('1H92!$979I8V4@26YF;RP@=&AA="!T:&4@8VQI96YT"B`@("`@
M("`@("`@("\O('5S97,@5$5,.U=/4DLZ(#`X,#`@,3(S(&EN<W1E860@;V8@
M5$5,.U194$4]5T]22SH*("`@("`@("`@("`@+R\@,#@P,#$R,RP@8V]N=F5R
M="!T:&4@9&%T82!A8V-O<F1I;F=L>2X*("`@("`@("`@("`@:68@*"%E;7!T
M>2@D9&DM/E]#5$-A<%LG=&5X="]X+79C87)D)UU;)U1%3"==*2`F)@H@("`@
M("`@("`@("`@("`@96UP='DH)&1I+3Y?0U1#87!;)W1E>'0O>"UV8V%R9"==
M6R=414PG72T^7W!A<F%M<ULG5%E012==*2`F)@H@("`@("`@("`@("`@("`@
M(65M<'1Y*"1D:2T^7T-40V%P6R=T97AT+W@M=F-A<F0G75LG5$5,)UTM/E]P
M87)A;7-;)U9/24-%)UTI*2!["B`@("`@("`@("`@("`@("`D8V]N=&5N="`]
M('!R96=?<F5P;&%C92@G+RA<<EQN?%QR?%QN*51%3#M465!%/4A/344O)RP@
M)UPQ5$5,.TA/344[5D])0T4G+"`D8V]N=&5N="P@,2D["B`@("`@("`@("`@
M("`@("`D8V]N=&5N="`]('!R96=?<F5P;&%C92@G+RA<<EQN?%QR?%QN*51%
M3#M465!%/5=/4DLO)RP@)UPQ5$5,.U=/4DL[5D])0T4G+"`D8V]N=&5N="P@
M,2D["B`@("`@("`@("`@("`@("`D8V]N=&5N="`]('!R96=?<F5P;&%C92@G
M+RA<<EQN?%QR?%QN*51%3#M465!%/4-%3$PO)RP@)UPQ5$5,.U9/24-%.T-%
M3$PG+"`D8V]N=&5N="P@,2D["B`@("`@("`@("`@("`@("`D8V]N=&5N="`]
M('!R96=?<F5P;&%C92@G+RA<<EQN?%QR?%QN*51%3#M465!%/49!6"\G+"`G
M7#%414P[5T]22SM&05@G+"`D8V]N=&5N="P@,2D["B`@("`@("`@("`@("`@
M("`D8V]N=&5N="`]('!R96=?<F5P;&%C92@G+RA<<EQN?%QR?%QN*51%3#M4
M65!%/5!!1T52+R<L("=<,51%3#M004=%4CM73U)+)RP@)&-O;G1E;G0L(#$I
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!)9B!W92!C86X@97AT
M<F%C="!F<F]M('1H92!$979I8V4@26YF;RP@=&AA="!T:&4@8VQI96YT"B`@
M("`@("`@("`@("\O('5S97,@0412.U=/4DLZ("XN+B!I;G-T96%D(&]F($%$
M4CM465!%/5=/4DLZ(#`X,#`Q,C,L"B`@("`@("`@("`@("\O(&-O;G9E<G0@
M=&AE(&1A=&$@86-C;W)D:6YG;'DN"B`@("`@("`@("`@(&EF("@A96UP='DH
M)&1I+3Y?0U1#87!;)W1E>'0O>"UV8V%R9"==6R=!1%(G72D@)B8*("`@("`@
M("`@("`@("`@(&5M<'1Y*"1D:2T^7T-40V%P6R=T97AT+W@M=F-A<F0G75LG
M0412)UTM/E]P87)A;7-;)U194$4G72D@)B8*("`@("`@("`@("`@("`@("%E
M;7!T>2@D9&DM/E]#5$-A<%LG=&5X="]X+79C87)D)UU;)T%$4B==+3Y?<&%R
M86US6R=73U)+)UTI*2!["B`@("`@("`@("`@("`@("`D8V]N=&5N="`]('!R
M96=?<F5P;&%C92@G+RA<<EQN?%QR?%QN*4%$4CM465!%/5=/4DLO)RP@)UPQ
M0412.U=/4DLG+"`D8V]N=&5N="P@,2D["B`@("`@("`@("`@("`@("`D8V]N
M=&5N="`]('!R96=?<F5P;&%C92@G+RA<<EQN?%QR?%QN*4%$4CM465!%/4A/
M344O)RP@)UPQ0412.TA/344G+"`D8V]N=&5N="P@,2D["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N(&%R<F%Y*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V]M92!D979I8V5S(&QI:V4@=&AE(%-O;GD@17)I8W-S
M;VX@4#@P,"]0.3`P+U`Y,3`@:&%N9&QE"B`@("`@*B!V=&]D;W,@*'1A<VMS
M*2!A;F0@=F5V96YT<R!I;B!T:&4@<V%M92`B8V%L96YD87(B('-Y;F,N("!4
M:&ES"B`@("`@*B!R97%U:7)E<R!S<&5C:6%L(&%C=&EO;G,@;VX@;W5R('-I
M9&4@87,@=V4@<W1O<F4@=&AI<R!I;@H@("`@("H@9&EF9F5R96YT(&1A=&%B
M87-E<R`H;F%G(&%N9"!K<F]N;VQI=&@I+B`@5&AI<R!F=6YC=&EO;@H@("`@
M("H@9&5T97)M:6YE<R!W:&5T:&5R('1H92!C;&EE;G0@9&]E<R!I="!L:6ME
M('1H870N("!#=7)R96YT;'D*("`@("`J('1H:7,@:7,@9&]N92!B>2!C:&5C
M:VEN9R!T:&4@1&5V26YF(&EN9F]R;6%T:6]N+B!&;W(@9&EF9F5R96YT"B`@
M("`@*B!C;&EE;G1S('1H97)E(&UA>2!B92!D:69F97)E;G0@=V%Y<R!T;R!F
M:6YD(&]U="!H;W<@=&AE(&-L:65N=`H@("`@("H@;&EK97,@:71S('1A<VMS
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!H86YD;&5487-K<TEN0V%L96YD87(H
M*0H@("`@>PH@("`@("`@("\O($1E9F%U;'0Z('1A<VMS(&%N9"!E=F5N=',@
M87)E('-E<&5R871E(&1A=&%B87-E<RX*("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3;VUE(&1E=FEC97,@;F5E9"!A(&UA
M<'!I;F<@;V8@8VQI96YT('9S+B!S97)V97(@8V%T96=O<FEE(&YA;65S+@H@
M("`@("H@5&AE(&)A8VME;F0@<')O=FED97,@82!M96-H86YI<VT@9F]R('1H
M:7,@;6%P<&EN9RX@270@:7,@=7-E9`H@("`@("H@=VAE;B!T:&ES(&YE961S
M0V%T96=O<GE-87!P:6YG(')E='5R;G,@=')U92X*("`@("`J($9O<B!S<&5C
M:6%L(&-A<V5S('1H92!M87!P:6YG(&UA>2!A;'-O(&)E(&EM<&QE;65N=&5D
M(&1I<F5C=&QY(&EN"B`@("`@*B!C;VYV97)T0VQI96YT,E-E<G9E<B!A;F0@
M8V]N=F5R=%-E<G9E<C)#;&EE;G0N($EN('1H:7,@8V%S90H@("`@("H@;F5E
M9'-#871E9V]R>4UA<'!I;F<@;6%Y(')E='5R;B!F86QS92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@;F5E9'-#871E9V]R>4UA<'!I;F<H*0H@("`@>PH@("`@
M("`@(')E='5R;B!F86QS93L*("`@('T*"GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O4WEN8TU,+U-Y;F,N<&AP````
M````````````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-#`V-#,@
M,3`U,34T,S,W,S0@,#(Q,3`W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&9R86UE=V]R
M:R]3>6YC34PO4WEN8TU,+U-Y;F,N<&AP+'8@,2XX+C0N.2`R,#`V+S`U+S`Q
M(#$R.C`U.C$T(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V
M($%N=&AO;GD@36EL;',@/&%M:6QL<T!P>7)A;6ED-BYC;VT^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*@H@*B!`875T:&]R("!!;G1H;VYY($UI;&QS(#QA;6EL;'-`<'ER
M86UI9#8N8V]M/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@
M4WEN8TU,"B`J+PIC;&%S<R!3>6YC34Q?4WEN8R!["@H@("`@+RHJ"B`@("`@
M*B!487)G970Z(&-O;G1A8W1S+"!N;W1E<RP@8V%L96YD87(L('1A<VMS+`H@
M("`@("HO"B`@("!V87(@)%]T87)G971,;V-54DD[("\O('1A<F=E="!M96%N
M<R!S97)V97(@:&5R90H*("`@('9A<B`D7W-O=7)C94QO8U5223L@+R\@<V]U
M<F-E(&UE86YS(&-L:65N="!H97)E"@H@("`@=F%R("1?86QE<G0["@H@("`@
M+RHJ"B`@("`@*B!4<G5E(&EN9&EC871E<R!T:&%T('1H97)E(&%R92!S=&EL
M;"!S>6YC(&5L96UE;G1S('1H870@:&%V92!N;W0@8F5E;@H@("`@("H@<V5N
M="!Y970@9'5E('1O(&UE<W-A9V4@<VEZ92!L:6UI=&%T:6]N<R!A;F0@:&%V
M92!T;R!B92!S96YT(&EN('1H92!N97AT"B`@("`@*B!M97-S86=E+@H@("`@
M("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]P96YD
M:6YG16QE;65N=',["@H@("`@+RHJ"B`@("`@*B!296UE;6)E<B!E;G1R:65S
M('=E(&AA=F4@:&%N9&QE9"!A;')E861Y.B!O;F-E('=E('-E;F0@82!D96QE
M=&4@9F]R(&%N"B`@("`@*B!E;G1R>2P@=V4@9&]N)W0@=V%N="!T;R!S96YD
M(&%N(&%D9"!A9G1E<G=A<F1S+B!4:&ES(&%R<F%Y(&ES(&%L<V\@=7-E9`H@
M("`@("H@:68@82!S>6YC(&ES('-E;G0@:6X@;75L=&EP;&4@;65S<V%G97,@
M9'5E('1O(&UE<W-A9V4@<VEZ92!R97-T<FEC=&EO;G,N"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]D;VYE.PH*("`@(&9U
M;F-T:6]N(%-Y;F--3%]3>6YC*"1A;&5R="P@)'-E<G9E<E5222P@)&-L:65N
M=%5222D*("`@('L*("`@("`@("`D=&AI<RT^7V%L97)T(#T@)&%L97)T.PH@
M("`@("`@("1T:&ES+3Y?<&5N9&EN9T5L96UE;G1S(#T@9F%L<V4["B`@("`@
M("`@)'1H:7,M/E]D;VYE(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^7W1A
M<F=E=$QO8U5222`](&)A<V5N86UE*"1S97)V97)54DDI.PH@("`@("`@("1T
M:&ES+3Y?<V]U<F-E3&]C55))(#T@)&-L:65N=%5223L*("`@("`@("!G;&]B
M86P@)&)A8VME;F0["B`@("`@("`@)&)A8VME;F0M/FQO9TUE<W-A9V4H(F-R
M96%T92!F;W(@<WEN8U1Y<&4])'-E<G9E<E5222(L(%]?1DE,15]?+"!?7TQ)
M3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M2&5R92=S('=H97)E('1H92!A8W1U86P@<')O8V5S<VEN9R!O9B!A(&-L:65N
M="US96YT(%-Y;F,*("`@("`J($ET96T@=&%K97,@<&QA8V4N($5N=')I97,@
M87)E(&%D9&5D+"!D96QE=&5D(&]R(')E<&QA8V5D"B`@("`@*B!F<F]M('1H
M92!S97)V97(@9&%T86)A<V4@8GD@=7-I;F<@2&]R9&4@05!)("A296=I<W1R
M>2D@8V%L;',N"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA;F1L95-Y;F-)=&5M
M*"1I=&5M*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8F%C:V5N9#L*"B`@("`@
M("`@)'-T871E(#T@)B1?4T534TE/3ELG4WEN8TU,+G-T871E)UT["B`@("`@
M("`@)&1E=FEC92`]("8D<W1A=&4M/F=E=$1E=FEC92@I.PH@("`@("`@("1S
M>6YC261E;G1I9FEE<B`]("1S=&%T92T^9V5T4WEN8TED96YT:69I97(H*3L*
M"B`@("`@("`@)&AO<F1E5'EP92`]("1T>7!E(#T@)'1H:7,M/E]T87)G971,
M;V-54DD["@H@("`@("`@("\O(%5S92!C;VYT96YT5'EP92!E>'!L:6-I=&QY
M('-P96-I9FEE9"!I;B!T:&ES('-Y;F,@8V]M;6%N9"X*("`@("`@("`D8V]N
M=&5N=%1Y<&4@/2`D:71E;2T^9V5T0V]N=&5N=%1Y<&4H*3L*"B`@("`@("`@
M+R\@268@;F]T('!R;W9I9&5D+"!U<V4@9&5F875L="!F<F]M(&1E=FEC92!I
M;F9O+@H@("`@("`@(&EF("@A)&-O;G1E;G14>7!E*2!["B`@("`@("`@("`@
M("1C;VYT96YT5'EP92`]("1D979I8V4M/F=E=%!R969E<G)E9$-O;G1E;G14
M>7!E*"1T>7!E*3L*("`@("`@("!]"@H@("`@("`@(&QI<W0H)&-O;G1E;G0L
M("1C;VYT96YT5'EP92D@/0H@("`@("`@("`@("`D9&5V:6-E+3YC;VYV97)T
M0VQI96YT,E-E<G9E<B@D:71E;2T^9V5T0V]N=&5N="@I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]N=&5N=%1Y<&4I
M.PH@("`@("`@("1C=6ED(#T@)&ET96TM/F=E=$-U:60H*3L*("`@("`@("`D
M<W5I9"`](&9A;'-E.PH*("`@("`@("`O+R!(86YD;&4@8VQI96YT(&%D9"!R
M97%U97-T<RX*("`@("`@("!I9B`H)&ET96TM/F=E=$5L96UE;G14>7!E*"D@
M/3TG061D)RD@>PH@("`@("`@("`@("`D<W5I9"`]("1B86-K96YD+3YI;7!O
M<G1%;G1R>2@D<WEN8TED96YT:69I97(L("1H;W)D951Y<&4L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;VYT96YT+"`D
M8V]N=&5N=%1Y<&4L("1C=6ED*3L*("`@("`@("`@("`@:68@*"%I<U]A*"1S
M=6ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D<W1A=&4M
M/FQO9R@B0VQI96YT+4%D9"(I.PH@("`@("`@("`@("`@("`@)&)A8VME;F0M
M/FQO9TUE<W-A9V4H)V%D9&5D(&-L:65N="!E;G1R>2!A<R`G("X@)'-U:60L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?
M7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1S=&%T92T^;&]G*")#;&EE;G0M061D
M1F%I;'5R92(I.PH@("`@("`@("`@("`@("`@)&)A8VME;F0M/FQO9TUE<W-A
M9V4H)T5R<F]R(&EN(&%D9&EN9R!C;&EE;G0@96YT<GDZ)R`N("1S=6ED+3YM
M97-S86=E+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@
M("`@("`@("`@('T*"B`@("`@("`@+R\@2&%N9&QE(&-L:65N="!D96QE=&4@
M<F5Q=65S=',N"B`@("`@("`@?2!E;'-E:68@*"1I=&5M+3YG971%;&5M96YT
M5'EP92@I(#T])T1E;&5T92<I('L*("`@("`@("`@("`@)'-U:60@/2`D8F%C
M:V5N9"T^9&5L971E16YT<GDH)'-Y;F-)9&5N=&EF:65R+"`D='EP92P@)&-U
M:60I.PH@("`@("`@("`@("!I9B`H)'1Y<&4@/3T@)V-A;&5N9&%R)PH@("`@
M("`@("`@("`@("`@)B8@)&1E=FEC92T^:&%N9&QE5&%S:W-);D-A;&5N9&%R
M*"DI('L*("`@("`@("`@("`@("`@("\O(&1E;&5T945N=')Y(&1O97,@;F]T
M(&YE960@=&\@<F5T=7)N(&%N(&5R<F]R(&]N"B`@("`@("`@("`@("`@("`O
M+R!D96QE=&EO;B!O9B!N;VYE>&ES=&5N="!E;G1R:65S+B!3;R!J=7-T('1O
M(&)E('-U<F4*("`@("`@("`@("`@("`@("\O('=E(&AA=F4@=&\@9&5L971E
M(&9R;VT@=&AE('1A<VMS(&1A=&%B87-E(&%S('=E;&PZ"B`@("`@("`@("`@
M("`@("`D8F%C:V5N9"T^;&]G365S<V%G92@G<W!E8VEA;"!T87-K<R!D96QE
M=&4@)R`N("1S=6ED("X@)R!D=64@=&\@8VQI96YT(')E<75E<W0G+"!?7T9)
M3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@
M("`@("1S=6ED(#T@)&)A8VME;F0M/F1E;&5T945N=')Y*"1S>6YC261E;G1I
M9FEE<BP@)W1A<VMS)RP@)&-U:60I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&EF("@A:7-?82@D<W5I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@)'-T871E+3YL;V<H(D-L:65N="U$96QE=&4B*3L*("`@("`@
M("`@("`@("`@("1B86-K96YD+3YL;V=-97-S86=E*"=D96QE=&5D(&5N=')Y
M("<@+B`D<W5I9"`N("<@9'5E('1O(&-L:65N="!R97%U97-T)RP@7U]&24Q%
M7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D<W1A=&4M/FQO9R@B0VQI96YT+41E
M;&5T949A:6QU<F4B*3L*("`@("`@("`@("`@("`@("1T:&ES+3YL;V=-97-S
M86=E*"=&86EL=7)E(&1E;&5T:6YG(&-L:65N="!E;G1R>2P@;6%Y8F4@9V]N
M92!A;')E861Y(&]N('-E<G9E<BX@;7-G.B<N("1S=6ED+3YM97-S86=E+"!?
M7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@
M('T*"B`@("`@("`@+R\@2&%N9&QE(&-L:65N="!R97!L86-E(')E<75E<W1S
M+@H@("`@("`@('T@96QS96EF("@D:71E;2T^9V5T16QE;65N=%1Y<&4H*2`]
M/2`G4F5P;&%C92<I('L*("`@("`@("`@("`@)'-U:60@/2`D8F%C:V5N9"T^
M<F5P;&%C945N=')Y*"1S>6YC261E;G1I9FEE<BP@)&AO<F1E5'EP92P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;VYT
M96YT+"`D8V]N=&5N=%1Y<&4L("1C=6ED*3L*"B`@("`@("`@("`@(&EF("@A
M:7-?82@D<W5I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@
M)'-T871E+3YL;V<H(D-L:65N="U297!L86-E(BD["B`@("`@("`@("`@("`@
M("`D8F%C:V5N9"T^;&]G365S<V%G92@G<F5P;&%C960@96YT<GD@)R`N("1S
M=6ED("X@)R!D=64@=&\@8VQI96YT(')E<75E<W0G+"!?7T9)3$5?7RP@7U],
M24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1B86-K96YD+3YL;V=-97-S86=E*"1S=6ED+3YM
M97-S86=E+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*
M("`@("`@("`@("`@("`@("1B86-K96YD+3YL;V=-97-S86=E*"1S=6ED+"!?
M7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@
M("`@("`@("`O+R!%;G1R>2!M87D@:&%V92!B965N(&1E;&5T960[('1R>2!A
M9&1I;F<@:70N"B`@("`@("`@("`@("`@("`D<W5I9"`]("1B86-K96YD+3YI
M;7!O<G1%;G1R>2@D<WEN8TED96YT:69I97(L("1H;W)D951Y<&4L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]N
M=&5N="P@)&-O;G1E;G14>7!E+"`D8W5I9"D["B`@("`@("`@("`@("`@("!I
M9B`H(6ES7V$H)'-U:60L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@("`@("`D<W1A=&4M/FQO9R@B0VQI96YT+4%D9%)E<&QA8V4B*3L*("`@
M("`@("`@("`@("`@("`@("`D8F%C:V5N9"T^;&]G365S<V%G92@G861D960@
M8VQI96YT(&5N=')Y(&1U92!T;R!R97!L86-E(')E<75E<W0@87,@)R`N("1S
M=6ED+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'-T
M871E+3YL;V<H(D-L:65N="U!9&1&86EL=7)E(BD["B`@("`@("`@("`@("`@
M("`@("`@)&)A8VME;F0M/FQO9TUE<W-A9V4H)T5R<F]R(&EN(&%D9&EN9R!C
M;&EE;G0@96YT<GD@9'5E('1O(')E<&QA8V4@<F5Q=65S=#HG("X@)'-U:60M
M/FUE<W-A9V4L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1B86-K96YD+3YL;V=-97-S86=E*"=5;F5X<&5C
M=&5D(&5L96UE;G14>7!E.B`G("X@)&ET96TM/F=E=$5L96UE;G14>7!E*"DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?
M7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D<W5I9#L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@82`F
M;'0[4WEN8R9G=#L@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!C<F5A
M=&53>6YC3W5T<'5T*"1C=7)R96YT0VUD240L("8D;W5T<'5T*0H@("`@>PH@
M("`@("`@("1S=&%T92`]("8D7U-%4U-)3TY;)U-Y;F--3"YS=&%T92==.PH@
M("`@("`@("1A='1R<R`](&%R<F%Y*"D["@H@("`@("`@("1O=71P=70M/G-T
M87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G4WEN8R<L("1A='1R<RD[
M"B`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))
M*"DL("=#;61)1"<L("1A='1R<RD["B`@("`@("`@)&]U='!U="T^8VAA<F%C
M=&5R<R@D8W5R<F5N=$-M9$E$*3L*("`@("`@("`D8W5R<F5N=$-M9$E$*RL[
M"B`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I
M+"`G0VUD240G*3L*"B`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S
M=&%T92T^9V5T55))*"DL("=487)G970G+"`D871T<G,I.PH@("`@("`@("1O
M=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G3&]C55))
M)RP@)&%T=')S*3L*("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1T:&ES
M+3Y?<V]U<F-E3&]C55))*3L*("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT
M*"1S=&%T92T^9V5T55))*"DL("=,;V-54DDG*3L*("`@("`@("`D;W5T<'5T
M+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=487)G970G*3L*"B`@
M("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL
M("=3;W5R8V4G+"`D871T<G,I.PH@("`@("`@("1O=71P=70M/G-T87)T16QE
M;65N="@D<W1A=&4M/F=E=%5222@I+"`G3&]C55)))RP@)&%T=')S*3L*("`@
M("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1T:&ES+3Y?=&%R9V5T3&]C55))
M*3L*("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))
M*"DL("=,;V-54DDG*3L*("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S
M=&%T92T^9V5T55))*"DL("=3;W5R8V4G*3L*"B`@("`@("`@)'-Y;F-4>7!E
M(#T@)'1H:7,M/E]T87)G971,;V-54DD["@H@("`@("`@(&=L;V)A;"`D8F%C
M:V5N9#L*("`@("`@("`D8F%C:V5N9"T^;&]G365S<V%G92@B:&%N9&QE4WEN
M8R!F;W(@<WEN8U1Y<&4])'-Y;F-4>7!E(BP@7U]&24Q%7U\L(%]?3$E.15]?
M+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("\O($AE<F4G<R!W:&5R92!S
M97)V97(@;6]D:69I8V%T:6]N<R!A<F4@<V5N="!T;R!T:&4@8VQI96YT.@H@
M("`@("`@("1R969T<R`]("1S=&%T92T^9V5T4V5R=F5R06YC:&]R3&%S="@D
M<WEN8U1Y<&4I.PH@("`@("`@("1C=7)R96YT0VUD240@/2`D=&AI<RT^:&%N
M9&QE4WEN8R@D8W5R<F5N=$-M9$E$+"`D<WEN8U1Y<&4L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1O=71P=70L("1R969T
M<RD["@H@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG9715
M4DDH*2P@)U-Y;F,G*3L*"B`@("`@("`@<F5T=7)N("1C=7)R96YT0VUD240[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!396YD<R!S97)V97(@8VAA;F=E<R!T
M;R!T:&4@8VQI96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!H86YD;&53>6YC
M*"1C=7)R96YT0VUD240L("1S>6YC5'EP92P@)B1O=71P=70L("1R969T<RP@
M)&5N9%]T<R`](#`I"B`@("!["B`@("`@("`@9VQO8F%L("1B86-K96YD.PH@
M("`@("`@(&=L;V)A;"`D;65S<V%G949U;&P["@H@("`@("`@("\J("1M97-S
M86=E1G5L;"!W:6QL(&)E('-E="!T;R!T<G5E('1O(&EN9&EC871E('1H870@
M=&AE<F4G<R!N;R!R;V]M"B`@("`@("`@("H@9F]R(&]T:&5R(&1A=&$@:6X@
M=&AI<R!M97-S86=E+B!)9B!I="=S(&9A;'-E("AE;7!T>2D@86YD('1H97)E
M"B`@("`@("`@("H@87)E('!E;F1I;F<@4WEN8R!D871A+"!T:&4@9FEN86P@
M8V]M;6%N9"!W:6QL('-E;G0@=&AE('!E;F1I;F<@9&%T82X*("`@("`@("`@
M*B!4:&ES(&=L;V)A;"!D871A('-H;W5L9"!B92!M;W9E9"!T;R!A(&=L;V)A
M;"!O8FIE8W0L('1O9V5T:&5R"B`@("`@("`@("H@=VET:"!C=7)R96YT0VUD
M240@86YD("1O=71P=70N("HO"B`@("`@("`@)&UE<W-A9V5&=6QL(#T@9F%L
M<V4["@H@("`@("`@("1S=&%T92`]("8D7U-%4U-)3TY;)U-Y;F--3"YS=&%T
M92==.PH@("`@("`@("1D979I8V4@/2`F)'-T871E+3YG971$979I8V4H*3L*
M("`@("`@("`D<WEN8TED96YT:69I97(@/2`D<W1A=&4M/F=E=%-Y;F-)9&5N
M=&EF:65R*"D["B`@("`@("`@)&-O;G1E;G14>7!E(#T@)&1E=FEC92T^9V5T
M4')E9F5R<F5D0V]N=&5N=%1Y<&5#;&EE;G0H)'-Y;F-4>7!E+"`D=&AI<RT^
M7W-O=7)C94QO8U5222D["@H@("`@("`@("\J(%=E(&9A:71H9G5L;'D@97AP
M96-T('1O(&1E86P@=VET:"!A;&P@<F5M86EN:6YG(&5L96UE;G1S+B!7:6QL
M(&)E"B`@("`@("`@("H@<V5T('1O('1R=64@:68@=V4@<G5N(&]U="!O9B!S
M<&%C92!F;W(@;65S<V%G92!C<F5A=&EO;BX@*B\*("`@("`@("`D=&AI<RT^
M<V5T4&5N9&EN9T5L96UE;G1S*&9A;'-E*3L*"B`@("`@("`@+R\@2&%N9&QE
M(&1E;&5T:6]N<RX*("`@("`@("`D9&5L971I;VYS(#T@)&)A8VME;F0M/F=E
M=%-E<G9E<D1E;&5T:6]N<R@D<WEN8TED96YT:69I97(L("1S>6YC5'EP92P@
M)')E9G1S+"`D96YD7W1S*3L*"B`@("`@("`@:68@*"1R969T<R`^(#`I('L*
M("`@("`@("`@("`@+R\@1&]N)W0@<V5N9"!D96QE=&5S(&]N(%-L;W=3>6YC
M+@H@("`@("`@("`@("!F;W)E86-H("@D9&5L971I;VYS(&%S("1S=6ED(#T^
M("1C=6ED*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V1O;F5;)'-U:61=
M(#T@=')U93L*("`@("`@("`@("`@("`@("1B86-K96YD+3YL;V=-97-S86=E
M*")D96QE=&4Z(&-U:60])&-U:60@<W5I9#TD<W5I9"!R969T<SH@)')E9G1S
M(BP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@
M("`@("`@("`@("`O+R!#<F5A=&4@82!$96QE=&4@<F5Q=65S="!F;W(@8VQI
M96YT+@H@("`@("`@("`@("`@("`@)&-U<G)E;G1#;61)1"`]("1T:&ES+3YO
M=71P=71#;VUM86YD*"1C=7)R96YT0VUD240L("1O=71P=70L("=$96QE=&4G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&YU;&PL(&YU;&PL("1C=6ED+"!N=6QL*3L*("`@("`@("`@
M("`@("`@("1S=&%T92T^;&]G*"=397)V97(M1&5L971E)RD["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@+R\@2&%N9&QE(&%D9&ET:6]N<RX*
M("`@("`@("`D861D<R`]("1B86-K96YD+3YG971397)V97)!9&1I=&EO;G,H
M)'-Y;F-)9&5N=&EF:65R+"`D<WEN8U1Y<&4L("1R969T<RP@)&5N9%]T<RD[
M"B`@("`@("`@9F]R96%C:"`H)&%D9',@87,@)'-U:60@/3X@)&-U:60I('L*
M("`@("`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7V1O;F5;)'-U:61=*2D@
M>PH@("`@("`@("`@("`@("`@+R\@06QR96%D>2!S96YT(&1E;&5T92P@;F\@
M;F5E9"!T;R!A9&0N"B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D8F%C:V5N9"T^;&]G365S<V%G92@B861D
M.B`D<W5I9"(L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I
M.PH*("`@("`@("`@("`@)&,@/2`D8F%C:V5N9"T^<F5T<FEE=F5%;G1R>2@D
M<WEN8U1Y<&4L("1S=6ED+"`D8V]N=&5N=%1Y<&4I.PH@("`@("`@("`@("!I
M9B`H(6ES7V$H)&,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M("\O($ET96T@:6X@:&ES=&]R>2!B=70@;F]T(&EN(&1A=&%B87-E+B!3=')A
M;F=E+"!B=70@8V%N(&AA<'!E;BX*("`@("`@("`@("`@("`@(&QI<W0H)&-L
M:65N=$-O;G1E;G0L("1C;&EE;G1#;VYT96YT5'EP92D@/0H@("`@("`@("`@
M("`@("`@("`@("1D979I8V4M/F-O;G9E<G1397)V97(R0VQI96YT*"1C+"`D
M8V]N=&5N=%1Y<&4I.PH@("`@("`@("`@("`@("`@+R\@0VAE8VL@:68@=V4@
M:&%V92!S<&%C92!L969T(&EN('1H92!M97-S86=E+@H@("`@("`@("`@("`@
M("`@:68@*"@D<W1A=&4M/F=E=$UA>$US9U-I>F4H*0H@("`@("`@("`@("`@
M("`@("`@("T@)&]U='!U="T^9V5T3W5T<'5T4VEZ92@I"B`@("`@("`@("`@
M("`@("`@("`@+2!S=')L96XH)&-L:65N=$-O;G1E;G0I*2`\(#4P*2!["B`@
M("`@("`@("`@("`@("`@("`@)&)A8VME;F0M/FQO9TUE<W-A9V4H)VUA>"!M
M97-S86=E('-I>F4@<F5A8VAE9"!C=7)S:7IE/2<*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`N("1O=71P=70M/F=E=$]U='!U
M=%-I>F4H*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@
M("`@("`@("`@("`@("`@("`D;65S<V%G949U;&P@/2!T<G5E.PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YS971096YD:6YG16QE;65N=',H=')U92D[
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1C=7)R96YT0VUD240["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=&AI<RT^7V1O;F5;
M)'-U:61=(#T@=')U93L*("`@("`@("`@("`@("`@("1C=7)R96YT0VUD240@
M/2`D=&AI<RT^;W5T<'5T0V]M;6%N9"@D8W5R<F5N=$-M9$E$+"`D;W5T<'5T
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=!9&0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1C;&EE;G1#;VYT96YT+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1C;&EE;G1#;VYT96YT5'EP92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N=6QL+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1S=6ED*3L*("`@("`@("`@("`@("`@("1S=&%T92T^;&]G*"=397)V97(M
M061D)RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M8F%C:V5N9"T^;&]G365S<V%G92@G87!I(&5X<&]R="!C86QL(&9O<B`G("X@
M)'-U:60@+B`G(&9A:6QE9#H@("<@+B`D8RT^9V5T365S<V%G92@I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?
M3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("\O($AA;F1L92!C:&%N9V5S+@H@("`@("`@(&EF("@D
M<F5F=',@(3T@,"D@>PH@("`@("`@("`@("`O+R!$;VXG="!S96YD(&-H86YG
M97,@9F]R(%-L;W=3>6YC+"!C;VYF=7-E<R!S;VUE(&-L:65N=',N"B`@("`@
M("`@("`@("1E;F1?=',@/2!T:6UE*"D["B`@("`@("`@("`@("1C:&%N9V5S
M(#T@)&)A8VME;F0M/F=E=%-E<G9E<DUO9&EF:6-A=&EO;G,H)'-Y;F-)9&5N
M=&EF:65R+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1S>6YC5'EP92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5F
M=',L("1E;F1?=',I.PH@("`@("`@("`@("!I9B`H:7-?82@D8VAA;F=E<RP@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)&)A8VME;F0M/FQO
M9TUE<W-A9V4H)&-H86YG97,L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],
M3T=?15)2*3L*("`@("`@("`@("`@("`@(')E='5R;B`D8VAA;F=E<SL*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@9F]R96%C:"`H)&-H86YG97,@87,@
M)'-U:60@/3X@)&-U:60I('L*("`@("`@("`@("`@("`@(&EF("@A96UP='DH
M)'1H:7,M/E]D;VYE6R1S=6ED72DI('L*("`@("`@("`@("`@("`@("`@("`O
M+R!!;')E861Y('-E;G0@9&5L971E(&]R(&%D9"P@;F\@;F5E9"!T;R!M;V1I
M9GDN"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`@("`@:68@*"$D8W5I9"D@>PH@("`@("`@
M("`@("`@("`@("`@("\O(%1/1$\Z(&-R96%T92!A;B`B861D(B!H97)E(&EN
M<W1E860_"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`@("`@)&,@/2`D8F%C:V5N9"T^<F5T
M<FEE=F5%;G1R>2@D<WEN8U1Y<&4L("1S=6ED+"`D8V]N=&5N=%1Y<&4I.PH@
M("`@("`@("`@("`@("`@:68@*"%I<U]A*"1C+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("`@("`@("`@)&)A8VME;F0M/FQO9TUE<W-A9V4H(F-H
M86YG93H@)'-U:60B+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I
M.PH@("`@("`@("`@("`@("`@("`@(&QI<W0H)&-L:65N=$-O;G1E;G0L("1C
M;&EE;G1#;VYT96YT5'EP92D@/0H@("`@("`@("`@("`@("`@("`@("`@("`D
M9&5V:6-E+3YC;VYV97)T4V5R=F5R,D-L:65N="@D8RP@)&-O;G1E;G14>7!E
M*3L*("`@("`@("`@("`@("`@("`@("`O+R!#:&5C:R!I9B!W92!H879E('-P
M86-E(&QE9G0@:6X@=&AE(&UE<W-A9V4N"B`@("`@("`@("`@("`@("`@("`@
M:68@*"@D<W1A=&4M/F=E=$UA>$US9U-I>F4H*0H@("`@("`@("`@("`@("`@
M("`@("`@("`@+2`D;W5T<'5T+3YG971/=71P=713:7IE*"D*("`@("`@("`@
M("`@("`@("`@("`@("`@("T@<W1R;&5N*"1C;&EE;G1#;VYT96YT*2D@/"`U
M,"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D8F%C:V5N9"T^;&]G365S
M<V%G92@G;6%X(&UE<W-A9V4@<VEZ92!R96%C:&5D(&-U<G-I>F4])PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("1O
M=71P=70M/F=E=$]U='!U=%-I>F4H*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!0
M14%27TQ/1U]$14)51RD["B`@("`@("`@("`@("`@("`@("`@("`@("1M97-S
M86=E1G5L;"`]('1R=64["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YS971096YD:6YG16QE;65N=',H=')U92D["B`@("`@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D8W5R<F5N=$-M9$E$.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1O;F5;)'-U:61=
M(#T@=')U93L*("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=$-M9$E$(#T@
M)'1H:7,M/F]U='!U=$-O;6UA;F0H)&-U<G)E;G1#;61)1"P@)&]U='!U="P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)U)E<&QA8V4G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8VQI96YT0V]N
M=&5N="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&-L:65N=$-O;G1E;G14>7!E+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D8W5I9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@;G5L;"D["B`@("`@("`@("`@("`@
M("`@("`@)'-T871E+3YL;V<H)U-E<G9E<BU297!L86-E)RD["B`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("\O($ET96T@
M:6X@:&ES=&]R>2!B=70@;F]T(&EN(&1A=&%B87-E+B!3=')A;F=E+"!B=70*
M("`@("`@("`@("`@("`@("`@("`O+R!C86X@:&%P<&5N+@H@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!)
M9B!T87-K<R!A<F4@:&%N9&QE9"!I;G-I9&4@8V%L96YD87(L(&1O('1H92!S
M86UE(&%G86EN(&9O<@H@("`@("`@("\O('1A<VMS+@H@("`@("`@(&EF("@D
M<WEN8U1Y<&4@/3T@)V-A;&5N9&%R)R`F)B`D9&5V:6-E+3YH86YD;&5487-K
M<TEN0V%L96YD87(H*2D@>PH@("`@("`@("`@("`D8F%C:V5N9"T^;&]G365S
M<V%G92@B:&%N9&QI;F<@=&%S:W,@:6X@8V%L96YD87(@<WEN8R(L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?
M7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`@("`@)&-U<G)E;G1#;61)
M1"`]("1T:&ES+3YH86YD;&53>6YC*"1C=7)R96YT0VUD240L("=T87-K<R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D;W5T<'5T+"`D<F5F=',L("1E;F1?=',I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1C=7)R96YT0VUD240["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!/=71P=70@82!S:6YG;&4@4WEN8R!C;VUM86YD("A!9&0L($1E;&5T92P@
M4F5P;&%C92DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&]U='!U=$-O;6UA;F0H
M)&-U<G)E;G1#;61)1"P@)B1O=71P=70L("1C;VUM86YD+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D8V]N=&5N="P@)&-O;G1E;G14>7!E(#T@;G5L
M;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-U:60@/2!N=6QL+"`D
M<W5I9"`](&YU;&PI"B`@("!["B`@("`@("`@)'-T871E(#T@)B1?4T534TE/
M3ELG4WEN8TU,+G-T871E)UT["@H@("`@("`@("1A='1R<R`](&%R<F%Y*"D[
M"B`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))
M*"DL("1C;VUM86YD+"`D871T<G,I.PH*("`@("`@("`D;W5T<'5T+3YS=&%R
M=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)T-M9$E$)RP@)&%T=')S*3L*
M("`@("`@("`D8VAA<G,@/2`D8W5R<F5N=$-M9$E$.PH@("`@("`@("1O=71P
M=70M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@("`@("`D;W5T<'5T+3YE;F1%
M;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=#;61)1"<I.PH*("`@("`@("!I
M9B`H:7-S970H)&-O;G1E;G14>7!E*2D@>PH@("`@("`@("`@("`D;W5T<'5T
M+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)TUE=&$G+"`D871T
M<G,I.PH@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E
M+3YG97154DE-971A*"DL("=4>7!E)RP@)&%T=')S*3L*("`@("`@("`@("`@
M)&]U='!U="T^8VAA<F%C=&5R<R@D8V]N=&5N=%1Y<&4I.PH@("`@("`@("`@
M("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))365T82@I+"`G
M5'EP92<I.PH@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T
M92T^9V5T55))*"DL("=-971A)RD["B`@("`@("`@?0H*("`@("`@("!I9B`H
M:7-S970H)&-O;G1E;G0I"B`@("`@("`@("`@('Q\(&ES<V5T*"1C=6ED*2!\
M?"!I<W-E="@D<W5I9"DI('L*("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%
M;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=)=&5M)RP@)&%T=')S*3L*("`@
M("`@("`@("`@:68@*"1S=6ED("$](&YU;&PI('L*("`@("`@("`@("`@("`@
M("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G4V]U
M<F-E)RP@)&%T=')S*3L*("`@("`@("`@("`@("`@("1O=71P=70M/G-T87)T
M16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G3&]C55)))RP@)&%T=')S*3L*
M("`@("`@("`@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)'-U:60I.PH@
M("`@("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E
M=%5222@I+"`G3&]C55)))RD["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YE
M;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=3;W5R8V4G*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@:68@*"1C=6ED("$](&YU;&PI('L*("`@
M("`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E
M=%5222@I+"`G5&%R9V5T)RP@)&%T=')S*3L*("`@("`@("`@("`@("`@("1O
M=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G3&]C55))
M)RP@)&%T=')S*3L*("`@("`@("`@("`@("`@("1O=71P=70M/F-H87)A8W1E
M<G,H)&-U:60I.PH@("`@("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N
M="@D<W1A=&4M/F=E=%5222@I+"`G3&]C55)))RD["B`@("`@("`@("`@("`@
M("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=487)G
M970G*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H:7-S970H)&-O
M;G1E;G0I*2!["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE
M;G0H)'-T871E+3YG97154DDH*2P@)T1A=&$G+"`D871T<G,I.PH@("`@("`@
M("`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D8V]N=&5N="D["B`@("`@
M("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))
M*"DL("=$871A)RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&]U='!U
M="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G271E;2<I.PH@("`@
M("`@('T*"B`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E
M=%5222@I+"`D8V]M;6%N9"D["@H@("`@("`@("1C=7)R96YT0VUD240K*SL*
M"B`@("`@("`@<F5T=7)N("1C=7)R96YT0VUD240["B`@("!]"@H@("`@9G5N
M8W1I;VX@<V5T4&5N9&EN9T5L96UE;G1S*"1E*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?<&5N9&EN9T5L96UE;G1S(#T@)&4["B`@("!]"@H@("`@9G5N8W1I
M;VX@:&%S4&5N9&EN9T5L96UE;G1S*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/E]P96YD:6YG16QE;65N=',["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B]3>6YC34PO0V]N<W1A;G1S+G!H<```````
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,S$Q,B`Q,#4Q-30S
M,S<S-"`P,C(Q,S8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@2V%R
M<W1E;B!&;W5R;6]N="`\:V%R<W1E;D!H;W)D92YO<F<^"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+U-Y;F--3"]3>6YC34PO0V]N<W1A;G1S+G!H<"QV(#$N
M,2XR+C0@,C`P-B\P-2\P,2`Q,CHP-3HQ-"!J86X@17AP("0*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($MA<G-T96X@1F]U<FUO;G0@/&MA<G-T96Y`
M:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!3>6YC34P*("HO"F1E9FEN92@G04Q%
M4E1?1$E34$Q!62<L(#$P,"D["@HO+R!.;W0@:6UP;&5M96YT960N"F1E9FEN
M92@G04Q%4E1?5%=/7U=!62<L(#(P,"D["F1E9FEN92@G04Q%4E1?4TQ/5U]3
M64Y#)RP@,C`Q*3L*9&5F:6YE*"=!3$525%]/3D5?5T%97T923TU?0TQ)14Y4
M)RP@,C`R*3L*9&5F:6YE*"=!3$525%]2149215-(7T923TU?0TQ)14Y4)RP@
M,C`S*3L*9&5F:6YE*"=!3$525%]/3D5?5T%97T923TU?4T525D52)RP@,C`T
M*3L*9&5F:6YE*"=!3$525%]2149215-(7T923TU?4T525D52)RP@,C`U*3L*
M"B\O($YO="!I;7!L96UE;G1E9"X*9&5F:6YE*"=!3$525%]45T]?5T%97T)9
M7U-%4E9%4B<L(#(P-BD["F1E9FEN92@G04Q%4E1?3TY%7U=!65]&4D]-7T-,
M245.5%]"65]315)615(G+"`R,#<I.PID969I;F4H)T%,15)47U)%1E)%4TA?
M1E)/35]#3$E%3E1?0EE?4T525D52)RP@,C`X*3L*9&5F:6YE*"=!3$525%]/
M3D5?5T%97T923TU?4T525D527T)97U-%4E9%4B<L(#(P.2D["F1E9FEN92@G
M04Q%4E1?4D5&4D532%]&4D]-7U-%4E9%4E]"65]315)615(G+"`R,3`I.PH*
M9&5F:6YE*"=!3$525%]215-53%1?04Q%4E0G+"`R,C$I.PID969I;F4H)T%,
M15)47TY%6%1?34534T%'12<L(#(R,BD["F1E9FEN92@G04Q%4E1?3D]?14Y$
M7T]&7T1!5$$G+"`R,C,I.PH*9&5F:6YE*"=-24U%7U-93D--3%]834PG+"`G
M87!P;&EC871I;VXO=FYD+G-Y;F-M;"MX;6PG*3L*9&5F:6YE*"=-24U%7U-9
M3D--3%]70EA-3"<L("=A<'!L:6-A=&EO;B]V;F0N<WEN8VUL*W=B>&UL)RD[
M"@ID969I;F4H)TU)345?4UE.0TU,7T1%5DE#15])3D9/7UA-3"<L("=A<'!L
M:6-A=&EO;B]V;F0N<WEN8VUL+61E=FEN9BMX;6PG*3L*9&5F:6YE*"=-24U%
M7U-93D--3%]$159)0T5?24Y&3U]70EA-3"<L("=A<'!L:6-A=&EO;B]V;F0N
M<WEN8VUL+61E=FEN9BMW8GAM;"<I.PH*9&5F:6YE*"=-24U%7U1%6%1?4$Q!
M24XG+"`G=&5X="]P;&%I;B<I.PID969I;F4H)TU)345?5D-!4D1?5C(Q)RP@
M)W1E>'0O>"UV8V%R9"<I.PID969I;F4H)TU)345?5D-!4D1?5C,P)RP@)W1E
M>'0O=F-A<F0G*3L*"F1E9FEN92@G34E-15]60T%,14Y$05(G+"`G=&5X="]X
M+79C86QE;F1A<B<I.PID969I;F4H)TU)345?24-!3$5.1$%2)RP@)W1E>'0O
M8V%L96YD87(G*3L*9&5F:6YE*"=-24U%7UA-3%])0T%,14Y$05(G+"`G87!P
M;&EC871I;VXO=FYD+G-Y;F-M;"UX8V%L)RD["@ID969I;F4H)TU)345?3453
M4T%'12<L("=T97AT+VUE<W-A9V4G*3L*"F1E9FEN92@G34E-15]364Y#34Q?
M6$U,7T5-04E,)RP@)V%P<&QI8V%T:6]N+W9N9"YS>6YC;6PM>&US9R<I.PID
M969I;F4H)TU)345?4UE.0TU,7UA-3%]"3T]+34%22R<L("=A<'!L:6-A=&EO
M;B]V;F0N<WEN8VUL+7AB;V]K;6%R:R<I.PID969I;F4H)TU)345?4UE.0TU,
M7U)%3$%424].04Q?3T)*14-4)RP@)V%P<&QI8V%T:6]N+W9N9"YS>6YC;6PM
M>')E;&%T:6]N86PG*3L*"F1E9FEN92@G4D534$].4T5?24Y?4%)/1U)%4U,G
M+"`Q,#$I.PH*9&5F:6YE*"=215-03TY315]/2R<L(#(P,"D["F1E9FEN92@G
M4D534$].4T5?251%35]!1$1%1"<L(#(P,2D["F1E9FEN92@G4D534$].4T5?
M04-#15!4141?1D]27U!23T-%4U-)3D<G+"`R,#(I.PID969I;F4H)U)%4U!/
M3E-%7TY/3D%55$A/4DE!5$%4259%7U)%4U!/3E-%)RP@,C`S*3L*9&5F:6YE
M*"=215-03TY315].3U]#3TY414Y4)RP@,C`T*3L*9&5F:6YE*"=215-03TY3
M15]215-%5%]#3TY414Y4)RP@,C`U*3L*9&5F:6YE*"=215-03TY315]005)4
M24%,7T-/3E1%3E0G+"`R,#8I.PID969I;F4H)U)%4U!/3E-%7T-/3D9,24-4
M7U)%4T],5D5$7U=)5$A?34521T4G+"`R,#<I.PID969I;F4H)U)%4U!/3E-%
M7T-/3D9,24-47U)%4T],5D5$7U=)5$A?0TQ)14Y47U=)3DY)3D<G+"`R,#@I
M.PID969I;F4H)U)%4U!/3E-%7T-/3D9)3$-47U)%4T],5D5$7U=)5$A?1%50
M3$E#051%)RP@,C`Y*3L*9&5F:6YE*"=215-03TY315]$14Q%5$5?5TE42$]5
M5%]!4D-(259%)RP@,C$P*3L*9&5F:6YE*"=215-03TY315])5$5-7TY/7T1%
M3$54140G+"`R,3$I.PID969I;F4H)U)%4U!/3E-%7T%55$A%3E1)0T%424].
M7T%#0T505$5$)RP@,C$R*3L*9&5F:6YE*"=215-03TY315]#2%5.2T5$7TE4
M14U?04-#15!4141?04Y$7T)51D9%4D5$)RP@,C$S*3L*9&5F:6YE*"=215-0
M3TY315]/4$52051)3TY?0T%.0T5,3$5$)RP@,C$T*3L*9&5F:6YE*"=215-0
M3TY315].3U]%6$5#551%1"<L(#(Q-2D["F1E9FEN92@G4D534$].4T5?051/
M34E#7U)/3$Q?0D%#2U]/2R<L(#(Q-BD["@ID969I;F4H)U)%4U!/3E-%7TU5
M3%1)4$Q%7T-(3TE#15,G+"`S,#`I.PHO+R!.965D('1O(&-H86YG92!N86UE
M<RX*+R\@9&5F:6YE*"=215-03TY315]-54Q425!,15]#2$])0T53)RP@,S`Q
M*3L*+R\@9&5F:6YE*"=215-03TY315]-54Q425!,15]#2$])0T53)RP@,S`R
M*3L*+R\@9&5F:6YE*"=215-03TY315]-54Q425!,15]#2$])0T53)RP@,S`S
M*3L*+R\@9&5F:6YE*"=215-03TY315]-54Q425!,15]#2$])0T53)RP@,S`T
M*3L*9&5F:6YE*"=215-03TY315]54T5?4%)/6%DG+"`S,#4I.PH*9&5F:6YE
M*"=215-03TY315]"041?4D5154535"<L(#0P,"D["F1E9FEN92@G4D534$].
M4T5?24Y604Q)1%]#4D5$14Y424%,4R<L(#0P,2D["B\O($YE960@=&\@8VAA
M;F=E(&YA;65S+@HO+R!D969I;F4H)U)%4U!/3E-%7TE.5D%,241?0U)%1$5.
M5$E!3%,G+"`T,#(I.PHO+R!D969I;F4H)U)%4U!/3E-%7TE.5D%,241?0U)%
M1$5.5$E!3%,G+"`T,#,I.PID969I;F4H)U)%4U!/3E-%7TY/5%]&3U5.1"<L
M(#0P-"D["B\O($YE960@=&\@8VAA;F=E(&YA;65S+@HO+R!D969I;F4H)U)%
M4U!/3E-%7TE.5D%,241?0U)%1$5.5$E!3%,G+"`T,#4I.PHO+R!D969I;F4H
M)U)%4U!/3E-%7TE.5D%,241?0U)%1$5.5$E!3%,G+"`T,#8I.PID969I;F4H
M)U)%4U!/3E-%7T-2141%3E1)04Q37TU)4U-)3D<G+"`T,#<I.PHO+R!D969I
M;F4H)U)%4U!/3E-%7TE.5D%,241?0U)%1$5.5$E!3%,G+"`T,#@I.PHO+R!D
M969I;F4H)U)%4U!/3E-%7TE.5D%,241?0U)%1$5.5$E!3%,G+"`T,#DI.PHO
M+R!D969I;F4H)U)%4U!/3E-%7TE.5D%,241?0U)%1$5.5$E!3%,G+"`T,3`I
M.PHO+R!D969I;F4H)U)%4U!/3E-%7TE.5D%,241?0U)%1$5.5$E!3%,G+"`T
M,3$I.PHO+R!D969I;F4H)U)%4U!/3E-%7TE.5D%,241?0U)%1$5.5$E!3%,G
M+"`T,3(I.PHO+R!D969I;F4H)U)%4U!/3E-%7TE.5D%,241?0U)%1$5.5$E!
M3%,G+"`T,3,I.PHO+R!D969I;F4H)U)%4U!/3E-%7TE.5D%,241?0U)%1$5.
M5$E!3%,G+"`T,30I.PHO+R!D969I;F4H)U)%4U!/3E-%7TE.5D%,241?0U)%
M1$5.5$E!3%,G+"`T,34I.PID969I;F4H)U)%4U!/3E-%7U)%455%4U1?4TE:
M15]43T]?0DE')RP@-#$V*3L*+R\@3F5E9"!T;R!C:&%N9V4@;F%M97,N"B\O
M(&1E9FEN92@G4D534$].4T5?24Y604Q)1%]#4D5$14Y424%,4R<L(#0Q-RD[
M"B\O(&1E9FEN92@G4D534$].4T5?24Y604Q)1%]#4D5$14Y424%,4R<L(#0Q
M."D["B\O(&1E9FEN92@G4D534$].4T5?24Y604Q)1%]#4D5$14Y424%,4R<L
M(#0Q.2D["B\O(&1E9FEN92@G4D534$].4T5?24Y604Q)1%]#4D5$14Y424%,
M4R<L(#0R,"D["B\O(&1E9FEN92@G4D534$].4T5?24Y604Q)1%]#4D5$14Y4
M24%,4R<L(#0R,2D["B\O(&1E9FEN92@G4D534$].4T5?24Y604Q)1%]#4D5$
M14Y424%,4R<L(#0R,BD["B\O(&1E9FEN92@G4D534$].4T5?24Y604Q)1%]#
M4D5$14Y424%,4R<L(#0R,RD["F1E9FEN92@G4D534$].4T5?4TE:15]-25--
M051#2"<L(#0R-"D["@ID969I;F4H)U)%4U!/3E-%7T-/34U!3D1?1D%)3$5$
M)RP@-3`P*3L*+R\@3F5E9"!T;R!C:&%N9V4@;F%M97,N"B\O(&1E9FEN92@G
M4D534$].4T5?0T]-34%.1%]&04E,140G+"`U,#$I.PHO+R!D969I;F4H)U)%
M4U!/3E-%7T-/34U!3D1?1D%)3$5$)RP@-3`R*3L*+R\@9&5F:6YE*"=215-0
M3TY315]#3TU-04Y$7T9!24Q%1"<L(#4P,RD["B\O(&1E9FEN92@G4D534$].
M4T5?0T]-34%.1%]&04E,140G+"`U,#0I.PHO+R!D969I;F4H)U)%4U!/3E-%
M7T-/34U!3D1?1D%)3$5$)RP@-3`U*3L*+R\@9&5F:6YE*"=215-03TY315]#
M3TU-04Y$7T9!24Q%1"<L(#4P-BD["B\O(&1E9FEN92@G4D534$].4T5?0T]-
M34%.1%]&04E,140G+"`U,#<I.PHO+R!D969I;F4H)U)%4U!/3E-%7T-/34U!
M3D1?1D%)3$5$)RP@-3`X*3L*+R\@9&5F:6YE*"=215-03TY315]#3TU-04Y$
M7T9!24Q%1"<L(#4P.2D["B\O(&1E9FEN92@G4D534$].4T5?0T]-34%.1%]&
M04E,140G+"`U,3`I.PHO+R!D969I;F4H)U)%4U!/3E-%7T-/34U!3D1?1D%)
M3$5$)RP@-3$Q*3L*+R\@9&5F:6YE*"=215-03TY315]#3TU-04Y$7T9!24Q%
M1"<L(#4Q,BD["B\O(&1E9FEN92@G4D534$].4T5?0T]-34%.1%]&04E,140G
M+"`U,3,I.PHO+R!D969I;F4H)U)%4U!/3E-%7T-/34U!3D1?1D%)3$5$)RP@
M-3$T*3L*+R\@9&5F:6YE*"=215-03TY315]#3TU-04Y$7T9!24Q%1"<L(#4Q
M-2D["B\O(&1E9FEN92@G4D534$].4T5?051/34E#7U)/3$Q?0D%#2U]&04E,
M140G+"`U,38I.PH*9&5F:6YE*"=.04U%7U-004-%7U5225]364Y#34Q?,5\Q
M)RP@)W-Y;F-M;#IS>6YC;6PQ+C$G*3L*9&5F:6YE*"=.04U%7U-004-%7U52
M25]364Y#34PG+"`G<WEN8VUL.G-Y;F-M;"<I.PID969I;F4H)TY!345?4U!!
M0T5?55))7TU%5$E.1B<L("=S>6YC;6PZ;65T:6YF)RD["F1E9FEN92@G3D%-
M15]34$%#15]54DE?345424Y&7S%?,2<L("=S>6YC;6PZ;65T:6YF)RD["F1E
M9FEN92@G3D%-15]34$%#15]54DE?1$5624Y&)RP@)W-Y;F-M;#ID979I;F8G
M*3L*9&5F:6YE*"=.04U%7U-004-%7U5225]$159)3D9?,5\Q)RP@)W-Y;F-M
M;#ID979I;F8G*3L*"B\J*@H@*B!)9B!S970@=&\@=')U92P@;&]G<R!A;&P@
M:6YC;VUI;F<@86YD(&]U=&=O=6YD(&EC86QE;F1A<B]V8V%R9"!D871A"B`J
M('1O("]T;7`O<WEN8R]L;V<N='AT+B!4:&4@=V5B('-E<G9E<B!U<V5R("AL
M:6ME('=W=W)U;BD@;75S="!H879E"B`J('=R:71E(&%C8V5S<R!T;R!T:&ES
M(&9I;&4N"B`J+PID969I;F4H)T1%0E5'3$]'7TE#04Q%3D1!4D1!5$$G+"!T
M<G5E*3L*"B\J*@H@*B!)9B!S970@=&\@=')U92P@82!C;W!Y(&]F(&%N>2!$
M979);F8@<F5C96EV960@9G)O;2!C;&EE;G1S"B`J(&ES('-A=F5D('1O("]T
M;7`O<WEN8R]D979I;F8N='AT+@H@*B!4:&4@=V5B('-E<G9E<B!U<V5R("AL
M:6ME('=W=W)U;BD@;75S="!H879E"B`J('=R:71E(&%C8V5S<R!T;R!T:&ES
M(&9I;&4N"B`J+PH*9&5F:6YE*"=$14)51TQ/1U]$159)3D8G+"!T<G5E*3L*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+U-Y;F--3"]$979I8V5);F9O+G!H<```````````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$Q,C<V(#$P-3$U-#,S-S,T
M(#`R,C(P-@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@4WEN8TU,7T1E=FEC94EN9F\@<F5P<F5S96YT
M<R!A(&1E=FEC92!I;F9O<FUA=&EO;B!S970@86-C;W)D:6YG('1O('1H90H@
M*B!3>6YC34P@<W!E8RX*("H*("H@4V5E(&AT='`Z+R]W=W<N<WEN8VUL+F]R
M9R]D;V-S+W-Y;F-M;%]D979I;F9?=C$Q7S(P,#(P,C$U+G!D9@H@*@H@*B!!
M($1E=FEC94EN9F\@;V)J96-T(&ES(&-R96%T960@8GD@0V]M;6%N9"]0=70Z
M.E-Y;F--3%]#;VUM86YD7U!U="!F<F]M(&%N"B`J(&%P<')O<')I871E(%A-
M3"!M97-S86=E+B!3>6YC34Q?0V]M;6%N9%]0=70@9&ER96-T;'D@<&]P=6QA
M=&5S('1H92!M96UB97)S"B`J('9A<FEA8FQE<RX*("H*("H@5&AE(&-U<G)E
M;G0@:6UP;&5M96YT871I;VX@<VAO=6QD(&AA;F1L92!A;&P@1&5V26YF(#$N
M,2!$5$0@96QE;65N=',*("H@97AP8V5P="!$4TUE;2!E;G1R:65S+@H@*@H@
M*B!#;W!Y<FEG:'0@,C`P-2TR,#`V($MA<G-T96X@1F]U<FUO;G0@/&MA<G-T
M96Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO4WEN8TU,+U-Y;F--3"]$979I8V5);F9O+G!H<"QV(#$N,BXR+C8@
M,C`P-B\P-2\P-2`R,3HQ-#HT-2!K87)S=&5N($5X<"`D"B`J"B`J($!A=71H
M;W(@($MA<G-T96X@1F]U<FUO;G0@/&MA<G-T96Y`:&]R9&4N;W)G/@H@*B!`
M<&%C:V%G92!3>6YC34P*("HO"F-L87-S(%-Y;F--3%]$979I8V5);F9O('L*
M"B`@("!V87(@)%]697)$5$0["B`@("!V87(@)%]-86X["B`@("!V87(@)%]-
M;V0["B`@("!V87(@)%]/14T["B`@("!V87(@)%]&=U8["B`@("!V87(@)%]3
M=U8["B`@("!V87(@)%](=U8["B`@("!V87(@)%]$979)1#L*("`@('9A<B`D
M7T1E=E1Y<#L*"B`@("`O*BH*("`@("`J($%R<F%Y(&]F(%-Y;F--3%]$871A
M4W1O<F4@;V)J96-T<RX*("`@("`J+PH@("`@=F%R("1?1&%T85-T;W)E.PH*
M("`@("\J*@H@("`@("H@07)R87DZ($-45'EP92`]/B!A<G)A>3H@4')O<&5R
M='E.86UE(#T^(%-Y;F--3%]0<F]P97)T>2!O8FIE8W0N"B`@("`@*B\*("`@
M('9A<B`D7T-40V%P.PH*("`@("\J*@H@("`@("H@07)R87D@6$YA;2`]/B!A
M<G)A>2!O9B!8=F%L(&5N=')I97,N"B`@("`@*B\*("`@('9A<B`D7T5X=#L*
M"B`@("`O*BH*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@
M)%]55$,["@H@("`@+RHJ"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@
M("`@=F%R("1?4W5P<&]R=$QA<F=E3V)J<SL*"B`@("`O*BH*("`@("`J($!V
M87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]3=7!P;W)T3G5M8F5R3V9#
M:&%N9V5S.PH*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE($1E=DEN9B!D
M871A(&9O<B!A(&1A=&%S=&]R92!I9&5N=&EF:65D(&)Y("1S;W5R8V554DD*
M("`@("`J("A?4V]U<F-E4F5F('!A<F%M971E<BDN("!2971U<FYS(&$@4WEN
M8TU,7T1A=&%3=&]R92!O8FIE8W0@;W(@;G5L;"!I9@H@("`@("H@;F\@<W5C
M:"!D871A<W1O<F4@97AI<W1S+@H@("`@("HO(`H@("`@9G5N8W1I;VX@9V5T
M1&%T85-T;W)E*"1S;W5R8V554DDI"B`@("!["@H@("`@("`@(&EF("AI<U]A
M<G)A>2@D=&AI<RT^7T1A=&%3=&]R92DI('L*("`@("`@("`@("`@9F]R96%C
M:"`H)'1H:7,M/E]$871A4W1O<F4@87,@)'8I('L*("`@("`@("`@("`@("`@
M(&EF("@D=BT^7U-O=7)C95)E9B`]/2`D<V]U<F-E55))*2!["B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1V.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!N=6QL.PH@("`@
M?0I]"@HO*BH*("H@5&AE(%-Y;F--3%]$871A4W1O<F4@8VQA<W,@9&5S8W)I
M8F5S(&]N92!O9B!T:&4@<&]S<VEB;&4@9&%T87-T;W)E<PH@*B`H:2YE+B!D
M871A8F%S97,I(&]F('1H92!D979I8V4N("!-;W-T(&EM<&]R=&%N="!A='1R
M:6)U=&5S(&%R92!T:&4*("H@<')E9F5R<F5D($UI;64@5'EP97,@9F]R('-E
M;F1I;F<@86YD(')E8V5I=FEN9R!D871A(&9O<B!T:&ES(&1A=&%S=&]R93H*
M("H@7U1X+5!R968@86YD(%]2>"U0<F5F"B`J"B`J($!P86-K86=E(%-Y;F--
M3`H@*B\*8VQA<W,@4WEN8TU,7T1A=&%3=&]R92!["@H@("`@+RHJ"B`@("`@
M*B!4:&4@;&]C86P@55))(&]F('1H92!D871A<W1O<F4N"B`@("`@*B\*("`@
M('9A<B`D7U-O=7)C95)E9CL*"B`@("`O*BH*("`@("`J($]P=&EO;F%L+@H@
M("`@("HO"B`@("!V87(@)%]$:7-P;&%Y3F%M93L*"B`@("`O*BH*("`@("`J
M($]P=&EO;F%L+@H@("`@("HO"B`@("!V87(@)%]-87A'54E$4VEZ93L*"B`@
M("`O*BH*("`@("`J($]N92!E;&5M96YT(&%R<F%Y(&]F($-45'EP92`]/B!6
M97)#5`H@("`@("HO"B`@("!V87(@)%]2>%]0<F5F.PH*("`@("\J*@H@("`@
M("H@07)R87D@;V8@0U14>7!E(#T^(%9E<D-4"B`@("`@*B\*("`@('9A<B`D
M7U)X.PH*("`@("\J*@H@("`@("H@3VYE(&5L96UE;G0@87)R87D@;V8@0U14
M>7!E(#T^(%9E<D-4"B`@("`@*B\*("`@('9A<B`D7U1X7U!R968["@H@("`@
M+RHJ"B`@("`@*B!!<G)A>2!O9B!#5%1Y<&4@/3X@5F5R0U0*("`@("`J+PH@
M("`@=F%R("1?5'@["@H@("`@+RHJ"B`@("`@*B!/<'1I;VYA;"X*("`@("`J
M+PH@("`@=F%R("1?1%--96T["@H@("`@+RHJ"B`@("`@*B!!<G)A>2!3>6YC
M5'EP92`]/B!T<G5E"B`@("`@*B\*("`@('9A<B`D7U-Y;F-#87`["@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('1H92!P<F5F97)R960@8V]N=&5N='EP92!T
M:&4@8VQI96YT('=A;G1S('1O(')E8V5I=F4@*%)8*2X@3W(*("`@("`J($Y5
M3$P@:68@;F]T('-P96-I9FEE9"`H=VAI8V@@:7,@;F]T(&%L;&]W960@8GD@
M<')O=&]C;VPI+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9710<F5F97)R9612
M6$-O;G1E;G14>7!E*"D*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH)'1H
M:7,M/E]2>%]0<F5F*2D@>PH@("`@("`@("`@("`D<B`](&%R<F%Y7VME>7,H
M)'1H:7,M/E]2>%]0<F5F*3L*("`@("`@("`@("`@<F5T=7)N("1R6S!=.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@;G5L;#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE('9E<G-I;VX@;V8@=&AE('!R969E<G)E9"!C
M;VYT96YT>7!E('1H92!C;&EE;G0@=V%N=',@=&\*("`@("`J(')E8V5I=F4@
M*%)8*2X@3W(@3E5,3"!I9B!N;W0@<W!E8VEF:65D("AW:&EC:"!I<R!N;W0@
M86QL;W=E9"!B>0H@("`@("H@<')O=&]C;VPI+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G9710<F5F97)R96126$-O;G1E;G14>7!E5F5R<VEO;B@I"B`@("![
M"B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3Y?4GA?4')E9BDI('L*("`@
M("`@("`@("`@)'(@/2!A<G)A>5]V86QU97,H)'1H:7,M/E]2>%]0<F5F*3L*
M("`@("`@("`@("`@<F5T=7)N("1R6S!=.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@3E5,3#L*("`@('T*?0H*+RHJ"B`J(%1H92!C;&%S<R!3>6YC34Q?
M4')O<&5R='D@:7,@=7-E9"!T;R!D969I;F4@82!S:6YG;&4@<')O<&5R='D@
M;V8@82!V8V%R9`H@*B!E;&5M96YT+B`@5&AE(&-O;G1E;G1S(&]F(&$@4')O
M<&5R='D@8V%N(&)E(&1E9FEN960@8GD@86X@96YU;65R871I;VX@;V8*("H@
M=F%L:60@=F%L=65S("A?5F%L16YU;2D@;W(@8GD@82!$871A5'EP92]3:7IE
M(&-O;6)I;F%T:6]N+"!O<B!N;W0@870@86QL+@H@*@H@*B!`<&%C:V%G92!3
M>6YC34P*("HO"F-L87-S(%-Y;F--3%]0<F]P97)T>2!["@H@("`@+RHJ"B`@
M("`@*B!!<G)A>2!O9B!V86QI9"!V86QU97,@/3X@=')U90H@("`@("HO"B`@
M("!V87(@)%]686Q%;G5M.PH*("`@("\J*@H@("`@("H@268@;F]T(%9A;$5N
M=6TN"B`@("`@*B\*("`@('9A<B`D7T1A=&%4>7!E.PH*("`@("\J*@H@("`@
M("H@268@;F]T(%9A;$5N=6TL(&]P=&EO;F%L+@H@("`@("HO"B`@("!V87(@
M)%]3:7IE.PH*("`@("\J*@H@("`@("H@3W!T:6]N86PN"B`@("`@*B\*("`@
M('9A<B`D7T1I<W!L87E.86UE.PH*("`@("\J*@H@("`@("H@07)R87D@;V8@
M4&%R86U.86UE(#T^(%-Y;F--3%]0<F]P97)T>5!A<F%M971E<@H@("`@("HO
M"B`@("!V87(@)%]P87)A;7,["@I]"@HO*BH*("H@5&AE(&-L87-S(%-Y;F--
M3%]0<F]P97)T>5!A<F%M971E<B!I<R!U<V5D('1O(&1E9FEN92!A('-I;F=L
M92!P87)A;65T97(@;V8*("H@82!P<F]P97)T>2!O9B!A('9C87)D(&5L96UE
M;G0N("!4:&4@8V]N=&5N=',@;V8@82!0<F]P97)T>5!A<F%M971E<B!C86X@
M8F4*("H@9&5F:6YE9"!B>2!A;B!E;G5M97)A=&EO;B!O9B!V86QI9"!V86QU
M97,@*%]686Q%;G5M*2!O<B!B>2!A($1A=&%4>7!E+U-I>F4*("H@8V]M8FEN
M871I;VXL(&]R(&YO="!A="!A;&PN"B`J"B`J($!P86-K86=E(%-Y;F--3`H@
M*B\*8VQA<W,@4WEN8TU,7U!R;W!E<G1Y4&%R86UE=&5R('L*"B`@("`O*BH*
M("`@("`J($EF('!R;W9I9&5D.B!A<G)A>2!O9B!686Q%;G5M(#T^('1R=64*
M("`@("`J+PH@("`@=F%R("1?5F%L16YU;3L*"B`@("`O*BH*("`@("`J($EF
M(&YO="!686Q%;G5M+@H@("`@("HO"B`@("!V87(@)%]$871A5'EP93L*"B`@
M("`O*BH*("`@("`J($EF(&YO="!686Q%;G5M+"!O<'1I;VYA;"X*("`@("`J
M+PH@("`@=F%R("1?4VEZ93L*"B`@("`O*BH*("`@("`J($]P=&EO;F%L+@H@
M("`@("HO"B`@("!V87(@)%]$:7-P;&%Y3F%M93L*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]3>6YC34PO0V]M;6%N9"YP:'``````
M````````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S4V-2`Q,#4Q
M-30S,S<S-"`P,C$U-3,`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*"FEN8VQU9&5?;VYC92`G4WEN8TU,+U-T871E
M+G!H<"<["@HO*BH*("H@5&AE(%-Y;F--3%]#;VUM86YD(&-L87-S('!R;W9I
M9&5S(&$@<W5P97(@8VQA<W,@9F\@4WEN8T)O9'D*("H@8V]M;6%N9',N"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+U-Y;F--3"]3>6YC34PO0V]M;6%N9"YP
M:'`L=B`Q+C0N,3`N-R`R,#`V+S`Q+S`Q(#(Q.C(X.C,V(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($%N=&AO;GD@36EL;',@/&%M:6QL
M<T!P>7)A;6ED-BYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!!
M;G1H;VYY($UI;&QS(#QA;6EL;'-`<'ER86UI9#8N8V]M/@H@*B!`<VEN8V4@
M("!(;W)D92`S+C`*("H@0'!A8VMA9V4@4WEN8TU,"B`J+PIC;&%S<R!3>6YC
M34Q?0V]M;6%N9"!["@H@("`@+RHJ"B`@("`@*B!`=F%R(&EN=&5G97(*("`@
M("`J+PH@("`@=F%R("1?8VUD240["@H@("`@+RHJ"B`@("`@*B!);G1E<FYA
M;"!S=')U8W1U<F4@=7-E9"!D=7)I;F<@6$U,('!A<G-I;F<N"B`@("`@*@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]3=&%C:R`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)%]C:&%R<SL*"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D8V]M;6%N
M9"P@)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@:6YC;'5D95]O;F-E
M("=3>6YC34PO0V]M;6%N9"\G("X@)&-O;6UA;F0@+B`G+G!H<"<["B`@("`@
M("`@)&-L87-S(#T@)U-Y;F--3%]#;VUM86YD7R<@+B`D8V]M;6%N9#L*("`@
M("`@("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@
M)&-M9"`]("9N97<@)&-L87-S*"1P87)A;7,I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1'3$]"04Q36R=B86-K96YD)UTM/FQO9TUE<W-A9V4H
M)T-L87-S(&1E9FEN:71I;VX@;V8@)R`N("1C;&%S<R`N("<@;F]T(&9O=6YD
M+B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@
M("`@("!I;F-L=61E7V]N8V4@)U!%05(N<&AP)SL*("`@("`@("`@("`@)&-M
M9"`](%!%05(Z.G)A:7-E17)R;W(H)T-L87-S(&1E9FEN:71I;VX@;V8@)R`N
M("1C;&%S<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1C;60["B`@("!]"@H@("`@9G5N8W1I;VX@;W5T<'5T*"1C=7)R
M96YT0VUD240L("1O=71P=70I"B`@("!["B`@("!]"@H@("`@9G5N8W1I;VX@
M<W1A<G1%;&5M96YT*"1U<FDL("1L;V-A;$YA;64L("1A='1R<RD*("`@('L*
M("`@("`@("`D=&AI<RT^7U-T86-K6UT@/2`D;&]C86Q.86UE.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&5N9$5L96UE;G0H)'5R:2P@)&5L96UE;G0I"B`@("![
M"B`@("`@("`@<W=I=&-H("AC;W5N="@D=&AI<RT^7U-T86-K*2D@>PH@("`@
M("`@(&-A<V4@,CH*("`@("`@("`@("`@:68@*"1E;&5M96YT(#T]("=#;61)
M1"<I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?8VUD240@/2!I;G1V86PH
M=')I;2@D=&AI<RT^7V-H87)S*2D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V-H87)S(#T@
M)R<["B`@("`@("`@87)R87E?<&]P*"1T:&ES+3Y?4W1A8VLI.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&-H87)A8W1E<G,H)'-T<BD*("`@('L*("`@("`@("`D
M=&AI<RT^7V-H87)S("X]("1S='(["B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O1FEL90``````````````````````````````
M````````````````````````````````````````````````````````````
M,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W
M,S0@,#$W,3`V`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]&:6QE+U!$1@``
M````````````````````````````````````````````````````````````
M```````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#`P,"`Q,#4Q-30S,S<S-"`P,3<U,3<`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+T9I;&4O4$1&+V9O;G1S````````````````````````````````
M`````````````````````````````````````````````#`P,#<U-2``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S,T(#`R,#8U,``@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O1FEL92]01$8O9F]N=',O8V]U<FEE
M<BYP:'``````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`T,38@,3`U
M,34T,S,W,S0@,#(S,3$Q`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B!`<&%C:V%G92!&:6QE7U!$1@H@
M*B\*9F]R("@D:2`](#`[("1I(#P](#(U-3L@)&DK*RD@>PH@("`@)&9O;G1?
M=VED=&AS6R=C;W5R:65R)UU;8VAR*"1I*5T@/2`V,#`["GT*)&9O;G1?=VED
M=&AS6R=C;W5R:65R0B==(#T@)&9O;G1?=VED=&AS6R=C;W5R:65R)UT["B1F
M;VYT7W=I9'1H<ULG8V]U<FEE<DDG72`]("1F;VYT7W=I9'1H<ULG8V]U<FEE
M<B==.PHD9F]N=%]W:61T:'-;)V-O=7)I97)"22==(#T@)&9P9&9?=VED=&AS
M6R=C;W5R:65R)UT["@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+T9I;&4O4$1&+V9O;G1S+VAE;'9E=&EC86)I+G!H<```
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`V,C$P(#$P-3$U-#,S-S,T(#`R
M,S<Q-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@0'!A8VMA9V4@1FEL95]01$8*("HO"B1F;VYT7W=I
M9'1H<ULG:&5L=F5T:6-A0DDG72`](&%R<F%Y*`H@("`@8VAR*#`I/3XR-S@L
M8VAR*#$I/3XR-S@L8VAR*#(I/3XR-S@L8VAR*#,I/3XR-S@L8VAR*#0I/3XR
M-S@L8VAR*#4I/3XR-S@L8VAR*#8I/3XR-S@L8VAR*#<I/3XR-S@L8VAR*#@I
M/3XR-S@L8VAR*#DI/3XR-S@L8VAR*#$P*3T^,C<X+&-H<B@Q,2D]/C(W."QC
M:'(H,3(I/3XR-S@L8VAR*#$S*3T^,C<X+&-H<B@Q-"D]/C(W."QC:'(H,34I
M/3XR-S@L8VAR*#$V*3T^,C<X+&-H<B@Q-RD]/C(W."QC:'(H,3@I/3XR-S@L
M8VAR*#$Y*3T^,C<X+&-H<B@R,"D]/C(W."QC:'(H,C$I/3XR-S@L"B`@("!C
M:'(H,C(I/3XR-S@L8VAR*#(S*3T^,C<X+&-H<B@R-"D]/C(W."QC:'(H,C4I
M/3XR-S@L8VAR*#(V*3T^,C<X+&-H<B@R-RD]/C(W."QC:'(H,C@I/3XR-S@L
M8VAR*#(Y*3T^,C<X+&-H<B@S,"D]/C(W."QC:'(H,S$I/3XR-S@L)R`G/3XR
M-S@L)R$G/3XS,S,L)R(G/3XT-S0L)R,G/3XU-38L)R0G/3XU-38L)R4G/3XX
M.#DL)R8G/3XW,C(L)UPG)ST^,C,X+"<H)ST^,S,S+"<I)ST^,S,S+"<J)ST^
M,S@Y+"<K)ST^-3@T+`H@("`@)RPG/3XR-S@L)RTG/3XS,S,L)RXG/3XR-S@L
M)R\G/3XR-S@L)S`G/3XU-38L)S$G/3XU-38L)S(G/3XU-38L)S,G/3XU-38L
M)S0G/3XU-38L)S4G/3XU-38L)S8G/3XU-38L)S<G/3XU-38L)S@G/3XU-38L
M)SDG/3XU-38L)SHG/3XS,S,L)SLG/3XS,S,L)SPG/3XU.#0L)STG/3XU.#0L
M)SXG/3XU.#0L)S\G/3XV,3$L)T`G/3XY-S4L)T$G/3XW,C(L"B`@("`G0B<]
M/C<R,BPG0R<]/C<R,BPG1"<]/C<R,BPG12<]/C8V-RPG1B<]/C8Q,2PG1R<]
M/C<W."PG2"<]/C<R,BPG22<]/C(W."PG2B<]/C4U-BPG2R<]/C<R,BPG3"<]
M/C8Q,2PG32<]/C@S,RPG3B<]/C<R,BPG3R<]/C<W."PG4"<]/C8V-RPG42<]
M/C<W."PG4B<]/C<R,BPG4R<]/C8V-RPG5"<]/C8Q,2PG52<]/C<R,BPG5B<]
M/C8V-RPG5R<]/CDT-"P*("`@("=8)ST^-C8W+"=9)ST^-C8W+"=:)ST^-C$Q
M+"=;)ST^,S,S+"=<7"<]/C(W."PG72<]/C,S,RPG7B<]/C4X-"PG7R<]/C4U
M-BPG8"<]/C,S,RPG82<]/C4U-BPG8B<]/C8Q,2PG8R<]/C4U-BPG9"<]/C8Q
M,2PG92<]/C4U-BPG9B<]/C,S,RPG9R<]/C8Q,2PG:"<]/C8Q,2PG:2<]/C(W
M."PG:B<]/C(W."PG:R<]/C4U-BPG;"<]/C(W."PG;2<]/C@X.2P*("`@("=N
M)ST^-C$Q+"=O)ST^-C$Q+"=P)ST^-C$Q+"=Q)ST^-C$Q+"=R)ST^,S@Y+"=S
M)ST^-34V+"=T)ST^,S,S+"=U)ST^-C$Q+"=V)ST^-34V+"=W)ST^-S<X+"=X
M)ST^-34V+"=Y)ST^-34V+"=Z)ST^-3`P+"=[)ST^,S@Y+"=\)ST^,C@P+"=]
M)ST^,S@Y+"=^)ST^-3@T+&-H<B@Q,C<I/3XS-3`L8VAR*#$R."D]/C4U-BQC
M:'(H,3(Y*3T^,S4P+&-H<B@Q,S`I/3XR-S@L8VAR*#$S,2D]/C4U-BP*("`@
M(&-H<B@Q,S(I/3XU,#`L8VAR*#$S,RD]/C$P,#`L8VAR*#$S-"D]/C4U-BQC
M:'(H,3,U*3T^-34V+&-H<B@Q,S8I/3XS,S,L8VAR*#$S-RD]/C$P,#`L8VAR
M*#$S."D]/C8V-RQC:'(H,3,Y*3T^,S,S+&-H<B@Q-#`I/3XQ,#`P+&-H<B@Q
M-#$I/3XS-3`L8VAR*#$T,BD]/C8Q,2QC:'(H,30S*3T^,S4P+&-H<B@Q-#0I
M/3XS-3`L8VAR*#$T-2D]/C(W."QC:'(H,30V*3T^,C<X+&-H<B@Q-#<I/3XU
M,#`L8VAR*#$T."D]/C4P,"QC:'(H,30Y*3T^,S4P+&-H<B@Q-3`I/3XU-38L
M8VAR*#$U,2D]/C$P,#`L8VAR*#$U,BD]/C,S,RQC:'(H,34S*3T^,3`P,"P*
M("`@(&-H<B@Q-30I/3XU-38L8VAR*#$U-2D]/C,S,RQC:'(H,34V*3T^.30T
M+&-H<B@Q-3<I/3XS-3`L8VAR*#$U."D]/C4P,"QC:'(H,34Y*3T^-C8W+&-H
M<B@Q-C`I/3XR-S@L8VAR*#$V,2D]/C,S,RQC:'(H,38R*3T^-34V+&-H<B@Q
M-C,I/3XU-38L8VAR*#$V-"D]/C4U-BQC:'(H,38U*3T^-34V+&-H<B@Q-C8I
M/3XR.#`L8VAR*#$V-RD]/C4U-BQC:'(H,38X*3T^,S,S+&-H<B@Q-CDI/3XW
M,S<L8VAR*#$W,"D]/C,W,"QC:'(H,3<Q*3T^-34V+&-H<B@Q-S(I/3XU.#0L
M8VAR*#$W,RD]/C,S,RQC:'(H,3<T*3T^-S,W+&-H<B@Q-S4I/3XS,S,L"B`@
M("!C:'(H,3<V*3T^-#`P+&-H<B@Q-S<I/3XU.#0L8VAR*#$W."D]/C,S,RQC
M:'(H,3<Y*3T^,S,S+&-H<B@Q.#`I/3XS,S,L8VAR*#$X,2D]/C8Q,2QC:'(H
M,3@R*3T^-34V+&-H<B@Q.#,I/3XR-S@L8VAR*#$X-"D]/C,S,RQC:'(H,3@U
M*3T^,S,S+&-H<B@Q.#8I/3XS-C4L8VAR*#$X-RD]/C4U-BQC:'(H,3@X*3T^
M.#,T+&-H<B@Q.#DI/3XX,S0L8VAR*#$Y,"D]/C@S-"QC:'(H,3DQ*3T^-C$Q
M+&-H<B@Q.3(I/3XW,C(L8VAR*#$Y,RD]/C<R,BQC:'(H,3DT*3T^-S(R+&-H
M<B@Q.34I/3XW,C(L8VAR*#$Y-BD]/C<R,BQC:'(H,3DW*3T^-S(R+`H@("`@
M8VAR*#$Y."D]/C$P,#`L8VAR*#$Y.2D]/C<R,BQC:'(H,C`P*3T^-C8W+&-H
M<B@R,#$I/3XV-C<L8VAR*#(P,BD]/C8V-RQC:'(H,C`S*3T^-C8W+&-H<B@R
M,#0I/3XR-S@L8VAR*#(P-2D]/C(W."QC:'(H,C`V*3T^,C<X+&-H<B@R,#<I
M/3XR-S@L8VAR*#(P."D]/C<R,BQC:'(H,C`Y*3T^-S(R+&-H<B@R,3`I/3XW
M-S@L8VAR*#(Q,2D]/C<W."QC:'(H,C$R*3T^-S<X+&-H<B@R,3,I/3XW-S@L
M8VAR*#(Q-"D]/C<W."QC:'(H,C$U*3T^-3@T+&-H<B@R,38I/3XW-S@L8VAR
M*#(Q-RD]/C<R,BQC:'(H,C$X*3T^-S(R+&-H<B@R,3DI/3XW,C(L"B`@("!C
M:'(H,C(P*3T^-S(R+&-H<B@R,C$I/3XV-C<L8VAR*#(R,BD]/C8V-RQC:'(H
M,C(S*3T^-C$Q+&-H<B@R,C0I/3XU-38L8VAR*#(R-2D]/C4U-BQC:'(H,C(V
M*3T^-34V+&-H<B@R,C<I/3XU-38L8VAR*#(R."D]/C4U-BQC:'(H,C(Y*3T^
M-34V+&-H<B@R,S`I/3XX.#DL8VAR*#(S,2D]/C4U-BQC:'(H,C,R*3T^-34V
M+&-H<B@R,S,I/3XU-38L8VAR*#(S-"D]/C4U-BQC:'(H,C,U*3T^-34V+&-H
M<B@R,S8I/3XR-S@L8VAR*#(S-RD]/C(W."QC:'(H,C,X*3T^,C<X+&-H<B@R
M,SDI/3XR-S@L8VAR*#(T,"D]/C8Q,2QC:'(H,C0Q*3T^-C$Q+`H@("`@8VAR
M*#(T,BD]/C8Q,2QC:'(H,C0S*3T^-C$Q+&-H<B@R-#0I/3XV,3$L8VAR*#(T
M-2D]/C8Q,2QC:'(H,C0V*3T^-C$Q+&-H<B@R-#<I/3XU.#0L8VAR*#(T."D]
M/C8Q,2QC:'(H,C0Y*3T^-C$Q+&-H<B@R-3`I/3XV,3$L8VAR*#(U,2D]/C8Q
M,2QC:'(H,C4R*3T^-C$Q+&-H<B@R-3,I/3XU-38L8VAR*#(U-"D]/C8Q,2QC
M:'(H,C4U*3T^-34V*3L*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B]&:6QE+U!$1B]F;VYT<R]T:6UE<RYP:'``````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-C$W-R`Q,#4Q-30S,S<S-"`P
M,C(U-S0`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J($!P86-K86=E($9I;&5?4$1&"B`J+PHD9F]N=%]W
M:61T:'-;)W1I;65S)UT@/2!A<G)A>2@*("`@(&-H<B@P*3T^,C4P+&-H<B@Q
M*3T^,C4P+&-H<B@R*3T^,C4P+&-H<B@S*3T^,C4P+&-H<B@T*3T^,C4P+&-H
M<B@U*3T^,C4P+&-H<B@V*3T^,C4P+&-H<B@W*3T^,C4P+&-H<B@X*3T^,C4P
M+&-H<B@Y*3T^,C4P+&-H<B@Q,"D]/C(U,"QC:'(H,3$I/3XR-3`L8VAR*#$R
M*3T^,C4P+&-H<B@Q,RD]/C(U,"QC:'(H,30I/3XR-3`L8VAR*#$U*3T^,C4P
M+&-H<B@Q-BD]/C(U,"QC:'(H,3<I/3XR-3`L8VAR*#$X*3T^,C4P+&-H<B@Q
M.2D]/C(U,"QC:'(H,C`I/3XR-3`L8VAR*#(Q*3T^,C4P+`H@("`@8VAR*#(R
M*3T^,C4P+&-H<B@R,RD]/C(U,"QC:'(H,C0I/3XR-3`L8VAR*#(U*3T^,C4P
M+&-H<B@R-BD]/C(U,"QC:'(H,C<I/3XR-3`L8VAR*#(X*3T^,C4P+&-H<B@R
M.2D]/C(U,"QC:'(H,S`I/3XR-3`L8VAR*#,Q*3T^,C4P+"<@)ST^,C4P+"<A
M)ST^,S,S+"<B)ST^-#`X+"<C)ST^-3`P+"<D)ST^-3`P+"<E)ST^.#,S+"<F
M)ST^-S<X+"=<)R<]/C$X,"PG*"<]/C,S,RPG*2<]/C,S,RPG*B<]/C4P,"PG
M*R<]/C4V-"P*("`@("<L)ST^,C4P+"<M)ST^,S,S+"<N)ST^,C4P+"<O)ST^
M,C<X+"<P)ST^-3`P+"<Q)ST^-3`P+"<R)ST^-3`P+"<S)ST^-3`P+"<T)ST^
M-3`P+"<U)ST^-3`P+"<V)ST^-3`P+"<W)ST^-3`P+"<X)ST^-3`P+"<Y)ST^
M-3`P+"<Z)ST^,C<X+"<[)ST^,C<X+"<\)ST^-38T+"<])ST^-38T+"<^)ST^
M-38T+"<_)ST^-#0T+"=`)ST^.3(Q+"=!)ST^-S(R+`H@("`@)T(G/3XV-C<L
M)T,G/3XV-C<L)T0G/3XW,C(L)T4G/3XV,3$L)T8G/3XU-38L)T<G/3XW,C(L
M)T@G/3XW,C(L)TDG/3XS,S,L)THG/3XS.#DL)TLG/3XW,C(L)TPG/3XV,3$L
M)TTG/3XX.#DL)TXG/3XW,C(L)T\G/3XW,C(L)U`G/3XU-38L)U$G/3XW,C(L
M)U(G/3XV-C<L)U,G/3XU-38L)U0G/3XV,3$L)U4G/3XW,C(L)U8G/3XW,C(L
M)U<G/3XY-#0L"B`@("`G6"<]/C<R,BPG62<]/C<R,BPG6B<]/C8Q,2PG6R<]
M/C,S,RPG7%PG/3XR-S@L)UTG/3XS,S,L)UXG/3XT-CDL)U\G/3XU,#`L)V`G
M/3XS,S,L)V$G/3XT-#0L)V(G/3XU,#`L)V,G/3XT-#0L)V0G/3XU,#`L)V4G
M/3XT-#0L)V8G/3XS,S,L)V<G/3XU,#`L)V@G/3XU,#`L)VDG/3XR-S@L)VHG
M/3XR-S@L)VLG/3XU,#`L)VPG/3XR-S@L)VTG/3XW-S@L"B`@("`G;B<]/C4P
M,"PG;R<]/C4P,"PG<"<]/C4P,"PG<2<]/C4P,"PG<B<]/C,S,RPG<R<]/C,X
M.2PG="<]/C(W."PG=2<]/C4P,"PG=B<]/C4P,"PG=R<]/C<R,BPG>"<]/C4P
M,"PG>2<]/C4P,"PG>B<]/C0T-"PG>R<]/C0X,"PG?"<]/C(P,"PG?2<]/C0X
M,"PG?B<]/C4T,2QC:'(H,3(W*3T^,S4P+&-H<B@Q,C@I/3XU,#`L8VAR*#$R
M.2D]/C,U,"QC:'(H,3,P*3T^,S,S+&-H<B@Q,S$I/3XU,#`L"B`@("!C:'(H
M,3,R*3T^-#0T+&-H<B@Q,S,I/3XQ,#`P+&-H<B@Q,S0I/3XU,#`L8VAR*#$S
M-2D]/C4P,"QC:'(H,3,V*3T^,S,S+&-H<B@Q,S<I/3XQ,#`P+&-H<B@Q,S@I
M/3XU-38L8VAR*#$S.2D]/C,S,RQC:'(H,30P*3T^.#@Y+&-H<B@Q-#$I/3XS
M-3`L8VAR*#$T,BD]/C8Q,2QC:'(H,30S*3T^,S4P+&-H<B@Q-#0I/3XS-3`L
M8VAR*#$T-2D]/C,S,RQC:'(H,30V*3T^,S,S+&-H<B@Q-#<I/3XT-#0L8VAR
M*#$T."D]/C0T-"QC:'(H,30Y*3T^,S4P+&-H<B@Q-3`I/3XU,#`L8VAR*#$U
M,2D]/C$P,#`L8VAR*#$U,BD]/C,S,RQC:'(H,34S*3T^.3@P+`H@("`@8VAR
M*#$U-"D]/C,X.2QC:'(H,34U*3T^,S,S+&-H<B@Q-38I/3XW,C(L8VAR*#$U
M-RD]/C,U,"QC:'(H,34X*3T^-#0T+&-H<B@Q-3DI/3XW,C(L8VAR*#$V,"D]
M/C(U,"QC:'(H,38Q*3T^,S,S+&-H<B@Q-C(I/3XU,#`L8VAR*#$V,RD]/C4P
M,"QC:'(H,38T*3T^-3`P+&-H<B@Q-C4I/3XU,#`L8VAR*#$V-BD]/C(P,"QC
M:'(H,38W*3T^-3`P+&-H<B@Q-C@I/3XS,S,L8VAR*#$V.2D]/C<V,"QC:'(H
M,3<P*3T^,C<V+&-H<B@Q-S$I/3XU,#`L8VAR*#$W,BD]/C4V-"QC:'(H,3<S
M*3T^,S,S+&-H<B@Q-S0I/3XW-C`L8VAR*#$W-2D]/C,S,RP*("`@(&-H<B@Q
M-S8I/3XT,#`L8VAR*#$W-RD]/C4V-"QC:'(H,3<X*3T^,S`P+&-H<B@Q-SDI
M/3XS,#`L8VAR*#$X,"D]/C,S,RQC:'(H,3@Q*3T^-3`P+&-H<B@Q.#(I/3XT
M-3,L8VAR*#$X,RD]/C(U,"QC:'(H,3@T*3T^,S,S+&-H<B@Q.#4I/3XS,#`L
M8VAR*#$X-BD]/C,Q,"QC:'(H,3@W*3T^-3`P+&-H<B@Q.#@I/3XW-3`L8VAR
M*#$X.2D]/C<U,"QC:'(H,3DP*3T^-S4P+&-H<B@Q.3$I/3XT-#0L8VAR*#$Y
M,BD]/C<R,BQC:'(H,3DS*3T^-S(R+&-H<B@Q.30I/3XW,C(L8VAR*#$Y-2D]
M/C<R,BQC:'(H,3DV*3T^-S(R+&-H<B@Q.3<I/3XW,C(L"B`@("!C:'(H,3DX
M*3T^.#@Y+&-H<B@Q.3DI/3XV-C<L8VAR*#(P,"D]/C8Q,2QC:'(H,C`Q*3T^
M-C$Q+&-H<B@R,#(I/3XV,3$L8VAR*#(P,RD]/C8Q,2QC:'(H,C`T*3T^,S,S
M+&-H<B@R,#4I/3XS,S,L8VAR*#(P-BD]/C,S,RQC:'(H,C`W*3T^,S,S+&-H
M<B@R,#@I/3XW,C(L8VAR*#(P.2D]/C<R,BQC:'(H,C$P*3T^-S(R+&-H<B@R
M,3$I/3XW,C(L8VAR*#(Q,BD]/C<R,BQC:'(H,C$S*3T^-S(R+&-H<B@R,30I
M/3XW,C(L8VAR*#(Q-2D]/C4V-"QC:'(H,C$V*3T^-S(R+&-H<B@R,3<I/3XW
M,C(L8VAR*#(Q."D]/C<R,BQC:'(H,C$Y*3T^-S(R+`H@("`@8VAR*#(R,"D]
M/C<R,BQC:'(H,C(Q*3T^-S(R+&-H<B@R,C(I/3XU-38L8VAR*#(R,RD]/C4P
M,"QC:'(H,C(T*3T^-#0T+&-H<B@R,C4I/3XT-#0L8VAR*#(R-BD]/C0T-"QC
M:'(H,C(W*3T^-#0T+&-H<B@R,C@I/3XT-#0L8VAR*#(R.2D]/C0T-"QC:'(H
M,C,P*3T^-C8W+&-H<B@R,S$I/3XT-#0L8VAR*#(S,BD]/C0T-"QC:'(H,C,S
M*3T^-#0T+&-H<B@R,S0I/3XT-#0L8VAR*#(S-2D]/C0T-"QC:'(H,C,V*3T^
M,C<X+&-H<B@R,S<I/3XR-S@L8VAR*#(S."D]/C(W."QC:'(H,C,Y*3T^,C<X
M+&-H<B@R-#`I/3XU,#`L8VAR*#(T,2D]/C4P,"P*("`@(&-H<B@R-#(I/3XU
M,#`L8VAR*#(T,RD]/C4P,"QC:'(H,C0T*3T^-3`P+&-H<B@R-#4I/3XU,#`L
M8VAR*#(T-BD]/C4P,"QC:'(H,C0W*3T^-38T+&-H<B@R-#@I/3XU,#`L8VAR
M*#(T.2D]/C4P,"QC:'(H,C4P*3T^-3`P+&-H<B@R-3$I/3XU,#`L8VAR*#(U
M,BD]/C4P,"QC:'(H,C4S*3T^-3`P+&-H<B@R-30I/3XU,#`L8VAR*#(U-2D]
M/C4P,"D["@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O1FEL92]01$8O9F]N=',O>F%P9F1I;F=B871S+G!H
M<```````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#8P,S`@,3`U,34T,S,W,S0@
M,#(T,3$S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B!`<&%C:V%G92!&:6QE7U!$1@H@*B\*)&9O;G1?
M=VED=&AS6R=Z87!F9&EN9V)A=',G72`](&%R<F%Y*`H@("`@8VAR*#`I/3XP
M+&-H<B@Q*3T^,"QC:'(H,BD]/C`L8VAR*#,I/3XP+&-H<B@T*3T^,"QC:'(H
M-2D]/C`L8VAR*#8I/3XP+&-H<B@W*3T^,"QC:'(H."D]/C`L8VAR*#DI/3XP
M+&-H<B@Q,"D]/C`L8VAR*#$Q*3T^,"QC:'(H,3(I/3XP+&-H<B@Q,RD]/C`L
M8VAR*#$T*3T^,"QC:'(H,34I/3XP+&-H<B@Q-BD]/C`L8VAR*#$W*3T^,"QC
M:'(H,3@I/3XP+&-H<B@Q.2D]/C`L8VAR*#(P*3T^,"QC:'(H,C$I/3XP+`H@
M("`@8VAR*#(R*3T^,"QC:'(H,C,I/3XP+&-H<B@R-"D]/C`L8VAR*#(U*3T^
M,"QC:'(H,C8I/3XP+&-H<B@R-RD]/C`L8VAR*#(X*3T^,"QC:'(H,CDI/3XP
M+&-H<B@S,"D]/C`L8VAR*#,Q*3T^,"PG("<]/C(W."PG(2<]/CDW-"PG(B<]
M/CDV,2PG(R<]/CDW-"PG)"<]/CDX,"PG)2<]/C<Q.2PG)B<]/C<X.2PG7"<G
M/3XW.3`L)R@G/3XW.3$L)RDG/3XV.3`L)RHG/3XY-C`L)RLG/3XY,SDL"B`@
M("`G+"<]/C4T.2PG+2<]/C@U-2PG+B<]/CDQ,2PG+R<]/CDS,RPG,"<]/CDQ
M,2PG,2<]/CDT-2PG,B<]/CDW-"PG,R<]/C<U-2PG-"<]/C@T-BPG-2<]/C<V
M,BPG-B<]/C<V,2PG-R<]/C4W,2PG."<]/C8W-RPG.2<]/C<V,RPG.B<]/C<V
M,"PG.R<]/C<U.2PG/"<]/C<U-"PG/2<]/C0Y-"PG/B<]/C4U,BPG/R<]/C4S
M-RPG0"<]/C4W-RPG02<]/C8Y,BP*("`@("=")ST^-S@V+"=#)ST^-S@X+"=$
M)ST^-S@X+"=%)ST^-SDP+"=&)ST^-SDS+"=')ST^-SDT+"=()ST^.#$V+"=)
M)ST^.#(S+"=*)ST^-S@Y+"=+)ST^.#0Q+"=,)ST^.#(S+"=-)ST^.#,S+"=.
M)ST^.#$V+"=/)ST^.#,Q+"=0)ST^.3(S+"=1)ST^-S0T+"=2)ST^-S(S+"=3
M)ST^-S0Y+"=4)ST^-SDP+"=5)ST^-SDR+"=6)ST^-CDU+"=7)ST^-S<V+`H@
M("`@)U@G/3XW-C@L)UDG/3XW.3(L)UHG/3XW-3DL)ULG/3XW,#<L)UQ<)ST^
M-S`X+"==)ST^-C@R+"=>)ST^-S`Q+"=?)ST^.#(V+"=@)ST^.#$U+"=A)ST^
M-S@Y+"=B)ST^-S@Y+"=C)ST^-S`W+"=D)ST^-C@W+"=E)ST^-CDV+"=F)ST^
M-C@Y+"=G)ST^-S@V+"=H)ST^-S@W+"=I)ST^-S$S+"=J)ST^-SDQ+"=K)ST^
M-S@U+"=L)ST^-SDQ+"=M)ST^.#<S+`H@("`@)VXG/3XW-C$L)V\G/3XW-C(L
M)W`G/3XW-C(L)W$G/3XW-3DL)W(G/3XW-3DL)W,G/3XX.3(L)W0G/3XX.3(L
M)W4G/3XW.#@L)W8G/3XW.#0L)W<G/3XT,S@L)W@G/3XQ,S@L)WDG/3XR-S<L
M)WHG/3XT,34L)WLG/3XS.3(L)WPG/3XS.3(L)WTG/3XV-C@L)WXG/3XV-C@L
M8VAR*#$R-RD]/C`L8VAR*#$R."D]/C,Y,"QC:'(H,3(Y*3T^,SDP+&-H<B@Q
M,S`I/3XS,3<L8VAR*#$S,2D]/C,Q-RP*("`@(&-H<B@Q,S(I/3XR-S8L8VAR
M*#$S,RD]/C(W-BQC:'(H,3,T*3T^-3`Y+&-H<B@Q,S4I/3XU,#DL8VAR*#$S
M-BD]/C0Q,"QC:'(H,3,W*3T^-#$P+&-H<B@Q,S@I/3XR,S0L8VAR*#$S.2D]
M/C(S-"QC:'(H,30P*3T^,S,T+&-H<B@Q-#$I/3XS,S0L8VAR*#$T,BD]/C`L
M8VAR*#$T,RD]/C`L8VAR*#$T-"D]/C`L8VAR*#$T-2D]/C`L8VAR*#$T-BD]
M/C`L8VAR*#$T-RD]/C`L8VAR*#$T."D]/C`L8VAR*#$T.2D]/C`L8VAR*#$U
M,"D]/C`L8VAR*#$U,2D]/C`L8VAR*#$U,BD]/C`L8VAR*#$U,RD]/C`L"B`@
M("!C:'(H,34T*3T^,"QC:'(H,34U*3T^,"QC:'(H,34V*3T^,"QC:'(H,34W
M*3T^,"QC:'(H,34X*3T^,"QC:'(H,34Y*3T^,"QC:'(H,38P*3T^,"QC:'(H
M,38Q*3T^-S,R+&-H<B@Q-C(I/3XU-#0L8VAR*#$V,RD]/C4T-"QC:'(H,38T
M*3T^.3$P+&-H<B@Q-C4I/3XV-C<L8VAR*#$V-BD]/C<V,"QC:'(H,38W*3T^
M-S8P+&-H<B@Q-C@I/3XW-S8L8VAR*#$V.2D]/C4Y-2QC:'(H,3<P*3T^-CDT
M+&-H<B@Q-S$I/3XV,C8L8VAR*#$W,BD]/C<X."QC:'(H,3<S*3T^-S@X+&-H
M<B@Q-S0I/3XW.#@L8VAR*#$W-2D]/C<X."P*("`@(&-H<B@Q-S8I/3XW.#@L
M8VAR*#$W-RD]/C<X."QC:'(H,3<X*3T^-S@X+&-H<B@Q-SDI/3XW.#@L8VAR
M*#$X,"D]/C<X."QC:'(H,3@Q*3T^-S@X+&-H<B@Q.#(I/3XW.#@L8VAR*#$X
M,RD]/C<X."QC:'(H,3@T*3T^-S@X+&-H<B@Q.#4I/3XW.#@L8VAR*#$X-BD]
M/C<X."QC:'(H,3@W*3T^-S@X+&-H<B@Q.#@I/3XW.#@L8VAR*#$X.2D]/C<X
M."QC:'(H,3DP*3T^-S@X+&-H<B@Q.3$I/3XW.#@L8VAR*#$Y,BD]/C<X."QC
M:'(H,3DS*3T^-S@X+&-H<B@Q.30I/3XW.#@L8VAR*#$Y-2D]/C<X."QC:'(H
M,3DV*3T^-S@X+&-H<B@Q.3<I/3XW.#@L"B`@("!C:'(H,3DX*3T^-S@X+&-H
M<B@Q.3DI/3XW.#@L8VAR*#(P,"D]/C<X."QC:'(H,C`Q*3T^-S@X+&-H<B@R
M,#(I/3XW.#@L8VAR*#(P,RD]/C<X."QC:'(H,C`T*3T^-S@X+&-H<B@R,#4I
M/3XW.#@L8VAR*#(P-BD]/C<X."QC:'(H,C`W*3T^-S@X+&-H<B@R,#@I/3XW
M.#@L8VAR*#(P.2D]/C<X."QC:'(H,C$P*3T^-S@X+&-H<B@R,3$I/3XW.#@L
M8VAR*#(Q,BD]/C@Y-"QC:'(H,C$S*3T^.#,X+&-H<B@R,30I/3XQ,#$V+&-H
M<B@R,34I/3XT-3@L8VAR*#(Q-BD]/C<T."QC:'(H,C$W*3T^.3(T+&-H<B@R
M,3@I/3XW-#@L8VAR*#(Q.2D]/CDQ."P*("`@(&-H<B@R,C`I/3XY,C<L8VAR
M*#(R,2D]/CDR."QC:'(H,C(R*3T^.3(X+&-H<B@R,C,I/3XX,S0L8VAR*#(R
M-"D]/C@W,RQC:'(H,C(U*3T^.#(X+&-H<B@R,C8I/3XY,C0L8VAR*#(R-RD]
M/CDR-"QC:'(H,C(X*3T^.3$W+&-H<B@R,CDI/3XY,S`L8VAR*#(S,"D]/CDS
M,2QC:'(H,C,Q*3T^-#8S+&-H<B@R,S(I/3XX.#,L8VAR*#(S,RD]/C@S-BQC
M:'(H,C,T*3T^.#,V+&-H<B@R,S4I/3XX-C<L8VAR*#(S-BD]/C@V-RQC:'(H
M,C,W*3T^-CDV+&-H<B@R,S@I/3XV.38L8VAR*#(S.2D]/C@W-"QC:'(H,C0P
M*3T^,"QC:'(H,C0Q*3T^.#<T+`H@("`@8VAR*#(T,BD]/C<V,"QC:'(H,C0S
M*3T^.30V+&-H<B@R-#0I/3XW-S$L8VAR*#(T-2D]/C@V-2QC:'(H,C0V*3T^
M-S<Q+&-H<B@R-#<I/3XX.#@L8VAR*#(T."D]/CDV-RQC:'(H,C0Y*3T^.#@X
M+&-H<B@R-3`I/3XX,S$L8VAR*#(U,2D]/C@W,RQC:'(H,C4R*3T^.3(W+&-H
M<B@R-3,I/3XY-S`L8VAR*#(U-"D]/CDQ."QC:'(H,C4U*3T^,"D["@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+T9I;&4O4$1&+V9O;G1S+W1I;65S8BYP:'``````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`V,C`U(#$P-3$U-#,S-S,T
M(#`R,C<R-@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@0'!A8VMA9V4@1FEL95]01$8*("HO"B1F;VYT
M7W=I9'1H<ULG=&EM97-")UT@/2!A<G)A>2@*("`@(&-H<B@P*3T^,C4P+&-H
M<B@Q*3T^,C4P+&-H<B@R*3T^,C4P+&-H<B@S*3T^,C4P+&-H<B@T*3T^,C4P
M+&-H<B@U*3T^,C4P+&-H<B@V*3T^,C4P+&-H<B@W*3T^,C4P+&-H<B@X*3T^
M,C4P+&-H<B@Y*3T^,C4P+&-H<B@Q,"D]/C(U,"QC:'(H,3$I/3XR-3`L8VAR
M*#$R*3T^,C4P+&-H<B@Q,RD]/C(U,"QC:'(H,30I/3XR-3`L8VAR*#$U*3T^
M,C4P+&-H<B@Q-BD]/C(U,"QC:'(H,3<I/3XR-3`L8VAR*#$X*3T^,C4P+&-H
M<B@Q.2D]/C(U,"QC:'(H,C`I/3XR-3`L8VAR*#(Q*3T^,C4P+`H@("`@8VAR
M*#(R*3T^,C4P+&-H<B@R,RD]/C(U,"QC:'(H,C0I/3XR-3`L8VAR*#(U*3T^
M,C4P+&-H<B@R-BD]/C(U,"QC:'(H,C<I/3XR-3`L8VAR*#(X*3T^,C4P+&-H
M<B@R.2D]/C(U,"QC:'(H,S`I/3XR-3`L8VAR*#,Q*3T^,C4P+"<@)ST^,C4P
M+"<A)ST^,S,S+"<B)ST^-34U+"<C)ST^-3`P+"<D)ST^-3`P+"<E)ST^,3`P
M,"PG)B<]/C@S,RPG7"<G/3XR-S@L)R@G/3XS,S,L)RDG/3XS,S,L)RHG/3XU
M,#`L)RLG/3XU-S`L"B`@("`G+"<]/C(U,"PG+2<]/C,S,RPG+B<]/C(U,"PG
M+R<]/C(W."PG,"<]/C4P,"PG,2<]/C4P,"PG,B<]/C4P,"PG,R<]/C4P,"PG
M-"<]/C4P,"PG-2<]/C4P,"PG-B<]/C4P,"PG-R<]/C4P,"PG."<]/C4P,"PG
M.2<]/C4P,"PG.B<]/C,S,RPG.R<]/C,S,RPG/"<]/C4W,"PG/2<]/C4W,"PG
M/B<]/C4W,"PG/R<]/C4P,"PG0"<]/CDS,"PG02<]/C<R,BP*("`@("=")ST^
M-C8W+"=#)ST^-S(R+"=$)ST^-S(R+"=%)ST^-C8W+"=&)ST^-C$Q+"=')ST^
M-S<X+"=()ST^-S<X+"=))ST^,S@Y+"=*)ST^-3`P+"=+)ST^-S<X+"=,)ST^
M-C8W+"=-)ST^.30T+"=.)ST^-S(R+"=/)ST^-S<X+"=0)ST^-C$Q+"=1)ST^
M-S<X+"=2)ST^-S(R+"=3)ST^-34V+"=4)ST^-C8W+"=5)ST^-S(R+"=6)ST^
M-S(R+"=7)ST^,3`P,"P*("`@("=8)ST^-S(R+"=9)ST^-S(R+"=:)ST^-C8W
M+"=;)ST^,S,S+"=<7"<]/C(W."PG72<]/C,S,RPG7B<]/C4X,2PG7R<]/C4P
M,"PG8"<]/C,S,RPG82<]/C4P,"PG8B<]/C4U-BPG8R<]/C0T-"PG9"<]/C4U
M-BPG92<]/C0T-"PG9B<]/C,S,RPG9R<]/C4P,"PG:"<]/C4U-BPG:2<]/C(W
M."PG:B<]/C,S,RPG:R<]/C4U-BPG;"<]/C(W."PG;2<]/C@S,RP*("`@("=N
M)ST^-34V+"=O)ST^-3`P+"=P)ST^-34V+"=Q)ST^-34V+"=R)ST^-#0T+"=S
M)ST^,S@Y+"=T)ST^,S,S+"=U)ST^-34V+"=V)ST^-3`P+"=W)ST^-S(R+"=X
M)ST^-3`P+"=Y)ST^-3`P+"=Z)ST^-#0T+"=[)ST^,SDT+"=\)ST^,C(P+"=]
M)ST^,SDT+"=^)ST^-3(P+&-H<B@Q,C<I/3XS-3`L8VAR*#$R."D]/C4P,"QC
M:'(H,3(Y*3T^,S4P+&-H<B@Q,S`I/3XS,S,L8VAR*#$S,2D]/C4P,"P*("`@
M(&-H<B@Q,S(I/3XU,#`L8VAR*#$S,RD]/C$P,#`L8VAR*#$S-"D]/C4P,"QC
M:'(H,3,U*3T^-3`P+&-H<B@Q,S8I/3XS,S,L8VAR*#$S-RD]/C$P,#`L8VAR
M*#$S."D]/C4U-BQC:'(H,3,Y*3T^,S,S+&-H<B@Q-#`I/3XQ,#`P+&-H<B@Q
M-#$I/3XS-3`L8VAR*#$T,BD]/C8V-RQC:'(H,30S*3T^,S4P+&-H<B@Q-#0I
M/3XS-3`L8VAR*#$T-2D]/C,S,RQC:'(H,30V*3T^,S,S+&-H<B@Q-#<I/3XU
M,#`L8VAR*#$T."D]/C4P,"QC:'(H,30Y*3T^,S4P+&-H<B@Q-3`I/3XU,#`L
M8VAR*#$U,2D]/C$P,#`L8VAR*#$U,BD]/C,S,RQC:'(H,34S*3T^,3`P,"P*
M("`@(&-H<B@Q-30I/3XS.#DL8VAR*#$U-2D]/C,S,RQC:'(H,34V*3T^-S(R
M+&-H<B@Q-3<I/3XS-3`L8VAR*#$U."D]/C0T-"QC:'(H,34Y*3T^-S(R+&-H
M<B@Q-C`I/3XR-3`L8VAR*#$V,2D]/C,S,RQC:'(H,38R*3T^-3`P+&-H<B@Q
M-C,I/3XU,#`L8VAR*#$V-"D]/C4P,"QC:'(H,38U*3T^-3`P+&-H<B@Q-C8I
M/3XR,C`L8VAR*#$V-RD]/C4P,"QC:'(H,38X*3T^,S,S+&-H<B@Q-CDI/3XW
M-#<L8VAR*#$W,"D]/C,P,"QC:'(H,3<Q*3T^-3`P+&-H<B@Q-S(I/3XU-S`L
M8VAR*#$W,RD]/C,S,RQC:'(H,3<T*3T^-S0W+&-H<B@Q-S4I/3XS,S,L"B`@
M("!C:'(H,3<V*3T^-#`P+&-H<B@Q-S<I/3XU-S`L8VAR*#$W."D]/C,P,"QC
M:'(H,3<Y*3T^,S`P+&-H<B@Q.#`I/3XS,S,L8VAR*#$X,2D]/C4U-BQC:'(H
M,3@R*3T^-30P+&-H<B@Q.#,I/3XR-3`L8VAR*#$X-"D]/C,S,RQC:'(H,3@U
M*3T^,S`P+&-H<B@Q.#8I/3XS,S`L8VAR*#$X-RD]/C4P,"QC:'(H,3@X*3T^
M-S4P+&-H<B@Q.#DI/3XW-3`L8VAR*#$Y,"D]/C<U,"QC:'(H,3DQ*3T^-3`P
M+&-H<B@Q.3(I/3XW,C(L8VAR*#$Y,RD]/C<R,BQC:'(H,3DT*3T^-S(R+&-H
M<B@Q.34I/3XW,C(L8VAR*#$Y-BD]/C<R,BQC:'(H,3DW*3T^-S(R+`H@("`@
M8VAR*#$Y."D]/C$P,#`L8VAR*#$Y.2D]/C<R,BQC:'(H,C`P*3T^-C8W+&-H
M<B@R,#$I/3XV-C<L8VAR*#(P,BD]/C8V-RQC:'(H,C`S*3T^-C8W+&-H<B@R
M,#0I/3XS.#DL8VAR*#(P-2D]/C,X.2QC:'(H,C`V*3T^,S@Y+&-H<B@R,#<I
M/3XS.#DL8VAR*#(P."D]/C<R,BQC:'(H,C`Y*3T^-S(R+&-H<B@R,3`I/3XW
M-S@L8VAR*#(Q,2D]/C<W."QC:'(H,C$R*3T^-S<X+&-H<B@R,3,I/3XW-S@L
M8VAR*#(Q-"D]/C<W."QC:'(H,C$U*3T^-3<P+&-H<B@R,38I/3XW-S@L8VAR
M*#(Q-RD]/C<R,BQC:'(H,C$X*3T^-S(R+&-H<B@R,3DI/3XW,C(L"B`@("!C
M:'(H,C(P*3T^-S(R+&-H<B@R,C$I/3XW,C(L8VAR*#(R,BD]/C8Q,2QC:'(H
M,C(S*3T^-34V+&-H<B@R,C0I/3XU,#`L8VAR*#(R-2D]/C4P,"QC:'(H,C(V
M*3T^-3`P+&-H<B@R,C<I/3XU,#`L8VAR*#(R."D]/C4P,"QC:'(H,C(Y*3T^
M-3`P+&-H<B@R,S`I/3XW,C(L8VAR*#(S,2D]/C0T-"QC:'(H,C,R*3T^-#0T
M+&-H<B@R,S,I/3XT-#0L8VAR*#(S-"D]/C0T-"QC:'(H,C,U*3T^-#0T+&-H
M<B@R,S8I/3XR-S@L8VAR*#(S-RD]/C(W."QC:'(H,C,X*3T^,C<X+&-H<B@R
M,SDI/3XR-S@L8VAR*#(T,"D]/C4P,"QC:'(H,C0Q*3T^-34V+`H@("`@8VAR
M*#(T,BD]/C4P,"QC:'(H,C0S*3T^-3`P+&-H<B@R-#0I/3XU,#`L8VAR*#(T
M-2D]/C4P,"QC:'(H,C0V*3T^-3`P+&-H<B@R-#<I/3XU-S`L8VAR*#(T."D]
M/C4P,"QC:'(H,C0Y*3T^-34V+&-H<B@R-3`I/3XU-38L8VAR*#(U,2D]/C4U
M-BQC:'(H,C4R*3T^-34V+&-H<B@R-3,I/3XU,#`L8VAR*#(U-"D]/C4U-BQC
M:'(H,C4U*3T^-3`P*3L*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B]&:6QE+U!$1B]F;VYT<R]T:6UE<VDN<&AP````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-C$W-B`Q,#4Q-30S,S<S
M-"`P,C(W-#0`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J($!P86-K86=E($9I;&5?4$1&"B`J+PHD9F]N
M=%]W:61T:'-;)W1I;65S22==(#T@87)R87DH"B`@("!C:'(H,"D]/C(U,"QC
M:'(H,2D]/C(U,"QC:'(H,BD]/C(U,"QC:'(H,RD]/C(U,"QC:'(H-"D]/C(U
M,"QC:'(H-2D]/C(U,"QC:'(H-BD]/C(U,"QC:'(H-RD]/C(U,"QC:'(H."D]
M/C(U,"QC:'(H.2D]/C(U,"QC:'(H,3`I/3XR-3`L8VAR*#$Q*3T^,C4P+&-H
M<B@Q,BD]/C(U,"QC:'(H,3,I/3XR-3`L8VAR*#$T*3T^,C4P+&-H<B@Q-2D]
M/C(U,"QC:'(H,38I/3XR-3`L8VAR*#$W*3T^,C4P+&-H<B@Q."D]/C(U,"QC
M:'(H,3DI/3XR-3`L8VAR*#(P*3T^,C4P+&-H<B@R,2D]/C(U,"P*("`@(&-H
M<B@R,BD]/C(U,"QC:'(H,C,I/3XR-3`L8VAR*#(T*3T^,C4P+&-H<B@R-2D]
M/C(U,"QC:'(H,C8I/3XR-3`L8VAR*#(W*3T^,C4P+&-H<B@R."D]/C(U,"QC
M:'(H,CDI/3XR-3`L8VAR*#,P*3T^,C4P+&-H<B@S,2D]/C(U,"PG("<]/C(U
M,"PG(2<]/C,S,RPG(B<]/C0R,"PG(R<]/C4P,"PG)"<]/C4P,"PG)2<]/C@S
M,RPG)B<]/C<W."PG7"<G/3XR,30L)R@G/3XS,S,L)RDG/3XS,S,L)RHG/3XU
M,#`L)RLG/3XV-S4L"B`@("`G+"<]/C(U,"PG+2<]/C,S,RPG+B<]/C(U,"PG
M+R<]/C(W."PG,"<]/C4P,"PG,2<]/C4P,"PG,B<]/C4P,"PG,R<]/C4P,"PG
M-"<]/C4P,"PG-2<]/C4P,"PG-B<]/C4P,"PG-R<]/C4P,"PG."<]/C4P,"PG
M.2<]/C4P,"PG.B<]/C,S,RPG.R<]/C,S,RPG/"<]/C8W-2PG/2<]/C8W-2PG
M/B<]/C8W-2PG/R<]/C4P,"PG0"<]/CDR,"PG02<]/C8Q,2P*("`@("=")ST^
M-C$Q+"=#)ST^-C8W+"=$)ST^-S(R+"=%)ST^-C$Q+"=&)ST^-C$Q+"=')ST^
M-S(R+"=()ST^-S(R+"=))ST^,S,S+"=*)ST^-#0T+"=+)ST^-C8W+"=,)ST^
M-34V+"=-)ST^.#,S+"=.)ST^-C8W+"=/)ST^-S(R+"=0)ST^-C$Q+"=1)ST^
M-S(R+"=2)ST^-C$Q+"=3)ST^-3`P+"=4)ST^-34V+"=5)ST^-S(R+"=6)ST^
M-C$Q+"=7)ST^.#,S+`H@("`@)U@G/3XV,3$L)UDG/3XU-38L)UHG/3XU-38L
M)ULG/3XS.#DL)UQ<)ST^,C<X+"==)ST^,S@Y+"=>)ST^-#(R+"=?)ST^-3`P
M+"=@)ST^,S,S+"=A)ST^-3`P+"=B)ST^-3`P+"=C)ST^-#0T+"=D)ST^-3`P
M+"=E)ST^-#0T+"=F)ST^,C<X+"=G)ST^-3`P+"=H)ST^-3`P+"=I)ST^,C<X
M+"=J)ST^,C<X+"=K)ST^-#0T+"=L)ST^,C<X+"=M)ST^-S(R+`H@("`@)VXG
M/3XU,#`L)V\G/3XU,#`L)W`G/3XU,#`L)W$G/3XU,#`L)W(G/3XS.#DL)W,G
M/3XS.#DL)W0G/3XR-S@L)W4G/3XU,#`L)W8G/3XT-#0L)W<G/3XV-C<L)W@G
M/3XT-#0L)WDG/3XT-#0L)WHG/3XS.#DL)WLG/3XT,#`L)WPG/3XR-S4L)WTG
M/3XT,#`L)WXG/3XU-#$L8VAR*#$R-RD]/C,U,"QC:'(H,3(X*3T^-3`P+&-H
M<B@Q,CDI/3XS-3`L8VAR*#$S,"D]/C,S,RQC:'(H,3,Q*3T^-3`P+`H@("`@
M8VAR*#$S,BD]/C4U-BQC:'(H,3,S*3T^.#@Y+&-H<B@Q,S0I/3XU,#`L8VAR
M*#$S-2D]/C4P,"QC:'(H,3,V*3T^,S,S+&-H<B@Q,S<I/3XQ,#`P+&-H<B@Q
M,S@I/3XU,#`L8VAR*#$S.2D]/C,S,RQC:'(H,30P*3T^.30T+&-H<B@Q-#$I
M/3XS-3`L8VAR*#$T,BD]/C4U-BQC:'(H,30S*3T^,S4P+&-H<B@Q-#0I/3XS
M-3`L8VAR*#$T-2D]/C,S,RQC:'(H,30V*3T^,S,S+&-H<B@Q-#<I/3XU-38L
M8VAR*#$T."D]/C4U-BQC:'(H,30Y*3T^,S4P+&-H<B@Q-3`I/3XU,#`L8VAR
M*#$U,2D]/C@X.2QC:'(H,34R*3T^,S,S+&-H<B@Q-3,I/3XY.#`L"B`@("!C
M:'(H,34T*3T^,S@Y+&-H<B@Q-34I/3XS,S,L8VAR*#$U-BD]/C8V-RQC:'(H
M,34W*3T^,S4P+&-H<B@Q-3@I/3XS.#DL8VAR*#$U.2D]/C4U-BQC:'(H,38P
M*3T^,C4P+&-H<B@Q-C$I/3XS.#DL8VAR*#$V,BD]/C4P,"QC:'(H,38S*3T^
M-3`P+&-H<B@Q-C0I/3XU,#`L8VAR*#$V-2D]/C4P,"QC:'(H,38V*3T^,C<U
M+&-H<B@Q-C<I/3XU,#`L8VAR*#$V."D]/C,S,RQC:'(H,38Y*3T^-S8P+&-H
M<B@Q-S`I/3XR-S8L8VAR*#$W,2D]/C4P,"QC:'(H,3<R*3T^-C<U+&-H<B@Q
M-S,I/3XS,S,L8VAR*#$W-"D]/C<V,"QC:'(H,3<U*3T^,S,S+`H@("`@8VAR
M*#$W-BD]/C0P,"QC:'(H,3<W*3T^-C<U+&-H<B@Q-S@I/3XS,#`L8VAR*#$W
M.2D]/C,P,"QC:'(H,3@P*3T^,S,S+&-H<B@Q.#$I/3XU,#`L8VAR*#$X,BD]
M/C4R,RQC:'(H,3@S*3T^,C4P+&-H<B@Q.#0I/3XS,S,L8VAR*#$X-2D]/C,P
M,"QC:'(H,3@V*3T^,S$P+&-H<B@Q.#<I/3XU,#`L8VAR*#$X."D]/C<U,"QC
M:'(H,3@Y*3T^-S4P+&-H<B@Q.3`I/3XW-3`L8VAR*#$Y,2D]/C4P,"QC:'(H
M,3DR*3T^-C$Q+&-H<B@Q.3,I/3XV,3$L8VAR*#$Y-"D]/C8Q,2QC:'(H,3DU
M*3T^-C$Q+&-H<B@Q.38I/3XV,3$L8VAR*#$Y-RD]/C8Q,2P*("`@(&-H<B@Q
M.3@I/3XX.#DL8VAR*#$Y.2D]/C8V-RQC:'(H,C`P*3T^-C$Q+&-H<B@R,#$I
M/3XV,3$L8VAR*#(P,BD]/C8Q,2QC:'(H,C`S*3T^-C$Q+&-H<B@R,#0I/3XS
M,S,L8VAR*#(P-2D]/C,S,RQC:'(H,C`V*3T^,S,S+&-H<B@R,#<I/3XS,S,L
M8VAR*#(P."D]/C<R,BQC:'(H,C`Y*3T^-C8W+&-H<B@R,3`I/3XW,C(L8VAR
M*#(Q,2D]/C<R,BQC:'(H,C$R*3T^-S(R+&-H<B@R,3,I/3XW,C(L8VAR*#(Q
M-"D]/C<R,BQC:'(H,C$U*3T^-C<U+&-H<B@R,38I/3XW,C(L8VAR*#(Q-RD]
M/C<R,BQC:'(H,C$X*3T^-S(R+&-H<B@R,3DI/3XW,C(L"B`@("!C:'(H,C(P
M*3T^-S(R+&-H<B@R,C$I/3XU-38L8VAR*#(R,BD]/C8Q,2QC:'(H,C(S*3T^
M-3`P+&-H<B@R,C0I/3XU,#`L8VAR*#(R-2D]/C4P,"QC:'(H,C(V*3T^-3`P
M+&-H<B@R,C<I/3XU,#`L8VAR*#(R."D]/C4P,"QC:'(H,C(Y*3T^-3`P+&-H
M<B@R,S`I/3XV-C<L8VAR*#(S,2D]/C0T-"QC:'(H,C,R*3T^-#0T+&-H<B@R
M,S,I/3XT-#0L8VAR*#(S-"D]/C0T-"QC:'(H,C,U*3T^-#0T+&-H<B@R,S8I
M/3XR-S@L8VAR*#(S-RD]/C(W."QC:'(H,C,X*3T^,C<X+&-H<B@R,SDI/3XR
M-S@L8VAR*#(T,"D]/C4P,"QC:'(H,C0Q*3T^-3`P+`H@("`@8VAR*#(T,BD]
M/C4P,"QC:'(H,C0S*3T^-3`P+&-H<B@R-#0I/3XU,#`L8VAR*#(T-2D]/C4P
M,"QC:'(H,C0V*3T^-3`P+&-H<B@R-#<I/3XV-S4L8VAR*#(T."D]/C4P,"QC
M:'(H,C0Y*3T^-3`P+&-H<B@R-3`I/3XU,#`L8VAR*#(U,2D]/C4P,"QC:'(H
M,C4R*3T^-3`P+&-H<B@R-3,I/3XT-#0L8VAR*#(U-"D]/C4P,"QC:'(H,C4U
M*3T^-#0T*3L*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O1FEL92]01$8O9F]N=',O:&5L=F5T:6-A8BYP
M:'``````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#8R,#<@,3`U,34T,S,W
M,S0@,#(S-34S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!`<&%C:V%G92!&:6QE7U!$1@H@*B\*)&9O
M;G1?=VED=&AS6R=H96QV971I8V%")UT@/2!A<G)A>2@*("`@(&-H<B@P*3T^
M,C<X+&-H<B@Q*3T^,C<X+&-H<B@R*3T^,C<X+&-H<B@S*3T^,C<X+&-H<B@T
M*3T^,C<X+&-H<B@U*3T^,C<X+&-H<B@V*3T^,C<X+&-H<B@W*3T^,C<X+&-H
M<B@X*3T^,C<X+&-H<B@Y*3T^,C<X+&-H<B@Q,"D]/C(W."QC:'(H,3$I/3XR
M-S@L8VAR*#$R*3T^,C<X+&-H<B@Q,RD]/C(W."QC:'(H,30I/3XR-S@L8VAR
M*#$U*3T^,C<X+&-H<B@Q-BD]/C(W."QC:'(H,3<I/3XR-S@L8VAR*#$X*3T^
M,C<X+&-H<B@Q.2D]/C(W."QC:'(H,C`I/3XR-S@L8VAR*#(Q*3T^,C<X+`H@
M("`@8VAR*#(R*3T^,C<X+&-H<B@R,RD]/C(W."QC:'(H,C0I/3XR-S@L8VAR
M*#(U*3T^,C<X+&-H<B@R-BD]/C(W."QC:'(H,C<I/3XR-S@L8VAR*#(X*3T^
M,C<X+&-H<B@R.2D]/C(W."QC:'(H,S`I/3XR-S@L8VAR*#,Q*3T^,C<X+"<@
M)ST^,C<X+"<A)ST^,S,S+"<B)ST^-#<T+"<C)ST^-34V+"<D)ST^-34V+"<E
M)ST^.#@Y+"<F)ST^-S(R+"=<)R<]/C(S."PG*"<]/C,S,RPG*2<]/C,S,RPG
M*B<]/C,X.2PG*R<]/C4X-"P*("`@("<L)ST^,C<X+"<M)ST^,S,S+"<N)ST^
M,C<X+"<O)ST^,C<X+"<P)ST^-34V+"<Q)ST^-34V+"<R)ST^-34V+"<S)ST^
M-34V+"<T)ST^-34V+"<U)ST^-34V+"<V)ST^-34V+"<W)ST^-34V+"<X)ST^
M-34V+"<Y)ST^-34V+"<Z)ST^,S,S+"<[)ST^,S,S+"<\)ST^-3@T+"<])ST^
M-3@T+"<^)ST^-3@T+"<_)ST^-C$Q+"=`)ST^.3<U+"=!)ST^-S(R+`H@("`@
M)T(G/3XW,C(L)T,G/3XW,C(L)T0G/3XW,C(L)T4G/3XV-C<L)T8G/3XV,3$L
M)T<G/3XW-S@L)T@G/3XW,C(L)TDG/3XR-S@L)THG/3XU-38L)TLG/3XW,C(L
M)TPG/3XV,3$L)TTG/3XX,S,L)TXG/3XW,C(L)T\G/3XW-S@L)U`G/3XV-C<L
M)U$G/3XW-S@L)U(G/3XW,C(L)U,G/3XV-C<L)U0G/3XV,3$L)U4G/3XW,C(L
M)U8G/3XV-C<L)U<G/3XY-#0L"B`@("`G6"<]/C8V-RPG62<]/C8V-RPG6B<]
M/C8Q,2PG6R<]/C,S,RPG7%PG/3XR-S@L)UTG/3XS,S,L)UXG/3XU.#0L)U\G
M/3XU-38L)V`G/3XS,S,L)V$G/3XU-38L)V(G/3XV,3$L)V,G/3XU-38L)V0G
M/3XV,3$L)V4G/3XU-38L)V8G/3XS,S,L)V<G/3XV,3$L)V@G/3XV,3$L)VDG
M/3XR-S@L)VHG/3XR-S@L)VLG/3XU-38L)VPG/3XR-S@L)VTG/3XX.#DL"B`@
M("`G;B<]/C8Q,2PG;R<]/C8Q,2PG<"<]/C8Q,2PG<2<]/C8Q,2PG<B<]/C,X
M.2PG<R<]/C4U-BPG="<]/C,S,RPG=2<]/C8Q,2PG=B<]/C4U-BPG=R<]/C<W
M."PG>"<]/C4U-BPG>2<]/C4U-BPG>B<]/C4P,"PG>R<]/C,X.2PG?"<]/C(X
M,"PG?2<]/C,X.2PG?B<]/C4X-"QC:'(H,3(W*3T^,S4P+&-H<B@Q,C@I/3XU
M-38L8VAR*#$R.2D]/C,U,"QC:'(H,3,P*3T^,C<X+&-H<B@Q,S$I/3XU-38L
M"B`@("!C:'(H,3,R*3T^-3`P+&-H<B@Q,S,I/3XQ,#`P+&-H<B@Q,S0I/3XU
M-38L8VAR*#$S-2D]/C4U-BQC:'(H,3,V*3T^,S,S+&-H<B@Q,S<I/3XQ,#`P
M+&-H<B@Q,S@I/3XV-C<L8VAR*#$S.2D]/C,S,RQC:'(H,30P*3T^,3`P,"QC
M:'(H,30Q*3T^,S4P+&-H<B@Q-#(I/3XV,3$L8VAR*#$T,RD]/C,U,"QC:'(H
M,30T*3T^,S4P+&-H<B@Q-#4I/3XR-S@L8VAR*#$T-BD]/C(W."QC:'(H,30W
M*3T^-3`P+&-H<B@Q-#@I/3XU,#`L8VAR*#$T.2D]/C,U,"QC:'(H,34P*3T^
M-34V+&-H<B@Q-3$I/3XQ,#`P+&-H<B@Q-3(I/3XS,S,L8VAR*#$U,RD]/C$P
M,#`L"B`@("!C:'(H,34T*3T^-34V+&-H<B@Q-34I/3XS,S,L8VAR*#$U-BD]
M/CDT-"QC:'(H,34W*3T^,S4P+&-H<B@Q-3@I/3XU,#`L8VAR*#$U.2D]/C8V
M-RQC:'(H,38P*3T^,C<X+&-H<B@Q-C$I/3XS,S,L8VAR*#$V,BD]/C4U-BQC
M:'(H,38S*3T^-34V+&-H<B@Q-C0I/3XU-38L8VAR*#$V-2D]/C4U-BQC:'(H
M,38V*3T^,C@P+&-H<B@Q-C<I/3XU-38L8VAR*#$V."D]/C,S,RQC:'(H,38Y
M*3T^-S,W+&-H<B@Q-S`I/3XS-S`L8VAR*#$W,2D]/C4U-BQC:'(H,3<R*3T^
M-3@T+&-H<B@Q-S,I/3XS,S,L8VAR*#$W-"D]/C<S-RQC:'(H,3<U*3T^,S,S
M+`H@("`@8VAR*#$W-BD]/C0P,"QC:'(H,3<W*3T^-3@T+&-H<B@Q-S@I/3XS
M,S,L8VAR*#$W.2D]/C,S,RQC:'(H,3@P*3T^,S,S+&-H<B@Q.#$I/3XV,3$L
M8VAR*#$X,BD]/C4U-BQC:'(H,3@S*3T^,C<X+&-H<B@Q.#0I/3XS,S,L8VAR
M*#$X-2D]/C,S,RQC:'(H,3@V*3T^,S8U+&-H<B@Q.#<I/3XU-38L8VAR*#$X
M."D]/C@S-"QC:'(H,3@Y*3T^.#,T+&-H<B@Q.3`I/3XX,S0L8VAR*#$Y,2D]
M/C8Q,2QC:'(H,3DR*3T^-S(R+&-H<B@Q.3,I/3XW,C(L8VAR*#$Y-"D]/C<R
M,BQC:'(H,3DU*3T^-S(R+&-H<B@Q.38I/3XW,C(L8VAR*#$Y-RD]/C<R,BP*
M("`@(&-H<B@Q.3@I/3XQ,#`P+&-H<B@Q.3DI/3XW,C(L8VAR*#(P,"D]/C8V
M-RQC:'(H,C`Q*3T^-C8W+&-H<B@R,#(I/3XV-C<L8VAR*#(P,RD]/C8V-RQC
M:'(H,C`T*3T^,C<X+&-H<B@R,#4I/3XR-S@L8VAR*#(P-BD]/C(W."QC:'(H
M,C`W*3T^,C<X+&-H<B@R,#@I/3XW,C(L8VAR*#(P.2D]/C<R,BQC:'(H,C$P
M*3T^-S<X+&-H<B@R,3$I/3XW-S@L8VAR*#(Q,BD]/C<W."QC:'(H,C$S*3T^
M-S<X+&-H<B@R,30I/3XW-S@L8VAR*#(Q-2D]/C4X-"QC:'(H,C$V*3T^-S<X
M+&-H<B@R,3<I/3XW,C(L8VAR*#(Q."D]/C<R,BQC:'(H,C$Y*3T^-S(R+`H@
M("`@8VAR*#(R,"D]/C<R,BQC:'(H,C(Q*3T^-C8W+&-H<B@R,C(I/3XV-C<L
M8VAR*#(R,RD]/C8Q,2QC:'(H,C(T*3T^-34V+&-H<B@R,C4I/3XU-38L8VAR
M*#(R-BD]/C4U-BQC:'(H,C(W*3T^-34V+&-H<B@R,C@I/3XU-38L8VAR*#(R
M.2D]/C4U-BQC:'(H,C,P*3T^.#@Y+&-H<B@R,S$I/3XU-38L8VAR*#(S,BD]
M/C4U-BQC:'(H,C,S*3T^-34V+&-H<B@R,S0I/3XU-38L8VAR*#(S-2D]/C4U
M-BQC:'(H,C,V*3T^,C<X+&-H<B@R,S<I/3XR-S@L8VAR*#(S."D]/C(W."QC
M:'(H,C,Y*3T^,C<X+&-H<B@R-#`I/3XV,3$L8VAR*#(T,2D]/C8Q,2P*("`@
M(&-H<B@R-#(I/3XV,3$L8VAR*#(T,RD]/C8Q,2QC:'(H,C0T*3T^-C$Q+&-H
M<B@R-#4I/3XV,3$L8VAR*#(T-BD]/C8Q,2QC:'(H,C0W*3T^-3@T+&-H<B@R
M-#@I/3XV,3$L8VAR*#(T.2D]/C8Q,2QC:'(H,C4P*3T^-C$Q+&-H<B@R-3$I
M/3XV,3$L8VAR*#(U,BD]/C8Q,2QC:'(H,C4S*3T^-34V+&-H<B@R-30I/3XV
M,3$L8VAR*#(U-2D]/C4U-BD["@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+T9I;&4O4$1&+V9O;G1S+VAE;'9E=&EC86DN
M<&AP````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`V,C$P(#$P-3$U-#,S
M-S,T(#`R,S4U-``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@0'!A8VMA9V4@1FEL95]01$8*("HO"B1F
M;VYT7W=I9'1H<ULG:&5L=F5T:6-A22==(#T@87)R87DH"B`@("!C:'(H,"D]
M/C(W."QC:'(H,2D]/C(W."QC:'(H,BD]/C(W."QC:'(H,RD]/C(W."QC:'(H
M-"D]/C(W."QC:'(H-2D]/C(W."QC:'(H-BD]/C(W."QC:'(H-RD]/C(W."QC
M:'(H."D]/C(W."QC:'(H.2D]/C(W."QC:'(H,3`I/3XR-S@L8VAR*#$Q*3T^
M,C<X+&-H<B@Q,BD]/C(W."QC:'(H,3,I/3XR-S@L8VAR*#$T*3T^,C<X+&-H
M<B@Q-2D]/C(W."QC:'(H,38I/3XR-S@L8VAR*#$W*3T^,C<X+&-H<B@Q."D]
M/C(W."QC:'(H,3DI/3XR-S@L8VAR*#(P*3T^,C<X+&-H<B@R,2D]/C(W."P*
M("`@(&-H<B@R,BD]/C(W."QC:'(H,C,I/3XR-S@L8VAR*#(T*3T^,C<X+&-H
M<B@R-2D]/C(W."QC:'(H,C8I/3XR-S@L8VAR*#(W*3T^,C<X+&-H<B@R."D]
M/C(W."QC:'(H,CDI/3XR-S@L8VAR*#,P*3T^,C<X+&-H<B@S,2D]/C(W."PG
M("<]/C(W."PG(2<]/C(W."PG(B<]/C,U-2PG(R<]/C4U-BPG)"<]/C4U-BPG
M)2<]/C@X.2PG)B<]/C8V-RPG7"<G/3XQ.3$L)R@G/3XS,S,L)RDG/3XS,S,L
M)RHG/3XS.#DL)RLG/3XU.#0L"B`@("`G+"<]/C(W."PG+2<]/C,S,RPG+B<]
M/C(W."PG+R<]/C(W."PG,"<]/C4U-BPG,2<]/C4U-BPG,B<]/C4U-BPG,R<]
M/C4U-BPG-"<]/C4U-BPG-2<]/C4U-BPG-B<]/C4U-BPG-R<]/C4U-BPG."<]
M/C4U-BPG.2<]/C4U-BPG.B<]/C(W."PG.R<]/C(W."PG/"<]/C4X-"PG/2<]
M/C4X-"PG/B<]/C4X-"PG/R<]/C4U-BPG0"<]/C$P,34L)T$G/3XV-C<L"B`@
M("`G0B<]/C8V-RPG0R<]/C<R,BPG1"<]/C<R,BPG12<]/C8V-RPG1B<]/C8Q
M,2PG1R<]/C<W."PG2"<]/C<R,BPG22<]/C(W."PG2B<]/C4P,"PG2R<]/C8V
M-RPG3"<]/C4U-BPG32<]/C@S,RPG3B<]/C<R,BPG3R<]/C<W."PG4"<]/C8V
M-RPG42<]/C<W."PG4B<]/C<R,BPG4R<]/C8V-RPG5"<]/C8Q,2PG52<]/C<R
M,BPG5B<]/C8V-RPG5R<]/CDT-"P*("`@("=8)ST^-C8W+"=9)ST^-C8W+"=:
M)ST^-C$Q+"=;)ST^,C<X+"=<7"<]/C(W."PG72<]/C(W."PG7B<]/C0V.2PG
M7R<]/C4U-BPG8"<]/C,S,RPG82<]/C4U-BPG8B<]/C4U-BPG8R<]/C4P,"PG
M9"<]/C4U-BPG92<]/C4U-BPG9B<]/C(W."PG9R<]/C4U-BPG:"<]/C4U-BPG
M:2<]/C(R,BPG:B<]/C(R,BPG:R<]/C4P,"PG;"<]/C(R,BPG;2<]/C@S,RP*
M("`@("=N)ST^-34V+"=O)ST^-34V+"=P)ST^-34V+"=Q)ST^-34V+"=R)ST^
M,S,S+"=S)ST^-3`P+"=T)ST^,C<X+"=U)ST^-34V+"=V)ST^-3`P+"=W)ST^
M-S(R+"=X)ST^-3`P+"=Y)ST^-3`P+"=Z)ST^-3`P+"=[)ST^,S,T+"=\)ST^
M,C8P+"=])ST^,S,T+"=^)ST^-3@T+&-H<B@Q,C<I/3XS-3`L8VAR*#$R."D]
M/C4U-BQC:'(H,3(Y*3T^,S4P+&-H<B@Q,S`I/3XR,C(L8VAR*#$S,2D]/C4U
M-BP*("`@(&-H<B@Q,S(I/3XS,S,L8VAR*#$S,RD]/C$P,#`L8VAR*#$S-"D]
M/C4U-BQC:'(H,3,U*3T^-34V+&-H<B@Q,S8I/3XS,S,L8VAR*#$S-RD]/C$P
M,#`L8VAR*#$S."D]/C8V-RQC:'(H,3,Y*3T^,S,S+&-H<B@Q-#`I/3XQ,#`P
M+&-H<B@Q-#$I/3XS-3`L8VAR*#$T,BD]/C8Q,2QC:'(H,30S*3T^,S4P+&-H
M<B@Q-#0I/3XS-3`L8VAR*#$T-2D]/C(R,BQC:'(H,30V*3T^,C(R+&-H<B@Q
M-#<I/3XS,S,L8VAR*#$T."D]/C,S,RQC:'(H,30Y*3T^,S4P+&-H<B@Q-3`I
M/3XU-38L8VAR*#$U,2D]/C$P,#`L8VAR*#$U,BD]/C,S,RQC:'(H,34S*3T^
M,3`P,"P*("`@(&-H<B@Q-30I/3XU,#`L8VAR*#$U-2D]/C,S,RQC:'(H,34V
M*3T^.30T+&-H<B@Q-3<I/3XS-3`L8VAR*#$U."D]/C4P,"QC:'(H,34Y*3T^
M-C8W+&-H<B@Q-C`I/3XR-S@L8VAR*#$V,2D]/C,S,RQC:'(H,38R*3T^-34V
M+&-H<B@Q-C,I/3XU-38L8VAR*#$V-"D]/C4U-BQC:'(H,38U*3T^-34V+&-H
M<B@Q-C8I/3XR-C`L8VAR*#$V-RD]/C4U-BQC:'(H,38X*3T^,S,S+&-H<B@Q
M-CDI/3XW,S<L8VAR*#$W,"D]/C,W,"QC:'(H,3<Q*3T^-34V+&-H<B@Q-S(I
M/3XU.#0L8VAR*#$W,RD]/C,S,RQC:'(H,3<T*3T^-S,W+&-H<B@Q-S4I/3XS
M,S,L"B`@("!C:'(H,3<V*3T^-#`P+&-H<B@Q-S<I/3XU.#0L8VAR*#$W."D]
M/C,S,RQC:'(H,3<Y*3T^,S,S+&-H<B@Q.#`I/3XS,S,L8VAR*#$X,2D]/C4U
M-BQC:'(H,3@R*3T^-3,W+&-H<B@Q.#,I/3XR-S@L8VAR*#$X-"D]/C,S,RQC
M:'(H,3@U*3T^,S,S+&-H<B@Q.#8I/3XS-C4L8VAR*#$X-RD]/C4U-BQC:'(H
M,3@X*3T^.#,T+&-H<B@Q.#DI/3XX,S0L8VAR*#$Y,"D]/C@S-"QC:'(H,3DQ
M*3T^-C$Q+&-H<B@Q.3(I/3XV-C<L8VAR*#$Y,RD]/C8V-RQC:'(H,3DT*3T^
M-C8W+&-H<B@Q.34I/3XV-C<L8VAR*#$Y-BD]/C8V-RQC:'(H,3DW*3T^-C8W
M+`H@("`@8VAR*#$Y."D]/C$P,#`L8VAR*#$Y.2D]/C<R,BQC:'(H,C`P*3T^
M-C8W+&-H<B@R,#$I/3XV-C<L8VAR*#(P,BD]/C8V-RQC:'(H,C`S*3T^-C8W
M+&-H<B@R,#0I/3XR-S@L8VAR*#(P-2D]/C(W."QC:'(H,C`V*3T^,C<X+&-H
M<B@R,#<I/3XR-S@L8VAR*#(P."D]/C<R,BQC:'(H,C`Y*3T^-S(R+&-H<B@R
M,3`I/3XW-S@L8VAR*#(Q,2D]/C<W."QC:'(H,C$R*3T^-S<X+&-H<B@R,3,I
M/3XW-S@L8VAR*#(Q-"D]/C<W."QC:'(H,C$U*3T^-3@T+&-H<B@R,38I/3XW
M-S@L8VAR*#(Q-RD]/C<R,BQC:'(H,C$X*3T^-S(R+&-H<B@R,3DI/3XW,C(L
M"B`@("!C:'(H,C(P*3T^-S(R+&-H<B@R,C$I/3XV-C<L8VAR*#(R,BD]/C8V
M-RQC:'(H,C(S*3T^-C$Q+&-H<B@R,C0I/3XU-38L8VAR*#(R-2D]/C4U-BQC
M:'(H,C(V*3T^-34V+&-H<B@R,C<I/3XU-38L8VAR*#(R."D]/C4U-BQC:'(H
M,C(Y*3T^-34V+&-H<B@R,S`I/3XX.#DL8VAR*#(S,2D]/C4P,"QC:'(H,C,R
M*3T^-34V+&-H<B@R,S,I/3XU-38L8VAR*#(S-"D]/C4U-BQC:'(H,C,U*3T^
M-34V+&-H<B@R,S8I/3XR-S@L8VAR*#(S-RD]/C(W."QC:'(H,C,X*3T^,C<X
M+&-H<B@R,SDI/3XR-S@L8VAR*#(T,"D]/C4U-BQC:'(H,C0Q*3T^-34V+`H@
M("`@8VAR*#(T,BD]/C4U-BQC:'(H,C0S*3T^-34V+&-H<B@R-#0I/3XU-38L
M8VAR*#(T-2D]/C4U-BQC:'(H,C0V*3T^-34V+&-H<B@R-#<I/3XU.#0L8VAR
M*#(T."D]/C8Q,2QC:'(H,C0Y*3T^-34V+&-H<B@R-3`I/3XU-38L8VAR*#(U
M,2D]/C4U-BQC:'(H,C4R*3T^-34V+&-H<B@R-3,I/3XU,#`L8VAR*#(U-"D]
M/C4U-BQC:'(H,C4U*3T^-3`P*3L*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B]&:6QE+U!$1B]F;VYT<R]T:6UE<V)I+G!H
M<```````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-C(P,B`Q,#4Q-30S
M,S<S-"`P,C,P-S0`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J($!P86-K86=E($9I;&5?4$1&"B`J+PHD
M9F]N=%]W:61T:'-;)W1I;65S0DDG72`](&%R<F%Y*`H@("`@8VAR*#`I/3XR
M-3`L8VAR*#$I/3XR-3`L8VAR*#(I/3XR-3`L8VAR*#,I/3XR-3`L8VAR*#0I
M/3XR-3`L8VAR*#4I/3XR-3`L8VAR*#8I/3XR-3`L8VAR*#<I/3XR-3`L8VAR
M*#@I/3XR-3`L8VAR*#DI/3XR-3`L8VAR*#$P*3T^,C4P+&-H<B@Q,2D]/C(U
M,"QC:'(H,3(I/3XR-3`L8VAR*#$S*3T^,C4P+&-H<B@Q-"D]/C(U,"QC:'(H
M,34I/3XR-3`L8VAR*#$V*3T^,C4P+&-H<B@Q-RD]/C(U,"QC:'(H,3@I/3XR
M-3`L8VAR*#$Y*3T^,C4P+&-H<B@R,"D]/C(U,"QC:'(H,C$I/3XR-3`L"B`@
M("!C:'(H,C(I/3XR-3`L8VAR*#(S*3T^,C4P+&-H<B@R-"D]/C(U,"QC:'(H
M,C4I/3XR-3`L8VAR*#(V*3T^,C4P+&-H<B@R-RD]/C(U,"QC:'(H,C@I/3XR
M-3`L8VAR*#(Y*3T^,C4P+&-H<B@S,"D]/C(U,"QC:'(H,S$I/3XR-3`L)R`G
M/3XR-3`L)R$G/3XS.#DL)R(G/3XU-34L)R,G/3XU,#`L)R0G/3XU,#`L)R4G
M/3XX,S,L)R8G/3XW-S@L)UPG)ST^,C<X+"<H)ST^,S,S+"<I)ST^,S,S+"<J
M)ST^-3`P+"<K)ST^-3<P+`H@("`@)RPG/3XR-3`L)RTG/3XS,S,L)RXG/3XR
M-3`L)R\G/3XR-S@L)S`G/3XU,#`L)S$G/3XU,#`L)S(G/3XU,#`L)S,G/3XU
M,#`L)S0G/3XU,#`L)S4G/3XU,#`L)S8G/3XU,#`L)S<G/3XU,#`L)S@G/3XU
M,#`L)SDG/3XU,#`L)SHG/3XS,S,L)SLG/3XS,S,L)SPG/3XU-S`L)STG/3XU
M-S`L)SXG/3XU-S`L)S\G/3XU,#`L)T`G/3XX,S(L)T$G/3XV-C<L"B`@("`G
M0B<]/C8V-RPG0R<]/C8V-RPG1"<]/C<R,BPG12<]/C8V-RPG1B<]/C8V-RPG
M1R<]/C<R,BPG2"<]/C<W."PG22<]/C,X.2PG2B<]/C4P,"PG2R<]/C8V-RPG
M3"<]/C8Q,2PG32<]/C@X.2PG3B<]/C<R,BPG3R<]/C<R,BPG4"<]/C8Q,2PG
M42<]/C<R,BPG4B<]/C8V-RPG4R<]/C4U-BPG5"<]/C8Q,2PG52<]/C<R,BPG
M5B<]/C8V-RPG5R<]/C@X.2P*("`@("=8)ST^-C8W+"=9)ST^-C$Q+"=:)ST^
M-C$Q+"=;)ST^,S,S+"=<7"<]/C(W."PG72<]/C,S,RPG7B<]/C4W,"PG7R<]
M/C4P,"PG8"<]/C,S,RPG82<]/C4P,"PG8B<]/C4P,"PG8R<]/C0T-"PG9"<]
M/C4P,"PG92<]/C0T-"PG9B<]/C,S,RPG9R<]/C4P,"PG:"<]/C4U-BPG:2<]
M/C(W."PG:B<]/C(W."PG:R<]/C4P,"PG;"<]/C(W."PG;2<]/C<W."P*("`@
M("=N)ST^-34V+"=O)ST^-3`P+"=P)ST^-3`P+"=Q)ST^-3`P+"=R)ST^,S@Y
M+"=S)ST^,S@Y+"=T)ST^,C<X+"=U)ST^-34V+"=V)ST^-#0T+"=W)ST^-C8W
M+"=X)ST^-3`P+"=Y)ST^-#0T+"=Z)ST^,S@Y+"=[)ST^,S0X+"=\)ST^,C(P
M+"=])ST^,S0X+"=^)ST^-3<P+&-H<B@Q,C<I/3XS-3`L8VAR*#$R."D]/C4P
M,"QC:'(H,3(Y*3T^,S4P+&-H<B@Q,S`I/3XS,S,L8VAR*#$S,2D]/C4P,"P*
M("`@(&-H<B@Q,S(I/3XU,#`L8VAR*#$S,RD]/C$P,#`L8VAR*#$S-"D]/C4P
M,"QC:'(H,3,U*3T^-3`P+&-H<B@Q,S8I/3XS,S,L8VAR*#$S-RD]/C$P,#`L
M8VAR*#$S."D]/C4U-BQC:'(H,3,Y*3T^,S,S+&-H<B@Q-#`I/3XY-#0L8VAR
M*#$T,2D]/C,U,"QC:'(H,30R*3T^-C$Q+&-H<B@Q-#,I/3XS-3`L8VAR*#$T
M-"D]/C,U,"QC:'(H,30U*3T^,S,S+&-H<B@Q-#8I/3XS,S,L8VAR*#$T-RD]
M/C4P,"QC:'(H,30X*3T^-3`P+&-H<B@Q-#DI/3XS-3`L8VAR*#$U,"D]/C4P
M,"QC:'(H,34Q*3T^,3`P,"QC:'(H,34R*3T^,S,S+&-H<B@Q-3,I/3XQ,#`P
M+`H@("`@8VAR*#$U-"D]/C,X.2QC:'(H,34U*3T^,S,S+&-H<B@Q-38I/3XW
M,C(L8VAR*#$U-RD]/C,U,"QC:'(H,34X*3T^,S@Y+&-H<B@Q-3DI/3XV,3$L
M8VAR*#$V,"D]/C(U,"QC:'(H,38Q*3T^,S@Y+&-H<B@Q-C(I/3XU,#`L8VAR
M*#$V,RD]/C4P,"QC:'(H,38T*3T^-3`P+&-H<B@Q-C4I/3XU,#`L8VAR*#$V
M-BD]/C(R,"QC:'(H,38W*3T^-3`P+&-H<B@Q-C@I/3XS,S,L8VAR*#$V.2D]
M/C<T-RQC:'(H,3<P*3T^,C8V+&-H<B@Q-S$I/3XU,#`L8VAR*#$W,BD]/C8P
M-BQC:'(H,3<S*3T^,S,S+&-H<B@Q-S0I/3XW-#<L8VAR*#$W-2D]/C,S,RP*
M("`@(&-H<B@Q-S8I/3XT,#`L8VAR*#$W-RD]/C4W,"QC:'(H,3<X*3T^,S`P
M+&-H<B@Q-SDI/3XS,#`L8VAR*#$X,"D]/C,S,RQC:'(H,3@Q*3T^-3<V+&-H
M<B@Q.#(I/3XU,#`L8VAR*#$X,RD]/C(U,"QC:'(H,3@T*3T^,S,S+&-H<B@Q
M.#4I/3XS,#`L8VAR*#$X-BD]/C,P,"QC:'(H,3@W*3T^-3`P+&-H<B@Q.#@I
M/3XW-3`L8VAR*#$X.2D]/C<U,"QC:'(H,3DP*3T^-S4P+&-H<B@Q.3$I/3XU
M,#`L8VAR*#$Y,BD]/C8V-RQC:'(H,3DS*3T^-C8W+&-H<B@Q.30I/3XV-C<L
M8VAR*#$Y-2D]/C8V-RQC:'(H,3DV*3T^-C8W+&-H<B@Q.3<I/3XV-C<L"B`@
M("!C:'(H,3DX*3T^.30T+&-H<B@Q.3DI/3XV-C<L8VAR*#(P,"D]/C8V-RQC
M:'(H,C`Q*3T^-C8W+&-H<B@R,#(I/3XV-C<L8VAR*#(P,RD]/C8V-RQC:'(H
M,C`T*3T^,S@Y+&-H<B@R,#4I/3XS.#DL8VAR*#(P-BD]/C,X.2QC:'(H,C`W
M*3T^,S@Y+&-H<B@R,#@I/3XW,C(L8VAR*#(P.2D]/C<R,BQC:'(H,C$P*3T^
M-S(R+&-H<B@R,3$I/3XW,C(L8VAR*#(Q,BD]/C<R,BQC:'(H,C$S*3T^-S(R
M+&-H<B@R,30I/3XW,C(L8VAR*#(Q-2D]/C4W,"QC:'(H,C$V*3T^-S(R+&-H
M<B@R,3<I/3XW,C(L8VAR*#(Q."D]/C<R,BQC:'(H,C$Y*3T^-S(R+`H@("`@
M8VAR*#(R,"D]/C<R,BQC:'(H,C(Q*3T^-C$Q+&-H<B@R,C(I/3XV,3$L8VAR
M*#(R,RD]/C4P,"QC:'(H,C(T*3T^-3`P+&-H<B@R,C4I/3XU,#`L8VAR*#(R
M-BD]/C4P,"QC:'(H,C(W*3T^-3`P+&-H<B@R,C@I/3XU,#`L8VAR*#(R.2D]
M/C4P,"QC:'(H,C,P*3T^-S(R+&-H<B@R,S$I/3XT-#0L8VAR*#(S,BD]/C0T
M-"QC:'(H,C,S*3T^-#0T+&-H<B@R,S0I/3XT-#0L8VAR*#(S-2D]/C0T-"QC
M:'(H,C,V*3T^,C<X+&-H<B@R,S<I/3XR-S@L8VAR*#(S."D]/C(W."QC:'(H
M,C,Y*3T^,C<X+&-H<B@R-#`I/3XU,#`L8VAR*#(T,2D]/C4U-BP*("`@(&-H
M<B@R-#(I/3XU,#`L8VAR*#(T,RD]/C4P,"QC:'(H,C0T*3T^-3`P+&-H<B@R
M-#4I/3XU,#`L8VAR*#(T-BD]/C4P,"QC:'(H,C0W*3T^-3<P+&-H<B@R-#@I
M/3XU,#`L8VAR*#(T.2D]/C4U-BQC:'(H,C4P*3T^-34V+&-H<B@R-3$I/3XU
M-38L8VAR*#(U,BD]/C4U-BQC:'(H,C4S*3T^-#0T+&-H<B@R-30I/3XU,#`L
M8VAR*#(U-2D]/C0T-"D["@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O1FEL92]01$8O9F]N=',O:&5L=F5T:6-A
M+G!H<```````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#8R,#<@,3`U,34T
M,S,W,S0@,#(S-#$Q`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B!`<&%C:V%G92!&:6QE7U!$1@H@*B\*
M)&9O;G1?=VED=&AS6R=H96QV971I8V$G72`](&%R<F%Y*`H@("`@8VAR*#`I
M/3XR-S@L8VAR*#$I/3XR-S@L8VAR*#(I/3XR-S@L8VAR*#,I/3XR-S@L8VAR
M*#0I/3XR-S@L8VAR*#4I/3XR-S@L8VAR*#8I/3XR-S@L8VAR*#<I/3XR-S@L
M8VAR*#@I/3XR-S@L8VAR*#DI/3XR-S@L8VAR*#$P*3T^,C<X+&-H<B@Q,2D]
M/C(W."QC:'(H,3(I/3XR-S@L8VAR*#$S*3T^,C<X+&-H<B@Q-"D]/C(W."QC
M:'(H,34I/3XR-S@L8VAR*#$V*3T^,C<X+&-H<B@Q-RD]/C(W."QC:'(H,3@I
M/3XR-S@L8VAR*#$Y*3T^,C<X+&-H<B@R,"D]/C(W."QC:'(H,C$I/3XR-S@L
M"B`@("!C:'(H,C(I/3XR-S@L8VAR*#(S*3T^,C<X+&-H<B@R-"D]/C(W."QC
M:'(H,C4I/3XR-S@L8VAR*#(V*3T^,C<X+&-H<B@R-RD]/C(W."QC:'(H,C@I
M/3XR-S@L8VAR*#(Y*3T^,C<X+&-H<B@S,"D]/C(W."QC:'(H,S$I/3XR-S@L
M)R`G/3XR-S@L)R$G/3XR-S@L)R(G/3XS-34L)R,G/3XU-38L)R0G/3XU-38L
M)R4G/3XX.#DL)R8G/3XV-C<L)UPG)ST^,3DQ+"<H)ST^,S,S+"<I)ST^,S,S
M+"<J)ST^,S@Y+"<K)ST^-3@T+`H@("`@)RPG/3XR-S@L)RTG/3XS,S,L)RXG
M/3XR-S@L)R\G/3XR-S@L)S`G/3XU-38L)S$G/3XU-38L)S(G/3XU-38L)S,G
M/3XU-38L)S0G/3XU-38L)S4G/3XU-38L)S8G/3XU-38L)S<G/3XU-38L)S@G
M/3XU-38L)SDG/3XU-38L)SHG/3XR-S@L)SLG/3XR-S@L)SPG/3XU.#0L)STG
M/3XU.#0L)SXG/3XU.#0L)S\G/3XU-38L)T`G/3XQ,#$U+"=!)ST^-C8W+`H@
M("`@)T(G/3XV-C<L)T,G/3XW,C(L)T0G/3XW,C(L)T4G/3XV-C<L)T8G/3XV
M,3$L)T<G/3XW-S@L)T@G/3XW,C(L)TDG/3XR-S@L)THG/3XU,#`L)TLG/3XV
M-C<L)TPG/3XU-38L)TTG/3XX,S,L)TXG/3XW,C(L)T\G/3XW-S@L)U`G/3XV
M-C<L)U$G/3XW-S@L)U(G/3XW,C(L)U,G/3XV-C<L)U0G/3XV,3$L)U4G/3XW
M,C(L)U8G/3XV-C<L)U<G/3XY-#0L"B`@("`G6"<]/C8V-RPG62<]/C8V-RPG
M6B<]/C8Q,2PG6R<]/C(W."PG7%PG/3XR-S@L)UTG/3XR-S@L)UXG/3XT-CDL
M)U\G/3XU-38L)V`G/3XS,S,L)V$G/3XU-38L)V(G/3XU-38L)V,G/3XU,#`L
M)V0G/3XU-38L)V4G/3XU-38L)V8G/3XR-S@L)V<G/3XU-38L)V@G/3XU-38L
M)VDG/3XR,C(L)VHG/3XR,C(L)VLG/3XU,#`L)VPG/3XR,C(L)VTG/3XX,S,L
M"B`@("`G;B<]/C4U-BPG;R<]/C4U-BPG<"<]/C4U-BPG<2<]/C4U-BPG<B<]
M/C,S,RPG<R<]/C4P,"PG="<]/C(W."PG=2<]/C4U-BPG=B<]/C4P,"PG=R<]
M/C<R,BPG>"<]/C4P,"PG>2<]/C4P,"PG>B<]/C4P,"PG>R<]/C,S-"PG?"<]
M/C(V,"PG?2<]/C,S-"PG?B<]/C4X-"QC:'(H,3(W*3T^,S4P+&-H<B@Q,C@I
M/3XU-38L8VAR*#$R.2D]/C,U,"QC:'(H,3,P*3T^,C(R+&-H<B@Q,S$I/3XU
M-38L"B`@("!C:'(H,3,R*3T^,S,S+&-H<B@Q,S,I/3XQ,#`P+&-H<B@Q,S0I
M/3XU-38L8VAR*#$S-2D]/C4U-BQC:'(H,3,V*3T^,S,S+&-H<B@Q,S<I/3XQ
M,#`P+&-H<B@Q,S@I/3XV-C<L8VAR*#$S.2D]/C,S,RQC:'(H,30P*3T^,3`P
M,"QC:'(H,30Q*3T^,S4P+&-H<B@Q-#(I/3XV,3$L8VAR*#$T,RD]/C,U,"QC
M:'(H,30T*3T^,S4P+&-H<B@Q-#4I/3XR,C(L8VAR*#$T-BD]/C(R,BQC:'(H
M,30W*3T^,S,S+&-H<B@Q-#@I/3XS,S,L8VAR*#$T.2D]/C,U,"QC:'(H,34P
M*3T^-34V+&-H<B@Q-3$I/3XQ,#`P+&-H<B@Q-3(I/3XS,S,L8VAR*#$U,RD]
M/C$P,#`L"B`@("!C:'(H,34T*3T^-3`P+&-H<B@Q-34I/3XS,S,L8VAR*#$U
M-BD]/CDT-"QC:'(H,34W*3T^,S4P+&-H<B@Q-3@I/3XU,#`L8VAR*#$U.2D]
M/C8V-RQC:'(H,38P*3T^,C<X+&-H<B@Q-C$I/3XS,S,L8VAR*#$V,BD]/C4U
M-BQC:'(H,38S*3T^-34V+&-H<B@Q-C0I/3XU-38L8VAR*#$V-2D]/C4U-BQC
M:'(H,38V*3T^,C8P+&-H<B@Q-C<I/3XU-38L8VAR*#$V."D]/C,S,RQC:'(H
M,38Y*3T^-S,W+&-H<B@Q-S`I/3XS-S`L8VAR*#$W,2D]/C4U-BQC:'(H,3<R
M*3T^-3@T+&-H<B@Q-S,I/3XS,S,L8VAR*#$W-"D]/C<S-RQC:'(H,3<U*3T^
M,S,S+`H@("`@8VAR*#$W-BD]/C0P,"QC:'(H,3<W*3T^-3@T+&-H<B@Q-S@I
M/3XS,S,L8VAR*#$W.2D]/C,S,RQC:'(H,3@P*3T^,S,S+&-H<B@Q.#$I/3XU
M-38L8VAR*#$X,BD]/C4S-RQC:'(H,3@S*3T^,C<X+&-H<B@Q.#0I/3XS,S,L
M8VAR*#$X-2D]/C,S,RQC:'(H,3@V*3T^,S8U+&-H<B@Q.#<I/3XU-38L8VAR
M*#$X."D]/C@S-"QC:'(H,3@Y*3T^.#,T+&-H<B@Q.3`I/3XX,S0L8VAR*#$Y
M,2D]/C8Q,2QC:'(H,3DR*3T^-C8W+&-H<B@Q.3,I/3XV-C<L8VAR*#$Y-"D]
M/C8V-RQC:'(H,3DU*3T^-C8W+&-H<B@Q.38I/3XV-C<L8VAR*#$Y-RD]/C8V
M-RP*("`@(&-H<B@Q.3@I/3XQ,#`P+&-H<B@Q.3DI/3XW,C(L8VAR*#(P,"D]
M/C8V-RQC:'(H,C`Q*3T^-C8W+&-H<B@R,#(I/3XV-C<L8VAR*#(P,RD]/C8V
M-RQC:'(H,C`T*3T^,C<X+&-H<B@R,#4I/3XR-S@L8VAR*#(P-BD]/C(W."QC
M:'(H,C`W*3T^,C<X+&-H<B@R,#@I/3XW,C(L8VAR*#(P.2D]/C<R,BQC:'(H
M,C$P*3T^-S<X+&-H<B@R,3$I/3XW-S@L8VAR*#(Q,BD]/C<W."QC:'(H,C$S
M*3T^-S<X+&-H<B@R,30I/3XW-S@L8VAR*#(Q-2D]/C4X-"QC:'(H,C$V*3T^
M-S<X+&-H<B@R,3<I/3XW,C(L8VAR*#(Q."D]/C<R,BQC:'(H,C$Y*3T^-S(R
M+`H@("`@8VAR*#(R,"D]/C<R,BQC:'(H,C(Q*3T^-C8W+&-H<B@R,C(I/3XV
M-C<L8VAR*#(R,RD]/C8Q,2QC:'(H,C(T*3T^-34V+&-H<B@R,C4I/3XU-38L
M8VAR*#(R-BD]/C4U-BQC:'(H,C(W*3T^-34V+&-H<B@R,C@I/3XU-38L8VAR
M*#(R.2D]/C4U-BQC:'(H,C,P*3T^.#@Y+&-H<B@R,S$I/3XU,#`L8VAR*#(S
M,BD]/C4U-BQC:'(H,C,S*3T^-34V+&-H<B@R,S0I/3XU-38L8VAR*#(S-2D]
M/C4U-BQC:'(H,C,V*3T^,C<X+&-H<B@R,S<I/3XR-S@L8VAR*#(S."D]/C(W
M."QC:'(H,C,Y*3T^,C<X+&-H<B@R-#`I/3XU-38L8VAR*#(T,2D]/C4U-BP*
M("`@(&-H<B@R-#(I/3XU-38L8VAR*#(T,RD]/C4U-BQC:'(H,C0T*3T^-34V
M+&-H<B@R-#4I/3XU-38L8VAR*#(T-BD]/C4U-BQC:'(H,C0W*3T^-3@T+&-H
M<B@R-#@I/3XV,3$L8VAR*#(T.2D]/C4U-BQC:'(H,C4P*3T^-34V+&-H<B@R
M-3$I/3XU-38L8VAR*#(U,BD]/C4U-BQC:'(H,C4S*3T^-3`P+&-H<B@R-30I
M/3XU-38L8VAR*#(U-2D]/C4P,"D["@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+T9I;&4O4$1&+V9O;G1S+W-Y;6)O;"YP
M:'``````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`V,#<S(#$P-3$U
M-#,S-S,T(#`R,C<U,P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@0'!A8VMA9V4@1FEL95]01$8*("HO
M"B1F;VYT7W=I9'1H<ULG<WEM8F]L)UT@/2!A<G)A>2@*("`@(&-H<B@P*3T^
M,C4P+&-H<B@Q*3T^,C4P+&-H<B@R*3T^,C4P+&-H<B@S*3T^,C4P+&-H<B@T
M*3T^,C4P+&-H<B@U*3T^,C4P+&-H<B@V*3T^,C4P+&-H<B@W*3T^,C4P+&-H
M<B@X*3T^,C4P+&-H<B@Y*3T^,C4P+&-H<B@Q,"D]/C(U,"QC:'(H,3$I/3XR
M-3`L8VAR*#$R*3T^,C4P+&-H<B@Q,RD]/C(U,"QC:'(H,30I/3XR-3`L8VAR
M*#$U*3T^,C4P+&-H<B@Q-BD]/C(U,"QC:'(H,3<I/3XR-3`L8VAR*#$X*3T^
M,C4P+&-H<B@Q.2D]/C(U,"QC:'(H,C`I/3XR-3`L8VAR*#(Q*3T^,C4P+`H@
M("`@8VAR*#(R*3T^,C4P+&-H<B@R,RD]/C(U,"QC:'(H,C0I/3XR-3`L8VAR
M*#(U*3T^,C4P+&-H<B@R-BD]/C(U,"QC:'(H,C<I/3XR-3`L8VAR*#(X*3T^
M,C4P+&-H<B@R.2D]/C(U,"QC:'(H,S`I/3XR-3`L8VAR*#,Q*3T^,C4P+"<@
M)ST^,C4P+"<A)ST^,S,S+"<B)ST^-S$S+"<C)ST^-3`P+"<D)ST^-30Y+"<E
M)ST^.#,S+"<F)ST^-S<X+"=<)R<]/C0S.2PG*"<]/C,S,RPG*2<]/C,S,RPG
M*B<]/C4P,"PG*R<]/C4T.2P*("`@("<L)ST^,C4P+"<M)ST^-30Y+"<N)ST^
M,C4P+"<O)ST^,C<X+"<P)ST^-3`P+"<Q)ST^-3`P+"<R)ST^-3`P+"<S)ST^
M-3`P+"<T)ST^-3`P+"<U)ST^-3`P+"<V)ST^-3`P+"<W)ST^-3`P+"<X)ST^
M-3`P+"<Y)ST^-3`P+"<Z)ST^,C<X+"<[)ST^,C<X+"<\)ST^-30Y+"<])ST^
M-30Y+"<^)ST^-30Y+"<_)ST^-#0T+"=`)ST^-30Y+"=!)ST^-S(R+`H@("`@
M)T(G/3XV-C<L)T,G/3XW,C(L)T0G/3XV,3(L)T4G/3XV,3$L)T8G/3XW-C,L
M)T<G/3XV,#,L)T@G/3XW,C(L)TDG/3XS,S,L)THG/3XV,S$L)TLG/3XW,C(L
M)TPG/3XV.#8L)TTG/3XX.#DL)TXG/3XW,C(L)T\G/3XW,C(L)U`G/3XW-C@L
M)U$G/3XW-#$L)U(G/3XU-38L)U,G/3XU.3(L)U0G/3XV,3$L)U4G/3XV.3`L
M)U8G/3XT,SDL)U<G/3XW-C@L"B`@("`G6"<]/C8T-2PG62<]/C<Y-2PG6B<]
M/C8Q,2PG6R<]/C,S,RPG7%PG/3XX-C,L)UTG/3XS,S,L)UXG/3XV-3@L)U\G
M/3XU,#`L)V`G/3XU,#`L)V$G/3XV,S$L)V(G/3XU-#DL)V,G/3XU-#DL)V0G
M/3XT.30L)V4G/3XT,SDL)V8G/3XU,C$L)V<G/3XT,3$L)V@G/3XV,#,L)VDG
M/3XS,CDL)VHG/3XV,#,L)VLG/3XU-#DL)VPG/3XU-#DL)VTG/3XU-S8L"B`@
M("`G;B<]/C4R,2PG;R<]/C4T.2PG<"<]/C4T.2PG<2<]/C4R,2PG<B<]/C4T
M.2PG<R<]/C8P,RPG="<]/C0S.2PG=2<]/C4W-BPG=B<]/C<Q,RPG=R<]/C8X
M-BPG>"<]/C0Y,RPG>2<]/C8X-BPG>B<]/C0Y-"PG>R<]/C0X,"PG?"<]/C(P
M,"PG?2<]/C0X,"PG?B<]/C4T.2QC:'(H,3(W*3T^,"QC:'(H,3(X*3T^,"QC
M:'(H,3(Y*3T^,"QC:'(H,3,P*3T^,"QC:'(H,3,Q*3T^,"P*("`@(&-H<B@Q
M,S(I/3XP+&-H<B@Q,S,I/3XP+&-H<B@Q,S0I/3XP+&-H<B@Q,S4I/3XP+&-H
M<B@Q,S8I/3XP+&-H<B@Q,S<I/3XP+&-H<B@Q,S@I/3XP+&-H<B@Q,SDI/3XP
M+&-H<B@Q-#`I/3XP+&-H<B@Q-#$I/3XP+&-H<B@Q-#(I/3XP+&-H<B@Q-#,I
M/3XP+&-H<B@Q-#0I/3XP+&-H<B@Q-#4I/3XP+&-H<B@Q-#8I/3XP+&-H<B@Q
M-#<I/3XP+&-H<B@Q-#@I/3XP+&-H<B@Q-#DI/3XP+&-H<B@Q-3`I/3XP+&-H
M<B@Q-3$I/3XP+&-H<B@Q-3(I/3XP+&-H<B@Q-3,I/3XP+`H@("`@8VAR*#$U
M-"D]/C`L8VAR*#$U-2D]/C`L8VAR*#$U-BD]/C`L8VAR*#$U-RD]/C`L8VAR
M*#$U."D]/C`L8VAR*#$U.2D]/C`L8VAR*#$V,"D]/C<U,"QC:'(H,38Q*3T^
M-C(P+&-H<B@Q-C(I/3XR-#<L8VAR*#$V,RD]/C4T.2QC:'(H,38T*3T^,38W
M+&-H<B@Q-C4I/3XW,3,L8VAR*#$V-BD]/C4P,"QC:'(H,38W*3T^-S4S+&-H
M<B@Q-C@I/3XW-3,L8VAR*#$V.2D]/C<U,RQC:'(H,3<P*3T^-S4S+&-H<B@Q
M-S$I/3XQ,#0R+&-H<B@Q-S(I/3XY.#<L8VAR*#$W,RD]/C8P,RQC:'(H,3<T
M*3T^.3@W+&-H<B@Q-S4I/3XV,#,L"B`@("!C:'(H,3<V*3T^-#`P+&-H<B@Q
M-S<I/3XU-#DL8VAR*#$W."D]/C0Q,2QC:'(H,3<Y*3T^-30Y+&-H<B@Q.#`I
M/3XU-#DL8VAR*#$X,2D]/C<Q,RQC:'(H,3@R*3T^-#DT+&-H<B@Q.#,I/3XT
M-C`L8VAR*#$X-"D]/C4T.2QC:'(H,3@U*3T^-30Y+&-H<B@Q.#8I/3XU-#DL
M8VAR*#$X-RD]/C4T.2QC:'(H,3@X*3T^,3`P,"QC:'(H,3@Y*3T^-C`S+&-H
M<B@Q.3`I/3XQ,#`P+&-H<B@Q.3$I/3XV-3@L8VAR*#$Y,BD]/C@R,RQC:'(H
M,3DS*3T^-C@V+&-H<B@Q.30I/3XW.34L8VAR*#$Y-2D]/CDX-RQC:'(H,3DV
M*3T^-S8X+&-H<B@Q.3<I/3XW-C@L"B`@("!C:'(H,3DX*3T^.#(S+&-H<B@Q
M.3DI/3XW-C@L8VAR*#(P,"D]/C<V."QC:'(H,C`Q*3T^-S$S+&-H<B@R,#(I
M/3XW,3,L8VAR*#(P,RD]/C<Q,RQC:'(H,C`T*3T^-S$S+&-H<B@R,#4I/3XW
M,3,L8VAR*#(P-BD]/C<Q,RQC:'(H,C`W*3T^-S$S+&-H<B@R,#@I/3XW-C@L
M8VAR*#(P.2D]/C<Q,RQC:'(H,C$P*3T^-SDP+&-H<B@R,3$I/3XW.3`L8VAR
M*#(Q,BD]/C@Y,"QC:'(H,C$S*3T^.#(S+&-H<B@R,30I/3XU-#DL8VAR*#(Q
M-2D]/C(U,"QC:'(H,C$V*3T^-S$S+&-H<B@R,3<I/3XV,#,L8VAR*#(Q."D]
M/C8P,RQC:'(H,C$Y*3T^,3`T,BP*("`@(&-H<B@R,C`I/3XY.#<L8VAR*#(R
M,2D]/C8P,RQC:'(H,C(R*3T^.3@W+&-H<B@R,C,I/3XV,#,L8VAR*#(R-"D]
M/C0Y-"QC:'(H,C(U*3T^,S(Y+&-H<B@R,C8I/3XW.3`L8VAR*#(R-RD]/C<Y
M,"QC:'(H,C(X*3T^-S@V+&-H<B@R,CDI/3XW,3,L8VAR*#(S,"D]/C,X-"QC
M:'(H,C,Q*3T^,S@T+&-H<B@R,S(I/3XS.#0L8VAR*#(S,RD]/C,X-"QC:'(H
M,C,T*3T^,S@T+&-H<B@R,S4I/3XS.#0L8VAR*#(S-BD]/C0Y-"QC:'(H,C,W
M*3T^-#DT+&-H<B@R,S@I/3XT.30L8VAR*#(S.2D]/C0Y-"QC:'(H,C0P*3T^
M,"QC:'(H,C0Q*3T^,S(Y+`H@("`@8VAR*#(T,BD]/C(W-"QC:'(H,C0S*3T^
M-C@V+&-H<B@R-#0I/3XV.#8L8VAR*#(T-2D]/C8X-BQC:'(H,C0V*3T^,S@T
M+&-H<B@R-#<I/3XS.#0L8VAR*#(T."D]/C,X-"QC:'(H,C0Y*3T^,S@T+&-H
M<B@R-3`I/3XS.#0L8VAR*#(U,2D]/C,X-"QC:'(H,C4R*3T^-#DT+&-H<B@R
M-3,I/3XT.30L8VAR*#(U-"D]/C0Y-"QC:'(H,C4U*3T^,"D["@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]&:6QE+U!$1BYP:'``````````````
M````````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#(W,C`R-R`Q,#4Q
M-30S,S<S-"`P,C`S,C$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J($9I;&5?4$1&.CH*("H*("H@5&AE
M($9I;&5?4$1&.CH@8VQA<W,@<')O=FED97,@82!02%`M;VYL>2!I;7!L96UE
M;G1A=&EO;B!O9B!A(%!$1B!L:6)R87)Y+@H@*B!.;R!E>'1E<FYA;"!L:6)S
M(&]R(%!(4"!E>'1E;G-I;VYS(&%R92!R97%U:7)E9"X*("H*("H@0F%S960@
M;VX@=&AE($901$8@8VQA<W,@8GD@3VQI=FEE<B!0;&%T:&5Y("AH='1P.B\O
M=W=W+F9P9&8N;W)G*2X*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!/;&EV
M:65R(%!L871H97D@/&]L:79I97)`9G!D9BYO<F<^"B`J($-O<'ER:6=H="`R
M,#`S+3(P,#8@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T9I;&5?4$1&+U!$1BYP
M:'`L=B`Q+C$X+C$P+C$R(#(P,#8O,#$O,#$@,C$Z,C@Z,34@:F%N($5X<"`D
M"B`J"B`J($!A=71H;W(@($]L:79I97(@4&QA=&AE>2`\;VQI=FEE<D!F<&1F
M+F]R9SX*("H@0&%U=&AO<B`@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O
M;3X*("H@0'!A8VMA9V4@1FEL95]01$8*("HO"F-L87-S($9I;&5?4$1&('L*
M"B`@("`O*BH*("`@("`J($-U<G)E;G0@<&%G92!N=6UB97(N"B`@("`@*@H@
M("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7W!A9V4@/2`P
M.PH*("`@("\J*@H@("`@("H@0W5R<F5N="!O8FIE8W0@;G5M8F5R+@H@("`@
M("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]N(#T@
M,CL*"B`@("`O*BH*("`@("`J($%R<F%Y(&]F(&]B:F5C="!O9F9S971S+@H@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?;V9F
M<V5T<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!"=69F97(@:&]L9&EN
M9R!I;BUM96UO<GD@4$1&+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D7V)U9F9E<B`]("<G.PH*("`@("\J*@H@("`@("H@
M07)R87D@8V]N=&%I;FEN9R!T:&4@<&%G97,N"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P86=E<R`](&%R<F%Y*"D["@H@
M("`@+RHJ"B`@("`@*B!#=7)R96YT(&1O8W5M96YT('-T871E+@H@("`@("H@
M("`P("T@:6YI=&EA;"!S=&%T90H@("`@("H@("`Q("T@9&]C=6UE;G0@;W!E
M;F5D"B`@("`@*B`@(#(@+2!P86=E(&]P96YE9`H@("`@("H@("`S("T@9&]C
M=6UE;G0@8VQO<V5D"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@
M*B\*("`@('9A<B`D7W-T871E(#T@,#L*"B`@("`O*BH*("`@("`J($9L86<@
M:6YD:6-A=&EN9R!I9B!01$8@9FEL92!I<R!T;R!B92!C;VUP<F5S<V5D(&]R
M(&YO="X*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@
M=F%R("1?8V]M<')E<W,["@H@("`@+RHJ"B`@("`@*B!4:&4@9&5F875L="!P
M86=E(&]R:65N=&%T:6]N+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D7V1E9F%U;'1?;W)I96YT871I;VX["@H@("`@+RHJ
M"B`@("`@*B!4:&4@8W5R<F5N="!P86=E(&]R:65N=&%T:6]N+@H@("`@("H*
M("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V-U<G)E;G1?
M;W)I96YT871I;VX["@H@("`@+RHJ"B`@("`@*B!!<G)A>2!I;F1I8V%T:6YG
M(&]R:65N=&%T:6]N(&-H86YG97,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)%]O<FEE;G1A=&EO;E]C:&%N9V5S(#T@87)R
M87DH*3L*"B`@("`O*BH*("`@("`J($-U<G)E;G0@=VED=&@@;V8@<&%G92!F
M;W)M870@:6X@<&]I;G1S+@H@("`@("H*("`@("`J($!V87(@9FQO870*("`@
M("`J+PH@("`@=F%R("1F=U!T.PH*("`@("\J*@H@("`@("H@0W5R<F5N="!H
M96EG:'0@;V8@<&%G92!F;W)M870@:6X@<&]I;G1S+@H@("`@("H*("`@("`J
M($!V87(@9FQO870*("`@("`J+PH@("`@=F%R("1F:%!T.PH*("`@("\J*@H@
M("`@("H@0W5R<F5N="!W:61T:"!O9B!P86=E(&9O<FUA="!I;B!U<V5R('5N
M:71S+@H@("`@("H*("`@("`J($!V87(@9FQO870*("`@("`J+PH@("`@=F%R
M("1F=SL*"B`@("`O*BH*("`@("`J($-U<G)E;G0@:&5I9VAT(&]F('!A9V4@
M9F]R;6%T(&EN('5S97(@=6YI=',N"B`@("`@*@H@("`@("H@0'9A<B!F;&]A
M=`H@("`@("HO"B`@("!V87(@)&9H.PH*("`@("\J*@H@("`@("H@0W5R<F5N
M="!W:61T:"!O9B!P86=E(&EN('!O:6YT<RX*("`@("`J"B`@("`@*B!`=F%R
M(&9L;V%T"B`@("`@*B\*("`@('9A<B`D=U!T.PH*("`@("\J*@H@("`@("H@
M0W5R<F5N="!H96EG:'0@;V8@<&%G92!I;B!P;VEN=',N"B`@("`@*@H@("`@
M("H@0'9A<B!F;&]A=`H@("`@("HO"B`@("!V87(@)&A0=#L*"B`@("`O*BH*
M("`@("`J($-U<G)E;G0@=VED=&@@;V8@<&%G92!I;B!U<V5R('5N:71S"B`@
M("`@*@H@("`@("H@0'9A<B!F;&]A=`H@("`@("HO"B`@("!V87(@)'<["@H@
M("`@+RHJ"B`@("`@*B!#=7)R96YT(&AE:6=H="!O9B!P86=E(&EN('5S97(@
M=6YI=',*("`@("`J"B`@("`@*B!`=F%R(&9L;V%T"B`@("`@*B\*("`@('9A
M<B`D:#L*"B`@("`O*BH*("`@("`J(%-C86QE(&9A8W1O<B`H;G5M8F5R(&]F
M('!O:6YT<R!I;B!U<V5R('5N:71S*2X*("`@("`J"B`@("`@*B!`=F%R(&9L
M;V%T"B`@("`@*B\*("`@('9A<B`D7W-C86QE.PH*("`@("\J*@H@("`@("H@
M3&5F="!P86=E(&UA<F=I;B!S:7IE+@H@("`@("H*("`@("`J($!V87(@9FQO
M870*("`@("`J+PH@("`@=F%R("1?;&5F=%]M87)G:6X["@H@("`@+RHJ"B`@
M("`@*B!4;W`@<&%G92!M87)G:6X@<VEZ92X*("`@("`J"B`@("`@*B!`=F%R
M(&9L;V%T"B`@("`@*B\*("`@('9A<B`D7W1O<%]M87)G:6X["@H@("`@+RHJ
M"B`@("`@*B!2:6=H="!P86=E(&UA<F=I;B!S:7IE+@H@("`@("H*("`@("`J
M($!V87(@9FQO870*("`@("`J+PH@("`@=F%R("1?<FEG:'1?;6%R9VEN.PH*
M("`@("\J*@H@("`@("H@0G)E86L@<&%G92!M87)G:6X@<VEZ92P@=&AE(&)O
M='1O;2!M87)G:6X@=VAI8V@@=')I9V=E<G,@82!P86=E(&)R96%K+@H@("`@
M("H*("`@("`J($!V87(@9FQO870*("`@("`J+PH@("`@=F%R("1?8G)E86M?
M;6%R9VEN.PH*("`@("\J*@H@("`@("H@0V5L;"!M87)G:6X@<VEZ92X*("`@
M("`J"B`@("`@*B!`=F%R(&9L;V%T"B`@("`@*B\*("`@('9A<B`D7V-E;&Q?
M;6%R9VEN.PH*("`@("\J*@H@("`@("H@5&AE(&-U<G)E;G0@:&]R:7IO;G1A
M;"!P;W-I=&EO;B!F;W(@8V5L;"!P;W-I=&EO;FEN9RX*("`@("`J(%9A;'5E
M(&ES('-E="!I;B!U<V5R('5N:71S(&%N9"!I<R!C86QC=6QA=&5D(&9R;VT@
M=&AE('1O<"!L969T(&-O<FYE<@H@("`@("H@87,@;W)I9VEN+@H@("`@("H*
M("`@("`J($!V87(@9FQO870*("`@("`J+PH@("`@=F%R("1X.PH*("`@("\J
M*@H@("`@("H@5&AE(&-U<G)E;G0@=F5R=&EC86P@<&]S:71I;VX@9F]R(&-E
M;&P@<&]S:71I;VYI;F<N"B`@("`@*B!686QU92!I<R!S970@:6X@=7-E<B!U
M;FET<R!A;F0@:7,@8V%L8W5L871E9"!F<F]M('1H92!T;W`@;&5F="!C;W)N
M97(*("`@("`J(&%S(&]R:6=I;BX*("`@("`J"B`@("`@*B!`=F%R(&9L;V%T
M"B`@("`@*B\*("`@('9A<B`D>3L*"B`@("`O*BH*("`@("`J(%1H92!H96EG
M:'0@;V8@=&AE(&QA<W0@8V5L;"!P<FEN=&5D+@H@("`@("H*("`@("`J($!V
M87(@9FQO870*("`@("`J+PH@("`@=F%R("1?;&%S=%]H96EG:'0["@H@("`@
M+RHJ"B`@("`@*B!,:6YE('=I9'1H(&EN('5S97(@=6YI=',N"B`@("`@*@H@
M("`@("H@0'9A<B!F;&]A=`H@("`@("HO"B`@("!V87(@)%]L:6YE7W=I9'1H
M.PH*("`@("\J*@H@("`@("H@06X@87)R87D@;V8@<W1A;F1A<F0@9F]N="!N
M86UE<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D7V-O<F5?9F]N=',@/2!A<G)A>2@G8V]U<FEE<B<@("`@("`]/B`G0V]U
M<FEE<B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-O=7)I97)"
M)R`@("`@/3X@)T-O=7)I97(M0F]L9"<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)V-O=7)I97)))R`@("`@/3X@)T-O=7)I97(M3V)L:7%U92<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-O=7)I97)"22<@("`@
M/3X@)T-O=7)I97(M0F]L9$]B;&EQ=64G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=H96QV971I8V$G("`@(#T^("=(96QV971I8V$G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=H96QV971I8V%")R`@(#T^("=(
M96QV971I8V$M0F]L9"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)VAE;'9E=&EC84DG("`@/3X@)TAE;'9E=&EC82U/8FQI<75E)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G:&5L=F5T:6-A0DDG("`]/B`G2&5L
M=F5T:6-A+4)O;&1/8FQI<75E)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G=&EM97,G("`@("`@("`]/B`G5&EM97,M4F]M86XG+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=T:6UE<T(G("`@("`@(#T^("=4:6UE
M<RU";VQD)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=&EM97-)
M)R`@("`@("`]/B`G5&EM97,M271A;&EC)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G=&EM97-"22<@("`@("`]/B`G5&EM97,M0F]L9$ET86QI
M8R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-Y;6)O;"<@("`@
M("`@/3X@)U-Y;6)O;"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)WIA<&9D:6YG8F%T<R<@/3X@)UIA<&9$:6YG8F%T<R<I.PH*("`@("\J*@H@
M("`@("H@06X@87)R87D@;V8@=7-E9"!F;VYT<RX*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V9O;G1S(#T@87)R87DH*3L*
M"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&]F(&9O;G0@9FEL97,N"B`@("`@
M*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]F;VYT7V9I
M;&5S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&]F(&5N
M8V]D:6YG(&1I9F9E<F5N8V5S+@H@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1?9&EF9G,@/2!A<G)A>2@I.PH*("`@("\J*@H@
M("`@("H@06X@87)R87D@;V8@=7-E9"!I;6%G97,N"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]I;6%G97,@/2!A<G)A>2@I
M.PH*("`@("\J*@H@("`@("H@06X@87)R87D@;V8@;&EN:W,@:6X@<&%G97,N
M"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P
M86=E7VQI;FMS.PH*("`@("\J*@H@("`@("H@06X@87)R87D@;V8@:6YT97)N
M86P@;&EN:W,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)%]L:6YK<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#=7)R
M96YT(&9O;G0@9F%M:6QY+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D7V9O;G1?9F%M:6QY(#T@)R<["@H@("`@+RHJ"B`@
M("`@*B!#=7)R96YT(&9O;G0@<W1Y;&4N"B`@("`@*@H@("`@("H@0'9A<B!S
M=')I;F<*("`@("`J+PH@("`@=F%R("1?9F]N=%]S='EL92`]("<G.PH*("`@
M("\J*@H@("`@("H@56YD97)L:6YI;F<@9FQA9RX*("`@("`J"B`@("`@*B!`
M=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?=6YD97)L:6YE(#T@9F%L
M<V4["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!C;VYT86EN:6YG(&-U<G)E
M;G0@9F]N="!I;F9O+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1?8W5R<F5N=%]F;VYT.PH*("`@("\J*@H@("`@("H@0W5R
M<F5N="!F;VYT('-I>F4@:6X@<&]I;G1S+@H@("`@("H*("`@("`J($!V87(@
M9FQO870*("`@("`J+PH@("`@=F%R("1?9F]N=%]S:7IE7W!T(#T@,3(["@H@
M("`@+RHJ"B`@("`@*B!#=7)R96YT(&9O;G0@<VEZ92!I;B!U<V5R('5N:71S
M+@H@("`@("H*("`@("`J($!V87(@9FQO870*("`@("`J+PH@("`@=F%R("1?
M9F]N=%]S:7IE.PH*("`@("\J*@H@("`@("H@0V]M;6%N9',@9F]R(&9I;&QI
M;F<@8V]L;W(N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@
M("`@=F%R("1?9FEL;%]C;VQO<B`]("<P(&<G.PH*("`@("\J*@H@("`@("H@
M0V]M;6%N9',@9F]R(&1R87=I;F<@8V]L;W(N"B`@("`@*@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?9')A=U]C;VQO<B`]("<P($<G
M.PH*("`@("\J*@H@("`@("H@5V]R9"!S<&%C:6YG+@H@("`@("H*("`@("`J
M($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]W;W)D7W-P86-I;F<@
M/2`P.PH*("`@("\J*@H@("`@("H@075T;VUA=&EC('!A9V4@8G)E86MI;F<N
M"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D
M7V%U=&]?<&%G95]B<F5A:SL*"B`@("`O*BH*("`@("`J(%1H<F5S:&]L9"!U
M<V5D('1O('1R:6=G97(@<&%G92!B<F5A:W,N"B`@("`@*@H@("`@("H@0'9A
M<B!F;&]A=`H@("`@("HO"B`@("!V87(@)%]P86=E7V)R96%K7W1R:6=G97([
M"@H@("`@+RHJ"B`@("`@*B!&;&%G('-E="!W:&5N('!R;V-E<W-I;F<@9F]O
M=&5R+@H@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V
M87(@)%]I;E]F;V]T97(@/2!F86QS93L*"B`@("`O*BH*("`@("`J(%IO;VT@
M9&ES<&QA>2!M;V1E+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B\*("`@('9A<B`D7WIO;VU?;6]D93L*"B`@("`O*BH*("`@("`J($QA>6]U
M="!D:7-P;&%Y(&UO9&4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@
M("`J+PH@("`@=F%R("1?;&%Y;W5T7VUO9&4["@H@("`@+RHJ"B`@("`@*B!!
M;B!A<G)A>2!C;VYT86EN:6YG('1H92!D;V-U;65N="!I;F9O+"!C;VYS:7-T
M:6YG(&]F.@H@("`@("H@("`M('1I=&QE"B`@("`@*B`@("T@<W5B:F5C=`H@
M("`@("H@("`M(&%U=&AO<@H@("`@("H@("`M(&ME>7=O<F1S"B`@("`@*B`@
M("T@8W)E871O<@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1?:6YF;R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!!;&EA
M<R!F;W(@=&]T86P@;G5M8F5R(&]F('!A9V5S+@H@("`@("H*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V%L:6%S7VYB7W!A9V5S(#T@
M)WMN8GTG.PH*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@
M8V]N<F5T92!01$8@:6YS=&%N8V4N($ET(&%L;&]W<R!T;R!S970@=7`@=&AE
M('!A9V4*("`@("`J(&9O<FUA="P@=&AE(&]R:65N=&%T:6]N(&%N9"!T:&4@
M=6YI=',@;V8@;65A<W5R96UE;G0@=7-E9"!I;B!A;&P@=&AE"B`@("`@*B!M
M971H;V1S("AE>&-E<'0@9F]R('1H92!F;VYT('-I>F5S*2X*("`@("`J"B`@
M("`@*B!%>&%M<&QE.CQP<F4^"B`@("`@*B`D<&1F(#T@)D9I;&5?4$1&.CIF
M86-T;W)Y*&%R<F%Y*"=O<FEE;G1A=&EO;B<@/3X@)U`G+`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=6YI="<@/3X@)VUM)RP*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V9O<FUA
M="<@/3X@)T$T)RDI.SPO<')E/@H@("`@("H*("`@("`J($!P87)A;2!A<G)A
M>2`D<&%R86US("!!(&AA<V@@=VET:"!P87)A;65T97)S(&9O<B!T:&4@8W)E
M871E9"!01$8@;V)J96-T+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M(%!O<W-I8FQE('!A<F%M971E<G,@87)E.@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@(&]R:65N=&%T:6]N("T@1&5F875L="!P86=E(&]R:65N=&%T
M:6]N+B!0;W-S:6)L90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('9A
M;'5E<R!A<F4@*&-A<V4@:6YS96YS:71I=F4I.@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@(#QP<F4^"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`M(%`@;W(@4&]R=')A:70@*&1E9F%U;'0I"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`M($P@;W(@3&%N9'-C87!E"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@/"]P<F4^"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@=6YI="`M(%5S97(@;65A<W5R92!U;FET<RX@4&]S<VEB;&4@
M=F%L=65S('9A;'5E<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&%R
M93H*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`\<')E/@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@+2!P=#H@<&]I;G0*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("T@;6TZ(&UI;&QI;65T97(@*&1E9F%U
M;'0I"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M(&-M.B!C96YT
M:6UE=&5R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M(&EN.B!I
M;F-H"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@/"]P<F4^"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@02!P;VEN="!E<75A;',@,2\W,B!O
M9B!I;F-H+"!T:&%T(&ES('1O('-A>2!A8F]U=`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@(#`N,S4@;6T@*&%N(&EN8V@@8F5I;F<@,BXU-"!C;2DN
M(%1H:7,@:7,@82!V97)Y"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M8V]M;6]N('5N:70@:6X@='EP;V=R87!H>3L@9F]N="!S:7IE<R!A<F4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("!E>'!R97-S960@:6X@=&AA="!U
M;FET+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&9O<FUA="`M(%1H
M92!F;W)M870@=7-E9"!F;W(@<&%G97,N($ET(&-A;B!B90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@(&5I=&AE<B!O;F4@;V8@=&AE(&9O;&QO=VEN
M9R!V86QU97,@*&-A<V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!I
M;G-E;G-I=&EV92DZ"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@/'!R
M93X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("T@03,*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("T@030@*&1E9F%U;'0I"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`M($$U"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`M($QE='1E<@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@+2!,96=A;`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@(#PO<')E/@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&]R(&$@
M8W5S=&]M(&9O<FUA="!I;B!T:&4@9F]R;2!O9B!A('1W;RUE;&5M96YT"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@87)R87D@8V]N=&%I;FEN9R!T
M:&4@=VED=&@@86YD('1H92!H96EG:'0*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`H97AP<F5S<V5D(&EN('1H92!U;FET(&=I=F5N(&)Y('1H92!U
M;FET"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<&%R86UE=&5R*2X*
M("`@("`J($!P87)A;2!S=')I;F<@)&-L87-S("!4:&4@8V]N8W)E=&4@8VQA
M<W,@;F%M92!T;R!R971U<FX@86X@:6YS=&%N8V4@;V8N"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@1&5F875L=',@=&\@1FEL95]01$8N"B`@("`@
M*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1P87)A;7,@/2!A<G)A>2@I+"`D
M8VQA<W,@/2`G1FEL95]01$8G*0H@("`@>PH@("`@("`@("\J($-H96-K(&9O
M<B!02%`@;&]C86QE+7)E;&%T960@8G5G+B`J+PH@("`@("`@(&EF("@Q+C$@
M/3T@,2D@>PH@("`@("`@("`@("!R971U<FX@1FEL95]01$8Z.G)A:7-E17)R
M;W(H)T1O(&YO="!A;'1E<B!T:&4@;&]C86QE(&)E9F]R92!I;F-L=61I;F<@
M=&AE(&-L87-S(&9I;&4N)RD["B`@("`@("`@?0H*("`@("`@("`O*B!$969A
M=6QT('!A<F%M971E<G,N("HO"B`@("`@("`@)&1E9F%U;'1S(#T@87)R87DH
M)V]R:65N=&%T:6]N)R`]/B`G4"<L("=U;FET)R`]/B`G;6TG+"`G9F]R;6%T
M)R`]/B`G030G*3L*"B`@("`@("`@+RH@0F%C:W=A<F0@8V]M<&%T:6)I;&ET
M>2!W:71H(&]L9"!M971H;V0@<VEG;F%T=7)E+B`J+PH@("`@("`@("\J(%-H
M;W5L9"!B92!R96UO=F5D(&$@9F5W('9E<G-I;VYS(&QA=&5R+B`J+PH@("`@
M("`@(&EF("@A:7-?87)R87DH)'!A<F%M<RDI('L*("`@("`@("`@("`@)&-L
M87-S(#T@)T9I;&5?4$1&)SL*("`@("`@("`@("`@)'!A<F%M<R`]("1D969A
M=6QT<SL*("`@("`@("`@("`@)&YA;65S(#T@87)R87E?:V5Y<R@D9&5F875L
M=',I.PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!F=6YC7VYU;5]A
M<F=S*"D[("1I*RLI('L*("`@("`@("`@("`@("`@("1P87)A;7-;)&YA;65S
M6R1I75T@/2!F=6YC7V=E=%]A<F<H)&DI.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'!A<F%M<R`](&%R<F%Y7VUE<F=E
M*"1D969A=6QT<RP@)'!A<F%M<RD["B`@("`@("`@?0H*("`@("`@("`O*B!#
M<F5A=&4@=&AE(%!$1B!O8FIE8W0N("HO"B`@("`@("`@)'!D9B`]("9N97<@
M)&-L87-S*"D["@H@("`@("`@("\J(%-C86QE(&9A8W1O<BX@*B\*("`@("`@
M("!I9B`H)'!A<F%M<ULG=6YI="==(#T]("=P="<I('L*("`@("`@("`@("`@
M)'!D9BT^7W-C86QE(#T@,3L*("`@("`@("!](&5L<V5I9B`H)'!A<F%M<ULG
M=6YI="==(#T]("=M;2<I('L*("`@("`@("`@("`@)'!D9BT^7W-C86QE(#T@
M-S(@+R`R-2XT.PH@("`@("`@('T@96QS96EF("@D<&%R86US6R=U;FET)UT@
M/3T@)V-M)RD@>PH@("`@("`@("`@("`D<&1F+3Y?<V-A;&4@/2`W,B`O(#(N
M-30["B`@("`@("`@?2!E;'-E:68@*"1P87)A;7-;)W5N:70G72`]/2`G:6XG
M*2!["B`@("`@("`@("`@("1P9&8M/E]S8V%L92`](#<R.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B!&:6QE7U!$1CHZ<F%I<V5%<G)O
M<BAS<')I;G1F*"=);F-O<G)E8W0@=6YI=',Z("5S)RP@)'!A<F%M<ULG=6YI
M="==*2D["B`@("`@("`@?0H@("`@("`@("\J(%!A9V4@9F]R;6%T+B`J+PH@
M("`@("`@(&EF("AI<U]S=')I;F<H)'!A<F%M<ULG9F]R;6%T)UTI*2!["B`@
M("`@("`@("`@("1P87)A;7-;)V9O<FUA="==(#T@<W1R=&]L;W=E<B@D<&%R
M86US6R=F;W)M870G72D["B`@("`@("`@("`@(&EF("@D<&%R86US6R=F;W)M
M870G72`]/2`G83,G*2!["B`@("`@("`@("`@("`@("`D<&%R86US6R=F;W)M
M870G72`](&%R<F%Y*#@T,2XX.2P@,3$Y,"XU-2D["B`@("`@("`@("`@('T@
M96QS96EF("@D<&%R86US6R=F;W)M870G72`]/2`G830G*2!["B`@("`@("`@
M("`@("`@("`D<&%R86US6R=F;W)M870G72`](&%R<F%Y*#4Y-2XR."P@.#0Q
M+C@Y*3L*("`@("`@("`@("`@?2!E;'-E:68@*"1P87)A;7-;)V9O<FUA="==
M(#T]("=A-2<I('L*("`@("`@("`@("`@("`@("1P87)A;7-;)V9O<FUA="==
M(#T@87)R87DH-#(P+CDT+"`U.34N,C@I.PH@("`@("`@("`@("!](&5L<V5I
M9B`H)'!A<F%M<ULG9F]R;6%T)UT@/3T@)VQE='1E<B<I('L*("`@("`@("`@
M("`@("`@("1P87)A;7-;)V9O<FUA="==(#T@87)R87DH-C$R+"`W.3(I.PH@
M("`@("`@("`@("!](&5L<V5I9B`H)'!A<F%M<ULG9F]R;6%T)UT@/3T@)VQE
M9V%L)RD@>PH@("`@("`@("`@("`@("`@)'!A<F%M<ULG9F]R;6%T)UT@/2!A
M<G)A>2@V,3(L(#$P,#@I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N($9I;&5?4$1&.CIR86ES945R<F]R*'-P<FEN=&8H
M)U5N:VYO=VX@<&%G92!F;W)M870Z("5S)RP@)'!A<F%M<ULG9F]R;6%T)UTI
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<&1F+3YF=U!T(#T@)'!A
M<F%M<ULG9F]R;6%T)UU;,%T["B`@("`@("`@("`@("1P9&8M/F9H4'0@/2`D
M<&%R86US6R=F;W)M870G75LQ73L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D<&1F+3YF=U!T(#T@)'!A<F%M<ULG9F]R;6%T)UU;,%T@*B`D<&1F
M+3Y?<V-A;&4["B`@("`@("`@("`@("1P9&8M/F9H4'0@/2`D<&%R86US6R=F
M;W)M870G75LQ72`J("1P9&8M/E]S8V%L93L*("`@("`@("!]"B`@("`@("`@
M)'!D9BT^9G<@/2`D<&1F+3YF=U!T("\@)'!D9BT^7W-C86QE.PH@("`@("`@
M("1P9&8M/F9H(#T@)'!D9BT^9FA0="`O("1P9&8M/E]S8V%L93L*"B`@("`@
M("`@+RH@4&%G92!O<FEE;G1A=&EO;BX@*B\*("`@("`@("`D<&%R86US6R=O
M<FEE;G1A=&EO;B==(#T@<W1R=&]L;W=E<B@D<&%R86US6R=O<FEE;G1A=&EO
M;B==*3L*("`@("`@("!I9B`H)'!A<F%M<ULG;W)I96YT871I;VXG72`]/2`G
M<"<@?'P@)'!A<F%M<ULG;W)I96YT871I;VXG72`]/2`G<&]R=')A:70G*2![
M"B`@("`@("`@("`@("1P9&8M/E]D969A=6QT7V]R:65N=&%T:6]N(#T@)U`G
M.PH@("`@("`@("`@("`D<&1F+3YW4'0@/2`D<&1F+3YF=U!T.PH@("`@("`@
M("`@("`D<&1F+3YH4'0@/2`D<&1F+3YF:%!T.PH@("`@("`@('T@96QS96EF
M("@D<&%R86US6R=O<FEE;G1A=&EO;B==(#T]("=L)R!\?"`D<&%R86US6R=O
M<FEE;G1A=&EO;B==(#T]("=L86YD<V-A<&4G*2!["B`@("`@("`@("`@("1P
M9&8M/E]D969A=6QT7V]R:65N=&%T:6]N(#T@)TPG.PH@("`@("`@("`@("`D
M<&1F+3YW4'0@/2`D<&1F+3YF:%!T.PH@("`@("`@("`@("`D<&1F+3YH4'0@
M/2`D<&1F+3YF=U!T.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B!&:6QE7U!$1CHZ<F%I<V5%<G)O<BAS<')I;G1F*"=);F-O<G)E8W0@
M;W)I96YT871I;VXZ("5S)RP@)'!A<F%M<ULG;W)I96YT871I;VXG72DI.PH@
M("`@("`@('T*("`@("`@("`D<&1F+3Y?8W5R<F5N=%]O<FEE;G1A=&EO;B`]
M("1P9&8M/E]D969A=6QT7V]R:65N=&%T:6]N.PH@("`@("`@("1P9&8M/G<@
M/2`D<&1F+3YW4'0@+R`D<&1F+3Y?<V-A;&4["B`@("`@("`@)'!D9BT^:"`]
M("1P9&8M/FA0="`O("1P9&8M/E]S8V%L93L*"B`@("`@("`@+RH@4&%G92!M
M87)G:6YS("@Q(&-M*2`J+PH@("`@("`@("1M87)G:6X@/2`R."XS-2`O("1P
M9&8M/E]S8V%L93L*("`@("`@("`D<&1F+3YS971-87)G:6YS*"1M87)G:6XL
M("1M87)G:6XI.PH*("`@("`@("`O*B!);G1E<FEO<B!C96QL(&UA<F=I;B`H
M,2!M;2D@*B\*("`@("`@("`D<&1F+3Y?8V5L;%]M87)G:6X@/2`D;6%R9VEN
M("\@,3`["@H@("`@("`@("\J($QI;F4@=VED=&@@*#`N,B!M;2D@*B\*("`@
M("`@("`D<&1F+3Y?;&EN95]W:61T:"`]("XU-C<@+R`D<&1F+3Y?<V-A;&4[
M"@H@("`@("`@("\J($%U=&]M871I8R!P86=E(&)R96%K("HO"B`@("`@("`@
M)'!D9BT^<V5T075T;U!A9V5"<F5A:RAT<G5E+"`R("H@)&UA<F=I;BD["@H@
M("`@("`@("\J($9U;&P@=VED=&@@9&ES<&QA>2!M;V1E("HO"B`@("`@("`@
M)'!D9BT^<V5T1&ES<&QA>4UO9&4H)V9U;&QW:61T:"<I.PH*("`@("`@("`O
M*B!#;VUP<F5S<VEO;B`J+PH@("`@("`@("1P9&8M/G-E=$-O;7!R97-S:6]N
M*'1R=64I.PH*("`@("`@("!R971U<FX@)'!D9CL*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@82!014%27T5R<F]R(&]B:F5C="X@5W)A<',@87)O
M=6YD(%!%05(Z.G)A:7-E17)R;W(H*2!T;PH@("`@("H@879O:60@:&%V:6YG
M('1O(&EN8VQU9&4@4$5!4BYP:'`@=6YL97-S(&%N(&5R<F]R(&]C8W5R<RX*
M("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&5R<F]R("!4:&4@97)R;W(@
M;65S<V%G92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&]B:F5C="!014%27T5R
M<F]R"B`@("`@*B\*("`@(&9U;F-T:6]N(')A:7-E17)R;W(H)&5R<F]R*0H@
M("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G4$5!4BYP:'`G.PH@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*"1E<G)O<BD["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!$969I;F5S('1H92!L969T+"!T;W`@86YD(')I9VAT(&UA
M<F=I;G,N($)Y(&1E9F%U;'0L('1H97D@97%U86P*("`@("`J(#$@8VTN("!#
M86QL('1H:7,@;65T:&]D('1O(&-H86YG92!T:&5M+@H@("`@("H*("`@("`J
M($!P87)A;2!F;&]A="`D;&5F="`@($QE9G0@;6%R9VEN+@H@("`@("H@0'!A
M<F%M(&9L;V%T("1T;W`@("`@5&]P(&UA<F=I;BX*("`@("`J($!P87)A;2!F
M;&]A="`D<FEG:'0@(%)I9VAT(&UA<F=I;BX@268@;F]T('-P96-I9FEE9"!D
M969A=6QT('1O('1H92!V86QU90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@;V8@=&AE(&QE9G0@;VYE+@H@("`@("H*("`@("`J($!S964@1FEL95]0
M1$8Z.G-E=$%U=&]086=E0G)E86L*("`@("`J($!S964@1FEL95]01$8Z.G-E
M=$QE9G1-87)G:6X*("`@("`J($!S964@1FEL95]01$8Z.G-E=%)I9VAT36%R
M9VEN"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS9714;W!-87)G:6X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V5T36%R9VEN<R@D;&5F="P@)'1O<"P@)')I9VAT
M(#T@;G5L;"D*("`@('L*("`@("`@("`O*B!3970@;&5F="!A;F0@=&]P(&UA
M<F=I;G,N("HO"B`@("`@("`@)'1H:7,M/E]L969T7VUA<F=I;B`@/2`D;&5F
M=#L*("`@("`@("`D=&AI<RT^7W1O<%]M87)G:6X@("`]("1T;W`["B`@("`@
M("`@+RH@268@;F\@<FEG:'0@;6%R9VEN('-E="!D969A=6QT('1O('-A;64@
M87,@;&5F="X@*B\*("`@("`@("`D=&AI<RT^7W)I9VAT7VUA<F=I;B`]("AI
M<U]N=6QL*"1R:6=H="D@/R`D;&5F="`Z("1R:6=H="D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!$969I;F5S('1H92!L969T(&UA<F=I;BX@5&AE(&UE=&AO
M9"!C86X@8F4@8V%L;&5D(&)E9F]R92!C<F5A=&EN9R!T:&4*("`@("`J(&9I
M<G-T('!A9V4N"B`@("`@*B!)9B!T:&4@8W5R<F5N="!A8G-C:7-S82!G971S
M(&]U="!O9B!P86=E+"!I="!I<R!B<F]U9VAT(&)A8VL@=&\@=&AE"B`@("`@
M*B!M87)G:6XN"B`@("`@*@H@("`@("H@0'!A<F%M(&9L;V%T("1M87)G:6X@
M("!4:&4@;6%R9VEN+@H@("`@("H*("`@("`J($!S964@1FEL95]01$8Z.G-E
M=$%U=&]086=E0G)E86L*("`@("`J($!S964@1FEL95]01$8Z.G-E=$UA<F=I
M;G,*("`@("`J($!S964@1FEL95]01$8Z.G-E=%)I9VAT36%R9VEN"B`@("`@
M*B!`<V5E($9I;&5?4$1&.CIS9714;W!-87)G:6X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5T3&5F=$UA<F=I;B@D;6%R9VEN*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?;&5F=%]M87)G:6X@/2`D;6%R9VEN.PH@("`@("`@("\J($EF('1H
M97)E(&ES(&$@8W5R<F5N="!P86=E(&%N9"!T:&4@8W5R<F5N="!8('!O<VET
M:6]N(&ES(&QE<W,@=&AA;@H@("`@("`@("`J(&UA<F=I;B!S970@=&AE(%@@
M<&]S:71I;VX@=&\@=&AE(&UA<F=I;B!V86QU92X@*B\*("`@("`@("!I9B`H
M)'1H:7,M/E]P86=E(#X@,"`F)B`D=&AI<RT^>"`\("1M87)G:6XI('L*("`@
M("`@("`@("`@)'1H:7,M/G@@/2`D;6%R9VEN.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($1E9FEN97,@=&AE('1O<"!M87)G:6XN(%1H92!M
M971H;V0@8V%N(&)E(&-A;&QE9"!B969O<F4@8W)E871I;F<@=&AE"B`@("`@
M*B!F:7)S="!P86=E+@H@("`@("H*("`@("`J($!P87)A;2!F;&]A="`D;6%R
M9VEN("!4:&4@;6%R9VEN+@H@("`@("HO"B`@("!F=6YC=&EO;B!S9714;W!-
M87)G:6XH)&UA<F=I;BD*("`@('L*("`@("`@("`D=&AI<RT^7W1O<%]M87)G
M:6X@/2`D;6%R9VEN.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5F:6YE<R!T
M:&4@<FEG:'0@;6%R9VEN+B!4:&4@;65T:&]D(&-A;B!B92!C86QL960@8F5F
M;W)E(&-R96%T:6YG('1H90H@("`@("H@9FER<W0@<&%G92X*("`@("`J"B`@
M("`@*B!`<&%R86T@9FQO870@)&UA<F=I;B`@5&AE(&UA<F=I;BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V5T4FEG:'1-87)G:6XH)&UA<F=I;BD*("`@('L*
M("`@("`@("`D=&AI<RT^7W)I9VAT7VUA<F=I;B`]("1M87)G:6X["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!%;F%B;&5S(&]R(&1I<V%B;&5S('1H92!A=71O
M;6%T:6,@<&%G92!B<F5A:VEN9R!M;V1E+B!7:&5N(&5N86)L:6YG+`H@("`@
M("H@=&AE('-E8V]N9"!P87)A;65T97(@:7,@=&AE(&1I<W1A;F-E(&9R;VT@
M=&AE(&)O='1O;2!O9B!T:&4@<&%G92!T:&%T"B`@("`@*B!D969I;F5S('1H
M92!T<FEG9V5R:6YG(&QI;6ET+B!">2!D969A=6QT+"!T:&4@;6]D92!I<R!O
M;B!A;F0@=&AE(&UA<F=I;@H@("`@("H@:7,@,B!C;2X*("`@("`J"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B!A=71O("`@0F]O;&5A;B!I;F1I8V%T:6YG(&EF
M(&UO9&4@<VAO=6QD(&)E(&]N(&]R(&]F9BX*("`@("`J($!P87)A;2!F;&]A
M="`D;6%R9VEN("!$:7-T86YC92!F<F]M('1H92!B;W1T;VT@;V8@=&AE('!A
M9V4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$%U=&]086=E0G)E86LH)&%U
M=&\L("1M87)G:6X@/2`P*0H@("`@>PH@("`@("`@("1T:&ES+3Y?875T;U]P
M86=E7V)R96%K("`@(#T@)&%U=&\["B`@("`@("`@)'1H:7,M/E]B<F5A:U]M
M87)G:6X@("`@("`@/2`D;6%R9VEN.PH@("`@("`@("1T:&ES+3Y?<&%G95]B
M<F5A:U]T<FEG9V5R(#T@)'1H:7,M/F@@+2`D;6%R9VEN.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1&5F:6YE<R!T:&4@=V%Y('1H92!D;V-U;65N="!I<R!T
M;R!B92!D:7-P;&%Y960@8GD@=&AE('9I97=E<BX@5&AE('IO;VT*("`@("`J
M(&QE=F5L(&-A;B!B92!S970Z('!A9V5S(&-A;B!B92!D:7-P;&%Y960@96YT
M:7)E;'D@;VX@<V-R965N+"!O8V-U<'D@=&AE"B`@("`@*B!F=6QL('=I9'1H
M(&]F('1H92!W:6YD;W<L('5S92!R96%L('-I>F4L(&)E('-C86QE9"!B>2!A
M('-P96-I9FEC"B`@("`@*B!Z;V]M:6YG(&9A8W1O<B!O<B!U<V4@=FEE=V5R
M(&1E9F%U;'0@*&-O;F9I9W5R960@:6X@=&AE(%!R969E<F5N8V5S"B`@("`@
M*B!M96YU(&]F($%C<F]B870I+B!4:&4@<&%G92!L87EO=70@8V%N(&)E('-P
M96-I9FEE9"!T;V\Z('-I;F=L92!A="!O;F-E+`H@("`@("H@8V]N=&EN=6]U
M<R!D:7-P;&%Y+"!T=V\@8V]L=6UN<R!O<B!V:65W97(@9&5F875L="X*("`@
M("`J($)Y(&1E9F%U;'0L(&1O8W5M96YT<R!U<V4@=&AE(&9U;&P@=VED=&@@
M;6]D92!W:71H(&-O;G1I;G5O=7,@9&ES<&QA>2X*("`@("`J"B`@("`@*B!`
M<&%R86T@;6EX960@)'IO;VT@("`@("`@("`@("`@5&AE('IO;VT@=&\@=7-E
M+B!)="!C86X@8F4@;VYE(&]F('1H90H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&9O;&QO=VEN9R!S=')I;F<@=F%L=65S.@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+2!F=6QL<&%G
M93H@96YT:7)E('!A9V4@;VX@<V-R965N"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`M(&9U;&QW:61T:#H@;6%X:6UU;2!W:61T
M:"!O9B!W:6YD;W<*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("T@<F5A;#H@=7-E<R!R96%L('-I>F4@*#$P,"4@>F]O;2D*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("T@9&5F875L
M=#H@=7-E<R!V:65W97(@9&5F875L="!M;V1E"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@;W(@82!N=6UB97(@:6YD:6-A=&EN9R!T
M:&4@>F]O;6EN9R!F86-T;W(N"B`@("`@*B!`<&%R86T@<W1R:6YG(&QA>6]U
M="`@5&AE('!A9V4@;&%Y;W5T+B!0;W-S:6)L92!V86QU97,@87)E.@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@+2!S:6YG;&4Z(&]N92!P86=E
M(&%T(&]N8V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("T@8V]N
M=&EN=6]U<SH@<&%G97,@:6X@8V]N=&EN=6]U<VQY"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`M('1W;SH@='=O('!A9V5S(&]N('1W;R!C;VQU
M;6YS"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M(&1E9F%U;'0Z
M('5S97,@=FEE=V5R(&1E9F%U;'0@;6]D90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@1&5F875L="!V86QU92!I<R!C;VYT:6YU;W5S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S971$:7-P;&%Y36]D92@D>F]O;2P@)&QA>6]U
M="`]("=C;VYT:6YU;W5S)RD*("`@('L*("`@("`@("`D>F]O;2`]('-T<G1O
M;&]W97(H)'IO;VTI.PH@("`@("`@(&EF("@D>F]O;2`]/2`G9G5L;'!A9V4G
M('Q\("1Z;V]M(#T]("=F=6QL=VED=&@G('Q\("1Z;V]M(#T]("=R96%L)PH@
M("`@("`@("`@("!\?"`D>F]O;2`]/2`G9&5F875L="<@?'P@(6ES7W-T<FEN
M9R@D>F]O;2DI('L*("`@("`@("`@("`@)'1H:7,M/E]Z;V]M7VUO9&4@/2`D
M>F]O;3L*("`@("`@("!](&5L<V5I9B`H)'IO;VT@/3T@)WIO;VTG*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?>F]O;5]M;V1E(#T@)&QA>6]U=#L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H<W!R:6YT9B@G26YC;W)R96-T('IO;VT@9&ES<&QA>2!M;V1E.B`E<R<L
M("1Z;V]M*2D["B`@("`@("`@?0H*("`@("`@("`D;&%Y;W5T(#T@<W1R=&]L
M;W=E<B@D;&%Y;W5T*3L*("`@("`@("!I9B`H)&QA>6]U="`]/2`G<VEN9VQE
M)R!\?"`D;&%Y;W5T(#T]("=C;VYT:6YU;W5S)R!\?"`D;&%Y;W5T(#T]("=T
M=V\G"B`@("`@("`@("`@('Q\("1L87EO=70@/3T@)V1E9F%U;'0G*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T7VUO9&4@/2`D;&%Y;W5T.PH@("`@
M("`@('T@96QS96EF("@D>F]O;2`A/2`G>F]O;2<I('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*'-P<FEN=&8H)TEN8V]R<F5C="!L
M87EO=70@9&ES<&QA>2!M;V1E.B`E<R<L("1L87EO=70I*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!8W1I=F%T97,@;W(@9&5A8W1I=F%T
M97,@<&%G92!C;VUP<F5S<VEO;BX@5VAE;B!A8W1I=F%T960L('1H92!I;G1E
M<FYA;`H@("`@("H@<F5P<F5S96YT871I;VX@;V8@96%C:"!P86=E(&ES(&-O
M;7!R97-S960L('=H:6-H(&QE861S('1O(&$@8V]M<')E<W-I;VX*("`@("`J
M(')A=&EO(&]F(&%B;W5T(#(@9F]R('1H92!R97-U;'1I;F<@9&]C=6UE;G0N
M"B`@("`@*B!#;VUP<F5S<VEO;B!I<R!O;B!B>2!D969A=6QT+@H@("`@("H@
M3F]T93H@=&AE(%IL:6(@97AT96YS:6]N(&ES(')E<75I<F5D(&9O<B!T:&ES
M(&9E871U<F4N($EF(&YO="!P<F5S96YT+`H@("`@("H@8V]M<')E<W-I;VX@
M=VEL;"!B92!T=7)N960@;V9F+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L
M96%N("1C;VUP<F5S<R`@0F]O;&5A;B!I;F1I8V%T:6YG(&EF(&-O;7!R97-S
M:6]N(&UU<W0@8F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M96YA8FQE9"!O<B!N;W0N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$-O;7!R
M97-S:6]N*"1C;VUP<F5S<RD*("`@('L*("`@("`@("`O*B!)9B!N;R!G>F-O
M;7!R97-S(&9U;F-T:6]N(&ES(&%V86EL86)L92!T:&5N(&1E9F%U;'0@=&\@
M9F%L<V4N("HO"B`@("`@("`@)'1H:7,M/E]C;VUP<F5S<R`]("AF=6YC=&EO
M;E]E>&ES=',H)V=Z8V]M<')E<W,G*2`_("1C;VUP<F5S<R`Z(&9A;'-E*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@:6YF;R!T;R!A(&1O8W5M
M96YT+B!0;W-S:6)L92!I;F9O('-E='1I;F=S(&%R93H*("`@("`J("`@+2!T
M:71L90H@("`@("H@("`M('-U8FIE8W0*("`@("`J("`@+2!A=71H;W(*("`@
M("`J("`@+2!K97EW;W)D<PH@("`@("H@("`M(&-R96%T;W(*("`@("`J"B`@
M("`@*B!`<&%R86T@;6EX960@)&EN9F\@("`@268@<&%S<V5D(&%S(&%N(&%R
M<F%Y('1H96X@=&AE(&-O;7!L971E(&AA<V@*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!C;VYT86EN:6YG('1H92!I;F9O('1O(&)E(&EN<V5R=&5D
M(&EN=&\@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@9&]C=6UE
M;G0N($]T:&5R=VES92!T:&4@;F%M92!O9B!S971T:6YG('1O(&)E('-E="X*
M("`@("`J($!P87)A;2!S=')I;F<@)'9A;'5E("!4:&4@=F%L=64@;V8@=&AE
M('-E='1I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$EN9F\H)&EN9F\L
M("1V86QU92`]("<G*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D:6YF
M;RDI('L*("`@("`@("`@("`@)'1H:7,M/E]I;F9O(#T@)&EN9F\["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]I;F9O6R1I;F9O72`]
M("1V86QU93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$969I
M;F5S(&%N(&%L:6%S(&9O<B!T:&4@=&]T86P@;G5M8F5R(&]F('!A9V5S+B!)
M="!W:6QL(&)E('-U8G-T:71U=&5D"B`@("`@*B!A<R!T:&4@9&]C=6UE;G0@
M:7,@8VQO<V5D+@H@("`@("H*("`@("`J($5X86UP;&4Z"B`@("`@*B!C;&%S
M<R!->5]&:6QE7U!$1B!E>'1E;F1S($9I;&5?4$1&('L*("`@("`J("`@("!F
M=6YC=&EO;B!F;V]T97(H*0H@("`@("H@("`@('L*("`@("`J("`@("`@("`@
M+R\@1V\@=&\@,2XU(&-M(&9R;VT@8F]T=&]M"B`@("`@*B`@("`@("`@("1T
M:&ES+3YS9719*"TQ-2D["B`@("`@*B`@("`@("`@("\O(%-E;&5C="!!<FEA
M;"!I=&%L:6,@.`H@("`@("H@("`@("`@("`D=&AI<RT^<V5T1F]N="@G07)I
M86PG+"`G22<L(#@I.PH@("`@("H@("`@("`@("`O+R!0<FEN="!C=7)R96YT
M(&%N9"!T;W1A;"!P86=E(&YU;6)E<G,*("`@("`J("`@("`@("`@)'1H:7,M
M/F-E;&PH,"P@,3`L("=086=E("<@+B`D=&AI<RT^9V5T4&%G94YO*"D@+B`G
M+WMN8GTG+"`P+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`P+"`G0R<I
M.PH@("`@("H@("`@('T*("`@("`J('T*("`@("`J("1P9&8@/2`F37E?1FEL
M95]01$8Z.F9A8W1O<GDH*3L*("`@("`J("1P9&8M/F%L:6%S3F)086=E<R@I
M.PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%L:6%S("!4:&4@86QI
M87,N($1E9F%U;'0@=F%L=64Z('MN8GTN"B`@("`@*@H@("`@("H@0'-E92!&
M:6QE7U!$1CHZ9V5T4&%G94YO"B`@("`@*B!`<V5E($9I;&5?4$1&.CIF;V]T
M97(*("`@("`J+PH@("`@9G5N8W1I;VX@86QI87-.8E!A9V5S*"1A;&EA<R`]
M("=[;F)])RD*("`@('L*("`@("`@("`D=&AI<RT^7V%L:6%S7VYB7W!A9V5S
M(#T@)&%L:6%S.PH@("`@?0H*("`@("\J*@H@("`@("H@5&AI<R!M971H;V0@
M8F5G:6YS('1H92!G96YE<F%T:6]N(&]F('1H92!01$8@9&]C=6UE;G0[(&ET
M(&UU<W0@8F4*("`@("`J(&-A;&QE9"!B969O<F4@86YY(&]U='!U="!C;VUM
M86YD<RX@3F\@<&%G92!I<R!C<F5A=&5D(&)Y('1H:7,@;65T:&]D+`H@("`@
M("H@=&AE<F5F;W)E(&ET(&ES(&YE8V5S<V%R>2!T;R!C86QL($9I;&5?4$1&
M.CIA9&1086=E+@H@("`@("H*("`@("`J($!S964@1FEL95]01$8Z.F%D9%!A
M9V4*("`@("`J($!S964@1FEL95]01$8Z.F-L;W-E"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&]P96XH*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8F5G:6Y$;V,H
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1E<FUI;F%T97,@=&AE(%!$1B!D
M;V-U;65N="X@270@:7,@;F]T(&YE8V5S<V%R>2!T;R!C86QL('1H:7,@;65T
M:&]D"B`@("`@*B!E>'!L:6-I=&QY(&)E8V%U<V4@1FEL95]01$8Z.F]U='!U
M="!D;V5S(&ET(&%U=&]M871I8V%L;'DN"B`@("`@*B!)9B!T:&4@9&]C=6UE
M;G0@8V]N=&%I;G,@;F\@<&%G92P@1FEL95]01$8Z.F%D9%!A9V4@:7,@8V%L
M;&5D('1O('!R979E;G0*("`@("`J(&9R;VT@9V5T=&EN9R!A;B!I;G9A;&ED
M(&1O8W5M96YT+@H@("`@("H*("`@("`J($!S964@1FEL95]01$8Z.F]P96X*
M("`@("`J($!S964@1FEL95]01$8Z.F]U='!U=`H@("`@("HO"B`@("!F=6YC
M=&EO;B!C;&]S92@I"B`@("!["B`@("`@("`@+RH@5&5R;6EN871E(&1O8W5M
M96YT("HO"B`@("`@("`@:68@*"1T:&ES+3Y?<&%G92`]/2`P*2!["B`@("`@
M("`@("`@("1T:&ES+3YA9&1086=E*"D["B`@("`@("`@?0H@("`@("`@("\J
M(%!A9V4@9F]O=&5R("HO"B`@("`@("`@)'1H:7,M/E]I;E]F;V]T97(@/2!T
M<G5E.PH@("`@("`@("1T:&ES+3YF;V]T97(H*3L*("`@("`@("`D=&AI<RT^
M7VEN7V9O;W1E<B`](&9A;'-E.PH@("`@("`@("\J($-L;W-E('!A9V4@*B\*
M("`@("`@("`D=&AI<RT^7V5N9%!A9V4H*3L*("`@("`@("`O*B!#;&]S92!D
M;V-U;65N="`J+PH@("`@("`@("1T:&ES+3Y?96YD1&]C*"D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!!9&1S(&$@;F5W('!A9V4@=&\@=&AE(&1O8W5M96YT
M+B!)9B!A('!A9V4@:7,@86QR96%D>2!P<F5S96YT+"!T:&4*("`@("`J($9I
M;&5?4$1&.CIF;V]T97(@;65T:&]D(&ES(&-A;&QE9"!F:7)S="!T;R!O=71P
M=70@=&AE(&9O;W1E<BX@5&AE;B!T:&4*("`@("`J('!A9V4@:7,@861D960L
M('1H92!C=7)R96YT('!O<VET:6]N('-E="!T;R!T:&4@=&]P+6QE9G0@8V]R
M;F5R(&%C8V]R9&EN9PH@("`@("H@=&\@=&AE(&QE9G0@86YD('1O<"!M87)G
M:6YS+"!A;F0@1FEL95]01$8Z.FAE861E<B!I<R!C86QL960@=&\@9&ES<&QA
M>0H@("`@("H@=&AE(&AE861E<BX*("`@("`J(%1H92!F;VYT('=H:6-H('=A
M<R!S970@8F5F;W)E(&-A;&QI;F<@:7,@875T;VUA=&EC86QL>2!R97-T;W)E
M9"X@5&AE<F4*("`@("`J(&ES(&YO(&YE960@=&\@8V%L;"!&:6QE7U!$1CHZ
M<V5T1F]N="!A9V%I;B!I9B!Y;W4@=V%N="!T;R!C;VYT:6YU92!W:71H"B`@
M("`@*B!T:&4@<V%M92!F;VYT+B!4:&4@<V%M92!I<R!T<G5E(&9O<B!C;VQO
M<G,@86YD(&QI;F4@=VED=&@N"B`@("`@*B!4:&4@;W)I9VEN(&]F('1H92!C
M;V]R9&EN871E('-Y<W1E;2!I<R!A="!T:&4@=&]P+6QE9G0@8V]R;F5R(&%N
M9`H@("`@("H@:6YC<F5A<VEN9R!O<F1I;F%T97,@9V\@9&]W;G=A<F1S+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&]R:65N=&%T:6]N("!086=E
M(&]R:65N=&%T:6]N+B!0;W-S:6)L92!V86QU97,*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A<F4@*&-A<V4@:6YS96YS:71I=F4I.@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+2!0(&]R(%!O
M<G1R86ET"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`M
M($P@;W(@3&%N9'-C87!E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@5&AE(&1E9F%U;'0@=F%L=64@:7,@=&AE(&]N92!P87-S960@=&\@
M=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N<W1R
M=6-T;W(N"B`@("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ4$1&"B`@("`@
M*B!`<V5E($9I;&5?4$1&.CIH96%D97(*("`@("`J($!S964@1FEL95]01$8Z
M.F9O;W1E<@H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T36%R9VEN<PH@("`@
M("HO"B`@("!F=6YC=&EO;B!A9&1086=E*"1O<FEE;G1A=&EO;B`]("<G*0H@
M("`@>PH@("`@("`@("\J($9O<B!G;V]D(&UE87-U<F4@;6%K92!S=7)E('1H
M:7,@:7,@8V%L;&5D+B`J+PH@("`@("`@("1T:&ES+3Y?8F5G:6Y$;V,H*3L*
M"B`@("`@("`@+RH@4V%V92!S='EL92!S971T:6YG<R!S;R!T:&%T('1H97D@
M87)E(&YO="!O=F5R<FED9&5N(&)Y"B`@("`@("`@("H@:&5A9&5R*"DN("HO
M"B`@("`@("`@)&QW(#T@)'1H:7,M/E]L:6YE7W=I9'1H.PH@("`@("`@("1D
M8R`]("1T:&ES+3Y?9')A=U]C;VQO<CL*("`@("`@("`D9F,@/2`D=&AI<RT^
M7V9I;&Q?8V]L;W(["B`@("`@("`@:68@*"1T:&ES+3Y?<&%G92`^(#`I('L*
M("`@("`@("`@("`@+RH@4&%G92!F;V]T97(N("HO"B`@("`@("`@("`@("1T
M:&ES+3Y?:6Y?9F]O=&5R(#T@=')U93L*("`@("`@("`@("`@)'1H:7,M/F9O
M;W1E<B@I.PH@("`@("`@("`@("`D=&AI<RT^7VEN7V9O;W1E<B`](&9A;'-E
M.PH@("`@("`@("`@("`O*B!#;&]S92!P86=E+B`J+PH@("`@("`@("`@("`D
M=&AI<RT^7V5N9%!A9V4H*3L*("`@("`@("!]"B`@("`@("`@+RH@4W1A<G0@
M;F5W('!A9V4N("HO"B`@("`@("`@)'1H:7,M/E]B96=I;E!A9V4H)&]R:65N
M=&%T:6]N*3L*("`@("`@("`O*B!3970@;&EN92!C87`@<W1Y;&4@=&\@<W%U
M87)E+B`J+PH@("`@("`@("1T:&ES+3Y?;W5T*"<R($HG*3L*("`@("`@("`O
M*B!3970@;&EN92!W:61T:"X@*B\*("`@("`@("`D=&AI<RT^7VQI;F5?=VED
M=&@@/2`D;'<["B`@("`@("`@)'1H:7,M/E]O=70H<W!R:6YT9B@G)2XR9B!W
M)RP@)&QW("H@)'1H:7,M/E]S8V%L92DI.PH@("`@("`@("\J(%-E="!F;VYT
M(&9O<B!T:&4@8F5G:6YN:6YG(&]F('1H92!P86=E+B`J+PH@("`@("`@(&EF
M("@D=&AI<RT^7V9O;G1?9F%M:6QY*2!["B`@("`@("`@("`@("1T:&ES+3YS
M971&;VYT*"1T:&ES+3Y?9F]N=%]F86UI;'DL("1S='EL92P@)'1H:7,M/E]F
M;VYT7W-I>F5?<'0I.PH@("`@("`@("`@("`D9F]N=%]F86UI;'D@/2`D=&AI
M<RT^7V9O;G1?9F%M:6QY.PH@("`@("`@("`@("`D9F]N=%]S='EL92`]("1T
M:&ES+3Y?9F]N=%]S='EL92`N("@D=&AI<RT^7W5N9&5R;&EN92`_("=5)R`Z
M("<G*3L*("`@("`@("`@("`@)&9O;G1?<VEZ92`@/2`D=&AI<RT^7V9O;G1?
M<VEZ95]P=#L*("`@("`@("!]"B`@("`@("`@+RH@4V5T(&-O;&]R<RX@*B\*
M("`@("`@("`D=&AI<RT^7V9I;&Q?8V]L;W(@/2`D9F,["B`@("`@("`@+RH@
M0VAE8VL@:68@9FEL;"!C;VQO<B!H87,@8F5E;B!S970@8F5F;W)E('1H:7,@
M<&%G92X@*B\*("`@("`@("!I9B`H)'1H:7,M/E]F:6QL7V-O;&]R("$]("<P
M(&<G*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"1T:&ES+3Y?9FEL;%]C
M;VQO<BD["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?9')A=U]C;VQO<B`]
M("1D8SL*("`@("`@("`O*B!#:&5C:R!I9B!D<F%W(&-O;&]R(&AA<R!B965N
M('-E="!B969O<F4@=&AI<R!P86=E+B`J+PH@("`@("`@(&EF("@D=&AI<RT^
M7V1R87=?8V]L;W(@(3T@)S`@1R<I('L*("`@("`@("`@("`@)'1H:7,M/E]O
M=70H)'1H:7,M/E]D<F%W7V-O;&]R*3L*("`@("`@("!]"B`@("`@("`@+RH@
M4&%G92!H96%D97(N("HO"B`@("`@("`@)'1H:7,M/FAE861E<B@I.PH@("`@
M("`@("\J(%)E<W1O<F4@;&EN92!W:61T:"X@*B\*("`@("`@("!I9B`H)'1H
M:7,M/E]L:6YE7W=I9'1H("$]("1L=RD@>PH@("`@("`@("`@("`D=&AI<RT^
M7VQI;F5?=VED=&@@/2`D;'<["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*'-P
M<FEN=&8H)R4N,F8@=R<L("1L=R`J("1T:&ES+3Y?<V-A;&4I*3L*("`@("`@
M("!]"B`@("`@("`@+RH@36%K92!S=7)E('1H92!F;VYT(&ES('-E="!F;W(@
M=&AI<R!P86=E(&%S(&ET('=A<R!B969O<F4@=&AE"B`@("`@("`@("H@:&5A
M9&5R+B`J+PH@("`@("`@(&EF("@D9F]N=%]F86UI;'DI('L*("`@("`@("`@
M("`@)'1H:7,M/G-E=$9O;G0H)&9O;G1?9F%M:6QY+"`D9F]N=%]S='EL92P@
M)&9O;G1?<VEZ92P@=')U92D["B`@("`@("`@?0H@("`@("`@("\J(%)E<W1O
M<F4@8V]L;W)S+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7V1R87=?8V]L;W(@
M(3T@)&1C*2!["B`@("`@("`@("`@("1T:&ES+3Y?9')A=U]C;VQO<B`]("1D
M8SL*("`@("`@("`@("`@)'1H:7,M/E]O=70H)&1C*3L*("`@("`@("!]"B`@
M("`@("`@:68@*"1T:&ES+3Y?9FEL;%]C;VQO<B`A/2`D9F,I('L*("`@("`@
M("`@("`@)'1H:7,M/E]F:6QL7V-O;&]R(#T@)&9C.PH@("`@("`@("`@("`D
M=&AI<RT^7V]U="@D9F,I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%1H:7,@;65T:&]D(&ES('5S960@=&\@<F5N9&5R('1H92!P86=E(&AE
M861E<BX@270@:7,@875T;VUA=&EC86QL>0H@("`@("H@8V%L;&5D(&)Y($9I
M;&5?4$1&.CIA9&1086=E(&%N9"!S:&]U;&0@;F]T(&)E(&-A;&QE9"!D:7)E
M8W1L>2!B>2!T:&4*("`@("`J(&%P<&QI8V%T:6]N+B!4:&4@:6UP;&5M96YT
M871I;VX@:6X@1FEL95]01$8Z.B!I<R!E;7!T>2P@<V\@>6]U(&AA=F4@=&\*
M("`@("`J('-U8F-L87-S(&ET(&%N9"!O=F5R<FED92!T:&4@;65T:&]D(&EF
M('EO=2!W86YT(&$@<W!E8VEF:6,@<')O8V5S<VEN9RX*("`@("`J"B`@("`@
M*B!%>&%M<&QE.@H@("`@("H*("`@("`J(&-L87-S($UY7T9I;&5?4$1&(&5X
M=&5N9',@1FEL95]01$8@>PH@("`@("H@("`@(&9U;F-T:6]N(&AE861E<B@I
M"B`@("`@*B`@("`@>PH@("`@("H@("`@("`@("`O+R!396QE8W0@07)I86P@
M8F]L9"`Q-0H@("`@("H@("`@("`@("`D=&AI<RT^<V5T1F]N="@G07)I86PG
M+"`G0B<L(#$U*3L*("`@("`J("`@("`@("`@+R\@36]V92!T;R!T:&4@<FEG
M:'0*("`@("`J("`@("`@("`@)'1H:7,M/F-E;&PH.#`I.PH@("`@("H@("`@
M("`@("`O+R!&<F%M960@=&ET;&4*("`@("`J("`@("`@("`@)'1H:7,M/F-E
M;&PH,S`L(#$P+"`G5&ET;&4G+"`Q+"`P+"`G0R<I.PH@("`@("H@("`@("`@
M("`O+R!,:6YE(&)R96%K"B`@("`@*B`@("`@("`@("1T:&ES+3YN97=,:6YE
M*#(P*3L*("`@("`J("`@("!]"B`@("`@*B!]"B`@("`@*@H@("`@("H@0'-E
M92!&:6QE7U!$1CHZ9F]O=&5R"B`@("`@*B\*("`@(&9U;F-T:6]N(&AE861E
M<B@I"B`@("!["B`@("`@("`@+RH@5&\@8F4@:6UP;&5M96YT960@:6X@>6]U
M<B!O=VX@:6YH97)I=&5D(&-L87-S+B`J+PH@("`@?0H*("`@("\J*@H@("`@
M("H@5&AI<R!M971H;V0@:7,@=7-E9"!T;R!R96YD97(@=&AE('!A9V4@9F]O
M=&5R+B!)="!I<R!A=71O;6%T:6-A;&QY"B`@("`@*B!C86QL960@8GD@1FEL
M95]01$8Z.F%D9%!A9V4@86YD($9I;&5?4$1&.CIC;&]S92!A;F0@<VAO=6QD
M(&YO="!B92!C86QL960*("`@("`J(&1I<F5C=&QY(&)Y('1H92!A<'!L:6-A
M=&EO;BX@5&AE(&EM<&QE;65N=&%T:6]N(&EN($9I;&5?4$1&.CH@:7,@96UP
M='DL"B`@("`@*B!S;R!Y;W4@:&%V92!T;R!S=6)C;&%S<R!I="!A;F0@;W9E
M<G)I9&4@=&AE(&UE=&AO9"!I9B!Y;W4@=V%N="!A('-P96-I9FEC"B`@("`@
M*B!P<F]C97-S:6YG+@H@("`@("H*("`@("`J($5X86UP;&4Z"B`@("`@*@H@
M("`@("H@8VQA<W,@37E?1FEL95]01$8@97AT96YD<R!&:6QE7U!$1B!["B`@
M("`@*B`@("!F=6YC=&EO;B!F;V]T97(H*0H@("`@("H@("`@>PH@("`@("H@
M("`@("`@("\O($=O('1O(#$N-2!C;2!F<F]M(&)O='1O;0H@("`@("H@("`@
M("`@("1T:&ES+3YS9719*"TQ-2D["B`@("`@*B`@("`@("`@+R\@4V5L96-T
M($%R:6%L(&ET86QI8R`X"B`@("`@*B`@("`@("`@)'1H:7,M/G-E=$9O;G0H
M)T%R:6%L)RP@)TDG+"`X*3L*("`@("`J("`@("`@("`O+R!0<FEN="!C96YT
M97)E9"!P86=E(&YU;6)E<@H@("`@("H@("`@("`@("1T:&ES+3YC96QL*#`L
M(#$P+"`G4&%G92`G("X@)'1H:7,M/F=E=%!A9V5.;R@I+"`P+"`P+"`G0R<I
M.PH@("`@("H@("`@?0H@("`@("H@?0H@("`@("H*("`@("`J($!S964@1FEL
M95]01$8Z.FAE861E<@H@("`@("HO"B`@("!F=6YC=&EO;B!F;V]T97(H*0H@
M("`@>PH@("`@("`@("\J(%1O(&)E(&EM<&QE;65N=&5D(&EN('EO=7(@;W=N
M(&EN:&5R:71E9"!C;&%S<RX@*B\*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE(&-U<G)E;G0@<&%G92!N=6UB97(N"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G1E9V5R"B`@("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ
M86QI87-.8E!A9V5S"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A9V5.;R@I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%G93L*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E=',@=&AE(&9I;&P@8V]L;W(N(%-P96-I9FEE<R!T
M:&4@8V]L;W(@9F]R(&)O=&@@9FEL;&5D(&%R96%S(&%N9`H@("`@("H@=&5X
M="X@1&5P96YD:6YG(&]N('1H92!C;VQO<G-P86-E(&-A;&QE9"P@=&AE(&YU
M;6)E<B!O9B!C;VQO<B!C;VUP;VYE;G0*("`@("`J('!A<F%M971E<G,@<F5Q
M=6ER960@8V%N(&)E(&5I=&AE<B`Q+"`S(&]R(#0N(%1H92!M971H;V0@8V%N
M(&)E(&-A;&QE9`H@("`@("H@8F5F;W)E('1H92!F:7)S="!P86=E(&ES(&-R
M96%T960@86YD('1H92!C;VQO<B!I<R!R971A:6YE9"!F<F]M('!A9V4@=&\*
M("`@("`J('!A9V4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8W,@
M($EN9&EC871E<R!T:&4@8V]L;W)S<&%C92!W:&EC:"!C86X@8F4@96ET:&5R
M("=R9V(G+`H@("`@("H@("`@("`@("`@("`@("`@("`@("=C;7EK)R!O<B`G
M9W)A>2<N($1E9F%U;'1S('1O("=R9V(G+@H@("`@("H@0'!A<F%M(&9L;V%T
M("1C,2`@($9I<G-T(&-O;&]R(&-O;7!O;F5N="P@9FQO871I;F<@<&]I;G0@
M=F%L=64@8F5T=V5E;B`P"B`@("`@*B`@("`@("`@("`@("`@("`@("`@86YD
M(#$N(%)E<75I<F5D(&9O<B!G<F%Y+"!R9V(@86YD(&-M>6LN"B`@("`@*B!`
M<&%R86T@9FQO870@)&,R("`@4V5C;VYD(&-O;&]R(&-O;7!O;F5N="P@9FQO
M871I;F<@<&]I;G0@=F%L=64@8F5T=V5E;@H@("`@("H@("`@("`@("`@("`@
M("`@("`@(#`@86YD(#$N(%)E<75I<F5D(&9O<B!R9V(@86YD(&-M>6LN"B`@
M("`@*B!`<&%R86T@9FQO870@)&,S("`@5&AI<F0@8V]L;W(@8V]M<&]N96YT
M+"!F;&]A=&EN9R!P;VEN="!V86QU92!B971W965N"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@,"!A;F0@,2X@4F5Q=6ER960@9F]R(')G8B!A;F0@8VUY
M:RX*("`@("`J($!P87)A;2!F;&]A="`D8S0@("!&;W5R=&@@8V]L;W(@8V]M
M<&]N96YT+"!F;&]A=&EN9R!P;VEN="!V86QU92!B971W965N"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@,"!A;F0@,2X@4F5Q=6ER960@9F]R(&-M>6LN
M"B`@("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T1')A=T-O;&]R"B`@
M("`@*B!`<V5E($9I;&5?4$1&.CIR96-T"B`@("`@*B!`<V5E($9I;&5?4$1&
M.CIC96QL"B`@("`@*B!`<V5E($9I;&5?4$1&.CIM=6QT:4-E;&P*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V5T1FEL;$-O;&]R*"1C<R`]("=R9V(G+"`D8S$L
M("1C,B`](#`L("1C,R`](#`L("1C-"`](#`I"B`@("!["B`@("`@("`@)&-S
M(#T@<W1R=&]L;W=E<B@D8W,I.PH@("`@("`@(&EF("@D8W,@/3T@)W)G8B<I
M('L*("`@("`@("`@("`@)'1H:7,M/E]F:6QL7V-O;&]R(#T@<W!R:6YT9B@G
M)2XS9B`E+C-F("4N,V8@<F<G+"`D8S$L("1C,BP@)&,S*3L*("`@("`@("!]
M(&5L<V5I9B`H)&-S(#T]("=C;7EK)RD@>PH@("`@("`@("`@("`D=&AI<RT^
M7V9I;&Q?8V]L;W(@/2!S<')I;G1F*"<E+C-F("4N,V8@)2XS9B`E+C-F(&LG
M+"`D8S$L("1C,BP@)&,S+"`D8S0I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1T:&ES+3Y?9FEL;%]C;VQO<B`]('-P<FEN=&8H)R4N,V8@9R<L
M("1C,2D["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^7W!A9V4@/B`P
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"1T:&ES+3Y?9FEL;%]C;VQO
M<BD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@
M9')A=R!C;VQO<BP@=7-E9"!W:&5N(&1R87=I;F<@;&EN97,N($1E<&5N9&EN
M9R!O;B!T:&4*("`@("`J(&-O;&]R<W!A8V4@8V%L;&5D+"!T:&4@;G5M8F5R
M(&]F(&-O;&]R(&-O;7!O;F5N="!P87)A;65T97)S(')E<75I<F5D"B`@("`@
M*B!C86X@8F4@96ET:&5R(#$L(#,@;W(@-"X@5&AE(&UE=&AO9"!C86X@8F4@
M8V%L;&5D(&)E9F]R92!T:&4@9FER<W0@<&%G90H@("`@("H@:7,@8W)E871E
M9"!A;F0@=&AE(&-O;&]R(&ES(')E=&%I;F5D(&9R;VT@<&%G92!T;R!P86=E
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-S("!);F1I8V%T97,@
M=&AE(&-O;&]R<W!A8V4@=VAI8V@@8V%N(&)E(&5I=&AE<B`G<F=B)RP*("`@
M("`J("`@("`@("`@("`@("`@("`@("`G8VUY:R<@;W(@)V=R87DG+B!$969A
M=6QT<R!T;R`G<F=B)RX*("`@("`J($!P87)A;2!F;&]A="`D8S$@("!&:7)S
M="!C;VQO<B!C;VUP;VYE;G0L(&9L;V%T:6YG('!O:6YT('9A;'5E(&)E='=E
M96X@,`H@("`@("H@("`@("`@("`@("`@("`@("`@(&%N9"`Q+B!297%U:7)E
M9"!F;W(@9W)A>2P@<F=B(&%N9"!C;7EK+@H@("`@("H@0'!A<F%M(&9L;V%T
M("1C,B`@(%-E8V]N9"!C;VQO<B!C;VUP;VYE;G0L(&9L;V%T:6YG('!O:6YT
M('9A;'5E(&)E='=E96X*("`@("`J("`@("`@("`@("`@("`@("`@("`P(&%N
M9"`Q+B!297%U:7)E9"!F;W(@<F=B(&%N9"!C;7EK+@H@("`@("H@0'!A<F%M
M(&9L;V%T("1C,R`@(%1H:7)D(&-O;&]R(&-O;7!O;F5N="P@9FQO871I;F<@
M<&]I;G0@=F%L=64@8F5T=V5E;B`P"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@86YD(#$N(%)E<75I<F5D(&9O<B!R9V(@86YD(&-M>6LN"B`@("`@*B!`
M<&%R86T@9FQO870@)&,T("`@1F]U<G1H(&-O;&]R(&-O;7!O;F5N="P@9FQO
M871I;F<@<&]I;G0@=F%L=64@8F5T=V5E;@H@("`@("H@("`@("`@("`@("`@
M("`@("`@(#`@86YD(#$N(%)E<75I<F5D(&9O<B!C;7EK+@H@("`@("H*("`@
M("`J($!S964@1FEL95]01$8Z.G-E=$9I;&Q#;VQO<@H@("`@("H@0'-E92!&
M:6QE7U!$1CHZ;&EN90H@("`@("H@0'-E92!&:6QE7U!$1CHZ<F5C=`H@("`@
M("H@0'-E92!&:6QE7U!$1CHZ8V5L;`H@("`@("H@0'-E92!&:6QE7U!$1CHZ
M;75L=&E#96QL"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$1R87=#;VQO<B@D
M8W,@/2`G<F=B)RP@)&,Q+"`D8S(@/2`P+"`D8S,@/2`P+"`D8S0@/2`P*0H@
M("`@>PH@("`@("`@("1C<R`]('-T<G1O;&]W97(H)&-S*3L*("`@("`@("!I
M9B`H)&-S(#T]("=R9V(G*2!["B`@("`@("`@("`@("1T:&ES+3Y?9')A=U]C
M;VQO<B`]('-P<FEN=&8H)R4N,V8@)2XS9B`E+C-F(%)')RP@)&,Q+"`D8S(L
M("1C,RD["B`@("`@("`@?2!E;'-E:68@*"1C<R`]/2`G8VUY:R<I('L*("`@
M("`@("`@("`@)'1H:7,M/E]D<F%W7V-O;&]R(#T@<W!R:6YT9B@G)2XS9B`E
M+C-F("4N,V8@)2XS9B!+)RP@)&,Q+"`D8S(L("1C,RP@)&,T*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7V1R87=?8V]L;W(@/2!S
M<')I;G1F*"<E+C-F($<G+"`D8S$I.PH@("`@("`@('T*("`@("`@("!I9B`H
M)'1H:7,M/E]P86=E(#X@,"D@>PH@("`@("`@("`@("`D=&AI<RT^7V]U="@D
M=&AI<RT^7V1R87=?8V]L;W(I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE(&QE;F=T:"!O9B!A('1E>'0@<W1R:6YG+B!!
M(&9O;G0@;75S="!B92!S96QE8W1E9"X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1T97AT("!4:&4@=&5X="!W:&]S92!L96YG=&@@:7,@=&\@8F4@
M8V]M<'5T960N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<'0@("!";V]L96%N
M('1O(&EN9&EC871E(&EF('1H92!W:61T:"!S:&]U;&0@8F4@<F5T=7)N960*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@(&EN('!O:6YT<R!O<B!U<V5R
M('5N:71S+B!$969A=6QT(&ES("=F86QS92<N"B`@("`@*@H@("`@("H@0')E
M='5R;B!F;&]A=`H@("`@("HO"B`@("!F=6YC=&EO;B!G9713=')I;F=7:61T
M:"@D=&5X="P@)'!T(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1E>'0@/2`H
M<W1R:6YG*21T97AT.PH@("`@("`@("1W:61T:"`](#`["B`@("`@("`@)&QE
M;F=T:"`]('-T<FQE;B@D=&5X="D["B`@("`@("`@9F]R("@D:2`](#`[("1I
M(#P@)&QE;F=T:#L@)&DK*RD@>PH@("`@("`@("`@("`D=VED=&@@*ST@)'1H
M:7,M/E]C=7)R96YT7V9O;G1;)V-W)UU;)'1E>'1[)&E]73L*("`@("`@("!]
M"@H@("`@("`@("\J($%D:G5S="!F;W(@=V]R9"!S<&%C:6YG+B`J+PH@("`@
M("`@("1W:61T:"`K/2`D=&AI<RT^7W=O<F1?<W!A8VEN9R`J('-U8G-T<E]C
M;W5N="@D=&5X="P@)R`G*2`J("1T:&ES+3Y?8W5R<F5N=%]F;VYT6R=C=R==
M6R<@)UT["@H@("`@("`@(&EF("@D<'0I('L*("`@("`@("`@("`@<F5T=7)N
M("1W:61T:"`J("1T:&ES+3Y?9F]N=%]S:7IE7W!T("\@,3`P,#L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'=I9'1H("H@)'1H:7,M
M/E]F;VYT7W-I>F4@+R`Q,#`P.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($1E9FEN97,@=&AE(&QI;F4@=VED=&@N($)Y(&1E9F%U;'0L('1H
M92!V86QU92!E<75A;',@,"XR(&UM+B!4:&4@;65T:&]D"B`@("`@*B!C86X@
M8F4@8V%L;&5D(&)E9F]R92!T:&4@9FER<W0@<&%G92!I<R!C<F5A=&5D(&%N
M9"!T:&4@=F%L=64@:7,*("`@("`J(')E=&%I;F5D(&9R;VT@<&%G92!T;R!P
M86=E+@H@("`@("H*("`@("`J($!P87)A;2!F;&]A="`D=VED=&@@(%1H92!W
M:61T:"X*("`@("`J"B`@("`@*B!`<V5E($9I;&5?4$1&.CIL:6YE"B`@("`@
M*B!`<V5E($9I;&5?4$1&.CIR96-T"B`@("`@*B!`<V5E($9I;&5?4$1&.CIC
M96QL"B`@("`@*B!`<V5E($9I;&5?4$1&.CIM=6QT:4-E;&P*("`@("`J+PH@
M("`@9G5N8W1I;VX@<V5T3&EN95=I9'1H*"1W:61T:"D*("`@('L*("`@("`@
M("`D=&AI<RT^7VQI;F5?=VED=&@@/2`D=VED=&@["B`@("`@("`@:68@*"1T
M:&ES+3Y?<&%G92`^(#`I('L*("`@("`@("`@("`@)'1H:7,M/E]O=70H<W!R
M:6YT9B@G)2XR9B!W)RP@)'=I9'1H("H@)'1H:7,M/E]S8V%L92DI.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1R87=S(&$@;&EN92!B971W
M965N('1W;R!P;VEN=',N"B`@("`@*@H@("`@("H@0'!A<F%M(&9L;V%T("1X
M,2`@06)S8VES<V$@;V8@9FER<W0@<&]I;G0N"B`@("`@*B!`<&%R86T@9FQO
M870@)'DQ("!/<F1I;F%T92!O9B!F:7)S="!P;VEN="X*("`@("`J($!P87)A
M;2!F;&]A="`D>#(@($%B<V-I<W-A(&]F('-E8V]N9"!P;VEN="X*("`@("`J
M($!P87)A;2!F;&]A="`D>3(@($]R9&EN871E(&]F('-E8V]N9"!P;VEN="X*
M("`@("`J"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS971,:6YE5VED=&@*("`@
M("`J($!S964@1FEL95]01$8Z.G-E=$1R87=#;VQO<BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@;&EN92@D>#$L("1Y,2P@)'@R+"`D>3(I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]O=70H<W!R:6YT9B@G)2XR9B`E+C)F(&T@)2XR9B`E+C)F
M(&P@4R<L("1X,2`J("1T:&ES+3Y?<V-A;&4L("@D=&AI<RT^:"`M("1Y,2D@
M*B`D=&AI<RT^7W-C86QE+"`D>#(@*B`D=&AI<RT^7W-C86QE+"`H)'1H:7,M
M/F@@+2`D>3(I("H@)'1H:7,M/E]S8V%L92DI.PH@("`@?0H*("`@("\J*@H@
M("`@("H@3W5T<'5T<R!A(')E8W1A;F=L92X@270@8V%N(&)E(&1R87=N("AB
M;W)D97(@;VYL>2DL(&9I;&QE9"`H=VET:"!N;PH@("`@("H@8F]R9&5R*2!O
M<B!B;W1H+@H@("`@("H*("`@("`J($!P87)A;2!F;&]A="`D>"`@("`@("!!
M8G-C:7-S82!O9B!U<'!E<BUL969T(&-O<FYE<BX*("`@("`J($!P87)A;2!F
M;&]A="`D>2`@("`@("!/<F1I;F%T92!O9B!U<'!E<BUL969T(&-O<FYE<BX*
M("`@("`J($!P87)A;2!F;&]A="`D=VED=&@@("!7:61T:"X*("`@("`J($!P
M87)A;2!F;&]A="`D:&5I9VAT("!(96EG:'0N"B`@("`@*B!`<&%R86T@9FQO
M870@)'-T>6QE("`@4W1Y;&4@;V8@<F5N9&5R:6YG+B!0;W-S:6)L92!V86QU
M97,@87)E.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@+2!$(&]R
M(&5M<'1Y('-T<FEN9SH@9')A=R`H9&5F875L="D*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("T@1CH@9FEL;`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@+2!$1B!O<B!&1#H@9')A=R!A;F0@9FEL;`H@("`@("H*
M("`@("`J($!S964@1FEL95]01$8Z.G-E=$QI;F57:61T:`H@("`@("H@0'-E
M92!&:6QE7U!$1CHZ<V5T1')A=T-O;&]R"B`@("`@*B!`<V5E($9I;&5?4$1&
M.CIS971&:6QL0V]L;W(*("`@("`J+PH@("`@9G5N8W1I;VX@<F5C="@D>"P@
M)'DL("1W:61T:"P@)&AE:6=H="P@)'-T>6QE(#T@)R<I"B`@("!["B`@("`@
M("`@)'-T>6QE(#T@<W1R=&]U<'!E<B@D<W1Y;&4I.PH@("`@("`@(&EF("@D
M<W1Y;&4@/3T@)T8G*2!["B`@("`@("`@("`@("1O<"`]("=F)SL*("`@("`@
M("!](&5L<V5I9B`H)'-T>6QE(#T]("=&1"<@?'P@)'-T>6QE(#T]("=$1B<I
M('L*("`@("`@("`@("`@)&]P(#T@)T(G.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1O<"`]("=3)SL*("`@("`@("!]"@H@("`@("`@("1X("`@
M("`@/2`D=&AI<RT^7W1O4'0H)'@I.PH@("`@("`@("1Y("`@("`@/2`D=&AI
M<RT^7W1O4'0H)'DI.PH@("`@("`@("1W:61T:"`@/2`D=&AI<RT^7W1O4'0H
M)'=I9'1H*3L*("`@("`@("`D:&5I9VAT(#T@)'1H:7,M/E]T;U!T*"1H96EG
M:'0I.PH*("`@("`@("`D=&AI<RT^7V]U="AS<')I;G1F*"<E+C)F("4N,F8@
M)2XR9B`E+C)F(')E("5S)RP@)'@L("1T:&ES+3YH4'0@+2`D>2P@)'=I9'1H
M+"`M)&AE:6=H="P@)&]P*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!/=71P
M=71S(&$@8VER8VQE+B!)="!C86X@8F4@9')A=VX@*&)O<F1E<B!O;FQY*2P@
M9FEL;&5D("AW:71H(&YO"B`@("`@*B!B;W)D97(I(&]R(&)O=&@N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&9L;V%T("1X("`@("`@($%B<V-I<W-A(&]F('1H
M92!C96YT97(@;V8@=&AE(&-I<F-L92X*("`@("`J($!P87)A;2!F;&]A="`D
M>2`@("`@("!/<F1I;F%T92!O9B!T:&4@8V5N=&5R(&]F('1H92!C:7)C;&4N
M"B`@("`@*B!`<&%R86T@9FQO870@)'(@("`@("`@0VER8VQE(')A9&EU<RX*
M("`@("`J($!P87)A;2!S=')I;F<@)'-T>6QE("!3='EL92!O9B!R96YD97)I
M;F<N(%!O<W-I8FQE('9A;'5E<R!A<F4Z"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`M($0@;W(@96UP='D@<W1R:6YG.B!D<F%W("AD969A=6QT
M*0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@+2!&.B!F:6QL"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M($1&(&]R($9$.B!D<F%W
M(&%N9"!F:6QL"B`@("`@*B\*("`@(&9U;F-T:6]N(&-I<F-L92@D>"P@)'DL
M("1R+"`D<W1Y;&4@/2`G)RD*("`@('L*("`@("`@("`D<W1Y;&4@/2!S=')T
M;VQO=V5R*"1S='EL92D["B`@("`@("`@:68@*"1S='EL92`]/2`G9B<I('L*
M("`@("`@("`@("`@)&]P(#T@)V8G.R`@("`@("\O(%-T>6QE(&ES(&9I;&P@
M;VYL>2X*("`@("`@("!](&5L<V5I9B`H)'-T>6QE(#T]("=F9"<@?'P@)'-T
M>6QE(#T]("=D9B<I('L*("`@("`@("`@("`@)&]P(#T@)T(G.R`@("`@("\O
M(%-T>6QE(&ES(&9I;&P@86YD('-T<F]K92X*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D;W`@/2`G4R<[("`@("`@+R\@4W1Y;&4@:7,@<W1R;VME
M(&]N;'DN"B`@("`@("`@?0H*("`@("`@("`D>"`]("1T:&ES+3Y?=&]0="@D
M>"D["B`@("`@("`@)'D@/2`D=&AI<RT^7W1O4'0H)'DI.PH@("`@("`@("1R
M(#T@)'1H:7,M/E]T;U!T*"1R*3L*"B`@("`@("`@+RH@26YV97)T('1H92!Y
M('-C86QE+B`J+PH@("`@("`@("1Y(#T@)'1H:7,M/FA0="`M("1Y.PH@("`@
M("`@("\J($QE;F=T:"!O9B!T:&4@0F5Z:65R(&-O;G1R;VPN("HO"B`@("`@
M("`@)&(@/2`D<B`J(#`N-34R.PH*("`@("`@("`O*B!-;W9E(&9R;VT@=&AE
M(&=I=F5N(&]R:6=I;B!A;F0@<V5T('1H92!C=7)R96YT('!O:6YT"B`@("`@
M("`@("H@=&\@=&AE('-T87)T(&]F('1H92!F:7)S="!"97II97(@8W5R=F4N
M("HO"B`@("`@("`@)&,@/2!S<')I;G1F*"<E+C)F("4N,F8@;2<L("1X("T@
M)'(L("1Y*3L*("`@("`@("`D>"`]("1X("T@)'(["B`@("`@("`@+RH@1FER
M<W0@8VER8VQE('%U87)T97(N("HO"B`@("`@("`@)&,@+CT@<W!R:6YT9B@G
M("4N,F8@)2XR9B`E+C)F("4N,F8@)2XR9B`E+C)F(&,G+`H@("`@("`@("`@
M("`@("`@("`@("`@)'@L("1Y("L@)&(L("`@("`@("`@("`O+R!&:7)S="!C
M;VYT<F]L('!O:6YT+@H@("`@("`@("`@("`@("`@("`@("`@)'@@*R`D<B`M
M("1B+"`D>2`K("1R+"`O+R!396-O;F0@8V]N=')O;"!P;VEN="X*("`@("`@
M("`@("`@("`@("`@("`@("1X("L@)'(L("1Y("L@)'(I.R`@("`@+R\@1FEN
M86P@<&]I;G0N"B`@("`@("`@+RH@4V5T('@O>2!T;R!T:&4@9FEN86P@<&]I
M;G0N("HO"B`@("`@("`@)'@@/2`D>"`K("1R.PH@("`@("`@("1Y(#T@)'D@
M*R`D<CL*("`@("`@("`O*B!396-O;F0@8VER8VQE('%U87)T97(N("HO"B`@
M("`@("`@)&,@+CT@<W!R:6YT9B@G("4N,F8@)2XR9B`E+C)F("4N,F8@)2XR
M9B`E+C)F(&,G+`H@("`@("`@("`@("`@("`@("`@("`@)'@@*R`D8BP@)'DL
M"B`@("`@("`@("`@("`@("`@("`@("`D>"`K("1R+"`D>2`M("1R("L@)&(L
M"B`@("`@("`@("`@("`@("`@("`@("`D>"`K("1R+"`D>2`M("1R*3L*("`@
M("`@("`O*B!3970@>"]Y('1O('1H92!F:6YA;"!P;VEN="X@*B\*("`@("`@
M("`D>"`]("1X("L@)'(["B`@("`@("`@)'D@/2`D>2`M("1R.PH@("`@("`@
M("\J(%1H:7)D(&-I<F-L92!Q=6%R=&5R+B`J+PH@("`@("`@("1C("X]('-P
M<FEN=&8H)R`E+C)F("4N,F8@)2XR9B`E+C)F("4N,F8@)2XR9B!C)RP*("`@
M("`@("`@("`@("`@("`@("`@("1X+"`D>2`M("1B+`H@("`@("`@("`@("`@
M("`@("`@("`@)'@@+2`D<B`K("1B+"`D>2`M("1R+`H@("`@("`@("`@("`@
M("`@("`@("`@)'@@+2`D<BP@)'D@+2`D<BD["B`@("`@("`@+RH@4V5T('@O
M>2!T;R!T:&4@9FEN86P@<&]I;G0N("HO"B`@("`@("`@)'@@/2`D>"`M("1R
M.PH@("`@("`@("1Y(#T@)'D@+2`D<CL*("`@("`@("`O*B!&;W5R=&@@8VER
M8VQE('%U87)T97(N("HO"B`@("`@("`@)&,@+CT@<W!R:6YT9B@G("4N,F8@
M)2XR9B`E+C)F("4N,F8@)2XR9B`E+C)F(&,@)7,G+`H@("`@("`@("`@("`@
M("`@("`@("`@)'@@+2`D8BP@)'DL"B`@("`@("`@("`@("`@("`@("`@("`D
M>"`M("1R+"`D>2`K("1R("T@)&(L"B`@("`@("`@("`@("`@("`@("`@("`D
M>"`M("1R+"`D>2`K("1R+`H@("`@("`@("`@("`@("`@("`@("`@)&]P*3L*
M("`@("`@("`O*B!/=71P=70@=&AE('=H;VQE('-T<FEN9RX@*B\*("`@("`@
M("`D=&AI<RT^7V]U="@D8RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!);7!O
M<G1S(&$@5')U951Y<&4@;W(@5'EP93$@9F]N="!A;F0@;6%K97,@:70@879A
M:6QA8FQE+B!)="!I<PH@("`@("H@;F5C97-S87)Y('1O(&=E;F5R871E(&$@
M9F]N="!D969I;FET:6]N(&9I;&4@9FER<W0@=VET:"!T:&4*("`@("`J(&UA
M:V5F;VYT+G!H<"!U=&EL:71Y+@H@("`@("H@5&AE(&QO8V%T:6]N(&]F('1H
M92!D969I;FET:6]N(&9I;&4@*&%N9"!T:&4@9F]N="!F:6QE(&ET<V5L9B!W
M:&5N"B`@("`@*B!E;6)E9&1I;F<I(&UU<W0@8F4@9F]U;F0@870@=&AE(&9U
M;&P@<&%T:"!N86UE(&EN8VQU9&5D+@H@("`@("H*("`@("`J($5X86UP;&4Z
M"B`@("`@*B`D<&1F+3YA9&1&;VYT*"=#;VUI8R<L("=))RD["B`@("`@*B!I
M<R!E<75I=F%L96YT('1O.@H@("`@("H@)'!D9BT^861D1F]N="@G0V]M:6,G
M+"`G22<L("=C;VUI8VDN<&AP)RD["B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9F%M:6QY("!&;VYT(&9A;6EL>2X@5&AE(&YA;64@8V%N(&)E(&-H
M;W-E;B!A<F)I=')A<FEL>2X*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@268@:70@:7,@82!S=&%N9&%R9"!F86UI;'D@;F%M92P@:70@=VEL;`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("!O=F5R<FED92!T:&4@8V]R
M<F5S<&]N9&EN9R!F;VYT+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<W1Y;&4@
M("!&;VYT('-T>6QE+B!0;W-S:6)L92!V86QU97,@87)E("AC87-E"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@(&EN<V5N<VET:79E*3H*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`M(&5M<'1Y('-T<FEN9SH@<F5G
M=6QA<B`H9&5F875L="D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`M($(Z(&)O;&0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`M
M($DZ(&ET86QI8PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("T@
M0DD@;W(@24(Z(&)O;&0@:71A;&EC"B`@("`@*B!`<&%R86T@<W1R:6YG("1F
M:6QE("`@(%1H92!F;VYT(&1E9FEN:71I;VX@9FEL92X@0GD@9&5F875L="P@
M=&AE(&YA;64@:7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@8G5I
M;'0@9G)O;2!T:&4@9F%M:6QY(&%N9"!S='EL92P@:6X@;&]W97(@8V%S90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("!W:71H(&YO('-P86-E+@H@
M("`@("H*("`@("`J($!S964@1FEL95]01$8Z.G-E=$9O;G0*("`@("`J+PH@
M("`@9G5N8W1I;VX@861D1F]N="@D9F%M:6QY+"`D<W1Y;&4@/2`G)RP@)&9I
M;&4@/2`G)RD*("`@('L*("`@("`@("`D9F%M:6QY(#T@<W1R=&]L;W=E<B@D
M9F%M:6QY*3L*("`@("`@("!I9B`H)&9A;6EL>2`]/2`G87)I86PG*2!["B`@
M("`@("`@("`@("1F86UI;'D@/2`G:&5L=F5T:6-A)SL*("`@("`@("!]"@H@
M("`@("`@("1S='EL92`]('-T<G1O=7!P97(H)'-T>6QE*3L*("`@("`@("!I
M9B`H)'-T>6QE(#T]("=)0B<I('L*("`@("`@("`@("`@)'-T>6QE(#T@)T))
M)SL*("`@("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?9F]N='-;
M)&9A;6EL>2`N("1S='EL95TI*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<BAS<')I;G1F*"=&;VYT(&%L<F5A9'D@861D960Z("5S
M("5S)RP@)&9A;6EL>2P@)'-T>6QE*2D["B`@("`@("`@?0H@("`@("`@(&EF
M("@D9FEL92`]/2`G)RD@>PH@("`@("`@("`@("`D9FEL92`]('-T<E]R97!L
M86-E*"<@)RP@)R<L("1F86UI;'DI("X@<W1R=&]L;W=E<B@D<W1Y;&4I("X@
M)RYP:'`G.PH@("`@("`@('T*("`@("`@("!I;F-L=61E*"1F:6QE*3L*("`@
M("`@("!I9B`H(6ES<V5T*"1N86UE*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H)T-O=6QD(&YO="!I;F-L=61E(&9O;G0@9&5F
M:6YI=&EO;B!F:6QE+B<I.PH@("`@("`@('T*("`@("`@("`D:2`](&-O=6YT
M*"1T:&ES+3Y?9F]N=',I("L@,3L*("`@("`@("`D=&AI<RT^7V9O;G1S6R1F
M86UI;'D@+B`D<W1Y;&5=(#T@87)R87DH)VDG(#T^("1I+"`G='EP92<@/3X@
M)'1Y<&4L("=N86UE)R`]/B`D;F%M92P@)V1E<V,G(#T^("1D97-C+"`G=7`G
M(#T^("1U<"P@)W5T)R`]/B`D=70L("=C=R<@/3X@)&-W+"`G96YC)R`]/B`D
M96YC+"`G9FEL92<@/3X@)&9I;&4I.PH@("`@("`@(&EF("@D9&EF9BD@>PH@
M("`@("`@("`@("`O*B!396%R8V@@97AI<W1I;F<@96YC;V1I;F=S+B`J+PH@
M("`@("`@("`@("`D9"`](#`["B`@("`@("`@("`@("1N8B`](&-O=6YT*"1T
M:&ES+3Y?9&EF9G,I.PH@("`@("`@("`@("!F;W(@*"1I(#T@,3L@)&D@/#T@
M)&YB.R`D:2LK*2!["B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]D:69F
M<ULD:5T@/3T@)&1I9F8I('L*("`@("`@("`@("`@("`@("`@("`D9"`]("1I
M.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D9"`]/2`P*2!["B`@
M("`@("`@("`@("`@("`D9"`]("1N8B`K(#$["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V1I9F9S6R1D72`]("1D:69F.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1T:&ES+3Y?9F]N='-;)&9A;6EL>2XD<W1Y;&5=6R=D:69F)UT@
M/2`D9#L*("`@("`@("!]"B`@("`@("`@:68@*"1F:6QE*2!["B`@("`@("`@
M("`@(&EF("@D='EP92`]/2`G5')U951Y<&4G*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7V9O;G1?9FEL97-;)&9I;&5=(#T@87)R87DH)VQE;F=T:#$G
M(#T^("1O<FEG:6YA;'-I>F4I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]F;VYT7V9I;&5S6R1F:6QE72`](&%R<F%Y
M*"=L96YG=&@Q)R`]/B`D<VEZ93$L("=L96YG=&@R)R`]/B`D<VEZ93(I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M4V5T<R!T:&4@9F]N="!U<V5D('1O('!R:6YT(&-H87)A8W1E<B!S=')I;F=S
M+B!)="!I<R!M86YD871O<GD@=&\@8V%L;`H@("`@("H@=&AI<R!M971H;V0@
M870@;&5A<W0@;VYC92!B969O<F4@<')I;G1I;F<@=&5X="!O<B!T:&4@<F5S
M=6QT:6YG"B`@("`@*B!D;V-U;65N="!W;W5L9"!N;W0@8F4@=F%L:60N(%1H
M92!F;VYT(&-A;B!B92!E:71H97(@82!S=&%N9&%R9"!O;F4@;W(@80H@("`@
M("H@9F]N="!A9&1E9"!V:6$@=&AE($9I;&5?4$1&.CIA9&1&;VYT(&UE=&AO
M9"X@4W1A;F1A<F0@9F]N=',@=7-E(%=I;F1O=W,*("`@("`J(&5N8V]D:6YG
M(&-P,3(U,B`H5V5S=&5R;B!%=7)O<&4I+@H@("`@("H@5&AE(&UE=&AO9"!C
M86X@8F4@8V%L;&5D(&)E9F]R92!T:&4@9FER<W0@<&%G92!I<R!C<F5A=&5D
M(&%N9"!T:&4@9F]N=`H@("`@("H@:7,@<F5T86EN960@9G)O;2!P86=E('1O
M('!A9V4N"B`@("`@*B!)9B!Y;W4@:G5S="!W:7-H('1O(&-H86YG92!T:&4@
M8W5R<F5N="!F;VYT('-I>F4L(&ET(&ES('-I;7!L97(@=&\@8V%L;`H@("`@
M("H@1FEL95]01$8Z.G-E=$9O;G13:7IE+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&9A;6EL>2`@1F%M:6QY(&9O;G0N($ET(&-A;B!B92!E:71H
M97(@82!N86UE(&1E9FEN960@8GD*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@1FEL95]01$8Z.F%D9$9O;G0@;W(@;VYE(&]F('1H92!S=&%N9&%R
M9"!F86UI;&EE<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`H8V%S
M92!I;G-E;G-I=&EV92DZ"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@+2!#;W5R:65R("AF:7AE9"UW:61T:"D*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`M($AE;'9E=&EC82!O<B!!<FEA;"`H<V%N<R!S97)I
M9BD*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`M(%1I;65S("AS
M97)I9BD*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`M(%-Y;6)O
M;"`H<WEM8F]L:6,I"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M+2!:87!F1&EN9V)A=',@*'-Y;6)O;&EC*0H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("!)="!I<R!A;'-O('!O<W-I8FQE('1O('!A<W,@86X@96UP
M='D@<W1R:6YG+B!);@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!T
M:&%T(&-A<V4L('1H92!C=7)R96YT(&9A;6EL>2!I<R!R971A:6YE9"X*("`@
M("`J($!P87)A;2!S=')I;F<@)'-T>6QE("`@1F]N="!S='EL92X@4&]S<VEB
M;&4@=F%L=65S(&%R92`H8V%S90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("!I;G-E;G-I=&EV92DZ"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@+2!E;7!T>2!S=')I;F<Z(')E9W5L87(*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`M($(Z(&)O;&0*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`M($DZ(&ET86QI8PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("T@53H@=6YD97)L:6YE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@(&]R(&%N>2!C;VUB:6YA=&EO;BX@5&AE(&1E9F%U;'0@
M=F%L=64@:7,@<F5G=6QA<BX*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@0F]L9"!A;F0@:71A;&EC('-T>6QE<R!D;R!N;W0@87!P;'D@=&\@4WEM
M8F]L(&%N9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!:87!F1&EN
M9V)A=',N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<VEZ92`@($9O;G0@<VEZ
M92!I;B!P;VEN=',N(%1H92!D969A=6QT('9A;'5E(&ES('1H90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("!C=7)R96YT('-I>F4N($EF(&YO('-I
M>F4@:&%S(&)E96X@<W!E8VEF:65D('-I;F-E"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@('1H92!B96=I;FYI;F<@;V8@=&AE(&1O8W5M96YT+"!T
M:&4@=F%L=64@=&%K96X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M:7,@,3(N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9F]R8V4@($9O<F-E('1H
M92!S971T:6YG(&]F('1H92!F;VYT+B!%86-H(&YE=R!P86=E('=I;&P*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@<F5Q=6ER92!A(&YE=R!C86QL
M('1O($9I;&5?4$1&.CIS971&;VYT(&%N9`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("!S971T:6YG<R!T:&ES('1O('1R=64@=VEL;"!M86ME('-U
M<F4@=&AA="!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@8VAE
M8VMS(&9O<B!S86UE(&9O;G0@8V%L;',@=VEL;"!B92!S:VEP<&5D+@H@("`@
M("H*("`@("`J($!S964@1FEL95]01$8Z.F%D9$9O;G0*("`@("`J($!S964@
M1FEL95]01$8Z.G-E=$9O;G13:7IE"B`@("`@*B!`<V5E($9I;&5?4$1&.CIC
M96QL"B`@("`@*B!`<V5E($9I;&5?4$1&.CIM=6QT:4-E;&P*("`@("`J($!S
M964@1FEL95]01$8Z.E=R:71E"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$9O
M;G0H)&9A;6EL>2P@)'-T>6QE(#T@)R<L("1S:7IE(#T@;G5L;"P@)&9O<F-E
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&9A;6EL>2`]('-T<G1O;&]W97(H
M)&9A;6EL>2D["B`@("`@("`@:68@*"1F86UI;'D@/3T@)V%R:6%L)RD@>PH@
M("`@("`@("`@("`O*B!5<V4@:&5L=F5T:6-A(&EN<W1E860@;V8@87)I86PN
M("HO"B`@("`@("`@("`@("1F86UI;'D@/2`G:&5L=F5T:6-A)SL*("`@("`@
M("!](&5L<V5I9B`H)&9A;6EL>2`]/2`G<WEM8F]L)R!\?"`D9F%M:6QY(#T]
M("=Z87!F9&EN9V)A=',G*2!["B`@("`@("`@("`@("\J(%1H97-E('1W;R!F
M;VYT<R!D;R!N;W0@:&%V92!S='EL97,@879A:6QA8FQE+B`J+PH@("`@("`@
M("`@("`D<W1Y;&4@/2`G)SL*("`@("`@("!]"@H@("`@("`@("1S='EL92`]
M('-T<G1O=7!P97(H)'-T>6QE*3L*"B`@("`@("`@+RH@56YD97)L:6YE(&ES
M(&AA;F1L960@<V5P87)A=&5L>2P@:68@<W!E8VEF:65D(&EN('1H92!S='EL
M92!V87(*("`@("`@("`@*B!R96UO=F4@:70@9G)O;2!T:&4@<W1Y;&4@86YD
M('-E="!T:&4@=6YD97)L:6YE(&9L86<N("HO"B`@("`@("`@:68@*'-T<G!O
M<R@D<W1Y;&4L("=5)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?=6YD97)L:6YE(#T@=')U93L*("`@("`@("`@("`@)'-T>6QE(#T@<W1R
M7W)E<&QA8V4H)U4G+"`G)RP@)'-T>6QE*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D=&AI<RT^7W5N9&5R;&EN92`](&9A;'-E.PH@("`@("`@
M('T*"B`@("`@("`@:68@*"1S='EL92`]/2`G24(G*2!["B`@("`@("`@("`@
M("1S='EL92`]("="22<["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!N;R!S
M:7IE('-P96-I9FEE9"P@=7-E(&-U<G)E;G0@<VEZ92X@*B\*("`@("`@("!I
M9B`H:7-?;G5L;"@D<VEZ92DI('L*("`@("`@("`@("`@)'-I>F4@/2`D=&AI
M<RT^7V9O;G1?<VEZ95]P=#L*("`@("`@("!]"@H@("`@("`@("\J($EF(&9O
M;G0@<F5Q=65S=&5D(&ES(&%L<F5A9'D@=&AE(&-U<G)E;G0@9F]N="!A;F0@
M;F\@9F]R8V4@<V5T=&EN9PH@("`@("`@("`J(&]F('1H92!F;VYT(&ES(')E
M<75E<W1E9"`H96<N('=H96X@861D:6YG(&$@;F5W('!A9V4I(&1O;B=T(&)O
M=&AE<@H@("`@("`@("`J('=I=&@@=&AE(')E<W0@;V8@=&AE(&9U;F-T:6]N
M(&%N9"!S:6UP;'D@<F5T=7)N+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7V9O
M;G1?9F%M:6QY(#T]("1F86UI;'D@)B8@)'1H:7,M/E]F;VYT7W-T>6QE(#T]
M("1S='EL92`F)@H@("`@("`@("`@("`D=&AI<RT^7V9O;G1?<VEZ95]P="`]
M/2`D<VEZ92`F)B`A)&9O<F-E*2!["B`@("`@("`@("`@(')E='5R;CL*("`@
M("`@("!]"@H@("`@("`@("\J(%-E="!T:&4@9F]N="!K97DN("HO"B`@("`@
M("`@)&9O;G1K97D@/2`D9F%M:6QY("X@)'-T>6QE.PH*("`@("`@("`O*B!4
M97-T(&EF(&%L<F5A9'D@8V%C:&5D+B`J+PH@("`@("`@(&EF("@A:7-S970H
M)'1H:7,M/E]F;VYT<ULD9F]N=&ME>5TI*2!["B`@("`@("`@("`@("\J($=E
M="!T:&4@8VAA<F%C=&5R('=I9'1H(&1E9FEN:71I;VX@9FEL92X@*B\*("`@
M("`@("`@("`@)&9O;G1?=VED=&AS(#T@)D9I;&5?4$1&.CI?9V5T1F]N=$9I
M;&4H)&9O;G1K97DI.PH@("`@("`@("`@("!I9B`H:7-?82@D9F]N=%]W:61T
M:',L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M9F]N=%]W:61T:',["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1I(#T@
M8V]U;G0H)'1H:7,M/E]F;VYT<RD@*R`Q.PH@("`@("`@("`@("`D=&AI<RT^
M7V9O;G1S6R1F;VYT:V5Y72`](&%R<F%Y*`H@("`@("`@("`@("`@("`@)VDG
M("`@(#T^("1I+`H@("`@("`@("`@("`@("`@)W1Y<&4G(#T^("=C;W)E)RP*
M("`@("`@("`@("`@("`@("=N86UE)R`]/B`D=&AI<RT^7V-O<F5?9F]N='-;
M)&9O;G1K97E=+`H@("`@("`@("`@("`@("`@)W5P)R`@(#T^("TQ,#`L"B`@
M("`@("`@("`@("`@("`G=70G("`@/3X@-3`L"B`@("`@("`@("`@("`@("`G
M8W<G("`@/3X@)&9O;G1?=VED=&AS6R1F;VYT:V5Y72D["B`@("`@("`@?0H*
M("`@("`@("`O*B!3=&]R92!F;VYT(&EN9F]R;6%T:6]N(&%S(&-U<G)E;G0@
M9F]N="X@*B\*("`@("`@("`D=&AI<RT^7V9O;G1?9F%M:6QY("`]("1F86UI
M;'D["B`@("`@("`@)'1H:7,M/E]F;VYT7W-T>6QE("`@/2`D<W1Y;&4["B`@
M("`@("`@)'1H:7,M/E]F;VYT7W-I>F5?<'0@/2`D<VEZ93L*("`@("`@("`D
M=&AI<RT^7V9O;G1?<VEZ92`@("`]("1S:7IE("\@)'1H:7,M/E]S8V%L93L*
M("`@("`@("`D=&AI<RT^7V-U<G)E;G1?9F]N="`]("8D=&AI<RT^7V9O;G1S
M6R1F;VYT:V5Y73L*"B`@("`@("`@+RH@3W5T<'5T(&9O;G0@:6YF;W)M871I
M;VX@:68@870@;&5A<W0@;VYE('!A9V4@:&%S(&)E96X@9&5F:6YE9"X@*B\*
M("`@("`@("!I9B`H)'1H:7,M/E]P86=E(#X@,"D@>PH@("`@("`@("`@("`D
M=&AI<RT^7V]U="AS<')I;G1F*"="5"`O1B5D("4N,F8@5&8@150G+"`D=&AI
M<RT^7V-U<G)E;G1?9F]N=%LG:2==+"`D=&AI<RT^7V9O;G1?<VEZ95]P="DI
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1E9FEN97,@=&AE
M('-I>F4@;V8@=&AE(&-U<G)E;G0@9F]N="X*("`@("`J"B`@("`@*B!`<&%R
M86T@9FQO870@)'-I>F4@(%1H92!S:7IE("AI;B!P;VEN=',I+@H@("`@("H*
M("`@("`J($!S964@1FEL95]01$8Z.G-E=$9O;G0*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5T1F]N=%-I>F4H)'-I>F4I"B`@("!["B`@("`@("`@+RH@268@
M=&AE(&9O;G0@<VEZ92!I<R!A;')E861Y('1H92!C=7)R96YT(&9O;G0@<VEZ
M92P@:G5S="!R971U<FXN("HO"B`@("`@("`@:68@*"1T:&ES+3Y?9F]N=%]S
M:7IE7W!T(#T]("1S:7IE*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@
M("!]"B`@("`@("`@+RH@4V5T('1H92!C=7)R96YT(&9O;G0@<VEZ92P@8F]T
M:"!I;B!P;VEN=',@86YD('-C86QE9"!T;R!U<V5R"B`@("`@("`@("H@=6YI
M=',N("HO"B`@("`@("`@)'1H:7,M/E]F;VYT7W-I>F5?<'0@/2`D<VEZ93L*
M("`@("`@("`D=&AI<RT^7V9O;G1?<VEZ92`]("1S:7IE("\@)'1H:7,M/E]S
M8V%L93L*"B`@("`@("`@+RH@3W5T<'5T(&9O;G0@:6YF;W)M871I;VX@:68@
M870@;&5A<W0@;VYE('!A9V4@:&%S(&)E96X@9&5F:6YE9"X@*B\*("`@("`@
M("!I9B`H)'1H:7,M/E]P86=E(#X@,"D@>PH@("`@("`@("`@("`D=&AI<RT^
M7V]U="AS<')I;G1F*"="5"`O1B5D("4N,F8@5&8@150G+"`D=&AI<RT^7V-U
M<G)E;G1?9F]N=%LG:2==+"`D=&AI<RT^7V9O;G1?<VEZ95]P="DI.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@82!N97<@:6YT
M97)N86P@;&EN:R!A;F0@<F5T=7)N<R!I=',@:61E;G1I9FEE<BX@06X@:6YT
M97)N86P*("`@("`J(&QI;FL@:7,@82!C;&EC:V%B;&4@87)E82!W:&EC:"!D
M:7)E8W1S('1O(&%N;W1H97(@<&QA8V4@=VET:&EN('1H90H@("`@("H@9&]C
M=6UE;G0N"B`@("`@*B!4:&4@:61E;G1I9FEE<B!C86X@=&AE;B!B92!P87-S
M960@=&\@1FEL95]01$8Z.F-E;&PL($9I;&5?4$1&.CIW<FET92P*("`@("`J
M($9I;&5?4$1&.CII;6%G92!O<B!&:6QE7U!$1CHZ;&EN:RX@5&AE(&1E<W1I
M;F%T:6]N(&ES(&1E9FEN960@=VET:`H@("`@("H@1FEL95]01$8Z.G-E=$QI
M;FLN"B`@("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ8V5L;`H@("`@("H@
M0'-E92!&:6QE7U!$1CHZ5W)I=&4*("`@("`J($!S964@1FEL95]01$8Z.FEM
M86=E"B`@("`@*B!`<V5E($9I;&5?4$1&.CI,:6YK"B`@("`@*B!`<V5E($9I
M;&5?4$1&.CI3971,:6YK"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$QI;FLH
M*0H@("`@>PH@("`@("`@("1N(#T@8V]U;G0H)'1H:7,M/E]L:6YK<RD@*R`Q
M.PH@("`@("`@("1T:&ES+3Y?;&EN:W-;)&Y=(#T@87)R87DH,"P@,"D["B`@
M("`@("`@<F5T=7)N("1N.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5F:6YE
M<R!T:&4@<&%G92!A;F0@<&]S:71I;VX@82!L:6YK('!O:6YT<R!T;RX*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;&EN:R`@5&AE(&QI;FL@:61E
M;G1I9FEE<B!R971U<FYE9"!B>2!&:6QE7U!$1CHZ861D3&EN:RX*("`@("`J
M($!P87)A;2!F;&]A="`D>2`@("`@("!/<F1I;F%T92!O9B!T87)G970@<&]S
M:71I;VX[("TQ(&EN9&EC871E<R!T:&4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!C=7)R96YT('!O<VET:6]N+B!4:&4@9&5F875L="!V86QU92!I
M<R`P("AT;W`@;V8*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!P86=E
M*2X*("`@("`J($!P87)A;2!I;G1E9V5R("1P86=E("!.=6UB97(@;V8@=&%R
M9V5T('!A9V4[("TQ(&EN9&EC871E<R!T:&4@8W5R<F5N=`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@('!A9V4N(%1H:7,@:7,@=&AE(&1E9F%U;'0@
M=F%L=64N"B`@("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ861D3&EN:PH@
M("`@("HO"B`@("!F=6YC=&EO;B!S971,:6YK*"1L:6YK+"`D>2`](#`L("1P
M86=E(#T@+3$I"B`@("!["B`@("`@("`@:68@*"1Y(#T]("TQ*2!["B`@("`@
M("`@("`@("1Y(#T@)'1H:7,M/GD["B`@("`@("`@?0H@("`@("`@(&EF("@D
M<&%G92`]/2`M,2D@>PH@("`@("`@("`@("`D<&%G92`]("1T:&ES+3Y?<&%G
M93L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]L:6YK<ULD;&EN:UT@/2!A
M<G)A>2@D<&%G92P@)'DI.PH@("`@?0H*("`@("\J*@H@("`@("H@4'5T<R!A
M(&QI;FL@;VX@82!R96-T86YG=6QA<B!A<F5A(&]F('1H92!P86=E+B!497AT
M(&]R(&EM86=E(&QI;FMS(&%R90H@("`@("H@9V5N97)A;&QY('!U="!V:6$@
M1FEL95]01$8Z.F-E;&PL($9I;&5?4$1&.CI7<FET92!O<B!&:6QE7U!$1CHZ
M:6UA9V4L"B`@("`@*B!B=70@=&AI<R!M971H;V0@8V%N(&)E('5S969U;"!F
M;W(@:6YS=&%N8V4@=&\@9&5F:6YE(&$@8VQI8VMA8FQE(&%R96$*("`@("`J
M(&EN<VED92!A;B!I;6%G92X*("`@("`J"B`@("`@*B!`<&%R86T@9FQO870@
M)'@@("`@("`@06)S8VES<V$@;V8@=&AE('5P<&5R+6QE9G0@8V]R;F5R(&]F
M('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@9FQO870@)'D@("`@("`@
M3W)D:6YA=&4@;V8@=&AE('5P<&5R+6QE9G0@8V]R;F5R(&]F('1H92!R96-T
M86YG;&4N"B`@("`@*B!`<&%R86T@9FQO870@)'=I9'1H("`@5VED=&@@;V8@
M=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!F;&]A="`D:&5I9VAT("!(
M96EG:'0@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!M:7AE9"`D
M;&EN:R`@("!54DP@;W(@:61E;G1I9FEE<B!R971U<FYE9"!B>2!&:6QE7U!$
M1CHZ861D3&EN:RX*("`@("`J"B`@("`@*B!`<V5E($9I;&5?4$1&.CIA9&1,
M:6YK"B`@("`@*B!`<V5E($9I;&5?4$1&.CIC96QL"B`@("`@*B!`<V5E($9I
M;&5?4$1&.CI7<FET90H@("`@("H@0'-E92!&:6QE7U!$1CHZ:6UA9V4*("`@
M("`J+PH@("`@9G5N8W1I;VX@;&EN:R@D>"P@)'DL("1W:61T:"P@)&AE:6=H
M="P@)&QI;FLI"B`@("!["B`@("`@("`@+RH@4V5T('5P('1H92!C;V]R9&EN
M871E<R!W:71H(&-O<G)E8W0@<V-A;&EN9R!I;B!P="X@*B\*("`@("`@("`D
M>"`@("`@(#T@)'1H:7,M/E]T;U!T*"1X*3L*("`@("`@("`D>2`@("`@(#T@
M)'1H:7,M/FA0="`M("1T:&ES+3Y?=&]0="@D>2D["B`@("`@("`@)'=I9'1H
M("`]("1T:&ES+3Y?=&]0="@D=VED=&@I.PH@("`@("`@("1H96EG:'0@/2`D
M=&AI<RT^7W1O4'0H)&AE:6=H="D["@H@("`@("`@("\J(%-A=F4@;&EN:R!T
M;R!P86=E(&QI;FMS(&%R<F%Y+B`J+PH@("`@("`@("1T:&ES+3Y?;&EN:R@D
M>"P@)'DL("1W:61T:"P@)&AE:6=H="P@)&QI;FLI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4')I;G1S(&$@8VAA<F%C=&5R('-T<FEN9RX@5&AE(&]R:6=I
M;B!I<R!O;B!T:&4@;&5F="!O9B!T:&4@9FER<W0*("`@("`J(&-H87)A8W1E
M<BP@;VX@=&AE(&)A<V5L:6YE+B!4:&ES(&UE=&AO9"!A;&QO=W,@=&\@<&QA
M8V4@82!S=')I;F<*("`@("`J('!R96-I<V5L>2!O;B!T:&4@<&%G92P@8G5T
M(&ET(&ES('5S=6%L;'D@96%S:65R('1O('5S92!&:6QE7U!$1CHZ8V5L;"P*
M("`@("`J($9I;&5?4$1&.CIM=6QT:4-E;&P@;W(@1FEL95]01$8Z.E=R:71E
M('=H:6-H(&%R92!T:&4@<W1A;F1A<F0@;65T:&]D<R!T;PH@("`@("H@<')I
M;G0@=&5X="X*("`@("`J"B`@("`@*B!`<&%R86T@9FQO870@)'@@("`@("!!
M8G-C:7-S82!O9B!T:&4@;W)I9VEN+@H@("`@("H@0'!A<F%M(&9L;V%T("1Y
M("`@("`@3W)D:6YA=&4@;V8@=&AE(&]R:6=I;BX*("`@("`J($!P87)A;2!S
M=')I;F<@)'1E>'0@(%-T<FEN9R!T;R!P<FEN="X*("`@("`J"B`@("`@*B!`
M<V5E($9I;&5?4$1&.CIS971&;VYT"B`@("`@*B!`<V5E($9I;&5?4$1&.CIC
M96QL"B`@("`@*B!`<V5E($9I;&5?4$1&.CIM=6QT:4-E;&P*("`@("`J($!S
M964@1FEL95]01$8Z.E=R:71E"B`@("`@*B\*("`@(&9U;F-T:6]N('1E>'0H
M)'@L("1Y+"`D=&5X="D*("`@('L*("`@("`@("`O*B!38V%L92!C;V]R9&EN
M871E<R!I;G1O('!O:6YT<R!A;F0@<V5T(&-O<G)E8W0@62!P;W-I=&EO;BX@
M*B\*("`@("`@("`D>"`]("1T:&ES+3Y?=&]0="@D>"D["B`@("`@("`@)'D@
M/2`D=&AI<RT^:%!T("T@)'1H:7,M/E]T;U!T*"1Y*3L*"B`@("`@("`@+RH@
M17-C87!E(&%N>2!P;W1E;G1I86QL>2!H87)M9G5L(&-H87)A8W1E<G,N("HO
M"B`@("`@("`@)'1E>'0@/2`D=&AI<RT^7V5S8V%P92@D=&5X="D["@H@("`@
M("`@("1O=70@/2!S<')I;G1F*"="5"`E+C)F("4N,F8@5&0@*"5S*2!4:B!%
M5"<L("1X+"`D>2P@)'1E>'0I.PH@("`@("`@(&EF("@D=&AI<RT^7W5N9&5R
M;&EN92`F)B`D=&5X="`A/2`G)RD@>PH@("`@("`@("`@("`D;W5T("X]("<@
M)R`N("1T:&ES+3Y?9&]5;F1E<FQI;F4H)'@L("1Y+"`D=&5X="D["B`@("`@
M("`@?0H@("`@("`@("1T:&ES+3Y?;W5T*"1O=70I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@5VAE;F5V97(@82!P86=E(&)R96%K(&-O;F1I=&EO;B!I<R!M
M970L('1H92!M971H;V0@:7,@8V%L;&5D+"!A;F0@=&AE"B`@("`@*B!B<F5A
M:R!I<R!I<W-U960@;W(@;F]T(&1E<&5N9&EN9R!O;B!T:&4@<F5T=7)N960@
M=F%L=64N(%1H92!D969A=6QT"B`@("`@*B!I;7!L96UE;G1A=&EO;B!R971U
M<FYS(&$@=F%L=64@86-C;W)D:6YG('1O('1H92!M;V1E('-E;&5C=&5D(&)Y
M"B`@("`@*B!&:6QE7U!$1CIS971!=71O4&%G94)R96%K+@H@("`@("H@5&AI
M<R!M971H;V0@:7,@8V%L;&5D(&%U=&]M871I8V%L;'D@86YD('-H;W5L9"!N
M;W0@8F4@8V%L;&5D(&1I<F5C=&QY"B`@("`@*B!B>2!T:&4@87!P;&EC871I
M;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N"B`@("`@*@H@("`@
M("H@0'-E92!&:6QE7U!$1CHZ<V5T075T;U!A9V5"<F5A:RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@86-C97!T4&%G94)R96%K*"D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]A=71O7W!A9V5?8G)E86L["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!0<FEN=',@82!C96QL("AR96-T86YG=6QA<B!A<F5A*2!W:71H
M(&]P=&EO;F%L(&)O<F1E<G,L(&)A8VMG<F]U;F0*("`@("`J(&-O;&]R(&%N
M9"!C:&%R86-T97(@<W1R:6YG+B!4:&4@=7!P97(M;&5F="!C;W)N97(@;V8@
M=&AE(&-E;&P*("`@("`J(&-O<G)E<W!O;F1S('1O('1H92!C=7)R96YT('!O
M<VET:6]N+B!4:&4@=&5X="!C86X@8F4@86QI9VYE9"!O<@H@("`@("H@8V5N
M=&5R960N($%F=&5R('1H92!C86QL+"!T:&4@8W5R<F5N="!P;W-I=&EO;B!M
M;W9E<R!T;R!T:&4@<FEG:'0@;W(@=&\*("`@("`J('1H92!N97AT(&QI;F4N
M($ET(&ES('!O<W-I8FQE('1O('!U="!A(&QI;FL@;VX@=&AE('1E>'0N"B`@
M("`@*B!)9B!A=71O;6%T:6,@<&%G92!B<F5A:VEN9R!I<R!E;F%B;&5D(&%N
M9"!T:&4@8V5L;"!G;V5S(&)E>6]N9"!T:&4*("`@("`J(&QI;6ET+"!A('!A
M9V4@8G)E86L@:7,@9&]N92!B969O<F4@;W5T<'5T=&EN9RX*("`@("`J"B`@
M("`@*B!`<&%R86T@9FQO870@)'=I9'1H("`@0V5L;"!W:61T:"X@268@,"P@
M=&AE(&-E;&P@97AT96YD<R!U<"!T;R!T:&4@<FEG:'0*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!M87)G:6XN"B`@("`@*B!`<&%R86T@9FQO870@
M)&AE:6=H="`@0V5L;"!H96EG:'0N($1E9F%U;'0@=F%L=64Z(#`N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1T97AT("`@4W1R:6YG('1O('!R:6YT+B!$969A
M=6QT('9A;'5E.B!E;7!T>2X*("`@("`J($!P87)A;2!M:7AE9"`D8F]R9&5R
M("!);F1I8V%T97,@:68@8F]R9&5R<R!M=7-T(&)E(&1R87=N(&%R;W5N9"!T
M:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!C96QL+B!4:&4@=F%L
M=64@8V%N(&)E(&5I=&AE<B!A(&YU;6)E<CH*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("T@,#H@;F\@8F]R9&5R("AD969A=6QT*0H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@+2`Q.B!F<F%M90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@(&]R(&$@<W1R:6YG(&-O;G1A:6YI;F<@<V]M
M92!O<B!A;&P@;V8@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M9F]L;&]W:6YG(&-H87)A8W1E<G,@*&EN(&%N>2!O<F1E<BDZ"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`M($PZ(&QE9G0*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("T@5#H@=&]P"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`M(%(Z(')I9VAT"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`M($(Z(&)O='1O;0H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)&QN("`@($EN9&EC871E<R!W:&5R92!T:&4@8W5R<F5N="!P;W-I=&EO;B!S
M:&]U;&0@9V\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!A9G1E<B!T
M:&4@8V%L;"X@4&]S<VEB;&4@=F%L=65S(&%R93H*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("T@,#H@=&\@=&AE(')I9VAT("AD969A=6QT*0H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@+2`Q.B!T;R!T:&4@8F5G
M:6YN:6YG(&]F('1H92!N97AT(&QI;F4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("T@,CH@8F5L;W<*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!0=71T:6YG(#$@:7,@97%U:79A;&5N="!T;R!P=71T:6YG(#`@86YD
M(&-A;&QI;F<*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!&:6QE7U!$
M1CHZ;F5W3&EN92!J=7-T(&%F=&5R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M86QI9VX@($%L;&]W<R!T;R!C96YT97(@;W(@86QI9VX@=&AE('1E>'0N(%!O
M<W-I8FQE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@=F%L=65S(&%R
M93H*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("T@3"!O<B!E;7!T
M>2!S=')I;F<Z(&QE9G0@*&1E9F%U;'0I"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`M($,Z(&-E;G1E<@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@+2!2.B!R:6=H=`H@("`@("H@0'!A<F%M(&EN=&5G97(@)&9I
M;&P@($EN9&EC871E<R!I9B!T:&4@8V5L;"!F:6QL('1Y<&4N(%!O<W-I8FQE
M('9A;'5E<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&%R93H*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("T@,#H@=')A;G-P87)E;G0@
M*&1E9F%U;'0I"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M(#$Z
M('!A:6YT960*("`@("`J($!P87)A;2!S=')I;F<@)&QI;FL@("!54DP@;W(@
M:61E;G1I9FEE<B!R971U<FYE9"!B>0H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@($9I;&5?4$1&.F%D9$QI;FLN"B`@("`@*@H@("`@
M("H@0'-E92!&:6QE7U!$1CHZ<V5T1F]N=`H@("`@("H@0'-E92!&:6QE7U!$
M1CHZ<V5T1')A=T-O;&]R"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS971&:6QL
M0V]L;W(*("`@("`J($!S964@1FEL95]01$8Z.G-E=$QI;F57:61T:`H@("`@
M("H@0'-E92!&:6QE7U!$1CHZ861D3&EN:PH@("`@("H@0'-E92!&:6QE7U!$
M1CHZ;F5W3&EN90H@("`@("H@0'-E92!&:6QE7U!$1CHZ;75L=&E#96QL"B`@
M("`@*B!`<V5E($9I;&5?4$1&.CI7<FET90H@("`@("H@0'-E92!&:6QE7U!$
M1CHZ<V5T075T;U!A9V5"<F5A:PH@("`@("HO"B`@("!F=6YC=&EO;B!C96QL
M*"1W:61T:"P@)&AE:6=H="`](#`L("1T97AT(#T@)R<L("1B;W)D97(@/2`P
M+"`D;&X@/2`P+"`D86QI9VX@/2`G)RP@)&9I;&P@/2`P+"`D;&EN:R`]("<G
M*0H@("`@>PH@("`@("`@("1K(#T@)'1H:7,M/E]S8V%L93L*("`@("`@("!I
M9B`H)'1H:7,M/GD@*R`D:&5I9VAT(#X@)'1H:7,M/E]P86=E7V)R96%K7W1R
M:6=G97(@)B8@(21T:&ES+3Y?:6Y?9F]O=&5R("8F("1T:&ES+3Y!8V-E<'10
M86=E0G)E86LH*2D@>PH@("`@("`@("`@("`D>"`]("1T:&ES+3YX.PH@("`@
M("`@("`@("`D=W,@/2`D=&AI<RT^7W=O<F1?<W!A8VEN9SL*("`@("`@("`@
M("`@:68@*"1W<R`^(#`I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?=V]R
M9%]S<&%C:6YG(#T@,#L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<P
M(%1W)RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/F%D9%!A
M9V4H)'1H:7,M/E]C=7)R96YT7V]R:65N=&%T:6]N*3L*("`@("`@("`@("`@
M)'1H:7,M/G@@/2`D>#L*("`@("`@("`@("`@:68@*"1W<R`^(#`I('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?=V]R9%]S<&%C:6YG(#T@)'=S.PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]O=70H<W!R:6YT9B@G)2XS9B!4=R<L("1W
M<R`J("1K*2D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@
M*"1W:61T:"`]/2`P*2!["B`@("`@("`@("`@("1W:61T:"`]("1T:&ES+3YW
M("T@)'1H:7,M/E]R:6=H=%]M87)G:6X@+2`D=&AI<RT^>#L*("`@("`@("!]
M"B`@("`@("`@)',@/2`G)SL*("`@("`@("!I9B`H)&9I;&P@/3T@,2!\?"`D
M8F]R9&5R(#T](#$I('L*("`@("`@("`@("`@:68@*"1F:6QL(#T](#$I('L*
M("`@("`@("`@("`@("`@("1O<"`]("@D8F]R9&5R(#T](#$I(#\@)T(G(#H@
M)V8G.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&]P
M(#T@)U,G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1S(#T@<W!R:6YT
M9B@G)2XR9B`E+C)F("4N,F8@)2XR9B!R92`E<R`G+"`D=&AI<RT^>"`J("1K
M+"`H)'1H:7,M/F@@+2`D=&AI<RT^>2D@*B`D:RP@)'=I9'1H("H@)&LL("TD
M:&5I9VAT("H@)&LL("1O<"D["B`@("`@("`@?0H@("`@("`@(&EF("AI<U]S
M=')I;F<H)&)O<F1E<BDI('L*("`@("`@("`@("`@:68@*'-T<G!O<R@D8F]R
M9&5R+"`G3"<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@)',@+CT@
M<W!R:6YT9B@G)2XR9B`E+C)F(&T@)2XR9B`E+C)F(&P@4R`G+"`D=&AI<RT^
M>"`J("1K+"`H)'1H:7,M/F@@+2`D=&AI<RT^>2D@*B`D:RP@)'1H:7,M/G@@
M*B`D:RP@*"1T:&ES+3YH("T@*"1T:&ES+3YY("L@)&AE:6=H="DI("H@)&LI
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AS=')P;W,H)&)O<F1E
M<BP@)U0G*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1S("X]('-P
M<FEN=&8H)R4N,F8@)2XR9B!M("4N,F8@)2XR9B!L(%,@)RP@)'1H:7,M/G@@
M*B`D:RP@*"1T:&ES+3YH("T@)'1H:7,M/GDI("H@)&LL("@D=&AI<RT^>"`K
M("1W:61T:"D@*B`D:RP@*"1T:&ES+3YH("T@)'1H:7,M/GDI("H@)&LI.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AS=')P;W,H)&)O<F1E<BP@
M)U(G*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1S("X]('-P<FEN
M=&8H)R4N,F8@)2XR9B!M("4N,F8@)2XR9B!L(%,@)RP@*"1T:&ES+3YX("L@
M)'=I9'1H*2`J("1K+"`H)'1H:7,M/F@@+2`D=&AI<RT^>2D@*B`D:RP@*"1T
M:&ES+3YX("L@)'=I9'1H*2`J("1K+"`H)'1H:7,M/F@@+2`H)'1H:7,M/GD@
M*R`D:&5I9VAT*2D@*B`D:RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M:68@*'-T<G!O<R@D8F]R9&5R+"`G0B<I("$]/2!F86QS92D@>PH@("`@("`@
M("`@("`@("`@)',@+CT@<W!R:6YT9B@G)2XR9B`E+C)F(&T@)2XR9B`E+C)F
M(&P@4R`G+"`D=&AI<RT^>"`J("1K+"`H)'1H:7,M/F@@+2`H)'1H:7,M/GD@
M*R`D:&5I9VAT*2D@*B`D:RP@*"1T:&ES+3YX("L@)'=I9'1H*2`J("1K+"`H
M)'1H:7,M/F@@+2`H)'1H:7,M/GD@*R`D:&5I9VAT*2D@*B`D:RD["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*"1T97AT("$]("<G*2![
M"B`@("`@("`@("`@(&EF("@D86QI9VX@/3T@)U(G*2!["B`@("`@("`@("`@
M("`@("`D9'@@/2`D=VED=&@@+2`D=&AI<RT^7V-E;&Q?;6%R9VEN("T@)'1H
M:7,M/F=E=%-T<FEN9U=I9'1H*"1T97AT*3L*("`@("`@("`@("`@?2!E;'-E
M:68@*"1A;&EG;B`]/2`G0R<I('L*("`@("`@("`@("`@("`@("1D>"`]("@D
M=VED=&@@+2`D=&AI<RT^9V5T4W1R:6YG5VED=&@H)'1E>'0I*2`O(#(["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D9'@@/2`D=&AI
M<RT^7V-E;&Q?;6%R9VEN.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T
M97AT(#T@<W1R7W)E<&QA8V4H)RDG+"`G7%PI)RP@<W1R7W)E<&QA8V4H)R@G
M+"`G7%PH)RP@<W1R7W)E<&QA8V4H)UQ<)RP@)UQ<7%PG+"`D=&5X="DI*3L*
M("`@("`@("`@("`@)'1E<W0R(#T@*"@N-2`J("1H96EG:'0I("L@*"XS("H@
M)'1H:7,M/E]F;VYT7W-I>F4I*3L*("`@("`@("`@("`@)'1E<W0Q(#T@)'1H
M:7,M/F9H4'0@+2`H*"1T:&ES+3YY("L@)'1E<W0R*2`J("1K*3L*("`@("`@
M("`@("`@)',@+CT@<W!R:6YT9B@G0E0@)2XR9B`E+C)F(%1D("@E<RD@5&H@
M150G+"`H)'1H:7,M/G@@*R`D9'@I("H@)&LL("@D=&AI<RT^:"`M("@D=&AI
M<RT^>2`K("XU("H@)&AE:6=H="`K("XS("H@)'1H:7,M/E]F;VYT7W-I>F4I
M*2`J("1K+"`D=&5X="D["B`@("`@("`@("`@(&EF("@D=&AI<RT^7W5N9&5R
M;&EN92D@>PH@("`@("`@("`@("`@("`@)',@+CT@)R`G("X@)'1H:7,M/E]D
M;U5N9&5R;&EN92@D=&AI<RT^>"`K("1D>"P@)'1H:7,M/GD@*R`N-2`J("1H
M96EG:'0@*R`N,R`J("1T:&ES+3Y?9F]N=%]S:7IE+"`D=&5X="D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@:68@*"1L:6YK*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^;&EN:R@D=&AI<RT^>"`K("1D>"P@)'1H:7,M/GD@*R`N
M-2`J("1H96EG:'0M+C4@*B`D=&AI<RT^7V9O;G1?<VEZ92P@)'1H:7,M/F=E
M=%-T<FEN9U=I9'1H*"1T97AT*2P@)'1H:7,M/E]F;VYT7W-I>F4L("1L:6YK
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H)',I('L*
M("`@("`@("`@("`@)'1H:7,M/E]O=70H)',I.PH@("`@("`@('T*("`@("`@
M("`D=&AI<RT^7VQA<W1?:&5I9VAT(#T@)&AE:6=H=#L*("`@("`@("!I9B`H
M)&QN(#X@,"D@>PH@("`@("`@("`@("`O*B!';R!T;R!N97AT(&QI;F4N("HO
M"B`@("`@("`@("`@("1T:&ES+3YY("L]("1H96EG:'0["B`@("`@("`@("`@
M(&EF("@D;&X@/3T@,2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G@@/2`D
M=&AI<RT^7VQE9G1?;6%R9VEN.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'1H:7,M/G@@*ST@)'=I9'1H.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@;65T:&]D(&%L;&]W<R!P
M<FEN=&EN9R!T97AT('=I=&@@;&EN92!B<F5A:W,N(%1H97D@8V%N(&)E"B`@
M("`@*B!A=71O;6%T:6,@*&%S('-O;VX@87,@=&AE('1E>'0@<F5A8VAE<R!T
M:&4@<FEG:'0@8F]R9&5R(&]F('1H92!C96QL*2!O<@H@("`@("H@97AP;&EC
M:70@*'9I82!T:&4@7&X@8VAA<F%C=&5R*2X@07,@;6%N>2!C96QL<R!A<R!N
M96-E<W-A<GD@87)E(&]U='!U="P*("`@("`J(&]N92!B96QO=R!T:&4@;W1H
M97(N"B`@("`@*B!497AT(&-A;B!B92!A;&EG;F5D+"!C96YT97)E9"!O<B!J
M=7-T:69I960N(%1H92!C96QL(&)L;V-K(&-A;B!B90H@("`@("H@9G)A;65D
M(&%N9"!T:&4@8F%C:V=R;W5N9"!P86EN=&5D+@H@("`@("H*("`@("`J($!P
M87)A;2!F;&]A="`D=VED=&@@("!7:61T:"!O9B!C96QL<RX@268@,"P@=&AE
M>2!E>'1E;F0@=7`@=&\@=&AE(')I9VAT"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@;6%R9VEN(&]F('1H92!P86=E+@H@("`@("H@0'!A<F%M(&9L
M;V%T("1H96EG:'0@($AE:6=H="!O9B!C96QL<RX*("`@("`J($!P87)A;2!S
M=')I;F<@)'1E>'0@("!3=')I;F<@=&\@<')I;G0N"B`@("`@*B!`<&%R86T@
M;6EX960@)&)O<F1E<B`@26YD:6-A=&5S(&EF(&)O<F1E<G,@;75S="!B92!D
M<F%W;B!A<F]U;F0@=&AE(&-E;&P*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!B;&]C:RX@5&AE('9A;'5E(&-A;B!B92!E:71H97(@82!N=6UB97(Z
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M(#`Z(&YO(&)O<F1E
M<B`H9&5F875L="D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("T@
M,3H@9G)A;64*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!O<B!A('-T
M<FEN9R!C;VYT86EN:6YG('-O;64@;W(@86QL(&]F('1H90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@(&9O;&QO=VEN9R!C:&%R86-T97)S("AI;B!A
M;GD@;W)D97(I.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("T@
M3#H@;&5F=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("T@5#H@
M=&]P"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@+2!2.B!R:6=H
M=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("T@0CH@8F]T=&]M
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1A;&EG;B`@4V5T<R!T:&4@=&5X="!A
M;&EG;FUE;G0N(%!O<W-I8FQE('9A;'5E<R!A<F4Z"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`M($PZ(&QE9G0@86QI9VYM96YT"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`M($,Z(&-E;G1E<@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@+2!2.B!R:6=H="!A;&EG;FUE;G0*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("T@2CH@:G5S=&EF:6-A=&EO
M;B`H9&5F875L="!V86QU92D*("`@("`J($!P87)A;2!I;G1E9V5R("1F:6QL
M("!);F1I8V%T97,@:68@=&AE(&-E;&P@8F%C:V=R;W5N9"!M=7-T.@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@+2`P.B!T<F%N<W!A<F5N="`H
M9&5F875L="D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("T@,3H@
M<&%I;G1E9`H@("`@("H*("`@("`J($!S964@1FEL95]01$8Z.G-E=$9O;G0*
M("`@("`J($!S964@1FEL95]01$8Z.G-E=$1R87=#;VQO<@H@("`@("H@0'-E
M92!&:6QE7U!$1CHZ<V5T1FEL;$-O;&]R"B`@("`@*B!`<V5E($9I;&5?4$1&
M.CIS971,:6YE5VED=&@*("`@("`J($!S964@1FEL95]01$8Z.F-E;&P*("`@
M("`J($!S964@1FEL95]01$8Z.G=R:71E"B`@("`@*B!`<V5E($9I;&5?4$1&
M.CIS971!=71O4&%G94)R96%K"B`@("`@*B\*("`@(&9U;F-T:6]N(&UU;'1I
M0V5L;"@D=VED=&@L("1H96EG:'0L("1T97AT+"`D8F]R9&5R(#T@,"P@)&%L
M:6=N(#T@)THG+"`D9FEL;"`](#`I"B`@("!["B`@("`@("`@)&-W(#T@)B1T
M:&ES+3Y?8W5R<F5N=%]F;VYT6R=C=R==.PH@("`@("`@(&EF("@D=VED=&@@
M/3T@,"D@>PH@("`@("`@("`@("`D=VED=&@@/2`D=&AI<RT^=R`M("1T:&ES
M+3Y?<FEG:'1?;6%R9VEN("T@)'1H:7,M/G@["B`@("`@("`@?0H@("`@("`@
M("1W;6%X(#T@*"1W:61T:"TR("H@)'1H:7,M/E]C96QL7VUA<F=I;BD@*B`Q
M,#`P("\@)'1H:7,M/E]F;VYT7W-I>F4["B`@("`@("`@)',@/2!S=')?<F5P
M;&%C92@B7'(B+"`G)RP@)'1E>'0I.PH@("`@("`@("1N8B`]('-T<FQE;B@D
M<RD["B`@("`@("`@:68@*"1N8B`^(#`@)B8@)'-;)&YB+3%=(#T](")<;B(I
M('L*("`@("`@("`@("`@)&YB+2T["B`@("`@("`@?0H@("`@("`@("1B(#T@
M,#L*("`@("`@("!I9B`H)&)O<F1E<BD@>PH@("`@("`@("`@("!I9B`H)&)O
M<F1E<B`]/2`Q*2!["B`@("`@("`@("`@("`@("`D8F]R9&5R(#T@)TQ44D(G
M.PH@("`@("`@("`@("`@("`@)&(@/2`G3%)4)SL*("`@("`@("`@("`@("`@
M("1B,B`]("=,4B<["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D8C(@/2`G)SL*("`@("`@("`@("`@("`@(&EF("AS=')P;W,H)&)O
M<F1E<BP@)TPG*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("`D
M8C(@+CT@)TPG.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M:68@*'-T<G!O<R@D8F]R9&5R+"`G4B<I("$]/2!F86QS92D@>PH@("`@("`@
M("`@("`@("`@("`@("1B,B`N/2`G4B<["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`D8B`]("AS=')P;W,H)&)O<F1E<BP@)U0G*2`A/3T@
M9F%L<V4I(#\@)&(R("X@)U0G(#H@)&(R.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@("`@("1S97`@/2`M,3L*("`@("`@("`D:2`@(#T@,#L*("`@
M("`@("`D:B`@(#T@,#L*("`@("`@("`D;"`@(#T@,#L*("`@("`@("`D;G,@
M(#T@,#L*("`@("`@("`D;FP@(#T@,3L*("`@("`@("!W:&EL92`H)&D@/"`D
M;F(I('L*("`@("`@("`@("`@+RH@1V5T(&YE>'0@8VAA<F%C=&5R+B`J+PH@
M("`@("`@("`@("`D8R`]("1S6R1I73L*("`@("`@("`@("`@:68@*"1C(#T]
M(")<;B(I('L*("`@("`@("`@("`@("`@("\J($5X<&QI8VET(&QI;F4@8G)E
M86LN("HO"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]W;W)D7W-P86-I
M;F<@/B`P*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]W;W)D7W-P
M86-I;F<@/2`P.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<P
M(%1W)RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=&AI
M<RT^8V5L;"@D=VED=&@L("1H96EG:'0L('-U8G-T<B@D<RP@)&HL("1I+21J
M*2P@)&(L(#(L("1A;&EG;BP@)&9I;&PI.PH@("`@("`@("`@("`@("`@)&DK
M*SL*("`@("`@("`@("`@("`@("1S97`@/2`M,3L*("`@("`@("`@("`@("`@
M("1J(#T@)&D["B`@("`@("`@("`@("`@("`D;"`](#`["B`@("`@("`@("`@
M("`@("`D;G,@/2`P.PH@("`@("`@("`@("`@("`@)&YL*RL["B`@("`@("`@
M("`@("`@("!I9B`H)&)O<F1E<B`F)B`D;FP@/3T@,BD@>PH@("`@("`@("`@
M("`@("`@("`@("1B(#T@)&(R.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M:68@*"1C(#T]("<@)RD@>PH@("`@("`@("`@("`@("`@)'-E<"`]("1I.PH@
M("`@("`@("`@("`@("`@)&QS(#T@)&P["B`@("`@("`@("`@("`@("`D;G,K
M*SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D;"`K/2`D8W=;)&-=.PH@
M("`@("`@("`@("!I9B`H)&P@/B`D=VUA>"D@>PH@("`@("`@("`@("`@("`@
M+RH@075T;VUA=&EC(&QI;F4@8G)E86LN("HO"B`@("`@("`@("`@("`@("!I
M9B`H)'-E<"`]/2`M,2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D:2`]
M/2`D:BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D:2LK.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M
M/E]W;W)D7W-P86-I;F<@/B`P*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?=V]R9%]S<&%C:6YG(#T@,#L*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]O=70H)S`@5'<G*3L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-E;&PH)'=I9'1H+"`D
M:&5I9VAT+"!S=6)S='(H)',L("1J+"`D:2`M("1J*2P@)&(L(#(L("1A;&EG
M;BP@)&9I;&PI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("!I9B`H)&%L:6=N(#T]("=*)RD@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W=O<F1?<W!A8VEN9R`]("@D;G,^,2D@/R`H
M)'=M87@@+2`D;',I+S$P,#`@*B`D=&AI<RT^7V9O;G1?<VEZ92`O("@D;G,@
M+2`Q*2`Z(#`["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T
M*'-P<FEN=&8H)R4N,V8@5'<G+"`D=&AI<RT^7W=O<F1?<W!A8VEN9R`J("1T
M:&ES+3Y?<V-A;&4I*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/F-E;&PH)'=I9'1H+"`D:&5I9VAT+"!S=6)S
M='(H)',L("1J+"`D<V5P("T@)&HI+"`D8BP@,BP@)&%L:6=N+"`D9FEL;"D[
M"B`@("`@("`@("`@("`@("`@("`@)&D@/2`D<V5P("L@,3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1S97`@/2`M,3L*("`@("`@("`@
M("`@("`@("1J(#T@)&D["B`@("`@("`@("`@("`@("`D;"`](#`["B`@("`@
M("`@("`@("`@("`D;G,@/2`P.PH@("`@("`@("`@("`@("`@)&YL*RL["B`@
M("`@("`@("`@("`@("!I9B`H)&)O<F1E<B`F)B`D;FP@/3T@,BD@>PH@("`@
M("`@("`@("`@("`@("`@("1B(#T@)&(R.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&DK*SL*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`O*B!,87-T(&-H=6YK+B`J
M+PH@("`@("`@(&EF("@D=&AI<RT^7W=O<F1?<W!A8VEN9R`^(#`I('L*("`@
M("`@("`@("`@)'1H:7,M/E]W;W)D7W-P86-I;F<@/2`P.PH@("`@("`@("`@
M("`D=&AI<RT^7V]U="@G,"!4=R<I.PH@("`@("`@('T*("`@("`@("!I9B`H
M)&)O<F1E<B`F)B!S=')P;W,H)&)O<F1E<BP@)T(G*2`A/3T@9F%L<V4I('L*
M("`@("`@("`@("`@)&(@+CT@)T(G.PH@("`@("`@('T*("`@("`@("`D=&AI
M<RT^8V5L;"@D=VED=&@L("1H96EG:'0L('-U8G-T<B@D<RP@)&HL("1I*2P@
M)&(L(#(L("1A;&EG;BP@)&9I;&PI.PH@("`@("`@("1T:&ES+3YX(#T@)'1H
M:7,M/E]L969T7VUA<F=I;CL*("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@
M;65T:&]D('!R:6YT<R!T97AT(&9R;VT@=&AE(&-U<G)E;G0@<&]S:71I;VXN
M(%=H96X@=&AE(')I9VAT"B`@("`@*B!M87)G:6X@:7,@<F5A8VAE9"`H;W(@
M=&AE(%QN(&-H87)A8W1E<B!I<R!M970I(&$@;&EN92!B<F5A:R!O8V-U<G,@
M86YD"B`@("`@*B!T97AT(&-O;G1I;G5E<R!F<F]M('1H92!L969T(&UA<F=I
M;BX@57!O;B!M971H;V0@97AI="P@=&AE(&-U<G)E;G0*("`@("`J('!O<VET
M:6]N(&ES(&QE9G0@:G5S="!A="!T:&4@96YD(&]F('1H92!T97AT+@H@("`@
M("H@270@:7,@<&]S<VEB;&4@=&\@<'5T(&$@;&EN:R!O;B!T:&4@=&5X="X*
M("`@("`J"B`@("`@*B!%>&%M<&QE.@H@("`@("H@+R]"96=I;B!W:71H(')E
M9W5L87(@9F]N=`H@("`@("H@)'!D9BT^<V5T1F]N="@G07)I86PG+"<G+#$T
M*3L*("`@("`J("1P9&8M/G=R:71E*#4L)U9I<VET("<I.PH@("`@("H@+R]4
M:&5N('!U="!A(&)L=64@=6YD97)L:6YE9"!L:6YK"B`@("`@*B`D<&1F+3YS
M971497AT0V]L;W(H,"PP+#(U-2D["B`@("`@*B`D<&1F+3YS971&;VYT*"<G
M+"=5)RD["B`@("`@*B`D<&1F+3YW<FET92@U+"=W=W<N9G!D9BYO<F<G+"=H
M='1P.B\O=W=W+F9P9&8N;W)G)RD["B`@("`@*@H@("`@("H@0'!A<F%M(&9L
M;V%T("1H96EG:'0@($QI;F4@:&5I9VAT+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=&5X="`@(%-T<FEN9R!T;R!P<FEN="X*("`@("`J($!P87)A;2!M:7AE
M9"`D;&EN:R`@("!54DP@;W(@:61E;G1I9FEE<B!R971U<FYE9"!B>2!!9&1,
M:6YK*"DN"B`@("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T1F]N=`H@
M("`@("H@0'-E92!&:6QE7U!$1CHZ861D3&EN:PH@("`@("H@0'-E92!&:6QE
M7U!$1CHZ;75L=&E#96QL"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS971!=71O
M4&%G94)R96%K"B`@("`@*B\*("`@(&9U;F-T:6]N('=R:71E*"1H96EG:'0L
M("1T97AT+"`D;&EN:R`]("<G*0H@("`@>PH@("`@("`@("1C=R`]("8D=&AI
M<RT^7V-U<G)E;G1?9F]N=%LG8W<G73L*("`@("`@("`D=VED=&@@/2`D=&AI
M<RT^=R`M("1T:&ES+3Y?<FEG:'1?;6%R9VEN("T@)'1H:7,M/G@["B`@("`@
M("`@)'=M87@@/2`H)'=I9'1H("T@,B`J("1T:&ES+3Y?8V5L;%]M87)G:6XI
M("H@,3`P,"`O("1T:&ES+3Y?9F]N=%]S:7IE.PH@("`@("`@("1S(#T@<W1R
M7W)E<&QA8V4H(EQR(BP@)R<L("1T97AT*3L*("`@("`@("`D;F(@/2!S=')L
M96XH)',I.PH@("`@("`@("1S97`@/2`M,3L*("`@("`@("`D:2`](#`["B`@
M("`@("`@)&H@/2`P.PH@("`@("`@("1L(#T@,#L*("`@("`@("`D;FP@/2`Q
M.PH@("`@("`@('=H:6QE("@D:2`\("1N8BD@>PH@("`@("`@("`@("`O*B!'
M970@;F5X="!C:&%R86-T97(N("HO"B`@("`@("`@("`@("1C(#T@)'-[)&E]
M.PH@("`@("`@("`@("!I9B`H)&,@/3T@(EQN(BD@>PH@("`@("`@("`@("`@
M("`@+RH@17AP;&EC:70@;&EN92!B<F5A:RX@*B\*("`@("`@("`@("`@("`@
M("1T:&ES+3YC96QL*"1W:61T:"P@)&AE:6=H="P@<W5B<W1R*"1S+"`D:BP@
M)&D@+2`D:BDL(#`L(#(L("<G+"`P+"`D;&EN:RD["B`@("`@("`@("`@("`@
M("`D:2LK.PH@("`@("`@("`@("`@("`@)'-E<"`]("TQ.PH@("`@("`@("`@
M("`@("`@)&H@/2`D:3L*("`@("`@("`@("`@("`@("1L(#T@,#L*("`@("`@
M("`@("`@("`@(&EF("@D;FP@/3T@,2D@>PH@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YX(#T@)'1H:7,M/E]L969T7VUA<F=I;CL*("`@("`@("`@("`@
M("`@("`@("`D=VED=&@@/2`D=&AI<RT^=R`M("1T:&ES+3Y?<FEG:'1?;6%R
M9VEN("T@)'1H:7,M/G@["B`@("`@("`@("`@("`@("`@("`@)'=M87@@/2`H
M)'=I9'1H("T@,B`J("1T:&ES+3Y?8V5L;%]M87)G:6XI("H@,3`P,"`O("1T
M:&ES+3Y?9F]N=%]S:7IE.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@)&YL*RL["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!I9B`H)&,@/3T@)R`G*2!["B`@("`@("`@
M("`@("`@("`D<V5P(#T@)&D["B`@("`@("`@("`@("`@("`D;',@/2`D;#L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D;"`K/2`D8W=;)&-=.PH@("`@
M("`@("`@("!I9B`H)&P@/B`D=VUA>"D@>PH@("`@("`@("`@("`@("`@+RH@
M075T;VUA=&EC(&QI;F4@8G)E86LN("HO"B`@("`@("`@("`@("`@("!I9B`H
M)'-E<"`]/2`M,2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^
M>"`^("1T:&ES+3Y?;&5F=%]M87)G:6XI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@+RH@36]V92!T;R!N97AT(&QI;F4N("HO"B`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YX(#T@)'1H:7,M/E]L969T7VUA<F=I;CL*("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/GD@*ST@)&AE:6=H=#L*("`@
M("`@("`@("`@("`@("`@("`@("`@)'=I9'1H(#T@)'1H:7,M/G<@+2`D=&AI
M<RT^7W)I9VAT7VUA<F=I;B`M("1T:&ES+3YX.PH@("`@("`@("`@("`@("`@
M("`@("`@("`D=VUA>"`]("@D=VED=&@@+2`R("H@)'1H:7,M/E]C96QL7VUA
M<F=I;BD@*B`Q,#`P("\@)'1H:7,M/E]F;VYT7W-I>F4["B`@("`@("`@("`@
M("`@("`@("`@("`@("1I*RL["B`@("`@("`@("`@("`@("`@("`@("`@("1N
M;"LK.PH@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@:68@*"1I(#T]
M("1J*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1I*RL["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC96QL
M*"1W:61T:"P@)&AE:6=H="P@<W5B<W1R*"1S+"`D:BP@)&D@+2`D:BDL(#`L
M(#(L("<G+"`P+"`D;&EN:RD["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YC96QL*"1W:61T:"P@)&AE:6=H
M="P@<W5B<W1R*"1S+"`D:BP@)'-E<"`M("1J*2P@,"P@,BP@)R<L(#`L("1L
M:6YK*3L*("`@("`@("`@("`@("`@("`@("`D:2`]("1S97`@*R`Q.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'-E<"`]("TQ.PH@("`@
M("`@("`@("`@("`@)&H@/2`D:3L*("`@("`@("`@("`@("`@("1L(#T@,#L*
M("`@("`@("`@("`@("`@(&EF("@D;FP@/3T@,2D@>PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YX(#T@)'1H:7,M/E]L969T7VUA<F=I;CL*("`@("`@
M("`@("`@("`@("`@("`D=VED=&@@/2`D=&AI<RT^=R`M("1T:&ES+3Y?<FEG
M:'1?;6%R9VEN("T@)'1H:7,M/G@["B`@("`@("`@("`@("`@("`@("`@)'=M
M87@@/2`H)'=I9'1H("T@,B`J("1T:&ES+3Y?8V5L;%]M87)G:6XI("H@,3`P
M,"`O("1T:&ES+3Y?9F]N=%]S:7IE.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@)&YL*RL["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M96QS90H@("`@("`@("`@("`@("`@)&DK*SL*("`@("`@("!]"B`@("`@("`@
M+RH@3&%S="!C:'5N:RX@*B\*("`@("`@("!I9B`H)&D@(3T@)&HI('L*("`@
M("`@("`@("`@)'1H:7,M/F-E;&PH)&P@+R`Q,#`P("H@)'1H:7,M/E]F;VYT
M7W-I>F4L("1H96EG:'0L('-U8G-T<B@D<RP@)&HL("1I*2P@,"P@,"P@)R<L
M(#`L("1L:6YK*3L*("`@("`@("!]"B`@("!]"@H@("`@("\J*@H@("`@("H@
M=W)I=&4@4F]T871E9"!497AT+@H@("`@("H*("`@("`J(%=R:71E('1E>'0@
M870@86X@86YG;&4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@@
M("`@("`@("!8(&-O;W)D:6YA=&4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M>2`@("`@("`@(%D@8V]O<F1I;F%T92X*("`@("`J($!P87)A;2!S=')I;F<@
M)'1E>'0@("`@("`@5&5X="!T;R!W<FET92X*("`@("`J($!P87)A;2!F;&]A
M="`D=&5X=%]A;F=L92`@06YG;&4@=&\@<F]T871E("A%9RX@.3`@/2!B;W1T
M;VT@=&\@=&]P*2X*("`@("`J($!P87)A;2!F;&]A="`D9F]N=%]A;F=L92`@
M4F]T871E(&-H87)A8W1E<G,@87,@=V5L;"!A<R!T97AT+@H@("`@("H*("`@
M("`J($!S964@1FEL95]01$8Z.G-E=$9O;G0*("`@("`J+PH@("`@(&9U;F-T
M:6]N('=R:71E4F]T871E9"@D>"P@)'DL("1T97AT+"`D=&5X=%]A;F=L92P@
M)&9O;G1?86YG;&4@/2`P*0H@("`@('L*("`@("`@("`@+RH@17-C87!E('1E
M>'0N("HO"B`@("`@("`@("1T97AT(#T@)'1H:7,M/E]E<V-A<&4H)'1E>'0I
M.PH*("`@("`@("`@)&9O;G1?86YG;&4@*ST@.3`@*R`D=&5X=%]A;F=L93L*
M("`@("`@("`@)'1E>'1?86YG;&4@*CT@35]022`O(#$X,#L*("`@("`@("`@
M)&9O;G1?86YG;&4@*CT@35]022`O(#$X,#L*"B`@("`@("`@("1T97AT7V1X
M(#T@8V]S*"1T97AT7V%N9VQE*3L*("`@("`@("`@)'1E>'1?9'D@/2!S:6XH
M)'1E>'1?86YG;&4I.PH@("`@("`@("`D9F]N=%]D>"`](&-O<R@D9F]N=%]A
M;F=L92D["B`@("`@("`@("1F;VYT7V1Y(#T@<VEN*"1F;VYT7V%N9VQE*3L*
M"B`@("`@("`@("1S/2!S<')I;G1F*"="5"`E+C)F("4N,F8@)2XR9B`E+C)F
M("4N,F8@)2XR9B!4;2`H)7,I(%1J($54)RP*("`@("`@("`@("`@("`@("`@
M("`@)'1E>'1?9'@L("1T97AT7V1Y+"`D9F]N=%]D>"P@)&9O;G1?9'DL"B`@
M("`@("`@("`@("`@("`@("`@("1X("H@)'1H:7,M/E]S8V%L92P@*"1T:&ES
M+3YH+21Y*2`J("1T:&ES+3Y?<V-A;&4L("1T97AT*3L*"B`@("`@("`@(&EF
M("@@)'1H:7,M/E]D<F%W7V-O;&]R*2!["B`@("`@("`@("`@("`D<STG<2`G
M("X@)'1H:7,M/E]D<F%W7V-O;&]R("X@)R`G("X@)',@+B`G(%$G.PH@("`@
M("`@("!]"B`@("`@("`@("1T:&ES+3Y?;W5T*"1S*3L*("`@("!]"@H@("`@
M+RHJ"B`@("`@*B!0<FEN=',@86X@:6UA9V4@:6X@=&AE('!A9V4N(%1H92!U
M<'!E<BUL969T(&-O<FYE<B!A;F0@870@;&5A<W0@;VYE(&]F"B`@("`@*B!T
M:&4@9&EM96YS:6]N<R!M=7-T(&)E('-P96-I9FEE9#L@=&AE(&AE:6=H="!O
M<B!T:&4@=VED=&@@8V%N(&)E"B`@("`@*B!C86QC=6QA=&5D(&%U=&]M871I
M8V%L;'D@:6X@;W)D97(@=&\@:V5E<"!T:&4@:6UA9V4@<')O<&]R=&EO;G,N
M"B`@("`@*B!3=7!P;W)T960@9F]R;6%T<R!A<F4@2E!%1R!A;F0@4$Y'+@H@
M("`@("H*("`@("`J($9O<B!*4$5'+"!A;&P@9FQA=F]R<R!A<F4@86QL;W=E
M9#H*("`@("`J("`@+2!G<F%Y('-C86QE<PH@("`@("H@("`M('1R=64@8V]L
M;W)S("@R-"!B:71S*0H@("`@("H@("`M($--64L@*#,R(&)I=',I"B`@("`@
M*@H@("`@("H@1F]R(%!.1RP@87)E(&%L;&]W960Z"B`@("`@*B`@("T@9W)A
M>2!S8V%L97,@;VX@870@;6]S="`X(&)I=',@*#(U-B!L979E;',I"B`@("`@
M*B`@("T@:6YD97AE9"!C;VQO<G,*("`@("`J("`@+2!T<G5E(&-O;&]R<R`H
M,C0@8FET<RD*("`@("`J(&)U="!A<F4@;F]T('-U<'!O<G1E9#H*("`@("`J
M("`@+2!);G1E<FQA8VEN9PH@("`@("H@("`M($%L<&AA(&-H86YN96P*("`@
M("`J"B`@("`@*B!)9B!A('1R86YS<&%R96YT(&-O;&]R(&ES(&1E9FEN960L
M(&ET('=I;&P@8F4@=&%K96X@:6YT;R!A8V-O=6YT("AB=70*("`@("`J('=I
M;&P@8F4@;VYL>2!I;G1E<G!R971E9"!B>2!!8W)O8F%T(#0@86YD(&%B;W9E
M*2X*("`@("`J(%1H92!F;W)M870@8V%N(&)E('-P96-I9FEE9"!E>'!L:6-I
M=&QY(&]R(&EN9F5R<F5D(&9R;VT@=&AE(&9I;&4*("`@("`J(&5X=&5N<VEO
M;BX*("`@("`J($ET(&ES('!O<W-I8FQE('1O('!U="!A(&QI;FL@;VX@=&AE
M(&EM86=E+@H@("`@("H*("`@("`J(%)E;6%R:SH@:68@86X@:6UA9V4@:7,@
M=7-E9"!S979E<F%L('1I;65S+"!O;FQY(&]N92!C;W!Y('=I;&P@8F4*("`@
M("`J(&5M8F5D9&5D(&EN('1H92!F:6QE+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&9I;&4@("!.86UE(&]F('1H92!F:6QE(&-O;G1A:6YI;F<@
M=&AE(&EM86=E+@H@("`@("H@0'!A<F%M(&9L;V%T("1X("`@("`@($%B<V-I
M<W-A(&]F('1H92!U<'!E<BUL969T(&-O<FYE<BX*("`@("`J($!P87)A;2!F
M;&]A="`D>2`@("`@("!/<F1I;F%T92!O9B!T:&4@=7!P97(M;&5F="!C;W)N
M97(N"B`@("`@*B!`<&%R86T@9FQO870@)'=I9'1H("`@5VED=&@@;V8@=&AE
M(&EM86=E(&EN('1H92!P86=E+B!)9B!E<75A;"!T;R!Z97)O+`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@(&ET(&ES(&%U=&]M871I8V%L;'D@8V%L
M8W5L871E9"!T;R!K965P('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@(&]R:6=I;F%L('!R;W!O<G1I;VYS+@H@("`@("H@0'!A<F%M(&9L;V%T
M("1H96EG:'0@($AE:6=H="!O9B!T:&4@:6UA9V4@:6X@=&AE('!A9V4N($EF
M(&YO="!S<&5C:69I960*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!O
M<B!E<75A;"!T;R!Z97)O+"!I="!I<R!A=71O;6%T:6-A;&QY(&-A;&-U;&%T
M960*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!T;R!K965P('1H92!O
M<FEG:6YA;"!P<F]P;W)T:6]N<RX*("`@("`J($!P87)A;2!S=')I;F<@)'1Y
M<&4@("!);6%G92!F;W)M870N(%!O<W-I8FQE('9A;'5E<R!A<F4@*&-A<V4*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!I;G-E;G-I=&EV92D@.B!*
M4$<L($I014<L(%!.1RX@268@;F]T('-P96-I9FEE9"P*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!T:&4@='EP92!I<R!I;F9E<G)E9"!F<F]M('1H
M92!F:6QE(&5X=&5N<VEO;BX*("`@("`J($!P87)A;2!M:7AE9"`D;&EN:R`@
M("!54DP@;W(@:61E;G1I9FEE<B!R971U<FYE9"!B>2!&:6QE7U!$1CHZ861D
M3&EN:RX*("`@("`J"B`@("`@*B!`<V5E($9I;&5?4$1&.CIA9&1,:6YK"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&EM86=E*"1F:6QE+"`D>"P@)'DL("1W:61T
M:"`](#`L("1H96EG:'0@/2`P+"`D='EP92`]("<G+"`D;&EN:R`]("<G*0H@
M("`@>PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]I;6%G97-;)&9I;&5=
M*2D@>PH@("`@("`@("`@("`O*B!&:7)S="!U<V4@;V8@:6UA9V4L(&=E="!S
M;VUE(&9I;&4@:6YF;RX@*B\*("`@("`@("`@("`@:68@*"1T>7!E(#T]("<G
M*2!["B`@("`@("`@("`@("`@("`D<&]S(#T@<W1R<G!O<R@D9FEL92P@)RXG
M*3L*("`@("`@("`@("`@("`@(&EF("@D<&]S(#T]/2!F86QS92D@>PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BAS<')I
M;G1F*"=);6%G92!F:6QE(&AA<R!N;R!E>'1E;G-I;VX@86YD(&YO('1Y<&4@
M=V%S('-P96-I9FEE9#H@)7,G+"`D9FEL92DI.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@)'1Y<&4@/2!S=6)S='(H)&9I;&4L("1P;W,@
M*R`Q*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D='EP92`]('-T<G1O
M;&]W97(H)'1Y<&4I.PH@("`@("`@("`@("`D;7%R(#T@9V5T7VUA9VEC7W%U
M;W1E<U]R=6YT:6UE*"D["B`@("`@("`@("`@('-E=%]M86=I8U]Q=6]T97-?
M<G5N=&EM92@P*3L*("`@("`@("`@("`@:68@*"1T>7!E(#T]("=J<&<G('Q\
M("1T>7!E(#T]("=J<&5G)RD@>PH@("`@("`@("`@("`@("`@)&EN9F\@/2`D
M=&AI<RT^7W!A<G-E2E!'*"1F:6QE*3L*("`@("`@("`@("`@?2!E;'-E:68@
M*"1T>7!E(#T]("=P;F<G*2!["B`@("`@("`@("`@("`@("`D:6YF;R`]("1T
M:&ES+3Y?<&%R<V503D<H)&9I;&4I.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*'-P<FEN
M=&8H)U5N<W5P<&]R=&5D(&EM86=E(&9I;&4@='EP93H@)7,G+"`D='EP92DI
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@('-E=%]M86=I8U]Q=6]T97-?
M<G5N=&EM92@D;7%R*3L*("`@("`@("`@("`@)&EN9F];)VDG72`](&-O=6YT
M*"1T:&ES+3Y?:6UA9V5S*2`K(#$["B`@("`@("`@("`@("1T:&ES+3Y?:6UA
M9V5S6R1F:6QE72`]("1I;F9O.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1I;F9O(#T@)'1H:7,M/E]I;6%G97-;)&9I;&5=.PH@("`@("`@('T*
M"B`@("`@("`@+RH@36%K92!S=7)E(&%L;"!V87)S(&%R92!C;VYV97)T960@
M=&\@<'0@<V-A;&4N("HO"B`@("`@("`@)'@@("`@("`]("1T:&ES+3Y?=&]0
M="@D>"D["B`@("`@("`@)'D@("`@("`]("1T:&ES+3Y?=&]0="@D>2D["B`@
M("`@("`@)'=I9'1H("`]("1T:&ES+3Y?=&]0="@D=VED=&@I.PH@("`@("`@
M("1H96EG:'0@/2`D=&AI<RT^7W1O4'0H)&AE:6=H="D["@H@("`@("`@("\J
M($EF(&YO="!S<&5C:69I960@9&\@875T;VUA=&EC('=I9'1H(&%N9"!H96EG
M:'0@8V%L8W5L871I;VYS+B`J+PH@("`@("`@(&EF("AE;7!T>2@D=VED=&@I
M("8F(&5M<'1Y*"1H96EG:'0I*2!["B`@("`@("`@("`@("1W:61T:"`]("1I
M;F9O6R=W)UT["B`@("`@("`@("`@("1H96EG:'0@/2`D:6YF;ULG:"==.PH@
M("`@("`@('T@96QS96EF("AE;7!T>2@D=VED=&@I*2!["B`@("`@("`@("`@
M("1W:61T:"`]("1H96EG:'0@*B`D:6YF;ULG=R==("\@)&EN9F];)V@G73L*
M("`@("`@("!](&5L<V5I9B`H96UP='DH)&AE:6=H="DI('L*("`@("`@("`@
M("`@)&AE:6=H="`]("1W:61T:"`J("1I;F9O6R=H)UT@+R`D:6YF;ULG=R==
M.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]O=70H<W!R:6YT9B@G<2`E
M+C)F(#`@,"`E+C)F("4N,F8@)2XR9B!C;2`O225D($1O(%$G+"`D=VED=&@L
M("1H96EG:'0L("1X+"`D=&AI<RT^:%!T("T@*"1Y("L@)&AE:6=H="DL("1I
M;F9O6R=I)UTI*3L*"B`@("`@("`@+RH@4V5T(&%N>2!L:6YK(&EF(')E<75E
M<W1E9"X@*B\*("`@("`@("!I9B`H)&QI;FLI('L*("`@("`@("`@("`@)'1H
M:7,M/E]L:6YK*"1X+"`D>2P@)'=I9'1H+"`D:&5I9VAT+"`D;&EN:RD["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4&5R9F]R;7,@82!L:6YE
M(&)R96%K+B!4:&4@8W5R<F5N="!A8G-C:7-S82!G;V5S(&)A8VL@=&\@=&AE
M(&QE9G0*("`@("`J(&UA<F=I;B!A;F0@=&AE(&]R9&EN871E(&EN8W)E87-E
M<R!B>2!T:&4@86UO=6YT('!A<W-E9"!I;B!P87)A;65T97(N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&9L;V%T("1H96EG:'0@(%1H92!H96EG:'0@;V8@=&AE
M(&)R96%K+B!">2!D969A=6QT+"!T:&4@=F%L=64*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!E<75A;',@=&AE(&AE:6=H="!O9B!T:&4@;&%S="!P
M<FEN=&5D(&-E;&PN"B`@("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ8V5L
M;`H@("`@("HO"B`@("!F=6YC=&EO;B!N97=,:6YE*"1H96EG:'0@/2`G)RD*
M("`@('L*("`@("`@("`D=&AI<RT^>"`]("1T:&ES+3Y?;&5F=%]M87)G:6X[
M"B`@("`@("`@:68@*&ES7W-T<FEN9R@D:&5I9VAT*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^>2`K/2`D=&AI<RT^7VQA<W1?:&5I9VAT.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1T:&ES+3YY("L]("1H96EG:'0["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@86)S8VES
M<V$@;V8@=&AE(&-U<G)E;G0@<&]S:71I;VX@:6X@=7-E<B!U;FET<RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&9L;V%T"B`@("`@*@H@("`@("H@0'-E92!&
M:6QE7U!$1CHZ<V5T6`H@("`@("H@0'-E92!&:6QE7U!$1CHZ9V5T60H@("`@
M("H@0'-E92!&:6QE7U!$1CHZ<V5T60H@("`@("HO"B`@("!F=6YC=&EO;B!G
M9718*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G@["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!$969I;F5S('1H92!A8G-C:7-S82!O9B!T:&4@8W5R
M<F5N="!P;W-I=&EO;BX@268@=&AE('!A<W-E9"!V86QU92!I<PH@("`@("H@
M;F5G871I=F4L(&ET(&ES(')E;&%T:79E('1O('1H92!R:6=H="!O9B!T:&4@
M<&%G92X*("`@("`J"B`@("`@*B!`<&%R86T@9FQO870@)'@@(%1H92!V86QU
M92!O9B!T:&4@86)S8VES<V$N"B`@("`@*@H@("`@("H@0'-E92!&:6QE7U!$
M1CHZ9V5T6`H@("`@("H@0'-E92!&:6QE7U!$1CHZ9V5T60H@("`@("H@0'-E
M92!&:6QE7U!$1CHZ<V5T60H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T6%D*
M("`@("`J+PH@("`@9G5N8W1I;VX@<V5T6"@D>"D*("`@('L*("`@("`@("!I
M9B`H)'@@/CT@,"D@>PH@("`@("`@("`@("`O*B!!8G-O;'5T92!V86QU92X@
M*B\*("`@("`@("`@("`@)'1H:7,M/G@@/2`D>#L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`O*B!.96=A=&EV92P@<V\@<F5L871I=F4@=&\@<FEG
M:'0@961G92!O9B!T:&4@<&%G92X@*B\*("`@("`@("`@("`@)'1H:7,M/G@@
M/2`D=&AI<RT^=R`K("1X.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE(&]R9&EN871E(&]F('1H92!C=7)R96YT('!O<VET
M:6]N(&EN('5S97(@=6YI=',N"B`@("`@*@H@("`@("H@0')E='5R;B!F;&]A
M=`H@("`@("H*("`@("`J($!S964@1FEL95]01$8Z.G-E=%D*("`@("`J($!S
M964@1FEL95]01$8Z.F=E=%@*("`@("`J($!S964@1FEL95]01$8Z.G-E=%@*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T62@I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3YY.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5F:6YE<R!T
M:&4@;W)D:6YA=&4@;V8@=&AE(&-U<G)E;G0@<&]S:71I;VXN($EF('1H92!P
M87-S960@=F%L=64@:7,*("`@("`J(&YE9V%T:79E+"!I="!I<R!R96QA=&EV
M92!T;R!T:&4@8F]T=&]M(&]F('1H92!P86=E+@H@("`@("H*("`@("`J($!P
M87)A;2!F;&]A="`D>2`@5&AE('9A;'5E(&]F('1H92!O<F1I;F%T92X*("`@
M("`J"B`@("`@*B!`<V5E($9I;&5?4$1&.CIG9718"B`@("`@*B!`<V5E($9I
M;&5?4$1&.CIG9719"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS9719"B`@("`@
M*B!`<V5E($9I;&5?4$1&.CIS971860H@("`@("HO"B`@("!F=6YC=&EO;B!S
M9719*"1Y*0H@("`@>PH@("`@("`@(&EF("@D>2`^/2`P*2!["B`@("`@("`@
M("`@("1T:&ES+3YY(#T@)'D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'1H:7,M/GD@/2`D=&AI<RT^:"`K("1Y.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($1E9FEN97,@=&AE(&%B<V-I<W-A(&%N9"!O<F1I
M;F%T92!O9B!T:&4@8W5R<F5N="!P;W-I=&EO;BX@268@=&AE"B`@("`@*B!P
M87-S960@=F%L=65S(&%R92!N96=A=&EV92P@=&AE>2!A<F4@<F5L871I=F4@
M<F5S<&5C=&EV96QY('1O('1H92!R:6=H=`H@("`@("H@86YD(&)O='1O;2!O
M9B!T:&4@<&%G92X*("`@("`J"B`@("`@*B!`<&%R86T@9FQO870@)'@@(%1H
M92!V86QU92!O9B!T:&4@86)S8VES<V$N"B`@("`@*B!`<&%R86T@9FQO870@
M)'D@(%1H92!V86QU92!O9B!T:&4@;W)D:6YA=&4N"B`@("`@*@H@("`@("H@
M0'-E92!&:6QE7U!$1CHZ<V5T6`H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T
M60H@("`@("HO"B`@("!F=6YC=&EO;B!S971862@D>"P@)'DI"B`@("!["B`@
M("`@("`@)'1H:7,M/G-E=%DH)'DI.PH@("`@("`@("1T:&ES+3YS9718*"1X
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(')A=R!01$8@
M9FEL92X*("`@("`J"B`@("`@*B!`<V5E($9I;&5?4$1&.CIO=71P=70*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T3W5T<'5T*"D*("`@('L*("`@("`@("`O
M*B!#:&5C:R!W:&5T:&5R(&9I;&4@:&%S(&)E96X@8VQO<V5D+B`J+PH@("`@
M("`@(&EF("@D=&AI<RT^7W-T871E(#P@,RD@>PH@("`@("`@("`@("`D=&AI
M<RT^8VQO<V4H*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^
M7V)U9F9E<CL*("`@('T*"B`@("`O*BH*("`@("`J($9U;F-T:6]N('1O(&]U
M='!U="!T:&4@8G5F9F5R960@9&%T82!T;R!T:&4@8G)O=W-E<BX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QE;F%M92`@5&AE(&9I;&5N86UE
M(&9O<B!T:&4@;W5T<'5T(&9I;&4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M:6YL:6YE("`@5')U92!I9B!I;FQI;F4L(&9A;'-E(&EF(&%T=&%C:&UE;G0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&]U='!U="@D9FEL96YA;64@/2`G=6YK
M;F]W;BYP9&8G+"`D:6YL:6YE(#T@9F%L<V4I"B`@("!["B`@("`@("`@+RH@
M0VAE8VL@=VAE=&AE<B!F:6QE(&AA<R!B965N(&-L;W-E9"X@*B\*("`@("`@
M("!I9B`H)'1H:7,M/E]S=&%T92`\(#,I('L*("`@("`@("`@("`@)'1H:7,M
M/F-L;W-E*"D["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!(5%107T1O=VYL
M;V%D(&ES(&YO="!A=F%I;&%B;&4@<F5T=7)N(%!%05)?17)R;W(N("HO"B`@
M("`@("`@:68@*"%`:6YC;'5D95]O;F-E("=(5%10+T1O=VYL;V%D+G!H<"<I
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=-:7-S
M:6YG(%!%05(@<&%C:V%G92!(5%107T1O=VYL;V%D+B<I.PH@("`@("`@('T*
M"B`@("`@("`@+RH@0VAE8VL@:68@:&5A9&5R<R!H879E(&)E96X@<V5N="X@
M*B\*("`@("`@("!I9B`H:&5A9&5R<U]S96YT*"DI('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=5;F%B;&4@=&\@<V5N9"!01$8@
M9FEL92P@<V]M92!D871A(&AA<R!A;')E861Y(&)E96X@;W5T<'5T('1O(&)R
M;W=S97(N)RD["B`@("`@("`@?0H*("`@("`@("`O*B!087)A;7,@9F]R('1H
M92!O=71P=70N("HO"B`@("`@("`@)&1I<W!O<VET:6]N(#T@*"$D:6YL:6YE
M*2`_($A45%!?1$]73DQ/041?051404-(345.5"`Z($A45%!?1$]73DQ/041?
M24Y,24Y%.PH@("`@("`@("1P87)A;7,@/2!A<G)A>2@G9&%T82<@("`@("`@
M("`@("`@("`]/B`D=&AI<RT^7V)U9F9E<BP*("`@("`@("`@("`@("`@("`@
M("`@("`@)V-O;G1E;G1T>7!E)R`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W!D
M9B<L"B`@("`@("`@("`@("`@("`@("`@("`@("=C;VYT96YT9&ES<&]S:71I
M;VXG(#T^(&%R<F%Y*"1D:7-P;W-I=&EO;BP@)&9I;&5N86UE*2D["B`@("`@
M("`@+RH@3W5T<'5T('1H92!F:6QE+B`J+PH@("`@("`@(')E='5R;B!(5%10
M7T1O=VYL;V%D.CIS=&%T:6-396YD*"1P87)A;7,I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1G5N8W1I;VX@=&\@<V%V92!T:&4@4$1&(&9I;&4@<V]M97=H
M97)E(&QO8V%L('1O('1H92!S97)V97(N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D9FEL96YA;64@(%1H92!F:6QE;F%M92!F;W(@=&AE(&]U='!U
M="!F:6QE+@H@("`@("HO"B`@("!F=6YC=&EO;B!S879E*"1F:6QE;F%M92`]
M("=U;FMN;W=N+G!D9B<I"B`@("!["B`@("`@("`@+RH@0VAE8VL@=VAE=&AE
M<B!F:6QE(&AA<R!B965N(&-L;W-E9"X@*B\*("`@("`@("!I9B`H)'1H:7,M
M/E]S=&%T92`\(#,I('L*("`@("`@("`@("`@)'1H:7,M/F-L;W-E*"D["B`@
M("`@("`@?0H*("`@("`@("`D9B`](&9O<&5N*"1F:6QE;F%M92P@)W=B)RD[
M"B`@("`@("`@:68@*"$D9BD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H<W!R:6YT9B@G56YA8FQE('1O('-A=F4@4$1&(&9I;&4Z
M("5S)RP@)&9I;&5N86UE*2D["B`@("`@("`@?0H@("`@("`@(&9W<FET92@D
M9BP@)'1H:7,M/E]B=69F97(L('-T<FQE;B@D=&AI<RT^7V)U9F9E<BDI.PH@
M("`@("`@(&9C;&]S92@D9BD["B`@("!]"@H@("`@9G5N8W1I;VX@7W1O4'0H
M)'9A;"D*("`@('L*("`@("`@("!R971U<FX@)'9A;"`J("1T:&ES+3Y?<V-A
M;&4["B`@("!]"@H@("`@9G5N8W1I;VX@)E]G971&;VYT1FEL92@D9F]N=&ME
M>2P@)'!A=&@@/2`G)RD*("`@('L*("`@("`@("!S=&%T:6,@)&9O;G1?=VED
M=&AS.PH*("`@("`@("!I9B`H(6ES<V5T*"1F;VYT7W=I9'1H<ULD9F]N=&ME
M>5TI*2!["B`@("`@("`@("`@(&EF("@A96UP='DH)'!A=&@I*2!["B`@("`@
M("`@("`@("`@("`D9FEL92`]("1P871H("X@<W1R=&]L;W=E<B@D9F]N=&ME
M>2D@+B`G+G!H<"<["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D9FEL92`]("=&:6QE+U!$1B]F;VYT<R\G("X@<W1R=&]L;W=E<B@D
M9F]N=&ME>2D@+B`G+G!H<"<["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M0')E<75I<F4@)&9I;&4["B`@("`@("`@("`@(&EF("@A:7-S970H)&9O;G1?
M=VED=&AS6R1F;VYT:V5Y72DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<BAS<')I;G1F*"=#;W5L9"!N;W0@:6YC;'5D92!F
M;VYT(&UE=')I8R!F:6QE.B`E<R<L("1F:6QE*2D["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D9F]N=%]W:61T:',["B`@("!]
M"@H@("`@9G5N8W1I;VX@7VQI;FLH)'@L("1Y+"`D=VED=&@L("1H96EG:'0L
M("1L:6YK*0H@("`@>PH@("`@("`@("\J(%-A=F4@;&EN:R!T;R!P86=E(&QI
M;FMS(&%R<F%Y+B`J+PH@("`@("`@("1T:&ES+3Y?<&%G95]L:6YK<ULD=&AI
M<RT^7W!A9V5=6UT@/2!A<G)A>2@D>"P@)'DL("1W:61T:"P@)&AE:6=H="P@
M)&QI;FLI.PH@("`@?0H*("`@(&9U;F-T:6]N(%]B96=I;D1O8R@I"B`@("![
M"B`@("`@("`@+RH@4W1A<G0@9&]C=6UE;G0L(&)U="!O;FQY(&EF(&YO="!Y
M970@<W1A<G1E9"X@*B\*("`@("`@("!I9B`H)'1H:7,M/E]S=&%T92`\(#$I
M('L*("`@("`@("`@("`@)'1H:7,M/E]S=&%T92`](#$["B`@("`@("`@("`@
M("1T:&ES+3Y?;W5T*"<E4$1&+3$N,R<I.PH@("`@("`@('T*("`@('T*"B`@
M("!F=6YC=&EO;B!?<'5T4&%G97,H*0H@("`@>PH@("`@("`@("1N8B`]("1T
M:&ES+3Y?<&%G93L*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?86QI87-?
M;F)?<&%G97,I*2!["B`@("`@("`@("`@("\J(%)E<&QA8V4@;G5M8F5R(&]F
M('!A9V5S+B`J+PH@("`@("`@("`@("!F;W(@*"1N(#T@,3L@)&X@/#T@)&YB
M.R`D;BLK*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A9V5S6R1N72`]
M('-T<E]R97!L86-E*"1T:&ES+3Y?86QI87-?;F)?<&%G97,L("1N8BP@)'1H
M:7,M/E]P86=E<ULD;ETI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@(&EF("@D=&AI<RT^7V1E9F%U;'1?;W)I96YT871I;VX@/3T@)U`G*2![
M"B`@("`@("`@("`@("1W4'0@/2`D=&AI<RT^9G=0=#L*("`@("`@("`@("`@
M)&A0="`]("1T:&ES+3YF:%!T.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1W4'0@/2`D=&AI<RT^9FA0=#L*("`@("`@("`@("`@)&A0="`]("1T
M:&ES+3YF=U!T.PH@("`@("`@('T*("`@("`@("`D9FEL=&5R(#T@*"1T:&ES
M+3Y?8V]M<')E<W,I(#\@)R]&:6QT97(@+T9L871E1&5C;V1E("<@.B`G)SL*
M("`@("`@("!F;W(@*"1N(#T@,3L@)&X@/#T@)&YB.R`D;BLK*2!["B`@("`@
M("`@("`@("\J(%!A9V4@*B\*("`@("`@("`@("`@)'1H:7,M/E]N97=O8FHH
M*3L*("`@("`@("`@("`@)'1H:7,M/E]O=70H)SP\+U1Y<&4@+U!A9V4G*3L*
M("`@("`@("`@("`@)'1H:7,M/E]O=70H)R]087)E;G0@,2`P(%(G*3L*("`@
M("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?;W)I96YT871I;VY?8VAA;F=E
M<ULD;ETI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U="AS<')I;G1F
M*"<O365D:6%";W@@6S`@,"`E+C)F("4N,F9=)RP@)&A0="P@)'=0="DI.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O4F5S;W5R
M8V5S(#(@,"!2)RD["B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A
M9V5?;&EN:W-;)&Y=*2D@>PH@("`@("`@("`@("`@("`@+RH@3&EN:W,@*B\*
M("`@("`@("`@("`@("`@("1A;FYO=',@/2`G+T%N;F]T<R!;)SL*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<&%G95]L:6YK<ULD;ET@87,@
M)'!L*2!["B`@("`@("`@("`@("`@("`@("`@)')E8W0@/2!S<')I;G1F*"<E
M+C)F("4N,F8@)2XR9B`E+C)F)RP@)'!L6S!=+"`D<&Q;,5TL("1P;%LP72`K
M("1P;%LR72P@)'!L6S%=("T@)'!L6S-=*3L*("`@("`@("`@("`@("`@("`@
M("`D86YN;W1S("X]("<\/"]4>7!E("]!;FYO="`O4W5B='EP92`O3&EN:R`O
M4F5C="!;)R`N("1R96-T("X@)UT@+T)O<F1E<B!;,"`P(#!=("<["B`@("`@
M("`@("`@("`@("`@("`@:68@*&ES7W-T<FEN9R@D<&Q;-%TI*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1A;FYO=',@+CT@)R]!(#P\+U,@+U5222`O
M55))("<@+B`D=&AI<RT^7W1E>'13=')I;F<H)'!L6S1=*2`N("<^/CX^)SL*
M("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D;"`]("1T:&ES+3Y?;&EN:W-;)'!L6S1=73L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&AE:6=H="`](&ES<V5T*"1T:&ES+3Y?;W)I96YT
M871I;VY?8VAA;F=E<ULD;%LP75TI(#\@)'=0="`Z("1H4'0["B`@("`@("`@
M("`@("`@("`@("`@("`@("1A;FYO=',@+CT@<W!R:6YT9B@G+T1E<W0@6R5D
M(#`@4B`O6%E:(#`@)2XR9B!N=6QL73X^)RP@,2`K(#(@*B`D;%LP72P@)&AE
M:6=H="`M("1L6S%=("H@)'1H:7,M/E]S8V%L92D["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'1H
M:7,M/E]O=70H)&%N;F]T<RXG72<I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1T:&ES+3Y?;W5T*"<O0V]N=&5N=',@)R`N("@D=&AI<RT^7VX@*R`Q
M*2`N("<@,"!2/CXG*3L*("`@("`@("`@("`@)'1H:7,M/E]O=70H)V5N9&]B
M:B<I.PH@("`@("`@("`@("`O*B!086=E(&-O;G1E;G0@*B\*("`@("`@("`@
M("`@)'`@/2`H)'1H:7,M/E]C;VUP<F5S<RD@/R!G>F-O;7!R97-S*"1T:&ES
M+3Y?<&%G97-;)&Y=*2`Z("1T:&ES+3Y?<&%G97-;)&Y=.PH@("`@("`@("`@
M("`D=&AI<RT^7VYE=V]B:B@I.PH@("`@("`@("`@("`D=&AI<RT^7V]U="@G
M/#PG("X@)&9I;'1E<B`N("<O3&5N9W1H("<@+B!S=')L96XH)'`I("X@)SX^
M)RD["B`@("`@("`@("`@("1T:&ES+3Y?<'5T4W1R96%M*"1P*3L*("`@("`@
M("`@("`@)'1H:7,M/E]O=70H)V5N9&]B:B<I.PH@("`@("`@('T*("`@("`@
M("`O*B!086=E<R!R;V]T("HO"B`@("`@("`@)'1H:7,M/E]O9F9S971S6S%=
M(#T@<W1R;&5N*"1T:&ES+3Y?8G5F9F5R*3L*("`@("`@("`D=&AI<RT^7V]U
M="@G,2`P(&]B:B<I.PH@("`@("`@("1T:&ES+3Y?;W5T*"<\/"]4>7!E("]0
M86=E<R<I.PH@("`@("`@("1K:61S(#T@)R]+:61S(%LG.PH@("`@("`@(&9O
M<B`H)&D@/2`P.R`D:2`\("1N8CL@)&DK*RD@>PH@("`@("`@("`@("`D:VED
M<R`N/2`H,R`K(#(@*B`D:2D@+B`G(#`@4B`G.PH@("`@("`@('T*("`@("`@
M("`D=&AI<RT^7V]U="@D:VED<R`N("==)RD["B`@("`@("`@)'1H:7,M/E]O
M=70H)R]#;W5N="`G("X@)&YB*3L*("`@("`@("`D=&AI<RT^7V]U="AS<')I
M;G1F*"<O365D:6%";W@@6S`@,"`E+C)F("4N,F9=)RP@)'=0="P@)&A0="DI
M.PH@("`@("`@("1T:&ES+3Y?;W5T*"<^/B<I.PH@("`@("`@("1T:&ES+3Y?
M;W5T*"=E;F1O8FHG*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<'5T1F]N=',H
M*0H@("`@>PH@("`@("`@("1N9B`]("1T:&ES+3Y?;CL*("`@("`@("!F;W)E
M86-H("@D=&AI<RT^7V1I9F9S(&%S("1D:69F*2!["B`@("`@("`@("`@("\J
M($5N8V]D:6YG<R`J+PH@("`@("`@("`@("`D=&AI<RT^7VYE=V]B:B@I.PH@
M("`@("`@("`@("`D=&AI<RT^7V]U="@G/#PO5'EP92`O16YC;V1I;F<@+T)A
M<V5%;F-O9&EN9R`O5VEN06YS:45N8V]D:6YG("]$:69F97)E;F-E<R!;)R`N
M("1D:69F("X@)UT^/B<I.PH@("`@("`@("`@("`D=&AI<RT^7V]U="@G96YD
M;V)J)RD["B`@("`@("`@?0H@("`@("`@("1M<7(@/2!G971?;6%G:6-?<75O
M=&5S7W)U;G1I;64H*3L*("`@("`@("!S971?;6%G:6-?<75O=&5S7W)U;G1I
M;64H,"D["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]F;VYT7V9I;&5S(&%S
M("1F:6QE(#T^("1I;F9O*2!["B`@("`@("`@("`@("\J($9O;G0@9FEL92!E
M;6)E9&1I;F<N("HO"B`@("`@("`@("`@("1T:&ES+3Y?;F5W;V)J*"D["B`@
M("`@("`@("`@("1T:&ES+3Y?9F]N=%]F:6QE<ULD9FEL95U;)VXG72`]("1T
M:&ES+3Y?;CL*("`@("`@("`@("`@)'-I>F4@/2!F:6QE<VEZ92@D9FEL92D[
M"B`@("`@("`@("`@(&EF("@A)'-I>F4I('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G1F]N="!F:6QE(&YO="!F;W5N9"XG
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7V]U="@G/#PO
M3&5N9W1H("<@+B`D<VEZ92D["B`@("`@("`@("`@(&EF("AS=6)S='(H)&9I
M;&4L("TR*2`]/2`G+GHG*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U
M="@G+T9I;'1E<B`O1FQA=&5$96-O9&4G*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D=&AI<RT^7V]U="@G+TQE;F=T:#$@)R`N("1I;F9O6R=L96YG
M=&@Q)UTI.PH@("`@("`@("`@("!I9B`H:7-S970H)&EN9F];)VQE;F=T:#(G
M72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O3&5N9W1H,B`G
M("X@)&EN9F];)VQE;F=T:#(G72`N("<@+TQE;F=T:#,@,"<I.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<^/B<I.PH@("`@("`@
M("`@("`D9B`](&9O<&5N*"1F:6QE+"`G<F(G*3L*("`@("`@("`@("`@)'1H
M:7,M/E]P=713=')E86TH9G)E860H)&8L("1S:7IE*2D["B`@("`@("`@("`@
M(&9C;&]S92@D9BD["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"=E;F1O8FHG
M*3L*("`@("`@("!]"B`@("`@("`@<V5T7VUA9VEC7W%U;W1E<U]R=6YT:6UE
M*"1M<7(I.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?9F]N=',@87,@)&L@
M/3X@)&9O;G0I('L*("`@("`@("`@("`@+RH@1F]N="!O8FIE8W1S("HO"B`@
M("`@("`@("`@("1T:&ES+3Y?;F5W;V)J*"D["B`@("`@("`@("`@("1T:&ES
M+3Y?9F]N='-;)&M=6R=N)UT@/2`D=&AI<RT^7VX["B`@("`@("`@("`@("1N
M86UE(#T@)&9O;G1;)VYA;64G73L*("`@("`@("`@("`@)'1H:7,M/E]O=70H
M)SP\+U1Y<&4@+T9O;G0G*3L*("`@("`@("`@("`@)'1H:7,M/E]O=70H)R]"
M87-E1F]N="`O)R`N("1N86UE*3L*("`@("`@("`@("`@:68@*"1F;VYT6R=T
M>7!E)UT@/3T@)V-O<F4G*2!["B`@("`@("`@("`@("`@("`O*B!3=&%N9&%R
M9"!F;VYT+B`J+PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O=70H)R]3=6)T
M>7!E("]4>7!E,2<I.PH@("`@("`@("`@("`@("`@:68@*"1N86UE("$]("=3
M>6UB;VPG("8F("1N86UE("$]("=:87!F1&EN9V)A=',G*2!["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]O=70H)R]%;F-O9&EN9R`O5VEN06YS:45N
M8V]D:6YG)RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`O*B!!9&1I=&EO;F%L(&9O;G0N("HO"B`@
M("`@("`@("`@("`@("`D=&AI<RT^7V]U="@G+U-U8G1Y<&4@+R<@+B`D9F]N
M=%LG='EP92==*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O1FER
M<W1#:&%R(#,R)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U="@G+TQA
M<W1#:&%R(#(U-2<I.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O=70H)R]7
M:61T:',@)R`N("@D=&AI<RT^7VX@*R`Q*2`N("<@,"!2)RD["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V]U="@G+T9O;G1$97-C<FEP=&]R("<@+B`H)'1H
M:7,M/E]N("L@,BD@+B`G(#`@4B<I.PH@("`@("`@("`@("`@("`@:68@*"1F
M;VYT6R=E;F,G72D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M9F]N=%LG9&EF9B==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7V]U="@G+T5N8V]D:6YG("<@+B`H)&YF("L@)&9O;G1;)V1I9F8G72DN
M)R`P(%(G*3L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7V]U="@G+T5N8V]D:6YG("]7:6Y!
M;G-I16YC;V1I;F<G*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]O
M=70H)SX^)RD["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"=E;F1O8FHG*3L*
M("`@("`@("`@("`@:68@*"1F;VYT6R=T>7!E)UT@(3T@)V-O<F4G*2!["B`@
M("`@("`@("`@("`@("`O*B!7:61T:',N("HO"B`@("`@("`@("`@("`@("`D
M=&AI<RT^7VYE=V]B:B@I.PH@("`@("`@("`@("`@("`@)&-W(#T@)B1F;VYT
M6R=C=R==.PH@("`@("`@("`@("`@("`@)',@/2`G6R<["B`@("`@("`@("`@
M("`@("!F;W(@*"1I(#T@,S([("1I(#P](#(U-3L@)&DK*RD@>PH@("`@("`@
M("`@("`@("`@("`@("1S("X]("1C=UMC:'(H)&DI72`N("<@)SL*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T*"1S("X@
M)UTG*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T*"=E;F1O8FHG*3L*
M("`@("`@("`@("`@("`@("\J($1E<V-R:7!T;W(N("HO"B`@("`@("`@("`@
M("`@("`D=&AI<RT^7VYE=V]B:B@I.PH@("`@("`@("`@("`@("`@)',@/2`G
M/#PO5'EP92`O1F]N=$1E<V-R:7!T;W(@+T9O;G1.86UE("\G("X@)&YA;64[
M"B`@("`@("`@("`@("`@("!F;W)E86-H("@D9F]N=%LG9&5S8R==(&%S("1K
M(#T^("1V*2!["B`@("`@("`@("`@("`@("`@("`@)',@+CT@)R`O)R`N("1K
M("X@)R`G("X@)'8["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D9FEL92`]("1F;VYT6R=F:6QE)UT["B`@("`@("`@("`@("`@("!I9B`H
M)&9I;&4I('L*("`@("`@("`@("`@("`@("`@("`D<R`N/2`G("]&;VYT1FEL
M92<@+B`H)&9O;G1;)W1Y<&4G72`]/2`G5'EP93$G(#\@)R<@.B`G,B<I("X@
M)R`G("X@)'1H:7,M/E]F;VYT7V9I;&5S6R1F:6QE75LG;B==("X@)R`P(%(G
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'1H:7,M/E]O
M=70H)',@+B`G/CXG*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T*"=E
M;F1O8FHG*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("!F
M=6YC=&EO;B!?<'5T26UA9V5S*"D*("`@('L*("`@("`@("`D9FEL=&5R(#T@
M*"1T:&ES+3Y?8V]M<')E<W,I(#\@)R]&:6QT97(@+T9L871E1&5C;V1E("<@
M.B`G)SL*("`@("`@("!F;W)E86-H("@D=&AI<RT^7VEM86=E<R!A<R`D9FEL
M92`]/B`D:6YF;RD@>PH@("`@("`@("`@("`D=&AI<RT^7VYE=V]B:B@I.PH@
M("`@("`@("`@("`D=&AI<RT^7VEM86=E<ULD9FEL95U;)VXG72`]("1T:&ES
M+3Y?;CL*("`@("`@("`@("`@)'1H:7,M/E]O=70H)SP\+U1Y<&4@+UA/8FIE
M8W0G*3L*("`@("`@("`@("`@)'1H:7,M/E]O=70H)R]3=6)T>7!E("]);6%G
M92<I.PH@("`@("`@("`@("`D=&AI<RT^7V]U="@G+U=I9'1H("<@+B`D:6YF
M;ULG=R==*3L*("`@("`@("`@("`@)'1H:7,M/E]O=70H)R](96EG:'0@)R`N
M("1I;F9O6R=H)UTI.PH@("`@("`@("`@("!I9B`H)&EN9F];)V-S)UT@/3T@
M)TEN9&5X960G*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U="@G+T-O
M;&]R4W!A8V4@6R]);F1E>&5D("]$979I8V521T(@)R`N("AS=')L96XH)&EN
M9F];)W!A;"==*2\S("T@,2D@+B`G("<@+B`H)'1H:7,M/E]N("L@,2DN)R`P
M(%)=)RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V]U="@G+T-O;&]R4W!A8V4@+R<@+B`D:6YF;ULG8W,G72D["B`@
M("`@("`@("`@("`@("!I9B`H)&EN9F];)V-S)UT@/3T@)T1E=FEC94--64LG
M*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]O=70H)R]$96-O9&4@
M6S$@,"`Q(#`@,2`P(#$@,%TG*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7V]U="@G+T)I='-097)#;VUP
M;VYE;G0@)R`N("1I;F9O6R=B<&,G72D["B`@("`@("`@("`@("1T:&ES+3Y?
M;W5T*"<O1FEL=&5R("\G("X@)&EN9F];)V8G72D["B`@("`@("`@("`@(&EF
M("AI<W-E="@D:6YF;ULG<&%R;7,G72DI('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?;W5T*"1I;F9O6R=P87)M<R==*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!I9B`H:7-S970H)&EN9F];)W1R;G,G72D@)B8@:7-?87)R87DH
M)&EN9F];)W1R;G,G72DI('L*("`@("`@("`@("`@("`@("1T<FYS(#T@)R<[
M"B`@("`@("`@("`@("`@("`D:5]M87@@/2!C;W5N="@D:6YF;ULG=')N<R==
M*3L*("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1I7VUA>#L@
M)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("1T<FYS("X]("1I;F9O6R=T
M<FYS)UU;)&E=("X@)R`G("X@)&EN9F];)W1R;G,G75LD:5TN)R`G.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'1H:7,M/E]O=70H)R]-
M87-K(%LG("X@)'1R;G,@+B`G72<I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1T:&ES+3Y?;W5T*"<O3&5N9W1H("<@+B!S=')L96XH)&EN9F];)V1A
M=&$G72D@+B`G/CXG*3L*("`@("`@("`@("`@)'1H:7,M/E]P=713=')E86TH
M)&EN9F];)V1A=&$G72D["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"=E;F1O
M8FHG*3L*"B`@("`@("`@("`@("\J(%!A;&5T=&4N("HO"B`@("`@("`@("`@
M(&EF("@D:6YF;ULG8W,G72`]/2`G26YD97AE9"<I('L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?;F5W;V)J*"D["B`@("`@("`@("`@("`@("`D<&%L(#T@
M*"1T:&ES+3Y?8V]M<')E<W,I(#\@9WIC;VUP<F5S<R@D:6YF;ULG<&%L)UTI
M(#H@)&EN9F];)W!A;"==.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O=70H
M)SP\)R`N("1F:6QT97(@+B`G+TQE;F=T:"`G("X@<W1R;&5N*"1P86PI("X@
M)SX^)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!U=%-T<F5A;2@D<&%L
M*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T*"=E;F1O8FHG*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?<'5T
M4F5S;W5R8V5S*"D*("`@('L*("`@("`@("`D=&AI<RT^7W!U=$9O;G1S*"D[
M"B`@("`@("`@)'1H:7,M/E]P=71);6%G97,H*3L*("`@("`@("`O*B!297-O
M=7)C92!D:6-T:6]N87)Y("HO"B`@("`@("`@)'1H:7,M/E]O9F9S971S6S)=
M(#T@<W1R;&5N*"1T:&ES+3Y?8G5F9F5R*3L*("`@("`@("`D=&AI<RT^7V]U
M="@G,B`P(&]B:B<I.PH@("`@("`@("1T:&ES+3Y?;W5T*"<\/"]0<F]C4V5T
M(%LO4$1&("]497AT("]);6%G94(@+TEM86=E0R`O26UA9V5)72<I.PH@("`@
M("`@("1T:&ES+3Y?;W5T*"<O1F]N="`\/"<I.PH@("`@("`@(&9O<F5A8V@@
M*"1T:&ES+3Y?9F]N=',@87,@)&9O;G0I('L*("`@("`@("`@("`@)'1H:7,M
M/E]O=70H)R]&)R`N("1F;VYT6R=I)UT@+B`G("<@+B`D9F]N=%LG;B==("X@
M)R`P(%(G*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]O=70H)SX^)RD[
M"B`@("`@("`@:68@*&-O=6YT*"1T:&ES+3Y?:6UA9V5S*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7V]U="@G+UA/8FIE8W0@/#PG*3L*("`@("`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/E]I;6%G97,@87,@)&EM86=E*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V]U="@G+TDG("X@)&EM86=E6R=I)UT@+B`G("<@
M+B`D:6UA9V5;)VXG72`N("<@,"!2)RD["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)'1H:7,M/E]O=70H)SX^)RD["B`@("`@("`@?0H@("`@("`@("1T
M:&ES+3Y?;W5T*"<^/B<I.PH@("`@("`@("1T:&ES+3Y?;W5T*"=E;F1O8FHG
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<'5T26YF;R@I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]O=70H)R]0<F]D=6-E<B`G("X@)'1H:7,M/E]T97AT4W1R
M:6YG*"=(;W)D92!01$8G*2D["B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^
M7VEN9F];)W1I=&QE)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O
M5&ET;&4@)R`N("1T:&ES+3Y?=&5X=%-T<FEN9R@D=&AI<RT^7VEN9F];)W1I
M=&QE)UTI*3L*("`@("`@("!]"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^
M7VEN9F];)W-U8FIE8W0G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]O=70H
M)R]3=6)J96-T("<@+B`D=&AI<RT^7W1E>'13=')I;F<H)'1H:7,M/E]I;F9O
M6R=S=6)J96-T)UTI*3L*("`@("`@("!]"B`@("`@("`@:68@*"%E;7!T>2@D
M=&AI<RT^7VEN9F];)V%U=&AO<B==*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7V]U="@G+T%U=&AO<B`G("X@)'1H:7,M/E]T97AT4W1R:6YG*"1T:&ES+3Y?
M:6YF;ULG875T:&]R)UTI*3L*("`@("`@("!]"B`@("`@("`@:68@*"%E;7!T
M>2@D=&AI<RT^:V5Y=V]R9',I*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T
M*"<O2V5Y=V]R9',@)R`N("1T:&ES+3Y?=&5X=%-T<FEN9R@D=&AI<RT^:V5Y
M=V]R9',I*3L*("`@("`@("!]"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^
M8W)E871O<BDI('L*("`@("`@("`@("`@)'1H:7,M/E]O=70H)R]#<F5A=&]R
M("<@+B`D=&AI<RT^7W1E>'13=')I;F<H)'1H:7,M/F-R96%T;W(I*3L*("`@
M("`@("!]"B`@("`@("`@)'1H:7,M/E]O=70H)R]#<F5A=&EO;D1A=&4@)R`N
M("1T:&ES+3Y?=&5X=%-T<FEN9R@G1#HG("X@9&%T92@G66UD2&ES)RDI*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!?<'5T0V%T86QO9R@I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]O=70H)R]4>7!E("]#871A;&]G)RD["B`@("`@("`@)'1H
M:7,M/E]O=70H)R]086=E<R`Q(#`@4B<I.PH@("`@("`@(&EF("@D=&AI<RT^
M7WIO;VU?;6]D92`]/2`G9G5L;'!A9V4G*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?;W5T*"<O3W!E;D%C=&EO;B!;,R`P(%(@+T9I=%TG*3L*("`@("`@("!]
M(&5L<V5I9B`H)'1H:7,M/E]Z;V]M7VUO9&4@/3T@)V9U;&QW:61T:"<I('L*
M("`@("`@("`@("`@)'1H:7,M/E]O=70H)R]/<&5N06-T:6]N(%LS(#`@4B`O
M1FET2"!N=6QL72<I.PH@("`@("`@('T@96QS96EF("@D=&AI<RT^7WIO;VU?
M;6]D92`]/2`G<F5A;"<I('L*("`@("`@("`@("`@)'1H:7,M/E]O=70H)R]/
M<&5N06-T:6]N(%LS(#`@4B`O6%E:(&YU;&P@;G5L;"`Q72<I.PH@("`@("`@
M('T@96QS96EF("@A:7-?<W1R:6YG*"1T:&ES+3Y?>F]O;5]M;V1E*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7V]U="@G+T]P96Y!8W1I;VX@6S,@,"!2("]8
M65H@;G5L;"!N=6QL("<@+B`H)'1H:7,M/E]Z;V]M7VUO9&4@+R`Q,#`I+B==
M)RD["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^7VQA>6]U=%]M;V1E
M(#T]("=S:6YG;&4G*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O4&%G
M94QA>6]U="`O4VEN9VQE4&%G92<I.PH@("`@("`@('T@96QS96EF("@D=&AI
M<RT^7VQA>6]U=%]M;V1E(#T]("=C;VYT:6YU;W5S)RD@>PH@("`@("`@("`@
M("`D=&AI<RT^7V]U="@G+U!A9V5,87EO=70@+T]N94-O;'5M;B<I.PH@("`@
M("`@('T@96QS96EF("@D=&AI<RT^7VQA>6]U=%]M;V1E(#T]("=T=V\G*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O4&%G94QA>6]U="`O5'=O0V]L
M=6UN3&5F="<I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?<'5T
M5')A:6QE<B@I"B`@("!["B`@("`@("`@)'1H:7,M/E]O=70H)R]3:7IE("<@
M+B`H)'1H:7,M/E]N("L@,2DI.PH@("`@("`@("1T:&ES+3Y?;W5T*"<O4F]O
M="`G("X@)'1H:7,M/E]N("X@)R`P(%(G*3L*("`@("`@("`D=&AI<RT^7V]U
M="@G+TEN9F\@)R`N("@D=&AI<RT^7VX@+2`Q*2`N("<@,"!2)RD["B`@("!]
M"@H@("`@9G5N8W1I;VX@7V5N9$1O8R@I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]P=71086=E<R@I.PH@("`@("`@("1T:&ES+3Y?<'5T4F5S;W5R8V5S*"D[
M"B`@("`@("`@+RH@26YF;R`J+PH@("`@("`@("1T:&ES+3Y?;F5W;V)J*"D[
M"B`@("`@("`@)'1H:7,M/E]O=70H)SP\)RD["B`@("`@("`@)'1H:7,M/E]P
M=71);F9O*"D["B`@("`@("`@)'1H:7,M/E]O=70H)SX^)RD["B`@("`@("`@
M)'1H:7,M/E]O=70H)V5N9&]B:B<I.PH@("`@("`@("\J($-A=&%L;V<@*B\*
M("`@("`@("`D=&AI<RT^7VYE=V]B:B@I.PH@("`@("`@("1T:&ES+3Y?;W5T
M*"<\/"<I.PH@("`@("`@("1T:&ES+3Y?<'5T0V%T86QO9R@I.PH@("`@("`@
M("1T:&ES+3Y?;W5T*"<^/B<I.PH@("`@("`@("1T:&ES+3Y?;W5T*"=E;F1O
M8FHG*3L*("`@("`@("`O*B!#<F]S<RUR968@*B\*("`@("`@("`D;R`]('-T
M<FQE;B@D=&AI<RT^7V)U9F9E<BD["B`@("`@("`@)'1H:7,M/E]O=70H)WAR
M968G*3L*("`@("`@("`D=&AI<RT^7V]U="@G,"`G("X@*"1T:&ES+3Y?;B`K
M(#$I*3L*("`@("`@("`D=&AI<RT^7V]U="@G,#`P,#`P,#`P,"`V-34S-2!F
M("<I.PH@("`@("`@(&9O<B`H)&D@/2`Q.R`D:2`\/2`D=&AI<RT^7VX[("1I
M*RLI('L*("`@("`@("`@("`@)'1H:7,M/E]O=70H<W!R:6YT9B@G)3`Q,&0@
M,#`P,#`@;B`G+"`D=&AI<RT^7V]F9G-E='-;)&E=*2D["B`@("`@("`@?0H@
M("`@("`@("\J(%1R86EL97(@*B\*("`@("`@("`D=&AI<RT^7V]U="@G=')A
M:6QE<B<I.PH@("`@("`@("1T:&ES+3Y?;W5T*"<\/"<I.PH@("`@("`@("1T
M:&ES+3Y?<'5T5')A:6QE<B@I.PH@("`@("`@("1T:&ES+3Y?;W5T*"<^/B<I
M.PH@("`@("`@("1T:&ES+3Y?;W5T*"=S=&%R='AR968G*3L*("`@("`@("`D
M=&AI<RT^7V]U="@D;RD["B`@("`@("`@)'1H:7,M/E]O=70H)R4E14]&)RD[
M"B`@("`@("`@)'1H:7,M/E]S=&%T92`](#,["B`@("!]"@H@("`@9G5N8W1I
M;VX@7V)E9VEN4&%G92@D;W)I96YT871I;VXI"B`@("!["B`@("`@("`@)'1H
M:7,M/E]P86=E*RL["B`@("`@("`@)'1H:7,M/E]P86=E<ULD=&AI<RT^7W!A
M9V5=(#T@)R<["B`@("`@("`@)'1H:7,M/E]S=&%T92`](#(["B`@("`@("`@
M)'1H:7,M/G@@/2`D=&AI<RT^7VQE9G1?;6%R9VEN.PH@("`@("`@("1T:&ES
M+3YY(#T@)'1H:7,M/E]T;W!?;6%R9VEN.PH@("`@("`@("1T:&ES+3Y?;&%S
M=%]H96EG:'0@/2`P.PH@("`@("`@("\J(%!A9V4@;W)I96YT871I;VX@*B\*
M("`@("`@("!I9B`H(21O<FEE;G1A=&EO;BD@>PH@("`@("`@("`@("`D;W)I
M96YT871I;VX@/2`D=&AI<RT^7V1E9F%U;'1?;W)I96YT871I;VX["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&]R:65N=&%T:6]N(#T@<W1R=&]U
M<'!E<B@D;W)I96YT871I;VY[,'TI.PH@("`@("`@("`@("!I9B`H)&]R:65N
M=&%T:6]N("$]("1T:&ES+3Y?9&5F875L=%]O<FEE;G1A=&EO;BD@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]O<FEE;G1A=&EO;E]C:&%N9V5S6R1T:&ES
M+3Y?<&%G95T@/2!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@(&EF("@D;W)I96YT871I;VX@(3T@)'1H:7,M/E]C=7)R96YT7V]R:65N
M=&%T:6]N*2!["B`@("`@("`@("`@("\J($-H86YG92!O<FEE;G1A=&EO;B`J
M+PH@("`@("`@("`@("!I9B`H)&]R:65N=&%T:6]N(#T]("=0)RD@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/G=0="`]("1T:&ES+3YF=U!T.PH@("`@("`@
M("`@("`@("`@)'1H:7,M/FA0="`]("1T:&ES+3YF:%!T.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/G<@("`]("1T:&ES+3YF=SL*("`@("`@("`@("`@("`@
M("1T:&ES+3YH("`@/2`D=&AI<RT^9F@["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^=U!T(#T@)'1H:7,M/F9H4'0["B`@
M("`@("`@("`@("`@("`D=&AI<RT^:%!T(#T@)'1H:7,M/F9W4'0["B`@("`@
M("`@("`@("`@("`D=&AI<RT^=R`@(#T@)'1H:7,M/F9H.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/F@@("`]("1T:&ES+3YF=SL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D=&AI<RT^7W!A9V5?8G)E86M?=')I9V=E<B`]("1T:&ES
M+3YH("T@)'1H:7,M/E]B<F5A:U]M87)G:6X["B`@("`@("`@("`@("1T:&ES
M+3Y?8W5R<F5N=%]O<FEE;G1A=&EO;B`]("1O<FEE;G1A=&EO;CL*("`@("`@
M("!]"B`@("!]"@H@("`@9G5N8W1I;VX@7V5N9%!A9V4H*0H@("`@>PH@("`@
M("`@("\J($5N9"!O9B!P86=E(&-O;G1E;G1S("HO"B`@("`@("`@)'1H:7,M
M/E]S=&%T92`](#$["B`@("!]"@H@("`@9G5N8W1I;VX@7VYE=V]B:B@I"B`@
M("!["B`@("`@("`@+RH@0F5G:6X@82!N97<@;V)J96-T("HO"B`@("`@("`@
M)'1H:7,M/E]N*RL["B`@("`@("`@)'1H:7,M/E]O9F9S971S6R1T:&ES+3Y?
M;ET@/2!S=')L96XH)'1H:7,M/E]B=69F97(I.PH@("`@("`@("1T:&ES+3Y?
M;W5T*"1T:&ES+3Y?;B`N("<@,"!O8FHG*3L*("`@('T*"B`@("!F=6YC=&EO
M;B!?9&]5;F1E<FQI;F4H)'@L("1Y+"`D=&5X="D*("`@('L*("`@("`@("`O
M*B!3970@=&AE(')E8W1A;F=L92!W:61T:"!A8V-O<F1I;F<@=&\@=&5X="!W
M:61T:"X@*B\*("`@("`@("`D=VED=&@@(#T@)'1H:7,M/F=E=%-T<FEN9U=I
M9'1H*"1T97AT+"!T<G5E*3L*"B`@("`@("`@+RH@4V5T(')E8W1A;F=L92!P
M;W-I=&EO;B!A;F0@:&5I9VAT+"!U<VEN9R!U;F1E<FQI;F4@<&]S:71I;VX@
M86YD"B`@("`@("`@("H@=&AI8VMN97-S('-E='1I;F=S('-C86QE9"!B>2!T
M:&4@9F]N="!S:7IE+B`J+PH@("`@("`@("1Y(#T@)'D@*R`H)'1H:7,M/E]C
M=7)R96YT7V9O;G1;)W5P)UT@*B`D=&AI<RT^7V9O;G1?<VEZ95]P="`O(#$P
M,#`I.PH@("`@("`@("1H96EG:'0@/2`M)'1H:7,M/E]C=7)R96YT7V9O;G1;
M)W5T)UT@*B`D=&AI<RT^7V9O;G1?<VEZ95]P="`O(#$P,#`["@H@("`@("`@
M(')E='5R;B!S<')I;G1F*"<E+C)F("4N,F8@)2XR9B`E+C)F(')E(&8G+"`D
M>"P@)'DL("1W:61T:"P@)&AE:6=H="D["B`@("!]"@H@("`@9G5N8W1I;VX@
M7W!A<G-E2E!'*"1F:6QE*0H@("`@>PH@("`@("`@("\J($5X=')A8W0@:6YF
M;R!F<F]M(&$@2E!%1R!F:6QE+B`J+PH@("`@("`@("1I;6<@/2!`9V5T:6UA
M9V5S:7IE*"1F:6QE*3L*("`@("`@("!I9B`H(21I;6<I('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*'-P<FEN=&8H)TUI<W-I;F<@
M;W(@:6YC;W)R96-T(&EM86=E(&9I;&4Z("5S)RP@)&9I;&4I*3L*("`@("`@
M("!]"B`@("`@("`@:68@*"1I;6=;,ET@(3T@,BD@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H<W!R:6YT9B@G3F]T(&$@2E!%1R!F
M:6QE.B`E<R<L("1F:6QE*2D["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S
M970H)&EM9ULG8VAA;FYE;',G72D@?'P@)&EM9ULG8VAA;FYE;',G72`]/2`S
M*2!["B`@("`@("`@("`@("1C;VQS<&%C92`]("=$979I8V521T(G.PH@("`@
M("`@('T@96QS96EF("@D:6UG6R=C:&%N;F5L<R==(#T](#0I('L*("`@("`@
M("`@("`@)&-O;'-P86-E(#T@)T1E=FEC94--64LG.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1C;VQS<&%C92`]("=$979I8V5'<F%Y)SL*("`@
M("`@("!]"B`@("`@("`@)&)P8R`](&ES<V5T*"1I;6=;)V)I=',G72D@/R`D
M:6UG6R=B:71S)UT@.B`X.PH*("`@("`@("`O*B!296%D('=H;VQE(&9I;&4N
M("HO"B`@("`@("`@)&8@/2!F;W!E;B@D9FEL92P@)W)B)RD["B`@("`@("`@
M)&1A=&$@/2!F<F5A9"@D9BP@9FEL97-I>F4H)&9I;&4I*3L*("`@("`@("!F
M8VQO<V4H)&8I.PH*("`@("`@("!R971U<FX@87)R87DH)W<G(#T^("1I;6=;
M,%TL("=H)R`]/B`D:6UG6S%=+"`G8W,G(#T^("1C;VQS<&%C92P@)V)P8R<@
M/3X@)&)P8RP@)V8G(#T^("=$0U1$96-O9&4G+"`G9&%T82<@/3X@)&1A=&$I
M.PH@("`@?0H*("`@(&9U;F-T:6]N(%]P87)S95!.1R@D9FEL92D*("`@('L*
M("`@("`@("`O*B!%>'1R86-T(&EN9F\@9G)O;2!A(%!.1R!F:6QE+B`J+PH@
M("`@("`@("1F(#T@9F]P96XH)&9I;&4L("=R8B<I.PH@("`@("`@(&EF("@A
M)&8I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*'-P
M<FEN=&8H)U5N86)L92!T;R!O<&5N(&EM86=E(&9I;&4Z("5S)RP@)&9I;&4I
M*3L*("`@("`@("!]"@H@("`@("`@("\J($-H96-K('-I9VYA='5R92X@*B\*
M("`@("`@("!I9B`H9G)E860H)&8L(#@I("$](&-H<B@Q,S<I("X@)U!.1R<@
M+B!C:'(H,3,I("X@8VAR*#$P*2`N(&-H<B@R-BD@+B!C:'(H,3`I*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BAS<')I;G1F*"=.
M;W0@82!03D<@9FEL93H@)7,G+"`D9FEL92DI.PH@("`@("`@('T*"B`@("`@
M("`@+RH@4F5A9"!H96%D97(@8VAU;FLN("HO"B`@("`@("`@9G)E860H)&8L
M(#0I.PH@("`@("`@(&EF("AF<F5A9"@D9BP@-"D@(3T@)TE(1%(G*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BAS<')I;G1F*"=)
M;F-O<G)E8W0@4$Y'(&9I;&4Z("5S)RP@)&9I;&4I*3L*("`@("`@("!]"B`@
M("`@("`@)'=I9'1H(#T@)'1H:7,M/E]F<F5A9$EN="@D9BD["B`@("`@("`@
M)&AE:6=H="`]("1T:&ES+3Y?9G)E861);G0H)&8I.PH@("`@("`@("1B<&,@
M/2!O<F0H9G)E860H)&8L(#$I*3L*("`@("`@("!I9B`H)&)P8R`^(#@I('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*'-P<FEN=&8H
M)S$V+6)I="!D97!T:"!N;W0@<W5P<&]R=&5D.B`E<R<L("1F:6QE*2D["B`@
M("`@("`@?0H@("`@("`@("1C="`](&]R9"AF<F5A9"@D9BP@,2DI.PH@("`@
M("`@(&EF("@D8W0@/3T@,"D@>PH@("`@("`@("`@("`D8V]L<W!A8V4@/2`G
M1&5V:6-E1W)A>2<["B`@("`@("`@?2!E;'-E:68@*"1C="`]/2`R*2!["B`@
M("`@("`@("`@("1C;VQS<&%C92`]("=$979I8V521T(G.PH@("`@("`@('T@
M96QS96EF("@D8W0@/3T@,RD@>PH@("`@("`@("`@("`D8V]L<W!A8V4@/2`G
M26YD97AE9"<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*'-P<FEN=&8H)T%L<&AA(&-H86YN96P@;F]T
M('-U<'!O<G1E9#H@)7,G+"`D9FEL92DI.PH@("`@("`@('T*("`@("`@("!I
M9B`H;W)D*&9R96%D*"1F+"`Q*2D@(3T@,"D@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H<W!R:6YT9B@G56YK;F]W;B!C;VUP<F5S
M<VEO;B!M971H;V0Z("5S)RP@)&9I;&4I*3L*("`@("`@("!]"B`@("`@("`@
M:68@*&]R9"AF<F5A9"@D9BP@,2DI("$](#`I('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*'-P<FEN=&8H)U5N:VYO=VX@9FEL=&5R
M(&UE=&AO9#H@)7,G+"`D9FEL92DI.PH@("`@("`@('T*("`@("`@("!I9B`H
M;W)D*&9R96%D*"1F+"`Q*2D@(3T@,"D@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H<W!R:6YT9B@G26YT97)L86-I;F<@;F]T('-U
M<'!O<G1E9#H@)7,G+"`D9FEL92DI.PH@("`@("`@('T*("`@("`@("!F<F5A
M9"@D9BP@-"D["B`@("`@("`@)'!A<FUS(#T@)R]$96-O9&5087)M<R`\/"]0
M<F5D:6-T;W(@,34@+T-O;&]R<R`G("X@*"1C="`]/2`R(#\@,R`Z(#$I+B<@
M+T)I='-097)#;VUP;VYE;G0@)R`N("1B<&,@+B`G("]#;VQU;6YS("<@+B`D
M=VED=&@N)SX^)SL*("`@("`@("`O*B!38V%N(&-H=6YK<R!L;V]K:6YG(&9O
M<B!P86QE='1E+"!T<F%N<W!A<F5N8WD@86YD(&EM86=E(&1A=&$N("HO"B`@
M("`@("`@)'!A;"`]("<G.PH@("`@("`@("1T<FYS(#T@)R<["B`@("`@("`@
M)&1A=&$@/2`G)SL*("`@("`@("!D;R!["B`@("`@("`@("`@("1N(#T@)'1H
M:7,M/E]F<F5A9$EN="@D9BD["B`@("`@("`@("`@("1T>7!E(#T@9G)E860H
M)&8L(#0I.PH@("`@("`@("`@("!I9B`H)'1Y<&4@/3T@)U!,5$4G*2!["B`@
M("`@("`@("`@("`@("`O*B!296%D('!A;&5T=&4@*B\*("`@("`@("`@("`@
M("`@("1P86P@/2!F<F5A9"@D9BP@)&XI.PH@("`@("`@("`@("`@("`@9G)E
M860H)&8L(#0I.PH@("`@("`@("`@("!](&5L<V5I9B`H)'1Y<&4@/3T@)W12
M3E,G*2!["B`@("`@("`@("`@("`@("`O*B!296%D('1R86YS<&%R96YC>2!I
M;F9O("HO"B`@("`@("`@("`@("`@("`D="`](&9R96%D*"1F+"`D;BD["B`@
M("`@("`@("`@("`@("!I9B`H)&-T(#T](#`I('L*("`@("`@("`@("`@("`@
M("`@("`D=')N<R`](&%R<F%Y*&]R9"AS=6)S='(H)'0L(#$L(#$I*2D["B`@
M("`@("`@("`@("`@("!](&5L<V5I9B`H)&-T(#T](#(I('L*("`@("`@("`@
M("`@("`@("`@("`D=')N<R`](&%R<F%Y*&]R9"AS=6)S='(H)'0L(#$L(#$I
M*2P@;W)D*'-U8G-T<B@D="P@,RP@,2DI+"!O<F0H<W5B<W1R*"1T+"`U+"`Q
M*2DI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`D<&]S(#T@<W1R<&]S*"1T+"!C:'(H,"DI.PH@("`@("`@("`@("`@
M("`@("`@(&EF("AI<U]I;G0H)'!O<RDI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1R;G,@/2!A<G)A>2@D<&]S*3L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!F<F5A9"@D
M9BP@-"D["B`@("`@("`@("`@('T@96QS96EF("@D='EP92`]/2`G241!5"<I
M('L*("`@("`@("`@("`@("`@("\J(%)E860@:6UA9V4@9&%T82!B;&]C:R`J
M+PH@("`@("`@("`@("`@("`@)&1A=&$@+CT@9G)E860H)&8L("1N*3L*("`@
M("`@("`@("`@("`@(&9R96%D*"1F+"`T*3L*("`@("`@("`@("`@?2!E;'-E
M:68@*"1T>7!E(#T]("=)14Y$)RD@>PH@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!F<F5A9"@D
M9BP@)&X@*R`T*3L*("`@("`@("`@("`@?0H@("`@("`@('T@=VAI;&4@*"1N
M*3L*"B`@("`@("`@:68@*"1C;VQS<&%C92`]/2`G26YD97AE9"<@)B8@96UP
M='DH)'!A;"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*'-P<FEN=&8H)TUI<W-I;F<@<&%L971T92!I;CH@)7,G+"`D9FEL92DI
M.PH@("`@("`@('T*("`@("`@("!F8VQO<V4H)&8I.PH*("`@("`@("!R971U
M<FX@87)R87DH)W<G(#T^("1W:61T:"P@)V@G(#T^("1H96EG:'0L("=C<R<@
M/3X@)&-O;'-P86-E+"`G8G!C)R`]/B`D8G!C+"`G9B<@/3X@)T9L871E1&5C
M;V1E)RP@)W!A<FUS)R`]/B`D<&%R;7,L("=P86PG(#T^("1P86PL("=T<FYS
M)R`]/B`D=')N<RP@)V1A=&$G(#T^("1D871A*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!?9G)E861);G0H)&8I"B`@("!["B`@("`@("`@+RH@4F5A9"!A(#0M
M8GET92!I;G1E9V5R(&9R;VT@9FEL92X@*B\*("`@("`@("`D:2`@/2!O<F0H
M9G)E860H)&8L(#$I*2`\/"`R-#L*("`@("`@("`D:2`K/2!O<F0H9G)E860H
M)&8L(#$I*2`\/"`Q-CL*("`@("`@("`D:2`K/2!O<F0H9G)E860H)&8L(#$I
M*2`\/"`X.PH@("`@("`@("1I("L](&]R9"AF<F5A9"@D9BP@,2DI.PH@("`@
M("`@(')E='5R;B`D:3L*("`@('T*"B`@("!F=6YC=&EO;B!?=&5X=%-T<FEN
M9R@D<RD*("`@('L*("`@("`@("`O*B!&;W)M870@82!T97AT('-T<FEN9R`J
M+PH@("`@("`@(')E='5R;B`G*"<@+B`D=&AI<RT^7V5S8V%P92@D<RD@+B`G
M*2<["B`@("!]"@H@("`@9G5N8W1I;VX@7V5S8V%P92@D<RD*("`@('L*("`@
M("`@("`O*B!!9&0@7"!B969O<F4@7"P@*"!A;F0@*2`J+PH@("`@("`@(')E
M='5R;B!S=')?<F5P;&%C92AA<G)A>2@G*2<L)R@G+"=<7"<I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@G7%PI)RPG7%PH)RPG7%Q<7"<I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`D<RD["B`@("!]"@H@("`@
M9G5N8W1I;VX@7W!U=%-T<F5A;2@D<RD*("`@('L*("`@("`@("`D=&AI<RT^
M7V]U="@G<W1R96%M)RD["B`@("`@("`@)'1H:7,M/E]O=70H)',I.PH@("`@
M("`@("1T:&ES+3Y?;W5T*"=E;F1S=')E86TG*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!?;W5T*"1S*0H@("`@>PH@("`@("`@("\J($%D9"!A(&QI;F4@=&\@
M=&AE(&1O8W5M96YT+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7W-T871E(#T]
M(#(I('L*("`@("`@("`@("`@)'1H:7,M/E]P86=E<ULD=&AI<RT^7W!A9V5=
M("X]("1S("X@(EQN(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M=&AI<RT^7V)U9F9E<B`N/2`D<R`N(")<;B(["B`@("`@("`@?0H@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O1FEL92]#4U8N<&AP````````````
M````````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-#`S-#8@,3`U
M,34T,S,W,S0@,#(P,S0P`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*
M<F5Q=6ER95]O;F-E("=&:6QE+G!H<"<["@HO*BH*("H@5&AE($9I;&5?0U-6
M('!A8VMA9V4@86QL;W=S(')E861I;F<@86YD(&-R96%T:6YG(&]F($-35B!D
M871A(&%N9"!F:6QE<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<"QV(#$N-"XR+C<@,C`P-B\P,R\S,"`Q,#HQ-3HR.2!S96QS
M:WD@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P,R!4;VUA<R!6;VX@
M5F5S8VAL97(@0V]X(#QC;WA`:61E8VYE="YC;VT^"B`J($-O<'ER:6=H="`R
M,#`U+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@
M5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP(&]F
M('1H92!02%`@;&EC96YS92P@=&AA="!I<PH@*B!B=6YD;&5D('=I=&@@=&AI
M<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R!A=F%I;&%B
M;&4@870@=&AR;W5G:`H@*B!T:&4@=V]R;&0M=VED92UW96(@870@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("!)9B!Y;W4@9&ED(&YO
M=`H@*B!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R
M92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE"B`J('=O<FQD+7=I
M9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T
M('-O('=E(&-A;B!M86EL('EO=2!A"B`J(&-O<'D@:6UM961I871E;'DN"B`J
M"B`J($!A=71H;W(@(%1O;6%S(%9O;B!697-C:&QE<B!#;W@@/&-O>$!I9&5C
M;F5T+F-O;3X*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E
M+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXQ"B`J($!P86-K86=E($9I;&5?
M0U-6"B`J+PIC;&%S<R!&:6QE7T-35B!["@H@("`@+RHJ"B`@("`@*B!$:7-C
M;W9E<G,@=&AE(&9O<FUA="!O9B!A($-35B!F:6QE("AT:&4@;G5M8F5R(&]F
M(&9I96QD<RP@=&AE('-E<&%R871O<BP*("`@("`J('1H92!Q=6]T92!S=')I
M;F<L(&%N9"!T:&4@;&EN92!B<F5A:RDN"B`@("`@*@H@("`@("H@5V4@8V%N
M)W0@=7-E('1H92!A=71O7V1E=&5C=%]L:6YE7V5N9&EN9W,@4$A0('-E='1I
M;F<L(&)E8V%U<V4@:70G<R!N;W0*("`@("`J('-U<'!O<G1E9"!B>2!F9V5T
M<R@I(&-O;G1R87)Y('1O('=H870@=&AE(&UA;G5A;"!S87ES+@H@("`@("H*
M("`@("`J($!S=&%T:6,*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("!4
M:&4@0U-6(&9I;&4@;F%M90H@("`@("H@0'!A<F%M(&%R<F%Y("`@17AT<F$@
M<V5P87)A=&]R<R!T:&%T('-H;W5L9"!B92!C:&5C:V5D(&9O<BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@9F]R;6%T(&AA<V@N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&1I<V-O=F5R1F]R;6%T*"1F:6QE+"`D97AT<F%3
M97!S(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H(21F<"`]($!F;W!E
M;B@D9FEL92P@)W(G*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@G0V]U;&0@;F]T(&]P96X@9FEL93H@)R`N("1F:6QE*3L*("`@
M("`@("!]"@H@("`@("`@("1S97!S(#T@87)R87DH(EQT(BP@)SLG+"`G.B<L
M("<L)RD["B`@("`@("`@)'-E<',@/2!A<G)A>5]M97)G92@D<V5P<RP@)&5X
M=')A4V5P<RD["B`@("`@("`@)&UA=&-H97,@/2!A<G)A>2@I.PH@("`@("`@
M("1C<FQF(#T@;G5L;#L*("`@("`@("`D8V]N9B`](&%R<F%Y*"D["@H@("`@
M("`@("\J(%1A:V4@=&AE(&9I<G-T(#$P(&QI;F5S(&%N9"!S=&]R92!T:&4@
M;G5M8F5R(&]F(&]C=7)R96YC97,@9F]R(&5A8V@*("`@("`@("`@*B!S97!A
M<F%T;W(@:6X@96%C:"!L:6YE+B`J+PH@("`@("`@(&9O<B`H)&D@/2`P.R`H
M)&D@/"`Q,"D@)B8@*"1L:6YE(#T@9F=E=',H)&9P*2D[*2!["B`@("`@("`@
M("`@("\J($1O('=E(&AA=F4@36%C(&QI;F4@96YD:6YG<S\@*B\*("`@("`@
M("`@("`@)&QI;F5S(#T@<')E9U]S<&QI="@G+UQR*#\A7&XI+R<L("1L:6YE
M+"`Q,"D["B`@("`@("`@("`@("1J(#T@,#L*("`@("`@("`@("`@)&,@/2!C
M;W5N="@D;&EN97,I.PH@("`@("`@("`@("!I9B`H)&,@/B`Q*2!["B`@("`@
M("`@("`@("`@("`D8W)L9B`](")<<B(["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@=VAI;&4@*"1I(#P@,3`@)B8@)&H@/"`D8RD@>PH@("`@("`@("`@
M("`@("`@)&QI;F4@/2`D;&EN97-;)&I=.PH@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D8W)L9BDI('L*("`@("`@("`@("`@("`@("`@("!F;W)E86-H
M("AA<G)A>2@B7')<;B(L(")<;B(I(&%S("1C*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("AS=6)S='(H)&QI;F4L("US=')L96XH)&,I*2`]/2`D
M8RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-R;&8@/2`D8SL*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&DK*SL*("`@("`@("`@("`@
M("`@("1J*RL["B`@("`@("`@("`@("`@("!F;W)E86-H("@D<V5P<R!A<R`D
M<V5P*2!["B`@("`@("`@("`@("`@("`@("`@)&UA=&-H97-;)'-E<%U;)&E=
M(#T@<W5B<W1R7V-O=6YT*"1L:6YE+"`D<V5P*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H:7-S970H
M)&-R;&8I*2!["B`@("`@("`@("`@("1C;VYF6R=C<FQF)UT@/2`D8W)L9CL*
M("`@("`@("!]"@H@("`@("`@("\J($=R;W5P('1H92!R97-U;'1S(&)Y(&%M
M;W5N="!O9B!E<75A;"!O8W5R<F5N8V5S+B`J+PH@("`@("`@("1F:65L9',@
M/2!A<G)A>2@I.PH@("`@("`@("1A;6]U;G0@/2!A<G)A>2@I.PH@("`@("`@
M(&9O<F5A8V@@*"1M871C:&5S(&%S("1S97`@/3X@)&QI;F5S*2!["B`@("`@
M("`@("`@("1T:6UE<R`](&%R<F%Y*"D["B`@("`@("`@("`@("1T:6UE<ULP
M72`](#`["B`@("`@("`@("`@(&9O<F5A8V@@*"1L:6YE<R!A<R`D;G5M*2![
M"B`@("`@("`@("`@("`@("!I9B`H)&YU;2`^(#`I('L*("`@("`@("`@("`@
M("`@("`@("`D=&EM97-;)&YU;5T@/2`H:7-S970H)'1I;65S6R1N=6U=*2D@
M/R`D=&EM97-;)&YU;5T@*R`Q(#H@,3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!A<G-O<G0H)'1I;65S*3L*("`@("`@
M("`@("`@)&9I96QD<ULD<V5P72`](&ME>2@D=&EM97,I.PH@("`@("`@("`@
M("`D86UO=6YT6R1S97!=(#T@)'1I;65S6VME>2@D=&EM97,I73L*("`@("`@
M("!]"B`@("`@("`@87)S;W)T*"1A;6]U;G0I.PH@("`@("`@("1S97`@/2!K
M97DH)&%M;W5N="D["@H@("`@("`@("1C;VYF6R=F:65L9',G72`]("1F:65L
M9'-;)'-E<%T@*R`Q.PH@("`@("`@("1C;VYF6R=S97`G72`@("`]("1S97`[
M"@H@("`@("`@("\J(%1E<W0@:68@=&AE<F4@87)E(&9I96QD<R!W:71H('%U
M;W1E<R!A<G)O=6YD(&EN('1H92!F:7)S="`U"B`@("`@("`@("H@;&EN97,N
M("HO"B`@("`@("`@)'%U;W1E<R`]("<B7"<G.PH@("`@("`@("1Q=6]T92`@
M/2`G)SL*("`@("`@("!R97=I;F0H)&9P*3L*("`@("`@("!F;W(@*"1I(#T@
M,#L@*"1I(#P@-2D@)B8@*"1L:6YE(#T@9F=E=',H)&9P*2D[("1I*RLI('L*
M("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H(GPD<V5P*%LD<75O=&5S72DN
M*BA;)'%U;W1E<UTI)'-E<'Q5(BP@)&QI;F4L("1M871C:"DI('L*("`@("`@
M("`@("`@("`@(&EF("@D;6%T8VA;,5T@/3T@)&UA=&-H6S)=*2!["B`@("`@
M("`@("`@("`@("`@("`@)'%U;W1E(#T@)&UA=&-H6S%=.PH@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*")\7BA;)'%U;W1E<UTI
M+BHH6R1Q=6]T97-=*21S97!\(BP@)&QI;F4L("1M871C:"D@?'P*("`@("`@
M("`@("`@("`@('!R96=?;6%T8V@H(GPH6R1Q=6]T97-=*2XJ*%LD<75O=&5S
M72DD<V5P7',D?%5S(BP@)&QI;F4L("1M871C:"DI"B`@("`@("`@("`@('L*
M("`@("`@("`@("`@("`@(&EF("@D;6%T8VA;,5T@/3T@)&UA=&-H6S)=*2![
M"B`@("`@("`@("`@("`@("`@("`@)'%U;W1E(#T@)&UA=&-H6S%=.PH@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1C;VYF6R=Q=6]T92==(#T@
M)'%U;W1E.PH*("`@("`@("!F8VQO<V4H)&9P*3L*"B`@("`@("`@+R\@6%A8
M(%=H870@86)O=70@=')Y:6YG('1O(&1I<V-O=F5R('1H92`B:&5A9&5R(C\*
M("`@("`@("!R971U<FX@)&-O;F8["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M96%D<R!A(')O=R!F<F]M(&$@0U-6(&9I;&4@86YD(')E='5R;G,@:70@87,@
M86X@87)R87DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL92`@
M5&AE(&YA;64@;V8@=&AE($-35B!F:6QE+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1C;VYF("`@5&AE(&-O;F9I9W5R871I;VX@9F]R('1H92!#4U8@9FEL92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y?&)O;VQE86X@(%1H92!#4U8@
M9&%T82!O<B!F86QS92!I9B!N;R!M;W)E(&1A=&$@879A:6QA8FQE+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!R96%D*"1F:6QE+"`F)&-O;F8I"B`@("!["B`@
M("`@("`@)&9P(#T@1FEL95]#4U8Z.F=E=%!O:6YT97(H)&9I;&4L("1C;VYF
M+"!&24Q%7TU/1$5?4D5!1"D["B`@("`@("`@:68@*&ES7V$H)&9P+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D9G`["B`@("`@("`@
M?0H*("`@("`@("`D;&EN92`](&9G971S*"1F<"D["B`@("`@("`@:68@*"$D
M;&EN92D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*
M("`@("`@("`O*B!5<V4@<F5A9%%U;W1E9"@I(&EF('=E(&AA=F4@36%C(&QI
M;F4@96YD:6YG<RX@*B\*("`@("`@("!I9B`H<')E9U]M871C:"@G+UQR*#\A
M7&XI+R<L("1L:6YE*2D@>PH@("`@("`@("`@("!F<V5E:R@D9G`L("US=')L
M96XH)&QI;F4I+"!3145+7T-54BD["B`@("`@("`@("`@(')E='5R;B!&:6QE
M7T-35CHZ<F5A9%%U;W1E9"@D9FEL92P@)&-O;F8I.PH@("`@("`@('T*"B`@
M("`@("`@1FEL95]#4U8Z.E]L:6YE*$9I;&5?0U-6.CI?;&EN92@I("L@,2D[
M"@H@("`@("`@(&EF("@D8V]N9ELG9FEE;&1S)UT@/3T@,2D@>PH@("`@("`@
M("`@("!R971U<FX@87)R87DH)&QI;F4I.PH@("`@("`@('T*"B`@("`@("`@
M)&9I96QD<R`](&5X<&QO9&4H)&-O;F9;)W-E<"==+"`D;&EN92D["B`@("`@
M("`@:68@*"1C;VYF6R=Q=6]T92==*2!["B`@("`@("`@("`@("1L87-T(#T@
M)B1F:65L9'-;8V]U;G0H)&9I96QD<RD@+2`Q73L*("`@("`@("`@("`@+RH@
M1F%L;&)A8VL@=&\@<F5A9"!T:&4@;&EN92!W:71H(')E8611=6]T960H*2!W
M:&5N(&=U97-S('1H870@=&AE"B`@("`@("`@("`@("`J('-I;7!L92!E>'!L
M;V1E('=O;B=T('=O<FL@<FEG:'0N("HO"B`@("`@("`@("`@(&EF("@H<W5B
M<W1R*"1L87-T+"`M<W1R;&5N*"1C;VYF6R=C<FQF)UTI*2`]/2`D8V]N9ELG
M8W)L9B==("8F"B`@("`@("`@("`@("`@("`@)&QA<W1[,'T@/3T@)&-O;F9;
M)W%U;W1E)UT@)B8*("`@("`@("`@("`@("`@("`D;&%S='MS=')L96XH<G1R
M:6TH)&QA<W0I*2`M(#%]("$]("1C;VYF6R=Q=6]T92==*2!\?`H@("`@("`@
M("`@("`@("`@*&-O=6YT*"1F:65L9',I("$]("1C;VYF6R=F:65L9',G72D*
M("`@("`@("`@("`@("`@("`@("`O+R!86%@@<&5R:&%P<R!T:&5R92!I<R!A
M('-E<&%R871O<B!I;G-I9&4@82!Q=6]T960@9FEE;&0*("`@("`@("`@("`@
M("`@("`@("`O+W!R96=?;6%T8V@H(GQ[)&-O;F9;)W%U;W1E)UU]+BI[)&-O
M;F9;)W-E<"==?2XJ>R1C;VYF6R=Q=6]T92==?7Q5(BP@)&QI;F4I"B`@("`@
M("`@("`@("`@("`I"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@(&9S
M965K*"1F<"P@+7-T<FQE;B@D;&EN92DL(%-%14M?0U52*3L*("`@("`@("`@
M("`@("`@(')E='5R;B!&:6QE7T-35CHZ<F5A9%%U;W1E9"@D9FEL92P@)&-O
M;F8I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&QA
M<W0@/2!R=')I;2@D;&%S="D["B`@("`@("`@("`@("`@("!F;W)E86-H("@D
M9FEE;&1S(&%S("1K(#T^("1V*2!["B`@("`@("`@("`@("`@("`@("`@)&9I
M96QD<ULD:UT@/2!&:6QE7T-35CHZ=6YQ=6]T92@D=BP@)&-O;F9;)W%U;W1E
M)UTL("1C;VYF6R=C<FQF)UTI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&9I96QD<UMC
M;W5N="@D9FEE;&1S*2`M,5T@/2!R=')I;2@D9FEE;&1S6V-O=6YT*"1F:65L
M9',I("TQ72D["B`@("`@("`@?0H*("`@("`@("!I9B`H8V]U;G0H)&9I96QD
M<RD@/"`D8V]N9ELG9FEE;&1S)UTI('L*("`@("`@("`@("`@1FEL95]#4U8Z
M.G=A<FYI;F<H<W!R:6YT9BA?*")7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN
M(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB*2P@1FEL95]#4U8Z
M.E]L:6YE*"DL("1C;VYF6R=F:65L9',G72P@8V]U;G0H)&9I96QD<RDI*3L*
M("`@("`@("`@("`@)&9I96QD<R`](&%R<F%Y7VUE<F=E*"1F:65L9',L(&%R
M<F%Y7V9I;&PH,"P@)&-O;F9;)V9I96QD<R==("T@8V]U;G0H)&9I96QD<RDL
M("<G*2D["B`@("`@("`@?2!E;'-E:68@*&-O=6YT*"1F:65L9',I(#X@)&-O
M;F9;)V9I96QD<R==*2!["B`@("`@("`@("`@($9I;&5?0U-6.CIW87)N:6YG
M*'-P<FEN=&8H7R@B36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N
M('1H92!E>'!E8W1E9"`E9"XB*2P@1FEL95]#4U8Z.E]L:6YE*"DL("1C;VYF
M6R=F:65L9',G72DI.PH@("`@("`@("`@("!A<G)A>5]S<&QI8V4H)&9I96QD
M<RP@)&-O;F9;)V9I96QD<R==*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D9FEE;&1S.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5A9',@82!R;W<@
M9G)O;2!A($-35B!F:6QE(&%N9"!R971U<FYS(&ET(&%S(&%N(&%R<F%Y+@H@
M("`@("H@5&AI<R!M971H;V0@:7,@86)L92!T;R!R96%D(&9I96QD<R!W:71H
M(&UU;'1I;&EN92!D871A(&%N9"!N;W)M86QI>F5S"B`@("`@*B!L:6YE8G)E
M86MS('1O('-I;F=L92!N97=L:6YE(&-H87)A8W1E<G,@*#!X,&$I+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&4@(%1H92!N86UE(&]F('1H
M92!#4U8@9FEL92X*("`@("`J($!P87)A;2!A<G)A>2`D8V]N9B`@(%1H92!C
M;VYF:6=U<F%T:6]N(&9O<B!T:&4@0U-6(&9I;&4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>7QB;V]L96%N("!4:&4@0U-6(&1A=&$@;W(@9F%L<V4@
M:68@;F\@;6]R92!D871A(&%V86EL86)L92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F5A9%%U;W1E9"@D9FEL92P@)B1C;VYF*0H@("`@>PH@("`@("`@("1F
M<"`]($9I;&5?0U-6.CIG9710;VEN=&5R*"1F:6QE+"`D8V]N9BP@1DE,15]-
M3T1%7U)%040I.PH@("`@("`@(&EF("AI<U]A*"1F<"P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&9P.PH@("`@("`@('T*"B`@("`@
M("`@+RH@02!B=69F97(@=VET:"!A;&P@8VAA<F%C=&5R<R!O9B!T:&4@8W5R
M<F5N="!F:65L9"!R96%D('-O(&9A<BX@*B\*("`@("`@("`D8G5F9B`]("<G
M.PH@("`@("`@("\J(%1H92!C=7)R96YT(&-H87)A8W1E<BX@*B\*("`@("`@
M("`D8R`](&YU;&P["B`@("`@("`@+RH@5&AE(')E860@9FEE;&1S+B`J+PH@
M("`@("`@("1R970@/2!A<G)A>2@I.PH@("`@("`@("\J(%1H92!N=6UB97(@
M;V8@=&AE(&-U<G)E;G0@9FEE;&0N("HO"B`@("`@("`@)&D@/2`Q.PH@("`@
M("`@("\J($%R92!W92!I;G-I9&4@82!Q=6]T960@9FEE;&0_("HO"B`@("`@
M("`@)&EN7W%U;W1E(#T@9F%L<V4["@H@("`@("`@('=H:6QE("@H)&-H(#T@
M9F=E=&,H)&9P*2D@(3T](&9A;'-E*2!["B`@("`@("`@("`@("\J(%!R979I
M;W5S(&-H87)A8W1E<BX@*B\*("`@("`@("`@("`@)'!R978@/2`D8SL*("`@
M("`@("`@("`@+RH@0W5R<F5N="!C:&%R86-T97(N("HO"B`@("`@("`@("`@
M("1C(#T@)&-H.PH*("`@("`@("`@("`@+RH@4VEM<&QE(&-H87)A8W1E<BX@
M*B\*("`@("`@("`@("`@:68@*"1C("$]("1C;VYF6R=Q=6]T92==("8F"B`@
M("`@("`@("`@("`@("`D8R`A/2`D8V]N9ELG<V5P)UT@)B8*("`@("`@("`@
M("`@("`@('-T<G!O<R@D8V]N9ELG8W)L9B==+"`D8RD@/3T](&9A;'-E*2![
M"B`@("`@("`@("`@("`@("`D8G5F9B`N/2`D8SL*("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)&-O
M;F9;)W%U;W1E)UT@)B8@)&,@/3T@)&-O;F9;)W%U;W1E)UT@)B8*("`@("`@
M("`@("`@("`@("@D<')E=B`]/2`D8V]N9ELG<V5P)UT@?'P*("`@("`@("`@
M("`@("`@("`D<')E=B`]/2!S=6)S='(H)&-O;F9;)V-R;&8G72P@+3$I('Q\
M"B`@("`@("`@("`@("`@("`@)'!R978@/3T](&YU;&PI*0H@("`@("`@("`@
M("!["B`@("`@("`@("`@("`@("`O*B!1=6]T92!B96=I;BX@*B\*("`@("`@
M("`@("`@("`@("1I;E]Q=6]T92`]('1R=64["B`@("`@("`@("`@('T@96QS
M96EF("@D:6Y?<75O=&4I('L*("`@("`@("`@("`@("`@("\J(%%U;W1E(&5N
M9#\@*B\*("`@("`@("`@("`@("`@(&EF("@D8R`]/2`D8V]N9ELG<V5P)UT@
M)B8@)'!R978@/3T@)&-O;F9;)W%U;W1E)UTI('L*("`@("`@("`@("`@("`@
M("`@("`D:6Y?<75O=&4@/2!F86QS93L*("`@("`@("`@("`@("`@('T@96QS
M96EF("@D8R`]/2!S=6)S='(H)&-O;F9;)V-R;&8G72P@+3$I*2!["B`@("`@
M("`@("`@("`@("`@("`@)'-U8B`]("AS=')L96XH)&-O;F9;)V-R;&8G72D@
M/B`Q("8F"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<')E=B`]/2!S
M=6)S='(H)&-O;F9;)V-R;&8G72P@+3(L(#$I*0H@("`@("`@("`@("`@("`@
M("`@("`@("`_(#(*("`@("`@("`@("`@("`@("`@("`@("`@.B`Q.PH@("`@
M("`@("`@("`@("`@("`@(&EF("@H<W1R;&5N*"1B=69F*2`^/2`D<W5B*2`F
M)@H@("`@("`@("`@("`@("`@("`@("`@("`H)&)U9F9[<W1R;&5N*"1B=69F
M*2`M("1S=6)](#T]("1C;VYF6R=Q=6]T92==*2D*("`@("`@("`@("`@("`@
M("`@("!["B`@("`@("`@("`@("`@("`@("`@("`@("1I;E]Q=6]T92`](&9A
M;'-E.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@($9I;&5?0U-6.CI?;&EN92A&:6QE7T-35CHZ7VQI;F4H
M*2`K(#$I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@16YD(&]F(&QI;F4@
M;W(@96YD(&]F(&9I96QD+B`J+PH@("`@("`@("`@("!I9B`H(21I;E]Q=6]T
M92`F)@H@("`@("`@("`@("`@("`@*"1C(#T]("1C;VYF6R=S97`G72!\?"`D
M8R`]/2!S=6)S='(H)&-O;F9;)V-R;&8G72P@+3$I*2D@>PH@("`@("`@("`@
M("`@("`@+RH@36]R92!F:65L9',@=&AA;B!E>'!E8W1E9"X@*B\*("`@("`@
M("`@("`@("`@(&EF("@D8R`]/2`D8V]N9ELG<V5P)UT@)B8*("`@("`@("`@
M("`@("`@("`@("`H8V]U;G0H)')E="D@*R`Q*2`]/2`D8V]N9ELG9FEE;&1S
M)UTI('L*("`@("`@("`@("`@("`@("`@("!W:&EL92`H)&,@(3T](&9A;'-E
M("8F("1C("$]('-U8G-T<B@D8V]N9ELG8W)L9B==+"`M,2DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&,@/2!F9V5T8R@D9G`I.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!&:6QE7T-35CHZ=V%R
M;FEN9RAS<')I;G1F*%\H(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@
M=&AA;B!T:&4@97AP96-T960@)60N(BDL($9I;&5?0U-6.CI?;&EN92@I+"`D
M8V]N9ELG9FEE;&1S)UTI*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("`@("!I9B`H)'!R978@/3T@<W5B<W1R*"1C;VYF6R=C<FQF)UTL("TR
M+"`Q*2D@>PH@("`@("`@("`@("`@("`@("`@("1B=69F(#T@<W5B<W1R*"1B
M=69F+"`P+"`M,2D["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@
M("`@+RH@3&5S<R!F:65L9',@=&AA;B!E>'!E8W1E9"X@*B\*("`@("`@("`@
M("`@("`@(&EF("@H)&,@/3T@<W5B<W1R*"1C;VYF6R=C<FQF)UTL("TQ*2D@
M)B8*("`@("`@("`@("`@("`@("`@("`H)&D@(3T@)&-O;F9;)V9I96QD<R==
M*2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D:2`]/2`Q*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("\J(%-K:7`@96UP='D@;&EN97,N("HO"B`@
M("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5T.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!&:6QE7T-35CHZ=V%R
M;FEN9RAS<')I;G1F*%\H(E=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN
M92`E9"X@17AP96-T960@)60L(&9O=6YD("5D+B(I+"!&:6QE7T-35CHZ7VQI
M;F4H*2P@)&-O;F9;)V9I96QD<R==+"`D:2DI.PH*("`@("`@("`@("`@("`@
M("`@("`D<F5T6UT@/2!&:6QE7T-35CHZ=6YQ=6]T92@D8G5F9BP@)&-O;F9;
M)W%U;W1E)UTL("1C;VYF6R=C<FQF)UTI.PH@("`@("`@("`@("`@("`@("`@
M("1R970@/2!A<G)A>5]M97)G92@D<F5T+"!A<G)A>5]F:6QL*#`L("1C;VYF
M6R=F:65L9',G72`M("1I+"`G)RDI.PH@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D<F5T.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@
M("1R971;72`]($9I;&5?0U-6.CIU;G%U;W1E*"1B=69F+"`D8V]N9ELG<75O
M=&4G72P@)&-O;F9;)V-R;&8G72D["B`@("`@("`@("`@("`@("!I9B`H8V]U
M;G0H)')E="D@/3T@)&-O;F9;)V9I96QD<R==*2!["B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1R970["B`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@)&)U9F8@/2`G)SL*("`@("`@("`@("`@("`@("1I*RL["B`@
M("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D8G5F9B`N/2`D8SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F
M96]F*"1F<"D@/R!F86QS92`Z("1R970["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!7<FET97,@82!H87-H(&EN=&\@82!#4U8@9FEL92X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1F:6QE("`@5&AE(&YA;64@;V8@=&AE($-35B!F
M:6QE+@H@("`@("H@0'!A<F%M(&%R<F%Y("1F:65L9',@(%1H92!#4U8@9&%T
M82X*("`@("`J($!P87)A;2!A<G)A>2`D8V]N9B`@("!4:&4@8V]N9FEG=7)A
M=&EO;B!F;W(@=&AE($-35B!F:6QE+@H@("`@("H*("`@("`J($!R971U<FX@
M8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!014%27T5R<F]R(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('=R:71E*"1F:6QE+"`D9FEE;&1S
M+"`F)&-O;F8I"B`@("!["B`@("`@("`@:68@*&ES7V$H)&9P(#T@1FEL95]#
M4U8Z.F=E=%!O:6YT97(H)&9I;&4L("1C;VYF+"!&24Q%7TU/1$5?5U))5$4I
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D9G`["B`@
M("`@("`@?0H*("`@("`@("!I9B`H8V]U;G0H)&9I96QD<RD@(3T@)&-O;F9;
M)V9I96QD<R==*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*'-P<FEN=&8H7R@B5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T
M960@)60L(&9O=6YD("5D+B(I+"`D8V]N9ELG9FEE;&1S)UTL(&-O=6YT*"1F
M:65L9',I*2D["B`@("`@("`@?0H*("`@("`@("`D=W)I=&4@/2`G)SL*("`@
M("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D9FEE;&1S*3L@)&DK*RD@
M>PH@("`@("`@("`@("!I9B`H(6ES7VYU;65R:6,H)&9I96QD<ULD:5TI("8F
M("1C;VYF6R=Q=6]T92==*2!["B`@("`@("`@("`@("`@("`D=W)I=&4@+CT@
M)&-O;F9;)W%U;W1E)UT@+B`D9FEE;&1S6R1I72`N("1C;VYF6R=Q=6]T92==
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'=R:71E
M("X]("1F:65L9'-;)&E=.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("@D:2`\("AC;W5N="@D9FEE;&1S*2`M(#$I*2!["B`@("`@("`@("`@("`@
M("`D=W)I=&4@+CT@)&-O;F9;)W-E<"==.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)'=R:71E("X]("1C;VYF6R=C<FQF)UT["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@A9G=R:71E*"1F
M<"P@)'=R:71E*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BAS<')I;G1F*%\H(D-A;FYO="!W<FET92!T;R!F:6QE(%PB)7-<(B(I
M+"`D9FEL92DI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S('-U<G)O=6YD:6YG('%U;W1E
M<R!F<F]M(&$@<W1R:6YG(&%N9"!N;W)M86QI>F5S(&QI;F5B<F5A:W,N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEE;&0@(%1H92!S=')I;F<@
M=&\@=6YQ=6]T92X*("`@("`J($!P87)A;2!S=')I;F<@)'%U;W1E("!4:&4@
M<75O=&4@8VAA<F%C=&5R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8W)L9B`@
M(%1H92!L:6YE8G)E86L@8VAA<F%C=&5R+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@=6YQ=6]T960@9&%T82X*("`@("`J+PH@("`@9G5N
M8W1I;VX@=6YQ=6]T92@D9FEE;&0L("1Q=6]T92P@)&-R;&8I"B`@("!["B`@
M("`@("`@+RH@4VMI<"!E;7!T>2!F:65L9',@*&9O<FTZ(#L[*2`J+PH@("`@
M("`@(&EF("@A<W1R;&5N*"1F:65L9"DI('L*("`@("`@("`@("`@<F5T=7)N
M("1F:65L9#L*("`@("`@("!]"B`@("`@("`@:68@*"1Q=6]T92`F)B`D9FEE
M;&1[,'T@/3T@)'%U;W1E("8F("1F:65L9'MS=')L96XH)&9I96QD*2TQ?2`]
M/2`D<75O=&4I('L*("`@("`@("`@("`@<F5T=7)N('-T<E]R97!L86-E*"1C
M<FQF+"`B7&XB+"!S=6)S='(H)&9I96QD+"`Q+"`M,2DI.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@)&9I96QD.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4V5T<R!O<B!G971S('1H92!C=7)R96YT(&QI;F4@8F5I;F<@<&%R<V5D+@H@
M("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1L:6YE("!)9B!S<&5C:69I
M960L('1H92!C=7)R96YT(&QI;F4N"B`@("`@*@H@("`@("H@0')E='5R;B!I
M;G1E9V5R("!4:&4@8W5R<F5N="!L:6YE+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?;&EN92@D;&EN92`](&YU;&PI"B`@("!["B`@("`@("`@<W1A=&EC("1C
M=7)R96YT7VQI;F4@/2`P.PH*("`@("`@("!I9B`H(6ES7VYU;&PH)&QI;F4I
M*2!["B`@("`@("`@("`@("1C=7)R96YT7VQI;F4@/2`D;&EN93L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D8W5R<F5N=%]L:6YE.PH@("`@?0H*("`@
M("\J*@H@("`@("H@061D<R!A('=A<FYI;F<@=&\@;W(@<F5T<FEE=F5S(&%N
M9"!R97-E=',@=&AE('=A<FYI;F<@<W1A8VLN"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`@02!W87)N:6YG('-T<FEN9RX@($EF(&YO="!S<&5C:69I
M960L('1H92!E>&ES=&EN9PH@("`@("H@("`@("`@("`@("`@("`@=V%R;FEN
M9W,@=VEL;"!B92!R971U<FYE9"!I;G-T96%D(&%N9"!T:&4@=V%R;FEN9R!S
M=&%C:PH@("`@("H@("`@("`@("`@("`@("`@9V5T<R!E;7!T:65D+@H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@($EF(&YO('!A<F%M971E<B!H87,@
M8F5E;B!S<&5C:69I960L('1H92!L:7-T(&]F(&5X:7-T:6YG"B`@("`@*B`@
M("`@("`@("`@("`@("!W87)N:6YG<RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M=V%R;FEN9R@D=V%R;FEN9R`](&YU;&PI"B`@("!["B`@("`@("`@<W1A=&EC
M("1W87)N:6YG<R`](&%R<F%Y*"D["@H@("`@("`@(&EF("AI<U]N=6QL*"1W
M87)N:6YG*2D@>PH@("`@("`@("`@("`D<F5T=7)N(#T@)'=A<FYI;F=S.PH@
M("`@("`@("`@("`D=V%R;FEN9W,@/2!A<G)A>2@I.PH@("`@("`@("`@("!R
M971U<FX@)')E='5R;CL*("`@("`@("!]"@H@("`@("`@("1W87)N:6YG<UM=
M(#T@)'=A<FYI;F<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&]R
M(&-R96%T97,@=&AE(&9I;&4@9&5S8W)I<'1O<B!A<W-O8VEA=&5D('=I=&@@
M82!F:6QE+@H@("`@("H*("`@("`J($!S=&%T:6,*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1F:6QE("!4:&4@;F%M92!O9B!T:&4@9FEL90H@("`@
M("H@0'!A<F%M(&%R<F%Y("1C;VYF("`@5&AE(&-O;F9I9W5R871I;VX*("`@
M("`J($!P87)A;2!S=')I;F<@)&UO9&4@(%1H92!O<&5N(&UO9&4N($9)3$5?
M34]$15]214%$(&]R($9)3$5?34]$15]74DE412X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(')E<V]U<F-E("!4:&4@9FEL92!R97-O=7)C92!O<B!014%27T5R
M<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9710;VEN=&5R
M*"1F:6QE+"`F)&-O;F8L("1M;V1E(#T@1DE,15]-3T1%7U)%040I"B`@("![
M"B`@("`@("`@<W1A=&EC("1R97-O=7)C97,@/2!A<G)A>2@I.PH@("`@("`@
M('-T871I8R`D8V]N9FEG(#T@87)R87DH*3L*"B`@("`@("`@)'-I9VYA='5R
M92`]("1F:6QE("X@<V5R:6%L:7IE*"1C;VYF*3L*("`@("`@("!I9B`H:7-S
M970H)')E<V]U<F-E<ULD<VEG;F%T=7)E72DI('L*("`@("`@("`@("`@)&-O
M;F8@/2`D8V]N9FEG6R1S:6=N871U<F5=.PH@("`@("`@("`@("!R971U<FX@
M)')E<V]U<F-E<ULD<VEG;F%T=7)E73L*("`@("`@("!]"B`@("`@("`@:68@
M*&ES7V$H)&5R<F]R(#T@1FEL95]#4U8Z.E]C:&5C:T-O;F9I9R@D8V]N9BDL
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*
M("`@("`@("!]"B`@("`@("`@)&-O;F9I9ULD<VEG;F%T=7)E72`]("1C;VYF
M.PH*("`@("`@("`D9G`@/2!`9F]P96XH)&9I;&4L("1M;V1E*3L*("`@("`@
M("!I9B`H(6ES7W)E<V]U<F-E*"1F<"DI('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")#86XG="!O<&5N(&9I;&4@
M7"(E<UPB+B(I+"`D9FEL92DI.PH@("`@("`@('T*("`@("`@("`D<F5S;W5R
M8V5S6R1S:6=N871U<F5=(#T@)&9P.PH@("`@("`@($9I;&5?0U-6.CI?;&EN
M92@P*3L*"B`@("`@("`@:68@*"1M;V1E(#T]($9)3$5?34]$15]214%$("8F
M("%E;7!T>2@D8V]N9ELG:&5A9&5R)UTI*2!["B`@("`@("`@("`@(&EF("AI
M<U]A*"1H96%D97(@/2!&:6QE7T-35CHZ<F5A9"@D9FEL92P@)&-O;F8I+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&AE861E
M<CL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1F
M<#L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!T:&4@8V]N9FEG=7)A
M=&EO;B!G:79E;B!B>2!T:&4@=7-E<BX*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@)&-O;F8@("`@5&AE(&-O;F9I9W5R871I;VX@87-S;V,@87)R87D*
M("`@("`J($!P87)A;2!S=')I;F<@)&5R<F]R("!4:&4@97)R;W(@=VEL;"!B
M92!W<FET=&5N(&AE<F4@:68@86YY"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C
M:&5C:T-O;F9I9R@F)&-O;F8I"B`@("!["B`@("`@("`@+R\@8VAE8VL@8V]N
M9@H@("`@("`@(&EF("@A:7-?87)R87DH)&-O;F8I*2!["B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*"=);G9A;&ED(&-O;F9I9W5R871I
M;VXN)RD["B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES<V5T*"1C;VYF6R=F
M:65L9',G72D@?'P@(6ES7VYU;65R:6,H)&-O;F9;)V9I96QD<R==*2D@>PH@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")4:&4@;G5M
M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N(BDI.PH@("`@("`@('T*
M"B`@("`@("`@:68@*&ES<V5T*"1C;VYF6R=S97`G72DI('L*("`@("`@("`@
M("`@:68@*'-T<FQE;B@D8V]N9ELG<V5P)UTI("$](#$I('L*("`@("`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E1H92!S97!A<F%T
M;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB*2D["B`@("`@("`@
M("`@('T*("`@("`@("!](&5L<V5I9B`H)&-O;F9;)V9I96QD<R==(#X@,2D@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;R!S
M97!A<F%T;W(@<W!E8VEF:65D+B(I*3L*("`@("`@("!]"@H@("`@("`@(&EF
M("@A96UP='DH)&-O;F9;)W%U;W1E)UTI*2!["B`@("`@("`@("`@(&EF("AS
M=')L96XH)&-O;F9;)W%U;W1E)UTI("$](#$I('L*("`@("`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E1H92!Q=6]T92!C:&%R86-T
M97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB*2D["B`@("`@("`@
M("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D8V]N9ELG<75O
M=&4G72`]("<G.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I<W-E="@D8V]N
M9ELG8W)L9B==*2D@>PH@("`@("`@("`@("`D8V]N9ELG8W)L9B==(#T@(EQN
M(CL*("`@("`@("!]"B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B]497AT````````````````````````````````
M```````````````````````````````````````````````````````````P
M,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<S
M-2`P,3<Q-30`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U1E>'0O<F535```
M````````````````````````````````````````````````````````````
M`````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P,#`P(#$P-3$U-#,S-S,U(#`R,#`S,0`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O5&5X="]R95-4+T9O<FUA='1E<@``````````````````````````
M````````````````````````````````````````````,#`P-S4U(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S0@,#(Q-S<S`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]497AT+W)E4U0O1F]R;6%T=&5R+VAT
M;6PN<&AP````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-C$P,2`Q,#4Q
M-30S,S<S-"`P,C,U,C4`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*"G)E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,
M15]?*2`N("<O+BXO1F]R;6%T=&5R+G!H<"<["@HO*BH*("H@5&AE(%1E>'1?
M<F535%]&;W)M871T97)?:'1M;#HZ(&-L87-S(&ES('1H92!(5$U,(&9O<FUA
M='1E<BX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]R95-4+W)E4U0O
M1F]R;6%T=&5R+VAT;6PN<&AP+'8@,2XV+C$R+C4@,C`P-B\P,2\P,2`R,3HR
M.#HS.2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!*87-O
M;B!-+B!&96QI8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("H*("H@0&%U=&AO<B`@2F%S;VX@32X@1F5L:6-E(#QJ9F5L:6-E0&-R
M;VYO<WES+F-O;3X*("H@0'!A8VMA9V4@5&5X=%]R95-4"B`J+PIC;&%S<R!4
M97AT7W)E4U1?1F]R;6%T=&5R7VAT;6P@97AT96YD<R!497AT7W)E4U1?1F]R
M;6%T=&5R('L*"B`@("`O*BH*("`@("`J(%1H92!C=7)R96YT(&]U='!U="!C
M:&%R<V5T+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@
M('9A<B`D7V-H87)S970@/2!N=6QL.PH*("`@(&9U;F-T:6]N(&9O<FUA="@F
M)&YO9&4L("1C:&%R<V5T(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES
M<V5T*"1C:&%R<V5T*2D@>PH@("`@("`@("`@("`D8VAA<G-E="`]("1T:&ES
M+3Y?8VAA<G-E=#L*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]S=')I;F<H
M)&YO9&4I*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D8VAA<G-E="DI('L*
M("`@("`@("`@("`@("`@(')E='5R;B!`:'1M;'-P96-I86QC:&%R<R@D;F]D
M92P@14Y47U%53U1%4RP@)&-H87)S970I.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(&AT;6QS<&5C:6%L8VAA<G,H)&YO
M9&4L($5.5%]154]415,I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!S=VET8V@@*"1N;V1E+3Y?='EP92D@>PH@("`@("`@(&-A<V4@)T1O
M8W5M96YT)SH*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?8VAI;&1R96XH
M)&YO9&4I.PH*("`@("`@("!C87-E("=(96%D:6YG)SH*("`@("`@("`@("`@
M)&QE=F5L(#T@)&YO9&4M/F=E=%!R;W!E<G1Y*"=L979E;"<I.PH@("`@("`@
M("`@("!R971U<FX@)SQH)R`N("1L979E;"`N("<^)R`N("1T:&ES+3Y?8VAI
M;&1R96XH)&YO9&4I("X@)SPO:"<@+@H@("`@("`@("`@("`@("`@)&QE=F5L
M("X@)SXG.PH*("`@("`@("!C87-E("=,:6YK)SH*("`@("`@("`@("`@<F5T
M=7)N("<\82!H<F5F/2(G("X*("`@("`@("`@("`@("`@("AI<W-E="@D8VAA
M<G-E="D@/PH@("`@("`@("`@("`@("`@($!H=&UL<W!E8VEA;&-H87)S*"1N
M;V1E+3YG9710<F]P97)T>2@G:')E9B<I+"!%3E1?455/5$53+"`D8VAA<G-E
M="D@.@H@("`@("`@("`@("`@("`@(&AT;6QS<&5C:6%L8VAA<G,H)&YO9&4M
M/F=E=%!R;W!E<G1Y*"=H<F5F)RDL($5.5%]154]415,I*2`N"B`@("`@("`@
M("`@("`@("`G(CXG("X*("`@("`@("`@("`@("`@("1T:&ES+3Y?8VAI;&1R
M96XH)&YO9&4I("X@)SPO83XG.PH*("`@("`@("!C87-E("=,:71E<F%L+4)L
M;V-K)SH*("`@("`@("`@("`@;&ES="@D=&5X="D@/2`D;F]D92T^7V-H:6QD
M<F5N.PH@("`@("`@("`@("!R971U<FX@)SQP<F4^)R`N("AI<W-E="@D8VAA
M<G-E="D@/PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!`:'1M;'-P
M96-I86QC:&%R<R@D=&5X="P@14Y47U%53U1%4RP@)&-H87)S970I(#H*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:'1M;'-P96-I86QC:&%R<R@D
M=&5X="P@14Y47U%53U1%4RDI("X@)SPO<')E/B<["@H@("`@("`@(&-A<V4@
M)U!A<F%G<F%P:"<Z"B`@("`@("`@("`@(')E='5R;B`B/'`^(B`N("1T:&ES
M+3Y?8VAI;&1R96XH)&YO9&4I("X@(CPO<#XB.PH*("`@("`@("!C87-E("=)
M;G1E<G!R971E9"U497AT)SH*("`@("`@("`@("`@<W=I=&-H("@D;F]D92T^
M9V5T4')O<&5R='DH)W)O;&4G*2D@>PH@("`@("`@("`@("!C87-E("=E;7!H
M87-I<R<Z"B`@("`@("`@("`@("`@("!R971U<FX@)SQE;3XG("X@)'1H:7,M
M/E]C:&EL9')E;B@D;F]D92D@+B`G/"]E;3XG.PH*("`@("`@("`@("`@8V%S
M92`G;&ET97)A;"<Z"B`@("`@("`@("`@("`@("!R971U<FX@)SQT=#XG("X@
M)'1H:7,M/E]C:&EL9')E;B@D;F]D92D@+B`G/"]T=#XG.PH*("`@("`@("`@
M("`@8V%S92`G<W1R;VYG)SH*("`@("`@("`@("`@("`@(')E='5R;B`G/'-T
M<F]N9SXG("X@)'1H:7,M/E]C:&EL9')E;B@D;F]D92D@+B`G/"]S=')O;F<^
M)SL*"B`@("`@("`@("`@(&-A<V4@)W-U<&5R<V-R:7!T)SH*("`@("`@("`@
M("`@("`@(')E='5R;B`G/'-U<#XG("X@)'1H:7,M/E]C:&EL9')E;B@D;F]D
M92D@+B`G/"]S=7`^)SL*"B`@("`@("`@("`@(&-A<V4@)W-U8G-C<FEP="<Z
M"B`@("`@("`@("`@("`@("!R971U<FX@)SQS=6(^)R`N("1T:&ES+3Y?8VAI
M;&1R96XH)&YO9&4I("X@)SPO<W5B/B<["@H@("`@("`@("`@("!C87-E("=T
M:71L92UR969E<F5N8V4G.@H@("`@("`@("`@("`@("`@<F5T=7)N("<\8VET
M93XG("X@)'1H:7,M/E]C:&EL9')E;B@D;F]D92D@+B`G/"]C:71E/B<["@H@
M("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@+R\@6%A8.B!)
M<W-U92!A('=A<FYI;F<N"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]C:&EL9')E;B@D;F]D92D["B`@("`@("`@("`@('T*"B`@("`@("`@8V%S
M92`G4V5C=&EO;B<Z"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V-H:6QD
M<F5N*"1N;V1E*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@7V-H
M:6QD<F5N*"8D;F]D92D*("`@('L*("`@("`@("`D<F5S=6QT(#T@)R<["B`@
M("`@("`@9F]R96%C:"`H)&YO9&4M/E]C:&EL9')E;B!A<R`D8VAI;&0I('L*
M("`@("`@("`@("`@)')E<W5L="`N/2`D=&AI<RT^9F]R;6%T*"1C:&EL9"D[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O5&5X="]R95-4+U!A<G-E<BYP:'``
M````````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-C$W-#`@,3`U
M,34T,S,W,S0@,#(R,#8T`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B!4:&4@5&5X=%]R95-47U!A<G-E
M<CHZ(&-L87-S(&EM<&QE;65N=',@82!P87)S97(@9F]R(')E4W1R=6-T=7)E
M9%1E>'0*("H@9&]C=6UE;G1S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]4
M97AT7W)E4U0O<F535"]087)S97(N<&AP+'8@,2XX+C(N."`R,#`V+S`Q+S`Q
M(#(Q.C(X.C,Y(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V
M($IA<V]N($TN($9E;&EC92`\:F9E;&EC94!C<F]N;W-Y<RYC;VT^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9"!N;W0*("H@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!*87-O;B!-+B!&96QI8V4@/&IF96QI
M8V5`8W)O;F]S>7,N8V]M/@H@*B!`<&%C:V%G92!497AT7W)E4U0*("HO"F-L
M87-S(%1E>'1?<F535%]087)S97(@>PH*("`@("\J*@H@("`@("H@5&AE('!A
M<G-E('1R964N"B`@("`@*@H@("`@("H@0'9A<B!497AT7W)E4U0*("`@("`J
M+PH@("`@=F%R("1?9&]C=6UE;G0["@H@("`@+RHJ"B`@("`@*B!!(&AA<V@@
M;V8@861O<FYM96YT(&QE=F5L<RX*("`@("`J"B`@("`@*B!4:&4@:V5Y<R!A
M<F4@;VYE+6-H87)A8W1E<B!O<B!T=V\M8VAA<F%C=&5R('-T<FEN9W,N("!4
M:&4@;VYE+6-H87)A8W1E<@H@("`@("H@<W1R:6YG<R!R97!R97-E;G0@=6YD
M97)L:6YE(&%D;W)N;65N=',@;V8@=&AE('-P96-I9FEE9"!C:&%R86-T97(L
M(&%N9`H@("`@("H@=&AE(&1O=6)L92UC:&%R86-T97(@:V5Y<R!A<F4@=&AE
M('5N9&5R;&EN92UA;F0M;W9E<FQI;F4@<W1Y;&5S+B`@5&AE"B`@("`@*B!V
M86QU97,@87-S;V-I871E9"!W:71H('1H92!K97ES(&%R92!I;G1E9V5R<R!R
M97!R97-E;G1I;F<@=&AE"B`@("`@*B!A9&]R;FUE;G0G<R!H96%D:6YG(&QE
M=F5L+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R
M("1?861O<FYM96YT3&5V96QS(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J
M($-O;G-T<G5C=&]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!497AT7W)E4U1?
M4&%R<V5R*"D*("`@('L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M82!P87)S92!T<F5E(')E<')E<V5N=&EN9R!A(&1O8W5M96YT+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H:7,@:7,@=&AE('1E>'0@
M;V8@=&AE(&1O8W5M96YT('1O('!A<G-E+@H@("`@("H*("`@("`J($!R971U
M<FX@5&5X=%]R95-4("!4:&4@<&%R<V4@=')E92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@)G!A<G-E*"1T97AT*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=&5X
M="`]("1T97AT.PH*("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)
M3$5?7RD@+B`G+RXN+W)E4U0N<&AP)SL*"B`@("`@("`@)'1H:7,M/E]D;V-U
M;65N="`]("9N97<@5&5X=%]R95-4*"=$;V-U;65N="<I.PH@("`@("`@("1T
M:&ES+3Y?<'5S:%-T871E*"1T:&ES+3Y?9&]C=6UE;G0L("=396-T:6]N)RP@
M,"D["@H@("`@("`@('=H:6QE("@D=&AI<RT^7VYE>'0H*2D@>PH*("`@("`@
M("`@("`@+R\*("`@("`@("`@("`@+R\@4&%R<V4@82!@+BXG(&1I<F5C=&EV
M92X@(%=E(')E=W)I=&4@86X@8%]?)R!D:7)E8W1I=F4@=&\@80H@("`@("`@
M("`@("`O+R!@+BX@7U\Z("<@9&ER96-T:79E(&AE<F4N"B`@("`@("`@("`@
M("\O"B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7BA<+EPN?%]?*5QS
M*R@N*C\I7',J)"\G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7VQI;F5"=69F97);,%TL("1M*2D@>PH@("`@("`@("`@("`@("`@:68@
M*"1M6S%=(#T]("=?7R<I('L*("`@("`@("`@("`@("`@("`@("`D=&5X="`]
M("=?7SH@)R`N("1M6S)=.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`D=&5X="`]("1M6S)=.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@=VAI;&4@*"1T:&ES+3Y?96YS=7)E3&EN
M97,H,BD@)B8*("`@("`@("`@("`@("`@("`@("`@("!P<F5G7VUA=&-H*"<O
M7B`@*%M>7'-=+BH_*5QS*B0O)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?;&EN94)U9F9E<ELQ72P@)&TI*2!["B`@("`@
M("`@("`@("`@("`@("`@)'1E>'0@+CT@)R`G+B1M6S%=.PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?;F5X="@I.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@)'1H:7,M/E]P87)S941I<F5C=&EV92@D=&5X="D[
M"B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@+R\*("`@("`@("`@("`@+R\@3&]O:R!F;W(@;W9E<FQI;F4M
M86YD+75N9&5R;&EN92!H96%D:6YG<RX*("`@("`@("`@("`@+R\*("`@("`@
M("`@("`@:68@*"1T:&ES+3Y?96YS=7)E3&EN97,H,RD@)B8*("`@("`@("`@
M("`@("`@('!R96=?;6%T8V@H)R]>*"XK/RE<<RHD+R<L("1T:&ES+3Y?;&EN
M94)U9F9E<ELQ72P@)&QI;F5-871C:"D@)B8*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?8VAE8VM!9&]R;FUE;G0H87)R87DH,"P@,BDL('-T<FQE;B@D;&EN
M94UA=&-H6S%=*2DI('L*"B`@("`@("`@("`@("`@("`D861O<FYM96YT5'EP
M92`]("1T:&ES+3Y?;&EN94)U9F9E<ELP77LP?3L*("`@("`@("`@("`@("`@
M("1A9&]R;FUE;G14>7!E("X]("1A9&]R;FUE;G14>7!E.PH*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?;F5X="@I.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]N97AT*"D["@H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M861O<FYM96YT3&5V96QS6R1A9&]R;FUE;G14>7!E72DI('L*("`@("`@("`@
M("`@("`@("`@("`D;F5W3&5V96P@/2`D=&AI<RT^7V%D;W)N;65N=$QE=F5L
M<ULD861O<FYM96YT5'EP95T["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]P;W!4;TQE=F5L*"=396-T:6]N)RP@)&YE=TQE=F5L("T@,2D["B`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1N97=,
M979E;"`]("1T:&ES+3Y?9V5T4W1A=&5,979E;"@G4V5C=&EO;B<I("L@,3L*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%D;W)N;65N=$QE=F5L<ULD
M861O<FYM96YT5'EP95T@/2`D;F5W3&5V96P["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`D;F]D92`]("8D=&AI<RT^7VUA:V5.;V1E*"1T
M:&ES+3Y?8W5R<F5N=$YO9&4L("=396-T:6]N)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)VQE=F5L)R`]/B`D
M;F5W3&5V96PI*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<'5S:%-T871E
M*"1N;V1E+"`G4V5C=&EO;B<L("1N97=,979E;"D["B`@("`@("`@("`@("`@
M("!P<F5G7VUA=&-H*"<O7EQS*B@N*C\I7',J)"\G+"`D;&EN94UA=&-H6S%=
M+"`D;&EN94UA=&-H*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;6%K94YO
M9&4H)'1H:7,M/E]C=7)R96YT3F]D92P@)TAE861I;F<G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G;&5V96PG(#T^("1N97=,
M979E;"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1L:6YE
M36%T8VA;,5TI.PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("\O"B`@("`@("`@("`@("\O($QO;VL@9F]R
M('5N9&5R;&EN92!H96%D:6YG<RX*("`@("`@("`@("`@+R\*("`@("`@("`@
M("`@:68@*"1T:&ES+3Y?96YS=7)E3&EN97,H,BD@)B8*("`@("`@("`@("`@
M("`@('!R96=?;6%T8V@H)R]>*%M>7'-=+BH_*5QS*B0O)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]L:6YE0G5F9F5R6S!=+"`D;&EN
M94UA=&-H*2`F)@H@("`@("`@("`@("`@("`@)'1H:7,M/E]C:&5C:T%D;W)N
M;65N="AA<G)A>2@Q*2P@<W1R;&5N*"1L:6YE36%T8VA;,5TI*2D@>PH*("`@
M("`@("`@("`@("`@("1A9&]R;FUE;G14>7!E(#T@)'1H:7,M/E]L:6YE0G5F
M9F5R6S%=>S!].PH@("`@("`@("`@("`@("`@)'1H:7,M/E]N97AT*"D["B`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]A9&]R;FUE;G1,979E
M;'-;)&%D;W)N;65N=%1Y<&5=*2D@>PH@("`@("`@("`@("`@("`@("`@("1N
M97=,979E;"`]("1T:&ES+3Y?861O<FYM96YT3&5V96QS6R1A9&]R;FUE;G14
M>7!E73L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!O<%1O3&5V96PH
M)U-E8W1I;VXG+"`D;F5W3&5V96P@+2`Q*3L*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@)&YE=TQE=F5L(#T@)'1H:7,M
M/E]G9713=&%T94QE=F5L*"=396-T:6]N)RD@*R`Q.PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?861O<FYM96YT3&5V96QS6R1A9&]R;FUE;G14>7!E
M72`]("1N97=,979E;#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("1N;V1E(#T@)B1T:&ES+3Y?;6%K94YO9&4H)'1H:7,M/E]C=7)R96YT
M3F]D92P@)U-E8W1I;VXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!A<G)A>2@G;&5V96PG(#T^("1N97=,979E;"DI.PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]P=7-H4W1A=&4H)&YO9&4L("=396-T
M:6]N)RP@)&YE=TQE=F5L*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;6%K
M94YO9&4H)'1H:7,M/E]C=7)R96YT3F]D92P@)TAE861I;F<G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G;&5V96PG(#T^("1N
M97=,979E;"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1L
M:6YE36%T8VA;,5TI.PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("\O"B`@("`@("`@("`@("\O(%!A<G-E
M(&$@8#HZ)R!P87)A9W)A<&@N"B`@("`@("`@("`@("\O"B`@("`@("`@("`@
M(&EF("AP<F5G7VUA=&-H*"<O7EQS*CHZ7',J)"\G+"`D=&AI<RT^7VQI;F5"
M=69F97);,%TI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VYE>'0H*3L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R<V5,:71E<F%L0FQO8VLH*3L*
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`O+PH@("`@("`@("`@("`O+R!087)S92!A('!A<F%G<F%P:"X@
M(%=E(&5N9"!T:&4@<&%R86=R87!H('=H96X@=V4@<F5T=7)N('1O"B`@("`@
M("`@("`@("\O(&$@;&]W97(@:6YD96YT871I;VX@;&5V96P@;W(@96YC;W5N
M=&5R(&$@8FQA;FL@;&EN92X*("`@("`@("`@("`@+R\*("`@("`@("`@("`@
M:68@*'!R96=?;6%T8V@H)R]>*%QS*BDH6UY<<UTN*C\I7',J)"\G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VQI;F5"=69F97);,%TL
M("1M*2D@>PH@("`@("`@("`@("`@("`@)'1E>'0@/2`D;5LR73L*("`@("`@
M("`@("`@("`@("1L979E;"`]('-T<FQE;B@D;5LQ72D["B`@("`@("`@("`@
M("`@("!W:&EL92`H)'1H:7,M/E]E;G-U<F5,:6YE<R@R*2`F)@H@("`@("`@
M("`@("`@("`@("`@("`@('!R96=?;6%T8V@H)R]>*%QS*BDH6UY<<UTN*C\I
M7',J)"\G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]L:6YE0G5F9F5R6S%=+"`D;2DI('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H<W1R;&5N*"1M6S%=*2`\("1L979E;"D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@)'1E>'0@+CT@)R`G("X@)&U;,ET["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]N97AT*"D["B`@("`@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`@("`@)'1R86EL:6YG3&ET97)A;"`](&9A;'-E.PH@
M("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>*"XJ6UY<<UTZ*3I<
M<RHD+R<L("1T97AT+"`D;2DI('L*("`@("`@("`@("`@("`@("`@("`D=&5X
M="`]("1M6S%=.PH@("`@("`@("`@("`@("`@("`@("1T<F%I;&EN9TQI=&5R
M86P@/2!T<G5E.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T
M8V@H)R]>*"XJ/RE<<RHZ.EQS*B0O)RP@)'1E>'0L("1M*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1T97AT(#T@)&U;,5T["B`@("`@("`@("`@("`@("`@
M("`@)'1R86EL:6YG3&ET97)A;"`]('1R=64["B`@("`@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`@("`@)'1H:7,M/E]M86ME3F]D92@D=&AI<RT^7V-U
M<G)E;G1.;V1E+"`G4&%R86=R87!H)RP@87)R87DH*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1E>'0I.PH*("`@("`@("`@("`@("`@
M(&EF("@D=')A:6QI;F=,:71E<F%L*2!["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]N97AT*"D["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)S94QI=&5R86Q";&]C:R@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("\O(%A86#H@2&%N9&QE(&=A<F)A9V4@;&EN92X*"B`@("`@("`@?3L*"B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?9&]C=6UE;G0["B`@("!]"@H@("`@9G5N
M8W1I;VX@)E]M86ME3F]D92@F)'!A<F5N="P@)'1Y<&4L("1P<F]P<R`](&%R
M<F%Y*"DL("1C:&EL9%1E>'0@/2!N=6QL*0H@("`@>PH@("`@("`@("1N;V1E
M(#T@)FYE=R!497AT7W)E4U0H)'1Y<&4I.PH@("`@("`@(&9O<F5A8V@@*"1P
M<F]P<R!A<R`D;F%M92`]/B`D=F%L=64I('L*("`@("`@("`@("`@)&YO9&4M
M/G-E=%!R;W!E<G1Y*"1N86UE+"`D=F%L=64I.PH@("`@("`@('T*("`@("`@
M("!I9B`H(6ES7VYU;&PH)'!A<F5N="DI('L*("`@("`@("`@("`@)'!A<F5N
M="T^87!P96YD0VAI;&0H)&YO9&4I.PH@("`@("`@('T*("`@("`@("!I9B`H
M(6ES7VYU;&PH)&-H:6QD5&5X="DI('L*("`@("`@("`@("`@)'1H:7,M/E]P
M87)S94EN;&EN92@D;F]D92P@)&-H:6QD5&5X="D["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D;F]D93L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K
M<R!M=6QT:7!L92!A9&]R;F5M;G0@;&EN97,@:6X@=&AE(&QI;F4@8G5F9F5R
M(&%N9"!M86ME<R!S=7)E('1H97D*("`@("`J(&%R92!A9&]R;FUE;G1S(&%N
M9"!T:&%T(&%L;"!A<F4@:61E;G1I8V%L(&%D;W)N;65N=',N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1L:6YE<R`@("`@("`@06X@87)R87D@;V8@;&EN92!N=6UB97)S('1O
M(&-H96-K(&EF('1H97D@87)E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A9&]R;FUE;G1S+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&UI
M;DQE;F=T:"`@5&AE(&UI;FEM=6T@;&5N9W1H(&9O<B!T:&ES(&%D;W)N;65N
M="X@(%1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@9&5F
M875L="!I<R`Q+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE
M=&AE<B!T:&ES(&QI;F4@:7,@86X@861O<FYM96YT('=H:6-H(&UA=&-H97,@
M=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@(&%B;W9E(&-R:71E<FEA+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?8VAE8VM!9&]R;FUE;G0H)&QI;F5S(#T@
M87)R87DH,"DL("1M:6Y,96YG=&@@/2`Q*0H@("`@>PH@("`@("`@("1C:'(@
M/2!N=6QL.PH@("`@("`@(&9O<F5A8V@@*"1L:6YE<R!A<R`D:2D@>PH@("`@
M("`@("`@("!I9B`H(7!R96=?;6%T8V@H)R]>*%M>82UZ02U:,"TY7'@W9BU<
M>&9F7'-=*RE<<RHD+R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7VQI;F5"=69F97);)&E=+"`D;2DI('L*("`@("`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M:7-?;G5L;"@D8VAR*2D@>PH@("`@("`@("`@("`@("`@:68@*'-T<FQE;B@D
M;5LQ72D@/"`D;6EN3&5N9W1H*2!["B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M)&-H<B`]("1M6S%=>S!].PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@:68@*'-T<FQE;B@D;5LQ72D@(3T@)&UI;DQE;F=T:"D@>PH@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D;6EN3&5N9W1H(#T@
M<W1R;&5N*"1M6S%=*3L*("`@("`@("`@("`@9F]R("@D:B`](#`[("1J(#P@
M<W1R;&5N*"1M6S%=*3L@)&HK*RD@>PH@("`@("`@("`@("`@("`@:68@*"1M
M6S%=>R1J?2`A/2`D8VAR*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N
M("9?<&%R<V5);FQI;F4H)B1N;V1E+"`D=&5X="D*("`@('L*("`@("`@("!S
M=&%T:6,@)&%L:6%S97,@/2!A<G)A>2@G<W5P)R`]/B`G<W5P97)S8W)I<'0G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S=6(G(#T^("=S
M=6)S8W)I<'0G*3L*("`@("`@("!S=&%T:6,@)'-C:&5M87,@/2!A<G)A>2@G
M:'1T<"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAT='!S
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9G1P)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:7)C)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G=&5L;F5T)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G;F5W<R<I.PH*("`@("`@("!W:&EL92`H
M<W1R;&5N*"1T97AT*2`^(#`I('L*("`@("`@("`@("`@:68@*'!R96=?;6%T
M8V@H)R]>7"I<*B@H/SI<7%Q<+GQ;7EQ<7%Q=*2H_*5PJ7"HH+BHI)"\G+"`D
M=&5X="P@)&TI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VUA:V5.;V1E
M*"1N;V1E+"`G26YT97)P<F5T960M5&5X="<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"=R;VQE)R`]/B`G<W1R;VYG)RDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1M6S%=*3L*("`@("`@
M("`@("`@("`@("1T97AT(#T@)&U;,ET["B`@("`@("`@("`@('T@96QS96EF
M("AP<F5G7VUA=&-H*"<O7EPJ*"@_.EQ<7%PN?%M>7%Q<7%TI*C\I7"HH+BHI
M)"\G+"`D=&5X="P@)&TI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VUA
M:V5.;V1E*"1N;V1E+"`G26YT97)P<F5T960M5&5X="<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=R;VQE)R`]/B`G96UP:&%S
M:7,G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&U;,5TI
M.PH@("`@("`@("`@("`@("`@)'1E>'0@/2`D;5LR73L*("`@("`@("`@("`@
M?2!E;'-E:68@*'!R96=?;6%T8V@H)R]>8&`H+BH_*6!@*"XJ*20O)RP@)'1E
M>'0L("1M*2D@>PH@("`@("`@("`@("`@("`@)'-U8B`]("8D=&AI<RT^7VUA
M:V5.;V1E*"1N;V1E+"`G26YT97)P<F5T960M5&5X="<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W)O;&4G(#T^
M("=L:71E<F%L)RDI.PH@("`@("`@("`@("`@("`@)'-U8BT^87!P96YD0VAI
M;&0H)&U;,5TI.PH@("`@("`@("`@("`@("`@)'1E>'0@/2`D;5LR73L*("`@
M("`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H)R]>.BA;82UZ+5TK*3I@
M*"@_.EQ<7%PN?%M>7%Q<7%TI*C\I8"@N*BDD+R<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T97AT+"`D;2DI('L*("`@("`@("`@("`@
M("`@("1R;VQE(#T@)&U;,5T["B`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)&%L:6%S97-;)&U;,5U=*2D@>PH@("`@("`@("`@("`@("`@("`@("1R;VQE
M(#T@)&%L:6%S97-;)&U;,5U=.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@)'-U8B`]("8D=&AI<RT^7VUA:V5.;V1E*"1N;V1E+"`G26YT
M97)P<F5T960M5&5X="<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)W)O;&4G(#T^("1R;VQE*2D["B`@("`@("`@
M("`@("`@("!I9B`H)')O;&4@/3T@)VQI=&5R86PG*2!["B`@("`@("`@("`@
M("`@("`@("`@)'-U8BT^87!P96YD0VAI;&0H)&U;,ETI.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M<G-E26YL:6YE*"1S=6(L("1M6S)=*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("1T97AT(#T@)&U;,UT["B`@("`@("`@("`@('T@96QS
M96EF("AP<F5G7VUA=&-H*"<O7F`H*#\Z7%Q<7"Y\6UY<7%Q<72DJ/RE@.BA;
M82UZ+5TK*3HH+BHI)"\G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&5X="P@)&TI*2!["B`@("`@("`@("`@("`@("`D<F]L92`]("1M
M6S)=.PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A;&EA<V5S6R1M6S)=
M72DI('L*("`@("`@("`@("`@("`@("`@("`D<F]L92`]("1A;&EA<V5S6R1M
M6S)=73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1S=6(@
M/2`F)'1H:7,M/E]M86ME3F]D92@D;F]D92P@)TEN=&5R<')E=&5D+51E>'0G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*"=R;VQE)R`]/B`D<F]L92DI.PH@("`@("`@("`@("`@("`@:68@*"1R
M;VQE(#T]("=L:71E<F%L)RD@>PH@("`@("`@("`@("`@("`@("`@("1S=6(M
M/F%P<&5N9$-H:6QD*"1M6S%=*3L*("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)S94EN;&EN92@D<W5B
M+"`D;5LQ72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M=&5X="`]("1M6S-=.PH@("`@("`@("`@("!](&5L<V5I9B`H<')E9U]M871C
M:"@G+UY@*"@_.EQ<7%PN?%M>7%Q<7%TI*C\I8%]?*"XJ*20O)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1E>'0L("1M*2D@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P87)S94QI;FLH)&YO9&4L("1M6S%=+"!T
M<G5E*3L*("`@("`@("`@("`@("`@("1T97AT(#T@)&U;,ET["B`@("`@("`@
M("`@('T@96QS96EF("AP<F5G7VUA=&-H*"<O7F`H*#\Z7%Q<7"Y\6UY<7%Q<
M72DJ/RE@7R@N*BDD+R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T97AT+"`D;2DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M<V5,:6YK*"1N;V1E+"`D;5LQ72P@9F%L<V4I.PH@("`@("`@("`@("`@("`@
M)'1E>'0@/2`D;5LR73L*("`@("`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T
M8V@H)R]>8"@H/SI<7%Q<+GQ;7EQ<7%Q=*2H_*6`H+BHI)"\G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&5X="P@)&TI*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7VUA:V5.;V1E*"1N;V1E+"`G26YT97)P<F5T
M960M5&5X="<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*"=R;VQE)R`]/B`G=&ET;&4M<F5F97)E;F-E)RDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1M6S%=*3L*("`@("`@("`@("`@("`@
M("1T97AT(#T@)&U;,ET["B`@("`@("`@("`@('T@96QS96EF("AP<F5G7VUA
M=&-H*"<O7B@H/SHG("X@:F]I;B@G?"<L("1S8VAE;6%S*2`N("`G*3I<+UPO
M6RTP+3EA+7HC)28K+EPO.CL_7UQ<?ETK6RTP+3EA+7HC)28K7"]?7%Q^72DH
M+BHI)"]I)RP@)'1E>'0L("1M*2D@>PH@("`@("`@("`@("`@("`@)'-U8B`]
M("8D=&AI<RT^7VUA:V5.;V1E*"1N;V1E+"`G3&EN:R<L(&%R<F%Y*"=H<F5F
M)R`]/B`D;5LQ72DI.PH@("`@("`@("`@("`@("`@)'-U8BT^87!P96YD0VAI
M;&0H)&U;,5TI.PH@("`@("`@("`@("`@("`@)'1E>'0@/2`D;5LR73L*("`@
M("`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H)R]>*%MA+7HP+3DM72M`
M6V$M>C`M.2U<+ETK7"Y;82UZ,"TY+5TK*2@N*BDD+VDG+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&5X="P@)&TI*2!["B`@("`@("`@
M("`@("`@("`D<W5B(#T@)B1T:&ES+3Y?;6%K94YO9&4H)&YO9&4L("=,:6YK
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@G:')E9B<@/3X@)VUA:6QT;SHG("X@)&U;,5TI*3L*("`@("`@("`@
M("`@("`@("1S=6(M/F%P<&5N9$-H:6QD*"1M6S%=*3L*("`@("`@("`@("`@
M("`@("1T97AT(#T@)&U;,ET["B`@("`@("`@("`@('T@96QS96EF("AP<F5G
M7VUA=&-H*"<O7BA<=RLI7UQB*"XJ*20O)RP@)'1E>'0L("1M*2D@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P87)S94QI;FLH)&YO9&4L("1M6S%=+"!F
M86QS92D["B`@("`@("`@("`@("`@("`D=&5X="`]("1M6S)=.PH@("`@("`@
M("`@("!](&5L<V5I9B`H<')E9U]M871C:"@G+UY<7%Q<7',H+BHI)"\G+"`D
M=&5X="P@)&TI*2!["B`@("`@("`@("`@("`@("`O+R!"86-K<VQA<V@M97-C
M87!E9"!W:&ET97-P86-E(&-H87)A8W1E<G,@87)E(')E;6]V960@9G)O;0H@
M("`@("`@("`@("`@("`@+R\@=&AE(&1O8W5M96YT+@H@("`@("`@("`@("`@
M("`@)'1E>'0@/2`D;5LQ73L*("`@("`@("`@("`@?2!E;'-E:68@*'!R96=?
M;6%T8V@H)R]>7%Q<7"@N*2@N*BDD+R<L("1T97AT+"`D;2DI('L*("`@("`@
M("`@("`@("`@("1C(#T@)&U;,5T["B`@("`@("`@("`@("`@("`D=&5X="`]
M("1M6S)=.PH@("`@("`@("`@("`@("`@)&YO9&4M/F%P<&5N9$-H:6QD*"1C
M*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("\O(%A8
M6#H@5V4@<VAO=6QD('1R>2!T;R!U<V4@82!R96=E>'`@=&\@9W)A8B!A<R!M
M=6-H('1E>'0@87,*("`@("`@("`@("`@("`@("\O('!O<W-I8FQE+"!T:&5N
M(&9A;&P@=&AR;W5G:"!T;R!T:&4@<VEN9VQE+6-H87)A8W1E<B!C87-E"B`@
M("`@("`@("`@("`@("`O+R!I9B!W92!C86XG="!G970@86YY=&AI;F<N"@H@
M("`@("`@("`@("`@("`@)&,@/2!S=6)S='(H)'1E>'0L(#`L(#$I.PH@("`@
M("`@("`@("`@("`@)'1E>'0@/2!S=6)S='(H)'1E>'0L(#$I.PH@("`@("`@
M("`@("`@("`@)&YO9&4M/F%P<&5N9$-H:6QD*"1C*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1B;V1Y.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4&%R<V5S(&%N(&%N;VYY;6]U<R!O<B!N86UE9"!L:6YK
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!P87)A;2!497AT7W)E4U0@("`@("`@("`@(%1H92!P87)E;G0@;F]D92!F
M;W(@=&AE(&QI;FLN"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("`@("`@
M("!4:&4@=&5X="!T;R!P87)S92X*("`@("`J($!P87)A;2!B;V]L96%N("1A
M;F]N>6UO=7,@(%=H971H97(@=&AI<R!I<R!A;B!A;F]N>6UO=7,@;&EN:RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(%1E>'1?<F535"`@5&AE(&YE=R!L:6YK
M(&YO9&4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9?<&%R<V5,:6YK*"8D;F]D
M92P@)'1E>'0L("1A;F]N>6UO=7,@/2!F86QS92D*("`@('L*("`@("`@("`D
M;&EN:R`]("8D=&AI<RT^7VUA:V5.;V1E*"1N;V1E+"`G3&EN:R<I.PH*("`@
M("`@("!I9B`H<')E9U]M871C:"@G+SPH+BHI/B\G+"`D=&5X="P@)&TI*2![
M"B`@("`@("`@("`@("1L:6YK+3YS9710<F]P97)T>2@G:')E9B<L("1M6S%=
M*3L*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>*%M>/%TK/RE<<RH\
M+R<L("1T97AT+"`D;2DI('L*("`@("`@("`@("`@("`@("1L:6YK+3YA<'!E
M;F1#:&EL9"@D;5LQ72D["B`@("`@("`@("`@("`@("!I9B`H(21A;F]N>6UO
M=7,I('L*("`@("`@("`@("`@("`@("`@("`D;&EN:RT^<V5T4')O<&5R='DH
M)VYA;64G+"`D=&AI<RT^7VYO<FUA;&EZ94YA;64H)&U;,5TI*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(&EF("@A)&%N;VYY;6]U<RD@>PH@("`@("`@("`@("`@("`@
M)&QI;FLM/G-E=%!R;W!E<G1Y*"=N86UE)RP@)'1H:7,M/E]N;W)M86QI>F5.
M86UE*"1T97AT*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&QI;FLM
M/F%P<&5N9$-H:6QD*"1T97AT*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D
M86YO;GEM;W5S("8F(&ES7VYU;&PH)&QI;FLM/F=E=%!R;W!E<G1Y*"=H<F5F
M)RDI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<75E=65!;F]N>6UO=7-2969E
M<F5N8V4H)&QI;FLL("=L:6YK)RD["B`@("`@("`@?2!E;'-E:68@*"$D86YO
M;GEM;W5S("8F("%I<U]N=6QL*"1L:6YK+3YG9710<F]P97)T>2@G;F%M92<I
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!U=$YA;65D4F5F97)E;F-E*"1L
M:6YK+"`G;&EN:R<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1L:6YK
M.PH@("`@?0H*("`@("\J*@H@("`@("H@3F]R;6%L:7IE<R!A;B!O8FIE8W0@
M;F%M92X*("`@("`J(%1H:7,@;65A;G,@=&AA="!W92!L;W=E<F-A<V4@:70@
M86YD(&YO<FUA;&EZ92!A;GD@=VAI=&5S<&%C92!I;B!I="X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!!(&YA;64@=&\@;F]R;6%L:7IE
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;F]R;6%L:7IE
M9"!N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!?;F]R;6%L:7IE3F%M92@D
M;F%M92D*("`@('L*("`@("`@("!R971U<FX@<')E9U]R97!L86-E*"<O7',K
M+R<L("<@)RP@<W1R=&]L;W=E<B@D;F%M92DI.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4&%R<V5S(&%N9"!E>&5C=71E<R!A(&`N+B<@9&ER96-T:79E+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'1E>'0@($$@9&ER96-T:79E('1O(&5X96-U=&4L(&QE
M<W,@=&AE(&QE861I;F<@8"XN("<N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P
M87)S941I<F5C=&EV92@D=&5X="D*("`@('L*("`@("`@("!I9B`H<')E9U]M
M871C:"@G+UY?7SI<<RHH+BH_*5QS*B0O)RP@)'1E>'0L("1M*2D@>PH@("`@
M("`@("`@("`O+PH@("`@("`@("`@("`O+R!!;F]N>6UO=7,@;&EN:R!D969I
M;FET:6]N"B`@("`@("`@("`@("\O"B`@("`@("`@("`@("1D969N(#T@)FYE
M=R!497AT7W)E4U0H)TQI;FLG*3L*("`@("`@("`@("`@:68@*'!R96=?;6%T
M8V@H)R]>6V$M>C`M.2U=*T!;82UZ,"TY+5PN72M<+EMA+7HP+3DM72LD+VDG
M+"`D;5LQ72DI('L*("`@("`@("`@("`@("`@("1M6S%=(#T@)VUA:6QT;SHG
M("X@)&U;,5T["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&1E9FXM/G-E
M=%!R;W!E<G1Y*"=H<F5F)RP@)&U;,5TI.PH@("`@("`@("`@("`D=&AI<RT^
M7W%U975E06YO;GEM;W5S1&5F:6YI=&EO;B@D9&5F;BP@)VQI;FLG*3L*("`@
M("`@("!](&5L<V5I9B`H<')E9U]M871C:"@G+UY<<RI?*"XJ/RDZ7',J*"XJ
M/RE<<RHD+R<L("1T97AT+"`D;2DI('L*("`@("`@("`@("`@+R\*("`@("`@
M("`@("`@+R\@3F%M960@;&EN:R!D969I;FET:6]N"B`@("`@("`@("`@("\O
M"B`@("`@("`@("`@("1D969N(#T@)FYE=R!497AT7W)E4U0H)TQI;FLG*3L*
M("`@("`@("`@("`@)&1E9FXM/G-E=%!R;W!E<G1Y*"=N86UE)RP@)'1H:7,M
M/E]N;W)M86QI>F5.86UE*"1M6S%=*2D["B`@("`@("`@("`@(&EF("AP<F5G
M7VUA=&-H*"<O7EMA+7HP+3DM72M`6V$M>C`M.2U<+ETK7"Y;82UZ,"TY+5TK
M)"]I)RP@)&U;,ETI*2!["B`@("`@("`@("`@("`@("`D;5LR72`]("=M86EL
M=&\Z)R`N("1M6S)=.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1D969N
M+3YS9710<F]P97)T>2@G:')E9B<L("1M6S)=*3L*("`@("`@("`@("`@)'1H
M:7,M/E]P=71.86UE9$1E9FEN:71I;VXH)&1E9FXL("=L:6YK)RD["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4VMI<',@8FQA;FL@;&EN97,@
M=6YT:6P@=V4@9FEN9"!O;F4@=V4@8V%N(&=E="!T:&4@:6YD96YT871I;VX@
M;&5V96P*("`@("`J(&9R;VTL('1H96XL(&=A=&AE<G,@;&EN97,@=6YT:6P@
M=V4@:&%V92!A(&1I9F9E<F5N="!L979E;"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@7W!A<G-E3&ET97)A;$)L;V-K*"D*("`@('L*("`@("`@("!I9B`H(21T
M:&ES+3Y?96YS=7)E3&EN97,H,2DI('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@=VAI;&4@*'!R96=?;6%T8V@H)R]>
M7',J)"\G+"`D=&AI<RT^7VQI;F5"=69F97);,%TI*2!["B`@("`@("`@("`@
M(&EF("@A)'1H:7,M/E]N97AT*"DI('L*("`@("`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@
M*"%P<F5G7VUA=&-H*"<O7BA<<RLI*"XJ/RE<<RHD+R<L("1T:&ES+3Y?;&EN
M94)U9F9E<ELP72P@)&TI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!]"B`@("`@("`@)&QE=F5L(#T@<W1R;&5N*"1M6S%=*3L*("`@
M("`@("`D=&5X="`]("1M6S)=.PH*("`@("`@("!I9B`H)'1H:7,M/E]N97AT
M*"DI('L*("`@("`@("`@("`@)')E(#T@)R]>*#\Z('LG("X@)&QE=F5L("X@
M)WTH+BH_*7PH*2E<<RHD+R<["B`@("`@("`@("`@('=H:6QE("AP<F5G7VUA
M=&-H*"1R92P@)'1H:7,M/E]L:6YE0G5F9F5R6S!=+"`D;2DI('L*("`@("`@
M("`@("`@("`@("1T97AT("X](")<;B(@+B`D;5LQ73L*("`@("`@("`@("`@
M("`@(&EF("@A)'1H:7,M/E]N97AT*"DI('L*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@)&P@/2`F)'1H:7,M/E]M86ME3F]D92@D=&AI<RT^
M7V-U<G)E;G1.;V1E+"`G3&ET97)A;"U";&]C:R<L(&%R<F%Y*"DI.PH@("`@
M("`@("1L+3YA<'!E;F1#:&EL9"AP<F5G7W)E<&QA8V4H)R]<<RLD+W,G+"`G
M)RP@)'1E>'0I*3L*"B`@("`@("`@+R\@6%A8.B!$:7)T>2!H86-K(0H@("`@
M("`@(&%R<F%Y7W5N<VAI9G0H)'1H:7,M/E]L:6YE0G5F9F5R+"`G)RD["B`@
M("!]"@H@("`@+R\M+2TM"B`@("`O+R!,:6YE+7)E861I;F<@;65M8F5R<PH@
M("`@+R\M+2TM"@H@("`@+RHJ"B`@("`@*B!4:&4@<F5M86EN9&5R(&]F('1H
M92!T97AT('=E(&%R92!P87)S:6YG+"!B96EN9R!M;V1I9FEE9"!B>2!?9V5T
M3&EN92@I"B`@("`@*B!A;F0@7VYE>'0H*2X*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D7W1E>'0["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!T:&4@;&EN
M97,@=V4@:&%V92!P965K960@870N"B`@("`@*@H@("`@("H@5&AE(&9I<G-T
M(&5L96UE;G0@:7,@=&AE(&QI;F4@=V4@87)E(&-U<G)E;G1L>2!W;W)K:6YG
M('=I=&@@86YD('-O(&]N+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]L:6YE0G5F
M9F5R(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%)E=')I979E<R!T:&4@
M;F5X="!L:6YE(&9R;VT@82!B;&]C:R!O9B!T97AT+@H@("`@("H*("`@("`J
M(%=E(')E<&QA8V4@=&%B<R!W:71H(#@@<W!A8V5S+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T3&EN
M92@I"B`@("!["B`@("`@("`@:68@*'-T<FQE;B@D=&AI<RT^7W1E>'0I(#T]
M(#`I('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H@("`@
M("`@("1I(#T@<W1R<&]S*"1T:&ES+3Y?=&5X="P@(EQN(BD["B`@("`@("`@
M:68@*"1I("$]/2!F86QS92D@>PH@("`@("`@("`@("`D;&EN92`]('-U8G-T
M<B@D=&AI<RT^7W1E>'0L(#`L("1I*3L*("`@("`@("`@("`@)'1H:7,M/E]T
M97AT(#T@<W5B<W1R*"1T:&ES+3Y?=&5X="P@)&D@*R`Q*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D;&EN92`]("1T:&ES+3Y?=&5X=#L*("`@
M("`@("`@("`@)'1H:7,M/E]T97AT(#T@)R<["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B!P<F5G7W)E<&QA8V4H)R]<="\G+"`G("`@("`@("`G+"`D;&EN
M92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!"=6UP<R!T;R!T:&4@;F5X="!L
M:6YE(&EN('1H92!I;G!U="X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7VYE>'0H*0H@("`@>PH@("`@("`@
M("\O(%-P96-I86P@8V%S92!T:&4@9FER<W0@=&EM92`G<F]U;F0N"B`@("`@
M("`@:68@*&-O=6YT*"1T:&ES+3Y?;&EN94)U9F9E<BD@/3T@,"D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]E;G-U<F5,:6YE<R@Q*3L*("`@("`@
M("!]"@H@("`@("`@(&EF("@A)'1H:7,M/E]E;G-U<F5,:6YE<R@R*2D@>PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@(&%R
M<F%Y7W-H:69T*"1T:&ES+3Y?;&EN94)U9F9E<BD["B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!-86ME<R!S=7)E('1H97)E
M(&ES(&$@8V5R=&%I;B!N=6UB97(@;V8@;&EN97,@870@;6EN:6UU;2!I;B!T
M:&4@;&EN90H@("`@("H@8G5F9F5R+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1C;W5N="`@
M5&AI<R!I<R!T:&4@;G5M8F5R(&]F(&QI;F5S('=H:6-H(&UU<W0@8F4@:6X@
M=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&)U9F9E<BX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T('=E
M('-U8V-E961E9"X@(%=E(&-A;B!F86EL(&%T"B`@("`@*B`@("`@("`@("`@
M("`@("`@(&5N9"UO9BUF:6QE+@H@("`@("HO"B`@("!F=6YC=&EO;B!?96YS
M=7)E3&EN97,H)&-O=6YT(#T@,2D*("`@('L*("`@("`@("!W:&EL92`H8V]U
M;G0H)'1H:7,M/E]L:6YE0G5F9F5R*2`\("1C;W5N="D@>PH@("`@("`@("`@
M("`D;&EN92`]("1T:&ES+3Y?9V5T3&EN92@I.PH@("`@("`@("`@("!I9B`H
M:7-?;G5L;"@D;&EN92DI('L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7VQI;F5"=69F
M97);72`]("1L:6YE.PH@("`@("`@('T*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"B`@("`O+RTM+2T*("`@("\O($%N;VYY;6]U<R!R969E<F5N8V5S
M(&%N9"!D969I;FET:6]N<PH@("`@+R\M+2TM"@H@("`@=F%R("1?86YO;GEM
M;W5S4F5F97)E;F-E<R`](&%R<F%Y*"D["B`@("!V87(@)%]A;F]N>6UO=7-$
M969I;FET:6]N<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!3:6YC92!A
M;F]N>6UO=7,@<F5F97)E;F-E<R!A;F0@9&5F:6YI=&EO;G,@*&4N9RX@9F]O
M=&YO=&5S+"!L:6YK<RD@9&\*("`@("`J(&YO="!N965D('1O(&)E(&1E9FEN
M960@(FEN(&QO8VMS=&5P(B!A8V-O<F1I;F<@=&\@=&AE('-P96,L('=E(&-R
M96%T90H@("`@("H@=&AE('!A<G1I86P@<&%R<V4@;F]D92!I;B!B;W1H('!L
M86-E<R!A;F0@=7-E('1H:7,@;FEF='D@<WES=&5M('1O"B`@("`@*B!Q=65U
M92!O<B!M97)G92!I;B!E86-H('!L86-E+B`@3F]T92!T:&%T('1H92!R969E
M<F5N8V4@:7,@=&AE(")M87-T97(B"B`@("`@*B!N;V1E+B`@5&AE(&1E9FEN
M:71I;VX@9V5T<R!T:')O=VX@87=A>2!S:6YC92!I="!R96%L;'D@:7-N)W0@
M:6X@=&AE"B`@("`@*B!P87)S92!T<F5E(&%N>7=A>2X*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@;V)J96-T
M("8D;F]D92`@5&AE(&YO9&4@=&\@<75E=64@;W(@;65R9V4@=&\N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1T>7!E("`@5&AE('1Y<&4@;V8@86YO;GEM;W5S
M(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@7W%U975E06YO;GEM;W5S
M4F5F97)E;F-E*"8D;F]D92P@)'1Y<&4I"B`@("!["B`@("`@("`@:68@*"%A
M<G)A>5]K97E?97AI<W1S*"1T>7!E+"`D=&AI<RT^7V%N;VYY;6]U<T1E9FEN
M:71I;VYS*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V%N;VYY;6]U<T1E9FEN
M:71I;VYS6R1T>7!E72`](&%R<F%Y*"D["B`@("`@("`@?0H@("`@("`@(&EF
M("AC;W5N="@D=&AI<RT^7V%N;VYY;6]U<T1E9FEN:71I;VYS6R1T>7!E72D@
M/B`P*2!["B`@("`@("`@("`@("1D969N(#T@)B1T:&ES+3Y?86YO;GEM;W5S
M1&5F:6YI=&EO;G-;)'1Y<&5=6S!=.PH@("`@("`@("`@("!A<G)A>5]S:&EF
M="@D=&AI<RT^7V%N;VYY;6]U<T1E9FEN:71I;VYS6R1T>7!E72D["B`@("`@
M("`@("`@("1T:&ES+3Y?;65R9V5.;V1E4')O<&5R=&EE<R@D;F]D92P@)&1E
M9FXI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?86YO
M;GEM;W5S4F5F97)E;F-E<ULD='EP95U;72`]("8D;F]D93L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!(86YD;&5S(&%N(&%N;VYY;6]U<R!D
M969I;FET:6]N+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H*("`@("`J($!P87)A;2!O8FIE8W0@)B1N;V1E("!4:&4@;F]D92!T;R!Q
M=65U92!O<B!M97)G92!F<F]M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP
M92`@(%1H92!T>7!E(&]F(&%N;VYY;6]U<R!O8FIE8W0N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]Q=65U94%N;VYY;6]U<T1E9FEN:71I;VXH)B1N;V1E+"`D
M='EP92D*("`@('L*("`@("`@("!I9B`H(6%R<F%Y7VME>5]E>&ES=',H)'1Y
M<&4L("1T:&ES+3Y?86YO;GEM;W5S4F5F97)E;F-E<RDI('L*("`@("`@("`@
M("`@)'1H:7,M/E]A;F]N>6UO=7-2969E<F5N8V5S6R1T>7!E72`](&%R<F%Y
M*"D["B`@("`@("`@?0H@("`@("`@(&EF("AC;W5N="@D=&AI<RT^7V%N;VYY
M;6]U<U)E9F5R96YC97-;)'1Y<&5=*2`^(#`I('L*("`@("`@("`@("`@)')E
M9B`]("8D=&AI<RT^7V%N;VYY;6]U<U)E9F5R96YC97-;)'1Y<&5=6S!=.PH@
M("`@("`@("`@("!A<G)A>5]S:&EF="@D=&AI<RT^7V%N;VYY;6]U<U)E9F5R
M96YC97-;)'1Y<&5=*3L*("`@("`@("`@("`@)'1H:7,M/E]M97)G94YO9&50
M<F]P97)T:65S*"1R968L("1N;V1E*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=&AI<RT^7V%N;VYY;6]U<T1E9FEN:71I;VYS6R1T>7!E75M=
M(#T@)B1N;V1E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($UE
M<F=E<R!T:&4@<')O<&5R=&EE<R!F<F]M(&5A8V@@;F]D92!I;G1O('1H92!O
M=&AE<B!N;V1E+@H@("`@("H*("`@("`J(%1H92!N;V1E('1Y<&4@:7,@;F]T
M(&-H86YG960@*&9O<B!T:&4@8V%S92!W:&5R92!W92!H879E(&$@9F]O=&YO
M=&4*("`@("`J(')E9F5R96YC92!A;F0@82!F;V]T;F]T92!D969I;FET:6]N
M*2P@8G5T(&)O=&@@;F]D97,@=VEL;"!H879E(&%L;`H@("`@("H@<')O<&5R
M=&EE<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@;V)J96-T("8D;F]D92`@5&AE(')E9F5R96YC92!N;V1E
M+@H@("`@("H@0'!A<F%M(&]B:F5C="`F)&1E9FX@(%1H92!D969I;FET:6]N
M(&YO9&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]M97)G94YO9&50<F]P97)T
M:65S*"8D;F]D92P@)B1D969N*0H@("`@>PH@("`@("`@("\O(%A86#H@5V4@
M<VAO=6QD(&UA:V4@<W5R92!T:&5R92!I<R!N;R!C;VQL:7-I;VXN"B`@("`@
M("`@9F]R96%C:"`H)&1E9FXM/E]P<F]P97)T:65S(&%S("1N86UE(#T^("1V
M86QU92D@>PH@("`@("`@("`@("`D;F]D92T^<V5T4')O<&5R='DH)&YA;64L
M("1V86QU92D["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1N;V1E+3Y?
M<')O<&5R=&EE<R!A<R`D;F%M92`]/B`D=F%L=64I('L*("`@("`@("`@("`@
M)&1E9FXM/G-E=%!R;W!E<G1Y*"1N86UE+"`D=F%L=64I.PH@("`@("`@('T*
M("`@('T*"B`@("`O+RTM+2T*("`@("\O($YA;65D(')E9F5R96YC97,@86YD
M(&1E9FEN:71I;VYS"B`@("`O+RTM+2T*"B`@("!V87(@)%]N86UE9%)E9F5R
M96YC97,@/2!A<G)A>2@I.PH@("`@=F%R("1?;F%M961$969I;FET:6]N<R`]
M(&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!3=&]R97,@82!N86UE9"!R969E
M<F5N8V4@<&%R<V4@;F]D92!I;B!A(&AA<V@@<V\@=V4@8V%N(&QA=&5R(&UE
M<F=E"B`@("`@*B!P<F]P97)T:65S('=I=&@@82!D969I;FET:6]N+B`@268@
M=V4@86QR96%D>2!H879E(&$@9&5F:6YI=&EO;BP@9&\*("`@("`J('1H92!M
M97)G92!N;W<N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0'!A<F%M(%1E>'1?<F535"`F)&YO9&4@(%1H92!P87)S92!T
M<F5E(&YO9&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E("`@("`@5&AE
M('1Y<&4@;V8@;F%M960@<F5F97)E;F-E+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=V4@<W5C8V5S<V9U;&QY(&%D
M9&5D('1H92!R969E<F5N8V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P=71.
M86UE9%)E9F5R96YC92@F)&YO9&4L("1T>7!E*0H@("`@>PH@("`@("`@("1N
M86UE(#T@)&YO9&4M/F=E=%!R;W!E<G1Y*"=N86UE)RD["B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?;F%M9612969E<F5N8V5S6R1T>7!E75LD;F%M95TI
M*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@
M("`@)'1H:7,M/E]N86UE9%)E9F5R96YC97-;)'1Y<&5=6R1N86UE72`]("8D
M;F]D93L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]N86UE9$1E9FEN:71I
M;VYS6R1T>7!E75LD;F%M95TI*2!["B`@("`@("`@("`@("1D969N(#T@)B1T
M:&ES+3Y?;F%M961$969I;FET:6]N<ULD='EP95U;)&YA;65=.PH@("`@("`@
M("`@("`D=&AI<RT^7VUE<F=E3F]D95!R;W!E<G1I97,H)&YO9&4L("1D969N
M*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!4:&4@:6YV97)S92!O9B![0&QI;FL@7W!U=$YA;65D4F5F
M97)E;F-E*"E]+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("HO"B`@("!F=6YC=&EO;B!?<'5T3F%M961$969I;FET:6]N*"8D;F]D92P@
M)'1Y<&4I"B`@("!["B`@("`@("`@)&YA;64@/2`D;F]D92T^9V5T4')O<&5R
M='DH)VYA;64G*3L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]N86UE9$1E
M9FEN:71I;VYS6R1T>7!E75LD;F%M95TI*2!["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]N86UE9$1E9FEN
M:71I;VYS6R1T>7!E75LD;F%M95T@/2`F)&YO9&4["B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?;F%M9612969E<F5N8V5S6R1T>7!E75LD;F%M95TI*2![
M"B`@("`@("`@("`@("1R968@/2`F)'1H:7,M/E]N86UE9%)E9F5R96YC97-;
M)'1Y<&5=6R1N86UE73L*("`@("`@("`@("`@)'1H:7,M/E]M97)G94YO9&50
M<F]P97)T:65S*"1R968L("1N;V1E*3L*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+R\M+2TM"B`@("`O+R!3=&%T92!S=&%C
M:R!M86YA9V5M96YT"B`@("`O+RTM+2T*"B`@("`O*BH*("`@("`J(%1H92!S
M=&%T92!S=&%C:RX*("`@("`J"B`@("`@*B!)="!I<R!U<V5D('1O(&ME97`@
M=')A8VL@;V8@;F5S=&5D(&)O9'DM;&5V96P@96QE;65N=',@86YD(&AO=R!T
M:&5Y"B`@("`@*B!M:6=H="!E;F0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)%]S=&%T95-T86-K(#T@87)R87DH*3L*"B`@
M("!V87(@)%]C=7)R96YT3F]D93L*"B`@("!F=6YC=&EO;B!?<'5S:%-T871E
M*"8D;F]D92P@)'-T871E5'EP92P@)&QE=F5L*0H@("`@>PH@("`@("`@("1S
M=&%T92`]("9N97<@5&5X=%]R95-47U!A<G-E<E]S=&%T92@D;F]D92P@)'-T
M871E5'EP92P@)&QE=F5L*3L*("`@("`@("`D=&AI<RT^7W-T871E4W1A8VM;
M72`]("8D<W1A=&4["B`@("`@("`@)'1H:7,M/E]C=7)R96YT3F]D92`]("8D
M;F]D93L*("`@('T*"B`@("!F=6YC=&EO;B!?9V5T4W1A=&5,979E;"@D<W1A
M=&54>7!E*0H@("`@>PH@("`@("`@(&9O<B`H)&D@/2!C;W5N="@D=&AI<RT^
M7W-T871E4W1A8VLI("T@,3L@)&D@/CT@,#L@)&DM+2D@>PH@("`@("`@("`@
M("!I9B`H)'1H:7,M/E]S=&%T95-T86-K6R1I72T^<W1A=&54>7!E(#T]("1S
M=&%T951Y<&4I('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W-T
M871E4W1A8VM;)&E=+3YL979E;#L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@("`@("!R971U<FX@,#L*("`@('T*"B`@("!F=6YC=&EO;B!?<&]P5&],
M979E;"@D<W1A=&54>7!E+"`D;&5V96PI"B`@("!["B`@("`@("`@=VAI;&4@
M*"1T:&ES+3Y?9V5T4W1A=&5,979E;"@D<W1A=&54>7!E*2`^("1L979E;"D@
M>PH@("`@("`@("`@("`D=&AI<RT^7W!O<"@I.PH@("`@("`@('T*("`@('T*
M"B`@("!F=6YC=&EO;B!?<&]P*"D*("`@('L*("`@("`@("!A<G)A>5]P;W`H
M)'1H:7,M/E]S=&%T95-T86-K*3L*("`@("`@("!I9B`H8V]U;G0H)'1H:7,M
M/E]S=&%T95-T86-K*2D@>PH@("`@("`@("`@("`D<W1A=&4@/2`F)'1H:7,M
M/E]S=&%T95-T86-K6V-O=6YT*"1T:&ES+3Y?<W1A=&53=&%C:RD@+2`Q73L*
M("`@("`@("`@("`@)'1H:7,M/E]C=7)R96YT3F]D92`]("8D<W1A=&4M/FYO
M9&4["B`@("`@("`@?0H@("`@?0H*?0H*+RHJ"B`J(%1H:7,@8VQA<W,@<F5P
M<F5S96YT<R!A(&YO9&4@;VX@=&AE('!A<G-E<B=S('-T871E('-T86-K+@H@
M*@H@*B!`<&%C:V%G92!497AT7W)E4U0*("HO"F-L87-S(%1E>'1?<F535%]0
M87)S97)?<W1A=&4@>PH*("`@('9A<B`D;F]D93L*("`@('9A<B`D<W1A=&54
M>7!E.PH@("`@=F%R("1L979E;#L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C
M=&]R+@H@("`@("H*("`@("`J($!P87)A;2!O8FIE8W0@)B1N;V1E("`@("`@
M5&AI<R!I<R!T:&4@<&%R<V4@;F]D92!A<W-O8VEA=&5D('=I=&@@=&AI<PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!S=&%T92X@($)L;V-K
M+6QE=F5L(&5L96UE;G1S('!A<G-E9"!I;B!T:&ES"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@('-T871E('=I;&P@8F4@8VAI;&1R96X@;V8@
M=&AI<R!N;V1E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<W1A=&54>7!E("!#
M=7)R96YT;'D@;VYL>2`G4V5C=&EO;B<N"B`@("`@*B!`<&%R86T@;6EX960@
M)&QE=F5L("`@("`@(%1H:7,@:7,@=&AE(&YE<W1I;F<@;&5V96P@;V8@=&AI
M<R!S=&%T92!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!497AT7W)E4U1?
M4&%R<V5R7W-T871E*"8D;F]D92P@)'-T871E5'EP92P@)&QE=F5L*0H@("`@
M>PH@("`@("`@("1T:&ES+3YN;V1E(#T@)B1N;V1E.PH@("`@("`@("1T:&ES
M+3YS=&%T951Y<&4@/2`D<W1A=&54>7!E.PH@("`@("`@("1T:&ES+3YL979E
M;"`]("1L979E;#L*("`@('T*"GT*````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O5&5X="]R95-4
M+T9O<FUA='1E<BYP:'``````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#,T,S0@,3`U,34T,S,W,S4@,#(R-3<P`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@5&5X
M=%]R95-47T9O<FUA='1E<CHZ(&-L87-S(&ES('1H92!F<F%M97=O<FL@9F]R
M(')E;F1E<FEN9PH@*B!R95-T<G5C='5R961497AT(&1O8W5M96YT<R!T;R!D
M:69F97)E;G0@;65D:6$@*&4N9RX@2%1-3"DN"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+U1E>'1?<F535"]R95-4+T9O<FUA='1E<BYP:'`L=B`Q+C4N,3`N
M.2`R,#`V+S`Q+S`Q(#(Q.C(X.C,Y(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P,RTR,#`V($IA<V]N($TN($9E;&EC92`\:F9E;&EC94!C<F]N;W-Y
M<RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9"!N;W0*
M("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*87-O;B!-+B!&
M96QI8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M/@H@*B!`<&%C:V%G92!497AT
M7W)E4U0*("HO"F-L87-S(%1E>'1?<F535%]&;W)M871T97(@>PH*("`@("\J
M*@H@("`@("H@07)R87D@;V8@9')I=F5R+7-P96-I9FEC('!A<F%M971E<G,@
M9F]R(&9O<FUA='1I;F<N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)%]A<F=S.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T
M(&$@;F5W(&9O<FUA='1E<BX*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E
M8W1E9`H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D87)G<R`@07)G=6UE
M;G1S('-P96-I9FEC('1O('1H:7,@9F]R;6%T=&5R+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!497AT7W)E4U1?1F]R;6%T=&5R*"1A<F=S(#T@87)R87DH*2D*
M("`@('L*("`@("`@("`D=&AI<RT^7V%R9W,@/2`D87)G<SL*("`@('T*"B`@
M("`O*BH*("`@("`J($-O;G-T<G5C="!A(&YE=R!F;W)M871T97(N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9')I=F5R("!.86UE(&]F('1H92!F
M;W)M871T:6YG(&1R:79E<B!T;R!C;VYS=')U8W0N"B`@("`@*B!`<&%R86T@
M87)R87D@)&%R9W,@("`@($%N(&%R<F%Y(&]F(&1R:79E<BUS<&5C:69I8R!P
M87)A;65T97)S+@H@("`@("H*("`@("`J($!R971U<FX@5&5X=%]R95-47T9O
M<FUA='1E<B`@5&AE(&9O<FUA='1E<@H@("`@("HO"B`@("!F=6YC=&EO;B`F
M9F%C=&]R>2@D9')I=F5R+"`D87)G<R`](&%R<F%Y*"DI"B`@("!["B`@("`@
M("`@:68@*&ES7V%R<F%Y*"1D<FEV97(I*2!["B`@("`@("`@("`@(&QI<W0H
M)'!A=&@L("1D<FEV97(I(#T@)&1R:79E<CL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D<&%T:"`](&1I<FYA;64H7U]&24Q%7U\I("X@)R]&;W)M
M871T97(O)SL*("`@("`@("!]"B`@("`@("`@)&-L87-S(#T@)U1E>'1?<F53
M5%]&;W)M871T97)?)R`N("1D<FEV97(["B`@("`@("`@<F5Q=6ER95]O;F-E
M("1P871H("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("`D9F]R;6%T=&5R
M(#T@)FYE=R`D8VQA<W,H)&%R9W,I.PH@("`@("`@(')E='5R;B`D9F]R;6%T
M=&5R.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5N9&5R('1H92!D;V-U;65N
M="X*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<&%R
M86T@5&5X=%]R95-4("1D;V-U;65N="`@5&AE(&1O8W5M96YT('=E('=I;&P@
M<F5N9&5R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VAA<G-E="`@("`@(%1H
M92!O=71P=70@8VAA<G-E="X*("`@("`J+PH@("`@9G5N8W1I;VX@9F]R;6%T
M*"8D9&]C=6UE;G0L("1C:&%R<V5T(#T@;G5L;"D*("`@('L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U1E>'0O1&EF9@``````
M````````````````````````````````````````````````````````````
M`````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M,#`P(#$P-3$U-#,S-S,U(#`R,#`R-``@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O5&5X="]$:69F+U)E;F1E<F5R````````````````````````````````
M````````````````````````````````````````,#`P-S4U(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S4@,#(Q-3<R`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B]497AT+T1I9F8O4F5N9&5R97(O:6YL:6YE
M+G!H<```````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,#0U-2`Q,#4Q-30S
M,S<S-2`P,C,V-#4`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"G)E<75I<F5?;VYC92`G5&5X="]$:69F+U)E;F1E
M<F5R+G!H<"<["@HO*BH*("H@(DEN;&EN92(@9&EF9B!R96YD97)E<BX*("H*
M("H@5&AI<R!C;&%S<R!R96YD97)S(&1I9F9S(&EN('1H92!7:6MI+7-T>6QE
M(")I;FQI;F4B(&9O<FUA="X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X
M=%]$:69F+T1I9F8O4F5N9&5R97(O:6YL:6YE+G!H<"QV(#$N-"XQ,"XQ,2`R
M,#`V+S`V+S$V(#$T.C`X.C$U(&-H=6-K($5X<"`D"B`J"B`J($!A=71H;W(@
M($-I<')I86X@4&]P;W9I8VD*("H@0'!A8VMA9V4@5&5X=%]$:69F"B`J+PIC
M;&%S<R!497AT7T1I9F9?4F5N9&5R97)?:6YL:6YE(&5X=&5N9',@5&5X=%]$
M:69F7U)E;F1E<F5R('L*"B`@("`O*BH*("`@("`J($YU;6)E<B!O9B!L96%D
M:6YG(&-O;G1E>'0@(FQI;F5S(B!T;R!P<F5S97)V92X*("`@("`J+PH@("`@
M=F%R("1?;&5A9&EN9U]C;VYT97AT7VQI;F5S(#T@,3`P,#`["@H@("`@+RHJ
M"B`@("`@*B!.=6UB97(@;V8@=')A:6QI;F<@8V]N=&5X="`B;&EN97,B('1O
M('!R97-E<G9E+@H@("`@("HO"B`@("!V87(@)%]T<F%I;&EN9U]C;VYT97AT
M7VQI;F5S(#T@,3`P,#`["@H@("`@+RHJ"B`@("`@*B!0<F5F:7@@9F]R(&EN
M<V5R=&5D('1E>'0N"B`@("`@*B\*("`@('9A<B`D7VEN<U]P<F5F:7@@/2`G
M/&EN<SXG.PH*("`@("\J*@H@("`@("H@4W5F9FEX(&9O<B!I;G-E<G1E9"!T
M97AT+@H@("`@("HO"B`@("!V87(@)%]I;G-?<W5F9FEX(#T@)SPO:6YS/B<[
M"@H@("`@+RHJ"B`@("`@*B!0<F5F:7@@9F]R(&1E;&5T960@=&5X="X*("`@
M("`J+PH@("`@=F%R("1?9&5L7W!R969I>"`]("<\9&5L/B<["@H@("`@+RHJ
M"B`@("`@*B!3=69F:7@@9F]R(&1E;&5T960@=&5X="X*("`@("`J+PH@("`@
M=F%R("1?9&5L7W-U9F9I>"`]("<\+V1E;#XG.PH*("`@("\J*@H@("`@("H@
M2&5A9&5R(&9O<B!E86-H(&-H86YG92!B;&]C:RX*("`@("`J+PH@("`@=F%R
M("1?8FQO8VM?:&5A9&5R(#T@)R<["@H@("`@+RHJ"B`@("`@*B!7:&%T(&%R
M92!W92!C=7)R96YT;'D@<W!L:71T:6YG(&]N/R!5<V5D('1O(')E8W5R<V4@
M=&\@<VAO=R!W;W)D+6QE=F5L"B`@("`@*B!C:&%N9V5S+@H@("`@("HO"B`@
M("!V87(@)%]S<&QI=%]L979E;"`]("=L:6YE<R<["@H@("`@9G5N8W1I;VX@
M7V)L;V-K2&5A9&5R*"1X8F5G+"`D>&QE;BP@)'EB96<L("1Y;&5N*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V)L;V-K7VAE861E<CL*("`@('T*
M"B`@("!F=6YC=&EO;B!?<W1A<G1";&]C:R@D:&5A9&5R*0H@("`@>PH@("`@
M("`@(')E='5R;B`D:&5A9&5R.PH@("`@?0H*("`@(&9U;F-T:6]N(%]L:6YE
M<R@D;&EN97,L("1P<F5F:7@@/2`G("<L("1E;F-O9&4@/2!T<G5E*0H@("`@
M>PH@("`@("`@(&EF("@D96YC;V1E*2!["B`@("`@("`@("`@(&%R<F%Y7W=A
M;&LH)&QI;F5S+"!A<G)A>2@F)'1H:7,L("=?96YC;V1E)RDI.PH@("`@("`@
M('T*"B`@("`@("`@:68@*"1T:&ES+3Y?<W!L:71?;&5V96P@/3T@)W=O<F1S
M)RD@>PH@("`@("`@("`@("!R971U<FX@:6UP;&]D92@G)RP@)&QI;F5S*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@:6UP;&]D92@B
M7&XB+"`D;&EN97,I("X@(EQN(CL*("`@("`@("!]"B`@("!]"@H@("`@9G5N
M8W1I;VX@7V%D9&5D*"1L:6YE<RD*("`@('L*("`@("`@("!A<G)A>5]W86QK
M*"1L:6YE<RP@87)R87DH)B1T:&ES+"`G7V5N8V]D92<I*3L*("`@("`@("`D
M;&EN97-;,%T@/2`D=&AI<RT^7VEN<U]P<F5F:7@@+B`D;&EN97-;,%T["B`@
M("`@("`@)&QI;F5S6V-O=6YT*"1L:6YE<RD@+2`Q72`N/2`D=&AI<RT^7VEN
M<U]S=69F:7@["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;&EN97,H)&QI;F5S
M+"`G("<L(&9A;'-E*3L*("`@('T*"B`@("!F=6YC=&EO;B!?9&5L971E9"@D
M;&EN97,L("1W;W)D<R`](&9A;'-E*0H@("`@>PH@("`@("`@(&%R<F%Y7W=A
M;&LH)&QI;F5S+"!A<G)A>2@F)'1H:7,L("=?96YC;V1E)RDI.PH@("`@("`@
M("1L:6YE<ULP72`]("1T:&ES+3Y?9&5L7W!R969I>"`N("1L:6YE<ULP73L*
M("`@("`@("`D;&EN97-;8V]U;G0H)&QI;F5S*2`M(#%=("X]("1T:&ES+3Y?
M9&5L7W-U9F9I>#L*("`@("`@("!R971U<FX@)'1H:7,M/E]L:6YE<R@D;&EN
M97,L("<@)RP@9F%L<V4I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]C:&%N9V5D
M*"1O<FEG+"`D9FEN86PI"B`@("!["B`@("`@("`@+RH@268@=V4G=F4@86QR
M96%D>2!S<&QI="!O;B!W;W)D<RP@9&]N)W0@=')Y('1O(&1O('-O(&%G86EN
M("T@:G5S=`H@("`@("`@("`J(&1I<W!L87DN("HO"B`@("`@("`@:68@*"1T
M:&ES+3Y?<W!L:71?;&5V96P@/3T@)W=O<F1S)RD@>PH@("`@("`@("`@("`D
M<')E9FEX(#T@)R<["B`@("`@("`@("`@('=H:6QE("@D;W)I9ULP72`A/3T@
M9F%L<V4@)B8@)&9I;F%L6S!=("$]/2!F86QS92`F)@H@("`@("`@("`@("`@
M("`@("`@<W5B<W1R*"1O<FEG6S!=+"`P+"`Q*2`]/2`G("<@)B8*("`@("`@
M("`@("`@("`@("`@('-U8G-T<B@D9FEN86Q;,%TL(#`L(#$I(#T]("<@)RD@
M>PH@("`@("`@("`@("`@("`@)'!R969I>"`N/2!S=6)S='(H)&]R:6=;,%TL
M(#`L(#$I.PH@("`@("`@("`@("`@("`@)&]R:6=;,%T@/2!S=6)S='(H)&]R
M:6=;,%TL(#$I.PH@("`@("`@("`@("`@("`@)&9I;F%L6S!=(#T@<W5B<W1R
M*"1F:6YA;%LP72P@,2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T
M=7)N("1P<F5F:7@@+B`D=&AI<RT^7V1E;&5T960H)&]R:6<I("X@)'1H:7,M
M/E]A9&1E9"@D9FEN86PI.PH@("`@("`@('T*"B`@("`@("`@)'1E>'0Q(#T@
M:6UP;&]D92@B7&XB+"`D;W)I9RD["B`@("`@("`@)'1E>'0R(#T@:6UP;&]D
M92@B7&XB+"`D9FEN86PI.PH*("`@("`@("`O*B!.;VXM<')I;G1I;F<@;F5W
M;&EN92!M87)K97(N("HO"B`@("`@("`@)&YL(#T@(EPP(CL*"B`@("`@("`@
M+RH@5V4@=V%N="!T;R!S<&QI="!O;B!W;W)D(&)O=6YD87)I97,L(&)U="!W
M92!N965D('1O"B`@("`@("`@("H@<')E<V5R=F4@=VAI=&5S<&%C92!A<R!W
M96QL+B!4:&5R969O<F4@=V4@<W!L:70@;VX@=V]R9',L"B`@("`@("`@("H@
M8G5T(&EN8VQU9&4@86QL(&)L;V-K<R!O9B!W:&ET97-P86-E(&EN('1H92!W
M;W)D;&ES="X@*B\*("`@("`@("`D9&EF9B`]("9N97<@5&5X=%]$:69F*"1T
M:&ES+3Y?<W!L:71/;E=O<F1S*"1T97AT,2P@)&YL*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<W!L:71/;E=O<F1S*"1T97AT
M,BP@)&YL*2D["@H@("`@("`@("\J($=E="!T:&4@9&EF9B!I;B!I;FQI;F4@
M9F]R;6%T+B`J+PH@("`@("`@("1R96YD97)E<B`]("9N97<@5&5X=%]$:69F
M7U)E;F1E<F5R7VEN;&EN92AA<G)A>5]M97)G92@D=&AI<RT^9V5T4&%R86US
M*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=S<&QI=%]L979E;"<@/3X@
M)W=O<F1S)RDI*3L*"B`@("`@("`@+RH@4G5N('1H92!D:69F(&%N9"!G970@
M=&AE(&]U='!U="X@*B\*("`@("`@("!R971U<FX@<W1R7W)E<&QA8V4H)&YL
M+"`B7&XB+"`D<F5N9&5R97(M/G)E;F1E<B@D9&EF9BDI("X@(EQN(CL*("`@
M('T*"B`@("!F=6YC=&EO;B!?<W!L:71/;E=O<F1S*"1S=')I;F<L("1N97=L
M:6YE17-C87!E(#T@(EQN(BD*("`@('L*("`@("`@("`O+R!)9VYO<F4@7#`[
M(&]T:&5R=VES92!T:&4@=VAI;&4@;&]O<"!W:6QL(&YE=F5R(&9I;FES:"X*
M("`@("`@("`D<W1R:6YG(#T@<W1R7W)E<&QA8V4H(EPP(BP@)R<L("1S=')I
M;F<I.PH*("`@("`@("`D=V]R9',@/2!A<G)A>2@I.PH@("`@("`@("1L96YG
M=&@@/2!S=')L96XH)'-T<FEN9RD["B`@("`@("`@)'!O<R`](#`["@H@("`@
M("`@('=H:6QE("@D<&]S(#P@)&QE;F=T:"D@>PH@("`@("`@("`@("`O+R!%
M870@82!W;W)D('=I=&@@86YY('!R96-E9&EN9R!W:&ET97-P86-E+@H@("`@
M("`@("`@("`D<W!A8V5S(#T@<W1R<W!N*'-U8G-T<B@D<W1R:6YG+"`D<&]S
M*2P@(B!<;B(I.PH@("`@("`@("`@("`D;F5X='!O<R`]('-T<F-S<&XH<W5B
M<W1R*"1S=')I;F<L("1P;W,@*R`D<W!A8V5S*2P@(B!<;B(I.PH@("`@("`@
M("`@("`D=V]R9'-;72`]('-T<E]R97!L86-E*")<;B(L("1N97=L:6YE17-C
M87!E+"!S=6)S='(H)'-T<FEN9RP@)'!O<RP@)'-P86-E<R`K("1N97AT<&]S
M*2D["B`@("`@("`@("`@("1P;W,@*ST@)'-P86-E<R`K("1N97AT<&]S.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1W;W)D<SL*("`@('T*"B`@("!F
M=6YC=&EO;B!?96YC;V1E*"8D<W1R:6YG*0H@("`@>PH@("`@("`@("1S=')I
M;F<@/2!H=&UL<W!E8VEA;&-H87)S*"1S=')I;F<I.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+U1E>'0O1&EF9B]296YD97)E<B]U;FEF:65D+G!H<```````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,3`P(#$P-3$U-#,S-S,U(#`R,S<W
M-@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*<F5Q=6ER95]O;F-E("=497AT+T1I9F8O4F5N9&5R97(N<&AP)SL*
M"B\J*@H@*B`B56YI9FEE9"(@9&EF9B!R96YD97)E<BX*("H*("H@5&AI<R!C
M;&%S<R!R96YD97)S('1H92!D:69F(&EN(&-L87-S:6,@(G5N:69I960@9&EF
M9B(@9F]R;6%T+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]497AT7T1I9F8O
M1&EF9B]296YD97)E<B]U;FEF:65D+G!H<"QV(#$N,RXQ,"XS(#(P,#8O,#$O
M,#@@,#$Z,S<Z,C`@:F%N($5X<"`D"B`J"B`J($!P86-K86=E(%1E>'1?1&EF
M9@H@*B\*8VQA<W,@5&5X=%]$:69F7U)E;F1E<F5R7W5N:69I960@97AT96YD
M<R!497AT7T1I9F9?4F5N9&5R97(@>PH*("`@("\J*@H@("`@("H@3G5M8F5R
M(&]F(&QE861I;F<@8V]N=&5X="`B;&EN97,B('1O('!R97-E<G9E+@H@("`@
M("HO"B`@("!V87(@)%]L96%D:6YG7V-O;G1E>'1?;&EN97,@/2`T.PH*("`@
M("\J*@H@("`@("H@3G5M8F5R(&]F('1R86EL:6YG(&-O;G1E>'0@(FQI;F5S
M(B!T;R!P<F5S97)V92X*("`@("`J+PH@("`@=F%R("1?=')A:6QI;F=?8V]N
M=&5X=%]L:6YE<R`](#0["@H@("`@9G5N8W1I;VX@7V)L;V-K2&5A9&5R*"1X
M8F5G+"`D>&QE;BP@)'EB96<L("1Y;&5N*0H@("`@>PH@("`@("`@(&EF("@D
M>&QE;B`A/2`Q*2!["B`@("`@("`@("`@("1X8F5G("X]("<L)R`N("1X;&5N
M.PH@("`@("`@('T*("`@("`@("!I9B`H)'EL96X@(3T@,2D@>PH@("`@("`@
M("`@("`D>6)E9R`N/2`G+"<@+B`D>6QE;CL*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N(")`0"`M)'AB96<@*R1Y8F5G($!`(CL*("`@('T*"B`@("!F=6YC
M=&EO;B!?861D960H)&QI;F5S*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^7VQI;F5S*"1L:6YE<RP@)RLG*3L*("`@('T*"B`@("!F=6YC=&EO;B!?
M9&5L971E9"@D;&EN97,I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M;&EN97,H)&QI;F5S+"`G+2<I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]C:&%N
M9V5D*"1O<FEG+"`D9FEN86PI"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?9&5L971E9"@D;W)I9RD@+B`D=&AI<RT^7V%D9&5D*"1F:6YA;"D["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O5&5X="]$:69F+U)E
M;F1E<F5R+G!H<```````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,3(V,S,@,3`U,34T,S,W,S4@,#(R,S8W`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B!!(&-L87-S('1O
M(')E;F1E<B!$:69F<R!I;B!D:69F97)E;G0@9F]R;6%T<RX*("H*("H@5&AI
M<R!C;&%S<R!R96YD97)S('1H92!D:69F(&EN(&-L87-S:6,@9&EF9B!F;W)M
M870N($ET(&ES(&EN=&5N9&5D('1H870*("H@=&AI<R!C;&%S<R!B92!C=7-T
M;VUI>F5D('9I82!I;FAE<FET86YC92P@=&\@;V)T86EN(&9A;F-I97(@;W5T
M<'5T<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]$:69F+T1I9F8O
M4F5N9&5R97(N<&AP+'8@,2XU+C$P+C<@,C`P-2\Q,B\Q-B`Q,3HT-#HP,"!J
M86X@17AP("0*("H*("H@0'!A8VMA9V4@5&5X=%]$:69F"B`J+PIC;&%S<R!4
M97AT7T1I9F9?4F5N9&5R97(@>PH*("`@("\J*@H@("`@("H@3G5M8F5R(&]F
M(&QE861I;F<@8V]N=&5X="`B;&EN97,B('1O('!R97-E<G9E+@H@("`@("H*
M("`@("`J(%1H:7,@<VAO=6QD(&)E(&QE9G0@870@>F5R;R!F;W(@=&AI<R!C
M;&%S<RP@8G5T('-U8F-L87-S97,@;6%Y('=A;G0@=&\*("`@("`J('-E="!T
M:&ES('1O(&]T:&5R('9A;'5E<RX*("`@("`J+PH@("`@=F%R("1?;&5A9&EN
M9U]C;VYT97AT7VQI;F5S(#T@,#L*"B`@("`O*BH*("`@("`J($YU;6)E<B!O
M9B!T<F%I;&EN9R!C;VYT97AT(")L:6YE<R(@=&\@<')E<V5R=F4N"B`@("`@
M*@H@("`@("H@5&AI<R!S:&]U;&0@8F4@;&5F="!A="!Z97)O(&9O<B!T:&ES
M(&-L87-S+"!B=70@<W5B8VQA<W-E<R!M87D@=V%N="!T;PH@("`@("H@<V5T
M('1H:7,@=&\@;W1H97(@=F%L=65S+@H@("`@("HO"B`@("!V87(@)%]T<F%I
M;&EN9U]C;VYT97AT7VQI;F5S(#T@,#L*"B`@("`O*BH*("`@("`J($-O;G-T
M<G5C=&]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!497AT7T1I9F9?4F5N9&5R
M97(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@9F]R96%C:"`H
M)'!A<F%M<R!A<R`D<&%R86T@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("1V
M(#T@)U\G("X@)'!A<F%M.PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/B1V*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/B1V(#T@)'9A;'5E.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M1V5T(&%N>2!R96YD97)E<B!P87)A;65T97)S+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@($%L;"!P87)A;65T97)S(&]F('1H:7,@<F5N9&5R97(@
M;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971087)A;7,H*0H@("`@
M>PH@("`@("`@("1P87)A;7,@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@
M*&=E=%]O8FIE8W1?=F%R<R@D=&AI<RD@87,@)&L@/3X@)'8I('L*("`@("`@
M("`@("`@:68@*"1K>S!](#T]("=?)RD@>PH@("`@("`@("`@("`@("`@)'!A
M<F%M<UMS=6)S='(H)&LL(#$I72`]("1V.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E;F1E<G,@82!D:69F+@H@("`@("H*("`@("`J($!P87)A;2!4
M97AT7T1I9F8@)&1I9F8@($$@5&5X=%]$:69F(&]B:F5C="X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&9O<FUA='1E9"!O=71P=70N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<B@D9&EF9BD*("`@('L*("`@("`@
M("`D>&D@/2`D>6D@/2`Q.PH@("`@("`@("1B;&]C:R`](&9A;'-E.PH@("`@
M("`@("1C;VYT97AT(#T@87)R87DH*3L*"B`@("`@("`@)&YL96%D(#T@)'1H
M:7,M/E]L96%D:6YG7V-O;G1E>'1?;&EN97,["B`@("`@("`@)&YT<F%I;"`]
M("1T:&ES+3Y?=')A:6QI;F=?8V]N=&5X=%]L:6YE<SL*"B`@("`@("`@)&]U
M='!U="`]("1T:&ES+3Y?<W1A<G1$:69F*"D["@H@("`@("`@("1D:69F<R`]
M("1D:69F+3YG971$:69F*"D["B`@("`@("`@9F]R96%C:"`H)&1I9F9S(&%S
M("1I(#T^("1E9&ET*2!["B`@("`@("`@("`@(&EF("AI<U]A*"1E9&ET+"`G
M5&5X=%]$:69F7T]P7V-O<'DG*2D@>PH@("`@("`@("`@("`@("`@:68@*&ES
M7V%R<F%Y*"1B;&]C:RDI('L*("`@("`@("`@("`@("`@("`@("`D:V5E<"`]
M("1I(#T](&-O=6YT*"1D:69F<RD@+2`Q(#\@)&YT<F%I;"`Z("1N;&5A9"`K
M("1N=')A:6P["B`@("`@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1E9&ET
M+3YO<FEG*2`\/2`D:V5E<"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M8FQO8VM;72`]("1E9&ET.PH@("`@("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D;G1R86EL*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D8V]N=&5X="`](&%R<F%Y7W-L:6-E
M*"1E9&ET+3YO<FEG+"`P+"`D;G1R86EL*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1B;&]C:UM=(#T@)FYE=R!497AT7T1I9F9?3W!?8V]P>2@D
M8V]N=&5X="D["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`@("`@)&]U='!U="`N/2`D=&AI<RT^7V)L;V-K*"1X,"P@
M)&YT<F%I;"`K("1X:2`M("1X,"P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1Y,"P@)&YT<F%I;"`K("1Y:2`M
M("1Y,"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1B;&]C:RD["B`@("`@("`@("`@("`@("`@("`@("`@("1B
M;&]C:R`](&9A;'-E.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1C;VYT97AT(#T@)&5D:70M/F]R
M:6<["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!I9B`H
M(6ES7V%R<F%Y*"1B;&]C:RDI('L*("`@("`@("`@("`@("`@("`@("`D8V]N
M=&5X="`](&%R<F%Y7W-L:6-E*"1C;VYT97AT+"!C;W5N="@D8V]N=&5X="D@
M+2`D;FQE860I.PH@("`@("`@("`@("`@("`@("`@("1X,"`]("1X:2`M(&-O
M=6YT*"1C;VYT97AT*3L*("`@("`@("`@("`@("`@("`@("`D>3`@/2`D>6D@
M+2!C;W5N="@D8V]N=&5X="D["B`@("`@("`@("`@("`@("`@("`@)&)L;V-K
M(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@("!I9B`H)&-O;G1E>'0I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)&)L;V-K6UT@/2`F;F5W(%1E
M>'1?1&EF9E]/<%]C;W!Y*"1C;VYT97AT*3L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D8FQO8VM;
M72`]("1E9&ET.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)&5D
M:70M/F]R:6<I('L*("`@("`@("`@("`@("`@("1X:2`K/2!C;W5N="@D961I
M="T^;W)I9RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1E9&ET
M+3YF:6YA;"D@>PH@("`@("`@("`@("`@("`@)'EI("L](&-O=6YT*"1E9&ET
M+3YF:6YA;"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF
M("AI<U]A<G)A>2@D8FQO8VLI*2!["B`@("`@("`@("`@("1O=71P=70@+CT@
M)'1H:7,M/E]B;&]C:R@D>#`L("1X:2`M("1X,"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1Y,"P@)'EI("T@)'DP+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&)L;V-K*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D;W5T<'5T("X@)'1H:7,M/E]E;F1$:69F
M*"D["B`@("!]"@H@("`@9G5N8W1I;VX@7V)L;V-K*"1X8F5G+"`D>&QE;BP@
M)'EB96<L("1Y;&5N+"`F)&5D:71S*0H@("`@>PH@("`@("`@("1O=71P=70@
M/2`D=&AI<RT^7W-T87)T0FQO8VLH)'1H:7,M/E]B;&]C:TAE861E<B@D>&)E
M9RP@)'AL96XL("1Y8F5G+"`D>6QE;BDI.PH*("`@("`@("!F;W)E86-H("@D
M961I=',@87,@)&5D:70I('L*("`@("`@("`@("`@<W=I=&-H("AS=')T;VQO
M=V5R*&=E=%]C;&%S<R@D961I="DI*2!["B`@("`@("`@("`@(&-A<V4@)W1E
M>'1?9&EF9E]O<%]C;W!Y)SH*("`@("`@("`@("`@("`@("1O=71P=70@+CT@
M)'1H:7,M/E]C;VYT97AT*"1E9&ET+3YO<FEG*3L*("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G=&5X=%]D:69F7V]P7V%D9"<Z
M"B`@("`@("`@("`@("`@("`D;W5T<'5T("X]("1T:&ES+3Y?861D960H)&5D
M:70M/F9I;F%L*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@8V%S92`G=&5X=%]D:69F7V]P7V1E;&5T92<Z"B`@("`@("`@("`@("`@
M("`D;W5T<'5T("X]("1T:&ES+3Y?9&5L971E9"@D961I="T^;W)I9RD["B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)W1E>'1?
M9&EF9E]O<%]C:&%N9V4G.@H@("`@("`@("`@("`@("`@)&]U='!U="`N/2`D
M=&AI<RT^7V-H86YG960H)&5D:70M/F]R:6<L("1E9&ET+3YF:6YA;"D["B`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1O=71P=70@+B`D=&AI<RT^7V5N9$)L;V-K*"D[
M"B`@("!]"@H@("`@9G5N8W1I;VX@7W-T87)T1&EF9B@I"B`@("!["B`@("`@
M("`@<F5T=7)N("<G.PH@("`@?0H*("`@(&9U;F-T:6]N(%]E;F1$:69F*"D*
M("`@('L*("`@("`@("!R971U<FX@)R<["B`@("!]"@H@("`@9G5N8W1I;VX@
M7V)L;V-K2&5A9&5R*"1X8F5G+"`D>&QE;BP@)'EB96<L("1Y;&5N*0H@("`@
M>PH@("`@("`@(&EF("@D>&QE;B`^(#$I('L*("`@("`@("`@("`@)'AB96<@
M+CT@)RPG("X@*"1X8F5G("L@)'AL96X@+2`Q*3L*("`@("`@("!]"B`@("`@
M("`@:68@*"1Y;&5N(#X@,2D@>PH@("`@("`@("`@("`D>6)E9R`N/2`G+"<@
M+B`H)'EB96<@*R`D>6QE;B`M(#$I.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1X8F5G("X@*"1X;&5N(#\@*"1Y;&5N(#\@)V,G(#H@)V0G*2`Z("=A
M)RD@+B`D>6)E9SL*("`@('T*"B`@("!F=6YC=&EO;B!?<W1A<G1";&]C:R@D
M:&5A9&5R*0H@("`@>PH@("`@("`@(')E='5R;B`D:&5A9&5R("X@(EQN(CL*
M("`@('T*"B`@("!F=6YC=&EO;B!?96YD0FQO8VLH*0H@("`@>PH@("`@("`@
M(')E='5R;B`G)SL*("`@('T*"B`@("!F=6YC=&EO;B!?;&EN97,H)&QI;F5S
M+"`D<')E9FEX(#T@)R`G*0H@("`@>PH@("`@("`@(')E='5R;B`D<')E9FEX
M("X@:6UP;&]D92@B7&XD<')E9FEX(BP@)&QI;F5S*2`N(")<;B(["B`@("!]
M"@H@("`@9G5N8W1I;VX@7V-O;G1E>'0H)&QI;F5S*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7VQI;F5S*"1L:6YE<RD["B`@("!]"@H@("`@9G5N
M8W1I;VX@7V%D9&5D*"1L:6YE<RD*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]L:6YE<R@D;&EN97,L("<^)RD["B`@("!]"@H@("`@9G5N8W1I;VX@
M7V1E;&5T960H)&QI;F5S*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M7VQI;F5S*"1L:6YE<RP@)SPG*3L*("`@('T*"B`@("!F=6YC=&EO;B!?8VAA
M;F=E9"@D;W)I9RP@)&9I;F%L*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^7V1E;&5T960H)&]R:6<I("X@(BTM+5QN(B`N("1T:&ES+3Y?861D960H
M)&9I;F%L*3L*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O5&5X="]$:69F+G!H<```````````````````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-C,U-30@,3`U,34T,S,W,S4@,#(P
M-C,Q`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B!497AT7T1I9F8*("H*("H@1V5N97)A;"!!4$D@9F]R
M(&=E;F5R871I;F<@86YD(&9O<FUA='1I;F<@9&EF9G,@+2!T:&4@9&EF9F5R
M96YC97,@8F5T=V5E;@H@*B!T=V\@<V5Q=65N8V5S(&]F('-T<FEN9W,N"B`J
M"B`J(%1H92!02%`@9&EF9B!C;V1E('5S960@:6X@=&AI<R!P86-K86=E('=A
M<R!O<FEG:6YA;&QY('=R:71T96X@8GD@1V5O9F9R97D*("H@5"X@1&%I<FEK
M:2!A;F0@:7,@=7-E9"!W:71H(&AI<R!P97)M:7-S:6]N+@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]497AT7T1I9F8O1&EF9BYP:'`L=B`Q+C$Q+C(N-R`R
M,#`V+S`R+S`V(#`P.C(U.C4R(&IA;B!%>'`@)`H@*@H@*B!`<&%C:V%G92!4
M97AT7T1I9F8*("H@0&%U=&AO<B`@1V5O9F9R97D@5"X@1&%I<FEK:2`\9&%I
M<FEK:4!D86ER:6MI+F]R9SX*("HO"F-L87-S(%1E>'1?1&EF9B!["@H@("`@
M+RHJ"B`@("`@*B!!<G)A>2!O9B!C:&%N9V5S+@H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1?961I=',["@H@("`@+RHJ"B`@
M("`@*B!#;VUP=71E<R!D:69F<R!B971W965N('-E<75E;F-E<R!O9B!S=')I
M;F=S+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D9G)O;5]L:6YE<R`@
M06X@87)R87D@;V8@<W1R:6YG<RX@(%1Y<&EC86QL>2!T:&5S92!A<F4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@;&EN97,@9G)O;2!A(&9I
M;&4N"B`@("`@*B!`<&%R86T@87)R87D@)'1O7VQI;F5S("`@($%N(&%R<F%Y
M(&]F('-T<FEN9W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%1E>'1?1&EF9B@D
M9G)O;5]L:6YE<RP@)'1O7VQI;F5S*0H@("`@>PH@("`@("`@(&%R<F%Y7W=A
M;&LH)&9R;VU?;&EN97,L(&%R<F%Y*"1T:&ES+"`G7W1R:6U.97=L:6YE<R<I
M*3L*("`@("`@("!A<G)A>5]W86QK*"1T;U]L:6YE<RP@87)R87DH)'1H:7,L
M("=?=')I;4YE=VQI;F5S)RDI.PH*("`@("`@("!I9B`H97AT96YS:6]N7VQO
M861E9"@G>&1I9F8G*2D@>PH@("`@("`@("`@("`D96YG:6YE(#T@)FYE=R!4
M97AT7T1I9F9?16YG:6YE7WAD:69F*"D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&5N9VEN92`]("9N97<@5&5X=%]$:69F7T5N9VEN95]N871I
M=F4H*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?961I=',@/2`D96YG
M:6YE+3YD:69F*"1F<F]M7VQI;F5S+"`D=&]?;&EN97,I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!T:&4@87)R87D@;V8@9&EF9F5R96YC97,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1I9F8H*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7V5D:71S.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0V]M<'5T97,@82!R979E<G-E9"!D:69F+@H@("`@("H*("`@("`J($5X86UP
M;&4Z"B`@("`@*B`\8V]D93X*("`@("`J("1D:69F(#T@)FYE=R!497AT7T1I
M9F8H)&QI;F5S,2P@)&QI;F5S,BD["B`@("`@*B`D<F5V(#T@)&1I9F8M/G)E
M=F5R<V4H*3L*("`@("`J(#PO8V]D93X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(%1E>'1?1&EF9B`@02!$:69F(&]B:F5C="!R97!R97-E;G1I;F<@=&AE(&EN
M=F5R<V4@;V8@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@;W)I9VEN
M86P@9&EF9BX@($YO=&4@=&AA="!W92!P=7)P;W-E;'D@9&]N)W0@<F5T=7)N
M(&$*("`@("`J("`@("`@("`@("`@("`@("`@("!R969E<F5N8V4@:&5R92P@
M<VEN8V4@=&AI<R!E<W-E;G1I86QL>2!I<R!A(&-L;VYE*"D*("`@("`J("`@
M("`@("`@("`@("`@("`@("!M971H;V0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E=F5R<V4H*0H@("`@>PH@("`@("`@(&EF("AV97)S:6]N7V-O;7!A<F4H
M>F5N9%]V97)S:6]N*"DL("<R)RP@)SXG*2D@>PH@("`@("`@("`@("`D<F5V
M(#T@8VQO;F4H)'1H:7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1R978@/2`D=&AI<SL*("`@("`@("!]"B`@("`@("`@)')E=BT^7V5D:71S
M(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V5D:71S(&%S
M("1E9&ET*2!["B`@("`@("`@("`@("1R978M/E]E9&ET<UM=(#T@)&5D:70M
M/G)E=F5R<V4H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R978["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@9F]R(&%N(&5M<'1Y(&1I9F8N
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1W;R!S
M97%U96YC97,@=V5R92!I9&5N=&EC86PN"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&ES16UP='DH*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?961I
M=',@87,@)&5D:70I('L*("`@("`@("`@("`@:68@*"%I<U]A*"1E9&ET+"`G
M5&5X=%]$:69F7T]P7V-O<'DG*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]M<'5T97,@=&AE(&QE
M;F=T:"!O9B!T:&4@3&]N9V5S="!#;VUM;VX@4W5B<V5Q=65N8V4@*$Q#4RDN
M"B`@("`@*@H@("`@("H@5&AI<R!I<R!M;W-T;'D@9F]R(&1I86=N;W-T:6,@
M<'5R<&]S97,N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@
M;&5N9W1H(&]F('1H92!,0U,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QC<R@I
M"B`@("!["B`@("`@("`@)&QC<R`](#`["B`@("`@("`@9F]R96%C:"`H)'1H
M:7,M/E]E9&ET<R!A<R`D961I="D@>PH@("`@("`@("`@("!I9B`H:7-?82@D
M961I="P@)U1E>'1?1&EF9E]/<%]C;W!Y)RDI('L*("`@("`@("`@("`@("`@
M("1L8W,@*ST@8V]U;G0H)&5D:70M/F]R:6<I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D;&-S.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1V5T<R!T:&4@;W)I9VEN86P@<V5T(&]F(&QI;F5S+@H@("`@("H*
M("`@("`J(%1H:7,@<F5C;VYS=')U8W1S('1H92`D9G)O;5]L:6YE<R!P87)A
M;65T97(@<&%S<V5D('1O('1H92!C;VYS=')U8W1O<BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("!4:&4@;W)I9VEN86P@<V5Q=65N8V4@;V8@<W1R
M:6YG<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3W)I9VEN86PH*0H@("`@
M>PH@("`@("`@("1L:6YE<R`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H
M)'1H:7,M/E]E9&ET<R!A<R`D961I="D@>PH@("`@("`@("`@("!I9B`H)&5D
M:70M/F]R:6<I('L*("`@("`@("`@("`@("`@(&%R<F%Y7W-P;&EC92@D;&EN
M97,L(&-O=6YT*"1L:6YE<RDL(#`L("1E9&ET+3YO<FEG*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@)&QI;F5S.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1V5T<R!T:&4@9FEN86P@<V5T(&]F(&QI;F5S+@H@
M("`@("H*("`@("`J(%1H:7,@<F5C;VYS=')U8W1S('1H92`D=&]?;&EN97,@
M<&%R86UE=&5R('!A<W-E9"!T;R!T:&4@8V]N<W1R=6-T;W(N"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>2`@5&AE('-E<75E;F-E(&]F('-T<FEN9W,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$9I;F%L*"D*("`@('L*("`@("`@
M("`D;&EN97,@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?
M961I=',@87,@)&5D:70I('L*("`@("`@("`@("`@:68@*"1E9&ET+3YF:6YA
M;"D@>PH@("`@("`@("`@("`@("`@87)R87E?<W!L:6-E*"1L:6YE<RP@8V]U
M;G0H)&QI;F5S*2P@,"P@)&5D:70M/F9I;F%L*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!R971U<FX@)&QI;F5S.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5M;W9E<R!T<F%I;&EN9R!N97=L:6YE<R!F<F]M(&$@;&EN
M92!O9B!T97AT+B!4:&ES(&ES(&UE86YT('1O(&)E('5S960*("`@("`J('=I
M=&@@87)R87E?=V%L:R@I+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&QI;F4@(%1H92!L:6YE('1O('1R:6TN"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D:V5Y("!4:&4@:6YD97@@;V8@=&AE(&QI;F4@:6X@=&AE(&%R<F%Y+B!.
M;W0@=7-E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7W1R:6U.97=L:6YE<R@F
M)&QI;F4L("1K97DI"B`@("!["B`@("`@("`@)&QI;F4@/2!S=')?<F5P;&%C
M92AA<G)A>2@B7&XB+"`B7'(B*2P@)R<L("1L:6YE*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($-H96-K<R!A(&1I9F8@9F]R('9A;&ED:71Y+@H@("`@("H*
M("`@("`J(%1H:7,@:7,@:&5R92!O;FQY(&9O<B!D96)U9V=I;F<@<'5R<&]S
M97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C:&5C:R@D9G)O;5]L:6YE<RP@
M)'1O7VQI;F5S*0H@("`@>PH@("`@("`@(&EF("AS97)I86QI>F4H)&9R;VU?
M;&EN97,I("$]('-E<FEA;&EZ92@D=&AI<RT^9V5T3W)I9VEN86PH*2DI('L*
M("`@("`@("`@("`@=')I9V=E<E]E<G)O<B@B4F5C;VYS=')U8W1E9"!O<FEG
M:6YA;"!D;V5S;B=T(&UA=&-H(BP@15]54T527T524D]2*3L*("`@("`@("!]
M"B`@("`@("`@:68@*'-E<FEA;&EZ92@D=&]?;&EN97,I("$]('-E<FEA;&EZ
M92@D=&AI<RT^9V5T1FEN86PH*2DI('L*("`@("`@("`@("`@=')I9V=E<E]E
M<G)O<B@B4F5C;VYS=')U8W1E9"!F:6YA;"!D;V5S;B=T(&UA=&-H(BP@15]5
M4T527T524D]2*3L*("`@("`@("!]"@H@("`@("`@("1R978@/2`D=&AI<RT^
M<F5V97)S92@I.PH@("`@("`@(&EF("AS97)I86QI>F4H)'1O7VQI;F5S*2`A
M/2!S97)I86QI>F4H)')E=BT^9V5T3W)I9VEN86PH*2DI('L*("`@("`@("`@
M("`@=')I9V=E<E]E<G)O<B@B4F5V97)S960@;W)I9VEN86P@9&]E<VXG="!M
M871C:"(L($5?55-%4E]%4E)/4BD["B`@("`@("`@?0H@("`@("`@(&EF("AS
M97)I86QI>F4H)&9R;VU?;&EN97,I("$]('-E<FEA;&EZ92@D<F5V+3YG971&
M:6YA;"@I*2D@>PH@("`@("`@("`@("!T<FEG9V5R7V5R<F]R*")2979E<G-E
M9"!F:6YA;"!D;V5S;B=T(&UA=&-H(BP@15]54T527T524D]2*3L*("`@("`@
M("!]"@H@("`@("`@("1P<F5V='EP92`](&YU;&P["B`@("`@("`@9F]R96%C
M:"`H)'1H:7,M/E]E9&ET<R!A<R`D961I="D@>PH@("`@("`@("`@("!I9B`H
M)'!R979T>7!E(#T](&=E=%]C;&%S<R@D961I="DI('L*("`@("`@("`@("`@
M("`@('1R:6=G97)?97)R;W(H(D5D:70@<V5Q=65N8V4@:7,@;F]N+6]P=&EM
M86PB+"!%7U5315)?15)23U(I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1P<F5V='EP92`](&=E=%]C;&%S<R@D961I="D["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@=')U93L*("`@('T*"GT*"B\J*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]497AT7T1I9F8O1&EF9BYP:'`L=B`Q+C$Q+C(N-R`R,#`V+S`R
M+S`V(#`P.C(U.C4R(&IA;B!%>'`@)`H@*@H@*B!`<&%C:V%G92!497AT7T1I
M9F8*("H@0&%U=&AO<B`@1V5O9F9R97D@5"X@1&%I<FEK:2`\9&%I<FEK:4!D
M86ER:6MI+F]R9SX*("HO"F-L87-S(%1E>'1?36%P<&5D1&EF9B!E>'1E;F1S
M(%1E>'1?1&EF9B!["@H@("`@+RHJ"B`@("`@*B!#;VUP=71E<R!A(&1I9F8@
M8F5T=V5E;B!S97%U96YC97,@;V8@<W1R:6YG<RX*("`@("`J"B`@("`@*B!4
M:&ES(&-A;B!B92!U<V5D('1O(&-O;7!U=&4@=&AI;F=S(&QI:V4@8V%S92UI
M;G-E;G-I='9E(&1I9F9S+"!O<B!D:69F<PH@("`@("H@=VAI8V@@:6=N;W)E
M(&-H86YG97,@:6X@=VAI=&4M<W!A8V4N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1F<F]M7VQI;F5S("`@("`@("`@06X@87)R87D@;V8@<W1R:6YG
M<RX*("`@("`J($!P87)A;2!A<G)A>2`D=&]?;&EN97,@("`@("`@("`@($%N
M(&%R<F%Y(&]F('-T<FEN9W,N"B`@("`@*B!`<&%R86T@87)R87D@)&UA<'!E
M9%]F<F]M7VQI;F5S("!4:&ES(&%R<F%Y('-H;W5L9"!H879E('1H92!S86UE
M('-I>F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&YU;6)E<B!O9B!E;&5M96YT<R!A<R`D9G)O;5]L:6YE<RX@(%1H90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@96QE;65N=',@
M:6X@)&UA<'!E9%]F<F]M7VQI;F5S(&%N9`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&UA<'!E9%]T;U]L:6YE<R!A<F4@=VAA
M="!I<R!A8W1U86QL>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8V]M<&%R960@=VAE;B!C;VUP=71I;F<@=&AE(&1I9F8N"B`@
M("`@*B!`<&%R86T@87)R87D@)&UA<'!E9%]T;U]L:6YE<R`@("!4:&ES(&%R
M<F%Y('-H;W5L9"!H879E('1H92!S86UE(&YU;6)E<@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@;V8@96QE;65N=',@87,@)'1O
M7VQI;F5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!497AT7TUA<'!E9$1I9F8H
M)&9R;VU?;&EN97,L("1T;U]L:6YE<RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D;6%P<&5D7V9R;VU?;&EN97,L("1M87!P961?=&]?;&EN97,I
M"B`@("!["B`@("`@("`@87-S97)T*&-O=6YT*"1F<F]M7VQI;F5S*2`]/2!C
M;W5N="@D;6%P<&5D7V9R;VU?;&EN97,I*3L*("`@("`@("!A<W-E<G0H8V]U
M;G0H)'1O7VQI;F5S*2`]/2!C;W5N="@D;6%P<&5D7W1O7VQI;F5S*2D["@H@
M("`@("`@('!A<F5N=#HZ5&5X=%]$:69F*"1M87!P961?9G)O;5]L:6YE<RP@
M)&UA<'!E9%]T;U]L:6YE<RD["@H@("`@("`@("1X:2`]("1Y:2`](#`["B`@
M("`@("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)'1H:7,M/E]E9&ET<RD[
M("1I*RLI('L*("`@("`@("`@("`@)&]R:6<@/2`F)'1H:7,M/E]E9&ET<ULD
M:5TM/F]R:6<["B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D;W)I9RDI('L*
M("`@("`@("`@("`@("`@("1O<FEG(#T@87)R87E?<VQI8V4H)&9R;VU?;&EN
M97,L("1X:2P@8V]U;G0H)&]R:6<I*3L*("`@("`@("`@("`@("`@("1X:2`K
M/2!C;W5N="@D;W)I9RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1F
M:6YA;"`]("8D=&AI<RT^7V5D:71S6R1I72T^9FEN86P["B`@("`@("`@("`@
M(&EF("AI<U]A<G)A>2@D9FEN86PI*2!["B`@("`@("`@("`@("`@("`D9FEN
M86P@/2!A<G)A>5]S;&EC92@D=&]?;&EN97,L("1Y:2P@8V]U;G0H)&9I;F%L
M*2D["B`@("`@("`@("`@("`@("`D>6D@*ST@8V]U;G0H)&9I;F%L*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@('T*"GT*"B\J*@H@*B!#;&%S<R!U
M<V5D(&EN=&5R;F%L;'D@8GD@1&EF9B!T;R!A8W1U86QL>2!C;VUP=71E('1H
M92!D:69F<RX@(%1H:7,@8VQA<W,*("H@=7-E<R!T:&4@>&1I9F8@4$5#3"!P
M86-K86=E("AH='1P.B\O<&5C;"YP:'`N;F5T+W!A8VMA9V4O>&1I9F8I('1O
M(&-O;7!U=&4*("H@=&AE(&1I9F9E<F5N8V5S(&)E='=E96X@=&AE('1W;R!I
M;G!U="!A<G)A>7,N"B`J"B`J($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!H
M;W)D92YO<F<^"B`J($!P86-K86=E(%1E>'1?1&EF9@H@*@H@*B!`86-C97-S
M('!R:79A=&4*("HO"F-L87-S(%1E>'1?1&EF9E]%;F=I;F5?>&1I9F8@>PH*
M("`@(&9U;F-T:6]N(&1I9F8H)&9R;VU?;&EN97,L("1T;U]L:6YE<RD*("`@
M('L*("`@("`@("`O*B!#;VYV97)T('1H92!T=V\@:6YP=70@87)R87ES(&EN
M=&\@<W1R:6YG<R!F;W(@>&1I9F8@<')O8V5S<VEN9RX@*B\*("`@("`@("`D
M9G)O;5]S=')I;F<@/2!I;7!L;V1E*")<;B(L("1F<F]M7VQI;F5S*3L*("`@
M("`@("`D=&]?<W1R:6YG(#T@:6UP;&]D92@B7&XB+"`D=&]?;&EN97,I.PH*
M("`@("`@("`O*B!$:69F('1H92!T=V\@<W1R:6YG<R!A;F0@8V]N=F5R="!T
M:&4@<F5S=6QT('1O(&%N(&%R<F%Y+B`J+PH@("`@("`@("1D:69F(#T@>&1I
M9F9?<W1R:6YG7V1I9F8H)&9R;VU?<W1R:6YG+"`D=&]?<W1R:6YG+"!C;W5N
M="@D=&]?;&EN97,I*3L*("`@("`@("`D9&EF9B`](&5X<&QO9&4H(EQN(BP@
M)&1I9F8I.PH*("`@("`@("`O*B!786QK('1H<F]U9V@@=&AE(&1I9F8@;VYE
M(&QI;F4@870@82!T:6UE+B`@5V4@8G5I;&0@=&AE("1E9&ET<PH@("`@("`@
M("`J(&%R<F%Y(&]F(&1I9F8@;W!E<F%T:6]N<R!B>2!R96%D:6YG('1H92!F
M:7)S="!C:&%R86-T97(@;V8@=&AE"B`@("`@("`@("H@>&1I9F8@;W5T<'5T
M("AW:&EC:"!I<R!I;B!T:&4@(G5N:69I960@9&EF9B(@9F]R;6%T*2X*("`@
M("`@("`@*@H@("`@("`@("`J($YO=&4@=&AA="!W92!D;VXG="!H879E(&5N
M;W5G:"!I;F9O<FUA=&EO;B!T;R!D971E8W0@(F-H86YG960B"B`@("`@("`@
M("H@;&EN97,@=7-I;F<@=&AI<R!A<'!R;V%C:"P@<V\@=V4@8V%N)W0@861D
M(%1E>'1?1&EF9E]/<%]C:&%N9V5D"B`@("`@("`@("H@:6YS=&%N8V5S('1O
M('1H92`D961I=',@87)R87DN("!4:&4@<F5S=6QT(&ES('-T:6QL('!E<F9E
M8W1L>0H@("`@("`@("`J('9A;&ED+"!A;&)E:70@82!L:71T;&4@;&5S<R!D
M97-C<FEP=&EV92!A;F0@969F:6-I96YT+B`J+PH@("`@("`@("1E9&ET<R`]
M(&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)&1I9F8@87,@)&QI;F4I('L*
M("`@("`@("`@("`@<W=I=&-H("@D;&EN95LP72D@>PH@("`@("`@("`@("!C
M87-E("<@)SH*("`@("`@("`@("`@("`@("1E9&ET<UM=(#T@)FYE=R!497AT
M7T1I9F9?3W!?8V]P>2AA<G)A>2AS=6)S='(H)&QI;F4L(#$I*2D["B`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)RLG.@H@("`@
M("`@("`@("`@("`@)&5D:71S6UT@/2`F;F5W(%1E>'1?1&EF9E]/<%]A9&0H
M87)R87DH<W5B<W1R*"1L:6YE+"`Q*2DI.PH@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("!C87-E("<M)SH*("`@("`@("`@("`@("`@("1E
M9&ET<UM=(#T@)FYE=R!497AT7T1I9F9?3W!?9&5L971E*&%R<F%Y*'-U8G-T
M<B@D;&EN92P@,2DI*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&5D:71S.PH@("`@
M?0H*?0H*+RHJ"B`J($-L87-S('5S960@:6YT97)N86QL>2!B>2!$:69F('1O
M(&%C='5A;&QY(&-O;7!U=&4@=&AE(&1I9F9S+B`@5&AI<R!C;&%S<R!I<PH@
M*B!I;7!L96UE;G1E9"!U<VEN9R!N871I=F4@4$A0(&-O9&4N"B`J"B`J(%1H
M92!A;&=O<FET:&T@=7-E9"!H97)E(&ES(&UO<W1L>2!L:69T960@9G)O;2!T
M:&4@<&5R;"!M;V1U;&4*("H@06QG;W)I=&AM.CI$:69F("AV97)S:6]N(#$N
M,#8I(&)Y($YE9"!+;VYZ+"!W:&EC:"!I<R!A=F%I;&%B;&4@870Z"B`J(&AT
M='`Z+R]W=W<N<&5R;"YC;VTO0U!!3B]A=71H;W)S+VED+TXO3D4O3D5$2T].
M6B]!;&=O<FET:&TM1&EF9BTQ+C`V+GII<`H@*@H@*B!-;W)E(&ED96%S(&%R
M92!T86ME;B!F<F]M.@H@*B!H='1P.B\O=W=W+FEC<RYU8VDN961U+WYE<'!S
M=&5I;B\Q-C$O.38P,C(Y+FAT;6P*("H*("H@4V]M92!I9&5A<R`H86YD(&$@
M8FET(&]F(&-O9&4I(&%R92!T86ME;B!F<F]M(&%N86QY>F4N8RP@;V8@1TY5
M"B`J(&1I9F9U=&EL<RTR+C<L('=H:6-H(&-A;B!B92!F;W5N9"!A=#H*("H@
M9G1P.B\O9VYU9&ES="YG;G4N;W)G+W!U8B]G;G4O9&EF9G5T:6QS+V1I9F9U
M=&EL<RTR+C<N=&%R+F=Z"B`J"B`J(%-O;64@:61E87,@*'-U8F1I=FES:6]N
M(&)Y($Y#2%5.2U,@/B`R+"!A;F0@<V]M92!O<'1I;6EZ871I;VYS*2!A<F4@
M9G)O;0H@*B!'96]F9G)E>2!4+B!$86ER:6MI(#QD86ER:6MI0&1A:7)I:VDN
M;W)G/BX@5&AE(&]R:6=I;F%L(%!(4"!V97)S:6]N(&]F('1H:7,*("H@8V]D
M92!W87,@=W)I='1E;B!B>2!H:6TL(&%N9"!I<R!U<V5D+V%D87!T960@=VET
M:"!H:7,@<&5R;6ES<VEO;BX*("H*("H@0&%U=&AO<B`@1V5O9F9R97D@5"X@
M1&%I<FEK:2`\9&%I<FEK:4!D86ER:6MI+F]R9SX*("H@0'!A8VMA9V4@5&5X
M=%]$:69F"B`J"B`J($!A8V-E<W,@<')I=F%T90H@*B\*8VQA<W,@5&5X=%]$
M:69F7T5N9VEN95]N871I=F4@>PH*("`@(&9U;F-T:6]N(&1I9F8H)&9R;VU?
M;&EN97,L("1T;U]L:6YE<RD*("`@('L*("`@("`@("`D;E]F<F]M(#T@8V]U
M;G0H)&9R;VU?;&EN97,I.PH@("`@("`@("1N7W1O(#T@8V]U;G0H)'1O7VQI
M;F5S*3L*"B`@("`@("`@)'1H:7,M/GAC:&%N9V5D(#T@)'1H:7,M/GEC:&%N
M9V5D(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^>'8@/2`D=&AI<RT^>78@
M/2!A<G)A>2@I.PH@("`@("`@("1T:&ES+3YX:6YD(#T@)'1H:7,M/GEI;F0@
M/2!A<G)A>2@I.PH@("`@("`@('5N<V5T*"1T:&ES+3YS97$I.PH@("`@("`@
M('5N<V5T*"1T:&ES+3YI;E]S97$I.PH@("`@("`@('5N<V5T*"1T:&ES+3YL
M8W,I.PH*("`@("`@("`O+R!3:VEP(&QE861I;F<@8V]M;6]N(&QI;F5S+@H@
M("`@("`@(&9O<B`H)'-K:7`@/2`P.R`D<VMI<"`\("1N7V9R;VT@)B8@)'-K
M:7`@/"`D;E]T;SL@)'-K:7`K*RD@>PH@("`@("`@("`@("!I9B`H)&9R;VU?
M;&EN97-;)'-K:7!=("$]/2`D=&]?;&EN97-;)'-K:7!=*2!["B`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI
M<RT^>&-H86YG961;)'-K:7!=(#T@)'1H:7,M/GEC:&%N9V5D6R1S:VEP72`]
M(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+R\@4VMI<"!T<F%I;&EN9R!C
M;VUM;VX@;&EN97,N"B`@("`@("`@)'AI(#T@)&Y?9G)O;3L@)'EI(#T@)&Y?
M=&\["B`@("`@("`@9F]R("@D96YD<VMI<"`](#`[("TM)'AI(#X@)'-K:7`@
M)B8@+2TD>6D@/B`D<VMI<#L@)&5N9'-K:7`K*RD@>PH@("`@("`@("`@("!I
M9B`H)&9R;VU?;&EN97-;)'AI72`A/3T@)'1O7VQI;F5S6R1Y:5TI('L*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1T:&ES+3YX8VAA;F=E9%LD>&E=(#T@)'1H:7,M/GEC:&%N9V5D6R1Y:5T@
M/2!F86QS93L*("`@("`@("!]"@H@("`@("`@("\O($EG;F]R92!L:6YE<R!W
M:&EC:"!D;R!N;W0@97AI<W0@:6X@8F]T:"!F:6QE<RX*("`@("`@("!F;W(@
M*"1X:2`]("1S:VEP.R`D>&D@/"`D;E]F<F]M("T@)&5N9'-K:7`[("1X:2LK
M*2!["B`@("`@("`@("`@("1X:&%S:%LD9G)O;5]L:6YE<ULD>&E=72`](#$[
M"B`@("`@("`@?0H@("`@("`@(&9O<B`H)'EI(#T@)'-K:7`[("1Y:2`\("1N
M7W1O("T@)&5N9'-K:7`[("1Y:2LK*2!["B`@("`@("`@("`@("1L:6YE(#T@
M)'1O7VQI;F5S6R1Y:5T["B`@("`@("`@("`@(&EF("@H)'1H:7,M/GEC:&%N
M9V5D6R1Y:5T@/2!E;7!T>2@D>&AA<VA;)&QI;F5=*2DI('L*("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1Y
M:&%S:%LD;&EN95T@/2`Q.PH@("`@("`@("`@("`D=&AI<RT^>79;72`]("1L
M:6YE.PH@("`@("`@("`@("`D=&AI<RT^>6EN9%M=(#T@)'EI.PH@("`@("`@
M('T*("`@("`@("!F;W(@*"1X:2`]("1S:VEP.R`D>&D@/"`D;E]F<F]M("T@
M)&5N9'-K:7`[("1X:2LK*2!["B`@("`@("`@("`@("1L:6YE(#T@)&9R;VU?
M;&EN97-;)'AI73L*("`@("`@("`@("`@:68@*"@D=&AI<RT^>&-H86YG961;
M)'AI72`](&5M<'1Y*"1Y:&%S:%LD;&EN95TI*2D@>PH@("`@("`@("`@("`@
M("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M
M/GAV6UT@/2`D;&EN93L*("`@("`@("`@("`@)'1H:7,M/GAI;F1;72`]("1X
M:3L*("`@("`@("!]"@H@("`@("`@("\O($9I;F0@=&AE($Q#4RX*("`@("`@
M("`D=&AI<RT^7V-O;7!A<F5S97$H,"P@8V]U;G0H)'1H:7,M/GAV*2P@,"P@
M8V]U;G0H)'1H:7,M/GEV*2D["@H@("`@("`@("\O($UE<F=E(&5D:71S('=H
M96X@<&]S<VEB;&4N"B`@("`@("`@)'1H:7,M/E]S:&EF=$)O=6YD87)I97,H
M)&9R;VU?;&EN97,L("1T:&ES+3YX8VAA;F=E9"P@)'1H:7,M/GEC:&%N9V5D
M*3L*("`@("`@("`D=&AI<RT^7W-H:69T0F]U;F1A<FEE<R@D=&]?;&EN97,L
M("1T:&ES+3YY8VAA;F=E9"P@)'1H:7,M/GAC:&%N9V5D*3L*"B`@("`@("`@
M+R\@0V]M<'5T92!T:&4@961I="!O<&5R871I;VYS+@H@("`@("`@("1E9&ET
M<R`](&%R<F%Y*"D["B`@("`@("`@)'AI(#T@)'EI(#T@,#L*("`@("`@("!W
M:&EL92`H)'AI(#P@)&Y?9G)O;2!\?"`D>6D@/"`D;E]T;RD@>PH@("`@("`@
M("`@("!A<W-E<G0H)'EI(#P@)&Y?=&\@?'P@)'1H:7,M/GAC:&%N9V5D6R1X
M:5TI.PH@("`@("`@("`@("!A<W-E<G0H)'AI(#P@)&Y?9G)O;2!\?"`D=&AI
M<RT^>6-H86YG961;)'EI72D["@H@("`@("`@("`@("`O+R!3:VEP(&UA=&-H
M:6YG(")S;F%K92(N"B`@("`@("`@("`@("1C;W!Y(#T@87)R87DH*3L*("`@
M("`@("`@("`@=VAI;&4@*"1X:2`\("1N7V9R;VT@)B8@)'EI(#P@)&Y?=&\*
M("`@("`@("`@("`@("`@("`@("8F("$D=&AI<RT^>&-H86YG961;)'AI72`F
M)B`A)'1H:7,M/GEC:&%N9V5D6R1Y:5TI('L*("`@("`@("`@("`@("`@("1C
M;W!Y6UT@/2`D9G)O;5]L:6YE<ULD>&DK*UT["B`@("`@("`@("`@("`@("`K
M*R1Y:3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&-O<'DI('L*
M("`@("`@("`@("`@("`@("1E9&ET<UM=(#T@)FYE=R!497AT7T1I9F9?3W!?
M8V]P>2@D8V]P>2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O($9I
M;F0@9&5L971E<R`F(&%D9',N"B`@("`@("`@("`@("1D96QE=&4@/2!A<G)A
M>2@I.PH@("`@("`@("`@("!W:&EL92`H)'AI(#P@)&Y?9G)O;2`F)B`D=&AI
M<RT^>&-H86YG961;)'AI72D@>PH@("`@("`@("`@("`@("`@)&1E;&5T95M=
M(#T@)&9R;VU?;&EN97-;)'AI*RM=.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`D861D(#T@87)R87DH*3L*("`@("`@("`@("`@=VAI;&4@*"1Y:2`\
M("1N7W1O("8F("1T:&ES+3YY8VAA;F=E9%LD>6E=*2!["B`@("`@("`@("`@
M("`@("`D861D6UT@/2`D=&]?;&EN97-;)'EI*RM=.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!I9B`H)&1E;&5T92`F)B`D861D*2!["B`@("`@("`@
M("`@("`@("`D961I='-;72`]("9N97<@5&5X=%]$:69F7T]P7V-H86YG92@D
M9&5L971E+"`D861D*3L*("`@("`@("`@("`@?2!E;'-E:68@*"1D96QE=&4I
M('L*("`@("`@("`@("`@("`@("1E9&ET<UM=(#T@)FYE=R!497AT7T1I9F9?
M3W!?9&5L971E*"1D96QE=&4I.PH@("`@("`@("`@("!](&5L<V5I9B`H)&%D
M9"D@>PH@("`@("`@("`@("`@("`@)&5D:71S6UT@/2`F;F5W(%1E>'1?1&EF
M9E]/<%]A9&0H)&%D9"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D961I=',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$:79I
M9&5S('1H92!,87)G97-T($-O;6UO;B!3=6)S97%U96YC92`H3$-3*2!O9B!T
M:&4@<V5Q=65N8V5S("A83T9&+`H@("`@("H@6$Q)32D@86YD("A93T9&+"!9
M3$E-*2!I;G1O($Y#2%5.2U,@87!P<F]X:6UA=&5L>2!E<75A;&QY('-I>F5D
M"B`@("`@*B!S96=M96YT<RX*("`@("`J"B`@("`@*B!2971U<FYS("A,0U,L
M(%!44RDN("!,0U,@:7,@=&AE(&QE;F=T:"!O9B!T:&4@3$-3+B!05%,@:7,@
M86X@87)R87D@;V8*("`@("`J($Y#2%5.2U,K,2`H6"P@62D@:6YD97AE<R!G
M:79I;F<@=&AE(&1I=FEN9R!P;VEN=',@8F5T=V5E;B!S=6(*("`@("`J('-E
M<75E;F-E<RX@(%1H92!F:7)S="!S=6(M<V5Q=65N8V4@:7,@8V]N=&%I;F5D
M(&EN("A8,"P@6#$I+"`H63`L(%DQ*2P*("`@("`J('1H92!S96-O;F0@:6X@
M*%@Q+"!8,BDL("A9,2P@63(I(&%N9"!S;R!O;BX@($YO=&4@=&AA="`H6#`L
M(%DP*2`]/0H@("`@("H@*%A/1D8L(%E/1D8I(&%N9"`H6%M.0TA53DM372P@
M65M.0TA53DM372D@/3T@*%A,24TL(%E,24TI+@H@("`@("H*("`@("`J(%1H
M:7,@9G5N8W1I;VX@87-S=6UE<R!T:&%T('1H92!F:7)S="!L:6YE<R!O9B!T
M:&4@<W!E8VEF:65D('!O<G1I;VYS(&]F"B`@("`@*B!T:&4@='=O(&9I;&5S
M(&1O(&YO="!M871C:"P@86YD(&QI:V5W:7-E('1H870@=&AE(&QA<W0@;&EN
M97,@9&\@;F]T"B`@("`@*B!M871C:"X@(%1H92!C86QL97(@;75S="!T<FEM
M(&UA=&-H:6YG(&QI;F5S(&9R;VT@=&AE(&)E9VEN;FEN9R!A;F0@96YD"B`@
M("`@*B!O9B!T:&4@<&]R=&EO;G,@:70@:7,@9V]I;F<@=&\@<W!E8VEF>2X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V1I86<@*"1X;V9F+"`D>&QI;2P@)'EO
M9F8L("1Y;&EM+"`D;F-H=6YK<RD*("`@('L*("`@("`@("`D9FQI<"`](&9A
M;'-E.PH*("`@("`@("!I9B`H)'AL:6T@+2`D>&]F9B`^("1Y;&EM("T@)'EO
M9F8I('L*("`@("`@("`@("`@+RH@5&AI;F=S('-E96US(&9A<W1E<B`H22=M
M(&YO="!S=7)E($D@=6YD97)S=&%N9"!W:'DI('=H96X@=&AE"B`@("`@("`@
M("`@("`J('-H;W)T97-T('-E<75E;F-E(&ES(&EN(%@N("HO"B`@("`@("`@
M("`@("1F;&EP(#T@=')U93L*("`@("`@("`@("`@;&ES="`H)'AO9F8L("1X
M;&EM+"`D>6]F9BP@)'EL:6TI"B`@("`@("`@("`@("`@("`](&%R<F%Y*"1Y
M;V9F+"`D>6QI;2P@)'AO9F8L("1X;&EM*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("@D9FQI<"D@>PH@("`@("`@("`@("!F;W(@*"1I(#T@)'EL:6T@+2`Q
M.R`D:2`^/2`D>6]F9CL@)&DM+2D@>PH@("`@("`@("`@("`@("`@)'EM871C
M:&5S6R1T:&ES+3YX=ELD:5U=6UT@/2`D:3L*("`@("`@("`@("`@?0H@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(&9O<B`H)&D@/2`D>6QI;2`M(#$[
M("1I(#X]("1Y;V9F.R`D:2TM*2!["B`@("`@("`@("`@("`@("`D>6UA=&-H
M97-;)'1H:7,M/GEV6R1I75U;72`]("1I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("`D=&AI<RT^;&-S(#T@,#L*("`@("`@("`D=&AI<RT^
M<V5Q6S!=/2`D>6]F9B`M(#$["B`@("`@("`@)'1H:7,M/FEN7W-E<2`](&%R
M<F%Y*"D["B`@("`@("`@)'EM:61S6S!=(#T@87)R87DH*3L*"B`@("`@("`@
M)&YU;65R(#T@)'AL:6T@+2`D>&]F9B`K("1N8VAU;FMS("T@,3L*("`@("`@
M("`D>"`]("1X;V9F.PH@("`@("`@(&9O<B`H)&-H=6YK(#T@,#L@)&-H=6YK
M(#P@)&YC:'5N:W,[("1C:'5N:RLK*2!["B`@("`@("`@("`@(&EF("@D8VAU
M;FL@/B`P*2!["B`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/#T@
M)'1H:7,M/FQC<SL@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("1Y;6ED
M<ULD:5U;)&-H=6YK("T@,5T@/2`D=&AI<RT^<V5Q6R1I73L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'@Q(#T@)'AO
M9F8@*R`H:6YT*2@H)&YU;65R("L@*"1X;&EM+21X;V9F*2HD8VAU;FLI("\@
M)&YC:'5N:W,I.PH@("`@("`@("`@("!F;W(@*#L@)'@@/"`D>#$[("1X*RLI
M('L*("`@("`@("`@("`@("`@("1L:6YE(#T@)&9L:7`@/R`D=&AI<RT^>79;
M)'A=(#H@)'1H:7,M/GAV6R1X73L*("`@("`@("`@("`@("`@(&EF("AE;7!T
M>2@D>6UA=&-H97-;)&QI;F5=*2D@>PH@("`@("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&UA
M=&-H97,@/2`D>6UA=&-H97-;)&QI;F5=.PH@("`@("`@("`@("`@("`@9F]R
M96%C:"`H)&UA=&-H97,@87,@)'DI('L*("`@("`@("`@("`@("`@("`@("!I
M9B`H96UP='DH)'1H:7,M/FEN7W-E<5LD>5TI*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1K(#T@)'1H:7,M/E]L8W-0;W,H)'DI.PH@("`@("`@("`@
M("`@("`@("`@("`@("!A<W-E<G0H)&L@/B`P*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@)'EM:61S6R1K72`]("1Y;6ED<ULD:R`M(#%=.PH@("`@("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@=VAI;&4@*&QI
M<W0H)&IU;FLL("1Y*2`](&5A8V@H)&UA=&-H97,I*2!["B`@("`@("`@("`@
M("`@("`@("`@:68@*"1Y(#X@)'1H:7,M/G-E<5LD:R`M(#%=*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@(&%S<V5R="@D>2`\("1T:&ES+3YS97%;)&M=
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@+RH@3W!T:6UI>F%T:6]N.B!T
M:&ES(&ES(&$@8V]M;6]N(&-A<V4Z(&YE>'0@;6%T8V@@:7,*("`@("`@("`@
M("`@("`@("`@("`@("`@("H@:G5S="!R97!L86-I;F<@<')E=FEO=7,@;6%T
M8V@N("HO"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YI;E]S97%;
M)'1H:7,M/G-E<5LD:UU=(#T@9F%L<V4["B`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YS97%;)&M=(#T@)'D["B`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YI;E]S97%;)'E=(#T@,3L*("`@("`@("`@("`@("`@("`@
M("!](&5L<V5I9B`H96UP='DH)'1H:7,M/FEN7W-E<5LD>5TI*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1K(#T@)'1H:7,M/E]L8W-0;W,H)'DI.PH@
M("`@("`@("`@("`@("`@("`@("`@("!A<W-E<G0H)&L@/B`P*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@)'EM:61S6R1K72`]("1Y;6ED<ULD:R`M(#%=
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)'-E<'-;72`]("1F;&EP
M(#\@87)R87DH)'EO9F8L("1X;V9F*2`Z(&%R<F%Y*"1X;V9F+"`D>6]F9BD[
M"B`@("`@("`@)'EM:60@/2`D>6UI9'-;)'1H:7,M/FQC<UT["B`@("`@("`@
M9F]R("@D;B`](#`[("1N(#P@)&YC:'5N:W,@+2`Q.R`D;BLK*2!["B`@("`@
M("`@("`@("1X,2`]("1X;V9F("L@*&EN="DH*"1N=6UE<B`K("@D>&QI;2`M
M("1X;V9F*2`J("1N*2`O("1N8VAU;FMS*3L*("`@("`@("`@("`@)'DQ(#T@
M)'EM:61;)&Y=("L@,3L*("`@("`@("`@("`@)'-E<'-;72`]("1F;&EP(#\@
M87)R87DH)'DQ+"`D>#$I(#H@87)R87DH)'@Q+"`D>3$I.PH@("`@("`@('T*
M("`@("`@("`D<V5P<UM=(#T@)&9L:7`@/R!A<G)A>2@D>6QI;2P@)'AL:6TI
M(#H@87)R87DH)'AL:6TL("1Y;&EM*3L*"B`@("`@("`@<F5T=7)N(&%R<F%Y
M*"1T:&ES+3YL8W,L("1S97!S*3L*("`@('T*"B`@("!F=6YC=&EO;B!?;&-S
M4&]S*"1Y<&]S*0H@("`@>PH@("`@("`@("1E;F0@/2`D=&AI<RT^;&-S.PH@
M("`@("`@(&EF("@D96YD(#T](#`@?'P@)'EP;W,@/B`D=&AI<RT^<V5Q6R1E
M;F1=*2!["B`@("`@("`@("`@("1T:&ES+3YS97%;*RLD=&AI<RT^;&-S72`]
M("1Y<&]S.PH@("`@("`@("`@("`D=&AI<RT^:6Y?<V5Q6R1Y<&]S72`](#$[
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;&-S.PH@("`@("`@('T*"B`@
M("`@("`@)&)E9R`](#$["B`@("`@("`@=VAI;&4@*"1B96<@/"`D96YD*2![
M"B`@("`@("`@("`@("1M:60@/2`H:6YT*2@H)&)E9R`K("1E;F0I("\@,BD[
M"B`@("`@("`@("`@(&EF("@D>7!O<R`^("1T:&ES+3YS97%;)&UI9%TI('L*
M("`@("`@("`@("`@("`@("1B96<@/2`D;6ED("L@,3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1E;F0@/2`D;6ED.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!A<W-E<G0H)'EP;W,@(3T@)'1H
M:7,M/G-E<5LD96YD72D["@H@("`@("`@("1T:&ES+3YI;E]S97%;)'1H:7,M
M/G-E<5LD96YD75T@/2!F86QS93L*("`@("`@("`D=&AI<RT^<V5Q6R1E;F1=
M(#T@)'EP;W,["B`@("`@("`@)'1H:7,M/FEN7W-E<5LD>7!O<UT@/2`Q.PH@
M("`@("`@(')E='5R;B`D96YD.PH@("`@?0H*("`@("\J*@H@("`@("H@1FEN
M9',@3$-3(&]F('1W;R!S97%U96YC97,N"B`@("`@*@H@("`@("H@5&AE(')E
M<W5L=',@87)E(')E8V]R9&5D(&EN('1H92!V96-T;W)S("1T:&ES+3Y[>"QY
M?6-H86YG961;72P@8GD*("`@("`J('-T;W)I;F<@82`Q(&EN('1H92!E;&5M
M96YT(&9O<B!E86-H(&QI;F4@=&AA="!I<R!A;B!I;G-E<G1I;VX@;W(*("`@
M("`J(&1E;&5T:6]N("AI92X@:7,@;F]T(&EN('1H92!,0U,I+@H@("`@("H*
M("`@("`J(%1H92!S=6)S97%U96YC92!O9B!F:6QE(#`@:7,@*%A/1D8L(%A,
M24TI(&%N9"!L:6ME=VES92!F;W(@9FEL92`Q+@H@("`@("H*("`@("`J($YO
M=&4@=&AA="!83$E-+"!93$E-(&%R92!E>&-L=7-I=F4@8F]U;F1S+B`@06QL
M(&QI;F4@;G5M8F5R<R!A<F4*("`@("`J(&]R:6=I;BTP(&%N9"!D:7-C87)D
M960@;&EN97,@87)E(&YO="!C;W5N=&5D+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?8V]M<&%R97-E<2`H)'AO9F8L("1X;&EM+"`D>6]F9BP@)'EL:6TI"B`@
M("!["B`@("`@("`@+RH@4VQI9&4@9&]W;B!T:&4@8F]T=&]M(&EN:71I86P@
M9&EA9V]N86PN("HO"B`@("`@("`@=VAI;&4@*"1X;V9F(#P@)'AL:6T@)B8@
M)'EO9F8@/"`D>6QI;0H@("`@("`@("`@("`@("`F)B`D=&AI<RT^>'9;)'AO
M9F9=(#T]("1T:&ES+3YY=ELD>6]F9ETI('L*("`@("`@("`@("`@*RLD>&]F
M9CL*("`@("`@("`@("`@*RLD>6]F9CL*("`@("`@("!]"@H@("`@("`@("\J
M(%-L:61E('5P('1H92!T;W`@:6YI=&EA;"!D:6%G;VYA;"X@*B\*("`@("`@
M("!W:&EL92`H)'AL:6T@/B`D>&]F9B`F)B`D>6QI;2`^("1Y;V9F"B`@("`@
M("`@("`@("`@("8F("1T:&ES+3YX=ELD>&QI;2`M(#%=(#T]("1T:&ES+3YY
M=ELD>6QI;2`M(#%=*2!["B`@("`@("`@("`@("TM)'AL:6T["B`@("`@("`@
M("`@("TM)'EL:6T["B`@("`@("`@?0H*("`@("`@("!I9B`H)'AO9F8@/3T@
M)'AL:6T@?'P@)'EO9F8@/3T@)'EL:6TI('L*("`@("`@("`@("`@)&QC<R`]
M(#`["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@5&AI<R!I<R!A
M9"!H;V,@8G5T('-E96US('1O('=O<FL@=V5L;"X@("1N8VAU;FMS(#T*("`@
M("`@("`@("`@("H@<W%R="AM:6XH)'AL:6T@+2`D>&]F9BP@)'EL:6T@+2`D
M>6]F9BD@+R`R+C4I.R`D;F-H=6YK<R`]"B`@("`@("`@("`@("`J(&UA>"@R
M+&UI;B@X+"AI;G0I)&YC:'5N:W,I*3L@*B\*("`@("`@("`@("`@)&YC:'5N
M:W,@/2!M:6XH-RP@)'AL:6T@+2`D>&]F9BP@)'EL:6T@+2`D>6]F9BD@*R`Q
M.PH@("`@("`@("`@("!L:7-T*"1L8W,L("1S97!S*0H@("`@("`@("`@("`@
M("`@/2`D=&AI<RT^7V1I86<H)'AO9F8L("1X;&EM+"`D>6]F9BP@)'EL:6TL
M("1N8VAU;FMS*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D;&-S(#T](#`I
M('L*("`@("`@("`@("`@+RH@6"!A;F0@62!S97%U96YC97,@:&%V92!N;R!C
M;VUM;VX@<W5B<V5Q=65N8V4Z(&UA<FL@86QL"B`@("`@("`@("`@("`J(&-H
M86YG960N("HO"B`@("`@("`@("`@('=H:6QE("@D>6]F9B`\("1Y;&EM*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^>6-H86YG961;)'1H:7,M/GEI;F1;
M)'EO9F8K*UU=(#T@,3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!W:&EL
M92`H)'AO9F8@/"`D>&QI;2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/GAC
M:&%N9V5D6R1T:&ES+3YX:6YD6R1X;V9F*RM=72`](#$["B`@("`@("`@("`@
M('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!5<V4@=&AE('!A
M<G1I=&EO;G,@=&\@<W!L:70@=&AI<R!P<F]B;&5M(&EN=&\@<W5B<')O8FQE
M;7,N("HO"B`@("`@("`@("`@(')E<V5T*"1S97!S*3L*("`@("`@("`@("`@
M)'!T,2`]("1S97!S6S!=.PH@("`@("`@("`@("!W:&EL92`H)'!T,B`](&YE
M>'0H)'-E<',I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-O;7!A<F5S
M97$@*"1P=#%;,%TL("1P=#);,%TL("1P=#%;,5TL("1P=#);,5TI.PH@("`@
M("`@("`@("`@("`@)'!T,2`]("1P=#(["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&IU<W1S(&EN<V5R=',O9&5L
M971E<R!O9B!I9&5N=&EC86P@;&EN97,@=&\@:F]I;B!C:&%N9V5S(&%S(&UU
M8V@@87,*("`@("`J('!O<W-I8FQE+@H@("`@("H*("`@("`J(%=E(&1O('-O
M;65T:&EN9R!W:&5N(&$@<G5N(&]F(&-H86YG960@;&EN97,@:6YC;'5D92!A
M(&QI;F4@870@;VYE(&5N9`H@("`@("H@86YD(&AA<R!A;B!E>&-L=61E9"P@
M:61E;G1I8V%L(&QI;F4@870@=&AE(&]T:&5R+B`@5V4@87)E(&9R964@=&\*
M("`@("`J(&-H;V]S92!W:&EC:"!I9&5N=&EC86P@;&EN92!I<R!I;F-L=61E
M9"X@(&!C;VUP87)E<V5Q)R!U<W5A;&QY(&-H;V]S97,*("`@("`J('1H92!O
M;F4@870@=&AE(&)E9VEN;FEN9RP@8G5T('5S=6%L;'D@:70@:7,@8VQE86YE
M<B!T;R!C;VYS:61E<B!T:&4*("`@("`J(&9O;&QO=VEN9R!I9&5N=&EC86P@
M;&EN92!T;R!B92!T:&4@(F-H86YG92(N"B`@("`@*@H@("`@("H@5&AI<R!I
M<R!E>'1R86-T960@=F5R8F%T:6T@9G)O;2!A;F%L>7IE+F,@*$=.52!D:69F
M=71I;',M,BXW*2X*("`@("`J+PH@("`@9G5N8W1I;VX@7W-H:69T0F]U;F1A
M<FEE<R@D;&EN97,L("8D8VAA;F=E9"P@)&]T:&5R7V-H86YG960I"B`@("![
M"B`@("`@("`@)&D@/2`P.PH@("`@("`@("1J(#T@,#L*"B`@("`@("`@87-S
M97)T*"=C;W5N="@D;&EN97,I(#T](&-O=6YT*"1C:&%N9V5D*2<I.PH@("`@
M("`@("1L96X@/2!C;W5N="@D;&EN97,I.PH@("`@("`@("1O=&AE<E]L96X@
M/2!C;W5N="@D;W1H97)?8VAA;F=E9"D["@H@("`@("`@('=H:6QE("@Q*2![
M"B`@("`@("`@("`@("\J(%-C86X@9F]R=V%R9"!T;R!F:6YD('1H92!B96=I
M;FYI;F<@;V8@86YO=&AE<B!R=6X@;V8*("`@("`@("`@("`@("H@8VAA;F=E
M<RX@06QS;R!K965P('1R86-K(&]F('1H92!C;W)R97-P;VYD:6YG('!O:6YT
M(&EN('1H90H@("`@("`@("`@("`@*B!O=&AE<B!F:6QE+@H@("`@("`@("`@
M("`@*@H@("`@("`@("`@("`@*B!4:')O=6=H;W5T('1H:7,@8V]D92P@)&D@
M86YD("1J(&%R92!A9&IU<W1E9"!T;V=E=&AE<B!S;R!T:&%T"B`@("`@("`@
M("`@("`J('1H92!F:7)S="`D:2!E;&5M96YT<R!O9B`D8VAA;F=E9"!A;F0@
M=&AE(&9I<G-T("1J(&5L96UE;G1S(&]F"B`@("`@("`@("`@("`J("1O=&AE
M<E]C:&%N9V5D(&)O=&@@8V]N=&%I;B!T:&4@<V%M92!N=6UB97(@;V8@>F5R
M;W,@*'5N8VAA;F=E9`H@("`@("`@("`@("`@*B!L:6YE<RDN"B`@("`@("`@
M("`@("`J"B`@("`@("`@("`@("`J($9U<G1H97)M;W)E+"`D:B!I<R!A;'=A
M>7,@:V5P="!S;R!T:&%T("1J(#T]("1O=&AE<E]L96X@;W(*("`@("`@("`@
M("`@("H@)&]T:&5R7V-H86YG961;)&I=(#T](&9A;'-E+B`J+PH@("`@("`@
M("`@("!W:&EL92`H)&H@/"`D;W1H97)?;&5N("8F("1O=&AE<E]C:&%N9V5D
M6R1J72D@>PH@("`@("`@("`@("`@("`@)&HK*SL*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@=VAI;&4@*"1I(#P@)&QE;B`F)B`A("1C:&%N9V5D6R1I
M72D@>PH@("`@("`@("`@("`@("`@87-S97)T*"<D:B`\("1O=&AE<E]L96X@
M)B8@(2`D;W1H97)?8VAA;F=E9%LD:ETG*3L*("`@("`@("`@("`@("`@("1I
M*RL[("1J*RL["B`@("`@("`@("`@("`@("!W:&EL92`H)&H@/"`D;W1H97)?
M;&5N("8F("1O=&AE<E]C:&%N9V5D6R1J72D@>PH@("`@("`@("`@("`@("`@
M("`@("1J*RL["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@(&EF("@D:2`]/2`D;&5N*2!["B`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'-T87)T(#T@)&D[
M"@H@("`@("`@("`@("`O*B!&:6YD('1H92!E;F0@;V8@=&AI<R!R=6X@;V8@
M8VAA;F=E<RX@*B\*("`@("`@("`@("`@=VAI;&4@*"LK)&D@/"`D;&5N("8F
M("1C:&%N9V5D6R1I72D@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@(&1O('L*("`@("`@("`@("`@("`@
M("\J(%)E8V]R9"!T:&4@;&5N9W1H(&]F('1H:7,@<G5N(&]F(&-H86YG97,L
M('-O('1H870@=V4@8V%N"B`@("`@("`@("`@("`@("`@*B!L871E<B!D971E
M<FUI;F4@=VAE=&AE<B!T:&4@<G5N(&AA<R!G<F]W;BX@*B\*("`@("`@("`@
M("`@("`@("1R=6YL96YG=&@@/2`D:2`M("1S=&%R=#L*"B`@("`@("`@("`@
M("`@("`O*B!-;W9E('1H92!C:&%N9V5D(')E9VEO;B!B86-K+"!S;R!L;VYG
M(&%S('1H92!P<F5V:6]U<PH@("`@("`@("`@("`@("`@("H@=6YC:&%N9V5D
M(&QI;F4@;6%T8VAE<R!T:&4@;&%S="!C:&%N9V5D(&]N92X@(%1H:7,@;65R
M9V5S"B`@("`@("`@("`@("`@("`@*B!W:71H('!R979I;W5S(&-H86YG960@
M<F5G:6]N<RX@*B\*("`@("`@("`@("`@("`@('=H:6QE("@D<W1A<G0@/B`P
M("8F("1L:6YE<ULD<W1A<G0@+2`Q72`]/2`D;&EN97-;)&D@+2`Q72D@>PH@
M("`@("`@("`@("`@("`@("`@("1C:&%N9V5D6RTM)'-T87)T72`](#$["B`@
M("`@("`@("`@("`@("`@("`@)&-H86YG961;+2TD:5T@/2!F86QS93L*("`@
M("`@("`@("`@("`@("`@("!W:&EL92`H)'-T87)T(#X@,"`F)B`D8VAA;F=E
M9%LD<W1A<G0@+2`Q72D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<W1A
M<G0M+3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@87-S97)T*"<D:B`^(#`G*3L*("`@("`@("`@("`@("`@("`@("!W:&EL
M92`H)&]T:&5R7V-H86YG961;+2TD:ETI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@8V]N=&EN=64["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@(&%S<V5R="@G)&H@/CT@,"`F)B`A)&]T:&5R7V-H86YG
M961;)&I=)RD["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@
M+RH@4V5T($-/4E)%4U!/3D1)3D<@=&\@=&AE(&5N9"!O9B!T:&4@8VAA;F=E
M9"!R=6XL(&%T('1H90H@("`@("`@("`@("`@("`@("H@;&%S="!P;VEN="!W
M:&5R92!I="!C;W)R97-P;VYD<R!T;R!A(&-H86YG960@<G5N(&EN('1H90H@
M("`@("`@("`@("`@("`@("H@;W1H97(@9FEL92X@0T]24D534$].1$E.1R`]
M/2!,14X@;65A;G,@;F\@<W5C:"!P;VEN="!H87,*("`@("`@("`@("`@("`@
M("`J(&)E96X@9F]U;F0N("HO"B`@("`@("`@("`@("`@("`D8V]R<F5S<&]N
M9&EN9R`]("1J(#P@)&]T:&5R7VQE;B`_("1I(#H@)&QE;CL*"B`@("`@("`@
M("`@("`@("`O*B!-;W9E('1H92!C:&%N9V5D(')E9VEO;B!F;W)W87)D+"!S
M;R!L;VYG(&%S('1H92!F:7)S=`H@("`@("`@("`@("`@("`@("H@8VAA;F=E
M9"!L:6YE(&UA=&-H97,@=&AE(&9O;&QO=VEN9R!U;F-H86YG960@;VYE+B`@
M5&AI<PH@("`@("`@("`@("`@("`@("H@;65R9V5S('=I=&@@9F]L;&]W:6YG
M(&-H86YG960@<F5G:6]N<RX@($1O('1H:7,@<V5C;VYD+"!S;PH@("`@("`@
M("`@("`@("`@("H@=&AA="!I9B!T:&5R92!A<F4@;F\@;65R9V5S+"!T:&4@
M8VAA;F=E9"!R96=I;VX@:7,@;6]V960*("`@("`@("`@("`@("`@("`J(&9O
M<G=A<F0@87,@9F%R(&%S('!O<W-I8FQE+B`J+PH@("`@("`@("`@("`@("`@
M=VAI;&4@*"1I(#P@)&QE;B`F)B`D;&EN97-;)'-T87)T72`]/2`D;&EN97-;
M)&E=*2!["B`@("`@("`@("`@("`@("`@("`@)&-H86YG961;)'-T87)T*RM=
M(#T@9F%L<V4["B`@("`@("`@("`@("`@("`@("`@)&-H86YG961;)&DK*UT@
M/2`Q.PH@("`@("`@("`@("`@("`@("`@('=H:6QE("@D:2`\("1L96X@)B8@
M)&-H86YG961;)&E=*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1I*RL[
M"B`@("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@("!A
M<W-E<G0H)R1J(#P@)&]T:&5R7VQE;B`F)B`A("1O=&AE<E]C:&%N9V5D6R1J
M72<I.PH@("`@("`@("`@("`@("`@("`@("1J*RL["B`@("`@("`@("`@("`@
M("`@("`@:68@*"1J(#P@)&]T:&5R7VQE;B`F)B`D;W1H97)?8VAA;F=E9%LD
M:ETI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&-O<G)E<W!O;F1I;F<@
M/2`D:3L*("`@("`@("`@("`@("`@("`@("`@("`@=VAI;&4@*"1J(#P@)&]T
M:&5R7VQE;B`F)B`D;W1H97)?8VAA;F=E9%LD:ETI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1J*RL["B`@("`@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T@=VAI;&4@*"1R=6YL96YG=&@@(3T@)&D@+2`D<W1A<G0I
M.PH*("`@("`@("`@("`@+RH@268@<&]S<VEB;&4L(&UO=F4@=&AE(&9U;&QY
M+6UE<F=E9"!R=6X@;V8@8VAA;F=E<R!B86-K('1O(&$*("`@("`@("`@("`@
M("H@8V]R<F5S<&]N9&EN9R!R=6X@:6X@=&AE(&]T:&5R(&9I;&4N("HO"B`@
M("`@("`@("`@('=H:6QE("@D8V]R<F5S<&]N9&EN9R`\("1I*2!["B`@("`@
M("`@("`@("`@("`D8VAA;F=E9%LM+21S=&%R=%T@/2`Q.PH@("`@("`@("`@
M("`@("`@)&-H86YG961;+2TD:5T@/2`P.PH@("`@("`@("`@("`@("`@87-S
M97)T*"<D:B`^(#`G*3L*("`@("`@("`@("`@("`@('=H:6QE("@D;W1H97)?
M8VAA;F=E9%LM+21J72D@>PH@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@87-S97)T*"<D
M:B`^/2`P("8F("$D;W1H97)?8VAA;F=E9%LD:ETG*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@('T*"GT*"B\J*@H@*B!`<&%C:V%G92!497AT7T1I
M9F8*("H@0&%U=&AO<B`@1V5O9F9R97D@5"X@1&%I<FEK:2`\9&%I<FEK:4!D
M86ER:6MI+F]R9SX*("H*("H@0&%C8V5S<R!P<FEV871E"B`J+PIC;&%S<R!4
M97AT7T1I9F9?3W`@>PH*("`@('9A<B`D;W)I9SL*("`@('9A<B`D9FEN86P[
M"@H@("`@9G5N8W1I;VX@<F5V97)S92@I"B`@("!["B`@("`@("`@=')I9V=E
M<E]E<G)O<B@G06)S=')A8W0@;65T:&]D)RP@15]54T527T524D]2*3L*("`@
M('T*"B`@("!F=6YC=&EO;B!N;W)I9R@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3YO<FEG(#\@8V]U;G0H)'1H:7,M/F]R:6<I(#H@,#L*("`@('T*
M"B`@("!F=6YC=&EO;B!N9FEN86PH*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^9FEN86P@/R!C;W5N="@D=&AI<RT^9FEN86PI(#H@,#L*("`@('T*
M"GT*"B\J*@H@*B!`<&%C:V%G92!497AT7T1I9F8*("H@0&%U=&AO<B`@1V5O
M9F9R97D@5"X@1&%I<FEK:2`\9&%I<FEK:4!D86ER:6MI+F]R9SX*("H*("H@
M0&%C8V5S<R!P<FEV871E"B`J+PIC;&%S<R!497AT7T1I9F9?3W!?8V]P>2!E
M>'1E;F1S(%1E>'1?1&EF9E]/<"!["@H@("`@9G5N8W1I;VX@5&5X=%]$:69F
M7T]P7V-O<'DH)&]R:6<L("1F:6YA;"`](&9A;'-E*0H@("`@>PH@("`@("`@
M(&EF("@A:7-?87)R87DH)&9I;F%L*2D@>PH@("`@("`@("`@("`D9FEN86P@
M/2`D;W)I9SL*("`@("`@("!]"B`@("`@("`@)'1H:7,M/F]R:6<@/2`D;W)I
M9SL*("`@("`@("`D=&AI<RT^9FEN86P@/2`D9FEN86P["B`@("!]"@H@("`@
M9G5N8W1I;VX@)G)E=F5R<V4H*0H@("`@>PH@("`@("`@("1R979E<G-E(#T@
M)FYE=R!497AT7T1I9F9?3W!?8V]P>2@D=&AI<RT^9FEN86PL("1T:&ES+3YO
M<FEG*3L*("`@("`@("!R971U<FX@)')E=F5R<V4["B`@("!]"@I]"@HO*BH*
M("H@0'!A8VMA9V4@5&5X=%]$:69F"B`J($!A=71H;W(@($=E;V9F<F5Y(%0N
M($1A:7)I:VD@/&1A:7)I:VE`9&%I<FEK:2YO<F<^"B`J"B`J($!A8V-E<W,@
M<')I=F%T90H@*B\*8VQA<W,@5&5X=%]$:69F7T]P7V1E;&5T92!E>'1E;F1S
M(%1E>'1?1&EF9E]/<"!["@H@("`@9G5N8W1I;VX@5&5X=%]$:69F7T]P7V1E
M;&5T92@D;&EN97,I"B`@("!["B`@("`@("`@)'1H:7,M/F]R:6<@/2`D;&EN
M97,["B`@("`@("`@)'1H:7,M/F9I;F%L(#T@9F%L<V4["B`@("!]"@H@("`@
M9G5N8W1I;VX@)G)E=F5R<V4H*0H@("`@>PH@("`@("`@("1R979E<G-E(#T@
M)FYE=R!497AT7T1I9F9?3W!?861D*"1T:&ES+3YO<FEG*3L*("`@("`@("!R
M971U<FX@)')E=F5R<V4["B`@("!]"@I]"@HO*BH*("H@0'!A8VMA9V4@5&5X
M=%]$:69F"B`J($!A=71H;W(@($=E;V9F<F5Y(%0N($1A:7)I:VD@/&1A:7)I
M:VE`9&%I<FEK:2YO<F<^"B`J"B`J($!A8V-E<W,@<')I=F%T90H@*B\*8VQA
M<W,@5&5X=%]$:69F7T]P7V%D9"!E>'1E;F1S(%1E>'1?1&EF9E]/<"!["@H@
M("`@9G5N8W1I;VX@5&5X=%]$:69F7T]P7V%D9"@D;&EN97,I"B`@("!["B`@
M("`@("`@)'1H:7,M/F9I;F%L(#T@)&QI;F5S.PH@("`@("`@("1T:&ES+3YO
M<FEG(#T@9F%L<V4["B`@("!]"@H@("`@9G5N8W1I;VX@)G)E=F5R<V4H*0H@
M("`@>PH@("`@("`@("1R979E<G-E(#T@)FYE=R!497AT7T1I9F9?3W!?9&5L
M971E*"1T:&ES+3YF:6YA;"D["B`@("`@("`@<F5T=7)N("1R979E<G-E.PH@
M("`@?0H*?0H*+RHJ"B`J($!P86-K86=E(%1E>'1?1&EF9@H@*B!`875T:&]R
M("!'96]F9G)E>2!4+B!$86ER:6MI(#QD86ER:6MI0&1A:7)I:VDN;W)G/@H@
M*@H@*B!`86-C97-S('!R:79A=&4*("HO"F-L87-S(%1E>'1?1&EF9E]/<%]C
M:&%N9V4@97AT96YD<R!497AT7T1I9F9?3W`@>PH*("`@(&9U;F-T:6]N(%1E
M>'1?1&EF9E]/<%]C:&%N9V4H)&]R:6<L("1F:6YA;"D*("`@('L*("`@("`@
M("`D=&AI<RT^;W)I9R`]("1O<FEG.PH@("`@("`@("1T:&ES+3YF:6YA;"`]
M("1F:6YA;#L*("`@('T*"B`@("!F=6YC=&EO;B`F<F5V97)S92@I"B`@("![
M"B`@("`@("`@)')E=F5R<V4@/2`F;F5W(%1E>'1?1&EF9E]/<%]C:&%N9V4H
M)'1H:7,M/F9I;F%L+"`D=&AI<RT^;W)I9RD["B`@("`@("`@<F5T=7)N("1R
M979E<G-E.PH@("`@?0H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+U1E>'0O1FQO=V5D+G!H<```````````````````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#(V-S(Q(#$P-3$U-#,S-S,U(#`R
M,3$W-``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@5&AE(%1E>'1?1FQO=V5D.CH@8VQA<W,@<')O=FED
M97,@8V]M;6]N(&UE=&AO9',@9F]R(&UA;FEP=6QA=&EN9R!T97AT"B`J('5S
M:6YG('1H92!E;F-O9&EN9R!D97-C<FEB960@:6X@4D9#(#,V-S8@*"=F;&]W
M960G('1E>'0I+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]497AT7T9L;W=E
M9"]&;&]W960N<&AP+'8@,2XQ-"XQ,"XQ-R`R,#`V+S`S+S$Q(#`Y.C4P.C(R
M(&IA;B!%>'`@)`H@*@H@*B!4:&ES(&-L87-S(&ES(&)A<V5D(&]N('1H92!4
M97AT.CI&;&]W960@<&5R;"!M;V1U;&4@*%9E<G-I;VX@,"XQ-"D@9F]U;F0*
M("H@:6X@=&AE($-004X@<&5R;"!R97!O<VET;W)Y+B`@5&AI<R!M;V1U;&4@
M:7,@<F5L96%S960@=6YD97(@=&AE(%!E<FP*("H@;&EC96YS92P@=VAI8V@@
M:7,@8V]M<&%T:6)L92!W:71H('1H92!,1U!,+@H@*@H@*B!#;W!Y<FEG:'0@
M,C`P,BTR,#`S(%!H:6QI<"!-86L*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!-
M:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6-H865L(%-L=7-A<GH@
M/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J($!S:6YC92`@($AO
M<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]497AT"B`J+PIC;&%S<R!497AT
M7T9L;W=E9"!["@H@("`@+RHJ"B`@("`@*B!4:&4@;6%X:6UU;2!L96YG=&@@
M=&AA="!A(&QI;F4@:7,@86QL;W=E9"!T;R!B92`H=6YL97-S(&9A8V5D('=I
M=&@*("`@("`J('=I=&@@82!W;W)D('1H870@:7,@=6YR96%S;VYA8FQY(&QO
M;F<I+B!4:&ES(&-L87-S('=I;&P@<F4M=W)A<"!A"B`@("`@*B!L:6YE(&EF
M(&ET(&5X8V5E9',@=&AI<R!L96YG=&@N"B`@("`@*@H@("`@("H@0'9A<B!I
M;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7VUA>&QE;F=T:"`](#<X.PH*("`@
M("\J*@H@("`@("H@5VAE;B!T:&ES(&-L87-S('=R87!S(&$@;&EN92P@=&AE
M(&YE=VQY(&-R96%T960@;&EN97,@=VEL;"!B92!S<&QI=`H@("`@("H@870@
M=&AI<R!L96YG=&@N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@
M*B\*("`@('9A<B`D7V]P=&QE;F=T:"`](#<R.PH*("`@("\J*@H@("`@("H@
M5&AE('1E>'0@=&\@8F4@9F]R;6%T=&5D+@H@("`@("H*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W1E>'0["@H@("`@+RHJ"B`@("`@
M*B!4:&4@8V%C:&5D(&]U='!U="!O9B!T:&4@9F]R;6%T=&EN9RX*("`@("`J
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V]U='!U="`]
M(&YU;&P["@H@("`@+RHJ"B`@("`@*B!4:&4@8VAA<F%C=&5R('-E="!O9B!T
M:&4@=&5X="X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)%]C:&%R<V5T.PH*("`@("\J*@H@("`@("H@0V]N=F5R="!T97AT
M('5S:6YG($1E;%-P/PH@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@
M("HO"B`@("!V87(@)%]D96QS<"`](&9A;'-E.PH*("`@("\J*@H@("`@("H@
M0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X
M="`@("`@5&AE('1E>'0@=&\@<')O8V5S<RX*("`@("`J($!P87)A;2!S=')I
M;F<@)&-H87)S970@(%1H92!C:&%R86-T97(@<V5T(&]F("1T97AT+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!497AT7T9L;W=E9"@D=&5X="P@)&-H87)S970@
M/2!N=6QL*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=&5X="`]("1T97AT.PH@
M("`@("`@("1T:&ES+3Y?8VAA<G-E="`]("1C:&%R<V5T.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5T('1H92!M87AI;75M(&QE;F=T:"!O9B!A(&QI;F4@
M;V8@=&5X="X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;6%X("!!
M(&YE=R!V86QU92!F;W(@)%]M87AL96YG=&@N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('-E=$UA>$QE;F=T:"@D;6%X*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M;6%X;&5N9W1H(#T@)&UA>#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T
M:&4@;W!T:6UA;"!L96YG=&@@;V8@82!L:6YE(&]F('1E>'0N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&UA>"`@02!N97<@=F%L=64@9F]R("1?
M;W!T;&5N9W1H+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971/<'1,96YG=&@H
M)&]P="D*("`@('L*("`@("`@("`D=&AI<RT^7V]P=&QE;F=T:"`]("1O<'0[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=VAE=&AE<B!T;R!F;W)M870@
M=&5S="!U<VEN9R!$96Q3<"X*("`@("`J"B`@("`@*B!`<VEN8V4@2&]R9&4@
M,RXQ"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&1E;'-P("!5<V4@
M1&5L4W`_"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$1E;%-P*"1D96QS<"D*
M("`@('L*("`@("`@("`D=&AI<RT^7V1E;'-P(#T@*&)O;VPI("1D96QS<#L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E9F]R;6%T<R!T:&4@:6YP=70@<W1R
M:6YG+"!W:&5R92!T:&4@<W1R:6YG(&ES("=F;W)M870]9FQO=V5D)R!P;&%I
M;@H@("`@("H@=&5X="!A<R!D97-C<FEB960@:6X@4D9#(#(V-#8N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'%U;W1E("!!9&0@;&5V96P@;V8@
M<75O=&EN9R!T;R!E86-H(&QI;F4_"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!T97AT(&-O;G9E<G1E9"!T;R!21D,@,C8T-B`G9FEX960G
M(&9O<FUA="X*("`@("`J+PH@("`@9G5N8W1I;VX@=&]&:7AE9"@D<75O=&4@
M/2!F86QS92D*("`@('L*("`@("`@("`D='AT(#T@)R<["@H@("`@("`@("1T
M:&ES+3Y?<F5F;W)M870H9F%L<V4L("1Q=6]T92D["B`@("`@("`@9F]R96%C
M:"`H)'1H:7,M/E]O=71P=70@87,@)'9A;"D@>PH@("`@("`@("`@("`D='AT
M("X]("1V86Q;)W1E>'0G72`N(")<;B(["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B!R=')I;2@D='AT*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E9F]R
M;6%T<R!T:&4@:6YP=70@<W1R:6YG+"!A;F0@<F5T=7)N<R!T:&4@;W5T<'5T
M(&EN(&%N(&%R<F%Y(&9O<FUA=`H@("`@("H@=VET:"!Q=6]T92!L979E;"!I
M;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<75O
M=&4@($%D9"!L979E;"!O9B!Q=6]T:6YG('1O(&5A8V@@;&EN93\*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!O9B!A<G)A>7,@=VET
M:"!T:&4@9F]L;&]W:6YG(&5L96UE;G1S.@H@("`@("H@/'!R93X*("`@("`J
M("=L979E;"<@+2!4:&4@<75O=&4@;&5V96P@;V8@=&AE(&-U<G)E;G0@;&EN
M92X*("`@("`J("=T97AT)R`@+2!4:&4@=&5X="!F;W(@=&AE(&-U<G)E;G0@
M;&EN92X*("`@("`J(#PO<')E/@H@("`@("HO"B`@("!F=6YC=&EO;B!T;T9I
M>&5D07)R87DH)'%U;W1E(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]R969O<FUA="AF86QS92P@)'%U;W1E*3L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]O=71P=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2969O<FUA=',@
M=&AE(&EN<'5T('-T<FEN9RP@=VAE<F4@=&AE('-T<FEN9R!I<R`G9F]R;6%T
M/69I>&5D)R!P;&%I;@H@("`@("H@=&5X="!A<R!D97-C<FEB960@:6X@4D9#
M(#(V-#8N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'%U;W1E("!!
M9&0@;&5V96P@;V8@<75O=&EN9R!T;R!E86-H(&QI;F4_"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!T97AT(&-O;G9E<G1E9"!T;R!21D,@
M,C8T-B`G9FQO=V5D)R!F;W)M870N"B`@("`@*B\*("`@(&9U;F-T:6]N('1O
M1FQO=V5D*"1Q=6]T92`](&9A;'-E*0H@("`@>PH@("`@("`@("1T>'0@/2`G
M)SL*"B`@("`@("`@)'1H:7,M/E]R969O<FUA="AT<G5E+"`D<75O=&4I.PH@
M("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?;W5T<'5T(&%S("1V86PI('L*("`@
M("`@("`@("`@)'1X="`N/2`D=F%L6R=T97AT)UT@+B`B7&XB.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)'1X=#L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E9F]R;6%T<R!T:&4@:6YP=70@<W1R:6YG+"!W:&5R92!T:&4@<W1R:6YG
M(&ES("=F;W)M870]9FQO=V5D)R!P;&%I;@H@("`@("H@=&5X="!A<R!D97-C
M<FEB960@:6X@4D9#(#(V-#8N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'1O9FQO=V5D("!#
M;VYV97)T('1O(&9L;W=E9#\*("`@("`J($!P87)A;2!B;V]L96%N("1Q=6]T
M92`@("`@061D(&QE=F5L(&]F('%U;W1I;F<@=&\@96%C:"!L:6YE/PH@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@($$@;&ES="!O9B!A<G)A>7,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]R969O<FUA="@D=&]F;&]W960L("1Q=6]T
M92D*("`@('L*("`@("`@("!I9B`H(6ES7VYU;&PH)'1H:7,M/E]O=71P=70I
M*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("1T
M:&ES+3Y?;W5T<'5T(#T@87)R87DH*3L*("`@("`@("`D=&5X="`](&5X<&QO
M9&4H(EQN(BP@)'1H:7,M/E]T97AT*3L*"B`@("`@("`@+RH@4V5T('9A<FEA
M8FQE<R!U<V5D(&EN(')E9V5X<',N("HO"B`@("`@("`@)&1E;'-P(#T@*"1T
M;V9L;W=E9"`F)B`D=&AI<RT^7V1E;'-P*2`_(#$@.B`P.PH@("`@("`@("1O
M<'0@/2`D=&AI<RT^7V]P=&QE;F=T:"`M(#$@+2`D9&5L<W`["@H@("`@("`@
M("\J(%!R;V-E<W,@;65S<V%G92!L:6YE(&)Y(&QI;F4N("HO"B`@("`@("`@
M9&\@>PH@("`@("`@("`@("`D;&EN92`](&%R<F%Y7W-H:69T*"1T97AT*3L*
M"B`@("`@("`@("`@("\J(%!E<B!21D,@,C8T-B!;-"XS72P@=&AE("=5<V5N
M970@4VEG;F%T=7)E($-O;G9E;G1I;VXG(&QI;F4*("`@("`@("`@("`@("H@
M*$1!4T@@1$%32"!34"D@:7,@;F]T(&-O;G-I9&5R960@9FQO=V5D+B`@5V%T
M8V@@9F]R('1H:7,@=VAE;@H@("`@("`@("`@("`@*B!D96%L:6YG('=I=&@@
M<&]T96YT:6%L;'D@9FQO=V5D(&QI;F5S+B`J+PH*("`@("`@("`@("`@+RH@
M5&AE(&YE>'0@=&AR964@<W1E<',@8V]M92!F<F]M(%)&0R`R-C0V(%LT+C)=
M+B`J+PH@("`@("`@("`@("`O*B!35$50(#$Z($1E=&5R;6EN92!Q=6]T92!L
M979E;"!F;W(@;&EN92X@*B\*("`@("`@("`@("`@:68@*"@D;G5M7W%U;W1E
M<R`]("1T:&ES+3Y?;G5M<75O=&5S*"1L:6YE*2DI('L*("`@("`@("`@("`@
M("`@("1L:6YE(#T@<W5B<W1R*"1L:6YE+"`D;G5M7W%U;W1E<RD["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("\J($]N;'D@8V]M8FEN92!L:6YE<R!I
M9B!W92!A<F4@8V]N=F5R=&EN9R!T;R!F;&]W960@;W(@:68@=&AE"B`@("`@
M("`@("`@("`J(&-U<G)E;G0@;&EN92!I<R!Q=6]T960N("HO"B`@("`@("`@
M("`@(&EF("@A)'1O9FQO=V5D('Q\("1N=6U?<75O=&5S*2!["B`@("`@("`@
M("`@("`@("`O*B!35$50(#(Z(%)E;6]V92!S<&%C92!S='5F9FEN9R!F<F]M
M(&QI;F4N("HO"B`@("`@("`@("`@("`@("`D;&EN92`]("1T:&ES+3Y?=6YS
M='5F9B@D;&EN92D["@H@("`@("`@("`@("`@("`@+RH@4U1%4"`S.B!3:&]U
M;&0@=V4@:6YT97)P<F5T('1H:7,@;&EN92!A<R!F;&]W960_"B`@("`@("`@
M("`@("`@("`@*B!7:&EL92!L:6YE(&ES(&9L;W=E9"`H;F]T(&5M<'1Y(&%N
M9"!T:&5R92!I<R!A('-P86-E"B`@("`@("`@("`@("`@("`@*B!A="!T:&4@
M96YD(&]F('1H92!L:6YE*2P@86YD('1H97)E(&ES(&$@;F5X="!L:6YE+"!A
M;F0@=&AE"B`@("`@("`@("`@("`@("`@*B!N97AT(&QI;F4@:&%S('1H92!S
M86UE('%U;W1E(&1E<'1H+"!A9&0@=&\@=&AE(&-U<G)E;G0*("`@("`@("`@
M("`@("`@("`J(&QI;F4N($$@;&EN92!I<R!N;W0@9FQO=V5D(&EF(&ET(&ES
M(&$@<VEG;F%T=7)E(&QI;F4N("HO"B`@("`@("`@("`@("`@("!W:&EL92`H
M(65M<'1Y*"1L:6YE*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("@D;&EN
M92`A/2`G+2T@)RD@)B8*("`@("`@("`@("`@("`@("`@("`@("`H)&QI;F5[
M<W1R;&5N*"1L:6YE*2TQ?2`]/2`G("<I("8F"B`@("`@("`@("`@("`@("`@
M("`@("`@(65M<'1Y*"1T97AT*2`F)@H@("`@("`@("`@("`@("`@("`@("`@
M("@D=&AI<RT^7VYU;7%U;W1E<R@D=&5X=%LP72D@/3T@)&YU;5]Q=6]T97,I
M*2!["B`@("`@("`@("`@("`@("`@("`@+RH@268@1&5L4W`@:7,@>65S(&%N
M9"!T:&ES(&ES(&9L;W=E9"!I;G!U="P@=V4@;F5E9"!T;PH@("`@("`@("`@
M("`@("`@("`@("`J(')E;6]V92!T:&4@=')A:6QI;F<@<W!A8V4N("HO"B`@
M("`@("`@("`@("`@("`@("`@:68@*"$D=&]F;&]W960@)B8@)'1H:7,M/E]D
M96QS<"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;&EN92`]('-U8G-T
M<B@D;&EN92P@,"P@+3$I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`D;&EN92`N/2`D=&AI<RT^7W5N<W1U9F8H<W5B<W1R
M*&%R<F%Y7W-H:69T*"1T97AT*2P@)&YU;5]Q=6]T97,I*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@16YS=7)E
M(&QI;F4@:7,@9FEX960L('-I;F-E('=E(&%L<F5A9'D@:F]I;F5D(&%L;"!F
M;&]W960*("`@("`@("`@("`@("H@;&EN97,N(%)E;6]V92!A;&P@=')A:6QI
M;F<@)R`G(&9R;VT@=&AE(&QI;F4N("HO"B`@("`@("`@("`@(&EF("@D;&EN
M92`A/2`G+2T@)RD@>PH@("`@("`@("`@("`@("`@)&QI;F4@/2!R=')I;2@D
M;&EN92D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($EN8W)E;65N
M="!Q=6]T92!D97!T:"!I9B!W92=R92!Q=6]T:6YG+B`J+PH@("`@("`@("`@
M("!I9B`H)'%U;W1E*2!["B`@("`@("`@("`@("`@("`D;G5M7W%U;W1E<RLK
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!4:&4@<75O=&4@<')E
M9FEX(&9O<B!T:&4@;&EN92X@*B\*("`@("`@("`@("`@)'%U;W1E<W1R(#T@
M<W1R7W)E<&5A="@G/B<L("1N=6U?<75O=&5S*3L*"B`@("`@("`@("`@(&EF
M("AE;7!T>2@D;&EN92DI('L*("`@("`@("`@("`@("`@("\J($QI;F4@:7,@
M96UP='DN("HO"B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U='!U=%M=(#T@
M87)R87DH)W1E>'0G(#T^("1Q=6]T97-T<BP@)VQE=F5L)R`]/B`D;G5M7W%U
M;W1E<RD["B`@("`@("`@("`@('T@96QS96EF("AE;7!T>2@D=&AI<RT^7VUA
M>&QE;F=T:"D@?'P@*"A3=')I;F<Z.FQE;F=T:"@D;&EN92P@)'1H:7,M/E]C
M:&%R<V5T*2`K("1N=6U?<75O=&5S*2`\/2`D=&AI<RT^7VUA>&QE;F=T:"DI
M('L*("`@("`@("`@("`@("`@("\J($QI;F4@9&]E<R!N;W0@<F5Q=6ER92!R
M97=R87!P:6YG+B`J+PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O=71P=71;
M72`](&%R<F%Y*"=T97AT)R`]/B`D<75O=&5S='(@+B`D=&AI<RT^7W-T=69F
M*"1L:6YE+"`D;G5M7W%U;W1E<RP@)'1O9FQO=V5D*2P@)VQE=F5L)R`]/B`D
M;G5M7W%U;W1E<RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D;6EN(#T@)&YU;5]Q=6]T97,@*R`Q.PH*("`@("`@("`@("`@("`@
M("\J(%)E=W)A<"!T:&ES('!A<F%G<F%P:"X@*B\*("`@("`@("`@("`@("`@
M('=H:6QE("@D;&EN92D@>PH@("`@("`@("`@("`@("`@("`@("\J(%-T=69F
M(&%N9"!R92UQ=6]T92!T:&4@;&EN92X@*B\*("`@("`@("`@("`@("`@("`@
M("`D;&EN92`]("1Q=6]T97-T<B`N("1T:&ES+3Y?<W1U9F8H)&QI;F4L("1N
M=6U?<75O=&5S+"`D=&]F;&]W960I.PH@("`@("`@("`@("`@("`@("`@("1L
M:6YE7VQE;F=T:"`](%-T<FEN9SHZ;&5N9W1H*"1L:6YE+"`D=&AI<RT^7V-H
M87)S970I.PH@("`@("`@("`@("`@("`@("`@(&EF("@D;&EN95]L96YG=&@@
M/#T@)'1H:7,M/E]O<'1L96YG=&@I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@+RH@4F5M86EN:6YG('-E8W1I;VX@;V8@;&EN92!I<R!S:&]R="!E;F]U
M9V@N("HO"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T
M6UT@/2!A<G)A>2@G=&5X="<@/3X@)&QI;F4L("=L979E;"<@/3X@)&YU;5]Q
M=6]T97,I.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@("`@("`@("!](&5L<V5I9B`H)&T@/2!3=')I;F<Z.G)E9V5X36%T
M8V@H)&QI;F4L(&%R<F%Y*"=>*"Y[)R`N("1M:6X@+B`G+"<@+B`D;W!T("X@
M)WTI("@N*BDG+"`G7B@N>R<@+B`D;6EN("X@)RPG("X@)'1H:7,M/E]M87AL
M96YG=&@@+B`G?2D@*"XJ*2<L("=>*"Y[)R`N("1M:6X@+B`G+'TI/R`H+BHI
M)RDL("1T:&ES+3Y?8VAA<G-E="DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@+RH@5V4@;F5E9"!T;R!W<F%P('1E>'0@870@82!C97)T86EN(&YU;6)E
M<B!O9@H@("`@("`@("`@("`@("`@("`@("`@("`@*B`J8VAA<F%C=&5R<RHL
M(&YO="!A(&-E<G1A:6X@;G5M8F5R(&]F("IB>71E<RH["B`@("`@("`@("`@
M("`@("`@("`@("`@("`J('1H=7,@=&AE(&YE960@9F]R(&$@;75L=&EB>71E
M(&-A<&%B;&4@<F5G97@N"B`@("`@("`@("`@("`@("`@("`@("`@("`J($EF
M(&$@;75L=&EB>71E(')E9V5X(&ES;B=T(&%V86EL86)L92P@=V4@87)E('-T
M=6-K"B`@("`@("`@("`@("`@("`@("`@("`@("`J('=I=&@@<')E9U]M871C
M:"@I("AT:&4@9G5N8W1I;VX@=VEL;"!S=&EL;"!W;W)K("T*("`@("`@("`@
M("`@("`@("`@("`@("`@("H@=V4@=VEL;"!J=7-T(&)E(&QE9G0@=VET:"!S
M:&]R=&5R(')O=W,@=&AA;B!E>'!E8W1E9`H@("`@("`@("`@("`@("`@("`@
M("`@("`@*B!I9B!M=6QT:6)Y=&4@8VAA<F%C=&5R<R!E>&ES="!I;B!T:&4@
M<F]W*2X*("`@("`@("`@("`@("`@("`@("`@("`@("H*("`@("`@("`@("`@
M("`@("`@("`@("`@("H@06QG;W)I=&AI;3H*("`@("`@("`@("`@("`@("`@
M("`@("`@("H@,2X@5')Y('1O(&9I;F0@82!S=')I;F<@87,@;&]N9R!A<R!?
M;W!T;&5N9W1H+@H@("`@("`@("`@("`@("`@("`@("`@("`@*B`R+B!4<GD@
M=&\@9FEN9"!A('-T<FEN9R!A<R!L;VYG(&%S(%]M87AL96YG=&@N"B`@("`@
M("`@("`@("`@("`@("`@("`@("`J(#,N(%1A:V4@=&AE(&9I<G-T('=O<F0N
M("HO"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D;5LQ72DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1M6S%=(#T@)&U;,ET[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;5LR72`]("<G.PH@("`@
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?;W5T<'5T6UT@/2!A<G)A>2@G=&5X="<@/3X@)&U;,5T@+B`G
M("<@+B`H*"1D96QS<"D@/R`G("<@.B`G)RDL("=L979E;"<@/3X@)&YU;5]Q
M=6]T97,I.PH@("`@("`@("`@("`@("`@("`@("`@("`D;&EN92`]("1M6S)=
M.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@("`@("\J($]N92!E>&-E<W-I=F5L>2!L;VYG('=O<F0@;&5F="!O
M;B!L:6YE+B`@0F4*("`@("`@("`@("`@("`@("`@("`@("`@("H@86)S;VQU
M=&5L>2!S=7)E(&ET(&1O97,@;F]T(&5X8V5E9"`Y.3@@8VAA<F%C=&5R<PH@
M("`@("`@("`@("`@("`@("`@("`@("`@*B!I;B!L96YG=&@@;W(@96QS92!W
M92!M=7-T('1R=6YC871E+B`J+PH@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H)&QI;F5?;&5N9W1H(#X@.3DX*2![(`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]O=71P=71;72`](&%R<F%Y*"=T97AT)R`]/B!3
M=')I;F<Z.G-U8G-T<B@D;&EN92P@,"P@.3DX+"`D=&AI<RT^7V-H87)S970I
M+"`G;&5V96PG(#T^("1N=6U?<75O=&5S*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1L:6YE(#T@4W1R:6YG.CIS=6)S='(H)&QI;F4L(#DY."P@
M;G5L;"P@)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?;W5T<'5T6UT@/2!A<G)A>2@G=&5X="<@/3X@)&QI;F4L("=L979E;"<@
M/3X@)&YU;5]Q=6]T97,I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("!]('=H:6QE("@A96UP='DH)'1E>'0I*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE(&YU;6)E<B!O9B!L96%D:6YG("<^)R!C:&%R
M86-T97)S(&EN('1H92!T97AT(&EN<'5T+@H@("`@("H@)SXG(&-H87)A8W1E
M<G,@87)E(&1E9FEN960@8GD@4D9#(#(V-#8@=&\@:6YD:6-A=&4@82!Q=6]T
M960@;&EN92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("!4:&4@=&5X="!T;R!A;F%L
M>7IE+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(&YU;6)E
M<B!O9B!L96%D:6YG('%U;W1E(&-H87)A8W1E<G,N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]N=6UQ=6]T97,H)'1E>'0I"B`@("!["B`@("`@("`@<F5T=7)N
M('-T<G-P;B@D=&5X="P@)SXG*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-P
M86-E+7-T=69F<R!I9B!I="!S=&%R=',@=VET:"`G("<@;W(@)SXG(&]R("=&
M<F]M("<L(&]R(&EF"B`@("`@*B!Q=6]T92!D97!T:"!I<R!N;VXM>F5R;R`H
M9F]R(&%E<W1H971I8R!R96%S;VYS('-O('1H870@=&AE<F4@:7,@80H@("`@
M("H@<W!A8V4@869T97(@=&AE("<^)RDN"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@
M("`@("`@5&AE('1E>'0@=&\@<W1U9F8N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N=6U?<75O=&5S("!4:&4@<75O=&4M;&5V96P@;V8@=&AI<R!L:6YE+@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)'1O9FQO=V5D("`@07)E('=E(&-O;G9E
M<G1I;F<@=&\@9FQO=V5D('1E>'0_"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!S='5F9F5D('1E>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]S='5F9B@D=&5X="P@)&YU;5]Q=6]T97,L("1T;V9L;W=E9"D*("`@('L*
M("`@("`@("!I9B`H)'1O9FQO=V5D("8F"B`@("`@("`@("`@("@D;G5M7W%U
M;W1E<R!\?"!P<F5G7VUA=&-H*"(O7B@_.B!\/GQ&<F]M('Q&<F]M)"DO(BP@
M)'1E>'0I*2D@>PH@("`@("`@("`@("!R971U<FX@)R`G("X@)'1E>'0["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D=&5X=#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%5N<W1U9F9S(&$@<W!A8V4@<W1U9F9E9"!L:6YE+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'1E>'0@(%1H92!T97AT('1O('5N<W1U9F8N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!U;G-T=69F960@=&5X="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7W5N<W1U9F8H)'1E>'0I"B`@("!["B`@("`@("`@
M:68@*"%E;7!T>2@D=&5X="D@)B8@*"1T97AT>S!](#T]("<@)RDI('L*("`@
M("`@("`@("`@)'1E>'0@/2!S=6)S='(H)'1E>'0L(#$I.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@)'1E>'0["B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+U1E>'0O1&EF9C,N<&AP````````````````````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$U,C8R(#$P-3$U-#,S-S,U
M(#`R,#<P-0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`H*<F5Q=6ER95]O;F-E("=497AT+T1I9F8N<&AP)SL*"B\J
M*@H@*B!!(&-L87-S(&9O<B!C;VUP=71I;F<@=&AR964@=V%Y(&1I9F9S+@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]497AT7T1I9F8O1&EF9C,N<&AP+'8@
M,2XR+C$P+C,@,C`P-2\Q,"\Q."`Q,3HP,3HS,2!J86X@17AP("0*("H*("H@
M0'!A8VMA9V4@5&5X=%]$:69F"B`J($!A=71H;W(@($=E;V9F<F5Y(%0N($1A
M:7)I:VD@/&1A:7)I:VE`9&%I<FEK:2YO<F<^"B`J+PIC;&%S<R!497AT7T1I
M9F8S(&5X=&5N9',@5&5X=%]$:69F('L*"B`@("`O*BH*("`@("`J($-O;F9L
M:6-T(&-O=6YT97(N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@
M*B\*("`@('9A<B`D7V-O;F9L:6-T:6YG0FQO8VMS(#T@,#L*"B`@("`O*BH*
M("`@("`J($-O;7!U=&5S(&1I9F8@8F5T=V5E;B`S('-E<75E;F-E<R!O9B!S
M=')I;F=S+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D;W)I9R`@("!4
M:&4@;W)I9VEN86P@;&EN97,@=&\@=7-E+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1F:6YA;#$@(%1H92!F:7)S="!V97)S:6]N('1O(&-O;7!A<F4@=&\N"B`@
M("`@*B!`<&%R86T@87)R87D@)&9I;F%L,B`@5&AE('-E8V]N9"!V97)S:6]N
M('1O(&-O;7!A<F4@=&\N"B`@("`@*B\*("`@(&9U;F-T:6]N(%1E>'1?1&EF
M9C,H)&]R:6<L("1F:6YA;#$L("1F:6YA;#(I"B`@("!["B`@("`@("`@:68@
M*&5X=&5N<VEO;E]L;V%D960H)WAD:69F)RDI('L*("`@("`@("`@("`@)&5N
M9VEN92`]("9N97<@5&5X=%]$:69F7T5N9VEN95]X9&EF9B@I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1E;F=I;F4@/2`F;F5W(%1E>'1?1&EF
M9E]%;F=I;F5?;F%T:79E*"D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^
M7V5D:71S(#T@)'1H:7,M/E]D:69F,R@D96YG:6YE+3YD:69F*"1O<FEG+"`D
M9FEN86PQ*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D96YG:6YE+3YD:69F*"1O<FEG+"`D9FEN86PR*2D["B`@("!]"@H@("`@
M9G5N8W1I;VX@;65R9V5D3W5T<'5T*"1L86)E;#$@/2!F86QS92P@)&QA8F5L
M,B`](&9A;'-E*0H@("`@>PH@("`@("`@("1L:6YE<R`](&%R<F%Y*"D["B`@
M("`@("`@9F]R96%C:"`H)'1H:7,M/E]E9&ET<R!A<R`D961I="D@>PH@("`@
M("`@("`@("!I9B`H)&5D:70M/FES0V]N9FQI8W0H*2D@>PH@("`@("`@("`@
M("`@("`@+RH@1DE8344Z('1H:7,@<VAO=6QD('!R;V)A8FQY(&)E(&UO=F5D
M('-O;65W:&5R92!E;'-E+B`J+PH@("`@("`@("`@("`@("`@)&QI;F5S(#T@
M87)R87E?;65R9V4H)&QI;F5S+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)SP\/#P\/#PG("X@*"1L86)E;#$@/R`G("<@
M+B`D;&%B96PQ(#H@)R<I*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1E9&ET+3YF:6YA;#$L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@B/3T]/3T]/2(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5D:70M/F9I;F%L,BP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"<^/CX^
M/CX^)R`N("@D;&%B96PR(#\@)R`G("X@)&QA8F5L,B`Z("<G*2DI.PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]C;VYF;&EC=&EN9T)L;V-K<RLK.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&QI;F5S(#T@87)R
M87E?;65R9V4H)&QI;F5S+"`D961I="T^;65R9V5D*"DI.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&QI;F5S.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]D:69F,R@D961I=',Q+"`D961I=',R*0H@("`@>PH@("`@("`@
M("1E9&ET<R`](&%R<F%Y*"D["B`@("`@("`@)&)B(#T@)FYE=R!497AT7T1I
M9F8S7T)L;V-K0G5I;&1E<B@I.PH*("`@("`@("`D93$@/2!C=7)R96YT*"1E
M9&ET<S$I.PH@("`@("`@("1E,B`](&-U<G)E;G0H)&5D:71S,BD["B`@("`@
M("`@=VAI;&4@*"1E,2!\?"`D93(I('L*("`@("`@("`@("`@:68@*"1E,2`F
M)B`D93(@)B8@:7-?82@D93$L("=497AT7T1I9F9?3W!?8V]P>2<I("8F(&ES
M7V$H)&4R+"`G5&5X=%]$:69F7T]P7V-O<'DG*2D@>PH@("`@("`@("`@("`@
M("`@+RH@5V4@:&%V92!C;W!Y(&)L;V-K<R!F<F]M(&)O=&@@9&EF9G,N(%1H
M:7,@:7,@=&AE("AO;FQY*0H@("`@("`@("`@("`@("`@("H@=&EM92!W92!W
M86YT('1O(&5M:70@82!D:69F,R!C;W!Y(&)L;V-K+B`@1FQU<V@@8W5R<F5N
M=`H@("`@("`@("`@("`@("`@("H@9&EF9C,@9&EF9B!B;&]C:RP@:68@86YY
M+B`J+PH@("`@("`@("`@("`@("`@:68@*"1E9&ET(#T@)&)B+3YF:6YI<V@H
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1E9&ET<UM=(#T@)&5D:70["B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)&YC;W!Y(#T@;6EN
M*"1E,2T^;F]R:6<H*2P@)&4R+3YN;W)I9R@I*3L*("`@("`@("`@("`@("`@
M(&%S<V5R="@D;F-O<'D@/B`P*3L*("`@("`@("`@("`@("`@("1E9&ET<UM=
M(#T@)FYE=R!497AT7T1I9F8S7T]P7V-O<'DH87)R87E?<VQI8V4H)&4Q+3YO
M<FEG+"`P+"`D;F-O<'DI*3L*"B`@("`@("`@("`@("`@("!I9B`H)&4Q+3YN
M;W)I9R@I(#X@)&YC;W!Y*2!["B`@("`@("`@("`@("`@("`@("`@87)R87E?
M<W!L:6-E*"1E,2T^;W)I9RP@,"P@)&YC;W!Y*3L*("`@("`@("`@("`@("`@
M("`@("!A<G)A>5]S<&QI8V4H)&4Q+3YF:6YA;"P@,"P@)&YC;W!Y*3L*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&4Q
M(#T@;F5X="@D961I=',Q*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("`@("!I9B`H)&4R+3YN;W)I9R@I(#X@)&YC;W!Y*2!["B`@("`@("`@
M("`@("`@("`@("`@87)R87E?<W!L:6-E*"1E,BT^;W)I9RP@,"P@)&YC;W!Y
M*3L*("`@("`@("`@("`@("`@("`@("!A<G)A>5]S<&QI8V4H)&4R+3YF:6YA
M;"P@,"P@)&YC;W!Y*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@)&4R(#T@;F5X="@D961I=',R*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M(&EF("@D93$@)B8@)&4R*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1E
M,2T^;W)I9R`F)B`D93(M/F]R:6<I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&YO<FEG(#T@;6EN*"1E,2T^;F]R:6<H*2P@)&4R+3YN;W)I9R@I*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&]R:6<@/2!A<G)A>5]S<&QI8V4H
M)&4Q+3YO<FEG+"`P+"`D;F]R:6<I.PH@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>5]S<&QI8V4H)&4R+3YO<FEG+"`P+"`D;F]R:6<I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D8F(M/FEN<'5T*"1O<FEG*3L*("`@("`@("`@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A*"1E
M,2P@)U1E>'1?1&EF9E]/<%]C;W!Y)RDI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&)B+3YO=70Q*&%R<F%Y7W-P;&EC92@D93$M/F9I;F%L+"`P+"`D
M;F]R:6<I*3L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@
M("`@("`@(&EF("AI<U]A*"1E,BP@)U1E>'1?1&EF9E]/<%]C;W!Y)RDI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&)B+3YO=70R*&%R<F%Y7W-P;&EC
M92@D93(M/F9I;F%L+"`P+"`D;F]R:6<I*3L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*"1E
M,2`F)B`A("1E,2T^;W)I9RD@>PH@("`@("`@("`@("`@("`@("`@("1B8BT^
M;W5T,2@D93$M/F9I;F%L*3L*("`@("`@("`@("`@("`@("`@("`D93$@/2!N
M97AT*"1E9&ET<S$I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@:68@*"1E,B`F)B`A("1E,BT^;W)I9RD@>PH@("`@("`@("`@("`@("`@
M("`@("1B8BT^;W5T,B@D93(M/F9I;F%L*3L*("`@("`@("`@("`@("`@("`@
M("`D93(@/2!N97AT*"1E9&ET<S(I.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H)&5D:70@/2`D8F(M
M/F9I;FES:"@I*2!["B`@("`@("`@("`@("1E9&ET<UM=(#T@)&5D:70["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&5D:71S.PH@("`@?0H*?0H*+RHJ
M"B`J($!P86-K86=E(%1E>'1?1&EF9@H@*B!`875T:&]R("!'96]F9G)E>2!4
M+B!$86ER:6MI(#QD86ER:6MI0&1A:7)I:VDN;W)G/@H@*@H@*B!`86-C97-S
M('!R:79A=&4*("HO"F-L87-S(%1E>'1?1&EF9C-?3W`@>PH*("`@(&9U;F-T
M:6]N(%1E>'1?1&EF9C-?3W`H)&]R:6<@/2!F86QS92P@)&9I;F%L,2`](&9A
M;'-E+"`D9FEN86PR(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1H:7,M/F]R
M:6<@/2`D;W)I9R`_("1O<FEG(#H@87)R87DH*3L*("`@("`@("`D=&AI<RT^
M9FEN86PQ(#T@)&9I;F%L,2`_("1F:6YA;#$@.B!A<G)A>2@I.PH@("`@("`@
M("1T:&ES+3YF:6YA;#(@/2`D9FEN86PR(#\@)&9I;F%L,B`Z(&%R<F%Y*"D[
M"B`@("!]"@H@("`@9G5N8W1I;VX@;65R9V5D*"D*("`@('L*("`@("`@("!I
M9B`H(6ES<V5T*"1T:&ES+3Y?;65R9V5D*2D@>PH@("`@("`@("`@("!I9B`H
M)'1H:7,M/F9I;F%L,2`]/3T@)'1H:7,M/F9I;F%L,BD@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]M97)G960@/2`F)'1H:7,M/F9I;F%L,3L*("`@("`@
M("`@("`@?2!E;'-E:68@*"1T:&ES+3YF:6YA;#$@/3T]("1T:&ES+3YO<FEG
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VUE<F=E9"`]("8D=&AI<RT^
M9FEN86PR.PH@("`@("`@("`@("!](&5L<V5I9B`H)'1H:7,M/F9I;F%L,B`]
M/3T@)'1H:7,M/F]R:6<I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;65R
M9V5D(#T@)B1T:&ES+3YF:6YA;#$["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7VUE<F=E9"`](&9A;'-E.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]M97)G
M960["B`@("!]"@H@("`@9G5N8W1I;VX@:7-#;VYF;&EC="@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3YM97)G960H*2`]/3T@9F%L<V4["B`@("!]
M"@I]"@HO*BH*("H@0'!A8VMA9V4@5&5X=%]$:69F"B`J($!A=71H;W(@($=E
M;V9F<F5Y(%0N($1A:7)I:VD@/&1A:7)I:VE`9&%I<FEK:2YO<F<^"B`J"B`J
M($!A8V-E<W,@<')I=F%T90H@*B\*8VQA<W,@5&5X=%]$:69F,U]/<%]C;W!Y
M(&5X=&5N9',@5&5X=%]$:69F,U]/<"!["@H@("`@9G5N8W1I;VX@5&5X=%]$
M:69F,U]/<%]#;W!Y*"1L:6YE<R`](&9A;'-E*0H@("`@>PH@("`@("`@("1T
M:&ES+3YO<FEG(#T@)&QI;F5S(#\@)&QI;F5S(#H@87)R87DH*3L*("`@("`@
M("`D=&AI<RT^9FEN86PQ(#T@)B1T:&ES+3YO<FEG.PH@("`@("`@("1T:&ES
M+3YF:6YA;#(@/2`F)'1H:7,M/F]R:6<["B`@("!]"@H@("`@9G5N8W1I;VX@
M;65R9V5D*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F]R:6<["B`@
M("!]"@H@("`@9G5N8W1I;VX@:7-#;VYF;&EC="@I"B`@("!["B`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@?0H*?0H*+RHJ"B`J($!P86-K86=E(%1E>'1?
M1&EF9@H@*B!`875T:&]R("!'96]F9G)E>2!4+B!$86ER:6MI(#QD86ER:6MI
M0&1A:7)I:VDN;W)G/@H@*@H@*B!`86-C97-S('!R:79A=&4*("HO"F-L87-S
M(%1E>'1?1&EF9C-?0FQO8VM"=6EL9&5R('L*"B`@("!F=6YC=&EO;B!497AT
M7T1I9F8S7T)L;V-K0G5I;&1E<B@I"B`@("!["B`@("`@("`@)'1H:7,M/E]I
M;FET*"D["B`@("!]"@H@("`@9G5N8W1I;VX@:6YP=70H)&QI;F5S*0H@("`@
M>PH@("`@("`@(&EF("@D;&EN97,I('L*("`@("`@("`@("`@)'1H:7,M/E]A
M<'!E;F0H)'1H:7,M/F]R:6<L("1L:6YE<RD["B`@("`@("`@?0H@("`@?0H*
M("`@(&9U;F-T:6]N(&]U=#$H)&QI;F5S*0H@("`@>PH@("`@("`@(&EF("@D
M;&EN97,I('L*("`@("`@("`@("`@)'1H:7,M/E]A<'!E;F0H)'1H:7,M/F9I
M;F%L,2P@)&QI;F5S*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@
M;W5T,B@D;&EN97,I"B`@("!["B`@("`@("`@:68@*"1L:6YE<RD@>PH@("`@
M("`@("`@("`D=&AI<RT^7V%P<&5N9"@D=&AI<RT^9FEN86PR+"`D;&EN97,I
M.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!I<T5M<'1Y*"D*("`@
M('L*("`@("`@("!R971U<FX@(21T:&ES+3YO<FEG("8F("$D=&AI<RT^9FEN
M86PQ("8F("$D=&AI<RT^9FEN86PR.PH@("`@?0H*("`@(&9U;F-T:6]N(&9I
M;FES:"@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YI<T5M<'1Y*"DI('L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1E9&ET(#T@)FYE=R!497AT7T1I9F8S7T]P*"1T:&ES+3YO
M<FEG+"`D=&AI<RT^9FEN86PQ+"`D=&AI<RT^9FEN86PR*3L*("`@("`@("`@
M("`@)'1H:7,M/E]I;FET*"D["B`@("`@("`@("`@(')E='5R;B`D961I=#L*
M("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@7VEN:70H*0H@("`@>PH@
M("`@("`@("1T:&ES+3YO<FEG(#T@)'1H:7,M/F9I;F%L,2`]("1T:&ES+3YF
M:6YA;#(@/2!A<G)A>2@I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]A<'!E;F0H
M)B1A<G)A>2P@)&QI;F5S*0H@("`@>PH@("`@("`@(&%R<F%Y7W-P;&EC92@D
M87)R87DL('-I>F5O9B@D87)R87DI+"`P+"`D;&EN97,I.PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+U1E>'0O<F535"YP:'``````````````````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`W,3<R(#$P-3$U-#,S-S,U(#`R,#8S,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@5&AE(%1E>'1?<F535#HZ(&-L87-S(')E<')E<V5N=',@82!P87)S92!N
M;V1E(&]F(&$@<F53=')U8W1U<F5D5&5X=`H@*B!D;V-U;65N="!A;F0@<')O
M=FED97,@86X@05!)(&9O<B!P87)S:6YG(')E4W1R=6-T=7)E9%1E>'0@9&]C
M=6UE;G1S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]497AT7W)E4U0O<F53
M5"YP:'`L=B`Q+C4N,3`N-R`R,#`V+S`Q+S`Q(#(Q.C(X.C,X(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($IA<V]N($TN($9E;&EC92`\
M:F9E;&EC94!C<F]N;W-Y<RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U(&1I9"!N;W0*("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!*87-O;B!-+B!&96QI8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M/@H@
M*B!`<&%C:V%G92!497AT7W)E4U0*("HO"F-L87-S(%1E>'1?<F535"!["@H@
M("`@+RHJ"B`@("`@*B!4:&4@<&%R<V4@;F]D92!T>7!E+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'9A<B!S=')I;F<*("`@("`J
M+PH@("`@=F%R("1?='EP93L*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&]F
M('1H92!P87)S92!N;V1E)W,@8VAI;&1R96XN"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)%]C:&EL9')E;B`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!!(&AA
M<V@@;V8@<&%R<V4@;F]D92!P<F]P97)T:65S+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)%]P<F]P97)T:65S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($-O
M;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@
M(%1H:7,@:7,@=&AE(&YO9&4@='EP92X@(%1H92!D969A=6QT(&ES("=$;V-U
M;65N="<N"B`@("`@*B\*("`@(&9U;F-T:6]N(%1E>'1?<F535"@D='EP92`]
M("=$;V-U;65N="<I"B`@("!["B`@("`@("`@)'1H:7,M/E]T>7!E(#T@)'1Y
M<&4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!<'!E;F1S(&$@8VAI;&0@<&%R
M<V4@;F]D92!T;R!T:&ES('!A<G-E(&YO9&4N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9WQ497AT7W)E4U0@)B1C:&EL9"`@5&AI<R!I<R!T:&4@<W1R
M:6YG(&]R(&]B:F5C="!C:&EL9`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@=&\@87!P96YD('1O('1H:7,@<&%R<V4@;F]D92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@87!P96YD0VAI;&0H)B1C:&EL9"D*("`@
M('L*("`@("`@("`D;B`](&-O=6YT*"1T:&ES+3Y?8VAI;&1R96XI.PH@("`@
M("`@(&EF("AI<U]S=')I;F<H)&-H:6QD*2`F)B`D;B`^(#`@)B8@:7-?<W1R
M:6YG*"1T:&ES+3Y?8VAI;&1R96Y;)&X@+2`Q72DI('L*("`@("`@("`@("`@
M)'1H:7,M/E]C:&EL9')E;ELD;B`M(#%=("X]("1C:&EL9#L*("`@("`@("!]
M(&5L<V5I9B`H:7-?<W1R:6YG*"1C:&EL9"DI('L*("`@("`@("`@("`@)'1H
M:7,M/E]C:&EL9')E;EM=(#T@)&-H:6QD.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1T:&ES+3Y?8VAI;&1R96Y;72`]("8D8VAI;&0["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@=F%L=64@;V8@
M82!P87)S92!N;V1E('!R;W!E<G1Y+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&YA;64@("!4:&4@<')O<&5R='DG<R!N86UE+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=F%L=64@(%1H92!P<F]P97)T>2=S('9A;'5E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S9710<F]P97)T>2@D;F%M92P@)'9A;'5E*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?<')O<&5R=&EE<ULD;F%M95T@/2`D=F%L
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V97,@=&AE('9A;'5E
M(&]F(&$@<&%R<V4@;F]D92!P<F]P97)T>2X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1N86UE("!4:&4@<')O<&5R='DG<R!N86UE+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<')O<&5R='DG<R!V86QU92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4')O<&5R='DH)&YA;64I"B`@("![
M"B`@("`@("`@:68@*"%A<G)A>5]K97E?97AI<W1S*"1N86UE+"`D=&AI<RT^
M7W!R;W!E<G1I97,I*2!["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/E]P<F]P97)T:65S6R1N86UE
M73L*("`@('T*"B`@("`O*BH*("`@("`J($1U;7!S('1H:7,@<&%R<V4@;F]D
M92!A;F0@:71S(&-H:6QD<F5N+@H@("`@("H@5&AI<R!M971H;V0@:7,@9F]R
M(&1E8G5G9VEN9R!P=7)P;W-E<RX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D;&5V96P@(%1H:7,@:7,@=&AE(&EN9&5N="!L979E;"!O9B!T:&ES
M('!A<G-E(&YO9&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1U;7`H)&QE=F5L
M(#T@,"D*("`@('L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D;&5V96P[
M("1I*RLI('L*("`@("`@("`@("`@96-H;R`G("`G.PH@("`@("`@('T*("`@
M("`@("!E8VAO("1T:&ES+3Y?='EP92P@)SHZ)SL*("`@("`@("!K<V]R="@D
M=&AI<RT^7W!R;W!E<G1I97,I.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?
M<')O<&5R=&EE<R!A<R`D;F%M92`]/B`D=F%L=64I('L*("`@("`@("`@("`@
M96-H;R`G("<L("1N86UE+"`G/2(G+"!P<F5G7W)E<&QA8V4H)R];(EQ<7%Q=
M+R<L("=<7"0Q)RP@)'9A;'5E*2P*("`@("`@("`@("`@("`@("<B)SL*("`@
M("`@("!]"B`@("`@("`@96-H;R`B7&XB.PH@("`@("`@(&9O<F5A8V@@*"1T
M:&ES+3Y?8VAI;&1R96X@87,@)&-H:6QD*2!["B`@("`@("`@("`@(&EF("AI
M<U]S=')I;F<H)&-H:6QD*2D@>PH@("`@("`@("`@("`@("`@9F]R("@D:2`]
M(#`[("1I(#P@*"1L979E;"`K(#$I.R`D:2LK*2!["B`@("`@("`@("`@("`@
M("`@("`@96-H;R`G("`G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@96-H;R`G(B<L('!R96=?<F5P;&%C92@G+ULB7%Q<7%TO)RP@)UQ<
M)#$G+"`D8VAI;&0I+"`B7")<;B(["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D8VAI;&0M/F1U;7`H)&QE=F5L("L@,2D["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!087)S
M97,@82!R95-T<G5C='5R961497AT(&1O8W5M96YT+@H@("`@("H*("`@("`J
M($!S=&%T:6,*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("!4
M:&ES(&ES('1H92!T97AT(&]F('1H92!D;V-U;65N="!W92!W86YT('1O('!A
M<G-E+@H@("`@("H*("`@("`J($!R971U<FX@5&5X=%]R95-4("!4:&4@<&%R
M<V5D(&1O8W5M96YT(&]R(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@)G!A<G-E*"1T97AT*0H@("`@>PH@("`@("`@(')E
M<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O<F535"]087)S97(N
M<&AP)SL*("`@("`@("`D<&%R<V5R(#T@)FYE=R!497AT7W)E4U1?4&%R<V5R
M*"D["B`@("`@("`@<F5T=7)N("1P87)S97(M/G!A<G-E*"1T97AT*3L*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+UA-3```````````````````````````````
M````````````````````````````````````````````````````````````
M`#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S
M-S,U(#`Q-C8W,``@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O6$U,+U="6$U,
M````````````````````````````````````````````````````````````
M````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`P,#`@,3`U,34T,S,W,S4@,#$W-38Q`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B]834PO5T)834PO1%1$````````````````````````````````
M```````````````````````````````````````````````P,#`W-34@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<S-2`P,C`Q-S0`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+UA-3"]70EA-3"]$5$0O4WEN8TU,
M1&5V26YF+G!H<```````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`U-S0P(#$P
M-3$U-#,S-S,U(#`R,S(S,P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`H*:6YC;'5D95]O;F-E("=834PO5T)834PO
M1%1$+G!H<"<["@HO*BH*("H@)$AO<F1E.B!F<F%M97=O<FLO6$U,7U="6$U,
M+U="6$U,+T141"]3>6YC34Q$979);F8N<&AP+'8@,2XT+C$R+C4@,C`P-B\P
M,R\Q,2`P.3HU-3HR,R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M
M,C`P-B!!;G1H;VYY($UI;&QS(#QA;6EL;'-`<'ER86UI9#8N8V]M/@H@*@H@
M*B!&<F]M($)I;F%R>2!834P@0V]N=&5N="!&;W)M870@4W!E8VEF:6-A=&EO
M;B!697)S:6]N(#$N,RP@,C4@2G5L>2`R,#`Q"B`J(&9O=6YD(&%T(&AT='`Z
M+R]W=W<N=V%P9F]R=6TN;W)G"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0'!A8VMA
M9V4@6$U,7U="6$U,"B`J+PIC;&%S<R!834Q?5T)834Q?1%1$7U-Y;F--3$1E
M=DEN9B!E>'1E;F1S(%A-3%]70EA-3%]$5$0@>PH*("`@(&9U;F-T:6]N(&EN
M:70H*0H@("`@>PH@("`@("`@("\J('1H:7,@8V]D92!T86)L92!H87,@8F5E
M;B!E>'1R86-T960@9G)O;2!L:6)W8GAM;`H@("`@("`@("`J("AS964@:'1T
M<#HO+VQI8G=B>&UL+F%Y;65R:6-K+F-O;2\I(&)Y('5S:6YG"B`@("`@("`@
M("H*("`@("`@("`@*B!G<F5P("=<(EM>7")=*EPB+"`J,'@N+BP@,'@N+B!]
M+"<@=V)X;6Q?=&%B;&5S+F,*("`@("`@("`@*B!\('-E9"`M92`G<R->+BI<
M(EPH6UY<(ETJ7"E<(BP@*EPH,'@N+EPI+"!<*#!X+BY<*2!]+"XJ)",@("`@
M("`@(%PD=&AI<RT^<V5T5&%G7"A<,RP@7")<,5PB7"D[("\O(%PR(V<G"B`@
M("`@("`@("HO"@H@("`@("`@("1T:&ES+3YS971486<H,'@P-2P@(D-40V%P
M(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,#8L(")#5%1Y
M<&4B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@P-RP@(D1A
M=&%3=&]R92(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#`X
M+"`B1&%T851Y<&4B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H
M,'@P.2P@(D1E=DE$(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G
M*#!X,&$L(")$979);F8B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS9714
M86<H,'@P8BP@(D1E=E1Y<"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E
M=%1A9R@P>#!C+"`B1&ES<&QA>4YA;64B*3L@+R\@,'@P,`H@("`@("`@("1T
M:&ES+3YS971486<H,'@P9"P@(D13365M(BD[("\O(#!X,#`*("`@("`@("`D
M=&AI<RT^<V5T5&%G*#!X,&4L(")%>'0B*3L@+R\@,'@P,`H@("`@("`@("1T
M:&ES+3YS971486<H,'@P9BP@(D9W5B(I.R`O+R`P>#`P"B`@("`@("`@)'1H
M:7,M/G-E=%1A9R@P>#$P+"`B2'=6(BD[("\O(#!X,#`*("`@("`@("`D=&AI
M<RT^<V5T5&%G*#!X,3$L(")-86XB*3L@+R\@,'@P,`H@("`@("`@("1T:&ES
M+3YS971486<H,'@Q,BP@(DUA>$=52413:7IE(BD[("\O(#!X,#`*("`@("`@
M("`D=&AI<RT^<V5T5&%G*#!X,3,L(")-87A)1"(I.R`O+R`P>#`P"B`@("`@
M("`@)'1H:7,M/G-E=%1A9R@P>#$T+"`B36%X365M(BD[("\O(#!X,#`*("`@
M("`@("`D=&AI<RT^<V5T5&%G*#!X,34L(")-;V0B*3L@+R\@,'@P,`H@("`@
M("`@("1T:&ES+3YS971486<H,'@Q-BP@(D]%32(I.R`O+R`P>#`P"B`@("`@
M("`@)'1H:7,M/G-E=%1A9R@P>#$W+"`B4&%R86U.86UE(BD[("\O(#!X,#`*
M("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,3@L(")0<F]P3F%M92(I.R`O+R`P
M>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#$Y+"`B4G@B*3L@+R\@,'@P
M,`H@("`@("`@("1T:&ES+3YS971486<H,'@Q82P@(E)X+5!R968B*3L@+R\@
M,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@Q8BP@(E-H87)E9$UE;2(I
M.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#%C+"`B4VEZ92(I
M.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#%D+"`B4V]U<F-E
M4F5F(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,64L(")3
M=U8B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@Q9BP@(E-Y
M;F-#87`B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@R,"P@
M(E-Y;F-4>7!E(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X
M,C$L(")4>"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#(R
M+"`B5'@M4')E9B(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P
M>#(S+"`B5F%L16YU;2(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A
M9R@P>#(T+"`B5F5R0U0B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS9714
M86<H,'@R-2P@(E9E<D141"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E
M=%1A9R@P>#(V+"`B6$YA;2(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E
M=%1A9R@P>#(W+"`B6%9A;"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E
M=%1A9R@P>#(X+"`B551#(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T
M5&%G*#!X,CDL(")3=7!P;W)T3G5M8F5R3V9#:&%N9V5S(BD[("\O(#!X,#`*
M("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,F$L(")3=7!P;W)T3&%R9V5/8FIS
M(BD[("\O(#!X,#`*"B`@("`@("`@:68@*"1T:&ES+3YV97)S:6]N(#T](#`I
M('L*("`@("`@("`@("`@)'1H:7,M/G-E=$-O9&5086=E*#`L("<M+R]364Y#
M34PO+T141"!$979);F8@,2XP+R]%3B<L("=S>6YC;6PZ9&5V:6YF,2XP)RD[
M"B`@("`@("`@("`@("1T:&ES+3YS97154DDH)W-Y;F-M;#ID979I;F8Q+C`G
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^<V5T0V]D
M95!A9V4H,"P@)RTO+U-93D--3"\O1%1$($1E=DEN9B`Q+C$O+T5.)RP@)W-Y
M;F-M;#ID979I;F8Q+C$G*3L*("`@("`@("`@("`@)'1H:7,M/G-E=%5222@G
M<WEN8VUL.F1E=FEN9C$N,2<I.PH@("`@("`@('T*("`@('T*"GT*````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O6$U,+U="6$U,+T141"]3>6YC34Q-971);F8N<&AP````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#0T,C,@,3`U,34T,S,W,S4@,#(S,C,W
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"@II;F-L=61E7V]N8V4@)UA-3"]70EA-3"]$5$0N<&AP)SL*"B\J*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]834Q?5T)834PO5T)834PO1%1$+U-Y;F--
M3$UE=$EN9BYP:'`L=B`Q+C0N,3(N-2`R,#`V+S`S+S$Q(#`Y.C4U.C,S(&IA
M;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($%N=&AO;GD@36EL
M;',@/&%M:6QL<T!P>7)A;6ED-BYC;VT^"B`J"B`J($9R;VT@0FEN87)Y(%A-
M3"!#;VYT96YT($9O<FUA="!3<&5C:69I8V%T:6]N(%9E<G-I;VX@,2XS+"`R
M-2!*=6QY(#(P,#$*("H@9F]U;F0@870@:'1T<#HO+W=W=RYW87!F;W)U;2YO
M<F<*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`<&%C:V%G92!834Q?5T)834P*("HO
M"F-L87-S(%A-3%]70EA-3%]$5$1?4WEN8TU,365T26YF(&5X=&5N9',@6$U,
M7U="6$U,7T141"!["@H@("`@9G5N8W1I;VX@:6YI="@I"B`@("!["B`@("`@
M("`@+RH@=&AI<R!C;V1E('1A8FQE(&AA<R!B965N(&5X=')A8W1E9"!F<F]M
M(&QI8G=B>&UL"B`@("`@("`@("H@*'-E92!H='1P.B\O;&EB=V)X;6PN87EM
M97)I8VLN8V]M+RD@8GD@=7-I;F<*("`@("`@("`@*@H@("`@("`@("`J(&=R
M97`@)UPB6UY<(ETJ7"(L("HP>"XN+"`P>"XN('TL)R!W8GAM;%]T86)L97,N
M8PH@("`@("`@("`J('P@<V5D("UE("=S(UXN*EPB7"A;7EPB72I<*5PB+"`J
M7"@P>"XN7"DL(%PH,'@N+EPI('TL+BHD(R`@("`@("`@7"1T:&ES+3YS9714
M86=<*%PS+"!<(EPQ7")<*3L@+R\@7#(C9R<*("`@("`@("`@*B\*"B`@("`@
M("`@)'1H:7,M/G-E=%1A9R@P>#`U+"`B06YC:&]R(BD[("\O(#!X,#$*("`@
M("`@("`D=&AI<RT^<V5T5&%G*#!X,#8L(")%34DB*3L@+R\@,'@P,0H@("`@
M("`@("1T:&ES+3YS971486<H,'@P-RP@(D9O<FUA="(I.R`O+R`P>#`Q"B`@
M("`@("`@)'1H:7,M/G-E=%1A9R@P>#`X+"`B1G)E94E$(BD[("\O(#!X,#$*
M("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,#DL(")&<F5E365M(BD[("\O(#!X
M,#$*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,&$L("),87-T(BD[("\O(#!X
M,#$*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,&(L(")-87)K(BD[("\O(#!X
M,#$*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,&,L(")-87A-<V=3:7IE(BD[
M("\O(#!X,#$*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,34L(")-87A/8FI3
M:7IE(BD[("\O(#!X,#$*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,&0L(")-
M96TB*3L@+R\@,'@P,0H@("`@("`@("1T:&ES+3YS971486<H,'@P92P@(DUE
M=$EN9B(I.R`O+R`P>#`Q"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#!F+"`B
M3F5X="(I.R`O+R`P>#`Q"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#$P+"`B
M3F5X=$YO;F-E(BD[("\O(#!X,#$*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X
M,3$L(")3:&%R961-96TB*3L@+R\@,'@P,0H@("`@("`@("1T:&ES+3YS9714
M86<H,'@Q,BP@(E-I>F4B*3L@+R\@,'@P,0H@("`@("`@("1T:&ES+3YS9714
M86<H,'@Q,RP@(E1Y<&4B*3L@+R\@,'@P,0H@("`@("`@("1T:&ES+3YS9714
M86<H,'@Q-"P@(E9E<G-I;VXB*3L@+R\@,'@P,0H*("`@("`@("!I9B`H)'1H
M:7,M/G9E<G-I;VX@/3T@,"D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T0V]D
M95!A9V4H,"P@)RTO+U-93D--3"\O1%1$(%-Y;F--3"`Q+C`O+T5.)RP@)W-Y
M;F-M;#IS>6YC;6PQ+C`G*3L*("`@("`@("`@("`@)'1H:7,M/G-E=$-O9&50
M86=E*#$L("<M+R]364Y#34PO+T141"!-971);F8@,2XP+R]%3B<L("=S>6YC
M;6PZ;65T:6YF,2XP)RD["B`@("`@("`@("`@("1T:&ES+3YS97154DDH)W-Y
M;F-M;#IM971I;F8Q+C`G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D=&AI<RT^<V5T0V]D95!A9V4H,"P@)RTO+U-93D--3"\O1%1$(%-Y;F--
M3"`Q+C$O+T5.)RP@)W-Y;F-M;#IS>6YC;6PQ+C$G*3L*("`@("`@("`@("`@
M)'1H:7,M/G-E=$-O9&5086=E*#$L("<M+R]364Y#34PO+T141"!-971);F8@
M,2XQ+R]%3B<L("=S>6YC;6PZ;65T:6YF,2XQ)RD["B`@("`@("`@("`@("1T
M:&ES+3YS97154DDH)W-Y;F-M;#IM971I;F8Q+C$G*3L*("`@("`@("`@("`@
M+R\D=&AI<RT^<V5T55))*"=S>6YC;6PZ;65T:6YF)RD[("\O(&9O<B!S;VUE
M(&9U;FYY(')E87-O;BP@;&EB=V)X;6P@<')O9'5C97,@;F\@.FUE=&EN9C$N
M,2!H97)E"B`@("`@("`@?0H@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O6$U,+U="6$U,+T141"]3>6YC34PN<&AP
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#<Q,S,@,3`U,34T
M,S,W,S4@,#(R,3,U`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"@II;F-L=61E7V]N8V4@)UA-3"]70EA-3"]$5$0N
M<&AP)SL*"B\J*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]834Q?5T)834PO5T)8
M34PO1%1$+U-Y;F--3"YP:'`L=B`Q+C8N,3(N-2`R,#`V+S`S+S$Q(#`Y.C4U
M.C$R(&IA;B!%>'`@)`H@*@H@*B!&<F]M($)I;F%R>2!834P@0V]N=&5N="!&
M;W)M870@4W!E8VEF:6-A=&EO;B!697)S:6]N(#$N,RP@,C4@2G5L>2`R,#`Q
M"B`J(&9O=6YD(&%T(&AT='`Z+R]W=W<N=V%P9F]R=6TN;W)G"B`J"B`J($-O
M<'ER:6=H="`R,#`S+3(P,#8@06YT:&]N>2!-:6QL<R`\86UI;&QS0'!Y<F%M
M:60V+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`<&%C:V%G92!834Q?5T)8
M34P*("HO"F-L87-S(%A-3%]70EA-3%]$5$1?4WEN8TU,(&5X=&5N9',@6$U,
M7U="6$U,7T141"!["@H@("`@9G5N8W1I;VX@:6YI="@I"B`@("!["B`@("`@
M("`@+RH@=&AI<R!C;V1E('1A8FQE(&AA<R!B965N(&5X=')A8W1E9"!F<F]M
M(&QI8G=B>&UL"B`@("`@("`@("H@*'-E92!H='1P.B\O;&EB=V)X;6PN87EM
M97)I8VLN8V]M+RD@8GD@=7-I;F<*("`@("`@("`@*@H@("`@("`@("`J(&=R
M97`@)UPB6UY<(ETJ7"(L("HP>"XN+"`P>"XN('TL)R!W8GAM;%]T86)L97,N
M8PH@("`@("`@("`J('P@<V5D("UE("=S(UXN*EPB7"A;7EPB72I<*5PB+"`J
M7"@P>"XN7"DL(%PH,'@N+EPI('TL+BHD(R`@("`@("`@7"1T:&ES+3YS9714
M86=<*%PS+"!<(EPQ7")<*3L@+R\@7#(C9R<*("`@("`@("`@*B\*"B`@("`@
M("`@)'1H:7,M/G-E=%1A9R@P>#`U+"`B061D(BD[("\O(#!X,#`*("`@("`@
M("`D=&AI<RT^<V5T5&%G*#!X,#8L(")!;&5R="(I.R`O+R`P>#`P"B`@("`@
M("`@)'1H:7,M/G-E=%1A9R@P>#`W+"`B07)C:&EV92(I.R`O+R`P>#`P"B`@
M("`@("`@)'1H:7,M/G-E=%1A9R@P>#`X+"`B071O;6EC(BD[("\O(#!X,#`*
M("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,#DL(")#:&%L(BD[("\O(#!X,#`*
M("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,&$L(")#;60B*3L@+R\@,'@P,`H@
M("`@("`@("1T:&ES+3YS971486<H,'@P8BP@(D-M9$E$(BD[("\O(#!X,#`*
M("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,&,L(")#;612968B*3L@+R\@,'@P
M,`H@("`@("`@("1T:&ES+3YS971486<H,'@P9"P@(D-O<'DB*3L@+R\@,'@P
M,`H@("`@("`@("1T:&ES+3YS971486<H,'@P92P@(D-R960B*3L@+R\@,'@P
M,`H@("`@("`@("1T:&ES+3YS971486<H,'@P9BP@(D1A=&$B*3L@+R\@,'@P
M,`H@("`@("`@("1T:&ES+3YS971486<H,'@Q,"P@(D1E;&5T92(I.R`O+R`P
M>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#$Q+"`B17AE8R(I.R`O+R`P
M>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#$R+"`B1FEN86PB*3L@+R\@
M,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@Q,RP@(D=E="(I.R`O+R`P
M>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#$T+"`B271E;2(I.R`O+R`P
M>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#$U+"`B3&%N9R(I.R`O+R`P
M>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#$V+"`B3&]C3F%M92(I.R`O
M+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#$W+"`B3&]C55))(BD[
M("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,3@L(")-87`B*3L@
M+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@Q.2P@(DUA<$ET96TB
M*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@Q82P@(DUE=&$B
M*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@Q8BP@(DUS9TE$
M(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,6,L(")-<V=2
M968B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@Q9"P@(DYO
M4F5S<"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#%E+"`B
M3F]297-U;'1S(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X
M,68L(")0=70B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@R
M,"P@(E)E<&QA8V4B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H
M,'@R,2P@(E)E<W!54DDB*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS9714
M86<H,'@R,BP@(E)E<W5L=',B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS
M971486<H,'@R,RP@(E-E87)C:"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M
M/G-E=%1A9R@P>#(T+"`B4V5Q=65N8V4B*3L@+R\@,'@P,`H@("`@("`@("1T
M:&ES+3YS971486<H,'@R-2P@(E-E<W-I;VY)1"(I.R`O+R`P>#`P"B`@("`@
M("`@)'1H:7,M/G-E=%1A9R@P>#(V+"`B4V9T1&5L(BD[("\O(#!X,#`*("`@
M("`@("`D=&AI<RT^<V5T5&%G*#!X,C<L(")3;W5R8V4B*3L@+R\@,'@P,`H@
M("`@("`@("1T:&ES+3YS971486<H,'@R."P@(E-O=7)C95)E9B(I.R`O+R`P
M>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#(Y+"`B4W1A='5S(BD[("\O
M(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,F$L(")3>6YC(BD[("\O
M(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,F(L(")3>6YC0F]D>2(I
M.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#)C+"`B4WEN8TAD
M<B(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#)D+"`B4WEN
M8TU,(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,F4L(")4
M87)G970B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@R9BP@
M(E1A<F=E=%)E9B(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P
M>#,P+"`B4F5S97)V960@9F]R(&9U='5R92!U<V4B*3L@+R\@,'@P,`H@("`@
M("`@("1T:&ES+3YS971486<H,'@S,2P@(E9E<D141"(I.R`O+R`P>#`P"B`@
M("`@("`@)'1H:7,M/G-E=%1A9R@P>#,R+"`B5F5R4')O=&\B*3L@+R\@,'@P
M,`H@("`@("`@("1T:&ES+3YS971486<H,'@S,RP@(DYU;6)E<D]F0VAA;F=E
M9"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#,T+"`B36]R
M941A=&$B*3L@+R\@,'@P,`H*("`@("`@("!I9B`H)'1H:7,M/G9E<G-I;VX@
M/3T@,"D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T0V]D95!A9V4H,"P@)RTO
M+U-93D--3"\O1%1$(%-Y;F--3"`Q+C`O+T5.)RP@)W-Y;F-M;#IS>6YC;6PQ
M+C`G*3L*("`@("`@("`@("`@)'1H:7,M/G-E=$-O9&5086=E*#$L("<M+R]3
M64Y#34PO+T141"!-971);F8@,2XP+R]%3B<L("=S>6YC;6PZ;65T:6YF,2XP
M)RD["B`@("`@("`@("`@("1T:&ES+3YS97154DDH)W-Y;F-M;#IS>6YC;6PQ
M+C`G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^<V5T
M0V]D95!A9V4H,"P@)RTO+U-93D--3"\O1%1$(%-Y;F--3"`Q+C$O+T5.)RP@
M)W-Y;F-M;#IS>6YC;6PQ+C$G*3L*("`@("`@("`@("`@)'1H:7,M/G-E=$-O
M9&5086=E*#$L("<M+R]364Y#34PO+T141"!-971);F8@,2XQ+R]%3B<L("=S
M>6YC;6PZ;65T:6YF,2XQ)RD["B`@("`@("`@("`@("1T:&ES+3YS97154DDH
M)W-Y;F-M;#IS>6YC;6PQ+C$G*3L*("`@("`@("!]"B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O6$U,+U="
M6$U,+T-O;G1E;G1(86YD;&5R+G!H<```````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#8P-S$@,3`U,34T,S,W,S4@,#(S,C8U`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]834Q?5T)834PO5T)834PO0V]N=&5N=$AA;F1L97(N
M<&AP+'8@,2XY+C$P+C<@,C`P-B\P-2\P,2`Q,CHP-3HQ-2!J86X@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!!;G1H;VYY($UI;&QS(#QA;6EL
M;'-`<'ER86UI9#8N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y
M;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($9R;VT@0FEN
M87)Y(%A-3"!#;VYT96YT($9O<FUA="!3<&5C:69I8V%T:6]N(%9E<G-I;VX@
M,2XS+"`R-2!*=6QY(#(P,#$*("H@9F]U;F0@870@:'1T<#HO+W=W=RYW87!F
M;W)U;2YO<F<*("H*("H@0'!A8VMA9V4@6$U,7U="6$U,"B`J+PIC;&%S<R!8
M34Q?5T)834Q?0V]N=&5N=$AA;F1L97(@>PH*("`@('9A<B`D7V-U<G)E;G15
M<FD["B`@("!V87(@)%]O=71P=70@/2`G)SL*"B`@("!V87(@)%]O<&%Q=65(
M86YD;&5R.PH*("`@("\J*@H@("`@("H@0VAA<G-E="X*("`@("`J+PH@("`@
M=F%R("1?8VAA<G-E="`]("=55$8M."<["@H@("`@+RHJ"B`@("`@*B!70EA-
M3"!697)S:6]N+@H@("`@("H@,2P@,BP@;W(@,R!S=7!P;W)T960*("`@("`J
M+PH@("`@=F%R("1?=V)X;6Q697)S:6]N(#T@,CL*"B`@("!F=6YC=&EO;B!8
M34Q?5T)834Q?0V]N=&5N=$AA;F1L97(H*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?8W5R<F5N=%5R:2`]("9N97<@6$U,7U="6$U,7TQI9F]1=65U92@I.PH@
M("`@?0H*("`@(&9U;F-T:6]N(')A:7-E17)R;W(H)&5R<F]R*0H@("`@>PH@
M("`@("`@(&EN8VQU9&5?;VYC92`G4$5!4BYP:'`G.PH@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"1E<G)O<BD["B`@("!]"@H@("`@9G5N8W1I
M;VX@9V5T0VAA<G-E=%-T<B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?8VAA<G-E=#L*("`@('T*"B`@("!F=6YC=&EO;B!S971#:&%R<V5T*"1C
M<RD*("`@('L*("`@("`@("`D=&AI<RT^7V-H87)S970@/2`D8W,["B`@("!]
M"@H@("`@9G5N8W1I;VX@9V5T5F5R<VEO;B@I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?=V)X;6Q697)S:6]N.PH@("`@?0H*("`@(&9U;F-T:6]N
M('-E=%9E<G-I;VXH)'8I"B`@("!["B`@("`@("`@)'1H:7,M/E]W8GAM;%9E
M<G-I;VX@/2`R.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$]U='!U="@I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;W5T<'5T.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&=E=$]U='!U=%-I>F4H*0H@("`@>PH@("`@("`@(')E='5R
M;B!S=')L96XH)'1H:7,M/E]O=71P=70I.PH@("`@?0H*("`@(&9U;F-T:6]N
M('-T87)T16QE;65N="@D=7)I+"`D96QE;65N="P@)&%T=')S*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?;W5T<'5T("X]("<\)R`N("1E;&5M96YT.PH*("`@
M("`@("`D8W5R<F5N=%5R:2`]("1T:&ES+3Y?8W5R<F5N=%5R:2T^=&]P*"D[
M"@H@("`@("`@(&EF("@H*"$D8W5R<F5N=%5R:2D@?'P@*"1C=7)R96YT57)I
M("$]("1U<FDI*2`F)B`D=7)I*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T
M<'5T("X]("<@>&UL;G,](B<@+B`D=7)I("X@)R(G.PH@("`@("`@('T*"B`@
M("`@("`@)'1H:7,M/E]C=7)R96YT57)I+3YP=7-H*"1U<FDI.PH*("`@("`@
M("!F;W)E86-H("@D871T<G,@87,@)&%T='(I('L*("`@("`@("`@("`@)'1H
M:7,M/E]O=71P=70@+CT@)R`G("X@)&%T=');)V%T=')I8G5T92==("X@)STB
M)R`N("1A='1R6R=V86QU92==("X@)R(G.PH@("`@("`@('T*"B`@("`@("`@
M)'1H:7,M/E]O=71P=70@+CT@)SXG.PH@("`@?0H*("`@(&9U;F-T:6]N(&5N
M9$5L96UE;G0H)'5R:2P@)&5L96UE;G0I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]O=71P=70@+CT@)SPO)R`N("1E;&5M96YT("X@)SXG.PH*("`@("`@("`D
M=&AI<RT^7V-U<G)E;G15<FDM/G!O<"@I.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&-H87)A8W1E<G,H)'-T<BD*("`@('L*("`@("`@("`D=&AI<RT^7V]U='!U
M="`N/2`D<W1R.PH@("`@?0H*("`@(&9U;F-T:6]N(&]P87%U92@D;RD*("`@
M('L*("`@("`@("`D=&AI<RT^7V]U='!U="`N/2`D;SL*("`@('T*"B`@("!F
M=6YC=&EO;B!S971/<&%Q=65(86YD;&5R*"1O<&%Q=65(86YD;&5R*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?;W!A<75E2&%N9&QE<B`]("1O<&%Q=65(86YD
M;&5R.PH@("`@?0H*("`@(&9U;F-T:6]N(')E;6]V94]P87%U94AA;F1L97(H
M*0H@("`@>PH@("`@("`@('5N<V5T*"1T:&ES+3Y?;W!A<75E2&%N9&QE<BD[
M"B`@("!]"@H@("`@9G5N8W1I;VX@8W)E871E4W5B2&%N9&QE<B@I"B`@("![
M"B`@("`@("`@)&YA;64@/2!G971?8VQA<W,H)'1H:7,I.R`O+R!C;&]N92!C
M=7)R96YT(&-L87-S"B`@("`@("`@)'-H(#T@)FYE=R`D;F%M92@I.PH@("`@
M("`@("1S:"T^<V5T0VAA<G-E="@D=&AI<RT^9V5T0VAA<G-E=%-T<B@I*3L*
M("`@("`@("`D<V@M/G-E=%9E<G-I;VXH)'1H:7,M/F=E=%9E<G-I;VXH*2D[
M"B`@("`@("`@<F5T=7)N("1S:#L*("`@('T*"GT*"F-L87-S(%A-3%]70EA-
M3%],:69O475E=64@>PH*("`@('9A<B`D7W%U975E(#T@87)R87DH*3L*"B`@
M("!F=6YC=&EO;B!834Q?5T)834Q?3&EF;U%U975E*"D*("`@('L*("`@('T*
M"B`@("!F=6YC=&EO;B!P=7-H*"1O8FHI"B`@("!["B`@("`@("`@)'1H:7,M
M/E]Q=65U95M=(#T@)&]B:CL*("`@('T*"B`@("!F=6YC=&EO;B!P;W`H*0H@
M("`@>PH@("`@("`@(&EF("AC;W5N="@D=&AI<RT^7W%U975E*2D@>PH@("`@
M("`@("`@("!R971U<FX@87)R87E?<&]P*"1T:&ES+3Y?<75E=64I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@
M('T*("`@('T*"B`@("!F=6YC=&EO;B!T;W`H*0H@("`@>PH@("`@("`@(&EF
M("@D8V]U;G0@/2!C;W5N="@D=&AI<RT^7W%U975E*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]Q=65U95LD8V]U;G0@+2`Q73L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+UA-3"]7
M0EA-3"]$5$0N<&AP````````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`V-C0W(#$P-3$U-#,S-S,U(#`R,3`P,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@)$AO
M<F1E.B!F<F%M97=O<FLO6$U,7U="6$U,+U="6$U,+T141"YP:'`L=B`Q+C8N
M,3(N-2`R,#`V+S`S+S$Q(#`Y.C4U.C`Q(&IA;B!%>'`@)`H@*@H@*B!&<F]M
M($)I;F%R>2!834P@0V]N=&5N="!&;W)M870@4W!E8VEF:6-A=&EO;B!697)S
M:6]N(#$N,RP@,C4@2G5L>2`R,#`Q"B`J(&9O=6YD(&%T(&AT='`Z+R]W=W<N
M=V%P9F]R=6TN;W)G"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@06YT:&]N
M>2!-:6QL<R`\86UI;&QS0'!Y<F%M:60V+F-O;3X*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B!`<&%C:V%G92!834Q?5T)834P*("HO"F-L87-S(%A-3%]70EA-3%]$
M5$0@>PH*("`@('9A<B`D=F5R<VEO;CL*("`@('9A<B`D:6YT5&%G<SL*("`@
M('9A<B`D:6YT071T<FEB=71E<SL*("`@('9A<B`D<W1R5&%G<SL*("`@('9A
M<B`D<W1R071T<FEB=71E<SL*("`@('9A<B`D:6YT0V]D95!A9V5S.PH@("`@
M=F%R("1S=')#;V1E4&%G97,["B`@("!V87(@)'-T<D-O9&5086=E<U5223L*
M("`@('9A<B`D55)).PH@("`@=F%R("1834Q.4SL*("`@('9A<B`D1%!).PH*
M("`@(&9U;F-T:6]N(%A-3%]70EA-3%]$5$0H)'8I"B`@("!["B`@("`@("`@
M)'1H:7,M/G9E<G-I;VX@/2`D=CL*("`@("`@("`D=&AI<RT^:6YI="@I.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&EN:70H*0H@("`@>PH@("`@?0H*("`@(&9U
M;F-T:6]N('-E=$%T=')I8G5T92@D:6YT071T<FEB=71E+"`D<W1R071T<FEB
M=71E*0H@("`@>PH@("`@("`@("1T:&ES+3YS=')!='1R:6)U=&5S6R1S=')!
M='1R:6)U=&5=(#T@)&EN=$%T=')I8G5T93L*("`@("`@("`D=&AI<RT^:6YT
M071T<FEB=71E<ULD:6YT071T<FEB=71E72`]("1S=')!='1R:6)U=&4["B`@
M("!]"@H@("`@9G5N8W1I;VX@<V5T5&%G*"1I;G1486<L("1S=')486<I"B`@
M("!["B`@("`@("`@)'1H:7,M/G-T<E1A9W-;)'-T<E1A9UT@/2`D:6YT5&%G
M.PH@("`@("`@("1T:&ES+3YI;G1486=S6R1I;G1486==(#T@)'-T<E1A9SL*
M("`@('T*"B`@("!F=6YC=&EO;B!S971#;V1E4&%G92@D:6YT0V]D95!A9V4L
M("1S=')#;V1E4&%G92P@)'-T<D-O9&5086=E55))*0H@("`@>PH@("`@("`@
M("1T:&ES+3YS=')#;V1E4&%G97-54DE;)'-T<D-O9&5086=E55))72`]("1I
M;G1#;V1E4&%G93L*("`@("`@("`D=&AI<RT^<W1R0V]D95!A9V5S6R1S=')#
M;V1E4&%G95T@/2`D:6YT0V]D95!A9V4["B`@("`@("`@)'1H:7,M/FEN=$-O
M9&5086=E<ULD:6YT0V]D95!A9V5=(#T@)'-T<D-O9&5086=E.PH@("`@?0H*
M("`@(&9U;F-T:6]N('1O5&%G4W1R*"1T86<I"B`@("!["B`@("`@("`@<F5T
M=7)N(&ES<V5T*"1T:&ES+3YI;G1486=S6R1T86==*2`_("1T:&ES+3YI;G14
M86=S6R1T86==(#H@9F%L<V4["B`@("!]"@H@("`@9G5N8W1I;VX@=&]!='1R
M:6)U=&53='(H)&%T=')I8G5T92D*("`@('L*("`@("`@("!R971U<FX@:7-S
M970H)'1H:7,M/FEN=%1A9W-;)&%T=')I8G5T95TI(#\@)'1H:7,M/FEN=%1A
M9W-;)&%T=')I8G5T95T@.B!F86QS93L*("`@('T*"B`@("!F=6YC=&EO;B!T
M;T-O9&5086=E4W1R*"1C;V1E4&%G92D*("`@('L*("`@("`@("!R971U<FX@
M:7-S970H)'1H:7,M/FEN=$-O9&5086=E<ULD8V]D95!A9V5=*2`_("1T:&ES
M+3YI;G1#;V1E4&%G97-;)&-O9&5086=E72`Z(&9A;'-E.PH@("`@?0H*("`@
M(&9U;F-T:6]N('1O5&%G26YT*"1T86<I"B`@("!["B`@("`@("`@<F5T=7)N
M(&ES<V5T*"1T:&ES+3YS=')486=S6R1T86==*2`_("1T:&ES+3YS=')486=S
M6R1T86==(#H@9F%L<V4["B`@("!]"@H@("`@9G5N8W1I;VX@=&]!='1R:6)U
M=&5);G0H)&%T=')I8G5T92D*("`@('L*("`@("`@("!R971U<FX@:7-S970H
M)'1H:7,M/G-T<D%T=')I8G5T97-;)&%T=')I8G5T95TI(#\@)'1H:7,M/G-T
M<D%T=')I8G5T97-;)&%T=')I8G5T95T@.B!F86QS93L*("`@('T*"B`@("!F
M=6YC=&EO;B!T;T-O9&5086=E26YT*"1C;V1E4&%G92D*("`@('L*("`@("`@
M("!R971U<FX@:7-S970H)'1H:7,M/G-T<D-O9&5086=E<ULD8V]D95!A9V5=
M*2`_("1T:&ES+3YS=')#;V1E4&%G97-;)&-O9&5086=E72`Z(&9A;'-E.PH@
M("`@?0H*("`@(&9U;F-T:6]N('1O0V]D95!A9V554DDH)'5R:2D*("`@('L*
M("`@("`@("`D=7)I(#T@<W1R=&]L;W=E<B@D=7)I*3L*("`@("`@("!I9B@A
M:7-S970H)'1H:7,M/G-T<D-O9&5086=E<U5225LD=7)I72DI('L*("`@("`@
M("`@("`@9&EE*")U;F%B;&4@=&\@9FEN9"!C;V1E<&%G92!F;W(@)'5R:2%<
M;B(I.PH@("`@("`@('T*"B`@("`@("`@)')E="`](&ES<V5T*"1T:&ES+3YS
M=')#;V1E4&%G97-54DE;)'5R:5TI(#\@)'1H:7,M/G-T<D-O9&5086=E<U52
M25LD=7)I72`Z(&9A;'-E.PH*("`@("`@("!R971U<FX@)')E=#L*("`@('T*
M"B`@("`O*BH*("`@("`J($=E='1E<B!F;W(@<')O<&5R='D@=F5R<VEO;BX*
M("`@("`J($!R971U<FX@5F%L=64@;V8@<')O<&5R='D@=F5R<VEO;BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T5F5R<VEO;B@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3YV97)S:6]N.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4V5T=&5R(&9O<B!P<F]P97)T>2!V97)S:6]N+@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)'8@($YE=R!V86QU92!O9B!P<F]P97)T>2!V97)S:6]N+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S971697)S:6]N*"1V*0H@("`@>PH@("`@("`@
M("1T:&ES+3YV97)S:6]N(#T@)'8["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'
M971T97(@9F]R('!R;W!E<G1Y(%5222X*("`@("`J($!R971U<FX@5F%L=64@
M;V8@<')O<&5R='D@55))+@H@("`@("HO"B`@("!F=6YC=&EO;B!G97154DDH
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^55)).PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5T=&5R(&9O<B!P<F]P97)T>2!54DDN"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1U("!.97<@=F%L=64@;V8@<')O<&5R='D@55))+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!S97154DDH)'4I"B`@("!["B`@("`@("`@
M)'1H:7,M/E5222`]("1U.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T=&5R
M(&9O<B!P<F]P97)T>2!$4$DN"B`@("`@*B!`<F5T=7)N(%9A;'5E(&]F('!R
M;W!E<G1Y($1022X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1%!)*"D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/D1023L*("`@('T*"B`@("`O*BH*
M("`@("`J(%-E='1E<B!F;W(@<')O<&5R='D@1%!)+@H@("`@("H@0'!A<F%M
M($1022!.97<@=F%L=64@;V8@<')O<&5R='D@1%!)+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!S971$4$DH)&0I"B`@("!["B`@("`@("`@)'1H:7,M/D1022`]
M("1D.PH@("`@?0H*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]834PO
M5T)834PO1%1$36%N86=E<BYP:'``````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P-3$U-2`Q,#4Q-30S,S<S-2`P,C(R-C4`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*"FEN8VQU9&5?
M;VYC92`G6$U,+U="6$U,+T141"]3>6YC34PN<&AP)SL*:6YC;'5D95]O;F-E
M("=834PO5T)834PO1%1$+U-Y;F--3$UE=$EN9BYP:'`G.PII;F-L=61E7V]N
M8V4@)UA-3"]70EA-3"]$5$0O4WEN8TU,1&5V26YF+G!H<"<["@HO*BH*("H@
M)$AO<F1E.B!F<F%M97=O<FLO6$U,7U="6$U,+U="6$U,+T141$UA;F%G97(N
M<&AP+'8@,2XS+C$R+C$Q(#(P,#8O,#4O,#$@,3(Z,#4Z,34@:F%N($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@06YT:&]N>2!-:6QL<R`\86UI
M;&QS0'!Y<F%M:60V+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!&<F]M($)I
M;F%R>2!834P@0V]N=&5N="!&;W)M870@4W!E8VEF:6-A=&EO;B!697)S:6]N
M(#$N,RP@,C4@2G5L>0H@*B`R,#`Q(&9O=6YD(&%T(&AT='`Z+R]W=W<N=V%P
M9F]R=6TN;W)G"B`J"B`J($!P86-K86=E(%A-3%]70EA-3`H@*B\*8VQA<W,@
M6$U,7U="6$U,7T141$UA;F%G97(@>PH*("`@("\J*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)%]S=')$5$0@/2!A<G)A>2@I.PH*("`@
M("\J*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]S=')$
M5$154DD@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("HO"B`@("!F=6YC=&EO
M;B!834Q?5T)834Q?1%1$36%N86=E<B@I"B`@("!["B`@("`@("`@)'1H:7,M
M/G)E9VES=&5R1%1$*"<M+R]364Y#34PO+T141"!3>6YC34P@,2XP+R]%3B<L
M("=S>6YC;6PZ<WEN8VUL,2XP)RP@;F5W(%A-3%]70EA-3%]$5$1?4WEN8TU,
M*#`I*3L*("`@("`@("`D=&AI<RT^<F5G:7-T97)$5$0H)RTO+U-93D--3"\O
M1%1$(%-Y;F--3"`Q+C$O+T5.)RP@)W-Y;F-M;#IS>6YC;6PQ+C$G+"!N97<@
M6$U,7U="6$U,7T141%]3>6YC34PH,2DI.PH*("`@("`@("`D=&AI<RT^<F5G
M:7-T97)$5$0H)RTO+U-93D--3"\O1%1$($UE=$EN9B`Q+C`O+T5.)RP@)W-Y
M;F-M;#IM971I;F8Q+C`G+"!N97<@6$U,7U="6$U,7T141%]3>6YC34Q-971)
M;F8H,"DI.PH@("`@("`@("1T:&ES+3YR96=I<W1E<D141"@G+2\O4UE.0TU,
M+R]$5$0@365T26YF(#$N,2\O14XG+"`G<WEN8VUL.FUE=&EN9C$N,2<L(&YE
M=R!834Q?5T)834Q?1%1$7U-Y;F--3$UE=$EN9B@Q*2D["@H@("`@("`@("1T
M:&ES+3YR96=I<W1E<D141"@G+2\O4UE.0TU,+R]$5$0@1&5V26YF(#$N,"\O
M14XG+"`G<WEN8VUL.F1E=FEN9C$N,"<L(&YE=R!834Q?5T)834Q?1%1$7U-Y
M;F--3$1E=DEN9B@P*2D["B`@("`@("`@)'1H:7,M/G)E9VES=&5R1%1$*"<M
M+R]364Y#34PO+T141"!$979);F8@,2XQ+R]%3B<L("=S>6YC;6PZ9&5V:6YF
M,2XQ)RP@;F5W(%A-3%]70EA-3%]$5$1?4WEN8TU,1&5V26YF*#$I*3L*("`@
M('T*"B`@("`O*BH*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=$EN<W1A;F-E
M*"1P=6)L:6-)9&5N=&EF:65R*0H@("`@>PH@("`@("`@("1P=6)L:6-)9&5N
M=&EF:65R(#T@<W1R=&]L;W=E<B@D<'5B;&EC261E;G1I9FEE<BD["B`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3Y?<W1R1%1$6R1P=6)L:6-)9&5N=&EF:65R
M72DI('L*("`@("`@("`@("`@)&1T9"`]("8D=&AI<RT^7W-T<D141%LD<'5B
M;&EC261E;G1I9FEE<ET["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)&1T9"`](&YU;&P["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D9'1D.PH@
M("`@?0H*("`@("\J*@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T26YS=&%N
M8V554DDH)'5R:2D*("`@('L*("`@("`@("`D=7)I(#T@<W1R=&]L;W=E<B@D
M=7)I*3L*"B`@("`@("`@+R\@<V]M92!M86YU86P@:&%C:W,Z"B`@("`@("`@
M:68@*"1U<FD@/3T@)W-Y;F-M;#IS>6YC;6PG*2!["B`@("`@("`@("`@("1U
M<FD@/2`G<WEN8VUL.G-Y;F-M;#$N,"<["B`@("`@("`@?0H@("`@("`@(&EF
M("@D=7)I(#T]("=S>6YC;6PZ;65T:6YF)RD@>PH@("`@("`@("`@("`D=7)I
M(#T@)W-Y;F-M;#IM971I;F8Q+C`G.PH@("`@("`@('T*("`@("`@("!I9B`H
M)'5R:2`]/2`G<WEN8VUL.F1E=FEN9B<I('L*("`@("`@("`@("`@)'5R:2`]
M("=S>6YC;6PZ9&5V:6YF,2XP)SL*("`@("`@("!]"@H@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7W-T<D141%5225LD=7)I72DI('L*("`@("`@("`@("`@
M)&1T9"`]("8D=&AI<RT^7W-T<D141%5225LD=7)I73L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D9'1D(#T@;G5L;#L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1D=&0["B`@("!]"@H@("`@+RHJ"B`@("`@*B\*("`@(&9U
M;F-T:6]N(')E9VES=&5R1%1$*"1P=6)L:6-)9&5N=&EF:65R+"`D=7)I+"`F
M)&1T9"D*("`@('L*("`@("`@("`D<'5B;&EC261E;G1I9FEE<B`]('-T<G1O
M;&]W97(H)'!U8FQI8TED96YT:69I97(I.PH@("`@("`@("1D=&0M/G-E=$10
M22@D<'5B;&EC261E;G1I9FEE<BD["@H@("`@("`@("1T:&ES+3Y?<W1R1%1$
M6R1P=6)L:6-)9&5N=&EF:65R72`]("1D=&0["B`@("`@("`@)'1H:7,M/E]S
M=')$5$154DE;<W1R=&]L;W=E<B@D=7)I*5T@/2`D9'1D.PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+UA-3"]70EA-3"]%;F-O9&5R+G!H
M<```````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#(W-S(P(#$P
M-3$U-#,S-S,U(#`R,3<T,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`H*:6YC;'5D95]O;F-E("=834PO5T)834PN
M<&AP)SL*:6YC;'5D95]O;F-E("=834PO5T)834PO0V]N=&5N=$AA;F1L97(N
M<&AP)SL*:6YC;'5D95]O;F-E("=834PO5T)834PO1%1$36%N86=E<BYP:'`G
M.PII;F-L=61E7V]N8V4@)TAO<F1E+U-T<FEN9RYP:'`G.PH*+RHJ"B`J("1(
M;W)D93H@9G)A;65W;W)K+UA-3%]70EA-3"]70EA-3"]%;F-O9&5R+G!H<"QV
M(#$N,C4N,3`N,3,@,C`P-B\P-2\S,2`Q-SHP-CHS-R!S96QS:WD@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!!;G1H;VYY($UI;&QS(#QA;6EL
M;'-`<'ER86UI9#8N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($9R;VT@0FEN
M87)Y(%A-3"!#;VYT96YT($9O<FUA="!3<&5C:69I8V%T:6]N(%9E<G-I;VX@
M,2XS+"`R-2!*=6QY"B`J(#(P,#$@9F]U;F0@870@:'1T<#HO+W=W=RYW87!F
M;W)U;2YO<F<*("H*("H@0'!A8VMA9V4@6$U,7U="6$U,"B`J+PIC;&%S<R!8
M34Q?5T)834Q?16YC;V1E<B!E>'1E;F1S(%A-3%]70EA-3%]#;VYT96YT2&%N
M9&QE<B!["@H@("`@=F%R("1?<W1R:6YG<R`](&%R<F%Y*"D["@H@("`@=F%R
M("1?<W1R:6YG5&%B;&4["@H@("`@=F%R("1?:&%S5W)I='1E;DAE861E<B`]
M(&9A;'-E.PH*("`@('9A<B`D7V1T9#L*"B`@("!V87(@)%]O=71P=70@/2`G
M)SL*"B`@("!V87(@)%]U<FES(#T@87)R87DH*3L*"B`@("!V87(@)%]U<FE.
M=6US(#T@87)R87DH*3L*"B`@("!V87(@)%]C=7)R96YT55)).PH*("`@('9A
M<B`D7W-U8E!A<G-E<B`](&YU;&P["B`@("!V87(@)%]S=6)087)S97)3=&%C
M:R`](#`["@H@("`@+RHJ"B`@("`@*B!4:&4@6$U,('!A<G-E<BX*("`@("`J
M"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D7W!A<G-E
M<CL*"B`@("`O*BH*("`@("`J(%1H92!$5$0@36%N86=E<BX*("`@("`J"B`@
M("`@*B!`=F%R(%A-3%]70EA-3%]$5$1-86YA9V5R"B`@("`@*B\*("`@('9A
M<B`D7V1T9$UA;F%G97(["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@6$U,7U="6$U,7T5N8V]D97(H*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?9'1D36%N86=E<B`]("9N97<@6$U,7U="6$U,
M7T141$UA;F%G97(H*3L*("`@("`@("`D=&AI<RT^7W-T<FEN9U1A8FQE(#T@
M)FYE=R!834Q?5T)834Q?2&%S:%1A8FQE*"D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!486ME('1H92!I;G!U="`D>&UL(&%N9"!T=7)N(&ET(&EN=&\@5T)8
M34PN(%1H:7,@:7,@7VYO=%\@=&AE"B`@("`@*B!I;G1E;F1E9"!W87D@;V8@
M=7-I;F<@=&AI<R!C;&%S<RX@270@:7,@9&5R:79E9"!F<F]M"B`@("`@*B!#
M;VYT96YT:&%N9&QE<B!A;F0@;VYE('-H;W5L9"!U<V4@:70@87,@82!#;VYT
M96YT2&%N9&QE<B!A;F0*("`@("`J('!R;V1U8V4@=&AE(%A-3"US=')U8W1U
M<F4@=VET:"!S=&%R=$5L96UE;G0H*2P@96YD16QE;65N="@I+`H@("`@("H@
M86YD(&-H87)A8W1E<G,H*2X*("`@("`J+PH@("`@9G5N8W1I;VX@96YC;V1E
M*"1X;6PI"B`@("!["B`@("`@("`@+R\@0W)E871E('1H92!834P@<&%R<V5R
M(&%N9"!S970@;65T:&]D(')E9F5R96YC97,N"B`@("`@("`@)'1H:7,M/E]P
M87)S97(@/2!X;6Q?<&%R<V5R7V-R96%T95]N<R@D=&AI<RT^7V-H87)S970I
M.PH@("`@("`@('AM;%]S971?;V)J96-T*"1T:&ES+3Y?<&%R<V5R+"`D=&AI
M<RD["B`@("`@("`@>&UL7W!A<G-E<E]S971?;W!T:6]N*"1T:&ES+3Y?<&%R
M<V5R+"!834Q?3U!424].7T-!4T5?1D],1$E.1RP@9F%L<V4I.PH@("`@("`@
M('AM;%]S971?96QE;65N=%]H86YD;&5R*"1T:&ES+3Y?<&%R<V5R+"`G7W-T
M87)T16QE;65N="<L("=?96YD16QE;65N="<I.PH@("`@("`@('AM;%]S971?
M8VAA<F%C=&5R7V1A=&%?:&%N9&QE<B@D=&AI<RT^7W!A<G-E<BP@)U]C:&%R
M86-T97)S)RD["B`@("`@("`@>&UL7W-E=%]P<F]C97-S:6YG7VEN<W1R=6-T
M:6]N7VAA;F1L97(H)'1H:7,M/E]P87)S97(L("<G*3L*("`@("`@("!X;6Q?
M<V5T7V5X=&5R;F%L7V5N=&ET>5]R969?:&%N9&QE<B@D=&AI<RT^7W!A<G-E
M<BP@)R<I.PH*("`@("`@("!I9B`H(7AM;%]P87)S92@D=&AI<RT^7W!A<G-E
M<BP@)'AM;"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*'-P<FEN=&8H)UA-3"!E<G)O<CH@)7,@870@;&EN92`E9"<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('AM;%]E
M<G)O<E]S=')I;F<H>&UL7V=E=%]E<G)O<E]C;V1E*"1T:&ES+3Y?<&%R<V5R
M*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('AM;%]G971?8W5R<F5N=%]L:6YE7VYU;6)E<B@D=&AI<RT^7W!A<G-E
M<BDI*3L*("`@("`@("!]"@H@("`@("`@('AM;%]P87)S97)?9G)E92@D=&AI
M<RT^7W!A<G-E<BD["@H@("`@("`@(')E='5R;B`D=&AI<RT^7V]U='!U=#L*
M("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@=VEL;"!W<FET92!T:&4@8V]R
M<F5C="!H96%D97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET94AE861E
M<B@D=7)I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9'1D(#T@)B1T:&ES+3Y?
M9'1D36%N86=E<BT^9V5T26YS=&%N8V554DDH)'5R:2D["B`@("`@("`@:68@
M*"$D=&AI<RT^7V1T9"D@>PH@("`@("`@("`@("`O+R!43T1/.B!P<F]P97(@
M97)R;W(@:&%N9&QI;F<*("`@("`@("`@("`@9&EE*"=5;F%B;&4@=&\@9FEN
M9"!D=&0@9F]R("<@+B`D=7)I*3L*("`@("`@("!]"B`@("`@("`@)&1P:5-T
M<FEN9R`]("1T:&ES+3Y?9'1D+3YG971$4$DH*3L*"B`@("`@("`@+R\@4V5T
M(%9E<G-I;VX@3G5M8F5R(&9R;VT@4V5C=&EO;B`U+C0*("`@("`@("`O+R!V
M97)S:6]N(#T@=5]I;G0X"B`@("`@("`@+R\@8W5R<F5N=&QY(#$L(#(@;W(@
M,PH@("`@("`@("1T:&ES+3YW<FET959E<G-I;VY.=6UB97(H)'1H:7,M/E]W
M8GAM;%9E<G-I;VXI.PH*("`@("`@("`O+R!3970@1&]C=6UE;G0@4'5B;&EC
M($ED971I9FEE<B!F<F]M(%-E8W1I;VX@-2XU"B`@("`@("`@+R\@<'5B;&EC
M:60@/2!M8E]U7VEN=#,R('P@*"!Z97)O(&EN9&5X("D*("`@("`@("`O+R!Z
M97)O(#T@=5]I;G0X"B`@("`@("`@+R\@8V]N=&%I;FEN9R!T:&4@=F%L=64@
M>F5R;R`H,"D*("`@("`@("`O+R!4:&4@86-T=6%L($1022!I<R!D971E<FUI
M;F5D(&%F=&5R('1H92!3=')I;F<@5&%B;&4@:7,@<F5A9"X*("`@("`@("`D
M=&AI<RT^=W)I=&5$;V-U;65N=%!U8FQI8TED96YT:69I97(H)&1P:5-T<FEN
M9RP@)'1H:7,M/E]S=')I;F=S*3L*"B`@("`@("`@+R\@4V5T($-H87)S970@
M9G)O;2`U+C8*("`@("`@("`O+R!C:&%R<V5T(#T@;6)?=5]I;G0S,@H@("`@
M("`@("1T:&ES+3YW<FET94-H87)S970H)'1H:7,M/E]C:&%R<V5T*3L*"B`@
M("`@("`@+R\@4V5T(%-T<FEN9R!486)L92!F<F]M(#4N-PH@("`@("`@("\O
M('-T<F(Q(#T@;&5N9W1H("IB>71E"B`@("`@("`@)'1H:7,M/G=R:71E4W1R
M:6YG5&%B;&4H)'1H:7,M/E]S=')I;F=S+"`D=&AI<RT^7V-H87)S970L("1T
M:&ES+3Y?<W1R:6YG5&%B;&4I.PH*("`@("`@("`D=&AI<RT^7V-U<G)E;G15
M4DD@/2`D=7)I.PH*("`@("`@("`D=&AI<RT^7VAA<U=R:71T96Y(96%D97(@
M/2!T<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N('=R:71E5F5R<VEO;DYU;6)E
M<B@D=F5R<VEO;BD*("`@('L*("`@("`@("`D=&AI<RT^7V]U='!U="`N/2!C
M:'(H)'9E<G-I;VXI.PH@("`@?0H*("`@(&9U;F-T:6]N('=R:71E1&]C=6UE
M;G10=6)L:6-)9&5N=&EF:65R*"1D<&E3=')I;F<L("8D<W1R:6YG<RD*("`@
M('L*("`@("`@("`D:2`](%A-3%]70EA-3#HZ9V5T1%!)26YT*"1D<&E3=')I
M;F<I.PH*("`@("`@("!I9B`H)&D@/3T@,"D@>PH@("`@("`@("`@("`D<W1R
M:6YG<ULP72`]("1D<&E3=')I;F<["B`@("`@("`@("`@("1T:&ES+3Y?;W5T
M<'5T("X](&-H<B@P*3L*("`@("`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@
M8VAR*#`I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(%A-3%]70EA-
M3#HZ:6YT5&]-0E5);G0S,B@D=&AI<RT^7V]U='!U="P@)&DI.PH@("`@("`@
M('T*("`@('T*"B`@("!F=6YC=&EO;B!W<FET94-H87)S970H)&-H87)S970I
M"B`@("!["B`@("`@("`@)&-S(#T@6$U,7U="6$U,.CIG971#:&%R<V5T26YT
M*"1C:&%R<V5T*3L*"B`@("`@("`@:68@*"1C<R`]/2`P*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G56YS=7!P;W)T960@0VAA
M<G-E=#H@)R`N("1C:&%R<V5T*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!834Q?5T)834PZ.FEN=%1O34)526YT,S(H)'1H:7,M/E]O=71P=70L
M("1C<RD["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N('=R:71E4W1R
M:6YG5&%B;&4H)'-T<FEN9W,L("1C:&%R<V5T+"`D<W1R:6YG5&%B;&4I"B`@
M("!["B`@("`@("`@)'-T<FEN9T)Y=&5S(#T@87)R87DH*3L*("`@("`@("`D
M8V]U;G0@/2`P.PH@("`@("`@(&9O<F5A8V@@*"1S=')I;F=S(&%S("1S='(I
M('L*("`@("`@("`@("`@)&)Y=&5S(#T@)'1H:7,M/E]G971">71E<R@D<W1R
M+"`D8VAA<G-E="D["B`@("`@("`@("`@("1S=')I;F=">71E<R`](&%R<F%Y
M7VUE<F=E*"1S=')I;F=">71E<RP@)&)Y=&5S*3L*("`@("`@("`@("`@)&YU
M;&Q,96YG=&@@/2`D=&AI<RT^7V%D9$YU;&Q">71E*"1B>71E<RD["B`@("`@
M("`@("`@("1T:&ES+3Y?<W1R:6YG5&%B;&4M/G-E="@D<W1R+"`D8V]U;G0I
M.PH@("`@("`@("`@("`D8V]U;G0@*ST@8V]U;G0H)&)Y=&5S*2`K("1N=6QL
M3&5N9W1H.PH@("`@("`@('T*"B`@("`@("`@6$U,7U="6$U,.CII;G14;TU"
M54EN=#,R*"1T:&ES+3Y?;W5T<'5T+"!C;W5N="@D<W1R:6YG0GET97,I*3L*
M("`@("`@("`D=&AI<RT^7V]U='!U="`N/2!I;7!L;V1E*"<G+"`D<W1R:6YG
M0GET97,I.PH@("`@?0H*("`@(&9U;F-T:6]N('=R:71E4W1R:6YG*"1S='(L
M("1C<RD*("`@('L*("`@("`@("`D8GET97,@/2`D=&AI<RT^7V=E=$)Y=&5S
M*"1S='(L("1C<RD["B`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@:6UP;&]D
M92@G)RP@)&)Y=&5S*3L*("`@("`@("`D=&AI<RT^=W)I=&5.=6QL*"1C<RD[
M"B`@("!]"@H@("`@9G5N8W1I;VX@=W)I=&5.=6QL*"1C:&%R<V5T*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?;W5T<'5T("X](&-H<B@P*3L*("`@("`@("!R
M971U<FX@,3L*("`@('T*"B`@("!F=6YC=&EO;B!?861D3G5L;$)Y=&4H)B1B
M>71E<RD*("`@('L*("`@("`@("`D8GET97-;72`](&-H<B@P*3L*("`@("`@
M("!R971U<FX@,3L*("`@('T*"B`@("!F=6YC=&EO;B!?9V5T0GET97,H)'-T
M<FEN9RP@)&-S*0H@("`@>PH@("`@("`@("1S=')I;F<@/2!3=')I;F<Z.F-O
M;G9E<G1#:&%R<V5T*"1S=')I;F<L("1C<RP@)W5T9BTX)RD["B`@("`@("`@
M)&YB>71E<R`]('-T<FQE;B@D<W1R:6YG*3L*"B`@("`@("`@)&)Y=&5S(#T@
M87)R87DH*3L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D;F)Y=&5S.R`D
M:2LK*2!["B`@("`@("`@("`@("1B>71E<UM=(#T@)'-T<FEN9WLD:7T["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&)Y=&5S.PH@("`@?0H*("`@(&9U
M;F-T:6]N(%]S<&QI=%5222@D=&%G*0H@("`@>PH@("`@("`@("1P87)T<R`]
M(&5X<&QO9&4H)SHG+"`D=&%G*3L*("`@("`@("`D;F%M92`](&%R<F%Y7W!O
M<"@D<&%R=',I.PH@("`@("`@("1U<FD@/2!I;7!L;V1E*"<Z)RP@)'!A<G1S
M*3L*("`@("`@("!R971U<FX@87)R87DH)'5R:2P@)&YA;64I.PH@("`@?0H*
M("`@(&9U;F-T:6]N('-T87)T16QE;65N="@D=7)I+"`D;F%M92P@)&%T=')I
M8G5T97,I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?<W5B4&%R<V5R(#T]
M(&YU;&PI('L*("`@("`@("`@("`@:68@*"$D=&AI<RT^7VAA<U=R:71T96Y(
M96%D97(I('L*("`@("`@("`@("`@("`@("1T:&ES+3YW<FET94AE861E<B@D
M=7)I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)'1H:7,M/E]C
M=7)R96YT55))("$]("1U<FDI('L*("`@("`@("`@("`@("`@("1T:&ES+3YC
M:&%N9V5C;V1E<&%G92@D=7)I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H)'1H:7,M/E]S=6)087)S97(@/3T@;G5L;"D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/G=R:71E5&%G*"1N86UE+"`D871T<FEB=71E<RP@=')U
M92P@)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<W5B4&%R<V5R+3YS=&%R=$5L96UE;G0H
M)'5R:2PD;F%M92P@)&%T=')I8G5T97,I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]S=6)087)S97)3=&%C
M:RLK.PH@("`@("`@("`@("`D=&AI<RT^7W-U8E!A<G-E<BT^<W1A<G1%;&5M
M96YT*"1U<FDL)&YA;64L)&%T=')I8G5T97,I.PH@("`@("`@('T*("`@('T*
M"B`@("!F=6YC=&EO;B!?<W1A<G1%;&5M96YT*"1P87)S97(L("1T86<L("1A
M='1R:6)U=&5S*0H@("`@>PH@("`@("`@(&QI<W0H)'5R:2P@)&YA;64I(#T@
M)'1H:7,M/E]S<&QI=%5222@D=&%G*3L*"B`@("`@("`@)'1H:7,M/G-T87)T
M16QE;65N="@D=7)I+"`D;F%M92P@)&%T=')I8G5T97,I.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&]P87%U92@D;RD*("`@('L*("`@("`@("`D=&AI<RT^7V]U
M='!U="`N/2!C:'(H6$U,7U="6$U,7T=,3T)!3%]43TM%3E]/4$%1544I.PH@
M("`@("`@(%A-3%]70EA-3#HZ:6YT5&]-0E5);G0S,B@D=&AI<RT^7V]U='!U
M="P@<W1R;&5N*"1O*2D["B`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@)&\[
M"B`@("!]"@H@("`@9G5N8W1I;VX@8VAA<F%C=&5R<R@D8VAA<G,I"B`@("![
M"B`@("`@("`@)&-H87)S(#T@=')I;2@D8VAA<G,I.PH*("`@("`@("!I9B`H
M<W1R;&5N*"1C:&%R<RDI('L*("`@("`@("`@("`@+RH@5V4@9&5F:6YI=&5L
M>2!D;VXG="!W86YT(&%N>2!W:&ET97-P86-E+B`J+PH@("`@("`@("`@("!I
M9B`H)'1H:7,M/E]S=6)087)S97(@/3T@;G5L;"D@>PH@("`@("`@("`@("`@
M("`@)&D@/2`D=&AI<RT^7W-T<FEN9U1A8FQE+3YG970H)&-H87)S*3L*("`@
M("`@("`@("`@("`@(&EF("@D:2`A/2!N=6QL*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]O=71P=70@+CT@8VAR*%A-3%]70EA-3%]'3$]"04Q?
M5$]+14Y?4U127U0I.PH@("`@("`@("`@("`@("`@("`@(%A-3%]70EA-3#HZ
M:6YT5&]-0E5);G0S,B@D=&AI<RT^7V]U='!U="P@)&DI.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V]U
M='!U="`N/2!C:'(H6$U,7U="6$U,7T=,3T)!3%]43TM%3E]35%)?22D["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G=R:71E4W1R:6YG*"1C:&%R<RP@
M)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<W5B4&%R<V5R
M+3YC:&%R86-T97)S*"1C:&%R<RD["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("!]"@H@("`@9G5N8W1I;VX@7V-H87)A8W1E<G,H)'!A<G-E<BP@)&-H
M87)S*0H@("`@>PH@("`@("`@("1T:&ES+3YC:&%R86-T97)S*"1C:&%R<RD[
M"B`@("!]"@H@("`@9G5N8W1I;VX@=W)I=&5486<H)&YA;64L("1A='1R<RP@
M)&AA<T-O;G1E;G0L("1C<RD*("`@('L*("`@("`@("!I9B`H)&%T=')S("$]
M(&YU;&P@)B8@(6-O=6YT*"1A='1R<RDI('L*("`@("`@("`@("`@)&%T=')S
M(#T@;G5L;#L*("`@("`@("!]"@H@("`@("`@("1T(#T@)'1H:7,M/E]D=&0M
M/G1O5&%G26YT*"1N86UE*3L*("`@("`@("!I9B`H)'0@/3T@+3$I('L*("`@
M("`@("`@("`@)&D@/2`D=&AI<RT^7W-T<FEN9U1A8FQE+3YG970H)&YA;64I
M.PH@("`@("`@("`@("!I9B`H)&D@/3T@;G5L;"D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1N86UE("X@)R!I<R!N;W0@
M9F]U;F0@:6X@4W1R:6YG(%1A8FQE(&]R($141"<I.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@:68@*"1A='1R<R`]/2!N=6QL("8F
M("$D:&%S0V]N=&5N="D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M;W5T<'5T("X](&-H<BA834Q?5T)834Q?1TQ/0D%,7U1/2T5.7TQ)5$5204PI
M.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1A='1R<R`]/2!N=6QL("8F
M("1H87-#;VYT96YT*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]O
M=71P=70@+CT@8VAR*%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?3$E415)!3%]!
M*3L*("`@("`@("`@("`@("`@('T@96QS96EF("@D871T<G,@(3T@;G5L;"`F
M)B`D:&%S0V]N=&5N="D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M;W5T<'5T("X](&-H<BA834Q?5T)834Q?1TQ/0D%,7U1/2T5.7TQ)5$5204Q?
M0RD["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&%T=')S("$](&YU;&P@
M)B8@(21H87-#;VYT96YT*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]O=71P=70@+CT@8VAR*%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?3$E415)!
M3%]!0RD["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@6$U,
M7U="6$U,.CII;G14;TU"54EN=#,R*"1T:&ES+3Y?;W5T<'5T+"`D:2D["B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H
M)&%T=')S(#T](&YU;&P@)B8@(21H87-#;VYT96YT*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7V]U='!U="`N/2!C:'(H)'0I.PH@("`@("`@("`@("!]
M(&5L<V5I9B`H)&%T=')S(#T](&YU;&P@)B8@)&AA<T-O;G1E;G0I('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T("X](&-H<B@D="!\(#8T*3L*
M("`@("`@("`@("`@?2!E;'-E:68@*"1A='1R<R`A/2!N=6QL("8F("1H87-#
M;VYT96YT*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U='!U="`N/2!C
M:'(H)'0@?"`Q,C@I.PH@("`@("`@("`@("!](&5L<V5I9B`H)&%T=')S("$]
M(&YU;&P@)B8@(21H87-#;VYT96YT*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7V]U='!U="`N/2!C:'(H)'0@?"`Q.3(I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!I9B`H)&%T=')S("$](&YU;&P@)B8@:7-?87)R
M87DH)&%T=')S*2`F)B!C;W5N="@D871T<G,I(#X@,"D@>PH@("`@("`@("`@
M("`D=&AI<RT^=W)I=&5!='1R:6)U=&5S*"1A='1R<RP@)&-S*3L*("`@("`@
M("!]"B`@("!]"@H@("`@9G5N8W1I;VX@=W)I=&5!='1R:6)U=&5S*"1A='1R
M<RP@)&-S*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1A='1R<R!A<R`D;F%M
M92`]/B`D=F%L=64I('L*("`@("`@("`@("`@)'1H:7,M/G=R:71E071T<FEB
M=71E*"1N86UE+"`D=F%L=64L("1C<RD["B`@("`@("`@?0H*("`@("`@("`D
M=&AI<RT^7V]U='!U="`N/2!C:'(H6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%
M3D0I.PH@("`@?0H*("`@(&9U;F-T:6]N('=R:71E071T<FEB=71E*"1N86UE
M+"`D=F%L=64L("1C<RD*("`@('L*("`@("`@("`D82`]("1T:&ES+3Y?9'1D
M+3YT;T%T=')I8G5T92@D;F%M92D["B`@("`@("`@:68@*"1A(#T]("TQ*2![
M"B`@("`@("`@("`@("1I(#T@)'1H:7,M/E]S=')I;F=486)L92T^9V5T*"1N
M86UE*3L*("`@("`@("`@("`@:68@*"1I(#T](&YU;&PI('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D;F%M92`N("<@:7,@
M;F]T(&9O=6YD(&EN(%-T<FEN9R!486)L92!O<B!$5$0G*3L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T("X]
M(&-H<BA834Q?5T)834Q?1TQ/0D%,7U1/2T5.7TQ)5$5204PI.PH@("`@("`@
M("`@("`@("`@6$U,7U="6$U,.CII;G14;TU"54EN=#,R*"1T:&ES+3Y?;W5T
M<'5T+"`D:2D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=&AI<RT^7V]U='!U="`N/2`D83L*("`@("`@("!]"@H@("`@
M("`@("1I(#T@)'1H:7,M/E]S=')I;F=486)L92T^9V5T*"1N86UE*3L*("`@
M("`@("!I9B`H)&D@(3T@;G5L;"D@>PH@("`@("`@("`@("`D=&AI<RT^7V]U
M='!U="`N/2!C:'(H6$U,7U="6$U,7T=,3T)!3%]43TM%3E]35%)?5"D["B`@
M("`@("`@("`@(%A-3%]70EA-3#HZ:6YT5&]-0E5);G0S,B@D=&AI<RT^7V]U
M='!U="P@)&DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES
M+3Y?;W5T<'5T("X](&-H<BA834Q?5T)834Q?1TQ/0D%,7U1/2T5.7U-44E])
M*3L*("`@("`@("`@("`@)'1H:7,M/G=R:71E4W1R:6YG*"1V86QU92P@)&-S
M*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@96YD16QE;65N="@D
M=7)I+"`D;F%M92D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]S=6)087)S
M97(@/3T@;G5L;"D@>PH@("`@("`@("`@("`D=&AI<RT^7V]U='!U="`N/2!C
M:'(H6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%3D0I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1T:&ES+3Y?<W5B4&%R<V5R+3YE;F1%;&5M96YT
M*"1U<FDL("1N86UE*3L*("`@("`@("`@("`@)'1H:7,M/E]S=6)087)S97)3
M=&%C:RTM.PH*("`@("`@("`@("`@:68@*"1T:&ES+3Y?<W5B4&%R<V5R4W1A
M8VL@/3T@,"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@
M8VAR*%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?3U!!455%*3L*"B`@("`@("`@
M("`@("`@("!834Q?5T)834PZ.FEN=%1O34)526YT,S(H)'1H:7,M/E]O=71P
M=70L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M<W1R;&5N*"1T:&ES+3Y?<W5B4&%R<V5R+3YG971/=71P=70H*2DI.PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@)'1H:7,M/E]S=6)087)S
M97(M/F=E=$]U='!U="@I.PH*("`@("`@("`@("`@("`@("1T:&ES+3Y?<W5B
M4&%R<V5R(#T@;G5L;#L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*
M"B`@("!F=6YC=&EO;B!?96YD16QE;65N="@D<&%R<V5R+"`D=&%G*0H@("`@
M>PH@("`@("`@(&QI<W0H)'5R:2P@)&YA;64I(#T@)'1H:7,M/E]S<&QI=%52
M22@D=&%G*3L*("`@("`@("`D=&AI<RT^96YD16QE;65N="@D=7)I+"`D;F%M
M92D["B`@("!]"@H@("`@9G5N8W1I;VX@8VAA;F=E8V]D97!A9V4H)'5R:2D*
M("`@('L*("`@("`@("`O+R!`=&]D;SH@=&AI<R!I<R!A(&AA8VLA"B`@("`@
M("`@:68@*"1T:&ES+3Y?9'1D+3YG971697)S:6]N*"D@/3T@,2`F)B`A<')E
M9U]M871C:"@G+S%<+C$D+R<L("1U<FDI*2!["B`@("`@("`@("`@("1U<FD@
M+CT@)S$N,2<["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^7V1T9"T^
M9V5T5F5R<VEO;B@I(#T](#`@)B8@(7!R96=?;6%T8V@H)R\Q7"XP)"\G+"`D
M=7)I*2D@>PH@("`@("`@("`@("`D=7)I("X]("<Q+C`G.PH@("`@("`@('T*
M("`@("`@("`*("`@("`@("`D8W`@/2`D=&AI<RT^7V1T9"T^=&]#;V1E4&%G
M955222@D=7)I*3L*("`@("`@("!I9B`H<W1R;&5N*"1C<"DI('L*("`@("`@
M("`@("`@)'1H:7,M/E]D=&0@/2`F)'1H:7,M/E]D=&1-86YA9V5R+3YG971)
M;G-T86YC955222@D=7)I*3L*"B`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T
M("X](&-H<BA834Q?5T)834Q?1TQ/0D%,7U1/2T5.7U-7251#2%]004=%*3L*
M("`@("`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@8VAR*"1C<"D["B`@("`@
M("`@("`@("1T:&ES+3Y?8W5R<F5N=%5222`]("1U<FD["@H@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?<W5B4&%R<V5R(#T@)FYE=R!8
M34Q?5T)834Q?16YC;V1E<BAT<G5E*3L*("`@("`@("`@("`@)'1H:7,M/E]S
M=6)087)S97)3=&%C:R`](#$["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@1V5T=&5R(&9O<B!P<F]P97)T>2!O=71P=70N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$]U='!U="@I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?;W5T<'5T.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$]U='!U=%-I
M>F4H*0H@("`@>PH@("`@("`@(')E='5R;B!S=')L96XH)'1H:7,M/E]O=71P
M=70I.PH@("`@?0H*?0H`````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M6$U,+U="6$U,+T1E8V]D97(N<&AP````````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P-#<W,3<@,3`U,34T,S,W,S4@,#(Q-S,V`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"@II;F-L
M=61E7V]N8V4@)UA-3"]70EA-3"YP:'`G.PII;F-L=61E7V]N8V4@)UA-3"]7
M0EA-3"]$5$1-86YA9V5R+G!H<"<["FEN8VQU9&5?;VYC92`G6$U,+U="6$U,
M+T-O;G1E;G1(86YD;&5R+G!H<"<["@HO*BH*("H@)$AO<F1E.B!F<F%M97=O
M<FLO6$U,7U="6$U,+U="6$U,+T1E8V]D97(N<&AP+'8@,2XR,BXQ,"XX(#(P
M,#8O,#$O,#$@,C$Z,C@Z-#4@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`S+3(P,#8@06YT:&]N>2!-:6QL<R`\86UI;&QS0'!Y<F%M:60V+F-O;3X*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!&<F]M($)I;F%R>2!834P@0V]N=&5N="!&
M;W)M870@4W!E8VEF:6-A=&EO;B!697)S:6]N(#$N,RP@,C4@2G5L>0H@*B`R
M,#`Q(&9O=6YD(&%T(&AT='`Z+R]W=W<N=V%P9F]R=6TN;W)G"B`J"B`J($!P
M86-K86=E(%A-3%]70EA-3`H@*B\*8VQA<W,@6$U,7U="6$U,7T1E8V]D97(@
M97AT96YD<R!834Q?5T)834Q?0V]N=&5N=$AA;F1L97(@>PH*("`@("\J*@H@
M("`@("H@1&]C=6UE;G0@4'5B;&EC($ED96YT:69I97(@='EP90H@("`@("H@
M,2!M8E]U7VEN=#,R('=E;&P@:VYO=VX@='EP90H@("`@("H@,B!S=')I;F<@
M=&%B;&4*("`@("`J(&9R;VT@<W!E8R!B=70@8V]N=F5R=&5D(&EN=&\@82!S
M=')I;F<N"B`@("`@*@H@("`@("H@1&]C=6UE;G0@4'5B;&EC($ED96YT:69I
M97(*("`@("`J(%5S960@=VET:"!D<&E4>7!E+@H@("`@("HO"B`@("!V87(@
M)%]D<&D["@H@("`@+RHJ"B`@("`@*B!3=')I;F<@=&%B;&4@87,@9&5F:6YE
M9"!I;B`U+C<*("`@("`J+PH@("`@=F%R("1?<W1R:6YG5&%B;&4@/2!A<G)A
M>2@I.PH*("`@("\J*@H@("`@("H@0V]N=&5N="!H86YD;&5R+@H@("`@("H@
M0W5R<F5N=&QY(&IU<W0@;W5T<'5T<R!R87<@6$U,+@H@("`@("HO"B`@("!V
M87(@)%]C:#L*"B`@("!V87(@)%]T86=$5$0["@H@("`@=F%R("1?<')E=D%T
M=')I8G5T94141#L*"B`@("!V87(@)%]A='1R:6)U=&5$5$0["@H@("`@+RHJ
M"B`@("`@*B!3=&%T92!V87)I86)L97,N"B`@("`@*B\*("`@('9A<B`D7W1A
M9U-T86-K(#T@87)R87DH*3L*("`@('9A<B`D7VES071T<FEB=71E.PH@("`@
M=F%R("1?:7-$871A(#T@9F%L<V4["@H@("`@=F%R("1?97)R;W(@/2!F86QS
M93L*"B`@("`O*BH*("`@("`J(%1H92!$5$0@36%N86=E<BX*("`@("`J"B`@
M("`@*B!`=F%R(%A-3%]70EA-3%]$5$1-86YA9V5R"B`@("`@*B\*("`@('9A
M<B`D7V1T9$UA;F%G97(["@H@("`@+RHJ"B`@("`@*B!4:&4@<W1R:6YG('!O
M<VET:6]N+@H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@
M("!V87(@)%]S=')P;W,["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@6$U,7U="6$U,7T1E8V]D97(H*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?9'1D36%N86=E<B`]("9N97<@6$U,7U="6$U,
M7T141$UA;F%G97(H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE
M(&-O;G1E;G1(86YD;&5R('1H870@=VEL;"!R96-E:79E('1H92!O=71P=70@
M;V8@=&AE"B`@("`@*B!D96-O9&EN9RX*("`@("`J"B`@("`@*B!`<&%R86T@
M6$U,7U="6$U,7T-O;G1E;G1(86YD;&5R("1C:"!4:&4@8V]N=&5N=$AA;F1L
M97(*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T0V]N=&5N=$AA;F1L97(H)B1C
M:"D*("`@('L*("`@("`@("`D=&AI<RT^7V-H(#T@)B1C:#L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;B!O;F4@8GET92!F<F]M('1H92!I;G!U="!S
M=')E86TN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:6YP=70@(%1H
M92!70EA-3"!I;G!U="!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$)Y=&4H)&EN<'5T*0H@("`@>PH@("`@("`@(')E='5R;B!O<F0H)&EN<'5T
M>R1T:&ES+3Y?<W1R<&]S*RM]*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1A
M:V5S(&$@5T)834P@:6YP=70@9&]C=6UE;G0@86YD(')E='5R;G,@9&5C;V1E
M9"!834PN"B`@("`@*B!(;W=E=F5R('1H92!P<F5F97)R960@86YD(&UO<F4@
M969F96-I96YT(&UE=&AO9"!I<R!T;PH@("`@("H@=7-E(&1E8V]D92@I(')A
M=&AE<B!T:&%N(&1E8V]D951O4W1R:6YG*"D@86YD(&AA=F4@86X*("`@("`J
M(&%P<')O<')I871E(&-O;G1E;G1(86YD;&5R(&1E86P@=VET:"!T:&4@9&5C
M;V1E9"!D871A+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'=B>&UL
M("!4:&4@5T)834P@9&]C=6UE;G0@=&\@9&5C;V1E+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@9&5C;V1E9"!834P@9&]C=6UE;G0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&1E8V]D951O4W1R:6YG*"1W8GAM;"D*("`@
M('L*("`@("`@("`D=&AI<RT^7V-H(#T@)FYE=R!834Q?5T)834Q?0V]N=&5N
M=$AA;F1L97(H*3L*"B`@("`@("`@)'(@/2`D=&AI<RT^9&5C;V1E*"1W8GAM
M;"D["B`@("`@("`@:68@*&ES7V$H)'(L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1R.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M)'1H:7,M/E]C:"T^9V5T3W5T<'5T*"D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!486ME<R!A(%="6$U,(&EN<'5T(&1O8W5M96YT(&%N9"!D96-O9&5S(&ET
M+@H@("`@("H@1&5C;V1I;F<@<F5S=6QT(&ES(&1I<F5C=&QY('!A<W-E9"!T
M;R!T:&4@8V]N=&5N=$AA;F1L97(N"B`@("`@*B!!(&-O;G1E;G1H86YD;&5R
M(&UU<W0@8F4@<V5T('5S:6YG('-E=$-O;G1E;G1(86YD;&5R"B`@("`@*B!P
M<FEO<B!T;R!I;G9O8V%T:6]N(&]F('1H:7,@;65T:&]D"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=V)X;6P@(%1H92!70EA-3"!D;V-U;65N="!T
M;R!D96-O9&4N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O
M;B!S=6-C97-S(&]R(%!%05)?17)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&1E8V]D92@D=V)X;6PI"B`@("!["B`@("`@("`@)'1H:7,M/E]E<G)O<B`]
M(&9A;'-E.R`O+R!R97-E="!S=&%T90H*("`@("`@("`D=&AI<RT^7W-T<G!O
M<R`](#`["@H@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7V-H*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)TYO($-O;G1E;G1H
M86YD;&5R(&1E9FEN960N)RD["B`@("`@("`@?0H*("`@("`@("`O+R!'970@
M5F5R<VEO;B!.=6UB97(@9G)O;2!396-T:6]N(#4N-`H@("`@("`@("\O('9E
M<G-I;VX@/2!U7VEN=#@*("`@("`@("`O+R!C=7)R96YT;'D@,2P@,B!O<B`S
M"B`@("`@("`@)'1H:7,M/E]W8GAM;%9E<G-I;VX@/2`D=&AI<RT^9V5T5F5R
M<VEO;DYU;6)E<B@D=V)X;6PI.PH*("`@("`@("`O+R!'970@1&]C=6UE;G0@
M4'5B;&EC($ED971I9FEE<B!F<F]M(%-E8W1I;VX@-2XU"B`@("`@("`@+R\@
M<'5B;&EC:60@/2!M8E]U7VEN=#,R('P@*'IE<F\@:6YD97@I"B`@("`@("`@
M+R\@>F5R;R`]('5?:6YT.`H@("`@("`@("\O($-O;G1A:6YI;F<@=&AE('9A
M;'5E('IE<F\@*#`I"B`@("`@("`@+R\@5&AE(&%C='5A;"!$4$D@:7,@9&5T
M97)M:6YE9"!A9G1E<B!T:&4@4W1R:6YG(%1A8FQE(&ES(')E860N"B`@("`@
M("`@)&1P:5-T<G5C="`]("1T:&ES+3YG971$;V-U;65N=%!U8FQI8TED96YT
M:69I97(H)'=B>&UL*3L*"B`@("`@("`@+R\@1V5T($-H87)S970@9G)O;2`U
M+C8*("`@("`@("`O+R!C:&%R<V5T(#T@;6)?=5]I;G0S,@H@("`@("`@("1T
M:&ES+3Y?8VAA<G-E="`]("1T:&ES+3YG971#:&%R<V5T*"1W8GAM;"D["@H@
M("`@("`@("\O($=E="!3=')I;F<@5&%B;&4@9G)O;2`U+C<*("`@("`@("`O
M+R!S=')B,2`](&QE;F=T:"`J8GET90H@("`@("`@("1T:&ES+3YR971R:65V
M95-T<FEN9U1A8FQE*"1W8GAM;"D["@H@("`@("`@("\O($=E="!$;V-U;65N
M="!0=6)L:6,@261E=&EF:65R(&9R;VT@4V5C=&EO;B`U+C4N"B`@("`@("`@
M)'1H:7,M/E]D<&D@/2`D=&AI<RT^9V5T1&]C=6UE;G10=6)L:6-)9&5N=&EF
M:65R26UP;"@D9'!I4W1R=6-T6R=D<&E4>7!E)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9'!I4W1R=6-T6R=D<&E.=6UB97(G72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<W1R:6YG5&%B;&4I.PH*("`@("`@("`O+R!.;W<@=&AE(')E86P@
M9G5N(&)E9VEN<RX*("`@("`@("`O+R!&<F]M(%-E8W1I;VYS(#4N,B!A;F0@
M-2XX"@H*("`@("`@("`O+R!$969A=6QT(&-O;G1E;G0@:&%N9&QE<BX*("`@
M("`@("`D=&AI<RT^7V1T9$UA;F%G97(@/2`F;F5W(%A-3%]70EA-3%]$5$1-
M86YA9V5R*"D["@H@("`@("`@("\O($=E="!T:&4@<W1A<G1I;F<@1%1$+@H@
M("`@("`@("1T:&ES+3Y?=&%G1%1$(#T@)'1H:7,M/E]D=&1-86YA9V5R+3YG
M971);G-T86YC92@D=&AI<RT^7V1P:2D["@H@("`@("`@(&EF("@A)'1H:7,M
M/E]T86=$5$0I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*"=.;R!$5$0@9F]U;F0@9F]R("<*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`N("1T:&ES+3Y?9'!I("X@)R\G"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@+B`D9'!I4W1R=6-T6R=D<&E.=6UB97(G72D["B`@("`@
M("`@?0H*("`@("`@("`D=&AI<RT^7V%T=')I8G5T94141"`]("1T:&ES+3Y?
M=&%G1%1$.PH*("`@("`@("!W:&EL92`H96UP='DH)'1H:7,M/E]E<G)O<BD@
M)B8@)'1H:7,M/E]S=')P;W,@/"!S=')L96XH)'=B>&UL*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7V1E8V]D92@D=V)X;6PI.PH@("`@("`@('T*("`@("`@
M("!I9B`H(65M<'1Y*"1T:&ES+3Y?97)R;W(I*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7V5R<F]R.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!G971697)S:6]N3G5M8F5R*"1I
M;G!U="D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F=E=$)Y=&4H)&EN
M<'5T*3L*("`@('T*"B`@("!F=6YC=&EO;B!G971$;V-U;65N=%!U8FQI8TED
M96YT:69I97(H)&EN<'5T*0H@("`@>PH@("`@("`@("1I(#T@6$U,7U="6$U,
M.CI-0E5);G0S,E1O26YT*"1I;G!U="P@)'1H:7,M/E]S=')P;W,I.PH@("`@
M("`@(&EF("@D:2`]/2`P*2!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@G
M9'!I5'EP92<@/3X@,BP*("`@("`@("`@("`@("`@("`@("`@("`@("=D<&E.
M=6UB97(G(#T^("1T:&ES+3YG971">71E*"1I;G!U="DI.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@G9'!I5'EP92<@/3X@
M,2P*("`@("`@("`@("`@("`@("`@("`@("`@("=D<&E.=6UB97(G(#T^("1I
M*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@9V5T1&]C=6UE;G10
M=6)L:6-)9&5N=&EF:65R26UP;"@D9'!I5'EP92P@)&1P:4YU;6)E<BD*("`@
M('L*("`@("`@("!I9B`H)&1P:51Y<&4@/3T@,2D@>PH@("`@("`@("`@("!R
M971U<FX@6$U,7U="6$U,.CIG971$4$E3=')I;F<H)&1P:4YU;6)E<BD["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YG9713
M=')I;F=486)L945N=')Y*"1D<&E.=6UB97(I.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-H87)A8W1E<B!E;F-O9&EN
M9RX@3VYL>2!D969A=6QT(&-H87)A8W1E<@H@("`@("H@96YC;V1I;F=S(&9R
M;VT@2C)312!A<F4@<W5P<&]R=&5D+B`@1G)O;0H@("`@("H@:'1T<#HO+W=W
M=RYI86YA+F]R9R]A<W-I9VYM96YT<R]C:&%R86-T97(M<V5T<R!A;F0*("`@
M("`J(&AT='`Z+R]J879A+G-U;BYC;VTO:C)S92\Q+C0N,B]D;V-S+V%P:2]J
M879A+VYI;R]C:&%R<V5T+T-H87)S970N:'1M;`H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971#:&%R<V5T*"1I;G!U="D*("`@('L*("`@("`@("`D8W,@/2!8
M34Q?5T)834PZ.DU"54EN=#,R5&]);G0H)&EN<'5T+"`D=&AI<RT^7W-T<G!O
M<RD["B`@("`@("`@<F5T=7)N(%A-3%]70EA-3#HZ9V5T0VAA<G-E=%-T<FEN
M9R@D8W,I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S('1H92!S
M=')I;F<@=&%B;&4N"B`@("`@*B!4:&4@<W1R:6YG('1A8FQE(&-O;G-I<W1S
M(&]F(&%N(&UB7W5?:6YT,S(@;&5N9W1H"B`@("`@*B!A;F0@=&AE;B!L96YG
M=&@@8GET97,@9F]R;6EN9R!T:&4@=&%B;&4N"B`@("`@*B!2969E<F5N8V5S
M('1O('1H92!S=')I;F<@=&%B;&4@<F5F97(@=&\@=&AE"B`@("`@*B!S=&%R
M=&EN9R!P;W-I=&EO;B!O9B!T:&4@*&YU;&P@=&5R;6EN871E9"D*("`@("`J
M('-T<FEN9R!I;B!T:&ES('1A8FQE+@H@("`@("HO"B`@("!F=6YC=&EO;B!R
M971R:65V95-T<FEN9U1A8FQE*"1I;G!U="D*("`@('L*("`@("`@("`D<VEZ
M92`](%A-3%]70EA-3#HZ34)526YT,S)4;TEN="@D:6YP=70L("1T:&ES+3Y?
M<W1R<&]S*3L*("`@("`@("`D=&AI<RT^7W-T<FEN9U1A8FQE(#T@<W5B<W1R
M*"1I;G!U="P@)'1H:7,M/E]S=')P;W,L("1S:7IE*3L*("`@("`@("`D=&AI
M<RT^7W-T<G!O<R`K/2`D<VEZ93L*("`@("`@("`O+R!P<FEN="`B<W1R:6YG
M=&%B;&4H)'-I>F4I.B(@+B`D=&AI<RT^7W-T<FEN9U1A8FQE("XB7&XB.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&=E=%-T<FEN9U1A8FQE16YT<GDH)&EN9&5X
M*0H@("`@>PH@("`@("`@(&EF("@D:6YD97@@/CT@<W1R;&5N*"1T:&ES+3Y?
M<W1R:6YG5&%B;&4I*2!["B`@("`@("`@("`@("1T:&ES+3Y?97)R;W(@/0H@
M("`@("`@("`@("`@("`@)'1H:7,M/E]C:"T^<F%I<V5%<G)O<B@G26YV86QI
M9"!O9F9S970@)R`N("1I;F1E>`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@+B`G('9A;'5E(&5N8V]U;G1E<F5D(&%R;W5N9"!P;W-I
M=&EO;B`G"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N
M("1T:&ES+3Y?<W1R<&]S"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`N("<N($)R;VME;B!W8GAM;#\G*3L*("`@("`@("`@("`@<F5T
M=7)N("<G.PH@("`@("`@('T*"B`@("`@("`@+R\@8V]P>2!O9B!M971H;V0@
M=&5R;7-T<B!B=70@=VET:&]U="!M;V1I9FEC871I;VX@;V8@=&AI<RT^7W-T
M<G!O<PH*("`@("`@("`D<W1R(#T@)R,G.R`O+R!M=7-T('-T87)T('=I=&@@
M;F]N96UP='D@<W1R:6YG('1O(&%L;&]W(&%R<F%Y(&%C8V5S<PH*("`@("`@
M("`D:2`](#`["B`@("`@("`@)&-H(#T@)'1H:7,M/E]S=')I;F=486)L95LD
M:6YD97@K*UT["B`@("`@("`@:68@*&]R9"@D8V@I(#T](#`I('L*("`@("`@
M("`@("`@<F5T=7)N("<G.R`O+R!D;VXG="!R971U<FX@)R,G"B`@("`@("`@
M?0H*("`@("`@("!W:&EL92`H;W)D*"1C:"D@(3T@,"D@>PH@("`@("`@("`@
M("`D<W1R6R1I*RM=(#T@)&-H.PH@("`@("`@("`@("!I9B`H)&EN9&5X(#X]
M('-T<FQE;B@D=&AI<RT^7W-T<FEN9U1A8FQE*2D@>PH@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&-H(#T@)'1H
M:7,M/E]S=')I;F=486)L95LD:6YD97@K*UT["B`@("`@("`@?0H@("`@("`@
M("\O('!R:6YT(")S=')I;F<@=&%B;&4@96YT<GDZ("1S=')<;B(["B`@("`@
M("`@<F5T=7)N("1S='(["@H@("`@?0H*("`@(&9U;F-T:6]N(%]D96-O9&4H
M)&EN<'5T*0H@("`@>PH@("`@("`@("1T;VME;B`]("1T:&ES+3YG971">71E
M*"1I;G!U="D["B`@("`@("`@)'-T<B`]("<G.PH*("`@("`@("`O+R!P<FEN
M="`B<&]S:71I;VXZ("(@+B`D=&AI<RT^7W-T<G!O<R`N("(@=&]K96XZ("(@
M+B`D=&]K96X@+B`B('-T<C$P.B`B("X@<W5B<W1R*"1I;G!U="P@)'1H:7,M
M/E]S=')P;W,L(#$P*2`N(")<;B([("\O($!T;V1O.B!R96UO=F4@9&5B=6<@
M;W5T<'5T"@H@("`@("`@('-W:71C:"`H)'1O:V5N*2!["B`@("`@("`@8V%S
M92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7U-44E]).@H@("`@("`@("`@("`O
M+R!396-T:6]N(#4N."XT+C$*("`@("`@("`@("`@)'-T<B`]("1T:&ES+3YT
M97)M<W1R*"1I;G!U="D["B`@("`@("`@("`@("1T:&ES+3Y?8V@M/F-H87)A
M8W1E<G,H)'-T<BD["B`@("`@("`@("`@("\O('!R:6YT(")S='(Z)'-T<EQN
M(CL@+R\@0%1/1$\@4F5M;W9E(&1E8G5G(&-O9&4*("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@(&-A<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%3E]35%)?
M5#H*("`@("`@("`@("`@+R\@4V5C=&EO;B`U+C@N-"XQ"B`@("`@("`@("`@
M("1X(#T@6$U,7U="6$U,.CI-0E5);G0S,E1O26YT*"1I;G!U="P@)'1H:7,M
M/E]S=')P;W,I.PH@("`@("`@("`@("`D<W1R(#T@)'1H:7,M/F=E=%-T<FEN
M9U1A8FQE16YT<GDH)'@I.PH@("`@("`@("`@("`D=&AI<RT^7V-H+3YC:&%R
M86-T97)S*"1S='(I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S
M92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T585%])7S`Z"B`@("`@("`@8V%S
M92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T585%])7S$Z"B`@("`@("`@8V%S
M92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T585%])7S(Z"B`@("`@("`@("`@
M("\O(%-E8W1I;VX@-2XX+C0N,@H@("`@("`@("`@("`D<W1R(#T@)'1H:7,M
M/G1E<FUS='(H)&EN<'5T*3L*("`@("`@("`@("`@)'1H:7,M/E]C:"T^8VAA
M<F%C=&5R<R@D<W1R*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?5%\P.@H@("`@("`@(&-A
M<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?5%\Q.@H@("`@("`@(&-A
M<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?5%\R.@H@("`@("`@("`@
M("`O+R!396-T:6]N(#4N."XT+C(*("`@("`@("`@("`@)'-T<B`]("1T:&ES
M+3YG9713=')I;F=486)L945N='DH6$U,7U="6$U,.CI-0E5);G0S,E1O26YT
M*"1I;G!U="P@)'1H:7,M/E]S=')P;W,I*3L*("`@("`@("`@("`@)'1H:7,M
M/E]C:"T^8VAA<F%C=&5R<R@D<W1R*3L*("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@(&-A<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?,#H*("`@
M("`@("!C87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?15A47S$Z"B`@("`@
M("`@8V%S92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T585%\R.@H@("`@("`@
M("`@("`O+R!396-T:6]N(#4N."XT+C(*("`@("`@("`@("`@)&5X=&5N<VEO
M;B`]("1T:&ES+3YG971">71E*"1I;G!U="D["B`@("`@("`@("`@("1T:&ES
M+3Y?8V@M/F-H87)A8W1E<G,H)&5X=&5N<VEO;BD["B`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("!C87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?14Y4
M2519.@H@("`@("`@("`@("`O+R!396-T:6]N(#4N."XT+C,*("`@("`@("`@
M("`@+R\@54-3+30@8VAR86-T97(@96YC;V1I;F<_"B`@("`@("`@("`@("1E
M;G1I='D@/2`D=&AI<RT^96YT:71Y*%A-3%]70EA-3#HZ34)526YT,S)4;TEN
M="@D:6YP=70L("1T:&ES+3Y?<W1R<&]S*2D["@H@("`@("`@("`@("`D=&AI
M<RT^7V-H+3YC:&%R86-T97)S*"<F(R<@+B`D96YT:71Y("X@)SLG*3L*("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@6$U,7U="6$U,7T=,3T)!
M3%]43TM%3E]023H*("`@("`@("`@("`@+R\@4V5C=&EO;B`U+C@N-"XT"B`@
M("`@("`@("`@("\O('1H<F]W(&YE=R!)3T5X8V5P=&EO;@H@("`@("`@("`@
M("`O+R!D:64H(E="6$U,(&=L;V)A;"!T;VME;B!P<F]C97-S:6YG(&EN<W1R
M=6-T:6]N*%!)+"`B("L@=&]K96X@*R`B*2!I<R!U;G-U<'!O<G1E9"%<;B(I
M.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!834Q?5T)834Q?
M1TQ/0D%,7U1/2T5.7TQ)5$5204PZ"B`@("`@("`@("`@("\O(%-E8W1I;VX@
M-2XX+C0N-0H@("`@("`@("`@("`D<W1R(#T@)'1H:7,M/F=E=%-T<FEN9U1A
M8FQE16YT<GDH6$U,7U="6$U,.CI-0E5);G0S,E1O26YT*"1I;G!U="P@)'1H
M:7,M/E]S=')P;W,I*3L*("`@("`@("`@("`@)'1H:7,M/G!A<G-E5&%G*"1I
M;G!U="P@)'-T<BP@9F%L<V4L(&9A;'-E*3L*("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@(&-A<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%3E],251%4D%,
M7T$Z"B`@("`@("`@("`@("\O(%-E8W1I;VX@-2XX+C0N-0H@("`@("`@("`@
M("`D<W1R(#T@)'1H:7,M/F=E=%-T<FEN9U1A8FQE16YT<GDH6$U,7U="6$U,
M.CI-0E5);G0S,E1O26YT*"1I;G!U="P@)'1H:7,M/E]S=')P;W,I*3L*("`@
M("`@("`@("`@)'1H:7,M/G!A<G-E5&%G*"1I;G!U="P@)'-T<BP@=')U92P@
M9F%L<V4I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!834Q?
M5T)834Q?1TQ/0D%,7U1/2T5.7TQ)5$5204Q?04,Z"B`@("`@("`@("`@("\O
M(%-E8W1I;VX@-2XX+C0N-0H@("`@("`@("`@("`D<W1R(#T@)'1H:7,M/F=E
M=%-T<FEN9U1A8FQE16YT<GDH6$U,7U="6$U,.CI-0E5);G0S,E1O26YT*"1I
M;G!U="P@)'1H:7,M/E]S=')P;W,I*3L*("`@("`@("`@("`@)'1H:7,M/G!A
M<G-E5&%G*"1I;G!U="P@)'-T<FEN9RP@=')U92P@=')U92D["B`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("!C87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+
M14Y?3$E415)!3%]#.@H@("`@("`@("`@("`O+R!396-T:6]N(#4N."XT+C4*
M("`@("`@("`@("`@)'-T<B`]("1T:&ES+3YG9713=')I;F=486)L945N=')Y
M*%A-3%]70EA-3#HZ34)526YT,S)4;TEN="@D:6YP=70L("1T:&ES+3Y?<W1R
M<&]S*2D["B`@("`@("`@("`@("1T:&ES+3YP87)S951A9R@D:6YP=70L("1S
M='(L(&9A;'-E+"!T<G5E*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&-A<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%3E]/4$%1544Z"B`@("`@("`@
M("`@("\O(%-E8W1I;VX@-2XX+C0N-@H@("`@("`@("`@("`D<VEZ92`](%A-
M3%]70EA-3#HZ34)526YT,S)4;TEN="@D:6YP=70L("1T:&ES+3Y?<W1R<&]S
M*3L*("`@("`@("`@("`@+R\@<')I;G0@(F]P87%U92!O9B!S:7IE("1S:7IE
M7&XB.R`O+R!`=&]D;R!R96UO=F4@9&5B=6<*("`@("`@("`@("`@)&(@/2!S
M=6)S='(H)&EN<'5T+"`D=&AI<RT^7W-T<G!O<RP@)'-I>F4I.PH@("`@("`@
M("`@("`D=&AI<RT^7W-T<G!O<R`K/2`D<VEZ93L*"B`@("`@("`@("`@("\O
M(&]P87%U92!D871A(&EN<VED92!A(#QD871A/B!E;&5M96YT(&UA>2!O<B!M
M87D@;F]T(&)E"B`@("`@("`@("`@("\O(&$@;F5S=&5D('=B>&UL(&1O8W5M
M96YT("AF;W(@97AA;7!L92!D979I;F8@9&%T82DN"B`@("`@("`@("`@("\O
M(%=E(&9I;F0@;W5T(&)Y(&-H96-K:6YG('1H92!F:7)S="!B>71E(&]F('1H
M92!D871A.B!I9B!I="=S"B`@("`@("`@("`@("\O(#$L(#(@;W(@,R!W92!E
M>'!E8W0@:70@=&\@8F4@=&AE('9E<G-I;VX@;G5M8F5R(&]F(&$@=V)X;6P*
M("`@("`@("`@("`@+R\@9&]C=6UE;G0@86YD('1H=7,@<W1A<G0@82!N97<@
M=V)X;6P@9&5C;V1E<B!I;G-T86YC92!O;B!I="X*"B`@("`@("`@("`@(&EF
M("@D=&AI<RT^7VES1&%T82`F)B!O<F0H)&(I(#P](#$P*2!["B`@("`@("`@
M("`@("`@("`D9&5C;V1E<B`]("9N97<@6$U,7U="6$U,7T1E8V]D97(H=')U
M92D["B`@("`@("`@("`@("`@("`D9&5C;V1E<BT^<V5T0V]N=&5N=$AA;F1L
M97(H)'1H:7,M/E]C:"D["B`@("`@("`@("`@("`@("`D<R`]("1D96-O9&5R
M+3YD96-O9&4H)&(I.PH@("`@("`@("\O("`@("`@("`@("`@("`@("\J("\O
M($!T;V1O.B!&25A-12!C=7)R96YT;'D@=V4@8V%N)W0@9&5C;V1E($YO:VEA
M"B`@("`@("`@("`@("`@("`O+R!$979);F8@9&%T82X@4V\@:6=N;W)E(&5R
M<F]R(&9O<B!T:&4@=&EM92!B965I;F<N"B`@("`@("`@:68@*&ES7V$H)',L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V5R<F]R(#T@)',["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@+R\@*B\*("`@("`@("`@
M("`@("`@("\O("1T:&ES+3Y?8V@M/F-H87)A8W1E<G,H)',I.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+RH@;F]R;6%L(&]P87%U
M92!B96AA=FEO=7(Z(&IU<W0@8V]P>2!T:&4@<F%W(&1A=&$Z("HO"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7V-H+3YC:&%R86-T97)S*"`D8BD["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("\O(&]L9"!A<'!R;V%C:"!T;R!D96%L
M('=I=&@@;W!A<75E(&1A=&$@:6YS:61E($-O;G1E;G1(86YD;&5R.@H@("`@
M("`@("`@("`O+R!&25A-12!/<&%Q=64@:7,@=7-E9"!B>2!364Y#34PN("!/
M<&%Q=64@9&%T82!T:&%T(&1E<&5N9',@;VX@=&AE(&-O;G1E>'0*("`@("`@
M("`@("`@+R\@:68@*&-O;G1E;G1(86YD;&5R(&EN<W1A;F-E;V8@3W!A<75E
M0V]N=&5N=$AA;F1L97(I('L*("`@("`@("`@("`@+R\@("`@("@H3W!A<75E
M0V]N=&5N=$AA;F1L97(I8V]N=&5N=$AA;F1L97(I+F]P87%U92AB*3L*("`@
M("`@("`@("`@+R\@?2!E;'-E('L*("`@("`@("`@("`@+R\@("`@(%-T<FEN
M9R!S='(@/2!N97<@4W1R:6YG*&(L(#`L('-I>F4L(&-H87)S970I.PH@("`@
M("`@("`@("`O+R`@("`@8VAA<EM=(&-H87)S(#T@<W1R+G1O0VAA<D%R<F%Y
M*"D["@H@("`@("`@("`@("`O+R`@("`@8V]N=&5N=$AA;F1L97(N8VAA<F%C
M=&5R<RAC:&%R<RP@,"P@8VAA<G,N;&5N9W1H*3L*("`@("`@("`@("`@+R\@
M?0H*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@6$U,7U="6$U,
M7T=,3T)!3%]43TM%3E]%3D0Z"B`@("`@("`@("`@("\O(%-E8W1I;VX@-2XX
M+C0N-RXQ"B`@("`@("`@("`@("1S='(@/2`D=&AI<RT^96YD5&%G*"D["B`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%A-3%]70EA-3%]'3$]"
M04Q?5$]+14Y?4U=)5$-(7U!!1T4Z"B`@("`@("`@("`@("\O(%-E8W1I;VX@
M-2XX+C0N-RXR"B`@("`@("`@("`@("1C;V1E4&%G92`]("1T:&ES+3YG971"
M>71E*"1I;G!U="D["B`@("`@("`@("`@("\O('!R:6YT(")S=VET8V@@=&\@
M8V]D97!A9V4@)&-O9&5086=E7&XB.R`O+R!`=&]D;SH@<F5M;W9E(&1E8G5G
M(&-O9&4*("`@("`@("`@("`@)'1H:7,M/G-W:71C:$5L96UE;G1#;V1E4&%G
M92@D8V]D95!A9V4I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@9&5F
M875L=#H*("`@("`@("`@("`@+R\@4V5C=&EO;B`U+C@N,@H@("`@("`@("`@
M("`O+R!396-T:6]N(#4N."XS"B`@("`@("`@("`@("1H87-!='1R:6)U=&5S
M(#T@*"@D=&]K96X@)B`P>#@P*2`A/2`P*3L*("`@("`@("`@("`@)&AA<T-O
M;G1E;G0@/2`H*"1T;VME;B`F(#!X-#`I("$](#`I.PH@("`@("`@("`@("`D
M<F5A;%1O:V5N(#T@)'1O:V5N("8@,'@S1CL*("`@("`@("`@("`@)'-T<B`]
M("1T:&ES+3YG971486<H)')E86Q4;VME;BD["@H@("`@("`@("`@("`O+R!P
M<FEN="`B96QE;65N=#HD<W1R7&XB.R`O+R!`5$]$3R!296UO=F4@9&5B=6<@
M8V]D90H@("`@("`@("`@("`D=&AI<RT^<&%R<V5486<H)&EN<'5T+"`D<W1R
M+"`D:&%S071T<FEB=71E<RP@)&AA<T-O;G1E;G0I.PH*("`@("`@("`@("`@
M:68@*"1R96%L5&]K96X@/3T@,'@P9BD@>PH@("`@("`@("`@("`@("`@+R\@
M<W1O<F4@:68@=V4G<F4@:6YS:61E(&$@1&%T82!T86<N(%1H:7,@;6%Y(&-O
M;G1A:6X*("`@("`@("`@("`@("`@("\O(&%N(&%D9&ET:6]N86P@96YC;&]S
M960@=V)X;6P@9&]C=6UE;G0@;VX@=VAI8V@@=V4@:&%V90H@("`@("`@("`@
M("`@("`@+R\@=&\@<G5N(&$@<V5P97)A=&4@96YC;V1E<@H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]I<T1A=&$@/2!T<G5E.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]I<T1A=&$@/2!F86QS93L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@
M("!]"@H@("`@9G5N8W1I;VX@<&%R<V5486<H)&EN<'5T+"`D=&%G+"`D:&%S
M071T<FEB=71E<RP@)&AA<T-O;G1E;G0I"B`@("!["B`@("`@("`@)&%T=')S
M(#T@87)R87DH*3L*("`@("`@("!I9B`H)&AA<T%T=')I8G5T97,I('L*("`@
M("`@("`@("`@)&%T=')S(#T@)'1H:7,M/F=E=$%T=')I8G5T97,H)&EN<'5T
M*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?8V@M/G-T87)T16QE;65N
M="@D=&AI<RT^9V5T0W5R<F5N=%5222@I+"`D=&%G+"`D871T<G,I.PH*("`@
M("`@("!I9B`H)&AA<T-O;G1E;G0I('L*("`@("`@("`@("`@+R\@1DE8344@
M22!F;W)G;W0@=VAA="!D;V5S('1H:7,@9&]E<RX@3F]T('-U<F4@:68@=&AI
M<R!I<PH@("`@("`@("`@("`O+R!R:6=H=#\*("`@("`@("`@("`@)'1H:7,M
M/E]T86=3=&%C:UM=(#T@)'1A9SL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D=&AI<RT^7V-H+3YE;F1%;&5M96YT*"1T:&ES+3YG971#=7)R96YT
M55))*"DL("1T86<I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!E
M;F1486<H*0H@("`@>PH@("`@("`@(&EF("AC;W5N="@D=&AI<RT^7W1A9U-T
M86-K*2D@>PH@("`@("`@("`@("`D=&%G(#T@87)R87E?<&]P*"1T:&ES+3Y?
M=&%G4W1A8VLI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T86<@
M/2`G56YK;F]W;B<["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V-H+3YE
M;F1%;&5M96YT*"1T:&ES+3YG971#=7)R96YT55))*"DL("1T86<I.PH*("`@
M("`@("!R971U<FX@)'1A9SL*("`@('T*"B`@("!F=6YC=&EO;B!G971!='1R
M:6)U=&5S*"1I;G!U="D*("`@('L*("`@("`@("`D=&AI<RT^<W1A<G1'971!
M='1R:6)U=&5S*"D["B`@("`@("`@)&AA<TUO<F5!='1R:6)U=&5S(#T@=')U
M93L*"B`@("`@("`@)&%T=')S(#T@87)R87DH*3L*("`@("`@("`D871T<B`]
M(&YU;&P["B`@("`@("`@)'9A;'5E(#T@;G5L;#L*("`@("`@("`D=&]K96X@
M/2!N=6QL.PH*("`@("`@("!W:&EL92`H)&AA<TUO<F5!='1R:6)U=&5S*2![
M"B`@("`@("`@("`@("1T;VME;B`]("1T:&ES+3YG971">71E*"1I;G!U="D[
M"@H@("`@("`@("`@("!S=VET8V@@*"1T;VME;BD@>PH@("`@("`@("`@("`O
M+R!!='1R:6)U=&4@<W!E8VEF:65D+@H@("`@("`@("`@("!C87-E(%A-3%]7
M0EA-3%]'3$]"04Q?5$]+14Y?3$E415)!3#H*("`@("`@("`@("`@("`@("\O
M(%-E8W1I;VX@-2XX+C0N-0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A
M='1R*2D@>PH@("`@("`@("`@("`@("`@("`@("1A='1R<UM=(#T@87)R87DH
M)V%T=')I8G5T92<@/3X@)&%T='(L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G=F%L=64G(#T^("1V86QU92D["B`@("`@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`@("`@)&%T='(@/2`D=&AI<RT^9V5T4W1R
M:6YG5&%B;&5%;G1R>2A834Q?5T)834PZ.DU"54EN=#,R5&]);G0H)&EN<'5T
M+"`D=&AI<RT^7W-T<G!O<RDI.PH@("`@("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@("`@("`O+R!686QU92!S<&5C:69I960N"B`@("`@("`@("`@(&-A
M<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?25\P.@H@("`@("`@("`@
M("!C87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?15A47TE?,3H*("`@("`@
M("`@("`@8V%S92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T585%])7S(Z"B`@
M("`@("`@("`@("`@("`O+R!396-T:6]N(#4N."XT+C(*("`@("`@("`@("`@
M("`@("1V86QU92`N/2`D=&AI<RT^=&5R;7-T<B@D:6YP=70I.PH@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(%A-3%]70EA-3%]'
M3$]"04Q?5$]+14Y?15A47U1?,#H*("`@("`@("`@("`@8V%S92!834Q?5T)8
M34Q?1TQ/0D%,7U1/2T5.7T585%]47S$Z"B`@("`@("`@("`@(&-A<V4@6$U,
M7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?5%\R.@H@("`@("`@("`@("`@("`@
M+R\@4V5C=&EO;B`U+C@N-"XR"B`@("`@("`@("`@("`@("`D=F%L=64@+CT@
M)'1H:7,M/F=E=%-T<FEN9U1A8FQE16YT<GDH6$U,7U="6$U,.CI-0E5);G0S
M,E1O26YT*"1I;G!U="P@)'1H:7,M/E]S=')P;W,I*3L*("`@("`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92!834Q?5T)834Q?1TQ/0D%,
M7U1/2T5.7T585%\P.@H@("`@("`@("`@("!C87-E(%A-3%]70EA-3%]'3$]"
M04Q?5$]+14Y?15A47S$Z"B`@("`@("`@("`@(&-A<V4@6$U,7U="6$U,7T=,
M3T)!3%]43TM%3E]%6%1?,CH*("`@("`@("`@("`@("`@("\O(%-E8W1I;VX@
M-2XX+C0N,@H@("`@("`@("`@("`@("`@)'9A;'5E("X]("1I;G!U=%LD=&AI
M<RT^7W-T<G!O<RLK73L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@8V%S92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T5.5$E463H*("`@
M("`@("`@("`@("`@("\O(%-E8W1I;VX@-2XX+C0N,PH@("`@("`@("`@("`@
M("`@)'9A;'5E("X]("1T:&ES+3YE;G1I='DH6$U,7U="6$U,.CI-0E5);G0S
M,E1O26YT*"1I;G!U="P@)'1H:7,M/E]S=')P;W,I*3L*("`@("`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92!834Q?5T)834Q?1TQ/0D%,
M7U1/2T5.7U-44E]).@H@("`@("`@("`@("`@("`@+R\@4V5C=&EO;B`U+C@N
M-"XQ"B`@("`@("`@("`@("`@("`D=F%L=64@+CT@)'1H:7,M/G1E<FUS='(H
M)&EN<'5T*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M8V%S92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7U-44E]4.@H@("`@("`@("`@
M("`@("`@+R\@4V5C=&EO;B`U+C@N-"XQ"B`@("`@("`@("`@("`@("`D=F%L
M=64@+CT@)'1H:7,M/F=E=%-T<FEN9U1A8FQE16YT<GDH6$U,7U="6$U,.CI-
M0E5);G0S,E1O26YT*"1I;G!U="P@)'1H:7,M/E]S=')P;W,I*3L*("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92!834Q?5T)834Q?
M1TQ/0D%,7U1/2T5.7T]005%513H*("`@("`@("`@("`@("`@("\O(%-E8W1I
M;VX@-2XX+C0N-@H@("`@("`@("`@("`@("`@)'-I>F4@/2!834Q?5T)834PZ
M.DU"54EN=#,R5&]);G0H)&EN<'5T+"`D=&AI<RT^7W-T<G!O<RD["B`@("`@
M("`@("`@("`@("`D8B`]('-U8G-T<B@D:6YP=70L("1T:&ES+3Y?<W1R<&]S
M+"`D=&AI<RT^7W-T<G!O<R`K("1S:7IE*3L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<W1R<&]S("L]("1S:7IE.PH*("`@("`@("`@("`@("`@("1V86QU
M92`N/2`D8CL*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M8V%S92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T5.1#H*("`@("`@("`@("`@
M("`@("\O(%-E8W1I;VX@-2XX+C0N-RXQ"B`@("`@("`@("`@("`@("`D:&%S
M36]R94%T=')I8G5T97,@/2!F86QS93L*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D871T<BDI('L*("`@("`@("`@("`@("`@("`@("`D871T<G-;72`]
M(&%R<F%Y*"=A='1R:6)U=&4G(#T^("1A='1R+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W9A;'5E)R`]/B`D=F%L=64I.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("!C87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?4U=)5$-(7U!!1T4Z
M"B`@("`@("`@("`@("`@("`O+R!396-T:6]N(#4N."XT+C<N,@H@("`@("`@
M("`@("`@("`@)&-O9&5086=E(#T@)'1H:7,M/F=E=$)Y=&4H)&EN<'5T*3L*
M("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/E]P<F5V071T<FEB=71E1%1$
M*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P<F5V071T<FEB=71E
M1%1$(#T@)'1H:7,M/E]A='1R:6)U=&5$5$0["B`@("`@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`@("`@)'1H:7,M/G-W:71C:$%T=')I8G5T94-O9&50
M86=E*"1C;V1E4&%G92D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!I9B`H)'1O:V5N(#X@
M,3(X*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A='1R*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D871T<G-;72`](&%R<F%Y*"=A
M='1R:6)U=&4G(#T^("1A='1R+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=V86QU92<@/3X@)'9A;'5E*3L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&%T='(@/2`D=&AI
M<RT^7V%T=')I8G5T94141"T^=&]!='1R:6)U=&4H)'1O:V5N*3L*("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@+R\@5F%L
M=64N"B`@("`@("`@("`@("`@("`@("`@)'9A;'5E("X]("1T:&ES+3Y?871T
M<FEB=71E1%1$+3YT;T%T=')I8G5T92@D=&]K96XI.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(&EF("@A)'1H:7,M/E]P<F5V071T<FEB=71E1%1$
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?871T<FEB=71E1%1$(#T@)'1H:7,M
M/E]P<F5V071T<FEB=71E1%1$.PH@("`@("`@("`@("`D=&AI<RT^7W!R979!
M='1R:6)U=&5$5$0@/2!F86QS93L*("`@("`@("!]"@H@("`@("`@("1T:&ES
M+3YS=&]P1V5T071T<FEB=71E<R@I.PH@("`@?0H*("`@(&9U;F-T:6]N('-T
M87)T1V5T071T<FEB=71E<R@I"B`@("!["B`@("`@("`@)'1H:7,M/E]I<T%T
M=')I8G5T92`]('1R=64["B`@("!]"@H@("`@9G5N8W1I;VX@<W1O<$=E=$%T
M=')I8G5T97,H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:7-!='1R:6)U=&4@
M/2!F86QS93L*("`@('T*"B`@("!F=6YC=&EO;B!G971#=7)R96YT55))*"D*
M("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]I<T%T=')I8G5T92D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]T86=$5$0M/F=E=%5222@I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V%T=')I
M8G5T94141"T^9V5T55))*"D["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T
M:6]N('=R:71E4W1R:6YG*"1S='(I"B`@("!["B`@("`@("`@)'1H:7,M/E]C
M:"T^8VAA<F%C=&5R<R@D<W1R*3L*("`@('T*"B`@("!F=6YC=&EO;B!G9714
M86<H)'1A9RD*("`@('L*("`@("`@("`O+R!3:&]U;&0@:VYO=R!W:&EC:"!S
M=&%T92!I="!I<R!I;BX*("`@("`@("!R971U<FX@)'1H:7,M/E]T86=$5$0M
M/G1O5&%G4W1R*"1T86<I.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$%T=')I
M8G5T92@D871T<FEB=71E*0H@("`@>PH@("`@("`@("\O(%-H;W5L9"!K;F]W
M('=H:6-H('-T871E(&ET(&ES(&EN+@H@("`@("`@("1T:&ES+3Y?871T<FEB
M=71E1%1$+3YT;T%T=')I8G5T94EN="@D871T<FEB=71E*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!S=VET8VA%;&5M96YT0V]D95!A9V4H)&-O9&5086=E*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?=&%G1%1$(#T@)B1T:&ES+3Y?9'1D36%N
M86=E<BT^9V5T26YS=&%N8V4H)'1H:7,M/E]T86=$5$0M/G1O0V]D95!A9V53
M='(H)&-O9&5086=E*2D["B`@("`@("`@)'1H:7,M/G-W:71C:$%T=')I8G5T
M94-O9&5086=E*"1C;V1E4&%G92D["B`@("!]"@H@("`@9G5N8W1I;VX@<W=I
M=&-H071T<FEB=71E0V]D95!A9V4H)&-O9&5086=E*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?871T<FEB=71E1%1$(#T@)B1T:&ES+3Y?9'1D36%N86=E<BT^
M9V5T26YS=&%N8V4H)'1H:7,M/E]A='1R:6)U=&5$5$0M/G1O0V]D95!A9V53
M='(H)&-O9&5086=E*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@
M=&AE(&AE>"!V97)S:6]N(&]F('1H92!B87-E(#$P("1E;G1I='DN"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&5N=&ET>2@D96YT:71Y*0H@("`@>PH@("`@("`@
M(')E='5R;B!D96-H97@H)&5N=&ET>2D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!296%D<R!A(&YU;&P@=&5R;6EN871E9"!S=')I;F<N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('1E<FUS='(H)&EN<'5T*0H@("`@>PH@("`@("`@("1S='(@
M/2`G(R<[("\O(&UU<W0@<W1A<G0@=VET:"!N;VYE;7!T>2!S=')I;F<@=&\@
M86QL;W<@87)R87D@86-C97-S"B`@("`@("`@)&D@/2`P.PH@("`@("`@("1C
M:"`]("1I;G!U=%LD=&AI<RT^7W-T<G!O<RLK73L*("`@("`@("!I9B`H;W)D
M*"1C:"D@/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@)R<[("\O(&1O;B=T
M(')E='5R;B`G(R<*("`@("`@("!]"B`@("`@("`@=VAI;&4@*&]R9"@D8V@I
M("$](#`I('L*("`@("`@("`@("`@)'-T<ELD:2LK72`]("1C:#L*("`@("`@
M("`@("`@)&-H(#T@)&EN<'5T6R1T:&ES+3Y?<W1R<&]S*RM=.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1S='(["B`@("!]"@I]"@H`````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+UA-3"]35D<N<&AP````````````````
M````````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#4S,C$V(#$P-3$U
M-#,S-S,U(#`R,#$R-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@6$U,7U-61PH@*@H@*B!7<F%P<&5R
M(&-L87-S('1H870@<')O=FED97,@<V]M92!E>&%M<&QE<R!A;F0@82!F97<@
M8V]N=F5N:65N8V4*("H@;65T:&]D<RX*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO6$U,7U-61R]35D<N<&AP+'8@,2XQ-RXQ,"XT(#(P,#8O,#$O,#$@,C$Z
M,C@Z-#0@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU
M8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B!`<&%C:V%G92!834Q?4U9'"B`J+PIC;&%S<R!834Q?4U9'('L*"B`@
M("!F=6YC=&EO;B!E>&%M<&QE*"D*("`@('L*("`@("`@("`O+R!#<F5A=&4@
M86X@:6YS=&%N8V4@;V8@6$U,7U-61U]$;V-U;65N="X@06QL(&]T:&5R(&]B
M:F5C=',*("`@("`@("`O+R!W:6QL(&)E(&%D9&5D('1O('1H:7,@:6YS=&%N
M8V4@9F]R('!R:6YT:6YG+B!3970@=&AE(&AE:6=H=`H@("`@("`@("\O(&%N
M9"!W:61T:"!O9B!T:&4@=FEE=W!O<G0N"B`@("`@("`@)'-V9R`]("9N97<@
M6$U,7U-61U]$;V-U;65N="AA<G)A>2@G=VED=&@G(#T^(#0P,"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=H96EG:'0G
M(#T^(#(P,"DI.PH*("`@("`@("`O+R!#<F5A=&4@86X@:6YS=&%N8V4@;V8@
M6$U,7U-61U]'<F]U<"X@4V5T('1H92!S='EL92P*("`@("`@("`O+R!T<F%N
M<V9O<FUS(&9O<B!C:&EL9"!O8FIE8W1S+@H@("`@("`@("1G(#T@)FYE=R!8
M34Q?4U9'7T=R;W5P*&%R<F%Y*"=S='EL92<@/3X@)W-T<F]K93IB;&%C:R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1R86YS
M9F]R;2<@/3X@)W1R86YS;&%T92@R,#`@,3`P*2<I*3L*"B`@("`@("`@+R\@
M061D(&$@<&%R96YT('1O('1H92!G(&EN<W1A;F-E+@H@("`@("`@("1G+3YA
M9&1087)E;G0H)'-V9RD["@H@("`@("`@("\O(%1H92!S86UE(')E<W5L=',@
M8V%N(&)E(&%C8V]M<&QI<VAE9"!B>2!M86MI;F<@9R!A(&-H:6QD(&]F('1H
M92!S=F<N"B`@("`@("`@+R\@)'-V9RT^861D0VAI;&0H)&<I.PH*("`@("`@
M("`O+R!#<F5A=&4@86YD(&%N:6UA=&4@82!C:7)C;&4N"B`@("`@("`@)&-I
M<F-L92`]("9N97<@6$U,7U-61U]#:7)C;&4H87)R87DH)V-X)R`]/B`P+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-Y
M)R`]/B`P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W(G(#T^(#$P,"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=S='EL92<@/3X@)W-T<F]K92UW:61T:#HS)RDI
M.PH@("`@("`@("1C:7)C;&4M/F%D9$-H:6QD*&YE=R!834Q?4U9'7T%N:6UA
M=&4H87)R87DH)V%T=')I8G5T94YA;64G(#T^("=R)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A='1R
M:6)U=&54>7!E)R`]/B`G6$U,)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=F<F]M)R`]/B`P+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W1O)R`]/B`W-2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=D=7(G(#T^("<S<R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M9FEL;"<@/3X@)V9R965Z92<I*2D["B`@("`@("`@)&-I<F-L92T^861D0VAI
M;&0H;F5W(%A-3%]35D=?06YI;6%T92AA<G)A>2@G871T<FEB=71E3F%M92<@
M/3X@)V9I;&PG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V%T=')I8G5T951Y<&4G(#T^("=#4U,G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)V9R;VTG(#T^("=G<F5E;B<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=&\G(#T^("=R960G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)V1U<B<@/3X@)S-S)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=F:6QL)R`]/B`G9G)E
M97IE)RDI*3L*"B`@("`@("`@+R\@36%K92!T:&4@8VER8VQE(&$@8VAI;&0@
M;V8@9RX*("`@("`@("`D9RT^861D0VAI;&0H)&-I<F-L92D["@H@("`@("`@
M("\O($-R96%T92!A;F0@86YI;6%T92!S;VUE('1E>'0N"B`@("`@("`@)'1E
M>'0@/2`F;F5W(%A-3%]35D=?5&5X="AA<G)A>2@G=&5X="<@/3X@)U-61R!C
M:&%R="$G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G>"<@/3X@,"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)WDG(#T^(#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=S='EL92<@/3X@)V9O;G0M<VEZ93HR,#MT97AT+6%N8VAO
M<CIM:61D;&4[)RDI.PH@("`@("`@("1T97AT+3YA9&1#:&EL9"AN97<@6$U,
M7U-61U]!;FEM871E*&%R<F%Y*"=A='1R:6)U=&5.86UE)R`]/B`G9F]N="US
M:7IE)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G871T<FEB=71E5'EP92<@/3X@)V%U=&\G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=F
M<F]M)R`]/B`P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=T;R<@/3X@,C`L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1U<B<@/3X@)S-S
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G9FEL;"<@/3X@)V9R965Z92<I*2D["@H@("`@("`@("\O($UA
M:V4@=&AE('1E>'0@82!C:&EL9"!O9B!G+@H@("`@("`@("1G+3YA9&1#:&EL
M9"@D=&5X="D["@H@("`@("`@("\O(%-E;F0@82!M97-S86=E('1O('1H92!S
M=F<@:6YS=&%N8V4@=&\@<W1A<G0@<')I;G1I;F<N"B`@("`@("`@)'-V9RT^
M<')I;G1%;&5M96YT*"D["B`@("!]"@I]"@HO*BH*("H@6$U,7U-61U]%;&5M
M96YT"B`J"B`J(%1H:7,@:7,@=&AE(&)A<V4@8VQA<W,@9F]R('1H92!D:69F
M97)E;G0@4U9'($5L96UE;G0*("H@3V)J96-T<RX@17AT96YD('1H:7,@8VQA
M<W,@=&\@8W)E871E(&$@;F5W(%-61R!%;&5M96YT+@H@*@H@*B!`<&%C:V%G
M92!834Q?4U9'"B`J+PIC;&%S<R!834Q?4U9'7T5L96UE;G0@>PH*("`@('9A
M<B`D7V5L96UE;G1S(#T@;G5L;#L*("`@('9A<B`D7W-T>6QE(#T@;G5L;#L*
M("`@('9A<B`D7W1R86YS9F]R;2`](&YU;&P["B`@("!V87(@)%]I9"`](&YU
M;&P["@H@("`@9G5N8W1I;VX@6$U,7U-61U]%;&5M96YT*"1P87)A;7,@/2!A
M<G)A>2@I*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)'`@
M/3X@)'8I('L*("`@("`@("`@("`@)'!A<F%M(#T@)U\G("X@)'`["B`@("`@
M("`@("`@("1T:&ES+3XD<&%R86T@/2`D=CL*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!-;W-T(%-61R!E;&5M96YT<R!C86X@8V]N=&%I;B!C
M:&EL9"!E;&5M96YT<RX@5&AI<R!M971H;V0@8V%L;',*("`@("`J('1H92!P
M<FEN=$5L96UE;G0@;65T:&]D(&]F(&%N>2!C:&EL9"!E;&5M96YT(&%D9&5D
M('1O('1H:7,*("`@("`J(&]B:F5C="!B>2!U<V4@;V8@=&AE(&%D9$-H:6QD
M(&UE=&AO9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<')I;G1%;&5M96YT*"D*
M("`@('L*("`@("`@("`O+R!,;V]P(&%N9"!C86QL+@H@("`@("`@(&EF("AI
M<U]A<G)A>2@D=&AI<RT^7V5L96UE;G1S*2D@>PH@("`@("`@("`@("!F;W)E
M86-H("@D=&AI<RT^7V5L96UE;G1S(&%S("1C:&EL9"D@>PH@("`@("`@("`@
M("`@("`@)&-H:6QD+3YP<FEN=$5L96UE;G0H*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@;65T:&]D(&%D
M9',@86X@;V)J96-T(')E9F5R96YC92`H;W(@=F%L=64L(&EF("1C;W!Y(&ES
M"B`@("`@*B!T<G5E*2!T;R!T:&4@7V5L96UE;G1S(&%R<F%Y+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!A9&1#:&EL9"@F)&5L96UE;G0L("1C;W!Y(#T@9F%L
M<V4I"B`@("!["B`@("`@("`@:68@*"1C;W!Y*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?96QE;65N='-;72`]("8D96QE;65N="T^8V]P>2@I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?96QE;65N='-;72`]("8D
M96QE;65N=#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES
M(&UE=&AO9"!S96YD<R!A(&UE<W-A9V4@=&\@=&AE('!A<W-E9"!E;&5M96YT
M(')E<75E<W1I;F<@=&\*("`@("`J(&)E(&%D9&5D(&%S(&$@8VAI;&0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&%D9%!A<F5N="@F)'!A<F5N="D*("`@('L*
M("`@("`@("!I9B`H:7-?<W5B8VQA<W-?;V8H)'!A<F5N="P@)UA-3%]35D=?
M16QE;65N="<I*2!["B`@("`@("`@("`@("1P87)E;G0M/F%D9$-H:6QD*"1T
M:&ES*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@8V]P>2@I"B`@
M("!["B`@("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92AZ96YD7W9E<G-I;VXH
M*2P@)S(G+"`G/B<I*2!["B`@("`@("`@("`@(')E='5R;B!C;&]N92@D=&AI
M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'AM;%]S=F<@/2`D
M=&AI<SL*("`@("`@("`@("`@<F5T=7)N("1X;6Q?<W9G.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J(%!R:6YT(&5A8V@@;V8@=&AE('!A<W-E
M9"!P87)A;65T97)S+"!I9B!T:&5Y(&%R92!S970N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('!R:6YT4&%R86US*"D*("`@('L*("`@("`@("!F;W)E86-H("AF
M=6YC7V=E=%]A<F=S*"D@87,@)'!A<F%M*2!["B`@("`@("`@("`@("1?<&%R
M86T@/2`G7R<@+B`D<&%R86T["B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^)%]P87)A;2DI('L*("`@("`@("`@("`@("`@('-W:71C:"`H)'!A<F%M
M*2!["B`@("`@("`@("`@("`@("!C87-E("=F:6QT97(G.@H@("`@("`@("`@
M("`@("`@("`@(&5C:&\@)R!F:6QT97(](G5R;"@C)R`N("1T:&ES+3XD7W!A
M<F%M("X@)RDB)SL*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@("`@(&5C:&\@
M)R`G("X@<W1R7W)E<&QA8V4H)U\G+"`G+2<L("1P87)A;2D@+B`G/2(G("X@
M)'1H:7,M/B1?<&%R86T@+B`G(B<["B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("!]"@H@("`@+R\@4V5T(&%N>2!N86UE9"!A='1R:6)U=&4@;V8@86X@
M96QE;65N="!T;R!A('9A;'5E+@H@("`@9G5N8W1I;VX@<V5T4&%R86TH)'!A
M<F%M+"`D=F%L=64I"B`@("!["B`@("`@("`@)&%T='(@/2`G7R<@+B`D<&%R
M86T["B`@("`@("`@)'1H:7,M/B1A='1R(#T@)'9A;'5E.PH@("`@?0H*("`@
M("\O($=E="!A;GD@;F%M960@871T<FEB=71E(&]F(&%N(&5L96UE;G0N"B`@
M("!F=6YC=&EO;B!G971087)A;2@D<&%R86TI"B`@("!["B`@("`@("`@)&%T
M='(@/2`G7R<@+B`D<&%R86T["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3XD
M871T<BDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3XD871T<CL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@
M("!]"B`@("!]"@H@("`@+R\@4')I;G0@;W5T('1H92!O8FIE8W0@9F]R(&1E
M8G5G9VEN9RX*("`@(&9U;F-T:6]N(&1E8G5G*"D*("`@('L*("`@("`@("!E
M8VAO("<\<')E/B<[('9A<E]D=6UP*"1T:&ES*3L@96-H;R`G/"]P<F4^)SL*
M("`@('T*"GT*"B\J*@H@*B!834Q?4U9'7T9R86=M96YT"B`J"B`J($!P86-K
M86=E(%A-3%]35D<*("HO"F-L87-S(%A-3%]35D=?1G)A9VUE;G0@97AT96YD
M<R!834Q?4U9'7T5L96UE;G0@>PH*("`@('9A<B`D7W=I9'1H.PH@("`@=F%R
M("1?:&5I9VAT.PH@("`@=F%R("1?=FEE=T)O>#L*("`@('9A<B`D7W@["B`@
M("!V87(@)%]Y.PH*("`@(&9U;F-T:6]N('!R:6YT16QE;65N="@I"B`@("![
M"B`@("`@("`@96-H;R`G/'-V9R<["B`@("`@("`@)'1H:7,M/G!R:6YT4&%R
M86US*"=I9"<L("=W:61T:"<L("=H96EG:'0G+"`G>"<L("=Y)RP@)W9I97="
M;W@G+"`G<W1Y;&4G*3L*("`@("`@("!E8VAO("<@>&UL;G,](FAT='`Z+R]W
M=W<N=S,N;W)G+S(P,#`O<W9G(B!X;6QN<SIX;&EN:STB:'1T<#HO+W=W=RYW
M,RYO<F<O,3DY.2]X;&EN:R(^)R`N(")<;B(["B`@("`@("`@<&%R96YT.CIP
M<FEN=$5L96UE;G0H*3L*("`@("`@("!E8VAO("(\+W-V9SY<;B(["B`@("!]
M"@H@("`@9G5N8W1I;VX@8G5F9F5R3V)J96-T*"D*("`@('L*("`@("`@("!O
M8E]S=&%R="@I.PH@("`@("`@("1T:&ES+3YP<FEN=$5L96UE;G0H*3L*("`@
M("`@("`D;W5T<'5T(#T@;V)?9V5T7V-O;G1E;G1S*"D["B`@("`@("`@;V)?
M96YD7V-L96%N*"D["@H@("`@("`@(')E='5R;B`D;W5T<'5T.PH@("`@?0I]
M"@HO*BH*("H@6$U,7U-61U]$;V-U;65N=`H@*@H@*B!4:&ES(&5X=&5N9',@
M=&AE(%A-3%]35D=?1G)A9VUE;G0@8VQA<W,N($ET('=R87!S('1H92!834Q?
M4U9'7T9R86UE;G0@;W5T<'5T"B`J('=I=&@@82!C;VYT96YT(&AE861E<BP@
M>&UL(&1E9FEN:71I;VX@86YD(&1O8W1Y<&4N"B`J"B`J($!P86-K86=E(%A-
M3%]35D<*("HO"F-L87-S(%A-3%]35D=?1&]C=6UE;G0@97AT96YD<R!834Q?
M4U9'7T9R86=M96YT('L*"B`@("!F=6YC=&EO;B!P<FEN=$5L96UE;G0H*0H@
M("`@>PH@("`@("`@(&AE861E<B@G0V]N=&5N="U4>7!E.B!I;6%G92]S=F<K
M>&UL)RD["@H@("`@("`@('!R:6YT*"<\/WAM;"!V97)S:6]N/2(Q+C`B(&5N
M8V]D:6YG/2)I<V\M.#@U.2TQ(C\^)RXB7&XB*3L*("`@("`@("!P<FEN="@G
M/"%$3T-465!%('-V9R!054),24,@(BTO+U<S0R\O1%1$(%-61R`Q+C`O+T5.
M(@H)("`@("`@("`B:'1T<#HO+W=W=RYW,RYO<F<O5%(O,C`P,2]214,M4U9'
M+3(P,#$P.3`T+T141"]S=F<Q,"YD=&0B/B<@+B`B7&XB*3L*"B`@("`@("`@
M<&%R96YT.CIP<FEN=$5L96UE;G0H*3L*("`@('T*"GT*"B\J*@H@*B!834Q?
M4U9'7T=R;W5P"B`J"B`J($!P86-K86=E(%A-3%]35D<*("HO"F-L87-S(%A-
M3%]35D=?1W)O=7`@97AT96YD<R!834Q?4U9'7T5L96UE;G0@>PH*("`@(&9U
M;F-T:6]N('!R:6YT16QE;65N="@I"B`@("!["B`@("`@("`@96-H;R`G/&<G
M.PH@("`@("`@("1T:&ES+3YP<FEN=%!A<F%M<R@G:60G+"`G<W1Y;&4G+"`G
M=')A;G-F;W)M)RP@)V9I;'1E<B<I.PH@("`@("`@('!R:6YT*"(^7&XB*3L*
M("`@("`@("!P87)E;G0Z.G!R:6YT16QE;65N="@I.PH@("`@("`@('!R:6YT
M*"(\+V<^7&XB*3L*("`@('T*"GT*"B\J*@H@*B!834Q?4U9'7U1E>'1P871H
M"B`J"B`J($!P86-K86=E(%A-3%]35D<*("HO"F-L87-S(%A-3%]35D=?5&5X
M='!A=&@@97AT96YD<R!834Q?4U9'7T5L96UE;G0@>PH*("`@('9A<B`D7W1E
M>'0["B`@("!V87(@)%]X.PH@("`@=F%R("1?>3L*("`@('9A<B`D7V1X.PH@
M("`@=F%R("1?9'D["B`@("!V87(@)%]R;W1A=&4["B`@("!V87(@)%]T97AT
M3&5N9W1H.PH@("`@=F%R("1?;&5N9W1H061J=7-T.PH@("`@=F%R("1?8VAA
M<G-E=#L*"B`@("!F=6YC=&EO;B!P<FEN=$5L96UE;G0H)&5L96UE;G0@/2`G
M=&5X='!A=&@G*0H@("`@>PH@("`@("`@(&5C:&\@)SPG("X@)&5L96UE;G0[
M"B`@("`@("`@)'1H:7,M/G!R:6YT4&%R86US*"=I9"<L("=X)RP@)WDG+"`G
M9'@G+"`G9'DG+"`G<F]T871E)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W1E>'1,96YG=&@G+"`G;&5N9W1H061J=7-T)RP@)W-T>6QE)RP@)W1R
M86YS9F]R;2<I.PH@("`@("`@(&5C:&\@)SXG.PH@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7V-H87)S970I*2!["B`@("`@("`@("`@(&5C:&\@0&AT;6QS
M<&5C:6%L8VAA<G,H)'1H:7,M/E]T97AT+"!%3E1?0T]-4$%4+"`D=&AI<RT^
M7V-H87)S970I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&5C:&\@
M:'1M;'-P96-I86QC:&%R<R@D=&AI<RT^7W1E>'0I.PH@("`@("`@('T*("`@
M("`@("!P87)E;G0Z.G!R:6YT16QE;65N="@I.PH@("`@("`@(&5C:&\@(CPO
M)&5L96UE;G0^7&XB.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=%-H87!E*"1X
M+"`D>2P@)'1E>'0I"B`@("!["B`@("`@("`@)'1H:7,M/E]X(#T@)'@["B`@
M("`@("`@)'1H:7,M/E]Y(#T@)'D["B`@("`@("`@)'1H:7,M/E]T97AT(#T@
M)'1E>'0["B`@("!]"@I]"@HO*BH*("H@6$U,7U-61U]497AT"B`J"B`J($!P
M86-K86=E(%A-3%]35D<*("HO"F-L87-S(%A-3%]35D=?5&5X="!E>'1E;F1S
M(%A-3%]35D=?5&5X='!A=&@@>PH*("`@(&9U;F-T:6]N('!R:6YT16QE;65N
M="@I"B`@("!["B`@("`@("`@<&%R96YT.CIP<FEN=$5L96UE;G0H)W1E>'0G
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!S9713:&%P92@D>"P@)'DL("1T97AT
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?>"`]("1X.PH@("`@("`@("1T:&ES
M+3Y?>2`]("1Y.PH@("`@("`@("1T:&ES+3Y?=&5X="`]("1T97AT.PH@("`@
M?0H*?0H*+RHJ"B`J(%A-3%]35D=?5'-P86X*("H*("H@0'!A8VMA9V4@6$U,
M7U-61PH@*B\*8VQA<W,@6$U,7U-61U]4<W!A;B!E>'1E;F1S(%A-3%]35D=?
M16QE;65N="!["@H@("`@=F%R("1?=&5X=#L*("`@('9A<B`D7W@["B`@("!V
M87(@)%]Y.PH@("`@=F%R("1?9'@["B`@("!V87(@)%]D>3L*("`@('9A<B`D
M7W)O=&%T93L*("`@('9A<B`D7W1E>'1,96YG=&@["B`@("!V87(@)%]L96YG
M=&A!9&IU<W0["@H@("`@9G5N8W1I;VX@<')I;G1%;&5M96YT*"D*("`@('L*
M("`@("`@("!E8VAO("<\='-P86XG.PH@("`@("`@("1T:&ES+3YP<FEN=%!A
M<F%M<R@G:60G+"`G>"<L("=Y)RP@)V1X)RP@)V1Y)RP@)W)O=&%T92<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=T97AT3&5N9W1H)RP@)VQE;F=T
M:$%D:G5S="<L("=S='EL92<L("=T<F%N<V9O<FTG*3L*("`@("`@("!E8VAO
M("<^)R`N("1T:&ES+3Y?=&5X=#L*("`@("`@("!I9B`H:7-?87)R87DH)'1H
M:7,M/E]E;&5M96YT<RDI('L*("`@("`@("`@("`@<&%R96YT.CIP<FEN=$5L
M96UE;G0H*3L*("`@("`@("!]"B`@("`@("`@96-H;R`B/"]T<W!A;CY<;B([
M"B`@("!]"@H@("`@9G5N8W1I;VX@<V5T4VAA<&4H)'@L("1Y+"`D=&5X="D*
M("`@('L*("`@("`@("`D=&AI<RT^7W@@/2`D>#L*("`@("`@("`D=&AI<RT^
M7WD@/2`D>3L*("`@("`@("`D=&AI<RT^7W1E>'0@(#T@)'1E>'0["B`@("!]
M"@I]"@HO*BH*("H@6$U,7U-61U]#:7)C;&4*("H*("H@0'!A8VMA9V4@6$U,
M7U-61PH@*B\*8VQA<W,@6$U,7U-61U]#:7)C;&4@97AT96YD<R!834Q?4U9'
M7T5L96UE;G0@>PH*("`@('9A<B`D7V-X.PH@("`@=F%R("1?8WD["B`@("!V
M87(@)%]R.PH*("`@(&9U;F-T:6]N('!R:6YT16QE;65N="@I"B`@("!["B`@
M("`@("`@96-H;R`G/&-I<F-L92<["@H@("`@("`@("1T:&ES+3YP<FEN=%!A
M<F%M<R@G:60G+"`G8W@G+"`G8WDG+"`G<B<L("=S='EL92<L("=T<F%N<V9O
M<FTG*3L*("`@("`@("!I9B`H:7-?87)R87DH)'1H:7,M/E]E;&5M96YT<RDI
M('L*("`@("`@("`@("`@+R\@4')I;G0@8VAI;&1R96XL('-T87)T(&%N9"!E
M;F0@=&%G+@H@("`@("`@("`@("!E8VAO("(^7&XB.PH@("`@("`@("`@("!P
M87)E;G0Z.G!R:6YT16QE;65N="@I.PH@("`@("`@("`@("!E8VAO("(\+V-I
M<F-L93Y<;B(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@4')I
M;G0@<VAO<G0@=&%G+@H@("`@("`@("`@("!E8VAO("(O/EQN(CL*("`@("`@
M("!]"B`@("!]"@H@("`@9G5N8W1I;VX@<V5T4VAA<&4H)&-X+"`D8WDL("1R
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8W@@/2`D8W@["B`@("`@("`@)'1H
M:7,M/E]C>2`]("1C>3L*("`@("`@("`D=&AI<RT^7W(@(#T@)'(["B`@("!]
M"@I]"@HO*BH*("H@6$U,7U-61U],:6YE"B`J"B`J($!P86-K86=E(%A-3%]3
M5D<*("HO"F-L87-S(%A-3%]35D=?3&EN92!E>'1E;F1S(%A-3%]35D=?16QE
M;65N="!["@H@("`@=F%R("1?>#$["B`@("!V87(@)%]Y,3L*("`@('9A<B`D
M7W@R.PH@("`@=F%R("1?>3(["@H@("`@9G5N8W1I;VX@<')I;G1%;&5M96YT
M*"D*("`@('L*("`@("`@("!E8VAO("<\;&EN92<["B`@("`@("`@)'1H:7,M
M/G!R:6YT4&%R86US*"=I9"<L("=X,2<L("=Y,2<L("=X,B<L("=Y,B<L("=S
M='EL92<I.PH@("`@("`@(&EF("AI<U]A<G)A>2@D=&AI<RT^7V5L96UE;G1S
M*2D@>PH@("`@("`@("`@("`O+R!0<FEN="!C:&EL9')E;BP@<W1A<G0@86YD
M(&5N9"!T86<N"B`@("`@("`@("`@('!R:6YT*"(^7&XB*3L*("`@("`@("`@
M("`@<&%R96YT.CIP<FEN=$5L96UE;G0H*3L*("`@("`@("`@("`@<')I;G0H
M(CPO;&EN93Y<;B(I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O
M(%!R:6YT('-H;W)T('1A9RX*("`@("`@("`@("`@<')I;G0H(B\^7&XB*3L*
M("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@<V5T4VAA<&4H)'@Q+"`D
M>3$L("1X,BP@)'DR*0H@("`@>PH@("`@("`@("1T:&ES+3Y?>#$@/2`D>#$[
M"B`@("`@("`@)'1H:7,M/E]Y,2`]("1Y,3L*("`@("`@("`D=&AI<RT^7W@R
M("`]("1X,CL*("`@("`@("`D=&AI<RT^7WDR("`]("1Y,CL*("`@('T*"GT*
M"B\J*@H@*B!834Q?4U9'7U)E8W0*("H*("H@0'!A8VMA9V4@6$U,7U-61PH@
M*B\*8VQA<W,@6$U,7U-61U]296-T(&5X=&5N9',@6$U,7U-61U]%;&5M96YT
M('L*"B`@("!V87(@)%]X.PH@("`@=F%R("1?>3L*("`@('9A<B`D7W=I9'1H
M.PH@("`@=F%R("1?:&5I9VAT.PH@("`@=F%R("1?<G@["B`@("!V87(@)%]R
M>3L*"B`@("!F=6YC=&EO;B!P<FEN=$5L96UE;G0H*0H@("`@>PH@("`@("`@
M(&5C:&\@)SQR96-T)SL*("`@("`@("`D=&AI<RT^<')I;G1087)A;7,H)VED
M)RP@)W@G+"`G>2<L("=W:61T:"<L("=H96EG:'0G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G<G@G+"`G<GDG+"`G<W1Y;&4G*3L*("`@("`@("!I
M9B`H:7-?87)R87DH)'1H:7,M/E]E;&5M96YT<RDI('L*("`@("`@("`@("`@
M+R\@4')I;G0@8VAI;&1R96XL('-T87)T(&%N9"!E;F0@=&%G+@H@("`@("`@
M("`@("!P<FEN="@B/EQN(BD["B`@("`@("`@("`@('!A<F5N=#HZ<')I;G1%
M;&5M96YT*"D["B`@("`@("`@("`@('!R:6YT*"(\+W)E8W0^7&XB*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!0<FEN="!S:&]R="!T86<N
M"B`@("`@("`@("`@('!R:6YT*"(O/EQN(BD["B`@("`@("`@?0H@("`@?0H*
M("`@(&9U;F-T:6]N('-E=%-H87!E*"1X+"`D>2P@)'=I9'1H+"`D:&5I9VAT
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?>"`]("1X.PH@("`@("`@("1T:&ES
M+3Y?>2`]("1Y.PH@("`@("`@("1T:&ES+3Y?=VED=&@@(#T@)'=I9'1H.PH@
M("`@("`@("1T:&ES+3Y?:&5I9VAT("`]("1H96EG:'0["B`@("!]"@I]"@HO
M*BH*("H@6$U,7U-61U]%;&QI<'-E"B`J"B`J($!P86-K86=E(%A-3%]35D<*
M("HO"F-L87-S(%A-3%]35D=?16QL:7!S92!E>'1E;F1S(%A-3%]35D=?16QE
M;65N="!["@H@("`@=F%R("1?8W@["B`@("!V87(@)%]C>3L*("`@('9A<B`D
M7W)X.PH@("`@=F%R("1?<GD["@H@("`@9G5N8W1I;VX@<')I;G1%;&5M96YT
M*"D*("`@('L*("`@("`@("!E8VAO("<\96QL:7!S92<["B`@("`@("`@)'1H
M:7,M/G!R:6YT4&%R86US*"=I9"<L("=C>"<L("=C>2<L("=R>"<L("=R>2<L
M("=S='EL92<L("=T<F%N<V9O<FTG*3L*("`@("`@("!I9B`H:7-?87)R87DH
M)'1H:7,M/E]E;&5M96YT<RDI('L*("`@("`@("`@("`@+R\@4')I;G0@8VAI
M;&1R96XL('-T87)T(&%N9"!E;F0@=&%G+@H@("`@("`@("`@("!P<FEN="@B
M/EQN(BD["B`@("`@("`@("`@('!A<F5N=#HZ<')I;G1%;&5M96YT*"D["B`@
M("`@("`@("`@('!R:6YT*"(\+V5L;&EP<V4^7&XB*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`O+R!0<FEN="!S:&]R="!T86<N"B`@("`@("`@
M("`@('!R:6YT*"(@+SY<;B(I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC
M=&EO;B!S9713:&%P92@D8W@L("1C>2P@)')X+"`D<GDI"B`@("!["B`@("`@
M("`@)'1H:7,M/E]C>"`]("1C>#L*("`@("`@("`D=&AI<RT^7V-Y(#T@)&-Y
M.PH@("`@("`@("1T:&ES+3Y?<G@@(#T@)')X.PH@("`@("`@("1T:&ES+3Y?
M<GD@(#T@)')Y.PH@("`@?0H*?0H*+RHJ"B`J(%A-3%]35D=?4&]L>6QI;F4*
M("H*("H@0'!A8VMA9V4@6$U,7U-61PH@*B\*8VQA<W,@6$U,7U-61U]0;VQY
M;&EN92!E>'1E;F1S(%A-3%]35D=?16QE;65N="!["@H@("`@=F%R("1?<&]I
M;G1S.PH*("`@(&9U;F-T:6]N('!R:6YT16QE;65N="@I"B`@("!["B`@("`@
M("`@96-H;R`G/'!O;'EL:6YE)SL*("`@("`@("`D=&AI<RT^<')I;G1087)A
M;7,H)VED)RP@)W!O:6YT<R<L("=S='EL92<L("=T<F%N<V9O<FTG*3L*"B`@
M("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3Y?96QE;65N=',I*2!["B`@("`@
M("`@("`@("\O(%!R:6YT(&-H:6QD<F5N+"!S=&%R="!A;F0@96YD('1A9RX*
M("`@("`@("`@("`@<')I;G0H(CY<;B(I.PH@("`@("`@("`@("!P87)E;G0Z
M.G!R:6YT16QE;65N="@I.PH@("`@("`@("`@("!P<FEN="@B/"]P;VQY;&EN
M93Y<;B(I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O(%!R:6YT
M('-H;W)T('1A9RX*("`@("`@("`@("`@<')I;G0H(B\^7&XB*3L*("`@("`@
M("!]"B`@("!]"@H@("`@9G5N8W1I;VX@<V5T4VAA<&4H)'!O:6YT<RD*("`@
M('L*("`@("`@("`D=&AI<RT^7W!O:6YT<R`]("1P;VEN=',["B`@("!]"@I]
M"@HO*BH*("H@6$U,7U-61U]0;VQY9V]N"B`J"B`J($!P86-K86=E(%A-3%]3
M5D<*("HO"F-L87-S(%A-3%]35D=?4&]L>6=O;B!E>'1E;F1S(%A-3%]35D=?
M16QE;65N="!["@H@("`@=F%R("1?<&]I;G1S.PH*("`@(&9U;F-T:6]N('!R
M:6YT16QE;65N="@I"B`@("!["B`@("`@("`@96-H;R`G/'!O;'EG;VXG.PH@
M("`@("`@("1T:&ES+3YP<FEN=%!A<F%M<R@G:60G+"`G<&]I;G1S)RP@)W-T
M>6QE)RP@)W1R86YS9F]R;2<I.PH@("`@("`@(&EF("AI<U]A<G)A>2@D=&AI
M<RT^7V5L96UE;G1S*2D@>PH@("`@("`@("`@("`O+R!0<FEN="!C:&EL9')E
M;BP@<W1A<G0@86YD(&5N9"!T86<N"B`@("`@("`@("`@('!R:6YT*"(^7&XB
M*3L*("`@("`@("`@("`@<&%R96YT.CIP<FEN=$5L96UE;G0H*3L*("`@("`@
M("`@("`@<')I;G0H(CPO<&]L>6=O;CY<;B(I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("\O(%!R:6YT('-H;W)T('1A9RX*("`@("`@("`@("`@
M<')I;G0H(B\^7&XB*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@
M<V5T4VAA<&4H)'!O:6YT<RD*("`@('L*("`@("`@("`D=&AI<RT^7W!O:6YT
M<R`]("1P;VEN=',["B`@("!]"@I]"@HO*BH*("H@6$U,7U-61U]0871H"B`J
M"B`J($!P86-K86=E(%A-3%]35D<*("HO"F-L87-S(%A-3%]35D=?4&%T:"!E
M>'1E;F1S(%A-3%]35D=?16QE;65N="!["@H@("`@=F%R("1?9#L*"B`@("!F
M=6YC=&EO;B!P<FEN=$5L96UE;G0H*0H@("`@>PH@("`@("`@(&5C:&\@)SQP
M871H)SL*("`@("`@("`D=&AI<RT^<')I;G1087)A;7,H)VED)RP@)V0G+"`G
M<W1Y;&4G+"`G=')A;G-F;W)M)RD["B`@("`@("`@:68@*&ES7V%R<F%Y*"1T
M:&ES+3Y?96QE;65N=',I*2!["B`@("`@("`@("`@("\O(%!R:6YT(&-H:6QD
M<F5N+"!S=&%R="!A;F0@96YD('1A9RX*("`@("`@("`@("`@<')I;G0H(CY<
M;B(I.PH@("`@("`@("`@("!P87)E;G0Z.G!R:6YT16QE;65N="@I.PH@("`@
M("`@("`@("!P<FEN="@B/"]P871H/EQN(BD["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@+R\@4')I;G0@<VAO<G0@=&%G+@H@("`@("`@("`@("!P
M<FEN="@B+SY<;B(I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!S
M9713:&%P92@D9"D*("`@('L*("`@("`@("`D=&AI<RT^7V0@/2`D9#L*("`@
M('T*"GT*"B\J*@H@*B!834Q?4U9'7TEM86=E"B`J"B`J($!P86-K86=E(%A-
M3%]35D<*("HO"F-L87-S(%A-3%]35D=?26UA9V4@97AT96YD<R!834Q?4U9'
M7T5L96UE;G0@>PH*("`@('9A<B`D7W@["B`@("!V87(@)%]Y.PH@("`@=F%R
M("1?=VED=&@["B`@("!V87(@)%]H96EG:'0["B`@("!V87(@)%]H<F5F.PH*
M("`@(&9U;F-T:6]N('!R:6YT16QE;65N="@I"B`@("!["B`@("`@("`@96-H
M;R`G/&EM86=E)SL*("`@("`@("`D=&AI<RT^<')I;G1087)A;7,H)VED)RP@
M)W@G+"`G>2<L("=W:61T:"<L("=H96EG:'0G+"`G<W1Y;&4G*3L*("`@("`@
M("!I9B`H(65M<'1Y*"1T:&ES+3Y?:')E9BDI('L*("`@("`@("`@("`@96-H
M;R`G('AL:6YK.FAR968](B<@+B`D=&AI<RT^7VAR968@+B`G(B<["B`@("`@
M("`@?0H@("`@("`@(&EF("AI<U]A<G)A>2@D=&AI<RT^7V5L96UE;G1S*2D@
M>PH@("`@("`@("`@("`O+R!0<FEN="!C:&EL9')E;BP@<W1A<G0@86YD(&5N
M9"!T86<N"B`@("`@("`@("`@(&5C:&\@(CY<;B(["B`@("`@("`@("`@('!A
M<F5N=#HZ<')I;G1%;&5M96YT*"D["B`@("`@("`@("`@(&5C:&\@(CPO:6UA
M9V4^7&XB.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O(%!R:6YT
M('-H;W)T('1A9RX*("`@("`@("`@("`@96-H;R`B("\^7&XB.PH@("`@("`@
M('T*("`@('T*"B`@("!F=6YC=&EO;B!S9713:&%P92@D>"P@)'DL("1W:61T
M:"P@)&AE:6=H="D*("`@('L*("`@("`@("`D=&AI<RT^7W@@/2`D>#L*("`@
M("`@("`D=&AI<RT^7WD@/2`D>3L*("`@("`@("`D=&AI<RT^7W=I9'1H("`]
M("1W:61T:#L*("`@("`@("`D=&AI<RT^7VAE:6=H="`@/2`D:&5I9VAT.PH@
M("`@?0H*?0H*+RHJ"B`J(%A-3%]35D=?06YI;6%T90H@*@H@*B!`<&%C:V%G
M92!834Q?4U9'"B`J+PIC;&%S<R!834Q?4U9'7T%N:6UA=&4@97AT96YD<R!8
M34Q?4U9'7T5L96UE;G0@>PH*("`@('9A<B`D7V%T=')I8G5T94YA;64["B`@
M("!V87(@)%]A='1R:6)U=&54>7!E.PH@("`@=F%R("1?9G)O;3L*("`@('9A
M<B`D7W1O.PH@("`@=F%R("1?8F5G:6X["B`@("!V87(@)%]D=7(["B`@("!V
M87(@)%]F:6QL.PH*("`@(&9U;F-T:6]N('!R:6YT16QE;65N="@I"B`@("![
M"B`@("`@("`@96-H;R`G/&%N:6UA=&4G.PH@("`@("`@("1T:&ES+3YP<FEN
M=%!A<F%M<R@G:60G+"`G871T<FEB=71E3F%M92<L("=A='1R:6)U=&54>7!E
M)RP@)V9R;VTG+"`G=&\G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M8F5G:6XG+"`G9'5R)RP@)V9I;&PG*3L*("`@("`@("!I9B`H:7-?87)R87DH
M)'1H:7,M/E]E;&5M96YT<RDI('L*("`@("`@("`@("`@+R\@4')I;G0@8VAI
M;&1R96XL('-T87)T(&%N9"!E;F0@=&%G+@H@("`@("`@("`@("!E8VAO("(^
M7&XB.PH@("`@("`@("`@("!P87)E;G0Z.G!R:6YT16QE;65N="@I.PH@("`@
M("`@("`@("!E8VAO("(\+V%N:6UA=&4^7&XB.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(&5C:&\@(B`O/EQN(CL*("`@("`@("!]"B`@("!]"@H@
M("`@9G5N8W1I;VX@<V5T4VAA<&4H)&%T=')I8G5T94YA;64L("1A='1R:6)U
M=&54>7!E(#T@)R<L("1F<F]M(#T@)R<L"B`@("`@("`@("`@("`@("`@("`@
M("`D=&\@/2`G)RP@)&)E9VEN(#T@)R<L("1D=7(@/2`G)RP@)&9I;&P@/2`G
M)RD*("`@('L*("`@("`@("`D=&AI<RT^7V%T=')I8G5T94YA;64@/2`D871T
M<FEB=71E3F%M93L*("`@("`@("`D=&AI<RT^7V%T=')I8G5T951Y<&4@/2`D
M871T<FEB=71E5'EP93L*("`@("`@("`D=&AI<RT^7V9R;VT@(#T@)&9R;VT[
M"B`@("`@("`@)'1H:7,M/E]T;R`]("1T;SL*("`@("`@("`D=&AI<RT^7V)E
M9VEN(#T@)&)E9VEN.PH@("`@("`@("1T:&ES+3Y?9'5R(#T@)&1U<CL*("`@
M("`@("`D=&AI<RT^7V9I;&P@/2`D9FEL;#L*("`@('T*"GT*"B\J*@H@*B!8
M34Q?4U9'7T9I;'1E<@H@*@H@*B!`<&%C:V%G92!834Q?4U9'"B`J+PIC;&%S
M<R!834Q?4U9'7T9I;'1E<B!E>'1E;F1S(%A-3%]35D=?16QE;65N="!["@H@
M("`@9G5N8W1I;VX@<')I;G1%;&5M96YT*"D*("`@('L*("`@("`@("!E8VAO
M("<\9FEL=&5R)SL*("`@("`@("`D=&AI<RT^<')I;G1087)A;7,H)VED)RD[
M"B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3Y?96QE;65N=',I*2!["B`@
M("`@("`@("`@("\O(%!R:6YT(&-H:6QD<F5N+"!S=&%R="!A;F0@96YD('1A
M9RX*("`@("`@("`@("`@96-H;R`B/EQN(CL*("`@("`@("`@("`@<&%R96YT
M.CIP<FEN=$5L96UE;G0H*3L*("`@("`@("`@("`@96-H;R`B/"]F:6QT97(^
M7&XB.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&5C:&\@(B`O/EQN
M(CL*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@861D4')I;6ET:79E
M*"1P<FEM:71I=F4L("1P87)A;7,I"B`@("!["B`@("`@("`@)'1H:7,M/F%D
M9$-H:6QD*&YE=R!834Q?4U9'7T9I;'1E<E!R:6UI=&EV92@D<')I;6ET:79E
M+"`D<&%R86US*2D["B`@("!]"@I]"@HO*BH*("H@6$U,7U-61U]&:6QT97)0
M<FEM:71I=F4*("H*("H@0'!A8VMA9V4@6$U,7U-61PH@*B\*8VQA<W,@6$U,
M7U-61U]&:6QT97)0<FEM:71I=F4@97AT96YD<R!834Q?4U9'7T5L96UE;G0@
M>PH*("`@('9A<B`D7W!R:6UI=&EV97,@/2!A<G)A>2@G0FQE;F0G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=#;VQO<DUA=')I>"<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)T-O;7!O;F5N=%1R86YS9F5R)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G0V]M<&]S:71E)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G0V]N=F]L=F5-871R:7@G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=$:69F=7-E3&EG:'1I;F<G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=$:7-P;&%C96UE;G1-
M87`G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=&;&]O9"<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)T=A=7-S:6%N0FQU<B<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)TEM86=E)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G365R9V4G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=-;W)P:&]L;V=Y)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G3V9F<V5T)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G4W!E8W5L87),:6=H=&EN9R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)U1I;&4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=4=7)B=6QE;F-E)RD["@H@("`@=F%R("1?<')I;6ET:79E.PH*("`@('9A
M<B`D7VEN.PH@("`@=F%R("1?:6XR.PH@("`@=F%R("1?<F5S=6QT.PH@("`@
M=F%R("1?>#L*("`@('9A<B`D7WD["B`@("!V87(@)%]D>#L*("`@('9A<B`D
M7V1Y.PH@("`@=F%R("1?=VED=&@["B`@("!V87(@)%]H96EG:'0["B`@("!V
M87(@)%]M;V1E.PH@("`@=F%R("1?='EP93L*("`@('9A<B`D7W9A;'5E<SL*
M("`@('9A<B`D7V]P97)A=&]R.PH@("`@=F%R("1?:S$["B`@("!V87(@)%]K
M,CL*("`@('9A<B`D7VLS.PH@("`@=F%R("1?:S0["B`@("!V87(@)%]S=7)F
M86-E4V-A;&4["B`@("!V87(@)%]D:69F=7-E0V]N<W1A;G0["B`@("!V87(@
M)%]K97)N96Q5;FET3&5N9W1H.PH@("`@=F%R("1?9FQO;W)?8V]L;W(["B`@
M("!V87(@)%]F;&]O9%]O<&%C:71Y.PH*("`@(&9U;F-T:6]N(%A-3%]35D=?
M1FEL=&5R4')I;6ET:79E*"1P<FEM:71I=F4L("1P87)A;7,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@('!A<F5N=#HZ6$U,7U-61U]%;&5M96YT*"1P87)A
M;7,I.PH@("`@("`@("1T:&ES+3Y?<')I;6ET:79E(#T@)'!R:6UI=&EV93L*
M("`@('T*"B`@("!F=6YC=&EO;B!P<FEN=$5L96UE;G0H*0H@("`@>PH@("`@
M("`@("1N86UE(#T@)V9E)R`N("1T:&ES+3Y?<')I;6ET:79E.PH@("`@("`@
M(&5C:&\@)SPG("X@)&YA;64["B`@("`@("`@)'1H:7,M/G!R:6YT4&%R86US
M*"=I9"<L("=X)RP@)WDG+"`G9'@G+"`G9'DG+"`G=VED=&@G+"`G:&5I9VAT
M)RP@)VEN)RP@)VEN,B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("=R
M97-U;'0G+"`G;6]D92<L("=T>7!E)RP@)W9A;'5E<R<L("=O<&5R871O<B<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("=K,2<L("=K,B<L("=K,R<L
M("=K-"<L("=S=7)F86-E4V-A;&4G+"`G<W1D1&5V:6%T:6]N)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V1I9F9U<V5#;VYS=&%N="<L("=K97)N
M96Q5;FET3&5N9W1H)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@)V9L
M;V]D7V-O;&]R)RP@)V9L;V]D7V]P86-I='DG*3L*("`@("`@("!I9B`H:7-?
M87)R87DH)'1H:7,M/E]E;&5M96YT<RDI('L*("`@("`@("`@("`@+R\@4')I
M;G0@8VAI;&1R96XL('-T87)T(&%N9"!E;F0@=&%G+@H@("`@("`@("`@("!E
M8VAO("(^7&XB.PH@("`@("`@("`@("!P87)E;G0Z.G!R:6YT16QE;65N="@I
M.PH@("`@("`@("`@("!E8VAO("<\+R<@+B`D;F%M92`N("<^)SL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!E8VAO("<O/B<["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@1F]R(&9E365R9V4@96QE;65N=',N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&%D9$UE<F=E3F]D92@D:6XI"B`@("!["B`@
M("`@("`@)'1H:7,M/F%D9$-H:6QD*&YE=R!834Q?4U9'7T9I;'1E<DUE<F=E
M3F]D92AA<G)A>2@G:6XG(#T^("1I;BDI*3L*("`@('T*"GT*"B\J*@H@*B!8
M34Q?4U9'7T9I;'1E<DUE<F=E3F]D90H@*@H@*B!`<&%C:V%G92!834Q?4U9'
M"B`J+PIC;&%S<R!834Q?4U9'7T9I;'1E<DUE<F=E3F]D92!E>'1E;F1S(%A-
M3%]35D=?16QE;65N="!["@H@("`@=F%R("1?:6X["@H@("`@9G5N8W1I;VX@
M<')I;G1%;&5M96YT*"D*("`@('L*("`@("`@("!E8VAO("<\9F5-97)G94YO
M9&4G.PH@("`@("`@("1T:&ES+3YP<FEN=%!A<F%M<R@G:6XG*3L*("`@("`@
M("!E8VAO("<O/B<["B`@("!]"@I]"@HO*BH*("H@6$U,7U-61U]5<V4*("H*
M("H@0'!A8VMA9V4@6$U,7U-61PH@*B\*8VQA<W,@6$U,7U-61U]5<V4@97AT
M96YD<R!834Q?4U9'7T5L96UE;G0@>PH*("`@('9A<B`D7W-Y;6)O;#L*"B`@
M("!F=6YC=&EO;B!834Q?4U9'7U5S92@D<WEM8F]L+"`D<&%R86US(#T@87)R
M87DH*2D*("`@('L*("`@("`@("!P87)E;G0Z.EA-3%]35D=?16QE;65N="@D
M<&%R86US*3L*("`@("`@("`D=&AI<RT^7W-Y;6)O;"`]("1S>6UB;VP["B`@
M("!]"@H@("`@9G5N8W1I;VX@<')I;G1%;&5M96YT*"D*("`@('L*("`@("`@
M("!E8VAO("<\=7-E('AL:6YK.FAR968](B,G("X@)'1H:7,M/E]S>6UB;VP@
M+B`G(B\^)SL*("`@('T*"GT*"B\J*@H@*B!834Q?4U9'7T1E9G,*("H*("H@
M0'!A8VMA9V4@6$U,7U-61PH@*B\*8VQA<W,@6$U,7U-61U]$969S(&5X=&5N
M9',@6$U,7U-61U]%;&5M96YT('L*"B`@("!F=6YC=&EO;B!P<FEN=$5L96UE
M;G0H*0H@("`@>PH@("`@("`@(&5C:&\@)SQD969S)SL*("`@("`@("`D=&AI
M<RT^<')I;G1087)A;7,H)VED)RP@)W-T>6QE)RP@)W1R86YS9F]R;2<I.PH@
M("`@("`@(&5C:&\@(CY<;B(["B`@("`@("`@<&%R96YT.CIP<FEN=$5L96UE
M;G0H*3L*("`@("`@("!E8VAO("(\+V1E9G,^7&XB.PH@("`@?0H*?0H*+RHJ
M"B`J(%A-3%]35D=?36%R:V5R"B`J"B`J($!P86-K86=E(%A-3%]35D<*("HO
M"F-L87-S(%A-3%]35D=?36%R:V5R(&5X=&5N9',@6$U,7U-61U]%;&5M96YT
M('L*"B`@("!V87(@)%]R9698.PH@("`@=F%R("1?<F5F63L*("`@('9A<B`D
M7VUA<FME<E5N:71S.PH@("`@=F%R("1?;6%R:V5R5VED=&@["B`@("!V87(@
M)%]M87)K97)(96EG:'0["B`@("!V87(@)%]O<FEE;G0["@H@("`@9G5N8W1I
M;VX@<')I;G1%;&5M96YT*"D*("`@('L*("`@("`@("!E8VAO("<\;6%R:V5R
M)SL*("`@("`@("`D=&AI<RT^<')I;G1087)A;7,H)VED)RP@)W)E9E@G+"`G
M<F5F62<L("=M87)K97)5;FET<R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=M87)K97)7:61T:"<L("=M87)K97)(96EG:'0G+"`G;W)I96YT)RD[
M"B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3Y?96QE;65N=',I*2![("\O
M(%!R:6YT(&-H:6QD<F5N+"!S=&%R="!A;F0@96YD('1A9RX*("`@("`@("`@
M("`@<')I;G0H(CY<;B(I.PH@("`@("`@("`@("!P87)E;G0Z.G!R:6YT16QE
M;65N="@I.PH@("`@("`@("`@("!P<FEN="@B/"]M87)K97(^7&XB*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!P<FEN="@B+SY<;B(I.PH@("`@
M("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!S9713:&%P92@D<F5F6"`]("<G
M+"`D<F5F62`]("<G+"`D;6%R:V5R56YI=',@/2`G)RP*("`@("`@("`@("`@
M("`@("`@("`@("1M87)K97)7:61T:"`]("<G+"`D;6%R:V5R2&5I9VAT(#T@
M)R<L("1O<FEE;G0@/2`G)RD*("`@('L*("`@("`@("`D=&AI<RT^7W)E9E@@
M/2`D<F5F6#L*("`@("`@("`D=&AI<RT^7W)E9ED@(#T@)')E9ED["B`@("`@
M("`@)'1H:7,M/E]M87)K97)5;FET<R`]("1M87)K97)5;FET<SL*("`@("`@
M("`D=&AI<RT^7VUA<FME<E=I9'1H(#T@)&UA<FME<E=I9'1H.PH@("`@("`@
M("1T:&ES+3Y?;6%R:V5R2&5I9VAT(#T@)&UA<FME<DAE:6=H=#L*("`@("`@
M("`D=&AI<RT^7V]R:65N="`]("1O<FEE;G0["B`@("!]"@I]"@HO*BH*("H@
M6$U,7U-61U]4:71L90H@*@H@*B!`<&%C:V%G92!834Q?4U9'"BHO"F-L87-S
M(%A-3%]35D=?5&ET;&4@97AT96YD<R!834Q?4U9'7T5L96UE;G0@>PH*("`@
M('9A<B`D7W1I=&QE.PH*("`@(&9U;F-T:6]N('!R:6YT16QE;65N="@I"B`@
M("!["B`@("`@("`@96-H;R`G/'1I=&QE)SL*("`@("`@("`D=&AI<RT^<')I
M;G1087)A;7,H)VED)RP@)W-T>6QE)RD["B`@("`@("`@<')I;G0H(CY<;B(I
M.PH@("`@("`@('!R:6YT*"1T:&ES+3Y?=&ET;&4I.PH@("`@("`@('!A<F5N
M=#HZ<')I;G1%;&5M96YT*"D["B`@("`@("`@<')I;G0H(CPO=&ET;&4^7&XB
M*3L*("`@('T*"GT*"B\J*@H@*B!834Q?4U9'7T1E<V,*("H*("H@0'!A8VMA
M9V4@6$U,7U-61PH@*B\*8VQA<W,@6$U,7U-61U]$97-C(&5X=&5N9',@6$U,
M7U-61U]%;&5M96YT('L*"B`@("!V87(@)%]D97-C.PH*("`@(&9U;F-T:6]N
M('!R:6YT16QE;65N="@I"B`@("!["B`@("`@("`@96-H;R`G/&1E<V,G.PH@
M("`@("`@("1T:&ES+3YP<FEN=%!A<F%M<R@G:60G+"`G<W1Y;&4G*3L*("`@
M("`@("!E8VAO("<^)R`N("1T:&ES+3Y?9&5S8SL*("`@("`@("!P87)E;G0Z
M.G!R:6YT16QE;65N="@I.PH@("`@("`@(&5C:&\@(CPO9&5S8SY<;B(["B`@
M("!]"@I]"@HO*BH*("H@6$U,7U-61U]4<F5F"B`J"B`J($!P86-K86=E(%A-
M3%]35D<*("HO"F-L87-S(%A-3%]35D=?5')E9B!E>'1E;F1S(%A-3%]35D=?
M16QE;65N="!["@H@("`@=F%R("1?=&5X=#L*("`@('9A<B`D7W@["B`@("!V
M87(@)%]Y.PH@("`@=F%R("1?9'@["B`@("!V87(@)%]D>3L*("`@('9A<B`D
M7W)O=&%T93L*("`@('9A<B`D7W1E>'1,96YG=&@["B`@("!V87(@)%]L96YG
M=&A!9&IU<W0["@H@("`@9G5N8W1I;VX@<')I;G1%;&5M96YT*"D*("`@('L*
M("`@("`@("!E8VAO("<\=')E9B<["B`@("`@("`@)'1H:7,M/G!R:6YT4&%R
M86US*"=I9"<L("=X)RP@)WDG+"`G9'@G+"`G9'DG+"`G<F]T871E)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W1E>'1,96YG=&@G+"`G;&5N9W1H
M061J=7-T)RP@)W-T>6QE)RD["B`@("`@("`@96-H;R`G/B<@+B`D=&AI<RT^
M7W1E>'0["B`@("`@("`@<&%R96YT.CIP<FEN=$5L96UE;G0H*3L*("`@("`@
M("!E8VAO("(\+W1R968^7&XB.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+UA-3"]70EA-3"YP:'``````````````
M````````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#(R,C`V(#$P-3$U
M-#,S-S,U(#`R,#,U,P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`H*+RHJ"B`J($-O;G-T86YT<R!A<F4@9G)O;2!"
M:6YA<GD@6$U,($-O;G1E;G0@1F]R;6%T(%-P96-I9FEC871I;VX@5F5R<VEO
M;@H@*B`Q+C,L(#(U($IU;'D@,C`P,2!F;W5N9"!A="!H='1P.B\O=W=W+G=A
M<&9O<G5M+F]R9PH@*B\*"B\J*@H@*B!&<F]M(#<N,2!';&]B86P@5&]K96YS
M+@H@*B\*"F1E9FEN92@G6$U,7U="6$U,7T=,3T)!3%]43TM%3E]35TE40TA?
M4$%'12<L(#`I.R`@+R\@,'@P,`ID969I;F4H)UA-3%]70EA-3%]'3$]"04Q?
M5$]+14Y?14Y$)RP@,2D[("`@("`@("`@("\O(#!X,#$*9&5F:6YE*"=834Q?
M5T)834Q?1TQ/0D%,7U1/2T5.7T5.5$E462<L(#(I.R`@("`@("`O+R`P>#`R
M"F1E9FEN92@G6$U,7U="6$U,7T=,3T)!3%]43TM%3E]35%)?22<L(#,I.R`@
M("`@("`@+R\@,'@P,PID969I;F4H)UA-3%]70EA-3%]'3$]"04Q?5$]+14Y?
M3$E415)!3"<L(#0I.R`@("`@("\O(#!X,#0*"F1E9FEN92@G6$U,7U="6$U,
M7T=,3T)!3%]43TM%3E]%6%1?25\P)RP@-C0I.R`@("`@+R\@,'@T,`ID969I
M;F4H)UA-3%]70EA-3%]'3$]"04Q?5$]+14Y?15A47TE?,2<L(#8U*3L@("`@
M("\O(#!X-#$*9&5F:6YE*"=834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T585%])
M7S(G+"`V-BD[("`@("`O+R`P>#0R"F1E9FEN92@G6$U,7U="6$U,7T=,3T)!
M3%]43TM%3E]022<L(#8W*3L@("`@("`@("`@+R\@,'@T,PID969I;F4H)UA-
M3%]70EA-3%]'3$]"04Q?5$]+14Y?3$E415)!3%]#)RP@-C@I.R`@("\O(#!X
M-#0*"F1E9FEN92@G6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?5%\P)RP@
M,3(X*3L@("`@+R\@,'@X,`ID969I;F4H)UA-3%]70EA-3%]'3$]"04Q?5$]+
M14Y?15A47U1?,2<L(#$R.2D[("`@("\O(#!X.#$*9&5F:6YE*"=834Q?5T)8
M34Q?1TQ/0D%,7U1/2T5.7T585%]47S(G+"`Q,S`I.R`@("`O+R`P>#@R"F1E
M9FEN92@G6$U,7U="6$U,7T=,3T)!3%]43TM%3E]35%)?5"<L(#$S,2D[("`@
M("`@+R\@,'@X,PID969I;F4H)UA-3%]70EA-3%]'3$]"04Q?5$]+14Y?3$E4
M15)!3%]!)RP@,3,R*3L@("\O(#!X.#0*"F1E9FEN92@G6$U,7U="6$U,7T=,
M3T)!3%]43TM%3E]%6%1?,"<L(#$Y,BD[("`@("`@+R\@,'A#,`ID969I;F4H
M)UA-3%]70EA-3%]'3$]"04Q?5$]+14Y?15A47S$G+"`Q.3,I.R`@("`@("\O
M(#!X0S$*9&5F:6YE*"=834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T585%\R)RP@
M,3DT*3L@("`@("`O+R`P>$,R"F1E9FEN92@G6$U,7U="6$U,7T=,3T)!3%]4
M3TM%3E]/4$%1544G+"`Q.34I.R`@("`@+R\@,'A#,PID969I;F4H)UA-3%]7
M0EA-3%]'3$]"04Q?5$]+14Y?3$E415)!3%]!0R<L(#$Y-BD[("\O(#!X0S0*
M"B\J*@H@*B!.;W0@<W5R92!W:&5R92!D969I;F5D+@H@*B!!1$0@0TA!4%1%
M4@H@*B\*9&5F:6YE*"=$4$E?1%1$7U=-3%\Q7S`G+"`G+2\O5T%01D]254TO
M+T141"!734P@,2XP+R]%3B<I.PID969I;F4H)T1025]$5$1?5U1!7S%?,"<L
M("<M+R]705!&3U)532\O1%1$(%=402`Q+C`O+T5.)RD["F1E9FEN92@G1%!)
M7T141%]734Q?,5\Q)RP@)RTO+U=!4$9/4E5-+R]$5$0@5TU,(#$N,2\O14XG
M*3L*9&5F:6YE*"=$4$E?1%1$7U-)7S%?,2<L("<M+R]705!&3U)532\O1%1$
M(%-)(#$N,2\O14XG*3L*9&5F:6YE*"=$4$E?1%1$7U-,7S%?,"<L("<M+R]7
M05!&3U)532\O1%1$(%-,(#$N,"\O14XG*3L*9&5F:6YE*"=$4$E?1%1$7T-/
M7S%?,"<L("<M+R]705!&3U)532\O1%1$($-/(#$N,"\O14XG*3L*9&5F:6YE
M*"=$4$E?1%1$7T-(04Y.14Q?,5\Q)RP@)RTO+U=!4$9/4E5-+R]$5$0@0TA!
M3DY%3"`Q+C$O+T5.)RD["F1E9FEN92@G1%!)7T141%]734Q?,5\R)RP@)RTO
M+U=!4$9/4E5-+R]$5$0@5TU,(#$N,B\O14XG*3L*9&5F:6YE*"=$4$E?1%1$
M7U=-3%\Q7S,G+"`G+2\O5T%01D]254TO+T141"!734P@,2XS+R]%3B<I.PID
M969I;F4H)T1025]$5$1?4%)/5E\Q7S`G+"`G+2\O5T%01D]254TO+T141"!0
M4D]6(#$N,"\O14XG*3L*9&5F:6YE*"=$4$E?1%1$7U=405]734Q?,5\R)RP@
M)RTO+U=!4$9/4E5-+R]$5$0@5U1!+5=-3"`Q+C(O+T5.)RD["F1E9FEN92@G
M1%!)7T141%]#2$%.3D5,7S%?,B<L("<M+R]705!&3U)532\O1%1$($-(04Y.
M14P@,2XR+R]%3B<I.PID969I;F4H)T1025]$5$1?4UE.0TU,7S%?,"<L("<M
M+R]364Y#34PO+T141"!3>6YC34P@,2XP+R]%3B<I.PID969I;F4H)T1025]$
M5$1?1$5624Y&7S%?,"<L("<M+R]364Y#34PO+T141"!$979);F8@,2XP+R]%
M3B<I.PID969I;F4H)T1025]$5$1?4UE.0TU,7S%?,2<L("<M+R]364Y#34PO
M+T141"!3>6YC34P@,2XQ+R]%3B<I.PID969I;F4H)T1025]$5$1?1$5624Y&
M7S%?,2<L("<M+R]364Y#34PO+T141"!$979);F8@,2XQ+R]%3B<I.PH*+RHJ
M"B`J($]N;'D@9&5F875L="!C:&%R86-T97(@96YC;V1I;F=S(&9R;VT@2C)3
M12!A<F4@8W5R<F5N=&QY('-U<'!O<G1E9"X*("HO"F1E9FEN92@G0TA!4E-%
M5%]54U]!4T-)22<L("=54RU!4T-)22<I.PID969I;F4H)T-(05)3151?25-/
M7S@X-3E?,2<L("=)4T\M.#@U.2TQ)RD["F1E9FEN92@G0TA!4E-%5%]55$9?
M."<L("=55$8M."<I.PID969I;F4H)T-(05)3151?551&7S$V0D4G+"`G551&
M+3$V0D4G*3L*9&5F:6YE*"=#2$%24T547U541E\Q-DQ%)RP@)U541BTQ-DQ%
M)RD["F1E9FEN92@G0TA!4E-%5%]55$9?,38G+"`G551&+3$V)RD["@HO*BH*
M("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!!;G1H;VYY($UI;&QS(#QA;6EL;'-`
M<'ER86UI9#8N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+UA-3%]70EA-3"]70EA-3"YP:'`L=B`Q+C$S+C$R+C@@,C`P-B\P
M,R\Q,R`P.3HQ-CHR-2!J86X@17AP("0*("H*("H@0'!A8VMA9V4@6$U,7U="
M6$U,"B`J+PIC;&%S<R!834Q?5T)834P@>PH*("`@("\J*@H@("`@("H@1&5C
M;V1I;F<@375L=&DM8GET92!);G1E9V5R<R!F<F]M(%-E8W1I;VX@-2XQ"B`@
M("`@*@H@("`@("H@57-E(&QO;F<@8F5C875S92!I="!I<R!U;G-I9VYE9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@34)526YT,S)4;TEN="@D:6XL("8D<&]S
M*0H@("`@>PH@("`@("`@("1V86P@/2`P.PH*("`@("`@("!D;R!["B`@("`@
M("`@("`@("1B(#T@;W)D*"1I;ELD<&]S*RM=*3L*("`@("`@("`@("`@)'9A
M;"`\/#T@-SL@+R\@0FET<VAI9G0@;&5F="`W(&)I=',N"B`@("`@("`@("`@
M("1V86P@*ST@*"1B("8@,3(W*3L*("`@("`@("!]('=H:6QE("@H)&(@)B`Q
M,C@I("$](#`I.PH*("`@("`@("!R971U<FX@)'9A;#L*("`@('T*"B`@("`O
M*BH*("`@("`J($5N8V]D:6YG($UU;'1I+6)Y=&4@26YT96=E<G,@9G)O;2!3
M96-T:6]N(#4N,0H@("`@("HO"B`@("!F=6YC=&EO;B!I;G14;TU"54EN=#,R
M*"8D;W5T+"`D:2D*("`@('L*("`@("`@("!I9B`H)&D@/B`R-C@T,S4T-34I
M('L*("`@("`@("`@("`@)&)Y=&5S,"`](#`@?"!834Q?5T)834PZ.F=E=$)I
M=',H,"P@)&DI.PH@("`@("`@("`@("`D8GET97,Q(#T@,3(X('P@6$U,7U="
M6$U,.CIG971":71S*#$L("1I*3L*("`@("`@("`@("`@)&)Y=&5S,B`](#$R
M."!\(%A-3%]70EA-3#HZ9V5T0FET<R@R+"`D:2D["B`@("`@("`@("`@("1B
M>71E<S,@/2`Q,C@@?"!834Q?5T)834PZ.F=E=$)I=',H,RP@)&DI.PH@("`@
M("`@("`@("`D8GET97,T(#T@,3(X('P@6$U,7U="6$U,.CIG971":71S*#0L
M("1I*3L*"B`@("`@("`@("`@("1O=70@+CT@8VAR*"1B>71E<S0I("X@8VAR
M*"1B>71E<S,I("X@8VAR*"1B>71E<S(I("X@8VAR*"1B>71E<S$I("X@8VAR
M*"1B>71E<S`I.PH@("`@("`@('T@96QS96EF("@D:2`^(#(P.3<Q-3$I('L*
M("`@("`@("`@("`@)&)Y=&5S,"`](#`@?"!834Q?5T)834PZ.F=E=$)I=',H
M,"P@)&DI.PH@("`@("`@("`@("`D8GET97,Q(#T@,3(X('P@6$U,7U="6$U,
M.CIG971":71S*#$L("1I*3L*("`@("`@("`@("`@)&)Y=&5S,B`](#$R."!\
M(%A-3%]70EA-3#HZ9V5T0FET<R@R+"`D:2D["B`@("`@("`@("`@("1B>71E
M<S,@/2`Q,C@@?"!834Q?5T)834PZ.F=E=$)I=',H,RP@)&DI.PH*("`@("`@
M("`@("`@)&]U="`N/2!C:'(H)&)Y=&5S,RD@+B!C:'(H)&)Y=&5S,BD@+B!C
M:'(H)&)Y=&5S,2D@+B!C:'(H)&)Y=&5S,"D["B`@("`@("`@?2!E;'-E:68@
M*"1I(#X@,38S.#,I('L*("`@("`@("`@("`@)&)Y=&5S,"`](#`@?"!834Q?
M5T)834PZ.F=E=$)I=',H,"P@)&DI.PH@("`@("`@("`@("`D8GET97,Q(#T@
M,3(X('P@6$U,7U="6$U,.CIG971":71S*#$L("1I*3L*("`@("`@("`@("`@
M)&)Y=&5S,B`](#$R."!\(%A-3%]70EA-3#HZ9V5T0FET<R@R+"`D:2D["@H@
M("`@("`@("`@("`D;W5T("X](&-H<B@D8GET97,R*2`N(&-H<B@D8GET97,Q
M*2`N(&-H<B@D8GET97,P*3L*("`@("`@("!](&5L<V5I9B`H)&D@/B`Q,C<I
M('L*("`@("`@("`@("`@)&)Y=&5S,"`](#`@?"!834Q?5T)834PZ.F=E=$)I
M=',H,"P@)&DI.PH@("`@("`@("`@("`D8GET97,Q(#T@,3(X('P@6$U,7U="
M6$U,.CIG971":71S*#$L("1I*3L*"B`@("`@("`@("`@("1O=70@+CT@8VAR
M*"1B>71E<S$I("X@8VAR*"1B>71E<S`I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1B>71E<S`@/2`P('P@6$U,7U="6$U,.CIG971":71S*#`L
M("1I*3L*"B`@("`@("`@("`@("1O=70@+CT@8VAR*"1B>71E<S`I.PH@("`@
M("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!G971":71S*"1N=6TL("1L*0H@
M("`@>PH@("`@("`@('-W:71C:"`H)&YU;2D@>PH@("`@("`@(&-A<V4@,#H*
M("`@("`@("`@("`@<F5T=7)N("1L("8@,3(W.R`O+R`P>#=&"@H@("`@("`@
M(&-A<V4@,3H*("`@("`@("`@("`@<F5T=7)N("@D;"`^/B`W*2`F(#$R-SL@
M+R\@,'@W1@H*("`@("`@("!C87-E(#(Z"B`@("`@("`@("`@(')E='5R;B`H
M)&P@/CX@,30I("8@,3(W.R`O+R`P>#=&"@H@("`@("`@(&-A<V4@,SH*("`@
M("`@("`@("`@<F5T=7)N("@D;"`^/B`R,2D@)B`Q,C<[("\O(#!X-T8*"B`@
M("`@("`@8V%S92`T.@H@("`@("`@("`@("!R971U<FX@*"1L(#X^(#(X*2`F
M(#$R-SL@+R\@,'@W1@H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(#`["B`@
M("!]"@H@("`@9G5N8W1I;VX@9V5T1%!)4W1R:6YG*"1I*0H@("`@>PH@("`@
M("`@("\J*@H@("`@("`@("`J($%$1"!#2$%05$52"B`@("`@("`@("HO"B`@
M("`@("`@)$1025-T<FEN9R`](&%R<F%Y*#(@/3X@1%!)7T141%]734Q?,5\P
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`S(#T^($1025]$5$1?5U1!
M7S%?,"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@-"`]/B!$4$E?1%1$
M7U=-3%\Q7S$L"B`@("`@("`@("`@("`@("`@("`@("`@("`@(#4@/3X@1%!)
M7T141%]325\Q7S$L"B`@("`@("`@("`@("`@("`@("`@("`@("`@(#8@/3X@
M1%!)7T141%]33%\Q7S`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@(#<@
M/3X@1%!)7T141%]#3U\Q7S`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#@@/3X@1%!)7T141%]#2$%.3D5,7S%?,2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@.2`]/B!$4$E?1%1$7U=-3%\Q7S(L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#$P(#T^($1025]$5$1?5TU,7S%?,RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@,3$@/3X@1%!)7T141%]04D]67S%?,"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@,3(@/3X@1%!)7T141%]75$%?5TU,
M7S%?,BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@,3,@/3X@1%!)7T14
M1%]#2$%.3D5,7S%?,BP*"B`@("`@("`@("`@("`@("`@("`@("`@("`@("\O
M($YO="!A;&P@4WEN8TU,(&-L:65N=',@:VYO=R!T:&ES+"!S;R!W90H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`O+R!S:&]U;&0@=7-E('1H92!S=')I
M;F<@=&%B;&4N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(#!X1D0Q
M(#T^($1025]$5$1?4UE.0TU,7S%?,2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@-#`T.2`]/B!$4$E?1%1$7U-93D--3%\Q7S`L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#0P-3`@/3X@1%!)7T141%]$159)3D9?,5\P+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`T,#4Q(#T^($1025]$5$1?4UE.
M0TU,7S%?,2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@-#`U,B`]/B!$
M4$E?1%1$7T1%5DE.1E\Q7S$L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("D["B`@("`@("`@<F5T=7)N(&ES<V5T*"1$4$E3=')I;F=;)&E=*2`_("1$
M4$E3=')I;F=;)&E=(#H@;G5L;#L*("`@('T*"B`@("!F=6YC=&EO;B!G971$
M4$E);G0H)&1P:2D*("`@('L*("`@("`@("`O*BH*("`@("`@("`@*B!!1$0@
M0TA!4%1%4@H@("`@("`@("`J+PH@("`@("`@("1$4$E);G0@/2!A<G)A>2A$
M4$E?1%1$7U=-3%\Q7S`@/3X@,BP*("`@("`@("`@("`@("`@("`@("`@("`@
M1%!)7T141%]75$%?,5\P(#T^(#,L"B`@("`@("`@("`@("`@("`@("`@("`@
M($1025]$5$1?5TU,7S%?,2`]/B`T+`H@("`@("`@("`@("`@("`@("`@("`@
M("!$4$E?1%1$7U-)7S%?,2`]/B`U+`H@("`@("`@("`@("`@("`@("`@("`@
M("!$4$E?1%1$7U-,7S%?,"`]/B`V+`H@("`@("`@("`@("`@("`@("`@("`@
M("!$4$E?1%1$7T-/7S%?,"`]/B`W+`H@("`@("`@("`@("`@("`@("`@("`@
M("!$4$E?1%1$7T-(04Y.14Q?,5\Q(#T^(#@L"B`@("`@("`@("`@("`@("`@
M("`@("`@($1025]$5$1?5TU,7S%?,B`]/B`Y+`H@("`@("`@("`@("`@("`@
M("`@("`@("!$4$E?1%1$7U=-3%\Q7S,@/3X@,3`L"B`@("`@("`@("`@("`@
M("`@("`@("`@($1025]$5$1?4%)/5E\Q7S`@/3X@,3$L"B`@("`@("`@("`@
M("`@("`@("`@("`@($1025]$5$1?5U1!7U=-3%\Q7S(@/3X@,3(L"B`@("`@
M("`@("`@("`@("`@("`@("`@($1025]$5$1?0TA!3DY%3%\Q7S(@/3X@,3,L
M"@H@("`@("`@("`@("`@("`@("`@("`@("`O+R!.;W0@86QL(%-Y;F--3"!C
M;&EE;G1S(&MN;W<@=&AI<RP@<V\@;6%Y8F4@=V4*("`@("`@("`@("`@("`@
M("`@("`@("`@+R\@<VAO=6QD('5S92!T:&4@<W1R:6YG('1A8FQE+@H@("`@
M("`@("`@("`@("`@("`@("`@("!$4$E?1%1$7U-93D--3%\Q7S`@/3X@-#`T
M.2P*("`@("`@("`@("`@("`@("`@("`@("`@1%!)7T141%]$159)3D9?,5\P
M(#T^(#0P-3`L"B`@("`@("`@("`@("`@("`@("`@("`@($1025]$5$1?4UE.
M0TU,7S%?,2`]/B`T,#4Q+`H@("`@("`@("`@("`@("`@("`@("`@("!$4$E?
M1%1$7T1%5DE.1E\Q7S$@/3X@-#`U,@H@("`@("`@("`@("`@("`@("`@("`@
M("`O+R!$4$E?1%1$7U-93D--3%\Q7S$@/3X@,'A&1#$L"B`@("`@("`@("`@
M("`@("`@("`@("`@("\O($1025]$5$1?1$5624Y&7S%?,2`]/B`P>$9$,BP*
M("`@("`@("`@("`@("`@("`@("`@("`@*3L*"B`@("`@("`@<F5T=7)N(&ES
M<V5T*"1$4$E);G1;)&1P:5TI(#\@)$1024EN=%LD9'!I72`Z(#`["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C:&%R86-T97(@96YC;V1I
M;F<N"B`@("`@*B!O;FQY(&1E9F%U;'0@8VAA<F%C=&5R(&5N8V]D:6YG<R!F
M<F]M($HR4T4@87)E('-U<'!O<G1E9`H@("`@("H@9G)O;2!H='1P.B\O=W=W
M+FEA;F$N;W)G+V%S<VEG;FUE;G1S+V-H87)A8W1E<BUS971S"B`@("`@*B!A
M;F0@:'1T<#HO+VIA=F$N<W5N+F-O;2]J,G-E+S$N-"XR+V1O8W,O87!I+VIA
M=F$O;FEO+V-H87)S970O0VAA<G-E="YH=&UL"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$-H87)S9713=')I;F<H)&-S*0H@("`@>PH@("`@("`@("\J*@H@
M("`@("`@("`J($9R;VT@:'1T<#HO+W=W=RYI86YA+F]R9R]A<W-I9VYM96YT
M<R]C:&%R86-T97(M<V5T<PH@("`@("`@("`J+PH@("`@("`@("1C:&%R<V5T
M4W1R:6YG(#T@87)R87DH,R`]/B`G55,M05-#24DG+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@-"`]/B`G25-/+3@X-3DM,2<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`Q,#8@/3X@)U541BTX)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#$P,3,@/3X@)U541BTQ-D)%)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#$P,30@/3X@)U541BTQ
M-DQ%)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#$P,34@/3X@
M)U541BTQ-B<I.PH*("`@("`@("!R971U<FX@:7-S970H)&-H87)S9713=')I
M;F=;)&-S72D@/R`D8VAA<G-E=%-T<FEN9ULD8W-=(#H@;G5L;#L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-H87)A8W1E<B!E;F-O9&EN
M9RX*("`@("`J"B`@("`@*B!/;FQY(&1E9F%U;'0@8VAA<F%C=&5R(&5N8V]D
M:6YG<R!F<F]M($HR4T4@87)E('-U<'!O<G1E9"X*("`@("`J"B`@("`@*B!&
M<F]M(&AT='`Z+R]W=W<N:6%N82YO<F<O87-S:6=N;65N=',O8VAA<F%C=&5R
M+7-E=',@86YD"B`@("`@*B!H='1P.B\O:F%V82YS=6XN8V]M+VHR<V4O,2XT
M+C(O9&]C<R]A<&DO:F%V82]N:6\O8VAA<G-E="]#:&%R<V5T+FAT;6P*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T0VAA<G-E=$EN="@D8W,I"B`@("!["B`@
M("`@("`@+RHJ"B`@("`@("`@("H@1G)O;2!H='1P.B\O=W=W+FEA;F$N;W)G
M+V%S<VEG;FUE;G1S+V-H87)A8W1E<BUS971S"B`@("`@("`@("HO"B`@("`@
M("`@)&-H87)S971);G0@/2!A<G)A>2@G55,M05-#24DG(#T^(#,L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G25-/+3@X-3DM,2<@/3X@-"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=55$8M."<@/3X@,3`V+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)U541BTQ-D)%)R`]/B`Q,#$S+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)U541BTQ-DQ%)R`]/B`Q,#$T
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U541BTQ-B<@/3X@,3`Q
M-2D["@H@("`@("`@(')E='5R;B!I<W-E="@D8VAA<G-E=$EN=%LD8W-=*2`_
M("1C:&%R<V5T26YT6R1C<UT@.B!N=6QL.PH@("`@?0H*?0H*+RHJ"B`J($!P
M86-K86=E(%A-3%]70EA-3`H@*B\*8VQA<W,@6$U,7U="6$U,7TAA<VA486)L
M92!["@H@("`@=F%R("1?:#L*"B`@("!F=6YC=&EO;B!S970H)&LL("1V*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?:%LD:UT@/2`D=CL*("`@('T*"B`@("!F
M=6YC=&EO;B!G970H)&LI"B`@("!["B`@("`@("`@<F5T=7)N(&ES<V5T*"1T
M:&ES+3Y?:%LD:UTI(#\@)'1H:7,M/E]H6R1K72`Z(&YU;&P["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B]61E,`````````````````````````````````````````````````````
M```````````````````````````````````````P,#`W-34@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<S-2`P,38V-C8`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+U9&4R])4T]7<FET97(`````````````````
M````````````````````````````````````````````````````````````
M`#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S
M-S,U(#`R,#4Q-0`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O5D93+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WD`````````````````````````````
M````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`P,#`@,3`U,34T,S,W,S4@,#(T,S0T`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y
M+G!H<``````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P-#<V,2`Q,#4Q-30S,S<S-2`P,C8Q,38`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*"B\J*@H@*B!3=')A=&5G>2!F;W(@=W)I=&EN9R!F:6QE('1O('1E;7!O
M<F%R>2!D:7)E8W1O<GDL('1H96X@8V]P>6EN9R!T;R!61E,N"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/
M=71P=713=')A=&5G>2]C;W!Y+G!H<"QV(#$N,2XX+C0@,C`P-B\P,2\P,2`R
M,3HR.#HT-"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!#
M<F]N;W-Y<RP@3$Q#(#QH='1P.B\O=W=W+F-R;VYO<WES+F-O;2\^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!*87-O;B!-+B!&96QI8V4@/&IF96QI
M8V5`8W)O;F]S>7,N8V]M/@H@*B!`<&%C:V%G92!61E-?25-/"B`J($!S:6YC
M92`@($AO<F1E(#,N,`H@*B\*8VQA<W,@5D937TE33U=R:71E<E]296%L3W5T
M<'5T4W1R871E9WE?8V]P>2!E>'1E;F1S(%9&4U])4T]7<FET97)?4F5A;$]U
M='!U=%-T<F%T96=Y('L*"B`@("!V87(@)%]T96UP1FEL96YA;64@/2!N=6QL
M.PH*("`@("\J*@H@("`@("H@1V5T(&$@<F5A;"!F:6QE;F%M92!T;R!W:&EC
M:"!W92!C86X@=W)I=&4N"B`@("`@*@H@("`@("H@26X@=&AI<R!I;7!L96UE
M;G1A=&EO;BP@=V4@8W)E871E(&%N9"!S=&]R92!A('1E;7!O<F%R>2!F:6QE
M;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4F5A;$9I;&5N86UE*"D*
M("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^7W1E;7!&:6QE;F%M
M92DI('L*"B`@("`@("`@("`@("1T;7!?;&]C871I;VYS(#T@87)R87DH)R]T
M;7`G+"`G+W9A<B]T;7`G+"`G8SI<5U5496UP)RP@)V,Z7'1E;7`G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=C.EQW:6YD;W=S7'1E
M;7`G+"`G8SI<=VEN;G1<=&5M<"<I.PH*("`@("`@("`@("`@+RH@1FER<W0L
M('1R>2!02%`G<R!U<&QO861?=&UP7V1I<B!D:7)E8W1I=F4N("HO"B`@("`@
M("`@("`@("1T;7`@/2!I;FE?9V5T*"=U<&QO861?=&UP7V1I<B<I.PH*("`@
M("`@("`@("`@+RH@3W1H97)W:7-E+"!T<GD@=&\@9&5T97)M:6YE('1H92!4
M35!$25(@96YV:7)O;FUE;G0*("`@("`@("`@("`@("H@=F%R:6%B;&4N("HO
M"B`@("`@("`@("`@(&EF("AE;7!T>2@D=&UP*2D@>PH@("`@("`@("`@("`@
M("`@)'1M<"`](&=E=&5N=B@G5$U01$E2)RD["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("\J($EF('=E('-T:6QL(&-A;FYO="!D971E<FUI;F4@82!V
M86QU92P@=&AE;B!C>6-L92!T:')O=6=H(&$*("`@("`@("`@("`@("H@;&ES
M="!O9B!P<F5S970@<&]S<VEB:6QI=&EE<RX@*B\*("`@("`@("`@("`@=VAI
M;&4@*&5M<'1Y*"1T;7`I("8F(&-O=6YT*"1T;7!?;&]C871I;VYS*2D@>PH@
M("`@("`@("`@("`@("`@)'1M<%]C:&5C:R`](&%R<F%Y7W-H:69T*"1T;7!?
M;&]C871I;VYS*3L*("`@("`@("`@("`@("`@(&EF("A`:7-?9&ER*"1T;7!?
M8VAE8VLI*2!["B`@("`@("`@("`@("`@("`@("`@)'1M<"`]("1T;7!?8VAE
M8VL["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@(&EF("AE;7!T>2@D=&UP*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@
M9&ER96-T;W)Y+B(I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1H
M:7,M/E]T96UP1FEL96YA;64@/2!T96UP;F%M*"1T;7`L("=I<V\G*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^7W1E;7!&:6QE;F%M93L*
M("`@('T*"B`@("!F=6YC=&EO;B!F:6YI<VAE9"@I"B`@("!["B`@("`@("`@
M:68@*&5M<'1Y*"1T:&ES+3Y?=&5M<$9I;&5N86UE*2D@>PH@("`@("`@("`@
M("!R971U<FX["B`@("`@("`@?0H@("`@("`@(&EF("@A9FEL95]E>&ES=',H
M)'1H:7,M/E]T96UP1FEL96YA;64I*2!["B`@("`@("`@("`@(')E='5R;CL*
M("`@("`@("!]"@H@("`@("`@(&EF("AP<F5G7VUA=&-H*"<A7B@N*BDO*%M>
M+UTJ*20A)RP@)'1H:7,M/E]T87)G971&:6QE+"`D;6%T8VAE<RDI('L*("`@
M("`@("`@("`@)&1I<B`]("1M871C:&5S6S%=.PH@("`@("`@("`@("`D9FEL
M92`]("1M871C:&5S6S)=.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1D:7(@/2`G)SL*("`@("`@("`@("`@)&9I;&4@/2`D=&AI<RT^7W1A<F=E
M=$9I;&4["B`@("`@("`@?0H*("`@("`@("`D<F5S(#T@)'1H:7,M/E]T87)G
M97169G,M/G=R:71E*"1D:7(L("1F:6QE+"`D=&AI<RT^7W1E;7!&:6QE;F%M
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1R
M=64I.PH@("`@("`@($!U;FQI;FLH)'1H:7,M/E]T96UP1FEL96YA;64I.PH@
M("`@("`@("1T:&ES+3Y?=&5M<$9I;&5N86UE(#T@;G5L;#L*("`@("`@("!R
M971U<FX@)')E<SL*("`@('T*"GT*"@```````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713
M=')A=&5G>2]D:7)E8W0N<&AP````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C4Q-"`Q,#4Q-30S
M,S<S-2`P,C8T,3``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"B\J*@H@*B!3=')A=&5G>2!F;W(@9&ER96-T;'D@
M=W)I=&EN9R!O=71P=70@9FEL92!T;R!61E,N"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2]D:7)E8W0N<&AP+'8@,2XQ+C@N-2`R,#`V+S`Q+S`Q(#(Q.C(X.C0T
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($-R;VYO<WES
M+"!,3$,@/&AT='`Z+R]W=W<N8W)O;F]S>7,N8V]M+SX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($IA<V]N($TN($9E;&EC92`\:F9E;&EC94!C<F]N
M;W-Y<RYC;VT^"B`J($!P86-K86=E(%9&4U])4T\*("H@0'-I;F-E("`@2&]R
M9&4@,RXP"B`J+PIC;&%S<R!61E-?25-/5W)I=&5R7U)E86Q/=71P=713=')A
M=&5G>5]D:7)E8W0@97AT96YD<R!61E-?25-/5W)I=&5R7U)E86Q/=71P=713
M=')A=&5G>2!["@H@("`@9G5N8W1I;VX@9V5T4F5A;$9I;&5N86UE*"D*("`@
M('L*("`@("`@("`O*B!3;R!W92!S:&]U;&1N)W0@8F4@86-C97-S:6YG(%]G
M971.871I=F50871H*"DN("!)9B!W92!H860@<F5A;`H@("`@("`@("`J(&%C
M8V5S<R!C;VYT<F]L+"!T:&%T('=O=6QD(&)E('!R;W1E8W1E9"!A;F0@=V4G
M9"!B92!A(&9R:65N9"P@87,*("`@("`@("`@*B!T:&%T(&ES('1H92!P;VEN
M="!O9B!T:&ES(&5X8V5R8VES92X@*B\*("`@("`@("`D9FEL96YA;64@/2`D
M=&AI<RT^7W1A<F=E=%9F<RT^7V=E=$YA=&EV95!A=&@H)'1H:7,M/E]T87)G
M971&:6QE*3L*"B`@("`@("`@+RH@36%K92!S=7)E('1H92!P871H('1O('1H
M92!F:6QE(&5X:7-T<RX@*B\*("`@("`@("`D9&ER(#T@9&ER;F%M92@D9FEL
M96YA;64I.PH@("`@("`@('=H:6QE("@A0&ES7V1I<B@D9&ER*2D@>PH@("`@
M("`@("`@("!I9B`H(4!M:V1I<B@D9&ER+"`P-S4U*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")#;W5L
M9"!N;W0@;6MD:7(@7"(E<UPB+B(I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9&ER*2D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)&1I<B`](&1I<FYA;64H)&1I<BD["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&9I;&5N86UE.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&9I;FES:&5D*"D*("`@('L*("`@("`@("`O*B!.;W1H:6YG('1O(&1O
M+B`J+PH@("`@?0H*?0H*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U9&
M4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WD`````````````````````
M`````````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S,U(#`R-#$T,P`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<```````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3$U,38@,3`U,34T,S,W,S4@
M,#(U-S$Q`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"@HO*BH*("H@4W1R871E9WD@9F]R(&-O<'EI;F<@:6YP=70@
M=')E92!O=70@;V8@82!61E,*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`L=B`Q+C$N."XU(#(P,#8O,#$O,#$@,C$Z,C@Z-#0@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@0W)O;F]S>7,L($Q,0R`\:'1T<#HO
M+W=W=RYC<F]N;W-Y<RYC;VTO/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@2F%S;VX@32X@1F5L:6-E(#QJ9F5L:6-E0&-R;VYO<WES+F-O;3X*("H@
M0'!A8VMA9V4@5D937TE33PH@*B!`<VEN8V4@("!(;W)D92`S+C`*("HO"F-L
M87-S(%9&4U])4T]7<FET97)?4F5A;$EN<'5T4W1R871E9WE?8V]P>2!E>'1E
M;F1S(%9&4U])4T]7<FET97)?4F5A;$EN<'5T4W1R871E9WD@>PH*("`@('9A
M<B`D7W1E;7!0871H(#T@;G5L;#L*"B`@("!F=6YC=&EO;B!G971296%L4&%T
M:"@I"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)'1H:7,M/E]T96UP4&%T
M:"DI('L*("`@("`@("`@("`@)'1M<%]L;V-A=&EO;G,@/2!A<G)A>2@G+W1M
M<"<L("<O=F%R+W1M<"<L("=C.EQ7551E;7`G+"`G8SI<=&5M<"<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V,Z7'=I;F1O=W-<=&5M
M<"<L("=C.EQW:6YN=%QT96UP)RD["@H@("`@("`@("`@("`O*B!&:7)S="P@
M=')Y(%!(4"=S('5P;&]A9%]T;7!?9&ER(&1I<F5C=&EV92X@*B\*("`@("`@
M("`@("`@)'1M<"`](&EN:5]G970H)W5P;&]A9%]T;7!?9&ER)RD["@H@("`@
M("`@("`@("`O*B!/=&AE<G=I<V4L('1R>2!T;R!D971E<FUI;F4@=&AE(%1-
M4$1)4B!E;G9I<F]N;65N=`H@("`@("`@("`@("`@*B!V87)I86)L92X@*B\*
M("`@("`@("`@("`@:68@*&5M<'1Y*"1T;7`I*2!["B`@("`@("`@("`@("`@
M("`D=&UP(#T@9V5T96YV*"=435!$25(G*3L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@+RH@268@=V4@<W1I;&P@8V%N;F]T(&1E=&5R;6EN92!A('9A
M;'5E+"!T:&5N(&-Y8VQE('1H<F]U9V@@80H@("`@("`@("`@("`@*B!L:7-T
M(&]F('!R97-E="!P;W-S:6)I;&ET:65S+B`J+PH@("`@("`@("`@("!W:&EL
M92`H96UP='DH)'1M<"D@)B8@8V]U;G0H)'1M<%]L;V-A=&EO;G,I*2!["B`@
M("`@("`@("`@("`@("`D=&UP7V-H96-K(#T@87)R87E?<VAI9G0H)'1M<%]L
M;V-A=&EO;G,I.PH@("`@("`@("`@("`@("`@:68@*$!I<U]D:7(H)'1M<%]C
M:&5C:RDI('L*("`@("`@("`@("`@("`@("`@("`D=&UP(#T@)'1M<%]C:&5C
M:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@:68@*&5M<'1Y*"1T;7`I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BA?*")#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D
M:7)E8W1O<GDN(BDI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AI
M<RT^7W1E;7!0871H(#T@=&5M<&YA;2@D=&UP+"`G:7-O9"<I.PH@("`@("`@
M("`@("!`=6YL:6YK*"1T:&ES+3Y?=&5M<%!A=&@I.PH*("`@("`@("`@("`@
M)')E<R`]("1T:&ES+3Y?8V]P>51O5&5M<%!A=&@H*3L*("`@("`@("`@("`@
M:68@*&ES7V$H)')E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1R97,["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D=&AI<RT^7W1E;7!0871H.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&9I;FES:&5D*"D*("`@('L*("`@("`@("!R971U<FX@5D937TE33U=R
M:71E<E]296%L26YP=713=')A=&5G>5]C;W!Y.CI?<F5M;W9E4F5C=7)S:79E
M*"1T:&ES+3Y?=&5M<%!A=&@I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96UO
M=F5296-U<G-I=F4H)'!A=&@I"B`@("!["B`@("`@("`@)&1H(#T@0&]P96YD
M:7(H)'!A=&@I.PH@("`@("`@(&EF("@A:7-?<F5S;W5R8V4H)&1H*2D@>PH@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H
M(D-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N(BDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A=&@I*3L*
M("`@("`@("!]"B`@("`@("`@=VAI;&4@*"@D96YT(#T@<F5A9&1I<B@D9&@I
M*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@:68@*"1E;G0@/3T@)RXG('Q\
M("1E;G0@/3T@)RXN)RD@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1F=6QL(#T@<W!R:6YT9B@G)7,O
M)7,G+"`D<&%T:"P@)&5N="D["B`@("`@("`@("`@(&EF("AI<U]D:7(H)&9U
M;&PI*2!["B`@("`@("`@("`@("`@("`D<F5S(#T@5D937TE33U=R:71E<E]2
M96%L26YP=713=')A=&5G>5]C;W!Y.CI?<F5M;W9E4F5C=7)S:79E*"1F=6QL
M*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R97,L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@(&EF("@A0'5N;&EN:R@D9G5L;"DI('L*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D-O=6QD(&YO
M="!U;FQI;FL@7"(E<UPB+B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9U;&PI*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!C;&]S
M961I<B@D9&@I.PH*("`@("`@("!I9B`H(4!R;61I<B@D<&%T:"DI('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")#
M;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(I+"`D9G5L;"DI.PH@("`@("`@('T*
M("`@('T*"B`@("!F=6YC=&EO;B!?8V]P>51O5&5M<%!A=&@H*0H@("`@>PH@
M("`@("`@("1D:7)3=&%C:R`](&%R<F%Y*"<G*3L*"B`@("`@("`@=VAI;&4@
M*&-O=6YT*"1D:7)3=&%C:RD@/B`P*2!["B`@("`@("`@("`@("1D:7(@/2!A
M<G)A>5]S:&EF="@D9&ER4W1A8VLI.PH@("`@("`@("`@("!I9B`H96UP='DH
M)&1I<BDI('L*("`@("`@("`@("`@("`@("1T87)G970@/2`D=&AI<RT^7W1E
M;7!0871H.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)'1A<F=E="`]('-P<FEN=&8H)R5S+R5S)RP@)'1H:7,M/E]T96UP4&%T:"P@
M)&1I<BD["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%`;6MD:7(H
M)'1A<F=E="DI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*'-P<FEN=&8H7R@B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB*2P@
M)'1A<F=E="DI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<V]U<F-E
M4&%T:"`]("1T:&ES+3Y?<V]U<F-E4F]O=#L*("`@("`@("`@("`@:68@*"%E
M;7!T>2@D9&ER*2D@>PH@("`@("`@("`@("`@("`@)'-O=7)C95!A=&@@+CT@
M)R\G("X@)&1I<CL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&QI<W0@
M/2`D=&AI<RT^7W-O=7)C959F<RT^;&ES=$9O;&1E<B@D<V]U<F-E4&%T:"P@
M;G5L;"P@=')U92D["B`@("`@("`@("`@(&EF("AI<U]A*"1L:7-T+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&QI<W0["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@(&9O<F5A8V@@*"1L:7-T(&%S("1E
M;G1R>2D@>PH@("`@("`@("`@("`@("`@:68@*"1E;G1R>5LG='EP92==(#T]
M("<J*F1I<B<I('L*("`@("`@("`@("`@("`@("`@("!I9B`H96UP='DH)&1I
M<BDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&1I<E-T86-K6UT@/2`D
M96YT<GE;)VYA;64G73L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D9&ER4W1A8VM;72`]('-P<FEN=&8H
M)R5S+R5S)RP@)&1I<BP@)&5N=')Y6R=N86UE)UTI.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@)&1A=&$@/2`D=&AI<RT^7W-O=7)C959F<RT^<F5A9"@D<V]U
M<F-E4&%T:"P@)&5N=')Y6R=N86UE)UTI.PH@("`@("`@("`@("`@("`@("`@
M(&EF("AI<U]A*"1D871A+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D9&%T83L*("`@("`@("`@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`@("`@("`@("1T87)G971&:6QE(#T@<W!R:6YT
M9B@G)7,O)7,G+"`D=&%R9V5T+"`D96YT<GE;)VYA;64G72D["B`@("`@("`@
M("`@("`@("`@("`@)&9H(#T@0&9O<&5N*"1T87)G971&:6QE+"`G=R<I.PH@
M("`@("`@("`@("`@("`@("`@(&EF("@A:7-?<F5S;W5R8V4H)&9H*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BAS<')I;G1F*%\H(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN
M9RXB*2P@)'1A<F=E=$9I;&4I*3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@:68@*&9W<FET92@D9F@L("1D871A*2`A/2!S
M=')L96XH)&1A=&$I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B17)R;W(@=W)I=&EN9R!<
M(B5S7"(N(BDL("1T87)G971&:6QE*2D["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@(&9C;&]S92@D9F@I.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO9&ER96-T+G!H<```````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,S0V(#$P-3$U
M-#,S-S,U(#`R-C(Q,0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`H*+RHJ"B`J(%-T<F%T96=Y(&9O<B!D:7)E8W1L
M>2!A8V-E<W-I;F<@:6YP=70@=')E92!I;B!A("=F:6QE)R!61E,*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO9&ER96-T+G!H<"QV(#$N,2XX+C0@,C`P-B\P,2\P
M,2`R,3HR.#HT-"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P
M-B!#<F]N;W-Y<RP@3$Q#(#QH='1P.B\O=W=W+F-R;VYO<WES+F-O;2\^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*87-O;B!-+B!&96QI8V4@/&IF
M96QI8V5`8W)O;F]S>7,N8V]M/@H@*B!`<&%C:V%G92!61E-?25-/"B`J($!S
M:6YC92`@($AO<F1E(#,N,`H@*B\*8VQA<W,@5D937TE33U=R:71E<E]296%L
M26YP=713=')A=&5G>5]D:7)E8W0@97AT96YD<R!61E-?25-/5W)I=&5R7U)E
M86Q);G!U=%-T<F%T96=Y('L*"B`@("!F=6YC=&EO;B!G971296%L4&%T:"@I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<V]U<F-E5F9S+3Y?9V5T
M3F%T:79E4&%T:"@D=&AI<RT^7W-O=7)C95)O;W0I.PH@("`@?0H*("`@(&9U
M;F-T:6]N(&9I;FES:&5D*"D*("`@('L*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U9&4R])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+G!H<```````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`U,S4U
M(#$P-3$U-#,S-S,U(#`R-3$T-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`H*+RHJ"B`J($5N8V%P<W5L871E('-T
M<F%T96=I97,@9F]R(&%B:6QI='D@=&\@=W)I=&4@;W5T<'5T('1O(')E86P@
M9FEL92X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<"QV(#$N,2XX+C<@,C`P
M-B\P,2\P,2`R,3HR.#HT,R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P
M,#0M,C`P-B!#<F]N;W-Y<RP@3$Q#(#QH='1P.B\O=W=W+F-R;VYO<WES+F-O
M;2\^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*87-O;B!-+B!&96QI
M8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M/@H@*B!`<&%C:V%G92!61E-?25-/
M"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B\*8VQA<W,@5D937TE33U=R:71E
M<E]296%L3W5T<'5T4W1R871E9WD@>PH*("`@("\J*@H@("`@("H@5&AE(%9&
M4R!T;R!W:&EC:"!W92!W:6QL('=R:71E('1H92!F:6QE+@H@("`@("H*("`@
M("`J($!V87(@5D93"B`@("`@*B\*("`@('9A<B`D7W1A<F=E=%9F<SL*"B`@
M("`O*BH*("`@("`J(%=H97)E('1O('-T;W)E('1H92!F:6QE(&EN('1H92!6
M1E,N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?=&%R9V5T1FEL93L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R"B`@
M("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="`F)'1A<F=E=%9F<R`@("`@("`@
M5&AE(%9&4R!T;R!W:&EC:"!W92!W:6QL('=R:71E('1H90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9FEL92X*("`@("`J($!P
M87)A;2!S=')I;F<@)'1A<F=E=$9I;&4@("`@("`@(%1H92!P871H(&%N9"!N
M86UE(&]F(&9I;&4@=&\@=W)I=&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%9&
M4U])4T]7<FET97)?4F5A;$]U='!U=%-T<F%T96=Y*"8D=&%R9V5T5F9S+"`D
M=&%R9V5T1FEL92D*("`@('L*("`@("`@("`D=&AI<RT^7W1A<F=E=%9F<R`]
M("8D=&%R9V5T5F9S.PH@("`@("`@("1T:&ES+3Y?=&%R9V5T1FEL92`]("1T
M87)G971&:6QE.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5L96-T(&%N9"!C
M<F5A=&4@82!C;VYC<F5T92!S=')A=&5G>2!F;W(@=7-I;F<@82!R96%L(&]U
M='!U="!F:6QE+@H@("`@("H*("`@("`J($!P87)A;2!O8FIE8W0@)B1T87)G
M97169G,@("`@("`@(%1H92!61E,@=&\@=VAI8V@@=V4@=VEL;"!W<FET92!T
M:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E
M<W5L="X*("`@("`J($!P87)A;2!S=')I;F<@)'1A<F=E=$9I;&4@("`@("`@
M(%1H92!P871H(&%N9"!F:6QE;F%M92!O9B!T:&4@=&%R9V5T"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F:6QE('=I=&AI;B!T
M:&4@5D93+@H@("`@("H@0')E='5R;B!O8FIE8W0@("!!(&-O;F-R971E(&]U
M='!U="!S=')A=&5G>2!O8FIE8W0@;W(@4$5!4E]%<G)O<B!O;@H@("`@("H@
M("`@("`@("`@("`@("`@("!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B`F9F%C=&]R>2@F)'1A<F=E=%9F<RP@)'1A<F=E=$9I;&4I"B`@("!["B`@
M("`@("`@:68@*'-T<G1O;&]W97(H9V5T7V-L87-S*"1T87)G97169G,I*2`]
M/2`G=F9S7V9I;&4G*2!["B`@("`@("`@("`@("1M971H;V0@/2`G9&ER96-T
M)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;65T:&]D(#T@)V-O
M<'DG.PH@("`@("`@('T*"B`@("`@("`@:6YC;'5D95]O;F-E(&1I<FYA;64H
M7U]&24Q%7U\I("X@)R]296%L3W5T<'5T4W1R871E9WDO)R`N("1M971H;V0@
M+@H@("`@("`@("`@("`@("`@("`@("`@)RYP:'`G.PH@("`@("`@("1C;&%S
M<R`]("=61E-?25-/5W)I=&5R7U)E86Q/=71P=713=')A=&5G>5\G("X@)&UE
M=&AO9#L*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B
M0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E<UPB+B(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1M971H;V0I*3L*
M("`@("`@("!]"@H@("`@("`@("1S=')A=&5G>2`]("9N97<@)&-L87-S*"1T
M87)G97169G,L("1T87)G971&:6QE*3L*("`@("`@("!R971U<FX@)'-T<F%T
M96=Y.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T(&$@<F5A;"!F:6QE<WES
M=&5M(&9I;&5N86UE('=E(&-A;B!W<FET92!T;RX*("`@("`J"B`@("`@*B!`
M86)S=')A8W0*("`@("`J($!R971U<FX@<W1R:6YG("`@5&AE(&9I;&5N86UE
M(&]R(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T4F5A;$9I;&5N86UE*"D*("`@('L*("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BA?*").;W0@:6UP;&5M96YT960N(BDI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@26YD:6-A=&4@=&AA="!W92=R92!D;VYE('=R:71I
M;F<@=&\@=&AE(')E86P@9FEL92X*("`@("`J"B`@("`@*B!`86)S=')A8W0*
M("`@("`J($!R971U<FX@;6EX960@("`@3G5L;"!O<B!014%27T5R<F]R(&]N
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&9I;FES:&5D*"D*("`@
M('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;W0@:6UP
M;&5M96YT960N(BDI.PH@("`@?0H*?0H*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O5D93+TE33U=R:71E<B]M:VES;V9S+G!H<```````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#0W,#<@,3`U,34T,S,W,S4@,#(R
M-S<P`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"@HO*BH*("H@1')I=F5R(&9O<B!U<VEN9R!M:VES;V9S(&9O<B!C
M<F5A=&EN9R!)4T\@:6UA9V5S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<"QV(#$N,2XX+C4@
M,C`P-B\P,2\P,2`R,3HR.#HT,R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#0M,C`P-B!#<F]N;W-Y<RP@3$Q#(#QH='1P.B\O=W=W+F-R;VYO<WES
M+F-O;2\^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*87-O;B!-+B!&
M96QI8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M/@H@*B!`<&%C:V%G92!61E-?
M25-/"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B\*8VQA<W,@5D937TE33U=R
M:71E<E]M:VES;V9S(&5X=&5N9',@5D937TE33U=R:71E<B!["@H@("`@9G5N
M8W1I;VX@<')O8V5S<R@I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E(&1I
M<FYA;64H7U]&24Q%7U\I("X@)R]296%L26YP=713=')A=&5G>2YP:'`G.PH@
M("`@("`@("1I;G!U=%-T<F%T96=Y(#T@)E9&4U])4T]7<FET97)?4F5A;$EN
M<'5T4W1R871E9WDZ.F9A8W1O<GDH)'1H:7,M/E]S;W5R8V569G,L("1T:&ES
M+3Y?<&%R86US6R=S;W5R8V52;V]T)UTI.PH@("`@("`@(&EF("AI<U]A*"1I
M;G!U=%-T<F%T96=Y+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D:6YP=713=')A=&5G>3L*("`@("`@("!]"@H@("`@("`@(')E<75I
M<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O4F5A;$]U='!U=%-T<F%T
M96=Y+G!H<"<["B`@("`@("`@)&]U='!U=%-T<F%T96=Y(#T@)E9&4U])4T]7
M<FET97)?4F5A;$]U='!U=%-T<F%T96=Y.CIF86-T;W)Y*"1T:&ES+3Y?=&%R
M9V5T5F9S+"`D=&AI<RT^7W!A<F%M<ULG=&%R9V5T1FEL92==*3L*("`@("`@
M("!I9B`H:7-?82@D;W5T<'5T4W1R871E9WDL("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1O=71P=713=')A=&5G>3L*("`@("`@("!]
M"@H@("`@("`@("1C;60@/2!S<')I;G1F*"=M:VES;V9S("UQ=6EE="`M<B`M
M2B`M;R`E<R`E<R`^+V1E=B]N=6QL)RP*("`@("`@("`@("`@("`@("`@("`@
M("!E<V-A<&5S:&5L;&%R9R@D;W5T<'5T4W1R871E9WDM/F=E=%)E86Q&:6QE
M;F%M92@I*2P*("`@("`@("`@("`@("`@("`@("`@("!E<V-A<&5S:&5L;&%R
M9R@D:6YP=713=')A=&5G>2T^9V5T4F5A;%!A=&@H*2DI.PH@("`@("`@("1R
M97,@/2!S>7-T96TH)&-M9"P@)&5C*3L*"B`@("`@("`@+RH@0V]U;&0@8F4@
M82!L;W0@;V8@<W!A8V4@=7-E9"X@($=I=F4@8F]T:"!A(&-H86YC92!T;R!C
M;&5A;B!U<"!E=F5N"B`@("`@("`@("H@:68@;VYE(&5R<F]R<R!O=70N("HO
M"B`@("`@("`@)&9I;E)E<S$@/2`D:6YP=713=')A=&5G>2T^9FEN:7-H960H
M*3L*("`@("`@("`D9FEN4F5S,B`]("1O=71P=713=')A=&5G>2T^9FEN:7-H
M960H*3L*("`@("`@("!I9B`H:7-?82@D9FEN4F5S,2P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&9I;E)E<S$["B`@("`@("`@?0H@
M("`@("`@(&EF("AI<U]A*"1F:6Y297,R+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D9FEN4F5S,CL*("`@("`@("!]"@H@("`@("`@
M(&EF("@D<F5S(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB*2D[
M"B`@("`@("`@?0H@("`@("`@(&EF("@D96,@(3T@,"D@>PH@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(FUK:7-O9G,@
M97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(I+"`D96,I*3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F4@:68@=V4@
M8V%N('5S92!T:&ES(&1R:79E<B!T;R!M86ME(&EM86=E<PH@("`@("H*("`@
M("`J($!S=&%T:6,*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H
M971H97(@=V4@8V%N('5S92!T:&ES('-T<F%T96=Y(&9O<B!M86MI;F<@25-/
M(&EM86=E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<W1R871E9WE!=F%I;&%B
M;&4H*0H@("`@>PH@("`@("`@("\J($-H96-K(&EF('=E(&-A;B!F:6YD(&%N
M9"!E>&5C=71E('1H92!@;6MI<V]F<R<@8V]M;6%N9"X@*B\*("`@("`@("`D
M<F5S(#T@<WES=&5M*")M:VES;V9S("UH96QP(#XO9&5V+VYU;&P@,CXF,2(L
M("1E8RD["B`@("`@("`@:68@*"1R97,@/3T](&9A;'-E*2!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@:68@*"1E8R`A
M/2`P*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@I]"@H`````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O5D93+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2YP:'``````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#0V-S<@,3`U
M,34T,S,W,S4@,#(T-S4Q`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"@HO*BH*("H@16YC87!S=6QA=&4@<W1R871E
M9VEE<R!F;W(@9V5T=&EN9R!A(')E86PL(&QO8V%L(&9I;&5S>7-T96T@<W1R
M=6-T=7)E(&9R;VT*("H@82!61E,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H
M<"QV(#$N,2XX+C<@,C`P-B\P,2\P,2`R,3HR.#HT,R!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!#<F]N;W-Y<RP@3$Q#(#QH='1P.B\O
M=W=W+F-R;VYO<WES+F-O;2\^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!*87-O;B!-+B!&96QI8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M/@H@*B!`
M<&%C:V%G92!61E-?25-/"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B\*8VQA
M<W,@5D937TE33U=R:71E<E]296%L26YP=713=')A=&5G>2!["@H@("`@+RHJ
M"B`@("`@*B!!(')E9F5R96YC92!T;R!T:&4@<V]U<F-E(%9&4R!W92!W86YT
M('1O(')E860N"B`@("`@*@H@("`@("H@0'9A<B!61E,*("`@("`J+PH@("`@
M=F%R("1?<V]U<F-E5F9S(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%1H92!R
M;V]T(&1I<F5C=&]R>2!W:71H:6X@=&AE('-O=7)C92!61E,*("`@("`J"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]S;W5R8V52;V]T
M.PH*("`@(&9U;F-T:6]N(%9&4U])4T]7<FET97)?4F5A;$EN<'5T4W1R871E
M9WDH)B1S;W5R8V569G,L("1S;W5R8V52;V]T*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?<V]U<F-E5F9S(#T@)B1S;W5R8V569G,["B`@("`@("`@)'1H:7,M
M/E]S;W5R8V52;V]T(#T@)B1S;W5R8V52;V]T.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1V5T(&$@<F5A;"!P871H('1O('1H92!I;G!U="!T<F5E+@H@("`@
M("H*("`@("`J($!A8G-T<F%C=`H@("`@("H@0')E='5R;B!M:7AE9"`@("!!
M('-T<FEN9R!W:71H('1H92!R96%L('!A=&@L(&]R(%!%05)?17)R;W(@;VX@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4F5A;%!A=&@H*0H@
M("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DYO="!I
M;7!L96UE;G1E9"XB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!);F1I8V%T
M92!W92!A<F4@9FEN:7-H960@=VET:"!T:&ES(&EN<'5T('-T<F%T96=Y+@H@
M("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H@0')E='5R;B!M:7AE9"`@
M("`@("`@3G5L;"!O<B!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&9I;FES:&5D*"D*("`@('L*("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BA?*").;W0@:6UP;&5M96YT960N(BDI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1&5C:61E('=H:6-H('-T<F%T96=Y('1O('5S
M92!T;R!G970@82!R96%L($93(&%N9"!C<F5A=&4@:70N"B`@("`@*@H@("`@
M("H@0'-T871I8PH@("`@("H*("`@("`J($!P87)A;2!O8FIE8W0@)B1S;W5R
M8V569G,@("`@("`@(%1H92!61E,@=V4@=V%N="!T;R!R96%D(&9R;VTN"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1S;W5R8V52;V]T("`@("`@("!4:&4@<F]O
M="!D:7)E8W1O<GD@:6X@=&AA="!61E,N"B`@("`@*B!`<F5T=7)N(&]B:F5C
M="`@($$@8V]N8W)E=&4@<W1R871E9WD@;W(@4$5!4E]%<G)O<B!I9B!N;R!S
M=')A=&5G>2!I<PH@("`@("H@("`@("`@("`@("`@("`@("!A=F%I;&%B;&4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&9A8W1O<GDH)B1S;W5R8V569G,L("1S
M;W5R8V52;V]T*0H@("`@>PH@("`@("`@(&EF("AS=')T;VQO=V5R*&=E=%]C
M;&%S<R@D<V]U<F-E5F9S*2D@/3T@)W9F<U]F:6QE)RD@>PH@("`@("`@("`@
M("`D;65T:&]D(#T@)V1I<F5C="<["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&UE=&AO9"`]("=C;W!Y)SL*("`@("`@("!]"@H@("`@("`@($!I
M;F-L=61E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+U)E86Q);G!U=%-T
M<F%T96=Y+R<@+B`D;65T:&]D("X*("`@("`@("`@("`@("`@("`@("`@("<N
M<&AP)SL*("`@("`@("`D8VQA<W,@/2`G5D937TE33U=R:71E<E]296%L26YP
M=713=')A=&5G>5\G("X@)&UE=&AO9#L*("`@("`@("!I9B`H(6-L87-S7V5X
M:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*'-P<FEN=&8H7R@B0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E
M<UPB+B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1M971H;V0I*3L*("`@("`@("!]"@H@("`@("`@("1S=')A=&5G
M>2`]("9N97<@)&-L87-S*"1S;W5R8V569G,L("1S;W5R8V52;V]T*3L*("`@
M("`@("!R971U<FX@)'-T<F%T96=Y.PH@("`@?0H*?0H*````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O5D93+TE33U=R
M:71E<BYP:'``````````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#8U,S<@,3`U,34T,S,W,S4@,#(Q,S(P`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@
M)U!%05(N<&AP)SL*"B\J*@H@*B!61E,@05!)(&9O<B!A8G-T<F%C=&5D(&-R
M96%T:6]N(&]F($E33R`H0T0M4D]-*2!F:6QE<WES=&5M<RX*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP+'8@
M,2XQ+C@N-R`R,#`V+S`Q+S`Q(#(Q.C(X.C0S(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P-"TR,#`V($-R;VYO<WES+"!,3$,@/&AT='`Z+R]W=W<N
M8W)O;F]S>7,N8V]M+SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA
M<V]N($TN($9E;&EC92`\:F9E;&EC94!C<F]N;W-Y<RYC;VT^"B`J($!P86-K
M86=E(%9&4U])4T\*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J+PIC;&%S<R!6
M1E-?25-/5W)I=&5R('L*"B`@("`O*BH*("`@("`J($$@5D93(&]B:F5C="!U
M<V5D(&9O<B!R96%D:6YG('1H92!S;W5R8V4@9FEL97,*("`@("`J"B`@("`@
M*B!`=F%R(%9&4PH@("`@("HO"B`@("!V87(@)%]S;W5R8V569G,@/2!N=6QL
M.PH*("`@("\J*@H@("`@("H@02!61E,@;V)J96-T('5S960@9F]R('=R:71I
M;F<@=&AE($E33R!I;6%G90H@("`@("H*("`@("`J($!V87(@5D93"B`@("`@
M*B\*("`@('9A<B`D7W1A<F=E=%9F<R`](&YU;&P["@H@("`@+RHJ"B`@("`@
M*B!(87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@
M("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<&%R86US
M(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!N97<@
M5D937TE33U=R:71E<B!O8FIE8W0*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@<&%R86UE=&5R<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@5D937TE33U=R:71E<B@F)'-O=7)C959F<RP@
M)B1T87)G97169G,L("1P87)A;7,I"B`@("!["B`@("`@("`@)'1H:7,M/E]S
M;W5R8V569G,@/2`F)'-O=7)C959F<SL*("`@("`@("`D=&AI<RT^7W1A<F=E
M=%9F<R`]("8D=&%R9V5T5F9S.PH@("`@("`@("1T:&ES+3Y?<&%R86US(#T@
M)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T92!T:&4@25-/
M(&EM86=E"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@3G5L;"!O<B!014%27T5R<F]R(&]N(&9A:6QU<F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N('!R;V-E<W,H*0H@("`@>PH@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DYO="!I;7!L96UE;G1E9"XB
M*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T('1O(&-R96%T92!A
M(&-O;F-R971E(%9&4U])4T]7<FET97(@<W5B8VQA<W,N"B`@("`@*@H@("`@
M("H@5&AI<R!M971H;V0@=7-E<R!I=',@<&%R86UE=&5R<R!A;F0@8VAE8VMS
M('1H92!S>7-T96T@=&\@9&5T97)M:6YE"B`@("`@*B!T:&4@;6]S="!A<'!R
M;W!R:6%T92!S=6)C;&%S<R!T;R!U<V4@9F]R(&)U:6QD:6YG($E33R!I;6%G
M97,N("!)9@H@("`@("H@;F]N92!I<R!F;W5N9"P@86X@97)R;W(@:7,@<F%I
M<V5D+@H@("`@("H*("`@("`J($!P87)A;2!O8FIE8W0@)B1S;W5R8V569G,@
M("`@("!2969E<F5N8V4@=&\@=&AE(%9&4R!O8FIE8W0@9G)O;2!W:&EC:`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H92!F:6QE
M<R!W:6QL(&)E(')E860@=&\@8W)E871E('1H90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@($E33R!I;6%G92X*("`@("`J($!P87)A
M;2!O8FIE8W0@)B1T87)G97169G,@("`@("!2969E<F5N8V4@=&\@=&AE(%9&
M4R!O8FIE8W0@=&\@=VAI8V@@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@25-/(&EM86=E('=I;&P@8F4@=W)I='1E;BX*("`@
M("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@("`@("`@("!(87-H(&]F('!A
M<F%M971E<G,@9F]R(&-R96%T:6YG('1H90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EM86=E.@H@("`@("H@("`@("`@("`@("`@
M("=S;W5R8V52;V]T)R`]/B`@("`@02!D:7)E8W1O<GD@:6X@=&AE('-O=7)C
M92!61E,@9F]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!F:6QE<R!T;R!B92!R96%D(&9R;VT@9F]R('1H92!I;6%G92X*("`@
M("`J("`@("`@("`@("`@("`G=&%R9V5T1FEL92<@/3X@("`@(%!A=&@@86YD
M(&9I;&5N86UE(&]F('1H92!)4T\@9FEL92!T;PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@=W)I=&4@:6YT;R!T:&4@=&%R9V5T
M(%9&4RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@("`@("`@("`@
M("`@("`@02!N97=L>2!C<F5A=&5D(&-O;F-R971E(%9&4U])4T]7<FET97(*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S=6)C;&%S
M<RP@;W(@82!014%27T5R<F]R(&]N(&%N(&5R<F]R+@H@("`@("HO"B`@("!F
M=6YC=&EO;B`F9F%C=&]R>2@F)'-O=7)C959F<RP@)B1T87)G97169G,L("1P
M87)A;7,I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1P87)A;7-;)W1A<F=E
M=$9I;&4G72DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R
M86UE=&5R+B(I*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1P87)A
M;7-;)W-O=7)C95)O;W0G72DI('L*("`@("`@("`@("`@)'!A<F%M<ULG<V]U
M<F-E4F]O="==(#T@)R\G.PH@("`@("`@('T*"B`@("`@("`@+RH@4FEG:'0@
M;F]W+"!M:VES;V9S(&ES('1H92!O;FQY(&1R:79E<BP@8G5T(&UA:V4@<W5R
M92!W92!C86X*("`@("`@("`@*B!S=7!P;W)T(&ET+B`J+PH@("`@("`@(')E
M<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O25-/5W)I=&5R+VUK
M:7-O9G,N<&AP)SL*("`@("`@("!I9B`H5D937TE33U=R:71E<E]M:VES;V9S
M.CIS=')A=&5G>4%V86EL86)L92@I*2!["B`@("`@("`@("`@("1I<V]W<FET
M97(@/2`F;F5W(%9&4U])4T]7<FET97)?;6MI<V]F<R@D<V]U<F-E5F9S+"`D
M=&%R9V5T5F9S+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'!A<F%M<RD["B`@("`@("`@("`@(')E='5R
M;B`D:7-O=W)I=&5R.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H7R@B3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI
M;F<@25-/(&EM86=E<RXB*2D["B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U9&4R]/8FIE
M8W0N<&AP````````````````````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#(Q,C(U(#$P-3$U-#,S-S,U(#`R,#8V-@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E
M(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B]61E,N<&AP)SL*"B\J*@H@*B!!
M('=R87!P97(@9F]R('1H92!61E,@8VQA<W,@=&\@<F5T=7)N(&]B:F5C=',L
M(&EN<W1E860@;V8@87)R87ES+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]6
M1E,O5D93+T]B:F5C="YP:'`L=B`Q+C$R+C$P+C$Q(#(P,#8O,#4O,S$@,#0Z
M-3`Z,#(@<VQU<V%R>B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V
M($IO;B!7;V]D(#QJ;VY`:F5L;'EB;V(N8V\N=6L^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B!`875T:&]R("!*;VX@5V]O9"`\:F]N0&IE;&QY8F]B+F-O+G5K/@H@
M*B!`<&%C:V%G92!61E,*("HO"F-L87-S(%9&4U]/8FIE8W0@>PH*("`@("\J
M*@H@("`@("H@5&AE(&%C='5A;"!V9G,@=&AA="!D;V5S('1H92!W;W)K"B`@
M("`@*@H@("`@("H@0'9A<B!61E,*("`@("`J+PH@("`@=F%R("1?=F9S.PH*
M("`@("\J*@H@("`@("H@5&AE(&-U<G)E;G0@<&%T:"!T:&%T(&AA<R!B965N
M('!A<W-E9"!T;R!L:7-T1F]L9&5R+"!I9B!T:&ES"B`@("`@*B!C:&%N9V5S
M+"!T:&4@;&ES="!W:6QL(&)E(')E8G5I;'0N"B`@("`@*@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?8W5R<F5N=%!A=&@["@H@("`@
M+RHJ"B`@("`@*B!4:&4@<F5T=7)N('9A;'5E(&9R;VT@82!S=&%N9&%R9"!6
M1E,@;&ES=$9O;&1E<B!C86QL+"!T;PH@("`@("H@8F4@<F5A9"!W:71H('1H
M92!/8FIE8W0@;&ES=$9O;&1E<BX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*B\*("`@('9A<B`D7V9O;&1E<DQI<W0["@H@("`@+RHJ"B`@("`@
M*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!)9B!Y;W4@<&%S<R!I;B!A
M;B!E>&ES=&EN9R!61E,@;V)J96-T+"!I="!W:6QL(&)E('5S960@87,@=&AE
M(%9&4PH@("`@("H@;V)J96-T(&9O<B!T:&ES(&]B:F5C="X*("`@("`J"B`@
M("`@*B!`<&%R86T@5D93("8D=F9S("!4:&4@5D93(&]B:F5C="!T;R!W<F%P
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!61E-?3V)J96-T*"8D=F9S*0H@("`@
M>PH@("`@("`@(&EF("AI<W-E="@D=F9S*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^7W9F<R`]("1V9G,["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E=&4@5D937T]B:F5C="!I
M;G-T86YC92!B87-E9"!O;B`D9')I=F5R+@H@("`@("H*("`@("`J($!P87)A
M;2!M:7AE9"`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!61E,@<W5B
M8VQA<W,@=&\@<F5T=7)N+B!)9@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("1D<FEV97(@:7,@86X@87)R87D@=&AE;B!W92!W:6QL(&QO;VL@:6X*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`D9')I=F5R6S!=+VQI8B]6
M1E,O(&9O<B!T:&4@<W5B8VQA<W,*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!I;7!L96UE;G1A=&EO;B!N86UE9"`D9')I=F5R6S%=+G!H<"X*("`@
M("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!A
M;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P87)A;65T97)S(&$@<W5B8VQA
M<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(%9&4U]/8FIE
M8W0@(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R971E(%9&4U]/8FIE8W0@:6YS
M=&%N8V4L(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(&9A;'-E(&]N
M(&%N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D9')I
M=F5R+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=F9S(#T@
M)E9&4SHZ9F%C=&]R>2@D9')I=F5R+"`D<&%R86US(#T@87)R87DH*2D["B`@
M("`@("`@)'9F<V]B:F5C="`]("9N97<@5D937T]B:F5C="@D=F9S*3L*("`@
M("`@("!R971U<FX@)'9F<V]B:F5C=#L*("`@('T*"B`@("`O*BH*("`@("`J
M($%T=&5M<'1S('1O(')E='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R971E
M(%9&4R!I;G-T86YC90H@("`@("H@8F%S960@;VX@)&1R:79E<BX@270@=VEL
M;"!O;FQY(&-R96%T92!A(&YE=R!I;G-T86YC92!I9B!N;PH@("`@("H@5D93
M(&EN<W1A;F-E('=I=&@@=&AE('-A;64@<&%R86UE=&5R<R!C=7)R96YT;'D@
M97AI<W1S+@H@("`@("H*("`@("`J(%1H:7,@<VAO=6QD(&)E('5S960@:68@
M;75L=&EP;&4@='EP97,@;V8@9FEL92!B86-K96YD<R`H86YD+`H@("`@("H@
M=&AU<RP@;75L=&EP;&4@5D93(&EN<W1A;F-E<RD@87)E(')E<75I<F5D+@H@
M("`@("H*("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH@
M)'9A<B`]("961E,Z.G-I;F=L971O;B@I"B`@("`@*@H@("`@("H@0'!A<F%M
M(&UI>&5D("1D<FEV97(@(%1H92!T>7!E(&]F(&-O;F-R971E(%9&4R!S=6)C
M;&%S<R!T;R!R971U<FXN($EF"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@)&1R:79E<B!I<R!A;B!A<G)A>2!T:&5N('=E('=I;&P@;&]O:R!I;@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("1D<FEV97);,%TO;&EB+U9&
M4R\@9F]R('1H92!S=6)C;&%S<PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@(&EM<&QE;65N=&%T:6]N(&YA;65D("1D<FEV97);,5TN<&AP+@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N
M>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@;W(*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!C;VYN96-T:6]N('!A<F%M971E<G,@82!S=6)C;&%S
M<R!M:6=H="!N965D+@H@("`@("H*("`@("`J($!R971U<FX@5D937T]B:F5C
M="`@5&AE(&-O;F-R971E(%9&4U]/8FIE8W0@<F5F97)E;F-E+"!O<B!F86QS
M92!O;@H@("`@("H@("`@("`@("`@("`@("`@("`@("!E<G)O<BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@D9')I=F5R+"`D<&%R86US(#T@
M87)R87DH*2D*("`@('L*("`@("`@("`D=F9S(#T@)E9&4SHZ<VEN9VQE=&]N
M*"1D<FEV97(L("1P87)A;7,@/2!A<G)A>2@I*3L*("`@("`@("`D=F9S;V)J
M96-T(#T@)FYE=R!61E-?3V)J96-T*"1V9G,I.PH@("`@("`@(')E='5R;B`D
M=F9S;V)J96-T.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VL@=&AE(&-R
M961E;G1I86QS('1H870@=V4@:&%V92!T;R!S964@:68@=&AE<F4@:7,@82!V
M86QI9"!L;V=I;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E
M(&]N('-U8V-E<W,L(%!%05)?17)R;W(@9&5S8W)I8FEN9R!T:&4@<')O8FQE
M;0H@("`@("H@("`@("`@("`@("`@("`@:68@=&AE(&-R961E;G1I86QS(&%R
M92!I;G9A;&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!C:&5C:T-R961E;G1I
M86QS*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]V9G,M/F-H96-K
M0W)E9&5N=&EA;',H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!C;VYF
M:6=U<F%T:6]N('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1P87)A;7,@($%N(&%S<V]C:6%T:79E(&%R<F%Y(&]F('!A<F%M971E
M<B!N86UE+W9A;'5E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<&%I
M<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%!A<F%M<R@D<&%R86US(#T@
M87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^7W9F<RT^<V5T4&%R86US
M*"1P87)A;7,I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F4@82!F
M:6QE(&9R;VT@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1P871H("!4:&4@<&%T:&YA;64@=&\@=&AE(&9I;&4N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!F:6QE(&1A=&$N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(')E860H)'!A=&@I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?=F9S+3YR96%D*&1I<FYA;64H)'!A=&@I+"!B87-E;F%M92@D<&%T
M:"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@4W1O<F4@82!F:6QE(&EN('1H
M92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@
M("`@(%1H92!P871H('1O('-T;W)E('1H92!F:6QE(&EN+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=&UP1FEL92`@("`@(%1H92!T96UP;W)A<GD@9FEL92!C
M;VYT86EN:6YG('1H92!D871A('1O(&)E"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@<W1O<F5D+@H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)&%U=&]C<F5A=&4@($%U=&]M871I8V%L;'D@8W)E871E(&1I<F5C=&]R:65S
M/PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S
M<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('=R:71E*"1P871H+"`D=&UP1FEL92P@)&%U=&]C<F5A
M=&4@/2!F86QS92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]V9G,M
M/G=R:71E*&1I<FYA;64H)'!A=&@I+"!B87-E;F%M92@D<&%T:"DL("1T;7!&
M:6QE+"`D875T;V-R96%T92`](&9A;'-E*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%-T;W)E(&$@9FEL92!I;B!T:&4@5D93(&9R;VT@<F%W(&1A=&$N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@("`@(%1H92!P
M871H('1O('-T;W)E('1H92!F:6QE(&EN+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9&%T82`@("`@("`@(%1H92!F:6QE(&1A=&$N"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`D875T;V-R96%T92`@075T;VUA=&EC86QL>2!C<F5A=&4@9&ER
M96-T;W)I97,_"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O
M;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@=W)I=&5$871A*"1P871H+"`D9&%T82P@
M)&%U=&]C<F5A=&4@/2!F86QS92D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]V9G,M/G=R:71E1&%T82AD:7)N86UE*"1P871H*2P@8F%S96YA;64H
M)'!A=&@I+"`D9&%T82P@)&%U=&]C<F5A=&4@/2!F86QS92D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!$96QE=&4@82!F:6QE(&9R;VT@=&AE(%9&4RX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!T;R!S
M=&]R92!T:&4@9FEL92!I;BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@
M(%1H92!F:6QE;F%M92!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@
M;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E1FEL92@D
M<&%T:"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]V9G,M/F1E;&5T
M949I;&4H9&ER;F%M92@D<&%T:"DL(&)A<V5N86UE*"1P871H*2D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!296YA;64@82!F:6QE(&EN('1H92!61E,N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;VQD<&%T:"`@5&AE(&]L9"!P
M871H('1O('1H92!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;VQD;F%M
M92`@5&AE(&]L9"!F:6QE;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@)&YE
M=W!A=&@@(%1H92!N97<@<&%T:"!O9B!T:&4@9FEL92X*("`@("`J($!P87)A
M;2!S=')I;F<@)&YE=VYA;64@(%1H92!N97<@9FEL96YA;64N"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!
M4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F5N86UE*"1O;&1P871H+"`D;F5W<&%T:"D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]V9G,M/G)E;F%M92AD:7)N86UE*"1O;&1P871H*2P@
M8F%S96YA;64H)&]L9'!A=&@I+"!D:7)N86UE*"1N97=P871H*2P@8F%S96YA
M;64H)&YE=W!A=&@I*3L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T92!A
M(&9O;&1E<B!I;B!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'!A=&@@(%1H92!P871H('1O('1H92!F;VQD97(N"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%
M<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M8W)E871E1F]L9&5R*"1P871H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^7W9F<RT^8W)E871E1F]L9&5R*&1I<FYA;64H)'!A=&@I*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($1E;&5T97,@82!F;VQD97(@9G)O;2!T:&4@5D93
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@5&AE('!A=&@@
M;V8@=&AE(&9O;&1E<B!T;R!D96QE=&4N"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE
M8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E1F]L
M9&5R*"1P871H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W9F<RT^
M9&5L971E1F]L9&5R*&1I<FYA;64H)'!A=&@I*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@82!61E-?3&ES=$ET96T@;V)J96-T(&EF('1H92!F
M;VQD97(@8V%N"B`@("`@*B!B92!R96%D+"!O<B!A(%!%05)?17)R;W(@:68@
M:70@8V%N)W0@8F4N(%)E='5R;G,@9F%L<V4@;VYC90H@("`@("H@=&AE(&9O
M;&1E<B!H87,@8F5E;B!C;VUP;&5T96QY(')E860N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@;V8@=&AE(&1I<F5T;W)Y
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@($9I;&4@;&ES="`H87)R
M87DI(&]N('-U8V-E<W,L(&$@4$5!4E]%<G)O<@H@("`@("H@("`@("`@("`@
M("`@("`@;V)J96-T(&]N(&9A:6QU<F4L(&]R(&9A;'-E(&EF('1H92!F;VQD
M97(@:7,*("`@("`J("`@("`@("`@("`@("`@(&-O;7!L971E;'D@<F5A9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=$9O;&1E<B@D<&%T:"D*("`@('L*
M("`@("`@("!I9B`H(2@D<&%T:"`]/3T@)'1H:7,M/E]C=7)R96YT4&%T:"DI
M('L*("`@("`@("`@("`@)&9O;&1E<DQI<W0@/2`D=&AI<RT^7W9F<RT^;&ES
M=$9O;&1E<B@D<&%T:"D["B`@("`@("`@("`@(&EF("@D9F]L9&5R3&ES="D@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]F;VQD97),:7-T(#T@)&9O;&1E
M<DQI<W0["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-U<G)E;G10871H(#T@
M)'!A=&@["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D-O=6QD(&YO="!R
M96%D("5S+B(I+"`D<&%T:"DI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+TQI
M<W1)=&5M+G!H<"<["B`@("`@("`@:68@*"1F:6QE(#T@87)R87E?<VAI9G0H
M)'1H:7,M/E]F;VQD97),:7-T*2D@>PH@("`@("`@("`@("`D9FEL92`]("9N
M97<@5D937TQI<W1)=&5M*"1P871H+"`D9FEL92D["B`@("`@("`@("`@(')E
M='5R;B`D9FEL93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0VAA
M;F=E<R!P97)M:7-S:6]N<R!F;W(@86X@271E;2!O;B!T:&4@5D93+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@("`@("`@($AO;&1S('1H
M92!P871H(&]F(&1I<F5C=&]R>2!O9B!T:&4@271E;2X*("`@("`J($!P87)A
M;2!S=')I;F<@)'!E<FUI<W-I;VX@(%1/1$\*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B
M:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C:&%N9V50
M97)M:7-S:6]N<R@D<&%T:"P@)'!E<FUI<W-I;VXI"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?=F9S+3YC:&%N9V5097)M:7-S:6]N<RAD:7)N86UE
M*"1P871H*2P@8F%S96YA;64H)'!A=&@I+"`D<&5R;6ES<VEO;BD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&QI<W0@;V8@861D:71I;VYA
M;"!C<F5D96YT:6%L<R!R97%U:7)E9"P@:68@86YY+@H@("`@("H*("`@("`J
M($!R971U<FX@87)R87D@($-R961E;G1I86P@;&ES="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T4F5Q=6ER961#<F5D96YT:6%L<R@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?=F9S+3YG971297%U:7)E9$-R961E;G1I86QS
M*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&%R<F%Y('-P
M96-I9FEC>6EN9R!W:&%T('!E<FUI<W-I;VYS(&%R92!C:&%N9V5A8FQE(&9O
M<B!T:&ES"B`@("`@*B!I;7!L96UE;G1A=&EO;BX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!#:&%N9V5A8FQE('!E<FUI<VEO;G,N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=$UO9&EF:6%B;&5097)M:7-S:6]N<R@I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=F9S+3YG971-;V1I9FEA8FQE4&5R
M;6ES<VEO;G,H*3L*("`@('T*"B`@("`O*BH*("`@("`J($-L;W-E(&%N>2!R
M97-O=7)C97,@=&AA="!N965D('1O(&)E(&-L;W-E9"X*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V1I<V-O
M;FYE8W0H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=F9S+3Y?9&ES8V]N;F5C
M="@I.PH@("`@?0H*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M5D93+W-M8BYP:'``````````````````````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P-38P,38@,3`U,34T,S,W,S4@,#(P,C0W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B!3=&%T96QE<W,@5D93(&EM<&QE;65N=&%T:6]N(&9O<B!A(%--0B!S97)V
M97(L(&)A<V5D(&]N('-M8F-L:65N="X*("H*("H@4F5Q=6ER960@=F%L=65S
M(&9O<B`D<&%R86US.@H@*B`\<')E/@H@*B`@("=U<V5R;F%M92<@("T@5&AE
M('5S97)N86UE('=I=&@@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@4TU"('-E
M<G9E<BX*("H@("`G<&%S<W=O<F0G("`M(%1H92!P87-S=V]R9"!W:71H('=H
M:6-H('1O(&-O;FYE8W0@=&\@=&AE(%--0B!S97)V97(N"B`J("`@)VAO<W1S
M<&5C)R`@+2!4:&4@4TU"('-E<G9E<B!T;R!C;VYN96-T('1O+@H@*B`@("=P
M;W)T)R`@("`@("T@5&AE(%--0B!P;W)T(&YU;6)E<B!T;R!C;VYN96-T('1O
M+@H@*B`@("=S:&%R92<@("`@("T@5&AE('-H87)E('1O(&%C8V5S<R!O;B!T
M:&4@4TU"('-E<G9E<BX*("H@("`G<VUB8VQI96YT)R`M(%1H92!P871H('1O
M('1H92`G<VUB8VQI96YT)R!E>&5C=71A8FQE+@H@*B`\+W!R93X*("H*("H@
M3W!T:6]N86P@=F%L=65S(&9O<B`D<&%R86US.@H@*B`\<')E/@H@*B`@("=I
M<&%D9')E<W,G("T@5&AE(&%D9')E<W,@;V8@=&AE('-E<G9E<B!T;R!C;VYN
M96-T('1O+@H@*B`\+W!R93X*("H*("H@1G5N8W1I;VYS(&YO="!I;7!L96UE
M;G1E9#H*("H@("`M(&-H86YG95!E<FUI<W-I;VYS*"DZ(%1H92!334(@<&5R
M;6ES<VEO;B!S='EL92!D;V5S(&YO="!F:70@=VET:"!T:&4*("H@("`@("`@
M("`@("`@("`@("`@("`@("`@(&UO9'5L92X*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP+'8@,2XQ,2XR+C@@,C`P-B\P-2\S,2`P
M-#HU,#HP,B!S;'5S87)Z($5X<"`D"B`J"B`J($-O9&5B87-E(&-O<'ER:6=H
M="`R,#`R(%!A=6P@1V%R96%U(#QP875L0'AH87=K+FYE=#XN("!!9&%P=&5D
M('=I=&@*("H@<&5R;6ES<VEO;B!B>2!0871R:6-E($QE=F5S<75E(#QW87EN
M94!P=&%F9BYC83X@9G)O;2!P:'!S;6(M,"XX(&-O9&4L(&%N9`H@*B!C;VYV
M97)T960@=&\@=&AE($Q'4$PN("!0;&5A<V4@9&\@;F]T('1A=6YT(&]R:6=I
M;F%L(&%U=&AO<BP@8V]N=&%C=`H@*B!0871R:6-E($QE=F5S<75E(&]R(&1E
M=D!L:7-T<RYH;W)D92YO<F<N"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!0875L($=A<F5A=2`\<&%U;$!X:&%W:RYN970^"B`J($!A=71H;W(@(%!A
M=')I8V4@3&5V97-Q=64@/'=A>6YE0'!T869F+F-A/@H@*B!`<VEN8V4@("!(
M;W)D92`S+C$*("H@0'!A8VMA9V4@5D93"B`J+PIC;&%S<R!61E-?<VUB(&5X
M=&5N9',@5D93('L*"B`@("`O*BH*("`@("`J($QI<W0@;V8@861D:71I;VYA
M;"!C<F5D96YT:6%L<R!R97%U:7)E9"!F;W(@=&AI<R!61E,@8F%C:V5N9"X*
M("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V-R
M961E;G1I86QS(#T@87)R87DH)W5S97)N86UE)RP@)W!A<W-W;W)D)RD["@H@
M("`@+RHJ"B`@("`@*B!,:7-T(&]F('!E<FUI<W-I;VYS(&%N9"!I9B!T:&5Y
M(&-A;B!B92!C:&%N9V5D(&EN('1H:7,@5D93(&)A8VME;F0N"B`@("`@*@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P97)M:7-S:6]N
M<R`](&%R<F%Y*`H@("`@("`@("=O=VYE<B<@/3X@87)R87DH)W)E860G(#T^
M(&9A;'-E+"`G=W)I=&4G(#T^(&9A;'-E+"`G97AE8W5T92<@/3X@9F%L<V4I
M+`H@("`@("`@("=G<F]U<"<@/3X@87)R87DH)W)E860G(#T^(&9A;'-E+"`G
M=W)I=&4G(#T^(&9A;'-E+"`G97AE8W5T92<@/3X@9F%L<V4I+`H@("`@("`@
M("=A;&PG("`@/3X@87)R87DH)W)E860G(#T^(&9A;'-E+"`G=W)I=&4G(#T^
M(&9A;'-E+"`G97AE8W5T92<@/3X@9F%L<V4I*3L*"B`@("`O*BH*("`@("`J
M($%U=&AE;G1I8V%T97,@82!U<V5R(&]N('1H92!334(@<V5R=F5R(&%N9"!S
M:&%R92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86Y\4$5!4E]%<G)O<B`@5')U92!O;B!S=6-C
M97-S(&]R(&$@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?8V]N;F5C="@I"B`@("!["B`@("`@("`@)&-M9"`](&%R<F%Y
M*"=Q=6ET)RD["B`@("`@("`@)&5R<B`]("1T:&ES+3Y?8V]M;6%N9"@G)RP@
M)&-M9"D["B`@("`@("`@:68@*&ES7V$H)&5R<BP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")!=71H
M96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N(BDI.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E=')I979E<R!A(&9I;&4@9G)O;2!T:&4@5D93+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H;F%M92!T;R!T:&4@
M9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!F:6QE;F%M
M92!T;R!R971R:65V92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE(&9I;&4@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A9"@D<&%T
M:"P@)&YA;64I"B`@("!["B`@("`@("`@;&ES="@D<&%T:"P@)&YA;64I(#T@
M)'1H:7,M/E]E<V-A<&53:&5L;$-O;6UA;F0H)'!A=&@L("1N86UE*3L*("`@
M("`@("`D=&5M<"`]("1T:&ES+3Y?9V5T5&5M<$9I;&4H*3L*("`@("`@("`D
M8VUD(#T@87)R87DH)V=E="!<(B<@+B`D;F%M92`N("=<(B`G("X@)'1E;7`I
M.PH@("`@("`@("1E<G(@/2`D=&AI<RT^7V-O;6UA;F0H)'!A=&@L("1C;60I
M.PH@("`@("`@(&EF("AI<U]A*"1E<G(L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1E<G(["B`@("`@("`@?0H@("`@("`@(&EF("@A
M9FEL95]E>&ES=',H)'1E;7`I*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O(&]P96X@5D93(&9I
M;&4@7"(E<UPB+B(I+"`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2DI
M.PH@("`@("`@('T*("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=F:6QE
M7V=E=%]C;VYT96YT<R<I*2!["B`@("`@("`@("`@("1F:6QE(#T@9FEL95]G
M971?8V]N=&5N=',H)'1E;7`I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1F<"`](&9O<&5N*"1T96UP+"`G<B<I.PH@("`@("`@("`@("`D9FEL
M92`](&9R96%D*"1F<"P@9FEL97-I>F4H)'1E;7`I*3L*("`@("`@("`@("`@
M9F-L;W-E*"1F<"D["B`@("`@("`@?0H@("`@("`@('5N;&EN:R@D=&5M<"D[
M"B`@("`@("`@:68@*"1F:6QE*2!["B`@("`@("`@("`@(')E='5R;B`D9FEL
M93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BAS<')I;G1F*%\H(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M(%PB)7-<(BXB*2P@)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M92DI*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3=&]R97,@82!F:6QE
M(&EN('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T
M:"`@("`@("`@(%1H92!P871H('1O('-T;W)E('1H92!F:6QE(&EN+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@("`@(%1H92!F:6QE;F%M92!T
M;R!U<V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T;7!&:6QE("`@("`@5&AE
M('1E;7!O<F%R>2!F:6QE(&-O;G1A:6YI;F<@=&AE(&1A=&$@=&\@8F4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S=&]R960N"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D875T;V-R96%T92`@075T;VUA=&EC86QL>2!C
M<F5A=&4@9&ER96-T;W)I97,_"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M96%N?%!%05)?17)R;W(@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R
M;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@=W)I=&4H)'!A
M=&@L("1N86UE+"`D=&UP1FEL92P@)&%U=&]C<F5A=&4@/2!F86QS92D*("`@
M('L*("`@("`@("`O+R!$;W5B;&4@<75O=&5S(&YO="!A;&QO=V5D(&EN(%--
M0B!F:6QE;F%M92X*("`@("`@("`D;F%M92`]('-T<E]R97!L86-E*"<B)RP@
M(B<B+"`D;F%M92D["@H@("`@("`@(&QI<W0H)'!A=&@L("1N86UE*2`]("1T
M:&ES+3Y?97-C87!E4VAE;&Q#;VUM86YD*"1P871H+"`D;F%M92D["B`@("`@
M("`@)&-M9"`](&%R<F%Y*"=P=70@7"(G("X@)'1M<$9I;&4@+B`G7"(@7"(G
M("X@)&YA;64@+B`G7"(G*3L*("`@("`@("`O+R!D;R!W92!N965D('1O(&9I
M<G-T(&%U=&]C<F5A=&4@=&AE(&1I<F5C=&]R>3\*("`@("`@("!I9B`H)&%U
M=&]C<F5A=&4I('L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YA=71O
M8W)E871E4&%T:"@D<&%T:"D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1E<G(@
M/2`D=&AI<RT^7V-O;6UA;F0H)'!A=&@L("1C;60I.PH@("`@("`@(&EF("AI
M<U]A*"1E<G(L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1E<G(["B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4W1O<F5S(&$@9FEL92!I;B!T:&4@5D93(&9R;VT@
M<F%W(&1A=&$N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@
M("`@("`@(%1H92!P871H('1O('-T;W)E('1H92!F:6QE(&EN+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;F%M92`@("`@("`@(%1H92!F:6QE;F%M92!T;R!U
M<V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A("`@("`@("`@5&AE(&9I
M;&4@9&%T82X*("`@("`J($!P87)A;2!B;V]L96%N("1A=71O8W)E871E("!!
M=71O;6%T:6-A;&QY(&-R96%T92!D:7)E8W1O<FEE<S\*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86Y\4$5!4E]%<G)O<B`@5')U92!O;B!S=6-C97-S
M(&]R(&$@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!W<FET941A=&$H)'!A=&@L("1N86UE+"`D9&%T82P@)&%U=&]C<F5A
M=&4@/2!F86QS92D*("`@('L*("`@("`@("`D=&UP1FEL92`]("1T:&ES+3Y?
M9V5T5&5M<$9I;&4H*3L*("`@("`@("`D9G`@/2!F;W!E;B@D=&UP1FEL92P@
M)W=B)RD["B`@("`@("`@9G=R:71E*"1F<"P@)&1A=&$I.PH@("`@("`@(&9C
M;&]S92@D9G`I.PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^=W)I=&4H)'!A
M=&@L("1N86UE+"`D=&UP1FEL92P@)&%U=&]C<F5A=&4I.PH@("`@("`@('5N
M;&EN:R@D=&UP1FEL92D["B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&$@9FEL92!F<F]M('1H92!61E,N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@
M=&\@9&5L971E('1H92!F:6QE(&9R;VTN"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N86UE("!4:&4@9FEL96YA;64@=&\@=7-E+@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;&5A;GQ014%27T5R<F]R("!4<G5E(&]N('-U8V-E<W,@;W(@
M82!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&1E;&5T949I;&4H)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@(&QI<W0H
M)'!A=&@L("1N86UE*2`]("1T:&ES+3Y?97-C87!E4VAE;&Q#;VUM86YD*"1P
M871H+"`D;F%M92D["B`@("`@("`@)&-M9"`](&%R<F%Y*"=D96P@7"(G("X@
M)&YA;64@+B`G7"(G*3L*("`@("`@("`D97)R(#T@)'1H:7,M/E]C;VUM86YD
M*"1P871H+"`D8VUD*3L*("`@("`@("!I9B`H:7-?82@D97)R+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D97)R.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($-H
M96-K<R!I9B!A(&=I=F5N('!A=&AN86UE(&ES(&$@9F]L9&5R+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H('1O('1H92!F
M;VQD97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@9FEL92!O
M<B!F;VQD97(@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%1R=64@:68@:70@:7,@82!F;VQD97(L(&9A;'-E(&]T:&5R=VES92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@:7-&;VQD97(H)'!A=&@L("1N86UE*0H@("`@
M>PH@("`@("`@(&QI<W0H)'!A=&@L("1N86UE*2`]("1T:&ES+3Y?97-C87!E
M4VAE;&Q#;VUM86YD*"1P871H+"`D;F%M92D["B`@("`@("`@)&-M9"`](&%R
M<F%Y*"=Q=6ET)RD["B`@("`@("`@)&5R<B`]("1T:&ES+3Y?8V]M;6%N9"@D
M=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2P@)&-M9"D["B`@("`@("`@
M:68@*&ES7V$H)&5R<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1&5L971E<R!A(&9O;&1E<B!F<F]M('1H
M92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@
M("`@5&AE('!A=&@@=&\@9&5L971E('1H92!F;VQD97(@9G)O;2X*("`@("`J
M($!P87)A;2!S=')I;F<@)&YA;64@("`@("`@(%1H92!N86UE(&]F('1H92!F
M;VQD97(@=&\@9&5L971E+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)')E8W5R
M<VEV92`@1F]R8V4@82!R96-U<G-I=F4@9&5L971E/PH@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;GQ014%27T5R<F]R("!4<G5E(&]N('-U8V-E<W,@
M;W(@82!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&1E;&5T949O;&1E<B@D<&%T:"P@)&YA;64L("1R96-U<G-I=F4@/2!F
M86QS92D*("`@('L*("`@("`@("`D:7-$:7(@/2!F86QS93L*("`@("`@("`D
M9&ER0VAE8VL@/2`D=&AI<RT^;&ES=$9O;&1E<B@D<&%T:"D["B`@("`@("`@
M9F]R96%C:"`H)&1I<D-H96-K(&%S("1F:6QE*2!["B`@("`@("`@("`@(&EF
M("@D9FEL95LG;F%M92==(#T]("1N86UE("8F("1F:6QE6R=T>7!E)UT@/3T@
M)RHJ9&ER)RD@>PH@("`@("`@("`@("`@("`@)&ES1&ER(#T@=')U93L*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!I9B`H(21I<T1I<BD@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(EPB)7-<(B!I<R!N;W0@82!D:7)E
M8W1O<GDN(BDL("1P871H("X@)R\G("X@)&YA;64I*3L*("`@("`@("!]"@H@
M("`@("`@("1F:6QE7VQI<W0@/2`D=&AI<RT^;&ES=$9O;&1E<B@D=&AI<RT^
M7V=E=%!A=&@H)'!A=&@L("1N86UE*2D["B`@("`@("`@:68@*&ES7V$H)&9I
M;&5?;&ES="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)&9I;&5?;&ES=#L*("`@("`@("!]"@H@("`@("`@(&EF("@D9FEL95]L:7-T
M("8F("$D<F5C=7)S:79E*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L
M('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T4&%T
M:"@D<&%T:"P@)&YA;64I*2D["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H
M("@D9FEL95]L:7-T(&%S("1F:6QE*2!["B`@("`@("`@("`@(&EF("@D9FEL
M95LG='EP92==(#T]("<J*F1I<B<I('L*("`@("`@("`@("`@("`@("1R97-U
M;'0@/2`D=&AI<RT^9&5L971E1F]L9&5R*"1T:&ES+3Y?9V5T4&%T:"@D<&%T
M:"P@)&YA;64I+"`D9FEL95LG;F%M92==+"`D<F5C=7)S:79E*3L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI
M<RT^9&5L971E1FEL92@D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2P@
M)&9I;&5;)VYA;64G72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@
M*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("\O(%)E86QL>2!D96QE=&4@=&AE(&9O;&1E<BX*("`@("`@("!L
M:7-T*"1P871H+"`D;F%M92D@/2`D=&AI<RT^7V5S8V%P95-H96QL0V]M;6%N
M9"@D<&%T:"P@)&YA;64I.PH@("`@("`@("1C;60@/2!A<G)A>2@G<FUD:7(@
M7"(G("X@)&YA;64@+B`G7"(G*3L*("`@("`@("`D97)R(#T@)'1H:7,M/E]C
M;VUM86YD*"1P871H+"`D8VUD*3L*("`@("`@("!I9B`H:7-?82@D97)R+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R
M(%PB)7-<(BXB*2P@)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M92DI*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296YA;65S(&$@9FEL92!I
M;B!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&]L9'!A
M=&@@(%1H92!O;&0@<&%T:"!T;R!T:&4@9FEL92X*("`@("`J($!P87)A;2!S
M=')I;F<@)&]L9&YA;64@(%1H92!O;&0@9FEL96YA;64N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1N97=P871H("!4:&4@;F5W('!A=&@@;V8@=&AE(&9I;&4N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=N86UE("!4:&4@;F5W(&9I;&5N
M86UE+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;GQ014%27T5R<F]R
M("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]N(&9A:6QU<F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F%M92@D;VQD<&%T:"P@)&]L9&YA
M;64L("1N97=P871H+"`D;F5W;F%M92D*("`@('L*("`@("`@("!I9B`H:7-?
M82@D<F5S=6QT(#T@)'1H:7,M/F%U=&]C<F5A=&50871H*"1N97=P871H*2P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@("`@("!]"@H@("`@("`@("\O($1O=6)L92!Q=6]T97,@;F]T(&%L;&]W
M960@:6X@4TU"(&9I;&5N86UE+@H@("`@("`@("1N97=N86UE(#T@<W1R7W)E
M<&QA8V4H)R(G+"`B)R(L("1N97=N86UE*3L*"B`@("`@("`@;&ES="@D9FEL
M92P@)&YA;64I(#T@)'1H:7,M/E]E<V-A<&53:&5L;$-O;6UA;F0H)&]L9&YA
M;64L("1N97=N86UE*3L*("`@("`@("`D8VUD(#T@87)R87DH)W)E;F%M92!<
M(B<@+B`@<W1R7W)E<&QA8V4H)R\G+"`G7%Q<7"<L("1O;&1P871H*2`N("=<
M7"<@+B`D9FEL92`N("=<(B!<(B<@+@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!S=')?<F5P;&%C92@G+R<L("=<7%Q<)RP@)&YE=W!A
M=&@I("X@)UQ<)R`N("1N86UE("X@)UPB)RD["B`@("`@("`@:68@*&ES7V$H
M)&5R<B`]("1T:&ES+3Y?8V]M;6%N9"@G)RP@)&-M9"DL("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R
M:6YT9BA?*")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB*2P@
M)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M92DI*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E
M871E<R!A(&9O;&1E<B!O;B!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'!A=&@@(%1H92!P871H(&]F(&1I<F5C=&]R>2!T;R!C<F5A
M=&4@9F]L9&5R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&YA
M;64@;V8@=&AE(&YE=R!F;VQD97(N"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N?%!%05)?17)R;W(@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?
M17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@8W)E871E
M1F]L9&5R*"1P871H+"`D;F%M92D*("`@('L*("`@("`@("`O+R!$;W5B;&4@
M<75O=&5S(&YO="!A;&QO=V5D(&EN(%--0B!F:6QE;F%M92X*("`@("`@("`D
M;F%M92`]('-T<E]R97!L86-E*"<B)RP@(B<B+"`D;F%M92D["@H@("`@("`@
M(&QI<W0H)&1I<BP@)&UK9&ER*2`]("1T:&ES+3Y?97-C87!E4VAE;&Q#;VUM
M86YD*"1P871H+"`D;F%M92D["B`@("`@("`@)&-M9"`](&%R<F%Y*"=M:V1I
M<B!<(B<@+B`D;6MD:7(@+B`G7"(G*3L*("`@("`@("`D97)R(#T@)'1H:7,M
M/E]C;VUM86YD*"1D:7(L("1C;60I.PH@("`@("`@(&EF("AI<U]A*"1E<G(L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD
M97(@7"(E<UPB+B(I+"`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2DI
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@86X@=6YS;W)T960@9FEL92!L:7-T+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@("`@("`@5&AE('!A=&@@
M;V8@=&AE(&1I<F5C=&]R>2!T;R!G970@=&AE(&9I;&4@;&ES=`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("!F;W(N"B`@("`@*B!`<&%R86T@
M;6EX960@)&9I;'1E<B`@("`@($AA<V@@;V8@:71E;7,@=&\@9FEL=&5R(&)A
M<V5D(&]N(&9I;&5N86UE+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&1O=&9I
M;&5S("!3:&]W(&1O=&9I;&5S/R!4:&ES(&ES(&ER<F5L979A;G0@=VET:`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!S;6)C;&EE;G0N"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B`D9&ER;VYL>2`@(%-H;W<@9&ER96-T;W)I
M97,@;VYL>3\*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86Y\4$5!4E]%
M<G)O<B`@1FEL92!L:7-T(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]N
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=$9O;&1E<B@D<&%T:"`]("<G+"`D
M9FEL=&5R(#T@;G5L;"P@)&1O=&9I;&5S(#T@=')U92P@)&1I<F]N;'D@/2!F
M86QS92D*("`@('L*("`@("`@("!L:7-T*"1P871H*2`]("1T:&ES+3Y?97-C
M87!E4VAE;&Q#;VUM86YD*"1P871H*3L*("`@("`@("`D8VUD(#T@87)R87DH
M)VQS)RD["B`@("`@("`@)')E<R`]("1T:&ES+3Y?8V]M;6%N9"@D<&%T:"P@
M)&-M9"D["B`@("`@("`@:68@*&ES7V$H)')E<RP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("!]"B`@("`@("`@
M)&YU;5]L:6YE<R`](&-O=6YT*"1R97,I.PH@("`@("`@("1F:6QE<R`](&%R
M<F%Y*"D["B`@("`@("`@9F]R("@D<B`](#`[("1R(#P@)&YU;5]L:6YE<SL@
M)'(K*RD@>PH@("`@("`@("`@("`O+R!-871C:"!F:6QE(&QI<W1I;F<N"B`@
M("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7BA<<UQS+BM<<WLV+'TI+R<L
M("1R97-;)')=*2D@>PH@("`@("`@("`@("`@("`@+R\@4W!L:70@:6YT;R!C
M;VQU;6YS(&%T(&5V97)Y('-I>"!S<&%C97,*("`@("`@("`@("`@("`@("1S
M<&QI=#$@/2!P<F5G7W-P;&ET*"<O7'-[-BQ]+R<L('1R:6TH)')E<ULD<ETI
M*3L*("`@("`@("`@("`@("`@("\O($EF('1H92!F:6QE(&YA;64@:7-N)W0@
M+B!O<B`N+@H@("`@("`@("`@("`@("`@:68@*"1S<&QI=#%;,%T@(3T@)RXG
M("8F("1S<&QI=#%;,%T@(3T@)RXN)RD@>PH@("`@("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D<W!L:70Q6S)=*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`O+R!)9B!T:&5R92!I<R!A('-M86QL(&9I;&4@<VEZ92P@:6YF(&-O
M=6QD(&)E('-P;&ET"B`@("`@("`@("`@("`@("`@("`@("`@("\O(&EN=&\@
M,R!C;VQS+@H@("`@("`@("`@("`@("`@("`@("`@("`D<W!L:70Q6S%=("X]
M("<@)R`N("1S<&QI=#%;,ET["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("\O(%-P;&ET(&9I;&4@:6YF(&%T(&5V97)Y(&]N
M92!O<B!M;W)E('-P86-E<RX*("`@("`@("`@("`@("`@("`@("`D<W!L:70R
M(#T@<')E9U]S<&QI="@G+UQS*R\G+"`D<W!L:70Q6S%=*3L*("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-?;G5M97)I8R@D<W!L:70R6S!=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`O+R!)9B!T:&5R92!I<R!N;R!F:6QE(&%T
M='(L('-H:69T(&-O;',@;W9E<BX*("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87E?=6YS:&EF="@D<W!L:70R+"`G)RD["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("1M>5]N86UE(#T@)'-P;&ET,5LP
M73L*"B`@("`@("`@("`@("`@("`@("`@+R\@1FEL=&5R(&]U="!D;W1F:6QE
M<R!I9B!T:&5Y(&%R96XG="!W86YT960N"B`@("`@("`@("`@("`@("`@("`@
M:68@*"$D9&]T9FEL97,@)B8@<W5B<W1R*"1M>5]N86UE+"`P+"`Q*2`]/2`G
M+B<I('L*("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@("`D;7E?<VEZ
M92`]("1S<&QI=#);,5T["B`@("`@("`@("`@("`@("`@("`@)&5X=%]N86UE
M(#T@97AP;&]D92@G+B<L("1M>5]N86UE*3L*"B`@("`@("`@("`@("`@("`@
M("`@:68@*"AS=')P;W,H)'-P;&ET,ELP72P@)T0G*2`A/3T@9F%L<V4I*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1M>5]T>7!E(#T@)RHJ9&ER)SL*
M("`@("`@("`@("`@("`@("`@("`@("`@)&UY7W-I>F4@/2`M,3L*("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D;7E?='EP92`](%9&4SHZ<W1R=&]L;W=E<B@D97AT7VYA;65;8V]U;G0H
M)&5X=%]N86UE*2`M(#%=*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@)&UY7V1A=&4@/2!S=')T;W1I;64H)'-P;&ET,ELT
M72`N("<@)R`N("1S<&QI=#);,UT@+B`G("<@+@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1S<&QI=#);-ET@+B`G("<@+B`D
M<W!L:70R6S5=*3L*("`@("`@("`@("`@("`@("`@("`D9FEL961A=&$@/2!A
M<G)A>2@G;W=N97(G(#T^("<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=G<F]U<"<@/3X@)R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W!E<FUS)R`]/B`G)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;F%M92<@/3X@)&UY7VYA
M;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y
M<&4G(#T^("1M>5]T>7!E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=D871E)R`]/B`D;7E?9&%T92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G<VEZ92<@/3X@)&UY7W-I>F4I.PH@
M("`@("`@("`@("`@("`@("`@("\O('=A=&-H(&9O<B!F:6QT97)S(&%N9"!D
M:7)O;FQY"B`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?9FEL=&5R
M36%T8V@H)&9I;'1E<BP@)&UY7VYA;64I*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@('5N<V5T*"1F:6QE*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M8V]N=&EN=64["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@(&EF("@D9&ER;VYL>2`F)B`D;7E?='EP92`A/3T@)RHJ9&ER)RD@
M>PH@("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D9FEL92D["B`@("`@
M("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("`@("`@("`@)&9I;&5S6R1F:6QE9&%T85LG
M;F%M92==72`]("1F:6QE9&%T83L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@)&9I;&5S.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A('-O<G1E9"!L:7-T(&]F(&9O
M;&1E<G,@:6X@<W!E8VEF:65D(&1I<F5C=&]R>2X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1P871H("`@("`@("`@5&AE('!A=&@@;V8@=&AE(&1I
M<F5C=&]R>2!T;R!G970@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@9&ER96-T;W)Y(&QI<W0@9F]R+@H@("`@("H@0'!A<F%M(&UI
M>&5D("1F:6QT97(@("`@("`@($AA<V@@;V8@:71E;7,@=&\@9FEL=&5R(&)A
M<V5D(&]N(&9O;&1E<FQI<W0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&]T
M9F]L9&5R<R`@26YC;'5D92!D;W1F;VQD97)S/R!)<G)E;&5V86YT(&9O<B!3
M34(N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N?%!%05)?17)R;W(@
M($9O;&1E<B!L:7-T(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]N"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@;&ES=$9O;&1E<G,H)'!A=&@@/2`G)RP@)&9I
M;'1E<B`](&YU;&PL("1D;W1F;VQD97)S(#T@=')U92D*("`@('L*("`@("`@
M("`D9F]L9&5R<R`](&%R<F%Y*"D["B`@("`@("`@)&9O;&1E<B`](&%R<F%Y
M*"D["@H@("`@("`@("1F;VQD97),:7-T(#T@)'1H:7,M/FQI<W1&;VQD97(H
M)'!A=&@L(&YU;&PL("1D;W1F;VQD97)S+"!T<G5E*3L*("`@("`@("!I9B`H
M:7-?82@D9F]L9&5R3&ES="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&9O;&1E<DQI<W0["B`@("`@("`@?0H*("`@("`@("`O+R!D
M:7)N86UE('=I;&P@<W1R:7`@;&%S="!C;VUP;VYE;G0@9G)O;2!P871H+"!E
M=F5N(&]N(&$@9&ER96-T;W)Y"B`@("`@("`@)&9O;&1E<ELG=F%L)UT@/2!D
M:7)N86UE*"1P871H*3L*("`@("`@("`D9F]L9&5R6R=A8F)R978G72`]("<N
M+B<["B`@("`@("`@)&9O;&1E<ELG;&%B96PG72`]("<N+B<["@H@("`@("`@
M("1F;VQD97)S6R1F;VQD97);)W9A;"==72`]("1F;VQD97(["@H@("`@("`@
M(&9O<F5A8V@@*"1F;VQD97),:7-T(&%S("1F:6QE<RD@>PH@("`@("`@("`@
M("`D9F]L9&5R6R=V86PG72`]("1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@)&9I
M;&5S6R=N86UE)UTI.PH@("`@("`@("`@("`D9F]L9&5R6R=A8F)R978G72`]
M("1F:6QE<ULG;F%M92==.PH@("`@("`@("`@("`D9F]L9&5R6R=L86)E;"==
M(#T@)&9O;&1E<ELG=F%L)UT["@H@("`@("`@("`@("`D9F]L9&5R<ULD9F]L
M9&5R6R=V86PG75T@/2`D9F]L9&5R.PH@("`@("`@('T*"B`@("`@("`@:W-O
M<G0H)&9O;&1E<G,I.PH@("`@("`@(')E='5R;B`D9F]L9&5R<SL*("`@('T*
M"B`@("`O*BH*("`@("`J($-O<&EE<R!A(&9I;&4@=&AR;W5G:"!T:&4@8F%C
M:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@
M<&%T:"!T;R!S=&]R92!T:&4@9FEL92!I;BX*("`@("`J($!P87)A;2!S=')I
M;F<@)&YA;64@(%1H92!F:6QE;F%M92!T;R!U<V4N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1D97-T("!4:&4@9&5S=&EN871I;VX@;V8@=&AE(&9I;&4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N?%!%05)?17)R;W(@(%1R=64@
M;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@8V]P>2@D<&%T:"P@)&YA;64L("1D97-T*0H@("`@
M>PH@("`@("`@("1O<FEG(#T@)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M
M92D["B`@("`@("`@:68@*'!R96=?;6%T8V@H)WQ>)R`N('!R96=?<75O=&4H
M)&]R:6<I("X@)R\_)'PG+"`D9&5S="DI('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B0V%N;F]T(&-O<'D@9FEL92AS*2`M('-O
M=7)C92!A;F0@9&5S=&EN871I;VX@87)E('1H92!S86UE+B(I*3L*("`@("`@
M("!]"@H@("`@("`@("1F:6QE0VAE8VL@/2`D=&AI<RT^;&ES=$9O;&1E<B@D
M9&5S="P@;G5L;"P@=')U92D["B`@("`@("`@9F]R96%C:"`H)&9I;&5#:&5C
M:R!A<R`D9FEL92D@>PH@("`@("`@("`@("!I9B`H)&9I;&5;)VYA;64G72`]
M/2`D;F%M92D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H<W!R:6YT9BA?*"(E<R!A;')E861Y(&5X:7-T<RXB*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]G9710871H*"1D97-T+"`D;F%M92DI*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@)&ES1&ER(#T@9F%L<V4["B`@("`@("`@)&1I
M<D-H96-K(#T@)'1H:7,M/FQI<W1&;VQD97(H)'!A=&@L(&YU;&PL(&9A;'-E
M*3L*("`@("`@("!F;W)E86-H("@D9&ER0VAE8VL@87,@)&9I;&4I('L*("`@
M("`@("`@("`@:68@*"1F:6QE6R=N86UE)UT@/3T@)&YA;64@)B8@)&9I;&5;
M)W1Y<&4G72`]/2`G*BID:7(G*2!["B`@("`@("`@("`@("`@("`D:7-$:7(@
M/2!T<G5E.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(&EF("@D:7-$:7(I('L*("`@("`@("`@("`@
M)')E<W5L="`]("1T:&ES+3YC<F5A=&5&;VQD97(H)&1E<W0L("1N86UE*3L*
M"B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`D9FEL95]L:7-T(#T@)'1H:7,M/FQI<W1&;VQD
M97(H)&]R:6<I.PH@("`@("`@("`@("!F;W)E86-H("@D9FEL95]L:7-T(&%S
M("1F:6QE*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F-O
M<'DH)&]R:6<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&9I;&5;)VYA;64G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7V=E=%!A=&@H)&1E<W0L("1N86UE*2D["B`@
M("`@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D=&UP1FEL92`]("1T:&ES+3Y?8W)E871E5&5M<$9I;&4H
M)'!A=&@L("1N86UE*3L*("`@("`@("`@("`@:68@*&ES7V$H)'1M<$9I;&4L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*'-P<FEN=&8H7R@B1F%I;&5D('1O(')E=')I979E.B`E
M<R(I+"`D;W)I9RDI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<F5S
M(#T@)'1H:7,M/G=R:71E*"1D97-T+"`D;F%M92P@)'1M<$9I;&4I.PH@("`@
M("`@("`@("!U;FQI;FLH)'1M<$9I;&4I.PH@("`@("`@("`@("!I9B`H:7-?
M82@D<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D-O<'D@9F%I;&5D.B`E
M<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7V=E=%!A=&@H)&1E<W0L("1N86UE*2DI.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O*BH*("`@("`J($UO=F5S(&$@9FEL92!T:')O=6=H('1H92!B
M86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H
M92!P871H('1O('-T;W)E('1H92!F:6QE(&EN+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;F%M92`@5&AE(&9I;&5N86UE('1O('5S92X*("`@("`J($!P87)A
M;2!S=')I;F<@)&1E<W0@(%1H92!D97-T:6YA=&EO;B!O9B!T:&4@9FEL92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86Y\4$5!4E]%<G)O<B`@5')U
M92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!M;W9E*"1P871H+"`D;F%M92P@)&1E<W0I"B`@
M("!["B`@("`@("`@)&]R:6<@/2`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N
M86UE*3L*("`@("`@("!I9B`H<')E9U]M871C:"@G?%XG("X@<')E9U]Q=6]T
M92@D;W)I9RD@+B`G+S\D?"<L("1D97-T*2D@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#86YN;W0@;6]V92!F:6QE*',I("T@
M9&5S=&EN871I;VX@:7,@=VET:&EN('-O=7)C92XB*2D["B`@("`@("`@?0H*
M("`@("`@("`D9FEL94-H96-K(#T@)'1H:7,M/FQI<W1&;VQD97(H)&1E<W0L
M(&YU;&PL('1R=64I.PH@("`@("`@(&9O<F5A8V@@*"1F:6QE0VAE8VL@87,@
M)&9I;&4I('L*("`@("`@("`@("`@:68@*"1F:6QE6R=N86UE)UT@/3T@)&YA
M;64I('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*'-P<FEN=&8H7R@B)7,@86QR96%D>2!E>&ES=',N(BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M9V5T4&%T:"@D9&5S="P@)&YA;64I*2D["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("1E<G(@/2`D=&AI<RT^<F5N86UE*"1P871H+"`D;F%M
M92P@)&1E<W0L("1N86UE*3L*("`@("`@("!I9B`H:7-?82@D97)R+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*'-P<FEN=&8H7R@B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?9V5T4&%T:"@D9&5S="P@)&YA;64I*2D["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!T:&4@9G5L;"!P871H(&]F(&%N(&ET96TN"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@;V8@9&ER96-T;W)Y(&]F('1H
M92!I=&5M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&YA;64@
M;V8@=&AE(&ET96TN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@1G5L
M;"!P871H('=H96X@)'!A=&@@:7-S970@86YD(&IU<W0@)&YA;64@=VAE;B!N
M;W0@<V5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T4&%T:"@D<&%T:"P@
M)&YA;64I"B`@("!["B`@("`@("`@:68@*"1P871H("$]/2`G)RD@>PH@("`@
M("`@("`@("`@<F5T=7)N("@D<&%T:"`N("<O)R`N("1N86UE*3L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1N86UE.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5P;&%C96UE;G0@9F]R(&5S8V%P97-H96QL8VUD*"DL('9A<FEA8FQE
M(&QE;F=T:"!A<F=S+"!A<R!W92!O;FQY('=A;G0*("`@("`J(&-E<G1A:6X@
M8VAA<F%C=&5R<R!E<V-A<&5D+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D87)R87D@(%-T<FEN
M9W,@=&\@97-C87!E+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V5S8V%P95-H96QL0V]M;6%N9"@I"B`@("![
M"B`@("`@("`@)')E="`](&%R<F%Y*"D["B`@("`@("`@)&%R9W,@/2!F=6YC
M7V=E=%]A<F=S*"D["B`@("`@("`@9F]R96%C:"`H)&%R9W,@87,@)&%R9RD@
M>PH@("`@("`@("`@("`D<F5T6UT@/2!S=')?<F5P;&%C92AA<G)A>2@G.R<L
M("=<7"<I+"!A<G)A>2@G7#LG+"`G7%Q<7"<I+"`D87)G*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1R970["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%
M>&5C=71E<R!A(&-O;6UA;F0@86YD(')E='5R;G,@;W5T<'5T(&QI;F5S(&EN
M(&%R<F%Y+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&-M9"`@0V]M;6%N9"!T;R!B92!E>&5C
M=71E9`H@("`@("H*("`@("`J($!R971U<FX@;6EX960@($%R<F%Y(&]N('-U
M8V-E<W,L(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]E>&5C=71E*"1C;60I"B`@("!["B`@("`@("`@)&-M9"`]('-T<E]R97!L
M86-E*"<B+54E(B<L("<M3B<L("1C;60I.PH@("`@("`@(&5X96,H)&-M9"P@
M)&]U="P@)')E="D["@H@("`@("`@("\O($EN('-O;64@8V%S97,L("AL:6ME
M('1R>6EN9R!T;R!D96QE=&4@82!N;VYE>&ES=&%N="!F:6QE*2P*("`@("`@
M("`O+R!S;6)C;&EE;G0@=VEL;"!R971U<FX@<W5C8V5S<R`H870@;&5A<W0@
M;VX@,BXR+C<@=F5R<VEO;B!))VT*("`@("`@("`O+R!T97-T:6YG(&]N*2X@
M4V\@=')Y('1O(&UA=&-H(&5R<F]R('-T<FEN9W,L(&5V96X@869T97(@<W5C
M8V5S<RX*("`@("`@("!I9B`H)')E="`A/2`P*2!["B`@("`@("`@("`@("1E
M<G(@/2`G)SL*("`@("`@("`@("`@9F]R96%C:"`H)&]U="!A<R`D;&EN92D@
M>PH@("`@("`@("`@("`@("`@:68@*'-T<G!O<R@D;&EN92P@)U5S86=E.B<I
M(#T]/2`P*2!["B`@("`@("`@("`@("`@("`@("`@)&5R<B`]("=#;VUM86YD
M('-Y;G1A>"!I;F-O<G)E8W0G.PH@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*'-T<G!O
M<R@D;&EN92P@)T524E-25B<I("$]/2!F86QS92!\?`H@("`@("`@("`@("`@
M("`@("`@('-T<G!O<R@D;&EN92P@)T524D1/4R<I("$]/2!F86QS92D@>PH@
M("`@("`@("`@("`@("`@("`@("1E<G(@/2!P<F5G7W)E<&QA8V4H)R\N*EPH
M*"XK*5PI+BHO)RP@)UQ<,2<L("1L:6YE*3L*("`@("`@("`@("`@("`@("`@
M("!I9B`H(21E<G(I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&5R<B`]
M("1L:6YE.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!I9B`H(21E<G(I('L*("`@("`@("`@("`@("`@("1E<G(@
M/2`D;W5T(#\@)&]U=%MC;W5N="@D;W5T*2`M(#%=(#H@)')E=#L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D
M97)R*3L*("`@("`@("!]"@H@("`@("`@("\O($-H96-K(&9O<B!E<G)O<G,@
M979E;B!O;B!S=6-C97-S+@H@("`@("`@("1E<G(@/2`G)SL*("`@("`@("!F
M;W)E86-H("@D;W5T(&%S("1L:6YE*2!["B`@("`@("`@("`@(&EF("AS=')P
M;W,H)&QI;F4L("=.5%]35$%455-?3D]?4U5#2%]&24Q%)RD@(3T](&9A;'-E
M('Q\"B`@("`@("`@("`@("`@("!S=')P;W,H)&QI;F4L("=.5%]35$%455-?
M3T)*14-47TY!345?3D]47T9/54Y$)RD@(3T](&9A;'-E*2!["B`@("`@("`@
M("`@("`@("`D97)R(#T@7R@B3F\@<W5C:"!F:6QE(BD["B`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@?2!E;'-E:68@*'-T<G!O<R@D;&EN
M92P@)TY47U-405154U]!0T-%4U-?1$5.245$)RD@(3T](&9A;'-E*2!["B`@
M("`@("`@("`@("`@("`D97)R(#T@7R@B4&5R;6ES<VEO;B!$96YI960B*3L*
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!I9B`H)&5R<BD@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@D97)R*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D;W5T.PH@("`@?0H*("`@("\J*@H@("`@("H@17AE8W5T97,@4TU"(&-O
M;6UA;F1S("T@=VET:&]U="!A=71H96YT:6-A=&EO;B`M(&%N9"!R971U<FYS
M(&]U='!U=`H@("`@("H@;&EN97,@:6X@87)R87DN"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P
M871H("!"87-E('!A=&@@9F]R(&-O;6UA;F0N"B`@("`@*B!`<&%R86T@87)R
M87D@)&-M9"`@($-O;6UA;F1S('1O(&)E(&5X96-U=&5D+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@($%R<F%Y(&]N('-U8V-E<W,L(&9A;'-E(&]N
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VUM86YD*"1P871H
M+"`D8VUD*0H@("`@>PH@("`@("`@(&QI<W0H)'-H87)E*2`]("1T:&ES+3Y?
M97-C87!E4VAE;&Q#;VUM86YD*"1T:&ES+3Y?<&%R86US6R=S:&%R92==*3L*
M("`@("`@("!P=71E;G8H)U!!4U-71#TG("X@)'1H:7,M/E]P87)A;7-;)W!A
M<W-W;W)D)UTI.PH@("`@("`@("1I<&]P=&EO;B`]("AI<W-E="@D=&AI<RT^
M7W!A<F%M<ULG:7!A9&1R97-S)UTI*2`_("@G("U)("<@+B`D=&AI<RT^7W!A
M<F%M<ULG:7!A9&1R97-S)UTI(#H@;G5L;#L*("`@("`@("`D9G5L;&-M9"`]
M("1T:&ES+3Y?<&%R86US6R=S;6)C;&EE;G0G72`N"B`@("`@("`@("`@("<@
M(B\O)R`N("1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==("X@)R\G("X@)'-H
M87)E("X@)R(G("X*("`@("`@("`@("`@)R`B+7`G("X@)'1H:7,M/E]P87)A
M;7-;)W!O<G0G72`N("<B)R`N"B`@("`@("`@("`@("<@(BU5)R`N("1T:&ES
M+3Y?<&%R86US6R=U<V5R;F%M92==("X@)R(G("X*("`@("`@("`@("`@)R`M
M1"`B)R`N("1P871H("X@)R(@)R`N"B`@("`@("`@("`@("1I<&]P=&EO;B`N
M"B`@("`@("`@("`@("<@+6,@(B<["B`@("`@("`@9F]R96%C:"`H)&-M9"!A
M<R`D8RD@>PH@("`@("`@("`@("`D9G5L;&-M9"`N/2`D8R`N("([(CL*("`@
M("`@("!]"B`@("`@("`@)&9U;&QC;60@+CT@)R(G.PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7V5X96-U=&4H)&9U;&QC;60I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T<FEE=F5S(&$@9FEL92!F<F]M('1H92!61E,@86YD('-T;W)E
M<R!I="!T;R!A('1E;7!O<F%R>2!F:6QE+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@
M(%1H92!P871H;F%M92!T;R!T:&4@9FEL92X*("`@("`J($!P87)A;2!S=')I
M;F<@)&YA;64@(%1H92!F:6QE;F%M92!T;R!R971R:65V92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@=&5M<&]R87)Y(&9I;&5N86UE(&]R
M(&$@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?8W)E871E5&5M<$9I;&4H)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@
M(&QI<W0H)'!A=&@L("1N86UE*2`]("1T:&ES+3Y?97-C87!E4VAE;&Q#;VUM
M86YD*"1P871H+"`D;F%M92D["B`@("`@("`@)'1E;7`@/2`D=&AI<RT^7V=E
M=%1E;7!&:6QE*"D["B`@("`@("`@)&-M9"`](&%R<F%Y*"=G970@7"(G("X@
M)&YA;64@+B`G7"(@)R`N("1T96UP*3L*("`@("`@("`D97)R(#T@)'1H:7,M
M/E]C;VUM86YD*"1P871H+"`D8VUD*3L*("`@("`@("!I9B`H:7-?82@D97)R
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D97)R.PH@
M("`@("`@('T*("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1T96UP*2D@>PH@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H
M(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB*2P@)'1H:7,M/E]G
M9710871H*"1P871H+"`D;F%M92DI*3L*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N("1T96UP.PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O5D93+T=#+G!H<```````````````````````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#(V-C8@,3`U,34T,S,W,S4@,#$W-S8Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B!#;&%S<R!F;W(@<')O=FED:6YG(&=A<F)A9V4@8V]L;&5C=&EO
M;B!F;W(@86YY(%9&4R!I;G-T86YC92X*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO5D93+U9&4R]'0RYP:'`L=B`Q+C0N,3(N."`R,#`V+S`Q+S`Q(#(Q.C(X
M.C0R(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI8VAA
M96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU
M<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@
M,RXP"B`J($!P86-K86=E(%9&4PH@*B\*8VQA<W,@5D937T=#('L*"B`@("`O
M*BH*("`@("`J($=A<F)A9V4@8V]L;&5C="!F:6QE<R!I;B!T:&4@5D93('-T
M;W)A9V4@<WES=&5M+@H@("`@("H*("`@("`J($!P87)A;2!61E,@)B1V9G,@
M("`@("!4:&4@5D93(&]B:F5C="!T;R!P97)F;W)M(&=A<F)A9V4@8V]L;&5C
M=&EO;B!O;BX*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@("!4:&4@5D93
M('!A=&@@=&\@8VQE86XN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<V5C<R`@
M5&AE(&UI;FEM=6T@86UO=6YT(&]F('1I;64@*&EN('-E8V]N9',I(')E<75I
M<F5D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@8F5F;W)E(&$@9FEL
M92!I<R!R96UO=F5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!G8R@F)'9F<RP@
M)'!A=&@L("1S96-S(#T@,S0U-C`P*0H@("`@>PH@("`@("`@("\J($$@,24@
M8VAA;F-E('=E('=I;&P@<G5N(&=A<F)A9V4@8V]L;&5C=&EO;B!D=7)I;F<@
M82!C86QL+B`J+PH@("`@("`@(&EF("AR86YD*#`L(#DY*2`]/2`P*2!["B`@
M("`@("`@("`@("\J($UA:V4@<W5R92!C;&5A;FEN9R!I<R!D;VYE(')E8W5R
M<VEV96QY+B`J+PH@("`@("`@("`@("`D9FEL97,@/2`D=F9S+3YL:7-T1F]L
M9&5R*"1P871H+"!N=6QL+"!T<G5E+"!F86QS92P@=')U92D["B`@("`@("`@
M("`@(&EF("@A:7-?82@D9FEL97,L("=014%27T5R<F]R)RD@)B8@:7-?87)R
M87DH)&9I;&5S*2D@>PH@("`@("`@("`@("`@("`@)&UO9'1I;64@/2!T:6UE
M*"D@+2`D<V5C<SL*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1F:6QE<R!A
M<R`D=F%L*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1V86Q;)V1A=&4G
M72`\("1M;V1T:6UE*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1V9G,M
M/F1E;&5T949I;&4H)'!A=&@L("1V86Q;)VYA;64G72D["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@?0H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]61E,O<W%L+G!H<```````
M````````````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#$P-#0P
M-R`Q,#4Q-30S,S<S-2`P,C`R-C,`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*"B\J*@H@*B!&:6QE('9A;'5E(&9O
M<B!V9G-?='EP92!C;VQU;6XN"B`J+PID969I;F4H)U9&4U]&24Q%)RP@,2D[
M"@HO*BH*("H@1F]L9&5R('9A;'5E(&9O<B!V9G-?='EP92!C;VQU;6XN"B`J
M+PID969I;F4H)U9&4U]&3TQ$15(G+"`R*3L*"B\J*@H@*B!61E,@:6UP;&5M
M96YT871I;VX@9F]R(%!(4"=S(%!%05(@9&%T86)A<V4@86)S=')A8W1I;VX@
M;&%Y97(N"B`J"B`J(%)E<75I<F5D('9A;'5E<R!F;W(@)'!A<F%M<SH\<')E
M/@H@*B`@("`@("=P:'!T>7!E)R`@("`@("!4:&4@9&%T86)A<V4@='EP92`H
M:64N("=P9W-Q;"<L("=M>7-Q;"<L(&5T8RXI+CPO<')E/@H@*@H@*B!/<'1I
M;VYA;"!V86QU97,Z/'!R93X*("H@("`@("`G=&%B;&4G("`@("`@("`@5&AE
M(&YA;64@;V8@=&AE('9F<R!T86)L92!I;B`G9&%T86)A<V4G+B!$969A=6QT
M<R!T;PH@*B`@("`@("`@("`@("`@("`@("`@("`G:&]R9&5?=F9S)RX\+W!R
M93X*("H*("H@4F5Q=6ER960@8GD@<V]M92!D871A8F%S92!I;7!L96UE;G1A
M=&EO;G,Z/'!R93X*("H@("`@("`G:&]S='-P96,G("`@("`@5&AE(&AO<W1N
M86UE(&]F('1H92!D871A8F%S92!S97)V97(N"B`J("`@("`@)W!R;W1O8V]L
M)R`@("`@(%1H92!C;VUM=6YI8V%T:6]N('!R;W1O8V]L("@G=&-P)RP@)W5N
M:7@G+"!E=&,N*2X*("H@("`@("`G9&%T86)A<V4G("`@("`@5&AE(&YA;64@
M;V8@=&AE(&1A=&%B87-E+@H@*B`@("`@("=U<V5R;F%M92<@("`@("!4:&4@
M=7-E<FYA;64@=VET:"!W:&EC:"!T;R!C;VYN96-T('1O('1H92!D871A8F%S
M92X*("H@("`@("`G<&%S<W=O<F0G("`@("`@5&AE('!A<W-W;W)D(&%S<V]C
M:6%T960@=VET:"`G=7-E<FYA;64G+@H@*B`@("`@("=O<'1I;VYS)R`@("`@
M("!!9&1I=&EO;F%L(&]P=&EO;G,@=&\@<&%S<R!T;R!T:&4@9&%T86)A<V4N
M"B`J("`@("`@)W1T>2<@("`@("`@("`@(%1H92!45%D@;VX@=VAI8V@@=&\@
M8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N"B`J("`@("`@)W!O<G0G("`@("`@
M("`@(%1H92!P;W)T(&]N('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B
M87-E+CPO<')E/@H@*@H@*B!4:&4@=&%B;&4@<W1R=6-T=7)E(&9O<B!T:&4@
M5D93(&-A;B!B92!F;W5N9"!I;@H@*B!D871A+W9F<RYS<6PN"B`J"B`J($1A
M=&%B87-E('-P96-I9FEC(&YO=&5S.@H@*@H@*B!-4U-13#H*("H@/'!R93X*
M("H@+2!4:&4@=F9S7V1A=&$@9FEE;&0@;75S="!B92!O9B!T>7!E($E-04=%
M+@H@*B`M(%EO=2!N965D('1H92!F;VQL;W=I;F<@<&AP+FEN:2!S971T:6YG
M<SH*("H@("`@.R!686QI9"!R86YG92`P("T@,C$T-S0X,S8T-RX@1&5F875L
M="`](#0P.38N"B`J("`@(&US<W%L+G1E>'1L:6UI="`](#`@.R!Z97)O('1O
M('!A<W,@=&AR;W5G:`H@*@H@*B`@("`[(%9A;&ED(')A;F=E(#`@+2`R,30W
M-#@S-C0W+B!$969A=6QT(#T@-#`Y-BX*("H@("`@;7-S<6PN=&5X='-I>F4@
M/2`P(#L@>F5R;R!T;R!P87-S('1H<F]U9V@*("H@/"]P<F4^"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<"QV(#$N.#4N-"XR-B`R
M,#`V+S`U+S,Q(#`T.C4P.C`R('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!61E,*("HO"F-L87-S
M(%9&4U]S<6P@97AT96YD<R!61E,@>PH*("`@("\J*@H@("`@("H@2&%N9&QE
M(&9O<B!T:&4@8W5R<F5N="!D871A8F%S92!C;VYN96-T:6]N+@H@("`@("H*
M("`@("`J($!V87(@1$(*("`@("`J+PH@("`@=F%R("1?9&(@/2!F86QS93L*
M"B`@("`O*BH*("`@("`J(%)E=')I979E<R!T:&4@9FEL97-I>F4@9G)O;2!T
M:&4@5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H
M92!P871H;F%M92!T;R!T:&4@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@
M)&YA;64@(%1H92!F:6QE;F%M92!T;R!R971R:65V92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&EN="!4:&4@9FEL92!S:7IE+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!S:7IE*"1P871H+"`D;F%M92D*("`@('L*("`@("`@("`D8V]N;B`]
M("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@
M("`@("!]"@H@("`@("`@("1L96YG=&A?;W`@/2`D=&AI<RT^7V=E=$9I;&53
M:7IE3W`H*3L*("`@("`@("`D<W%L(#T@<W!R:6YT9B@*("`@("`@("`@("`@
M)U-%3$5#5"`E<RAV9G-?9&%T82D@1E)/32`E<R!72$5212!V9G-?<&%T:"`]
M(#\@04Y$('9F<U]N86UE(#T@/R<L"B`@("`@("`@("`@("1L96YG=&A?;W`L
M"B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92=="B`@("`@("`@
M*3L*("`@("`@("`D=F%L=65S(#T@87)R87DH)'1H:7,M/E]C;VYV97)T4&%T
M:"@D<&%T:"DL("1N86UE*3L*("`@("`@("`D=&AI<RT^;&]G*"1S<6PL(%!%
M05)?3$]'7T1%0E5'*3L*("`@("`@("`D<VEZ92`]("1T:&ES+3Y?9&(M/F=E
M=$]N92@D<W%L+"`D=F%L=65S*3L*"B`@("`@("`@:68@*&ES7VYU;&PH)'-I
M>F4I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P
M<FEN=&8H7R@B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S+R5S
M7"(N(BDL("1P871H+"`D;F%M92DI.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1S:7IE.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M<VEZ92!O9B!A(&9I;&4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!O
M9B!T:&4@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!F
M:6QE;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!S
M:7IE(&]F('1H92!F;VQD97(@:6X@8GET97,@;W(@4$5!4E]%<G)O<B!O;@H@
M("`@("H@("`@("`@("`@("`@("`@("!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971&;VQD97)3:7IE*"1P871H(#T@;G5L;"P@)&YA;64@/2!N
M=6QL*0H@("`@>PH@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D[
M"B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@)'=H
M97)E(#T@*&ES7VYU;&PH)'!A=&@I*2`_(&YU;&P@.B!S<')I;G1F*"=72$52
M12!V9G-?<&%T:"`]("5S)RP@*"@A<W1R;&5N*"1P871H*2D@/R`G(B(G(#H@
M)'1H:7,M/E]D8BT^<75O=&4H)'1H:7,M/E]C;VYV97)T4&%T:"@D<&%T:"DI
M*2D["B`@("`@("`@)&QE;F=T:%]O<"`]("1T:&ES+3Y?9V5T1FEL95-I>F5/
M<"@I.PH@("`@("`@("1S<6P@/2!S<')I;G1F*`H@("`@("`@("`@("`G4T5,
M14-4(%-532@E<RAV9G-?9&%T82DI($923TT@)7,@)7,G+`H@("`@("`@("`@
M("`D;&5N9W1H7V]P+`H@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B
M;&4G72P*("`@("`@("`@("`@)'=H97)E"B`@("`@("`@*3L*("`@("`@("`D
M=&AI<RT^;&]G*"1S<6PL(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`D<VEZ
M92`]("1T:&ES+3Y?9&(M/F=E=$]N92@D<W%L*3L*"B`@("`@("`@<F5T=7)N
M("1S:7IE("$]/2!N=6QL(#\@)'-I>F4@.B`P.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T<FEE=F4@82!F:6QE(&9R;VT@=&AE(%9&4RX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:&YA;64@=&\@=&AE
M(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@9FEL96YA
M;64@=&\@<F5T<FEE=F4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!F:6QE(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E860H)'!A
M=&@L("1N86UE*0H@("`@>PH@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN
M96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?<F5A9$)L;V(H)'1H:7,M/E]P87)A;7-;)W1A
M8FQE)UTL("=V9G-?9&%T82<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@87)R87DH)W9F<U]P871H)R`]/B`D=&AI<RT^7V-O;G9E<G10871H
M*"1P871H*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G=F9S7VYA;64G(#T^("1N86UE*2D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971R:65V97,@82!P87)T(&]F(&$@9FEL92!F<F]M('1H92!61E,N(%!A
M<G1I8W5L87)L>2!U<V5F=6P*("`@("`J('=H96X@<F5A9&EN9R!L87)G92!F
M:6QE<R!W:&EC:"!W;W5L9"!E>&-E960@=&AE(%!(4"!M96UO<GD*("`@("`J
M(&QI;6ET<R!I9B!T:&5Y('=E<F4@<W1O<F5D(&EN(&$@<W1R:6YG+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@("1P871H("`@("`@(%1H92!P871H
M;F%M92!T;R!T:&4@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@("1N86UE
M("`@("`@(%1H92!F:6QE;F%M92!T;R!R971R:65V92X*("`@("`J($!P87)A
M;2!I;G1E9V5R("1O9F9S970@("`@(%1H92!O9F9S970@;V8@=&AE('!A<G0N
M("A4:&4@;F5W(&]F9G-E="!W:6QL(&)E"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!S=&]R960@:6X@:&5R92DN"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D;&5N9W1H("`@("!4:&4@;&5N9W1H(&]F('1H92!P87)T+B!)
M9B!T:&4@;&5N9W1H(#T@+3$L('1H90H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@=VAO;&4@<&%R="!A9G1E<B!T:&4@;V9F<V5T(&ES(')E
M=')I979E9"X@268*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&UO<F4@8GET97,@87)E(&=I=F5N(&%S(&5X:7-T<R!A9G1E<B!T:&4@9VEV
M96X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&]F9G-E="X@
M3VYL>2!T:&4@879A:6QA8FQE(&)Y=&5S(&%R92!R96%D+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)')E;6%I;FEN9R`@5&AE(&)Y=&5S('1H870@87)E(&QE
M9G0L(&%F=&5R('1H92!P87)T('1H870@:7,*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(')E=')I979E9"X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R!4:&4@9FEL92!D871A+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!R96%D4&%R="@D<&%T:"P@)&YA;64L("8D;V9F<V5T+"`D;&5N9W1H(#T@
M+3$L("8D<F5M86EN:6YG*0H@("`@>PH@("`@("`@("1C;VYN(#T@)'1H:7,M
M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*
M"B`@("`@("`@)&1A=&$@/2`D=&AI<RT^7W)E861";&]B*"1T:&ES+3Y?<&%R
M86US6R=T86)L92==+"`G=F9S7V1A=&$G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!A<G)A>2@G=F9S7W!A=&@G(#T^("1T:&ES+3Y?8V]N
M=F5R=%!A=&@H)'!A=&@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G=F9S7VYA;64G(#T^("1N86UE*2D["@H@("`@("`@("\O
M($-A;&-U;&%T92!H;W<@;6%N>2!B>71E<R!-55-4(&)E(')E860L('-O('1H
M92!R96UA:6YG:6YG"B`@("`@("`@+R\@8GET97,@86YD('1H92!N97<@;V9F
M<V5T(&-A;B!B92!C86QC=6QA=&5D(&-O<G)E8W1L>2X*("`@("`@("`D<VEZ
M92`]('-T<FQE;B`H)&1A=&$I.PH@("`@("`@(&EF("@D;&5N9W1H(#T]("TQ
M('Q\("@H)&QE;F=T:"`K("1O9F9S970I(#X@)'-I>F4I*2!["B`@("`@("`@
M("`@("1L96YG=&@@/2`D<VEZ92`M("1O9F9S970["B`@("`@("`@?0H@("`@
M("`@(&EF("@D<F5M86EN:6YG(#P@,"D@>PH@("`@("`@("`@("`D<F5M86EN
M:6YG(#T@,#L*("`@("`@("!]"@H@("`@("`@("1D871A(#T@<W5B<W1R*"1D
M871A+"`D;V9F<V5T+"`D;&5N9W1H*3L*("`@("`@("`D;V9F<V5T(#T@)&]F
M9G-E="`K("1L96YG=&@["B`@("`@("`@)')E;6%I;FEN9R`]("1S:7IE("T@
M)&]F9G-E=#L*"B`@("`@("`@<F5T=7)N("1D871A.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4W1O<F5S(&$@9FEL92!I;B!T:&4@5D93+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'!A=&@@("`@("`@("!4:&4@<&%T:"!T;R!S
M=&]R92!T:&4@9FEL92!I;BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@
M("`@("`@("!4:&4@9FEL96YA;64@=&\@=7-E+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D=&UP1FEL92`@("`@(%1H92!T96UP;W)A<GD@9FEL92!C;VYT86EN
M:6YG('1H92!D871A('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@8F4@<W1O<F5D+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%U=&]C
M<F5A=&4@($%U=&]M871I8V%L;'D@8W)E871E(&1I<F5C=&]R:65S/PH@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A
M(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('=R:71E*"1P871H+"`D;F%M92P@)'1M<$9I;&4L("1A=71O8W)E
M871E(#T@9F%L<V4I"B`@("!["B`@("`@("`@+RH@1&]N)W0@;F5E9"!T;R!C
M:&5C:R!Q=6]T82!H97)E('-I;F-E(&ET('=I;&P@8F4@8VAE8VME9"!W:&5N
M"B`@("`@("`@("H@=W)I=&5$871A*"D@:7,@8V%L;&5D+B`J+PH@("`@("`@
M(&EF("AF=6YC=&EO;E]E>&ES=',H)V9I;&5?9V5T7V-O;G1E;G1S)RDI('L*
M("`@("`@("`@("`@)&1A=&$@/2!F:6QE7V=E=%]C;VYT96YT<R@D=&UP1FEL
M92D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'-I>F4@/2!F:6QE
M<VEZ92@D=&UP1FEL92D["B`@("`@("`@("`@(&EF("@D<VEZ92`]/3T@,"D@
M>PH@("`@("`@("`@("`@("`@)&1A=&$@/2`G)SL*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D9&%T8490(#T@0&9O<&5N*"1T
M;7!&:6QE+"`G<F(G*3L*("`@("`@("`@("`@("`@(&EF("@A)&1A=&%&4"D@
M>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*'-P<FEN=&8H7R@B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO
M="!E>&ES="XB*2P@)'1M<$9I;&4I*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("1D871A(#T@0&9R96%D*"1D871A1E`L("1S:7IE*3L*
M("`@("`@("`@("`@("`@($!F8VQO<V4H)&1A=&%&4"D["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^=W)I=&5$871A
M*"1P871H+"`D;F%M92P@)&1A=&$L("1A=71O8W)E871E*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%-T;W)E(&$@9FEL92!I;B!T:&4@5D93(&9R;VT@<F%W
M(&1A=&$N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@
M("`@(%1H92!P871H('1O('-T;W)E('1H92!F:6QE(&EN+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;F%M92`@("`@("`@(%1H92!F:6QE;F%M92!T;R!U<V4N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A("`@("`@("`@5&AE(&9I;&4@
M9&%T82X*("`@("`J($!P87)A;2!B;V]L96%N("1A=71O8W)E871E("!!=71O
M;6%T:6-A;&QY(&-R96%T92!D:7)E8W1O<FEE<S\*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET
M941A=&$H)'!A=&@L("1N86UE+"`D9&%T82P@)&%U=&]C<F5A=&4@/2!F86QS
M92D*("`@('L*("`@("`@("`D<F5S(#T@)'1H:7,M/E]C:&5C:U%U;W1A5W)I
M=&4H)W-T<FEN9R<L("1D871A*3L*("`@("`@("!I9B`H:7-?82@D<F5S+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@
M("`@('T*"B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@
M("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*("`@("`@("`D<&%T:"`]
M("1T:&ES+3Y?8V]N=F5R=%!A=&@H)'!A=&@I.PH*("`@("`@("`O*B!#:&5C
M:R!T;R!S964@:68@=&AE(&1A=&$@86QR96%D>2!E>&ES=',N("HO"B`@("`@
M("`@)'-Q;"`]('-P<FEN=&8H)U-%3$5#5"!V9G-?:60@1E)/32`E<R!72$52
M12!V9G-?<&%T:"`E<R!!3D0@=F9S7VYA;64@/2`_)RP*("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P*("`@("`@("`@
M("`@("`@("`@("`@("`H96UP='DH)'!A=&@I("8F("1T:&ES+3Y?9&(M/F1B
M<WEN=&%X(#T]("=O8VDX)RD@/R`G($E3($Y53$PG(#H@)R`]("<@+B`D=&AI
M<RT^7V1B+3YQ=6]T92@D<&%T:"DI.PH@("`@("`@("1V86QU97,@/2!A<G)A
M>2@D;F%M92D["B`@("`@("`@)'1H:7,M/FQO9R@D<W%L+"!014%27TQ/1U]$
M14)51RD["B`@("`@("`@)&ED(#T@)'1H:7,M/E]D8BT^9V5T3VYE*"1S<6PL
M("1V86QU97,I.PH*("`@("`@("!I9B`H:7-?82@D:60L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@)'1H:7,M/FQO9R@D:60L(%!%05)?3$]'7T52
M4BD["B`@("`@("`@("`@(')E='5R;B`D:60["B`@("`@("`@?0H*("`@("`@
M("!I9B`H(6ES7VYU;&PH)&ED*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]U<&1A=&5";&]B*"1T:&ES+3Y?<&%R86US6R=T86)L92==+"`G=F9S
M7V1A=&$G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1D871A+"!A<G)A>2@G=F9S7VED)R`]/B`D:60I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=V9G-?;6]D:69I960G
M(#T^('1I;64H*2DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J
M($-H96-K('1O('-E92!I9B!T:&4@9F]L9&5R(&%L<F5A9'D@97AI<W1S+B`J
M+PH@("`@("`@("`@("`D9&ER<R`](&5X<&QO9&4H)R\G+"`D<&%T:"D["B`@
M("`@("`@("`@("1P871H7VYA;64@/2!A<G)A>5]P;W`H)&1I<G,I.PH@("`@
M("`@("`@("`D<&%R96YT(#T@:6UP;&]D92@G+R<L("1D:7)S*3L*("`@("`@
M("`@("`@:68@*"$D=&AI<RT^:7-&;VQD97(H)'!A<F5N="P@)'!A=&A?;F%M
M92DI('L*("`@("`@("`@("`@("`@(&EF("@A)&%U=&]C<F5A=&4I('L*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I
M;G1F*%\H(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES="(I+"`D<&%T:"DL("=H
M;W)D92YE<G)O<B<I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F%U=&]C<F5A=&50871H
M*"1P871H*3L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&ED(#T@)'1H
M:7,M/E]D8BT^;F5X=$ED*"1T:&ES+3Y?<&%R86US6R=T86)L92==*3L*("`@
M("`@("`@("`@:68@*&ES7V$H)&ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^;&]G*"1I9"P@4$5!4E],3T=?15)2*3L*("`@
M("`@("`@("`@("`@(')E='5R;B`D:60["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?:6YS97)T0FQO8B@D=&AI<RT^7W!A<F%M
M<ULG=&%B;&4G72P@)W9F<U]D871A)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9&%T82P@87)R87DH)W9F<U]I9"<@/3X@)&ED
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G=F9S7W1Y<&4G(#T^(%9&4U]&24Q%+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=F9S7W!A
M=&@G(#T^("1P871H+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G=F9S7VYA;64G(#T^("1N86UE+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G=F9S7VUO9&EF:65D)R`]/B!T:6UE*"DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=V9G-?;W=N97(G
M(#T^("1T:&ES+3Y?<&%R86US6R=U<V5R)UTI*3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$96QE=&4@82!F:6QE(&9R;VT@=&AE(%9&4RX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!T
M;R!S=&]R92!T:&4@9FEL92!I;BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA
M;64@(%1H92!F:6QE;F%M92!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE
M8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E1FEL
M92@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@)')E<R`]("1T:&ES+3Y?
M8VAE8VM1=6]T841E;&5T92@D<&%T:"P@)&YA;64I.PH@("`@("`@(&EF("AI
M<U]A*"1R97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1R97,["B`@("`@("`@?0H*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N
M;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@
M("`@("1P871H(#T@)'1H:7,M/E]C;VYV97)T4&%T:"@D<&%T:"D["@H@("`@
M("`@("1S<6P@/2!S<')I;G1F*"=$14Q%5$4@1E)/32`E<R!72$5212!V9G-?
M='EP92`](#\@04Y$('9F<U]P871H("5S($%.1"!V9G-?;F%M92`](#\G+`H@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==
M+`H@("`@("`@("`@("`@("`@("`@("`@("AE;7!T>2@D<&%T:"D@)B8@)'1H
M:7,M/E]D8BT^9&)S>6YT87@@/3T@)V]C:3@G*2`_("<@25,@3E5,3"<@.B`G
M(#T@)R`N("1T:&ES+3Y?9&(M/G%U;W1E*"1P871H*2D["B`@("`@("`@)'9A
M;'5E<R`](&%R<F%Y*%9&4U]&24Q%+"`D;F%M92D["B`@("`@("`@)'1H:7,M
M/FQO9R@D<W%L+"!014%27TQ/1U]$14)51RD["B`@("`@("`@)')E<W5L="`]
M("1T:&ES+3Y?9&(M/G%U97)Y*"1S<6PL("1V86QU97,I.PH*("`@("`@("!I
M9B`H)'1H:7,M/E]D8BT^869F96-T9612;W=S*"D@/3T@,"D@>PH@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@9&5L
M971E(%9&4R!F:6QE+B(I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5N86UE(&$@9FEL92!O
M<B!F;VQD97(@:6X@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1O;&1P871H("!4:&4@;VQD('!A=&@@=&\@=&AE(&9I;&4N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1O;&1N86UE("!4:&4@;VQD(&9I;&5N86UE+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;F5W<&%T:"`@5&AE(&YE=R!P871H(&]F
M('1H92!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5W;F%M92`@5&AE
M(&YE=R!F:6QE;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4
M<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YA;64H)&]L9'!A=&@L("1O
M;&1N86UE+"`D;F5W<&%T:"P@)&YE=VYA;64I"B`@("!["B`@("`@("`@)&-O
M;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N
M;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H<W1R<&]S*"1N97=P871H+"`G+R<I
M(#T]/2!F86QS92D@>PH@("`@("`@("`@("`D<&%R96YT(#T@)R<["B`@("`@
M("`@("`@("1P871H(#T@)&YE=W!A=&@["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@;&ES="@D<&%R96YT+"`D<&%T:"D@/2!E>'!L;V1E*"<O)RP@
M)&YE=W!A=&@L(#(I.PH@("`@("`@('T*("`@("`@("!I9B`H(21T:&ES+3YI
M<T9O;&1E<B@D<&%R96YT+"`D<&%T:"DI('L*("`@("`@("`@("`@:68@*&ES
M7V$H)')E<W5L="`]("1T:&ES+3YA=71O8W)E871E4&%T:"@D;F5W<&%T:"DL
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D;VQD<&%T
M:"`]("1T:&ES+3Y?8V]N=F5R=%!A=&@H)&]L9'!A=&@I.PH@("`@("`@("1N
M97=P871H(#T@)'1H:7,M/E]C;VYV97)T4&%T:"@D;F5W<&%T:"D["@H@("`@
M("`@("1S<6P@(#T@)U501$%412`G("X@)'1H:7,M/E]P87)A;7-;)W1A8FQE
M)UT["B`@("`@("`@)'-Q;"`N/2`G(%-%5"!V9G-?<&%T:"`](#\L('9F<U]N
M86UE(#T@/RP@=F9S7VUO9&EF:65D(#T@/R!72$5212!V9G-?<&%T:"`](#\@
M04Y$('9F<U]N86UE(#T@/R<["B`@("`@("`@)'1H:7,M/FQO9R@D<W%L+"!0
M14%27TQ/1U]$14)51RD["@H@("`@("`@("1V86QU97,@/2!A<G)A>2@D;F5W
M<&%T:"P@)&YE=VYA;64L('1I;64H*2P@)&]L9'!A=&@L("1O;&1N86UE*3L*
M"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1S<6PL("1V
M86QU97,I.PH*("`@("`@("!I9B`H)'1H:7,M/E]D8BT^869F96-T9612;W=S
M*"D@/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BA?*")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(I*3L*("`@("`@("!]
M"@H@("`@("`@("1R96YA;64@/2`D=&AI<RT^7W)E8W5R<VEV95)E;F%M92@D
M;VQD<&%T:"P@)&]L9&YA;64L("1N97=P871H+"`D;F5W;F%M92D["B`@("`@
M("`@:68@*&ES7V$H)')E;F%M92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^;&]G*"1R96YA;64L(%!%05)?3$]'7T524BD["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA
M8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB*2P@)')E;F%M92T^
M9V5T365S<V%G92@I*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@82!F;VQD97(@
M;VX@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H
M("!(;VQD<R!T:&4@<&%T:"!O9B!D:7)E8W1O<GD@=&\@8W)E871E(&9O;&1E
M<BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@($AO;&1S('1H92!N86UE
M(&]F('1H92!N97<@9F]L9&5R+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-R96%T949O;&1E<B@D
M<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O
M;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*("`@
M("`@("`D:60@/2`D=&AI<RT^7V1B+3YN97AT260H)'1H:7,M/E]P87)A;7-;
M)W1A8FQE)UTI.PH@("`@("`@(&EF("AI<U]A*"1I9"P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^;&]G*"1I9"P@4$5!4E],3T=?15)2
M*3L*("`@("`@("`@("`@<F5T=7)N("1I9#L*("`@("`@("!]"@H@("`@("`@
M("1S<6P@(#T@)TE.4T525"!)3E1/("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B
M;&4G73L*("`@("`@("`D<W%L("X]("<@*'9F<U]I9"P@=F9S7W1Y<&4L('9F
M<U]P871H+"!V9G-?;F%M92P@=F9S7VUO9&EF:65D+"!V9G-?;W=N97(I(%9!
M3%5%4R`H/RP@/RP@/RP@/RP@/RP@/RDG.PH@("`@("`@("1T:&ES+3YL;V<H
M)'-Q;"P@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`D=F%L=65S(#T@87)R
M87DH)&ED+"!61E-?1D],1$52+"`D=&AI<RT^7V-O;G9E<G10871H*"1P871H
M*2P@)&YA;64L('1I;64H*2P@)'1H:7,M/E]P87)A;7-;)W5S97(G72D["@H@
M("`@("`@(')E='5R;B`D=&AI<RT^7V1B+3YQ=65R>2@D<W%L+"`D=F%L=65S
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($1E;&5T92!A(&9O;&1E<B!F<F]M
M('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@
M("`@("`@5&AE('!A=&@@;V8@=&AE(&9O;&1E<BX*("`@("`J($!P87)A;2!S
M=')I;F<@)&YA;64@("`@("`@(%1H92!F;VQD97(@;F%M92!T;R!U<V4N"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B`D<F5C=7)S:79E("!&;W)C92!A(')E8W5R
M<VEV92!D96QE=&4_"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U
M92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E1F]L9&5R*"1P871H+"`D
M;F%M92P@)')E8W5R<VEV92`](&9A;'-E*0H@("`@>PH@("`@("`@("1C;VYN
M(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@
M("`@("`@('T*"B`@("`@("`@)'!A=&@@/2`D=&AI<RT^7V-O;G9E<G10871H
M*"1P871H*3L*"B`@("`@("`@)&9O;&1E<E!A=&@@/2`D=&AI<RT^7V=E=$YA
M=&EV95!A=&@H)'!A=&@L("1N86UE*3L*"B`@("`@("`@+RH@0VAE8VL@:68@
M;F]T(')E8W5R<VEV92!A;F0@9F%I;"!I9B!D:7)E8W1O<GD@;F]T(&5M<'1Y
M("HO"B`@("`@("`@:68@*"$D<F5C=7)S:79E*2!["B`@("`@("`@("`@("1F
M;VQD97),:7-T(#T@)'1H:7,M/FQI<W1&;VQD97(H)&9O;&1E<E!A=&@L(&YU
M;&PL('1R=64I.PH@("`@("`@("`@("!I9B`H:7-?82@D9F]L9&5R3&ES="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@D
M9F]L9&5R3&ES="P@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@("`@(')E
M='5R;B`D9F]L9&5R3&ES=#L*("`@("`@("`@("`@?2!E;'-E:68@*"%E;7!T
M>2@D9F]L9&5R3&ES="DI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O(&1E;&5T92`E<RP@
M=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A=&@@+B`G+R<@
M+B`D;F%M92DI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O
M*B!&:7)S="!D96QE=&4@979E<GET:&EN9R!B96QO=R!T:&4@9F]L9&5R+"!S
M;R!I9B!E<G)O<B!W90H@("`@("`@("`J(&=E="!N;R!O<G!H86YS("HO"B`@
M("`@("`@)'-Q;"`]('-P<FEN=&8H)T1%3$5412!&4D]-("5S(%=(15)%('9F
M<U]P871H("5S)RP*("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M<F%M<ULG=&%B;&4G72P*("`@("`@("`@("`@("`@("`@("`@("`H96UP='DH
M)&9O;&1E<E!A=&@I("8F("1T:&ES+3Y?9&(M/F1B<WEN=&%X(#T]("=O8VDX
M)RD@/R`G($E3($Y53$PG(#H@)R!,24M%("<@+B`D=&AI<RT^7V1B+3YQ=6]T
M92@D=&AI<RT^7V=E=$YA=&EV95!A=&@H)&9O;&1E<E!A=&@L("<E)RDI*3L*
M("`@("`@("`D=&AI<RT^;&]G*"1S<6PL(%!%05)?3$]'7T1%0E5'*3L*("`@
M("`@("`D9&5L971E0V]N=&5N=',@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<W%L
M*3L*("`@("`@("!I9B`H:7-?82@D9&5L971E0V]N=&5N=',L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@)'1H:7,M/FQO9R@D9&5L971E0V]N=&5N
M=',L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O(&1E;&5T92!61E,@<F5C
M=7)S:79E;'DZ("5S+B(I+"`D9&5L971E0V]N=&5N=',M/F=E=$UE<W-A9V4H
M*2DI.PH@("`@("`@('T*"B`@("`@("`@+RH@3F]W(&1E;&5T92!E=F5R>71H
M:6YG(&EN<VED92!T:&4@9F]L9&5R+B`J+PH@("`@("`@("1S<6P@/2!S<')I
M;G1F*"=$14Q%5$4@1E)/32`E<R!72$5212!V9G-?<&%T:"`E<R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@*&5M<'1Y*"1P871H*2`F)B`D=&AI<RT^
M7V1B+3YD8G-Y;G1A>"`]/2`G;V-I."<I(#\@)R!)4R!.54Q,)R`Z("<@/2`G
M("X@)'1H:7,M/E]D8BT^<75O=&4H)&9O;&1E<E!A=&@I*3L*("`@("`@("`D
M=&AI<RT^;&]G*"1S<6PL(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`D9&5L
M971E(#T@)'1H:7,M/E]D8BT^<75E<GDH)'-Q;"D["B`@("`@("`@:68@*&ES
M7V$H)&1E;&5T92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^;&]G*"1D96QE=&4L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB*2P@)&1E;&5T92T^9V5T365S<V%G
M92@I*2D["B`@("`@("`@?0H*("`@("`@("`O*B!!;&P@;VL@;F]W(&1E;&5T
M92!T:&4@86-T=6%L(&9O;&1E<B`J+PH@("`@("`@("1S<6P@/2!S<')I;G1F
M*"=$14Q%5$4@1E)/32`E<R!72$5212!V9G-?<&%T:"`E<R!!3D0@=F9S7VYA
M;64@/2`_)RP*("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M
M<ULG=&%B;&4G72P*("`@("`@("`@("`@("`@("`@("`@("`H96UP='DH)'!A
M=&@I("8F("1T:&ES+3Y?9&(M/F1B<WEN=&%X(#T]("=O8VDX)RD@/R`G($E3
M($Y53$PG(#H@)R`]("<@+B`D=&AI<RT^7V1B+3YQ=6]T92@D<&%T:"DI.PH@
M("`@("`@("1V86QU97,@/2!A<G)A>2@D;F%M92D["B`@("`@("`@)'1H:7,M
M/FQO9R@D<W%L+"!014%27TQ/1U]$14)51RD["B`@("`@("`@)&1E;&5T92`]
M("1T:&ES+3Y?9&(M/G%U97)Y*"1S<6PL("1V86QU97,I.PH@("`@("`@(&EF
M("AI<U]A*"1D96QE=&4L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M)'1H:7,M/FQO9R@D9&5L971E+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E5N86)L92!T
M;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N(BDL("1D96QE=&4M/F=E=$UE
M<W-A9V4H*2DI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1D96QE=&4[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@82!L:7-T(&]F('1H92!C
M;VYT96YT<R!O9B!A(&9O;&1E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1P871H("`@("`@(%1H92!D:7)E8W1O<GD@<&%T:"X*("`@("`J($!P
M87)A;2!M:7AE9"`D9FEL=&5R("`@("`@4W1R:6YG+VAA<V@@;V8@:71E;7,@
M=&\@9FEL=&5R(&)A<V5D(&]N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&9I;&5N86UE+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&1O=&9I
M;&5S("!3:&]W(&1O=&9I;&5S/PH@("`@("H@0'!A<F%M(&)O;VQE86X@)&1I
M<F]N;'D@("!3:&]W(&1I<F5C=&]R:65S(&]N;'D_"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@1FEL92!L:7-T(&]N('-U8V-E<W,@;W(@9F%L<V4@
M;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7VQI<W1&;VQD97(H
M)'!A=&@L("1F:6QT97(@/2!N=6QL+"`D9&]T9FEL97,@/2!T<G5E+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@)&1I<F]N;'D@/2!F86QS92D*("`@('L*
M("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF
M("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@("`@("1P871H(#T@)'1H:7,M
M/E]C;VYV97)T4&%T:"@D<&%T:"D["@H@("`@("`@("\O($9I>"!F;W(@3W)A
M8VQE(&YO="!D:69F97)E;G1I871I;F<@8F5T=V5E;B`G)R!A;F0@3E5,3"X*
M("`@("`@("!I9B`H96UP='DH)'!A=&@I("8F("1T:&ES+3Y?9&(M/F1B<WEN
M=&%X(#T]("=O8VDX)RD@>PH@("`@("`@("`@("`D=VAE<F4@/2`G=F9S7W!A
M=&@@25,@3E5,3"<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'=H
M97)E(#T@)W9F<U]P871H(#T@)R`N("1T:&ES+3Y?9&(M/G%U;W1E*"1P871H
M*3L*("`@("`@("!]"@H@("`@("`@("1L96YG=&A?;W`@/2`D=&AI<RT^7V=E
M=$9I;&53:7IE3W`H*3L*("`@("`@("`D<W%L(#T@<W!R:6YT9B@G4T5,14-4
M('9F<U]N86UE+"!V9G-?='EP92P@)7,H=F9S7V1A=&$I+"!V9G-?;6]D:69I
M960L('9F<U]O=VYE<B!&4D]-("5S(%=(15)%("5S)RP*("`@("`@("`@("`@
M("`@("`@("`@("`D;&5N9W1H7V]P+`H@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=T86)L92==+`H@("`@("`@("`@("`@("`@("`@
M("`@("1W:&5R92D["B`@("`@("`@)'1H:7,M/FQO9R@D<W%L+"!014%27TQ/
M1U]$14)51RD["B`@("`@("`@)&9I;&5,:7-T(#T@)'1H:7,M/E]D8BT^9V5T
M06QL*"1S<6PI.PH@("`@("`@(&EF("AI<U]A*"1F:6QE3&ES="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&9I;&5,:7-T.PH@("`@
M("`@('T*"B`@("`@("`@)&9I;&5S(#T@87)R87DH*3L*("`@("`@("!F;W)E
M86-H("@D9FEL94QI<W0@87,@)&QI;F4I('L*("`@("`@("`@("`@+R\@1FEL
M=&5R(&]U="!D;W1F:6QE<R!I9B!T:&5Y(&%R96XG="!W86YT960N"B`@("`@
M("`@("`@(&EF("@A)&1O=&9I;&5S("8F('-U8G-T<B@D;&EN95LP72P@,"P@
M,2D@/3T@)RXG*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)&9I;&5;)VYA;64G72`]("1L:6YE6S!=
M.PH*("`@("`@("`@("`@:68@*"1L:6YE6S%=(#T](%9&4U]&24Q%*2!["B`@
M("`@("`@("`@("`@("`D;F%M92`](&5X<&QO9&4H)RXG+"`D;&EN95LP72D[
M"@H@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1N86UE*2`]/2`Q*2!["B`@
M("`@("`@("`@("`@("`@("`@)&9I;&5;)W1Y<&4G72`]("<J*FYO;F4G.PH@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D
M9FEL95LG='EP92==(#T@5D93.CIS=')T;VQO=V5R*"1N86UE6V-O=6YT*"1N
M86UE*2`M(#%=*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@
M("`D9FEL95LG<VEZ92==(#T@)&QI;F5;,ET["B`@("`@("`@("`@('T@96QS
M96EF("@D;&EN95LQ72`]/2!61E-?1D],1$52*2!["B`@("`@("`@("`@("`@
M("`D9FEL95LG='EP92==(#T@)RHJ9&ER)SL*("`@("`@("`@("`@("`@("1F
M:6QE6R=S:7IE)UT@/2`M,3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M)&9I;&5;)V1A=&4G72`]("1L:6YE6S-=.PH@("`@("`@("`@("`D9FEL95LG
M;W=N97(G72`]("1L:6YE6S1=.PH@("`@("`@("`@("`D9FEL95LG<&5R;7,G
M72`]("<G.PH@("`@("`@("`@("`D9FEL95LG9W)O=7`G72`]("<G.PH*("`@
M("`@("`@("`@+R\@9FEL=&5R:6YG"B`@("`@("`@("`@(&EF("@D=&AI<RT^
M7V9I;'1E<DUA=&-H*"1F:6QT97(L("1F:6QE6R=N86UE)UTI*2!["B`@("`@
M("`@("`@("`@("!U;G-E="@D9FEL92D["B`@("`@("`@("`@("`@("!C;VYT
M:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&1I<F]N;'D@
M)B8@)&9I;&5;)W1Y<&4G72`A/3T@)RHJ9&ER)RD@>PH@("`@("`@("`@("`@
M("`@=6YS970H)&9I;&4I.PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1F:6QE<ULD9FEL95LG;F%M92==
M72`]("1F:6QE.PH@("`@("`@("`@("!U;G-E="@D9FEL92D["B`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D9FEL97,["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&$@<V]R=&5D(&QI<W0@;V8@9F]L9&5R<R!I;B!S<&5C:69I
M960@9&ER96-T;W)Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A
M=&@@("`@("`@("!4:&4@<&%T:"!O9B!T:&4@9&ER96-T;W)Y('1O(&=E="!T
M:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!D:7)E8W1O
M<GD@;&ES="!F;W(N"B`@("`@*B!`<&%R86T@;6EX960@)&9I;'1E<B`@("`@
M("`@4W1R:6YG+VAA<V@@;V8@:71E;7,@=&\@9FEL=&5R(&)A<V5D(&]N"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]L9&5R;&ES="X*
M("`@("`J($!P87)A;2!B;V]L96%N("1D;W1F;VQD97)S("!);F-L=61E(&1O
M=&9O;&1E<G,_"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@1F]L9&5R
M(&QI<W0@;VX@<W5C8V5S<R!O<B!014%27T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T1F]L9&5R<R@D<&%T:"`]
M("<G+"`D9FEL=&5R(#T@87)R87DH*2P@)&1O=&9O;&1E<G,@/2!T<G5E*0H@
M("`@>PH@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@
M("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@)'!A=&@@/2`D
M=&AI<RT^7V-O;G9E<G10871H*"1P871H*3L*"B`@("`@("`@)'-Q;"`@/2`G
M4T5,14-4('9F<U]N86UE+"!V9G-?<&%T:"!&4D]-("<@+B`D=&AI<RT^7W!A
M<F%M<ULG=&%B;&4G73L*("`@("`@("`D<W%L("X]("<@5TA%4D4@=F9S7W!A
M=&@@/2`_($%.1"!V9G-?='EP92`](#\G.PH@("`@("`@("1T:&ES+3YL;V<H
M)'-Q;"P@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`D=F%L=65S(#T@87)R
M87DH)'!A=&@L(%9&4U]&3TQ$15(I.PH*("`@("`@("`D9F]L9&5R3&ES="`]
M("1T:&ES+3Y?9&(M/F=E=$%L;"@D<W%L+"`D=F%L=65S*3L*("`@("`@("!I
M9B`H:7-?82@D9F]L9&5R3&ES="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)&9O;&1E<DQI<W0["B`@("`@("`@?0H*("`@("`@("`D
M9F]L9&5R<R`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)&9O;&1E<DQI
M<W0@87,@)&QI;F4I('L*("`@("`@("`@("`@)&9O;&1E<ELG=F%L)UT@/2`D
M=&AI<RT^7V=E=$YA=&EV95!A=&@H)&QI;F5;,5TL("1L:6YE6S!=*3L*("`@
M("`@("`@("`@)&9O;&1E<ELG86)B<F5V)UT@/2`G)SL*("`@("`@("`@("`@
M)&9O;&1E<ELG;&%B96PG72`]("<G.PH*("`@("`@("`@("`@)&-O=6YT(#T@
M<W5B<W1R7V-O=6YT*"1F;VQD97);)W9A;"==+"`G+R<I.PH*("`@("`@("`@
M("`@)'@@/2`P.PH@("`@("`@("`@("!W:&EL92`H)'@@/"`D8V]U;G0I('L*
M("`@("`@("`@("`@("`@("1F;VQD97);)V%B8G)E=B==("X]("<@("`@)SL*
M("`@("`@("`@("`@("`@("1F;VQD97);)VQA8F5L)UT@+CT@)R`@("`G.PH@
M("`@("`@("`@("`@("`@)'@K*SL*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@)&9O;&1E<ELG86)B<F5V)UT@+CT@)&QI;F5;,%T["B`@("`@("`@("`@
M("1F;VQD97);)VQA8F5L)UT@+CT@)&QI;F5;,%T["@H@("`@("`@("`@("`D
M<W1R;&5N(#T@5D93.CIS=')L96XH)&9O;&1E<ELG;&%B96PG72D["B`@("`@
M("`@("`@(&EF("@D<W1R;&5N(#X@,C8I('L*("`@("`@("`@("`@("`@("1F
M;VQD97);)V%B8G)E=B==(#T@<W5B<W1R*"1F;VQD97);)VQA8F5L)UTL(#`L
M("@D8V]U;G0@*B`T*2D["B`@("`@("`@("`@("`@("`D;&5N9W1H(#T@*#(Y
M("T@*"1C;W5N="`J(#0I*2`O(#(["B`@("`@("`@("`@("`@("`D9F]L9&5R
M6R=A8F)R978G72`N/2!S=6)S='(H)&9O;&1E<ELG;&%B96PG72P@*"1C;W5N
M="`J(#0I+"`D;&5N9W1H*3L*("`@("`@("`@("`@("`@("1F;VQD97);)V%B
M8G)E=B==("X]("<N+BXG.PH@("`@("`@("`@("`@("`@)&9O;&1E<ELG86)B
M<F5V)UT@+CT@<W5B<W1R*"1F;VQD97);)VQA8F5L)UTL("TQ("H@)&QE;F=T
M:"P@)&QE;F=T:"D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1F;W5N
M9"`](&9A;'-E.PH@("`@("`@("`@("!F;W)E86-H("@D9FEL=&5R(&%S("1F
M;'1R*2!["B`@("`@("`@("`@("`@("!I9B`H)&9O;&1E<ELG=F%L)UT@/3T@
M)&9L='(I('L*("`@("`@("`@("`@("`@("`@("`D9F]U;F0@/2!T<G5E.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!I
M9B`H(21F;W5N9"D@>PH@("`@("`@("`@("`@("`@)&9O;&1E<G-;)&9O;&1E
M<ELG=F%L)UU=(#T@)&9O;&1E<CL*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@:W-O<G0H)&9O;&1E<G,I.PH@("`@("`@(')E='5R;B`D9F]L
M9&5R<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E;F%M97,@86QL(&-H:6QD
M('!A=&AS+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H(&]F('1H92!F
M;VQD97(@=&\@<F5N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@
M5&AE(&9O;&1E<FYA;64@=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]R96-U<G-I=F52
M96YA;64H)&]L9'!A=&@L("1O;&1N86UE+"`D;F5W<&%T:"P@)&YE=VYA;64I
M"B`@("!["B`@("`@("`@)&]L9'!A=&@@/2`D=&AI<RT^7V-O;G9E<G10871H
M*"1O;&1P871H*3L*("`@("`@("`D;F5W<&%T:"`]("1T:&ES+3Y?8V]N=F5R
M=%!A=&@H)&YE=W!A=&@I.PH*("`@("`@("`D<W%L("`]("=314Q%0U0@=F9S
M7VYA;64@1E)/32`G("X@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT["B`@("`@
M("`@)'-Q;"`N/2`G(%=(15)%('9F<U]T>7!E(#T@/R!!3D0@=F9S7W!A=&@@
M/2`_)SL*("`@("`@("`D=&AI<RT^;&]G*"1S<6PL(%!%05)?3$]'7T1%0E5'
M*3L*"B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*%9&4U]&3TQ$15(L("1T:&ES
M+3Y?9V5T3F%T:79E4&%T:"@D;VQD<&%T:"P@)&]L9&YA;64I*3L*"B`@("`@
M("`@)&9O;&1E<DQI<W0@/2`D=&AI<RT^7V1B+3YG971#;VPH)'-Q;"P@,"P@
M)'9A;'5E<RD["@H@("`@("`@(&9O<F5A8V@@*"1F;VQD97),:7-T(&%S("1F
M;VQD97(I('L*("`@("`@("`@("`@)'1H:7,M/E]R96-U<G-I=F5296YA;64H
M)'1H:7,M/E]G971.871I=F50871H*"1O;&1P871H+"`D;VQD;F%M92DL("1F
M;VQD97(L("1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D;F5W<&%T:"P@)&YE=VYA
M;64I+"`D9F]L9&5R*3L*("`@("`@("!]"@H@("`@("`@("1S<6P@/2`G55!$
M051%("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`N("<@4T54('9F<U]P
M871H(#T@/R!72$5212!V9G-?<&%T:"`](#\G.PH@("`@("`@("1T:&ES+3YL
M;V<H)'-Q;"P@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`D=F%L=65S(#T@
M87)R87DH)'1H:7,M/E]G971.871I=F50871H*"1N97=P871H+"`D;F5W;F%M
M92DL("1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D;VQD<&%T:"P@)&]L9&YA;64I
M*3L*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1S<6PL
M("1V86QU97,I.PH*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;B!A(&9U;&P@9FEL96YA;64@;VX@=&AE(&YA
M=&EV92!F:6QE<WES=&5M+"!F<F]M(&$@5D93"B`@("`@*B!P871H(&%N9"!N
M86UE+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!61E,@9FEL92!P871H+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(%9&4R!F:6QE;F%M92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&9U;&P@;F%T:79E
M(&9I;&5N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T3F%T:79E4&%T
M:"@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1P871H
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&YA;64["B`@("`@("`@?0H*("`@
M("`@("!I9B`H(65M<'1Y*"1P871H*2D@>PH@("`@("`@("`@("!I9B`H:7-S
M970H)'1H:7,M/E]P87)A;7-;)VAO;64G72D@)B8*("`@("`@("`@("`@("`@
M('!R96=?;6%T8V@H)WQ>?B\_*"XJ*21\)RP@)'!A=&@L("1M871C:&5S*2D@
M>PH@("`@("`@("`@("`@("`@)'!A=&@@/2`D=&AI<RT^7W!A<F%M<ULG:&]M
M92==("X@)R\G("X@)&UA=&-H97-;,5T["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D<&%T:"`N("<O)R`N("1N86UE.PH@("`@
M?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@;W!E;B!A('!E<G-I<W1E
M;G0@8V]N;F5C=&EO;B!T;R!T:&4@4U%,('-E<G9E<BX*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N;F5C="@I"B`@("![
M"B`@("`@("`@:68@*"1T:&ES+3Y?9&(@/3T](&9A;'-E*2!["B`@("`@("`@
M("`@(&EF("@A:7-?87)R87DH)'1H:7,M/E]P87)A;7,I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB*2D[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1R97%U:7)E9"`](&%R<F%Y
M*"=P:'!T>7!E)RD["B`@("`@("`@("`@(&9O<F5A8V@@*"1R97%U:7)E9"!A
M<R`D=F%L*2!["B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?
M<&%R86US6R1V86Q=*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B4F5Q=6ER960@7"(E<UPB(&YO
M="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(BDL("1V86PI*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG9&%T86)A<V4G72DI('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=D871A8F%S92==(#T@)R<[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^
M7W!A<F%M<ULG=7-E<FYA;64G72DI('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=U<V5R;F%M92==(#T@)R<["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G
M72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=H;W-T<W!E
M8R==(#T@)R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%I<W-E
M="@D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DI('L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=T86)L92==(#T@)VAO<F1E7W9F<R<["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("\J($-O;FYE8W0@=&\@=&AE(%-13"!S
M97)V97(@=7-I;F<@=&AE('-U<'!L:65D('!A<F%M971E<G,N("HO"B`@("`@
M("`@("`@(')E<75I<F5?;VYC92`G1$(N<&AP)SL*("`@("`@("`@("`@)'1H
M:7,M/E]D8B`]("9$0CHZ8V]N;F5C="@D=&AI<RT^7W!A<F%M<RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<&5R<VES
M=&5N="<@/3X@(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=P97)S:7-T96YT)UTI
M*2D["B`@("`@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?9&(L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H)'1H:7,M/E]D
M8BP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@("`@("1E<G)O<B`]("1T
M:&ES+3Y?9&(["B`@("`@("`@("`@("`@("`D=&AI<RT^7V1B(#T@9F%L<V4[
M"B`@("`@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@("`@("!]
M"@H*("`@("`@("`@("`@+R\@4V5T($1"('!O<G1A8FEL:71Y(&]P=&EO;G,N
M"B`@("`@("`@("`@('-W:71C:"`H)'1H:7,M/E]D8BT^<&AP='EP92D@>PH@
M("`@("`@("`@("!C87-E("=M<W-Q;"<Z"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7V1B+3YS971/<'1I;VXH)W!O<G1A8FEL:71Y)RP@1$)?4$]25$%"24Q)
M5%E?3$]715)#05-%('P@1$)?4$]25$%"24Q)5%E?15)23U)3('P@1$)?4$]2
M5$%"24Q)5%E?4E1224TI.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`D=&AI<RT^7V1B+3YS
M971/<'1I;VXH)W!O<G1A8FEL:71Y)RP@1$)?4$]25$%"24Q)5%E?3$]715)#
M05-%('P@1$)?4$]25$%"24Q)5%E?15)23U)3*3L*("`@("`@("`@("`@?0H*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1&ES8V]N;F5C="!F<F]M('1H92!344P@<V5R=F5R(&%N9"!C
M;&5A;B!U<"!T:&4@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V1I<V-O;FYE8W0H*0H@
M("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V1B*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?9&(M/F1I<V-O;FYE8W0H*3L*("`@("`@("`@("`@)'1H:7,M/E]D
M8B`](&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%1/
M1$\*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1T86)L92`@("`@5$]$3PH@("`@("H@0'!A<F%M
M('-T<FEN9R`D9FEE;&0@("`@(%1/1$\*("`@("`J($!P87)A;2!S=')I;F<@
M)&-R:71E<FEA("!43T1/"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@
M5$]$3PH@("`@("HO"B`@("!F=6YC=&EO;B!?<F5A9$)L;V(H)'1A8FQE+"`D
M9FEE;&0L("1C<FET97)I82D*("`@('L*("`@("`@("!I9B`H(6-O=6YT*"1C
M<FET97)I82DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H)UEO=2!M=7-T('-P96-I9GD@=&AE(&9E=&-H(&-R:71E<FEA)RD["B`@
M("`@("`@?0H*("`@("`@("`D=VAE<F4@/2`G)SL*"B`@("`@("`@<W=I=&-H
M("@D=&AI<RT^7V1B+3YD8G-Y;G1A>"D@>PH@("`@("`@(&-A<V4@)V]C:3@G
M.@H@("`@("`@("`@("!F;W)E86-H("@D8W)I=&5R:6$@87,@)&ME>2`]/B`D
M=F%L=64I('L*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'=H97)E*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1W:&5R92`N/2`G($%.1"`G.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1V86QU
M92DI('L*("`@("`@("`@("`@("`@("`@("`D=VAE<F4@+CT@)&ME>2`N("<@
M25,@3E5,3"<["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1W:&5R92`N/2`D:V5Y("X@)R`]("<@+B`D=&AI<RT^7V1B
M+3YQ=6]T92@D=F%L=64I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`D<W1A=&5M96YT(#T@3T-)4&%R<V4H)'1H:7,M
M/E]D8BT^8V]N;F5C=&EO;BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('-P<FEN=&8H)U-%3$5#5"`E<R!&4D]-("5S(%=(15)%("5S)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9I
M96QD+"`D=&%B;&4L("1W:&5R92DI.PH@("`@("`@("`@("!/0TE%>&5C=71E
M*"1S=&%T96UE;G0I.PH@("`@("`@("`@("!I9B`H3T-)1F5T8VA);G1O*"1S
M=&%T96UE;G0L("1L;V(I*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@
M)&QO8ELP72T^;&]A9"@I.PH@("`@("`@("`@("`@("`@:68@*&ES7VYU;&PH
M)')E<W5L="DI('L*("`@("`@("`@("`@("`@("`@("`D<F5S=6QT(#T@4$5!
M4CHZ<F%I<V5%<G)O<B@G56YA8FQE('1O(&QO860@4U%,(&1A=&$N)RD["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D<F5S=6QT(#T@4$5!4CHZ<F%I<V5%<G)O<B@G56YA8FQE('1O
M(&QO860@4U%,(&1A=&$N)RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M3T-)1G)E95-T871E;65N="@D<W1A=&5M96YT*3L*("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(&9O<F5A8V@@*"1C
M<FET97)I82!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("`@("`@
M:68@*"%E;7!T>2@D=VAE<F4I*2!["B`@("`@("`@("`@("`@("`@("`@)'=H
M97)E("X]("<@04Y$("<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`D=VAE<F4@+CT@)&ME>2`N("<@/2`G("X@)'1H:7,M/E]D8BT^<75O
M=&4H)'9A;'5E*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'-Q;"`]
M('-P<FEN=&8H)U-%3$5#5"`E<R!&4D]-("5S(%=(15)%("5S)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&9I96QD+"`D=&%B;&4L("1W:&5R92D[
M"B`@("`@("`@("`@("1T:&ES+3YL;V<H)'-Q;"P@4$5!4E],3T=?1$5"54<I
M.PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^9V5T3VYE*"1S
M<6PI.PH*("`@("`@("`@("`@:68@*&ES7VYU;&PH)')E<W5L="DI('L*("`@
M("`@("`@("`@("`@("1R97-U;'0@/2!014%2.CIR86ES945R<F]R*"=5;F%B
M;&4@=&\@;&]A9"!344P@9&%T82XG*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@('-W:71C:"`H)'1H:7,M/E]D8BT^9&)S>6YT87@I
M('L*("`@("`@("`@("`@("`@(&-A<V4@)W!G<W%L)SH*("`@("`@("`@("`@
M("`@("`@("`D<F5S=6QT(#T@<&%C:R@G2"<@+B!S=')L96XH)')E<W5L="DL
M("1R97-U;'0I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O*BH*("`@("`J(%1/1$\*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1T86)L92`@("`@("!43T1/"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1F:65L9"`@("`@("!43T1/"B`@("`@*B!`<&%R86T@<W1R:6YG("1D
M871A("`@("`@("!43T1/"B`@("`@*B!`<&%R86T@<W1R:6YG("1A='1R:6)U
M=&5S("!43T1/"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5$]$3PH@
M("`@("HO"B`@("!F=6YC=&EO;B!?:6YS97)T0FQO8B@D=&%B;&4L("1F:65L
M9"P@)&1A=&$L("1A='1R:6)U=&5S*0H@("`@>PH@("`@("`@("1F:65L9',@
M/2!A<G)A>2@I.PH@("`@("`@("1V86QU97,@/2!A<G)A>2@I.PH*("`@("`@
M("!S=VET8V@@*"1T:&ES+3Y?9&(M/F1B<WEN=&%X*2!["B`@("`@("`@8V%S
M92`G;V-I."<Z"B`@("`@("`@("`@(&9O<F5A8V@@*"1A='1R:6)U=&5S(&%S
M("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("`@("`D9FEE;&1S6UT@
M/2`D:V5Y.PH@("`@("`@("`@("`@("`@)'9A;'5E<UM=(#T@)'1H:7,M/E]D
M8BT^<75O=&53;6%R="@D=F%L=64I.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`D<W1A=&5M96YT(#T@3T-)4&%R<V4H)'1H:7,M/E]D8BT^8V]N;F5C
M=&EO;BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-P<FEN
M=&8H)TE.4T525"!)3E1/("5S("@E<RP@)7,I)R`N"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("<@5D%,5453("@E<RP@14U0
M5%E?0DQ/0B@I*2!215154DY)3D<@)7,@24Y43R`Z8FQO8B<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T86)L92P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:6UP;&]D
M92@G+"`G+"`D9FEE;&1S*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&9I96QD+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I;7!L;V1E*"<L("<L("1V86QU97,I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9FEE
M;&0I*3L*"B`@("`@("`@("`@("1L;V(@/2!/0TE.97=$97-C<FEP=&]R*"1T
M:&ES+3Y?9&(M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@("!/0TE":6YD0GE.
M86UE*"1S=&%T96UE;G0L("<Z8FQO8B<L("1L;V(L("TQ+"!344Q47T),3T(I
M.PH@("`@("`@("`@("!/0TE%>&5C=71E*"1S=&%T96UE;G0L($]#25]$149!
M54Q4*3L*("`@("`@("`@("`@)&QO8BT^<V%V92@D9&%T82D["B`@("`@("`@
M("`@("1R97-U;'0@/2!/0TE#;VUM:70H)'1H:7,M/E]D8BT^8V]N;F5C=&EO
M;BD["B`@("`@("`@("`@("1L;V(M/F9R964H*3L*("`@("`@("`@("`@3T-)
M1G)E95-T871E;65N="@D<W1A=&5M96YT*3L*("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0@/R!T<G5E(#H@4$5!4CHZ<F%I<V5%<G)O<B@G56YK;F]W;B!%
M<G)O<B<I.PH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("!F;W)E86-H
M("@D871T<FEB=71E<R!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@
M("`@("`@)&9I96QD<UM=(#T@)&ME>3L*("`@("`@("`@("`@("`@("1V86QU
M97-;72`]("1V86QU93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'%U
M97)Y(#T@<W!R:6YT9B@G24Y315)4($E.5$\@)7,@*"5S+"`E<RD@5D%,5453
M("@E<RDG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T86)L92P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I;7!L;V1E*"<L("<L("1F
M:65L9',I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F:65L9"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G/R<@+B!S=')?<F5P96%T
M*"<L(#\G+"!C;W5N="@D=F%L=65S*2DI.PH@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("!]"@H@("`@("`@('-W:71C:"`H)'1H:7,M/E]D8BT^9&)S>6YT
M87@I('L*("`@("`@("!C87-E("=M<W-Q;"<Z"B`@("`@("`@8V%S92`G<&=S
M<6PG.@H@("`@("`@("`@("`D=F%L=65S6UT@/2!B:6XR:&5X*"1D871A*3L*
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@
M("`@("1V86QU97-;72`]("1D871A.PH@("`@("`@('T*"B`@("`@("`@+RH@
M17AE8W5T92!T:&4@<75E<GDN("HO"B`@("`@("`@)'1H:7,M/FQO9R@D<75E
M<GDL(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("!R971U<FX@)'1H:7,M/E]D
M8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%1/1$\*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1T86)L92`@("`@(%1/1$\*("`@("`J
M($!P87)A;2!S=')I;F<@)&9I96QD("`@("`@5$]$3PH@("`@("H@0'!A<F%M
M('-T<FEN9R`D9&%T82`@("`@("!43T1/"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1W:&5R92`@("`@(%1/1$\*("`@("`J($!P87)A;2!A<G)A>2`D86QS;W5P
M9&%T92`@5$]$3PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1/1$\*
M("`@("`J+PH@("`@9G5N8W1I;VX@7W5P9&%T94)L;V(H)'1A8FQE+"`D9FEE
M;&0L("1D871A+"`D=VAE<F4L("1A;'-O=7!D871E*0H@("`@>PH@("`@("`@
M("1F:65L9',@/2!A<G)A>2@I.PH@("`@("`@("1V86QU97,@/2!A<G)A>2@I
M.PH*("`@("`@("!S=VET8V@@*"1T:&ES+3Y?9&(M/F1B<WEN=&%X*2!["B`@
M("`@("`@8V%S92`G;V-I."<Z"B`@("`@("`@("`@("1W:&5R97-T<FEN9R`]
M("<G.PH@("`@("`@("`@("!F;W)E86-H("@D=VAE<F4@87,@)&ME>2`]/B`D
M=F%L=64I('L*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'=H97)E<W1R
M:6YG*2D@>PH@("`@("`@("`@("`@("`@("`@("1W:&5R97-T<FEN9R`N/2`G
M($%.1"`G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'=H
M97)E<W1R:6YG("X]("1K97D@+B`G(#T@)R`N("1T:&ES+3Y?9&(M/G%U;W1E
M*"1V86QU92D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1S=&%T96UE
M;G0@/2!/0TE087)S92@D=&AI<RT^7V1B+3YC;VYN96-T:6]N+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@<W!R:6YT9B@G4T5,14-4("5S
M($923TT@)7,@5TA%4D4@)7,@1D]2(%501$%412<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F:65L9"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1A8FQE+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=VAE<F5S
M=')I;F<I*3L*"B`@("`@("`@("`@($]#245X96-U=&4H)'-T871E;65N="P@
M3T-)7T1%1D%53%0I.PH@("`@("`@("`@("!/0TE&971C:$EN=&\H)'-T871E
M;65N="P@)&QO8BD["B`@("`@("`@("`@("1L;V);,%TM/G-A=F4H)&1A=&$I
M.PH@("`@("`@("`@("`D<F5S=6QT(#T@3T-)0V]M;6ET*"1T:&ES+3Y?9&(M
M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@("`D;&]B6S!=+3YF<F5E*"D["B`@
M("`@("`@("`@($]#249R9653=&%T96UE;G0H)'-T871E;65N="D["B`@("`@
M("`@("`@(')E='5R;B`D<F5S=6QT(#\@=')U92`Z(%!%05(Z.G)A:7-E17)R
M;W(H)U5N:VYO=VX@17)R;W(G*3L*"B`@("`@("`@9&5F875L=#H*("`@("`@
M("`@("`@)'5P9&%T97-T<FEN9R`]("<G.PH@("`@("`@("`@("`D=F%L=65S
M(#T@87)R87DH*3L*("`@("`@("`@("`@9F]R96%C:"`H)&%L<V]U<&1A=&4@
M87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@("`@("1U<&1A=&5S
M=')I;F<@+CT@)&ME>2`N("<@/2`_+"`G.PH@("`@("`@("`@("`@("`@)'9A
M;'5E<UM=(#T@)'9A;'5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1U
M<&1A=&5S=')I;F<@+CT@)&9I96QD("X@)R`](#\G.PH@("`@("`@("`@("!S
M=VET8V@@*"1T:&ES+3Y?9&(M/F1B<WEN=&%X*2!["B`@("`@("`@("`@(&-A
M<V4@)VUS<W%L)SH*("`@("`@("`@("`@8V%S92`G<&=S<6PG.@H@("`@("`@
M("`@("`@("`@)'9A;'5E<UM=(#T@8FEN,FAE>"@D9&%T82D["B`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@
M("`@("`@("`D=F%L=65S6UT@/2`D9&%T83L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@)'=H97)E<W1R:6YG(#T@)R<["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1W:&5R92!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("`@
M("`@:68@*"%E;7!T>2@D=VAE<F5S=')I;F<I*2!["B`@("`@("`@("`@("`@
M("`@("`@)'=H97)E<W1R:6YG("X]("<@04Y$("<["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`D=VAE<F5S=')I;F<@+CT@)&ME>2`N("<@
M/2`_)SL*("`@("`@("`@("`@("`@("1V86QU97-;72`]("1V86QU93L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G55!$
M051%("5S(%-%5"`E<R!72$5212`E<R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1A8FQE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1U<&1A=&5S=')I;F<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'=H97)E<W1R:6YG*3L*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H*
M("`@("`@("`O*B!%>&5C=71E('1H92!Q=65R>2X@*B\*("`@("`@("`D=&AI
M<RT^;&]G*"1Q=65R>2P@4$5!4E],3T=?1$5"54<I.PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0V]N=F5R="!T:&4@<&%T:&YA;64@9G)O;2!R96=U
M;&%R(&9I;&5S>7-T96T@9F]R;2!T;R!T:&4@:6YT97)N86P*("`@("`J(&9O
M<FUA="!N965D960@=&\@86-C97-S('1H92!F:6QE(&EN('1H92!D871A8F%S
M92X*("`@("`J($YA;65L>2P@=V4@=VEL;"!T<F5A="`G+R<@87,@82!B87-E
M(&1I<F5C=&]R>2!A<R!T:&ES(&ES('!R971T>2!M=6-H"B`@("`@*B!T:&4@
M<W1A;F1A<F0@=V%Y('1O(&%C8V5S<R!B87-E(&1I<F5C=&]R:65S(&]V97(@
M;6]S="!F:6QE<WES=&5M<RX*?2`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!!(%9&4R!P
M871H+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<&%T:"!W
M:71H(&%N>2!B96=I;FYI;F<@<VQA<V@@<W1R:7!P960@;V9F+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?8V]N=F5R=%!A=&@H)'!A=&@I"B`@("!["B`@("`@
M("`@:68@*"%E;7!T>2@D<&%T:"D@)B8@*'-T<G!O<R@D<&%T:"P@)R\G*2`]
M/3T@,"DI('L*("`@("`@("`@("`@)'!A=&@@/2!S=')V86PH<W5B<W1R*"1P
M871H+"`Q*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'!A=&@["B`@
M("!]"@H@("`@9G5N8W1I;VX@7V=E=$9I;&53:7IE3W`H*0H@("`@>PH@("`@
M("`@('-W:71C:"`H)'1H:7,M/E]D8BT^9&)S>6YT87@I('L*("`@("`@("!C
M87-E("=M>7-Q;"<Z"B`@("`@("`@("`@(')E='5R;B`G3$5.1U1()SL*"B`@
M("`@("`@8V%S92`G;V-I."<Z"B`@("`@("`@("`@(')E='5R;B`G3$5.1U1(
M0B<["@H@("`@("`@(&-A<V4@)VUS<W%L)SH*("`@("`@("!C87-E("=S>6)A
M<V4G.@H@("`@("`@("`@("!R971U<FX@)T1!5$%,14Y'5$@G.PH*("`@("`@
M("!C87-E("=P9W-Q;"<Z"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@
M<F5T=7)N("=/0U1%5%],14Y'5$@G.PH@("`@("`@('T*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+U9&4R]M=7-Q;"YP:'``````````````````````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#0S-C(W(#$P-3$U-#,S-S,U(#`R,#8S,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`H*
M<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]S<6PN<&AP)SL*
M"B\J*@H@*B!097)M:7-S:6]N(&9O<B!R96%D(&%C8V5S<RX*("HO"F1E9FEN
M92@G5D937T9,04=?4D5!1"<L(#$I.PH*+RHJ"B`J(%!E<FUI<W-I;VX@9F]R
M(')E860@86-C97-S+@H@*B\*9&5F:6YE*"=61E-?1DQ!1U]74DE412<L(#(I
M.PH*+RHJ"B`J($UU;'1I(%5S97(@5D93(&EM<&QE;65N=&%T:6]N(&9O<B!0
M2%`G<R!014%2(&1A=&%B87-E"B`J(&%B<W1R86-T:6]N(&QA>65R+@H@*@H@
M*B!297%U:7)E9"!V86QU97,@9F]R("1P87)A;7,Z/'!R93X*("H@("`@("`G
M<&AP='EP92<@("`@("`@5&AE(&1A=&%B87-E('1Y<&4@*&EE+B`G<&=S<6PG
M+"`G;7ES<6PG+"!E=&,N*2X\+W!R93X*("H*("H@3W!T:6]N86P@=F%L=65S
M.CQP<F4^"B`J("`@("`@)W1A8FQE)R`@("`@("`@(%1H92!N86UE(&]F('1H
M92!V9G,@=&%B;&4@:6X@)V1A=&%B87-E)RX@1&5F875L=',@=&\*("H@("`@
M("`@("`@("`@("`@("`@("`@)VAO<F1E7VUU=F9S)RX\+W!R93X*("H*("H@
M4F5Q=6ER960@8GD@<V]M92!D871A8F%S92!I;7!L96UE;G1A=&EO;G,Z/'!R
M93X*("H@("`@("`G:&]S='-P96,G("`@("`@5&AE(&AO<W1N86UE(&]F('1H
M92!D871A8F%S92!S97)V97(N"B`J("`@("`@)W!R;W1O8V]L)R`@("`@(%1H
M92!C;VUM=6YI8V%T:6]N('!R;W1O8V]L("@G=&-P)RP@)W5N:7@G+"!E=&,N
M*2X*("H@("`@("`G9&%T86)A<V4G("`@("`@5&AE(&YA;64@;V8@=&AE(&1A
M=&%B87-E+@H@*B`@("`@("=U<V5R;F%M92<@("`@("!4:&4@=7-E<FYA;64@
M=VET:"!W:&EC:"!T;R!C;VYN96-T('1O('1H92!D871A8F%S92X*("H@("`@
M("`G<&%S<W=O<F0G("`@("`@5&AE('!A<W-W;W)D(&%S<V]C:6%T960@=VET
M:"`G=7-E<FYA;64G+@H@*B`@("`@("=O<'1I;VYS)R`@("`@("!!9&1I=&EO
M;F%L(&]P=&EO;G,@=&\@<&%S<R!T;R!T:&4@9&%T86)A<V4N"B`J("`@("`@
M)W1T>2<@("`@("`@("`@(%1H92!45%D@;VX@=VAI8V@@=&\@8V]N;F5C="!T
M;R!T:&4@9&%T86)A<V4N"B`J("`@("`@)W!O<G0G("`@("`@("`@(%1H92!P
M;W)T(&]N('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+CPO<')E
M/@H@*@H@*B!+;F]W;B!)<W-U97,Z"B`J($1E;&5T92!I<R!N;W0@<F5C=7-I
M=F4L('-O(&9I;&5S(&%N9"!F;VQD97)S('1H870@=7-E9"!T;R!B92!I;B!A
M(&9O;&1E<@H@*B!T:&%T(&=E=',@9&5L971E9"!L:79E(&9O<F5V97(@:6X@
M=&AE(&1A=&%B87-E+"!O<B!R92UA<'!E87(@=VAE;B!T:&4@9F]L9&5R"B`J
M(&ES(')E8W)E871E9"X*("H@4F5N86UE(&AA<R!T:&4@<V%M92!I<W-U92P@
M<V\@9FEL97,@87)E(&QO<W0@:68@82!F;VQD97(@:7,@<F5N86UE9"X*("H*
M("H@5&AE('1A8FQE('-T<G5C='5R92!F;W(@=&AE(%9&4R!C86X@8F4@9F]U
M;F0@:6X*("H@9&%T82]M=79F<RYS<6PN"B`J"B`J($1A=&%B87-E('-P96-I
M9FEC(&YO=&5S.@H@*@H@*B!-4U-13#H*("H@+2!4:&4@=F9S7V1A=&$@9FEE
M;&0@;75S="!B92!O9B!T>7!E($E-04=%+@H@*B`M(%EO=2!N965D('1H92!F
M;VQL;W=I;F<@<&AP+FEN:2!S971T:6YG<SH*("H@/&-O9&4^"B`J("`@(#L@
M5F%L:60@<F%N9V4@,"`M(#(Q-#<T.#,V-#<N($1E9F%U;'0@/2`T,#DV+@H@
M*B`@("!M<W-Q;"YT97AT;&EM:70@/2`P(#L@>F5R;R!T;R!P87-S('1H<F]U
M9V@*("H*("H@("`@.R!686QI9"!R86YG92`P("T@,C$T-S0X,S8T-RX@1&5F
M875L="`](#0P.38N"B`J("`@(&US<W%L+G1E>'1S:7IE(#T@,"`[('IE<F\@
M=&\@<&%S<R!T:')O=6=H"B`J(#PO8V]D93X*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`L=B`Q+C,P+C0N,38@,C`P-B\P-2\S
M,2`P-#HU,#HP,B!S;'5S87)Z($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R
M+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@36EK92!#;V-H<F%N92`\;6EK94!G
M<F%F=&]N:&%L;"YC;RYN>CX*("H@0'!A8VMA9V4@5D93"B`J+PIC;&%S<R!6
M1E-?;75S<6P@97AT96YD<R!61E-?<W%L('L*"B`@("`O*BH*("`@("`J($QI
M<W0@;V8@<&5R;6ES<VEO;G,@86YD(&EF('1H97D@8V%N(&)E(&-H86YG960@
M:6X@=&AI<R!61E,*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*
M("`@('9A<B`D7W!E<FUI<W-I;VYS(#T@87)R87DH"B`@("`@("`@)V]W;F5R
M)R`]/B!A<G)A>2@G<F5A9"<@/3X@9F%L<V4L("=W<FET92<@/3X@9F%L<V4L
M("=E>&5C=71E)R`]/B!F86QS92DL"B`@("`@("`@)V=R;W5P)R`]/B!A<G)A
M>2@G<F5A9"<@/3X@9F%L<V4L("=W<FET92<@/3X@9F%L<V4L("=E>&5C=71E
M)R`]/B!F86QS92DL"B`@("`@("`@)V%L;"<@("`]/B!A<G)A>2@G<F5A9"<@
M/3X@=')U92P@("=W<FET92<@/3X@=')U92P@("=E>&5C=71E)R`]/B!F86QS
M92D*("`@("D["@H@("`@+RHJ"B`@("`@*B!3=&]R92!A(&9I;&4@:6X@=&AE
M(%9&4R!F<F]M(')A=R!D871A+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'!A=&@@("`@("`@("!4:&4@<&%T:"!T;R!S=&]R92!T:&4@9FEL92!I
M;BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@("`@("!4:&4@9FEL
M96YA;64@=&\@=7-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&%T82`@("`@
M("`@(%1H92!F:6QE(&1A=&$N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D875T
M;V-R96%T92`@075T;VUA=&EC86QL>2!C<F5A=&4@9&ER96-T;W)I97,_"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R
M(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@=W)I=&5$871A*"1P871H+"`D;F%M92P@)&1A=&$L("1A=71O
M8W)E871E(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI<RT^
M7V-O;FYE8W0H*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8V]N;BDI
M('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@
M("`@+RH@36%K92!S=7)E('=E(&AA=F4@=W)I=&4@86-C97-S('1O('1H:7,@
M86YD(&%L;"!P87)E;G0*("`@("`@("`@*B!P871H<RX@*B\*("`@("`@("!I
M9B`H)'!A=&@@(3T@)R<I('L*("`@("`@("`@("`@)'!A=&AS(#T@97AP;&]D
M92@G+R<L("1P871H*3L*("`@("`@("`@("`@)'!A=&A?;F%M92`](&%R<F%Y
M7W!O<"@D<&%T:',I.PH@("`@("`@("`@("!I9B`H(21T:&ES+3YI<T9O;&1E
M<BAI;7!L;V1E*"<O)RP@)'!A=&AS*2P@)'!A=&A?;F%M92DI('L*("`@("`@
M("`@("`@("`@(&EF("@A)&%U=&]C<F5A=&4I('L*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D9O;&1E
M<B`E<R!D;V5S(&YO="!E>&ES="(I+"`D<&%T:"DL("=H;W)D92YE<G)O<B<I
M.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`D<F5S=6QT(#T@)'1H:7,M/F%U=&]C<F5A=&50871H*"1P871H*3L*("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D<&%T:'-;72`]("1P871H7VYA;64[
M"B`@("`@("`@("`@("1P<F5V:6]U<R`]("<G.PH*("`@("`@("`@("`@9F]R
M96%C:"`H)'!A=&AS(&%S("1T:&ES<&%T:"D@>PH@("`@("`@("`@("`@("`@
M)')E<W5L=',@/2`D=&AI<RT^7V1B+3YG971!;&PH<W!R:6YT9B@G4T5,14-4
M('9F<U]O=VYE<BP@=F9S7W!E<FUS($923TT@)7,*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%=(15)%
M('9F<U]P871H(#T@/R!!3D0@=F9S7VYA;64](#\G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG=&%B;&4G72DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@D<')E=FEO=7,L("1T:&ES
M<&%T:"DI.PH@("`@("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D<F5S=6QT
M<RD@?'P@8V]U;G0H)')E<W5L=',I(#P@,2D@>PH@("`@("`@("`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!C<F5A
M=&4@5D93(&9I;&4N(BDI.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@("`@("1A;&QO=V5D(#T@9F%L<V4["B`@("`@("`@("`@("`@("!F;W)E
M86-H("@D<F5S=6QT<R!A<R`D<F5S=6QT*2!["B`@("`@("`@("`@("`@("`@
M("`@:68@*"1R97-U;'1;,%T@/3T@)'1H:7,M/E]P87)A;7-;)W5S97(G72!\
M?"`D<F5S=6QT6S%=("8@5D937T9,04=?5U))5$4I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&%L;&]W960@/2!T<G5E.PH@("`@("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*"$D86QL;W=E9"D@>PH@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(BDI.PH@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1P<F5V:6]U<R`]("1T:&ES
M<&%T:#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M('!A<F5N=#HZ=W)I=&5$871A*"1P871H+"`D;F%M92P@)&1A=&$L("1A=71O
M8W)E871E*3L*("`@('T*"B`@("`O*BH*("`@("`J($1E;&5T92!A(&9I;&4@
M9G)O;2!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A
M=&@@(%1H92!P871H('1O('-T;W)E('1H92!F:6QE(&EN+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;F%M92`@5&AE(&9I;&5N86UE('1O('5S92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!0
M14%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!D96QE=&5&:6QE*"1P871H+"`D;F%M92D*("`@('L*("`@("`@("`D
M8V]N;B`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1C;VYN*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX["B`@
M("`@("`@?0H*("`@("`@("`D9FEL94QI<W0@/2`D=&AI<RT^7V1B+3YG971!
M;&PH<W!R:6YT9B@G4T5,14-4('9F<U]I9"P@=F9S7V]W;F5R+"!V9G-?<&5R
M;7,@1E)/32`E<PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!72$5212!V9G-?<&%T:"`](#\@04Y$('9F<U]N86UE
M/2`_($%.1"!V9G-?='EP92`](#\G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L
M92==*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH)'!A=&@L("1N86UE+"!61E-?1DE,12DI.PH*("`@("`@("!I9B`H
M(6ES7V%R<F%Y*"1F:6QE3&ES="D@?'P@8V]U;G0H)&9I;&5,:7-T*2`\(#$I
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA
M8FQE('1O(&1E;&5T92!61E,@9FEL92XB*2D["B`@("`@("`@?0H*("`@("`@
M("`O*B!4:&5R92!M87D@8F4@;VYE(&]R(&UO<F4@9FEL97,@=VET:"!T:&4@
M<V%M92!N86UE(&)U="!T:&4*("`@("`@("`@("!U<V5R(&UA>2!N;W0@:&%V
M92!R96%D(&%C8V5S<R!T;R!T:&5M+"!S;R!D;V5S;B=T('-E90H@("`@("`@
M("`@('1H96TN(%-O('=E(&AA=F4@=&\@9&5L971E('1H92!O;F4@=&AE>2!H
M879E(&%C8V5S<R!T;RX@*B\*("`@("`@("!F;W)E86-H("@D9FEL94QI<W0@
M87,@)&9I;&4I('L*("`@("`@("`@("`@:68@*"1F:6QE6S%=(#T]("1T:&ES
M+3Y?<&%R86US6R=U<V5R)UT@?'P@)&9I;&5;,ET@)B!61E-?1DQ!1U]74DE4
M12D@>PH@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U
M97)Y*'-P<FEN=&8H)T1%3$5412!&4D]-("5S(%=(15)%('9F<U]I9"`](#\G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1F:6QE
M6S!=*2D["@H@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?9&(M/F%F9F5C
M=&5D4F]W<R@I(#T](#`I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE
M+B(I*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O
M+R!&25A-13H@)T%C8V5S<R!$96YI960@9&5L971I;F<@9FEL92`E<R\E<R<*
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE+B(I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M;F%M92!A(&9I;&4@;W(@9F]L9&5R(&EN('1H92!61E,N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;VQD<&%T:"`@5&AE(&]L9"!P871H('1O('1H
M92!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;VQD;F%M92`@5&AE(&]L
M9"!F:6QE;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@)&YE=W!A=&@@(%1H
M92!N97<@<&%T:"!O9B!T:&4@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@
M)&YE=VYA;64@(%1H92!N97<@9FEL96YA;64N"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N86UE
M*"1O;&1P871H+"`D;VQD;F%M92P@)&YE=W!A=&@L("1N97=N86UE*0H@("`@
M>PH@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)&-O;FXI*2!["B`@("`@("`@("`@(')E='5R
M;B`D8V]N;CL*("`@("`@("!]"@H@("`@("`@("1F:6QE3&ES="`]("1T:&ES
M+3Y?9&(M/F=E=$%L;"AS<')I;G1F*"=314Q%0U0@=F9S7VED+"!V9G-?;W=N
M97(L('9F<U]P97)M<R!&4D]-("5S"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!72$5212!V9G-?<&%T
M:"`](#\@04Y$('9F<U]N86UE/2`_)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=T86)L92==*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@87)R87DH)&]L9'!A=&@L("1O;&1N86UE*2D["@H@("`@("`@
M(&EF("@A:7-?87)R87DH)&9I;&5,:7-T*2!\?"!C;W5N="@D9FEL94QI<W0I
M(#P@,2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?
M*")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(I*3L*("`@("`@("!]"@H@
M("`@("`@(&EF("AS=')P;W,H)&YE=W!A=&@L("<O)RD@/3T](&9A;'-E*2![
M"B`@("`@("`@("`@("1P87)E;G0@/2`G)SL*("`@("`@("`@("`@)'!A=&@@
M/2`D;F5W<&%T:#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!L:7-T
M*"1P87)E;G0L("1P871H*2`](&5X<&QO9&4H)R\G+"`D;F5W<&%T:"P@,BD[
M"B`@("`@("`@?0H@("`@("`@(&EF("@A)'1H:7,M/FES1F]L9&5R*"1P87)E
M;G0L("1P871H*2D@>PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT(#T@
M)'1H:7,M/F%U=&]C<F5A=&50871H*"1N97=P871H*2P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("\J(%1H97)E(&UA>2!B92!O;F4@
M;W(@;6]R92!F:6QE<R!W:71H('1H92!S86UE(&YA;64@8G5T('1H92!U<V5R
M(&UA>0H@("`@("`@("`J(&YO="!H879E(')E860@86-C97-S('1O('1H96TL
M('-O(&1O97-N)W0@<V5E('1H96TN(%-O('=E(&AA=F4@=&\*("`@("`@("`@
M*B!R96YA;64@=&AE(&]N92!T:&5Y(&AA=F4@86-C97-S('1O+B`J+PH@("`@
M("`@(&9O<F5A8V@@*"1F:6QE3&ES="!A<R`D9FEL92D@>PH@("`@("`@("`@
M("!I9B`H)&9I;&5;,5T@/3T@)'1H:7,M/E]P87)A;7-;)W5S97(G72!\?"`D
M9FEL95LR72`F(%9&4U]&3$%'7U=2251%*2!["B`@("`@("`@("`@("`@("`D
M<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH<W!R:6YT9B@G55!$051%("5S
M(%-%5"!V9G-?<&%T:"`](#\L('9F<U]N86UE(#T@/RP@=F9S7VUO9&EF:65D
M(#T@/PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@5TA%4D4@=F9S7VED(#T@/R<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG=&%B;&4G72DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@87)R87DH)&YE=W!A=&@L("1N97=N86UE+"!T
M:6UE*"DL("1F:6QE6S!=*2D["B`@("`@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@<F5N86UE
M(%9&4R!F:6QE("5S+R5S+B(I+"`D;VQD<&%T:"P@)&]L9&YA;64I*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($-R96%T97,@82!F;VQD97(@;VX@=&AE(%9&
M4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!(;VQD<R!T
M:&4@<&%T:"!O9B!D:7)E8W1O<GD@=&\@8W)E871E(&9O;&1E<BX*("`@("`J
M($!P87)A;2!S=')I;F<@)&YA;64@($AO;&1S('1H92!N86UE(&]F('1H92!N
M97<@9F]L9&5R+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@
M;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&-R96%T949O;&1E<B@D<&%T:"P@)&YA
M;64I"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8V]N;BDI('L*("`@("`@("`@
M("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@+RH@;6%K92!S
M=7)E('=E(&AA=F4@=W)I=&4@86-C97-S('1O('1H:7,@86YD(&%L;"!P87)E
M;G0@<&%T:',@*B\*("`@("`@("!I9B`H)'!A=&@@(3T@(B(I('L*("`@("`@
M("`@("`@)'!A=&AS(#T@97AP;&]D92@G+R<L("1P871H*3L*("`@("`@("`@
M("`@)'!R979I;W5S(#T@)R<["@H@("`@("`@("`@("!F;W)E86-H("@D<&%T
M:',@87,@)'1H:7-P871H*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT<R`]
M("1T:&ES+3Y?9&(M/F=E=$%L;"AS<')I;G1F*"=314Q%0U0@=F9S7V]W;F5R
M+"!V9G-?<&5R;7,@1E)/32`E<PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!72$5212!V
M9G-?<&%T:"`](#\@04Y$('9F<U]N86UE/2`_)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)'!R979I;W5S
M+"`D=&AI<W!A=&@I*3L*("`@("`@("`@("`@("`@(&EF("@A:7-?87)R87DH
M)')E<W5L=',I('Q\(&-O=6YT*"1R97-U;'1S*2`\(#$I('L*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@
M=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(BDI.PH@("`@("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@("`@("1A;&QO=V5D(#T@9F%L<V4["B`@("`@("`@
M("`@("`@("!F;W)E86-H("@D<F5S=6QT<R!A<R`D<F5S=6QT*2!["B`@("`@
M("`@("`@("`@("`@("`@:68@*"1R97-U;'1;,%T@/3T@)'1H:7,M/E]P87)A
M;7-;)W5S97(G72!\?"`D<F5S=6QT6S%=("8@5D937T9,04=?5U))5$4I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&%L;&]W960@/2!T<G5E.PH@("`@
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*"$D
M86QL;W=E9"D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C
M=&]R>2XB*2D["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@
M)'!R979I;W5S(#T@)'1H:7-P871H.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("`D:60@/2`D=&AI<RT^7V1B+3YN97AT260H)'1H:7,M/E]P
M87)A;7-;)W1A8FQE)UTI.PH@("`@("`@(')E='5R;B`D=&AI<RT^7V1B+3YQ
M=65R>2AS<')I;G1F*"=)3E-%4E0@24Y43R`E<R`H=F9S7VED+"!V9G-?='EP
M92P@=F9S7W!A=&@L('9F<U]N86UE+"!V9G-?;6]D:69I960L('9F<U]O=VYE
M<BP@=F9S7W!E<FUS*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%9!3%5%4R`H/RP@/RP@/RP@/RP@/RP@/RP@/RDG+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=T86)L92==*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@87)R87DH)&ED+"!61E-?1D],1$52+"`D<&%T:"P@)&YA;64L('1I
M;64H*2P@)'1H:7,M/E]P87)A;7-;)W5S97(G72P@,"DI.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1&5L971E(&$@9FEL92!F<F]M('1H92!61E,N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@("`@5&AE('!A=&@@
M=&\@9&5L971E('1H92!F;VQD97(@9G)O;2X*("`@("`J($!P87)A;2!S=')I
M;F<@)&YA;64@("`@("`@(%1H92!F;VQD97)N86UE('1O('5S92X*("`@("`J
M($!P87)A;2!B;V]L96%N("1R96-U<G-I=F4@($9O<F-E(&$@<F5C=7)S:79E
M(&1E;&5T93\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N
M('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!D96QE=&5&;VQD97(H)'!A=&@L("1N86UE
M+"`D<F5C=7)S:79E(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&-O;FX@/2`D
M=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M8V]N;BDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"1R96-U<G-I=F4I('L*("`@("`@("`@("`@)')E<W5L
M="`]("1T:&ES+3YE;7!T>49O;&1E<B@D<&%T:"`N("<O)R`N("1N86UE*3L*
M("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@
M('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;&ES="`]("1T:&ES
M+3YL:7-T1F]L9&5R*"1P871H("X@)R\G("X@)&YA;64I.PH@("`@("`@("`@
M("!I9B`H:7-?82@D;&ES="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1L:7-T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("AC;W5N="@D;&ES="DI('L*("`@("`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O(&1E;&5T92`E
M<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A=&@@+B`G
M+R<@+B`D;F%M92DI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`D9FEL94QI<W0@/2`D=&AI<RT^7V1B+3YG971!;&PH<W!R:6YT9B@G4T5,
M14-4('9F<U]I9"P@=F9S7V]W;F5R+"!V9G-?<&5R;7,@1E)/32`E<PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@5TA%4D4@=F9S7W!A=&@@/2`_($%.1"!V9G-?;F%M93T@/R!!3D0@
M=F9S7W1Y<&4@/2`_)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L
M92==*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH)'!A=&@L("1N86UE+"!61E-?1D],1$52*2D["@H@("`@("`@(&EF
M("@A:7-?87)R87DH)&9I;&5,:7-T*2!\?"!C;W5N="@D9FEL94QI<W0I(#P@
M,2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(BDI.PH@("`@("`@('T*
M"B`@("`@("`@+RH@5&AE<F4@;6%Y(&)E(&]N92!O<B!M;W)E(&9O;&1E<G,@
M=VET:"!T:&4@<V%M92!N86UE(&)U="!A<R!T:&4@=7-E<@H@("`@("`@("`J
M(&UA>2!N;W0@:&%V92!R96%D(&%C8V5S<R!T;R!T:&5M+"!T:&5Y(&1O;B=T
M('-E92!T:&5M+B!3;R!W92!H879E('1O"B`@("`@("`@("H@9&5L971E('1H
M92!O;F4@=&AE>2!H879E(&%C8V5S<R!T;R`J+PH@("`@("`@(&9O<F5A8V@@
M*"1F:6QE3&ES="!A<R`D9FEL92D@>PH@("`@("`@("`@("!I9B`H)&9I;&5;
M,5T@/3T@)'1H:7,M/E]P87)A;7-;)W5S97(G72!\?"`D9FEL95LR72`F(%9&
M4U]&3$%'7U=2251%*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H
M:7,M/E]D8BT^<75E<GDH<W!R:6YT9B@G1$5,151%($923TT@)7,@5TA%4D4@
M=F9S7VED(#T@/R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH)&9I;&5;,%TI*3L*"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M
M/E]D8BT^869F96-T9612;W=S*"D@/3T@,"D@>PH@("`@("`@("`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>2XB*2D["B`@("`@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@("\O($9)6$U%.B`G06-C97-S($1E;FEE9"!D96QE
M=&EN9R!F;VQD97(@)7,O)7,G"B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H7R@B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(I*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!A(&QI<W0@;V8@=&AE(&-O
M;G1E;G1S(&]F(&$@9F]L9&5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'!A=&@@("`@("`@5&AE('!A=&@@;V8@=&AE(&1I<F5C=&]R>2X*("`@
M("`J($!P87)A;2!M:7AE9"`D9FEL=&5R("`@("`@4W1R:6YG+VAA<V@@=&\@
M9FEL=&5R(&9I;&4O9&ER;F%M92!O;BX*("`@("`J($!P87)A;2!B;V]L96%N
M("1D;W1F:6QE<R`@4VAO=R!D;W1F:6QE<S\*("`@("`J($!P87)A;2!B;V]L
M96%N("1D:7)O;FQY("`@4VAO=R!O;FQY(&1I<F5C=&]R:65S/PH@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@($9I;&4@;&ES="!O;B!S=6-C97-S(&]R
M(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]L:7-T
M1F]L9&5R*"1P871H+"`D9FEL=&5R(#T@;G5L;"P@)&1O=&9I;&5S(#T@=')U
M92P*("`@("`@("`@("`@("`@("`@("`@("`@)&1I<F]N;'D@/2!F86QS92D*
M("`@('L*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@
M("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@("`@("1L96YG=&A?
M;W`@/2`D=&AI<RT^7V=E=$9I;&53:7IE3W`H*3L*("`@("`@("`D9FEL94QI
M<W0@/2`D=&AI<RT^7V1B+3YG971!;&PH<W!R:6YT9B@G4T5,14-4('9F<U]N
M86UE+"!V9G-?='EP92P@=F9S7VUO9&EF:65D+"!V9G-?;W=N97(L('9F<U]P
M97)M<RP@)7,H=F9S7V1A=&$I($923TT@)7,*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!72$5212!V9G-?<&%T:"`]
M(#\@04Y$("AV9G-?;W=N97(@/2`_(&]R('9F<U]P97)M<R`F)B`_*2<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&QE;F=T:%]O<"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1P871H
M+"`D=&AI<RT^7W!A<F%M<ULG=7-E<B==+"!61E-?1DQ!1U]214%$*2D["B`@
M("`@("`@:68@*&ES7V$H)&9I;&5,:7-T+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D9FEL94QI<W0["B`@("`@("`@?0H*("`@("`@
M("`D9FEL97,@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1F:6QE3&ES
M="!A<R`D;&EN92D@>PH@("`@("`@("`@("`O+R!&:6QT97(@;W5T(&1O=&9I
M;&5S(&EF('1H97D@87)E;B=T('=A;G1E9"X*("`@("`@("`@("`@:68@*"$D
M9&]T9FEL97,@)B8@<W5B<W1R*"1L:6YE6S!=+"`P+"`Q*2`]/2`G+B<I('L*
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`D9FEL95LG;F%M92==(#T@<W1R:7!S;&%S:&5S*"1L:6YE6S!=
M*3L*"B`@("`@("`@("`@(&EF("@D;&EN95LQ72`]/2!61E-?1DE,12D@>PH@
M("`@("`@("`@("`@("`@)&YA;64@/2!E>'!L;V1E*"<N)RP@)&QI;F5;,%TI
M.PH*("`@("`@("`@("`@("`@(&EF("AC;W5N="@D;F%M92D@/3T@,2D@>PH@
M("`@("`@("`@("`@("`@("`@("1F:6QE6R=T>7!E)UT@/2`G*BIN;VYE)SL*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M)&9I;&5;)W1Y<&4G72`](%9&4SHZ<W1R=&]L;W=E<B@D;F%M95MC;W5N="@D
M;F%M92D@+2`Q72D["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@
M("`@)&9I;&5;)W-I>F4G72`]("1L:6YE6S5=.PH@("`@("`@("`@("!](&5L
M<V5I9B`H)&QI;F5;,5T@/3T@5D937T9/3$1%4BD@>PH@("`@("`@("`@("`@
M("`@)&9I;&5;)W1Y<&4G72`]("<J*F1I<B<["B`@("`@("`@("`@("`@("`D
M9FEL95LG<VEZ92==(#T@+3$["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1F:6QE6R=D871E)UT@/2`D;&EN95LR73L*("`@("`@("`@("`@)&9I;&5;
M)V]W;F5R)UT@/2`D;&EN95LS73L*"B`@("`@("`@("`@("1L:6YE6S1=(#T@
M:6YT=F%L*"1L:6YE6S1=*3L*("`@("`@("`@("`@)&9I;&5;)W!E<FUS)UT@
M(#T@*"1L:6YE6S%=(#T](%9&4U]&3TQ$15(I(#\@)V0G(#H@)RTG.PH@("`@
M("`@("`@("`D9FEL95LG<&5R;7,G72`N/2`G<G<M)SL*("`@("`@("`@("`@
M)&9I;&5;)W!E<FUS)UT@+CT@*"1L:6YE6S1=("8@5D937T9,04=?4D5!1"D@
M/R`G<B<@.B`G+2<["B`@("`@("`@("`@("1F:6QE6R=P97)M<R==("X]("@D
M;&EN95LT72`F(%9&4U]&3$%'7U=2251%*2`_("=W)R`Z("<M)SL*("`@("`@
M("`@("`@)&9I;&5;)W!E<FUS)UT@+CT@)RTG.PH@("`@("`@("`@("`D9FEL
M95LG9W)O=7`G72`]("<G.PH*("`@("`@("`@("`@+R\@9FEL=&5R:6YG"B`@
M("`@("`@("`@(&EF("@D=&AI<RT^7V9I;'1E<DUA=&-H*"1F:6QT97(L("1F
M:6QE6R=N86UE)UTI*2!["B`@("`@("`@("`@("`@("!U;G-E="@D9FEL92D[
M"B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!I9B`H)&1I<F]N;'D@)B8@)&9I;&5;)W1Y<&4G72`A/3T@)RHJ
M9&ER)RD@>PH@("`@("`@("`@("`@("`@=6YS970H)&9I;&4I.PH@("`@("`@
M("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1F:6QE<ULD9FEL95LG;F%M92==72`]("1F:6QE.PH@("`@("`@("`@("!U
M;G-E="@D9FEL92D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&9I;&5S
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAA;F=E<R!P97)M:7-S:6]N<R!F
M;W(@86X@271E;2!O;B!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'!A=&@@($AO;&1S('1H92!P871H(&]F(&1I<F5C=&]R>2!O9B!T
M:&4@271E;2X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@($AO;&1S('1H
M92!N86UE(&]F('1H92!)=&5M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-H86YG95!E<FUI<W-I
M;VYS*"1P871H+"`D;F%M92P@)'!E<FUI<W-I;VXI"B`@("!["B`@("`@("`@
M)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D8V]N;BDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@
M("`@("`@('T*"B`@("`@("`@)'9A;"`](&EN='9A;"AS=6)S='(H)'!E<FUI
M<W-I;VXL("TQ*2D["B`@("`@("`@)'!E<FT@/2`P.PH@("`@("`@("1P97)M
M('P]("@D=F%L("8@-"D@/R!61E-?1DQ!1U]214%$(#H@,#L*("`@("`@("`D
M<&5R;2!\/2`H)'9A;"`F(#(I(#\@5D937T9,04=?5U))5$4@.B`P.PH*("`@
M("`@("`D9FEL94QI<W0@/2`D=&AI<RT^7V1B+3YG971!;&PH<W!R:6YT9B@G
M4T5,14-4('9F<U]I9"P@=F9S7V]W;F5R+"!V9G-?<&5R;7,@1E)/32`E<PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@5TA%4D4@=F9S7W!A=&@@/2`_($%.1"!V9G-?;F%M93T@/R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1P871H+"`D
M;F%M92DI.PH*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1F:6QE3&ES="D@?'P@
M8V]U;G0H)&9I;&5,:7-T*2`\(#$I('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB
M*2D["B`@("`@("`@?0H*("`@("`@("`O*B!4:&5R92!M87D@8F4@;VYE(&]R
M(&UO<F4@9FEL97,@=VET:"!T:&4@<V%M92!N86UE(&)U="!T:&4@=7-E<B!M
M87D*("`@("`@("`@*B!N;W0@:&%V92!R96%D(&%C8V5S<R!T;R!T:&5M+"!S
M;R!D;V5S;B=T('-E92!T:&5M+B!3;R!W92!H879E('1O"B`@("`@("`@("H@
M8VAM;V0@=&AE(&]N92!T:&5Y(&AA=F4@86-C97-S('1O+B`J+PH@("`@("`@
M(&9O<F5A8V@@*"1F:6QE3&ES="!A<R`D9FEL92D@>PH@("`@("`@("`@("!I
M9B`H)&9I;&5;,5T@/3T@)'1H:7,M/E]P87)A;7-;)W5S97(G72!\?"`D9FEL
M95LR72`F(%9&4U]&3$%'7U=2251%*2!["B`@("`@("`@("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH<W!R:6YT9B@G55!$051%("5S(%-%
M5"!V9G-?<&5R;7,@/2`_"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!72$5212!V9G-?:60@/2`_)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@D<&5R;2P@)&9I
M;&5;,%TI*3L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BAS<')I;G1F*%\H(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO
M;B!F;W(@5D93(&9I;&4@)7,O)7,N(BDL("1P871H+"`D;F%M92DI.PH@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O5D93+V9T<"YP:'``````````````````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P-S4R,S0@,3`U,34T,S,W,S4@,#(P,C8R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B!61E,@:6UP;&5M96YT871I;VX@9F]R(&%N($944"!S97)V97(N"B`J
M"B`J(%)E<75I<F5D('9A;'5E<R!F;W(@)'!A<F%M<SH\<')E/@H@*B`@("`@
M("=U<V5R;F%M92<@("`@("`@5&AE('5S97)N86UE('=I=&@@=VAI8V@@=&\@
M8V]N;F5C="!T;R!T:&4@9G1P('-E<G9E<BX*("H@("`@("`G<&%S<W=O<F0G
M("`@("`@(%1H92!P87-S=V]R9"!W:71H('=H:6-H('1O(&-O;FYE8W0@=&\@
M=&AE(&9T<"!S97)V97(N"B`J("`@("`@)VAO<W1S<&5C)R`@("`@("!4:&4@
M9G1P('-E<G9E<B!T;R!C;VYN96-T('1O+CPO<')E/@H@*@H@*B!/<'1I;VYA
M;"!V86QU97,@9F]R("1P87)A;7,Z/'!R93X*("H@("`@("`G;6%P;&]C86QI
M9',G("`@($EF('1R=64@86YD('1H92!03U-)6"!E>'1E;G-I;VX@:7,@879A
M:6QA8FQE+"!T:&4*("H@("`@("`@("`@("`@("`@("`@("`@(&1R:79E<B!W
M:6QL(&UA<"!T:&4@=7-E<B!A;F0@9W)O=7`@241S(')E='5R;F5D(&9R;VT*
M("H@("`@("`@("`@("`@("`@("`@("`@('1H92!&5%`@<V5R=F5R('=I=&@@
M=&AE(&QO8V%L($E$<R!F<F]M('1H92!L;V-A;`H@*B`@("`@("`@("`@("`@
M("`@("`@("`@<&%S<W=O<F0@9FEL92X@(%1H:7,@:7,@=7-E9G5L(&]N;'D@
M:68@=&AE($944"!S97)V97(*("H@("`@("`@("`@("`@("`@("`@("`@(&ES
M(')U;FYI;F<@;VX@;&]C86QH;W-T(&]R(&EF('1H92!L;V-A;"!U<V5R+V=R
M;W5P"B`J("`@("`@("`@("`@("`@("`@("`@("!)1',@87)E(&ED96YT:6-A
M;"!T;R!T:&4@<F5M;W1E($944"!S97)V97(N"B`J("`@("`@)W!A<W8G("`@
M("`@("`@("!)9B!T<G5E+"!C;VYN96-T:6]N('=I;&P@8F4@<V5T('1O('!A
M<W-I=F4@;6]D92X*("H@("`@("`G<&]R="<@("`@("`@("`@(%1H92!P;W)T
M('5S960@=&\@8V]N;F5C="!T;R!T:&4@9G1P('-E<G9E<B!I9B!O=&AE<@H@
M*B`@("`@("`@("`@("`@("`@("`@("`@=&AA;B`R,2X*("H@("`@("`G<W-L
M)R`@("`@("`@("`@($EF('1R=64L(&%N9"!02%`@:&%D(&)E96X@8V]M<&EL
M960@=VET:"!/<&5N4U-,"B`J("`@("`@("`@("`@("`@("`@("`@("!S=7!P
M;W)T+"!43%,@=')A;G-P;W)T+6QE=F5L(&5N8W)Y<'1I;VX@=VEL;"!B90H@
M*B`@("`@("`@("`@("`@("`@("`@("`@;F5G;W1I871E9"!W:71H('1H92!S
M97)V97(N"B`J("`@("`@)W1I;65O=70G("`@("`@("!)9B!D969I;F5D+"!U
M<V4@=&AI<R!V86QU92!A<R!T:&4@=&EM96]U="!F;W(@=&AE"B`J("`@("`@
M("`@("`@("`@("`@("`@("!S97)V97(N/"]P<F4^"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<"QV(#$N-S4N-"XR,2`R,#`V+S`U
M+S,Q(#`T.C4P.C`R('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I9VAT(#(P
M,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@
M0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L(%9A<F=H97-E(#QM:6ME+G9A
M<F=H97-E0&%S8V5L;&%T96-H+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`
M875T:&]R("!-:6-H865L(%9A<F=H97-E(#QM:6ME+G9A<F=H97-E0&%S8V5L
M;&%T96-H+F-O;3X*("H@0'!A8VMA9V4@5D93"B`J+PIC;&%S<R!61E-?9G1P
M(&5X=&5N9',@5D93('L*"B`@("`O*BH*("`@("`J($QI<W0@;V8@861D:71I
M;VYA;"!C<F5D96YT:6%L<R!R97%U:7)E9"!F;W(@=&AI<R!61E,@8F%C:V5N
M9"X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D
M7V-R961E;G1I86QS(#T@87)R87DH)W5S97)N86UE)RP@)W!A<W-W;W)D)RD[
M"@H@("`@+RHJ"B`@("`@*B!,:7-T(&]F('!E<FUI<W-I;VYS(&%N9"!I9B!T
M:&5Y(&-A;B!B92!C:&%N9V5D(&EN('1H:7,@5D93(&)A8VME;F0N"B`@("`@
M*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P97)M:7-S
M:6]N<R`](&%R<F%Y*`H@("`@("`@("=O=VYE<B<@/3X@87)R87DH)W)E860G
M(#T^('1R=64L("=W<FET92<@/3X@=')U92P@)V5X96-U=&4G(#T^('1R=64I
M+`H@("`@("`@("=G<F]U<"<@/3X@87)R87DH)W)E860G(#T^('1R=64L("=W
M<FET92<@/3X@=')U92P@)V5X96-U=&4G(#T^('1R=64I+`H@("`@("`@("=A
M;&PG("`@/3X@87)R87DH)W)E860G(#T^('1R=64L("=W<FET92<@/3X@=')U
M92P@)V5X96-U=&4G(#T^('1R=64I*3L*"B`@("`O*BH*("`@("`J(%9A<FEA
M8FQE(&AO;&1I;F<@=&AE(&-O;FYE8W1I;VX@=&\@=&AE(&9T<"!S97)V97(N
M"B`@("`@*@H@("`@("H@0'9A<B!R97-O=7)C90H@("`@("HO"B`@("!V87(@
M)%]S=')E86T@/2!F86QS93L*"B`@("`O*BH*("`@("`J($QO8V%L(&-A8VAE
M(&%R<F%Y(&9O<B!U<V5R($E$<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*B\*("`@('9A<B`D7W5I9',@/2!A<G)A>2@I.PH*("`@("\J*@H@
M("`@("H@3&]C86P@8V%C:&4@87)R87D@9F]R(&=R;W5P($E$<RX*("`@("`J
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V=I9',@/2!A
M<G)A>2@I.PH*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<VEZ92!O9B!A
M(&9I;&4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!O9B!T:&4@9FEL
M92X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!F:6QE;F%M92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!S:7IE(&]F('1H
M92!F:6QE(&EN(&)Y=&5S(&]R(%!%05)?17)R;W(@;VX*("`@("`J("`@("`@
M("`@("`@("`@("`@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<VEZ
M92@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI<RT^
M7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*
M("`@("`@("!I9B`H*"1S:7IE(#T@0&9T<%]S:7IE*"1T:&ES+3Y?<W1R96%M
M+"`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2DI(#T]/2!F86QS92D@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F
M*%\H(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<UPB+B(I+"`D
M=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2DI.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1S:7IE.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M<FEE=F5S(&$@9FEL92!F<F]M('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&AN86UE('1O('1H92!F:6QE+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&9I;&5N86UE('1O(')E
M=')I979E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9FEL
M92!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96%D*"1P871H+"`D;F%M
M92D*("`@('L*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C="@I.PH@
M("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@("`@("1T;7!&
M:6QE(#T@)'1H:7,M/E]G971496UP1FEL92@I.PH@("`@("`@("1F971C:"`]
M($!F='!?9V5T*"1T:&ES+3Y?<W1R96%M+"`D=&UP1FEL92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE
M*2P@1E107T))3D%262D["B`@("`@("`@:68@*"1F971C:"`]/3T@9F%L<V4I
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT
M9BA?*")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(BDL("1T:&ES
M+3Y?9V5T4&%T:"@D<&%T:"P@)&YA;64I*2D["B`@("`@("`@?0H*("`@("`@
M("`D<VEZ92`](&9I;&5S:7IE*"1T;7!&:6QE*3L*("`@("`@("!I9B`H)'-I
M>F4@/3T](#`I('L*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@('T*
M"B`@("`@("`@:68@*$]37U=)3D1/5U,I('L*("`@("`@("`@("`@)&UO9&4@
M/2`G<F(G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1M;V1E(#T@
M)W(G.PH@("`@("`@('T*"B`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G
M9FEL95]G971?8V]N=&5N=',G*2D@>PH@("`@("`@("`@("`D9&%T82`](&9I
M;&5?9V5T7V-O;G1E;G1S*"1T;7!&:6QE*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D9G`@/2!F;W!E;B@D=&UP1FEL92P@)&UO9&4I.PH@("`@
M("`@("`@("`D9&%T82`](&9R96%D*"1F<"P@)'-I>F4I.PH@("`@("`@("`@
M("!F8VQO<V4H)&9P*3L*("`@("`@("!]"B`@("`@("`@=6YL:6YK*"1T;7!&
M:6QE*3L*"B`@("`@("`@<F5T=7)N("1D871A.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4W1O<F5S(&$@9FEL92!I;B!T:&4@5D93+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'!A=&@@("`@("`@("!4:&4@<&%T:"!T;R!S=&]R
M92!T:&4@9FEL92!I;BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@
M("`@("!4:&4@9FEL96YA;64@=&\@=7-E+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=&UP1FEL92`@("`@(%1H92!T96UP;W)A<GD@9FEL92!C;VYT86EN:6YG
M('1H92!D871A('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@8F4@<W1O<F5D+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%U=&]C<F5A
M=&4@($%U=&]M871I8V%L;'D@8W)E871E(&1I<F5C=&]R:65S/PH@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%
M05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('=R:71E*"1P871H+"`D;F%M92P@)'1M<$9I;&4L("1A=71O8W)E871E
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE
M8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*("`@("`@
M("`D<F5S(#T@)'1H:7,M/E]C:&5C:U%U;W1A5W)I=&4H)V9I;&4G+"`D=&UP
M1FEL92D["B`@("`@("`@:68@*&ES7V$H)')E<RP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("!]"@H@("`@("`@
M(&EF("@A0&9T<%]P=70H)'1H:7,M/E]S=')E86TL("1T:&ES+3Y?9V5T4&%T
M:"@D<&%T:"P@)&YA;64I+"`D=&UP1FEL92P@1E107T))3D%262DI('L*("`@
M("`@("`@("`@:68@*"1A=71O8W)E871E*2!["B`@("`@("`@("`@("`@("`D
M<F5S=6QT(#T@)'1H:7,M/F%U=&]C<F5A=&50871H*"1P871H*3L*("`@("`@
M("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@A0&9T<%]P=70H)'1H:7,M
M/E]S=')E86TL("1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@)&YA;64I+"`D=&UP
M1FEL92P@1E107T))3D%262DI('L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E5N86)L92!T;R!W<FET
M92!61E,@9FEL92!<(B5S7"(N(BDL("1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@
M)&YA;64I*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS
M<')I;G1F*%\H(E5N86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(BDL
M("1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@)&YA;64I*2D["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4W1O<F5S(&$@9FEL92!I;B!T:&4@5D93(&9R;VT@<F%W
M(&1A=&$N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@
M("`@(%1H92!P871H('1O('-T;W)E('1H92!F:6QE(&EN+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;F%M92`@("`@("`@(%1H92!F:6QE;F%M92!T;R!U<V4N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A("`@("`@("`@5&AE(&9I;&4@
M9&%T82X*("`@("`J($!P87)A;2!B;V]L96%N("1A=71O8W)E871E("!!=71O
M;6%T:6-A;&QY(&-R96%T92!D:7)E8W1O<FEE<S\*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET
M941A=&$H)'!A=&@L("1N86UE+"`D9&%T82P@)&%U=&]C<F5A=&4@/2!F86QS
M92D*("`@('L*("`@("`@("`D<F5S(#T@)'1H:7,M/E]C:&5C:U%U;W1A5W)I
M=&4H)W-T<FEN9R<L("1D871A*3L*("`@("`@("!I9B`H:7-?82@D<F5S+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@
M("`@('T*"B`@("`@("`@)'1M<$9I;&4@/2`D=&AI<RT^7V=E=%1E;7!&:6QE
M*"D["B`@("`@("`@)&9P(#T@9F]P96XH)'1M<$9I;&4L("=W8B<I.PH@("`@
M("`@(&9W<FET92@D9G`L("1D871A*3L*("`@("`@("!F8VQO<V4H)&9P*3L*
M"B`@("`@("`@)')E<W5L="`]("1T:&ES+3YW<FET92@D<&%T:"P@)&YA;64L
M("1T;7!&:6QE+"`D875T;V-R96%T92D["B`@("`@("`@=6YL:6YK*"1T;7!&
M:6QE*3L*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O*BH*
M("`@("`J($1E;&5T97,@82!F:6QE(&9R;VT@=&AE(%9&4RX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!T;R!D96QE=&4@
M=&AE(&9I;&4@9G)O;2X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H
M92!F:6QE;F%M92!T;R!D96QE=&4N"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@
M;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E1FEL92@D
M<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@)')E<R`]("1T:&ES+3Y?8VAE
M8VM1=6]T841E;&5T92@D<&%T:"P@)&YA;64I.PH@("`@("`@(&EF("AI<U]A
M*"1R97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R
M97,["B`@("`@("`@?0H*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C
M="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@("`@
M(&EF("@A0&9T<%]D96QE=&4H)'1H:7,M/E]S=')E86TL("1T:&ES+3Y?9V5T
M4&%T:"@D<&%T:"P@)&YA;64I*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E5N86)L92!T;R!D96QE=&4@5D93
M(&9I;&4@7"(E<UPB+B(I+"`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE
M*2DI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#:&5C:W,@:68@82!G:79E;B!I=&5M(&ES(&$@9F]L
M9&5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P
M87)E;G0@9F]L9&5R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE
M(&ET96T@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R
M=64@:68@:70@:7,@82!F;VQD97(L(&9A;'-E(&]T:&5R=VES92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@:7-&;VQD97(H)'!A=&@L("1N86UE*0H@("`@>PH@
M("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@
M*&ES7V$H)&-O;FXL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`](&9A;'-E
M.PH@("`@("`@("1O;&1D:7(@/2`D=&AI<RT^9V5T0W5R<F5N=$1I<F5C=&]R
M>2@I.PH*("`@("`@("`O*B!3964@:68@=V4@8V%N(&-H86YG92!T;R!T:&4@
M9VEV96X@<&%T:"X@*B\*("`@("`@("!I9B`H0&9T<%]C:&1I<B@D=&AI<RT^
M7W-T<F5A;2P@)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M92DI*2!["B`@
M("`@("`@("`@("1R97-U;'0@/2!T<G5E.PH@("`@("`@('T*"B`@("`@("`@
M)'1H:7,M/E]S9710871H*"1O;&1D:7(I.PH*("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@('T*"B`@("`O*BH*("`@("`J($1E;&5T97,@82!F;VQD97(@
M9G)O;2!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A
M=&@@("`@("`@(%1H92!P87)E;G0@9F]L9&5R+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;F%M92`@("`@("`@5&AE(&YA;64@;V8@=&AE(&9O;&1E<B!T;R!D
M96QE=&4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<F5C=7)S:79E("!&;W)C
M92!A(')E8W5R<VEV92!D96QE=&4_"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@
M;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E1F]L9&5R
M*"1P871H+"`D;F%M92P@)')E8W5R<VEV92`](&9A;'-E*0H@("`@>PH@("`@
M("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES
M7V$H)&-O;FXL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@)&ES1&ER(#T@9F%L<V4["B`@
M("`@("`@)&1I<D-H96-K(#T@)'1H:7,M/FQI<W1&;VQD97(H)'!A=&@I.PH@
M("`@("`@(&9O<F5A8V@@*"1D:7)#:&5C:R!A<R`D9FEL92D@>PH@("`@("`@
M("`@("!I9B`H)&9I;&5;)VYA;64G72`]/2`D;F%M92`F)B`D9FEL95LG='EP
M92==(#T]("<J*F1I<B<I('L*("`@("`@("`@("`@("`@("1I<T1I<B`]('1R
M=64["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@:68@*"1I<T1I<BD@>PH@("`@("`@("`@("`D9FEL
M95]L:7-T(#T@)'1H:7,M/FQI<W1&;VQD97(H)'1H:7,M/E]G9710871H*"1P
M871H+"`D;F%M92DI.PH@("`@("`@("`@("!I9B`H:7-?82@D9FEL95]L:7-T
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&9I
M;&5?;&ES=#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*&-O=6YT
M*"1F:6QE7VQI<W0I("8F("$D<F5C=7)S:79E*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E5N86)L92!T
M;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2XB
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M92DI*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@9F]R96%C:"`H)&9I;&5?;&ES="!A<R`D
M9FEL92D@>PH@("`@("`@("`@("`@("`@:68@*"1F:6QE6R=T>7!E)UT@/3T@
M)RHJ9&ER)RD@>PH@("`@("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI
M<RT^9&5L971E1F]L9&5R*"1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@)&YA;64I
M+"`D9FEL95LG;F%M92==+"`D<F5C=7)S:79E*3L*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES
M+3YD96QE=&5&:6QE*"1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@)&YA;64I+"`D
M9FEL95LG;F%M92==*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"%`9G1P7W)M9&ER
M*"1T:&ES+3Y?<W1R96%M+"`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE
M*2DI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*'-P<FEN=&8H7R@B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(I
M+"`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2DI.PH@("`@("`@("`@
M("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*"%`9G1P7V1E
M;&5T92@D=&AI<RT^7W-T<F5A;2P@)'1H:7,M/E]G9710871H*"1P871H+"`D
M;F%M92DI*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BAS<')I;G1F*%\H(D-A;FYO="!D96QE=&4@9FEL92!<(B5S7"(N(BDL
M("1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@)&YA;64I*2D["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5N86UE<R!A(&9I;&4@:6X@=&AE(%9&4RX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1O;&1P871H("!4:&4@;VQD('!A=&@@
M=&\@=&AE(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1O;&1N86UE("!4
M:&4@;VQD(&9I;&5N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5W<&%T
M:"`@5&AE(&YE=R!P871H(&]F('1H92!F:6QE+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;F5W;F%M92`@5&AE(&YE=R!F:6QE;F%M92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R
M<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R
M96YA;64H)&]L9'!A=&@L("1O;&1N86UE+"`D;F5W<&%T:"P@)&YE=VYA;64I
M"B`@("!["B`@("`@("`@:68@*&ES7V$H)&-O;FX@/2`D=&AI<RT^7V-O;FYE
M8W0H*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O
M;FX["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?82@D<F5S=6QT(#T@)'1H
M:7,M/F%U=&]C<F5A=&50871H*"1N97=P871H*2P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@
M("`@(&EF("@A0&9T<%]R96YA;64H)'1H:7,M/E]S=')E86TL("1T:&ES+3Y?
M9V5T4&%T:"@D;VQD<&%T:"P@)&]L9&YA;64I+"`D=&AI<RT^7V=E=%!A=&@H
M)&YE=W!A=&@L("1N97=N86UE*2DI('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE(%PB)7-<(BXB*2P@)'1H:7,M/E]G9710871H*"1O;&1P871H+"`D
M;VQD;F%M92DI*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0W)E871E<R!A(&9O;&1E<B!O;B!T:&4@
M5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P
M87)E;G0@9F]L9&5R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE
M(&YA;64@;V8@=&AE(&YE=R!F;VQD97(N"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE
M8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@8W)E871E1F]L
M9&5R*"1P871H+"`D;F%M92D*("`@('L*("`@("`@("`D8V]N;B`]("1T:&ES
M+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]
M"@H@("`@("`@(&EF("@A0&9T<%]M:V1I<B@D=&AI<RT^7W-T<F5A;2P@)'1H
M:7,M/E]G9710871H*"1P871H+"`D;F%M92DI*2!["B`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O(&-R
M96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB*2P@)'1H:7,M/E]G9710871H
M*"1P871H+"`D;F%M92DI*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAA;F=E<R!P97)M:7-S:6]N
M<R!F;W(@86X@:71E;2!O;B!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'!A=&@@("`@("`@(%1H92!P87)E;G0@9F]L9&5R(&]F('1H
M92!I=&5M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@("`@5&AE
M(&YA;64@;V8@=&AE(&ET96TN"B`@("`@*B!`<&%R86T@<W1R:6YG("1P97)M
M:7-S:6]N("!4:&4@<&5R;6ES<VEO;B!T;R!S970N"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@8VAA
M;F=E4&5R;6ES<VEO;G,H)'!A=&@L("1N86UE+"`D<&5R;6ES<VEO;BD*("`@
M('L*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@
M(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@("`@(&EF("@A0&9T<%]S
M:71E*"1T:&ES+3Y?<W1R96%M+"`G0TA-3T0@)R`N("1P97)M:7-S:6]N("X@
M)R`G("X@)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M92DI*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA
M8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N
M(BDL("1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@)&YA;64I*2D["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@86X@86X@=6YS;W)T960@9FEL92!L:7-T(&]F('1H92!S<&5C
M:69I960@9&ER96-T;W)Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'!A=&@@("`@("`@5&AE('!A=&@@;V8@=&AE(&1I<F5C=&]R>2X*("`@("`J
M($!P87)A;2!M:7AE9"`D9FEL=&5R("`@("`@4W1R:6YG+VAA<V@@=&\@9FEL
M=&5R(&9I;&4O9&ER;F%M92!O;BX*("`@("`J($!P87)A;2!B;V]L96%N("1D
M;W1F:6QE<R`@4VAO=R!D;W1F:6QE<S\*("`@("`J($!P87)A;2!B;V]L96%N
M("1D:7)O;FQY("`@4VAO=R!O;FQY(&1I<F5C=&]R:65S/PH@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@($9I;&4@;&ES="!O;B!S=6-C97-S(&]R(%!%
M05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7VQI
M<W1&;VQD97(H)'!A=&@@/2`G)RP@)&9I;'1E<B`](&YU;&PL("1D;W1F:6QE
M<R`]('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`D9&ER;VYL>2`]
M(&9A;'-E*0H@("`@>PH@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T
M*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@
M)&9I;&5S(#T@87)R87DH*3L*("`@("`@("`D='EP92`](%9&4SHZ<W1R=&]L
M;W=E<BA`9G1P7W-Y<W1Y<&4H)'1H:7,M/E]S=')E86TI*3L*("`@("`@("!I
M9B`H)'1Y<&4@/3T@)W5N:VYO=VXG*2!["B`@("`@("`@("`@("\O($=O('=I
M=&@@=6YI>"US='EL92!L:7-T:6YG<R!B>2!D969A=6QT+@H@("`@("`@("`@
M("`D='EP92`]("=U;FEX)SL*("`@("`@("!](&5L<V5I9B`H<W1R<&]S*"1T
M>7!E+"`G=VEN)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("1T>7!E(#T@
M)W=I;B<["B`@("`@("`@?2!E;'-E:68@*'-T<G!O<R@D='EP92P@)VYE='=A
M<F4G*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@)'1Y<&4@/2`G;F5T=V%R
M92<["B`@("`@("`@?0H*("`@("`@("`D;VQD9&ER(#T@)'1H:7,M/F=E=$-U
M<G)E;G1$:7)E8W1O<GDH*3L*("`@("`@("!I9B`H(65M<'1Y*"1P871H*2D@
M>PH@("`@("`@("`@("`D<F5S(#T@)'1H:7,M/E]S9710871H*"1P871H*3L*
M("`@("`@("`@("`@:68@*&ES7V$H)')E<RP@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(&EF("@D='EP92`]/2`G=6YI>"<I('L*("`@("`@
M("`@("`@+R\@268@=V4@9&]N)W0@=V%N="!D;W1F:6QE<RP@5V4@8V%N('-A
M=F4@=V]R:R!H97)E(&)Y(&YO=`H@("`@("`@("`@("`O+R!D;VEN9R!A;B!L
M<R`M82!A;F0@=&AE;B!N;W0@9&]I;F<@=&AE(&-H96-K(&QA=&5R("AB>0H@
M("`@("`@("`@("`O+R!S971T:6YG("1D;W1F:6QE<R!T;R!T<G5E+"!T:&4@
M:68@:7,@<VAO<G0M8VER8W5I=&5D*2X*("`@("`@("`@("`@:68@*"1D;W1F
M:6QE<RD@>PH@("`@("`@("`@("`@("`@)&QI<W0@/2!F='!?<F%W;&ES="@D
M=&AI<RT^7W-T<F5A;2P@)RUA;"<I.PH@("`@("`@("`@("`@("`@)&1O=&9I
M;&5S(#T@=')U93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1L:7-T(#T@9G1P7W)A=VQI<W0H)'1H:7,M/E]S=')E86TL("<M;"<I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`D
M;&ES="`](&9T<%]R87=L:7-T*"1T:&ES+3Y?<W1R96%M+"`G)RD["B`@("`@
M("`@?0H*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1L:7-T*2D@>PH@("`@("`@
M("`@("!I9B`H:7-S970H)&]L9&1I<BDI('L*("`@("`@("`@("`@("`@("1R
M97,@/2`D=&AI<RT^7W-E=%!A=&@H)&]L9&1I<BD["B`@("`@("`@("`@("`@
M("!I9B`H:7-?82@D<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@("`@("`@
M?0H*("`@("`@("`O*B!)9B`G;6%P;&]C86QI9',G(&ES('-E="P@8VAE8VL@
M9F]R('1H92!03U-)6"!E>'1E;G-I;VXN("HO"B`@("`@("`@)&UA<&ED<R`]
M(&9A;'-E.PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;)VUA
M<&QO8V%L:61S)UTI("8F"B`@("`@("`@("`@(&5X=&5N<VEO;E]L;V%D960H
M)W!O<VEX)RDI('L*("`@("`@("`@("`@)&UA<&ED<R`]('1R=64["B`@("`@
M("`@?0H*("`@("`@("`D8W5R<G1I;64@/2!T:6UE*"D["@H@("`@("`@(&9O
M<F5A8V@@*"1L:7-T(&%S("1L:6YE*2!["B`@("`@("`@("`@("1F:6QE(#T@
M87)R87DH*3L*("`@("`@("`@("`@)&ET96T@/2!P<F5G7W-P;&ET*"<O7',K
M+R<L("1L:6YE*3L*("`@("`@("`@("`@:68@*"1T>7!E(#T]("=U;FEX)R!\
M?"`H)'1Y<&4@/3T@)W=I;B<@)B8@(7!R96=?;6%T8V@H)WQ<9%QD+5QD7&0M
M7&1<9'PG+"`D:71E;5LP72DI*2!["B`@("`@("`@("`@("`@("!I9B`H8V]U
M;G0H)&ET96TI(#P@."!\?"!S=6)S='(H)&QI;F4L(#`L(#4I(#T]("=T;W1A
M;"<I('L*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1F:6QE6R=P97)M<R==(#T@)&ET
M96U;,%T["B`@("`@("`@("`@("`@("!I9B`H)&UA<&ED<RD@>PH@("`@("`@
M("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]U:61S6R1I=&5M6S)=
M72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&5N=')Y(#T@<&]S:7A?
M9V5T<'=U:60H)&ET96U;,ETI.PH@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W5I9'-;)&ET96U;,EU=(#T@*&5M<'1Y*"1E;G1R>2DI(#\@)&ET
M96U;,ET@.B`D96YT<GE;)VYA;64G73L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@)&9I;&5;)V]W;F5R)UT@/2`D=&AI<RT^
M7W5I9'-;)&ET96U;,EU=.PH@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]U:61S6R1I=&5M6S-=72DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&5N=')Y(#T@<&]S:7A?9V5T9W)G:60H)&ET96U;,UTI.PH@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W5I9'-;)&ET96U;,UU=
M(#T@*&5M<'1Y*"1E;G1R>2DI(#\@)&ET96U;,UT@.B`D96YT<GE;)VYA;64G
M73L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M)&9I;&5;)V=R;W5P)UT@/2`D=&AI<RT^7W5I9'-;)&ET96U;,UU=.PH*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&9I
M;&5;)V]W;F5R)UT@/2`D:71E;5LR73L*("`@("`@("`@("`@("`@("`@("`D
M9FEL95LG9W)O=7`G72`]("1I=&5M6S-=.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@)&9I;&5;)VYA;64G72`]('-U8G-T<B@D;&EN92P@
M<W1R<&]S*"1L:6YE+"!S<')I;G1F*"(E<R`E,G,@)35S(BP@)&ET96U;-5TL
M("1I=&5M6S9=+"`D:71E;5LW72DI("L@,3,I.PH*("`@("`@("`@("`@("`@
M("\O($9I;'1E<B!O=70@)RXG(&%N9"`G+BXG(&5N=')I97,N"B`@("`@("`@
M("`@("`@("!I9B`H<')E9U]M871C:"@G+UY<+EPN/UPO/R0O)RP@)&9I;&5;
M)VYA;64G72DI('L*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O+R!&:6QT97(@;W5T
M(&1O=&9I;&5S(&EF('1H97D@87)E;B=T('=A;G1E9"X*("`@("`@("`@("`@
M("`@(&EF("@A)&1O=&9I;&5S("8F('-U8G-T<B@D9FEL95LG;F%M92==+"`P
M+"`Q*2`]/2`G+B<I('L*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*
M("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D<#$@/2!S=6)S
M='(H)&9I;&5;)W!E<FUS)UTL(#`L(#$I.PH@("`@("`@("`@("`@("`@:68@
M*"1P,2`]/3T@)VPG*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&5;)VQI
M;FLG72`]('-U8G-T<B@D9FEL95LG;F%M92==+"!S=')P;W,H)&9I;&5;)VYA
M;64G72P@)RT^)RD@*R`S*3L*("`@("`@("`@("`@("`@("`@("`D9FEL95LG
M;F%M92==(#T@<W5B<W1R*"1F:6QE6R=N86UE)UTL(#`L('-T<G!O<R@D9FEL
M95LG;F%M92==+"`G+3XG*2`M(#$I.PH@("`@("`@("`@("`@("`@("`@("1F
M:6QE6R=T>7!E)UT@/2`G*BIS>6TG.PH*("`@("`@("`@("`@("`@("`@(&EF
M("@D=&AI<RT^:7-&;VQD97(H)R<L("1F:6QE6R=L:6YK)UTI*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1F:6QE6R=L:6YK='EP92==(#T@
M)RHJ9&ER)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%R=',@/2!E>'!L
M;V1E*"<O)RP@)&9I;&5;)VQI;FLG72D["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F%M92`](&5X<&QO
M9&4H)RXG+"!A<G)A>5]P;W`H)'!A<G1S*2D["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H8V]U;G0H
M)&YA;64I(#T](#$@?'P@*"1N86UE6S!=(#T]/2`G)R`F)B!C;W5N="@D;F%M
M92D@/3T@,BDI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9FEL95LG;&EN:W1Y<&4G72`]("<J
M*FYO;F4G.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F
M:6QE6R=L:6YK='EP92==(#T@5D93.CIS=')T;VQO=V5R*&%R<F%Y7W!O<"@D
M;F%M92DI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)'`Q(#T]/2`G9"<I('L*
M("`@("`@("`@("`@("`@("`@("`D9FEL95LG='EP92==(#T@)RHJ9&ER)SL*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M)&YA;64@/2!E>'!L;V1E*"<N)RP@)&9I;&5;)VYA;64G72D["B`@("`@("`@
M("`@("`@("`@("`@:68@*&-O=6YT*"1N86UE*2`]/2`Q('Q\("AS=6)S='(H
M)&9I;&5;)VYA;64G72P@,"P@,2D@/3T]("<N)R`F)B!C;W5N="@D;F%M92D@
M/3T@,BDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&9I;&5;)W1Y<&4G
M72`]("<J*FYO;F4G.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1F:6QE6R=T>7!E)UT@/2!61E,Z.G-T
M<G1O;&]W97(H)&YA;65;8V]U;G0H)&YA;64I("T@,5TI.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&EF("@D9FEL95LG='EP92==(#T]("<J*F1I<B<I('L*("`@("`@("`@("`@
M("`@("`@("`D9FEL95LG<VEZ92==(#T@+3$["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE6R=S:7IE)UT@/2`D
M:71E;5LT73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF
M("AS=')P;W,H)&ET96U;-UTL("<Z)RD@(3T](&9A;'-E*2!["B`@("`@("`@
M("`@("`@("`@("`@)&9I;&5;)V1A=&4G72`]('-T<G1O=&EM92@D:71E;5LW
M72`N("<Z,#`G("X@)&ET96U;-5T@+B`G("<@+B`D:71E;5LV72`N("<@)R`N
M(&1A=&4H)UDG+"`D8W5R<G1I;64I*3L*("`@("`@("`@("`@("`@("`@("`O
M+R!)9B!T:&4@9G1P('-E<G9E<B!R97!O<G1S(&$@9FEL92!M;V1I9FEC871I
M;VX@9&%T92!M;W)E"B`@("`@("`@("`@("`@("`@("`@+R\@;&5S<R!T:&%N
M(&]N92!D87D@:6X@=&AE(&9U='5R92P@9&]N)W0@=')Y('1O('-U8G1R86-T
M"B`@("`@("`@("`@("`@("`@("`@+R\@82!Y96%R(&9R;VT@=&AE(&1A=&4N
M("!4:&5R92!I<R!N;R!W87D@=&\@:VYO=RP@9F]R"B`@("`@("`@("`@("`@
M("`@("`@+R\@97AA;7!L92P@:68@=&AE(%9&4R!S97)V97(@86YD('1H92!F
M='`@<V5R=F5R(')E<VED90H@("`@("`@("`@("`@("`@("`@("\O(&EN(&1I
M9F9E<F5N="!T:6UE>F]N97,N("!792!S:&]U;&0@<VEM<&QY(')E<&]R="!T
M;R!T:&4*("`@("`@("`@("`@("`@("`@("`O+R`@=7-E<B!W:&%T('1H92!&
M5%`@<V5R=F5R(&ES(')E='5R;FEN9RX*("`@("`@("`@("`@("`@("`@("!I
M9B`H)&9I;&5;)V1A=&4G72`^("@D8W5R<G1I;64@*R`X-C0P,"DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&9I;&5;)V1A=&4G72`]('-T<G1O=&EM
M92@D:71E;5LW72`N("<Z,#`G("X@)&ET96U;-5T@+B`G("<@+B`D:71E;5LV
M72`N("<@)R`N("AD871E*"=9)RP@)&-U<G)T:6UE*2`M(#$I*3L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("1F:6QE6R=D871E)UT@/2!S=')T;W1I;64H)S`P
M.C`P.C`P)R`N("1I=&5M6S5=("X@)R`G("X@)&ET96U;-ET@+B`G("<@+B`D
M:71E;5LW72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS
M96EF("@D='EP92`]/2`G;F5T=V%R92<I('L*("`@("`@("`@("`@("`@("1F
M:6QE(#T@07)R87DH*3L*("`@("`@("`@("`@("`@("1F:6QE6R=P97)M<R==
M(#T@)&ET96U;,5T["B`@("`@("`@("`@("`@("`D9FEL95LG;W=N97(G72`]
M("1I=&5M6S)=.PH@("`@("`@("`@("`@("`@:68@*"1I=&5M6S!=(#T]("=D
M)RD@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE6R=T>7!E)UT@/2`G*BID
M:7(G.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`D9FEL95LG='EP92==(#T@)RHJ;F]N92<["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`D9FEL95LG<VEZ92==(#T@)&ET96U;,UT[
M"B`@("`@("`@("`@("`@("`D9FEL95LG;F%M92==(#T@)&ET96U;-UT["B`@
M("`@("`@("`@("`@("`D:6YD97@@/2`X.PH@("`@("`@("`@("`@("`@=VAI
M;&4@*"1I;F1E>"`\(&-O=6YT*"1I=&5M*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1F:6QE6R=N86UE)UT@+CT@)R`G("X@)&ET96U;)&EN9&5X73L*("`@
M("`@("`@("`@("`@("`@("`D:6YD97@K*SL*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("\J($AA;F1L
M92!7:6YD;W=S($944"!S97)V97)S(')E='5R;FEN9R!$3U,M<W1Y;&4@9FEL
M90H@("`@("`@("`@("`@("`@("H@;&ES=&EN9W,N("HO"B`@("`@("`@("`@
M("`@("`D9FEL95LG<&5R;7,G72`]("<G.PH@("`@("`@("`@("`@("`@)&9I
M;&5;)V]W;F5R)UT@/2`G)SL*("`@("`@("`@("`@("`@("1F:6QE6R=G<F]U
M<"==(#T@)R<["B`@("`@("`@("`@("`@("`D9FEL95LG;F%M92==(#T@)&ET
M96U;,UT["B`@("`@("`@("`@("`@("`D:6YD97@@/2`T.PH@("`@("`@("`@
M("`@("`@=VAI;&4@*"1I;F1E>"`\(&-O=6YT*"1I=&5M*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1F:6QE6R=N86UE)UT@+CT@)R`G("X@)&ET96U;)&EN
M9&5X73L*("`@("`@("`@("`@("`@("`@("`D:6YD97@K*SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1F:6QE6R=D871E)UT@/2!S=')T
M;W1I;64H)&ET96U;,%T@+B`G("<@+B`D:71E;5LQ72D["B`@("`@("`@("`@
M("`@("!I9B`H)&ET96U;,ET@/3T@)SQ$25(^)RD@>PH@("`@("`@("`@("`@
M("`@("`@("1F:6QE6R=T>7!E)UT@/2`G*BID:7(G.PH@("`@("`@("`@("`@
M("`@("`@("1F:6QE6R=S:7IE)UT@/2`M,3L*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@)&9I;&5;)W-I>F4G72`]("1I
M=&5M6S)=.PH@("`@("`@("`@("`@("`@("`@("1N86UE(#T@97AP;&]D92@G
M+B<L("1F:6QE6R=N86UE)UTI.PH@("`@("`@("`@("`@("`@("`@(&EF("AC
M;W5N="@D;F%M92D@/3T@,2!\?"`H<W5B<W1R*"1F:6QE6R=N86UE)UTL(#`L
M(#$I(#T]/2`G+B<@)B8@8V]U;G0H)&YA;64I(#T](#(I*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1F:6QE6R=T>7!E)UT@/2`G*BIN;VYE)SL*("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D9FEL95LG='EP92==(#T@5D93.CIS=')T;VQO=V5R*"1N86UE6V-O
M=6YT*"1N86UE*2`M(#%=*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O($9I
M;'1E<FEN9RX*("`@("`@("`@("`@:68@*"1T:&ES+3Y?9FEL=&5R36%T8V@H
M)&9I;'1E<BP@)&9I;&5;)VYA;64G72DI('L*("`@("`@("`@("`@("`@('5N
M<V5T*"1F:6QE*3L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("@D9&ER;VYL>2`F)B`D9FEL95LG='EP
M92==("$]/2`G*BID:7(G*2!["B`@("`@("`@("`@("`@("!U;G-E="@D9FEL
M92D["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@)&9I;&5S6R1F:6QE6R=N86UE)UU=(#T@)&9I;&4["B`@
M("`@("`@("`@('5N<V5T*"1F:6QE*3L*("`@("`@("!]"@H@("`@("`@(&EF
M("AI<W-E="@D;VQD9&ER*2D@>PH@("`@("`@("`@("`D<F5S(#T@)'1H:7,M
M/E]S9710871H*"1O;&1D:7(I.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E
M<SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@)&9I
M;&5S.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A('-O<G1E9"!L
M:7-T(&]F(&9O;&1E<G,@:6X@=&AE('-P96-I9FEE9"!D:7)E8W1O<GDN"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@("`@(%1H92!P
M871H(&]F('1H92!D:7)E8W1O<GD@=&\@9V5T('1H90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&1I<F5C=&]R>2!L:7-T(&9O<BX*("`@
M("`J($!P87)A;2!M:7AE9"`D9FEL=&5R("`@("`@("!(87-H(&]F(&ET96US
M('1O(&9I;'1E<B!B87-E9"!O;B!F;VQD97)L:7-T+@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)&1O=&9O;&1E<G,@($EN8VQU9&4@9&]T9F]L9&5R<S\*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!&;VQD97(@;&ES="!O;B!S=6-C
M97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@;&ES=$9O;&1E<G,H)'!A=&@@/2`G)RP@)&9I;'1E
M<B`](&YU;&PL("1D;W1F;VQD97)S(#T@=')U92D*("`@('L*("`@("`@("`D
M8V]N;B`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1C
M;VYN+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N
M;CL*("`@("`@("!]"@H@("`@("`@("1F;VQD97)S(#T@87)R87DH*3L*("`@
M("`@("`D9F]L9&5R(#T@87)R87DH*3L*"B`@("`@("`@)&9O;&1E<DQI<W0@
M/2`D=&AI<RT^;&ES=$9O;&1E<B@D<&%T:"P@;G5L;"P@)&1O=&9O;&1E<G,L
M('1R=64I.PH@("`@("`@(&EF("AI<U]A*"1F;VQD97),:7-T+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D9F]L9&5R3&ES=#L*("`@
M("`@("!]"@H@("`@("`@("1F;VQD97);)W9A;"==(#T@)'1H:7,M/E]P87)E
M;G1$:7(H)'!A=&@I.PH@("`@("`@("1F;VQD97);)V%B8G)E=B==(#T@)RXN
M)SL*("`@("`@("`D9F]L9&5R6R=L86)E;"==(#T@)RXN)SL*"B`@("`@("`@
M)&9O;&1E<G-;)&9O;&1E<ELG=F%L)UU=(#T@)&9O;&1E<CL*"B`@("`@("`@
M9F]R96%C:"`H)&9O;&1E<DQI<W0@87,@)&9I;&5S*2!["B`@("`@("`@("`@
M("1F;VQD97);)W9A;"==(#T@)'1H:7,M/E]G9710871H*"1P871H+"`D9FEL
M97-;)VYA;64G72D["B`@("`@("`@("`@("1F;VQD97);)V%B8G)E=B==(#T@
M)&9I;&5S6R=N86UE)UT["B`@("`@("`@("`@("1F;VQD97);)VQA8F5L)UT@
M/2`D9F]L9&5R6R=V86PG73L*"B`@("`@("`@("`@("1F;VQD97)S6R1F;VQD
M97);)W9A;"==72`]("1F;VQD97(["B`@("`@("`@?0H*("`@("`@("!K<V]R
M="@D9F]L9&5R<RD["B`@("`@("`@<F5T=7)N("1F;VQD97)S.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0V]P:65S(&$@9FEL92!T:')O=6=H('1H92!B86-K
M96YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P
M871H(&]F('1H92!O<FEG:6YA;"!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;F%M92`@5&AE(&YA;64@;V8@=&AE(&]R:6=I;F%L(&9I;&4N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1D97-T("!4:&4@;F%M92!O9B!T:&4@9&5S=&EN
M871I;VX@9&ER96-T;W)Y+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O<'DH)'!A=&@L("1N86UE
M+"`D9&5S="D*("`@('L*("`@("`@("`D;W)I9R`]("1T:&ES+3Y?9V5T4&%T
M:"@D<&%T:"P@)&YA;64I.PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"=\7B<@
M+B!P<F5G7W%U;W1E*"1O<FEG*2`N("<O/R1\)RP@)&1E<W0I*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-A;FYO="!C;W!Y
M(&9I;&4H<RD@+2!S;W5R8V4@86YD(&1E<W1I;F%T:6]N(&%R92!T:&4@<V%M
M92XB*2D["B`@("`@("`@?0H*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N
M;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@
M("`@("1F:6QE0VAE8VL@/2`D=&AI<RT^;&ES=$9O;&1E<B@D9&5S="P@;G5L
M;"P@=')U92D["B`@("`@("`@:68@*&ES7V$H)&9I;&5#:&5C:RP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&9I;&5#:&5C:SL*("`@
M("`@("!]"B`@("`@("`@9F]R96%C:"`H)&9I;&5#:&5C:R!A<R`D9FEL92D@
M>PH@("`@("`@("`@("!I9B`H)&9I;&5;)VYA;64G72`]/2`D;F%M92D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT
M9BA?*"(E<R!A;')E861Y(&5X:7-T<RXB*2P@)'1H:7,M/E]G9710871H*"1D
M97-T+"`D;F%M92DI*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@)&ES1&ER(#T@9F%L<V4["B`@("`@("`@)&1I<D-H96-K(#T@)'1H:7,M
M/FQI<W1&;VQD97(H)'!A=&@L(&YU;&PL(&9A;'-E*3L*("`@("`@("!I9B`H
M:7-?82@D9&ER0VAE8VLL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1D:7)#:&5C:SL*("`@("`@("!]"B`@("`@("`@9F]R96%C:"`H
M)&1I<D-H96-K(&%S("1F:6QE*2!["B`@("`@("`@("`@(&EF("@D9FEL95LG
M;F%M92==(#T]("1N86UE("8F("1F:6QE6R=T>7!E)UT@/3T@)RHJ9&ER)RD@
M>PH@("`@("`@("`@("`@("`@)&ES1&ER(#T@=')U93L*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I
M9B`H)&ES1&ER*2!["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^8W)E
M871E1F]L9&5R*"1D97-T+"`D;F%M92D["@H@("`@("`@("`@("!I9B`H:7-?
M82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&9I
M;&5?;&ES="`]("1T:&ES+3YL:7-T1F]L9&5R*"1T:&ES+3Y?9V5T4&%T:"@D
M<&%T:"P@)&YA;64I*3L*("`@("`@("`@("`@9F]R96%C:"`H)&9I;&5?;&ES
M="!A<R`D9FEL92D@>PH@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES
M+3YC;W!Y*"1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@)&YA;64I+"`D9FEL95LG
M;F%M92==+"`D=&AI<RT^7V=E=%!A=&@H)&1E<W0L("1N86UE*2D["B`@("`@
M("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=&UP1FEL92`]("1T:&ES+3Y?9V5T5&5M<$9I;&4H*3L*("`@
M("`@("`@("`@)&9E=&-H(#T@0&9T<%]G970H)'1H:7,M/E]S=')E86TL("1T
M;7!&:6QE+"`D;W)I9RP@1E107T))3D%262D["B`@("`@("`@("`@(&EF("@A
M)&9E=&-H*2!["B`@("`@("`@("`@("`@("!U;FQI;FLH)'1M<$9I;&4I.PH@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT
M9BA?*")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB*2P@)&]R:6<I*3L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"%`9G1P7W!U="@D=&AI
M<RT^7W-T<F5A;2P@)'1H:7,M/E]G9710871H*"1D97-T+"`D;F%M92DL("1T
M;7!&:6QE+"!&5%!?0DE.05)9*2D@>PH@("`@("`@("`@("`@("`@=6YL:6YK
M*"1T;7!&:6QE*3L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*'-P<FEN=&8H7R@B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(I
M+"`D=&AI<RT^7V=E=%!A=&@H)&1E<W0L("1N86UE*2DI.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!U;FQI;FLH)'1M<$9I;&4I.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!-
M;W9E<R!A(&9I;&4@=&AR;W5G:"!T:&4@8F%C:V5N9"X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!O9B!T:&4@;W)I9VEN
M86P@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!N86UE
M(&]F('1H92!O<FEG:6YA;"!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M9&5S="`@5&AE(&1E<W1I;F%T:6]N(&9I;&4@;F%M92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R
M<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!M
M;W9E*"1P871H+"`D;F%M92P@)&1E<W0I"B`@("!["B`@("`@("`@)&]R:6<@
M/2`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*3L*("`@("`@("!I9B`H
M<')E9U]M871C:"@G?%XG("X@<')E9U]Q=6]T92@D;W)I9RD@+B`G+S\D?"<L
M("1D97-T*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BA?*")#86YN;W0@;6]V92!F:6QE*',I("T@9&5S=&EN871I;VX@:7,@=VET
M:&EN('-O=7)C92XB*2D["B`@("`@("`@?0H*("`@("`@("`D8V]N;B`]("1T
M:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@
M("!]"@H@("`@("`@("1F:6QE0VAE8VL@/2`D=&AI<RT^;&ES=$9O;&1E<B@D
M9&5S="P@;G5L;"P@=')U92D["B`@("`@("`@9F]R96%C:"`H)&9I;&5#:&5C
M:R!A<R`D9FEL92D@>PH@("`@("`@("`@("!I9B`H)&9I;&5;)VYA;64G72`]
M/2`D;F%M92D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H<W!R:6YT9BA?*"(E<R!A;')E861Y(&5X:7-T<RXB*2P@)'1H:7,M
M/E]G9710871H*"1D97-T+"`D;F%M92DI*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@:68@*"%`9G1P7W)E;F%M92@D=&AI<RT^7W-T<F5A
M;2P@)&]R:6<L("1T:&ES+3Y?9V5T4&%T:"@D9&5S="P@)&YA;64I*2D@>PH@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H
M(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB*2P@)'1H:7,M/E]G9710871H
M*"1D97-T+"`D;F%M92DI*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8W5R<F5N
M="!W;W)K:6YG(&1I<F5C=&]R>2!O;B!T:&4@1E10('-E<G9E<BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-U<G)E;G0@=V]R:VEN9R!D
M:7)E8W1O<GDN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-U<G)E;G1$:7)E
M8W1O<GDH*0H@("`@>PH@("`@("`@(&EF("AI<U]A*"1C;VYN96-T960@/2`D
M=&AI<RT^7V-O;FYE8W0H*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&-O;FYE8W1E9#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M(&9T<%]P=V0H)'1H:7,M/E]S=')E86TI.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0VAA;F=E<R!T:&4@8W5R<F5N="!D:7)E8W1O<GD@;VX@=&AE('-E<G9E
M<BX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!T;R!C:&%N9V4@=&\N
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S
M+"!O<B!A(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@7W-E=%!A=&@H)'!A=&@I"B`@("!["B`@("`@("`@:68@*"%`9G1P
M7V-H9&ER*"1T:&ES+3Y?<W1R96%M+"`D<&%T:"DI('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@
M8VAA;F=E('1O("5S+B(I+"`D<&%T:"DI.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE
M(&9U;&P@<&%T:"!O9B!A;B!I=&5M+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H
M92!D:7)E8W1O<GD@;V8@=&AE(&ET96TN"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N86UE("!4:&4@;F%M92!O9B!T:&4@:71E;2X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!&=6QL('!A=&@@=&\@=&AE(&9I;&4@=VAE;B`D<&%T
M:"!I<R!N;W0@96UP='D@86YD(&IU<W0*("`@("`J("`@("`@("`@("`@("`@
M("1N86UE('=H96X@;F]T('-E="X*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E
M=%!A=&@H)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@(&EF("@D<&%T:"`A
M/3T@)R<I('L*("`@("`@("`@("`@<F5T=7)N("@D<&%T:"`N("<O)R`N("1N
M86UE*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("@D;F%M92D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!P87)E;G0@9&ER96-T;W)Y
M(&]F('1H92!S<&5C:69I960@<&%T:"X*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4
M:&4@<&%T:"!T;R!G970@=&AE('!A<F5N="!O9BX*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE('!A<F5N="!D:7)E8W1O<GD@*'-T<FEN9RD@
M;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(*("`@("`J("`@("`@("`@("`@
M("`@("!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M7W!A<F5N=$1I<B@D<&%T:"D*("`@('L*("`@("`@("`D8V]N;B`]("1T:&ES
M+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]
M"@H@("`@("`@("1O;&1D:7(@/2`D=&AI<RT^9V5T0W5R<F5N=$1I<F5C=&]R
M>2@I.PH@("`@("`@($!F='!?8V1U<"@D=&AI<RT^7W-T<F5A;2D["@H@("`@
M("`@("1P87)E;G0@/2`D=&AI<RT^9V5T0W5R<F5N=$1I<F5C=&]R>2@I.PH@
M("`@("`@("1T:&ES+3Y?<V5T4&%T:"@D;VQD9&ER*3L*"B`@("`@("`@:68@
M*"$D<&%R96YT*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*%\H(E5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN
M(BDI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1P87)E;G0["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!O<&5N(&$@8V]N;F5C=&EO
M;B!T;R!T:&4@1E10('-E<G9E<BX*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U
M8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?8V]N;F5C="@I"B`@("!["B`@("`@("`@:68@
M*"1T:&ES+3Y?<W1R96%M(#T]/2!F86QS92D@>PH@("`@("`@("`@("!I9B`H
M(65X=&5N<VEO;E]L;V%D960H)V9T<"<I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")4:&4@1E10(&5X=&5N<VEO;B!I
M<R!N;W0@879A:6QA8FQE+B(I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@:68@*"%I<U]A<G)A>2@D=&AI<RT^7W!A<F%M<RDI('L*("`@("`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DYO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+B(I*3L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@)')E<75I<F5D(#T@87)R87DH
M)VAO<W1S<&5C)RP@)W5S97)N86UE)RP@)W!A<W-W;W)D)RD["B`@("`@("`@
M("`@(&9O<F5A8V@@*"1R97%U:7)E9"!A<R`D=F%L*2!["B`@("`@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R86US6R1V86Q=*2D@>PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN
M=&8H7R@B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O
M;F9I9W5R871I;VXN(BDL("1V86PI*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@+RH@0V]N;F5C="!T;R!T:&4@9G1P
M('-E<G9E<B!U<VEN9R!T:&4@<W5P<&QI960@<&%R86UE=&5R<RX@*B\*("`@
M("`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG<W-L)UTI*2![
M"B`@("`@("`@("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=F='!?<W-L
M7V-O;FYE8W0G*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<W1R
M96%M(#T@0&9T<%]S<VQ?8V]N;F5C="@D=&AI<RT^7W!A<F%M<ULG:&]S='-P
M96,G72P@)'1H:7,M/E]P87)A;7-;)W!O<G0G72D["B`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(I*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<W1R96%M(#T@0&9T<%]C;VYN96-T*"1T:&ES
M+3Y?<&%R86US6R=H;W-T<W!E8R==+"`D=&AI<RT^7W!A<F%M<ULG<&]R="==
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(21T:&ES+3Y?<W1R
M96%M*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BA?*")#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(I*3L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)&-O;FYE8W1E9"`]($!F='!?;&]G
M:6XH)'1H:7,M/E]S=')E86TL("1T:&ES+3Y?<&%R86US6R=U<V5R;F%M92==
M+"`D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72D["B`@("`@("`@("`@(&EF
M("@A)&-O;FYE8W1E9"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]D:7-C
M;VYN96-T*"D["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BA?*")!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB
M*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@A96UP='DH)'1H
M:7,M/E]P87)A;7-;)W!A<W8G72DI('L*("`@("`@("`@("`@("`@($!F='!?
M<&%S=B@D=&AI<RT^7W-T<F5A;2P@=')U92D["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;)W1I;65O=70G
M72DI('L*("`@("`@("`@("`@("`@(&9T<%]S971?;W!T:6]N*"1T:&ES+3Y?
M<W1R96%M+"!&5%!?5$E-14]55%]314,L("1T:&ES+3Y?<&%R86US6R=T:6UE
M;W5T)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($1I<V-O;FYE8W1S(&9R
M;VT@=&AE($944"!S97)V97(@86YD(&-L96%N<R!U<"!T:&4@8V]N;F5C=&EO
M;BX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V1I<V-O;FYE8W0H*0H@("`@>PH@("`@("`@($!F='!?<75I
M="@D=&AI<RT^7W-T<F5A;2D["B`@("`@("`@)'1H:7,M/E]S=')E86T@/2!F
M86QS93L*("`@('T*"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O5D93+T)R
M;W=S97(N<&AP````````````````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#(V,S8@,3`U,34T,S,W,S4@,#(Q,3$P`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B!#;&%S
M<R!F;W(@<')O=FED:6YG(&$@9V5N97)I8R!522!F;W(@86YY(%9&4R!I;G-T
M86YC92X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5D93+U9&4R]"<F]W<V5R
M+G!H<"QV(#$N."XQ,"XY(#(P,#8O,#4O,S$@,#0Z-3`Z,#(@<VQU<V%R>B!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!P86-K
M86=E(%9&4PH@*B\*8VQA<W,@5D937T)R;W=S97(@>PH*("`@("\J*@H@("`@
M("H@5&AE(%9&4R!I;G-T86YC92!T:&%T('=E(&%R92!B<F]W<VEN9RX*("`@
M("`J"B`@("`@*B!`=F%R(%9&4PH@("`@("HO"B`@("!V87(@)%]V9G,["@H@
M("`@+RHJ"B`@("`@*B!4:&4@9&ER96-T;W)Y('=H97)E('1H92!T96UP;&%T
M97,@=&\@=7-E(&%R92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)%]T96UP;&%T97,["@H@("`@+RHJ"B`@("`@*B!#;VYS
M=')U8W1O<@H@("`@("H*("`@("`J($!P87)A;2!61E,@)B1V9G,@("`@("`@
M("`@02!61E,@;V)J96-T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5M<&QA
M=&5S("!43T1/"B`@("`@*B\*("`@(&9U;F-T:6]N(%9&4U]"<F]W<V5R*"8D
M=F9S+"`D=&5M<&QA=&5S*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=F9S
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W9F<R`]("1V9G,["B`@("`@("`@
M?0H@("`@("`@("1T:&ES+3Y?=&5M<&QA=&5S(#T@)'1E;7!L871E<SL*("`@
M('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@5D93(&]B:F5C="!I;B!T:&4@
M;&]C86P@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!61E,@)B1V9G,@
M($$@5D93(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T5D933V)J
M96-T*"8D=F9S*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=F9S(#T@)B1V9G,[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!43T1/"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<&%T:"`@("`@("!43T1/"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D9&]T9FEL97,@(%1/1$\*("`@("`J($!P87)A;2!B;V]L96%N("1D
M:7)O;FQY("`@5$]$3PH@("`@("HO"B`@("!F=6YC=&EO;B!G971522@D<&%T
M:"P@)&1O=&9I;&5S(#T@9F%L<V4L("1D:7)O;FQY(#T@9F%L<V4I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]V9G,M/FQI<W1&;VQD97(H)'!A=&@L("1D;W1F
M:6QE<RP@)&1I<F]N;'DI.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B]61E,O<W%L7V9I;&4N<&AP````````````````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`W,C0U-"`Q,#4Q-30S,S<S
M-2`P,C$R-S``(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*"B\J*@H@*B!&:6QE('9A;'5E(&9O<B!V9G-?='EP92!C
M;VQU;6XN"B`J+PID969I;F4H)U9&4U]&24Q%)RP@,2D["@HO*BH*("H@1F]L
M9&5R('9A;'5E(&9O<B!V9G-?='EP92!C;VQU;6XN"B`J+PID969I;F4H)U9&
M4U]&3TQ$15(G+"`R*3L*"B\J*@H@*B!61E,Z.B!I;7!L96UE;G1A=&EO;B!U
M<VEN9R!02%`G<R!014%2(&1A=&%B87-E(&%B<W1R86-T:6]N"B`J(&QA>65R
M(&%N9"!L;V-A;"!F:6QE('-Y<W1E;2!F;W(@9FEL92!S=&]R86=E+@H@*@H@
M*B!297%U:7)E9"!V86QU97,@9F]R("1P87)A;7,Z/'!R93X*("H@("`@("`G
M<&AP='EP92<@("`@("`@5&AE(&1A=&%B87-E('1Y<&4@*&EE+B`G<&=S<6PG
M+"`G;7ES<6PG+"!E=&,N*2X*("H@("`@("`G=F9S<F]O="<@("`@("`@5&AE
M(')O;W0@9&ER96-T;W)Y(&]F('=H97)E('1H92!F:6QE<R!S:&]U;&0@8F4*
M("H@("`@("`@("`@("`@("`@("`@("`@86-T=6%L;'D@<W1O<F5D+CPO<')E
M/@H@*@H@*B!/<'1I;VYA;"!V86QU97,Z/'!R93X*("H@("`@("`G=&%B;&4G
M("`@("`@("`@5&AE(&YA;64@;V8@=&AE('9F<R!T86)L92!I;B`G9&%T86)A
M<V4G+B!$969A=6QT<R!T;PH@*B`@("`@("`@("`@("`@("`@("`@("`G:&]R
M9&5?=F9S)RX\+W!R93X*("H*("H@4F5Q=6ER960@8GD@<V]M92!D871A8F%S
M92!I;7!L96UE;G1A=&EO;G,Z/'!R93X*("H@("`@("`G:&]S='-P96,G("`@
M("`@5&AE(&AO<W1N86UE(&]F('1H92!D871A8F%S92!S97)V97(N"B`J("`@
M("`@)W!R;W1O8V]L)R`@("`@(%1H92!C;VUM=6YI8V%T:6]N('!R;W1O8V]L
M("@G=&-P)RP@)W5N:7@G+"!E=&,N*2X*("H@("`@("`G9&%T86)A<V4G("`@
M("`@5&AE(&YA;64@;V8@=&AE(&1A=&%B87-E+@H@*B`@("`@("=U<V5R;F%M
M92<@("`@("!4:&4@=7-E<FYA;64@=VET:"!W:&EC:"!T;R!C;VYN96-T('1O
M('1H92!D871A8F%S92X*("H@("`@("`G<&%S<W=O<F0G("`@("`@5&AE('!A
M<W-W;W)D(&%S<V]C:6%T960@=VET:"`G=7-E<FYA;64G+@H@*B`@("`@("=O
M<'1I;VYS)R`@("`@("!!9&1I=&EO;F%L(&]P=&EO;G,@=&\@<&%S<R!T;R!T
M:&4@9&%T86)A<V4N"B`J("`@("`@)W1T>2<@("`@("`@("`@(%1H92!45%D@
M;VX@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N"B`J("`@("`@
M)W!O<G0G("`@("`@("`@(%1H92!P;W)T(&]N('=H:6-H('1O(&-O;FYE8W0@
M=&\@=&AE(&1A=&%B87-E+CPO<')E/@H@*@H@*B!4:&4@=&%B;&4@<W1R=6-T
M=7)E(&9O<B!T:&4@5D93(&-A;B!B92!F;W5N9"!I;@H@*B!D871A+W9F<RYS
M<6PN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP+'8@,2XT-"XT+C(R(#(P,#8O,#4O,S$@,#0Z-3`Z,#(@<VQU<V%R>B!%
M>'`@)`H@*@H@*B!`875T:&]R("!-:6-H865L(%9A<F=H97-E(#QM:6ME+G9A
M<F=H97-E0&%S8V5L;&%T96-H+F-O;3X*("H@0'!A8VMA9V4@5D93"B`J+PIC
M;&%S<R!61E-?<W%L7V9I;&4@97AT96YD<R!61E,@>PH*("`@("\J*@H@("`@
M("H@2&%N9&QE(&9O<B!T:&4@8W5R<F5N="!D871A8F%S92!C;VYN96-T:6]N
M+@H@("`@("H*("`@("`J($!V87(@1$(*("`@("`J+PH@("`@=F%R("1?9&(@
M/2!F86QS93L*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('-I>F4@;V8@
M82!F:6QE+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@;V8@=&AE(&9I
M;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@9FEL96YA;64N
M"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@<VEZ92!O9B!T
M:&4@9FEL92!I;B!B>71E<R!O<B!014%27T5R<F]R(&]N"B`@("`@*B`@("`@
M("`@("`@("`@("`@(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-I
M>F4H)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@(&EF("@H)'-I>F4@/2!`
M9FEL97-I>F4H)'1H:7,M/E]G971.871I=F50871H*"1P871H+"`D;F%M92DI
M*2`]/3T@9F%L<V4I>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BAS<')I;G1F*%\H(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@
M7"(E<R\E<UPB+B(L("1P871H+"`D;F%M92DI*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D<VEZ93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I
M979E(&$@9FEL92!F<F]M('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<&%T:"`@5&AE('!A=&AN86UE('1O('1H92!F:6QE+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&9I;&5N86UE('1O(')E=')I
M979E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9FEL92!D
M871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96%D*"1P871H+"`D;F%M92D*
M("`@('L*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@
M("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@("`@("1F:6QE(#T@
M)'1H:7,M/E]G971.871I=F50871H*"1P871H+"`D;F%M92D["@H@("`@("`@
M(&EF("AF=6YC=&EO;E]E>&ES=',H)V9I;&5?9V5T7V-O;G1E;G1S)RDI('L*
M("`@("`@("`@("`@)&1A=&$@/2!F:6QE7V=E=%]C;VYT96YT<R@D9FEL92D[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&9P(#T@0&9O<&5N*"1F
M:6QE+"`G<F(G*3L*("`@("`@("`@("`@:68@*"$D9G`I('L*("`@("`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!O
M<&5N(%9&4R!F:6QE+B(I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M9&%T82`](&9R96%D*"1F<"P@9FEL97-I>F4H)&9I;&4I*3L*("`@("`@("`@
M("`@9F-L;W-E*"1F<"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&1A
M=&$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3=&]R92!A(&9I;&4@:6X@=&AE
M(%9&4RP@=VET:"!T:&4@9&%T82!C;W!I960@9G)O;2!A('1E;7!O<F%R>0H@
M("`@("H@9FEL92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H
M("`@("`@("`@5&AE('!A=&@@=&\@<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@("`@5&AE(&9I;&5N86UE('1O
M('5S92X*("`@("`J($!P87)A;2!S=')I;F<@)'1M<$9I;&4@("`@("!4:&4@
M=&5M<&]R87)Y(&9I;&4@8V]N=&%I;FEN9R!T:&4@9&%T82!T;R!B90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-T;W)E9"X*("`@("`J
M($!P87)A;2!B;V]L96%N("1A=71O8W)E871E("!!=71O;6%T:6-A;&QY(&-R
M96%T92!D:7)E8W1O<FEE<S\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET92@D<&%T:"P@)&YA
M;64L("1T;7!&:6QE+"`D875T;V-R96%T92`](&9A;'-E*0H@("`@>PH@("`@
M("`@("\J($YO(&YE960@=&\@8VAE8VL@<75O=&$@:&5R92!A<R!W92!W:6QL
M(&-H96-K(&ET('=H96X@=V4@8V%L;`H@("`@("`@("`J('=R:71E1&%T82@I
M+B`J+PH*("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=F:6QE7V=E=%]C
M;VYT96YT<R<I*2!["B`@("`@("`@("`@("1D871A(#T@9FEL95]G971?8V]N
M=&5N=',H)'1M<$9I;&4I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1D871A1E`@/2!`9F]P96XH)'1M<$9I;&4L("=R8B<I.PH@("`@("`@("`@
M("`D9&%T82`]($!F<F5A9"@D9&%T8490+"!F:6QE<VEZ92@D=&UP1FEL92DI
M.PH@("`@("`@("`@("!F8VQO<V4H)&1A=&%&4"D["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D=&AI<RT^=W)I=&5$871A*"1P871H+"`D;F%M92P@)&1A
M=&$L("1A=71O8W)E871E*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-T;W)E
M(&$@9FEL92!I;B!T:&4@5D93(&9R;VT@<F%W(&1A=&$N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@("`@(%1H92!P871H('1O('-T
M;W)E('1H92!F:6QE(&EN+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@
M("`@("`@(%1H92!F:6QE;F%M92!T;R!U<V4N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1D871A("`@("`@("`@5&AE(&9I;&4@9&%T82X*("`@("`J($!P87)A
M;2!B;V]L96%N("1A=71O8W)E871E("!!=71O;6%T:6-A;&QY(&-R96%T92!D
M:7)E8W1O<FEE<S\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E
M(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET941A=&$H)'!A=&@L("1N86UE
M+"`D9&%T82P@)&%U=&]C<F5A=&4@/2!F86QS92D*("`@('L*("`@("`@("`D
M<F5S(#T@)'1H:7,M/E]C:&5C:U%U;W1A5W)I=&4H)W-T<FEN9R<L("1D871A
M*3L*("`@("`@("!I9B`H:7-?82@D<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@('T*"B`@("`@("`@)&9P
M(#T@0&9O<&5N*"1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D<&%T:"P@)&YA;64I
M+"`G=R<I.PH@("`@("`@(&EF("@A)&9P*2!["B`@("`@("`@("`@(&EF("@D
M875T;V-R96%T92D@>PH@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES
M+3YA=71O8W)E871E4&%T:"@D<&%T:"D["B`@("`@("`@("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D9G`@/2!`9F]P96XH)'1H:7,M/E]G971.871I=F50871H
M*"1P871H+"`D;F%M92DL("=W)RD["B`@("`@("`@("`@("`@("!I9B`H(21F
M<"D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*%\H(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(I
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(I*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"%`9G=R:71E*"1F<"P@)&1A
M=&$I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(E5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+B(I*3L*("`@("`@("!]
M"@H@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?=W)I=&5344Q$871A*"1P871H
M+"`D;F%M92P@)&%U=&]C<F5A=&4I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@($!U;FQI;FLH)'1H:7,M/E]G971.871I=F50871H*"1P871H+"`D
M;F%M92DI.PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?
M*")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB*2D["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@36]V97,@82!F:6QE(&EN('1H92!D
M871A8F%S92!A;F0@=&AE(&9I;&4@<WES=&5M+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H('1O('-T;W)E('1H92!F:6QE
M(&EN+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&]L9"!F:6QE
M;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@)&1E<W0@(%1H92!N97<@9FEL
M96YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S
M=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@;6]V92@D<&%T:"P@)&YA;64L("1D97-T*0H@
M("`@>PH@("`@("`@("1O<FEG(#T@)'1H:7,M/E]G971.871I=F50871H*"1P
M871H+"`D;F%M92D["B`@("`@("`@:68@*'!R96=?;6%T8V@H)WQ>)R`N('!R
M96=?<75O=&4H)&]R:6<I("X@)R\_)'PG+"`D9&5S="DI('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V%N;F]T(&UO=F4@9FEL
M92AS*2`M(&1E<W1I;F%T:6]N(&ES('=I=&AI;B!S;W5R8V4N(BDI.PH@("`@
M("`@('T*"B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@
M("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*("`@("`@("`D9FEL94-H
M96-K(#T@)'1H:7,M/FQI<W1&;VQD97(H)&1E<W0L(&YU;&PL(&9A;'-E*3L*
M("`@("`@("!F;W)E86-H("@D9FEL94-H96-K(&%S("1F:6QE*2!["B`@("`@
M("`@("`@(&EF("@D9FEL95LG;F%M92==(#T]("1N86UE*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@
M;6]V92!61E,@9FEL92XB*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(&EF("AS=')P;W,H)&1E<W0L("1T:&ES+3Y?9V5T4U%,3F%T:79E
M4&%T:"@D<&%T:"P@)&YA;64I*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(&UO=F4@5D93
M(&9I;&4N(BDI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3YR
M96YA;64H)'!A=&@L("1N86UE+"`D9&5S="P@)&YA;64I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0V]P:65S(&$@9FEL92!T:')O=6=H('1H92!B86-K96YD
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H
M('1O('-T;W)E('1H92!F:6QE(&EN+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;F%M92`@5&AE(&9I;&5N86UE('1O('5S92X*("`@("`J($!P87)A;2!S=')I
M;F<@)&1E<W0@(%1H92!D97-T:6YA=&EO;B!O9B!T:&4@9FEL92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!0
M14%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!C;W!Y*"1P871H+"`D;F%M92P@)&1E<W0I"B`@("!["B`@("`@("`@
M)&]R:6<@/2`D=&AI<RT^7V=E=$YA=&EV95!A=&@H)'!A=&@L("1N86UE*3L*
M("`@("`@("!I9B`H<')E9U]M871C:"@G?%XG("X@<')E9U]Q=6]T92@D;W)I
M9RD@+B`G+S\D?"<L("1D97-T*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BA?*")#86YN;W0@8V]P>2!F:6QE*',I("T@<V]U<F-E
M(&%N9"!D97-T:6YA=&EO;B!A<F4@=&AE('-A;64N(BDI.PH@("`@("`@('T*
M"B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I
M9B`H:7-?82@D8V]N;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)&-O;FX["B`@("`@("`@?0H*("`@("`@("`D9FEL94-H96-K(#T@
M)'1H:7,M/FQI<W1&;VQD97(H)&1E<W0L(&YU;&PL(&9A;'-E*3L*("`@("`@
M("!F;W)E86-H("@D9FEL94-H96-K(&%S("1F:6QE*2!["B`@("`@("`@("`@
M(&EF("@D9FEL95LG;F%M92==(#T]("1N86UE*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@8V]P>2!6
M1E,@9FEL92XB*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(&EF("AS=')P;W,H)&1E<W0L("1T:&ES+3Y?9V5T4U%,3F%T:79E4&%T:"@D
M<&%T:"P@)&YA;64I*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N
M(BDI.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7V1I<B@D;W)I9RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F5C=7)S:79E0V]P>2@D<&%T
M:"P@)&YA;64L("1D97-T*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A0&-O
M<'DH)&]R:6<L("1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D9&5S="P@)&YA;64I
M*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5
M;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB*2D["B`@("`@("`@?0H*("`@("`@
M("`D:60@/2`D=&AI<RT^7V1B+3YN97AT260H)'1H:7,M/E]P87)A;7-;)W1A
M8FQE)UTI.PH*("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=)3E-%4E0@24Y4
M3R`E<R`H=F9S7VED+"!V9G-?='EP92P@=F9S7W!A=&@L('9F<U]N86UE+"!V
M9G-?;6]D:69I960L('9F<U]O=VYE<BD@5D%,5453("@_+"`_+"`_+"`_+"`_
M+"`_*2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M
M<ULG=&%B;&4G72D["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"1I9"P@5D93
M7T9)3$4L("1D97-T+"`D;F%M92P@=&EM92@I+"`D=&AI<RT^7W!A<F%M<ULG
M=7-E<B==*3L*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y
M*"1Q=65R>2P@)'9A;'5E<RD["@H@("`@("`@(&EF("AI<U]A*"1R97-U;'0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@=6YL:6YK*"1T:&ES+3Y?
M9V5T3F%T:79E4&%T:"@D9&5S="P@)&YA;64I*3L*("`@("`@("`@("`@<F5T
M=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@82!F;VQD97(@;VX@=&AE
M(%9&4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!(;VQD
M<R!T:&4@<&%T:"!O9B!D:7)E8W1O<GD@=&\@8W)E871E(&9O;&1E<BX*("`@
M("`J($!P87)A;2!S=')I;F<@)&YA;64@($AO;&1S('1H92!N86UE(&]F('1H
M92!N97<@9F]L9&5R+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R
M=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-R96%T949O;&1E<B@D<&%T:"P@
M)&YA;64I"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H
M*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*("`@("`@("`D
M:60@/2`D=&AI<RT^7V1B+3YN97AT260H)'1H:7,M/E]P87)A;7-;)W1A8FQE
M)UTI.PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2AS<')I
M;G1F*"=)3E-%4E0@24Y43R`E<R`H=F9S7VED+"!V9G-?='EP92P@=F9S7W!A
M=&@L('9F<U]N86UE+"!V9G-?;6]D:69I960L('9F<U]O=VYE<BD*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!604Q515,@
M*#\L(#\L(#\L(#\L(#\L(#\I)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1I
M9"P@5D937T9/3$1%4BP@)'!A=&@L("1N86UE+"!T:6UE*"DL("1T:&ES+3Y?
M<&%R86US6R=U<V5R)UTI*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"%`;6MD:7(H)'1H:7,M/E]G971.871I
M=F50871H*"1P871H+"`D;F%M92DI*2!["B`@("`@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^7V1B+3YQ=65R>2AS<')I;G1F*"=$14Q%5$4@1E)/32`E<R!7
M2$5212!V9G-?:60@/2`_)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)&ED*2D["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB*2D["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E;F%M92!A(&9I;&4@;W(@9F]L9&5R(&EN('1H92!61E,N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;VQD<&%T:"`@5&AE(&]L9"!P871H
M('1O('1H92!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;VQD;F%M92`@
M5&AE(&]L9"!F:6QE;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@)&YE=W!A
M=&@@(%1H92!N97<@<&%T:"!O9B!T:&4@9FEL92X*("`@("`J($!P87)A;2!S
M=')I;F<@)&YE=VYA;64@(%1H92!N97<@9FEL96YA;64N"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%
M<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<F5N86UE*"1O;&1P871H+"`D;VQD;F%M92P@)&YE=W!A=&@L("1N97=N86UE
M*0H@("`@>PH@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@
M("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@:68@*'-T
M<G!O<R@D;F5W<&%T:"P@)R\G*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@
M)'!A<F5N="`]("<G.PH@("`@("`@("`@("`D<&%T:"`]("1N97=P871H.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(&QI<W0H)'!A<F5N="P@)'!A
M=&@I(#T@97AP;&]D92@G+R<L("1N97=P871H+"`R*3L*("`@("`@("!]"B`@
M("`@("`@:68@*"$D=&AI<RT^:7-&;VQD97(H)'!A<F5N="P@)'!A=&@I*2![
M"B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^875T;V-R
M96%T95!A=&@H)&YE=W!A=&@I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*'-P<FEN
M=&8H)U501$%412`E<R!3150@=F9S7W!A=&@@/2`_+"!V9G-?;F%M92`](#\L
M('9F<U]M;V1I9FEE9"`](#\*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!72$5212!V9G-?<&%T:"`](#\@04Y$('9F<U]N
M86UE(#T@/R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@D;F5W<&%T:"P@)&YE
M=VYA;64L('1I;64H*2P@)&]L9'!A=&@L("1O;&1N86UE*2D["@H@("`@("`@
M(&EF("@D=&AI<RT^7V1B+3YA9F9E8W1E9%)O=W,H*2`]/2`P*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4N(BDI.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES
M7V$H)'1H:7,M/E]R96-U<G-I=F5344Q296YA;64H)&]L9'!A=&@L("1O;&1N
M86UE+"`D;F5W<&%T:"P@)&YE=VYA;64I+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2AS<')I;G1F
M*"=54$1!5$4@)7,@4T54('9F<U]P871H(#T@/RP@=F9S7VYA;64@/2`_"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%=(15)%('9F<U]P871H(#T@/R!!3D0@=F9S7VYA;64@/2`_)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)W1A8FQE)UTI+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@87)R87DH)&]L9'!A=&@L("1O;&1N86UE+"`D
M;F5W<&%T:"P@)&YE=VYA;64I*3L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y
M+B(I*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A0&ES7V1I<B@D=&AI<RT^
M7V=E=$YA=&EV95!A=&@H)&YE=W!A=&@I*2D@>PH@("`@("`@("`@("!I9B`H
M:7-?82@D<F5S(#T@)'1H:7,M/F%U=&]C<F5A=&50871H*"1N97=P871H*2P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97,[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@A0')E;F%M
M92@D=&AI<RT^7V=E=$YA=&EV95!A=&@H)&]L9'!A=&@L("1O;&1N86UE*2P@
M)'1H:7,M/E]G971.871I=F50871H*"1N97=P871H+"`D;F5W;F%M92DI*2![
M"B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2AS<')I
M;G1F*"=54$1!5$4@)7,@4T54('9F<U]P871H(#T@/RP@=F9S7VYA;64@/2`_
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(%=(15)%('9F<U]P871H(#T@/R!!3D0@=F9S7VYA;64@/2`_)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)&]L9'!A=&@L("1O;&1N86UE
M+"`D;F5W<&%T:"P@)&YE=VYA;64I*3L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB
M*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O*BH*("`@("`J($1E;&5T92!A(&9O;&1E<B!F<F]M('1H92!61E,N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@("`@5&AE('!A
M=&@@=&\@9&5L971E('1H92!F;VQD97(@9G)O;2X*("`@("`J($!P87)A;2!S
M=')I;F<@)&YA;64@("`@("`@(%1H92!F;VQD97)N86UE('1O('5S92X*("`@
M("`J($!P87)A;2!B;V]L96%N("1R96-U<G-I=F4@($9O<F-E(&$@<F5C=7)S
M:79E(&1E;&5T93\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E
M(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96QE=&5&;VQD97(H)'!A=&@L("1N
M86UE+"`D<F5C=7)S:79E(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&-O;FX@
M/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX["B`@
M("`@("`@?0H*("`@("`@("!I9B`H)')E8W5R<VEV92D@>PH@("`@("`@("`@
M("`D<F5S=6QT(#T@)'1H:7,M/F5M<'1Y1F]L9&5R*"1P871H("X@)R\G("X@
M)&YA;64I.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1L:7-T
M(#T@)'1H:7,M/FQI<W1&;VQD97(H)'!A=&@@+B`G+R<@+B`D;F%M92D["B`@
M("`@("`@("`@(&EF("AI<U]A*"1L:7-T+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)&QI<W0["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@:68@*&-O=6YT*"1L:7-T*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@
M9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<&%T:"`N("<O)R`N("1N86UE*2D["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2AS<')I;G1F
M*"=$14Q%5$4@1E)/32`E<R!72$5212!V9G-?='EP92`](#\@04Y$('9F<U]P
M871H(#T@/R!!3D0@=F9S7VYA;64@/2`_)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B
M;&4G72DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*%9&4U]&3TQ$15(L("1P871H+"`D;F%M92DI.PH*("`@("`@("!I9B`H
M)'1H:7,M/E]D8BT^869F96-T9612;W=S*"D@/3T@,"!\?"!I<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y
M+B(I*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?<F5C
M=7)S:79E4U%,1&5L971E*"1P871H+"`D;F%M92DL("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA
M8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(I*3L*
M("`@("`@("!]"@H@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?<F5C=7)S:79E
M3$931&5L971E*"1P871H+"`D;F%M92DL("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O
M(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(I*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1&5L971E(&$@9FEL92!F<F]M('1H92!61E,N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@=&\@<W1O<F4@=&AE
M(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@9FEL
M96YA;64@=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R
M=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T949I;&4H)'!A=&@L("1N
M86UE*0H@("`@>PH@("`@("`@("1R97,@/2`D=&AI<RT^7V-H96-K475O=&%$
M96QE=&4H)'!A=&@L("1N86UE*3L*("`@("`@("!I9B`H:7-?82@D<F5S+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@
M("`@('T*"B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@
M("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT
M(#T@)'1H:7,M/E]D8BT^<75E<GDH<W!R:6YT9B@G1$5,151%($923TT@)7,@
M5TA%4D4@=F9S7W1Y<&4@/2`_($%.1"!V9G-?<&%T:"`](#\@04Y$('9F<U]N
M86UE(#T@/R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2A61E-?1DE,12P@)'!A
M=&@L("1N86UE*2D["@H@("`@("`@(&EF("@D=&AI<RT^7V1B+3YA9F9E8W1E
M9%)O=W,H*2`]/2`P*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*%\H(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N(BDI.PH@("`@
M("`@('T*"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@
M("`@("`@(&EF("@A0'5N;&EN:R@D=&AI<RT^7V=E=$YA=&EV95!A=&@H)'!A
M=&@L("1N86UE*2DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H7R@B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB*2D["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;B!A(&QI<W0@;V8@=&AE(&-O;G1E;G1S(&]F(&$@9F]L9&5R
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@("`@("`@5&AE
M(&1I<F5C=&]R>2!P871H+@H@("`@("H@0'!A<F%M(&UI>&5D("1F:6QT97(@
M("`@("!3=')I;F<O:&%S:"!O9B!I=&5M<R!T;R!F:6QT97(@8F%S960@;VX*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@9FEL96YA;64N"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B`D9&]T9FEL97,@(%-H;W<@9&]T9FEL97,_
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&ER;VYL>2`@(%-H;W<@9&ER96-T
M;W)I97,@;VYL>3\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!&:6QE
M(&QI<W0@;VX@<W5C8V5S<R!O<B!F86QS92!O;B!F86EL=7)E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?;&ES=$9O;&1E<B@D<&%T:"P@)&9I;'1E<B`](&YU
M;&PL("1D;W1F:6QE<R`]('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@
M("1D:7)O;FQY(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI
M<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@
M?0H*("`@("`@("`D9FEL97,@/2!A<G)A>2@I.PH@("`@("`@("1F:6QE3&ES
M="`](&%R<F%Y*"D["@H@("`@("`@("1F:6QE3&ES="`]("1T:&ES+3Y?9&(M
M/F=E=$%L;"AS<')I;G1F*"=314Q%0U0@=F9S7VYA;64L('9F<U]T>7!E+"!V
M9G-?;6]D:69I960L('9F<U]O=VYE<B!&4D]-("5S"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@5TA%4D4@=F9S7W!A
M=&@@/2`_)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1P871H*2D[
M"B`@("`@("`@:68@*&ES7V$H)&9I;&5,:7-T+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D9FEL94QI<W0["B`@("`@("`@?0H*("`@
M("`@("!F;W)E86-H("@D9FEL94QI<W0@87,@)&QI;F4I('L*("`@("`@("`@
M("`@+R\@1FEL=&5R(&]U="!D;W1F:6QE<R!I9B!T:&5Y(&%R96XG="!W86YT
M960N"B`@("`@("`@("`@(&EF("@A)&1O=&9I;&5S("8F('-U8G-T<B@D;&EN
M95LP72P@,"P@,2D@/3T@)RXG*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU
M93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&9I;&5;)VYA;64G72`]
M("1L:6YE6S!=.PH*("`@("`@("`@("`@:68@*"1L:6YE6S%=(#T](%9&4U]&
M24Q%*2!["B`@("`@("`@("`@("`@("`D;F%M92`](&5X<&QO9&4H)RXG+"`D
M;&EN95LP72D["@H@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1N86UE*2`]
M/2`Q*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&5;)W1Y<&4G72`]("<J
M*FYO;F4G.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D9FEL95LG='EP92==(#T@5D93.CIS=')T;VQO=V5R*"1N86UE
M6V-O=6YT*"1N86UE*2`M(#%=*3L*("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("`@("`D9FEL95LG<VEZ92==(#T@9FEL97-I>F4H)'1H:7,M/E]G
M971.871I=F50871H*"1P871H+"`D;&EN95LP72DI.PH@("`@("`@("`@("!]
M(&5L<V5I9B`H)&QI;F5;,5T@/3T@5D937T9/3$1%4BD@>PH@("`@("`@("`@
M("`@("`@)&9I;&5;)W1Y<&4G72`]("<J*F1I<B<["B`@("`@("`@("`@("`@
M("`D9FEL95LG<VEZ92==(#T@+3$["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1F:6QE6R=D871E)UT@/2`D;&EN95LR73L*("`@("`@("`@("`@)&9I
M;&5;)V]W;F5R)UT@/2`D;&EN95LS73L*("`@("`@("`@("`@)&9I;&5;)W!E
M<FUS)UT@/2`G)SL*("`@("`@("`@("`@)&9I;&5;)V=R;W5P)UT@/2`G)SL*
M"B`@("`@("`@("`@("\O($9I;'1E<FEN9RX*("`@("`@("`@("`@:68@*"1T
M:&ES+3Y?9FEL=&5R36%T8V@H)&9I;'1E<BP@)&9I;&5;)VYA;64G72DI('L*
M("`@("`@("`@("`@("`@('5N<V5T*"1F:6QE*3L*("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D9&ER
M;VYL>2`F)B`D9FEL95LG='EP92==("$]/2`G*BID:7(G*2!["B`@("`@("`@
M("`@("`@("!U;G-E="@D9FEL92D["B`@("`@("`@("`@("`@("!C;VYT:6YU
M93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&9I;&5S6R1F:6QE6R=N
M86UE)UU=(#T@)&9I;&4["B`@("`@("`@("`@('5N<V5T*"1F:6QE*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D9FEL97,["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS(&$@<V]R=&5D(&QI<W0@;V8@9F]L9&5R<R!I;B!S
M<&5C:69I960@9&ER96-T;W)Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'!A=&@@("`@("`@("!4:&4@<&%T:"!O9B!T:&4@9&ER96-T;W)Y('1O
M(&=E="!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!D
M:7)E8W1O<GD@;&ES="!F;W(N"B`@("`@*B!`<&%R86T@;6EX960@)&9I;'1E
M<B`@("`@("`@4W1R:6YG+VAA<V@@;V8@:71E;7,@=&\@9FEL=&5R(&)A<V5D
M(&]N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]L9&5R
M;&ES="X*("`@("`J($!P87)A;2!B;V]L96%N("1D;W1F;VQD97)S("!);F-L
M=61E(&1O=&9O;&1E<G,_"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@
M1F]L9&5R(&QI<W0@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W1&;VQD97)S
M*"1P871H(#T@)R<L("1F:6QT97(@/2!A<G)A>2@I+"`D9&]T9F]L9&5R<R`]
M('1R=64I"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H
M*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*("`@("`@("`D
M<W%L(#T@<W!R:6YT9B@G4T5,14-4('9F<U]N86UE+"!V9G-?<&%T:"!&4D]-
M("5S(%=(15)%('9F<U]P871H(#T@/R!!3D0@=F9S7W1Y<&4@/2`_)RP*("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72D[
M"@H@("`@("`@("1F;VQD97),:7-T(#T@)'1H:7,M/E]D8BT^9V5T06QL*"1S
M<6PL(&%R<F%Y*"1P871H+"`D5D937T9/3$1%4BDI.PH@("`@("`@(&EF("AI
M<U]A*"1F;VQD97),:7-T+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D9F]L9&5R3&ES=#L*("`@("`@("!]"@H@("`@("`@("1F;VQD
M97)S(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D9F]L9&5R3&ES="!A
M<R`D;&EN92D@>PH@("`@("`@("`@("`D9F]L9&5R6R=V86PG72`]("1T:&ES
M+3Y?9V5T3F%T:79E4&%T:"@D;&EN95LQ72P@)&QI;F5;,%TI.PH@("`@("`@
M("`@("`D9F]L9&5R6R=A8F)R978G72`]("<G.PH@("`@("`@("`@("`D9F]L
M9&5R6R=L86)E;"==(#T@)R<["@H@("`@("`@("`@("`D8V]U;G0@/2!S=6)S
M=')?8V]U;G0H)&9O;&1E<ELG=F%L)UTL("<O)RD["@H@("`@("`@("`@("`D
M>"`](#`["B`@("`@("`@("`@('=H:6QE("@D>"`\("1C;W5N="D@>PH@("`@
M("`@("`@("`@("`@)&9O;&1E<ELG86)B<F5V)UT@+CT@)R`@("`G.PH@("`@
M("`@("`@("`@("`@)&9O;&1E<ELG;&%B96PG72`N/2`G("`@("<["B`@("`@
M("`@("`@("`@("`D>"LK.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M9F]L9&5R6R=A8F)R978G72`N/2`D;&EN95LP73L*("`@("`@("`@("`@)&9O
M;&1E<ELG;&%B96PG72`N/2`D;&EN95LP73L*"B`@("`@("`@("`@("1S=')L
M96X@/2!61E,Z.G-T<FQE;B@D9F]L9&5R6R=L86)E;"==*3L*("`@("`@("`@
M("`@:68@*"1S=')L96X@/B`R-BD@>PH@("`@("`@("`@("`@("`@)&9O;&1E
M<ELG86)B<F5V)UT@/2!S=6)S='(H)&9O;&1E<ELG;&%B96PG72P@,"P@*"1C
M;W5N="`J(#0I*3L*("`@("`@("`@("`@("`@("1L96YG=&@@/2`H,CD@+2`H
M)&-O=6YT("H@-"DI("\@,CL*("`@("`@("`@("`@("`@("1F;VQD97);)V%B
M8G)E=B==("X]('-U8G-T<B@D9F]L9&5R6R=L86)E;"==+"`H)&-O=6YT("H@
M-"DL("1L96YG=&@I.PH@("`@("`@("`@("`@("`@)&9O;&1E<ELG86)B<F5V
M)UT@+CT@)RXN+B<["B`@("`@("`@("`@("`@("`D9F]L9&5R6R=A8F)R978G
M72`N/2!S=6)S='(H)&9O;&1E<ELG;&%B96PG72P@+3$@*B`D;&5N9W1H+"`D
M;&5N9W1H*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&9O=6YD(#T@
M9F%L<V4["B`@("`@("`@("`@(&9O<F5A8V@@*"1F:6QT97(@87,@)&9L='(I
M('L*("`@("`@("`@("`@("`@(&EF("@D9F]L9&5R6R=V86PG72`]/2`D9FQT
M<BD@>PH@("`@("`@("`@("`@("`@("`@("1F;W5N9"`]('1R=64["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@A
M)&9O=6YD*2!["B`@("`@("`@("`@("`@("`D9F]L9&5R<ULD9F]L9&5R6R=V
M86PG75T@/2`D9F]L9&5R.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!K<V]R="@D9F]L9&5R<RD["B`@("`@("`@<F5T=7)N("1F;VQD97)S
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5C=7)S:79E;'D@8V]P:65S('1H
M92!C;VYT96YT<R!O9B!A(&9O;&1E<B!T;R!A(&1E<W1I;F%T:6]N+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'!A=&@@(%1H92!P871H('1O('-T;W)E('1H92!D:7)E8W1O
M<GD@:6XN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@;F%M92!O
M9B!T:&4@9&ER96-T;W)Y+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&5S="`@
M5&AE(&1E<W1I;F%T:6]N(&]F('1H92!D:7)E8W1O<GDN"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%
M<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M7W)E8W5R<VEV94-O<'DH)'!A=&@L("1N86UE+"`D9&5S="D*("`@('L*("`@
M("`@("`D<F5S=6QT(#T@)'1H:7,M/F-R96%T949O;&1E<B@D9&5S="P@)&YA
M;64I.PH*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@
M("`@("`@)&9I;&5?;&ES="`]("1T:&ES+3YL:7-T1F]L9&5R*"1T:&ES+3Y?
M9V5T4U%,3F%T:79E4&%T:"@D<&%T:"P@)&YA;64I*3L*"B`@("`@("`@9F]R
M96%C:"`H)&9I;&5?;&ES="!A<R`D9FEL92D@>PH@("`@("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/F-O<'DH)'1H:7,M/E]G971344Q.871I=F50871H*"1P
M871H+"`D;F%M92DL("1F:6QE6R=N86UE)UTL("1T:&ES+3Y?9V5T4U%,3F%T
M:79E4&%T:"@D9&5S="P@)&YA;64I*3L*"B`@("`@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@('T*"B`@("`O*BH*("`@("`J(%-T;W)E(&$@
M9FEL97,@:6YF;W)M871I;VX@=VET:&EN('1H92!D871A8F%S92X*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1P871H("`@("`@("`@5&AE('!A=&@@=&\@<W1O<F4@=&AE(&9I
M;&4@:6XN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@("`@5&AE
M(&9I;&5N86UE('1O('5S92X*("`@("`J($!P87)A;2!B;V]L96%N("1A=71O
M8W)E871E("!!=71O;6%T:6-A;&QY(&-R96%T92!D:7)E8W1O<FEE<S\*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@
M82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?=W)I=&5344Q$871A*"1P871H+"`D;F%M92P@)&%U=&]C<F5A
M=&4@/2!F86QS92D*("`@('L*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N
M;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@
M("`@("\O($9I;&4@86QR96%D>2!E>&ES=',@:6X@9&%T86)A<V4*("`@("`@
M("!I9B`H)'1H:7,M/F5X:7-T<R@D<&%T:"P@)&YA;64I*2!["B`@("`@("`@
M("`@("1Q=65R>2`]("=54$1!5$4@)R`N("1T:&ES+3Y?<&%R86US6R=T86)L
M92==("X*("`@("`@("`@("`@("`@("`@("`@)R!3150@=F9S7VUO9&EF:65D
M(#T@/R<@+@H@("`@("`@("`@("`@("`@("`@("`G(%=(15)%('9F<U]P871H
M(#T@/R!!3D0@=F9S7VYA;64@/2`_)SL*("`@("`@("`@("`@)'9A;'5E<R`]
M(&%R<F%Y*'1I;64H*2P@)'!A=&@L("1N86UE*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D:60@/2`D=&AI<RT^7V1B+3YN97AT260H)'1H:7,M
M/E]P87)A;7-;)W1A8FQE)UTI.PH*("`@("`@("`@("`@)'%U97)Y(#T@)TE.
M4T525"!)3E1/("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`N"B`@("`@
M("`@("`@("`@("`@("`@("<@*'9F<U]I9"P@=F9S7W1Y<&4L('9F<U]P871H
M+"!V9G-?;F%M92P@=F9S7VUO9&EF:65D+"<@+@H@("`@("`@("`@("`@("`@
M("`@("`G('9F<U]O=VYE<BD@5D%,5453("@_+"`_+"`_+"`_+"`_+"`_*2<[
M"B`@("`@("`@("`@("1V86QU97,@/2!A<G)A>2@D:60L(%9&4U]&24Q%+"`D
M<&%T:"P@)&YA;64L('1I;64H*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=U<V5R)UTI.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E;F%M97,@86QL(&-H:6QD('!A=&AS
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&]L9'!A=&@@(%1H92!O;&0@<&%T:"!O9B!T:&4@
M9F]L9&5R('1O(')E;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@)&]L9&YA
M;64@(%1H92!O;&0@;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@)&YE=W!A
M=&@@(%1H92!N97<@<&%T:"!O9B!T:&4@9F]L9&5R('1O(')E;F%M92X*("`@
M("`J($!P87)A;2!S=')I;F<@)&YE=VYA;64@(%1H92!N97<@;F%M92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@
M82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?<F5C=7)S:79E4U%,4F5N86UE*"1O;&1P871H+"`D;VQD;F%M
M92P@)&YE=W!A=&@L("1N97=N86UE*0H@("`@>PH@("`@("`@("1F;VQD97),
M:7-T(#T@)'1H:7,M/E]D8BT^9V5T0V]L*'-P<FEN=&8H)U-%3$5#5"!V9G-?
M;F%M92!&4D]-("5S(%=(15)%('9F<U]T>7!E(#T@/R!!3D0@=F9S7W!A=&@@
M/2`_)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`P+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*%9&4U]&3TQ$
M15(L("1T:&ES+3Y?9V5T4U%,3F%T:79E4&%T:"@D;VQD<&%T:"P@)&]L9&YA
M;64I*2D["@H@("`@("`@(&9O<F5A8V@@*"1F;VQD97),:7-T(&%S("1F;VQD
M97(I('L*("`@("`@("`@("`@)'1H:7,M/E]R96-U<G-I=F5344Q296YA;64H
M)'1H:7,M/E]G971344Q.871I=F50871H*"1O;&1P871H+"`D;VQD;F%M92DL
M("1F;VQD97(L("1T:&ES+3Y?9V5T4U%,3F%T:79E4&%T:"@D;F5W<&%T:"P@
M)&YE=VYA;64I+"`D9F]L9&5R*3L*("`@("`@("!]"@H@("`@("`@("1R97-U
M;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2AS<')I;G1F*"=54$1!5$4@)7,@4T54
M('9F<U]P871H(#T@/R!72$5212!V9G-?<&%T:"`](#\G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=T86)L92==*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@87)R87DH)'1H:7,M/E]G971344Q.871I=F50871H*"1N97=P871H
M+"`D;F5W;F%M92DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?9V5T4U%,3F%T:79E4&%T:"@D;VQD<&%T:"P@
M)&]L9&YA;64I*2D["@H@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E(&$@9F]L9&5R<R!C
M;VYT96YT<R!F<F]M('1H92!61E,@:6X@=&AE(%-13"!D871A8F%S92P*("`@
M("`J(')E8W5R<VEV96QY+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H
M(&]F('1H92!F;VQD97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4
M:&4@9F]L9&5R;F%M92!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@
M;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7W)E8W5R<VEV95-1
M3$1E;&5T92@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@)')E<W5L="`]
M("1T:&ES+3Y?9&(M/G%U97)Y*'-P<FEN=&8H)T1%3$5412!&4D]-("5S(%=(
M15)%('9F<U]T>7!E(#T@/R!!3D0@=F9S7W!A=&@@/2`_)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M<F%M<ULG=&%B;&4G72DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*%9&4U]&24Q%+"`D=&AI<RT^7V=E=%-13$YA=&EV95!A
M=&@H)'!A=&@L("1N86UE*2DI.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("`@("`@?0H*("`@("`@("`D9F]L9&5R3&ES="`]("1T:&ES+3Y?9&(M
M/F=E=$-O;"AS<')I;G1F*"=314Q%0U0@=F9S7VYA;64@1E)/32`E<R!72$52
M12!V9G-?='EP92`](#\@04Y$('9F<U]P871H(#T@/R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG=&%B;&4G72DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@,"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!A<G)A>2A61E-?1D],1$52+"`D=&AI<RT^7V=E=%-1
M3$YA=&EV95!A=&@H)'!A=&@L("1N86UE*2DI.PH*("`@("`@("!F;W)E86-H
M("@D9F]L9&5R3&ES="!A<R`D9F]L9&5R*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?<F5C=7)S:79E4U%,1&5L971E*"1T:&ES+3Y?9V5T4U%,3F%T:79E4&%T
M:"@D<&%T:"P@)&YA;64I+"`D9F]L9&5R*3L*("`@("`@("!]"@H@("`@("`@
M("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2AS<')I;G1F*"=$14Q%5$4@
M1E)/32`E<R!72$5212!V9G-?='EP92`](#\@04Y$('9F<U]N86UE(#T@/R!!
M3D0@=F9S7W!A=&@@/2`_)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*%9&4U]&
M3TQ$15(L("1N86UE+"`D<&%T:"DI.PH*("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@('T*"B`@("`O*BH*("`@("`J($1E;&5T92!A(&9O;&1E<G,@8V]N
M=&5N=',@9G)O;2!T:&4@5D93+"!R96-U<G-I=F5L>2X*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1P871H("!4:&4@<&%T:"!O9B!T:&4@9F]L9&5R+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;F%M92`@5&AE(&9O;&1E<FYA;64@=&\@=7-E+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%
M05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]R96-U<G-I=F5,1E-$96QE=&4H)'!A=&@L("1N86UE*0H@("`@>PH@
M("`@("`@("1D:7(@/2`D=&AI<RT^7V=E=$YA=&EV95!A=&@H)'!A=&@L("1N
M86UE*3L*("`@("`@("`D9&@@/2!`;W!E;F1I<B@D9&ER*3L*"B`@("`@("`@
M=VAI;&4@*&9A;'-E("$]/2`H)&9I;&4@/2!R96%D9&ER*"1D:"DI*2!["B`@
M("`@("`@("`@(&EF("@D9FEL92`A/2`G+B<@)B8@)&9I;&4@(3T@)RXN)RD@
M>PH@("`@("`@("`@("`@("`@:68@*&ES7V1I<B@D9&ER("X@)R\G("X@)&9I
M;&4I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R96-U<G-I=F5,
M1E-$96QE=&4H96UP='DH)'!A=&@I(#\@)&YA;64@.B`D<&%T:"`N("<O)R`N
M("1N86UE+"`D9FEL92D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@($!U;FQI;FLH)&1I<B`N("<O)R`N("1F:6QE*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M("`@("!`8VQO<V5D:7(H)&1H*3L*"B`@("`@("`@<F5T=7)N(')M9&ER*"1D
M:7(I.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@;W!E;B!A
M('!E<G-I<W1E;G0@8V]N;F5C=&EO;B!T;R!T:&4@4U%,('-E<G9E<BX*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B
M:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N;F5C
M="@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?9&(@/3T](&9A;'-E*2![
M"B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)'1H:7,M/E]P87)A;7,I*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,
M+49I;&4@5D93+B(I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)')E
M<75I<F5D(#T@87)R87DH)W!H<'1Y<&4G+"`G=F9S<F]O="<I.PH@("`@("`@
M("`@("!F;W)E86-H("@D<F5Q=6ER960@87,@)'9A;"D@>PH@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULD=F%L72DI('L*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I
M;G1F*%\H(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C
M;VYF:6=U<F%T:6]N+B(I+"`D=F%L*2D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P
M87)A;7-;)V1A=&%B87-E)UTI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG9&%T86)A<V4G72`]("<G.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=U<V5R;F%M92==
M*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W5S97)N86UE
M)UT@/2`G)SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"%I<W-E
M="@D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G72DI('L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==(#T@)R<["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;
M)W1A8FQE)UTI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG
M=&%B;&4G72`]("=H;W)D95]V9G,G.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`O*B!#;VYN96-T('1O('1H92!344P@<V5R=F5R('5S:6YG('1H92!S
M=7!P;&EE9"!P87)A;65T97)S+B`J+PH@("`@("`@("`@("!R97%U:7)E7V]N
M8V4@)T1"+G!H<"<["B`@("`@("`@("`@("1T:&ES+3Y?9&(@/2`F1$(Z.F-O
M;FYE8W0H)'1H:7,M/E]P87)A;7,L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87DH)W!E<G-I<W1E;G0G(#T^("%E;7!T>2@D
M=&AI<RT^7W!A<F%M<ULG<&5R<VES=&5N="==*2DI.PH@("`@("`@("`@("!I
M9B`H:7-?82@D=&AI<RT^7V1B+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("`@("`D97)R;W(@/2`D=&AI<RT^7V1B.PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]D8B`](&9A;'-E.PH@("`@("`@("`@("`@("`@<F5T=7)N("1E
M<G)O<CL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@4V5T($1"('!O
M<G1A8FEL:71Y(&]P=&EO;G,N"B`@("`@("`@("`@('-W:71C:"`H)'1H:7,M
M/E]D8BT^<&AP='EP92D@>PH@("`@("`@("`@("!C87-E("=M<W-Q;"<Z"B`@
M("`@("`@("`@("`@("`D=&AI<RT^7V1B+3YS971/<'1I;VXH)W!O<G1A8FEL
M:71Y)RP@1$)?4$]25$%"24Q)5%E?3$]715)#05-%('P@1$)?4$]25$%"24Q)
M5%E?15)23U)3('P@1$)?4$]25$%"24Q)5%E?4E1224TI.PH@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@
M("`@("`D=&AI<RT^7V1B+3YS971/<'1I;VXH)W!O<G1A8FEL:71Y)RP@1$)?
M4$]25$%"24Q)5%E?3$]715)#05-%('P@1$)?4$]25$%"24Q)5%E?15)23U)3
M*3L*("`@("`@("`@("`@?0H*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@1&ES8V]N;F5C="!F<F]M('1H
M92!344P@<V5R=F5R(&%N9"!C;&5A;B!U<"!T:&4@8V]N;F5C=&EO;BX*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V1I<V-O;FYE8W0H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V1B
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?9&(M/F1I<V-O;FYE8W0H*3L*("`@
M("`@("`@("`@)'1H:7,M/E]D8B`](&9A;'-E.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;B!A(&9U;&P@9FEL96YA;64@;VX@=&AE
M(&YA=&EV92!F:6QE<WES=&5M+"!F<F]M(&$@5D93"B`@("`@*B!P871H(&%N
M9"!N86UE+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!61E,@9FEL92!P871H
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(%9&4R!F:6QE;F%M
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&9U;&P@;F%T
M:79E(&9I;&5N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T3F%T:79E
M4&%T:"@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@:68@*"%E;7!T>2@D
M;F%M92DI('L*("`@("`@("`@("`@)&YA;64@/2`G+R<@+B`D;F%M93L*("`@
M("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1P871H*2D@>PH@("`@("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]P87)A;7-;)VAO;64G72D@)B8*("`@("`@
M("`@("`@("`@('!R96=?;6%T8V@H)WQ>?B\_*"XJ*21\)RP@)'!A=&@L("1M
M871C:&5S*2D@>PH@("`@("`@("`@("`@("`@)'!A=&@@/2`D=&AI<RT^7W!A
M<F%M<ULG:&]M92==("`N("<O)R`N("1M871C:&5S6S%=.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P87)A;7-;)W9F<W)O
M;W0G72`N("<O)R`N("1P871H("X@)&YA;64["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%R86US6R=V9G-R;V]T)UT@
M+B`D;F%M93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FX@82!F=6QL(%-13"!F:6QE;F%M92!O;B!T:&4@;F%T:79E(&9I;&5S>7-T
M96TL(&9R;VT@82!61E,*("`@("`J('!A=&@@86YD(&YA;64N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<&%T:"`@5&AE(%9&4R!F:6QE('!A=&@N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1N86UE("!4:&4@5D93(&9I;&5N86UE+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@9G5L;"!N871I=F4@9FEL96YA;64N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]G971344Q.871I=F50871H*"1P871H+"`D
M;F%M92D*("`@('L*("`@("`@("!I9B`H96UP='DH)'!A=&@I*2!["B`@("`@
M("`@("`@(')E='5R;B`D;F%M93L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D<&%T:"`N("<O)R`N("1N86UE.PH@("`@?0H*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B]61E,O9FEL92YP:'``````````````````````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`U-30P,2`Q,#4Q-30S,S<S-2`P,C`T,#(`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J(%9&4R!I;7!L96UE;G1A=&EO;B!F;W(@82!S=&%N9&%R9"!F:6QE<WES
M=&5M+@H@*@H@*B!297%U:7)E9"!P87)A;65T97)S.CQP<F4^"B`J("`@)W9F
M<W)O;W0G("!4:&4@<F]O="!P871H/"]P<F4^"B`J"B`J($YO=&4Z(%1H92!U
M<V5R('1H870@>6]U<B!W96)S97)V97(@<G5N<R!A<R`H8V]M;6]N;'D@)VYO
M8F]D>2<L"B`J("=A<&%C:&4G+"!O<B`G=W=W+61A=&$G*2!-55-4(&AA=F4@
M<F5A9"]W<FET92!P97)M:7-S:6]N('1O('1H90H@*B!D:7)E8W1O<GD@>6]U
M('-P96-I9GD@87,@=&AE("=V9G-R;V]T)RX*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<"QV(#$N-C,N-"XR,2`R,#`V+S`U+S,Q
M(#`T.C4P.C`R('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M
M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:`H@*B!`<&%C
M:V%G92!61E,*("HO"F-L87-S(%9&4U]F:6QE(&5X=&5N9',@5D93('L*"B`@
M("`O*BH*("`@("`J($QI<W0@;V8@<&5R;6ES<VEO;G,@86YD(&EF('1H97D@
M8V%N(&)E(&-H86YG960@:6X@=&AI<R!61E,*("`@("`J(&)A8VME;F0N"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P97)M
M:7-S:6]N<R`](&%R<F%Y*`H@("`@("`@("=O=VYE<B<@/3X@87)R87DH)W)E
M860G(#T^('1R=64L("=W<FET92<@/3X@=')U92P@)V5X96-U=&4G(#T^('1R
M=64I+`H@("`@("`@("=G<F]U<"<@/3X@87)R87DH)W)E860G(#T^('1R=64L
M("=W<FET92<@/3X@=')U92P@)V5X96-U=&4G(#T^('1R=64I+`H@("`@("`@
M("=A;&PG("`@/3X@87)R87DH)W)E860G(#T^('1R=64L("=W<FET92<@/3X@
M=')U92P@)V5X96-U=&4G(#T^('1R=64I"B`@("`I.PH*("`@("\J*@H@("`@
M("H@0V]N<W1R=6-T<R!A(&YE=R!&:6QE<WES=&5M(&)A<V5D(%9&4R!O8FIE
M8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S
M:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@5D937V9I;&4H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("![
M"B`@("`@("`@<&%R96YT.CI61E,H)'!A<F%M<RD["@H@("`@("`@(&EF("@A
M96UP='DH)'1H:7,M/E]P87)A;7-;)W9F<W)O;W0G72DI('L*("`@("`@("`@
M("`@:68@*'-U8G-T<B@D=&AI<RT^7W!A<F%M<ULG=F9S<F]O="==+"`M,2D@
M/3T@)R\G('Q\"B`@("`@("`@("`@("`@("!S=6)S='(H)'1H:7,M/E]P87)A
M;7-;)W9F<W)O;W0G72P@+3$I(#T]("=<7"<I('L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=V9G-R;V]T)UT@/2!S=6)S='(H)'1H:7,M/E]P
M87)A;7-;)W9F<W)O;W0G72P@,"P@<W1R;&5N*"1T:&ES+3Y?<&%R86US6R=V
M9G-R;V]T)UTI("T@,2D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971R:65V97,@=&AE(&9I;&5S:7IE(&9R;VT@
M=&AE(%9&4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4
M:&4@<&%T:&YA;64@=&\@=&AE(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N86UE("!4:&4@9FEL96YA;64@=&\@<F5T<FEE=F4N"B`@("`@*@H@("`@
M("H@0')E='5R;B!I;G1E9V5R(%1H92!F:6QE('-I>F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('-I>F4H)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@("1S
M:7IE(#T@0&9I;&5S:7IE*"1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D<&%T:"P@
M)&YA;64I*3L*("`@("`@("!I9B`H)'-I>F4@/3T](&9A;'-E*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA
M8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S+R5S7"(N(BDL("1P871H
M+"`D;F%M92DI.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'-I>F4["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V92!A(&9I;&4@9G)O;2!T:&4@
M5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P
M871H;F%M92!T;R!T:&4@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)&YA
M;64@(%1H92!F:6QE;F%M92!T;R!R971R:65V92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(&9I;&4@9&%T82X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F5A9"@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@)&9I;&4@
M/2`D=&AI<RT^7V=E=$YA=&EV95!A=&@H)'!A=&@L("1N86UE*3L*("`@("`@
M("!I9B`H9G5N8W1I;VY?97AI<W1S*"=F:6QE7V=E=%]C;VYT96YT<R<I*2![
M"B`@("`@("`@("`@("1D871A(#T@9FEL95]G971?8V]N=&5N=',H)&9I;&4I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1F<"`]($!F;W!E;B@D
M9FEL92P@)W)B)RD["B`@("`@("`@("`@(&EF("@A)&9P*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92XB*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)&9I;&5S:7IE(#T@9FEL97-I>F4H)&9I;&4I.PH@("`@("`@("`@("!I9B`H
M)&9I;&5S:7IE(#T](#`I('L*("`@("`@("`@("`@("`@("1D871A(#T@)R<[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D9&%T82`]
M(&9R96%D*"1F<"P@)&9I;&5S:7IE*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!F8VQO<V4H)&9P*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M9&%T83L*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E<R!A('!A<G0@
M;V8@82!F:6QE(&9R;VT@=&AE(%9&4RX@4&%R=&EC=6QA<FQY('5S969U;"!W
M:&5N"B`@("`@*B!R96%D:6YG(&QA<F=E(&9I;&5S('=H:6-H('=O=6QD(&5X
M8V5E9"!T:&4@4$A0(&UE;6]R>2!L:6UI=',@:68@=&AE>0H@("`@("H@=V5R
M92!S=&]R960@:6X@82!S=')I;F<N"B`@("`@*@H@("`@("H@0&%B<W1R86-T
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'!A=&@@("`@("`@5&AE
M('!A=&AN86UE('1O('1H92!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`@
M)&YA;64@("`@("`@5&AE(&9I;&5N86UE('1O(')E=')I979E+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&]F9G-E="`@("`@5&AE(&]F9G-E="!O9B!T:&4@
M<&%R="X@*%1H92!N97<@;V9F<V5T('=I;&P*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&)E('-T;W)E9"!I;B!H97)E*2X*("`@("`J($!P
M87)A;2!I;G1E9V5R("1L96YG=&@@("`@(%1H92!L96YG=&@@;V8@=&AE('!A
M<G0N($EF('1H92!L96YG=&@@/2`M,2P*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('1H92!W:&]L92!P87)T(&%F=&5R('1H92!O9F9S970@
M:7,@<F5T<FEE=F5D+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@268@;6]R92!B>71E<R!A<F4@9VEV96X@87,@97AI<W1S(&%F=&5R('1H
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@9VEV96X@;V9F
M<V5T+B!/;FQY('1H92!A=F%I;&%B;&4@8GET97,@87)E"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!R96%D+@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)')E;6%I;FEN9R`@5&AE(&)Y=&5S('1H870@87)E(&QE9G0L(&%F
M=&5R('1H92!P87)T('1H870*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&ES(')E=')I979E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R!4:&4@9FEL92!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96%D
M0GET95)A;F=E*"1P871H+"`D;F%M92P@)B1O9F9S970L("1L96YG=&@@/2`M
M,2P@)B1R96UA:6YI;F<I"B`@("!["B`@("`@("`@:68@*"1O9F9S970@/"`P
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN
M=&8H7R@B5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL
M92XB*2P@)&]F9G-E="DI.PH@("`@("`@('T*"B`@("`@("`@+R\@0V%L8W5L
M871E(&AO=R!M86YY(&)Y=&5S($U54U0@8F4@<F5A9"P@<V\@=&AE(')E;6%I
M;F=I;F<*("`@("`@("`O+R!B>71E<R!A;F0@=&AE(&YE=R!O9F9S970@8V%N
M(&)E(&-A;&-U;&%T960@8V]R<F5C=&QY+@H@("`@("`@("1F:6QE(#T@)'1H
M:7,M/E]G971.871I=F50871H*"1P871H+"`D;F%M92D["B`@("`@("`@)'-I
M>F4@/2!F:6QE<VEZ92`H)&9I;&4I.PH@("`@("`@(&EF("@D;&5N9W1H(#T]
M("TQ('Q\("@H)&QE;F=T:"`K("1O9F9S970I(#X@)'-I>F4I*2!["B`@("`@
M("`@("`@("1L96YG=&@@/2`D<VEZ92`M("1O9F9S970["B`@("`@("`@?0H@
M("`@("`@(&EF("@D<F5M86EN:6YG(#P@,"D@>PH@("`@("`@("`@("`D<F5M
M86EN:6YG(#T@,#L*("`@("`@("!]"@H@("`@("`@("1F<"`]($!F;W!E;B@D
M9FEL92P@)W)B)RD["B`@("`@("`@:68@*"$D9G`I('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(&]P96X@5D93
M(&9I;&4N(BDI.PH@("`@("`@('T*("`@("`@("!F<V5E:R@D9G`L("1O9F9S
M970I.PH@("`@("`@("1D871A(#T@9G)E860H)&9P+"`D;&5N9W1H*3L*("`@
M("`@("`D;V9F<V5T(#T@9G1E;&PH)&9P*3L*("`@("`@("`D<F5M86EN:6YG
M(#T@)'-I>F4@+2`D;V9F<V5T.PH*("`@("`@("!F8VQO<V4H)&9P*3L*"B`@
M("`@("`@<F5T=7)N("1D871A.PH@("`@?0H*("`@("\J*@H@("`@("H@4W1O
M<F4@82!F:6QE(&EN('1H92!61E,L('=I=&@@=&AE(&1A=&$@8V]P:65D(&9R
M;VT@82!T96UP;W)A<GD*("`@("`J(&9I;&4N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<&%T:"`@("`@("`@(%1H92!P871H('1O('-T;W)E('1H
M92!F:6QE(&EN+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@("`@
M(%1H92!F:6QE;F%M92!T;R!U<V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T
M;7!&:6QE("`@("`@5&AE('1E;7!O<F%R>2!F:6QE(&-O;G1A:6YI;F<@=&AE
M(&1A=&$@=&\@8F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!S=&]R960N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D875T;V-R96%T92`@
M075T;VUA=&EC86QL>2!C<F5A=&4@9&ER96-T;W)I97,_"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%
M<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M=W)I=&4H)'!A=&@L("1N86UE+"`D=&UP1FEL92P@)&%U=&]C<F5A=&4@/2!T
M<G5E*0H@("`@>PH@("`@("`@(&EF("@A0&ES7V1I<B@D=&AI<RT^7V=E=$YA
M=&EV95!A=&@H)'!A=&@I*2D@>PH@("`@("`@("`@("!I9B`H)&%U=&]C<F5A
M=&4I('L*("`@("`@("`@("`@("`@("1R97,@/2`D=&AI<RT^875T;V-R96%T
M95!A=&@H)'!A=&@I.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E<RP@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M<F5S.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B5D93
M(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB*2D["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@("1R97,@/2`D=&AI<RT^7V-H96-K475O=&%7
M<FET92@G9FEL92<L("1T;7!&:6QE*3L*("`@("`@("!I9B`H:7-?82@D<F5S
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S.PH@
M("`@("`@('T*"B`@("`@("`@+R\@4VEN8V4@=V4@86QR96%D>2!H879E('1H
M92!D871A(&EN(&$@9FEL92P@9&]N)W0@<F5A9"!I=`H@("`@("`@("\O(&EN
M=&\@4$A0)W,@;65M;W)Y(&%T(&%L;"`M(&IU<W0@8V]P>2@I(&ET('1O('1H
M92!N97<*("`@("`@("`O+R!L;V-A=&EO;BX@5V4@;&5A=F4@:70@=&\@=&AE
M(&-A;&QE<B!T;R!C;&5A;B!U<"!T:&4*("`@("`@("`O+R!T96UP;W)A<GD@
M9FEL92P@<V\@=V4@9&]N)W0@=7-E(')E;F%M92@I+@H@("`@("`@(&EF("A`
M8V]P>2@D=&UP1FEL92P@)'1H:7,M/E]G971.871I=F50871H*"1P871H+"`D
M;F%M92DI*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(BDI
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($UO=F5S(&$@9FEL
M92!I;B!T:&4@9&%T86)A<V4@86YD('1H92!F:6QE('-Y<W1E;2X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!T;R!S=&]R
M92!T:&4@9FEL92!I;BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H
M92!F:6QE;F%M92!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@;6]V92@D<&%T:"P@)&YA
M;64L("1D97-T*0H@("`@>PH@("`@("`@("1O<FEG(#T@)'1H:7,M/E]G971.
M871I=F50871H*"1P871H+"`D;F%M92D["B`@("`@("`@:68@*'!R96=?;6%T
M8V@H)WQ>)R`N('!R96=?<75O=&4H)&]R:6<I("X@)R\_)'PG+"`D9&5S="DI
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V%N
M;F]T(&UO=F4@9FEL92AS*2`M(&1E<W1I;F%T:6]N(&ES('=I=&AI;B!S;W5R
M8V4N(BDI.PH@("`@("`@('T*"B`@("`@("`@)&9I;&5#:&5C:R`]("1T:&ES
M+3YL:7-T1F]L9&5R*"1D97-T+"!F86QS92D["B`@("`@("`@9F]R96%C:"`H
M)&9I;&5#:&5C:R!A<R`D9FEL92D@>PH@("`@("`@("`@("!I9B`H)&9I;&5;
M)VYA;64G72`]/2`D;F%M92D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(BDI
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H(4!R96YA
M;64H)&]R:6<L("1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D9&5S="P@)&YA;64I
M*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5
M;F%B;&4@=&\@;6]V92!61E,@9FEL92XB*2D["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($-O<&EE<R!A
M(&9I;&4@=&AR;W5G:"!T:&4@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!T;R!S=&]R92!T:&4@9FEL92!I
M;BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!F:6QE;F%M92!T
M;R!U<V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1D97-T("!4:&4@9&5S=&EN
M871I;VX@;V8@=&AE(&9I;&4N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]P>2@D<&%T:"P@)&YA
M;64L("1D97-T*0H@("`@>PH@("`@("`@("1O<FEG(#T@)'1H:7,M/E]G971.
M871I=F50871H*"1P871H+"`D;F%M92D["B`@("`@("`@:68@*'!R96=?;6%T
M8V@H)WQ>)R`N('!R96=?<75O=&4H)&]R:6<I("X@)R\_)'PG+"`D9&5S="DI
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V%N
M;F]T(&-O<'D@9FEL92AS*2`M('-O=7)C92!A;F0@9&5S=&EN871I;VX@87)E
M('1H92!S86UE+B(I*3L*("`@("`@("!]"@H@("`@("`@("1F:6QE0VAE8VL@
M/2`D=&AI<RT^;&ES=$9O;&1E<B@D9&5S="P@9F%L<V4I.PH@("`@("`@(&9O
M<F5A8V@@*"1F:6QE0VAE8VL@87,@)&9I;&4I('L*("`@("`@("`@("`@:68@
M*"1F:6QE6R=N86UE)UT@/3T@)&YA;64I('L*("`@("`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!C;W!Y(%9&4R!F
M:6QE+B(I*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@
M*"%`8V]P>2@D;W)I9RP@)'1H:7,M/E]G971.871I=F50871H*"1D97-T+"`D
M;F%M92DI*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(I*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4W1O
M<F4@82!F:6QE(&EN('1H92!61E,@9G)O;2!R87<@9&%T82X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@("`@5&AE('!A=&@@=&\@
M<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE
M("`@("`@("`@5&AE(&9I;&5N86UE('1O('5S92X*("`@("`J($!P87)A;2!S
M=')I;F<@)&1A=&$@("`@("`@("!4:&4@9FEL92!D871A+@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)&%U=&]C<F5A=&4@($%U=&]M871I8V%L;'D@8W)E871E
M(&1I<F5C=&]R:65S/PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R
M=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('=R:71E1&%T82@D<&%T:"P@)&YA
M;64L("1D871A+"`D875T;V-R96%T92`]('1R=64I"B`@("!["B`@("`@("`@
M:68@*"%`:7-?9&ER*"1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D<&%T:"DI*2![
M"B`@("`@("`@("`@(&EF("@D875T;V-R96%T92D@>PH@("`@("`@("`@("`@
M("`@)')E<R`]("1T:&ES+3YA=71O8W)E871E4&%T:"@D<&%T:"D["B`@("`@
M("`@("`@("`@("!I9B`H:7-?82@D<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")61E,@9&ER96-T;W)Y(&1O97,@;F]T
M(&5X:7-T+B(I*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M+R\@5')E870@86X@871T96UP="!T;R!W<FET92!A;B!E;7!T>2!F:6QE(&%S
M(&$@=&]U8V@H*2!C86QL+`H@("`@("`@("\O('-I;F-E(&]T:&5R=VES92!T
M:&4@9FEL92!W:6QL(&YO="!B92!C<F5A=&5D(&%T(&%L;"X*("`@("`@("!I
M9B`H(7-T<FQE;B@D9&%T82DI('L*("`@("`@("`@("`@:68@*$!T;W5C:"@D
M=&AI<RT^7V=E=$YA=&EV95!A=&@H)'!A=&@L("1N86UE*2DI('L*("`@("`@
M("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA
M8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB*2D["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@("1R97,@/2`D=&AI<RT^7V-H96-K475O
M=&%7<FET92@G<W1R:6YG)RP@)&1A=&$I.PH@("`@("`@(&EF("AI<U]A*"1R
M97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97,[
M"B`@("`@("`@?0H*("`@("`@("`O+R!/=&AE<G=I<V4@=V4@9V\@86AE860@
M86YD('1R>2!T;R!W<FET92!O=70@=&AE(&9I;&4N"B`@("`@("`@)&9P(#T@
M0&9O<&5N*"1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D<&%T:"P@)&YA;64I+"`G
M=R<I.PH@("`@("`@(&EF("@A)&9P*2!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O
M<B!W<FET:6YG+B(I*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A0&9W<FET
M92@D9G`L("1D871A*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BA?*")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB*2D[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J($1E;&5T92!A(&9I;&4@9G)O;2!T:&4@5D93+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H('1O('-T;W)E
M('1H92!F:6QE(&EN+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE
M(&9I;&5N86UE('1O('5S92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96QE=&5&:6QE*"1P871H
M+"`D;F%M92D*("`@('L*("`@("`@("`D<F5S(#T@)'1H:7,M/E]C:&5C:U%U
M;W1A1&5L971E*"1P871H+"`D;F%M92D["B`@("`@("`@:68@*&ES7V$H)')E
M<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<SL*
M("`@("`@("!]"@H@("`@("`@(&EF("@A0'5N;&EN:R@D=&AI<RT^7V=E=$YA
M=&EV95!A=&@H)'!A=&@L("1N86UE*2DI('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(&1E;&5T92!61E,@9FEL
M92XB*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*
M"B`@("`O*BH*("`@("`J($1E;&5T92!A(&9O;&1E<B!F<F]M('1H92!61E,N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@("`@5&AE
M('!A=&@@=&\@9&5L971E('1H92!F;VQD97(@9G)O;2X*("`@("`J($!P87)A
M;2!S=')I;F<@)&YA;64@("`@("`@(%1H92!F;VQD97)N86UE('1O('5S92X*
M("`@("`J($!P87)A;2!B;V]L96%N("1R96-U<G-I=F4@($9O<F-E(&$@<F5C
M=7)S:79E(&1E;&5T93\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%1R
M=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T949O;&1E<B@D<&%T:"P@
M)&YA;64L("1R96-U<G-I=F4@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H
M)')E8W5R<VEV92D@>PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F5M
M<'1Y1F]L9&5R*"1P871H("X@)R\G("X@)&YA;64I.PH@("`@("`@("`@("!I
M9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1L:7-T(#T@)'1H:7,M/FQI<W1&;VQD97(H
M)'!A=&@@+B`G+R<@+B`D;F%M92D["B`@("`@("`@("`@(&EF("AI<U]A*"1L
M:7-T+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)&QI<W0["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*&-O=6YT*"1L
M:7-T*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T
M;W)Y(&ES(&YO="!E;7!T>2(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<&%T:"`N("<O)R`N("1N86UE*2D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@A0')M9&ER
M*"1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D<&%T:"P@)&YA;64I*2D@>PH@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@
M9&5L971E(%9&4R!D:7)E8W1O<GDN(BDI.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&$@
M9F]L9&5R(&]N('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<&%T:"`@5&AE('!A=&@@=&\@9&5L971E('1H92!F;VQD97(@9G)O;2X*
M("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!F;VQD97)N86UE('1O
M('5S92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U
M8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!C<F5A=&5&;VQD97(H)'!A=&@L("1N86UE*0H@
M("`@>PH@("`@("`@(&EF("@A0&UK9&ER*"1T:&ES+3Y?9V5T3F%T:79E4&%T
M:"@D<&%T:"P@)&YA;64I*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN
M(BDI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#:&5C:R!I9B!A(&=I=F5N('!A=&AN86UE(&ES(&$@
M9F]L9&5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H
M92!P871H('1O('1H92!F;VQD97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N
M86UE("!4:&4@9FEL92]F;VQD97(@;F%M92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%1R=64@:68@:70@:7,@82!F;VQD97(L(&9A;'-E(&]T
M:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-&;VQD97(H)'!A=&@L
M("1N86UE*0H@("`@>PH@("`@("`@(')E='5R;B!`:7-?9&ER*"1T:&ES+3Y?
M9V5T3F%T:79E4&%T:"@D<&%T:"P@)&YA;64I*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($-H86YG97,@<&5R;6ES<VEO;G,@9F]R(&%N(&ET96T@:6X@=&AE
M(%9&4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@
M("`@5&AE('!A=&@@;V8@9&ER96-T;W)Y(&]F('1H92!I=&5M+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;F%M92`@("`@("`@(%1H92!N86UE(&]F('1H92!I
M=&5M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'!E<FUI<W-I;VX@(%1H92!O
M8W1A;"!V86QU92!O9B!T:&4@;F5W('!E<FUI<W-I;VXN"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%
M<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M8VAA;F=E4&5R;6ES<VEO;G,H)'!A=&@L("1N86UE+"`D<&5R;6ES<VEO;BD*
M("`@('L*("`@("`@("!I9B`H(4!C:&UO9"@D=&AI<RT^7V=E=$YA=&EV95!A
M=&@H)'!A=&@L("1N86UE*2P@)'!E<FUI<W-I;VXI*2!["B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O
M(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB*2P@)'!A
M=&@L("1N86UE*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!A(&QI<W0@;V8@=&AE(&-O
M;G1E;G1S(&]F(&$@9F]L9&5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'!A=&@@("`@("`@5&AE('!A=&@@;V8@=&AE(&1I<F5C=&]R>2X*("`@
M("`J($!P87)A;2!M:7AE9"`D9FEL=&5R("`@("`@4W1R:6YG+VAA<V@@=&\@
M9FEL=&5R(&9I;&4O9&ER;F%M92!O;BX*("`@("`J($!P87)A;2!B;V]L96%N
M("1D;W1F:6QE<R`@4VAO=R!D;W1F:6QE<S\*("`@("`J($!P87)A;2!B;V]L
M96%N("1D:7)O;FQY("`@4VAO=R!O;FQY(&1I<F5C=&]R:65S/PH@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@($9I;&4@;&ES="!O;B!S=6-C97-S+"!0
M14%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!?;&ES
M=$9O;&1E<B@D<&%T:"P@)&9I;'1E<B`](&YU;&PL("1D;W1F:6QE<R`]('1R
M=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`D9&ER;VYL>2`](&9A;'-E
M*0H@("`@>PH@("`@("`@("1F:6QE<R`](&%R<F%Y*"D["B`@("`@("`@)'!A
M=&@@/2!I<W-E="@D<&%T:"D@/R`D=&AI<RT^7V=E=$YA=&EV95!A=&@H)'!A
M=&@I(#H@)'1H:7,M/E]G971.871I=F50871H*"D["@H@("`@("`@(&EF("@A
M0&ES7V1I<B@D<&%T:"DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H7R@B3F]T(&$@9&ER96-T;W)Y(BDI.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"%`8VAD:7(H)'!A=&@I*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!A8V-E<W,@5D93(&1I
M<F5C=&]R>2XB*2D["B`@("`@("`@?0H*("`@("`@("`D:&%N9&QE(#T@;W!E
M;F1I<B@D<&%T:"D["B`@("`@("`@=VAI;&4@*"@D96YT<GD@/2!R96%D9&ER
M*"1H86YD;&4I*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@+R\@1FEL=&5R
M(&]U="`G+B<@86YD("<N+B<@96YT<FEE<RX*("`@("`@("`@("`@:68@*"1E
M;G1R>2`]/2`G+B<@?'P@)&5N=')Y(#T]("<N+B<I('L*("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!&
M:6QT97(@;W5T(&1O=&9I;&5S(&EF('1H97D@87)E;B=T('=A;G1E9"X*("`@
M("`@("`@("`@:68@*"$D9&]T9FEL97,@)B8@<W5B<W1R*"1E;G1R>2P@,"P@
M,2D@/3T@)RXG*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@+R\@1FEL92!N86UE"B`@("`@("`@("`@
M("1F:6QE6R=N86UE)UT@/2`D96YT<GD["@H@("`@("`@("`@("`O+R!5;FEX
M('-T>6QE(&9I;&4@<&5R;6ES<VEO;G,*("`@("`@("`@("`@)&9I;&5;)W!E
M<FUS)UT@/2`D=&AI<RT^7V=E=%5N:7A097)M<RAF:6QE<&5R;7,H)&5N=')Y
M*2D["@H@("`@("`@("`@("`O+R!/=VYE<@H@("`@("`@("`@("`D9FEL95LG
M;W=N97(G72`](&9I;&5O=VYE<B@D96YT<GDI.PH@("`@("`@("`@("!I9B`H
M9G5N8W1I;VY?97AI<W1S*"=P;W-I>%]G971P=W5I9"<I*2!["B`@("`@("`@
M("`@("`@("`D;W=N97(@/2!P;W-I>%]G971P=W5I9"@D9FEL95LG;W=N97(G
M72D["B`@("`@("`@("`@("`@("`D9FEL95LG;W=N97(G72`]("1O=VYE<ELG
M;F%M92==.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!'<F]U<`H@
M("`@("`@("`@("`D9FEL95LG9W)O=7`G72`](&9I;&5G<F]U<"@D96YT<GDI
M.PH@("`@("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=P;W-I>%]G971G
M<F=I9"<I*2!["B`@("`@("`@("`@("`@("`D9W)O=7`@/2!P;W-I>%]G971G
M<F=I9"@D9FEL95LG9W)O=7`G72D["B`@("`@("`@("`@("`@("`D9FEL95LG
M9W)O=7`G72`]("1G<F]U<%LG;F%M92==.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`O+R!3:7IE"B`@("`@("`@("`@("1F:6QE6R=S:7IE)UT@/2!F
M:6QE<VEZ92@D96YT<GDI.PH*("`@("`@("`@("`@+R\@1&%T90H@("`@("`@
M("`@("`D9FEL95LG9&%T92==(#T@9FEL96UT:6UE*"1E;G1R>2D["@H@("`@
M("`@("`@("`O+R!4>7!E"B`@("`@("`@("`@(&EF("A`:7-?9&ER*"1E;G1R
M>2D@)B8@(6ES7VQI;FLH)&5N=')Y*2D@>PH@("`@("`@("`@("`@("`@)&9I
M;&5;)W!E<FUS)UT@/2`G9"<@+B`D9FEL95LG<&5R;7,G73L*("`@("`@("`@
M("`@("`@("1F:6QE6R=T>7!E)UT@/2`G*BID:7(G.PH@("`@("`@("`@("`@
M("`@)&9I;&5;)W-I>F4G72`]("TQ.PH@("`@("`@("`@("!](&5L<V5I9B`H
M:7-?;&EN:R@D96YT<GDI*2!["B`@("`@("`@("`@("`@("`D9FEL95LG<&5R
M;7,G72`]("=L)R`N("1F:6QE6R=P97)M<R==.PH@("`@("`@("`@("`@("`@
M)&9I;&5;)W1Y<&4G72`]("<J*G-Y;2<["B`@("`@("`@("`@("`@("`D9FEL
M95LG;&EN:R==(#T@<F5A9&QI;FLH)&5N=')Y*3L*("`@("`@("`@("`@("`@
M("1F:6QE6R=L:6YK='EP92==(#T@)RHJ;F]N92<["B`@("`@("`@("`@("`@
M("!I9B`H9FEL95]E>&ES=',H)&9I;&5;)VQI;FLG72DI('L*("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-?9&ER*"1F:6QE6R=L:6YK)UTI*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1F:6QE6R=L:6YK='EP92==(#T@)RHJ9&ER
M)SL*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H:7-?;&EN:R@D9FEL
M95LG;&EN:R==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D9FEL95LG
M;&EN:W1Y<&4G72`]("<J*G-Y;2<["B`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E:68@*&ES7V9I;&4H)&9I;&5;)VQI;FLG72DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&5X="`](&5X<&QO9&4H)RXG+"`D9FEL95LG;&EN:R==
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"$H8V]U;G0H)&5X="D@
M/3T@,2!\?"`H)&5X=%LP72`]/3T@)R<@)B8@8V]U;G0H)&5X="D@/3T@,BDI
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9FEL95LG;&EN:W1Y
M<&4G72`](%9&4SHZ<W1R=&]L;W=E<B@D97AT6V-O=6YT*"1E>'0I("T@,5TI
M.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`D9FEL95LG;&EN:W1Y<&4G72`]("<J*F)R;VME;B<["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T@96QS96EF("AI<U]F:6QE*"1E;G1R
M>2DI('L*("`@("`@("`@("`@("`@("1F:6QE6R=P97)M<R==(#T@)RTG("X@
M)&9I;&5;)W!E<FUS)UT["B`@("`@("`@("`@("`@("`D97AT(#T@97AP;&]D
M92@G+B<L("1E;G1R>2D["@H@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1E
M>'0I(#T](#$@?'P@*'-U8G-T<B@D9FEL95LG;F%M92==+"`P+"`Q*2`]/3T@
M)RXG("8F(&-O=6YT*"1E>'0I(#T](#(I*2!["B`@("`@("`@("`@("`@("`@
M("`@)&9I;&5;)W1Y<&4G72`]("<J*FYO;F4G.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D9FEL95LG='EP92==(#T@
M5D93.CIS=')T;VQO=V5R*"1E>'1;8V]U;G0H)&5X="D@+2`Q72D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D9FEL95LG='EP92==(#T@)RHJ;F]N92<["B`@("`@("`@("`@("`@
M("!I9B`H*&9I;&5P97)M<R@D96YT<GDI("8@,'A#,#`P*2`]/2`P>$,P,#`I
M('L*("`@("`@("`@("`@("`@("`@("`D9FEL95LG<&5R;7,G72`]("=S)R`N
M("1F:6QE6R=P97)M<R==.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"AF
M:6QE<&5R;7,H)&5N=')Y*2`F(#!X-C`P,"D@/3T@,'@V,#`P*2!["B`@("`@
M("`@("`@("`@("`@("`@)&9I;&5;)W!E<FUS)UT@/2`G8B<@+B`D9FEL95LG
M<&5R;7,G73L*("`@("`@("`@("`@("`@('T@96QS96EF("@H9FEL97!E<FUS
M*"1E;G1R>2D@)B`P>#(P,#`I(#T](#!X,C`P,"D@>PH@("`@("`@("`@("`@
M("`@("`@("1F:6QE6R=P97)M<R==(#T@)V,G("X@)&9I;&5;)W!E<FUS)UT[
M"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H*&9I;&5P97)M<R@D96YT<GDI
M("8@,'@Q,#`P*2`]/2`P>#$P,#`I('L*("`@("`@("`@("`@("`@("`@("`D
M9FEL95LG<&5R;7,G72`]("=P)R`N("1F:6QE6R=P97)M<R==.PH@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D9FEL95LG
M<&5R;7,G72`]("<_)R`N("1F:6QE6R=P97)M<R==.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!&:6QT97)I;F<N
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^7V9I;'1E<DUA=&-H*"1F:6QT97(L
M("1F:6QE6R=N86UE)UTI*2!["B`@("`@("`@("`@("`@("!U;G-E="@D9FEL
M92D["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!I9B`H)&1I<F]N;'D@)B8@)&9I;&5;)W1Y<&4G72`A/3T@
M)RHJ9&ER)RD@>PH@("`@("`@("`@("`@("`@=6YS970H)&9I;&4I.PH@("`@
M("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1F:6QE<ULD9FEL95LG;F%M92==72`]("1F:6QE.PH@("`@("`@("`@
M("!U;G-E="@D9FEL92D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&9I
M;&5S.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A('-O<G1E9"!L
M:7-T(&]F(&9O;&1E<G,@:6X@<W!E8VEF:65D(&1I<F5C=&]R>2X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@("`@5&AE('!A=&@@
M;V8@=&AE(&1I<F5C=&]R>2!T;R!G970@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@9&ER96-T;W)Y(&QI<W0@9F]R+@H@("`@("H@
M0'!A<F%M(&UI>&5D("1F:6QT97(@("`@("`@($AA<V@@;V8@:71E;7,@=&\@
M9FEL=&5R(&)A<V5D(&]N(&9O;&1E<FQI<W0N"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D9&]T9F]L9&5R<R`@26YC;'5D92!D;W1F;VQD97)S/PH@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@($9O;&1E<B!L:7-T(&]N('-U8V-E<W,@
M;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!L:7-T1F]L9&5R<R@D<&%T:"`]("<G+"`D9FEL=&5R(#T@
M;G5L;"P@)&1O=&9O;&1E<G,@/2!T<G5E*0H@("`@>PH@("`@("`@("1C;VYN
M(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@
M("`@("`@('T*"B`@("`@("`@)&9O;&1E<G,@/2!A<G)A>2@I.PH@("`@("`@
M("1F;VQD97)S6V1I<FYA;64H)'!A=&@I72`](&%R<F%Y*"=V86PG(#T^(&1I
M<FYA;64H)'!A=&@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=A8F)R978G(#T^("<N+B<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)VQA8F5L)R`]/B`G+BXG*3L*"B`@
M("`@("`@)&9O;&1E<DQI<W0@/2`D=&AI<RT^;&ES=$9O;&1E<B@D<&%T:"P@
M;G5L;"P@)&1O=&9O;&1E<G,L('1R=64I.PH@("`@("`@(&EF("AI<U]A*"1F
M;VQD97),:7-T+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D9F]L9&5R3&ES=#L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1F
M;VQD97),:7-T(&%S("1N86UE(#T^("1F:6QE<RD@>PH@("`@("`@("`@("`D
M9F]L9&5R<ULD;F%M95T@/2!A<G)A>2@G=F%L)R`]/B`D<&%T:"`N("<O)R`N
M("1F:6QE<ULG;F%M92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G86)B<F5V)R`]/B`D9FEL97-;)VYA;64G72P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)VQA8F5L)R`]/B`D<&%T:"`N
M("<O)R`N("1F:6QE<ULG;F%M92==*3L*("`@("`@("!]"@H@("`@("`@(&MS
M;W)T*"1F;VQD97)S*3L*"B`@("`@("`@<F5T=7)N("1F;VQD97)S.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N(%5N:7@@<W1Y;&4@<&5R;7,N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)'!E<FUS("!4:&4@<&5R;6ES<VEO;G,@=&\@<V5T+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!5;FEX('-T>6QE('!E<FUS
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T56YI>%!E<FUS*"1P97)M<RD*
M("`@('L*("`@("`@("`O+R!$971E<FUI;F4@<&5R;6ES<VEO;G,*("`@("`@
M("`D;W=N97);)W)E860G72`@("`]("@D<&5R;7,@)B`P,#0P,"D@/R`G<B<@
M.B`G+2<["B`@("`@("`@)&]W;F5R6R=W<FET92==("`@/2`H)'!E<FUS("8@
M,#`R,#`I(#\@)W<G(#H@)RTG.PH@("`@("`@("1O=VYE<ELG97AE8W5T92==
M(#T@*"1P97)M<R`F(#`P,3`P*2`_("=X)R`Z("<M)SL*("`@("`@("`D9W)O
M=7!;)W)E860G72`@("`]("@D<&5R;7,@)B`P,#`T,"D@/R`G<B<@.B`G+2<[
M"B`@("`@("`@)&=R;W5P6R=W<FET92==("`@/2`H)'!E<FUS("8@,#`P,C`I
M(#\@)W<G(#H@)RTG.PH@("`@("`@("1G<F]U<%LG97AE8W5T92==(#T@*"1P
M97)M<R`F(#`P,#$P*2`_("=X)R`Z("<M)SL*("`@("`@("`D=V]R;&1;)W)E
M860G72`@("`]("@D<&5R;7,@)B`P,#`P-"D@/R`G<B<@.B`G+2<["B`@("`@
M("`@)'=O<FQD6R=W<FET92==("`@/2`H)'!E<FUS("8@,#`P,#(I(#\@)W<G
M(#H@)RTG.PH@("`@("`@("1W;W)L9%LG97AE8W5T92==(#T@*"1P97)M<R`F
M(#`P,#`Q*2`_("=X)R`Z("<M)SL*"B`@("`@("`@+R\@061J=7-T(&9O<B!3
M54E$+"!31TE$(&%N9"!S=&EC:WD@8FET"B`@("`@("`@:68@*"1P97)M<R`F
M(#!X.#`P*2!["B`@("`@("`@("`@("1O=VYE<ELG97AE8W5T92==(#T@*"1O
M=VYE<ELG97AE8W5T92==(#T]("=X)RD@/R`G<R<@.B`G4R<["B`@("`@("`@
M?0H@("`@("`@(&EF("@D<&5R;7,@)B`P>#0P,"D@>PH@("`@("`@("`@("`D
M9W)O=7!;)V5X96-U=&4G72`]("@D9W)O=7!;)V5X96-U=&4G72`]/2`G>"<I
M(#\@)W,G(#H@)U,G.PH@("`@("`@('T*("`@("`@("!I9B`H)'!E<FUS("8@
M,'@R,#`I('L*("`@("`@("`@("`@)'=O<FQD6R=E>&5C=71E)UT@/2`H)'=O
M<FQD6R=E>&5C=71E)UT@/3T@)W@G*2`_("=T)R`Z("=4)SL*("`@("`@("!]
M"@H@("`@("`@("1U;FEX4&5R;7,@/2`D;W=N97);)W)E860G72`N("1O=VYE
M<ELG=W)I=&4G72`N("1O=VYE<ELG97AE8W5T92==("X*("`@("`@("`@("`@
M("`@("`@("`@)&=R;W5P6R=R96%D)UT@+B`D9W)O=7!;)W=R:71E)UT@+B`D
M9W)O=7!;)V5X96-U=&4G72`N"B`@("`@("`@("`@("`@("`@("`@("1W;W)L
M9%LG<F5A9"==("X@)'=O<FQD6R=W<FET92==("X@)'=O<FQD6R=E>&5C=71E
M)UT["@H@("`@("`@(')E='5R;B`D=6YI>%!E<FUS.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5N86UE(&$@9FEL92!O<B!F;VQD97(@:6X@=&AE(%9&4RX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1O;&1P871H("!4:&4@;VQD
M('!A=&@@=&\@=&AE(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1O;&1N
M86UE("!4:&4@;VQD(&9I;&5N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;F5W<&%T:"`@5&AE(&YE=R!P871H(&]F('1H92!F:6QE+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;F5W;F%M92`@5&AE(&YE=R!F:6QE;F%M92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!0
M14%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!R96YA;64H)&]L9'!A=&@L("1O;&1N86UE+"`D;F5W<&%T:"P@)&YE
M=VYA;64I"B`@("!["B`@("`@("`@:68@*"%`:7-?9&ER*"1T:&ES+3Y?9V5T
M3F%T:79E4&%T:"@D;F5W<&%T:"DI*2!["B`@("`@("`@("`@(&EF("AI<U]A
M*"1R97,@/2`D=&AI<RT^875T;V-R96%T95!A=&@H)&YE=W!A=&@I+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<SL*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"%`<F5N86UE*"1T
M:&ES+3Y?9V5T3F%T:79E4&%T:"@D;VQD<&%T:"P@)&]L9&YA;64I+`H@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$YA=&EV95!A=&@H)&YE=W!A
M=&@L("1N97=N86UE*2DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE
M("5S+R5S+B(I+"`D;VQD<&%T:"P@)&]L9&YA;64I*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N(&$@9G5L;"!F:6QE;F%M92!O;B!T:&4@;F%T:79E(&9I;&5S>7-T96TL
M(&9R;VT@82!61E,*("`@("`J('!A=&@@86YD(&YA;64N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<&%T:"`@5&AE(%9&4R!F:6QE('!A=&@N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1N86UE("!4:&4@5D93(&9I;&5N86UE+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@9G5L;"!N871I=F4@9FEL96YA;64N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]G971.871I=F50871H*"1P871H(#T@)R<L("1N
M86UE(#T@)R<I"B`@("!["B`@("`@("`@)&YA;64@/2!B87-E;F%M92@D;F%M
M92D["B`@("`@("`@:68@*"%E;7!T>2@D;F%M92DI('L*("`@("`@("`@("`@
M)&YA;64@/2!S=')?<F5P;&%C92@G+BXG+"`G)RP@)&YA;64I.PH@("`@("`@
M("`@("!I9B`H<W5B<W1R*"1N86UE+"`P+"`Q*2`A/2`G+R<I('L*("`@("`@
M("`@("`@("`@("1N86UE(#T@)R\G("X@)&YA;64["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)'!A=&@I*2!["B`@("`@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A<F%M<ULG:&]M92==*2`F)@H@
M("`@("`@("`@("`@("`@<')E9U]M871C:"@G?%Y^+S\H+BHI)'PG+"`D<&%T
M:"P@)&UA=&-H97,I*2!["B`@("`@("`@("`@("`@("`D<&%T:"`]("1T:&ES
M+3Y?<&%R86US6R=H;VUE)UT@+B`G+R<@+B`D;6%T8VAE<ULQ73L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)'!A=&@@/2!S=')?<F5P;&%C92@G+BXG
M+"`G)RP@)'!A=&@I.PH@("`@("`@("`@("!I9B`H<W5B<W1R*"1P871H+"`P
M+"`Q*2`]/2`G+R<I('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7W!A<F%M<ULG=F9S<F]O="==("X@)'!A=&@@+B`D;F%M93L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A
M<F%M<ULG=F9S<F]O="==("X@)R\G("X@)'!A=&@@+B`D;F%M93L*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7W!A<F%M<ULG=F9S<F]O="==("X@)&YA;64["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@4W1U8B!T;R!C:&5C:R!I9B!W92!H879E
M(&$@=F%L:60@8V]N;F5C=&EO;BX@36%K97,@<W5R92!T:&%T"B`@("`@*B!T
M:&4@=F9S<F]O="!I<R!R96%D86)L92X*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&EF
M('9F<W)O;W0@:7,@<F5A9&%B;&4L(%!%05)?17)R;W(@:68@:70@:7-N)W0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYN96-T*"D*("`@('L*("`@("`@
M("!I9B`H*$!I<U]D:7(H)'1H:7,M/E]P87)A;7-;)W9F<W)O;W0G72D@)B8*
M("`@("`@("`@("`@($!I<U]R96%D86)L92@D=&AI<RT^7W!A<F%M<ULG=F9S
M<F]O="==*2D@?'P*("`@("`@("`@("`@0&UK9&ER*"1T:&ES+3Y?<&%R86US
M6R=V9G-R;V]T)UTI*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*%\H(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB
M*2D["B`@("`@("`@?0H@("`@?0H*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O5D93+TQI<W1)
M=&5M+G!H<```````````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#0U,S0@,3`U,34T,S,W,S4@,#(Q,C$V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!!;B!I=&5M
M(')E='5R;F5D(&9R;VT@82!F;VQD97(@;&ES="X*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO5D93+U9&4R],:7-T271E;2YP:'`L=B`Q+C$Q+C$P+C<@,C`P
M-B\P-2\S,2`P-#HU,#HP,B!S;'5S87)Z($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`R+3(P,#8@2F]N(%=O;V0@/&IO;D!J96QL>6)O8BYC;RYU:SX*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IO;B!7;V]D(#QJ;VY`:F5L;'EB
M;V(N8V\N=6L^"B`J($!P86-K86=E(%9&4PH@*B\*8VQA<W,@5D937TQI<W1)
M=&5M('L*"B`@("`O*BH*("`@("`J(%9&4R!P871H"B`@("`@*@H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?<&%T:#L*"B`@("`O*BH*
M("`@("`J($9I;&5N86UE"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@
M("`J+PH@("`@=F%R("1?;F%M93L*"B`@("`O*BH*("`@("`J($9I;&4@<&5R
M;6ES<VEO;G,@*"IN:7@@9F]R;6%T.B!D<G=X<G=X<G=X*0H@("`@("H*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W!E<FUS.PH*("`@
M("\J*@H@("`@("H@3W=N97(@=7-E<@H@("`@("H*("`@("`J($!V87(@<W1R
M:6YG"B`@("`@*B\*("`@('9A<B`D7V]W;F5R.PH*("`@("\J*@H@("`@("H@
M3W=N97(@9W)O=7`*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO
M"B`@("!V87(@)%]G<F]U<#L*"B`@("`O*BH*("`@("`J(%-I>F4N"B`@("`@
M*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?<VEZ93L*
M"B`@("`O*BH*("`@("`J($QA<W0@;6]D:69I960@9&%T92X*("`@("`J"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]D871E.PH*("`@
M("\J*@H@("`@("H@5'EP90H@("`@("H@("`N*B`@("`@("TM("!&:6QE(&5X
M=&5N<VEO;@H@("`@("H@("`J*FYO;F4@("TM("!5;G)E8V]G;FEZ960@='EP
M90H@("`@("H@("`J*G-Y;2`@("TM("!3>6UL:6YK"B`@("`@*B`@("HJ9&ER
M("`@+2T@($1I<F5C=&]R>0H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D7W1Y<&4["@H@("`@+RHJ"B`@("`@*B!4>7!E(&]F
M('1A<F=E="!I9B!T>7!E(&ES("<J*G-Y;2<N"B`@("`@*B!.0BX@3F]T(&%L
M;"!B86-K96YD<R!A<F4@8V%P86)L92!O9B!D:7-T:6YG=6ES:&EN9R!A;&P@
M;V8@=&AE<V4N"B`@("`@*B`@("XJ("`@("`@("`M+2`@1FEL92!E>'1E;G-I
M;VX*("`@("`J("`@*BIN;VYE("`@("TM("!5;G)E8V]G;FEZ960@='EP90H@
M("`@("H@("`J*G-Y;2`@("`@+2T@(%-Y;6QI;FL@=&\@82!S>6UL:6YK"B`@
M("`@*B`@("HJ9&ER("`@("`M+2`@1&ER96-T;W)Y"B`@("`@*B`@("HJ8G)O
M:V5N("`M+2`@5&%R9V5T(&YO="!F;W5N9"`M(&)R;VME;B!L:6YK"B`@("`@
M*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?;&EN:W1Y
M<&4["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("H*("`@("`J
M(%)E<75I<F5S('1H92!P871H('1O('1H92!F:6QE+"!A;F0@:70G<R!A<G)A
M>2!O9B!P<F]P97)T:65S+`H@("`@("H@<F5T=7)N960@9G)O;2!A('-T86YD
M87)D(%9&4SHZ;&ES=$9O;&1E<B@I(&-A;&PN"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<&%T:"`@("`@(%1H92!P871H('1O('1H92!F:6QE+@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1F:6QE07)R87D@($%N(&%R<F%Y(&]F(&9I
M;&4@<')O<&5R=&EE<RX*("`@("`J+PH@("`@9G5N8W1I;VX@5D937TQI<W1)
M=&5M*"1P871H+"`D9FEL94%R<F%Y*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M<&%T:"`]("1P871H("X@)R\G("X@)&9I;&5!<G)A>5LG;F%M92==.PH@("`@
M("`@("1T:&ES+3Y?;F%M92`]("1F:6QE07)R87E;)VYA;64G73L*("`@("`@
M("`D=&AI<RT^7V1I<FYA;64@/2`D<&%T:#L*("`@("`@("`D=&AI<RT^7W!E
M<FUS(#T@)&9I;&5!<G)A>5LG<&5R;7,G73L*("`@("`@("`D=&AI<RT^7V]W
M;F5R(#T@)&9I;&5!<G)A>5LG;W=N97(G73L*("`@("`@("`D=&AI<RT^7V=R
M;W5P(#T@)&9I;&5!<G)A>5LG9W)O=7`G73L*("`@("`@("`D=&AI<RT^7W-I
M>F4@/2`D9FEL94%R<F%Y6R=S:7IE)UT["B`@("`@("`@)'1H:7,M/E]D871E
M(#T@)&9I;&5!<G)A>5LG9&%T92==.PH@("`@("`@("1T:&ES+3Y?='EP92`]
M("1F:6QE07)R87E;)W1Y<&4G73L*("`@("`@("`D=&AI<RT^7VQI;FMT>7!E
M(#T@)&9I;&5!<G)A>5LG;&EN:W1Y<&4G73L*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O0FQO8VL`````````````````````````````````````````````````
M````````````````````````````````````````,#`P-S4U(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S4@,#$W,C8R`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B]";&]C:R]T:6UE+G!H<```````````````
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S`T-R`Q,#4Q-30S
M,S<S-2`P,C$P,30`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"B1B;&]C:U]N86UE(#T@7R@B0W5R<F5N="!4:6UE
M(BD["@HO*BH*("H@)$AO<F1E.B!H;W)D92]L:6(O0FQO8VLO=&EM92YP:'`L
M=B`Q+C$V(#(P,#0O,3$O,C,@,34Z,3<Z-3,@8VAU8VL@17AP("0*("H*("H@
M0'!A8VMA9V4@2&]R9&5?0FQO8VL*("HO"F-L87-S($AO<F1E7T)L;V-K7TAO
M<F1E7W1I;64@97AT96YD<R!(;W)D95]";&]C:R!["@H@("`@=F%R("1?87!P
M(#T@)VAO<F1E)SL*"B`@("!F=6YC=&EO;B!?<&%R86US*"D*("`@('L*("`@
M("`@("!R971U<FX@)'!A<F%M<R`](&%R<F%Y*"=T:6UE)R`]/B!A<G)A>2@G
M='EP92<@/3X@)V5N=6TG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B!?*")4:6UE(&9O<FUA="(I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=D969A=6QT)R`]/B`G,C0M:&]U<B<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W9A;'5E<R<@/3X@87)R
M87DH)S(T+6AO=7(G(#T^(%\H(C(T($AO=7(@1F]R;6%T(BDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)S$R+6AO=7(G(#T^(%\H(C$R($AO=7(@1F]R;6%T(BDI
M*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@=&ET;&4@=&\@9V\@:6X@
M=&AI<R!B;&]C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@(%1H
M92!T:71L92!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=&ET;&4H*0H@
M("`@>PH@("`@("`@(')E='5R;B!?*")#=7)R96YT(%1I;64B*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%1H92!C;VYT96YT('1O(&=O(&EN('1H:7,@8FQO
M8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@("!4:&4@8V]N=&5N
M=`H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N=&5N="@I"B`@("!["B`@("`@
M("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%R86US6R=T:6UE)UTI*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=T:6UE)UT@/2`G,C0M:&]U<B<["B`@
M("`@("`@?0H*("`@("`@("`O+R!3970@=&AE('1I;65Z;VYE('9A<FEA8FQE
M+"!I9B!A=F%I;&%B;&4N"B`@("`@("`@3DQ3.CIS9714:6UE6F]N92@I.PH*
M("`@("`@("`D:'1M;"`]("<\=&%B;&4@=VED=&@](C$P,"4B(&AE:6=H=#TB
M,3`P)2(^/'1R/CQT9"!S='EL93TB9F]N="UF86UI;'DZ=F5R9&%N83MF;VYT
M+7-I>F4Z,3AP>#LB(&%L:6=N/2)C96YT97(B('9A;&EG;CTB;6ED9&QE(CXG
M.PH@("`@("`@("1H=&UL("X]('-T<F9T:6UE*"<E02P@)4(@)60L("59("<I
M.PH@("`@("`@(&EF("@D=&AI<RT^7W!A<F%M<ULG=&EM92==(#T]("<R-"UH
M;W5R)RD@>PH@("`@("`@("`@("`D:'1M;"`N/2!S=')F=&EM92@G)4@Z)4TG
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D:'1M;"`N/2!S=')F
M=&EM92@G)4DZ)4T@)7`G*3L*("`@("`@("!]"B`@("`@("`@)&AT;6P@+CT@
M)SPO=&0^/"]T<CX\+W1A8FQE/B<["@H@("`@("`@(')E='5R;B`D:'1M;#L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'``````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-#,V-30@,3`U,34T,S,W,S4@
M,#(R-S,S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"@HO*B!$:7-A8FQE(&)L;V-K(&EF(&YO="!C;VYF:6=U<F5D
M+B`J+PII9B`H(65M<'1Y*"1'3$]"04Q36R=C;VYF)UU;)W=E871H97)D;W1C
M;VTG75LG<&%R=&YE<E]I9"==*2`F)@H@("`@(65M<'1Y*"1'3$]"04Q36R=C
M;VYF)UU;)W=E871H97)D;W1C;VTG75LG;&EC96YS95]K97DG72DI('L*("`@
M("1B;&]C:U]N86UE(#T@7R@B=V5A=&AE<BYC;VTB*3L*?0H*+RHJ"B`J(%1H
M92!(;W)D95]";&]C:U]W96%T:&5R9&]T8V]M(&-L87-S('!R;W9I9&5S(&%N
M(&%P<&QE="!F;W(@=&AE"B`J('!O<G1A;"!S8W)E96X@=&\@9&ES<&QA>2!W
M96%T:&5R(&%N9"!F;W)E8V%S="!D871A(&9R;VT@=V5A=&AE<BYC;VT*("H@
M9F]R(&$@<W!E8VEF:65D(&QO8V%T:6]N+@H@*@H@*B`D2&]R9&4Z(&AO<F1E
M+VQI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<"QV(#$N,S<N-"XQ,R`R,#`U
M+S$R+S`U(#`S.C0Q.C`P(&-H=6-K($5X<"`D"B`J"B`J($!P86-K86=E($AO
M<F1E7T)L;V-K"B`J+PIC;&%S<R!(;W)D95]";&]C:U](;W)D95]W96%T:&5R
M9&]T8V]M(&5X=&5N9',@2&]R9&5?0FQO8VL@>PH*("`@('9A<B`D7V%P<"`]
M("=H;W)D92<["@H@("`@+RHJ"B`@("`@*B!4:&4@=&ET;&4@=&\@9V\@:6X@
M=&AI<R!B;&]C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@(%1H
M92!T:71L92!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=&ET;&4H*0H@
M("`@>PH@("`@("`@(')E='5R;B!?*")796%T:&5R($9O<F5C87-T(BD["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@<&%R86UE=&5R<R!T;R!G;R!W:71H
M('1H:7,@8FQO8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@
M87)R87D@8V]N=&%I;FEN9R!T:&4@<&%R86UE=&5R<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@7W!A<F%M<R@I"B`@("!["B`@("`@("`@:68@*"$H0&EN8VQU
M9&5?;VYC92`G4V5R=FEC97,O5V5A=&AE<BYP:'`G*2!\?`H@("`@("`@("`@
M("`A*$!I;F-L=61E7V]N8V4@)T-A8VAE+G!H<"<I('Q\"B`@("`@("`@("`@
M("$H0&EN8VQU9&5?;VYC92`G6$U,+U-E<FEA;&EZ97(N<&AP)RD@?'P*("`@
M("`@("`@("`@(6EN:5]G970H)V%L;&]W7W5R;%]F;W!E;B<I*2!["B`@("`@
M("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=4:&4@=V5A=&AE<BYC;VT@8FQO
M8VL@=VEL;"!N;W0@=V]R:R!W:71H;W5T(%!%05)<)W,@4V5R=FEC97-?5V5A
M=&AE<BP@0V%C:&4L(&%N9"!834Q?(%-E<FEA;&EZ97(@<&%C:V%G97,L(&%N
M9"!A;&QO=U]U<FQ?9F]P96X@96YA8FQE9"X@4G5N(&!P96%R(&EN<W1A;&P@
M4V5R=FEC97-?5V5A=&AE<B!#86-H92!834Q?4V5R:6%L:7IE<K0@86YD(&5N
M<W5R92!T:&%T(&%L;&]W7W5R;%]F;W!E;B!I<R!E;F%B;&5D(&EN('!H<"YI
M;FDN)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L
M(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("`D<&%R86US
M(#T@87)R87DH"B`@("`@("`@("`@("`@("`G97)R;W(G(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("=T>7!E)R`]/B`G97)R;W(G+`H@("`@("`@
M("`@("`@("`@("`@("=N86UE)R`]/B!?*")%<G)O<B(I+`H@("`@("`@("`@
M("`@("`@("`@("=D969A=6QT)R`]/B!?*")4:&4@=V5A=&AE<BYC;VT@8FQO
M8VL@:7,@;F]T(&%V86EL86)L92XB*0H@("`@("`@("`@("`@("`@*0H@("`@
M("`@("`@("`I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P87)A
M;7,@/2!A<G)A>2@*("`@("`@("`@("`@("`@("=L;V-A=&EO;B<@/3X@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@+R\@)W1Y<&4G(#T^("=W96%T:&5R
M9&]T8V]M)RP*("`@("`@("`@("`@("`@("`@("`G='EP92<@/3X@)W1E>'0G
M+`H@("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B!?*"),;V-A=&EO;B(I
M+`H@("`@("`@("`@("`@("`@("`@("=D969A=6QT)R`]/B`G0F]S=&]N+"!-
M02<*("`@("`@("`@("`@("`@("DL"B`@("`@("`@("`@("`@("`G=6YI=',G
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=T>7!E)R`]/B`G96YU
M;2<L"B`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^(%\H(E5N:71S(BDL
M"B`@("`@("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^("=S=&%N9&%R9"<L
M"B`@("`@("`@("`@("`@("`@("`@)S`G(#T^("=N;VYE)RP*("`@("`@("`@
M("`@("`@("`@("`G=F%L=65S)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@
M("`@("`@("`@)W-T86YD87)D)R`]/B!?*")3=&%N9&%R9"(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`G;65T<FEC)R`]/B!?*")-971R:6,B*0H@("`@
M("`@("`@("`@("`@("`@("D*("`@("`@("`@("`@("`@("DL"B`@("`@("`@
M("`@("`@("`G9&%Y<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@
M)W1Y<&4G(#T^("=E;G5M)RP*("`@("`@("`@("`@("`@("`@("`G;F%M92<@
M/3X@7R@B1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F
M;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82!L87)G92!N
M=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(I+`H@
M("`@("`@("`@("`@("`@("`@("=D969A=6QT)R`]/B`G,R<L"B`@("`@("`@
M("`@("`@("`@("`@)W9A;'5E<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@
M("`@("`@("`@("<Q)R`]/B`G,2<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("<R)R`]/B`G,B<L"B`@("`@("`@("`@("`@("`@("`@("`@("<S)R`]/B`G
M,R<L"B`@("`@("`@("`@("`@("`@("`@("`@("<T)R`]/B`G-"<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("<U)R`]/B`G-2<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("<V)R`]/B`G-B<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("<W)R`]/B`G-R<L"B`@("`@("`@("`@("`@("`@("`@("`@("<X)R`]/B`G
M."<L"B`@("`@("`@("`@("`@("`@("`@("`@("<Y)R`]/B`G.2<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("<Q,"<@/3X@)S$P)PH@("`@("`@("`@("`@
M("`@("`@("D*("`@("`@("`@("`@("`@("DL"B`@("`@("`@("`@("`@("`G
M9&5T86EL961&;W)E8V%S="<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@
M("`@)W1Y<&4G(#T^("=C:&5C:V)O>"<L"B`@("`@("`@("`@("`@("`@("`@
M)VYA;64G(#T^(%\H(D1I<W!L87D@9&5T86EL960@9F]R96-A<W0B*2P*("`@
M("`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@,`H@("`@("`@("`@("`@
M("`@*0H@("`@("`@("`@("`I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1P87)A;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@8V]N=&5N="!T
M;R!G;R!I;B!T:&ES(&)L;V-K+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("`@5&AE(&-O;G1E;G0*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;G1E
M;G0H*0H@("`@>PH@("`@("`@(&EF("@A*$!I;F-L=61E7V]N8V4@)U-E<G9I
M8V5S+U=E871H97(N<&AP)RD@?'P*("`@("`@("`@("`@(2A`:6YC;'5D95]O
M;F-E("=#86-H92YP:'`G*2!\?`H@("`@("`@("`@("`A:6YI7V=E="@G86QL
M;W=?=7)L7V9O<&5N)RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A
M9V4H)U1H92!W96%T:&5R+F-O;2!B;&]C:R!W:6QL(&YO="!W;W)K('=I=&AO
M=70@=&AE(%!%05)397)V:6-E<U]796%T:&5R(&%N9"!#86-H92!P86-K86=E
M<RP@86YD(&%L;&]W7W5R;%]F;W!E;B!E;F%B;&5D+B!2=6X@<&5A<B!I;G-T
M86QL(%-E<G9I8V5S7U=E871H97(@0V%C:&4L(&%N9"!E;G-U<F4@=&AA="!A
M;&QO=U]U<FQ?9F]P96Y?=W)A<'!E<G,@:7,@96YA8FQE9"!I;B!P:'`N:6YI
M+B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?
M7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N(%\H
M(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+B(I.PH@
M("`@("`@('T*"B`@("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("!I9B`H
M96UP='DH)'1H:7,M/E]P87)A;7-;)VQO8V%T:6]N)UTI*2!["B`@("`@("`@
M("`@(')E='5R;B!?*").;R!L;V-A=&EO;B!I<R!S970N(BD["B`@("`@("`@
M?0H*("`@("`@("`D=V5A=&AE<D1O=$-O;2`]("9397)V:6-E<U]796%T:&5R
M.CIS97)V:6-E*"=796%T:&5R1&]T0V]M)RD["B`@("`@("`@)'=E871H97)$
M;W1#;VTM/G-E=$%C8V]U;G1$871A*`H@("`@("`@("`@("`H:7-S970H)&-O
M;F9;)W=E871H97)D;W1C;VTG75LG<&%R=&YE<E]I9"==*2`_("1C;VYF6R=W
M96%T:&5R9&]T8V]M)UU;)W!A<G1N97)?:60G72`Z("<G*2P*("`@("`@("`@
M("`@*&ES<V5T*"1C;VYF6R=W96%T:&5R9&]T8V]M)UU;)VQI8V5N<V5?:V5Y
M)UTI(#\@)&-O;F9;)W=E871H97)D;W1C;VTG75LG;&EC96YS95]K97DG72`Z
M("<G*2D["@H@("`@("`@("1C86-H941I<B`]($AO<F1E.CIG971496UP1&ER
M*"D["B`@("`@("`@:68@*"$D8V%C:&5$:7(I('L*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B3F\@=&5M<&]R87)Y(&1I<F5C=&]R
M>2!A=F%I;&%B;&4@9F]R(&-A8VAE+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=V5A=&AE<D1O=$-O;2T^<V5T
M0V%C:&4H)V9I;&4G+"!A<G)A>2@G8V%C:&5?9&ER)R`]/B`H)&-A8VAE1&ER
M("X@)R\G*2DI.PH@("`@("`@('T*("`@("`@("`D=V5A=&AE<D1O=$-O;2T^
M<V5T1&%T951I;65&;W)M870H)VTN9"Y9)RP@)T@Z:2<I.PH@("`@("`@("1W
M96%T:&5R1&]T0V]M+3YS9715;FET<T9O<FUA="@D=&AI<RT^7W!A<F%M<ULG
M=6YI=',G72D["B`@("`@("`@)'5N:71S(#T@)'=E871H97)$;W1#;VTM/F=E
M=%5N:71S1F]R;6%T*"D["@H@("`@("`@("\O($EF('1H92!U<V5R(&5N=&5R
M960@82!Z:7`@8V]D92!F;W(@=&AE(&QO8V%T:6]N+"!N;R!N965D('1O"B`@
M("`@("`@+R\@<V5A<F-H("AW96%T:&5R+F-O;2!A8V-E<'1S('II<"!C;V1E
M<R!A<R!L;V-A=&EO;B!)1',I+@H@("`@("`@("\O(%1H92!L;V-A=&EO;B!)
M1"!S:&]U;&0@86QR96%D>2!H879E(&)E96X@=F%L:61A=&5D(&EN"B`@("`@
M("`@+R\@9V5T4&%R86US+@H@("`@("`@("1S96%R8V@@/2`H<')E9U]M871C
M:"@G+UQB*#\Z7%QD>S5]*"U<7&1[-7TI/RE\*#\Z6T$M6EU[-'U<7&1[-'TI
M7&(O)RP*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)VQO8V%T:6]N)UTL
M("1M871C:&5S*2`_"B`@("`@("`@("`@("1M871C:&5S6S!=(#H*("`@("`@
M("`@("`@)'=E871H97)$;W1#;VTM/G-E87)C:$QO8V%T:6]N*"1T:&ES+3Y?
M<&%R86US6R=L;V-A=&EO;B==*2D["B`@("`@("`@:68@*&ES7V$H)'-E87)C
M:"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!S=VET8V@@*"1S96%R
M8V@M/F=E=$-O9&4H*2D@>PH@("`@("`@("`@("!C87-E(%-%4E9)0T537U=%
M051(15)?15)23U)?4T525DE#15].3U1?1D]53D0Z"B`@("`@("`@("`@("`@
M("!R971U<FX@7R@B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O
M=6YD+B(I.PH@("`@("`@("`@("!C87-E(%-%4E9)0T537U=%051(15)?15)2
M3U)?54Y+3D]73E],3T-!5$E/3CH*("`@("`@("`@("`@("`@(')E='5R;B!?
M*")5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(I.PH@("`@("`@("`@("!C
M87-E(%-%4E9)0T537U=%051(15)?15)23U)?5U)/3D=?4T525D527T1!5$$Z
M"B`@("`@("`@("`@("`@("!R971U<FX@7R@B4V5R=F5R(&1A=&$@=W)O;F<@
M;W(@;F]T(&%V86EL86)L92XB*3L*("`@("`@("`@("`@8V%S92!315)624-%
M4U]714%42$527T524D]27T-!0TA%7TE.251?1D%)3$5$.@H@("`@("`@("`@
M("`@("`@<F5T=7)N(%\H(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N
M(BD["B`@("`@("`@("`@(&-A<V4@4T525DE#15-?5T5!5$A%4E]%4E)/4E]$
M0E].3U1?0T].3D5#5$5$.@H@("`@("`@("`@("`@("`@<F5T=7)N(%\H(DUE
M=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB*3L*("`@("`@("`@("`@8V%S92!3
M15)624-%4U]714%42$527T524D]27U5.2TY/5TY?15)23U(Z"B`@("`@("`@
M("`@("`@("!R971U<FX@7R@B06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E
M9"XB*3L*("`@("`@("`@("`@8V%S92!315)624-%4U]714%42$527T524D]2
M7TY/7TQ/0T%424]..@H@("`@("`@("`@("`@("`@<F5T=7)N(%\H(DYO(&QO
M8V%T:6]N('!R;W9I9&5D+B(I.PH@("`@("`@("`@("!C87-E(%-%4E9)0T53
M7U=%051(15)?15)23U)?24Y604Q)1%],3T-!5$E/3CH*("`@("`@("`@("`@
M("`@(')E='5R;B!?*"));G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(I.PH@
M("`@("`@("`@("!C87-E(%-%4E9)0T537U=%051(15)?15)23U)?24Y604Q)
M1%]005)43D527TE$.@H@("`@("`@("`@("`@("`@<F5T=7)N(%\H(DEN=F%L
M:60@<&%R=&YE<B!I9"XB*3L*("`@("`@("`@("`@8V%S92!315)624-%4U]7
M14%42$527T524D]27TE.5D%,241?4%)/1%5#5%]#3T1%.@H@("`@("`@("`@
M("`@("`@<F5T=7)N(%\H(DEN=F%L:60@<')O9'5C="!C;V1E+B(I.PH@("`@
M("`@("`@("!C87-E(%-%4E9)0T537U=%051(15)?15)23U)?24Y604Q)1%],
M24-%3E-%7TM%63H*("`@("`@("`@("`@("`@(')E='5R;B!?*"));G9A;&ED
M(&QI8V5N<V4@:V5Y+B(I.PH@("`@("`@("`@("!D969A=6QT.@H@("`@("`@
M("`@("`@("`@<F5T=7)N("1S96%R8V@M/F=E=&UE<W-A9V4H*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&AT;6P@/2`G)SL*("`@("`@
M("!I9B`H:7-?87)R87DH)'-E87)C:"DI('L*("`@("`@("`@("`@+R\@4V5V
M97)A;"!L;V-A=&EO;G,@<F5T=7)N960@9'5E('1O(&EM<')E8VES92!L;V-A
M=&EO;@H@("`@("`@("`@("`O+R!P87)A;65T97(N"B`@("`@("`@("`@("1H
M=&UL(#T@7R@B4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@
M<&%R86UE=&5R.B`B*2`N"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M
M<ULG;&]C871I;VXG72`N"B`@("`@("`@("`@("`@("`G/&)R("\^/'5L/B<[
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1S96%R8V@@87,@)&ED7W=E871H97(]
M/B1R96%L7VQO8V%T:6]N*2!["B`@("`@("`@("`@("`@("`D:'1M;"`N/2`B
M/&QI/B1R96%L7VQO8V%T:6]N("@D:61?=V5A=&AE<BD\+VQI/EQN(CL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D:'1M;"`N/2`G/"]U;#XG.PH@("`@
M("`@("`@("!R971U<FX@)&AT;6P["B`@("`@("`@?0H*("`@("`@("`D;&]C
M871I;VX@/2`D=V5A=&AE<D1O=$-O;2T^9V5T3&]C871I;VXH)'-E87)C:"D[
M"B`@("`@("`@:68@*&ES7V$H)&QO8V%T:6]N+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D;&]C871I;VXM/F=E=&UE<W-A9V4H*3L*
M("`@("`@("!]"B`@("`@("`@)'=E871H97(@/2`D=V5A=&AE<D1O=$-O;2T^
M9V5T5V5A=&AE<B@D<V5A<F-H*3L*("`@("`@("!I9B`H:7-?82@D=V5A=&AE
M<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'=E871H
M97(M/F=E=&UE<W-A9V4H*3L*("`@("`@("!]"B`@("`@("`@)&9O<F5C87-T
M(#T@)'=E871H97)$;W1#;VTM/F=E=$9O<F5C87-T*"1S96%R8V@L("1T:&ES
M+3Y?<&%R86US6R=D87ES)UTI.PH@("`@("`@(&EF("AI<U]A*"1F;W)E8V%S
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&9O<F5C
M87-T+3YG971M97-S86=E*"D["B`@("`@("`@?0H*("`@("`@("`O+R!,;V-A
M=&EO;B!A;F0@;&]C86P@=&EM92X*("`@("`@("`D:'1M;"`N/2`G/&1I=B!C
M;&%S<STB8V]N=')O;"(^)R`N"B`@("`@("`@("`@("<\<W1R;VYG/B<@+B`D
M;&]C871I;VY;)VYA;64G72`N("<\+W-T<F]N9SX@)R`N(%\H(DQO8V%L('1I
M;64Z("(I("X@)&QO8V%T:6]N6R=T:6UE)UT@+@H@("`@("`@("`@("`G/"]D
M:78^)SL*"B`@("`@("`@+R\@4W5N<FES92]S=6YS970N"B`@("`@("`@)&AT
M;6P@+CT@)SQS=')O;F<^)R`N(%\H(E-U;G)I<V4Z("(I("X@)SPO<W1R;VYG
M/B<@+@H@("`@("`@("`@("!(;W)D93HZ:6UG*"=B;&]C:R]S=6YR:7-E+W-U
M;G)I<V4N<&YG)RP@7R@B4W5N<FES92(I*2`N"B`@("`@("`@("`@("1L;V-A
M=&EO;ELG<W5N<FES92==.PH@("`@("`@("1H=&UL("X]("<@/'-T<F]N9SXG
M("X@7R@B4W5N<V5T.B`B*2`N("<\+W-T<F]N9SXG("X*("`@("`@("`@("`@
M2&]R9&4Z.FEM9R@G8FQO8VLO<W5N<FES92]S=6YS970N<&YG)RP@7R@B4W5N
M<V5T(BDI("X*("`@("`@("`@("`@)&QO8V%T:6]N6R=S=6YS970G73L*"B`@
M("`@("`@+R\@5&5M<&5R871U<F4N"B`@("`@("`@)&AT;6P@+CT@)SQB<B`O
M/CQS=')O;F<^)R`N(%\H(E1E;7!E<F%T=7)E.B`B*2`N("<\+W-T<F]N9SXG
M("X*("`@("`@("`@("`@<F]U;F0H)'=E871H97);)W1E;7!E<F%T=7)E)UTI
M("X@)R9D96<[)R`N(%-T<FEN9SHZ=7!P97(H)'5N:71S6R=T96UP)UTI.PH*
M("`@("`@("`O+R!$97<@<&]I;G0N"B`@("`@("`@)&AT;6P@+CT@)R`\<W1R
M;VYG/B<@+B!?*")$97<@<&]I;G0Z("(I("X@)SPO<W1R;VYG/B<@+@H@("`@
M("`@("`@("!R;W5N9"@D=V5A=&AE<ELG9&5W4&]I;G0G72D@+B`G)F1E9SLG
M("X@4W1R:6YG.CIU<'!E<B@D=6YI='-;)W1E;7`G72D["@H@("`@("`@("\O
M($9E96QS(&QI:V4@=&5M<&5R871U<F4N"B`@("`@("`@)&AT;6P@+CT@)R`\
M<W1R;VYG/B<@+B!?*")&965L<R!L:6ME.B`B*2`N("<\+W-T<F]N9SXG("X*
M("`@("`@("`@("`@<F]U;F0H)'=E871H97);)V9E;'1496UP97)A='5R92==
M*2`N("<F9&5G.R<@+B!3=')I;F<Z.G5P<&5R*"1U;FET<ULG=&5M<"==*3L*
M"B`@("`@("`@+R\@4')E<W-U<F4@86YD('1R96YD+@H@("`@("`@("1H=&UL
M("X]("<\8G(@+SX\<W1R;VYG/B<@+B!?*")0<F5S<W5R93H@(BD@+B`G/"]S
M=')O;F<^)SL*("`@("`@("`D=')E;F0@/2`D=V5A=&AE<ELG<')E<W-U<F54
M<F5N9"==.PH@("`@("`@("1H=&UL("X]('-P<FEN=&8H7R@B)60@)7,@86YD
M("5S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("!R;W5N9"@D=V5A=&AE
M<ELG<')E<W-U<F4G72DL("1U;FET<ULG<')E<R==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@7R@D=')E;F0I*3L*"B`@("`@("`@+R\@5VEN9"X*("`@
M("`@("`D:'1M;"`N/2`G/&)R("\^/'-T<F]N9SXG("X@7R@B5VEN9#H@(BD@
M+B`G/"]S=')O;F<^)SL*("`@("`@("!I9B`H)'=E871H97);)W=I;F1$:7)E
M8W1I;VXG72`]/2`G5D%2)RD@>PH@("`@("`@("`@("`D:'1M;"`N/2!?*")6
M87)I86)L92(I.PH@("`@("`@('T@96QS96EF("@D=V5A=&AE<ELG=VEN9$1I
M<F5C=&EO;B==(#T]("=#04Q-)RD@>PH@("`@("`@("`@("`D:'1M;"`N/2!?
M*")#86QM(BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&AT;6P@
M+CT@7R@B1G)O;2!T:&4@(BD@+B`D=V5A=&AE<ELG=VEN9$1I<F5C=&EO;B==
M.PH@("`@("`@(&EF("AI<W-E="@D=V5A=&AE<ELG=VEN9$=U<W0G72D@)B8@
M)'=E871H97);)W=I;F1'=7-T)UT@/B`P*2!["B`@("`@("`@("`@("1H=&UL
M("X]("<L("<@+B!?*")G=7-T:6YG(BD@+B`G("<@+B`D=V5A=&AE<ELG=VEN
M9$=U<W0G72`N"B`@("`@("`@("`@("`@("`G("<@+B`D=6YI='-;)W=I;F0G
M73L*("`@("`@("!]"@H@("`@("`@("`@("`D:'1M;"`N/2`G("@G("X@)'=E
M871H97);)W=I;F1$96=R965S)UT@+B`G*2<["B`@("`@("`@?0H@("`@("`@
M("1H=&UL("X](%\H(B!A="`B*2`N(')O=6YD*"1W96%T:&5R6R=W:6YD)UTI
M("X@)R`G("X@)'5N:71S6R=W:6YD)UT["@H@("`@("`@("\O($AU;6ED:71Y
M+@H@("`@("`@("1H=&UL("X]("<\8G(@+SX\<W1R;VYG/B<@+B!?*")(=6UI
M9&ET>3H@(BD@+B`G/"]S=')O;F<^)R`N"B`@("`@("`@("`@("1W96%T:&5R
M6R=H=6UI9&ET>2==("X@)R4G.PH*("`@("`@("`O+R!6:7-I8FEL:71Y+@H@
M("`@("`@("1H=&UL("X]("<@/'-T<F]N9SXG("X@7R@B5FES:6)I;&ET>3H@
M(BD@+B`G/"]S=')O;F<^)R`N"B`@("`@("`@("`@("AI<U]N=6UE<FEC*"1W
M96%T:&5R6R=V:7-I8FEL:71Y)UTI"B`@("`@("`@("`@("`_(')O=6YD*"1W
M96%T:&5R6R=V:7-I8FEL:71Y)UTI("X@)R`G("X@)'5N:71S6R=V:7,G70H@
M("`@("`@("`@("`@.B`D=V5A=&AE<ELG=FES:6)I;&ET>2==*3L*"B`@("`@
M("`@+R\@558@:6YD97@N"B`@("`@("`@)&AT;6P@+CT@)R`\<W1R;VYG/B<@
M+B!?*")5+E8N(&EN9&5X.B`B*2`N("<\+W-T<F]N9SXG.PH@("`@("`@("1U
M=B`]("1W96%T:&5R6R=U=E1E>'0G73L*("`@("`@("`D:'1M;"`N/2`D=V5A
M=&AE<ELG=79);F1E>"==("X@)R`M("<@+B!?*"1U=BD["@H@("`@("`@("\O
M($-U<G)E;G0@8V]N9&ET:6]N+@H@("`@("`@("1C;VYD:71I;VX@/2!I;7!L
M;V1E*"<@+R`G+"!A<G)A>5]M87`H)U\G+"!E>'!L;V1E*"<@+R`G+"`D=V5A
M=&AE<ELG8V]N9&ET:6]N)UTI*2D["B`@("`@("`@)&AT;6P@+CT@)SQB<B`O
M/CQS=')O;F<^)R`N(%\H(D-U<G)E;G0@8V]N9&ET:6]N.B`B*2`N("<\+W-T
M<F]N9SXG("X*("`@("`@("`@("`@2&]R9&4Z.FEM9R@G8FQO8VLO=V5A=&AE
M<F1O=&-O;2\S,G@S,B\G("X*("`@("`@("`@("`@("`@("`@("`@("`H)'=E
M871H97);)V-O;F1I=&EO;DEC;VXG72`]/2`G+2<@/R`G;F$G(#H@)'=E871H
M97);)V-O;F1I=&EO;DEC;VXG72D@+B`G+G!N9R<L"B`@("`@("`@("`@("`@
M("`@("`@("`@)&-O;F1I=&EO;BP*("`@("`@("`@("`@("`@("`@("`@("`G
M86QI9VX](FUI9&1L92(G*3L*("`@("`@("`D:'1M;"`N/2`G("<@+B`D8V]N
M9&ET:6]N.PH*("`@("`@("`O+R!$;R!T:&4@9F]R96-A<W0@;F]W("AI9B!R
M97%U97-T960I+@H@("`@("`@(&EF("@D=&AI<RT^7W!A<F%M<ULG9&%Y<R==
M(#X@,"D@>PH@("`@("`@("`@("`D:'1M;"`N/2`G/&1I=B!C;&%S<STB8V]N
M=')O;"(@<W1Y;&4](G1E>'0M86QI9VXZ8V5N=&5R(CX\<W1R;VYG/B<@+@H@
M("`@("`@("`@("`@("`@<W!R:6YT9BA?*"(E9"UD87D@9F]R96-A<W0B*2P@
M)'1H:7,M/E]P87)A;7-;)V1A>7,G72D@+@H@("`@("`@("`@("`@("`@)SPO
M<W1R;VYG/CPO9&EV/B<["@H@("`@("`@("`@("`D9G5T=7)E1&%Y<R`](#`[
M"B`@("`@("`@("`@("1H=&UL("X]("<\=&%B;&4@=VED=&@](C$P,"4B(&-E
M;&QS<&%C:6YG/2(S(CXG.PH@("`@("`@("`@("`O+R!(96%D97)S+@H@("`@
M("`@("`@("`D:'1M;"`N/2`G/'1R/B<["B`@("`@("`@("`@("1H=&UL("X]
M("<\=&@^)R`N(%\H(D1A>2(I("X@)SPO=&@^/'1H/B9N8G-P.SPO=&@^/'1H
M/B<@+@H@("`@("`@("`@("`@("`@<W!R:6YT9BA?*")496UP97)A='5R93QB
M<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(BDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("<\<W!A;B!S='EL93TB8V]L;W(Z<F5D(CXG+"`G/"]S<&%N
M/B<L"B`@("`@("`@("`@("`@("`@("`@("`@("<\<W!A;B!S='EL93TB8V]L
M;W(Z8FQU92(^)RP@)SPO<W!A;CXG+`H@("`@("`@("`@("`@("`@("`@("`@
M("!3=')I;F<Z.G5P<&5R*"1U;FET<ULG=&5M<"==*2D@+@H@("`@("`@("`@
M("`@("`@)SPO=&@^/'1H/B<@+B!?*")#;VYD:71I;VXB*2`N("<\+W1H/B<@
M+@H@("`@("`@("`@("`@("`@)SQT:#XG("X@7R@B4')E8VEP:71A=&EO;CQB
M<B`O/F-H86YC92(I("X@)SPO=&@^)SL*("`@("`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?<&%R86US6R=D971A:6QE9$9O<F5C87-T)UTI*2!["B`@("`@
M("`@("`@("`@("`D:'1M;"`N/2`G/'1H/B<@+B!?*")(=6UI9&ET>2(I("X@
M)SPO=&@^/'1H/B<@+B!?*")7:6YD(BD@+B`G/"]T:#XG.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1H=&UL("X]("<\+W1R/B<["@H@("`@("`@("`@
M("!F;W)E86-H("@D9F]R96-A<W1;)V1A>7,G72!A<R`D=VAI8V@@/3X@)&1A
M>2D@>PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@)SQT<B!C;&%S<STB:71E
M;3`B/B<["@H@("`@("`@("`@("`@("`@+R\@1&%Y(&YA;64N"B`@("`@("`@
M("`@("`@("`D:'1M;"`N/2`G/'1D(')O=W-P86X](C(B('-T>6QE/2)B;W)D
M97(Z,7!X('-O;&ED("-D9&0[('1E>'0M86QI9VXZ8V5N=&5R(CXG("X*("`@
M("`@("`@("`@("`@("`@("`@("`@)SQS=')O;F<^)SL*("`@("`@("`@("`@
M("`@(&EF("@D=VAI8V@@/3T@,"D@>PH@("`@("`@("`@("`@("`@("`@("1H
M=&UL("X](%\H(E1O9&%Y(BD["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H
M)'=H:6-H(#T](#$I('L*("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2!?
M*")4;VUO<G)O=R(I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`D:'1M;"`N/2!S=')F=&EM92@G)4$G+"!M:W1I;64H
M,"P@,"P@,"P@9&%T92@G;2<I+"!D871E*"=D)RD@*R`D9G5T=7)E1&%Y<RP@
M9&%T92@G62<I*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D:'1M;"`N/2`G/"]S=')O;F<^/&)R("\^)R`N"B`@("`@("`@("`@("`@
M("`@("`@<W1R9G1I;64H)R5B("5D)RP@;6MT:6UE*#`L(#`L(#`L(&1A=&4H
M)VTG*2P@9&%T92@G9"<I("L@)&9U='5R941A>7,L(&1A=&4H)UDG*2DI("X*
M("`@("`@("`@("`@("`@("`@("`G/"]T9#XG("X*("`@("`@("`@("`@("`@
M("`@("`G/'1D('-T>6QE/2)B;W)D97(Z,7!X('-O;&ED("-D9&0[('1E>'0M
M86QI9VXZ8V5N=&5R(CXG("X*("`@("`@("`@("`@("`@("`@("`G/'-P86X@
M<W1Y;&4](F-O;&]R.F]R86YG92(^)R`N"B`@("`@("`@("`@("`@("`@("`@
M7R@B1&%Y(BD@+B`G/"]S<&%N/CPO=&0^)SL*"B`@("`@("`@("`@("`@("`O
M+R!4:&4@9&%Y('!O<G1I;VX@;V8@=&AE(&9O<F5C87-T(&ES(&YO(&QO;F=E
M<B!A=F%I;&%B;&4@869T97(@,CHP,"!P+FTN(&QO8V%L('1O9&%Y+@H@("`@
M("`@("`@("`@("`@:68@*"1W:&EC:"`]/2`P("8F("AS=')T;W1I;64H)&QO
M8V%T:6]N6R=T:6UE)UTI(#X]('-T<G1O=&EM92@G,30Z,#`G*2DI('L*("`@
M("`@("`@("`@("`@("`@("`O+R!"86QA;F-E('1H92!G<FED+@H@("`@("`@
M("`@("`@("`@("`@("1H=&UL("X]("<\=&0@8V]L<W!A;CTB)R`N"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`H*&ES<V5T*"1T:&ES+3Y?<&%R86US
M6R=D971A:6QE9$9O<F5C87-T)UTI(#\@)S4G(#H@)S,G*2`N("<B)RD@+@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)R!S='EL93TB8F]R9&5R.C%P
M>"!S;VQI9"`C9&1D.R!T97AT+6%L:6=N.F-E;G1E<B(^)R`N"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G)FYB<W`[/&)R("\^)R`N(%\H(DEN9F]R
M;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(BD@+B`G/&)R("\^)FYB<W`[
M)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G/"]T9#XG.PH@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`O+R!&
M;W)E8V%S="!C;VYD:71I;VXN"B`@("`@("`@("`@("`@("`@("`@)&-O;F1I
M=&EO;B`](&EM<&QO9&4H)R`O("<L(&%R<F%Y7VUA<"@G7R<L(&5X<&QO9&4H
M)R`O("<L("1D87E;)V1A>2==6R=C;VYD:71I;VXG72DI*3L*"B`@("`@("`@
M("`@("`@("`@("`@+R\@2&EG:"!T96UP97)A='5R92X*("`@("`@("`@("`@
M("`@("`@("`D:'1M;"`N/2`G/'1D('-T>6QE/2)B;W)D97(Z,7!X('-O;&ED
M("-D9&0[('1E>'0M86QI9VXZ8V5N=&5R(CXG("X*("`@("`@("`@("`@("`@
M("`@("`@("`@)SQS<&%N('-T>6QE/2)C;VQO<CIR960B/B<@+@H@("`@("`@
M("`@("`@("`@("`@("`@("!R;W5N9"@D9&%Y6R=T96UP97)A='5R94AI9V@G
M72D@+B`G/"]S<&%N/CPO=&0^)SL*"B`@("`@("`@("`@("`@("`@("`@+R\@
M0V]N9&ET:6]N+@H@("`@("`@("`@("`@("`@("`@("1H=&UL("X]("<\=&0@
M<W1Y;&4](F)O<F1E<CHQ<'@@<V]L:60@(V1D9#L@=&5X="UA;&EG;CIC96YT
M97(B/B<@+@H@("`@("`@("`@("`@("`@("`@("`@("!(;W)D93HZ:6UG*"=B
M;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+R<@+B`H)&1A>5LG9&%Y)UU;)V-O
M;F1I=&EO;DEC;VXG72`]/2`G+2<@/R`G;F$G(#H@)&1A>5LG9&%Y)UU;)V-O
M;F1I=&EO;DEC;VXG72D@+B`G+G!N9R<L("1C;VYD:71I;VXI("X*("`@("`@
M("`@("`@("`@("`@("`@("`@)SQB<B`O/B<@+B`D8V]N9&ET:6]N("X@)SPO
M=&0^)SL*"B`@("`@("`@("`@("`@("`@("`@+R\@4')E8VEP:71A=&EO;B!C
M:&%N8V4N"B`@("`@("`@("`@("`@("`@("`@)&AT;6P@+CT@)SQT9"!S='EL
M93TB8F]R9&5R.C%P>"!S;VQI9"`C9&1D.R!T97AT+6%L:6=N.F-E;G1E<B(^
M)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("1D87E;)V1A>2==6R=P<F5C
M:7!I=&%T:6]N)UT@+B`G)2<@+B`G/"]T9#XG.PH*("`@("`@("`@("`@("`@
M("`@("`O+R!)9B!A(&1E=&%I;&5D(&9O<F5C87-T('=A<R!R97%U97-T960L
M('-H;W<@:'5M:61I='D@86YD"B`@("`@("`@("`@("`@("`@("`@+R\@=VEN
M9',N"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%R
M86US6R=D971A:6QE9$9O<F5C87-T)UTI*2!["@H@("`@("`@("`@("`@("`@
M("`@("`@("`O+R!(=6UI9&ET>2X*("`@("`@("`@("`@("`@("`@("`@("`@
M)&AT;6P@+CT@)SQT9"!S='EL93TB8F]R9&5R.C%P>"!S;VQI9"`C9&1D.R!T
M97AT+6%L:6=N.F-E;G1E<B(^)R`N"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D9&%Y6R=D87DG75LG:'5M:61I='DG72`N("<E/"]T9#XG.PH*("`@
M("`@("`@("`@("`@("`@("`@("`@+R\@5VEN9',N"B`@("`@("`@("`@("`@
M("`@("`@("`@("1H=&UL("X]("<\=&0@<W1Y;&4](F)O<F1E<CHQ<'@@<V]L
M:60@(V1D9"(^)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!?*")&
M<F]M('1H92`B*2`N("1D87E;)V1A>2==6R=W:6YD1&ER96-T:6]N)UT@+@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@7R@B(&%T("(I("X@)&1A>5LG
M9&%Y)UU;)W=I;F0G72`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M("<@+B`D=6YI='-;)W=I;F0G73L*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1D87E;)V1A>2==6R=W:6YD1W5S="==*2`F)@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&1A>5LG9&%Y)UU;)W=I;F1'=7-T)UT@
M/B`P*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2!?
M*"(L(&=U<W1I;F<@(BD@+B`D9&%Y6R=D87DG75LG=VEN9$=U<W0G72`N"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R`G("X@)'5N:71S6R=W
M:6YD)UT["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`@("`@("`@("1H=&UL("X]("<\+W1R
M/B<["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@+R\@3FEG
M:'0@9F]R96-A<W0*("`@("`@("`@("`@("`@("1N:6=H="`](&EM<&QO9&4H
M)R`O("<L(&%R<F%Y7VUA<"@G7R<L(&5X<&QO9&4H)R`O("<L("1D87E;)VYI
M9VAT)UU;)V-O;F1I=&EO;B==*2DI.PH*("`@("`@("`@("`@("`@("\O(%-H
M861E(&ET(&9O<B!V:7-U86P@<V5P87)A=&EO;BX*("`@("`@("`@("`@("`@
M("1H=&UL("X]("<\='(@8VQA<W,](FET96TQ(CXG.PH*("`@("`@("`@("`@
M("`@("1H=&UL("X]("<\=&0@<W1Y;&4](F)O<F1E<CHQ<'@@<V]L:60@(V1D
M9#L@=&5X="UA;&EG;CIC96YT97(B/B<@+@H@("`@("`@("`@("`@("`@("`@
M(%\H(DYI9VAT(BD@+B`G/"]T9#XG.PH*("`@("`@("`@("`@("`@("\O($QO
M=R!T96UP97)A='5R92X*("`@("`@("`@("`@("`@("1H=&UL("X]("<\=&0@
M<W1Y;&4](F)O<F1E<CHQ<'@@<V]L:60@(V1D9#L@=&5X="UA;&EG;CIC96YT
M97(B/B<@+@H@("`@("`@("`@("`@("`@("`@("<\<W!A;B!S='EL93TB8V]L
M;W(Z8FQU92(^)R`N"B`@("`@("`@("`@("`@("`@("`@<F]U;F0H)&1A>5LG
M=&5M<&5R871U<F5,;W<G72D@+B`G/"]S<&%N/CPO=&0^)SL*"B`@("`@("`@
M("`@("`@("`O+R!#;VYD:71I;VXN"B`@("`@("`@("`@("`@("`D:'1M;"`N
M/2`G/'1D('-T>6QE/2)B;W)D97(Z,7!X('-O;&ED("-D9&0[('1E>'0M86QI
M9VXZ8V5N=&5R(CXG("X*("`@("`@("`@("`@("`@("`@("!(;W)D93HZ:6UG
M*"=B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+R<@+B`H)&1A>5LG;FEG:'0G
M75LG8V]N9&ET:6]N26-O;B==(#T]("<M)R`_("=N82<@.B`D9&%Y6R=N:6=H
M="==6R=C;VYD:71I;VY)8V]N)UTI("X@)RYP;F<G+"`D;FEG:'0I("X*("`@
M("`@("`@("`@("`@("`@("`G/&)R("\^)R`N("1N:6=H="`N("<\+W1D/B<[
M"@H@("`@("`@("`@("`@("`@+R\@4')E8VEP:71A=&EO;B!C:&%N8V4N"B`@
M("`@("`@("`@("`@("`D:'1M;"`N/2`G/'1D('-T>6QE/2)B;W)D97(Z,7!X
M('-O;&ED("-D9&0[('1E>'0M86QI9VXZ8V5N=&5R(CXG("X*("`@("`@("`@
M("`@("`@("`@("`D9&%Y6R=N:6=H="==6R=P<F5C:7!I=&%T:6]N)UT@+B`G
M)3PO=&0^)SL*"B`@("`@("`@("`@("`@("`O+R!)9B!A(&1E=&%I;&5D(&9O
M<F5C87-T('=A<R!R97%U97-T960L(&1I<W!L87D@:'5M:61I='D@86YD"B`@
M("`@("`@("`@("`@("`O+R!W:6YD<RX*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7W!A<F%M<ULG9&5T86EL961&;W)E8V%S="==*2D@>PH*
M("`@("`@("`@("`@("`@("`@("`O+R!(=6UI9&ET>2X*("`@("`@("`@("`@
M("`@("`@("`D:'1M;"`N/2`G/'1D('-T>6QE/2)B;W)D97(Z,7!X('-O;&ED
M("-D9&0[('1E>'0M86QI9VXZ8V5N=&5R(CXG("X*("`@("`@("`@("`@("`@
M("`@("`@("`@)&1A>5LG;FEG:'0G75LG:'5M:61I='DG72`N("<E/"]T9#XG
M.PH*("`@("`@("`@("`@("`@("`@("`O+R!7:6YD<RX*("`@("`@("`@("`@
M("`@("`@("`D:'1M;"`N/2`G/'1D('-T>6QE/2)B;W)D97(Z,7!X('-O;&ED
M("-D9&0B/B<@+@H@("`@("`@("`@("`@("`@("`@("`@("!?*")&<F]M('1H
M92`B*2`N("1D87E;)VYI9VAT)UU;)W=I;F1$:7)E8W1I;VXG72`N"B`@("`@
M("`@("`@("`@("`@("`@("`@(%\H(B!A="`B*2`N("1D87E;)VYI9VAT)UU;
M)W=I;F0G72`N"B`@("`@("`@("`@("`@("`@("`@("`@("<@)R`N("1U;FET
M<ULG=VEN9"==.PH@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&%Y
M6R=N:6=H="==6R=W:6YD1W5S="==*2`F)B`D9&%Y6R=N:6=H="==6R=W:6YD
M1W5S="==(#X@,"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D:'1M;"`N
M/2!?*"(L(&=U<W1I;F<@(BD@+B`D9&%Y6R=N:6=H="==6R=W:6YD1W5S="==
M("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("<@)R`N("1U;FET<ULG
M=VEN9"==.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("`D:'1M;"`N/2`G/"]T<CXG.PH*("`@("`@
M("`@("`@("`@("\O(%!R97!A<F4@9F]R(&YE>'0@9&%Y+@H@("`@("`@("`@
M("`@("`@)&9U='5R941A>7,K*SL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D:'1M;"`N/2`G/"]T86)L93XG.PH@("`@("`@('T*"B`@("`@("`@+R\@
M1&ES<&QA>2!A(&)A<B!A="!T:&4@8F]T=&]M(&]F('1H92!B;&]C:R!W:71H
M('1H92!R97%U:7)E9`H@("`@("`@("\O(&%T=')I8G5T:6]N('1O('=E871H
M97(N8V]M(&%N9"!T:&4@;&]G;RP@8F]T:"!L:6YK960@=&\*("`@("`@("`O
M+R!W96%T:&5R+F-O;2!W:71H('1H92!P87)T;F5R($E$+@H@("`@("`@(')E
M='5R;B`D:'1M;"`N("<\9&EV(&-L87-S/2)R:6=H=$%L:6=N(&QI;F5D4F]W
M(CXG("X*("`@("`@("`@("`@7R@B5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y
M(BD@+B`G("<@+@H@("`@("`@("`@("!(;W)D93HZ;&EN:RA(;W)D93HZ97AT
M97)N86Q5<FPH)VAT='`Z+R]W=W<N=V5A=&AE<BYC;VTO/W!R;V0]>&]A<"9A
M;7`[<&%R/2<@+@H@("`@("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1O
M=$-O;2T^7W!A<G1N97))1"DL"B`@("`@("`@("`@("`@("`@("`@("`@("=W
M96%T:&5R+F-O;2<L("<G+"`G7V)L86YK)RP@)R<L("=W96%T:&5R+F-O;2<I
M("X*("`@("`@("`@("`@)SQE;3YW96%T:&5R+F-O;3PO96T^)G)E9SL@)R`N
M"B`@("`@("`@("`@($AO<F1E.CII;6<H)V)L;V-K+W=E871H97)D;W1C;VTO
M,S)X,S(O5%=#;&]G;U\S,G!X+G!N9R<L("=W96%T:&5R+F-O;2!L;V=O)RD@
M+@H@("`@("`@("`@("`G/"]A/CPO9&EV/B<["B`@("!]"@I]"@``````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B]";&]C:R]A8V-O=6YT+G!H<```````````````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`T,S<Q-2`Q,#4Q-30S,S<S-2`P
M,C$U,C``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*"B1B;&]C:U]N86UE(#T@7R@B06-C;W5N="!);F9O<FUA=&EO
M;B(I.PH*+RHJ"B`J("1(;W)D93H@:&]R9&4O;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP+'8@,2XW+C(N-"`R,#`V+S`S+S$P(#$W.C(X.C0T(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P,2TR,#`V($5R:6,@4F]S=&5T=&5R(#QE<FEC
M+G)O<W1E='1E<D!P:'ES:6-S+G5T97AA<RYE9'4^"B`J($-O<'ER:6=H="`R
M,#`U+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!S:6YC92`@($AO<F1E(#,N,0H@*B!`<&%C:V%G92!(
M;W)D95]";&]C:PH@*B\*8VQA<W,@2&]R9&5?0FQO8VM?2&]R9&5?86-C;W5N
M="!E>'1E;F1S($AO<F1E7T)L;V-K('L*"B`@("!V87(@)%]A<'`@/2`G:&]R
M9&4G.PH*("`@("\J*@H@("`@("H@5&AE('1I=&QE('1O(&=O(&EN('1H:7,@
M8FQO8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@("!4:&4@=&ET
M;&4@=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@7W1I=&QE*"D*("`@('L*
M("`@("`@("!R971U<FX@7R@B37D@06-C;W5N="!);F9O<FUA=&EO;B(I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@5&AE(&-O;G1E;G0@=&\@9V\@:6X@=&AI
M<R!B;&]C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@(%1H92!C
M;VYT96YT"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYT96YT*"D*("`@('L*
M("`@("`@("!G;&]B86P@)')E9VES=')Y+"`D8V]N9CL*"B`@("`@("`@<W=I
M=&-H("@D8V]N9ELG86-C;W5N=',G75LG9')I=F5R)UTI('L*("`@("`@("!C
M87-E("=N=6QL)SH*("`@("`@("`@("`@)&UY9')I=F5R(#T@)FYE=R!!8V-O
M=6YT<U]$<FEV97(H*3L*("`@("`@("`@("`@8G)E86L["B`@("`@("`@8V%S
M92`G;&]C86QH;W-T)SH*("`@("`@("!C87-E("=L9&%P)SH*("`@("`@("`@
M("`@)&-L87-S(#T@)T%C8V]U;G1S7T1R:79E<E\G("X@)&-O;F9;)V%C8V]U
M;G1S)UU;)V1R:79E<B==.PH@("`@("`@("`@("`D;7ED<FEV97(@/2`F;F5W
M("1C;&%S<R@D8V]N9ELG86-C;W5N=',G75LG<&%R86US)UTI.PH@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("!R971U
M<FX@)R<["B`@("`@("`@?0H*("`@("`@("`O+R!#:&5C:R!F;W(@<&%S<W=O
M<F0@<W1A='5S+@H@("`@("`@(&EF("AI<U]A*"1S=&%T=7,@/2`D;7ED<FEV
M97(M/F-H96-K4&%S<W=O<F13=&%T=7,H*2P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("`D<W1A='5S(#T@)'-T871U<RT^9V5T365S<V%G92@I.PH@
M("`@("`@('T*"B`@("`@("`@:68@*&ES7V$H)'5S97)N86UE(#T@)&UY9')I
M=F5R+3YG9715<V5R;F%M92@I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D=7-E<FYA;64M/F=E=$UE<W-A9V4H*3L*("`@("`@("!]
M"B`@("`@("`@)'1A8FQE(#T@87)R87DH7R@B3&]G:6XB*2`]/B`D=7-E<FYA
M;64I.PH@("`@("`@(&EF("AI<U]A*"1F=6QL;F%M92`]("1M>61R:79E<BT^
M9V5T1G5L;&YA;64H*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)&9U;&QN86UE+3YG971-97-S86=E*"D["B`@("`@("`@?2!E;'-E
M:68@*"1F=6QL;F%M92D@>PH@("`@("`@("`@("`D=&%B;&5;7R@B1G5L;"!.
M86UE(BE=(#T@)&9U;&QN86UE.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?
M82@D:&]M92`]("1M>61R:79E<BT^9V5T2&]M92@I+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D:&]M92T^9V5T365S<V%G92@I.PH@
M("`@("`@('T@96QS96EF("@D:&]M92D@>PH@("`@("`@("`@("`D=&%B;&5;
M7R@B2&]M92!$:7)E8W1O<GDB*5T@/2`D:&]M93L*("`@("`@("!]"B`@("`@
M("`@:68@*&ES7V$H)'-H96QL(#T@)&UY9')I=F5R+3YG9713:&5L;"@I+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<VAE;&PM/F=E
M=$UE<W-A9V4H*3L*("`@("`@("!](&5L<V5I9B`H)'-H96QL*2!["B`@("`@
M("`@("`@("1T86)L95M?*")$969A=6QT(%-H96QL(BE=(#T@)'-H96QL.PH@
M("`@("`@('T*("`@("`@("!I9B`H:7-?82@D<75O=&$@/2`D;7ED<FEV97(M
M/F=E=%%U;W1A*"DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1Q=6]T82T^9V5T365S<V%G92@I.PH@("`@("`@('T@96QS96EF("@D
M<75O=&$I('L*("`@("`@("`@("`@)'1A8FQE6U\H(E%U;W1A(BE=(#T@<W!R
M:6YT9BA?*"(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E
M*2(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1Q=6]T85LG=7-E9"==("\@*"`Q,#(T("H@,3`R-"XP*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<75O=&%;)VQI;6ET
M)UT@+R`H(#$P,C0@*B`Q,#(T+C`I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("@D<75O=&%;)W5S960G72`J(#$P,"XP*2`O
M("1Q=6]T85LG;&EM:70G72D["B`@("`@("`@?0H@("`@("`@(&EF("AI<U]A
M*"1L87-T8VAA;F=E(#T@)&UY9')I=F5R+3YG971087-S=V]R9$-H86YG92@I
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D;&%S=&-H
M86YG92T^9V5T365S<V%G92@I.PH@("`@("`@('T@96QS96EF("@D;&%S=&-H
M86YG92D@>PH@("`@("`@("`@("`D=&%B;&5;7R@B3&%S="!087-S=V]R9"!#
M:&%N9V4B*5T@/2`D;&%S=&-H86YG93L*("`@("`@("!]"@H@("`@("`@("1O
M=71P=70@/2`G/'1A8FQE(&-L87-S/2)I=&5M(B!W:61T:#TB,3`P)2(@8V5L
M;'-P86-I;F<](C$B/B<["@H@("`@("`@(&EF("@A96UP='DH)'-T871U<RDI
M('L*("`@("`@("`@("`@)&]U='!U="`N/2`G/'1R/CQT9"!C;VQS<&%N/2(R
M(CX\<"!C;&%S<STB;F]T:6-E(CXG("X*("`@("`@("`@("`@("`@($AO<F1E
M.CII;6<H)V%L97)T<R]W87)N:6YG+G!N9R<L(%\H(E=A<FYI;F<B*2D@+@H@
M("`@("`@("`@("`@("`@)R9N8G-P.R9N8G-P.R<@+B`D<W1A='5S("X@)SPO
M<#X\+W1D/CPO='(^)SL*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1T
M86)L92!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("`D;W5T<'5T
M("X]("(\='(@8VQA<W,]7")T97AT7"(^/'1D/B1K97D\+W1D/CQT9#XD=F%L
M=64\+W1D/CPO='(^7&XB.PH@("`@("`@('T*("`@("`@("`D;W5T<'5T("X]
M("(\+W1A8FQE/EQN(CL*"B`@("`@("`@:68@*"1R96=I<W1R>2T^9V5T*"=S
M=&%T=7,G+"`G9F]R=V%R9',G*2`A/2`G:6YA8W1I=F4G("8F"B`@("`@("`@
M("`@("1R96=I<W1R>2T^:&%S365T:&]D*"=S=6UM87)Y)RP@)V9O<G=A<F1S
M)RDI('L*("`@("`@("`@("`@)'-U;6UA<GD@/2`D<F5G:7-T<GDM/F-A;&Q"
M>5!A8VMA9V4H)V9O<G=A<F1S)RP@)W-U;6UA<GDG*3L*("`@("`@("`@("`@
M:68@*"%I<U]A*"1S=6UM87)Y+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("`@("`D;W5T<'5T("X]("<\8G(@+SXG("X@)'-U;6UA<GD@+B`B7&XB
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@D<F5G:7-T
M<GDM/F=E="@G<W1A='5S)RP@)W9A8V%T:6]N)RD@(3T@)VEN86-T:79E)R`F
M)@H@("`@("`@("`@("`D<F5G:7-T<GDM/FAA<TUE=&AO9"@G<W5M;6%R>2<L
M("=V86-A=&EO;B<I*2!["B`@("`@("`@("`@("1S=6UM87)Y(#T@)')E9VES
M=')Y+3YC86QL0GE086-K86=E*"=V86-A=&EO;B<L("=S=6UM87)Y)RD["B`@
M("`@("`@("`@(&EF("@A:7-?82@D<W5M;6%R>2P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("`@("`@)&]U='!U="`N/2`G/&)R("\^)R`N("1S=6UM
M87)Y("X@(EQN(CL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1O=71P=70["B`@("!]"@I]"@HO*BH*("H@06-C;W5N='-?1')I
M=F5R.CH@9&5F:6YE<R!A;B!!4$D@9F]R(&=E='1I;F<O9&ES<&QA>6EN9R!A
M8V-O=6YT(&EN9F]R;6%T:6]N"B`J(&9O<B!A('5S97(@9F]R('1H92!A8V-O
M=6YT<R!M;V1U;&4N"B`J"B`J($-O<'ER:6=H="`R,#`Q+3(P,#8@17)I8R!2
M;W-T971T97(@/&5R:6,N<F]S=&5T=&5R0'!H>7-I8W,N=71E>&%S+F5D=3X*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($5R:6,@4F]S=&5T=&5R(#QE
M<FEC+G)O<W1E='1E<D!P:'ES:6-S+G5T97AA<RYE9'4^"B`J($!S:6YC92`@
M($AO<F1E(#,N,0H@*B!`<&%C:V%G92!(;W)D95]";&]C:PH@*B\*8VQA<W,@
M06-C;W5N='-?1')I=F5R('L*"B`@("`O*BH*("`@("`J($5R<F]R('-T<FEN
M9R!R971U<FYE9"!T;R!U<V5R(&EF(&%N(&5R<F]R(&]C8W5R<RX*("`@("`J
M"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)&5R<E]S='([
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!U<V5R;F%M92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&QO=V5R8V%S960@=7-E<FYA
M;64N"B`@("`@*@H@("`@("HO"B`@("!F=6YC=&EO;B!G9715<V5R;F%M92@I
M"B`@("!["B`@("`@("`@)&%U=&@@/2!E>'!L;V1E*"=`)RP@075T:#HZ9V5T
M075T:"@I*3L*("`@("`@("!R971U<FX@4W1R:6YG.CIL;W=E<B@D875T:%LP
M72D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!U<V5R(')E
M86QM+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=7-E<B!R
M96%L;2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4F5A;&TH*0H@("`@>PH@
M("`@("`@("1A=71H(#T@97AP;&]D92@G0"<L($%U=&@Z.F=E=$%U=&@H*2D[
M"B`@("`@("`@<F5T=7)N(&ES<V5T*"1A=71H6S%=*2`_("1A=71H6S%=(#H@
M)R<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!U<V5R)W,@
M<75O=&$@:68@879A:6QA8FQE+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@($$@<75O=&$@87)R87DL(&5L96UE;G1S(&%R92!U<V5D(&)Y=&5S(&%N
M9"!L:6UI="!B>71E<R!O;@H@("`@("H@("`@("`@("`@("`@("`@<W5C8V5S
M<RP@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M475O=&$H*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@=&AE('5S97(G<R!F=6QL(&YA;64N"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE('5S97(G<R!F=6QL(&YA
M;64@*'-T<FEN9RDL(&]R(&9A;'-E("AE<G)O<BDN"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=$9U;&QN86UE*"D*("`@('L*("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!U<V5R)W,@
M:&]M92`H;&]G:6XI(&1I<F5C=&]R>2X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!4:&4@=7-E<B=S(&1I<F5C=&]R>2`H<W1R:6YG*2P@;W(@9F%L
M<V4@*&5R<F]R*2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T2&]M92@I"B`@
M("!["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@=7-E<B=S(&1E9F%U;'0@<VAE;&PN"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@5&AE('5S97(G<R!S:&5L;"`H<W1R:6YG
M*2P@;W(@9F%L<V4@*&5R<F]R*2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M4VAE;&PH*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&1A=&4@;V8@=&AE('5S97(G<R!L
M87-T('!A<W-W;W)D(&-H86YG92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("!$871E('-T<FEN9R`H<W1R:6YG*2!O<B!F86QS92`H97)R;W(I+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971087-S=V]R9$-H86YG92@I"B`@("![
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!T:&4@<W1A='5S(&]F('1H92!C=7)R96YT('!A<W-W;W)D+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@($$@<W1R:6YG('=I=&@@82!W
M87)N:6YG(&UE<W-A9V4@:68@=&AE('!A<W-W;W)D(&ES(&%B;W5T"B`@("`@
M*B`@("`@("`@("`@("`@("!T;R!E>'!I<F4L(%!%05)?17)R;W(@;VX@97)R
M;W(@86YD(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M8VAE8VM087-S=V]R9%-T871U<R@I"B`@("!["B`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@?0H*?0H*+RHJ"B`J($EM<&QE;65N=',@=&AE($%C8V]U;G1S
M($%022!F;W(@<V5R=F5R<R!W:71H('5N:7@@86-C;W5N=',@;VX@=&AE(&QO
M8V%L:&]S=`H@*B!M86-H:6YE("AS86UE(&UA8VAI;F4@87,@=&AE('=E8B!S
M97)V97(I+B`@4VAO=6QD('=O<FL@9F]R(&QO8V%L('5N:7@*("H@86-C;W5N
M=',L(&YI<R]N:7,K(&%C8V]U;G1S+"!O<B!A;GD@4$%-(&]R:65N=&5D(&%C
M8V]U;G1S('1H870@87!P96%R(&%S"B`J(&QO8V%L(&%C8V]U;G1S(&]N('1H
M92!L;V-A;"!M86-H:6YE+B`@5&AE(&5X8V5P=&EO;B!I<R!T:&4@<75O=&$@
M<W5P<&]R="X*("H@4V5E('1H870@<F]U=&EN92!F;W(@861D:71I;VYA;"!C
M;VUM96YT<RX*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!%<FEC($IO;B!2
M;W-T971T97(@/&5R:6,N<F]S=&5T=&5R0'!H>7-I8W,N=71E>&%S+F5D=3X*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($5R:6,@4F]S=&5T=&5R(#QE
M<FEC+G)O<W1T=&5R0'!H>7-I8W,N=71E>&%S+F5D=3X*("H@0'-I;F-E("`@
M2&]R9&4@,RXQ"B`J($!P86-K86=E($AO<F1E7T)L;V-K"B`J+PIC;&%S<R!!
M8V-O=6YT<U]$<FEV97)?;&]C86QH;W-T(&5X=&5N9',@06-C;W5N='-?1')I
M=F5R('L*"B`@("`O*BH*("`@("`J($AA<V@@8V]N=&%I;FEN9R!C;VYN96-T
M:6]N('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)'!A<F%M<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@
M*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A
M<F%M<R`@2&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@06-C;W5N='-?1')I=F5R7VQO8V%L:&]S
M="@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^<&%R
M86US(#T@)'!A<F%M<SL*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YP87)A
M;7-;)W%U;W1A7W!A=&@G72DI('L*("`@("`@("`@("`@)'1H:7,M/G!A<F%M
M<ULG<75O=&%?<&%T:"==(#T@)W%U;W1A)SL*("`@("`@("!]"B`@("`@("`@
M:68@*"%I<W-E="@D=&AI<RT^<&%R86US6R=G<F5P7W!A=&@G72DI('L*("`@
M("`@("`@("`@)'1H:7,M/G!A<F%M<ULG9W)E<%]P871H)UT@/2`G9W)E<"<[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M=7-E<B!A8V-O=6YT(&9R;VT@=&AE('!O<VEX(&EN9F]R;6%T:6]N+@H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@($$@:&%S:"!W:71H(&-O;7!L971E
M(&%C8V]U;G0@9&5T86EL<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$%C
M8V]U;G0H*0H@("`@>PH@("`@("`@('-T871I8R`D:6YF;W)M871I;VX["@H@
M("`@("`@(&EF("@A:7-S970H)&EN9F]R;6%T:6]N*2D@>PH@("`@("`@("`@
M("`O+R!T:&ES('=O;B=T('=O<FL@:68@=V4@9&]N)W0@:&%V92!P;W-I>"!E
M>'1E;G-I;VYS"B`@("`@("`@("`@(&EF("@A571I;#HZ97AT96YS:6]N17AI
M<W1S*"=P;W-I>"<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BA?*")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9R(I*3L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'5S97(@/2!3=')I;F<Z.FQO
M=V5R*"1T:&ES+3YG9715<V5R;F%M92@I*3L*("`@("`@("`@("`@)&EN9F]R
M;6%T:6]N(#T@<&]S:7A?9V5T<'=N86TH)'5S97(I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1I;F9O<FUA=&EO;CL*("`@('T*"B`@("`O*BH*("`@
M("`J($EM<&QE;65N="!T:&4@475O=&$@05!)(&9O<B!)34%0('-E<G9E<G,@
M=VET:"!A('5N:7@@<75O=&$@8V]M;6%N9"X*("`@("`J(%1H:7,@;6%Y(')E
M<75I<F4@82!M;V1I9FEE9"`B<75O=&$B(&-O;6UA;F0@=&AA="!A;&QO=W,@
M=&AE(&AT='!D"B`@("`@*B!S97)V97(@86-C;W5N="!T;R!G970@<75O=&%S
M(&9O<B!O=&AE<B!U<V5R<RXN+B`@270@<F5Q=6ER97,@=&AA="!Y;W5R"B`@
M("`@*B!W96(@<V5R=F5R(&%N9"!U<V5R('-E<G9E<B!B92!T:&4@<V%M92!S
M97)V97(@;W(@870@;&5A<W0@:&%V92!S:&%R960*("`@("`J(&%U=&AE;G1I
M8V%T:6]N(&%N9"!F:6QE('-E<G9E<G,@*&4N9RX@=FEA($Y)4R].1E,I+B`@
M06YD(&QA<W0L(&ET("AA<PH@("`@("H@=W)I='1E;BD@<F5Q=6ER97,@=&AE
M('!O<VEX('!H<"!E>'1E;G-I;VYS+@H@("`@("H*("`@("`J($EF('EO=7(@
M<75O=&$@8V]M;6%N9"!W<F%P<R!T:&4@;W5T<'5T(&]N=&\@='=O(&QI;F5S
M+"!T:&5N('1H:7,@;6]D=6QE"B`@("`@*B!W:6QL(&]N;'D@=V]R:R!I9B!Y
M;W4@:&%V92!A(&=R97`@=VAI8V@@<W5P<&]R=',@=&AE("U!('-W:71C:"P@
M86YD('EO=0H@("`@("H@87!P96YD(&%N("U!,2!S=VET8V@@=&\@>6]U<B!G
M<F5P7W!A=&@@*&4N9RX@)R]B:6XO9W)E<"`M03$G*2X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!4:&4@<75O=&$@:&%S:"`H8GET97,@=7-E9"P@
M;&EM:70I(&]R(&9A;'-E(&9O<B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T475O=&$H*0H@("`@>PH@("`@("`@("1I;F9O<FUA=&EO;B`]("1T
M:&ES+3Y?9V5T06-C;W5N="@I.PH@("`@("`@(&EF("AI<U]A*"1I;F9O<FUA
M=&EO;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&EN
M9F]R;6%T:6]N.PH@("`@("`@('T*"B`@("`@("`@)&AO;65D:7(@/2`D:6YF
M;W)M871I;VY;)V1I<B==.PH*("`@("`@("`O+R!)9B!W92!W86YT(&UO=6YT
M('!O:6YT('1R86YS;&%T:6]N<RP@=&AE;B!T<F%N<VQA=&4@=&AE(&QO9VEN
M(&1I<@H@("`@("`@("\O(&YA;64@=&\@82!M;W5N="!P;VEN="X@($EF(&YO
M="P@=&AE;B!S:6UP;'D@<&%R<V4@;W5T('1H92!D979I8V4*("`@("`@("`O
M+R!N86UE(&9R;VT@=&AE(&QO9VEN(&1I<F5C=&]R>2P@86YD('5S92!T:&%T
M(&EN<W1E860N"B`@("`@("`@:68@*"1T:&ES+3YP87)A;7-;)W1R86YS;&%T
M94UO=6YT4&]I;G0G72`F)@H@("`@("`@("`@("!F:6QE7V5X:7-T<R@D=&AI
M<RT^<&%R86US6R=T<F%N<VQA=&EO;E1A8FQE)UTI*0H@("`@("`@('L*("`@
M("`@("`@("`@<F5Q=6ER95]O;F-E("=&:6QE+T9S=&%B+G!H<"<["B`@("`@
M("`@("`@("1S>7-486(@/2!&:6QE7T9S=&%B.CIS:6YG;&5T;VXH)'1H:7,M
M/G!A<F%M<ULG=')A;G-L871I;VY486)L92==*3L*("`@("`@("`@("`@9&\@
M>PH@("`@("`@("`@("`@("`D96YT<GD@/2`F)'-Y<U1A8BT^9V5T16YT<GE&
M;W)0871H*"1H;VUE9&ER*3L*("`@("`@("`@("`@("`@)&AO;65D:7(@/2!D
M:7)N86UE*"1H;VUE9&ER*3L*("`@("`@("`@("`@("`@:68@*"1H;VUE9&ER
M(#T]("<N)R!\?"!E;7!T>2@D:&]M961I<BDI('L*("`@("`@("`@("`@("`@
M("`@("1H;VUE9&ER(#T@)R\G.PH@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T@=VAI;&4@*&ES7V$H)&5N=')Y+"`G4$5!4E]%<G)O<B<I*3L*("`@
M("`@("`@("`@)&UO=6YT4&]I;G0@/2`D96YT<GDM/F1E=FEC93L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("1H;VUE9&ER(#T@97AP;&]D92@G+R<L
M("1H;VUE9&ER*3L*("`@("`@("`@("`D;6]U;G10;VEN="`]("<O)R`N("1H
M;VUE9&ER6S%=.PH@("`@("`@('T*"B`@("`@("`@)&-M9&QI;F4@/2!S<')I
M;G1F*"<E<R`M=2`E<R`R/B8Q('P@)7,@)7,G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^<&%R86US6R=Q=6]T85]P871H)UTL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YG9715<V5R3F%M92@I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<&%R86US6R=G<F5P
M7W!A=&@G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@)&UO=6YT4&]I
M;G0I.PH@("`@("`@("1J=6YK(#T@97AE8R@D8VUD;&EN92P@)'%U;W1A7V1A
M=&$L("1R971U<FY?8V]D92D["B`@("`@("`@:68@*"1R971U<FY?8V]D92`]
M/2`P("8F("%E;7!T>2@D<75O=&%?9&%T85LP72DI('L*("`@("`@("`@("`O
M+R!);B!C87-E(&]F('%U;W1A(&]U='!U="!W<F%P<&EN9R!O;B!T=V\@;&EN
M97,L('=E(&-O;F-A="!T:&4*("`@("`@("`@("`O+R!S96-O;F0@;&EN92!O
M9B!R97-U;'1S+"!I9B!A;GDL(&AE<F4N"B`@("`@("`@("`@:68@*"%E;7!T
M>2@D<75O=&%?9&%T85LQ72DI('L*("`@("`@("`@("`@("`@)'%U;W1A7V1A
M=&%;,%T@+CT@)'%U;W1A7V1A=&%;,5T["B`@("`@("`@("`@?0H@("`@("`@
M("`@("\O($YO=R!P87)S92!O=70@=&AE('%U;W1A(&EN9F\@86YD(')E='5R
M;B!I="X*("`@("`@("`@("`D<75O=&$@/2!P<F5G7W-P;&ET*"<O7',K+R<L
M('1R:6TH)'%U;W1A7V1A=&%;,%TI*3L*("`@("`@("`@("!R971U<FX@87)R
M87DH)W5S960G(#T^("1Q=6]T85LQ72`J(#$P,C0L("=L:6UI="<@/3X@)'%U
M;W1A6S)=("H@,3`R-"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B!F86QS
M93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('5S97(G<R!F
M=6QL(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE('5S
M97(G<R!F=6QL(&YA;64@*'-T<FEN9RDL(&]R(&9A;'-E("AE<G)O<BDN"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$9U;&QN86UE*"D*("`@('L*("`@("`@
M("`D:6YF;W)M871I;VX@/2`D=&AI<RT^7V=E=$%C8V]U;G0H*3L*("`@("`@
M("!I9B`H:7-?82@D:6YF;W)M871I;VXL("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1I;F9O<FUA=&EO;CL*("`@("`@("!]"B`@("`@
M("`@)&=E8V]S7V%R<F%Y(#T@97AP;&]D92@G+"<L("1I;F9O<FUA=&EO;ELG
M9V5C;W,G72D["B`@("`@("`@<F5T=7)N("1G96-O<U]A<G)A>5LP73L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('5S97(G<R!H;VUE("AL
M;V=I;BD@9&ER96-T;W)Y+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1H92!U<V5R)W,@9&ER96-T;W)Y("AS=')I;F<I+"!O<B!F86QS92`H97)R
M;W(I+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971(;VUE*"D*("`@('L*("`@
M("`@("`D:6YF;W)M871I;VX@/2`D=&AI<RT^7V=E=$%C8V]U;G0H*3L*("`@
M("`@("!I9B`H:7-?82@D:6YF;W)M871I;VXL("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1I;F9O<FUA=&EO;CL*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N("1I;F9O<FUA=&EO;ELG9&ER)UT["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('1H92!U<V5R)W,@9&5F875L="!S:&5L;"X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@=7-E<B=S('-H96QL
M("AS=')I;F<I+"!O<B!F86QS92`H97)R;W(I+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G9713:&5L;"@I"B`@("!["B`@("`@("`@)&EN9F]R;6%T:6]N(#T@
M)'1H:7,M/E]G971!8V-O=6YT*"D["B`@("`@("`@:68@*&ES7V$H)&EN9F]R
M;6%T:6]N+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M:6YF;W)M871I;VX["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D:6YF;W)M
M871I;VY;)W-H96QL)UT["B`@("!]"@I]"@HO*BH*("H@5&AE(&QD87`@8VQA
M<W,@871T96UP=',@=&\@<F5T=7)N('5S97(@:6YF;W)M871I;VX@<W1O<F5D
M(&EN(&%N(&QD87`*("H@9&ER96-T;W)Y('-E<G9I8V4N"B`J"B`J($-O<'ER
M:6=H="`R,#`Q+3(P,#8@17)I8R!2;W-T971T97(@/&5R:6,N<F]S=&5T=&5R
M0'!H>7-I8W,N=71E>&%S+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($5R:6,@2F]N(%)O<W1E='1E<B`\97)I8RYR;W-T971T97)`<&AY<VEC
M<RYU=&5X87,N961U/@H@*B!`<VEN8V4@("!(;W)D92`S+C$*("H@0'!A8VMA
M9V4@2&]R9&5?0FQO8VL*("HO"F-L87-S($%C8V]U;G1S7T1R:79E<E]L9&%P
M(&5X=&5N9',@06-C;W5N='-?1')I=F5R('L*"B`@("`O*BH*("`@("`J(%!O
M:6YT97(@=&\@=&AE(&QD87`@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@*B!`
M=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D7V1S.PH*("`@("\J*@H@
M("`@("H@2&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*
M("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A
M<F%M<SL*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!N97<@06-C;W5N
M='-?1')I=F5R7VQD87`@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N('!A
M<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N($%C8V]U;G1S7T1R:79E
M<E]L9&%P*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?<&%R86US(#T@87)R87E?;65R9V4H"B`@("`@("`@("`@(&%R<F%Y*"=H
M;W-T)R`]/B`G;&]C86QH;W-T)RP*("`@("`@("`@("`@("`@("`@)W!O<G0G
M(#T^(#,X.2P*("`@("`@("`@("`@("`@("`@)V)A<V5D;B<@/3X@)R<L"B`@
M("`@("`@("`@("`@("`@("=A='1R)R`]/B`G=6ED)RP*("`@("`@("`@("`@
M("`@("`@)W9E<G-I;VXG(#T^("<S)RDL"B`@("`@("`@("`@("1P87)A;7,I
M.PH@("`@?0H*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('5S97(@86-C
M;W5N="!F<F]M('1H92!L9&%P('-O=7)C92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("!!(&AA<V@@=VET:"!C;VUP;&5T92!A8V-O=6YT(&1E=&%I
M;',N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971!8V-O=6YT*"D*("`@('L*
M("`@("`@("!S=&%T:6,@)&EN9F]R;6%T:6]N.PH*("`@("`@("!I9B`H(6ES
M<V5T*"1I;F9O<FUA=&EO;BDI('L*("`@("`@("`@("`@)'5S97)N86UE("`]
M("1T:&ES+3YG9715<V5R;F%M92@I.PH*("`@("`@("`@("`@+R\@8V]N;F5C
M="!T;R!T:&4@;&1A<"!S97)V97(*("`@("`@("`@("`@)'1H:7,M/E]D<R`]
M(&QD87!?8V]N;F5C="@D=&AI<RT^7W!A<F%M<ULG:&]S="==+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=P;W)T)UTI.PH@("`@("`@("`@("!I9B`H(21T:&ES+3Y?9',I('L*("`@
M("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-O=6QD
M(&YO="!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(I*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P87)A;7-;)W9E<G-I
M;VXG72DI('L*("`@("`@("`@("`@("`@(&EF("@A;&1A<%]S971?;W!T:6]N
M*"1T:&ES+3Y?9',L($Q$05!?3U!47U!23U1/0T],7U9%4E-)3TXL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M
M<ULG=F5R<VEO;B==*2D@>PH@("`@("`@("`@("`@("`@("`@($AO<F1E.CIL
M;V=-97-S86=E*'-P<FEN=&8H)U-E="!,1$%0('!R;W1O8V]L('9E<G-I;VX@
M=&\@)60@9F%I;&5D.B!;)61=("5S)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=V97)S
M:6]N)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!L9&%P7V5R<FYO*"1C;VYN*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&QD87!?97)R;W(H)&-O;FXI
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("\O(&)I;F0@87,@86YO;GEM;W5S
M"B`@("`@("`@("`@("1R97-U;'0@/2!`;&1A<%]B:6YD*"1T:&ES+3Y?9',I
M.PH@("`@("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-O=6QD(&YO="!B:6YD('1O
M($Q$05`@<V5R=F5R+B(I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M+R\@1V5T('1H92!F=6QL;F%M90H@("`@("`@("`@("`D<V5A<F-H4F5S=6QT
M(#T@;&1A<%]S96%R8V@H)'1H:7,M/E]D<RP@)'1H:7,M/E]P87)A;7-;)V)A
M<V5D;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P87)A;7-;)V%T='(G72`N("<])R`N("1U<V5R;F%M92D[
M"B`@("`@("`@("`@("1I;F9O<FUA=&EO;B`](&QD87!?9V5T7V5N=')I97,H
M)'1H:7,M/E]D<RP@)'-E87)C:%)E<W5L="D["@H@("`@("`@("`@("`O+R!D
M:7-C;VYN96-T(&9R;VT@=&AE(&QD87`@<V5R=F5R"B`@("`@("`@("`@($!L
M9&%P7V-L;W-E*"1T:&ES+3Y?9',I.PH*("`@("`@("`@("`@:68@*"1I;F9O
M<FUA=&EO;ELG8V]U;G0G72`]/2`P*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD
M(BDI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&EN9F]R;6%T:6]N.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&4@=7-E<B=S(&9U;&P@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("!4:&4@=7-E<B=S(&9U;&P@;F%M92`H<W1R:6YG*2P@;W(@9F%L<V4@
M*&5R<F]R*2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1G5L;&YA;64H*0H@
M("`@>PH@("`@("`@("1I;F9O<FUA=&EO;B`]("1T:&ES+3Y?9V5T06-C;W5N
M="@I.PH@("`@("`@(&EF("AI<U]A*"1I;F9O<FUA=&EO;BP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&EN9F]R;6%T:6]N.PH@("`@
M("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1I;F9O<FUA=&EO;ELP75LG8VX[
M;&%N9RUE<R==6S!=*2`F)@H@("`@("`@("`@("`D:6YF;W)M871I;VY;,%U;
M)V-N.VQA;F<M97,G75LP72`A/2`G)RD@>PH@("`@("`@("`@("`D;F%M92`]
M("1I;F9O<FUA=&EO;ELP75LG8VX[;&%N9RUE<R==6S!=.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1N86UE(#T@)&EN9F]R;6%T:6]N6S!=6R=C
M;B==6S!=.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("AE;7!T>2@D;F%M
M92D@/R!F86QS92`Z("1N86UE*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE('5S97(G<R!H;VUE("AL;V=I;BD@9&ER96-T;W)Y+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!U<V5R)W,@9&ER96-T;W)Y
M("AS=')I;F<I+"!O<B!F86QS92`H97)R;W(I+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971(;VUE*"D*("`@('L*("`@("`@("`D:6YF;W)M871I;VX@/2`D
M=&AI<RT^7V=E=$%C8V]U;G0H*3L*("`@("`@("!I9B`H:7-?82@D:6YF;W)M
M871I;VXL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1I
M;F9O<FUA=&EO;CL*("`@("`@("!]"B`@("`@("`@)&AO;65D:7(@/2`D:6YF
M;W)M871I;VY;,%U;)VAO;65D:7)E8W1O<GDG75LP73L*("`@("`@("!R971U
M<FX@*&5M<'1Y*"1H;VUE9&ER*2`_(&9A;'-E(#H@)&AO;65D:7(I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@=7-E<B=S(&1E9F%U;'0@
M<VAE;&PN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE('5S97(G
M<R!S:&5L;"`H<W1R:6YG*2P@;W(@9F%L<V4@*&5R<F]R*2X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T4VAE;&PH*0H@("`@>PH@("`@("`@("1I;F9O<FUA
M=&EO;B`]("1T:&ES+3Y?9V5T06-C;W5N="@I.PH@("`@("`@(&EF("AI<U]A
M*"1I;F9O<FUA=&EO;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)&EN9F]R;6%T:6]N.PH@("`@("`@('T*("`@("`@("`D<VAE;&P@
M/2`D:6YF;W)M871I;VY;,%U;)VQO9VEN<VAE;&PG75LP73L*("`@("`@("!R
M971U<FX@*&5M<'1Y*"1S:&5L;"D@/R!F86QS92`Z("1S:&5L;"D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!D871E(&]F('1H92!U<V5R
M)W,@;&%S="!P87-S=V]R9"!C:&%N9V4N"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@1&%T92!S=')I;F<@*'-T<FEN9RD@;W(@9F%L<V4@*&5R<F]R
M*2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%S<W=O<F1#:&%N9V4H*0H@
M("`@>PH@("`@("`@("1I;F9O<FUA=&EO;B`]("1T:&ES+3Y?9V5T06-C;W5N
M="@I.PH@("`@("`@(&EF("AI<U]A*"1I;F9O<FUA=&EO;BP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&EN9F]R;6%T:6]N.PH@("`@
M("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1I;F9O<FUA=&EO;ELP75LG<VAA
M9&]W;&%S=&-H86YG92==6S!=*2D@>PH@("`@("`@("`@("`D;&%S=&-H86YG
M92`]('-T<F9T:6UE*"<E>"<L("1I;F9O<FUA=&EO;ELP75LG<VAA9&]W;&%S
M=&-H86YG92==6S!=("H@.#8T,#`I.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("AE;7!T>2@D;&%S=&-H86YG92D@/R!F86QS92`Z("1L87-T8VAA;F=E
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('-T871U<R!O
M9B!T:&4@8W5R<F5N="!P87-S=V]R9"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!!('-T<FEN9R!W:71H(&$@=V%R;FEN9R!M97-S86=E(&EF('1H
M92!P87-S=V]R9"!I<R!A8F]U=`H@("`@("H@("`@("`@("`@("`@("`@=&\@
M97AP:7)E+"!014%27T5R<F]R(&]N(&5R<F]R(&%N9"!F86QS92!O=&AE<G=I
M<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-H96-K4&%S<W=O<F13=&%T=7,H
M*0H@("`@>PH@("`@("`@("1I;F9O<FUA=&EO;B`]("1T:&ES+3Y?9V5T06-C
M;W5N="@I.PH@("`@("`@(&EF("AI<U]A*"1I;F9O<FUA=&EO;BP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&EN9F]R;6%T:6]N.PH@
M("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1I;F9O<FUA=&EO;ELP75LG
M<VAA9&]W;6%X)UU;,%TI("8F"B`@("`@("`@("`@(&ES<V5T*"1I;F9O<FUA
M=&EO;ELP75LG<VAA9&]W;&%S=&-H86YG92==6S!=*2`F)@H@("`@("`@("`@
M("!I<W-E="@D:6YF;W)M871I;VY;,%U;)W-H861O=W=A<FYI;F<G75LP72DI
M('L*("`@("`@("`@("`@)'1O9&%Y(#T@9FQO;W(H=&EM92@I("\@.#8T,#`I
M.PH@("`@("`@("`@("`D=V%R;F1A>2`]("1I;F9O<FUA=&EO;ELP75LG<VAA
M9&]W;&%S=&-H86YG92==6S!=("L*("`@("`@("`@("`@("`@("`@("`@("`D
M:6YF;W)M871I;VY;,%U;)W-H861O=VUA>"==6S!=("T@)&EN9F]R;6%T:6]N
M6S!=6R=S:&%D;W=W87)N:6YG)UU;,%T["B`@("`@("`@("`@("1T;V5X<&ER
M92`]("1I;F9O<FUA=&EO;ELP75LG<VAA9&]W;&%S=&-H86YG92==6S!=("L@
M)&EN9F]R;6%T:6]N6S!=6R=S:&%D;W=M87@G75LP72`M("1T;V1A>3L*"B`@
M("`@("`@("`@(&EF("@D=&]D87D@/CT@)'=A<FYD87DI('L*("`@("`@("`@
M("`@("`@(')E='5R;B!S<')I;G1F*%\H(B5D(&1A>7,@=6YT:6P@>6]U<B!P
M87-S=V]R9"!E>'!I<F5S+B(I+"`D=&]E>'!I<F4I.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*("`@('T*"GT*````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+T)L;V-K+V=O;V=L92YP:'``````````````````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S-C$S(#$P-3$U-#,S-S,U(#`R
M,3,S,0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`H*)&)L;V-K7VYA;64@/2!?*")';V]G;&4@4V5A<F-H(BD["@HO
M*BH*("H@)$AO<F1E.B!H;W)D92]L:6(O0FQO8VLO9V]O9VQE+G!H<"QV(#$N
M,3`N,3`N,2`R,#`U+S$P+S$X(#$Q.C,S.C,Y(&IA;B!%>'`@)`H@*@H@*B!`
M<&%C:V%G92!(;W)D95]";&]C:PH@*B\*8VQA<W,@2&]R9&5?0FQO8VM?2&]R
M9&5?9V]O9VQE(&5X=&5N9',@2&]R9&5?0FQO8VL@>PH*("`@('9A<B`D7V%P
M<"`]("=H;W)D92<["@H@("`@+RHJ"B`@("`@*B!4:&4@=&ET;&4@=&\@9V\@
M:6X@=&AI<R!B;&]C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M(%1H92!T:71L92!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=&ET;&4H
M*0H@("`@>PH@("`@("`@(')E='5R;B!?*")';V]G;&4@4V5A<F-H(BD["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@8V]N=&5N="!T;R!G;R!I;B!T:&ES
M(&)L;V-K+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("`@5&AE(&-O
M;G1E;G0*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;G1E;G0H*0H@("`@>PH@
M("`@("`@("1H=&UL("`]("<\9F]R;2!N86UE/2)G;V]G;&4B(&]N<W5B;6ET
M/2)O<&5N7V=O;V=L95]W:6XH*3L@<F5T=7)N(&9A;'-E.R(^)SL*("`@("`@
M("`D:'1M;"`N/2`G/'1A8FQE('=I9'1H/2(Q,#`E(B!H96EG:'0](C$P,"4B
M/B<["B`@("`@("`@)&AT;6P@+CT@)SQT<CX\<V-R:7!T('1Y<&4](G1E>'0O
M:F%V87-C<FEP="(@<W)C/2(G("X@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E
M="@G=V5B<F]O="<L("=H;W)D92<I("X@)R]S97)V:6-E<R]J879A<V-R:7!T
M+G!H<#]F:6QE/6]P96Y?9V]O9VQE7W=I;BYJ<R9A;7`[87!P/6AO<F1E(CX\
M+W-C<FEP=#XG.PH@("`@("`@("1H=&UL("X]("<\=&0^)R`N($AO<F1E.CII
M;6<H)V=O;V=L92YP;F<G+"`G1V]O9VQE)RD@+B`G/"]T9#X\+W1R/B<["B`@
M("`@("`@)&AT;6P@+CT@)SQT<CX\=&0^/&EN<'5T(&UA>$QE;F=T:#TB,C4V
M(B!S:7IE/2(T,"(@;F%M93TB<2(@=VED=&@](C$P,"4B("\^/"]T9#X\+W1R
M/B<["B`@("`@("`@)&AT;6P@+CT@)SQT<CX\=&0^/'1A8FQE('=I9'1H/2(Q
M,#`E(CX\='(^/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)R861I
M;R(@;F%M93TB87)E82(@=F%L=64](G=E8B(@=VED=&@](C(P)2(@8VAE8VME
M9#TB8VAE8VME9"(@+SXG("X@7R@B5V5B(BD@+B`G/"]T9#XG.PH@("`@("`@
M("1H=&UL("X]("<\=&0@86QI9VX](F-E;G1E<B(^/&EN<'5T('1Y<&4](G)A
M9&EO(B!N86UE/2)A<F5A(B!V86QU93TB:6UA9V5S(B!W:61T:#TB,C`E(B`O
M/B<@+B!?*"));6%G97,B*2`N("<\+W1D/B<["B`@("`@("`@)&AT;6P@+CT@
M)SQT9"!A;&EG;CTB8V5N=&5R(CX\:6YP=70@='EP93TB<F%D:6\B(&YA;64]
M(F%R96$B('9A;'5E/2)G<F]U<',B('=I9'1H/2(R,"4B("\^)R`N(%\H(D=R
M;W5P<R(I("X@)SPO=&0^)SL*("`@("`@("`D:'1M;"`N/2`G/'1D(&%L:6=N
M/2)C96YT97(B/CQI;G!U="!T>7!E/2)R861I;R(@;F%M93TB87)E82(@=F%L
M=64](F1I<F5C=&]R>2(@=VED=&@](C(P)2(@+SXG("X@7R@B1&ER96-T;W)Y
M(BD@+B`G/"]T9#XG.PH@("`@("`@("1H=&UL("X]("<\=&0@86QI9VX](F-E
M;G1E<B(^/&EN<'5T('1Y<&4](G)A9&EO(B!N86UE/2)A<F5A(B!V86QU93TB
M;F5W<R(@=VED=&@](C(P)2(@+SXG("X@7R@B3F5W<R(I("X@)SPO=&0^/"]T
M<CX\+W1A8FQE/CPO=&0^/"]T<CXG.PH@("`@("`@("1H=&UL("X]("<\='(^
M/'1D/CQI;G!U="!T>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB('9A;'5E
M/2(G("X@7R@B1V]O9VQE(%-E87)C:"(I("X@)R(@+SX\+W1D/CPO='(^)SL*
M("`@("`@("`D:'1M;"`N/2`G/"]T86)L93XG.PH@("`@("`@("1H=&UL("X]
M("<\+V9O<FT^)SL*("`@("`@("!R971U<FX@)&AT;6P["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B]";&]C:R]S=6YR:7-E+G!H<```````````````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`Q,38U-2`Q,#4Q-30S,S<S-2`P,C$U-3(`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*"B1B;&]C:U]N86UE(#T@7R@B4W5N<FES92]3=6YS970B*3L*"B\J*@H@
M*B`D2&]R9&4Z(&AO<F1E+VQI8B]";&]C:R]S=6YR:7-E+G!H<"QV(#$N,30N
M,3`N,R`R,#`U+S$P+S$X(#$Q.C,S.C,Y(&IA;B!%>'`@)`H@*@H@*B!`<&%C
M:V%G92!(;W)D95]";&]C:PH@*B\*8VQA<W,@2&]R9&5?0FQO8VM?2&]R9&5?
M<W5N<FES92!E>'1E;F1S($AO<F1E7T)L;V-K('L*"B`@("!V87(@)%]A<'`@
M/2`G:&]R9&4G.PH*("`@(&9U;F-T:6]N(%]T:71L92@I"B`@("!["B`@("`@
M("`@<F5T=7)N(%\H(E-U;G)I<V4O4W5N<V5T(BD["B`@("!]"@H@("`@9G5N
M8W1I;VX@7W!A<F%M<R@I"B`@("!["B`@("`@("`@)'!A<F%M<R`](&%R<F%Y
M*"=L;V-A=&EO;B<@/3X@87)R87DH)W1Y<&4G(#T^("=M;&5N=6TG+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=N86UE
M)R`]/B!?*"),;V-A=&EO;B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=D969A=6QT)R`]/B`G-3$N-3$W.BTP+C$Q
M-R<I*3L*"B`@("`@("`@9VQO8F%L("1C;V]R9&EN871E<SL*("`@("`@("!I
M9B`H(6ES7V%R<F%Y*"1C;V]R9&EN871E<RDI('L*("`@("`@("`@("`@0&EN
M8VQU9&4@)TAO<F1E+TY,4R]C;V]R9&EN871E<RYP:'`G.PH@("`@("`@("`@
M("!I9B`H(6ES7V%R<F%Y*"1C;V]R9&EN871E<RDI('L*("`@("`@("`@("`@
M("`@("1C;V]R9&EN871E<R`](&%R<F%Y*"D["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("`@("`@)'!A<F%M<ULG;&]C871I;VXG75LG=F%L=65S)UT@
M/2`D8V]O<F1I;F%T97,["@H@("`@("`@(')E='5R;B`D<&%R86US.PH@("`@
M?0H*("`@(&9U;F-T:6]N(%]C;VYT96YT*"D*("`@('L*("`@("`@("!I9B`H
M96UP='DH)'1H:7,M/E]P87)A;7-;)VQO8V%T:6]N)UTI*2!["B`@("`@("`@
M("`@(')E='5R;B!?*").;R!L;V-A=&EO;B!I<R!S970N(BD["B`@("`@("`@
M?0H*("`@("`@("`O+R!3970@=&AE('1I;65Z;VYE('9A<FEA8FQE+"!I9B!A
M=F%I;&%B;&4N"B`@("`@("`@3DQ3.CIS9714:6UE6F]N92@I.PH*("`@("`@
M("!L:7-T*"1L870L("1L;VYG*2`](&5X<&QO9&4H)SHG+"`D=&AI<RT^7W!A
M<F%M<ULG;&]C871I;VXG72D["B`@("`@("`@)')I<V4@/2`D=&AI<RT^7V-A
M;&-U;&%T95-U;G-E="AT:6UE*"DL("1L870L("1L;VYG+"!F86QS92P@9FQO
M;W(H9&%T92@G6B<I("\@,S8P,"DI.PH@("`@("`@("1S970@/2`D=&AI<RT^
M7V-A;&-U;&%T95-U;G-E="AT:6UE*"DL("1L870L("1L;VYG+"!T<G5E+"!F
M;&]O<BAD871E*"=:)RD@+R`S-C`P*2D["@H@("`@("`@("1L;V-A=&EO;B`]
M("<G.PH@("`@("`@(&=L;V)A;"`D8V]O<F1I;F%T97,["B`@("`@("`@:68@
M*"%I<U]A<G)A>2@D8V]O<F1I;F%T97,I*2!["B`@("`@("`@("`@(')E<75I
M<F4@)TAO<F1E+TY,4R]C;V]R9&EN871E<RYP:'`G.PH@("`@("`@('T*("`@
M("`@("!F;W)E86-H("@D8V]O<F1I;F%T97,@87,@)&-O=6YT<GDI('L*("`@
M("`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)'1H:7,M/E]P87)A;7-;
M)VQO8V%T:6]N)UTL("1C;W5N=')Y*2D@>PH@("`@("`@("`@("`@("`@)&QO
M8V%T:6]N(#T@)&-O=6YT<GE;)'1H:7,M/E]P87)A;7-;)VQO8V%T:6]N)UU=
M.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`G/'1A8FQE('=I9'1H/2(Q,#`E(B!H96EG
M:'0](C$P,"4B(&-E;&QS<&%C:6YG/2(P(CX\='(^)R`N"B`@("`@("`@("`@
M("<\=&0@8V]L<W!A;CTB,B(@8VQA<W,](F-O;G1R;VPB/CQS=')O;F<^)R`N
M("1L;V-A=&EO;B`N("<\+W-T<F]N9SX\+W1D/CPO='(^/'1R(&AE:6=H=#TB
M,3`P)2(^)R`N"B`@("`@("`@("`@("<\=&0@=VED=&@](C4P)2(@86QI9VX]
M(F-E;G1E<B(^)R`N"B`@("`@("`@("`@($AO<F1E.CII;6<H)V)L;V-K+W-U
M;G)I<V4O<W5N<FES92YP;F<G+"!?*")3=6X@4FES92(I*2`N"B`@("`@("`@
M("`@("<\8G(@+SXG("X@)')I<V4@+B`G/"]T9#XG("X*("`@("`@("`@("`@
M)SQT9"!W:61T:#TB-3`E(B!A;&EG;CTB8V5N=&5R(CXG("X*("`@("`@("`@
M("`@2&]R9&4Z.FEM9R@G8FQO8VLO<W5N<FES92]S=6YS970N<&YG)RP@7R@B
M4W5N(%-E="(I*2`N"B`@("`@("`@("`@("<\8G(@+SXG("X@)'-E="`N("<\
M+W1D/B<@+B`G/"]T<CX\+W1A8FQE/B<["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!H='1P.B\O=W=W+GIE;F0N8V]M+V-O9&5X+G!H<#]I9#TQ,S4F<VEN9VQE
M/3$*("`@("`J+PH@("`@9G5N8W1I;VX@7V-A;&-U;&%T95-U;G-E="@D9&%T
M92P@)&QA=&ET=61E+"`D;&]N9VET=61E+"`D<W5N<V5T(#T@=')U92P@)'1I
M;65Z;VYE*0H@("`@>PH@("`@("`@("1Y9&%Y(#T@9&%T92@G>B<L("1D871E
M*3L*("`@("`@("`D;6]N(#T@9&%T92@G;B<L("1D871E*3L*("`@("`@("`D
M;61A>2`](&1A=&4H)VHG+"`D9&%T92D["B`@("`@("`@)'EE87(@/2!D871E
M*"=9)RP@)&1A=&4I.PH*("`@("`@("!I9B`H)'1I;65Z;VYE(#T]("<Q,R<I
M('L*("`@("`@("`@("`@)'1I;65Z;VYE(#T@)RTQ,2<["B`@("`@("`@("`@
M("1M9&%Y*RL["B`@("`@("`@("`@("1Y9&%Y*RL["B`@("`@("`@?0H*("`@
M("`@("`D02`](#$N-3<P.#L*("`@("`@("`D0B`](#,N,30Q-3D["B`@("`@
M("`@)$,@/2`T+C<Q,C,Y.PH@("`@("`@("1$(#T@-BXR.#,Q.3L*("`@("`@
M("`D12`](#`N,#$W-#4S,R`J("1L871I='5D93L*("`@("`@("`D1B`](#`N
M,#$W-#4S,R`J("1L;VYG:71U9&4["B`@("`@("`@)$<@/2`P+C(V,3<Y.2`@
M*B`D=&EM97IO;F4["@H@("`@("`@("\O($9O<B!A<W1R;VYO;6EC86P@='=I
M;&EG:'0L('5S92!2(#T@+2XS,#DP,3<*("`@("`@("`O+R!&;W(@;F%U=&EC
M86P@='=I;&EG:'0L('5S92!2(#T@+2XR,#<Y,3(*("`@("`@("`O+R!&;W(@
M8VEV:6P@='=I;&EG:'0L('5S92!2(#T@+2XQ,#0U,C@*("`@("`@("`O+R!&
M;W(@<W5N<FES92!O<B!S=6YS970L('5S92!2(#T@+2XP,30U-#,Y"B`@("`@
M("`@)%(@/2`M+C`Q-#4T,SD["@H@("`@("`@(&EF("@D<W5N<V5T*2!["B`@
M("`@("`@("`@("1*(#T@)$,["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)$H@/2`D03L*("`@("`@("!]"@H@("`@("`@("1+(#T@)'ED87D@*R`H
M*"1*("T@)$8I("\@)$0I.PH@("`@("`@("1,(#T@*"1+("H@+C`Q-S(P,BD@
M+2`N,#4W-#`S.3L@("`@("`@("`@("`@("\O(%-O;&%R($UE86X@06YO;6]L
M>0H@("`@("`@("1-(#T@)$P@*R`N,#,S-#0P-2`J('-I;B@D3"D[("`@("`@
M("`@("`@("`@("\O(%-O;&%R(%1R=64@3&]N9VET=61E"B`@("`@("`@)$T@
M*ST@-"XY,S(X.2`K("@S+C0Y,#8V12TP-"D@*B!S:6XH,B`J("1,*3L@+R\@
M475A9')A;G0@1&5T97)M:6YA=&EO;@H@("`@("`@('=H:6QE("@D32`\(#`I
M('L*("`@("`@("`@("`@)$T@/2`H)$T@*R`D1"D["B`@("`@("`@?0H@("`@
M("`@('=H:6QE("@D32`^/2`D1"D@>PH@("`@("`@("`@("`D32`]("@D32`M
M("1$*3L*("`@("`@("!]"@H@("`@("`@(&EF("@H)$T@+R`D02D@+2!I;G1V
M86PH)$T@+R`D02D@/3T@,"D@>PH@("`@("`@("`@("`D32`K/2`T+C@T.#$T
M12TP-CL*("`@("`@("!]"@H@("`@("`@("10(#T@<VEN*"1-*2`O(&-O<R@D
M32D[("`@("`@("`@("`@("`@("`@("\O(%-O;&%R(%)I9VAT($%S8V5N<VEO
M;@H@("`@("`@("10(#T@871A;C(H+CDQ-S0V("H@)%`L(#$I.PH*("`@("`@
M("`O+R!1=6%D<F%N="!!9&IU<W1M96YT"B`@("`@("`@:68@*"1-(#X@)$,I
M('L*("`@("`@("`@("`@)%`@*ST@)$0["B`@("`@("`@?2!E;'-E:68@*"1-
M(#X@)$$I('L*("`@("`@("`@("`@)%`@*ST@)$(["B`@("`@("`@?0H*("`@
M("`@("`D42`]("XS.3<X,B`J('-I;B@D32D[("`@("`@("`@("`@+R\@4V]L
M87(@1&5C;&EN871I;VX*("`@("`@("`D42`]("11("\@<W%R="@M)%$@*B`D
M42`K(#$I.R`@("`@+R\@5&AI<R!I<R!H;W<@=&AE(&]R:6=I;F%L(&%U=&AO
M<B!W<F]T92!I="$*("`@("`@("`D42`](&%T86XR*"11+"`Q*3L*"B`@("`@
M("`@)%,@/2`D4B`M("AS:6XH)%$I("H@<VEN*"1%*2D["B`@("`@("`@)%,@
M/2`D4R`O("AC;W,H)%$I("H@8V]S*"1%*2D["@H@("`@("`@(&EF("AA8G,H
M)%,I(#X@,2D@>PH@("`@("`@("`@("!R971U<FX@)VYO;F4G.R`@("`@("`@
M("`@("`@("`O+R!.=6QL('!H96YO;65N;VX*("`@("`@("!]"@H@("`@("`@
M("13(#T@)%,@+R!S<7)T*"TD4R`J("13("L@,2D["B`@("`@("`@)%,@/2`D
M02`M(&%T86XR*"13+"`Q*3L*"B`@("`@("`@:68@*"$D<W5N<V5T*2!["B`@
M("`@("`@("`@("13(#T@)$0@+2`D4R`["B`@("`@("`@?0H*("`@("`@("`D
M5"`]("13("L@)%`@+2`P+C`Q-S(P,C@@*B`D2R`M(#$N-S,S-C0[("\O($QO
M8V%L(&%P<&%R96YT('1I;64*("`@("`@("`D52`]("14("T@)$8[("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("\O(%5N:79E<G-A;"!T:6UE<@H@("`@
M("`@("16(#T@)%4@*R`D1SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+R\@5V%L;"!C;&]C:R!T:6UE"@H@("`@("`@("\O(%%U861R86YT($1E=&5R
M;6EN871I;VX*("`@("`@("!W:&EL92`H)%8@/"`P*2!["B`@("`@("`@("`@
M("16(#T@*"16("L@)$0I.PH@("`@("`@('T*("`@("`@("!W:&EL92`H)%8@
M/CT@)$0I('L*("`@("`@("`@("`@)%8@/2`H)%8@+2`D1"D["B`@("`@("`@
M?0H@("`@("`@("16(#T@)%8@*B`S+C@Q.3<R.PH*("`@("`@("`D:&]U<B`]
M(&EN='9A;"@D5BD["B`@("`@("`@)%8@("`M/2`D:&]U<CL*("`@("`@("`D
M;6EN("`](&EN='9A;"@D5B`J(#8P*3L*("`@("`@("`D5B`@("T]("1M:6X@
M+R`V,#L*("`@("`@("`D<V5C("`](&EN='9A;"@D5B`J(#,V,#`I.PH*("`@
M("`@("!R971U<FX@<W1R9G1I;64H)R58)RP@;6MT:6UE*"1H;W5R+"`D;6EN
M+"`D<V5C+"`D;6]N+"`D;61A>2P@)'EE87(I*3L*("`@('T*"GT*````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O0FQO8VLO;6]O;BYP:'``````````````````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3<P,C4@,3`U,34T,S,W,S4@
M,#(Q,#(W`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"@HD8FQO8VM?;F%M92`](%\H(DUO;VX@4&AA<V5S(BD["@HO
M*BH*("H@)$AO<F1E.B!H;W)D92]L:6(O0FQO8VLO;6]O;BYP:'`L=B`Q+C$V
M+C$P+C0@,C`P-2\Q,"\Q."`Q,3HS,SHS.2!J86X@17AP("0*("H*("H@0'!A
M8VMA9V4@2&]R9&5?0FQO8VL*("HO"F-L87-S($AO<F1E7T)L;V-K7TAO<F1E
M7VUO;VX@97AT96YD<R!(;W)D95]";&]C:R!["@H@("`@=F%R("1?87!P(#T@
M)VAO<F1E)SL*"B`@("!F=6YC=&EO;B!?=&ET;&4H*0H@("`@>PH@("`@("`@
M(')E='5R;B!?*")-;V]N(%!H87-E<R(I.PH@("`@?0H*("`@(&9U;F-T:6]N
M(%]P87)A;7,H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@*("`@("`@
M("`@("`@)W!H87-E)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("=N86UE
M)R`]/B!?*")7:&EC:"!P:&%S97,B*2P*("`@("`@("`@("`@("`@("=T>7!E
M)R`]/B`G96YU;2<L"B`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@)V-U
M<G)E;G0G+`H@("`@("`@("`@("`@("`@)W9A;'5E<R<@/3X@87)R87DH)V-U
M<G)E;G0G(#T^(%\H(D-U<G)E;G0@-"!0:&%S97,B*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=N97AT)R`]/B!?*").97AT(#0@4&AA
M<V5S(BDI*2P*("`@("`@("`@("`@)VAE;6ES<&AE<F4G(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`@("`@)VYA;64G(#T^(%\H(DAE;6ES<&AE<F4B*2P*("`@
M("`@("`@("`@("`@("=T>7!E)R`]/B`G96YU;2<L"B`@("`@("`@("`@("`@
M("`G9&5F875L="<@/3X@)VYO<G1H97)N)RP*("`@("`@("`@("`@("`@("=V
M86QU97,G(#T^(&%R<F%Y*"=N;W)T:&5R;B<@/3X@7R@B3F]R=&AE<FX@2&5M
M:7-P:&5R92(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W-O=71H97)N)R`]/B!?*")3;W5T:&5R;B!(96UI<W!H97)E(BDI*2P*("`@
M("`@("`@("`@*3L*("`@('T*"B`@("!F=6YC=&EO;B!?8V]N=&5N="@I"B`@
M("!["B`@("`@("`@)'!H87-E<R`]("1T:&ES+3Y?8V%L8W5L871E36]O;E!H
M87-E<RAD871E*"=9)RDI.PH@("`@("`@("1N;W<@/2!T:6UE*"D["@H@("`@
M("`@("1L87-T3F5W(#T@,#L*("`@("`@("`D;&%S=$YE=U-T86UP(#T@,#L*
M("`@("`@("`D;V9F<V5T(#T@,#L*("`@("`@("!F;W)E86-H("@D<&AA<V5S
M(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("!I9B`H)&ME>2`\("1N
M;W<@)B8@)&ME>2`^("1L87-T3F5W4W1A;7`@)B8@)'9A;"`]/2!?*").97<@
M36]O;B(I*2!["B`@("`@("`@("`@("`@("`D;&%S=$YE=R`]("1O9F9S970[
M"B`@("`@("`@("`@("`@("`D;&%S=$YE=U-T86UP(#T@)&ME>3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D;V9F<V5T*RL["B`@("`@("`@?0H*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]P87)A;7-;)W!H87-E)UTI("8F("1T
M:&ES+3Y?<&%R86US6R=P:&%S92==(#T]("=N97AT)RD@>PH@("`@("`@("`@
M("`D9&%T97,@/2!A<G)A>5]S;&EC92AA<G)A>5]K97ES*"1P:&%S97,I+"`D
M;&%S=$YE=R`K(#0L(#0I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1D871E<R`](&%R<F%Y7W-L:6-E*&%R<F%Y7VME>7,H)'!H87-E<RDL("1L
M87-T3F5W+"`T*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^7W!A<F%M<ULG:&5M:7-P:&5R92==*2`F)B`D=&AI<RT^7W!A<F%M<ULG
M:&5M:7-P:&5R92==(#T]("=N;W)T:&5R;B<I('L*("`@("`@("`@("`@)&QO
M8V%T:6]N(#T@7R@B3F]R=&AE<FX@2&5M:7-P:&5R92(I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1L;V-A=&EO;B`](%\H(E-O=71H97)N($AE
M;6ES<&AE<F4B*3L*("`@("`@("!]"@H@("`@("`@("1H=&UL(#T@)SQT86)L
M92!W:61T:#TB,3`P)2(@:&5I9VAT/2(Q,#`E(B!C96QL<W!A8VEN9STB,"(^
M)R`N"B`@("`@("`@("`@("<\='(^/'1D(&-O;'-P86X](C0B(&-L87-S/2)C
M;VYT<F]L(CX\<W1R;VYG/B<@+B`D;&]C871I;VX@+B`G/"]S=')O;F<^/"]T
M9#X\+W1R/B<@+@H@("`@("`@("`@("`G/'1R(&AE:6=H=#TB,3`P)2(^/'1D
M('=I9'1H/2(R-24B(&%L:6=N/2)C96YT97(B/B<@+@H@("`@("`@("`@("!(
M;W)D93HZ:6UG*"=B;&]C:R]M;V]N+VYE=VUO;VXN<&YG)RP@7R@B3F5W($UO
M;VXB*2D@+@H@("`@("`@("`@("`G/&)R("\^)R`N('-T<F9T:6UE*"<E9"`E
M8B<L("1D871E<ULP72D@+@H@("`@("`@("`@("`G/"]T9#XG.PH*("`@("`@
M("`D:'1M;"`N/2`G/'1D('=I9'1H/2(R-24B(&%L:6=N/2)C96YT97(B/B<[
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%R86US6R=H96UI<W!H97)E
M)UTI("8F("1T:&ES+3Y?<&%R86US6R=H96UI<W!H97)E)UT@/3T@)VYO<G1H
M97)N)RD@>PH@("`@("`@("`@("`D:'1M;"`N/2!(;W)D93HZ:6UG*"=B;&]C
M:R]M;V]N+VQA<W1Q=6%R=&5R+G!N9R<L(%\H(D9I<G-T(%%U87)T97(B*2D[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&AT;6P@+CT@2&]R9&4Z
M.FEM9R@G8FQO8VLO;6]O;B]F:7)S='%U87)T97(N<&YG)RP@7R@B1FER<W0@
M475A<G1E<B(I*3L*("`@("`@("!]"B`@("`@("`@)&AT;6P@+CT@)SQB<B`O
M/B<@+B!S=')F=&EM92@G)60@)6(G+"`D9&%T97-;,5TI("X@)SPO=&0^)SL*
M"B`@("`@("`@)&AT;6P@+CT@)SQT9"!W:61T:#TB,C4E(B!A;&EG;CTB8V5N
M=&5R(CXG("X*("`@("`@("`@("`@2&]R9&4Z.FEM9R@G8FQO8VLO;6]O;B]F
M=6QL;6]O;BYP;F<G+"!?*")&=6QL($UO;VXB*2D@+@H@("`@("`@("`@("`G
M/&)R("\^)R`N('-T<F9T:6UE*"<E9"`E8B<L("1D871E<ULR72D@+B`G/"]T
M9#XG.PH*("`@("`@("`D:'1M;"`N/2`G/'1D('=I9'1H/2(R-24B(&%L:6=N
M/2)C96YT97(B/B<["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%R86US
M6R=H96UI<W!H97)E)UTI("8F("1T:&ES+3Y?<&%R86US6R=H96UI<W!H97)E
M)UT@/3T@)VYO<G1H97)N)RD@>PH@("`@("`@("`@("`D:'1M;"`N/2!(;W)D
M93HZ:6UG*"=B;&]C:R]M;V]N+V9I<G-T<75A<G1E<BYP;F<G+"!?*"),87-T
M(%%U87)T97(B*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&AT
M;6P@+CT@2&]R9&4Z.FEM9R@G8FQO8VLO;6]O;B]L87-T<75A<G1E<BYP;F<G
M+"!?*"),87-T(%%U87)T97(B*2D["B`@("`@("`@?0H@("`@("`@("1H=&UL
M("X]("<\8G(@+SXG("X@<W1R9G1I;64H)R5D("5B)RP@)&1A=&5S6S-=*2`N
M("<\+W1D/CPO='(^/"]T86)L93XG.PH*("`@("`@("!R971U<FX@)&AT;6P[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&%R<F%Y('=I=&@@
M86QL('1H92!P:&%S97,@;V8@=&AE(&UO;VX@9F]R(&$@=VAO;&4*("`@("`J
M('EE87(N"B`@("`@*@H@("`@("H@0F%S960@;VX@8V]D92!F<F]M"B`@("`@
M*B!H='1P.B\O=W=W+GIE;F0N8V]M+V-O9&5X+G!H<#]I9#TX,S`F<VEN9VQE
M/3$@8GD@07)E(%!E9&5R<V5N+@H@("`@("H*("`@("`J($-O;G9E<G1E9"!F
M<F]M($)A<VEC(&)Y(%)O9V5R(%<N(%-I;FYO="P@4VMY("8@5&5L97-C;W!E
M+"!-87)C:"`Q.3@U+@H@("`@("H@0V]N=F5R=&5D(&9R;VT@:F%V87-C<FEP
M="!B>2!!<F4@4&5D97)S96X@,C`P,@H@("`@("H@2F%V87-C<FEP="!F;W5N
M9"!A="!H='1P.B\O=W=W+G-T96QL869A;F4N8V]M+VUO;VY?<&AA<V4O;6]O
M;E]P:&%S92YH=&T*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`@("1Y
M96%R("`@5&AE(&9O=7(@9&EG:70@>65A<B!T;R!R971U<FX@=&AE(&UO;VX*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!P:&%S97,@9F]R+@H@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@("`@5&AE(&UO;VX@<&AA<V5S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V%L8W5L871E36]O;E!H87-E<R@D
M62D*("`@('L*("`@("`@("`D4C$@/2`S+C$T,34Y,C8U("\@,3@P.PH@("`@
M("`@("15("`](&9A;'-E.PH@("`@("`@("1+,"`](&EN='9A;"@H)%D@+2`Q
M.3`P*2`J(#$R+C,V.#4I.PH@("`@("`@("14("`]("@D62`M(#$X.3DN-2D@
M+R`Q,#`["B`@("`@("`@)%0R(#T@)%0@*B`D5#L*("`@("`@("`D5#,@/2`D
M5"`J("14("H@)%0["B`@("`@("`@)$HP(#T@,C0Q-3`R,"`K(#(Y("H@)$LP
M.PH@("`@("`@("1&,"`](#`N,#`P,3$W."`J("14,B`M(#`N,#`P,#`P,34U
M("H@)%0S.PH@("`@("`@("1&,"`K/2`H,"XW-3DS,R`K(#`N-3,P-3@X-C@J
M)$LP*3L*("`@("`@("`D1C`@+3T@*#`N,#`P.#,W("H@)%0@*R`P+C`P,#,S
M-2`J("14,BD["B`@("`@("`@)$TP("`]("1+,"`J(#`N,#@P.#0X,C$Q,S,[
M"B`@("`@("`@)$TP("`](#,V,"`J("@D33`@+2!I;G1V86PH)$TP*2D@*R`S
M-3DN,C(T,CL*("`@("`@("`D33`@+3T@,"XP,#`P,S,S("H@)%0R.PH@("`@
M("`@("1-,"`M/2`P+C`P,#`P,S0W("H@)%0S.PH@("`@("`@("1-,2`@/2`D
M2S`@*B`P+C`W,3<Q,S8V,3(X.PH@("`@("`@("1-,2`@/2`S-C`@*B`H)$TQ
M("T@:6YT=F%L*"1-,2DI("L@,S`V+C`R-3,["B`@("`@("`@)$TQ("L](#`N
M,#$P-S,P-B`J("14,CL*("`@("`@("`D33$@*ST@,"XP,#`P,3(S-B`J("14
M,SL*("`@("`@("`D0C$@(#T@)$LP("H@,"XP.#4Q.34X-3$R.#L*("`@("`@
M("`D0C$@(#T@,S8P("H@*"1",2`M(&EN='9A;"@D0C$I*2`K(#(Q+C(Y-C0[
M"B`@("`@("`@)$(Q("T](#`N,#`Q-C4R."`J("14,CL*("`@("`@("`D0C$@
M+3T@,"XP,#`P,#(S.2`J("14,SL*("`@("`@("!F;W(@*"1+.2`](#`[("1+
M.2`\/2`R.#L@)$LY(#T@)$LY("L@,"XU*2!["B`@("`@("`@("`@("1*(#T@
M)$HP("L@,30@*B`D2SD["B`@("`@("`@("`@("1&(#T@)$8P("L@,"XW-C4R
M.30@*B`D2SD["B`@("`@("`@("`@("1+(#T@)$LY("\@,CL*("`@("`@("`@
M("`@)$TU(#T@*"1-,"`K("1+("H@,CDN,3`U,S4V,#@I("H@)%(Q.PH@("`@
M("`@("`@("`D338@/2`H)$TQ("L@)$L@*B`S.#4N.#$V.3$X,#8I("H@)%(Q
M.PH@("`@("`@("`@("`D0C8@/2`H)$(Q("L@)$L@*B`S.3`N-C<P-3`V-#8I
M("H@)%(Q.PH@("`@("`@("`@("`D1B`M/2`P+C0P-C@@*B!S:6XH)$TV*3L*
M("`@("`@("`@("`@)$8@*ST@*#`N,3<S-"`M(#`N,#`P,SDS("H@)%0I("H@
M<VEN*"1--2D["B`@("`@("`@("`@("1&("L](#`N,#$V,2`J('-I;B@R("H@
M)$TV*3L*("`@("`@("`@("`@)$8@*ST@,"XP,3`T("H@<VEN*#(@*B`D0C8I
M.PH@("`@("`@("`@("`D1B`M/2`P+C`P-S0@*B!S:6XH)$TU("T@)$TV*3L*
M("`@("`@("`@("`@)$8@+3T@,"XP,#4Q("H@<VEN*"1--2`K("1--BD["B`@
M("`@("`@("`@("1&("L](#`N,#`R,2`J('-I;B@R("H@)$TU*3L*("`@("`@
M("`@("`@)$8@*ST@,"XP,#$P("H@<VEN*#(@*B`D0C8@+2`D338I.PH*("`@
M("`@("`@("`@+RH@061D(#$O,B!M:6YU=&4@9F]R('!R;W!E<B!R;W5N9&EN
M9R!T;R!M:6YU=&5S('!E<B!3:WD@)@H@("`@("`@("`@("`@*B!496P@87)T
M:6-L92X@*B\*("`@("`@("`@("`@)$8@*ST@,"XU("\@,30T,#L*("`@("`@
M("`@("`@)$H@*ST@:6YT=F%L*"1&*3L*("`@("`@("`@("`@)$8@+3T@:6YT
M=F%L*"1&*3L*"B`@("`@("`@("`@("\J($-O;G9E<G0@9G)O;2!*1"!T;R!#
M86QE;F1A<B!$871E+B`J+PH@("`@("`@("`@("`D:G5L:6%N(#T@)$H@*R!R
M;W5N9"@D1BD["B`@("`@("`@("`@("1P87)T<R`@/2!E>'!L;V1E*"<O)RP@
M)'1H:7,M/E]J9'1O9W)E9V]R:6%N*"1J=6QI86XI*3L*("`@("`@("`@("`@
M)'-T86UP("`](&=M;6MT:6UE*#`L(#`L(#`L("1P87)T<ULP72P@)'!A<G1S
M6S%=+"`D<&%R='-;,ETI.PH*("`@("`@("`@("`@+RH@:&%L9B!++B`J+PH@
M("`@("`@("`@("!I9B`H*"1+.2`M(&9L;V]R*"1+.2DI(#X@,"D@>PH@("`@
M("`@("`@("`@("`@:68@*"15*2!["B`@("`@("`@("`@("`@("`@("`@+RH@
M3F5W(&AA;&8N("HO"B`@("`@("`@("`@("`@("`@("`@)'!H87-E<ULD<W1A
M;7!=(#T@7R@B1FER<W0@2&%L9B(I.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`O*B!&=6QL(&AA;&8N("HO"B`@("`@
M("`@("`@("`@("`@("`@)'!H87-E<ULD<W1A;7!=(#T@7R@B3&%S="!(86QF
M(BD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`O*B!F=6QL($LN("HO"B`@("`@("`@("`@("`@("!I
M9B`H(215*2!["B`@("`@("`@("`@("`@("`@("`@)'!H87-E<ULD<W1A;7!=
M(#T@7R@B3F5W($UO;VXB*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@)'!H87-E<ULD<W1A;7!=(#T@7R@B1G5L;"!-
M;V]N(BD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D52`]
M("$D53L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1P:&%S97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@:68@=&AE
M(&ID=&]G<F5G;W)I86X@9G5N8W1I;VX@97AI<W1S+"!A;F0@:68@;F]T"B`@
M("`@*B!C86QC=6QA=&5S('1H92!G<F5G;W)I86X@9&%T92!M86YU86QL>2X*
M("`@("`J"B`@("`@*B!`<&%R86T@:6YT("1J=6QI86X@5&AE(&IU;&EA;B!D
M871E"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@;2]D+UD*("`@("`J
M+PH@("`@9G5N8W1I;VX@7VID=&]G<F5G;W)I86XH)&IU;&EA;BD*("`@('L*
M("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=J9'1O9W)E9V]R:6%N)RDI
M('L*("`@("`@("`@("`@<F5T=7)N(&ID=&]G<F5G;W)I86XH)&IU;&EA;BD[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@1G)O;2!H='1P.B\O
M<&AP+FYE="]M86YU86PO96XO9G5N8W1I;VXN:F1T;V=R96=O<FEA;BYP:'`*
M("`@("`@("`@("`@)&IU;&EA;B`]("1J=6QI86X@+2`Q-S(Q,3$Y.PH@("`@
M("`@("`@("`D8V%L8S$@/2`T("H@)&IU;&EA;B`M(#$["B`@("`@("`@("`@
M("1Y96%R(#T@9FQO;W(H)&-A;&,Q("\@,30V,#DW*3L*("`@("`@("`@("`@
M)&IU;&EA;B`](&9L;V]R*"1C86QC,2`M(#$T-C`Y-R`J("1Y96%R*3L*("`@
M("`@("`@("`@)&1A>2`](&9L;V]R*"1J=6QI86X@+R`T*3L*("`@("`@("`@
M("`@)&-A;&,R(#T@-"`J("1D87D@*R`S.PH@("`@("`@("`@("`D:G5L:6%N
M(#T@9FQO;W(H)&-A;&,R("\@,30V,2D["B`@("`@("`@("`@("1D87D@/2`D
M8V%L8S(@+2`Q-#8Q("H@)&IU;&EA;CL*("`@("`@("`@("`@)&1A>2`](&9L
M;V]R*"@D9&%Y("L@-"D@+R`T*3L*("`@("`@("`@("`@)&-A;&,S(#T@-2`J
M("1D87D@+2`S.PH@("`@("`@("`@("`D;6]N=&@@/2!F;&]O<B@D8V%L8S,@
M+R`Q-3,I.PH@("`@("`@("`@("`D9&%Y(#T@)&-A;&,S("T@,34S("H@)&UO
M;G1H.PH@("`@("`@("`@("`D9&%Y(#T@9FQO;W(H*"1D87D@*R`U*2`O(#4I
M.PH@("`@("`@("`@("`D>65A<B`](#$P,"`J("1Y96%R("L@)&IU;&EA;CL*
M"B`@("`@("`@("`@(&EF("@D;6]N=&@@/"`Q,"D@>PH@("`@("`@("`@("`@
M("`@)&UO;G1H(#T@)&UO;G1H("L@,SL*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1M;VYT:"`]("1M;VYT:"`M(#D["B`@("`@("`@
M("`@("`@("`D>65A<B`]("1Y96%R("L@,3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!R971U<FX@(B1M;VYT:"\D9&%Y+R1Y96%R(CL*("`@("`@("!]
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP````````````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#$Q,3$W(#$P-3$U-#,S-S,U(#`R,34S-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`H*)&)L;V-K7VYA;64@/2!?
M*")286YD;VT@1F]R='5N92(I.PH*+RHJ"B`J("1(;W)D93H@:&]R9&4O;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP+'8@,2XQ-"XQ,"XR(#(P,#4O,3`O,3@@,3$Z
M,S,Z,SD@:F%N($5X<"`D"B`J"B`J($!P86-K86=E($AO<F1E7T)L;V-K"B`J
M+PIC;&%S<R!(;W)D95]";&]C:U](;W)D95]F;W)T=6YE(&5X=&5N9',@2&]R
M9&5?0FQO8VL@>PH*("`@('9A<B`D7V%P<"`]("=H;W)D92<["@H@("`@+RHJ
M"B`@("`@*B!4:&4@=&ET;&4@=&\@9V\@:6X@=&AI<R!B;&]C:RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@(%1H92!T:71L92!T97AT+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?=&ET;&4H*0H@("`@>PH@("`@("`@(')E='5R
M;B!?*")&;W)T=6YE(BD["B`@("!]"@H@("`@9G5N8W1I;VX@7W!A<F%M<R@I
M"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("`D9&5S8W)I
M<'1I;VYS(#T@87)R87DH)V%R="<@/3X@7R@B07)T(BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=A<V-I:2UA<G0G(#T^(%\H(D%S8VEI($%R
M="(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8F]F:"UE>&-U
M<V5S)R`]/B!?*")"3T9(($5X8W5S97,B*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V-O;7!U=&5R<R<@/3X@7R@B0V]M<'5T97)S(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=C;V]K:64G(#T^(%\H(D-O
M;VMI92(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5F:6YI
M=&EO;G,G(#T^(%\H(D1E9FEN:71I;VYS(BDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=D<G5G<R<@/3X@7R@B1')U9W,B*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V5D=6-A=&EO;B<@/3X@7R@B161U8V%T
M:6]N(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=E=&AN:6,G
M(#T^(%\H(D5T:&YI8R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G9F]O9"<@/3X@7R@B1F]O9"(I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G9F]R='5N97,G(#T^(%\H(D9O<G1U;F5S(BDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=F;W)T=6YE<S(G(#T^(%\H(D9O<G1U
M;F5S(#(B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V=O961E
M;"<@/3X@7R@B1V]E9&5L(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=H=6UO<FES=',G(#T^(%\H(DAU;6]R:7-T<R(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G:V5R;F5L;F5W8FEE<R<@/3X@7R@B2V5R
M;F5L($YE=V)I97,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)VMI9',G(#T^(%\H(DMI9',B*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VQA=R<@/3X@7R@B3&%W(BDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=L:6UE<FEC:R<@/3X@7R@B3&EM97)I8VLB*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)VQI;G5X8V]O:VEE)R`]/B!?*"),
M:6YU>"!#;V]K:64B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)VQI=&5R871U<F4G(#T^(%\H(DQI=&5R871U<F4B*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)VQO=F4G(#T^(%\H(DQO=F4B*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)VUA9VEC)R`]/B!?*")-86=I8R(I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;65D:6-I;F4G(#T^
M(%\H(DUE9&EC:6YE(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=M:7-C96QL86YE;W5S)R`]/B!?*")-:7-C96QL86YE;W5S(BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=N97=S)R`]/B!?*").97=S(BDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=O<V9O<G1U;F4G(#T^
M(%\H(D]P97)A=&EN9R!3>7-T96TB*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W!E;W!L92<@/3X@7R@B4&5O<&QE(BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=P971S)R`]/B!?*")0971S(BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=P;&%T:71U9&5S)R`]/B!?*")0
M;&%T:71U9&5S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P
M;VQI=&EC<R<@/3X@7R@B4&]L:71I8W,B*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W)I9&1L97,G(#T^(%\H(E)I9&1L97,B*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W-C:65N8V4G(#T^(%\H(E-C:65N
M8V4B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-O;F=S+7!O
M96US)R`]/B!?*")3;VYG<R`F(%!O96US(BDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=S<&]R=',G(#T^(%\H(E-P;W)T<R(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G<W1A<G1R96LG(#T^(%\H(E-T87(@
M5')E:R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=')A;G-L
M871E+6UE)R`]/B!?*")4<F%N<VQA=&EO;G,B*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W=I<V1O;2<@/3X@7R@B5VES9&]M(BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=W;W)K)R`]/B!?*")7;W)K(BDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=Z:7!P>2<@/3X@7R@B
M6FEP<'DB*2D["@H@("`@("`@("1V86QU97,@/2!N=6QL.PH@("`@("`@(&EF
M("AI<W-E="@D8V]N9ELG9F]R='5N92==6R=E>&5C7W!A=&@G72D@)B8*("`@
M("`@("`@("`@:7-?97AE8W5T86)L92@D8V]N9ELG9F]R='5N92==6R=E>&5C
M7W!A=&@G72DI('L*("`@("`@("`@("`@97AE8R@D8V]N9ELG9F]R='5N92==
M6R=E>&5C7W!A=&@G72`N("<@+68@,CXF,2<L("1O=71P=70L("1S=&%T=7,I
M.PH@("`@("`@("`@("!I9B`H(21S=&%T=7,I('L*("`@("`@("`@("`@("`@
M(&9O<B`H)&D@/2`Q.R`D:2`\(&-O=6YT*"1O=71P=70I.R`D:2LK*2!["B`@
M("`@("`@("`@("`@("`@("`@)&9O<G1U;F4@/2!S=6)S='(H)&]U='!U=%LD
M:5TL('-T<G)P;W,H)&]U='!U=%LD:5TL("<@)RD@*R`Q*3L*("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&1E<V-R:7!T:6]N<ULD9F]R='5N95TI
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU97-;)&9O<G1U;F5=
M(#T@)&1E<V-R:7!T:6]N<ULD9F]R='5N95T["B`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E<ULD
M9F]R='5N95T@/2`D9F]R='5N93L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@:68@*&ES7VYU;&PH)'9A;'5E<RDI('L*("`@("`@("`@("`@)'9A;'5E
M<R`]("1D97-C<FEP=&EO;G,["B`@("`@("`@?0H@("`@("`@(&%S;W)T*"1V
M86QU97,I.PH@("`@("`@("1V86QU97,@/2!A<G)A>5]M97)G92AA<G)A>2@G
M)R`]/B!?*")!;&PB*2DL("1V86QU97,I.PH*("`@("`@("!R971U<FX@87)R
M87DH"B`@("`@("`@("`@("=O9F9E;F0G(#T^(&%R<F%Y*`H@("`@("`@("`@
M("`@("`@)W1Y<&4G(#T^("=E;G5M)RP*("`@("`@("`@("`@("`@("=N86UE
M)R`]/B!?*")/9F9E;G-E(&9I;'1E<B(I+`H@("`@("`@("`@("`@("`@)V1E
M9F%U;'0G(#T^("<G+`H@("`@("`@("`@("`@("`@)W9A;'5E<R<@/3X@87)R
M87DH)R<@/3X@7R@B3F\@;V9F96YS:79E(&9O<G1U;F5S(BDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("<@+6\G(#T^(%\H(D]N;'D@;V9F
M96YS:79E(&9O<G1U;F5S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("<@+6$G(#T^(%\H(D)O=&@B*2DI+`H@("`@("`@("`@("`G9F]R
M='5N92<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`G='EP92<@/3X@)VUU
M;'1I96YU;2<L"B`@("`@("`@("`@("`@("`G;F%M92<@/3X@7R@B1F]R='5N
M92!T>7!E(BDL"B`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@87)R87DH
M)R<I+`H@("`@("`@("`@("`@("`@)W9A;'5E<R<@/3X@)'9A;'5E<RDI.PH@
M("`@?0H*("`@("\J*@H@("`@("H@5&AE(&-O;G1E;G0@=&\@9V\@:6X@=&AI
M<R!B;&]C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@(%1H92!C
M;VYT96YT"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYT96YT*"D*("`@('L*
M("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@(&EF("AI<W-E="@D8V]N
M9ELG9F]R='5N92==6R=E>&5C7W!A=&@G72D@)B8*("`@("`@("`@("`@:7-?
M97AE8W5T86)L92@D8V]N9ELG9F]R='5N92==6R=E>&5C7W!A=&@G72DI('L*
M("`@("`@("`@("`@)&-M9$QI;F4@/2`D8V]N9ELG9F]R='5N92==6R=E>&5C
M7W!A=&@G73L*("`@("`@("`@("`@)&-M9$QI;F4@+CT@)'1H:7,M/E]P87)A
M;7-;)V]F9F5N9"==.PH@("`@("`@("`@("`D8VUD3&EN92`N/2`G("<@+B!I
M;7!L;V1E*"<@)RP@)'1H:7,M/E]P87)A;7-;)V9O<G1U;F4G72D["B`@("`@
M("`@("`@(')E='5R;B!N;#)B<BAH=&UL<W!E8VEA;&-H87)S*'-H96QL7V5X
M96,H)&-M9$QI;F4I*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<F5T=7)N("<G.PH@("`@("`@('T*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,C8U-"`Q,#4Q-30S,S<S-2`P,C0T-S<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%!O
M<W-I8FQE('-T<FEN9W,@9G)O;2!W96%T:&5R+F-O;2P@:G5S="!T;R!H879E
M('1H96T@:6X@=&AE('-O=7)C92!F;W(*("H@;&]C86QI>F%T:6]N(')E87-O
M;G,N"B`J"B`J("1(;W)D93H@:&]R9&4O;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`L=B`Q+C$N,BXV(#(P,#8O,#4O,#,@,3<Z,#<Z,C<@
M:F%N($5X<"`D"B`J+PH*7R@B04T@0VQO=61S(BD["E\H(D%-($QI9VAT(%)A
M:6XB*3L*7R@B04T@3&EG:'0@4VYO=R(I.PI?*")!32!286EN(BD["E\H(D%-
M(%-H;W=E<G,B*3L*7R@B04T@4VYO=R!3:&]W97)S(BD["E\H(D-L96%R(BD[
M"E\H(D-L96%R:6YG($QA=&4B*3L*7R@B0VQO=61S($5A<FQY(BD["E\H(D-L
M;W5D>2(I.PI?*")&86ER(BD["E\H(D9E=R!3:&]W97)S(BD["E\H(D9E=R!3
M;F]W(%-H;W=E<G,B*3L*7R@B1F]G(BD["E\H(D9R965Z:6YG($1R:7IZ;&4B
M*3L*7R@B2&%Z92(I.PI?*")(96%V>2!4+5-T;W)M(BD["E\H(DES;VQA=&5D
M(%0M4W1O<FUS(BD["E\H(DQI9VAT($1R:7IZ;&4B*3L*7R@B3&EG:'0@4F%I
M;B(I.PI?*"),:6=H="!286EN($5A<FQY(BD["E\H(DQI9VAT(%)A:6X@3&%T
M92(I.PI?*"),:6=H="!286EN(%-H;W=E<B(I.PI?*"),:6=H="!286EN('=I
M=&@@5&AU;F1E<B(I.PI?*"),:6=H="!3;F]W(BD["E\H(DQI9VAT(%-N;W<@
M4VAO=V5R(BD["E\H(DUO<W1L>2!#;&5A<B(I.PI?*")-;W-T;'D@0VQO=61Y
M(BD["E\H(DUO<W1L>2!#;&]U9'D@86YD(%=I;F1Y(BD["E\H(DUO<W1L>2!3
M=6YN>2(I.PI?*")087)T;'D@0VQO=61Y(BD["E\H(E!-($QI9VAT(%)A:6XB
M*3L*7R@B4$T@4F%I;B(I.PI?*")032!3:&]W97)S(BD["E\H(E!-(%-N;W<B
M*3L*7R@B4$T@4VYO=R!3:&]W97)S(BD["E\H(E!-(%-U;B(I.PI?*")032!4
M+5-T;W)M<R(I.PI?*")286EN(BD["E\H(E)A:6X@16%R;'DB*3L*7R@B4F%I
M;B!,871E(BD["E\H(E)A:6X@4VAO=V5R(BD["E\H(E)A:6X@86YD(%-N;W<B
M*3L*7R@B4F%I;B!T;R!3;F]W(BD["E\H(E-C871T97)E9"!4+5-T;W)M<R(I
M.PI?*")3:&]W97)S(BD["E\H(E-H;W=E<G,@16%R;'DB*3L*7R@B4VAO=V5R
M<R!,871E(BD["E\H(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(BD["E\H(E-N
M;W<B*3L*7R@B4VYO=R!3:&]W97(B*3L*7R@B4VYO=R!3:&]W97)S(BD["E\H
M(E-N;W<@4VAO=V5R<R!%87)L>2(I.PI?*")3;F]W(%-H;W=E<G,@3&%T92(I
M.PI?*")3=6YN>2(I.PI?*")4+5-T;W)M(BD["E\H(E0M4W1O<FT@86YD(%=I
M;F1Y(BD["E\H(E0M4W1O<FUS(BD["E\H(E0M4W1O<FUS($5A<FQY(BD["E\H
M(E1H=6YD97(B*3L*7R@B5VEN9"(I.PI?*")7:6YD($5A<FQY(BD["E\H(DQO
M=R(I.PI?*")-;V1E<F%T92(I.PI?*")(:6=H(BD["E\H(E9E<GD@2&EG:"(I
M.PI?*")F86QL:6YG(BD["E\H(G-T96%D>2(I.PI?*")R:7-I;F<B*3L*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+T)L;V-K+VEF<F%M92YP:'``````````````
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`T,3$P(#$P-3$U-#,S
M-S,U(#`R,3,Q,0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`H*)&)L;V-K7VYA;64@/2!?*")6:65W(&%N(&5X=&5R
M;F%L('=E8B!P86=E(BD["@HO*BH*("H@)$AO<F1E.B!H;W)D92]L:6(O0FQO
M8VLO:69R86UE+G!H<"QV(#$N,3@N."XT(#(P,#8O,#(O,C$@,3`Z-3,Z-#4@
M:F%N($5X<"`D"B`J"B`J($!P86-K86=E($AO<F1E7T)L;V-K"B`J+PIC;&%S
M<R!(;W)D95]";&]C:U](;W)D95]I9G)A;64@97AT96YD<R!(;W)D95]";&]C
M:R!["@H@("`@=F%R("1?87!P(#T@)VAO<F1E)SL*"B`@("!F=6YC=&EO;B!?
M<&%R86US*"D*("`@('L*("`@("`@("!R971U<FX@87)R87DH)VEF<F%M92<@
M/3X@87)R87DH)W1Y<&4G(#T^("=T97AT)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^(%\H(E523"(I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5F875L="<@
M/3X@)R<I+`H@("`@("`@("`@("`@("`@("`@("`G=&ET;&4G("`]/B!A<G)A
M>2@G='EP92<@/3X@)W1E>'0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G;F%M92<@/3X@7R@B5&ET;&4B*2DL"B`@("`@("`@
M("`@("`@("`@("`@("=H96EG:'0G(#T^(&%R<F%Y*"=T>7!E)R`]/B`G:6YT
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYA
M;64G(#T^(%\H(DAE:6=H="(I*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4
M:&4@=&ET;&4@=&\@9V\@:6X@=&AI<R!B;&]C:RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@(%1H92!T:71L92!T97AT+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?=&ET;&4H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T
M<GD["@H@("`@("`@("1T:71L92`](&ES<V5T*"1T:&ES+3Y?<&%R86US6R=T
M:71L92==*0H@("`@("`@("`@("`_("1T:&ES+3Y?<&%R86US6R=T:71L92==
M"B`@("`@("`@("`@(#H@)'1H:7,M/E]P87)A;7-;)VEF<F%M92==.PH*("`@
M("`@("`D:'1M;"`]($AO<F1E.CIL:6YK*"1T:&ES+3Y?<&%R86US6R=I9G)A
M;64G72D@+B`D=&ET;&4@+@H@("`@("`@("`@("`G/"]A/B`Z.B`\<VUA;&P^
M)R`N"B`@("`@("`@("`@($AO<F1E.CIL:6YK*"1T:&ES+3Y?<&%R86US6R=I
M9G)A;64G72P@)R<L("<G+"`G7V)L86YK)RD@+@H@("`@("`@("`@("!(;W)D
M93HZ:6UG*"=W96)S:71E+G!N9R<L(%\H(D]P96X@:6X@82!N97<@=VEN9&]W
M(BDI("X@)R`G("X*("`@("`@("`@("`@7R@B3W!E;B!I;B!A(&YE=R!W:6YD
M;W<B*2`N("<\+V$^/"]S;6%L;#XG.PH*("`@("`@("!R971U<FX@)&AT;6P[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@8V]N=&5N="!T;R!G;R!I;B!T
M:&ES(&)L;V-K+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("`@5&AE
M(&-O;G1E;G0*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;G1E;G0H*0H@("`@
M>PH@("`@("`@(&=L;V)A;"`D8G)O=W-E<CL*"B`@("`@("`@:68@*"$D8G)O
M=W-E<BT^:&%S1F5A='5R92@G:69R86UE<R<I*2!["B`@("`@("`@("`@(')E
M='5R;B!?*")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E
M871U<F4N(BD["B`@("`@("`@?0H*("`@("`@("!I9B`H96UP='DH)'1H:7,M
M/E]P87)A;7-;)VAE:6=H="==*2D@>PH@("`@("`@("`@("!I9B`H)&)R;W=S
M97(M/FES0G)O=W-E<B@G;7-I92<I('Q\("1B<F]W<V5R+3YI<T)R;W=S97(H
M)VMO;G%U97)O<B<I*2!["B`@("`@("`@("`@("`@("`D:&5I9VAT(#T@)R<[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D:&5I9VAT
M(#T@)R!H96EG:'0](C$P,"4B)SL*("`@("`@("`@("`@?0H@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1H96EG:'0@/2`G(&AE:6=H=#TB)R`N(&AT
M;6QS<&5C:6%L8VAA<G,H)'1H:7,M/E]P87)A;7-;)VAE:6=H="==*2`N("<B
M)SL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("<\:69R86UE('-R8STB)R`N
M(&AT;6QS<&5C:6%L8VAA<G,H)'1H:7,M/E]P87)A;7-;)VEF<F%M92==*2`N
M("<B('=I9'1H/2(Q,#`E(B<@+B`D:&5I9VAT("X@)R!M87)G:6YH96EG:'0]
M(C`B('-C<F]L;&EN9STB875T;R(@9G)A;65B;W)D97(](C`B/CPO:69R86UE
M/B<["B`@("!]"@I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+T)L;V-K+VUE=&%R+G!H
M<```````````````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#0W
M,3,W(#$P-3$U-#,S-S,U(#`R,3$W-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`H*)&)L;V-K7VYA;64@/2!?*")-
M971A<B!796%T:&5R(BD["@HO*BH*("H@5&AE($AO<F1E7T)L;V-K7VUE=&%R
M(&-L87-S('!R;W9I9&5S(&%N(&%P<&QE="!F;W(@=&AE('!O<G1A;`H@*B!S
M8W)E96X@=&\@9&ES<&QA>2!-151!4B!W96%T:&5R(&1A=&$@9F]R(&$@<W!E
M8VEF:65D(&QO8V%T:6]N"B`J("AC=7)R96YT;'D@86ER<&]R=',I+@H@*@H@
M*B`D2&]R9&4Z(&AO<F1E+VQI8B]";&]C:R]M971A<BYP:'`L=B`Q+C(R+C$P
M+C8@,C`P-B\P-B\R,R`Q.3HS,3HR."!J86X@17AP("0*("H*("H@0'!A8VMA
M9V4@2&]R9&5?0FQO8VL*("HO"F-L87-S($AO<F1E7T)L;V-K7TAO<F1E7VUE
M=&%R(&5X=&5N9',@2&]R9&5?0FQO8VL@>PH*("`@('9A<B`D7V%P<"`]("=H
M;W)D92<["@H@("`@+RHJ"B`@("`@*B!4:&4@=&ET;&4@=&\@9V\@:6X@=&AI
M<R!B;&]C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@(%1H92!T
M:71L92!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=&ET;&4H*0H@("`@
M>PH@("`@("`@(')E='5R;B!?*")#=7)R96YT(%=E871H97(B*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!?<&%R86US*"D*("`@('L*("`@("`@("!I9B`H(4!I
M;F-L=61E7V]N8V4@)U-E<G9I8V5S+U=E871H97(N<&AP)RD@>PH@("`@("`@
M("`@("!(;W)D93HZ;&]G365S<V%G92@G5&AE(&UE=&%R(&)L;V-K('=I;&P@
M;F]T('=O<FL@=VET:&]U="!397)V:6-E<U]796%T:&5R(&9R;VT@4$5!4BX@
M4G5N('!E87(@:6YS=&%L;"!397)V:6-E<U]796%T:&5R+B<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!
M4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*`H@("`@("`@
M("`@("`@("`@)V5R<F]R)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@
M("`G='EP92<@/3X@)V5R<F]R)RP*("`@("`@("`@("`@("`@("`@("`G;F%M
M92<@/3X@7R@B17)R;W(B*2P*("`@("`@("`@("`@("`@("`@("`G9&5F875L
M="<@/3X@7R@B365T87(@8FQO8VL@;F]T(&%V86EL86)L92XB*0H@("`@("`@
M("`@("`@("`@*0H@("`@("`@("`@("`I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@("`@("\O($=E="!L
M;V-A=&EO;G,@9G)O;2!T:&4@9&%T86)A<V4N"B`@("`@("`@("`@(')E<75I
M<F5?;VYC92`G1$(N<&AP)SL*("`@("`@("`@("`@)&1B(#T@)D1".CIC;VYN
M96-T*"1C;VYF6R=S<6PG72D["B`@("`@("`@("`@(&EF("AI<U]A*"1D8BP@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1D8CL*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@4V5T($1"('!O<G1A8FEL
M:71Y(&]P=&EO;G,N"B`@("`@("`@("`@('-W:71C:"`H)&1B+3YP:'!T>7!E
M*2!["B`@("`@("`@("`@(&-A<V4@)VUS<W%L)SH*("`@("`@("`@("`@("`@
M("1D8BT^<V5T3W!T:6]N*"=P;W)T86)I;&ET>2<L($1"7U!/4E1!0DE,2519
M7TQ/5T520T%312!\($1"7U!/4E1!0DE,25197T524D]24R!\($1"7U!/4E1!
M0DE,25197U)44DE-*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@)&1B+3YS971/<'1I;VXH
M)W!O<G1A8FEL:71Y)RP@1$)?4$]25$%"24Q)5%E?3$]715)#05-%('P@1$)?
M4$]25$%"24Q)5%E?15)23U)3*3L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@)')E<W5L="`]("1D8BT^<75E<GDH)U-%3$5#5"!I8V%O+"!N86UE+"!C
M;W5N=')Y($923TT@;65T87)!:7)P;W)T<R!/4D1%4B!"62!C;W5N=')Y)RD[
M"B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`D;&]C871I;VYS(#T@87)R87DH*3L*("`@("`@
M("`@("`@=VAI;&4@*"1R;W<@/2`D<F5S=6QT+3YF971C:%)O=RA$0E]&151#
M2$U/1$5?05-33T,I*2!["B`@("`@("`@("`@("`@("`D;&]C871I;VYS6R1R
M;W=;)V-O=6YT<GDG75U;)')O=ULG:6-A;R==72`]("1R;W=;)VYA;64G73L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*`H@("`@
M("`@("`@("`@("`@)VQO8V%T:6]N)R`]/B!A<G)A>2@*("`@("`@("`@("`@
M("`@("`@("`G='EP92<@/3X@)VUL96YU;2<L"B`@("`@("`@("`@("`@("`@
M("`@)VYA;64G(#T^(%\H(DQO8V%T:6]N(BDL"B`@("`@("`@("`@("`@("`@
M("`@)V1E9F%U;'0G(#T^("=+4T9")RP*("`@("`@("`@("`@("`@("`@("`G
M=F%L=65S)R`]/B`D;&]C871I;VYS+`H@("`@("`@("`@("`@("`@*2P*("`@
M("`@("`@("`@("`@("=U;FET<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@
M("`@("`@)W1Y<&4G(#T^("=E;G5M)RP*("`@("`@("`@("`@("`@("`@("`G
M;F%M92<@/3X@7R@B56YI=',B*2P*("`@("`@("`@("`@("`@("`@("`G9&5F
M875L="<@/3X@)W,G+`H@("`@("`@("`@("`@("`@("`@("=V86QU97,G(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`G<R<@/3X@7R@B4W1A
M;F1A<F0B*2P*("`@("`@("`@("`@("`@("`@("`@("`@)VTG(#T^(%\H(DUE
M=')I8R(I"B`@("`@("`@("`@("`@("`@("`@*0H@("`@("`@("`@("`@("`@
M*2P*("`@("`@("`@("`@("`@("=K;F]T<R<@/3X@87)R87DH"B`@("`@("`@
M("`@("`@("`@("`@)W1Y<&4G(#T^("=C:&5C:V)O>"<L"B`@("`@("`@("`@
M("`@("`@("`@)VYA;64G(#T^(%\H(E=I;F0@<W!E960@:6X@:VYO=',B*2P*
M("`@("`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@,`H@("`@("`@("`@
M("`@("`@*2P*("`@("`@("`@("`@("`@("=T868G(#T^(&%R<F%Y*`H@("`@
M("`@("`@("`@("`@("`@("=T>7!E)R`]/B`G8VAE8VMB;W@G+`H@("`@("`@
M("`@("`@("`@("`@("=N86UE)R`]/B!?*")$:7-P;&%Y(&9O<F5C87-T("A4
M048I(BDL"B`@("`@("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^(#`*("`@
M("`@("`@("`@("`@("D*("`@("`@("`@("`@*3L*("`@("`@("!]"B`@("!]
M"@H@("`@9G5N8W1I;VX@7W)O=R@D;&%B96PL("1C;VYT96YT*0H@("`@>PH@
M("`@("`@(')E='5R;B`G/&)R("\^/'-T<F]N9SXG("X@)&QA8F5L("X@)SH\
M+W-T<F]N9SX@)R`N("1C;VYT96YT.PH@("`@?0H*("`@(&9U;F-T:6]N(%]S
M86UE4F]W*"1L86)E;"P@)&-O;G1E;G0I"B`@("!["B`@("`@("`@<F5T=7)N
M("<@/'-T<F]N9SXG("X@)&QA8F5L("X@)SH\+W-T<F]N9SX@)R`N("1C;VYT
M96YT.PH@("`@?0H*("`@("\J*@H@("`@("H@5&AE(&-O;G1E;G0@=&\@9V\@
M:6X@=&AI<R!B;&]C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M(%1H92!C;VYT96YT"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYT96YT*"D*
M("`@('L*("`@("`@("!I9B`H(4!I;F-L=61E7V]N8V4@)U-E<G9I8V5S+U=E
M871H97(N<&AP)RD@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G
M5&AE(&UE=&%R(&)L;V-K('=I;&P@;F]T('=O<FL@=VET:&]U="!397)V:6-E
M<U]796%T:&5R(&9R;VT@4$5!4BX@4G5N('!E87(@:6YS=&%L;"!397)V:6-E
M<U]796%T:&5R+B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@
M<F5T=7)N(%\H(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@
M:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(BD["B`@
M("`@("`@?0H*("`@("`@("!G;&]B86P@)&-O;F8["B`@("`@("`@<W1A=&EC
M("1M971A<DQO8W,["@H@("`@("`@(&EF("@A:7-S970H)&-O;F9;)W-Q;"==
M*2D@>PH@("`@("`@("`@("!R971U<FX@7R@B02!D871A8F%S92!B86-K96YD
M(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(I.PH@("`@("`@('T*"B`@
M("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%R86US6R=L;V-A=&EO;B==*2D@
M>PH@("`@("`@("`@("!R971U<FX@7R@B3F\@;&]C871I;VX@:7,@<V5T+B(I
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I<U]A<G)A>2@D;65T87),;V-S
M*2D@>PH@("`@("`@("`@("`D;65T87),;V-S(#T@)'1H:7,M/F=E=%!A<F%M
M<R@I.PH@("`@("`@('T*"B`@("`@("`@<F5Q=6ER95]O;F-E("=397)V:6-E
M<R]796%T:&5R+G!H<"<["B`@("`@("`@)&UE=&%R(#T@)E-E<G9I8V5S7U=E
M871H97(Z.G-E<G9I8V4H)TU%5$%2)RP@87)R87DH)V1E8G5G)R`]/B`P*2D[
M"B`@("`@("`@)&UE=&%R+3YS971-971A<D1"*"1C;VYF6R=S<6PG72D["B`@
M("`@("`@)&UE=&%R+3YS9715;FET<T9O<FUA="@D=&AI<RT^7W!A<F%M<ULG
M=6YI=',G72D["B`@("`@("`@)&UE=&%R+3YS971$871E5&EM949O<FUA="@G
M32!J+"!9)RP@)T@Z:2<I.PH@("`@("`@("1M971A<BT^<V5T365T87)3;W5R
M8V4H)VAT='`G*3L*"B`@("`@("`@)'5N:71S(#T@)&UE=&%R+3YG9715;FET
M<T9O<FUA="@D=&AI<RT^7W!A<F%M<ULG=6YI=',G72D["B`@("`@("`@)'=E
M871H97(@/2`D;65T87(M/F=E=%=E871H97(H)'1H:7,M/E]P87)A;7-;)VQO
M8V%T:6]N)UTI.PH*("`@("`@("`D:'1M;"`]("<\=&%B;&4@=VED=&@](C$P
M,"4B(&-E;&QS<&%C:6YG/2(P(CXG("X*("`@("`@("`@("`@)SQT<CX\=&0@
M8VQA<W,](F-O;G1R;VPB/CQS=')O;F<^)R`N"B`@("`@("`@("`@('-P<FEN
M=&8H)R5S+"`E<R`H)7,I)RP*("`@("`@("`@("`@("`@("`@("`D;65T87),
M;V-S6R=L;V-A=&EO;B==6R=V86QU97,G75LD=&AI<RT^7W!A<F%M<ULG7U]L
M;V-A=&EO;B==75LD=&AI<RT^7W!A<F%M<ULG;&]C871I;VXG75TL"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)U]?;&]C871I;VXG72P*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG;&]C871I;VXG
M72D@+@H@("`@("`@("`@("`G/"]S=')O;F<^/"]T9#X\+W1R/CPO=&%B;&4^
M/'-T<F]N9SXG("X@7R@B3&%S="!5<&1A=&5D.B(I("X@)SPO<W1R;VYG/B`G
M("X*("`@("`@("`@("`@)'=E871H97);)W5P9&%T92==("X@)SQB<B`O/CQB
M<B`O/B<["@H@("`@("`@("\O(%=I;F0N"B`@("`@("`@:68@*&ES<V5T*"1W
M96%T:&5R6R=W:6YD)UTI*2!["B`@("`@("`@("`@("1H=&UL("X]("<\<W1R
M;VYG/B<@+B!?*")7:6YD.B(I("X@)SPO<W1R;VYG/B`G.PH@("`@("`@("`@
M("!I9B`H)'=E871H97);)W=I;F1$:7)E8W1I;VXG72`]/2`G5F%R:6%B;&4G
M*2!["B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US
M6R=K;F]T<R==*2D@>PH@("`@("`@("`@("`@("`@("`@("1H=&UL("X]('-P
M<FEN=&8H7R@B)7,@870@)7,@)7,B*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@)'=E871H97);)W=I;F1$:7)E8W1I;VXG72P*("`@("`@("`@("`@("`@
M("`@("`@("`@<F]U;F0H)&UE=&%R+3YC;VYV97)T4W!E960H)'=E871H97);
M)W=I;F0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1U;FET<ULG
M=VEN9"==+"`G:W0G*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("=K="<I
M.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`D:'1M;"`N/2!S<')I;G1F*%\H(B5S(&%T("5S("5S(BDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("1W96%T:&5R6R=W:6YD1&ER96-T:6]N)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@(')O=6YD*"1W96%T:&5R6R=W:6YD)UTI
M+`H@("`@("`@("`@("`@("`@("`@("`@("`D=6YI='-;)W=I;F0G72D["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS96EF("@H)'=E871H
M97);)W=I;F1$96=R965S)UT@/3T@)S`P,"<I("8F"B`@("`@("`@("`@("`@
M("`@("`@("`@("@D=V5A=&AE<ELG=VEN9"==(#T]("<P)RDI('L*("`@("`@
M("`@("`@("`@("1H=&UL("X]('-P<FEN=&8H7R@B8V%L;2(I*3L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1H=&UL("X]('-P<FEN
M=&8H7R@B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<ELG=VEN9$1I<F5C=&EO
M;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=V5A=&AE
M<ELG=VEN9$1E9W)E97,G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@96UP='DH)'1H:7,M/E]P87)A;7-;)VMN;W1S)UTI(#\*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@<F]U;F0H)'=E871H97);)W=I
M;F0G72D@.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R;W5N
M9"@D;65T87(M/F-O;G9E<G13<&5E9"@D=V5A=&AE<ELG=VEN9"==+"`D=6YI
M='-;)W=I;F0G72P@)VMT)RDI+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!E;7!T>2@D=&AI<RT^7W!A<F%M<ULG:VYO=',G72D@/PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=6YI='-;)W=I;F0G72`Z
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=K="<I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D=V5A=&AE
M<ELG=VEN9$=U<W0G72DI('L*("`@("`@("`@("`@:68@*"1W96%T:&5R6R=W
M:6YD1W5S="==*2!["B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES
M+3Y?<&%R86US6R=K;F]T<R==*2D@>PH@("`@("`@("`@("`@("`@("`@("1H
M=&UL("X]('-P<FEN=&8H7R@B+"!G=7-T:6YG("5S("5S(BDL"B`@("`@("`@
M("`@("`@("`@("`@("`@(')O=6YD*"1M971A<BT^8V]N=F5R=%-P965D*"1W
M96%T:&5R6R=W:6YD1W5S="==+`H@("`@("`@("`@("`@("`@("`@("`@("`D
M=6YI='-;)W=I;F0G72P@)VMT)RDI+`H@("`@("`@("`@("`@("`@("`@("`@
M("`G:W0G*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@)&AT;6P@+CT@<W!R:6YT9BA?*"(L(&=U<W1I;F<@)7,@)7,B
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@<F]U;F0H)'=E871H97);)W=I
M;F1'=7-T)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("`D=6YI='-;)W=I
M;F0G72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@:68@*&ES<V5T*"1W96%T:&5R6R=W:6YD5F%R:6%B:6QI
M='DG72DI('L*("`@("`@("`@("`@:68@*"1W96%T:&5R6R=W:6YD5F%R:6%B
M:6QI='DG75LG9G)O;2==*2!["B`@("`@("`@("`@("`@("`D:'1M;"`N/2!S
M<')I;G1F*%\H(BP@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<R(I+`H@("`@("`@
M("`@("`@("`@("`@("1W96%T:&5R6R=W:6YD5F%R:6%B:6QI='DG75LG9G)O
M;2==+`H@("`@("`@("`@("`@("`@("`@("1W96%T:&5R6R=W:6YD5F%R:6%B
M:6QI='DG75LG=&\G72D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@("\O(%9I<VEB:6QI='DN"B`@("`@("`@:68@*&ES<V5T*"1W96%T:&5R
M6R=V:7-I8FEL:71Y)UTI*2!["B`@("`@("`@("`@("1H=&UL("X]("1T:&ES
M+3Y?<V%M95)O=RA?*")6:7-I8FEL:71Y(BDL("1W96%T:&5R6R=V:7-I8FEL
M:71Y)UT@+B`G("<@+B`D=6YI='-;)W9I<R==*3L*("`@("`@("!]"@H@("`@
M("`@("\O(%1E;7!E<F%T=7)E+T1E=U!O:6YT+@H@("`@("`@(&EF("AI<W-E
M="@D=V5A=&AE<ELG=&5M<&5R871U<F4G72DI('L*("`@("`@("`@("`@)&AT
M;6P@+CT@)'1H:7,M/E]R;W<H7R@B5&5M<&5R871U<F4B*2P@<F]U;F0H)'=E
M871H97);)W1E;7!E<F%T=7)E)UTI("X@)R9D96<[)R`N(%-T<FEN9SHZ=7!P
M97(H)'5N:71S6R=T96UP)UTI*3L*("`@("`@("!]"B`@("`@("`@:68@*&ES
M<V5T*"1W96%T:&5R6R=D97=0;VEN="==*2D@>PH@("`@("`@("`@("`D:'1M
M;"`N/2`D=&AI<RT^7W-A;652;W<H7R@B1&5W(%!O:6YT(BDL(')O=6YD*"1W
M96%T:&5R6R=D97=0;VEN="==*2`N("<F9&5G.R<@+B!3=')I;F<Z.G5P<&5R
M*"1U;FET<ULG=&5M<"==*2D["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E
M="@D=V5A=&AE<ELG9F5L=%1E;7!E<F%T=7)E)UTI*2!["B`@("`@("`@("`@
M("1H=&UL("X]("1T:&ES+3Y?<V%M95)O=RA?*")&965L<R!,:6ME(BDL(')O
M=6YD*"1W96%T:&5R6R=F96QT5&5M<&5R871U<F4G72D@+B`G)F1E9SLG("X@
M4W1R:6YG.CIU<'!E<B@D=6YI='-;)W1E;7`G72DI.PH@("`@("`@('T*"B`@
M("`@("`@+R\@4')E<W-U<F4N"B`@("`@("`@:68@*&ES<V5T*"1W96%T:&5R
M6R=P<F5S<W5R92==*2D@>PH@("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^
M7W)O=RA?*")0<F5S<W5R92(I+"`D=V5A=&AE<ELG<')E<W-U<F4G72`N("<@
M)R`N("1U;FET<ULG<')E<R==*3L*("`@("`@("!]"@H@("`@("`@("\O($AU
M;6ED:71Y+@H@("`@("`@(&EF("AI<W-E="@D=V5A=&AE<ELG:'5M:61I='DG
M72DI('L*("`@("`@("`@("`@)&AT;6P@+CT@)'1H:7,M/E]S86UE4F]W*%\H
M(DAU;6ED:71Y(BDL(')O=6YD*"1W96%T:&5R6R=H=6UI9&ET>2==*2`N("<E
M)RD["B`@("`@("`@?0H*("`@("`@("`O+R!#;&]U9',N"B`@("`@("`@:68@
M*&ES<V5T*"1W96%T:&5R6R=C;&]U9',G72DI('L*("`@("`@("`@("`@)&-L
M;W5D<R`]("<G.PH@("`@("`@("`@("!F;W)E86-H("@D=V5A=&AE<ELG8VQO
M=61S)UT@87,@)&-L;W5D*2!["B`@("`@("`@("`@("`@("`D8VQO=61S("X]
M("<\8G(@+SXG.PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1C;&]U9%LG
M:&5I9VAT)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)&-L;W5D<R`N/2!S
M<')I;G1F*%\H(B5S(&%T("5S("5S(BDL("1C;&]U9%LG86UO=6YT)UTL("1C
M;&]U9%LG:&5I9VAT)UTL("1U;FET<ULG:&5I9VAT)UTI.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D8VQO=61S("X]
M("1C;&]U9%LG86UO=6YT)UT["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)&AT;6P@+CT@)'1H:7,M/E]R;W<H7R@B0VQO
M=61S(BDL("1C;&]U9',I.PH@("`@("`@('T*"B`@("`@("`@+R\@0V]N9&ET
M:6]N<RX*("`@("`@("!I9B`H:7-S970H)'=E871H97);)V-O;F1I=&EO;B==
M*2D@>PH@("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7W)O=RA?*")#;VYD
M:71I;VYS(BDL("1W96%T:&5R6R=C;VYD:71I;VXG72D["B`@("`@("`@?0H*
M("`@("`@("`O+R!296UA<FMS+@H@("`@("`@(&EF("AI<W-E="@D=V5A=&AE
M<ELG<F5M87)K)UTI*2!["B`@("`@("`@("`@("1R96UA<FMS(#T@)R<["B`@
M("`@("`@("`@("1O=&AE<B`]("<G.PH@("`@("`@("`@("!F;W)E86-H("@D
M=V5A=&AE<ELG<F5M87)K)UT@87,@)')E;6%R:R`]/B`D=F%L=64I('L*("`@
M("`@("`@("`@("`@('-W:71C:"`H)')E;6%R:RD@>PH@("`@("`@("`@("`@
M("`@8V%S92`G<V5A<')E<W-U<F4G.@H@("`@("`@("`@("`@("`@("`@("1R
M96UA<FMS("X]("<\8G(@+SXG("X@7R@B4')E<W-U<F4@870@<V5A(&QE=F5L
M.B`B*2`N("1V86QU92`N("<@)R`N("1U;FET<ULG<')E<R==.PH@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)W!R
M96-I<&ET871I;VXG.@H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1V
M86QU92!A<R`D<')E8VEP*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("AI<U]N=6UE<FEC*"1P<F5C:7!;)V%M;W5N="==*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)')E;6%R:W,@+CT@)SQB<B`O/B<@+@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('-P<FEN=&8H7R@B4')E8VEP
M:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<F5C:7!;)VAO=7)S)UTI
M("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<')E8VEP6R=A
M;6]U;G0G72`N("<@)R`N("1U;FET<ULG<F%I;B==.PH@("`@("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)')E;6%R:W,@+CT@)SQB<B`O/B<@+@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('-P<FEN=&8H7R@B4')E8VEP:71A=&EO;B!F;W(@;&%S
M="`E<R!H;W5R*',I.B`B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1P<F5C:7!;)VAO=7)S)UTI("X@)'!R96-I<%LG86UO
M=6YT)UT["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("`@("`@8V%S92`G<VYO=V1E<'1H)SH*("`@("`@("`@("`@("`@("`@
M("`D<F5M87)K<R`N/2`G/&)R("\^)R`N(%\H(E-N;W<@9&5P=&@Z("(I("X@
M)'9A;'5E("X@)R`G("X@)'5N:71S6R=R86EN)UT["B`@("`@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G<VYO=V5Q=6EV
M)SH*("`@("`@("`@("`@("`@("`@("`D<F5M87)K<R`N/2`G/&)R("\^)R`N
M(%\H(E-N;W<@97%U:79A;&5N="!I;B!W871E<CH@(BD@+B`D=F%L=64@+B`G
M("<@+B`D=6YI='-;)W)A:6XG73L*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@("`@("!C87-E("=S=6YD=7)A=&EO;B<Z"B`@("`@
M("`@("`@("`@("`@("`@)')E;6%R:W,@+CT@)SQB<B`O/B<@+B!S<')I;G1F
M*%\H(B5S(&UI;G5T97,B*2P@)'9A;'5E*3L*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("<Q:'1E;7`G.@H@("`@
M("`@("`@("`@("`@("`@("1R96UA<FMS("X]("<\8G(@+SXG("X@7R@B5&5M
M<"!F;W(@;&%S="!H;W5R.B`B*2`N(')O=6YD*"1V86QU92D@+B`G)F1E9SLG
M("X@4W1R:6YG.CIU<'!E<B@D=6YI='-;)W1E;7`G72D["B`@("`@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G,6AD97<G
M.@H@("`@("`@("`@("`@("`@("`@("1R96UA<FMS("X]("<\8G(@+SXG("X@
M7R@B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(I("X@<F]U;F0H)'9A;'5E
M*2`N("<F9&5G.R<@+B!3=')I;F<Z.G5P<&5R*"1U;FET<ULG=&5M<"==*3L*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C
M87-E("<V:&UA>'1E;7`G.@H@("`@("`@("`@("`@("`@("`@("1R96UA<FMS
M("X]("<\8G(@+SXG("X@7R@B36%X('1E;7`@;&%S="`V(&AO=7)S.B`B*2`N
M(')O=6YD*"1V86QU92D@+B`G)F1E9SLG("X@4W1R:6YG.CIU<'!E<B@D=6YI
M='-;)W1E;7`G72D["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("`@("`@8V%S92`G-FAM:6YT96UP)SH*("`@("`@("`@("`@("`@
M("`@("`D<F5M87)K<R`N/2`G/&)R("\^)R`N(%\H(DUI;B!T96UP(&QA<W0@
M-B!H;W5R<SH@(BD@+B!R;W5N9"@D=F%L=64I("X@)R9D96<[)R`N(%-T<FEN
M9SHZ=7!P97(H)'5N:71S6R=T96UP)UTI.PH@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)S(T:&UA>'1E;7`G.@H@
M("`@("`@("`@("`@("`@("`@("1R96UA<FMS("X]("<\8G(@+SXG("X@7R@B
M36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(BD@+B!R;W5N9"@D=F%L=64I("X@
M)R9D96<[)R`N(%-T<FEN9SHZ=7!P97(H)'5N:71S6R=T96UP)UTI.PH@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@
M)S(T:&UI;G1E;7`G.@H@("`@("`@("`@("`@("`@("`@("1R96UA<FMS("X]
M("<\8G(@+SXG("X@7R@B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(BD@+B!R
M;W5N9"@D=F%L=64I("X@)R9D96<[)R`N(%-T<FEN9SHZ=7!P97(H)'5N:71S
M6R=T96UP)UTI.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@("`@(&-A<V4@)W-E;G-O<G,G.@H@("`@("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1V86QU92!A<R`D<V5N<V]R*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1R96UA<FMS("X]("<\8G(@+SXG("X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(%\H(E-E;G-O<CH@(BD@+B`D<V5N<V]R.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@("`@
M("1O=&AE<B`N/2`G/&)R("\^)R`N("1V86QU93L*("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@)&AT;6P@+CT@)'1H:7,M/E]R;W<H7R@B4F5M87)K<R(I
M+"`D<F5M87)K<R`N("1O=&AE<BD["B`@("`@("`@?0H*("`@("`@("`O+R!4
M048*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=T868G72DI
M('L*("`@("`@("`@("`@)'1A9B`]("1M971A<BT^9V5T1F]R96-A<W0H)'1H
M:7,M/E]P87)A;7-;)VQO8V%T:6]N)UTI.PH@("`@("`@("`@("!I9B`H(6ES
M7V$H)'1A9BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)&9O
M<F5C87-T(#T@)SQT86)L92!W:61T:#TB,3`P)2(@8V5L;'-P86-I;F<](C`B
M/B<["B`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@)SQT<CX\=&0@8VQA
M<W,](F-O;G1R;VPB(&-O;'-P86X](C(B/CQC96YT97(^/'-T<F]N9SXG("X@
M7R@B1F]R96-A<W0@*%1!1BDB*2`N("<\+W-T<F]N9SX\+W1D/CPO='(^/"]T
M86)L93XG.PH@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]("<\<W1R;VYG
M/E9A;&ED.B`\+W-T<F]N9SXG("X@)'1A9ELG=F%L:61&<F]M)UT@+B`G("T@
M)R`N("1T869;)W9A;&ED5&\G72`N("<\8G(@+SX\8G(@+SXG.PH@("`@("`@
M("`@("`@("`@)&ET96T@/2`P.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)'1A9ELG=&EM92==(&%S("1T:6UE(#T^("1E;G1R>2D@>PH@("`@("`@("`@
M("`@("`@("`@("1I=&5M*RL["B`@("`@("`@("`@("`@("`@("`@)&9O<F5C
M87-T("X]("<\=&%B;&4@=VED=&@](C$P,"4B(&-E;&QS<&%C:6YG/2(P(CXG
M.PH@("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2`G/'1R(&-L87-S
M/2)I=&5M)R`N("@D:71E;2`E(#(I("X@)R(^)SL*("`@("`@("`@("`@("`@
M("`@("`D9F]R96-A<W0@+CT@)SQT9"!A;&EG;CTB8V5N=&5R(B!W:61T:#TB
M-3`B/B<@+B`D=&EM92`N("<\+W1D/CQT9#X\<W1R;VYG/E=I;F0Z/"]S=')O
M;F<^("<["B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1E;G1R>5LG
M=VEN9"==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&5N=')Y
M6R=W:6YD1&ER96-T:6]N)UT@/3T@)U9A<FEA8FQE)RD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG
M:VYO=',G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M9F]R96-A<W0@+CT@<W!R:6YT9BA?*"(E<R!A="`E<R`E<R(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S=')T;VQO=V5R*"1E;G1R
M>5LG=VEN9$1I<F5C=&EO;B==*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<F]U;F0H)&UE=&%R+3YC;VYV97)T4W!E960H)&5N=')Y
M6R=W:6YD)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=6YI='-;)W=I;F0G72P@)VMT)RDI+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G:W0G*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&9O<F5C87-T("X]('-P<FEN=&8H7R@B)7,@870@)7,@)7,B*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5N=')Y6R=W
M:6YD1&ER96-T:6]N)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(')O=6YD*"1E;G1R>5LG=VEN9"==*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'5N:71S6R=W:6YD)UTI.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@
M("!](&5L<V5I9B`H*"1E;G1R>5LG=VEN9$1E9W)E97,G72`]/2`G,#`P)RD@
M)B8*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*"1E;G1R
M>5LG=VEN9"==(#T]("<P)RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1F;W)E8V%S="`N/2!S<')I;G1F*%\H(F-A;&TB*2D["B`@("`@("`@
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9F]R96-A<W0@+CT@<W!R:6YT9BA?*")F<F]M('1H92`E<R`H
M)7,I(&%T("5S("5S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1E;G1R>5LG=VEN9$1I<F5C=&EO;B==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D96YT
M<GE;)W=I;F1$96=R965S)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&5M<'1Y*"1T:&ES+3Y?<&%R86US6R=K;F]T
M<R==*2`_"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(')O=6YD*"1E;G1R>5LG=VEN9"==*2`Z"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')O=6YD*"1M971A<BT^
M8V]N=F5R=%-P965D*"1E;G1R>5LG=VEN9"==+"`D=6YI='-;)W=I;F0G72P@
M)VMT)RDI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!E;7!T>2@D=&AI<RT^7W!A<F%M<ULG:VYO=',G72D@/PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=6YI
M='-;)W=I;F0G72`Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=K="<I.PH@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2`G/&)R("\^
M)SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1E;G1R>5LG=&5M<&5R871U<F5,;W<G72D@?'P@:7-S970H
M)&5N=')Y6R=T96UP97)A='5R94AI9V@G72DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&9O<F5C87-T("X]("<\<W1R;VYG/E1E;7!E<F%T=7)E/"]S
M=')O;F<^)SL*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1E
M;G1R>5LG=&5M<&5R871U<F5,;W<G72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1F;W)E8V%S="`N/2`G/'-T<F]N9SX@3&]W.CPO<W1R;VYG
M/B<["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@
M)&5N=')Y6R=T96UP97)A='5R94QO=R==.PH@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D96YT
M<GE;)W1E;7!E<F%T=7)E2&EG:"==*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&9O<F5C87-T("X]("<\<W1R;VYG/B!(:6=H.CPO<W1R;VYG
M/B<["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@
M)&5N=')Y6R=T96UP97)A='5R94AI9V@G73L*("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@
M)SQB<B`O/B<["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D96YT<GE;)W=I;F1S:&5A<B==*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@)SQS=')O;F<^5VEN
M9'-H96%R.CPO<W1R;VYG/B<["B`@("`@("`@("`@("`@("`@("`@("`@("1F
M;W)E8V%S="`N/2!S<')I;G1F*%\H(F9R;VT@=&AE("5S("@E<RD@870@)7,@
M)7,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1E;G1R>5LG=VEN9'-H96%R1&ER96-T:6]N)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D96YT<GE;)W=I;F1S:&5A<D1E
M9W)E97,G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1E;G1R>5LG=VEN9'-H96%R2&5I9VAT)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=6YI='-;)VAE:6=H="==*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]("<\8G(@+SXG
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)&5N=')Y6R=V:7-I8FEL:71Y)UTI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1F;W)E8V%S="`N/2`G/'-T<F]N9SY6:7-I8FEL:71Y
M.CPO<W1R;VYG/B`G.PH@("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A
M<W0@+CT@<W1R=&]L;W=E<B@D96YT<GE;)W9I<U%U86QI9FEE<B==*2`N("<@
M)R`N("1E;G1R>5LG=FES:6)I;&ET>2==("X@)R`G("X@)'5N:71S6R=V:7,G
M73L*("`@("`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]("<\8G(@
M+SXG.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)&5N=')Y6R=C;VYD:71I;VXG72DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&9O<F5C87-T("X]("<\<W1R;VYG/D-O;F1I=&EO
M;G,Z/"]S=')O;F<^("<["B`@("`@("`@("`@("`@("`@("`@("`@("1F;W)E
M8V%S="`N/2`D96YT<GE;)V-O;F1I=&EO;B==.PH@("`@("`@("`@("`@("`@
M("`@("`@("`D9F]R96-A<W0@+CT@)SQB<B`O/B<["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2`G/'-T
M<F]N9SY#;&]U9',Z/"]S=')O;F<^("<["B`@("`@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)&5N=')Y6R=C;&]U9',G72!A<R`D8VQO=61S*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D8VQO=61S6R=T>7!E)UTI
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@
M)R`G("X@)&-L;W5D<ULG='EP92==.PH@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2`G("<@
M+B`D8VQO=61S6R=A;6]U;G0G73L*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1C;&]U9'-;)VAE:6=H="==*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&9O<F5C87-T("X]("<@870@)R`N("1C;&]U9'-;
M)VAE:6=H="==("X@)R`G("X@)'5N:71S6R=H96EG:'0G73L*("`@("`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1F;W)E8V%S="`N/2`G("<["B`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@)&9O<F5C87-T("X]("<\+W1D/CPO='(^)SL*("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)&5N=')Y6R=F;6,G72DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&ET96TK*SL*("`@("`@("`@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)&5N=')Y6R=F;6,G72!A<R`D9FUC16YT<GDI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2`G/'1R(&-L87-S
M/2)I=&5M)R`N("@D:71E;2`E(#(I("X@)R(^)SL*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1F;W)E8V%S="`N/2`G/'1D(&%L:6=N/2)C96YT97(B
M('=I9'1H/2(U,"(^)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F
M;W)E8V%S="`N/2`G*B`G("X@)&9M8T5N=')Y6R=F<F]M)UT@+B`G/&)R("\^
M("T@)R`N("1F;6-%;G1R>5LG=&\G72`N("<\+W1D/B<["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@)SQT9#XG.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]("<\<W1R;VYG/E1Y
M<&4Z(#PO<W1R;VYG/B<@+B`D9FUC16YT<GE;)W1Y<&4G73L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9FUC16YT<GE;)W!R;V)A
M8FEL:71Y)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&9O<F5C87-T("X]("<@/'-T<F]N9SX@4')O8CH@/"]S=')O;F<^)R`N("1F
M;6-%;G1R>5LG<')O8F%B:6QI='DG72`N("<E)SL*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D9FUC16YT<GE;)V-O;F1I=&EO;B==*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2`G(#QS=')O;F<^
M($-O;F1I=&EO;G,Z(#PO<W1R;VYG/B<@+B`D9FUC16YT<GE;)V-O;F1I=&EO
M;B==.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1F;6-%;G1R>5LG8VQO=61S
M)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O<F5C
M87-T("X]("<@/'-T<F]N9SY#;&]U9',Z/"]S=')O;F<^)SL*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D9FUC16YT<GE;)V-L
M;W5D<R==(&%S("1F;6-#;&]U9',I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1F;6-#;&]U9'-;)W1Y<&4G72DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F
M;W)E8V%S="`N/2`G("<@+B`D9FUC0VQO=61S6R=T>7!E)UT["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1F;6-#;&]U9'-;)VAE
M:6=H="==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&9O<F5C87-T("X]("<@)R`N("1F;6-#;&]U9'-;)V%M;W5N="==
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O
M<F5C87-T("X]("<@)R`N("1F;6-#;&]U9'-;)VAE:6=H="==.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]
M("<@)R`N("1U;FET<ULG:&5I9VAT)UT["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@)R`G("X@)&9M8T-L
M;W5D<ULG86UO=6YT)UT["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&9M8T5N=')Y6R=V:7-1=6%L:69I97(G
M72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A
M<W0@+CT@)R`\<W1R;VYG/E9I<VEB:6QI='DZ/"]S=')O;F<^("<["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]('-T<G1O
M;&]W97(H)&9M8T5N=')Y6R=V:7-1=6%L:69I97(G72D@+B`G("<["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]("1F;6-%
M;G1R>5LG=FES:6)I;&ET>2==("X@)R`G("X@)'5N:71S6R=V:7,G73L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1F;W)E8V%S="`N/2`G/"]T9#X\+W1R/B<["B`@("`@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]("<\
M+W1A8FQE/B<["@H@("`@("`@("`@("`@("`@)&AT;6P@+CT@)&9O<F5C87-T
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&AT
M;6P["B`@("!]"@I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B]";&]C:R]C;VQO<BYP:'``````````````````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,38V-2`Q,#4Q-30S,S<S-2`P,C$R,#``
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*"B\O(%1H:7,@8FQO8VL@:7,@86X@97AA;7!L92!A;F0@<')O8F%B;'D@
M;F]T('5S969U;"!T;R!U<V5R<RX*+R\@)&)L;V-K7VYA;64@/2!?*")#;VQO
M<B(I.PH*+RHJ"B`J("1(;W)D93H@:&]R9&4O;&EB+T)L;V-K+V-O;&]R+G!H
M<"QV(#$N,3(@,C`P-"\P-B\P,2`Q,#HP-3HS,2!J86X@17AP("0*("H*("H@
M0'!A8VMA9V4@2&]R9&5?0FQO8VL*("HO"F-L87-S($AO<F1E7T)L;V-K7TAO
M<F1E7V-O;&]R(&5X=&5N9',@2&]R9&5?0FQO8VL@>PH*("`@('9A<B`D7V%P
M<"`]("=H;W)D92<["@H@("`@9G5N8W1I;VX@7W!A<F%M<R@I"B`@("!["B`@
M("`@("`@<F5T=7)N(&%R<F%Y*"=T>7!E)R`]/B`G=&5X="<L"B`@("`@("`@
M("`@("`@("`@("`@("=N86UE)R`]/B!?*")#;VQO<B(I+`H@("`@("`@("`@
M("`@("`@("`@("`G9&5F875L="<@/3X@)R-F9C`P,#`G*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%1H92!T:71L92!T;R!G;R!I;B!T:&ES(&)L;V-K+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("`@5&AE('1I=&QE('1E>'0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]T:71L92@I"B`@("!["B`@("`@("`@
M<F5T=7)N(%\H(D-O;&]R(BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@
M8V]N=&5N="!T;R!G;R!I;B!T:&ES(&)L;V-K+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("`@5&AE(&-O;G1E;G0*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V-O;G1E;G0H*0H@("`@>PH@("`@("`@("1H=&UL("`]("<\=&%B;&4@
M=VED=&@](C$P,"(@:&5I9VAT/2(Q,#`B(&)G8V]L;W(](B5S(CXG.PH@("`@
M("`@("1H=&UL("X]("<\='(^/'1D/B9N8G-P.SPO=&0^/"]T<CXG.PH@("`@
M("`@("1H=&UL("X]("<\+W1A8FQE/B<["@H@("`@("`@(')E='5R;B!S<')I
M;G1F*"1H=&UL+"`D=&AI<RT^7W!A<F%M<ULG8V]L;W(G72D["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D90``````````````````````````````````
M```````````````````````````````````````````````````````P,#`W
M-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<T,"`P
M,3<R-C4`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TUO8FEL90``
M````````````````````````````````````````````````````````````
M`````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M,#`P(#$P-3$U-#,S-S,U(#`R,#4P,``@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O36]B:6QE+U)E;F1E<F5R````````````````````````````
M````````````````````````````````````````,#`P-S4U(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S4@,#(R,C0V`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-;V)I;&4O4F5N9&5R97(O:'1M
M;"YP:'``````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R-C0W,"`Q,#4Q-30S
M,S<S-2`P,C0P,3,`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J($AO<F1E7TUO8FEL95]296YD97)E<CHZ
M(&]U='!U="!M;V1U;&4@9F]R('-I;7!L92!(5$U,(&%N9`H@*B!);6]D92]!
M=F%N=&=O+W-I;6EL87(@9&5V:6-E<RX*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO36]B:6QE+TUO8FEL92]296YD97)E<B]H=&UL+G!H<"QV(#$N,C@N,3`N
M-B`R,#`V+S`Q+S`Q(#(Q.C(X.C(V(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`
M<&%C:V%G92!(;W)D95]-;V)I;&4*("HO"F-L87-S($AO<F1E7TUO8FEL95]2
M96YD97)E<E]H=&UL(&5X=&5N9',@2&]R9&5?36]B:6QE7U)E;F1E<F5R('L*
M"B`@("`O*BH*("`@("`J(%!R;W!E<FQY(&5N8V]D92!C:&%R86-T97)S(&9O
M<B!O=71P=70@=&\@86X@2%1-3"!B<F]W<V5R+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&EN<'5T("!#:&%R86-T97)S('1O(&5N8V]D92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&5N8V]D960@=&5X="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@97-C87!E*"1I;G!U="D*("`@('L*("`@
M("`@("!R971U<FX@0&AT;6QS<&5C:6%L8VAA<G,H)&EN<'5T+"!%3E1?0T]-
M4$%4+"!.3%,Z.F=E=$-H87)S970H*2D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#<F5A=&5S('1H92!P86=E(&EN('1H92!A<'!R;W!R:6%T92!M87)K=7`N
M($1E<&5N9&EN9R!O;B!T:&4*("`@("`J(&-L:65N=',@8G)O=W-E<B!T>7!E
M('!U<F4@2%1-3"P@:&%N9&AE;&1F<FEE;F1L>2!!=F%N=$=O($A434PL"B`@
M("`@*B!I+6UO9&4@8TA434PL(&]R($U-3"!I<R!C<F5A=&5D+@H@("`@("H*
M("`@("`J($!P87)A;2!(;W)D95]-;V)I;&4@)&1E8VL@(%1H92!D96-K('1O
M(')E;F1E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R*"8D9&5C:RD*
M("`@('L*("`@("`@("!I9B`H)&1E8VLM/E]D96)U9RD@>PH@("`@("`@("`@
M("!H96%D97(H)T-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#TG
M("X@3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(&AE861E<B@G0V]N=&5N="U4>7!E.B!T97AT+VAT;6P[(&-H87)S
M970])R`N($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@("`@("!]"B`@("`@("`@
M:&5A9&5R*"=687)Y.B!!8V-E<'0M3&%N9W5A9V4G*3L*"B`@("`@("`@:68@
M*"$D=&AI<RT^:7-"<F]W<V5R*"=M;6PG*2D@>PH@("`@("`@("`@("!E8VAO
M("(\(41/0U194$4@:'1M;"!054),24,@7"(M+R]7,T,O+T141"!(5$U,(#0N
M,"!4<F%N<VET:6]N86PO+T5.7"(^7&XB.PH@("`@("`@('T*"B`@("`@("`@
M96-H;R`A96UP='DH)$=,3T)!3%-;)VQA;F=U86=E)UTI(#\@)SQH=&UL(&QA
M;F<](B<@+B!S=')T<B@D1TQ/0D%,4ULG;&%N9W5A9V4G72P@)U\G+"`G+2<I
M("X@)R(^)R`Z("<\:'1M;#XG.PH@("`@("`@(&5C:&\@)SQH96%D/B<["@H@
M("`@("`@(&EF("@D=&AI<RT^:7-"<F]W<V5R*"=A=F%N=&=O)RDI('L*("`@
M("`@("`@("`@96-H;R`G/&UE=&$@;F%M93TB2&%N9&AE;&1&<FEE;F1L>2(@
M8V]N=&5N=#TB5')U92(^)SL*("`@("`@("!]"@H@("`@("`@('!R:6YT9B@B
M/'1I=&QE/B5S/"]T:71L93Y<;B(L("1T:&ES+3YE<V-A<&4H)&1E8VLM/F=E
M="@G=&ET;&4G*2DI.PH*("`@("`@("!I9B`H)&1E8VLM/E]S:6UU;&%T;W(I
M('L*("`@("`@("`@("`@+R\@57-E('-I;75L871O<B`H;6]B:6QE('1H96UE
M*2!S='EL97-H965T+@H@("`@("`@("`@("!E8VAO($AO<F1E.CIS='EL97-H
M965T3&EN:R@G:&]R9&4G+"`G;6]B:6QE)RD["B`@("`@("`@?0H*("`@("`@
M("!E8VAO("<\+VAE860^/&)O9'D^)SL*"B`@("`@("`@:68@*"1D96-K+3Y?
M<VEM=6QA=&]R*2!["B`@("`@("`@("`@(&5C:&\@(CQC96YT97(^/&)R("\^
M7&XB.PH@("`@("`@("`@("`O+R!#<F5A=&4@9&5F875L="!D979I8V4@<VEM
M=6QA=&]R('1A8FQE(&QA>6]U="!W:71H"B`@("`@("`@("`@("\O(&-E;G1R
M86P@0U-3(&QA>6]U="X*("`@("`@("`@("`@96-H;R`B/'1A8FQE(&)O<F1E
M<CU<(C!<(B!C96QL<&%D9&EN9SU<(C!<(B!C96QL<W!A8VEN9SU<(C!<(CY<
M;B(["B`@("`@("`@("`@(&5C:&\@(CQT<CX\=&0@8V]L<W!A;CU<(C-<(B!C
M;&%S<SU<(G1O<%PB/B9N8G-P.SPO=&0^/"]T<CY<;B(["B`@("`@("`@("`@
M(&5C:&\@(CQT<CX\=&0@=F%L:6=N/5PB=&]P7"(@8VQA<W,]7")L969T7"(^
M)FYB<W`[/"]T9#Y<;B(["B`@("`@("`@("`@(&5C:&\@(CQT9"!V86QI9VX]
M7")T;W!<(B!C;&%S<SU<(F1I<W!L87E<(CY<;B(["B`@("`@("`@?0H*("`@
M("`@("`D9&EV<W1Y;&4@/2`G)SL*("`@("`@("!I9B`H)'1H:7,M/FAA<U%U
M:7)K*"=S8W)O;&Q?=&1S)RD@)B8@)&1E8VLM/E]S:6UU;&%T;W(I('L*("`@
M("`@("`@("`@+R\@36%K92!C;VYT96YT(&]F('1A8FQE(&5L96UE;G0@<V-R
M;VQL86)L92`H2&]R9&5?36]B:6QE"B`@("`@("`@("`@("\O('-I;75L871O
M<BDN"B`@("`@("`@("`@("1D:79S='EL92`]("<@8VQA<W,](G-I;61E=B(G
M.PH@("`@("`@('T*("`@("`@("!E8VAO("<\9&EV)R`N("1D:79S='EL92`N
M("<^)SL*"B`@("`@("`@:68@*"@D8VYT(#T@8V]U;G0H)&1E8VLM/E]C87)D
M<RDI("$]/2`P*2!["B`@("`@("`@("`@("1I(#T@,#L*("`@("`@("`@("`@
M9F]R96%C:"`H)&1E8VLM/E]C87)D<R!A<R`D8V%R9"D@>PH@("`@("`@("`@
M("`@("`@:68@*"1I("$](#`I('L*("`@("`@("`@("`@("`@("`@("!E8VAO
M("<\:'(@+SXG.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M)'1H:7,M/E]R96YD97)#87)D*"1C87)D*3L*("`@("`@("`@("`@("`@("1I
M*RL["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!F;W)E86-H("@D9&5C:RT^7V5L96UE;G1S(&%S("1P86=E7V5L96UE;G0I
M('L*("`@("`@("`@("`@("`@("1T:&ES+3YR96YD97)%;&5M96YT*"1P86=E
M7V5L96UE;G0I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!E
M8VAO("<\+V1I=CXG.PH*("`@("`@("!I9B`H)&1E8VLM/E]S:6UU;&%T;W(I
M('L*("`@("`@("`@("`@+R\@1&ES<&QA>2!L;W=E<B!P87)T(&]F($AO<F1E
M7TUO8FEL92!D969A=6QT(&1E=FEC90H@("`@("`@("`@("`O+R!S:6UU;&%T
M;W(N"B`@("`@("`@("`@(&5C:&\@)SPO=&0^/'1D('9A;&EG;CTB=&]P(B!C
M;&%S<STB<FEG:'0B/B9N8G-P.SPO=&0^/"]T<CX\='(^/'1D(&-O;'-P86X]
M(C,B(&-L87-S/2)B;W1T;VTB/B9N8G-P.SPO=&0^/"]T<CX\+W1A8FQE/CPO
M8V5N=&5R/B<["B`@("`@("`@?0H*("`@("`@("!E8VAO("<\+V)O9'D^/"]H
M=&UL/B<["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<D-A<F0H)B1C87)D
M*0H@("`@>PH@("`@("`@("1N86UE(#T@)&-A<F0M/F=E="@G;F%M92<I(#\@
M)R!N86UE/2(G("X@)'1H:7,M/F5S8V%P92@D8V%R9"T^9V5T*"=N86UE)RDI
M("X@)R(G(#H@)R<["B`@("`@("`@<')I;G1F*"<\825S/B5S/"]A/B<L("1N
M86UE+"`D8V%R9"T^9V5T*"=T:71L92<I*3L*"B`@("`@("`@:68@*&-O=6YT
M*"1C87)D+3Y?<V]F=&ME>7,I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1C
M87)D+3Y?<V]F=&ME>7,@87,@)&ME>2D@>PH@("`@("`@("`@("`@("`@96-H
M;R`G('P@/&$@:')E9CTB)R`N("1K97E;)W5R;"==("X@)R(^)R`N("`D=&AI
M<RT^97-C87!E*"1K97E;)VQA8F5L)UTI("X@)SPO83XG.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("`O+R!296YD97(@86QL('1A9W,N"B`@
M("`@("`@9F]R96%C:"`H)&-A<F0M/E]E;&5M96YT<R!A<R`D<&%G95]E;&5M
M96YT*2!["B`@("`@("`@("`@("1T:&ES+3YR96YD97)%;&5M96YT*"1P86=E
M7V5L96UE;G0I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N
M9&5R3&EN:R@F)&QI;FLI"B`@("!["B`@("`@("`@:68@*"1L:6YK+3YG970H
M)W1I=&QE)RD@)B8*("`@("`@("`@("`@(21T:&ES+3YI<T)R;W=S97(H)V%V
M86YT9V\G*2`F)@H@("`@("`@("`@("`A)'1H:7,M/FES0G)O=W-E<B@G:6UO
M9&4G*2`F)@H@("`@("`@("`@("`A)'1H:7,M/FES0G)O=W-E<B@G;6UL)RDI
M('L*("`@("`@("`@("`@)'1I=&QE7V]P=&EO;B`]('-P<FEN=&8H)R!O;FUO
M=7-E;W9E<CTB<V5L9BYS=&%T=7,]7"<E<UPG.W)E='5R;B!T<G5E.R(G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^97-C
M87!E*"1L:6YK+3YG970H)W1I=&QE)RDI*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D=&ET;&5?;W!T:6]N(#T@)R<["B`@("`@("`@?0H*("`@
M("`@("`D86-C97-S:V5Y7V]P=&EO;B`]("<G.PH@("`@("`@(&EF("@D;&EN
M:RT^9V5T*"=A8V-E<W-K97DG*2D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M
M/FES0G)O=W-E<B@G:6UO9&4G*2D@>PH@("`@("`@("`@("`@("`@)&%C8V5S
M<VME>5]O<'1I;VX@/2!S<')I;G1F*"<@86-C97-S:V5Y/2(E9"(G+"`D;&EN
M:RT^9V5T*"=A8V-E<W-K97DG*2D["B`@("`@("`@("`@('T@96QS96EF("@D
M=&AI<RT^:7-"<F]W<V5R*"=M;6PG*2D@>PH@("`@("`@("`@("`@("`@)&%C
M8V5S<VME>5]O<'1I;VX@/2!S<')I;G1F*"<@9&ER96-T:V5Y/2(E9"(G+"`D
M;&EN:RT^9V5T*"=A8V-E<W-K97DG*2D["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@('!R:6YT9B@G/&$@:')E9CTB)7,B)7,E<SXE<SPO83XG
M+`H@("`@("`@("`@("`@("!S=')?<F5P;&%C92@G)F%M<#MA;7`[)RP@)R9A
M;7`[)RP@)'1H:7,M/F5S8V%P92@D;&EN:RT^9V5T*"=U<FPG*2DI+`H@("`@
M("`@("`@("`@("`D=&ET;&5?;W!T:6]N+"`D86-C97-S:V5Y7V]P=&EO;BP*
M("`@("`@("`@("`@("`@)'1H:7,M/F5S8V%P92@D;&EN:RT^9V5T*"=L86)E
M;"<I*2D["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<DQI;FMS970H)B1L
M:6YK<V5T*0H@("`@>PH@("`@("`@(&EF("AC;W5N="@D;&EN:W-E="T^7V5L
M96UE;G1S*2D@>PH@("`@("`@("`@("!E8VAO("<\;VP^)SL*("`@("`@("`@
M("`@9F]R96%C:"`H)&QI;FMS970M/E]E;&5M96YT<R!A<R`D=F%L*2!["B`@
M("`@("`@("`@("`@("!E8VAO("<\;&D^)SL*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<F5N9&5R3&EN:R@D=F%L*3L*("`@("`@("`@("`@("`@(&5C:&\@
M)SPO;&D^)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E8VAO("<\+V]L
M/B<["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)497AT
M*"8D96QE;65N="D*("`@('L*("`@("`@("!F;W)E86-H("@D96QE;65N="T^
M7V%T=')I8G5T97,@87,@)&%T=')I8G5T92D@>PH@("`@("`@("`@("!E8VAO
M("<\)R`N("1A='1R:6)U=&4@+B`G/B<["B`@("`@("`@?0H*("`@("`@("!I
M9B`H)&5L96UE;G0M/F=E="@G;&EN96)R96%K<R<I*2!["B`@("`@("`@("`@
M(&5C:&\@;FPR8G(H)'1H:7,M/F5S8V%P92@D96QE;65N="T^9V5T*"=T97AT
M)RDI*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!E8VAO("1T:&ES
M+3YE<V-A<&4H)&5L96UE;G0M/F=E="@G=&5X="<I*3L*("`@("`@("!]"@H@
M("`@("`@("1A='1R:6)U=&5S(#T@87)R87E?<F5V97)S92@D96QE;65N="T^
M7V%T=')I8G5T97,I.PH@("`@("`@(&9O<F5A8V@@*"1A='1R:6)U=&5S(&%S
M("1A='1R:6)U=&4I('L*("`@("`@("`@("`@96-H;R`G/"\G("X@)&%T=')I
M8G5T92`N("<^)SL*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@7W)E
M;F1E<DEM86=E*"8D:6UA9V4I"B`@("!["B`@("`@("`@)&%T=')I8G5T97,@
M/2`G)SL*("`@("`@("!F;W)E86-H("@D:6UA9V4M/E]A='1R:6)U=&5S(&%S
M("1A='1R:6)U=&4@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("1A='1R:6)U
M=&5S("X]('-P<FEN=&8H)R`E<STB)7,B)RP@)&%T=')I8G5T92P@)'9A;'5E
M*3L*("`@("`@("!]"B`@("`@("`@<')I;G1F*"<\:6UG('-R8STB)7,N<&YG
M(B5S("\^)RP@)&EM86=E+3Y?<W)C+"`D871T<FEB=71E<RD["B`@("!]"@H@
M("`@9G5N8W1I;VX@7W)E;F1E<D9O<FTH)B1F;W)M*0H@("`@>PH@("`@("`@
M('!R:6YT9B@G/&9O<FT@86-T:6]N/2(E<R(@;65T:&]D/2(E<R(^)RP@)&9O
M<FTM/F=E="@G=7)L)RDL("1F;W)M+3YG970H)VUE=&AO9"<I*3L*("`@("`@
M("!P87)E;G0Z.E]R96YD97)&;W)M*"1F;W)M*3L*("`@("`@("!E8VAO("<\
M+V9O<FT^)SL*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R26YP=70H)B1I
M;G!U="D*("`@('L*("`@("`@("`D='EP92`]("=T>7!E/2(G("X@)&EN<'5T
M+3YG970H)W1Y<&4G*2`N("<B)SL*("`@("`@("`D<VEZ92`]("1I;G!U="T^
M9V5T*"=S:7IE)RD@/R!S<')I;G1F*"=S:7IE/2(E9"(G+"`D:6YP=70M/F=E
M="@G<VEZ92<I*2`Z("<G.PH@("`@("`@("1M87AL96YG=&@@/2`D:6YP=70M
M/F=E="@G;6%X;&5N9W1H)RD@/R!S<')I;G1F*"=M87AL96YG=&@](B5D(B<L
M("1I;G!U="T^9V5T*"=M87AL96YG=&@G*2D@.B`G)SL*"B`@("`@("`@:68@
M*"1T:&ES+3YI<T)R;W=S97(H)VEM;V1E)RDI('L*("`@("`@("`@("`@)&UO
M9&4@/2!S<')I;G1F*"<@:7-T>6QE/2(E9"(G+"`D:6YP=70M/F=E="@G;6]D
M92<I*3L*("`@("`@("!](&5L<V5I9B`H)'1H:7,M/FES0G)O=W-E<B@G;6UL
M)RDI('L*("`@("`@("`@("`@)&UO9&4@/2`D=&AI<RT^7V=E=$UO9&4H)&EN
M<'5T+3YG970H)VUO9&4G*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&UO9&4@/2`G)SL*("`@("`@("!]"@H@("`@("`@("\O($-R96%T92!(
M5$U,(&EN<'5T+@H@("`@("`@('!R:6YT9B@G)7,@/&EN<'5T("5S(&YA;64]
M(B5S(B!V86QU93TB)7,B)7,E<R5S+SXG+`H@("`@("`@("`@("`@("`D=&AI
M<RT^97-C87!E*"1I;G!U="T^9V5T*"=L86)E;"<I*2P@)'1Y<&4L"B`@("`@
M("`@("`@("`@("1T:&ES+3YE<V-A<&4H)&EN<'5T+3YG970H)VYA;64G*2DL
M("1T:&ES+3YE<V-A<&4H)&EN<'5T+3YG970H)W9A;'5E)RDI+"`D<VEZ92P@
M)&UA>&QE;F=T:"P@)&UO9&4I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD
M97)497AT87)E82@F)'1E>'1A<F5A*0H@("`@>PH@("`@("`@(&EF("@D=&AI
M<RT^:7-"<F]W<V5R*"=I;6]D92<I*2!["B`@("`@("`@("`@("1M;V1E(#T@
M<W!R:6YT9B@G(&ES='EL93TB)60B)RP@)'1H:7,M/FUO9&4I.PH@("`@("`@
M('T@96QS96EF("@D=&AI<RT^:7-"<F]W<V5R*"=M;6PG*2D@>PH@("`@("`@
M("`@("`D;6]D92`]("1T:&ES+3Y?9V5T36]D92@D=&AI<RT^;6]D92D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&UO9&4@/2`G)SL*("`@("`@
M("!]"@H@("`@("`@("1W<F%P(#T@)R<["B`@("`@("`@:68@*"$D=&AI<RT^
M:7-"<F]W<V5R*"=I;6]D92<I("8F("$D=&AI<RT^:7-"<F]W<V5R*"=M;6PG
M*2D@>PH@("`@("`@("`@("`D=W)A<"`]("<@=W)A<#TB=FER='5A;"(G.PH@
M("`@("`@('T*"B`@("`@("`@<')I;G1F*"<E<SQB<B`O/CQT97AT87)E82!N
M86UE/2(E<R(@<F]W<STB)7,B(&-O;',](B5S(B5S)7,^)7,\+W1E>'1A<F5A
M/B<L"B`@("`@("`@("`@("`@("1T:&ES+3YE<V-A<&4H)'1E>'1A<F5A+3YG
M970H)VQA8F5L)RDI+"`D=&5X=&%R96$M/F=E="@G;F%M92<I+"`D=&5X=&%R
M96$M/F=E="@G<F]W<R<I+`H@("`@("`@("`@("`@("`D=&5X=&%R96$M/F=E
M="@G8V]L<R<I+"`D;6]D92P@)'=R87`L("1T97AT87)E82T^9V5T*"=V86QU
M92<I*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R4V5L96-T*"8D<V5L
M96-T*0H@("`@>PH@("`@("`@(&5C:&\@)SQS96QE8W0@;F%M93TB)R`N("1S
M96QE8W0M/F=E="@G;F%M92<I("X@)R(@<VEZ93TB,2(^)SL*("`@("`@("!F
M;W)E86-H("@D<V5L96-T+3Y?;W!T:6]N<R!A<R`D=F%L*2!["B`@("`@("`@
M("`@(&EF("@D=F%L6R=V86QU92==(#T]("1S96QE8W0M/E]V86QU92D@>PH@
M("`@("`@("`@("`@("`@)'-E;"`]("<@<V5L96-T960](G-E;&5C=&5D(B<[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<V5L(#T@
M)R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@96-H;R`G/&]P=&EO;B<@
M+B`D<V5L("X@)R!V86QU93TB)R`N("1V86Q;)W9A;'5E)UT@+B`G(CXG("X@
M)'1H:7,M/F5S8V%P92@D=F%L6R=L86)E;"==*2`N("<\+V]P=&EO;CXG.PH@
M("`@("`@('T*("`@("`@("!E8VAO("<\+W-E;&5C=#XG.PH@("`@?0H*("`@
M(&9U;F-T:6]N(%]R96YD97)2861I;R@F)')A9&EO*0H@("`@>PH@("`@("`@
M(&9O<F5A8V@@*"1R861I;RT^7V)U='1O;G,@87,@)'9A;"D@>PH@("`@("`@
M("`@("`D<V5L(#T@*"1V86Q;)W9A;'5E)UT@/3T@)')A9&EO+3Y?=F%L=64I
M(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@.B`G)SL*("`@("`@("`@("`@<')I
M;G1F*"<\:6YP=70@='EP93TB<F%D:6\B(&YA;64](B5S(B5S('9A;'5E/2(E
M<R(@+SX@)7,\8G(@+SXG+`H@("`@("`@("`@("`@("`@("`@)')A9&EO+3YG
M970H)VYA;64G*2P@)'-E;"P@)'9A;%LG=F%L=64G72P*("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YE<V-A<&4H)'9A;%LG;&%B96PG72DI.PH@("`@("`@
M('T*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R0VAE8VMB;W@H)B1C:&5C
M:V)O>"D*("`@('L*("`@("`@("`D<W1A=&4@/2`D8VAE8VMB;W@M/FES0VAE
M8VME9"@I(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@.B`G)SL*("`@("`@("!P
M<FEN=&8H)SQI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB)7,B)7,@=F%L
M=64](B5S(B`O/B`E<SQB<B`O/B<L"B`@("`@("`@("`@("`@("1C:&5C:V)O
M>"T^9V5T*"=N86UE)RDL("1S=&%T92P@)&-H96-K8F]X+3YG970H)W9A;'5E
M)RDL"B`@("`@("`@("`@("`@("1T:&ES+3YE<V-A<&4H)&-H96-K8F]X+3YG
M970H)VQA8F5L)RDI*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R4W5B
M;6ET*"8D<W5B;6ET*0H@("`@>PH@("`@("`@("1N86UE(#T@(65M<'1Y*"1S
M=6)M:70M/E]N86UE*2`_("<@;F%M93TB)R`N("1S=6)M:70M/E]N86UE("X@
M)R(G(#H@)R<["B`@("`@("`@<')I;G1F*"<\:6YP=70@='EP93TB<W5B;6ET
M(B5S('9A;'5E/2(E<R(@+SX\8G(@+SXG+`H@("`@("`@("`@("`@("`D;F%M
M92P@)'1H:7,M/F5S8V%P92@D<W5B;6ET+3Y?;&%B96PI*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!?<F5N9&5R2&ED9&5N*"8D:&ED9&5N*0H@("`@>PH@("`@
M("`@('!R:6YT9B@G/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB)7,B('9A
M;'5E/2(E<R(@+SXG+`H@("`@("`@("`@("`@("`D:&ED9&5N+3YG970H)VYA
M;64G*2P@)&AI9&1E;BT^9V5T*"=V86QU92<I*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!?<F5N9&5R5&%B;&4H)B1T86)L92D*("`@('L*("`@("`@("`D8F]R
M9&5R(#T@)'1A8FQE+3YG970H)V)O<F1E<B<I.PH@("`@("`@("1P861D:6YG
M(#T@)'1A8FQE+3YG970H)W!A9&1I;F<G*3L*("`@("`@("`D<W!A8VEN9R`]
M("1T86)L92T^9V5T*"=S<&%C:6YG)RD["@H@("`@("`@(&5C:&\@)SQT86)L
M92<["B`@("`@("`@:68@*"%I<U]N=6QL*"1B;W)D97(I*2!["B`@("`@("`@
M("`@(&5C:&\@)R!B;W)D97(](B<@+B`D8F]R9&5R("X@)R(G.PH@("`@("`@
M('T*("`@("`@("!I9B`H(6ES7VYU;&PH)'!A9&1I;F<I*2!["B`@("`@("`@
M("`@(&5C:&\@)R!C96QL<&%D9&EN9STB)R`N("1P861D:6YG("X@)R(G.PH@
M("`@("`@('T*("`@("`@("!I9B`H(6ES7VYU;&PH)'-P86-I;F<I*2!["B`@
M("`@("`@("`@(&5C:&\@)R!C96QL<W!A8VEN9STB)R`N("1S<&%C:6YG("X@
M)R(G.PH@("`@("`@('T*("`@("`@("!E8VAO("<^)SL*"B`@("`@("`@<&%R
M96YT.CI?<F5N9&5R5&%B;&4H)'1A8FQE*3L*"B`@("`@("`@+R\@5&5R;6EN
M871E('1A8FQE+@H@("`@("`@(&EF("@D=&AI<RT^:7-"<F]W<V5R*"=M;6PG
M*2D@>PH@("`@("`@("`@("!E8VAO("<\+W1A8FQE/CQB<B`O/B<["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@34U,(&AA<R!P<F]B;&5M<R!W
M:71H('1H92!C;&5A<B!A='1R:6)U=&4N"B`@("`@("`@("`@(&5C:&\@)SPO
M=&%B;&4^/&)R(&-L96%R/2)A;&PB/B<["B`@("`@("`@?0H@("`@?0H*("`@
M(&9U;F-T:6]N(%]R96YD97)0:&]N92@F)'!H;VYE*0H@("`@>PH@("`@("`@
M(&EF("@D=&AI<RT^:7-"<F]W<V5R*"=I;6]D92<I*2!["B`@("`@("`@("`@
M("\O($-R96%T92!P:&]N971O.B!L:6YK(&9O<B!I+4UO9&4N"B`@("`@("`@
M("`@('!R:6YT9B@G/'`^/&$@:')E9CTB<&AO;F5T;SHE<R(^)7,\+V$^/"]P
M/B<L"B`@("`@("`@("`@("`@("`@("`D<&AO;F4M/F=E="@G;G5M8F5R)RDL
M("1P:&]N92T^9V5T*"=L86)E;"<I*3L*("`@("`@("!](&5L<V5I9B`H)'1H
M:7,M/FES0G)O=W-E<B@G;6UL)RDI('L*("`@("`@("`@("`@+R\@0W)E871E
M('1E;#H@;&EN:R!F;W(@34U,+@H@("`@("`@("`@("!P<FEN=&8H)SQP/CQA
M(&AR968](G1E;#HE<R(^)7,\+V$^/"]P/B<L"B`@("`@("`@("`@("`@("`@
M("`D<&AO;F4M/F=E="@G;G5M8F5R)RDL("1P:&]N92T^9V5T*"=L86)E;"<I
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!$:7-P;&%Y('!H
M;VYE(&YU;6)E<B!A<R!P;&%I;B!T97AT+@H@("`@("`@("`@("!P<FEN=&8H
M)SQP/CQB:6<^)7,\+V)I9SX\+W`^)RP@)'!H;VYE+3YG970H)VQA8F5L)RDI
M.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R4G5L92@F
M)')U;&4I"B`@("!["B`@("`@("`@)'=I9'1H(#T@)')U;&4M/F=E="@G=VED
M=&@G*3L*("`@("`@("`D<VEZ92`]("1R=6QE+3YG970H)W-I>F4G*3L*"B`@
M("`@("`@96-H;R`G/&AR)R`N("@D=VED=&@@/R`G('=I9'1H/2(G("X@)'=I
M9'1H("X@)R(G(#H@)R<I("X@*"1S:7IE(#\@)R!S:7IE/2(G("X@)'-I>F4@
M+B`G(B<@.B`G)RD@+B`B("\^7&XB.PH@("`@?0H*("`@(&9U;F-T:6]N(%]G
M971-;V1E*"1M;V1E*0H@("`@>PH@("`@("`@('-W:71C:"`H)&UO9&4I('L*
M("`@("`@("!C87-E("=K871A:V%N82<Z"B`@("`@("`@("`@(')E='5R;B`G
M(&UO9&4](FMA=&%K86YA(B<["@H@("`@("`@(&-A<V4@)VAI<F%G86YA)SH*
M("`@("`@("`@("`@<F5T=7)N("<@;6]D93TB:&ER86=A;F$B)SL*"B`@("`@
M("`@8V%S92`G;G5M97)I8R<Z"B`@("`@("`@("`@(')E='5R;B`G(&UO9&4]
M(FYU;65R:6,B)SL*"B`@("`@("`@8V%S92`G86QP:&$G.@H@("`@("`@(&1E
M9F%U;'0Z"B`@("`@("`@("`@(')E='5R;B`G(&UO9&4](F%L<&AA8F5T(B<[
M"B`@("`@("`@?0H@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-;V)I;&4O4F5N9&5R97(O
M=VUL+G!H<```````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R-C4R,R`Q,#4Q
M-30S,S<S-2`P,C,V-#4`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J($AO<F1E7TUO8FEL95]296YD97)E
M<CHZ(&]U='!U="!M;V1U;&4@9F]R(%=-3"`H5VER96QE<W,@36%R:W5P($QA
M;F=U86=E*2X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO36]B:6QE+TUO8FEL
M92]296YD97)E<B]W;6PN<&AP+'8@,2XS,BXQ,"XW(#(P,#8O,#(O,C0@,C`Z
M-#`Z,S@@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#
M:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?
M36]B:6QE"B`J+PIC;&%S<R!(;W)D95]-;V)I;&5?4F5N9&5R97)?=VUL(&5X
M=&5N9',@2&]R9&5?36]B:6QE7U)E;F1E<F5R('L*"B`@("`O*BH*("`@("`J
M(%!R;W!E<FQY(&5N8V]D92!C:&%R86-T97)S(&9O<B!O=71P=70@=&\@82!7
M34P@9&5V:6-E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&EN<'5T
M("!#:&%R86-T97)S('1O(&5N8V]D92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE(&5N8V]D960@=&5X="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@97-C87!E*"1I;G!U="D*("`@('L*("`@("`@("`O+R!%;F-O9&4@96YT
M:71I97,N"B`@("`@("`@)&]U='!U="`]($!H=&UL<W!E8VEA;&-H87)S*"1I
M;G!U="P@14Y47T-/35!!5"P@3DQ3.CIG971#:&%R<V5T*"DI.PH*("`@("`@
M("`O+R!%<V-A<&4@)"!C:&%R86-T97(@:6X@5TU,+@H@("`@("`@("1O=71P
M=70@/2!S=')?<F5P;&%C92@G)"<L("<D)"<L("1O=71P=70I.PH*("`@("`@
M("`O+R!'96YE<F%T92!55$8M."X*("`@("`@("`D;W5T<'5T(#T@4W1R:6YG
M.CIC;VYV97)T0VAA<G-E="@D;W5T<'5T+"!.3%,Z.F=E=$-H87)S970H*2P@
M)W5T9BTX)RD["@H@("`@("`@(')E='5R;B`D;W5T<'5T.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0W)E871E<R!T:&4@<&%G92!I;B!734PL(&%L;&]W:6YG
M(&9O<B!D:69F97)E;G0@5TU,(&)R;W=S97(@<75I<FMS+@H@("`@("H*("`@
M("`J($!P87)A;2!(;W)D95]-;V)I;&4@)&1E8VL@(%1H92!D96-K('1O(')E
M;F1E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R*"8D9&5C:RD*("`@
M('L*("`@("`@("!I9B`H)&1E8VLM/E]D96)U9RD@>PH@("`@("`@("`@("!H
M96%D97(H)T-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UU=&8M
M."<I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&AE861E<B@G0V]N
M=&5N="U4>7!E.B!T97AT+W9N9"YW87`N=VUL.R!C:&%R<V5T/75T9BTX)RD[
M"B`@("`@("`@?0H*("`@("`@("!E8VAO("(\/WAM;"!V97)S:6]N/5PB,2XP
M7"(_/EQN(CL*("`@("`@("!I9B`H)'1H:7,M/FAA<U%U:7)K*"=O=U]G=6E?
M,2XS)RDI('L*("`@("`@("`@("`@96-H;R`G/"%$3T-465!%('=M;"!054),
M24,@(BTO+U!(3TY%+D-/32\O1%1$(%=-3"`Q+C,O+T5.(B`B:'1T<#HO+W=W
M=RYO<&5N=V%V92YC;VTO9'1D+W=M;#$S+F1T9"(^)SL*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!E8VAO("<\(41/0U194$4@=VUL(%!50DQ)0R`B
M+2\O5T%01D]254TO+T141"!734P@,2XQ+R]%3B(@(FAT='`Z+R]W=W<N=V%P
M9F]R=6TN;W)G+T141"]W;6Q?,2XQ+GAM;"(^)SL*("`@("`@("!]"B`@("`@
M("`@96-H;R`G/'=M;#XG.PH*("`@("`@("!I9B`H8V]U;G0H)&1E8VLM/E]C
M87)D<RDI('L*("`@("`@("`@("`@9F]R96%C:"`H)&1E8VLM/E]C87)D<R!A
M<R`D8V%R9"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]R96YD97)#87)D
M*"1C87)D*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1T:71L92`]("1D96-K+3YG970H)W1I=&QE)RD@/R`G('1I=&QE
M/2(G("X@)'1H:7,M/F5S8V%P92@D9&5C:RT^9V5T*"=T:71L92<I*2`N("<B
M)R`Z("<G.PH@("`@("`@("`@("!P<FEN=&8H)SQC87)D)7,^)RP@)'1I=&QE
M*3L*"B`@("`@("`@("`@("\O(%)E;F1E<B!A;&P@=&%G<RX*("`@("`@("`@
M("`@9F]R96%C:"`H)&1E8VLM/E]E;&5M96YT<R!A<R`D<&%G95]E;&5M96YT
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<F5N9&5R16QE;65N="@D<&%G
M95]E;&5M96YT*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@96-H;R`G
M/"]C87)D/B<["B`@("`@("`@?0H*("`@("`@("`O+R!%;F0@=&AE(%=-3"!P
M86=E+@H@("`@("`@(&5C:&\@)SPO=VUL/B<["B`@("!]"@H@("`@9G5N8W1I
M;VX@7W)E;F1E<D-A<F0H)B1C87)D*0H@("`@>PH@("`@("`@("1N86UE(#T@
M)&-A<F0M/F=E="@G;F%M92<I(#\@)R!I9#TB)R`N("1T:&ES+3YE<V-A<&4H
M)&-A<F0M/F=E="@G;F%M92<I*2`N("<B)R`Z("<G.PH@("`@("`@("1T:71L
M92`]("1C87)D+3YG970H)W1I=&QE)RD@/R`G('1I=&QE/2(G("X@)'1H:7,M
M/F5S8V%P92@D8V%R9"T^9V5T*"=T:71L92<I*2`N("<B)R`Z("<G.PH@("`@
M("`@('!R:6YT9B@G/&-A<F0E<R5S/B<L("1N86UE+"`D=&ET;&4I.PH*("`@
M("`@("`O+R!);FET:6%L:7IE(%=-3"!V87)I86)L97,@=VET:"!T:&5I<B!D
M969A=6QT('9A;'5E<RX*("`@("`@("!I9B`H(6ES7VYU;&PH)&-A<F0M/E]F
M;W)M*2D@>PH@("`@("`@("`@("!E8VAO("<\;VYE=F5N="!T>7!E/2)O;F5N
M=&5R9F]R=V%R9"(^/')E9G)E<V@^)SL*("`@("`@("`@("`@)&1E9F%U;'1S
M(#T@)&-A<F0M/E]F;W)M+3YG971$969A=6QT<R@I.PH@("`@("`@("`@("!F
M;W)E86-H("@D9&5F875L=',@87,@)&0I('L*("`@("`@("`@("`@("`@('!R
M:6YT9B@G/'-E='9A<B!N86UE/2)?)7,B('9A;'5E/2(E<R(O/B<L("1D6R=N
M86UE)UTL("1T:&ES+3YE<V-A<&4H)&1;)W9A;'5E)UTI*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!E8VAO("<\+W)E9G)E<V@^/"]O;F5V96YT/B<[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H8V]U;G0H)&-A<F0M/E]S;V9T:V5Y
M<RDI('L*("`@("`@("`@("`@:68@*&-O=6YT*"1C87)D+3Y?<V]F=&ME>7,I
M(#T](#$I('L*("`@("`@("`@("`@("`@("\O($EF('1H97)E(&ES(&]N;'D@
M;VYE('-O9G1K97DL(&UA:V4@:70@;V8@='EP90H@("`@("`@("`@("`@("`@
M+R\@)V]P=&EO;G,G('-O('1H870@:70@86QW87ES('-H;W=S('5P(&]N('1H
M92!R:6=H="P*("`@("`@("`@("`@("`@("\O(&EN<W1E860@;V8@:&%V:6YG
M('1O('-H87)E('1H92!L969T('-O9G1K97D@=VET:`H@("`@("`@("`@("`@
M("`@+R\@86-T:79E(&QI;FMS+"!M86MI;F<@:70@;75C:"!H87)D97(@=&\@
M9V5T('1O+@H@("`@("`@("`@("`@("`@)'1Y<&4@/2`G;W!T:6]N<R<["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D='EP92`]("=A
M8V-E<'0G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&9O<F5A8V@@*"1C
M87)D+3Y?<V]F=&ME>7,@87,@)&ME>2D@>PH@("`@("`@("`@("`@("`@96-H
M;R`G/&1O('1Y<&4](B<@+B`D='EP92`N("<B(&QA8F5L/2(G("X@)'1H:7,M
M/F5S8V%P92@D:V5Y6R=L86)E;"==*2`N("<B/CQG;R!H<F5F/2(G("X@)&ME
M>5LG=7)L)UT@+B`G(B\^/"]D;SXG.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("`O+R!296YD97(@86QL('1A9W,N"B`@("`@("`@9F]R96%C
M:"`H)&-A<F0M/E]E;&5M96YT<R!A<R`D<&%G95]E;&5M96YT*2!["B`@("`@
M("`@("`@("1T:&ES+3YR96YD97)%;&5M96YT*"1P86=E7V5L96UE;G0I.PH@
M("`@("`@('T*"B`@("`@("`@96-H;R`G/"]C87)D/B<["B`@("!]"@H@("`@
M9G5N8W1I;VX@7W)E;F1E<DQI;FLH)B1L:6YK*0H@("`@>PH@("`@("`@("1T
M:71L95]O<'1I;VX@/2`D;&EN:RT^9V5T*"=T:71L92<I(#\@<W!R:6YT9B@G
M('1I=&QE/2(E<R(G+"`D=&AI<RT^97-C87!E*"1L:6YK+3YG970H)W1I=&QE
M)RDI*2`Z("<G.PH*("`@("`@("!P<FEN=&8H)SQA)7,@:')E9CTB)7,B/B5S
M/"]A/B<L"B`@("`@("`@("`@("`@("1T:71L95]O<'1I;VXL('-T<E]R97!L
M86-E*"<F86UP.V%M<#LG+"`G)F%M<#LG+"`D=&AI<RT^97-C87!E*"1L:6YK
M+3YG970H)W5R;"<I*2DL"B`@("`@("`@("`@("`@("1T:&ES+3YE<V-A<&4H
M)&QI;FLM/F=E="@G;&%B96PG*2DI.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R
M96YD97),:6YK<V5T*"8D;&EN:W-E="D*("`@('L*("`@("`@("!I9B`H8V]U
M;G0H)&QI;FMS970M/E]E;&5M96YT<RDI('L*("`@("`@("`@("`@:68@*"1T
M:&ES+3YI<T)R;W=S97(H)W5P)RDI('L*("`@("`@("`@("`@("`@(&5C:&\@
M)SQS96QE8W0^)SL*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1L:6YK<V5T
M+3Y?96QE;65N=',@87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@("`@("1T
M:71L92`]("1V86PM/F=E="@G=&ET;&4G*2`_("<@=&ET;&4](B<@+B`D=&AI
M<RT^97-C87!E*"1V86PM/F=E="@G=&ET;&4G*2D@+B`G(B<@.B`G)SL*("`@
M("`@("`@("`@("`@("`@("!P<FEN=&8H)SQO<'1I;VX@;VYP:6-K/2(E<R(E
M<SXE<SPO;W!T:6]N/B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@('-T
M<E]R97!L86-E*"<F86UP.V%M<#LG+"`G)F%M<#LG+"`D=&AI<RT^97-C87!E
M*"1V86PM/F=E="@G=7)L)RDI*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1I=&QE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M97-C87!E*"1V86PM/F=E="@G;&%B96PG*2DI.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@96-H;R`G/"]S96QE8W0^)SL*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1L:6YK<V5T
M+3Y?96QE;65N=',@87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<F5N9&5R3&EN:R@D=F%L*3L*("`@("`@("`@("`@("`@("`@("!E
M8VAO("<\8G(@+SXG.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)497AT*"8D
M96QE;65N="D*("`@('L*("`@("`@("!F;W)E86-H("@D96QE;65N="T^7V%T
M=')I8G5T97,@87,@)&%T=')I8G5T92D@>PH@("`@("`@("`@("!E8VAO("<\
M)R`N("1A='1R:6)U=&4@+B`G/B<["B`@("`@("`@?0H*("`@("`@("!I9B`H
M)&5L96UE;G0M/F=E="@G;&EN96)R96%K<R<I*2!["B`@("`@("`@("`@(&5C
M:&\@;FPR8G(H)'1H:7,M/F5S8V%P92@D96QE;65N="T^9V5T*"=T97AT)RDI
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!E8VAO("1T:&ES+3YE
M<V-A<&4H)&5L96UE;G0M/F=E="@G=&5X="<I*3L*("`@("`@("!]"@H@("`@
M("`@("1A='1R:6)U=&5S(#T@87)R87E?<F5V97)S92@D96QE;65N="T^7V%T
M=')I8G5T97,I.PH@("`@("`@(&9O<F5A8V@@*"1A='1R:6)U=&5S(&%S("1A
M='1R:6)U=&4I('L*("`@("`@("`@("`@96-H;R`G/"\G("X@)&%T=')I8G5T
M92`N("<^)SL*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E
M<DEM86=E*"8D:6UA9V4I"B`@("!["B`@("`@("`@)&%T=')I8G5T97,@/2`G
M)SL*("`@("`@("!F;W)E86-H("@D:6UA9V4M/E]A='1R:6)U=&5S(&%S("1A
M='1R:6)U=&4@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("1A='1R:6)U=&5S
M("X]('-P<FEN=&8H)R`E<STB)7,B)RP@)&%T=')I8G5T92P@)'9A;'5E*3L*
M("`@("`@("!]"B`@("`@("`@<')I;G1F*"<\:6UG('-R8STB)7,N=V)M<"(E
M<R\^)RP@)&EM86=E+3Y?<W)C+"`D871T<FEB=71E<RD["B`@("!]"@H@("`@
M9G5N8W1I;VX@7W)E;F1E<DEN<'5T*"8D:6YP=70I"B`@("!["B`@("`@("`@
M)'1Y<&4@/2`G('1Y<&4](B<@+B`D:6YP=70M/F=E="@G='EP92<I("X@)R(G
M.PH@("`@("`@("1S:7IE(#T@)&EN<'5T+3YG970H)W-I>F4G*2`_('-P<FEN
M=&8H)R!S:7IE/2(E9"(G+"`D:6YP=70M/F=E="@G<VEZ92<I*2`Z("<G.PH@
M("`@("`@("1M87AL96YG=&@@/2`D:6YP=70M/F=E="@G;6%X;&5N9W1H)RD@
M/R!S<')I;G1F*"<@;6%X;&5N9W1H/2(E9"(G+"`D:6YP=70M/F=E="@G;6%X
M;&5N9W1H)RDI(#H@)R<["@H@("`@("`@('!R:6YT9B@G)7,\:6YP=70@96UP
M='EO:STB=')U92(@9F]R;6%T/2(E<R(E<R!N86UE/2)?)7,B('9A;'5E/2(E
M<R(E<R5S+SXG+`H@("`@("`@("`@("`@("`D=&AI<RT^97-C87!E*"1I;G!U
M="T^9V5T*"=L86)E;"<I*2P@)&EN<'5T+3YG970H)V9O<FUA="<I+`H@("`@
M("`@("`@("`@("`D='EP92P@)'1H:7,M/F5S8V%P92@D:6YP=70M/F=E="@G
M;F%M92<I*2P@)'1H:7,M/F5S8V%P92@D:6YP=70M/F=E="@G=F%L=64G*2DL
M("1S:7IE+"`D;6%X;&5N9W1H*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N
M9&5R5&5X=&%R96$H)B1T97AT87)E82D*("`@('L*("`@("`@("!P<FEN=&8H
M)R5S/&EN<'5T(&5M<'1Y;VL](G1R=64B(&YA;64](E\E<R(@=F%L=64](B5S
M(B\^)RP*("`@("`@("`@("`@("`@)'1H:7,M/F5S8V%P92@D=&5X=&%R96$M
M/F=E="@G;&%B96PG*2DL"B`@("`@("`@("`@("`@("1T97AT87)E82T^9V5T
M*"=N86UE)RDL("1T97AT87)E82T^9V5T*"=V86QU92<I*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!?<F5N9&5R4V5L96-T*"8D<V5L96-T*0H@("`@>PH@("`@
M("`@(&EF("@D=&AI<RT^:&%S475I<FLH)V]W7V=U:5\Q+C,G*2D@>PH@("`@
M("`@("`@("!S=VET8V@@*"1S96QE8W0M/F=E="@G='EP92<I*2!["B`@("`@
M("`@("`@(&-A<V4@)W-P:6XG.@H@("`@("`@("`@("`@("`@)'1Y<&5?;W!T
M:6]N(#T@)W1Y<&4](G-P:6XB)SL*("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@8V%S92`G<&]P=7`G.@H@("`@("`@("`@("!D969A=6QT
M.@H@("`@("`@("`@("`@("`@)'1Y<&5?;W!T:6]N(#T@)W1Y<&4](G!O<'5P
M(B<["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@96-H;R`G/'-E;&5C="`G("X@)'1Y<&5?;W!T:6]N("X@)R!N
M86UE/2)?)R`N("1S96QE8W0M/F=E="@G;F%M92<I("X@)R(^)SL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!E8VAO("<\<V5L96-T(&YA;64](E\G
M("X@)'-E;&5C="T^9V5T*"=N86UE)RD@+B`G(CXG.PH@("`@("`@('T*"B`@
M("`@("`@9F]R96%C:"`H)'-E;&5C="T^7V]P=&EO;G,@87,@)'9A;"D@>PH@
M("`@("`@("`@("!E8VAO("<\;W!T:6]N('9A;'5E/2(G("X@)'9A;%LG=F%L
M=64G72`N("<B/B<@+B`D=&AI<RT^97-C87!E*"1V86Q;)VQA8F5L)UTI("X@
M)SPO;W!T:6]N/B<["B`@("`@("`@?0H@("`@("`@(&5C:&\@)SPO<V5L96-T
M/B<["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E)A9&EO*"8D<F%D:6\I
M"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YH87-1=6ER:R@G;W=?9W5I7S$N
M,R<I*2!["B`@("`@("`@("`@("\O($]P96YW879E($=522!E>'1E;G-I;VYS
M(&9O<B!734P@,2XS"B`@("`@("`@("`@('!R:6YT9B@G/'-E;&5C="!T>7!E
M/2)R861I;R(@;F%M93TB7R5S(CXG+"`D<F%D:6\M/F=E="@G;F%M92<I*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!#;VYV96YT:6]N86P@
M5TU,("AS:6UI;&%R('1O($AO<F1E7TUO8FEL95]S96QE8W0I+@H@("`@("`@
M("`@("!P<FEN=&8H)SQS96QE8W0@;F%M93TB7R5S(CXG+"`D<F%D:6\M/F=E
M="@G;F%M92<I*3L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1R861I
M;RT^7V)U='1O;G,@87,@)'9A;"D@>PH@("`@("`@("`@("!P<FEN=&8H)SQO
M<'1I;VX@=F%L=64](B5S(CXE<SPO;W!T:6]N/B<L"B`@("`@("`@("`@("`@
M("`@("`D=F%L6R=V86QU92==+"`D=&AI<RT^97-C87!E*"1V86Q;)VQA8F5L
M)UTI*3L*("`@("`@("!]"@H@("`@("`@(&5C:&\@)SPO<V5L96-T/B<["B`@
M("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<D-H96-K8F]X*"8D8VAE8VMB;W@I
M"B`@("!["B`@("`@("`@<')I;G1F*"<\<V5L96-T(&YA;64](E\E<R(@;75L
M=&EP;&4](G1R=64B/B<L("1C:&5C:V)O>"T^9V5T*"=N86UE)RDI.PH@("`@
M("`@('!R:6YT9B@G/&]P=&EO;B!V86QU93TB)7,B/B5S/"]O<'1I;VX^/"]S
M96QE8W0^)RP*("`@("`@("`@("`@("`@)&-H96-K8F]X+3YG970H)W9A;'5E
M)RDL("1T:&ES+3YE<V-A<&4H)&-H96-K8F]X+3YG970H)VQA8F5L)RDI*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R4W5B;6ET*"8D<W5B;6ET*0H@
M("`@>PH@("`@("`@(&EF("@D=&AI<RT^:&%S475I<FLH)V]W7V=U:5\Q+C,G
M*2D@>PH@("`@("`@("`@("`O+R!#<F5A=&4@/&1O('1Y<&4](F)U='1O;B(^
M('-E<75E;F-E(&9O<B!/<&5N=V%V92!'54D*("`@("`@("`@("`@+R\@97AT
M96YS:6]N<R!734P@,2XS+@H@("`@("`@("`@("!P<FEN=&8H)SQD;R!T>7!E
M/2)B=71T;VXB(&QA8F5L/2(E<R(^)RP*("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YE<V-A<&4H)'-U8FUI="T^9V5T*"=L86)E;"<I*2D["B`@("`@("`@
M("`@("1T86<@/2`G9&\G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("\O($-R96%T92`\86YC:&]R/B!S97%U96YC92!I;B!N;W)M86P@5TU,+@H@
M("`@("`@("`@("!P<FEN=&8H)SQA;F-H;W(@=&ET;&4](B5S(CXE<R<L"B`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^97-C87!E*"1S=6)M:70M/F=E="@G
M;&%B96PG*2DL"B`@("`@("`@("`@("`@("`@("`D=&AI<RT^97-C87!E*"1S
M=6)M:70M/F=E="@G;&%B96PG*2DI.PH@("`@("`@("`@("`D=&%G(#T@)V%N
M8VAO<B<["B`@("`@("`@?0H*("`@("`@("!I9B`H)'-U8FUI="T^7V9O<FTM
M/F=E="@G;65T:&]D)RD@/3T@)W!O<W0G*2!["B`@("`@("`@("`@('!R:6YT
M9B@G/&=O(&AR968](B5S(B!M971H;V0](G!O<W0B/B<L($AO<F1E.CIU<FPH
M)'-U8FUI="T^7V9O<FTM/F=E="@G=7)L)RDI*3L*"B`@("`@("`@("`@("\O
M(%9A;'5E(&9O<B!T:&ES('-U8FUI="!E;&5M96YT+"!O;FQY(&EF(&YO;BUE
M;7!T>2!N86UE+@H@("`@("`@("`@("!I9B`H)'-U8FUI="T^9V5T*"=N86UE
M)RDI('L*("`@("`@("`@("`@("`@('!R:6YT9B@G/'!O<W1F:65L9"!N86UE
M/2(E<R(@=F%L=64](B5S(B\^)RP@)'-U8FUI="T^9V5T*"=N86UE)RDL("1T
M:&ES+3YE<V-A<&4H)'-U8FUI="T^9V5T*"=L86)E;"<I*2D["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("1D969A=6QT<R`]("1S=6)M:70M/E]F;W)M
M+3YG971$969A=6QT<R@I.PH@("`@("`@("`@("!F;W)E86-H("@D9&5F875L
M=',@87,@)&0I('L*("`@("`@("`@("`@("`@(&EF("AA<G)A>5]K97E?97AI
M<W1S*"=H:61D96XG+"`D9"DI('L*("`@("`@("`@("`@("`@("`@("!P<FEN
M=&8H)SQP;W-T9FEE;&0@;F%M93TB)7,B('9A;'5E/2(E<R(O/B<L("1D6R=N
M86UE)UTL("1T:&ES+3YE<V-A<&4H)&1;)W9A;'5E)UTI*3L*("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@<')I;G1F*"<\
M<&]S=&9I96QD(&YA;64](B5S(B!V86QU93TB)"A?)7,I(B\^)RP@)&1;)VYA
M;64G72P@)&1;)VYA;64G72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!3=&%R="!W
M:71H('1H92!V86QU92!F;W(@=&AI<R!S=6)M:70@96QE;65N="X*("`@("`@
M("`@("`@)'%U97)Y7W-T<FEN9R`]("1S=6)M:70M/F=E="@G;F%M92<I("X@
M)STG("X@)'1H:7,M/F5S8V%P92@D<W5B;6ET+3YG970H)VQA8F5L)RDI("X@
M)R9A;7`[)SL*"B`@("`@("`@("`@("1G971V87)S(#T@)'-U8FUI="T^7V9O
M<FTM/F=E=$=E=%9A<G,H*3L*("`@("`@("`@("`@9F]R96%C:"`H)&=E='9A
M<G,@87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@)'%U97)Y7W-T<FEN9R`N
M/2`D=F%L("X@)STD*%\G("X@)'9A;"`N("<I)F%M<#LG.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!I9B`H<W5B<W1R*"1Q=65R>5]S=')I;F<L("TU
M*2`]/2`G)F%M<#LG*2!["B`@("`@("`@("`@("`@("`D<75E<GE?<W1R:6YG
M(#T@<W5B<W1R*"1Q=65R>5]S=')I;F<L(#`L('-T<FQE;B@D<75E<GE?<W1R
M:6YG*2`M(#4I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!P<FEN=&8H
M)SQG;R!H<F5F/2(E<S\E<R(^)RP@)'-U8FUI="T^7V9O<FTM/F=E="@G=7)L
M)RDL("1Q=65R>5]S=')I;F<I.PH@("`@("`@('T*"B`@("`@("`@96-H;R`B
M/"]G;SX\+R1T86<^(CL*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5&%B
M;&4H)B1T86)L92D*("`@('L*("`@("`@("`O+R!#;W5N="!M87AI;75M(&YU
M;6)E<B!O9B!C;VQU;6YS(&EN('1A8FQE+@H@("`@("`@("1M87@@/2`P.PH@
M("`@("`@(&9O<F5A8V@@*"1T86)L92T^7W)O=W,@87,@)')O=RD@>PH@("`@
M("`@("`@("`D;6%X(#T@;6%X*"1M87@L("1R;W<M/F=E=$-O;'5M;D-O=6YT
M*"DI.PH@("`@("`@('T*("`@("`@("!P<FEN=&8H)SQT86)L92!C;VQU;6YS
M/2(E9"(^)RP@)&UA>"D["@H@("`@("`@('!A<F5N=#HZ7W)E;F1E<E1A8FQE
M*"1T86)L92D["@H@("`@("`@("\O(%1E<FUI;F%T92!T86)L92X*("`@("`@
M("!E8VAO("<\+W1A8FQE/B<["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E
M<E!H;VYE*"8D<&AO;F4I"B`@("!["B`@("`@("`@)'1I=&QE(#T@)'!H;VYE
M+3YG970H)W1I=&QE)RD["B`@("`@("`@)'1I=&QE7V]P=&EO;B`]("@D=&ET
M;&4@/R!S<')I;G1F*"<@=&ET;&4](B5S(B<L("1T:&ES+3YE<V-A<&4H)'1I
M=&QE*2D@.B`G)RD["@H@("`@("`@('!R:6YT9B@G/&$E<R!H<F5F/2)W=&%I
M.B\O=W`O;6,[)7,B/B5S/"]A/B<L("1T:71L95]O<'1I;VXL"B`@("`@("`@
M("`@("`@('-T<E]R97!L86-E*"<K)RP@)R4R0B<L("1P:&]N92T^9V5T*"=N
M=6UB97(G*2DL("1P:&]N92T^9V5T*"=L86)E;"<I*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!?<F5N9&5R4G5L92@F)')U;&4I"B`@("!["B`@("`@("`@:68@
M*"1T:&ES+3YH87-1=6ER:R@G;W=?9W5I7S$N,R<I*2!["B`@("`@("`@("`@
M("\O(%=!4"!D979I8V4@86-C97!T<R!/<&5N=V%V92!'54D@97AT96YS:6]N
M<R!F;W(@5TU,(#$N,PH@("`@("`@("`@("`D=VED=&@@/2`D<G5L92T^9V5T
M*"=W:61T:"<I.PH@("`@("`@("`@("`D<VEZ92`]("1R=6QE+3YG970H)W-I
M>F4G*3L*"B`@("`@("`@("`@(&5C:&\@)SQH<B<@+B`H)'=I9'1H(#\@)R!W
M:61T:#TB)R`N("1W:61T:"`N("<B)R`Z("<G*2`N("@D<VEZ92`_("<@<VEZ
M93TB)R`N("1S:7IE("X@)R(G(#H@)R<I("X@)R`O/B<["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@+R\@5T%0(&1E=FEC92!D;V5S(&YO="!U;F1E
M<G-T86YD(#QH<B`O/B!T86=S+@H@("`@("`@("`@("`O+R`]/3X@9')A=R!S
M;VUE(&YU;6)E<B!O9B!H>7!H96YS('1O(&-R96%T92!A(')U;&4*("`@("`@
M("`@("`@96-H;R`G+2TM+2TM+2TM+3QB<B`O/B<["B`@("`@("`@?0H@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-;V)I;&4O4F5N9&5R
M97(N<&AP````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,3(P-B`Q
M,#4Q-30S,S<S-2`P,C,P,S8`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J($AO<F1E7TUO8FEL95]296YD
M97)E<CHZ(&9R86UE=V]R:R!F;W(@;6]B:6QE(&1E=FEC92!M87)K=7`*("H@
M<F5N9&5R97)S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-;V)I;&4O36]B
M:6QE+U)E;F1E<F5R+G!H<"QV(#$N,34N,3`N."`R,#`V+S`Q+S`Q(#(Q.C(X
M.C(V(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K
M($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]-;V)I
M;&4*("HO"F-L87-S($AO<F1E7TUO8FEL95]296YD97)E<B!E>'1E;F1S($AO
M<F1E7TUO8FEL92!["@H@("`@=F%R("1?8G)O=W-E<CL*"B`@("!F=6YC=&EO
M;B!(;W)D95]-;V)I;&5?4F5N9&5R97(H)&)R;W=S97(@/2!N=6QL*0H@("`@
M>PH@("`@("`@(&EF("AI<U]N=6QL*"1B<F]W<V5R*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7V)R;W=S97(@/2`F;F5W($)R;W=S97(H*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7V)R;W=S97(@/2`D8G)O=W-E
M<CL*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@:7-"<F]W<V5R*"1A
M9V5N="D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]B<F]W<V5R+3YI
M<T)R;W=S97(H)&%G96YT*3L*("`@('T*"B`@("!F=6YC=&EO;B!H87-1=6ER
M:R@D<75I<FLI"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8G)O=W-E
M<BT^:&%S475I<FLH)'%U:7)K*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M;F1E<B!A;GD@2&]R9&5?36]B:6QE7V5L96UE;G0@;V)J96-T+B!,;V]K<R!F
M;W(@=&AE"B`@("`@*B!A<'!R;W!R:6%T92!R96YD97)I;F<@9G5N8W1I;VX@
M:6X@=&AE(')E;F1E<F5R.R!I9B!T:&5R92!I<VXG=`H@("`@("H@;VYE+"!W
M92!I9VYO<F4@=&AI<R!E;&5M96YT+@H@("`@("H*("`@("`J($!P87)A;2!(
M;W)D95]-;V)I;&5?96QE;65N="`D96QE;65N="`@5&AE(&5L96UE;G0@=&\@
M<F5N9&5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97)%;&5M96YT*"8D
M96QE;65N="D*("`@('L*("`@("`@("`D9G5N8R`]("=?<F5N9&5R)R`N('5C
M9FER<W0H<W1R7W)E<&QA8V4H)VAO<F1E7VUO8FEL95\G+"`G)RP@<W1R=&]L
M;W=E<BAG971?8VQA<W,H)&5L96UE;G0I*2DI.PH@("`@("`@(&EF("AM971H
M;V1?97AI<W1S*"1T:&ES+"`D9G5N8RDI('L*("`@("`@("`@("`@)'1H:7,M
M/B1F=6YC*"1E;&5M96YT*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I
M;VX@7W)E;F1E<D)L;V-K*"8D8FQO8VLI"B`@("!["B`@("`@("`@:68@*&-O
M=6YT*"1B;&]C:RT^7V5L96UE;G1S*2D@>PH@("`@("`@("`@("!E8VAO("<\
M<#XG.PH@("`@("`@("`@("!F;W)E86-H("@D8FQO8VLM/E]E;&5M96YT<R!A
M<R`D8FQO8VM%;&5M96YT*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<F5N
M9&5R16QE;65N="@D8FQO8VM%;&5M96YT*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!E8VAO("(\+W`^7&XB.PH@("`@("`@('T*("`@('T*"B`@("!F
M=6YC=&EO;B!?<F5N9&5R1F]R;2@F)&9O<FTI"B`@("!["B`@("`@("`@9F]R
M96%C:"`H)&9O<FTM/E]E;&5M96YT<R!A<R`D9F]R;45L96UE;G0I('L*("`@
M("`@("`@("`@)'1H:7,M/G)E;F1E<D5L96UE;G0H)&9O<FU%;&5M96YT*3L*
M("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E1A8FQE*"8D
M=&%B;&4I"B`@("!["B`@("`@("`@9F]R96%C:"`H)'1A8FQE+3Y?<F]W<R!A
M<R`D<F]W*2!["B`@("`@("`@("`@("1T:&ES+3Y?<F5N9&5R4F]W*"1R;W<I
M.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R4F]W*"8D
M<F]W*0H@("`@>PH@("`@("`@(&5C:&\@)SQT<CXG.PH@("`@("`@(&9O<F5A
M8V@@*"1R;W<M/E]C;VQU;6YS(&%S("1C;VQU;6XI('L*("`@("`@("`@("`@
M96-H;R`G/'1D/B<["B`@("`@("`@("`@("\O($-A;&P@8W)E871E(&9U;F-T
M:6]N(&9O<B!E86-H(&-E;&QE;&5M96YT('1H870@:7,@80H@("`@("`@("`@
M("`O+R!(;W)D95]-;V)I;&4@;V)J96-T+@H@("`@("`@("`@("!I9B`H(6ES
M7VYU;&PH)&-O;'5M;BDI('L*("`@("`@("`@("`@("`@("1T:&ES+3YR96YD
M97)%;&5M96YT*"1C;VQU;6XI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5C:&\@)SPO=&0^)SL*("`@("`@("!]"B`@("`@("`@96-H;R`B/"]T<CY<
M;B(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@
M82!C;VYC<F5T92!(;W)D95]-;V)I;&5?4F5N9&5R97(@:6YS=&%N8V4*("`@
M("`J(&)A<V5D(&]N("1T>7!E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'1Y<&4@("`@("!4:&4@:VEN9"!O9B!M87)K=7`@*&AT;6PL(&AD;6PL
M('=M;"D@=V4@=V%N="!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@(&=E;F5R871E+@H@("`@("H@0'!A<F%M($)R;W=S97(@)&)R;W=S97(@
M(%1H92!"<F]W<V5R(&]B:F5C="!T;R!U<V4N"B`@("`@*B!`<&%R86T@87)R
M87D@)'!A<F%M<R`@("`@02!H87-H(&-O;G1A:6YI;F<@86YY(&]P=&EO;G,@
M9F]R('1H92!R96YD97)E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N($AO<F1E
M7TUO8FEL95]296YD97)E<B`@5&AE(&YE=VQY(&-R96%T960@8V]N8W)E=&4*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!(;W)D95]-
M;V)I;&5?4F5N9&5R97(@:6YS=&%N8V4L(&]R(&$*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!014%27T5R<F]R(&]B:F5C="!O;B!A
M;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH)'1Y<&4L
M("1B<F]W<V5R(#T@;G5L;"P@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@
M("`@("`@)'1Y<&4@/2!B87-E;F%M92@D='EP92D["@H@("`@("`@(&EF("A`
M9FEL95]E>&ES=',H9&ER;F%M92A?7T9)3$5?7RD@+B`G+U)E;F1E<F5R+R<@
M+B`D='EP92`N("<N<&AP)RDI('L*("`@("`@("`@("`@:6YC;'5D95]O;F-E
M(&1I<FYA;64H7U]&24Q%7U\I("X@)R]296YD97)E<B\G("X@)'1Y<&4@+B`G
M+G!H<"<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@0&EN8VQU9&5?
M;VYC92`G2&]R9&4O36]B:6QE+U)E;F1E<F5R+R<@+B`D='EP92`N("<N<&AP
M)SL*("`@("`@("!]"@H@("`@("`@("1C;&%S<R`]("=(;W)D95]-;V)I;&5?
M4F5N9&5R97)?)R`N("1T>7!E.PH@("`@("`@(&EF("AC;&%S<U]E>&ES=',H
M)&-L87-S*2D@>PH@("`@("`@("`@("`D<F5N9&5R97(@/2`F;F5W("1C;&%S
M<R@D8G)O=W-E<BP@)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)')E;F1E<F5R(#T@4$5!4CHZ<F%I<V5%<G)O<B@G0VQA<W,@9&5F
M:6YI=&EO;B!O9B`G("X@)&-L87-S("X@)R!N;W0@9F]U;F0N)RD["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)')E;F1E<F5R.PH@("`@?0H*("`@("\J
M*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E=&4@2&]R9&5?
M36]B:6QE7U)E;F1E<F5R(&EN<W1A;F-E"B`@("`@*B!B87-E9"!O;B`D='EP
M92X@270@=VEL;"!O;FQY(&-R96%T92!A(&YE=R!I;G-T86YC92!I9B!N;PH@
M("`@("H@<F5N9&5R97(@=VET:"!T:&4@<V%M92!P87)A;65T97)S(&-U<G)E
M;G1L>2!E>&ES=',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP
M92`@("`@(%1H92!K:6YD(&]F(&UA<FMU<"`H:'1M;"P@:&1M;"P@=VUL*2!W
M92!W86YT('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@9V5N
M97)A=&4N"B`@("`@*B!`<&%R86T@0G)O=W-E<B`D8G)O=W-E<B`@5&AE($)R
M;W=S97(@;V)J96-T('1O('5S92X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R
M86US("`@("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@;W!T:6]N<R!F;W(@=&AE
M(')E;F1E<F5R+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?36]B:6QE
M7U)E;F1E<F5R("!4:&4@;F5W;'D@8W)E871E9"!C;VYC<F5T90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($AO<F1E7TUO8FEL95]2
M96YD97)E<B!I;G-T86YC92P@;W(@80H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(%!%05)?17)R;W(@;V)J96-T(&]N(&%N(&5R<F]R
M+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1T>7!E+"`D8G)O
M=W-E<B`](&YU;&PL("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@
M('-T871I8R`D:6YS=&%N8V5S(#T@87)R87DH*3L*"B`@("`@("`@)'-I9VYA
M='5R92`](&UD-2AS97)I86QI>F4H87)R87DH)'1Y<&4L("1B<F]W<V5R+"`D
M<&%R86US*2DI.PH@("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E<ULD<VEG
M;F%T=7)E72DI('L*("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E
M72`]("9(;W)D95]-;V)I;&5?4F5N9&5R97(Z.F9A8W1O<GDH)'1Y<&4L("1B
M<F]W<V5R+"`D<&%R86US*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M:6YS=&%N8V5S6R1S:6=N871U<F5=.PH@("`@?0H*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O1&%T80``
M````````````````````````````````````````````````````````````
M````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#`P,#`@,3`U,34T,S,W,S4@,#(P,30R`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92]$871A+V]U=&QO;VMC<W8N<&AP````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,S0R,R`Q,#4Q-30S,S<S-2`P,C,Q-#0`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M"G)E<75I<F5?;VYC92`G2&]R9&4O1&%T82]C<W8N<&AP)SL*"B\J*@H@*B!(
M;W)D95]$871A(&EM<&QE;65N=&%T:6]N(&9O<B!/=71L;V]K(&-O;6UA+7-E
M<&%R871E9"!D871A("A#4U8I+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]$
M871A+T1A=&$O;W5T;&]O:V-S=BYP:'`L=B`Q+C,N,3`N,R`R,#`U+S$P+S$X
M(#$Q.C`Q.C`T(&IA;B!%>'`@)`H@*@H@*B!`<&%C:V%G92!(;W)D95]$871A
M"B`J+PIC;&%S<R!(;W)D95]$871A7V]U=&QO;VMC<W8@97AT96YD<R!(;W)D
M95]$871A7V-S=B!["@H@("`@+RHJ"B`@("`@*B!"=6EL9',@82!#4U8@9FEL
M92!F<F]M(&$@9VEV96X@9&%T82!S=')U8W1U<F4@86YD(')E='5R;G,@:70@
M87,@80H@("`@("H@<W1R:6YG+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A
M>2`@("1D871A("`@("`@($$@='=O+61I;65N<VEO;F%L(&%R<F%Y(&-O;G1A
M:6YI;F<@=&AE(&1A=&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('-E="X*("`@("`J($!P87)A;2!B;V]L96%N("1H96%D97(@("`@($EF
M('1R=64L('1H92!R;W=S(&]F("1D871A(&%R92!A<W-O8VEA=&EV90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87ES('=I=&@@9FEE
M;&0@;F%M97,@87,@=&AE:7(@:V5Y<RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE($-35B!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!E
M>'!O<G1$871A*"1D871A+"`D:&5A9&5R(#T@9F%L<V4L("1E>'!O<G1?;6%P
M<&EN9R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D
M9&%T82D@?'P@8V]U;G0H)&1A=&$I(#T](#`I('L*("`@("`@("`@("`@<F5T
M=7)N("<G.PH@("`@("`@('T*"B`@("`@("`@)&5X<&]R="`]("<G.PH@("`@
M("`@("1E;VP@/2`B7')<;B(["B`@("`@("`@)&AE860@/2!A<G)A>5]K97ES
M*&-U<G)E;G0H)&1A=&$I*3L*("`@("`@("!I9B`H)&AE861E<BD@>PH@("`@
M("`@("`@("!F;W)E86-H("@D:&5A9"!A<R`D:V5Y*2!["B`@("`@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1K97DI*2!["B`@("`@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1E>'!O<G1?;6%P<&EN9ULD:V5Y72DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&ME>2`]("1E>'!O<G1?;6%P<&EN9ULD:V5Y73L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&5X
M<&]R="`N/2`G(B<@+B`D:V5Y("X@)R(G.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@)&5X<&]R="`N/2`G+"<["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)&5X<&]R="`]('-U8G-T<B@D97AP;W)T+"`P+"`M,2D@
M+B`D96]L.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)&1A=&$@87,@
M)')O=RD@>PH@("`@("`@("`@("!F;W)E86-H("@D:&5A9"!A<R`D:V5Y*2![
M"B`@("`@("`@("`@("`@("`D8V5L;"`]("1R;W=;)&ME>5T["B`@("`@("`@
M("`@("`@("!I9B`H(65M<'1Y*"1C96QL*2!\?"`D8V5L;"`]/3T@,"D@>PH@
M("`@("`@("`@("`@("`@("`@("1C96QL(#T@<')E9U]R97!L86-E*"(O7"(O
M(BP@(EPB7"(B+"`D8V5L;"D["B`@("`@("`@("`@("`@("`@("`@)&5X<&]R
M="`N/2`G(B<@+B`D8V5L;"`N("<B)SL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("1E>'!O<G0@+CT@)RPG.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1E>'!O<G0@/2!S=6)S='(H)&5X<&]R="P@,"P@+3$I("X@
M)&5O;#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D97AP;W)T.PH@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M2&]R9&4O1&%T82]V8V%R9"YP:'``````````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#(Q-#,@,3`U,34T,S,W,S4@,#(R,#,Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"@IR97%U
M:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+VEM8RYP:'`G.PIR97%U
M:7)E7V]N8V4@)TAO<F1E+VE#86QE;F1A<BYP:'`G.PH*+RHJ"B`J($EM<&QE
M;65N="!T:&4@2&]R9&5?1&%T83HZ($%022!F;W(@=D-A<F0@9&%T82X*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO1&%T82]$871A+W9C87)D+G!H<"QV(#$N
M,S,N,3`N-R`R,#`V+S`Q+S`Q(#(Q.C(X.C$S(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,3DY.2TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO
M<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R
M(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A
M8VMA9V4@2&]R9&5?1&%T80H@*B\*8VQA<W,@2&]R9&5?1&%T85]V8V%R9"!E
M>'1E;F1S($AO<F1E7T1A=&%?:6UC('L*"B`@("`O*BH*("`@("`J($5X<&]R
M=',@=F-A;&5N9&%R(&1A=&$@87,@82!S=')I;F<N(%5N;&EK92!V179E;G0L
M('9#87)D(&1A=&$*("`@("`J(&ES(&YO="!E;F-L;W-E9"!I;B!"14=)3GQ%
M3D0Z=D-A;&5N9&%R+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D9&%T
M82`@("`@06X@87)R87D@8V]N=&%I;FEN9R!(;W)D95]I0V%L96YD87)?=F-A
M<F0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@;V)J96-T<RX*("`@
M("`J($!P87)A;2!S=')I;F<@)&UE=&AO9"`@5&AE(&E4:7`@;65T:&]D('1O
M('5S92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&E#86QE
M;F1A<B!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>'!O<G1$871A*"1D
M871A+"`D;65T:&]D(#T@)U)%455%4U0G*0H@("`@>PH@("`@("`@("1S(#T@
M)R<["B`@("`@("`@9F]R96%C:"`H)&1A=&$@87,@)'9C87)D*2!["B`@("`@
M("`@("`@("1S+CT@)'9C87)D+3YE>'!O<G1V0V%L96YD87(H*3L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1S.PH@("`@?0H*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]$871A+W9T;V1O+G!H<```
M````````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3(R,2`Q,#4Q
M-30S,S<S-2`P,C(P-C$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*"B\J*B!792!R96QY(&]N('1H92!(;W)D95]$
M871A7VEM8SHZ(&%B<W1R86-T(&-L87-S+B`J+PIR97%U:7)E7V]N8V4@9&ER
M;F%M92A?7T9)3$5?7RD@+B`G+VEM8RYP:'`G.PH*+RHJ"B`J($EM<&QE;65N
M="!T:&4@2&]R9&5?1&%T83HZ($%022!F;W(@=E1O9&\@9&%T82X*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO1&%T82]$871A+W9T;V1O+G!H<"QV(#$N."XQ
M,"XS(#(P,#8O,#$O,#$@,C$Z,C@Z,3,@:F%N($5X<"`D"B`J"B`J($-O<'ER
M:6=H="`Q.3DY+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*
M("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K
M($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!(;W)D
M95]$871A"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B\*8VQA<W,@2&]R9&5?
M1&%T85]V=&]D;R!E>'1E;F1S($AO<F1E7T1A=&%?:6UC('L*"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]$871A+W1S=BYP
M:'``````````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R,3`S
M,R`Q,#4Q-30S,S<S-2`P,C$U-#4`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J($AO<F1E7T1A=&$@:6UP
M;&5M96YT871I;VX@9F]R('1A8BUS97!A<F%T960@9&%T82`H5%-6*2X*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`L=B`Q+C(S
M+C$P+C$P(#(P,#8O,#@O,#,@,#(Z-3`Z-#`@<V5L<VMY($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`Q.3DY+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E
M+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA;B!38VAN96ED
M97(@/&IA;D!H;W)D92YO<F<^"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@
M0'!A8VMA9V4@2&]R9&5?1&%T80H@*B\*8VQA<W,@2&]R9&5?1&%T85]T<W8@
M97AT96YD<R!(;W)D95]$871A('L*"B`@("!V87(@)%]E>'1E;G-I;VX@/2`G
M='-V)SL*("`@('9A<B`D7V-O;G1E;G14>7!E(#T@)W1E>'0O=&%B+7-E<&%R
M871E9"UV86QU97,G.PH*("`@(&9U;F-T:6]N(&EM<&]R=$1A=&$H)&-O;G1E
M;G1S+"`D:&5A9&5R(#T@9F%L<V4L("1D96QI;6ET97(@/2`B7'0B*0H@("`@
M>PH@("`@("`@("1C;VYT96YT<R`](&5X<&QO9&4H(EQN(BP@)&-O;G1E;G1S
M*3L*("`@("`@("`D9&%T82`](&%R<F%Y*"D["B`@("`@("`@:68@*"1H96%D
M97(I('L*("`@("`@("`@("`@)&AE860@/2!E>'!L;V1E*"1D96QI;6ET97(L
M(&%R<F%Y7W-H:69T*"1C;VYT96YT<RDI.PH@("`@("`@('T*("`@("`@("!F
M;W)E86-H("@D8V]N=&5N=',@87,@)&QI;F4I('L*("`@("`@("`@("`@:68@
M*'1R:6TH)&QI;F4I(#T]("<G*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU
M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D;&EN92`](&5X<&QO9&4H
M)&1E;&EM:71E<BP@)&QI;F4I.PH@("`@("`@("`@("!I9B`H(6ES<V5T*"1H
M96%D*2D@>PH@("`@("`@("`@("`@("`@)&1A=&%;72`]("1L:6YE.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&YE=VQI;F4@/2!A
M<G)A>2@I.PH@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@8V]U
M;G0H)&AE860I.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@)&YE=VQI
M;F5;)&AE861;)&E=72`](&5M<'1Y*"1L:6YE6R1I72D@/R`G)R`Z("1L:6YE
M6R1I73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1D871A
M6UT@/2`D;F5W;&EN93L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!R971U<FX@)&1A=&$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL9',@
M82!44U8@9FEL92!F<F]M(&$@9VEV96X@9&%T82!S=')U8W1U<F4@86YD(')E
M='5R;G,@:70@87,@80H@("`@("H@<W1R:6YG+@H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`D9&%T82`@("`@($$@='=O+61I;65N<VEO;F%L(&%R<F%Y
M(&-O;G1A:6YI;F<@=&AE(&1A=&$@<V5T+@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)&AE861E<B`@268@=')U92P@=&AE(')O=W,@;V8@)&1A=&$@87)E(&%S
M<V]C:6%T:79E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>7,@=VET:"!F:65L9"!N86UE<R!A<R!T:&5I<B!K97ES+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@5%-6(&1A=&$N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&5X<&]R=$1A=&$H)&1A=&$L("1H96%D97(@/2!F86QS92D*
M("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1D871A*2!\?"!C;W5N="@D
M9&%T82D@/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@
M?0H@("`@("`@("1E>'!O<G0@/2`G)SL*("`@("`@("`D:&5A9"`](&%R<F%Y
M7VME>7,H8W5R<F5N="@D9&%T82DI.PH@("`@("`@(&EF("@D:&5A9&5R*2![
M"B`@("`@("`@("`@("1E>'!O<G0@/2!I;7!L;V1E*")<="(L("1H96%D*2`N
M(")<;B(["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1D871A(&%S("1R
M;W<I('L*("`@("`@("`@("`@9F]R96%C:"`H)&AE860@87,@)&ME>2D@>PH@
M("`@("`@("`@("`@("`@)&-E;&P@/2`D<F]W6R1K97E=.PH@("`@("`@("`@
M("`@("`@:68@*"%E;7!T>2@D8V5L;"D@?'P@)&-E;&P@/3T](#`I('L*("`@
M("`@("`@("`@("`@("`@("`D97AP;W)T("X]("1C96QL.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@)&5X<&]R="`N/2`B7'0B.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1E>'!O<G0@/2!S=6)S='(H)&5X<&]R
M="P@,"P@+3$I("X@(EQN(CL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1E
M>'!O<G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL9',@82!44U8@9FEL
M92!F<F]M(&$@9VEV96X@9&%T82!S=')U8W1U<F4@86YD('1R:6=G97)S(&ET
M<R!D;W=N;&]A9"X*("`@("`J($ET($1/15,@3D]4(&5X:70@=&AE(&-U<G)E
M;G0@<V-R:7!T(&)U="!O;FQY(&]U='!U=',@=&AE(&-O<G)E8W0@:&5A9&5R
M<PH@("`@("H@86YD(&1A=&$N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9FEL96YA;64@(%1H92!N86UE(&]F('1H92!F:6QE('1O(&)E(&1O=VYL
M;V%D960N"B`@("`@*B!`<&%R86T@87)R87D@)&1A=&$@("`@("`@02!T=V\M
M9&EM96YS:6]N86P@87)R87D@8V]N=&%I;FEN9R!T:&4@9&%T80H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@('-E="X*("`@("`J($!P87)A;2!B
M;V]L96%N("1H96%D97(@("!)9B!T<G5E+"!T:&4@<F]W<R!O9B`D9&%T82!A
M<F4@87-S;V-I871I=F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>7,@=VET:"!F:65L9"!N86UE<R!A<R!T:&5I<B!K97ES+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!E>'!O<G1&:6QE*"1F:6QE;F%M92P@)&1A=&$L
M("1H96%D97(@/2!F86QS92D*("`@('L*("`@("`@("`D97AP;W)T(#T@)'1H
M:7,M/F5X<&]R=$1A=&$H)&1A=&$L("1H96%D97(I.PH@("`@("`@("1'3$]"
M04Q36R=B<F]W<V5R)UTM/F1O=VYL;V%D2&5A9&5R<R@D9FEL96YA;64L("=T
M97AT+W1A8BUS97!A<F%T960M=F%L=65S)RP@9F%L<V4L('-T<FQE;B@D97AP
M;W)T*2D["B`@("`@("`@96-H;R`D97AP;W)T.PH@("`@?0H*("`@("\J*@H@
M("`@("H@5&%K97,@86QL(&YE8V5S<V%R>2!A8W1I;VYS(&9O<B!T:&4@9VEV
M96X@:6UP;W)T('-T97`L('!A<F%M971E<G,@86YD"B`@("`@*B!F;W)M('9A
M;'5E<R!A;F0@<F5T=7)N<R!T:&4@;F5X="!N96-E<W-A<GD@<W1E<"X*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D86-T:6]N("!4:&4@8W5R<F5N
M="!S=&5P+B!/;F4@;V8@=&AE($E-4$]25%\J(&-O;G-T86YT<RX*("`@("`J
M($!P87)A;2!A<G)A>2`D<&%R86T@("`@($%N(&%S<V]C:6%T:79E(&%R<F%Y
M(&-O;G1A:6YI;F<@;F5E9&5D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("!P87)A;65T97)S(&9O<B!T:&4@8W5R<F5N="!S=&5P+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@($5I=&AE<B!T:&4@;F5X="!S=&5P(&%S
M(&%N(&EN=&5G97(@8V]N<W1A;G0@;W(@:6UP;W)T960*("`@("`J("`@("`@
M("`@("`@("`@(&1A=&$@<V5T(&%F=&5R('1H92!F:6YA;"!S=&5P+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!N97AT4W1E<"@D86-T:6]N+"`D<&%R86T@/2!A
M<G)A>2@I*0H@("`@>PH@("`@("`@('-W:71C:"`H)&%C=&EO;BD@>PH@("`@
M("`@(&-A<V4@24U03U)47T9)3$4Z"B`@("`@("`@("`@("1N97AT7W-T97`@
M/2!P87)E;G0Z.FYE>'13=&5P*"1A8W1I;VXL("1P87)A;2D["B`@("`@("`@
M("`@(&EF("AI<U]A*"1N97AT7W-T97`L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@(')E='5R;B`D;F5X=%]S=&5P.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!I9B`H)%]315-324].6R=I;7!O<G1?9&%T82==6R=F
M;W)M870G72`]/2`G;75L8F5R<GDG('Q\"B`@("`@("`@("`@("`@("`D7U-%
M4U-)3TY;)VEM<&]R=%]D871A)UU;)V9O<FUA="==(#T]("=P:6YE)RD@>PH@
M("`@("`@("`@("`@("`@)%]315-324].6R=I;7!O<G1?9&%T82==6R=D871A
M)UT@/2`D=&AI<RT^:6UP;W)T1FEL92@D7T9)3$536R=I;7!O<G1?9FEL92==
M6R=T;7!?;F%M92==*3L*("`@("`@("`@("`@("`@("1F;W)M870@/2`D7U-%
M4U-)3TY;)VEM<&]R=%]D871A)UU;)V9O<FUA="==.PH@("`@("`@("`@("`@
M("`@:68@*"1F;W)M870@/3T@)VUU;&)E<G)Y)RD@>PH@("`@("`@("`@("`@
M("`@("`@("1A<'!+97ES("`](&%R<F%Y*"=A;&EA<R<L("=N86UE)RP@)V5M
M86EL)RP@)V-O;7!A;GDG+"`G=V]R:T%D9')E<W,G+"`G=V]R:U!H;VYE)RP@
M)VAO;650:&]N92<L("=F87@G+"`G;F]T97,G*3L*("`@("`@("`@("`@("`@
M("`@("`D9&%T84ME>7,@/2!A<G)A>2@P+"`Q+"`R+"`S+"`T+"`U+"`V+"`W
M+"`Y*3L*("`@("`@("`@("`@("`@('T@96QS96EF("@D9F]R;6%T(#T]("=P
M:6YE)RD@>PH@("`@("`@("`@("`@("`@("`@("1A<'!+97ES(#T@87)R87DH
M)V%L:6%S)RP@)VYA;64G+"`G96UA:6PG+"`G;F]T97,G*3L*("`@("`@("`@
M("`@("`@("`@("`D9&%T84ME>7,@/2!A<G)A>2@P+"`Q+"`R+"`T*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1A<'!+
M97ES(&%S("1K97D@/3X@)&%P<"D@>PH@("`@("`@("`@("`@("`@("`@("1M
M87!;)&1A=&%+97ES6R1K97E=72`]("1A<'`["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`D9&%T82`](&%R<F%Y*"D["B`@("`@("`@("`@
M("`@("!F;W)E86-H("@D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)V1A=&$G
M72!A<R`D<F]W*2!["B`@("`@("`@("`@("`@("`@("`@)&AA<V@@/2!A<G)A
M>2@I.PH@("`@("`@("`@("`@("`@("`@(&EF("@D9F]R;6%T(#T]("=M=6QB
M97)R>2<I('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T
M8V@H(B]>1W)P.B\B+"`D<F]W6S!=*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`@("`@)')O=ULQ72`]('!R96=?<F5P;&%C
M92@G+UXH6UXL(ETK*2Q<<RHH+BHI)"\G+"`G)#(@)#$G+"`D<F]W6S%=*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&1A=&%+97ES(&%S
M("1K97DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AA<G)A
M>5]K97E?97AI<W1S*"1K97DL("1R;W<I*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&AA<VA;)&ME>5T@/2!S=')I<'-L87-H97,H<')E
M9U]R97!L86-E*"<O7%Q<7'(O)RP@(EQN(BP@)')O=ULD:V5Y72DI.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1F;W)M870@
M/3T@)W!I;F4G*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AC;W5N
M="@D<F]W*2`\(#,@?'P@<')E9U]M871C:"@B+UXC1$5,151%1"\B+"`D<F]W
M6S!=*2!\?"!P<F5G7VUA=&-H*"(O6R@I72\B+"`D<F]W6S)=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)')O=ULQ
M72`]('!R96=?<F5P;&%C92@G+UXH6UXL(ETK*2Q<<RHH+BHI)"\G+"`G)#(@
M)#$G+"`D<F]W6S%=*3L*("`@("`@("`@("`@("`@("`@("`@("`@+RH@061D
M<F5S<R!C86X@8F4@82!F=6QL(%)&0S@R,B!A9&1R97-S("HO"B`@("`@("`@
M("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G36%I;"]21D,X,C(N<&AP
M)SL*("`@("`@("`@("`@("`@("`@("`@("`@)&%D9')?87)R(#T@36%I;%]2
M1D,X,C(Z.G!A<G-E061D<F5S<TQI<W0H)')O=ULR72D["B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("AE;7!T>2@D861D<E]A<G);,%TM/FUA:6QB;W@I
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@
M("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@
M("`D<F]W6S)=(#T@)&%D9')?87)R6S!=+3YM86EL8F]X("X@)T`G("X@)&%D
M9')?87)R6S!=+3YH;W-T.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M96UP='DH)')O=ULQ72D@)B8@(65M<'1Y*"1A9&1R7V%R<ELP72T^<&5R<V]N
M86PI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F]W6S%=(#T@
M)&%D9')?87)R6S!=+3YP97)S;VYA;#L*("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D9&%T84ME
M>7,@87,@)&ME>2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*&%R<F%Y7VME>5]E>&ES=',H)&ME>2P@)')O=RDI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D:&%S:%LD:V5Y72`]("1R;W=;)&ME>5T[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@)&1A=&%;72`]("1H87-H.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@)%]315-324].6R=I;7!O<G1?9&%T82==6R=D871A
M)UT@/2`D9&%T83L*("`@("`@("`@("`@("`@("1?4T534TE/3ELG:6UP;W)T
M7V1A=&$G75LG;6%P)UT@/2`D;6%P.PH@("`@("`@("`@("`@("`@)')E="`]
M("1T:&ES+3YN97AT4W1E<"A)35!/4E1?1$%402P@)'!A<F%M*3L*("`@("`@
M("`@("`@("`@(')E='5R;B`D<F5T.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`O*B!-;W9E('5P;&]A9&5D(&9I;&4@<V\@=&AA="!W92!C86X@<F5A
M9"!I="!A9V%I;B!I;B!T:&4@;F5X="!S=&5P"B`@("`@("`@("`@("`@(&%F
M=&5R('1H92!U<V5R(&=A=F4@<V]M92!F;W)M870@9&5T86EL<RX@*B\*("`@
M("`@("`@("`@)'5P;&]A9&5D(#T@0G)O=W-E<CHZ=V%S1FEL955P;&]A9&5D
M*"=I;7!O<G1?9FEL92<L(%\H(E135B!F:6QE(BDI.PH@("`@("`@("`@("!I
M9B`H:7-?82@D=7!L;V%D960L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"1U<&QO861E9"T^9V5T
M365S<V%G92@I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D9FEL95]N
M86UE(#T@2&]R9&4Z.F=E=%1E;7!&:6QE*"=I;7!O<G0G+"!F86QS92D["B`@
M("`@("`@("`@(&EF("@A;6]V95]U<&QO861E9%]F:6QE*"1?1DE,15-;)VEM
M<&]R=%]F:6QE)UU;)W1M<%]N86UE)UTL("1F:6QE7VYA;64I*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")4:&4@=7!L
M;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N(BDI.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG9FEL
M95]N86UE)UT@/2`D9FEL95]N86UE.PH*("`@("`@("`@("`@+RH@4F5A9"!T
M:&4@9FEL92=S(&9I<G-T('1W;R!L:6YE<R!T;R!S:&]W('1H96T@=&\@=&AE
M('5S97(N("HO"B`@("`@("`@("`@("1?4T534TE/3ELG:6UP;W)T7V1A=&$G
M75LG9FER<W1?;&EN97,G72`]("<G.PH@("`@("`@("`@("`D9G`@/2!`9F]P
M96XH)&9I;&5?;F%M92P@)W(G*3L*("`@("`@("`@("`@:68@*"1F<"D@>PH@
M("`@("`@("`@("`@("`@)&QI;F5?;F\@/2`Q.PH@("`@("`@("`@("`@("`@
M=VAI;&4@*"1L:6YE7VYO(#P@,R`F)B`D;&EN92`](&9G971S*"1F<"DI('L*
M("`@("`@("`@("`@("`@("`@("`D;F5W;&EN92`](%-T<FEN9SHZ;&5N9W1H
M*"1L:6YE*2`^(#$P,"`_(")<;B(@.B`G)SL*("`@("`@("`@("`@("`@("`@
M("`D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)V9I<G-T7VQI;F5S)UT@+CT@
M<W5B<W1R*"1L:6YE+"`P+"`Q,#`I("X@)&YE=VQI;F4["B`@("`@("`@("`@
M("`@("`@("`@)&QI;F5?;F\K*SL*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!R971U<FX@24U03U)47U135CL*("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@24U03U)47U135CH*("`@("`@
M("`@("`@)%]315-324].6R=I;7!O<G1?9&%T82==6R=H96%D97(G72`](%5T
M:6PZ.F=E=$9O<FU$871A*"=H96%D97(G*3L*("`@("`@("`@("`@)&EM<&]R
M=%]D871A(#T@)'1H:7,M/FEM<&]R=$9I;&4H)%]315-324].6R=I;7!O<G1?
M9&%T82==6R=F:6QE7VYA;64G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)%]315-324].6R=I;7!O<G1?9&%T82==
M6R=H96%D97(G72D["B`@("`@("`@("`@("1?4T534TE/3ELG:6UP;W)T7V1A
M=&$G75LG9&%T82==(#T@)&EM<&]R=%]D871A.PH@("`@("`@("`@("!U;G-E
M="@D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)VUA<"==*3L*("`@("`@("`@
M("`@<F5T=7)N($E-4$]25%]-05!0140["B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!D969A=6QT.@H@("`@("`@("`@("!R971U<FX@<&%R96YT.CIN
M97AT4W1E<"@D86-T:6]N+"`D<&%R86TI.PH@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("!]"B`@("!]"@I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T1A
M=&$O:6-A;&5N9&%R+G!H<```````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`Q,C`W(#$P-3$U-#,S-S,U(#`R,C8U-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`H*+RHJ(%=E(')E;'D@
M;VX@=&AE($AO<F1E7T1A=&%?:6UC.CH@86)S=')A8W0@8VQA<W,N("HO"G)E
M<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O:6UC+G!H<"<["@HO
M*BH*("H@5&AI<R!I<R!I0V%L96YD87(@*'9#86QE;F1A<BDN"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+T1A=&$O1&%T82]I8V%L96YD87(N<&AP+'8@,2XS
M,2XQ,"XS(#(P,#8O,#$O,#$@,C$Z,C@Z,3,@:F%N($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D
M92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E
M;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@2V%R<W1E;B!&
M;W5R;6]N="`\9F]U<FUO;G1`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!(;W)D
M95]$871A"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B\*8VQA<W,@2&]R9&5?
M1&%T85]I8V%L96YD87(@97AT96YD<R!(;W)D95]$871A7VEM8R!["@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+T1A=&$O=FYO=&4N<&AP````````````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`R,S<R(#$P-3$U-#,S-S,U(#`R,C`W,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`H*<F5Q=6ER
M95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]I;6,N<&AP)SL*"B\J*@H@
M*B!);7!L96UE;G0@=&AE($AO<F1E7T1A=&$Z.B!!4$D@9F]R('9.;W1E(&1A
M=&$N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T1A=&$O1&%T82]V;F]T92YP
M:'`L=B`Q+C@N,3`N-2`R,#`V+S`Q+S`Q(#(Q.C(X.C$S(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H
M;W)D92YO<F<^"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'!A
M8VMA9V4@2&]R9&5?1&%T80H@*B!`<VEN8V4@("!(;W)D92`S+C`*("HO"F-L
M87-S($AO<F1E7T1A=&%?=FYO=&4@97AT96YD<R!(;W)D95]$871A7VEM8R![
M"@H@("`@+RHJ"B`@("`@*B!%>'!O<G1S('9C86QE;F1A<B!D871A(&%S(&$@
M<W1R:6YG+B!5;FQI:V4@=D5V96YT+"!V3F]T92!D871A"B`@("`@*B!I<R!N
M;W0@96YC;&]S960@:6X@0D5'24Y\14Y$.G9#86QE;F1A<BX*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@)&1A=&$@("`@($%N(&%R<F%Y(&-O;G1A:6YI
M;F<@2&]R9&5?:4-A;&5N9&%R7W9N;W1E"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@(&]B:F5C=',N"B`@("`@*B!`<&%R86T@<W1R:6YG("1M971H
M;V0@(%1H92!I5&EP(&UE=&AO9"!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!I0V%L96YD87(@9&%T82X*("`@("`J+PH@("`@
M9G5N8W1I;VX@97AP;W)T1&%T82@D9&%T82P@)&UE=&AO9"`]("=215%515-4
M)RD*("`@('L*("`@("`@("!G;&]B86P@)'!R969S.PH*("`@("`@("`D=&AI
M<RT^7VE#86P@/2`F;F5W($AO<F1E7VE#86QE;F1A<B@I.PH*("`@("`@("`D
M=&AI<RT^7VE#86PM/G-E=$%T=')I8G5T92@G34542$]$)RP@)&UE=&AO9"D[
M"B`@("`@("`@)',@/2`G)SL*("`@("`@("!F;W)E86-H("@D9&%T82!A<R`D
M979E;G0I('L*("`@("`@("`@("`@)',N/2`D979E;G0M/F5X<&]R='9#86QE
M;F1A<B@I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)',["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O1&%T82]I;6,N<&AP````````
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#8T,C<@,3`U,34T
M,S,W,S4@,#(Q-3$S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+VE#86QE;F1A
M<BYP:'`G.PH*+RHJ"B`J($%B<W1R86-T(&EM<&QE;65N=&%T:6]N(&]F('1H
M92!(;W)D95]$871A.CH@05!)(&9O<B!)34,@9&%T82`M"B`J('9#87)D<R!A
M;F0@:4-A;&5N9&%R(&1A=&$L(&5T8RX@4')O=FED97,@82!N=6UB97(@;V8@
M=71I;&ET>0H@*B!M971H;V1S('1H870@=D-A<F0@86YD(&E#86QE;F1A<B!I
M;7!L96UE;G1A=&EO;B!C86X@<VAA<F4@86YD(')E;'D*("H@;VXN"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+T1A=&$O1&%T82]I;6,N<&AP+'8@,2XS,BXQ
M,"XX(#(P,#8O,#4O,#D@,C,Z,#8Z,#D@8VAU8VL@17AP("0*("H*("H@0V]P
M>7)I9VAT(#$Y.3DM,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\
M:F%N0&AO<F1E+F]R9SX*("H@0'!A8VMA9V4@2&]R9&5?1&%T80H@*B!`<VEN
M8V4@("!(;W)D92`S+C`*("HO"F-L87-S($AO<F1E7T1A=&%?:6UC(&5X=&5N
M9',@2&]R9&5?1&%T82!["@H@("`@=F%R("1?:4-A;"`](&9A;'-E.PH*("`@
M(&9U;F-T:6]N(&EM<&]R=$1A=&$H)'1E>'0I"B`@("!["B`@("`@("`@)'1H
M:7,M/E]I0V%L(#T@;F5W($AO<F1E7VE#86QE;F1A<B@I.PH@("`@("`@(&EF
M("@A)'1H:7,M/E]I0V%L+3YP87)S979#86QE;F1A<B@D=&5X="DI('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B5&AE<F4@=V%S
M(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(BDI.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?:4-A;"T^9V5T0V]M
M<&]N96YT<R@I.PH@("`@?0H*("`@("\J*@H@("`@("H@0G5I;&1S(&%N(&E#
M86QE;F1A<B!F:6QE(&9R;VT@82!G:79E;B!D871A('-T<G5C='5R92!A;F0*
M("`@("`J(')E='5R;G,@:70@87,@82!S=')I;F<N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1D871A("`@("!!;B!A<G)A>2!C;VYT86EN:6YG($AO
M<F1E7VE#86QE;F1A<E]V979E;G0*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@;V)J96-T<PH@("`@("H@0'!A<F%M('-T<FEN9R`D;65T:&]D("!4
M:&4@:51I<"!M971H;V0@=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@:4-A;&5N9&%R(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&5X<&]R=$1A=&$H)&1A=&$L("1M971H;V0@/2`G4D5154535"<I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]I0V%L(#T@;F5W($AO<F1E7VE#86QE;F1A
M<B@I.PH@("`@("`@("1T:&ES+3Y?:4-A;"T^<V5T071T<FEB=71E*"=-151(
M3T0G+"`D;65T:&]D*3L*"B`@("`@("`@9F]R96%C:"`H)&1A=&$@87,@)&5V
M96YT*2!["B`@("`@("`@("`@("1T:&ES+3Y?:4-A;"T^861D0V]M<&]N96YT
M*"1E=F5N="D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]I
M0V%L+3YE>'!O<G1V0V%L96YD87(H*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($)U:6QD<R!A;B!I0V%L96YD87(@9FEL92!F<F]M(&$@9VEV96X@9&%T82!S
M=')U8W1U<F4@86YD"B`@("`@*B!T<FEG9V5R<R!I=',@9&]W;FQO860N("!)
M="!$3T53($Y/5"!E>&ET('1H92!C=7)R96YT('-C<FEP="!B=70*("`@("`J
M(&]N;'D@;W5T<'5T<R!T:&4@8V]R<F5C="!H96%D97)S(&%N9"!D871A+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&5N86UE("`@5&AE(&YA
M;64@;V8@=&AE(&9I;&4@=&\@8F4@9&]W;FQO861E9"X*("`@("`J($!P87)A
M;2!A<G)A>2`D9&%T82`@("`@("`@06X@87)R87D@8V]N=&%I;FEN9R!(;W)D
M95]I0V%L96YD87)?=F5V96YT<PH@("`@("HO"B`@("!F=6YC=&EO;B!E>'!O
M<G1&:6QE*"1F:6QE;F%M92P@)&1A=&$I"B`@("!["B`@("`@("`@)&5X<&]R
M="`]("1T:&ES+3YE>'!O<G1$871A*"1D871A*3L*("`@("`@("`D1TQ/0D%,
M4ULG8G)O=W-E<B==+3YD;W=N;&]A9$AE861E<G,H)&9I;&5N86UE+"`G=&5X
M="]C86QE;F1A<B<L(&9A;'-E+"!S=')L96XH)&5X<&]R="DI.PH@("`@("`@
M(&5C:&\@)&5X<&]R=#L*("`@('T*"B`@("`O*BH*("`@("`J(%1A:V5S(&%L
M;"!N96-E<W-A<GD@86-T:6]N<R!F;W(@=&AE(&=I=F5N(&EM<&]R="!S=&5P
M+`H@("`@("H@<&%R86UE=&5R<R!A;F0@9F]R;2!V86QU97,@86YD(')E='5R
M;G,@=&AE(&YE>'0@;F5C97-S87)Y('-T97`N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&%C=&EO;B`@5&AE(&-U<G)E;G0@<W1E<"X@3VYE(&]F
M('1H92!)35!/4E1?*B!C;VYS=&%N=',N"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M("`@("!!;B!A<W-O8VEA=&EV92!A<G)A>2!C;VYT86EN:6YG(&YE
M961E9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@<&%R86UE=&5R
M<R!F;W(@=&AE(&-U<G)E;G0@<W1E<"X*("`@("`J($!R971U<FX@;6EX960@
M($5I=&AE<B!T:&4@;F5X="!S=&5P(&%S(&%N(&EN=&5G97(@8V]N<W1A;G0@
M;W(@:6UP;W)T960*("`@("`J("`@("`@("`@("`@("`@(&1A=&$@<V5T(&%F
M=&5R('1H92!F:6YA;"!S=&5P+@H@("`@("HO"B`@("!F=6YC=&EO;B!N97AT
M4W1E<"@D86-T:6]N+"`D<&%R86T@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@
M('-W:71C:"`H)&%C=&EO;BD@>PH@("`@("`@(&-A<V4@24U03U)47T9)3$4Z
M"B`@("`@("`@("`@("1N97AT7W-T97`@/2!P87)E;G0Z.FYE>'13=&5P*"1A
M8W1I;VXL("1P87)A;2D["B`@("`@("`@("`@(&EF("AI<U]A*"1N97AT7W-T
M97`L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M;F5X=%]S=&5P.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D:6UP;W)T
M7V1A=&$@/2`D=&AI<RT^:6UP;W)T1FEL92@D7T9)3$536R=I;7!O<G1?9FEL
M92==6R=T;7!?;F%M92==*3L*("`@("`@("`@("`@:68@*&ES7V$H)&EM<&]R
M=%]D871A+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)&EM<&]R=%]D871A.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]I0V%L+3YG971#;VUP;VYE;G1S*"D["B`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("!R971U
M<FX@<&%R96YT.CIN97AT4W1E<"@D86-T:6]N+"`D<&%R86TI.PH@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("!]"B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T1A=&$O8W-V+G!H<```````
M````````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#(V-S0W(#$P-3$U
M-#,S-S,U(#`R,34T-0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@2&]R9&5?1&%T82!I;7!L96UE;G1A
M=&EO;B!F;W(@8V]M;6$M<V5P87)A=&5D(&1A=&$@*$-35BDN"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+T1A=&$O1&%T82]C<W8N<&AP+'8@,2XS,"XQ,"XX
M(#(P,#8O,#$O,C@@,38Z,C$Z-3@@8VAU8VL@17AP("0*("H*("H@0V]P>7)I
M9VAT(#$Y.3DM,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N
M0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G
M92!(;W)D95]$871A"B`J+PIC;&%S<R!(;W)D95]$871A7V-S=B!E>'1E;F1S
M($AO<F1E7T1A=&$@>PH*("`@('9A<B`D7V5X=&5N<VEO;B`]("=C<W8G.PH@
M("`@=F%R("1?8V]N=&5N=%1Y<&4@/2`G=&5X="]C;VUM82US97!A<F%T960M
M=F%L=65S)SL*"B`@("`O*BH*("`@("`J(%1R:65S('1O(&1I<V-O=F5R('1H
M92!#4U8@9FEL92=S('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D9FEL96YA;64@(%1H92!N86UE(&]F('1H92!F:6QE('1O(&EN
M=F5S=&EG871E+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%S
M<V]C:6%T:79E(&%R<F%Y('=I=&@@=&AE(&9O;&QO=VEN9R!P;W-S:6)L92!K
M97ES.@H@("`@("H@/'!R93X*("`@("`J("=S97`G.B`@("!4:&4@9FEE;&0@
M<V5P87)A=&]R"B`@("`@*B`G<75O=&4G.B`@5&AE('%U;W1I;F<@8VAA<F%C
M=&5R"B`@("`@*B`G9FEE;&1S)SH@5&AE(&YU;6)E<B!O9B!F:65L9',@*&-O
M;'5M;G,I"B`@("`@*B`\+W!R93X*("`@("`J+PH@("`@9G5N8W1I;VX@9&ES
M8V]V97)&;W)M870H)&9I;&5N86UE*0H@("`@>PH@("`@("`@($!I;F-L=61E
M7V]N8V4H)T9I;&4O0U-6+G!H<"<I.PH@("`@("`@(&EF("AC;&%S<U]E>&ES
M=',H)T9I;&5?0U-6)RDI('L*("`@("`@("`@("`@<F5T=7)N($9I;&5?0U-6
M.CID:7-C;W9E<D9O<FUA="@D9FEL96YA;64I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B!A<G)A>2@G<V5P)R`]/B`G+"<I.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($EM<&]R=',@86YD('!A<G-E
M<R!A($-35B!F:6QE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9I
M;&5N86UE("!4:&4@;F%M92!O9B!T:&4@9FEL92!T;R!P87)S92X*("`@("`J
M($!P87)A;2!B;V]L96%N("1H96%D97(@("!$;V5S('1H92!F:7)S="!L:6YE
M(&-O;G1A:6X@=&AE(&9I96QD+V-O;'5M;@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@(&YA;65S/PH@("`@("H@0'!A<F%M('-T<FEN9R`D<V5P
M("`@("`@(%1H92!F:65L9"]C;VQU;6X@<V5P87)A=&]R+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<75O=&4@("`@(%1H92!Q=6]T:6YG(&-H87)A8W1E<BX*
M("`@("`J($!P87)A;2!I;G1E9V5R("1F:65L9',@("!4:&4@;G5M8F5R(&]R
M(&9I96QD<R]C;VQU;6YS+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VAA<G-E
M="`@(%1H92!F:6QE)W,@8VAA<G-E="X@0'-I;F-E($AO<F1E(#,N,2X*("`@
M("`J($!P87)A;2!S=')I;F<@)&-R;&8@("`@("!4:&4@9FEL92=S(&QI;F5F
M965D(&-H87)A8W1E<G,N($!S:6YC92!(;W)D92`S+C$N"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@02!T=V\M9&EM96YS:6]N86P@87)R87D@;V8@
M86QL(&EM<&]R=&5D(&1A=&$@<F]W<RX@($EF"B`@("`@*B`@("`@("`@("`@
M("`@("`D:&5A9&5R('=A<R!T<G5E('1H92!R;W=S(&%R92!A<W-O8VEA=&EV
M92!A<G)A>7,@=VET:"!T:&4*("`@("`J("`@("`@("`@("`@("`@(&9I96QD
M+V-O;'5M;B!N86UE<R!A<R!T:&4@:V5Y<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@:6UP;W)T1FEL92@D9FEL96YA;64L("1H96%D97(@/2!F86QS92P@)'-E
M<"`]("<G+"`D<75O=&4@/2`G)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M)&9I96QD<R`](&YU;&PL("1I;7!O<G1?;6%P<&EN9R`](&%R<F%Y*"DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("1C:&%R<V5T(#T@;G5L;"P@)&-R;&8@
M/2!N=6QL*0H@("`@>PH@("`@("`@($!I;F-L=61E7V]N8V4H)T9I;&4O0U-6
M+G!H<"<I.PH*("`@("`@("`D9&%T82`](&%R<F%Y*"D["@H@("`@("`@("\J
M($9I;&5?0U-6(&ES('!R97-E;G0N("HO"B`@("`@("`@:68@*&-L87-S7V5X
M:7-T<R@G1FEL95]#4U8G*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W=A<FYI
M;F=S(#T@87)R87DH*3L*"B`@("`@("`@("`@("\J($9I;&5?0U-6(&ES(&$@
M8FET('!I8VMY(&%T('=H870@<&%R86UE=&5R(&ET(&5X<&5C=',N("HO"B`@
M("`@("`@("`@("1C;VYF(#T@87)R87DH*3L*("`@("`@("`@("`@:68@*"%E
M;7!T>2@D<75O=&4I*2!["B`@("`@("`@("`@("`@("`D8V]N9ELG<75O=&4G
M72`]("1Q=6]T93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H96UP
M='DH)'-E<"DI('L*("`@("`@("`@("`@("`@("1C;VYF6R=S97`G72`]("<L
M)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1C;VYF
M6R=S97`G72`]("1S97`["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@
M*"1F:65L9',I('L*("`@("`@("`@("`@("`@("1C;VYF6R=F:65L9',G72`]
M("1F:65L9',["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("!R971U<FX@)&1A=&$["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@
M*"%E;7!T>2@D8W)L9BDI('L*("`@("`@("`@("`@("`@("1C;VYF6R=C<FQF
M)UT@/2`D8W)L9CL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@4W1R
M:7`@86YD(&ME97`@=&AE(&9I<G-T(&QI;F4@:68@:70@8V]N=&%I;G,@=&AE
M(&9I96QD"B`@("`@("`@("`@("`J(&YA;65S+B`J+PH@("`@("`@("`@("!I
M9B`H)&AE861E<BD@>PH@("`@("`@("`@("`@("`@)&AE860@/2!&:6QE7T-3
M5CHZ<F5A9"@D9FEL96YA;64L("1C;VYF*3L*("`@("`@("`@("`@("`@(&EF
M("AI<U]A*"1H96%D+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1H96%D.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@:68@*"%E;7!T>2@D8VAA<G-E="DI('L*("`@("`@("`@("`@
M("`@("`@("`D:&5A9"`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&AE860L
M("1C:&%R<V5T+"!.3%,Z.F=E=$-H87)S970H*2D["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@('=H:6QE("@D;&EN92`]
M($9I;&5?0U-6.CIR96%D*"1F:6QE;F%M92P@)&-O;F8I*2!["B`@("`@("`@
M("`@("`@("!I9B`H:7-?82@D;&EN92P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D;&EN93L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&-H87)S970I*2!["B`@
M("`@("`@("`@("`@("`@("`@)&QI;F4@/2!3=')I;F<Z.F-O;G9E<G1#:&%R
M<V5T*"1L:6YE+"`D8VAA<G-E="P@3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D:&5A
M9"DI('L*("`@("`@("`@("`@("`@("`@("`D9&%T85M=(#T@)&QI;F4["B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1N
M97=L:6YE(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@("!F;W(@*"1I
M(#T@,#L@)&D@/"!C;W5N="@D:&5A9"D[("1I*RLI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1I;7!O<G1?;6%P<&EN9ULD:&5A9%LD
M:5U=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&AE861;)&E=
M(#T@)&EM<&]R=%]M87!P:6YG6R1H96%D6R1I75T["B`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)&-E;&P@/2`D
M;&EN95LD:5T["B`@("`@("`@("`@("`@("`@("`@("`@("1C96QL(#T@<')E
M9U]R97!L86-E*"(O7")<(B\B+"`B7"(B+"`D8V5L;"D["B`@("`@("`@("`@
M("`@("`@("`@("`@("1N97=L:6YE6R1H96%D6R1I75T@/2!E;7!T>2@D8V5L
M;"D@/R`G)R`Z("1C96QL.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`D9&%T85M=(#T@)&YE=VQI;F4["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1F<"`]($9I;&5?
M0U-6.CIG9710;VEN=&5R*"1F:6QE;F%M92P@)&-O;F8I.PH@("`@("`@("`@
M("!I9B`H)&9P("8F("%I<U]A*"1F<"P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@<F5W:6YD*"1F<"D["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("1T:&ES+3Y?=V%R;FEN9W,@/2!&:6QE7T-35CHZ=V%R;FEN9R@I
M.PH*("`@("`@("`O*B!&86QL(&)A8VL@=&\@9F=E=&-S=B@I+B`J+PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1F<"`](&9O<&5N*"1F:6QE;F%M
M92P@)W(G*3L*("`@("`@("`@("`@:68@*"$D9G`I('L*("`@("`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M+RH@4W1R:7`@86YD(&ME97`@=&AE(&9I<G-T(&QI;F4@:68@:70@8V]N=&%I
M;G,@=&AE(&9I96QD"B`@("`@("`@("`@("`@(&YA;65S+B`J+PH@("`@("`@
M("`@("!I9B`H)&AE861E<BD@>PH@("`@("`@("`@("`@("`@)&AE860@/2!F
M9V5T8W-V*"1F<"P@,3`R-"P@)'-E<"D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@:68@*"%E;7!T>2@D8VAA<G-E="DI('L*("`@("`@("`@("`@("`@
M("1H96%D(#T@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D:&5A9"P@)&-H87)S
M970L($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!W:&EL92`H)&QI;F4@/2!F9V5T8W-V*"1F<"P@,3`R-"P@)'-E<"DI
M('L*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&-H87)S970I*2!["B`@
M("`@("`@("`@("`@("`@("`@)&QI;F4@/2!3=')I;F<Z.F-O;G9E<G1#:&%R
M<V5T*"1L:6YE+"`D8VAA<G-E="P@3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D:&5A
M9"DI('L*("`@("`@("`@("`@("`@("`@("`D9&%T85M=(#T@)&QI;F4["B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1N
M97=L:6YE(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@("!F;W(@*"1I
M(#T@,#L@)&D@/"!C;W5N="@D:&5A9"D[("1I*RLI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1I;7!O<G1?;6%P<&EN9ULD:&5A9%LD
M:5U=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&AE861;)&E=
M(#T@)&EM<&]R=%]M87!P:6YG6R1H96%D6R1I75T["B`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)&-E;&P@/2`D
M;&EN95LD:5T["B`@("`@("`@("`@("`@("`@("`@("`@("1C96QL(#T@<')E
M9U]R97!L86-E*"(O7"(O(BP@(EPB7"(B+"`D8V5L;"D["B`@("`@("`@("`@
M("`@("`@("`@("`@("1N97=L:6YE6R1H96%D6R1I75T@/2!E;7!T>2@D8V5L
M;"D@/R`G)R`Z("1C96QL.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`D9&%T85M=(#T@)&YE=VQI;F4["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&9C;&]S92@D9G`I
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&1A=&$["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!"=6EL9',@82!#4U8@9FEL92!F<F]M(&$@9VEV96X@9&%T
M82!S=')U8W1U<F4@86YD(')E='5R;G,@:70@87,@80H@("`@("H@<W1R:6YG
M+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D9&%T82`@("`@($$@='=O
M+61I;65N<VEO;F%L(&%R<F%Y(&-O;G1A:6YI;F<@=&AE(&1A=&$@<V5T+@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)&AE861E<B`@268@=')U92P@=&AE(')O
M=W,@;V8@)&1A=&$@87)E(&%S<V]C:6%T:79E"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("!A<G)A>7,@=VET:"!F:65L9"!N86UE<R!A<R!T:&5I
M<B!K97ES+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@0U-6
M(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X<&]R=$1A=&$H)&1A=&$L
M("1H96%D97(@/2!F86QS92P@)&5X<&]R=%]M87!P:6YG(#T@87)R87DH*2D*
M("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1D871A*2!\?"!C;W5N="@D
M9&%T82D@/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@
M?0H*("`@("`@("`D97AP;W)T(#T@)R<["B`@("`@("`@)&5O;"`](")<;B([
M"B`@("`@("`@)&AE860@/2!A<G)A>5]K97ES*&-U<G)E;G0H)&1A=&$I*3L*
M("`@("`@("!I9B`H)&AE861E<BD@>PH@("`@("`@("`@("!F;W)E86-H("@D
M:&5A9"!A<R`D:V5Y*2!["B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1K
M97DI*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1E>'!O<G1?
M;6%P<&EN9ULD:V5Y72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&ME
M>2`]("1E>'!O<G1?;6%P<&EN9ULD:V5Y73L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@)&5X<&]R="`N/2`G(B<@+B`D:V5Y
M("X@)R(G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&5X
M<&]R="`N/2`G+"<["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&5X<&]R
M="`]('-U8G-T<B@D97AP;W)T+"`P+"`M,2D@+B`D96]L.PH@("`@("`@('T*
M"B`@("`@("`@9F]R96%C:"`H)&1A=&$@87,@)')O=RD@>PH@("`@("`@("`@
M("!F;W)E86-H("@D:&5A9"!A<R`D:V5Y*2!["B`@("`@("`@("`@("`@("`D
M8V5L;"`]("1R;W=;)&ME>5T["B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y
M*"1C96QL*2!\?"`D8V5L;"`]/3T@,"D@>PH@("`@("`@("`@("`@("`@("`@
M("1E>'!O<G0@+CT@)R(G("X@)&-E;&P@+B`G(B<["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`D97AP;W)T("X]("<L)SL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D97AP;W)T(#T@<W5B<W1R*"1E>'!O<G0L(#`L
M("TQ*2`N("1E;VP["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&5X<&]R
M=#L*("`@('T*"B`@("`O*BH*("`@("`J($)U:6QD<R!A($-35B!F:6QE(&9R
M;VT@82!G:79E;B!D871A('-T<G5C='5R92!A;F0@=')I9V=E<G,@:71S"B`@
M("`@*B!D;W=N;&]A9"X@($ET($1/15,@3D]4(&5X:70@=&AE(&-U<G)E;G0@
M<V-R:7!T(&)U="!O;FQY(&]U='!U=',@=&AE"B`@("`@*B!C;W)R96-T(&AE
M861E<G,@86YD(&1A=&$N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M9FEL96YA;64@(%1H92!N86UE(&]F('1H92!F:6QE('1O(&)E(&1O=VYL;V%D
M960N"B`@("`@*B!`<&%R86T@87)R87D@)&1A=&$@("`@("`@02!T=V\M9&EM
M96YS:6]N86P@87)R87D@8V]N=&%I;FEN9R!T:&4@9&%T80H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@('-E="X*("`@("`J($!P87)A;2!B;V]L
M96%N("1H96%D97(@("!)9B!T<G5E+"!T:&4@<F]W<R!O9B`D9&%T82!A<F4@
M87-S;V-I871I=F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>7,@=VET:"!F:65L9"!N86UE<R!A<R!T:&5I<B!K97ES+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!E>'!O<G1&:6QE*"1F:6QE;F%M92P@)&1A=&$L("1H
M96%D97(@/2!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@)&5X<&]R
M=%]M87!P:6YG(#T@87)R87DH*2D*("`@('L*("`@("`@("`D97AP;W)T(#T@
M)'1H:7,M/F5X<&]R=$1A=&$H)&1A=&$L("1H96%D97(L("1E>'!O<G1?;6%P
M<&EN9RD["B`@("`@("`@)$=,3T)!3%-;)V)R;W=S97(G72T^9&]W;FQO861(
M96%D97)S*"1F:6QE;F%M92P@)V%P<&QI8V%T:6]N+V-S=B<L(&9A;'-E+"!S
M=')L96XH)&5X<&]R="DI.PH@("`@("`@(&5C:&\@)&5X<&]R=#L*("`@('T*
M"B`@("`O*BH*("`@("`J(%1A:V5S(&%L;"!N96-E<W-A<GD@86-T:6]N<R!F
M;W(@=&AE(&=I=F5N(&EM<&]R="!S=&5P+"!P87)A;65T97)S(&%N9`H@("`@
M("H@9F]R;2!V86QU97,@86YD(')E='5R;G,@=&AE(&YE>'0@;F5C97-S87)Y
M('-T97`N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&%C=&EO;B`@
M5&AE(&-U<G)E;G0@<W1E<"X@3VYE(&]F('1H92!)35!/4E1?*B!C;VYS=&%N
M=',N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M("`@("!!;B!A<W-O8VEA
M=&EV92!A<G)A>2!C;VYT86EN:6YG(&YE961E9`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@<&%R86UE=&5R<R!F;W(@=&AE(&-U<G)E;G0@<W1E
M<"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!%:71H97(@=&AE(&YE
M>'0@<W1E<"!A<R!A;B!I;G1E9V5R(&-O;G-T86YT(&]R(&EM<&]R=&5D"B`@
M("`@*B`@("`@("`@("`@("`@("!D871A('-E="!A9G1E<B!T:&4@9FEN86P@
M<W1E<"X*("`@("`J+PH@("`@9G5N8W1I;VX@;F5X=%-T97`H)&%C=&EO;BP@
M)'!A<F%M(#T@87)R87DH*2D*("`@('L*("`@("`@("!S=VET8V@@*"1A8W1I
M;VXI('L*("`@("`@("!C87-E($E-4$]25%]&24Q%.@H@("`@("`@("`@("`D
M;F5X=%]S=&5P(#T@<&%R96YT.CIN97AT4W1E<"@D86-T:6]N+"`D<&%R86TI
M.PH@("`@("`@("`@("!I9B`H:7-?82@D;F5X=%]S=&5P+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&YE>'1?<W1E<#L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@+RH@36]V92!U<&QO861E9"!F:6QE
M('-O('1H870@=V4@8V%N(')E860@:70@86=A:6X@:6X@=&AE(&YE>'0*("`@
M("`@("`@("`@("`@<W1E<"!A9G1E<B!T:&4@=7-E<B!G879E('-O;64@9F]R
M;6%T(&1E=&%I;',N("HO"B`@("`@("`@("`@("1F:6QE7VYA;64@/2!(;W)D
M93HZ9V5T5&5M<$9I;&4H)VEM<&]R="<L(&9A;'-E*3L*("`@("`@("`@("`@
M:68@*"%M;W9E7W5P;&]A9&5D7V9I;&4H)%]&24Q%4ULG:6UP;W)T7V9I;&4G
M75LG=&UP7VYA;64G72P@)&9I;&5?;F%M92DI('L*("`@("`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E1H92!U<&QO861E9"!F:6QE
M(&-O=6QD(&YO="!B92!S879E9"XB*2D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)%]315-324].6R=I;7!O<G1?9&%T82==6R=F:6QE7VYA;64G72`]
M("1F:6QE7VYA;64["@H@("`@("`@("`@("`O*B!4<GD@=&\@9&ES8V]V97(@
M=&AE(&9I;&4@9F]R;6%T(&]U<G-E;'9E<RX@*B\*("`@("`@("`@("`@)&-O
M;F8@/2`D=&AI<RT^9&ES8V]V97)&;W)M870H)&9I;&5?;F%M92D["B`@("`@
M("`@("`@(&EF("@A)&-O;F8I('L*("`@("`@("`@("`@("`@("1C;VYF(#T@
M87)R87DH)W-E<"<@/3X@)RPG*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D7U-%4U-)3TY;)VEM<&]R=%]D871A)UT@/2!A<G)A>5]M97)G92@D7U-%
M4U-)3TY;)VEM<&]R=%]D871A)UTL("1C;VYF*3L*"B`@("`@("`@("`@("\J
M($-H96-K(&EF(&-H87)S970@=V%S('-P96-I9FEE9"X@*B\*("`@("`@("`@
M("`@)%]315-324].6R=I;7!O<G1?9&%T82==6R=C:&%R<V5T)UT@/2!5=&EL
M.CIG971&;W)M1&%T82@G8VAA<G-E="<I.PH*("`@("`@("`@("`@+RH@4F5A
M9"!T:&4@9FEL92=S(&9I<G-T('1W;R!L:6YE<R!T;R!S:&]W('1H96T@=&\@
M=&AE('5S97(N("HO"B`@("`@("`@("`@("1?4T534TE/3ELG:6UP;W)T7V1A
M=&$G75LG9FER<W1?;&EN97,G72`]("<G.PH@("`@("`@("`@("`D9G`@/2!`
M9F]P96XH)&9I;&5?;F%M92P@)W(G*3L*("`@("`@("`@("`@:68@*"1F<"D@
M>PH@("`@("`@("`@("`@("`@)&QI;F5?;F\@/2`Q.PH@("`@("`@("`@("`@
M("`@=VAI;&4@*"1L:6YE7VYO(#P@,R`F)B`D;&EN92`](&9G971S*"1F<"DI
M('L*("`@("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1?4T534TE/3ELG
M:6UP;W)T7V1A=&$G75LG8VAA<G-E="==*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D;&EN92`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&QI;F4L
M("1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG8VAA<G-E="==+"!.3%,Z.F=E
M=$-H87)S970H*2D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@("1N97=L:6YE(#T@4W1R:6YG.CIL96YG=&@H)&QI;F4I(#X@
M,3`P(#\@(EQN(B`Z("<G.PH@("`@("`@("`@("`@("`@("`@("1?4T534TE/
M3ELG:6UP;W)T7V1A=&$G75LG9FER<W1?;&EN97,G72`N/2!S=6)S='(H)&QI
M;F4L(#`L(#$P,"D@+B`D;F5W;&EN93L*("`@("`@("`@("`@("`@("`@("`D
M;&EN95]N;RLK.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@("`@(')E='5R;B!)35!/4E1?0U-6.PH*("`@("`@("!C87-E($E-
M4$]25%]#4U8Z"B`@("`@("`@("`@("1?4T534TE/3ELG:6UP;W)T7V1A=&$G
M75LG:&5A9&5R)UT@/2!5=&EL.CIG971&;W)M1&%T82@G:&5A9&5R)RD["B`@
M("`@("`@("`@("1I;7!O<G1?;6%P<&EN9R`](&%R<F%Y*"D["B`@("`@("`@
M("`@(&EF("AI<W-E="@D<&%R86U;)VEM<&]R=%]M87!P:6YG)UTI*2!["B`@
M("`@("`@("`@("`@("`D:6UP;W)T7VUA<'!I;F<@/2`D<&%R86U;)VEM<&]R
M=%]M87!P:6YG)UT["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&EM<&]R
M=%]D871A(#T@)'1H:7,M/FEM<&]R=$9I;&4H)%]315-324].6R=I;7!O<G1?
M9&%T82==6R=F:6QE7VYA;64G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)%]315-324].6R=I;7!O<G1?9&%T82==
M6R=H96%D97(G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@571I;#HZ9V5T1F]R;41A=&$H)W-E<"<I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!5=&EL.CIG
M971&;W)M1&%T82@G<75O=&4G*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@571I;#HZ9V5T1F]R;41A=&$H)V9I96QD
M<R<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D:6UP;W)T7VUA<'!I;F<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1?4T534TE/3ELG:6UP;W)T7V1A=&$G
M75LG8VAA<G-E="==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)V-R;&8G
M72D["B`@("`@("`@("`@("1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG9&%T
M82==(#T@)&EM<&]R=%]D871A.PH@("`@("`@("`@("!U;G-E="@D7U-%4U-)
M3TY;)VEM<&]R=%]D871A)UU;)VUA<"==*3L*("`@("`@("`@("`@<F5T=7)N
M($E-4$]25%]-05!0140["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@
M(')E='5R;B!P87)E;G0Z.FYE>'13=&5P*"1A8W1I;VXL("1P87)A;2D["B`@
M("`@("`@?0H@("`@?0H*?0H`````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T=R87!H````````````
M````````````````````````````````````````````````````````````
M`````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P
M-3$U-#,S-S,U(#`R,#,S,@`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O1W)A<&@O4&QO=```````````````````````````````````````````
M````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S4@,#(Q,C4P`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92]'<F%P:"]0;&]T+V)A<F=R;W5P960N<&AP
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C4W,B`Q,#4Q-30S,S<S-2`P
M,C0R,#``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O1W)A<&@O4&QO="]B87(N
M<&AP)SL*"B\J*@H@*B!'<F]U<&5D(&)A<B!G<F%P:"!I;7!L96UE;G1A=&EO
M;B!F;W(@=&AE($AO<F1E7T=R87!H('!A8VMA9V4N"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+T=R87!H+T=R87!H+U!L;W0O8F%R9W)O=7!E9"YP:'`L=B`Q
M+C$N,3`N-"`R,#`V+S`Q+S`Q(#(Q.C(X.C$X(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G
M96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N
M,`H@*B!`<&%C:V%G92!(;W)D95]'<F%P:`H@*B\*8VQA<W,@2&]R9&5?1W)A
M<&A?4&QO=%]B87)G<F]U<&5D(&5X=&5N9',@2&]R9&5?1W)A<&A?4&QO=%]B
M87(@>PH*("`@('9A<B`D7W-T97`@/2`N-3L*("`@('9A<B`D7V-O;&]R<R`]
M(&%R<F%Y*"D["B`@("!V87(@)%]D871A<V5T<R`](&%R<F%Y*"D["@H@("`@
M9G5N8W1I;VX@9')A=R@I"B`@("!["B`@("`@("`@+R\@0V%L8W5L871E('1H
M92!S=&%R=&EN9R!O9F9S970@9F]R(&5A8V@@8F%R+"!F<F]M('=H:6-H('=E
M"B`@("`@("`@+R\@;6]V92!I="!O=F5R(&)Y("1T:&ES+3Y?<W1E<"X*("`@
M("`@("`D9&%T87-E=',@/2!C;W5N="@D=&AI<RT^7V1A=&%S971S*3L*("`@
M("`@("`D9VQO8F%L3V9F<V5T(#T@)'1H:7,M/E]O9F9S970@+2`H*"1T:&ES
M+3Y?<W1E<"`J("@D9&%T87-E=',@+2`Q*2D@+R`R*3L*"B`@("`@("`@9F]R
M("@D:2`](#`[("1I(#P@)&1A=&%S971S.R`D:2LK*2!["B`@("`@("`@("`@
M("\O($-A;&-U;&%T92!T:&4@;V9F<V5T(&]F('1H:7,@<V5T(&]F(&)A<G,N
M"B`@("`@("`@("`@("1T:&ES+3Y?;V9F<V5T(#T@)&=L;V)A;$]F9G-E="`K
M("@D=&AI<RT^7W-T97`@*B`D:2D["@H@("`@("`@("`@("`O+R!3970@8F%R
M('!A<F%M971E<G,@=&AA="!C:&%N9V4@<&5R+6=R;W5P+@H@("`@("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]C;VQO<G-;)&E=*2D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]C;VQO<B`]("1T:&ES+3Y?8V]L;W)S6R1I73L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7V1A=&%S970@/2`D=&AI
M<RT^7V1A=&%S971S6R1I73L*"B`@("`@("`@("`@("\O($1R87<@=&AI<R!D
M871A<V5T+@H@("`@("`@("`@("!P87)E;G0Z.F1R87<H*3L*("`@("`@("!]
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T=R
M87!H+U!L;W0O8F%R+G!H<```````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`S,#(S(#$P-3$U-#,S-S,U(#`R,C8P,@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@0F%R(&=R
M87!H(&EM<&QE;65N=&%T:6]N(&9O<B!T:&4@2&]R9&5?1W)A<&@@<&%C:V%G
M92X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO1W)A<&@O1W)A<&@O4&QO="]B
M87(N<&AP+'8@,2XU+C$R+C0@,C`P-B\P,2\P,2`R,3HR.#HQ."!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@
M("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?1W)A<&@*("HO"F-L87-S
M($AO<F1E7T=R87!H7U!L;W1?8F%R('L*"B`@("!V87(@)&=R87!H.PH*("`@
M('9A<B`D7V-O;&]R(#T@)V)L=64G.PH@("`@=F%R("1?;W5T;&EN92`]("=B
M;&%C:R<["B`@("!V87(@)%]W:61T:"`](#$P.PH@("`@=F%R("1?;V9F<V5T
M(#T@,#L*("`@('9A<B`D7V1A=&%S970["@H@("`@9G5N8W1I;VX@2&]R9&5?
M1W)A<&A?4&QO=%]B87(H)B1G<F%P:"P@)'!A<F%M<RD*("`@('L*("`@("`@
M("`D=&AI<RT^9W)A<&@@/2`F)&=R87!H.PH*("`@("`@("!F;W)E86-H("@D
M<&%R86US(&%S("1P87)A;2`]/B`D=F%L=64I('L*("`@("`@("`@("`@)&ME
M>2`]("=?)R`N("1P87)A;3L*("`@("`@("`@("`@)'1H:7,M/B1K97D@/2`D
M=F%L=64["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&1R87<H)&UI
M;ED@/2!F86QS92D*("`@('L*("`@("`@("`D9&%T82`]("1T:&ES+3YG<F%P
M:"T^7V1A=&%;)WDG75LD=&AI<RT^7V1A=&%S971=.PH*("`@("`@("`D8F%R
M5VED=&@@/2`D=&AI<RT^7W=I9'1H.PH@("`@("`@("1B87)/9F9S970@/2`D
M=&AI<RT^7V]F9G-E="`J("1B87)7:61T:#L*("`@("`@("`D=2`](#`["B`@
M("`@("`@)'8@/2`P.PH@("`@("`@("1C;W5N="`](&-O=6YT*"1D871A*3L*
M("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D8V]U;G0[("1I*RLI('L*("`@
M("`@("`@("`@)'@@/2`D:3L*("`@("`@("`@("`@:68@*"1M:6Y9(#T]/2!F
M86QS92!\?"`D9&%T85LD:5T@/CT@)&UI;EDI('L*("`@("`@("`@("`@("`@
M("1Y(#T@)&1A=&%;)&E=.PH@("`@("`@("`@("`@("`@)'1H:7,M/F=R87!H
M+3YT<F%N<VQA=&4H)'@L("1Y*3L*("`@("`@("`@("`@("`@("1X(#T@)'@@
M+2`H)&)A<E=I9'1H("\@,BD@*R`D8F%R3V9F<V5T.PH@("`@("`@("`@("`@
M("`@)&AE:6=H="`]("1T:&ES+3YG<F%P:"T^7V=R87!H0F]T=&]M("T@)'D[
M"@H@("`@("`@("`@("`@("`@)'1H:7,M/F=R87!H+3YI;6<M/G)E8W1A;F=L
M92@D>"P@)'DL("1B87)7:61T:"P@)&AE:6=H="P@)'1H:7,M/E]O=71L:6YE
M+"`D=&AI<RT^7V-O;&]R*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]'<F%P:"]0
M;&]T+V)A<G-T86-K960N<&AP````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,38R-2`Q,#4Q-30S,S<S-2`P,C0Q-#<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%-T86-K960@8F%R
M(&=R87!H(&EM<&QE;65N=&%T:6]N(&9O<B!T:&4@2&]R9&5?1W)A<&@@<&%C
M:V%G92X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO1W)A<&@O1W)A<&@O4&QO
M="]B87)S=&%C:V5D+G!H<"QV(#$N,2XQ,"XT(#(P,#8O,#$O,#$@,C$Z,C@Z
M,3@@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU8VL@
M2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@
M*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*
M("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T=R87!H
M"B`J+PIC;&%S<R!(;W)D95]'<F%P:%]0;&]T7V)A<G-T86-K960@>PH*("`@
M('9A<B`D9W)A<&@["@H@("`@=F%R("1?8V]L;W(@/2`G8FQU92<["B`@("!V
M87(@)%]O=71L:6YE(#T@)V)L86-K)SL*("`@('9A<B`D7W=I9'1H(#T@,3`[
M"B`@("!V87(@)%]O9F9S970@/2`P.PH@("`@=F%R("1?9&%T87-E=#L*"B`@
M("!F=6YC=&EO;B!(;W)D95]'<F%P:%]0;&]T7V)A<G-T86-K960H)B1G<F%P
M:"P@)'!A<F%M<RD*("`@('L*("`@("`@("`D=&AI<RT^9W)A<&@@/2`F)&=R
M87!H.PH*("`@("`@("!F;W)E86-H("@D<&%R86US(&%S("1P87)A;2`]/B`D
M=F%L=64I('L*("`@("`@("`@("`@)&ME>2`]("=?)R`N("1P87)A;3L*("`@
M("`@("`@("`@)'1H:7,M/B1K97D@/2`D=F%L=64["B`@("`@("`@?0H@("`@
M?0H*("`@(&9U;F-T:6]N(&1R87<H*0H@("`@>PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]'
M<F%P:"]0;&]T+VQI;F4N<&AP````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,S(U-R`Q,#4Q-30S,S<S-2`P,C(W-S8`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J($QI;F4@
M9W)A<&@@:6UP;&5M96YT871I;VX@9F]R('1H92!(;W)D95]'<F%P:"!P86-K
M86=E+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]'<F%P:"]'<F%P:"]0;&]T
M+VQI;F4N<&AP+'8@,2XT+C$R+C0@,C`P-B\P,2\P,2`R,3HR.#HQ."!J86X@
M17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U
M8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN
M8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?1W)A<&@*("HO"F-L
M87-S($AO<F1E7T=R87!H7U!L;W1?;&EN92!["@H@("`@=F%R("1?9W)A<&@[
M"B`@("!V87(@)%]C;VQO<B`]("=B;'5E)SL*("`@('9A<B`D7W=I9'1H(#T@
M,3L*("`@('9A<B`D7V1A=&%S970["@H@("`@9G5N8W1I;VX@2&]R9&5?1W)A
M<&A?4&QO=%]L:6YE*"8D9W)A<&@L("1P87)A;7,I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]G<F%P:"`]("8D9W)A<&@["@H@("`@("`@(&9O<F5A8V@@*"1P
M87)A;7,@87,@)'!A<F%M(#T^("1V86QU92D@>PH@("`@("`@("`@("`D:V5Y
M(#T@)U\G("X@)'!A<F%M.PH@("`@("`@("`@("`D=&AI<RT^)&ME>2`]("1V
M86QU93L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@9')A=R@D;6EN
M62`](&9A;'-E*0H@("`@>PH@("`@("`@("1D871A(#T@)'1H:7,M/E]G<F%P
M:"T^7V1A=&%;)WDG75LD=&AI<RT^7V1A=&%S971=.PH*("`@("`@("`D8V]U
M;G0@/2!C;W5N="@D9&%T82D["B`@("`@("`@)'9E<G1S(#T@87)R87DH*3L*
M("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D8V]U;G0[("1I*RLI('L*("`@
M("`@("`@("`@)'@@/2`D:3L*("`@("`@("`@("`@:68@*"1M:6Y9("$]/2!F
M86QS92`F)B`D9&%T85LD:5T@/"`D;6EN62D@>PH@("`@("`@("`@("`@("`@
M:68@*&-O=6YT*"1V97)T<RD@/3T@,2D@>PH@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?9W)A<&@M/FEM9RT^8VER8VQE*"1V97)T<ULP75LG>"==+"`D
M=F5R='-;,%U;)WDG72P@)'1H:7,M/E]W:61T:"P@)'1H:7,M/E]C;VQO<BP@
M)'1H:7,M/E]C;VQO<BD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=R87!H
M+3YI;6<M/G!O;'EL:6YE*"1V97)T<RP@)'1H:7,M/E]C;VQO<BP@)'1H:7,M
M/E]W:61T:"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M=F5R=',@/2!A<G)A>2@I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L
M<V4@>PH@("`@("`@("`@("`@("`@)'D@/2`D9&%T85LD:5T["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V=R87!H+3YT<F%N<VQA=&4H)'@L("1Y*3L*("`@
M("`@("`@("`@("`@("1V97)T<UM=(#T@87)R87DH)W@G(#T^("1X+"`G>2<@
M/3X@)'DI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D=&AI
M<RT^7V=R87!H+3YI;6<M/G!O;'EL:6YE*"1V97)T<RP@)'1H:7,M/E]C;VQO
M<BP@)'1H:7,M/E]W:61T:"D["B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O1W)A<&@O
M4&QO="]S8V%T=&5R+G!H<```````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#(T,C$@,3`U,34T,S,W,S4@,#(S-3`T`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B!38V%T=&5R('!L
M;W0@:6UP;&5M96YT871I;VX@9F]R('1H92!(;W)D95]'<F%P:"!P86-K86=E
M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]'<F%P:"]'<F%P:"]0;&]T+W-C
M871T97(N<&AP+'8@,2XS+C$R+C0@,C`P-B\P,2\P,2`R,3HR.#HQ."!J86X@
M17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U
M8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN
M8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?1W)A<&@*("HO"F-L
M87-S($AO<F1E7T=R87!H7U!L;W1?<V-A='1E<B!["@H@("`@=F%R("1?9W)A
M<&@["B`@("!V87(@)%]C;VQO<B`]("=B;'5E)SL*("`@('9A<B`D7W-H87!E
M(#T@)W-Q=6%R92<["B`@("!V87(@)%]D871A<V5T.PH*("`@(&9U;F-T:6]N
M($AO<F1E7T=R87!H7U!L;W1?<V-A='1E<B@F)&=R87!H+"`D<&%R86US*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?9W)A<&@@/2`F)&=R87!H.PH*("`@("`@
M("!F;W)E86-H("@D<&%R86US(&%S("1P87)A;2`]/B`D=F%L=64I('L*("`@
M("`@("`@("`@)&ME>2`]("=?)R`N("1P87)A;3L*("`@("`@("`@("`@)'1H
M:7,M/B1K97D@/2`D=F%L=64["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T
M:6]N(&1R87<H)&UI;ED@/2!F86QS92D*("`@('L*("`@("`@("`D9&%T82`]
M("1T:&ES+3Y?9W)A<&@M/E]D871A6R=Y)UU;)'1H:7,M/E]D871A<V5T73L*
M"B`@("`@("`@)&-O=6YT(#T@8V]U;G0H)&1A=&$I.PH@("`@("`@("1V97)T
M<R`](&%R<F%Y*"D["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&-O=6YT
M.R`D:2LK*2!["B`@("`@("`@("`@("1X(#T@)&D["B`@("`@("`@("`@(&EF
M("@D;6EN62`]/3T@9F%L<V4@?'P@)&1A=&%;)&E=(#X]("1M:6Y9*2!["B`@
M("`@("`@("`@("`@("`D>2`]("1D871A6R1I73L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?9W)A<&@M/G1R86YS;&%T92@D>"P@)'DI.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]G<F%P:"T^:6UG+3YB<G5S:"@D>"P@)'DL("1T:&ES
M+3Y?8V]L;W(L("1T:&ES+3Y?<VAA<&4I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@?0H*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B](;W)D92]'<F%P:"]#:&%R=```````````````````````
M```````````````````````````````````````````````````P,#`W-34@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<S-2`P,C$S
M-S,`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T=R87!H+T-H87)T
M+W!I93-D+G!H<```````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,S8W
M(#$P-3$U-#,S-S,U(#`R,S$W-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@,T0@4&EE(&=R87!H(&EM
M<&QE;65N=&%T:6]N(&9O<B!T:&4@2&]R9&5?1W)A<&@@<&%C:V%G92X*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO1W)A<&@O1W)A<&@O0VAA<G0O<&EE,V0N
M<&AP+'8@,2XQ+C$P+C0@,C`P-B\P,2\P,2`R,3HR.#HQ."!J86X@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H
M=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(
M;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?1W)A<&@*("HO"F-L87-S($AO
M<F1E7T=R87!H7T-H87)T7W!I93-D('L*"B`@("!V87(@)&=R87!H.PH*("`@
M('9A<B`D7V1A=&%S970["B`@("!V87(@)%]P861D:6YG(#T@,C`["B`@("!V
M87(@)%]O=71L:6YE(#T@=')U93L*("`@('9A<B`D7V-O;&]R<R`](&%R<F%Y
M*"=T86XG+"`G<&%L96=O;&1E;G)O9"<L("=O;&EV961R86(G+"`G8FQU92<L
M("=R960G+"`G9W)E96XG+"`G>65L;&]W)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("=O<F%N9V4G+"`G9W)A>2<L("=P=7)P;&4G*3L*("`@("\J*@H@
M("`@("`B,C4U+#$U,RPP(BP*("`@("`@(C`L,C`T+#$U,R(L"B`@("`@("(R
M,#0L,C4U+#$P,B(L"B`@("`@("(R-34L,3`R+#$P,B(L"B`@("`@("(Q,#(L
M,C`T+#(U-2(L"B`@("`@("(R,#0L,34S+#(U-2(L"B`@("`@("(R-34L,"PP
M(BP*("`@("`@(C4Q+#`L,C4U(BP*("`@("`@(C(U-2PU,2PQ-3,B+`H@("`@
M("`B,C`T+#`L,C4U(BP*("`@("`@(C(U-2PR-34L-3$B+`H@("`@("`B-3$L
M,C4U+#4Q(BP*("`@("`@(C(U-2PQ,#(L,"(I.PH@("`@*B\*"B`@("!F=6YC
M=&EO;B!(;W)D95]'<F%P:%]#:&%R=%]P:64S9"@F)&=R87!H+"`D<&%R86US
M*0H@("`@>PH@("`@("`@("1T:&ES+3YG<F%P:"`]("8D9W)A<&@["@H@("`@
M("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)'!A<F%M(#T^("1V86QU92D@>PH@
M("`@("`@("`@("`D:V5Y(#T@)U\G("X@)'!A<F%M.PH@("`@("`@("`@("`D
M=&AI<RT^)&ME>2`]("1V86QU93L*("`@("`@("!]"B`@("!]"@H@("`@9G5N
M8W1I;VX@9')A=R@I"B`@("!["B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O1W)A<&@O0VAA<G0O<&EE+G!H<```````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,3`W,3<@,3`U,34T,S,W,S4@,#(R-S0V`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B!0:64@9W)A<&@@:6UP;&5M96YT871I;VX@9F]R('1H92!(;W)D
M95]'<F%P:"!P86-K86=E+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]'<F%P
M:"]'<F%P:"]#:&%R="]P:64N<&AP+'8@,2XQ,"XQ,"XT(#(P,#8O,#$O,#$@
M,C$Z,C@Z,3@@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E
M+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E
M7T=R87!H"B`J+PIC;&%S<R!(;W)D95]'<F%P:%]#:&%R=%]P:64@>PH*("`@
M('9A<B`D9W)A<&@["@H@("`@=F%R("1?9&%T87-E=#L*("`@('9A<B`D7W!A
M9&1I;F<@/2`R,#L*("`@('9A<B`D7V]U=&QI;F4@/2!T<G5E.PH@("`@=F%R
M("1?8V]L;W)S(#T@87)R87DH)W1A;B<L("=P86QE9V]L9&5N<F]D)RP@)V]L
M:79E9')A8B<L("=B;'5E)RP@)W)E9"<L("=G<F5E;B<L("=Y96QL;W<G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@)V]R86YG92<L("=G<F%Y)RP@)W!U
M<G!L92<I.PH@("`@+RHJ"B`@("`@("(R-34L,34S+#`B+`H@("`@("`B,"PR
M,#0L,34S(BP*("`@("`@(C(P-"PR-34L,3`R(BP*("`@("`@(C(U-2PQ,#(L
M,3`R(BP*("`@("`@(C$P,BPR,#0L,C4U(BP*("`@("`@(C(P-"PQ-3,L,C4U
M(BP*("`@("`@(C(U-2PP+#`B+`H@("`@("`B-3$L,"PR-34B+`H@("`@("`B
M,C4U+#4Q+#$U,R(L"B`@("`@("(R,#0L,"PR-34B+`H@("`@("`B,C4U+#(U
M-2PU,2(L"B`@("`@("(U,2PR-34L-3$B+`H@("`@("`B,C4U+#$P,BPP(BD[
M"B`@("`J+PH*("`@(&9U;F-T:6]N($AO<F1E7T=R87!H7T-H87)T7W!I92@F
M)&=R87!H+"`D<&%R86US*0H@("`@>PH@("`@("`@("1T:&ES+3YG<F%P:"`]
M("8D9W)A<&@["@H@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)'!A<F%M
M(#T^("1V86QU92D@>PH@("`@("`@("`@("`D:V5Y(#T@)U\G("X@)'!A<F%M
M.PH@("`@("`@("`@("`D=&AI<RT^)&ME>2`]("1V86QU93L*("`@("`@("!]
M"B`@("!]"@H@("`@9G5N8W1I;VX@9')A=R@I"B`@("!["B`@("`@("`@)&1A
M=&$@/2`D=&AI<RT^9W)A<&@M/E]D871A6R=Y)UU;)'1H:7,M/E]D871A<V5T
M73L*"B`@("`@("`@+R\@26YI=&EA;&EZ92!S;VUE('9A<FEA8FQE<RX*("`@
M("`@("`D9&EA;65T97(@/2!M:6XH)'1H:7,M/F=R87!H+3Y?9W)A<&A7:61T
M:"P@)'1H:7,M/F=R87!H+3Y?9W)A<&A(96EG:'0I("T@*"1T:&ES+3Y?<&%D
M9&EN9R`J(#(I.PH@("`@("`@("1R861I=7,@/2`D9&EA;65T97(@+R`R.PH@
M("`@("`@("1C;W5N="`](&-O=6YT*"1D871A*3L*("`@("`@("`D>&-E;G1E
M<B`]("1T:&ES+3YG<F%P:"T^7V=R87!H3&5F="`K("1T:&ES+3Y?<&%D9&EN
M9R`K("@D=&AI<RT^9W)A<&@M/E]G<F%P:%=I9'1H("\@,BD["B`@("`@("`@
M)'EC96YT97(@/2`D=&AI<RT^9W)A<&@M/E]G<F%P:%1O<"`K("1T:&ES+3Y?
M<&%D9&EN9R`K("@D=&AI<RT^9W)A<&@M/E]G<F%P:$AE:6=H="`O(#(I.PH*
M("`@("`@("`O+R!#86QC=6QA=&4@=&AE('-U;2!O9B!A;&P@<VQI8V5S+@H@
M("`@("`@("1S=6T@/2`P.PH@("`@("`@(&9O<F5A8V@@*"1D871A(&%S("1X
M*2!["B`@("`@("`@("`@("1S=6T@*ST@)'@["B`@("`@("`@?0H*("`@("`@
M("`O+R!#;VYV97)T(&5A8V@@<VQI8V4@:6YT;R!T:&4@8V]R<F5S<&]N9&EN
M9R!P97)C96YT86=E(&]F(&$*("`@("`@("`O+R`S-C`M9&5G<F5E(&-I<F-L
M92X*("`@("`@("`D9&5G0V]U;G0@/2`P.PH@("`@("`@("1S;&EC97,@/2!A
M<G)A>2@I.PH@("`@("`@("1D96=R965S(#T@87)R87DH*3L*("`@("`@("!F
M;W)E86-H("@D9&%T82!A<R`D:2`]/B`D>2D@>PH@("`@("`@("`@("!I9B`H
M*"@D>2`O("1S=6TI("H@,S8P*2`^(#`I('L*("`@("`@("`@("`@("`@("1D
M96=R965S6R1D96=#;W5N=%T@/2`H)'D@+R`D<W5M*2`J(#,V,#L*("`@("`@
M("`@("`@("`@("1S;&EC97-;)&1E9T-O=6YT72`]("1Y.PH@("`@("`@("`@
M("`@("`@)&YA;65S6R1D96=#;W5N=%T@/2!I<W-E="@D=&AI<RT^9W)A<&@M
M/E]D871A6R=X)UU;)&E=*2`_("1T:&ES+3YG<F%P:"T^7V1A=&%;)W@G75LD
M:5T@.B`G)SL*("`@("`@("`@("`@("`@("1D96=#;W5N="LK.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!$<F%W('1H92!B87-E;&EN
M92X*("`@("`@("!I9B`H)&-O=6YT(#X@,2D@>PH@("`@("`@("`@("`D;&%S
M=%]A;F=L92`](#`["B`@("`@("`@("`@("1C;W5N="`](&-O=6YT*"1D96=R
M965S*3L*("`@("`@("`@("`@9F]R("@D>B`](#`[("1Z(#P@)&-O=6YT.R`D
M>BLK*2!["B`@("`@("`@("`@("`@("`O+R!#86QC=6QA=&4@86YD(&1R87<@
M87)C<R!C;W)R97-P;VYD:6YG('1O(&5A8V@*("`@("`@("`@("`@("`@("\O
M('-L:6-E+@H@("`@("`@("`@("`@("`@)&-Z(#T@)'H@)2!C;W5N="@D=&AI
M<RT^7V-O;&]R<RD["B`@("`@("`@("`@("`@("`D=&AI<RT^9W)A<&@M/FEM
M9RT^87)C*"1X8V5N=&5R+"`D>6-E;G1E<BP@)')A9&EU<RP@)&QA<W1?86YG
M;&4L("@D;&%S=%]A;F=L92`K("1D96=R965S6R1Z72DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T;&EN92`_
M("=B;&%C:R<@.B`D=&AI<RT^7V-O;&]R<ULD8WI=+"`D=&AI<RT^7V-O;&]R
M<ULD8WI=*3L*("`@("`@("`@("`@("`@("1L87-T7V%N9VQE(#T@)&QA<W1?
M86YG;&4@*R`D9&5G<F5E<ULD>ET["B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^9W)A<&@M/FEM9RT^8VER8VQE
M*"1X8V5N=&5R+"`D>6-E;G1E<BP@)')A9&EU<RP@)V)L86-K)RP@)'1H:7,M
M/E]C;VQO<G-;,%TI.PH@("`@("`@('T*"B`@("`@("`@+R\@0W)E871E('1H
M92!C;VQO<B!K97D@86YD('-L:6-E(&QA8F5L<RX*("`@("`@("`D>4)A<V4@
M/2`D=&AI<RT^9W)A<&@M/E]G<F%P:%1O<#L*("`@("`@("`D>$)A<V4@/2`U
M.PH@("`@("`@("1M87@@/2!S=')L96XH*'-T<FEN9REM87@H)&1A=&$I*3L*
M("`@("`@("!F;W(@*"1Z(#T@,#L@)'H@/"`D9&5G0V]U;G0[("1Z*RLI('L*
M("`@("`@("`@("`@)&-Z(#T@)'H@)2!C;W5N="@D=&AI<RT^7V-O;&]R<RD[
M"B`@("`@("`@("`@("1P97)C96YT(#T@*"1D96=R965S6R1Z72`O(#,V,"D@
M*B`Q,#`["B`@("`@("`@("`@("1P97)C96YT(#T@<F]U;F0H)'!E<F-E;G0L
M(#(I.PH@("`@("`@("`@("`D>4)A<V4@*ST@,34["@H@("`@("`@("`@("`D
M=&AI<RT^9W)A<&@M/FEM9RT^<F5C=&%N9VQE*"1X0F%S92P@)'E"87-E+"`Q
M,BP@,3(L("=B;&%C:R<L("1T:&ES+3Y?8V]L;W)S6R1C>ETI.PH@("`@("`@
M("`@("!I9B`H)'-L:6-E<ULD>ET@/CT@,3`P,"`F)B`D<VQI8V5S6R1Z72`\
M(#$P,#`P,#`I('L*("`@("`@("`@("`@("`@("1S;&EC97-;)'I=(#T@)'-L
M:6-E<ULD>ET@+R`Q,#`P.PH@("`@("`@("`@("`@("`@)'-L:6-E<ULD>ET@
M/2`D<VQI8V5S6R1Z72`N("=K)SL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D<F5P96%T(#T@)&UA>"`M('-T<FQE;B@D<VQI8V5S6R1Z72D["B`@("`@
M("`@("`@(&EF("@D<F5P96%T(#P@,"D@>PH@("`@("`@("`@("`@("`@)')E
M<&5A="`](#`["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'-L:6-E<ULD
M>ET@/2!S=')?<F5P96%T*"<@)RP@)')E<&5A="D@+B`D<VQI8V5S6R1Z73L*
M"B`@("`@("`@("`@("1T:&ES+3YG<F%P:"T^:6UG+3YT97AT*"1S;&EC97-;
M)'I=+"`D>$)A<V4@*R`R,"P@*"1Y0F%S92`K(#$I*3L*"B`@("`@("`@("`@
M("1L86)E;"`]("1N86UE<ULD>ET@+B`G("@G("X@)'!E<F-E;G0@+B`G)2DG
M.PH@("`@("`@("`@("!I9B`H<W1R;&5N*"1L86)E;"D@/B`R,"D@>PH@("`@
M("`@("`@("`@("`@)&QA8F5L<R`](&5X<&QO9&4H(EQN(BP@=V]R9'=R87`H
M)&QA8F5L+"`R,"DI.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&QA8F5L
M<R!A<R`D:2`]/B`D;&%B96PI('L*("`@("`@("`@("`@("`@("`@("!I9B`H
M)&D@/B`P*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1Y0F%S92`K/2`Q
M-3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/F=R87!H+3YI;6<M/G1E>'0H)&QA8F5L+"`D>$)A<V4@*R`S-2`K
M("@D;6%X("H@-"DL("@D>4)A<V4@*R`Q*2D["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M9W)A<&@M/FEM9RT^=&5X="@D;&%B96PL("1X0F%S92`K(#,U("L@*"1M87@@
M*B`T*2P@*"1Y0F%S92`K(#$I*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@('T*"GT*````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]'<F]U<```````````````````````````````````````````````````
M```````````````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<S-2`P,C`S-C4`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP````````````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#8S,34U(#$P-3$U-#,S-S,U(#`R
M,C$P-P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@5&AE($=R;W5P7VQD87`@8VQA<W,@<')O=FED97,@
M86X@3$1!4"!B86-K96YD(&9O<B!T:&4@2&]R9&4@9W)O=7!S"B`J('-Y<W1E
M;2X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`L=B`Q+C$X+C(N,B`R,#`V+S`Q+S`Q(#(Q.C(X.C$Y(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P-2TR,#`V($)E;B!#:&%V970@/&)E;D!H;W)D
M92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!"96X@0VAA=F5T
M(#QB96Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C$*("H@0'!A
M8VMA9V4@2&]R9&5?1W)O=7`*("HO"F-L87-S($=R;W5P7VQD87`@97AT96YD
M<R!'<F]U<"!["@H@("`@+RHJ"B`@("`@*B!,1$%0(&-O;FYE8W1I;VX@:&%N
M9&QE"B`@("`@*B\*("`@('9A<B`D7V1S.PH*("`@("\J*@H@("`@("H@3&]C
M86P@8V]P>2!O9B!T:&4@9VQO8F%L("1C;VYF6R=G<F]U<"==6R=P87)A;7,G
M72!A<G)A>2X@(%-I;7!L>0H@("`@("H@9F]R(&-O9&EN9R!C;VYV96YI96YC
M92X*("`@("`J+PH@("`@=F%R("1?<&%R86US.PH*("`@("\J*@H@("`@("H@
M1V5N97)A=&5D($Q$05`@9FEL=&5R(&)A<V5D(&]N('1H92!C;VYF:6<@<&%R
M86UE=&5R<PH@("`@("HO"B`@("!V87(@)%]F:6QT97(["@H@("`@+RHJ"B`@
M("`@*B!#;VYS=')U8W1O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@1W)O=7!?
M;&1A<"@I"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF.PH@("`@("`@("1T
M:&ES+3Y?<&%R86US(#T@)&-O;F9;)V=R;W5P)UU;)W!A<F%M<R==.PH*("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG9VED)UT@/2!S=')T;VQO=V5R*"1T:&ES
M+3Y?<&%R86US6R=G:60G72D["B`@("`@("`@)'1H:7,M/E]P87)A;7-;)VUE
M;6)E<G5I9"==(#T@<W1R=&]L;W=E<B@D=&AI<RT^7W!A<F%M<ULG;65M8F5R
M=6ED)UTI.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<&%R86US6R=N97=G
M<F]U<%]O8FIE8W1C;&%S<R==(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG;F5W9W)O=7!?;V)J96-T8VQA<W,G75LD
M:V5Y72`]('-T<G1O;&]W97(H)'9A;"D["B`@("`@("`@?0H*("`@("`@("`O
M*B!'96YE<F%T92!,1$%0('-E87)C:"!F:6QT97(N("HO"B`@("`@("`@:68@
M*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG9FEL=&5R)UTI*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?9FEL=&5R(#T@)'1H:7,M/E]P87)A;7-;)V9I;'1E<B==
M.PH@("`@("`@('T@96QS96EF("@A:7-?87)R87DH)'1H:7,M/E]P87)A;7-;
M)V]B:F5C=&-L87-S)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?9FEL=&5R
M(#T@)V]B:F5C=&-L87-S/2<@+B`D=&AI<RT^7W!A<F%M<ULG;V)J96-T8VQA
M<W,G73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7V9I
M;'1E<B`]("<G.PH@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7W!A<F%M
M<ULG;V)J96-T8VQA<W,G72!A<R`D;V)J96-T8VQA<W,I('L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?9FEL=&5R(#T@)R@F)R`N("1T:&ES+3Y?9FEL=&5R
M.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]F:6QT97(@+CT@)RAO8FIE8W1C
M;&%S<STG("X@)&]B:F5C=&-L87-S("X@)RDI)SL*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]F:6QT97(@/2!S=')T;VQO=V5R
M*"1T:&ES+3Y?9FEL=&5R*3L*("`@('T*"B`@("`O*BH*("`@("`J($-O;FYE
M8W1S('1O('1H92!,1$%0('-E<G9E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@(%1R=64@;W(@1F%L<V4@8F%S960@;VX@<W5C8V5S<R!O9B!C
M;VYN96-T(&%N9"!B:6YD+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N;F5C
M="@I"B`@("!["B`@("`@("`@+RH@0V]N;F5C="!T;R!T:&4@3$1!4"!S97)V
M97(N("HO"B`@("`@("`@)'1H:7,M/E]D<R`]($!L9&%P7V-O;FYE8W0H)'1H
M:7,M/E]P87)A;7-;)VAO<W1S<&5C)UTI.PH@("`@("`@(&EF("@A)'1H:7,M
M/E]D<RD@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?
M*")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB*2D["B`@("`@
M("`@?0H*("`@("`@("!I9B`H(6QD87!?<V5T7V]P=&EO;B@D=&AI<RT^7V1S
M+"!,1$%07T]05%]04D]43T-/3%]615)324].+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=V97)S:6]N)UTI*2!["B`@
M("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*`H@("`@("`@("`@("`@("`@
M<W!R:6YT9B@G4V5T($Q$05`@<')O=&]C;VP@=F5R<VEO;B!T;R`E9"!F86EL
M960Z(%LE9%T@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG=F5R<VEO;B==+`H@("`@("`@("`@("`@("`@("`@("`@("!L
M9&%P7V5R<FYO*"1C;VYN*2P*("`@("`@("`@("`@("`@("`@("`@("`@;&1A
M<%]E<G)O<B@D8V]N;BDL"B`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,
M15]?+"!?7TQ)3D5?7RDI.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?<&%R86US6R=B:6YD9&XG72DI('L*("`@("`@("`@("`@)&)I
M;F0@/2!`;&1A<%]B:6YD*"1T:&ES+3Y?9',L("1T:&ES+3Y?<&%R86US6R=B
M:6YD9&XG72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=P87-S=V]R9"==*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D8FEN9"`]($!L9&%P7V)I;F0H)'1H:7,M/E]D<RD["B`@("`@
M("`@?0H*("`@("`@("!I9B`H(21B:6YD*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(D-O=6QD(&YO="!B:6YD('1O($Q$05`@
M<V5R=F5R+B(I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5C=7)S:79E;'D@9&5L971E<R`D9&XN
M("1T:&ES+3Y?9',@35535"!A;')E861Y(&)E(&-O;FYE8W1E9"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&EF(&1E;&5T92!W87,@<W5C
M8V5S<V9U;"P@4$5!4E]%<G)O<B!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]R96-U<G-I=F5?9&5L971E*"1D;BD*("`@('L*("`@("`@("`D
M<V5A<F-H(#T@0&QD87!?;&ES="@D=&AI<RT^7V1S+"`D9&XL("=O8FIE8W1C
M;&%S<STJ)RP@87)R87DH)R<I*3L*("`@("`@("!I9B`H(21S96%R8V@I('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V]U;&0@
M;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB*2D["B`@("`@("`@?0H*("`@
M("`@("`D8VAI;&1R96X@/2!`;&1A<%]G971?96YT<FEE<R@D=&AI<RT^7V1S
M+"`D<V5A<F-H*3L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D8VAI;&1R
M96Y;)V-O=6YT)UT[("1I*RLI('L*("`@("`@("`@("`@)')E<W5L="`]("1T
M:&ES+3Y?<F5C=7)S:79E7V1E;&5T92@D8VAI;&1R96Y;)&E=6R=D;B==*3L*
M("`@("`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D=R;W5P7VQD87`Z
M(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,B*2P@)'1H:7,M/F=E=$YA;64H
M)&-H:6QD<F5N6R1I75LG9&XG72DI*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@)')E<W5L="`]($!L9&%P7V1E;&5T92@D=&AI<RT^7V1S
M+"`D9&XI.PH@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D=R;W5P7VQD87`Z
M(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,B*2P@)&1N*2D["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O*BH*("`@
M("`J(%-E87)C:&5S(&5X:7-T:6YG(&=R;W5P<R!F;W(@=&AE(&AI9VAE<W0@
M9VED;G5M8F5R+"!A;F0@<F5T=7)N<PH@("`@("H@;VYE(&AI9VAE<BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@7VYE>'1':60H*0H@("`@>PH@("`@("`@("\J
M($-O;FYE8W0@=&\@=&AE($Q$05`@<V5R=F5R+B`J+PH@("`@("`@("1S=6-C
M97-S(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)'-U
M8V-E<W,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)'-U8V-E<W,M/F=E=$UE<W-A9V4H*2D["B`@("`@
M("`@?0H*("`@("`@("`D<V5A<F-H(#T@0&QD87!?<V5A<F-H*"1T:&ES+3Y?
M9',L("1D;BP@)'1H:7,M/E]F:6QT97(I.PH@("`@("`@(&EF("@A)'-E87)C
M:"D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#
M;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(I*3L*("`@("`@("!]
M"@H@("`@("`@($!L9&%P7W-O<G0H)'1H:7,M/E]D<RP@)'-E87)C:"P@)V=I
M9&YU;6)E<B<I.PH@("`@("`@("1R97-U;'0@/2!`;&1A<%]G971?96YT<FEE
M<R@D=&AI<RT^7V1S+"`D<V5A<F-H*3L*("`@("`@("!`;&1A<%]C;&]S92@D
M=&AI<RT^7V1S*3L*"B`@("`@("`@:68@*"%I<U]A<G)A>2@D<F5S=6QT*2!\
M?"`H8V]U;G0H)')E<W5L="D@/#T@,2DI('L*("`@("`@("`@("`@<F5T=7)N
M(#`["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E<W5L=%LD<F5S=6QT
M6R=C;W5N="==("T@,5U;)V=I9&YU;6)E<B==6S!=("L@,3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;B!A(&YE=R!G<F]U<"!O8FIE8W0N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("!4:&4@9W)O=7`G<R!N
M86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%R96YT("!4:&4@9W)O=7`G
M<R!P87)E;G0G<R!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@3$1!4%]'
M<F]U<"`@02!N97<@9W)O=7`@;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO
M;B`F;F5W1W)O=7`H)&YA;64L("1P87)E;G0@/2!N=6QL*0H@("`@>PH@("`@
M("`@(&EF("AE;7!T>2@D;F%M92DI('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H7R@B1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP
M='DB*2D["B`@("`@("`@?0H*("`@("`@("!G;&]B86P@)&-O;F8["B`@("`@
M("`@:68@*"%E;7!T>2@D8V]N9ELG:&]O:W,G75LG9W)O=7!L9&%P)UTI*2![
M"B`@("`@("`@("`@($!I;F-L=61E($A/4D1%7T)!4T4@+B`G+V-O;F9I9R]H
M;V]K<RYP:'`G.PH@("`@("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=?
M:&]R9&5?:&]O:U]G<F]U<&QD87`G*2D@>PH@("`@("`@("`@("`@("`@)&5N
M=')Y(#T@8V%L;%]U<V5R7V9U;F,H)U]H;W)D95]H;V]K7V=R;W5P;&1A<"<L
M("1N86UE+"`D<&%R96YT*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("\O(%1R>2!T:&ES('-I;7!L92!D969A=6QT(&%N
M9"!H;W!E(&ET('=O<FMS+@H@("`@("`@("`@("`D96YT<GE;)'1H:7,M/E]P
M87)A;7-;)V=I9"==72`]("1N86UE.PH@("`@("`@("`@("`D96YT<GE;)V]B
M:F5C=&-L87-S)UT@/2`D=&AI<RT^7W!A<F%M<ULG;F5W9W)O=7!?;V)J96-T
M8VQA<W,G73L*("`@("`@("`@("`@)&5N=')Y6R=G:61N=6UB97(G72`]("1T
M:&ES+3Y?;F5X=$=I9"@I.PH@("`@("`@('T*"B`@("`@("`@)&=R;W5P(#T@
M)FYE=R!,1$%07T=R;W5P*"1N86UE+"`D<&%R96YT*3L*("`@("`@("`D9W)O
M=7`M/E]F<F]M071T<FEB=71E<R@D96YT<GDI.PH@("`@("`@("1G<F]U<"T^
M<V5T1W)O=7!/8B@D=&AI<RD["B`@("`@("`@<F5T=7)N("1G<F]U<#L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!A;B!,1$%07T=R;W5P(&]B:F5C
M="!C;W)R97-P;VYD:6YG('1O('1H92!N86UE9"!G<F]U<"P@=VET:"!T:&4*
M("`@("`J('5S97)S(&%N9"!O=&AE<B!D871A(')E=')I979E9"!A<'!R;W!R
M:6%T96QY+@H@("`@("H*("`@("`J($Y/5$4Z(&=E=$=R;W5P0GE)9"@I('-H
M;W5L9"!B92!U<V5D('=H97)E('!O<W-I8FQE(&EN<W1E860@;V8*("`@("`J
M(&=E=$=R;W5P*"D@8F5C875S92!G<F]U<"!N86UE<R!A<F4@<&]T96YT:6%L
M;'D@;F]N+75N:7%U92!V86QU97,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;F%M92`@5&AE(&YA;64@;V8@=&AE(&=R;W5P('1O(')E=')I979E
M+@H@("`@("H*("`@("`J($!R971U<FX@3$1!4%]'<F]U<"`@5&AE(')E<75E
M<W1E9"!G<F]U<"X*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=$=R;W5P*"1N
M86UE*0H@("`@>PH@("`@("`@("1D;B`]("1T:&ES+3YG971'<F]U<$ED*"1N
M86UE*3L*("`@("`@("!I9B`H:7-?82@D9&XL("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)&1N+3YG971-
M97-S86=E*"DI.PH@("`@("`@('T*("`@("`@("`D9W)O=7`@/2`F)'1H:7,M
M/F=E=$=R;W5P0GE)9"@D9&XI.PH@("`@("`@(')E='5R;B`D9W)O=7`["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@86X@3$1!4%]/8FIE8W0@;V)J
M96-T(&-O<G)E<W!O;F1I;F<@=&\@=&AE(&=I=F5N(&1N+"!W:71H('1H90H@
M("`@("H@=7-E<G,@86YD(&]T:&5R(&1A=&$@<F5T<FEE=F5D(&%P<')O<')I
M871E;'DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&X@(%1H92!D
M;B!O9B!T:&4@9W)O=7`@=&\@<F5T<FEE=F4N"B`@("`@*@H@("`@("H@0')E
M='5R;B!,1$%07T]B:F5C="`@5&AE(')E<75E<W1E9"!G<F]U<"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@)F=E=$=R;W5P0GE)9"@D9&XI"B`@("!["B`@("`@
M("`@<W1A=&EC("1C86-H93L*"B`@("`@("`@:68@*"%I<U]A<G)A>2@D8V%C
M:&4I*2!["B`@("`@("`@("`@("1C86-H92`](&%R<F%Y*"D["B`@("`@("`@
M?0H*("`@("`@("!I9B`H(6ES<V5T*"1C86-H95LD9&Y=*2D@>PH@("`@("`@
M("`@("`O*B!#;VYN96-T('1O('1H92!,1$%0('-E<G9E<BX@*B\*("`@("`@
M("`@("`@)'-U8V-E<W,@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("`@
M("`@:68@*&ES7V$H)'-U8V-E<W,L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"1S=6-C97-S+3YG
M971-97-S86=E*"DI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<V5A
M<F-H(#T@0&QD87!?<V5A<F-H*"1T:&ES+3Y?9',L("1D;BP@)'1H:7,M/E]F
M:6QT97(I.PH@("`@("`@("`@("!I9B`H(21S96%R8V@I('L*("`@("`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-O=6QD(&YO="!R
M96%C:"!T:&4@3$1!4"!S97)V97(N(BDI.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`D<F5S=6QT(#T@0&QD87!?9V5T7V5N=')I97,H)'1H:7,M/E]D
M<RP@)'-E87)C:"D["B`@("`@("`@("`@($!L9&%P7V-L;W-E*"1T:&ES+3Y?
M9',I.PH@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1R97-U;'0I('Q\("AC
M;W5N="@D<F5S=6QT*2`\/2`Q*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B16UP='D@<F5S=6QT+B(I*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)&%T=')I8G5T97,@/2!A<G)A>2@I.PH@
M("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D<F5S=6QT6S!=6R=C;W5N
M="==.R`D:2LK*2!["B`@("`@("`@("`@("`@("!I9B`H)')E<W5L=%LP75LD
M<F5S=6QT6S!=6R1I75U;)V-O=6YT)UT@/B`Q*2!["B`@("`@("`@("`@("`@
M("`@("`@)&%T=')I8G5T97-;)')E<W5L=%LP75LD:5U=(#T@87)R87DH*3L*
M("`@("`@("`@("`@("`@("`@("!F;W(@*"1J(#T@,#L@)&H@/"`D<F5S=6QT
M6S!=6R1R97-U;'1;,%U;)&E=75LG8V]U;G0G73L@)&HK*RD@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D871T<FEB=71E<ULD<F5S=6QT6S!=6R1I75U;
M72`]("1R97-U;'1;,%U;)')E<W5L=%LP75LD:5U=6R1J73L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("1A='1R:6)U=&5S6R1R97-U;'1;,%U;)&E=72`]("1R
M97-U;'1;,%U;)')E<W5L=%LP75LD:5U=6S!=.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1A='1R:6)U=&5S6R=D;B==
M(#T@)')E<W5L=%LP75LG9&XG73L*"B`@("`@("`@("`@("1G<F]U<"`](&YE
M=R!,1$%07T=R;W5P*"1T:&ES+3YG971'<F]U<$YA;64H)&1N*2D["B`@("`@
M("`@("`@("1G<F]U<"T^7V9R;VU!='1R:6)U=&5S*"1A='1R:6)U=&5S*3L*
M("`@("`@("`@("`@)&=R;W5P+3YS971'<F]U<$]B*"1T:&ES*3L*("`@("`@
M("`@("`@)&-A8VAE6R1D;ET@/2`D9W)O=7`["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B`D8V%C:&5;)&1N73L*("`@('T*"B`@("`O*BH*("`@("`J($=E
M="!A(&=L;V)A;&QY('5N:7%U92!)1"!F;W(@82!G<F]U<"X@(%1H:7,@<F5A
M;&QY(&IU<W0@<F5T=7)N<R!T:&4@9&X*("`@("`J(&9O<B!T:&4@9W)O=7`L
M(&)U="!I<R!I;F-L=61E9"!F;W(@8V]M<&%T:6)I;&ET>2!W:71H('1H92!'
M<F]U<"!C;&%S<RX*("`@("`J"B`@("`@*B!`<&%R86T@3$1!4%]/8FIE8W0@
M)&=R;W5P("!4:&4@9W)O=7`N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(&$@1U5)1"!R969E<G)I;F<@=&\@)&=R;W5P+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971'54E$*"1G<F]U<"D*("`@('L*("`@("`@("!R971U<FX@
M)&=R;W5P+3YG970H)V1N)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@
M82!G<F]U<"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X@(%1H92!G<F]U<"!M=7-T
M(&9I<G-T(&)E(&-R96%T960@=VET:`H@("`@("H@1W)O=7!?;&1A<#HZ;F5W
M1W)O=7`H*2P@86YD(&AA=F4@86YY(&EN:71I86P@=7-E<G,@861D960@=&\@
M:70L(&)E9F]R90H@("`@("H@=&AI<R!F=6YC=&EO;B!I<R!C86QL960N"B`@
M("`@*@H@("`@("H@0'!A<F%M($Q$05!?1W)O=7`@)&=R;W5P("!4:&4@;F5W
M(&=R;W5P(&]B:F5C="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4
M<G5E(&EF('-U8V-E<W-F=6PL(%!%05)?17)R;W(@;W1H97)W:7-E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!A9&1'<F]U<"@D9W)O=7`I"B`@("!["B`@("`@
M("`@:68@*"%I<U]A*"1G<F]U<"P@)T1A=&%4<F5E3V)J96-T7T=R;W5P)RDI
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T=R;W5P
M<R!M=7-T(&)E($1A=&%4<F5E3V)J96-T7T=R;W5P(&]B:F5C=',@;W(@97AT
M96YD('1H870@8VQA<W,N)RD["B`@("`@("`@?0H*("`@("`@("`O*B!#;VYN
M96-T('1O('1H92!,1$%0('-E<G9E<BX@*B\*("`@("`@("`D<W5C8V5S<R`]
M("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1S=6-C97-S
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"1S=6-C97-S+3YG971-97-S86=E*"DI.PH@("`@("`@('T*
M"B`@("`@("`@)&1N(#T@)&=R;W5P+3YG970H)V1N)RD["@H@("`@("`@("1E
M;G1R>2`]("1G<F]U<"T^7W1O071T<FEB=71E<R@I.PH@("`@("`@("1S=6-C
M97-S(#T@0&QD87!?861D*"1T:&ES+3Y?9',L("1D;BP@)&5N=')Y*3L*"B`@
M("`@("`@:68@*"$D<W5C8V5S<RD@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D=R;W5P7VQD87`Z(%5N86)L92!T
M;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z
M("(I+"`D9W)O=7`M/F=E=$YA;64H*2D@+B!`;&1A<%]E<G)O<B@D=&AI<RT^
M7V1S*2D["B`@("`@("`@?0H*("`@("`@("!`;&1A<%]C;&]S92@D=&AI<RT^
M7V1S*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3=&]R92!U<&1A=&5D(&1A=&$@+2!U<V5R<RP@971C+B`M(&]F(&$@
M9W)O=7`@=&\@=&AE(&)A8VME;F0@<WES=&5M+@H@("`@("H*("`@("`J($!P
M87)A;2!,1$%07T]B:F5C="`D9W)O=7`@(%1H92!G<F]U<"!T;R!U<&1A=&4*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,L
M(%!%05)?17)R;W(@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!U
M<&1A=&5'<F]U<"@D9W)O=7`I"B`@("!["B`@("`@("`@:68@*"%I<U]A*"1G
M<F]U<"P@)T1A=&%4<F5E3V)J96-T7T=R;W5P)RDI('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T=R;W5P<R!M=7-T(&)E($1A=&%4
M<F5E3V)J96-T7T=R;W5P(&]B:F5C=',@;W(@97AT96YD('1H870@8VQA<W,N
M)RD["B`@("`@("`@?0H*("`@("`@("`D96YT<GD@/2`D9W)O=7`M/E]T;T%T
M=')I8G5T97,H*3L*"B`@("`@("`@+RH@0V]N;F5C="!T;R!T:&4@3$1!4"!S
M97)V97(N("HO"B`@("`@("`@)'-U8V-E<W,@/2`D=&AI<RT^7V-O;FYE8W0H
M*3L*("`@("`@("!I9B`H:7-?82@D<W5C8V5S<RP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D<W5C8V5S
M<RT^9V5T365S<V%G92@I*3L*("`@("`@("!]"@H@("`@("`@("1R97-U;'0@
M/2!`;&1A<%]M;V1I9GDH)'1H:7,M/E]D<RP@)&=R;W5P+3YG971)9"@I+"`D
M96YT<GDI.PH@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D=R;W5P7VQD87`Z
M(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,B*2P@)&=R;W5P+3YG971.86UE
M*"DI*3L*("`@("`@("!]"@H@("`@("`@($!L9&%P7V-L;W-E*"1T:&ES+3Y?
M9',I.PH*("`@("`@("`O*B!,;V<@=&AE('5P9&%T92!O9B!T:&4@9W)O=7`@
M=7-E<G,@;VX@=&AE(&AI<W1O<GD@;&]G+B`J+PH@("`@("`@("1H:7-T;W)Y
M(#T@)DAO<F1E7TAI<W1O<GDZ.G-I;F=L971O;B@I.PH@("`@("`@("1G=6ED
M(#T@)'1H:7,M/F=E=$=5240H)&=R;W5P*3L*("`@("`@("!F;W)E86-H("@D
M9W)O=7`M/F=E=$%U9&ET3&]G*"D@87,@)'5S97))9"`]/B`D86-T:6]N*2![
M"B`@("`@("`@("`@("1H:7-T;W)Y+3YL;V<H)&=U:60L(&%R<F%Y*"=A8W1I
M;VXG(#T^("1A8W1I;VXL("=U<V5R)R`]/B`D=7-E<DED*2P@=')U92D["B`@
M("`@("`@?0H@("`@("`@("1G<F]U<"T^8VQE87)!=61I=$QO9R@I.PH*("`@
M("`@("`O*B!,;V<@=&AE(&=R;W5P(&UO9&EF:6-A=&EO;BX@*B\*("`@("`@
M("`D:&ES=&]R>2T^;&]G*"1G=6ED+"!A<G)A>2@G86-T:6]N)R`]/B`G;6]D
M:69Y)RDL('1R=64I.PH@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0VAA;F=E('1H92!N86UE(&]F(&$@9W)O=7`N"B`@
M("`@*@H@("`@("H@0'!A<F%M($1A=&%4<F5E3V)J96-T7T=R;W5P("1G<F]U
M<"`@5&AE(&=R;W5P('1O(')E;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@
M)&YE=TYA;64@("`@("`@("`@("`@(%1H92!G<F]U<"=S(&YE=R!N86UE+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!R96YA;65'<F]U<"@D9W)O=7`L("1N97=.
M86UE*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D9W)O=7`L("=$871A5')E
M94]B:F5C=%]'<F]U<"<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"='<F]U<',@;75S="!B92!$871A5')E94]B:F5C=%]'<F]U
M<"!O8FIE8W1S(&]R(&5X=&5N9"!T:&%T(&-L87-S+B<I.PH@("`@("`@('T*
M"B`@("`@("`@)&=R;W5P+3YS970H)'1H:7,M/E]P87)A;7-;)V=I9"==+"`D
M;F5W3F%M92D["B`@("`@("`@)&5N=')Y(#T@)&=R;W5P+3Y?=&]!='1R:6)U
M=&5S*"D["@H@("`@("`@("\J($-O;FYE8W0@=&\@=&AE($Q$05`@<V5R=F5R
M+B`J+PH@("`@("`@("1S=6-C97-S(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@
M("`@("`@:68@*&ES7V$H)'-U8V-E<W,L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)'-U8V-E<W,M/F=E
M=$UE<W-A9V4H*2D["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@0&QD
M87!?;6]D:69Y*"1T:&ES+3Y?9',L("1G<F]U<"T^9V5T260H*2P@)&5N=')Y
M*3L*("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")'<F]U<%]L9&%P.B!5;F%B
M;&4@=&\@=7!D871E(&=R;W5P("5S(BDL("1G<F]U<"T^9V5T3F%M92@I*2D[
M"B`@("`@("`@?0H*("`@("`@("!`;&1A<%]C;&]S92@D=&AI<RT^7V1S*3L*
M"B`@("`@("`@+RH@2&ES=&]R>2!,;V<@=&AE(&YA;64@8VAA;F=E(&]F('1H
M92!G<F]U<"X@*B\*("`@("`@("`D:&ES=&]R>2`]("9(;W)D95](:7-T;W)Y
M.CIS:6YG;&5T;VXH*3L*("`@("`@("`D:&ES=&]R>2T^;&]G*"1G<F]U<"T^
M9V5T*"=D;B<I+"!A<G)A>2@G86-T:6]N)R`]/B`G<F5N86UE)RDL('1R=64I
M.PH@("`@("`@(')E='5R;B`D<F5S=6QT.PH*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E;6]V92!A(&=R;W5P(&9R;VT@=&AE(&=R;W5P<R!S>7-T96T@<&5R
M;6%N96YT;'DN"B`@("`@*@H@("`@("H@0'!A<F%M($Q$05!?1W)O=7`@)&=R
M;W5P("!4:&4@9W)O=7`@=&\@<F5M;W9E+@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)&9O<F-E("`@("!296-U<G-I=F5L>2!D96QE=&4@8VAI;&1R96X@9W)O
M=7!S(&EF('1R=64N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U
M92!O;B!S=6-C97-S+"!014%27T5R<F]R(&]T:&5R=VES92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<F5M;W9E1W)O=7`H)&=R;W5P+"`D9F]R8V4@/2!F86QS
M92D*("`@('L*("`@("`@("!I9B`H(6ES7V$H)&=R;W5P+"`G1&%T851R965/
M8FIE8W1?1W)O=7`G*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@G1W)O=7!S(&UU<W0@8F4@1&%T851R965/8FIE8W1?1W)O=7`@
M;V)J96-T<R!O<B!E>'1E;F0@=&AA="!C;&%S<RXG*3L*("`@("`@("!]"@H@
M("`@("`@("1D;B`]("1G<F]U<"T^9V5T260H*3L*"B`@("`@("`@+RH@0V]N
M;F5C="!T;R!T:&4@3$1!4"!S97)V97(N("HO"B`@("`@("`@)'-U8V-E<W,@
M/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D<W5C8V5S
M<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@D<W5C8V5S<RT^9V5T365S<V%G92@I*3L*("`@("`@("!]
M"@H@("`@("`@(&EF("@D9F]R8V4I('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<F5C=7)S:79E7V1E;&5T92@D9&XI.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1R97-U;'0@/2!`;&1A<%]D96QE=&4H)'1H:7,M/E]D
M<RP@)&1N*3L*("`@("`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D=R
M;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,B*2P@)&1N*2D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971R:65V92!T:&4@;F%M92!O9B!A(&=R;W5P+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&1N("!4:&4@9&X@;V8@=&AE(&=R;W5P('1O(')E
M=')I979E('1H92!N86UE(&9O<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE(&=R;W5P)W,@;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T1W)O=7!.86UE*"1D;BD*("`@('L*("`@("`@("`D<F5S=6QT(#T@;&1A
M<%]E>'!L;V1E7V1N*"1D;BP@,2D["B`@("`@("`@<F5T=7)N("1R97-U;'1;
M,%T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$871A5')E94]B:F5C="!F=6QL
M(&YA;65S(&EN8VQU9&4@<F5F97)E;F-E<R!T;R!P87)E;G1S+"!B=70@3$1!
M4"!D;V5S"B`@("`@*B!N;W0@:&%V92!T:&ES(&-O;F-E<'0N("!4:&ES(&9U
M;F-T:6]N('-I;7!L>2!R971U<FYS('1H92`D9W)O=7`*("`@("`J('!A<F%M
M971E<B!A;F0@:7,@:6YC;'5D960@9F]R(&-O;7!A=&EB:6QI='D@=VET:"!T
M:&4@1W)O=7`@8VQA<W,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M9W)O=7`@($=R;W5P(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@("1G<F]U<"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1W)O=7!3:&]R
M=$YA;64H)&=R;W5P*0H@("`@>PH@("`@("`@(')E='5R;B`D9W)O=7`["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V92!T:&4@240@;V8@=&AE(&=I
M=F5N(&=R;W5P+@H@("`@("H*("`@("`J($Y/5$4Z($EF(&=I=F5N(&$@9W)O
M=7`@;F%M92P@=&AI<R!F=6YC=&EO;B!C86X@8F4@=6YR96QI86)L92!I9B!M
M;W)E"B`@("`@*B!T:&%N(&]N92!G<F]U<"!E>&ES=',@=VET:"!T:&4@<V%M
M92!N86UE+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D9W)O=7`@("!,
M1$%07T=R;W5P(&]B:F5C="P@;W(@82!G<F]U<"!N86UE("AS=')I;F<I"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!G<F]U<"=S($E$+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971'<F]U<$ED*"1G<F]U<"D*("`@('L*
M("`@("`@("!I9B`H:7-?82@D9W)O=7`L("=,1$%07T=R;W5P)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1G<F]U<"T^9V5T*"=D;B<I.PH@("`@("`@('T*
M"B`@("`@("`@<W1A=&EC("1C86-H93L*"B`@("`@("`@:68@*"%I<U]A<G)A
M>2@D8V%C:&4I*2!["B`@("`@("`@("`@("1C86-H92`](&%R<F%Y*"D["B`@
M("`@("`@?0H*("`@("`@("!I9B`H(6ES<V5T*"1C86-H95LD9W)O=7!=*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("`@("`@
M)'-E87)C:"`]($!L9&%P7W-E87)C:"@D=&AI<RT^7V1S+"`D=&AI<RT^7W!A
M<F%M<ULG8F%S961N)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)V=I9"==("X@)STG("X@)&=R;W5P+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1T:&ES
M+3Y?<&%R86US6R=G:60G72DI.PH@("`@("`@("`@("!I9B`H(21S96%R8V@I
M('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(D-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N(BDI.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`D<F5S=6QT(#T@0&QD87!?9V5T7V5N=')I
M97,H)'1H:7,M/E]D<RP@)'-E87)C:"D["B`@("`@("`@("`@($!L9&%P7V-L
M;W-E*"1T:&ES+3Y?9',I.PH@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1R
M97-U;'0I('Q\("AC;W5N="@D<F5S=6QT*2`\/2`Q*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B16UP='D@<F5S=6QT
M+B(I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D8V%C:&5;)&=R;W5P
M72`]("1R97-U;'1;,%U;)V1N)UT["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)&-A8VAE6R1G<F]U<%T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C
M:R!I9B!A(&=R;W5P(&5X:7-T<R!I;B!T:&4@<WES=&5M+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&=R;W5P("!4:&4@9W)O=7`@;F%M92!T;R!C
M:&5C:R!F;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E
M(&EF('1H92!G<F]U<"!E>&ES=',L($9A;'-E(&]T:&5R=VES92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@97AI<W1S*"1G<F]U<"D*("`@('L*("`@("`@("!S
M=&%T:6,@)&-A8VAE.PH*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1C86-H92DI
M('L*("`@("`@("`@("`@)&-A8VAE(#T@87)R87DH*3L*("`@("`@("!]"@H@
M("`@("`@(&EF("@A:7-S970H)&-A8VAE6R1G<F]U<%TI*2!["B`@("`@("`@
M("`@("\J($-O;FYE8W0@=&\@=&AE($Q$05`@<V5R=F5R+B`J+PH@("`@("`@
M("`@("`D<W5C8V5S<R`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@("`@
M("!I9B`H:7-?82@D<W5C8V5S<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)'-U8V-E<W,M/F=E
M=$UE<W-A9V4H*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1S96%R
M8V@@/2!`;&1A<%]S96%R8V@H)'1H:7,M/E]D<RP@)&1N+"`G*"8G("X@)'1H
M:7,M/E]F:6QT97(@+B`G*"<@+B`D=&AI<RT^7W!A<F%M<ULG9VED)UT@+B`G
M/2<@+B`D9W)O=7`@+B`G*2DG*3L*("`@("`@("`@("`@:68@*"$D<V5A<F-H
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?
M*")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(I*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)')E<W5L="`]($!L9&%P7V=E=%]E;G1R
M:65S*"1T:&ES+3Y?9',L("1S96%R8V@I.PH@("`@("`@("`@("!`;&1A<%]C
M;&]S92@D=&AI<RT^7V1S*3L*("`@("`@("`@("`@)&-A8VAE6R1G<F]U<%T@
M/2`H:7-?87)R87DH)')E<W5L="D@)B8@*&-O=6YT*"1R97-U;'0@/B`Q*2DI
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1C86-H95LD9W)O=7!=.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1V5T(&$@;&ES="!O9B!T:&4@<&%R96YT
M<R!O9B!A(&-H:6QD(&=R;W5P+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&1N("!4:&4@9&X@;V8@=&AE(&-H:6QD(&=R;W5P+@H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@(%1H92!D;B!A;F0@;F%M92!O9B!T:&4@<&%R
M96YT(&=R;W5P+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971'<F]U<%!A<F5N
M=',H)&1N*0H@("`@>PH@("`@("`@("1P87)E;G0@/2`D=&AI<RT^9V5T1W)O
M=7!087)E;G0H)&1N*3L*("`@("`@("!R971U<FX@87)R87DH)'!A<F5N="`]
M/B`D=&AI<RT^9V5T1W)O=7!.86UE*"1P87)E;G0I*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($=E="!T:&4@<&%R96YT(&]F('1H92!G:79E;B!G<F]U<"X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D;B`@5&AE(&1N(&]F('1H
M92!C:&EL9"!G<F]U<"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE(&1N(&]F('1H92!P87)E;G0@9W)O=7`N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$=R;W5P4&%R96YT*"1D;BD*("`@('L*("`@("`@("`D<F5S=6QT
M(#T@;&1A<%]E>'!L;V1E7V1N*"1D;BP@,"D["B`@("`@("`@=6YS970H)')E
M<W5L=%LG8V]U;G0G72D["B`@("`@("`@=6YS970H)')E<W5L=%LP72D["B`@
M("`@("`@)'!A<F5N=%]D;B`](&EM<&QO9&4H)RPG+"`D<F5S=6QT*3L*"B`@
M("`@("`@:68@*"1P87)E;G1?9&X@/3T@)$=,3T)!3%-;)V-O;F8G75LG9W)O
M=7`G75LG<&%R86US)UU;)V)A<V5D;B==*2!["B`@("`@("`@("`@(')E='5R
M;B!$051!5%)%15]23T]4.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(')E='5R;B`D<&%R96YT7V1N.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($=E="!A(&QI<W0@;V8@<&%R96YT<R!A;&P@=&AE('=A>2!U<"!T
M;R!T:&4@<F]O="!O8FIE8W0@9F]R('1H92!G:79E;@H@("`@("H@9W)O=7`N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&X@(%1H92!D;B!O9B!T
M:&4@9W)O=7`N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!F;&%T
M(&QI<W0@;V8@86QL(&]F('1H92!P87)E;G1S(&]F('1H92!G:79E;B!G<F]U
M<"P*("`@("`J("`@("`@("`@("`@("`@(&AA<VAE9"!I;B`D9&X@/3X@)&YA
M;64@9F]R;6%T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971'<F]U<%!A<F5N
M=$QI<W0H)&1N*0H@("`@>PH@("`@("`@("1R97-U;'0@/2!L9&%P7V5X<&QO
M9&5?9&XH)&1N+"`P*3L*("`@("`@("`D;G5M(#T@)')E<W5L=%LG8V]U;G0G
M73L*"B`@("`@("`@=6YS970H)')E<W5L=%LG8V]U;G0G72D["B`@("`@("`@
M=6YS970H)')E<W5L=%LP72D["@H@("`@("`@("1C;W5N="`](#`["B`@("`@
M("`@)'!A<F5N=',@/2!A<G)A>2@I.PH@("`@("`@("1P87)E;G1?9&X@/2!I
M;7!L;V1E*"<L)RP@)')E<W5L="D["B`@("`@("`@=VAI;&4@*"1P87)E;G1?
M9&X@(3T@)'1H:7,M/E]P87)A;7-;)V)A<V5D;B==("8F("1C;W5N="LK("$]
M("1N=6TI('L*("`@("`@("`@("`@)'!A<F5N='-;)'!A<F5N=%]D;ET@/2`D
M=&AI<RT^9V5T1W)O=7!.86UE*"1P87)E;G1?9&XI.PH@("`@("`@("`@("!U
M;G-E="@D<F5S=6QT6R1C;W5N=%TI.PH@("`@("`@("`@("`D<&%R96YT7V1N
M(#T@:6UP;&]D92@G+"<L("1R97-U;'0I.PH@("`@("`@('T*("`@("`@("`D
M<&%R96YT<UM$051!5%)%15]23T]472`]($1!5$%44D5%7U)/3U0["@H@("`@
M("`@(')E='5R;B`D<&%R96YT<SL*("`@('T*"B`@("`O*BH*("`@("`J($=E
M="!A(&QI<W0@;V8@979E<GD@9W)O=7`L(&EN('1H92!F;W)M870@9&X@/3X@
M9W)O=7!N86UE+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1R969R
M97-H("!)9B!T<G5E+"!T:&4@8V%C:&5D('9A;'5E(&ES(&EG;F]R960@86YD
M('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&=R;W5P(&QI
M<W0@:7,@<F5F<F5S:&5D(&9R;VT@=&AE(&=R;W5P(&)A8VME;F0N"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@9&X@/3X@9W)O=7!N86UE(&AA<V@N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W1'<F]U<',H)')E9G)E<V@@/2!F
M86QS92D*("`@('L*("`@("`@("!S=&%T:6,@)&=R;W5P<SL*"B`@("`@("`@
M:68@*"1R969R97-H('Q\(&ES7VYU;&PH)&=R;W5P<RDI('L*("`@("`@("`@
M("`@+RH@0V]N;F5C="!T;R!T:&4@3$1!4"!S97)V97(N("HO"B`@("`@("`@
M("`@("1S=6-C97-S(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@("`@
M(&EF("AI<U]A*"1S=6-C97-S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D<W5C8V5S<RT^9V5T
M365S<V%G92@I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'-E87)C
M:"`]($!L9&%P7W-E87)C:"@D=&AI<RT^7V1S+"`D=&AI<RT^7W!A<F%M<ULG
M8F%S961N)UTL("1T:&ES+3Y?9FEL=&5R+"!A<G)A>2@D=&AI<RT^7W!A<F%M
M<ULG9VED)UTI*3L*("`@("`@("`@("`@:68@*"$D<V5A<F-H*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#;W5L9"!N
M;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(I*3L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@0&QD87!?<V]R="@D=&AI<RT^7V1S+"`D<V5A<F-H+"`D
M=&AI<RT^7W!A<F%M<ULG9VED)UTI.PH*("`@("`@("`@("`@)')E<W5L="`]
M($!L9&%P7V=E=%]E;G1R:65S*"1T:&ES+3Y?9',L("1S96%R8V@I.PH@("`@
M("`@("`@("!`;&1A<%]C;&]S92@D=&AI<RT^7V1S*3L*("`@("`@("`@("`@
M:68@*"%I<U]A<G)A>2@D<F5S=6QT*2!\?"`H8V]U;G0H)')E<W5L="D@/#T@
M,2DI('L*("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`D9W)O=7!S(#T@87)R87DH*3L*("`@("`@
M("`@("`@9F]R("@D:2`](#`[("1I(#P@)')E<W5L=%LG8V]U;G0G73L@)&DK
M*RD@>PH@("`@("`@("`@("`@("`@)&=R;W5P<ULD<F5S=6QT6R1I75LG9&XG
M75T@/2`D<F5S=6QT6R1I75LD=&AI<RT^7W!A<F%M<ULG9VED)UU=6S!=.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&=R;W5P
M<SL*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A(&QI<W0@;V8@979E<GD@
M=7-E<B!T:&%T(&ES('!A<G0@;V8@=&AE('-P96-I9FEE9"!G<F]U<"!A;F0@
M86YY"B`@("`@*B!O9B!I=',@<W5B9W)O=7!S+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&1N("!4:&4@9&X@;V8@=&AE('!A<F5N="!G<F]U<"X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@8V]M<&QE=&4@=7-E
M<B!L:7-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T06QL57-E<G,H)&1N
M*0H@("`@>PH@("`@("`@('-T871I8R`D8V%C:&4["@H@("`@("`@(&EF("@A
M:7-?87)R87DH)&-A8VAE*2D@>PH@("`@("`@("`@("`D8V%C:&4@/2!A<G)A
M>2@I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I<W-E="@D8V%C:&5;)&1N
M72DI('L*("`@("`@("`@("`@)'-U8V-E<W,@/2`D=&AI<RT^7V-O;FYE8W0H
M*3L*("`@("`@("`@("`@:68@*&ES7V$H)'-U8V-E<W,L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"1S=6-C97-S+3YG971-97-S86=E*"DI.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`D<V5A<F-H(#T@0&QD87!?<V5A<F-H*"1T:&ES+3Y?9',L("1T
M:&ES+3YG971'<F]U<%!A<F5N="@D9&XI+"`D=&AI<RT^7V9I;&5R*3L*("`@
M("`@("`@("`@:68@*"$D<V5A<F-H*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$
M05`@<V5R=F5R+B(I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)')E
M<W5L="`]($!L9&%P7V=E=%]E;G1R:65S*"1T:&ES+3Y?9',L("1S96%R8V@I
M.PH@("`@("`@("`@("!`;&1A<%]C;&]S92@D=&AI<RT^7V1S*3L*("`@("`@
M("`@("`@:68@*"%I<U]A<G)A>2@D<F5S=6QT*2!\?"`H8V]U;G0H)')E<W5L
M="D@/#T@,2DI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*%\H(D5M<'1Y(')E<W5L="XB*2D["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("1U<V5R<R`](&%R<F%Y*"D["B`@("`@("`@("`@(&9O<B`H
M)&D@/2`P.R`D:2`\("1R97-U;'1;)V-O=6YT)UT[("1I*RLI('L*("`@("`@
M("`@("`@("`@(&9O<B`H)&H@/2`P.R`D:B`\("1R97-U;'1;)&E=6R1T:&ES
M+3Y?<&%R86US6R=M96UB97)U:60G75U;)V-O=6YT)UT[("1J*RLI('L*("`@
M("`@("`@("`@("`@("`@("`D=7-E<G-;72`]("1R97-U;'1;)&E=6R1T:&ES
M+3Y?<&%R86US6R=M96UB97)U:60G75U;)&I=.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`D8V%C:&5;)&1N72`](&%R
M<F%Y7W5N:7%U92@D=7-E<G,I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1C86-H95LD9&Y=.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T(&$@;&ES
M="!O9B!E=F5R>2!G<F]U<"!T:&%T('1H92!G:79E;B!U<V5R(&ES(&$@;65M
M8F5R(&]F+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1U<V5R("`@
M("`@("`@(%1H92!U<V5R('1O(&=E="!G<F]U<',@9F]R+@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)'!A<F5N=$=R;W5P<R`@06QS;R!R971U<FX@=&AE('!A
M<F5N=',@;V8@86YY(&=R;W5P<S\*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!!;B!A<G)A>2!O9B!A;&P@9W)O=7!S('1H92!U<V5R(&ES(&EN+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971'<F]U<$UE;6)E<G-H:7!S*"1U<V5R
M+"`D<&%R96YT1W)O=7!S(#T@9F%L<V4I"B`@("!["B`@("`@("`@<W1A=&EC
M("1C86-H93L*"B`@("`@("`@:68@*&5M<'1Y*"1C86-H95LD=7-E<ETI*2![
M"B`@("`@("`@("`@("\J($-O;FYE8W0@=&\@=&AE($Q$05`@<V5R=F5R+B`J
M+PH@("`@("`@("`@("`D<W5C8V5S<R`]("1T:&ES+3Y?8V]N;F5C="@I.PH@
M("`@("`@("`@("!I9B`H:7-?82@D<W5C8V5S<RP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)'-U
M8V-E<W,M/F=E=$UE<W-A9V4H*2D["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1S96%R8V@@/2!`;&1A<%]S96%R8V@H)'1H:7,M/E]D<RP@)'1H:7,M
M/E]P87)A;7-;)V)A<V5D;B==+"`G*"<@+B`D=&AI<RT^7W!A<F%M<ULG;65M
M8F5R=6ED)UT@+B`G/2<@+B`D=7-E<B`N("<I)RD["B`@("`@("`@("`@(&EF
M("@A)'-E87)C:"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H7R@B0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB
M*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1R97-U;'0@/2!`;&1A
M<%]G971?96YT<FEE<R@D=&AI<RT^7V1S+"`D<V5A<F-H*3L*("`@("`@("`@
M("`@0&QD87!?8VQO<V4H)'1H:7,M/E]D<RD["B`@("`@("`@("`@(&EF("@A
M:7-?87)R87DH)')E<W5L="D@?'P@*&-O=6YT*"1R97-U;'0I(#P](#$I*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")%
M;7!T>2!R97-U;'0N(BDI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M9W)O=7!S(#T@87)R87DH*3L*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I
M(#P@)')E<W5L=%LG8V]U;G0G73L@)&DK*RD@>PH@("`@("`@("`@("`@("`@
M)&=R;W5P<ULD<F5S=6QT6R1I75LG9&XG75T@/2`D<F5S=6QT6R1I75LD=&AI
M<RT^7W!A<F%M<ULG9VED)UU=6S!=.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`D8V%C:&5;)'5S97)=(#T@)&=R;W5P<SL*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D8V%C:&5;)'5S97)=.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@=')E92!D97!T:"!O9B!T:&4@9VEV96X@9W)O=7`L
M(')E;&%T:79E('1O('1H92!B87-E(&1N+@H@("`@("H@,"!I<R!R971U<FYE
M9"!F;W(@86YY(&]B:F5C="!D:7)E8W1L>2!B96QO=R!T:&4@8F%S92!D;BX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D;B`@5&AE(&1N(&]F('1H
M92!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E;F=E<B`@5&AE
M('1R92!D97!T:"!O9B!T:&4@9W)O=7`N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$QE=F5L*"1D;BD*("`@('L*("`@("`@("`D8F%S92`]($!L9&%P7V5X
M<&QO9&5?9&XH)'1H:7,M/E]P87)A;7-;)V)A<V5D;B==+"`P*3L*("`@("`@
M("`D9W)O=7`@/2!`;&1A<%]E>'!L;V1E7V1N*"1D;BP@,"D["B`@("`@("`@
M<F5T=7)N("1G<F]U<%LG8V]U;G0G72`M("1B87-E6R=C;W5N="==("T@,3L*
M("`@('T*"GT*"B\J*@H@*B!%>'1E;G-I;VX@;V8@=&AE($1A=&%4<F5E3V)J
M96-T7T=R;W5P(&-L87-S(&9O<B!S=&]R:6YG(&=R;W5P(&EN9F]R;6%T:6]N
M"B`J(&EN(&%N($Q$05`@9&ER96-T;W)Y+@H@*@H@*B!`875T:&]R("!"96X@
M0VAA=F5T(#QB96Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C$*
M("H@0'!A8VMA9V4@2&]R9&5?1W)O=7`*("HO"F-L87-S($Q$05!?1W)O=7`@
M97AT96YD<R!$871A5')E94]B:F5C=%]'<F]U<"!["@H@("`@+RHJ"B`@("`@
M*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N
M86UE("`@(%1H92!N86UE(&]F('1H:7,@9W)O=7`N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1P87)E;G0@(%1H92!D;B!O9B!T:&4@<&%R96YT(&]F('1H:7,@
M9W)O=7`N"B`@("`@*B\*("`@(&9U;F-T:6]N($Q$05!?1W)O=7`H)&YA;64L
M("1P87)E;G0@/2!N=6QL*0H@("`@>PH@("`@("`@('!A<F5N=#HZ1&%T851R
M965/8FIE8W1?1W)O=7`H)&YA;64I.PH@("`@("`@(&EF("@D<&%R96YT*2![
M"B`@("`@("`@("`@("1T:&ES+3YD871A6R=D;B==(#T@<W1R=&]L;W=E<B@D
M1TQ/0D%,4ULG8V]N9B==6R=G<F]U<"==6R=P87)A;7,G75LG9VED)UTI("X@
M)STG("X@)&YA;64@+B`G+"<@+B`D<&%R96YT.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1T:&ES+3YD871A6R=D;B==(#T@<W1R=&]L;W=E<B@D
M1TQ/0D%,4ULG8V]N9B==6R=G<F]U<"==6R=P87)A;7,G75LG9VED)UTI("X@
M)STG("X@)&YA;64@+@H@("`@("`@("`@("`@("`@)RPG("X@<W1R=&]L;W=E
M<B@D1TQ/0D%,4ULG8V]N9B==6R=G<F]U<"==6R=P87)A;7,G75LG8F%S961N
M)UTI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A(&QI
M<W0@;V8@979E<GD@=7-E<B!T:&%T(&ES('!A<G0@;V8@=&AI<R!G<F]U<"`H
M86YD(&]N;'D*("`@("`J('1H:7,@9W)O=7`I+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@(%1H92!U<V5R(&QI<W0N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&QI<W15<V5R<R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M9W)O=7!/8BT^;&ES=%5S97)S*"1T:&ES+3YD871A6R=D;B==*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($=E="!A(&QI<W0@;V8@979E<GD@=7-E<B!T:&%T
M(&ES(&$@;65M8F5R(&]F('1H:7,@9W)O=7`@86YD(&%N>2!O9@H@("`@("H@
M:70G<R!S=6)G<F]U<',N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@
M5&AE(&-O;7!L971E('5S97(@;&ES="X*("`@("`J+PH@("`@9G5N8W1I;VX@
M;&ES=$%L;%5S97)S*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]G
M<F]U<$]B+3YL:7-T06QL57-E<G,H)'1H:7,M/F1A=&%;)V1N)UTI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@5&%K92!I;B!A(&QI<W0@;V8@871T<FEB=71E
M<R!F<F]M('1H92!B86-K96YD(&%N9"!M87`@:70@=&\@;W5R"B`@("`@*B!I
M;G1E<FYA;"!D871A(&%R<F%Y+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A
M>2`D871T<FEB=71E<R`@5&AE(&QI<W0@;V8@871T<FEB=71E<R!F<F]M('1H
M92!B86-K96YD+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9G)O;4%T=')I8G5T
M97,H)&%T=')I8G5T97,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES
M+3YD871A6R=U<V5R<R==(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D
M871T<FEB=71E<R!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("!I
M9B`H)&ME>2`]/2!S=')T;VQO=V5R*"1'3$]"04Q36R=C;VYF)UU;)V=R;W5P
M)UU;)W!A<F%M<R==6R=M96UB97)U:60G72DI('L*("`@("`@("`@("`@("`@
M(&EF("AI<U]A<G)A>2@D=F%L=64I*2!["B`@("`@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)'9A;'5E(&%S("1U<V5R*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YD871A6R=U<V5R<R==6R1U<V5R72`]("<Q)SL*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YD871A6R=U<V5R<R==6R1V86QU
M95T@/2`G,2<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS
M96EF("@D:V5Y(#T]("=M86EL)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/F1A=&%;)V5M86EL)UT@/2`D=F%L=64["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^9&%T85LD:V5Y72`]("1V86QU93L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($UA<"!T:&ES(&]B:F5C="=S(&%T=')I8G5T97,@9G)O;2!T:&4@9&%T82!A
M<G)A>2!I;G1O(&$@9F]R;6%T('1H870*("`@("`J(&-A;B!B92!S=&]R960@
M:6X@86X@3$1!4"!E;G1R>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!4:&4@96YT<GD@87)R87DN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]T;T%T
M=')I8G5T97,H*0H@("`@>PH@("`@("`@("1A='1R:6)U=&5S(#T@87)R87DH
M*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^9&%T82!A<R`D:V5Y(#T^("1V
M86QU92D@>PH@("`@("`@("`@("!I9B`H)&ME>2`]/2`G=7-E<G,G*2!["B`@
M("`@("`@("`@("`@("!F;W)E86-H("@D=F%L=64@87,@)'5S97(@/3X@)&UE
M;6)E<G-H:7`I('L*("`@("`@("`@("`@("`@("`@("`D871T<FEB=71E<UMS
M=')T;VQO=V5R*"1'3$]"04Q36R=C;VYF)UU;)V=R;W5P)UU;)W!A<F%M<R==
M6R=M96UB97)U:60G72E=6UT@/2`D=7-E<CL*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?2!E;'-E:68@*"1K97D@/3T@)V5M86EL)RD@>PH@("`@
M("`@("`@("`@("`@)&%T=')I8G5T97-;)VUA:6PG72`]("%E;7!T>2@D=F%L
M=64I(#\@)'9A;'5E(#H@)R`G.PH@("`@("`@("`@("!](&5L<V5I9B`H)&ME
M>2`A/2`G9&XG("8F("1K97D@(3T@<W1R=&]L;W=E<B@D1TQ/0D%,4ULG8V]N
M9B==6R=G<F]U<"==6R=P87)A;7,G75LG;65M8F5R=6ED)UTI*2!["B`@("`@
M("`@("`@("`@("`D871T<FEB=71E<ULD:V5Y72`]("%E;7!T>2@D=F%L=64I
M(#\@)'9A;'5E(#H@)R`G.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)&%T=')I8G5T97,["B`@("!]"@I]````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92]'<F]U<"]H;V]K<RYP:'``````````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-C4T-"`Q,#4Q-30S,S<S-2`P
M,C(S,3$`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J(%1H92!'<F]U<%]H;V]K<SHZ(&-L87-S('!R;W9I
M9&5S('1H92!(;W)D92!G<F]U<',@<WES=&5M('=I=&@@=&AE"B`J(&%D9&ET
M:6]N(&]F(&%D9&EN9R!S=7!P;W)T(&9O<B!H;V]K(&9U;F-T:6]N<R!T;R!D
M969I;F4@:68@82!U<V5R"B`J(&ES(&EN(&$@9W)O=7`N"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VAO;VMS+G!H<"QV(#$N-RXR+C$P
M(#(P,#8O,#$O,#$@,C$Z,C@Z,3D@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`S+3(P,#8@2F%S;VX@4G5S="`\:G)U<W1`<G5S='EP87)T<RYC;VT^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*87-O;B!2=7-T(#QJ<G5S
M=$!R=7-T>7!A<G1S+F-O;3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P
M86-K86=E($AO<F1E7T=R;W5P"B`J+PIC;&%S<R!'<F]U<%]H;V]K<R!E>'1E
M;F1S($=R;W5P('L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!'<F]U<%]H;V]K<R@I"B`@("!["B`@("`@("`@
M<&%R96YT.CI'<F]U<"@I.PH@("`@("`@(')E<75I<F4@)$=,3T)!3%-;)W)E
M9VES=')Y)UTM/F=E="@G9FEL97)O;W0G+"`G:&]R9&4G*2`N("<O8V]N9FEG
M+VAO;VMS+G!H<"<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!L:7-T
M(&]F(&5V97)Y(&=R;W5P('1H870@)'5S97(@:7,@:6XN"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@)'5S97(@("`@("`@("`@5&AE('5S97(@=&\@
M9V5T(&=R;W5P<R!F;W(N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<&%R96YT
M1W)O=7!S("!!;'-O(')E='5R;B!T:&4@<&%R96YT<R!O9B!A;GD@9W)O=7!S
M/PH@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y(&]F(&%L
M;"!G<F]U<',@=&AE('5S97(@:7,@:6XN"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$=R;W5P365M8F5R<VAI<',H)'5S97(L("1P87)E;G1'<F]U<',@/2!F
M86QS92D*("`@('L*("`@("`@("`D;65M8F5R<VAI<',@/2!P87)E;G0Z.F=E
M=$=R;W5P365M8F5R<VAI<',H)'5S97(L("1P87)E;G1'<F]U<',I.PH@("`@
M("`@("1G<F]U<',@/2`D=&AI<RT^;&ES=$=R;W5P<R@I.PH@("`@("`@(&9O
M<F5A8V@@*"1G<F]U<',@87,@)&=I9"`]/B`D9W)O=7`I('L*("`@("`@("`@
M("`@:68@*"1T:&ES+3YH87-(;V]K*"1G<F]U<"D@)B8*("`@("`@("`@("`@
M("`@(&-A;&Q?=7-E<E]F=6YC*"1T:&ES+3Y?9V5T1W)O=7!(;V]K3F%M92@D
M9W)O=7`I+"`D=7-E<BDI('L*("`@("`@("`@("`@("`@("1M96UB97)S:&EP
M<R`K/2!A<G)A>2@D9VED(#T^("1G<F]U<"D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@:68@*"1P87)E;G1'<F]U<',I('L*("`@("`@("`@("`@("`@
M("1P87)E;G1S(#T@)'1H:7,M/F=E=$=R;W5P4&%R96YT3&ES="@D9VED*3L*
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1P87)E;G1S(&%S("1P:60@/3X@
M)'!A<F5N="D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^:&%S
M2&]O:R@D<&%R96YT*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("!C86QL
M7W5S97)?9G5N8R@D=&AI<RT^7V=E=$=R;W5P2&]O:TYA;64H)&=R;W5P*2P@
M)'5S97(I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1M96UB97)S:&EP
M<R`K/2!A<G)A>2@D<&ED(#T^("1P87)E;G0I.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1M96UB97)S:&EP<SL*("`@('T*"B`@("`O
M*BH*("`@("`J(%-A>2!I9B!A('5S97(@:7,@82!M96UB97(@;V8@82!G<F]U
M<"!O<B!N;W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'5S97(@
M("`@("`@5&AE(&YA;64@;V8@=&AE('5S97(N"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D9VED("`@("`@("!4:&4@240@;V8@=&AE(&=R;W5P+@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)'-U8F=R;W5P<R`@4F5T=7)N('1R=64@:68@=&AE
M('5S97(@:7,@:6X@86YY('-U8F=R;W5P<PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@;V8@)&=R;W5P+"!A;'-O+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;@H@("`@("HO"B`@("!F=6YC=&EO;B!U<V5R27-)
M;D=R;W5P*"1U<V5R+"`D9VED+"`D<W5B9W)O=7!S(#T@=')U92D*("`@('L*
M("`@("`@("`D9W)O=7`@/2`D=&AI<RT^9V5T1W)O=7!.86UE*"1G:60I.PH@
M("`@("`@(&EF("@D=&AI<RT^:&%S2&]O:R@D9W)O=7`I*2!["B`@("`@("`@
M("`@(&EF("AC86QL7W5S97)?9G5N8R@D=&AI<RT^7V=E=$=R;W5P2&]O:TYA
M;64H)&=R;W5P*2P@)'5S97(I*2!["B`@("`@("`@("`@("`@("`D:6Y'<F]U
M<"`]('1R=64["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D:6Y'<F]U<"`](&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)&EN1W)O=7`@/2!F86QS93L*("`@("`@("!]
M"@H@("`@("`@(&EF("@D:6Y'<F]U<"!\?"!P87)E;G0Z.G5S97))<TEN1W)O
M=7`H)'5S97(L("1G:60L("1S=6)G<F]U<',I*2!["B`@("`@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$971E
M<FUI;F5S(&EF(&$@9W)O=7`@:&%S(&$@:&]O:R!A<W-O8VEA=&5D('=I=&@@
M:70N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&=R
M;W5P(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E
M(&EF('1H92!G<F]U<"!H87,@82!H;V]K+"!F86QS92!O=&AE<G=I<V4*("`@
M("`J+PH@("`@9G5N8W1I;VX@:&%S2&]O:R@D;F%M92D*("`@('L*("`@("`@
M("!R971U<FX@9G5N8W1I;VY?97AI<W1S*"1T:&ES+3Y?9V5T1W)O=7!(;V]K
M3F%M92@D;F%M92DI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&4@;F%M92!O9B!T:&4@:&]O:R!F=6YC=&EO;BX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1N86UE("!4:&4@9W)O=7`@;F%M92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&9U;F-T:6]N(&YA;64@9F]R('1H
M92!H;V]K(&9O<B!T:&ES(&=R;W5P"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G
M971'<F]U<$AO;VM.86UE*"1N86UE*0H@("`@>PH@("`@("`@(')E='5R;B`G
M7V=R;W5P7VAO;VM?)R`N('-T<E]R97!L86-E*"<Z)RP@)U]?)RP@)&YA;64I
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O26UA9V4`````````````````````````
M````````````````````````````````````````````````````````,#`P
M-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S4@
M,#(P,S$S`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]);6%G92]R
M9V(N<&AP````````````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`T
M,C8W,2`Q,#4Q-30S,S<S-2`P,C$V-C<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%)'0B!C;VQO<B!N
M86UE<R]V86QU97,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TEM86=E+TEM
M86=E+W)G8BYP:'`L=B`Q+C(N,3(N,2`R,#`U+S$P+S$X(#$Q.C`Q.C$S(&IA
M;B!%>'`@)`H@*@H@*B!`<&%C:V%G92!(;W)D95]);6%G90H@*B\*)$=,3T)!
M3%-;)VAO<F1E7VEM86=E7W)G8E]C;VQO<G,G72`](&%R<F%Y*`H@("`@)V%Q
M=6$G(#T^(&%R<F%Y*#`L(#(U-2P@,C4U*2P@"0D*("`@("=L:6UE)R`]/B!A
M<G)A>2@P+"`R-34L(#`I+"`)"0H@("`@)W1E86PG(#T^(&%R<F%Y*#`L(#$R
M."P@,3(X*2P*("`@("=W:&ET97-M;VME)R`]/B!A<G)A>2@R-#4L(#(T-2P@
M,C0U*2P*("`@("=G86EN<V)O<F\G(#T^(&%R<F%Y*#(R,"P@,C(P+"`R,C`I
M+`H@("`@)V]L9&QA8V4G(#T^(&%R<F%Y*#(U,RP@,C0U+"`R,S`I+`H@("`@
M)VQI;F5N)R`]/B!A<G)A>2@R-3`L(#(T,"P@,C,P*2P*("`@("=A;G1I<75E
M=VAI=&4G(#T^(&%R<F%Y*#(U,"P@,C,U+"`R,34I+`H@("`@)W!A<&%Y87=H
M:7`G(#T^(&%R<F%Y*#(U-2P@,C,Y+"`R,3,I+`H@("`@)V)L86YC:&5D86QM
M;VYD)R`]/B!A<G)A>2@R-34L(#(S-2P@,C`U*2P*("`@("=B:7-Q=64G(#T^
M(&%R<F%Y*#(U-2P@,C(X+"`Q.38I+`H@("`@)W!E86-H<'5F9B<@/3X@87)R
M87DH,C4U+"`R,3@L(#$X-2DL"B`@("`G;F%V86IO=VAI=&4G(#T^(&%R<F%Y
M*#(U-2P@,C(R+"`Q-S,I+`H@("`@)VUO8V-A<VEN)R`]/B!A<G)A>2@R-34L
M(#(R."P@,3@Q*2P*("`@("=C;W)N<VEL:R<@/3X@87)R87DH,C4U+"`R-#@L
M(#(R,"DL"B`@("`G:79O<GDG(#T^(&%R<F%Y*#(U-2P@,C4U+"`R-#`I+`H@
M("`@)VQE;6]N8VAI9F9O;B<@/3X@87)R87DH,C4U+"`R-3`L(#(P-2DL"B`@
M("`G<V5A<VAE;&PG(#T^(&%R<F%Y*#(U-2P@,C0U+"`R,S@I+`H@("`@)VUI
M;G1C<F5A;2<@/3X@87)R87DH,C0U+"`R-34L(#(U,"DL"B`@("`G87IU<F4G
M(#T^(&%R<F%Y*#(T,"P@,C4U+"`R-34I+`H@("`@)V%L:6-E8FQU92<@/3X@
M87)R87DH,C0P+"`R-#@L(#(U-2DL"B`@("`G;&%V96YD97(G(#T^(&%R<F%Y
M*#(S,"P@,C,P+"`R-3`I+`H@("`@)VQA=F5N9&5R8FQU<V@G(#T^(&%R<F%Y
M*#(U-2P@,C0P+"`R-#4I+`H@("`@)VUI<W1Y<F]S92<@/3X@87)R87DH,C4U
M+"`R,C@L(#(R-2DL"B`@("`G=VAI=&4G(#T^(&%R<F%Y*#(U-2P@,C4U+"`R
M-34I+`H@("`@)V)L86-K)R`]/B!A<G)A>2@P+"`P+"`P*2P*("`@("=D87)K
M<VQA=&5G<F%Y)R`]/B!A<G)A>2@T-RP@-SDL(#<Y*2P*("`@("=D:6UG<F%Y
M)R`]/B!A<G)A>2@Q,#4L(#$P-2P@,3`U*2P*("`@("=S;&%T96=R87DG(#T^
M(&%R<F%Y*#$Q,BP@,3(X+"`Q-#0I+`H@("`@)VQI9VAT<VQA=&5G<F%Y)R`]
M/B!A<G)A>2@Q,3DL(#$S-BP@,34S*2P*("`@("=G<F%Y)R`]/B!A<G)A>2@Q
M.3`L(#$Y,"P@,3DP*2P*("`@("=L:6=H=&=R87DG(#T^(&%R<F%Y*#(Q,2P@
M,C$Q+"`R,3$I+`H@("`@)VUI9&YI9VAT8FQU92<@/3X@87)R87DH,C4L(#(U
M+"`Q,3(I+`H@("`@)VYA=GDG(#T^(&%R<F%Y*#`L(#`L(#$R."DL"B`@("`G
M8V]R;F9L;W=E<F)L=64G(#T^(&%R<F%Y*#$P,"P@,30Y+"`R,S<I+`H@("`@
M)V1A<FMS;&%T96)L=64G(#T^(&%R<F%Y*#<R+"`V,2P@,3,Y*2P*("`@("=S
M;&%T96)L=64G(#T^(&%R<F%Y*#$P-BP@.3`L(#(P-2DL"B`@("`G;65D:75M
M<VQA=&5B;'5E)R`]/B!A<G)A>2@Q,C,L(#$P-"P@,C,X*2P*("`@("=L:6=H
M='-L871E8FQU92<@/3X@87)R87DH,3,R+"`Q,3(L(#(U-2DL"B`@("`G;65D
M:75M8FQU92<@/3X@87)R87DH,"P@,"P@,C`U*2P*("`@("=R;WEA;&)L=64G
M(#T^(&%R<F%Y*#8U+"`Q,#4L(#(R-2DL"B`@("`G8FQU92<@/3X@87)R87DH
M,"P@,"P@,C4U*2P*("`@("=D;V1G97)B;'5E)R`]/B!A<G)A>2@S,"P@,30T
M+"`R-34I+`H@("`@)V1E97!S:WEB;'5E)R`]/B!A<G)A>2@P+"`Q.3$L(#(U
M-2DL"B`@("`G<VMY8FQU92<@/3X@87)R87DH,3,U+"`R,#8L(#(S-2DL"B`@
M("`G;&EG:'1S:WEB;'5E)R`]/B!A<G)A>2@Q,S4L(#(P-BP@,C4P*2P*("`@
M("=S=&5E;&)L=64G(#T^(&%R<F%Y*#<P+"`Q,S`L(#$X,"DL"B`@("`G;&EG
M:'1R960G(#T^(&%R<F%Y*#(Q,2P@,38W+"`Q-C@I+`H@("`@)VQI9VAT<W1E
M96QB;'5E)R`]/B!A<G)A>2@Q-S8L(#$Y-BP@,C(R*2P*("`@("=L:6=H=&)L
M=64G(#T^(&%R<F%Y*#$W,RP@,C$V+"`R,S`I+`H@("`@)W!O=V1E<F)L=64G
M(#T^(&%R<F%Y*#$W-BP@,C(T+"`R,S`I+`H@("`@)W!A;&5T=7)Q=6]I<V4G
M(#T^(&%R<F%Y*#$W-2P@,C,X+"`R,S@I+`H@("`@)V1A<FMT=7)Q=6]I<V4G
M(#T^(&%R<F%Y*#`L(#(P-BP@,C`Y*2P*("`@("=M961I=6UT=7)Q=6]I<V4G
M(#T^(&%R<F%Y*#<R+"`R,#DL(#(P-"DL"B`@("`G='5R<75O:7-E)R`]/B!A
M<G)A>2@V-"P@,C(T+"`R,#@I+`H@("`@)V-Y86XG(#T^(&%R<F%Y*#`L(#(U
M-2P@,C4U*2P*("`@("=L:6=H=&-Y86XG(#T^(&%R<F%Y*#(R-"P@,C4U+"`R
M-34I+`H@("`@)V-A9&5T8FQU92<@/3X@87)R87DH.34L(#$U."P@,38P*2P*
M("`@("=M961I=6UA<75A;6%R:6YE)R`]/B!A<G)A>2@Q,#(L(#(P-2P@,3<P
M*2P*("`@("=A<75A;6%R:6YE)R`]/B!A<G)A>2@Q,C<L(#(U-2P@,C$R*2P*
M("`@("=D87)K9W)E96XG(#T^(&%R<F%Y*#`L(#$P,"P@,"DL"B`@("`G9&%R
M:V]L:79E9W)E96XG(#T^(&%R<F%Y*#@U+"`Q,#<L(#0W*2P*("`@("=D87)K
M<V5A9W)E96XG(#T^(&%R<F%Y*#$T,RP@,3@X+"`Q-#,I+`H@("`@)W-E86=R
M965N)R`]/B!A<G)A>2@T-BP@,3,Y+"`X-RDL"B`@("`G;65D:75M<V5A9W)E
M96XG(#T^(&%R<F%Y*#8P+"`Q-SDL(#$Q,RDL"B`@("`G;&EG:'1S96%G<F5E
M;B<@/3X@87)R87DH,S(L(#$W."P@,3<P*2P*("`@("=P86QE9W)E96XG(#T^
M(&%R<F%Y*#$U,BP@,C4Q+"`Q-3(I+`H@("`@)W-P<FEN9V=R965N)R`]/B!A
M<G)A>2@P+"`R-34L(#$R-RDL"B`@("`G;&%W;F=R965N)R`]/B!A<G)A>2@Q
M,C0L(#(U,BP@,"DL"B`@("`G9W)E96XG(#T^(&%R<F%Y*#`L(#(U-2P@,"DL
M"B`@("`G8VAA<G1R975S92<@/3X@87)R87DH,3(W+"`R-34L(#`I+`H@("`@
M)VUE9&EU;7-P<FEN9V=R965N)R`]/B!A<G)A>2@P+"`R-3`L(#$U-"DL"B`@
M("`G9W)E96YY96QL;W<G(#T^(&%R<F%Y*#$W,RP@,C4U+"`T-RDL"B`@("`G
M;&EM96=R965N)R`]/B!A<G)A>2@U,"P@,C`U+"`U,"DL"B`@("`G>65L;&]W
M9W)E96XG(#T^(&%R<F%Y*#$U-"P@,C`U+"`U,"DL"B`@("`G9F]R97-T9W)E
M96XG(#T^(&%R<F%Y*#,T+"`Q,SDL(#,T*2P*("`@("=O;&EV961R86(G(#T^
M(&%R<F%Y*#$P-RP@,30R+"`S-2DL"B`@("`G9&%R:VMH86MI)R`]/B!A<G)A
M>2@Q.#DL(#$X,RP@,3`W*2P*("`@("=K:&%K:2<@/3X@87)R87DH,C0P+"`R
M,S`L(#$T,"DL"B`@("`G<&%L96=O;&1E;G)O9"<@/3X@87)R87DH,C,X+"`R
M,S(L(#$W,"DL"B`@("`G;&EG:'1G;VQD96YR;V1Y96QL;W<G(#T^(&%R<F%Y
M*#(U,"P@,C4P+"`R,3`I+`H@("`@)VQI9VAT>65L;&]W)R`]/B!A<G)A>2@R
M-34L(#(U-2P@,C`P*2P*("`@("=Y96QL;W<G(#T^(&%R<F%Y*#(U-2P@,C4U
M+"`P*2P*("`@("=G;VQD)R`]/B!A<G)A>2@R-34L(#(Q-2P@,"DL"B`@("`G
M;&EG:'1G;VQD96YR;V0G(#T^(&%R<F%Y*#(S."P@,C(Q+"`Q,S`I+`H@("`@
M)V=O;&1E;G)O9"<@/3X@87)R87DH,C$X+"`Q-C4L(#,R*2P*("`@("=D87)K
M9V]L9&5N<F]D)R`]/B!A<G)A>2@Q.#0L(#$S-"P@,3$I+`H@("`@)W)O<WEB
M<F]W;B<@/3X@87)R87DH,3@X+"`Q-#,L(#$T,RDL"B`@("`G:6YD:6%N<F5D
M)R`]/B!A<G)A>2@R,#4L(#DR+"`Y,BDL"B`@("`G<V%D9&QE8G)O=VXG(#T^
M(&%R<F%Y*#$S.2P@-CDL(#$Y*2P*("`@("=S:65N;F$G(#T^(&%R<F%Y*#$V
M,"P@.#(L(#0U*2P*("`@("=P97)U)R`]/B!A<G)A>2@R,#4L(#$S,RP@-C,I
M+`H@("`@)V)U<FQY=V]O9"<@/3X@87)R87DH,C(R+"`Q.#0L(#$S-2DL"B`@
M("`G8F5I9V4G(#T^(&%R<F%Y*#(T-2P@,C0U+"`R,C`I+`H@("`@)W=H96%T
M)R`]/B!A<G)A>2@R-#4L(#(R,BP@,3<Y*2P*("`@("=S86YD>6)R;W=N)R`]
M/B!A<G)A>2@R-#0L(#$V-"P@.38I+`H@("`@)W1A;B<@/3X@87)R87DH,C$P
M+"`Q.#`L(#$T,"DL"B`@("`G8VAO8V]L871E)R`]/B!A<G)A>2@R,3`L(#$P
M-2P@,S`I+`H@("`@)V9I<F5B<FEC:R<@/3X@87)R87DH,3<X+"`S-"P@,S0I
M+`H@("`@)V)R;W=N)R`]/B!A<G)A>2@Q-C4L(#0R+"`T,BDL"B`@("`G9&%R
M:W-A;&UO;B<@/3X@87)R87DH,C,S+"`Q-3`L(#$R,BDL"B`@("`G<V%L;6]N
M)R`]/B!A<G)A>2@R-3`L(#$R."P@,3$T*2P*("`@("=L:6=H='-A;&UO;B<@
M/3X@87)R87DH,C4U+"`Q-C`L(#$R,BDL"B`@("`G;W)A;F=E)R`]/B!A<G)A
M>2@R-34L(#$V-2P@,"DL"B`@("`G9&%R:V]R86YG92<@/3X@87)R87DH,C4U
M+"`Q-#`L(#`I+`H@("`@)V-O<F%L)R`]/B!A<G)A>2@R-34L(#$R-RP@.#`I
M+`H@("`@)VQI9VAT8V]R86PG(#T^(&%R<F%Y*#(T,"P@,3(X+"`Q,C@I+`H@
M("`@)W1O;6%T;R<@/3X@87)R87DH,C4U+"`Y.2P@-S$I+`H@("`@)V]R86YG
M97)E9"<@/3X@87)R87DH,C4U+"`V.2P@,"DL"B`@("`G<F5D)R`]/B!A<G)A
M>2@R-34L(#`L(#`I+`H@("`@)VAO='!I;FLG(#T^(&%R<F%Y*#(U-2P@,3`U
M+"`Q.#`I+`H@("`@)V1E97!P:6YK)R`]/B!A<G)A>2@R-34L(#(P+"`Q-#<I
M+`H@("`@)W!I;FLG(#T^(&%R<F%Y*#(U-2P@,3DR+"`R,#,I+`H@("`@)VQI
M9VAT<&EN:R<@/3X@87)R87DH,C4U+"`Q.#(L(#$Y,RDL"B`@("`G<&%L979I
M;VQE=')E9"<@/3X@87)R87DH,C$Y+"`Q,3(L(#$T-RDL"B`@("`G;6%R;V]N
M)R`]/B!A<G)A>2@Q-S8L(#0X+"`Y-BDL"B`@("`G;65D:75M=FEO;&5T<F5D
M)R`]/B!A<G)A>2@Q.3DL(#(Q+"`Q,S,I+`H@("`@)W9I;VQE=')E9"<@/3X@
M87)R87DH,C`X+"`S,BP@,30T*2P*("`@("=M86=E;G1A)R`]/B!A<G)A>2@R
M-34L(#`L(#(U-2DL"B`@("`G=FEO;&5T)R`]/B!A<G)A>2@R,S@L(#$S,"P@
M,C,X*2P*("`@("=P;'5M)R`]/B!A<G)A>2@R,C$L(#$V,"P@,C(Q*2P*("`@
M("=O<F-H:60G(#T^(&%R<F%Y*#(Q."P@,3$R+"`R,30I+`H@("`@)VUE9&EU
M;6]R8VAI9"<@/3X@87)R87DH,3@V+"`X-2P@,C$Q*2P*("`@("=D87)K;W)C
M:&ED)R`]/B!A<G)A>2@Q-3,L(#4P+"`R,#0I+`H@("`@)V1A<FMV:6]L970G
M(#T^(&%R<F%Y*#$T."P@,"P@,C$Q*2P*("`@("=B;'5E=FEO;&5T)R`]/B!A
M<G)A>2@Q,S@L(#0S+"`R,C8I+`H@("`@)W!U<G!L92<@/3X@87)R87DH,38P
M+"`S,BP@,C0P*2P*("`@("=M961I=6UP=7)P;&4G(#T^(&%R<F%Y*#$T-RP@
M,3$R+"`R,3DI+`H@("`@)W1H:7-T;&4G(#T^(&%R<F%Y*#(Q-BP@,3DQ+"`R
M,38I+`H@("`@)W-N;W<Q)R`]/B!A<G)A>2@R-34L(#(U,"P@,C4P*2P*("`@
M("=S;F]W,B<@/3X@87)R87DH,C,X+"`R,S,L(#(S,RDL"B`@("`G<VYO=S,G
M(#T^(&%R<F%Y*#(P-2P@,C`Q+"`R,#$I+`H@("`@)W-N;W<T)R`]/B!A<G)A
M>2@Q,SDL(#$S-RP@,3,W*2P*("`@("=S96%S:&5L;#$G(#T^(&%R<F%Y*#(U
M-2P@,C0U+"`R,S@I+`H@("`@)W-E87-H96QL,B<@/3X@87)R87DH,C,X+"`R
M,CDL(#(R,BDL"B`@("`G<V5A<VAE;&PS)R`]/B!A<G)A>2@R,#4L(#$Y-RP@
M,3DQ*2P*("`@("=S96%S:&5L;#0G(#T^(&%R<F%Y*#$S.2P@,3,T+"`Q,S`I
M+`H@("`@)T%N=&EQ=657:&ET93$G(#T^(&%R<F%Y*#(U-2P@,C,Y+"`R,3DI
M+`H@("`@)T%N=&EQ=657:&ET93(G(#T^(&%R<F%Y*#(S."P@,C(S+"`R,#0I
M+`H@("`@)T%N=&EQ=657:&ET93,G(#T^(&%R<F%Y*#(P-2P@,3DR+"`Q-S8I
M+`H@("`@)T%N=&EQ=657:&ET930G(#T^(&%R<F%Y*#$S.2P@,3,Q+"`Q,C`I
M+`H@("`@)V)I<W%U93$G(#T^(&%R<F%Y*#(U-2P@,C(X+"`Q.38I+`H@("`@
M)V)I<W%U93(G(#T^(&%R<F%Y*#(S."P@,C$S+"`Q.#,I+`H@("`@)V)I<W%U
M93,G(#T^(&%R<F%Y*#(P-2P@,3@S+"`Q-3@I+`H@("`@)V)I<W%U930G(#T^
M(&%R<F%Y*#$S.2P@,3(U+"`Q,#<I+`H@("`@)W!E86-H4'5F9C$G(#T^(&%R
M<F%Y*#(U-2P@,C$X+"`Q.#4I+`H@("`@)W!E86-H<'5F9C(G(#T^(&%R<F%Y
M*#(S."P@,C`S+"`Q-S,I+`H@("`@)W!E86-H<'5F9C,G(#T^(&%R<F%Y*#(P
M-2P@,3<U+"`Q-#DI+`H@("`@)W!E86-H<'5F9C0G(#T^(&%R<F%Y*#$S.2P@
M,3$Y+"`Q,#$I+`H@("`@)VYA=F%J;W=H:71E,2<@/3X@87)R87DH,C4U+"`R
M,C(L(#$W,RDL"B`@("`G;F%V86IO=VAI=&4R)R`]/B!A<G)A>2@R,S@L(#(P
M-RP@,38Q*2P*("`@("=N879A:F]W:&ET93,G(#T^(&%R<F%Y*#(P-2P@,3<Y
M+"`Q,SDI+`H@("`@)VYA=F%J;W=H:71E-"<@/3X@87)R87DH,3,Y+"`Q,C$L
M(#DT*2P*("`@("=L96UO;F-H:69F;VXQ)R`]/B!A<G)A>2@R-34L(#(U,"P@
M,C`U*2P*("`@("=L96UO;F-H:69F;VXR)R`]/B!A<G)A>2@R,S@L(#(S,RP@
M,3DQ*2P*("`@("=L96UO;F-H:69F;VXS)R`]/B!A<G)A>2@R,#4L(#(P,2P@
M,38U*2P*("`@("=L96UO;F-H:69F;VXT)R`]/B!A<G)A>2@Q,SDL(#$S-RP@
M,3$R*2P*("`@("=I=F]R>3$G(#T^(&%R<F%Y*#(U-2P@,C4U+"`R-#`I+`H@
M("`@)VEV;W)Y,B<@/3X@87)R87DH,C,X+"`R,S@L(#(R-"DL"B`@("`G:79O
M<GDS)R`]/B!A<G)A>2@R,#4L(#(P-2P@,3DS*2P*("`@("=I=F]R>30G(#T^
M(&%R<F%Y*#$S.2P@,3,Y+"`Q,S$I+`H@("`@)VAO;F5Y9&5W)R`]/B!A<G)A
M>2@Q.3,L(#(P-2P@,3DS*2P*("`@("=L879E;F1E<F)L=7-H,2<@/3X@87)R
M87DH,C4U+"`R-#`L(#(T-2DL"B`@("`G;&%V96YD97)B;'5S:#(G(#T^(&%R
M<F%Y*#(S."P@,C(T+"`R,CDI+`H@("`@)VQA=F5N9&5R8FQU<V@S)R`]/B!A
M<G)A>2@R,#4L(#$Y,RP@,3DW*2P*("`@("=L879E;F1E<F)L=7-H-"<@/3X@
M87)R87DH,3,Y+"`Q,S$L(#$S-"DL"B`@("`G;6ES='ER;W-E,2<@/3X@87)R
M87DH,C4U+"`R,C@L(#(R-2DL"B`@("`G;6ES='ER;W-E,B<@/3X@87)R87DH
M,C,X+"`R,3,L(#(Q,"DL"B`@("`G;6ES='ER;W-E,R<@/3X@87)R87DH,C`U
M+"`Q.#,L(#$X,2DL"B`@("`G;6ES='ER;W-E-"<@/3X@87)R87DH,3,Y+"`Q
M,C4L(#$R,RDL"B`@("`G87IU<F4Q)R`]/B!A<G)A>2@R-#`L(#(U-2P@,C4U
M*2P*("`@("=A>G5R93(G(#T^(&%R<F%Y*#(R-"P@,C,X+"`R,S@I+`H@("`@
M)V%Z=7)E,R<@/3X@87)R87DH,3DS+"`R,#4L(#(P-2DL"B`@("`G87IU<F4T
M)R`]/B!A<G)A>2@Q,S$L(#$S.2P@,3,Y*2P*("`@("=S;&%T96)L=64Q)R`]
M/B!A<G)A>2@Q,S$L(#$Q,2P@,C4U*2P*("`@("=S;&%T96)L=64R)R`]/B!A
M<G)A>2@Q,C(L(#$P,RP@,C,X*2P*("`@("=S;&%T96)L=64S)R`]/B!A<G)A
M>2@Q,#4L(#@Y+"`R,#4I+`H@("`@)W-L871E8FQU930G(#T^(&%R<F%Y*#<Q
M+"`V,"P@,3,Y*2P*("`@("=R;WEA;&)L=64Q)R`]/B!A<G)A>2@W,BP@,3$X
M+"`R-34I+`H@("`@)W)O>6%L8FQU93(G(#T^(&%R<F%Y*#8W+"`Q,3`L(#(S
M."DL"B`@("`G<F]Y86QB;'5E,R<@/3X@87)R87DH-3@L(#DU+"`R,#4I+`H@
M("`@)W)O>6%L8FQU930G(#T^(&%R<F%Y*#,Y+"`V-"P@,3,Y*2P*("`@("=D
M;V1G97)B;'5E,2<@/3X@87)R87DH,S`L(#$T-"P@,C4U*2P*("`@("=D;V1G
M97)B;'5E,B<@/3X@87)R87DH,C@L(#$S-"P@,C,X*2P*("`@("=D;V1G97)B
M;'5E,R<@/3X@87)R87DH,C0L(#$Q-BP@,C`U*2P*("`@("=D;V1G97)B;'5E
M-"<@/3X@87)R87DH,38L(#<X+"`Q,SDI+`H@("`@)W-T965L8FQU93$G(#T^
M(&%R<F%Y*#DY+"`Q.#0L(#(U-2DL"B`@("`G<W1E96QB;'5E,B<@/3X@87)R
M87DH.3(L(#$W,BP@,C,X*2P*("`@("=S=&5E;&)L=64S)R`]/B!A<G)A>2@W
M.2P@,30X+"`R,#4I+`H@("`@)W-T965L8FQU930G(#T^(&%R<F%Y*#4T+"`Q
M,#`L(#$S.2DL"B`@("`G9&5E<'-K>6)L=64Q)R`]/B!A<G)A>2@P+"`Q.3$L
M(#(U-2DL"B`@("`G9&5E<'-K>6)L=64R)R`]/B!A<G)A>2@P+"`Q-S@L(#(S
M."DL"B`@("`G9&5E<'-K>6)L=64S)R`]/B!A<G)A>2@P+"`Q-30L(#(P-2DL
M"B`@("`G9&5E<'-K>6)L=64T)R`]/B!A<G)A>2@P+"`Q,#0L(#$S.2DL"B`@
M("`G<VMY8FQU93$G(#T^(&%R<F%Y*#$S-2P@,C`V+"`R-34I+`H@("`@)W-K
M>6)L=64R)R`]/B!A<G)A>2@Q,C8L(#$Y,BP@,C,X*2P*("`@("=S:WEB;'5E
M,R<@/3X@87)R87DH,3`X+"`Q-C8L(#(P-2DL"B`@("`G<VMY8FQU930G(#T^
M(&%R<F%Y*#<T+"`Q,3(L(#$S.2DL"B`@("`G;&EG:'1S:WEB;'5E,2<@/3X@
M87)R87DH,3<V+"`R,C8L(#(U-2DL"B`@("`G;&EG:'1S:WEB;'5E,B<@/3X@
M87)R87DH,38T+"`R,3$L(#(S."DL"B`@("`G;&EG:'1S:WEB;'5E,R<@/3X@
M87)R87DH,30Q+"`Q.#(L(#(P-2DL"B`@("`G;&EG:'1S:WEB;'5E-"<@/3X@
M87)R87DH.38L(#$R,RP@,3,Y*2P*("`@("=S;&%T96=R87DQ)R`]/B!A<G)A
M>2@Q.3@L(#(R-BP@,C4U*2P*("`@("=S;&%T96=R87DR)R`]/B!A<G)A>2@Q
M.#4L(#(Q,2P@,C,X*2P*("`@("=S;&%T96=R87DS)R`]/B!A<G)A>2@Q-3DL
M(#$X,BP@,C`U*2P*("`@("=S;&%T96=R87DT)R`]/B!A<G)A>2@Q,#@L(#$R
M,RP@,3,Y*2P*("`@("=L:6=H='-T965L8FQU93$G(#T^(&%R<F%Y*#(P,BP@
M,C(U+"`R-34I+`H@("`@)VQI9VAT<W1E96QB;'5E,B<@/3X@87)R87DH,3@X
M+"`R,3`L(#(S."DL"B`@("`G;&EG:'1S=&5E;&)L=64S)R`]/B!A<G)A>2@Q
M-C(L(#$X,2P@,C`U*2P*("`@("=L:6=H='-T965L8FQU930G(#T^(&%R<F%Y
M*#$Q,"P@,3(S+"`Q,SDI+`H@("`@)VQI9VAT8FQU93$G(#T^(&%R<F%Y*#$Y
M,2P@,C,Y+"`R-34I+`H@("`@)VQI9VAT8FQU93(G(#T^(&%R<F%Y*#$W."P@
M,C(S+"`R,S@I+`H@("`@)VQI9VAT8FQU93,G(#T^(&%R<F%Y*#$U-"P@,3DR
M+"`R,#4I+`H@("`@)VQI9VAT8FQU930G(#T^(&%R<F%Y*#$P-"P@,3,Q+"`Q
M,SDI+`H@("`@)VQI9VAT8WEA;C$G(#T^(&%R<F%Y*#(R-"P@,C4U+"`R-34I
M+`H@("`@)VQI9VAT8WEA;C(G(#T^(&%R<F%Y*#(P.2P@,C,X+"`R,S@I+`H@
M("`@)VQI9VAT8WEA;C,G(#T^(&%R<F%Y*#$X,"P@,C`U+"`R,#4I+`H@("`@
M)VQI9VAT8WEA;C0G(#T^(&%R<F%Y*#$R,BP@,3,Y+"`Q,SDI+`H@("`@)W!A
M;&5T=7)Q=6]I<V4Q)R`]/B!A<G)A>2@Q.#<L(#(U-2P@,C4U*2P*("`@("=P
M86QE='5R<75O:7-E,B<@/3X@87)R87DH,3<T+"`R,S@L(#(S."DL"B`@("`G
M<&%L971U<G%U;VES93,G(#T^(&%R<F%Y*#$U,"P@,C`U+"`R,#4I+`H@("`@
M)W!A;&5T=7)Q=6]I<V4T)R`]/B!A<G)A>2@Q,#(L(#$S.2P@,3,Y*2P*("`@
M("=C861E=&)L=64Q)R`]/B!A<G)A>2@Q-3(L(#(T-2P@,C4U*2P*("`@("=C
M861E=&)L=64R)R`]/B!A<G)A>2@Q-#(L(#(R.2P@,C,X*2P*("`@("=C861E
M=&)L=64S)R`]/B!A<G)A>2@Q,C(L(#$Y-RP@,C`U*2P*("`@("=C861E=&)L
M=64T)R`]/B!A<G)A>2@X,RP@,3,T+"`Q,SDI+`H@("`@)W1U<G%U;VES93$G
M(#T^(&%R<F%Y*#`L(#(T-2P@,C4U*2P*("`@("=T=7)Q=6]I<V4R)R`]/B!A
M<G)A>2@P+"`R,CDL(#(S."DL"B`@("`G='5R<75O:7-E,R<@/3X@87)R87DH
M,"P@,3DW+"`R,#4I+`H@("`@)W1U<G%U;VES930G(#T^(&%R<F%Y*#`L(#$S
M-"P@,3,Y*2P*("`@("=C>6%N,2<@/3X@87)R87DH,"P@,C4U+"`R-34I+`H@
M("`@)V-Y86XR)R`]/B!A<G)A>2@P+"`R,S@L(#(S."DL"B`@("`G8WEA;C,G
M(#T^(&%R<F%Y*#`L(#(P-2P@,C`U*2P*("`@("=C>6%N-"<@/3X@87)R87DH
M,"P@,3,Y+"`Q,SDI+`H@("`@)V1A<FMS;&%T96=R87DQ)R`]/B!A<G)A>2@Q
M-3$L(#(U-2P@,C4U*2P*("`@("=D87)K<VQA=&5G<F%Y,B<@/3X@87)R87DH
M,30Q+"`R,S@L(#(S."DL"B`@("`G9&%R:W-L871E9W)A>3,G(#T^(&%R<F%Y
M*#$R,2P@,C`U+"`R,#4I+`H@("`@)V1A<FMS;&%T96=R87DT)R`]/B!A<G)A
M>2@X,BP@,3,Y+"`Q,SDI+`H@("`@)V%Q=6%M87)I;F4Q)R`]/B!A<G)A>2@Q
M,C<L(#(U-2P@,C$R*2P*("`@("=A<75A;6%R:6YE,B<@/3X@87)R87DH,3$X
M+"`R,S@L(#$Y."DL"B`@("`G87%U86UA<FEN93,G(#T^(&%R<F%Y*#$P,BP@
M,C`U+"`Q-S`I+`H@("`@)V%Q=6%M87)I;F4T)R`]/B!A<G)A>2@V.2P@,3,Y
M+"`Q,38I+`H@("`@)V1A<FMS96%G<F5E;C$G(#T^(&%R<F%Y*#$Y,RP@,C4U
M+"`Q.3,I+`H@("`@)V1A<FMS96%G<F5E;C(G(#T^(&%R<F%Y*#$X,"P@,C,X
M+"`Q.#`I+`H@("`@)V1A<FMS96%G<F5E;C,G(#T^(&%R<F%Y*#$U-2P@,C`U
M+"`Q-34I+`H@("`@)V1A<FMS96%G<F5E;C0G(#T^(&%R<F%Y*#$P-2P@,3,Y
M+"`Q,#4I+`H@("`@)W-E86=R965N,2<@/3X@87)R87DH.#0L(#(U-2P@,34Y
M*2P*("`@("=S96%G<F5E;C(G(#T^(&%R<F%Y*#<X+"`R,S@L(#$T."DL"B`@
M("`G<V5A9W)E96XS)R`]/B!A<G)A>2@V-RP@,C`U+"`Q,C@I+`H@("`@)W-E
M86=R965N-"<@/3X@87)R87DH-#8L(#$S.2P@.#<I+`H@("`@)W!A;&5G<F5E
M;C$G(#T^(&%R<F%Y*#$U-"P@,C4U+"`Q-30I+`H@("`@)W!A;&5G<F5E;C(G
M(#T^(&%R<F%Y*#$T-"P@,C,X+"`Q-#0I+`H@("`@)W!A;&5G<F5E;C,G(#T^
M(&%R<F%Y*#$R-"P@,C`U+"`Q,C0I+`H@("`@)W!A;&5G<F5E;C0G(#T^(&%R
M<F%Y*#@T+"`Q,SDL(#@T*2P*("`@("=S<')I;F=G<F5E;C$G(#T^(&%R<F%Y
M*#`L(#(U-2P@,3(W*2P*("`@("=S<')I;F=G<F5E;C(G(#T^(&%R<F%Y*#`L
M(#(S."P@,3$X*2P*("`@("=S<')I;F=G<F5E;C,G(#T^(&%R<F%Y*#`L(#(P
M-2P@,3`R*2P*("`@("=S<')I;F=G<F5E;C0G(#T^(&%R<F%Y*#`L(#$S.2P@
M-CDI+`H@("`@)V-H87)T<F5U<V4Q)R`]/B!A<G)A>2@Q,C<L(#(U-2P@,"DL
M"B`@("`G8VAA<G1R975S93(G(#T^(&%R<F%Y*#$Q."P@,C,X+"`P*2P*("`@
M("=C:&%R=')E=7-E,R<@/3X@87)R87DH,3`R+"`R,#4L(#`I+`H@("`@)V-H
M87)T<F5U<V4T)R`]/B!A<G)A>2@V.2P@,3,Y+"`P*2P*("`@("=O;&EV961R
M86(Q)R`]/B!A<G)A>2@Q.3(L(#(U-2P@-C(I+`H@("`@)V]L:79E9')A8C(G
M(#T^(&%R<F%Y*#$W.2P@,C,X+"`U."DL"B`@("`G;VQI=F5D<F%B,R<@/3X@
M87)R87DH,34T+"`R,#4L(#4P*2P*("`@("=O;&EV961R86(T)R`]/B!A<G)A
M>2@Q,#4L(#$S.2P@,S0I+`H@("`@)V1A<FMO;&EV96=R965N,2<@/3X@87)R
M87DH,C`R+"`R-34L(#$Q,BDL"B`@("`G9&%R:V]L:79E9W)E96XR)R`]/B!A
M<G)A>2@Q.#@L(#(S."P@,3`T*2P*("`@("=D87)K;VQI=F5G<F5E;C,G(#T^
M(&%R<F%Y*#$V,BP@,C`U+"`Y,"DL"B`@("`G9&%R:V]L:79E9W)E96XT)R`]
M/B!A<G)A>2@Q,3`L(#$S.2P@-C$I+`H@("`@)VMH86MI,2<@/3X@87)R87DH
M,C4U+"`R-#8L(#$T,RDL"B`@("`G:VAA:VDR)R`]/B!A<G)A>2@R,S@L(#(S
M,"P@,3,S*2P*("`@("=K:&%K:3,G(#T^(&%R<F%Y*#(P-2P@,3DX+"`Q,34I
M+`H@("`@)VMH86MI-"<@/3X@87)R87DH,3,Y+"`Q,S0L(#<X*2P*("`@("=L
M:6=H=&=O;&1E;G)O9#$G(#T^(&%R<F%Y*#(U-2P@,C,V+"`Q,SDI+`H@("`@
M)VQI9VAT9V]L9&5N<F]D,B<@/3X@87)R87DH,C,X+"`R,C`L(#$S,"DL"B`@
M("`G;&EG:'1G;VQD96YR;V0S)R`]/B!A<G)A>2@R,#4L(#$Y,"P@,3$R*2P*
M("`@("=L:6=H=&=O;&1E;G)O9#0G(#T^(&%R<F%Y*#$S.2P@,3(Y+"`W-BDL
M"B`@("`G>65L;&]W,2<@/3X@87)R87DH,C4U+"`R-34L(#`I+`H@("`@)WEE
M;&QO=S(G(#T^(&%R<F%Y*#(S."P@,C,X+"`P*2P*("`@("=Y96QL;W<S)R`]
M/B!A<G)A>2@R,#4L(#(P-2P@,"DL"B`@("`G>65L;&]W-"<@/3X@87)R87DH
M,3,Y+"`Q,SDL(#`I+`H@("`@)V=O;&0Q)R`]/B!A<G)A>2@R-34L(#(Q-2P@
M,"DL"B`@("`G9V]L9#(G(#T^(&%R<F%Y*#(S."P@,C`Q+"`P*2P*("`@("=G
M;VQD,R<@/3X@87)R87DH,C`U+"`Q-S,L(#`I+`H@("`@)V=O;&0T)R`]/B!A
M<G)A>2@Q,SDL(#$Q-RP@,"DL"B`@("`G9V]L9&5N<F]D,2<@/3X@87)R87DH
M,C4U+"`Q.3,L(#,W*2P*("`@("=G;VQD96YR;V0R)R`]/B!A<G)A>2@R,S@L
M(#$X,"P@,S0I+`H@("`@)V=O;&1E;G)O9#,G(#T^(&%R<F%Y*#(P-2P@,34U
M+"`R.2DL"B`@("`G9V]L9&5N<F]D-"<@/3X@87)R87DH,3,Y+"`Q,#4L(#(P
M*2P*("`@("=D87)K9V]L9&5N<F]D,2<@/3X@87)R87DH,C4U+"`Q.#4L(#$U
M*2P*("`@("=D87)K9V]L9&5N<F]D,B<@/3X@87)R87DH,C,X+"`Q-S,L(#$T
M*2P*("`@("=D87)K9V]L9&5N<F]D,R<@/3X@87)R87DH,C`U+"`Q-#DL(#$R
M*2P*("`@("=D87)K9V]L9&5N<F]D-"<@/3X@87)R87DH,3,Y+"`Q,#$L(#@I
M+`H@("`@)W)O<WEB<F]W;C$G(#T^(&%R<F%Y*#(U-2P@,3DS+"`Q.3,I+`H@
M("`@)W)O<WEB<F]W;C(G(#T^(&%R<F%Y*#(S."P@,3@P+"`Q.#`I+`H@("`@
M)W)O<WEB<F]W;C,G(#T^(&%R<F%Y*#(P-2P@,34U+"`Q-34I+`H@("`@)W)O
M<WEB<F]W;C0G(#T^(&%R<F%Y*#$S.2P@,3`U+"`Q,#4I+`H@("`@)VEN9&EA
M;G)E9#$G(#T^(&%R<F%Y*#(U-2P@,3`V+"`Q,#8I+`H@("`@)VEN9&EA;G)E
M9#(G(#T^(&%R<F%Y*#(S."P@.3DL(#DY*2P*("`@("=I;F1I86YR960S)R`]
M/B!A<G)A>2@R,#4L(#@U+"`X-2DL"B`@("`G:6YD:6%N<F5D-"<@/3X@87)R
M87DH,3,Y+"`U."P@-3@I+`H@("`@)W-I96YN83$G(#T^(&%R<F%Y*#(U-2P@
M,3,P+"`W,2DL"B`@("`G<VEE;FYA,B<@/3X@87)R87DH,C,X+"`Q,C$L(#8V
M*2P*("`@("=S:65N;F$S)R`]/B!A<G)A>2@R,#4L(#$P-"P@-3<I+`H@("`@
M)W-I96YN830G(#T^(&%R<F%Y*#$S.2P@-S$L(#,X*2P*("`@("=B=7)L>7=O
M;V0Q)R`]/B!A<G)A>2@R-34L(#(Q,2P@,34U*2P*("`@("=B=7)L>7=O;V0R
M)R`]/B!A<G)A>2@R,S@L(#$Y-RP@,30U*2P*("`@("=B=7)L>7=O;V0S)R`]
M/B!A<G)A>2@R,#4L(#$W,"P@,3(U*2P*("`@("=B=7)L>7=O;V0T)R`]/B!A
M<G)A>2@Q,SDL(#$Q-2P@.#4I+`H@("`@)W=H96%T,2<@/3X@87)R87DH,C4U
M+"`R,S$L(#$X-BDL"B`@("`G=VAE870R)R`]/B!A<G)A>2@R,S@L(#(Q-BP@
M,3<T*2P*("`@("=W:&5A=#,G(#T^(&%R<F%Y*#(P-2P@,3@V+"`Q-3`I+`H@
M("`@)W=H96%T-"<@/3X@87)R87DH,3,Y+"`Q,C8L(#$P,BDL"B`@("`G=&%N
M,2<@/3X@87)R87DH,C4U+"`Q-C4L(#<Y*2P*("`@("=T86XR)R`]/B!A<G)A
M>2@R,S@L(#$U-"P@-S,I+`H@("`@)W1A;C,G(#T^(&%R<F%Y*#(P-2P@,3,S
M+"`V,RDL"B`@("`G=&%N-"<@/3X@87)R87DH,3,Y+"`Y,"P@-#,I+`H@("`@
M)V-H;V-O;&%T93$G(#T^(&%R<F%Y*#(U-2P@,3(W+"`S-BDL"B`@("`G8VAO
M8V]L871E,B<@/3X@87)R87DH,C,X+"`Q,3@L(#,S*2P*("`@("=C:&]C;VQA
M=&4S)R`]/B!A<G)A>2@R,#4L(#$P,BP@,CDI+`H@("`@)V-H;V-O;&%T930G
M(#T^(&%R<F%Y*#$S.2P@-CDL(#$Y*2P*("`@("=F:7)E8G)I8VLQ)R`]/B!A
M<G)A>2@R-34L(#0X+"`T."DL"B`@("`G9FER96)R:6-K,B<@/3X@87)R87DH
M,C,X+"`T-"P@-#0I+`H@("`@)V9I<F5B<FEC:S,G(#T^(&%R<F%Y*#(P-2P@
M,S@L(#,X*2P*("`@("=F:7)E8G)I8VLT)R`]/B!A<G)A>2@Q,SDL(#(V+"`R
M-BDL"B`@("`G8G)O=VXQ)R`]/B!A<G)A>2@R-34L(#8T+"`V-"DL"B`@("`G
M8G)O=VXR)R`]/B!A<G)A>2@R,S@L(#4Y+"`U.2DL"B`@("`G8G)O=VXS)R`]
M/B!A<G)A>2@R,#4L(#4Q+"`U,2DL"B`@("`G8G)O=VXT)R`]/B!A<G)A>2@Q
M,SDL(#,U+"`S-2DL"B`@("`G<V%L;6]N,2<@/3X@87)R87DH,C4U+"`Q-#`L
M(#$P-2DL"B`@("`G<V%L;6]N,B<@/3X@87)R87DH,C,X+"`Q,S`L(#DX*2P*
M("`@("=S86QM;VXS)R`]/B!A<G)A>2@R,#4L(#$Q,BP@.#0I+`H@("`@)W-A
M;&UO;C0G(#T^(&%R<F%Y*#$S.2P@-S8L(#4W*2P*("`@("=L:6=H='-A;&UO
M;C$G(#T^(&%R<F%Y*#(U-2P@,38P+"`Q,C(I+`H@("`@)VQI9VAT<V%L;6]N
M,B<@/3X@87)R87DH,C,X+"`Q-#DL(#$Q-"DL"B`@("`G;&EG:'1S86QM;VXS
M)R`]/B!A<G)A>2@R,#4L(#$R.2P@.3@I+`H@("`@)VQI9VAT<V%L;6]N-"<@
M/3X@87)R87DH,3,Y+"`X-RP@-C8I+`H@("`@)V]R86YG93$G(#T^(&%R<F%Y
M*#(U-2P@,38U+"`P*2P*("`@("=O<F%N9V4R)R`]/B!A<G)A>2@R,S@L(#$U
M-"P@,"DL"B`@("`G;W)A;F=E,R<@/3X@87)R87DH,C`U+"`Q,S,L(#`I+`H@
M("`@)V]R86YG930G(#T^(&%R<F%Y*#$S.2P@.3`L(#`I+`H@("`@)V1A<FMO
M<F%N9V4Q)R`]/B!A<G)A>2@R-34L(#$R-RP@,"DL"B`@("`G9&%R:V]R86YG
M93(G(#T^(&%R<F%Y*#(S."P@,3$X+"`P*2P*("`@("=D87)K;W)A;F=E,R<@
M/3X@87)R87DH,C`U+"`Q,#(L(#`I+`H@("`@)V1A<FMO<F%N9V4T)R`]/B!A
M<G)A>2@Q,SDL(#8Y+"`P*2P*("`@("=C;W)A;#$G(#T^(&%R<F%Y*#(U-2P@
M,3$T+"`X-BDL"B`@("`G8V]R86PR)R`]/B!A<G)A>2@R,S@L(#$P-BP@.#`I
M+`H@("`@)V-O<F%L,R<@/3X@87)R87DH,C`U+"`Y,2P@-CDI+`H@("`@)V-O
M<F%L-"<@/3X@87)R87DH,3,Y+"`V,BP@-#<I+`H@("`@)W1O;6%T;S$G(#T^
M(&%R<F%Y*#(U-2P@.3DL(#<Q*2P*("`@("=T;VUA=&\R)R`]/B!A<G)A>2@R
M,S@L(#DR+"`V-BDL"B`@("`G=&]M871O,R<@/3X@87)R87DH,C`U+"`W.2P@
M-3<I+`H@("`@)W1O;6%T;S0G(#T^(&%R<F%Y*#$S.2P@-30L(#,X*2P*("`@
M("=O<F%N9V5R960Q)R`]/B!A<G)A>2@R-34L(#8Y+"`P*2P*("`@("=O<F%N
M9V5R960R)R`]/B!A<G)A>2@R,S@L(#8T+"`P*2P*("`@("=O<F%N9V5R960S
M)R`]/B!A<G)A>2@R,#4L(#4U+"`P*2P*("`@("=O<F%N9V5R960T)R`]/B!A
M<G)A>2@Q,SDL(#,W+"`P*2P*("`@("=D965P<&EN:S$G(#T^(&%R<F%Y*#(U
M-2P@,C`L(#$T-RDL"B`@("`G9&5E<'!I;FLR)R`]/B!A<G)A>2@R,S@L(#$X
M+"`Q,S<I+`H@("`@)V1E97!P:6YK,R<@/3X@87)R87DH,C`U+"`Q-BP@,3$X
M*2P*("`@("=D965P<&EN:S0G(#T^(&%R<F%Y*#$S.2P@,3`L(#@P*2P*("`@
M("=H;W1P:6YK,2<@/3X@87)R87DH,C4U+"`Q,3`L(#$X,"DL"B`@("`G:&]T
M<&EN:S(G(#T^(&%R<F%Y*#(S."P@,3`V+"`Q-C<I+`H@("`@)VAO='!I;FLS
M)R`]/B!A<G)A>2@R,#4L(#DV+"`Q-#0I+`H@("`@)VAO='!I;FLT)R`]/B!A
M<G)A>2@Q,SDL(#4X+"`Y."DL"B`@("`G<&EN:S$G(#T^(&%R<F%Y*#(U-2P@
M,3@Q+"`Q.3<I+`H@("`@)W!I;FLR)R`]/B!A<G)A>2@R,S@L(#$V.2P@,3@T
M*2P*("`@("=P:6YK,R<@/3X@87)R87DH,C`U+"`Q-#4L(#$U."DL"B`@("`G
M<&EN:S0G(#T^(&%R<F%Y*#$S.2P@.3DL(#$P."DL"B`@("`G;&EG:'1P:6YK
M,2<@/3X@87)R87DH,C4U+"`Q-S0L(#$X-2DL"B`@("`G;&EG:'1P:6YK,B<@
M/3X@87)R87DH,C,X+"`Q-C(L(#$W,RDL"B`@("`G;&EG:'1P:6YK,R<@/3X@
M87)R87DH,C`U+"`Q-#`L(#$T.2DL"B`@("`G;&EG:'1P:6YK-"<@/3X@87)R
M87DH,3,Y+"`Y-2P@,3`Q*2P*("`@("=P86QE=FEO;&5T<F5D,2<@/3X@87)R
M87DH,C4U+"`Q,S`L(#$W,2DL"B`@("`G<&%L979I;VQE=')E9#(G(#T^(&%R
M<F%Y*#(S."P@,3(Q+"`Q-3DI+`H@("`@)W!A;&5V:6]L971R960S)R`]/B!A
M<G)A>2@R,#4L(#$P-"P@,3,W*2P*("`@("=P86QE=FEO;&5T<F5D-"<@/3X@
M87)R87DH,3,Y+"`W,2P@.3,I+`H@("`@)VUA<F]O;C$G(#T^(&%R<F%Y*#(U
M-2P@-3(L(#$W.2DL"B`@("`G;6%R;V]N,B<@/3X@87)R87DH,C,X+"`T."P@
M,38W*2P*("`@("=M87)O;VXS)R`]/B!A<G)A>2@R,#4L(#0Q+"`Q-#0I+`H@
M("`@)VUA<F]O;C0G(#T^(&%R<F%Y*#$S.2P@,C@L(#DX*2P*("`@("=V:6]L
M971R960Q)R`]/B!A<G)A>2@R-34L(#8R+"`Q-3`I+`H@("`@)W9I;VQE=')E
M9#(G(#T^(&%R<F%Y*#(S."P@-3@L(#$T,"DL"B`@("`G=FEO;&5T<F5D,R<@
M/3X@87)R87DH,C`U+"`U,"P@,3(P*2P*("`@("=V:6]L971R960T)R`]/B!A
M<G)A>2@Q,SDL(#,T+"`X,BDL"B`@("`G;6%G96YT83$G(#T^(&%R<F%Y*#(U
M-2P@,"P@,C4U*2P*("`@("=M86=E;G1A,B<@/3X@87)R87DH,C,X+"`P+"`R
M,S@I+`H@("`@)VUA9V5N=&$S)R`]/B!A<G)A>2@R,#4L(#`L(#(P-2DL"B`@
M("`G;6%G96YT830G(#T^(&%R<F%Y*#$S.2P@,"P@,3,Y*2P*("`@("=M961I
M=6UR960G(#T^(&%R<F%Y*#$T,"P@,S0L(#,T*2P*("`@("=O<F-H:60Q)R`]
M/B!A<G)A>2@R-34L(#$S,2P@,C4P*2P*("`@("=O<F-H:60R)R`]/B!A<G)A
M>2@R,S@L(#$R,BP@,C,S*2P*("`@("=O<F-H:60S)R`]/B!A<G)A>2@R,#4L
M(#$P-2P@,C`Q*2P*("`@("=O<F-H:60T)R`]/B!A<G)A>2@Q,SDL(#<Q+"`Q
M,S<I+`H@("`@)W!L=6TQ)R`]/B!A<G)A>2@R-34L(#$X-RP@,C4U*2P*("`@
M("=P;'5M,B<@/3X@87)R87DH,C,X+"`Q-S0L(#(S."DL"B`@("`G<&QU;3,G
M(#T^(&%R<F%Y*#(P-2P@,34P+"`R,#4I+`H@("`@)W!L=6TT)R`]/B!A<G)A
M>2@Q,SDL(#$P,BP@,3,Y*2P*("`@("=M961I=6UO<F-H:60Q)R`]/B!A<G)A
M>2@R,C0L(#$P,BP@,C4U*2P*("`@("=M961I=6UO<F-H:60R)R`]/B!A<G)A
M>2@R,#DL(#DU+"`R,S@I+`H@("`@)VUE9&EU;6]R8VAI9#,G(#T^(&%R<F%Y
M*#$X,"P@.#(L(#(P-2DL"B`@("`G;65D:75M;W)C:&ED-"<@/3X@87)R87DH
M,3(R+"`U-2P@,3,Y*2P*("`@("=D87)K;W)C:&ED,2<@/3X@87)R87DH,3DQ
M+"`V,BP@,C4U*2P*("`@("=D87)K;W)C:&ED,B<@/3X@87)R87DH,3<X+"`U
M."P@,C,X*2P*("`@("=D87)K;W)C:&ED,R<@/3X@87)R87DH,34T+"`U,"P@
M,C`U*2P*("`@("=D87)K;W)C:&ED-"<@/3X@87)R87DH,3`T+"`S-"P@,3,Y
M*2P*("`@("=P=7)P;&4Q)R`]/B!A<G)A>2@Q-34L(#0X+"`R-34I+`H@("`@
M)W!U<G!L93(G(#T^(&%R<F%Y*#$T-2P@-#0L(#(S."DL"B`@("`G<'5R<&QE
M,R<@/3X@87)R87DH,3(U+"`S."P@,C`U*2P*("`@("=P=7)P;&4T)R`]/B!A
M<G)A>2@X-2P@,C8L(#$S.2DL"B`@("`G;65D:75M<'5R<&QE,2<@/3X@87)R
M87DH,3<Q+"`Q,S`L(#(U-2DL"B`@("`G;65D:75M<'5R<&QE,B<@/3X@87)R
M87DH,34Y+"`Q,C$L(#(S."DL"B`@("`G;65D:75M<'5R<&QE,R<@/3X@87)R
M87DH,3,W+"`Q,#0L(#(P-2DL"B`@("`G;65D:75M<'5R<&QE-"<@/3X@87)R
M87DH.3,L(#<Q+"`Q,SDI+`H@("`@)W1H:7-T;&4Q)R`]/B!A<G)A>2@R-34L
M(#(R-2P@,C4U*2P*("`@("=T:&ES=&QE,B<@/3X@87)R87DH,C,X+"`R,3`L
M(#(S."DL"B`@("`G=&AI<W1L93,G(#T^(&%R<F%Y*#(P-2P@,3@Q+"`R,#4I
M+`H@("`@)W1H:7-T;&4T)R`]/B!A<G)A>2@Q,SDL(#$R,RP@,3,Y*2P*("`@
M("=G<F%Y,2<@/3X@87)R87DH,3`L(#$P+"`Q,"DL"B`@("`G9W)A>3(G(#T^
M(&%R<F%Y*#0P+"`T,"P@,S`I+`H@("`@)V=R87DS)R`]/B!A<G)A>2@W,"P@
M-S`L(#<P*2P*("`@("=G<F%Y-"<@/3X@87)R87DH,3`P+"`Q,#`L(#$P,"DL
M"B`@("`G9W)A>34G(#T^(&%R<F%Y*#$S,"P@,3,P+"`Q,S`I+`H@("`@)V=R
M87DV)R`]/B!A<G)A>2@Q-C`L(#$V,"P@,38P*2P*("`@("=G<F%Y-R<@/3X@
M87)R87DH,3DP+"`Q.3`L(#$Y,"DL"B`@("`G9W)A>3@G(#T^(&%R<F%Y*#(Q
M,"P@,C$P+"`R,3`I+`H@("`@)V=R87DY)R`]/B!A<G)A>2@R-#`L(#(T,"P@
M,C0P*2P*("`@("=D87)K9W)A>2<@/3X@87)R87DH,3`P+"`Q,#`L(#$P,"DL
M"B`@("`G9&%R:V)L=64G(#T^(&%R<F%Y*#`L(#`L(#$S.2DL"B`@("`G9&%R
M:V-Y86XG(#T^(&%R<F%Y*#`L(#$S.2P@,3,Y*2P*("`@("=D87)K;6%G96YT
M82<@/3X@87)R87DH,3,Y+"`P+"`Q,SDI+`H@("`@)V1A<FMR960G(#T^(&%R
M<F%Y*#$S.2P@,"P@,"DL"B`@("`G<VEL=F5R)R`]/B!A<G)A>2@Q.3(L("`Q
M.3(L("`Q.3(I+`H@("`@)V5G9W!L86YT)R`]/B!A<G)A>2@Q-#0L(#$W-BP@
M,38X*2P*("`@("=L:6=H=&=R965N)R`]/B!A<G)A>2@Q-#0L(#(S."P@,30T
M*0HI.PH`````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92]);6%G92]S=F<N<&AP````````````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`S,38P,2`Q,#4Q-30S,S<S-2`P
M,C$W,#,`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*"G)E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O
M+BXO26UA9V4N<&AP)SL*<F5Q=6ER95]O;F-E("=834PO4U9'+G!H<"<["@HO
M*BH*("H@5&AI<R!C;&%S<R!I;7!L96UE;G1S('1H92!(;W)D95]);6%G93HZ
M($%022!F;W(@4U9'+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]);6%G92])
M;6%G92]S=F<N<&AP+'8@,2XS,2XQ,"XV(#(P,#8O,#$O,#$@,C$Z,C@Z,C(@
M:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU8VL@2&%G
M96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,
M*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`
M875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@
M0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TEM86=E"B`J
M+PIC;&%S<R!(;W)D95]);6%G95]S=F<@97AT96YD<R!(;W)D95]);6%G92![
M"@H@("`@=F%R("1?<W9G.PH*("`@("\J*@H@("`@("H@0V%P86)I;&ET97,@
M;V8@=&AI<R!D<FEV97(N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)%]C87!A8FEL:71I97,@/2!A<G)A>2@G8V%N=F%S)RD[
M"@H@("`@9G5N8W1I;VX@2&]R9&5?26UA9V5?<W9G*"1P87)A;7,I"B`@("![
M"B`@("`@("`@<&%R96YT.CI(;W)D95]);6%G92@D<&%R86US*3L*("`@("`@
M("`D=&AI<RT^7W-V9R`]("9N97<@6$U,7U-61U]$;V-U;65N="AA<G)A>2@G
M=VED=&@G(#T^("1T:&ES+3Y?=VED=&@L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAE:6=H="<@/3X@)'1H
M:7,M/E]H96EG:'0I*3L*("`@('T*"B`@("!F=6YC=&EO;B!G971#;VYT96YT
M5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=I;6%G92]S=F<K>&UL)SL*
M("`@('T*"B`@("!F=6YC=&EO;B!G971,:6YK*"1U<FPL("1T:71L92`]("<G
M*0H@("`@>PH@("`@?0H*("`@(&9U;F-T:6]N(&1I<W!L87DH*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?<W9G+3YP<FEN=$5L96UE;G0H*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;B!T:&4@<F%W(&1A=&$@9F]R('1H:7,@:6UA
M9V4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!R87<@:6UA
M9V4@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@<F%W*"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/E]S=F<M/F)U9F9E<D]B:F5C="@I.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&=E=$9O;G0H)&9O;G0I"B`@("!["B`@("`@("`@
M<F5T=7)N("1F;VYT.PH@("`@?0H*("`@(&9U;F-T:6]N(%]C<F5A=&53>6UB
M;VPH)',L("1I9"D*("`@('L*("`@("`@("`D<RT^<V5T4&%R86TH)VED)RP@
M)&ED*3L*("`@("`@("`D9&5F<R`]("9N97<@6$U,7U-61U]$969S*"D["B`@
M("`@("`@)&1E9G,M/F%D9$-H:6QD*"1S*3L*("`@("`@("`D=&AI<RT^7W-V
M9RT^861D0VAI;&0H)&1E9G,I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]C<F5A
M=&5$<F]P4VAA9&]W*"1I9"`]("=D<F]P4VAA9&]W)RD*("`@('L*("`@("`@
M("`D9&5F<R`]("9N97<@6$U,7U-61U]$969S*"D["B`@("`@("`@)&9I;'1E
M<B`]("9N97<@6$U,7U-61U]&:6QT97(H87)R87DH)VED)R`]/B`D:60I*3L*
M("`@("`@("`D9FEL=&5R+3YA9&10<FEM:71I=F4H)T=A=7-S:6%N0FQU<B<L
M(&%R<F%Y*"=I;B<@/3X@)U-O=7)C94%L<&AA)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S=&1$979I
M871I;VXG(#T^(#(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G<F5S=6QT)R`]/B`G8FQU<B<I*3L*("`@
M("`@("`D9FEL=&5R+3YA9&10<FEM:71I=F4H)T]F9G-E="<L(&%R<F%Y*"=I
M;B<@/3X@)V)L=7(G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V1X)R`]/B`T+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1Y)R`]/B`T+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E<W5L
M="<@/3X@)V]F9G-E=$)L=7(G*2D["B`@("`@("`@)&UE<F=E(#T@)FYE=R!8
M34Q?4U9'7T9I;'1E<E!R:6UI=&EV92@G365R9V4G*3L*("`@("`@("`D;65R
M9V4M/F%D9$UE<F=E3F]D92@G;V9F<V5T0FQU<B<I.PH@("`@("`@("1M97)G
M92T^861D365R9V5.;V1E*"=3;W5R8V5'<F%P:&EC)RD["@H@("`@("`@("1F
M:6QT97(M/F%D9$-H:6QD*"1M97)G92D["B`@("`@("`@)&1E9G,M/F%D9$-H
M:6QD*"1F:6QT97(I.PH@("`@("`@("1T:&ES+3Y?<W9G+3YA9&1#:&EL9"@D
M9&5F<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W<R!A('1E>'0@<W1R
M:6YG(&]N('1H92!I;6%G92!I;B!A('-P96-I9FEE9"!L;V-A=&EO;BP@=VET
M:`H@("`@("H@=&AE('-P96-I9FEE9"!S='EL92!I;F9O<FUA=&EO;BX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D=&5X="`@("`@("!4:&4@=&5X
M="!T;R!D<F%W+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@@("`@("`@("`@
M5&AE(&QE9G0@>"!C;V]R9&EN871E(&]F('1H92!S=&%R="!O9B!T:&4@=&5X
M="!S=')I;F<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>2`@("`@("`@("!4
M:&4@=&]P('D@8V]O<F1I;F%T92!O9B!T:&4@<W1A<G0@;V8@=&AE('1E>'0@
M<W1R:6YG+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&9O;G0@("`@("`@5&AE
M(&9O;G0@:61E;G1I9FEE<B!Y;W4@=V%N="!T;R!U<V4@9F]R('1H92!T97AT
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&-O;&]R("`@("`@5&AE(&-O;&]R
M('1H870@>6]U('=A;G0@=&AE('1E>'0@9&ES<&QA>65D(&EN+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&1I<F5C=&EO;B`@06X@:6YT96=E<B!T:&%T('-P
M96-I9FEE<R!T:&4@;W)I96YT871I;VX@;V8@=&AE('1E>'0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('1E>'0H)'-T<FEN9RP@)'@L("1Y+"`D9F]N="`]("=M
M;VYO<W!A8V4G+"`D8V]L;W(@/2`G8FQA8VLG+"`D9&ER96-T:6]N(#T@,"D*
M("`@('L*("`@("`@("`D:&5I9VAT(#T@,3(["B`@("`@("`@)'-T>6QE(#T@
M)V9O;G0M9F%M:6QY.B<@+B`D9F]N="`N("<[9F]N="UH96EG:'0Z)R`N("1H
M96EG:'0@+B`G<'@[9FEL;#HG("X@)'1H:7,M/F=E=$AE>$-O;&]R*"1C;VQO
M<BD@+B`G.W1E>'0M86YC:&]R.G-T87)T.R<["B`@("`@("`@)'1R86YS9F]R
M;2`]("=R;W1A=&4H)R`N("1D:7)E8W1I;VX@+B`G+"<@+B`D>"`N("<L)R`N
M("1Y("X@)RDG.PH@("`@("`@("1T:&ES+3Y?<W9G+3YA9&1#:&EL9"AN97<@
M6$U,7U-61U]497AT*&%R<F%Y*"=T97AT)R`]/B`D<W1R:6YG+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=X)R`]/B`H:6YT*21X+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=Y)R`]/B`H:6YT*21Y("L@)&AE
M:6=H="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G=')A;G-F;W)M)R`]/B`D=')A;G-F;W)M+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=S='EL92<@/3X@)'-T>6QE*2DI.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1')A=R!A(&-I<F-L92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D>"`@("`@(%1H92!X(&-O;W)D:6YA=&4@;V8@=&AE(&-E;G1R92X*("`@
M("`J($!P87)A;2!I;G1E9V5R("1Y("`@("`@5&AE('D@8V]O<F1I;F%T92!O
M9B!T:&4@8V5N=')E+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'(@("`@("!4
M:&4@<F%D:75S(&]F('1H92!C:7)C;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("`D8V]L;W(@(%1H92!L:6YE(&-O;&]R(&]F('1H92!C:7)C;&4N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("`D9FEL;"`@(%1H92!C;VQO<B!T;R!F:6QL('1H
M92!C:7)C;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-I<F-L92@D>"P@)'DL
M("1R+"`D8V]L;W(L("1F:6QL(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H
M(65M<'1Y*"1F:6QL*2D@>PH@("`@("`@("`@("`D<W1Y;&4@/2`G9FEL;#HG
M("X@)'1H:7,M/F=E=$AE>$-O;&]R*"1F:6QL*2`N("<[("<["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)'-T>6QE(#T@)V9I;&PZ;F]N93LG.PH@
M("`@("`@('T*("`@("`@("`D<W1Y;&4@+CT@)W-T<F]K93HG("X@)'1H:7,M
M/F=E=$AE>$-O;&]R*"1C;VQO<BD@+B`G.R!S=')O:V4M=VED=&@Z,2<["@H@
M("`@("`@("1T:&ES+3Y?<W9G+3YA9&1#:&EL9"AN97<@6$U,7U-61U]#:7)C
M;&4H87)R87DH)V-X)R`]/B`D>"P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=C>2<@/3X@)'DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G<B<@/3X@)'(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<W1Y;&4G(#T^("1S='EL
M92DI*3L*("`@('T*"B`@("`O*BH*("`@("`J($1R87<@82!P;VQY9V]N(&)A
M<V5D(&]N(&$@<V5T(&]F('9E<G1I8V5S+@H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D=F5R=&EC97,@($%N(&%R<F%Y(&]F('@@86YD('D@;&%B96QE
M9"!A<G)A>7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("AE9RX@
M)'9E<G1I8V5S6S!=6R=X)UTL("1V97)T:6-E<ULP75LG>2==+"`N+BXI+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D8V]L;W(@("`@5&AE(&-O;&]R('EO=2!W
M86YT('1O(&1R87<@=&AE('!O;'EG;VX@=VET:"X*("`@("`J($!P87)A;2!S
M=')I;F<@)&9I;&P@("`@(%1H92!C;VQO<B!T;R!F:6QL('1H92!P;VQY9V]N
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!P;VQY9V]N*"1V97)T<RP@)&-O;&]R
M+"`D9FEL;"`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"%E;7!T>2@D9FEL
M;"DI('L*("`@("`@("`@("`@)'-T>6QE(#T@)V9I;&PZ)R`N("1T:&ES+3YG
M971(97A#;VQO<B@D9FEL;"D@+B`G.R`G.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1S='EL92`]("=F:6QL.FYO;F4[)SL*("`@("`@("!]"B`@
M("`@("`@)'-T>6QE("X]("=S=')O:V4Z)R`N("1T:&ES+3YG971(97A#;VQO
M<B@D8V]L;W(I("X@)SL@<W1R;VME+7=I9'1H.C$G.PH*("`@("`@("`D<&]I
M;G1S(#T@)R<["B`@("`@("`@9F]R96%C:"`H)'9E<G1S(&%S("1V*2!["B`@
M("`@("`@("`@("1P;VEN=',@+CT@)'9;)W@G72`N("<L)R`N("1V6R=Y)UT@
M+B`G("<["B`@("`@("`@?0H@("`@("`@("1P;VEN=',@/2!T<FEM*"1P;VEN
M=',I.PH*("`@("`@("`D=&AI<RT^7W-V9RT^861D0VAI;&0H;F5W(%A-3%]3
M5D=?4&]L>6=O;BAA<G)A>2@G<&]I;G1S)R`]/B`D<&]I;G1S+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=S='EL92<@/3X@)'-T>6QE*2DI.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1')A=R!A(')E8W1A;F=L92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D>"`@("`@("!4:&4@;&5F="!X+6-O;W)D:6YA=&4@;V8@=&AE(')E
M8W1A;F=L92X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y("`@("`@(%1H92!T
M;W`@>2UC;V]R9&EN871E(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D=VED=&@@("!4:&4@=VED=&@@;V8@=&AE(')E8W1A;F=L
M92X*("`@("`J($!P87)A;2!I;G1E9V5R("1H96EG:'0@(%1H92!H96EG:'0@
M;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!S=')I;F<@)&-O;&]R
M("`@(%1H92!L:6YE(&-O;&]R(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1F:6QL("`@("!4:&4@8V]L;W(@=&\@9FEL;"!T:&4@
M<F5C=&%N9VQE+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96-T86YG;&4H)'@L
M("1Y+"`D=VED=&@L("1H96EG:'0L("1C;VQO<BP@)&9I;&P@/2!N=6QL*0H@
M("`@>PH@("`@("`@(&EF("@A96UP='DH)&9I;&PI*2!["B`@("`@("`@("`@
M("1S='EL92`]("=F:6QL.B<@+B`D=&AI<RT^9V5T2&5X0V]L;W(H)&9I;&PI
M("X@)SL@)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<W1Y;&4@
M/2`G9FEL;#IN;VYE.R<["B`@("`@("`@?0H@("`@("`@("1S='EL92`N/2`G
M<W1R;VME.B<@+B`D=&AI<RT^9V5T2&5X0V]L;W(H)&-O;&]R*2`N("<[('-T
M<F]K92UW:61T:#HQ)SL*"B`@("`@("`@)'1H:7,M/E]S=F<M/F%D9$-H:6QD
M*&YE=R!834Q?4U9'7U)E8W0H87)R87DH)W@G(#T^("1X+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=Y
M)R`]/B`D>2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G=VED=&@G(#T^("1W:61T:"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M:&5I9VAT)R`]/B`D:&5I9VAT+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S='EL92<@/3X@)'-T>6QE
M*2DI.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A(')E8W1A;F=L92X*
M("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>"`@("`@("!4:&4@;&5F
M="!X+6-O;W)D:6YA=&4@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A
M;2!I;G1E9V5R("1Y("`@("`@(%1H92!T;W`@>2UC;V]R9&EN871E(&]F('1H
M92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D=VED=&@@("!4
M:&4@=VED=&@@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I;G1E
M9V5R("1H96EG:'0@(%1H92!H96EG:'0@;V8@=&AE(')E8W1A;F=L92X*("`@
M("`J($!P87)A;2!I;G1E9V5R("1R;W5N9"`@(%1H92!W:61T:"!O9B!T:&4@
M8V]R;F5R(')O=6YD:6YG+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&-O;&]R
M("`@5&AE(&QI;F4@8V]L;W(@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P
M87)A;2!S=')I;F<@("1F:6QL("`@(%1H92!C;VQO<B!T;R!F:6QL('1H92!R
M96-T86YG;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')O=6YD961296-T86YG
M;&4H)'@L("1Y+"`D=VED=&@L("1H96EG:'0L("1R;W5N9"P@)&-O;&]R+"`D
M9FEL;"D*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1F:6QL*2D@>PH@("`@
M("`@("`@("`D<W1Y;&4@/2`G9FEL;#HG("X@)'1H:7,M/F=E=$AE>$-O;&]R
M*"1F:6QL*2`N("<[("<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'-T>6QE(#T@)V9I;&PZ;F]N93LG.PH@("`@("`@('T*("`@("`@("`D<W1Y
M;&4@+CT@)W-T<F]K93HG("X@)'1H:7,M/F=E=$AE>$-O;&]R*"1C;VQO<BD@
M+B`G.R!S=')O:V4M=VED=&@Z,2<["@H@("`@("`@("1T:&ES+3Y?<W9G+3YA
M9&1#:&EL9"AN97<@6$U,7U-61U]296-T*&%R<F%Y*"=X)R`]/B`D>"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G>2<@/3X@)'DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W)X)R`]/B`D<F]U;F0L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W)Y)R`]/B`D<F]U;F0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W=I9'1H)R`]/B`D=VED=&@L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)VAE:6=H="<@/3X@)&AE:6=H="P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<W1Y;&4G
M(#T^("1S='EL92DI*3L*("`@('T*"B`@("`O*BH*("`@("`J($1R87<@82!L
M:6YE+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1X,"`@("`@5&AE
M('@@8V]O<F1I;F%T92!O9B!T:&4@<W1A<G0N"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D>3`@("`@(%1H92!Y(&-O;W)D:6YA=&4@;V8@=&AE('-T87)T+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)'@Q("`@("!4:&4@>"!C;V]R9&EN871E
M(&]F('1H92!E;F0N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>3$@("`@(%1H
M92!Y(&-O;W)D:6YA=&4@;V8@=&AE(&5N9"X*("`@("`J($!P87)A;2!S=')I
M;F<@)&-O;&]R("`@5&AE(&QI;F4@8V]L;W(N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1W:61T:"`@(%1H92!W:61T:"!O9B!T:&4@;&EN92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@;&EN92@D>#$L("1Y,2P@)'@R+"`D>3(L("1C;VQO<B`]
M("=B;&%C:R<L("1W:61T:"`](#$I"B`@("!["B`@("`@("`@)'-T>6QE(#T@
M)W-T<F]K93HG("X@)'1H:7,M/F=E=$AE>$-O;&]R*"1C;VQO<BD@+B`G.R!S
M=')O:V4M=VED=&@Z)R`N("AI;G0I)'=I9'1H.PH@("`@("`@("1T:&ES+3Y?
M<W9G+3YA9&1#:&EL9"AN97<@6$U,7U-61U],:6YE*&%R<F%Y*"=X,2<@/3X@
M)'@Q+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=Y,2<@/3X@)'DQ+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=X,B<@/3X@)'@R
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=Y,B<@/3X@)'DR+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S='EL92<@/3X@)'-T
M>6QE*2DI.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A(&1A<VAE9"!L
M:6YE+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1X,"`@("`@("`@
M("`@5&AE('@@8V]O<F1I;F%T92!O9B!T:&4@<W1A<G0N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D>3`@("`@("`@("`@(%1H92!Y(&-O;W)D:6YA=&4@;V8@
M=&AE('-T87)T+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@Q("`@("`@("`@
M("!4:&4@>"!C;V]R9&EN871E(&]F('1H92!E;F0N"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D>3$@("`@("`@("`@(%1H92!Y(&-O;W)D:6YA=&4@;V8@=&AE
M(&5N9"X*("`@("`J($!P87)A;2!S=')I;F<@("1C;VQO<B`@("`@("`@5&AE
M(&QI;F4@8V]L;W(N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D=VED=&@@("`@
M("`@(%1H92!W:61T:"!O9B!T:&4@;&EN92X*("`@("`J($!P87)A;2!I;G1E
M9V5R("1D87-H7VQE;F=T:"`@5&AE(&QE;F=T:"!O9B!A(&1A<V@@;VX@=&AE
M(&1A<VAE9"!L:6YE"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9&%S:%]S<&%C
M92`@(%1H92!L96YG=&@@;V8@82!S<&%C92!I;B!T:&4@9&%S:&5D(&QI;F4*
M("`@("`J+PH@("`@9G5N8W1I;VX@9&%S:&5D3&EN92@D>#$L("1Y,2P@)'@R
M+"`D>3(L("1C;VQO<B`]("=B;&%C:R<L("1W:61T:"`](#$L("1D87-H7VQE
M;F=T:"`](#(L("1D87-H7W-P86-E(#T@,BD*("`@('L*("`@("`@("`D<W1Y
M;&4@/2`G<W1R;VME.B<@+B`D=&AI<RT^9V5T2&5X0V]L;W(H)&-O;&]R*2`N
M("<[('-T<F]K92UW:61T:#HG("X@*&EN="DD=VED=&@@+B`G.R!S=')O:V4M
M9&%S:&%R<F%Y.B<@+B`D9&%S:%]L96YG=&@@+B`G+"<@+B`D9&%S:%]S<&%C
M92`N("<[)SL*("`@("`@("`D=&AI<RT^7W-V9RT^861D0VAI;&0H;F5W(%A-
M3%]35D=?3&EN92AA<G)A>2@G>#$G(#T^("1X,2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G>3$G(#T^
M("1Y,2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G>#(G(#T^("1X,BP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G>3(G(#T^("1Y
M,BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G<W1Y;&4G(#T^("1S='EL92DI*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($1R87<@82!P;VQY;&EN92`H82!N;VXM8VQO<V5D+"!N;VXM
M9FEL;&5D('!O;'EG;VXI(&)A<V5D(&]N(&$*("`@("`J('-E="!O9B!V97)T
M:6-E<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'9E<G1I8V5S("!!
M;B!A<G)A>2!O9B!X(&%N9"!Y(&QA8F5L960@87)R87ES"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`H96<N("1V97)T:6-E<ULP75LG>"==+"`D
M=F5R=&EC97-;,%U;)WDG72P@+BXN*2X*("`@("`J($!P87)A;2!S=')I;F<@
M)&-O;&]R("`@(%1H92!C;VQO<B!Y;W4@=V%N="!T;R!D<F%W('1H92!L:6YE
M('=I=&@N"B`@("`@*B!`<&%R86T@<W1R:6YG("1W:61T:"`@("!4:&4@=VED
M=&@@;V8@=&AE(&QI;F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('!O;'EL:6YE
M*"1V97)T<RP@)&-O;&]R+"`D=VED=&@@/2`Q*0H@("`@>PH@("`@("`@("1S
M='EL92`]("=S=')O:V4Z)R`N("1T:&ES+3YG971(97A#;VQO<B@D8V]L;W(I
M("X@)SL@<W1R;VME+7=I9'1H.B<@+B`D=VED=&@@+B`G.V9I;&PZ;F]N93LG
M.PH*("`@("`@("`O+R!#86QC=6QA=&4@=&AE('!A=&@@96YT<GDN"B`@("`@
M("`@)'!A=&@@/2`G)SL*"B`@("`@("`@)&9I<G-T(#T@=')U93L*("`@("`@
M("!F;W)E86-H("@D=F5R=',@87,@)'9E<G0I('L*("`@("`@("`@("`@:68@
M*"1F:7)S="D@>PH@("`@("`@("`@("`@("`@)&9I<G-T(#T@9F%L<V4["B`@
M("`@("`@("`@("`@("`D<&%T:"`N/2`G32`G("X@)'9E<G1;)W@G72`N("<L
M)R`N("1V97)T6R=Y)UT["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D<&%T:"`N/2`G($P@)R`N("1V97)T6R=X)UT@+B`G+"<@+B`D
M=F5R=%LG>2==.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D
M=&AI<RT^7W-V9RT^861D0VAI;&0H;F5W(%A-3%]35D=?4&%T:"AA<G)A>2@G
M9"<@/3X@)'!A=&@L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W-T>6QE)R`]/B`D<W1Y;&4I*2D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W(&%N(&%R8RX*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D>"`@("`@(%1H92!X(&-O;W)D:6YA=&4@;V8@
M=&AE(&-E;G1R92X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y("`@("`@5&AE
M('D@8V]O<F1I;F%T92!O9B!T:&4@8V5N=')E+@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)'(@("`@("!4:&4@<F%D:75S(&]F('1H92!A<F,N"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D<W1A<G0@(%1H92!S=&%R="!A;F=L92!O9B!T:&4@
M87)C+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&5N9"`@("!4:&4@96YD(&%N
M9VQE(&]F('1H92!A<F,N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D8V]L;W(@
M(%1H92!L:6YE(&-O;&]R(&]F('1H92!A<F,N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("`D9FEL;"`@(%1H92!F:6QL(&-O;&]R(&]F('1H92!A<F,@*&1E9F%U
M;'1S('1O(&YO;F4I+@H@("`@("HO"B`@("!F=6YC=&EO;B!A<F,H)'@L("1Y
M+"`D<BP@)'-T87)T+"`D96YD+"`D8V]L;W(@/2`G8FQA8VLG+"`D9FEL;"`]
M(&YU;&PI"B`@("!["B`@("`@("`@:68@*"%E;7!T>2@D9FEL;"DI('L*("`@
M("`@("`@("`@)'-T>6QE(#T@)V9I;&PZ)R`N("1T:&ES+3YG971(97A#;VQO
M<B@D9FEL;"D@+B`G.R`G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1S='EL92`]("=F:6QL.FYO;F4[)SL*("`@("`@("!]"B`@("`@("`@)'-T
M>6QE("X]("=S=')O:V4Z)R`N("1T:&ES+3YG971(97A#;VQO<B@D8V]L;W(I
M("X@)SL@<W1R;VME+7=I9'1H.C$G.PH*("`@("`@("`D;6ED(#T@<F]U;F0H
M*"1S=&%R="`K("1E;F0I("\@,BD["@H@("`@("`@("\O($-A;&-U;&%T92!T
M:&4@<&%T:"!E;G1R>2X*("`@("`@("`D<&%T:"`]("<G.PH*("`@("`@("`O
M+R!)9B!F:6QL960L(&1R87<@=&AE(&]U=&QI;F4N"B`@("`@("`@:68@*"%E
M;7!T>2@D9FEL;"DI('L*("`@("`@("`@("`@+R\@4W1A<G0@870@=&AE(&-E
M;G1E<B!O9B!T:&4@96QL:7!S92!T:&4@87)C(&ES(&]N+@H@("`@("`@("`@
M("`D<&%T:"`N/2`B32`D>"PD>2`B.PH*("`@("`@("`@("`@+R\@1')A=R!O
M=70@=&\@96QL:7!S92!E9&=E+@H@("`@("`@("`@("!L:7-T*"1A<F-8+"`D
M87)C62D@/2`D=&AI<RT^7V-I<F-L95!O:6YT*"1S=&%R="P@)'(@*B`R*3L*
M("`@("`@("`@("`@)'!A=&@@+CT@)TP@)R`N(')O=6YD*"1X("L@)&%R8U@I
M("X@)RPG("X*("`@("`@("`@("`@("`@(')O=6YD*"1Y("L@)&%R8UDI("X@
M)R`G.PH@("`@("`@('T*"B`@("`@("`@+R\@1')A=R!A<F-S+@H@("`@("`@
M(&QI<W0H)&%R8U@L("1A<F-9*2`]("1T:&ES+3Y?8VER8VQE4&]I;G0H)&UI
M9"P@)'(@*B`R*3L*("`@("`@("`D<&%T:"`N/2`B02`D<BPD<B`P(#`@,2`B
M("X*("`@("`@("`@("`@<F]U;F0H)'@@*R`D87)C6"D@+B`G+"<@+@H@("`@
M("`@("`@("!R;W5N9"@D>2`K("1A<F-9*2`N("<@)SL*"B`@("`@("`@;&ES
M="@D87)C6"P@)&%R8UDI(#T@)'1H:7,M/E]C:7)C;&50;VEN="@D96YD+"`D
M<B`J(#(I.PH@("`@("`@("1P871H("X](")!("1R+"1R(#`@,"`Q("(@+@H@
M("`@("`@("`@("!R;W5N9"@D>"`K("1A<F-8*2`N("<L)R`N"B`@("`@("`@
M("`@(')O=6YD*"1Y("L@)&%R8UDI("X@)R`G.PH*("`@("`@("`O+R!)9B!F
M:6QL960L(&-L;W-E('1H92!O=71L:6YE+@H@("`@("`@(&EF("@A96UP='DH
M)&9I;&PI*2!["B`@("`@("`@("`@("1P871H("X]("=:)SL*("`@("`@("!]
M"@H@("`@("`@("1P871H(#T@=')I;2@D<&%T:"D["@H@("`@("`@("1T:&ES
M+3Y?<W9G+3YA9&1#:&EL9"AN97<@6$U,7U-61U]0871H*&%R<F%Y*"=D)R`]
M/B`D<&%T:"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G<W1Y;&4G(#T^("1S='EL92DI*3L*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]);6%G92]S=V8N<&AP````
M````````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`T-#<P-"`Q,#4Q
M-30S,S<S-2`P,C$W,3,`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*"G)E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,
M15]?*2`N("<O+BXO26UA9V4N<&AP)SL*"B\J*@H@*B!4:&ES(&-L87-S(&EM
M<&QE;65N=',@=&AE($AO<F1E7TEM86=E.CH@05!)(&9O<B!35T8L('5S:6YG
M('1H92!02%`*("H@36EN9R!E>'1E;G-I;VXN"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+TEM86=E+TEM86=E+W-W9BYP:'`L=B`Q+C(T+C$P+C8@,C`P-B\P
M,2\P,2`R,3HR.#HR,B!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M
M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@
M2&]R9&5?26UA9V4*("HO"F-L87-S($AO<F1E7TEM86=E7W-W9B!E>'1E;F1S
M($AO<F1E7TEM86=E('L*"B`@("`O*BH*("`@("`J($-A<&%B:6QI=&5S(&]F
M('1H:7,@9')I=F5R+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1?8V%P86)I;&ET:65S(#T@87)R87DH)V-A;G9A<R<I.PH*
M("`@("\J*@H@("`@("H@4U=&(')O;W0@;6]V:64N"B`@("`@*@H@("`@("H@
M0'9A<B!R97-O=7)C90H@("`@("HO"B`@("!V87(@)%]M;W9I93L*"B`@("!F
M=6YC=&EO;B!(;W)D95]);6%G95]S=V8H)'!A<F%M<RD*("`@('L*("`@("`@
M("!P87)E;G0Z.DAO<F1E7TEM86=E*"1P87)A;7,I.PH*("`@("`@("`D=&AI
M<RT^7VUO=FEE(#T@)FYE=R!35T9-;W9I92@I.PH@("`@("`@("1T:&ES+3Y?
M;6]V:64M/G-E=$1I;65N<VEO;B@D=&AI<RT^7W=I9'1H+"`D=&AI<RT^7VAE
M:6=H="D["@H@("`@("`@("\O($9)6$U%.B!H;VYO<B!T:&4@)V)A8VMG<F]U
M;F0G('!A<F%M971E<B!H97)E+@H@("`@("`@("1T:&ES+3Y?;6]V:64M/G-E
M=$)A8VMG<F]U;F0H,'AF9BP@,'AF9BP@,'AF9BD["B`@("`@("`@)'1H:7,M
M/E]M;W9I92T^<V5T4F%T92@S,"D["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T
M0V]N=&5N=%1Y<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G87!P;&EC871I
M;VXO>"US:&]C:W=A=F4M9FQA<V@G.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1&ES<&QA>2!T:&4@;6]V:64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1I<W!L
M87DH*0H@("`@>PH@("`@("`@("1T:&ES+3YH96%D97)S*"D["B`@("`@("`@
M)'1H:7,M/E]M;W9I92T^;W5T<'5T*"D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FX@=&AE(')A=R!D871A(&9O<B!T:&ES(&EM86=E+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F%W(&EM86=E(&1A=&$N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')A=R@I"B`@("!["B`@("`@("`@;V)?<W1A
M<G0H*3L*("`@("`@("`D=&AI<RT^7VUO=FEE+3YO=71P=70H*3L*("`@("`@
M("`D9&%T82`](&]B7V=E=%]C;VYT96YT<R@I.PH@("`@("`@(&]B7V5N9%]C
M;&5A;B@I.PH*("`@("`@("!R971U<FX@)&1A=&$["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#<F5A=&5S(&$@8V]L;W(@=&AA="!C86X@8F4@86-C97-S960@
M:6X@=&AI<R!O8FIE8W0N(%=H96X@80H@("`@("H@8V]L;W(@:7,@<V5T+"!T
M:&4@<F=B82!V86QU97,@87)E(')E='5R;F5D(&EN(&%N(&%R<F%Y+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!N86UE(&]F('1H
M92!C;VQO<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@<F5D
M+"!G<F5E;BP@8FQU92P@86QP:&$@=F%L=65S(&]F('1H92!C;VQO<BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@86QL;V-A=&5#;VQO<B@D;F%M92D*("`@('L*
M("`@("`@("!L:7-T*"1R+"`D9RP@)&(I(#T@)'1H:7,M/F=E=%)'0B@D;F%M
M92D["B`@("`@("`@<F5T=7)N(&%R<F%Y*"=R960G(#T^("1R+`H@("`@("`@
M("`@("`@("`@("`@("`G9W)E96XG(#T^("1G+`H@("`@("`@("`@("`@("`@
M("`@("`G8FQU92<@/3X@)&(L"B`@("`@("`@("`@("`@("`@("`@("=A;'!H
M82<@/3X@,C4U*3L*("`@('T*"B`@("!F=6YC=&EO;B!G971&;VYT*"1F;VYT
M*0H@("`@>PH@("`@("`@('-W:71C:"`H)&9O;G0I('L*("`@("`@("!C87-E
M("=S86YS+7-E<FEF)SH*("`@("`@("`@("`@<F5T=7)N("=?<V%N<R<["@H@
M("`@("`@(&-A<V4@)W-E<FEF)SH*("`@("`@("`@("`@<F5T=7)N("=?<V5R
M:68G.PH*("`@("`@("!C87-E("=M;VYO<W!A8V4G.@H@("`@("`@("`@("!R
M971U<FX@)U]T>7!E=W)I=&5R)SL*"B`@("`@("`@9&5F875L=#H*("`@("`@
M("`@("`@<F5T=7)N("1F;VYT.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($1R87=S(&$@=&5X="!S=')I;F<@;VX@=&AE(&EM86=E(&EN(&$@
M<W!E8VEF:65D(&QO8V%T:6]N+"!W:71H"B`@("`@*B!T:&4@<W!E8VEF:65D
M('-T>6QE(&EN9F]R;6%T:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@("1T97AT("`@("`@(%1H92!T97AT('1O(&1R87<N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D>"`@("`@("`@("!4:&4@;&5F="!X(&-O;W)D:6YA=&4@
M;V8@=&AE('-T87)T(&]F('1H92!T97AT('-T<FEN9RX*("`@("`J($!P87)A
M;2!I;G1E9V5R("1Y("`@("`@("`@(%1H92!T;W`@>2!C;V]R9&EN871E(&]F
M('1H92!S=&%R="!O9B!T:&4@=&5X="!S=')I;F<N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("`D9F]N="`@("`@("!4:&4@9F]N="!I9&5N=&EF:65R('EO=2!W
M86YT('1O('5S92!F;W(@=&AE('1E>'0N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("`D8V]L;W(@("`@("!4:&4@8V]L;W(@=&AA="!Y;W4@=V%N="!T:&4@=&5X
M="!D:7-P;&%Y960@:6XN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9&ER96-T
M:6]N("!!;B!I;G1E9V5R('1H870@<W!E8VEF:65S('1H92!O<FEE;G1A=&EO
M;B!O9B!T:&4@=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@=&5X="@D<W1R
M:6YG+"`D>"P@)'DL("1F;VYT(#T@)VUO;F]S<&%C92<L("1C;VQO<B`]("=B
M;&%C:R<L("1D:7)E8W1I;VX@/2`P*0H@("`@>PH@("`@("`@("1C;VQO<B`]
M("1T:&ES+3YA;&QO8V%T94-O;&]R*"1C;VQO<BD["@H@("`@("`@(&EF("AS
M=6)S='(H4$A07T]3+"`P+"`S*2`]/2`G5TE.)RD@>PH@("`@("`@("`@("`D
M=&5X="`]("9N97<@4U=&5&5X=$9I96QD*%-71E1%6%1&245,1%].3T5$250I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T97AT(#T@)FYE=R!3
M5T9497AT*"D["B`@("`@("`@?0H@("`@("`@("1T97AT+3YS971#;VQO<B@D
M8V]L;W);)W)E9"==+"`D8V]L;W);)V=R965N)UTL("1C;VQO<ELG8FQU92==
M+"`D8V]L;W);)V%L<&AA)UTI.PH@("`@("`@("1T97AT+3YA9&13=')I;F<H
M)'-T<FEN9RD["B`@("`@("`@)'1E>'0M/G-E=$9O;G0H;F5W(%-71D9O;G0H
M)'1H:7,M/F=E=$9O;G0H)&9O;G0I*2D["@H@("`@("`@("1T(#T@)'1H:7,M
M/E]M;W9I92T^861D*"1T97AT*3L*("`@("`@("`D="T^;6]V951O*"1X+"`D
M>2D["B`@("`@("`@)'0M/G)O=&%T92@D9&ER96-T:6]N*3L*"B`@("`@("`@
M<F5T=7)N("1T.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A(&-I<F-L
M92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>"`@("`@(%1H92!X
M(&-O+6]R9&EN871E(&]F('1H92!C96YT<F4N"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D>2`@("`@(%1H92!Y(&-O+6]R9&EN871E(&]F('1H92!C96YT<F4N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<B`@("`@(%1H92!R861I=7,@;V8@
M=&AE(&-I<F-L92X*("`@("`J($!P87)A;2!S=')I;F<@("1C;VQO<B`@5&AE
M(&QI;F4@8V]L;W(@;V8@=&AE(&-I<F-L92X*("`@("`J($!P87)A;2!S=')I
M;F<@("1F:6QL("`@5&AE(&-O;&]R('1O(&9I;&P@=&AE(&-I<F-L92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@8VER8VQE*"1X+"`D>2P@)'(L("1C;VQO<BP@
M)&9I;&P@/2`G;F]N92<I"B`@("!["B`@("`@("`@)',@/2`F;F5W(%-71E-H
M87!E*"D["B`@("`@("`@)&-O;&]R(#T@)'1H:7,M/F%L;&]C871E0V]L;W(H
M)&-O;&]R*3L*("`@("`@("`D<RT^<V5T3&EN92@Q+"`D8V]L;W);)W)E9"==
M+"`D8V]L;W);)V=R965N)UTL("1C;VQO<ELG8FQU92==+"`D8V]L;W);)V%L
M<&AA)UTI.PH*("`@("`@("!I9B`H)&9I;&P@(3T@)VYO;F4G*2!["B`@("`@
M("`@("`@("1F:6QL0V]L;W(@/2`D=&AI<RT^86QL;V-A=&5#;VQO<B@D9FEL
M;"D["B`@("`@("`@("`@("1F(#T@)',M/F%D9$9I;&PH)&9I;&Q#;VQO<ELG
M<F5D)UTL("1F:6QL0V]L;W);)V=R965N)UTL("1F:6QL0V]L;W);)V)L=64G
M72P@)&9I;&Q#;VQO<ELG86QP:&$G72D["B`@("`@("`@("`@("1S+3YS9712
M:6=H=$9I;&PH)&8I.PH@("`@("`@('T*"B`@("`@("`@)&$@/2`D<B`J(#`N
M-#$T,C$S-38R.R`O+R`]('1A;B@R,BXU(&1E9RD*("`@("`@("`D8B`]("1R
M("H@,"XW,#<Q,#8W.#$[("\O(#T@<W%R="@R*2\R(#T@<VEN*#0U(&1E9RD*
M"B`@("`@("`@)',M/FUO=F5096Y4;R@D>"`K("1R+"`D>2D["@H@("`@("`@
M("1S+3YD<F%W0W5R=F54;R@D>"`K("1R+"`D>2`M("1A+"`D>"`K("1B+"`D
M>2`M("1B*3L*("`@("`@("`D<RT^9')A=T-U<G9E5&\H)'@@*R`D82P@)'D@
M+2`D<BP@)'@L("1Y("T@)'(I.PH@("`@("`@("1S+3YD<F%W0W5R=F54;R@D
M>"`M("1A+"`D>2`M("1R+"`D>"`M("1B+"`D>2`M("1B*3L*("`@("`@("`D
M<RT^9')A=T-U<G9E5&\H)'@@+2`D<BP@)'D@+2`D82P@)'@@+2`D<BP@)'DI
M.PH@("`@("`@("1S+3YD<F%W0W5R=F54;R@D>"`M("1R+"`D>2`K("1A+"`D
M>"`M("1B+"`D>2`K("1B*3L*("`@("`@("`D<RT^9')A=T-U<G9E5&\H)'@@
M+2`D82P@)'D@*R`D<BP@)'@L("1Y("L@)'(I.PH@("`@("`@("1S+3YD<F%W
M0W5R=F54;R@D>"`K("1A+"`D>2`K("1R+"`D>"`K("1B+"`D>2`K("1B*3L*
M("`@("`@("`D<RT^9')A=T-U<G9E5&\H)'@@*R`D<BP@)'D@*R`D82P@)'@@
M*R`D<BP@)'DI.PH*("`@("`@("!R971U<FX@)'1H:7,M/E]M;W9I92T^861D
M*"1S*3L*("`@('T*"B`@("`O*BH*("`@("`J($1R87<@82!P;VQY9V]N(&)A
M<V5D(&]N(&$@<V5T(&]F('9E<G1I8V5S+@H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D=F5R=&EC97,@($%N(&%R<F%Y(&]F('@@86YD('D@;&%B96QE
M9"!A<G)A>7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("AE9RX@
M)'9E<G1I8V5S6S!=6R=X)UTL("1V97)T:6-E<ULP75LG>2==+"`N+BXI+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D8V]L;W(@("`@5&AE(&-O;&]R('EO=2!W
M86YT('1O(&1R87<@=&AE('!O;'EG;VX@=VET:"X*("`@("`J($!P87)A;2!S
M=')I;F<@)&9I;&P@("`@(%1H92!C;VQO<B!T;R!F:6QL('1H92!P;VQY9V]N
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!P;VQY9V]N*"1V97)T<RP@)&-O;&]R
M+"`D9FEL;"`]("=N;VYE)RD*("`@('L*("`@("`@("`D8V]L;W(@/2`D=&AI
M<RT^86QL;V-A=&5#;VQO<B@D8V]L;W(I.PH*("`@("`@("!I9B`H:7-?87)R
M87DH)&-O;&]R*2`F)B!I<U]A<G)A>2@D=F5R=',I("8F("AS:7IE;V8H)'9E
M<G1S*2`^(#(I*2!["B`@("`@("`@("`@("1S:&%P92`]("9N97<@4U=&4VAA
M<&4H*3L*("`@("`@("`@("`@)'-H87!E+3YS971,:6YE*#$L("1C;VQO<ELG
M<F5D)UTL("1C;VQO<ELG9W)E96XG72P@)&-O;&]R6R=B;'5E)UTL("1C;VQO
M<ELG86QP:&$G72D["@H@("`@("`@("`@("!I9B`H)&9I;&P@(3T@)VYO;F4G
M*2!["B`@("`@("`@("`@("`@("`D9FEL;$-O;&]R(#T@)'1H:7,M/F%L;&]C
M871E0V]L;W(H)&9I;&PI.PH@("`@("`@("`@("`@("`@)&8@/2`D<VAA<&4M
M/F%D9$9I;&PH)&9I;&Q#;VQO<ELG<F5D)UTL("1F:6QL0V]L;W);)V=R965N
M)UTL("1F:6QL0V]L;W);)V)L=64G72P@)&9I;&Q#;VQO<ELG86QP:&$G72D[
M"B`@("`@("`@("`@("`@("`D<VAA<&4M/G-E=%)I9VAT1FEL;"@D9BD["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1F:7)S=%]D;VYE(#T@9F%L<V4[
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1V97)T<R!A<R`D=F%L=64I('L*("`@
M("`@("`@("`@("`@(&EF("@A)&9I<G-T7V1O;F4I('L*("`@("`@("`@("`@
M("`@("`@("`D<VAA<&4M/FUO=F5096Y4;R@D=F%L=65;)W@G72P@)'9A;'5E
M6R=Y)UTI.PH@("`@("`@("`@("`@("`@("`@("1F:7)S=%]D;VYE(#T@=')U
M93L*("`@("`@("`@("`@("`@("`@("`D9FER<W1?>"`]("1V86QU95LG>"==
M.PH@("`@("`@("`@("`@("`@("`@("1F:7)S=%]Y(#T@)'9A;'5E6R=Y)UT[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<VAA<&4M/F1R
M87=,:6YE5&\H)'9A;'5E6R=X)UTL("1V86QU95LG>2==*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D<VAA<&4M/F1R87=,:6YE5&\H)&9I<G-T7W@L
M("1F:7)S=%]Y*3L*"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VUO=FEE
M+3YA9&0H)'-H87!E*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O
M+R!)9B!T:&4@8V]L;W(@:7,@86X@87)R87D@86YD('1H92!V97)T:6-E<R!I
M<R!A(&%N(&%R<F%Y"B`@("`@("`@("`@("\O(&]F(&UO<F4@=&AA;B`R('!O
M:6YT<RX*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($1R87<@82!R96-T86YG;&4N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)'@@("`@("`@5&AE(&QE9G0@>"UC;V]R
M9&EN871E(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D>2`@("`@("!4:&4@=&]P('DM8V]O<F1I;F%T92!O9B!T:&4@<F5C=&%N
M9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'=I9'1H("`@5&AE('=I9'1H
M(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:&5I
M9VAT("!4:&4@:&5I9VAT(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("`D8V]L;W(@("!4:&4@;&EN92!C;VQO<B!O9B!T:&4@<F5C
M=&%N9VQE+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&9I;&P@("`@5&AE(&-O
M;&]R('1O(&9I;&P@=&AE(')E8W1A;F=L92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F5C=&%N9VQE*"1X+"`D>2P@)'=I9'1H+"`D:&5I9VAT+"`D8V]L;W(L
M("1F:6QL(#T@)VYO;F4G*0H@("`@>PH@("`@("`@("1V97)T<ULP72`](&%R
M<F%Y*"=X)R`]/B`D>"P@)WDG(#T^("1Y*3L*("`@("`@("`D=F5R='-;,5T@
M/2!A<G)A>2@G>"<@/3X@)'@@*R`D=VED=&@L("=Y)R`]/B`D>2D["B`@("`@
M("`@)'9E<G1S6S)=(#T@87)R87DH)W@G(#T^("1X("L@)'=I9'1H+"`G>2<@
M/3X@)'D@*R`D:&5I9VAT*3L*("`@("`@("`D=F5R='-;,UT@/2!A<G)A>2@G
M>"<@/3X@)'@L("=Y)R`]/B`D>2`K("1H96EG:'0I.PH*("`@("`@("!R971U
M<FX@)'1H:7,M/G!O;'EG;VXH)'9E<G1S+"`D8V]L;W(L("1F:6QL*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($1R87<@82!R96-T86YG;&4N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)'@@("`@("`@5&AE(&QE9G0@>"UC;V]R
M9&EN871E(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D>2`@("`@("!4:&4@=&]P('DM8V]O<F1I;F%T92!O9B!T:&4@<F5C=&%N
M9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'=I9'1H("`@5&AE('=I9'1H
M(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:&5I
M9VAT("!4:&4@:&5I9VAT(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D<F]U;F0@("!4:&4@=VED=&@@;V8@=&AE(&-O<FYE<B!R
M;W5N9&EN9RX*("`@("`J($!P87)A;2!S=')I;F<@)&-O;&]R("`@(%1H92!L
M:6YE(&-O;&]R(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1F:6QL("`@("!4:&4@8V]L;W(@=&\@9FEL;"!T:&4@<F5C=&%N9VQE
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!R;W5N9&5D4F5C=&%N9VQE*"1X+"`D
M>2P@)'=I9'1H+"`D:&5I9VAT+"`D<F]U;F0L("1C;VQO<B`]("=B;&%C:R<L
M("1F:6QL(#T@)VYO;F4G*0H@("`@>PH@("`@("`@(&EF("@D<F]U;F0@/#T@
M,"D@>PH@("`@("`@("`@("`O+R!/<'1I;6EZ92!O=70@86YY(&-A;&QS('=I
M=&@@;F\@8V]R;F5R(')O=6YD:6YG+@H@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)E8W1A;F=L92@D>"P@)'DL("1W:61T:"P@)&AE:6=H="P@)&-O;&]R
M+"`D9FEL;"D["B`@("`@("`@?0H*("`@("`@("`D<R`]("9N97<@4U=&4VAA
M<&4H*3L*("`@("`@("`D8V]L;W(@/2`D=&AI<RT^86QL;V-A=&5#;VQO<B@D
M8V]L;W(I.PH@("`@("`@("1S+3YS971,:6YE*#$L("1C;VQO<ELG<F5D)UTL
M("1C;VQO<ELG9W)E96XG72P@)&-O;&]R6R=B;'5E)UTL("1C;VQO<ELG86QP
M:&$G72D["@H@("`@("`@(&EF("@D9FEL;"`A/2`G;F]N92<I('L*("`@("`@
M("`@("`@)&9I;&Q#;VQO<B`]("1T:&ES+3YA;&QO8V%T94-O;&]R*"1F:6QL
M*3L*("`@("`@("`@("`@)&8@/2`D<RT^861D1FEL;"@D9FEL;$-O;&]R6R=R
M960G72P@)&9I;&Q#;VQO<ELG9W)E96XG72P@)&9I;&Q#;VQO<ELG8FQU92==
M+"`D9FEL;$-O;&]R6R=A;'!H82==*3L*("`@("`@("`@("`@)',M/G-E=%)I
M9VAT1FEL;"@D9BD["B`@("`@("`@?0H*("`@("`@("`O+R!3970@8V]R;F5R
M('!O:6YT<R!T;R!A=F]I9"!L;W1S(&]F(')E9'5N9&%N="!M871H+@H@("`@
M("`@("1X,2`]("1X("L@)')O=6YD.PH@("`@("`@("1Y,2`]("1Y("L@)')O
M=6YD.PH*("`@("`@("`D>#(@/2`D>"`K("1W:61T:"`M("1R;W5N9#L*("`@
M("`@("`D>3(@/2`D>2`K("1R;W5N9#L*"B`@("`@("`@)'@S(#T@)'@@*R`D
M=VED=&@@+2`D<F]U;F0["B`@("`@("`@)'DS(#T@)'D@*R`D:&5I9VAT("T@
M)')O=6YD.PH*("`@("`@("`D>#0@/2`D>"`K("1R;W5N9#L*("`@("`@("`D
M>30@/2`D>2`K("1H96EG:'0@+2`D<F]U;F0["@H@("`@("`@("\O(%-T87)T
M(&EN('1H92!U<'!E<B!L969T+@H@("`@("`@("1P,2`]("1T:&ES+3Y?87)C
M4&]I;G1S*"1R;W5N9"P@,3@P+"`R,C4I.PH@("`@("`@("1P,B`]("1T:&ES
M+3Y?87)C4&]I;G1S*"1R;W5N9"P@,C(U+"`R-S`I.PH*("`@("`@("`O+R!3
M=&%R="!A="!T:&4@;&]W97(@;&5F="!C;W)N97(@;V8@=&AE('1O<"!L969T
M(&-U<G9E+@H@("`@("`@("1S+3YM;W9E4&5N5&\H)'@Q("L@)'`Q6R=X,2==
M+"`D>3$@*R`D<#%;)WDQ)UTI.PH*("`@("`@("`O+R!$<F%W('1H92!U<'!E
M<B!L969T(&-O<FYE<BX*("`@("`@("`D<RT^9')A=T-U<G9E5&\H)'@Q("L@
M)'`Q6R=X,R==+"`D>3$@*R`D<#%;)WDS)UTL("1X,2`K("1P,5LG>#(G72P@
M)'DQ("L@)'`Q6R=Y,B==*3L*("`@("`@("`D<RT^9')A=T-U<G9E5&\H)'@Q
M("L@)'`R6R=X,R==+"`D>3$@*R`D<#);)WDS)UTL("1X,2`K("1P,ELG>#(G
M72P@)'DQ("L@)'`R6R=Y,B==*3L*"B`@("`@("`@+R\@0V%L8W5L871E('1H
M92!U<'!E<B!R:6=H="!P;VEN=',N"B`@("`@("`@)'`S(#T@)'1H:7,M/E]A
M<F-0;VEN=',H)')O=6YD+"`R-S`L(#,Q-2D["B`@("`@("`@)'`T(#T@)'1H
M:7,M/E]A<F-0;VEN=',H)')O=6YD+"`S,34L(#,V,"D["@H@("`@("`@("\O
M($-O;FYE8W0@=&AE('1O<"!L969T(&%N9"!R:6=H="!C=7)V97,N"B`@("`@
M("`@)',M/F1R87=,:6YE5&\H)'@R("L@)'`S6R=X,2==+"`D>3(@*R`D<#-;
M)WDQ)UTI.PH*("`@("`@("`O+R!$<F%W('1H92!U<'!E<B!R:6=H="!C;W)N
M97(N"B`@("`@("`@)',M/F1R87=#=7)V951O*"1X,B`K("1P,ULG>#,G72P@
M)'DR("L@)'`S6R=Y,R==+"`D>#(@*R`D<#-;)W@R)UTL("1Y,B`K("1P,ULG
M>3(G72D["B`@("`@("`@)',M/F1R87=#=7)V951O*"1X,B`K("1P-%LG>#,G
M72P@)'DR("L@)'`T6R=Y,R==+"`D>#(@*R`D<#1;)W@R)UTL("1Y,B`K("1P
M-%LG>3(G72D["@H@("`@("`@("\O($-A;&-U;&%T92!T:&4@;&]W97(@<FEG
M:'0@<&]I;G1S+@H@("`@("`@("1P-2`]("1T:&ES+3Y?87)C4&]I;G1S*"1R
M;W5N9"P@,"P@-#4I.PH@("`@("`@("1P-B`]("1T:&ES+3Y?87)C4&]I;G1S
M*"1R;W5N9"P@-#4L(#DP*3L*"B`@("`@("`@+R\@0V]N;F5C="!T:&4@=&]P
M(')I9VAT(&%N9"!L;W=E<B!R:6=H="!C=7)V97,N"B`@("`@("`@)',M/F1R
M87=,:6YE5&\H)'@S("L@)'`U6R=X,2==+"`D>3,@*R`D<#5;)WDQ)UTI.PH*
M("`@("`@("`O+R!$<F%W('1H92!L;W=E<B!R:6=H="!C;W)N97(N"B`@("`@
M("`@)',M/F1R87=#=7)V951O*"1X,R`K("1P-5LG>#,G72P@)'DS("L@)'`U
M6R=Y,R==+"`D>#,@*R`D<#5;)W@R)UTL("1Y,R`K("1P-5LG>3(G72D["B`@
M("`@("`@)',M/F1R87=#=7)V951O*"1X,R`K("1P-ELG>#,G72P@)'DS("L@
M)'`V6R=Y,R==+"`D>#,@*R`D<#9;)W@R)UTL("1Y,R`K("1P-ELG>3(G72D[
M"@H@("`@("`@("\O($-A;&-U;&%T92!T:&4@;&]W97(@;&5F="!P;VEN=',N
M"B`@("`@("`@)'`W(#T@)'1H:7,M/E]A<F-0;VEN=',H)')O=6YD+"`Y,"P@
M,3,U*3L*("`@("`@("`D<#@@/2`D=&AI<RT^7V%R8U!O:6YT<R@D<F]U;F0L
M(#$S-2P@,3@P*3L*"B`@("`@("`@+R\@0V]N;F5C="!T:&4@8F]T=&]M(')I
M9VAT(&%N9"!B;W1T;VT@;&5F="!C=7)V97,N"B`@("`@("`@)',M/F1R87=,
M:6YE5&\H)'@T("L@)'`W6R=X,2==+"`D>30@*R`D<#=;)WDQ)UTI.PH*("`@
M("`@("`O+R!$<F%W('1H92!L;W=E<B!L969T(&-O<FYE<BX*("`@("`@("`D
M<RT^9')A=T-U<G9E5&\H)'@T("L@)'`W6R=X,R==+"`D>30@*R`D<#=;)WDS
M)UTL("1X-"`K("1P-ULG>#(G72P@)'DT("L@)'`W6R=Y,B==*3L*("`@("`@
M("`D<RT^9')A=T-U<G9E5&\H)'@T("L@)'`X6R=X,R==+"`D>30@*R`D<#A;
M)WDS)UTL("1X-"`K("1P.%LG>#(G72P@)'DT("L@)'`X6R=Y,B==*3L*"B`@
M("`@("`@+R\@0VQO<V4@=&AE('-H87!E+@H@("`@("`@("1S+3YD<F%W3&EN
M951O*"1X,2`K("1P,5LG>#$G72P@)'DQ("L@)'`Q6R=Y,2==*3L*"B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?;6]V:64M/F%D9"@D<RD["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!$<F%W(&$@;&EN92X*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D>#`@("`@(%1H92!X(&-O+6]R9&EN871E(&]F('1H92!S=&%R
M="X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y,"`@("`@5&AE('D@8V\M;W)D
M:6YA=&4@;V8@=&AE('-T87)T+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@Q
M("`@("!4:&4@>"!C;RUO<F1I;F%T92!O9B!T:&4@96YD+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)'DQ("`@("!4:&4@>2!C;RUO<F1I;F%T92!O9B!T:&4@
M96YD+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&-O;&]R("!4:&4@;&EN92!C
M;VQO<BX*("`@("`J($!P87)A;2!S=')I;F<@("1W:61T:"`@5&AE('=I9'1H
M(&]F('1H92!L:6YE+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:6YE*"1X,2P@
M)'DQ+"`D>#(L("1Y,BP@)&-O;&]R(#T@)V)L86-K)RP@)'=I9'1H(#T@,2D*
M("`@('L*("`@("`@("`D8V]L;W(@/2`D=&AI<RT^86QL;V-A=&5#;VQO<B@D
M8V]L;W(I.PH*("`@("`@("!I9B`H:7-?87)R87DH)&-O;&]R*2D@>PH@("`@
M("`@("`@("`D<VAA<&4@/2`F;F5W(%-71E-H87!E*"D["B`@("`@("`@("`@
M("1S:&%P92T^<V5T3&EN92@D=VED=&@L("1C;VQO<ELG<F5D)UTL("1C;VQO
M<ELG9W)E96XG72P@)&-O;&]R6R=B;'5E)UTL("1C;VQO<ELG86QP:&$G72D[
M"B`@("`@("`@("`@("1S:&%P92T^;6]V95!E;E1O*"1X,2P@)'DQ*3L*("`@
M("`@("`@("`@)'-H87!E+3YD<F%W3&EN951O*"1X,BP@)'DR*3L*"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7VUO=FEE+3YA9&0H)'-H87!E*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A(&1A<VAE9"!L:6YE
M+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1X,"`@("`@("`@("`@
M5&AE('@@8V\M;W)D:6YA=&4@;V8@=&AE('-T87)T+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)'DP("`@("`@("`@("!4:&4@>2!C;RUO<F1I;F%T92!O9B!T
M:&4@<W1A<G0N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>#$@("`@("`@("`@
M(%1H92!X(&-O+6]R9&EN871E(&]F('1H92!E;F0N"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D>3$@("`@("`@("`@(%1H92!Y(&-O+6]R9&EN871E(&]F('1H
M92!E;F0N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D8V]L;W(@("`@("`@(%1H
M92!L:6YE(&-O;&]R+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'=I9'1H("`@
M("`@("!4:&4@=VED=&@@;V8@=&AE(&QI;F4N"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D9&%S:%]L96YG=&@@(%1H92!L96YG=&@@;V8@82!D87-H(&]N('1H
M92!D87-H960@;&EN90H@("`@("H@0'!A<F%M(&EN=&5G97(@)&1A<VA?<W!A
M8V4@("!4:&4@;&5N9W1H(&]F(&$@<W!A8V4@:6X@=&AE(&1A<VAE9"!L:6YE
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&1A<VAE9$QI;F4H)'@P+"`D>3`L("1X
M,2P@)'DQ+"`D8V]L;W(@/2`G8FQA8VLG+"`D=VED=&@@/2`Q+"`D9&%S:%]L
M96YG=&@@/2`R+"`D9&%S:%]S<&%C92`](#(I"B`@("!["B`@("`@("`@+R\@
M1V5T('1H92!L96YG=&@@;V8@=&AE(&QI;F4@:6X@<&EX96QS+@H@("`@("`@
M("1L:6YE7VQE;F=T:"`](&UA>"AC96EL*'-Q<G0H<&]W*"@D>#$@+2`D>#`I
M+"`R*2`K('!O=R@H)'DQ("T@)'DP*2P@,BDI*2P@,BD["@H@("`@("`@("1C
M;W-4:&5T82`]("@D>#$@+2`D>#`I("\@)&QI;F5?;&5N9W1H.PH@("`@("`@
M("1S:6Y4:&5T82`]("@D>3$@+2`D>3`I("\@)&QI;F5?;&5N9W1H.PH@("`@
M("`@("1L87-T>"`]("1X,#L*("`@("`@("`D;&%S='D@/2`D>3`["@H@("`@
M("`@("\O($1R87<@=&AE(&1A<VAE9"!L:6YE+@H@("`@("`@(&9O<B`H)&D@
M/2`P.R`D:2`\("1L:6YE7VQE;F=T:#L@)&D@*ST@*"1D87-H7VQE;F=T:"`K
M("1D87-H7W-P86-E*2D@>PH@("`@("`@("`@("`D>"`]("@D9&%S:%]L96YG
M=&@@*B`D8V]S5&AE=&$I("L@)&QA<W1X.PH@("`@("`@("`@("`D>2`]("@D
M9&%S:%]L96YG=&@@*B`D<VEN5&AE=&$I("L@)&QA<W1Y.PH*("`@("`@("`@
M("`@)'1H:7,M/FQI;F4H)&QA<W1X+"`D;&%S='DL("1X+"`D>2P@)&-O;&]R
M*3L*"B`@("`@("`@("`@("1L87-T>"`]("1X("L@*"1D87-H7W-P86-E("H@
M)&-O<U1H971A*3L*("`@("`@("`@("`@)&QA<W1Y(#T@)'D@*R`H)&1A<VA?
M<W!A8V4@*B`D<VEN5&AE=&$I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($1R87<@82!P;VQY;&EN92`H82!N;VXM8VQO<V5D+"!N;VXM9FEL
M;&5D('!O;'EG;VXI(&)A<V5D(&]N(&$*("`@("`J('-E="!O9B!V97)T:6-E
M<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@("`D=F5R=&EC97,@($%N
M(&%R<F%Y(&]F('@@86YD('D@;&%B96QE9"!A<G)A>7,*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@*&5G+B`D=F5R=&EC97-;,%U;)W@G72P@
M)'9E<G1I8V5S6S!=6R=Y)UTL("XN+BDN"B`@("`@*B!`<&%R86T@<W1R:6YG
M("`D8V]L;W(@("`@(%1H92!C;VQO<B!Y;W4@=V%N="!T;R!D<F%W('1H92!L
M:6YE('=I=&@N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D=VED=&@@("`@(%1H
M92!W:61T:"!O9B!T:&4@;&EN92X*("`@("`J+PH@("`@9G5N8W1I;VX@<&]L
M>6QI;F4H)'9E<G1S+"`D8V]L;W(L("1W:61T:"`](#$I"B`@("!["B`@("`@
M("`@)&-O;&]R(#T@)'1H:7,M/F%L;&]C871E0V]L;W(H)&-O;&]R*3L*"B`@
M("`@("`@)'-H87!E(#T@)FYE=R!35T93:&%P92@I.PH@("`@("`@("1S:&%P
M92T^<V5T3&EN92@D=VED=&@L("1C;VQO<ELG<F5D)UTL("1C;VQO<ELG9W)E
M96XG72P@)&-O;&]R6R=B;'5E)UTL("1C;VQO<ELG86QP:&$G72D["@H@("`@
M("`@("1F:7)S=%]D;VYE(#T@9F%L<V4["B`@("`@("`@9F]R96%C:"`H)'9E
M<G1S(&%S("1V86QU92D@>PH@("`@("`@("`@("!I9B`H(21F:7)S=%]D;VYE
M*2!["B`@("`@("`@("`@("`@("`D<VAA<&4M/FUO=F5096Y4;R@D=F%L=65;
M)W@G72P@)'9A;'5E6R=Y)UTI.PH@("`@("`@("`@("`@("`@)&9I<G-T7V1O
M;F4@/2!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1S:&%P92T^
M9')A=TQI;F54;R@D=F%L=65;)W@G72P@)'9A;'5E6R=Y)UTI.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;6]V:64M/F%D9"@D<VAA<&4I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A;B!A<F,N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)'@@("`@("!4:&4@>"!C;RUO<F1I;F%T
M92!O9B!T:&4@8V5N=')E+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'D@("`@
M("!4:&4@>2!C;RUO<F1I;F%T92!O9B!T:&4@8V5N=')E+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)'(@("`@("!4:&4@<F%D:75S(&]F('1H92!A<F,N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D<W1A<G0@(%1H92!S=&%R="!A;F=L92!O
M9B!T:&4@87)C+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&5N9"`@("!4:&4@
M96YD(&%N9VQE(&]F('1H92!A<F,N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C
M;VQO<B`@(%1H92!L:6YE(&-O;&]R(&]F('1H92!A<F,N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1F:6QL("`@(%1H92!F:6QL(&-O;&]R(&]F('1H92!A<F,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&%R8R@D>"P@)'DL("1R+"`D<W1A<G0L
M("1E;F0L("1C;VQO<B`]("=B;&%C:R<L("1F:6QL(#T@)VYO;F4G*0H@("`@
M>PH@("`@("`@("1S(#T@)FYE=R!35T93:&%P92@I.PH@("`@("`@("1C;VQO
M<B`]("1T:&ES+3YA;&QO8V%T94-O;&]R*"1C;VQO<BD["B`@("`@("`@)',M
M/G-E=$QI;F4H,2P@)&-O;&]R6R=R960G72P@)&-O;&]R6R=G<F5E;B==+"`D
M8V]L;W);)V)L=64G72P@)&-O;&]R6R=A;'!H82==*3L*"B`@("`@("`@:68@
M*"1F:6QL("$]("=N;VYE)RD@>PH@("`@("`@("`@("`D9FEL;$-O;&]R(#T@
M)'1H:7,M/F%L;&]C871E0V]L;W(H)&9I;&PI.PH@("`@("`@("`@("`D9B`]
M("1S+3YA9&1&:6QL*"1F:6QL0V]L;W);)W)E9"==+"`D9FEL;$-O;&]R6R=G
M<F5E;B==+"`D9FEL;$-O;&]R6R=B;'5E)UTL("1F:6QL0V]L;W);)V%L<&AA
M)UTI.PH@("`@("`@("`@("`D<RT^<V5T4FEG:'1&:6QL*"1F*3L*("`@("`@
M("!]"@H@("`@("`@(&EF("@D96YD("T@)'-T87)T(#P](#0U*2!["B`@("`@
M("`@("`@("1P=',@/2`D=&AI<RT^7V%R8U!O:6YT<R@D<BP@)'-T87)T+"`D
M96YD*3L*("`@("`@("`@("`@)',M/FUO=F5096Y4;R@D>"P@)'DI.PH@("`@
M("`@("`@("`D<RT^9')A=TQI;F54;R@D<'1S6R=X,2==("L@)'@L("1P='-;
M)WDQ)UT@*R`D>2D["B`@("`@("`@("`@("1S+3YD<F%W0W5R=F54;R@D<'1S
M6R=X,R==("L@)'@L("1P='-;)WDS)UT@*R`D>2P@)'!T<ULG>#(G72`K("1X
M+"`D<'1S6R=Y,B==("L@)'DI.PH@("`@("`@("`@("`D<RT^9')A=TQI;F54
M;R@D>"P@)'DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1S96-T
M:6]N<R`](&-E:6PH*"1E;F0@+2`D<W1A<G0I("\@-#4I.PH@("`@("`@("`@
M("!F;W(@*"1I(#T@,#L@)&D@/"`D<V5C=&EO;G,[("1I*RLI('L*("`@("`@
M("`@("`@("`@("1P=',@/2`D=&AI<RT^7V%R8U!O:6YT<R@D<BP@)'-T87)T
M("L@*"1I("H@-#4I+"`H)'-T87)T("L@*"@D:2`K(#$I("H@-#4I(#X@)&5N
M9"D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`_
M("1E;F0*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`Z("@D<W1A<G0@*R`H*"1I("L@,2D@*B`T-2DI*3L*"B`@("`@("`@("`@
M("`@("`O+R!)9B!W92!A<F4@;VX@=&AE(&9I<G-T('-E8W1I;VXL(&UO=F4@
M=&AE('!E;B!T;R!T:&4*("`@("`@("`@("`@("`@("\O(&-E;G1R92!A;F0@
M9')A=R!O=70@=&\@=&AE(&5D9V4N"B`@("`@("`@("`@("`@("!I9B`H)&D@
M/3T@,"`F)B`D9FEL;"`A/2`G;F]N92<I('L*("`@("`@("`@("`@("`@("`@
M("`D<RT^;6]V95!E;E1O*"1X+"`D>2D["B`@("`@("`@("`@("`@("`@("`@
M)',M/F1R87=,:6YE5&\H)'!T<ULG>#$G72`K("1X+"`D<'1S6R=Y,2==("L@
M)'DI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`D<RT^;6]V95!E;E1O*"1P='-;)W@Q)UT@*R`D>"P@)'!T<ULG>3$G
M72`K("1Y*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O
M+R!$<F%W('1H92!A<F,N"B`@("`@("`@("`@("`@("`D<RT^9')A=T-U<G9E
M5&\H)'!T<ULG>#,G72`K("1X+"`D<'1S6R=Y,R==("L@)'DL("1P='-;)W@R
M)UT@*R`D>"P@)'!T<ULG>3(G72`K("1Y*3L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@:68@*"1F:6QL("$]("=N;VYE)RD@>PH@("`@("`@("`@("`@
M("`@+R\@1')A=R!A(&QI;F4@9G)O;2!T:&4@961G92!B86-K('1O('1H92!C
M96YT<F4@=&\@8VQO<V4*("`@("`@("`@("`@("`@("\O(&]F9B!T:&4@<V5G
M;65N="X*("`@("`@("`@("`@("`@("1S+3YD<F%W3&EN951O*"1X+"`D>2D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI
M<RT^7VUO=FEE+3YA9&0H)',I.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A
M=R!A(')E8W1A;F=L92!F:6QL960@=VET:"!A(&=R861I96YT(&9R;VT@)&-O
M;&]R,2!T;PH@("`@("H@)&-O;&]R,BX*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D>"`@("`@("!4:&4@;&5F="!X+6-O;W)D:6YA=&4@;V8@=&AE
M(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y("`@("`@(%1H
M92!T;W`@>2UC;V]R9&EN871E(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D=VED=&@@("!4:&4@=VED=&@@;V8@=&AE(')E8W1A
M;F=L92X*("`@("`J($!P87)A;2!I;G1E9V5R("1H96EG:'0@(%1H92!H96EG
M:'0@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!S=')I;F<@("1C
M;VQO<B`@(%1H92!O=71L:6YE(&-O;&]R(&]F('1H92!R96-T86YG;&4N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("`D9FEL;#$@("!4:&4@;F%M92!O9B!T:&4@
M<W1A<G0@8V]L;W(@9F]R('1H92!G<F%D:65N="X*("`@("`J($!P87)A;2!S
M=')I;F<@("1F:6QL,B`@(%1H92!N86UE(&]F('1H92!E;F0@8V]L;W(@9F]R
M('1H92!G<F%D:65N="X*("`@("`J+PH@("`@9G5N8W1I;VX@9W)A9&EE;G12
M96-T86YG;&4H)'@L("1Y+"`D=VED=&@L("1H96EG:'0L("1C;VQO<B`]("=B
M;&%C:R<L("1F:6QL,2`]("=B;&%C:R<L("1F:6QL,B`]("=W:&ET92<I"B`@
M("!["B`@("`@("`@)',@/2`F;F5W(%-71E-H87!E*"D["@H@("`@("`@(&EF
M("@D8V]L;W(@(3T@)VYO;F4G*2!["B`@("`@("`@("`@("1C;VQO<B`]("1T
M:&ES+3YA;&QO8V%T94-O;&]R*"1C;VQO<BD["B`@("`@("`@("`@("1S+3YS
M971,:6YE*#$L("1C;VQO<ELG<F5D)UTL("1C;VQO<ELG9W)E96XG72P@)&-O
M;&]R6R=B;'5E)UTL("1C;VQO<ELG86QP:&$G72D["B`@("`@("`@?0H*("`@
M("`@("`D9FEL;#$@/2`D=&AI<RT^86QL;V-A=&5#;VQO<B@D9FEL;#$I.PH@
M("`@("`@("1F:6QL,B`]("1T:&ES+3YA;&QO8V%T94-O;&]R*"1F:6QL,BD[
M"B`@("`@("`@)&=R861I96YT(#T@)FYE=R!35T9'<F%D:65N="@I.PH@("`@
M("`@("1G<F%D:65N="T^861D16YT<GDH,"XP+"`D9FEL;#%;)W)E9"==+"`D
M9FEL;#%;)V=R965N)UTL("1F:6QL,5LG8FQU92==+"`D9FEL;#%;)V%L<&AA
M)UTI.PH@("`@("`@("1G<F%D:65N="T^861D16YT<GDH,2XP+"`D9FEL;#);
M)W)E9"==+"`D9FEL;#);)V=R965N)UTL("1F:6QL,ELG8FQU92==+"`D9FEL
M;#);)V%L<&AA)UTI.PH*("`@("`@("`D9B`]("1S+3YA9&1&:6QL*"1G<F%D
M:65N="P@4U=&1DE,3%],24Y%05)?1U)!1$E%3E0I.PH@("`@("`@("1F+3YS
M8V%L951O*"1W:61T:"`O("1T:&ES+3Y?=VED=&@I.PH@("`@("`@("1F+3YM
M;W9E5&\H)'@L("1Y*3L*("`@("`@("`D<RT^<V5T4FEG:'1&:6QL*"1F*3L*
M"B`@("`@("`@)'9E<G1S6S!=(#T@87)R87DH)W@G(#T^("1X+"`G>2<@/3X@
M)'DI.PH@("`@("`@("1V97)T<ULQ72`](&%R<F%Y*"=X)R`]/B`D>"`K("1W
M:61T:"P@)WDG(#T^("1Y*3L*("`@("`@("`D=F5R='-;,ET@/2!A<G)A>2@G
M>"<@/3X@)'@@*R`D=VED=&@L("=Y)R`]/B`D>2`K("1H96EG:'0I.PH@("`@
M("`@("1V97)T<ULS72`](&%R<F%Y*"=X)R`]/B`D>"P@)WDG(#T^("1Y("L@
M)&AE:6=H="D["@H@("`@("`@("1F:7)S=%]D;VYE(#T@9F%L<V4["B`@("`@
M("`@9F]R96%C:"`H)'9E<G1S(&%S("1V97)T*2!["B`@("`@("`@("`@(&EF
M("@A)&9I<G-T7V1O;F4I('L*("`@("`@("`@("`@("`@("1S+3YM;W9E4&5N
M5&\H)'9E<G1;)W@G72P@)'9E<G1;)WDG72D["B`@("`@("`@("`@("`@("`D
M9FER<W1?9&]N92`]('1R=64["B`@("`@("`@("`@("`@("`D9FER<W1?>"`]
M("1V97)T6R=X)UT["B`@("`@("`@("`@("`@("`D9FER<W1?>2`]("1V97)T
M6R=Y)UT["B`@("`@("`@("`@('T*("`@("`@("`@("`@)',M/F1R87=,:6YE
M5&\H)'9E<G1;)W@G72P@)'9E<G1;)WDG72D["B`@("`@("`@?0H@("`@("`@
M("1S+3YD<F%W3&EN951O*"1F:7)S=%]X+"`D9FER<W1?>2D["@H@("`@("`@
M(')E='5R;B`D=&AI<RT^7VUO=FEE+3YA9&0H)',I.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M26UA9V4O9V0N<&AP````````````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`Q,#<V-#8@,3`U,34T,S,W,S4@,#(Q-3$S`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"@IR97%U:7)E7V]N
M8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN+TEM86=E+G!H<"<["@HO*BH*
M("H@5&AI<R!C;&%S<R!I;7!L96UE;G1S('1H92!(;W)D95]);6%G93HZ($%0
M22!F;W(@=&AE(%!(4"!'1`H@*B!E>'1E;G-I;VXN($ET(&UA:6YL>2!P<F]V
M:61E<R!S;VUE('5T:6QI='D@9G5N8W1I;VYS+"!S=6-H(&%S('1H90H@*B!A
M8FEL:71Y('1O(&UA:V4@<&EX96QS+"!F;W(@;F]W+@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]);6%G92]);6%G92]G9"YP:'`L=B`Q+C0X+C$P+C$T(#(P
M,#8O,#$O,#$@,C$Z,C@Z,C(@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K
M86=E($AO<F1E7TEM86=E"B`J+PIC;&%S<R!(;W)D95]);6%G95]G9"!E>'1E
M;F1S($AO<F1E7TEM86=E('L*"B`@("`O*BH*("`@("`J($-A<&%B:6QI=&5S
M(&]F('1H:7,@9')I=F5R+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1?8V%P86)I;&ET:65S(#T@87)R87DH)W)E<VEZ92<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8W)O<"<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G<F]T871E)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=F;&EP)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=M:7)R;W(G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V=R87ES8V%L92<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G<V5P:6$G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)WEE;&QO=VEZ92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G=V%T97)M87)K)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=C86YV87,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@*3L*"B`@
M("`O*BH*("`@("`J(%=H870@:VEN9"!O9B!I;6%G97,@<VAO=6QD($=$(&=E
M;F5R871E/R!$969A=6QT<R!T;R`G<&YG)RX*("`@("`J"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]T>7!E(#T@)W!N9R<["@H@("`@
M+RHJ"B`@("`@*B!'1"!);6%G92!R97-O=7)C92!F;W(@=&AE(&-U<G)E;G0@
M:6UA9V4@9&%T82X*("`@("`J"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@("`@
M*B\*("`@('9A<B`D7VEM.PH*("`@("\J*@H@("`@("H@4W1R:6YG(&ED96YT
M:69I97(@;V8@=&AE(&-U<G)E;G0@:6UA9V4N($YE=R!I;6%G92!D871A('=I
M;&P@;F]T(&)E"B`@("`@*B!L;V%D960@:68@=&AE('-A;64@:60@:7,@86QR
M96%D>2!L;V%D960N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J
M+PH@("`@=F%R("1?:60@/2`G)SL*"B`@("!F=6YC=&EO;B!(;W)D95]);6%G
M95]G9"@D<&%R86US*0H@("`@>PH@("`@("`@('!A<F5N=#HZ2&]R9&5?26UA
M9V4H)'!A<F%M<RD["B`@("`@("`@:68@*"%E;7!T>2@D<&%R86US6R=T>7!E
M)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?='EP92`]("1P87)A;7-;)W1Y
M<&4G73L*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)'!A<F%M<ULG
M=VED=&@G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]I;2`]("8D=&AI<RT^
M7V-R96%T92@D=&AI<RT^7W=I9'1H+"`D=&AI<RT^7VAE:6=H="D["B`@("`@
M("`@("`@("1T:&ES+3Y?8V%L;"@G:6UA9V5&:6QL)RP@87)R87DH)'1H:7,M
M/E]I;2P@,"P@,"P@)'1H:7,M/F%L;&]C871E0V]L;W(H)'1H:7,M/E]B86-K
M9W)O=6YD*2DI.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!G971#
M;VYT96YT5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=I;6%G92\G("X@
M)'1H:7,M/E]T>7!E.PH@("`@?0H*("`@("\J*@H@("`@("H@1&ES<&QA>2!T
M:&4@8W5R<F5N="!I;6%G92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&ES<&QA
M>2@I"B`@("!["B`@("`@("`@)'1H:7,M/FAE861E<G,H*3L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]C86QL*"=I;6%G92<@+B`D=&AI<RT^7W1Y<&4L(&%R
M<F%Y*"1T:&ES+3Y?:6TI*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE(')A=R!D871A(&9O<B!T:&ES(&EM86=E+@H@("`@("H*("`@("`J
M($!P87)A;2!B;V]L96%N("1C;VYV97)T("!)9B!T<G5E+"!T:&4@:6UA9V4@
M9&%T82!W:6QL(&)E(')E='5R;F5D(&EN('1H90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@('1A<F=E="!F;W)M870L(&EN9&5P96YD96YT;'D@
M9G)O;2!A;GD@:6UA9V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("!O<&5R871I;VYS+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@<F%W(&EM86=E(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')A=R@D
M8V]N=F5R="`](&9A;'-E*0H@("`@>PH@("`@("`@(')E='5R;B!5=&EL.CIB
M=69F97)/=71P=70H)VEM86=E)R`N("1T:&ES+3Y?='EP92P@)'1H:7,M/E]I
M;2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!297-E="!T:&4@:6UA9V4@9&%T
M82X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5S970H*0H@("`@>PH@("`@("`@
M('!A<F5N=#HZ<F5S970H*3L*("`@("`@("!I9B`H:7-?<F5S;W5R8V4H)'1H
M:7,M/E]I;2DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?8V%L;"@G
M:6UA9V5$97-T<F]Y)RP@87)R87DH)'1H:7,M/E]I;2DI.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($=E
M="!T:&4@:&5I9VAT(&%N9"!W:61T:"!O9B!T:&4@8W5R<F5N="!I;6%G92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!H87-H('=I=&@@)W=I
M9'1H)R!C;VYT86EN:6YG('1H92!W:61T:"P*("`@("`J("`@("`@("`@("`@
M("`@("=H96EG:'0G(&-O;G1A:6YI;F<@=&AE(&AE:6=H="!O9B!T:&4@:6UA
M9V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1I;65N<VEO;G,H*0H@("`@
M>PH@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?:6TL("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6T["B`@("`@("`@?2!E
M;'-E:68@*&ES7W)E<V]U<F-E*"1T:&ES+3Y?:6TI*2!["B`@("`@("`@("`@
M(')E='5R;B!A<G)A>2@G=VED=&@G(#T^("1T:&ES+3Y?8V%L;"@G:6UA9V53
M6"<L(&%R<F%Y*"1T:&ES+3Y?:6TI*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("=H96EG:'0G(#T^("1T:&ES+3Y?8V%L;"@G:6UA9V5362<L(&%R<F%Y
M*"1T:&ES+3Y?:6TI*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<F5T=7)N(&%R<F%Y*"=W:61T:"<@/3X@,"P@)VAE:6=H="<@/3X@,"D["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E<R!A(&-O;&]R
M('1H870@8V%N(&)E(&%C8V5S<V5D(&EN('1H:7,@;V)J96-T+B!7:&5N(&$*
M("`@("`J(&-O;&]R(&ES('-E="P@=&AE(&EN=&5G97(@<F5S;W5R8V4@;V8@
M:70@:7,@<F5T=7)N960N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;F%M92`@5&AE(&YA;64@;V8@=&AE(&-O;&]R+@H@("`@("H*("`@("`J($!R
M971U<FX@:6YT96=E<B`@5&AE(')E<V]U<F-E(&]F('1H92!C;VQO<B!T:&%T
M(&-A;B!B92!P87-S960@=&\@1T0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%L
M;&]C871E0V]L;W(H)&YA;64I"B`@("!["B`@("`@("`@<W1A=&EC("1C;VQO
M<G,@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H96UP='DH)&-O;&]R<ULD;F%M
M95TI*2!["B`@("`@("`@("`@(&QI<W0H)'(L("1G+"`D8BD@/2`D=&AI<RT^
M9V5T4D="*"1N86UE*3L*("`@("`@("`@("`@)&-O;&]R<ULD;F%M95T@/2`D
M=&AI<RT^7V-A;&PH)VEM86=E0V]L;W)!;&QO8V%T92<L(&%R<F%Y*"1T:&ES
M+3Y?:6TL("1R+"`D9RP@)&(I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D8V]L;W)S6R1N86UE73L*("`@('T*"B`@("!F=6YC=&EO;B!G971&;VYT
M*"1F;VYT*0H@("`@>PH@("`@("`@('-W:71C:"`H)&9O;G0I('L*("`@("`@
M("!C87-E("=T:6YY)SH*("`@("`@("`@("`@<F5T=7)N(#$["@H@("`@("`@
M(&-A<V4@)VUE9&EU;2<Z"B`@("`@("`@("`@(')E='5R;B`S.PH*("`@("`@
M("!C87-E("=L87)G92<Z"B`@("`@("`@("`@(')E='5R;B`T.PH*("`@("`@
M("!C87-E("=G:6%N="<Z"B`@("`@("`@("`@(')E='5R;B`U.PH*("`@("`@
M("!C87-E("=S;6%L;"<Z"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@
M<F5T=7)N(#(["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@3&]A
M9"!T:&4@:6UA9V4@9&%T82!F<F]M(&$@<W1R:6YG+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&ED("`@("`@("`@($%N(&%R8FET<F%R>2!I9"!F
M;W(@=&AE(&EM86=E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:6UA9V5?9&%T
M82`@5&AE(&1A=&$@=&\@=7-E(&9O<B!T:&4@:6UA9V4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&QO8613=')I;F<H)&ED+"`D:6UA9V5?9&%T82D*("`@('L*
M("`@("`@("!I9B`H)&ED("$]("1T:&ES+3Y?:60I('L*("`@("`@("`@("`@
M:68@*"1T:&ES+3Y?:6TI('L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R
M97-U;'0@/2`D=&AI<RT^<F5S970H*2P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?:6T@/2`F
M)'1H:7,M/E]C86QL*"=I;6%G94-R96%T949R;VU3=')I;F<G+"!A<G)A>2@D
M:6UA9V5?9&%T82DI.PH@("`@("`@("`@("`D=&AI<RT^7VED(#T@)&ED.PH@
M("`@("`@("`@("!I9B`H:7-?82@D=&AI<RT^7VEM+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($QO860@
M=&AE(&EM86=E(&1A=&$@9G)O;2!A(&9I;&4N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D9FEL96YA;64@(%1H92!F=6QL('!A=&@@86YD(&9I;&5N
M86UE('1O('1H92!F:6QE('1O(&QO860*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("!T:&4@:6UA9V4@9&%T82!F<F]M+B!4:&4@9FEL96YA;64@
M=VEL;"!A;'-O(&)E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M=7-E9"!F;W(@=&AE(&EM86=E(&ED+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%!%05(@17)R;W(@:68@9FEL92!D;V5S(&YO="!E>&ES="!O<B!C
M;W5L9"!N;W0@8F4@;&]A9&5D"B`@("`@*B`@("`@("`@("`@("`@("!O=&AE
M<G=I<V4@3E5,3"!I9B!S=6-C97-S9G5L(&]R(&%L<F5A9'D@;&]A9&5D+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!L;V%D1FEL92@D9FEL96YA;64I"B`@("![
M"B`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3YR97-E="@I+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@
M("`@("`@('T*"B`@("`@("`@:68@*&ES7V$H)&EN9F\@/2`D=&AI<RT^7V-A
M;&PH)V=E=&EM86=E<VEZ92<L(&%R<F%Y*"1F:6QE;F%M92DI+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D:6YF;SL*("`@("`@("!]
M"@H@("`@("`@(&EF("AI<U]A<G)A>2@D:6YF;RDI('L*("`@("`@("`@("`@
M<W=I=&-H("@D:6YF;ULR72D@>PH@("`@("`@("`@("!C87-E(#$Z"B`@("`@
M("`@("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=I;6%G96-R96%T969R
M;VUG:68G*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6T@/2`F
M)'1H:7,M/E]C86QL*"=I;6%G96-R96%T969R;VUG:68G+"!A<G)A>2@D9FEL
M96YA;64I*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("!C87-E(#(Z"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7VEM(#T@)B1T:&ES+3Y?8V%L;"@G:6UA9V5C<F5A=&5F<F]M:G!E9R<L
M(&%R<F%Y*"1F:6QE;F%M92DI.PH@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@(&-A<V4@,SH*("`@("`@("`@("`@("`@("1T:&ES+3Y?:6T@
M/2`F)'1H:7,M/E]C86QL*"=I;6%G96-R96%T969R;VUP;F<G+"!A<G)A>2@D
M9FEL96YA;64I*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("!C87-E(#$U.@H@("`@("`@("`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T
M<R@G:6UA9V5C<F5A=&5F<F]M9W=B;7`G*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?:6T@/2`F)'1H:7,M/E]C86QL*"=I;6%G96-R96%T969R
M;VUG=V)M<"<L(&%R<F%Y*"1F:6QE;F%M92DI.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@,38Z
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7VEM(#T@)B1T:&ES+3Y?8V%L;"@G
M:6UA9V5C<F5A=&5F<F]M>&)M)RP@87)R87DH)&9I;&5N86UE*2D["B`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@:68@*&ES7V$H)'1H:7,M/E]I;2P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;3L*("`@("`@("!]"@H@("`@
M("`@(&EF("AI<U]R97-O=7)C92@D=&AI<RT^7VEM*2D@>PH@("`@("`@("`@
M("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@<&%R96YT
M.CIL;V%D1FEL92@D9FEL96YA;64I.PH@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^7VEM(#T@)B1T
M:&ES+3Y?8V%L;"@G:6UA9V5#<F5A=&5&<F]M4W1R:6YG)RP@87)R87DH)'1H
M:7,M/E]D871A*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!297-I>F4@=&AE
M(&-U<G)E;G0@:6UA9V4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)'=I9'1H("`@("`@5&AE(&YE=R!W:61T:"X*("`@("`J($!P87)A;2!I;G1E
M9V5R("1H96EG:'0@("`@(%1H92!N97<@:&5I9VAT+@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)')A=&EO("`@("`@36%I;G1A:6X@;W)I9VEN86P@87-P96-T
M(')A=&EO+@H@("`@("HO"B`@("!F=6YC=&EO;B!R97-I>F4H)'=I9'1H+"`D
M:&5I9VAT+"`D<F%T:6\@/2!T<G5E*0H@("`@>PH@("`@("`@("\J($%B;W)T
M(&EF('=E)W)E(&%S:V5D('1O(&1I=FED92!B>2!Z97)O+"!O<B!T<G5N8V%T
M92!T:&4*("`@("`@("`@*B!I;6%G92!C;VUP;&5T96QY(&EN(&5I=&AE<B!D
M:7)E8W1I;VXN("HO"B`@("`@("`@:68@*"$D=VED=&@@?'P@(21H96EG:'0I
M('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"1R871I;RD@>PH@("`@("`@("`@("!I9B`H)'=I9'1H("\@)&AE:6=H="`^
M("1T:&ES+3Y?8V%L;"@G:6UA9V536"<L(&%R<F%Y*"1T:&ES+3Y?:6TI*2`O
M("1T:&ES+3Y?8V%L;"@G:6UA9V5362<L(&%R<F%Y*"1T:&ES+3Y?:6TI*2D@
M>PH@("`@("`@("`@("`@("`@)'=I9'1H(#T@)&AE:6=H="`J("1T:&ES+3Y?
M8V%L;"@G:6UA9V536"<L(&%R<F%Y*"1T:&ES+3Y?:6TI*2`O("1T:&ES+3Y?
M8V%L;"@G:6UA9V5362<L(&%R<F%Y*"1T:&ES+3Y?:6TI*3L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1H96EG:'0@/2`D=VED=&@@
M*B`D=&AI<RT^7V-A;&PH)VEM86=E4UDG+"!A<G)A>2@D=&AI<RT^7VEM*2D@
M+R`D=&AI<RT^7V-A;&PH)VEM86=E4U@G+"!A<G)A>2@D=&AI<RT^7VEM*2D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1I;2`]("1T:&ES
M+3Y?:6T["B`@("`@("`@)'1H:7,M/E]I;2`]("8D=&AI<RT^7V-R96%T92@D
M=VED=&@L("1H96EG:'0I.PH@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?:6TL
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M:6T["B`@("`@("`@?0H@("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI
M<RT^7V-A;&PH)VEM86=E1FEL;"<L(&%R<F%Y*"1T:&ES+3Y?:6TL(#`L(#`L
M("1T:&ES+3Y?8V%L;"@G:6UA9V5#;VQO<D%L;&]C871E)RP@87)R87DH)'1H
M:7,M/E]I;2P@,C4U+"`R-34L(#(U-2DI*2DL("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@("`@
M(&EF("AI<U]A*"1T:&ES+3Y?8V%L;"@G:6UA9V5#;W!Y4F5S86UP;&5D)RP@
M87)R87DH)'1H:7,M/E]I;2P@)&EM+"`P+"`P+"`P+"`P+"`D=VED=&@L("1H
M96EG:'0L("1T:&ES+3Y?8V%L;"@G:6UA9V536"<L(&%R<F%Y*"1I;2DI+"`D
M=&AI<RT^7V-A;&PH)VEM86=E4UDG+"!A<G)A>2@D:6TI*2DI+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V-A;&PH)VEM
M86=E0V]P>5)E<VEZ960G+"!A<G)A>2@D=&AI<RT^7VEM+"`D:6TL(#`L(#`L
M(#`L(#`L("1W:61T:"P@)&AE:6=H="P@)'1H:7,M/E]C86QL*"=I;6%G95-8
M)RP@87)R87DH)&EM*2DL("1T:&ES+3Y?8V%L;"@G:6UA9V5362<L(&%R<F%Y
M*"1I;2DI*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0W)O
M<"!T:&4@8W5R<F5N="!I;6%G92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D>#$@(%1H92!T;W`@;&5F="!C;W)N97(@;V8@=&AE(&-R;W!P960@
M:6UA9V4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>3$@(%1H92!T;W`@<FEG
M:'0@8V]R;F5R(&]F('1H92!C<F]P<&5D(&EM86=E+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)'@R("!4:&4@8F]T=&]M(&QE9G0@8V]R;F5R(&]F('1H92!C
M<F]P<&5D(&EM86=E+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'DR("!4:&4@
M8F]T=&]M(')I9VAT(&-O<FYE<B!O9B!T:&4@8W)O<'!E9"!I;6%G92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@8W)O<"@D>#$L("1Y,2P@)'@R+"`D>3(I"B`@
M("!["B`@("`@("`@)&EM(#T@)'1H:7,M/E]I;3L*("`@("`@("`D=&AI<RT^
M7VEM(#T@)B1T:&ES+3Y?8W)E871E*"1X,B`M("1X,2P@)'DR("T@)'DQ*3L*
M("`@("`@("!I9B`H:7-?82@D=&AI<RT^7VEM+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@)'1H:7,M/E]C86QL*"=I;6%G94-O<'DG+"!A<G)A>2@D
M=&AI<RT^7VEM+"`D:6TL(#`L(#`L("1X,2P@)'DQ+"`D>#(@+2`D>#$L("1Y
M,B`M("1Y,2DI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F]T871E('1H92!C
M=7)R96YT(&EM86=E+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1A
M;F=L92`@("`@("!4:&4@86YG;&4@=&\@<F]T871E('1H92!I;6%G92!B>2P*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I;B!T:&4@8VQO
M8VMW:7-E(&1I<F5C=&EO;@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&)A8VMG
M<F]U;F0@(%1H92!B86-K9W)O=6YD(&-O;&]R('1O(&9I;&P@86YY('1R:6%N
M9VQE<PH@("`@("HO"B`@("!F=6YC=&EO;B!R;W1A=&4H)&%N9VQE+"`D8F%C
M:V=R;W5N9"`]("=W:&ET92<I"B`@("!["B`@("`@("`@:68@*"%F=6YC=&EO
M;E]E>&ES=',H)VEM86=E<F]T871E)RDI('L*("`@("`@("`@("`@<F5T=7)N
M.PH@("`@("`@('T*"B`@("`@("`@)&)A8VMG<F]U;F0@/2`D=&AI<RT^86QL
M;V-A=&5#;VQO<B@D8F%C:V=R;W5N9"D["B`@("`@("`@:68@*&ES7V$H)&)A
M8VMG<F]U;F0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1B86-K9W)O=6YD.PH@("`@("`@('T*"B`@("`@("`@<W=I=&-H("@D86YG
M;&4I('L*("`@("`@("!C87-E("<Y,"<Z"B`@("`@("`@("`@("1X(#T@)'1H
M:7,M/E]C86QL*"=I;6%G95-8)RP@87)R87DH)'1H:7,M/E]I;2DI.PH@("`@
M("`@("`@("`D>2`]("1T:&ES+3Y?8V%L;"@G:6UA9V5362<L(&%R<F%Y*"1T
M:&ES+3Y?:6TI*3L*("`@("`@("`@("`@)'AY;6%X(#T@;6%X*"1X+"`D>2D[
M"@H@("`@("`@("`@("`D:6T@/2`F)'1H:7,M/E]C<F5A=&4H)'AY;6%X+"`D
M>'EM87@I.PH@("`@("`@("`@("!I9B`H:7-?82@D:6TL("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D:6T["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3Y?8V%L
M;"@G:6UA9V5#;W!Y)RP@87)R87DH)&EM+"`D=&AI<RT^7VEM+"`P+"`P+"`P
M+"`P+"`D>"P@)'DI*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)&EM(#T@)B1T:&ES+3Y?8V%L;"@G:6UA9V52;W1A=&4G+"!A<G)A>2@D:6TL
M(#(W,"P@)&)A8VMG<F]U;F0I*3L*("`@("`@("`@("`@:68@*&ES7V$H)&EM
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&EM
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?:6T@/2`D:6T[
M"B`@("`@("`@("`@("1I;2`]("8D=&AI<RT^7V-R96%T92@D>2P@)'@I.PH@
M("`@("`@("`@("!I9B`H:7-?82@D:6TL("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@(')E='5R;B`D:6T["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@:68@*"1X(#P@)'DI('L*("`@("`@("`@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E0V]P>2<L(&%R<F%Y*"1I
M;2P@)'1H:7,M/E]I;2P@,"P@,"P@,"P@,"P@)'AY;6%X+"`D>'EM87@I*2P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V5I
M9B`H)'@@/B`D>2D@>PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L
M="`]("1T:&ES+3Y?8V%L;"@G:6UA9V5#;W!Y)RP@87)R87DH)&EM+"`D=&AI
M<RT^7VEM+"`P+"`P+"`D>'EM87@@+2`D>2P@)'AY;6%X("T@)'@L("1X>6UA
M>"P@)'AY;6%X*2DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7VEM(#T@)&EM.PH@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@)'1H
M:7,M/E]I;2`]("8D=&AI<RT^7V-A;&PH)VEM86=E4F]T871E)RP@87)R87DH
M)'1H:7,M/E]I;2P@,S8P("T@)&%N9VQE+"`D8F%C:V=R;W5N9"DI.PH@("`@
M("`@("`@("!I9B`H:7-?82@D=&AI<RT^7VEM+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!&;&EP('1H92!C=7)R96YT(&EM86=E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!F;&EP*"D*("`@('L*("`@("`@("`D>"`]("1T:&ES+3Y?
M8V%L;"@G:6UA9V536"<L(&%R<F%Y*"1T:&ES+3Y?:6TI*3L*("`@("`@("`D
M>2`]("1T:&ES+3Y?8V%L;"@G:6UA9V5362<L(&%R<F%Y*"1T:&ES+3Y?:6TI
M*3L*"B`@("`@("`@)&EM(#T@)B1T:&ES+3Y?8W)E871E*"1X+"`D>2D["B`@
M("`@("`@:68@*&ES7V$H)&EM+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D:6T["B`@("`@("`@?0H@("`@("`@(&9O<B`H)&-U<ED@
M/2`P.R`D8W5R62`\("1Y.R`D8W5R62LK*2!["B`@("`@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E0V]P>2<L(&%R<F%Y
M*"1I;2P@)'1H:7,M/E]I;2P@,"P@)'D@+2`H)&-U<ED@*R`Q*2P@,"P@)&-U
M<EDL("1X+"`Q*2DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("`D=&AI<RT^7VEM(#T@)&EM.PH@("`@?0H*("`@("\J*@H@("`@("H@
M36ER<F]R('1H92!C=7)R96YT(&EM86=E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!M:7)R;W(H*0H@("`@>PH@("`@("`@("1X(#T@)'1H:7,M/E]C86QL*"=I
M;6%G95-8)RP@87)R87DH)'1H:7,M/E]I;2DI.PH@("`@("`@("1Y(#T@)'1H
M:7,M/E]C86QL*"=I;6%G95-9)RP@87)R87DH)'1H:7,M/E]I;2DI.PH*("`@
M("`@("`D:6T@/2`F)'1H:7,M/E]C<F5A=&4H)'@L("1Y*3L*("`@("`@("!I
M9B`H:7-?82@D:6TL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1I;3L*("`@("`@("!]"B`@("`@("`@9F]R("@D8W5R6"`](#`[("1C
M=7)8(#P@)'@[("1C=7)8*RLI('L*("`@("`@("`@("`@:68@*&ES7V$H)')E
M<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA9V5#;W!Y)RP@87)R87DH)&EM+"`D
M=&AI<RT^7VEM+"`D>"`M("@D8W5R6"`K(#$I+"`P+"`D8W5R6"P@,"P@,2P@
M)'DI*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1T
M:&ES+3Y?:6T@/2`D:6T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T
M('1H92!C=7)R96YT(&EM86=E('1O(&=R87ES8V%L92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9W)A>7-C86QE*"D*("`@('L*("`@("`@("`D<F%T95(@/2`N
M,C(Y.PH@("`@("`@("1R871E1R`]("XU.#<["B`@("`@("`@)')A=&5"(#T@
M+C$Q-#L*("`@("`@("`D=VAI=&5N97-S(#T@,SL*"B`@("`@("`@:68@*&9U
M;F-T:6]N7V5X:7-T<R@G:6UA9V5I<W1R=65C;VQO<B<I("8F("1T:&ES+3Y?
M8V%L;"@G:6UA9V5)<U1R=65#;VQO<B<L(&%R<F%Y*"1T:&ES+3Y?:6TI*2`]
M/3T@=')U92D@>PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT(#T@)'1H
M:7,M/E]C86QL*"=I;6%G951R=65#;VQO<E1O4&%L971T92<L(&%R<F%Y*"1T
M:&ES+3Y?:6TL('1R=64L(#(U-BDI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@)&-O;&]R<R`](&UI;B@R-38L("1T:&ES+3Y?8V%L
M;"@G:6UA9V5#;VQO<G-4;W1A;"<L(&%R<F%Y*"1T:&ES+3Y?:6TI*2D["B`@
M("`@("`@9F]R("@D>"`](#`[("1X(#P@)&-O;&]R<SL@)'@K*RD@>PH@("`@
M("`@("`@("`D<W)C(#T@)'1H:7,M/E]C86QL*"=I;6%G94-O;&]R<T9O<DEN
M9&5X)RP@87)R87DH)'1H:7,M/E]I;2P@)'@I*3L*("`@("`@("`@("`@:68@
M*&ES7V$H)'-R8RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1S<F,["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&YE=R`]
M(&UI;B@R-34L(&%B<R@D<W)C6R=R960G72`J("1R871E4B`K("1S<F-;)V=R
M965N)UT@*B`D<F%T94<@*R`D<W)C6R=B;'5E)UT@*B`D<F%T94(I("L@)'=H
M:71E;F5S<RD["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI
M<RT^7V-A;&PH)VEM86=E0V]L;W)3970G+"!A<G)A>2@D=&AI<RT^7VEM+"`D
M>"P@)&YE=RP@)&YE=RP@)&YE=RDI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-E<&EA(&9I;'1E<BX*("`@
M("`J"B`@("`@*B!"87-I8V%L;'D@='5R;G,@=&AE(&EM86=E('1O(&=R87ES
M8V%L92!A;F0@=&AE;B!A9&1S('-O;64*("`@("`J(&1E9FEN960@=&EN="!O
M;B!I="`H4B`K/2`S,"P@1R`K/2`T,RP@0B`K/2`M,C,I('-O(&ET('=I;&P*
M("`@("`J(&%P<&5A<B!T;R!B92!A('9E<GD@;VQD('!I8W1U<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E<&EA*"D*("`@('L*("`@("`@("`D=&EN=%(@
M/2`X,#L*("`@("`@("`D=&EN=$<@/2`T,SL*("`@("`@("`D=&EN=$(@/2`M
M,C,["B`@("`@("`@)')A=&52(#T@+C(R.3L*("`@("`@("`D<F%T94<@/2`N
M-3@W.PH@("`@("`@("1R871E0B`]("XQ,30["B`@("`@("`@)'=H:71E;F5S
M<R`](#,["@H@("`@("`@(&EF("@D=&AI<RT^7V-A;&PH)VEM86=E27-4<G5E
M0V]L;W(G+"!A<G)A>2@D=&AI<RT^7VEM*2D@/3T]('1R=64I('L*("`@("`@
M("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA9V54
M<G5E0V]L;W)4;U!A;&5T=&4G+"!A<G)A>2@D=&AI<RT^7VEM+"!T<G5E+"`R
M-38I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1C
M;VQO<G,@/2!M87@H,C4V+"`D=&AI<RT^7V-A;&PH)VEM86=E0V]L;W)S5&]T
M86PG+"!A<G)A>2@D=&AI<RT^7VEM*2DI.PH@("`@("`@(&9O<B`H)'@@/2`P
M.R`D>"`\("1C;VQO<G,[("1X*RLI('L*("`@("`@("`@("`@)'-R8R`]("1T
M:&ES+3Y?8V%L;"@G:6UA9V5#;VQO<G-&;W));F1E>"<L(&%R<F%Y*"1T:&ES
M+3Y?:6TL("1X*2D["B`@("`@("`@("`@(&EF("AI<U]A*"1S<F,L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<W)C.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1N97<@/2!M:6XH,C4U+"!A8G,H)'-R
M8ULG<F5D)UT@*B`D<F%T95(@*R`D<W)C6R=G<F5E;B==("H@)')A=&5'("L@
M)'-R8ULG8FQU92==("H@)')A=&5"*2`K("1W:&ET96YE<W,I.PH@("`@("`@
M("`@("`D<B`](&UI;B@R-34L("1N97<@*R`D=&EN=%(I.PH@("`@("`@("`@
M("`D9R`](&UI;B@R-34L("1N97<@*R`D=&EN=$<I.PH@("`@("`@("`@("`D
M8B`](&UI;B@R-34L("1N97<@*R`D=&EN=$(I.PH@("`@("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G94-O;&]R4V5T)RP@
M87)R87DH)'1H:7,M/E]I;2P@)'@L("1R+"`D9RP@)&(I*2P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!996QL
M;W=I>F4@9FEL=&5R+@H@("`@("H*("`@("`J($%D9',@82!L87EE<B!O9B!Y
M96QL;W<@=&AA="!C86X@8F4@=')A;G-P87)E;G0@;W(@<V]L:60N($EF"B`@
M("`@*B`D:6YT96YS:71Y02!I<R`R-34@=&AE(&EM86=E('=I;&P@8F4@,"4@
M=')A;G-P87)E;G0@*'-O;&ED*2X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D:6YT96YS:71Y62`@2&]W('-T<F]N9R!S:&]U;&0@=&AE('EE;&QO
M=R`H<F5D(&%N9"!G<F5E;BD@8F4_("@P+3(U-2D*("`@("`J($!P87)A;2!I
M;G1E9V5R("1I;G1E;G-I='E"("!(;W<@=V5A:R!S:&]U;&0@=&AE(&)L=64@
M8F4_("@^/2`R+"!I;B!T:&4@<&]S:71I=F4@;&EM:70@:70@=VEL;"!B92!M
M86ME($),544@,"D*("`@("`J+PH@("`@9G5N8W1I;VX@>65L;&]W:7IE*"1I
M;G1E;G-I='E9(#T@-3`L("1I;G1E;G-I='E"(#T@,RD*("`@('L*("`@("`@
M("!I9B`H)'1H:7,M/E]C86QL*"=I;6%G94ES5')U94-O;&]R)RP@87)R87DH
M)'1H:7,M/E]I;2DI(#T]/2!T<G5E*2!["B`@("`@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E5')U94-O;&]R5&]086QE
M='1E)RP@87)R87DH)'1H:7,M/E]I;2P@=')U92P@,C4V*2DL("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D8V]L;W)S(#T@;6%X*#(U
M-BP@)'1H:7,M/E]C86QL*"=I;6%G94-O;&]R<U1O=&%L)RP@87)R87DH)'1H
M:7,M/E]I;2DI*3L*("`@("`@("!F;W(@*"1X(#T@,#L@)'@@/"`D8V]L;W)S
M.R`D>"LK*2!["B`@("`@("`@("`@("1S<F,@/2`D=&AI<RT^7V-A;&PH)VEM
M86=E0V]L;W)S1F]R26YD97@G+"!A<G)A>2@D=&AI<RT^7VEM+"`D>"DI.PH@
M("`@("`@("`@("!I9B`H:7-?82@D<W)C+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)'-R8SL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D<B`](&UI;B@D<W)C6R=R960G72`K("1I;G1E;G-I='E9+"`R
M-34I.PH@("`@("`@("`@("`D9R`](&UI;B@D<W)C6R=G<F5E;B==("L@)&EN
M=&5N<VET>5DL(#(U-2D["B`@("`@("`@("`@("1B(#T@;6%X*"@D<B`K("1G
M*2`O(&UA>"@D:6YT96YS:71Y0BP@,BDL(#`I.PH@("`@("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G94-O;&]R4V5T)RP@
M87)R87DH)'1H:7,M/E]I;2P@)'@L("1R+"`D9RP@)&(I*2P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@=V%T97)M
M87)K*"1T97AT+"`D:&%L:6=N(#T@)W)I9VAT)RP@)'9A;&EG;B`]("=B;W1T
M;VTG+"`D9F]N="`]("=S;6%L;"<I"B`@("!["B`@("`@("`@)&-O;&]R(#T@
M)'1H:7,M/E]C86QL*"=I;6%G94-O;&]R0VQO<V5S="<L(&%R<F%Y*"1T:&ES
M+3Y?:6TL(#(U-2P@,C4U+"`R-34I*3L*("`@("`@("!I9B`H:7-?82@D8V]L
M;W(L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VQO
M<CL*("`@("`@("!]"B`@("`@("`@)'-H861O=R`]("1T:&ES+3Y?8V%L;"@G
M:6UA9V5#;VQO<D-L;W-E<W0G+"!A<G)A>2@D=&AI<RT^7VEM+"`P+"`P+"`P
M*2D["B`@("`@("`@:68@*&ES7V$H)'-H861O=RP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)'-H861O=SL*("`@("`@("!]"@H@("`@
M("`@("\O(%-H861O=R!O9F9S970@:6X@<&EX96QS+@H@("`@("`@("1D<F]P
M(#T@,3L*"B`@("`@("`@+R\@36%X:6UU;2!T97AT('=I9'1H+@H@("`@("`@
M("1M87AW:61T:"`](#(P,#L*"B`@("`@("`@+R\@06UO=6YT(&]F('-P86-E
M('1O(&QE879E(&)E='=E96X@=&AE('1E>'0@86YD('1H92!I;6%G90H@("`@
M("`@("\O(&)O<F1E<BX*("`@("`@("`D<&%D9&EN9R`](#$P.PH*("`@("`@
M("`D9B`]("1T:&ES+3YG971&;VYT*"1F;VYT*3L*("`@("`@("`D9F]N='=I
M9'1H(#T@)'1H:7,M/E]C86QL*"=I;6%G949O;G17:61T:"<L(&%R<F%Y*"1F
M*2D["B`@("`@("`@:68@*&ES7V$H)&9O;G1W:61T:"P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&9O;G1W:61T:#L*("`@("`@("!]
M"B`@("`@("`@)&9O;G1H96EG:'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E1F]N
M=$AE:6=H="<L(&%R<F%Y*"1F*2D["B`@("`@("`@:68@*&ES7V$H)&9O;G1H
M96EG:'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1F
M;VYT:&5I9VAT.PH@("`@("`@('T*"B`@("`@("`@+R\@4V\@=&AA="!S:&%D
M;W<@:7,@;F]T(&]F9B!T:&4@:6UA9V4@=VET:"!R:6=H="!A;&EG;B!A;F0*
M("`@("`@("`O+R!B;W1T;VT@=F%L:6=N+@H@("`@("`@("1M87)G:6X@/2!F
M;&]O<B@D<&%D9&EN9R`K("1D<F]P*2`O(#(["@H@("`@("`@(&EF("@D;6%X
M=VED=&@I('L*("`@("`@("`@("`@)&UA>&-H87)S<&5R;&EN92`](&9L;V]R
M*"@D;6%X=VED=&@@+2`H)&UA<F=I;B`J(#(I*2`O("1F;VYT=VED=&@I.PH@
M("`@("`@("`@("`D=&5X="`]('=O<F1W<F%P*"1T97AT+"`D;6%X8VAA<G-P
M97)L:6YE+"`B7&XB+"`Q*3L*("`@("`@("!]"@H@("`@("`@("\O(%-P;&ET
M("1T97AT(&EN=&\@:6YD:79I9'5A;"!L:6YE<RX*("`@("`@("`D;&EN97,@
M/2!E>'!L;V1E*")<;B(L("1T97AT*3L*"B`@("`@("`@<W=I=&-H("@D=F%L
M:6=N*2!["B`@("`@("`@8V%S92`G8V5N=&5R)SH*("`@("`@("`@("`@)'D@
M/2`H)'1H:7,M/E]C86QL*"=I;6%G95-9)RP@87)R87DH)'1H:7,M/E]I;2DI
M("T@*"1F;VYT:&5I9VAT("H@8V]U;G0H)&QI;F5S*2DI("\@,CL*("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)V)O='1O;2<Z"B`@("`@("`@
M("`@("1Y(#T@)'1H:7,M/E]C86QL*"=I;6%G95-9)RP@87)R87DH)'1H:7,M
M/E]I;2DI("T@*"@D9F]N=&AE:6=H="`J(&-O=6YT*"1L:6YE<RDI("L@)&UA
M<F=I;BD["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!D969A=6QT.@H@
M("`@("`@("`@("`D>2`]("1M87)G:6X["B`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@('T*"B`@("`@("`@<W=I=&-H("@D:&%L:6=N*2!["B`@("`@("`@
M8V%S92`G<FEG:'0G.@H@("`@("`@("`@("!F;W)E86-H("@D;&EN97,@87,@
M)&QI;F4I('L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D
M=&AI<RT^7V-A;&PH)VEM86=E4W1R:6YG)RP@87)R87DH)'1H:7,M/E]I;2P@
M)&8L("@D=&AI<RT^7V-A;&PH)VEM86=E4U@G+"!A<G)A>2@D=&AI<RT^7VEM
M*2D@+2`D9F]N='=I9'1H("H@<W1R;&5N*"1L:6YE*2D@+2`D;6%R9VEN("L@
M)&1R;W`L("@D>2`K("1D<F]P*2P@)&QI;F4L("1S:&%D;W<I*2P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)')E<W5L="`]
M("1T:&ES+3Y?8V%L;"@G:6UA9V53=')I;F<G+"!A<G)A>2@D=&AI<RT^7VEM
M+"`D9BP@*"1T:&ES+3Y?8V%L;"@G:6UA9V536"<L(&%R<F%Y*"1T:&ES+3Y?
M:6TI*2`M("1F;VYT=VED=&@@*B!S=')L96XH)&QI;F4I*2`M("1M87)G:6XL
M("1Y+"`D;&EN92P@)&-O;&]R*2D["B`@("`@("`@("`@("`@("`D>2`K/2`D
M9F]N=&AE:6=H=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@8V%S92`G8V5N=&5R)SH*("`@("`@("`@("`@9F]R96%C:"`H
M)&QI;F5S(&%S("1L:6YE*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G95-T<FEN9R<L(&%R<F%Y*"1T
M:&ES+3Y?:6TL("1F+"!F;&]O<B@H)'1H:7,M/E]C86QL*"=I;6%G95-8)RP@
M87)R87DH)'1H:7,M/E]I;2DI("T@)&9O;G1W:61T:"`J('-T<FQE;B@D;&EN
M92DI("\@,BD@*R`D9')O<"P@*"1Y("L@)&1R;W`I+"`D;&EN92P@)'-H861O
M=RDI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N("1R97-U;'0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G95-T<FEN9R<L(&%R<F%Y
M*"1T:&ES+3Y?:6TL("1F+"!F;&]O<B@H)'1H:7,M/E]C86QL*"=I;6%G95-8
M)RP@87)R87DH)'1H:7,M/E]I;2DI("T@)&9O;G1W:61T:"`J('-T<FQE;B@D
M;&EN92DI("\@,BDL("1Y+"`D;&EN92P@)&-O;&]R*2D["B`@("`@("`@("`@
M("`@("`D>2`K/2`D9F]N=&AE:6=H=#L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@9F]R
M96%C:"`H)&QI;F5S(&%S("1L:6YE*2!["B`@("`@("`@("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G95-T<FEN9R<L(&%R
M<F%Y*"1T:&ES+3Y?:6TL("1F+"`D;6%R9VEN("L@)&1R;W`L("@D>2`K("1D
M<F]P*2P@)&QI;F4L("1S:&%D;W<I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G
M:6UA9V53=')I;F<G+"!A<G)A>2@D=&AI<RT^7VEM+"`D9BP@)&UA<F=I;BP@
M)'DL("1L:6YE+"`D8V]L;W(I*3L*("`@("`@("`@("`@("`@("1Y("L]("1F
M;VYT:&5I9VAT.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@('T*"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W<R!A('1E>'0@<W1R:6YG(&]N
M('1H92!I;6%G92!I;B!A('-P96-I9FEE9"!L;V-A=&EO;BP@=VET:`H@("`@
M("H@=&AE('-P96-I9FEE9"!S='EL92!I;F9O<FUA=&EO;BX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("`D=&5X="`@("`@("!4:&4@=&5X="!T;R!D
M<F%W+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@@("`@("`@("`@5&AE(&QE
M9G0@>"!C;V]R9&EN871E(&]F('1H92!S=&%R="!O9B!T:&4*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('1E>'0@<W1R:6YG+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)'D@("`@("`@("`@5&AE('1O<"!Y(&-O;W)D:6YA
M=&4@;V8@=&AE('-T87)T(&]F('1H92!T97AT"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!S=')I;F<N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("`D9F]N="`@("`@("!4:&4@9F]N="!I9&5N=&EF:65R('EO=2!W86YT('1O
M('5S92!F;W(@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!T97AT+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&-O;&]R("`@("`@5&AE
M(&-O;&]R('1H870@>6]U('=A;G0@=&AE('1E>'0@9&ES<&QA>65D(&EN+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&1I<F5C=&EO;B`@06X@:6YT96=E<B!T
M:&%T('-P96-I9FEE<R!T:&4@;W)I96YT871I;VX@;V8*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('1H92!T97AT+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!T97AT*"1S=')I;F<L("1X+"`D>2P@)&9O;G0@/2`G;6]N;W-P
M86-E)RP@)&-O;&]R(#T@)V)L86-K)RP@)&1I<F5C=&EO;B`](#`I"B`@("![
M"B`@("`@("`@)&,@/2`D=&AI<RT^86QL;V-A=&5#;VQO<B@D8V]L;W(I.PH@
M("`@("`@(&EF("AI<U]A*"1C+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D8SL*("`@("`@("!]"B`@("`@("`@)&8@/2`D=&AI<RT^
M9V5T1F]N="@D9F]N="D["B`@("`@("`@<W=I=&-H("@D9&ER96-T:6]N*2![
M"B`@("`@("`@8V%S92`M.3`Z"B`@("`@("`@8V%S92`R-S`Z"B`@("`@("`@
M("`@("1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E4W1R:6YG57`G+"!A
M<G)A>2@D=&AI<RT^7VEM+"`D9BP@)'@L("1Y+"`D<W1R:6YG+"`D8RDI.PH@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`P.@H@("`@("`@(&1E
M9F%U;'0Z"B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM
M86=E4W1R:6YG)RP@87)R87DH)'1H:7,M/E]I;2P@)&8L("1X+"`D>2P@)'-T
M<FEN9RP@)&,I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A(&-I<F-L92X*("`@("`J
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>"`@("`@5&AE('@@8V\M;W)D:6YA
M=&4@;V8@=&AE(&-E;G1R92X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y("`@
M("!4:&4@>2!C;RUO<F1I;F%T92!O9B!T:&4@8V5N=')E+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)'(@("`@(%1H92!R861I=7,@;V8@=&AE(&-I<F-L92X*
M("`@("`J($!P87)A;2!S=')I;F<@)&-O;&]R("!4:&4@;&EN92!C;VQO<B!O
M9B!T:&4@8VER8VQE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL;"`@(%1H
M92!C;VQO<B!T;R!F:6QL('1H92!C:7)C;&4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&-I<F-L92@D>"P@)'DL("1R+"`D8V]L;W(L("1F:6QL(#T@;G5L;"D*
M("`@('L*("`@("`@("`D8R`]("1T:&ES+3YA;&QO8V%T94-O;&]R*"1C;VQO
M<BD["B`@("`@("`@:68@*&ES7V$H)&,L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1C.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?
M;G5L;"@D9FEL;"DI('L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?
M8V%L;"@G:6UA9V5%;&QI<'-E)RP@87)R87DH)'1H:7,M/E]I;2P@)'@L("1Y
M+"`D<B`J(#(L("1R("H@,BP@)&,I*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!I9B`H)&9I;&P@(3T]("1C;VQO<BD@>PH@("`@("`@("`@("`@
M("`@)&9I;&Q#;VQO<B`]("1T:&ES+3YA;&QO8V%T94-O;&]R*"1F:6QL*3L*
M("`@("`@("`@("`@("`@(&EF("AI<U]A*"1F:6QL0V]L;W(L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)&9I;&Q#;VQO
M<CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E1FEL;&5D16QL:7!S92<L
M(&%R<F%Y*"1T:&ES+3Y?:6TL("1X+"`D>2P@)'(@*B`R+"`D<B`J(#(L("1F
M:6QL0V]L;W(I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA9V5%;&QI<'-E
M)RP@87)R87DH)'1H:7,M/E]I;2P@)'@L("1Y+"`D<B`J(#(L("1R("H@,BP@
M)&,I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1R
M97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E1FEL;&5D16QL:7!S92<L(&%R
M<F%Y*"1T:&ES+3Y?:6TL("1X+"`D>2P@)'(@*B`R+"`D<B`J(#(L("1C*2D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W(&$@
M<&]L>6=O;B!B87-E9"!O;B!A('-E="!O9B!V97)T:6-E<RX*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@)'9E<G1I8V5S("!!;B!A<G)A>2!O9B!X(&%N
M9"!Y(&QA8F5L960@87)R87ES"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`H96<N("1V97)T:6-E<ULP75LG>"==+"`D=F5R=&EC97-;,%U;)WDG
M72P@+BXN*2X*("`@("`J($!P87)A;2!S=')I;F<@)&-O;&]R("`@(%1H92!C
M;VQO<B!Y;W4@=V%N="!T;R!D<F%W('1H92!P;VQY9V]N('=I=&@N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1F:6QL("`@("!4:&4@8V]L;W(@=&\@9FEL;"!T
M:&4@<&]L>6=O;BX*("`@("`J+PH@("`@9G5N8W1I;VX@<&]L>6=O;B@D=F5R
M=',L("1C;VQO<BP@)&9I;&P@/2`G;F]N92<I"B`@("!["B`@("`@("`@)'9E
M<G1I8V5S(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D=F5R=',@87,@
M)'9E<G0I('L*("`@("`@("`@("`@)'9E<G1I8V5S6UT@/2`D=F5R=%LG>"==
M.PH@("`@("`@("`@("`D=F5R=&EC97-;72`]("1V97)T6R=Y)UT["B`@("`@
M("`@?0H*("`@("`@("!I9B`H)&9I;&P@(3T@)VYO;F4G*2!["B`@("`@("`@
M("`@("1F(#T@)'1H:7,M/F%L;&]C871E0V]L;W(H)&9I;&PI.PH@("`@("`@
M("`@("!I9B`H:7-?82@D9BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1F.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E1FEL;&5D4&]L
M>6=O;B<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1V97)T:6-E<RP@8V]U;G0H)'9E
M<G1S*2P@)&8I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(&EF("@D9FEL;"`]/2`G;F]N92<@?'P@)&9I;&P@(3T@)&-O;&]R*2![
M"B`@("`@("`@("`@("1C(#T@)'1H:7,M/F%L;&]C871E0V]L;W(H)&-O;&]R
M*3L*("`@("`@("`@("`@:68@*&ES7V$H)&,L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D8SL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G
M95!O;'EG;VXG+"!A<G)A>2@D=&AI<RT^7VEM+"`D=F5R=&EC97,L(&-O=6YT
M*"1V97)T<RDL("1C*2DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A(')E8W1A;F=L92X*("`@("`J
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>"`@("`@("!4:&4@;&5F="!X+6-O
M;W)D:6YA=&4@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I;G1E
M9V5R("1Y("`@("`@(%1H92!T;W`@>2UC;V]R9&EN871E(&]F('1H92!R96-T
M86YG;&4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D=VED=&@@("!4:&4@=VED
M=&@@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I;G1E9V5R("1H
M96EG:'0@(%1H92!H96EG:'0@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P
M87)A;2!S=')I;F<@)&-O;&]R("`@(%1H92!L:6YE(&-O;&]R(&]F('1H92!R
M96-T86YG;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QL("`@("!4:&4@
M8V]L;W(@=&\@9FEL;"!T:&4@<F5C=&%N9VQE('=I=&@N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(')E8W1A;F=L92@D>"P@)'DL("1W:61T:"P@)&AE:6=H="P@
M)&-O;&]R(#T@)V)L86-K)RP@)&9I;&P@/2`G;F]N92<I"B`@("!["B`@("`@
M("`@:68@*"1F:6QL("$]("=N;VYE)RD@>PH@("`@("`@("`@("`D9B`]("1T
M:&ES+3YA;&QO8V%T94-O;&]R*"1F:6QL*3L*("`@("`@("`@("`@:68@*&ES
M7V$H)&8L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D9CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H:7-?82@D<F5S
M=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G949I;&QE9%)E8W1A;F=L92<L(&%R
M<F%Y*"1T:&ES+3Y?:6TL("1X+"`D>2P@)'@@*R`D=VED=&@L("1Y("L@)&AE
M:6=H="P@)&8I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(&EF("@D9FEL;"`]/2`G;F]N92<@?'P@)&9I;&P@(3T@)&-O;&]R*2![
M"B`@("`@("`@("`@("1C(#T@)'1H:7,M/F%L;&]C871E0V]L;W(H)&-O;&]R
M*3L*("`@("`@("`@("`@:68@*&ES7V$H)&,L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D8SL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G
M95)E8W1A;F=L92<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1X+"`D>2P@)'@@*R`D
M=VED=&@L("1Y("L@)&AE:6=H="P@)&,I*2P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W(&$@<F]U;F1E
M9"!R96-T86YG;&4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@@
M("`@("`@5&AE(&QE9G0@>"UC;V]R9&EN871E(&]F('1H92!R96-T86YG;&4N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>2`@("`@("!4:&4@=&]P('DM8V]O
M<F1I;F%T92!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)'=I9'1H("`@5&AE('=I9'1H(&]F('1H92!R96-T86YG;&4N"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D:&5I9VAT("!4:&4@:&5I9VAT(&]F('1H92!R
M96-T86YG;&4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]U;F0@("!4:&4@
M=VED=&@@;V8@=&AE(&-O<FYE<B!R;W5N9&EN9RX*("`@("`J($!P87)A;2!S
M=')I;F<@)&-O;&]R("`@(%1H92!L:6YE(&-O;&]R(&]F('1H92!R96-T86YG
M;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QL("`@("!4:&4@8V]L;W(@
M=&\@9FEL;"!T:&4@<F]U;F1E9"!R96-T86YG;&4@=VET:"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<F]U;F1E9%)E8W1A;F=L92@D>"P@)'DL("1W:61T:"P@
M)&AE:6=H="P@)')O=6YD+"`D8V]L;W(@/2`G8FQA8VLG+"`D9FEL;"`]("=N
M;VYE)RD*("`@('L*("`@("`@("!I9B`H)')O=6YD(#P](#`I('L*("`@("`@
M("`@("`@+R\@3W!T:6UI>F4@;W5T(&%N>2!C86QL<R!W:71H(&YO(&-O<FYE
M<B!R;W5N9&EN9RX*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR96-T86YG
M;&4H)'@L("1Y+"`D=VED=&@L("1H96EG:'0L("1C;VQO<BP@)&9I;&PI.PH@
M("`@("`@('T*"B`@("`@("`@)&,@/2`D=&AI<RT^86QL;V-A=&5#;VQO<B@D
M8V]L;W(I.PH@("`@("`@(&EF("AI<U]A*"1C+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D8SL*("`@("`@("!]"@H@("`@("`@("\O
M(%-E="!C;W)N97(@<&]I;G1S('1O(&%V;VED(&QO=',@;V8@<F5D=6YD86YT
M(&UA=&@N"B`@("`@("`@)'@Q(#T@)'@@*R`D<F]U;F0["B`@("`@("`@)'DQ
M(#T@)'D@*R`D<F]U;F0["@H@("`@("`@("1X,B`]("1X("L@)'=I9'1H("T@
M)')O=6YD.PH@("`@("`@("1Y,B`]("1Y("L@)')O=6YD.PH*("`@("`@("`D
M>#,@/2`D>"`K("1W:61T:"`M("1R;W5N9#L*("`@("`@("`D>3,@/2`D>2`K
M("1H96EG:'0@+2`D<F]U;F0["@H@("`@("`@("1X-"`]("1X("L@)')O=6YD
M.PH@("`@("`@("1Y-"`]("1Y("L@)&AE:6=H="`M("1R;W5N9#L*"B`@("`@
M("`@)'(@/2`D<F]U;F0@*B`R.PH*("`@("`@("`O+R!#86QC=6QA=&4@=&AE
M('5P<&5R(&QE9G0@87)C+@H@("`@("`@("1P,2`]("1T:&ES+3Y?87)C4&]I
M;G1S*"1R;W5N9"P@,3@P+"`R,C4I.PH@("`@("`@("1P,B`]("1T:&ES+3Y?
M87)C4&]I;G1S*"1R;W5N9"P@,C(U+"`R-S`I.PH*("`@("`@("`O+R!#86QC
M=6QA=&4@=&AE('5P<&5R(')I9VAT(&%R8RX*("`@("`@("`D<#,@/2`D=&AI
M<RT^7V%R8U!O:6YT<R@D<F]U;F0L(#(W,"P@,S$U*3L*("`@("`@("`D<#0@
M/2`D=&AI<RT^7V%R8U!O:6YT<R@D<F]U;F0L(#,Q-2P@,S8P*3L*"B`@("`@
M("`@+R\@0V%L8W5L871E('1H92!L;W=E<B!R:6=H="!A<F,N"B`@("`@("`@
M)'`U(#T@)'1H:7,M/E]A<F-0;VEN=',H)')O=6YD+"`P+"`T-2D["B`@("`@
M("`@)'`V(#T@)'1H:7,M/E]A<F-0;VEN=',H)')O=6YD+"`T-2P@.3`I.PH*
M("`@("`@("`O+R!#86QC=6QA=&4@=&AE(&QO=V5R(&QE9G0@87)C+@H@("`@
M("`@("1P-R`]("1T:&ES+3Y?87)C4&]I;G1S*"1R;W5N9"P@.3`L(#$S-2D[
M"B`@("`@("`@)'`X(#T@)'1H:7,M/E]A<F-0;VEN=',H)')O=6YD+"`Q,S4L
M(#$X,"D["@H@("`@("`@("\O($1R87<@=&AE(&-O<FYE<G,@+2!U<'!E<B!L
M969T+"!U<'!E<B!R:6=H="P@;&]W97(@<FEG:'0L"B`@("`@("`@+R\@;&]W
M97(@;&5F="X*("`@("`@("!I9B`H:7-?82@D<F5S=6QT(#T@)'1H:7,M/E]C
M86QL*"=I;6%G94%R8R<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1X,2P@)'DQ+"`D
M<BP@)'(L(#$X,"P@,C<P+"`D8RDI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G94%R8R<L(&%R<F%Y
M*"1T:&ES+3Y?:6TL("1X,BP@)'DR+"`D<BP@)'(L(#(W,"P@,S8P+"`D8RDI
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?82@D<F5S=6QT(#T@)'1H:7,M
M/E]C86QL*"=I;6%G94%R8R<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1X,RP@)'DS
M+"`D<BP@)'(L(#`L(#DP+"`D8RDI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G94%R8R<L(&%R<F%Y
M*"1T:&ES+3Y?:6TL("1X-"P@)'DT+"`D<BP@)'(L(#DP+"`Q.#`L("1C*2DL
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("`@("`@?0H*("`@("`@("`O+R!$<F%W('1H92!C;VYN96-T:6YG('-I
M9&5S("T@=&]P+"!R:6=H="P@8F]T=&]M+"!L969T+@H@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E3&EN92<L(&%R<F%Y
M*"1T:&ES+3Y?:6TL("1X,2`K("1P,ELG>#(G72P@)'DQ("L@)'`R6R=Y,B==
M+"`D>#(@*R`D<#-;)W@Q)UTL("1Y,B`K("1P,ULG>3$G72P@)&,I*2P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M("`@("!]"B`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3Y?8V%L
M;"@G:6UA9V5,:6YE)RP@87)R87DH)'1H:7,M/E]I;2P@)'@R("L@)'`T6R=X
M,B==+"`D>3(@*R`D<#1;)WDR)UTL("1X,R`K("1P-5LG>#$G72P@)'DS("L@
M)'`U6R=Y,2==+"`D8RDI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G94QI;F4G+"!A<G)A>2@D=&AI
M<RT^7VEM+"`D>#,@*R`D<#9;)W@R)UTL("1Y,R`K("1P-ELG>3(G72P@)'@T
M("L@)'`W6R=X,2==+"`D>30@*R`D<#=;)WDQ)UTL("1C*2DL("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M?0H@("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM
M86=E3&EN92<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1X-"`K("1P.%LG>#(G72P@
M)'DT("L@)'`X6R=Y,B==+"`D>#$@*R`D<#%;)W@Q)UTL("1Y,2`K("1P,5LG
M>3$G72P@)&,I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@(&EF("@D9FEL;"`A/2`G
M;F]N92<I('L*("`@("`@("`@("`@)&8@/2`D=&AI<RT^86QL;V-A=&5#;VQO
M<B@D9FEL;"D["B`@("`@("`@("`@(&EF("AI<U]A*"1F+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&8["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3Y?8V%L
M;"@G:6UA9V5&:6QL5&]";W)D97(G+"!A<G)A>2@D=&AI<RT^7VEM+"`D>"`K
M("@D=VED=&@@+R`R*2P@)'D@*R`H)&AE:6=H="`O(#(I+"`D8RP@)&8I*2P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!$<F%W(&$@;&EN92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D>#`@("`@5&AE('@@8V\M;W)D:6YA=&4@;V8@=&AE('-T87)T+@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)'DP("`@(%1H92!Y(&-O+6]R9&EN871E(&]F
M('1H92!S=&%R="X*("`@("`J($!P87)A;2!I;G1E9V5R("1X,2`@("!4:&4@
M>"!C;RUO<F1I;F%T92!O9B!T:&4@96YD+@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)'DQ("`@(%1H92!Y(&-O+6]R9&EN871E(&]F('1H92!E;F0N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1C;VQO<B`@5&AE(&QI;F4@8V]L;W(N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1W:61T:"`@5&AE('=I9'1H(&]F('1H92!L:6YE
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:6YE*"1X,2P@)'DQ+"`D>#(L("1Y
M,BP@)&-O;&]R(#T@)V)L86-K)RP@)'=I9'1H(#T@,2D*("`@('L*("`@("`@
M("`D8R`]("1T:&ES+3YA;&QO8V%T94-O;&]R*"1C;VQO<BD["B`@("`@("`@
M:68@*&ES7V$H)&,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1C.PH@("`@("`@('T*"B`@("`@("`@+R\@1&]N)W0@;F5E9"!T;R!D
M;R!A;GET:&EN9R!S<&5C:6%L(&9O<B!S:6YG;&4M=VED=&@@;&EN97,N"B`@
M("`@("`@:68@*"1W:61T:"`]/2`Q*2!["B`@("`@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^7V-A;&PH)VEM86=E3&EN92<L(&%R<F%Y*"1T:&ES+3Y?:6TL
M("1X,2P@)'DQ+"`D>#(L("1Y,BP@)&,I*3L*("`@("`@("!](&5L<V5I9B`H
M)'@Q(#T]("1X,BD@>PH@("`@("`@("`@("`O+R!&;W(@=F5R=&EC86P@;&EN
M97,L('=E(&-A;B!J=7-T(&1R87<@82!V97)T:6-A;`H@("`@("`@("`@("`O
M+R!R96-T86YG;&4N"B`@("`@("`@("`@("1L969T(#T@)'@Q("T@9FQO;W(H
M*"1W:61T:"`M(#$I("\@,BD["B`@("`@("`@("`@("1R:6=H="`]("1X,2`K
M(&9L;V]R*"1W:61T:"`O(#(I.PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H
M:7,M/E]C86QL*"=I;6%G949I;&QE9%)E8W1A;F=L92<L(&%R<F%Y*"1T:&ES
M+3Y?:6TL("1L969T+"`D>3$L("1R:6=H="P@)'DR+"`D8RDI.PH@("`@("`@
M('T@96QS96EF("@D>3$@/3T@)'DR*2!["B`@("`@("`@("`@("\O($9O<B!H
M;W)I>F]N=&%L(&QI;F5S+"!W92!C86X@:G5S="!D<F%W(&$@:&]R:7IO;G1A
M;`H@("`@("`@("`@("`O+R!F:6QL960@<F5C=&%N9VQE+@H@("`@("`@("`@
M("`D=&]P(#T@)'DQ("T@9FQO;W(H)'=I9'1H("\@,BD["B`@("`@("`@("`@
M("1B;W1T;VT@/2`D>3$@*R!F;&]O<B@H)'=I9'1H("T@,2D@+R`R*3L*("`@
M("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA9V5&:6QL9612
M96-T86YG;&4G+"!A<G)A>2@D=&AI<RT^7VEM+"`D>#$L("1T;W`L("1X,BP@
M)&)O='1O;2P@)&,I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O
M+R!!;F=L960@;&EN97,N"@H@("`@("`@("`@("`O+R!-86ME('-U<F4@=&AA
M="!T:&4@96YD('!O:6YT<R!O9B!T:&4@;&EN92!A<F4*("`@("`@("`@("`@
M+R\@<&5R<&5N9&EC=6QA<B!T;R!T:&4@;&EN92!I='-E;&8N"B`@("`@("`@
M("`@("1A(#T@871A;C(H)'DQ("T@)'DR+"`D>#(@+2`D>#$I.PH@("`@("`@
M("`@("`D9'@@/2`H<VEN*"1A*2`J("1W:61T:"`O(#(I.PH@("`@("`@("`@
M("`D9'D@/2`H8V]S*"1A*2`J("1W:61T:"`O(#(I.PH*("`@("`@("`@("`@
M)'9E<G1S(#T@87)R87DH)'@R("L@)&1X+"`D>3(@*R`D9'DL("1X,B`M("1D
M>"P@)'DR("T@)&1Y+"`D>#$@+2`D9'@L("1Y,2`M("1D>2P@)'@Q("L@)&1X
M+"`D>3$@*R`D9'DI.PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]C
M86QL*"=I;6%G949I;&QE9%!O;'EG;VXG+"!A<G)A>2@D=&AI<RT^7VEM+"`D
M=F5R=',L(&-O=6YT*"1V97)T<RD@+R`R+"`D8RDI.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$
M<F%W(&$@9&%S:&5D(&QI;F4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)'@P("`@("`@("`@("!4:&4@>"!C;RUO<F1I;F%T92!O9B!T:&4@<W1A
M<G0N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>3`@("`@("`@("`@(%1H92!Y
M(&-O+6]R9&EN871E(&]F('1H92!S=&%R="X*("`@("`J($!P87)A;2!I;G1E
M9V5R("1X,2`@("`@("`@("`@5&AE('@@8V\M;W)D:6YA=&4@;V8@=&AE(&5N
M9"X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y,2`@("`@("`@("`@5&AE('D@
M8V\M;W)D:6YA=&4@;V8@=&AE(&5N9"X*("`@("`J($!P87)A;2!S=')I;F<@
M)&-O;&]R("`@("`@("`@5&AE(&QI;F4@8V]L;W(N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1W:61T:"`@("`@("`@(%1H92!W:61T:"!O9B!T:&4@;&EN92X*
M("`@("`J($!P87)A;2!I;G1E9V5R("1D87-H7VQE;F=T:"`@5&AE(&QE;F=T
M:"!O9B!A(&1A<V@@;VX@=&AE(&1A<VAE9"!L:6YE"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D9&%S:%]S<&%C92`@(%1H92!L96YG=&@@;V8@82!S<&%C92!I
M;B!T:&4@9&%S:&5D(&QI;F4*("`@("`J+PH@("`@9G5N8W1I;VX@9&%S:&5D
M3&EN92@D>#`L("1Y,"P@)'@Q+"`D>3$L("1C;VQO<B`]("=B;&%C:R<L("1W
M:61T:"`](#$L("1D87-H7VQE;F=T:"`](#(L("1D87-H7W-P86-E(#T@,BD*
M("`@('L*("`@("`@("`D8R`]("1T:&ES+3YA;&QO8V%T94-O;&]R*"1C;VQO
M<BD["B`@("`@("`@:68@*&ES7V$H)&,L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1C.PH@("`@("`@('T*("`@("`@("`D=R`]("1T
M:&ES+3YA;&QO8V%T94-O;&]R*"=W:&ET92<I.PH@("`@("`@(&EF("AI<U]A
M*"1W+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D=SL*
M("`@("`@("!]"@H@("`@("`@("\O(%-E="!U<"!T:&4@<W1Y;&4@87)R87D@
M86-C;W)D:6YG('1O('1H92`D9&%S:%\J('!A<F%M971E<G,N"B`@("`@("`@
M)'-T>6QE(#T@87)R87DH*3L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D
M9&%S:%]L96YG=&@[("1I*RLI('L*("`@("`@("`@("`@)'-T>6QE6UT@/2`D
M8SL*("`@("`@("!]"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&1A<VA?
M<W!A8V4[("1I*RLI('L*("`@("`@("`@("`@)'-T>6QE6UT@/2`D=SL*("`@
M("`@("!]"@H@("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A
M;&PH)VEM86=E4V5T4W1Y;&4G+"!A<G)A>2@D=&AI<RT^7VEM+"`D<W1Y;&4I
M*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@("`@("!]"B`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T:&ES
M+3Y?8V%L;"@G:6UA9V539714:&EC:VYE<W,G+"!A<G)A>2@D=&AI<RT^7VEM
M+"`D=VED=&@I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M8V%L;"@G:6UA9V5,:6YE)RP@87)R87DH)'1H:7,M/E]I;2P@)'@P+"`D>3`L
M("1X,2P@)'DQ+"!)34=?0T],3U)?4U193$5$*2D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!$<F%W(&$@<&]L>6QI;F4@*&$@;F]N+6-L;W-E9"P@;F]N+69I
M;&QE9"!P;VQY9V]N*2!B87-E9"!O;B!A"B`@("`@*B!S970@;V8@=F5R=&EC
M97,N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1V97)T:6-E<R`@06X@
M87)R87D@;V8@>"!A;F0@>2!L86)E;&5D(&%R<F%Y<PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@*&5G+B`D=F5R=&EC97-;,%U;)W@G72P@)'9E
M<G1I8V5S6S!=6R=Y)UTL("XN+BDN"B`@("`@*B!`<&%R86T@<W1R:6YG("1C
M;VQO<B`@("!4:&4@8V]L;W(@>6]U('=A;G0@=&\@9')A=R!T:&4@;&EN92!W
M:71H+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=VED=&@@("`@5&AE('=I9'1H
M(&]F('1H92!L:6YE+@H@("`@("HO"B`@("!F=6YC=&EO;B!P;VQY;&EN92@D
M=F5R=',L("1C;VQO<BP@)'=I9'1H(#T@,2D*("`@('L*("`@("`@("`D9FER
M<W0@/2!T<G5E.PH@("`@("`@(&9O<F5A8V@@*"1V97)T<R!A<R`D=F5R="D@
M>PH@("`@("`@("`@("!I9B`H(21F:7)S="D@>PH@("`@("`@("`@("`@("`@
M:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3YL:6YE*"1L87-T6"P@)&QA<W19
M+"`D=F5R=%LG>"==+"`D=F5R=%LG>2==+"`D8V]L;W(L("1W:61T:"DL("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1F:7)S="`](&9A;'-E.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1L87-T6"`]("1V97)T6R=X)UT["B`@("`@("`@("`@
M("1L87-T62`]("1V97)T6R=Y)UT["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@1')A=R!A;B!A<F,N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)'@@("`@("!4:&4@>"!C;RUO<F1I;F%T92!O9B!T:&4@8V5N=')E
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'D@("`@("!4:&4@>2!C;RUO<F1I
M;F%T92!O9B!T:&4@8V5N=')E+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'(@
M("`@("!4:&4@<F%D:75S(&]F('1H92!A<F,N"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D<W1A<G0@(%1H92!S=&%R="!A;F=L92!O9B!T:&4@87)C+@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&5N9"`@("!4:&4@96YD(&%N9VQE(&]F('1H
M92!A<F,N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D8V]L;W(@(%1H92!L:6YE
M(&-O;&]R(&]F('1H92!A<F,N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D9FEL
M;"`@(%1H92!F:6QL(&-O;&]R(&]F('1H92!A<F,@*&1E9F%U;'1S('1O(&YO
M;F4I+@H@("`@("HO"B`@("!F=6YC=&EO;B!A<F,H)'@L("1Y+"`D<BP@)'-T
M87)T+"`D96YD+"`D8V]L;W(@/2`G8FQA8VLG+"`D9FEL;"`](&YU;&PI"B`@
M("!["B`@("`@("`@)&,@/2`D=&AI<RT^86QL;V-A=&5#;VQO<B@D8V]L;W(I
M.PH@("`@("`@(&EF("AI<U]A*"1C+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D8SL*("`@("`@("!]"B`@("`@("`@:68@*&ES7VYU
M;&PH)&9I;&PI*2!["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V-A
M;&PH)VEM86=E07)C)RP@87)R87DH)'1H:7,M/E]I;2P@)'@L("1Y+"`D<B`J
M(#(L("1R("H@,BP@)'-T87)T+"`D96YD+"`D8RDI.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(&EF("@D9FEL;"`A/3T@)&-O;&]R*2!["B`@("`@
M("`@("`@("`@("`D9B`]("1T:&ES+3YA;&QO8V%T94-O;&]R*"1F:6QL*3L*
M("`@("`@("`@("`@("`@(&EF("AI<U]A*"1F+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1F.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T:&ES
M+3Y?8V%L;"@G:6UA9V5&:6QL961!<F,G+"!A<G)A>2@D=&AI<RT^7VEM+"`D
M>"P@)'DL("1R("H@,BP@)'(@*B`R+"`D<W1A<G0L("1E;F0L("1F+"!)34=?
M05)#7U!)12DI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G949I;&QE9$%R
M8R<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1X+"`D>2P@)'(@*B`R+"`D<B`J(#(L
M("1S=&%R="P@)&5N9"P@)&,L($E-1U]!4D-?141'140@?"!)34=?05)#7TY/
M1DE,3"DI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA9V5&:6QL961!<F,G+"!A<G)A
M>2@D=&AI<RT^7VEM+"`D>"P@)'DL("1R("H@,BP@)'(@*B`R+"`D<W1A<G0L
M("1E;F0L("1C+"!)34=?05)#7U!)12DI.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@("\J*@H@
M("`@("H@0W)E871E<R!A;B!I;6%G92!O9B!T:&4@9VEV96X@<VEZ92X*("`@
M("`J($EF('!O<W-I8FQE('1H92!F=6YC=&EO;B!R971U<FYS(&$@=')U92!C
M;VQO<B!I;6%G92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D=VED
M=&@@("!4:&4@:6UA9V4@=VED=&@N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M:&5I9VAT("!4:&4@:6UA9V4@:&5I9VAT+@H@("`@("H*("`@("`J($!R971U
M<FX@<F5S;W5R8V5\;V)J96-T(%!%05(@17)R;W(@(%1H92!I;6%G92!H86YD
M;&5R(&]R(&$@4$5!4E]%<G)O<B!O;@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N("9?8W)E871E*"1W:61T:"P@)&AE:6=H="D*("`@('L*("`@("`@("`D
M<F5S=6QT(#T@)B1T:&ES+3Y?8V%L;"@G:6UA9V5#<F5A=&54<G5E0V]L;W(G
M+"!A<G)A>2@D=VED=&@L("1H96EG:'0I*3L*("`@("`@("!I9B`H(6ES7W)E
M<V]U<F-E*"1R97-U;'0I*2!["B`@("`@("`@("`@("1R97-U;'0@/2`F)'1H
M:7,M/E]C86QL*"=I;6%G94-R96%T92<L(&%R<F%Y*"1W:61T:"P@)&AE:6=H
M="DI.PH@("`@("`@('T*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*
M"B`@("`O*BH*("`@("`J(%=R87!S(&$@8V%L;"!T;R!A(&9U;F-T:6]N(&]F
M('1H92!G9"!E>'1E;G-I;VXN"B`@("`@*B!)9B!T:&4@8V%L;"!P<F]D=6-E
M<R!A;B!E<G)O<BP@82!014%27T5R<F]R(&ES(')E='5R;F5D+"!T:&4@9G5N
M8W1I;VX*("`@("`J(')E<W5L="!O=&AE<G=I<V4N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D9G5N8W1I;VX@(%1H92!N86UE(&]F('1H92!F=6YC
M=&EO;B!T;R!W<F%P+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("`@
M($%N(&%R<F%Y('=I=&@@86QL('!A<F%M971E<G,@9F]R('1H870@9G5N8W1I
M;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@16ET:&5R('1H92!F
M=6YC=&EO;B!R97-U;'0@;W(@82!014%27T5R<F]R(&EF(&%N(&5R<F]R"B`@
M("`@*B`@("`@("`@("`@("`@("!O8V-U<F5D('=H96X@97AE8W5T:6YG('1H
M92!F=6YC=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@)E]C86QL*"1F=6YC
M=&EO;BP@)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@=6YS970H)'!H
M<%]E<G)O<FUS9RD["B`@("`@("`@)'1R86-K(#T@:6YI7W-E="@G=')A8VM?
M97)R;W)S)RP@,2D["B`@("`@("`@)')E<W5L="`]($!C86QL7W5S97)?9G5N
M8U]A<G)A>2@D9G5N8W1I;VXL("1P87)A;7,I.PH@("`@("`@(&EF("@D=')A
M8VL@(3T](&9A;'-E*2!["B`@("`@("`@("`@(&EN:5]S970H)W1R86-K7V5R
M<F]R<R<L("1T<F%C:RD["B`@("`@("`@?0H@("`@("`@(&EF("@A96UP='DH
M)'!H<%]E<G)O<FUS9RDI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=0
M14%2+G!H<"<["B`@("`@("`@("`@("1R97-U;'0@/2!014%2.CIR86ES945R
M<F]R*"1F=6YC=&EO;B`N("<Z("<@+B`D<&AP7V5R<F]R;7-G*3L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@I]"@``````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]);6%G92]I;2YP:'``````````
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`S-S,T-B`Q,#4Q-30S
M,S<S-2`P,C$U,C4`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O26UA9V4N<&AP
M)SL*"B\J*@H@*B!4:&ES(&-L87-S(&EM<&QE;65N=',@=&AE($AO<F1E7TEM
M86=E.CH@05!)(&9O<B!);6%G94UA9VEC:RX*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO26UA9V4O26UA9V4O:6TN<&AP+'8@,2XS-"XQ,"XQ,2`R,#`V+S`Q
M+S`Q(#(Q.C(X.C(R(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR
M,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y
M<FEG:'0@,C`P,RTR,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA
M;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(
M86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@36EK92!#
M;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@
M2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TEM86=E"B`J+PIC;&%S<R!(
M;W)D95]);6%G95]I;2!E>'1E;F1S($AO<F1E7TEM86=E('L*"B`@("`O*BH*
M("`@("`J($-A<&%B:6QI=&5S(&]F('1H:7,@9')I=F5R+@H@("`@("H*("`@
M("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?8V%P86)I;&ET:65S
M(#T@87)R87DH)W)E<VEZ92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G8W)O<"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M<F]T871E)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=G<F%Y
M<V-A;&4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V9L:7`G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VUI<G)O<B<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<V5P:6$G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)V-A;G9A<R<*("`@("`@("`@("`@
M("`@("`@("`@("`@("D["@H@("`@+RHJ"B`@("`@*B!7:&%T(&MI;F0@;V8@
M:6UA9V5S('-H;W5L9"!);6%G94UA9VEC:R!G96YE<F%T93\@1&5F875L=',@
M=&\@)W!N9R<N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@
M("`@=F%R("1?='EP92`]("=P;F<G.PH*("`@("\J*@H@("`@("H@3W!E<F%T
M:6]N<R!T;R!B92!P97)F;W)M960N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)%]O<&5R871I;VYS(#T@87)R87DH*3L*"B`@
M("`O*BH*("`@("`J($-U<G)E;G0@<W1R;VME(&-O;&]R.R!C86-H960@<V\@
M=V4@9&]N)W0@:7-S=64@;6]R92`M<W1R;VME(&-O;6UA;F1S"B`@("`@*B!T
M:&%N(&YE8V5S<V%R>2X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)%]S=')O:V5#;VQO<B`](&YU;&P["@H@("`@+RHJ"B`@
M("`@*B!#=7)R96YT('-T<F]K92!W:61T:#L@8V%C:&5D('-O('=E(&1O;B=T
M(&ES<W5E(&UO<F4@+7-T<F]K97=I9'1H"B`@("`@*B!C;VUM86YD<R!T:&%N
M(&YE8V5S<V%R>2X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO
M"B`@("!V87(@)%]S=')O:V57:61T:"`](&YU;&P["@H@("`@+RHJ"B`@("`@
M*B!#=7)R96YT(&9I;&P@8V]L;W([(&-A8VAE9"!S;R!W92!D;VXG="!I<W-U
M92!M;W)E("UF:6QL(&-O;6UA;F1S('1H86X*("`@("`J(&YE8V5S<V%R>2X*
M("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]F
M:6QL0V]L;W(@/2!N=6QL.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N
M"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7TEM86=E7VEM*"1P87)A;7,I
M"B`@("!["B`@("`@("`@<&%R96YT.CI(;W)D95]);6%G92@D<&%R86US*3L*
M"B`@("`@("`@:68@*"%E;7!T>2@D<&%R86US6R=T>7!E)UTI*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?='EP92`]("1P87)A;7-;)W1Y<&4G73L*("`@("`@
M("!]"@H@("`@("`@("\O($UA:V4@<W5R92!W92!S=&%R="!W:71H(&$@=VAI
M=&4@8F%C:V=R;W5N9"!T;R!B92!C;VYS:7-T96YT"B`@("`@("`@+R\@=VET
M:"!O=&AE<B!D<FEV97)S+@H@("`@("`@(&EF("@A96UP='DH)'!A<F%M<ULG
M8F%C:V=R;W5N9"==*2D@>PH@("`@("`@("`@("`D8F<@/2`D<&%R86US6R=B
M86-K9W)O=6YD)UT["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&)G
M(#T@)W=H:71E)SL*("`@("`@("!]"B`@("`@("`@)'1H:7,M/G)E8W1A;F=L
M92@P+"`P+"`D=&AI<RT^7W=I9'1H+"`D=&AI<RT^7VAE:6=H="P@)&)G+"`D
M8F<I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!C;VYT96YT
M('1Y<&4@9F]R('1H:7,@:6UA9V4N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!C;VYT96YT('1Y<&4@9F]R('1H:7,@:6UA9V4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$-O;G1E;G14>7!E*"D*("`@('L*("`@("`@
M("!R971U<FX@)VEM86=E+R<@+B`D=&AI<RT^7W1Y<&4["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('1H92!R87<@9&%T82!F;W(@=&AI<R!I;6%G
M92X*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D8V]N=F5R="`@268@
M=')U92P@=&AE(&EM86=E(&1A=&$@=VEL;"!B92!R971U<FYE9"!I;B!T:&4*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!T87)G970@9F]R;6%T
M+"!I;F1E<&5N9&5N=&QY(&9R;VT@86YY(&EM86=E"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@;W!E<F%T:6]N<RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(')A=R!I;6%G92!D871A+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!R87<H)&-O;G9E<G0@/2!F86QS92D*("`@('L*("`@("`@
M("!G;&]B86P@)&-O;F8["@H@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]D
M871A*2D@>PH@("`@("`@("`@("`O+R!)9B!T:&5R92!A<F4@;F\@;W!E<F%T
M:6]N<RP@86YD('=E(&%L<F5A9'D@:&%V92!D871A+`H@("`@("`@("`@("`O
M+R!D;VXG="!B;W1H97(@=W)I=&EN9R!O=70@9FEL97,L(&IU<W0@<F5T=7)N
M('1H92!C=7)R96YT"B`@("`@("`@("`@("\O(&1A=&$N"B`@("`@("`@("`@
M(&EF("@A)&-O;G9E<G0@)B8@(6-O=6YT*"1T:&ES+3Y?;W!E<F%T:6]N<RDI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1A=&$["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1T;7!I;B`]("1T:&ES+3YT;T9I;&4H
M)'1H:7,M/E]D871A*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O
M+R!#<F5A=&4@86X@96UP='D@4%!-(&9I;&4@=&\@;&]A9"X*("`@("`@("`@
M("`@)'1M<&EN(#T@571I;#HZ9V5T5&5M<$9I;&4H)VEM9R<L(&9A;'-E+"`D
M=&AI<RT^7W1M<&1I<BD["B`@("`@("`@("`@("1F<"`](&9O<&5N*"1T;7!I
M;BP@)W=B)RD["B`@("`@("`@("`@(&9W<FET92@D9G`L('-P<FEN=&8H(E`S
M7&XE9"`E9%QN,C4U7&X@(BP@)'1H:7,M/E]W:61T:"P@)'1H:7,M/E]H96EG
M:'0I*3L*("`@("`@("`@("`@9F-L;W-E*"1F<"D["B`@("`@("`@?0H*("`@
M("`@("`D=&UP;W5T(#T@571I;#HZ9V5T5&5M<$9I;&4H)VEM9R<L(&9A;'-E
M+"`D=&AI<RT^7W1M<&1I<BD["@H@("`@("`@("1C;VUM86YD("`]("1C;VYF
M6R=I;6%G92==6R=C;VYV97)T)UT["B`@("`@("`@)&-O;6UA;F0@+CT@)R`G
M("X@:6UP;&]D92@G("<L("1T:&ES+3Y?;W!E<F%T:6]N<RD["B`@("`@("`@
M)&-O;6UA;F0@+CT@)R`B)R`N("1T;7!I;B`N("<B("MP<F]F:6QE("(J(B`G
M("X@)'1H:7,M/E]T>7!E("X@)SHB)R`N("1T;7!O=70@+B`G(B`R/B8Q)SL*
M"B`@("`@("`@97AE8R@D8V]M;6%N9"P@)&]U='!U="P@)')E='9A;"D["@H@
M("`@("`@("1T:&ES+3Y?9&%T82`](&9I;&5?9V5T7V-O;G1E;G1S*"1T;7!O
M=70I.PH*("`@("`@("!`=6YL:6YK*"1T;7!I;BD["B`@("`@("`@0'5N;&EN
M:R@D=&UP;W5T*3L*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&%T83L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E<V5T('1H92!I;6%G92!D871A+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!R97-E="@I"B`@("!["B`@("`@("`@<&%R96YT
M.CIR97-E="@I.PH@("`@("`@("1T:&ES+3Y?;W!E<F%T:6]N<R`](&%R<F%Y
M*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!297-I>F4@=&AE(&-U<G)E;G0@
M:6UA9V4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'=I9'1H("`@
M5&AE(&YE=R!W:61T:"X*("`@("`J($!P87)A;2!I;G1E9V5R("1H96EG:'0@
M(%1H92!N97<@:&5I9VAT+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)')A=&EO
M("`@36%I;G1A:6X@;W)I9VEN86P@87-P96-T(')A=&EO+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!R97-I>F4H)'=I9'1H+"`D:&5I9VAT+"`D<F%T:6\@/2!T
M<G5E*0H@("`@>PH@("`@("`@(&EF("@D<F%T:6\I('L*("`@("`@("`@("`@
M)'1H:7,M/E]O<&5R871I;VYS6UT@/2`B+7-I>F4@>R1W:61T:'UX>R1H96EG
M:'1]("UR97-I>F4@>R1W:61T:'UX>R1H96EG:'1](CL*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D=&AI<RT^7V]P97)A=&EO;G-;72`]("(M<VEZ
M92![)'=I9'1H?7A[)&AE:6=H='T@+7)E<VEZ92![)'=I9'1H?7A[)&AE:6=H
M='TA(CL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F]P('1H
M92!C=7)R96YT(&EM86=E+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R
M("1X,2`@5&AE('1O<"!L969T(&-O<FYE<B!O9B!T:&4@8W)O<'!E9"!I;6%G
M92X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y,2`@5&AE('1O<"!R:6=H="!C
M;W)N97(@;V8@=&AE(&-R;W!P960@:6UA9V4N"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D>#(@(%1H92!B;W1T;VT@;&5F="!C;W)N97(@;V8@=&AE(&-R;W!P
M960@:6UA9V4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>3(@(%1H92!B;W1T
M;VT@<FEG:'0@8V]R;F5R(&]F('1H92!C<F]P<&5D(&EM86=E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!C<F]P*"1X,2P@)'DQ+"`D>#(L("1Y,BD*("`@('L*
M("`@("`@("`D;&EN92`]("@D>#(@+2`D>#$I("X@)W@G("X@*"1Y,B`M("1Y
M,2D@+B`G*R<@+B`D>#$@+B`G*R<@+B`D>3(["B`@("`@("`@)'1H:7,M/E]O
M<&5R871I;VYS6UT@/2`G+6-R;W`@)R`N("1L:6YE.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F]T871E('1H92!C=7)R96YT(&EM86=E+@H@("`@("H*("`@
M("`J($!P87)A;2!I;G1E9V5R("1A;F=L92`@("`@("!4:&4@86YG;&4@=&\@
M<F]T871E('1H92!I;6%G92!B>2P*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!I;B!T:&4@8VQO8VMW:7-E(&1I<F5C=&EO;BX*("`@("`J
M($!P87)A;2!I;G1E9V5R("1B86-K9W)O=6YD("!4:&4@8F%C:V=R;W5N9"!C
M;VQO<B!T;R!F:6QL(&%N>2!T<FEA;F=L97,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(')O=&%T92@D86YG;&4L("1B86-K9W)O=6YD(#T@)W=H:71E)RD*("`@
M('L*("`@("`@("`D=&AI<RT^7V]P97)A=&EO;G-;72`]("(M<F]T871E('LD
M86YG;&5]("UB86-K9W)O=6YD("1B86-K9W)O=6YD(CL*("`@('T*"B`@("`O
M*BH*("`@("`J($9L:7`@=&AE(&-U<G)E;G0@:6UA9V4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&9L:7`H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;W!E<F%T
M:6]N<UM=(#T@)RUF;&EP)SL*("`@('T*"B`@("`O*BH*("`@("`J($UI<G)O
M<B!T:&4@8W5R<F5N="!I;6%G92X*("`@("`J+PH@("`@9G5N8W1I;VX@;6ER
M<F]R*"D*("`@('L*("`@("`@("`D=&AI<RT^7V]P97)A=&EO;G-;72`]("<M
M9FQO<"<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T('1H92!C=7)R
M96YT(&EM86=E('1O(&=R87ES8V%L92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9W)A>7-C86QE*"D*("`@('L*("`@("`@("`D=&AI<RT^7V]P97)A=&EO;G-;
M72`]("<M8V]L;W)S<&%C92!'4D%9("UC;VQO<G,@,C4V)SL*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E<&EA(&9I;'1E<BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@<V5P:6$H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;W!E<F%T:6]N<UM=
M(#T@)RUM;V1U;&%T92`Q,3`@+6-O;&]R<W!A8V4@1U)!62`M8V]L;W)S(#(U
M-B`M9V%M;6$@,2XR-2\Q+S`N-C8G.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1')A=W,@82!T97AT('-T<FEN9R!O;B!T:&4@:6UA9V4@:6X@82!S<&5C:69I
M960@;&]C871I;VXL('=I=&@*("`@("`J('1H92!S<&5C:69I960@<W1Y;&4@
M:6YF;W)M871I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'1E
M>'0@("`@("`@5&AE('1E>'0@=&\@9')A=RX*("`@("`J($!P87)A;2!I;G1E
M9V5R("1X("`@("`@("`@(%1H92!L969T('@@8V]O<F1I;F%T92!O9B!T:&4@
M<W1A<G0@;V8@=&AE('1E>'0@<W1R:6YG+@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)'D@("`@("`@("`@5&AE('1O<"!Y(&-O;W)D:6YA=&4@;V8@=&AE('-T
M87)T(&]F('1H92!T97AT('-T<FEN9RX*("`@("`J($!P87)A;2!S=')I;F<@
M("1F;VYT("`@("`@(%1H92!F;VYT(&ED96YT:69I97(@>6]U('=A;G0@=&\@
M=7-E(&9O<B!T:&4@=&5X="X*("`@("`J($!P87)A;2!S=')I;F<@("1C;VQO
M<B`@("`@(%1H92!C;VQO<B!T:&%T('EO=2!W86YT('1H92!T97AT(&1I<W!L
M87EE9"!I;BX*("`@("`J($!P87)A;2!I;G1E9V5R("1D:7)E8W1I;VX@($%N
M(&EN=&5G97(@=&AA="!S<&5C:69I97,@=&AE(&]R:65N=&%T:6]N(&]F('1H
M92!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!T97AT*"1S=')I;F<L("1X
M+"`D>2P@)&9O;G0@/2`G7W-A;G,G+"`D8V]L;W(@/2`G8FQA8VLG+"`D9&ER
M96-T:6]N(#T@,"D*("`@('L*("`@("`@("`D=&AI<RT^<V5T4W1R;VME0V]L
M;W(H)&-O;&]R*3L*("`@("`@("`D=&AI<RT^<V5T4W1R;VME5VED=&@H,2D[
M"@H@("`@("`@("1S=')I;F<@/2!A9&1S;&%S:&5S*"<B)R`N("1S=')I;F<@
M+B`G(B<I.PH@("`@("`@("1Y(#T@)'D@*R`Q,CL*("`@("`@("`D=&AI<RT^
M7V]P97)A=&EO;G-;72`]("(M9')A=R!<(G1E>'0@)'@L)'D@)'-T<FEN9UPB
M(CL*("`@('T*"B`@("`O*BH*("`@("`J($1R87<@82!C:7)C;&4N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@@("`@(%1H92!X(&-O;W)D:6YA
M=&4@;V8@=&AE(&-E;G1R92X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y("`@
M("!4:&4@>2!C;V]R9&EN871E(&]F('1H92!C96YT<F4N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D<B`@("`@5&AE(')A9&EU<R!O9B!T:&4@8VER8VQE+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D8V]L;W(@(%1H92!L:6YE(&-O;&]R(&]F
M('1H92!C:7)C;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QL("`@5&AE
M(&-O;&]R('1O(&9I;&P@=&AE(&-I<F-L92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@8VER8VQE*"1X+"`D>2P@)'(L("1C;VQO<BP@)&9I;&P@/2`G;F]N92<I
M"B`@("!["B`@("`@("`@)'1H:7,M/G-E=%-T<F]K94-O;&]R*"1C;VQO<BD[
M"B`@("`@("`@)'1H:7,M/G-E=$9I;&Q#;VQO<B@D9FEL;"D["@H@("`@("`@
M("1X36%X(#T@)'@@*R`D<CL*("`@("`@("`D=&AI<RT^7V]P97)A=&EO;G-;
M72`]("(M9')A=R!<(F-I<F-L92`D>"PD>2`D>$UA>"PD>5PB(CL*("`@('T*
M"B`@("`O*BH*("`@("`J($1R87<@82!P;VQY9V]N(&)A<V5D(&]N(&$@<V5T
M(&]F('9E<G1I8V5S+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D=F5R
M=&EC97,@($%N(&%R<F%Y(&]F('@@86YD('D@;&%B96QE9"!A<G)A>7,*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("AE9RX@)'9E<G1I8V5S6S!=
M6R=X)UTL("1V97)T:6-E<ULP75LG>2==+"`N+BXI+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D8V]L;W(@("`@5&AE(&-O;&]R('EO=2!W86YT('1O(&1R87<@
M=&AE('!O;'EG;VX@=VET:"X*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&P@
M("`@(%1H92!C;VQO<B!T;R!F:6QL('1H92!P;VQY9V]N+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!P;VQY9V]N*"1V97)T<RP@)&-O;&]R+"`D9FEL;"`]("=N
M;VYE)RD*("`@('L*("`@("`@("`D=&AI<RT^<V5T4W1R;VME0V]L;W(H)&-O
M;&]R*3L*("`@("`@("`D=&AI<RT^<V5T1FEL;$-O;&]R*"1F:6QL*3L*"B`@
M("`@("`@)&-O;6UA;F0@/2`G)SL*("`@("`@("!F;W)E86-H("@D=F5R=',@
M87,@)'9E<G0I('L*("`@("`@("`@("`@)&-O;6UA;F0@+CT@<W!R:6YT9B@G
M("5D+"5D)RP@)'9E<G1;)W@G72P@)'9E<G1;)WDG72D["B`@("`@("`@?0H@
M("`@("`@("1T:&ES+3Y?;W!E<F%T:6]N<UM=(#T@(BUD<F%W(%PB<&]L>6=O
M;B`D8V]M;6%N9%PB(CL*("`@('T*"B`@("`O*BH*("`@("`J($1R87<@82!R
M96-T86YG;&4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@@("`@
M("`@5&AE(&QE9G0@>"UC;V]R9&EN871E(&]F('1H92!R96-T86YG;&4N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D>2`@("`@("!4:&4@=&]P('DM8V]O<F1I
M;F%T92!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)'=I9'1H("`@5&AE('=I9'1H(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D:&5I9VAT("!4:&4@:&5I9VAT(&]F('1H92!R96-T
M86YG;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VQO<B`@("!4:&4@;&EN
M92!C;VQO<B!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9FEL;"`@("`@5&AE(&-O;&]R('1O(&9I;&P@=&AE(')E8W1A;F=L92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<F5C=&%N9VQE*"1X+"`D>2P@)'=I9'1H
M+"`D:&5I9VAT+"`D8V]L;W(L("1F:6QL(#T@)VYO;F4G*0H@("`@>PH@("`@
M("`@("1T:&ES+3YS9713=')O:V5#;VQO<B@D8V]L;W(I.PH@("`@("`@("1T
M:&ES+3YS971&:6QL0V]L;W(H)&9I;&PI.PH*("`@("`@("`D>$UA>"`]("1X
M("L@)'=I9'1H.PH@("`@("`@("1Y36%X(#T@)'D@*R`D:&5I9VAT.PH@("`@
M("`@("1T:&ES+3Y?;W!E<F%T:6]N<UM=(#T@(BUD<F%W(%PB<F5C=&%N9VQE
M("1X+"1Y("1X36%X+"1Y36%X7"(B.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1')A=R!A(')O=6YD960@<F5C=&%N9VQE+@H@("`@("H*("`@("`J($!P87)A
M;2!I;G1E9V5R("1X("`@("`@(%1H92!L969T('@M8V]O<F1I;F%T92!O9B!T
M:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'D@("`@("`@
M5&AE('1O<"!Y+6-O;W)D:6YA=&4@;V8@=&AE(')E8W1A;F=L92X*("`@("`J
M($!P87)A;2!I;G1E9V5R("1W:61T:"`@(%1H92!W:61T:"!O9B!T:&4@<F5C
M=&%N9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&AE:6=H="`@5&AE(&AE
M:6=H="!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)')O=6YD("`@5&AE('=I9'1H(&]F('1H92!C;W)N97(@<F]U;F1I;F<N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("`D8V]L;W(@("!4:&4@;&EN92!C;VQO<B!O
M9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&9I;&P@
M("`@5&AE(&-O;&]R('1O(&9I;&P@=&AE(')O=6YD960@<F5C=&%N9VQE('=I
M=&@N"B`@("`@*B\*("`@(&9U;F-T:6]N(')O=6YD961296-T86YG;&4H)'@L
M("1Y+"`D=VED=&@L("1H96EG:'0L("1R;W5N9"P@)&-O;&]R+"`D9FEL;"D*
M("`@('L*("`@("`@("`D=&AI<RT^<V5T4W1R;VME0V]L;W(H)&-O;&]R*3L*
M("`@("`@("`D=&AI<RT^<V5T1FEL;$-O;&]R*"1F:6QL*3L*"B`@("`@("`@
M)'@Q(#T@)'@@*R`D=VED=&@["B`@("`@("`@)'DQ(#T@)'D@*R`D:&5I9VAT
M.PH@("`@("`@("1T:&ES+3Y?;W!E<F%T:6]N<UM=(#T@(BUD<F%W(%PB<F]U
M;F1296-T86YG;&4@)'@L)'D@)'@Q+"1Y,2P@)')O=6YD+"1R;W5N9%PB(CL*
M("`@('T*"B`@("`O*BH*("`@("`J($1R87<@82!L:6YE+@H@("`@("H*("`@
M("`J($!P87)A;2!I;G1E9V5R("1X,"`@("`@5&AE('@@8V]O<F1I;F%T92!O
M9B!T:&4@<W1A<G0N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>3`@("`@(%1H
M92!Y(&-O;W)D:6YA=&4@;V8@=&AE('-T87)T+@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)'@Q("`@("!4:&4@>"!C;V]R9&EN871E(&]F('1H92!E;F0N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D>3$@("`@(%1H92!Y(&-O;W)D:6YA=&4@
M;V8@=&AE(&5N9"X*("`@("`J($!P87)A;2!S=')I;F<@)&-O;&]R("`@5&AE
M(&QI;F4@8V]L;W(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1W:61T:"`@(%1H
M92!W:61T:"!O9B!T:&4@;&EN92X*("`@("`J+PH@("`@9G5N8W1I;VX@;&EN
M92@D>#`L("1Y,"P@)'@Q+"`D>3$L("1C;VQO<B`]("=B;&%C:R<L("1W:61T
M:"`](#$I"B`@("!["B`@("`@("`@)'1H:7,M/G-E=%-T<F]K94-O;&]R*"1C
M;VQO<BD["B`@("`@("`@)'1H:7,M/G-E=%-T<F]K95=I9'1H*"1W:61T:"D[
M"B`@("`@("`@)'1H:7,M/E]O<&5R871I;VYS6UT@/2`B+61R87<@7")L:6YE
M("1X,"PD>3`@)'@Q+"1Y,5PB(CL*("`@('T*"B`@("`O*BH*("`@("`J($1R
M87<@82!D87-H960@;&EN92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D>#`@("`@("`@("`@(%1H92!X(&-O+6]R9&EN871E(&]F('1H92!S=&%R
M="X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y,"`@("`@("`@("`@5&AE('D@
M8V\M;W)D:6YA=&4@;V8@=&AE('-T87)T+@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)'@Q("`@("`@("`@("!4:&4@>"!C;RUO<F1I;F%T92!O9B!T:&4@96YD
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'DQ("`@("`@("`@("!4:&4@>2!C
M;RUO<F1I;F%T92!O9B!T:&4@96YD+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M8V]L;W(@("`@("`@("!4:&4@;&EN92!C;VQO<BX*("`@("`J($!P87)A;2!S
M=')I;F<@)'=I9'1H("`@("`@("`@5&AE('=I9'1H(&]F('1H92!L:6YE+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&1A<VA?;&5N9W1H("!4:&4@;&5N9W1H
M(&]F(&$@9&%S:"!O;B!T:&4@9&%S:&5D(&QI;F4*("`@("`J($!P87)A;2!I
M;G1E9V5R("1D87-H7W-P86-E("`@5&AE(&QE;F=T:"!O9B!A('-P86-E(&EN
M('1H92!D87-H960@;&EN90H@("`@("HO"B`@("!F=6YC=&EO;B!D87-H961,
M:6YE*"1X,"P@)'DP+"`D>#$L("1Y,2P@)&-O;&]R(#T@)V)L86-K)RP@)'=I
M9'1H(#T@,2P@)&1A<VA?;&5N9W1H(#T@,BP@)&1A<VA?<W!A8V4@/2`R*0H@
M("`@>PH@("`@("`@("1T:&ES+3YS9713=')O:V5#;VQO<B@D8V]L;W(I.PH@
M("`@("`@("1T:&ES+3YS9713=')O:V57:61T:"@D=VED=&@I.PH@("`@("`@
M("1T:&ES+3Y?;W!E<F%T:6]N<UM=(#T@(BUD<F%W(%PB;&EN92`D>#`L)'DP
M("1X,2PD>3%<(B(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W(&$@<&]L
M>6QI;F4@*&$@;F]N+6-L;W-E9"P@;F]N+69I;&QE9"!P;VQY9V]N*2!B87-E
M9"!O;B!A"B`@("`@*B!S970@;V8@=F5R=&EC97,N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1V97)T:6-E<R`@06X@87)R87D@;V8@>"!A;F0@>2!L
M86)E;&5D(&%R<F%Y<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M*&5G+B`D=F5R=&EC97-;,%U;)W@G72P@)'9E<G1I8V5S6S!=6R=Y)UTL("XN
M+BDN"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VQO<B`@("!4:&4@8V]L;W(@
M>6]U('=A;G0@=&\@9')A=R!T:&4@;&EN92!W:71H+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=VED=&@@("`@5&AE('=I9'1H(&]F('1H92!L:6YE+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!P;VQY;&EN92@D=F5R=',L("1C;VQO<BP@)'=I
M9'1H(#T@,2D*("`@('L*("`@("`@("`D=&AI<RT^<V5T4W1R;VME0V]L;W(H
M)&-O;&]R*3L*("`@("`@("`D=&AI<RT^<V5T4W1R;VME5VED=&@H)'=I9'1H
M*3L*("`@("`@("`D=&AI<RT^<V5T1FEL;$-O;&]R*"=N;VYE)RD["@H@("`@
M("`@("1C;VUM86YD(#T@)R<["B`@("`@("`@9F]R96%C:"`H)'9E<G1S(&%S
M("1V97)T*2!["B`@("`@("`@("`@("1C;VUM86YD("X]('-P<FEN=&8H)R`E
M9"PE9"<L("1V97)T6R=X)UTL("1V97)T6R=Y)UTI.PH@("`@("`@('T*("`@
M("`@("`D=&AI<RT^7V]P97)A=&EO;G-;72`]("(M9')A=R!<(G!O;'EL:6YE
M("1C;VUM86YD7"(B.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A;B!A
M<F,N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@@("`@("!4:&4@
M>"!C;V]R9&EN871E(&]F('1H92!C96YT<F4N"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D>2`@("`@(%1H92!Y(&-O;W)D:6YA=&4@;V8@=&AE(&-E;G1R92X*
M("`@("`J($!P87)A;2!I;G1E9V5R("1R("`@("`@5&AE(')A9&EU<R!O9B!T
M:&4@87)C+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'-T87)T("!4:&4@<W1A
M<G0@86YG;&4@;V8@=&AE(&%R8RX*("`@("`J($!P87)A;2!I;G1E9V5R("1E
M;F0@("`@5&AE(&5N9"!A;F=L92!O9B!T:&4@87)C+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`@)&-O;&]R("!4:&4@;&EN92!C;VQO<B!O9B!T:&4@87)C+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`@)&9I;&P@("!4:&4@9FEL;"!C;VQO<B!O
M9B!T:&4@87)C("AD969A=6QT<R!T;R!N;VYE*2X*("`@("`J+PH@("`@9G5N
M8W1I;VX@87)C*"1X+"`D>2P@)'(L("1S=&%R="P@)&5N9"P@)&-O;&]R(#T@
M)V)L86-K)RP@)&9I;&P@/2`G;F]N92<I"B`@("!["B`@("`@("`@)'1H:7,M
M/G-E=%-T<F]K94-O;&]R*"1C;VQO<BD["B`@("`@("`@)'1H:7,M/G-E=$9I
M;&Q#;VQO<B@D9FEL;"D["@H@("`@("`@("\O(%-P;&ET('5P(&%R8W,@9W)E
M871E<B!T:&%N(#$X,"!D96=R965S(&EN=&\@='=O('!I96-E<RX*("`@("`@
M("`D;6ED(#T@<F]U;F0H*"1S=&%R="`K("1E;F0I("\@,BD["B`@("`@("`@
M)'@@/2!R;W5N9"@D>"D["B`@("`@("`@)'D@/2!R;W5N9"@D>2D["B`@("`@
M("`@)'(@/2!R;W5N9"@D<BD["B`@("`@("`@:68@*"1M:60@/B`Y,"D@>PH@
M("`@("`@("`@("`D=&AI<RT^7V]P97)A=&EO;G-;72`]("(M9')A=R!<(F5L
M;&EP<V4@)'@L)'D@)'(L)'(@)'-T87)T+"1M:61<(B(["B`@("`@("`@("`@
M("1T:&ES+3Y?;W!E<F%T:6]N<UM=(#T@(BUD<F%W(%PB96QL:7!S92`D>"PD
M>2`D<BPD<B`D;6ED+"1E;F1<(B(["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'1H:7,M/E]O<&5R871I;VYS6UT@/2`B+61R87<@7")E;&QI<'-E
M("1X+"1Y("1R+"1R("1S=&%R="PD96YD7"(B.PH@("`@("`@('T*"B`@("`@
M("`@+R\@268@9FEL;&5D+"!D<F%W('1H92!O=71L:6YE+@H@("`@("`@(&EF
M("@A96UP='DH)&9I;&PI*2!["B`@("`@("`@("`@(&QI<W0H)'@Q+"`D>3$I
M(#T@)'1H:7,M/E]C:7)C;&50;VEN="@D<W1A<G0L("1R("H@,BD["B`@("`@
M("`@("`@(&QI<W0H)'@R+"`D>3(I(#T@)'1H:7,M/E]C:7)C;&50;VEN="@D
M;6ED+"`D<B`J(#(I.PH@("`@("`@("`@("!L:7-T*"1X,RP@)'DS*2`]("1T
M:&ES+3Y?8VER8VQE4&]I;G0H)&5N9"P@)'(@*B`R*3L*"B`@("`@("`@("`@
M("\O(%1H:7,@<V5E;7,@=&\@<F5S=6QT(&EN('-L:6=H=&QY(&)E='1E<B!P
M;&%C96UE;G0@;V8*("`@("`@("`@("`@+R\@<&EE('-L:6-E<RX*("`@("`@
M("`@("`@)'@K*SL*("`@("`@("`@("`@)'DK*SL*"B`@("`@("`@("`@("1V
M97)T<R`](&%R<F%Y*&%R<F%Y*"=X)R`]/B`D>"`K("1X,RP@)WDG(#T^("1Y
M("L@)'DS*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W@G
M(#T^("1X+"`G>2<@/3X@)'DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@G>"<@/3X@)'@@*R`D>#$L("=Y)R`]/B`D>2`K("1Y,2DI.PH*
M("`@("`@("`@("`@:68@*"1M:60@/B`Y,"D@>PH@("`@("`@("`@("`@("`@
M)'9E<G1S,2`](&%R<F%Y*&%R<F%Y*"=X)R`]/B`D>"`K("1X,BP@)WDG(#T^
M("1Y("L@)'DR*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@G>"<@/3X@)'@L("=Y)R`]/B`D>2DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87DH)W@G(#T^("1X("L@)'@Q+"`G>2<@/3X@
M)'D@*R`D>3$I*3L*("`@("`@("`@("`@("`@("1V97)T<S(@/2!A<G)A>2AA
M<G)A>2@G>"<@/3X@)'@@*R`D>#,L("=Y)R`]/B`D>2`K("1Y,RDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W@G(#T^("1X+"`G
M>2<@/3X@)'DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*"=X)R`]/B`D>"`K("1X,BP@)WDG(#T^("1Y("L@)'DR*2D["@H@("`@
M("`@("`@("`@("`@)'1H:7,M/G!O;'EG;VXH)'9E<G1S,2P@)&9I;&PL("1F
M:6QL*3L*("`@("`@("`@("`@("`@("1T:&ES+3YP;VQY9V]N*"1V97)T<S(L
M("1F:6QL+"`D9FEL;"D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^<&]L>6=O;B@D=F5R=',L("1F:6QL+"`D9FEL;"D[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3YP;VQY;&EN92@D
M=F5R=',L("1C;VQO<BD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@0VAA;F=E('1H92!C=7)R96YT('-T<F]K92!C;VQO<BX@5VEL;"!O;FQY
M(&%F9F5C="!T:&4@8V]M;6%N9`H@("`@("H@<W1R:6YG(&EF("1S=')O:V4@
M:7,@9&EF9F5R96YT(&9R;VT@=&AE('!R979I;W5S('-T<F]K92!C;VQO<@H@
M("`@("H@*'-T;W)E9"!I;B`D=&AI<RT^7W-T<F]K94-O;&]R*2X*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!S964@)%]S=')O:V5#
M;VQO<@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-O;&]R("!4:&4@
M;F5W('-T<F]K92!C;VQO<BX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T4W1R
M;VME0V]L;W(H)&-O;&]R*0H@("`@>PH@("`@("`@(&EF("@D8V]L;W(@(3T@
M)'1H:7,M/E]S=')O:V5#;VQO<BD@>PH@("`@("`@("`@("`D=&AI<RT^7V]P
M97)A=&EO;G-;72`]("(M<W1R;VME("1C;VQO<B(["B`@("`@("`@("`@("1T
M:&ES+3Y?<W1R;VME0V]L;W(@/2`D8V]L;W(["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@0VAA;F=E('1H92!C=7)R96YT('-T<F]K92!W:61T
M:"X@5VEL;"!O;FQY(&%F9F5C="!T:&4@8V]M;6%N9`H@("`@("H@<W1R:6YG
M(&EF("1W:61T:"!I<R!D:69F97)E;G0@9G)O;2!T:&4@<')E=FEO=7,@<W1R
M;VME('=I9'1H"B`@("`@*B`H<W1O<F5D(&EN("1T:&ES+3Y?<W1R;VME5VED
M=&@I+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'-E
M92`D7W-T<F]K90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'=I9'1H
M("!4:&4@;F5W('-T<F]K92!W:61T:"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<V5T4W1R;VME5VED=&@H)'=I9'1H*0H@("`@>PH@("`@("`@(&EF("@D=VED
M=&@@(3T@)'1H:7,M/E]S=')O:V57:61T:"D@>PH@("`@("`@("`@("`D=&AI
M<RT^7V]P97)A=&EO;G-;72`]("(M<W1R;VME=VED=&@@)'=I9'1H(CL*("`@
M("`@("`@("`@)'1H:7,M/E]S=')O:V57:61T:"`]("1W:61T:#L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&%N9V4@=&AE(&-U<G)E;G0@
M9FEL;"!C;VQO<BX@5VEL;"!O;FQY(&%F9F5C="!T:&4@8V]M;6%N9`H@("`@
M("H@<W1R:6YG(&EF("1C;VQO<B!I<R!D:69F97)E;G0@9G)O;2!T:&4@<')E
M=FEO=7,@9FEL;"!C;VQO<@H@("`@("H@*'-T;W)E9"!I;B`D=&AI<RT^7V9I
M;&Q#;VQO<BDN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*B!`<V5E("1?9FEL;`H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-O
M;&]R("!4:&4@;F5W(&9I;&P@8V]L;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-E=$9I;&Q#;VQO<B@D8V]L;W(I"B`@("!["B`@("`@("`@:68@*"1C;VQO
M<B`A/2`D=&AI<RT^7V9I;&Q#;VQO<BD@>PH@("`@("`@("`@("`D=&AI<RT^
M7V]P97)A=&EO;G-;72`]("(M9FEL;"`D8V]L;W(B.PH@("`@("`@("`@("`D
M=&AI<RT^7V9I;&Q#;VQO<B`]("1C;VQO<CL*("`@("`@("!]"B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]);6%G92]P;F<N<&AP````````````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`Q-34S,B`Q,#4Q-30S,S<S-2`P,C$V-S4`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*"G)E<75I<F5?
M;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXO26UA9V4N<&AP)SL*"B\J
M*@H@*B!4:&ES(&-L87-S(&EM<&QE;65N=',@=&AE($AO<F1E7TEM86=E.CH@
M05!)(&9O<B!03D<@:6UA9V5S+B!)=`H@*B!M86EN;'D@<')O=FED97,@<V]M
M92!U=&EL:71Y(&9U;F-T:6]N<RP@<W5C:"!A<R!T:&4@86)I;&ET>2!T;R!M
M86ME"B`J('!I>&5L<R!O<B!S;VQI9"!I;6%G97,@9F]R(&YO=RX*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO26UA9V4O26UA9V4O<&YG+G!H<"QV(#$N,3DN
M,3`N."`R,#`V+S`U+S,Q(#$W.C`V.C,V('-E;'-K>2!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,RTR,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O
M;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6ME
M($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@
M("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?26UA9V4*("HO"F-L87-S
M($AO<F1E7TEM86=E7W!N9R!E>'1E;F1S($AO<F1E7TEM86=E('L*"B`@("`O
M*BH*("`@("`J(%1H92!A<G)A>2!O9B!P:7AE;"!D871A+@H@("`@("H*("`@
M("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?:6UG(#T@87)R87DH
M*3L*"B`@("`O*BH*("`@("`J($-O;&]R(&1E<'1H("AO;FQY(#@@86YD(#$V
M(&EM<&QE;65N=&5D*2X*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@
M("`J+PH@("`@=F%R("1?8V]L;W)$97!T:"`](#@["@H@("`@+RHJ"B`@("`@
M*B!#;VQO<B!T>7!E("AO;FQY(#(@*'1R=64@8V]L;W(I(&EM<&QE;65N=&5D
M*2X*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R
M("1?8V]L;W)4>7!E(#T@,CL*"B`@("`O*BH*("`@("`J($-O;7!R97-S:6]N
M(&UE=&AO9"`H,"!I<R!T:&4@;VYL>2!C=7)R96YT('9A;&ED('9A;'5E*2X*
M("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?
M8V]M<')E<W-I;VY-971H;V0@/2`P.PH*("`@("\J*@H@("`@("H@1FEL=&5R
M(&UE=&AO9"`H,"!I<R!T:&4@;VYL>2!C=7)R96YT('9A;&ED('9A;'5E*2X*
M("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?
M9FEL=&5R365T:&]D(#T@,#L*"B`@("`O*BH*("`@("`J($EN=&5R;&%C92!M
M971H;V0@*&]N;'D@,"`H;F\@:6YT97)L86-E*2!I;7!L96UE;G1E9"DN"B`@
M("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7VEN
M=&5R;&%C94UE=&AO9"`](#`["@H@("`@+RHJ"B`@("`@*B!03D<@:6UA9V4@
M8V]N<W1R=6-T;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7TEM86=E
M7W!N9R@D<&%R86US*0H@("`@>PH@("`@("`@('!A<F5N=#HZ2&]R9&5?26UA
M9V4H)'!A<F%M<RD["@H@("`@("`@(&EF("@A96UP='DH)'!A<F%M<ULG=VED
M=&@G72DI('L*("`@("`@("`@("`@)'1H:7,M/G)E8W1A;F=L92@P+"`P+"`D
M<&%R86US6R=W:61T:"==+"`D<&%R86US6R=H96EG:'0G72P@)'1H:7,M/E]B
M86-K9W)O=6YD+"`D=&AI<RT^7V)A8VMG<F]U;F0I.PH@("`@("`@('T*("`@
M('T*"B`@("!F=6YC=&EO;B!G971#;VYT96YT5'EP92@I"B`@("!["B`@("`@
M("`@<F5T=7)N("=I;6%G92]P;F<G.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N('1H92!R87<@9&%T82!F;W(@=&AI<R!I;6%G92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')A=R!I;6%G92!D871A+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!R87<H*0H@("`@>PH@("`@("`@(')E='5R;@H@
M("`@("`@("`@("`D=&AI<RT^7VAE861E<B@I("X*("`@("`@("`@("`@)'1H
M:7,M/E])2$12*"D@+@H*("`@("`@("`@("`@+RH@4V%Y('=H870@8W)E871E
M9"!T:&4@:6UA9V4@9FEL92X@*B\*("`@("`@("`@("`@)'1H:7,M/E]T15AT
M*"=3;V9T=V%R92<L("=(;W)D92!&<F%M97=O<FL@26UA9V5?<&YG($-L87-S
M)RD@+@H*("`@("`@("`@("`@+RH@4V5T('1H92!L87-T(&UO9&EF:65D(&1A
M=&4O=&EM92X@*B\*("`@("`@("`@("`@)'1H:7,M/E]T24U%*"D@+@H*("`@
M("`@("`@("`@)'1H:7,M/E])1$%4*"D@+@H@("`@("`@("`@("`D=&AI<RT^
M7TE%3D0H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E<V5T('1H92!I;6%G
M92!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!R97-E="@I"B`@("!["B`@
M("`@("`@<&%R96YT.CIR97-E="@I.PH@("`@("`@("1T:&ES+3Y?:6UG(#T@
M87)R87DH*3L*("`@('T*"B`@("`O*BH*("`@("`J($1R87<@82!R96-T86YG
M;&4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@@("`@("`@5&AE
M(&QE9G0@>"UC;V]R9&EN871E(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D>2`@("`@("!4:&4@=&]P('DM8V]O<F1I;F%T92!O
M9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'=I9'1H
M("`@5&AE('=I9'1H(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D:&5I9VAT("!4:&4@:&5I9VAT(&]F('1H92!R96-T86YG;&4N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VQO<B`@("!4:&4@;&EN92!C;VQO
M<B!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL
M;"`@("`@5&AE(&-O;&]R('1O(&9I;&P@=&AE(')E8W1A;F=L92!W:71H+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!R96-T86YG;&4H)'@L("1Y+"`D=VED=&@L
M("1H96EG:'0L("1C;VQO<B`]("=B;&%C:R<L("1F:6QL(#T@)VYO;F4G*0H@
M("`@>PH@("`@("`@(&QI<W0H)'(L("1G+"`D8BD@/2`D=&AI<RT^9V5T4D="
M*"1C;VQO<BD["B`@("`@("`@:68@*"1F:6QL("$]("=N;VYE)RD@>PH@("`@
M("`@("`@("!L:7-T*"1F4BP@)&9'+"`D9D(I(#T@)'1H:7,M/F=E=%)'0B@D
M9FEL;"D["B`@("`@("`@?0H*("`@("`@("`D>#(@/2`D>"`K("1W:61T:#L*
M("`@("`@("`D>3(@/2`D>2`K("1H96EG:'0["@H@("`@("`@(&9O<B`H)&@@
M/2`D>3L@)&@@/#T@)'DR.R`D:"LK*2!["B`@("`@("`@("`@(&9O<B`H)'<@
M/2`D>#L@)'<@/#T@)'@R.R`D=RLK*2!["B`@("`@("`@("`@("`@("`O+R!3
M964@:68@=V4G<F4@;VX@86X@961G92X*("`@("`@("`@("`@("`@(&EF("@D
M=R`]/2`D>"!\?"`D:"`]/2`D>2!\?"`D=R`]/2`D>#(@?'P@)&@@/3T@)'DR
M*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I;6=;)&A=6R1W72`]
M(&%R<F%Y*"=R)R`]/B`D<BP@)V<G(#T^("1G+"`G8B<@/3X@)&(I.PH@("`@
M("`@("`@("`@("`@?2!E;'-E:68@*"1F:6QL("$]("=N;VYE)RD@>PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?:6UG6R1H75LD=UT@/2!A<G)A>2@G
M<B<@/3X@)&92+"`G9R<@/3X@)&9'+"`G8B<@/3X@)&9"*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($-R96%T92!T:&4@4$Y'(&9I;&4@:&5A9&5R+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?:&5A9&5R*"D*("`@('L*("`@("`@("!R971U<FX@
M<&%C:R@G0T-#0T-#0T,G+"`Q,S<L(#@P+"`W."P@-S$L(#$S+"`Q,"P@,C8L
M(#$P*3L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T92!);6%G92!(96%D
M97(@8FQO8VLN"B`@("`@*B\*("`@(&9U;F-T:6]N(%])2$12*"D*("`@('L*
M("`@("`@("`D9&%T82`]('!A8VLH)V$T3DY#0T-#0R<L("=)2$12)RP@)'1H
M:7,M/E]W:61T:"P@)'1H:7,M/E]H96EG:'0L("1T:&ES+3Y?8V]L;W)$97!T
M:"P@)'1H:7,M/E]C;VQO<E1Y<&4L("1T:&ES+3Y?8V]M<')E<W-I;VY-971H
M;V0L("1T:&ES+3Y?9FEL=&5R365T:&]D+"`D=&AI<RT^7VEN=&5R;&%C94UE
M=&AO9"D["B`@("`@("`@<F5T=7)N('!A8VLH)TYA)R`N('-T<FQE;B@D9&%T
M82D@+B`G3B<L('-T<FQE;B@D9&%T82D@+2`T+"`D9&%T82P@8W)C,S(H)&1A
M=&$I*3L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T92!)14Y$(&)L;V-K
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?245.1"@I"B`@("!["B`@("`@("`@
M)&1A=&$@/2`G245.1"<["B`@("`@("`@<F5T=7)N('!A8VLH)TYA)R`N('-T
M<FQE;B@D9&%T82D@+B`G3B<L('-T<FQE;B@D9&%T82D@+2`T+"`D9&%T82P@
M8W)C,S(H)&1A=&$I*3L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T92!)
M;6%G92!$871A(&)L;V-K+@H@("`@("HO"B`@("!F=6YC=&EO;B!?241!5"@I
M"B`@("!["B`@("`@("`@)&1A=&$@/2`G)SL*("`@("`@("`D<')E=G-C86YL
M:6YE(#T@;G5L;#L*("`@("`@("`D9FEL=&5R(#T@,#L*("`@("`@("!F;W(@
M*"1I(#T@,#L@)&D@/"`D=&AI<RT^7VAE:6=H=#L@)&DK*RD@>PH@("`@("`@
M("`@("`D<V-A;FQI;F4@/2!A<G)A>2@I.PH@("`@("`@("`@("`D9&%T82`N
M/2!C:'(H)&9I;'1E<BD["B`@("`@("`@("`@(&9O<B`H)&H@/2`P.R`D:B`\
M("1T:&ES+3Y?=VED=&@[("1J*RLI('L*("`@("`@("`@("`@("`@(&EF("@D
M=&AI<RT^7V-O;&]R1&5P=&@@/3T@."D@>PH@("`@("`@("`@("`@("`@("`@
M("1S8V%N;&EN95LD:ET@/2!P86-K*"=#0T,G+"`D=&AI<RT^7VEM9ULD:5U;
M)&I=6R=R)UTL("1T:&ES+3Y?:6UG6R1I75LD:EU;)V<G72P@)'1H:7,M/E]I
M;6=;)&E=6R1J75LG8B==*3L*("`@("`@("`@("`@("`@('T@96QS96EF("@D
M=&AI<RT^7V-O;&]R1&5P=&@@/3T@,38I('L*("`@("`@("`@("`@("`@("`@
M("`D<V-A;FQI;F5;)&I=(#T@<&%C:R@G;FYN)RP@)'1H:7,M/E]I;6=;)&E=
M6R1J75LG<B==(#P\(#@L("1T:&ES+3Y?:6UG6R1I75LD:EU;)V<G72`\/"`X
M+"`D=&AI<RT^7VEM9ULD:5U;)&I=6R=B)UT@/#P@."D["B`@("`@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`@("`@:68@*"1F:6QT97(@/3T@,"D@>PH@
M("`@("`@("`@("`@("`@("`@("\J($YO($9I;'1E<BX@*B\*("`@("`@("`@
M("`@("`@("`@("`D9&%T82`N/2`D<V-A;FQI;F5;)&I=.PH@("`@("`@("`@
M("`@("`@?2!E;'-E:68@*"1F:6QT97(@/3T@,BD@>PH@("`@("`@("`@("`@
M("`@("`@("\J(%5P($9I;'1E<BX@*B\*("`@("`@("`@("`@("`@("`@("`D
M<&EX96P@/2`D<V-A;FQI;F5;)&I=("T@)'!R979S8V%N;&EN95LD:ET["B`@
M("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?8V]L;W)$97!T:"`]/2`X
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1D871A("X]('!A8VLH)T-#
M0R<L("1P:7AE;"`^/B`Q-BP@*"1P:7AE;"`^/B`X*2`F(#!X1D8L("1P:7AE
M;"`F(#!X1D8I.PH@("`@("`@("`@("`@("`@("`@('T@96QS96EF("@D=&AI
M<RT^7V-O;&]R1&5P=&@@/3T@,38I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&1A=&$@+CT@<&%C:R@G;FYN)RP@*"1P:7AE;"`^/B`S,BDL("@D<&EX
M96P@/CX@,38I("8@,'A&1D9&+"`D<&EX96P@)B`P>$9&1D8I.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D<')E=G-C86YL:6YE(#T@)'-C86YL:6YE.PH@("`@
M("`@('T*("`@("`@("`D8V]M<')E<W-E9"`](&=Z9&5F;&%T92@D9&%T82P@
M.2D["@H@("`@("`@("1D871A(#T@)TE$050G("X@<&%C:R@G0T-A)R`N('-T
M<FQE;B@D8V]M<')E<W-E9"D@+B`G830G+"`P>#<X+"`P>#`Q+"`D8V]M<')E
M<W-E9"P@)'1H:7,M/E]!9&QE<C,R*"1D871A*2D["B`@("`@("`@<F5T=7)N
M('!A8VLH)TYA)R`N('-T<FQE;B@D9&%T82D@+B`G3B<L('-T<FQE;B@D9&%T
M82D@+2`T+"`D9&%T82P@8W)C,S(H)&1A=&$I*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($-R96%T92!T15AT(&)L;V-K+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?=$58="@D:V5Y=V]R9"P@)'1E>'0I"B`@("!["B`@("`@("`@)&1A=&$@
M/2`G=$58="<@+B`D:V5Y=V]R9"`N(")<,"(@+B`D=&5X=#L*("`@("`@("!R
M971U<FX@<&%C:R@G3F$G("X@<W1R;&5N*"1D871A*2`N("=.)RP@<W1R;&5N
M*"1D871A*2`M(#0L("1D871A+"!C<F,S,B@D9&%T82DI.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0W)E871E(&QA<W0@;6]D:69I960@=&EM92!B;&]C:RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@7W1)344H)&1A=&4@/2!N=6QL*0H@("`@
M>PH@("`@("`@(&EF("AI<U]N=6QL*"1D871E*2D@>PH@("`@("`@("`@("`D
M9&%T92`]('1I;64H*3L*("`@("`@("!]"@H@("`@("`@("1D871A(#T@)W1)
M344G("X@<&%C:R@G;D-#0T-#)RP@:6YT=F%L*&1A=&4H)UDG+"`D9&%T92DI
M+"!I;G1V86PH9&%T92@G;2<L("1D871E*2DL(&EN='9A;"AD871E*"=J)RP@
M)&1A=&4I*2P@:6YT=F%L*&1A=&4H)T<G+"`D9&%T92DI+"!I;G1V86PH9&%T
M92@G:2<L("1D871E*2DL(&EN='9A;"AD871E*"=S)RP@)&1A=&4I*2D["B`@
M("`@("`@<F5T=7)N('!A8VLH)TYA)R`N('-T<FQE;B@D9&%T82D@+B`G3B<L
M('-T<FQE;B@D9&%T82D@+2`T+"`D9&%T82P@8W)C,S(H)&1A=&$I*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($-A;&-U;&%T92!A;B!!9&QE<C,R(&-H96-K
M<W5M(&9O<B!A('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@7T%D;&5R
M,S(H)&EN<'5T*0H@("`@>PH@("`@("`@("1S,2`](#$["B`@("`@("`@)',R
M(#T@,#L*("`@("`@("`D:4UA>"`]('-T<FQE;B@D:6YP=70I.PH@("`@("`@
M(&9O<B`H)&D@/2`P.R`D:2`\("1I36%X.R`D:2LK*2!["B`@("`@("`@("`@
M("1S,2`]("@D<S$@*R!O<F0H)&EN<'5T6R1I72DI("4@,'A&1D8Q.PH@("`@
M("`@("`@("`D<S(@/2`H)',R("L@)',Q*2`E(#!X1D9&,3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N('!A8VLH)TXG+"`H*"1S,B`\/"`Q-BD@?"`D<S$I
M*3L*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]097)M<P``````````
M````````````````````````````````````````````````````````````
M```````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q
M,#4Q-30S,S<S-2`P,C`S-3<`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<```````````````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#0U,C0S(#$P-3$U-#,S-S,U(#`R,30W-``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M5&AE(%!E<FUS7U5).CH@8VQA<W,@<')O=FED97,@54D@;65T:&]D<R!F;W(@
M=&AE($AO<F1E('!E<FUI<W-I;VYS"B`J('-Y<W1E;2X*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP+'8@,2XR-RXR+C@@,C`P
M-B\P,2\P,2`R,3HR.#HS,2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P
M,#$M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU
M8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`R+C$*("H@0'!A8VMA
M9V4@2&]R9&5?4&5R;7,*("HO"F-L87-S(%!E<FUS7U5)('L*"B`@("`O*BH*
M("`@("`J(%1H92!097)M<R!O8FIE8W0@=V4G<F4@9&ES<&QA>6EN9R!522!S
M='5F9B!F;W(N"B`@("`@*@H@("`@("H@0'9A<B!097)M<PH@("`@("HO"B`@
M("!V87(@)%]P97)M<SL*"B`@("`O*BH*("`@("`J(%1H92!(;W)D95]&;W)M
M(&]B:F5C="!T:&%T('=I;&P@8F4@=7-E9"!F;W(@9&ES<&QA>6EN9R!T:&4@
M961I="!F;W)M+@H@("`@("H*("`@("`J($!V87(@2&]R9&5?1F]R;0H@("`@
M("HO"B`@("!V87(@)%]F;W)M(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%1H
M92!687)I86)L97,@;V)J96-T('5S960@:6X@2&]R9&5?1F]R;2X*("`@("`J
M"B`@("`@*B!`=F%R(%9A<FEA8FQE<PH@("`@("HO"B`@("!V87(@)%]V87)S
M(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%1H92!P97)M:7-S:6]N('1Y<&4N
M"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?
M='EP92`]("=M871R:7@G.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N
M"B`@("`@*@H@("`@("H@0'!A<F%M(%!E<FUS("1P97)M<R`@5&AE(%!E<FUS
M(&]B:F5C="!T;R!D:7-P;&%Y(%5)('-T=69F(&9O<BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@4&5R;7-?54DH)B1P97)M<RD*("`@('L*("`@("`@("`D=&AI
M<RT^7W!E<FUS(#T@)B1P97)M<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;B!A($AO<F1E7U1R964@<F5P<F5S96YT871I;VX@;V8@=&AE('!E<FUI
M<W-I;VYS('1R964N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!H=&UL('-H;W=I;F<@=&AE('!E<FUI<W-I;VYS(&%S(&$@2&]R9&5?5')E
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R5')E92@D8W5R<F5N="`]
M($1!5$%44D5%7U)/3U0I"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R
M>3L*"B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]4<F5E+G!H<"<["@H@
M("`@("`@("\J($=E="!T:&4@<&5R;7,@=')E92X@*B\*("`@("`@("`D;F]D
M97,@/2`F)'1H:7,M/E]P97)M<RT^9V5T5')E92@I.PH*("`@("`@("`D:6-O
M;F1I<B`](&%R<F%Y*"=I8V]N9&ER)R`]/B`D1TQ/0D%,4ULG<F5G:7-T<GDG
M72T^9V5T26UA9V5$:7(H*2D["B`@("`@("`@)'!E<FUS7VYO9&4@/2`D:6-O
M;F1I<B`K(&%R<F%Y*"=I8V]N)R`]/B`G<&5R;7,N<&YG)RD["B`@("`@("`@
M)&%D9"`]($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G861M:6XO<&5R;7,O861D
M8VAI;&0N<&AP)RD["B`@("`@("`@)&5D:70@/2!(;W)D93HZ87!P;&EC871I
M;VY5<FPH)V%D;6EN+W!E<FUS+V5D:70N<&AP)RD["B`@("`@("`@)&1E;&5T
M92`]($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G861M:6XO<&5R;7,O9&5L971E
M+G!H<"<I.PH@("`@("`@("1E9&ET7VEM9R`]($AO<F1E.CII;6<H)V5D:70N
M<&YG)RP@7R@B161I="!097)M:7-S:6]N(BDI.PH@("`@("`@("1D96QE=&5?
M:6UG(#T@2&]R9&4Z.FEM9R@G9&5L971E+G!N9R<L(%\H(D1E;&5T92!097)M
M:7-S:6]N(BDI.PH*("`@("`@("`O*B!3970@=7`@=&AE('1R964N("HO"B`@
M("`@("`@)'1R964@/2`F2&]R9&5?5')E93HZ<VEN9VQE=&]N*"=P97)M<U]U
M:2<L("=J879A<V-R:7!T)RD["B`@("`@("`@)'1R964M/G-E=$]P=&EO;BAA
M<G)A>2@G86QT97)N871E)R`]/B!T<G5E+"`G:&ED94AE861E<G,G(#T^('1R
M=64I*3L*("`@("`@("`D=')E92T^<V5T2&5A9&5R*&%R<F%Y*&%R<F%Y*"=W
M:61T:"<@/3X@)S4P)2<I*2D["@H@("`@("`@(&9O<F5A8V@@*"1N;V1E<R!A
M<R`D<&5R;5]I9"`]/B`D;F]D92D@>PH@("`@("`@("`@("`D;F]D95]C;&%S
M<R`]("@D8W5R<F5N="`]/2`D<&5R;5]I9"D@/R!A<G)A>2@G8VQA<W,G(#T^
M("=S96QE8W1E9"<I(#H@87)R87DH*3L*("`@("`@("`@("`@:68@*"1P97)M
M7VED(#T]($1!5$%44D5%7U)/3U0I('L*("`@("`@("`@("`@("`@("1A9&1?
M:6UG(#T@2&]R9&4Z.FEM9R@G<&5R;7,N<&YG)RP@7R@B061D($YE=R!097)M
M:7-S:6]N(BDI.PH@("`@("`@("`@("`@("`@)&%D9%]L:6YK(#T@2&]R9&4Z
M.FQI;FLH571I;#HZ861D4&%R86UE=&5R*"1A9&0L("=P97)M7VED)RP@)'!E
M<FU?:60I+"!?*")!9&0@3F5W(%!E<FUI<W-I;VXB*2D@+B`D861D7VEM9R`N
M("<\+V$^)SL*("`@("`@("`@("`@("`@("1B87-E7VYO9&5?<&%R86US(#T@
M)&EC;VYD:7(@*R!A<G)A>2@G:6-O;B<@/3X@)V%D;6EN:7-T<F%T:6]N+G!N
M9R<I.PH*("`@("`@("`@("`@("`@("1T<F5E+3YA9&1.;V1E*"1P97)M7VED
M+"!N=6QL+"!?*")!;&P@4&5R;6ES<VEO;G,B*2P@,"P@=')U92P@)&)A<V5?
M;F]D95]P87)A;7,@*R`D;F]D95]C;&%S<RP@87)R87DH)&%D9%]L:6YK*2D[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<&%R96YT
M7VED(#T@)'1H:7,M/E]P97)M<RT^7V1A=&%T<F5E+3YG971087)E;G0H)&YO
M9&4I.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)'!A<F5N=%]I9"P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@($AO<F1E.CIF871A
M;"@D<&%R96YT7VED+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@("`@("1A9&1?:6UG(#T@2&]R9&4Z.FEM
M9R@G<&5R;7,N<&YG)RP@7R@B061D($-H:6QD(%!E<FUI<W-I;VXB*2D["B`@
M("`@("`@("`@("`@("`D861D7VQI;FL@/2!(;W)D93HZ;&EN:RA5=&EL.CIA
M9&1087)A;65T97(H)&%D9"P@)W!E<FU?:60G+"`D<&5R;5]I9"DL(%\H(D%D
M9"!#:&EL9"!097)M:7-S:6]N(BDI("X@)&%D9%]I;6<@+B`G/"]A/B<["B`@
M("`@("`@("`@("`@("`D961I=%]L:6YK(#T@2&]R9&4Z.FQI;FLH571I;#HZ
M861D4&%R86UE=&5R*"1E9&ET+"`G<&5R;5]I9"<L("1P97)M7VED*2P@7R@B
M161I="!097)M:7-S:6]N(BDI("X@)&5D:71?:6UG("X@)SPO83XG.PH@("`@
M("`@("`@("`@("`@)&1E;&5T95]L:6YK(#T@2&]R9&4Z.FQI;FLH571I;#HZ
M861D4&%R86UE=&5R*"1D96QE=&4L("=P97)M7VED)RP@)'!E<FU?:60I+"!?
M*")$96QE=&4@4&5R;6ES<VEO;B(I*2`N("1D96QE=&5?:6UG("X@)SPO83XG
M.PH@("`@("`@("`@("`@("`@)'!E<FUS7V5X=')A(#T@87)R87DH)&%D9%]L
M:6YK+"`D961I=%]L:6YK+"`D9&5L971E7VQI;FLI.PH@("`@("`@("`@("`@
M("`@)&YA;64@/2`D=&AI<RT^7W!E<FUS+3YG9714:71L92@D;F]D92D["@H@
M("`@("`@("`@("`@("`@)'1R964M/F%D9$YO9&4H)'!E<FU?:60L("1P87)E
M;G1?:60L("1N86UE+"!S=6)S=')?8V]U;G0H)&YO9&4L("<Z)RD@*R`Q+"!F
M86QS92P@)'!E<FUS7VYO9&4@*R`D;F]D95]C;&%S<RP@)'!E<FUS7V5X=')A
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)'1R964M/G-O
M<G0H)VQA8F5L)RD["@H@("`@("`@(')E='5R;B`D=')E92T^<F5N9&5R5')E
M92@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T(&%N(&5X:7-T:6YG(&9O
M<FT@;V)J96-T('1O('5S92!F;W(@=&AE(&5D:70@9F]R;2X*("`@("`J"B`@
M("`@*B!`<&%R86T@2&]R9&5?1F]R;2`D9F]R;2`@06X@97AI<W1I;F<@2&]R
M9&5?1F]R;2!O8FIE8W0@=&\@=7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S
M971&;W)M*"8D9F]R;2D*("`@('L*("`@("`@("`D=&AI<RT^7V9O<FT@/2`F
M)&9O<FT["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@86X@97AI<W1I;F<@
M=F%R<R!O8FIE8W0@=&\@=7-E(&9O<B!T:&4@961I="!F;W)M+@H@("`@("H*
M("`@("`J($!P87)A;2!687)I86)L97,@)'9A<G,@($%N(&5X:7-T:6YG(%9A
M<FEA8FQE<R!O8FIE8W0@=&\@=7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S
M971687)S*"8D=F%R<RD*("`@('L*("`@("`@("`D=&AI<RT^7W9A<G,@/2`F
M)'9A<G,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@82!F;W)M('1O
M(&%D9"!A('!E<FUI<W-I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M(%!E<FUS
M("1P97)M:7-S:6]N"B`@("`@*B!`<&%R86T@<W1R:6YG("1F;W)C95]C:&]I
M8V4@($EF('1H92!P97)M:7-S:6]N('1O(&)E(&%D9&5D(&-A;B!B92!O;F4@
M;V8*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;6%N>2P@
M<V5T=&EN9R!T:&ES('=I;&P@9F]R8V4@=&AE(&-H;VEC92!T;PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!O;F4@<&%R=&EC=6QA<BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@<V5T=7!!9&1&;W)M*"1P97)M:7-S:6]N
M+"`D9F]R8V5?8VAO:6-E(#T@;G5L;"D*("`@('L*("`@("`@("`O*B!);FET
M:6%L:7-E(&9O<FT@:68@<F5Q=6ER960N("HO"B`@("`@("`@)'1H:7,M/E]F
M;W)M26YI="@I.PH*("`@("`@("`D=&AI<RT^7V9O<FTM/G-E=%1I=&QE*'-P
M<FEN=&8H7R@B061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B*2P@
M)'1H:7,M/E]P97)M<RT^9V5T5&ET;&4H)'!E<FUI<W-I;VXM/F=E=$YA;64H
M*2DI*3L*("`@("`@("`D=&AI<RT^7V9O<FTM/G-E=$)U='1O;G,H7R@B061D
M(BDL('1R=64I.PH@("`@("`@("1T:&ES+3Y?=F%R<RT^<V5T*"=P97)M7VED
M)RP@)'1H:7,M/E]P97)M<RT^9V5T4&5R;6ES<VEO;DED*"1P97)M:7-S:6]N
M*2D["B`@("`@("`@)'1H:7,M/E]F;W)M+3YA9&1(:61D96XH)R<L("=P97)M
M7VED)RP@)W1E>'0G+"!F86QS92D["@H@("`@("`@("\J(%-E="!U<"!T:&4@
M86-T=6%L(&-H:6QD(&%D9&EN9R!F:65L9"X@*B\*("`@("`@("`D8VAI;&1?
M<&5R;7,@/2`D=&AI<RT^7W!E<FUS+3YG971!=F%I;&%B;&4H)'!E<FUI<W-I
M;VXM/F=E=$YA;64H*2D["B`@("`@("`@:68@*"1C:&EL9%]P97)M<R`]/3T@
M9F%L<V4I('L*("`@("`@("`@("`@+RH@1F%L<V4L('-O(&YO(&-H:6QD<R!A
M<F4@=&\@8F4@861D960@8F5L;W<@=&AI<R!L979E;"X@*B\*("`@("`@("`@
M("`@)'1H:7,M/E]F;W)M+3YA9&1687)I86)L92A?*")097)M:7-S:6]N(BDL
M("=C:&EL9"<L("=I;G9A;&ED)RP@=')U92P@9F%L<V4L(&YU;&PL(&%R<F%Y
M*%\H(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I
M;VXN(BDI*3L*("`@("`@("!](&5L<V5I9B`H:7-?87)R87DH)&-H:6QD7W!E
M<FUS*2D@>PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1F;W)C95]C:&]I8V4I
M*2!["B`@("`@("`@("`@("`@("`O*B!#:&]I8V4@87)R87D@879A:6QA8FQE
M+"!B=70@8VAO:6-E(&)E:6YG(&9O<F-E9"X@*B\*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?=F%R<RT^<V5T*"=C:&EL9"<L("1F;W)C95]C:&]I8V4I.PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]F;W)M+3YA9&1687)I86)L92A?*")0
M97)M:7-S:6]N<R(I+"`G8VAI;&0G+"`G96YU;2<L('1R=64L('1R=64L(&YU
M;&PL(&%R<F%Y*"1C:&EL9%]P97)M<RDI.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@+RH@0VAO:6-E(&%R<F%Y(&%V86EL86)L92P@
M<V\@<V5T('5P(&5N=6T@9FEE;&0N("HO"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7V9O<FTM/F%D9%9A<FEA8FQE*%\H(E!E<FUI<W-I;VYS(BDL("=C:&EL
M9"<L("=E;G5M)RP@=')U92P@9F%L<V4L(&YU;&PL(&%R<F%Y*"1C:&EL9%]P
M97)M<RDI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@1G5N8W1I;VX@=&\@=F%L:61A=&4@86YY(&%D9"!F;W)M(&EN
M<'5T+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@($5I=&AE<B!F86QS
M92!I9B!T:&4@9F]R;2!D;V5S(&YO="!V86QI9&%T92!C;W)R96-T;'D@;W(*
M("`@("`J("`@("`@("`@("`@("`@(&%N(&%R<F%Y('=I=&@@86QL('1H92!F
M;W)M('9A;'5E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@=F%L:61A=&5!9&1&
M;W)M*"8D:6YF;RD*("`@('L*("`@("`@("!I9B`H(21T:&ES+3Y?9F]R;2T^
M=F%L:61A=&4H)'1H:7,M/E]V87)S*2D@>PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V9O<FTM/F=E=$EN
M9F\H)'1H:7,M/E]V87)S+"`D:6YF;RD["B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@82!P97)M:7-S:6]N(&5D
M:71I;F<@9F]R;2X*("`@("`J"B`@("`@*B!`<&%R86T@1&%T851R965/8FIE
M8W1?4&5R;6ES<VEO;B`D<&5R;6ES<VEO;@H@("`@("HO"B`@("!F=6YC=&EO
M;B!S971U<$5D:71&;W)M*"1P97)M:7-S:6]N*0H@("`@>PH@("`@("`@(&=L
M;V)A;"`D<F5G:7-T<GD["@H@("`@("`@("\J($EN:71I86QI<V4@9F]R;2!I
M9B!R97%U:7)E9"X@*B\*("`@("`@("`D=&AI<RT^7V9O<FU);FET*"D["@H@
M("`@("`@("1T:&ES+3Y?9F]R;2T^<V5T0G5T=&]N<RA?*")5<&1A=&4B*2P@
M=')U92D["B`@("`@("`@)'!E<FU?:60@/2`D=&AI<RT^7W!E<FUS+3YG9710
M97)M:7-S:6]N260H)'!E<FUI<W-I;VXI.PH@("`@("`@("1T:&ES+3Y?9F]R
M;2T^861D2&ED9&5N*"<G+"`G<&5R;5]I9"<L("=T97AT)RP@9F%L<V4I.PH*
M("`@("`@("`O*B!'970@<&5R;6ES<VEO;B!C;VYF:6=U<F%T:6]N+B`J+PH@
M("`@("`@("1T:&ES+3Y?='EP92`]("1P97)M:7-S:6]N+3YG970H)W1Y<&4G
M*3L*("`@("`@("`D<&%R86US(#T@)'!E<FUI<W-I;VXM/F=E="@G<&%R86US
M)RD["@H@("`@("`@("\J($1E9F%U;'0@<&5R;6ES<VEO;G,N("HO"B`@("`@
M("`@)'!E<FU?=F%L(#T@)'!E<FUI<W-I;VXM/F=E=$1E9F%U;'1097)M:7-S
M:6]N<R@I.PH@("`@("`@("1T:&ES+3Y?9F]R;2T^<V5T4V5C=&EO;B@G9&5F
M875L="<L(%\H(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(BDL($AO<F1E.CII
M;6<H)W!E<FUS+G!N9R<L("<G+"`G)RP@)')E9VES=')Y+3YG971);6%G941I
M<B@G:&]R9&4G*2DL(&9A;'-E*3L*"B`@("`@("`@+RH@5V4@35535"!U<V4@
M)V1E9FQT)R!F;W(@=&AE('9A<FEA8FQE(&YA;64@8F5C875S92`G9&5F875L
M="<@:7,@80H@("`@("`@("`J(')E<V5R=F5D('=O<F0@:6X@2F%V85-C<FEP
M="X@*B\*("`@("`@("!I9B`H)'1H:7,M/E]T>7!E(#T]("=M871R:7@G*2![
M"B`@("`@("`@("`@("\J(%-E="!U<"!T:&4@8V]L=6UN<R!F;W(@=&AE('!E
M<FUI<W-I;VYS(&UA=')I>"X@*B\*("`@("`@("`@("`@)&-O;',@/2!097)M
M<SHZ9V5T4&5R;7-!<G)A>2@I.PH*("`@("`@("`@("`@+RH@1&5F:6YE(&$@
M<VEN9VQE(&UA=')I>"!R;W<@9F]R(&1E9F%U;'0@<&5R;7,N("HO"B`@("`@
M("`@("`@("1M871R:7@@/2!A<G)A>2@I.PH@("`@("`@("`@("`D;6%T<FEX
M6S!=(#T@4&5R;7,Z.FEN=&5G97)4;T%R<F%Y*"1P97)M7W9A;"D["B`@("`@
M("`@("`@("1T:&ES+3Y?9F]R;2T^861D5F%R:6%B;&4H)R<L("=D969L="<L
M("=M871R:7@G+"!F86QS92P@9F%L<V4L(&YU;&PL(&%R<F%Y*"1C;VQS+"!A
M<G)A>2@P(#T^("<G*2P@)&UA=')I>"DI.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1V87(@/2`F)'1H:7,M/E]F;W)M+3YA9&1687)I86)L92@G
M)RP@)V1E9FQT)RP@)'1H:7,M/E]T>7!E+"!F86QS92P@9F%L<V4L(&YU;&PL
M("1P87)A;7,I.PH@("`@("`@("`@("`D=F%R+3YS971$969A=6QT*"1P97)M
M7W9A;"D["B`@("`@("`@?0H*("`@("`@("`O*B!'=65S="!P97)M:7-S:6]N
M<RX@*B\*("`@("`@("`D<&5R;5]V86P@/2`D<&5R;6ES<VEO;BT^9V5T1W5E
M<W1097)M:7-S:6]N<R@I.PH@("`@("`@("1T:&ES+3Y?9F]R;2T^<V5T4V5C
M=&EO;B@G9W5E<W0G+"!?*")'=65S="!097)M:7-S:6]N<R(I+"`G)RP@9F%L
M<V4I.PH*("`@("`@("!I9B`H)'1H:7,M/E]T>7!E(#T]("=M871R:7@G*2![
M"B`@("`@("`@("`@("\J($1E9FEN92!A('-I;F=L92!M871R:7@@<F]W(&9O
M<B!G=65S="!P97)M<RX@*B\*("`@("`@("`@("`@)&UA=')I>"`](&%R<F%Y
M*"D["B`@("`@("`@("`@("1M871R:7A;,%T@/2!097)M<SHZ:6YT96=E<E1O
M07)R87DH)'!E<FU?=F%L*3L*("`@("`@("`@("`@)'1H:7,M/E]F;W)M+3YA
M9&1687)I86)L92@G)RP@)V=U97-T)RP@)VUA=')I>"<L(&9A;'-E+"!F86QS
M92P@;G5L;"P@87)R87DH)&-O;',L(&%R<F%Y*#`@/3X@)R<I+"`D;6%T<FEX
M*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'9A<B`]("8D=&AI
M<RT^7V9O<FTM/F%D9%9A<FEA8FQE*"<G+"`G9W5E<W0G+"`D=&AI<RT^7W1Y
M<&4L(&9A;'-E+"!F86QS92P@;G5L;"P@)'!A<F%M<RD["B`@("`@("`@("`@
M("1V87(M/G-E=$1E9F%U;'0H)'!E<FU?=F%L*3L*("`@("`@("!]"@H@("`@
M("`@("\J($]B:F5C="!C<F5A=&]R('!E<FUI<W-I;VYS+B`J+PH@("`@("`@
M("1P97)M7W9A;"`]("1P97)M:7-S:6]N+3YG971#<F5A=&]R4&5R;6ES<VEO
M;G,H*3L*("`@("`@("`D=&AI<RT^7V9O<FTM/G-E=%-E8W1I;VXH)V-R96%T
M;W(G+"!?*")#<F5A=&]R(%!E<FUI<W-I;VYS(BDL($AO<F1E.CII;6<H)W5S
M97(N<&YG)RP@)R<L("<G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D
M92<I*2P@9F%L<V4I.PH*("`@("`@("!I9B`H)'1H:7,M/E]T>7!E(#T]("=M
M871R:7@G*2!["B`@("`@("`@("`@("\J($1E9FEN92!A('-I;F=L92!M871R
M:7@@<F]W(&9O<B!C<F5A=&]R('!E<FUS+B`J+PH@("`@("`@("`@("`D;6%T
M<FEX(#T@87)R87DH*3L*("`@("`@("`@("`@)&UA=')I>%LP72`](%!E<FUS
M.CII;G1E9V5R5&]!<G)A>2@D<&5R;5]V86PI.PH@("`@("`@("`@("`D=&AI
M<RT^7V9O<FTM/F%D9%9A<FEA8FQE*"<G+"`G8W)E871O<B<L("=M871R:7@G
M+"!F86QS92P@9F%L<V4L(&YU;&PL(&%R<F%Y*"1C;VQS+"!A<G)A>2@P(#T^
M("<G*2P@)&UA=')I>"DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1V87(@/2`F)'1H:7,M/E]F;W)M+3YA9&1687)I86)L92@G)RP@)V-R96%T
M;W(G+"`D=&AI<RT^7W1Y<&4L(&9A;'-E+"!F86QS92P@;G5L;"P@)'!A<F%M
M<RD["B`@("`@("`@("`@("1V87(M/G-E=$1E9F%U;'0H)'!E<FU?=F%L*3L*
M("`@("`@("!]"@H@("`@("`@("\J(%5S97)S('!E<FUI<W-I;VYS+B`J+PH@
M("`@("`@("1P97)M7W9A;"`]("1P97)M:7-S:6]N+3YG9715<V5R4&5R;6ES
M<VEO;G,H*3L*("`@("`@("`D=&AI<RT^7V9O<FTM/G-E=%-E8W1I;VXH)W5S
M97)S)RP@7R@B26YD:79I9'5A;"!5<V5R<R(I+"!(;W)D93HZ:6UG*"=U<V5R
M+G!N9R<L("<G+"`G)RP@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G
M*2DL(&9A;'-E*3L*("`@("`@("`D875T:"`]("9!=71H.CIS:6YG;&5T;VXH
M)$=,3T)!3%-;)V-O;F8G75LG875T:"==6R=D<FEV97(G72D["B`@("`@("`@
M:68@*"1A=71H+3YH87-#87!A8FEL:71Y*"=L:7-T)RDI('L*("`@("`@("`@
M("`@+RH@5&AE(&%U=&@@9')I=F5R(&AA<R!L:7-T(&-A<&%B:6QI=&EE<R!S
M;R!S970@=7`@86X@87)R87D@=VAI8V@*("`@("`@("`@("`@("H@=&AE(&UA
M=')I>"!F:65L9"!T>7!E('=I;&P@<F5C;V=N:7-E('1O('-E="!U<"!A;B!E
M;G5M(&)O>"!F;W(*("`@("`@("`@("`@("H@861D:6YG(&YE=R!U<V5R<R!T
M;R!T:&4@<&5R;6ES<VEO;G,@;6%T<FEX+B`J+PH@("`@("`@("`@("`D;F5W
M7W5S97)S(#T@87)R87DH*3L*("`@("`@("`@("`@)'5S97)?;&ES="`]("1A
M=71H+3YL:7-T57-E<G,H*3L*("`@("`@("`@("`@:68@*&ES7V$H)'5S97)?
M;&ES="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)&YE=U]U
M<V5R<R`]('1R=64["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("!S;W)T*"1U<V5R7VQI<W0I.PH@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)'5S97)?;&ES="!A<R`D=7-E<BD@>PH@("`@("`@("`@("`@("`@("`@
M(&EF("@A:7-S970H)'!E<FU?=F%L6R1U<V5R72DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&YE=U]U<V5R<ULD=7-E<ET@/2`D=7-E<CL*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!.;R!L:7-T(&-A
M<&%B:6QI=&EE<RP@<V5T=&EN9R!T;R!T<G5E('-O('1H870@=&AE(&UA=')I
M>"!F:65L9`H@("`@("`@("`@("`@*B!T>7!E('=I;&P@;V9F97(@82!T97AT
M(&EN<'5T(&)O>"!F;W(@861D:6YG(&YE=R!U<V5R<RX@*B\*("`@("`@("`@
M("`@)&YE=U]U<V5R<R`]('1R=64["B`@("`@("`@?0H*("`@("`@("!I9B`H
M)'1H:7,M/E]T>7!E(#T]("=M871R:7@G*2!["B`@("`@("`@("`@("\J(%-E
M="!U<"!T:&4@;6%T<FEX(&%R<F%Y+"!B<F5A:VEN9R!U<"!E86-H('!E<FUI
M<W-I;VX@:6YT96=E<@H@("`@("`@("`@("`@*B!I;G1O(&%N(&%R<F%Y+B`@
M5&AE(&ME>7,@;V8@=&AI<R!A<G)A>2!W:6QL(&)E('1H92!R;W<*("`@("`@
M("`@("`@("H@:&5A9&5R<RX@*B\*("`@("`@("`@("`@)')O=W,@/2!A<G)A
M>2@I.PH@("`@("`@("`@("`D;6%T<FEX(#T@87)R87DH*3L*("`@("`@("`@
M("`@9F]R96%C:"`H)'!E<FU?=F%L(&%S("1U7VED(#T^("1U7W!E<FUS*2![
M"B`@("`@("`@("`@("`@("`D<F]W<ULD=5]I9%T@/2`D=5]I9#L*("`@("`@
M("`@("`@("`@("1M871R:7A;)'5?:61=(#T@4&5R;7,Z.FEN=&5G97)4;T%R
M<F%Y*"1U7W!E<FUS*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI
M<RT^7V9O<FTM/F%D9%9A<FEA8FQE*"<G+"`G=2<L("=M871R:7@G+"!F86QS
M92P@9F%L<V4L(&YU;&PL(&%R<F%Y*"1C;VQS+"`D<F]W<RP@)&UA=')I>"P@
M)&YE=U]U<V5R<RDI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF
M("@D;F5W7W5S97)S*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH
M)&YE=U]U<V5R<RDI('L*("`@("`@("`@("`@("`@("`@("`D=5]N(#T@571I
M;#HZ9V5T1F]R;41A=&$H)W5?;B<I.PH@("`@("`@("`@("`@("`@("`@("1U
M7VX@/2!E;7!T>2@D=5]N6R=U)UTI(#\@;G5L;"`Z("1U7VY;)W4G73L*("`@
M("`@("`@("`@("`@("`@("`D=7-E<E]H=&UL(#T@)SQS96QE8W0@;F%M93TB
M=5]N6W5=(CX\;W!T:6]N/B<@+B!?*"(M+2!S96QE8W0@+2TB*2`N("<\+V]P
M=&EO;CXG.PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1N97=?=7-E
M<G,@87,@)&YE=U]U<V5R*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1U
M<V5R7VAT;6P@+CT@)SQO<'1I;VX@=F%L=64](B<@+B`D;F5W7W5S97(@+B`G
M(B<["B`@("`@("`@("`@("`@("`@("`@("`@("1U<V5R7VAT;6P@+CT@)'5?
M;B`]/2`D;F5W7W5S97(@/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<[
M"B`@("`@("`@("`@("`@("`@("`@("`@("1U<V5R7VAT;6P@+CT@)SXG("X@
M:'1M;'-P96-I86QC:&%R<R@D;F5W7W5S97(I("X@)SPO;W!T:6]N/B<["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1U<V5R
M7VAT;6P@+CT@)SPO<V5L96-T/B<["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("1U<V5R7VAT;6P@/2`G/&EN<'5T('1Y
M<&4](G1E>'0B(&YA;64](G5?;EMU72(@+SXG.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@)'1H:7,M/E]F;W)M+3YA9&1687)I86)L92@D
M=7-E<E]H=&UL+"`G=5]N6W9=)RP@)'1H:7,M/E]T>7!E+"!F86QS92P@9F%L
M<V4L(&YU;&PL("1P87)A;7,I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&9O<F5A8V@@*"1P97)M7W9A;"!A<R`D=5]I9"`]/B`D=5]P97)M<RD@>PH@
M("`@("`@("`@("`@("`@)'9A<B`]("8D=&AI<RT^7V9O<FTM/F%D9%9A<FEA
M8FQE*"1U7VED+"`G=5]V6R<@+B`D=5]I9"`N("==)RP@)'1H:7,M/E]T>7!E
M+"!F86QS92P@9F%L<V4L(&YU;&PL("1P87)A;7,I.PH@("`@("`@("`@("`@
M("`@)'9A<BT^<V5T1&5F875L="@D=5]P97)M<RD["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@("\J($=R;W5P<R!P97)M:7-S:6]N<RX@*B\*
M("`@("`@("`D<&5R;5]V86P@/2`D<&5R;6ES<VEO;BT^9V5T1W)O=7!097)M
M:7-S:6]N<R@I.PH@("`@("`@("1T:&ES+3Y?9F]R;2T^<V5T4V5C=&EO;B@G
M9W)O=7!S)RP@7R@B1W)O=7!S(BDL($AO<F1E.CII;6<H)V=R;W5P+G!N9R<L
M("<G+"`G)RP@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G*2DL(&9A
M;'-E*3L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T=R;W5P+G!H<"<[
M"B`@("`@("`@)&=R;W5P<R`]("9'<F]U<#HZ<VEN9VQE=&]N*"D["B`@("`@
M("`@)&=R;W5P7VQI<W0@/2`D9W)O=7!S+3YL:7-T1W)O=7!S*"D["B`@("`@
M("`@:68@*"%E;7!T>2@D9W)O=7!?;&ES="DI('L*("`@("`@("`@("`@+RH@
M5&AE<F4@:7,@86X@879A:6QA8FQE(&QI<W0@;V8@9W)O=7!S('-O('-E="!U
M<"!A;B!A<G)A>2!W:&EC:`H@("`@("`@("`@("`@*B!T:&4@;6%T<FEX(&9I
M96QD('1Y<&4@=VEL;"!R96-O9VYI<V4@=&\@<V5T('5P(&%N(&5N=6T@8F]X
M(&9O<@H@("`@("`@("`@("`@*B!A9&1I;F<@;F5W(&=R;W5P<R!T;R!T:&4@
M<&5R;6ES<VEO;G,@;6%T<FEX+B`J+PH@("`@("`@("`@("`D;F5W7V=R;W5P
M<R`](&%R<F%Y*"D["B`@("`@("`@("`@(&9O<F5A8V@@*"1G<F]U<%]L:7-T
M(&%S("1G<F]U<$ED(#T^("1G<F]U<"D@>PH@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D<&5R;5]V86Q;)&=R;W5P261=*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1N97=?9W)O=7!S6R1G<F]U<$ED72`]("1G<F]U<#L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("\J($1O(&YO="!O9F9E<B!A('1E>'0@8F]X('1O(&%D9"!N
M97<@9W)O=7!S+B`J+PH@("`@("`@("`@("`D;F5W7V=R;W5P<R`](&9A;'-E
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES+3Y?='EP92`]/2`G;6%T
M<FEX)RD@>PH@("`@("`@("`@("`O*B!3970@=7`@=&AE(&UA=')I>"!A<G)A
M>2P@8G)E86L@=7`@96%C:"!P97)M:7-S:6]N(&EN=&5G97(@:6YT;PH@("`@
M("`@("`@("`@*B!A;B!A<G)A>2X@5&AE(&ME>7,@;V8@=&AI<R!A<G)A>2!W
M:6QL(&)E('1H92!R;W<@:&5A9&5R<RX@*B\*("`@("`@("`@("`@)')O=W,@
M/2!A<G)A>2@I.PH@("`@("`@("`@("`D;6%T<FEX(#T@87)R87DH*3L*("`@
M("`@("`@("`@9F]R96%C:"`H)'!E<FU?=F%L(&%S("1G7VED(#T^("1G7W!E
M<FUS*2!["B`@("`@("`@("`@("`@("`D<F]W<ULD9U]I9%T@/2!I<W-E="@D
M9W)O=7!?;&ES=%LD9U]I9%TI(#\@)&=R;W5P7VQI<W1;)&=?:61=(#H@)&=?
M:60["B`@("`@("`@("`@("`@("`D;6%T<FEX6R1G7VED72`](%!E<FUS.CII
M;G1E9V5R5&]!<G)A>2@D9U]P97)M<RD["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)'1H:7,M/E]F;W)M+3YA9&1687)I86)L92@G)RP@)V<G+"`G;6%T
M<FEX)RP@9F%L<V4L(&9A;'-E+"!N=6QL+"!A<G)A>2@D8V]L<RP@)')O=W,L
M("1M871R:7@L("1N97=?9W)O=7!S*2D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@:68@*"1N97=?9W)O=7!S*2!["B`@("`@("`@("`@("`@("!I
M9B`H:7-?87)R87DH)&YE=U]G<F]U<',I*2!["B`@("`@("`@("`@("`@("`@
M("`@)&=?;B`](%5T:6PZ.F=E=$9O<FU$871A*"=G7VXG*3L*("`@("`@("`@
M("`@("`@("`@("`D9U]N(#T@96UP='DH)&=?;ELG9R==*2`_(&YU;&P@.B`D
M9U]N6R=G)UT["B`@("`@("`@("`@("`@("`@("`@)&=R;W5P7VAT;6P@/2`G
M/'-E;&5C="!N86UE/2)G7VY;9UTB/CQO<'1I;VX^)R`N(%\H(BTM('-E;&5C
M="`M+2(I("X@)SPO;W!T:6]N/B<["B`@("`@("`@("`@("`@("`@("`@9F]R
M96%C:"`H)&YE=U]G<F]U<',@87,@)&=R;W5P260@/3X@)&=R;W5P*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1G<F]U<%]H=&UL("X]("<\;W!T:6]N
M('9A;'5E/2(G("X@)&=R;W5P260@+B`G(B<["B`@("`@("`@("`@("`@("`@
M("`@("`@("1G<F]U<%]H=&UL("X]("1G7VX@/3T@)&=R;W5P260@/R`G('-E
M;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<["B`@("`@("`@("`@("`@("`@("`@
M("`@("1G<F]U<%]H=&UL("X]("<^)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&=R
M;W5P*2`N("<\+V]P=&EO;CXG.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("`D9W)O=7!?:'1M;"`N/2`G/"]S96QE8W0^)SL*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M)&=R;W5P7VAT;6P@/2`G/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](F=?;EMG
M72(@+SXG.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'1H
M:7,M/E]F;W)M+3YA9&1687)I86)L92@D9W)O=7!?:'1M;"P@)V=?;EMV72<L
M("1T:&ES+3Y?='EP92P@9F%L<V4L(&9A;'-E+"!N=6QL+"`D<&%R86US*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!F;W)E86-H("@D<&5R;5]V86P@
M87,@)&=?:60@/3X@)&=?<&5R;7,I('L*("`@("`@("`@("`@("`@("1V87(@
M/2`F)'1H:7,M/E]F;W)M+3YA9&1687)I86)L92AI<W-E="@D9W)O=7!?;&ES
M=%LD9U]I9%TI(#\@)&=R;W5P7VQI<W1;)&=?:61=(#H@)&=?:60L("=G7W9;
M)R`N("1G7VED("X@)UTG+"`D=&AI<RT^7W1Y<&4L(&9A;'-E+"!F86QS92P@
M;G5L;"P@)'!A<F%M<RD["B`@("`@("`@("`@("`@("`D=F%R+3YS971$969A
M=6QT*"1G7W!E<FUS*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@+RH@4V5T(&9O<FT@=&ET;&4N("HO"B`@("`@("`@)'1H:7,M/E]F;W)M
M+3YS9714:71L92AS<')I;G1F*%\H(D5D:70@<&5R;6ES<VEO;G,@9F]R(%PB
M)7-<(B(I+"`D=&AI<RT^7W!E<FUS+3YG9714:71L92@D<&5R;6ES<VEO;BT^
M9V5T3F%M92@I*2DI.PH@("`@?0H*("`@("\J*@H@("`@("H@1G5N8W1I;VX@
M=&\@=F%L:61A=&4@86YY(&5D:70@9F]R;2!I;G!U="X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!%:71H97(@9F%L<V4@:68@=&AE(&9O<FT@9&]E
M<R!N;W0@=F%L:61A=&4@8V]R<F5C=&QY(&]R"B`@("`@*B`@("`@("`@("`@
M("`@("!A;B!A<G)A>2!W:71H(&%L;"!T:&4@9F]R;2!V86QU97,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('9A;&ED871E161I=$9O<FTH)B1I;F9O*0H@("`@
M>PH@("`@("`@(&EF("@A)'1H:7,M/E]F;W)M+3YV86QI9&%T92@D=&AI<RT^
M7W9A<G,I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"@H@("`@("`@("1T:&ES+3Y?9F]R;2T^9V5T26YF;R@D=&AI<RT^7W9A<G,L
M("1I;F9O*3L*"B`@("`@("`@:68@*"1T:&ES+3Y?='EP92`]/2`G;6%T<FEX
M)RD@>PH@("`@("`@("`@("`O*B!#;VQL87!S92!T:&4@87)R87D@9F]R(&1E
M9F%U;'0O9W5E<W0O8W)E871O<BX@*B\*("`@("`@("`@("`@)&EN9F];)V1E
M9FQT)UT@/2!I<W-E="@D:6YF;ULG9&5F;'0G75LP72D@/R`D:6YF;ULG9&5F
M;'0G75LP72`Z(&YU;&P["B`@("`@("`@("`@("1I;F9O6R=G=65S="==("`@
M/2!I<W-E="@D:6YF;ULG9W5E<W0G75LP72D@/R`D:6YF;ULG9W5E<W0G75LP
M72`Z(&YU;&P["B`@("`@("`@("`@("1I;F9O6R=C<F5A=&]R)UT@/2!I<W-E
M="@D:6YF;ULG8W)E871O<B==6S!=*2`_("1I;F9O6R=C<F5A=&]R)UU;,%T@
M.B!N=6QL.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1U7VX@/2`D
M=&AI<RT^7W9A<G,M/F=E="@G=5]N)RD["B`@("`@("`@("`@("1I;F9O6R=U
M)UT@/2!A<G)A>2@D=5]N6R=U)UT@/3X@)&EN9F];)W5?;B==6R=V)UTI.PH@
M("`@("`@("`@("!U;G-E="@D:6YF;ULG=5]N)UTI.PH@("`@("`@("`@("!I
M9B`H:7-S970H)&EN9F];)W5?=B==*2D@>PH@("`@("`@("`@("`@("`@)&EN
M9F];)W4G72`](&%R<F%Y7VUE<F=E*"1I;F9O6R=U)UTL("1I;F9O6R=U7W8G
M72D["B`@("`@("`@("`@("`@("!U;G-E="@D:6YF;ULG=5]V)UTI.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1G7VX@/2`D=&AI<RT^7W9A<G,M/F=E
M="@G9U]N)RD["B`@("`@("`@("`@("1I;F9O6R=G)UT@/2!A<G)A>2@D9U]N
M6R=G)UT@/3X@)&EN9F];)V=?;B==6R=V)UTI.PH@("`@("`@("`@("!U;G-E
M="@D:6YF;ULG9U]N)UTI.PH@("`@("`@("`@("!I9B`H:7-S970H)&EN9F];
M)V=?=B==*2D@>PH@("`@("`@("`@("`@("`@)&EN9F];)V<G72`](&%R<F%Y
M7VUE<F=E*"1I;F9O6R=G)UTL("1I;F9O6R=G7W8G72D["B`@("`@("`@("`@
M("`@("!U;G-E="@D:6YF;ULG9U]V)UTI.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@("`@("1I;F9O6R=D969A=6QT)UT@/2`D:6YF;ULG9&5F;'0G
M73L*("`@("`@("!U;G-E="@D:6YF;ULG9&5F;'0G72D["@H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E(&$@<&5R
M;6ES<VEO;B!D96QE=&EN9R!F;W)M+@H@("`@("H*("`@("`J($!P87)A;2!O
M8FIE8W0@)'!E<FUI<W-I;VX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T=7!$
M96QE=&5&;W)M*"1P97)M:7-S:6]N*0H@("`@>PH@("`@("`@("\J($EN:71I
M86QI<V4@9F]R;2!I9B!R97%U:7)E9"X@*B\*("`@("`@("`D=&AI<RT^7V9O
M<FU);FET*"D["@H@("`@("`@("1T:&ES+3Y?9F]R;2T^<V5T5&ET;&4H<W!R
M:6YT9BA?*")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(I+"`D=&AI
M<RT^7W!E<FUS+3YG9714:71L92@D<&5R;6ES<VEO;BT^9V5T3F%M92@I*2DI
M.PH@("`@("`@("1T:&ES+3Y?9F]R;2T^<V5T0G5T=&]N<RAA<G)A>2A?*")$
M96QE=&4B*2P@7R@B1&\@;F]T(&1E;&5T92(I*2D["B`@("`@("`@)'1H:7,M
M/E]F;W)M+3YA9&1(:61D96XH)R<L("=P97)M7VED)RP@)W1E>'0G+"!F86QS
M92D["B`@("`@("`@)'1H:7,M/E]F;W)M+3YA9&1687)I86)L92AS<')I;G1F
M*%\H(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B
M+7!E<FUI<W-I;VYS/R(I+"`D=&AI<RT^7W!E<FUS+3YG9714:71L92@D<&5R
M;6ES<VEO;BT^9V5T3F%M92@I*2DL("=P<F]M<'0G+"`G9&5S8W)I<'1I;VXG
M+"!F86QS92D["@H@("`@?0H*("`@("\J*@H@("`@("H@1G5N8W1I;VX@=&\@
M=F%L:61A=&4@86YY(&1E;&5T92!F;W)M(&EN<'5T+@H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@($EF('1H92!D96QE=&4@8G5T=&]N(&-O;F9I<FUA
M=&EO;B!H87,@8F5E;B!P<F5S<V5D(')E='5R;@H@("`@("H@("`@("`@("`@
M("`@("`@=')U92P@:68@86YY(&]T:&5R('-U8FUI="!B=71T;VX@:&%S(&)E
M96X@<')E<W-E9"!R971U<FX*("`@("`J("`@("`@("`@("`@("`@(&9A;'-E
M+B!)9B!F;W)M(&1I9"!N;W0@=F%L:61A=&4@<F5T=7)N(&YU;&PN"B`@("`@
M*B\*("`@(&9U;F-T:6]N('9A;&ED871E1&5L971E1F]R;2@F)&EN9F\I"B`@
M("!["B`@("`@("`@)&9O<FU?<W5B;6ET(#T@)'1H:7,M/E]V87)S+3YG970H
M)W-U8FUI=&)U='1O;B<I.PH*("`@("`@("!I9B`H)&9O<FU?<W5B;6ET(#T]
M(%\H(D1E;&5T92(I*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^7V9O<FTM
M/G9A;&ED871E*"1T:&ES+3Y?=F%R<RDI('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?9F]R;2T^9V5T26YF;R@D=&AI<RT^7W9A<G,L("1I;F9O*3L*("`@
M("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E:68@*"%E;7!T>2@D9F]R;5]S=6)M:70I*2!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!N
M=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5N9&5R<R!T:&4@961I="!F
M;W)M+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97)&;W)M*"1F;W)M7W-C
M<FEP="`]("=E9&ET+G!H<"<I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E
M("=(;W)D92]&;W)M+U)E;F1E<F5R+G!H<"<["B`@("`@("`@)')E;F1E<F5R
M(#T@)FYE=R!(;W)D95]&;W)M7U)E;F1E<F5R*"D["B`@("`@("`@)'1H:7,M
M/E]F;W)M+3YR96YD97)!8W1I=F4H)')E;F1E<F5R+"`D=&AI<RT^7W9A<G,L
M("1F;W)M7W-C<FEP="P@)W!O<W0G*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($-R96%T97,@86YY(&9O<FT@;V)J96-T<R!I9B!T:&5Y(&AA=F4@;F]T(&)E
M96X@:6YI=&EA;&ES960@>65T+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?9F]R;4EN:70H*0H@("`@>PH@
M("`@("`@(&EF("AI<U]N=6QL*"1T:&ES+3Y?=F%R<RDI('L*("`@("`@("`@
M("`@+RH@3F\@97AI<W1I;F<@=F%R<R!S970L(&=E="!T:&5M(&YO=RX@*B\*
M("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]687)I86)L97,N<&AP
M)SL*("`@("`@("`@("`@)'1H:7,M/E]V87)S(#T@)E9A<FEA8FQE<SHZ9V5T
M1&5F875L=%9A<FEA8FQE<R@I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I
M<U]A*"1T:&ES+3Y?9F]R;2P@)TAO<F1E7T9O<FTG*2D@>PH@("`@("`@("`@
M("`O*B!.;R!E>&ES=&EN9R!V86QI9"!F;W)M(&]B:F5C="!S970@<V\@<V5T
M('5P(&$@;F5W(&]N92X@*B\*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(
M;W)D92]&;W)M+G!H<"<["B`@("`@("`@("`@("1T:&ES+3Y?9F]R;2`]("9(
M;W)D95]&;W)M.CIS:6YG;&5T;VXH)R<L("1T:&ES+3Y?=F%R<RD["B`@("`@
M("`@?0H@("`@?0H*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U!E<FUS+V1A
M=&%T<F5E+G!H<```````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#8V
M-S<U(#$P-3$U-#,S-S,U(#`R,C<V-0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D
M92]$871A5')E92YP:'`G.PH*+RHJ"B`J(%1H92!097)M<U]D871A=')E93HZ
M(&-L87-S('!R;W9I9&5S(&$@1&%T851R964@9')I=F5R(&9O<B!T:&4@2&]R
M9&4*("H@<&5R;6ES<VEO;G,@<WES=&5M+@H@*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]D871A=')E92YP:'`L=B`Q+C8N,BXQ,B`R,#`V
M+S`W+S(P(#$X.C4P.C`U(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`Q+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J
M($-O<'ER:6=H="`R,#`T+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E
M+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N
M8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("!*86X@4V-H;F5I
M9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@
M0'!A8VMA9V4@2&]R9&5?4&5R;7,*("HO"F-L87-S(%!E<FUS7V1A=&%T<F5E
M(&5X=&5N9',@4&5R;7,@>PH*("`@("\J*@H@("`@("H@4&]I;G1E<B!T;R!A
M($1A=&%4<F5E(&EN<W1A;F-E('1O(&UA;F%G92!T:&4@9&EF9F5R96YT"B`@
M("`@*B!P97)M:7-S:6]N<RX*("`@("`J"B`@("`@*B!`=F%R($1A=&%4<F5E
M"B`@("`@*B\*("`@('9A<B`D7V1A=&%T<F5E.PH*("`@("\J*@H@("`@("H@
M0V]N<W1R=6-T;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(%!E<FUS7V1A=&%T
M<F5E*"D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@(&EF
M("AE;7!T>2@D8V]N9ELG9&%T871R964G75LG9')I=F5R)UTI*2!["B`@("`@
M("`@("`@($AO<F1E.CIF871A;"@G66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T
M851R964@8F%C:V5N9"!T;R!U<V4@=&AE(%!E<FUS($1A=&%4<F5E(&1R:79E
M<BXG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@
M)&1R:79E<B`]("1C;VYF6R=D871A=')E92==6R=D<FEV97(G73L*("`@("`@
M("`D=&AI<RT^7V1A=&%T<F5E(#T@)D1A=&%4<F5E.CIS:6YG;&5T;VXH)&1R
M:79E<BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@87)R87E?;65R9V4H2&]R9&4Z.F=E=$1R:79E<D-O;F9I9R@G
M9&%T871R964G+"`D9')I=F5R*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V=R
M;W5P)R`]/B`G:&]R9&4N<&5R;7,G*2DI.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@879A:6QA8FQE('!E<FUI<W-I;VYS(&9O<B!A(&=I
M=F5N(&QE=F5L+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@
M(%1H92!P97)M:7-S:6]N)W,@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("!!;B!A<G)A>2!O9B!A=F%I;&%B;&4@<&5R;6ES<VEO;G,@86YD
M('1H96ER('1I=&QE<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T079A:6QA
M8FQE*"1N86UE*0H@("`@>PH@("`@("`@(&EF("@D;F%M92`]/2!$051!5%)%
M15]23T]4*2!["B`@("`@("`@("`@("1N86UE(#T@)R<["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B!P87)E;G0Z.F=E=$%V86EL86)L92@D;F%M92D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!':79E;B!A('!E<FUI<W-I;VX@;F%M92P@
M<F5T=7)N<R!T:&4@=&ET;&4@9F]R('1H870@<&5R;6ES<VEO;B!B>0H@("`@
M("H@;&]O:VEN9R!I="!U<"!I;B!T:&4@87!P;&EC871I;VYS)W,@<&5R;6ES
M<VEO;B!A<&DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@
M5&AE('!E<FUI<W-I;VYS)W,@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE('1I=&QE(&9O<B!T:&4@<&5R;6ES<VEO;BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T5&ET;&4H)&YA;64I"B`@("!["B`@("`@("`@
M:68@*"1N86UE(#T]($1!5$%44D5%7U)/3U0I('L*("`@("`@("`@("`@<F5T
M=7)N(%\H(D%L;"!097)M:7-S:6]N<R(I.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@<&%R96YT.CIG9714:71L92@D;F%M92D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS(&$@;F5W('!E<FUI<W-I;VYS(&]B:F5C="X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@<&5R;6ES<VEO
M;B=S(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!$871A5')E94]B:F5C
M=%]097)M:7-S:6]N<R`@02!N97<@<&5R;6ES<VEO;G,@;V)J96-T+@H@("`@
M("HO"B`@("!F=6YC=&EO;B`F;F5W4&5R;6ES<VEO;B@D;F%M92D*("`@('L*
M("`@("`@("!I9B`H96UP='DH)&YA;64I*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"=097)M:7-S:6]N(&YA;65S(&UU<W0@8F4@
M;F]N+65M<'1Y)RD["B`@("`@("`@?0H*("`@("`@("`D='EP92`]("=M871R
M:7@G.PH@("`@("`@("1P87)A;7,@/2!N=6QL.PH@("`@("`@(&EF("@D<&]S
M(#T@<W1R<&]S*"1N86UE+"`G.B<I*2!["B`@("`@("`@("`@("1I;F9O(#T@
M)'1H:7,M/F=E=$%P<&QI8V%T:6]N4&5R;6ES<VEO;G,H<W5B<W1R*"1N86UE
M+"`P+"`D<&]S*2D["B`@("`@("`@("`@(&EF("@A:7-?82@D:6YF;RP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I;F9O
M6R=T>7!E)UTI("8F(&ES<V5T*"1I;F9O6R=T>7!E)UU;)&YA;65=*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1T>7!E(#T@)&EN9F];)W1Y<&4G75LD;F%M
M95T["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&EN9F];)W!A<F%M<R==*2`F)B!I<W-E="@D:6YF;ULG<&%R86US)UU;
M)&YA;65=*2D@>PH@("`@("`@("`@("`@("`@("`@("1P87)A;7,@/2`D:6YF
M;ULG<&%R86US)UU;)&YA;65=.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@("1P97)M(#T@)FYE=R!$871A5')E
M94]B:F5C=%]097)M:7-S:6]N*"1N86UE+"`D='EP92P@)'!A<F%M<RD["B`@
M("`@("`@)'!E<FTM/G-E=$1A=&%4<F5E*"1T:&ES+3Y?9&%T871R964I.PH*
M("`@("`@("!R971U<FX@)'!E<FT["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS(&$@1&%T851R965/8FIE8W1?4&5R;6ES<VEO;B!O8FIE8W0@8V]R
M<F5S<&]N9&EN9R!T;R!T:&4*("`@("`J(&YA;65D('!E<FUI<W-I;VXL('=I
M=&@@=&AE('5S97)S(&%N9"!O=&AE<B!D871A(')E=')I979E9`H@("`@("H@
M87!P<F]P<FEA=&5L>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N
M86UE("!4:&4@;F%M92!O9B!T:&4@<&5R;6ES<VEO;B!T;R!R971R:65V92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=%!E<FUI<W-I;VXH)&YA;64I"B`@
M("!["B`@("`@("`@+RH@0V%C:&4@;V8@<')E=FEO=7-L>2!R971R:65V960@
M<&5R;6ES<VEO;G,N("HO"B`@("`@("`@<W1A=&EC("1P97)M<T-A8VAE(#T@
M87)R87DH*3L*"B`@("`@("`@:68@*&ES<V5T*"1P97)M<T-A8VAE6R1N86UE
M72DI('L*("`@("`@("`@("`@<F5T=7)N("1P97)M<T-A8VAE6R1N86UE73L*
M("`@("`@("!]"@H@("`@("`@("1P97)M<T-A8VAE6R1N86UE72`]("1T:&ES
M+3Y?9&%T871R964M/F=E=$]B:F5C="@D;F%M92P@)T1A=&%4<F5E3V)J96-T
M7U!E<FUI<W-I;VXG*3L*("`@("`@("!R971U<FX@)'!E<FUS0V%C:&5;)&YA
M;65=.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A($1A=&%4<F5E
M3V)J96-T7U!E<FUI<W-I;VX@;V)J96-T(&-O<G)E<W!O;F1I;F<@=&\@=&AE
M(&=I=F5N"B`@("`@*B!U;FEQ=64@240L('=I=&@@=&AE('5S97)S(&%N9"!O
M=&AE<B!D871A(')E=')I979E9"!A<'!R;W!R:6%T96QY+@H@("`@("H*("`@
M("`J($!P87)A;2!I;G1E9V5R("1C:60@(%1H92!U;FEQ=64@240@;V8@=&AE
M('!E<FUI<W-I;VX@=&\@<F5T<FEE=F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9G971097)M:7-S:6]N0GE)9"@D8VED*0H@("`@>PH@("`@("`@(&EF("@D
M8VED(#T]($1!5$%44D5%7U)/3U0I('L*("`@("`@("`@("`@)&]B:F5C="`]
M("8D=&AI<RT^;F5W4&5R;6ES<VEO;BA$051!5%)%15]23T]4*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D;V)J96-T(#T@)B1T:&ES+3Y?9&%T
M871R964M/F=E=$]B:F5C=$)Y260H)&-I9"P@)T1A=&%4<F5E3V)J96-T7U!E
M<FUI<W-I;VXG*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1O8FIE8W0[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@<&5R;6ES<VEO;B!T;R!T
M:&4@<&5R;6ES<VEO;G,@<WES=&5M+B!4:&4@<&5R;6ES<VEO;B!M=7-T(&9I
M<G-T"B`@("`@*B!B92!C<F5A=&5D('=I=&@@4&5R;3HZ;F5W4&5R;6ES<VEO
M;B@I+"!A;F0@:&%V92!A;GD@:6YI=&EA;"!U<V5R<PH@("`@("H@861D960@
M=&\@:70L(&)E9F]R92!T:&ES(&9U;F-T:6]N(&ES(&-A;&QE9"X*("`@("`J
M"B`@("`@*B!`<&%R86T@1&%T851R965/8FIE8W1?4&5R;6ES<VEO;B`D<&5R
M;2`@5&AE(&YE=R!P97)M(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@
M861D4&5R;6ES<VEO;B@F)'!E<FTI"B`@("!["B`@("`@("`@:68@*"%I<U]A
M*"1P97)M+"`G1&%T851R965/8FIE8W1?4&5R;6ES<VEO;B<I*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=097)M:7-S:6]N<R!M
M=7-T(&)E($1A=&%4<F5E3V)J96-T7U!E<FUI<W-I;VX@;V)J96-T<R!O<B!E
M>'1E;F0@=&AA="!C;&%S<RXG*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D=&AI<RT^7V1A=&%T<F5E+3YA9&0H)'!E<FTI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5M;W9E<R!A('!E<FUI<W-I;VX@9G)O;2!T:&4@<&5R;6ES
M<VEO;G,@<WES=&5M('!E<FUA;F5N=&QY+@H@("`@("H*("`@("`J($!P87)A
M;2!$871A5')E94]B:F5C=%]097)M:7-S:6]N("1P97)M("!4:&4@<&5R;6ES
M<VEO;B!T;R!R96UO=F4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9F]R8V4@
M("`@("`@("`@("`@("`@("`@1F]R8V4@=&\@<F5M;W9E(&5V97)Y(&-H:6QD
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F5097)M:7-S:6]N*"8D<&5R
M;2P@)&9O<F-E(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"%I<U]A*"1P
M97)M+"`G1&%T851R965/8FIE8W1?4&5R;6ES<VEO;B<I*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=097)M:7-S:6]N<R!M=7-T
M(&)E($1A=&%4<F5E3V)J96-T7U!E<FUI<W-I;VX@;V)J96-T<R!O<B!E>'1E
M;F0@=&AA="!C;&%S<RXG*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M=&AI<RT^7V1A=&%T<F5E+3YR96UO=F4H)'!E<FTM/F=E=$YA;64H*2P@)&9O
M<F-E*3L*("`@('T*"B`@("`O*BH*("`@("`J($9I;F1S(&]U="!W:&%T(')I
M9VAT<R!T:&4@9VEV96X@=7-E<B!H87,@=&\@=&AI<R!O8FIE8W0N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&UI>&5D("1P97)M:7-S:6]N("!4:&4@9G5L;"!P
M97)M:7-S:6]N(&YA;64@;V8@=&AE(&]B:F5C="!T;PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("!C:&5C:R!T:&4@<&5R;6ES<VEO;G,@;V8L
M(&]R('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!$871A
M5')E94]B:F5C=%]097)M:7-S:6]N(&]B:F5C="X*("`@("`J($!P87)A;2!S
M=')I;F<@)'5S97(@("`@("`@5&AE('5S97(@=&\@8VAE8VL@9F]R+B!$969A
M=6QT<R!T;R!T:&4@8W5R<F5N=`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("!U<V5R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8W)E871O<B`@
M("!4:&4@=7-E<B!W:&\@8W)E871E9"!T:&4@;V)J96-T+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@($$@8FET;6%S:R!O9B!P97)M:7-S:6]N<RP@
M82!P97)M:7-S:6]N('9A;'5E+"!O<B!A;B!A<G)A>0H@("`@("H@("`@("`@
M("`@("`@("`@;V8@<&5R;6ES<VEO;B!V86QU97,@=&AE('5S97(@:&%S+"!D
M97!E;F1I;F<@;VX@=&AE"B`@("`@*B`@("`@("`@("`@("`@("!P97)M:7-S
M:6]N('1Y<&4@86YD('=H971H97(@=&AE('!E<FUI<W-I;VX@=F%L=64@:7,*
M("`@("`J("`@("`@("`@("`@("`@(&%M8FEG=6]U<RX@1F%L<V4@:68@=&AE
M<F4@:7,@;F\@<W5C:"!P97)M<VES<VEO;BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T4&5R;6ES<VEO;G,H)'!E<FUI<W-I;VXL("1U<V5R(#T@;G5L;"P@
M)&-R96%T;W(@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D<&5R
M;6ES<VEO;BP@)T1A=&%4<F5E3V)J96-T7U!E<FUI<W-I;VXG*2D@>PH@("`@
M("`@("`@("`D<&5R;6ES<VEO;B`]("8D=&AI<RT^9V5T4&5R;6ES<VEO;B@D
M<&5R;6ES<VEO;BD["B`@("`@("`@("`@(&EF("AI<U]A*"1P97)M:7-S:6]N
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!(;W)D93HZ;&]G
M365S<V%G92@D<&5R;6ES<VEO;BP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%2
M7TQ/1U]$14)51RD["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@D=7-E<B`]/3T@
M;G5L;"D@>PH@("`@("`@("`@("`D=7-E<B`]($%U=&@Z.F=E=$%U=&@H*3L*
M("`@("`@("!]"@H@("`@("`@("\O($EF('1H:7,@:7,@82!G=65S="!U<V5R
M+"!O;FQY(&-H96-K(&=U97-T('!E<FUI<W-I;VYS+@H@("`@("`@(&EF("AE
M;7!T>2@D=7-E<BDI('L*("`@("`@("`@("`@<F5T=7)N("1P97)M:7-S:6]N
M+3YG971'=65S=%!E<FUI<W-I;VYS*"D["B`@("`@("`@?0H*("`@("`@("`O
M+R!)9B`D8W)E871O<B!W87,@<W!E8VEF:65D+"!C:&5C:R!C<F5A=&]R('!E
M<FUI<W-I;VYS+@H@("`@("`@(&EF("@D8W)E871O<B`A/3T@;G5L;"D@>PH@
M("`@("`@("`@("`O+R!)9B!T:&4@=7-E<B!I<R!T:&4@8W)E871O<B!O9B!T
M:&4@979E;G0@<V5E(&EF('1H97)E"B`@("`@("`@("`@("\O(&%R92!C<F5A
M=&]R('!E<FUI<W-I;VYS+@H@("`@("`@("`@("!I9B`H<W1R;&5N*"1U<V5R
M*2`F)B`D=7-E<B`]/3T@)&-R96%T;W(@)B8*("`@("`@("`@("`@("`@("@D
M<&5R;7,@/2`D<&5R;6ES<VEO;BT^9V5T0W)E871O<E!E<FUI<W-I;VYS*"DI
M("$]/2!N=6QL*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'!E<FUS.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!#:&5C:R!U<V5R
M+6QE=F5L('!E<FUI<W-I;VYS+@H@("`@("`@("1U<V5R<&5R;7,@/2`D<&5R
M;6ES<VEO;BT^9V5T57-E<E!E<FUI<W-I;VYS*"D["B`@("`@("`@:68@*&ES
M<V5T*"1U<V5R<&5R;7-;)'5S97)=*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'5S97)P97)M<ULD=7-E<ET["B`@("`@("`@?0H*("`@("`@("`O+R!)9B!N
M;R!U<V5R('!E<FUI<W-I;VYS(&%R92!F;W5N9"P@=')Y(&=R;W5P('!E<FUI
M<W-I;VYS+@H@("`@("`@(&EF("AI<W-E="@D<&5R;6ES<VEO;BT^9&%T85LG
M9W)O=7!S)UTI("8F"B`@("`@("`@("`@(&ES7V%R<F%Y*"1P97)M:7-S:6]N
M+3YD871A6R=G<F]U<',G72D@)B8*("`@("`@("`@("`@8V]U;G0H)'!E<FUI
M<W-I;VXM/F1A=&%;)V=R;W5P<R==*2D@>PH@("`@("`@("`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+T=R;W5P+G!H<"<["B`@("`@("`@("`@("1G<F]U<',@
M/2`F1W)O=7`Z.G-I;F=L971O;B@I.PH*("`@("`@("`@("`@)&-O;7!O<VET
M95]P97)M(#T@;G5L;#L*("`@("`@("`@("`@)'1Y<&4@/2`D<&5R;6ES<VEO
M;BT^9V5T*"=T>7!E)RD["B`@("`@("`@("`@(&9O<F5A8V@@*"1P97)M:7-S
M:6]N+3YD871A6R=G<F]U<',G72!A<R`D9W)O=7`@/3X@)'!E<FTI('L*("`@
M("`@("`@("`@("`@(&EF("@D9W)O=7!S+3YU<V5R27-);D=R;W5P*"1U<V5R
M+"`D9W)O=7`I*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1C;VUP;W-I
M=&5?<&5R;2`]/3T@;G5L;"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M8V]M<&]S:71E7W!E<FT@/2`D='EP92`]/2`G;6%T<FEX)R`_(#`@.B!A<G)A
M>2@I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("!I9B`H)'1Y<&4@/3T@)VUA=')I>"<I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&-O;7!O<VET95]P97)M('P]("1P97)M.PH@("`@("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1C;VUP
M;W-I=&5?<&5R;5M=(#T@)'!E<FT["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!I
M9B`H)&-O;7!O<VET95]P97)M("$]/2!N=6QL*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@)&-O;7!O<VET95]P97)M.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("`O+R!)9B!T:&5R92!A<F4@9&5F875L="!P97)M:7-S
M:6]N<RP@<F5T=7)N('1H96TN"B`@("`@("`@:68@*"@D<&5R;7,@/2`D<&5R
M;6ES<VEO;BT^9V5T1&5F875L=%!E<FUI<W-I;VYS*"DI("$]/2!N=6QL*2![
M"B`@("`@("`@("`@(')E='5R;B`D<&5R;7,["B`@("`@("`@?0H*("`@("`@
M("`O+R!/=&AE<G=I<V4L(&1E;GD@86QL('!E<FUI<W-I;VYS('1O('1H92!O
M8FIE8W0N"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@=6YI<75E(&ED96YT:69I97(@;V8@=&AI<R!P
M97)M:7-S:6]N+@H@("`@("H*("`@("`J($!P87)A;2!$871A5')E94]B:F5C
M=%]097)M:7-S:6]N("1P97)M:7-S:6]N("!4:&4@<&5R;6ES<VEO;B!O8FIE
M8W0@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!G970@=&AE($E$(&]F+@H@("`@("H*("`@("`J($!R
M971U<FX@:6YT96=E<B`@5&AE('5N:7%U92!I9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T4&5R;6ES<VEO;DED*"1P97)M:7-S:6]N*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^7V1A=&%T<F5E+3YG971)9"@D<&5R;6ES<VEO
M;BT^9V5T3F%M92@I*3L*("`@('T*"B`@("`O*BH*("`@("`J($9I;F1S(&]U
M="!I9B!T:&4@=7-E<B!H87,@=&AE('-P96-I9FEE9"!R:6=H=',@=&\@=&AE
M(&=I=F5N(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P
M97)M:7-S:6]N("!4:&4@<&5R;6ES<VEO;B!T;R!C:&5C:RX*("`@("`J($!P
M87)A;2!S=')I;F<@)'5S97(@("`@("`@(%1H92!U<V5R('1O(&-H96-K(&9O
M<BX*("`@("`J($!P87)A;2!I;G1E9V5R("1P97)M("`@("`@(%1H92!P97)M
M:7-S:6]N(&QE=F5L('1H870@;F5E9',@=&\@8F4@8VAE8VME9`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D8W)E871O<B`@("`@5&AE(&-R96%T;W(@;V8@=&AE(&5V96YT
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!U
M<V5R(&AA<R!T:&4@<W!E8VEF:65D('!E<FUI<W-I;VYS+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!H87-097)M:7-S:6]N*"1P97)M:7-S:6]N+"`D=7-E<BP@
M)'!E<FTL("1C<F5A=&]R(#T@;G5L;"D*("`@('L*("`@("`@("!R971U<FX@
M*"1T:&ES+3YG971097)M:7-S:6]N<R@D<&5R;6ES<VEO;BP@)'5S97(L("1C
M<F5A=&]R*2`F("1P97)M*3L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K
M<R!I9B!A('!E<FUI<W-I;VX@97AI<W1S(&EN('1H92!S>7-T96TN"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&5R;6ES<VEO;B`@5&AE('!E<FUI
M<W-I;VX@=&\@8VAE8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!4<G5E(&EF('1H92!P97)M:7-S:6]N(&5X:7-T<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@97AI<W1S*"1P97)M:7-S:6]N*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7V1A=&%T<F5E+3YE>&ES=',H)'!E<FUI<W-I;VXI.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&QI<W0@;V8@<&%R96YT
M('!E<FUI<W-I;VYS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-H
M:6QD("!4:&4@;F%M92!O9B!T:&4@8VAI;&0@=&\@<F5T<FEE=F4@<&%R96YT
M<R!F;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!H87-H('=I
M=&@@86QL('!A<F5N=',@:6X@82!T<F5E(&9O<FUA="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T4&%R96YT<R@D8VAI;&0I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?9&%T871R964M/F=E=%!A<F5N=',H)&-H:6QD*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86QL('!E<FUI<W-I;VYS(&]F
M('1H92!S>7-T96T@:6X@82!T<F5E(&9O<FUA="X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!!(&AA<V@@=VET:"!A;&P@<&5R;6ES<VEO;G,@:6X@
M82!T<F5E(&9O<FUA="X*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=%1R964H
M*0H@("`@>PH@("`@("`@("1T<F5E(#T@)'1H:7,M/E]D871A=')E92T^9V5T
M*$1!5$%44D5%7T9/4DU!5%]&3$%4+"!$051!5%)%15]23T]4+"!T<G5E*3L*
M("`@("`@("!R971U<FX@)'1R964["B`@("!]"@I]"@HO*BH*("H@17AT96YS
M:6]N(&]F('1H92!$871A5')E94]B:F5C="!C;&%S<R!F;W(@<W1O<FEN9R!0
M97)M:7-S:6]N(&EN9F]R;6%T:6]N(&EN"B`J('1H92!$871A5')E92!D<FEV
M97(N($EF('EO=2!W86YT('1O('-T;W)E('-P96-I86QI>F5D(%!E<FUI<W-I
M;VX*("H@:6YF;W)M871I;VXL('EO=2!S:&]U;&0@97AT96YD('1H:7,@8VQA
M<W,@:6YS=&5A9"!O9B!E>'1E;F1I;F<*("H@1&%T851R965/8FIE8W0@9&ER
M96-T;'DN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R
M9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`R+C$*("H@0'!A8VMA9V4@2&]R
M9&5?4&5R;7,*("HO"F-L87-S($1A=&%4<F5E3V)J96-T7U!E<FUI<W-I;VX@
M97AT96YD<R!$871A5')E94]B:F5C="!["@H@("`@+RHJ"B`@("`@*B!4:&4@
M1&%T851R965/8FIE8W1?4&5R;6ES<VEO;B!C;VYS=')U8W1O<BX@2G5S="!M
M86ME<R!S=7)E('1O(&-A;&P@=&AE"B`@("`@*B!P87)E;G0@8V]N<W1R=6-T
M;W(@<V\@=&AA="!T:&4@<&5R;2=S(&YA;64@:7,@<V5T('!R;W!E<FQY+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("!4:&4@;F%M92!O
M9B!T:&4@<&5R;2X*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@("!4:&4@
M<&5R;6ES<VEO;B!T>7!E+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@
M($$@:&%S:"!W:71H(&%N>2!P87)A;65T97)S('1H870@=&AE('!E<FUI<W-I
M;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!T>7!E(&YE961S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!$871A5')E94]B:F5C=%]097)M:7-S:6]N
M*"1N86UE+"`D='EP92`]("=M871R:7@G+"`D<&%R86US(#T@;G5L;"D*("`@
M('L*("`@("`@("!P87)E;G0Z.D1A=&%4<F5E3V)J96-T*"1N86UE*3L*("`@
M("`@("`D=&AI<RT^9&%T85LG='EP92==(#T@)'1Y<&4["B`@("`@("`@:68@
M*&ES7V%R<F%Y*"1P87)A;7,I*2!["B`@("`@("`@("`@("1T:&ES+3YD871A
M6R=P87)A;7,G72`]("1P87)A;7,["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@1V5T<R!O;F4@;V8@=&AE(&%T=')I8G5T97,@;V8@=&AE(&]B
M:F5C="P@;W(@;G5L;"!I9B!I="!I<VXG="!D969I;F5D+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&%T=')I8G5T92`@5&AE(&%T=')I8G5T92!T
M;R!G970N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE('9A;'5E
M(&]F('1H92!A='1R:6)U=&4L(&]R(&YU;&PN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E="@D871T<FEB=71E*0H@("`@>PH@("`@("`@("1V86QU92`]('!A
M<F5N=#HZ9V5T*"1A='1R:6)U=&4I.PH@("`@("`@(&EF("@D=F%L=64@/3T]
M(&YU;&P@)B8@)&%T=')I8G5T92`]/2`G='EP92<I('L*("`@("`@("`@("`@
M)'9A;'5E(#T@)VUA=')I>"<["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D
M=F%L=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!5<&1A=&5S('1H92!P97)M
M:7-S:6]N<R!B87-E9"!O;B!D871A('!A<W-E9"!I;B!T:&4@87)R87DN"B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P97)M<R`@06X@87)R87D@8V]N
M=&%I;FEN9R!T:&4@<&5R;6ES<VEO;G,@=VAI8V@@87)E('1O(&)E"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("!U<&1A=&5D+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!U<&1A=&5097)M:7-S:6]N<R@D<&5R;7,I"B`@("!["B`@("`@
M("`@)'1Y<&4@/2`D=&AI<RT^9V5T*"=T>7!E)RD["@H@("`@("`@(&EF("@D
M='EP92`]/2`G;6%T<FEX)RD@>PH@("`@("`@("`@("`O*B!!<G)A>2!O9B!P
M97)M:7-S:6]N('1Y<&5S('1O(&ET97)A=&4@=&AR;W5G:"X@*B\*("`@("`@
M("`@("`@)'!E<FU?='EP97,@/2!097)M<SHZ9V5T4&5R;7-!<G)A>2@I.PH@
M("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)'!E<FUS(&%S("1P97)M7V-L
M87-S(#T^("1P97)M7W9A;'5E<RD@>PH@("`@("`@("`@("!S=VET8V@@*"1P
M97)M7V-L87-S*2!["B`@("`@("`@("`@(&-A<V4@)V1E9F%U;'0G.@H@("`@
M("`@("`@("!C87-E("=G=65S="<Z"B`@("`@("`@("`@(&-A<V4@)V-R96%T
M;W(G.@H@("`@("`@("`@("`@("`@:68@*"1T>7!E(#T]("=M871R:7@G*2![
M"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!E<FU?='EP97,@87,@
M)'9A;"`]/B`D;&%B96PI('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"%E;7!T>2@D<&5R;5]V86QU97-;)'9A;%TI*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^<V5T4&5R;2@D<&5R;5]C;&%S<RP@)'9A
M;"P@9F%L<V4I.PH@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G5N<V5T4&5R;2@D
M<&5R;5]C;&%S<RP@)'9A;"P@9F%L<V4I.PH@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M?2!E;'-E:68@*"%E;7!T>2@D<&5R;5]V86QU97,I*2!["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/G-E=%!E<FTH)'!E<FU?8VQA<W,L("1P97)M7W9A
M;'5E<RP@9F%L<V4I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^=6YS971097)M*"1P97)M7V-L87-S+"!N
M=6QL+"!F86QS92D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)W4G.@H@("`@("`@("`@("!C
M87-E("=G)SH*("`@("`@("`@("`@("`@("1P97)M260@/2!A<G)A>2@G8VQA
M<W,G(#T^("1P97)M7V-L87-S(#T]("=U)R`_("=U<V5R<R<@.B`G9W)O=7!S
M)RD["B`@("`@("`@("`@("`@("`O*B!&:6=U<F4@;W5T('=H870@;F%M97,@
M=&AA="!A<F4@<W1O<F5D(&EN('1H:7,@<&5R;6ES<VEO;@H@("`@("`@("`@
M("`@("`@("H@8VQA<W,@:&%V92!N;W0@8F5E;B!S=6)M:71T960@9F]R(&%N
M('5P9&%T92P@:64N(&AA=F4@8F5E;@H@("`@("`@("`@("`@("`@("H@<F5M
M;W9E9"!E;G1I<F5L>2X@*B\*("`@("`@("`@("`@("`@("1C=7)R96YT7VYA
M;65S(#T@:7-S970H)'1H:7,M/F1A=&%;)'!E<FU)9%LG8VQA<W,G75TI"B`@
M("`@("`@("`@("`@("`@("`@/R!A<G)A>5]K97ES*"1T:&ES+3YD871A6R1P
M97)M261;)V-L87-S)UU=*0H@("`@("`@("`@("`@("`@("`@(#H@87)R87DH
M*3L*("`@("`@("`@("`@("`@("1U<&1A=&5D7VYA;65S(#T@87)R87E?:V5Y
M<R@D<&5R;5]V86QU97,I.PH@("`@("`@("`@("`@("`@)')E;6]V961?;F%M
M97,@/2!A<G)A>5]D:69F*"1C=7)R96YT7VYA;65S+"`D=7!D871E9%]N86UE
M<RD["@H@("`@("`@("`@("`@("`@+RH@4F5M;W9E(&%N>2!N86UE<R!T:&%T
M(&AA=F4@8F5E;B!C;VUP;&5T96QY('5N<V5T+B`J+PH@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)')E;6]V961?;F%M97,@87,@)&YA;64I('L*("`@("`@
M("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^9&%T85LD<&5R;4ED6R=C;&%S
M<R==75LD;F%M95TI.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@("\J($EF(&YO=&AI;F<@=&\@86-T=6%L;'D@=7!D871E(&9I;FES:"!W
M:71H('1H:7,@8V%S92X@*B\*("`@("`@("`@("`@("`@(&EF("@D<&5R;5]V
M86QU97,@/3T](&YU;&PI('L*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU
M93L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O*B!,;V]P
M('1H<F]U9V@@=&AE(&YA;65S(&%N9"!U<&1A=&4@<&5R;6ES<VEO;G,@9F]R
M(&5A8V@N("HO"B`@("`@("`@("`@("`@("!F;W)E86-H("@D<&5R;5]V86QU
M97,@87,@)&YA;64@/3X@)&YA;65?=F%L=65S*2!["B`@("`@("`@("`@("`@
M("`@("`@)'!E<FU)9%LG;F%M92==(#T@)&YA;64["@H@("`@("`@("`@("`@
M("`@("`@(&EF("@D='EP92`]/2`G;6%T<FEX)RD@>PH@("`@("`@("`@("`@
M("`@("`@("`@("!F;W)E86-H("@D<&5R;5]T>7!E<R!A<R`D=F%L(#T^("1L
M86)E;"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%E;7!T
M>2@D;F%M95]V86QU97-;)'9A;%TI*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/G-E=%!E<FTH)'!E<FU)9"P@)'9A;"P@9F%L
M<V4I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=6YS971097)M
M*"1P97)M260L("1V86PL(&9A;'-E*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@('T@96QS96EF("@A96UP='DH)&YA;65?=F%L=65S*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T4&5R;2@D<&5R;4ED
M+"`D;F%M95]V86QU97,L(&9A;'-E*3L*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=6YS9710
M97)M*"1P97)M260L(&YU;&PL(&9A;'-E*3L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!&25A-13H@;F5E9',@9&]C<PH@("`@("HO"B`@("!F=6YC=&EO;B!S9710
M97)M*"1P97)M260L("1P97)M:7-S:6]N+"`D=7!D871E(#T@=')U92D*("`@
M('L*("`@("`@("!I9B`H:7-?87)R87DH)'!E<FU)9"DI('L*("`@("`@("`@
M("`@:68@*&5M<'1Y*"1P97)M261;)VYA;64G72DI('L*("`@("`@("`@("`@
M("`@(')E='5R;CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)'1H
M:7,M/F=E="@G='EP92<I(#T]("=M871R:7@G("8F"B`@("`@("`@("`@("`@
M("!I<W-E="@D=&AI<RT^9&%T85LD<&5R;4ED6R=C;&%S<R==75LD<&5R;4ED
M6R=N86UE)UU=*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/F1A=&%;)'!E
M<FU)9%LG8VQA<W,G75U;)'!E<FU)9%LG;F%M92==72!\/2`D<&5R;6ES<VEO
M;CL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES
M+3YD871A6R1P97)M261;)V-L87-S)UU=6R1P97)M261;)VYA;64G75T@/2`D
M<&5R;6ES<VEO;CL*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(&EF("@D=&AI<RT^9V5T*"=T>7!E)RD@/3T@)VUA=')I>"<@
M)B8*("`@("`@("`@("`@("`@(&ES<V5T*"1T:&ES+3YD871A6R1P97)M261=
M*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/F1A=&%;)'!E<FU)9%T@?#T@
M)'!E<FUI<W-I;VX["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^9&%T85LD<&5R;4ED72`]("1P97)M:7-S:6]N.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H)'5P9&%T92D@>PH@
M("`@("`@("`@("`D=&AI<RT^<V%V92@I.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($9)6$U%.B!N965D<R!D;V-S"B`@("`@*B\*("`@(&9U
M;F-T:6]N('5N<V5T4&5R;2@D<&5R;4ED+"`D<&5R;6ES<VEO;BP@)'5P9&%T
M92`]('1R=64I"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1P97)M260I
M*2!["B`@("`@("`@("`@(&EF("AE;7!T>2@D<&5R;4ED6R=N86UE)UTI*2![
M"B`@("`@("`@("`@("`@("!R971U<FX["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@:68@*"1T:&ES+3YG970H)W1Y<&4G*2`]/2`G;6%T<FEX)RD@>PH@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YD871A6R1P97)M261;
M)V-L87-S)UU=6R1P97)M261;)VYA;64G75TI*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/F1A=&%;)'!E<FU)9%LG8VQA<W,G75U;)'!E<FU)9%LG
M;F%M92==72`F/2!^)'!E<FUI<W-I;VX["B`@("`@("`@("`@("`@("`@("`@
M:68@*&5M<'1Y*"1T:&ES+3YD871A6R1P97)M261;)V-L87-S)UU=6R1P97)M
M261;)VYA;64G75TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T
M*"1T:&ES+3YD871A6R1P97)M261;)V-L87-S)UU=6R1P97)M261;)VYA;64G
M75TI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("!I9B`H)'5P9&%T92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^<V%V92@I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@('5N
M<V5T*"1T:&ES+3YD871A6R1P97)M261;)V-L87-S)UU=6R1P97)M261;)VYA
M;64G75TI.PH@("`@("`@("`@("`@("`@:68@*"1U<&1A=&4I('L*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^<V%V92@I.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M:68@*"1T:&ES+3YG970H)W1Y<&4G*2`]/2`G;6%T<FEX)RD@>PH@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YD871A6R1P97)M261=*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YD871A6R1P97)M261=("8]('XD
M<&5R;6ES<VEO;CL*("`@("`@("`@("`@("`@("`@("!I9B`H)'5P9&%T92D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V%V92@I.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES+3YD871A
M6R1P97)M261=*3L*("`@("`@("`@("`@("`@(&EF("@D=7!D871E*2!["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G-A=F4H*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($=R86YT<R!A('5S97(@861D:71I;VYA;"!P97)M:7-S:6]N<R!T
M;R!T:&ES(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U
M<V5R("`@("`@("`@(%1H92!U<V5R('1O(&=R86YT(&%D9&ET:6]N86P@<&5R
M;6ES<VEO;G,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M=&\N"B`@("`@*B!`<&%R86T@8V]N<W1A;G0@)'!E<FUI<W-I;VX@(%1H92!P
M97)M:7-S:6]N("A015)-4U]$14Q%5$4L(&5T8RXI('1O(&%D9"X*("`@("`J
M($!P87)A;2!B;V]L96%N("1U<&1A=&4@("`@("`@5VAE=&AE<B!T;R!A=71O
M;6%T:6-A;&QY('5P9&%T92!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8F%C:V5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@861D
M57-E<E!E<FUI<W-I;VXH)'5S97(L("1P97)M:7-S:6]N+"`D=7!D871E(#T@
M=')U92D*("`@('L*("`@("`@("!I9B`H96UP='DH)'5S97(I*2!["B`@("`@
M("`@("`@(')E='5R;CL*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YG
M970H)W1Y<&4G*2`]/2`G;6%T<FEX)R`F)@H@("`@("`@("`@("!I<W-E="@D
M=&AI<RT^9&%T85LG=7-E<G,G75LD=7-E<ETI*2!["B`@("`@("`@("`@("1T
M:&ES+3YD871A6R=U<V5R<R==6R1U<V5R72!\/2`D<&5R;6ES<VEO;CL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^9&%T85LG=7-E<G,G
M75LD=7-E<ET@/2`D<&5R;6ES<VEO;CL*("`@("`@("!]"@H@("`@("`@(&EF
M("@D=7!D871E*2!["B`@("`@("`@("`@("1T:&ES+3YS879E*"D["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1W)A;G1S(&=U97-T<R!A9&1I
M=&EO;F%L('!E<FUI<W-I;VYS('1O('1H:7,@;V)J96-T+@H@("`@("H*("`@
M("`J($!P87)A;2!C;VYS=&%N="`D<&5R;6ES<VEO;B`@5&AE('!E<FUI<W-I
M;VX@*%!%4DU37T1%3$5412P@971C+BD@=&\@861D+@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)'5P9&%T92`@("`@("!7:&5T:&5R('1O(&%U=&]M871I8V%L
M;'D@=7!D871E('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!B86-K96YD+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1'=65S=%!E
M<FUI<W-I;VXH)'!E<FUI<W-I;VXL("1U<&1A=&4@/2!T<G5E*0H@("`@>PH@
M("`@("`@(&EF("@D=&AI<RT^9V5T*"=T>7!E)RD@/3T@)VUA=')I>"<@)B8*
M("`@("`@("`@("`@:7-S970H)'1H:7,M/F1A=&%;)V=U97-T)UTI*2!["B`@
M("`@("`@("`@("1T:&ES+3YD871A6R=G=65S="==('P]("1P97)M:7-S:6]N
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YD871A6R=G
M=65S="==(#T@)'!E<FUI<W-I;VX["B`@("`@("`@?0H*("`@("`@("!I9B`H
M)'5P9&%T92D@>PH@("`@("`@("`@("`D=&AI<RT^<V%V92@I.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($=R86YT<R!C<F5A=&]R<R!A9&1I
M=&EO;F%L('!E<FUI<W-I;VYS('1O('1H:7,@;V)J96-T+@H@("`@("H*("`@
M("`J($!P87)A;2!C;VYS=&%N="`D<&5R;6ES<VEO;B`@5&AE('!E<FUI<W-I
M;VX@*%!%4DU37T1%3$5412P@971C+BD@=&\@861D+@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)'5P9&%T92`@("`@("!7:&5T:&5R('1O(&%U=&]M871I8V%L
M;'D@=7!D871E('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!B86-K96YD+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1#<F5A=&]R
M4&5R;6ES<VEO;B@D<&5R;6ES<VEO;BP@)'5P9&%T92`]('1R=64I"B`@("![
M"B`@("`@("`@:68@*"1T:&ES+3YG970H)W1Y<&4G*2`]/2`G;6%T<FEX)R`F
M)@H@("`@("`@("`@("!I<W-E="@D=&AI<RT^9&%T85LG8W)E871O<B==*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^9&%T85LG8W)E871O<B==('P]("1P97)M
M:7-S:6]N.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YD
M871A6R=C<F5A=&]R)UT@/2`D<&5R;6ES<VEO;CL*("`@("`@("!]"@H@("`@
M("`@(&EF("@D=7!D871E*2!["B`@("`@("`@("`@("1T:&ES+3YS879E*"D[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1W)A;G1S(&%D9&ET
M:6]N86P@9&5F875L="!P97)M:7-S:6]N<R!T;R!T:&ES(&]B:F5C="X*("`@
M("`J"B`@("`@*B!`<&%R86T@8V]N<W1A;G0@)'!E<FUI<W-I;VX@(%1H92!P
M97)M:7-S:6]N("A015)-4U]$14Q%5$4L(&5T8RXI('1O(&%D9"X*("`@("`J
M($!P87)A;2!B;V]L96%N("1U<&1A=&4@("`@("`@5VAE=&AE<B!T;R!A=71O
M;6%T:6-A;&QY('5P9&%T92!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8F%C:V5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@861D
M1&5F875L=%!E<FUI<W-I;VXH)'!E<FUI<W-I;VXL("1U<&1A=&4@/2!T<G5E
M*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^9V5T*"=T>7!E)RD@/3T@)VUA
M=')I>"<@)B8*("`@("`@("`@("`@:7-S970H)'1H:7,M/F1A=&%;)V1E9F%U
M;'0G72DI('L*("`@("`@("`@("`@)'1H:7,M/F1A=&%;)V1E9F%U;'0G72!\
M/2`D<&5R;6ES<VEO;CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M=&AI<RT^9&%T85LG9&5F875L="==(#T@)'!E<FUI<W-I;VX["B`@("`@("`@
M?0H*("`@("`@("!I9B`H)'5P9&%T92D@>PH@("`@("`@("`@("`D=&AI<RT^
M<V%V92@I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=R86YT
M<R!A(&=R;W5P(&%D9&ET:6]N86P@<&5R;6ES<VEO;G,@=&\@=&AI<R!O8FIE
M8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&=R;W5P260@("`@
M("!4:&4@:60@;V8@=&AE(&=R;W5P('1O(&=R86YT(&%D9&ET:6]N86P*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<&5R;6ES<VEO;G,@
M=&\N"B`@("`@*B!`<&%R86T@8V]N<W1A;G0@)'!E<FUI<W-I;VX@(%1H92!P
M97)M:7-S:6]N("A015)-4U]$14Q%5$4L(&5T8RXI('1O(&%D9"X*("`@("`J
M($!P87)A;2!B;V]L96%N("1U<&1A=&4@("`@("`@5VAE=&AE<B!T;R!A=71O
M;6%T:6-A;&QY('5P9&%T92!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8F%C:V5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@861D
M1W)O=7!097)M:7-S:6]N*"1G<F]U<$ED+"`D<&5R;6ES<VEO;BP@)'5P9&%T
M92`]('1R=64I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1G<F]U<$ED*2D@
M>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("!I9B`H
M)'1H:7,M/F=E="@G='EP92<I(#T]("=M871R:7@G("8F"B`@("`@("`@("`@
M(&ES<V5T*"1T:&ES+3YD871A6R=G<F]U<',G75LD9W)O=7!)9%TI*2!["B`@
M("`@("`@("`@("1T:&ES+3YD871A6R=G<F]U<',G75LD9W)O=7!)9%T@?#T@
M)'!E<FUI<W-I;VX["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H
M:7,M/F1A=&%;)V=R;W5P<R==6R1G<F]U<$ED72`]("1P97)M:7-S:6]N.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"1U<&1A=&4I('L*("`@("`@("`@("`@
M)'1H:7,M/G-A=F4H*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!296UO=F5S(&$@<&5R;6ES<VEO;B!T:&%T(&$@=7-E<B!C=7)R96YT;'D@
M:&%S(&]N('1H:7,@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'5S97(@("`@("`@("`@5&AE('5S97(@=&\@<F5M;W9E('1H92!P97)M
M:7-S:6]N(&9R;VTN"B`@("`@*B!`<&%R86T@8V]N<W1A;G0@)'!E<FUI<W-I
M;VX@(%1H92!P97)M:7-S:6]N("A015)-4U]$14Q%5$4L(&5T8RXI('1O"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E;6]V92X*("`@
M("`J($!P87)A;2!B;V]L96%N("1U<&1A=&4@("`@("`@5VAE=&AE<B!T;R!A
M=71O;6%T:6-A;&QY('5P9&%T92!T:&4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8F%C:V5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<F5M;W9E57-E<E!E<FUI<W-I;VXH)'5S97(L("1P97)M:7-S:6]N+"`D=7!D
M871E(#T@=')U92D*("`@('L*("`@("`@("!I9B`H96UP='DH)'5S97(I('Q\
M("%I<W-E="@D=&AI<RT^9&%T85LG=7-E<G,G75LD=7-E<ETI*2!["B`@("`@
M("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^
M9V5T*"=T>7!E)RD@/3T@)VUA=')I>"<I('L*("`@("`@("`@("`@)'1H:7,M
M/F1A=&%;)W5S97)S)UU;)'5S97)=("8]('XD<&5R;6ES<VEO;CL*("`@("`@
M("`@("`@:68@*&5M<'1Y*"1T:&ES+3YD871A6R=U<V5R<R==6R1U<V5R72DI
M('L*("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES+3YD871A6R=U<V5R<R==
M6R1U<V5R72D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!U;G-E="@D=&AI<RT^9&%T85LG=7-E<G,G75LD=7-E<ETI.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"1U<&1A=&4I('L*("`@("`@("`@("`@
M)'1H:7,M/G-A=F4H*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!296UO=F5S(&$@<&5R;6ES<VEO;B!T:&%T(&=U97-T<R!C=7)R96YT;'D@
M:&%V92!O;B!T:&ES(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@8V]N
M<W1A;G0@)'!E<FUI<W-I;VX@(%1H92!P97)M:7-S:6]N("A015)-4U]$14Q%
M5$4L(&5T8RXI('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(')E;6]V92X*("`@("`J($!P87)A;2!B;V]L96%N("1U<&1A=&4@("`@
M("`@5VAE=&AE<B!T;R!A=71O;6%T:6-A;&QY('5P9&%T92!T:&4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8F%C:V5N9"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<F5M;W9E1W5E<W1097)M:7-S:6]N*"1P97)M:7-S
M:6]N+"`D=7!D871E(#T@=')U92D*("`@('L*("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3YD871A6R=G=65S="==*2D@>PH@("`@("`@("`@("!R971U<FX[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/F=E="@G='EP92<I(#T]
M("=M871R:7@G*2!["B`@("`@("`@("`@("1T:&ES+3YD871A6R=G=65S="==
M("8]('XD<&5R;6ES<VEO;CL*("`@("`@("`@("`@:68@*"1U<&1A=&4I('L*
M("`@("`@("`@("`@("`@("1T:&ES+3YS879E*"D["B`@("`@("`@("`@('T*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!U;G-E="@D=&AI<RT^9&%T
M85LG9W5E<W0G72D["B`@("`@("`@("`@(&EF("@D=7!D871E*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^<V%V92@I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E<R!A('!E<FUI<W-I
M;VX@=&AA="!C<F5A=&]R<R!C=7)R96YT;'D@:&%V92!O;B!T:&ES(&]B:F5C
M="X*("`@("`J"B`@("`@*B!`<&%R86T@8V]N<W1A;G0@)'!E<FUI<W-I;VX@
M(%1H92!P97)M:7-S:6]N("A015)-4U]$14Q%5$4L(&5T8RXI('1O"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E;6]V92X*("`@("`J
M($!P87)A;2!B;V]L96%N("1U<&1A=&4@("`@("`@5VAE=&AE<B!T;R!A=71O
M;6%T:6-A;&QY('5P9&%T92!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8F%C:V5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M
M;W9E0W)E871O<E!E<FUI<W-I;VXH)'!E<FUI<W-I;VXL("1U<&1A=&4@/2!T
M<G5E*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/F1A=&%;)V-R
M96%T;W(G72DI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"1T:&ES+3YG970H)W1Y<&4G*2`]/2`G;6%T<FEX)RD@>PH@
M("`@("`@("`@("`D=&AI<RT^9&%T85LG8W)E871O<B==("8]('XD<&5R;6ES
M<VEO;CL*("`@("`@("`@("`@:68@*"1U<&1A=&4I('L*("`@("`@("`@("`@
M("`@("1T:&ES+3YS879E*"D["B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!U;G-E="@D=&AI<RT^9&%T85LG8W)E871O<B==
M*3L*("`@("`@("`@("`@:68@*"1U<&1A=&4I('L*("`@("`@("`@("`@("`@
M("1T:&ES+3YS879E*"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!296UO=F5S(&$@9&5F875L="!P97)M:7-S:6]N
M(&]N('1H:7,@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!C;VYS=&%N
M="`D<&5R;6ES<VEO;B`@5&AE('!E<FUI<W-I;VX@*%!%4DU37T1%3$5412P@
M971C+BD@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M<F5M;W9E+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'5P9&%T92`@("`@("!7
M:&5T:&5R('1O(&%U=&]M871I8V%L;'D@=7!D871E('1H90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!B86-K96YD+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!R96UO=F5$969A=6QT4&5R;6ES<VEO;B@D<&5R;6ES<VEO
M;BP@)'5P9&%T92`]('1R=64I"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D
M=&AI<RT^9&%T85LG9&5F875L="==*2D@>PH@("`@("`@("`@("!R971U<FX[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/F=E="@G='EP92<I(#T]
M("=M871R:7@G*2!["B`@("`@("`@("`@("1T:&ES+3YD871A6R=D969A=6QT
M)UT@)CT@?B1P97)M:7-S:6]N.PH@("`@("`@("`@("!I9B`H)'5P9&%T92D@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-A=F4H*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@('5N<V5T*"1T:&ES+3YD
M871A6R=D969A=6QT)UTI.PH@("`@("`@("`@("!I9B`H)'5P9&%T92D@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/G-A=F4H*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V97,@82!P97)M
M:7-S:6]N('1H870@82!G<F]U<"!C=7)R96YT;'D@:&%S(&]N('1H:7,@;V)J
M96-T+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1G<F]U<$ED("`@
M("`@5&AE(&ED(&]F('1H92!G<F]U<"!T;R!R96UO=F4@=&AE"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('!E<FUI<W-I;VX@9G)O;2X*
M("`@("`J($!P87)A;2!C;VYS=&%N="`D<&5R;6ES<VEO;B`@5&AE('!E<FUI
M<W-I;VX@*%!%4DU37T1%3$5412P@971C+BD@=&\*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@<F5M;W9E+@H@("`@("H@0'!A<F%M(&)O
M;VQE86X@)'5P9&%T92`@("`@("!7:&5T:&5R('1O(&%U=&]M871I8V%L;'D@
M=7!D871E('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!B86-K96YD+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F5'<F]U<%!E
M<FUI<W-I;VXH)&=R;W5P260L("1P97)M:7-S:6]N+"`D=7!D871E(#T@=')U
M92D*("`@('L*("`@("`@("!I9B`H96UP='DH)&=R;W5P260I('Q\("%I<W-E
M="@D=&AI<RT^9&%T85LG9W)O=7!S)UU;)&=R;W5P261=*2D@>PH@("`@("`@
M("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/F=E
M="@G='EP92<I(#T]("=M871R:7@G*2!["B`@("`@("`@("`@("1T:&ES+3YD
M871A6R=G<F]U<',G75LD9W)O=7!)9%T@)CT@?B1P97)M:7-S:6]N.PH@("`@
M("`@("`@("!I9B`H96UP='DH)'1H:7,M/F1A=&%;)V=R;W5P<R==6R1G<F]U
M<$ED72DI('L*("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES+3YD871A6R=G
M<F]U<',G75LD9W)O=7!)9%TI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("@D=7!D871E*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V%V92@I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M=6YS970H)'1H:7,M/F1A=&%;)V=R;W5P<R==6R1G<F]U<$ED72D["B`@("`@
M("`@("`@(&EF("@D=7!D871E*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M<V%V92@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!A;B!A<G)A>2!O9B!A;&P@=7-E<B!P97)M:7-S
M:6]N<R!O;B!T:&ES(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D<&5R;2`@3&ES="!O;FQY('5S97)S('=I=&@@=&AI<R!P97)M:7-S
M:6]N(&QE=F5L+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@($1E9F%U
M;'1S('1O(&%L;"!U<V5R<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!!;&P@=7-E<B!P97)M:7-S:6]N<R!F;W(@=&AI<R!O8FIE8W0L(&EN9&5X
M960@8GD@=7-E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T57-E<E!E<FUI
M<W-I;VYS*"1P97)M(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3YD871A6R=U<V5R<R==*2!\?"`A:7-?87)R87DH)'1H:7,M/F1A
M=&%;)W5S97)S)UTI*2!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@I.PH@
M("`@("`@('T@96QS96EF("@A)'!E<FTI('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YD871A6R=U<V5R<R==.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1U<V5R<R`](&%R<F%Y*"D["B`@("`@("`@("`@(&9O<F5A8V@@
M*"1T:&ES+3YD871A6R=U<V5R<R==(&%S("1U<V5R(#T^("1U<&5R;2D@>PH@
M("`@("`@("`@("`@("`@:68@*"1U<&5R;2`F("1P97)M*2!["B`@("`@("`@
M("`@("`@("`@("`@)'5S97)S6R1U<V5R72`]("1U<&5R;3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)'5S
M97)S.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE(&=U97-T('!E<FUI<W-I;VYS(&]N('1H:7,@;V)J96-T+@H@("`@("H*
M("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(&=U97-T('!E<FUI<W-I;VYS
M(&]N('1H:7,@;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971'=65S
M=%!E<FUI<W-I;VYS*"D*("`@('L*("`@("`@("!R971U<FX@(65M<'1Y*"1T
M:&ES+3YD871A6R=G=65S="==*2`_"B`@("`@("`@("`@("1T:&ES+3YD871A
M6R=G=65S="==(#H*("`@("`@("`@("`@;G5L;#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE(&-R96%T;W(@<&5R;6ES<VEO;G,@;VX@=&AI
M<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@
M8W)E871O<B!P97)M:7-S:6]N<R!O;B!T:&ES(&]B:F5C="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T0W)E871O<E!E<FUI<W-I;VYS*"D*("`@('L*("`@
M("`@("!R971U<FX@(65M<'1Y*"1T:&ES+3YD871A6R=C<F5A=&]R)UTI(#\*
M("`@("`@("`@("`@)'1H:7,M/F1A=&%;)V-R96%T;W(G72`Z"B`@("`@("`@
M("`@(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!D
M969A=6QT('!E<FUI<W-I;VYS(&]N('1H:7,@;V)J96-T+@H@("`@("H*("`@
M("`J($!R971U<FX@:6YT96=E<B`@5&AE(&1E9F%U;'0@<&5R;6ES<VEO;G,@
M;VX@=&AI<R!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1E9F%U
M;'1097)M:7-S:6]N<R@I"B`@("!["B`@("`@("`@<F5T=7)N("%E;7!T>2@D
M=&AI<RT^9&%T85LG9&5F875L="==*2`_"B`@("`@("`@("`@("1T:&ES+3YD
M871A6R=D969A=6QT)UT@.@H@("`@("`@("`@("!N=6QL.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!A;B!A<G)A>2!O9B!A;&P@9W)O=7`@<&5R
M;6ES<VEO;G,@;VX@=&AI<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)'!E<FT@($QI<W0@;VYL>2!U<V5R<R!W:71H('1H:7,@<&5R
M;6ES<VEO;B!L979E;"X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!$
M969A=6QT<R!T;R!A;&P@=7-E<G,N"B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>2`@06QL(&=R;W5P('!E<FUI<W-I;VYS(&9O<B!T:&ES(&]B:F5C="P@
M:6YD97AE9"!B>2!G<F]U<"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1W)O
M=7!097)M:7-S:6]N<R@D<&5R;2`](&YU;&PI"B`@("!["B`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^9&%T85LG9W)O=7!S)UTI('Q\"B`@("`@("`@("`@
M("%I<U]A<G)A>2@D=&AI<RT^9&%T85LG9W)O=7!S)UTI*2!["B`@("`@("`@
M("`@(')E='5R;B!A<G)A>2@I.PH@("`@("`@('T@96QS96EF("@A)'!E<FTI
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YD871A6R=G<F]U<',G73L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9W)O=7!S(#T@87)R87DH
M*3L*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/F1A=&%;)V=R;W5P<R==
M(&%S("1G<F]U<"`]/B`D9W!E<FTI('L*("`@("`@("`@("`@("`@(&EF("@D
M9W!E<FT@)B`D<&5R;2D@>PH@("`@("`@("`@("`@("`@("`@("1G<F]U<'-;
M)&=R;W5P72`]("1G<&5R;3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!R971U<FX@)&=R;W5P<SL*("`@("`@("!]"B`@
M("!]"@I]"@```'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]3
M97-S:6]N2&%N9&QE<@``````````````````````````````````````````
M```````````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#`P,"`Q,#4Q-30S,S<S-2`P,C(R,3(`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+VUY<W%L+G!H<```````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#(T,C0P(#$P-3$U-#,S-S,U(#`R-#$U
M,0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@4V5S<VEO;DAA;F1L97(Z.B!I;7!L96UE;G1A=&EO;B!F
M;W(@37E344P@*&YA=&EV92DN"B`J"B`J(%)E<75I<F5D('!A<F%M971E<G,Z
M/'!R93X*("H@("`G:&]S='-P96,G("`@+2!4:&4@:&]S=&YA;64@;V8@=&AE
M(&1A=&%B87-E('-E<G9E<BX*("H@("`G<')O=&]C;VPG("`@+2!4:&4@8V]M
M;75N:6-A=&EO;B!P<F]T;V-O;"`H)W1C<"<L("=U;FEX)RP@971C+BDN"B`J
M("`@)W5S97)N86UE)R`@("T@5&AE('5S97)N86UE('=I=&@@=VAI8V@@=&\@
M8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N"B`J("`@)W!A<W-W;W)D)R`@("T@
M5&AE('!A<W-W;W)D(&%S<V]C:6%T960@=VET:"`G=7-E<FYA;64G+@H@*B`@
M("=D871A8F%S92<@("`M(%1H92!N86UE(&]F('1H92!D871A8F%S92X*("H@
M("`G=&%B;&4G("`@("`@+2!4:&4@;F%M92!O9B!T:&4@<V5S<VEO;F1A=&$@
M=&%B;&4@:6X@)V1A=&%B87-E)RX*("H@("`G<F]W;&]C:VEN9R<@+2!7:&5T
M:&5R('1O('5S92!R;W<M;&5V96P@;&]C:VEN9R!A;F0@=')A;G-A8W1I;VYS
M("A);FYO1$(I"B`J("`@("`@("`@("`@("`@("`@;W(@=&%B;&4M;&5V96P@
M;&]C:VEN9R`H37E)4T%-*2X\+W!R93X*("H*("H@4F5Q=6ER960@9F]R('-O
M;64@8V]N9FEG=7)A=&EO;G,Z/'!R93X*("H@("`G<&]R="<@(%1H92!P;W)T
M(&]N('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+CPO<')E/@H@
M*@H@*B!/<'1I;VYA;"!P87)A;65T97)S.CQP<F4^"B`J("`@)W!E<G-I<W1E
M;G0G("!5<V4@<&5R<VES=&5N="!$0B!C;VYN96-T:6]N<S\@*&)O;VQE86XI
M/"]P<F4^"B`J"B`J(%1H92!T86)L92!S=')U8W1U<F4@9F]R('1H92!397-S
M:6]N2&%N9&QE<B!C86X@8F4@9F]U;F0@:6X*("H@:&]R9&4O<V-R:7!T<R]S
M<6PO:&]R9&5?<V5S<VEO;FAA;F1L97(N<W%L+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]M>7-Q;"YP
M:'`L=B`Q+C$V+C$R+C$T(#(P,#8O,#,O,CD@,3DZ,#8Z-#8@:F%N($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EK92!#;V-H<F%N92`\;6EK
M94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#
M:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT
M(#(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A;64@/&UI:V5`9W)A9G1O
M;FAA;&PN8V\N;GH^"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H
M;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(
M;W)D95]397-S:6]N2&%N9&QE<@H@*B\*8VQA<W,@4V5S<VEO;DAA;F1L97)?
M;7ES<6P@97AT96YD<R!397-S:6]N2&%N9&QE<B!["@H@("`@+RHJ"B`@("`@
M*B!(86YD;&4@9F]R('1H92!C=7)R96YT(&1A=&%B87-E(&-O;FYE8W1I;VXN
M"B`@("`@*@H@("`@("H@0'9A<B!R97-O=7)C90H@("`@("HO"B`@("!V87(@
M)%]D8CL*"B`@("`O*BH*("`@("`J($%R92!W92!C;VYN96-T960@=&\@=&AE
M(%-13"!S97)V97(N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@
M*B\*("`@('9A<B`D7V-O;FYE8W1E9"`](&9A;'-E.PH*("`@("\J*@H@("`@
M("H@0VQO<V4@=&AE(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E
M(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@8VQO<V4H*0H@("`@
M>PH@("`@("`@("\J($1I<V-O;FYE8W0@9G)O;2!D871A8F%S92X@*B\*("`@
M("`@("!I9B`H)'1H:7,M/E]C;VYN96-T960I('L*("`@("`@("`@("`@)'1H
M:7,M/E]C;VYN96-T960@/2!F86QS93L*("`@("`@("`@("`@<F5T=7)N($!M
M>7-Q;%]C;&]S92@D=&AI<RT^7V1B*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5A9"!T:&4@9&%T
M82!F;W(@82!P87)T:6-U;&%R('-E<W-I;VX@:61E;G1I9FEE<B!F<F]M('1H
M90H@("`@("H@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE('-E<W-I;VX@:61E;G1I9FEE<BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('-E<W-I;VX@9&%T
M82X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A9"@D:60I"B`@("!["B`@("`@
M("`@+RH@36%K92!S=7)E('=E(&AA=F4@82!V86QI9"!D871A8F%S92!C;VYN
M96-T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@
M("`O*B!397-S:6]N('1I;65O=70L(&1O;B=T(')E;'D@;VX@9V%R8F%G92!C
M;VQL96-T:6]N+B`J+PH@("`@("`@("1T:6UE;W5T(#T@=&EM92@I("T@:6YI
M7V=E="@G<V5S<VEO;BYG8U]M87AL:69E=&EM92<I.PH*("`@("`@("`D<75E
M<GD@/2!S<')I;G1F*"=314Q%0U0@<V5S<VEO;E]D871A($923TT@)7,@5TA%
M4D4@<V5S<VEO;E]I9"`]("5S)R`N"B`@("`@("`@("`@("`@("`@("`@("`@
M("`G($%.1"!S97-S:6]N7VQA<W1M;V1I9FEE9"`^("5S)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]Q=6]T92@D:60I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1I;65O=70I.PH*("`@("`@("!I9B`H
M(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=R;W=L;V-K:6YG)UTI*2!["B`@("`@
M("`@("`@("\J(%-T87)T(&$@=')A;G-A8W1I;VXN("HO"B`@("`@("`@("`@
M("1R97-U;'0@/2!`;7ES<6Q?<75E<GDH)U-405)4(%1204Y304-424].)RP@
M)'1H:7,M/E]D8BD["B`@("`@("`@("`@("1Q=65R>2`N/2`G($9/4B!54$1!
M5$4G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R97-U;'0@/2!`
M;7ES<6Q?<75E<GDH)TQ/0TL@5$%"3$53("<@+B`D=&AI<RT^7W!A<F%M<ULG
M=&%B;&4G72`N("<@5U))5$4G+"`D=&AI<RT^7V1B*3L*("`@("`@("!]"B`@
M("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@(')E='5R;B`G)SL*
M("`@("`@("!]"@H@("`@("`@("\J($QO9R!T:&4@<75E<GD@870@82!$14)5
M1R!L;V<@;&5V96PN("HO"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R
M:6YT9B@G4U%,(%%U97)Y(&)Y(%-E<W-I;VY(86YD;&5R7VUY<W%L.CIR96%D
M*"DZ('%U97)Y(#T@(B5S(B<L("1Q=65R>2DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD[
M"@H@("`@("`@("1R97-U;'0@/2!`;7ES<6Q?<75E<GDH)'%U97)Y+"`D=&AI
M<RT^7V1B*3L*("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@
M2&]R9&4Z.FQO9TUE<W-A9V4H)T5R<F]R(')E=')I979I;F<@<V5S<VEO;B!D
M871A("AI9"`]("<@+B`D:60@+B`G*2<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*
M("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N($!M>7-Q;%]R97-U;'0H)')E<W5L="P@,"P@,"D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!7<FET92!S97-S:6]N(&1A=&$@=&\@=&AE(%-E<W-I;VY(
M86YD;&5R(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M:60@("`@("`@("`@("!4:&4@<V5S<VEO;B!I9&5N=&EF:65R+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<V5S<VEO;E]D871A("!4:&4@<V5S<VEO;B!D871A
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C
M97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N('=R
M:71E*"1I9"P@)'-E<W-I;VY?9&%T82D*("`@('L*("`@("`@("`O*B!-86ME
M('-U<F4@=V4@:&%V92!A('9A;&ED(&1A=&%B87-E(&-O;FYE8W1I;VXN("HO
M"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@("\J($)U:6QD
M('1H92!344P@<75E<GDN("HO"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G
M4D503$%#12!)3E1/("5S("AS97-S:6]N7VED+"!S97-S:6]N7V1A=&$L('-E
M<W-I;VY?;&%S=&UO9&EF:65D*2<@+@H@("`@("`@("`@("`@("`@("`@("`@
M("`@)R!604Q515,@*"5S+"`E<RP@)7,I)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]Q=6]T92@D:60I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]Q=6]T92@D<V5S<VEO;E]D871A*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@('1I;64H*2D["@H@("`@("`@("1R97-U
M;'0@/2!`;7ES<6Q?<75E<GDH)'%U97)Y+"`D=&AI<RT^7V1B*3L*("`@("`@
M("!I9B`H96UP='DH)'1H:7,M/E]P87)A;7-;)W)O=VQO8VMI;F<G72DI('L*
M("`@("`@("`@("`@0&UY<W%L7W%U97)Y*"=53DQ/0TL@5$%"3$53("<@+B`D
M=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P@)'1H:7,M/E]D8BD["B`@("`@("`@
M?0H@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("!`;7ES<6Q?
M<75E<GDH)U)/3$Q"04-+)RP@)'1H:7,M/E]D8BD["B`@("`@("`@("`@($AO
M<F1E.CIL;V=-97-S86=E*"=%<G)O<B!W<FET:6YG('-E<W-I;VX@9&%T82<L
M(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@0&UY<W%L7W%U
M97)Y*"=#3TU-250G+"`D=&AI<RT^7V1B*3L*"B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$97-T<F]Y('1H92!D871A(&9O
M<B!A('!A<G1I8W5L87(@<V5S<VEO;B!I9&5N=&EF:65R(&EN('1H90H@("`@
M("H@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1I9"`@5&AE('-E<W-I;VX@:61E;G1I9FEE<BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L
M<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D97-T<F]Y*"1I
M9"D*("`@('L*("`@("`@("`O*B!-86ME('-U<F4@=V4@:&%V92!A('9A;&ED
M(&1A=&%B87-E(&-O;FYE8W1I;VXN("HO"B`@("`@("`@)'1H:7,M/E]C;VYN
M96-T*"D["@H@("`@("`@("\J($)U:6QD('1H92!344P@<75E<GDN("HO"B`@
M("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G1$5,151%($923TT@)7,@5TA%4D4@
M<V5S<VEO;E]I9"`]("5S)RP*("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%R86US6R=T86)L92==+"`D=&AI<RT^7W%U;W1E*"1I9"DI.PH*
M("`@("`@("`O*B!,;V<@=&AE('%U97)Y(&%T(&$@1$5"54<@;&]G(&QE=F5L
M+B`J+PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P<FEN=&8H)U-13"!1
M=65R>2!B>2!397-S:6]N2&%N9&QE<E]M>7-Q;#HZ9&5S=')O>2@I.B!Q=65R
M>2`]("(E<R(G+"`D<75E<GDI+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@
M("`O*B!%>&5C=71E('1H92!Q=65R>2X@*B\*("`@("`@("`D<F5S=6QT(#T@
M0&UY<W%L7W%U97)Y*"1Q=65R>2P@)'1H:7,M/E]D8BD["B`@("`@("`@:68@
M*&5M<'1Y*"1T:&ES+3Y?<&%R86US6R=R;W=L;V-K:6YG)UTI*2!["B`@("`@
M("`@("`@($!M>7-Q;%]Q=65R>2@G54Y,3T-+(%1!0DQ%4R`G("X@)'1H:7,M
M/E]P87)A;7-;)W1A8FQE)UTL("1T:&ES+3Y?9&(I.PH@("`@("`@('T*("`@
M("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@0&UY<W%L7W%U97)Y
M*"=23TQ,0D%#2R<L("1T:&ES+3Y?9&(I.PH@("`@("`@("`@("!(;W)D93HZ
M;&]G365S<V%G92@G1F%I;&5D('1O(&1E;&5T92!S97-S:6]N("AI9"`]("<@
M+B`D:60@+B`G*2<L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2
M*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@
M("`@0&UY<W%L7W%U97)Y*"=#3TU-250G+"`D=&AI<RT^7V1B*3L*"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'87)B86=E
M(&-O;&QE8W0@<W1A;&4@<V5S<VEO;G,@9G)O;2!T:&4@4V5S<VEO;DAA;F1L
M97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;6%X
M;&EF971I;64@(%1H92!M87AI;75M(&%G92!O9B!A('-E<W-I;VXN"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A
M;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V,H)&UA>&QI
M9F5T:6UE(#T@,S`P*0H@("`@>PH@("`@("`@("\J($UA:V4@<W5R92!W92!H
M879E(&$@=F%L:60@9&%T86)A<V4@8V]N;F5C=&EO;BX@*B\*("`@("`@("`D
M=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q
M=65R>2X@*B\*("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=$14Q%5$4@1E)/
M32`E<R!72$5212!S97-S:6]N7VQA<W1M;V1I9FEE9"`\("5S)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==+"`H
M:6YT*2AT:6UE*"D@+2`D;6%X;&EF971I;64I*3L*"B`@("`@("`@+RH@3&]G
M('1H92!Q=65R>2!A="!A($1%0E5'(&QO9R!L979E;"X@*B\*("`@("`@("!(
M;W)D93HZ;&]G365S<V%G92AS<')I;G1F*"=344P@475E<GD@8GD@4V5S<VEO
M;DAA;F1L97)?;7ES<6PZ.F=C*"DZ('%U97)Y(#T@(B5S(B<L("1Q=65R>2DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?
M+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("\J($5X96-U=&4@=&AE('%U
M97)Y+B`J+PH@("`@("`@("1R97-U;'0@/2!`;7ES<6Q?<75E<GDH)'%U97)Y
M+"`D=&AI<RT^7V1B*3L*("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@
M("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T5R<F]R(&=A<F)A9V4@8V]L;&5C
M=&EN9R!O;&0@<V5S<VEO;G,G+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B!`;7ES<6Q?869F96-T961?<F]W<R@D=&AI<RT^
M7V1B*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A(&QI<W0@;V8@=&AE
M('9A;&ED('-E<W-I;VX@:61E;G1I9FEE<G,N"B`@("`@*@H@("`@("H@0')E
M='5R;B!A<G)A>2`@02!L:7-T(&]F('9A;&ED('-E<W-I;VX@:61E;G1I9FEE
M<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-E<W-I;VY)1',H*0H@("`@
M>PH@("`@("`@("\J($UA:V4@<W5R92!W92!H879E(&$@=F%L:60@9&%T86)A
M<V4@8V]N;F5C=&EO;BX@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*
M"B`@("`@("`@+RH@4V5S<VEO;B!T:6UE;W5T+"!D;VXG="!R96QY(&]N(&=A
M<F)A9V4@8V]L;&5C=&EO;B`J+PH@("`@("`@("1T:6UE;W5T(#T@=&EM92@I
M("T@:6YI7V=E="@G<V5S<VEO;BYG8U]M87AL:69E=&EM92<I.PH*("`@("`@
M("`D<75E<GD@/2!S<')I;G1F*"=314Q%0U0@<V5S<VEO;E]I9"!&4D]-("5S
M)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`G(%=(15)%('-E<W-I;VY?
M;&%S=&UO9&EF:65D(#X@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&EM96]U="D["@H@("`@("`@("\J($QO9R!T:&4@<75E<GD@870@
M82!$14)51R!L;V<@;&5V96PN("HO"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A
M9V4H<W!R:6YT9B@G4U%,(%%U97)Y(&)Y(%-E<W-I;VY(86YD;&5R7VUY<W%L
M.CIG971397-S:6]N241S*"DZ('%U97)Y(#T@(B5S(B<L("1Q=65R>2DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!0
M14%27TQ/1U]$14)51RD["@H@("`@("`@("1R97-U;'0@/2!`;7ES<6Q?<75E
M<GDH)'%U97)Y+"`D=&AI<RT^7V1B*3L*("`@("`@("!I9B`H(21R97-U;'0I
M('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T5R<F]R(&=E='1I
M;F<@<V5S<VEO;B!)1',G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1S97-S:6]N
M<R`](&%R<F%Y*"D["@H@("`@("`@('=H:6QE("@D<F]W(#T@;7ES<6Q?9F5T
M8VA?<F]W*"1R97-U;'0I*0H@("`@("`@("`@("`D<V5S<VEO;G-;72`]("1R
M;W=;,%T["@H@("`@("`@(')E='5R;B`D<V5S<VEO;G,["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!%<V-A<&4@82!M>7-Q;"!S=')I;F<N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=F%L=64@(%1H92!S=')I;F<@=&\@<75O=&4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!Q=6]T960@<W1R:6YG+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?<75O=&4H)'9A;'5E*0H@("`@>PH@("`@("`@('-W:71C
M:"`H<W1R=&]L;W=E<BAG971T>7!E*"1V86QU92DI*2!["B`@("`@("`@8V%S
M92`G;G5L;"<Z"B`@("`@("`@("`@(')E='5R;B`G3E5,3"<["@H@("`@("`@
M(&-A<V4@)VEN=&5G97(G.@H@("`@("`@("`@("!R971U<FX@)'9A;'5E.PH*
M("`@("`@("!C87-E("=S=')I;F<G.@H@("`@("`@(&1E9F%U;'0Z"B`@("`@
M("`@("`@(')E='5R;B`B)R(@+B!`;7ES<6Q?<F5A;%]E<V-A<&5?<W1R:6YG
M*"1V86QU92P@)'1H:7,M/E]D8BD@+B`B)R(["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@071T96UP=',@=&\@;W!E;B!A(&-O;FYE8W1I;VX@
M=&\@=&AE(%-13"!S97)V97(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYN96-T*"D*("`@('L*("`@
M("`@("!I9B`H)'1H:7,M/E]C;VYN96-T960I('L*("`@("`@("`@("`@<F5T
M=7)N.PH@("`@("`@('T*"B`@("`@("`@2&]R9&4Z.F%S<V5R=$1R:79E<D-O
M;F9I9R@D=&AI<RT^7W!A<F%M<RP@)W-E<W-I;VYH86YD;&5R)RP*("`@("`@
M("`@("`@87)R87DH)VAO<W1S<&5C)RP@)W5S97)N86UE)RP@)V1A=&%B87-E
M)RDL"B`@("`@("`@("`@("=S97-S:6]N(&AA;F1L97(@37E344PG*3L*"B`@
M("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%R86US6R=P87-S=V]R9"==*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72`]("<G
M.PH@("`@("`@('T*"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%R86US
M6R=T86)L92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B
M;&4G72`]("=H;W)D95]S97-S:6]N:&%N9&QE<B<["B`@("`@("`@?0H*("`@
M("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)A;7-;)W!E<G-I<W1E;G0G72DI
M('L*("`@("`@("`@("`@)&-O;FYE8W0@/2`G;7ES<6Q?8V]N;F5C="<["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&-O;FYE8W0@/2`G;7ES<6Q?
M<&-O;FYE8W0G.PH@("`@("`@('T*"B`@("`@("`@:68@*"$D=&AI<RT^7V1B
M(#T@0"1C;VYN96-T*"1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M
M<ULG=7-E<FYA;64G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UTI*2!["B`@("`@("`@
M("`@($AO<F1E.CIF871A;"A014%2.CIR86ES945R<F]R*"=#;W5L9"!N;W0@
M8V]N;F5C="!T;R!D871A8F%S92!F;W(@4U%,(%-E<W-I;VY(86YD;&5R+B<I
M+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"%`;7ES<6Q?<V5L96-T7V1B*"1T:&ES+3Y?<&%R86US6R=D871A8F%S92==
M+"`D=&AI<RT^7V1B*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH4$5!
M4CHZ<F%I<V5%<G)O<BAS<')I;G1F*"=#;W5L9"!N;W0@8V]N;F5C="!T;R!T
M86)L92`E<R!F;W(@4U%,(%-E<W-I;VY(86YD;&5R+B<L("1T:&ES+3Y?<&%R
M86US6R=D871A8F%S92==*2P@7U]&24Q%7U\L(%]?3$E.15]?*2D["B`@("`@
M("`@?0H*("`@("`@("`D=&AI<RT^7V-O;FYE8W1E9"`]('1R=64["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(O
M;F]N92YP:'``````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,U,C(@,3`U
M,34T,S,W,S4@,#(S-S0S`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B!397-S:6]N2&%N9&QE<B!I;7!L
M96UE;G1A=&EO;B!F;W(@4$A0)W,@8G5I;'0M:6X@<V5S<VEO;B!H86YD;&5R
M+@H@*@H@*B!297%U:7)E9"!P87)A;65T97)S.CQP<F4^"B`J("`@3F]N92X\
M+W!R93X*("H*("H@3W!T:6]N86P@<&%R86UE=&5R<SH\<')E/@H@*B`@($YO
M;F4N/"]P<F4^"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U-E<W-I;VY(86YD
M;&5R+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP+'8@,2XS+C(N-"`R,#`V+S`Q
M+S`Q(#(Q.C(X.C,T(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-2TR
M,#`V($UA='0@4V5L<VMY(#QS96QS:WE`8V]L=6UB:6$N961U/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("H*("H@0&%U=&AO<B`@36%T="!396QS:WD@/'-E;'-K>4!C;VQU
M;6)I82YE9'4^"B`J($!S:6YC92`@($AO<F1E(#,N,0H@*B!`<&%C:V%G92!(
M;W)D95]397-S:6]N2&%N9&QE<@H@*B\*8VQA<W,@4V5S<VEO;DAA;F1L97)?
M;F]N92!E>'1E;F1S(%-E<W-I;VY(86YD;&5R('L*"B`@("`O*BH*("`@("`J
M(%)E860@=&AE(&1A=&$@9F]R(&$@<&%R=&EC=6QA<B!S97-S:6]N(&ED96YT
M:69I97(@9G)O;2!T:&4*("`@("`J(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@(%1H92!S97-S:6]N
M(&ED96YT:69I97(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!S97-S:6]N(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E860H)&ED
M*0H@("`@>PH@("`@("`@("1F:6QE(#T@<V5S<VEO;E]S879E7W!A=&@H*2`N
M($1)4D5#5$]265]315!!4D%43U(@+B`G<V5S<U\G("X@)&ED.PH*("`@("`@
M("`D<V5S<VEO;E]D871A(#T@0&9I;&5?9V5T7V-O;G1E;G1S*"1F:6QE*3L*
M("`@("`@("!I9B`H)'-E<W-I;VY?9&%T82`]/3T@9F%L<V4I('L*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(')E
M860@9FEL93H@(BD@+B`D9FEL92D["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)'-E<W-I;VY?9&%T83L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A
M(&QI<W0@;V8@=&AE('9A;&ED('-E<W-I;VX@:61E;G1I9FEE<G,N"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!L:7-T(&]F('9A;&ED('-E<W-I
M;VX@:61E;G1I9FEE<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-E<W-I
M;VY)1',H*0H@("`@>PH@("`@("`@("1S97-S:6]N<R`](&%R<F%Y*"D["@H@
M("`@("`@("1P871H(#T@<V5S<VEO;E]S879E7W!A=&@H*3L*("`@("`@("`D
M9"`](&1I<BAE;7!T>2@D<&%T:"D@/R!5=&EL.CIG971496UP1&ER*"D@.B`D
M<&%T:"D["@H@("`@("`@('=H:6QE("AF86QS92`A/3T@*"1E;G1R>2`]("1D
M+3YR96%D*"DI*2!["B`@("`@("`@("`@("\J($UA:V4@<W5R92!W92=R92!D
M96%L:6YG('=I=&@@9FEL97,@=&AA="!S=&%R="!W:71H"B`@("`@("`@("`@
M("`J('-E<W-?+B`J+PH@("`@("`@("`@("!I9B`H:7-?9FEL92@D9"T^<&%T
M:"`N($1)4D5#5$]265]315!!4D%43U(@+B`D96YT<GDI("8F"B`@("`@("`@
M("`@("`@("`A<W1R;F-M<"@D96YT<GDL("=S97-S7R<L('-T<FQE;B@G<V5S
M<U\G*2DI('L*("`@("`@("`@("`@("`@("1S97-S:6]N<UM=(#T@<W5B<W1R
M*"1E;G1R>2P@<W1R;&5N*"=S97-S7R<I*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1S97-S:6]N<SL*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+VQD87`N
M<&AP````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$P,#8W(#$P-3$U-#,S
M-S,U(#`R,S<R-@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@4V5S<VEO;DAA;F1L97(@:6UP;&5M96YT
M871I;VX@9F]R($Q$05`@9&ER96-T;W)I97,N"B`J"B`J(%)E<75I<F5D('!A
M<F%M971E<G,Z/'!R93X*("H@("`G9F]O)R`@("`@("!4:&4@9F]O+@H@*@H@
M*B!/<'1I;VYA;"!P87)A;65T97)S.CQP<F4^"B`J("`@)VAO<W1S<&5C)R`@
M5&AE(&AO<W1N86UE(&]F('1H92!L9&%P('-E<G9E<BX*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O;&1A
M<"YP:'`L=B`Q+C(N,BXR(#(P,#4O,3`O,3@@,3$Z,#$Z,C<@:F%N($5X<"`D
M"B`J"B`J(%1H:7,@8V]D92!I<R!A9&%P=&5D(&9R;VT@=&AE(&-O;6UE;G1S
M(&%T"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]S97-S:6]N+7-E="US879E+6AA
M;F1L97(N"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`<VEN8V4@("!(;W)D92`S+C$*
M("H@0'!A8VMA9V4@2&]R9&5?4V5S<VEO;DAA;F1L97(*("HO"F-L87-S(%-E
M<W-I;VY(86YD;&5R7VQD87`@97AT96YD<R!397-S:6]N2&%N9&QE<B!["@H@
M("`@+RHJ"B`@("`@*B!(86YD;&4@9F]R('1H92!C=7)R96YT(&1A=&%B87-E
M(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@("H@0'9A<B!R97-O=7)C90H@("`@
M("HO"B`@("!V87(@)%]C;VYN.PH*("`@("\J*@H@("`@("H@3W!E;B!T:&4@
M4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1S879E7W!A=&@@("`@(%1H92!P871H('1O('1H92!S97-S:6]N
M(&]B:F5C="X*("`@("`J($!P87)A;2!S=')I;F<@)'-E<W-I;VY?;F%M92`@
M5&AE(&YA;64@;V8@=&AE('-E<W-I;VXN"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]T:&5R=VES92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@;W!E;B@D<V%V95]P871H+"`D<V5S<VEO
M;E]N86UE*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8V]N;B`]($!L9&%P7V-O
M;FYE8W0H)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UTL("1T:&ES+3Y?<&%R
M86US6R=P;W)T)UTI.PH@("`@("`@(')E='5R;B!`;&1A<%]B:6YD*"1T:&ES
M+3Y?8V]N;BP@)'1H:7,M/E]P87)A;7-;)V1N)UTL("1T:&ES+3Y?<&%R86US
M6R=P87-S=V]R9"==*3L*("`@('T*"B`@("`O*BH*("`@("`J($-L;W-E('1H
M92!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O=&AE<G=I<V4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L;W-E*"D*("`@('L*("`@("`@("!R
M971U<FX@0&QD87!?8VQO<V4H)'1H:7,M/E]C;VYN*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E860@=&AE(&1A=&$@9F]R(&$@<&%R=&EC=6QA<B!S97-S
M:6]N(&ED96YT:69I97(@9G)O;2!T:&4*("`@("`J(%-E<W-I;VY(86YD;&5R
M(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@(%1H
M92!S97-S:6]N(&ED96YT:69I97(N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!S97-S:6]N(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E860H)&ED*0H@("`@>PH@("`@("`@("1S<B`]($!L9&%P7W-E87)C:"@D
M=&AI<RT^7V-O;FXL("1T:&ES+3Y?<&%R86US6R=D;B==+"`B*&-N/21I9"DB
M*3L*("`@("`@("`D:6YF;R`]($!L9&%P7V=E=%]E;G1R:65S*"1T:&ES+3Y?
M8V]N;BP@)'-R*3L*("`@("`@("!I9B`H)&EN9F];)V-O=6YT)UT@/B`P*2![
M"B`@("`@("`@("`@(')E='5R;B`D:6YF;ULP75LG<V5S<VEO;B==6S!=.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!7<FET92!S97-S:6]N(&1A=&$@
M=&\@=&AE(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D:60@("`@("`@("`@("!4:&4@<V5S<VEO;B!I9&5N
M=&EF:65R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5S<VEO;E]D871A("!4
M:&4@<V5S<VEO;B!D871A+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('=R:71E*"1I9"P@)'-E<W-I;VY?9&%T82D*("`@('L*
M("`@("`@("`D=7!D871E(#T@87)R87DH)V]B:F5C=$-L87-S)R`]/B!A<G)A
M>2@G<&AP<V5S<VEO;B<L("=T;W`G*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@)W-E<W-I;VXG(#T^("1S97-S:6]N7V1A=&$I.PH@("`@("`@("1D;B`]
M(")C;CTD:60L(B`N("1T:&ES+3Y?<&%R86US6R=D;B==.PH@("`@("`@($!L
M9&%P7V1E;&5T92@D=&AI<RT^7V-O;FXL("1D;BD["B`@("`@("`@<F5T=7)N
M($!L9&%P7V%D9"@D=&AI<RT^7V-O;FXL("1D;BP@)'5P9&%T92D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$97-T<F]Y('1H92!D871A(&9O<B!A('!A<G1I
M8W5L87(@<V5S<VEO;B!I9&5N=&EF:65R(&EN('1H90H@("`@("H@4V5S<VEO
M;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1I9"`@5&AE('-E<W-I;VX@:61E;G1I9FEE<BX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;W1H97)W
M:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D97-T<F]Y*"1I9"D*("`@('L*
M("`@("`@("`D9&X@/2`B8VX])&ED+"(@+B`D=&AI<RT^7W!A<F%M<ULG9&XG
M73L*("`@("`@("!R971U<FX@0&QD87!?9&5L971E*"1T:&ES+3Y?8V]N;BP@
M)&1N*3L*("`@('T*"B`@("`O*BH*("`@("`J($=A<F)A9V4@8V]L;&5C="!S
M=&%L92!S97-S:6]N<R!F<F]M('1H92!397-S:6]N2&%N9&QE<B!B86-K96YD
M+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1M87AL:69E=&EM92`@
M5&AE(&UA>&EM=6T@86=E(&]F(&$@<V5S<VEO;BX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;W1H97)W
M:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G8R@D;6%X;&EF971I;64@/2`S
M,#`I"B`@("!["B`@("`@("`@)'-R(#T@0&QD87!?<V5A<F-H*"1T:&ES+3Y?
M8V]N;BP@)'1H:7,M/E]P87)A;7-;)V1N)UTL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("<H;V)J96-T0VQA<W,]<&AP<V5S<VEO;BDG+"!A<G)A>2@G
M*R<L("=C;B<I*3L*("`@("`@("`D:6YF;R`]($!L9&%P7V=E=%]E;G1R:65S
M*"1T:&ES+3Y?8V]N;BP@)'-R*3L*("`@("`@("!I9B`H)&EN9F];)V-O=6YT
M)UT@/B`P*2!["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1I;F9O
M6R=C;W5N="==.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D:60@/2`D:6YF
M;ULD:5U;)V-N)UU;,%T["B`@("`@("`@("`@("`@("`D9&X@/2`B8VX])&ED
M+"(@+B`D=&AI<RT^7W!A<F%M<ULG9&XG73L*("`@("`@("`@("`@("`@("1L
M9&%P<W1A;7`@/2`D:6YF;ULD:5U;)VUO9&EF>71I;65S=&%M<"==6S!=.PH@
M("`@("`@("`@("`@("`@)'EE87(@/2!S=6)S='(H)&QD87!S=&%M<"P@,"P@
M-"D["B`@("`@("`@("`@("`@("`D;6]N=&@@/2!S=6)S='(H)&QD87!S=&%M
M<"P@-"P@,BD["B`@("`@("`@("`@("`@("`D9&%Y(#T@<W5B<W1R*"1L9&%P
M<W1A;7`L(#8L(#(I.PH@("`@("`@("`@("`@("`@)&AO=7(@/2!S=6)S='(H
M)&QD87!S=&%M<"P@."P@,BD["B`@("`@("`@("`@("`@("`D;6EN=71E(#T@
M<W5B<W1R*"1L9&%P<W1A;7`L(#$P+"`R*3L*("`@("`@("`@("`@("`@("1M
M;V1I9FEE9"`](&=M;6MT:6UE*"1H;W5R+"`D;6EN=71E+"`P+"`D;6]N=&@L
M("1D87DL("1Y96%R*3L*("`@("`@("`@("`@("`@(&EF("AT:6UE*"D@+2`D
M;6]D:69I960@/CT@)&UA>&QI9F5T:6UE*2!["B`@("`@("`@("`@("`@("`@
M("`@0&QD87!?9&5L971E*"1T:&ES+3Y?8V]N;BP@)&1N*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(O<V%P9&(N<&AP````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#8S,#<@,3`U,34T,S,W,S4@,#(T,3`Q
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"@IR97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+W-Q;"YP
M:'`G.PH*+RHJ"B`J(%-E<W-I;VY(86YD;&5R(&EM<&QE;65N=&%T:6]N(&9O
M<B!02%`G<R!014%2(&1A=&%B87-E(&%B<W1R86-T:6]N(&QA>65R+@H@*@H@
M*B!)9B!Y;W4@86-C97-S('EO=7(@9&%T86)A<V4@=&AR;W5G:"!/1$)#+"!Y
M;W4@=VEL;"!A;&UO<W0@8V5R=&%I;FQY(&YE960*("H@=&\@8VAA;F=E(%!(
M4"=S(&1E9F%U;'0@=F%L=64@9F]R(&]D8F,N9&5F875L=&QR;"`H=&AI<R!I
M<R!A('!H<"YI;FD*("H@<V5T=&EN9RDN(%1H92!D969A=6QT(&ES(#0P.38L
M('=H:6-H(&ES('1O;R!S;6%L;"`H>6]U<B!S97-S:6]N(&1A=&$@=VEL;`H@
M*B!B92!C:&]P<&5D(&]F9BDL(&%N9"!S971T:6YG(&ET('1O(#`@1$]%4R!.
M3U0@=V]R:R`M('1H870@9&]E<VXG="!M96%N(&YO"B`J(&QI;6ET+"!F;W(@
M<V]M92!R96%S;VXN(&]D8F,N9&5F875L=&QR;"`](#,R-S8X('-E96US('1O
M('=O<FL@<')E='1Y('=E;&P*("H@*'5S:6YG($U34U%,+3(P,#`I+@H@*@H@
M*B!297%U:7)E9"!P87)A;65T97)S.CQP<F4^"B`J("`@)VAO<W1S<&5C)R`@
M5&AE(&AO<W1N86UE(&]F('1H92!D871A8F%S92!S97)V97(N"B`J("`@)W!R
M;W1O8V]L)R`@5&AE(&-O;6UU;FEC871I;VX@<')O=&]C;VP@*"=T8W`G+"`G
M=6YI>"<L(&5T8RXI+@H@*B`@("=U<V5R;F%M92<@(%1H92!U<V5R;F%M92!W
M:71H('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+@H@*B`@("=P
M87-S=V]R9"<@(%1H92!P87-S=V]R9"!A<W-O8VEA=&5D('=I=&@@)W5S97)N
M86UE)RX*("H@("`G9&%T86)A<V4G("!4:&4@;F%M92!O9B!T:&4@9&%T86)A
M<V4N/"]P<F4^"B`J"B`J($]P=&EO;F%L('!A<F%M971E<G,Z/'!R93X*("H@
M("`G=&%B;&4G("`@("!4:&4@;F%M92!O9B!T:&4@<V5S<VEO;F1A=&$@=&%B
M;&4@:6X@)V1A=&%B87-E)RX@($1E9F%U;'0@:7,*("H@("`@("`@("`@("`@
M("`G:&]R9&5?<V5S<VEO;FAA;F1L97(G+CPO<')E/@H@*@H@*B!4:&4@=&%B
M;&4@<W1R=6-T=7)E(&9O<B!T:&4@4V5S<VEO;DAA;F1L97(@8V%N(&)E(&9O
M=6YD(&EN"B`J(&AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7W-E<W-I;VYH86YD
M;&5R+G-A<&1B+G-Q;"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4V5S<VEO
M;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O<V%P9&(N<&AP+'8@,2XQ,RXQ,BXX
M(#(P,#8O,#$O,#$@,C$Z,C@Z,S0@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`R+3(P,#8@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC
M;RYN>CX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A
M;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!S:6YC92`@($AO<F1E
M(#,N,`H@*B!`<&%C:V%G92!(;W)D95]397-S:6]N2&%N9&QE<@H@*B\*8VQA
M<W,@4V5S<VEO;DAA;F1L97)?<V%P9&(@97AT96YD<R!397-S:6]N2&%N9&QE
M<E]S<6P@>PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!344P@
M4V5S<VEO;DAA;F1L97(@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N('!A
M<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%-E<W-I;VY(86YD;&5R
M7W-A<&1B*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1P87)A
M;7-;)W!H<'1Y<&4G72`]("=O9&)C)SL*("`@("`@("!P87)E;G0Z.E-E<W-I
M;VY(86YD;&5R7W-Q;"@D<&%R86US*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E860@=&AE(&1A=&$@9F]R(&$@<&%R=&EC=6QA<B!S97-S:6]N(&ED96YT
M:69I97(@9G)O;2!T:&4*("`@("`J(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@(%1H92!S97-S:6]N
M(&ED96YT:69I97(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!S97-S:6]N(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E860H)&ED
M*0H@("`@>PH@("`@("`@("\J($UA:V4@<W5R92!W92!H879E(&$@=F%L:60@
M9&%T86)A<V4@8V]N;F5C=&EO;BX@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE
M8W0H*3L*"B`@("`@("`@+RH@0F5G:6X@82!T<F%N<V%C=&EO;BX@*B\*("`@
M("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^875T;V-O;6UI="AF86QS92D[
M"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D<F5S=6QT+"!?7T9)3$5?
M7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R
M;B`G)SL*("`@("`@("!]"@H@("`@("`@("\J($)U:6QD('1H92!344P@<75E
M<GDN("HO"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G4T5,14-4('-E<W-I
M;VY?9&%T82!&4D]-("5S(%=(15)%('-E<W-I;VY?:60@/2`E<R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P*
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&(M/G%U;W1E*"1I
M9"DI.PH*("`@("`@("`O*B!,;V<@=&AE('%U97)Y(&%T(&$@1$5"54<@;&]G
M(&QE=F5L+B`J+PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P<FEN=&8H
M)U-13"!1=65R>2!B>2!397-S:6]N2&%N9&QE<E]S<6PZ.G)E860H*3H@<75E
M<GD@/2`B)7,B)RP@)'%U97)Y*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@
M("`@+RH@17AE8W5T92!T:&4@<75E<GD@*B\*("`@("`@("`D<F5S=6QT(#T@
M;V1B8U]E>&5C*"1T:&ES+3Y?9&(M/F-O;FYE8W1I;VXL("1Q=65R>2D["B`@
M("`@("`@;V1B8U]L;VYG<F5A9&QE;B@D<F5S=6QT+"`Q,#0X-3<V*3L*"B`@
M("`@("`@+RH@1F5T8V@@=&AE('9A;'5E("HO"B`@("`@("`@;V1B8U]F971C
M:%]R;W<H)')E<W5L="P@,"D["B`@("`@("`@)&1A=&$@/2!O9&)C7W)E<W5L
M="@D<F5S=6QT+"`G<V5S<VEO;E]D871A)RD["@H@("`@("`@("\J($-L96%N
M('5P("HO"B`@("`@("`@;V1B8U]F<F5E7W)E<W5L="@D<F5S=6QT*3L*"B`@
M("`@("`@<F5T=7)N("1D871A.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+W-Q;"YP:'``````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#(S-S`Q(#$P-3$U-#,S-S,U(#`R,S8P
M-``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@4V5S<VEO;DAA;F1L97(@:6UP;&5M96YT871I;VX@9F]R
M(%!(4"=S(%!%05(@9&%T86)A<V4@86)S=')A8W1I;VX@;&%Y97(N"B`J"B`J
M(%)E<75I<F5D('!A<F%M971E<G,Z/'!R93X*("H@("`G<&AP='EP92<@("!4
M:&4@9&%T86)A<V4@='EP92`H92YG+B`G<&=S<6PG+"`G;7ES<6PG+"!E=&,N
M*2X\+W!R93X*("H*("H@4F5Q=6ER960@8GD@<V]M92!D871A8F%S92!I;7!L
M96UE;G1A=&EO;G,Z/'!R93X*("H@("`G:&]S='-P96,G("!4:&4@:&]S=&YA
M;64@;V8@=&AE(&1A=&%B87-E('-E<G9E<BX*("H@("`G<')O=&]C;VPG("!4
M:&4@8V]M;75N:6-A=&EO;B!P<F]T;V-O;"`H)W1C<"<L("=U;FEX)RP@971C
M+BDN"B`J("`@)V1A=&%B87-E)R`@5&AE(&YA;64@;V8@=&AE(&1A=&%B87-E
M+@H@*B`@("=U<V5R;F%M92<@(%1H92!U<V5R;F%M92!W:71H('=H:6-H('1O
M(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+@H@*B`@("=P87-S=V]R9"<@(%1H
M92!P87-S=V]R9"!A<W-O8VEA=&5D('=I=&@@)W5S97)N86UE)RX*("H@("`G
M;W!T:6]N<R<@("!!9&1I=&EO;F%L(&]P=&EO;G,@=&\@<&%S<R!T;R!T:&4@
M9&%T86)A<V4N"B`J("`@)W1T>2<@("`@("`@5&AE(%1462!O;B!W:&EC:"!T
M;R!C;VYN96-T('1O('1H92!D871A8F%S92X*("H@("`G<&]R="<@("`@("!4
M:&4@<&]R="!O;B!W:&EC:"!T;R!C;VYN96-T('1O('1H92!D871A8F%S92X\
M+W!R93X*("H*("H@3W!T:6]N86P@<&%R86UE=&5R<SH\<')E/@H@*B`@("=P
M97)S:7-T96YT)R`@57-E('!E<G-I<W1E;G0@1$(@8V]N;F5C=&EO;G,_("AB
M;V]L96%N*0H@*B`@("=T86)L92<@("`@("`@5&AE(&YA;64@;V8@=&AE('-E
M<W-I;VYD871A('1A8FQE(&EN("=D871A8F%S92<N("!$969A=6QT"B`J("`@
M("`@("`@("`@("`@("!I<R`G:&]R9&5?<V5S<VEO;FAA;F1L97(G+CPO<')E
M/@H@*@H@*B!4:&4@=&%B;&4@<W1R=6-T=7)E(&9O<B!T:&4@4V5S<VEO;DAA
M;F1L97(@8V%N(&)E(&9O=6YD(&EN"B`J(&AO<F1E+W-C<FEP=',O<W%L+VAO
M<F1E7W-E<W-I;VYH86YD;&5R+G-Q;"X*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O<W%L+G!H<"QV(#$N
M,C(N,3`N,3,@,C`P-B\P,2\P,2`R,3HR.#HS-"!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T
M;VYH86QL+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EK
M92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E
M("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7U-E<W-I;VY(86YD;&5R
M"B`J+PIC;&%S<R!397-S:6]N2&%N9&QE<E]S<6P@97AT96YD<R!397-S:6]N
M2&%N9&QE<B!["@H@("`@+RHJ"B`@("`@*B!(86YD;&4@9F]R('1H92!C=7)R
M96YT(&1A=&%B87-E(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@("H@0'9A<B!$
M0@H@("`@("HO"B`@("!V87(@)%]D8CL*"B`@("`O*BH*("`@("`J($)O;VQE
M86X@:6YD:6-A=&EN9R!W:&5T:&5R(&]R(&YO="!W92=R92!C;VYN96-T960@
M=&\@=&AE(%-13"!S97)V97(N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N
M"B`@("`@*B\*("`@('9A<B`D7V-O;FYE8W1E9"`](&9A;'-E.PH*("`@("\J
M*@H@("`@("H@0VQO<V4@=&AE(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L
M(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@8VQO<V4H
M*0H@("`@>PH@("`@("`@("\J($1I<V-O;FYE8W0@9G)O;2!D871A8F%S92X@
M*B\*("`@("`@("!I9B`H)'1H:7,M/E]C;VYN96-T960I('L*("`@("`@("`@
M("`@+RH@0VQO<V4@86YY(&]P96X@=')A;G-A8W1I;VYS+B`J+PH@("`@("`@
M("`@("`D=&AI<RT^7V1B+3YC;VUM:70H*3L*("`@("`@("`@("`@)'1H:7,M
M/E]D8BT^875T;T-O;6UI="AT<G5E*3L*"B`@("`@("`@("`@("1T:&ES+3Y?
M8V]N;F5C=&5D(#T@9F%L<V4["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7V1B+3YD:7-C;VYN96-T*"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E860@=&AE(&1A=&$@9F]R
M(&$@<&%R=&EC=6QA<B!S97-S:6]N(&ED96YT:69I97(@9G)O;2!T:&4*("`@
M("`J(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D:60@(%1H92!S97-S:6]N(&ED96YT:69I97(N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!S97-S:6]N(&1A=&$N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')E860H)&ED*0H@("`@>PH@("`@("`@("\J
M($UA:V4@<W5R92!W92!H879E(&$@=F%L:60@9&%T86)A<V4@8V]N;F5C=&EO
M;BX@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@+RH@
M0F5G:6X@82!T<F%N<V%C=&EO;BX@*B\*("`@("`@("`D<F5S=6QT(#T@)'1H
M:7,M/E]D8BT^875T;V-O;6UI="AF86QS92D["B`@("`@("`@:68@*&ES7V$H
M)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(;W)D93HZ
M;&]G365S<V%G92@D<F5S=6QT+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("!]"@H@
M("`@("`@("\J($5X96-U=&4@=&AE('%U97)Y+B`J+PH@("`@("`@(')E<75I
M<F5?;VYC92`G2&]R9&4O4U%,+G!H<"<["B`@("`@("`@)')E<W5L="`]($AO
M<F1E7U-13#HZ<F5A9$)L;V(H)'1H:7,M/E]D8BP@)'1H:7,M/E]P87)A;7-;
M)W1A8FQE)UTL("=S97-S:6]N7V1A=&$G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=S97-S:6]N7VED)R`]/B`D:60I
M*3L*"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D<F5S=6QT+"!?7T9)
M3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(')E
M='5R;B`G)SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@
M("`@?0H*("`@("\J*@H@("`@("H@5W)I=&4@<V5S<VEO;B!D871A('1O('1H
M92!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&ED("`@("`@("`@("`@5&AE('-E<W-I;VX@:61E;G1I9FEE
M<BX*("`@("`J($!P87)A;2!S=')I;F<@)'-E<W-I;VY?9&%T82`@5&AE('-E
M<W-I;VX@9&%T82X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R
M=64@;VX@<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!W<FET92@D:60L("1S97-S:6]N7V1A=&$I"B`@("!["B`@("`@
M("`@+RH@36%K92!S=7)E('=E(&AA=F4@82!V86QI9"!D871A8F%S92!C;VYN
M96-T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@
M("`O*B!"=6EL9"!T:&4@4U%,('%U97)Y+B`J+PH@("`@("`@("1Q=65R>2`]
M('-P<FEN=&8H)U-%3$5#5"!S97-S:6]N7VED($923TT@)7,@5TA%4D4@<V5S
M<VEO;E]I9"`](#\G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]P87)A;7-;)W1A8FQE)UTI.PH@("`@("`@("1V86QU97,@/2!A<G)A>2@D
M:60I.PH*("`@("`@("`O*B!,;V<@=&AE('%U97)Y(&%T(&$@1$5"54<@;&]G
M(&QE=F5L+B`J+PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P<FEN=&8H
M)U-13"!1=65R>2!B>2!397-S:6]N2&%N9&QE<E]S<6PZ.G=R:71E*"DZ('%U
M97)Y(#T@(B5S(B<L("1Q=65R>2DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@
M("`@("\J($5X96-U=&4@=&AE('%U97)Y+B`J+PH@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^7V1B+3YG971/;F4H)'%U97)Y+"`D=F%L=65S*3L*("`@("`@
M("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@($AO<F1E.CIL;V=-97-S86=E*"1R97-U;'0L(%]?1DE,15]?+"!?7TQ)
M3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*"B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]344PN
M<&AP)SL*("`@("`@("!I9B`H)')E<W5L="D@>PH@("`@("`@("`@("`D<F5S
M=6QT(#T@2&]R9&5?4U%,.CIU<&1A=&5";&]B*"1T:&ES+3Y?9&(L("1T:&ES
M+3Y?<&%R86US6R=T86)L92==+"`G<V5S<VEO;E]D871A)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<V5S<VEO;E]D
M871A+"!A<G)A>2@G<V5S<VEO;E]I9"<@/3X@)&ED*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<V5S<VEO
M;E]L87-T;6]D:69I960G(#T^('1I;64H*2DI.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1R97-U;'0@/2!(;W)D95]344PZ.FEN<V5R=$)L;V(H
M)'1H:7,M/E]D8BP@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL("=S97-S:6]N
M7V1A=&$G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1S97-S:6]N7V1A=&$L(&%R<F%Y*"=S97-S:6]N7VED)R`]/B`D
M:60L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W-E<W-I;VY?;&%S=&UO9&EF:65D
M)R`]/B!T:6UE*"DI*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]A*"1R
M97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@)'1H:7,M/E]D
M8BT^<F]L;&)A8VLH*3L*("`@("`@("`@("`@)'1H:7,M/E]D8BT^875T;T-O
M;6UI="AT<G5E*3L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)')E
M<W5L="P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/E]D8BT^8V]M;6ET*"D["B`@("`@("`@:68@*&ES7V$H
M)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7V1B+3YA=71O0V]M;6ET*'1R=64I.PH@("`@("`@("`@("!(;W)D93HZ;&]G
M365S<V%G92@D<F5S=6QT+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'
M7T524BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@
M("`@("`@("1T:&ES+3Y?9&(M/F%U=&]#;VUM:70H=')U92D["B`@("`@("`@
M<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$97-T<F]Y('1H
M92!D871A(&9O<B!A('!A<G1I8W5L87(@<V5S<VEO;B!I9&5N=&EF:65R(&EN
M('1H90H@("`@("H@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE('-E<W-I;VX@:61E;G1I9FEE
M<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C
M8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D
M97-T<F]Y*"1I9"D*("`@('L*("`@("`@("`O*B!-86ME('-U<F4@=V4@:&%V
M92!A('9A;&ED(&1A=&%B87-E(&-O;FYE8W1I;VXN("HO"B`@("`@("`@)'1H
M:7,M/E]C;VYN96-T*"D["@H@("`@("`@("\J($)U:6QD('1H92!344P@<75E
M<GDN("HO"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G1$5,151%($923TT@
M)7,@5TA%4D4@<V5S<VEO;E]I9"`](#\G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI.PH@("`@("`@("1V86QU
M97,@/2!A<G)A>2@D:60I.PH*("`@("`@("`O*B!,;V<@=&AE('%U97)Y(&%T
M(&$@1$5"54<@;&]G(&QE=F5L+B`J+PH@("`@("`@($AO<F1E.CIL;V=-97-S
M86=E*'-P<FEN=&8H)U-13"!1=65R>2!B>2!397-S:6]N2&%N9&QE<E]S<6PZ
M.F1E<W1R;WDH*3H@<75E<GD@/2`B)7,B)RP@)'%U97)Y*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'
M7T1%0E5'*3L*"B`@("`@("`@+RH@17AE8W5T92!T:&4@<75E<GDN("HO"B`@
M("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A
M;'5E<RD["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D<F5S=6QT+"!?
M7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1R97-U;'0@/2`D
M=&AI<RT^7V1B+3YC;VUM:70H*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S
M86=E*"1R97-U;'0L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2
M*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'87)B86=E
M(&-O;&QE8W0@<W1A;&4@<V5S<VEO;G,@9G)O;2!T:&4@4V5S<VEO;DAA;F1L
M97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;6%X
M;&EF971I;64@(%1H92!M87AI;75M(&%G92!O9B!A('-E<W-I;VXN"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A
M;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V,H)&UA>&QI
M9F5T:6UE(#T@,S`P*0H@("`@>PH@("`@("`@("\J($UA:V4@<W5R92!W92!H
M879E(&$@=F%L:60@9&%T86)A<V4@8V]N;F5C=&EO;BX@*B\*("`@("`@("`D
M=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q
M=65R>2X@*B\*("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=$14Q%5$4@1E)/
M32`E<R!72$5212!S97-S:6]N7VQA<W1M;V1I9FEE9"`\(#\G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI.PH@
M("`@("`@("1V86QU97,@/2!A<G)A>2AT:6UE*"D@+2`D;6%X;&EF971I;64I
M.PH*("`@("`@("`O*B!,;V<@=&AE('%U97)Y(&%T(&$@1$5"54<@;&]G(&QE
M=F5L+B`J+PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P<FEN=&8H)U-1
M3"!1=65R>2!B>2!397-S:6]N2&%N9&QE<E]S<6PZ.F=C*"DZ('%U97)Y(#T@
M(B5S(B<L("1Q=65R>2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("\J
M($5X96-U=&4@=&AE('%U97)Y+B`J+PH@("`@("`@("1R97-U;'0@/2`D=&AI
M<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R
M9&4Z.FQO9TUE<W-A9V4H)')E<W5L="P@7U]&24Q%7U\L(%]?3$E.15]?+"!0
M14%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@
M("`J($=E="!A(&QI<W0@;V8@=&AE('9A;&ED('-E<W-I;VX@:61E;G1I9FEE
M<G,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!L:7-T(&]F('9A
M;&ED('-E<W-I;VX@:61E;G1I9FEE<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=%-E<W-I;VY)1',H*0H@("`@>PH@("`@("`@("\J($UA:V4@<W5R92!W
M92!H879E(&$@=F%L:60@9&%T86)A<V4@8V]N;F5C=&EO;BX@*B\*("`@("`@
M("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@)'1I;65O=70@/2!T:6UE
M*"D@+2!I;FE?9V5T*"=S97-S:6]N+F=C7VUA>&QI9F5T:6UE)RD["@H@("`@
M("`@("\J($)U:6QD('1H92!344P@<75E<GDN("HO"B`@("`@("`@)'%U97)Y
M(#T@)U-%3$5#5"!S97-S:6]N7VED($923TT@)R`N("1T:&ES+3Y?<&%R86US
M6R=T86)L92==("X*("`@("`@("`@("`@("`@("`G(%=(15)%('-E<W-I;VY?
M;&%S=&UO9&EF:65D(#X@/R<["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"1T
M:6UE;W5T*3L*"B`@("`@("`@+RH@3&]G('1H92!Q=65R>2!A="!A($1%0E5'
M(&QO9R!L979E;"X@*B\*("`@("`@("!(;W)D93HZ;&]G365S<V%G92AS<')I
M;G1F*"=344P@475E<GD@8GD@4V5S<VEO;DAA;F1L97)?<W%L.CIG971397-S
M:6]N241S*"DZ('%U97)Y(#T@(B5S(B<L("1Q=65R>2DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$
M14)51RD["@H@("`@("`@("\J($5X96-U=&4@=&AE('%U97)Y+B`J+PH@("`@
M("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YG971#;VPH)'%U97)Y+"`P+"`D
M=F%L=65S*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1R97-U;'0L
M(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!O<&5N
M(&$@8V]N;F5C=&EO;B!T;R!T:&4@4U%,('-E<G9E<BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<SL@97AI=',@*$AO
M<F1E.CIF871A;"@I*2!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V-O;FYE8W0H*0H@("`@>PH@("`@("`@(&EF("@A)'1H:7,M/E]C;VYN96-T
M960I('L*("`@("`@("`@("`@2&]R9&4Z.F%S<V5R=$1R:79E<D-O;F9I9R@D
M=&AI<RT^7W!A<F%M<RP@)W-E<W-I;VYH86YD;&5R)RP*("`@("`@("`@("`@
M("`@(&%R<F%Y*"=P:'!T>7!E)RDL"B`@("`@("`@("`@("`@("`G<V5S<VEO
M;B!H86YD;&5R(%-13"<I.PH*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI
M<RT^7W!A<F%M<ULG9&%T86)A<V4G72DI('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%R86US6R=D871A8F%S92==(#T@)R<["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG=7-E<FYA
M;64G72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=U<V5R
M;F%M92==(#T@)R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%I
M<W-E="@D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G72DI('L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==(#T@)R<["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%R86US
M6R=T86)L92==*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)W1A8FQE)UT@/2`G:&]R9&5?<V5S<VEO;FAA;F1L97(G.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`O*B!#;VYN96-T('1O('1H92!344P@<V5R=F5R
M('5S:6YG('1H92!S=7!P;&EE9`H@("`@("`@("`@("`@*B!P87)A;65T97)S
M+B`J+PH@("`@("`@("`@("!I;F-L=61E7V]N8V4@)T1"+G!H<"<["B`@("`@
M("`@("`@("1T:&ES+3Y?9&(@/2`F1$(Z.F-O;FYE8W0H)'1H:7,M/E]P87)A
M;7,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)W!E<G-I<W1E;G0G(#T^("%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG<&5R
M<VES=&5N="==*2DI.PH@("`@("`@("`@("!I9B`H:7-?82@D=&AI<RT^7V1B
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!(;W)D93HZ9F%T
M86PH)'1H:7,M/E]D8BP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@)'1H:7,M/E]D8BT^<V5T3W!T:6]N*"=P;W)T
M86)I;&ET>2<L($1"7U!/4E1!0DE,25197TQ/5T520T%312!\($1"7U!/4E1!
M0DE,25197T524D]24RD["@H@("`@("`@("`@("`D=&AI<RT^7V-O;FYE8W1E
M9"`]('1R=64["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+VUE;6-A8VAE+G!H<```````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#$V,C$V(#$P-3$U-#,S-S,U(#`R-#4U,@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@4V5S<VEO;DAA;F1L97(Z.B!I;7!L96UE;G1A=&EO;B!F;W(@
M;65M8V%C:&4N"B`J(&UE;6-A8VAE('=E8G-I=&4Z(&AT='`Z+R]W=W<N9&%N
M9V$N8V]M+VUE;6-A8VAE9"\*("H*("H@4F5Q=6ER960@<&%R86UE=&5R<SH\
M<')E/@H@*B`@("=H;W-T<W!E8R<@(%1H92!H;W-T;F%M92!O9B!T:&4@;65M
M8V%C:&4@<V5R=F5R+@H@*B`@("=P;W)T)R`@("`@(%1H92!P;W)T(&]N('=H
M:6-H('1O(&-O;FYE8W0@=&\@=&AE(&UE;6-A8VAE('-E<G9E<BX\+W!R93X*
M("H*("H@3W!T:6]N86P@<&%R86UE=&5R<SH\<')E/@H@*B`@("=P97)S:7-T
M96YT)R`@57-E('!E<G-I<W1E;G0@1$(@8V]N;F5C=&EO;G,_("AB;V]L96%N
M*0H@*B`@("=C;VUP<F5S<VEO;B<@57-E(&-O;7!R97-S:6]N('=H96X@<W1O
M<FEN9R!S97-S:6]N<RX\+W!R93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O;65M8V%C:&4N<&AP+'8@
M,2XQ+C(N,2`R,#`V+S`U+S`R(#$W.C(W.C0Y(&-H=6-K($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`U+3(P,#8@4F]N9RU%;B!&86X@/')A9F%N0&EN9F]R
M+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@(%)O;F<M16X@1F%N
M(#QR869A;D!I;F9O<BYO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,0H@*B!`
M<&%C:V%G92!(;W)D95]397-S:6]N2&%N9&QE<@H@*B\*8VQA<W,@4V5S<VEO
M;DAA;F1L97)?;65M8V%C:&4@97AT96YD<R!397-S:6]N2&%N9&QE<B!["@H@
M("`@+RHJ"B`@("`@*B!#=7)R96YT(&UE;6-A8VAE(&-O;FYE8W1I;VXN"B`@
M("`@*@H@("`@("H@0'9A<B!O8FIE8W0*("`@("`J+PH@("`@=F%R("1?9&([
M"@H@("`@+RHJ"B`@("`@*B!";V]L96%N(&EN9&EC871I;F<@=VAE=&AE<B!O
M<B!N;W0@=V4G<F4@8V]N;F5C=&5D('1O('1H90H@("`@("H@;65M8V%C:&4@
M<V5R=F5R+@H@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@
M("!V87(@)%]C;VYN96-T960@/2!F86QS93L*"B`@("`O*BH*("`@("`J($QO
M8VL@:&%N9&QE+@H@("`@("H*("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J
M+PH@("`@=F%R("1?9G`["@H@("`@+RHJ"B`@("`@*B!#;&]S92!T:&4@4V5S
M<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!C;&]S92@I"B`@("!["B`@("`@("`@:68@*"1T
M:&ES+3Y?8V]N;F5C=&5D*2!["B`@("`@("`@("`@("1T:&ES+3Y?8V]N;F5C
M=&5D(#T@9F%L<V4["B`@("`@("`@("`@($!M96UC86-H95]C;&]S92@D=&AI
M<RT^7V1B*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?=6YL;V-K4V5S
M<VEO;B@I.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5A9"!T:&4@9&%T82!F;W(@82!P87)T:6-U;&%R('-E<W-I;VX@
M:61E;G1I9FEE<B!F<F]M('1H90H@("`@("H@4V5S<VEO;DAA;F1L97(@8F%C
M:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE('-E
M<W-I;VX@:61E;G1I9FEE<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE('-E<W-I;VX@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A
M9"@D:60I"B`@("!["B`@("`@("`@+RH@3V)T86EN('-E<W-I;VX@;&]C:RX@
M*B\*("`@("`@("`D=&AI<RT^7VQO8VM397-S:6]N*"1I9"D["@H@("`@("`@
M("\J($UA:V4@<W5R92!W92!H879E(&$@=F%L:60@;65M8V%C:&4@8V]N;F5C
M=&EO;BX@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@
M)')E<W5L="`]($!M96UC86-H95]G970H)'1H:7,M/E]D8BP@)&ED*3L*("`@
M("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE
M<W-A9V4H)T5R<F]R(')E=')I979I;F<@<V5S<VEO;B!D871A("AI9"`]("<@
M+B`D:60@+B`G*2<L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2
M*3L*("`@("`@("`@("`@)'1H:7,M/E]U;FQO8VM397-S:6]N*"D["B`@("`@
M("`@("`@($!U;FQI;FLH)'1H:7,M/E]P87)A;7-;)VQO8VM?9&ER)UT@+B`G
M+VQO8VM?)R`N("1I9"D["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=296%D('-E<W-I
M;VX@9&%T82`H:60@/2`G("X@)&ED("X@)RDG+"!?7T9)3$5?7RP@7U],24Y%
M7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@('T*"B`@("`O*BH*("`@("`J(%=R:71E('-E<W-I;VX@9&%T82!T;R!T
M:&4@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1I9"`@("`@("`@("`@(%1H92!S97-S:6]N(&ED96YT:69I
M97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1S97-S:6]N7V1A=&$@(%1H92!S
M97-S:6]N(&1A=&$N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@=W)I=&4H)&ED+"`D<V5S<VEO;E]D871A*0H@("`@>PH@("`@
M("`@("\J($UA:V4@<W5R92!W92!H879E(&$@=F%L:60@;65M8V%C:&4@8V]N
M;F5C=&EO;BX@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@
M("`@)&QI9F5T:6UE(#T@:6YI7V=E="@G<V5S<VEO;BYG8U]M87AL:69E=&EM
M92<I.PH@("`@("`@("1F;&%G<R`]("1T:&ES+3Y?<&%R86US6R=C;VUP<F5S
M<VEO;B==(#\@345-0T%#2$5?0T]-4%)%4U-%1"`Z(#`["B`@("`@("`@)')E
M<W5L="`]($!M96UC86-H95]S970H)'1H:7,M/E]D8BP@)&ED+"`D<V5S<VEO
M;E]D871A+"`D9FQA9W,L("1L:69E=&EM92D["@H@("`@("`@(&EF("@A)')E
M<W5L="D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G17)R;W(@
M=W)I=&EN9R!S97-S:6]N(&1A=&$@*&ED(#T@)R`N("1I9"`N("<I)RP@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@($AO<F1E.CIL;V=-97-S
M86=E*"=7<F]T92!S97-S:6]N(&1A=&$@*&ED(#T@)R`N("1I9"`N("<I)RP@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5S=')O>2!T
M:&4@9&%T82!F;W(@82!P87)T:6-U;&%R('-E<W-I;VX@:61E;G1I9FEE<B!I
M;B!T:&4*("`@("`J(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D:60@(%1H92!S97-S:6]N(&ED96YT:69I
M97(N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U
M8V-E<W,L(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9&5S=')O>2@D:60I"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E('=E(&AA
M=F4@82!V86QI9"!M96UC86-H92!C;VYN96-T:6]N+B`J+PH@("`@("`@("1T
M:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("`D<F5S=6QT(#T@0&UE;6-A8VAE
M7V1E;&5T92@D=&AI<RT^7V1B+"`D:60I.PH*("`@("`@("!I9B`H(21R97-U
M;'0I('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T9A:6QE9"!T
M;R!D96QE=&4@<V5S<VEO;B`H:60@/2`G("X@)&ED("X@)RDG+"!?7T9)3$5?
M7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H
M)T1E;&5T960@<V5S<VEO;B!D871A("AI9"`]("<@+B`D:60@+B`G*2<L(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`D
M=&AI<RT^7W5N;&]C:U-E<W-I;VXH*3L*("`@("`@("!`=6YL:6YK*"1T:&ES
M+3Y?<&%R86US6R=L;V-K7V1I<B==("X@)R]L;V-K7R<@+B`D:60I.PH@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@1V%R8F%G
M92!C;VQL96-T('-T86QE('-E<W-I;VYS(&9R;VT@=&AE(%-E<W-I;VY(86YD
M;&5R(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&UA
M>&QI9F5T:6UE("!4:&4@;6%X:6UU;2!A9V4@;V8@82!S97-S:6]N+@H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F
M86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=C*"1M87AL
M:69E=&EM92`](#,P,"D*("`@('L*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(&]P96X@82!C;VYN96-T
M:6]N('1O('1H92!M96UC86-H92!S97)V97(H<RDN"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYN96-T
M*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]C;VYN96-T960I('L*("`@
M("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T%L<F5A9'D@8V]N;F5C=&5D
M('1O(&$@;65M8V%C:&4@<V5R=F5R(&9O<B!M96UC86-H92!397-S:6]N2&%N
M9&QE<B<@+"!?7T9)3$5?7RP@7U],24Y%7U\L4$5!4E],3T=?1$5"54<I.PH@
M("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("!(;W)D93HZ
M87-S97)T1')I=F5R0V]N9FEG*"1T:&ES+3Y?<&%R86US+"`G<V5S<VEO;FAA
M;F1L97(G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)VAO<W1S<&5C)RP@)W!O<G0G*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=S97-S:6]N(&AA;F1L97(@;65M8V%C:&4G*3L*"B`@
M("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%R86US6R=P97)S:7-T96YT)UTI
M*2!["B`@("`@("`@("`@("1C;VYN96-T7W!E<G-I<W1E;G0@/2!F86QS93L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D8V]N;F5C=%]P97)S:7-T
M96YT(#T@=')U93L*("`@("`@("!]"B`@("`@("`@)&-O;B`](&YE=R!-96UC
M86-H93L*"B`@("`@("`@9F]R("@D:2`](#`L("1N(#T@8V]U;G0H)'1H:7,M
M/E]P87)A;7-;)VAO<W1S<&5C)UTI.R`D:2`\("1N.R`K*R1I*2!["B`@("`@
M("`@("`@(&EF("@A0"1C;VXM/F%D9%-E<G9E<B@D=&AI<RT^7W!A<F%M<ULG
M:&]S='-P96,G75LD:5TL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG<&]R="==6R1I72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1C;VYN96-T7W!E<G-I<W1E;G0I*2![
M"B`@("`@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G0V]U;&0@;F]T
M(&%D9"!;)R`N("1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==6R1I72`N("<Z
M)R`N("1T:&ES+3Y?<&%R86US6R=P;W)T)UU;)&E=("X@)UT@87,@;65M8V%C
M:&4@<V5R=F5R(&9O<B!M96UC86-H92!397-S:6]N2&%N9&QE<B<@+"!?7T9)
M3$5?7RP@7U],24Y%7U\L4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=!9&1E
M9"!;)R`N("1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==6R1I72`N("<Z)R`N
M("1T:&ES+3Y?<&%R86US6R=P;W)T)UU;)&E=("X@)UT@87,@;65M8V%C:&4@
M<V5R=F5R(&9O<B!M96UC86-H92!397-S:6]N2&%N9&QE<B<L(%]?1DE,15]?
M+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]C;VYN96-T960@/2!T<G5E.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("`O*B!#:&5C:R!I9B!A;GD@;V8@=&AE('!O;VQE9"!C
M;VYN96-T:6]N<R!W;W)K<RX@*B\*("`@("`@("!I9B`H)&-O;BT^9V5T5F5R
M<VEO;B@I*2!["B`@("`@("`@("`@("1T:&ES+3Y?9&(@/2`D8V]N.PH@("`@
M("`@("`@("`D=&AI<RT^7V-O;FYE8W1E9"`]('1R=64["B`@("`@("`@("`@
M($AO<F1E.CIL;V=-97-S86=E*"=#;VYN96-T960@=&\@82!M96UC86-H92!S
M97)V97(@9F]R(&UE;6-A8VAE(%-E<W-I;VY(86YD;&5R)R`L(%]?1DE,15]?
M+"!?7TQ)3D5?7RQ014%27TQ/1U]$14)51RD["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'1H:7,M/E]C;VYN96-T960@/2!F86QS93L*("`@("`@
M("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T-O=6QD(&YO="!C;VYN96-T('1O
M(&%N>2!M96UC86-H92!S97)V97(@9F]R(&UE;6-A8VAE(%-E<W-I;VY(86YD
M;&5R)R`L(%]?1DE,15]?+"!?7TQ)3D5?7RQ014%27TQ/1U]%4E(I.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("HO"B`@("!F=6YC=&EO;B!?;&]C:U-E<W-I;VXH)&ED*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?9G`@/2!`9F]P96XH)'1H:7,M/E]P87)A;7-;)VQO
M8VM?9&ER)UT@+B`G+VQO8VM?)R`N("1I9"P@)W<K)RD["B`@("`@("`@:68@
M*"$D=&AI<RT^7V9P*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E
M*"=#;W5L9"!N;W0@;W!E;B!S97-S:6]N(&QO8VL@9F]R("<@+B`D:60L(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("!I9B`H(4!F;&]C:R@D
M=&AI<RT^7V9P+"!,3T-+7T58*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G
M365S<V%G92@G0V]U;&0@;F]T(&QO8VL@<V5S<VEO;B`G("X@)&ED+"!?7T9)
M3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]U;FQO8VM397-S:6]N*"D*("`@('L*("`@("`@("!I
M9B`H:7-?<F5S;W5R8V4H)'1H:7,M/E]F<"DI('L*("`@("`@("`@("`@:68@
M*"%`9FQO8VLH)'1H:7,M/E]F<"P@3$]#2U]53BDI('L*("`@("`@("`@("`@
M("`@($AO<F1E.CIL;V=-97-S86=E*"=#;W5L9"!N;W0@=6YL;V-K('-E<W-I
M;VXG+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@0&9C;&]S92@D=&AI<RT^7V9P*3L*("`@
M("`@("!]"B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(O;V-I."YP:'``````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,C0P,S(@,3`U,34T,S,W,S4@,#(S-C0U
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B!397-S:6]N2&%N9&QE<CHZ(&EM<&QE;65N=&%T:6]N(&9O
M<B!/<F%C;&4@.&D@*&YA=&EV92DN"B`J"B`J(%)E<75I<F5D('!A<F%M971E
M<G,Z/'!R93X*("H@("`G:&]S='-P96,G("!4:&4@:&]S=&YA;64@;V8@=&AE
M(&1A=&%B87-E('-E<G9E<BX*("H@("`G<')O=&]C;VPG("!4:&4@8V]M;75N
M:6-A=&EO;B!P<F]T;V-O;"`H)W1C<"<L("=U;FEX)RP@971C+BDN"B`J("`@
M)W5S97)N86UE)R`@5&AE('5S97)N86UE('=I=&@@=VAI8V@@=&\@8V]N;F5C
M="!T;R!T:&4@9&%T86)A<V4N"B`J("`@)W!A<W-W;W)D)R`@5&AE('!A<W-W
M;W)D(&%S<V]C:6%T960@=VET:"`G=7-E<FYA;64G+@H@*B`@("=D871A8F%S
M92<@(%1H92!N86UE(&]F('1H92!D871A8F%S92X*("H@("`G=&%B;&4G("`@
M("!4:&4@;F%M92!O9B!T:&4@<V5S<VEO;F1A=&$@=&%B;&4@:6X@)V1A=&%B
M87-E)RX\+W!R93X*("H*("H@4F5Q=6ER960@9F]R('-O;64@8V]N9FEG=7)A
M=&EO;G,Z/'!R93X*("H@("`G<&]R="<@(%1H92!P;W)T(&]N('=H:6-H('1O
M(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+CPO<')E/@H@*@H@*B!/<'1I;VYA
M;"!P87)A;65T97)S.CQP<F4^"B`J("`@)W!E<G-I<W1E;G0G("!5<V4@<&5R
M<VES=&5N="!$0B!C;VYN96-T:6]N<S\@*&)O;VQE86XI/"]P<F4^"B`J"B`J
M(%1H92!T86)L92!S=')U8W1U<F4@9F]R('1H92!397-S:6]N2&%N9&QE<B!C
M86X@8F4@9F]U;F0@:6X*("H@:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?<V5S
M<VEO;FAA;F1L97(N;V-I."YS<6PN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+V]C:3@N<&AP+'8@,2XX
M+C0N,3$@,C`P-B\P,B\Q,"`Q.#HT-CHU,R!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#,M,C`P-B!,:6%M($AO96ME;F=A(#QL:6%M<D!U;6EC:"YE
M9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!,:6%M($AO96ME;F=A
M(#QL:6%M<D!U;6EC:"YE9'4^"B`J($!S:6YC92`@($AO<F1E(#(N,@H@*B!`
M<&%C:V%G92!(;W)D95]397-S:6]N2&%N9&QE<@H@*B\*8VQA<W,@4V5S<VEO
M;DAA;F1L97)?;V-I."!E>'1E;F1S(%-E<W-I;VY(86YD;&5R('L*"B`@("`O
M*BH*("`@("`J($AA;F1L92!F;W(@=&AE(&-U<G)E;G0@9&%T86)A<V4@8V]N
M;F5C=&EO;BX*("`@("`J"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*
M("`@('9A<B`D7V1B.PH*("`@("\J*@H@("`@("H@07)E('=E(&-O;FYE8W1E
M9"!T;R!T:&4@4U%,('-E<G9E<BX*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE
M86X*("`@("`J+PH@("`@=F%R("1?8V]N;F5C=&5D(#T@9F%L<V4["@H@("`@
M+RHJ"B`@("`@*B!#;&]S92!T:&4@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S
M<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;&]S
M92@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?8V]N;F5C=&5D*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?8V]N;F5C=&5D(#T@9F%L<V4["B`@("`@("`@
M("`@(')E='5R;B!/0TE,;V=/9F8H)'1H:7,M/E]D8BD["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M860@=&AE(&1A=&$@9F]R(&$@<&%R=&EC=6QA<B!S97-S:6]N(&ED96YT:69I
M97(@9G)O;2!T:&4*("`@("`J(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@(%1H92!S97-S:6]N(&ED
M96YT:69I97(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!S
M97-S:6]N(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E860H)&ED*0H@
M("`@>PH@("`@("`@("\J($UA:V4@<W5R92!W92!H879E(&$@=F%L:60@9&%T
M86)A<V4@8V]N;F5C=&EO;BX@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H
M*3L*"B`@("`@("`@)'-E;&5C=%]Q=65R>2`]('-P<FEN=&8H)U-%3$5#5"!S
M97-S:6]N7V1A=&$@1E)/32`E<R!72$5212!S97-S:6]N7VED(#T@)7,@1D]2
M(%501$%412<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)W1A8FQE)UTL("1T:&ES+3Y?<75O=&4H)&ED*2D["@H@
M("`@("`@("\J($QO9R!T:&4@<75E<GD@870@82!$14)51R!L;V<@;&5V96PN
M("HO"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R:6YT9B@G4U%,(%%U
M97)Y(&)Y(%-E<W-I;VY(86YD;&5R7V]C:3@Z.G)E860H*3H@<75E<GD@/2`B
M)7,B)RP@)'-E;&5C=%]Q=65R>2DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@
M("`@("\J($5X96-U=&4@<75E<GD@*B\*("`@("`@("`D<V5L96-T7W-T871E
M;65N="`]($]#25!A<G-E*"1T:&ES+3Y?9&(L("1S96QE8W1?<75E<GDI.PH@
M("`@("`@($]#245X96-U=&4H)'-E;&5C=%]S=&%T96UE;G0I.PH@("`@("`@
M(&EF("@A3T-)1F5T8VA);G1O*"1S96QE8W1?<W1A=&5M96YT+"`D<F5S=6QT
M*2D@>PH@("`@("`@("`@("`D:6YS97)T7W%U97)Y(#T@<W!R:6YT9B@G24Y3
M15)4($E.5$\@)7,@*'-E<W-I;VY?:60L('-E<W-I;VY?;&%S=&UO9&EF:65D
M+"!S97-S:6]N7V1A=&$I(%9!3%5%4R`H)7,L("5S+"!%35!465]"3$]"*"DI
M(%)%5%523DE.1R!S97-S:6]N7V1A=&$@24Y43R`Z8FQO8B<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T
M86)L92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W%U;W1E*"1I9"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<75O=&4H=&EM92@I*2D["B`@("`@("`@("`@
M("1I;G-E<G1?<W1A=&5M96YT(#T@3T-)4&%R<V4H)'1H:7,M/E]D8BP@)&EN
M<V5R=%]Q=65R>2D["B`@("`@("`@("`@("1L;V(@/2!/0TE.97=$97-C<FEP
M=&]R*"1T:&ES+3Y?9&(I.PH@("`@("`@("`@("!/0TE":6YD0GE.86UE*"1I
M;G-E<G1?<W1A=&5M96YT+"`G.F)L;V(G+"`D;&]B+"`M,2P@4U%,5%]"3$]"
M*3L*("`@("`@("`@("`@3T-)17AE8W5T92@D:6YS97)T7W-T871E;65N="P@
M3T-)7T1%1D%53%0I.PH@("`@("`@("`@("!I9B`H)'-E<W-I;VY?9&%T82D@
M>PH@("`@("`@("`@("`@("`@)&QO8BT^<V%V92@D<V5S<VEO;E]D871A*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D<F5S=6QT(#T@3T-)0V]M;6ET
M*"1T:&ES+3Y?9&(I.PH@("`@("`@("`@("!/0TE&<F5E4W1A=&5M96YT*"1I
M;G-E<G1?<W1A=&5M96YT*3L*("`@("`@("`@("`@3T-)17AE8W5T92@D<V5L
M96-T7W-T871E;65N="D["B`@("`@("`@("`@($]#249E=&-H26YT;R@D<V5L
M96-T7W-T871E;65N="P@)')E<W5L="D["B`@("`@("`@?0H@("`@("`@("1V
M86QU92`]("1R97-U;'1;,%TM/FQO860H*3L*("`@("`@("!/0TE&<F5E4W1A
M=&5M96YT*"1S96QE8W1?<W1A=&5M96YT*3L*("`@("`@("!R971U<FXH)'9A
M;'5E*3L*("`@('T*"B`@("`O*BH*("`@("`J(%=R:71E('-E<W-I;VX@9&%T
M82!T;R!T:&4@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1I9"`@("`@("`@("`@(%1H92!S97-S:6]N(&ED
M96YT:69I97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1S97-S:6]N7V1A=&$@
M(%1H92!S97-S:6]N(&1A=&$N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]T:&5R=VES92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@=W)I=&4H)&ED+"`D<V5S<VEO;E]D871A*0H@("`@
M>PH@("`@("`@("\J($UA:V4@<W5R92!W92!H879E(&$@=F%L:60@9&%T86)A
M<V4@8V]N;F5C=&EO;BX@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*
M"B`@("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*("`@("`@("`D
M<75E<GD@/2!S<')I;G1F*"=54$1!5$4@)7,@4T54('-E<W-I;VY?;&%S=&UO
M9&EF:65D(#T@)7,L('-E<W-I;VY?9&%T82`]($5-4%197T),3T(H*2!72$52
M12!S97-S:6]N7VED(#T@)7,@4D5455).24Y'('-E<W-I;VY?9&%T82!)3E1/
M(#IB;&]B)RP*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=T86)L92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]Q=6]T92AT:6UE*"DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]Q=6]T92@D:60I*3L*"B`@("`@("`@+RH@3&]G('1H92!Q=65R>2!A
M="!A($1%0E5'(&QO9R!L979E;"X@*B\*("`@("`@("!(;W)D93HZ;&]G365S
M<V%G92AS<')I;G1F*"=344P@475E<GD@8GD@4V5S<VEO;DAA;F1L97)?;V-I
M.#HZ=W)I=&4H*3H@<75E<GD@/2`B)7,B)RP@)'%U97)Y*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'
M7T1%0E5'*3L*"B`@("`@("`@+RH@17AE8W5T92!Q=65R>2`J+PH@("`@("`@
M("1S=&%T96UE;G0@/2!/0TE087)S92@D=&AI<RT^7V1B+"`D<75E<GDI.PH@
M("`@("`@("1L;V(@/2!/0TE.97=$97-C<FEP=&]R*"1T:&ES+3Y?9&(I.PH@
M("`@("`@($]#24)I;F1">4YA;64H)'-T871E;65N="P@)SIB;&]B)RP@)&QO
M8BP@+3$L(%-13%1?0DQ/0BD["B`@("`@("`@3T-)17AE8W5T92@D<W1A=&5M
M96YT+"!/0TE?1$5&055,5"D["B`@("`@("`@:68@*"1S97-S:6]N7V1A=&$I
M('L*("`@("`@("`@("`@)&QO8BT^<V%V92@D<V5S<VEO;E]D871A*3L*("`@
M("`@("!]"B`@("`@("`@)')E<W5L="`]($]#24-O;6UI="@D=&AI<RT^7V1B
M*3L*("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@2&]R9&4Z
M.FQO9TUE<W-A9V4H)T5R<F]R('=R:71I;F<@<V5S<VEO;B!D871A)RP@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"B`@("`O*BH*("`@("`J($1E<W1R;WD@=&AE(&1A=&$@9F]R(&$@
M<&%R=&EC=6QA<B!S97-S:6]N(&ED96YT:69I97(@:6X@=&AE"B`@("`@*B!3
M97-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&ED("!4:&4@<V5S<VEO;B!I9&5N=&EF:65R+@H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O
M=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E<W1R;WDH)&ED*0H@
M("`@>PH@("`@("`@("\J($UA:V4@<W5R92!W92!H879E(&$@=F%L:60@9&%T
M86)A<V4@8V]N;F5C=&EO;BX@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H
M*3L*"B`@("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*("`@("`@
M("`D<75E<GD@/2!S<')I;G1F*"`G1$5,151%($923TT@)7,@5TA%4D4@<V5S
M<VEO;E]I9"`]("5S)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG=&%B;&4G72P@)'1H:7,M/E]Q=6]T92@D:60I*3L*"B`@
M("`@("`@+RH@3&]G('1H92!Q=65R>2!A="!A($1%0E5'(&QO9R!L979E;"X@
M*B\*("`@("`@("!(;W)D93HZ;&]G365S<V%G92AS<')I;G1F*"=344P@475E
M<GD@8GD@4V5S<VEO;DAA;F1L97)?;V-I.#HZ9&5S=')O>2@I.B!Q=65R>2`]
M("(E<R(G+"`D<75E<GDI+`H@("`@("`@("`@("`@("`@("`@("`@("`@(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`O
M*B!%>&5C=71E('1H92!Q=65R>2X@*B\*("`@("`@("`D<W1A=&5M96YT(#T@
M3T-)4&%R<V4H)'1H:7,M/E]D8BP@)'%U97)Y*3L*("`@("`@("`D<F5S=6QT
M(#T@3T-)17AE8W5T92@D<W1A=&5M96YT*3L*("`@("`@("!I9B`H(21R97-U
M;'0I('L*("`@("`@("`@("`@3T-)1G)E95-T871E;65N="@D<W1A=&5M96YT
M*3L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T9A:6QE9"!T;R!D
M96QE=&4@<V5S<VEO;B`H:60@/2`G("X@)&ED("X@)RDG+"!?7T9)3$5?7RP@
M7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"@H@("`@("`@($]#249R9653=&%T96UE;G0H)'-T
M871E;65N="D["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'87)B86=E(&-O;&QE8W0@<W1A;&4@<V5S<VEO;G,@9G)O;2!T
M:&4@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D;6%X;&EF971I;64@(%1H92!M87AI;75M(&%G92!O9B!A
M('-E<W-I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E
M(&]N('-U8V-E<W,L(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V,H)&UA>&QI9F5T:6UE(#T@,2D*("`@('L*("`@("`@("`O*B!-
M86ME('-U<F4@=V4@:&%V92!A('9A;&ED(&1A=&%B87-E(&-O;FYE8W1I;VXN
M("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@("\J($)U
M:6QD('1H92!344P@<75E<GDN("HO"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT
M9B@G1$5,151%($923TT@)7,@5TA%4D4@<V5S<VEO;E]L87-T;6]D:69I960@
M/"`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M
M<ULG=&%B;&4G72P@)'1H:7,M/E]Q=6]T92AT:6UE*"D@+2`D;6%X;&EF971I
M;64I*3L*"B`@("`@("`@+RH@3&]G('1H92!Q=65R>2!A="!A($1%0E5'(&QO
M9R!L979E;"X@*B\*("`@("`@("!(;W)D93HZ;&]G365S<V%G92AS<')I;G1F
M*"=344P@475E<GD@8GD@4V5S<VEO;DAA;F1L97)?;V-I.#HZ9V,H*3H@<75E
M<GD@/2`B)7,B)RP@)'%U97)Y*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@
M("`@+RH@17AE8W5T92!T:&4@<75E<GDN("HO"B`@("`@("`@)'-T871E;65N
M="`]($]#25!A<G-E*"1T:&ES+3Y?9&(L("1Q=65R>2D["B`@("`@("`@)')E
M<W5L="`]($]#245X96-U=&4H)'-T871E;65N="D["B`@("`@("`@:68@*"$D
M<F5S=6QT*2!["B`@("`@("`@("`@($]#249R9653=&%T96UE;G0H)'-T871E
M;65N="D["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=%<G)O<B!G
M87)B86=E(&-O;&QE8W1I;F<@;VQD('-E<W-I;VYS)RP@7U]&24Q%7U\L(%]?
M3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("!/0TE&<F5E4W1A=&5M96YT*"1S=&%T
M96UE;G0I.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1V5T(&$@;&ES="!O9B!T:&4@=F%L:60@<V5S<VEO;B!I9&5N=&EF
M:65R<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!(&QI<W0@;V8@
M=F%L:60@<V5S<VEO;B!I9&5N=&EF:65R<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T4V5S<VEO;DE$<R@I"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E
M('=E(&AA=F4@82!V86QI9"!D871A8F%S92!C;VYN96-T:6]N+B`J+PH@("`@
M("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("`O*B!397-S:6]N('1I
M;65O=70L(&1O;B=T(')E;'D@;VX@9V%R8F%G92!C;VQL96-T:6]N("HO"B`@
M("`@("`@)'1I;65O=70@/2!T:6UE*"D@+2!I;FE?9V5T*"=S97-S:6]N+F=C
M7VUA>&QI9F5T:6UE)RD["@H@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)U-%
M3$5#5"!S97-S:6]N7VED($923TT@)7,G("X*("`@("`@("`@("`@("`@("`@
M("`@("`@("<@5TA%4D4@<V5S<VEO;E]L87-T;6]D:69I960@/B`E<R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G
M72P*("`@("`@("`@("`@("`@("`@("`@("`@("1T:6UE;W5T*3L*"B`@("`@
M("`@+RH@3&]G('1H92!Q=65R>2!A="!A($1%0E5'(&QO9R!L979E;"X@*B\*
M("`@("`@("!(;W)D93HZ;&]G365S<V%G92AS<')I;G1F*"=344P@475E<GD@
M8GD@4V5S<VEO;DAA;F1L97)?;V-I.#HZ9V5T4V5S<VEO;DE$<R@I.B!Q=65R
M>2`]("(E<R(G+"`D<75E<GDI+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@
M("`O*B!%>&5C=71E('%U97)Y("HO"B`@("`@("`@)'-T871E;65N="`]($]#
M25!A<G-E*"1T:&ES+3Y?9&(L("1Q=65R>2D["B`@("`@("`@3T-)17AE8W5T
M92@D<W1A=&5M96YT*3L*"B`@("`@("`@)'-E<W-I;VYS(#T@87)R87DH*3L*
M("`@("`@("!W:&EL92`H3T-)1F5T8VA);G1O*"1S=&%T96UE;G0L("1R;W<I
M*2!["B`@("`@("`@("`@("1S97-S:6]N<UM=(#T@)')O=ULP73L*("`@("`@
M("!]"@H@("`@("`@($]#249R9653=&%T96UE;G0H)'-T871E;65N="D["B`@
M("`@("`@<F5T=7)N("1S97-S:6]N<SL*("`@('T*"B`@("`O*BH*("`@("`J
M($5S8V%P92!A('-T<FEN9R!F;W(@:6YS97)T:6]N+B!3=&]L96X@9G)O;2!0
M14%2.CI$0BX*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'9A;'5E("!4:&4@<W1R:6YG('1O('%U;W1E+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<75O=&5D('-T<FEN
M9RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W%U;W1E*"1V86QU92D*("`@('L*
M("`@("`@("!R971U<FX@*"1V86QU92`]/3T@;G5L;"D@/R`G3E5,3"<@.B`B
M)R(@+B!S=')?<F5P;&%C92@B)R(L("(G)R(L("1V86QU92D@+B`B)R(["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!O<&5N(&$@8V]N;F5C
M=&EO;B!T;R!T:&4@4U%,('-E<G9E<BX*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;FYE8W0H*0H@("`@
M>PH@("`@("`@(&EF("@D=&AI<RT^7V-O;FYE8W1E9"D@>PH@("`@("`@("`@
M("!R971U<FX["B`@("`@("`@?0H*("`@("`@("!(;W)D93HZ87-S97)T1')I
M=F5R0V]N9FEG*"1T:&ES+3Y?<&%R86US+"`G<V5S<VEO;FAA;F1L97(G+`H@
M("`@("`@("`@("!A<G)A>2@G:&]S='-P96,G+"`G=7-E<FYA;64G+"`G<&%S
M<W=O<F0G*2P*("`@("`@("`@("`@)W-E<W-I;VX@:&%N9&QE<B!/<F%C;&4G
M*3L*"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG=&%B;&4G
M72DI('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT@/2`G
M:&]R9&5?<V5S<VEO;FAA;F1L97(G.PH@("`@("`@('T*"B`@("`@("`@:68@
M*&9U;F-T:6]N7V5X:7-T<R@G;V-I7V-O;FYE8W0G*2D@>PH@("`@("`@("`@
M("!I9B`H96UP='DH)'1H:7,M/E]P87)A;7-;)W!E<G-I<W1E;G0G72DI('L*
M("`@("`@("`@("`@("`@("1C;VYN96-T(#T@)V]C:5]C;VYN96-T)SL*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1C;VYN96-T(#T@
M)V]C:5]P8V]N;F5C="<["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)A;7-;)W!E<G-I
M<W1E;G0G72DI('L*("`@("`@("`@("`@("`@("1C;VYN96-T(#T@)T]#24QO
M9V]N)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1C
M;VYN96-T(#T@)T]#25!,;V=O;B<["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(&EF("@A:7-?<F5S;W5R8V4H)'1H:7,M/E]D8B`]($`D8V]N
M;F5C="@D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;64G72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)W!A<W-W;W)D)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=H;W-T<W!E
M8R==*2DI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*%!%05(Z.G)A:7-E
M17)R;W(H)T-O=6QD(&YO="!C;VYN96-T('1O(&1A=&%B87-E(&9O<B!344P@
M4V5S<VEO;DAA;F1L97(N)RDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@
M("`@?0H*("`@("`@("`D=&AI<RT^7V-O;FYE8W1E9"`]('1R=64["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]397-S:6]N2&%N9&QE<B]P
M9W-Q;"YP:'``````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R-S8U,2`Q,#4Q
M-30S,S<S-2`P,C0Q-#,`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J(%!O<W1G<F5344P@4V5S<VEO;B!(
M86YD;&5R(&9O<B!02%`@*&YA=&EV92DN"B`J"B`J($-O<'ER:6=H="`R,#`P
M+3(P,#8@2F]N(%!A<FES92`\:F]N0&-S:"YR:70N961U/BX@($%L;"!R:6=H
M=',@<F5S97)V960N"B`J"B`J("!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN
M('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70*("H@
M(&UO9&EF:6-A=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H
M92!F;VQL;W=I;F<@8V]N9&ET:6]N<PH@*B`@87)E(&UE=#H*("H@(#$N(%)E
M9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@
M86)O=F4@8V]P>7)I9VAT"B`J("`@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C
M;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N"B`J("`R
M+B!2961I<W1R:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U
M8V4@=&AE(&%B;W9E(&-O<'ER:6=H=`H@*B`@("`@;F]T:6-E+"!T:&ES(&QI
M<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R
M(&EN('1H90H@*B`@("`@9&]C=6UE;G1A=&EO;B!A;F0O;W(@;W1H97(@;6%T
M97)I86QS('!R;W9I9&5D('=I=&@@=&AE(&1I<W1R:6)U=&EO;BX*("H*("H@
M(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($%55$A/4B!!3D0@
M0T].5%))0E543U)3(&!@05,@25,G)R!!3D0*("H@($%.62!%6%!215-3($]2
M($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4($Q)34E4
M140@5$\L(%1(10H@*B`@24U03$E%1"!705)204Y42453($]&($U%4D-(04Y4
M04))3$E462!!3D0@1DE43D534R!&3U(@02!005)424-53$%2(%!54E!/4T4*
M("H@($%212!$25-#3$%)345$+B`@24X@3D\@159%3E0@4TA!3$P@5$A%($%5
M5$A/4B!/4B!#3TY44DE"551/4E,@0D4@3$E!0DQ%"B`J("!&3U(@04Y9($1)
M4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL(%-014-)04PL($5814U03$%2
M62P@3U(@0T].4T51545.5$E!3`H@*B`@1$%-04=%4R`H24Y#3%5$24Y'+"!"
M550@3D]4($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&(%-50E-425155$4@
M1T]/1%,*("H@($]2(%-%4E9)0T53.R!,3U-3($]&(%5312P@1$%402P@3U(@
M4%)/1DE44SL@3U(@0E5324Y%4U,@24Y415)255!424].*0H@*B`@2$]7159%
M4B!#0553140@04Y$($].($%.62!42$5/4ED@3T8@3$E!0DE,2519+"!72$54
M2$52($E.($-/3E1204-4+"!35%))0U0*("H@($Q)04))3$E462P@3U(@5$]2
M5"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!4DE324Y'
M($E.($%.62!705D*("H@($]55"!/1B!42$4@55-%($]&(%1(25,@4T]&5%=!
M4D4L($5614X@248@041625-%1"!/1B!42$4@4$]34TE"24Q)5%D@3T8*("H@
M(%-50T@@1$%-04=%+@H@*@H@*B!297%U:7)E9"!P87)A;65T97)S.CQP<F4^
M"B`J("`@)V1A=&%B87-E)R`@5&AE(&YA;64@;V8@=&AE(&1A=&%B87-E+@H@
M*B`@("=P87-S=V]R9"<@(%1H92!P87-S=V]R9"!A<W-O8VEA=&5D('=I=&@@
M)W5S97)N86UE)RX*("H@("`G<')O=&]C;VPG("!4:&4@8V]M;75N:6-A=&EO
M;B!P<F]T;V-O;"`H)W1C<"<L("=U;FEX)RDN"B`J("`@)W5S97)N86UE)R`@
M5&AE('5S97)N86UE('=I=&@@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T
M86)A<V4N"B`J"B`J(%)E<75I<F5D(&9O<B!S;VUE(&-O;F9I9W5R871I;VYS
M("AI+F4N("=P<F]T;V-O;"<@/2`G=&-P)RDZ/'!R93X*("H@("`G:&]S='-P
M96,G("!4:&4@:&]S=&YA;64@;V8@=&AE(&1A=&%B87-E('-E<G9E<BX*("H@
M("`G<&]R="<@("`@("!4:&4@<&]R="!O;B!W:&EC:"!T;R!C;VYN96-T('1O
M('1H92!D871A8F%S92X\+W!R93X*("H*("H@3W!T:6]N86P@<&%R86UE=&5R
M<SH\<')E/@H@*B`@("=P97)S:7-T96YT)R`@57-E('!E<G-I<W1E;G0@1$(@
M8V]N;F5C=&EO;G,_("AB;V]L96%N*0H@*B`@("`@("`@("`@("`@("`@1&5F
M875L=#H@3D\*("H@("`G=&%B;&4G("`@("`@(%1H92!N86UE(&]F('1H92!S
M97-S:6]N9&%T82!T86)L92!I;B`G9&%T86)A<V4G+@H@*B`@("`@("`@("`@
M("`@("`@1&5F875L=#H@)VAO<F1E7W-E<W-I;VYH86YD;&5R)SPO<')E/@H@
M*@H@*B!4:&4@=&%B;&4@<W1R=6-T=7)E(&9O<B!T:&4@4V5S<VEO;DAA;F1L
M97(@8V%N(&)E(&9O=6YD(&EN"B`J(&AO<F1E+W-C<FEP=',O<W%L+VAO<F1E
M7W-E<W-I;VYH86YD;&5R+G!G<W%L+G-Q;"X*("H*("H@0V]N=')I8G5T;W)S
M.CQP<F4^"B`J("!*87-O;B!#87)L<V]N("`@("`@("`@("!2971U<FX@86X@
M96UP='D@<W1R:6YG(&]N(&9A:6QE9"!R96%D<PH@*B`@<&%T0'!C<')O9W)A
M;6UE<BYC;VT@("`@4&5R9F]R;2!U<&1A=&4@:6X@82!S:6YG;&4@=')A;G-A
M8W1I;VX*("H@($IO;F%T:&%N($-R;VUP=&]N("`@("`@($QO8VL@<F]W(&9O
M<B!L:69E(&]F('-E<W-I;VX\+W!R93X*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O<&=S<6PN<&AP+'8@
M,2XQ,BXQ,"XQ-2`R,#`V+S`S+S(S(#$X.C`P.C$W(&IA;B!%>'`@)`H@*@H@
M*B!`875T:&]R("!*;VX@4&%R:7-E(#QJ;VY`8W-H+G)I="YE9'4^"B`J($!S
M:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]397-S:6]N2&%N
M9&QE<@H@*B\*8VQA<W,@4V5S<VEO;DAA;F1L97)?<&=S<6P@97AT96YD<R!3
M97-S:6]N2&%N9&QE<B!["@H@("`@+RHJ"B`@("`@*B!(86YD;&4@9F]R('1H
M92!C=7)R96YT(&1A=&%B87-E(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@("H@
M0'9A<B!R97-O=7)C90H@("`@("HO"B`@("!V87(@)%]D8CL*"B`@("`O*BH*
M("`@("`J($%R92!W92!C;VYN96-T960@=&\@=&AE(%-13"!S97)V97(N"B`@
M("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7V-O
M;FYE8W1E9"`](&9A;'-E.PH*("`@("\J*@H@("`@("H@0VQO<V4@=&AE(%-E
M<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]T:&5R=VES92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@8VQO<V4H*0H@("`@>PH@("`@("`@("\J($1I
M<V-O;FYE8W0@9G)O;2!D871A8F%S92X@*B\*("`@("`@("!I9B`H)'1H:7,M
M/E]C;VYN96-T960I('L*("`@("`@("`@("`@)'1H:7,M/E]C;VYN96-T960@
M/2!F86QS93L*("`@("`@("`@("`@<F5T=7)N($!P9U]C;&]S92@D=&AI<RT^
M7V1B*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5A9"!T:&4@9&%T82!F;W(@82!P87)T:6-U;&%R
M('-E<W-I;VX@:61E;G1I9FEE<B!F<F]M('1H90H@("`@("H@4V5S<VEO;DAA
M;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I
M9"`@5&AE('-E<W-I;VX@:61E;G1I9FEE<BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE('-E<W-I;VX@9&%T82X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F5A9"@D:60I"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E('=E
M(&AA=F4@82!V86QI9"!D871A8F%S92!C;VYN96-T:6]N+B`J+PH@("`@("`@
M("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("!`<&=?<75E<GDH)'1H:7,M
M/E]D8BP@)T)%1TE..R<I.PH*("`@("`@("`D=&EM96]U="`]('1I;64H*2`M
M(&EN:5]G970H)W-E<W-I;VXN9V-?;6%X;&EF971I;64G*3L*("`@("`@("`D
M<75E<GD@/2!S<')I;G1F*"=314Q%0U0@<V5S<VEO;E]D871A($923TT@)7,@
M5TA%4D4@)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`G<V5S<VEO;E]I
M9"`]("5S($%.1"!S97-S:6]N7VQA<W1M;V1I9FEE9"`^/2`E<R`G("X*("`@
M("`@("`@("`@("`@("`@("`@("`@("=&3U(@55!$051%.R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YQ=6]T92@D:60I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1I;65O=70I.PH*("`@("`@("`O*B!,
M;V<@=&AE('%U97)Y(&%T(&$@1$5"54<@;&]G(&QE=F5L+B`J+PH@("`@("`@
M($AO<F1E.CIL;V=-97-S86=E*'-P<FEN=&8H)U-13"!1=65R>2!B>2!397-S
M:6]N2&%N9&QE<E]P9W-Q;#HZ)R`N"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G<F5A9"@I.B!Q=65R>2`]("(E<R(G+"`D<75E<GDI+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`D<F5S=6QT(#T@0'!G7W%U97)Y
M*"1T:&ES+3Y?9&(L("1Q=65R>2D["B`@("`@("`@)&1A=&$@/2!P9U]F971C
M:%]R97-U;'0H)')E<W5L="P@,"P@)W-E<W-I;VY?9&%T82<I.PH@("`@("`@
M('!G7V9R965?<F5S=6QT*"1R97-U;'0I.PH*("`@("`@("!R971U<FX@<&%C
M:R@G2"HG+"`D9&%T82D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!7<FET92!S
M97-S:6]N(&1A=&$@=&\@=&AE(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@("`@("`@("`@("!4:&4@
M<V5S<VEO;B!I9&5N=&EF:65R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5S
M<VEO;E]D871A("!4:&4@<V5S<VEO;B!D871A+@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O=&AE<G=I
M<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N('=R:71E*"1I9"P@)'-E<W-I;VY?
M9&%T82D*("`@('L*("`@("`@("`O*B!-86ME('-U<F4@=V4@:&%V92!A('9A
M;&ED(&1A=&%B87-E(&-O;FYE8W1I;VXN("HO"B`@("`@("`@)'1H:7,M/E]C
M;VYN96-T*"D["@H@("`@("`@("1T:6UE;W5T(#T@=&EM92@I("T@:6YI7V=E
M="@G<V5S<VEO;BYG8U]M87AL:69E=&EM92<I.PH@("`@("`@("1Q=65R>2`]
M('-P<FEN=&8H)U-%3$5#5"!S97-S:6]N7V1A=&$@1E)/32`E<R!72$5212`G
M("X*("`@("`@("`@("`@("`@("`@("`@("`@("=S97-S:6]N7VED(#T@)7,@
M04Y$('-E<W-I;VY?;&%S=&UO9&EF:65D(#X]("5S("<@+@H@("`@("`@("`@
M("`@("`@("`@("`@("`@)T9/4B!54$1!5$4G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^<75O=&4H)&ED*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:6UE;W5T*3L*("`@("`@("`D<F5S=6QT(#T@0'!G
M7W%U97)Y*"1T:&ES+3Y?9&(L("1Q=65R>2D["B`@("`@("`@)')O=W,@/2!P
M9U]N=6U?<F]W<R@D<F5S=6QT*3L*("`@("`@("!P9U]F<F5E7W)E<W5L="@D
M<F5S=6QT*3L*"B`@("`@("`@:68@*"1R;W=S(#T](#`I('L*("`@("`@("`@
M("`@)'%U97)Y(#T@<W!R:6YT9B@G24Y315)4($E.5$\@)7,@*'-E<W-I;VY?
M:60L("<@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S97-S:6]N
M7VQA<W1M;V1I9FEE9"P@<V5S<VEO;E]D871A*2`G("X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G5D%,5453("@E<RP@)7,L("5S*3LG+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L
M92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YQ=6]T
M92@D:60I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1I;64H*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<75O=&4H8FEN
M,FAE>"@D<V5S<VEO;E]D871A*2DI.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1Q=65R>2`]('-P<FEN=&8H)U501$%412`E<R!3150@<V5S<VEO
M;E]L87-T;6]D:69I960@/2`E<RP@)R`N"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W-E<W-I;VY?9&%T82`]("5S(%=(15)%('-E<W-I;VY?:60@
M/2`E<SLG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=T86)L92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('1I;64H*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M<75O=&4H8FEN,FAE>"@D<V5S<VEO;E]D871A*2DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/G%U;W1E*"1I9"DI.PH@("`@("`@('T*
M"B`@("`@("`@+RH@3&]G('1H92!Q=65R>2!A="!A($1%0E5'(&QO9R!L979E
M;"X@*B\*("`@("`@("!(;W)D93HZ;&]G365S<V%G92AS<')I;G1F*"=344P@
M475E<GD@8GD@4V5S<VEO;DAA;F1L97)?<&=S<6PZ.B<@+@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W=R:71E*"DZ('%U97)Y(#T@(B5S
M(B<L("1Q=65R>2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%
M7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("1R97-U
M;'0@/2!`<&=?<75E<GDH)'1H:7,M/E]D8BP@)'%U97)Y*3L*("`@("`@("!I
M9B`H(21R97-U;'0I('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H
M)T5R<F]R('=R:71I;F<@<V5S<VEO;B!D871A.B`G("X@<&=?;&%S=%]E<G)O
M<B@D=&AI<RT^7V1B*2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%
M4E(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@
M("`@("1R;W=S(#T@<&=?869F96-T961?<F]W<R@D<F5S=6QT*3L*("`@("`@
M("!P9U]F<F5E7W)E<W5L="@D<F5S=6QT*3L*"B`@("`@("`@0'!G7W%U97)Y
M*"1T:&ES+3Y?9&(L("=#3TU-250[)RD["@H@("`@("`@(&EF("@D<F]W<R`A
M/2`Q*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=%<G)O<B!W
M<FET:6YG('-E<W-I;VX@9&%T82<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$97-T<F]Y('1H92!D
M871A(&9O<B!A('!A<G1I8W5L87(@<V5S<VEO;B!I9&5N=&EF:65R(&EN('1H
M90H@("`@("H@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE('-E<W-I;VX@:61E;G1I9FEE<BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S
M<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D97-T
M<F]Y*"1I9"D*("`@('L*("`@("`@("`O*B!-86ME('-U<F4@=V4@:&%V92!A
M('9A;&ED(&1A=&%B87-E(&-O;FYE8W1I;VXN("HO"B`@("`@("`@)'1H:7,M
M/E]C;VYN96-T*"D["@H@("`@("`@("\J($)U:6QD('1H92!344P@<75E<GDN
M("HO"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G1$5,151%($923TT@)7,@
M5TA%4D4@<V5S<VEO;E]I9"`]("5S.R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P@)'1H:7,M/G%U;W1E*"1I
M9"DI.PH*("`@("`@("`O*B!,;V<@=&AE('%U97)Y(&%T(&$@1$5"54<@;&]G
M(&QE=F5L+B`J+PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P<FEN=&8H
M)U-13"!1=65R>2!B>2!397-S:6]N2&%N9&QE<E]P9W-Q;#HZ)R`N"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5S=')O>2@I.B!Q=65R
M>2`]("(E<R(G+"`D<75E<GDI+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@
M("`O*B!%>&5C=71E('1H92!Q=65R>2X@*B\*("`@("`@("`D<F5S=6QT(#T@
M0'!G7W%U97)Y*"1T:&ES+3Y?9&(L("1Q=65R>2D["@H@("`@("`@($!P9U]Q
M=65R>2@D=&AI<RT^7V1B+"`G0T]-34E4.R<I.PH*("`@("`@("!I9B`H(21R
M97-U;'0I('L*("`@("`@("`@("`@<&=?9G)E95]R97-U;'0H)')E<W5L="D[
M"B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=&86EL960@=&\@9&5L
M971E('-E<W-I;VX@*&ED(#T@)R`N("1I9"`N("<I)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/
M1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*
M("`@("`@("!P9U]F<F5E7W)E<W5L="@D<F5S=6QT*3L*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($=A<F)A9V4@8V]L;&5C
M="!S=&%L92!S97-S:6]N<R!F<F]M('1H92!397-S:6]N2&%N9&QE<B!B86-K
M96YD+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1M87AL:69E=&EM
M92`@5&AE(&UA>&EM=6T@86=E(&]F(&$@<V5S<VEO;BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;W1H
M97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G8R@D;6%X;&EF971I;64@
M/2`S,#`I"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E('=E(&AA=F4@82!V
M86QI9"!D871A8F%S92!C;VYN96-T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?
M8V]N;F5C="@I.PH*("`@("`@("`O*B!"=6EL9"!T:&4@4U%,('%U97)Y+B`J
M+PH@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)T1%3$5412!&4D]-("5S(%=(
M15)%('-E<W-I;VY?;&%S=&UO9&EF:65D(#P@)7,G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^<75O=&4H=&EM92@I("T@)&UA>&QI
M9F5T:6UE*2D["@H@("`@("`@("\J($QO9R!T:&4@<75E<GD@870@82!$14)5
M1R!L;V<@;&5V96PN("HO"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R
M:6YT9B@G4U%,(%%U97)Y(&)Y(%-E<W-I;VY(86YD;&5R7W!G<W%L.CHG("X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=G8R@I.B!Q=65R
M>2`]("(E<R(G+"`D<75E<GDI+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@
M("`O*B!%>&5C=71E('1H92!Q=65R>2X@*B\*("`@("`@("`D<F5S=6QT(#T@
M0'!G7W%U97)Y*"1T:&ES+3Y?9&(L("1Q=65R>2D["B`@("`@("`@:68@*"$D
M<F5S=6QT*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=%<G)O
M<B!G87)B86=E(&-O;&QE8W1I;F<@;VQD('-E<W-I;VYS)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%2
M7TQ/1U]%4E(I.PH@("`@("`@('T*"B`@("`@("`@<&=?9G)E95]R97-U;'0H
M)')E<W5L="D["B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!%<V-A<&4@82!S=')I;F<@9F]R(&EN<V5R=&EO;B!I;G1O
M('1H92!D871A8F%S92X*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'9A;'5E("!4:&4@<W1R:6YG('1O('%U
M;W1E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<75O=&5D
M('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@<75O=&4H)'9A;'5E*0H@
M("`@>PH@("`@("`@(')E='5R;B`B)R(@+B!A9&1S;&%S:&5S*"1V86QU92D@
M+B`B)R(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!L:7-T(&]F('1H
M92!V86QI9"!S97-S:6]N(&ED96YT:69I97)S+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@($$@;&ES="!O9B!V86QI9"!S97-S:6]N(&ED96YT:69I
M97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971397-S:6]N241S*"D*("`@
M('L*("`@("`@("`O*B!-86ME('-U<F4@=V4@:&%V92!A('9A;&ED(&1A=&%B
M87-E(&-O;FYE8W1I;VXN("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D[
M"@H@("`@("`@("\J($)U:6QD('1H92!344P@<75E<GDN("HO"B`@("`@("`@
M)'%U97)Y(#T@)U-%3$5#5"!S97-S:6]N7VED($923TT@)R`N("1T:&ES+3Y?
M<&%R86US6R=T86)L92==.PH*("`@("`@("`O*B!,;V<@=&AE('%U97)Y(&%T
M(&$@1$5"54<@;&]G(&QE=F5L+B`J+PH@("`@("`@($AO<F1E.CIL;V=-97-S
M86=E*'-P<FEN=&8H)U-13"!1=65R>2!B>2!397-S:6]N2&%N9&QE<E]P9W-Q
M;#HZ)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9V5T
M4V5S<VEO;DE$<R@I.B!Q=65R>2`]("(E<R(G+"`D<75E<GDI+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],
M3T=?1$5"54<I.PH*("`@("`@("`O*B!%>&5C=71E('1H92!Q=65R>2X@*B\*
M("`@("`@("`D<F5S=6QT(#T@0'!G7W%U97)Y*"1T:&ES+3Y?9&(L("1Q=65R
M>2D["B`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@('!G7V9R
M965?<F5S=6QT*"1R97-U;'0I.PH@("`@("`@("`@("!(;W)D93HZ;&]G365S
M<V%G92@G17)R;W(@9V5T=&EN9R!S97-S:6]N($E$<R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],
M3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M"B`@("`@("`@)'-E<W-I;VYS(#T@87)R87DH*3L*("`@("`@("!W:&EL92`H
M)')O=R`]('!G7V9E=&-H7W)O=R@D<F5S=6QT*2D@>PH@("`@("`@("`@("`D
M<V5S<VEO;G-;72`]("1R;W=;,%T["B`@("`@("`@?0H*("`@("`@("!P9U]F
M<F5E7W)E<W5L="@D<F5S=6QT*3L*"B`@("`@("`@<F5T=7)N("1S97-S:6]N
M<SL*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(&]P96X@82!C
M;VYN96-T:6]N('1O('1H92!344P@<V5R=F5R+@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S.R!E>&ET<R`H2&]R9&4Z
M.F9A=&%L*"DI(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N
M;F5C="@I"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^7V-O;FYE8W1E9"D@
M>PH@("`@("`@("`@("!(;W)D93HZ87-S97)T1')I=F5R0V]N9FEG*"1T:&ES
M+3Y?<&%R86US+"`G<V5S<VEO;FAA;F1L97(G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=H;W-T<W!E8R<L("=U<V5R
M;F%M92<L("=D871A8F%S92<L("=P87-S=V]R9"<I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=S97-S:6]N(&AA;F1L97(@<&=S
M<6PG*3L*"B`@("`@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W!A<F%M<ULG
M=&%B;&4G72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T
M86)L92==(#T@)VAO<F1E7W-E<W-I;VYH86YD;&5R)SL*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@)&-O;FYE8W0@/2!E;7!T>2@D=&AI<RT^7W!A<F%M
M<ULG<&5R<VES=&5N="==*2`_"B`@("`@("`@("`@("`@("`G<&=?8V]N;F5C
M="<@.B=P9U]P8V]N;F5C="<["@H@("`@("`@("`@("`D<&%R86US='(@/2`G
M)SL*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%R86US6R=P<F]T
M;V-O;"==*2`F)@H@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!R
M;W1O8V]L)UT@/3T@)W1C<"<I('L*("`@("`@("`@("`@("`@("1P87)A;7-T
M<B`N/2`G(&AO<W0])R`N("1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==.PH@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%R86US6R=P;W)T
M)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)'!A<F%M<W1R("X]("<@<&]R
M=#TG("X@)'1H:7,M/E]P87)A;7-;)W!O<G0G73L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<&%R86US='(@+CT@)R!D
M8FYA;64])R`N("1T:&ES+3Y?<&%R86US6R=D871A8F%S92==("X*("`@("`@
M("`@("`@("`@("<@=7-E<CTG("X@)'1H:7,M/E]P87)A;7-;)W5S97)N86UE
M)UT@+@H@("`@("`@("`@("`@("`@)R!P87-S=V]R9#TG("X@)'1H:7,M/E]P
M87)A;7-;)W!A<W-W;W)D)UT["@H@("`@("`@("`@("!I9B`H(21T:&ES+3Y?
M9&(@/2!`)&-O;FYE8W0H)'!A<F%M<W1R*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AI
M<RT^7V-O;FYE8W1E9"`]('1R=64["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+U-E<W-I;VY(86YD;&5R+V1B;2YP:'``````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`V-#(S(#$P-3$U-#,S-S,U(#`R,S4U,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M4V5S<VEO;DAA;F1L97(Z.B!I;7!L96UE;G1A=&EO;B!F;W(@1$)-(&9I;&5S
M+@H@*B!.3U1%.B!4:&4@4$A0($1"32!F=6YC=&EO;G,@87)E(&1E<')E8V%T
M960N"B`J"B`J($YO(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!P87)A;65T
M97)S(&YE961E9"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4V5S<VEO;DAA
M;F1L97(O4V5S<VEO;DAA;F1L97(O9&)M+G!H<"QV(#$N.2XQ,BXW(#(P,#8O
M,#$O,#$@,C$Z,C@Z,S0@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R
M+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E
M($AO<F1E7U-E<W-I;VY(86YD;&5R"B`J+PIC;&%S<R!397-S:6]N2&%N9&QE
M<E]D8FT@97AT96YD<R!397-S:6]N2&%N9&QE<B!["@H@("`@+RHJ"B`@("`@
M*B!/=7(@<&]I;G1E<B!T;R!T:&4@1$)-(&9I;&4L(&EF(&]P96XN"B`@("`@
M*@H@("`@("H@0'9A<B!R97-O=7)C90H@("`@("HO"B`@("!V87(@)%]D8FT[
M"@H@("`@+RHJ"B`@("`@*B!/<&5N('1H92!397-S:6]N2&%N9&QE<B!B86-K
M96YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-A=F5?<&%T:"`@
M("`@5&AE('!A=&@@=&\@=&AE('-E<W-I;VX@;V)J96-T+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<V5S<VEO;E]N86UE("!4:&4@;F%M92!O9B!T:&4@<V5S
M<VEO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@
M<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!O<&5N*"1S879E7W!A=&@L("1S97-S:6]N7VYA;64I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]D8FT@/2!`9&)M;W!E;B@B)'-A=F5?<&%T:"\D<V5S<VEO
M;E]N86UE(BP@)V,G*3L*("`@("`@("!R971U<FX@)'1H:7,M/E]D8FT["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#;&]S92!T:&4@4V5S<VEO;DAA;F1L97(@
M8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@
M;VX@<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!C;&]S92@I"B`@("!["B`@("`@("`@<F5T=7)N($!D8FUC;&]S92@D
M=&AI<RT^7V1B;2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296%D('1H92!D
M871A(&9O<B!A('!A<G1I8W5L87(@<V5S<VEO;B!I9&5N=&EF:65R(&9R;VT@
M=&AE"B`@("`@*B!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&ED("!4:&4@<V5S<VEO;B!I9&5N=&EF:65R
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<V5S<VEO;B!D
M871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96%D*"1I9"D*("`@('L*("`@
M("`@("!I9B`H)&1A=&$@/2!D8FUF971C:"@D=&AI<RT^7V1B;2P@)&ED*2D@
M>PH@("`@("`@("`@("!R971U<FX@8F%S938T7V1E8V]D92AS=6)S='(H)&1A
M=&$L('-T<G!O<R@D9&%T82P@)WPG*2`K(#$I*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@5W)I=&4@<V5S<VEO;B!D871A('1O('1H92!397-S:6]N
M2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&ED("`@("`@("`@("`@5&AE('-E<W-I;VX@:61E;G1I9FEE<BX*("`@("`J
M($!P87)A;2!S=')I;F<@)'-E<W-I;VY?9&%T82`@5&AE('-E<W-I;VX@9&%T
M82X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C
M8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!W
M<FET92@D:60L("1S97-S:6]N7V1A=&$I"B`@("!["B`@("`@("`@<F5T=7)N
M($!D8FUR97!L86-E*"1T:&ES+3Y?9&)M+"`D:60L('1I;64H*2`N("=\)R`N
M(&)A<V4V-%]E;F-O9&4H)'-E<W-I;VY?9&%T82DI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1&5S=')O>2!T:&4@9&%T82!F;W(@82!P87)T:6-U;&%R('-E
M<W-I;VX@:61E;G1I9FEE<B!I;B!T:&4*("`@("`J(%-E<W-I;VY(86YD;&5R
M(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@(%1H
M92!S97-S:6]N(&ED96YT:69I97(N"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]T:&5R=VES92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9&5S=')O>2@D:60I"B`@("!["B`@("`@("`@
M:68@*"$H0&1B;61E;&5T92@D=&AI<RT^7V1B;2P@)&ED*2DI('L*("`@("`@
M("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T9A:6QE9"!T;R!D96QE=&4@<V5S
M<VEO;B`H:60@/2`G("X@)&ED("X@)RDG+"!?7T9)3$5?7RP@7U],24Y%7U\L
M(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1V%R8F%G92!C;VQL96-T('-T86QE('-E<W-I;VYS(&9R;VT@=&AE
M(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)&UA>&QI9F5T:6UE("!4:&4@;6%X:6UU;2!A9V4@;V8@82!S
M97-S:6]N+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O
M;B!S=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=C*"1M87AL:69E=&EM92`](#,P,"D*("`@('L*("`@("`@("`D97AP
M:7)E9"`]('1I;64H*2`M("1M87AL:69E=&EM93L*("`@("`@("`D:60@/2!D
M8FUF:7)S=&ME>2@D=&AI<RT^7V1B;2D["@H@("`@("`@('=H:6QE("@D:60I
M('L*("`@("`@("`@("`@:68@*"1D871A(#T@9&)M9F5T8V@H)'1H:7,M/E]D
M8FTL("1I9"DI('L*("`@("`@("`@("`@("`@("1A9V4@/2!S=6)S='(H)'1M
M<"P@,"P@<W1R<&]S*"1D871A+"`G?"<I*3L*("`@("`@("`@("`@("`@(&EF
M("@D97AP:7)E9"`^("1A9V4I('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^9&5S=')O>2@D:60I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`D:60@/2!D8FUN97AT:V5Y*"1T:&ES+3Y?9&)M
M+"`D:60I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92].;W1I9FEC871I;VX`````````````````````````````````````
M```````````````````````````````````P,#`W-34@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<S-B`P,C$W,C``(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<@``
M`````````````````````````````````````````````````````````#`P
M,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S,V
M(#`R,S4P-0`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'``````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#4T-#4@,3`U,34T,S,W,S8@,#(U-34T`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO
M<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP)SL*"B\J*@H@
M*B!4:&4@3F]T:69I8V%T:6]N7TQI<W1E;F5R7VUO8FEL93HZ(&-L87-S('!R
M;W9I9&5S(&9U;F-T:6]N86QI='D@9F]R"B`J(&1I<W!L87EI;F<@;65S<V%G
M97,@9G)O;2!T:&4@;65S<V%G92!S=&%C:R!O;B!M;V)I;&4@9&5V:6-E<RX*
M("H*("H@)$AO<F1E.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP+'8@,2XX+C$P+C@@,C`P-B\P,2\P
M,2`R,3HR.#HS,"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P
M-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R
M9&5?3F]T:69I8V%T:6]N"B`J+PIC;&%S<R!.;W1I9FEC871I;VY?3&ES=&5N
M97)?;6]B:6QE(&5X=&5N9',@3F]T:69I8V%T:6]N7TQI<W1E;F5R7W-T871U
M<R!["@H@("`@+RHJ"B`@("`@*B!4:&4@2&]R9&5?36]B:6QE.CH@;V)J96-T
M('1H870@<W1A='5S(&QI;F5S('-H;W5L9"!B92!A9&1E9"!T;RX*("`@("`J
M"B`@("`@*B!`=F%R($AO<F1E7TUO8FEL90H@("`@("HO"B`@("!V87(@)%]M
M;V)I;&4@/2!N=6QL.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*("`@
M("`J+PH@("`@9G5N8W1I;VX@3F]T:69I8V%T:6]N7TQI<W1E;F5R7VUO8FEL
M92@I"B`@("!["B`@("`@("`@)'1H:7,M/E]H86YD;&5S(#T@87)R87DH)VAO
M<F1E+F5R<F]R)R`@(#T^(%\H(D524B(I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=H;W)D92YS=6-C97-S)R`]/B!?*")354-#15-3(BDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAO<F1E+G=A<FYI
M;F<G(#T^(%\H(E=!4DXB*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G:&]R9&4N;65S<V%G92<@/3X@7R@B35-'(BDI.PH@("`@?0H*("`@
M("\J*@H@("`@("H@07-S;V-I871E(&$@2&]R9&5?36]B:6QE.CH@;V)J96-T
M('=I=&@@=&AE(&QI<W1E;F5R+@H@("`@("H*("`@("`J($!P87)A;2!(;W)D
M95]-;V)I;&4@(%1H92!(;W)D95]-;V)I;&4Z.B!O8FIE8W0@=&\@<V5N9"!S
M=&%T=7,@;&EN97,@=&\N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$UO8FEL
M94]B:F5C="@F)&UO8FEL92D*("`@('L*("`@("`@("`D=&AI<RT^7VUO8FEL
M92`]("8D;6]B:6QE.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&$@
M=6YI<75E(&ED96YT:69I97(@9F]R('1H:7,@;&ES=&5N97(N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%5N:7%U92!I9"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T3F%M92@I"B`@("!["B`@("`@("`@<F5T=7)N("=M;V)I
M;&4G.PH@("`@?0H*("`@("\J*@H@("`@("H@3W5T<'5T<R!T:&4@<W1A='5S
M(&QI;F4@:68@=&AE<F4@87)E(&%N>2!M97-S86=E<R!O;B!T:&4@)VUO8FEL
M92<*("`@("`J(&UE<W-A9V4@<W1A8VLN"B`@("`@*@H@("`@("H@0'!A<F%M
M(&%R<F%Y("8D;65S<V%G95-T86-K("!4:&4@<W1A8VL@;V8@;65S<V%G97,N
M"B`@("`@*B!`<&%R86T@87)R87D@)&]P=&EO;G,@("`@("`@($%N(&%R<F%Y
M(&]F(&]P=&EO;G,N($]P=&EO;G,Z("=N;W-P86-E)PH@("`@("HO"B`@("!F
M=6YC=&EO;B!N;W1I9GDH)B1M97-S86=E4W1A8VLL("1O<'1I;VYS(#T@87)R
M87DH*2D*("`@('L*("`@("`@("!I9B`H(21T:&ES+3Y?;6]B:6QE*2!["B`@
M("`@("`@("`@('!A<F5N=#HZ3F]T:69I8V%T:6]N7TQI<W1E;F5R7W-T871U
M<R@I.PH@("`@("`@("`@("!R971U<FX@<&%R96YT.CIN;W1I9GDH)&UE<W-A
M9V53=&%C:RP@)&]P=&EO;G,I.PH@("`@("`@('T*"B`@("`@("`@:68@*&-O
M=6YT*"1M97-S86=E4W1A8VLI*2!["B`@("`@("`@("`@('=H:6QE("@D;65S
M<V%G92`](&%R<F%Y7W-H:69T*"1M97-S86=E4W1A8VLI*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^9V5T365S<V%G92@D;65S<V%G92D["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)'0@/2`F)'1H:7,M/E]M;V)I;&4M/F%D9"AN
M97<@2&]R9&5?36]B:6QE7W1E>'0H(EQN(BDI.PH@("`@("`@("`@("`D="T^
M<V5T*"=L:6YE8G)E86MS)RP@=')U92D["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@3W5T<'5T<R!O;F4@;65S<V%G92X*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@)&UE<W-A9V4@($]N92!M97-S86=E(&AA<V@@9G)O
M;2!T:&4@<W1A8VLN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$UE<W-A9V4H
M)&UE<W-A9V4I"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^7VUO8FEL92D@
M>PH@("`@("`@("`@("!P87)E;G0Z.DYO=&EF:6-A=&EO;E],:7-T96YE<E]S
M=&%T=7,H*3L*("`@("`@("`@("`@<F5T=7)N('!A<F5N=#HZ9V5T365S<V%G
M92@D;65S<V%G92D["B`@("`@("`@?0H*("`@("`@("`D979E;G0@/2`D=&AI
M<RT^9V5T179E;G0H)&UE<W-A9V4I.PH@("`@("`@("1T:&ES+3Y?;6]B:6QE
M+3YA9&0H;F5W($AO<F1E7TUO8FEL95]T97AT*'-P<FEN=&8H7R@B)7,Z("5S
M(BDL("1T:&ES+3Y?:&%N9&QE<ULD;65S<V%G95LG='EP92==72P@<W1R:7!?
M=&%G<R@D979E;G0M/F=E=$UE<W-A9V4H*2DI*2D["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O
M875D:6\N<&AP```````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S0S-"`Q,#4Q-30S,S<S
M-B`P,C4T,#(`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+G!H<"<["@HO*BH*("H@5&AE($YO=&EF:6-A=&EO;E],:7-T
M96YE<E]A=61I;SHZ(&-L87-S('!R;W9I9&5S(&9U;F-T:6]N86QI='D@9F]R
M"B`J(&EN<V5R=&EN9R!E;6)E9&1E9"!A=61I;R!N;W1I9FEC871I;VYS(&9R
M;VT@=&AE('-T86-K(&EN=&\@=&AE('!A9V4N"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O875D
M:6\N<&AP+'8@,2XS+C(N,B`R,#`V+S`Q+S`Q(#(Q.C(X.C,P(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-2TR,#`V($-R;VYO<WES+"!,3$,@/&AT
M='`Z+R]W=W<N8W)O;F]S>7,N8V]M+SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($IA<V]N($TN($9E;&EC92`\:F9E;&EC94!C<F]N;W-Y<RYC;VT^
M"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95].;W1I
M9FEC871I;VX*("HO"F-L87-S($YO=&EF:6-A=&EO;E],:7-T96YE<E]A=61I
M;R!E>'1E;F1S($YO=&EF:6-A=&EO;E],:7-T96YE<B!["@H@("`@+RHJ"B`@
M("`@*B!#;VYS=')U8W1O<@H@("`@("HO"B`@("!F=6YC=&EO;B!.;W1I9FEC
M871I;VY?3&ES=&5N97)?875D:6\H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M:&%N9&QE<R`](&%R<F%Y*"=A=61I;R<@/3X@)R<I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N(&$@=6YI<75E(&ED96YT:69I97(@9F]R('1H:7,@
M;&ES=&5N97(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%5N:7%U
M92!I9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3F%M92@I"B`@("!["B`@
M("`@("`@<F5T=7)N("=A=61I;R<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!/
M=71P=71S('1H92!E;6)E9&1E9"!A=61I;R!C;V1E(&EF('1H97)E(&%R92!A
M;GD@;65S<V%G97,@;VX@=&AE"B`@("`@*B`G875D:6\G(&UE<W-A9V4@<W1A
M8VLN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("8D;65S<V%G95-T86-K
M("`@("!4:&4@<W1A8VL@;V8@;65S<V%G97,N"B`@("`@*B!`<&%R86T@87)R
M87D@)&]P=&EO;G,@($%N(&%R<F%Y(&]F(&]P=&EO;G,N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&YO=&EF>2@F)&UE<W-A9V53=&%C:RP@)&]P=&EO;G,@/2!A
M<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("AC;W5N="@D;65S<V%G95-T86-K
M*2D@>PH@("`@("`@("`@("!W:&EL92`H)&UE<W-A9V4@/2!A<G)A>5]S:&EF
M="@D;65S<V%G95-T86-K*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/F=E
M=$UE<W-A9V4H)&UE<W-A9V4I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@3W5T<'5T<R!O;F4@;65S<V%G92X*("`@
M("`J"B`@("`@*B!`<&%R86T@87)R87D@)&UE<W-A9V4@($]N92!M97-S86=E
M(&AA<V@@9G)O;2!T:&4@<W1A8VLN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$UE<W-A9V4H)&UE<W-A9V4I"B`@("!["B`@("`@("`@)&5V96YT(#T@)'1H
M:7,M/F=E=$5V96YT*"1M97-S86=E*3L*("`@("`@("!E8VAO("<\96UB960@
M<W)C/2(G+"!H=&UL<W!E8VEA;&-H87)S*"1E=F5N="T^9V5T365S<V%G92@I
M*2P*("`@("`@("`@("`@("<B('=I9'1H/2(P(B!H96EG:'0](C`B(&%U=&]S
M=&%R=#TB=')U92(@+SXG.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VIA=F%S
M8W)I<'0N<&AP````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#0P,30@,3`U,34T,S,W,S8@,#(V
M-#0R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T
M96YE<BYP:'`G.PH*+RHJ"B`J(%1H92!.;W1I9FEC871I;VY?3&ES=&5N97)?
M:F%V87-C<FEP=#HZ(&-L87-S('!R;W9I9&5S(&9U;F-T:6]N86QI='D@9F]R
M"B`J(&EN<V5R=&EN9R!J879A<V-R:7!T(&-O9&4@9G)O;2!T:&4@;65S<V%G
M92!S=&%C:R!I;G1O('1H92!P86=E+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R
M:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VIA=F%S8W)I
M<'0N<&AP+'8@,2XW+C$P+C8@,C`P-B\P,2\P,2`R,3HR.#HS,"!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!*86X@4V-H;F5I9&5R(#QJ
M86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F%N
M(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@
M,RXP"B`J($!P86-K86=E($AO<F1E7TYO=&EF:6-A=&EO;@H@*B\*8VQA<W,@
M3F]T:69I8V%T:6]N7TQI<W1E;F5R7VIA=F%S8W)I<'0@97AT96YD<R!.;W1I
M9FEC871I;VY?3&ES=&5N97(@>PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T
M;W(*("`@("`J+PH@("`@9G5N8W1I;VX@3F]T:69I8V%T:6]N7TQI<W1E;F5R
M7VIA=F%S8W)I<'0H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:&%N9&QE<R`]
M(&%R<F%Y*"=J879A<V-R:7!T)R`]/B`G)RD["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FX@82!U;FEQ=64@:61E;G1I9FEE<B!F;W(@=&AI<R!L:7-T
M96YE<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@56YI<75E(&ED
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971.86UE*"D*("`@('L*("`@("`@
M("!R971U<FX@)VIA=F%S8W)I<'0G.PH@("`@?0H*("`@("\J*@H@("`@("H@
M3W5T<'5T<R!T:&4@:F%V87-C<FEP="!C;V1E(&EF('1H97)E(&%R92!A;GD@
M;65S<V%G97,@;VX@=&AE"B`@("`@*B`G:F%V87-C<FEP="<@;65S<V%G92!S
M=&%C:R!A;F0@:68@=&AE("=N;W1I9GE?:F%V87-C<FEP="<@;W!T:6]N(&ES
M('-E="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)B1M97-S86=E4W1A
M8VL@("`@(%1H92!S=&%C:R!O9B!M97-S86=E<RX*("`@("`J($!P87)A;2!A
M<G)A>2`D;W!T:6]N<R`@06X@87)R87D@;V8@;W!T:6]N<RX@3W!T:6]N<SH@
M)VYO<V-R:7!T)PH@("`@("HO"B`@("!F=6YC=&EO;B!N;W1I9GDH)B1M97-S
M86=E4W1A8VLL("1O<'1I;VYS(#T@87)R87DH*2D*("`@('L*("`@("`@("!I
M9B`H8V]U;G0H)&UE<W-A9V53=&%C:RDI('L*("`@("`@("`@("`@:68@*&5M
M<'1Y*"1O<'1I;VYS6R=N;W-C<FEP="==*2D@>PH@("`@("`@("`@("`@("`@
M96-H;R`G/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/B<["B`@("`@
M("`@("`@("`@("!E8VAO(")<;CPA+2U<;B(["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@=VAI;&4@*"1M97-S86=E(#T@87)R87E?<VAI9G0H)&UE<W-A
M9V53=&%C:RDI('L*("`@("`@("`@("`@("`@("1T:&ES+3YG971-97-S86=E
M*"1M97-S86=E*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H96UP
M='DH)&]P=&EO;G-;)VYO<V-R:7!T)UTI*2!["B`@("`@("`@("`@("`@("!E
M8VAO("(O+RTM/EQN/"]S8W)I<'0^7&XB.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@3W5T<'5T<R!O;F4@;65S<V%G
M92X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&UE<W-A9V4@($]N92!M
M97-S86=E(&AA<V@@9G)O;2!T:&4@<W1A8VLN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$UE<W-A9V4H)&UE<W-A9V4I"B`@("!["B`@("`@("`@)&5V96YT
M(#T@)'1H:7,M/F=E=$5V96YT*"1M97-S86=E*3L*("`@("`@("!E8VAO("1E
M=F5N="T^9V5T365S<V%G92@I("X@(EQN(CL*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+W-T871U<RYP:'``````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#0U-S`@,3`U
M,34T,S,W,S8@,#(U-C(V`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+TYO=&EF
M:6-A=&EO;B],:7-T96YE<BYP:'`G.PH*+RHJ"B`J(%1H92!.;W1I9FEC871I
M;VY?3&ES=&5N97)?<W1A='5S.CH@8VQA<W,@<')O=FED97,@9G5N8W1I;VYA
M;&ET>2!F;W(*("H@9&ES<&QA>6EN9R!M97-S86=E<R!F<F]M('1H92!M97-S
M86=E('-T86-K(&%S(&$@<W1A='5S(&QI;F4N"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A
M='5S+G!H<"QV(#$N,CDN,BXU(#(P,#8O,#$O,#$@,C$Z,C@Z,S`@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`Q+3(P,#8@2F%N(%-C:&YE:61E<B`\
M:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA
M;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E
M(#(N,0H@*B!`<&%C:V%G92!(;W)D95].;W1I9FEC871I;VX*("HO"F-L87-S
M($YO=&EF:6-A=&EO;E],:7-T96YE<E]S=&%T=7,@97AT96YD<R!.;W1I9FEC
M871I;VY?3&ES=&5N97(@>PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*
M("`@("`J+PH@("`@9G5N8W1I;VX@3F]T:69I8V%T:6]N7TQI<W1E;F5R7W-T
M871U<R@I"B`@("!["B`@("`@("`@)'1H:7,M/E]H86YD;&5S(#T@87)R87DH
M)VAO<F1E+F5R<F]R)R`@(#T^(&%R<F%Y*"=A;&5R=',O97)R;W(N<&YG)RP@
M7R@B17)R;W(B*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)VAO<F1E+G-U8V-E<W,G(#T^(&%R<F%Y*"=A;&5R=',O<W5C8V5S<RYP;F<G
M+"!?*")3=6-C97-S(BDI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=H;W)D92YW87)N:6YG)R`]/B!A<G)A>2@G86QE<G1S+W=A<FYI;F<N
M<&YG)RP@7R@B5V%R;FEN9R(I*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G:&]R9&4N;65S<V%G92<@/3X@87)R87DH)V%L97)T<R]M97-S
M86=E+G!N9R<L(%\H(DUE<W-A9V4B*2DI.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N(&$@=6YI<75E(&ED96YT:69I97(@9F]R('1H:7,@;&ES=&5N
M97(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%5N:7%U92!I9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3F%M92@I"B`@("!["B`@("`@("`@
M<F5T=7)N("=S=&%T=7,G.PH@("`@?0H*("`@("\J*@H@("`@("H@3W5T<'5T
M<R!T:&4@<W1A='5S(&QI;F4@:68@=&AE<F4@87)E(&%N>2!M97-S86=E<R!O
M;B!T:&4@)W-T871U<R<*("`@("`J(&UE<W-A9V4@<W1A8VLN"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("8D;65S<V%G95-T86-K("!4:&4@<W1A8VL@
M;V8@;65S<V%G97,N"B`@("`@*B!`<&%R86T@87)R87D@)&]P=&EO;G,@("`@
M("`@($%N(&%R<F%Y(&]F(&]P=&EO;G,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&YO=&EF>2@F)&UE<W-A9V53=&%C:RP@)&]P=&EO;G,@/2!A<G)A>2@I*0H@
M("`@>PH@("`@("`@(&EF("AC;W5N="@D;65S<V%G95-T86-K*2D@>PH@("`@
M("`@("`@("!W:&EL92`H)&UE<W-A9V4@/2!A<G)A>5]S:&EF="@D;65S<V%G
M95-T86-K*2D@>PH@("`@("`@("`@("`@("`@96-H;R`D=&AI<RT^9V5T365S
M<V%G92@D;65S<V%G92D["B`@("`@("`@("`@('T*("`@("`@("`@("`@96-H
M;R`G/&)R(&-L87-S/2)S<&%C97(B("\^)SL*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!/=71P=71S(&]N92!M97-S86=E+@H@("`@("H*("`@
M("`J($!P87)A;2!A<G)A>2`D;65S<V%G92`@3VYE(&UE<W-A9V4@:&%S:"!F
M<F]M('1H92!S=&%C:RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T365S<V%G
M92@D;65S<V%G92D*("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*
M("`@("`@("`D979E;G0@/2`D=&AI<RT^9V5T179E;G0H)&UE<W-A9V4I.PH@
M("`@("`@("1T97AT(#T@)&5V96YT+3YG971-97-S86=E*"D["@H@("`@("`@
M(&EF("@A:6Y?87)R87DH)V-O;G1E;G0N<F%W)RP@)'1H:7,M/F=E=$9L86=S
M*"1M97-S86=E*2DI('L*("`@("`@("`@("`@)'1E>'0@/2!H=&UL<W!E8VEA
M;&-H87)S*"1T97AT*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`G/'`@
M8VQA<W,](FYO=&EC92(^)R`N($AO<F1E.CII;6<H)'1H:7,M/E]H86YD;&5S
M6R1M97-S86=E6R=T>7!E)UU=6S!=+"`D=&AI<RT^7VAA;F1L97-;)&UE<W-A
M9V5;)W1Y<&4G75U;,5TL("<G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H
M;W)D92<I*2`N("<F;F)S<#LF;F)S<#LG("X@)'1E>'0@+B`G/"]P/B<["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O3F]T
M:69I8V%T:6]N+T5V96YT+G!H<```````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#(U,C0@,3`U,34T,S,W,S8@,#(S-3<T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@3F]T
M:69I8V%T:6]N7T5V96YT.CH@8VQA<W,@<')O=FED97,@82!C;VYT86EN97(@
M9F]R('!A<W-I;F<*("H@;65S<V%G97,@=&\@3F]T:69I8V%T:6]N7TQI<W1E
M;F5R(&-L87-S97,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO179E;G0N<&AP+'8@,2XU+C(N-2`R,#`V+S`Q
M+S`Q(#(Q.C(X.C(Y(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR
M,#`V($AA;G,@3&5L;&5L:60@/&AA;G-`=F5L=6TN;F5T/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("H*("H@0&%U=&AO<B`@2&%N<R!,96QL96QI9"`\:&%N<T!V96QU;2YN
M970^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95].
M;W1I9FEC871I;VX*("HO"F-L87-S($YO=&EF:6-A=&EO;E]%=F5N="!["@H@
M("`@+RHJ"B`@("`@*B!4:&4@;65S<V%G92!B96EN9R!P87-S960N"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@('9A<B`D7VUE<W-A9V4@/2`G)SL*"B`@("`O*BH*("`@("`J($EF('!A
M<W-E9"P@<V5T<R!T:&4@;65S<V%G92!F;W(@=&AI<R!E=F5N="X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1M97-S86=E("!4:&4@=&5X="!M97-S
M86=E(&9O<B!T:&ES(&5V96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!.;W1I
M9FEC871I;VY?179E;G0H)&UE<W-A9V4@/2!N=6QL*0H@("`@>PH@("`@("`@
M(&EF("@A:7-?;G5L;"@D;65S<V%G92DI('L*("`@("`@("`@("`@)'1H:7,M
M/G-E=$UE<W-A9V4H)&UE<W-A9V4I.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E=',@=&AE('1E>'0@;65S<V%G92!F;W(@=&AI<R!E=F5N
M="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1M97-S86=E("!4:&4@
M=&5X="!M97-S86=E('1O(&1I<W!L87DN"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-E=$UE<W-A9V4H)&UE<W-A9V4I"B`@("!["B`@("`@("`@)'1H:7,M/E]M
M97-S86=E(#T@)&UE<W-A9V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'971S
M('1H92!T97AT(&UE<W-A9V4@9F]R('1H:7,@979E;G0N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!T97AT(&UE<W-A9V4@=&\@9&ES<&QA
M>2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T365S<V%G92@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?;65S<V%G93L*("`@('T*"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(N<&AP
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-S8R,R`Q,#4Q-30S,S<S-B`P
M,C0S,#4`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J(%1H92!.;W1I9FEC871I;VY?3&ES=&5N97(Z.B!C
M;&%S<R!P<F]V:61E<R!F=6YC=&EO;F%L:71Y(&9O<B!D:7-P;&%Y:6YG"B`J
M(&UE<W-A9V5S(&9R;VT@=&AE(&UE<W-A9V4@<W1A8VL@87,@82!S=&%T=7,@
M;&EN92X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO
M=&EF:6-A=&EO;B],:7-T96YE<BYP:'`L=B`Q+C$V+C(N-R`R,#`V+S`Q+S`Q
M(#(Q.C(X.C(Y(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,2TR,#`V
M($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D
M92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#(N,0H@*B!`<&%C:V%G92!(;W)D
M95].;W1I9FEC871I;VX*("HO"F-L87-S($YO=&EF:6-A=&EO;E],:7-T96YE
M<B!["@H@("`@+RHJ"B`@("`@*B!!<G)A>2!O9B!M97-S86=E('1Y<&5S('1H
M870@=&AI<R!L:7-T96YE<B!H86YD;&5S+@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1?:&%N9&QE<R`](&%R<F%Y*"D["@H@
M("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("HO"B`@("!F=6YC=&EO
M;B!.;W1I9FEC871I;VY?3&ES=&5N97(H*0H@("`@>PH@("`@?0H*("`@("\J
M*@H@("`@("H@1&]E<R!T:&ES(&QI<W1E;F5R(&AA;F1L92!A(&-E<G1A:6X@
M='EP92!O9B!M97-S86=E/PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'1Y<&4@(%1H92!M97-S86=E('1Y<&4@:6X@<75E<W1I;VXN"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R('1H:7,@;&ES=&5N97(@
M:&%N9&QE<R!T:&4@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@:&%N9&QE
M<R@D='EP92D*("`@('L*("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/E]H
M86YD;&5S6R1T>7!E72D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@
M82!U;FEQ=64@:61E;G1I9FEE<B!F;W(@=&AI<R!L:7-T96YE<BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@56YI<75E(&ED+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971.86UE*"D*("`@('L*("`@("`@("!R971U<FX@9V5T
M7V-L87-S*"1T:&ES*3L*("`@('T*"B`@("`O*BH*("`@("`J($]U='!U=',@
M=&AE('-T871U<R!L:6YE+"!S96YD<R!E;6%I;',L('!A9V5S+"!E=&,N+"!I
M9B!T:&5R90H@("`@("H@87)E(&%N>2!M97-S86=E<R!O;B!T:&ES(&QI<W1E
M;F5R)W,@;65S<V%G92!S=&%C:RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)B1M97-S86=E4W1A8VL@(%1H92!S=&%C:R!O9B!M97-S86=E<RX*("`@
M("`J($!P87)A;2!A<G)A>2`D;W!T:6]N<R`@("`@("`@06X@87)R87D@;V8@
M;W!T:6]N<RX*("`@("`J+PH@("`@9G5N8W1I;VX@;F]T:69Y*"8D;65S<V%G
M95-T86-K<RP@)&]P=&EO;G,@/2!A<G)A>2@I*0H@("`@>PH@("`@?0H*("`@
M("\J*@H@("`@("H@4')O8V5S<V5S(&]N92!M97-S86=E(&9R;VT@=&AE(&UE
M<W-A9V4@<W1A8VLN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1M97-S
M86=E("!/;F4@;65S<V%G92!H87-H(&9R;VT@=&AE('-T86-K+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971-97-S86=E*"1M97-S86=E*0H@("`@>PH@("`@
M?0H*("`@("\J*@H@("`@("H@56YS97)I86QI>F4@86X@979E;G0@9G)O;2!T
M:&4@;65S<V%G92!S=&%C:RP@8VAE8VMI;F<@=&\@<V5E(&EF('1H90H@("`@
M("H@87!P<F]P<FEA=&4@8VQA<W,@97AI<W1S(&%N9"!K;'5D9VEN9R!I="!I
M;G1O(&$@8F%S92!.;W1I9FEC871I;VY?179E;G0*("`@("`J(&]B:F5C="!I
M9B!N;W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$5V96YT*"1M97-S86=E
M*0H@("`@>PH@("`@("`@("1O8B`](&9A;'-E.PH@("`@("`@(&EF("AC;&%S
M<U]E>&ES=',H)&UE<W-A9V5;)V-L87-S)UTI*2!["B`@("`@("`@("`@("1O
M8B`]($!U;G-E<FEA;&EZ92@D;65S<V%G95LG979E;G0G72D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&
M24Q%7U\I("X@)R]%=F5N="YP:'`G.PH@("`@("`@("`@("`D;V(@/2!`=6YS
M97)I86QI>F4H)&UE<W-A9V5;)V5V96YT)UTI.PH@("`@("`@("`@("!I9B`H
M(6UE=&AO9%]E>&ES=',H)&]B+"`G9V5T365S<V%G92<I*2!["B`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&]B+3Y?;65S<V%G92DI('L*("`@("`@("`@
M("`@("`@("`@("`D;V(@/2`F;F5W($YO=&EF:6-A=&EO;E]%=F5N="@D;V(M
M/E]M97-S86=E*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@+RH@268@=V4G=F4@9F%I;&5D('1O(&-R96%T
M92!A('9A;&ED($YO=&EF:6-A=&EO;E]%=F5N="!O8FIE8W0*("`@("`@("`@
M*B`H;W(@<W5B8VQA<W,@;V)J96-T*2!S;R!F87(L(')E='5R;B!A(%!%05)?
M17)R;W(N("HO"B`@("`@("`@:68@*"%M971H;V1?97AI<W1S*"1O8BP@)V=E
M=$UE<W-A9V4G*2D@>PH@("`@("`@("`@("`D;V(@/2!014%2.CIR86ES945R
M<F]R*"=5;F%B;&4@=&\@9&5C;V1E(&UE<W-A9V4@979E;G0Z("<@+B`D;65S
M<V%G95LG979E;G0G72D["B`@("`@("`@?0H*("`@("`@("`O*B!3<&5C:6%L
M;'D@:&%N9&QE(%!%05)?17)R;W(@;V)J96-T<R!A;F0@861D('5S97)I;F9O
M(&EF"B`@("`@("`@("H@:70G<R!T:&5R92X@*B\*("`@("`@("!I9B`H;65T
M:&]D7V5X:7-T<R@D;V(L("=G9715<V5R26YF;R<I*2!["B`@("`@("`@("`@
M("1U<V5R:6YF;R`]("1O8BT^9V5T57-E<DEN9F\H*3L*("`@("`@("`@("`@
M:68@*"1U<V5R:6YF;RD@>PH@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y
M*"1U<V5R:6YF;RDI('L*("`@("`@("`@("`@("`@("`@("`D=7-E<FEN9F\@
M/2!`:6UP;&]D92@G+"`G+"`D=7-E<FEN9F\I.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@)&]B+3Y?;65S<V%G92`]("1O8BT^9V5T365S
M<V%G92@I("X@)R`Z("<@+B`D=7-E<FEN9F\["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D;V(["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!5;G-E<FEA;&EZ92!A;B!A<G)A>2!O9B!E=F5N="!F;&%G<R!F<F]M
M('1H92!M97-S86=E('-T86-K+B`@268@=&AI<PH@("`@("H@979E;G0@:&%S
M(&YO(&9L86=S+"!O<B!T:&4@9FQA9W,@87)R87D@8V]U;&0@;F]T(&)E('5N
M<V5R:6%L:7IE9"P@86X*("`@("`J(&5M<'1Y(&%R<F%Y(&ES(')E='5R;F5D
M+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y(&]F(&9L
M86=S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971&;&%G<R@D;65S<V%G92D*
M("`@('L*("`@("`@("`O*B!)9B!T:&ES(&UE<W-A9V4@9&]E<VXG="!H879E
M(&%N>2!F;&%G<RP@<F5T=7)N(&%N(&5M<'1Y"B`@("`@("`@("H@87)R87DN
M("HO"B`@("`@("`@:68@*&5M<'1Y*"1M97-S86=E6R=F;&%G<R==*2D@>PH@
M("`@("`@("`@("!R971U<FX@87)R87DH*3L*("`@("`@("!]"@H@("`@("`@
M("\J(%5N<V5R:6%L:7IE('1H92!F;&%G<R!A<G)A>2!F<F]M('1H92!M97-S
M86=E+B`J+PH@("`@("`@("1F;&%G<R`]($!U;G-E<FEA;&EZ92@D;65S<V%G
M95LG9FQA9W,G72D["@H@("`@("`@("\J($EF('=E(&-O=6QD;B=T('5N<V5R
M:6%L:7IE('1H92!F;&%G<R!A<G)A>2P@<F5T=7)N(&%N(&5M<'1Y"B`@("`@
M("`@("H@87)R87DN("HO"B`@("`@("`@:68@*"%I<U]A<G)A>2@D9FQA9W,I
M*2!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1F;&%G<SL*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92])34%0````
M````````````````````````````````````````````````````````````
M```````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,#`P,"`Q,#4Q-30S,S<S-B`P,C`P,C``(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+TAO<F1E+TE-05`O04-,````````````````````````````````````
M`````````````````````````````````````````#`P,#<U-2``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S,V(#`R,#0Q-P`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP
M:'``````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#0R,38@,3`U,34T
M,S,W,S8@,#(R,S`P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP)SL*"B\J*@H@*B!#;VYT86EN<R!F=6YC=&EO;G,@<F5L
M871E9"!T;R!M86YA9VEN9R!!8V-E<W,@0V]N=')O;"!,:7-T<R!O;B!A;B!)
M34%0"B`J('-E<G9E<B!U<VEN9R!21D,@-#,Q-"X*("H*("H@4F5Q=6ER960@
M<&%R86UE=&5R<SH\<')E/@H@*B`@("=U<V5R;F%M92<@(%1H92!U<V5R;F%M
M92!F;W(@=&AE('-E<G9E<B!C;VYN96-T:6]N"B`J("`@)W!A<W-W;W)D)R`@
M5&AE('!A<W-W;W)D(&9O<B!T:&4@<V5R=F5R(&-O;FYE8W1I;VX*("H@("`G
M:&]S='-P96,G("!4:&4@:&]S=&YA;64@;W(@25`@861D<F5S<R!O9B!T:&4@
M<V5R=F5R+@H@*B`@("`@("`@("`@("`@($1%1D%53%0Z("=L;V-A;&AO<W0G
M"B`J("`@)W!O<G0G("`@("`@5&AE('-E<G9E<B!P;W)T('1O('=H:6-H('=E
M('=I;&P@8V]N;F5C="X*("H@("`@("`@("`@("`@("!)34%0(&ES(&=E;F5R
M86QL>2`Q-#,L('=H:6QE($E-05`M4U-,(&ES(&=E;F5R86QL>2`Y.3,N"B`J
M("`@("`@("`@("`@("`@1$5&055,5#H@,30S"B`J("`@)W!R;W1O8V]L)R`@
M5&AE(&-O;FYE8W1I;VX@<')O=&]C;VP@*&4N9RX@)VEM87`G+"`G<&]P,R<L
M("=N;G1P)RDN"B`J("`@("`@("`@("`@("`@4')O=&]C;VP@:7,@;VYE(&]F
M("=I;6%P+VYO=&QS)R`H;W(@;VYL>2`G:6UA<"<@:68@>6]U"B`J("`@("`@
M("`@("`@("`@:&%V92!A(&,M8VQI96YT('9E<G-I;VX@,C`P,&,@;W(@;VQD
M97(I+"`G:6UA<"]S<VPG+"!O<@H@*B`@("`@("`@("`@("`@("=I;6%P+W-S
M;"]N;W9A;&ED871E+6-E<G0G("AF;W(@82!S96QF+7-I9VYE9"!C97)T:69I
M8V%T92DN"B`J("`@("`@("`@("`@("`@1$5&055,5#H@)VEM87`G/"]P<F4^
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q
M-"YP:'`L=B`Q+C(N,BXQ(#(P,#8O,#(O,#8@,C,Z,C$Z,3D@<V5L<VMY($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`V($UA='0@4V5L<VMY(#QS96QS:WE`
M8V]L=6UB:6$N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D
M:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36%T
M="!396QS:WD@/'-E;'-K>4!C;VQU;6)I82YE9'4^"B`J($!S:6YC92`@($AO
M<F1E(#,N,0H@*B!`<&%C:V%G92!(;W)D95])34%0"B`J+PIC;&%S<R!)34%0
M7T%#3%]R9F,T,S$T(&5X=&5N9',@24U!4%]!0TQ?<F9C,C`X-B!["@H@("`@
M+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@)'!A<F%M<R`@06YY(&%D9&ET:6]N86P@<&%R86UE=&5R<R!T:&ES
M(&1R:79E<B!M87D@;F5E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@24U!4%]!
M0TQ?<F9C-#,Q-"@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!P
M87)E;G0Z.DE-05!?04-,7W)F8S(P.#8H)'!A<F%M<RD["@H@("`@("`@("1T
M:&ES+3Y?<FEG:'1S3&ES="`](&%R<F%Y*`H@("`@("`@("`@("`@)VPG(#T^
M(%\H(DQI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(I+`H@("`@("`@
M("`@("`@)W(G(#T^(%\H(E)E860@;65S<V%G97,B*2P*("`@("`@("`@("`@
M("=S)R`]/B!?*")-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B*2P*("`@
M("`@("`@("`@("=W)R`]/B!?*")-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N
M9RX@26UP;W)T86YT+T%N<W=E<F5D*2(I+`H@("`@("`@("`@("`@)VDG(#T^
M(%\H(DEN<V5R="!M97-S86=E<R(I+`H@("`@("`@("`@("`@)W`G(#T^(%\H
M(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(I
M+`H@("`@("`@("`@("`@)VLG(#T^(%\H(D-R96%T92!S=6(@9F]L9&5R<R(I
M+`H@("`@("`@("`@("`@)W@G(#T^(%\H(D1E;&5T92!S=6(@9F]L9&5R<R(I
M+`H@("`@("`@("`@("`@)W0G(#T^(%\H(D1E;&5T92!M97-S86=E<R(I+`H@
M("`@("`@("`@("`@)V4G(#T^(%\H(E!U<F=E(&UE<W-A9V5S(BDL"B`@("`@
M("`@("`@("`G82<@/3X@7R@B061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N
M<R!F;W(@;W1H97(@=7-E<G,B*0H@("`@("`@("D["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'``````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M-#(T-C<@,3`U,34T,S,W,S8@,#(R,S$V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B!#;VYT86EN<R!F
M=6YC=&EO;G,@<F5L871E9"!T;R!M86YA9VEN9R!!8V-E<W,@0V]N=')O;"!,
M:7-T<R!O;B!A;B!)34%0"B`J('-E<G9E<B!U<VEN9R!21D,@,C`X-BX*("H*
M("H@4F5Q=6ER960@<&%R86UE=&5R<SH\<')E/@H@*B`@("=U<V5R;F%M92<@
M(%1H92!U<V5R;F%M92!F;W(@=&AE('-E<G9E<B!C;VYN96-T:6]N"B`J("`@
M)W!A<W-W;W)D)R`@5&AE('!A<W-W;W)D(&9O<B!T:&4@<V5R=F5R(&-O;FYE
M8W1I;VX*("H@("`G:&]S='-P96,G("!4:&4@:&]S=&YA;64@;W(@25`@861D
M<F5S<R!O9B!T:&4@<V5R=F5R+@H@*B`@("`@("`@("`@("`@($1%1D%53%0Z
M("=L;V-A;&AO<W0G"B`J("`@)W!O<G0G("`@("`@5&AE('-E<G9E<B!P;W)T
M('1O('=H:6-H('=E('=I;&P@8V]N;F5C="X*("H@("`@("`@("`@("`@("!)
M34%0(&ES(&=E;F5R86QL>2`Q-#,L('=H:6QE($E-05`M4U-,(&ES(&=E;F5R
M86QL>2`Y.3,N"B`J("`@("`@("`@("`@("`@1$5&055,5#H@,30S"B`J("`@
M)W!R;W1O8V]L)R`@5&AE(&-O;FYE8W1I;VX@<')O=&]C;VP@*&4N9RX@)VEM
M87`G+"`G<&]P,R<L("=N;G1P)RDN"B`J("`@("`@("`@("`@("`@4')O=&]C
M;VP@:7,@;VYE(&]F("=I;6%P+VYO=&QS)R`H;W(@;VYL>2`G:6UA<"<@:68@
M>6]U"B`J("`@("`@("`@("`@("`@:&%V92!A(&,M8VQI96YT('9E<G-I;VX@
M,C`P,&,@;W(@;VQD97(I+"`G:6UA<"]S<VPG+"!O<@H@*B`@("`@("`@("`@
M("`@("=I;6%P+W-S;"]N;W9A;&ED871E+6-E<G0G("AF;W(@82!S96QF+7-I
M9VYE9"!C97)T:69I8V%T92DN"B`J("`@("`@("`@("`@("`@1$5&055,5#H@
M)VEM87`G/"]P<F4^"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`L=B`Q+C8N."XQ,B`R,#`V+S`W+S(V(#$Y.C,T
M.C0U(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@0VAR
M:7,@2&%S=&EE(#QI;7!`;V%K+7=O;V0N8V\N=6L^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U(&1I9`H@*B!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B!`875T:&]R("!#:')I<R!(87-T:64@/&EM<$!O86LM=V]O9"YC;RYU
M:SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TE-
M05`*("HO"F-L87-S($E-05!?04-,7W)F8S(P.#8@97AT96YD<R!)34%07T%#
M3"!["@H@("`@+RHJ"B`@("`@*B!)34%0(')E<V]U<F-E+@H@("`@("H*("`@
M("`J($!V87(@<F5S;W5R8V4*("`@("`J+PH@("`@=F%R("1?:6UA<#L*"B`@
M("`O*BH*("`@("`J($QI<W0@;V8@<V5R=F5R)W,@8V%P86)I;&ET:65S+"!O
M=71P=70@;V8@0T%004))3$E462!C;VUM86YD+B!&;W)M871E9`H@("`@("H@
M87,@82!H87-H"B`@("`@*B`\8V]D93X*("`@("`J(&%R<F%Y*`H@("`@("H@
M("`@("IC87!A8FEL:71Y*B`]/B`Q"B`@("`@*B`I"B`@("`@*B`\+V-O9&4^
M"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]C
M87!S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!;GD@861D:71I
M;VYA;"!P87)A;65T97)S('1H:7,@9')I=F5R(&UA>2!N965D+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!)34%07T%#3%]R9F,R,#@V*"1P87)A;7,@/2!A<G)A
M>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<&%R86US(#T@87)R87E?;65R
M9V4H87)R87DH)VAO<W1S<&5C)R`]/B`G;&]C86QH;W-T)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P;W)T)R`]/B`Q
M-#,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G<')O=&]C;VPG(#T^("=I;6%P)RDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<&%R86US*3L*"B`@("`@("`@)'1H:7,M/E]C
M87!S(#T@)'1H:7,M/E]G971#87!A8FEL:71Y*"D["B`@("`@("`@:68@*&ES
M7V$H)'1H:7,M/E]C87!S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?97)R;W(@/2`D=&AI<RT^7V-A<',["B`@("`@("`@("`@(')E
M='5R;CL*("`@("`@("!]"@H@("`@("`@(&EF("AS=6)S='(H)'1H:7,M/E]P
M87)A;7-;)W!R;W1O8V]L)UTL(#`L(#0I("$]("=I;6%P)RD@>PH@("`@("`@
M("`@("`O*B!.;R!P;VEN="!I;B!G;VEN9R!A;GD@9G5R=&AE<B!I9B!I="=S
M(&YO="!A;B!)34%0('-E<G9E<BX@*B\*("`@("`@("`@("`@)'1H:7,M/E]E
M<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H7R@B3VYL>2!)34%0('-E<G9E<G,@
M<W5P<&]R="!S:&%R960@9F]L9&5R<RXB*2D["B`@("`@("`@("`@("1T:&ES
M+3Y?<W5P<&]R=&5D(#T@9F%L<V4["B`@("`@("`@?2!E;'-E:68@*"%I<W-E
M="@D=&AI<RT^7V-A<'-;)V%C;"==*2D@>PH@("`@("`@("`@("`O*B!)9B!W
M92!C;W5L9&XG="!G970@=&AE('-E<G9E<B=S(&-A<&%B:6QI='DL('=E)VQL
M(&%S<W5M92!!0TP@:7,*("`@("`@("`@("`@("`@;F]T('-U<'!O<G1E9"!F
M;W(@;F]W+B`J+PH@("`@("`@("`@("`D=&AI<RT^7W-U<'!O<G1E9"`](&9A
M;'-E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?<W5P
M<&]R=&5D(#T@=')U93L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?<')O
M=&5C=&5D(#T@87)R87DH)'1H:7,M/E]P87)A;7-;)W5S97)N86UE)UTI.PH*
M("`@("`@("`D=&AI<RT^7W)I9VAT<TQI<W0@/2!A<G)A>2@*("`@("`@("`@
M("`@("=L)R`]/B!?*"),:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B
M*2P*("`@("`@("`@("`@("=R)R`]/B!?*")296%D(&UE<W-A9V5S(BDL"B`@
M("`@("`@("`@("`G<R<@/3X@7R@B36%R:R!W:71H(%-E96XO56YS965N(&9L
M86=S(BDL"B`@("`@("`@("`@("`G=R<@/3X@7R@B36%R:R!W:71H(&]T:&5R
M(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"DB*2P*("`@("`@("`@
M("`@("=I)R`]/B!?*"));G-E<G0@;65S<V%G97,B*2P*("`@("`@("`@("`@
M("=P)R`]/B!?*")0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@
M8GD@24U!4"DB*2P*("`@("`@("`@("`@("=C)R`]/B!?*")#<F5A=&4@<W5B
M(&9O;&1E<G,B*2P*("`@("`@("`@("`@("=D)R`]/B!?*")$96QE=&4@86YD
M('!U<F=E(&UE<W-A9V5S(BDL"B`@("`@("`@("`@("`G82<@/3X@7R@B061M
M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B*0H@
M("`@("`@("D["B`@("!]"@H@("`@9G5N8W1I;VX@7V-O;FYE8W0H*0H@("`@
M>PH@("`@("`@(&EF("@A)'1H:7,M/E]I;6%P*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?:6UA<"`]($!I;6%P7V]P96XH<W!R:6YT9B@G>R5S.B5D+R5S?2<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=P;W)T)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<')O=&]C;VPG72DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)W5S97)N86UE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UTL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@3U!?2$%,1D]014XI.PH@
M("`@("`@("`@("!I9B`H(21T:&ES+3Y?:6UA<"D@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]I;6%P(#T@4$5!4CHZ<F%I<V5%<G)O<BAI;6%P7VQA<W1?
M97)R;W(H*2D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N("%I<U]A*"1T:&ES+3Y?:6UA<"P@)U!%05)?17)R;W(G*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%-E=',@=&AE($%#3"!O;B!A;B!)34%0('-E<G9E
M<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F;VQD97(@("`@("!4
M:&4@9F]L9&5R(&]N('=H:6-H('1O(&5D:70@=&AE($%#3"X*("`@("`J($!P
M87)A;2!S=')I;F<@)'-H87)E7W5S97(@(%1H92!U<V5R('1O(&=R86YT(')I
M9VAT<R!T;RX*("`@("`J($!P87)A;2!A<G)A>2`D86-L("`@("`@("`@($%N
M(&%R<F%Y+"!T:&4@:V5Y<R!O9B!W:&EC:"!A<F4@=&AE(')I9VAT<R!T;PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8F4@9W)A;G1E9"`H
M<V5E(%)&0R`R,#@V*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4
M<G5E(&]N('-U8V-E<W,L(%!%05)?17)R;W(@;VX@9F%I;'5R92!O<B!I9B!S
M97)V97(*("`@("`J("`@("`@("`@("`@("`@(&1O97-N)W0@<W5P<&]R="!!
M0TQS+@H@("`@("HO"B`@("!F=6YC=&EO;B!C<F5A=&5!0TPH)&9O;&1E<BP@
M)'-H87)E7W5S97(L("1A8VPI"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^
M7V-O;FYE8W0H*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;6%P
M.PH@("`@("`@('T*"B`@("`@("`@)&%C;%]S='(@/2`G)SL*("`@("`@("!I
M9B`H(65M<'1Y*"1A8VPI*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1A8VP@
M87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@("`@("`D86-L7W-T<B`N
M/2`D:V5Y.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!#
M86XG="!C86QL('1H:7,@87,@0&EM87!?<V5T86-L*"D@87,@<W5P<')E<W-I
M;F<@97)R;W)S(&QE861S('1O"B`@("`@("`@("`@:6UA<%]E<G)O<G,H*2!R
M971U<FYI;F<@;F]T:&EN9RX@*B\*("`@("`@("`D<F5S=6QT(#T@:6UA<%]S
M971A8VPH)'1H:7,M/E]I;6%P+"`D9F]L9&5R+"`D<VAA<F5?=7-E<BP@)&%C
M;%]S='(I.PH*("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@
M)&5R<F]R<R`](&EM87!?97)R;W)S*"D["B`@("`@("`@("`@(&EF("AI<U]A
M<G)A>2@D97)R;W)S*2D@>PH@("`@("`@("`@("`@("`@)&5R<F]R7W-T<FEN
M9R`]("<G.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&5R<F]R<R!A<R`D
M97)R*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1E<G(@/3T@)T%#3"!N
M;W0@879A:6QA8FQE(&]N('1H:7,@24U!4"!S97)V97(G*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1E<G(@+CT@7R@B5&AI<R!)34%0('-E<G9E<B!D
M;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB*3L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&5R<F]R7W-T<FEN
M9R`N/2`D97)R.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)&5R<F]R7W-T<FEN9RD["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M<W!R:6YT9BA?*")#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H92!F;VQL
M;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B*2P@)'-H
M87)E7W5S97(L("1F;VQD97(L("1A8VQ?<W1R*2D["B`@("`@("`@?0H*("`@
M("`@("`O*B!)9B!02%`@-2!I<VXG="!A=F%I;&%B;&4@=V%I="!A(&)I="!T
M;R!E;G-U<F4@04-,('!R;W!A9V%T97,@:6X*("`@("`@("`@*B!#>7)U<R!-
M=7)D97(@8V]N9FEG=7)A=&EO;BX@*B\*("`@("`@("!I9B`H(69U;F-T:6]N
M7V5X:7-T<R@G:6UA<%]G971A8VPG*2D@>PH@("`@("`@("`@("!S;&5E<"@U
M*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*
M("`@("\J*@H@("`@("H@161I=',@86X@04-,(&]N(&%N($E-05`@<V5R=F5R
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9O;&1E<B`@("`@(%1H
M92!F;VQD97(@;VX@=VAI8V@@=&\@961I="!T:&4@04-,+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<VAA<F5?=7-E<B`@5&AE('5S97(@=&\@9W)A;G0@<FEG
M:'1S('1O+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A8VP@("`@("`@("`@06X@
M87)R87DL('1H92!K97ES(&]F('=H:6-H(&%R92!T:&4@<FEG:'1S('1O"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B92!G<F%N=&5D("AS
M964@4D9#(#(P.#8I+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R
M=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@9F%I;'5R92!U;FQE<W,@<V5R=F5R
M(&1O97-N)W0*("`@("`J("`@("`@("`@("`@("`@('-U<'!O<G0@04-,<RP@
M<F5T=7)N<R`G;F]?<W5P<&]R="<*("`@("`J+PH@("`@9G5N8W1I;VX@961I
M=$%#3"@D9F]L9&5R+"`D<VAA<F5?=7-E<BP@)&%C;"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/F-R96%T94%#3"@D9F]L9&5R+"`D<VAA<F5?=7-E
M<BP@)&%C;"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!G
M970@=&AE(')E<W5L="!O9B!A($-!4$%"24Q)5%D@8V]M;6%N9"!T;R!T:&4@
M8W5R<F5N="!)34%0"B`@("`@*B!S97)V97(N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@
M87)R87D@8V]N=&%I;FEN9R!T:&4@<V5R=F5R)W,@8V%P86)I;&ET:65S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?9V5T0V%P86)I;&ET>2@I"B`@("!["B`@
M("`@("`@)&-A<&%B:6QI=&EE<R`](&YU;&P["B`@("`@("`@)'-E<G9E<B`]
M("1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==.PH@("`@("`@("1S=6)?<')O
M=&\@/2!N=6QL.PH*("`@("`@("!I9B`H<')E9U]M871C:"@G?%Y;7B]=*R]S
M<VQ\)RP@)'1H:7,M/E]P87)A;7-;)W!R;W1O8V]L)UTI*2!["B`@("`@("`@
M("`@("1S97)V97(@/2`G<W-L.B\O)R`N("1S97)V97(["B`@("`@("`@?0H*
M("`@("`@("`D:6UA<"`](&9S;V-K;W!E;B@D<V5R=F5R+"`D=&AI<RT^7W!A
M<F%M<ULG<&]R="==+"`D97)R;F\L("1E<G)S='(L(#,P*3L*"B`@("`@("`@
M:68@*"$D:6UA<"D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BA?*")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET
M:65S(BD@+B`G("T@)R`N("@D97)R;F\@/R!?*")#;VYN96-T:6]N(&9A:6QE
M9#H@(BD@+B`D97)R;F\@+B`G(#H@)R`N("1E<G)S='(@.B!?*")#;VYN96-T
M:6]N(&9A:6QE9"XB*2DI.PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5S<&]N<V4@/2!F9V5T<R@D
M:6UA<"P@-#`Y-BD["B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7EPJ
M7',K3TLO)RP@)')E<W!O;G-E*2D@>PH@("`@("`@("`@("`@("`@9G!U=',H
M)&EM87`L(")X($-!4$%"24Q)5%E<<EQN(BD["B`@("`@("`@("`@("`@("`D
M<F5S<&]N<V4@/2!T<FEM*&9G971S*"1I;6%P+"`Q,#(T*2D["B`@("`@("`@
M("`@("`@("!I9B`H<')E9U]M871C:"@G+UY<*EQS*T-!4$%"24Q)5%DO)RP@
M)')E<W!O;G-E*2D@>PH@("`@("`@("`@("`@("`@("`@("1R97-P;VYS95]A
M<G)A>2`](&5X<&QO9&4H)R`G+"`D<F5S<&]N<V4I.PH@("`@("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1R97-P;VYS95]A<G)A>2!A<R`D=F%R*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("AS=')P;W,H)'9A<BP@)STG*2`A
M/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V87(R
M(#T@97AP;&]D92@G/2<L("1V87(L(#(I.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&-A<&%B:6QI=&EE<UM3=')I;F<Z.FQO=V5R*"1V87(R6S!=
M*5U;4W1R:6YG.CIL;W=E<B@D=F%R,ELQ72E=(#T@,3L*("`@("`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1C87!A8FEL:71I97-;4W1R:6YG.CIL;W=E<B@D=F%R*5T@/2`Q.PH@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@9F-L;W-E("@D:6UA<"D["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B0V]U;&0@;F]T(')E=')I979E('-E<G9E
M<B=S(&-A<&%B:6QI=&EE<R(I("X@)R`M("<@+B!?*")5;F5X<&5C=&5D(')E
M<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B*2`N("=<)W@@0T%004))3$E465PG
M(#H@)R`N("1R97-P;VYS92D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("!F8VQO<V4@*"1I;6%P*3L*
M("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-O
M=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B*2`N("<@
M+2`G("X@7R@B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C
M;VYN96-T:6]N.B`B*2`N("1R97-P;VYS92D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@9F-L;W-E("@D:6UA<"D["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)&-A<&%B:6QI=&EE<SL*("`@('T*"B`@("`O*BH*("`@("`J($%T
M=&5M<'1S('1O(')E=')I979E('1H92!E>&ES=&EN9R!!0TP@9F]R(&$@9F]L
M9&5R(&9R;VT@=&AE(&-U<G)E;G0*("`@("`J($E-05`@<V5R=F5R+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@9F]L9&5R("!4:&4@9F]L9&5R('1O
M(&=E="!T:&4@04-,(&9O<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!!(&AA<V@@8V]N=&%I;FEN9R!I;F9O<FUA=&EO;B!O;B!T:&4@04-,+@H@
M("`@("H@/'!R93X*("`@("`J($%R<F%Y("@*("`@("`J("`@=7-E<B`]/B!!
M<G)A>2`H"B`@("`@*B`@("`@<FEG:'0@/3X@,0H@("`@("H@("`I"B`@("`@
M*B`I"B`@("`@*B`\+W!R93X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T04-,
M*"1F;VQD97(I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8V%P
M<ULG875T:"==6R=D:6=E<W0M;60U)UTI*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7V=E=$%#3"@D9F]L9&5R+"`G9&EG97-T+6UD-2<I.PH@("`@
M("`@('T@96QS96EF("AI<W-E="@D=&AI<RT^7V-A<'-;)V%U=&@G75LG8W)A
M;2UM9#4G72DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9V5T04-,
M*"1F;VQD97(L("=C<F%M+6UD-2<I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7V=E=$%#3"@D9F]L9&5R+"`G;&]G:6XG
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T
M;R!R971R:65V92!T:&4@97AI<W1I;F<@04-,(&9O<B!A(&9O;&1E<B!F<F]M
M('1H92!C=7)R96YT"B`@("`@*B!)34%0('-E<G9E<BX*("`@("`J"B`@("`@
M*B!.0CH@:68@075T:%]305-,(&ES(&YO="!I;G-T86QL960@=&AI<R!F=6YC
M=&EO;B!W:6QL('-E;F0@=&AE('5S97)S"B`@("`@*B!P87-S=V]R9"!T;R!T
M:&4@24U!4"!S97)V97(@87,@<&QA:6X@=&5X="$A"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R!F
M;VQD97(@("`@5&AE(&9O;&1E<B!T;R!G970@=&AE($%#3"!F;W(N"B`@("`@
M*B!`<&%R86T@<W1R:6YG(&%U=&A-96-H("!4:&4@875T:&]R:7-A=&EO;B!M
M96-H86YI<VT@=&\@=7-E+B!/;F4@;V8*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@(&-R86TM;60U+"!D:6=E<W0M;60U(&]R(&QO9VEN+@H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@($$@:&%S:"!C;VYT86EN:6YG(&EN
M9F]R;6%T:6]N(&]N('1H92!!0TP*("`@("`J(#QP<F4^"B`@("`@*B!!<G)A
M>2`H"B`@("`@*B`@('5S97(@/3X@07)R87D@*`H@("`@("H@("`@(')I9VAT
M(#T^(#$*("`@("`J("`@*0H@("`@("H@*0H@("`@("H@/"]P<F4^"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]G971!0TPH)&9O;&1E<BP@)&%U=&A-96-H*0H@
M("`@>PH@("`@("`@("\J($EF(&EM87!?9V5T86-L*"D@:7,@879A:6QA8FQE
M+"!U<V4@:70@*B\*("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=I;6%P
M7V=E=&%C;"<I*2!["B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]C;VYN96-T
M*"DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM87`["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1R97-U;'0@/2!`:6UA<%]G971A
M8VPH)'1H:7,M/E]I;6%P+"`D9F]L9&5R*3L*("`@("`@("`@("`@:68@*"$D
M<F5S=6QT*2!["B`@("`@("`@("`@("`@("`D97)R;W)S(#T@:6UA<%]E<G)O
M<G,H*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D97)R;W)S*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1E<G)O<E]S=')I;F<@/2`G)SL*("`@
M("`@("`@("`@("`@("`@("!F;W)E86-H("@D97)R;W)S(&%S("1E<G(I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1E<G(@/3T@)T%#3"!N;W0@
M879A:6QA8FQE(&]N('1H:7,@24U!4"!S97)V97(G*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D97)R("X](%\H(E1H:7,@24U!4"!S97)V97(@
M9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(BD["B`@("`@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)&5R
M<F]R7W-T<FEN9R`N/2`D97)R.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D97)R
M;W)?<W1R:6YG*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B0V]U;&0@;F]T
M(')E=')I979E($%#3"(I*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1R971U<FY!0TP@/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W)E86-H("@D
M<F5S=6QT(&%S("1U<V5R(#T^("1R:6=H=',I('L*("`@("`@("`@("`@("`@
M(&9O<B`H)&D@/2`P+"`D:4UA>"`]('-T<FQE;B@D<FEG:'1S*3L@)&D@/"`D
M:4UA>#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("1R971U<FY!0TQ;
M)'5S97)=6R1R:6=H='-;)&E=72`](#$["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@(')E='5R;B`D<F5T=7)N04-,.PH@
M("`@("`@('T*"B`@("`@("`@9VQO8F%L("1N;W1I9FEC871I;VX["@H@("`@
M("`@("1H879E7W-A<VP@/2!F86QS93L*("`@("`@("`D<F5T=7)N04-,(#T@
M87)R87DH*3L*("`@("`@("`D<V5R=F5R(#T@)'1H:7,M/E]P87)A;7-;)VAO
M<W1S<&5C)UT["B`@("`@("`@)'-U8E]P<F]T;R`](&YU;&P["B`@("`@("`@
M)'1X:60@/2`P.PH*("`@("`@("`O*B!3:6QE;F-E('=A<FYI;F=S(&1U<FEN
M9R!C:&5C:R!I9B!!=71H7U-!4TP@;6]D=6QE(&ES(&EN<W1A;&QE9"X@*B\*
M("`@("`@("!I9B`H0&EN8VQU9&5?;VYC92`G075T:"]305-,+G!H<"<I('L*
M("`@("`@("`@("`@)&AA=F5?<V%S;"`]('1R=64["B`@("`@("`@?0H*("`@
M("`@("`D<&%S<R`]("1T:&ES+3Y?<&%R86US6R=P87-S=V]R9"==.PH*("`@
M("`@("!I9B`H<')E9U]M871C:"@G?%Y;7B]=*R]S<VQ\)RP@)'1H:7,M/E]P
M87)A;7-;)W!R;W1O8V]L)UTI*2!["B`@("`@("`@("`@("1S97)V97(@/2`G
M<W-L.B\O)R`N("1S97)V97(["B`@("`@("`@?0H*("`@("`@("`O*B!1=6]T
M92!T:&4@9F]L9&5R('-T<FEN9R!I9B!I="!C;VYT86EN<R!N;VX@86QP:&$M
M;G5M97)I8PH@("`@("`@("`@(&-H87)A8W1E<G,N("HO"B`@("`@("`@:68@
M*'!R96=?;6%T8V@H)R]<5R\G+"1F;VQD97(I*2!["B`@("`@("`@("`@("1F
M;VQD97(@/2`G(B<@+B`D9F]L9&5R("X@)R(G.PH@("`@("`@('T*"B`@("`@
M("`@)&EM87`@/2!F<V]C:V]P96XH)'-E<G9E<BP@)'1H:7,M/E]P87)A;7-;
M)W!O<G0G72P@)&5R<FYO+"`D97)R<W1R+"`S,"D["@H@("`@("`@(&EF("@A
M)&EM87`I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M7R@B0V]U;&0@;F]T(')E=')I979E($%#3"(I"B`@("`@("`@("`@("`@("`N
M("<@+2`G("X@*"1E<G)N;R`_(%\H(D-O;FYE8W1I;VX@9F%I;&5D.B`B*2`N
M("1E<G)N;RXG(#H@)R`N("1E<G)S='(@.B!?*")#;VYN96-T:6]N(&9A:6QE
M9"XB*2DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R97-P;VYS
M92`](&9G971S*"1I;6%P+"`T,#DV*3L*("`@("`@("`@("`@:68@*'!R96=?
M;6%T8V@H)R]>7"I<<RM/2R\G+"`D<F5S<&]N<V4I*2!["@H@("`@("`@("`@
M("`@("`@+RH@;&]G:6X@=7-I;F<@=&AE('!R969E<G)E9"!M96-H86YI<VT@
M9&5F875L="!T;R!L;V=I;B!I9@H@("`@("`@("`@("`@("`@("`@075T:%]3
M05-,(&ES(&YO="!I;G-T86QL960N("HO"B`@("`@("`@("`@("`@("!I9B`H
M)&AA=F5?<V%S;"`F)B`H)&%U=&A-96-H(#T]("=C<F%M+6UD-2<I*2!["B`@
M("`@("`@("`@("`@("`@("`@)&QO9VEN(#T@075T:%]305-,.CIF86-T;W)Y
M*"=C<F%M;60U)RD["@H@("`@("`@("`@("`@("`@("`@(&9P=71S*"1I;6%P
M+"`B)'1X:60@05542$5.5$E#051%($-204TM340U7')<;B(I.PH@("`@("`@
M("`@("`@("`@("`@("1C:&%L;&5N9V4@/2!E>'!L;V1E*"<@)RP@=')I;2AF
M9V5T<R@D:6UA<"P@,3`R-"DI*3L*"B`@("`@("`@("`@("`@("`@("`@)')E
M<W!O;G-E(#T@)&QO9VEN+3YG971297-P;VYS92@D7U-%4U-)3TY;)VEM<"==
M6R=U<V5R)UTL("1P87-S+"!B87-E-C1?9&5C;V1E*"1C:&%L;&5N9V5;,5TI
M*3L*("`@("`@("`@("`@("`@("`@("!F<'5T<R@D:6UA<"P@8F%S938T7V5N
M8V]D92@D<F5S<&]N<V4I("X@(EQR7&XB*3L*"B`@("`@("`@("`@("`@("!]
M(&5L<V5I9B@D:&%V95]S87-L("8F("@D875T:$UE8V@@/3T@)V1I9V5S="UM
M9#4G*2D@>PH@("`@("`@("`@("`@("`@("`@("1L;V=I;B`]($%U=&A?4T%3
M3#HZ9F%C=&]R>2@G9&EG97-T;60U)RD["@H@("`@("`@("`@("`@("`@("`@
M(&9P=71S*"1I;6%P+"`B)'1X:60@05542$5.5$E#051%($1)1T535"U-1#5<
M<EQN(BD["B`@("`@("`@("`@("`@("`@("`@)&-H86QL96YG92`](&5X<&QO
M9&4H)R`G+"!T<FEM*&9G971S*"1I;6%P+"`Q,#(T*2DI.PH*("`@("`@("`@
M("`@("`@("`@("`D<F5S<&]N<V4@/2`D;&]G:6XM/F=E=%)E<W!O;G-E*"1?
M4T534TE/3ELG:6UP)UU;)W5S97(G72P@)'!A<W,L(&)A<V4V-%]D96-O9&4H
M)&-H86QL96YG95LQ72DL"B`@("`@("`@("`@("`@("`@("`@("`@("1?4T53
M4TE/3ELG:6UP)UU;)W-E<G9E<B==+"`D7U-%4U-)3TY;)VEM<"==6R=B87-E
M7W!R;W1O8V]L)UTI.PH*("`@("`@("`@("`@("`@("`@("!F<'5T<R@D:6UA
M<"P@8F%S938T7V5N8V]D92@D<F5S<&]N<V4I("X@(EQR7&XB*3L*("`@("`@
M("`@("`@("`@("`@("`D<F5S<&]N<V4@/2!E>'!L;V1E*"<@)RP@=')I;2AF
M9V5T<R@D:6UA<"P@,3`R-"DI*3L*("`@("`@("`@("`@("`@("`@("`D<F5S
M<&]N<V4@/2!B87-E-C1?9&5C;V1E*"1R97-P;VYS95LQ72D["B`@("`@("`@
M("`@("`@("`@("`@:68@*'-T<G!O<R@D<F5S<&]N<V4L("=R<W!A=71H/2<I
M(#T]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@("`@("!F8VQO<V4H
M)&EM87`I.PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BA?*")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(BD*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("X@)R`M("<@+B!?*")5;F5X<&5C=&5D
M(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B*2`N("=$:6=E<W0M340U(')E
M<W!O;G-E)RP@)VAO<F1E+G=A<FYI;F<G*3L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@9G!U=',H)&EM87`L(")<<EQN(BD[
M"@H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H<')E9U]M871C:"@G+UQ7+R<L("1P87-S*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D<&%S<R`](&%D9'-L87-H97,H)'!A<W,I.PH@("`@
M("`@("`@("`@("`@("`@("`@("`D<&%S<R`]("<B)R`N("1P87-S("X@)R(G
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!F
M<'5T<R@D:6UA<"P@(B1T>&ED($Q/1TE.("(@+B`D7U-%4U-)3TY;)VEM<"==
M6R=U<V5R)UT@+B`G("<@+B`D<&%S<R`N(")<<EQN(BD["@H@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@)')E<W!O;G-E(#T@=')I;2AF9V5T
M<R@D:6UA<"P@,3`R-"DI.PH@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T
M8V@H(B]>)'1X:61<<T]++R(L("1R97-P;VYS92DI('L*("`@("`@("`@("`@
M("`@("`@("`D='AI9"LK.PH@("`@("`@("`@("`@("`@("`@(&9P=71S*"1I
M;6%P+"`B)'1X:60@1T5404-,("(@+B`D9F]L9&5R("X@(EQR7&XB*3L*("`@
M("`@("`@("`@("`@("`@("`D<F5S<&]N<V4@/2!T<FEM*&9G971S*"1I;6%P
M+"`T,#DV*2D["B`@("`@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H
M)R]>7"I<<RM!0TQ<<RLH+BHI+VDG+"`D<F5S<&]N<V4L("1M871C:&5S*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D<F5S7V%R<B`]("1T:&ES+3Y?
M871O;6ES92@D;6%T8VAE<ULQ72D["B`@("`@("`@("`@("`@("`@("`@("`@
M("1R97-?9F]L9&5R(#T@87)R87E?<VAI9G0H)')E<U]A<G(I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D:7-?:V5Y(#T@,3L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&ME>2`](&YU;&P["B`@("`@("`@("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1R97-?87)R(&%S("1V87(I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("@D:7-?:V5Y*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&ME>2`]("1V87(["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&ES7VME>2`](#`["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1P97)M<R`]('!R96=?<W!L:70H)R\O)RP@)'9A<BP@+3$L(%!2
M14=?4U!,251?3D]?14U05%DI.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1P97)M<R!A<R`D<%]K97D@/3X@)'!?=F%R*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R971U<FY!
M0TQ;)&ME>5U;)'!?=F%R72`](#$["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I
M<U]K97D@/2`Q.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@9F-L;W-E*"1I;6%P*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B0V]U;&0@;F]T(')E=')I979E($%#3"(I"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`N("<@+2`G("X@7R@B56YE>'!E8W1E9"!R97-P;VYS
M92!F<F]M('-E<G9E<B!T;SH@(BD@+B`B)R1T>&ED($=%5$%#3"<@.B`B("XD
M<F5S<&]N<V4I.PH*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&9C;&]S92@D:6UA
M<"D["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B0V]U;&0@;F]T(')E=')I979E($%#3"(I"B`@("`@("`@("`@("`@
M("`@("`@("`@("X@)R`M("<@+B!?*")5;F5X<&5C=&5D(')E<W!O;G-E(&9R
M;VT@<V5R=F5R('1O.B`B*2`N("=L;V=I;B`Z("<@+B`D<F5S<&]N<V4I.PH*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@(&9C;&]S92@D:6UA<"D["B`@("`@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#;W5L9"!N;W0@<F5T<FEE=F4@04-,
M(BD*("`@("`@("`@("`@("`@("`@("`N("<@+2`G("X@7R@B56YE>'!E8W1E
M9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B`B*2`N("1R
M97-P;VYS92D["@H@("`@("`@("`@("!]"B`@("`@("`@("`@(&9C;&]S92@D
M:6UA<"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E='5R;D%#3#L*
M("`@('T*"B`@("`O*BH*("`@("`J($-A;B!A('5S97(@961I="!T:&4@04-,
M(&9O<B!T:&ES(&9O;&1E<C\*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1F;VQD97(@(%1H92!F;VQD97(@;F%M92X*("`@("`J($!P87)A;2!S=')I
M;F<@)'5S97(@("`@02!U<V5R(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!4<G5E(&EF("1U<V5R(&AA<R!P97)M:7-S:6]N('1O(&5D
M:70@=&AE($%#3"!O;@H@("`@("H@("`@("`@("`@("`@("`@("`D9F]L9&5R
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!C86Y%9&ET*"1F;VQD97(L("1U<V5R
M*0H@("`@>PH@("`@("`@("\J(%=E(&-A;B=T(&5S=&%B;&ES:"!I9B!T:&4@
M=7-E<B!I<R!I;B!A(&=R;W5P('=I=&@@=&AE("=A)PH@("`@("`@("`@('!R
M:79I;&5G92P@<V\@:G5S="!R971U<FX@=')U92!A;F0@;&5A=F4@=&AE(&1E
M8VES:6]N('1O('1H90H@("`@("`@("`@('-E<G9E<B`J+PH@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)U9&5L>2!S<&QI
M="!A('-T<FEN9R!I;G1O("=A=&]M<R<N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:6X@(%1H
M92!S=')I;F<@=&\@<W!L:70N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A
M>2`@06X@87)R87D@;V8@)V%T;VUS)RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V%T;VUI<V4H)&EN*0H@("`@>PH@("`@("`@("1L96YG=&@@/2!S=')L96XH
M)&EN*3L*("`@("`@("`D<70@/2!F86QS93L*("`@("`@("`D:61X(#T@,#L*
M("`@("`@("`D;W5T(#T@87)R87DH*3L*"B`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P@)&QE;F=T:#L@)&DK*RD@>PH@("`@("`@("`@("`D8VAA<B`]('-U
M8G-T<B@D:6XL("1I+"`Q*3L*("`@("`@("`@("`@:68@*"@D8VAA<B`]/2`G
M(B<I("8F("$D<70I('L*("`@("`@("`@("`@("`@("1Q="`]('1R=64["B`@
M("`@("`@("`@("`@("`D:61X*RL["B`@("`@("`@("`@("`@("!C;VYT:6YU
M93L*("`@("`@("`@("`@?2!E;'-E:68@*"@D8VAA<B`]/2`G("<I("8F("$D
M<70I('L*("`@("`@("`@("`@("`@("1I9'@K*SL*("`@("`@("`@("`@?2!E
M;'-E:68@*"@D8VAA<B`]/2`G(B<I("8F("1Q="D@>PH@("`@("`@("`@("`@
M("`@)'%T(#T@9F%L<V4["B`@("`@("`@("`@("`@("`D:61X*RL["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!I9B`H96UP='DH)&]U
M=%LD:61X72DI('L*("`@("`@("`@("`@("`@("`@("`D;W5T6R1I9'A=(#T@
M)&-H87(["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("1O=71;)&ED>%T@+CT@)&-H87(["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;W5T
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O24U!4"]!9&UI;BYP:'``````````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3<P-3$@,3`U,34T,S,W,S8@
M,#(Q-C0T`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B!4:&4@24U!4%]!9&UI;CHZ(&-L87-S(&%L;&]W
M(&UA;F%G:6YG(&]F(&UA:6QB;WAE<R!O;B!)34%0('-E<G9E<G,N"B`J"B`J
M(%)E<75I<F5D('!A<F%M971E<G,Z/'!R93X*("H@("`G861M:6Y?=7-E<B<@
M("`@("!4:&4@;F%M92!O9B!A('5S97(@=VET:"!A9&UI;B!P<FEV:6QE9V5S
M+@H@*B`@("=A9&UI;E]P87-S=V]R9"<@(%1H92!P87-S=V]R9"!O9B!T:&4@
M861M:6YS=')A=&]R+CPO<')E/@H@*@H@*B!/<'1I;VYA;"!P87)A;65T97)S
M.CQP<F4^"B`J("`@)VAO<W1S<&5C)R`@("`@("!4:&4@:&]S=&YA;64@;W(@
M25`@861D<F5S<R!O9B!T:&4@<V5R=F5R+@H@*B`@("`@("`@("`@("`@("`@
M("`@1$5&055,5#H@)VQO8V%L:&]S="<*("H@("`G<&]R="<@("`@("`@("`@
M(%1H92!S97)V97(@<&]R="!T;R!W:&EC:"!W92!W:6QL(&-O;FYE8W0N"B`J
M("`@("`@("`@("`@("`@("`@("!)34%0(&ES(&=E;F5R86QL>2`Q-#,L('=H
M:6QE($E-05`M4U-,(&ES(&=E;F5R86QL>2`Y.3,N"B`J("`@("`@("`@("`@
M("`@("`@("!$149!54Q4.B`Q-#,*("H@("`G<')O=&]C;VPG("`@("`@(%1H
M92!C;VYN96-T:6]N('!R;W1O8V]L("AE+F<N("=I;6%P)RP@)W!O<#,G+"`G
M;FYT<"<I+@H@*B`@("`@("`@("`@("`@("`@("`@4')O=&]C;VP@:7,@;VYE
M(&]F("=I;6%P+VYO=&QS)R`H;W(@;VYL>2`G:6UA<"<@:68@>6]U"B`J("`@
M("`@("`@("`@("`@("`@("!H879E(&$@8RUC;&EE;G0@=F5R<VEO;B`R,#`P
M8R!O<B!O;&1E<BDL("=I;6%P+W-S;"<L"B`J("`@("`@("`@("`@("`@("`@
M("!O<B`G:6UA<"]S<VPO;F]V86QI9&%T92UC97)T)R`H9F]R(&$@<V5L9BUS
M:6=N960*("H@("`@("`@("`@("`@("`@("`@(&-E<G1I9FEC871E*2X*("H@
M("`@("`@("`@("`@("`@("`@($1%1D%53%0Z("=I;6%P)PH@*B`@("=U<V5R
M:&EE<F%R8VAY)R`@5&AE(&AI97)A<F-H>2!W:&5R92!U<V5R(&UA:6QB;WAE
M<R!A<F4@<W1O<F5D+@H@*B`@("`@("`@("`@("`@("`@("`@1$5&055,5#H@
M)W5S97(N)PH@*B`@("=D<VXG("`@("`@("`@("`@5&AE(&9U;&P@24U!4"!C
M;VYN96-T:6]N('-T<FEN9RX*("H@("`@("`@("`@("`@("`@("`@($EF(&YO
M="!P<F5S96YT+"!T:&ES(&ES(&)U:6QT(&9R;VT@)VAO<W1S<&5C)RP@)W!O
M<G0G"B`J("`@("`@("`@("`@("`@("`@("!A;F0@)W!R;W1O8V]L)R!P87)A
M;65T97)S+CPO<')E/@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R])34%0+TE-
M05`O061M:6XN<&AP+'8@,2XU+C8N.2`R,#`V+S`U+S,Q(#$Y.C,Y.C0W('-L
M=7-A<GH@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!*86X@4V-H
M;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E
M("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TE-05`*("HO"F-L87-S
M($E-05!?061M:6X@>PH*("`@("\J*@H@("`@("H@4&%R86UE=&5R(&AA<V@N
M"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P
M87)A;7,["@H@("`@+RHJ"B`@("`@*B!)34%0(')E<V]U<F-E+@H@("`@("H*
M("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J+PH@("`@=F%R("1?:6UA<#L*
M"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@=VET:"!A;&P@;F5C97-S87)Y
M('!A<F%M971E<G,*("`@("`J+PH@("`@9G5N8W1I;VX@24U!4%]!9&UI;B@D
M<&%R86US*0H@("`@>PH@("`@("`@("1D969A=6QT7W!A<F%M<R`](&%R<F%Y
M*`H@("`@("`@("`@("`G:&]S='-P96,G(#T^("=L;V-A;&AO<W0G+`H@("`@
M("`@("`@("`G<&]R="<@/3X@)S$T,R<L"B`@("`@("`@("`@("=P<F]T;V-O
M;"<@/3X@)VEM87`G+`H@("`@("`@("`@("`G=7-E<FAI97)A<F-H>2<@/3X@
M)W5S97(N)PH@("`@("`@("D["B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2!A
M<G)A>5]M97)G92@D9&5F875L=%]P87)A;7,L("1P87)A;7,I.PH*("`@("`@
M("`O*B!#<F5A=&4@1%-.('-T<FEN9RX@*B\*("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?<&%R86US6R=D<VXG72DI('L*("`@("`@("`@("`@)'1H:7,M
M/E]P87)A;7-;)V1S;B==(#T@<W!R:6YT9B@G>R5S.B5D+R5S?2<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]P87)A;7-;)VAO<W1S<&5C)UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!O<G0G72P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!A<F%M<ULG<')O=&]C;VPG72D["B`@("`@("`@("`@("1T:&ES
M+3Y?<F5F(#T@)'1H:7,M/E]P87)A;7-;)V1S;B==.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7GLH6UXZ72LI.BA<
M9"LI7"\H6UY]72LI?2\G+"`D=&AI<RT^7W!A<F%M<ULG9'-N)UTL("1M871C
M:&5S*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)VAO<W1S
M<&5C)UT@/2`D;6%T8VAE<ULQ73L*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=P;W)T)UT@/2`D;6%T8VAE<ULR73L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=P<F]T;V-O;"==(#T@)&UA=&-H97-;,UT["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7W)E9B`]('-P<FEN=&8H)WLE<SHE9"\E
M<WTG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=P;W)T)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)W!R;W1O8V]L)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@0V]N;F5C=',@=&\@=&AE($E-05`@<V5R
M=F5R('=I=&@@=&AE('!A<F%M971E<G,@<&%S<V5D('1O('1H90H@("`@("H@
M8V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!R97-O=7)C97QO
M8FIE8W0@($%N($E-05`@<F5S;W5R8V4@;W(@82!014%27T5R<F]R(&]N(&9A
M:6QU<F4*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;FYE8W0H*0H@("`@>PH@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]I;6%P*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7VEM87`@/2!`:6UA<%]O<&5N*"1T:&ES+3Y?<F5F+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=A9&UI;E]U<V5R)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V%D;6EN7W!A<W-W;W)D)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@3U!?2$%,
M1D]014XI.PH@("`@("`@("`@("!I9B`H(21T:&ES+3Y?:6UA<"D@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]I;6%P(#T@4$5!4CHZ<F%I<V5%<G)O<BA?
M*")!=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N(BDL("=H
M;W)D92YE<G)O<B<I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@
M(')E='5R;B`D=&AI<RT^7VEM87`["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!
M9&1S(&$@;6%I;&)O>"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1M
M86EL8F]X("`@("`@5&AE(&UA:6QB;W@@;F%M92!T;R!A9&0N"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!
M4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@861D36%I;&)O>"@D;6%I;&)O>"D*("`@('L*("`@("`@("!I9B`H:7-?
M82@D:6UA<"`]("1T:&ES+3Y?8V]N;F5C="@I+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D:6UA<#L*("`@("`@("!]"B`@("`@("`@
M:68@*"%`:6UA<%]C<F5A=&5M86EL8F]X*"1I;6%P+"`D=&AI<RT^7W)E9B`N
M("1T:&ES+3Y?<&%R86US6R=U<V5R:&EE<F%R8VAY)UT@+B`D;6%I;&)O>"DI
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H:6UA<%]L
M87-T7V5R<F]R*"DL("=H;W)D92YW87)N:6YG)RD["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)'1H:7,M/E]G<F%N=$%D;6EN4&5R;7,H)&UA:6QB;W@I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1W)A;G0@=&AE(&%D;6EN('5S97(@
M86QL(')I9VAT<R!O;B!T:&4@;6%I;&)O>"X*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1M86EL
M8F]X("`@("`@('1H92!N86UE(&]F('1H92!M86EL8F]X(&]N('=H:6-H('=E
M('=I;&P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9W)A
M;G0@=&AE('!E<FUI<W-I;VX*("`@("`J($!R971U<FX@;6EX960@5')U92!I
M9B!S=6-C97-S9G5L+"!O<B!014%27T5R<F]R(&]N(&9A:6QU<F4*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V=R86YT061M:6Y097)M<R@D;6%I;&)O>"D*("`@
M('L*("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G
M+T%#3"YP:'`G.PH*("`@("`@("`D<&%R86US(#T@87)R87DH)W5S97)N86UE
M)R`]/B`D=&AI<RT^7W!A<F%M<ULG861M:6Y?=7-E<B==+`H@("`@("`@("`@
M("`@("`@("`@("`@("`G<&%S<W=O<F0G(#T^("1T:&ES+3Y?<&%R86US6R=A
M9&UI;E]P87-S=V]R9"==+`H@("`@("`@("`@("`@("`@("`@("`@("`G:&]S
M='-P96,G(#T^("1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==+`H@("`@("`@
M("`@("`@("`@("`@("`@("`G<&]R="<@/3X@)'1H:7,M/E]P87)A;7-;)W!O
M<G0G72P*("`@("`@("`@("`@("`@("`@("`@("`@)W!R;W1O8V]L)R`]/B`D
M=&AI<RT^7W!A<F%M<ULG<')O=&]C;VPG72D["B`@("`@("`@)&%C;"`]("9)
M34%07T%#3#HZ9F%C=&]R>2@G<F9C,C`X-B<L("1P87)A;7,I.PH@("`@("`@
M("1R97-U;'0@/2`D86-L+3YC<F5A=&5!0TPH)'1H:7,M/E]P87)A;7-;)W5S
M97)H:65R87)C:'DG72`N("1M86EL8F]X+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V%D;6EN7W5S97(G72P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=L)R`]
M/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W(G(#T^('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G<R<@/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=W)R`]/B!T<G5E+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)VDG(#T^('1R=64L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<"<@/3X@=')U
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=C
M)R`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)V0G(#T^('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G82<@/3X@=')U92DI.PH@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1&5L971E<R!A(&UA:6QB;W@N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;6%I;&)O>"`@5&AE(&UA:6QB;W@@=&\@
M9&5L971E+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@
M<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')E;6]V94UA:6QB;W@H)&UA:6QB;W@I"B`@
M("!["B`@("`@("`@:68@*&ES7V$H)&EM87`@/2`D=&AI<RT^7V-O;FYE8W0H
M*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&EM87`[
M"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V=R86YT061M:6Y097)M<R@D
M;6%I;&)O>"D["B`@("`@("`@:68@*"%`:6UA<%]D96QE=&5M86EL8F]X*"1I
M;6%P+"`D=&AI<RT^7W)E9B`N("1T:&ES+3Y?<&%R86US6R=U<V5R:&EE<F%R
M8VAY)UT@+B`D;6%I;&)O>"DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H:6UA<%]L87-T7V5R<F]R*"DL("=H;W)D92YW87)N:6YG
M)RD["B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@3&ES="!A;&P@;6%I;&)O>&5S+@H@("`@("H*("`@("`J
M($YO=&4@=&AA="!T:&ES(&1O97,@;F]T('=O<FL@;VX@82!V:7)T=6%L+61O
M;6%I;B!E;F%B;&5D($-Y<G5S("AI="!W:6QL"B`@("`@*B!O;FQY(')E='5R
M;B!M86EL8F]X97,@:6X@=&AE(&1E9F%U;'0@9&]M86EN*2X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@87)R87D@;V8@;6%I;&)O>&5S+"!O
M<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&QI<W1-86EL8F]X97,H*0H@("`@>PH@("`@("`@(&EF("AI
M<U]A*"1I;6%P(#T@)'1H:7,M/E]C;VYN96-T*"DL("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1I;6%P.PH@("`@("`@('T*"B`@("`@
M("`@)&QI<W0@/2!`:6UA<%]L:7-T*"1I;6%P+"`D=&AI<RT^7W)E9BP@)'1H
M:7,M/E]P87)A;7-;)W5S97)H:65R87)C:'DG72`N("<E)RD["B`@("`@("`@
M:68@*"$D;&ES="D@>PH@("`@("`@("`@("!R971U<FX@87)R87DH*3L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N('!R96=?<F5P;&%C92@G+RXJ)R`N('!R
M96=?<75O=&4H)'1H:7,M/E]P87)A;7-;)W5S97)H:65R87)C:'DG72P@)R\G
M*2`N("<H+BHI+R<L("=<7#$G+"`D;&ES="D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#:&5C:R!W:&5T:&5R(&$@;6%I;&)O>"!E>&ES=',N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;6%I;&)O>"`@(%1H92!M86EL8F]X('1O
M(&-H96-K+@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!I9B!M86EL8F]X
M(&5X:7-T<RP@9F%L<V4@:68@;F]T+"!O<B!A(%!%05)?17)R;W(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&UA:6QB;WA%>&ES=',H)&UA:6QB;W@I"B`@("![
M"B`@("`@("`@:68@*&ES7V$H)&EM87`@/2`D=&AI<RT^7V-O;FYE8W0H*2P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&EM87`["B`@
M("`@("`@?0H*("`@("`@("`D;&ES="`]($!I;6%P7VQI<W0H)&EM87`L("1T
M:&ES+3Y?<F5F+"`D=&AI<RT^7W!A<F%M<ULG=7-E<FAI97)A<F-H>2==("X@
M)&UA:6QB;W@I.PH@("`@("`@(&EF("@D;&ES="`]/3T@9F%L<V4I('L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@8V]U;G0H)&QI<W0I(#X@,#L*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TE-05`O
M04-,+G!H<```````````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#$R-S$U(#$P-3$U-#,S-S,V(#`R,3(Q-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@0V]N=&%I;G,@
M9G5N8W1I;VYS(')E;&%T960@=&\@;6%N86=I;F<*("H@06-C97-S($-O;G1R
M;VP@3&ES=',N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPN<&AP+'8@,2XR+C$R+C$P(#(P,#8O,#(O,#,@,#,Z,#<Z-3<@<V5L<VMY
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@0VAR:7,@2&%S=&EE
M(#QI;7!`;V%K+7=O;V0N8V\N=6L^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!#:')I<R!(87-T:64@/&EM<$!O86LM=V]O9"YC;RYU:SX*("H@0'-I
M;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TE-05`*("HO"F-L
M87-S($E-05!?04-,('L*"B`@("`O*BH*("`@("`J($AA<V@@8V]N=&%I;FEN
M9R!C;VYN96-T:6]N('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A>2@I.PH*("`@
M("\J*@H@("`@("H@0F]O;&5A;B!I;F1I8V%T:6YG(&EF('1H92!D<FEV97(@
M:7,@<W5P<&]R=&5D(&)Y('1H92!S97)V97(*("`@("`J"B`@("`@*B!`=F%R
M(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?<W5P<&]R=&5D(#T@9F%L<V4[
M"@H@("`@+RHJ"B`@("`@*B!!;GD@4$5!4E]%<G)O<B!T:&%T(&]C8W5R960@
M8G5T(&-O=6QD;B=T(&)E(')E='5R;F5D(&1I<F5C=&QY+@H@("`@("H*("`@
M("`J($!V87(@4$5!4E]%<G)O<@H@("`@("HO"B`@("!V87(@)%]E<G)O<B`]
M(&YU;&P["@H@("`@+RHJ"B`@("`@*B!(87-H(&-O;G1A:6YI;F<@=&AE(&QI
M<W0@;V8@<&]S<VEB;&4@<FEG:'1S(&%N9"!A(&AU;6%N"B`@("`@*B!R96%D
M86)L92!D97-C<FEP=&EO;B!O9B!E86-H"B`@("`@*@H@("`@("H@07)R87D@
M*`H@("`@("H@("`@(')I9VAT+6ED(#T^(')I9VAT+61E<V-R:7!T:6]N"B`@
M("`@*B`I"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)%]R:6=H='-,:7-T(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($%R
M<F%Y(&-O;G1A:6YI;F<@=7-E<B!N86UE<R!T:&%T(&-A;FYO="!H879E('1H
M96ER(&%C8V5S<PH@("`@("H@<FEG:'1S(&-H86YG960N"B`@("`@*@H@("`@
M("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7W!R;W1E8W1E9#L*
M"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`D<&%R86US("!(87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO
M;B!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!)34%07T%#3"@D
M<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^7W!A<F%M
M<R`]("1P87)A;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T
M;R!R971R:65V92!T:&4@97AI<W1I;F<@04-,(&9O<B!A(&9O;&1E<B!F<F]M
M"B`@("`@*B!T:&4@8W5R<F5N="!)34%0('-E<G9E<BX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG(&9O;&1E<B`@5&AE(&9O;&1E<B!T;R!G970@=&AE
M($%#3"!F;W(*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!(&AA<V@@
M8V]N=&%I;FEN9R!I;F9O<FUA=&EO;B!O;B!T:&4@04-,"B`@("`@*B`@("`@
M("`@("`@("`@("!!<G)A>2`H"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M=7-E<B`]/B!!<G)A>2`H"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@<FEG:'0@/3X@,0H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@*0H@("`@("H@("`@("`@("`@("`@("`@*0H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971!0TPH)&9O;&1E<BD*("`@('L*("`@("`@("!R971U
M<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!!0TP@
M;VX@86X@24U!4"!S97)V97(*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1F;VQD97(@(%1H92!F;VQD97(@;VX@=VAI8V@@=&\@961I="!T:&4@04-,
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<VAA<F5?=7-E<B`@5&AE
M('5S97(@=&\@9W)A;G0@<FEG:'1S('1O"B`@("`@*@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1A8VP@($%N(&%R<F%Y+"!T:&4@:V5Y<R!O9B!W:&EC:"!A<F4@
M=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@<FEG:'1S('1O(&)E(&=R
M86YT960@*'-E92!21D,@,C`X-BD*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N(&9A:6QU<F4@=6YL97-S
M"B`@("`@*B`@("`@("`@("`@("`@("!S97)V97(@9&]E<VXG="!S=7!P;W)T
M($%#3',L(')E='5R;G,@)VYO7W-U<'!O<G0G"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&-R96%T94%#3"@D9F]L9&5R+"`D<VAA<F5?=7-E<BP@)&%C;"D*("`@
M('L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!%9&ET<R!A;B!!0TP@;VX@86X@24U!4"!S97)V97(*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1F;VQD97(@(%1H92!F;VQD97(@;VX@=VAI8V@@
M=&\@961I="!T:&4@04-,"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<VAA<F5?=7-E<B`@5&AE('5S97(@=&\@9W)A;G0@<FEG:'1S('1O"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("1A8VP@($%N(&%R<F%Y+"!T:&4@:V5Y
M<R!O9B!W:&EC:"!A<F4@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M<FEG:'1S('1O(&)E(&=R86YT960@*'-E92!21D,@,C`X-BD*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N
M(&9A:6QU<F4@=6YL97-S"B`@("`@*B`@("`@("`@("`@("`@("!S97)V97(@
M9&]E<VXG="!S=7!P;W)T($%#3',L(')E='5R;G,@)VYO7W-U<'!O<G0G"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&5D:71!0TPH)&9O;&1E<BP@)'-H87)E7W5S
M97(L("1A8VPI"B`@("!["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0V%N(&$@=7-E<B!E9&ET('1H92!!0TP@9F]R('1H
M:7,@9F]L9&5R/R!2971U<FYS('1R=64@:68@)'5S97(*("`@("`J('!E<FUI
M<W-I;VX@=&\@961I="!T:&4@04-,(&]N("1F;VQD97(*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1F;VQD97(@(%1H92!F;VQD97(@;F%M90H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97(@($$@=7-E<B!N86UE"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF("1U<V5R(&AA
M<R`G82<@<FEG:'0*("`@("`J+PH@("`@9G5N8W1I;VX@8V%N161I="@D9F]L
M9&5R+"`D=7-E<BD*("`@('L*("`@("`@("!R971U<FX@=')U93L*("`@('T*
M"B`@("!F=6YC=&EO;B!G9712:6=H=',H*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7W)I9VAT<TQI<W0["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T
M4')O=&5C=&5D*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]P<F]T
M96-T960["B`@("!]"@H@("`@9G5N8W1I;VX@:7-3=7!P;W)T960H*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W-U<'!O<G1E9#L*("`@('T*"B`@
M("!F=6YC=&EO;B!G971%<G)O<B@I"B`@("!["B`@("`@("`@)&5R<F]R(#T@
M)'1H:7,M/E]E<G)O<CL*("`@("`@("`D=&AI<RT^7V5R<F]R(#T@;G5L;#L*
M("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@?0H*("`@("\J*@H@("`@("H@
M071T96UP=',@=&\@<F5T=7)N(&%N($%#3"!I;G-T86YC92!B87-E9"!O;B`D
M9')I=F5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1R:79E<B`@
M5&AE('1Y<&4@;V8@8V]N8W)E=&4@04-,('-U8F-L87-S('1O(')E='5R;BX*
M("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@02!H87-H(&-O;G1A:6YI
M;F<@86YY(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!O<@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("!C;VYN96-T:6]N('!A<F%M971E<G,@82!S
M=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R971E($%#3"!I;G-T86YC92P@
M;W(@9F%L<V4*("`@("`J("`@("`@("`@("`@("`@(&]N(&5R<F]R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D9')I=F5R+"`D<&%R86US(#T@
M87)R87DH*2D*("`@('L*("`@("`@("`D9')I=F5R(#T@8F%S96YA;64H)&1R
M:79E<BD["B`@("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I
M("X@)R]!0TPO)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@)&-L87-S
M(#T@)TE-05!?04-,7R<@+B`D9')I=F5R.PH@("`@("`@(&EF("AC;&%S<U]E
M>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D86-L(#T@)FYE=R`D8VQA
M<W,H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&%C
M;"`](&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1A8VP["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!R969E
M<F5N8V4@=&\@82!C;VYC<F5T92!!0TP@:6YS=&%N8V4*("`@("`J(&)A<V5D
M(&]N("1D<FEV97(N("!)="!W:6QL(&]N;'D@8W)E871E(&$@;F5W(&EN<W1A
M;F-E(&EF(&YO"B`@("`@*B!!0TP@:6YS=&%N8V4@=VET:"!T:&4@<V%M92!P
M87)A;65T97)S(&-U<G)E;G1L>2!E>&ES=',N"B`@("`@*@H@("`@("H@5&AI
M<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.B`D=F%R(#T@)DE-05!?04-,
M.CIS:6YG;&5T;VXH*0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1R
M:79E<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@04-,('-U8F-L87-S('1O(')E
M='5R;BX*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@02!H87-H(&-O
M;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!O<@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("!C;VYN96-T:6]N('!A<F%M971E
M<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@(%1H92!C<F5A=&5D(&-O;F-R971E($%#3"!I;G-T86YC92P@
M;W(@9F%L<V4@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG
M;&5T;VXH)&1R:79E<BP@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@
M("`@<W1A=&EC("1I;G-T86YC97,["@H@("`@("`@(&EF("@A:7-S970H)&EN
M<W1A;F-E<RDI('L*("`@("`@("`@("`@)&EN<W1A;F-E<R`](&%R<F%Y*"D[
M"B`@("`@("`@?0H*("`@("`@("`D<VEG;F%T=7)E(#T@<V5R:6%L:7IE*&%R
M<F%Y*"1D<FEV97(L("1P87)A;7,I*3L*("`@("`@("!I9B`H(6ES<V5T*"1I
M;G-T86YC97-;)'-I9VYA='5R95TI*2!["B`@("`@("`@("`@("1I;G-T86YC
M97-;)'-I9VYA='5R95T@/2`F24U!4%]!0TPZ.F9A8W1O<GDH)&1R:79E<BP@
M)'!A<F%M<RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EN<W1A;F-E
M<ULD<VEG;F%T=7)E73L*("`@('T*"GT*````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+TE-05`O4V5A<F-H+G!H<```````````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#0Q,S`Q(#$P-3$U-#,S-S,V(#`R
M,C`Q-``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@5&AE($E-05!?4V5A<F-H.CH@8VQA<W,@<&5R9F]R
M;7,@8V]M<&QE>"!S96%R8VAI;F<@;V8@86X@24U!4"!M86EL8F]X+@H@*@H@
M*B!#;&%S<V5S('1O(&AE;'`@=VET:"!C;VUP;&5X('-E87)C:&EN9R!O9B!A
M;B!)34%0(&UA:6QB;W@N("!4:&4@8G5I;'0M:6X*("H@4$A0('-E87)C:"@I
M(&9U;F-T:6]N(&]N;'D@86QL;W=S($E-05!V,B!S96%R8V@@<75E<FEE<R`H
M<V5E(%)&0R`Q,3<V*2X*("H@5&AI<R!L:6)R87)Y(&%L;&]W<R!M;W)E(&-O
M;7!L97@@<V5A<F-H97,@=&\@8F4@8W)E871E9"`H92YG+B!/4B!S96%R8VAE
M<RP*("H@<V5A<F-H:6YG('-P96-I9FEC(&AE861E<G,I+@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R])34%0+TE-05`O4V5A<F-H+G!H<"QV(#$N,CDN,3`N
M,C4@,C`P-B\P-B\P-B`Q-3HT-#HR-R!S;'5S87)Z($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`R,#`S+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I
M9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H1U!,*2X@268@
M>6]U(&1I9"!N;W0*("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D
M=3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TE-
M05`*("HO"F-L87-S($E-05!?4V5A<F-H('L*"B`@("`O*BH*("`@("`J(%1H
M92!H96%D97)S(&-A8VAE+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1?:&5A9&5R<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@
M("`@*B!4:&4@<F5S=6QT<R!C86-H92X*("`@("`J"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D7W)E<W5L="`](&%R<F%Y*"D["@H@("`@
M+RHJ"B`@("`@*B!4:&4@<&%R86UA=&5R(&QI<W0N"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A>2@I
M.PH*("`@("\J*@H@("`@("H@5&AE(&-H87)S970@;V8@=&AE('-E87)C:"!V
M86QU97,N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1?8VAA<G-E=#L*"B`@("`O*BH*("`@("`J($EN=&5R;F%L(&9L86<@
M=7-E9"!B>2!S96%R8VA-86EL8F]X*"DN"B`@("`@*@H@("`@("H@0'9A<B!I
M;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7W-E87)C:&9L86<@/2`P.PH*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!A(')E9F5R96YC92!T;R!T:&4@9VQO8F%L
M($E-05!?4V5A<F-H(&]B:F5C="P@;VYL>2!C<F5A=&EN9R!I=`H@("`@("H@
M:68@:70@9&]E<VXG="!A;')E861Y(&5X:7-T+@H@("`@("H*("`@("`J(%1H
M:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH\8V]D93X*("`@("`J("`@
M)&EM87!?<V5A<F-H(#T@)DE-05!?4V5A<F-H.CIS:6YG;&5T;VXH*3L\+V-O
M9&4^"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N>2!P
M87)A;65T97)S('1H92!C;VYS=')U8W1O<B!M87D@;F5E9"X*("`@("`J"B`@
M("`@*B!`<F5T=7)N($E-05!?4V5A<F-H("!4:&4@24U!4%]396%R8V@@:6YS
M=&%N8V4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)'!A<F%M
M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<W1A=&EC("1O8FIE8W0["@H@
M("`@("`@(&EF("@A:7-S970H)&]B:F5C="DI('L*("`@("`@("`@("`@)&]B
M:F5C="`](&YE=R!)34%07U-E87)C:"@D<&%R86US*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D;V)J96-T.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A
M;7,@($$@:&%S:"!C;VYT86EN:6YG('1H92!F;VQL;W=I;F<@96YT<FEE<SH\
M<')E/@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("=P;W`S)R`]/B!B
M;V]L96%N("AU<VEN9R!03U`S(&-O;FYE8W1I;VX_*0H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("=C:&%R<V5T)R`]/B!S=')I;F<@*&-H87)S970@
M;V8@<V5A<F-H('9A;'5E<RD*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`G;F]?:6UA<%]S96%R8V@G(#T^('1R=64@:68@=&AE($E-05`@<V5R=F5R
M(&1O97,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&YO="!S=7!P;W)T('1H92!C:&%R<V5T(&EN"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@
M<V5A<F-H(&-O;6UA;F0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`\
M+W!R93X*("`@("`J+PH@("`@9G5N8W1I;VX@24U!4%]396%R8V@H)'!A<F%M
M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D
M<&%R86US.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5A<F-H97,@;65S<V%G
M97,@8GD@04Q,(&AE861E<G,@*')A=&AE<B!T:&%N('1H92!L:6UI=&5D('-E
M="!P<F]V:61E9`H@("`@("H@8GD@:6UA<%]S96%R8V@H*2DN"B`@("`@*@H@
M("`@("H@0'!A<F%M($E-05!?4V5A<F-H7U%U97)Y("1Q=65R>2`@5&AE('-E
M87)C:"!Q=65R>2X*("`@("`J($!P87)A;2!R97-O=7)C92`D:6UA<"`@("`@
M("`@("`@($%N($E-05`@<F5S;W5R8V4@<W1R96%M+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;6)O>"`@("`@("`@("`@("`@5&AE(&YA;64@;V8@=&AE(&UA
M:6QB;W@@=&\@<V5A<F-H+B!&;W(*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(%!/4#,L('1H:7,@<VAO=6QD(&)E(&5M<'1Y+@H@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!L:7-T(&]F(&EN9&EC
M97,@=&AA="!M871C:"!T:&4@<V5A<F-H(')U;&5S(&EN('1H90H@("`@("H@
M("`@("`@("`@("`@("`@8W5R<F5N="!M86EL8F]X+@H@("`@("H@("`@("`@
M("`@("`@("`@4F5T=7)N<R!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!S96%R8VA-86EL8F]X*"1Q=65R>2P@)&EM87`L("1M
M8F]X*0H@("`@>PH@("`@("`@("\J($-H96-K(&9O<B!)34%0(&5X=&5N<VEO
M;BX@*B\*("`@("`@("!I9B`H(55T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G:6UA
M<"<I*2!["B`@("`@("`@("`@($AO<F1E.CIF871A;"A014%2.CIR86ES945R
M<F]R*")4:&ES(&9U;F-T:6]N(')E<75I<F5S("=I;6%P)R!T;R!B92!B=6EL
M="!I;G1O(%!(4"XB*2P@7U]&24Q%7U\L(%]?3$E.15]?+"!F86QS92D["B`@
M("`@("`@?0H*("`@("`@("`O*B!/<&5N('1O('1H92!C;W)R96-T(&UA:6QB
M;W@N("HO"B`@("`@("`@:68@*"$D=&AI<RT^7W!A<F%M<ULG<&]P,R==*2![
M"B`@("`@("`@("`@(&EF("@A0&EM87!?<F5O<&5N*"1I;6%P+"`D;6)O>"P@
M3U!?4D5!1$].3%DI*2!["B`@("`@("`@("`@("`@("!R971U<FX@87)R87DH
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@0VQE87(@
M=&AE('-E87)C:"!F;&%G+B`J+PH@("`@("`@("1T:&ES+3Y?<V5A<F-H9FQA
M9R`](#`["@H@("`@("`@(')E='5R;B`D=&AI<RT^7W-E87)C:$UA:6QB;W@H
M)'%U97)Y+"`D:6UA<"P@)&UB;W@I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4V5A<F-H97,@=&AE(&UA:6QB;W@@86YD('-O<G1S('1H92!R97-U;'1S+@H@
M("`@("H*("`@("`J($!P87)A;2!)34%07U-E87)C:%]1=65R>2`D<75E<GD@
M(%1H92!S96%R8V@@<75E<GDN"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)&EM
M87`@("`@("`@("`@("!!;B!)34%0(')E<V]U<F-E('-T<F5A;2X*("`@("`J
M($!P87)A;2!S=')I;F<@)&UB;W@@("`@("`@("`@("`@(%1H92!N86UE(&]F
M('1H92!M86EL8F]X('1O('-E87)C:"X*("`@("`J($!P87)A;2!I;G1E9V5R
M("1S;W)T8GD@("`@("`@("`@(%1H92!C<FET97)I82!T;R!S;W)T(&)Y("AS
M964*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EM
M87!?<V]R="@I*2X*("`@("`J($!P87)A;2!I;G1E9V5R("1S;W)T9&ER("`@
M("`@("`@(#$@9F]R(')E=F5R<V4@<V]R=&EN9RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!4:&4@;&ES="!O9B!I;F1I8V5S('1H870@;6%T8V@@
M=&AE('-E87)C:"!R=6QE<R!I;B!T:&4*("`@("`J("`@("`@("`@("`@("`@
M(&-U<G)E;G0@;6%I;&)O>"!A;F0@<V]R=&5D+@H@("`@("H@("`@("`@("`@
M("`@("`@4F5T=7)N<R!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!S96%R8VA3;W)T36%I;&)O>"@D<75E<GDL("1I;6%P+"`D
M;6)O>"P@)'-O<G1B>2P@)'-O<G1D:7(@/2`P*0H@("`@>PH@("`@("`@("1I
M;F1I8V5S(#T@)'1H:7,M/G-E87)C:$UA:6QB;W@H)'%U97)Y+"`D:6UA<"P@
M)&UB;W@I.PH@("`@("`@(&EF("AI<U]A*"1I;F1I8V5S+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D:6YD:6-E<SL*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D:6YD:6-E<U]S;W)T(#T@0&EM87!?<V]R
M="@D:6UA<"P@)'-O<G1B>2P@)'-O<G1D:7(L(%-%7U5)1"D["B`@("`@("`@
M("`@(')E='5R;B!A<G)A>5]V86QU97,H87)R87E?:6YT97)S96-T*"1I;F1I
M8V5S7W-O<G0L("1I;F1I8V5S*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@26YT97)N86P@=W)A<'!E<B!M971H;V0@=&\@:6UA<%]S96%R
M8V@@=&AA="!A;&QO=W,@8VAA<G-E="!A=V%R90H@("`@("H@<V5A<F-H97,@
M:68@879A:6QA8FQE+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("HO"B`@("!F=6YC=&EO;B!?:6UA<%-E87)C:"@D:6UA<"P@)&-R:71E
M<FEA*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;
M)V-H87)S970G72DI('L*("`@("`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?
M<&%R86US6R=N;U]I;6%P7V-H87)S970G72D@)B8*("`@("`@("`@("`@("`@
M('9E<G-I;VY?8V]M<&%R92AP:'!V97)S:6]N*"DL("<T+C,N,R<L("<^/2<I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@0&EM87!?<V5A<F-H*"1I;6%P
M+"`D8W)I=&5R:6$L(%-%7U5)1"P@)'1H:7,M/E]P87)A;7-;)V-H87)S970G
M72D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D8W)I
M=&5R:6$@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1C<FET97)I82P@)'1H
M:7,M/E]P87)A;7-;)V-H87)S970G72P@)U53+4%30TE))RD["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!`:6UA<%]S96%R8V@H
M)&EM87`L("1C<FET97)I82P@4T5?54E$*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($EN=&5R;F%L(&9U;F-T:6]N('1O('-E87)C:"!T:&4@;6%I;&)O>"X*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N
M8W1I;VX@7W-E87)C:$UA:6QB;W@H)'%U97)Y+"`D:6UA<"P@)&UB;W@I"B`@
M("!["B`@("`@("`@)&EN9&EC97,@/2!A<G)A>2@I.PH*("`@("`@("`D=&AI
M<RT^7W-E87)C:&9L86<@/2`P.PH*("`@("`@("`O*B!$;R!T:&4@<VEM<&QE
M('-E87)C:&5S('1H870@:6UA<%]S96%R8V@H*2!C86X@:&%N9&QE+B`J+PH@
M("`@("`@(&EF("@H)&]B(#T@)'%U97)Y+3YB=6EL9"@I*2D@>PH@("`@("`@
M("`@("!I9B`H)&]B+3YN;W0I('L*("`@("`@("`@("`@("`@(&EF("@A*"1I
M;F1I8V5S,2`]("1T:&ES+3Y?:6UA<%-E87)C:"@D:6UA<"P@)&]B+3YF;&%G
M<RDI*2!["B`@("`@("`@("`@("`@("`@("`@)&EN9&EC97,Q(#T@87)R87DH
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@A*"1I
M;F1I8V5S,B`]("1T:&ES+3Y?:6UA<%-E87)C:"@D:6UA<"P@)&]B+3YQ=65R
M>2DI*2!["B`@("`@("`@("`@("`@("`@("`@)&EN9&EC97,R(#T@87)R87DH
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1I;F1I8V5S
M(#T@87)R87E?9&EF9B@D:6YD:6-E<S$L("1I;F1I8V5S,BD["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("!I9B`H(2@D:6YD:6-E<R`]
M("1T:&ES+3Y?:6UA<%-E87)C:"@D:6UA<"P@)&]B+3YF=6QL<75E<GDI*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1I;F1I8V5S(#T@87)R87DH*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@
M4V5T('1H92!S96%R8V@@9FQA9RX@*B\*("`@("`@("`@("`@:68@*"1T:&ES
M+3Y?<V5A<F-H9FQA9R`]/2`P*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7W-E87)C:&9L86<@/2`Q.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("`O*B!0<F]C97-S(&5X=&5N9&5D('-E87)C:&5S+B`J+PH@("`@("`@
M(&EF("@H)&5X=&5N9&5D(#T@)'%U97)Y+3YE>'1E;F1E9%-E87)C:"@I*2D@
M>PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]S96%R8VA02%`H)&5X
M=&5N9&5D+"`D<75E<GDM/F9L86=S*"DL("1I;6%P+"`D;6)O>"D["B`@("`@
M("`@("`@("\J(%-E="!T:&4@<V5A<F-H(&9L86<N("HO"B`@("`@("`@("`@
M(&EF("@D=&AI<RT^7W-E87)C:&9L86<@/3T@,"D@>PH@("`@("`@("`@("`@
M("`@)&EN9&EC97,@/2`D<F5S=6QT.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]S96%R8VAF;&%G(#T@,3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1I;F1I8V5S(#T@87)R87E?=F%L=65S*&%R<F%Y7VEN=&5R
M<V5C="@D:6YD:6-E<RP@)')E<W5L="DI.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("`O*B!0<F]C97-S('-I>F4@<V5A<F-H97,N("HO"B`@
M("`@("`@:68@*"@D<VEZ94]B(#T@)'%U97)Y+3YS:7IE4V5A<F-H*"DI*2![
M"B`@("`@("`@("`@("1O=F5R=FEE=R`]($!I;6%P7V9E=&-H7V]V97)V:65W
M*"1I;6%P+"!I;7!L;V1E*"<L)RP@)&EN9&EC97,I+"!&5%]5240I.PH@("`@
M("`@("`@("`D9G5N8R`](&-R96%T95]F=6YC=&EO;B@G)&$G+"`G<F5T=7)N
M("@D82`G("X@)'-I>F5/8BT^<VEZ96]P("X@)R`G("X@)'-I>F5/8BT^<VEZ
M92`N("<I.R<I.PH@("`@("`@("`@("`D<F5S=6QT(#T@87)R87DH*3L*("`@
M("`@("`@("`@9F]R96%C:"`H)&]V97)V:65W(&%S("1V86PI('L*("`@("`@
M("`@("`@("`@(&EF("@D9G5N8R@D=F%L+3YS:7IE*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1R97-U;'1;72`]("1V86PM/G5I9#L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)'1H:7,M/E]S
M96%R8VAF;&%G(#T](#`I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5A
M<F-H9FQA9R`](#$["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&EN9&EC
M97,@/2!A<G)A>5]V86QU97,H87)R87E?:6YT97)S96-T*"1I;F1I8V5S+"`D
M<F5S=6QT*2D["B`@("`@("`@?0H*("`@("`@("`O*B!0<F]C97-S($%.1"!S
M96%R8VAE<R!N;W<N("HO"B`@("`@("`@)&EN9&EC97,@/2`D=&AI<RT^7V1O
M06YD3W)396%R8V@H)'%U97)Y+3YA;F1396%R8V@H*2P@)&EM87`L("1M8F]X
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A
M;F0G+"`D:6YD:6-E<RD["@H@("`@("`@("\J(%!R;V-E<W,@3U(@<V5A<F-H
M97,@;F]W+B`J+PH@("`@("`@("1I;F1I8V5S(#T@)'1H:7,M/E]D;T%N9$]R
M4V5A<F-H*"1Q=65R>2T^;W)396%R8V@H*2P@)&EM87`L("1M8F]X+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=O<B<L("1I
M;F1I8V5S*3L*"B`@("`@("`@<F5T=7)N("1I;F1I8V5S.PH@("`@?0H*("`@
M("\J*@H@("`@("H@26YT97)N86P@9G5N8W1I;VX@=&\@<V5A<F-H('1H92!M
M86EL8F]X+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO
M"B`@("!F=6YC=&EO;B!?9&]!;F1/<E-E87)C:"@D<75E<GDL("1I;6%P+"`D
M;6)O>"P@)&UO9&4L("1I;F1I8V5S+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&)A<V4@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H96UP='DH
M)'%U97)Y*2D@>PH@("`@("`@("`@("!R971U<FX@)&EN9&EC97,["B`@("`@
M("`@?0H*("`@("`@("!F;W)E86-H("@D<75E<GD@87,@)'9A;"D@>PH@("`@
M("`@("`@("!I9B`H:7-?82@D=F%L+"`G24U!4%]396%R8VA?475E<GDG*2D@
M>PH@("`@("`@("`@("`@("`@)'!R979S96%R8V@@/2`H96UP='DH)&EN9&EC
M97,I("8F("@D=&AI<RT^7W-E87)C:&9L86<@/3T@,"DI.PH@("`@("`@("`@
M("`@("`@)')E<W5L="`]("1T:&ES+3Y?<V5A<F-H36%I;&)O>"@D=F%L+"`D
M:6UA<"P@)&UB;W@I.PH@("`@("`@("`@("`@("`@:68@*"1M;V1E(#T]("=A
M;F0G*2!["B`@("`@("`@("`@("`@("`@("`@+RH@268@=&AE(')E<W5L="!I
M<R!E;7!T>2!I;B!A;B!!3D0@<V5A<F-H+"!W92!K;F]W('1H870*("`@("`@
M("`@("`@("`@("`@("`@("!T:&4@96YT:7)E($%.1"!S96%R8V@@=VEL;"!B
M92!E;7!T>2!S;R!R971U<FX*("`@("`@("`@("`@("`@("`@("`@("!I;6UE
M9&EA=&5L>2X@*B\*("`@("`@("`@("`@("`@("`@("!I9B`H96UP='DH)')E
M<W5L="DI('L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y
M*"D["B`@("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@
M("`O*B!)9B!W92!H879E(')E86-H960@=&AI<R!P;VEN="P@86YD(&AA=F4@
M;F]T('!E<F9O<FUE9"!A"B`@("`@("`@("`@("`@("`@("`@("`@<V5A<F-H
M('EE="P@=V4@;75S="!U<V4@=&AE(')E<W5L=',@87,@=&AE(&EN9&EC97,*
M("`@("`@("`@("`@("`@("`@("`@("!L:7-T+B!7:71H;W5T('1H:7,@8VAE
M8VLL('1H92!I;F1I8V5S(&QI<W0@=VEL;"!A;'=A>7,*("`@("`@("`@("`@
M("`@("`@("`@("!B92!E;7!T>2!I9B!A;B!!3D0@<V5A<F-H(&ES('1H92!F
M:7)S="!S96%R8V@N("HO"B`@("`@("`@("`@("`@("`@("`@:68@*"1P<F5V
M<V5A<F-H*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1I;F1I8V5S(#T@
M)')E<W5L=#L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S96%R
M8VAF;&%G(#T@,3L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D:6YD:6-E<R`](&%R<F%Y7W9A;'5E<RAA
M<G)A>5]I;G1E<G-E8W0H)&EN9&EC97,L("1R97-U;'0I*3L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H(65M<'1Y
M*"1R97-U;'0I*2!["B`@("`@("`@("`@("`@("`@("`@)&EN9&EC97,@/2!A
M<G)A>5]U;FEQ=64H87)R87E?;65R9V4H)&EN9&EC97,L("1R97-U;'0I*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1I;F1I8V5S(#T@)'1H:7,M/E]D;T%N9$]R4V5A<F-H*"1V
M86PL("1I;6%P+"`D;6)O>"P@)&UO9&4L("1I;F1I8V5S*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;F1I8V5S.PH@("`@
M?0H*("`@("\J*@H@("`@("H@57-E<R!02%`@8F%S960@9G5N8W1I;VYS('1O
M('!E<F9O<FT@=&AE('-E87)C:"X*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1D0VQA<W,@)&EM87!?<75E
M<GD@(%-E87)C:"!Q=65R>2X*("`@("`J($!P87)A;2!S=')I;F<@)&9L86=S
M("`@("`@("`@06YY(&%D9&ET:6]N86P@9FQA9W,N"B`@("`@*B!`<&%R86T@
M<F5S;W5R8V4@)&EM87`@("`@("`@($%N($E-05`@<F5S;W5R8V4@<W1R96%M
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;6)O>"`@("`@("`@("!4:&4@;F%M
M92!O9B!T:&4@<V5A<F-H(&UA:6QB;W@N"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@5&AE(&QI<W0@;V8@:6YD:6-E<R!T:&%T(&UA=&-H+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?<V5A<F-H4$A0*"1I;6%P7W%U97)Y+"`D9FQA
M9W,L("1I;6%P+"`D;6)O>"D*("`@('L*("`@("`@("`D:6YD:6-E<R`](&%R
M<F%Y*"D["@H@("`@("`@(&EF("AE;7!T>2@D9FQA9W,I*2!["B`@("`@("`@
M("`@("1F;&%G<R`]("=!3$PG.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E
M;7!T>2@D=&AI<RT^7W!A<F%M<ULG<&]P,R==*2D@>PH@("`@("`@("`@("`D
M;6)O>"`]("=03U`S)SL*("`@("`@("!]"@H@("`@("`@("1C86-H95]K97D@
M/2`D;6)O>"`N("=\)R`N("1F;&%G<SL*"B`@("`@("`@+RH@5V4@:&%V92!T
M;R!U<V4@<&%R<V5-24U%2&5A9&5R<R@I('1O(&=E="!E86-H(&AE861E<B!A
M;F0@<V5E(&EF(&%N>0H@("`@("`@("`J(&9I96QD(&UA=&-H97,N(%5S92!I
M;6%P7W-E87)C:"@I('1O(&=E="!T:&4@;&ES="!O9B!M97-S86=E(&EN9&EC
M97,*("`@("`@("`@*B!O<B!R971U<FX@96UP='D@;&ES="!I9B!N;R!S96%R
M8V@@<F5S=6QT<RX@*B\*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<F5S
M=6QT6R1C86-H95]K97E=*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W)E<W5L
M=%LD8V%C:&5?:V5Y72`]($!I;6%P7W-E87)C:"@D:6UA<"P@)&9L86=S+"!3
M15]5240I.PH@("`@("`@('T*"B`@("`@("`@+RH@268@96UP='D@;65S<V%G
M92!L:7-T+"!R971U<FX@;F]W+B`J+PH@("`@("`@(&EF("AE;7!T>2@D=&AI
M<RT^7W)E<W5L=%LD8V%C:&5?:V5Y72DI('L*("`@("`@("`@("`@<F5T=7)N
M(&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("!I;F-L=61E7V]N8V4@)TAO
M<F1E+TU)344O4W1R=6-T=7)E+G!H<"<["@H@("`@("`@(&EF("@A:7-S970H
M)'1H:7,M/E]H96%D97)S6R1M8F]X72DI('L*("`@("`@("`@("`@)'1H:7,M
M/E]H96%D97)S6R1M8F]X72`](&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@
M("`O*B!'970@=&AE(&AE861E<B]Q=65R>2!T;R!S96%R8V@@9F]R+B`J+PH@
M("`@("`@("1Q=65R>2`](')E<V5T*"1I;6%P7W%U97)Y+3YQ=65R>2D["B`@
M("`@("`@)&ME>2`]('-T<G1O;&]W97(H:V5Y*"1I;6%P7W%U97)Y+3YQ=65R
M>2DI.PH*("`@("`@("!F;W)E86-H("@D=&AI<RT^7W)E<W5L=%LD8V%C:&5?
M:V5Y72!A<R`D:6YD97@I('L*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI
M<RT^7VAE861E<G-;)&UB;WA=6R1I;F1E>%TI*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7VAE861E<G-;)&UB;WA=6R1I;F1E>%T@/2!-24U%7U-T<G5C
M='5R93HZ<&%R<V5-24U%2&5A9&5R<RA`:6UA<%]F971C:&AE861E<B@D:6UA
M<"P@)&EN9&5X+"!&5%]5240I+"!N=6QL+"!T<G5E*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D:"`]("8D=&AI<RT^7VAE861E<G-;)&UB;WA=6R1I
M;F1E>%T["@H@("`@("`@("`@("`O*B!792!N965D('1O(&1O(&$@8V%S92!I
M;G-E;G-I=&EV92!S96%R8V@@;VX@=&5X="!B96-A=7-E+"!F;W(*("`@("`@
M("`@("`@("H@97AA;7!L92P@92UM86EL(&%D9')E<W-E<R!M87D@;F]T(&)E
M(&-A=6=H="!C;W)R96-T;'D*("`@("`@("`@("`@("H@*&9I;'1E<FEN9R!F
M;W(@97AA;7!L94!E>&%M<&QE+F-O;2!W:6QL(&YO="!C871C:`H@("`@("`@
M("`@("`@*B!E>$%M<&QE0&5X86UP;&4N8V]M*2X@*B\*("`@("`@("`@("`@
M)&UA=&-H7W-U8V-E<W,@/2!F86QS93L*("`@("`@("`@("`@:68@*&ES<V5T
M*"1H6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@)&AD<E]A<G)A>2`]("AI
M<U]A<G)A>2@D:%LD:V5Y72DI(#\@)&A;)&ME>5T@.B!A<G)A>2@D:%LD:V5Y
M72D["B`@("`@("`@("`@("`@("!F;W)E86-H("@D:&1R7V%R<F%Y(&%S("1V
M86PI('L*("`@("`@("`@("`@("`@("`@("!I9B`H<W1R:7-T<B@D=F%L+"!S
M=')V86PH)'%U97)Y*2D@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1M871C:%]S=6-C97-S(#T@=')U93L*("`@("`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@H)&EM
M87!?<75E<GDM/FYO="`F)B`A)&UA=&-H7W-U8V-E<W,I('Q\"B`@("`@("`@
M("`@("`@("`H(21I;6%P7W%U97)Y+3YN;W0@)B8@)&UA=&-H7W-U8V-E<W,I
M*2!["B`@("`@("`@("`@("`@("`D:6YD:6-E<UM=(#T@)&EN9&5X.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EN9&EC97,[
M"B`@("!]"@I]"@HO*BH*("H@5&AE($E-05!?4V5A<F-H7T]B:F5C=#HZ(&-L
M87-S(&ES('5S960@=&\@9F]R;75L871E('%U97)I97,@=&\@8F4@=7-E9"!W
M:71H"B`J('1H92!)34%07U-E87)C:#HZ(&-L87-S+@H@*@H@*B!`875T:&]R
M("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE
M9'4^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95])
M34%0"B`J+PIC;&%S<R!)34%07U-E87)C:%]1=65R>2!["@H@("`@=F%R("1?
M86YD(#T@87)R87DH*3L*("`@('9A<B`D7V5X=&5N9&5D4V5A<F-H(#T@87)R
M87DH*3L*("`@('9A<B`D7V9L86=S(#T@87)R87DH*3L*("`@('9A<B`D7VYO
M="`](&9A;'-E.PH@("`@=F%R("1?;W(@/2!A<G)A>2@I.PH@("`@=F%R("1?
M<75E<GD@/2!N=6QL.PH@("`@=F%R("1?<VEZ92`](&YU;&P["B`@("!V87(@
M)%]S:7IE;W`@/2!N=6QL.PH*("`@(&9U;F-T:6]N($E-05!?4V5A<F-H7U%U
M97)Y*"D*("`@('L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86YY
M(&5X=&5N9&5D('-E87)C:&5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>'1E
M;F1E9%-E87)C:"@I"B`@("!["B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^
M7V5X=&5N9&5D4V5A<F-H*2D@>PH@("`@("`@("`@("`D<V5A<F-H(#T@)FYE
M=R!S=&1#;&%S<SL*("`@("`@("`@("`@)'-E87)C:"T^;F]T(#T@)'1H:7,M
M/E]N;W0["B`@("`@("`@("`@("1S96%R8V@M/G%U97)Y(#T@)'1H:7,M/E]E
M>'1E;F1E9%-E87)C:#L*("`@("`@("`@("`@<F5T=7)N("1S96%R8V@["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<&%R86UE
M=&5R<R!F;W(@82!S:7IE('-E87)C:"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<VEZ95-E87)C:"@I"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)'1H:7,M
M/E]S:7IE*2D@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]
M"B`@("`@("`@)&]B(#T@)FYE=R!S=&1#;&%S<SL*("`@("`@("`D;V(M/G-I
M>F4@/2`H9FQO870I)'1H:7,M/E]S:7IE.PH@("`@("`@("1O8BT^<VEZ96]P
M(#T@)'1H:7,M/E]S:7IE;W`["@H@("`@("`@(')E='5R;B`D;V(["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N>2!!3D0@<V5A<F-H97,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&%N9%-E87)C:"@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?86YD.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!A;GD@3U(@<V5A<F-H97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&]R
M4V5A<F-H*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]O<CL*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&9L86=S+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!F;&%G<R@I"B`@("!["B`@("`@("`@<F5T=7)N("@H
M96UP='DH)'1H:7,M/E]F;&%G<RDI(#\@)R<@.B!I;7!L;V1E*"<@)RP@)'1H
M:7,M/E]F;&%G<RDI.PH@("`@?0H*("`@("\J*@H@("`@("H@0G5I;&1S('1H
M92!)34%0('-E87)C:"!Q=65R>2X*("`@("`J+PH@("`@9G5N8W1I;VX@8G5I
M;&0H*0H@("`@>PH@("`@("`@("1S96%R8V@@/2`F;F5W('-T9$-L87-S.PH*
M("`@("`@("`D<V5A<F-H+3YN;W0@/2`D=&AI<RT^7VYO=#L*("`@("`@("`D
M<V5A<F-H+3YF;&%G<R`]("1T:&ES+3YF;&%G<R@I.PH*("`@("`@("!I9B`H
M96UP='DH)'1H:7,M/E]Q=65R>2DI('L*("`@("`@("`@("`@:68@*"%E;7!T
M>2@D=&AI<RT^7V]R*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("<G.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1S96%R8V@M/G%U97)Y(#T@)T%,
M3"<["B`@("`@("`@("`@("1S96%R8V@M/FYO="`](&9A;'-E.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(&EF("@D<V5A<F-H+3YN;W0@)B8@96UP
M='DH)'-E87)C:"T^9FQA9W,I*2!["B`@("`@("`@("`@("`@("`D<V5A<F-H
M+3YF;&%G<R`]("=!3$PG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1S
M96%R8V@M/G%U97)Y(#T@)'1H:7,M/E]Q=65R>3L*("`@("`@("!]"B`@("`@
M("`@)'-E87)C:"T^9G5L;'%U97)Y(#T@*"%E;7!T>2@D<V5A<F-H+3YF;&%G
M<RD@/R`D<V5A<F-H+3YF;&%G<R`N("<@)R`Z("<G*2`N("1S96%R8V@M/G%U
M97)Y.PH*("`@("`@("!R971U<FX@)'-E87)C:#L*("`@('T*"B`@("`O*B!)
M34%0('-E87)C:"!M;V1I9FEE<G,N("HO"B`@("!F=6YC=&EO;B!?;6]D:69I
M97)S*"1O8BP@)&-M9"D*("`@('L*("`@("`@("!I9B`H:7-?82@D;V(L("=)
M34%07U-E87)C:%]1=65R>2<I*2!["B`@("`@("`@("`@("1O8B`](&%R<F%Y
M*"1O8BD["B`@("`@("`@?0H@("`@("`@(&%R<F%Y7W!U<V@H)'1H:7,M/B1C
M;60L("1O8BD["B`@("!]"@H@("`@9G5N8W1I;VX@:6UA<$%N9"@D;V(I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]M;V1I9FEE<G,H)&]B+"`G7V%N9"<I.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&EM87!/<B@D;V(I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]M;V1I9FEE<G,H)&]B+"`G7V]R)RD["B`@("!]"@H@("`@+RH@
M24U!4"!396%R8V@@1FQA9W,N("HO"B`@("`O*B!4:&5R92!I<R!N;R!N965D
M('1O('-U<'!O<G0@=&AE($M%65=/4D0O54Y+15E73U)$('%U97)Y('-I;F-E
M('1H90H@("`@("`@:6YD:79I9'5A;"!K97EW;W)D<R!H879E(&ED96YT:6-A
M;"!F=6YC=&EO;F%L:71Y+B`J+PH@("`@9G5N8W1I;VX@7VEM87!&;&%G<R@D
M9FQA9RP@)&-M9"D*("`@('L*("`@("`@("`D8VUD(#T@*"1F;&%G*2`_("1C
M;60@.B`G54XG("X@)&-M9#L*("`@("`@("`D=&AI<RT^7V9L86=S6UT@/2`D
M8VUD.PH@("`@?0H*("`@(&9U;F-T:6]N(&%N<W=E<F5D*"1F;&%G*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?:6UA<$9L86=S*"1F;&%G+"`G04Y35T52140G
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!D96QE=&5D*"1F;&%G*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?:6UA<$9L86=S*"1F;&%G+"`G1$5,151%1"<I.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&9L86=G960H)&9L86<I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]I;6%P1FQA9W,H)&9L86<L("=&3$%'1T5$)RD["B`@("!]
M"@H@("`@9G5N8W1I;VX@<V5E;B@D9FQA9RD*("`@('L*("`@("`@("`D=&AI
M<RT^7VEM87!&;&%G<R@D9FQA9RP@)U-%14XG*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!R96-E;G0H)&9L86<I"B`@("!["B`@("`@("`@)'1H:7,M/E]I;6%P
M1FQA9W,H=')U92P@*"@D9FQA9RD@/R`G4D5#14Y4)R`Z("=/3$0G*2D["B`@
M("!]"@H@("`@9G5N8W1I;VX@:6UA<$YE=R@I"B`@("!["B`@("`@("`@)'1H
M:7,M/E]I;6%P1FQA9W,H=')U92P@)TY%5R<I.PH@("`@?0H*("`@("\J($E-
M05`@2&5A9&5R(%-E87)C:"X@*B\*("`@(&9U;F-T:6]N(&AE861E<B@D:&5A
M9&5R+"`D<75E<GDL("1N;W0@/2!F86QS92D*("`@('L*("`@("`@("`D:&5A
M9&5R(#T@=6-F:7)S="AR=')I;2@D:&5A9&5R+"`G.B<I*3L*("`@("`@("`D
M<W1D2&1R<R`](&%R<F%Y*"=4;R<L("=#8R<L("=&<F]M)RP@)U-U8FIE8W0G
M*3L*("`@("`@("!I9B`H)'%U97)Y("$]("<G*2!["B`@("`@("`@("`@(&EF
M("AI;E]A<G)A>2@D:&5A9&5R+"`D<W1D2&1R<RDI('L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<75E<GD@/2!3=')I;F<Z.G5P<&5R*"1H96%D97(I("X@
M)R`B)R`N(&%D9'-L87-H97,H)'%U97)Y*2`N("<B)SL*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?97AT96YD961396%R
M8VA;)&AE861E<ET@/2`D<75E<GD["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'1H:7,M/E]N;W0@/2`D;F]T.PH@("`@("`@('T*("`@('T*"B`@("`O
M*B!)34%0($1A=&4@4V5A<F-H+B`J+PH@("`@9G5N8W1I;VX@7VEM87!$871E
M*"1D87DL("1M;VYT:"P@)'EE87(L("1C;60I"B`@("!["B`@("`@("`@)'1H
M:7,M/E]Q=65R>2`]("1C;60@+B`G("<@+B!D871E*")D+4TM>2(L(&UK=&EM
M92@P+"`P+"`P+"`D;6]N=&@L("1D87DL("1Y96%R*2D["B`@("!]"@H@("`@
M9G5N8W1I;VX@8F5F;W)E*"1D87DL("1M;VYT:"P@)'EE87(I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]I;6%P1&%T92@D9&%Y+"`D;6]N=&@L("1Y96%R+"`G
M0D5&3U)%)RD["B`@("!]"@H@("`@9G5N8W1I;VX@<VEN8V4H)&1A>2P@)&UO
M;G1H+"`D>65A<BD*("`@('L*("`@("`@("`D=&AI<RT^7VEM87!$871E*"1D
M87DL("1M;VYT:"P@)'EE87(L("=324Y#12<I.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&]N*"1D87DL("1M;VYT:"P@)'EE87(I"B`@("!["B`@("`@("`@)'1H
M:7,M/E]I;6%P1&%T92@D9&%Y+"`D;6]N=&@L("1Y96%R+"`G3TXG*3L*("`@
M('T*"B`@("`O*B!)34%0(%1E>'0@<V5A<F-H97,N("HO"B`@("!F=6YC=&EO
M;B!B;V1Y*"1Q=65R>2P@)&YO="`](&9A;'-E*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?<75E<GD@/2`G0D]$62`B)R`N("1Q=65R>2`N("<B)SL*("`@("`@
M("`D=&AI<RT^7VYO="`]("1N;W0["B`@("!]"@H@("`@9G5N8W1I;VX@=&5X
M="@D<75E<GDL("1N;W0@/2!F86QS92D*("`@('L*("`@("`@("`D=&AI<RT^
M7W%U97)Y(#T@)U1%6%0@(B<@+B`D<75E<GD@+B`G(B<["B`@("`@("`@)'1H
M:7,M/E]N;W0@/2`D;F]T.PH@("`@?0H*("`@("\J($E-05`@4VEZ92!S96%R
M8VAE<RX@*B\*("`@(&9U;F-T:6]N('-I>F4H)'-I>F4L("1O<&5R871O<BD*
M("`@('L*("`@("`@("`D=&AI<RT^7W-I>F4@/2`D<VEZ93L*("`@("`@("`D
M=&AI<RT^7W-I>F5O<"`]("1O<&5R871O<CL*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92])34%0+U1R964N<&AP````
M````````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#$V-30Q,R`Q,#4Q
M-30S,S<S-B`P,C$U,C$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RH@0V]N<W1A;G1S(&9O<B!M86EL8F]X16QT
M(&%T=')I8G5T97,N"B`J($%L;"!V97)S:6]N<R!O9B!C+6-L:65N="`H8RUC
M;&EE;G0O;6%I;"YH*2!D969I;F4@=&AE<V4@8V]N<W1A;G1S.@H@*B`@($Q!
M5%1?3D])3D9%4DE/4E,@*&QO;F<I(#!X,2`](#$*("H@("!,05147TY/4T5,
M14-4("AL;VYG*2`P>#(@/2`R"B`J("`@3$%45%]-05)+140@*&QO;F<I(#!X
M-"`](#0*("H@("!,05147U5.34%22T5$("AL;VYG*2`P>#@@/2`X"B`J"B`J
M($YE=V5R('9E<G-I;VYS(&]F(&,M8VQI96YT("AI;6%P+3(P,#(@86YD(&=R
M96%T97(I(&1E9FEN92!T:&5S92!C;VYS=&%N=',Z"B`J("`@3$%45%]2149%
M4E)!3"`H;&]N9RD@,'@Q,"`](#$V"B`J("`@3$%45%](05-#2$E,1%)%3B`H
M;&]N9RD@,'@R,"`](#,R"B`J("`@3$%45%](05-.3T-(24Q$4D5.("AL;VYG
M*2`P>#0P(#T@-C0*("H@+BXN8G5T('1H97-E(&-O;G-T86YT(&YA;65S(&1O
M(&YO="!A<'!E87(@:6X@4$A0('5N=&EL(%!(4"`T+C,N-2!A;F0@-2XP+@H@
M*B\*:68@*"%D969I;F5D*"=,05147TA!4T-(24Q$4D5.)RDI('L*("`@($!D
M969I;F4H)TQ!5%1?4D5&15)204PG+"`Q-BD["B`@("!`9&5F:6YE*"=,0514
M7TA!4T-(24Q$4D5.)RP@,S(I.PH@("`@0&1E9FEN92@G3$%45%](05-.3T-(
M24Q$4D5.)RP@-C0I.PI]"@HO*B!3=&%R="!A="`Q,C@@9F]R(&]U<B!L;V-A
M;"!B:71M87-K<R!T;R!A;&QO=R!F;W(@=&AE(&,M8VQI96YT($Q!5%1?*@H@
M("!C;VYS=&%N=',N("HO"F1E9FEN92@G24U!4%12145?14Q47TA!4U]#2$E,
M1%)%3B<L(#$R."D[("\O($1%4%)%0T%4140*9&5F:6YE*"=)34%05%)%15]%
M3%1?25-?3U!%3B<L(#(U-BD["F1E9FEN92@G24U!4%12145?14Q47TE37U-5
M0E-#4DE"140G+"`U,3(I.PID969I;F4H)TE-05!44D5%7T5,5%])4U]$25-#
M3U9%4D5$)RP@,3`R-"D["F1E9FEN92@G24U!4%12145?14Q47TE37U!/3$Q%
M1"<L(#(P-#@I.PID969I;F4H)TE-05!44D5%7T5,5%].145$7U-/4E0G+"`T
M,#DV*3L*+R\@)S@Q.3(G(&ES('5S960@8GD@24U0(#0N>"!S;R!D;R!N;W0@
M=7-E(&ET(&AE<F4*9&5F:6YE*"=)34%05%)%15]%3%1?3D%-15-004-%)RP@
M,38S.#0I.PH*+RH@5&AE(&ES3W!E;B@I(&5X<&%N9&5D(&UO9&4@8V]N<W1A
M;G1S+B`J+PID969I;F4H)TE-05!44D5%7T]014Y?3D].12<L(#`I.PID969I
M;F4H)TE-05!44D5%7T]014Y?04Q,)RP@,2D["F1E9FEN92@G24U!4%12145?
M3U!%3E]54T52)RP@,BD["@HO*B!7:&EC:"!M;V1E(&]F($E-05`@86-C97-S
M(&%R92!W92!U<VEN9RX@*B\*9&5F:6YE*"=)34%05%)%15]-3T1%7TU!24PG
M+"`P*3L*9&5F:6YE*"=)34%05%)%15]-3T1%7TY%5U,G+"`Q*3L*"B\J(%1H
M92!I;FET86QI>F%T:6]N(&UO9&4@=&\@=7-E('=H96X@8W)E871I;F<@=&AE
M('1R964N("HO"F1E9FEN92@G24U!4%12145?24Y)5%]354(G+"`Q*3L*9&5F
M:6YE*"=)34%05%)%15])3DE47U5.4U5")RP@,BD["F1E9FEN92@G24U!4%12
M145?24Y)5%]&151#2$%,3"<L(#0I.PH*+RH@5&AE(&UA;FYE<B!T;R!W:&EC
M:"!T;R!T<F%V97)S92!T:&4@=')E92!W:&5N(&-A;&QI;F<@;F5X="@I+B`J
M+PID969I;F4H)TE-05!44D5%7TY%6%1?4TA/5T-,3U-%1"<L(#$I.PID969I
M;F4H)TE-05!44D5%7TY%6%1?4TA/5U-50B<L(#(I.PH*+RH@5&AE('-T<FEN
M9R!U<V5D('1O(&EN9&EC871E('1H92!B87-E(&]F('1H92!T<F5E+B`J+PID
M969I;F4H)TE-05!44D5%7T)!4T5?14Q4)RP@;G5L;"D["@HO*BH*("H@5&AE
M($E-05!?5')E92!C;&%S<R!P<F]V:61E<R!A('1R964@=FEE=R!O9B!T:&4@
M9F]L9&5R<R!S=7!P;W)T960@=VET:`H@*B!T:&4@4$A0(&EM87`@97AT96YS
M:6]N("A)34%0+U!/4#,O3DY44"!R97!O<VET;W)I97,I+B`@270@<')O=FED
M97,@86-C97-S"B`J(&9U;F-T:6]N<R!T;R!I=&5R871E('1H<F]U9V@@=&AI
M<R!T<F5E(&%N9"!Q=65R>2!I;F9O<FUA=&EO;B!A8F]U=`H@*B!I;F1I=FED
M=6%L(&UA:6QB;WAE<R]F;VQD97)S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R
M:R])34%0+TE-05`O5')E92YP:'`L=B`Q+C0X+C(N-#,@,C`P-B\P-2\Q,B`Q
M-CHR.3HR.2!S;'5S87)Z($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`P+3(P
M,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER
M:6=H="`R,#`P+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H@
M0V]P>7)I9VAT(#(P,#`M,C`P-B!!;FEL($UA9&AA=F%P961D>2`\879S;4!H
M;W)D92YO<F<^"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EC:&%E;"!3;'5S
M87)Z(#QS;'5S87)Z0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U
M=&AO<B`@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@
M06YI;"!-861H879A<&5D9'D@/&%V<VU`:&]R9&4N;W)G/@H@*B!`875T:&]R
M("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`:&]R9&4N;W)G/@H@*B!`<VEN
M8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?24U!4`H@*B\*8VQA
M<W,@24U!4%]4<F5E('L*"B`@("`O*BH*("`@("`J($%S<V]C:6%T:79E(&%R
M<F%Y(&-O;G1A:6YI;F<@=&AE(&UA:6QB;W@@=')E92X*("`@("`J"B`@("`@
M*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W1R964["@H@("`@+RHJ
M"B`@("`@*B!,;V-A=&EO;B!O9B!C=7)R96YT(&5L96UE;G0@:6X@=&AE('1R
M964N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?8W5R<G!A<F5N="`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!,;V-A=&EO
M;B!O9B!C=7)R96YT(&5L96UE;G0@:6X@=&AE('1R964N"B`@("`@*@H@("`@
M("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7V-U<G)K97D@/2!N
M=6QL.PH*("`@("\J*@H@("`@("H@3&]C871I;VX@;V8@8W5R<F5N="!E;&5M
M96YT(&EN('1H92!T<F5E+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1?8W5R<G-T86-K(#T@87)R87DH*3L*"B`@("`O*BH*
M("`@("`J(%-H;W<@=6YS=6)S8W)I8F5D(&UA:6QB;WAE<S\*("`@("`J"B`@
M("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?<VAO=W5N<W5B
M(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!087)E;G0@;&ES="X*("`@("`J
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A<F5N="`]
M(&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@8V%C:&5D(&QI<W0@;V8@
M;6%I;&)O>&5S('1O('!O;&PN"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]P;VQL(#T@;G5L;#L*"B`@("`O*BH*("`@("`J
M(%1H92!C86-H960@;&ES="!O9B!E>'!A;F1E9"!F;VQD97)S+@H@("`@("H*
M("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?97AP86YD960@
M/2!N=6QL.PH*("`@("\J*@H@("`@("H@0V%C:&5D(&QI<W0@;V8@<W5B<V-R
M:6)E9"!M86EL8F]X97,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)%]S=6)S8W)I8F5D(#T@;G5L;#L*"B`@("`O*BH*("`@
M("`J($-A8VAE9"!L:7-T(&]F('5N<W5B<V-R:6)E9"!M86EL8F]X97,N"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]U;G-U
M8G-C<FEB960@/2!N=6QL.PH*("`@("\J*@H@("`@("H@26YI="!M;V1E(&9L
M86<N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A
M<B`D7VEN:71M;V1E(#T@,#L*"B`@("`O*BH*("`@("`J(%1R964@8VAA;F=E
M9"!F;&%G+B`@4V5T('=H96X@<V]M971H:6YG(&EN('1H92!T<F5E(&AA<R!B
M965N(&%L=&5R960N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@
M*B\*("`@('9A<B`D7V-H86YG960@/2!F86QS93L*"B`@("`O*BH*("`@("`J
M($AA=F4@=V4@<VAO=VX@=6YS=6)S8W)I8F5D(&9O;&1E<G,@<')E=FEO=7-L
M>3\*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R
M("1?=6YS=6)V:65W(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!4:&4@24U!
M4%]3;W)T(&]B:F5C="X*("`@("`J"B`@("`@*B!`=F%R($E-05!?4V]R=`H@
M("`@("HO"B`@("!V87(@)%]I;6%P7W-O<G0@/2!N=6QL.PH*("`@("\J*@H@
M("`@("H@26YS97)T(&%N(&5L96UE;G0@:6X@=&AE('1R964@=&AA="!D;V5S
M;B=T(&%P<&5A<B!O;B!T:&4@24U!4"!S97)V97(N"B`@("`@*B!)9B!S970L
M($E-05!?5')E93HZ('=I;&P@8V%L;"!?9V5T3F]N24U!4$5L="@I('1O(&]B
M=&%I;B!T:&4@96QE;65N=`H@("`@("H@=&\@861D('1O('1H92!T<F5E+@H@
M("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]N
M;VYI;6%P96QT(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!4:&4@;F%M92!T
M;R!U<V4@=VAE;B!S=&]R:6YG('1H92!O8FIE8W0@:6X@=&AE('-E<W-I;VXN
M"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?
M8V%C:&5N86UE.PH*("`@("\J*@H@("`@("H@5&AE(&%P<&QI8V%T:6]N('1H
M870@9V5N97)A=&5D('1H:7,@=')E92X*("`@("`J(%1(25,@4TA/54Q$($)%
M(%-%5"!)3B!%5D5262!354)#3$%34R!#3TY35%)50U1/4BX*("`@("`J"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]A<'`@/2!N=6QL
M.PH*("`@("\J*@H@("`@("H@5&AE('-E<G9E<B!S=')I;F<@9F]R('1H92!C
M=7)R96YT('-E<G9E<BX*("`@("`J(%1(25,@4TA/54Q$($)%(%-%5"!)3B!%
M5D5262!354)#3$%34R!#3TY35%)50U1/4BX*("`@("`J"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]S97)V97(@/2`G)SL*"B`@("`O
M*BH*("`@("`J(%-H;W5L9"!W92!U<V4@)VUA:6PG(&UO9&4@;W(@)VYE=W,G
M(&UO9&4_"B`@("`@*B!42$E3(%-(3U5,1"!"12!3150@24X@159%4ED@4U5"
M0TQ!4U,@0T].4U1254-43U(N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R
M"B`@("`@*B\*("`@('9A<B`D7VUO9&4@/2!N=6QL.PH*("`@("\J*@H@("`@
M("H@5&AE(&QI<W0@;V8@;F%M97-P86-E<R!T;R!A9&0@=&\@=&AE('1R964N
M"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]N
M86UE<W!A8V5S.PH@("`@+RHJ"B`@("`@*B!$;V5S('1H92!)34%0('-E<G9E
M<B!S=7!P;W)T('1H92!C:&EL9')E;B!E>'1E;G-I;VX_"B`@("`@*@H@("`@
M("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7V-H:6QD<F5N<W5P
M<&]R="`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!5<V5D('1O(&1E=&5R;6EN
M92!T:&4@;&ES="!O9B!E;&5M96YT(&-H86YG97,N"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]E;'1D:69F(#T@;G5L;#L*
M"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(')E9F5R96YC
M92!T;R!A(&-O;F-R971E($E-05!?5')E92!I;G-T86YC92X*("`@("`J"B`@
M("`@*B!)9B!A;B!)34%07U1R964@;V)J96-T(&ES(&-U<G)E;G1L>2!S=&]R
M960@:6X@=&AE(&QO8V%L('-E<W-I;VXL"B`@("`@*B!R96-R96%T92!T:&%T
M(&]B:F5C="X@($5L<V4L(&EF("1C<F5A=&4@:7,@=')U92P@=VEL;"!C<F5A
M=&4@82!N97<*("`@("`J(&EN<W1A;F-E+B`@16YS=7)E<R!T:&%T(&]N;'D@
M;VYE($E-05!?5')E92!I;G-T86YC92!I<R!A=F%I;&%B;&4*("`@("`J(&%T
M(&%N>2!T:6UE+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@
M:6YV;VME9"!A<SH\<')E/@H@("`@("H@("`D:6UA<%]T<F5E(#T@)DE-05!?
M5')E93HZ<VEN9VQE=&]N*"1A<'`L("1C;&%S<VYA;64L(%LD8W)E871E6RP@
M)'5N<W5B75TI.SPO<')E/@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&%P<"`@("`@("`@5&AE(&-U<G)E;G0@87!P;&EC871I;VX@;F%M92X*("`@
M("`J($!P87)A;2!S=')I;F<@)&-L87-S;F%M92`@5&AE(&-L87-S(&YA;64@
M=&\@=7-E('=H96X@:6YS=&%N=&EA=&EN9R!A(&YE=PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("!O8FIE8W0N"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D8W)E871E("`@($-R96%T92!A(&YE=R!)34%07U1R964@:68@:70@
M9&]E<VXG="!E>&ES="!I;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("!T:&4@<V5S<VEO;C\*("`@("`J($!P87)A;2!I;G1E9V5R("1I;FET
M("`@("`@5&AE(&EN:71I86QI>F%T:6]N(&UO9&4@=&\@=7-E+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D8V%C:&5N86UE("!4:&4@;F%M92!T;R!U<V4@=VAE
M;B!S=&]R:6YG(&EN('1H92!S97-S:6]N+@H@("`@("H*("`@("`J($!R971U
M<FX@24U!4%]4<F5E("!4:&4@24U!4%]4<F5E(&]B:F5C="!O<B!N=6QL+@H@
M("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1A<'`L("1C;&%S<VYA
M;64L("1C<F5A=&4@/2!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@
M)&EN:70@/2!)34%05%)%15])3DE47U-50BP@)&-A8VAE;F%M92`]("=I;6%P
M=')E92<I"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T86YC92`](&%R<F%Y
M*"D["@H@("`@("`@(&EF("AI<W-E="@D:6YS=&%N8V5;)&%P<%TI*2!["B`@
M("`@("`@("`@(')E='5R;B`D:6YS=&%N8V5;)&%P<%T["B`@("`@("`@?0H*
M("`@("`@("!I9B`H(65M<'1Y*"1?4T534TE/3ELD87!P75LD8V%C:&5N86UE
M72DI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]397-S:6]N
M3V)J96-T<RYP:'`G.PH@("`@("`@("`@("`D8V%C:&5397-S(#T@)DAO<F1E
M7U-E<W-I;VY/8FIE8W1S.CIS:6YG;&5T;VXH*3L*("`@("`@("`@("`@)&EN
M<W1A;F-E6R1A<'!=(#T@)B1C86-H95-E<W,M/G%U97)Y*"1?4T534TE/3ELD
M87!P75LD8V%C:&5N86UE72D["B`@("`@("`@("`@(')E9VES=&5R7W-H=71D
M;W=N7V9U;F-T:6]N*&%R<F%Y*"8D:6YS=&%N8V5;)&%P<%TL("=?<W1O<F4G
M*2D["B`@("`@("`@?2!E;'-E:68@*"1C<F5A=&4I('L*("`@("`@("`@("`@
M)&EN<W1A;F-E6R1A<'!=(#T@)FYE=R`D8VQA<W-N86UE*"1I;FET+"`D8V%C
M:&5N86UE*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6YS=&%N8V5;
M)&%P<%T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:6YI="`@("`@(%1H92!I;FET
M:6%L:7IA=&EO;B!M;V1E('1O('5S92X*("`@("`J($!P87)A;2!S=')I;F<@
M)&-A8VAE;F%M92`@5&AE(&YA;64@=&\@=7-E('=H96X@<W1O<FEN9R!I;B!T
M:&4@<V5S<VEO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@24U!4%]4<F5E*"1I
M;FET(#T@24U!4%12145?24Y)5%]354(L("1C86-H96YA;64@/2`G:6UA<'1R
M964G*0H@("`@>PH@("`@("`@(')E9VES=&5R7W-H=71D;W=N7V9U;F-T:6]N
M*&%R<F%Y*"8D=&AI<RP@)U]S=&]R92<I*3L*("`@("`@("`D=&AI<RT^7V-A
M8VAE;F%M92`]("1C86-H96YA;64["B`@("`@("`@)'1H:7,M/FEN:70H)&EN
M:70I.PH@("`@?0H*("`@("\J*@H@("`@("H@4W1O<F4@82!S97)I86QI>F5D
M('9E<G-I;VX@;V8@;W5R<V5L9B!I;B!T:&4@8W5R<F5N="!S97-S:6]N+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC
M=&EO;B!?<W1O<F4H*0H@("`@>PH@("`@("`@("\J(%=E(&]N;'D@;F5E9"!T
M;R!R97-T;W)E('1H92!O8FIE8W0@:68@=&AE('1R964@:&%S(&-H86YG960N
M("HO"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7V-H86YG960I*2!["B`@
M("`@("`@("`@("\J($1O;B=T('-T;W)E("1?97AP86YD960@86YD("1?<&]L
M;"`M('1H97-E('9A;'5E<R!A<F4@:&%N9&QE9`H@("`@("`@("`@("`@*B!B
M>2!T:&4@<W5B8VQA<W-E<RX*("`@("`@("`@("`@("H@1&]N)W0@<W1O<F4@
M)%]I;6%P7W-O<G0@;W(@)%]E;'1D:69F("T@=&AI<R!N965D<R!T;R!B90H@
M("`@("`@("`@("`@*B!R96=E;F5R871E9"!F;W(@96%C:"!R97%U97-T+@H@
M("`@("`@("`@("`@*B!$;VXG="!S=&]R92`D7V-U<G)K97DL("1?8W5R<G!A
M<F5N="P@86YD("1?8W5R<E-T86-K('-I;F-E('1H90H@("`@("`@("`@("`@
M*B!U<V5R($U54U0@8V%L;"!R97-E="@I(&)E9F]R92!C>6-L:6YG('1H<F]U
M9V@@=&AE('1R964N"B`@("`@("`@("`@("`J(%)E<V5T('1H92`D7V-H86YG
M960@9FQA9RX@*B\*("`@("`@("`@("`@)'1H:7,M/E]C=7)R:V5Y(#T@)'1H
M:7,M/E]C=7)R<&%R96YT(#T@)'1H:7,M/E]E;'1D:69F(#T@)'1H:7,M/E]E
M>'!A;F1E9"`]("1T:&ES+3Y?:6UA<%]S;W)T(#T@)'1H:7,M/E]P;VQL(#T@
M;G5L;#L*("`@("`@("`@("`@)'1H:7,M/E]C=7)R4W1A8VL@/2!A<G)A>2@I
M.PH@("`@("`@("`@("`D=&AI<RT^7V-H86YG960@/2!F86QS93L*"B`@("`@
M("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O4V5S<VEO;D]B:F5C=',N<&AP
M)SL*("`@("`@("`@("`@)&-A8VAE4V5S<R`]("9(;W)D95]397-S:6]N3V)J
M96-T<SHZ<VEN9VQE=&]N*"D["@H@("`@("`@("`@("`O*B!2975S92!O;&0@
M<V5S<VEO;B!)1"!I9B!P;W-S:6)L92X@*B\*("`@("`@("`@("`@:68@*&ES
M<V5T*"1?4T534TE/3ELD=&AI<RT^7V%P<%U;)'1H:7,M/E]C86-H96YA;65=
M*2D@>PH@("`@("`@("`@("`@("`@)&-A8VAE4V5S<RT^;W9E<G=R:71E*"1?
M4T534TE/3ELD=&AI<RT^7V%P<%U;)'1H:7,M/E]C86-H96YA;65=+"`D=&AI
M<RP@9F%L<V4I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@:68@*"%I<W-E="@D7U-%4U-)3TY;)'1H:7,M/E]A<'!=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1?4T534TE/3ELD=&AI<RT^7V%P<%T@/2!A<G)A
M>2@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)%]315-3
M24].6R1T:&ES+3Y?87!P75LD=&AI<RT^7V-A8VAE;F%M95T@/2`D8V%C:&53
M97-S+3YS=&]R94]I9"@D=&AI<RP@9F%L<V4I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&QI<W0@
M;V8@9F]L9&5R<R]M86EL8F]X97,@;6%T8VAI;F<@82!C97)T86EN('!A=&@N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE(&UA:6QB;W@@<&%T:"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!(&QI<W0@;V8@;6%I;&)O>%]O8FIE
M8W1S('=H;W-E(&YA;64@;6%T8VAE9"`D<&%T:"X*("`@("`J("`@("`@("`@
M("`@("`@(%1H92!S97)V97(@<W1R:6YG(&AA<R!B965N(')E;6]V960@9G)O
M;2!T:&4@;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$QI<W0H)'!A
M=&@I"B`@("!["B`@("`@("`@)'5N:7%U92`](&%R<F%Y*"D["@H@("`@("`@
M(&EF("@A)'1H:7,M/E]S:&]W=6YS=6(I('L*("`@("`@("`@("`@)'1H:7,M
M/E]I;FET4W5B<V-R:6)E9"@I.PH@("`@("`@('T*("`@("`@("`D;F5W8F]X
M97,@/2!`:6UA<%]G971M86EL8F]X97,H)'1H:7,M/E]G9713=')E86TH*2P@
M)'1H:7,M/E]S97)V97(L("1P871H*3L*("`@("`@("!I9B`H:7-?87)R87DH
M)&YE=V)O>&5S*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D;F5W8F]X97,@
M87,@)&)O>"D@>PH@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?<VAO=W5N
M<W5B('Q\"B`@("`@("`@("`@("`@("`@("`@(6ES<V5T*"1T:&ES+3Y?<W5B
M<V-R:6)E9%LD8F]X+3YN86UE72DI('L*("`@("`@("`@("`@("`@("`@("`O
M*B!3=')I<"!O9F8@<V5R=F5R('-T<FEN9RX@*B\*("`@("`@("`@("`@("`@
M("`@("`D8F]X(#T@)'1H:7,M/E]R96UO=F5397)V97)3=')I;F<H)&)O>"D[
M"B`@("`@("`@("`@("`@("`@("`@:68@*"1B;W@M/FYA;64@)B8@(6ES<V5T
M*"1U;FEQ=65;)&)O>"T^;F%M95TI*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1U;FEQ=65;)&)O>"T^;F%M95T@/2`D8F]X.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1U;FEQ=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!-86ME(&$@<VEN9VQE(&UA:6QB;W@@=')E92!E;&5M96YT+@H@
M("`@("H@06X@96QE;65N="!C;VYS:7-T<R!O9B!T:&4@9F]L;&]W:6YG(&ET
M96US("AW92!U<V4@<VEN9VQE(&QE='1E<G,@:&5R90H@("`@("H@=&\@<V%V
M92!I;B!S97-S:6]N('-T;W)A9V4@<W!A8V4I.@H@("`@("H@("`G82<@("TM
M("!!='1R:6)U=&5S"B`@("`@*B`@("=C)R`@+2T@($QE=F5L(&-O=6YT"B`@
M("`@*B`@("=L)R`@+2T@($QA8F5L"B`@("`@*B`@("=P)R`@+2T@(%!A<F5N
M="!N;V1E"B`@("`@*B`@("=V)R`@+2T@(%9A;'5E"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="!S
M=&1#;&%S<R`D;V(@(%1H92!O8FIE8W0@<F5T=7)N960@8GD@:6UA<%]G971M
M86EL8F]X97,H*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!3964@
M9F]R;6%T(&%B;W9E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?;6%K94UA:6QB
M;WA4<F5E16QT*"1O8BD*("`@('L*("`@("`@("`D96QT6R=A)UT@/2`D;V(M
M/F%T=')I8G5T97,["B`@("`@("`@)&5L=%LG8R==(#T@,#L*("`@("`@("`D
M96QT6R=P)UT@/2!)34%05%)%15]"05-%7T5,5#L*("`@("`@("`D96QT6R=V
M)UT@/2`D;V(M/FYA;64["@H@("`@("`@("\J(%-E="!S=6)S8W)I8F5D('9A
M;'5E<RX@36%K92!S=7)E($E.0D]8(&ES(&%L=V%Y<R!S=6)S8W)I8F5D"B`@
M("`@("`@("H@=&\@*&EF('=O<FMI;F<@=VET:"!M86EL*2!S;R!T:&5R92!I
M<R!A;'=A>7,@870@;&5A<W0@,0H@("`@("`@("`J('9I97=A8FQE(&5L96UE
M;G0N("HO"B`@("`@("`@:68@*"1E;'1;)W8G72`]/2`G24Y"3U@G*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?<V5T4W5B<V-R:6)E9"@D96QT+"!T<G5E*3L*
M("`@("`@("!](&5L<V5I9B`H(21T:&ES+3YI<U-U8G-C<FEB960H)&5L="DI
M('L*("`@("`@("`@("`@)'1H:7,M/E]I;FET4W5B<V-R:6)E9"@I.PH@("`@
M("`@("`@("`D=&AI<RT^7W-E=%-U8G-C<FEB960H)&5L="P@:7-S970H)'1H
M:7,M/E]S=6)S8W)I8F5D6R1E;'1;)W8G75TI*3L*("`@("`@("!]"@H@("`@
M("`@("\J($-H96-K(&9O<B!P;VQL960@<W1A='5S+B`J+PH@("`@("`@(&EF
M("@A)'1H:7,M/FES4&]L;&5D*"1E;'0I*2!["B`@("`@("`@("`@("1T:&ES
M+3YG9710;VQL3&ES="@I.PH@("`@("`@("`@("`D=&AI<RT^7W-E=%!O;&QE
M9"@D96QT+"!I<W-E="@D=&AI<RT^7W!O;&Q;)&5L=%LG=B==72DI.PH@("`@
M("`@('T*"B`@("`@("`@+RH@0VAE8VL@9F]R(&]P96X@<W1A='5S+B`J+PH@
M("`@("`@("1T:&ES+3Y?<V5T3W!E;B@D96QT+"`D=&AI<RT^:7-/<&5N*"1E
M;'0I*3L*"B`@("`@("`@+RH@0V]M<'5T960@=F%L=65S+B`J+PH@("`@("`@
M("1N<U]I;F9O(#T@)'1H:7,M/E]G971.86UE<W!A8V4H)&5L=%LG=B==*3L*
M("`@("`@("`D=&UP(#T@97AP;&]D92@H:7-?;G5L;"@D;G-?:6YF;RDI(#\@
M)'1H:7,M/E]D96QI;6ET97(@.B`D;G-?:6YF;ULG9&5L:6UI=&5R)UTL("1E
M;'1;)W8G72D["B`@("`@("`@)&5L=%LG8R==(#T@8V]U;G0H)'1M<"D@+2`Q
M.PH@("`@("`@("1L86)E;"`]("1E;'1;)V,G73L*("`@("`@("!I9B`H(65M
M<'1Y*"1E;'1;)V,G72D@)B8*("`@("`@("`@("`@(7!R96=?;6%T8V@H(B]<
M>RXJ<&]P,RXJ7'TO(BP@)&]B+3YF=6QL4V5R=F5R4&%T:"DI('L*("`@("`@
M("`@("`@)&5L=%LG<"==(#T@:6UP;&]D92@H:7-?;G5L;"@D;G-?:6YF;RDI
M(#\@)'1H:7,M/E]D96QI;6ET97(@.B`D;G-?:6YF;ULG9&5L:6UI=&5R)UTL
M(&%R<F%Y7W-L:6-E*"1T;7`L(#`L("1E;'1;)V,G72DI.PH@("`@("`@("`@
M("`O*B!3=')I<"!P97)S;VYA;"!N86UE<W!A8V4N("HO"B`@("`@("`@("`@
M(&EF("@A:7-?;G5L;"@D;G-?:6YF;RD@)B8*("`@("`@("`@("`@("`@("%E
M;7!T>2@D;G-?:6YF;ULG;F%M92==*2`F)@H@("`@("`@("`@("`@("`@*"1N
M<U]I;F9O6R=T>7!E)UT@/3T@)W!E<G-O;F%L)RDI('L*("`@("`@("`@("`@
M("`@("1E;'1;)V,G72TM.PH@("`@("`@("`@("`@("`@:68@*'-T<G!O<R@D
M96QT6R=P)UTL("1N<U]I;F9O6R=D96QI;6ET97(G72D@/3T](&9A;'-E*2![
M"B`@("`@("`@("`@("`@("`@("`@)&5L=%LG<"==(#T@24U!4%12145?0D%3
M15]%3%0["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H<W1R<&]S*"1E;'1;
M)W8G72P@)&YS7VEN9F];)VYA;64G72`N("=)3D)/6"<@+B`D;G-?:6YF;ULG
M9&5L:6UI=&5R)UTI(#T]/2`P*2!["B`@("`@("`@("`@("`@("`@("`@)&5L
M=%LG<"==(#T@)TE.0D]8)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@("`@("`D96QT6R=L)UT@/2!3=')I;F<Z.F-O
M;G9E<G1#:&%R<V5T*"1T;7!;)&QA8F5L72P@)U541C<M24U!4"<I.PH*("`@
M("`@("!R971U<FX@)&5L=#L*("`@('T*"B`@("`O*BH*("`@("`J($EN:71A
M;&EZ92!T:&4@;&ES="!A="!T:&4@=&]P(&QE=F5L(&]F('1H92!H:65R87)C
M:'DN"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&EN:70@(%1H92!I
M;FET:6%L:7IA=&EO;B!M;V1E+@H@("`@("HO"B`@("!F=6YC=&EO;B!I;FET
M*"1I;FET*0H@("`@>PH@("`@("`@("\J(%)E<V5T(&%L;"!C;&%S<R!V87)I
M86)L97,@=&\@=&AE(&1E9F%U;'1S+B`J+PH@("`@("`@("1T:&ES+3Y?8VAA
M;F=E9"`]('1R=64["B`@("`@("`@)'1H:7,M/E]C=7)R:V5Y(#T@;G5L;#L*
M("`@("`@("`D=&AI<RT^7V-U<G)P87)E;G0@/2!N=6QL.PH@("`@("`@("1T
M:&ES+3Y?8W5R<G-T86-K(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^7W1R
M964@/2!A<G)A>2@I.PH@("`@("`@("1T:&ES+3Y?<&%R96YT(#T@87)R87DH
M*3L*("`@("`@("`D=&AI<RT^7W-H;W=U;G-U8B`]("1T:&ES+3Y?=6YS=6)V
M:65W(#T@*"1I;FET("8@24U!4%12145?24Y)5%]53E-50BD["B`@("`@("`@
M)'1H:7,M/E]S=6)S8W)I8F5D(#T@;G5L;#L*("`@("`@("`D=&AI<RT^7W5N
M<W5B<V-R:6)E9"`](&YU;&P["@H@("`@("`@("\J(%-E="!I;FET:6%L:7IA
M=&EO;B!M;V1E+B`J+PH@("`@("`@("1T:&ES+3Y?:6YI=&UO9&4@/2`D:6YI
M=#L*"B`@("`@("`@+RH@1V5T('1H92!I;FET:6%L(&QI<W0@;V8@;6%I;&)O
M>&5S(&9R;VT@=&AE('-U8F-L87-S+B`J+PH@("`@("`@("1B;WAE<R`]("1T
M:&ES+3Y?:6YI="@I.PH*("`@("`@("`O*B!#<F5A=&4@82!P;&%C96AO;&1E
M<B!E;&5M96YT('1O('1H92!B87-E(&]F('1H92!T<F5E(&QI<W0@<V\@=V4@
M8V%N"B`@("`@("`@("H@:V5E<"!T<F%C:R!O9B!W:&5T:&5R('1H92!B87-E
M(&QE=F5L(&YE961S('1O(&)E('-O<G1E9"X@*B\*("`@("`@("`D=&AI<RT^
M7W1R965;24U!4%12145?0D%315]%3%1=(#T@87)R87DH)V$G(#T^($E-05!4
M4D5%7T5,5%])4U]$25-#3U9%4D5$*3L*"B`@("`@("`@+RH@0VAE8VL@=&\@
M;6%K92!S=7)E(&%L;"!N86UE<W!A8V4@96QE;65N=',@87)E(&EN('1H92!T
M<F5E+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7VYA;65S<&%C97,I('L*("`@
M("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]N86UE<W!A8V5S(&%S("1K97D@
M/3X@)'9A;"D@>PH@("`@("`@("`@("`@("`@:68@*"1V86Q;)W1Y<&4G72`A
M/2`G<&5R<V]N86PG*2!["B`@("`@("`@("`@("`@("`@("`@)&YA;64@/2!S
M=6)S='(H)&ME>2P@,"P@+3$@*B!S=')L96XH)'9A;%LG9&5L:6UI=&5R)UTI
M*3L*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?=')E
M95LD=F%L6R=N86UE)UU=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M;V(@/2`F;F5W('-T9$-L87-S.PH@("`@("`@("`@("`@("`@("`@("`@("`D
M;V(M/F1E;&EM:71E<B`]("1V86Q;)V1E;&EM:71E<B==.PH@("`@("`@("`@
M("`@("`@("`@("`@("`D;V(M/F%T=')I8G5T97,@/2!,05147TY/4T5,14-4
M('P@24U!4%12145?14Q47TY!34534$%#13L*("`@("`@("`@("`@("`@("`@
M("`@("`@+RH@)&]B+3YF=6QL4V5R=F5R4&%T:"!I<R!N;W0@8V]M<&QE=&5L
M>2!S970@:&5R92X@*B\*("`@("`@("`@("`@("`@("`@("`@("`@)&]B+3YF
M=6QL4V5R=F5R4&%T:"`]("1O8BT^;F%M92`]("1N86UE.PH@("`@("`@("`@
M("`@("`@("`@("`@("`D96QT(#T@)'1H:7,M/E]M86ME36%I;&)O>%1R965%
M;'0H)&]B*3L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I;G-E
M<G1%;'0H)&5L="D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!#
M<F5A=&4@=&AE(&QI<W0@*$E.0D]8(&%N9"!A;GD@;W1H97(@:&EE<F%R8VAI
M97,I+B`J+PH@("`@("`@("1T:&ES+3Y?861D3&5V96PH)&)O>&5S*3L*"B`@
M("`@("`@+RH@16YD(&EN:71I86QI>F%T:6]N(&UO9&4N("HO"B`@("`@("`@
M)'1H:7,M/E]I;FET;6]D92`](#`["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M=6)C;&%S<R!S<&5C:69I8R!I;FET:6%L:7IA=&EO;B!T87-K<RX*("`@("`J
M(%1(25,@34542$]$($U54U0@0D4@1$5&24Y%1"!)3B!!3$P@4U5"0TQ!4U-%
M4RX*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@
M:6YI=&EA;"!L:7-T(&]F(&5L96UE;G1S('1O(&%D9"!T;R!T:&4@=')E92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7VEN:70H*0H@("`@>PH@("`@("`@(')E
M='5R;B!A<G)A>2@I.PH@("`@?0H*("`@("\J*@H@("`@("H@17AP86YD(&$@
M;6%I;"!F;VQD97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]L
M9&5R("`@("`@5&AE(&9O;&1E<B!N86UE('1O(&5X<&%N9"X*("`@("`J($!P
M87)A;2!B;V]L96%N("1E>'!A;F1A;&P@($5X<&%N9"!A;&P@9F]L9&5R<R!U
M;F1E<B!T:&ES(&]N93\*("`@("`J+PH@("`@9G5N8W1I;VX@97AP86YD*"1F
M;VQD97(L("1E>'!A;F1A;&P@/2!F86QS92D*("`@('L*("`@("`@("`D9F]L
M9&5R(#T@)'1H:7,M/E]C;VYV97)T3F%M92@D9F]L9&5R*3L*"B`@("`@("`@
M:68@*"%I<W-E="@D=&AI<RT^7W1R965;)&9O;&1E<ETI*2!["B`@("`@("`@
M("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?8VAA;F=E
M9"`]('1R=64["@H@("`@("`@("\J($UE<F=E(&EN(&YE>'0@;&5V96P@;V8@
M:6YF;W)M871I;VXN("HO"B`@("`@("`@:68@*"1T:&ES+3YH87-#:&EL9')E
M;B@D=&AI<RT^7W1R965;)&9O;&1E<ETI*2!["B`@("`@("`@("`@(&EF("@A
M)'1H:7,M/FES1&ES8V]V97)E9"@D=&AI<RT^7W1R965;)&9O;&1E<ETI*2![
M"B`@("`@("`@("`@("`@("`D:6YF;R`]("1T:&ES+3Y?8VAI;&1R96Y);F9O
M*"1F;VQD97(I.PH@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D:6YF;RDI
M('L*("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]I;FET;6]D92D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H*"1T:&ES+3Y?:6YI=&UO
M9&4@)B!)34%05%)%15])3DE47T9%5$-(04Q,*2!\?`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/FES3W!E;B@D=&AI<RT^7W1R965;)&9O
M;&1E<ETI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V%D9$QE=F5L*"1I;F9O*3L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?861D3&5V96PH)&EN9F\I.PH@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W-E=$]P96XH)'1H:7,M/E]T<F5E6R1F;VQD
M97)=+"!T<G5E*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!I
M9B`H(2@D=&AI<RT^7VEN:71M;V1E("8@24U!4%12145?24Y)5%]&151#2$%,
M3"DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-E=$]P96XH)'1H
M:7,M/E]T<F5E6R1F;VQD97)=+"!T<G5E*3L*("`@("`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("`@("`O*B!%>'!A;F0@86QL(&-H:6QD<F5N(&)E;F5A
M=&@@=&AI<R!O;F4N("HO"B`@("`@("`@("`@("`@("!I9B`H)&5X<&%N9&%L
M;"`F)B`A96UP='DH)'1H:7,M/E]P87)E;G1;)&9O;&1E<ETI*2!["B`@("`@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]P87)E;G1;)&9O;&1E
M<ET@87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M97AP86YD*"1T:&ES+3Y?=')E95LD=F%L75LG=B==+"!T<G5E*3L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VQL87!S92!A
M(&UA:6P@9F]L9&5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9O
M;&1E<B`@5&AE(&9O;&1E<B!N86UE('1O(&-O;&QA<'-E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!C;VQL87!S92@D9F]L9&5R*0H@("`@>PH@("`@("`@("1F
M;VQD97(@/2`D=&AI<RT^7V-O;G9E<G1.86UE*"1F;VQD97(I.PH*("`@("`@
M("!I9B`H(6ES<V5T*"1T:&ES+3Y?=')E95LD9F]L9&5R72DI('L*("`@("`@
M("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]C:&%N
M9V5D(#T@=')U93L*"B`@("`@("`@+RH@4V5T('1H92!F;VQD97(@871T<FEB
M=71E<R!T;R!N;W0@97AP86YD960N("HO"B`@("`@("`@)'1H:7,M/E]S971/
M<&5N*"1T:&ES+3Y?=')E95LD9F]L9&5R72P@9F%L<V4I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5T<R!T:&4@:6YT97)N86P@87)R87D@<&]I;G1E<B!T
M;R!T:&4@;F5X="!E;&5M96YT+"!A;F0@<F5T=7)N<R!T:&4*("`@("`J(&YE
M>'0@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1M87-K
M("!!(&UA<VL@=VET:"!T:&4@9F]L;&]W:6YG(&5L96UE;G1S.@H@("`@("H@
M/'!R93X*("`@("`J($E-05!44D5%7TY%6%1?4TA/5T-,3U-%1"`M($1O;B=T
M(&EG;F]R92!C;&]S960@96QE;65N=',N"B`@("`@*B!)34%05%)%15].15A4
M7U-(3U=354(@+2!/;FQY('-H;W<@<W5B<V-R:6)E9"!E;&5M96YT<RX*("`@
M("`J(#PO<')E/@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%)E='5R
M;G,@=&AE(&YE>'0@96QE;65N="!O<B!F86QS92!I9B!T:&4@96QE;65N="!D
M;V5S;B=T"B`@("`@*B`@("`@("`@("`@("`@("!E>&ES="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@;F5X="@D;6%S:R`](#`I"B`@("!["B`@("`@("`@:68@
M*&ES7VYU;&PH)'1H:7,M/E]C=7)R:V5Y*2`F)B!I<U]N=6QL*"1T:&ES+3Y?
M8W5R<G!A<F5N="DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*"B`@("`@("`@)&-U<G(@/2`D=&AI<RT^8W5R<F5N="@I.PH*("`@
M("`@("`D;VQD7W-H;W=U;G-U8B`]("1T:&ES+3Y?<VAO=W5N<W5B.PH@("`@
M("`@(&EF("@D;6%S:R`F($E-05!44D5%7TY%6%1?4TA/5U-50BD@>PH@("`@
M("`@("`@("`D=&AI<RT^7W-H;W=U;G-U8B`](&9A;'-E.PH@("`@("`@('T*
M("`@("`@(`H@("`@("`@(&EF("@D=&AI<RT^7V%C=&EV945L="@D8W5R<BD@
M)B8*("`@("`@("`@("`@*"@D;6%S:R`F($E-05!44D5%7TY%6%1?4TA/5T-,
M3U-%1"D@?'P@)'1H:7,M/FES3W!E;B@D8W5R<BDI("8F"B`@("`@("`@("`@
M("@D=&AI<RT^7V-U<G)P87)E;G0@(3T@)&-U<G);)W8G72DI('L*("`@("`@
M("`@("`@+RH@268@=&AE(&-U<G)E;G0@96QE;65N="!I<R!O<&5N+"!A;F0@
M8VAI;&1R96X@97AI<W0L(&UO=F4@:6YT;PH@("`@("`@("`@("`@*B!I="X@
M*B\*("`@("`@("`@("`@)'1H:7,M/E]C=7)R<W1A8VM;72`](&%R<F%Y*"=K
M)R`]/B`D=&AI<RT^7V-U<G)K97DL("=P)R`]/B`D=&AI<RT^7V-U<G)P87)E
M;G0I.PH@("`@("`@("`@("`D=&AI<RT^7V-U<G)K97D@/2`P.PH@("`@("`@
M("`@("`D=&AI<RT^7V-U<G)P87)E;G0@/2`D8W5R<ELG=B==.PH@("`@("`@
M("`@("!I9B`H)'1H:7,M/E]N965D4V]R="@D=&AI<RT^7W1R965;)&-U<G);
M)W8G75TI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W-O<G1,:7-T*"1T
M:&ES+3Y?<&%R96YT6R1C=7)R6R=V)UU=+"!I<U]N=6QL*"1C=7)R6R=V)UTI
M*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T3F5E9%-O<G0H)'1H:7,M
M/E]T<F5E6R1C=7)R6R=V)UU=+"!F86QS92D["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V-H86YG960@/2!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@+RH@16QS92P@:6YC<F5M96YT('=I=&AI
M;B!T:&4@8W5R<F5N="!S=6)F;VQD97(N("HO"B`@("`@("`@("`@("1T:&ES
M+3Y?8W5R<FME>2LK.PH@("`@("`@('T*"B`@("`@("`@+RH@268@=&AE('!O
M:6YT97(@9&]E<VXG="!P;VEN="!T;R!A;B!E;&5M96YT+"!T<GD@=&\@;6]V
M92!B86-K('1O"B`@("`@("`@("`@=&AE('!R979I;W5S('-U8F9O;&1E<BX@
M($EF('1H97)E(&ES(&YO('!R979I;W5S('-U8F9O;&1E<BP*("`@("`@("`@
M("!R971U<FX@9F%L<V4N("HO"B`@("`@("`@)&-U<G(@/2`D=&AI<RT^8W5R
M<F5N="@I.PH@("`@("`@(&EF("@A)&-U<G(@)B8*("`@("`@("`@("`@*"1M
M87-K("8@24U!4%12145?3D585%]32$]70TQ/4T5$*2`F)@H@("`@("`@("`@
M("`A)'1H:7,M/FES1&ES8V]V97)E9"@D=&AI<RT^7W1R965;)'1H:7,M/E]C
M=7)R<&%R96YT72D@)B8*("`@("`@("`@("`@)'1H:7,M/FAA<T-H:6QD<F5N
M*"1T:&ES+3Y?=')E95LD=&AI<RT^7V-U<G)P87)E;G1=*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7V%D9$QE=F5L*"1T:&ES+3Y?8VAI;&1R96Y);F9O*"1T
M:&ES+3Y?=')E95LD=&AI<RT^7V-U<G)P87)E;G1=6R=V)UTI*3L*("`@("`@
M("`@("`@)&-U<G(@/2`D=&AI<RT^8W5R<F5N="@I.PH@("`@("`@('T*"B`@
M("`@("`@)'1H:7,M/E]S:&]W=6YS=6(@/2`D;VQD7W-H;W=U;G-U8CL*"B`@
M("`@("`@:68@*"$D8W5R<BD@>PH@("`@("`@("`@("!I9B`H96UP='DH)'1H
M:7,M/E]C=7)R<W1A8VLI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-U
M<G)K97D@/2!N=6QL.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C=7)R<&%R
M96YT(#T@;G5L;#L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&1O('L*("`@("`@
M("`@("`@("`@("`@("`D;VQD(#T@87)R87E?<&]P*"1T:&ES+3Y?8W5R<G-T
M86-K*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-U<G)K97D@/2`D
M;VQD6R=K)UT@*R`Q.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R
M<G!A<F5N="`]("1O;&1;)W`G73L*("`@("`@("`@("`@("`@('T@=VAI;&4@
M*"@H)&-U<G(@/2`D=&AI<RT^8W5R<F5N="@I*2`]/2!F86QS92D@)B8*("`@
M("`@("`@("`@("`@("`@("`@("`@(&-O=6YT*"1T:&ES+3Y?8W5R<G-T86-K
M*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@A)'1H
M:7,M/E]A8W1I=F5%;'0H)&-U<G(I*2!["B`@("`@("`@("`@("\J(%-K:7`@
M=&AI<R!E;G1R>2!I9CH*("`@("`@("`@("`@("H@,2X@5V4@87)E(&YO="!S
M:&]W:6YG(&%L;"!E;&5M96YT<PH@("`@("`@("`@("`@*B`R+B!792!A<F4@
M;F]T('-U8G-C<FEB960@=&\@=&AI<R!E;&5M96YT"B`@("`@("`@("`@("`J
M(#,N($ET(&ES(&YO="!A(&-O;G1A:6YE<B`M3U(M+"!I9B!I="!I<R!A(&-O
M;G1A:6YE<BP@:68@=&AE<F4*("`@("`@("`@("`@("H@("`@87)E(&YO('9I
M97=A8FQE(&5L96UE;G1S('5N9&5R;F5A=&@@:70N"B`@("`@("`@("`@("`J
M(#0N(%1H:7,@:7,@86X@96UP='D@;F%M97-P86-E(&5L96UE;G0N("HO"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^;F5X="@D;6%S:RD["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&-U<G(["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!3970@:6YT97)N86P@<&]I;G1E<B!T;R!T:&4@:&5A9"!O9B!T:&4@=')E
M92X*("`@("`J(%1H:7,@35535"!B92!C86QL960@8F5F;W)E('EO=2!C86X@
M=')A=F5R<V4@=&AE('1R964@=VET:"!N97AT*"DN"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@4F5T=7)N<R!T:&4@96QE;65N="!A="!T:&4@:&5A
M9"!O9B!T:&4@=')E92!O<B!F86QS90H@("`@("H@("`@("`@("`@("`@("`@
M:68@=&AE(&5L96UE;G0@9&]E<VXG="!E>&ES="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F5S970H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8W5R<FME>2`]
M(#`["B`@("`@("`@)'1H:7,M/E]C=7)R<&%R96YT(#T@24U!4%12145?0D%3
M15]%3%0["B`@("`@("`@)'1H:7,M/E]C=7)R<W1A8VL@/2!A<G)A>2@I.PH*
M("`@("`@("!I9B`H)'1H:7,M/E]N965D4V]R="@D=&AI<RT^7W1R965;)'1H
M:7,M/E]C=7)R<&%R96YT72DI('L*("`@("`@("`@("`@)'1H:7,M/E]S;W)T
M3&ES="@D=&AI<RT^7W!A<F5N=%LD=&AI<RT^7V-U<G)P87)E;G1=+"!I<U]N
M=6QL*"1T:&ES+3Y?8W5R<G!A<F5N="DI.PH@("`@("`@("`@("`D=&AI<RT^
M7W-E=$YE9613;W)T*"1T:&ES+3Y?=')E95LD=&AI<RT^7V-U<G)P87)E;G1=
M+"!F86QS92D["B`@("`@("`@("`@("1T:&ES+3Y?8VAA;F=E9"`]('1R=64[
M"B`@("`@("`@?0H*("`@("`@("`O*B!7:&5N(')E<V5T=&EN9R!I;B!N97=S
M(&UO9&4L('1H92!F:7)S="!E;&5M96YT(&UA>2!N;W0@8F4*("`@("`@("`@
M*B!V:65W86)L92`H=6YL:6ME(&UA:6P@;6]D92P@=VAE<F4@=&AE(&9I<G-T
M(&5L96UE;G0@:7,@24Y"3U@@86YD"B`@("`@("`@("H@:7,@86QW87ES('9I
M97=A8FQE*2X@(%1H97)E9F]R92P@=V4@;F5E9"!T;R!S96%R8V@@9F]R('1H
M92!F:7)S=`H@("`@("`@("`J('9I97=A8FQE(&ET96T@86YD('1H870@=VEL
M;"!B92!T:&4@8F%S92!O9B!T:&4@=FEE=V%B;&4@=')E92X@*B\*("`@("`@
M("!I9B`H)'1H:7,M/E]M;V1E(#T]($E-05!44D5%7TU/1$5?3D574RD@>PH@
M("`@("`@("`@("`D8W5R<B`]("1T:&ES+3YC=7)R96YT*"D["B`@("`@("`@
M("`@(&EF("@A)'1H:7,M/E]A8W1I=F5%;'0H)&-U<G(I*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^;F5X="@I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)'1H:7,M/F-U<G)E;G0H*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;B!T:&4@8W5R<F5N="!T<F5E(&5L96UE;G0N
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&-U<G)E;G0@=')E
M92!E;&5M96YT(&]R(&9A;'-E(&EF('1H97)E(&ES(&YO"B`@("`@*B`@("`@
M("`@("`@("`@("!E;&5M96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!C=7)R
M96YT*"D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R96YT
M6R1T:&ES+3Y?8W5R<G!A<F5N=%U;)'1H:7,M/E]C=7)R:V5Y72DI('L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?861D06QI87-E<R@D=&AI<RT^7W1R965;)'1H:7,M/E]P
M87)E;G1;)'1H:7,M/E]C=7)R<&%R96YT75LD=&AI<RT^7V-U<G)K97E=72D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S(&EF('1H97)E(&%R
M92!M;W)E(&5L96UE;G1S(&EN('1H92!C=7)R96YT('1R964@;&5V96PN"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H97)E(&%R
M92!M;W)E(&5L96UE;G1S+"!F86QS92!I9B!T:&ES(&ES('1H90H@("`@("H@
M("`@("`@("`@("`@("`@("!L87-T(&5L96UE;G0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('!E96LH*0H@("`@>PH@("`@("`@(&9O<B`H)&D@/2`H)'1H:7,M
M/E]C=7)R:V5Y("L@,2D[(#L@)&DK*RD@>PH@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3Y?<&%R96YT6R1T:&ES+3Y?8W5R<G!A<F5N=%U;)&E=*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^7V%C=&EV945L="@D=&AI<RT^7V%D
M9$%L:6%S97,H)'1H:7,M/E]T<F5E6R1T:&ES+3Y?<&%R96YT6R1T:&ES+3Y?
M8W5R<G!A<F5N=%U;)&E=72DI*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M=')U93L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($%D9',@86QI87-E<R!T;R!A('1R964@96QE;65N="!A;F0@<F5T
M=7)N<R!T:&4@<F5S=6QT:6YG(&%R<F%Y+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')O=&5C=&5D"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1E;'0@
M($$@=')E92!E;&5M96YT+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M($$@=')E92!E;&5M96YT('=I=&@@=&AE(&%L:6%S97,@861D960N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]A9&1!;&EA<V5S*"1E;'0I"B`@("!["B`@("`@
M("`@)&5L=%LG;&%B96PG72`]("1E;'1;)VPG73L*("`@("`@("`D96QT6R=L
M979E;"==(#T@)&5L=%LG8R==.PH@("`@("`@("1E;'1;)W!A<F5N="==(#T@
M)&5L=%LG<"==.PH@("`@("`@("1E;'1;)W9A;'5E)UT@/2`D96QT6R=V)UT[
M"@H@("`@("`@(')E='5R;B`D96QT.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!T:&4@<F5Q=65S=&5D(&5L96UE;G0N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&YA;64@;V8@=&AE('1R964@96QE
M;65N="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!2971U<FYS('1H
M92!R97%U97-T960@96QE;65N="!O<B!F86QS92!I9B!N;W0@9F]U;F0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E="@D;F%M92D*("`@('L*("`@("`@("`D
M;F%M92`]("1T:&ES+3Y?8V]N=F5R=$YA;64H)&YA;64I.PH*("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/E]T<F5E6R1N86UE72DI('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?861D06QI87-E<R@D=&AI<RT^7W1R965;)&YA;65=
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@26YS97)T(&$@9F]L
M9&5R+VUA:6QB;W@@:6YT;R!T:&4@=')E92X*("`@("`J"B`@("`@*B!`<&%R
M86T@;6EX960@)&ED("!4:&4@;F%M92!O9B!T:&4@9F]L9&5R("AO<B!A(&QI
M<W0@;V8@9F]L9&5R(&YA;65S*0H@("`@("H@("`@("`@("`@("`@("`@("`@
M=&\@861D("AM=7-T(&)E('!R97-E;G0@;VX@=&AE(&UA:6P@<V5R=F5R*2X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S
M<RP@9F%L<V4@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&EN<V5R
M="@D:60I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?;6]D92`]/2!)34%0
M5%)%15]-3T1%7TY%5U,I('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@:68@*&ES7V%R<F%Y*"1I9"DI('L*("`@("`@
M("`@("`@:68@*"$D=&AI<RT^7VYO;FEM87!E;'0I('L*("`@("`@("`@("`@
M("`@("\J(%=E('=A;G0@=&\@861D(&9R;VT@=&AE($)!4T4@;V8@=&AE('1R
M964@=7`@9F]R(&5F9FEC:65N8WD*("`@("`@("`@("`@("`@("`J('-A:V4N
M("HO"B`@("`@("`@("`@("`@("`D=&AI<RT^7W-O<G1,:7-T*"1I9"D["B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D:60@
M/2!A<G)A>2@D:60I.PH@("`@("`@('T*"B`@("`@("`@)&%D9',@/2!A<G)A
M>2@I.PH*("`@("`@("!F;W)E86-H("@D:60@87,@)'9A;"D@>PH@("`@("`@
M("`@("`D;G-?:6YF;R`]("1T:&ES+3Y?9V5T3F%M97-P86-E*"1V86PI.PH@
M("`@("`@("`@("!I9B`H:7-?;G5L;"@D;G-?:6YF;RD@?'P@)'1H:7,M/E]N
M;VYI;6%P96QT*2!["B`@("`@("`@("`@("`@("`D861D<UM=(#T@)'9A;#L*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("\J($)R96%K
M(&%P87)T('1H92!N86UE('9I82!T:&4@9&5L:6UI=&5R(&%N9"!G;R!S=&5P
M(&)Y('-T97`*("`@("`@("`@("`@("`@("`J('1H<F]U9V@@=&AE(&YA;64@
M=&\@;6%K92!S=7)E(&%L;"!S=6)F;VQD97)S(&5X:7-T(&EN('1H90H@("`@
M("`@("`@("`@("`@("H@=')E92X@*B\*("`@("`@("`@("`@("`@("1P87)T
M<R`](&5X<&QO9&4H)&YS7VEN9F];)V1E;&EM:71E<B==+"`D=F%L*3L*("`@
M("`@("`@("`@("`@("1P87)T<ULP72`]("1T:&ES+3Y?8V]N=F5R=$YA;64H
M)'!A<G1S6S!=*3L*("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M(&-O=6YT*"1P87)T<RD[("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`D
M861D<UM=(#T@:6UP;&]D92@D;G-?:6YF;ULG9&5L:6UI=&5R)UTL(&%R<F%Y
M7W-L:6-E*"1P87)T<RP@,"P@)&D@*R`Q*2D["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*&%R
M<F%Y7W5N:7%U92@D861D<RD@87,@)&ED*2!["B`@("`@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7W1R965;)&ED72DI('L*("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^7V-H
M86YG960@/2!T<G5E.PH*("`@("`@("`@("`@:68@*"1T:&ES+3Y?;F]N:6UA
M<&5L="D@>PH@("`@("`@("`@("`@("`@)&5L="`]("1T:&ES+3Y?9V5T3F]N
M24U!4$5L="@D:60I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)&]B(#T@)'1H:7,M/E]G971,:7-T*"1I9"D["B`@("`@("`@("`@
M("`@("`D96QT(#T@)'1H:7,M/E]M86ME36%I;&)O>%1R965%;'0H<F5S970H
M)&]B*2D["B`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3YI<U-U8G-C<FEB
M960H)&5L="DI('L*("`@("`@("`@("`@("`@("`@("`D=&UP(#T@0&EM87!?
M;'-U8B@D=&AI<RT^7V=E=%-T<F5A;2@I+"`D=&AI<RT^7W-E<G9E<BP@)&5L
M=%LG=B==*3L*("`@("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1T;7`I
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T4W5B<V-R
M:6)E9"@D96QT+"!T<G5E*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D
M=&AI<RT^7VEN<V5R=$5L="@D96QT*2D@>PH@("`@("`@("`@("`@("`@+RH@
M5V4@:VYO=R!T:&%T('1H92!P87)E;G0@9F]L9&5R(&AA<R!C:&EL9')E;BX@
M*B\*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W1R965;)&5L
M=%LG<"==72DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-E=$-H
M:6QD<F5N*"1T:&ES+3Y?=')E95LD96QT6R=P)UU=+"!T<G5E*3L*("`@("`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O*B!-86ME('-U<F4@=V4@
M87)E('-O<G1E9"!C;W)R96-T;'DN("HO"B`@("`@("`@("`@("`@("!I9B`H
M8V]U;G0H)'1H:7,M/E]P87)E;G1;)&5L=%LG<"==72D@/B`Q*2!["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]S971.965D4V]R="@D=&AI<RT^7W1R
M965;)&5L=%LG<"==72P@=')U92D["B`@("`@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`@("`@+RH@061D('1O('-U8G-C<FEB960O=6YS=6)S8W)I8F5D
M(&QI<W0N("HO"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/FES4W5B<V-R
M:6)E9"@D96QT*2`F)@H@("`@("`@("`@("`@("`@("`@("%I<U]N=6QL*"1T
M:&ES+3Y?<W5B<V-R:6)E9"DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W-U8G-C<FEB961;)&5L=%LG=B==72`](#$["B`@("`@("`@("`@("`@
M("!](&5L<V5I9B`H(21T:&ES+3YI<U-U8G-C<FEB960H)&5L="D@)B8*("`@
M("`@("`@("`@("`@("`@("`@("`@("`A:7-?;G5L;"@D=&AI<RT^7W5N<W5B
M<V-R:6)E9"DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W5N<W5B
M<V-R:6)E9%LD96QT6R=V)UU=(#T@,3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!);G-E<G0@86X@96QE;65N="!I;G1O('1H
M92!T<F5E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D96QT("!4:&4@96QE;65N="!T;R!I;G-E
M<G0N(%1H92!K97D@:6X@=&AE('1R964@:7,@=&AE"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@)W8G("AV86QU92D@96QE;65N="!O9B!T:&4@96QE;65N
M="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@861D
M960@=&\@=&AE('1R964N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]I;G-E<G1%
M;'0H)&5L="D*("`@('L*("`@("`@("`O*B!$;VXG="!I;F-L=61E('1H92!P
M87)E;G0@9&ER96-T;W)I97,@=&AA="!55R!P87-S97,@8F%C:R!I;@H@("`@
M("`@("`@("4O)2!L:7-T<RX@*B\*("`@("`@("!I9B`H<W1R;&5N*"1E;'1;
M)VPG72D@)B8*("`@("`@("`@("`@*"%I<W-E="@D=&AI<RT^7W1R965;)&5L
M=%LG=B==72D@?'P*("`@("`@("`@("`@("1T:&ES+3YI<T-O;G1A:6YE<B@D
M=&AI<RT^7W1R965;)&5L=%LG=B==72DI("8F"B`@("`@("`@("`@("\J(%1/
M1$\Z(%)E;6]V92!D;W1F:6QE<R!F:6QT97(@:6X@;F5X="!M86IO<B!R96QE
M87-E+B`J+PH@("`@("`@("`@("`H)'1H:7,M/E]D;W1F:6QE<R!\?"`H)&5L
M=%LG;"==6S!=("$]("<N)RDI*2!["B`@("`@("`@("`@("\J(%-E="!T:&4@
M<&%R96YT(&%R<F%Y('1O('1H92!V86QU92!I;B`D96QT6R=P)UTN("HO"B`@
M("`@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W!A<F5N=%LD96QT6R=P)UU=
M*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)E;G1;)&5L=%LG<"==
M72`](&%R<F%Y*"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M
M/E]P87)E;G1;)&5L=%LG<"==75M=(#T@)&5L=%LG=B==.PH@("`@("`@("`@
M("`D=&AI<RT^7W1R965;)&5L=%LG=B==72`]("1E;'0["B`@("`@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$
M96QE=&4@86X@96QE;65N="!F<F]M('1H92!T<F5E+@H@("`@("H*("`@("`J
M($!P87)A;2!M:7AE9"`D:60@(%1H92!E;&5M96YT(&YA;64@;W(@86X@87)R
M87D@;V8@96QE;65N="!N86UE<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%)E='5R;B!T<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N(&5R<F]R
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96QE=&4H)&ED*0H@("`@>PH@("`@
M("`@(&EF("AI<U]A<G)A>2@D:60I*2!["B`@("`@("`@("`@("\J(%=E('=A
M;G0@=&\@9&5L971E(&9R;VT@=&AE(%1/4"!O9B!T:&4@=')E92!D;W=N('1O
M(&5N<W5R92!T:&%T"B`@("`@("`@("`@("`J('!A<F5N=',@:&%V92!A;B!A
M8V-U<F%T92!V:65W(&]F('=H870@8VAI;&1R96X@87)E(&QE9G0N("HO"B`@
M("`@("`@("`@("1T:&ES+3Y?<V]R=$QI<W0H)&ED*3L*("`@("`@("`@("`@
M)&ED(#T@87)R87E?<F5V97)S92@D:60I.PH*("`@("`@("`@("`@)'-U8V-E
M<W,@/2!T<G5E.PH@("`@("`@("`@("!F;W)E86-H("@D:60@87,@)'9A;"D@
M>PH@("`@("`@("`@("`@("`@)&-U<G)S=6-C97-S(#T@)'1H:7,M/F1E;&5T
M92@D=F%L*3L*("`@("`@("`@("`@("`@(&EF("@A)&-U<G)S=6-C97-S*2![
M"B`@("`@("`@("`@("`@("`@("`@)'-U8V-E<W,@/2!F86QS93L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@
M)'-U8V-E<W,["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&ED(#T@
M)'1H:7,M/E]C;VYV97)T3F%M92@D:60L('1R=64I.PH@("`@("`@('T*"B`@
M("`@("`@)&YS7VEN9F\@/2`D=&AI<RT^7V=E=$YA;65S<&%C92@D:60I.PH*
M("`@("`@("!I9B`H*"1I9"`]/2`G24Y"3U@G*2!\?`H@("`@("`@("`@("`A
M:7-S970H)'1H:7,M/E]T<F5E6R1I9%TI('Q\"B`@("`@("`@("`@("@D:60@
M/3T@)&YS7VEN9F];)VYA;64G72DI('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]C:&%N9V5D(#T@=')U
M93L*"B`@("`@("`@)&5L="`]("8D=&AI<RT^7W1R965;)&ED73L*"B`@("`@
M("`@+RH@1&\@;F]T(&1E;&5T92!F<F]M('1R964@:68@=&AE<F4@87)E(&-H
M:6QD(&5L96UE;G1S("T@:6YS=&5A9"P*("`@("`@("`@*B!C;VYV97)T('1O
M(&$@8V]N=&%I;F5R(&5L96UE;G0N("HO"B`@("`@("`@:68@*"1T:&ES+3YH
M87-#:&EL9')E;B@D96QT*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W-E=$-O
M;G1A:6YE<B@D96QT+"!T<G5E*3L*("`@("`@("`@("`@<F5T=7)N('1R=64[
M"B`@("`@("`@?0H*("`@("`@("`D<&%R96YT(#T@)&5L=%LG<"==.PH*("`@
M("`@("`O*B!$96QE=&4@=&AE('1R964@96YT<FEE<RX@*B\*("`@("`@("!U
M;G-E="@D=&AI<RT^7W1R965;)&ED72D["B`@("`@("`@=6YS970H)'1H:7,M
M/E]S=6)S8W)I8F5D6R1I9%TI.PH@("`@("`@('5N<V5T*"1T:&ES+3Y?=6YS
M=6)S8W)I8F5D6R1I9%TI.PH*("`@("`@("`O*B!$96QE=&4@=&AE(&5N=')Y
M(&9R;VT@=&AE('!A<F5N="!T<F5E+B`J+PH@("`@("`@("1K97D@/2!A<G)A
M>5]S96%R8V@H)&ED+"`D=&AI<RT^7W!A<F5N=%LD<&%R96YT72D["B`@("`@
M("`@=6YS970H)'1H:7,M/E]P87)E;G1;)'!A<F5N=%U;)&ME>5TI.PH*("`@
M("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)E;G1;)'!A<F5N=%TI*2!["B`@
M("`@("`@("`@("\J(%1H:7,@9F]L9&5R(&ES(&YO=R!C;VUP;&5T96QY(&5M
M<'1Y("AN;R!C:&EL9')E;BDN("!)9B!T:&4*("`@("`@("`@("`@("H@9F]L
M9&5R(&ES(&$@8V]N=&%I;F5R(&]N;'DL('=E('-H;W5L9"!D96QE=&4@=&AE
M(&9O;&1E<B!F<F]M"B`@("`@("`@("`@("`J('1H92!T<F5E+B`J+PH@("`@
M("`@("`@("!U;G-E="@D=&AI<RT^7W!A<F5N=%LD<&%R96YT72D["B`@("`@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W1R965;)'!A<F5N=%TI*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7W-E=$-H:6QD<F5N*"1T:&ES+3Y?=')E
M95LD<&%R96YT72P@;G5L;"D["B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M
M/FES0V]N=&%I;F5R*"1T:&ES+3Y?=')E95LD<&%R96YT72D@)B8*("`@("`@
M("`@("`@("`@("`@("`A)'1H:7,M/FES3F%M97-P86-E*"1T:&ES+3Y?=')E
M95LD<&%R96YT72DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9&5L
M971E*"1P87)E;G0I.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"$D=&AI
M<RT^:&%S0VAI;&1R96XH)'1H:7,M/E]T<F5E6R1P87)E;G1=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5M;W9E17AP86YD961,:7-T*"1P
M87)E;G0I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T0VAI;&1R
M96XH)'1H:7,M/E]T<F5E6R1P87)E;G1=+"!F86QS92D["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]S971/<&5N*"1T:&ES+3Y?=')E95LD<&%R96YT
M72P@9F%L<V4I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@4F5B=6EL9"!T:&4@<&%R
M96YT('1R964N("HO"B`@("`@("`@("`@("1T:&ES+3Y?<&%R96YT6R1P87)E
M;G1=(#T@87)R87E?=F%L=65S*"1T:&ES+3Y?<&%R96YT6R1P87)E;G1=*3L*
M("`@("`@("!]"@H@("`@("`@("\J(%)E;6]V92!T:&4@;6%I;&)O>"!F<F]M
M('1H92!E>'!A;F1E9"!F;VQD97)S(&QI<W0N("HO"B`@("`@("`@)'1H:7,M
M/E]R96UO=F5%>'!A;F1E9$QI<W0H)&ED*3L*"B`@("`@("`@+RH@4F5M;W9E
M('1H92!M86EL8F]X(&9R;VT@=&AE(&YA=E]P;VQL(&QI<W0N("HO"B`@("`@
M("`@)'1H:7,M/G)E;6]V95!O;&Q,:7-T*"1I9"D["@H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4W5B<V-R:6)E(&%N(&5L
M96UE;G0@=&\@=&AE('1R964N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D
M("1I9"`@5&AE(&5L96UE;G0@;F%M92!O<B!A;B!A<G)A>2!O9B!E;&5M96YT
M(&YA;65S+@H@("`@("HO"B`@("!F=6YC=&EO;B!S=6)S8W)I8F4H)&ED*0H@
M("`@>PH@("`@("`@(&EF("@A:7-?87)R87DH)&ED*2D@>PH@("`@("`@("`@
M("`D:60@/2!A<G)A>2@D:60I.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C
M:"`H)&ED(&%S("1V86PI('L*("`@("`@("`@("`@)'9A;"`]("1T:&ES+3Y?
M8V]N=F5R=$YA;64H)'9A;"D["B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^7W1R965;)'9A;%TI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-H
M86YG960@/2!T<G5E.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]S9713=6)S
M8W)I8F5D*"1T:&ES+3Y?=')E95LD=F%L72P@=')U92D["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7W-E=$-O;G1A:6YE<B@D=&AI<RT^7W1R965;)'9A;%TL
M(&9A;'-E*3L*("`@("`@("`@("`@("`@(&EF("@A:7-?;G5L;"@D=&AI<RT^
M7W-U8G-C<FEB960I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S
M=6)S8W)I8F5D6R1V86Q=(#T@,3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('5N<V5T*"1T:&ES+3Y?=6YS=6)S8W)I8F5D6R1V86Q=*3L*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3YI
M;G-E<G0H)'9A;"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!5;G-U8G-C<FEB92!A;B!E;&5M96YT(&9R;VT@=&AE
M('1R964N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1I9"`@5&AE(&5L
M96UE;G0@;F%M92!O<B!A;B!A<G)A>2!O9B!E;&5M96YT(&YA;65S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!U;G-U8G-C<FEB92@D:60I"B`@("!["B`@("`@
M("`@:68@*"%I<U]A<G)A>2@D:60I*2!["B`@("`@("`@("`@("1I9"`](&%R
M<F%Y*"1I9"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@5V4@
M=V%N="!T;R!D96QE=&4@9G)O;2!T:&4@5$]0(&]F('1H92!T<F5E(&1O=VX@
M=&\@96YS=7)E('1H870*("`@("`@("`@("`@("H@<&%R96YT<R!H879E(&%N
M(&%C8W5R871E('9I97<@;V8@=VAA="!C:&EL9')E;B!A<F4@;&5F="X@*B\*
M("`@("`@("`@("`@)'1H:7,M/E]S;W)T3&ES="@D:60I.PH@("`@("`@("`@
M("`D:60@/2!A<G)A>5]R979E<G-E*"1I9"D["B`@("`@("`@?0H*("`@("`@
M("!F;W)E86-H("@D:60@87,@)'9A;"D@>PH@("`@("`@("`@("`D=F%L(#T@
M)'1H:7,M/E]C;VYV97)T3F%M92@D=F%L*3L*"B`@("`@("`@("`@("\J($E.
M0D]8(&-A;B!N979E<B!B92!U;G-U8G-C<FEB960@=&\@*&EF(&EN(&UA:6P@
M;6]D92DN("HO"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W1R965;
M)'9A;%TI("8F("@D=F%L("$]("=)3D)/6"<I*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7V-H86YG960@/2!T<G5E.PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]U;G-U8G9I97<@/2!T<G5E.PH*("`@("`@("`@("`@("`@("1E;'0@
M/2`F)'1H:7,M/E]T<F5E6R1V86Q=.PH*("`@("`@("`@("`@("`@("\J($1O
M(&YO="!D96QE=&4@9G)O;2!T<F5E(&EF('1H97)E(&%R92!C:&EL9"!E;&5M
M96YT<R`M"B`@("`@("`@("`@("`@("`@*B!I;G-T96%D+"!C;VYV97)T('1O
M(&$@8V]N=&%I;F5R(&5L96UE;G0N("HO"B`@("`@("`@("`@("`@("!I9B`H
M(21T:&ES+3Y?<VAO=W5N<W5B("8F("1T:&ES+3YH87-#:&EL9')E;B@D96QT
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T0V]N=&%I;F5R
M*"1E;'0L('1R=64I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@("\J(%-E="!A<R!U;G-U8G-C<FEB960L(&%D9"!T;R!U;G-U8G-C<FEB
M960@;&ES="P@86YD(')E;6]V90H@("`@("`@("`@("`@("`@("H@9G)O;2!S
M=6)S8W)I8F5D(&QI<W0N("HO"B`@("`@("`@("`@("`@("`D=&AI<RT^7W-E
M=%-U8G-C<FEB960H)&5L="P@9F%L<V4I.PH@("`@("`@("`@("`@("`@:68@
M*"%I<U]N=6QL*"1T:&ES+3Y?=6YS=6)S8W)I8F5D*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?=6YS=6)S8W)I8F5D6R1V86Q=(#T@,3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?
M<W5B<V-R:6)E9%LD=F%L72D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@86YO=&AE<B!L979E;"!O9B!H:65R
M87)C:'D@=&\@=&AE('1R964N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1L:7-T("!!(&QI<W0@
M;V8@<W1D0VQA<W,@;V)J96-T<R!I;B!T:&4@9F]R;6%T(')E='5R;F5D"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@(&9R;VT@:6UA<%]G971M86EL8F]X
M97,H*2X*("`@("`J+PH@("`@9G5N8W1I;VX@7V%D9$QE=F5L*"1L:7-T*0H@
M("`@>PH@("`@("`@("1E>'!A;F1A;&P@/2`H)'1H:7,M/E]I;FET;6]D92`F
M($E-05!44D5%7TE.251?1D540TA!3$PI.PH*("`@("`@("!F;W)E86-H("@D
M;&ES="!A<R`D=F%L*2!["B`@("`@("`@("`@("1E;'0@/2`D=&AI<RT^7VUA
M:V5-86EL8F]X5')E945L="@D=F%L*3L*"B`@("`@("`@("`@("1P87)E;G0@
M/2`D96QT6R=P)UT["B`@("`@("`@("`@("1T:&ES+3Y?:6YS97)T16QT*"1E
M;'0I.PH@("`@("`@("`@("`D=&AI<RT^7V-H86YG960@/2!T<G5E.PH*("`@
M("`@("`@("`@:68@*"1E>'!A;F1A;&P@?'P@)'1H:7,M/FES3W!E;B@D96QT
M*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/F5X<&%N9"@D96QT6R=V)UTI
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!3;W)T('1H
M92!L:7-T+B`J+PH@("`@("`@(&EF("@A96UP='DH)&QI<W0I("8F"B`@("`@
M("`@("`@("%E;7!T>2@D=&AI<RT^7W!A<F5N=%LD<&%R96YT72DI('L*("`@
M("`@("`@("`@)'1H:7,M/E]S971$:7-C;W9E<F5D*"1T:&ES+3Y?=')E95LD
M<&%R96YT72P@=')U92D["B`@("`@("`@("`@(&EF("AC;W5N="@D=&AI<RT^
M7W!A<F5N=%LD<&%R96YT72D@/B`Q*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7W-E=$YE9613;W)T*"1T:&ES+3Y?=')E95LD<&%R96YT72P@=')U92D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!3970@86X@871T<FEB=71E(&9O<B!A;B!E;&5M96YT+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!A<G)A
M>2`F)&5L="`@("`@5&AE('1R964@96QE;65N="X*("`@("`J($!P87)A;2!I
M;G1E9V5R("1C;VYS="`@5&AE(&-O;G-T86YT('1O('-E="]R96UO=F4@9G)O
M;2!T:&4@8FET;6%S:RX*("`@("`J($!P87)A;2!B;V]L96%N("1B;V]L("`@
M4VAO=6QD('1H92!A='1R:6)U=&4@8F4@<V5T/PH@("`@("HO"B`@("!F=6YC
M=&EO;B!?<V5T071T<FEB=71E*"8D96QT+"`D8V]N<W0L("1B;V]L*0H@("`@
M>PH@("`@("`@(&EF("@D8F]O;"D@>PH@("`@("`@("`@("`D96QT6R=A)UT@
M?#T@)&-O;G-T.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1E;'1;
M)V$G72`F/2!^)&-O;G-T.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($1O97,@=&AE(&5L96UE;G0@:&%V92!A;GD@86-T:79E(&-H:6QD<F5N
M/PH@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D96QT("!!('1R964@96QE
M;65N="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@
M=&AE(&5L96UE;G0@:&%S(&%C=&EV92!C:&EL9')E;BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@:&%S0VAI;&1R96XH)&5L="D*("`@('L*("`@("`@("!S=&%T
M:6,@)&AA<T-H:6QD<F5N0V%C:&4@/2!A<G)A>2@I.PH*("`@("`@("`D:7-?
M;G,@/2`D=&AI<RT^:7-.86UE<W!A8V4H)&5L="D["@H@("`@("`@("\J($1O
M;B=T(&1O('1H92!F;VQL;W=I;F<@:68@=V4@87)E(&1E86QI;F<@=VET:"!A
M(&YA;65S<&%C90H@("`@("`@("`J(&-O;G1A:6YE<BX@*B\*("`@("`@("!I
M9B`H(21I<U]N<RD@>PH@("`@("`@("`@("`O*B!.;W0@86QL($E-05`@<V5R
M=F5R<R!S=7!P;W)T('1H92!(05-#2$E,1%)%3B!F;&%G("AL:6ME(%57(2D@
M<V\*("`@("`@("`@("`@("H@=V4@;F5E9"!T;R!S:VEP('1H:7,@8VAE8VL@
M:68@=&AE($E-05`@<V5R=F5R(&1O97-N)W0@<V5T"B`@("`@("`@("`@("`J
M(&5I=&AE<B!(05-#2$E,1%)%3B!O<B!(05-.3T-(24Q$4D5.+B`J+PH@("`@
M("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?8VAI;&1R96YS=7!P;W)T*2!\
M?`H@("`@("`@("`@("`@("`@*&ES7VYU;&PH)'1H:7,M/E]C:&EL9')E;G-U
M<'!O<G0I("8F"B`@("`@("`@("`@("`@("`@*"1E;'1;)V$G72`F($Q!5%1?
M2$%30TA)3$1214XI('Q\"B`@("`@("`@("`@("`@("`@*"1E;'1;)V$G72`F
M($Q!5%1?2$%33D]#2$E,1%)%3BDI*2!["B`@("`@("`@("`@("`@("`D<F5T
M(#T@*"1E;'1;)V$G72`F($Q!5%1?2$%30TA)3$1214XI.PH*("`@("`@("`@
M("`@("`@("\J($-(14-+.B!)9B!W92!A<F4@=FEE=VEN9R!A;&P@9F]L9&5R
M<RP@86YD('1H97)E(&ES(&$@9F]L9&5R"B`@("`@("`@("`@("`@("`@*B!L
M:7-T960@87,@97AP86YD960@8G5T(&ET(&1O97,@;F]T(&-O;G1A:6X@86YY
M(&-H:6QD<F5N+`H@("`@("`@("`@("`@("`@("H@=&AE;B!W92!S:&]U;&0@
M<F5M;W9E(&ET(&9R;VT@=&AE(&5X<&%N9&5D(&QI<W0@<VEN8V4@:70*("`@
M("`@("`@("`@("`@("`J(&1O97-N)W0@97AI<W0@86YY;6]R92X@*B\*("`@
M("`@("`@("`@("`@(&EF("@D=&AI<RT^7W-H;W=U;G-U8B`F)B`A)')E="D@
M>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YI=$5X<&%N9&5D3&ES
M="@I.PH@("`@("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]E
M>'!A;F1E9%LD96QT6R=V)UU=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W)E;6]V945X<&%N9&5D3&ES="@D96QT6R=V)UTI.PH@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-E=$]P96XH)'1H:7,M/E]T
M<F5E6R1E;'1;)W8G75TL(&9A;'-E*3L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*"$D<F5T
M*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\J($EF('=E(&%R92!V:65W
M:6YG(&%L;"!E;&5M96YT<R`H<W5B<V-R:6)E9"!A;F0@=6YS=6)S8W)I8F5D
M*0H@("`@("`@("`@("`@("`@("H@86YD('=E(')E86-H('1H:7,@<&]I;G0@
M=V4@:VYO=R!T:&%T('1H97)E(&UU<W0@8F4@=FEE=V%B;&4*("`@("`@("`@
M("`@("`@("`J(&-H:6QD<F5N('-O(')E='5R;B!T<G5E+B`J+PH@("`@("`@
M("`@("`@("`@:68@*"1T:&ES+3Y?<VAO=W5N<W5B*2!["B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J($-A8VAE(')E<W5L=',@
M9G)O;2!B96QO=R!S:6YC92P@;6]S="!L:6ME;'D@:68@=V4@9V5T('1H:7,@
M9F%R+`H@("`@("`@("`J('1H:7,@8V]D92!W:6QL(&)E(&%C8V5S<V5D('-E
M=F5R86P@=&EM97,@:6X@=&AE(&-U<G)E;G0@<F5Q=65S="X@*B\*("`@("`@
M("!I9B`H:7-S970H)&AA<T-H:6QD<F5N0V%C:&5;)&5L=%LG=B==72DI('L*
M("`@("`@("`@("`@<F5T=7)N("1H87-#:&EL9')E;D-A8VAE6R1E;'1;)W8G
M75T["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!W92!R96%C:"!T:&ES('!O
M:6YT+"!T:&5N('=E(&%R92!E:71H97(@:6X@<W5B<V-R:6)E+6]N;'D@;6]D
M90H@("`@("`@("`J(&]R('=E(&%R92!D96%L:6YG('=I=&@@82!N86UE<W!A
M8V4@8V]N=&%I;F5R+B!#:&5C:R!F;W(@=&AE"B`@("`@("`@("H@97AI<W1E
M;F-E(&]F(&%N>2!S=6)S8W)I8F5D(&UA:6QB;WAE<R!B96QO=R!T:&4@8W5R
M<F5N="!N;V1E+B`J+PH@("`@("`@("1T:&ES+3Y?:6YI=%-U8G-C<FEB960H
M*3L*("`@("`@("`D9F]L9&5R7VQI<W0@/2`D=&AI<RT^7W-U8G-C<FEB960[
M"B`@("`@("`@:68@*"1T:&ES+3Y?<VAO=W5N<W5B*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?:6YI=%5N<W5B<V-R:6)E9"@I.PH@("`@("`@("`@("`D9F]L
M9&5R7VQI<W0@*ST@)'1H:7,M/E]U;G-U8G-C<FEB960["B`@("`@("`@?0H@
M("`@("`@("1N<U]I;F9O(#T@)'1H:7,M/E]G971.86UE<W!A8V4H)&5L=%LG
M=B==*3L*("`@("`@("!I9B`H(6ES7VYU;&PH)&YS7VEN9F\I*2!["B`@("`@
M("`@("`@("1S96%R8VA?<W1R(#T@)&5L=%LG=B==("X@)&YS7VEN9F];)V1E
M;&EM:71E<B==.PH@("`@("`@("`@("!I9B`H*"1E;'1;)W8G72`]/2`G24Y"
M3U@G*2`F)@H@("`@("`@("`@("`@("`@*"1N<U]I;F9O6R=N86UE)UT@/3T@
M*"=)3D)/6"<@+B`D;G-?:6YF;ULG9&5L:6UI=&5R)UTI*2D@>PH@("`@("`@
M("`@("`@("`@)'-E87)C:%]S='(@+CT@)&YS7VEN9F];)VYA;64G73L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!F;W)E86-H("AA<G)A>5]K97ES*"1F
M;VQD97)?;&ES="D@87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@:68@*'-T
M<G!O<R@D=F%L+"`D<V5A<F-H7W-T<BD@/3T](#`I('L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7VAA<T-H:6QD<F5N0V%C:&5;)&5L=%LG=B==72`]
M('1R=64["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("\J($1O(&]N92!F:6YA;"!C:&5C:R!I9B!T:&ES(&ES(&$@;F%M97-P86-E
M(&-O;G1A:6YE<B`M(&EF('=E(&=E=`H@("`@("`@("`J('1H:7,@9F%R+"!A
M;F0@87)E('9I97=I;F<@86QL(&9O;&1E<G,L('1H96X@=V4@:VYO=R!W92!H
M879E(&YO"B`@("`@("`@("H@8VAI;&1R96X@<V\@;6%K92!S=7)E('1H92!E
M;&5M96YT(&ES(&YO="!S970@=&\@97AP86YD960O;W!E;BX@*B\*("`@("`@
M("!I9B`H)&ES7VYS("8F("1T:&ES+3Y?<VAO=W5N<W5B*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?:6YI=$5X<&%N9&5D3&ES="@I.PH@("`@("`@("`@("!I
M9B`H(65M<'1Y*"1T:&ES+3Y?97AP86YD961;)&5L=%LG=B==72DI('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<F5M;W9E17AP86YD961,:7-T*"1E;'1;
M)W8G72D["B`@("`@("`@("`@("`@("`D=&AI<RT^7W-E=$]P96XH)'1H:7,M
M/E]T<F5E6R1E;'1;)W8G75TL(&9A;'-E*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@)&AA<T-H:6QD<F5N0V%C:&5;)&5L=%LG=B==72`]
M(&9A;'-E.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*
M("`@("`J(%-E="!T:&4@8VAI;&1R96X@871T<FEB=71E(&9O<B!A;B!E;&5M
M96YT+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!P87)A;2!A<G)A>2`F)&5L="`@02!T<F5E(&5L96UE;G0N"B`@("`@
M*B!`<&%R86T@;6EX960@)&)O;VP@(%1H92!S971T:6YG+B!)9B!N=6QL+"!C
M;&5A<G,@=&AE(&9L86<N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S971#:&EL
M9')E;B@F)&5L="P@)&)O;VPI"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH
M)&)O;VPI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V5T071T<FEB=71E*"1E
M;'0L($Q!5%1?2$%30TA)3$1214XL(&9A;'-E*3L*("`@("`@("`@("`@)'1H
M:7,M/E]S971!='1R:6)U=&4H)&5L="P@3$%45%](05-.3T-(24Q$4D5.+"!F
M86QS92D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]S
M971!='1R:6)U=&4H)&5L="P@3$%45%](05-#2$E,1%)%3BP@)&)O;VPI.PH@
M("`@("`@("`@("`D=&AI<RT^7W-E=$%T=')I8G5T92@D96QT+"!,05147TA!
M4TY/0TA)3$1214XL("$D8F]O;"D["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@2&%S('1H92!T<F5E(&5L96UE;G0@8F5E;B!D:7-C;W9E<F5D
M/PH@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D96QT("!!('1R964@96QE
M;65N="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@($YO;BUZ97)O
M(&EF('1H92!E;&5M96YT(&AA<R!B965N(&1I<V-O=F5R960N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&ES1&ES8V]V97)E9"@D96QT*0H@("`@>PH@("`@("`@
M(')E='5R;B`D96QT6R=A)UT@)B!)34%05%)%15]%3%1?25-?1$E30T]615)%
M1#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@9&ES8V]V97)E9"!A
M='1R:6)U=&4@9F]R(&%N(&5L96UE;G0N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("8D96QT("`@
M($$@=')E92!E;&5M96YT+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&)O;VP@
M(%1H92!S971T:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<V5T1&ES8V]V
M97)E9"@F)&5L="P@)&)O;VPI"B`@("!["B`@("`@("`@)'1H:7,M/E]S971!
M='1R:6)U=&4H)&5L="P@24U!4%12145?14Q47TE37T1)4T-/5D52140L("1B
M;V]L*3L*("`@('T*"B`@("`O*BH*("`@("`J($ES('1H92!T<F5E(&5L96UE
M;G0@;W!E;C\*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&5L="`@02!T
M<F5E(&5L96UE;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4
M<G5E(&EF('1H92!E;&5M96YT(&ES(&]P96XN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&ES3W!E;B@D96QT*0H@("`@>PH@("`@("`@(&EF("@A)'1H:7,M/E]I
M;FET;6]D92D@>PH@("`@("`@("`@("!R971U<FX@*"@D96QT6R=A)UT@)B!)
M34%05%)%15]%3%1?25-?3U!%3BD@)B8@)'1H:7,M/FAA<T-H:6QD<F5N*"1E
M;'0I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!S=VET8V@@*"1T
M:&ES+3Y?9V5T26YI=$5X<&%N9&5D36]D92@I*2!["B`@("`@("`@("`@(&-A
M<V4@24U!4%12145?3U!%3E].3TY%.@H@("`@("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C
M87-E($E-05!44D5%7T]014Y?04Q,.@H@("`@("`@("`@("`@("`@<F5T=7)N
M('1R=64["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A
M<V4@24U!4%12145?3U!%3E]54T52.@H@("`@("`@("`@("`@("`@)'1H:7,M
M/E]I;FET17AP86YD961,:7-T*"D["B`@("`@("`@("`@("`@("!R971U<FX@
M(65M<'1Y*"1T:&ES+3Y?97AP86YD961;)&5L=%LG=B==72D["B`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J(%-E="!T:&4@;W!E;B!A='1R:6)U=&4@9F]R(&%N
M(&5L96UE;G0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("8D96QT("`@($$@=')E92!E;&5M96YT
M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&)O;VP@(%1H92!S971T:6YG+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?<V5T3W!E;B@F)&5L="P@)&)O;VPI"B`@
M("!["B`@("`@("`@)'1H:7,M/E]S971!='1R:6)U=&4H)&5L="P@24U!4%12
M145?14Q47TE37T]014XL("1B;V]L*3L*("`@("`@("!I9B`H(21T:&ES+3Y?
M:6YI=&UO9&4I('L*("`@("`@("`@("`@)'1H:7,M/E]I;FET17AP86YD961,
M:7-T*"D["B`@("`@("`@("`@(&EF("@D8F]O;"D@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]A9&1%>'!A;F1E9$QI<W0H)&5L=%LG=B==*3L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5M;W9E
M17AP86YD961,:7-T*"1E;'1;)W8G72D["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!)<R!T:&ES(&5L96UE;G0@82!C
M;VYT86EN97(@;VYL>2P@;F]T(&$@;6%I;&)O>"`H;65A;FEN9R!Y;W4@8V%N
M"B`@("`@*B!N;W0@;W!E;B!I="D_"B`@("`@*@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1E;'0@($$@=')E92!E;&5M96YT+@H@("`@("H*("`@("`J($!R971U
M<FX@:6YT96=E<B`@5')U92!I9B!T:&4@96QE;65N="!I<R!A(&-O;G1A:6YE
M<BX*("`@("`J+PH@("`@9G5N8W1I;VX@:7-#;VYT86EN97(H)&5L="D*("`@
M('L*("`@("`@("!R971U<FX@*"@D96QT6R=A)UT@)B!,05147TY/4T5,14-4
M*2!\?`H@("`@("`@("`@("`@("`@*"$D=&AI<RT^7W-H;W=U;G-U8B`F)@H@
M("`@("`@("`@("`@("`@("$D=&AI<RT^:7-3=6)S8W)I8F5D*"1E;'0I("8F
M"B`@("`@("`@("`@("`@("`@)'1H:7,M/FAA<T-H:6QD<F5N*"1E;'0I*2D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&5L96UE;G0@87,@82!C
M;VYT86EN97(_"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("8D96QT("`@($$@=')E92!E;&5M96YT
M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&)O;VP@($ES('1H92!E;&5M96YT
M(&$@8V]N=&%I;F5R/PH@("`@("HO"B`@("!F=6YC=&EO;B!?<V5T0V]N=&%I
M;F5R*"8D96QT+"`D8F]O;"D*("`@('L*("`@("`@("`D=&AI<RT^7W-E=$%T
M=')I8G5T92@D96QT+"!,05147TY/4T5,14-4+"`D8F]O;"D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!)<R!T:&4@=7-E<B!S=6)S8W)I8F5D('1O('1H:7,@
M96QE;65N=#\*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&5L="`@02!T
M<F5E(&5L96UE;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4
M<G5E(&EF('1H92!U<V5R(&ES('-U8G-C<FEB960@=&\@=&AE(&5L96UE;G0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES4W5B<V-R:6)E9"@D96QT*0H@("`@
M>PH@("`@("`@(')E='5R;B`D96QT6R=A)UT@)B!)34%05%)%15]%3%1?25-?
M4U5"4T-224)%1#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@<W5B
M<V-R:7!T:6]N('-T871U<R!F;W(@86X@96QE;65N="X*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)B1E;'0@("`@02!T<F5E(&5L96UE;G0N"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D8F]O;"`@27,@=&AE(&5L96UE;G0@<W5B<V-R:6)E9"!T;S\*("`@("`J
M+PH@("`@9G5N8W1I;VX@7W-E=%-U8G-C<FEB960H)B1E;'0L("1B;V]L*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?<V5T071T<FEB=71E*"1E;'0L($E-05!4
M4D5%7T5,5%])4U]354)30U))0D5$+"`D8F]O;"D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!)<R!T:&4@96QE;65N="!A(&YA;65S<&%C92!C;VYT86EN97(_
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1E;'0@($$@=')E92!E;&5M
M96YT+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5')U92!I9B!T
M:&4@96QE;65N="!I<R!A(&YA;65S<&%C92!C;VYT86EN97(_"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&ES3F%M97-P86-E*"1E;'0I"B`@("!["B`@("`@("`@
M<F5T=7)N("1E;'1;)V$G72`F($E-05!44D5%7T5,5%].04U%4U!!0T4["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F4@=&AE('-E<G9E<B!S=')I;F<@
M9G)O;2!T:&4@)VYA;64G('!A<F%M971E<BX*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@;V)J96-T('-T9$-L
M87-S("1O8B`@06X@;V)J96-T(')E='5R;F5D(&9R;VT*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I;6%P7V=E=&UA:6QB;WAE<R@I+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1D0VQA<W,@(%1H92!O8FIE8W0@<F5T
M=7)N960@=VET:"!T:&4@<V5R=F5R('-T<FEN9R!S=')I<'!E9`H@("`@("H@
M("`@("`@("`@("`@("`@("`@9G)O;2!T:&4@)VYA;64G('!A<F%M971E<BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@7W)E;6]V95-E<G9E<E-T<FEN9R@D;V(I
M"B`@("!["B`@("`@("`@)&]B+3YF=6QL4V5R=F5R4&%T:"`]("1O8BT^;F%M
M93L*("`@("`@("`D;V(M/FYA;64@/2`D=&AI<RT^7V-O;G9E<G1.86UE*'-U
M8G-T<B@D;V(M/FYA;64L('-T<G!O<R@D;V(M/FYA;64L("=])RD@*R`Q*2D[
M"B`@("`@("`@<F5T=7)N("1O8CL*("`@('T*"B`@("`O*BH*("`@("`J($EN
M:71I86QI>F4@=&AE(&5X<&%N9&5D(&9O;&1E<B!L:7-T+@H@("`@("H@5$A)
M4R!-151(3T0@4TA/54Q$($)%($1%1DE.140@24X@04Q,(%-50D-,05-315,N
M"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]I;FET17AP86YD961,
M:7-T*"D*("`@('L*("`@("`@("`D=&AI<RT^7V5X<&%N9&5D(#T@87)R87DH
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($%D9"!A;B!E;&5M96YT('1O('1H
M92!E>'!A;F1E9"!L:7-T+@H@("`@("H@5$A)4R!-151(3T0@4TA/54Q$($)%
M($1%1DE.140@24X@04Q,(%-50D-,05-315,N"B`@("`@*@H@("`@("H@0&%B
M<W1R86-T"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D:60@(%1H92!E;&5M96YT(&YA;64@=&\@
M<F5M;W9E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?861D17AP86YD961,:7-T
M*"1I9"D*("`@('L*("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V92!A;B!E
M;&5M96YT(&9R;VT@=&AE(&5X<&%N9&5D(&QI<W0N"B`@("`@*B!42$E3($U%
M5$A/1"!32$]53$0@0D4@1$5&24Y%1"!)3B!!3$P@4U5"0TQ!4U-%4RX*("`@
M("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE(&5L
M96UE;G0@;F%M92!T;R!R96UO=F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]R
M96UO=F5%>'!A;F1E9$QI<W0H)&ED*0H@("`@>PH@("`@?0H*("`@("\J*@H@
M("`@("H@26YI=&EA;&EZ92]G970@=&AE(&QI<W0@;V8@96QE;65N=',@=&\@
M<&]L;"X*("`@("`J(%1(25,@34542$]$(%-(3U5,1"!"12!$149)3D5$($E.
M($%,3"!354)#3$%34T53+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!L:7-T(&]F(&5L96UE;G1S
M('1O('!O;&P@*&YA;64@:6X@:V5Y(&9I96QD*2X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T4&]L;$QI<W0H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<&]L
M;"`](&%R<F%Y*"D["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&]L;#L*("`@
M('T*"B`@("`O*BH*("`@("`J($%D9"!E;&5M96YT('1O('1H92!P;VQL(&QI
M<W0N"B`@("`@*B!42$E3($U%5$A/1"!32$]53$0@0D4@1$5&24Y%1"!)3B!!
M3$P@4U5"0TQ!4U-%4RX*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J
M"B`@("`@*B!`<&%R86T@;6EX960@)&ED("!4:&4@96QE;65N="!N86UE(&]R
M(&$@;&ES="!O9B!E;&5M96YT(&YA;65S('1O(&%D9"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@861D4&]L;$QI<W0H)&ED*0H@("`@>PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5M;W9E(&5L96UE;G0@9G)O;2!T:&4@<&]L;"!L:7-T+@H@
M("`@("H@5$A)4R!-151(3T0@4TA/54Q$($)%($1%1DE.140@24X@04Q,(%-5
M0D-,05-315,N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D:60@(%1H92!F;VQD97(O;6%I;&)O>"!O<B!A
M(&QI<W0@;V8@9F]L9&5R<R]M86EL8F]X97,*("`@("`J("`@("`@("`@("`@
M("`@("`@("!T;R!R96UO=F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V
M95!O;&Q,:7-T*"1I9"D*("`@('L*("`@('T*"B`@("`O*BH*("`@("`J($1O
M97,@=&AE('5S97(@=V%N="!T;R!P;VQL('1H:7,@;6%I;&)O>"!F;W(@;F5W
M+W5N<V5E;B!M97-S86=E<S\*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)&5L="`@02!T<F5E(&5L96UE;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!I
M;G1E9V5R("!4<G5E(&EF('1H92!U<V5R('=A;G1S('1O('!O;&P@=&AE(&5L
M96UE;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES4&]L;&5D*"1E;'0I"B`@
M("!["B`@("`@("`@<F5T=7)N("1E;'1;)V$G72`F($E-05!44D5%7T5,5%])
M4U]03TQ,140["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE('!O;&QE
M9"!A='1R:6)U=&4@9F]R(&%N(&5L96UE;G0N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("8D96QT
M("`@($$@=')E92!E;&5M96YT+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&)O
M;VP@(%1H92!S971T:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<V5T4&]L
M;&5D*"8D96QT+"`D8F]O;"D*("`@('L*("`@("`@("`D=&AI<RT^7W-E=$%T
M=')I8G5T92@D96QT+"!)34%05%)%15]%3%1?25-?4$],3$5$+"`D8F]O;"D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!&;&%G('1H92!E;&5M96YT(&%S(&YE
M961I;F<@:71S(&-H:6QD<F5N('1O(&)E('-O<G1E9"X*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)B1E;'0@("`@02!T<F5E(&5L96UE;G0N"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D8F]O;"`@5&AE('-E='1I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S
M971.965D4V]R="@F)&5L="P@)&)O;VPI"B`@("!["B`@("`@("`@)'1H:7,M
M/E]S971!='1R:6)U=&4H)&5L="P@24U!4%12145?14Q47TY%141?4T]25"P@
M)&)O;VPI.PH@("`@?0H*("`@("\J*@H@("`@("H@1&]E<R!T:&ES(&5L96UE
M;G0G<R!C:&EL9')E;B!N965D('-O<G1I;F<_"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1E;'0@($$@=')E92!E;&5M96YT+@H@("`@("H*("`@("`J
M($!R971U<FX@:6YT96=E<B`@5')U92!I9B!T:&4@8VAI;&1R96X@;F5E9"!T
M;R!B92!S;W)T960N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]N965D4V]R="@D
M96QT*0H@("`@>PH@("`@("`@(')E='5R;B`D96QT6R=A)UT@)B!)34%05%)%
M15]%3%1?3D5%1%]33U)4.PH@("`@?0H*("`@("\J*@H@("`@("H@26YI=&EA
M;&EZ92!T:&4@;&ES="!O9B!S=6)S8W)I8F5D(&UA:6QB;WAE<RX*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@
M7VEN:713=6)S8W)I8F5D*"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D
M=&AI<RT^7W-U8G-C<FEB960I*2!["B`@("`@("`@("`@("1T:&ES+3Y?8VAA
M;F=E9"`]('1R=64["B`@("`@("`@("`@("1T:&ES+3Y?<W5B<V-R:6)E9"`]
M(&%R<F%Y*"D["B`@("`@("`@("`@("1S=6)L:7-T(#T@87)R87DH*3L*"B`@
M("`@("`@("`@("\J($E.0D]8(&ES(&%L=V%Y<R!S=6)S8W)I8F5D('1O(&EF
M('=E(&%R92!I;B!M86EL(&UO9&4N("HO"B`@("`@("`@("`@(&EF("@D=&AI
M<RT^7VUO9&4@/3T@24U!4%12145?34]$15]-04E,*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7W-U8G-C<FEB961;)TE.0D]8)UT@/2`Q.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("!I9B`H)'1H:7,M/E]N86UE<W!A8V5S*2![
M"B`@("`@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7VYA;65S<&%C97,@
M87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@("`@("1T;7`@/2!`:6UA<%]L
M<W5B*"1T:&ES+3Y?9V5T4W1R96%M*"DL("1T:&ES+3Y?<V5R=F5R+"`D=F%L
M6R=N86UE)UT@+B`G*B<I.PH@("`@("`@("`@("`@("`@("`@(&EF("@A96UP
M='DH)'1M<"DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'-U8FQI<W0@
M/2!A<G)A>5]M97)G92@D<W5B;&ES="P@)'1M<"D["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)'-U8FQI<W0@/2!`:6UA<%]L<W5B*"1T:&ES
M+3Y?9V5T4W1R96%M*"DL("1T:&ES+3Y?<V5R=F5R+"`D=&AI<RT^7W!R969I
M>"`N("<J)RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@A96UP
M='DH)'-U8FQI<W0I*2!["B`@("`@("`@("`@("`@("!F;W)E86-H("@D<W5B
M;&ES="!A<R`D=F%L*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S
M=6)S8W)I8F5D6W-U8G-T<B@D=F%L+"!S=')P;W,H)'9A;"P@)WTG*2`K(#$I
M72`](#$["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!);FET:6%L:7IE('1H92!L:7-T
M(&]F('5N<W5B<V-R:6)E9"!M86EL8F]X97,N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]I;FET56YS=6)S
M8W)I8F5D*"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^7W5N
M<W5B<V-R:6)E9"DI('L*("`@("`@("`@("`@)'1H:7,M/E]C:&%N9V5D(#T@
M=')U93L*("`@("`@("`@("`@)'1H:7,M/E]I;FET4W5B<V-R:6)E9"@I.PH@
M("`@("`@("`@("`D=&AI<RT^7W5N<W5B<V-R:6)E9"`](&%R<F%Y*"D["B`@
M("`@("`@("`@("1A;&Q?;&ES="`](&%R<F%Y*"D["@H@("`@("`@("`@("`O
M*B!'970@;&ES="!O9B!A;&P@;6%I;&)O>&5S+B`J+PH@("`@("`@("`@("!I
M9B`H)'1H:7,M/E]N86UE<W!A8V5S*2!["B`@("`@("`@("`@("`@("!F;W)E
M86-H("@D=&AI<RT^7VYA;65S<&%C97,@87,@)'9A;"D@>PH@("`@("`@("`@
M("`@("`@("`@("1T;7`@/2!`:6UA<%]L:7-T*"1T:&ES+3Y?9V5T4W1R96%M
M*"DL("1T:&ES+3Y?<V5R=F5R+"`D=F%L6R=N86UE)UT@+B`G*B<I.PH@("`@
M("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'1M<"DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&%L;%]L:7-T(#T@87)R87E?;65R9V4H)&%L;%]L
M:7-T+"`D=&UP*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M86QL7VQI<W0@/2!`:6UA<%]L:7-T*"1T:&ES+3Y?9V5T4W1R96%M*"DL("1T
M:&ES+3Y?<V5R=F5R+"`D=&AI<RT^7W!R969I>"`N("<J)RD["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@(&EF("@A96UP='DH)&%L;%]L:7-T*2D@>PH@
M("`@("`@("`@("`@("`@+RH@1FEN9"!A;&P@;6%I;&)O>&5S('1H870@87)E
M;B=T(&EN('1H92!S=6)S8W)I8F5D(&QI<W0N("HO"B`@("`@("`@("`@("`@
M("!F;W)E86-H("@D86QL7VQI<W0@87,@)'9A;"D@>PH@("`@("`@("`@("`@
M("`@("`@("1V86P@/2!S=6)S='(H)'9A;"P@<W1R<&]S*"1V86PL("=])RD@
M*R`Q*3L*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?
M<W5B<V-R:6)E9%LD=F%L72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]U;G-U8G-C<FEB961;)'9A;%T@/2`Q.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-H;W5L9"!W92!E>'!A;F0@
M86QL(&5L96UE;G1S/PH@("`@("HO"B`@("!F=6YC=&EO;B!E>'!A;F1!;&PH
M*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<&%R96YT6VYU;&Q=
M(&%S("1V86PI('L*("`@("`@("`@("`@)'1H:7,M/F5X<&%N9"@D=F%L+"!T
M<G5E*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3:&]U;&0@
M=V4@8V]L;&%P<V4@86QL(&5L96UE;G1S/PH@("`@("HO"B`@("!F=6YC=&EO
M;B!C;VQL87!S94%L;"@I"B`@("!["B`@("`@("`@9F]R96%C:"`H)'1H:7,M
M/E]T<F5E(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("!I9B`H)&ME
M>2`A/2!)34%05%)%15]"05-%7T5,5"D@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/F-O;&QA<'-E*"1V86Q;)W8G72D["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("\J($-L96%R(&%L;"!E;G1R:65S(&9R;VT@=&AE(&5X
M<&%N9&5D(&QI<W0N("HO"B`@("`@("`@)'1H:7,M/E]I;FET17AP86YD961,
M:7-T*"D["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]E>'!A;F1E9"!A<R`D
M:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@)'1H:7,M/E]R96UO=F5%>'!A
M;F1E9$QI<W0H)&ME>2D["B`@("`@("`@?0H*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;B!T:&4@;&ES="!O9B!M86EL8F]X97,@:6X@=&AE(&YE>'0@
M;&5V96PN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D:60@(%1H92!C=7)R96YT(&UA:6QB;W@N
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!L:7-T(&]F(&UA:6QB
M;W@@;V)J96-T<R!O<B!T:&4@96UP='D@;&ES="X*("`@("`J("`@("`@("`@
M("`@("`@(%-E92!?9V5T3&ES="@I(&9O<B!F;W)M870N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]C:&EL9')E;DEN9F\H)&ED*0H@("`@>PH@("`@("`@("1I
M;F9O(#T@87)R87DH*3L*("`@("`@("`D;G-?:6YF;R`]("1T:&ES+3Y?9V5T
M3F%M97-P86-E*"1I9"D["@H@("`@("`@(&EF("AI<U]N=6QL*"1N<U]I;F9O
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&EN9F\["B`@("`@("`@?0H*("`@
M("`@("!I9B`H*"1I9"`]/2`G24Y"3U@G*2`F)@H@("`@("`@("`@("`H)&YS
M7VEN9F];)VYA;64G72`]/2`H)TE.0D]8)R`N("1N<U]I;F9O6R=D96QI;6ET
M97(G72DI*2!["B`@("`@("`@("`@("1S96%R8V@@/2`D:60@+B`D;G-?:6YF
M;ULG9&5L:6UI=&5R)UT@+B`D;G-?:6YF;ULG;F%M92==.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1S96%R8V@@/2`D:60@+B`D;G-?:6YF;ULG
M9&5L:6UI=&5R)UT["B`@("`@("`@?0H*("`@("`@("`D:6YF;R`]("1T:&ES
M+3Y?9V5T3&ES="@D<V5A<F-H("X@)R4G*3L*"B`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?=')E95LD:61=*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W-E
M=$-H:6QD<F5N*"1T:&ES+3Y?=')E95LD:61=+"`A96UP='DH)&EN9F\I*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6YF;SL*("`@('T*"B`@("`O
M*BH*("`@("`J(%-W:71C:"!S=6)S8W)I8F5D+W5N<W5B<V-R:6)E9"!V:65W
M:6YG+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1U;G-U8B`@4VAO
M=R!U;G-U8G-C<FEB960@96QE;65N=',_"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-H;W=5;G-U8G-C<FEB960H)'5N<W5B*0H@("`@>PH@("`@("`@(&EF("@D
M=6YS=6(@/3T]("1T:&ES+3Y?<VAO=W5N<W5B*2!["B`@("`@("`@("`@(')E
M='5R;CL*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?<VAO=W5N<W5B(#T@
M)'5N<W5B.PH@("`@("`@("1T:&ES+3Y?8VAA;F=E9"`]('1R=64["@H@("`@
M("`@("\J($EF('=E(&%R92!S=VET8VAI;F<@9G)O;2!U;G-U8G-C<FEB960@
M=&\@<W5B<V-R:6)E9"P@;F\@;F5E9`H@("`@("`@("`J('1O(&1O(&%N>71H
M:6YG("AW92!J=7-T(&EG;F]R92!U;G-U8G-C<FEB960@<W1U9F8I+B`J+PH@
M("`@("`@(&EF("@D=6YS=6(@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E
M='5R;CL*("`@("`@("!]"@H@("`@("`@("\J($EF('=E(&%R92!S=VET8VAI
M;F<@9G)O;2!S=6)S8W)I8F5D('1O('5N<W5B<V-R:6)E9"P@=V4@;F5E9`H@
M("`@("`@("`J('1O(&%D9"!A;&P@=6YS=6)S8W)I8F5D(&5L96UE;G1S('1H
M870@;&EV92!I;B!C=7)R96YT;'D*("`@("`@("`@*B!D:7-C;W9E<F5D(&ET
M96US+B`J+PH@("`@("`@("1T:&ES+3Y?=6YS=6)V:65W(#T@=')U93L*("`@
M("`@("`D=&AI<RT^7VEN:715;G-U8G-C<FEB960H*3L*("`@("`@("!I9B`H
M96UP='DH)'1H:7,M/E]U;G-U8G-C<FEB960I*2!["B`@("`@("`@("`@(')E
M='5R;CL*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?:6YI=&UO9&4@/2!)
M34%05%)%15])3DE47U5.4U5".PH@("`@("`@("1T:&ES+3YI;G-E<G0H87)R
M87E?:V5Y<R@D=&AI<RT^7W5N<W5B<V-R:6)E9"DI.PH@("`@("`@("1T:&ES
M+3Y?:6YI=&UO9&4@/2`P.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!A(')E9F5R96YC92!T;R!A(&-U<G)E;G1L>2!O<&5N($E-05`@<W1R96%M
M+@H@("`@("H@5$A)4R!-151(3T0@35535"!"12!$149)3D5$($E.($%,3"!3
M54)#3$%34T53+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@<F5S
M;W5R8V4@($%N($E-05`@<F5S;W5R8V4@<W1R96%M+@H@("`@("HO"B`@("!F
M=6YC=&EO;B`F7V=E=%-T<F5A;2@I"B`@("!["B`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8W5R<F5N
M=&QY('-E;&5C=&5D(&EN:71I86QI>F%T:6]N(&5X<&%N9&5D(&UO9&4N"B`@
M("`@*B!42$E3($U%5$A/1"!32$]53$0@0D4@1$5&24Y%1"!)3B!!3$P@4U5"
M0TQ!4U-%4RX*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G
M97(@(%1H92!C=7)R96YT(&EN:71I86QI>F%T:6]N(&5X<&%N9&5D(&UO9&4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971);FET17AP86YD961-;V1E*"D*
M("`@('L*("`@("`@("!R971U<FX@24U!4%12145?3U!%3E].3TY%.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1V5T(&EN9F]R;6%T:6]N(&%B;W5T(&YE=R]U
M;G-E96XO=&]T86P@;65S<V%G97,@9F]R('1H92!G:79E;B!E;&5M96YT+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!E;&5M96YT
M(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@07)R87D@=VET
M:"!T:&4@9F]L;&]W:6YG(&9I96QD<SH*("`@("`J(#QP<F4^"B`@("`@*B`G
M;65S<V%G97,G("`M+2`@3G5M8F5R(&]F('1O=&%L(&UE<W-A9V5S+@H@("`@
M("H@)VYE=VUS9R<@("`@+2T@($YU;6)E<B!O9B!N97<@;65S<V%G97,N"B`@
M("`@*B`G=6YS965N)R`@("`M+2`@3G5M8F5R(&]F('5N<V5E;B!M97-S86=E
M<RX*("`@("`J(#PO<')E/@H@("`@("HO"B`@("!F=6YC=&EO;B!G971%;&5M
M96YT26YF;R@D;F%M92D*("`@('L*("`@("`@("`D<W1A='5S(#T@87)R87DH
M*3L*"B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92])34%0+T-A8VAE+G!H
M<"<["B`@("`@("`@)&EM87!?8V%C:&4@/2`F24U!4%]#86-H93HZ<VEN9VQE
M=&]N*"D["B`@("`@("`@)'-T<R`]("1I;6%P7V-A8VAE+3YG9713=&%T=7,H
M)'1H:7,M/E]G9713=')E86TH*2P@)'1H:7,M/E]S97)V97(@+B`D;F%M92D[
M"B`@("`@("`@:68@*"%E;7!T>2@D<W1S*2D@>PH@("`@("`@("`@("`D<W1A
M='5S6R=M97-S86=E<R==(#T@)'-T<RT^;65S<V%G97,["B`@("`@("`@("`@
M("1S=&%T=7-;)W5N<V5E;B==(#T@:7-S970H)'-T<RT^=6YS965N*2`_("1S
M=',M/G5N<V5E;B`Z(#`["B`@("`@("`@("`@("1S=&%T=7-;)VYE=VUS9R==
M(#T@:7-S970H)'-T<RT^<F5C96YT*2`_("1S=',M/G)E8V5N="`Z(#`["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)'-T871U<SL*("`@('T*"B`@("`O
M*BH*("`@("`J(%-O<G1S(&$@;&ES="!O9B!M86EL8F]X97,N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R
M<F%Y("8D;6)O>"`@(%1H92!L:7-T(&]F(&UA:6QB;WAE<R!T;R!S;W)T+@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)&)A<V4@($%R92!W92!S;W)T:6YG(&$@
M;&ES="!O9B!M86EL8F]X97,@:6X@=&AE(&)A<V4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!O9B!T:&4@=')E92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@7W-O<G1,:7-T*"8D;6)O>"P@)&)A<V4@/2!F86QS92D*("`@('L*("`@
M("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^7VEM87!?<V]R="DI('L*("`@("`@
M("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92])34%0+U-O<G0N<&AP)SL*("`@
M("`@("`@("`@)'1H:7,M/E]I;6%P7W-O<G0@/2`F;F5W($E-05!?4V]R="@D
M=&AI<RT^7V1E;&EM:71E<BD["B`@("`@("`@?0H*("`@("`@("!I9B`H)&)A
M<V4I('L*("`@("`@("`@("`@9F]R96%C:"`H)&UB;W@@87,@)'9A;"D@>PH@
M("`@("`@("`@("`@("`@)&)A<V5S;W)T6R1V86Q=(#T@*"1V86P@/3T@)TE.
M0D]8)RD@/R`G24Y"3U@G(#H@)'1H:7,M/E]T<F5E6R1V86Q=6R=L)UT["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]I;6%P7W-O<G0M/G-O
M<G1-86EL8F]X97,H)&)A<V5S;W)T+"`H)'1H:7,M/E]M;V1E(#T]($E-05!4
M4D5%7TU/1$5?34%)3"DL('1R=64L('1R=64I.PH@("`@("`@("`@("`D;6)O
M>"`](&%R<F%Y7VME>7,H)&)A<V5S;W)T*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D=&AI<RT^7VEM87!?<V]R="T^<V]R=$UA:6QB;WAE<R@D
M;6)O>"P@*"1T:&ES+3Y?;6]D92`]/2!)34%05%)%15]-3T1%7TU!24PI*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@82!.;VXM
M24U!4"!M86EL8F]X(&5L96UE;G0@9VEV96X@86X@96QE;65N="!I9&5N=&EF
M:65R+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED
M("!4:&4@96QE;65N="!I9&5N=&EF:65R+@H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@($$@;6%I;&)O>"!E;&5M96YT+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?9V5T3F]N24U!4$5L="@D:60I"B`@("!["B`@("`@("`@<F5T=7)N
M(&%R<F%Y*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!)<R!T:&4@9VEV96X@
M96QE;65N="!A;B`B86-T:79E(B!E;&5M96YT("AI+F4N(&%N(&5L96UE;G0@
M=&AA="!S:&]U;&0*("`@("`J(&)E('=O<FME9"!W:71H(&=I=F5N('1H92!C
M=7)R96YT('9I97=I;F<@<&%R86UE=&5R<RDN"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1E;'0@
M($$@=')E92!E;&5M96YT+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5')U92!I9B!I="!I<R!A;B!A8W1I=F4@96QE;65N="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V%C=&EV945L="@D96QT*0H@("`@>PH@("`@("`@(&EF
M("@D=&AI<RT^7W-H;W=U;G-U8B`F)@H@("`@("`@("`@("`D=&AI<RT^:7-.
M86UE<W!A8V4H)&5L="DI('L*("`@("`@("`@("`@<F5T=7)N("@D=&AI<RT^
M:&%S0VAI;&1R96XH)&5L="DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B`H)'1H:7,M/E]S:&]W=6YS=6(@?'P*("`@("`@("`@("`@
M("`@("`@("`H)'1H:7,M/FES4W5B<V-R:6)E9"@D96QT*2`F)B`A)'1H:7,M
M/FES0V]N=&%I;F5R*"1E;'0I*2!\?`H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YH87-#:&EL9')E;B@D96QT*2D["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@0V]N=F5R="!A(&UA:6QB;W@@;F%M92!T;R!T:&4@8V]R
M<F5C="P@:6YT97)N86P@;F%M92`H:2YE+B!M86ME('-U<F4*("`@("`J($E.
M0D]8(&ES(&%L=V%Y<R!C87!I=&%L:7IE9"!F;W(@24U!4"!S97)V97)S*2X*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1N86UE("!4:&4@;6%I;&)O>"!N86UE+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8V]N=F5R=&5D(&YA;64N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]C;VYV97)T3F%M92@D;F%M92D*("`@('L*
M("`@("`@("!R971U<FX@*"@D=&AI<RT^7VUO9&4@/3T@24U!4%12145?34]$
M15]-04E,*2`F)B`H<W1R8V%S96-M<"@D;F%M92P@)TE.0D]8)RD@/3T@,"DI
M(#\@)TE.0D]8)R`Z("1N86UE.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T
M(&YA;65S<&%C92!I;F9O(&9O<B!A(&9U;&P@9F]L9&5R('!A=&@N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;6%I;&)O>"`@5&AE(&9O;&1E<B!P871H+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1H92!N86UE<W!A8V4@:6YF;R!F;W(@=&AE
M(&9O;&1E<B!P871H(&]R(&YU;&P@:68@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@("!P871H(&1O97-N)W0@97AI<W0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]G971.86UE<W!A8V4H)&UA:6QB;W@I"B`@("!["B`@("`@("`@<W1A=&EC
M("1N86UE<W!A8V5#86-H92`](&%R<F%Y*"D["@H@("`@("`@(&EF("AI<W-E
M="@D;F%M97-P86-E0V%C:&5;)&UA:6QB;WA=*2D@>PH@("`@("`@("`@("!R
M971U<FX@)&YA;65S<&%C94-A8VAE6R1M86EL8F]X73L*("`@("`@("!]"@H@
M("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]N86UE<W!A8V5S*2D@>PH@("`@
M("`@("`@("!F;W)E86-H("@D=&AI<RT^7VYA;65S<&%C97,@87,@)&ME>2`]
M/B`D=F%L*2!["B`@("`@("`@("`@("`@("!I9B`H*"@D;6%I;&)O>"`N("1V
M86Q;)V1E;&EM:71E<B==*2`]/2`D:V5Y*2!\?`H@("`@("`@("`@("`@("`@
M("`@("@A96UP='DH)&ME>2D@)B8@*'-T<G!O<R@D;6%I;&)O>"P@)&ME>2D@
M/3T](#`I*2D@>PH@("`@("`@("`@("`@("`@("`@("1N86UE<W!A8V5#86-H
M95LD;6%I;&)O>%T@/2`D=F%L.PH@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D=F%L.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]N86UE<W!A8V5S6R<G72DI('L*
M("`@("`@("`@("`@("`@("1N86UE<W!A8V5#86-H95LD;6%I;&)O>%T@/2`D
M=&AI<RT^7VYA;65S<&%C97-;)R==.PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?;F%M97-P86-E<ULG)UT["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("1N86UE<W!A8V5#86-H95LD;6%I;&)O>%T@/2!N=6QL.PH@("`@
M("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!I9B`H<W5B<W1R*"1T:&ES+3Y?<')E9FEX+"`M,2D@/3T@)'1H:7,M
M/E]D96QI;6ET97(I('L*("`@("`@("`@("`@("`@("1N86UE(#T@<W5B<W1R
M*"1T:&ES+3Y?<')E9FEX+"`P+"!S=')L96XH)'1H:7,M/E]P<F5F:7@I("T@
M,2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D;F%M
M92`]("1T:&ES+3Y?<')E9FEX.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1N86UE<W!A8V5#86-H95LD;6%I;&)O>%T@/2!A<G)A>2@G9&5L:6UI=&5R
M)R`]/B`D=&AI<RT^7V1E;&EM:71E<BP@)VYA;64G(#T^("1N86UE+"`G='EP
M92<@/3X@)W!E<G-O;F%L)RD["B`@("`@("`@("`@(')E='5R;B`D;F%M97-P
M86-E0V%C:&5;)&UA:6QB;WA=.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($1O97,@=&AE($E-05`@<V5R=F5R('-U<'!O<G0@=&AE("=#2$E,
M1%)%3B<@24U!4"!E>'1E;G-I;VX_"B`@("`@*@H@("`@("H@0'!A<F%M(&)O
M;VQE86X@)'-U<'!O<G0@(%1R=64@:68@=&AE($E-05`@<V5R=F5R('-U<'!O
M<G1S('1H92!#2$E,1%)%3@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@(&5X=&5N<VEO;BP@9F%L<V4@:68@:70@9&]E<VXG="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@24U!4&-H:6QD<F5N4W5P<&]R="@D<W5P<&]R="D*("`@
M('L*("`@("`@("`D=&AI<RT^7V-H:6QD<F5N<W5P<&]R="`]("AB;V]L*2`D
M<W5P<&]R=#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@<W1A<G0@
M<&]I;G0@9F]R(&1E=&5R;6EN:6YG(&5L96UE;G0@9&EF9F5R96YC97,@=FEA
M(&5L=$1I9F8H*2X*("`@("`J"B`@("`@*B!`<VEN8V4@2&]R9&4@,RXQ"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&5L=$1I9F93=&%R="@I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]E;'1D:69F(#T@)'1H:7,M/E]T<F5E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N('1H92!L:7-T(&]F(&5L96UE;G1S('1H870@
M:&%V92!C:&%N9V5D('-I;F-E(&YO9&5$:69F4W1A<G0H*0H@("`@("H@=V%S
M(&QA<W0@8V%L;&5D+@H@("`@("H*("`@("`J($!S:6YC92!(;W)D92`S+C$*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!W:71H('1H
M92!F;VQL;W=I;F<@:V5Y<SH*("`@("`J(#QP<F4^"B`@("`@*B`G82<@/3X@
M02!L:7-T(&]F(&5L96UE;G1S('1H870@:&%V92!B965N(&%D9&5D+@H@("`@
M("H@)V,G(#T^($$@;&ES="!O9B!E;&5M96YT<R!T:&%T(&AA=F4@8F5E;B!C
M:&%N9V5D+@H@("`@("H@)V0G(#T^($$@;&ES="!O9B!E;&5M96YT<R!T:&%T
M(&AA=F4@8F5E;B!D96QE=&5D+@H@("`@("H@/"]P<F4^"B`@("`@*B`@("`@
M("`@("`@("`@("!2971U<FYS(&9A;'-E(&EF(&YO(&-H86YG97,@:&%V92!O
M8V-U<G)E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@96QT1&EF9B@I"B`@("![
M"B`@("`@("`@:68@*"$D=&AI<RT^7V-H86YG960@?'P@(21T:&ES+3Y?96QT
M9&EF9BD@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*
M("`@("`@("`D861D960@/2`D8VAA;F=E9"`]("1D96QE=&5D(#T@87)R87DH
M*3L*"B`@("`@("`@+RH@1&5T97)M:6YE('1H92!D96QE=&5D(&ET96US+B`J
M+PH@("`@("`@("1D96QE=&5D(#T@87)R87E?=F%L=65S*&%R<F%Y7V1I9F8H
M87)R87E?:V5Y<R@D=&AI<RT^7V5L=&1I9F8I+"!A<G)A>5]K97ES*"1T:&ES
M+3Y?=')E92DI*3L*"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]T<F5E(&%S
M("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3Y?96QT9&EF9ELD:V5Y72DI('L*("`@("`@("`@("`@("`@("1A9&1E9%M=
M(#T@)&ME>3L*("`@("`@("`@("`@?2!E;'-E:68@*"1V86P@(3T@)'1H:7,M
M/E]E;'1D:69F6R1K97E=*2!["B`@("`@("`@("`@("`@("`D8VAA;F=E9%M=
M(#T@)&ME>3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@
M*&5M<'1Y*"1A9&1E9"D@)B8@96UP='DH)&-H86YG960I("8F(&5M<'1Y*"1D
M96QE=&5D*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"=A)R`]/B`D861D
M960L("=C)R`]/B`D8VAA;F=E9"P@)V0G(#T^("1D96QE=&5D*3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ*BH@1&5P<F5C871E9"!V87)I86)L97,O9G5N
M8W1I;VYS+B!4:&5S92!R96UA:6X@9F]R($)#(&]N;'DN("HJ*BHO"@H@("`@
M+RHJ"B`@("`@*B!4:&4@<')E9FEX('=I=&AO=70@82!T<F%I;&EN9R!D96QI
M;6ET97(N"B`@("`@*@H@("`@("H@0&1E<')E8V%T960@<VEN8V4@2&]R9&4@
M,RXQ"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]P<F5F
M:7AN;V1E;&EM(#T@)R<["@H@("`@+RHJ"B`@("`@*B!4:&4@<V5R=F5R('-T
M<FEN9R!U<V5D(&9O<B!T:&4@9&5L:6UI=&5R+@H@("`@("H@5$A)4R!32$]5
M3$0@0D4@4T54($E.($5615)9(%-50D-,05-3($-/3E-44E5#5$]2+@H@("`@
M("H*("`@("`J($!D97!R96-A=&5D('-I;F-E($AO<F1E(#,N,0H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?9&5L:6UI=&5R(#T@)R\G
M.PH*("`@("\J*@H@("`@("H@5VAE<F4@=V4@<W1A<G0@;&ES=&EN9R!F;VQD
M97)S+@H@("`@("H@5$A)4R!32$]53$0@0D4@4T54($E.($5615)9(%-50D-,
M05-3($-/3E-44E5#5$]2+@H@("`@("H*("`@("`J($!D97!R96-A=&5D('-I
M;F-E($AO<F1E(#,N,0H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1?<')E9FEX(#T@)R<["@H@("`@+RHJ"B`@("`@*B!4:&4@;&]C871I
M;VX@;V8@=&AE(&9I<G-T(&QE=F5L(&]F(&9O;&1E<G,@8F5L;W<@=&AE($E.
M0D]8+@H@("`@("H@5$A)4R!32$]53$0@0D4@4T54($E.($5615)9(%-50D-,
M05-3($-/3E-44E5#5$]2+@H@("`@("H*("`@("`J($!D97!R96-A=&5D('-I
M;F-E($AO<F1E(#,N,0H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1?;F%M97-P86-E(#T@)R<["@H@("`@+RHJ"B`@("`@*B!3:&]U;&0@
M9&]T9FEL97,@8F4@<VAO=VX_"B`@("`@*B!42$E3(%-(3U5,1"!"12!3150@
M24X@159%4ED@4U5"0TQ!4U,@0T].4U1254-43U(N"B`@("`@*@H@("`@("H@
M0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7V1O=&9I;&5S(#T@9F%L
M<V4["@H@("`@+RHJ"B`@("`@*B!4:&4@97AI<W1E;F-E(&]F('1H:7,@9G5N
M8W1I;VX@:6X@24U!4%]4<F5E(&EN9&EC871E<R!T:&%T(&5X=&5N9&5D"B`@
M("`@*B!N86UE<W!A8V4@<W5P<&]R="!I<R!A=F%I;&%B;&4N"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N("!2971U<FYS('1R=64N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&5X=&5N9&5D3F%M97-P86-E4W5P<&]R="@I"B`@("![
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FX@=&AE('!R969I>"X*("`@("`J"B`@("`@*B!`9&5P<F5C871E9"!S
M:6YC92!(;W)D92`S+C$*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<')E
M9FEX('=H97)E(&9O;&1E<G,@8F5G:6X@=&\@8F4@;&ES=&5D+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G9710<F5F:7@H*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7W!R969I>#L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!I
M;F9O<FUA=&EO;B!A8F]U="!A('-P96-I9FEC(&UA:6QB;W@N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`9&5P<F5C871E9"!S:6YC
M92!(;W)D92`S+C$*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H
M("!4:&4@;6%I;&)O>"!T;R!Q=65R>2X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T9$-L87-S("!3964@:6UA<%]G971M86EL8F]X97,H*2X@(%1H92!S97)V
M97(@<W1R:6YG(&AA<PH@("`@("H@("`@("`@("`@("`@("`@("`@86QR96%D
M>2!B965N(')E;6]V960@9G)O;2!T:&4@)VYA;64G('!A<F%M971E<BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V=E=$UA:6QB;W@H)'!A=&@I"B`@("!["B`@
M("`@("`@)&)O>"`]("1T:&ES+3Y?9V5T3&ES="@D<&%T:"D["B`@("`@("`@
M:68@*&5M<'1Y*"1B;W@I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@<F5S970H)&)O
M>"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@36%K92!S=7)E
M('1H97)E(&ES(&YO('1R86EL:6YG(&1E;&EM:71E<B!O;B!T:&4@96QE;65N
M="!N86UE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H
M92!E;&5M96YT(&YA;64N"B`@("`@*B!`9&5P<F5C871E9"!S:6YC92!(;W)D
M92`S+C$*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&5L96UE
M;G0@;F%M92!W:71H(&%N>2!T<F%I;&EN9R!D96QI;6ET97(@<W1R:7!P960*
M("`@("`J("`@("`@("`@("`@("`@("!O9F8N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&YO5')A:6QI;F=$96QI;6ET97(H)&YA;64I"B`@("!["B`@("`@("`@
M)&YS7VEN9F\@/2`D=&AI<RT^7V=E=$YA;65S<&%C92@D;F%M92D["B`@("`@
M("`@:68@*'-U8G-T<B@D;F%M92P@+3$I(#T]("1N<U]I;F9O6R=D96QI;6ET
M97(G72D@>PH@("`@("`@("`@("`D;F%M92`]('-U8G-T<B@D;F%M92P@,"P@
M<W1R;&5N*"1N86UE*2`M(#$I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1N86UE.PH@("`@?0H*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O24U!4"]4:')E860N<&AP````
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,34T-S8@,3`U,34T
M,S,W,S8@,#(R,#,T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B!)34%07U1H<F5A9"!P<F]V:61E<R!F
M=6YC=&EO;G,@9F]R('=O<FMI;F<@=VET:"!I;6%P7W1H<F5A9"@I(&]U='!U
M="X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO24U!4"])34%0+U1H<F5A9"YP
M:'`L=B`Q+C0N,3`N,3,@,C`P-B\P,2\P,2`R,3HR.#HR,2!J86X@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L
M=7-A<GI`8W5R96-A;G1I+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8W5R96-A;G1I+F]R9SX*("H@
M0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TE-05`*("HO
M"F-L87-S($E-05!?5&AR96%D('L*"B`@("`O*BH*("`@("`J(&EM87!?=&AR
M96%D*"D@;W5T<'5T+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1?=&AR96%D87)R87D["@H@("`@+RHJ"B`@("`@*B!);G1E
M<FYA;"!T:')E860@9&%T82!S=')U8W1U<F4N"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]T:')E860@/2!A<G)A>2@I.PH*
M("`@("\J*@H@("`@("H@07)R87D@:6YD97@@=&\@365S<V%G92!I;F1E>"!L
M;V]K=7`@87)R87DN"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)%]L;V]K=7`@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@
M0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1O8B`@
M3W5T<'5T(&9R;VT@:6UA<%]T:')E860H*2X*("`@("`J+PH@("`@9G5N8W1I
M;VX@24U!4%]4:')E860H)&]B*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=&AR
M96%D87)R87D@/2`D;V(["B`@("`@("`@)'1H:7,M/E]P<F]C97-S4W1R=6-T
M=7)E*"D["B`@("!]"@H@("`O*BH*("`@("`J($=E=',@=&AE(&EN9&5N=&EO
M;B!L979E;"!F;W(@86X@24U!4"!M97-S86=E(&EN9&5X+@H@("`@("H*("`@
M("`J($!P87)A;2!I;G1E9V5R("1I;F1E>"`@5&AE($E-05`@;65S<V%G92!I
M;F1E>"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!2971U<FYS('1H
M92!T:')E860@:6YD96YT(&QE=F5L(&EF("1I;F1E>"!F;W5N9"X*("`@("`J
M("`@("`@("`@("`@("`@(%)E='5R;G,@9F%L<V4@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T5&AR96%D26YD96YT*"1I;F1E>"D*("`@
M('L*("`@("`@("`D:V5Y(#T@)'1H:7,M/E]G971+97DH)&EN9&5X*3L*("`@
M("`@("!I9B`H(6ES7VYU;&PH)&ME>2DI('L*("`@("`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?=&AR96%D6R1K97E=6R=L979E;"==*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?=&AR96%D6R1K97E=6R=L979E;"==
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@8F%S92!T:')E
M860@:6YD97@@9F]R(&%N($E-05`@;65S<V%G92!I;F1E>"X*("`@("`J"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D:6YD97@@(%1H92!)34%0(&UE<W-A9V4@
M:6YD97@N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@4F5T=7)N<R!T
M:&4@8F%S92!)34%0(&EN9&5X(&EF("1I;F1E>"!I<R!P87)T(&]F(&$*("`@
M("`J("`@("`@("`@("`@("`@('1H<F5A9"X*("`@("`J("`@("`@("`@("`@
M("`@(%)E='5R;G,@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T5&AR96%D0F%S92@D:6YD97@I"B`@("!["B`@("`@("`@)&ME
M>2`]("1T:&ES+3Y?9V5T2V5Y*"1I;F1E>"D["B`@("`@("`@:68@*"%I<U]N
M=6QL*"1K97DI*2!["B`@("`@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]T
M:')E861;)&ME>5U;)V)A<V4G72DI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7W1H<F5A9%LD:V5Y75LG8F%S92==.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!)<R!T:&ES(&EN9&5X('1H92!L87-T(&EN('1H92!C=7)R
M96YT(&QE=F5L/PH@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1I;F1E
M>"`@5&AE($E-05`@;65S<V%G92!I;F1E>"X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%)E='5R;G,@=')U92!I9B`D:6YD97@@:7,@=&AE(&QA
M<W0@96QE;65N="!I;B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@8W5R
M<F5N="!T:')E860@;&5V96PN"B`@("`@*B`@("`@("`@("`@("`@("`@(%)E
M='5R;G,@9F%L<V4@:68@;F]T+"!O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!L87-T26Y,979E;"@D:6YD97@I"B`@("!["B`@("`@("`@
M)&ME>2`]("1T:&ES+3Y?9V5T2V5Y*"1I;F1E>"D["B`@("`@("`@:68@*"%I
M<U]N=6QL*"1K97DI*2!["B`@("`@("`@("`@(&EF("@A96UP='DH)'1H:7,M
M/E]T:')E861;)&ME>5U;)VQA<W0G72DI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7W1H<F5A9%LD:V5Y75LG;&%S="==.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!$;R!T:&4@;65S<V%G92!I;F1E>"`M/B!A<G)A>2!I
M;F1E>"!L;V]K=7`N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&EN9&5X("!4:&4@24U!4"!M
M97-S86=E(&EN9&5X+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H
M92!A<G)A>2!I;F1E>"!V86QU92!O<B!N=6QL(&EF(&YO(&EN9&5X+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?9V5T2V5Y*"1I;F1E>"D*("`@('L*("`@("`@
M("!R971U<FX@*&ES<V5T*"1T:&ES+3Y?;&]O:W5P6R1I;F1E>%TI*2`_("1T
M:&ES+3Y?;&]O:W5P6R1I;F1E>%T@.B!N=6QL.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N('1H92!S;W)T960@;&ES="!O9B!M97-S86=E<R!I;F1I
M8V5S+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1N97<@(%1R=64@
M9F]R(&YE=V5S="!F:7)S="P@9F%L<V4@9F]R(&]L9&5S="!F:7)S="X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@<V]R=&5D(&QI<W0@;V8@
M;65S<V%G97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&UE<W-A9V5,:7-T*"1N
M97<I"B`@("!["B`@("`@("`@<F5T=7)N("@D;F5W*2`_(&%R<F%Y7W)E=F5R
M<V4H87)R87E?:V5Y<R@D=&AI<RT^7VQO;VMU<"DI(#H@87)R87E?:V5Y<R@D
M=&AI<RT^7VQO;VMU<"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!L:7-T(&]F(&UE<W-A9V5S(&EN('1H92!C=7)R96YT('1H<F5A9"X*
M("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:6YD97@@(%1H92!)34%0
M(&EN9&5X(&]F('1H92!C=7)R96YT(&UE<W-A9V4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@02!L:7-T(&]F($E-05`@;65S<V%G92!I;F1I8V5S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714:')E860H)&EN9&5X*0H@("`@
M>PH@("`@("`@("\J($9I;F0@=&AE(&)E9VEN;FEN9R!O9B!T:&4@=&AR96%D
M+B`J+PH@("`@("`@("1B96=I;B`]("1T:&ES+3YG9714:')E861"87-E*"1I
M;F1E>"D["B`@("`@("`@)&ME>2`]("1T:&ES+3Y?9V5T2V5Y*"1B96=I;BD[
M"B`@("`@("`@:68@*&ES7VYU;&PH)&ME>2D@?'P@96UP='DH)&)E9VEN*2D@
M>PH@("`@("`@("`@("!R971U<FX@87)R87DH)&EN9&5X*3L*("`@("`@("!]
M"@H@("`@("`@("\J(%=O<FL@9F]R=V%R9"!F<F]M('1H92!F:7)S="!T:')E
M860@96QE;65N="!T;R!F:6YD('1H92!E;F0@;V8@=&AE"B`@("`@("`@("H@
M=&AR96%D+B`J+PH@("`@("`@("1T:')E861?;&ES="`](&%R<F%Y*"1T:&ES
M+3Y?=&AR96%D6R1K97E=6R=I;F1E>"==*3L*("`@("`@("!W:&EL92`H*RLD
M:V5Y*2!["B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]T:')E861;
M)&ME>5TI*2!["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D8W5R<B`]("1T:&ES+3Y?=&AR96%D6R1K97E=.PH@
M("`@("`@("`@("!I9B`H)&-U<G);)V)A<V4G72`]/2`D8F5G:6XI('L*("`@
M("`@("`@("`@("`@("1T:')E861?;&ES=%M=(#T@)'1H:7,M/E]T:')E861;
M)&ME>5U;)VEN9&5X)UT["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1T:')E861?;&ES=#L*("`@('T*"B`@("`O*BH*("`@("`J
M(%!R;V-E<W,@=&AE(&]U='!U="!F<F]M(&EM87!?=&AR96%D*"D@:6YT;R!A
M;B!I;G1E<FYA;"!D871A('-T<G5C='5R92X*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7W!R;V-E<W-3=')U
M8W1U<F4H*0H@("`@>PH@("`@("`@("1C;VYT86EN97(@/2`D8V]N=&%I;F5R
M7V)A<V4@/2`D;&%S=%]I;F1E>"`]("1T:')E861?8F%S92`]("1T:')E861?
M8F%S95]I9'@@/2`@;G5L;#L*("`@("`@("`D:6YD:6-E<R`](&%R<F%Y*"D[
M"B`@("`@("`@)&D@/2`D;&%S=%]I(#T@)&QE=F5L(#T@,#L*"B`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/E]T:')E861A<G)A>2!A<R`D:V5Y(#T^("1V86PI
M('L*("`@("`@("`@("`@)'!O<R`]('-T<G!O<R@D:V5Y+"`G+B<I.PH@("`@
M("`@("`@("`D:6YD97@@/2!S=6)S='(H)&ME>2P@,"P@)'!O<RD["B`@("`@
M("`@("`@("1T>7!E(#T@<W5B<W1R*"1K97DL("1P;W,@*R`Q*3L*"B`@("`@
M("`@("`@('-W:71C:"`H)'1Y<&4I('L*("`@("`@("`@("`@8V%S92`G;G5M
M)SH*("`@("`@("`@("`@("`@(&EF("@D=F%L(#T]/2`P*2!["B`@("`@("`@
M("`@("`@("`@("`@)&-O;G1A:6YE<B`]("1I;F1E>#L*("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&DK*SL*("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-?;G5L;"@D8V]N=&%I;F5R*2`F)B!E;7!T
M>2@D;&5V96PI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:')E861?
M8F%S92`]("1V86P["B`@("`@("`@("`@("`@("`@("`@("`@("1T:')E861?
M8F%S95]I9'@@/2`D:6YD97@["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?;&]O:W5P6R1V86Q=(#T@)&EN9&5X
M.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=&AR96%D6R1I;F1E>%T@
M/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=&AR96%D
M6R1I;F1E>%U;)VEN9&5X)UT@/2`D=F%L.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=N97AT
M)SH*("`@("`@("`@("`@("`@(&EF("@A:7-?;G5L;"@D8V]N=&%I;F5R*2`F
M)B`H)&-O;G1A:6YE<B`]/3T@)&EN9&5X*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1C;VYT86EN97)?8F%S92`]("1T:&ES+3Y?=&AR96%D87)R87E;)'9A
M;"`N("<N;G5M)UT["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("1I*RL["B`@("`@("`@("`@("`@("`@("`@:68@*"%I
M<U]N=6QL*"1C;VYT86EN97(I*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?=&AR96%D6R1I;F1E>%U;)V)A<V4G72`]("1C;VYT86EN97)?
M8F%S93L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W1H<F5A9%LD:6YD97A=6R=B87-E)UT@
M/2`H(65M<'1Y*"1L979E;"D@?'P@*"1V86P@(3T@,"DI(#\@)'1H<F5A9%]B
M87-E(#H@;G5L;#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@)&QE=F5L*RL["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V)R86YC:"<Z"B`@
M("`@("`@("`@("`@("!I9B`H)&-O;G1A:6YE<B`]/3T@)&EN9&5X*2!["B`@
M("`@("`@("`@("`@("`@("`@)&-O;G1A:6YE<B`]("1C;VYT86EN97)?8F%S
M92`](&YU;&P["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T:')E861;
M)&QA<W1?:6YD97A=6R=L87-T)UT@/2!T<G5E.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W1H<F5A9%LD
M:6YD97A=6R=L979E;"==(#T@)&QE=F5L+2T["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]T:')E861;)&EN9&5X75LG;&%S="==(#T@(2@A:7-?;G5L
M;"@D8V]N=&%I;F5R*2`F)B!E;7!T>2@D;&5V96PI*3L*("`@("`@("`@("`@
M("`@("`@("!I9B`H)&EN9&5X(#T]/2`D=&AR96%D7V)A<V5?:61X*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1I;F1E>"`](&YU;&P["B`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E:68@*"%E;7!T>2@D;&5V96PI("8F"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("%I<U]N=6QL*"1L87-T7VEN9&5X
M*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I<W-E="@D=&AI
M<RT^7W1H<F5A9%LD;&%S=%]I;F1E>%TI*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?=&AR96%D6R1L87-T7VEN9&5X75LG;&%S="==(#T@
M*"1L87-T7VD@/3T@*"1I("T@,2DI.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1L87-T7VEN9&5X
M(#T@)&EN9&5X.PH@("`@("`@("`@("`@("`@)&QA<W1?:2`]("1I*RL["B`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O24U!4"]3;W)T+G!H<```````````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#<Q,#4@,3`U,34T,S,W,S8@,#(Q-30R`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B!)34%07U-O<G0@<')O=FED97,@9G5N8W1I;VYS(&9O<B!S;W)T
M:6YG(&QI<W1S(&]F($E-05`@;6%I;&)O>&5S+V9O;&1E<G,N"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+TE-05`O24U!4"]3;W)T+G!H<"QV(#$N-BXX+C$S
M(#(P,#8O,#(O,34@,3@Z,#<Z-3(@<VQU<V%R>B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,C`P-"TR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W
M;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-
M:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^
M"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95])34%0
M"B`J+PIC;&%S<R!)34%07U-O<G0@>PH*("`@("\J*@H@("`@("H@5&AE(&1E
M;&EM:71E<B!C:&%R86-T97(@=&\@=7-E+@H@("`@("H*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V1E;&EM:71E<CL*"B`@("`O*BH*
M("`@("`J(%-H;W5L9"!W92!S;W)T('=I=&@@)TE.0D]8)R!A="!T:&4@9G)O
M;G0@;V8@=&AE(&QI<W0_"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@
M("`@*B\*("`@('9A<B`D7W-O<G1I;F)O>#L*"B`@("`O*BH*("`@("`J($-O
M;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1E;&EM
M:71E<B`@5&AE(&1E;&EM:71E<B!U<V5D('1O('-E<&%R871E(&UA:6QB;WAE
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@24U!4%]3;W)T*"1D96QI;6ET97(I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]D96QI;6ET97(@/2`D9&5L:6UI=&5R
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4V]R="!A(&QI<W0@;V8@;6%I;&)O
M>&5S("AB>2!V86QU92DN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("8D
M;6)O>"`@("!4:&4@;&ES="!O9B!M86EL8F]X97,@=&\@<V]R="X*("`@("`J
M($!P87)A;2!B;V]L96%N("1I;F)O>"`@5VAE;B!S;W)T:6YG+"!A;'=A>7,@
M<'5T("=)3D)/6"<@870@=&AE(&AE860@;V8*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@=&AE(&QI<W0_"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M:6YD97@@($UA:6YT86EN(&EN9&5X(&%S<V]C:6%T:6]N/PH@("`@("HO"B`@
M("!F=6YC=&EO;B!S;W)T36%I;&)O>&5S*"8D;6)O>"P@)&EN8F]X(#T@=')U
M92P@)&EN9&5X(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1H:7,M/E]S;W)T
M:6YB;W@@/2`D:6YB;W@["B`@("`@("`@:68@*"1I;F1E>"D@>PH@("`@("`@
M("`@("!U87-O<G0H)&UB;W@L(&%R<F%Y*"8D=&AI<RP@)U]M8F]X7V-M<"<I
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!U<V]R="@D;6)O>"P@
M87)R87DH)B1T:&ES+"`G7VUB;WA?8VUP)RDI.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J(%-O<G0@82!L:7-T(&]F(&UA:6QB;WAE<R`H8GD@
M:V5Y*2X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)B1M8F]X("`@(%1H
M92!L:7-T(&]F(&UA:6QB;WAE<R!T;R!S;W)T+"!W:71H('1H92!K97ES"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&)E:6YG('1H92!M86EL8F]X
M(&YA;65S+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&EN8F]X("!7:&5N('-O
M<G1I;F<L(&%L=V%Y<R!P=70@)TE.0D]8)R!A="!T:&4@:&5A9"!O9@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("!T:&4@;&ES=#\*("`@("`J+PH@
M("`@9G5N8W1I;VX@<V]R=$UA:6QB;WAE<T)Y2V5Y*"8D;6)O>"P@)&EN8F]X
M(#T@=')U92D*("`@('L*("`@("`@("`D=&AI<RT^7W-O<G1I;F)O>"`]("1I
M;F)O>#L*("`@("`@("!U:W-O<G0H)&UB;W@L(&%R<F%Y*"8D=&AI<RP@)U]M
M8F]X7V-M<"<I*3L*("`@('T*"B`@("`O*BH*("`@("`J($AI97)A<F-H:6-A
M;"!F;VQD97(@<V]R=&EN9R!F=6YC=&EO;B`H=7-E9"!W:71H('5S;W)T*"DI
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&$@($-O;7!A<FES;VX@:71E;2`Q+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D8B`@0V]M<&%R:7-O;B!I=&5M(#(N"B`@("`@*@H@
M("`@("H@0')E='5R;B!I;G1E9V5R("!3964@=7-O<G0H*2X*("`@("`J+PH@
M("`@9G5N8W1I;VX@7VUB;WA?8VUP*"1A+"`D8BD*("`@('L*("`@("`@("`O
M*B!!;'=A>7,@<F5T=7)N($E.0D]8(&%S(")S;6%L;&5R(BX@*B\*("`@("`@
M("!I9B`H)'1H:7,M/E]S;W)T:6YB;W@I('L*("`@("`@("`@("`@:68@*'-T
M<F-A<V5C;7`H)&$L("=)3D)/6"<I(#T](#`I('L*("`@("`@("`@("`@("`@
M(')E='5R;B`M,3L*("`@("`@("`@("`@?2!E;'-E:68@*'-T<F-A<V5C;7`H
M)&(L("=)3D)/6"<I(#T](#`I('L*("`@("`@("`@("`@("`@(')E='5R;B`Q
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D85]P87)T<R`]
M(&5X<&QO9&4H)'1H:7,M/E]D96QI;6ET97(L("1A*3L*("`@("`@("`D8E]P
M87)T<R`](&5X<&QO9&4H)'1H:7,M/E]D96QI;6ET97(L("1B*3L*"B`@("`@
M("`@)&%?8V]U;G0@/2!C;W5N="@D85]P87)T<RD["B`@("`@("`@)&)?8V]U
M;G0@/2!C;W5N="@D8E]P87)T<RD["@H@("`@("`@("1I36%X(#T@;6EN*"1A
M7V-O=6YT+"`D8E]C;W5N="D["@H@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M("1I36%X.R`D:2LK*2!["B`@("`@("`@("`@(&EF("@D85]P87)T<ULD:5T@
M(3T@)&)?<&%R='-;)&E=*2!["B`@("`@("`@("`@("`@("`O*B!)9B!O;FQY
M(&]N92!O9B!T:&4@9F]L9&5R<R!I<R!U;F1E<B!)3D)/6"P@<F5T=7)N(&ET
M(&%S"B`@("`@("`@("`@("`@("`@*B`B<VUA;&QE<B(N("HO"B`@("`@("`@
M("`@("`@("!I9B`H)'1H:7,M/E]S;W)T:6YB;W@@)B8@*"1I(#T](#`I*2![
M"B`@("`@("`@("`@("`@("`@("`@)&%?8F%S92`]("AS=')C87-E8VUP*"1A
M7W!A<G1S6S!=+"`G24Y"3U@G*2`]/2`P*3L*("`@("`@("`@("`@("`@("`@
M("`D8E]B87-E(#T@*'-T<F-A<V5C;7`H)&)?<&%R='-;,%TL("=)3D)/6"<I
M(#T](#`I.PH@("`@("`@("`@("`@("`@("`@(&EF("@D85]B87-E("8F("$D
M8E]B87-E*2!["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`M,3L*
M("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H(21A7V)A<V4@)B8@)&)?
M8F%S92D@>PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@,3L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`D8VUP(#T@<W1R;F%T8V%S96-M<"@D85]P87)T<ULD:5TL("1B
M7W!A<G1S6R1I72D["B`@("`@("`@("`@("`@("!I9B`H)&-M<"`]/2`P*2![
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N('-T<F-M<"@D85]P87)T<ULD
M:5TL("1B7W!A<G1S6R1I72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!R971U<FX@)&-M<#L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("@D85]C;W5N="`M("1B7V-O=6YT*3L*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O24U!4"]#86-H92YP:'``
M````````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3(Q-34@,3`U
M,34T,S,W,S8@,#(Q-C$W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B!4:&4@24U!4%]#86-H93HZ(&-L
M87-S(&9A8VEL:71A=&5S(&EN(&-A8VAI;F<@;W5T<'5T(&9R;VT@=&AE(%!(
M4"!I;6%P"B`J(&5X=&5N<VEO;B!I;B!T:&4@8W5R<F5N="!S97-S:6]N+@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R])34%0+TE-05`O0V%C:&4N<&AP+'8@
M,2XT+C$R+C$Q(#(P,#8O,#0O,C@@,34Z-#,Z-#`@<VQU<V%R>B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU
M<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$=0
M3"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@*@H@*B!`
M875T:&]R("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO
M<F%D;RYE9'4^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(
M;W)D95])34%0"B`J+PIC;&%S<R!)34%07T-A8VAE('L*"B`@("`O*BH*("`@
M("`J(%!O:6YT97(@=&\@=&AE('-E<W-I;VX@8V%C:&4N"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]C86-H93L*"B`@("`O
M*BH*("`@("`J(%1H92!C86-H960@<F5S=6QT<R!O9B!I;6%P7W-T871U<R@I
M(&-A;&QS+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1?<W1A='5S8V%C:&4@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!A(')E9F5R96YC92!T;R!T:&4@9VQO8F%L($E-05!?0V%C:&4@
M;V)J96-T+"!O;FQY(&-R96%T:6YG"B`@("`@*B!I="!I9B!I="!D;V5S;B=T
M(&%L<F5A9'D@97AI<W0N"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@;75S
M="!B92!I;G9O:V5D(&%S.@H@("`@("H@("`D:6UA<%]C86-H92`]("9)34%0
M7T-A8VAE.CIS:6YG;&5T;VXH*3L*("`@("`J"B`@("`@*B!`<F5T=7)N($E-
M05!?0V%C:&4@(%1H92!)34%07T-A8VAE(&EN<W1A;F-E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B`F<VEN9VQE=&]N*"D*("`@('L*("`@("`@("!S=&%T:6,@
M)&]B:F5C=#L*"B`@("`@("`@:68@*"%I<W-E="@D;V)J96-T*2D@>PH@("`@
M("`@("`@("`D;V)J96-T(#T@;F5W($E-05!?0V%C:&4H*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D;V)J96-T.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0V]N<W1R=6-T;W(*("`@("`J+PH@("`@9G5N8W1I;VX@24U!4%]#86-H
M92@I"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D7U-%4U-)3TY;)VEM87!?
M8V%C:&4G72DI('L*("`@("`@("`@("`@)%]315-324].6R=I;6%P7V-A8VAE
M)UT@/2!A<G)A>2@I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7V-A8VAE
M(#T@)B1?4T534TE/3ELG:6UA<%]C86-H92==.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1V5T(&1A=&$@9G)O;2!T:&4@8V%C:&4N"B`@("`@*@H@("`@("H@
M0'!A<F%M(')E<V]U<F-E("1I;6%P("`@5&AE($E-05`@<F5S;W5R8V4@<W1R
M96%M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;6%I;&)O>"`@5&AE(&9U;&P@
M*'MH;W-T;F%M97UM86EL8F]X*2!M86EL8F]X(&YA;64N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1K97D@("`@("!4:&4@;F%M92!O9B!A('-P96-I9FEC(&5N
M=')Y('1O(')E='5R;BX*("`@("`J($!P87)A;2!B;V]L96%N("1C:&5C:R`@
M($-H96-K(&9O<B!U<&1A=&5D(&UA:6QB;W@_"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@5&AE(&1A=&$@<F5Q=65S=&5D+"!O<B!F86QS92!I9B!N
M;W0@879A:6QA8FQE+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971#86-H92@D
M:6UA<"P@)&UA:6QB;W@L("1K97D@/2!N=6QL+"`D8VAE8VL@/2!T<G5E*0H@
M("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-A8VAE6R1M86EL8F]X
M72DI('L*("`@("`@("`@("`@:68@*"$D8VAE8VL@?'P@)'1H:7,M/F-H96-K
M0V%C:&4H)&EM87`L("1M86EL8F]X*2D@>PH@("`@("`@("`@("`@("`@)'!T
M<B`]("8D=&AI<RT^7V-A8VAE6R1M86EL8F]X73L*("`@("`@("`@("`@("`@
M(&EF("@A:7-?;G5L;"@D:V5Y*2D@>PH@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D<'1R6R=D)UU;)&ME>5TI*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D<'1R6R=D)UU;)&ME>5T["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@)'!T<ELG9"==.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!F86QS93L*
M("`@('T*"B`@("`O*BH*("`@("`J($ES('1H92!C86-H92!I;F9O<FUA=&EO
M;B!U<"UT;RUD871E/PH@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D
M:6UA<"`@(%1H92!)34%0(')E<V]U<F-E('-T<F5A;2X*("`@("`J($!P87)A
M;2!S=')I;F<@)&UA:6QB;W@@(%1H92!F=6QL("A[:&]S=&YA;65];6%I;&)O
M>"D@;6%I;&)O>"!N86UE+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'5P9&%T
M92`@4VAO=6QD('1H92!C86-H92!)1"!S=')I;F<@8F4@=7!D871E9#\*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@8V%C:&4@:6YF
M;W)M871I;VX@=7`M=&\M9&%T92P@9F%L<V4@:68@;F]T+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!C:&5C:T-A8VAE*"1I;6%P+"`D;6%I;&)O>"P@)'5P9&%T
M92`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-A
M8VAE6R1M86EL8F]X72DI('L*("`@("`@("`@("`@)&ED(#T@)'1H:7,M/E]G
M971#86-H94E$*"1I;6%P+"`D;6%I;&)O>"D["B`@("`@("`@("`@(&EF("@D
M=&AI<RT^7V-A8VAE6R1M86EL8F]X75LG:R==(#T]("1I9"D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T@96QS96EF("@D
M=7!D871E*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<W1O<F5#86-H92@D
M:6UA<"P@)&UA:6QB;W@I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E
M:68@*"1U<&1A=&4I('L*("`@("`@("`@("`@)'1H:7,M/G-T;W)E0V%C:&4H
M)&EM87`L("1M86EL8F]X*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4W1O<F4@9&%T82!I;B!T:&4@
M8V%C:&4N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1I;6%P("`@
M5&AE($E-05`@<F5S;W5R8V4@<W1R96%M+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;6%I;&)O>"`@5&AE(&9U;&P@*'MH;W-T;F%M97UM86EL8F]X*2!M86EL
M8F]X(&YA;64N"B`@("`@*B!`<&%R86T@87)R87D@)'9A;'5E<R`@("!4:&4@
M9&%T82!T;R!A9&0@=&\@=&AE(&-A8VAE+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!S=&]R94-A8VAE*"1I;6%P+"`D;6%I;&)O>"P@)'9A;'5E<R`](&%R<F%Y
M*"DI"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V-A8VAE6R1M
M86EL8F]X72DI('L*("`@("`@("`@("`@)'1H:7,M/E]C86-H95LD;6%I;&)O
M>%T@/2!A<G)A>2@G9"<@/3X@87)R87DH*2D["B`@("`@("`@?0H@("`@("`@
M("1P='(@/2`F)'1H:7,M/E]C86-H95LD;6%I;&)O>%T["B`@("`@("`@)'!T
M<B`](&%R<F%Y*`H@("`@("`@("`@("`G:R<@/3X@)'1H:7,M/E]G971#86-H
M94E$*"1I;6%P+"`D;6%I;&)O>"DL"B`@("`@("`@("`@("=D)R`]/B!A<G)A
M>5]M97)G92@D<'1R6R=D)UTL("1V86QU97,I"B`@("`@("`@*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@86YD(&-A8VAE<R!T:&4@<F5S=6QT
M<R!O9B!A;B!I;6%P7W-T871U<R@I(&-A;&PN"B`@("`@*@H@("`@("H@0'-I
M;F-E($AO<F1E(#,N,2XR"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E
M("1I;6%P("`@5&AE($E-05`@<F5S;W5R8V4@<W1R:6YG+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;6%I;&)O>"`@5&AE(&9U;&P@*'MH;W-T;F%M97UM86EL
M8F]X*2!M86EL8F]X(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!S=&1#
M;&%S<R`@5&AE(&EM87!?<W1A='5S*"D@;V)J96-T(&]R('1H92!E;7!T>2!S
M=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-T871U<R@D:6UA<"P@
M)&UA:6QB;W@I"B`@("!["B`@("`@("`@)'1H:7,M/E]G971#86-H94E$*"1I
M;6%P+"`D;6%I;&)O>"D["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<W1A='5S
M8V%C:&5;)&UA:6QB;WA=.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5N97)A
M=&4@=&AE('5N:7%U92!)1"!S=')I;F<@9F]R('1H92!M86EL8F]X+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A
M;2!R97-O=7)C92`D:6UA<"`@(%1H92!)34%0(')E<V]U<F-E('-T<F5A;2X*
M("`@("`J($!P87)A;2!S=')I;F<@)&UA:6QB;W@@(%1H92!F=6QL("A[:&]S
M=&YA;65];6%I;&)O>"D@;6%I;&)O>"!N86UE+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!!('5N:7%U92!S=')I;F<@9F]R('1H92!C=7)R96YT
M('-T871E(&]F('1H92!M86EL8F]X+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M9V5T0V%C:&5)1"@D:6UA<"P@)&UA:6QB;W@I"B`@("!["B`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^7W-T871U<V-A8VAE6R1M86EL8F]X72DI('L*("`@
M("`@("`@("`@)'1H:7,M/E]S=&%T=7-C86-H95LD;6%I;&)O>%T@/2!`:6UA
M<%]S=&%T=7,H)&EM87`L("1M86EL8F]X+"!305]!3$PI.PH@("`@("`@("`@
M("!I9B`H(21T:&ES+3Y?<W1A='5S8V%C:&5;)&UA:6QB;WA=*2!["B`@("`@
M("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92AI;6%P7VQA<W1?97)R;W(H
M*2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U].3U1)0T4I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^7W-T871U
M<V-A8VAE6R1M86EL8F]X72D@>PH@("`@("`@("`@("`D;V(@/2`D=&AI<RT^
M7W-T871U<V-A8VAE6R1M86EL8F]X73L*("`@("`@("`@("`@<F5T=7)N(&EM
M<&QO9&4H)WPG+"!A<G)A>2@D;V(M/FUE<W-A9V5S+"`D;V(M/G)E8V5N="P@
M)&]B+3YU;G-E96XL("1O8BT^=6ED;F5X="P@)&]B+3YU:61V86QI9&ET>2DI
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D;6%I;&)O
M>#L*("`@("`@("!]"B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O4')E9G,`````````````````````````````````````````
M````````````````````````````````````````,#`P-S4U(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S8@,#(P,S4Q`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]0<F5F<R]S<6PN<&AP````````
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`S,C$W,R`Q,#4Q-30S
M,S<S-B`P,C$W-#8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J($!P86-K86=E($AO<F1E7U!R969S"B`J
M+PH*+RHJ"B`J(%!%05(@1$(@;&%Y97(N"B`J+PIR97%U:7)E7V]N8V4@)T1"
M+G!H<"<["@HO*BH*("H@2&]R9&5?4W1R:6YG(&-L87-S+@H@*B\*<F5Q=6ER
M95]O;F-E("=(;W)D92]3=')I;F<N<&AP)SL*"B\J*@H@*B!0<F5F97)E;F-E
M<R!S=&]R86=E(&EM<&QE;65N=&%T:6]N(&9O<B!02%`G<R!014%2(&1A=&%B
M87-E"B`J(&%B<W1R86-T:6]N(&QA>65R+@H@*@H@*B!297%U:7)E9"!P87)A
M;65T97)S.CQP<F4^"B`J("`@)W!H<'1Y<&4G("`@5&AE(&1A=&%B87-E('1Y
M<&4@*&EE+B`G<&=S<6PG+"`G;7ES<6PG+"!E=&,N*2X*("H@("`G8VAA<G-E
M="<@("!4:&4@9&%T86)A<V4G<R!I;G1E<FYA;"!C:&%R<V5T+CPO<')E/@H@
M*@H@*B!/<'1I;VYA;"!P87)A;65T97)S.CQP<F4^"B`J("`@)W1A8FQE)R`@
M("`@5&AE(&YA;64@;V8@=&AE('!R969E<F5N8V5S('1A8FQE(&EN("=D871A
M8F%S92<N"B`J("`@("`@("`@("`@("`@1$5&055,5#H@)VAO<F1E7W!R969S
M)SPO<')E/@H@*@H@*B!297%U:7)E9"!B>2!S;VUE(&1A=&%B87-E(&EM<&QE
M;65N=&%T:6]N<SH\<')E/@H@*B`@("=H;W-T<W!E8R<@(%1H92!H;W-T;F%M
M92!O9B!T:&4@9&%T86)A<V4@<V5R=F5R+@H@*B`@("=P<F]T;V-O;"<@(%1H
M92!C;VUM=6YI8V%T:6]N('!R;W1O8V]L("@G=&-P)RP@)W5N:7@G+"!E=&,N
M*2X*("H@("`G9&%T86)A<V4G("!4:&4@;F%M92!O9B!T:&4@9&%T86)A<V4N
M"B`J("`@)W5S97)N86UE)R`@5&AE('5S97)N86UE('=I=&@@=VAI8V@@=&\@
M8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N"B`J("`@)W!A<W-W;W)D)R`@5&AE
M('!A<W-W;W)D(&%S<V]C:6%T960@=VET:"`G=7-E<FYA;64G+@H@*B`@("=O
M<'1I;VYS)R`@($%D9&ET:6]N86P@;W!T:6]N<R!T;R!P87-S('1O('1H92!D
M871A8F%S92X*("H@("`G<&]R="<@("`@("!4:&4@<&]R="!O;B!W:&EC:"!T
M;R!C;VYN96-T('1O('1H92!D871A8F%S92X*("H@("`G='1Y)R`@("`@("!4
M:&4@5%19(&]N('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+CPO
M<')E/@H@*@H@*B!4:&4@=&%B;&4@<W1R=6-T=7)E(&9O<B!T:&4@4')E9G,@
M<WES=&5M(&ES(&EN"B`J('-C<FEP=',O<W%L+VAO<F1E7W!R969S+G-Q;"X*
M("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<W%L+G!H<"QV
M(#$N.3$N,3`N,C`@,C`P-B\P-"\Q,"`Q-3HU.#HQ-"!C:'5C:R!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D
M92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*;VX@4&%R:7-E
M(#QJ;VY`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A
M8VMA9V4@2&]R9&5?4')E9G,*("HO"F-L87-S(%!R969S7W-Q;"!E>'1E;F1S
M(%!R969S('L*"B`@("`O*BH*("`@("`J($AA<V@@8V]N=&%I;FEN9R!C;VYN
M96-T:6]N('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A>2@I.PH*("`@("\J*@H@
M("`@("H@2&%N9&QE(&9O<B!T:&4@8W5R<F5N="!D871A8F%S92!C;VYN96-T
M:6]N+@H@("`@("H*("`@("`J($!V87(@1$(*("`@("`J+PH@("`@=F%R("1?
M9&(["@H@("`@+RHJ"B`@("`@*B!";V]L96%N(&EN9&EC871I;F<@=VAE=&AE
M<B!O<B!N;W0@=V4G<F4@8V]N;F5C=&5D('1O('1H92!344P@<V5R=F5R+@H@
M("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]C
M;VYN96-T960@/2!F86QS93L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@
M82!N97<@4U%,('!R969E<F5N8V5S(&]B:F5C="X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1U<V5R("`@("`@5&AE('5S97(@=VAO(&]W;G,@=&AE
M<V4@<')E9F5R96YC97,N"B`@("`@*B!`<&%R86T@<W1R:6YG("1P87-S=V]R
M9"`@5&AE('!A<W-W;W)D(&%S<V]C:6%T960@=VET:"`D=7-E<BX@*%5N=7-E
M9"D*("`@("`J($!P87)A;2!S=')I;F<@)'-C;W!E("`@("!4:&4@8W5R<F5N
M="!P<F5F97)E;F-E<R!S8V]P92X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R
M86US("`@("!!(&AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N('!A<F%M971E
M<G,N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D8V%C:&EN9R`@4VAO=6QD(&-A
M8VAI;F<@8F4@=7-E9#\*("`@("`J+PH@("`@9G5N8W1I;VX@4')E9G-?<W%L
M*"1U<V5R+"`D<&%S<W=O<F0@/2`G)RP@)'-C;W!E(#T@)R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"DL("1C86-H:6YG(#T@
M9F%L<V4I"B`@("!["B`@("`@("`@)'1H:7,M/E]U<V5R(#T@)'5S97(["B`@
M("`@("`@)'1H:7,M/E]S8V]P92`]("1S8V]P93L*("`@("`@("`D=&AI<RT^
M7W!A<F%M<R`]("1P87)A;7,["B`@("`@("`@)'1H:7,M/E]C86-H:6YG(#T@
M)&-A8VAI;F<["@H@("`@("`@('!A<F5N=#HZ4')E9G,H*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-H87)S970@=7-E9"!B>2!T:&4@
M8V]N8W)E=&4@<')E9F5R96YC92!B86-K96YD+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@<')E9F5R96YC92!B86-K96YD)W,@8VAA<G-E
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0VAA<G-E="@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?<&%R86US6R=C:&%R<V5T)UT["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971R:65V97,@=&AE(')E<75E<W1E9"!S970@
M;V8@<')E9F5R96YC97,@9G)O;2!T:&4@=7-E<B=S(&1A=&%B87-E"B`@("`@
M*B!E;G1R>2X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!R969S("!!
M;B!A<G)A>2!L:7-T:6YG('1H92!P<F5F97)E;F-E<R!T;R!R971R:65V92X@
M268*("`@("`J("`@("`@("`@("`@("`@("`@("`@(&YO="!S<&5C:69I960L
M(')E=')I979E(&%L;"!O9B!T:&4@<')E9F5R96YC97,*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@(&QI<W1E9"!I;B!T:&4@)'!R969S(&AA<V@N"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R
M(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<F5T<FEE=F4H)'!R969S(#T@87)R87DH*2D*("`@('L*("`@
M("`@("`O*B!!='1E;7!T('1O('!U;&P@=&AE('9A;'5E<R!F<F]M('1H92!S
M97-S:6]N(&-A8VAE(&9I<G-T+B`J+PH@("`@("`@(&EF("@D=&AI<RT^8V%C
M:&5,;V]K=7`H*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@
M("!]"@H@("`@("`@("\J($QO860@9&5F875L=',@=&\@;6%K92!S=7)E('=E
M(&AA=F4@86QL('!R969E<F5N8V5S+B`J+PH@("`@("`@('!A<F5N=#HZ<F5T
M<FEE=F4H*3L*"B`@("`@("`@+RH@36%K92!S=7)E('=E)W)E(&-O;FYE8W1E
M9"X@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@+RH@
M0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*("`@("`@("`D<75E<GD@/2`G4T5,
M14-4('!R969?<V-O<&4L('!R969?;F%M92P@<')E9E]V86QU92!&4D]-("<[
M"B`@("`@("`@)'%U97)Y("X]("1T:&ES+3Y?<&%R86US6R=T86)L92==("X@
M)R`G.PH@("`@("`@("1Q=65R>2`N/2`G5TA%4D4@<')E9E]U:60@/2`_)SL*
M("`@("`@("`D<75E<GD@+CT@)R!!3D0@*'!R969?<V-O<&4@/2`_)SL*("`@
M("`@("`D<75E<GD@+CT@(B!/4B!P<F5F7W-C;W!E(#T@)VAO<F1E)RD@3U)$
M15(@0ED@<')E9E]S8V]P92(["@H@("`@("`@("1V86QU97,@/2!A<G)A>2@D
M=&AI<RT^7W5S97(L("1T:&ES+3Y?<V-O<&4I.PH*("`@("`@("!(;W)D93HZ
M;&]G365S<V%G92AS<')I;G1F*"=344P@475E<GD@8GD@4')E9G-?<W%L.CIR
M971R:65V92@I.B`E<R<L("1Q=65R>2DL(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`O*B!%>&5C=71E('1H92!Q=65R
M>2X@*B\*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U
M97)Y+"`D=F%L=65S*3L*"B`@("`@("`@:68@*&ES<V5T*"1R97-U;'0I("8F
M("%I<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M)')O=R`]("1R97-U;'0M/F9E=&-H4F]W*$1"7T9%5$-(34]$15]!4U-/0RD[
M"B`@("`@("`@("`@(&EF("AI<U]A*"1R;W<L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1R;W<L(%]?1DE,
M15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@("`@
M(')E='5R;CL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@4V5T('1H
M92!R97%U97-T960@=F%L=65S(&EN('1H92`D=&AI<RT^7W!R969S(&AA<V@*
M("`@("`@("`@("`@("H@8F%S960@;VX@=&AE(&-O;G1E;G1S(&]F('1H92!3
M44P@<F5S=6QT+@H@("`@("`@("`@("`@*@H@("`@("`@("`@("`@*B!.;W1E
M('1H870@4')E9G,Z.G-E=%9A;'5E*"D@8V%N)W0@8F4@=7-E9"!H97)E(&)E
M8V%U<V4*("`@("`@("`@("`@("H@;V8@=&AE(&-H96-K(&9O<B!T:&4@(F-H
M86YG96%B;&4B(&)I="X@5V4@=V%N="!T;PH@("`@("`@("`@("`@*B!O=F5R
M<FED92!T:&%T(&-H96-K('=H96X@<&]P=6QA=&EN9R!T:&4@)'1H:7,M/E]P
M<F5F<PH@("`@("`@("`@("`@*B!H87-H(&9R;VT@=&AE(%-13"!S97)V97(N
M("HO"B`@("`@("`@("`@('=H:6QE("@D<F]W("8F("%I<U]A*"1R;W<L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("1N86UE(#T@=')I;2@D
M<F]W6R=P<F5F7VYA;64G72D["B`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]P<F5F<ULD;F%M95TI*2!["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]S971686QU92@D;F%M92P@)')O=ULG<')E9E]V86QU92==+"!F
M86QS92P@9F%L<V4I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971$
M:7)T>2@D;F%M92P@9F%L<V4I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^861D*"1N86UE+"`D<F]W6R=P
M<F5F7W9A;'5E)UTL("1R;W=;)W!R969?<V-O<&4G72`]/2`G:&]R9&4G(#\@
M7U!2149?4TA!4D5$(#H@,"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`D<F]W(#T@)')E<W5L="T^9F5T8VA2;W<H1$)?1D540TA-3T1%
M7T%34T]#*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@0V%L;"!H
M;V]K<RX@*B\*("`@("`@("`@("`@)'1H:7,M/E]C86QL2&]O:W,H*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G
M3F\@<')E9F5R96YC97,@=V5R92!R971R:65V960N)RP@7U]&24Q%7U\L(%]?
M3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@("`@(')E='5R;CL*
M("`@("`@("!]"@H@("`@("`@("\J(%5P9&%T92!T:&4@<V5S<VEO;B!C86-H
M92X@*B\*("`@("`@("`D=&AI<RT^8V%C:&55<&1A=&4H*3L*"B`@("`@("`@
M<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3=&]R97,@<')E
M9F5R96YC97,@=&\@4U%,('-E<G9E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S=&]R92@I"B`@
M("!["B`@("`@("`@+RH@0VAE8VL@9F]R(&%N>2`B9&ER='DB('!R969E<F5N
M8V5S+B!)9B!N;R`B9&ER='DB"B`@("`@("`@("H@<')E9F5R96YC97,@87)E
M(&9O=6YD+"!T:&5R92=S(&YO(&YE960@=&\@=7!D871E('1H92!344P*("`@
M("`@("`@*B!S97)V97(N($5X:70@<W5C8V5S<V9U;&QY+B`J+PH@("`@("`@
M("1D:7)T>5]P<F5F<R`]("1T:&ES+3Y?9&ER='E0<F5F<R@I.PH@("`@("`@
M(&EF("@A8V]U;G0H)&1I<G1Y7W!R969S*2D@>PH@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("\J($UA:V4@<W5R92!W92=R
M92!C;VYN96-T960N("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@
M("`@("`@("\J($QO;W`@=&AR;W5G:"!T:&4@(F1I<G1Y(B!P<F5F97)E;F-E
M<RX@($EF(&$@<F]W(&%L<F5A9'D*("`@("`@("`@*B!E>&ES=',@9F]R('1H
M:7,@<')E9F5R96YC92P@871T96UP="!T;R!U<&1A=&4@:70N"B`@("`@("`@
M("H@3W1H97)W:7-E+"!I;G-E<G0@82!N97<@<F]W+B`J+PH@("`@("`@(&9O
M<F5A8V@@*"1D:7)T>5]P<F5F<R!A<R`D;F%M92D@>PH@("`@("`@("`@("`O
M+R!$;VXG="!S=&]R92!L;V-K960@<')E9F5R96YC97,N"B`@("`@("`@("`@
M(&EF("@D=&AI<RT^:7-,;V-K960H)&YA;64I*2!["B`@("`@("`@("`@("`@
M("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'-C;W!E
M(#T@)'1H:7,M/F=E=%-C;W!E*"1N86UE*3L*"B`@("`@("`@("`@("\J($1O
M97,@86X@96YT<GD@86QR96%D>2!E>&ES="!F;W(@=&AI<R!P<F5F97)E;F-E
M/R`J+PH@("`@("`@("`@("`D<75E<GD@/2`G4T5,14-4(#$@1E)/32`G.PH@
M("`@("`@("`@("`D<75E<GD@+CT@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT@
M+B`G("<["B`@("`@("`@("`@("1Q=65R>2`N/2`G5TA%4D4@<')E9E]U:60@
M/2`_)SL*("`@("`@("`@("`@)'%U97)Y("X]("<@04Y$('!R969?;F%M92`]
M(#\G.PH@("`@("`@("`@("`D<75E<GD@+CT@)R!!3D0@*'!R969?<V-O<&4@
M/2`_)SL*("`@("`@("`@("`@)'%U97)Y("X]("(@3U(@<')E9E]S8V]P92`]
M("=H;W)D92<I(CL*"B`@("`@("`@("`@("1V86QU97,@/2!A<G)A>2@D=&AI
M<RT^7W5S97(L("1N86UE+"`D<V-O<&4I.PH*("`@("`@("`@("`@+RH@17AE
M8W5T92!T:&4@<75E<GDN("HO"B`@("`@("`@("`@("1C:&5C:R`]("1T:&ES
M+3Y?9&(M/F=E=$]N92@D<75E<GDL("1V86QU97,I.PH*("`@("`@("`@("`@
M+RH@4F5T=7)N(&%N(&5R<F]R(&EF('1H92!Q=65R>2!F86EL<RX@*B\*("`@
M("`@("`@("`@:68@*&ES7V$H)&-H96-K+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G1F%I;&5D(')E=')I
M979I;F<@<')E9G,@9F]R("<@+B`D=&AI<RT^7W5S97(L(%]?1DE,15]?+"!?
M7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(D9A:6QE9"!R971R:65V:6YG('!R969E
M<F5N8V5S+B(I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@27,@
M=&AE<F4@86X@97AI<W1I;F<@<F]W(&9O<B!T:&ES('!R969E<F5N8V4_("HO
M"B`@("`@("`@("`@(&EF("@A96UP='DH)&-H96-K*2D@>PH@("`@("`@("`@
M("`@("`@+RH@57!D871E('1H92!E>&ES=&EN9R!R;W<N("HO"B`@("`@("`@
M("`@("`@("`D<75E<GD@/2`G55!$051%("<@+B`D=&AI<RT^7W!A<F%M<ULG
M=&%B;&4G72`N("<@)SL*("`@("`@("`@("`@("`@("1Q=65R>2`N/2`G4T54
M('!R969?=F%L=64@/2`_)SL*("`@("`@("`@("`@("`@("1Q=65R>2`N/2`G
M(%=(15)%('!R969?=6ED(#T@/R<["B`@("`@("`@("`@("`@("`D<75E<GD@
M+CT@)R!!3D0@<')E9E]N86UE(#T@/R<["B`@("`@("`@("`@("`@("`D<75E
M<GD@+CT@)R!!3D0@<')E9E]S8V]P92`](#\G.PH*("`@("`@("`@("`@("`@
M("1V86QU97,@/2!A<G)A>2@H<W1R:6YG*21T:&ES+3YG971686QU92@D;F%M
M92P@9F%L<V4I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?=7-E<BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<V-O<&4I
M.PH*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R
M>2@D<75E<GDL("1V86QU97,I.PH*("`@("`@("`@("`@("`@("\J(%)E='5R
M;B!A;B!E<G)O<B!I9B!T:&4@=7!D871E(&9A:6QS+B`J+PH@("`@("`@("`@
M("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@("`@($AO<F1E.CIF871A;"@D<F5S=6QT+"!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@+RH@26YS97)T(&$@;F5W(')O=RX@
M*B\*("`@("`@("`@("`@("`@("1Q=65R>2`@/2`G24Y315)4($E.5$\@)R`N
M("1T:&ES+3Y?<&%R86US6R=T86)L92==("X@)R`G.PH@("`@("`@("`@("`@
M("`@)'%U97)Y("X]("<H<')E9E]U:60L('!R969?<V-O<&4L('!R969?;F%M
M92P@<')E9E]V86QU92D@5D%,5453)SL*("`@("`@("`@("`@("`@("1Q=65R
M>2`N/2`G*#\L(#\L(#\L(#\I)SL*"B`@("`@("`@("`@("`@("`D=F%L=65S
M(#T@87)R87DH)'1H:7,M/E]U<V5R+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1S8V]P92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`H
M<W1R:6YG*21T:&ES+3YG971686QU92@D;F%M92P@9F%L<V4I*3L*"B`@("`@
M("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y
M+"`D=F%L=65S*3L*"B`@("`@("`@("`@("`@("`O*B!2971U<FX@86X@97)R
M;W(@:68@=&AE(&EN<V5R="!F86EL<RX@*B\*("`@("`@("`@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@("`@("!(;W)D93HZ9F%T86PH)')E<W5L="P@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@+RH@36%R:R!T:&ES('!R969E<F5N8V4@87,@(F-L96%N(B!N;W<N
M("HO"B`@("`@("`@("`@("1T:&ES+3YS971$:7)T>2@D;F%M92P@9F%L<V4I
M.PH@("`@("`@('T*"B`@("`@("`@+RH@57!D871E('1H92!S97-S:6]N(&-A
M8VAE+B`J+PH@("`@("`@("1T:&ES+3YC86-H955P9&%T92@I.PH*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%!E<F9O<FT@
M8VQE86YU<"!O<&5R871I;VYS+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L
M96%N("1A;&P@($-L96%N=7`@86QL($AO<F1E('!R969E<F5N8V5S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!C;&5A;G5P*"1A;&P@/2!F86QS92D*("`@('L*
M("`@("`@("`O*B!#;&]S92!T:&4@9&%T86)A<V4@8V]N;F5C=&EO;BX@*B\*
M("`@("`@("`D=&AI<RT^7V1I<V-O;FYE8W0H*3L*"B`@("`@("`@<&%R96YT
M.CIC;&5A;G5P*"1A;&PI.PH@("`@?0H*("`@("\J*@H@("`@("H@0VQE87)S
M(&%L;"!P<F5F97)E;F-E<R!F<F]M('1H92!B86-K96YD+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!C;&5A<B@I"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E
M('=E)W)E(&-O;FYE8W1E9"X@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H
M*3L*"B`@("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*("`@("`@
M("`D<75E<GD@/2`G1$5,151%($923TT@)R`N("1T:&ES+3Y?<&%R86US6R=T
M86)L92==.PH@("`@("`@("1Q=65R>2`N/2`G(%=(15)%('!R969?=6ED(#T@
M/R<["@H@("`@("`@("1V86QU97,@/2!A<G)A>2@D=&AI<RT^7W5S97(I.PH*
M("`@("`@("!(;W)D93HZ;&]G365S<V%G92AS<')I;G1F*"=344P@475E<GD@
M8GD@4')E9G-?<W%L.CIC;&5A<B@I.B`E<R<L("1Q=65R>2DL(%]?1DE,15]?
M+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`O*B!%>&5C
M=71E('1H92!Q=65R>2X@*B\*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D
M8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*"B`@("`@("`@+RH@0VQE86YU
M<"X@*B\*("`@("`@("!P87)E;G0Z.F-L96%R*"D["@H@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R=',@82!V
M86QU92!F<F]M('1H92!D<FEV97(G<R!C:&%R<V5T('1O('1H92!S<&5C:69I
M960@8VAA<G-E="X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)'9A;'5E
M("`@("!!('9A;'5E('1O(&-O;G9E<G0N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1C:&%R<V5T("!4:&4@8VAA<G-E="!T;R!C;VYV97)T('1O+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1H92!C;VYV97)T960@=F%L=64N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&-O;G9E<G1&<F]M1')I=F5R*"1V86QU92P@
M)&-H87)S970I"B`@("!["B`@("`@("`@<W1A=&EC("1C;VYV97)T960@/2!A
M<G)A>2@I.PH*("`@("`@("!I9B`H:7-?87)R87DH)'9A;'5E*2D@>PH@("`@
M("`@("`@("!R971U<FX@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D=F%L=64L
M("1T:&ES+3Y?<&%R86US6R=C:&%R<V5T)UTL("1C:&%R<V5T*3L*("`@("`@
M("!]"@H@("`@("`@(&EF("AI<U]B;V]L*"1V86QU92DI('L*("`@("`@("`@
M("`@<F5T=7)N("1V86QU93L*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-S
M970H)&-O;G9E<G1E9%LD8VAA<G-E=%U;)'9A;'5E72DI('L*("`@("`@("`@
M("`@)&-O;G9E<G1E9%LD8VAA<G-E=%U;)'9A;'5E72`](%-T<FEN9SHZ8V]N
M=F5R=$-H87)S970H)'9A;'5E+"`D=&AI<RT^7W!A<F%M<ULG8VAA<G-E="==
M+"`D8VAA<G-E="D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-O;G9E
M<G1E9%LD8VAA<G-E=%U;)'9A;'5E73L*("`@('T*"B`@("`O*BH*("`@("`J
M($-O;G9E<G1S(&$@=F%L=64@9G)O;2!T:&4@<W!E8VEF:65D(&-H87)S970@
M=&\@=&AE(&1R:79E<B=S(&-H87)S970N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&UI>&5D("1V86QU92`@02!V86QU92!T;R!C;VYV97)T+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D8VAA<G-E="`@5&AE(&-H87)S970@=&\@8V]N=F5R="!F
M<F]M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!C;VYV97)T
M960@=F%L=64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;G9E<G14;T1R:79E
M<B@D=F%L=64L("1C:&%R<V5T*0H@("`@>PH@("`@("`@(')E='5R;B!3=')I
M;F<Z.F-O;G9E<G1#:&%R<V5T*"1V86QU92P@)&-H87)S970L("1T:&ES+3Y?
M<&%R86US6R=C:&%R<V5T)UTI.PH@("`@?0H*("`@("\J*@H@("`@("H@071T
M96UP=',@=&\@;W!E;B!A('!E<G-I<W1E;G0@8V]N;F5C=&EO;B!T;R!T:&4@
M4U%,('-E<G9E<BX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@
M82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?8V]N;F5C="@I"B`@("!["B`@("`@("`@+RH@0VAE8VL@=&\@
M<V5E(&EF('=E(&%R92!A;')E861Y(&-O;FYE8W1E9"X@*B\*("`@("`@("!I
M9B`H)'1H:7,M/E]C;VYN96-T960I('L*("`@("`@("`@("`@<F5T=7)N('1R
M=64["B`@("`@("`@?0H*("`@("`@("!(;W)D93HZ87-S97)T1')I=F5R0V]N
M9FEG*"1T:&ES+3Y?<&%R86US+"`G<')E9G,G+`H@("`@("`@("`@("!A<G)A
M>2@G<&AP='EP92<L("=C:&%R<V5T)RDL"B`@("`@("`@("`@("=P<F5F97)E
M;F-E<R!344PG*3L*"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M
M<ULG9&%T86)A<V4G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)V1A=&%B87-E)UT@/2`G)SL*("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E
M="@D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;64G72DI('L*("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)W5S97)N86UE)UT@/2`G)SL*("`@("`@("!]"B`@
M("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72DI
M('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UT@/2`G
M)SL*("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M
M<ULG:&]S='-P96,G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)VAO<W1S<&5C)UT@/2`G)SL*("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E
M="@D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DI('L*("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)W1A8FQE)UT@/2`G:&]R9&5?<')E9G,G.PH@("`@("`@
M('T*"B`@("`@("`@+RH@0V]N;F5C="!T;R!T:&4@4U%,('-E<G9E<B!U<VEN
M9R!T:&4@<W5P<&QI960@<&%R86UE=&5R<RX@*B\*("`@("`@("`D=&AI<RT^
M7V1B(#T@)D1".CIC;VYN96-T*"1T:&ES+3Y?<&%R86US+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W!E<G-I<W1E;G0G(#T^
M("%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG<&5R<VES=&5N="==*2DI.PH@("`@
M("`@(&EF("AI<U]A*"1T:&ES+3Y?9&(L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@2&]R9&4Z.F9A=&%L*"1T:&ES+3Y?9&(L(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("`O+R!3970@1$(@<&]R=&%B
M:6QI='D@;W!T:6]N<RX*("`@("`@("!S=VET8V@@*"1T:&ES+3Y?9&(M/G!H
M<'1Y<&4I('L*("`@("`@("!C87-E("=M<W-Q;"<Z"B`@("`@("`@("`@("1T
M:&ES+3Y?9&(M/G-E=$]P=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]03U)404))
M3$E465],3U=%4D-!4T4@?"!$0E]03U)404))3$E465]%4E)/4E,@?"!$0E]0
M3U)404))3$E465]25%))32D["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M(&1E9F%U;'0Z"B`@("`@("`@("`@("1T:&ES+3Y?9&(M/G-E=$]P=&EO;B@G
M<&]R=&%B:6QI='DG+"!$0E]03U)404))3$E465],3U=%4D-!4T4@?"!$0E]0
M3U)404))3$E465]%4E)/4E,I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M
M/E]C;VYN96-T960@/2!T<G5E.PH*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O*BH*("`@("`J($1I<V-O;FYE8W0@9G)O;2!T:&4@4U%,('-E
M<G9E<B!A;F0@8VQE86X@=7`@=&AE(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]D:7-C;VYN96-T*"D*("`@('L*("`@("`@("!I
M9B`H)'1H:7,M/E]C;VYN96-T960I('L*("`@("`@("`@("`@)'1H:7,M/E]C
M;VYN96-T960@/2!F86QS93L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M9&(M/F1I<V-O;FYE8W0H*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!R971U<FX@=')U93L*("`@("`@("!]"B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+U!R969S+U5)+G!H<```````````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#,T-34V(#$P-3$U-#,S-S,V(#`R,30W,P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@0VQA<W,@9F]R(&%U=&\M9V5N97)A=&EN9R!T:&4@<')E9F5R96YC97,@
M=7-E<B!I;G1E<F9A8V4@86YD"B`J('!R;V-E<W-I;F<@=&AE(&9O<FUS+@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`L=B`Q
M+C8S+C(N,34@,C`P-B\P,2\Q,B`R,CHR-3HQ-"!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#(P,#$M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO
M<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`R
M+C$*("H@0'!A8VMA9V4@2&]R9&5?4')E9G,*("HO"F-L87-S(%!R969S7U5)
M('L*"B`@("`O*BH*("`@("`J($1E=&5R;6EN92!W:&5T:&5R(&]R(&YO="!A
M('!R969E<F5N8V5S(&=R;W5P(&ES(&5D:71A8FQE+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&=R;W5P("!4:&4@<')E9F5R96YC97,@9W)O=7`@
M=&\@8VAE8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T
M:&5R(&]R(&YO="!T:&4@9W)O=7`@:7,@961I=&%B;&4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=R;W5P27-%9&ET86)L92@D9W)O=7`I"B`@("!["B`@("`@
M("`@9VQO8F%L("1P<F5F<RP@)'!R969'<F]U<',["@H@("`@("`@('-T871I
M8R`D<F5S=6QT<R`](&%R<F%Y*"D["@H@("`@("`@(&EF("@A:7-S970H)')E
M<W5L='-;)&=R;W5P72DI('L*("`@("`@("`@("`@:68@*"%E;7!T>2@D<')E
M9D=R;W5P<ULD9W)O=7!=6R=U<FPG72DI('L*("`@("`@("`@("`@("`@("1R
M97-U;'1S6R1G<F]U<%T@/2!T<G5E.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)')E<W5L='-;)&=R;W5P72`](&9A;'-E.PH@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1P<F5F1W)O=7!S6R1G<F]U<%U;)VUE
M;6)E<G,G72DI('L*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D<')E
M9D=R;W5P<ULD9W)O=7!=6R=M96UB97)S)UT@87,@)'!R968I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"$D<')E9G,M/FES3&]C:V5D*"1P<F5F
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E<W5L='-;)&=R
M;W5P72`]('1R=64["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R97-U;'1S6R1G<F]U<%T["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!(86YD;&4@82!P<F5F97)E;F-E<R!F;W)M
M('-U8FUI<W-I;VX@:68@=&AE<F4@:7,@;VYE+"!U<&1A=&EN9PH@("`@("H@
M86YY('!R969E<F5N8V5S('=H:6-H(&AA=F4@8F5E;B!C:&%N9V5D+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&=R;W5P("!4:&4@<')E9F5R96YC
M97,@9W)O=7`@=&AA="!W87,@961I=&5D+@H@("`@("H@0'!A<F%M(&]B:F5C
M="`D<V%V92`@(%1H92!O8FIE8W0@=VAE<F4@=&AE(&-H86YG960@=F%L=65S
M(&%R90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('-A=F5D+B!-=7-T
M(&EM<&QE;65N="!S971686QU92AS=')I;F<L('-T<FEN9RDN"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R('!R969E<F5N8V5S(&AA
M=F4@8F5E;B!U<&1A=&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!H86YD;&5&
M;W)M*"8D9W)O=7`L("8D<V%V92D*("`@('L*("`@("`@("!G;&]B86P@)'!R
M969S+"`D<')E9D=R;W5P<RP@)%]P<F5F<RP@)&YO=&EF:6-A=&EO;BP@)')E
M9VES=')Y.PH*("`@("`@("`D=7!D871E9"`](&9A;'-E.PH*("`@("`@("`O
M*B!2=6X@=&AR;W5G:"!T:&4@86-T:6]N(&AA;F1L97)S("HO"B`@("`@("`@
M:68@*%5T:6PZ.F=E=%!O<W0H)V%C=&EO;DE$)RD@/3T@)W5P9&%T95]P<F5F
M<R<I('L*("`@("`@("`@("`@:68@*&ES<V5T*"1G<F]U<"D@)B8@4')E9G-?
M54DZ.F=R;W5P27-%9&ET86)L92@D9W)O=7`I*2!["B`@("`@("`@("`@("`@
M("`D=7!D871E9"`](&9A;'-E.PH*("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1P<F5F1W)O=7!S6R1G<F]U<%U;)VUE;6)E<G,G72!A<R`D<')E9BD@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("@A)'!R969S+3YI<TQO8VME9"@D<')E
M9BD@?'P*("`@("`@("`@("`@("`@("`@("`@("`@*"1?<')E9G-;)'!R969=
M6R=T>7!E)UT@/3T@)W-P96-I86PG*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("!S=VET8V@@*"1?<')E9G-;)'!R969=6R=T>7!E)UTI('L*"B`@("`@
M("`@("`@("`@("`@("`@("`@("\J(%1H97-E(&5I=&AE<B!A<F5N)W0@<V5T
M(&]R(&%R92!S970@:6X@;W1H97(*("`@("`@("`@("`@("`@("`@("`@("`@
M("H@<&%R=',@;V8@=&AE(%5)+B`J+PH@("`@("`@("`@("`@("`@("`@("`@
M("!C87-E("=I;7!L:6-I="<Z"B`@("`@("`@("`@("`@("`@("`@("`@(&-A
M<V4@)VQI;FLG.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("`@("`@("`@("`@("!C87-E("=S96QE8W0G.@H@("`@
M("`@("`@("`@("`@("`@("`@("!C87-E("=T97AT)SH*("`@("`@("`@("`@
M("`@("`@("`@("`@8V%S92`G=&5X=&%R96$G.@H@("`@("`@("`@("`@("`@
M("`@("`@("!C87-E("=P87-S=V]R9"<Z"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=7!D871E9"`]("1U<&1A=&5D('P@)'-A=F4M/G-E=%9A;'5E
M*"1P<F5F+"!5=&EL.CIG9710;W-T*"1P<F5F*2D["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("`@("`@("`@
M(&-A<V4@)V5N=6TG.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A
M;"`](%5T:6PZ.F=E=%!O<W0H)'!R968I.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1?<')E9G-;)'!R969=6R=E;G5M)UU;)'9A
M;%TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'5P9&%T
M960@/2`D=7!D871E9"!\("1S879E+3YS971686QU92@D<')E9BP@)'9A;"D[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H
M7R@B06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(I+"`G:&]R9&4N
M97)R;W(G*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@
M("`@("`@("`@8V%S92`G;75L=&EE;G5M)SH*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1V86QS(#T@571I;#HZ9V5T4&]S="@D<')E9BD["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<V5T(#T@87)R87DH*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1I;G9A;&ED(#T@9F%L<V4["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)'9A;',I*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'9A
M;',@87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)%]P<F5F<ULD<')E9EU;)V5N=6TG75LD=F%L72DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S
M971;72`]("1V86P["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D:6YV86QI9"`]('1R=64["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&EN=F%L:60I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP
M=7-H*%\H(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB*2P@)VAO
M<F1E+F5R<F]R)RD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1U<&1A=&5D
M(#T@)'5P9&%T960@?"`D<V%V92T^<V5T5F%L=64H)'!R968L($!S97)I86QI
M>F4H)'-E="DI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@
M("`@("`@("`@("!C87-E("=N=6UB97(G.@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&YU;2`](%5T:6PZ.F=E=%!O<W0H)'!R968I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*&EN='9A;"@D;G5M*2`A/2`D;G5M
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YO=&EF:6-A
M=&EO;BT^<'5S:"A?*")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(BDL
M("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E:68@*"1N=6T@/3T@,"D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B5&AI<R!N=6UB97(@
M;75S="!B92!A="!L96%S="!O;F4N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=7!D871E9"`]("1U<&1A=&5D('P@)'-A
M=F4M/G-E=%9A;'5E*"1P<F5F+"`D;G5M*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G8VAE8VMB;W@G.@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A;"`](%5T:6PZ.F=E=%!O
M<W0H)'!R968I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'5P9&%T
M960@/2`D=7!D871E9"!\("1S879E+3YS971686QU92@D<')E9BP@:7-S970H
M)'9A;"D@/R`Q(#H@,"D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)W-P96-I86PG
M.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+RH@0V]D92!F;W(@<W!E
M8VEA;"!E;&5M96YT<R!M=7-T(&)E"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@*B!W<FET=&5N('-P96-I9FEC86QL>2!F;W(@96%C:`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("H@87!P;&EC871I;VXN("HO"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=H
M86YD;&5?)R`N("1P<F5F*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1U<&1A=&5D(#T@)'5P9&%T960@?"!C86QL7W5S97)?9G5N8R@G
M:&%N9&QE7R<@+B`D<')E9BP@)'5P9&%T960I.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@
M*"1U<&1A=&5D*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&9U;F-T:6]N
M7V5X:7-T<R@G<')E9G-?8V%L;&)A8VLG*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("!P<F5F<U]C86QL8F%C:R@I.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-?82@D<')E9G,L("=0<F5F
M<U]S97-S:6]N)RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&YO=&EF
M:6-A=&EO;BT^<'5S:"A?*")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T
M960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(BDL("=H;W)D
M92YS=6-C97-S)RD["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")9
M;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(BDL("=H;W)D92YS=6-C
M97-S)RD["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@("1G<F]U<"`](&YU;&P["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=7!D871E9#L*("`@
M('T*"B`@("`O*BH*("`@("`J($=E;F5R871E('1H92!522!F;W(@=&AE('!R
M969E<F5N8V5S(&EN=&5R9F%C92P@96ET:&5R(&9O<B!A"B`@("`@*B!S<&5C
M:69I8R!G<F]U<"P@;W(@=&AE(&=R;W5P('-E;&5C=&EO;B!I;G1E<F9A8V4N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9W)O=7`@(%1H92!G<F]U
M<"!T;R!G96YE<F%T92!T:&4@54D@9F]R+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G96YE<F%T955)*"1G<F]U<"`](&YU;&PI"B`@("!["B`@("`@("`@9VQO
M8F%L("1B<F]W<V5R+"`D8V]N9BP@)'!R969S+"`D<')E9D=R;W5P<RP@)%]P
M<F5F<RP@)')E9VES=')Y+"`D87!P.PH*("`@("`@("`O*B!#:&5C:R!I9B!A
M;GD@;W!T:6]N<R!A<F4@86-T=6%L;'D@879A:6QA8FQE+B`J+PH@("`@("`@
M(&EF("AI<U]N=6QL*"1P<F5F1W)O=7!S*2D@>PH@("`@("`@("`@("`D1TQ/
M0D%,4ULG;F]T:69I8V%T:6]N)UTM/G!U<V@H7R@B5&AE<F4@87)E(&YO(&]P
M=&EO;G,@879A:6QA8FQE+B(I+"`G:&]R9&4N;65S<V%G92<I.PH@("`@("`@
M('T*"B`@("`@("`@+RH@4VAO=R!T:&4@:&5A9&5R+B`J+PH@("`@("`@(%!R
M969S7U5).CIG96YE<F%T94AE861E<B@D9W)O=7`I.PH*("`@("`@("`O*B!!
M<W-I9VX@=F%R:6%B;&5S('1O(&AO;&0@<V5L96-T(&QI<W1S+B`J+PH@("`@
M("`@(&EF("@A)'!R969S+3YI<TQO8VME9"@G;&%N9W5A9V4G*2D@>PH@("`@
M("`@("`@("`D1TQ/0D%,4ULG;&%N9W5A9V5?;W!T:6]N<R==(#T@)$=,3T)!
M3%-;)VYL<R==6R=L86YG=6%G97,G73L*("`@("`@("`@("`@87)R87E?=6YS
M:&EF="@D1TQ/0D%,4ULG;&%N9W5A9V5?;W!T:6]N<R==+"!?*")$969A=6QT
M(BDI.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D9W)O=7`I("8F
M(%!R969S7U5).CIG<F]U<$ES161I=&%B;&4H)&=R;W5P*2D@>PH@("`@("`@
M("`@("!F;W)E86-H("@D<')E9D=R;W5P<ULD9W)O=7!=6R=M96UB97)S)UT@
M87,@)'!R968I('L*("`@("`@("`@("`@("`@(&EF("@A)'!R969S+3YI<TQO
M8VME9"@D<')E9BDI('L*("`@("`@("`@("`@("`@("`@("`O*B!'970@=&AE
M(&AE;'`@;&EN:RX@*B\*("`@("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y
M*"1?<')E9G-;)'!R969=6R=H96QP)UTI*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1H96QP;&EN:R`]($AE;'`Z.FQI;FLH(65M<'1Y*"1?<')E9G-;
M)'!R969=6R=S:&%R960G72D@/R`G:&]R9&4G(#H@)')E9VES=')Y+3YG971!
M<'`H*2P@)%]P<F5F<ULD<')E9EU;)VAE;'`G72D["B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)&AE;'!L
M:6YK(#T@;G5L;#L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`@("`@("`@('-W:71C:"`H)%]P<F5F<ULD<')E9EU;)W1Y<&4G72D@>PH@
M("`@("`@("`@("`@("`@("`@(&-A<V4@)VEM<&QI8VET)SH*("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@("`@(&-A
M<V4@)W-P96-I86PG.@H@("`@("`@("`@("`@("`@("`@("`@("!R97%U:7)E
M("1R96=I<W1R>2T^9V5T*"=T96UP;&%T97,G+"`A96UP='DH)%]P<F5F<ULD
M<')E9EU;)W-H87)E9"==*2`_("=H;W)D92<@.B`D<F5G:7-T<GDM/F=E=$%P
M<"@I*2`N("(O<')E9G,O)'!R968N:6YC(CL*("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@("`@(&1E9F%U;'0Z"B`@
M("`@("`@("`@("`@("`@("`@("`@(')E<75I<F4@)')E9VES=')Y+3YG970H
M)W1E;7!L871E<R<L("=H;W)D92<I("X@)R]P<F5F<R\G("X@)%]P<F5F<ULD
M<')E9EU;)W1Y<&4G72`N("<N:6YC)SL*("`@("`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(')E<75I<F4@)')E9VES
M=')Y+3YG970H)W1E;7!L871E<R<L("=H;W)D92<I("X@)R]P<F5F<R]E;F0N
M:6YC)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<W!A;B`](#$P
M,#L*("`@("`@("`@("`@)&-O;'5M;G,@/2!A<G)A>2@I.PH@("`@("`@("`@
M("!I9B`H:7-?87)R87DH)'!R969'<F]U<',I*2!["B`@("`@("`@("`@("`@
M("!F;W)E86-H("@D<')E9D=R;W5P<R!A<R`D9W)O=7`@/3X@)&=V86QS*2![
M"B`@("`@("`@("`@("`@("`@("`@:68@*%!R969S7U5).CIG<F]U<$ES161I
M=&%B;&4H)&=R;W5P*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D8V]L
M(#T@)&=V86QS6R=C;VQU;6XG73L*("`@("`@("`@("`@("`@("`@("`@("`@
M=6YS970H)&=V86QS6R=C;VQU;6XG72D["B`@("`@("`@("`@("`@("`@("`@
M("`@("1C;VQU;6YS6R1C;VQ=6R1G<F]U<%T@/2`D9W9A;',["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@:68@*&-O=6YT*"1C;VQU;6YS*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1S<&%N(#T@<F]U;F0H,3`P("\@8V]U;G0H)&-O;'5M;G,I*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@<F5Q=6ER
M92`D<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+W!R
M969S+V]V97)V:65W+FEN8R<["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@1V5N97)A=&5S('1H92!T:&4@9G5L;"!H96%D97(@;V8@82!P<F5F
M97)E;F-E('-C<F5E;B!I;F-L=61I;F<*("`@("`J(&UE;G4@86YD(&YA=FEG
M871I;VX@8F%R<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1G<F]U
M<"`@5&AE(&=R;W5P('1O(&=E;F5R871E('1H92!H96%D97(@9F]R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G96YE<F%T94AE861E<B@D9W)O=7`@/2!N=6QL
M*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GDL("1P<F5F1W)O=7!S
M+"`D87!P+"`D<&5R;7,L("1P<F5F<RP@)&YO=&EF:6-A=&EO;CL*"B`@("`@
M("`@)'1I=&QE(#T@7R@B57-E<B!/<'1I;VYS(BD["B`@("`@("`@:68@*"1G
M<F]U<"`]/2`G:61E;G1I=&EE<R<@)B8@(21P<F5F<RT^:7-,;V-K960H)V1E
M9F%U;'1?:61E;G1I='DG*2D@>PH@("`@("`@("`@("`D;F]T:69I8V%T:6]N
M+3YP=7-H*"=N97=#:&]I8V4H*2<L("=J879A<V-R:7!T)RD["B`@("`@("`@
M?0H@("`@("`@(')E<75I<F4@)')E9VES=')Y+3YG970H)W1E;7!L871E<R<L
M("1A<'`I("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["B`@("`@("`@:68@*&ES
M7V-A;&QA8FQE*&%R<F%Y*"1A<'`L("=G971-96YU)RDI*2!["B`@("`@("`@
M("`@("1M96YU(#T@8V%L;%]U<V5R7V9U;F,H87)R87DH)&%P<"P@)V=E=$UE
M;G4G*2D["B`@("`@("`@("`@(')E<75I<F4@)')E9VES=')Y+3YG970H)W1E
M;7!L871E<R<L("=H;W)D92<I("X@)R]M96YU+VUE;G4N:6YC)SL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`O*B!5<V4@82!D969A=6QT(&UE;G4N
M("HO"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O365N=2YP:'`G
M.PH@("`@("`@("`@("`D;65N=2`]("9N97<@365N=2@I.PH@("`@("`@("`@
M("!R97%U:7)E("1R96=I<W1R>2T^9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G
M*2`N("<O;65N=2]M96YU+FEN8R<["B`@("`@("`@?0H*("`@("`@("!I9B`H
M:7-?8V%L;&%B;&4H87)R87DH)&%P<"P@)W-T871U<R<I*2D@>PH@("`@("`@
M("`@("!C86QL7W5S97)?9G5N8RAA<G)A>2@D87!P+"`G<W1A='5S)RDI.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1'3$]"04Q36R=N;W1I9FEC
M871I;VXG72T^;F]T:69Y*&%R<F%Y*"=L:7-T96YE<G,G(#T^("=S=&%T=7,G
M*2D["B`@("`@("`@?0H*("`@("`@("`O*B!'970@;&ES="!O9B!A8V-E<W-I
M8FQE(&%P<&QI8V%T:6]N<RX@*B\*("`@("`@("`D87!P<R`](&%R<F%Y*"D[
M"B`@("`@("`@9F]R96%C:"`H)')E9VES=')Y+3YA<'!L:6-A=&EO;G,@87,@
M)&%P<&QI8V%T:6]N(#T^("1P87)A;7,I('L*("`@("`@("`@("`@+R\@36%K
M92!S=7)E('1H92!A<'`@:7,@:6YS=&%L;&5D(&%N9"!H87,@82!P<F5F<R!F
M:6QE+@H@("`@("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1R96=I<W1R>2T^
M9V5T*"=F:6QE<F]O="<L("1A<'!L:6-A=&EO;BD@+B`G+V-O;F9I9R]P<F5F
M<RYP:'`G*2D@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@(&EF("@D<&%R86US6R=S=&%T=7,G72`]/2`G
M:&5A9&EN9R<@?'P*("`@("`@("`@("`@("`@("1P87)A;7-;)W-T871U<R==
M(#T]("=B;&]C:R<I('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`O*B!#:&5C:R!I9B!T:&4@8W5R<F5N
M="!U<V5R(&AA<R!P97)M:7-S;VX@=&\@<V5E('1H:7,*("`@("`@("`@("`@
M("H@87!P;&EC871I;VXL(&%N9"!I9B!T:&4@87!P;&EC871I;VX@:7,@86-T
M:79E+@H@("`@("`@("`@("`@*B!!9&UI;FES=')A=&]R<R!A;'=A>7,@<V5E
M(&%L;"!A<'!L:6-A=&EO;G,N("HO"B`@("`@("`@("`@(&EF("@H075T:#HZ
M:7-!9&UI;B@I("8F("1P87)A;7-;)W-T871U<R==("$]("=I;F%C=&EV92<I
M('Q\"B`@("`@("`@("`@("`@("`H)')E9VES=')Y+3YH87-097)M:7-S:6]N
M*"1A<'!L:6-A=&EO;BD@)B8*("`@("`@("`@("`@("`@("`H)'!A<F%M<ULG
M<W1A='5S)UT@/3T@)V%C=&EV92<@?'P@)'!A<F%M<ULG<W1A='5S)UT@/3T@
M)VYO=&]O;&)A<B<I*2D@>PH@("`@("`@("`@("`@("`@)&%P<'-;)&%P<&QI
M8V%T:6]N72`](%\H)'!A<F%M<ULG;F%M92==*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!A<V]R="@D87!P<RD["@H@("`@("`@("\J(%-H
M;W<@=&AE(&-U<G)E;G0@87!P;&EC871I;VX@86YD(&$@9F]R;2!F;W(@<W=I
M=&-H:6YG"B`@("`@("`@("H@87!P;&EC871I;VYS+B`J+PH@("`@("`@(')E
M<75I<F4@)')E9VES=')Y+3YG970H)W1E;7!L871E<R<L("=H;W)D92<I("X@
M)R]P<F5F<R]A<'`N:6YC)SL*"B`@("`@("`@+RH@268@=&AE<F4G<R!O;FQY
M(&]N92!P<F5F1W)O=7`L(&IU<W0@<VAO=R!I="X@*B\*("`@("`@("!I9B`H
M96UP='DH)&=R;W5P*2`F)B!C;W5N="@D<')E9D=R;W5P<RD@/3T@,2D@>PH@
M("`@("`@("`@("`D9W)O=7`@/2!A<G)A>5]K97ES*"1P<F5F1W)O=7!S*3L*
M("`@("`@("`@("`@)&=R;W5P(#T@87)R87E?<&]P*"1G<F]U<"D["B`@("`@
M("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1G<F]U<"D@)B8@4')E9G-?54DZ
M.F=R;W5P27-%9&ET86)L92@D9W)O=7`I*2!["B`@("`@("`@("`@(')E<75I
M<F4@)')E9VES=')Y+3YG970H)W1E;7!L871E<R<L("=H;W)D92<I("X@)R]P
M<F5F<R]B96=I;BYI;F,G.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($=E;F5R871E('1H92!C;VYT96YT(&]F('1H92!T:71L92!B87(@;F%V
M:6=A=&EO;B!C96QL("AP<F5V:6]U<R!\(&YE>'0*("`@("`J(&]P=&EO;B!G
M<F]U<"DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9W)O=7`@($-U
M<G)E;G0@;W!T:6]N(&=R;W5P+@H@("`@("HO"B`@("!F=6YC=&EO;B!G96YE
M<F%T94YA=FEG871I;VY#96QL*"1G<F]U<"D*("`@('L*("`@("`@("!G;&]B
M86P@)'!R969'<F]U<',L("1R96=I<W1R>2P@)&%P<#L*"B`@("`@("`@+R\@
M4V5A<F-H(&9O<B!P<F5V:6]U<R!A;F0@;F5X="!G<F]U<',N"B`@("`@("`@
M)'!R979I;W5S(#T@;G5L;#L*("`@("`@("`D;F5X="`](&YU;&P["B`@("`@
M("`@)&QA<W0@/2!N=6QL.PH@("`@("`@("1F:7)S="`](&YU;&P["B`@("`@
M("`@)&9O=6YD(#T@9F%L<V4["B`@("`@("`@)&9I;FES:"`](&9A;'-E.PH@
M("`@("`@(&9O<F5A8V@@*"1P<F5F1W)O=7!S(&%S("1P9W)O=7`@/3X@)&=V
M86PI('L*("`@("`@("`@("`@:68@*%!R969S7U5).CIG<F]U<$ES161I=&%B
M;&4H)'!G<F]U<"DI('L*("`@("`@("`@("`@("`@(&EF("@A)&9I<G-T*2![
M"B`@("`@("`@("`@("`@("`@("`@)&9I<G-T(#T@)'!G<F]U<#L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@A)&9O=6YD*2!["B`@
M("`@("`@("`@("`@("`@("`@:68@*"1P9W)O=7`@/3T@)&=R;W5P*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1P<F5V:6]U<R`]("1L87-T.PH@("`@
M("`@("`@("`@("`@("`@("`@("`D9F]U;F0@/2!T<G5E.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@:68@*"$D9FEN:7-H*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1F:6YI<V@@/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@("`@
M("`D;F5X="`]("1P9W)O=7`["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&QA<W0@/2`D<&=R;W5P
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@A)'!R979I
M;W5S*2!["B`@("`@("`@("`@("1P<F5V:6]U<R`]("1L87-T.PH@("`@("`@
M('T*("`@("`@("!I9B`H(21N97AT*2!["B`@("`@("`@("`@("1N97AT(#T@
M)&9I<G-T.PH@("`@("`@('T*"B`@("`@("`@+RH@1&]N)W0@;&]O<"!I9B!T
M:&5R92=S(&]N;'D@;VYE(&=R;W5P+B`J+PH@("`@("`@(&EF("@D;F5X="`]
M/2`D<')E=FEO=7,I('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*
M"B`@("`@("`@96-H;R`G/'5L/CQL:3XG.PH@("`@("`@(&EF("@A96UP='DH
M)'!R969'<F]U<'-;)'!R979I;W5S75LG=7)L)UTI*2!["B`@("`@("`@("`@
M(&5C:&\@2&]R9&4Z.FQI;FLH2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"1P<F5F
M1W)O=7!S6R1P<F5V:6]U<UU;)W5R;"==*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!?*")0<F5V:6]U<R!O<'1I;VYS(BDI.PH@("`@("`@("`@
M("!E8VAO("<F;'0[)FQT.R`G("X@)'!R969'<F]U<'-;)'!R979I;W5S75LG
M;&%B96PG73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!E8VAO($AO
M<F1E.CIL:6YK*%5T:6PZ.F%D9%!A<F%M971E<BA(;W)D93HZ=7)L*"1R96=I
M<W1R>2T^9V5T*"=W96)R;V]T)RP@)VAO<F1E)RD@+B`G+W-E<G9I8V5S+W!R
M969S+G!H<"<I+"!A<G)A>2@G9W)O=7`G(#T^("1P<F5V:6]U<RP@)V%P<"<@
M/3X@)&%P<"DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%\H(E!R
M979I;W5S(&]P=&EO;G,B*2D["B`@("`@("`@("`@(&5C:&\@)R9L=#LF;'0[
M("<@+B`D<')E9D=R;W5P<ULD<')E=FEO=7-=6R=L86)E;"==.PH@("`@("`@
M('T*("`@("`@("!E8VAO("<\+V$^)FYB<W`[?"9N8G-P.R<["B`@("`@("`@
M:68@*"%E;7!T>2@D<')E9D=R;W5P<ULD;F5X=%U;)W5R;"==*2D@>PH@("`@
M("`@("`@("!E8VAO($AO<F1E.CIL:6YK*$AO<F1E.CIA<'!L:6-A=&EO;E5R
M;"@D<')E9D=R;W5P<ULD;F5X=%U;)W5R;"==*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!?*").97AT(&]P=&EO;G,B*2D["B`@("`@("`@("`@
M(&5C:&\@)'!R969'<F]U<'-;)&YE>'1=6R=L86)E;"==("X@)R`F9W0[)F=T
M.R<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@96-H;R!(;W)D93HZ
M;&EN:RA5=&EL.CIA9&1087)A;65T97(H2&]R9&4Z.G5R;"@D<F5G:7-T<GDM
M/F=E="@G=V5B<F]O="<L("=H;W)D92<I("X@)R]S97)V:6-E<R]P<F5F<RYP
M:'`G*2P@87)R87DH)V=R;W5P)R`]/B`D;F5X="P@)V%P<"<@/3X@)&%P<"DI
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%\H(DYE>'0@;W!T:6]N
M<R(I*3L*("`@("`@("`@("`@96-H;R`D<')E9D=R;W5P<ULD;F5X=%U;)VQA
M8F5L)UT@+B`G("9G=#LF9W0[)SL*("`@("`@("!]"B`@("`@("`@96-H;R`G
M/"]A/CPO;&D^/"]U;#XG.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T('1H
M92!D969A=6QT(&%P<&QI8V%T:6]N('1O('-H;W<@<')E9F5R96YC97,@9F]R
M+B!$969A=6QT<PH@("`@("H@=&\@)VAO<F1E)RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T1&5F875L=$%P<"@I"B`@("!["B`@("`@("`@)&%P<&QI8V%T
M:6]N<R`]("1'3$]"04Q36R=R96=I<W1R>2==+3YL:7-T07!P<RAN=6QL+"!T
M<G5E+"!015)-4U]214%$*3L*("`@("`@("!R971U<FX@:7-S970H)&%P<&QI
M8V%T:6]N<ULG:&]R9&4G72D@/R`G:&]R9&4G(#H@87)R87E?<VAI9G0H)&%P
M<&QI8V%T:6]N<RD["B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+U!R969S+VMO;&%B+G!H<```````````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S,S8W(#$P-3$U-#,S-S,V
M(#`R,C(T,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D92]0<F5F<R]L9&%P+G!H
M<"<["@HO*BH*("H@2V]L86(@:6UP;&5M96YT871I;VX@;V8@=&AE($AO<F1E
M('!R969E<F5N8V4@<WES=&5M+B!$97)I=F5S(&9R;VT@=&AE"B`J(%!R969S
M7VQD87`@3$1!4"!A=71H96YT:6-A=&EO;B!O8FIE8W0L(&%N9"!S:6UP;'D@
M<')O=FED97,@<&%R86UE=&5R<R!T;R!I=`H@*B!B87-E9"!O;B!T:&4@9VQO
M8F%L($MO;&%B(&-O;F9I9W5R871I;VXN"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+U!R969S+U!R969S+VMO;&%B+G!H<"QV(#$N,2XQ,"XX(#(P,#8O,#8O
M,C$@,C`Z,#DZ,#<@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P
M,#8@4W1U87)T($)I;F=E(#QS+F)I;F=E0&-O9&5F=7-I;VXN8V\N>F$^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!3='5A<G0@0FEN9V4@/',N8FEN
M9V5`8V]D969U<VEO;BYC;RYZ83X*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J
M($!P86-K86=E($AO<F1E7U!R969S"B`J+PIC;&%S<R!0<F5F<U]K;VQA8B!E
M>'1E;F1S(%!R969S7VQD87`@>PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T
M<R!A(&YE=R!+;VQA8B!P<F5F97)E;F-E<R!O8FIE8W0N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=7-E<B`@("`@(%1H92!U<V5R('=H;R!O=VYS
M('1H97-E('!R969E<F5N8V5S+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%S
M<W=O<F0@(%1H92!P87-S=V]R9"!A<W-O8VEA=&5D('=I=&@@)'5S97(N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1S8V]P92`@("`@5&AE(&-U<G)E;G0@87!P
M;&EC871I;VX@<V-O<&4N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@
M("`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)&-A8VAI;F<@(%-H;W5L9"!C86-H:6YG
M(&)E('5S960_"B`@("`@*B\*("`@(&9U;F-T:6]N(%!R969S7VMO;&%B*"1U
M<V5R+"`D<&%S<W=O<F0L("1S8V]P92`]("<G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"DL("1C86-H:6YG(#T@9F%L<V4I
M"B`@("!["B`@("`@("`@)'!A<F%M<ULG:&]S='-P96,G72`]("1'3$]"04Q3
M6R=C;VYF)UU;)VMO;&%B)UU;)VQD87`G75LG<V5R=F5R)UT["B`@("`@("`@
M)'!A<F%M<ULG<&]R="==(#T@)$=,3T)!3%-;)V-O;F8G75LG:V]L86(G75LG
M;&1A<"==6R=P;W)T)UT["B`@("`@("`@)'!A<F%M<ULG=F5R<VEO;B==(#T@
M)S,G.PH@("`@("`@("1P87)A;7-;)V)A<V5D;B==(#T@)$=,3T)!3%-;)V-O
M;F8G75LG:V]L86(G75LG;&1A<"==6R=B87-E9&XG73L*("`@("`@("`D<&%R
M86US6R=F971C:&1N)UT@/2!T<G5E.PH@("`@("`@("1P87)A;7-;)W-E87)C
M:&1N)UT@/2`D1TQ/0D%,4ULG8V]N9B==6R=K;VQA8B==6R=L9&%P)UU;)W!H
M<&1N)UT["B`@("`@("`@)'!A<F%M<ULG<V5A<F-H<&%S<R==(#T@)$=,3T)!
M3%-;)V-O;F8G75LG:V]L86(G75LG;&1A<"==6R=P:'!P=R==.PH@("`@("`@
M("1P87)A;7-;)W5I9"==(#T@87)R87DH)VUA:6PG+"`G=6ED)RD["@H@("`@
M("`@('!A<F5N=#HZ4')E9G-?;&1A<"@D=7-E<BP@)'!A<W-W;W)D+"`D<V-O
M<&4L("1P87)A;7,L("1C86-H:6YG*3L*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B](;W)D92]0<F5F<R]L9&%P+G!H<```````````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`U,#$P,R`Q,#4Q-30S,S<S-B`P,C(P
M-C``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*"B\J*@H@*B!(;W)D95]3=')I;F<@8VQA<W,N"B`J+PIR97%U:7)E
M7V]N8V4@)TAO<F1E+U-T<FEN9RYP:'`G.PH*+RHJ"B`J(%!R969E<F5N8V5S
M('-T;W)A9V4@:6UP;&5M96YT871I;VX@9F]R(%!(4"=S($Q$05`@97AT96YT
M:6]N+@H@*@H@*B!297%U:7)E9"!P87)A;65T97)S.CQP<F4^"B`J("`@)V)A
M<V5D;B<@("`@5&AE(&)A<V4@1$X@9F]R('1H92!,1$%0('-E<G9E<BX*("H@
M("`G:&]S='-P96,G("!4:&4@:&]S=&YA;64@;V8@=&AE($Q$05`@<V5R=F5R
M+@H@*B`@("=U:60G("`@("`@(%1H92!U<V5R;F%M92!S96%R8V@@:V5Y+CPO
M<')E/@H@*@H@*B!/<'1I;VYA;"!P87)A;65T97)S.CQP<F4^"B`J("`@)W!A
M<W-W;W)D)R`@)W)O;W1D;B=S('!A<W-W;W)D(&9O<B!B:6YD(&%U=&AE;G1I
M8V%T:6]N+@H@*B`@("=P;W)T)R`@("`@(%1H92!P;W)T(&]F('1H92!,1$%0
M('-E<G9E<BX*("H@("`@("`@("`@("`@("!$149!54Q4.B`S.#D*("H@("`G
M<F]O=&1N)R`@("!4:&4@1$X@;V8@=&AE(')O;W0@*&%D;6EN:7-T<F%T:79E
M*2!A8V-O=6YT('1O(&)I;F0@9F]R"B`J("`@("`@("`@("`@("`@=W)I=&4@
M;W!E<F%T:6]N<RX*("H@("`G=7-E<FYA;64G("!43T1/"B`J("`@)W9E<G-I
M;VXG("`@5&AE('9E<G-I;VX@;V8@=&AE($Q$05`@<')O=&]C;VP@=&\@=7-E
M+@H@*B`@("`@("`@("`@("`@($1%1D%53%0Z($Y/3D4@*'-Y<W1E;2!D969A
M=6QT('=I;&P@8F4@=7-E9"D\+W!R93X*("H*("H@3D]413H@<&%R86UE=&5R
M("=U<V5R;F%M92<@:&%S(&)E96X@9&5P<F5C871E9"X@57-E("=R;V]T9&XG
M+@H@*@H@*@H@*B!)9B!S971T:6YG('5P(&%S('1H92!(;W)D92!P<F5F97)E
M;F-E(&AA;F1L97(@:6X@8V]N9BYP:'`L('1H92!F;VQL;W=I;F<*("H@:7,@
M86X@97AA;7!L92!C;VYF:6=U<F%T:6]N+@H@*B!4:&4@<V-H96UA<R!N965D
M960@9F]R(&QD87`@87)E(&EN(&AO<F1E+W-C<FEP=',O;&1A<"X*("H*("H@
M/'!R93X*("H@("`D8V]N9ELG<')E9G,G75LG9')I=F5R)UT@/2`G;&1A<"<[
M"B`J("`@)&-O;F9;)W!R969S)UU;)W!A<F%M<R==6R=H;W-T<W!E8R==(#T@
M)VQO8V%L:&]S="<["B`J("`@)&-O;F9;)W!R969S)UU;)W!A<F%M<R==6R=P
M;W)T)UT@/2`G,S@Y)SL*("H@("`D8V]N9ELG<')E9G,G75LG<&%R86US)UU;
M)V)A<V5D;B==(#T@)V1C/65X86UP;&4L9&,];W)G)SL*("H@("`D8V]N9ELG
M<')E9G,G75LG<&%R86US)UU;)W5I9"==(#T@)VUA:6PG.PH@*B`\+W!R93X*
M("H*("H@5&AE(&9O;&QO=VEN9R!I<R!V86QI9"!B=70@=V]U;&0@;VYL>2!B
M92!N96-E<W-A<GD@:68@=7-E<G,*("H@9&\@3D]4(&AA=F4@<&5R;6ES<VEO
M;B!T;R!M;V1I9GD@=&AE:7(@;W=N($Q$05`@86-C;W5N=',N"B`J"B`J(#QP
M<F4^"B`J("`@)&-O;F9;)W!R969S)UU;)W!A<F%M<R==6R=R;V]T9&XG72`]
M("=C;CU-86YA9V5R+&1C/65X86UP;&4L9&,];W)G)SL*("H@("`D8V]N9ELG
M<')E9G,G75LG<&%R86US)UU;)W!A<W-W;W)D)UT@/2`G<&%S<W=O<F0G.PH@
M*B`\+W!R93X*("H*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O;&1A<"YP:'`L=B`Q+C@U+C$P+C(P(#(P,#8O,#8O,C$@,C`Z,#<Z-34@
M:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@2F]N(%!A<FES
M92`\:F]N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E
M(#$N,PH@*B!`<&%C:V%G92!(;W)D95]0<F5F<PH@*B\*8VQA<W,@4')E9G-?
M;&1A<"!E>'1E;F1S(%!R969S('L*"B`@("`O*BH*("`@("`J($AA<V@@8V]N
M=&%I;FEN9R!C;VYN96-T:6]N('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A>2@I
M.PH*("`@("\J*@H@("`@("H@2&%N9&QE(&9O<B!T:&4@8W5R<F5N="!,1$%0
M(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@("H@0'9A<B!R97-O=7)C90H@("`@
M("HO"B`@("!V87(@)%]C;VYN96-T:6]N.PH*("`@("\J*@H@("`@("H@0F]O
M;&5A;B!I;F1I8V%T:6YG('=H971H97(@;W(@;F]T('=E)W)E(&-O;FYE8W1E
M9"!T;R!T:&4@3$1!4"!S97)V97(N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L
M96%N"B`@("`@*B\*("`@('9A<B`D7V-O;FYE8W1E9"`](&9A;'-E.PH*("`@
M("\J*@H@("`@("H@4W1R:6YG(&AO;&1I;F<@=&AE('5S97(G<R!$3BX*("`@
M("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]D;B`]
M("<G.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!,1$%0('!R
M969E<F5N8V5S(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1U<V5R("`@("`@5&AE('5S97(@=VAO(&]W;G,@=&AE<V4@<')E9F5R96YC
M97,N"B`@("`@*B!`<&%R86T@<W1R:6YG("1P87-S=V]R9"`@5&AE('!A<W-W
M;W)D(&%S<V]C:6%T960@=VET:"`D=7-E<BX*("`@("`J($!P87)A;2!S=')I
M;F<@)'-C;W!E("`@("!4:&4@8W5R<F5N="!A<'!L:6-A=&EO;B!S8V]P92X*
M("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@("!!(&AA<V@@8V]N=&%I
M;FEN9R!C;VYN96-T:6]N('!A<F%M971E<G,N"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D8V%C:&EN9R`@4VAO=6QD(&-A8VAI;F<@8F4@=7-E9#\*("`@("`J
M+PH@("`@9G5N8W1I;VX@4')E9G-?;&1A<"@D=7-E<BP@)'!A<W-W;W)D+"`D
M<V-O<&4@/2`G)RP*("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<R`]
M(&%R<F%Y*"DL("1C86-H:6YG(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@
M*"%5=&EL.CIE>'1E;G-I;VY%>&ES=',H)VQD87`G*2D@>PH@("`@("`@("`@
M("!(;W)D93HZ9F%T86PH4$5!4CHZ<F%I<V5%<G)O<BA?*")0<F5F<U]L9&%P
M.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(BDI+"!?7T9)
M3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]U
M<V5R(#T@)'5S97(["B`@("`@("`@)'1H:7,M/E]S8V]P92`]("1S8V]P93L*
M("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P87)A;7,["B`@("`@("`@)'1H
M:7,M/E]C86-H:6YG(#T@)&-A8VAI;F<["@H@("`@("`@("\J($EF(&$@=F%L
M:60@<V5R=F5R('!O<G0@:&%S(&YO="!B965N('-P96-I9FEE9"P@<V5T('1H
M92!D969A=6QT+B`J+PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A
M;7-;)W!O<G0G72D@?'P@(6ES7VEN="@D=&AI<RT^7W!A<F%M<ULG<&]R="==
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<&]R="==(#T@,S@Y
M.PH@("`@("`@('T*"B`@("`@("`@+RH@268@)'!A<F%M<ULG<F]O=&1N)UT@
M:7,@96UP='DL(&%U=&AE;G1I8V%T92!A<R!T:&4@8W5R<F5N="!U<V5R+@H@
M("`@("`@("`@($YO=&4Z(%1H:7,@87-S=6UE<R!T:&4@=7-E<B!I<R!A;&QO
M=V5D('1O(&UO9&EF>2!T:&5I<B!O=VX@3$1!4`H@("`@("`@("`@("`@("`@
M(&5N=')Y+B`J+PH@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W!A<F%M<ULG
M=7-E<FYA;64G72D@)B8*("`@("`@("`@("`@96UP='DH)'1H:7,M/E]P87)A
M;7-;)W)O;W1D;B==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG
M=7-E<FYA;64G72`]("1U<V5R.PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M
M<ULG<&%S<W=O<F0G72`]("1P87-S=V]R9#L*("`@("`@("!]"@H@("`@("`@
M('!A<F5N=#HZ4')E9G,H*3L*("`@('T*"B`@("`O*BH*("`@("`J($]P96YS
M(&$@8V]N;F5C=&EO;B!T;R!T:&4@3$1!4"!S97)V97(N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;FYE8W0H*0H@("`@
M>PH@("`@("`@("\J(%)E='5R;B!I9B!A;')E861Y(&-O;FYE8W1E9"X@*B\*
M("`@("`@("!I9B`H)'1H:7,M/E]C;VYN96-T960I('L*("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("!(;W)D93HZ87-S97)T
M1')I=F5R0V]N9FEG*"1T:&ES+3Y?<&%R86US+"`G<')E9G,G+`H@("`@("`@
M("`@("!A<G)A>2@G:&]S='-P96,G+"`G8F%S961N)RP@)W5I9"<L("=P87-S
M=V]R9"<I+`H@("`@("`@("`@("`G<')E9F5R96YC97,@3$1!4"<I.PH*("`@
M("`@("`O*B!!;&QO=R!F;W(@;75L=&EP;&4@=6ED('-E87)C:"!F:65L9',@
M*B\*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1T:&ES+3Y?<&%R86US6R=U:60G
M72DI('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W5I9"==(#T@87)R
M87DH)'1H:7,M/E]P87)A;7-;)W5I9"==*3L*("`@("`@("!]"@H@("`@("`@
M("\J($-O;FYE8W0@=&\@=&AE($Q$05`@<V5R=F5R(&%N;VYY;6]U<VQY+B`J
M+PH@("`@("`@("1C;VYN(#T@;&1A<%]C;VYN96-T*"1T:&ES+3Y?<&%R86US
M6R=H;W-T<W!E8R==+"`D=&AI<RT^7W!A<F%M<ULG<&]R="==*3L*("`@("`@
M("!I9B`H(21C;VYN*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E
M*`H@("`@("`@("`@("`@("`@<W!R:6YT9B@G1F%I;&5D('1O(&]P96X@86X@
M3$1!4"!C;VYN96-T:6]N('1O("5S+B<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==*2P*("`@("`@("`@("`@
M("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"@H@("`@("`@("\J(%-E="!T:&4@3$1!4"!P<F]T
M;V-O;"!V97)S:6]N+B`J+PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A
M<F%M<ULG=F5R<VEO;B==*2D@>PH@("`@("`@("`@("!I9B`H(6QD87!?<V5T
M7V]P=&EO;B@D8V]N;BP@3$1!4%]/4%1?4%)/5$]#3TQ?5D524TE/3BP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)W9E<G-I;VXG72DI('L*("`@("`@("`@("`@("`@($AO<F1E.CIL;V=-97-S
M86=E*`H@("`@("`@("`@("`@("`@("`@('-P<FEN=&8H)U-E="!,1$%0('!R
M;W1O8V]L('9E<G-I;VX@=&\@)60@9F%I;&5D.B!;)61=("5S)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=V97)S:6]N
M)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!L9&%P7V5R<FYO*"1T
M:&ES+3Y?8V]N;F5C=&EO;BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!L9&%P7V5R<F]R*"1T:&ES+3Y?8V]N;F5C=&EO;BDI+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@268@;F5C97-S87)Y+"!B
M:6YD('1O('1H92!,1$%0('-E<G9E<B!A<R!T:&4@=7-E<B!W:71H('-E87)C
M:`H@("`@("`@("`J('!E<FUI<W-I;VYS+B`J+PH@("`@("`@(&EF("@A96UP
M='DH)'1H:7,M/E]P87)A;7-;)W-E87)C:&1N)UTI*2!["B`@("`@("`@("`@
M("1B:6YD(#T@0&QD87!?8FEN9"@D8V]N;BP@)'1H:7,M/E]P87)A;7-;)W-E
M87)C:&1N)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG<V5A<F-H<&%S<R==*3L*("`@("`@("`@("`@:68@*"$D
M8FEN9"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H<W!R:6YT9B@G0FEN9"!T;R!S97)V97(@)7,Z)60@=VET:"!$3B`E<R!F
M86EL960Z(%LE9%T@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G
M72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)W!O<G0G72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)W-E87)C:&1N)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&QD87!?97)R;F\H)'1H:7,M/E]C;VYN96-T
M:6]N*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@;&1A<%]E<G)O<B@D=&AI<RT^7V-O;FYE8W1I;VXI*2D["B`@
M("`@("`@("`@('T*"7T*"B`@("`@("`@+RH@4F5G:7-T97(@;W5R(&-A;&QB
M86-K(&9U;F-T:6]N('1O(&AA;F1L92!R969E<G)A;',N("HO"B`@("`@("`@
M:68@*&9U;F-T:6]N7V5X:7-T<R@G;&1A<%]S971?<F5B:6YD7W!R;V,G*2`F
M)@H@("`@("`@("`@("`A;&1A<%]S971?<F5B:6YD7W!R;V,H)&-O;FXL(&%R
M<F%Y*"1T:&ES+"`G7W)E8FEN9%!R;V,G*2DI('L*("`@("`@("`@("`@2&]R
M9&4Z.FQO9TUE<W-A9V4H"B`@("`@("`@("`@("`@("!S<')I;G1F*"=3970@
M<F5B:6YD('!R;V,@9F%I;&5D.B!;)61=("5S)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@;&1A<%]E<G)N;R@D=&AI<RT^7V-O;FYE8W1I;VXI+`H@("`@
M("`@("`@("`@("`@("`@("`@("!L9&%P7V5R<F]R*"1T:&ES+3Y?8V]N;F5C
M=&EO;BDI+`H@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@
M+RH@4W1O<F4@=&AE(&-O;FYE8W1I;VX@:&%N9&QE(&%T('1H92!I;G-T86YC
M92!L979E;"X@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W1I;VX@/2`D8V]N
M;CL*("`@("`@("`D=&AI<RT^7V-O;FYE8W1E9"`]('1R=64["@H@("`@("`@
M(&EF("@A)'1H:7,M/E]P87)A;7-;)V9E=&-H9&XG72D@>PH@("`@("`@("`@
M("`O*B!$969I;F4@=&AE($1.(&]F('1H92!C=7)R96YT('5S97(N("HO"B`@
M("`@("`@("`@("1T:&ES+3Y?9&X@/2!S<')I;G1F*"<E<STE<RPE<R<L("1T
M:&ES+3Y?<&%R86US6R=U:60G75LP72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]U<V5R+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG8F%S961N)UTI.PH*("`@
M("`@("`@("`@+RH@06YD('1H92!$3B!O9B!T:&4@875T:&5N=&EC871I;F<@
M=7-E<B`H;6%Y(&)E('1H92!S86UE(&%S(&%B;W9E*2X@*B\*("`@("`@("`@
M("`@:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG<F]O=&1N)UTI*2!["B`@
M("`@("`@("`@("`@("`D8FEN9%]D;B`]("1T:&ES+3Y?<&%R86US6R=R;V]T
M9&XG73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1B
M:6YD7V1N(#T@<W!R:6YT9B@G)7,])7,L)7,G+"`D=&AI<RT^7W!A<F%M<ULG
M=6ED)UU;,%TL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)W5S97)N86UE)UTL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V)A<V5D;B==*3L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@0FEN9"!T;R!T:&4@3$1!
M4"!S97)V97(@87,@=&AE(&%U=&AE;G1I8V%T:6YG('5S97(N("HO"B`@("`@
M("`@("`@("1B:6YD(#T@0&QD87!?8FEN9"@D=&AI<RT^7V-O;FYE8W1I;VXL
M("1B:6YD7V1N+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)W!A<W-W;W)D)UTI.PH@("`@("`@("`@("!I9B`H(21B
M:6YD*2!["B`@("`@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@*("`@
M("`@("`@("`@("`@("`@("!S<')I;G1F*"=":6YD('1O('-E<G9E<B`E<SHE
M9"!W:71H($1.("5S(&9A:6QE9#H@6R5D72`E<R<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=P;W)T
M)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8FEN9%]D;BP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&QD87!?97)R;F\H)'1H:7,M/E]C
M;VYN96-T:6]N*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&QD87!?
M97)R;W(H)'1H:7,M/E]C;VYN96-T:6]N*2DL"B`@("`@("`@("`@("`@("`@
M("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@
M4V5A<F-H(&9O<B!T:&4@=7-E<B=S(&9U;&P@1$XN("HO"B`@("`@("`@9F]R
M96%C:"`H)'1H:7,M/E]P87)A;7-;)W5I9"==(&%S("1U:61?9FEE;&0I('L*
M("`@("`@("`@("`@)'-E87)C:"`](&QD87!?<V5A<F-H*"1T:&ES+3Y?8V]N
M;F5C=&EO;BP@)'1H:7,M/E]P87)A;7-;)V)A<V5D;B==+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'5I9%]F:65L9"`N("<])R`N("1T
M:&ES+3Y?=7-E<BP@87)R87DH)V1N)RDI.PH@("`@("`@("`@("!I9B`H)'-E
M87)C:"D@>PH@("`@("`@("`@("`@("`@)')E<W5L="`](&QD87!?9V5T7V5N
M=')I97,H)'1H:7,M/E]C;VYN96-T:6]N+"`D<V5A<F-H*3L*("`@("`@("`@
M("`@("`@(&EF("@D<F5S=6QT("8F("1R97-U;'1;)V-O=6YT)UT@/B`P*2![
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D;B`]("1R97-U;'1;,%U;
M)V1N)UT["B`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?<&%R86US
M6R=F971C:&1N)UTI('L*("`@("`@("`@("`@("`@("`@("`@("`@+R\@4F4M
M8FEN9"!A<R!T:&4@=7-E<BX*("`@("`@("`@("`@("`@("`@("`@("`@)&)I
M;F0@/2!`;&1A<%]B:6YD*"1T:&ES+3Y?8V]N;F5C=&EO;BP@)'1H:7,M/E]D
M;BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=P87-S=V]R9"==*3L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M($AO<F1E.CIL;V=-97-S86=E*`H@("`@("`@("`@("!S<')I;G1F*"=&86EL
M960@=&\@<F5T<FEE=F4@=7-E<EPG<R!$3CH@6R5D72`E<R<L"B`@("`@("`@
M("`@("`@("`@("`@;&1A<%]E<G)N;R@D=&AI<RT^7V-O;FYE8W1I;VXI+`H@
M("`@("`@("`@("`@("`@("`@(&QD87!?97)R;W(H)'1H:7,M/E]C;VYN96-T
M:6]N*2DL"B`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["@H@("`@
M("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J($1I<V-O
M;FYE8W0@9G)O;2!T:&4@3$1!4"!S97)V97(@86YD(&-L96%N('5P('1H92!C
M;VYN96-T:6]N+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F
M86QS92!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9&ES8V]N
M;F5C="@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?8V]N;F5C=&5D*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?9&X@/2`G)SL*("`@("`@("`@("`@)'1H
M:7,M/E]C;VYN96-T960@/2!F86QS93L*("`@("`@("`@("`@<F5T=7)N(&QD
M87!?8VQO<V4H)'1H:7,M/E]C;VYN96-T:6]N*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#86QL8F%C:R!F=6YC=&EO;B!F;W(@3$1!4"!R969E
M<G)A;',N("!4:&ES(&9U;F-T:6]N(&ES(&-A;&QE9"!W:&5N(&%N"B`@("`@
M*B!,1$%0(&]P97)A=&EO;B!R971U<FYS(&$@<F5F97)R86P@=&\@86X@86QT
M97)N871E('-E<G9E<BX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(#$@;VX@97)R;W(L(#`@
M;VX@<W5C8V5S<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W)E8FEN9%!R;V,H
M)&-O;FXL("1W:&\I"B`@("!["B`@("`@("`@+RH@4W1R:7`@;W5T('1H92!H
M;W-T;F%M92!W92=R92!B96EN9R!R961I<F5C=&5D('1O+B`J+PH@("`@("`@
M("1W:&\@/2!P<F5G7W)E<&QA8V4H87)R87DH)WQ>+BHZ+R]\)RP@)WPZ7&0J
M)'PG*2P@)R<L("1W:&\I.PH*("`@("`@("`O*B!&:6=U<F4@;W5T('1H92!$
M3B!O9B!T:&4@875T:&5N=&EC871I;F<@=7-E<BX@*B\*("`@("`@("!I9B`H
M(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=R;V]T9&XG72DI('L*("`@("`@("`@
M("`@)&)I;F1?9&X@/2`D=&AI<RT^7W!A<F%M<ULG<F]O=&1N)UT["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&)I;F1?9&X@/2!S<')I;G1F*"<E
M<STE<RPE<R<L("1T:&ES+3Y?<&%R86US6R=U:60G75LP72P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=U<V5R;F%M
M92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)V)A<V5D;B==*3L*("`@("`@("!]"@H@("`@("`@("\J($UA:V4@
M<W5R92!T:&4@<V5R=F5R('=E)W)E(&)E:6YG(')E9&ER96-T960@=&\@:7,@
M:6X@;W5R(&QI<W0@;V8*("`@("`@("`@("!V86QI9"!S97)V97)S+B`J+PH@
M("`@("`@(&EF("AS=')P;W,H)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UTL
M("1W:&\I(#T]/2!F86QS92D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S
M<V%G92@*("`@("`@("`@("`@("`@('-P<FEN=&8H)U)E9F5R<F%L('1A<F=E
M="`E<R!F;W(@1$X@)7,@:7,@;F]T(&EN('1H92!A=71H;W)I>F5D('-E<G9E
M<B!L:7-T(2<L("1W:&\L("1B:6YD7V1N*2P*("`@("`@("`@("`@("`@(%]?
M1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@(')E='5R;B`Q.PH@("`@
M("`@('T*"B`@("`@("`@+RH@0FEN9"!T;R!T:&4@;F5W('-E<G9E<BX@*B\*
M("`@("`@("`D8FEN9"`]($!L9&%P7V)I;F0H)&-O;FXL("1B:6YD7V1N+"`D
M=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72D["B`@("`@("`@:68@*"$D8FEN
M9"D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@*("`@("`@("`@
M("`@("`@('-P<FEN=&8H)U)E8FEN9"!T;R!S97)V97(@)7,Z)60@=VET:"!$
M3B`E<R!F86EL960Z(%LE9%T@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G72P*("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!O<G0G72P*("`@("`@("`@("`@
M("`@("`@("`@("`@)&)I;F1?9&XL"B`@("`@("`@("`@("`@("`@("`@("`@
M(&QD87!?97)R;F\H)'1H:7,M/E]C;VYN96-T:6]N*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@;&1A<%]E<G)O<B@D=&AI<RT^7V-O;FYE8W1I;VXI*2P*
M("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@,#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M=')I979E<R!T:&4@<F5Q=65S=&5D('-E="!O9B!P<F5F97)E;F-E<R!F<F]M
M('1H92!U<V5R)W,@3$1!4"!E;G1R>2X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R971R:65V92@I
M"B`@("!["B`@("`@("`@+RH@071T96UP="!T;R!P=6QL('1H92!V86QU97,@
M9G)O;2!T:&4@<V5S<VEO;B!C86-H92!F:7)S="X@*B\*("`@("`@("!I9B`H
M)'1H:7,M/F-A8VAE3&]O:W5P*"DI('L*("`@("`@("`@("`@<F5T=7)N('1R
M=64["B`@("`@("`@?0H*("`@("`@("`O*B!,;V%D(&1E9F%U;'1S('1O(&UA
M:V4@<W5R92!W92!H879E(&%L;"!P<F5F97)E;F-E<RX@*B\*("`@("`@("!P
M87)E;G0Z.G)E=')I979E*"D["@H@("`@("`@("\J($UA:V4@<W5R92!W92!A
M<F4@8V]N;F5C=&5D+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*
M("`@("`@("`O*B!/;FQY(&9E=&-H('1H92!F:65L9',@9F]R('1H92!A='1R
M:6)U=&5S('=E(&YE960N("HO"B`@("`@("`@)&%T=')S(#T@87)R87DH)VAO
M<F1E4')E9G,G*3L*("`@("`@("!I9B`H<W1R8VUP*"1T:&ES+3Y?<V-O<&4L
M("=H;W)D92<I("$](#`I('L*("`@("`@("`@("`@)&%T=')S6UT@/2`D=&AI
M<RT^7W-C;W!E("X@)U!R969S)SL*("`@("`@("!]"@H@("`@("`@("\J(%-E
M87)C:"!F;W(@=&AE(&UU;'1I+79A;'5E9"!F:65L9"!C;VYT86EN:6YG('1H
M92!A<G)A>2!O9@H@("`@("`@("`@('!R969E<F5N8V5S+B`J+PH@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3Y?<&%R86US6R=U:60G72!A<R`D=6ED7V9I96QD
M*2!["B`@("`@("`@("`@("1S96%R8V@@/2!L9&%P7W-E87)C:"@D=&AI<RT^
M7V-O;FYE8W1I;VXL("1T:&ES+3Y?<&%R86US6R=B87-E9&XG72P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1U:61?9FEE;&0@+B`G/2<@
M+B`D=&AI<RT^7W5S97(L("1A='1R<RD["B`@("`@("`@("`@(&EF("@D<V5A
M<F-H*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@;&1A<%]G971?96YT
M<FEE<R@D=&AI<RT^7V-O;FYE8W1I;VXL("1S96%R8V@I.PH@("`@("`@("`@
M("`@("`@:68@*"1R97-U;'0@)B8@)')E<W5L=%LG8V]U;G0G72`^(#`I('L*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1R
M97-U;'0I*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=&86EL
M960@=&\@8V]N;F5C="!T;R!,1$%0('!R969E<F5N8V5S('-E<G9E<BXG+"!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@+RH@;&1A
M<%]G971?96YT<FEE<R@I(&-O;G9E<G1S(&%T=')I8G5T92!I;F1E>&5S('1O
M(&QO=V5R8V%S92X@*B\*("`@("`@("`D9FEE;&0@/2!3=')I;F<Z.FQO=V5R
M*"1T:&ES+3Y?<V-O<&4@+B`G<')E9G,G*3L*"B`@("`@("`@:68@*&ES<V5T
M*"1R97-U;'0I*2!["B`@("`@("`@("`@("\J(%-E="!T:&4@<F5Q=65S=&5D
M('9A;'5E<R!I;B!T:&4@)'1H:7,M/E]P<F5F<R!H87-H(&)A<V5D(&]N"B`@
M("`@("`@("`@("`@('1H92!C;VYT96YT<R!O9B!T:&4@3$1!4"!R97-U;'0N
M"@H@("`@("`@("`@("`@("!0<F5F97)E;F-E<R!A<F4@<W1O<F5D(&%S(&-O
M;&]N+7-E<&%R871E9"!N86UE.G9A;'5E('!A:7)S+@H@("`@("`@("`@("`@
M("!%86-H('!A:7(@:7,@<W1O<F5D(&%S(&ET<R!O=VX@871T<FEB=71E(&]F
M9B!O9B!T:&4@;75L=&DM"B`@("`@("`@("`@("`@('9A;'5E(&%T=')I8G5T
M92!N86UE9"!I;CH@)'1H:7,M/E]S8V]P92`N("=0<F5F<R<*"B`@("`@("`@
M("`@("`@($YO=&4@=&AA="!0<F5F<SHZ<V5T5F%L=64H*2!C86XG="!B92!U
M<V5D(&AE<F4@8F5C875S92!O9B!T:&4*("`@("`@("`@("`@("`@8VAE8VL@
M9F]R('1H92`B8VAA;F=E86)L92(@8FET+B`@5V4@=V%N="!T;R!O=F5R<FED
M92!T:&%T"B`@("`@("`@("`@("`@(&-H96-K('=H96X@<&]P=6QA=&EN9R!T
M:&4@)'1H:7,M/E]P<F5F<R!H87-H(&9R;VT@=&AE($Q$05`*("`@("`@("`@
M("`@("`@<V5R=F5R+@H@("`@("`@("`@("`@*B\*"B`@("`@("`@("`@("1P
M<F5F<R`](&%R<F%Y*"D["@H@("`@("`@("`@("`O*B!)9B!H;W)D95!R969S
M(&5X:7-T<RP@;65R9V4@=&AE;2!A<R!T:&4@8F%S92!O9B!T:&4@<')E9G,N
M("HO"B`@("`@("`@("`@(&EF("AI<W-E="@D<F5S=6QT6S!=6R=H;W)D97!R
M969S)UTI*2!["B`@("`@("`@("`@("`@("`D<')E9G,@/2!A<G)A>5]M97)G
M92@D<')E9G,L("1R97-U;'1;,%U;)VAO<F1E<')E9G,G72D["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("\J($EF('1H:7,@<V-O<&4G<R!P<F5F<R!A
M<F4@879A:6QA8FQE+"!M97)G92!T:&5M(&%S('=I;&PN("!':79E"B`@("`@
M("`@("`@("`J('1H96T@82!H:6=H97(@<')E8V5D96YC92!T:&%N(&AO<F1E
M4')E9G,N("HO"B`@("`@("`@("`@(&EF("AS=')C;7`H)'1H:7,M/E]S8V]P
M92P@)VAO<F1E)RD@(3T@,"D@>PH@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1R97-U;'1;,%U;)&9I96QD72DI('L*("`@("`@("`@("`@("`@("`@("`D
M<')E9G,@/2!A<G)A>5]M97)G92@D<')E9G,L("1R97-U;'1;,%U;)&9I96QD
M72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@(&9O<F5A8V@@*"1P<F5F<R!A<R`D<')E9G-T<BD@>PH@("`@("`@("`@
M("`@("`@+RH@268@=&AE('-T<FEN9R!D;V5S;B=T(&-O;G1A:6X@82!C;VQO
M;B!D96QI;6ET97(L('-K:7`@:70N("HO"B`@("`@("`@("`@("`@("!I9B`H
M<W5B<W1R7V-O=6YT*"1P<F5F<W1R+"`G.B<I(#T](#`I('L*("`@("`@("`@
M("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("`@("`O*B!3<&QI="!T:&4@<W1R:6YG(&EN=&\@:71S(&YA;64Z
M=F%L=64@8V]M<&]N96YT<RX@*B\*("`@("`@("`@("`@("`@(&QI<W0H)'!R
M968L("1V86PI(#T@<W!L:70H)SHG+"`D<')E9G-T<BP@,BD["@H@("`@("`@
M("`@("`@("`@+RH@4F5T<FEE=F4@=&AI<R!P<F5F97)E;F-E+B`J+PH@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<')E9G-;)'!R969=*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T5F%L=64H)'!R968L
M(&)A<V4V-%]D96-O9&4H)'9A;"DL(&9A;'-E*3L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^<V5T1&5F875L="@D<')E9BP@9F%L<V4I.PH@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M861D*"1P<F5F+"!B87-E-C1?9&5C;V1E*"1V86PI+"!?4%)%1E]32$%2140I
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`O*B!#86QL(&AO;VMS+B`J+PH@("`@("`@("`@("`D=&AI<RT^7V-A;&Q(
M;V]K<R@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@($AO<F1E.CIL
M;V=-97-S86=E*"=.;R!P<F5F97)E;F-E<R!W97)E(')E=')I979E9"XG+"!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!R971U<FX["B`@("`@
M("`@?0H*("`@("`@("`O*B!5<&1A=&4@=&AE('-E<W-I;VX@8V%C:&4N("HO
M"B`@("`@("`@)'1H:7,M/F-A8VAE57!D871E*"D["@H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4W1O<F5S('!R969E<F5N
M8V5S('1O('1H92!,1$%0('-E<G9E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S=&]R92@I"B`@
M("!["B`@("`@("`@)'5P9&%T960@/2!T<G5E.PH*("`@("`@("`O*B!#:&5C
M:R!F;W(@86YY(")D:7)T>2(@<')E9F5R96YC97,N($EF(&YO(")D:7)T>2(*
M("`@("`@("`@*B!P<F5F97)E;F-E<R!A<F4@9F]U;F0L('1H97)E)W,@;F\@
M;F5E9"!T;R!U<&1A=&4@=&AE($Q$05`*("`@("`@("`@*B!S97)V97(N($5X
M:70@<W5C8V5S<V9U;&QY+B`J+PH@("`@("`@("1D:7)T>5]P<F5F<R`]("1T
M:&ES+3Y?9&ER='E0<F5F<R@I.PH@("`@("`@(&EF("@A8V]U;G0H)&1I<G1Y
M7W!R969S*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]
M"@H@("`@("`@("\J($UA:V4@<W5R92!W92!A<F4@8V]N;F5C=&5D+B`J+PH@
M("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("`O*B!"=6EL9"!A
M(&AA<V@@;V8@=&AE('!R969E<F5N8V5S(&%N9"!T:&5I<B!V86QU97,@=&AA
M="!N965D"B`@("`@("`@("H@=&\@8F4@<W1O<F5D(&EN('1H92!,1$%0('-E
M<G9E<BX@0F5C875S92!W92!H879E('1O('5P9&%T90H@("`@("`@("`J(&%L
M;"!O9B!T:&4@=F%L=65S(&]F(&$@;75L=&DM=F%L=64@96YT<GD@=VAO;&5S
M86QE+"!W90H@("`@("`@("`J(&-A;B=T(&IU<W0@<&EC:R!O=70@=&AE(&1I
M<G1Y('!R969E<F5N8V5S.R!W92!M=7-T('5P9&%T90H@("`@("`@("`J(&5V
M97)Y=&AI;F<N("HO"B`@("`@("`@)&YE=U]V86QU97,@/2!A<G)A>2@I.PH@
M("`@("`@(&9O<F5A8V@@*&%R<F%Y7VME>7,H)'1H:7,M/E]P<F5F<RD@87,@
M)'!R968I('L*("`@("`@("`@("`@+R\@1&]N)W0@<W1O<F4@;&]C:V5D('!R
M969E<F5N8V5S+@H@("`@("`@("`@("!I9B`H(21T:&ES+3YI<TQO8VME9"@D
M<')E9BDI('L*("`@("`@("`@("`@("`@("1E;G1R>2`]("1P<F5F("X@)SHG
M("X@8F%S938T7V5N8V]D92@D=&AI<RT^9V5T5F%L=64H)'!R968I*3L*("`@
M("`@("`@("`@("`@("1F:65L9"`]("1T:&ES+3YG97138V]P92@D<')E9BD@
M+B`G4')E9G,G.PH@("`@("`@("`@("`@("`@)&YE=U]V86QU97-;)&9I96QD
M75M=(#T@)&5N=')Y.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`O*B!%;G1R:65S(&UU<W0@:&%V92!T:&4@;V)J96-T8VQA<W-E<R`G=&]P
M)R!A;F0@)VAO<F1E<&5R<V]N)PH@("`@("`@("`J('1O('-U8V-E<W-F=6QL
M>2!S=&]R92!,1$%0('!R969S+B!#:&5C:R!F;W(@8F]T:"!O9B!T:&5M+`H@
M("`@("`@("`J(&%N9"!A9&0@=&AE;2!I9B!N96-E<W-A<GDN("HO"B`@("`@
M("`@9F]R96%C:"`H)'1H:7,M/E]P87)A;7-;)W5I9"==(&%S("1U:61?9FEE
M;&0I('L*("`@("`@("`@("`@)'-E87)C:"`](&QD87!?<V5A<F-H*"1T:&ES
M+3Y?8V]N;F5C=&EO;BP@)'1H:7,M/E]P87)A;7-;)V)A<V5D;B==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'5I9%]F:65L9"`N("<]
M)R`N("1T:&ES+3Y?=7-E<BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"=O8FIE8W1C;&%S<R<I*3L*("`@("`@("`@("`@:68@
M*"1S96%R8V@I('L*("`@("`@("`@("`@("`@("1R97-U;'0@/2!L9&%P7V=E
M=%]E;G1R:65S*"1T:&ES+3Y?8V]N;F5C=&EO;BP@)'-E87)C:"D["B`@("`@
M("`@("`@("`@("!I9B`H)')E<W5L="`F)B`D<F5S=6QT6R=C;W5N="==(#X@
M,"D@>PH@("`@("`@("`@("`@("`@("`@("1T;W`@/2!F86QS93L*("`@("`@
M("`@("`@("`@("`@("`D:&]R9&5P97)S;VX@/2!F86QS93L*"B`@("`@("`@
M("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)')E<W5L=%LP75LG;V)J
M96-T8VQA<W,G75LG8V]U;G0G73L@)&DK*RD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H)')E<W5L=%LP75LG;V)J96-T8VQA<W,G75LD:5T@/3T@
M)W1O<"<I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T;W`@/2!T
M<G5E.PH@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)')E<W5L
M=%LP75LG;V)J96-T8VQA<W,G75LD:5T@/3T@)VAO<F1E4&5R<V]N)RD@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&AO<F1E<&5R<V]N(#T@=')U
M93L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("`@("`@("`@+RH@061D(&%N>2!M:7-S:6YG
M(&]B:F5C=&-L87-S97,N("HO"B`@("`@("`@("`@("`@("`@("`@:68@*"$D
M=&]P*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&QD87!?;6]D7V%D9"@D
M=&AI<RT^7V-O;FYE8W1I;VXL("1T:&ES+3Y?9&XL(&%R<F%Y*"=O8FIE8W1C
M;&%S<R<@/3X@)W1O<"<I*3L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`@("`@("`@(&EF("@A)&AO<F1E<&5R<V]N*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@(&QD87!?;6]D7V%D9"@D=&AI<RT^7V-O;FYE8W1I
M;VXL("1T:&ES+3Y?9&XL(&%R<F%Y*"=O8FIE8W1C;&%S<R<@/3X@)VAO<F1E
M4&5R<V]N)RDI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@4V5N9"!T:&4@:&%S:"!T;R!T
M:&4@3$1!4"!S97)V97(N("HO"B`@("`@("`@:68@*&QD87!?;6]D7W)E<&QA
M8V4H)'1H:7,M/E]C;VYN96-T:6]N+"`D=&AI<RT^7V1N+"`D;F5W7W9A;'5E
M<RDI('L*("`@("`@("`@("`@9F]R96%C:"`H)&1I<G1Y7W!R969S(&%S("1P
M<F5F*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1&ER='DH)'!R968L
M(&9A;'-E*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@($AO<F1E.CIL;V=-97-S86=E*`H@("`@("`@("`@("`@("!S<')I
M;G1F*"=5;F%B;&4@=&\@;6]D:69Y('!R969E<F5N8V5S.B!;)61=("5S)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@;&1A<%]E<G)N;R@D=&AI<RT^7V-O
M;FYE8W1I;VXI+`H@("`@("`@("`@("`@("`@("`@("`@("!L9&%P7V5R<F]R
M*"1T:&ES+3Y?8V]N;F5C=&EO;BDI+`H@("`@("`@("`@("`@("`@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@)'5P9&%T960@/2!F86QS93L*
M("`@("`@("!]"@H@("`@("`@("\J($%T=&5M<'0@=&\@8V%C:&4@=&AE('!R
M969E<F5N8V5S(&EN('1H92!S97-S:6]N+B`J+PH@("`@("`@("1T:&ES+3YC
M86-H955P9&%T92@I.PH*("`@("`@("!R971U<FX@)'5P9&%T960["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#;&5A<G,@86QL('!R969E<F5N8V5S(&9R;VT@
M=&AE($Q$05`@8F%C:V5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@8VQE87(H
M*0H@("`@>PH@("`@("`@("\J($UA:V4@<W5R92!W92!A<F4@8V]N;F5C=&5D
M+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("`D871T
M<G,@/2`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^;&ES=$%P<',H87)R87DH)VEN
M86-T:79E)RP@)V%C=&EV92<L("=H:61D96XG+"`G;F]T;V]L8F%R)RP@)V%D
M;6EN)RDI.PH@("`@("`@(&9O<F5A8V@@*"1A='1R<R!A<R`D:V5Y(#T^("1V
M86PI('L*("`@("`@("`@("`@)&%T=')S6R1K97E=(#T@)'9A;"`N("=0<F5F
M<R<["B`@("`@("`@?0H*("`@("`@("`D<V5A<F-H(#T@;&1A<%]R96%D*"1T
M:&ES+3Y?8V]N;F5C=&EO;BP@)'1H:7,M/E]D;BP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=O8FIE8W1#;&%S<SUH;W)D95!E<G-O;B<L("1A='1R
M<RP@,2D["@H@("`@("`@(&EF("@D<V5A<F-H*2!["B`@("`@("`@("`@("1R
M97-U;'0@/2!L9&%P7V=E=%]E;G1R:65S*"1T:&ES+3Y?8V]N;F5C=&EO;BP@
M)'-E87)C:"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@2&]R9&4Z
M.FQO9TUE<W-A9V4H)T9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<')E9F5R
M96YC97,@<V5R=F5R+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@
M?0H*("`@("`@("`D871T<G,@/2!A<G)A>2@I.PH@("`@("`@(&EF("@D<F5S
M=6QT*2!["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1R97-U;'1;
M,%U;)V-O=6YT)UT[("1I*RLI('L*("`@("`@("`@("`@("`@("1A='1R<ULD
M<F5S=6QT6S!=6R1I75T@/2!A<G)A>2@I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&EF("@A;&1A<%]M;V1?9&5L*"1T:&ES+3Y?8V]N;F5C=&EO;BP@
M)'1H:7,M/E]D;BP@)&%T=')S*2D@>PH@("`@("`@("`@("`@("`@2&]R9&4Z
M.FQO9TUE<W-A9V4H"B`@("`@("`@("`@("`@("`@("`@<W!R:6YT9B@G56YA
M8FQE('1O(&-L96%R('!R969E<F5N8V5S.B!;)61=("5S)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&QD87!?97)R;F\H)'1H:7,M/E]C;VYN96-T
M:6]N*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&QD87!?97)R;W(H
M)'1H:7,M/E]C;VYN96-T:6]N*2DL"B`@("`@("`@("`@("`@("`@("`@7U]&
M24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*`H@("`@("`@("`@
M("`@("`@<W!R:6YT9B@G56YA8FQE('1O(&-L96%R('!R969E<F5N8V5S.B!;
M)61=("5S)RP*("`@("`@("`@("`@("`@("`@("`@("`@;&1A<%]E<G)N;R@D
M=&AI<RT^7V-O;FYE8W1I;VXI+`H@("`@("`@("`@("`@("`@("`@("`@("!L
M9&%P7V5R<F]R*"1T:&ES+3Y?8V]N;F5C=&EO;BDI+`H@("`@("`@("`@("`@
M("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("1T
M:&ES+3YC;&5A;G5P*'1R=64I.PH@("`@?0H*("`@("\J*@H@("`@("H@4&5R
M9F]R;2!C;&5A;G5P(&]P97)A=&EO;G,N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)&%L;"`@0VQE86YU<"!A;&P@2&]R9&4@<')E9F5R96YC97,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L96%N=7`H)&%L;"`](&9A;'-E*0H@
M("`@>PH@("`@("`@("\J($-L;W-E('1H92!,1$%0(&-O;FYE8W1I;VXN("HO
M"B`@("`@("`@)'1H:7,M/E]D:7-C;VYN96-T*"D["@H@("`@("`@('!A<F5N
M=#HZ8VQE86YU<"@D86QL*3L*("`@('T*"GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`Q-#`W-"`Q,#4Q-30S,S<S-B`P,C0R,3<`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J($-L87-S(&9O<B!H86YD;&EN9R!A(&QI<W0@;V8@8V%T96=O<FEE
M<R!S=&]R960@:6X@82!U<V5R)W,*("H@<')E9F5R96YC97,N"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP
M:'`L=B`Q+C$Q+C$P+C4@,C`P-B\P,2\P,2`R,3HR.#HS,B!J86X@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H
M=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(
M;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?4')E9G,*("HO"F-L87-S(%!R
M969S7T-A=&5G;W)Y36%N86=E<B!["@H@("`@+RHJ"B`@("`@*B!'970@86QL
M(&-A=&5G;W)I97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E="@I"B`@("![
M"B`@("`@("`@9VQO8F%L("1P<F5F<SL*"B`@("`@("`@)'-T<FEN9R`]("1P
M<F5F<RT^9V5T5F%L=64H)V-A=&5G;W)I97,G*3L*("`@("`@("!I9B`H96UP
M='DH)'-T<FEN9RDI('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@
M("`@("`@?0H*("`@("`@("`D8V%T96=O<FEE<R`](&5X<&QO9&4H)WPG+"`D
M<W1R:6YG*3L*("`@("`@("!A<V]R="@D8V%T96=O<FEE<RD["@H@("`@("`@
M(')E='5R;B`D8V%T96=O<FEE<SL*("`@('T*"B`@("!F=6YC=&EO;B!G9713
M96QE8W0H)&ED+"`D8W5R<F5N="`](&YU;&PI"B`@("!["B`@("`@("`@9VQO
M8F%L("1P<F5F<SL*"B`@("`@("`@)&AT;6P@/2`G/'-E;&5C="!I9#TB)R`N
M(&AT;6QS<&5C:6%L8VAA<G,H)&ED*2`N("<B(&YA;64](B<@+B!H=&UL<W!E
M8VEA;&-H87)S*"1I9"D@+B`G(CXG.PH*("`@("`@("`D8V%T96=O<FEE<R`]
M(%!R969S7T-A=&5G;W)Y36%N86=E<CHZ9V5T*"D["B`@("`@("`@:68@*"%I
M;E]A<G)A>2@D8W5R<F5N="P@)&-A=&5G;W)I97,I("8F("%E;7!T>2@D8W5R
M<F5N="DI('L*("`@("`@("`@("`@)&AT;6P@+CT@)SQO<'1I;VX@=F%L=64]
M(BIN97<J)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&-U<G)E;G0I("X@)R(^)R`N
M('-P<FEN=&8H7R@B57-E($-U<G)E;G0Z("5S(BDL(&AT;6QS<&5C:6%L8VAA
M<G,H)&-U<G)E;G0I*2`N("<\+V]P=&EO;CXG("X*("`@("`@("`@("`@("`@
M("<\;W!T:6]N('9A;'5E/2(B/BTM+2T\+V]P=&EO;CXG.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"$D<')E9G,M/FES3&]C:V5D*"=C871E9V]R:65S)RDI
M('L*("`@("`@("`@("`@)&AT;6P@+CT@)SQO<'1I;VX@=F%L=64](BIN97<J
M(CXG("X@7R@B3F5W($-A=&5G;W)Y(BD@+B`B/"]O<'1I;VX^7&XB("X*("`@
M("`@("`@("`@("`@("<\;W!T:6]N('9A;'5E/2(B/BTM+2T\+V]P=&EO;CXG
M.PH@("`@("`@('T*"B`@("`@("`@+R\@06QW87ES(&%D9"!A;B!5;F9I;&5D
M(&]P=&EO;BX*("`@("`@("`D:'1M;"`N/2`G/&]P=&EO;B!V86QU93TB(B<@
M+@H@("`@("`@("`@("`H96UP='DH)&-U<G)E;G0I(#\@)R!S96QE8W1E9#TB
M<V5L96-T960B/B<@.B`G/B<I("X*("`@("`@("`@("`@:'1M;'-P96-I86QC
M:&%R<RA?*")5;F9I;&5D(BDI("X@)SPO;W!T:6]N/B<["@H@("`@("`@(&9O
M<F5A8V@@*"1C871E9V]R:65S(&%S("1N86UE*2!["B`@("`@("`@("`@("1H
M=&UL("X]("<\;W!T:6]N('9A;'5E/2(G("X@:'1M;'-P96-I86QC:&%R<R@D
M;F%M92D@+B`G(B<@+@H@("`@("`@("`@("`@("`@*"1N86UE(#T]/2`D8W5R
M<F5N="`_("<@<V5L96-T960](G-E;&5C=&5D(CXG(#H@)SXG*2`N"B`@("`@
M("`@("`@("`@("!H=&UL<W!E8VEA;&-H87)S*"1N86UE*2`N("<\+V]P=&EO
M;CXG.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1H=&UL("X@)SPO<V5L
M96-T/B<["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T2F%V85-C<FEP="@D9F]R
M;6YA;64L("1E;&5M96YT;F%M92D*("`@('L*("`@("`@("`D<')O;7!T(#T@
M861D<VQA<VAE<RA?*")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA
M;64Z(BDI.PH@("`@("`@("1E<G)O<B`](&%D9'-L87-H97,H7R@B66]U(&UU
M<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+B(I*3L*"B`@("`@("`@<F5T
M=7)N(#P\/$I!5D%30U))4%0*"CQS8W)I<'0@='EP93TB=&5X="]J879A<V-R
M:7!T(CX*/"$M+0IF=6YC=&EO;B!C:&5C:T-A=&5G;W)Y*"D*>PH@("`@:68@
M*&1O8W5M96YT+B1F;W)M;F%M92XD96QE;65N=&YA;64N=F%L=64@/3T@)RIN
M97<J)RD@>PH@("`@("`@('9A<B!C871E9V]R>2`]('=I;F1O=RYP<F]M<'0H
M)R1P<F]M<'0G+"`G)RD["B`@("`@("`@:68@*&-A=&5G;W)Y("$](&YU;&P@
M)B8@8V%T96=O<GD@(3T@)R<I('L*("`@("`@("`@("`@9&]C=6UE;G0N)&9O
M<FUN86UE+FYE=U]C871E9V]R>2YV86QU92`](&-A=&5G;W)Y.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@('=I;F1O=RYA;&5R="@G)&5R<F]R)RD[
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!](&5L
M<V4@:68@*&1O8W5M96YT+B1F;W)M;F%M92XD96QE;65N=&YA;64N=F%L=64N
M:6YD97A/9B@G*FYE=RHG*2`A/2`M,2D@>PH@("`@("`@(&1O8W5M96YT+B1F
M;W)M;F%M92YN97=?8V%T96=O<GDN=F%L=64@/2!D;V-U;65N="XD9F]R;6YA
M;64N)&5L96UE;G1N86UE+G9A;'5E+G-U8G-T<B@U+"!D;V-U;65N="XD9F]R
M;6YA;64N)&5L96UE;G1N86UE+G9A;'5E+FQE;F=T:"D["B`@("!]"@H@("`@
M<F5T=7)N('1R=64["GT*+R\M+3X*/"]S8W)I<'0^"DI!5D%30U))4%0["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@82!N97<@8V%T96=O<GDN"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V%T96=O<GD@(%1H92!N86UE(&]F
M('1H92!C871E9V]R>2!T;R!A9&0N"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@1F%L<V4@;VX@9F%I;'5R92P@;W(@=&AE(&YE=R!C871E9V]R>2=S
M(&YA;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9"@D8V%T96=O<GDI"B`@
M("!["B`@("`@("`@9VQO8F%L("1P<F5F<SL*"B`@("`@("`@:68@*"1P<F5F
M<RT^:7-,;V-K960H)V-A=&5G;W)I97,G*2!\?"!E;7!T>2@D8V%T96=O<GDI
M*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@
M("`@("1C871E9V]R:65S(#T@4')E9G-?0V%T96=O<GE-86YA9V5R.CIG970H
M*3L*("`@("`@("!I9B`H:6Y?87)R87DH)&-A=&5G;W)Y+"`D8V%T96=O<FEE
M<RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@)&-A=&5G;W)I97-;72`]("1C871E9V]R>3L*("`@("`@("`D<')E
M9G,M/G-E=%9A;'5E*"=C871E9V]R:65S)RP@:6UP;&]D92@G?"<L("1C871E
M9V]R:65S*2D["@H@("`@("`@(')E='5R;B`D8V%T96=O<GD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!$96QE=&4@82!C871E9V]R>2X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1C871E9V]R>2`@5&AE(&-A=&5G;W)Y('1O(')E
M;6]V92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@
M<W5C8V5S<RP@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F5M;W9E*"1C871E9V]R>2D*("`@('L*("`@("`@("!G;&]B86P@)'!R
M969S.PH*("`@("`@("!I9B`H)'!R969S+3YI<TQO8VME9"@G8V%T96=O<FEE
M<R<I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@
M("`@("`@("1C871E9V]R:65S(#T@4')E9G-?0V%T96=O<GE-86YA9V5R.CIG
M970H*3L*"B`@("`@("`@)&ME>2`](&%R<F%Y7W-E87)C:"@D8V%T96=O<GDL
M("1C871E9V]R:65S*3L*("`@("`@("!I9B`H)&ME>2`]/3T@9F%L<V4I('L*
M("`@("`@("`@("`@<F5T=7)N("1K97D["B`@("`@("`@?0H*("`@("`@("!U
M;G-E="@D8V%T96=O<FEE<ULD:V5Y72D["B`@("`@("`@)'!R969S+3YS9716
M86QU92@G8V%T96=O<FEE<R<L(&EM<&QO9&4H)WPG+"`D8V%T96=O<FEE<RDI
M.PH*("`@("`@("`O+R!296UO=F4@86YY(&-O;&]R('-E='1I;F=S(&9O<B`D
M8V%T96=O<GDN"B`@("`@("`@)&-O;&]R<R`](%!R969S7T-A=&5G;W)Y36%N
M86=E<CHZ8V]L;W)S*"D["B`@("`@("`@=6YS970H)&-O;&]R<ULD8V%T96=O
M<GE=*3L*("`@("`@("!0<F5F<U]#871E9V]R>4UA;F%G97(Z.G-E=$-O;&]R
M<R@D8V]L;W)S*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('1H92!C;VQO<B!F;W(@96%C:"!O9B!T:&4@
M=7-E<B=S(&-A=&5G;W)I97,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A
M>2`@02!L:7-T(&]F(&-O;&]R<RP@:V5Y(&ES('1H92!C871E9V]R>2!N86UE
M+"!V86QU92!I<R!T:&4*("`@("`J("`@("`@("`@("`@("`@($A434P@8V]L
M;W(@8V]D92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]L;W)S*"D*("`@('L*
M("`@("`@("!G;&]B86P@)'!R969S.PH*("`@("`@("`O*B!$969A=6QT('9A
M;'5E<R!T:&%T(&-A;B!B92!O=F5R<FED9&5N(&)U="!M=7-T(&%L=V%Y<R!B
M90H@("`@("`@("`J('!R97-E;G0N("HO"B`@("`@("`@)&-O;&]R<ULG7V1E
M9F%U;'1?)UT@/2`G(T9&1D9&1B<["B`@("`@("`@)&-O;&]R<ULG7W5N9FEL
M961?)UT@/2`G(T1$1$1$1"<["@H@("`@("`@("1P86ER<R`](&5X<&QO9&4H
M)WPG+"`D<')E9G,M/F=E=%9A;'5E*"=C871E9V]R>5]C;VQO<G,G*2D["B`@
M("`@("`@9F]R96%C:"`H)'!A:7)S(&%S("1P86ER*2!["B`@("`@("`@("`@
M(&EF("@A96UP='DH)'!A:7(I*2!["B`@("`@("`@("`@("`@("!L:7-T*"1C
M871E9V]R>2P@)&-O;&]R*2`](&5X<&QO9&4H)SHG+"`D<&%I<BD["B`@("`@
M("`@("`@("`@("`D8V]L;W)S6R1C871E9V]R>5T@/2`D8V]L;W(["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1C;VQO<G-;)R==(#T@)&-O
M;&]R<ULG7W5N9FEL961?)UT["@H@("`@("`@(')E='5R;B`D8V]L;W)S.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@9F]R96=R;W5N9"!C
M;VQO<B!F;W(@96%C:"!O9B!T:&4@=7-E<B=S(&-A=&5G;W)I97,N"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!L:7-T(&]F(&-O;&]R<RP@:V5Y
M(&ES('1H92!C871E9V]R>2!N86UE+"!V86QU92!I<R!T:&4*("`@("`J("`@
M("`@("`@("`@("`@($A434P@8V]L;W(@8V]D92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9F=#;VQO<G,H*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G
M2&]R9&4O26UA9V4N<&AP)SL*"B`@("`@("`@)&-O;&]R<R`](%!R969S7T-A
M=&5G;W)Y36%N86=E<CHZ8V]L;W)S*"D["B`@("`@("`@)&9G8V]L;W)S(#T@
M87)R87DH*3L*("`@("`@("!F;W)E86-H("@D8V]L;W)S(&%S("1N86UE(#T^
M("1C;VQO<BD@>PH@("`@("`@("`@("`D9F=C;VQO<G-;)&YA;65=(#T@2&]R
M9&5?26UA9V4Z.F)R:6=H=&YE<W,H)&-O;&]R*2`\(#$R."`_("<C9C9F-F8V
M)R`Z("<C,#`P)SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D9F=C;VQO
M<G,["B`@("!]"@H@("`@9G5N8W1I;VX@<V5T0V]L;W(H)&-A=&5G;W)Y+"`D
M8V]L;W(I"B`@("!["B`@("`@("`@)&-O;&]R<R`](%!R969S7T-A=&5G;W)Y
M36%N86=E<CHZ8V]L;W)S*"D["B`@("`@("`@)&-O;&]R<ULD8V%T96=O<GE=
M(#T@)&-O;&]R.PH@("`@("`@(%!R969S7T-A=&5G;W)Y36%N86=E<CHZ<V5T
M0V]L;W)S*"1C;VQO<G,I.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=$-O;&]R
M<R@D8V]L;W)S*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<')E9G,["@H@("`@
M("`@("1P86ER<R`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)&-O;&]R
M<R!A<R`D8V%T96=O<GD@/3X@)&-O;&]R*2!["B`@("`@("`@("`@(&EF("@A
M96UP='DH)&-A=&5G;W)Y*2D@>PH@("`@("`@("`@("`@("`@)'!A:7)S6UT@
M/2`B)&-A=&5G;W)Y.B1C;VQO<B(["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("1P<F5F<RT^<V5T5F%L=64H)V-A=&5G;W)Y7V-O;&]R<R<L
M(&EM<&QO9&4H)WPG+"`D<&%I<G,I*3L*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4')E9G,O<V5S<VEO;BYP:'``````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#<Q,3<@,3`U,34T,S,W
M,S8@,#(R-C,R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!0<F5F97)E;F-E<R!S=&]R86=E(&EM<&QE
M;65N=&%T:6]N(&9O<B!02%`G<R!S97-S:6]N(&EM<&QE;65N=&%T:6]N+@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S97-S:6]N+G!H
M<"QV(#$N,S(N,3(N-R`R,#`V+S`U+S$Q(#$W.C$S.C(S(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D
M92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*;VX@4&%R:7-E
M(#QJ;VY`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,N-`H@*B!`
M<&%C:V%G92!(;W)D95]0<F5F<PH@*B\*8VQA<W,@4')E9G-?<V5S<VEO;B!E
M>'1E;F1S(%!R969S('L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!N
M97<@<V5S<VEO;B!P<F5F97)E;F-E<R!O8FIE8W0N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=7-E<B`@("`@(%1H92!U<V5R('=H;R!O=VYS('1H
M97-E('!R969E<F5N8V5S+B`H56YU<V5D*0H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<&%S<W=O<F0@(%1H92!P87-S=V]R9"!A<W-O8VEA=&5D('=I=&@@)'5S
M97(N("A5;G5S960I"B`@("`@*B!`<&%R86T@<W1R:6YG("1S8V]P92`@("`@
M5&AE(&-U<G)E;G0@<')E9F5R96YC97,@<V-O<&4N"B`@("`@*B!`<&%R86T@
M87)R87D@)'!A<F%M<R`@("`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO
M;B!P87)A;65T97)S+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`H56YU<V5D*0H@("`@("H@0'!A<F%M(&)O;VQE86X@)&-A8VAI;F<@(%-H
M;W5L9"!C86-H:6YG(&)E('5S960_("A5;G5S960I"B`@("`@*@H@("`@("HO
M"B`@("!F=6YC=&EO;B!0<F5F<U]S97-S:6]N*"1U<V5R+"`D<&%S<W=O<F0@
M/2`G)RP@)'-C;W!E(#T@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1P87)A;7,@/2!N=6QL+"`D8V%C:&EN9R`]('1R=64I"B`@("!["B`@("`@
M("`@:68@*"%5=&EL.CIE>'1E;G-I;VY%>&ES=',H)W-E<W-I;VXG*2D@>PH@
M("`@("`@("`@("!(;W)D93HZ9F%T86PH4$5!4CHZ<F%I<V5%<G)O<BA?*")0
M<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(BDL(%]?1DE,15]?+"!?7TQ)3D5?7RDI.PH@("`@("`@('T*"B`@
M("`@("`@)'1H:7,M/E]S8V]P92`]("1S8V]P93L*"B`@("`@("`@<&%R96YT
M.CI0<F5F<R@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S('1H
M92!R97%U97-T960@<V5T(&]F('!R969E<F5N8V5S(&9R;VT@=&AE(&-U<G)E
M;G0@<V5S<VEO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E
M(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!R971R:65V92@I"B`@("!["B`@("`@
M("`@+RH@3&]A9"!D969A=6QT<R!T;R!M86ME('-U<F4@=V4@:&%V92!A;&P@
M<')E9F5R96YC97,N("HO"B`@("`@("`@<&%R96YT.CIR971R:65V92@I.PH*
M("`@("`@("`D9VQO8F%L7W!R969S(#T@87)R87DH*3L*("`@("`@("`D;&]C
M86Q?<')E9G,@/2!A<G)A>2@I.PH*("`@("`@("`O*B!2971R:65V92!G;&]B
M86P@86YD(&QO8V%L('!R969E<F5N8V5S(&9R;VT@=&AE('-E<W-I;VX@=F%R
M:6%B;&4N("HO"B`@("`@("`@:68@*&ES<V5T*"1?4T534TE/3ELG:&]R9&5?
M<')E9G,G75LG:&]R9&4G72DI('L*("`@("`@("`@("`@)&=L;V)A;%]P<F5F
M<R`]("1?4T534TE/3ELG:&]R9&5?<')E9G,G75LG:&]R9&4G73L*("`@("`@
M("!]"B`@("`@("`@:68@*&ES<V5T*"1?4T534TE/3ELG:&]R9&5?<')E9G,G
M75LD=&AI<RT^7W-C;W!E72DI('L*("`@("`@("`@("`@)&QO8V%L7W!R969S
M(#T@)%]315-324].6R=H;W)D95]P<F5F<R==6R1T:&ES+3Y?<V-O<&5=.PH@
M("`@("`@('T*"B`@("`@("`@+RH@4F5T<FEE=F4@86YD('-T;W)E('1H92!L
M;V-A;"!A;F0@9VQO8F%L('!R969E<F5N8V5S+B`J+PH@("`@("`@("1T:&ES
M+3Y?<')E9G,@/2!A<G)A>5]M97)G92@D=&AI<RT^7W!R969S+"`D9VQO8F%L
M7W!R969S+"`D;&]C86Q?<')E9G,I.PH*("`@("`@("`O*B!#86QL(&AO;VMS
M+B`J+PH@("`@("`@(&EF("@A:7-S970H)%]315-324].6R=H;W)D95]P<F5F
M<R==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V-A;&Q(;V]K<R@I.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3=&]R97,@<')E9F5R96YC97,@:6X@=&AE(&-U<G)E;G0@<V5S<VEO
M;BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!R969S("!!;B!A<G)A
M>2!L:7-T:6YG('1H92!P<F5F97)E;F-E<R!T;R!B92!S=&]R960N($EF"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("!N;W0@<W!E8VEF:65D+"!S=&]R
M92!A;&P@=&AE('!R969E<F5N8V5S(&QI<W1E9"!I;@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@=&AE("1P<F5F<R!H87-H+@H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R
M;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-T
M;W)E*"1P<F5F<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@+RH@0W)E871E
M(&%N9"!R96=I<W1E<B!T:&4@<')E9F5R96YC97,@87)R87DL(&EF(&YE8V5S
M<V%R>2X@*B\*("`@("`@("!I9B`H(6ES<V5T*"1?4T534TE/3ELG:&]R9&5?
M<')E9G,G72DI('L*("`@("`@("`@("`@)%]315-324].6R=H;W)D95]P<F5F
M<R==(#T@87)R87DH*3L*("`@("`@("!]"@H@("`@("`@("\J($-O<'D@=&AE
M(&-U<G)E;G0@<')E9F5R96YC97,@:6YT;R!T:&4@<V5S<VEO;B!V87)I86)L
M92X@*B\*("`@("`@("!F;W)E86-H("@D=&AI<RT^7W!R969S(&%S("1N86UE
M(#T^("1P<F5F*2!["B`@("`@("`@("`@("1S8V]P92`]("1T:&ES+3YG9713
M8V]P92@D;F%M92D["B`@("`@("`@("`@("1?4T534TE/3ELG:&]R9&5?<')E
M9G,G75LD<V-O<&5=6R1N86UE72`]("1P<F5F.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!097)F;W)M
M(&-L96%N=7`@;W!E<F%T:6]N<RX*("`@("`J"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D86QL("!#;&5A;G5P(&%L;"!(;W)D92!P<F5F97)E;F-E<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@8VQE86YU<"@D86QL(#T@9F%L<V4I"B`@("![
M"B`@("`@("`@+RH@4&5R9F]R;2!A($AO<F1E+7=I9&4@8VQE86YU<#\@*B\*
M("`@("`@("!I9B`H)&%L;"D@>PH@("`@("`@("`@("!U;G-E="@D7U-%4U-)
M3TY;)VAO<F1E7W!R969S)UTI.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@('5N<V5T*"1?4T534TE/3ELG:&]R9&5?<')E9G,G75LD=&AI<RT^7W-C
M;W!E72D["B`@("`@("`@("`@("1?4T534TE/3ELG:&]R9&5?<')E9G,G75LG
M7V9I;&QE9"==(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!P87)E;G0Z
M.F-L96%N=7`H)&%L;"D["B`@("!]"@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4')E
M9G,O:6US<"YP:'``````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,3`W-S`@,3`U,34T,S,W,S8@,#(R,3$V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!0<F5F97)E
M;F-E('-T;W)A9V4@:6UP;&5M96YT871I;VX@9F]R(&%N($E-4U`@<V5R=F5R
M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]I;7-P+G!H
M<"QV(#$N,2XQ,"XQ,2`R,#`V+S`R+S(X(#`U.C4Y.C$Y('-L=7-A<GH@17AP
M("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!-:6-H865L(%)U8FEN<VMY
M(#QM<G5B:6YS:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!-:6-H865L(%)U8FEN<VMY(#QM<G5B:6YS:T!H;W)D92YO<F<^"B`J
M($!P86-K86=E($AO<F1E7U!R969S"B`J+PIC;&%S<R!0<F5F<U]I;7-P(&5X
M=&5N9',@4')E9G,@>PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(@9G5N
M8W1I;VXN"B`@("`@*B`D<&%R86US(&UU<W0@8V]N=&%I;CH*("`@("`J("=A
M=71H7VUE=&AO9"<L("=S97)V97(G+"`G<&]R="<*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`D=7-E<B`@("`@57-E<FYA;64@;V8@8W5R<F5N="!U
M<V5R+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'!A<W-W;W)D(%!A<W-W;W)D
M(&9O<B!C=7)R96YT('5S97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<V-O
M<&4@("`@5&AE('-C;W!E(&9O<B!T:&5S92!P<F5F97)E;F-E<RX*("`@("`J
M($!P87)A;2!A<G)A>2`@("1P87)A;7,@("!4:&4@<&%R86UE=&5R<R!N965D
M960@9F]R('1H:7,@;V)J96-T+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&-A
M8VAI;F<@($%R92!W92!U<VEN9R!S97-S:6]N(&-A8VAE/PH@("`@("HO"B`@
M("!F=6YC=&EO;B!0<F5F<U]I;7-P*"1U<V5R+"`D<&%S<W=O<F0@/2`G)RP@
M)'-C;W!E(#T@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("1P87)A;7,@
M/2!N=6QL+"`D8V%C:&EN9R`]('1R=64I"B`@("!["B`@("`@("`@9VQO8F%L
M("1C;VYF.PH*("`@("`@("!P87)E;G0Z.E!R969S*"D["B`@("`@("`@<F5Q
M=6ER95]O;F-E("=.970O24U34"YP:'`G.PH*("`@("`@("`D=&AI<RT^7W-C
M;W!E(#T@)'-C;W!E.PH@("`@("`@("1T:&ES+3Y?8V%C:&EN9R`]("1C86-H
M:6YG.PH@("`@("`@("1T:&ES+3Y?=7-E<B`]("1U<V5R.PH@("`@("`@("1T
M:&ES+3YP87)A;7,@/2`D<&%R86US.PH*("`@("`@("!I9B`H<')E9U]M871C
M:"@G+RA>+BHI0"\G+"`D=7-E<BP@)&UA=&-H97,I*2!["B`@("`@("`@("`@
M("1T:&ES+3YP87)A;7-;)W5S97)N86UE)UT@/2`D;6%T8VAE<ULQ73L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^<&%R86US6R=U<V5R
M;F%M92==(#T@)'5S97(["B`@("`@("`@?0H@("`@("`@("1T:&ES+3YP87)A
M;7-;)W!A<W-W;W)D)UT@/2`D<&%S<W=O<F0["B`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3YP87)A;7-;)W-O8VME="==*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^<&%R86US6R=S;V-K970G72`]("1P87)A;7-;)W-O8VME="==("X@)VEM
M<W!?)R`N("1T:&ES+3YP87)A;7-;)W5S97)N86UE)UT@+B`G+G-C:R<["B`@
M("`@("`@?0H@("`@("`@("1T:&ES+3Y?:6US<"`]("9.971?24U34#HZ<VEN
M9VQE=&]N*"=/<'1I;VYS)RP@)'1H:7,M/G!A<F%M<RD["B`@("`@("`@)')E
M<W5L="`]("1T:&ES+3Y?:6US<"T^:6YI="@I.PH@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z
M.F9A=&%L*"1R97-U;'0L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@
M?0H@("`@("`@("1T:&ES+3Y?:6US<"T^<V5T3&]G9V5R*"1C;VYF6R=L;V<G
M72D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V97,@=&AE(')E<75E
M<W1E9"!S970@;V8@<')E9F5R96YC97,@9G)O;2!T:&4@24U34"!S97)V97(N
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S
M(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<F5T<FEE=F4H*0H@("`@>PH@("`@("`@("\J($=E="!T
M:&4@9&5F875L=',N("HO"B`@("`@("`@<&%R96YT.CIR971R:65V92@I.PH*
M("`@("`@("`O*B!'970@=&AE('-H87)E9"!P<F5F<R!A;F0@<F5M;W9E('1H
M92!S8V]P92!V86QU92!F<F]M('1H90H@("`@("`@("`J('-T<FEN9RX@*B\*
M("`@("`@("`D9VQO8F%L7W!R969S(#T@)'1H:7,M/E]I;7-P+3YG970H)VAO
M<F1E+BHG*3L*("`@("`@("!I9B`H:7-?82@D9VQO8F%L7W!R969S+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D9VQO8F%L7W!R969S
M.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)&=L;V)A;%]P<F5F<R!A
M<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@)&YE=TME>2`]('-T<E]R
M97!L86-E*"=H;W)D92XG+"`G)RP@)&ME>2D["B`@("`@("`@("`@(&EF("@D
M=F%L(#T]("<M)RD@>PH@("`@("`@("`@("`@("`@)'9A;"`]("1T:&ES+3YG
M971$969A=6QT*"1N97=+97DI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]P<F5F<ULD;F5W2V5Y72DI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3YS971686QU92@D;F5W2V5Y+"`D=F%L*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3YA9&0H
M)&YE=TME>2P@)'9A;"P@7U!2149?4TA!4D5$*3L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@+RH@1&]N)W0@9F]R9V5T('1O(&-L96%N(&ET+B`J+PH@
M("`@("`@("`@("`D=&AI<RT^<V5T1&ER='DH)&YE=TME>2P@9F%L<V4I.PH@
M("`@("`@('T*"B`@("`@("`@+RH@3F]W('1H92!A<'`@<W!E8VEF:6,@<')E
M9G,N("HO"B`@("`@("`@)&QO8V%L7W!R969S(#T@)'1H:7,M/E]I;7-P+3YG
M970H)'1H:7,M/E]S8V]P92`N("<N*B<I.PH@("`@("`@(&EF("AI<U]A*"1L
M;V-A;%]P<F5F<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)&QO8V%L7W!R969S.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H
M)&QO8V%L7W!R969S(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`D
M;F5W2V5Y(#T@<W1R7W)E<&QA8V4H)'1H:7,M/E]S8V]P92`N("<N)RP@)R<L
M("1K97DI.PH@("`@("`@("`@("!I9B`H)'9A;"`]/2`G+2<I('L*("`@("`@
M("`@("`@("`@("1V86P@/2`D=&AI<RT^9V5T1&5F875L="@D;F5W2V5Y*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P
M<F5F<ULD;F5W2V5Y72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3YS9716
M86QU92@D;F5W2V5Y+"`D=F%L*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1T:&ES+3YA9&0H)&YE=TME>2P@)'9A;"P@,"D["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("\J($-L96%N('1H92!P<F5F+B`J
M+PH@("`@("`@("`@("`D=&AI<RT^<V5T1&ER='DH)&YE=TME>2P@9F%L<V4I
M.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]C86QL2&]O:W,H*3L*("`@
M("`@("`D=&AI<RT^8V%C:&55<&1A=&4H*3L*("`@("`@("!R971U<FX@=')U
M93L*("`@('T*"B`@("`O*BH*("`@("`J(%-T;W)E<R!A;&P@9&ER='D@<')E
M9G,@=&\@24U34"!S97)V97(N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<W1O<F4H*0H@("`@>PH@
M("`@("`@("1D:7)T>5]P<F5F<R`]("1T:&ES+3Y?9&ER='E0<F5F<R@I.PH@
M("`@("`@(&EF("@A8V]U;G0H)&1I<G1Y7W!R969S*2D@>PH@("`@("`@("`@
M("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1D
M:7)T>5]P<F5F<R!A<R`D;F%M92D@>PH@("`@("`@("`@("`D<V-O<&4@/2`D
M=&AI<RT^9V5T4V-O<&4H)&YA;64I.PH@("`@("`@("`@("`D=F%L=64@/2`D
M=&AI<RT^9V5T5F%L=64H)&YA;64I.PH@("`@("`@("`@("!I9B`H96UP='DH
M)'9A;'5E*2D@>PH@("`@("`@("`@("`@("`@)'9A;'5E(#T@)RTG.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P
M+3YS970H)'-C;W!E("X@)RXG("X@)&YA;64L("1V86QU92D["B`@("`@("`@
M("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@("1'3$]"04Q36R=N;W1I9FEC871I;VXG72T^<'5S:"@B5&AE
M<F4@=V%S(&$@<')O8FQE;2!S879I;F<@=&AE('!R969R96YC97,B*3L*("`@
M("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`O*B!#;&5A;B!T:&4@<')E9B!S:6YC92!I="!W87,@:G5S
M="!S879E9"X@*B\*("`@("`@("`@("`@)'1H:7,M/G-E=$1I<G1Y*"1N86UE
M+"!F86QS92D["B`@("`@("`@?0H@("`@("`@("1T:&ES+3YC86-H955P9&%T
M92@I.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*?0H``````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]&;W)M````````````
M````````````````````````````````````````````````````````````
M```````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q
M,#4Q-30S,S<S-B`P,C`Q-S4`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+T9O<FTO5'EP90``````````````````````````````````````````
M`````````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S,V(#`R,3$Q-@`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O1F]R;2]4>7!E+W1A8FQE<V5T+G!H<```
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(V,S(@,3`U,34T,S,W,S8@
M,#(S-3$T`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+T9O<FTN<&AP)SL*"B\J
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E
M="YP:'`L=B`Q+C,N,BXQ(#(P,#4O,3`O,3@@,3$Z,#$Z,#@@:F%N($5X<"`D
M"B`J"B`J($!P86-K86=E($AO<F1E7T9O<FT*("H@0'-I;F-E("`@2&]R9&4@
M,RXQ"B`J+PIC;&%S<R!(;W)D95]&;W)M7U1Y<&5?=&%B;&5S970@97AT96YD
M<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@('9A<B`D7W9A;'5E<SL*("`@('9A
M<B`D7VAE861E<CL*"B`@("!F=6YC=&EO;B!I;FET*"1V86QU97,L("1H96%D
M97(I"B`@("!["B`@("`@("`@)'1H:7,M/E]V86QU97,@/2`D=F%L=65S.PH@
M("`@("`@("1T:&ES+3Y?:&5A9&5R(#T@)&AE861E<CL*("`@('T*"B`@("!F
M=6YC=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S
M86=E*0H@("`@>PH@("`@("`@(&EF("AC;W5N="@D=&AI<RT^7W9A;'5E<RD@
M/3T@,"!\?"!C;W5N="@D=F%L=64I(#T](#`I('L*("`@("`@("`@("`@<F5T
M=7)N('1R=64["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1V86QU92!A
M<R`D:71E;2D@>PH@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?=F%L
M=65S6R1I=&5M72DI('L*("`@("`@("`@("`@("`@("1E<G)O<B`]('1R=64[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("!I9B`H(6ES<V5T*"1E<G)O<BDI('L*("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`D;65S<V%G92`](%\H
M(DEN=F%L:60@9&%T82!S=6)M:71T960N(BD["B`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$AE861E<B@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?:&5A9&5R.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&=E=%9A;'5E<R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M=F%L=65S.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&EN9F\@86)O
M=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@86)O=70H*0H@
M("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@*("`@("`@("`@("`@)VYA;64G
M(#T^(%\H(E1A8FQE(%-E="(I+`H@("`@("`@("`@("`G<&%R86US)R`]/B!A
M<G)A>2@*("`@("`@("`@("`@("`@("=V86QU97,G(#T^(&%R<F%Y*"=L86)E
M;"<@/3X@7R@B5F%L=65S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G='EP92<@(#T^("=S=')I;F=L:7-T)RDL"B`@("`@("`@("`@
M("`@("`G:&5A9&5R)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(DAE861E<G,B
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@
M/3X@)W-T<FEN9VQI<W0G*2DL"B`@("`@("`@("`@("D["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]&
M;W)M+T%C=&EO;@``````````````````````````````````````````````
M```````````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#`P,"`Q,#4Q-30S,S<S-B`P,C$T,3(`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+T9O<FTO06-T:6]N+V-O;F1I=&EO;F%L7V5N86)L
M92YP:'```````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S-#$U(#$P-3$U-#,S-S,V(#`R-C`Q
M-@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@2&]R9&5?1F]R;5]!8W1I;VY?8V]N9&ET:6]N86Q?96YA
M8FQE(&ES(&$@2&]R9&5?1F]R;5]!8W1I;VX@=&AA=`H@*B!E;F%B;&5S(&]R
M(&1I<V%B;&5S(&%N(&5L96UE;G0@8F%S960@;VX@=&AE('9A;'5E(&]F(&%N
M;W1H97(@96QE;65N=`H@*@H@*B!&;W)M870@;V8@=&AE("1P87)A;7,@<&%S
M<V5D('1O('1H92!C;VYS=')U8W1O<CH*("H@/'!R93X*("H@("1P87)A;7,@
M/2!A<G)A>2@*("H@("`@("`G=&%R9V5T)R`@/3X@)UMN86UE(&]F(&5L96UE
M;G0@=&AI<R!I<R!C;VYD:71I;VYA;"!O;ETG+`H@*B`@("`@("=E;F%B;&5D
M)R`]/B`G=')U92<@?"`G9F%L<V4G+`H@*B`@("`@("=V86QU97,G("`]/B!A
M<G)A>2A;=&%R9V5T('9A;'5E<R!T;R!C:&5C:UTI"B`J("`I.PH@*B`\+W!R
M93X*("H*("H@4V\@)'!A<F%M<R`](&%R<F%Y*"=F;V\G+"`G=')U92<L(&%R
M<F%Y*#$L(#(I*2!W:6QL(&5N86)L92!T:&4@9FEE;&0@=&AI<PH@*B!A8W1I
M;VX@:7,@871T86-H960@=&\@:68@=&AE('9A;'5E(&]F("=F;V\G(&ES(#$@
M;W(@,BP@86YD(&1I<V%B;&4@:70*("H@;W1H97)W:7-E+@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]&;W)M+T9O<FTO06-T:6]N+V-O;F1I=&EO;F%L7V5N
M86)L92YP:'`L=B`Q+C0N,3`N,R`R,#`V+S`Q+S`Q(#(Q.C(X.C$W(&IA;B!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UA='0@2WEN87-T;VX@
M/&UA='1`:WEN>"YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-
M871T($MY;F%S=&]N(#QM871T0&MY;G@N;W)G/@H@*B!`<&%C:V%G92!(;W)D
M95]&;W)M"B`J+PIC;&%S<R!(;W)D95]&;W)M7T%C=&EO;E]C;VYD:71I;VYA
M;%]E;F%B;&4@97AT96YD<R!(;W)D95]&;W)M7T%C=&EO;B!["@H@("`@=F%R
M("1?=')I9V=E<B`](&%R<F%Y*"=O;FQO860G*3L*"B`@("!F=6YC=&EO;B!G
M971!8W1I;VY38W)I<'0H)B1F;W)M+"`D<F5N9&5R97(L("1V87)N86UE*0H@
M("`@>PH@("`@("`@($AO<F1E.CIA9&138W)I<'1&:6QE*"=F;W)M7VAE;'!E
M<G,N:G,G+"`G:&]R9&4G+"!T<G5E*3L*"B`@("`@("`@)&9O<FU?;F%M92`]
M("1F;W)M+3YG971.86UE*"D["B`@("`@("`@)'1A<F=E="`]("1T:&ES+3Y?
M<&%R86US6R=T87)G970G73L*("`@("`@("`D96YA8FQE9"`]("1T:&ES+3Y?
M<&%R86US6R=E;F%B;&5D)UT["B`@("`@("`@:68@*"%I<U]S=')I;F<H)&5N
M86)L960I*2!["B`@("`@("`@("`@("1E;F%B;&5D(#T@*"1E;F%B;&5D*2`_
M("=T<G5E)R`Z("=F86QS92<["B`@("`@("`@?0H@("`@("`@("1V86QS(#T@
M)'1H:7,M/E]P87)A;7-;)W9A;'5E<R==.PH@("`@("`@("1V86QS(#T@*&ES
M7V%R<F%Y*"1V86QS*2D@/R`D=F%L<R`Z(&%R<F%Y*"1V86QS*3L*("`@("`@
M("`D87)G<R`]("(G)'9A<FYA;64G+"`D96YA8FQE9"P@)R(@+B!I;7!L;V1E
M*"(G+"<B+"`D=F%L<RD@+B`B)R(["@H@("`@("`@(')E='5R;B`B:68@*&%D
M9$5V96YT*&1O8W5M96YT+B1F;W)M7VYA;64N)'1A<F=E="P@)V]N8VAA;F=E
M)RP@7")C:&5C:T5N86)L960H=&AI<RP@)&%R9W,I.UPB*2D@>R`B"B`@("`@
M("`@("`@("X@(B`@8VAE8VM%;F%B;&5D*&1O8W5M96YT+B1F;W)M7VYA;64N
M)'9A<FYA;64L("1A<F=S*3L@(@H@("`@("`@("`@("`N("=].R<["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92]&;W)M+T%C=&EO;B]R96QO860N<&AP````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,34W,R`Q,#4Q-30S,S<S-B`P,C,T-38`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J($AO<F1E7T9O<FU?06-T:6]N7W)E;&]A9"!I<R!A($AO<F1E7T9O
M<FT@06-T:6]N('1H870@<F5L;V%D<R!T:&4*("H@9F]R;2!W:71H('1H92!C
M=7)R96YT("AN;W0@=&AE(&]R:6=I;F%L*2!V86QU92!A9G1E<B!T:&4@9F]R
M;2!E;&5M96YT"B`J('1H870@=&AE(&%C=&EO;B!I<R!A='1A8VAE9"!T;R!I
M<R!M;V1I9FEE9"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+T%C=&EO;B]R96QO860N<&AP+'8@,2XW+C$P+C0@,C`P-B\P,2\P,2`R,3HR
M.#HQ-R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!*86X@
M4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@
M0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'!A
M8VMA9V4@2&]R9&5?1F]R;0H@*B\*8VQA<W,@2&]R9&5?1F]R;5]!8W1I;VY?
M<F5L;V%D(&5X=&5N9',@2&]R9&5?1F]R;5]!8W1I;VX@>PH*("`@('9A<B`D
M7W1R:6=G97(@/2!A<G)A>2@G;VYC:&%N9V4G*3L*"B`@("!F=6YC=&EO;B!G
M971!8W1I;VY38W)I<'0H)&9O<FTL("1R96YD97)E<BP@)'9A<FYA;64I"B`@
M("!["B`@("`@("`@<F5T=7)N("=I9B`H=&AI<RYV86QU92D@>R!D;V-U;65N
M="XG("X@)&9O<FTM/F=E=$YA;64H*2`N("<N9F]R;6YA;64N=F%L=64]7"=<
M)SLG("X*("`@("`@("`@("`@)V1O8W5M96YT+B<@+B`D9F]R;2T^9V5T3F%M
M92@I("X@)RYS=6)M:70H*2!])SL*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B](;W)D92]&;W)M+T%C=&EO;B]C;VYD:71I;VYA;%]S971V
M86QU92YP:'`````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-3`Q,"`Q,#4Q-30S,S<S-B`P,C8T
M,3$`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J($AO<F1E7T9O<FU?06-T:6]N7V-O;F1I=&EO;F%L7W-E
M='9A;'5E(&ES(&$@2&]R9&5?1F]R;5]!8W1I;VX@=&AA=`H@*B!S971S('1H
M92!V86QU92!O9B!O;F4@2&]R9&5?1F]R;2!V87)I86)L92!B87-E9"!O;B!T
M:&4@=F%L=64@;V8@=&AE"B`J('9A<FEA8FQE('1H92!A8W1I;VX@:7,@871T
M86-H960@=&\N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T9O<FTO1F]R;2]!
M8W1I;VXO8V]N9&ET:6]N86Q?<V5T=F%L=64N<&AP+'8@,2XQ.2XQ,"XU(#(P
M,#8O,#$O,#$@,C$Z,C@Z,3<@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H@0'!A8VMA9V4@2&]R9&5?1F]R;0H@*B\*8VQA
M<W,@2&]R9&5?1F]R;5]!8W1I;VY?8V]N9&ET:6]N86Q?<V5T=F%L=64@97AT
M96YD<R!(;W)D95]&;W)M7T%C=&EO;B!["@H@("`@+RHJ"B`@("`@*B!7:&EC
M:"!*4R!E=F5N=',@<VAO=6QD('1R:6=G97(@=&AI<R!A8W1I;VX_"B`@("`@
M*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]T<FEG9V5R
M(#T@87)R87DH)V]N8VAA;F=E)RP@)V]N;&]A9"<I.PH*("`@(&9U;F-T:6]N
M(&=E=$%C=&EO;E-C<FEP="@D9F]R;2P@)')E;F1E<F5R+"`D=F%R;F%M92D*
M("`@('L*("`@("`@("!R971U<FX@)VUA<"A<)R<@+B`D<F5N9&5R97(M/E]G
M96Y)1"@D=F%R;F%M92P@9F%L<V4I("X@(B<L("<B("X@)')E;F1E<F5R+3Y?
M9V5N240H)'1H:7,M/F=E=%1A<F=E="@I+"!F86QS92D@+B`G7"<I.R<["B`@
M("!]"@H@("`@9G5N8W1I;VX@<V5T5F%L=65S*"8D=F%R<RP@)'-O=7)C959A
M;"P@)&%R<F%Y5F%L(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&UA<"`]("1T
M:&ES+3Y?<&%R86US6R=M87`G73L*("`@("`@("`D=&%R9V5T(#T@)'1H:7,M
M/F=E=%1A<F=E="@I.PH*("`@("`@("!I9B`H)&%R<F%Y5F%L*2!["B`@("`@
M("`@("`@("1I(#T@,#L*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1S;W5R
M8V5686PI*2!["B`@("`@("`@("`@("`@("!F;W)E86-H("@D<V]U<F-E5F%L
M(&%S("1V86PI('L*("`@("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1M
M87!;)'9A;%TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1V87)S+3YS
M970H)'1A<F=E="P@)&UA<%LD=F%L72P@)&DI.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`D:2LK.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@:68@*"%E;7!T>2@D;6%P6R1S;W5R8V5686Q=*2D@>PH@("`@("`@("`@
M("`@("`@)'9A<G,M/G-E="@D=&%R9V5T+"`D;6%P6R1S;W5R8V5686Q=*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!P
M<FEN=$IA=F%38W)I<'0H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<')I;G1*
M879A4V-R:7!T4W1A<G0H*3L*("`@("`@("`D;6%P(#T@)'1H:7,M/E]P87)A
M;7-;)VUA<"==.PH_/@H*=F%R(%]M87`@/2!N97<@07)R87DH/#]P:'`*)&D@
M/2`P.PIF;W)E86-H("@D;6%P(&%S("1V86PI('L*("`@(&EF("@D:2`^(#`I
M('L*("`@("`@("!E8VAO("<L("<["B`@("!]"B`@("!E8VAO("<B)R`N("1V
M86P@+B`G(B<["B`@("`D:2LK.PI]/SXI.PH*9G5N8W1I;VX@;6%P*'-O=7)C
M94ED+"!T87)G971)9"D*>PH@("`@=F%R(&YE=W9A;#L*("`@('9A<B!S;W5R
M8V4@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"AS;W5R8V5)9"D["B`@("!V
M87(@96QE;65N="`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*'1A<F=E=$ED
M*3L*("`@(&EF("AE;&5M96YT*2!["B`@("`@("`@:68@*%]M87!;<V]U<F-E
M+G-E;&5C=&5D26YD97A=*2!["B`@("`@("`@("`@(&YE=W9A;"`](%]M87!;
M<V]U<F-E+G-E;&5C=&5D26YD97A=.PH@("`@("`@("`@("!R97!L86-E(#T@
M=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!N97=V86P@/2`G
M)SL*("`@("`@("`@("`@<F5P;&%C92`](&9A;'-E.PH@("`@("`@("`@("!F
M;W(@*&D@/2`P.R!I(#P@7VUA<"YL96YG=&@[(&DK*RD@>PH@("`@("`@("`@
M("`@("`@:68@*&5L96UE;G0N=F%L=64@/3T@7VUA<%MI72D@>PH@("`@("`@
M("`@("`@("`@("`@(')E<&QA8V4@/2!T<G5E.PH@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!I9B`H<F5P;&%C92D@>PH@("`@("`@("`@("!E
M;&5M96YT+G9A;'5E(#T@;F5W=F%L.PH@("`@("`@('T*("`@('T*?3P_<&AP
M"B`@("`@("`@)'1H:7,M/E]P<FEN=$IA=F%38W)I<'1%;F0H*3L*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+T9O<FTO06-T:6]N+W-U8FUI="YP:'``````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`Q,S<W(#$P-3$U-#,S-S,V(#`R,S4Q-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@2&]R
M9&5?1F]R;5]!8W1I;VY?<W5B;6ET(&ES(&$@2&]R9&5?1F]R;2!!8W1I;VX@
M=&AA="!S=6)M:71S('1H90H@*B!F;W)M(&%F=&5R('1H92!F;W)M(&5L96UE
M;G0@=&AA="!T:&4@86-T:6]N(&ES(&%T=&%C:&5D('1O(&ES"B`J(&UO9&EF
M:65D+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]&;W)M+T9O<FTO06-T:6]N
M+W-U8FUI="YP:'`L=B`Q+C$P+C$R+C0@,C`P-B\P,2\P,2`R,3HR.#HQ-R!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E
M;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`
M<&%C:V%G92!(;W)D95]&;W)M"B`J+PIC;&%S<R!(;W)D95]&;W)M7T%C=&EO
M;E]S=6)M:70@97AT96YD<R!(;W)D95]&;W)M7T%C=&EO;B!["@H@("`@=F%R
M("1?=')I9V=E<B`](&%R<F%Y*"=O;F-H86YG92<I.PH*("`@(&9U;F-T:6]N
M(&=E=$%C=&EO;E-C<FEP="@D9F]R;2P@)')E;F1E<F5R+"`D=F%R;F%M92D*
M("`@('L*("`@("`@("!R971U<FX@)V1O8W5M96YT+B<@+B`D9F]R;2T^9V5T
M3F%M92@I("X@)RYS=6)M:70H*2<["B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+T9O<FTO06-T:6]N+W5P9&%T969I96QD+G!H<```````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`S-S`Q(#$P-3$U-#,S-S,V(#`R-#0W,0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@2&]R9&5?1F]R;5]!8W1I;VY?=7!D871E9FEE;&0@:7,@82!(;W)D95]&
M;W)M7T%C=&EO;B!T:&%T('5P9&%T97,*("H@=&AE('9A;'5E(&]F(&]N92!(
M;W)D95]&;W)M('9A<FEA8FQE(&%S('1H92!V87)I86)L92!T:&4@86-T:6]N
M(&ES"B`J(&%T=&%C:&5D('1O(&ES('5P9&%T960N"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+T9O<FTO1F]R;2]!8W1I;VXO=7!D871E9FEE;&0N<&AP+'8@
M,2XU+C$R+C0@,C`P-B\P,2\P,2`R,3HR.#HQ-R!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO
M<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!(;W)D95]&
M;W)M"B`J+PIC;&%S<R!(;W)D95]&;W)M7T%C=&EO;E]U<&1A=&5F:65L9"!E
M>'1E;F1S($AO<F1E7T9O<FU?06-T:6]N('L*"B`@("!V87(@)%]T<FEG9V5R
M(#T@87)R87DH)V]N8VAA;F=E)RP@)V]N;&]A9"<L("=O;FME>75P)RD["@H@
M("`@9G5N8W1I;VX@9V5T06-T:6]N4V-R:7!T*"8D9F]R;2P@)B1R96YD97)E
M<BP@)'9A<FYA;64I"B`@("!["B`@("`@("`@<F5T=7)N("=U<&1A=&5&:65L
M9"<@+B`D=&AI<RT^:60H*2`N("<H*3LG.PH@("`@?0H*("`@(&9U;F-T:6]N
M('-E=%9A;'5E<R@F)'9A<G,L("1S;W5R8V5686PL("1A<G)A>59A;"`](&9A
M;'-E*0H@("`@>PH@("`@?0H*("`@(&9U;F-T:6]N('!R:6YT2F%V85-C<FEP
M="@I"B`@("!["B`@("`@("`@)'1H:7,M/E]P<FEN=$IA=F%38W)I<'13=&%R
M="@I.PH@("`@("`@("1P:65C97,@/2!E>'!L;V1E*"<E<R<L("1T:&ES+3Y?
M<&%R86US6R=F;W)M870G72D["B`@("`@("`@)&9I96QD<R`]("1T:&ES+3Y?
M<&%R86US6R=F:65L9',G73L*("`@("`@("`D=F%L7V9I<G-T(#T@*'-U8G-T
M<B@D=&AI<RT^7W!A<F%M<ULG9F]R;6%T)UTL(#`L(#(I(#T]("<E<R<I.PH@
M("`@("`@(&EF("@D=F%L7V9I<G-T*2!["B`@("`@("`@("`@(&%R<F%Y7W-H
M:69T*"1P:65C97,I.PH@("`@("`@('T*("`@("`@("!I9B`H<W5B<W1R*"1T
M:&ES+3Y?<&%R86US6R=F;W)M870G72P@+3(I(#T]("<E<R<I('L*("`@("`@
M("`@("`@87)R87E?<&]P*"1P:65C97,I.PH@("`@("`@('T*"B`@("`@("`@
M)&%R9W,@/2!A<G)A>2@I.PH@("`@("`@(&EF("@D=F%L7V9I<G-T*2!["B`@
M("`@("`@("`@("1A<F=S6UT@/2`B9&]C=6UE;G0N9V5T16QE;65N=$)Y260H
M)R(@+B!A<G)A>5]S:&EF="@D9FEE;&1S*2`N("(G*2YV86QU92(["B`@("`@
M("`@?0H@("`@("`@('=H:6QE("AC;W5N="@D<&EE8V5S*2D@>PH@("`@("`@
M("`@("`D87)G<UM=(#T@(B<B("X@87)R87E?<VAI9G0H)'!I96-E<RD@+B`B
M)R(["B`@("`@("`@("`@("1A<F=S6UT@/2`B9&]C=6UE;G0N9V5T16QE;65N
M=$)Y260H)R(@+B!A<G)A>5]S:&EF="@D9FEE;&1S*2`N("(G*2YV86QU92([
M"B`@("`@("`@?0H_/@HO+R!5<&1A=&5R(&9O<B`\/W!H<"!E8VAO("1T:&ES
M+3YG971487)G970H*2`_/BX*9G5N8W1I;VX@=7!D871E1FEE;&0\/W!H<"!E
M8VAO("1T:&ES+3YI9"@I(#\^*"D*>PH@("`@=F%R('1A<F=E="`](&1O8W5M
M96YT+F=E=$5L96UE;G1">4ED*"<\/W!H<"!E8VAO("1T:&ES+3YG971487)G
M970H*2`_/B<I.PH@("`@:68@*'1A<F=E="D@>PH@("`@("`@('1A<F=E="YV
M86QU92`](#P_<&AP(&5C:&\@:6UP;&]D92@G("L@)RP@<W1R7W)E<&QA8V4H
M(EQN(BP@(EQ<;B(L("1A<F=S*2D@/SX["B`@("!]"GT\/W!H<`H@("`@("`@
M("1T:&ES+3Y?<')I;G1*879A4V-R:7!T16YD*"D["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]&;W)M+T%C=&EO;B]S=6U?9FEE;&1S+G!H<```````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,C<V,"`Q,#4Q-30S,S<S-B`P,C0S-#$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J($AO
M<F1E7T9O<FU?06-T:6]N7W-U;5]F:65L9',@:7,@82!(;W)D95]&;W)M7T%C
M=&EO;B!T:&%T('-E=',@=&AE('1A<F=E=`H@*B!F:65L9"!T;R!T:&4@<W5M
M(&]F(&]N92!O<B!M;W)E(&]T:&5R(&YU;65R:6,@9FEE;&1S+@H@*@H@*B!4
M:&4@<&%R86US(&%R<F%Y('-H;W5L9"!C;VYT86EN('1H92!N86UE<R!O9B!T
M:&4@9FEE;&1S('=H:6-H('=I;&P@8F4*("H@<W5M;65D+@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]&;W)M+T9O<FTO06-T:6]N+W-U;5]F:65L9',N<&AP
M+'8@,2XU+C$P+C0@,C`P-B\P,2\P,2`R,3HR.#HQ-R!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-871T($MY;F%S=&]N(#QM871T0&MY
M;G@N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36%T="!+>6YA
M<W1O;B`\;6%T=$!K>6YX+F]R9SX*("H@0'!A8VMA9V4@2&]R9&5?1F]R;0H@
M*B\*8VQA<W,@2&]R9&5?1F]R;5]!8W1I;VY?<W5M7V9I96QD<R!E>'1E;F1S
M($AO<F1E7T9O<FU?06-T:6]N('L*"B`@("!V87(@)%]T<FEG9V5R(#T@87)R
M87DH)V]N;&]A9"<I.PH*("`@(&9U;F-T:6]N(&=E=$%C=&EO;E-C<FEP="@F
M)&9O<FTL("1R96YD97)E<BP@)'9A<FYA;64I"B`@("!["B`@("`@("`@2&]R
M9&4Z.F%D9%-C<FEP=$9I;&4H)V9O<FU?:&5L<&5R<RYJ<R<L("=H;W)D92<L
M('1R=64I.PH*("`@("`@("`D9F]R;5]N86UE(#T@)&9O<FTM/F=E=$YA;64H
M*3L*("`@("`@("`D9FEE;&1S(#T@(B<B("X@:6UP;&]D92@B)RPG(BP@)'1H
M:7,M/E]P87)A;7,I("X@(B<B.PH@("`@("`@("1J<R`](&%R<F%Y*"D["B`@
M("`@("`@)&IS6UT@/2!S<')I;G1F*"=D;V-U;65N="YF;W)M<UM<)R5S7"==
M+F5L96UE;G1S6UPG)7-<)UTN9&ES86)L960@/2!T<G5E.R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("1F;W)M7VYA;64L"B`@("`@("`@("`@("`@("`@
M("`@("`@("1V87)N86UE*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7W!A
M<F%M<R!A<R`D9FEE;&0I('L*("`@("`@("`@("`@)&IS6UT@/2!S<')I;G1F
M*")A9&1%=F5N="AD;V-U;65N="YF;W)M<ULG)3%<)',G72YE;&5M96YT<ULG
M)3)<)',G72P@7")O;F-H86YG95PB+"!<(G-U;49I96QD<RAD;V-U;65N="YF
M;W)M<ULG)3%<)',G72P@)R4S7"1S)RP@)31<)',I.UPB*3LB+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&9O<FU?;F%M92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1F:65L9"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&9I96QD<RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@:6UP;&]D92@B
M7&XB+"`D:G,I.PH@("`@?0H*?0H`````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T9O<FTO06-T:6]N+G!H<```````
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$P-S`S(#$P-3$U-#,S
M-S,V(#`R,C(P,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@5&AE($AO<F1E7T9O<FU?06-T:6]N(&-L
M87-S('!R;W9I9&5S(&%N($%022!F;W(@861D:6YG(&%C=&EO;G,@=&\*("H@
M2&]R9&5?1F]R;2!V87)I86)L97,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+T9O<FTO1F]R;2]!8W1I;VXN<&AP+'8@,2XQ.2XQ,"XV(#(P,#8O,#$O,#$@
M,C$Z,C@Z,3<@:F%N($5X<"`D"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU
M8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H@0'!A8VMA9V4@2&]R9&5?1F]R;0H@*B\*8VQA<W,@2&]R9&5?1F]R
M;5]!8W1I;VX@>PH*("`@('9A<B`D7VED.PH@("`@=F%R("1?<&%R86US.PH@
M("`@=F%R("1?=')I9V=E<B`](&YU;&P["@H@("`@9G5N8W1I;VX@2&]R9&5?
M1F]R;5]!8W1I;VXH)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@)'1H
M:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@("`@("1T:&ES+3Y?:60@/2!M
M9#4H;71?<F%N9"@I*3L*("`@('T*"B`@("!F=6YC=&EO;B!G9714<FEG9V5R
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]T<FEG9V5R.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&ED*"D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]I9#L*("`@('T*"B`@("!F=6YC=&EO;B!G971!8W1I;VY38W)I<'0H
M)&9O<FTL("1R96YD97)E<BP@)'9A<FYA;64I"B`@("!["B`@("`@("`@<F5T
M=7)N("<G.PH@("`@?0H*("`@(&9U;F-T:6]N('!R:6YT2F%V85-C<FEP="@I
M"B`@("!["B`@("!]"@H@("`@9G5N8W1I;VX@7W!R:6YT2F%V85-C<FEP=%-T
M87)T*"D*("`@('L*("`@("`@("!E8VAO("<\<V-R:7!T('1Y<&4](G1E>'0O
M:F%V87-C<FEP="(^/"$M+2<["B`@("!]"@H@("`@9G5N8W1I;VX@7W!R:6YT
M2F%V85-C<FEP=$5N9"@I"B`@("!["B`@("`@("`@96-H;R`G+R\@+2T^/"]S
M8W)I<'0^)SL*("`@('T*"B`@("!F=6YC=&EO;B!G971487)G970H*0H@("`@
M>PH@("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^7W!A<F%M<ULG=&%R9V5T
M)UTI(#\@)'1H:7,M/E]P87)A;7-;)W1A<F=E="==(#H@;G5L;#L*("`@('T*
M"B`@("!F=6YC=&EO;B!S971686QU97,H)B1V87)S+"`D<V]U<F-E5F%L+"`D
M:6YD97@@/2!N=6QL+"`D87)R87E686P@/2!F86QS92D*("`@('L*("`@('T*
M"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(&-O;F-R971E
M($AO<F1E7T9O<FU?06-T:6]N(&EN<W1A;F-E"B`@("`@*B!B87-E9"!O;B`D
M9F]R;2X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&9O<FT@("`@5&AE
M('1Y<&4@;V8@8V]N8W)E=&4@2&]R9&5?1F]R;5]!8W1I;VX@<W5B8VQA<W,*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!T;R!R971U<FXN($EF("1F
M;W)M(&ES(&%N(&%R<F%Y+"!T:&5N('=E('=I;&P@;&]O:PH@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@(&EN("1F;W)M6S!=+VQI8B]&;W)M+T%C=&EO
M;B\@9F]R('1H92!S=6)C;&%S<PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@(&EM<&QE;65N=&%T:6]N(&YA;65D("1F;W)M6S%=+G!H<"X*("`@("`J
M($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@
M861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&$*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!F;W)M(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E
M='5R;B!(;W)D95]&;W)M7T%C=&EO;B`@5&AE(&-O;F-R971E($AO<F1E7T9O
M<FU?06-T:6]N(')E9F5R96YC92P@;W(*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&9A;'-E(&]N(&%N(&5R<F]R+@H@("`@("HO"B`@("!F
M=6YC=&EO;B`F9F%C=&]R>2@D86-T:6]N+"`D<&%R86US(#T@;G5L;"D*("`@
M('L*("`@("`@("!I9B`H:7-?87)R87DH)&%C=&EO;BDI('L*("`@("`@("`@
M("`@)&%P<"`]("1A8W1I;VY;,%T["B`@("`@("`@("`@("1A8W1I;VX@/2`D
M86-T:6]N6S%=.PH@("`@("`@('T*"B`@("`@("`@)&%C=&EO;B`](&)A<V5N
M86UE*"1A8W1I;VXI.PH@("`@("`@(&EF("AE;7!T>2@D86-T:6]N*2!\?"`H
M<W1R8VUP*"1A8W1I;VXL("=N;VYE)RD@/3T@,"DI('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T-A;FYO="!I;G-T86YT:6%T92!A
M8G-T<F%C="!C;&%S<R!(;W)D95]&;W)M7T%C=&EO;BXG*3L*("`@("`@("!]
M"@H@("`@("`@(&EF("@A96UP='DH)&%P<"DI('L*("`@("`@("`@("`@<F5Q
M=6ER95]O;F-E("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)V9I;&5R;V]T
M)RP@)&%P<"D@+B`G+VQI8B]&;W)M+T%C=&EO;B\G("X@)&%C=&EO;B`N("<N
M<&AP)SL*("`@("`@("!](&5L<V5I9B`H0&9I;&5?97AI<W1S*&1I<FYA;64H
M7U]&24Q%7U\I("X@)R]!8W1I;VXO)R`N("1A8W1I;VX@+B`G+G!H<"<I*2![
M"B`@("`@("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N
M("<O06-T:6]N+R<@+B`D86-T:6]N("X@)RYP:'`G.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O1F]R;2]!8W1I
M;VXO)R`N("1A8W1I;VX@+B`G+G!H<"<["B`@("`@("`@?0H*("`@("`@("`D
M8VQA<W,@/2`G2&]R9&5?1F]R;5]!8W1I;VY?)R`N("1A8W1I;VX["B`@("`@
M("`@:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1I
M;G-T86YC92`]("9N97<@)&-L87-S*"1P87)A;7,I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1I;G-T86YC92`](%!%05(Z.G)A:7-E17)R;W(H
M)T-L87-S(&1E9FEN:71I;VX@;V8@)R`N("1C;&%S<R`N("<@;F]T(&9O=6YD
M+B<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC93L*("`@
M('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(')E9F5R
M96YC92!T;R!A(&-O;F-R971E"B`@("`@*B!(;W)D95]&;W)M7T%C=&EO;B!I
M;G-T86YC92!B87-E9"!O;B`D86-T:6]N+B!)="!W:6QL(&]N;'D*("`@("`J
M(&-R96%T92!A(&YE=R!I;G-T86YC92!I9B!N;R!(;W)D95]&;W)M7T%C=&EO
M;B!I;G-T86YC92!W:71H"B`@("`@*B!T:&4@<V%M92!P87)A;65T97)S(&-U
M<G)E;G1L>2!E>&ES=',N"B`@("`@*@H@("`@("H@5&AI<R!S:&]U;&0@8F4@
M=7-E9"!I9B!M=6QT:7!L92!T>7!E<R!O9B!F;W)M(')E;F1E<F5R<R`H86YD
M+`H@("`@("H@=&AU<RP@;75L=&EP;&4@2&]R9&5?1F]R;5]!8W1I;VX@:6YS
M=&%N8V5S*2!A<F4@<F5Q=6ER960N"B`@("`@*@H@("`@("H@5&AI<R!M971H
M;V0@;75S="!B92!I;G9O:V5D(&%S.B`D=F%R(#T*("`@("`J("9(;W)D95]&
M;W)M7T%C=&EO;CHZ<VEN9VQE=&]N*"D*("`@("`J"B`@("`@*B!`<&%R86T@
M;6EX960@)&%C=&EO;B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@2&]R9&5?1F]R
M;5]!8W1I;VX@<W5B8VQA<W,@=&\@<F5T=7)N+@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@(%1H92!C;V1E(&ES(&1Y;F%M:6-A;&QY(&EN8VQU9&5D
M+B!)9B`D86-T:6]N(&ES(&%N(&%R<F%Y+`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@('1H96X@=V4@=VEL;"!L;V]K(&EN("1A8W1I;VY;,%TO;&EB
M+T9O<FTO06-T:6]N+R!F;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!T:&4@<W5B8VQA<W,@:6UP;&5M96YT871I;VX@;F%M960@)&%C=&EO;ELQ
M72YP:'`N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O
M;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!A"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@9F]R;2!M:6=H="!N965D+@H@("`@
M("H*("`@("`J($!R971U<FX@2&]R9&5?1F]R;5]!8W1I;VX@(%1H92!C;VYC
M<F5T92!(;W)D95]&;W)M7T%C=&EO;B!R969E<F5N8V4L(&]R"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!F86QS92!O;B!A;B!E<G)O<BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@D86-T:6]N+"`D<&%R
M86US(#T@;G5L;"D*("`@('L*("`@("`@("!S=&%T:6,@)&EN<W1A;F-E<SL*
M("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97,I*2!["B`@("`@("`@("`@
M("1I;G-T86YC97,@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@)'-I
M9VYA='5R92`]('-E<FEA;&EZ92AA<G)A>2@D86-T:6]N+"`D<&%R86US*2D[
M"B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S6R1S:6=N871U<F5=*2D@
M>PH@("`@("`@("`@("`D:6YS=&%N8V5S6R1S:6=N871U<F5=(#T@)DAO<F1E
M7T9O<FU?06-T:6]N.CIF86-T;W)Y*"1A8W1I;VXL("1P87)A;7,I.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;)'-I9VYA='5R95T[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O1F]R;2]296YD97)E<BYP:'``````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P-#0R,#0@,3`U,34T,S,W,S8@,#(R-3,W
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B!4:&4@2&]R9&5?1F]R;5]296YD97)E<B!C;&%S<R!P<F]V
M:61E<R!(5$U,(&%N9"!O=&AE<B!R96YD97)I;F=S(&]F"B`J(&9O<FUS(&9O
M<B!T:&4@2&]R9&5?1F]R;3HZ('!A8VMA9V4N"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`L=B`Q+C$X-2XT+C$U(#(P
M,#8O,#0O,34@,3@Z,#4Z,#0@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#$M,C`P-B!2;V)E<G0@12X@0V]Y;&4@/')O8F5R=&5C;WEL94!H;W1M
M86EL+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@(%)O8F5R="!%
M+B!#;WEL92`\<F]B97)T96-O>6QE0&AO=&UA:6PN8V]M/@H@*B!`<&%C:V%G
M92!(;W)D95]&;W)M"B`J+PIC;&%S<R!(;W)D95]&;W)M7U)E;F1E<F5R('L*
M"B`@("!V87(@)%]N86UE.PH@("`@=F%R("1?<F5Q=6ER961,96=E;F0@/2!F
M86QS93L*("`@('9A<B`D7W)E<75I<F5D36%R:V5R(#T@)RHG.PH@("`@=F%R
M("1?:&5L<$UA<FME<B`]("<_)SL*("`@('9A<B`D7V]N3&]A9$I3(#T@87)R
M87DH*3L*("`@('9A<B`D7W-H;W=(96%D97(@/2!T<G5E.PH@("`@=F%R("1?
M8V]L<R`](#(["B`@("!V87(@)%]V87)296YD97)E<B`](&YU;&P["B`@("!V
M87(@)%]F:7)S=$9I96QD(#T@;G5L;#L*("`@('9A<B`D7W-T<FEP9612;W=S
M(#T@=')U93L*"B`@("`O*BH*("`@("`J($1O97,@=&AE('1I=&QE(&]F('1H
M92!F;W)M(&-O;G1A:6X@2%1-3#\@268@<V\L('EO=2!A<F4@<F5S<&]N<VEB
M;&4@9F]R"B`@("`@*B!D;VEN9R!A;GD@;F5E9&5D(&5S8V%P:6YG+W-A;FET
M:7IA=&EO;B!Y;W5R<V5L9BX@3W1H97)W:7-E('1H92!T:71L90H@("`@("H@
M=VEL;"!B92!R=6X@=&AR;W5G:"!H=&UL<W!E8VEA;&-H87)S*"D@8F5F;W)E
M(&)E:6YG(&]U='!U="X*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@
M("`J+PH@("`@=F%R("1?96YC;V1E5&ET;&4@/2!T<G5E.PH*("`@("\J*@H@
M("`@("H@5VED=&@@;V8@=&AE(&%T=')I8G5T97,@8V]L=6UN+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'9A<B!S=')I;F<*("`@
M("`J+PH@("`@=F%R("1?871T<D-O;'5M;E=I9'1H(#T@)S$U)2<["@H@("`@
M+RHJ"B`@("`@*B!#;VYS=')U8W0@82!N97<@2&]R9&5?1F]R;5]296YD97)E
M<CHZ+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!4:&ES
M(&ES(&$@:&%S:"!O9B!R96YD97)E<BUS<&5C:69I8R!P87)A;65T97)S+@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@(%!O<W-I8FQE(&ME>7,Z/&-O
M9&4^"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@)W9A<G)E;F1E<F5R
M7V1R:79E<B<Z('-P96-I9FEE<R!T:&4@9')I=F5R"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@('!A<F%M971E<B!T;R!(;W)D95]525]687)2
M96YD97)E<CHZ9F%C=&]R>2@I+@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("=E;F-O9&5?=&ET;&4G.B!`<V5E("1?96YC;V1E5&ET;&4\+V-O9&4^
M"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7T9O<FU?4F5N9&5R97(H)'!A
M<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R
M>3L*("`@("`@("!I9B`H:7-S970H)')E9VES=')Y*2`F)B!I<U]A*"1R96=I
M<W1R>2P@)U)E9VES=')Y)RDI('L*("`@("`@("`@("`@+RH@4F5G:7-T<GD@
M879A:6QA8FQE+"!S;R!U<V4@82!P<F5T='D@:6UA9V4N("HO"B`@("`@("`@
M("`@("1T:&ES+3Y?<F5Q=6ER961-87)K97(@/2!(;W)D93HZ:6UG*"=R97%U
M:7)E9"YP;F<G+"`G*B<L("<G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H
M;W)D92<I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!.;R!R
M96=I<W1R>2!A=F%I;&%B;&4L('5S92!S;VUE=&AI;F<@<&QA:6XN("HO"B`@
M("`@("`@("`@("1T:&ES+3Y?<F5Q=6ER961-87)K97(@/2`G*B<["B`@("`@
M("`@?0H*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG96YC;V1E7W1I=&QE
M)UTI*2!["B`@("`@("`@("`@("1T:&ES+3YE;F-O9&54:71L92@D<&%R86US
M6R=E;F-O9&5?=&ET;&4G72D["B`@("`@("`@?0H*("`@("`@("`D9')I=F5R
M(#T@)VAT;6PG.PH@("`@("`@(&EF("AI<W-E="@D<&%R86US6R=V87)R96YD
M97)E<E]D<FEV97(G72DI('L*("`@("`@("`@("`@)&1R:79E<B`]("1P87)A
M;7-;)W9A<G)E;F1E<F5R7V1R:79E<B==.PH@("`@("`@('T*("`@("`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+U5)+U9A<E)E;F1E<F5R+G!H<"<["B`@("`@
M("`@)'1H:7,M/E]V87)296YD97)E<B`]("9(;W)D95]525]687)296YD97)E
M<CHZ9F%C=&]R>2@D9')I=F5R+"`D<&%R86US*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!S:&]W2&5A9&5R*"1B;V]L*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M<VAO=TAE861E<B`]("1B;V]L.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T
M<R!O<B!R971U<FYS('=H971H97(@=&AE(&9O<FT@=&ET;&4@<VAO=6QD(&)E
M(&5N8V]D960@=VET:`H@("`@("H@:'1M;'-P96-I86QC:&%R<R@I+@H@("`@
M("H*("`@("`J($!P87)A;2!B;V]L96%N("1E;F-O9&4@($EF('1R=64L('1H
M92!F;W)M('1I=&QE(&=E=',@96YC;V1E9"X@($EF(&9A;'-E"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!T:&4@=&ET;&4@8V%N(&-O;G1A:6X@
M2%1-3"P@8G5T('1H92!C;&%S<R!U<V5R"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("!I<R!R97-P;VYS:6)L92!T;R!E;F-O9&4@86YY('-P96-I
M86P@8VAA<F%C=&5R<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%=H971H97(@=&AE(&9O<FT@=&ET;&4@<VAO=6QD(&)E(&5N8V]D960N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&5N8V]D951I=&QE*"1E;F-O9&4@/2!N=6QL
M*0H@("`@>PH@("`@("`@(&EF("@A:7-?;G5L;"@D96YC;V1E*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7V5N8V]D951I=&QE(#T@)&5N8V]D93L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?96YC;V1E5&ET;&4@/2`D96YC
M;V1E.PH@("`@?0H*("`@("\J*@H@("`@("H@4W!E8VEF>2!T:&4@=VED=&@@
M;V8@=&AE(&%T=')I8G5T92!C;VQU;6X@:6X@=&AE(')E;F1E<F5D(&9O<FTN
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=VED=&@@(%1H92!W:61T
M:"!O9B!T:&4@871T<FEB=71E(&-O;'5M;BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T071T<D-O;'5M;E=I
M9'1H*"1W:61T:"D*("`@('L*("`@("`@("`D=&AI<RT^7V%T=')#;VQU;6Y7
M:61T:"`]("1W:61T:#L*("`@('T*"B`@("!F=6YC=&EO;B!O<&5N*"1A8W1I
M;VXL("1M971H;V0L("1N86UE+"`D96YC='EP92`](&YU;&PI"B`@("!["B`@
M("`@("`@)'1H:7,M/E]N86UE(#T@)&YA;64["B`@("`@("`@)&YA;64@/2!H
M=&UL<W!E8VEA;&-H87)S*"1N86UE*3L*("`@("`@("!E8VAO("(\9F]R;2!A
M8W1I;VX]7"(D86-T:6]N7"(@;65T:&]D/5PB)&UE=&AO9%PB(B`N("AE;7!T
M>2@D;F%M92D@/R`G)R`Z("(@;F%M93U<(B1N86UE7"(@:60]7"(D;F%M95PB
M(BD@+B`H:7-?;G5L;"@D96YC='EP92D@/R`G)R`Z("(@96YC='EP93U<(B1E
M;F-T>7!E7"(B*2`N("(^7&XB.PH@("`@("`@(%5T:6PZ.G!F;W)M26YP=70H
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!B96=I;D%C=&EV92@D;F%M92P@)&5X
M=')A(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^7W)E;F1E<D)E9VEN
M06-T:79E*"1N86UE+"`D97AT<F$I.PH@("`@?0H*("`@(&9U;F-T:6]N(&)E
M9VEN26YA8W1I=F4H)&YA;64L("1E>'1R82`](&YU;&PI"B`@("!["B`@("`@
M("`@)'1H:7,M/E]R96YD97)"96=I;DEN86-T:79E*"1N86UE+"`D97AT<F$I
M.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)396-T:6]N5&%B<R@F)&9O
M<FTI"B`@("!["B`@("`@("`@+RH@268@:F%V87-C<FEP="!I<R!N;W0@879A
M:6QA8FQE+"!D;R!N;W0@<F5N9&5R('1A8G,N("HO"B`@("`@("`@:68@*"$D
M1TQ/0D%,4ULG8G)O=W-E<B==+3YH87-&96%T=7)E*"=J879A<V-R:7!T)RDI
M('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@)&]P
M96Y?<V5C=&EO;B`]("1F;W)M+3YG971/<&5N4V5C=&EO;B@I.PH*("`@("`@
M("`O*B!!9&0@=&AE(&IA=F%S8W)I<'0@9F]R('1H92!T;V=G;&EN9R!T:&4@
M<V5C=&EO;G,N("HO"B`@("`@("`@2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)V9O
M<FU?<V5C=&EO;G,N:G,G+"`G:&]R9&4G+"!T<G5E*3L*("`@("`@("!E8VAO
M("<\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^)R`N(")<;B(["B`@
M("`@("`@<')I;G1F*"=V87(@<V5C=&EO;G-?)3$D<R`](&YE=R!(;W)D95]&
M;W)M7U-E8W1I;VYS*%PG)3$D<UPG+"!<)R4R)'-<)RD[)RP*("`@("`@("`@
M("`@("`@)&9O<FTM/F=E=$YA;64H*2P*("`@("`@("`@("`@("`@)&]P96Y?
M<V5C=&EO;BD["B`@("`@("`@96-H;R`B7&XB("X@)SPO<V-R:7!T/B<["@H@
M("`@("`@("\J($QO;W`@=&AR;W5G:"!T:&4@<V5C=&EO;G,@86YD('!R:6YT
M(&]U="!A('1A8B!F;W(@96%C:"X@*B\*("`@("`@("!E8VAO("(\9&EV(&-L
M87-S/5PB=&%B<V5T7"(^/'5L/EQN(CL*("`@("`@("!F;W)E86-H("@D9F]R
M;2T^7W-E8W1I;VYS(&%S("1S96-T:6]N(#T^("1V86PI('L*("`@("`@("`@
M("`@)&-L87-S(#T@*"1S96-T:6]N(#T]("1O<&5N7W-E8W1I;VXI(#\@)R!C
M;&%S<STB86-T:79E5&%B(B<@.B`G)SL*("`@("`@("`@("`@)&IS(#T@<W!R
M:6YT9B@G;VYC;&EC:STB<V5C=&EO;G-?)7,N=&]G9VQE*%PG)7-<)RD[(')E
M='5R;B!F86QS93LB)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R
M;2T^9V5T3F%M92@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("1S96-T
M:6]N*3L*("`@("`@("`@("`@<')I;G1F*"<\;&DE<R!I9#TB)7,B/CQA(&AR
M968](B,B("5S/B5S)7,\+V$^(#PO;&D^)R`N(")<;B(L"B`@("`@("`@("`@
M("`@("`@("`D8VQA<W,L("=?=&%B7R<@+B`D<V5C=&EO;BP@)&IS+`H@("`@
M("`@("`@("`@("`@("`@)&9O<FTM/F=E=%-E8W1I;VY);6%G92@D<V5C=&EO
M;BDL"B`@("`@("`@("`@("`@("`@("`D9F]R;2T^9V5T4V5C=&EO;D1E<V,H
M)'-E8W1I;VXI*3L*("`@("`@("!]"B`@("`@("`@96-H;R`B/"]U;#X\+V1I
M=CX\8G(@8VQA<W,]7")C;&5A<EPB("\^7&XB.PH@("`@?0H*("`@(&9U;F-T
M:6]N(%]R96YD97)396-T:6]N0F5G:6XH)B1F;W)M+"`D<V5C=&EO;BD*("`@
M('L*("`@("`@("`O+R!3=')I<&4@86QT97)N871E(')O=W,@:68@=&AA="!O
M<'1I;VX@:7,@='5R;F5D(&]N+@H@("`@("`@(&EF("@D=&AI<RT^7W-T<FEP
M9612;W=S*2!["B`@("`@("`@("`@($AO<F1E.CIA9&138W)I<'1&:6QE*"=S
M=')I<&4N:G,G+"`G:&]R9&4G+"!T<G5E*3L*("`@("`@("`@("`@)&-L87-S
M(#T@)R!C;&%S<STB<W1R:7!E9"(G.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1C;&%S<R`]("<G.PH@("`@("`@('T*"B`@("`@("`@)&]P96Y?
M<V5C=&EO;B`]("1F;W)M+3YG971/<&5N4V5C=&EO;B@I.PH@("`@("`@(&EF
M("AE;7!T>2@D;W!E;E]S96-T:6]N*2D@>PH@("`@("`@("`@("`D;W!E;E]S
M96-T:6]N(#T@)U]?8F%S92<["B`@("`@("`@?0H@("`@("`@('!R:6YT9B@G
M/&1I=B!I9#TB)7,B('-T>6QE/2)D:7-P;&%Y.B5S.R(^/'1A8FQE)7,@8V5L
M;'-P86-I;F<](C`B/B<L"B`@("`@("`@("`@("`@("=?<V5C=&EO;E\G("X@
M)'-E8W1I;VXL"B`@("`@("`@("`@("`@("@D;W!E;E]S96-T:6]N(#T]("1S
M96-T:6]N(#\@)V)L;V-K)R`Z("=N;VYE)RDL"B`@("`@("`@("`@("`@("1C
M;&%S<RD["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E-E8W1I;VY%;F0H
M*0H@("`@>PH@("`@("`@(&5C:&\@)SPO=&%B;&4^/"]D:78^)SL*("`@('T*
M"B`@("!F=6YC=&EO;B!E;F0H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<F5N
M9&5R16YD*"D["B`@("!]"@H@("`@9G5N8W1I;VX@8VQO<V4H)&9O8W5S(#T@
M=')U92D*("`@('L*("`@("`@("!E8VAO("(\+V9O<FT^7&XB.PH@("`@("`@
M(&EF("@D9F]C=7,@)B8@(65M<'1Y*"1T:&ES+3Y?9FER<W1&:65L9"DI('L*
M("`@("`@("`@("`@96-H;R`G/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I
M<'0B/@H\(2TM"G1R>2!["B`@("!D;V-U;65N="YG971%;&5M96YT0GE)9"@B
M)R`N("1T:&ES+3Y?9FER<W1&:65L9"`N("<B*2YF;V-U<R@I.PI](&-A=&-H
M*&4I('M]"B\O+2T^"CPO<V-R:7!T/@HG.PH@("`@("`@('T*("`@('T*"B`@
M("!F=6YC=&EO;B!L:7-T1F]R;59A<G,H)B1F;W)M*0H@("`@>PH@("`@("`@
M("1V87)I86)L97,@/2`F)&9O<FTM/F=E=%9A<FEA8FQE<RAT<G5E+"!T<G5E
M*3L*("`@("`@("`D=F%R<R`](&%R<F%Y*"D["B`@("`@("`@:68@*"1V87)I
M86)L97,I('L*("`@("`@("`@("`@9F]R96%C:"`H)'9A<FEA8FQE<R!A<R`D
M=F%R*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?;V)J96-T*"1V87(I*2![
M"B`@("`@("`@("`@("`@("`@("`@:68@*"$D=F%R+3YI<U)E861O;FQY*"DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)'9A<G-;)'9A<BT^9V5T5F%R
M3F%M92@I72`](#$["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=F%R<ULD=F%R
M72`](#$["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92].3%,N<&AP)SL*("`@
M("`@("!E8VAO("<\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)?9F]R;79A
M<G,B('9A;'5E/2(G("X@0&AT;6QS<&5C:6%L8VAA<G,H<V5R:6%L:7IE*"1V
M87)S*2P@14Y47U%53U1%4RP@3DQ3.CIG971#:&%R<V5T*"DI("X@)R(@+SXG
M.PH@("`@?0H*("`@(&9U;F-T:6]N(')E;F1E<D9O<FU!8W1I=F4H)B1F;W)M
M+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'1H:7,M/E]R96YD97)&;W)M*"1F
M;W)M+"`D=F%R<RP@=')U92D["B`@("!]"@H@("`@9G5N8W1I;VX@<F5N9&5R
M1F]R;4EN86-T:79E*"8D9F]R;2P@)B1V87)S*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?<F5N9&5R1F]R;2@D9F]R;2P@)'9A<G,L(&9A;'-E*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!?<F5N9&5R1F]R;2@F)&9O<FTL("8D=F%R<RP@)&%C
M=&EV92D*("`@('L*("`@("`@("`O*B!)9B!H96QP(&ES('!R97-E;G0@,R!C
M;VQU;6YS(&%R92!N965D960N("HO"B`@("`@("`@)'1H:7,M/E]C;VQS(#T@
M)&9O<FTM/FAA<TAE;'`H*2`_(#,@.B`R.PH*("`@("`@("`D=F%R:6%B;&5S
M(#T@)B1F;W)M+3YG971687)I86)L97,H9F%L<V4I.PH*("`@("`@("`O*B!#
M:&5C:R!F;W(@82!F;W)M('1O:V5N(&5R<F]R+B`J+PH@("`@("`@(&EF("@H
M)'1O:V5N17)R;W(@/2`D9F]R;2T^9V5T17)R;W(H)U]?9F]R;51O:V5N)RDI
M("$]/2!N=6QL*2!["B`@("`@("`@("`@('!R:6YT9B@G/'1R('9A;&EG;CTB
M=&]P(CX\=&0@8V]L<W!A;CTB)60B/CQS<&%N(&-L87-S/2)F;W)M+65R<F]R
M(CXE<SPO<W!A;CX\+W1D/CPO='(^)RP*("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?8V]L<RP*("`@("`@("`@("`@("`@("`@("1T;VME;D5R<F]R*3L*
M("`@("`@("!]"@H@("`@("`@("1E<G)O<E]S96-T:6]N(#T@;G5L;#L*("`@
M("`@("!R97-E="@D=F%R:6%B;&5S*3L*("`@("`@("!I9B`H8V]U;G0H)'9A
M<FEA8FQE<RD@/B`Q('Q\(&ME>2@D=F%R:6%B;&5S*2`A/2`G7U]B87-E)RD@
M>PH@("`@("`@("`@("`D=&AI<RT^7W)E;F1E<E-E8W1I;VY486)S*"1F;W)M
M*3L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1V87)I86)L97,@87,@
M)'-E8W1I;VY?:60@/3X@)'-E8W1I;VXI('L*("`@("`@("`@("`@)'1H:7,M
M/E]R96YD97)396-T:6]N0F5G:6XH)&9O<FTL("1S96-T:6]N7VED*3L*("`@
M("`@("`@("`@9F]R96%C:"`H)'-E8W1I;VX@87,@)'9A<BD@>PH@("`@("`@
M("`@("`@("`@)'1Y<&4@/2`D=F%R+3YG9714>7!E3F%M92@I.PH*("`@("`@
M("`@("`@("`@('-W:71C:"`H)'1Y<&4I('L*("`@("`@("`@("`@("`@(&-A
M<V4@)VAE861E<B<Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R96YD
M97)(96%D97(H)'9A<BT^9V5T2'5M86Y.86UE*"DL("1F;W)M+3YG971%<G)O
M<B@D=F%R+3YG971687).86UE*"DI*3L*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=D97-C<FEP=&EO;B<Z"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R96YD97)$97-C<FEP=&EO;B@D
M=F%R+3YG971(=6UA;DYA;64H*2D["B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("`@("`@8V%S92`G<W!A8V5R)SH*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W)E;F1E<E-P86-E<B@I.PH@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&1E9F%U;'0Z"B`@
M("`@("`@("`@("`@("`@("`@)&ES26YP=70@/2`H)&%C=&EV92`F)B`A)'9A
M<BT^:7-296%D;VYL>2@I*3L*("`@("`@("`@("`@("`@("`@("`D9F]R;6%T
M(#T@)&ES26YP=70@/R`G26YP=70G(#H@)T1I<W!L87DG.PH@("`@("`@("`@
M("`@("`@("`@("1B96=I;B`](")?<F5N9&5R5F%R)'MF;W)M871]0F5G:6XB
M.PH@("`@("`@("`@("`@("`@("`@("1E;F0@/2`B7W)E;F1E<E9A<B1[9F]R
M;6%T?45N9"(["@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3XD8F5G:6XH
M)&9O<FTL("1V87(L("1V87)S*3L*"B`@("`@("`@("`@("`@("`@("`@96-H
M;R`D=&AI<RT^7W9A<E)E;F1E<F5R+3YR96YD97(H)&9O<FTL("1V87(L("1V
M87)S+"`D:7-);G!U="D["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/B1E
M;F0H)&9O<FTL("1V87(L("1V87)S*3L*"B`@("`@("`@("`@("`@("`@("`@
M+RH@4')I;G0@86YY(&IA=F%S8W)I<'0@:68@86-T:6]N<R!P<F5S96YT+B`J
M+PH@("`@("`@("`@("`@("`@("`@(&EF("@D=F%R+3YH87-!8W1I;VXH*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D=F%R+3Y?86-T:6]N+3YP<FEN
M=$IA=F%38W)I<'0H*3L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@("`@("\J($ME97`@9FER<W0@9FEE;&0N("HO"B`@("`@("`@
M("`@("`@("`@("`@:68@*"1A8W1I=F4@)B8@96UP='DH)'1H:7,M/E]F:7)S
M=$9I96QD*2`F)B`A)'9A<BT^:7-296%D;VYL>2@I("8F("$D=F%R+3YI<TAI
M9&1E;B@I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9FER
M<W1&:65L9"`]("1V87(M/F=E=%9A<DYA;64H*3L*("`@("`@("`@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`@("`@("`@("\J($ME97`@<V5C=&EO;B!W
M:71H(&9I<G-T(&5R<F]R+B`J+PH@("`@("`@("`@("`@("`@("`@(&EF("AI
M<U]N=6QL*"1E<G)O<E]S96-T:6]N*2`F)B`D9F]R;2T^9V5T17)R;W(H)'9A
M<BDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&5R<F]R7W-E8W1I;VX@
M/2`D<V5C=&EO;E]I9#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?
M<F5N9&5R4V5C=&EO;D5N9"@I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I
M<U]N=6QL*"1E<G)O<E]S96-T:6]N*2`F)B`D9F]R;2T^7W-E8W1I;VYS*2![
M"B`@("`@("`@("`@(&5C:&\@)SQS8W)I<'0@='EP93TB=&5X="]J879A<V-R
M:7!T(CXG("X*("`@("`@("`@("`@("`@(")<;B(@+B!S<')I;G1F*"=S96-T
M:6]N<U\E<RYT;V=G;&4H7"<E<UPG*3LG+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&9O<FTM/F=E=$YA;64H*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1E<G)O<E]S96-T:6]N*2`N"B`@("`@("`@("`@
M("`@("`B7&X\+W-C<FEP=#XB.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC
M=&EO;B!S=6)M:70H)'-U8FUI="`](&YU;&PL("1R97-E="`](&9A;'-E*0H@
M("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1S=6)M:70I('Q\(&5M<'1Y*"1S
M=6)M:70I*2!["B`@("`@("`@("`@("1S=6)M:70@/2!?*")3=6)M:70B*3L*
M("`@("`@("!]"B`@("`@("`@:68@*"1R97-E="`]/3T@=')U92D@>PH@("`@
M("`@("`@("`D<F5S970@/2!?*")297-E="(I.PH@("`@("`@('T*("`@("`@
M("`D=&AI<RT^7W)E;F1E<E-U8FUI="@D<W5B;6ET+"`D<F5S970I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@26UP;&5M96YT871I;VX@<W!E8VEF:6,@8F5G
M:6X@9G5N8W1I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]R96YD97)"96=I
M;D%C=&EV92@D;F%M92P@)&5X=')A*0H@("`@>PH@("`@("`@(&5C:&\@)SQD
M:78@8VQA<W,](F9O<FTB(&ED/2(G("X@:'1M;'-P96-I86QC:&%R<R@D=&AI
M<RT^7VYA;64I("X@)R(^)SL*("`@("`@("!I9B`H)'1H:7,M/E]S:&]W2&5A
M9&5R*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V5C=&EO;DAE861E<B@D;F%M
M92P@)&5X=')A*3L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3Y?<F5Q
M=6ER961,96=E;F0I('L*("`@("`@("`@("`@96-H;R`G/'-P86X@8VQA<W,]
M(F9O<FTM97)R;W(B/B<@+B`D=&AI<RT^7W)E<75I<F5D36%R:V5R("X@)SPO
M<W!A;CX@/2`G("X@7R@B4F5Q=6ER960@1FEE;&0B*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!);7!L96UE;G1A=&EO;B!S<&5C:69I8R!B
M96=I;B!F=6YC=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@7W)E;F1E<D)E
M9VEN26YA8W1I=F4H)&YA;64L("1E>'1R82D*("`@('L*("`@("`@("!E8VAO
M("<\9&EV(&-L87-S/2)F;W)M(B!I9#TB)R`N(&AT;6QS<&5C:6%L8VAA<G,H
M)'1H:7,M/E]N86UE*2`N("<B/B<["B`@("`@("`@:68@*"1T:&ES+3Y?<VAO
M=TAE861E<BD@>PH@("`@("`@("`@("`D=&AI<RT^7W-E8W1I;VY(96%D97(H
M)&YA;64L("1E>'1R82D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@26UP;&5M96YT871I;VX@<W!E8VEF:6,@96YD(&9U;F-T:6]N+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?<F5N9&5R16YD*"D*("`@('L*("`@("`@("!E
M8VAO("<\+V1I=CXG("X@)'1H:7,M/E]V87)296YD97)E<BT^<F5N9&5R16YD
M*"D["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<DAE861E<B@D:&5A9&5R
M+"`D97)R;W(@/2`G)RD*("`@('L*/SX\='(^/'1D(&-L87-S/2)C;VYT<F]L
M(B!W:61T:#TB,3`P)2(@8V]L<W!A;CTB/#]P:'`@96-H;R`D=&AI<RT^7V-O
M;',@/SXB('9A;&EG;CTB8F]T=&]M(CX\<W1R;VYG/CP_<&AP(&5C:&\@)&AE
M861E<B`_/CPO<W1R;VYG/CP_<&AP"B`@("`@("`@:68@*"%E;7!T>2@D97)R
M;W(I*2!["C\^/&)R("\^/'-P86X@8VQA<W,](F9O<FTM97)R;W(B/CP_<&AP
M(&5C:&\@)&5R<F]R(#\^/"]S<&%N/CP_<&AP"B`@("`@("`@?0H_/CPO=&0^
M/"]T<CX*/#]P:'`*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R1&5S8W)I
M<'1I;VXH)'1E>'0I"B`@("!["C\^/'1R/CQT9"!W:61T:#TB,3`P)2(@8V]L
M<W!A;CTB/#]P:'`@96-H;R`D=&AI<RT^7V-O;',@/SXB/CQP('-T>6QE/2)P
M861D:6YG.CAP>"(^/#]P:'`@96-H;R`D=&5X="`_/CPO<#X\+W1D/CPO='(^
M"CP_<&AP"B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E-P86-E<B@I"B`@
M("!["C\^/'1R/CQT9"!C;VQS<&%N/2(\/W!H<"!E8VAO("1T:&ES+3Y?8V]L
M<R`_/B(^)FYB<W`[/"]T9#X\+W1R/@H\/W!H<`H@("`@?0H*("`@(&9U;F-T
M:6]N(%]R96YD97)3=6)M:70H)'-U8FUI="P@)')E<V5T*0H@("`@>PH_/CQD
M:78@8VQA<W,](F-O;G1R;VPB/@H@(#P_<&AP(&EF("@A:7-?87)R87DH)'-U
M8FUI="DI("1S=6)M:70@/2!A<G)A>2@D<W5B;6ET*3L@9F]R96%C:"`H)'-U
M8FUI="!A<R`D<W5B;6ET8G5T=&]N*3H@/SX*("`@(#QI;G!U="!C;&%S<STB
M8G5T=&]N(B!N86UE/2)S=6)M:71B=71T;VXB('1Y<&4](G-U8FUI="(@=F%L
M=64](CP_<&AP(&5C:&\@)'-U8FUI=&)U='1O;B`_/B(@+SX*("`\/W!H<"!E
M;F1F;W)E86-H.R`_/@H@(#P_<&AP(&EF("@A96UP='DH)')E<V5T*2DZ(#\^
M"B`@("`\:6YP=70@8VQA<W,](F)U='1O;B(@;F%M93TB<F5S971B=71T;VXB
M('1Y<&4](G)E<V5T(B!V86QU93TB/#]P:'`@96-H;R`D<F5S970@/SXB("\^
M"B`@/#]P:'`@96YD:68[(#\^"CPO9&EV/@H\/W!H<`H@("`@?0H*("`@("\O
M($EM<&QE;65N=&%T:6]N('-P96-I9FEC<R`M+2!I;G!U="!V87)I86)L97,N
M"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71"96=I;B@F)&9O<FTL("8D
M=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)&UE<W-A9V4@/2`D9F]R;2T^
M9V5T17)R;W(H)'9A<BD["B`@("`@("`@)&ES=F%L:60@/2!E;7!T>2@D;65S
M<V%G92D["B`@("`@("`@96-H;R`B/'1R('9A;&EG;CU<(G1O<%PB/EQN(CL*
M("`@("`@("!P<FEN=&8H)R`@/'1D)7,@86QI9VX](G)I9VAT(CXE<R5S)7,E
M<SPO=&0^)R`N(")<;B(L"B`@("`@("`@("`@("`@(&5M<'1Y*"1T:&ES+3Y?
M871T<D-O;'5M;E=I9'1H*2`_("<G(#H@)R!W:61T:#TB)R`N("1T:&ES+3Y?
M871T<D-O;'5M;E=I9'1H("X@)R(G+`H@("`@("`@("`@("`@("`D:7-V86QI
M9"`_("<G(#H@)SQS<&%N(&-L87-S/2)F;W)M+65R<F]R(CXG+`H@("`@("`@
M("`@("`@("`D=F%R+3YI<U)E<75I<F5D*"D@/R`G/'-P86X@8VQA<W,](F9O
M<FTM97)R;W(B/B<@+B`D=&AI<RT^7W)E<75I<F5D36%R:V5R("X@)SPO<W!A
M;CXF;F)S<#LG(#H@)R<L"B`@("`@("`@("`@("`@("1V87(M/F=E=$AU;6%N
M3F%M92@I+`H@("`@("`@("`@("`@("`D:7-V86QI9"`_("<G(#H@)SQB<B`O
M/B<@+B`D;65S<V%G92`N("<\+W-P86X^)RD["B`@("`@("`@<')I;G1F*"<@
M(#QT9"5S/B<L"B`@("`@("`@("`@("`@("@H(21V87(M/FAA<TAE;'`H*2`F
M)B`D9F]R;2T^:&%S2&5L<"@I*2`_("<@8V]L<W!A;CTB,B(G(#H@)R<I*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71%;F0H)B1F;W)M
M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@("\J($1I<W!L87D@86YY
M(&1E<V-R:7!T:6]N(&9O<B!T:&4@9FEE;&0N("HO"B`@("`@("`@:68@*"1V
M87(M/FAA<T1E<V-R:7!T:6]N*"DI('L*("`@("`@("`@("`@96-H;R`G/&)R
M("\^)R`N("1V87(M/F=E=$1E<V-R:7!T:6]N*"D["B`@("`@("`@?0H*("`@
M("`@("`O*B!$:7-P;&%Y(&%N>2!H96QP(&9O<B!T:&4@9FEE;&0N("HO"B`@
M("`@("`@:68@*"1V87(M/FAA<TAE;'`H*2D@>PH@("`@("`@("`@("!G;&]B
M86P@)')E9VES=')Y.PH@("`@("`@("`@("!I9B`H:7-S970H)')E9VES=')Y
M*2`F)B!I<U]A*"1R96=I<W1R>2P@)U)E9VES=')Y)RDI('L*("`@("`@("`@
M("`@("`@("1L:6YK(#T@2&5L<#HZ;&EN:R@D1TQ/0D%,4ULG<F5G:7-T<GDG
M72T^9V5T07!P*"DL("1V87(M/F=E=$AE;'`H*2D["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D;&EN:R`]("<\82!H<F5F/2(C(B!O
M;F-L:6-K/2)A;&5R="A<)R<@+B!A9&1S;&%S:&5S*$!H=&UL<W!E8VEA;&-H
M87)S*"1V87(M/F=E=$AE;'`H*2DI("X@)UPG*3MR971U<FX@9F%L<V4[(CXG
M("X@)'1H:7,M/E]H96QP36%R:V5R("X@)SPO83XG.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&5C:&\@(CPO=&0^7&X@(#QT9"!S='EL93U<(G1E>'0M
M86QI9VXZ<FEG:'1<(CXD;&EN:R9N8G-P.R(["B`@("`@("`@?0H*("`@("`@
M("!E8VAO("(\+W1D/EQN/"]T<CY<;B(["B`@("!]"@H@("`@+R\@26UP;&5M
M96YT871I;VX@<W!E8VEF:6-S("TM(&1I<W!L87D@=F%R:6%B;&5S+@H@("`@
M9G5N8W1I;VX@7W)E;F1E<E9A<D1I<W!L87E"96=I;B@F)&9O<FTL("8D=F%R
M+"`F)'9A<G,I"B`@("!["B`@("`@("`@)&UE<W-A9V4@/2`D9F]R;2T^9V5T
M17)R;W(H)'9A<BD["B`@("`@("`@)&ES=F%L:60@/2!E;7!T>2@D;65S<V%G
M92D["B`@("`@("`@96-H;R`B/'1R('9A;&EG;CU<(G1O<%PB/EQN(CL*("`@
M("`@("!P<FEN=&8H)R`@/'1D)7,@86QI9VX](G)I9VAT(CXE<SQS=')O;F<^
M)7,\+W-T<F]N9SXE<SPO=&0^)R`N(")<;B(L"B`@("`@("`@("`@("`@(&5M
M<'1Y*"1T:&ES+3Y?871T<D-O;'5M;E=I9'1H*2`_("<G(#H@)R!W:61T:#TB
M)R`N("1T:&ES+3Y?871T<D-O;'5M;E=I9'1H("X@)R(G+`H@("`@("`@("`@
M("`@("`D:7-V86QI9"`_("<G(#H@)SQS<&%N(&-L87-S/2)F;W)M+65R<F]R
M(CXG+`H@("`@("`@("`@("`@("`D=F%R+3YG971(=6UA;DYA;64H*2P*("`@
M("`@("`@("`@("`@)&ES=F%L:60@/R`G)R`Z("<\8G(@+SXG("X@)&UE<W-A
M9V4@+B`G/"]S<&%N/B<I.PH@("`@("`@(&5C:&\@)R`@/'1D/B<["B`@("!]
M"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<D1I<W!L87E%;F0H)B1F;W)M+"`F
M)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@(&5C:&\@(CPO=&0^7&X\+W1R
M/EQN(CL*("`@('T*"B`@("!F=6YC=&EO;B!?<V5C=&EO;DAE861E<B@D=&ET
M;&4L("1E>'1R82`]("<G*0H@("`@>PH@("`@("`@(&EF("AS=')L96XH)'1I
M=&QE*2D@>PH@("`@("`@("`@("!E8VAO("<\9&EV(&-L87-S/2)H96%D97(B
M/B<["B`@("`@("`@("`@(&EF("@A96UP='DH)&5X=')A*2D@>PH@("`@("`@
M("`@("`@("`@96-H;R`G/'-P86X@<W1Y;&4](F9L;V%T.G)I9VAT(CXG("X@
M)&5X=')A("X@)SPO<W!A;CXG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5C:&\@)'1H:7,M/E]E;F-O9&54:71L92`_(&AT;6QS<&5C:6%L8VAA<G,H
M)'1I=&QE*2`Z("1T:71L93L*("`@("`@("`@("`@96-H;R`G/"]D:78^)SL*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R
M971U<FX@82!C;VYC<F5T92!(;W)D95]&;W)M7U)E;F1E<F5R(&EN<W1A;F-E
M(&)A<V5D(&]N"B`@("`@*B`D<F5N9&5R97(N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&UI>&5D("1R96YD97)E<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@2&]R
M9&5?1F]R;5]296YD97)E<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@<W5B8VQA<W,@=&\@<F5T=7)N+B!4:&4@8V]D92!I<R!D>6YA;6EC86QL
M>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@:6YC;'5D960N($EF
M("1R96YD97)E<B!I<R!A;B!A<G)A>2P@=&AE;B!W92!W:6QL"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!L;V]K(&EN("1R96YD97)E<ELP72]L
M:6(O1F]R;2]296YD97)E<B\@9F]R('1H90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@<W5B8VQA<W,@:6UP;&5M96YT871I;VX@;F%M960@)')E
M;F1E<F5R6S%=+G!H<"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@
M($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I
M;VX@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@9F]R;2!M:6=H
M="!N965D+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?1F]R;5]296YD
M97)E<B`@5&AE(&-O;F-R971E($AO<F1E7T9O<FU?4F5N9&5R97(@<F5F97)E
M;F-E+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!O<B!F
M86QS92!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O
M<GDH)')E;F1E<F5R+"`D<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@("!I
M9B`H:7-?87)R87DH)')E;F1E<F5R*2D@>PH@("`@("`@("`@("`D87!P(#T@
M)')E;F1E<F5R6S!=.PH@("`@("`@("`@("`D<F5N9&5R97(@/2`D<F5N9&5R
M97);,5T["B`@("`@("`@?0H*("`@("`@("`O*B!2971U<FX@82!B87-E($AO
M<F1E7T9O<FU?4F5N9&5R97(@;V)J96-T(&EF(&YO(&1R:79E<B!I<PH@("`@
M("`@("`J('-P96-I9FEE9"X@*B\*("`@("`@("`D<F5N9&5R97(@/2!B87-E
M;F%M92@D<F5N9&5R97(I.PH@("`@("`@(&EF("AE;7!T>2@D<F5N9&5R97(I
M('Q\("AS=')C;7`H)')E;F1E<F5R+"`G;F]N92<I(#T](#`I*2!["B`@("`@
M("`@("`@("1F;W)M<F5N9&5R97(@/2`F;F5W($AO<F1E7T9O<FU?4F5N9&5R
M97(H)'!A<F%M<RD["B`@("`@("`@("`@(')E='5R;B`D9F]R;7)E;F1E<F5R
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D87!P*2D@>PH@("`@
M("`@("`@("!I;F-L=61E7V]N8V4@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E
M="@G9FEL97)O;W0G+"`D87!P*2`N("<O;&EB+T9O<FTO4F5N9&5R97(O)R`N
M("1R96YD97)E<B`N("<N<&AP)SL*("`@("`@("!](&5L<V5I9B`H0&9I;&5?
M97AI<W1S*&1I<FYA;64H7U]&24Q%7U\I("X@)R]296YD97)E<B\G("X@)')E
M;F1E<F5R("X@)RYP:'`G*2D@>PH@("`@("`@("`@("!I;F-L=61E7V]N8V4@
M9&ER;F%M92A?7T9)3$5?7RD@+B`G+U)E;F1E<F5R+R<@+B`D<F5N9&5R97(@
M+B`G+G!H<"<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@0&EN8VQU
M9&5?;VYC92`G2&]R9&4O1F]R;2]296YD97)E<B\G("X@)')E;F1E<F5R("X@
M)RYP:'`G.PH@("`@("`@('T*("`@("`@("`D8VQA<W,@/2`G2&]R9&5?1F]R
M;5]296YD97)E<E\G("X@)')E;F1E<F5R.PH@("`@("`@(&EF("AC;&%S<U]E
M>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D9F]R;7)E;F1E<F5R(#T@
M)FYE=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&9O<FUR96YD97)E<B`](%!%05(Z.G)A:7-E17)R;W(H)T-L87-S
M(&1E9FEN:71I;VX@;V8@)R`N("1C;&%S<R`N("<@;F]T(&9O=6YD+B<I.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1F;W)M<F5N9&5R97(["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!R969E<F5N
M8V4@=&\@82!C;VYC<F5T92!(;W)D95]&;W)M7U)E;F1E<F5R"B`@("`@*B!I
M;G-T86YC92!B87-E9"!O;B`D<F5N9&5R97(N($ET('=I;&P@;VYL>2!C<F5A
M=&4@82!N97<@:6YS=&%N8V4@:68@;F\*("`@("`J($AO<F1E7T9O<FU?4F5N
M9&5R97(@:6YS=&%N8V4@=VET:"!T:&4@<V%M92!P87)A;65T97)S(&-U<G)E
M;G1L>2!E>&ES=',N"B`@("`@*@H@("`@("H@5&AI<R!S:&]U;&0@8F4@=7-E
M9"!I9B!M=6QT:7!L92!T>7!E<R!O9B!F;W)M(')E;F1E<F5R<R`H86YD+`H@
M("`@("H@=&AU<RP@;75L=&EP;&4@2&]R9&5?1F]R;5]296YD97)E<B!I;G-T
M86YC97,I(&%R92!R97%U:7)E9"X*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO
M9"!M=7-T(&)E(&EN=F]K960@87,Z("1V87(@/2`F2&]R9&5?1F]R;5]296YD
M97)E<CHZ<VEN9VQE=&]N*"D*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@
M)')E;F1E<F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!(;W)D95]&;W)M7U)E
M;F1E<F5R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!S=6)C;&%S
M<R!T;R!R971U<FXN(%1H92!C;V1E(&ES(&1Y;F%M:6-A;&QY"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!I;F-L=61E9"X@268@)')E;F1E<F5R
M(&ES(&%N(&%R<F%Y+"!T:&5N('=E('=I;&P*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@(&QO;VL@:6X@)')E;F1E<F5R6S!=+VQI8B]&;W)M+U)E
M;F1E<F5R+R!F;W(@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("!S=6)C;&%S<R!I;7!L96UE;G1A=&EO;B!N86UE9"`D<F5N9&5R97);,5TN
M<&AP+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT
M86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@80H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@(&9O<FT@;6EG:'0@;F5E9"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N($AO<F1E7T9O<FU?4F5N9&5R97(@(%1H92!C;VYC
M<F5T92!(;W)D95]&;W)M7U)E;F1E<F5R(')E9F5R96YC92P*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@;W(@9F%L<V4@;VX@86X@97)R
M;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)')E;F1E<F5R
M+"`D<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@("!S=&%T:6,@)&EN<W1A
M;F-E<SL*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97,I*2!["B`@("`@
M("`@("`@("1I;G-T86YC97,@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@
M("`@)'-I9VYA='5R92`]('-E<FEA;&EZ92AA<G)A>2@D<F5N9&5R97(L("1P
M87)A;7,I*3L*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97-;)'-I9VYA
M='5R95TI*2!["B`@("`@("`@("`@("1I;G-T86YC97-;)'-I9VYA='5R95T@
M/2`F2&]R9&5?1F]R;5]296YD97)E<CHZ9F%C=&]R>2@D<F5N9&5R97(L("1P
M87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;
M)'-I9VYA='5R95T["B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U1O:V5N````````````
M````````````````````````````````````````````````````````````
M`````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P
M-3$U-#,S-S,V(#`R,#,U,@`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O5&]K96XO9FEL92YP:'``````````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,3`V-#0@,3`U,34T,S,W,S8@,#(R,#8V`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B!4
M;VME;B!T<F%C:VEN9R!I;7!L96UE;G1A=&EO;B!F;W(@;&]C86P@9FEL97,N
M"B`J"B`J($]P=&EO;F%L('!A<F%M971E<G,Z/'!R93X*("H@("`G=&]K96Y?
M9&ER)R`@5&AE(&1I<F5C=&]R>2!W:&5R92!T;R!K965P('1O:V5N(&9I;&5S
M+@H@*B`@("=T:6UE;W5T)R`@("!4:&4@<&5R:6]D("AI;B!S96-O;F1S*2!A
M9G1E<B!W:&EC:"!A;B!I9"!I<R!P=7)G960N"B`J("`@("`@("`@("`@("`@
M($1E9F%U;'1S('1O(#@V-#`P("AI+F4N(#(T(&AO=7)S*2X\+W!R93X*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO5&]K96XO5&]K96XO9FEL92YP:'`L=B`Q
M+C$Y+C8N-R`R,#`V+S`Q+S`Q(#(Q.C(X.C,Y(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,3DY.2TR,#`V($UA>"!+86QI:V$@/&UA>$!H;W)D92YO<F<^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-87@@2V%L:6MA(#QM87A`
M:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@
M2&]R9&5?5&]K96X*("HO"F-L87-S($AO<F1E7U1O:V5N7V9I;&4@97AT96YD
M<R!(;W)D95]4;VME;B!["@H@("`@+RHJ"B`@("`@*B!(86YD;&4@9F]R('1H
M92!O<&5N(&9I;&4@9&5S8W)I<'1O<BX*("`@("`J"B`@("`@*B!`=F%R(')E
M<V]U<F-E"B`@("`@*B\*("`@('9A<B`D7V9D(#T@9F%L<V4["@H@("`@+RHJ
M"B`@("`@*B!";V]L96%N(&EN9&EC871I;F<@=VAE=&AE<B!O<B!N;W0@=V4@
M:&%V92!A;B!O<&5N(&9I;&4@9&5S8W)I<'1O<BX*("`@("`J"B`@("`@*B!`
M=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?8V]N;F5C=&5D(#T@9F%L
M<V4["@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@82!N97<@9FEL92!B87-E9"!T
M;VME;BUT<F%C:VEN9R!C;VYT86EN97(N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG('-T;W)A9V4@<&%R
M86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?5&]K96Y?9FEL
M92@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^7W!A
M<F%M<R`]("1P87)A;7,["@H@("`@("`@("\J($-H;V]S92!T:&4@9&ER96-T
M;W)Y('1O('-A=F4@=&AE('-T=6(@9FEL97,N("HO"B`@("`@("`@:68@*"%I
M<W-E="@D=&AI<RT^7W!A<F%M<ULG=&]K96Y?9&ER)UTI*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=T;VME;E]D:7(G72`](%5T:6PZ.F=E=%1E
M;7!$:7(H*3L*("`@("`@("!]"@H@("`@("`@("\J(%-E="!T:6UE;W5T('1O
M(#(T(&AO=7)S(&EF(&YO="!S<&5C:69I960N("HO"B`@("`@("`@:68@*"%I
M<W-E="@D=&AI<RT^7W!A<F%M<ULG=&EM96]U="==*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULG=&EM96]U="==(#T@.#8T,#`["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E<R!A;&P@97AP:7)E9"!C
M;VYN96-T:6]N(&ED)W,@9G)O;2!T:&4@4U%,('-E<G9E<BX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@5')U92!O;B!S=6-C97-S+"!A(%!%05)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('!U<F=E*"D*("`@('L*("`@("`@("`O+R!-86ME('-U<F4@=V4@:&%V92!N
M;R!O<&5N(&9I;&4@9&5S8W)I<'1O<G,@8F5F;W)E('5N;&EN:VEN9PH@("`@
M("`@("\O(&9I;&5S+@H@("`@("`@(&EF("@A)'1H:7,M/E]D:7-C;VYN96-T
M*"DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U5N
M86)L92!T;R!C;&]S92!F:6QE(&1E<V-R:7!T;W)S)RD["B`@("`@("`@?0H*
M("`@("`@("`O*B!"=6EL9"!S='5B(&9I;&4@;&ES="X@*B\*("`@("`@("!I
M9B`H(2@D9&ER(#T@;W!E;F1I<B@D=&AI<RT^7W!A<F%M<ULG=&]K96Y?9&ER
M)UTI*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G
M56YA8FQE('1O(&]P96X@=&]K96X@9&ER96-T;W)Y)RD["B`@("`@("`@?0H*
M("`@("`@("`O*B!&:6YD(&5X<&ER960@<W1U8B!F:6QE<R`J+PH@("`@("`@
M('=H:6QE("@H)&1I<D5N=')Y(#T@<F5A9&1I<B@D9&ER*2D@(3T@)R<I('L*
M("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)WQ>8V]N;E]<=WLX?21\)RP@
M)&1I<D5N=')Y*2`F)B`H=&EM92@I("T@9FEL96UT:6UE*"1T:&ES+3Y?<&%R
M86US6R=T;VME;E]D:7(G72`N("<O)R`N("1D:7)%;G1R>2D@/CT@)'1H:7,M
M/E]P87)A;7-;)W1I;65O=70G72DI('L*("`@("`@("`@("`@("`@(&EF("@A
M0'5N;&EN:R@D=&AI<RT^7W!A<F%M<ULG=&]K96Y?9&ER)UT@+B`G+R<@+B`D
M9&ER16YT<GDI*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H)U5N86)L92!T;R!P=7)G92!T;VME;B!F:6QE+B<I.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!C;&]S961I<B@D9&ER*3L*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("!F=6YC=&EO;B!E>&ES=',H)'1O:V5N240I"B`@("!["B`@("`@
M("`@:68@*&ES7V$H*"1R97-U;'0@/2`D=&AI<RT^7V-O;FYE8W0H)'1O:V5N
M240I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("!]"@H@("`@("`@("\J($9I;F0@86QR96%D>2!U<V5D
M($E$<RX@*B\*("`@("`@("`D9FEL94-O;G1E;G1S(#T@0&9I;&4H)'1H:7,M
M/E]P87)A;7-;)W1O:V5N7V1I<B==("X@)R]C;VYN7R<@+B`D=&AI<RT^96YC
M;V1E4F5M;W1E061D<F5S<R@I*3L*("`@("`@("!I9B`H)&9I;&5#;VYT96YT
M<RD@>PH@("`@("`@("`@("`D:4UA>"`](&-O=6YT*"1F:6QE0V]N=&5N=',I
M.PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D:4UA>#L@)&DK*RD@
M>PH@("`@("`@("`@("`@("`@:68@*&-H;W`H)&9I;&5#;VYT96YT<ULD:5TI
M(#T]("1T;VME;DE$*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R
M=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("!F=6YC=&EO;B!A
M9&0H)'1O:V5N240I"B`@("!["B`@("`@("`@:68@*&ES7V$H*"1R97-U;'0@
M/2`D=&AI<RT^7V-O;FYE8W0H)'1O:V5N240I*2P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@
M("`@("\J(%=R:71E('1H92!E;G1R>2X@*B\*("`@("`@("!F=W)I=&4H)'1H
M:7,M/E]F9"P@(B1T;VME;DE$7&XB*3L*"B`@("`@("`@+RH@4F5T=7)N(&%N
M(&5R<F]R(&EF('1H92!U<&1A=&4@9F%I;',L('1O;RX@*B\*("`@("`@("!I
M9B`H(21T:&ES+3Y?9&ES8V]N;F5C="@I*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"=&86EL960@=&\@8VQO<V4@=&]K96X@9FEL
M92!C;&5A;FQY+B<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!/<&5N<R!A(&9I;&4@9&5S8W)I<'1O
M<B!T;R!A(&YE=R!O<B!E>&ES=&EN9R!F:6QE+@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!A(%!%05)?17)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYN
M96-T*"1T;VME;DE$*0H@("`@>PH@("`@("`@(&EF("@A)'1H:7,M/E]C;VYN
M96-T960I('L*"B`@("`@("`@("`@("\O($]P96X@82!F:6QE(&1E<V-R:7!T
M;W(@=&\@=&AE('1O:V5N('-T=6(@9FEL92X*("`@("`@("`@("`@)'1H:7,M
M/E]F9"`]($!F;W!E;B@D=&AI<RT^7W!A<F%M<ULG=&]K96Y?9&ER)UT@+B`G
M+V-O;FY?)R`N("1T:&ES+3YE;F-O9&5296UO=&5!9&1R97-S*"DL("=A)RD[
M"B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]F9"D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T9A:6QE9"!T;R!O<&5N('1O
M:V5N(&9I;&4N)RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES
M+3Y?8V]N;F5C=&5D(#T@=')U93L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@0VQO<V5S('1H92!F:6QE
M(&1E<V-R:7!T;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]D:7-C;VYN96-T*"D*("`@('L*("`@("`@("!I9B`H)'1H
M:7,M/E]C;VYN96-T960I('L*("`@("`@("`@("`@)'1H:7,M/E]C;VYN96-T
M960@/2!F86QS93L*("`@("`@("`@("`@<F5T=7)N(&9C;&]S92@D=&AI<RT^
M7V9D*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]4;VME;B]S
M<6PN<&AP````````````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q
M-#(T,"`Q,#4Q-30S,S<S-B`P,C$W-#(`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%1O:V5N('1R86-K
M:6YG(&EM<&QE;65N=&%T:6]N(&9O<B!02%`G<R!014%2(&1A=&%B87-E(&%B
M<W1R86-T:6]N(&QA>65R+@H@*@H@*B!297%U:7)E9"!P87)A;65T97)S.CQP
M<F4^"B`J("`@)W!H<'1Y<&4G("`@5&AE(&1A=&%B87-E('1Y<&4@*&EE+B`G
M<&=S<6PG+"`G;7ES<6PG+"!E=&,N*2X\+W!R93X*("H*("H@4F5Q=6ER960@
M8GD@<V]M92!D871A8F%S92!I;7!L96UE;G1A=&EO;G,Z/'!R93X*("H@("`G
M9&%T86)A<V4G("!4:&4@;F%M92!O9B!T:&4@9&%T86)A<V4N"B`J("`@)VAO
M<W1S<&5C)R`@5&AE(&AO<W1N86UE(&]F('1H92!D871A8F%S92!S97)V97(N
M"B`J("`@)W5S97)N86UE)R`@5&AE('5S97)N86UE('=I=&@@=VAI8V@@=&\@
M8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N"B`J("`@)W!A<W-W;W)D)R`@5&AE
M('!A<W-W;W)D(&%S<V]C:6%T960@=VET:"`G=7-E<FYA;64G+@H@*B`@("=O
M<'1I;VYS)R`@($%D9&ET:6]N86P@;W!T:6]N<R!T;R!P87-S('1O('1H92!D
M871A8F%S92X*("H@("`G='1Y)R`@("`@("!4:&4@5%19(&]N('=H:6-H('1O
M(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+@H@*B`@("=P;W)T)R`@("`@(%1H
M92!P;W)T(&]N('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+CPO
M<')E/@H@*@H@*B!/<'1I;VYA;"!P87)A;65T97)S.CQP<F4^"B`J("`@)W1A
M8FQE)R`@("`@5&AE(&YA;64@;V8@=&AE('1O:V5N<R!T86)L92!I;B`G9&%T
M86)A<V4G+@H@*B`@("`@("`@("`@("`@($1E9F%U;'1S('1O("=H;W)D95]T
M;VME;G,G+@H@*B`@("=T:6UE;W5T)R`@(%1H92!P97)I;V0@*&EN('-E8V]N
M9',I(&%F=&5R('=H:6-H(&%N(&ED(&ES('!U<F=E9"X*("H@("`@("`@("`@
M("`@("!$969A=6QT<R!T;R`X-C0P,"`H:2YE+B`R-"!H;W5R<RDN/"]P<F4^
M"B`J"B`J(%1H92!T86)L92!S=')U8W1U<F4@9F]R('1H92!T;VME;G,@:7,@
M87,@9F]L;&]W<SH*("H*("H@/'!R93X*("H@0U)%051%(%1!0DQ%(&AO<F1E
M7W1O:V5N<R`H"B`J("`@("!T;VME;E]A9&1R97-S("`@(%9!4D-(05(H,3`P
M*2!.3U0@3E5,3"P*("H@("`@('1O:V5N7VED("`@("`@("`@5D%20TA!4B@S
M,BD@3D]4($Y53$PL"B`J("`@("!T;VME;E]T:6UE<W1A;7`@($))1TE.5"!.
M3U0@3E5,3"P*("H*("H@("`@(%!224U!4ED@2T59("AT;VME;E]A9&1R97-S
M+"!T;VME;E]I9"D*("H@*3L*("H@/"]P<F4^"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+U1O:V5N+U1O:V5N+W-Q;"YP:'`L=B`Q+C(S+C8N,3(@,C`P-B\P
M,2\Q."`Q.3HT,#HU,2!B96X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM
M,C`P-B!-87@@2V%L:6MA(#QM87A`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@36%X($MA;&EK82`\;6%X0&AO<F1E+F]R9SX*("H@
M0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E7U1O:V5N"B`J
M+PIC;&%S<R!(;W)D95]4;VME;E]S<6P@97AT96YD<R!(;W)D95]4;VME;B![
M"@H@("`@+RHJ"B`@("`@*B!(86YD;&4@9F]R('1H92!C=7)R96YT(&1A=&%B
M87-E(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@("H@0'9A<B!$0@H@("`@("HO
M"B`@("!V87(@)%]D8B`]("<G.PH*("`@("\J*@H@("`@("H@0F]O;&5A;B!I
M;F1I8V%T:6YG('=H971H97(@;W(@;F]T('=E)W)E(&-O;FYE8W1E9"!T;R!T
M:&4@4U%,"B`@("`@*B!S97)V97(N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L
M96%N"B`@("`@*B\*("`@('9A<B`D7V-O;FYE8W1E9"`](&9A;'-E.PH*("`@
M("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!344P@8V]N;F5C=&EO;B!O
M8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@
M:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@2&]R9&5?5&]K96Y?<W%L*"1P87)A;7,@/2!A<G)A
M>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL*
M"B`@("`@("`@+RH@4V5T('1I;65O=70@=&\@,C0@:&]U<G,@:68@;F]T('-P
M96-I9FEE9"X@*B\*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R86US
M6R=T:6UE;W5T)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T
M:6UE;W5T)UT@/2`X-C0P,#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!$96QE=&5S(&%L;"!E>'!I<F5D(&-O;FYE8W1I;VX@:60G<R!F<F]M
M('1H92!344P@<V5R=F5R+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5')U92!O;B!S=6-C97-S+"!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('!U<F=E*"D*("`@('L*("`@
M("`@("!I9B`H:7-?82@H)')E<W5L="`]("1T:&ES+3Y?8V]N;F5C="@I*2P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@("`@("!]"@H@("`@("`@("\J($)U:6QD(%-13"!Q=65R>2X@*B\*("`@
M("`@("`D<75E<GD@/2`G1$5,151%($923TT@)R`N("1T:&ES+3Y?<&%R86US
M6R=T86)L92==("X@)R!72$5212`G.PH@("`@("`@("1Q=65R>2`N/2`G=&]K
M96Y?=&EM97-T86UP(#P@/R<["@H@("`@("`@("1V86QU97,@/2!A<G)A>2AT
M:6UE*"D@+2`D=&AI<RT^7W!A<F%M<ULG=&EM96]U="==*3L*"B`@("`@("`@
M)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD[
M"@H@("`@("`@("\J(%)E='5R;B!A;B!E<G)O<B!I9B!T:&4@=7!D871E(&9A
M:6QS+"!T;V\N("HO"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&5X:7-T<R@D=&]K96Y)1"D*("`@('L*("`@("`@("!I9B`H:7-?82@H)')E
M<W5L="`]("1T:&ES+3Y?8V]N;F5C="@I*2P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O
M*B!"=6EL9"!344P@<75E<GDN("HO"B`@("`@("`@)'%U97)Y("`]("=314Q%
M0U0@=&]K96Y?:60@1E)/32`G("X@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT[
M"B`@("`@("`@)'%U97)Y("X]("<@5TA%4D4@=&]K96Y?861D<F5S<R`](#\G
M.PH@("`@("`@("1Q=65R>2`N/2`G($%.1"!T;VME;E]I9"`](#\G.PH*("`@
M("`@("`D=F%L=65S(#T@87)R87DH)'1H:7,M/F5N8V]D95)E;6]T94%D9')E
M<W,H*2P@)'1O:V5N240I.PH*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D
M8BT^9V5T3VYE*"1Q=65R>2P@)'9A;'5E<RD["B`@("`@("`@:68@*&ES7V$H
M)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("%E
M;7!T>2@D<F5S=6QT*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@
M861D*"1T;VME;DE$*0H@("`@>PH@("`@("`@(&EF("AI<U]A*"@D<F5S=6QT
M(#T@)'1H:7,M/E]C;VYN96-T*"DI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@+RH@
M0G5I;&0@4U%,('%U97)Y+B`J+PH@("`@("`@("1Q=65R>2`@/2`G24Y315)4
M($E.5$\@)R`N("1T:&ES+3Y?<&%R86US6R=T86)L92==("X@)R`H=&]K96Y?
M861D<F5S<RP@=&]K96Y?:60L('1O:V5N7W1I;65S=&%M<"D@)SL*("`@("`@
M("`D<75E<GD@+CT@)U9!3%5%4R`H/RP@/RP@/RDG.PH*("`@("`@("`D=F%L
M=65S(#T@87)R87DH)'1H:7,M/F5N8V]D95)E;6]T94%D9')E<W,H*2P@)'1O
M:V5N240L('1I;64H*2D["@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B
M+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH@("`@("`@(&EF("AI<U]A*"1R
M97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*
M"B`@("`O*BH*("`@("`J($]P96YS(&$@8V]N;F5C=&EO;B!T;R!T:&4@4U%,
M('-E<G9E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@
M;VX@<W5C8V5S<RP@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?8V]N;F5C="@I"B`@("!["B`@("`@("`@
M:68@*"1T:&ES+3Y?8V]N;F5C=&5D*2!["B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`](%5T:6PZ.F%S<V5R
M=$1R:79E<D-O;F9I9R@D=&AI<RT^7W!A<F%M<RP@87)R87DH)W!H<'1Y<&4G
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=T;VME;B!344PG+"!A<G)A>2@G9')I=F5R)R`]/B`G=&]K96XG*2D["B`@
M("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/E]P87)A;7-;)V1A=&%B87-E)UTI*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=D871A8F%S92==(#T@)R<["B`@("`@
M("`@?0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;)W5S97)N
M86UE)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=U<V5R;F%M
M92==(#T@)R<["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/E]P87)A;7-;)W!A<W-W;W)D)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=P87-S=V]R9"==(#T@)R<["B`@("`@("`@?0H@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UTI*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==(#T@)R<["B`@("`@
M("`@?0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;)W1A8FQE
M)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==(#T@
M)VAO<F1E7W1O:V5N<R<["B`@("`@("`@?0H*("`@("`@("`O*B!#;VYN96-T
M('1O('1H92!344P@<V5R=F5R('5S:6YG('1H92!S=7!P;&EE9"!P87)A;65T
M97)S+B`J+PH@("`@("`@(')E<75I<F5?;VYC92`G1$(N<&AP)SL*("`@("`@
M("`D=&AI<RT^7V1B(#T@)D1".CIC;VYN96-T*"1T:&ES+3Y?<&%R86US+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W!E<G-I
M<W1E;G0G(#T^("%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG<&5R<VES=&5N="==
M*2DI.PH@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?9&(L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&(["B`@("`@("`@
M?0H*("`@("`@("`O+R!3970@1$(@<&]R=&%B:6QI='D@;W!T:6]N<RX*("`@
M("`@("!S=VET8V@@*"1T:&ES+3Y?9&(M/G!H<'1Y<&4I('L*("`@("`@("!C
M87-E("=M<W-Q;"<Z"B`@("`@("`@("`@("1T:&ES+3Y?9&(M/G-E=$]P=&EO
M;B@G<&]R=&%B:6QI='DG+"!$0E]03U)404))3$E465],3U=%4D-!4T4@?"!$
M0E]03U)404))3$E465]%4E)/4E,@?"!$0E]03U)404))3$E465]25%))32D[
M"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@
M("`@("1T:&ES+3Y?9&(M/G-E=$]P=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]0
M3U)404))3$E465],3U=%4D-!4T4@?"!$0E]03U)404))3$E465]%4E)/4E,I
M.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]C;VYN96-T960@/2!T<G5E
M.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J
M($1I<V-O;FYE8W0@9G)O;2!T:&4@4U%,('-E<G9E<B!A;F0@8VQE86X@=7`@
M=&AE(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!4<G5E(&]N('-U8V-E<W,L(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I
M;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V1I<V-O;FYE8W0H*0H@("`@
M>PH@("`@("`@(&EF("@D=&AI<RT^7V-O;FYE8W1E9"D@>PH@("`@("`@("`@
M("`D=&AI<RT^7V-O;FYE8W1E9"`](&9A;'-E.PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]D8BT^9&ES8V]N;F5C="@I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M2&]R9&4O34E-10``````````````````````````````````````````````
M````````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S<@,#(P,#(R`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<@``````````````
M```````````````````````````````````````````````````````````P
M,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<S
M-B`P,C$R-C(`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O
M5FEE=V5R+V]O;P``````````````````````````````````````````````
M`````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P,#`P(#$P-3$U-#,S-S,V(#`R,C`U-@`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O34E-12]6:65W97(O;V]O+W1A8FQE7V-E;&QS+GAS;```
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P-C8R-S(@,3`U,34T,S,W,S8@,#(U,34S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#PA+2T*
M"B`@(%1H92!#;VYT96YT<R!O9B!T:&ES(&9I;&4@87)E(&UA9&4@879A:6QA
M8FQE('-U8FIE8W0@=&\@=&AE('1E<FUS(&]F"B`@(&5I=&AE<B!O9B!T:&4@
M9F]L;&]W:6YG(&QI8V5N<V5S"@H@("`@("`@("`@+2!'3E4@3&5S<V5R($=E
M;F5R86P@4'5B;&EC($QI8V5N<V4@5F5R<VEO;B`R+C$*("`@("`@("`@("T@
M4W5N($EN9'5S=')Y(%-T86YD87)D<R!3;W5R8V4@3&EC96YS92!697)S:6]N
M(#$N,0H*("`@4W5N($UI8W)O<WES=&5M<R!);F,N+"!/8W1O8F5R+"`R,#`P
M"@H@("!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N<V4@5F5R<VEO
M;B`R+C$*("`@/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]"B`@($-O<'ER:6=H="`R,#`P(&)Y(%-U;B!-:6-R;W-Y<W1E
M;7,L($EN8RX*("`@.3`Q(%-A;B!!;G1O;FEO(%)O860L(%!A;&\@06QT;RP@
M0T$@.30S,#,L(%5300H*("`@5&AI<R!L:6)R87)Y(&ES(&9R964@<V]F='=A
M<F4[('EO=2!C86X@<F5D:7-T<FEB=71E(&ET(&%N9"]O<@H@("!M;V1I9GD@
M:70@=6YD97(@=&AE('1E<FUS(&]F('1H92!'3E4@3&5S<V5R($=E;F5R86P@
M4'5B;&EC"B`@($QI8V5N<V4@=F5R<VEO;B`R+C$L(&%S('!U8FQI<VAE9"!B
M>2!T:&4@1G)E92!3;V9T=V%R92!&;W5N9&%T:6]N+@H*("`@5&AI<R!L:6)R
M87)Y(&ES(&1I<W1R:6)U=&5D(&EN('1H92!H;W!E('1H870@:70@=VEL;"!B
M92!U<V5F=6PL"B`@(&)U="!7251(3U54($%.62!705)204Y463L@=VET:&]U
M="!E=F5N('1H92!I;7!L:65D('=A<G)A;G1Y(&]F"B`@($U%4D-(04Y404))
M3$E462!O<B!&251.15-3($9/4B!!(%!!4E1)0U5,05(@4%524$]312X@(%-E
M92!T:&4@1TY5"B`@($QE<W-E<B!'96YE<F%L(%!U8FQI8R!,:6-E;G-E(&9O
M<B!M;W)E(&1E=&%I;',N"@H@("!9;W4@<VAO=6QD(&AA=F4@<F5C96EV960@
M82!C;W!Y(&]F('1H92!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC"B`@($QI
M8V5N<V4@86QO;F<@=VET:"!T:&ES(&QI8G)A<GD[(&EF(&YO="P@=W)I=&4@
M=&\@=&AE($9R964@4V]F='=A<F4*("`@1F]U;F1A=&EO;BP@26YC+BP@-3D@
M5&5M<&QE(%!L86-E+"!3=6ET92`S,S`L($)O<W1O;BP*("`@34$@(#`R,3$Q
M+3$S,#<@(%5300H*"B`@(%-U;B!);F1U<W1R>2!3=&%N9&%R9',@4V]U<F-E
M($QI8V5N<V4@5F5R<VEO;B`Q+C$*("`@/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@("!4:&4@8V]N=&5N=',@
M;V8@=&AI<R!F:6QE(&%R92!S=6)J96-T('1O('1H92!3=6X@26YD=7-T<GD@
M4W1A;F1A<F1S"B`@(%-O=7)C92!,:6-E;G-E(%9E<G-I;VX@,2XQ("AT:&4@
M(DQI8V5N<V4B*3L@66]U(&UA>2!N;W0@=7-E('1H:7,@9FEL90H@("!E>&-E
M<'0@:6X@8V]M<&QI86YC92!W:71H('1H92!,:6-E;G-E+B!9;W4@;6%Y(&]B
M=&%I;B!A(&-O<'D@;V8@=&AE"B`@($QI8V5N<V4@870@:'1T<#HO+W=W=RYO
M<&5N;V9F:6-E+F]R9R]L:6-E;G-E+FAT;6PN"@H@("!3;V9T=V%R92!P<F]V
M:61E9"!U;F1E<B!T:&ES($QI8V5N<V4@:7,@<')O=FED960@;VX@86X@(D%3
M($E3(B!B87-I<RP*("`@5TE42$]55"!705)204Y462!/1B!!3ED@2TE.1"P@
M14E42$52($584%)%4U,@3U(@24U03$E%1"P@24Y#3%5$24Y'+`H@("!7251(
M3U54($Q)34E4051)3TXL(%=!4E)!3E1)15,@5$A!5"!42$4@4T]&5%=!4D4@
M25,@1E)%12!/1B!$149%0U13+`H@("!-15)#2$%.5$%"3$4L($9)5"!&3U(@
M02!005)424-53$%2(%!54E!/4T4L($]2($Y/3BU)3D9224Y'24Y'+@H@("!3
M964@=&AE($QI8V5N<V4@9F]R('1H92!S<&5C:69I8R!P<F]V:7-I;VYS(&=O
M=F5R;FEN9R!Y;W5R(')I9VAT<R!A;F0*("`@;V)L:6=A=&EO;G,@8V]N8V5R
M;FEN9R!T:&4@4V]F='=A<F4N"@H@("!4:&4@26YI=&EA;"!$979E;&]P97(@
M;V8@=&AE($]R:6=I;F%L($-O9&4@:7,Z(%-U;B!-:6-R;W-Y<W1E;7,L($EN
M8RX*"B`@($-O<'ER:6=H="#"J2`R,#`R(&)Y(%-U;B!-:6-R;W-Y<W1E;7,L
M($EN8RX*"B`@($%L;"!2:6=H=',@4F5S97)V960N"@H@("!#;VYT<FEB=71O
M<BAS*3H@7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?
M"@HM+3X*/'AS;#IS='EL97-H965T('9E<G-I;VX](C$N,"(*("`@("`@("`@
M("`@("`@('AM;&YS.GAS;#TB:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]84TPO
M5')A;G-F;W)M(@H@("`@("`@("`@("`@("`@>&UL;G,Z;V9F:6-E/2)H='1P
M.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]O9F9I8V4B"B`@("`@("`@("`@("`@
M("!X;6QN<SIS='EL93TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O<W1Y
M;&4B"B`@("`@("`@("`@("`@("!X;6QN<SIT97AT/2)H='1P.B\O;W!E;F]F
M9FEC92YO<F<O,C`P,"]T97AT(@H@("`@("`@("`@("`@("`@>&UL;G,Z=&%B
M;&4](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W1A8FQE(@H@("`@("`@
M("`@("`@("`@>&UL;G,Z9')A=STB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P
M,#`O9')A=VEN9R(*("`@("`@("`@("`@("`@('AM;&YS.F9O/2)H='1P.B\O
M=W=W+G<S+F]R9R\Q.3DY+UA33"]&;W)M870B"B`@("`@("`@("`@("`@("!X
M;6QN<SIX;&EN:STB:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]X;&EN:R(*("`@
M("`@("`@("`@("`@('AM;&YS.FYU;6)E<CTB:'1T<#HO+V]P96YO9F9I8V4N
M;W)G+S(P,#`O9&%T87-T>6QE(@H@("`@("`@("`@("`@("`@>&UL;G,Z<W9G
M/2)H='1P.B\O=W=W+G<S+F]R9R\R,#`P+W-V9R(*("`@("`@("`@("`@("`@
M('AM;&YS.F-H87)T/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]C:&%R
M="(*("`@("`@("`@("`@("`@('AM;&YS.F1R,V0](FAT='`Z+R]O<&5N;V9F
M:6-E+F]R9R\R,#`P+V1R,V0B"B`@("`@("`@("`@("`@("!X;6QN<SIM871H
M/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DX+TUA=&@O36%T:$U,(@H@("`@("`@
M("`@("`@("`@>&UL;G,Z9F]R;3TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P
M,#`O9F]R;2(*("`@("`@("`@("`@("`@('AM;&YS.G-C<FEP=#TB:'1T<#HO
M+V]P96YO9F9I8V4N;W)G+S(P,#`O<V-R:7!T(@H@("`@("`@("`@("`@("`@
M;V9F:6-E.F-L87-S/2)T97AT(@H@("`@("`@("`@("`@("`@;V9F:6-E.G9E
M<G-I;VX](C$N,"(*("`@("`@("`@("`@("`@('AM;&YS.F1C/2)H='1P.B\O
M<'5R;"YO<F<O9&,O96QE;65N=',O,2XQ+R(*("`@("`@("`@("`@("`@('AM
M;&YS.FUE=&$](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+VUE=&$B"B`@
M("`@("`@("`@("`@("!X;6QN<SIC;VYF:6<](FAT='`Z+R]O<&5N;V9F:6-E
M+F]R9R\R,#`Q+V-O;F9I9R(*("`@("`@("`@("`@("`@('AM;&YS.FAE;'`]
M(FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+VAE;'`B"B`@("`@("`@("`@
M("`@("!X;6QN<SIX=#TB:'1T<#HO+W=W=RYJ8VQA<FLN8V]M+WAT(@H@("`@
M("`@("`@("`@("`@>&UL;G,Z<WES=&5M/2)H='1P.B\O=W=W+FIC;&%R:RYC
M;VTO>'0O:F%V82]J879A+FQA;F<N4WES=&5M(@H@("`@("`@("`@("`@("`@
M>&UL;G,Z>&%L86X](FAT='`Z+R]X;6PN87!A8VAE+F]R9R]X86QA;B(*("`@
M("`@("`@("`@("`@('AM;&YS.FIA=F$](FAT='`Z+R]X;6PN87!A8VAE+F]R
M9R]X<VQT+VIA=F$B"B`@("`@("`@("`@("`@("!E>&-L=61E+7)E<W5L="UP
M<F5F:7AE<STB:F%V82(^"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B!W<FET92!R97!E
M871I;F<@=&%B;&4@8V5L;',@*BHJ("TM/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*"@H@("`@/"$M+2!M871C
M:&EN9R!C96QL<R!T;R!G:79E(&]U="`M/B!C;W9E<F5D('1A8FQE(&-E;&QS
M(&%R92!N;W0@=W)I='1E;B!O=70@+2T^"B`@("`\>'-L.G1E;7!L871E(&UA
M=&-H/2)T86)L93IT86)L92UC96QL(CX*("`@("`@("`\>'-L.G!A<F%M(&YA
M;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`\(2TM('!O<VET
M:6]N(&]F('1H92!C=7)R96YT(&EN<'5T(&-E;&P@=&\@9V5T('1H92!C;W)R
M96-T(&-O;'5M('-T>6QE("AH:61D96X@87)E(&%L<V\@8V]U;G1E9"DM+3X*
M("`@("`@("`\>'-L.G!A<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE
M<R(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB;6%X4F]W3&5N9W1H(B\^
M"@H@("`@("`@(#QX<VPZ:68@=&5S=#TB)&ES1&5B=6=-;V1E(CX*("`@("`@
M("`@("`@/'AS;#IM97-S86=E/@HM+2TM+2TM+2TM+2TM+3X@=&%B;&4Z=&%B
M;&4M8V5L;"!H87,@8F5E;B!E;G1E<F5D('=I=&@@;F]D92!V86QU93H@/'AS
M;#IV86QU92UO9B!S96QE8W0](BXB+SX\+WAS;#IM97-S86=E/@H@("`@("`@
M("`@("`\>'-L.FUE<W-A9V4^=&%B;&4Z;G5M8F5R+6-O;'5M;G,M<F5P96%T
M960Z("T\>'-L.G9A;'5E+6]F('-E;&5C=#TB0'1A8FQE.FYU;6)E<BUC;VQU
M;6YS+7)E<&5A=&5D(B\^+3PO>'-L.FUE<W-A9V4^"B`@("`@("`@/"]X<VPZ
M:68^"@H@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)C<F5A=&4M
M8V]L=6UN+7!O<VET:6]N+79A<FEA8FQE(CX*("`@("`@("`@("`@/"$M+2!P
M;W-I=&EO;B!O9B!T:&4@8W5R<F5N="!I;G!U="!C96QL('1O(&=E="!T:&4@
M8V]R<F5C="!C;VQU;2!S='EL92`H:&ED9&5N(&%R92!A;'-O(&-O=6YT960I
M+2T^"B`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q#;VQU
M;6Y3='EL945N=')I97,B("`@('-E;&5C=#TB)&%L;$-O;'5M;E-T>6QE16YT
M<FEE<R(O/@H@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L
M;&5C=&5D1VQO8F%L1&%T82(@("`@("`@<V5L96-T/2(D8V]L;&5C=&5D1VQO
M8F%L1&%T82(O/@H@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M;6%X4F]W3&5N9W1H(B`@("`@("`@("`@("!S96QE8W0](B1M87A2;W=,96YG
M=&@B+SX*("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H*("`@(#PO>'-L
M.G1E;7!L871E/@H*"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)C<F5A=&4M
M8V]L=6UN+7!O<VET:6]N+79A<FEA8FQE(CX*("`@("`@("`\(2TM('!O<VET
M:6]N(&]F('1H92!C=7)R96YT(&EN<'5T(&-E;&P@=&\@9V5T('1H92!C;W)R
M96-T(&-O;'5M('-T>6QE("AH:61D96X@87)E(&%L<V\@8V]U;G1E9"DM+3X*
M("`@("`@("`\>'-L.G!A<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE
M<R(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L
M1&%T82(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB;6%X4F]W3&5N9W1H
M(B\^"@H@("`@("`@(#PA+2T@8V]L=6UN('!O<VET:6]N(&YE961E9"!F;W(@
M<W1Y;&5S+"!E<W`N(&9O<B!C;VQU;6XM:&ED9&5N+69L86<@+2T^"B`@("`@
M("`@/'AS;#IV87)I86)L92!N86UE/2)P<F5C961I;F<M8V]L=6UN<R(^"B`@
M("`@("`@("`@(#QX<VPZ9F]R+65A8V@@<V5L96-T/2)P<F5C961I;F<M<VEB
M;&EN9SHZ*B(^"B`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB
M<75A;G1I='DB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB<W1R:6YG
M+6QE;F=T:"A`=&%B;&4Z;G5M8F5R+6-O;'5M;G,M<F5P96%T960I(#T@,"(^
M,3PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H
M97)W:7-E/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)`=&%B;&4Z;G5M8F5R+6-O
M;'5M;G,M<F5P96%T960B+SX\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@/"]X<VPZ
M96QE;65N=#X*("`@("`@("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@("`@("`@
M/"]X<VPZ=F%R:6%B;&4^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=X=#IN
M;V1E+7-E="<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T
M92!N86UE/2)C<F5A=&4M=&%B;&4M8V5L;"(^"B`@("`@("`@("`@("`@("`@
M("`@/"$M+2!P;W-I=&EO;B!O9B!T:&4@8W5R<F5N="!I;G!U="!C96QL('1O
M(&=E="!T:&4@8V]R<F5C="!C;VQU;2!S='EL92`H:&ED9&5N(&%R92!A;'-O
M(&-O=6YT960I+2T^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE<R(@("`@<V5L96-T/2(D
M86QL0V]L=6UN4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](FUA>%)O=TQE;F=T:"(@("`@("`@("`@
M("`@<V5L96-T/2(D;6%X4F]W3&5N9W1H(B\^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;'5M;BUP;W-I=&EO;B(@("`@
M("`@("`@<V5L96-T/2)S=6TH>'0Z;F]D92US970H)'!R96-E9&EN9RUC;VQU
M;6YS*2]Q=6%N=&ET>2D@*R`Q(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B("`@("`@
M<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@
M("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL
M86)L92@G>&%L86XZ;F]D97-E="<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ
M8V%L;"UT96UP;&%T92!N86UE/2)C<F5A=&4M=&%B;&4M8V5L;"(^"B`@("`@
M("`@("`@("`@("`@("`@/"$M+2!P;W-I=&EO;B!O9B!T:&4@8W5R<F5N="!I
M;G!U="!C96QL('1O(&=E="!T:&4@8V]R<F5C="!C;VQU;2!S='EL92`H:&ED
M9&5N(&%R92!A;'-O(&-O=6YT960I+2T^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE<R(@
M("`@<V5L96-T/2(D86QL0V]L=6UN4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FUA>%)O=TQE;F=T
M:"(@("`@("`@("`@("`@<V5L96-T/2(D;6%X4F]W3&5N9W1H(B\^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;'5M;BUP
M;W-I=&EO;B(@("`@("`@("`@<V5L96-T/2)S=6TH>&%L86XZ;F]D97-E="@D
M<')E8V5D:6YG+6-O;'5M;G,I+W%U86YT:71Y*2`K(#$B+SX*("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO
M8F%L1&%T82(@("`@("!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^
M"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*
M("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2).;V1E4V5T1G5N
M8W1I;VY.;W1!=F%I;&%B;&4B+SX*("`@("`@("`@("`@("`@(#QX<VPZ8V%L
M;"UT96UP;&%T92!N86UE/2)C<F5A=&4M=&%B;&4M8V5L;"(O/@H@("`@("`@
M("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@
M("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64]
M(F-R96%T92UT86)L92UC96QL(CX*("`@("`@("`\(2TM('!O<VET:6]N(&]F
M('1H92!C=7)R96YT(&EN<'5T(&-E;&P@=&\@9V5T('1H92!C;W)R96-T(&-O
M;'5M('-T>6QE("AH:61D96X@87)E(&%L<V\@8V]U;G1E9"DM+3X*("`@("`@
M("`\>'-L.G!A<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE<R(O/@H@
M("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O
M/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB;6%X4F]W3&5N9W1H(B\^"B`@
M("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQU;6XM<&]S:71I;VXB+SX*"@H@
M("`@("`@(#QX<VPZ:68@=&5S=#TB)&ES1&5B=6=-;V1E(CX*("`@("`@("`@
M("`@/'AS;#IM97-S86=E/DY%5R!604Q513H@8V]L=6UN+7!O<VET:6]N.B`M
M/'AS;#IV86QU92UO9B!S96QE8W0](B1C;VQU;6XM<&]S:71I;VXB+SXM/"]X
M<VPZ;65S<V%G93X*("`@("`@("`\+WAS;#II9CX*"@H@("`@("`@(#PA+2T@
M82!H:61D96X@8V]L=6UN('=I;&P@9VEV92!O=70@;F]T:&EN9R`M+3X*("`@
M("`@("`\>'-L.FEF('1E<W0](FYO="@D86QL0V]L=6UN4W1Y;&5%;G1R:65S
M+V-O;'5M;BUS='EL92UE;G1R>5MP;W-I=&EO;B@I(#T@)&-O;'5M;BUP;W-I
M=&EO;ETO0&-O;'5M;BUH:61D96XM9FQA9RDB/@H@("`@("`@("`@("`\>'-L
M.F-H;V]S93X*("`@("`@("`@("`@("`@(#PA+2T@=VAE;B!T:&4@8V]L=6UN
M<R!A<F4@;F]T(')E<&5A=&5D('1H92!N97AT(&-O;'5M;BUP;W-I=&EO;G,@
M<F%I<V5S('5P('1O(#$L(&]T:&5R=VES92!U<"!T;R!T:&4@86UO=6YT(&]F
M(')E<&5A=&5D(&-O;'5M;G,@+2T^"B`@("`@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB0'1A8FQE.FYU;6)E<BUC;VQU;6YS+7)E<&5A=&5D(CX*("`@
M("`@("`@("`@("`@("`@("`\(2TM('=R:71E<R!M=6QT:7!L92!E;G1R:65S
M(&]F(&$@8V5L;"`M+3X*("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM
M=&5M<&QA=&4@;F%M93TB<F5P96%T+7=R:71E+6-E;&PB/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D
M1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M86QL0V]L=6UN4W1Y;&5%;G1R:65S(B`@("!S96QE8W0](B1A;&Q#;VQU;6Y3
M='EL945N=')I97,B+SX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F-O;'5M;BUP;W-I=&EO;B(@("`@("`@("`@<V5L
M96-T/2(D8V]L=6UN+7!O<VET:6]N(B\^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)M87A2;W=,96YG=&@B("`@("`@
M("`@("`@('-E;&5C=#TB)&UA>%)O=TQE;F=T:"(O/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB;G5M8F5R+6-O;'5M
M;G,M<F5P96%T960B("!S96QE8W0](D!T86)L93IN=6UB97(M8V]L=6UN<RUR
M97!E871E9"(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M
M<&QA=&4^"B`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@
M("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@/"$M
M+2!W<FET97,@86X@96YT<GD@;V8@82!C96QL("TM/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)W<FET92UC96QL(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE<R(@("`@<V5L96-T/2(D
M86QL0V]L=6UN4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQU;6XM<&]S:71I;VXB("`@
M("`@("`@('-E;&5C=#TB)&-O;'5M;BUP;W-I=&EO;B(O/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB;6%X4F]W3&5N
M9W1H(B`@("`@("`@("`@("!S96QE8W0](B1M87A2;W=,96YG=&@B+SX*("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@
M("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`\+WAS;#IC
M:&]O<V4^"B`@("`@("`@/"]X<VPZ:68^"@H@("`@/"]X<VPZ=&5M<&QA=&4^
M"@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64](G)E<&5A="UW<FET92UC96QL
M(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A
M=&$B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE
M16YT<FEE<R(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L=6UN+7!O
M<VET:6]N(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)M87A2;W=,96YG
M=&@B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](FYU;6)E<BUC;VQU;6YS
M+7)E<&5A=&5D(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@
M("`\(2TM(#)$3SH@5&AI<R!I<R!T:&4@8W5R<F5N="!W;W)K87)O=6YD(&%G
M86EN<W0@=&AE(&)A8VMG<F]U;F0@<VEM=6QA=&EO;B!B>2!A;B`G96YD;&5S
M<R<@<F5P96%T:6YG(&-E;&P@+2T^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2(D;G5M8F5R+6-O;'5M;G,M<F5P96%T960@/B`Q(&%N9"`D;6%X4F]W
M3&5N9W1H(#X@)&-O;'5M;BUP;W-I=&EO;B(^"@H@("`@("`@("`@("`@("`@
M/'AS;#II9B!T97-T/2(D:7-$96)U9TUO9&4B/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ;65S<V%G93XK*RLK*RLK*RL@<W1A<G1I;F<@8V5L;"!W<FET
M:6YG("LK*RLK*RLK*SPO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IM97-S86=E/FYU;6)E<BUC;VQU;6YS+7)E<&5A=&5D.B`M/'AS
M;#IV86QU92UO9B!S96QE8W0](B1N=6UB97(M8V]L=6UN<RUR97!E871E9"(O
M/BT\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;65S
M<V%G93YM87A2;W=,96YG=&@Z("T\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&UA
M>%)O=TQE;F=T:"(O/BT\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ;65S<V%G93YC;VQU;6XM<&]S:71I;VXZ("T\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB)&-O;'5M;BUP;W-I=&EO;B(O/BT\+WAS;#IM97-S86=E
M/@H@("`@("`@("`@("`@("`@/"]X<VPZ:68^"@H@("`@("`@("`@("`@("`@
M/"$M+2!W<FET97,@86X@96YT<GD@;V8@82!C96QL("TM/@H@("`@("`@("`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G=R:71E+6-E;&PB/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL
M96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A
M(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F%L;$-O;'5M;E-T>6QE16YT<FEE<R(@("`@<V5L96-T/2(D86QL0V]L=6UN
M4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](F-O;'5M;BUP;W-I=&EO;B(@("`@("`@("`@<V5L96-T
M/2(D8V]L=6UN+7!O<VET:6]N(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](FUA>%)O=TQE;F=T:"(@("`@("`@("`@("`@
M<V5L96-T/2(D;6%X4F]W3&5N9W1H(B\^"B`@("`@("`@("`@("`@("`\+WAS
M;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@/"$M+2!R97!E870@
M8V%L;&EN9R!T:&ES(&UE=&AO9"!U;G1I;"!A;&P@96QE;65N=',@=W)I='1E
M;B!O=70@+2T^"B`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](B1I<T1E
M8G5G36]D92(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/BLK
M*RLK*RLK*R!C96QL(')E<&5T:71I;VX@*RLK*RLK*RLK/"]X<VPZ;65S<V%G
M93X*("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H@("`@("`@("`@("`@("`@
M/'AS;#IC86QL+71E;7!L871E(&YA;64](G)E<&5A="UW<FET92UC96QL(CX*
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L
M;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T
M82(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)A;&Q#;VQU;6Y3='EL945N=')I97,B("`@('-E;&5C=#TB)&%L;$-O;'5M
M;E-T>6QE16YT<FEE<R(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)C;VQU;6XM<&]S:71I;VXB("`@("`@("`@('-E;&5C
M=#TB)&-O;'5M;BUP;W-I=&EO;B`K(#$B+SX*("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB;6%X4F]W3&5N9W1H(B`@("`@("`@
M("`@("!S96QE8W0](B1M87A2;W=,96YG=&@B+SX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB;G5M8F5R+6-O;'5M;G,M<F5P
M96%T960B("!S96QE8W0](B1N=6UB97(M8V]L=6UN<RUR97!E871E9"`M(#$B
M+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E
M/@H@("`@("`@("`@("`@("`@/"$M+2`R1$\Z(%1H:7,@:7,@=&AE(&-U<G)E
M;G0@=V]R:V%R;W5N9"!A9V%I;G-T('1H92!B86-K9W)O=6YD('-I;75L871I
M;VX@8GD@86X@)V5N9&QE<W,G(')E<&5A=&EN9R!C96QL("TM/@H@("`@("`@
M("`@("`@("`@/"$M+2`@("`@(%=H96X@=&AE(&UA>%)O=TQE;F=T:"!I<R!R
M96%C:&5D(&$@;&%S="!E;G1R>2!O9B!A(&-E;&P@:7,@=W)I='1E;B`M+3X*
M("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)W<FET
M92UC96QL(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@("`@("`@<V5L96-T/2(D8V]L
M;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)A;&Q#;VQU;6Y3='EL945N=')I97,B("`@('-E
M;&5C=#TB)&%L;$-O;'5M;E-T>6QE16YT<FEE<R(O/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQU;6XM<&]S:71I;VXB
M("`@("`@("`@('-E;&5C=#TB)&-O;'5M;BUP;W-I=&EO;B(O/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)M87A2;W=,96YG
M=&@B("`@("`@("`@("`@('-E;&5C=#TB)&UA>%)O=TQE;F=T:"(O/@H@("`@
M("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@
M/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO
M>'-L.G1E;7!L871E/@H*"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)W<FET
M92UC96QL(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L
M;V)A;$1A=&$B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F%L;$-O;'5M
M;E-T>6QE16YT<FEE<R(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L
M=6UN+7!O<VET:6]N(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)M87A2
M;W=,96YG=&@B+SX*"@H@("`@("`@(#QX<VPZ:68@=&5S=#TB)&ES1&5B=6=-
M;V1E(CX*("`@("`@("`@("`@/'AS;#IM97-S86=E/E=R:71E5&5S="`M/B!)
M9B!N;W1H:6YG(&)E='=E96X@)RTG('=R:71E(&-E;&P@+3QX<VPZ=F%L=64M
M;V8@<V5L96-T/2(D86QL0V]L=6UN4W1Y;&5%;G1R:65S+V-O;'5M;BUS='EL
M92UE;G1R>5MP;W-I=&EO;B@I(#T@)&-O;'5M;BUP;W-I=&EO;ETO0&-O;'5M
M;BUH:61D96XM9FQA9R(O/BT\+WAS;#IM97-S86=E/@H@("`@("`@(#PO>'-L
M.FEF/@H*("`@("`@("`@("`@/'AS;#II9B!T97-T/2(D86QL0V]L=6UN4W1Y
M;&5%;G1R:65S+V-O;'5M;BUS='EL92UE;G1R>5MP;W-I=&EO;B@I(#T@)&-O
M;'5M;BUP;W-I=&EO;ETO0&-O;'5M;BUH:61D96XM9FQA9R(^"B`@("`@("`@
M("`@("`@("`\>'-L.FEF('1E<W0](B1I<T1E8G5G36]D92(^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IM97-S86=E/E1!0DQ%($-/3%5-3B!I<R!H:61D
M96XA/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H@
M("`@("`@("`@("`\+WAS;#II9CX*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@
M("`@("`@("`@(#PA+2T@82!H:61D96X@8V]L=6UN('=I;&P@9VEV92!O=70@
M;F]T:&EN9R`M+3X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1A;&Q#
M;VQU;6Y3='EL945N=')I97,O8V]L=6UN+7-T>6QE+65N=')Y6W!O<VET:6]N
M*"D@/2`D8V]L=6UN+7!O<VET:6]N72]`8V]L=6UN+6AI9&1E;BUF;&%G(CX*
M("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB)&ES1&5B=6=-;V1E(CX*
M("`@("`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^5$%"3$4@0T],54U.
M(&ES(&AI9&1E;B$\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@/"]X
M<VPZ:68^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"@H@("`@("`@("`@("`\
M(2TM($Y/5"!A(&AI9&1E;B!C;VQU;6X@+2T^"B`@("`@("`@("`@(#QX<VPZ
M;W1H97)W:7-E/@H*("`@("`@("`@("`@("`@(#PA+2T@82!T86)L92!I<R!A
M('1A8FQE(&AE861E<BP@=VAE;B!I="!H87,@82`B=&%B;&4Z=&%B;&4M:&5A
M9&5R+7)O=W,B(&%N8V5S=&]R("TM/@H@("`@("`@("`@("`@("`@/'AS;#IV
M87)I86)L92!N86UE/2)T86)L941A=&%4>7!E(CX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](F%N8V5S=&]R.CIT86)L93IT86)L92UH96%D97(M<F]W
M<R(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^=&@\
M+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YT9#PO>'-L.G1E
M>'0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@
M("`@("`\+WAS;#IV87)I86)L93X*"B`@("`@("`@("`@("`@("`\>'-L.F-H
M;V]S93X*("`@("`@("`@("`@("`@("`@("`\(2TM*RLK*RL@0U-3("A#05-#
M041)3D<@4U1,644@4TA%150I($A%041%4B!35%E,12!705D@*RLK*RLM+3X*
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&]U='!U=%1Y
M<&4@/2`G0U-37TA%041%4B<B/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.F5L96UE;G0@;F%M93TB>R1T86)L941A=&%4>7!E?2(^"@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2(D:7-$96)U9TUO
M9&4B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;65S
M<V%G93X**BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHG/'AS;#IV86QU92UO9B!S96QE8W0](B1T86)L941A=&%4>7!E(B\^)R!E
M;&5M96YT(&AA<R!B965N(&%D9&5D(3PO>'-L.FUE<W-A9V4^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#II9CX*"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](D!T86)L93IN=6UB97(M8V]L
M=6UN<RUS<&%N;F5D(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F%T=')I8G5T92!N86UE/2)C;VQS<&%N(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0]
M(D!T86)L93IN=6UB97(M8V]L=6UN<RUS<&%N;F5D(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ:68^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](D!T86)L93IN=6UB97(M<F]W
M<RUS<&%N;F5D(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.F%T=')I8G5T92!N86UE/2)R;W=S<&%N(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](D!T
M86)L93IN=6UB97(M<F]W<RUS<&%N;F5D(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ:68^"@H*"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\(2TM("HJ*B!T:&4@8V5L;"US='EL92`J*BH@+2T^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\(2TM(%1H92!C96QL('-T>6QE
M(&AA<R!N;R!C;VYC;'5S:6]N('=I=&@@=&AE(&-O;'5M;B!S='EL92P@<V\@
M=V4@<W=I=&-H('1H92!O<F1E<B]P<FEO<FET:65S(&1U92!T;R!B<F]W<V5R
M(&ES<W5E<PH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!4:&4@
M8V5L;"US='EL92!D97!E;F1S(&]N('1W;R!A='1R:6)U=&5S.@H*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`Q*2!T86)L93IS='EL92UN86UE
M("T@=&AE('-T>6QE('!R;W!E<G1I97,@;V8@8V5L;"X@5VAE;B!T:&5Y(&5X
M:7-T+"!A(&1E9F%U;'0@86QI9VYE;65N="`H8W`N(&)E;&]W*2!W:6QL(&)E
M(&%D9&5D(&9O<B!T:&4*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8V%S92!O9B!N;R!A;&EG;FUE;G0@
M:6X@=&AE('-T>6QE(&5X:7-T+@H*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`R*2!T86)L93IV86QU92UT>7!E("T@=&AE('9A;'5E('1Y<&4@
M;V8@=&AE('1A8FQE+6-E;&P@9VEV:6YG('1H92!D969A=6QT(&%L:6=N;65N
M=',N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@($)Y(&1E9F%U;'0@82!S=')I;F<@=F%L=64@:7,@;&5F
M="!A;&EG;F5D+"!A;&P@;W1H97(@87)E(&%L:6=N960Z<FEG:'0N"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`M+3X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`=&%B;&4Z<W1Y;&4M;F%M92(^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T
M<FEB=71E(&YA;64](G-T>6QE(CX*"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\(2TM($-%3$PM4U193$4Z(&%L:6=N;65N="!B
M>2!T86)L93IV86QU92UT>7!E("AW:71H;W5T(&5X:7-T:6YG('1A8FQE.G-T
M>6QE+6YA;64I+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F-E;&Q3='EL92(@<V5L96-T
M/2(D8V]L;&5C=&5D1VQO8F%L1&%T82]A;&QS='EL97,O*EMN86UE*"D]8W5R
M<F5N="@I+T!T86)L93IS='EL92UN86UE72(O/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0](G-T<FEN9RUL96YG=&@H)&-E;&Q3='EL92D@/B`P(&%N9"!N;W0H
M8V]N=&%I;G,H)&-E;&Q3='EL92P@)W1E>'0M86QI9VXG*2DB/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\(2TM
M($-%3$PM4U193$4Z(&%L:6=N;65N="!B>2!T86)L93IV86QU92UT>7!E("TM
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\(2TM(&YO(&%L:6=N;65N="!I;B!T:&4@8V5L;"!S='EL92P@=&AE
M(&%L:6=N;65N="!B87-E9"!O;B!T:&4@=&%B;&4Z=F%L=64M='EP92!W:6QL
M(&)E(&%D9&5D("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2)`=&%B;&4Z=F%L=64M='EP92!A;F0@;F]T*$!T86)L93IV86QU
M92UT>7!E(#T@)W-T<FEN9R<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB8V]N8V%T*"1C;VQL96-T961';&]B86Q$871A+V%L;'-T>6QE
M<R\J6VYA;64H*3UC=7)R96YT*"DO0'1A8FQE.G-T>6QE+6YA;65=+"`G=&5X
M="UA;&EG;CIR:6=H=#L@)RDB+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB8V]N8V%T*"1C;VQL96-T961';&]B86Q$871A+V%L;'-T>6QE<R\J
M6VYA;64H*3UC=7)R96YT*"DO0'1A8FQE.G-T>6QE+6YA;65=+"`G=&5X="UA
M;&EG;CIL969T.R`G*2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"$M
M+2!#14Q,+5-464Q%.B!A;&EG;FUE;G0@8GD@=&%B;&4Z=F%L=64M='EP92`M
M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"$M+2!N;R!#4U,@<W1Y;&4@<')O<&5R=&EE<R!E>&ES="P@;VYL
M>2!A;&EG;FUE;G0@9G)O;2!T:&4@=&%B;&4Z=F%L=64M='EP92!W:6QL(&)E
M('5S960@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E
M<W0](D!T86)L93IV86QU92UT>7!E(&%N9"!N;W0H0'1A8FQE.G9A;'5E+71Y
M<&4@/2`G<W1R:6YG)RDB/G1E>'0M86QI9VXZ<FEG:'0[(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.F]T:&5R=VES93YT97AT+6%L:6=N.FQE9G0[(#PO>'-L
M.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F-H;V]S93X*"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"$M+2!C;VQU;6XM<W1Y;&4@*&1I<VIU;F-T(&]F(&-E;&P@<W1Y
M;&4@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/"$M+2`R1$\Z(&]N;'D@86)S;VQU="!S='EL97,@87)E('-U<'!O<G1E
M9"P@<F5L871I=F4@<W1Y;&5S("AI+F4N("=S='EL93IR96PM8V]L=6UN+7=I
M9'1H)R!E+F<N('=I=&@@=F%L=64@(C@Y,S,J(B!A<F4@:6=N;W)E9"X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($ES
M<W5E.B!B<F]W<V5R<R`H;F]T('-U<F4@:68@0U-3*2!D;V5S(&YO="!S=7!P
M;W)T('1H92`G*B<@<F5L871I;VYS:&EP+"!O;FQY('1H92`G)2<L('=H97)E
M('1H92!S=6T@:7,@86QW87ES("<Q,#`G(0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@1F]R('1H:7,L(&ET(&ES(&5A
M<VEE<B!T;R!W;W)K(&]N('=I=&@@=&AE(&%B<V]L=71E('9A;'5E<RP@:6YS
M=&5A9"!O9B!C86QC=6QA=&EN9R!T:&4@=F%L=65S(&9O<B`Q,#`E("TM/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=F%L=64M;V8@<V5L96-T/2(D86QL0V]L=6UN4W1Y;&5%;G1R:65S+V-O;'5M
M;BUS='EL92UE;G1R>5MP;W-I=&EO;B@I/21C;VQU;6XM<&]S:71I;VY=(B\^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%T
M=')I8G5T93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"$M+2!#14Q,+5-464Q%.B!T86)L93IS='EL92UN86UE("TM/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N
M86UE/2)C;&%S<R(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB=')A;G-L871E*$!T86)L
M93IS='EL92UN86UE+"`G+B`E*"DO7"<L("<G*2(O/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U
M=&4@;F%M93TB<W1Y;&4B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"$M+2!#14Q,+5-464Q%.B!A;&EG;FUE;G0@8GD@=&%B
M;&4Z=F%L=64M='EP92`H=VET:&]U="!E>&ES=&EN9R!T86)L93IS='EL92UN
M86UE*2TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/"$M+2!N;R!T86)L93IS='EL92UN86UE(&5X:7-T+"!O;FQY(&%L:6=N
M;65N="!F<F]M('1H92!T86)L93IV86QU92UT>7!E('=I;&P@8F4@=7-E9"`M
M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`=&%B;&4Z=F%L=64M='EP92!A
M;F0@;F]T*$!T86)L93IV86QU92UT>7!E(#T@)W-T<FEN9R<I(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&5X
M="UA;&EG;CIR:6=H=#L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T
M97AT+6%L:6=N.FQE9G0["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U
M=&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H
M97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO
M;W-E/@H*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@26X@8V%S
M92!O9B!N;R!C96QL(&-O;G1E;G0@82!N;VXM8G)E86MA8FQE('-P86-E('=I
M;&P@8F4@:6YS97)T960*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('1O(&UA:V4@=&AE(&)R;W=S97(@<VAO=R!T:&4@=&%B;&4M8V5L
M;"!G<FED("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2)N;W0H8VAI;&0Z.G1E>'0H*2D@86YD(&YO="AC:&EL
M9#HZ*BDB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G1E>'0^("8C,38P.SPO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"$M+2`J*BH@=&AE(&-O;'5M;BUS='EL
M92`J*BH@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#PA+2T@('1H92!C;VQU;6X@<W1Y;&4@:&%S(&YO(&-O;F-L=7-I;VX@=VET
M:"!T:&4@8V5L;"!S='EL92P@<V\@=V4@<W=I=&-H('1H92!O<F1E<B]P<FEO
M<FET:65S(&1U92!T;R!B<F]W<V5R(&ES<W5E<RTM/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB<W!A
M;B(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.F%T=')I8G5T92!N86UE/2)C;&%S<R(^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE
M8W0](B1A;&Q#;VQU;6Y3='EL945N=')I97,O8V]L=6UN+7-T>6QE+65N=')Y
M6W!O<VET:6]N*"D@/2`D8V]L=6UN+7!O<VET:6]N72]`<W1Y;&4M;F%M92(O
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E
M9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.F%P<&QY+71E;7!L871E<SX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*"B`@("`@("`@("`@("`@("`@("`@/"$M
M+2LK*RLK($A434P@-"XP($E.3$E.140@5T%9("`K*RLK*RTM/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=#
M4U-?24Y,24Y%1"<B/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L
M96UE;G0@;F%M93TB>R1T86)L941A=&%4>7!E?2(^"@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2)`=&%B;&4Z;G5M8F5R+6-O
M;'5M;G,M<W!A;FYE9"(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IA='1R:6)U=&4@;F%M93TB8V]L<W!A;B(^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T
M/2)`=&%B;&4Z;G5M8F5R+6-O;'5M;G,M<W!A;FYE9"(O/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2)`=&%B;&4Z;G5M8F5R+7)O
M=W,M<W!A;FYE9"(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IA='1R:6)U=&4@;F%M93TB<F]W<W!A;B(^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)`
M=&%B;&4Z;G5M8F5R+7)O=W,M<W!A;FYE9"(O/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](G-T>6QE(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\(2TM(&-E;&PM<W1Y;&4@+2T^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A+V%L;'-T>6QE<R\J6VYA
M;64H*3UC=7)R96YT*"DO0'1A8FQE.G-T>6QE+6YA;65=(B\^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!C;VQU;6XM<W1Y;&4@+2T^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](B1A;&Q#;VQU;6Y3='EL945N=')I97,O8V]L=6UN+7-T>6QE
M+65N=')Y6W!O<VET:6]N*"D])&-O;'5M;BUP;W-I=&EO;ETB+SX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\(2TM(%1!0DQ%.E9!3%5%+519
M4$4@+2!T:&4@=F%L=64@;V8@82!T86)L92UC96QL('=I;&P@8F4@86QI9VYE
M9"!L969T(&)Y(&1E9F%U;'0@;VYL>2!E>&QI8VET(&YO;BUS=')I;F<@:7,@
M86QI9VYE9#IR:6=H="TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TB0'1A8FQE.G9A;'5E+71Y<&4@86YD
M(&YO="A`=&%B;&4Z=F%L=64M='EP92`]("=S=')I;F<G*2(^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^=&5X
M="UA;&EG;CIR:6=H=#L\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YT97AT
M+6%L:6=N.FQE9G0[/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\(2TM("8C,38P(&ES(&$@;F]N+6)R96%K86)L
M92!S<&%C92P@;F5C97-S87)Y('1O(&UA:V4@=&\@=&AE(&)R;W=S97(@<VAO
M=R!T:&4@=&%B;&4M8V5L;"!G<FED("TM/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#II9B!T97-T/2)N;W0H8VAI;&0Z.G1E>'0H*2D@86YD
M(&YO="AC:&EL9#HZ*BDB/B`F(S$V,#L\+WAS;#II9CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B
M86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IA
M<'!L>2UT96UP;&%T97,^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F5L96UE;G0^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@
M("`@("`@("`@("`@("`@("`\(2TM*RLK*RL@4$%,32!)3DQ)3D5$(%=!62`@
M*RLK*RLM+3X*("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB
M)&]U='!U=%1Y<&4@/2`G4$%,32<B/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F5L96UE;G0@;F%M93TB>R1T86)L941A=&%4>7!E?2(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](D!T86)L93IN
M=6UB97(M8V]L=6UN<RUS<&%N;F5D(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)C;VQS<&%N(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](D!T86)L93IN=6UB97(M8V]L=6UN<RUS<&%N;F5D(B\^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ:68^"@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2)`=&%B;&4Z
M;G5M8F5R+7)O=W,M<W!A;FYE9"(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB<F]W<W!A;B(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@
M<V5L96-T/2)`=&%B;&4Z;G5M8F5R+7)O=W,M<W!A;FYE9"(O/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L
M;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F%P<&QY+71E;7!L871E<SX*("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@("`@("`@("`@("`@(#PA+2TK*RLK*R!734P@5T%9("`K*RLK*RTM
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T
M5'EP92`]("=734PG(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC
M:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TB;F]T*"1A;&Q#;VQU;6Y3='EL945N=')I97,O8V]L=6UN+7-T>6QE
M+65N=')Y6VQA<W0H*2`]("1C;VQU;6XM<&]S:71I;VY=*2(^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C
M;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#XL(#PO>'-L.G1E>'0^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C
M;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA
M;64](F)R(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO
M=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S
M93X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@
M("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I
M<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^
M"CPO>'-L.G-T>6QE<VAE970^"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+V]O;R]M86EN7VAT;6PN
M>'-L`````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#4V-3,S(#$P-3$U-#,S-S,V(#`R
M-#8U,0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\(2TM"@H@("!4:&4@0V]N=&5N=',@;V8@=&AI<R!F:6QE(&%R92!M861E
M(&%V86EL86)L92!S=6)J96-T('1O('1H92!T97)M<R!O9@H@("!E:71H97(@
M;V8@=&AE(&9O;&QO=VEN9R!L:6-E;G-E<PH*("`@("`@("`@("T@1TY5($QE
M<W-E<B!'96YE<F%L(%!U8FQI8R!,:6-E;G-E(%9E<G-I;VX@,BXQ"B`@("`@
M("`@("`M(%-U;B!);F1U<W1R>2!3=&%N9&%R9',@4V]U<F-E($QI8V5N<V4@
M5F5R<VEO;B`Q+C$*"B`@(%-U;B!-:6-R;W-Y<W1E;7,@26YC+BP@3V-T;V)E
M<BP@,C`P,`H*("`@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8R!,:6-E;G-E
M(%9E<G-I;VX@,BXQ"B`@(#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/0H@("!#;W!Y<FEG:'0@,C`P,"!B>2!3=6X@36EC
M<F]S>7-T96US+"!);F,N"B`@(#DP,2!386X@06YT;VYI;R!2;V%D+"!086QO
M($%L=&\L($-!(#DT,S`S+"!54T$*"B`@(%1H:7,@;&EB<F%R>2!I<R!F<F5E
M('-O9G1W87)E.R!Y;W4@8V%N(')E9&ES=')I8G5T92!I="!A;F0O;W(*("`@
M;6]D:69Y(&ET('5N9&5R('1H92!T97)M<R!O9B!T:&4@1TY5($QE<W-E<B!'
M96YE<F%L(%!U8FQI8PH@("!,:6-E;G-E('9E<G-I;VX@,BXQ+"!A<R!P=6)L
M:7-H960@8GD@=&AE($9R964@4V]F='=A<F4@1F]U;F1A=&EO;BX*"B`@(%1H
M:7,@;&EB<F%R>2!I<R!D:7-T<FEB=71E9"!I;B!T:&4@:&]P92!T:&%T(&ET
M('=I;&P@8F4@=7-E9G5L+`H@("!B=70@5TE42$]55"!!3ED@5T%24D%.5%D[
M('=I=&AO=70@979E;B!T:&4@:6UP;&EE9"!W87)R86YT>2!O9@H@("!-15)#
M2$%.5$%"24Q)5%D@;W(@1DE43D534R!&3U(@02!005)424-53$%2(%!54E!/
M4T4N("!3964@=&AE($=.50H@("!,97-S97(@1V5N97)A;"!0=6)L:6,@3&EC
M96YS92!F;W(@;6]R92!D971A:6QS+@H*("`@66]U('-H;W5L9"!H879E(')E
M8V5I=F5D(&$@8V]P>2!O9B!T:&4@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI
M8PH@("!,:6-E;G-E(&%L;VYG('=I=&@@=&AI<R!L:6)R87)Y.R!I9B!N;W0L
M('=R:71E('1O('1H92!&<F5E(%-O9G1W87)E"B`@($9O=6YD871I;VXL($EN
M8RXL(#4Y(%1E;7!L92!0;&%C92P@4W5I=&4@,S,P+"!";W-T;VXL"B`@($U!
M("`P,C$Q,2TQ,S`W("!54T$*"@H@("!3=6X@26YD=7-T<GD@4W1A;F1A<F1S
M(%-O=7)C92!,:6-E;G-E(%9E<G-I;VX@,2XQ"B`@(#T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*("`@5&AE(&-O
M;G1E;G1S(&]F('1H:7,@9FEL92!A<F4@<W5B:F5C="!T;R!T:&4@4W5N($EN
M9'5S=')Y(%-T86YD87)D<PH@("!3;W5R8V4@3&EC96YS92!697)S:6]N(#$N
M,2`H=&AE("),:6-E;G-E(BD[(%EO=2!M87D@;F]T('5S92!T:&ES(&9I;&4*
M("`@97AC97!T(&EN(&-O;7!L:6%N8V4@=VET:"!T:&4@3&EC96YS92X@66]U
M(&UA>2!O8G1A:6X@82!C;W!Y(&]F('1H90H@("!,:6-E;G-E(&%T(&AT='`Z
M+R]W=W<N;W!E;F]F9FEC92YO<F<O;&EC96YS92YH=&UL+@H*("`@4V]F='=A
M<F4@<')O=FED960@=6YD97(@=&AI<R!,:6-E;G-E(&ES('!R;W9I9&5D(&]N
M(&%N(")!4R!)4R(@8F%S:7,L"B`@(%=)5$A/550@5T%24D%.5%D@3T8@04Y9
M($M)3D0L($5)5$A%4B!%6%!215-3($]2($E-4$Q)140L($E.0TQ51$E.1RP*
M("`@5TE42$]55"!,24U)5$%424].+"!705)204Y42453(%1(050@5$A%(%-/
M1E1705)%($E3($92144@3T8@1$5&14-44RP*("`@34520TA!3E1!0DQ%+"!&
M250@1D]2($$@4$%25$E#54Q!4B!055)03U-%+"!/4B!.3TXM24Y&4DE.1TE.
M1RX*("`@4V5E('1H92!,:6-E;G-E(&9O<B!T:&4@<W!E8VEF:6,@<')O=FES
M:6]N<R!G;W9E<FYI;F<@>6]U<B!R:6=H=',@86YD"B`@(&]B;&EG871I;VYS
M(&-O;F-E<FYI;F<@=&AE(%-O9G1W87)E+@H*("`@5&AE($EN:71I86P@1&5V
M96QO<&5R(&]F('1H92!/<FEG:6YA;"!#;V1E(&ES.B!3=6X@36EC<F]S>7-T
M96US+"!);F,N"@H@("!#;W!Y<FEG:'0@PJD@,C`P,B!B>2!3=6X@36EC<F]S
M>7-T96US+"!);F,N"@H@("!!;&P@4FEG:'1S(%)E<V5R=F5D+@H*("`@0V]N
M=')I8G5T;W(H<RDZ(%]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?
M7U]?7U]?7PH*+2T^"CQX<VPZ<W1Y;&5S:&5E="!V97)S:6]N/2(Q+C`B"B`@
M("`@("`@("`@("`@("!X;6QN<SIX<VP](FAT='`Z+R]W=W<N=S,N;W)G+S$Y
M.3DO6%-,+U1R86YS9F]R;2(*("`@("`@("`@("`@("`@('AM;&YS.F]F9FEC
M93TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O;V9F:6-E(@H@("`@("`@
M("`@("`@("`@>&UL;G,Z<W1Y;&4](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R
M,#`P+W-T>6QE(@H@("`@("`@("`@("`@("`@>&UL;G,Z=&5X=#TB:'1T<#HO
M+V]P96YO9F9I8V4N;W)G+S(P,#`O=&5X="(*("`@("`@("`@("`@("`@('AM
M;&YS.G1A8FQE/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]T86)L92(*
M("`@("`@("`@("`@("`@('AM;&YS.F1R87<](FAT='`Z+R]O<&5N;V9F:6-E
M+F]R9R\R,#`P+V1R87=I;F<B"B`@("`@("`@("`@("`@("!X;6QN<SIF;STB
M:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]84TPO1F]R;6%T(@H@("`@("`@("`@
M("`@("`@>&UL;G,Z>&QI;FL](FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3DO>&QI
M;FLB"B`@("`@("`@("`@("`@("!X;6QN<SIN=6UB97(](FAT='`Z+R]O<&5N
M;V9F:6-E+F]R9R\R,#`P+V1A=&%S='EL92(*("`@("`@("`@("`@("`@('AM
M;&YS.G-V9STB:'1T<#HO+W=W=RYW,RYO<F<O,C`P,"]S=F<B"B`@("`@("`@
M("`@("`@("!X;6QN<SIC:&%R=#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P
M,#`O8VAA<G0B"B`@("`@("`@("`@("`@("!X;6QN<SID<C-D/2)H='1P.B\O
M;W!E;F]F9FEC92YO<F<O,C`P,"]D<C-D(@H@("`@("`@("`@("`@("`@>&UL
M;G,Z;6%T:#TB:'1T<#HO+W=W=RYW,RYO<F<O,3DY."]-871H+TUA=&A-3"(*
M("`@("`@("`@("`@("`@('AM;&YS.F9O<FT](FAT='`Z+R]O<&5N;V9F:6-E
M+F]R9R\R,#`P+V9O<FTB"B`@("`@("`@("`@("`@("!X;6QN<SIS8W)I<'0]
M(FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W-C<FEP="(*("`@("`@("`@
M("`@("`@(&]F9FEC93IC;&%S<STB=&5X="(*("`@("`@("`@("`@("`@(&]F
M9FEC93IV97)S:6]N/2(Q+C`B"B`@("`@("`@("`@("`@("!X;6QN<SID8STB
M:'1T<#HO+W!U<FPN;W)G+V1C+V5L96UE;G1S+S$N,2\B"B`@("`@("`@("`@
M("`@("!X;6QN<SIM971A/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]M
M971A(@H@("`@("`@("`@("`@("`@>&UL;G,Z8V]N9FEG/2)H='1P.B\O;W!E
M;F]F9FEC92YO<F<O,C`P,2]C;VYF:6<B"B`@("`@("`@("`@("`@("!X;6QN
M<SIH96QP/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]H96QP(@H@("`@
M("`@("`@("`@("`@>&UL;G,Z>'0](FAT='`Z+R]W=W<N:F-L87)K+F-O;2]X
M="(*("`@("`@("`@("`@("`@('AM;&YS.G-Y<W1E;3TB:'1T<#HO+W=W=RYJ
M8VQA<FLN8V]M+WAT+VIA=F$O:F%V82YL86YG+E-Y<W1E;2(*("`@("`@("`@
M("`@("`@('AM;&YS.G5R;&5N8V]D97(](FAT='`Z+R]W=W<N:F-L87)K+F-O
M;2]X="]J879A+VIA=F$N;F5T+E523$5N8V]D97(B"B`@("`@("`@("`@("`@
M("!X;6QN<SIX86QA;CTB:'1T<#HO+WAM;"YA<&%C:&4N;W)G+WAA;&%N(@H@
M("`@("`@("`@("`@("`@>&UL;G,Z:F%V83TB:'1T<#HO+WAM;"YA<&%C:&4N
M;W)G+WAS;'0O:F%V82(*("`@("`@("`@("`@("`@(&5X8VQU9&4M<F5S=6QT
M+7!R969I>&5S/2)J879A(CX*"B`@("`\>'-L.F]U='!U="!M971H;V0@("`@
M("`](GAM;"(*("`@("`@("`@("`@("`@(&5N8V]D:6YG("`@(#TB551&+3@B
M"B`@("`@("`@("`@("`@("!I;F1E;G0@("`@("`](GEE<R(O/@H*"@H@("`@
M/"$M+2LK*RLK($E.0TQ51$5$(%A33"!-3T153$53("LK*RLK+2T^"B`@("`\
M(2TM(&EN:&5R:71E9"!S='EL92!P<F]P97)T:65S('=I;&P@8F4@8V]L;&5C
M=&5D(&%N9"!W<FET=&5N(&EN(&$@0U-3(&AE861E<B`H0U-3*2`M+3X*("`@
M(#QX<VPZ:6YC;'5D92!H<F5F/2)S='EL95]H96%D97(N>'-L(B\^"@H@("`@
M/"$M+2!I;FAE<FET960@<W1Y;&4@<')O<&5R=&EE<R!W:6QL(&)E(&-O;&QE
M8W1E9"!A;F0@=W)I='1E;B!A<R!H=&UL('!R;W!E<G1I97,@:6X@82!T96UP
M;W)A<GD@=F%R:6%B;&4@*$A434PT+"!004Q-*2`M+3X*("`@(#QX<VPZ:6YC
M;'5D92!H<F5F/2)S='EL95]I;FQI;F5D+GAS;"(O/@H*("`@(#PA+2T@;W5R
M('AM;"!S='EL92!P<F]P97)T:65S('=I;&P@8F4@;6%P<&5D('1O($-34R!A
M;F0@2%1-3#0N>"!P<F]P97)T:65S("TM/@H@("`@/'AS;#II;F-L=61E(&AR
M968](G-T>6QE7VUA<'!I;F<N>'-L(B\^"@H@("`@/"$M+2!C;VUM;VX@96QE
M;65N="!H86YD;&EN9R`M+3X*("`@(#QX<VPZ:6YC;'5D92!H<F5F/2)C;VUM
M;VXN>'-L(B\^"@H@("`@/"$M+2!T86)L92!H86YD;&EN9R`M+3X*("`@(#QX
M<VPZ:6YC;'5D92!H<F5F/2)T86)L92YX<VPB+SX*"B`@("`\(2TM('!A;&T@
M:&%N9&QI;F<@+2T^"B`@("`\>'-L.FEN8VQU9&4@:')E9CTB<&%L;2YX<VPB
M+SX*"B`@("`\(2TM(&=L;V)A;"!D;V-U;65N="!H86YD;&EN9R`M+3X*("`@
M(#QX<VPZ:6YC;'5D92!H<F5F/2)G;&]B86Q?9&]C=6UE;G0N>'-L(B\^"@H*
M"@H*"@H@("`@/"$M+2LK*RLK(%!!4D%-151%4B!&4D]-(%1(12!!4%!,24-!
M5$E/3B!!3D0@1TQ/0D%,(%9!4DE!0DQ%4R`K*RLK*RTM/@H*("`@(#PA+2T@
M34%.1$%43U)9.B!54DP@;V8@;65T82!S=')E86T@+2T^"B`@("`\>'-L.G!A
M<F%M(&YA;64](FUE=&%&:6QE55),(B\^"@H@("`@/"$M+2!-04Y$051/4EDZ
M(%523"!O9B!S='EL97,@<W1R96%M("TM/@H@("`@/'AS;#IP87)A;2!N86UE
M/2)S='EL97-&:6QE55),(B\^"@H@("`@/"$M+2!-04Y$051/4EDZ(&9O<B!R
M97-O;'9I;F<@<F5L871I=F4@;&EN:W,*("`@("`@("!&;W(@<F5S;VQV:6YG
M(')E86QT:79E(&QI;FMS('1O('1H92!P86-K960@4T\@9&]C=6UE;G0L(&DN
M92X@=&AE('!A=&@O55),(&]F('1H92!J87)E9"!S>'<@9FEL92`H92YG+B!M
M971A+GAM;"P@<W1Y;&5S+GAM;"P@;&EN:W,@=&\@9W)A<&AI8W,@:6X@82!R
M96QA=&EV92!D:7)E8W1O<GDI("TM/@H@("`@/'AS;#IP87)A;2!N86UE/2)A
M8G-O;'5T95-O=7)C941I<E)E9B(O/@H*("`@(#PA+2T@3U!424].04P@*&UA
M;F1A=&]R>2P@=VAE;B!W:&5N('-O=7)C92!I<R!C;VUP<F5S<V5D*3H@3F5C
M97-S87)Y(&9O<B!T:&4@:6X@=&AE('!A8VME9"!/3R!D;V-U;65N="!E;6)E
M9&1E9"!F:6QE<R`H;6]S=&QY(&=R87!H:6-S(&9R;VT@=&AE(&-O;7!R97-S
M960@+U!I8W1U<F4@9&ER*2X*("`@("`@("`@5VAE;B!T:&4@3W!E;D]F9FEC
M92`H3T\I(&9I;&4@:&%S(&)E96X@=6YP86-K960@=&AE(&%B<V]L=71E4V]U
M<F5$:7)2968@8V%N(&)E('1A:V5N+`H@("`@("`@("!/=&AE<G=I<V4L(&$@
M2D%2(%523"!C;W5L9"!B92!C:&]O<V5N(&]R('=H96X@=V]R:VEN9R!W:71H
M($]P96Y/9F9I8V4@82!S;R!C86QL960@4&%C:V%G92U54DP@96YC;V1E9"!O
M=F5R($A45%`@8V%N(&)E('5S960@=&\*("`@("`@("`@86-C97-S('1H92!J
M87)E9"!C;VYT96YT<R!O9B!T:&4@=&AE(&IA<F5D(&1O8W5M96YT+B`N("TM
M/@H@("`@/'AS;#IP87)A;2!N86UE/2)J87)E9%)O;W154DPB('-E;&5C=#TB
M)&%B<V]L=71E4V]U<F-E1&ER4F5F(B\^"@H@("`@/"$M+2!/4%1)3TY!3"`H
M;6%N9&%T;W)Y+"!W:&5N('5S960@:6X@<V5S<VEO;B!B87-E9"!E;G9I<F]N
M;65N="D*("`@("`@("`@57-E9G5L(&9O<B!796)!<'!L:6-A=&EO;G,Z(&EF
M(&$@2%144"!S97-S:6]N(&ES(&YO="!C;V]K:64@8F%S960L(%523"!R97=R
M:71I;F<@:7,@8F5E:6YG('5S960@*'1H92!S97-S:6]N(&ES(&%P<&5N9&5D
M('1O('1H92!54DPI+@H@("`@("`@("!4:&ES(%523"!S97-S:6]N(&ES('5S
M960@=VAE;B!C<F5A=&EN9R!L:6YK<R!T;R!G<F%P:&EC<R!B>2!84TQ4+B!/
M=&AE<G=I<V4@=&AE('5S97(@:&%V="!T;R!L;V<@86=A:6X@:6X@9F]R(&5V
M97)Y(&=R87!H:6,@:&4@=V]U;&0@;&EK92!T;R!S964N("TM/@H@("`@/'AS
M;#IP87)A;2!N86UE/2)O<'1I;VYA;%523%-U9F9I>"(O/@H*("`@(#PA+2T@
M3U!424].04PZ($1022`H9&]T<R!P97(@:6YC:"D@=&AE('-T86YD87)D('-O
M;'5T:6]N(&]F(&=I=F5N('!I8W1U<F5S("AN96-E<W-A<GD@9F]R('1H92!C
M;VYV97)S:6]N(&]F("=C;2<@:6YT;R`G<&EX96PG*2TM/@H@("`@/"$M+2!!
M;'1H;W5G:"!M86YY('!I8W1U<F5S(&AA=F4@=&AE(#DV(&1P:2!R97-O;'5T
M:6]N+"!A(&AI9VAE<B!R97-O;'1I;VX@9VEV92!B971T97(@<F5S=6QT<R!F
M;W(@8V]M;6]N(&)R;W=S97)S("TM/@H@("`@/'AS;#IP87)A;2!N86UE/2)D
M<&DB('-E;&5C=#TB.38B+SX*"B`@("`\(2TM($]05$E/3D%,.B!I;B!C87-E
M(&]F('5S:6YG(&$@9&EF9F5R96YT('!R;V-E<W-O<B!T:&%N(&$@2D%602!8
M4TQ4+"!Y;W4@8V%N('5N86)L92!T:&4@2F%V82!F=6YC=&EO;F%L:71Y"B`@
M("`@("`@("AI+F4N(&1E8G5G9VEN9R!T:6UE(&%N9"!E;F-O9&EN9R!C:&%P
M=&5R(&YA;65S(&9O<B!T:&4@8V]N=&5N="UT86)L92!A<R!H<F5F(&%N9"!A
M;F-H;W)S("D@+2T^"B`@("`\>'-L.G!A<F%M(&YA;64](F1I<V%B;&5*879A
M(B`@("!S96QE8W0](F9A;'-E(B\^"B`@("`\>'-L.G!A<F%M(&YA;64](FES
M2F%V841I<V%B;&5D(B!S96QE8W0](F)O;VQE86XH)&1I<V%B;&5*879A*2(O
M/@H*("`@(#PA+2T@3U!424].04PZ('5S97(M86=E;G0@=VEL;"!B92!D:69F
M97)N=&EA=&5D(&)Y('1H:7,@<&%R86UE=&5R(&=I=F5N(&)Y(&%P<&QI8V%T
M:6]N("AE+F<N(&IA=F$@<V5R=FQE="DM+3X*("`@(#QX<VPZ<&%R86T@;F%M
M93TB;W5T<'5T5'EP92(@<V5L96-T/2(G0U-37TA%041%4B<B+SX*("`@(#PA
M+2T@<V5T(&]F('!O<W-I8FQE(&1E=FEC951Y<',@*%=-3"!I<R!S970@:6X@
M:71S(&]W;B!S=&%R=&9I;&4@;6%I;E]W;6PN>'-L*3H*("`@(#QX<VPZ<&%R
M86T@;F%M93TB;W5T<'5T5'EP92(@<V5L96-T/2(G0U-37TA%041%4B<B+SX*
M("`@(#QX<VPZ<&%R86T@;F%M93TB;W5T<'5T5'EP92(@<V5L96-T/2(G0U-3
M7TE.3$E.140G(B\^"B`@("`\>'-L.G!A<F%M(&YA;64](F]U='!U=%1Y<&4B
M('-E;&5C=#TB)U!!3$TG(B\^("TM/@H*("`@(#PA+2T@3U!424].04PZ(&9O
M<B!A8W1I=F%T:6YG('1H92!D96)U9R!M;V1E('-E="!T:&4@=F%R:6%B;&4@
M:&5R92!T;R`G=')U92@I)R!O<B!G:79E(&%N>2!V86QU92!F<F]M(&]U='-I
M9&4@+2T^"B`@("`\>'-L.G!A<F%M(&YA;64](F1E8G5G(B`@("`@("`@('-E
M;&5C=#TB9F%L<V4B+SX*("`@(#QX<VPZ<&%R86T@;F%M93TB:7-$96)U9TUO
M9&4B("`@<V5L96-T/2)B;V]L96%N*"1D96)U9RDB+SX*"CPA+2T@*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*@H@("`@3U!424].04PZ($Y%141%1"!)
M3B!#3TY.14-424].(%=)5$@@02!'3$]"04P@1$]#54U%3E0@+2T^"@H@("`@
M/"$M+5-534U!4EDZ"B`@("`@("`@(&9O;&QO=VEN9R!P87)A;65T97(@=')I
M9V=E<G,@82`H<75I=&4@=&EM92!C;VYS=6UI;F<I(&5N86)L:6YG(&]F(&)O
M;VMM87)K<R!I;B!T:&4@=&%B;&4M;V8M8V]N=&5N="X*("`@("`@("!)3B!$
M151!24PZ"B`@("`@("`@($-U<G)E;G1L>2!S;VUE(&QI;FMS('5S960@:6X@
M=&AE($]F9FEC92!834P@*&4N9RX@:6X@=&AE(&-O;G1E;G0@=&%B;&4@87,@
M)R,W+E-O;64E,C!%>&%M<&QE)3(P2&5A9&QI;F4E-T]U=&QI;F4G*0H@("`@
M("`@("!I<R!N;W0@82!V86QI9"!54DP@*&-M<"X@8G5G(&ED(R`Q,#(S,3$I
M+B!.;R!F:6QE(&1E<W1I;F%T:6]N(&ES('-P96-I9FEE9"!N;W(@97AI<W0@
M86YY(&%N8VAO<B!E;&5M96YT(&9O<B!T:&5S90H@("`@("`@("!L:6YK<R!I
M;B!T:&4@3V9F:6-E(%A-3"X*("`@("`@("`@02!W;W)K87)O=6YD(&9O<B!T
M:&ES('1R86YS9F]R;6%T:6]N('1H97)E9F]R92!H860@=&\@8F4@;6%D92X@
M5&AI<R!T:6UE+6-O;G-U;6EN9R!M96-H86YI<VT@:7,@9&ES86)L960@8GD@
M9&5F875L="!A;F0*("`@("`@("`@8V%N(&)E(&%C=&EV871E9"!B>2!A('!A
M<F%M971E<B`H:2YE+B`G9&ES86)L94QI;FME9%1A8FQE3V9#;VYT96YT)RDN
M($$@8W)E871I;VX@;V8@86X@86YC:&]R(&ES(&UA9&4@9F]R(&5A8V@@:&5A
M9&5R(&5L96UE;G0N"B`@("`@("`@($%L;"!H96%D97(@=&ET;&5S(&=O;FYA
M(&)E(&5N8V]D:6YG('1O(&)E('5S86)L92!I;B!A(')E;&%T:79E(%523"X@
M("`@+2T^"B`@("`\>'-L.G!A<F%M(&YA;64](F1I<V%B;&5,:6YK961486)L
M94]F0V]N=&5N="(@<V5L96-T/2)F86QS92@I(B\^"@H@("`@/"$M+2!4:&4@
M8VAA<'1E<B!N=6UB97)S(&]F('1H92!C=7)R96YT(&1O8W5M96YT("AA<R!A
M('-E<75E;F-E(&]F(&$@9VQO8F%L(&1O8W5M96YT*2!I<R!D97!E;F1E;G0@
M;V8@=&AE(&YU;6)E<@H@("`@("`@(&]F(&-H87!T97(@;V8@=&AE('-A;64@
M;&5V96P@:6X@<')E8V5D:6YG(&1O8W5M96YT<RX@+2T^"B`@("`\>'-L.G!A
M<F%M(&YA;64](G!R96-E9&EN9T-H87!T97),979E;#$B("!S96QE8W0](C`B
M+SX*("`@(#QX<VPZ<&%R86T@;F%M93TB<')E8V5D:6YG0VAA<'1E<DQE=F5L
M,B(@('-E;&5C=#TB,"(O/@H@("`@/'AS;#IP87)A;2!N86UE/2)P<F5C961I
M;F=#:&%P=&5R3&5V96PS(B`@<V5L96-T/2(P(B\^"B`@("`\>'-L.G!A<F%M
M(&YA;64](G!R96-E9&EN9T-H87!T97),979E;#0B("!S96QE8W0](C`B+SX*
M("`@(#QX<VPZ<&%R86T@;F%M93TB<')E8V5D:6YG0VAA<'1E<DQE=F5L-2(@
M('-E;&5C=#TB,"(O/@H@("`@/'AS;#IP87)A;2!N86UE/2)P<F5C961I;F=#
M:&%P=&5R3&5V96PV(B`@<V5L96-T/2(P(B\^"B`@("`\>'-L.G!A<F%M(&YA
M;64](G!R96-E9&EN9T-H87!T97),979E;#<B("!S96QE8W0](C`B+SX*("`@
M(#QX<VPZ<&%R86T@;F%M93TB<')E8V5D:6YG0VAA<'1E<DQE=F5L."(@('-E
M;&5C=#TB,"(O/@H@("`@/'AS;#IP87)A;2!N86UE/2)P<F5C961I;F=#:&%P
M=&5R3&5V96PY(B`@<V5L96-T/2(P(B\^"B`@("`\>'-L.G!A<F%M(&YA;64]
M(G!R96-E9&EN9T-H87!T97),979E;#$P(B!S96QE8W0](C`B+SX*"B`@("`\
M(2TM(%A-3"!D;V-U;65N=',@8V]N=&%I;FEN9R!A('1A8FQE(&]F(&-O;G1E
M;G1S+`H@("`@("`@(&=O;FYA(&QI;FL@9F]R('5S86)I;&ET>2!R96%S;VX@
M86)O=F4@96%C:"!C:&%P=&5R('1O('1H92!P<F5C961I;F<@86YD(&9O;&QO
M=VEN9R!D;V-U;65N="!A;F0@=&AE(&-O;G1E;G0@=&%B;&4@+2T^"B`@("`\
M>'-L.G!A<F%M(&YA;64](F-O;G1E;G1486)L95523"(O/@H*("`@(#PA+2T@
M3F5E9&5D(&9O<B!T:&4@8G5G('=O<FMA<F]U;F0@;V8@;6ES<VEN9R!C;VYT
M96YT('1A8FQE(&QI;FMS"B`@("`@("`@8GD@=&AI<R!A;6)I9V]U<R!(5$U,
M(')E9F5R96YC97,@9G)O;2!T:&4@8V]N=&5N="!T86)L92!C86X@8F4@979O
M:61E9"TM/@H@("`@/'AS;#IP87)A;2!N86UE/2)G;&]B86Q$;V-U;65N=%)E
M9E1O0W5R<F5N=$9I;&4B+SX*"B`@("`\(2TM($YE961E9"!F;W(@=&AE(&)U
M9R!W;W)K87)O=6YD(&]F(&UI<W-I;F<@8V]N=&5N="!T86)L92!L:6YK<PH@
M("`@("`@(&)Y('1H:7,@;F]D92US970@=&AE(')E;&%T:6]N(&)E='=E96X@
M8V]N=&5N="UT86)L92!L:6YK(&%N9"!C:&EL9')E;B!D;V-U;65N="!H96%D
M97(@8V%N(&)E('5N86UB:6=O=7,@97-T86)L:7-H960@+2T^"B`@("`\>'-L
M.G!A<F%M(&YA;64](F-O;G1E;G1486)L94AE861I;F=S(B\^"@H*/"$M+2!%
M3D0@3T8@1TQ/0D%,($1/0U5-14Y4(%-%0U1)3TX**BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BTM/@H*"@H@("`@/"$M+2!W;W)K<R!F;W(@;F]R;6%L
M('-E<&%R871E9"!Z:7!P960@>&UL(&9I;&5S(&%S(&9O<B!F;&%T(&9I;'1E
M<B!S:6YG;&4@>&UL(&9I;&4@9F]R;6%T(&%S('=E;&P@+2T^"B`@("`\>'-L
M.G9A<FEA8FQE(&YA;64](F]F9FEC93IM971A+69I;&4B("`@("`@("`@("!S
M96QE8W0](F1O8W5M96YT*"1M971A1FEL95523"DB+SX*("`@(#QX<VPZ=F%R
M:6%B;&4@;F%M93TB;V9F:6-E.G-T>6QE<RUF:6QE(B`@("`@("`@('-E;&5C
M=#TB9&]C=6UE;G0H)'-T>6QE<T9I;&554DPI(B\^"B`@("`\>'-L.G9A<FEA
M8FQE(&YA;64](F]F9FEC93IF;VYT+61E8VQS(B`@("`@("`@("!S96QE8W0]
M(B1O9F9I8V4Z<W1Y;&5S+69I;&4O*B]O9F9I8V4Z9F]N="UD96-L<R(O/@H@
M("`@/'AS;#IV87)I86)L92!N86UE/2)O9F9I8V4Z<W1Y;&5S(B`@("`@("`@
M("`@("`@<V5L96-T/2(D;V9F:6-E.G-T>6QE<RUF:6QE+RHO;V9F:6-E.G-T
M>6QE<R(O/@H@("`@/"$M+2!O9F9I8V4Z875T;VUA=&EC+7-T>6QE<R!M87D@
M;V-C=7)E(&EN('1W;R!D:69F97)E;G0@9FEL97,@*&DN9"X@8V]N=&5N="YX
M;6P@86YD('-T>6QE<RYX;6PI+B!&=7)T:&5R;6]R92!T:&4@=&]P(&QE=F5L
M('1A9R!I<R!D:69F97)E;G0@:6X@82!F;&%T('AM;"!F:6QE("TM/@H@("`@
M/'AS;#IV87)I86)L92!N86UE/2)O9F9I8V4Z875T;VUA=&EC+7-T>6QE<R(@
M("`@<V5L96-T/2(O*B]O9F9I8V4Z875T;VUA=&EC+7-T>6QE<R(O/@H*("`@
M(#PA+2T@<VEM<&QE(&1E8VQA<F%T:6]N(&]F(%=-3"!U<V5D('1O(&%V;VED
M('!A<G-E<B!E<G)O<G,@+2T^"B`@("`\>'-L.G9A<FEA8FQE(&YA;64](G=A
M<"UP87)A9W)A<&@M96QE;65N=',M=VET:&]U="UT86)L92UR;W<B+SX*("`@
M(#QX<VPZ=F%R:6%B;&4@;F%M93TB=V%P+7!A<F%G<F%P:"UE;&5M96YT<R(O
M/@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)W;6PM<F5P96%T+7=R:71E+7)O
M=R(O/@H*"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B!B=6EL9"!T:&4@<')O<')I871E
M($A434P@9FEL92`J*BH@+2T^"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H@("`@/'AS;#IT96UP;&%T92!M
M871C:#TB+R(^"@H@("`@("`@(#PA+2T\>'-L.FUE<W-A9V4^"@H*("`@("`@
M("!%;G1E<F5D('1H92!S='EL95-H965T<RP@=')A;G-F;W)M871I;VX@8F5G
M:6YS+BXN(#PO>'-L.FUE<W-A9V4^+2T^"@H@("`@("`@(#QX<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&ES1&5B=6=-;V1E(CX*
M("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)C:&5C
M:RUP87)A;65T97(B+SX*"B`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0]
M(FYO="@D:7-*879A1&ES86)L960I(CX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB9&5B=6<M<W1Y;&4M8V]L;&5C=&EN
M9RUT:6UE(B\^"B`@("`@("`@("`@("`@("`\+WAS;#II9CX*("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@
M("`@("`@("`@("`@("`\(2TM('1O(&%C8V5S<R!T:&4@=F%R:6%B;&4@;&EK
M92!A(&YO9&4M<V5T(&ET(&ES(&YE8V5S<V%R>2!T;R!C;VYV97)T(&ET"B`@
M("`@("`@("`@("`@("`@("`@(&9R;VT@82!R97-U;'0M=')E92UF<F%G;65N
M="`H4E1&*2!T;R!A(&YO9&4@<V5T('5S:6YG('1H92!*86UE<R!#;&%R:R!E
M>'1E;G-I;VX@+2T^"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA
M;64](F-O;&QE8W1E9$=L;V)A;$1A=&$M4E1&(CX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TG8W)E871E+6%L;"UI;FQI
M;F4M<W1Y;&5S)R\^"B`@("`@("`@("`@("`@("`\+WAS;#IV87)I86)L93X*
M"B`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=X=#IN
M;V1E+7-E="<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL
M+71E;7!L871E(&YA;64](G-T87)T(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$
M871A(B!S96QE8W0](GAT.FYO9&4M<V5T*"1C;VQL96-T961';&]B86Q$871A
M+5)41BDB+SX*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT
M96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I
M;&%B;&4H)WAA;&%N.FYO9&5S970G*2(^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)S=&%R="(^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L
M;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2)X86QA;CIN;V1E<V5T*"1C;VQL
M96-T961';&]B86Q$871A+5)41BDB+SX*("`@("`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB
M3F]D95-E=$9U;F-T:6]N3F]T079A:6QA8FQE(B\^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)S=&%R="(O/@H@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@
M("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@/"]X<VPZ;W1H97)W
M:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E
M/@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB<W1A<G0B/@H@("`@("`@(#QX
M<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@("`@
M("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/"$M+2LK*RLK($-34R`H0T%3
M0T%$24Y'(%-43%E%(%-(1454*2!(14%$15(@4U193$4@5T%9("LK*RLK+2T^
M"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=#
M4U-?2$5!1$52)R(^"B`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M
M93TB:'1M;"(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA
M;64](FAE860B/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.FEF('1E
M<W0](B1I<T1E8G5G36]D92(^/'AS;#IM97-S86=E/D-34R!H96QP97(@=F%R
M:6%B;&4@=VEL;"!B92!C<F5A=&5D+BXN+CPO>'-L.FUE<W-A9V4^/"]X<VPZ
M:68^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T
M92!N86UE/2=C;VUM;VXM:&5A9&5R+7!R;W!E<G1I97,G+SX*("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2(D:7-$96)U9TUO9&4B/CQX
M<VPZ;65S<V%G93Y#4U,@=F%R:6%B;&4@<F5A9'DL(&AE861E<B!W:6QL(&)E
M(&-R96%T960N+BXN/"]X<VPZ;65S<V%G93X\+WAS;#II9CX*("`@("`@("`@
M("`@("`@("`@("`@("`@/"$M+2!C;VYS=')U8W1I;F<@=&AE(&-S<R!H96%D
M97(@<VEM=6QA=&EN9R!I;FAE<FET86YC92!O9B!S='EL92UF86UI;&EE<R!B
M>2!S='EL92!O<F1E<B`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IC86QL+71E;7!L871E(&YA;64])V-R96%T92UC<W,M<W1Y;&5H96%D97(G
M+SX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2(D:7-$
M96)U9TUO9&4B/CQX<VPZ;65S<V%G93Y#4U,@:&5A9&5R(&-R96%T:6]N(&9I
M;FES:&5D(3PO>'-L.FUE<W-A9V4^/"]X<VPZ:68^"B`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ96QE;65N=#X*"@H*("`@("`@("`@("`@("`@("`@("`\
M>'-L.G9A<FEA8FQE(&YA;64](F)A8VMG<F]U;F1);6%G95523"(@<V5L96-T
M/2(D;V9F:6-E.F%U=&]M871I8RUS='EL97,O<W1Y;&4Z<&%G92UM87-T97(O
M<W1Y;&4Z<')O<&5R=&EE<R]S='EL93IB86-K9W)O=6YD+6EM86=E+T!X;&EN
M:SIH<F5F(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA
M;64](F)O9'DB/@H@("`@("`@("`@("`@("`@("`@("`@("`\(2TM(&)A8VMG
M<F]U;F0@:6UA9V4@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M:68@=&5S=#TB)&)A8VMG<F]U;F1);6%G95523"(^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)B86-K9W)O=6YD
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S
M93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!F
M;W(@:6UA9V5S(&IA<F5D(&EN(&]P96X@;V9F:6-E(&1O8W5M96YT("TM/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TB8V]N=&%I;G,H)&)A8VMG<F]U;F1);6%G95523"P@)R-0:6-T=7)E
M<R\G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\(2TM(&-R96%T:6YG(&%N(&%B<V]L=71E(&AT='`@55),('1O('1H92!C
M;VYT86EN960O<&%C:V5D(&EM86=E(&9I;&4@+2T^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB8V]N8V%T*"1J87)E9%)O;W154DPL("<O4&EC='5R97,O)RP@<W5B<W1R
M:6YG+6%F=&5R*"1B86-K9W)O=6YD26UA9V554DPL("<C4&EC='5R97,O)RDL
M("1O<'1I;VYA;%523%-U9F9I>"DB+SX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N
M86UE/2)S<F,B/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(D8F%C:V=R;W5N9$EM
M86=E55),(B\^/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#II9CX*"B`@("`@("`@("`@("`@("`@("`@
M("`@(#PA+2T@<')O8V5S<VEN9R!T:&4@8V]N=&5N="!O9B!T:&4@>&UL(&9I
M;&4@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ87!P;'DM=&5M
M<&QA=&5S('-E;&5C=#TB+RHO;V9F:6-E.F)O9'DB/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E
M9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S
M/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"@H@("`@("`@
M("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*"B`@("`@("`@("`@(#PA+2TK*RLK*R!(5$U,(#0N,"!)3DQ)3DE.1R`@
M*RLK*RLM+3X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1O=71P=714
M>7!E(#T@)T-34U])3DQ)3D5$)R(^"B`@("`@("`@("`@("`@("`\>'-L.F5L
M96UE;G0@;F%M93TB:'1M;"(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IE
M;&5M96YT(&YA;64](FAE860B/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TG8V]M;6]N+6AE861E<BUP<F]P97)T
M:65S)R\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)B86-K9W)O
M=6YD26UA9V554DPB('-E;&5C=#TB)&]F9FEC93IA=71O;6%T:6,M<W1Y;&5S
M+W-T>6QE.G!A9V4M;6%S=&5R+W-T>6QE.G!R;W!E<G1I97,O<W1Y;&4Z8F%C
M:V=R;W5N9"UI;6%G92]`>&QI;FLZ:')E9B(O/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ96QE;65N="!N86UE/2)B;V1Y(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@/"$M+2!B86-K9W)O=6YD(&EM86=E("TM/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](B1B86-K9W)O=6YD26UA9V55
M4DPB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U
M=&4@;F%M93TB8F%C:V=R;W5N9"(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#PA+2T@9F]R(&EM86=E<R!J87)E9"!I;B!O<&5N(&]F
M9FEC92!D;V-U;65N="`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1B86-K9W)O=6YD
M26UA9V554DPL("<C4&EC='5R97,O)RDB/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"$M+2!C<F5A=&EN9R!A;B!A8G-O;'5T
M92!H='1P(%523"!T;R!T:&4@8V]N=&%I;F5D+W!A8VME9"!I;6%G92!F:6QE
M("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IV86QU92UO9B!S96QE8W0](F-O;F-A="@D:F%R9612;V]T55),+"`G
M+U!I8W1U<F5S+R<L('-U8G-T<FEN9RUA9G1E<B@D8F%C:V=R;W5N9$EM86=E
M55),+"`G(U!I8W1U<F5S+R<I+"`D;W!T:6]N86Q54DQ3=69F:7@I(B\^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H
M97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IA='1R:6)U=&4@;F%M93TB<W)C(CX\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB)&)A8VMG<F]U;F1);6%G95523"(O/CPO>'-L.F%T=')I8G5T93X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H
M97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%T
M=')I8G5T93X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ:68^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S('-E
M;&5C=#TB+RHO;V9F:6-E.F)O9'DB/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A
M=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`\
M+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H*("`@("`@
M("`@("`@/"$M+2LK*RLK(%!!3$TM5DE)("@S+C(@2%1-3"!354)3150I("`K
M*RLK*RTM/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&]U='!U=%1Y
M<&4@/2`G4$%,32<B/@H@("`@("`@("`@("`@("`@/"$M+2!T:&4@<')O>'D@
M=VEL;"!C;VYV97)T('1H92!H=&UL(&9I;&4@;&%T97(@=&\@4%%!("TM/@H@
M("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](FAT;6PB/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)H96%D(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64]
M)W!A;&TM:&5A9&5R+7!R;W!E<G1I97,G+SX*("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IE;&5M96YT/@H*("`@("`@("`@("`@("`@("`@("`\>'-L.F5L
M96UE;G0@;F%M93TB8F]D>2(^"B`@("`@("`@("`@("`@("`@("`@("`@(#PA
M+2T@<')O8V5S<VEN9R!T:&4@8V]N=&5N="!O9B!T:&4@>&UL(&9I;&4@+2T^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S
M('-E;&5C=#TB+RHO;V9F:6-E.F)O9'DB/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@
M("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@
M("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*"@H@("`@
M/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B!(96%D97(@9F]R($-34U])3DQ)3D5$
M(&%N9"!#4U-?2$5!1$52("HJ*B`M+3X*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H*("`@(#QX
M<VPZ=&5M<&QA=&4@;F%M93TG8V]M;6]N+6AE861E<BUP<F]P97)T:65S)SX*
M("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E<R!S96QE8W0](B1O9F9I8V4Z
M;65T82UF:6QE+RHO;V9F:6-E.FUE=&$O9&,Z=&ET;&4B+SX*("`@("`@("`\
M>'-L.F%P<&QY+71E;7!L871E<R!S96QE8W0](B1O9F9I8V4Z;65T82UF:6QE
M+RHO;V9F:6-E.FUE=&$O9&,Z9&5S8W)I<'1I;VXB+SX*/"$M+3)$3R!A9&0@
M9G5R=&AE<B!H96%D97(@96QE;65N=',N+@H@("`@("`@(#QX<VPZ87!P;'DM
M=&5M<&QA=&5S('-E;&5C=#TB)&]F9FEC93IM971A+69I;&4O*B]O9F9I8V4Z
M;65T82]D8SIS=6)J96-T(B\^"B`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T
M97,@<V5L96-T/2(D;V9F:6-E.FUE=&$M9FEL92\J+V]F9FEC93IM971A+VUE
M=&$Z:V5Y=V]R9'-;<&]S=&ET:6]N*"D],5TB+SXM+3X*("`@(#PO>'-L.G1E
M;7!L871E/@H*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@](F1C.G1I=&QE(CX*
M("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB=&ET;&4B/@H@("`@("`@("`@
M("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O/@H@("`@("`@(#PO>'-L.F5L
M96UE;G0^"B`@("`\+WAS;#IT96UP;&%T93X*"B`@("`\>'-L.G1E;7!L871E
M(&UA=&-H/2)D8SID97-C<FEP=&EO;B(^"B`@("`@("`@/'AS;#IE;&5M96YT
M(&YA;64](FUE=&$B/@H@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE
M/2)N86UE(CX*("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YD97-C<FEP=&EO
M;CPO>'-L.G1E>'0^"B`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@
M("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB8V]N=&5N="(^"B`@("`@
M("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O/@H@("`@("`@
M("`@("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@/"]X<VPZ96QE;65N=#X*
M("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA+2T@
M*BHJ($UE87-U<FEN9R!T:&4@=&EM92!F;W(@<W1Y;&4@8W)E871I;F<@*BHJ
M("TM/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB
M9&5B=6<M<W1Y;&4M8V]L;&5C=&EN9RUT:6UE(CX*"B`@("`@("`@/'AS;#IV
M87)I86)L92!N86UE/2)S=&%R=%1I;64M4E1&(CX*("`@("`@("`@("`@/'AS
M;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N
M8W1I;VXM879A:6QA8FQE*"=S>7-T96TZ8W5R<F5N="UT:6UE+6UI;&QI<R<I
M(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M<WES=&5M.F-U<G)E;G0M=&EM92UM:6QL:7,H*2(O/@H@("`@("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2)F=6YC=&EO;BUA=F%I;&%B;&4H)VIA=F$Z:F%V82YL86YG+E-Y<W1E;2YC
M=7)R96YT5&EM94UI;&QI<R<I(CX*("`@("`@("`@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB:F%V83IJ879A+FQA;F<N4WES=&5M+F-U<G)E
M;G14:6UE36EL;&ES*"DB+SX*("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`\+WAS;#IV87)I
M86)L93X*"@H*("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F-O;&QE8W1E
M9$=L;V)A;$1A=&$M4E1&(CX*("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L
M871E(&YA;64])V-R96%T92UA;&PM:6YL:6YE+7-T>6QE<R<O/@H@("`@("`@
M(#PO>'-L.G9A<FEA8FQE/@H*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@
M("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H)WAT
M.FYO9&4M<V5T)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/D-R
M96%T:6YG('1H92!I;FQI;F4@<W1Y;&5S+BXN+CPO>'-L.FUE<W-A9V4^"B`@
M("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G-T87)T5&EM92(@
M("`@("`@("`@("`@('-E;&5C=#TB;G5M8F5R*'AT.FYO9&4M<V5T*"1S=&%R
M=%1I;64M4E1&*2DB+SX*("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@
M;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@("`@<V5L96-T/2)X=#IN;V1E
M+7-E="@D8V]L;&5C=&5D1VQO8F%L1&%T82U25$8I(B\^"B`@("`@("`@("`@
M("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F5N9%1I;64B("`@("`@("`@("`@
M("`@('-E;&5C=#TB<WES=&5M.F-U<G)E;G0M=&EM92UM:6QL:7,H*2(O/@H*
M("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93Y4:6UE(&9O<B!I;G-T86YT
M:6%T:6YG('-T>6QE('9A<FEA8FQE.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M*"1E;F14:6UE("T@)'-T87)T5&EM92DB+SX@;7,\+WAS;#IM97-S86=E/@H@
M("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G-T87)T
M(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L
M1&%T82(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G>&%L86XZ;F]D97-E="<I(CX*
M("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93Y#<F5A=&EN9R!T:&4@:6YL
M:6YE('-T>6QE<RXN+BX\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@
M/'AS;#IV87)I86)L92!N86UE/2)S=&%R=%1I;64B("`@("`@("`@("`@("!S
M96QE8W0](FYU;6)E<BAX86QA;CIN;V1E<V5T*"1S=&%R=%1I;64M4E1&*2DB
M+SX*("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB96YD5&EM
M92(@("`@("`@("`@("`@("`@<V5L96-T/2)J879A.FIA=F$N;&%N9RY3>7-T
M96TN8W5R<F5N=%1I;65-:6QL:7,H*2(O/@H@("`@("`@("`@("`@("`@/'AS
M;#IV87)I86)L92!N86UE/2)C;VQL96-T961';&]B86Q$871A(B`@("!S96QE
M8W0](GAA;&%N.FYO9&5S970H)&-O;&QE8W1E9$=L;V)A;$1A=&$M4E1&*2(O
M/@H*("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93Y4:6UE(&9O<B!I;G-T
M86YT:6%T:6YG('-T>6QE('9A<FEA8FQE.B`\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB*"1E;F14:6UE("T@)'-T87)T5&EM92DB+SX@;7,\+WAS;#IM97-S86=E
M/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G-T
M87)T(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO
M8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T
M93X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`\+WAS;#IC:&]O
M<V4^"@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H@("`@/"$M+2!$14)51R!P=7)P
M;W-E(&]N;'DZ(&-H96-K:6YG('1H92!P87)A;65T97)S(&]F('1H:7,@=&5M
M<&QA=&4M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB8VAE8VLM<&%R86UE
M=&5R(CX*("`@("`@("`\>'-L.FUE<W-A9V4^4&%R86UE=&5R(&1P:3H@/'AS
M;#IV86QU92UO9B!S96QE8W0](B1D<&DB+SX\+WAS;#IM97-S86=E/@H@("`@
M("`@(#QX<VPZ;65S<V%G93Y087)A;65T97(@;65T849I;&554DPZ(#QX<VPZ
M=F%L=64M;V8@<V5L96-T/2(D;65T849I;&554DPB+SX\+WAS;#IM97-S86=E
M/@H@("`@("`@(#QX<VPZ;65S<V%G93Y087)A;65T97(@<W1Y;&5S1FEL9552
M3#H@/'AS;#IV86QU92UO9B!S96QE8W0](B1S='EL97-&:6QE55),(B\^/"]X
M<VPZ;65S<V%G93X*("`@("`@("`\>'-L.FUE<W-A9V4^4&%R86UE=&5R(&%B
M<V]L=71E4V]U<F-E1&ER4F5F.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&%B
M<V]L=71E4V]U<F-E1&ER4F5F(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`\
M>'-L.FUE<W-A9V4^4&%R86UE=&5R('!R96-E9&EN9T-H87!T97),979E;#$@
M.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'!R96-E9&EN9T-H87!T97),979E
M;#$B+SX\+WAS;#IM97-S86=E/@H@("`@("`@(#QX<VPZ;65S<V%G93Y087)A
M;65T97(@<')E8V5D:6YG0VAA<'1E<DQE=F5L,B`Z(#QX<VPZ=F%L=64M;V8@
M<V5L96-T/2(D<')E8V5D:6YG0VAA<'1E<DQE=F5L,B(O/CPO>'-L.FUE<W-A
M9V4^"B`@("`@("`@/'AS;#IM97-S86=E/E!A<F%M971E<B!P<F5C961I;F=#
M:&%P=&5R3&5V96PS(#H@/'AS;#IV86QU92UO9B!S96QE8W0](B1P<F5C961I
M;F=#:&%P=&5R3&5V96PS(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`\>'-L
M.FUE<W-A9V4^4&%R86UE=&5R('!R96-E9&EN9T-H87!T97),979E;#0@.B`\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB)'!R96-E9&EN9T-H87!T97),979E;#0B
M+SX\+WAS;#IM97-S86=E/@H@("`@("`@(#QX<VPZ;65S<V%G93Y087)A;65T
M97(@<')E8V5D:6YG0VAA<'1E<DQE=F5L-2`Z(#QX<VPZ=F%L=64M;V8@<V5L
M96-T/2(D<')E8V5D:6YG0VAA<'1E<DQE=F5L-2(O/CPO>'-L.FUE<W-A9V4^
M"B`@("`@("`@/'AS;#IM97-S86=E/E!A<F%M971E<B!P<F5C961I;F=#:&%P
M=&5R3&5V96PV(#H@/'AS;#IV86QU92UO9B!S96QE8W0](B1P<F5C961I;F=#
M:&%P=&5R3&5V96PV(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`\>'-L.FUE
M<W-A9V4^4&%R86UE=&5R('!R96-E9&EN9T-H87!T97),979E;#<@.B`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB)'!R96-E9&EN9T-H87!T97),979E;#<B+SX\
M+WAS;#IM97-S86=E/@H@("`@("`@(#QX<VPZ;65S<V%G93Y087)A;65T97(@
M<')E8V5D:6YG0VAA<'1E<DQE=F5L."`Z(#QX<VPZ=F%L=64M;V8@<V5L96-T
M/2(D<')E8V5D:6YG0VAA<'1E<DQE=F5L."(O/CPO>'-L.FUE<W-A9V4^"B`@
M("`@("`@/'AS;#IM97-S86=E/E!A<F%M971E<B!P<F5C961I;F=#:&%P=&5R
M3&5V96PY(#H@/'AS;#IV86QU92UO9B!S96QE8W0](B1P<F5C961I;F=#:&%P
M=&5R3&5V96PY(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`\>'-L.FUE<W-A
M9V4^4&%R86UE=&5R('!R96-E9&EN9T-H87!T97),979E;#$P.B`\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB)'!R96-E9&EN9T-H87!T97),979E;#$P(B\^/"]X
M<VPZ;65S<V%G93X*("`@(#PO>'-L.G1E;7!L871E/@H*/"]X<VPZ<W1Y;&5S
M:&5E=#X*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+V]O;R]P86QM
M+GAS;```````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#0Q-3,W(#$P-3$U-#,S
M-S,V(#`R,S8S,``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\(2TM"@H@("!4:&4@0V]N=&5N=',@;V8@=&AI<R!F:6QE(&%R
M92!M861E(&%V86EL86)L92!S=6)J96-T('1O('1H92!T97)M<R!O9@H@("!E
M:71H97(@;V8@=&AE(&9O;&QO=VEN9R!L:6-E;G-E<PH*("`@("`@("`@("T@
M1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8R!,:6-E;G-E(%9E<G-I;VX@,BXQ
M"B`@("`@("`@("`M(%-U;B!);F1U<W1R>2!3=&%N9&%R9',@4V]U<F-E($QI
M8V5N<V4@5F5R<VEO;B`Q+C$*"B`@(%-U;B!-:6-R;W-Y<W1E;7,@26YC+BP@
M3V-T;V)E<BP@,C`P,`H*("`@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8R!,
M:6-E;G-E(%9E<G-I;VX@,BXQ"B`@(#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@("!#;W!Y<FEG:'0@,C`P,"!B>2!3
M=6X@36EC<F]S>7-T96US+"!);F,N"B`@(#DP,2!386X@06YT;VYI;R!2;V%D
M+"!086QO($%L=&\L($-!(#DT,S`S+"!54T$*"B`@(%1H:7,@;&EB<F%R>2!I
M<R!F<F5E('-O9G1W87)E.R!Y;W4@8V%N(')E9&ES=')I8G5T92!I="!A;F0O
M;W(*("`@;6]D:69Y(&ET('5N9&5R('1H92!T97)M<R!O9B!T:&4@1TY5($QE
M<W-E<B!'96YE<F%L(%!U8FQI8PH@("!,:6-E;G-E('9E<G-I;VX@,BXQ+"!A
M<R!P=6)L:7-H960@8GD@=&AE($9R964@4V]F='=A<F4@1F]U;F1A=&EO;BX*
M"B`@(%1H:7,@;&EB<F%R>2!I<R!D:7-T<FEB=71E9"!I;B!T:&4@:&]P92!T
M:&%T(&ET('=I;&P@8F4@=7-E9G5L+`H@("!B=70@5TE42$]55"!!3ED@5T%2
M4D%.5%D[('=I=&AO=70@979E;B!T:&4@:6UP;&EE9"!W87)R86YT>2!O9@H@
M("!-15)#2$%.5$%"24Q)5%D@;W(@1DE43D534R!&3U(@02!005)424-53$%2
M(%!54E!/4T4N("!3964@=&AE($=.50H@("!,97-S97(@1V5N97)A;"!0=6)L
M:6,@3&EC96YS92!F;W(@;6]R92!D971A:6QS+@H*("`@66]U('-H;W5L9"!H
M879E(')E8V5I=F5D(&$@8V]P>2!O9B!T:&4@1TY5($QE<W-E<B!'96YE<F%L
M(%!U8FQI8PH@("!,:6-E;G-E(&%L;VYG('=I=&@@=&AI<R!L:6)R87)Y.R!I
M9B!N;W0L('=R:71E('1O('1H92!&<F5E(%-O9G1W87)E"B`@($9O=6YD871I
M;VXL($EN8RXL(#4Y(%1E;7!L92!0;&%C92P@4W5I=&4@,S,P+"!";W-T;VXL
M"B`@($U!("`P,C$Q,2TQ,S`W("!54T$*"@H@("!3=6X@26YD=7-T<GD@4W1A
M;F1A<F1S(%-O=7)C92!,:6-E;G-E(%9E<G-I;VX@,2XQ"B`@(#T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*("`@
M5&AE(&-O;G1E;G1S(&]F('1H:7,@9FEL92!A<F4@<W5B:F5C="!T;R!T:&4@
M4W5N($EN9'5S=')Y(%-T86YD87)D<PH@("!3;W5R8V4@3&EC96YS92!697)S
M:6]N(#$N,2`H=&AE("),:6-E;G-E(BD[(%EO=2!M87D@;F]T('5S92!T:&ES
M(&9I;&4*("`@97AC97!T(&EN(&-O;7!L:6%N8V4@=VET:"!T:&4@3&EC96YS
M92X@66]U(&UA>2!O8G1A:6X@82!C;W!Y(&]F('1H90H@("!,:6-E;G-E(&%T
M(&AT='`Z+R]W=W<N;W!E;F]F9FEC92YO<F<O;&EC96YS92YH=&UL+@H*("`@
M4V]F='=A<F4@<')O=FED960@=6YD97(@=&AI<R!,:6-E;G-E(&ES('!R;W9I
M9&5D(&]N(&%N(")!4R!)4R(@8F%S:7,L"B`@(%=)5$A/550@5T%24D%.5%D@
M3T8@04Y9($M)3D0L($5)5$A%4B!%6%!215-3($]2($E-4$Q)140L($E.0TQ5
M1$E.1RP*("`@5TE42$]55"!,24U)5$%424].+"!705)204Y42453(%1(050@
M5$A%(%-/1E1705)%($E3($92144@3T8@1$5&14-44RP*("`@34520TA!3E1!
M0DQ%+"!&250@1D]2($$@4$%25$E#54Q!4B!055)03U-%+"!/4B!.3TXM24Y&
M4DE.1TE.1RX*("`@4V5E('1H92!,:6-E;G-E(&9O<B!T:&4@<W!E8VEF:6,@
M<')O=FES:6]N<R!G;W9E<FYI;F<@>6]U<B!R:6=H=',@86YD"B`@(&]B;&EG
M871I;VYS(&-O;F-E<FYI;F<@=&AE(%-O9G1W87)E+@H*("`@5&AE($EN:71I
M86P@1&5V96QO<&5R(&]F('1H92!/<FEG:6YA;"!#;V1E(&ES.B!3=6X@36EC
M<F]S>7-T96US+"!);F,N"@H@("!#;W!Y<FEG:'0@PJD@,C`P,B!B>2!3=6X@
M36EC<F]S>7-T96US+"!);F,N"@H@("!!;&P@4FEG:'1S(%)E<V5R=F5D+@H*
M("`@0V]N=')I8G5T;W(H<RDZ(%]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?
M7U]?7U]?7U]?7U]?7PH*+2T^"CQX<VPZ<W1Y;&5S:&5E="!V97)S:6]N/2(Q
M+C`B"B`@("`@("`@("`@("`@("!X;6QN<SIX<VP](FAT='`Z+R]W=W<N=S,N
M;W)G+S$Y.3DO6%-,+U1R86YS9F]R;2(*("`@("`@("`@("`@("`@('AM;&YS
M.F]F9FEC93TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O;V9F:6-E(@H@
M("`@("`@("`@("`@("`@>&UL;G,Z<W1Y;&4](FAT='`Z+R]O<&5N;V9F:6-E
M+F]R9R\R,#`P+W-T>6QE(@H@("`@("`@("`@("`@("`@>&UL;G,Z=&5X=#TB
M:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O=&5X="(*("`@("`@("`@("`@
M("`@('AM;&YS.G1A8FQE/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]T
M86)L92(*("`@("`@("`@("`@("`@('AM;&YS.F1R87<](FAT='`Z+R]O<&5N
M;V9F:6-E+F]R9R\R,#`P+V1R87=I;F<B"B`@("`@("`@("`@("`@("!X;6QN
M<SIF;STB:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]84TPO1F]R;6%T(@H@("`@
M("`@("`@("`@("`@>&UL;G,Z>&QI;FL](FAT='`Z+R]W=W<N=S,N;W)G+S$Y
M.3DO>&QI;FLB"B`@("`@("`@("`@("`@("!X;6QN<SIN=6UB97(](FAT='`Z
M+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1A=&%S='EL92(*("`@("`@("`@("`@
M("`@('AM;&YS.G-V9STB:'1T<#HO+W=W=RYW,RYO<F<O,C`P,"]S=F<B"B`@
M("`@("`@("`@("`@("!X;6QN<SIC:&%R=#TB:'1T<#HO+V]P96YO9F9I8V4N
M;W)G+S(P,#`O8VAA<G0B"B`@("`@("`@("`@("`@("!X;6QN<SID<C-D/2)H
M='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]D<C-D(@H@("`@("`@("`@("`@
M("`@>&UL;G,Z;6%T:#TB:'1T<#HO+W=W=RYW,RYO<F<O,3DY."]-871H+TUA
M=&A-3"(*("`@("`@("`@("`@("`@('AM;&YS.F9O<FT](FAT='`Z+R]O<&5N
M;V9F:6-E+F]R9R\R,#`P+V9O<FTB"B`@("`@("`@("`@("`@("!X;6QN<SIS
M8W)I<'0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W-C<FEP="(*("`@
M("`@("`@("`@("`@(&]F9FEC93IC;&%S<STB=&5X="(*("`@("`@("`@("`@
M("`@(&]F9FEC93IV97)S:6]N/2(Q+C`B"B`@("`@("`@("`@("`@("!X;6QN
M<SID8STB:'1T<#HO+W!U<FPN;W)G+V1C+V5L96UE;G1S+S$N,2\B"B`@("`@
M("`@("`@("`@("!X;6QN<SIM971A/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O
M,C`P,"]M971A(@H@("`@("`@("`@("`@("`@>&UL;G,Z8V]N9FEG/2)H='1P
M.B\O;W!E;F]F9FEC92YO<F<O,C`P,2]C;VYF:6<B"B`@("`@("`@("`@("`@
M("!X;6QN<SIH96QP/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]H96QP
M(@H@("`@("`@("`@("`@("`@>&UL;G,Z>'0](FAT='`Z+R]W=W<N:F-L87)K
M+F-O;2]X="(*("`@("`@("`@("`@("`@('AM;&YS.G-Y<W1E;3TB:'1T<#HO
M+W=W=RYJ8VQA<FLN8V]M+WAT+VIA=F$O:F%V82YL86YG+E-Y<W1E;2(*("`@
M("`@("`@("`@("`@('AM;&YS.GAA;&%N/2)H='1P.B\O>&UL+F%P86-H92YO
M<F<O>&%L86XB"B`@("`@("`@("`@("`@("!X;6QN<SIJ879A/2)H='1P.B\O
M>&UL+F%P86-H92YO<F<O>'-L="]J879A(@H@("`@("`@("`@("`@("`@97AC
M;'5D92UR97-U;'0M<')E9FEX97,](FIA=F$B/@H*("`@(#QX<VPZ;W5T<'5T
M(&-D871A+7-E8W1I;VXM96QE;65N=',](FUE=&$B+SX*"@H@("`@/"$M+2`J
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H@("`@/"$M+2`J*BH@
M<W!E8VEF:6,@<&%L;2!H96%D97(@*BHJ("TM/@H@("`@/"$M+2`J*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H*("`@(#QX<VPZ=&5M<&QA=&4@
M;F%M93TG<&%L;2UH96%D97(M<')O<&5R=&EE<R<^"B`@("`@("`@/'AS;#IE
M;&5M96YT(&YA;64](FUE=&$B/@H@("`@("`@("`@("`\>'-L.F%T=')I8G5T
M92!N86UE/2)N86UE(CY086QM0V]M<'5T:6YG4&QA=&9O<FT\+WAS;#IA='1R
M:6)U=&4^"B`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](F-O;G1E
M;G0B/G1R=64\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@/"]X<VPZ96QE;65N
M=#X*("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB;65T82(^"B`@("`@("`@
M("`@(#QX<VPZ871T<FEB=71E(&YA;64](FYA;64B/DAA;F1H96QD1G)I96YD
M;'D\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@(#QX<VPZ871T<FEB=71E
M(&YA;64](F-O;G1E;G0B/G1R=64\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@
M/"]X<VPZ96QE;65N=#X*("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB;65T
M82(^"B`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](FYA;64B/DAI
M<W1O<GE,:7-T5&5X=#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@/'AS
M;#IA='1R:6)U=&4@;F%M93TB8V]N=&5N="(^1&%T96EM86YA9V5R)B,Q,#LZ
M("9A;7`[9&%T92`F86UP.W1I;64\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@
M/"]X<VPZ96QE;65N=#X*("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB;65T
M82(^"B`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](FYA;64B/F1E
M<V-R:7!T:6]N/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`\>'-L.F%T
M=')I8G5T92!N86UE/2)C;VYT96YT(CY3=&%R4&]R=&%L/"]X<VPZ871T<FEB
M=71E/@H@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@/'AS;#IE;&5M
M96YT(&YA;64](FUE=&$B/@H@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N
M86UE/2)N86UE(CYK97EW;W)D<SPO>'-L.F%T=')I8G5T93X*("`@("`@("`@
M("`@/'AS;#IA='1R:6)U=&4@;F%M93TB8V]N=&5N="(^<W1A<G!O<G1A;"P@
M<W1A<F]F9FEC92P@<V]F='=A<F4\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@
M/"]X<VPZ96QE;65N=#X*("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB;65T
M82(^"B`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](FAT='`M97%U
M:78B/D-O;G1E;G0M5'EP93PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@
M/'AS;#IA='1R:6)U=&4@;F%M93TB8V]N=&5N="(^=&5X="]H=&UL.R!C:&%R
M<V5T/6ES;RTX.#4Y+3$\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@/"]X<VPZ
M96QE;65N=#X*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\(2TM("HJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ
M(&-R96%T:6YG('1A8FQE(&%T=')I8G5T97,@*BHJ("TM/@H@("`@/"$M+2`J
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H@("`@/"$M
M+2!T86)L92!D871A("AT9"D@86YD('1A8FQE(&AE861E<B`H=&@I(&%T=')I
M8G5T97,@+2T^"B`@("`\>'-L.G1E;7!L871E(&YA;64](F-R96%T92UA='1R
M:6)U=&4M04Q)1TXB/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB<W1Y;&50
M<F]P97)T:65S(B\^"@H@("`@("`@(#QX<VPZ:68@=&5S=#TB8V]N=&%I;G,H
M)'-T>6QE4')O<&5R=&EE<RP@)V%L:6=N)RDB/@H@("`@("`@("`@("`\>'-L
M.F%T=')I8G5T92!N86UE/2)A;&EG;B(^"B`@("`@("`@("`@("`@("`@/'AS
M;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(F-O;G1A:6YS*"1S='EL95!R;W!E<G1I97,L("=A;&EG;CIL969T)RDB/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^;&5F=#PO>'-L.G1E
M>'0^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'-T>6QE4')O
M<&5R=&EE<RP@)V%L:6=N.G)I9VAT)RDB/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G1E>'0^<FEG:'0\+WAS;#IT97AT/@H@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IO
M=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YC
M96YT97(\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T
M:&5R=VES93X*("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@
M("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`\+WAS;#II9CX*("`@
M(#PO>'-L.G1E;7!L871E/@H*"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ(&-R96%T:6YG($QI
M<W0@871T<FEB=71E<R`@*BHJ("TM/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"CPA+2T*("`@(#QX<VPZ=&5M<&QA
M=&4@;F%M93TB8W)E871E+6QI<W0M871T<FEB=71E<R(^"B`@("`@("`@/'AS
M;#IP87)A;2!N86UE/2)S='EL95!R;W!E<G1I97,B+SX*"@HA(2$A(2$A(2$A
M(2$A(2$A(2$A(2$A(2$A(2$A(0HR(&)E(&EM<&QE;65N=&5D"B$A(2$A(2$A
M(2$A(2$A(2$A(2$A(2$A(2$A(2$A"@H*("`@(#PO>'-L.G1E;7!L871E/@HM
M+3X*"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ(&-R96%T:6YG(&YE
M<W1E9"!F;W)M870@=&%G<R`H4$%,32`F(%=-3"D@*BHJ("TM/@H@("`@/"$M
M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BH@+2T^"@H@("`@/"$M+2!)=&%L:6,@+2T^"B`@("`\>'-L.G1E;7!L
M871E(&YA;64](F-R96%T92UN97-T960M9F]R;6%T+71A9W,B/@H@("`@("`@
M(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@
M("`@(#QX<VPZ<&%R86T@;F%M93TB<W1Y;&50<F]P97)T:65S(B\^"B`@("`@
M("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C
M;VYT86EN<R@D<W1Y;&50<F]P97)T:65S+"`G:71A;&EC)RDB/@H@("`@("`@
M("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](FDB/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)B;VQD(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE
M4')O<&5R=&EE<R(@<V5L96-T/2(D<W1Y;&50<F]P97)T:65S(B\^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL
M96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A
M(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*
M("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@(#PO
M>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@
M("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F)O;&0B/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL95!R
M;W!E<G1I97,B('-E;&5C=#TB)'-T>6QE4')O<&5R=&EE<R(O/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961'
M;&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@
M("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@
M("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@
M/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#PA+2T@0F]L9"`M+3X*("`@(#QX<VPZ
M=&5M<&QA=&4@;F%M93TB8F]L9"(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE
M/2)C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@/'AS;#IP87)A;2!N
M86UE/2)S='EL95!R;W!E<G1I97,B+SX*"B`@("`@("`@/'AS;#IC:&]O<V4^
M"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@D<W1Y;&50
M<F]P97)T:65S+"`G8F]L9"<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ96QE
M;65N="!N86UE/2)B(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM
M=&5M<&QA=&4@;F%M93TB=6YD97)L:6YE(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE4')O<&5R=&EE<R(@
M<V5L96-T/2(D<W1Y;&50<F]P97)T:65S(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$
M871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@
M("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@
M("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/'AS
M;#IC86QL+71E;7!L871E(&YA;64](G5N9&5R;&EN92(^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE4')O<&5R=&EE
M<R(@<V5L96-T/2(D<W1Y;&50<F]P97)T:65S(B\^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A
M=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@
M("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L
M.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT
M96UP;&%T93X*"@H@("`@/"$M+2!5;F1E<FQI;F4@.B!L87-T(&9O<FUA="!A
M='1R:6)U=&4L('=H:6-H(&ES(&%L<V\@=7-E9"!F<F]M(%=-3"`M(%=-3"!E
M;F1S(&AE<F4A("TM/@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)U;F1E<FQI
M;F4B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L
M1&%T82(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB<W1Y;&50<F]P97)T
M:65S(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G4$%,32<B/@H@("`@("`@("`@
M("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:&5N('1E<W0](F-O;G1A:6YS*"1S='EL95!R;W!E<G1I97,L("=U;F1E<FQI
M;F4G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N
M86UE/2)U(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L
M;"UT96UP;&%T92!N86UE/2)S=')I:V5T:')O=6=H(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y
M;&50<F]P97)T:65S(B!S96QE8W0](B1S='EL95!R;W!E<G1I97,B+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D
M1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB<W1R:6ME
M=&AR;W5G:"(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB<W1Y;&50<F]P97)T:65S(B!S96QE8W0](B1S='EL
M95!R;W!E<G1I97,B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE
M8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/"]X<VPZ8VAO
M;W-E/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L
M.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@D<W1Y
M;&50<F]P97)T:65S+"`G=6YD97)L:6YE)RDB/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB=2(^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E<SX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L
M1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ87!P
M;'DM=&5M<&QA=&5S/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IE
M;&5M96YT/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E
M9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S
M/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@
M("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@/"]X<VPZ;W1H
M97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L
M871E/@H*"B`@("`\(2TM('-T<FEK971H<F]U9V@@+2T^"B`@("`\>'-L.G1E
M;7!L871E(&YA;64](G-T<FEK971H<F]U9V@B/@H@("`@("`@(#QX<VPZ<&%R
M86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@(#QX<VPZ
M<&%R86T@;F%M93TB<W1Y;&50<F]P97)T:65S(B\^"@H@("`@("`@(#QX<VPZ
M8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H
M)'-T>6QE4')O<&5R=&EE<RP@)W-T<FEK92<I(CX*("`@("`@("`@("`@("`@
M(#QX<VPZ96QE;65N="!N86UE/2)S=')I:V4B/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A;&EG;B(^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL95!R
M;W!E<G1I97,B('-E;&5C=#TB)'-T>6QE4')O<&5R=&EE<R(O/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C
M=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O
M/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@
M("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`\+WAS
M;#IW:&5N/@H@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A;&EG;B(^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE4')O
M<&5R=&EE<R(@<V5L96-T/2(D<W1Y;&50<F]P97)T:65S(B\^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L
M;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@
M("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@
M(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\
M+WAS;#IT96UP;&%T93X*"@H@("`@/"$M+2!!;&EG;FUE;G0@+2T^"B`@("`\
M>'-L.G1E;7!L871E(&YA;64](F%L:6=N(CX*("`@("`@("`\>'-L.G!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`\>'-L.G!A
M<F%M(&YA;64](G-T>6QE4')O<&5R=&EE<R(O/@H*("`@("`@("`\>'-L.F-H
M;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1S
M='EL95!R;W!E<G1I97,L("=A;&EG;B<I(CX*("`@("`@("`@("`@("`@(#QX
M<VPZ96QE;65N="!N86UE/2)D:78B/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ871T<FEB=71E(&YA;64](F%L:6=N(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1S='EL95!R;W!E<G1I97,L
M("=A;&EG;CIL969T)RDB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=&5X=#YL969T/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'-T>6QE4')O<&5R
M=&EE<RP@)V%L:6=N.G)I9VAT)RDB/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=&5X=#YR:6=H=#PO>'-L.G1E>'0^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/F-E;G1E<CPO>'-L.G1E>'0^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)F;VYT7V-O;6)I;F5D
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](G-T>6QE4')O<&5R=&EE<R(@<V5L96-T/2(D<W1Y;&50<F]P97)T:65S
M(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961'
M;&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT
M96UP;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E
M/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F9O
M;G1?8V]M8FEN960B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)S='EL95!R;W!E<G1I97,B('-E;&5C=#TB)'-T>6QE4')O
M<&5R=&EE<R(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T
M961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E
M;7!L871E/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@
M/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#PA+2T@
M0F]T:"!S:7IE(&%N9"!#;VQO<B!F;W(@9F]N="`M+3X*("`@(#QX<VPZ=&5M
M<&QA=&4@;F%M93TB9F]N=%]C;VUB:6YE9"(^"B`@("`@("`@/'AS;#IP87)A
M;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@/'AS;#IP
M87)A;2!N86UE/2)S='EL95!R;W!E<G1I97,B+SX*"B`@("`@("`@/'AS;#IC
M:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@D
M<W1Y;&50<F]P97)T:65S+"`G8V]L;W(G*2!A;F0@8V]N=&%I;G,H)'-T>6QE
M4')O<&5R=&EE<RP@)W-I>F4G*2(^"B`@("`@("`@("`@("`@("`\>'-L.F5L
M96UE;G0@;F%M93TB9F]N="(^"@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M871T<FEB=71E(&YA;64](F-O;&]R(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1S='EL95!R;W!E<G1I97,L("=C
M;VQO<CHC,#`P,#`P)RDB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=&5X=#XC,#`P,#`P/"]X<VPZ=&5X=#X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G1E>'0^(T9&1D9&1CPO>'-L.G1E>'0^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H*("`@("`@("`@("`@("`@
M("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)S:7IE(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G-U8G-T<FEN9RUA
M9G1E<BAS=6)S=')I;F<M8F5F;W)E*"1S='EL95!R;W!E<G1I97,@+"<Z<VEZ
M92<I+"`G<VEZ93HG*2(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%T
M=')I8G5T93X*"B`@("`@("`@("`@("`@("`@("`@/"$M+2!G970@=&AE(&5M
M8F5D9&5D(&-O;G1E;G0@+2T^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IA
M<'!L>2UT96UP;&%T97,^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0]
M(B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@("`@("`@("`@("`@/"]X<VPZ
M96QE;65N=#X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M
M<&QA=&4@;F%M93TB9F]N=%]S:6UP;&4B/@H@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL95!R;W!E<G1I97,B('-E;&5C
M=#TB)'-T>6QE4')O<&5R=&EE<R(O/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE
M8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`\
M+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I
M<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^
M"@H*("`@(#PA+2T@<VEZ92!O<B!#;VQO<B!F;W(@9F]N="`M+3X*("`@(#QX
M<VPZ=&5M<&QA=&4@;F%M93TB9F]N=%]S:6UP;&4B/@H@("`@("`@(#QX<VPZ
M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@(#QX
M<VPZ<&%R86T@;F%M93TB<W1Y;&50<F]P97)T:65S(B\^"@H@("`@("`@(#QX
M<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I
M;G,H)'-T>6QE4')O<&5R=&EE<RP@)V-O;&]R)RDB/@H@("`@("`@("`@("`@
M("`@/'AS;#IE;&5M96YT(&YA;64](F9O;G0B/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ871T<FEB=71E(&YA;64](F-O;&]R(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1S='EL95!R;W!E
M<G1I97,L("=C;VQO<CHC,#`P,#`P)RDB/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=&5X=#XC,#`P,#`P/"]X<VPZ=&5X=#X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^(T9&1D9&1CPO>'-L
M.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE
M<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^
M"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H*("`@("`@
M("`@("`@("`@("`@("`\(2TM(&=E="!T:&4@96UB961D960@8V]N=&5N="`M
M+3X*("`@("`@("`@("`@("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E<SX*
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IA<'!L>2UT96UP
M;&%T97,^"B`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(F-O;G1A:6YS*"1S='EL95!R;W!E<G1I97,L("=S:7IE)RDB/@H@("`@("`@
M("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](F9O;G0B/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](G-I>F4B/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<W5B<W1R
M:6YG+6%F=&5R*'-U8G-T<FEN9RUB969O<F4H)'-T>6QE4')O<&5R=&EE<R`L
M)SIS:7IE)RDL("=S:7IE.B<I(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ871T<FEB=71E/@H*("`@("`@("`@("`@("`@("`@("`\(2TM(&=E="!T
M:&4@96UB961D960@8V]N=&5N="`M+3X*("`@("`@("`@("`@("`@("`@("`\
M>'-L.F%P<&QY+71E;7!L871E<SX*("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E
M;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^"B`@("`@("`@("`@("`@("`\
M+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H*("`@("`@
M("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\(2TM(&=E
M="!T:&4@96UB961D960@8V]N=&5N="`M+3X*("`@("`@("`@("`@("`@(#QX
M<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0]
M(B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`\+WAS
M;#IA<'!L>2UT96UP;&%T97,^"B`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES
M93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*
M"@H\+WAS;#IS='EL97-H965T/@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E
M<B]O;V\O<W1Y;&5?;6%P<&EN9RYX<VP`````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#$Q,#0S
M,B`Q,#4Q-30S,S<S-B`P,C4U-#$`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/"$M+0H*("`@5&AE($-O;G1E;G1S(&]F('1H
M:7,@9FEL92!A<F4@;6%D92!A=F%I;&%B;&4@<W5B:F5C="!T;R!T:&4@=&5R
M;7,@;V8*("`@96ET:&5R(&]F('1H92!F;VQL;W=I;F<@;&EC96YS97,*"B`@
M("`@("`@("`M($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,@3&EC96YS92!6
M97)S:6]N(#(N,0H@("`@("`@("`@+2!3=6X@26YD=7-T<GD@4W1A;F1A<F1S
M(%-O=7)C92!,:6-E;G-E(%9E<G-I;VX@,2XQ"@H@("!3=6X@36EC<F]S>7-T
M96US($EN8RXL($]C=&]B97(L(#(P,#`*"B`@($=.52!,97-S97(@1V5N97)A
M;"!0=6)L:6,@3&EC96YS92!697)S:6]N(#(N,0H@("`]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*("`@0V]P>7)I9VAT
M(#(P,#`@8GD@4W5N($UI8W)O<WES=&5M<RP@26YC+@H@("`Y,#$@4V%N($%N
M=&]N:6\@4F]A9"P@4&%L;R!!;'1O+"!#02`Y-#,P,RP@55-!"@H@("!4:&ES
M(&QI8G)A<GD@:7,@9G)E92!S;V9T=V%R93L@>6]U(&-A;B!R961I<W1R:6)U
M=&4@:70@86YD+V]R"B`@(&UO9&EF>2!I="!U;F1E<B!T:&4@=&5R;7,@;V8@
M=&AE($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,*("`@3&EC96YS92!V97)S
M:6]N(#(N,2P@87,@<'5B;&ES:&5D(&)Y('1H92!&<F5E(%-O9G1W87)E($9O
M=6YD871I;VXN"@H@("!4:&ES(&QI8G)A<GD@:7,@9&ES=')I8G5T960@:6X@
M=&AE(&AO<&4@=&AA="!I="!W:6QL(&)E('5S969U;"P*("`@8G5T(%=)5$A/
M550@04Y9(%=!4E)!3E19.R!W:71H;W5T(&5V96X@=&AE(&EM<&QI960@=V%R
M<F%N='D@;V8*("`@34520TA!3E1!0DE,2519(&]R($9)5$Y%4U,@1D]2($$@
M4$%25$E#54Q!4B!055)03U-%+B`@4V5E('1H92!'3E4*("`@3&5S<V5R($=E
M;F5R86P@4'5B;&EC($QI8V5N<V4@9F]R(&UO<F4@9&5T86EL<RX*"B`@(%EO
M=2!S:&]U;&0@:&%V92!R96-E:79E9"!A(&-O<'D@;V8@=&AE($=.52!,97-S
M97(@1V5N97)A;"!0=6)L:6,*("`@3&EC96YS92!A;&]N9R!W:71H('1H:7,@
M;&EB<F%R>3L@:68@;F]T+"!W<FET92!T;R!T:&4@1G)E92!3;V9T=V%R90H@
M("!&;W5N9&%T:6]N+"!);F,N+"`U.2!496UP;&4@4&QA8V4L(%-U:71E(#,S
M,"P@0F]S=&]N+`H@("!-02`@,#(Q,3$M,3,P-R`@55-!"@H*("`@4W5N($EN
M9'5S=')Y(%-T86YD87)D<R!3;W5R8V4@3&EC96YS92!697)S:6]N(#$N,0H@
M("`]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]"B`@(%1H92!C;VYT96YT<R!O9B!T:&ES(&9I;&4@87)E('-U8FIE
M8W0@=&\@=&AE(%-U;B!);F1U<W1R>2!3=&%N9&%R9',*("`@4V]U<F-E($QI
M8V5N<V4@5F5R<VEO;B`Q+C$@*'1H92`B3&EC96YS92(I.R!9;W4@;6%Y(&YO
M="!U<V4@=&AI<R!F:6QE"B`@(&5X8V5P="!I;B!C;VUP;&EA;F-E('=I=&@@
M=&AE($QI8V5N<V4N(%EO=2!M87D@;V)T86EN(&$@8V]P>2!O9B!T:&4*("`@
M3&EC96YS92!A="!H='1P.B\O=W=W+F]P96YO9F9I8V4N;W)G+VQI8V5N<V4N
M:'1M;"X*"B`@(%-O9G1W87)E('!R;W9I9&5D('5N9&5R('1H:7,@3&EC96YS
M92!I<R!P<F]V:61E9"!O;B!A;B`B05,@25,B(&)A<VES+`H@("!7251(3U54
M(%=!4E)!3E19($]&($%.62!+24Y$+"!%251(15(@15A04D534R!/4B!)35!,
M245$+"!)3D-,541)3D<L"B`@(%=)5$A/550@3$E-251!5$E/3BP@5T%24D%.
M5$E%4R!42$%4(%1(12!33T945T%212!)4R!&4D5%($]&($1%1D5#5%,L"B`@
M($U%4D-(04Y404),12P@1DE4($9/4B!!(%!!4E1)0U5,05(@4%524$]312P@
M3U(@3D].+4E.1E))3D=)3D<N"B`@(%-E92!T:&4@3&EC96YS92!F;W(@=&AE
M('-P96-I9FEC('!R;W9I<VEO;G,@9V]V97)N:6YG('EO=7(@<FEG:'1S(&%N
M9`H@("!O8FQI9V%T:6]N<R!C;VYC97)N:6YG('1H92!3;V9T=V%R92X*"B`@
M(%1H92!);FET:6%L($1E=F5L;W!E<B!O9B!T:&4@3W)I9VEN86P@0V]D92!I
M<SH@4W5N($UI8W)O<WES=&5M<RP@26YC+@H*("`@0V]P>7)I9VAT(,*I(#(P
M,#(@8GD@4W5N($UI8W)O<WES=&5M<RP@26YC+@H*("`@06QL(%)I9VAT<R!2
M97-E<G9E9"X*"B`@($-O;G1R:6)U=&]R*',I.B!?7U]?7U]?7U]?7U]?7U]?
M7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U\*"BTM/@H\>'-L.G-T>6QE<VAE970@
M=F5R<VEO;CTB,2XP(@H@("`@("`@("`@("`@("`@>&UL;G,Z>'-L/2)H='1P
M.B\O=W=W+G<S+F]R9R\Q.3DY+UA33"]4<F%N<V9O<FTB"B`@("`@("`@("`@
M("`@("!X;6QN<SIO9F9I8V4](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P
M+V]F9FEC92(*("`@("`@("`@("`@("`@('AM;&YS.G-T>6QE/2)H='1P.B\O
M;W!E;F]F9FEC92YO<F<O,C`P,"]S='EL92(*("`@("`@("`@("`@("`@('AM
M;&YS.G1E>'0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W1E>'0B"B`@
M("`@("`@("`@("`@("!X;6QN<SIT86)L93TB:'1T<#HO+V]P96YO9F9I8V4N
M;W)G+S(P,#`O=&%B;&4B"B`@("`@("`@("`@("`@("!X;6QN<SID<F%W/2)H
M='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]D<F%W:6YG(@H@("`@("`@("`@
M("`@("`@>&UL;G,Z9F\](FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3DO6%-,+T9O
M<FUA="(*("`@("`@("`@("`@("`@('AM;&YS.GAL:6YK/2)H='1P.B\O=W=W
M+G<S+F]R9R\Q.3DY+WAL:6YK(@H@("`@("`@("`@("`@("`@>&UL;G,Z;G5M
M8F5R/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]D871A<W1Y;&4B"B`@
M("`@("`@("`@("`@("!X;6QN<SIS=F<](FAT='`Z+R]W=W<N=S,N;W)G+S(P
M,#`O<W9G(@H@("`@("`@("`@("`@("`@>&UL;G,Z8VAA<G0](FAT='`Z+R]O
M<&5N;V9F:6-E+F]R9R\R,#`P+V-H87)T(@H@("`@("`@("`@("`@("`@>&UL
M;G,Z9'(S9#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O9'(S9"(*("`@
M("`@("`@("`@("`@('AM;&YS.FUA=&@](FAT='`Z+R]W=W<N=S,N;W)G+S$Y
M.3@O36%T:"]-871H34PB"B`@("`@("`@("`@("`@("!X;6QN<SIF;W)M/2)H
M='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]F;W)M(@H@("`@("`@("`@("`@
M("`@>&UL;G,Z<V-R:7!T/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]S
M8W)I<'0B"B`@("`@("`@("`@("`@("!O9F9I8V4Z8VQA<W,](G1E>'0B"B`@
M("`@("`@("`@("`@("!O9F9I8V4Z=F5R<VEO;CTB,2XP(@H@("`@("`@("`@
M("`@("`@>&UL;G,Z9&,](FAT='`Z+R]P=7)L+F]R9R]D8R]E;&5M96YT<R\Q
M+C$O(@H@("`@("`@("`@("`@("`@>&UL;G,Z;65T83TB:'1T<#HO+V]P96YO
M9F9I8V4N;W)G+S(P,#`O;65T82(*("`@("`@("`@("`@("`@('AM;&YS.F-O
M;F9I9STB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#$O8V]N9FEG(@H@("`@
M("`@("`@("`@("`@>&UL;G,Z:&5L<#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G
M+S(P,#`O:&5L<"(*("`@("`@("`@("`@("`@('AM;&YS.GAT/2)H='1P.B\O
M=W=W+FIC;&%R:RYC;VTO>'0B"B`@("`@("`@("`@("`@("!X;6QN<SIS>7-T
M96T](FAT='`Z+R]W=W<N:F-L87)K+F-O;2]X="]J879A+VIA=F$N;&%N9RY3
M>7-T96TB"B`@("`@("`@("`@("`@("!X;6QN<SIX86QA;CTB:'1T<#HO+WAM
M;"YA<&%C:&4N;W)G+WAA;&%N(@H@("`@("`@("`@("`@("`@>&UL;G,Z:F%V
M83TB:'1T<#HO+WAM;"YA<&%C:&4N;W)G+WAS;'0O:F%V82(*("`@("`@("`@
M("`@("`@(&5X8VQU9&4M<F5S=6QT+7!R969I>&5S/2)J879A(CX*"@H@("`@
M/'AS;#IT96UP;&%T92!N86UE/2)W<FET92US='EL92UP<F]P97)T:65S(CX*
M("`@("`@("`\>'-L.G!A<F%M(&YA;64](G-T>6QE071T<FEB=71E4&%T:"(O
M/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/"$M+2LK*RLK
M($-34R!04D]015)42453("`K*RLK*RTM/@H@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G0U-37TA%041%4B<@;W(@)&]U='!U
M=%1Y<&4@/2`G0U-37TE.3$E.140G(CX*"B`@("`@("`@("`@("`@("`\>'-L
M.F9O<BUE86-H('-E;&5C=#TB)'-T>6QE071T<FEB=71E4&%T:"(^"B`@("`@
M("`@("`@("`@("`\(2TM(&ES1&5B=6=-;V1E34534T%'13H*("`@("`@("`@
M("`@("`@("`@("`\>'-L.FUE<W-A9V4^($YA;64Z/'AS;#IV86QU92UO9B!S
M96QE8W0](FYA;64H*2(O/B!686QU93H\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M+B(O/CPO>'-L.FUE<W-A9V4^("`@("`@+2T^"@H*("`@("`@("`@("`@("`@
M("`@("`\(2TM(#PA05143$E35"!S='EL93IP<F]P97)T:65S('-T>6QE.FAO
M<FEZ;VYT86PM<&]S("AF<F]M+6QE9G1\;&5F='QC96YT97)\<FEG:'1\9G)O
M;2UI;G-I9&5\:6YS:61E?&]U='-I9&4I(TE-4$Q)140^+2T^"B`@("`@("`@
M("`@("`@("`@("`@/"$M+2`R1$\Z(&ES(&EN<VED92]F<F]M+6EN<VED92!A
M;'-O(&)E='1E<B!S:&]W86)L92`_("TM/@H@("`@("`@("`@("`@("`@("`@
M(#PA+2T@(2$A(2`R1$\Z(%-T:6QL('1H97)E(&AA=F4@=&\@8F4@<&QA8V5D
M(&$@/&)R(&-L96%R/2=A;&PG+SX@=&\@9&ES86)L92!T:&4@9FQO=R$A(2$M
M+3X*("`@("`@("`@("`@("`@("`@("`\(2TM("`@("`@("`@("!4:&4@3T]O
M(&%T=')I8G5T92`G<W1Y;&4Z;G5M8F5R+7=R87!P960M<&%R86=R87!H<R<@
M:7,@8W5R<F5N=&QY(&EG;F]R960@+2T^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2=N86UE*"XI/2)S='EL93IW<F%P(B<^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG+CTB;&5F="(G/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^9FQO
M870Z(')I9VAT.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0])RX](G)I9VAT(B<^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YF;&]A=#H@
M;&5F=#L@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M)VYA;64H+BD@/2`B<W1Y;&4Z:&]R:7IO;G1A;"UP;W,B)SX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2<N/2)L969T(B<^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X
M=#YA;&EG;CH@;&5F=#L@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2<N/2)R:6=H="(G/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^86QI
M9VXZ(')I9VAT.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0])RX](F-E;G1E<B(G/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^86QI9VXZ
M(&-E;G1E<CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IW:&5N/@H\(2TM(')E<W5L=',@:6YT;R!A(&)A9"!V:65W("AO=F5R;&%P
M<&5D*2!I;B!-;WII;&QA(#$N,`H@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=H96X@=&5S=#TG;F%M92@N*2`](")T86)L93IA;&EG;B(G/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])RX](FQE
M9G0B)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IT97AT/F9L;V%T.B!R:6=H=#L@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2<N/2)R:6=H="(G
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E
M>'0^9FQO870Z(&QE9G0[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*+2T^"@H@("`@("`@("`@("`@("`@("`@("`@("`\
M(2TM(%!!1$1)3D<@9F]R(&%L;"!V87)I871I;VYS.B!F;SIP861D:6YG+"!F
M;SIP861D:6YG+71O<"P@9F\Z<&%D9&EN9RUB;W1T;VTL(&9O.G!A9&1I;F<M
M;&5F="P@9F\Z<&%D9&EN9RUR:6=H="`M+3X*("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0])V-O;G1A:6YS*&YA;64H+BDL(F9O.G!A
M9&1I;F<B*2<^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E
M>'0^<&%D9&EN9SH@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\(2TM"B`@("`@("`@("`@("`@("`@("`@("`@(&9O.F)O
M<F1E<@H@("`@("`@("`@("`@("`@("`@("`@("!F;SIB;W)D97(M=&]P"B`@
M("`@("`@("`@("`@("`@("`@("`@(&9O.F)O<F1E<BUB;W1T;VT*("`@("`@
M("`@("`@("`@("`@("`@("`@9F\Z8F]R9&5R+6QE9G0*("`@("`@("`@("`@
M("`@("`@("`@("`@9F\Z8F]R9&5R+7)I9VAT"@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@070@<')E<V5N="P@86QL(&9O=7(@8F]R9&5R<R!M=7-T
M(&)E('-E="!S:6UU;'1A;F5O=7-L>2!B>2!U<VEN9R!E:71H97(*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('1H92!F;SIB;W)D97(@<')O<&5R='D@
M;W(@8GD@871T86-H:6YG(&%L;"!F;W5R(&]F('1H92!O=&AE<B!B;W)D97(*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('!R;W!E<G1I97,@=&\@86X@
M:71E;2!S970@96QE;65N="X@26X@=&AE(&QA='1E<B!C87-E+"!I9B!O;F4@
M;W(@;6]R90H@("`@("`@("`@("`@("`@("`@("`@("`@("`@;V8@=&AE('!R
M;W!E<G1I97,@:7,@;6ES<VEN9R!T:&5I<B!V86QU97,@87)E(&%S<W5M960@
M=&\@8F4@;F]N92X@5&AE"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!O
M;FQY(&)O<F1E<B!S='EL97,@<W5P<&]R=&5D(&%R92!N;VYE(&]R(&AI9&1E
M;BP@<V]L:60L(&%N9"!D;W5B;&4N($%N>0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@;W1H97(@8F]R9&5R('-T>6QE('-P96-I9FEE9"!I<R!D:7-P
M;&%Y960@87,@<V]L:60N(%1R86YS<&%R96YT(&)O<F1E<G,*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&%R92!N;W0@<W5P<&]R=&5D(&%N9"!T:&4@
M8F]R9&5R('=I9'1H<R!T:&EN+"!M961I=6TL(&%N9"!T:&EC:R!A<F4*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&UA<'!E9"!T;R!L96YG=&AS+B!)
M;B!A9&1I=&EO;BP@;VYL>2!S;VUE(&1I<W1I;F-T(&)O<F1E<B!W:61T:',@
M87)E"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!S=7!P;W)T960N(%5N
M<W5P<&]R=&5D('=I9'1H<R!A<F4@<F]U;F1E9"!U<"!T;R!T:&4@;F5X="!S
M=7!P;W)T960*("`@("`@("`@("`@("`@("`@("`@("`@("`@('=I9'1H+@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@268@=&AE<F4@87)E(&YO('!A
M9&1I;F<@<')O<&5R=&EE<R!S<&5C:69I960@=VET:&EN('1H92!S86UE"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I=&5M('-E="!E;&5M96YT+"!A
M(&1E9F%U;'0@<&%D9&EN9R!I<R!U<V5D(&9O<B!S:61E<R!T:&%T(&AA=F4@
M80H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8F]R9&5R+B!!('9A;'5E
M(&]F(#!C;2!I<R!U<V5D(&9O<B!S:61E<R!W:71H;W5T(&$@8F]R9&5R+@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@*&-P+B!W9"US;RUX;6PM=&5X
M="YS9'<I"B`@("`@("`@("`@("`@("`@("`@("`@("TM/@H*/"$M+3)$3R!3
M5$%25#H@8VAA;F=E(&UE87-U<F5M96YT(&5Q=6%L;'D@+2T^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)F;SIB
M;W)D97(B)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO
M;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@8VAA
M;F=I;F<@=&AE(&1I<W1A;F-E(&UE87-U<F4Z(&EN8V@@=&\@:6X@+2T^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(F-O;G1A:6YS*"XL("=C:"<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IT97AT/F)O<F1E<BUW:61T:#H\+WAS;#IT97AT
M/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)S=6)S=')I;F<M8F5F;W)E*"XL)V-H
M("<I(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/F)O<F1E<BUS='EL93H\
M+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)S=6)S=')I;F<M8F5F
M;W)E*'-U8G-T<FEN9RUA9G1E<B@N+"=C:"`G*2P@)R`G*2(O/CQX<VPZ=&5X
M=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=&5X=#YB;W)D97(M8V]L;W(Z/"]X<VPZ=&5X=#X\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB<W5B<W1R:6YG+6%F=&5R*'-U8G-T<FEN9RUA
M9G1E<B@N+"=C:"`G*2P@)R`G*2(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TB8V]N=&%I;G,H+BP@)V-M)RDB/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G1E>'0^8F]R9&5R+7=I9'1H.CPO>'-L.G1E
M>'0^/'AS;#IV86QU92UO9B!S96QE8W0](G-U8G-T<FEN9RUB969O<F4H+BPG
M("<I(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/F)O<F1E<BUS='EL93H\
M+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)S=6)S=')I;F<M8F5F
M;W)E*'-U8G-T<FEN9RUA9G1E<B@N+"=C;2`G*2P@)R`G*2(O/CQX<VPZ=&5X
M=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=&5X=#YB;W)D97(M8V]L;W(Z/"]X<VPZ=&5X=#X\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB<W5B<W1R:6YG+6%F=&5R*'-U8G-T<FEN9RUA
M9G1E<B@N+"=C;2`G*2P@)R`G*2(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TB8V]N=&%I;G,H+BP@)W!T)RDB/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G1E>'0^8F]R9&5R+7=I9'1H.CPO>'-L.G1E
M>'0^/'AS;#IV86QU92UO9B!S96QE8W0](G-U8G-T<FEN9RUB969O<F4H+BPG
M("<I(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/F)O<F1E<BUS='EL93H\
M+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)S=6)S=')I;F<M8F5F
M;W)E*'-U8G-T<FEN9RUA9G1E<B@N+"=P="`G*2P@)R`G*2(O/CQX<VPZ=&5X
M=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=&5X=#YB;W)D97(M8V]L;W(Z/"]X<VPZ=&5X=#X\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB<W5B<W1R:6YG+6%F=&5R*'-U8G-T<FEN9RUA
M9G1E<B@N+"=P="`G*2P@)R`G*2(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](F9O.F)O<F1E
M<BUT;W`B)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X
M=#YB;W)D97(M=&]P.B`\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T
M/2(N(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:&5N('1E<W0])VYA;64H+BD](F9O.F)O<F1E<BUB;W1T;VTB)SX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YB;W)D97(M
M8F]T=&]M.B`\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^
M/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:&5N('1E<W0])VYA;64H+BD](F9O.F)O<F1E<BUL969T(B<^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^8F]R9&5R+6QE9G0Z(#PO
M>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](BXB+SX\>'-L.G1E>'0^
M.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG
M;F%M92@N*3TB9F\Z8F]R9&5R+7)I9VAT(B<^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G1E>'0^8F]R9&5R+7)I9VAT.B`\+WAS;#IT97AT
M/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^/'AS;#IT97AT/CL@/"]X<VPZ
M=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD]
M(G-T>6QE.F-O;'5M;BUW:61T:"(G/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"$M+2!C:&%N9VEN9R!T:&4@9&ES=&%N8V4@;65A<W5R93H@:6YC
M:"!T;R!I;B`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H+BP@)V-H)RDB/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^=VED=&@Z/"]X
M<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB<W5B<W1R:6YG+6)E9F]R
M92@N+"=C:"<I(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^=VED=&@Z
M/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O/CQX<VPZ=&5X
M=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TG;F%M92@N*3TB<W1Y;&4Z<F]W+6AE:6=H="(G/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"$M+2!C:&%N9VEN9R!T:&4@9&ES=&%N8V4@;65A
M<W5R93H@:6YC:"!T;R!I;B`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H+BP@)V-H)RDB/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^
M:&5I9VAT.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](G-U8G-T
M<FEN9RUB969O<F4H+BPG8V@G*2(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES
M93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT
M97AT/FAE:6=H=#H\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(N
M(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)F;SIW:61T:"(G/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/"$M+2!C:&%N9VEN9R!T:&4@9&ES=&%N8V4@
M;65A<W5R93H@:6YC:"!T;R!I;B`M+3X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H+BP@)V-H)RDB
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E
M>'0^=VED=&@Z/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB<W5B
M<W1R:6YG+6)E9F]R92@N+"=C:"<I(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X
M=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W
M:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G1E>'0^=VED=&@Z/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M+B(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H\(2TM,D1/($5.1#H@8VAA;F=E(&UE87-U
M<F5M96YT(&5Q=6%L;'D@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)F;SIF;VYT+7-T>6QE(B<^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M<W5B<W1R:6YG+6%F=&5R*&YA;64H+BDL("<Z)RDB+SX\>'-L.G1E>'0^.CPO
M>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](BXB+SX\>'-L.G1E>'0^
M.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG
M;F%M92@N*3TB<W1Y;&4Z9F]N="UN86UE(B<^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G1E>'0^9F]N="UF86UI;'DZ/"]X<VPZ=&5X=#X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE
M(&YA;64](F-O;G1E;G0B('-E;&5C=#TB+B(O/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D;V9F:6-E
M.F9O;G0M9&5C;',O<W1Y;&4Z9F]N="UD96-L6T!S='EL93IN86UE/21C;VYT
M96YT72]`9F\Z9F]N="UF86UI;'DB+SX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](F-O;G1A:6YS*"1O9F9I8V4Z
M9F]N="UD96-L<R]S='EL93IF;VYT+61E8VQ;0'-T>6QE.FYA;64])&-O;G1E
M;G1=+T!S='EL93IF;VYT+7-T>6QE+6YA;64L("=)=&%L:6,G*2(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/F9O;G0M<W1Y
M;&4Z:71A;&EC.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ:68^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.FEF('1E<W0](F-O;G1A:6YS*"1O9F9I8V4Z9F]N="UD96-L<R]S='EL
M93IF;VYT+61E8VQ;0'-T>6QE.FYA;64])&-O;G1E;G1=+T!S='EL93IF;VYT
M+7-T>6QE+6YA;64L("=";VQD)RDB/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=&5X=#YF;VYT+7=E:6=H=#IB;VQD.R`\+WAS;#IT
M97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ:68^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)F;SIF;VYT
M+7=E:6=H="(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV
M86QU92UO9B!S96QE8W0](G-U8G-T<FEN9RUA9G1E<BAN86UE*"XI+"`G.B<I
M(B\^/'AS;#IT97AT/CH\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T
M/2(N(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:&5N('1E<W0])VYA;64H+BD](F9O.F9O;G0M<VEZ92(G/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0]
M(G-U8G-T<FEN9RUA9G1E<BAN86UE*"XI+"`G.B<I(B\^/'AS;#IT97AT/CH\
M+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^/'AS;#IT97AT
M/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M)VYA;64H+BD](F9O.F9O;G0M9F%M:6QY(B<^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<W5B<W1R:6YG+6%F
M=&5R*&YA;64H+BDL("<Z)RDB+SX\>'-L.G1E>'0^.CPO>'-L.G1E>'0^/'AS
M;#IV86QU92UO9B!S96QE8W0](BXB+SX\>'-L.G1E>'0^.R`\+WAS;#IT97AT
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG;F%M92@N*3TB9F\Z
M8V]L;W(B)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2)S=6)S=')I;F<M869T97(H;F%M92@N*2P@)SHG*2(O
M/CQX<VPZ=&5X=#XZ/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M+B(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)F;SIM87)G:6XM;&5F="(G/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0]
M(G-U8G-T<FEN9RUA9G1E<BAN86UE*"XI+"`G.B<I(B\^/'AS;#IT97AT/CH\
M+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^/'AS;#IT97AT
M/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M)VYA;64H+BD](F9O.FUA<F=I;BUR:6=H="(G/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G-U8G-T<FEN9RUA
M9G1E<BAN86UE*"XI+"`G.B<I(B\^/'AS;#IT97AT/CH\+WAS;#IT97AT/CQX
M<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X
M=#X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](F9O
M.FUA<F=I;BUT;W`B)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2)S=6)S=')I;F<M869T97(H;F%M92@N*2P@
M)SHG*2(O/CQX<VPZ=&5X=#XZ/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB+B(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)F;SIM87)G:6XM8F]T=&]M
M(B<^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB<W5B<W1R:6YG+6%F=&5R*&YA;64H+BDL("<Z)RDB+SX\>'-L
M.G1E>'0^.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](BXB+SX\
M>'-L.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TG;F%M92@N*3TB9F\Z;&EN92UH96EG:'0B)SX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)S=6)S
M=')I;F<M869T97(H;F%M92@N*2P@)SHG*2(O/CQX<VPZ=&5X=#XZ/"]X<VPZ
M=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O/CQX<VPZ=&5X=#X[(#PO
M>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE
M*"XI/2)F;SIT97AT+6%L:6=N(B<^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\(2TM($E-4$]25$%.5"!I<R!N96-E<W-A<GD@87,@=&%B;&4@8V5L
M;"!V86QU92!A;&EG;FUE;G0@:7,@9&5C:61E9"!B>2!R=6YT:6UE(&]V97(@
M=&AE('9A;'5E='EP90H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!/=&AE<G=I<V4@82!T86)L92!C96QL('-T>6QE+6-L87-S('=I;&P@04Q7
M05E3(&)E(&]V97)W<FET=&5N(&)Y('1H92!R=6XM=&EM92!V86QU92`M+3X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB
M8V]N=&%I;G,H+BP@)W-T87)T)RDB/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G1E>'0^=&5X="UA;&EG;CIL969T("$@:6UP
M;W)T86YT.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"XL("=E;F0G*2(^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YT
M97AT+6%L:6=N.G)I9VAT("$@:6UP;W)T86YT.R`\+WAS;#IT97AT/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YT
M97AT+6%L:6=N.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0])RXG
M+SX\>'-L.G1E>'0^("$@:6UP;W)T86YT.R`\+WAS;#IT97AT/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)F;SIT97AT+6EN
M9&5N="(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU
M92UO9B!S96QE8W0](G-U8G-T<FEN9RUA9G1E<BAN86UE*"XI+"`G.B<I(B\^
M/'AS;#IT97AT/CH\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(N
M(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0])VYA;64H+BD](G-T>6QE.G1E>'0M8F%C:V=R;W5N9"UC
M;VQO<B(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT
M/F)A8VMG<F]U;F0M8V]L;W(Z/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB+B(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)F;SIB86-K9W)O=6YD+6-O
M;&]R(B<^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^
M8F%C:V=R;W5N9"UC;VQO<CH\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L
M96-T/2(N(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](G-T>6QE.F)A8VMG<F]U;F0M
M:6UA9V4B)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X
M=#YB86-K9W)O=6YD+6EM86=E.G5R;"@\+WAS;#IT97AT/CQX<VPZ=F%L=64M
M;V8@<V5L96-T/2)`>&QI;FLZ:')E9B(O/CQX<VPZ=&5X=#XI.R`\+WAS;#IT
M97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E
M<W0](D!S='EL93IR97!E870@/2`G<F5P96%T)R(^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YB86-K9W)O=6YD+7)E
M<&5A=#IR97!E870[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/F)A8VMG<F]U;F0M<F5P96%T
M.FYO+7)E<&5A=#L@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@
M=&5X="US:&%D;W<@:7,@82!#4U,R(&9E871U<F4@86YD('EE="!N;W0@8V]M
M;6]N('5S960@:6X@=7-E<BUA9V5N=',@+2T^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)F;SIT97AT+7-H861O
M=R(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](G-U8G-T<FEN9RUA9G1E<BAN86UE*"XI+"`G.B<I(B\^/'AS
M;#IT97AT/CH\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^
M/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:&5N('1E<W0])VYA;64H+BD](G-T>6QE.G1E>'0M8W)O<W-I;F<M;W5T(B<^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0])VYO
M="@N/2)N;VYE(BDG/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=&5X=#YT97AT+61E8V]R871I;VXZ;&EN92UT:')O=6=H.R`\+WAS
M;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ:68^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)S='EL
M93IT97AT+75N9&5R;&EN92(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#II9B!T97-T/2=N;W0H+CTB;F]N92(I)SX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^=&5X="UD96-O<F%T:6]N
M.G5N9&5R;&EN93L@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.FEF/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TG;F%M92@N*3TB<W1Y;&4Z=&5X="UP;W-I=&EO;B(G/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2=C;VYT86EN<R@N+"`B
M<W5B(BDG/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=&5X=#YV97)T:6-A;"UA;&EG;CIS=6([(#PO>'-L.G1E>'0^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#II9CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TG8V]N=&%I;G,H+BP@(G-U<"(I
M)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^
M=F5R=&EC86PM86QI9VXZ<W5P.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ:68^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@
M:7-$96)U9TUO9&5-15-304=%.@H@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.FUE<W-A9V4^3F\@=')A;G-F;W)M871I;VX@:6UP;&5M96YT960@
M9F]R(&%T=')I8G5T92UT>7`@/'AS;#IV86QU92UO9B!S96QE8W0](FYA;64H
M+BDB+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IO=&AE<G=I<V4^+2T^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M8VAO;W-E/@H@("`@("`@("`@("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#PA+2TK*RLK*R!004Q-
M(#,N,B!354)3150@04Y$(%=!4"!04D]015)42453("`K*RLK*RTM/@H@("`@
M("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#QX<VPZ
M9F]R+65A8V@@<V5L96-T/2(D<W1Y;&5!='1R:6)U=&50871H(CX*("`@("`@
M("`@("`@("`@("`@("`\(2TM(&ES1&5B=6=-;V1E34534T%'13H*("`@("`@
M("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^($YA;64Z/'AS;#IV86QU92UO
M9B!S96QE8W0](FYA;64H*2(O/B!686QU93H\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB+B(O/CPO>'-L.FUE<W-A9V4^("`@("`@+2T^"@H@("`@("`@("`@("`@
M("`@("`@(#PA+2T@0E5'(%=/4DL@05)/54Y$.@H@("`@("`@("`@("`@("`@
M("`@($1U92!T;R!A(&)U9R!I;B!T:&4@6%0@4')O8V5S<V]R+"!I="!I<R!N
M;W0@<&]S<VEB;&4@=&\@8W)E871E('-E<G9E<F%L(&5L96UE;G1S(&EN('9A
M<FEA8FQE(&%N9"!S96%R8V@@;W9E<B!T:&5M+`H@("`@("`@("`@("`@("`@
M("`@(&%F=&5R(&5X<&QI8VET(&-O;G9E<G-I;VX@=&\@;F]D97-E=`H@("`@
M("`@("`@("`@("`@("`@(%1H:7,@9V5N97)A=&5D('-T:6YG(&ED96YT:69I
M97(@<VAA;&P@8F4@;&%T97(@8VAA;F=E9"!B86-K('1O(&$@<V5T(&]F(&5L
M96UE;G1S"B`@("`@("`@("`@("`@("`@("`@+2T^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#PA
M+2TJ*BH@1D]234%4($%45%))0E5415,@*BHJ+2T^"@H@("`@("`@("`@("`@
M("`@("`@("`@("`\(2TM($ET86QI8R`M+3X*("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](F9O.F9O;G0M<W1Y;&4B
M)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB
M8V]N=&%I;G,H+BP@)VET86QI8R<I(&]R(&-O;G1A:6YS*"XL("=O8FQI<75E
M)RDB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X
M=#YI=&%L:6,L(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#II9CX*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*"B`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@0F]L9&9A8V4@
M+2T^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N
M86UE*"XI/2)F;SIF;VYT+7=E:6=H="(G/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#II9B!T97-T/2)C;VYT86EN<R@N+"`G8F]L9"<I(&]R
M(&-O;G1A:6YS*"XL("=B;VQD97(G*2(^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IT97AT/F)O;&0L(#PO>'-L.G1E>'0^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#II9CX*("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*"B`@("`@("`@("`@("`@("`@("`@
M("`@(#PA+2T@56YD97)L:6YE("TM/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=H96X@=&5S=#TG;F%M92@N*3TB<W1Y;&4Z=&5X="UU;F1E<FQI
M;F4B)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YU
M;F1E<FQI;F4L(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.G=H96X^"@H@("`@("`@("`@("`@("`@("`@("`@("`\(2TM($%L
M:6=N;65N="`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0])VYA;64H+BD](F9O.G1E>'0M86QI9VXB)SX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H+BP@
M)W-T87)T)RDB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G1E>'0^86QI9VXZ;&5F="P@/"]X<VPZ=&5X=#X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN
M<R@N+"`G96YD)RDB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G1E>'0^86QI9VXZ<FEG:'0L(#PO>'-L.G1E>'0^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N
M=&%I;G,H+BP@)V-E;G1E<B<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IT97AT/F%L:6=N.F-E;G1E<BP@/"]X<VPZ=&5X
M=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*"B`@("`@("`@
M("`@("`@("`@("`@("`@(#PA+2T@<W1R:6ME=&AR;W5G:"`M+3X*("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](G-T
M>6QE.G1E>'0M8W)O<W-I;F<M;W5T(B<^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G1E>'0^<W1R:6ME+"`\+WAS;#IT97AT/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H*("`@("`@("`@("`@("`@
M("`@("`@("`@/"$M+2!&;VYT("T@<VEZ92`H4&%L;3H@96UU;&%T;W(@=')A
M;G-F;W)M960@<VEZ97,@=&\@879A:6QA8FQE('-E="`H92YG+B`S,"!T;R`H
M<')O8F%B;'DI(#DI+2T^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2=N86UE*"XI/2)F;SIF;VYT+7-I>F4B)SX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YS:7IE.CPO>'-L.G1E>'0^
M/'AS;#IV86QU92UO9B!S96QE8W0](BXB+SX\>'-L.G1E>'0^.G-I>F4L(#PO
M>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^
M"@H@("`@("`@("`@("`@("`@("`@("`@("`\(2TM($9O;G0@+2!#;VQO<B`H
M4$%,33H@8G5T(&UO<W1L>2!O;FQY(#(@879A:6QA8FQE*0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8FQA8VL@*",P,#`P,#`I"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!G<F%Y("@C.#`X,#@P*2AR96YD97)E9"!A<R!D
M87)K(&=R87DI"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!S:6QV97(@
M*"-#,$,P0S`I*')E;F1E<F5D(&%S(&QI9VAT(&=R87DI"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!W:&ET92`H(T9&1D9&1BDM+3X*("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](F9O.F-O
M;&]R(B<^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S
M93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TB8V]N=&%I;G,H+B`L("<C1D9&1D9&)RD@;W(@8V]N=&%I;G,H+B`L
M("<C9F9F9F9F)RD@;W(@8V]N=&%I;G,H+B`L("=W:&ET92<I(&]R(&-O;G1A
M:6YS*"X@+"`G5TA)5$4G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=&5X=#YC;VQO<CHC1D9&1D9&+"`\+WAS;#IT97AT
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I
M<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=&5X=#YC;VQO<CHC,#`P,#`P+"`\+WAS;#IT97AT/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*"@H@("`@("`@("`@("`@("`@("`@
M("`@("`\(2TM*BHJ(%1!0DQ%($%45%))0E5415,@*BHJ+2T^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)F;SIF
M;VYT+7-I>F4B)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=&5X=#YS:7IE.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](BXB
M+SX\>'-L.G1E>'0^.G-I>F4L(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)S='EL93IC;VQU;6XM=VED=&@B
M)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@8VAA;F=I;F<@
M=&AE(&1I<W1A;F-E(&UE87-U<F4Z(&EN8V@@=&\@:6X@+2T^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A
M:6YS*"XL("=C:"<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IT97AT/G=I9'1H.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO
M9B!S96QE8W0](G-U8G-T<FEN9RUB969O<F4H+BPG8V@G*2(O/CQX<VPZ=&5X
M=#XZ=VED=&@L(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IT97AT/G=I9'1H.CPO>'-L.G1E>'0^/'AS
M;#IV86QU92UO9B!S96QE8W0](BXB+SX\>'-L.G1E>'0^.G=I9'1H.R`\+WAS
M;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H
M+BD](G-T>6QE.G)O=RUH96EG:'0B)SX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#PA+2T@8VAA;F=I;F<@=&AE(&1I<W1A;F-E(&UE87-U<F4Z(&EN
M8V@@=&\@:6X@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"XL("=C:"<I(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/FAE:6=H=#H\
M+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)S=6)S=')I;F<M8F5F
M;W)E*"XL)V-H)RDB+SX\>'-L.G1E>'0^.FAE:6=H=#L@/"]X<VPZ=&5X=#X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E
M>'0^:&5I9VAT.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](BXB
M+SX\>'-L.G1E>'0^.FAE:6=H=#L@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)S='EL93IW:61T:"(G/B`\
M(2TM96%R;&EE<B!F;SIW:61T:"TM/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"$M+2!C:&%N9VEN9R!T:&4@9&ES=&%N8V4@;65A<W5R93H@:6YC
M:"!T;R!I;B`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H+BP@)V-H)RDB/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^=VED=&@Z/"]X
M<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB<W5B<W1R:6YG+6)E9F]R
M92@N+"=C:"<I(B\^/'AS;#IT97AT/CIW:61T:#L@/"]X<VPZ=&5X=#X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^
M=VED=&@Z/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O/CQX
M<VPZ=&5X=#XZ=VED=&@[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F-H;V]S93X*("`@("`@("`@("`@("`@(#PO>'-L.F9O<BUE86-H/@H@("`@
M("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E
M/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"CPA+2T@,D1/.B!.04U)3D<@0T].
M5D5.5$E/3B!V87)I86)L92!A<F4@=W)I='1E;B!W:71H("<M)R!I;G-T96%D
M(&]F(&-A<V4M<V5N<VET:79E('=R:71I;F<@+2T^"@H*"B`@("`\(2TM("HJ
M*BHJ($U%05-54D5-14Y4($-/3E9%4E-)3TY3("HJ*BHJ"@H@("`@("H@,2!C
M96YT:6UE=&5R(#T@,3`@;6T*"B`@("`@*B`Q(&EN8V@@/2`R-2XT(&UM"B`@
M("`@("`@5VAI;&4@=&AE($5N9VQI<V@@:&%V92!A;')E861Y('-E96X@=&AE
M(&QI9VAT("AR96%D.B!T:&4@;65T<FEC('-Y<W1E;2DL('1H92!54PH@("`@
M("`@(')E;6%I;G,@;&]Y86P@=&\@=&AI<R!M961I979A;"!S>7-T96TN"@H@
M("`@("H@,2!D:61O="!P;VEN="`](#`N,S<V,#8U(&UM"B`@("`@("`@("`@
M(%1H92!D:61O="!S>7-T96T@;W)I9VEN871E9"!I;B!&<F%N8V4@8G5T('=A
M<R!U<V5D(&EN(&UO<W0@;V8@175R;W!E"@H@("`@("H@,2!P:6-A('!O:6YT
M(#T@,"XS-3$T-B!M;0H@("`@("`@("`@("!4:&4@4&EC82!P;VEN=',@<WES
M=&5M('=A<R!D979E;&]P960@:6X@16YG;&%N9"!A;F0@:7,@=7-E9"!I;B!'
M<F5A="U"<FET86EN(&%N9"!T:&4@55,N"@H@("`@("H@,2!0;W-T4V-R:7!T
M('!O:6YT(#T@,"XS-3(W-S$S."!M;0H@("`@("`@("`@("!7:&5N($%D;V)E
M(&-R96%T960@4&]S=%-C<FEP="P@=&AE>2!A9&1E9"!T:&5I<B!O=VX@<WES
M=&5M(&]F('!O:6YT<RX*("`@("`@("`@("`@5&AE<F4@87)E(&5X86-T;'D@
M-S(@4&]S=%-C<FEP="!P;VEN=',@:6X@,2!I;F-H+@H*("`@("`J(#$@<&EX
M96P@/2`P+C(V-#4X,S,S+BX@;6T@("`H8GD@.38@9'!I*0H@("`@("`@("`@
M("!-;W-T('!I8W1U<F5S(&AA=F4@=&AE(#DV(&1P:2!R97-O;'5T:6]N+"!B
M=70@=&AE(&1P:2!V87)I86)L92!M87D@=F%R>2!B>2!S='EL97-H965T('!A
M<F%M971E<@H@("`@+2T^"@H*("`@(#PA+2T@8VAA;F=I;F<@;65A<W5R92!T
M;R!M;2`M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB8V]N=F5R=#)M;2(^
M"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)V86QU92(O/@H*("`@("`@("`\
M>'-L.G!A<F%M(&YA;64](F-E;G1I;65T97(M:6XM;6TB("`@("`@("`@('-E
M;&5C=#TB,3`B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](FEN8V@M:6XM
M;6TB("`@("`@("`@("`@("`@('-E;&5C=#TB,C4N-"(O/@H@("`@("`@(#QX
M<VPZ<&%R86T@;F%M93TB9&ED;W0M<&]I;G0M:6XM;6TB("`@("`@("`@<V5L
M96-T/2(P+C,W-C`V-2(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB<&EC
M82UP;VEN="UI;BUM;2(@("`@("`@("`@<V5L96-T/2(P+C,U,30V(B\^"@H@
M("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TB8V]N=&%I;G,H)'9A;'5E+"`G8VTG*2(^"B`@("`@("`@("`@("`@("`\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB<F]U;F0H;G5M8F5R*'-U8G-T<FEN9RUB
M969O<F4H)'9A;'5E+"=C;2<@*2D@*B`D8V5N=&EM971E<BUI;BUM;2DB+SX*
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0](F-O;G1A:6YS*"1V86QU92P@)VEN)RDB/@H@("`@("`@("`@("`@
M("`@/'AS;#IV86QU92UO9B!S96QE8W0](G)O=6YD*&YU;6)E<BAS=6)S=')I
M;F<M8F5F;W)E*"1V86QU92PG:6XG("DI("H@)&EN8V@M:6XM;6TI(B\^"B`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2)C;VYT86EN<R@D=F%L=64L("=D<'0G*2(^"B`@("`@("`@("`@("`@
M("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<F]U;F0H;G5M8F5R*'-U8G-T<FEN
M9RUB969O<F4H)'9A;'5E+"=D<'0G*2D@*B`D9&ED;W0M<&]I;G0M:6XM;6TI
M(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2)C;VYT86EN<R@D=F%L=64L("=P<'0G*2(^"B`@("`@("`@
M("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<F]U;F0H;G5M8F5R*'-U
M8G-T<FEN9RUB969O<F4H)'9A;'5E+"=P<'0G*2D@*B`D<&EC82UP;VEN="UI
M;BUM;2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB)'9A;'5E(B\^"B`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES
M93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*
M"@H@("`@/"$M+2!C:&%N9VEN9R!M96%S=7)E('1O(&-M("TM/@H@("`@/'AS
M;#IT96UP;&%T92!N86UE/2)C;VYV97)T,F-M(CX*("`@("`@("`\>'-L.G!A
M<F%M(&YA;64](G9A;'5E(B\^"@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB
M8V5N=&EM971E<BUI;BUM;2(@("`@("`@("`@<V5L96-T/2(Q,"(O/@H@("`@
M("`@(#QX<VPZ<&%R86T@;F%M93TB:6YC:"UI;BUM;2(@("`@("`@("`@("`@
M("`@<V5L96-T/2(R-2XT(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)D
M:61O="UP;VEN="UI;BUM;2(@("`@("`@("!S96QE8W0](C`N,S<V,#8U(B\^
M"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)P:6-A+7!O:6YT+6EN+6UM(B`@
M("`@("`@("!S96QE8W0](C`N,S4Q-#8B+SX*"B`@("`@("`@/'AS;#IC:&]O
M<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@D=F%L
M=64L("=M;2<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L
M96-T/2)R;W5N9"AN=6UB97(H<W5B<W1R:6YG+6)E9F]R92@D=F%L=64L("=M
M;2<I*2!D:78@)&-E;G1I;65T97(M:6XM;6TI(B\^"B`@("`@("`@("`@(#PO
M>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN
M<R@D=F%L=64L("=I;B<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M
M;V8@<V5L96-T/2)R;W5N9"AN=6UB97(H<W5B<W1R:6YG+6)E9F]R92@D=F%L
M=64L("=I;B<I*2!D:78@)&-E;G1I;65T97(M:6XM;6T@*B`D:6YC:"UI;BUM
M;2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](F-O;G1A:6YS*"1V86QU92P@)V1P="<I(CX*("`@("`@
M("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)R;W5N9"AN=6UB97(H
M<W5B<W1R:6YG+6)E9F]R92@D=F%L=64L)V1P="<I*2!D:78@)&-E;G1I;65T
M97(M:6XM;6T@*B`D9&ED;W0M<&]I;G0M:6XM;6TI(B\^"B`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT
M86EN<R@D=F%L=64L("=P<'0G*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB<F]U;F0H;G5M8F5R*'-U8G-T<FEN9RUB969O<F4H
M)'9A;'5E+"=P<'0G*2D@9&EV("1C96YT:6UE=&5R+6EN+6UM("H@)'!I8V$M
M<&]I;G0M:6XM;6TI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/'AS;#IV
M86QU92UO9B!S96QE8W0](B1V86QU92(O/@H@("`@("`@("`@("`\+WAS;#IO
M=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M
M<&QA=&4^"@H@("`@/"$M+2!C:&%N9VEN9R!M96%S=7)E('1O(&EN8V@@*&-P
M+B!S96-T:6]N(&-O;6UE;G0I("TM/@H@("`@/'AS;#IT96UP;&%T92!N86UE
M/2)C;VYV97)T,FEN8V@B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB=F%L
M=64B+SX*"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C96YT:6UE=&5R+6EN
M+6UM(B`@("`@("`@("!S96QE8W0](C$P(B\^"B`@("`@("`@/'AS;#IP87)A
M;2!N86UE/2)I;F-H+6EN+6UM(B`@("`@("`@("`@("`@("!S96QE8W0](C(U
M+C0B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F1I9&]T+7!O:6YT+6EN
M+6UM(B`@("`@("`@('-E;&5C=#TB,"XS-S8P-C4B+SX*("`@("`@("`\>'-L
M.G!A<F%M(&YA;64](G!I8V$M<&]I;G0M:6XM;6TB("`@("`@("`@('-E;&5C
M=#TB,"XS-3$T-B(O/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1V86QU92P@)VUM)RDB/@H@
M("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G)O=6YD*&YU
M;6)E<BAS=6)S=')I;F<M8F5F;W)E*"1V86QU92P@)VUM)RDI(&1I=B`D:6YC
M:"UI;BUM;2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1V86QU92P@)V-M)RDB/@H@
M("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G)O=6YD*&YU
M;6)E<BAS=6)S=')I;F<M8F5F;W)E*"1V86QU92P@)V-M)RDI(&1I=B`D:6YC
M:"UI;BUM;2`J("1C96YT:6UE=&5R+6EN+6UM*2(O/@H@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I
M;G,H)'9A;'5E+"`G9'!T)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU
M92UO9B!S96QE8W0](G)O=6YD*&YU;6)E<BAS=6)S=')I;F<M8F5F;W)E*"1V
M86QU92PG9'!T)RDI(&1I=B`D:6YC:"UI;BUM;2`J("1D:61O="UP;VEN="UI
M;BUM;2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1V86QU92P@)W!P="<I(CX*("`@
M("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)R;W5N9"AN=6UB
M97(H<W5B<W1R:6YG+6)E9F]R92@D=F%L=64L)W!P="<I*2!D:78@)&EN8V@M
M:6XM;6T@*B`D<&EC82UP;VEN="UI;BUM;2DB+SX*("`@("`@("`@("`@/"]X
M<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@
M("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'9A;'5E(B\^"B`@("`@
M("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^
M"B`@("`\+WAS;#IT96UP;&%T93X*"@H@("`@/"$M+2!C:&%N9VEN9R!M96%S
M=7)E('1O(&1P="`H8W`N('-E8W1I;VX@8V]M;65N="D@+2T^"B`@("`\>'-L
M.G1E;7!L871E(&YA;64](F-O;G9E<G0R9'!T(CX*("`@("`@("`\>'-L.G!A
M<F%M(&YA;64](G9A;'5E(B\^"@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB
M8V5N=&EM971E<BUI;BUM;2(@("`@("`@("`@<V5L96-T/2(Q,"(O/@H@("`@
M("`@(#QX<VPZ<&%R86T@;F%M93TB:6YC:"UI;BUM;2(@("`@("`@("`@("`@
M("`@<V5L96-T/2(R-2XT(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)D
M:61O="UP;VEN="UI;BUM;2(@("`@("`@("!S96QE8W0](C`N,S<V,#8U(B\^
M"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)P:6-A+7!O:6YT+6EN+6UM(B`@
M("`@("`@("!S96QE8W0](C`N,S4Q-#8B+SX*"B`@("`@("`@/'AS;#IC:&]O
M<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@D=F%L
M=64L("=M;2<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L
M96-T/2)R;W5N9"AN=6UB97(H<W5B<W1R:6YG+6)E9F]R92@D=F%L=64L("=M
M;2<I*2!D:78@)&1I9&]T+7!O:6YT+6EN+6UM*2(O/@H@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I
M;G,H)'9A;'5E+"`G8VTG*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB<F]U;F0H;G5M8F5R*'-U8G-T<FEN9RUB969O<F4H)'9A
M;'5E+"`G8VTG*2D@9&EV("1D:61O="UP;VEN="UI;BUM;2`J("1C96YT:6UE
M=&5R+6EN+6UM*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'9A;'5E+"`G:6XG*2(^
M"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<F]U;F0H
M;G5M8F5R*'-U8G-T<FEN9RUB969O<F4H)'9A;'5E+"`G:6XG*2D@9&EV("1D
M:61O="UP;VEN="UI;BUM;2`J("1I;F-H+6EN+6UM*2(O/@H@("`@("`@("`@
M("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N
M=&%I;G,H)'9A;'5E+"`G<'!T)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IV
M86QU92UO9B!S96QE8W0](G)O=6YD*&YU;6)E<BAS=6)S=')I;F<M8F5F;W)E
M*"1V86QU92PG<'!T)RDI(&1I=B`D9&ED;W0M<&]I;G0M:6XM;6T@*B`D<&EC
M82UP;VEN="UI;BUM;2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@
M("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB)'9A;'5E(B\^"B`@("`@("`@("`@(#PO>'-L
M.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"@H@("`@/"]X<VPZ
M=&5M<&QA=&4^"@H*("`@(#PA+2T@8VAA;F=I;F<@;65A<W5R92!T;R!P<'0@
M*&-P+B!S96-T:6]N(&-O;6UE;G0I("TM/@H@("`@/'AS;#IT96UP;&%T92!N
M86UE/2)C;VYV97)T,G!P="(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)V
M86QU92(O/@H*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-E;G1I;65T97(M
M:6XM;6TB("`@("`@("`@('-E;&5C=#TB,3`B+SX*("`@("`@("`\>'-L.G!A
M<F%M(&YA;64](FEN8V@M:6XM;6TB("`@("`@("`@("`@("`@('-E;&5C=#TB
M,C4N-"(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB9&ED;W0M<&]I;G0M
M:6XM;6TB("`@("`@("`@<V5L96-T/2(P+C,W-C`V-2(O/@H@("`@("`@(#QX
M<VPZ<&%R86T@;F%M93TB<&EC82UP;VEN="UI;BUM;2(@("`@("`@("`@<V5L
M96-T/2(P+C,U,30V(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'9A;'5E+"`G;6TG*2(^
M"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<F]U;F0H
M;G5M8F5R*'-U8G-T<FEN9RUB969O<F4H)'9A;'5E+"`G;6TG*2D@9&EV("1P
M:6-A+7!O:6YT+6EN+6UM*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'9A;'5E+"`G
M8VTG*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M<F]U;F0H;G5M8F5R*'-U8G-T<FEN9RUB969O<F4H)'9A;'5E+"`G8VTG*2D@
M9&EV("1P:6-A+7!O:6YT+6EN+6UM("H@)&-E;G1I;65T97(M:6XM;6TI(B\^
M"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2)C;VYT86EN<R@D=F%L=64L("=I;B<I(CX*("`@("`@("`@("`@
M("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)R;W5N9"AN=6UB97(H<W5B<W1R
M:6YG+6)E9F]R92@D=F%L=64L("=I;B<I*2!D:78@)'!I8V$M<&]I;G0M:6XM
M;6T@*B`D:6YC:"UI;BUM;2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1V86QU92P@
M)V1P="<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T
M/2)R;W5N9"AN=6UB97(H<W5B<W1R:6YG+6)E9F]R92@D=F%L=64L)V1P="<I
M*2!D:78@)'!I8V$M<&]I;G0M:6XM;6T@*B`D9&ED;W0M<&]I;G0M:6XM;6TI
M(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ
M;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE
M8W0](B1V86QU92(O/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@
M("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@
M(#PA+2T@8VAA;F=I;F<@;65A<W5R92!T;R!P:7AE;"!B>2!V:6$@<&%R86UE
M=&5R('!R;W9I9&5D(&1P:2`H9&]T<R!P97(@:6YC:"D@<W1A;F1A<F0@9F%C
M=&]R("AC<"X@<V5C=&EO;B!C;VUM96YT*2`M+3X*("`@(#QX<VPZ=&5M<&QA
M=&4@;F%M93TB8V]N=F5R=#)P:7AE;"(^"B`@("`@("`@/'AS;#IP87)A;2!N
M86UE/2)V86QU92(O/@H*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-E;G1I
M;65T97(M:6XM;6TB("`@("`@("`@('-E;&5C=#TB,3`B+SX*("`@("`@("`\
M>'-L.G!A<F%M(&YA;64](FEN8V@M:6XM;6TB("`@("`@("`@("`@("`@('-E
M;&5C=#TB,C4N-"(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB9&ED;W0M
M<&]I;G0M:6XM;6TB("`@("`@("`@<V5L96-T/2(P+C,W-C`V-2(O/@H@("`@
M("`@(#QX<VPZ<&%R86T@;F%M93TB<&EC82UP;VEN="UI;BUM;2(@("`@("`@
M("`@<V5L96-T/2(P+C,U,30V(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE
M/2)P:7AE;"UI;BUM;2(@("`@("`@("`@("`@("!S96QE8W0](B1I;F-H+6EN
M+6UM(&1I=B`D9'!I(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'9A;'5E+"`G;6TG*2(^
M"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<F]U;F0H
M;G5M8F5R*'-U8G-T<FEN9RUB969O<F4H)'9A;'5E+"`G;6TG*2D@9&EV("1P
M:7AE;"UI;BUM;2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1V86QU92P@)V-M)RDB
M/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G)O=6YD
M*&YU;6)E<BAS=6)S=')I;F<M8F5F;W)E*"1V86QU92P@)V-M)RDI(&1I=B`D
M<&EX96PM:6XM;6T@*B`D8V5N=&EM971E<BUI;BUM;2DB+SX*("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O
M;G1A:6YS*"1V86QU92P@)VEN)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IV
M86QU92UO9B!S96QE8W0](G)O=6YD*&YU;6)E<BAS=6)S=')I;F<M8F5F;W)E
M*"1V86QU92P@)VEN)RDI(&1I=B`D<&EX96PM:6XM;6T@*B`D:6YC:"UI;BUM
M;2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](F-O;G1A:6YS*"1V86QU92P@)V1P="<I(CX*("`@("`@
M("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)R;W5N9"AN=6UB97(H
M<W5B<W1R:6YG+6)E9F]R92@D=F%L=64L)V1P="<I*2!D:78@)'!I>&5L+6EN
M+6UM("H@)&1I9&]T+7!O:6YT+6EN+6UM*2(O/@H@("`@("`@("`@("`\+WAS
M;#IW:&5N/@H@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@
M("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D=F%L=64B+SX*("`@("`@
M("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*
M("`@(#PO>'-L.G1E;7!L871E/@H*/"]X<VPZ<W1Y;&5S:&5E=#X*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O
M;V]O+V=L;V)A;%]D;V-U;65N="YX<VP`````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`R-3(U,S<@
M,3`U,34T,S,W,S8@,#(V,#0Q`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"`\(2TM"@H@("!4:&4@0V]N=&5N=',@;V8@=&AI
M<R!F:6QE(&%R92!M861E(&%V86EL86)L92!S=6)J96-T('1O('1H92!T97)M
M<R!O9@H@("!E:71H97(@;V8@=&AE(&9O;&QO=VEN9R!L:6-E;G-E<PH*("`@
M("`@("`@("T@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8R!,:6-E;G-E(%9E
M<G-I;VX@,BXQ"B`@("`@("`@("`M(%-U;B!);F1U<W1R>2!3=&%N9&%R9',@
M4V]U<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$*"B`@(%-U;B!-:6-R;W-Y<W1E
M;7,@26YC+BP@3V-T;V)E<BP@,C`P,`H*("`@1TY5($QE<W-E<B!'96YE<F%L
M(%!U8FQI8R!,:6-E;G-E(%9E<G-I;VX@,BXQ"B`@(#T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@("!#;W!Y<FEG:'0@
M,C`P,"!B>2!3=6X@36EC<F]S>7-T96US+"!);F,N"B`@(#DP,2!386X@06YT
M;VYI;R!2;V%D+"!086QO($%L=&\L($-!(#DT,S`S+"!54T$*"B`@(%1H:7,@
M;&EB<F%R>2!I<R!F<F5E('-O9G1W87)E.R!Y;W4@8V%N(')E9&ES=')I8G5T
M92!I="!A;F0O;W(*("`@;6]D:69Y(&ET('5N9&5R('1H92!T97)M<R!O9B!T
M:&4@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8PH@("!,:6-E;G-E('9E<G-I
M;VX@,BXQ+"!A<R!P=6)L:7-H960@8GD@=&AE($9R964@4V]F='=A<F4@1F]U
M;F1A=&EO;BX*"B`@(%1H:7,@;&EB<F%R>2!I<R!D:7-T<FEB=71E9"!I;B!T
M:&4@:&]P92!T:&%T(&ET('=I;&P@8F4@=7-E9G5L+`H@("!B=70@5TE42$]5
M5"!!3ED@5T%24D%.5%D[('=I=&AO=70@979E;B!T:&4@:6UP;&EE9"!W87)R
M86YT>2!O9@H@("!-15)#2$%.5$%"24Q)5%D@;W(@1DE43D534R!&3U(@02!0
M05)424-53$%2(%!54E!/4T4N("!3964@=&AE($=.50H@("!,97-S97(@1V5N
M97)A;"!0=6)L:6,@3&EC96YS92!F;W(@;6]R92!D971A:6QS+@H*("`@66]U
M('-H;W5L9"!H879E(')E8V5I=F5D(&$@8V]P>2!O9B!T:&4@1TY5($QE<W-E
M<B!'96YE<F%L(%!U8FQI8PH@("!,:6-E;G-E(&%L;VYG('=I=&@@=&AI<R!L
M:6)R87)Y.R!I9B!N;W0L('=R:71E('1O('1H92!&<F5E(%-O9G1W87)E"B`@
M($9O=6YD871I;VXL($EN8RXL(#4Y(%1E;7!L92!0;&%C92P@4W5I=&4@,S,P
M+"!";W-T;VXL"B`@($U!("`P,C$Q,2TQ,S`W("!54T$*"@H@("!3=6X@26YD
M=7-T<GD@4W1A;F1A<F1S(%-O=7)C92!,:6-E;G-E(%9E<G-I;VX@,2XQ"B`@
M(#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T*("`@5&AE(&-O;G1E;G1S(&]F('1H:7,@9FEL92!A<F4@<W5B:F5C
M="!T;R!T:&4@4W5N($EN9'5S=')Y(%-T86YD87)D<PH@("!3;W5R8V4@3&EC
M96YS92!697)S:6]N(#$N,2`H=&AE("),:6-E;G-E(BD[(%EO=2!M87D@;F]T
M('5S92!T:&ES(&9I;&4*("`@97AC97!T(&EN(&-O;7!L:6%N8V4@=VET:"!T
M:&4@3&EC96YS92X@66]U(&UA>2!O8G1A:6X@82!C;W!Y(&]F('1H90H@("!,
M:6-E;G-E(&%T(&AT='`Z+R]W=W<N;W!E;F]F9FEC92YO<F<O;&EC96YS92YH
M=&UL+@H*("`@4V]F='=A<F4@<')O=FED960@=6YD97(@=&AI<R!,:6-E;G-E
M(&ES('!R;W9I9&5D(&]N(&%N(")!4R!)4R(@8F%S:7,L"B`@(%=)5$A/550@
M5T%24D%.5%D@3T8@04Y9($M)3D0L($5)5$A%4B!%6%!215-3($]2($E-4$Q)
M140L($E.0TQ51$E.1RP*("`@5TE42$]55"!,24U)5$%424].+"!705)204Y4
M2453(%1(050@5$A%(%-/1E1705)%($E3($92144@3T8@1$5&14-44RP*("`@
M34520TA!3E1!0DQ%+"!&250@1D]2($$@4$%25$E#54Q!4B!055)03U-%+"!/
M4B!.3TXM24Y&4DE.1TE.1RX*("`@4V5E('1H92!,:6-E;G-E(&9O<B!T:&4@
M<W!E8VEF:6,@<')O=FES:6]N<R!G;W9E<FYI;F<@>6]U<B!R:6=H=',@86YD
M"B`@(&]B;&EG871I;VYS(&-O;F-E<FYI;F<@=&AE(%-O9G1W87)E+@H*("`@
M5&AE($EN:71I86P@1&5V96QO<&5R(&]F('1H92!/<FEG:6YA;"!#;V1E(&ES
M.B!3=6X@36EC<F]S>7-T96US+"!);F,N"@H@("!#;W!Y<FEG:'0@PJD@,C`P
M,B!B>2!3=6X@36EC<F]S>7-T96US+"!);F,N"@H@("!!;&P@4FEG:'1S(%)E
M<V5R=F5D+@H*("`@0V]N=')I8G5T;W(H<RDZ(%]?7U]?7U]?7U]?7U]?7U]?
M7U]?7U]?7U]?7U]?7U]?7U]?7U]?7PH*+2T^"CQX<VPZ<W1Y;&5S:&5E="!V
M97)S:6]N/2(Q+C`B"B`@("`@("`@("`@("`@("!X;6QN<SIX<VP](FAT='`Z
M+R]W=W<N=S,N;W)G+S$Y.3DO6%-,+U1R86YS9F]R;2(*("`@("`@("`@("`@
M("`@('AM;&YS.F]F9FEC93TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O
M;V9F:6-E(@H@("`@("`@("`@("`@("`@>&UL;G,Z<W1Y;&4](FAT='`Z+R]O
M<&5N;V9F:6-E+F]R9R\R,#`P+W-T>6QE(@H@("`@("`@("`@("`@("`@>&UL
M;G,Z=&5X=#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O=&5X="(*("`@
M("`@("`@("`@("`@('AM;&YS.G1A8FQE/2)H='1P.B\O;W!E;F]F9FEC92YO
M<F<O,C`P,"]T86)L92(*("`@("`@("`@("`@("`@('AM;&YS.F1R87<](FAT
M='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1R87=I;F<B"B`@("`@("`@("`@
M("`@("!X;6QN<SIF;STB:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]84TPO1F]R
M;6%T(@H@("`@("`@("`@("`@("`@>&UL;G,Z>&QI;FL](FAT='`Z+R]W=W<N
M=S,N;W)G+S$Y.3DO>&QI;FLB"B`@("`@("`@("`@("`@("!X;6QN<SIN=6UB
M97(](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1A=&%S='EL92(*("`@
M("`@("`@("`@("`@('AM;&YS.G-V9STB:'1T<#HO+W=W=RYW,RYO<F<O,C`P
M,"]S=F<B"B`@("`@("`@("`@("`@("!X;6QN<SIC:&%R=#TB:'1T<#HO+V]P
M96YO9F9I8V4N;W)G+S(P,#`O8VAA<G0B"B`@("`@("`@("`@("`@("!X;6QN
M<SID<C-D/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]D<C-D(@H@("`@
M("`@("`@("`@("`@>&UL;G,Z;6%T:#TB:'1T<#HO+W=W=RYW,RYO<F<O,3DY
M."]-871H+TUA=&A-3"(*("`@("`@("`@("`@("`@('AM;&YS.F9O<FT](FAT
M='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V9O<FTB"B`@("`@("`@("`@("`@
M("!X;6QN<SIS8W)I<'0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W-C
M<FEP="(*("`@("`@("`@("`@("`@(&]F9FEC93IC;&%S<STB=&5X="(*("`@
M("`@("`@("`@("`@(&]F9FEC93IV97)S:6]N/2(Q+C`B"B`@("`@("`@("`@
M("`@("!X;6QN<SID8STB:'1T<#HO+W!U<FPN;W)G+V1C+V5L96UE;G1S+S$N
M,2\B"B`@("`@("`@("`@("`@("!X;6QN<SIM971A/2)H='1P.B\O;W!E;F]F
M9FEC92YO<F<O,C`P,"]M971A(@H@("`@("`@("`@("`@("`@>&UL;G,Z8V]N
M9FEG/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,2]C;VYF:6<B"B`@("`@
M("`@("`@("`@("!X;6QN<SIH96QP/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O
M,C`P,"]H96QP(@H@("`@("`@("`@("`@("`@>&UL;G,Z>'0](FAT='`Z+R]W
M=W<N:F-L87)K+F-O;2]X="(*("`@("`@("`@("`@("`@(&5X=&5N<VEO;BUE
M;&5M96YT+7!R969I>&5S/2)X="(*("`@("`@("`@("`@("`@('AM;&YS.G5R
M;&5N8V]D97(](FAT='`Z+R]W=W<N:F-L87)K+F-O;2]X="]J879A+VIA=F$N
M;F5T+E523$5N8V]D97(B"B`@("`@("`@("`@("`@("!X;6QN<SIS>&=H96QP
M97(](FAT='`Z+R]W=W<N:F-L87)K+F-O;2]X="]J879A+V-O;2YS=6XN<W1A
M<BYX<VQT+FAE;'!E<BY3>&=#:&EL9%1R86YS9F]R;65R(@H@("`@("`@("`@
M("`@("`@>&UL;G,Z>&%L86X](FAT='`Z+R]X;6PN87!A8VAE+F]R9R]X86QA
M;B(*("`@("`@("`@("`@("`@('AM;&YS.FIA=F$](FAT='`Z+R]X;6PN87!A
M8VAE+F]R9R]X<VQT+VIA=F$B"B`@("`@("`@("`@("`@("!E>&-L=61E+7)E
M<W5L="UP<F5F:7AE<STB:F%V82(^"@H*"@H@("`@/"$M+2`J*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H@("`@
M/"$M+2`J*BH@1VQO8F%L($1O8W5M96YT("T@(%1A8FQE(&]F($-O;G1E;G0@
M("`@*BHJ("TM/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H*"@H@("`@/'AS;#IT96UP;&%T
M92!M871C:#TB=&5X=#IT86)L92UO9BUC;VYT96YT(CX*("`@("`@("`\>'-L
M.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@
M/'AS;#IA<'!L>2UT96UP;&%T97,^"B`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL
M96-T961';&]B86Q$871A(B\^"B`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA
M=&5S/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@("`\>'-L.G1E;7!L871E
M(&UA=&-H/2)T97AT.FEN9&5X+6)O9'DB/@H@("`@("`@(#QX<VPZ<&%R86T@
M;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@("`@("`\>'-L.F%P
M<&QY+71E;7!L871E<R!M;V1E/2)C;VYT96YT+71A8FQE(CX*("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B
M('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`\+WAS
M;#IA<'!L>2UT96UP;&%T97,^"B`@("`\+WAS;#IT96UP;&%T93X*"@H*("`@
M(#QX<VPZ=&5M<&QA=&4@;6%T8V@](G1E>'0Z:6YD97@M=&ET;&4B(&UO9&4]
M(F-O;G1E;G0M=&%B;&4B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L
M;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@("`@("`\>'-L.F%P<&QY+71E;7!L
M871E<SX*("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE
M8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B
M+SX*("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^"B`@("`\+WAS;#IT
M96UP;&%T93X*"B`@("`\>'-L.G1E;7!L871E(&UA=&-H/2)T97AT.G)E9F5R
M96YC92UR968B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D
M1VQO8F%L1&%T82(O/@H*("`@("`@("`\(2TM($IA=F$@:7,@;F5E9&5D(&%S
M('=E(&AA=F4@=&\@96YC;V1E('1H92!R96QA=&EV92!L:6YK<R`H8G5G(S$P
M,C,Q,2D@+2T^"B`@("`@("`@/'AS;#II9B!T97-T/2)N;W0H)&ES2F%V841I
M<V%B;&5D*2(^"B`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)A(CX*
M("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](FAR968B/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#XC/"]X<VPZ=&5X=#X*("`@
M("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB96YC
M;V1E+7-T<FEN9R(^"B`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@=&AE
M('-P86-E(&AA<R!T;R!B92!N;W)M86QI>F5D+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@;W1H97)W:7-E(&%N(&EL;&5G86P@87)G=6UE;G0@97AC
M97!T:6]N('=I;&P@8F4@=&AR;W=N(&9O<B!85"TM/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G1E>'14;T)E16YC
M;V1E9"(@<V5L96-T/2)`=&5X=#IR968M;F%M92(O/@H@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`\
M+WAS;#IA='1R:6)U=&4^"@H@("`@("`@("`@("`@("`@/'AS;#IA<'!L>2UT
M96UP;&%T97,^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E
M9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@(#PO>'-L.F%P<&QY+71E
M;7!L871E<SX*"B`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@
M/"]X<VPZ:68^"B`@("`\+WAS;#IT96UP;&%T93X*"B`@("`\>'-L.G1E;7!L
M871E(&UA=&-H/2)T97AT.G)E9F5R96YC92UM87)K(CX*("`@("`@("`\>'-L
M.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@
M/"$M+2!*879A(&ES(&YE961E9"!A<R!W92!H879E('1O(&5N8V]D92!T:&4@
M<F5L871I=F4@;&EN:W,@*&)U9R,Q,#(S,3$I("TM/@H@("`@("`@(#QX<VPZ
M:68@=&5S=#TB;F]T*"1I<TIA=F%$:7-A8FQE9"DB/@H@("`@("`@("`@("`\
M>'-L.F5L96UE;G0@;F%M93TB82(^"B`@("`@("`@("`@("`@("`\>'-L.F%T
M=')I8G5T92!N86UE/2)N86UE(CX*("`@("`@("`@("`@("`@("`@("`\>'-L
M.F-A;&PM=&5M<&QA=&4@;F%M93TB96YC;V1E+7-T<FEN9R(^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#PA+2T@=&AE('-P86-E(&AA<R!T;R!B92!N;W)M
M86QI>F5D+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@;W1H97)W:7-E
M(&%N(&EL;&5G86P@87)G=6UE;G0@97AC97!T:6]N('=I;&P@8F4@=&AR;W=N
M(&9O<B!85"TM/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB=&5X=%1O0F5%;F-O9&5D(B!S96QE8W0](D!T97AT.FYA
M;64B+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E
M/@H@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H*("`@("`@("`@
M("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A
M(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@
M("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^"@H@("`@("`@("`@("`\+WAS
M;#IE;&5M96YT/@H@("`@("`@(#PO>'-L.FEF/@H@("`@/"]X<VPZ=&5M<&QA
M=&4^"@H*"B`@("`\>'-L.G1E;7!L871E(&UA=&-H/2)T97AT.G)E9F5R96YC
M92UM87)K+7-T87)T(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE
M8W1E9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@/"$M+2!*879A(&ES(&YE961E
M9"!A<R!W92!H879E('1O(&5N8V]D92!T:&4@<F5L871I=F4@;&EN:W,@*&)U
M9R,Q,#(S,3$I("TM/@H@("`@("`@(#QX<VPZ:68@=&5S=#TB;F]T*"1I<TIA
M=F%$:7-A8FQE9"DB/@H@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB
M82(^"B`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)N86UE
M(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M
M93TB96YC;V1E+7-T<FEN9R(^"B`@("`@("`@("`@("`@("`@("`@("`@(#PA
M+2T@=&AE('-P86-E(&AA<R!T;R!B92!N;W)M86QI>F5D+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@;W1H97)W:7-E(&%N(&EL;&5G86P@87)G=6UE
M;G0@97AC97!T:6]N('=I;&P@8F4@=&AR;W=N(&9O<B!85"TM/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=&5X=%1O
M0F5%;F-O9&5D(B!S96QE8W0](D!T97AT.FYA;64B+SX*("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@
M/"]X<VPZ871T<FEB=71E/@H*("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B
M;&4@;F%M93TB96YD3V92969E<F5N8V4B/@H@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ9F]R+65A8V@@<V5L96-T/2)T97AT.G)E9F5R96YC92UM87)K+65N
M9%M`;F%M93UC=7)R96YT*"DO0'1E>'0Z;F%M95TB/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<&]S:71I;VXH*2(O
M/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F9O<BUE86-H/@H@("`@("`@
M("`@("`@("`@/"]X<VPZ=F%R:6%B;&4^"@H@("`@("`@("`@("`@("`@/'AS
M;#IF;W(M96%C:"!S96QE8W0](F9O;&QO=VEN9RUS:6)L:6YG.CHJ6W!O<VET
M:6]N*"D@)FQT.R`D96YD3V92969E<F5N8V5=(CX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.F%P<&QY+71E;7!L871E<SX*("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A
M=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^"B`@("`@("`@("`@
M("`@("`\+WAS;#IF;W(M96%C:#X*("`@("`@("`@("`@/"]X<VPZ96QE;65N
M=#X*("`@("`@(#PO>'-L.FEF/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"@H@
M("`@(#PA+2T@8V]N=&5N="!T86)L92!L:6YK("`M+3X*("`@(#QX<VPZ=&5M
M<&QA=&4@;6%T8V@](G1E>'0Z82(@;6]D93TB8V]N=&5N="UT86)L92(^"B`@
M("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B\^
M"@H*("`@("`@("`\(2TM($9O<B!A;F-H;W)S(&EN(&-O;G1E;G0M:&5A9&5R
M<R!A(&)U9R!E>&ES=',@*&-P+B!B=6<@:60C(#$P,C,Q,2D@86YD('1H97D@
M:&%V92!T;R!B92!W;W)K960@;W5T('-E<&%R871E;'DN"B`@("`@("`@("`@
M($-U<G)E;G1L>2!T:&4@;&EN:R!U<V5D(&EN('1H92!C;VYT96YT+71A8FQE
M(&]F(&%N($]F9FEC92!834P@*&4N9RX@:6X@=&AE(&-O;G1E;G0@=&%B;&4@
M87,@)R,W+E-O;64E,C!%>&%M<&QE)3(P2&5A9&QI;F4E-T]U=&QI;F4G*0H@
M("`@("`@("`@("!I<R!N;W0@82!V86QI9"!54DP@*&-P+B!B=6<@:60C(#$P
M,C,Q,2DN($YO(&9I;&4@9&5S=&EN871I;VX@:7,@<W!E8VEF:65D(&YO<B!E
M>&ES="!A;GD@86YC:&]R(&5L96UE;G0@9F]R('1H97-E"B`@("`@("`@("`@
M(&QI;FMS(&EN('1H92!/9F9I8V4@6$U,+"!N;W(@:7,@=&AE(&-H87!T97(@
M;F\N(&MN;W=N(&EN('1H92!L:6YK960@9FEL97,N"B`@("`@("`@("`@($$@
M=V]R:V%R;W5N9"!F;W(@=&AI<R!T<F%N<V9O<FUA=&EO;B!T:&5R969O<F4@
M:&%D('1O(&)E(&UA9&4N(%1H:7,@=&EM92UC;VYS=6UI;F<@;65C:&%N:7-M
M(&ES(&1I<V%B;&5D(&)Y(&1E9F%U;'0@86YD"B`@("`@("`@("`@(&-A;B!B
M92!A8W1I=F%T960@8GD@82!P87)A;65T97(@*&DN92X@)V1I<V%B;&5,:6YK
M961486)L94]F0V]N=&5N="<I+B!!(&-R96%T:6]N(&]F(&%N(&%N8VAO<B!I
M<R!M861E(&9O<B!E86-H(&AE861E<B!E;&5M96YT+@H@("`@("`@("`@("!!
M;&P@:&5A9&5R('1I=&QE<R!G;VYN82!B92!E;F-O9&EN9R!T;R!B92!U<V%B
M;&4@:6X@82!R96QA=&EV92!54DPN("TM/@H@("`@("`@(#QX<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&1I<V%B;&5,:6YK9614
M86)L94]F0V]N=&5N="!O<B`D:7-*879A1&ES86)L960B/@H@("`@("`@("`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F-R96%T92UC;VUM;VXM
M;&EN:R(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L
M;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA
M=&4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ
M;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E
M(&YA;64](F-R96%T92UC;VYT96YT+71A8FQE+6QI;FLB/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B
M86Q$871A(B`@("`@("!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^
M"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@
M("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@
M("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64]
M(F=E="UA8G-O;'5T92UC:&%P=&5R+6YO(CX*("`@("`@("`\>'-L.G!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`\>'-L.G!A
M<F%M(&YA;64](G!R96-E9&EN9T-H87!T97),979E;#$B+SX*"B`@("`@("`@
M/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D9VQO
M8F%L1&]C=6UE;G129694;T-U<G)E;G1&:6QE(CX*"B`@("`@("`@("`@("`@
M("`\>'-L.G9A<FEA8FQE(&YA;64](F-U<G)E;G1&:6QE2&5A9&EN9TYO(CX*
M("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB
M9V5T+6-U<G)E;G0M9FEL92UH96%D:6YG+6YO(B\^"B`@("`@("`@("`@("`@
M("`\+WAS;#IV87)I86)L93X*("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B
M;&4@;F%M93TB=&5S=%)E<W5L="(@<V5L96-T/2(D8V]N=&5N=%1A8FQE2&5A
M9&EN9W,O:&5A9&EN9ULD9VQO8F%L1&]C=6UE;G129694;T-U<G)E;G1&:6QE
M(#T@0&9I;&4M=7)L75MN=6UB97(H)&-U<G)E;G1&:6QE2&5A9&EN9TYO*5TB
M+SX*"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB
M9V5T+6=L;V)A;"UH96%D:6YG+6YO(CX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB8W5R<F5N=$9I;&5(96%D:6YG3F\B('-E
M;&5C=#TB=')A;G-L871E*"1T97-T4F5S=6QT+T!A8G-O;'5T92UC:&%P=&5R
M+6QE=F5L+"`G*R<L("<N)RDB+SX*("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB<')E8V5D:6YG0VAA<'1E<DQE=F5L,2(@<V5L
M96-T/2(D<')E8V5D:6YG0VAA<'1E<DQE=F5L,2(O/@H@("`@("`@("`@("`@
M("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*"B`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@
M(#PA+2T@5VAE;B!T:&4@8VAA<'1E<B!I<R!I;B!T:&4@9VQO8F%L(&1O8W5M
M96YT(&ET<V5L9B!T:&4@;&EN:R!H87,@=&\@8F4@<F5L871I=F4@*&4N9RX@
M(VEN9&5X*2!A(&%B<V]L=71E(&AR968@9&]E<R!N;W0*("`@("`@("`@("`@
M("`@("`@("!W;W)K('=I=&@@=&AE(&)R;W=S97(N($EN(&-A<V4@;V8@8VAA
M<'1E<B!I;B!T:&4@9VQO8F%L(&1O8W5M96YT+"!T:&4@;W5T<'5T(%523"!O
M9B!T:&4@9VQO8F%L(&1O8W5M96YT('=A<R!T86ME;BX@+2T^"B`@("`@("`@
M("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F-U<G)E;G1&:6QE2&5A9&EN
M9TYO(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@
M;F%M93TB9V5T+6-U<G)E;G0M9FEL92UH96%D:6YG+6YO(B\^"B`@("`@("`@
M("`@("`@("`\+WAS;#IV87)I86)L93X*("`@("`@("`@("`@("`@(#QX<VPZ
M=F%R:6%B;&4@;F%M93TB=&5S=%)E<W5L="(@<V5L96-T/2(D8V]L;&5C=&5D
M1VQO8F%L1&%T82]C;VYT96YT+71A8FQE+6AE861I;F=S+VAE861I;F=;)&-O
M;G1E;G1486)L95523"`]($!F:6QE+75R;%U;;G5M8F5R*"1C=7)R96YT1FEL
M94AE861I;F=.;RE=(B\^"@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E
M;7!L871E(&YA;64](F=E="UG;&]B86PM:&5A9&EN9RUN;R(^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-U<G)E;G1&:6QE
M2&5A9&EN9TYO(B!S96QE8W0](G1R86YS;&%T92@D=&5S=%)E<W5L="]`86)S
M;VQU=&4M8VAA<'1E<BUL979E;"P@)RLG+"`G+B<I(B\^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G!R96-E9&EN9T-H87!T
M97),979E;#$B('-E;&5C=#TB)'!R96-E9&EN9T-H87!T97),979E;#$B+SX*
M("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@
M("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@
M("`\+WAS;#IT96UP;&%T93X*"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)G
M970M8W5R<F5N="UF:6QE+6AE861I;F<M;F\B/@H@("`@("`@(#QX<VPZ8VAO
M;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A
M:6QA8FQE*"=S>&=H96QP97(Z9V5T+6-U<G)E;G0M8VAI;&0M:&5A9&EN9RUN
M;R<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)S
M>&=H96QP97(Z9V5T+6-U<G)E;G0M8VAI;&0M:&5A9&EN9RUN;R@I(B\^"B`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H)VIA=F$Z8V]M+G-U;BYS=&%R+GAS
M;'0N:&5L<&5R+E-X9T-H:6QD5')A;G-F;W)M97(N9V5T0W5R<F5N=$-H:6QD
M2&5A9&EN9TYO)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S
M96QE8W0](FIA=F$Z8V]M+G-U;BYS=&%R+GAS;'0N:&5L<&5R+E-X9T-H:6QD
M5')A;G-F;W)M97(N9V5T0W5R<F5N=$-H:6QD2&5A9&EN9TYO*"DB+SX*("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@
M("`\+WAS;#IT96UP;&%T93X*"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)G
M970M;F5X="UC=7)R96YT+69I;&4M:&5A9&EN9RUN;R(^"B`@("`@("`@/'AS
M;#IP87)A;2!N86UE/2)F:6QE(B\^"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H
M)W-X9VAE;'!E<CIG970M;F5X="UC=7)R96YT+6-H:6QD+6AE861I;F<M;F\G
M*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<WAG
M:&5L<&5R.F=E="UN97AT+6-U<G)E;G0M8VAI;&0M:&5A9&EN9RUN;R@D9FEL
M92DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G:F%V83IC;VTN<W5N
M+G-T87(N>'-L="YH96QP97(N4WAG0VAI;&14<F%N<V9O<FUE<BYG971.97AT
M0W5R<F5N=$-H:6QD2&5A9&EN9TYO)RDB/@H@("`@("`@("`@("`@("`@/'AS
M;#IV86QU92UO9B!S96QE8W0](FIA=F$Z8V]M+G-U;BYS=&%R+GAS;'0N:&5L
M<&5R+E-X9T-H:6QD5')A;G-F;W)M97(N9V5T3F5X=$-U<G)E;G1#:&EL9$AE
M861I;F=.;R@D9FEL92DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@
M("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H@("`@
M/'AS;#IT96UP;&%T92!N86UE/2)G970M9VQO8F%L+6AE861I;F<M;F\B/@H@
M("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8W5R<F5N=$9I;&5(96%D:6YG3F\B
M+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G!R96-E9&EN9T-H87!T97),
M979E;#$B+SX*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H)W-X9VAE;'!E<CIG
M970M9VQO8F%L+6AE861I;F<M;F\G*2(^"B`@("`@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB<WAG:&5L<&5R.F=E="UG;&]B86PM:&5A9&EN
M9RUN;RAS=')I;F<H)&-U<G)E;G1&:6QE2&5A9&EN9TYO*2P@;G5M8F5R*"1P
M<F5C961I;F=#:&%P=&5R3&5V96PQ*2DB+SX*("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V
M86EL86)L92@G:F%V83IC;VTN<W5N+G-T87(N>'-L="YH96QP97(N4WAG0VAI
M;&14<F%N<V9O<FUE<BYG971';&]B86Q(96%D:6YG3F\G*2(^"B`@("`@("`@
M("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB:F%V83IC;VTN<W5N+G-T
M87(N>'-L="YH96QP97(N4WAG0VAI;&14<F%N<V9O<FUE<BYG971';&]B86Q(
M96%D:6YG3F\H<W1R:6YG*"1C=7)R96YT1FEL94AE861I;F=.;RDL(&YU;6)E
M<B@D<')E8V5D:6YG0VAA<'1E<DQE=F5L,2DI(B\^"B`@("`@("`@("`@(#PO
M>'-L.G=H96X^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M
M<&QA=&4^"@H*"@H@("`@/"$M+2!N96-E<W-A<GD@87,@86YC:&]R(&9O<B!T
M:&4@8V]N=&5N="!T86)L92`M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB
M8W)E871E+6AE861I;F<M86YC:&]R(CX*("`@("`@("`\>'-L.G!A<F%M(&YA
M;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@/"$M+0H@("`@
M("`@($-U<G)E;G1L>2!T:&4@;&EN:R!U<V5D(&EN('1H92!/9F9I8V4@6$U,
M("AE+F<N(&EN('1H92!C;VYT96YT('1A8FQE(&%S("<C-RY3;VUE)3(P17AA
M;7!L924R,$AE861L:6YE)3=/=71L:6YE)RD*("`@("`@("!I<R!N;W0@82!V
M86QI9"!54DP@*&-M<"X@8G5G(&ED(R`Q,#(S,3$I+B!.;R!F:6QE(&1E<W1I
M;F%T:6]N(&ES('-P96-I9FEE9"!N;W(@97AI<W0@86YY(&%N8VAO<B!E;&5M
M96YT(&9O<B!T:&5S90H@("`@("`@(&QI;FMS(&EN('1H92!/9F9I8V4@6$U,
M+@H@("`@("`@($AE<F4@=V4@87)E(&-R96%T:6YG(&%N(&%N8VAO<B!W:71H
M('1H92!S<&%C92!N;W)M86QI>F5D('1E>'0@;V8@=&AI<R!H96%D97(@87,@
M<&]T96YT:6%L(&IU;7`@861D<F5S<R!O9B!T:&4@8V]N=&5N="!T86)L92`M
M+3X*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2(D9VQO8F%L1&]C=6UE;G129694;T-U<G)E;G1&:6QE(CX*"B`@
M("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F-U<G)E;G1&:6QE
M2&5A9&EN9TYO(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M
M<&QA=&4@;F%M93TB9V5T+6YE>'0M8W5R<F5N="UF:6QE+6AE861I;F<M;F\B
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](F9I;&4B('-E;&5C=#TB)&=L;V)A;$1O8W5M96YT4F5F5&]#=7)R96YT
M1FEL92(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA
M=&4^"B`@("`@("`@("`@("`@("`\+WAS;#IV87)I86)L93X*"@H@("`@("`@
M("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)T97-T4F5S=6QT(B!S96QE
M8W0](B1C;VYT96YT5&%B;&5(96%D:6YG<R]H96%D:6YG6R1G;&]B86Q$;V-U
M;65N=%)E9E1O0W5R<F5N=$9I;&4@/2!`9FEL92UU<FQ=6VYU;6)E<B@D8W5R
M<F5N=$9I;&5(96%D:6YG3F\I72(O/@H@("`@("`@("`@("`@("`@/'AS;#II
M9B!T97-T/2(D:7-$96)U9TUO9&4B/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ;65S<V%G93Y-871C:&EN9R!C:&EL9"!D;V-U;65N="!H96%D97(@3F\N
M(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D8W5R<F5N=$9I;&5(96%D:6YG3F\B
M+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;65S
M<V%G93YA8G-O;'5T92UC:&%P=&5R+6QE=F5L.B`@("`@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2(D=&5S=%)E<W5L="]`86)S;VQU=&4M8VAA<'1E<BUL
M979E;"(O/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IM97-S86=E/F5N8V]D9614:71L93H@("`@("`@("`@("`@("`@("`@/'AS
M;#IV86QU92UO9B!S96QE8W0](B1T97-T4F5S=6QT+T!E;F-O9&5D+71I=&QE
M(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@("`@("`@("`\>'-L.FUE
M<W-A9V4^9VQO8F%L1&]C=6UE;G129694;T-U<G)E;G1&:6QE.B`\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB)&=L;V)A;$1O8W5M96YT4F5F5&]#=7)R96YT1FEL
M92(O/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IM
M97-S86=E/BHJ*B`\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@/"]X
M<VPZ:68^"@H@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](F$B
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](FYA
M;64B/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB)'1E<W1297-U;'0O0&%B<V]L=71E+6-H87!T97(M;&5V96PB+SX*
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/BL\+WAS;#IT97AT
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB)'1E<W1297-U;'0O0&5N8V]D960M=&ET;&4B+SX*("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@("`\+WAS
M;#IE;&5M96YT/@H@("`@("`@("`@(#PO>'-L.G=H96X^"@H@("`@("`@("`@
M(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/"$M+2!7:&5N('1H
M92!C:&%P=&5R(&ES(&EN('1H92!G;&]B86P@9&]C=6UE;G0@:71S96QF('1H
M92!L:6YK(&AA<R!T;R!B92!R96QA=&EV92`H92YG+B`C:6YD97@I(&$@86)S
M;VQU=&4@:')E9B!D;V5S(&YO=`H@("`@("`@("`@("`@("`@("`@('=O<FL@
M=VET:"!T:&4@8G)O=W-E<BX@26X@8V%S92!O9B!C:&%P=&5R(&EN('1H92!G
M;&]B86P@9&]C=6UE;G0L('1H92!O=71P=70@55),(&]F('1H92!G;&]B86P@
M9&]C=6UE;G0@=V%S('1A:V5N+B`M+3X*("`@("`@("`@("`@("`@(#QX<VPZ
M=F%R:6%B;&4@;F%M93TB8W5R<F5N=$9I;&5(96%D:6YG3F\B/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)G970M;F5X
M="UC=7)R96YT+69I;&4M:&5A9&EN9RUN;R(^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB9FEL92(@<V5L96-T/2(D
M8V]N=&5N=%1A8FQE55),(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L.G9A<FEA8FQE
M/@H*"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G1E<W12
M97-U;'0B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$O8V]N=&5N="UT
M86)L92UH96%D:6YG<R]H96%D:6YG6R1C;VYT96YT5&%B;&554DP@/2!`9FEL
M92UU<FQ=6VYU;6)E<B@D8W5R<F5N=$9I;&5(96%D:6YG3F\I72(O/@H*("`@
M("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB)&ES1&5B=6=-;V1E(CX*("`@
M("`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^36%T8VAI;F<@9VQO8F%L
M(&1O8W5M96YT(&AE861E<B!.;RX@/'AS;#IV86QU92UO9B!S96QE8W0](B1C
M=7)R96YT1FEL94AE861I;F=.;R(O/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IM97-S86=E/F%B<V]L=71E+6-H87!T97(M;&5V
M96PZ("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'1E<W1297-U;'0O0&%B<V]L
M=71E+6-H87!T97(M;&5V96PB+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ;65S<V%G93YE;F-O9&5D5&ET;&4Z("`@("`@("`@
M("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1T97-T4F5S=6QT+T!E;F-O9&5D
M+71I=&QE(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@("`@("`@("`\
M>'-L.FUE<W-A9V4^8V]N=&5N=%1A8FQE55),.B`@("`@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2(D8V]N=&5N=%1A8FQE55),(B\^/"]X<VPZ;65S<V%G
M93X*("`@("`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^*BHJ(#PO>'-L
M.FUE<W-A9V4^"B`@("`@("`@("`@("`@("`\+WAS;#II9CX*"B`@("`@("`@
M("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB82(^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB;F%M92(^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D=&5S=%)E<W5L
M="]`86)S;VQU=&4M8VAA<'1E<BUL979E;"(O/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G1E>'0^*SPO>'-L.G1E>'0^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D=&5S=%)E<W5L="]`
M96YC;V1E9"UT:71L92(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%T
M=')I8G5T93X*("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"@H@("`@
M("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E
M/@H*"@H\(2TM"@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB=&ET;&4B
M('-E;&5C=#TB;F]R;6%L:7IE+7-P86-E*"XI(B\^"B`@("`@("`@/"%^?D1/
M3B=4(%=/4DL@("`@/'AS;#IV87)I86)L92!N86UE/2)T:71L92(@<V5L96-T
M/2)N;W)M86QI>F4M<W!A8V4H9&5S8V5N9&%N=#HZ=&5X="@I*2(O/B`@("`@
M("`@?GX^"B`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB)&=L;V)A;$1O8W5M96YT4F5F5&]#=7)R96YT1FEL92(^
M"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G1E<W1297-U
M;'1S(B!S96QE8W0](B1C;VYT96YT5&%B;&5(96%D:6YG<R]H96%D:6YG6R1G
M;&]B86Q$;V-U;65N=%)E9E1O0W5R<F5N=$9I;&4@/2!`9FEL92UU<FQ=6R1T
M:71L92`]($!T:71L95U;8W5R<F5N="@I+T!T97AT.FQE=F5L(#T@0&QE=F5L
M72(O/@H@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2(Q("9L=#L@8V]U
M;G0H)'1E<W1297-U;'1S*2(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IM
M97-S86=E/B`J*BH@0T%55$E/3CH@375L=&EP;&4@8VAA<'1E<B!H96%D:6YG
M<R!W:71H('-I;6EL87(@;F%M97,Z(#PO>'-L.FUE<W-A9V4^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IM97-S86=E/B`J*BH@5&ET;&4Z(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2(D=&ET;&4B+SX@3&5V96PZ(#QX<VPZ=F%L=64M;V8@
M<V5L96-T/2)`=&5X=#IL979E;"(O/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@
M("`@("`@("`\+WAS;#II9CX*"B`@("`@("`@("`@("`@("`@/'AS;#IV87)I
M86)L92!N86UE/2)E;F-O9&5D5&ET;&4B('-E;&5C=#TB)'1E<W1297-U;'1S
M+T!E;F-O9&5D+71I=&QE(B\^"B`@("`@("`@("`@("`@("`@/'AS;#IC:&]O
M<V4^"B`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D96YC
M;V1E9%1I=&QE(CX*("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE
M;65N="!N86UE/2)A(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ871T<FEB=71E(&YA;64](FYA;64B/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D96YC;V1E9%1I
M=&QE(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IA='1R
M:6)U=&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT
M/@H@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@
M("`@("`@/"%^?B!E=F5N('=H96X@:70@:7,@;F]T('Y^/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](FYE=T5N8V]D9614
M:71L92(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM
M=&5M<&QA=&4@;F%M93TB96YC;V1E+7-T<FEN9R(^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/"%^?B!T:&4@<W!A8V4@:&%S('1O(&)E(&YO
M<FUA;&EZ960L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&]T:&5R=VES92!A;B!I;&QE9V%L(&%R9W5M96YT(&5X8V5P=&EO;B!W:6QL
M(&)E('1H<F]W;B!F;W(@6%1^?CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G1E>'14;T)E16YC;V1E
M9"(@<V5L96-T/2(D=&ET;&4B+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.G9A<FEA8FQE/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IE;&5M96YT(&YA;64](F$B/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB;F%M92(^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1N
M97=%;F-O9&5D5&ET;&4B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R
M=VES93X*("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@
M("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@
M("`@("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)T97-T4F5S=6QT
M<R(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82]C;VYT96YT+71A8FQE
M+6AE861I;F=S+VAE861I;F=;)&-O;G1E;G1486)L95523"`]($!F:6QE+75R
M;%U;)'1I=&QE(#T@0'1I=&QE75MC=7)R96YT*"DO0'1E>'0Z;&5V96P@/2!`
M;&5V96Q=(B\^"B`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](C$@)FQT
M.R!C;W5N="@D=&5S=%)E<W5L=',I(CX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.FUE<W-A9V4^("HJ*B!#055424]..B!-=6QT:7!L92!C:&%P=&5R(&AE
M861I;F=S('=I=&@@<VEM:6QA<B!N86UE<SH@/"]X<VPZ;65S<V%G93X*("`@
M("`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^("HJ*B!4:71L93H@/'AS
M;#IV86QU92UO9B!S96QE8W0](B1T:71L92(O/B!,979E;#H@/'AS;#IV86QU
M92UO9B!S96QE8W0](D!T97AT.FQE=F5L(B\^/"]X<VPZ;65S<V%G93X*("`@
M("`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^("HJ*B`\+WAS;#IM97-S
M86=E/@H@("`@("`@("`@("`@("`@/"]X<VPZ:68^"@H@("`@("`@("`@("`@
M("`@/'AS;#IV87)I86)L92!N86UE/2)E;F-O9&5D5&ET;&4B('-E;&5C=#TB
M)'1E<W1297-U;'1S+T!E;F-O9&5D+71I=&QE(B\^"B`@("`@("`@("`@("`@
M("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0](B1E;F-O9&5D5&ET;&4B/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IE;&5M96YT(&YA;64](F$B/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB;F%M92(^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0]
M(B1E;F-O9&5D5&ET;&4B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\(7Y^(&5V96X@=VAE;B!I="!I<R!N;W0@?GX^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB
M;F5W16YC;V1E9%1I=&QE(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)E;F-O9&4M<W1R:6YG(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\(7Y^('1H92!S<&%C92!H
M87,@=&\@8F4@;F]R;6%L:7IE9"P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@;W1H97)W:7-E(&%N(&EL;&5G86P@87)G=6UE;G0@97AC
M97!T:6]N('=I;&P@8F4@=&AR;W=N(&9O<B!85'Y^/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=&5X
M=%1O0F5%;F-O9&5D(B!S96QE8W0](B1T:71L92(O/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ=F%R:6%B;&4^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB82(^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)N86UE(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB)&YE=T5N8V]D9614:71L92(O/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S
M93X*("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L
M.F-H;V]S93X*"BTM/@H*("`@(#PO>'-L.G1E;7!L871E/@H*"@H*("`@(#PA
M+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^
M"B`@("`\(2TM("`@($-214%424].($]&($$@0T].5$5.5"!404),12!,24Y+
M("`@("TM/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*B`M+3X*"@H@("`@/"$M+2!A('-P96-I86P@8F5H879I;W(@
M;V8@=&5X=#IA"B`@("`@("`@*&-A;&QE9"!F<F]M('1H92`G=&5X=#IA)R!T
M96UP;&%T92D@+2T^"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)C<F5A=&4M
M8V]N=&5N="UT86)L92UL:6YK(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64]
M(F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@/'AS;#IC:&]O<V4^
M"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)N;W0H)&]U='!U=%1Y<&4@
M/2`G5TU,)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64]
M(F$B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64]
M(FAR968B/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)S
M=&%R=',M=VET:"A`>&QI;FLZ:')E9BP@)R,G*2(^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)C;W)R96-T
M2&5A9&EN9R(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82]C;VYT96YT
M+71A8FQE+6AE861I;F=S+VAE861I;F=;8W5R<F5N="@I+T!X;&EN:SIH<F5F
M(#T@0&-O;G1E;G0M=&%B;&4M:61=(B\^"@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D8V]R<F5C=$AE
M861I;F<O0&]U="UF:6QE+75R;"(O/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=&5X=#XC/"]X<VPZ=&5X=#X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&-O
M<G)E8W1(96%D:6YG+T!A8G-O;'5T92UC:&%P=&5R+6QE=F5L(B\^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/BL\+WAS;#IT
M97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2(D8V]R<F5C=$AE861I;F<O0&5N8V]D960M=&ET;&4B
M+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA
M=&4@;F%M93TB8W)E871E+6-O;6UO;BUL:6YK(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O
M;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A
M=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC
M86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC
M:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H*
M("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB
M87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A
M=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@
M("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@
M("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\(2TM
M(#)$3SH@8W5R<F5N=&QY(&YO(%=-3"!S=7!P;W)T"@H@("`@("`@("`@("`@
M("`@/"%^?B!N;R!N97-T960@<"!T86=S(&EN('=M;#$N,2!A;&QO=V5D('Y^
M/@H@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0](F%N8V5S=&]R.CHJ6V-O;G1A:6YS*"1W
M87`M<&%R86=R87!H+65L96UE;G1S+"!N86UE*"DI72(^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)A(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](FAR968B
M/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)`>&QI;FLZ:')E9B(O/CPO>'-L.F%T
M=')I8G5T93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ87!P
M;'DM=&5M<&QA=&5S('-E;&5C=#TB+B(O/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.G=H96X^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)P(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE
M/2)A(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%T
M=')I8G5T92!N86UE/2)H<F5F(CX\>'-L.G9A;'5E+6]F('-E;&5C=#TB0'AL
M:6YK.FAR968B+SX\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,@<V5L96-T/2(N
M(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@
M("`@(#PO>'-L.F-H;V]S93X@("TM/@H@("`@("`@("`@("`\+WAS;#IO=&AE
M<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA
M=&4^"@H*"3PA+2T*"2`@("!#4D5!5$E/3B!/1B!!($A%3%!%4B!605))04),
M12!!4R!73U)+05)/54Y$($9/4B!42$4@0T].5$5.5"!404),12!53%(@0E5'
M"@H*("`@("`@("!!<R!N;R!V86QI9"!54DP@9G)O;2!T:&4@8V]N=&5N="!T
M86)L92!T;R!T:&4@8VAI;&0@9&]C=6UE;G1S(&5X:7-T(&EN('1H92!C;VYT
M96YT('1A8FQE+`H@("`@("`@(&$@=V]R:RUA<F]U;F0@:7,@9&]N93H*"B`@
M("`@("`@1FER<W0@='=O(&AE;'!E<B!V87)I86)L97,@87)E(&)E:6YG(&-R
M96%T960N"@H@("`@("`@($]N92!C;VYT86EN:6YG('1H92!L:7-T(&]F(&%L
M;"!R969E<F5N8V5S(&]F('1H92!G;&]B86P@9&]C=6UE;G0Z"B`@("`@("`@
M8V]N=&%I;F<@86QL('1H96ER('1I=&QE+`H@("`@("`@(&9O<B!E>&%M<&QE
M.@H*("`@("`@("`@(`D\8VAA<'1E<BUR968@=&ET;&4](F%4:71L92`Q(B\^
M"B`@("`@("`@("`)/&-H87!T97(M<F5F('1I=&QE/2)A5&ET;&4@,B(O/@H@
M("`@("`@("`@"3QC:&%P=&5R+7)E9B!T:71L93TB851I=&QE(#(O/@H@("`@
M("`@("`@"3QC:&%P=&5R+7)E9B!T:71L93TB851I=&QE(#,O/@H*("`@("`@
M("!4:&4@;W1H97(@8V]N=&%I;FEN9R!A;&P@:&5A9&EN9R!F<F]M('1H92!C
M:&EL9"!D;V-U;65N=',@;&EN:V5D(&9R;VT@=&AE(&=L;V)A;"!D;V-U;65N
M="X*("`@("`@("!4:&4@=F%R:6%B;&4@)V-H:6QD<F5N2&5A9&EN9W,G(&-O
M;G1A:6YS('1H96ER('1I=&QE(&%N9"!T:&4@;G5M8F5R(&]F('!R96-E9&EN
M9R!S:6UI;&%R('1I=&QE<RP*("`@("`@("!F;W(@97AA;7!L93H*"@H@("`@
M("`@("`@"3QC:&EL9"!F:6QE+75R;#TB85523"(^"B`@("`@("`@("`)"3QH
M96%D:6YG('1I=&QE/2)A5&ET;&4Q(B!L979E;#TB,2(^"B`@("`@("`@("`)
M"3QH96%D:6YG('1I=&QE/2)A5&ET;&4R(B!L979E;#TB,B(^"B`@("`@("`@
M("`)"3QH96%D:6YG('1I=&QE/2)A5&ET;&4S(B!L979E;#TB,2(^"B`@("`@
M("`@("`@(#PO8VAI;&0^"@H@("`@("`@($9O<B!E86-H(&-H87!T97(@<F5F
M97)E;F-E(&9R;VT@=&AE(&-O;G1E;G0@=&%B;&4@=&AE"@H@("`@("`@("!B
M>2!E;F-O9&EN9R!T:&4@8VAA<'1E<B!N86UE<R!O9B!T:&4@8VAI;&0@9&]C
M=6UE;G0@=VET:"!T:&4@:F%V82!54DQ%;F-O9&5R(&%N9`H@("`@("`@('5S
M92!T:&ES(&%S(&$@<&%R="!O9B!A(&QI;FLN($9U<G1H97)M;W)E(&9O<B!A
M;&P@:&5A9&EN9R!E;&5M96YT<R!A(&5N8V]D960@86YC:&]R('=I;&P@8F4@
M8W)E871E9"!F<F]M('1H92!H96%D:6YG+@H@("`@("`@($QA<W0@=&AE('=O
M<FMA<F]U;F0@<&%R<V5S(&%L;"!C:&EL9')E;B!D;V-U;65N=',@9F]R('1H
M:7,@86YH;W(L(&%S('1H97)E(&ES(&YO(&1I<W1I;F-T:6]N(&]F(&9I;&5S
M(&9R;VT@=&AE(&-O;G1E;G0@=&%B;&4@96YT<FEE<RX*"B`@("`@("`@5&AE
M(&YE=R!A9&1E9"!N;V1E('-E="!T;R!T:&4@8V]L;&5C=&5D1VQO8F%L1&%T
M82!V87)I86)L92!C;VYC97)I;F<@=&AE(&-O;G1E;G0@=&%B;&4@:7,@=W)I
M='1E;B!A<PH*"@D)/&-O;G1E;G0M=&%B;&4M:&5A9&EN9W,@8V]N=&5N="UT
M86)L92UU<FP](F%54DQ?5&]4:&5'96YE<F%T961#;VYT96YT5&%B;&4B/@H@
M("`@("`)"3QH96%D:6YG(&9I;&4M=7)L/2)A1FEL95523%1O5&AE1V5N97)A
M=&5D2&5A9&EN9S$B(&QE=F5L/2(Q(CX*("`@("`@"0D\:&5A9&EN9R!F:6QE
M+75R;#TB849I;&554DQ4;U1H94=E;F5R871E9$AE861I;F<R(B!L979E;#TB
M,B(^"B`@("`@(`D)/&AE861I;F<@9FEL92UU<FP](F%&:6QE55),5&]4:&5'
M96YE<F%T961(96%D:6YG,2(@;&5V96P](C$B/@H@("`@("`)"3QH96%D:6YG
M(&9I;&4M=7)L/2)A1FEL95523%1O5&AE1V5N97)A=&5D2&5A9&EN9S(B(&QE
M=F5L/2(R(CX*"0D\+V-O;G1E;G0M=&%B;&4M:&5A9&EN9W,^"@H*("`@("`@
M("!0<F5C;VYD:71I;VYS.@H)"51H92!C;W)R96-T('-E<75E;F-E(&]F(&-H
M:6QD(&1O8W5M96YT<R!A8V-O<F1I;F<@=&\@=&AE($-O;G1E;G0@5&%B;&4@
M:7,@;F5C97-S87)Y+"!G<F%N=&5D(&)Y('1H92!O9F9I8V4N"@DM+3X*"3QX
M<VPZ=&5M<&QA=&4@;F%M93TB0W)E871E+6AE;'!E<BUV87)I86)L97,M9F]R
M+4-O;G1E;G0M5&%B;&4B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L
M;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@("`@("`\>'-L.FEF('1E<W0](B1I
M<T1E8G5G36]D92(^/'AS;#IM97-S86=E/D-R96%T:6]N(&]F(&=L;V)A;"!D
M;V-U;65N="!H96QP97(@=F%R:6%B;&4@9F]R('1H92!C;VYT96YT('1A8FQE
M+BXN+CPO>'-L.FUE<W-A9V4^/"]X<VPZ:68^"@H@("`@("`@(#PA+2T@2&5R
M92!A(&AE;'!E<B!V87)I86)L92!O9B!T:&4@8V]N=&5N="!T86)L92!I<R!C
M<F5A=&5D+"!O9B!A;&P@8VAA<'1E<BUR969E<F5N8V5S('=H:6-H('!O:6YT
M('1O(&$@8VAI;&0@9&]C=6UE;G0N"B`@("`@("`@("`@("!A;B`G8VAA<'1E
M<BUR968G(&5L96UE;G0@=VEL;"!B92!C<F5A=&5D+"!C;VYT86EN9R!T:&5I
M<B!T:71L92!A;F0@=&AE(&YU;6)E<B!O9B!P<F5C961I;F<@<VEM:6QA<B!T
M:71L97,L"B`@("`@("`@("`@("!F;W(@97AA;7!L93H*"B`@("`@("`@("`@
M("`@"3QC:&%P=&5R+7)E9B!T:71L93TB851I=&QE(#$B+SX*("`@("`@("`@
M("`@("`)/&-H87!T97(M<F5F('1I=&QE/2)A5&ET;&4@,B(O/@H@("`@("`@
M("`@("`@(`D\8VAA<'1E<BUR968@=&ET;&4](F%4:71L92`R(B\^"B`@("`@
M("`@("`@("`@"3QC:&%P=&5R+7)E9B!T:71L93TB851I=&QE(#,B+SX*("`@
M("`@("`@("`@+2T^"B`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)C:&%P
M=&5R4F5F<RU25$8B/@H@("`@("`@("`@("`\(2TM("<O*B\G(&%S('1H92!F
M;&%T(&%N9"!T:&4@>FEP<&5D(%A-3"!F:6QE(&9O<FUA="!H879E(&1I9F9E
M<F5N="!R;V]T(&5L96UE;G1S("TM/@H@("`@("`@("`@("`\>'-L.F9O<BUE
M86-H('-E;&5C=#TB+RHO;V9F:6-E.F)O9'DO=&5X=#IT86)L92UO9BUC;VYT
M96YT+W1E>'0Z:6YD97@M8F]D>2]T97AT.G`O=&5X=#IA(CX*("`@("`@("`@
M("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB8W5R<F5N=%1I=&QE(B!S96QE
M8W0](FYO<FUA;&EZ92US<&%C92AS=')I;F<H+BDI(B\^"B`@("`@("`@("`@
M("`@("`\>'-L.F5L96UE;G0@;F%M93TB8VAA<'1E<BUR968B/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](G1I=&QE(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1C
M=7)R96YT5&ET;&4B+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IA='1R
M:6)U=&4^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M
M93TB8V]N=&5N="UT86)L92UI9"(^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)`>&QI;FLZ:')E9B(O/@H@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@
M/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@
M("`@("`@/"]X<VPZ=F%R:6%B;&4^"B`@("`@("`@/'AS;#II9B!T97-T/2(D
M:7-$96)U9TUO9&4B/CQX<VPZ;65S<V%G93Y&:6YI<VAE9"!T:&4@0W)E871I
M;VX@;V8@9VQO8F%L(&1O8W5M96YT(&AE;'!E<B!V87)I86)L92!F;W(@=&AE
M(&-O;G1E;G0@=&%B;&4A/"]X<VPZ;65S<V%G93X\+WAS;#II9CX*"@H*"B`@
M("`@("`@/'AS;#II9B!T97-T/2(D:7-$96)U9TUO9&4B/CQX<VPZ;65S<V%G
M93Y#<F5A=&EO;B!O9B!G;&]B86P@9&]C=6UE;G0@:&5L<&5R('9A<FEA8FQE
M(&9O<B!T:&4@8VAI;&0@9&]C=6UE;G1S+BXN+CPO>'-L.FUE<W-A9V4^/"]X
M<VPZ:68^"B`@("`@("`@/"$M+2!(97)E(&$@:&5L<&5R('9A<FEA8FQE(&]F
M(&-R96%T960@9G)O;2!T:&4@8VAI;&1R96X@9&]C=6UE;G1S+@H@("`@("`@
M("`@("`@0V]N=&%I;F<@86QL(&AE861I;F<@96QE;65N=',@9G)O;2!T:&4@
M8VAI;&0@9&]C=6UE;G1S+B!3;VUE(&]R(&%L;"!O9B!T:&5M(&%R90H@("`@
M("`@("`@("`@8VAA<'1E<G,@<F5F97)E;F-E9"!B>2!T:&4@1VQO8F%L($1O
M8W5M96YT+@H@("`@("`@("`@("`@5&AE('9A<FEA8FQE(&-O;G1A:6YS('1H
M96ER('1I=&QE+"!T:&4@;&5V96P@;V8@=&AE(&AE861I;F<@86YD('1H92!F
M:6QE(%523"!O9B!T:&4@8VAI;&0L"B`@("`@("`@("`@("!F;W(@97AA;7!L
M93H*"B`@("`@("`@("`)"3QH96%D:6YG('1I=&QE/2)A5&ET;&4Q(B!L979E
M;#TB,2(@9FEL92UU<FP](F%54DPQ(CX*("`@("`@("`@(`D)/&AE861I;F<@
M=&ET;&4](F%4:71L93(B(&QE=F5L/2(R(B!F:6QE+75R;#TB85523#$B/@H@
M("`@("`@("`@"0D\:&5A9&EN9R!T:71L93TB851I=&QE,R(@;&5V96P](C$B
M(&9I;&4M=7)L/2)A55),,2(^"B`@("`@("`@("`)"3QH96%D:6YG('1I=&QE
M/2)A5&ET;&4T(B!L979E;#TB,2(@9FEL92UU<FP](F%54DPR(CX*("`@("`@
M("`@(`D)/&AE861I;F<@=&ET;&4](F%4:71L934B(&QE=F5L/2(R(B!F:6QE
M+75R;#TB85523#(B/@H@("`@("`@("`@"0D\:&5A9&EN9R!T:71L93TB851I
M=&QE,B(@;&5V96P](C,B(&9I;&4M=7)L/2)A55),,B(^"B`@("`@("`@("`)
M"3QH96%D:6YG('1I=&QE/2)A5&ET;&4V(B!L979E;#TB,R(@9FEL92UU<FP]
M(F%54DPR(CX*("`@("`@("`@("`@("`@(#QH96%D:6YG+6-O=6YT/C<\+VAE
M861I;F<M8V]U;G0^"B`@("`@("`@("`@("TM/@H@("`@("`@(#QX<VPZ=F%R
M:6%B;&4@;F%M93TB8VAI;&1R96Y(96%D:6YG<RU25$8B/@H@("`@("`@("`@
M("`\(2TM(&%L;"!H96%D97)S(&9R;VT@8VAI;&1R96X@9&]C=6UE;G1S('=I
M;&P@8F4@861D960@+2T^"B`@("`@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA
M=&5S('-E;&5C=#TB+RHO;V9F:6-E.F)O9'DO=&5X=#IS96-T:6]N(B!M;V1E
M/2)C<F5A=&EO;BUO9BUV87)I86)L92(O/@H@("`@("`@(#PO>'-L.G9A<FEA
M8FQE/@H@("`@("`@(#QX<VPZ:68@=&5S=#TB)&ES1&5B=6=-;V1E(CX\>'-L
M.FUE<W-A9V4^1FEN:7-H960@=&AE($-R96%T:6]N(&]F(&=L;V)A;"!D;V-U
M;65N="!H96QP97(@=F%R:6%B;&4@9F]R('1H92!C:&EL9"!D;V-U;65N=',A
M/"]X<VPZ;65S<V%G93X\+WAS;#II9CX*"@H@("`@("`@(#QX<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA
M8FQE*"=X=#IN;V1E+7-E="<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ8V%L
M;"UT96UP;&%T92!N86UE/2)#<F5A=&4M9VQO8F%L+79A<FEA8FQE+69O<BU#
M;VYT96YT+51A8FQE(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB8VAA<'1E<E)E9G,B("`@("!S96QE8W0](GAT.FYO9&4M
M<V5T*"1C:&%P=&5R4F5F<RU25$8I(B\^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](F-H:6QD<F5N2&5A9&EN9W,B("`@("!S
M96QE8W0](GAT.FYO9&4M<V5T*"1C:&EL9')E;DAE861I;F=S+5)41BDB+SX*
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L
M;&5C=&5D1VQO8F%L1&%T82(@('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A
M=&$B+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H)WAA;&%N.FYO9&5S970G*2(^"B`@
M("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB0W)E871E
M+6=L;V)A;"UV87)I86)L92UF;W(M0V]N=&5N="U486)L92(^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-H87!T97)2969S
M(B`@("`@<V5L96-T/2)X86QA;CIN;V1E<V5T*"1C:&%P=&5R4F5F<RU25$8I
M(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F-H:6QD<F5N2&5A9&EN9W,B("`@("!S96QE8W0](GAA;&%N.FYO9&5S970H
M)&-H:6QD<F5N2&5A9&EN9W,M4E1&*2(O/@H@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B`@
M<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@
M("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*
M"@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64](D-R96%T92UG;&]B86PM=F%R
M:6%B;&4M9F]R+4-O;G1E;G0M5&%B;&4B/@H@("`@("`@(#QX<VPZ<&%R86T@
M;F%M93TB8VAA<'1E<E)E9G,B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64]
M(F-H:6QD<F5N2&5A9&EN9W,B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64]
M(F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*"@H@("`@("`@(#QX<VPZ:68@=&5S
M=#TB)&ES1&5B=6=-;V1E(CX*("`@("`@("`@("`@/"$M+2!H96QP97(@=F%R
M:6%B;&4@8V]L;&5C=&EN9R!A;&P@:&5A9&EN9W,@9G)O;2!T:&4@9VQO8F%L
M(&1O8W5M96YT(&9I;&4@8VAI;&1R96XM+3X*("`@("`@("`@("`@/'AS;#IF
M;W(M96%C:"!S96QE8W0](B1C:&EL9')E;DAE861I;F=S+VAE861I;F<B/@H@
M("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/B,@("`@("`@("`@("`@(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2)P;W-I=&EO;B@I(B\^/"]X<VPZ;65S<V%G
M93X*("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93YL979E;#H@("`@("`@
M("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB0&QE=F5L(B\^/"]X<VPZ;65S<V%G
M93X*("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93YT:71L93H@("`@("`@
M("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB0'1I=&QE(B\^/"]X<VPZ;65S<V%G
M93X*("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93YE;F-O9&5D+71I=&QE
M.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB0&5N8V]D960M=&ET;&4B+SX\+WAS
M;#IM97-S86=E/@H@("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/F9I;&4M
M=7)L.B`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)`9FEL92UU<FPB+SX\
M+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/FAE
M861E<BUN;SH@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)`:&5A9&5R+6YO
M(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G
M93XJ*CPO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@(#PO>'-L.F9O<BUE86-H
M/@H@("`@("`@("`@("`\>'-L.FUE<W-A9V4^*BH\+WAS;#IM97-S86=E/@H@
M("`@("`@("`@("`\>'-L.FUE<W-A9V4^*BH\+WAS;#IM97-S86=E/@H*("`@
M("`@("`@("`@/"$M+2!H96QP97(@=F%R:6%B;&4@8V]L;&5C=&EN9R!A;&P@
M:&5A9&EN9R!R969E<F5N8V5S(&9R;VT@=&AE(&-O;G1E;G0@=&%B;&4@;V8@
M=&AE('1H92!G;&]B86P@9&]C=6UE;G0@+2T^"B`@("`@("`@("`@(#QX<VPZ
M;65S<V%G93YC:&EL9')E;DAE861I;F=S+VAE861I;F<M8V]U;G0Z(#QX<VPZ
M=F%L=64M;V8@<V5L96-T/2(D8VAI;&1R96Y(96%D:6YG<R]H96%D:6YG+6-O
M=6YT(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@/'AS;#IF;W(M96%C
M:"!S96QE8W0](B1C:&%P=&5R4F5F<R]C:&%P=&5R+7)E9B(^"B`@("`@("`@
M("`@("`@("`\>'-L.FUE<W-A9V4^(R`\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M<&]S:71I;VXH*2(O/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@("`@("`\
M>'-L.FUE<W-A9V4^=&ET;&4Z(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)`=&ET
M;&4B+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@/'AS;#IM97-S
M86=E/BHJ/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@/"]X<VPZ9F]R+65A
M8V@^"B`@("`@("`@/"]X<VPZ:68^"@H*("`@("`@("`\>'-L.F-H;V]S93X*
M("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L
M92@G<WAG:&5L<&5R.G-E="UH96%D:6YG+6YO)RDB/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)S>&=H96QP97(Z<V5T+6AE
M861I;F<M;F\H,2DB+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB<WAG:&5L<&5R.G-E="UC=7)R96YT+6-H:6QD+6YO*#$I
M(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0]
M(G-X9VAE;'!E<CIS970M8W5R<F5N="UC:&EL9"UU<FPH<W1R:6YG*"1C:&EL
M9')E;DAE861I;F=S+VAE861I;F<O0&9I;&4M=7)L*2DB+SX*("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U
M;F-T:6]N+6%V86EL86)L92@G:F%V83IC;VTN<W5N+G-T87(N>'-L="YH96QP
M97(N4WAG0VAI;&14<F%N<V9O<FUE<BYS971(96%D:6YG3F\G*2(^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](FIA=F$Z8V]M
M+G-U;BYS=&%R+GAS;'0N:&5L<&5R+E-X9T-H:6QD5')A;G-F;W)M97(N<V5T
M2&5A9&EN9TYO*#$I(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU
M92UO9B!S96QE8W0](FIA=F$Z8V]M+G-U;BYS=&%R+GAS;'0N:&5L<&5R+E-X
M9T-H:6QD5')A;G-F;W)M97(N<V5T0W5R<F5N=$-H:6QD3F\H,2DB+SX*("`@
M("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB:F%V83IC
M;VTN<W5N+G-T87(N>'-L="YH96QP97(N4WAG0VAI;&14<F%N<V9O<FUE<BYS
M971#=7)R96YT0VAI;&15<FPH<W1R:6YG*"1C:&EL9')E;DAE861I;F=S+VAE
M861I;F<O0&9I;&4M=7(I*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@(#PO>'-L.F-H;V]S93X*"B`@("`@("`@/'AS;#II9B!T97-T/2(D
M:7-$96)U9TUO9&4B/CQX<VPZ;65S<V%G93Y#<F5A=&EN9R!G;&]B86P@9&]C
M=6UE;G0@=F%R:6%B;&4@9F]R(&-H87!T97(@<F5L871I;VYS+BXN+CPO>'-L
M.FUE<W-A9V4^/"]X<VPZ:68^"B`@("`@("`@/'AS;#IV87)I86)L92!N86UE
M/2)C;VYT96YT5&%B;&5(96%D:6YG<T=L;V)A;$1A=&$M4E1&(CX*("`@("`@
M("`@("`@/'AS;#IE;&5M96YT(&YA;64](F-O;G1E;G0M=&%B;&4M:&5A9&EN
M9W,B/@H@("`@("`@("`@("`@("`@/"$M+2!A;&P@:&5A9&EN9W,@87)E(&QI
M;FME9"!F<F]M('1H92!C=7)R96YT(&=L;V)A;"!D;V-U;65N="!I;G!U="!F
M:6QE("TM/@H@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB
M8V]N=&5N="UT86)L92UU<FPB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=F%L=64M;V8@<V5L96-T/2(D8V]N=&5N=%1A8FQE55),(B\^"B`@("`@("`@
M("`@("`@("`\+WAS;#IA='1R:6)U=&4^"@H@("`@("`@("`@("`@("`@/"$M
M+2!H860@=&\@=7-E(&$@9F]R(&QO;W`L(&%S(&$@<F5C=7)S:6]N(&5N9',@
M=VET:"!A;B!S=&%C:V]V97)F;&]W(&5X8V5P=&EO;B!A9G1E<B!A8F]U="`V
M,#`@<F5C=7)S:79E(&-A;&QS("TM/@H@("`@("`@("`@("`@("`@/'AS;#IC
M:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U
M;F-T:6]N+6%V86EL86)L92@G<WAG:&5L<&5R.F=E="UH96%D:6YG+6YO)RDB
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE
M8W0](B1C:&%P=&5R4F5F<R]C:&%P=&5R+7)E9B(^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB<V5A<F-H
M2&5A9&EN9TEN0VAI;&1$;V-U;65N="(^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-H87!T97)2969S
M(B`@("`@("`@('-E;&5C=#TB)&-H87!T97)2969S(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-H
M:6QD<F5N2&5A9&EN9W,B("`@('-E;&5C=#TB)&-H:6QD<F5N2&5A9&EN9W,B
M+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB8W5R<F5N=$-H87!T97)2969.;R(@<V5L96-T/2)P;W-I
M=&EO;B@I(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F-U<G)E;G1(96%D:6YG3F\B("`@('-E;&5C
M=#TB<WAG:&5L<&5R.F=E="UH96%D:6YG+6YO*"DB+SX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8W5R
M<F5N=$-H:6QD55),(B`@("`@<V5L96-T/2)S>&=H96QP97(Z9V5T+6-U<G)E
M;G0M8VAI;&0M=7)L*"DB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8W5R<F5N=$-H:6QD3F\B("`@
M("`@<V5L96-T/2)S>&=H96QP97(Z9V5T+6-U<G)E;G0M8VAI;&0M;F\H*2(O
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP
M;&%T93X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ9F]R+65A8V@^
M"B`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G
M:F%V83IC;VTN<W5N+G-T87(N>'-L="YH96QP97(N4WAG0VAI;&14<F%N<V9O
M<FUE<BYG971(96%D:6YG3F\G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F9O<BUE86-H('-E;&5C=#TB)&-H87!T97)2969S+V-H87!T97(M
M<F5F(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT
M96UP;&%T92!N86UE/2)S96%R8VA(96%D:6YG26Y#:&EL9$1O8W5M96YT(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB8VAA<'1E<E)E9G,B("`@("`@("`@<V5L96-T/2(D8VAA<'1E
M<E)E9G,B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB8VAI;&1R96Y(96%D:6YG<R(@("`@<V5L96-T
M/2(D8VAI;&1R96Y(96%D:6YG<R(O/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C=7)R96YT0VAA<'1E
M<E)E9DYO(B!S96QE8W0](G!O<VET:6]N*"DB+SX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8W5R<F5N
M=$AE861I;F=.;R(@("`@<V5L96-T/2)J879A.F-O;2YS=6XN<W1A<BYX<VQT
M+FAE;'!E<BY3>&=#:&EL9%1R86YS9F]R;65R+F=E=$AE861I;F=.;R@I(B\^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](F-U<G)E;G1#:&EL9%523"(@("`@('-E;&5C=#TB:F%V83IC
M;VTN<W5N+G-T87(N>'-L="YH96QP97(N4WAG0VAI;&14<F%N<V9O<FUE<BYG
M971#=7)R96YT0VAI;&15<FPH*2(O/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C=7)R96YT0VAI;&1.
M;R(@("`@("!S96QE8W0](FIA=F$Z8V]M+G-U;BYS=&%R+GAS;'0N:&5L<&5R
M+E-X9T-H:6QD5')A;G-F;W)M97(N9V5T0W5R<F5N=$-H:6QD3F\H*2(O/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T
M93X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@
M(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*"B`@
M("`@("`@("`@(#PA+2T@861D:6YG('1H92!A;')E861Y(&5X:7-I=&EN9R!G
M;&]B86P@9&%T82!E;G9I<F]N;65N="`M+3X*("`@("`@("`@("`@/'AS;#IC
M;W!Y+6]F('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@
M("`\+WAS;#IV87)I86)L93X*("`@("`@("`\>'-L.FEF('1E<W0](B1I<T1E
M8G5G36]D92(^/'AS;#IM97-S86=E/D9I;FES:&5D(&=L;V)A;"!D;V-U;65N
M="!V87)I86)L92!F;W(@8VAA<'1E<B!R96QA=&EO;G,A/"]X<VPZ;65S<V%G
M93X\+WAS;#II9CX*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@
M(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H)WAT.FYO9&4M
M<V5T)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA
M;64](G-T87)T+7-E;&8M86YD+6-H:6QD<F5N+71R86YS9F]R;6%T:6]N(CX*
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L
M;&5C=&5D1VQO8F%L1&%T82(@("`@("`@<V5L96-T/2)X=#IN;V1E+7-E="@D
M8V]N=&5N=%1A8FQE2&5A9&EN9W-';&]B86Q$871A+5)41BDB+SX*("`@("`@
M("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@(#PO
M>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO
M;BUA=F%I;&%B;&4H)WAA;&%N.FYO9&5S970G*2(^"B`@("`@("`@("`@("`@
M("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB<W1A<G0M<V5L9BUA;F0M8VAI
M;&1R96XM=')A;G-F;W)M871I;VXB/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B`@("`@
M("!S96QE8W0](GAA;&%N.FYO9&5S970H)&-O;G1E;G1486)L94AE861I;F=S
M1VQO8F%L1&%T82U25$8I(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL
M+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@(#PO
M>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\>'-L.G1E
M;7!L871E(&YA;64](G-E87)C:$AE861I;F=);D-H:6QD1&]C=6UE;G0B/@H@
M("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8VAA<'1E<E)E9G,B+SX*("`@("`@
M("`\>'-L.G!A<F%M(&YA;64](F-H:6QD<F5N2&5A9&EN9W,B+SX*("`@("`@
M("`\>'-L.G!A<F%M(&YA;64](F-U<G)E;G1#:&%P=&5R4F5F3F\B+SX*("`@
M("`@("`\>'-L.G!A<F%M(&YA;64](F-U<G)E;G1(96%D:6YG3F\B+SX*("`@
M("`@("`\>'-L.G!A<F%M(&YA;64](F-U<G)E;G1#:&EL9%523"(O/@H@("`@
M("`@(#QX<VPZ<&%R86T@;F%M93TB8W5R<F5N=$-H:6QD3F\B+SX*"@H@("`@
M("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB8W5R<F5N=$-H87!T97)2968B("`@
M("`@<V5L96-T/2(D8VAA<'1E<E)E9G,O8VAA<'1E<BUR969;)&-U<G)E;G1#
M:&%P=&5R4F5F3F]=(B\^"B`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)C
M=7)R96YT0VAA<'1E<DE$(B`@("`@("!S96QE8W0](B1C=7)R96YT0VAA<'1E
M<E)E9B]`8V]N=&5N="UT86)L92UI9"(O/@H@("`@("`@(#QX<VPZ=F%R:6%B
M;&4@;F%M93TB8W5R<F5N=$-H87!T97)4:71L92(@("`@<V5L96-T/2(D8W5R
M<F5N=$-H87!T97)2968O0'1I=&QE(B\^"@H@("`@("`@(#QX<VPZ=F%R:6%B
M;&4@;F%M93TB8W5R<F5N=$-H:6QD2&5A9&EN9R(@("`@<V5L96-T/2(D8VAI
M;&1R96Y(96%D:6YG<R]H96%D:6YG6R1C=7)R96YT2&5A9&EN9TYO72(O/@H@
M("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB:&5A9&EN9U1I=&QE(B`@("`@
M("`@("`@<V5L96-T/2(D8W5R<F5N=$-H:6QD2&5A9&EN9R]`=&ET;&4B+SX*
M("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](FAE861I;F=,979E;"(@("`@
M("`@("`@('-E;&5C=#TB)&-U<G)E;G1#:&EL9$AE861I;F<O0&QE=F5L(B\^
M"B`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)H96%D:6YG3F\B("`@("`@
M("`@("`@("!S96QE8W0](B1C=7)R96YT0VAI;&1(96%D:6YG+T!H96%D97(M
M;F\B+SX*("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](FYE=T-H:6QD55),
M(B`@("`@("`@("`@('-E;&5C=#TB)&-U<G)E;G1#:&EL9$AE861I;F<O0&9I
M;&4M=7)L(B\^"@H@("`@("`@(#QX<VPZ:68@=&5S=#TB)&ES1&5B=6=-;V1E
M(CX*("`@("`@("`@("`@/'AS;#IM97-S86=E/BHJ*B!N97<@:&5A9&EN9R`\
M+WAS;#IM97-S86=E/@H@("`@("`@("`@("`\>'-L.FUE<W-A9V4^8W5R<F5N
M=$-H87!T97))1#H@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1C=7)R96YT
M0VAA<'1E<DE$(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@/'AS;#IM
M97-S86=E/F-U<G)E;G1#:&%P=&5R5&ET;&4Z(#QX<VPZ=F%L=64M;V8@<V5L
M96-T/2(D8W5R<F5N=$-H87!T97)4:71L92(O/CPO>'-L.FUE<W-A9V4^"B`@
M("`@("`@("`@(#QX<VPZ;65S<V%G93YC=7)R96YT0VAA<'1E<DE$.B`@("`\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB)&-U<G)E;G1#:&%P=&5R240B+SX\+WAS
M;#IM97-S86=E/@H@("`@("`@("`@("`\>'-L.FUE<W-A9V4^8W5R<F5N=$AE
M861I;F=.;SH@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1C=7)R96YT2&5A
M9&EN9TYO(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@/'AS;#IM97-S
M86=E/FAE861I;F=4:71L93H@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T
M/2(D:&5A9&EN9U1I=&QE(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@
M/'AS;#IM97-S86=E/FAE861I;F=,979E;#H@("`@("`@(#QX<VPZ=F%L=64M
M;V8@<V5L96-T/2(D:&5A9&EN9TQE=F5L(B\^/"]X<VPZ;65S<V%G93X*("`@
M("`@("`@("`@/'AS;#IM97-S86=E/FAE861I;F=.;SH@("`@("`@("`@(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2(D:&5A9&EN9TYO(B\^/"]X<VPZ;65S<V%G
M93X*("`@("`@("`@("`@/'AS;#IM97-S86=E/FYE=T-H:6QD55),.B`@("`@
M("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D;F5W0VAI;&154DPB+SX\+WAS
M;#IM97-S86=E/@H@("`@("`@(#PO>'-L.FEF/@H*("`@("`@("`\>'-L.G9A
M<FEA8FQE(&YA;64](F]U=$9I;&554DPB/@H@("`@("`@("`@("`\>'-L.F-H
M;V]S93X*("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB<W5B<W1R
M:6YG+6)E9F]R92@D;F5W0VAI;&154DPL)RYX;6PG*2(^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O;F-A="AS=6)S=')I
M;F<M8F5F;W)E*"1N97=#:&EL9%523"PG+GAM;"<I+"<N:'1M)RDB+SX*("`@
M("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2)S=6)S=')I;F<M8F5F;W)E*"1N97=#:&EL9%523"PG
M+G-X)RDB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L
M96-T/2)C;VYC870H<W5B<W1R:6YG+6)E9F]R92@D;F5W0VAI;&154DPL)RYS
M>"<I+"<N:'1M)RDB+SX*("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@/"]X<VPZ=F%R:6%B
M;&4^"B`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)I<T-H87!T97)(96%D
M:6YG(B!S96QE8W0](B1H96%D:6YG5&ET;&4@/2`D8W5R<F5N=$-H87!T97)4
M:71L92(O/@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB:7-.97=&:6QE
M(B!S96QE8W0](G-T<FEN9R@D;F5W0VAI;&154DPI("$]('-T<FEN9R@D8W5R
M<F5N=$-H:6QD55),*2(O/@H*"@H*("`@("`@("`\>'-L.FEF('1E<W0](B1I
M<TYE=T9I;&4B/@H@("`@("`@("`@("`\(2TM(')E<V5T(&]F('1H92!A;')E
M861Y(&-O;&QE8W1E9"!C:&EL9"!H96%D97)S("TM/@H@("`@("`@("`@("`\
M>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB8V%L8RUC:&%P=&5R+6YU;6)E<G,B
M/@H@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)L979E
M;"(@<V5L96-T/2(P(B\^"B`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA
M=&4^"B`@("`@("`@/"]X<VPZ:68^"B`@("`@("`@/'AS;#IV87)I86)L92!N
M86UE/2)A8G-O;'5T94-H87!T97),979E;"(^"B`@("`@("`@("`@(#QX<VPZ
M8V%L;"UT96UP;&%T92!N86UE/2)C86QC+6-H87!T97(M;G5M8F5R<R(^"B`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FQE=F5L(B!S
M96QE8W0](FYU;6)E<B@D:&5A9&EN9TQE=F5L*2(O/@H@("`@("`@("`@("`\
M+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@(#PO>'-L.G9A<FEA8FQE/@H*
M"B`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](FAE861I;F<B/@H@("`@("`@
M("`@("`\(2TM(&YE8V5S<V%R>2!T;R!A<R!)1"!F<F]M('1H92!C;VYT96YT
M('1A8FQE('1O(&=E="!T:&4@8V]R<F5C="!H96%D:6YG(&5L96UE;G0@*'1H
M92!B=6=G>2!54DP@=7-E9"!A<R!)1"DM+3X*("`@("`@("`@("`@/'AS;#IA
M='1R:6)U=&4@;F%M93TB8V]N=&5N="UT86)L92UI9"(^"B`@("`@("`@("`@
M("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB)&ES0VAA<'1E<DAE861I;F<B/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&-U<G)E;G1#:&%P=&5R
M240B+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G1E>'0^;VYL>2!A(&AE861I;F<L(&)U="!N;W0@82!C
M:&%P=&5R/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IO
M=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@
M("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@/"$M+2!N;R!O
M9B!T:&4@=7-E9"!C:&EL9"P@;F5C97-S87)Y(&9O<B!Q=6EC:R!F:6YD:6YG
M(&]F(&-H87!T97)S(&]F(&YE>'0@9FEL92`@+2T^"B`@("`@("`@("`@(#QX
M<VPZ871T<FEB=71E(&YA;64](F-H:6QD+61O8W5M96YT+6YO(CX*("`@("`@
M("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2(D:7-.97=&:6QE(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1C=7)R96YT0VAI;&1.;R`K
M(#$B+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&-U<G)E;G1#:&EL9$YO
M(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@
M("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`\+WAS;#IA
M='1R:6)U=&4^"B`@("`@("`@("`@(#PA+2T@=&AE(%523"!O9B!T:&4@8VAI
M;&0@9&]C=6UE;G0@<V]U<F-E+"!C;VYT86EN:6YG('1H92!H96%D:6YG("TM
M/@H@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)F:6QE+75R;"(^
M"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&YE=T-H
M:6QD55),(B\^"B`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@
M("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB;W5T+69I;&4M=7)L(CX*("`@
M("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D;W5T1FEL9552
M3"(O/@H@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@
M(#QX<VPZ871T<FEB=71E(&YA;64](FQE=F5L(CX*("`@("`@("`@("`@("`@
M(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D:&5A9&EN9TQE=F5L(B\^"B`@("`@
M("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@/'AS;#IA='1R
M:6)U=&4@;F%M93TB=&ET;&4B/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU
M92UO9B!S96QE8W0](B1H96%D:6YG5&ET;&4B+SX*("`@("`@("`@("`@/"]X
M<VPZ871T<FEB=71E/@H@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE
M/2)E;F-O9&5D+71I=&QE(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M
M;V8@<V5L96-T/2(D8W5R<F5N=$-H:6QD2&5A9&EN9R]`96YC;V1E9"UT:71L
M92(O/@H@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@
M(#QX<VPZ871T<FEB=71E(&YA;64](F%B<V]L=71E+6-H87!T97(M;&5V96PB
M/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1A8G-O
M;'5T94-H87!T97),979E;"(O/@H@("`@("`@("`@("`\+WAS;#IA='1R:6)U
M=&4^"B`@("`@("`@/"]X<VPZ96QE;65N=#X*"@H@("`@("`@(#QX<VPZ8VAO
M;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&-H:6QD<F5N2&5A
M9&EN9W,O:&5A9&EN9RUC;W5N="`A/2`D8W5R<F5N=$AE861I;F=.;R(^"B`@
M("`@("`@("`@("`@("`\(2TM('!R;V-E9&4@87,@;&]N9R!T:&4@;&ES="!O
M9B!C:&EL9')E;B!I<VXG;G0@=V]R:V5D('1H<F]U9V@@+2T^"B`@("`@("`@
M("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB)&ES0VAA<'1E<DAE861I;F<B/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\(2TM(&=L;V)A;"!V87)I86)L97,@:&%V92!T;R!B92!S
M970L('-O('1H92!F;W(M96%C:"!L;V]P(&-A;B!A8V-E<W,@=&AE;2`M+3X*
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM
M879A:6QA8FQE*"=S>&=H96QP97(Z<V5T+6AE861I;F<M;F\G*2(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE
M8W0](G-X9VAE;'!E<CIS970M:&5A9&EN9RUN;R@D8W5R<F5N=$AE861I;F=.
M;R`K(#$I(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#II9B!T97-T/2(D:7-.97=&:6QE(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G-X9VAE;'!E
M<CIS970M8W5R<F5N="UC:&EL9"UN;R@D8W5R<F5N=$-H:6QD3F\@*R`Q*2(O
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB<WAG:&5L<&5R.G-E="UC=7)R96YT+6-H:6QD+75R
M;"AS=')I;F<H)&YE=T-H:6QD55),*2DB+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#II9CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G:F%V83IC
M;VTN<W5N+G-T87(N>'-L="YH96QP97(N4WAG0VAI;&14<F%N<V9O<FUE<BYS
M971(96%D:6YG3F\G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IV86QU92UO9B!S96QE8W0](FIA=F$Z8V]M+G-U;BYS=&%R+GAS
M;'0N:&5L<&5R+E-X9T-H:6QD5')A;G-F;W)M97(N<V5T2&5A9&EN9TYO*"1C
M=7)R96YT2&5A9&EN9TYO("L@,2DB+SX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.FEF('1E<W0](B1I<TYE=T9I;&4B/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB:F%V83IC;VTN<W5N+G-T87(N>'-L="YH96QP97(N4WAG0VAI;&14
M<F%N<V9O<FUE<BYS971#=7)R96YT0VAI;&1.;R@D8W5R<F5N=$-H:6QD3F\@
M*R`Q*2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB:F%V83IC;VTN<W5N+G-T87(N>'-L="YH
M96QP97(N4WAG0VAI;&14<F%N<V9O<FUE<BYS971#=7)R96YT0VAI;&15<FPH
M)&YE=T-H:6QD55),*2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.FEF/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#PA+2T@;F]T(&$@8VAA<'1E<B!H96%D:6YG+"!C86QL(&ET<V5L9B!U
M;G1I;"!A(&-H87!T97(@<F5F(&ES(&9O=6YD(&]R('1H92!E;F0@;V8@:&5A
M9&EN9W,@:7,@<F5A8VAE9"`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IC86QL+71E;7!L871E(&YA;64](G-E87)C:$AE861I;F=);D-H:6QD
M1&]C=6UE;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F-H87!T97)2969S(B`@("`@("`@('-E;&5C=#TB
M)&-H87!T97)2969S(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB8VAI;&1R96Y(96%D:6YG<R(@("`@<V5L
M96-T/2(D8VAI;&1R96Y(96%D:6YG<R(O/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-U<G)E;G1#:&%P=&5R
M4F5F3F\B('-E;&5C=#TB)&-U<G)E;G1#:&%P=&5R4F5F3F\B+SX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C
M=7)R96YT2&5A9&EN9TYO(B`@("!S96QE8W0](B1C=7)R96YT2&5A9&EN9TYO
M("L@,2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](F-U<G)E;G1#:&EL9%523"(@("`@('-E;&5C=#TB)&-U
M<G)E;G1#:&EL9%523"(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](F-U<G)E;G1#:&EL9$YO(B`@("`@('-E
M;&5C=#TB)&-U<G)E;G1#:&EL9$YO(B\^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.F]T
M:&5R=VES93X*("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB)&ES1&5B
M=6=-;V1E(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^06QL
M(&-H:6QD(&1O8W5M96YT<R!H879E(&)E96X@=V%L:V5D('1H<F]U9V@@=VET
M:&]U="!F:6YD:6YG('1H92!C:&%P=&5R(&YA;64A/"]X<VPZ;65S<V%G93X*
M("`@("`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^("`@("`@(&-H:6QD
M<F5N2&5A9&EN9W,O:&5A9&EN9RUC;W5N=#H@("`@/'AS;#IV86QU92UO9B!S
M96QE8W0](B1C:&EL9')E;DAE861I;F=S+VAE861I;F<M8V]U;G0B+SX\+WAS
M;#IM97-S86=E/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93X@
M("`@("`@8W5R<F5N=$AE861I;F=.;SH@("`@("`@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB)&-U<G)E;G1(96%D:6YG3F\B+SX\+WAS;#IM
M97-S86=E/@H@("`@("`@("`@("`@("`@/"]X<VPZ:68^"B`@("`@("`@("`@
M(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\
M+WAS;#IT96UP;&%T93X*"@H*"@H)/"$M+2!#:&%P=&5R<R!F<F]M('1H92!#
M;VYT96YT(%1A8FQE(&AA=F4@8W5R<F5N=&QY(&YO(&%N8VAO<B!T;R!C:&EL
M9"!D;V-U;65N=',@:6X@3T]O(%A-3"X*"0D@07,@<V]L=71I;VXL('=H96YE
M=F5R(&$@82!G;&]B86P@9&]C=6UE;G0@(&5V97)Y(&AE861E<B!O9B!T:&4@
M2%1-3"!O=71P=70@9V5T<R!G970G<R!A;B!A;F-H;W(@:6X@=&AE(%1H97)E
M9F]R92TM/@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)E;F-O9&4M<W1R:6YG
M(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F5N8V]D:6YG(B!S96QE8W0]
M(B=55$8M."<B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G1E>'14;T)E
M16YC;V1E9"(O/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@
M/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G=7)L96YC;V1E
M<CIE;F-O9&4G*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB=7)L96YC;V1E<CIE;F-O9&4H;F]R;6%L:7IE+7-P86-E*"1T97AT
M5&]"945N8V]D960I+"1E;F-O9&EN9RDB+SX*("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V
M86EL86)L92@G:F%V83IJ879A+FYE="Y54DQ%;F-O9&5R+F5N8V]D92<I(CX*
M("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)J879A.FIA
M=F$N;F5T+E523$5N8V]D97(N96YC;V1E*'-T<FEN9RAN;W)M86QI>F4M<W!A
M8V4H)'1E>'14;T)E16YC;V1E9"DI+'-T<FEN9R@D96YC;V1I;F<I*2(O/@H@
M("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@(#PO>'-L.F-H;V]S93X*
M("`@(#PO>'-L.G1E;7!L871E/@H*"@H*"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ("TM/@H@("`@/"$M+2`J*BH@(%1204Y31D]234%424].($]&($%,3"!#
M2$E,1"!$3T-5345.5%,@3T8@5$A%($=,3T)!3"!$3T-5345.5%,@0ED@55-)
M3D<@02!%6%1%4DY!3"!(14Q015(@0TQ!4U,@("HJ*B`M+3X*("`@(#PA+2T@
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H*"3PA+2T@82!N97<@96QE;65N="`G8V]N
M=&5N=%1A8FQE2&5A9&EN9W,G('=I;&P@8F4@861D960@=&\@=&AE(&AE;'!E
M<B!V87)I86)L92!T:&4@9FER<W0@=&EM92!A(&-H:6QD('=I;&P@8F4@=')A
M;G-F;W)M960@+2T^"B`@("`\>'-L.G1E;7!L871E(&YA;64](G1R86YS9F]R
M;2UG;&]B86PM9&]C=6UE;G0M86YD+6-H:6QD<F5N(CX*("`@("`@("`\>'-L
M.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*"@H@("`@("`@
M(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&-O
M;&QE8W1E9$=L;V)A;$1A=&$O8V]N=&5N="UT86)L92UH96%D:6YG<R(^"B`@
M("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB<W1A<G0M
M8VAI;&0M=')A;G-F;W)M871I;VXB/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B`@('-E
M;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@
M(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H)("`@("`@("`@("`@/"$M
M+2!4:&4@;F5C97-S87)Y(&%U>&EL:6%R>2!V87)I86)L92!H87-N)W0@8G5I
M;&0@>65T+@H)("`@("`@("`@("`@5&AI<R!V87)I86)L92!G;VYN82!S=&]R
M92!A;&P@:&5A9&5R<R`H=VET:"!C:&%P=&5R(&YU;6)E<G,I(&%N9"!T:&4@
M55),(&]F('1H96ER(&9I;&5S("TM/@H*("`@("`@("`@("`@("`@(#QX<VPZ
M8V%L;"UT96UP;&%T92!N86UE/2)#<F5A=&4M:&5L<&5R+79A<FEA8FQE<RUF
M;W(M0V]N=&5N="U486)L92(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B("`@<V5L96-T
M/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@/"]X
M<VPZ8V%L;"UT96UP;&%T93X*"B`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES
M93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*
M"@H*"3QX<VPZ=&5M<&QA=&4@;F%M93TB<W1A<G0M<V5L9BUA;F0M8VAI;&1R
M96XM=')A;G-F;W)M871I;VXB/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB
M8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@("`@("`\>'-L.FEF('1E<W0]
M(B1I<T1E8G5G36]D92(^"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T
M92!N86UE/2)D96)U9RUC;VYT96YT+71A8FQE+6AE861I;F=S+79A<FEA8FQE
M(CX*("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL
M96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A
M(B\^"B`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"@H@("`@("`@
M("`@("`\>'-L.FUE<W-A9V4^4&%R<VEN9R!T:&4@9VQO8F%L(&1O8W5M96YT
M+BXN/"]X<VPZ;65S<V%G93X*("`@("`@("`\+WAS;#II9CX*"B`@("`@("`@
M/'AS;#IA<'!L>2UT96UP;&%T97,^"B`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL
M96-T961';&]B86Q$871A(B\^"B`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA
M=&5S/@H*"B`@("`@("`@/'AS;#II9B!T97-T/2(D:7-$96)U9TUO9&4B/CQX
M<VPZ;65S<V%G93Y087)S:6YG('1H92!C:&EL9"!D;V-U;65N=',N+BX\+WAS
M;#IM97-S86=E/CPO>'-L.FEF/@H@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T
M92!N86UE/2)S=&%R="UC:&EL9"UT<F%N<V9O<FUA=&EO;B(^"B`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A
M(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@/"]X
M<VPZ8V%L;"UT96UP;&%T93X*"@D\+WAS;#IT96UP;&%T93X*"@H*"B`@("`\
M>'-L.G1E;7!L871E(&YA;64](G-T87)T+6-H:6QD+71R86YS9F]R;6%T:6]N
M(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A
M=&$B+SX*"B`@("`@("`@/'AS;#II9B!T97-T/2(D:7-$96)U9TUO9&4B/CQX
M<VPZ;65S<V%G93Y3=&%R=&EN9R!T:&4@8VAI;&0@=')A;G-F;W)M871I;VYS
M+BXN/"]X<VPZ;65S<V%G93X\+WAS;#II9CX*"B`@("`@("`@/"$M+2!!<R!T
M:&4@8VAI;&1S(&]F(&$@9VQO8F%L(&1O8W5M96YT("AW:71H('-U9F9I>"`N
M<WAG*2!D;R!N;W0@:VYO=R!A;GET:&EN9R!A8F]U="!T:&5I<B!G;&]B86P@
M<&%R96YT+`H@("`@("`@("`@("!T:&4@=')A;G-F;W)M871I;VX@;V8@9VQO
M8F%L(&1O8W5M96YT<R!C:&EL9')E;B!H879E('1O(&)E(&1O;F4@:6UP;&EZ
M:70N"B`@("`@("`@("`@($]T:&5R=VES92!T:&4@8VAA<'1E<B!N=6UB97(@
M;V8@=&AE(&-H:6QD<F5N('=I;&P@86QW87ES('-T87)T('=I=&@@>F5R;RP@
M87,@=&AE>2!D;R!N;W0@:VYO=R!A;GET:&EN9R!A8F]U="!T:&4*("`@("`@
M("`@("`@<')O8V5D:6YG(&-H87!T97)S+@H@("`@("`@("`@("!&=7)T:&5R
M;6]R92P@=&AE>2!D;VXG="!H879E(&%N>2!L:6YK<R!A8F]U="!P<F5C965D
M:6YG(&%N9"!F;VQL;W=I;F<@9&]C=6UE;G1S(&%N9"!N;R!L:6YK:6YG(&9O
M<B!U<V%B:6QI='D@<F5A<V]N<PH@("`@("`@("`@("!C;W5L9"!B92!D;VYE
M+B!4:&5R969O<F4@=&AE(&-H:6QD<F5N(&AA=F4@=&\@8F4@=')A;G-F;W)M
M960@9'5R:6YG('1H92!T<F%N<V9O<FUA=&EO;B!O9B!A(&=L;V)A;"`H<WAG
M*2!D;V-U;65N="`M+3X*"0D\>'-L.FEF('1E<W0](B1I<T1E8G5G36]D92(^
M"B`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](B1C;VQL96-T961';&]B86Q$871A+V-O;G1E;G0M=&%B
M;&4M:&5A9&EN9W,B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G
M93Y#;VYT96YT86)L92!D871A(&5X:7-T<R!A<R!G;&]B86P@9&%T82$\+WAS
M;#IM97-S86=E/@H@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ;65S<V%G93Y.;R!#;VYT96YT86)L92!G;&]B86P@9&%T82!E>&ES
M=',A/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R
M=VES93X*("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@(#PO>'-L
M.FEF/@H*("`@("`@("`\(2TM(&-U<G)E;G1L>2!T:&ES(&9U;F-T:6]N(&]N
M;'D@=V]R:W,@=VET:"!N;V1E+7-E=',@9G)O;2!85"`M+3X*("`@("`@("`\
M>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T
M:6]N+6%V86EL86)L92@G<WAG:&5L<&5R.G1R86YS9F]R;2UC:&EL9')E;B<I
M(CX*("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93X*("`@("`@("`@("`@
M("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<WAG:&5L<&5R.G1R86YS
M9F]R;2UC:&EL9')E;B@@)&-O;&QE8W1E9$=L;V)A;$1A=&$O8V]N=&5N="UT
M86)L92UH96%D:6YG<RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R
M:6YG*"1J87)E9%)O;W154DPI+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!S=')I;F<H)&%B<V]L=71E4V]U<F-E1&ER4F5F*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@<W1R:6YG*"1O<'1I;VYA;%523%-U9F9I>"DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('-T<FEN9R@D9'!I*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@<W1R:6YG*"1O=71P=714>7!E*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&ES1&5B=6=-;V1E*2(O/@H@("`@
M("`@("`@("`@("`@/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@
M("`@("`\>'-L.FUE<W-A9V4^2F%V82!M971H;V0@=')A;G-F;W)M0VAI;&1R
M96X@=&\@=')A;G-F;W)M(&%L;"!C:&EL9')E;B!O9B!A(&=L;V)A;"!D;V-U
M;65N="!C;W5L9"!N;W0@8F4@9F]U;F0N($)E('-U<F4@=&\@=7-E('1H92!8
M5"!P<F]C97-S;W(N/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@/"]X<VPZ
M;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E
M;7!L871E/@H*"@H*"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B`@0W)E871I;VX@;V8@:&5L
M<&5R('9A<FEA8FQE(&]F('1H92!H96%D:6YG<R!O9B!A;&P@8VAI;&1R96X@
M9&]C=6UE;G1S("`J*BH@+2T^"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H*("`@(#QX<VPZ=&5M<&QA=&4@;6%T
M8V@](B\J+V]F9FEC93IB;V1Y+W1E>'0Z<V5C=&EO;B(@;6]D93TB8W)E871I
M;VXM;V8M=F%R:6%B;&4B/@H@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N
M86UE/2)G971#:&EL9%)O;W1.;V1E(B\^"@H@("`@("`@(#PA+2T@869T97(@
M=&AE(&QA<W0@8VAI;&0@9&]C=6UE;G0@=&AE(&=L;V)A;"!D;V-U;65N="!W
M:6QL(&)E('!A<G-E9"`M+3X*("`@("`@("`\>'-L.FEF('1E<W0](G!O<VET
M:6]N*"D@/2!L87-T*"DB/@H@("`@("`@("`@("`\(2TM('-E87)C:"!T:&4@
M9VQO8F%L(&1O8W5M96YT(&%F=&5R(&%L;"!C:&EL9"!D;V-U;65N=',@:&%V
M92!B965N('-E87)C:&5D"@I/1$L@4$%40T@@3D\@24Y$15@@14Q%345.5"!7
M04Y4140@(2$@+2!N=6QL('!O:6YT97(@97AC97!T:6]N"B`@("`@("`@("`@
M(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)G9710<F5V:6]U<TAE861E<DYO
M(CX*("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)F:6QE
M55),(B`@("`@("`@("`@("`@("`@('-E;&5C=#TB)&-O;G1E;G1486)L9552
M3"(O/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%M
M;W5N=$]F0W5R<F5N=$AE861I;F<B("`@<V5L96-T/2)C;W5N="AF;VQL;W=I
M;F<M<VEB;&EN9SHZ=&5X=#IH*2(O/@H@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](FYO9&54;U-E87)C:$9O<DAE861I;F<B("`@<V5L
M96-T/2)F;VQL;W=I;F<M<VEB;&EN9SHZ=&5X=#IH(B\^"B`@("`@("`@("`@
M(#PO>'-L.F-A;&PM=&5M<&QA=&4^"BTM/@H@("`@("`@("`@(#PA+2T@9V5T
M('1H92!O=F5R86QL($YO(&]F($AE861E<G,@+2T^"B`@("`@("`@("`@/'AS
M;#IC86QL+71E;7!L871E(&YA;64](F=E=$%L;$AE861E<DYO(B\^"B`@("`@
M("`@/"]X<VPZ:68^"B`@("`\+WAS;#IT96UP;&%T93X*"@H@("`@/'AS;#IT
M96UP;&%T92!N86UE/2)G971#:&EL9%)O;W1.;V1E(CX*("`@("`@("`\>'-L
M.G9A<FEA8FQE(&YA;64](F9I;&554DPB("`@('-E;&5C=#TB=&5X=#IS96-T
M:6]N+7-O=7)C92]`>&QI;FLZ:')E9B(O/@H*("`@("`@("`\>'-L.F-H;V]S
M93X*("`@("`@("`@("`)/"$M+2!I9B!A8G-O;'5T92!54DP@;W(@86)S;VQU
M=&4@1$]3(%!!5$@@;W(@86)S;VQU=&4@56YI>"!P871H("TM/@H)"0D\>'-L
M.G=H96X@=&5S=#TB8V]N=&%I;G,H)&9I;&554DPL)R\O)RD@;W(@*'-U8G-T
M<FEN9R@D9FEL95523"PR+#$I(#T@)SHG*2!O<B!S=&%R=',M=VET:"@D9FEL
M95523"P@)R\G*2(^"B`@("`)"0D\>'-L.G9A<FEA8FQE(&YA;64](F-H:6QD
M4F]O=$YO9&4B('-E;&5C=#TB9&]C=6UE;G0H)&9I;&554DPI(B\^"B`@("`@
M("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB9V5T4')E=FEO
M=7-(96%D97).;R(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](F9I;&554DPB("`@("`@("`@("`@("`@('-E;&5C=#TB)&9I
M;&554DPB+SX*("`@("`@("`@("`@("`@(`D\(2TM($Y/(&%B<V]L=71E('-O
M=7)C92!P871H('=I;&P@8F4@861D960@87,@<')E9FEX("TM/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;6]U;G1/9D-U
M<G)E;G1(96%D:6YG(B!S96QE8W0](F-O=6YT*"1C:&EL9%)O;W1.;V1E+RHO
M;V9F:6-E.F)O9'DO9&5S8V5N9&%N=#HZ=&5X=#IH*2(O/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)N;V1E5&]396%R8VA&
M;W)(96%D:6YG(B!S96QE8W0](B1C:&EL9%)O;W1.;V1E+RHO;V9F:6-E.F)O
M9'DO9&5S8V5N9&%N=#HZ=&5X=#IH(B\^"B`@("`@("`@("`@("`@("`\+WAS
M;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@
M("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@(`D)"3QX<VPZ=F%R:6%B;&4@
M;F%M93TB8VAI;&12;V]T3F]D92(@<V5L96-T/2)D;V-U;65N="AC;VYC870H
M)&%B<V]L=71E4V]U<F-E1&ER4F5F+"<O)RPD9FEL95523"DI(B\^"B`@("`@
M("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB9V5T4')E=FEO
M=7-(96%D97).;R(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](F9I;&554DPB("`@("`@("`@("`@("`@('-E;&5C=#TB)&9I
M;&554DPB+SX*("`@("`@("`@("`@("`@(`D\(2TM('1H92!A8G-O;'5T92!S
M;W5R8V4@<&%T:"!W:6QL(&)E(&%D9&5D(&%S('!R969I>"`M+3X*("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB86UO=6YT3V9#
M=7)R96YT2&5A9&EN9R(@<V5L96-T/2)C;W5N="@D8VAI;&12;V]T3F]D92\J
M+V]F9FEC93IB;V1Y+V1E<V-E;F1A;G0Z.G1E>'0Z:"DB+SX*("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB;F]D951O4V5A<F-H
M1F]R2&5A9&EN9R(@<V5L96-T/2(D8VAI;&12;V]T3F]D92\J+V]F9FEC93IB
M;V1Y+V1E<V-E;F1A;G0Z.G1E>'0Z:"(O/@H@("`@("`@("`@("`@("`@/"]X
M<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E
M/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*
M"B`@("`\>'-L.G1E;7!L871E(&YA;64](F=E=%!R979I;W5S2&5A9&5R3F\B
M/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB9FEL95523"(O/@H@("`@("`@
M(#QX<VPZ<&%R86T@;F%M93TB;F]D951O4V5A<F-H1F]R2&5A9&EN9R(O/@H@
M("`@("`@(#QX<VPZ<&%R86T@;F%M93TB86UO=6YT3V9#=7)R96YT2&5A9&EN
M9R(O/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW
M:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G<WAG:&5L<&5R.F=E="UP
M<F5V:6]U<RUC:&EL9"UD;V-U;65N=',M:&5A9&EN9RUC;W5N="<I(CX*("`@
M("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A9&1(96%D
M:6YG26YF;R(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](FYO9&54;U-E87)C:$9O<DAE861I;F<B("`@<V5L96-T/2(D;F]D
M951O4V5A<F-H1F]R2&5A9&EN9R(O/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)F:6QE55),(B`@("`@("`@("`@("`@("`@
M('-E;&5C=#TB)&9I;&554DPB+SX*("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB<')E=FEO=7-(96%D97(B("`@("`@("`@("!S
M96QE8W0](G-X9VAE;'!E<CIG970M<')E=FEO=7,M8VAI;&0M9&]C=6UE;G1S
M+6AE861I;F<M8V]U;G0H)&%M;W5N=$]F0W5R<F5N=$AE861I;F<I(B\^"B`@
M("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@
M("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N
M8W1I;VXM879A:6QA8FQE*"=J879A.F-O;2YS=6XN<W1A<BYX<VQT+FAE;'!E
M<BY3>&=#:&EL9%1R86YS9F]R;65R+F=E=%!R979I;W5S0VAI;&1$;V-U;65N
M='-(96%D:6YG0V]U;G0G*2(^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM
M=&5M<&QA=&4@;F%M93TB861D2&5A9&EN9TEN9F\B/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)N;V1E5&]396%R8VA&;W)(
M96%D:6YG(B`@('-E;&5C=#TB)&YO9&54;U-E87)C:$9O<DAE861I;F<B+SX*
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB9FEL
M95523"(@("`@("`@("`@("`@("`@("!S96QE8W0](B1F:6QE55),(B\^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G!R979I
M;W5S2&5A9&5R(B`@("`@("`@("`@<V5L96-T/2)J879A.F-O;2YS=6XN<W1A
M<BYX<VQT+FAE;'!E<BY3>&=#:&EL9%1R86YS9F]R;65R+F=E=%!R979I;W5S
M0VAI;&1$;V-U;65N='-(96%D:6YG0V]U;G0H)&%M;W5N=$]F0W5R<F5N=$AE
M861I;F<I(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E
M/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@(#PO>'-L.F-H;V]S
M93X*"B`@("`\+WAS;#IT96UP;&%T93X*"@H@("`@/'AS;#IT96UP;&%T92!N
M86UE/2)A9&1(96%D:6YG26YF;R(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE
M/2)F:6QE55),(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)P<F5V:6]U
M<TAE861E<B(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB;F]D951O4V5A
M<F-H1F]R2&5A9&EN9R(O/@H*("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64]
M(G!R979I;W5S2&5A9&5R,B(@<V5L96-T/2)N=6UB97(H)'!R979I;W5S2&5A
M9&5R*2(O/@H@("`@("`@(#QX<VPZ9F]R+65A8V@@<V5L96-T/2(D;F]D951O
M4V5A<F-H1F]R2&5A9&EN9R(^"@H@("`@("`@("`@("`\>'-L.G9A<FEA8FQE
M(&YA;64](G1I=&QE(B!S96QE8W0](FYO<FUA;&EZ92US<&%C92@N*2(O/@H*
M("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)E;F-O9&5D5&ET;&4B
M/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F5N
M8V]D92US=')I;F<B/@H@("`@("`@("`@("`@("`@("`@(#PA+2T@=&AE('-P
M86-E(&AA<R!T;R!B92!N;W)M86QI>F5D+`H@("`@("`@("`@("`@("`@("`@
M("`@("!O=&AE<G=I<V4@86X@:6QL96=A;"!A<F=U;65N="!E>&-E<'1I;VX@
M=VEL;"!B92!T:')O=VX@9F]R(%A4+2T^"B`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)T97AT5&]"945N8V]D960B('-E;&5C
M=#TB)'1I=&QE(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L
M871E/@H@("`@("`@("`@("`\+WAS;#IV87)I86)L93X*"B`@("`@("`@("`@
M(#QX<VPZ96QE;65N="!N86UE/2)H96%D:6YG(CX*("`@("`@("`@("`@("`@
M(#PA+2T@;V1D(&)U="`G9&5S8V5N9&%N=#IT97AT*"DG(&1I9&XG="!W;W)K
M+"!B=70@)RXG+"!T;R!G970@86QL('1E>'0@;F]D97,@;V8@=&AE(&AE861E
M<B`M+3X*("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](G1I
M=&QE(CX\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'1I=&QE(B\^/"]X<VPZ871T
M<FEB=71E/@H@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB
M96YC;V1E9"UT:71L92(^/'AS;#IV86QU92UO9B!S96QE8W0](B1E;F-O9&5D
M5&ET;&4B+SX\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@("`\>'-L
M.F%T=')I8G5T92!N86UE/2)L979E;"(^/'AS;#IV86QU92UO9B!S96QE8W0]
M(D!T97AT.FQE=F5L(B\^/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@
M("`@/'AS;#IA='1R:6)U=&4@;F%M93TB9FEL92UU<FPB/CQX<VPZ=F%L=64M
M;V8@<V5L96-T/2(D9FEL95523"(O/CPO>'-L.F%T=')I8G5T93X*("`@("`@
M("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](FAE861E<BUN;R(^/'AS
M;#IV86QU92UO9B!S96QE8W0](G!O<VET:6]N*"D@*R`D<')E=FEO=7-(96%D
M97(R(B\^/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`\+WAS;#IE;&5M
M96YT/@H@("`@("`@(#PO>'-L.F9O<BUE86-H/@H*("`@(#PO>'-L.G1E;7!L
M871E/@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64](F=E=$%L;$AE861E<DYO
M(CX*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H)W-X9VAE;'!E<CIG970M86QL
M+6-H:6QD+61O8W5M96YT<RUH96%D:6YG+6-O=6YT)RDB/@H@("`@("`@("`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%D9$%L;$AE861E<DYO
M16QE;65N="(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](F%L;$AE861E<B(@("!S96QE8W0](G-X9VAE;'!E<CIG970M86QL
M+6-H:6QD+61O8W5M96YT<RUH96%D:6YG+6-O=6YT*"DB+SX*("`@("`@("`@
M("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L
M.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA
M=F%I;&%B;&4H)VIA=F$Z8V]M+G-U;BYS=&%R+GAS;'0N:&5L<&5R+E-X9T-H
M:6QD5')A;G-F;W)M97(N9V5T06QL0VAI;&1$;V-U;65N='-(96%D:6YG0V]U
M;G0G*2(^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M
M93TB861D06QL2&5A9&5R3F]%;&5M96YT(CX*("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB86QL2&5A9&5R(B`@('-E;&5C=#TB
M:F%V83IC;VTN<W5N+G-T87(N>'-L="YH96QP97(N4WAG0VAI;&14<F%N<V9O
M<FUE<BYG971!;&Q#:&EL9$1O8W5M96YT<TAE861I;F=#;W5N="@I(B\^"B`@
M("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@
M("`\+WAS;#IW:&5N/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L
M.G1E;7!L871E/@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB861D06QL2&5A
M9&5R3F]%;&5M96YT(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F%L;$AE
M861E<B(O/@H*("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB:&5A9&EN9RUC
M;W5N="(^"B`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D86QL
M2&5A9&5R(B\^"B`@("`@("`@/"]X<VPZ96QE;65N=#X*"B`@("`\+WAS;#IT
M96UP;&%T93X*"@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H@("`@/"$M
M+2`J*BH@($-R96%T:6]N(&]F(&$@;&EN92!O9B!L:6YK<R!A="!T:&4@8F5G
M:6YN:6YG(&%N9"!E;F0@;V8@82!C:&EL9"!D;V-U;65N="!T;R!E;FAA;F-E
M('5S86)I;&ET>2`@*BHJ("TM/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM
M/@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB861D+6-H:6QD+61O8W5M96YT
M+75S86)I;&ET>2UL:6YK<R(^"B`@("`@("`@/'AS;#IE;&5M96YT(&YA;64]
M(F-E;G1E<B(^"B`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)S;6%L
M;"(^"B`@("`@("`@("`@("`@("`\>'-L.G1E>'0^6R`\+WAS;#IT97AT/@H*
M"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F=L;V)A;$1O
M8W5M96YT1&ER(B!S96QE8W0](G-X9VAE;'!E<CIG970M9VQO8F%L+61O8W5M
M96YT+61I<B@I(B\^"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA
M;64](F-U<G)E;G1#:&EL9$YO(B!S96QE8W0](FYU;6)E<B@D8V]N=&5N=%1A
M8FQE2&5A9&EN9W,O:&5A9&EN9ULD9VQO8F%L1&]C=6UE;G129694;T-U<G)E
M;G1&:6QE(#T@0&9I;&4M=7)L72]`8VAI;&0M9&]C=6UE;G0M;F\I(B\^"B`@
M("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F5A<FQI97)$;V-5
M4DPB('-E;&5C=#TB)&-O;G1E;G1486)L94AE861I;F=S+VAE861I;F=;*"1C
M=7)R96YT0VAI;&1.;R`M(#$I(#T@0&-H:6QD+61O8W5M96YT+6YO72]`;W5T
M+69I;&4M=7)L(B\^"CPA+2T*/'AS;#IM97-S86=E/F9R;VTZ(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2(D9VQO8F%L1&]C=6UE;G129694;T-U<G)E;G1&:6QE
M(B\^/"]X<VPZ;65S<V%G93X*/'AS;#IM97-S86=E/G1O.B`\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB)&5A<FQI97)$;V-54DPB+SX\+WAS;#IM97-S86=E/@H\
M>'-L.FUE<W-A9V4^27,Z(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)G970M
M<F5L871I=F4M9FEL92UR968B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)S;W5R8V5&:6QE4F5F(B!S96QE8W0](B1G;&]B
M86Q$;V-U;65N=%)E9E1O0W5R<F5N=$9I;&4B+SX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=&%R9V5T1FEL95)E9B(@<V5L
M96-T/2(D96%R;&EE<D1O8U523"(O/@H@("`@("`@("`@("`@("`@(#PO>'-L
M.F-A;&PM=&5M<&QA=&4^"CPO>'-L.FUE<W-A9V4^+2T^"@H*("`@("`@("`@
M("`@("`@(#QX<VPZ:68@=&5S=#TB)&5A<FQI97)$;V-54DPB/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)A(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB:')E9B(^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\(2TM('=H96X@=&AE(&QI;FMS
M('-T87)T<R!W:71H(&$@)R,G(&ET)W,@82!L:6YK('1O('1H92!#;VYT96YT
M(%1A8FQE+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-H
M;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB<W1A<G1S+7=I=&@H)&5A<FQI97)$;V-54DPL("<C)RDB/@H*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL
M+71E;7!L871E(&YA;64](F=E="UR96QA=&EV92UF:6QE+7)E9B(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB<V]U<F-E1FEL95)E9B(@<V5L96-T/2(D9VQO8F%L1&]C
M=6UE;G129694;T-U<G)E;G1&:6QE(B\^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=&%R
M9V5T1FEL95)E9B(@<V5L96-T/2(N(B\^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"CPA+2T@("`@
M("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC870H)&-O;G1E;G1486)L
M95523"P@)&5A<FQI97)$;V-54DPI(B\^+2T^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE
M/2)G970M<F5L871I=F4M9FEL92UR968B/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-O
M=7)C949I;&52968B('-E;&5C=#TB)&=L;V)A;$1O8W5M96YT4F5F5&]#=7)R
M96YT1FEL92(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G1A<F=E=$9I;&52968B('-E
M;&5C=#TB)&5A<FQI97)$;V-54DPB+SX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*/"$M+0H*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](F-O;F-A="@D9VQO8F%L1&]C=6UE;G1$:7(L("1E87)L:65R
M1&]C55),*2(O/BTM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M871T<FEB=71E/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^
M4')E=FEO=7,@9&]C=6UE;G0\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F5L96UE;G0^"@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=&5X=#X@?"`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@/"]X<VPZ:68^
M"@H@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](F$B/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](FAR968B/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\(2TM('=H96X@9VQO8F%L1&]C=6UE
M;G129694;T-U<G)E;G1&:6QE(&ES('5N<V5T('1H92!C=7)R96YT(&9I;&4@
M:7,@=&AE($-O;G1E;G0@5&%B;&4M+3X*("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=H96X@=&5S=#TB)&=L;V)A;$1O8W5M96YT4F5F5&]#=7)R96YT1FEL
M92(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV87)I
M86)L92!N86UE/2)C;VYT96YT5&%B;&5$:7(B/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB
M9V5T+6YA;64M;V8M=&%B;&4M;V8M8V]N=&5N="UD;V-U;65N="(O/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G9A<FEA8FQE/@H*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M
M<&QA=&4@;F%M93TB9V5T+7)E;&%T:79E+69I;&4M<F5F(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](G-O=7)C949I;&52968B('-E;&5C=#TB)&=L;V)A;$1O8W5M96YT4F5F
M5&]#=7)R96YT1FEL92(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=&%R9V5T1FEL95)E9B(@
M<V5L96-T/2(D8V]N=&5N=%1A8FQE1&ER(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^(SPO>'-L.G1E>'0^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*"CPA+2T@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D8V]N=&5N=%1A
M8FQE55),(B\^+2T^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB
M=71E/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#Y#;VYT96YT(%1A
M8FQE/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^
M"@H*("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB;F5X=$1O
M8U523"(@<V5L96-T/2(D8V]N=&5N=%1A8FQE2&5A9&EN9W,O:&5A9&EN9ULH
M)&-U<G)E;G1#:&EL9$YO("L@,2D@/2!`8VAI;&0M9&]C=6UE;G0M;F]=+T!O
M=70M9FEL92UU<FPB+SX*("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB
M)&YE>'1$;V-54DPB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#X@
M?"`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N
M="!N86UE/2)A(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R
M:6)U=&4@;F%M93TB:')E9B(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\(2TM('=H96X@=&AE(&QI;FMS('-T87)T<R!W:71H(&$@)R,G(&ET)W,@
M82!L:6YK('1O('1H92!#;VYT96YT(%1A8FQE+2T^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB<W1A<G1S+7=I=&@H)&YE
M>'1$;V-54DPL("<C)RDB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB9V5T+7)E;&%T:79E
M+69I;&4M<F5F(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S;W5R8V5&:6QE4F5F(B!S
M96QE8W0](B1G;&]B86Q$;V-U;65N=%)E9E1O0W5R<F5N=$9I;&4B+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)T87)G971&:6QE4F5F(B!S96QE8W0](BXB+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT
M96UP;&%T93X*/"$M+2`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IV86QU92UO9B!S96QE8W0](F-O;F-A="@D8V]N=&5N=%1A8FQE55),
M+"`D;F5X=$1O8U523"DB+SXM+3X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB9V5T+7)E
M;&%T:79E+69I;&4M<F5F(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S;W5R8V5&:6QE
M4F5F(B!S96QE8W0](B1G;&]B86Q$;V-U;65N=%)E9E1O0W5R<F5N=$9I;&4B
M+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)T87)G971&:6QE4F5F(B!S96QE8W0](B1N
M97AT1&]C55),(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"CPA+2T@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T
M*"1G;&]B86Q$;V-U;65N=$1I<BP@)&YE>'1$;V-54DPI(B\^+2T^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#Y.97AT(&1O8W5M96YT/"]X<VPZ
M=&5X=#X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@
M("`@("`@("`@("`@/"]X<VPZ:68^"B`@("`@("`@("`@("`@("`\>'-L.G1E
M>'0^(%T\+WAS;#IT97AT/@H@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@
M("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`\+WAS;#IT96UP;&%T93X*"@H@
M("`@/'AS;#IT96UP;&%T92!N86UE/2)G970M<F5L871I=F4M9FEL92UR968B
M/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB<V]U<F-E1FEL95)E9B(O/@H@
M("`@("`@(#QX<VPZ<&%R86T@;F%M93TB=&%R9V5T1FEL95)E9B(O/@H*("`@
M("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(F9U;F-T:6]N+6%V86EL86)L92@G<WAG:&5L<&5R.F=E="UR96QA=&EV92UF
M:6QE+7)E9B<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L
M96-T/2)S>&=H96QP97(Z9V5T+7)E;&%T:79E+69I;&4M<F5F*'-T<FEN9R@D
M<V]U<F-E1FEL95)E9BDL('-T<FEN9R@D=&%R9V5T1FEL95)E9BDI(B\^"B`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H)VIA=F$Z8V]M+G-U;BYS=&%R+GAS
M;'0N:&5L<&5R+E-X9T-H:6QD5')A;G-F;W)M97(N9V5T4F5L871I=F5&:6QE
M4F5F)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0]
M(FIA=F$Z8V]M+G-U;BYS=&%R+GAS;'0N:&5L<&5R+E-X9T-H:6QD5')A;G-F
M;W)M97(N9V5T4F5L871I=F5&:6QE4F5F*'-T<FEN9R@D<V]U<F-E1FEL95)E
M9BDL('-T<FEN9R@D=&%R9V5T1FEL95)E9BDI(B\^"B`@("`@("`@("`@(#PO
M>'-L.G=H96X^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H*("`@(#PO>'-L.G1E
M;7!L871E/@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64](F=E="UN86UE+6]F
M+71A8FQE+6]F+6-O;G1E;G0M9&]C=6UE;G0B/@H*("`@("`@("`\>'-L.F-H
M;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V
M86EL86)L92@G<WAG:&5L<&5R.F=E="UN86UE+6]F+71A8FQE+6]F+6-O;G1E
M;G0M9&]C=6UE;G0G*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB<WAG:&5L<&5R.F=E="UN86UE+6]F+71A8FQE+6]F+6-O;G1E
M;G0M9&]C=6UE;G0H*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=J
M879A.F-O;2YS=6XN<W1A<BYX<VQT+FAE;'!E<BY3>&=#:&EL9%1R86YS9F]R
M;65R+F=E=$YA;65/9E1A8FQE3V9#;VYT96YT1&]C=6UE;G0G*2(^"B`@("`@
M("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB:F%V83IC;VTN<W5N
M+G-T87(N>'-L="YH96QP97(N4WAG0VAI;&14<F%N<V9O<FUE<BYG971.86UE
M3V9486)L94]F0V]N=&5N=$1O8W5M96YT*"DB+SX*("`@("`@("`@("`@/"]X
M<VPZ=VAE;CX*("`@("`@("`\+WAS;#IC:&]O<V4^"@H@("`@/"]X<VPZ=&5M
M<&QA=&4^"@H*"3QX<VPZ=&5M<&QA=&4@;F%M93TB9&5B=6<M8V]N=&5N="UT
M86)L92UH96%D:6YG<RUV87)I86)L92(^"B`@("`@("`@/'AS;#IP87)A;2!N
M86UE/2)C;VQL96-T961';&]B86Q$871A(B\^"@H@("`@("`@(#QX<VPZ;65S
M<V%G93X\>'-L.G1E>'0^*BHJ*B!42$4@2$5!1$E.1R!605))04),12`J*BHJ
M(#PO>'-L.G1E>'0^/"]X<VPZ;65S<V%G93X*("`@("`@("`\>'-L.FUE<W-A
M9V4^8V]N=&5N="UT86)L92UU<FPZ(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C
M;VQL96-T961';&]B86Q$871A+V-O;G1E;G0M=&%B;&4M:&5A9&EN9W,O8V]N
M=&5N="UT86)L92UU<FPB+SX\+WAS;#IM97-S86=E/@H*("`@("`@("`\>'-L
M.F9O<BUE86-H('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$O8V]N=&5N
M="UT86)L92UH96%D:6YG<R]H96%D:6YG(CX*("`@("`@("`@("`@/'AS;#IM
M97-S86=E/CQX<VPZ=&5X=#XJ*BHJ(&YE=R!H96%D:6YG.B`@("`@("`@/"]X
M<VPZ=&5X=#X\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`\>'-L.FUE<W-A
M9V4^8V]N=&5N="UT86)L92UI9#H@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB0&-O;G1E;G0M=&%B;&4M:60B+SX\+WAS;#IM97-S86=E/@H@("`@("`@
M("`@("`\>'-L.FUE<W-A9V4^8VAI;&0M9&]C=6UE;G0M;F\Z("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB0&-H:6QD+61O8W5M96YT+6YO(B\^/"]X<VPZ
M;65S<V%G93X*("`@("`@("`@("`@/'AS;#IM97-S86=E/F9I;&4M=7)L.B`@
M("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](D!F:6QE+75R;"(O
M/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@(#QX<VPZ;65S<V%G93YO=70M
M9FEL92UU<FPZ("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)`;W5T
M+69I;&4M=7)L(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@/'AS;#IM
M97-S86=E/FQE=F5L.B`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S
M96QE8W0](D!L979E;"(O/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@(#QX
M<VPZ;65S<V%G93YT:71L93H@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M
M;V8@<V5L96-T/2)`=&ET;&4B+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@
M("`\>'-L.FUE<W-A9V4^96YC;V1E9"UT:71L93H@("`@("`@("`\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB0&5N8V]D960M=&ET;&4B+SX\+WAS;#IM97-S86=E
M/@H@("`@("`@("`@("`\>'-L.FUE<W-A9V4^86)S;VQU=&4M8VAA<'1E<BUL
M979E;#H\>'-L.G9A;'5E+6]F('-E;&5C=#TB0&%B<V]L=71E+6-H87!T97(M
M;&5V96PB+SX\+WAS;#IM97-S86=E/@H@("`@("`@(#PO>'-L.F9O<BUE86-H
M/@H*"3PO>'-L.G1E;7!L871E/@H*"@D\(2TM(%1O(&UA:V4@=&AE(&AE861I
M;F=S('5N:7%U92P@=&AE(&%B<V]L=71E(&AE861I;F<@:7,@861D960@=&\@
M=&AE;0H)("`@("!%+F<N(%1H92!L979E;"`Q+C(N,RXT+B!W;W5L9"!R97-U
M;'0@:6YT;R!A(#$K,BLS*S0@<W1R:6YG("TM/@H@("`@/'AS;#IT96UP;&%T
M92!N86UE/2)C86QC+6-H87!T97(M;G5M8F5R<R(^"B`@("`@("`@/'AS;#IP
M87)A;2!N86UE/2)L979E;"(O/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G
M<WAG:&5L<&5R.F-A;&,M8VAA<'1E<BUN=6UB97)S)RDB/@H@("`@("`@("`@
M("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G-X9VAE;'!E<CIC86QC+6-H
M87!T97(M;G5M8F5R<R@D;&5V96PI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H
M96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I
M;&%B;&4H)VIA=F$Z8V]M+G-U;BYS=&%R+GAS;'0N:&5L<&5R+E-X9T-H:6QD
M5')A;G-F;W)M97(N8V%L8T-H87!T97).=6UB97)S)RDB/@H@("`@("`@("`@
M("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](FIA=F$Z8V]M+G-U;BYS=&%R
M+GAS;'0N:&5L<&5R+E-X9T-H:6QD5')A;G-F;W)M97(N8V%L8T-H87!T97).
M=6UB97)S*"1L979E;"DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@
M("`@("`\+WAS;#IC:&]O<V4^"@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"@H@
M("`@/'AS;#IT96UP;&%T92!M871C:#TB=&5X=#IP(B!M;V1E/2)C;VYT96YT
M+71A8FQE(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L
M;V)A;$1A=&$B+SX*"B`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)A;&Q4
M86)3=&]P4W1Y;&5S(B!S96QE8W0](B1O9F9I8V4Z875T;VUA=&EC+7-T>6QE
M<R]S='EL93IS='EL95M`<W1Y;&4Z;F%M92`](&-U<G)E;G0H*2]`=&5X=#IS
M='EL92UN86UE72]S='EL93IP<F]P97)T:65S+W-T>6QE.G1A8BUS=&]P<R(O
M/@H*("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB=&%B;&4B/@H@("`@("`@
M("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)B;W)D97(B/C`\+WAS;#IA='1R
M:6)U=&4^"B`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](F-L87-S
M(CX\>'-L.G9A;'5E+6]F('-E;&5C=#TB0'1E>'0Z<W1Y;&4M;F%M92(O/CPO
M>'-L.F%T=')I8G5T93X*/"$M+0H\>'-L.FUE<W-A9V4^*BHJ*BHJ*BHJ/"]X
M<VPZ;65S<V%G93X*/'AS;#IM97-S86=E/E-T>6QE;F%M93H\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB0'1E>'0Z<W1Y;&4M;F%M92(O/CPO>'-L.FUE<W-A9V4^
M"CQX<VPZ;65S<V%G93YP;W-I=&EO;CH@/'AS;#IV86QU92UO9B!S96QE8W0]
M(F-O=6YT*"1A;&Q486)3=&]P4W1Y;&5S+W-T>6QE.G1A8BUS=&]P*2(O/CPO
M>'-L.FUE<W-A9V4^"BTM/@H*("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA
M;64](F-O;&=R;W5P(CX*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP
M;&%T92!N86UE/2)C<F5A=&4M8V]L+65L96UE;G0B/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)L87-T3F]D95!O<VET:6]N
M(B!S96QE8W0](F-O=6YT*"1A;&Q486)3=&]P4W1Y;&5S+W-T>6QE.G1A8BUS
M=&]P*2(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)A;&Q486)3=&]P4W1Y;&5S(B!S96QE8W0](B1A;&Q486)3=&]P4W1Y
M;&5S(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@
M("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H*"B`@("`@("`@("`@(#PA+2T@
M86QL(&5L96UE;G1S(&)E9F]R92!T:&4@9FER<W0@=&%B4W1O<"`M+3X*("`@
M("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)T97-T3F\M4E1&(CX*("`@
M("`@("`@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S('-E;&5C=#TB;F]D
M92@I(B!M;V1E/2)C96QL+6-O;G1E;G0B+SX*("`@("`@("`@("`@/"]X<VPZ
M=F%R:6%B;&4^"@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@
M/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G>'0Z;F]D92US
M970G*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G1A
M8DYO9&50;W-I=&EO;G,B('-E;&5C=#TB>'0Z;F]D92US970H)'1E<W1.;RU2
M5$8I(B\^"@D)"3QX<VPZ96QE;65N="!N86UE/2)T<B(^"B`@("`@("`@("`@
M("`@(`D@/'AS;#IC86QL+71E;7!L871E(&YA;64](F-R96%T92UT9"UE;&5M
M96YT<R(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](FQA<W1.;V1E4&]S:71I;VXB('-E;&5C=#TB8V]U;G0H)&%L;%1A8E-T
M;W!3='EL97,O<W1Y;&4Z=&%B+7-T;W`I(B\^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G!O<VET:6]N(B`@("`@("`@('-E
M;&5C=#TB,2(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)A;&Q486)3=&]P4W1Y;&5S(B!S96QE8W0](B1A;&Q486)3=&]P
M4W1Y;&5S(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](G1A8DYO9&50;W-I=&EO;G,B('-E;&5C=#TB)'1A8DYO9&50;W-I
M=&EO;G,B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D
M1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP
M;&%T93X*("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*"B`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC
M=&EO;BUA=F%I;&%B;&4H)WAA;&%N.FYO9&5S970G*2(^"B`@("`@("`@("`@
M("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G1A8DYO9&50;W-I=&EO;G,B('-E
M;&5C=#TB>&%L86XZ;F]D97-E="@D=&5S=$YO+5)41BDB+SX*"0D)/'AS;#IE
M;&5M96YT(&YA;64](G1R(CX*("`@("`@("`@("`@("`@"2`\>'-L.F-A;&PM
M=&5M<&QA=&4@;F%M93TB8W)E871E+71D+65L96UE;G1S(CX*("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB;&%S=$YO9&50;W-I
M=&EO;B(@<V5L96-T/2)C;W5N="@D86QL5&%B4W1O<%-T>6QE<R]S='EL93IT
M86(M<W1O<"DB+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB<&]S:71I;VXB("`@("`@("`@<V5L96-T/2(Q(B\^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%L;%1A8E-T
M;W!3='EL97,B('-E;&5C=#TB)&%L;%1A8E-T;W!3='EL97,B+SX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=&%B3F]D95!O
M<VET:6]N<R(@<V5L96-T/2(D=&%B3F]D95!O<VET:6]N<R(O/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961'
M;&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@
M("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@
M("`\+WAS;#IE;&5M96YT/@H*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@
M("`@("`\+WAS;#IC:&]O<V4^"@H@("`@("`@("`@(#PA+2T@/'AS;#IV87)I
M86)L92!N86UE/2)T86).;V1E4&]S:71I;VYS(B!S96QE8W0](GAT.FYO9&4M
M<V5T*"1T97-T3F\M4E1&*2(O/@H*("`@("`@("`@("`@/'AS;#IE;&5M96YT
M(&YA;64](G1R(CX*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T
M92!N86UE/2)C<F5A=&4M=&0M96QE;65N=',B/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)L87-T3F]D95!O<VET:6]N(B!S
M96QE8W0](F-O=6YT*"1A;&Q486)3=&]P4W1Y;&5S+W-T>6QE.G1A8BUS=&]P
M*2(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)P;W-I=&EO;B(@("`@("`@("!S96QE8W0](C$B+SX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB86QL5&%B4W1O<%-T>6QE
M<R(@<V5L96-T/2(D86QL5&%B4W1O<%-T>6QE<R(O/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)T86).;V1E4&]S:71I;VYS
M(B!S96QE8W0](B1T86).;V1E4&]S:71I;VYS(B\^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A
M=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@
M("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L
M.F5L96UE;G0^+2T^"@H*("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@/"]X
M<VPZ=&5M<&QA=&4^"@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB8W)E871E
M+6-O;"UE;&5M96YT(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](FQA<W1.
M;V1E4&]S:71I;VXB+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F%L;%1A
M8E-T;W!3='EL97,B+SX*"B`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0]
M(B1A;&Q486)3=&]P4W1Y;&5S+W-T>6QE.G1A8BUS=&]P(CX*("`@("`@("`@
M("`@/'AS;#IE;&5M96YT(&YA;64](F-O;"(^"B`@("`@("`@("`@("`@("`\
M>'-L.F%T=')I8G5T92!N86UE/2)S='EL92(^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IT97AT/G=I9'1H.B`\+WAS;#IT97AT/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)G<F%P+6-E;&PM=VED
M=&@B/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB<&]S:71I;VXB("`@("`@("`@<V5L96-T/2)P;W-I=&EO;B@I(B\^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)A;&Q486)3=&]P4W1Y;&5S(B!S96QE8W0](B1A;&Q486)3=&]P4W1Y;&5S
M(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*
M("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@
M/"]X<VPZ96QE;65N=#X*("`@("`@("`\+WAS;#IF;W(M96%C:#X*"B`@("`\
M+WAS;#IT96UP;&%T93X*/"$M+0I38V5N87)I;W,@=&%B<W1O<',*"C$I('-T
M>6QE.G1Y<&4@;V8@<W1Y;&4Z=&%B+7-T;W`@:7,@)W)I9VAT)R!A;F0@96%R
M;&EE<B!T86)3=&]P(&ES(&YO="!R:6=H=`H@+3X@16%R;&EE<B!T97AT+6YO
M9&5S(&%N9"!F;VQL;W=I;F<@=&5X="UN;V1E<RP@=VEL;"!B92!P=70@:6YT
M;R!A;B!I;FYE<B!T86)L92P@=VET:"!T=V\@5$0@9FER<W0@86QI9VYE9"!L
M969T+"!W:71H('!R;V-E9&EN9R!T97AT;F]D97,L('1H92!L871T97(@86QI
M9VYE9"!R:6=H="X*"C(I('-T>6QE.G1Y<&4@:7,@)W)I9VAT)R!A;F0@96%R
M;&EE<B!T86)3=&]P(&ES(')I9VAT"B`M/B!F;VQL;W=I;F<@=&5X="UN;V1E
M<RP@=VEL;"!B92!P=70@:6YT;R!A(')I9VAT(&%L:6=N960@5$0*"C,I('-T
M>6QE.G1Y<&4@:7,@)VYO;BUR:6=H="<@86YD(&5A<FQI97(@=&%B4W1O<"`G
M;F]N+7)I9VAT)R!A<R!W96QL"B`M/B!P=70@=&AE('!R96-E9&EN9R!T86(@
M<W1O<',@:6YT;R!A(%1$("AL969T(&%L:6=N960@:7,@9&5F875L="D*"C0I
M(&9I<G-T('-T>6QE.G1Y<&4@=V]U;&0@:&%V92!N;R!R:6=H="!P<F5C961I
M9VX@=&%B4W1O<`H@+3X@=V]R:W,@=V5L;"!W:71H(&9I<G-T('-C96%N<FEO
M<R`Q(&%N9"`S"@HU*2!L87-T('-T>6QE.G1Y<&4@=V]U;&0@8F4@82!S<&5C
M:6%L(&-A<V4L(&EF(&ET('=O=6QD(&)E(&QE9G0@86QI9VYE9"P@8G5T('1H
M:7,@=V]N)W0@:&%P<&5N(&EN(&]U<B!C87-E+BX@.D0*"E-C96YA<FEO<R!U
M;FUA=&-H960Z"BT@=&5X=#IS='EL97!O<VET:6]N("=C96YT97(G('=I;&P@
M;F]T(&)E(&UA=&-H960@:6X@;W5R(&-A<V4@*&5F9F]R="!F;W(@;F]T:&EN
M9RDL('1H97)E('=I;&P@8F4@;VYL>2`G<FEG:'0G(&%N9"!N;W0@)W)I9VAT
M)PHM($EF('1H92!L87-T('1A8E-T;W`@:7,@;F]T(&9R;VT@=&5X=#IS='EL
M97!O<W1I;VX@)W)I9VAT)RP@=&AE(&QE;F=T:"!O9B!T:&4@;&%S="!C96QL
M(&ES('5N9&5F:6YE9"!A;F0@82!D;V-U;65N="!L96YG=&@@;75S="!B92!F
M;W5N9"X*("!.;W0@:&%P<&5N<R!I;B!O=7(@9VQO8F%L(&1O8W5M96YT(&-A
M<V4N($%L<V\@=&AE(&%L9V]R:71H;2!B96QO=R!W;W5L9"!H879E('1O(&)E
M(&5X<&%N9&5D("AC<"X@<V-E;F%R:6\@-2DN"@HM+3X*("`@(#QX<VPZ=&5M
M<&QA=&4@;F%M93TB8W)E871E+71D+65L96UE;G1S(CX*("`@("`@("`\>'-L
M.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`\
M>'-L.G!A<F%M(&YA;64](FQA<W1.;V1E4&]S:71I;VXB+SX*("`@("`@("`\
M>'-L.G!A<F%M(&YA;64](G!O<VET:6]N(B\^"B`@("`@("`@/'AS;#IP87)A
M;2!N86UE/2)A;&Q486)3=&]P4W1Y;&5S(B\^"B`@("`@("`@/'AS;#IP87)A
M;2!N86UE/2)T86).;V1E4&]S:71I;VYS(B\^"CPA+2T*/'AS;#IM97-S86=E
M/BLK*RLK*RLK/"]X<VPZ;65S<V%G93X*/'AS;#IM97-S86=E/E!O<VET:6]N
M.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'!O<VET:6]N(B\^/"]X<VPZ;65S
M<V%G93X*/'AS;#IM97-S86=E/FQA<W1.;V1E4&]S:71I;VXZ(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2(D;&%S=$YO9&50;W-I=&EO;B(O/CPO>'-L.FUE<W-A
M9V4^"BTM/@H*("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F-U<G)E;G13
M='EL951Y<&4B('-E;&5C=#TB)&%L;%1A8E-T;W!3='EL97,O<W1Y;&4Z=&%B
M+7-T;W!;)'!O<VET:6]N72]`<W1Y;&4Z='EP92(O/@H@("`@("`@(#QX<VPZ
M=F%R:6%B;&4@;F%M93TB96%R;&EE<E-T>6QE5'EP92(@<V5L96-T/2(D86QL
M5&%B4W1O<%-T>6QE<R]S='EL93IT86(M<W1O<%LD<&]S:71I;VX@+2`Q72]`
M<W1Y;&4Z='EP92(O/@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@
M("`\>'-L.G=H96X@=&5S=#TB)&-U<G)E;G13='EL951Y<&4@/2`G<FEG:'0G
M(CX*("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D96%R;&EE<E-T>6QE5'EP92`]("=R
M:6=H="<B/@H@("`@("`@("`@("`@("`@("`@("`@("`\(2TM"B`@("`@("`@
M("`@("`@("`@("`@("`@(#(I('-T>6QE.G1Y<&4@:7,@)W)I9VAT)R!A;F0@
M96%R;&EE<B!T86)3=&]P(&ES(')I9VAT"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`M/B!F;VQL;W=I;F<@=&5X="UN;V1E<RP@=VEL;"!B92!P=70@
M:6YT;R!A(')I9VAT(&%L:6=N960@5$0@+2T^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)T9"(^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)S='EL92(^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/F%L:6=N
M.B!R:6=H=#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB9W)A<"UC96QL+6-O;G1E;G0M
M8F5F;W)E+71A8BUS=&]P(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T
M82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)E
M;F1I;F=486)3=&]P4&]S:71I;VXB("!S96QE8W0](B1P;W-I=&EO;B`K(#$B
M+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB;&%S=$YO9&50;W-I=&EO;B(@<V5L96-T/2(D;&%S=$YO
M9&50;W-I=&EO;B(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)T86).;V1E4&]S:71I;VYS(B!S96QE
M8W0](B1T86).;V1E4&]S:71I;VYS(B\^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^
M"B`@("`@("`@("`@("`@("`@("`@/"$M+0H@("`@("`@("`@("`@("`@("`@
M("`@("`Q*2!S='EL93IT>7!E(&]F('-T>6QE.G1A8BUS=&]P(&ES("=R:6=H
M="<@86YD(&5A<FQI97(@=&%B4W1O<"!I<R!N;W0@<FEG:'0*("`@("`@("`@
M("`@("`@("`@("`@("`@("T^($5A<FQI97(@=&5X="UN;V1E<R!A;F0@9F]L
M;&]W:6YG('1E>'0M;F]D97,L('=I;&P@8F4@<'5T(&EN=&\@86X@:6YN97(@
M=&%B;&4L('=I=&@@='=O(%1$(&9I<G-T(&%L:6=N960@;&5F="P@=VET:"!P
M<F]C961I;F<@=&5X=&YO9&5S+"!T:&4@;&%T=&5R(&%L:6=N960@<FEG:'0N
M+2T^"CPA+2T@=F%L:60@2%1-3"!B=70@8G)O=W-E<G,@;6%K92!A(&QI;F4@
M8G)E86L@*&)O<F1E<CTP(&%N9"!P87)A9W)A<&AS='EL92!A;'-O(&UI<W-I
M;F<I.@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M
M93TB=&%B;&4B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IE
M;&5M96YT(&YA;64](G1D(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB9W)A<"UC96QL+6-O;G1E
M;G0M8F5F;W)E+71A8BUS=&]P(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L
M;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](F5N9&EN9U1A8E-T;W!0;W-I=&EO;B(@('-E;&5C=#TB)'!O
M<VET:6]N(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)L87-T3F]D95!O<VET:6]N(B!S96QE
M8W0](B1L87-T3F]D95!O<VET:6]N(B\^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)T86).;V1E
M4&]S:71I;VYS(B!S96QE8W0](B1T86).;V1E4&]S:71I;VYS(B\^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T
M93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M
M93TB=&0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M871T<FEB=71E(&YA;64](G-T>6QE(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IT97AT/F%L:6=N.B!R:6=H=#PO>'-L.G1E
M>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ871T
M<FEB=71E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M8V%L;"UT96UP;&%T92!N86UE/2)G<F%P+6-E;&PM8V]N=&5N="UB969O<F4M
M=&%B+7-T;W`B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@
M<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M96YD:6YG5&%B4W1O<%!O<VET:6]N(B`@<V5L96-T/2(D<&]S:71I;VX@*R`Q
M(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)L87-T3F]D95!O<VET:6]N(B!S96QE8W0](B1L
M87-T3F]D95!O<VET:6]N(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)T86).;V1E4&]S:71I
M;VYS(B!S96QE8W0](B1T86).;V1E4&]S:71I;VYS(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"BTM/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](G1D(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M
M<&QA=&4@;F%M93TB9W)A<"UC96QL+6-O;G1E;G0M8F5F;W)E+71A8BUS=&]P
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB
M)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F5N9&EN9U1A
M8E-T;W!0;W-I=&EO;B(@('-E;&5C=#TB)'!O<VET:6]N(B\^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)L87-T3F]D95!O<VET:6]N(B!S96QE8W0](B1L87-T3F]D95!O<VET
M:6]N(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)T86).;V1E4&]S:71I;VYS(B!S96QE8W0]
M(B1T86).;V1E4&]S:71I;VYS(B\^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*/"$M+2!/1$L@1D5!5%52
M12!.3R!004=%4PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ96QE;65N="!N86UE/2)T9"(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](G-T>6QE(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X
M=#YA;&EG;CH@<FEG:'0\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N
M86UE/2)G<F%P+6-E;&PM8V]N=&5N="UB969O<F4M=&%B+7-T;W`B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O
M;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)E;F1I;F=4
M86)3=&]P4&]S:71I;VXB("!S96QE8W0](B1P;W-I=&EO;B`K(#$B+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)L87-T3F]D95!O<VET:6]N(B!S96QE8W0](B1L87-T
M3F]D95!O<VET:6]N(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=&%B3F]D95!O<VET
M:6]N<R(@<V5L96-T/2(D=&%B3F]D95!O<VET:6]N<R(O/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE
M;G0^("`@("`@("`@("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE
M<G=I<V4^"B`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@
M("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@
M("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0](B1E87)L:65R4W1Y;&54>7!E(#T@)W)I9VAT
M)R(^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@
M("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@
M("`\(2TM"B`@("`@("`@("`@("`@("`@("`@("`@,RD@<W1Y;&4Z='EP92!I
M<R`G;F]N+7)I9VAT)R!A;F0@96%R;&EE<B!T86)3=&]P("=N;VXM<FEG:'0G
M(&%S('=E;&P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("T^('!U="!T
M:&4@<')E8V5D:6YG('1A8B!S=&]P<R!I;G1O(&$@5$0@*&QE9G0@86QI9VYE
M9"!I<R!D969A=6QT*2`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IE;&5M96YT(&YA;64](G1D(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)G<F%P+6-E;&PM8V]N=&5N
M="UB969O<F4M=&%B+7-T;W`B/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$
M871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F5N9&EN9U1A8E-T;W!0;W-I=&EO;B(@('-E;&5C=#TB)'!O<VET:6]N(B\^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](FQA<W1.;V1E4&]S:71I;VXB('-E;&5C=#TB)&QA<W1.;V1E
M4&]S:71I;VXB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB=&%B3F]D95!O<VET:6]N<R(@<V5L96-T
M/2(D=&%B3F]D95!O<VET:6]N<R(O/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@
M("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O
M<V4^"@H@("`@("`@(#QX<VPZ:68@=&5S=#TB)'!O<VET:6]N("$]("1L87-T
M3F]D95!O<VET:6]N(CX*("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E
M(&YA;64](F-R96%T92UT9"UE;&5M96YT<R(^"B`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L
M96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](FQA<W1.;V1E4&]S:71I;VXB('-E;&5C
M=#TB)&QA<W1.;V1E4&]S:71I;VXB+SX*("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)P;W-I=&EO;B(@("`@("`@("!S96QE8W0](B1P
M;W-I=&EO;B`K(#$B+SX*("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)A;&Q486)3=&]P4W1Y;&5S(B!S96QE8W0](B1A;&Q486)3=&]P
M4W1Y;&5S(B\^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB=&%B3F]D95!O<VET:6]N<R(@<V5L96-T/2(D=&%B3F]D95!O<VET:6]N
M<R(O/@H@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@
M(#PO>'-L.FEF/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#QX<VPZ=&5M
M<&QA=&4@;F%M93TB9W)A<"UC96QL+6-O;G1E;G0M8F5F;W)E+71A8BUS=&]P
M(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A
M=&$B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F5N9&EN9U1A8E-T;W!0
M;W-I=&EO;B(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB=&%B3F]D95!O
M<VET:6]N<R(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB;&%S=$YO9&50
M;W-I=&EO;B(O/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@
M/'AS;#IW:&5N('1E<W0](B1E;F1I;F=486)3=&]P4&]S:71I;VX@/2`Q(CX*
M("`@("`@("`@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S(&UO9&4](F-O
M;G1E;G0M=&%B;&4B('-E;&5C=#TB;F]D92@I6W!O<VET:6]N*"D@)FQT.R`D
M=&%B3F]D95!O<VET:6]N<R]T86(M<W1O<"UN;V1E+7!O<VET:6]N6R1E;F1I
M;F=486)3=&]P4&]S:71I;VY=72(^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C
M=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@(#PO
M>'-L.F%P<&QY+71E;7!L871E<SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1E;F1I;F=486)3=&]P4&]S
M:71I;VX@/B`D;&%S=$YO9&50;W-I=&EO;B(^"B`@("`@("`@("`@("`@("`\
M>'-L.F%P<&QY+71E;7!L871E<R!M;V1E/2)C;VYT96YT+71A8FQE(B!S96QE
M8W0](FYO9&4H*5MP;W-I=&EO;B@I(#X@)'1A8DYO9&50;W-I=&EO;G,O=&%B
M+7-T;W`M;F]D92UP;W-I=&EO;ELD96YD:6YG5&%B4W1O<%!O<VET:6]N("T@
M,5U=(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO
M8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA
M=&5S/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L
M.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA
M=&5S(&UO9&4](F-O;G1E;G0M=&%B;&4B('-E;&5C=#TB;F]D92@I6W!O<VET
M:6]N*"D@)FQT.R`D=&%B3F]D95!O<VET:6]N<R]T86(M<W1O<"UN;V1E+7!O
M<VET:6]N6R1E;F1I;F=486)3=&]P4&]S:71I;VY=75MP;W-I=&EO;B@I(#X@
M)'1A8DYO9&50;W-I=&EO;G,O=&%B+7-T;W`M;F]D92UP;W-I=&EO;ELD96YD
M:6YG5&%B4W1O<%!O<VET:6]N("T@,5U=(CX*("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@
M<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@
M("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@("`@("`@("`\+WAS;#IO
M=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M
M<&QA=&4^"@H@("`@/'AS;#IT96UP;&%T92!M;V1E/2)C;VYT96YT+71A8FQE
M(B!M871C:#TB=&5X=#IS(CX*("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@
M;F%M93TB=W)I=&4M8G)E86MA8FQE+7=H:71E<W!A8V4B/@H@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=VAI=&5S<&%C97,B('-E;&5C=#TB
M0'1E>'0Z8R(O/@H@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`\
M+WAS;#IT96UP;&%T93X*"@H@("`@/'AS;#IT96UP;&%T92!M871C:#TB*B(@
M;6]D93TB8V5L;"UC;VYT96YT(CX*"B`@("`@("`@/'AS;#II9B!T97-T/2)N
M86UE*"D@/2`G=&5X=#IT86(M<W1O<"<@;W(@*EMN86UE*"D@/2`G=&5X=#IT
M86(M<W1O<"==(CX*("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](G1A
M8BUS=&]P+6YO9&4M<&]S:71I;VXB/@H@("`@("`@("`@("`@("`@/'AS;#IV
M86QU92UO9B!S96QE8W0](G!O<VET:6]N*"DB+SX*("`@("`@("`@("`@/"]X
M<VPZ96QE;65N=#X*("`@("`@("`\+WAS;#II9CX*("`@(#PO>'-L.G1E;7!L
M871E/@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64](F=R87`M8V5L;"UW:61T
M:"(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)P;W-I=&EO;B(O/@H@("`@
M("`@(#QX<VPZ<&%R86T@;F%M93TB86QL5&%B4W1O<%-T>6QE<R(O/@H*("`@
M("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G1A8E-T;W!0;W-I=&EO;B(@<V5L
M96-T/2(D86QL5&%B4W1O<%-T>6QE<R]S='EL93IT86(M<W1O<%LD<&]S:71I
M;VY=+T!S='EL93IP;W-I=&EO;B(O/@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@
M("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'1A8E-T;W!0
M;W-I=&EO;BP@)V-M)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E
M;7!L871E(&YA;64](F-R96%T92UC96QL+7=I9'1H(CX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=VED=&@B("`@('-E;&5C
M=#TB;G5M8F5R*'-U8G-T<FEN9RUB969O<F4H)'1A8E-T;W!0;W-I=&EO;BPG
M8VTG*2DB+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB=6YI="(@("`@('-E;&5C=#TB)V-M)R(O/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P;W-I=&EO;B(@<V5L96-T
M/2(D<&]S:71I;VX@+2`Q(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F%L;%1A8E-T;W!3='EL97,B('-E;&5C=#TB)&%L
M;%1A8E-T;W!3='EL97,B+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM
M=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@
M(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@D=&%B4W1O<%!O<VET:6]N+"`G
M:6XG*2(^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M
M93TB8W)E871E+6-E;&PM=VED=&@B/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)W:61T:"(@("`@<V5L96-T/2)N=6UB97(H
M<W5B<W1R:6YG+6)E9F]R92@D=&%B4W1O<%!O<VET:6]N+"=I;B<I*2(O/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)U;FET
M(B`@("`@<V5L96-T/2(G:6XG(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](G!O<VET:6]N(B!S96QE8W0](B1P;W-I=&EO
M;B`M(#$B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB86QL5&%B4W1O<%-T>6QE<R(@<V5L96-T/2(D86QL5&%B4W1O<%-T
M>6QE<R(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0](F-O;G1A:6YS*"1T86)3=&]P4&]S:71I;VXL("=C:"<I(CX*("`@
M("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)C<F5A=&4M
M8V5L;"UW:61T:"(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](G=I9'1H(B`@("!S96QE8W0](FYU;6)E<BAS=6)S=')I;F<M
M8F5F;W)E*"1T86)3=&]P4&]S:71I;VXL)V-H)RDI(B\^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G5N:70B("`@("!S96QE
M8W0](B=C:"<B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB<&]S:71I;VXB('-E;&5C=#TB)'!O<VET:6]N("T@,2(O/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q4
M86)3=&]P4W1Y;&5S(B!S96QE8W0](B1A;&Q486)3=&]P4W1Y;&5S(B\^"B`@
M("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@
M("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N
M=&%I;G,H)'1A8E-T;W!0;W-I=&EO;BP@)W!T)RDB/@H@("`@("`@("`@("`@
M("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F-R96%T92UC96QL+7=I9'1H
M(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M=VED=&@B("`@('-E;&5C=#TB;G5M8F5R*'-U8G-T<FEN9RUB969O<F4H)'1A
M8E-T;W!0;W-I=&EO;BPG<'0G*2DB+SX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB=6YI="(@("`@('-E;&5C=#TB)W!T)R(O
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P
M;W-I=&EO;B(@<V5L96-T/2(D<&]S:71I;VX@+2`Q(B\^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%L;%1A8E-T;W!3='EL
M97,B('-E;&5C=#TB)&%L;%1A8E-T;W!3='EL97,B+SX*("`@("`@("`@("`@
M("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L.G=H
M96X^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^
M"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)C<F5A=&4M8V5L;"UW:61T:"(^
M"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)W:61T:"(O/@H@("`@("`@(#QX
M<VPZ<&%R86T@;F%M93TB=6YI="(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M
M93TB<&]S:71I;VXB+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F%L;%1A
M8E-T;W!3='EL97,B+SX*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@
M("`@(#QX<VPZ=VAE;B!T97-T/2(D<&]S:71I;VX@/B`Q(CX*("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)C<F5A=&4M8V5L;"UW
M:61T:"(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](G=I9'1H(B`@("!S96QE8W0](B1W:61T:"`M(&YU;6)E<BAS=6)S=')I
M;F<M8F5F;W)E*"1A;&Q486)3=&]P4W1Y;&5S+W-T>6QE.G1A8BUS=&]P6R1P
M;W-I=&EO;ETO0'-T>6QE.G!O<VET:6]N+"1U;FET*2DB+SX*("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=6YI="(@("`@('-E
M;&5C=#TB)'5N:70B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB<&]S:71I;VXB('-E;&5C=#TB)'!O<VET:6]N("T@,2(O
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A
M;&Q486)3=&]P4W1Y;&5S(B!S96QE8W0](B1A;&Q486)3=&]P4W1Y;&5S(B\^
M"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB
M)'!O<VET:6]N(#T@,2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB8V]N8V%T*"1W:61T:"`M(&YU;6)E<BAS=6)S=')I;F<M8F5F
M;W)E*"1A;&Q486)3=&]P4W1Y;&5S+W-T>6QE.G1A8BUS=&]P6R1P;W-I=&EO
M;ETO0'-T>6QE.G!O<VET:6]N+"1U;FET*2DL("1U;FET*2(O/@H@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*
M("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC870H
M)'=I9'1H+"`D=6YI="DB+SX*("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E
M/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*
M/"]X<VPZ<W1Y;&5S:&5E=#X`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]O
M;V\O=&%B;&5?<F]W<RYX<VP`````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q-S4R-2`Q
M,#4Q-30S,S<S-B`P,C4P-#``(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/"$M+0H*("`@5&AE($-O;G1E;G1S(&]F('1H:7,@
M9FEL92!A<F4@;6%D92!A=F%I;&%B;&4@<W5B:F5C="!T;R!T:&4@=&5R;7,@
M;V8*("`@96ET:&5R(&]F('1H92!F;VQL;W=I;F<@;&EC96YS97,*"B`@("`@
M("`@("`M($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,@3&EC96YS92!697)S
M:6]N(#(N,0H@("`@("`@("`@+2!3=6X@26YD=7-T<GD@4W1A;F1A<F1S(%-O
M=7)C92!,:6-E;G-E(%9E<G-I;VX@,2XQ"@H@("!3=6X@36EC<F]S>7-T96US
M($EN8RXL($]C=&]B97(L(#(P,#`*"B`@($=.52!,97-S97(@1V5N97)A;"!0
M=6)L:6,@3&EC96YS92!697)S:6]N(#(N,0H@("`]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*("`@0V]P>7)I9VAT(#(P
M,#`@8GD@4W5N($UI8W)O<WES=&5M<RP@26YC+@H@("`Y,#$@4V%N($%N=&]N
M:6\@4F]A9"P@4&%L;R!!;'1O+"!#02`Y-#,P,RP@55-!"@H@("!4:&ES(&QI
M8G)A<GD@:7,@9G)E92!S;V9T=V%R93L@>6]U(&-A;B!R961I<W1R:6)U=&4@
M:70@86YD+V]R"B`@(&UO9&EF>2!I="!U;F1E<B!T:&4@=&5R;7,@;V8@=&AE
M($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,*("`@3&EC96YS92!V97)S:6]N
M(#(N,2P@87,@<'5B;&ES:&5D(&)Y('1H92!&<F5E(%-O9G1W87)E($9O=6YD
M871I;VXN"@H@("!4:&ES(&QI8G)A<GD@:7,@9&ES=')I8G5T960@:6X@=&AE
M(&AO<&4@=&AA="!I="!W:6QL(&)E('5S969U;"P*("`@8G5T(%=)5$A/550@
M04Y9(%=!4E)!3E19.R!W:71H;W5T(&5V96X@=&AE(&EM<&QI960@=V%R<F%N
M='D@;V8*("`@34520TA!3E1!0DE,2519(&]R($9)5$Y%4U,@1D]2($$@4$%2
M5$E#54Q!4B!055)03U-%+B`@4V5E('1H92!'3E4*("`@3&5S<V5R($=E;F5R
M86P@4'5B;&EC($QI8V5N<V4@9F]R(&UO<F4@9&5T86EL<RX*"B`@(%EO=2!S
M:&]U;&0@:&%V92!R96-E:79E9"!A(&-O<'D@;V8@=&AE($=.52!,97-S97(@
M1V5N97)A;"!0=6)L:6,*("`@3&EC96YS92!A;&]N9R!W:71H('1H:7,@;&EB
M<F%R>3L@:68@;F]T+"!W<FET92!T;R!T:&4@1G)E92!3;V9T=V%R90H@("!&
M;W5N9&%T:6]N+"!);F,N+"`U.2!496UP;&4@4&QA8V4L(%-U:71E(#,S,"P@
M0F]S=&]N+`H@("!-02`@,#(Q,3$M,3,P-R`@55-!"@H*("`@4W5N($EN9'5S
M=')Y(%-T86YD87)D<R!3;W5R8V4@3&EC96YS92!697)S:6]N(#$N,0H@("`]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]"B`@(%1H92!C;VYT96YT<R!O9B!T:&ES(&9I;&4@87)E('-U8FIE8W0@
M=&\@=&AE(%-U;B!);F1U<W1R>2!3=&%N9&%R9',*("`@4V]U<F-E($QI8V5N
M<V4@5F5R<VEO;B`Q+C$@*'1H92`B3&EC96YS92(I.R!9;W4@;6%Y(&YO="!U
M<V4@=&AI<R!F:6QE"B`@(&5X8V5P="!I;B!C;VUP;&EA;F-E('=I=&@@=&AE
M($QI8V5N<V4N(%EO=2!M87D@;V)T86EN(&$@8V]P>2!O9B!T:&4*("`@3&EC
M96YS92!A="!H='1P.B\O=W=W+F]P96YO9F9I8V4N;W)G+VQI8V5N<V4N:'1M
M;"X*"B`@(%-O9G1W87)E('!R;W9I9&5D('5N9&5R('1H:7,@3&EC96YS92!I
M<R!P<F]V:61E9"!O;B!A;B`B05,@25,B(&)A<VES+`H@("!7251(3U54(%=!
M4E)!3E19($]&($%.62!+24Y$+"!%251(15(@15A04D534R!/4B!)35!,245$
M+"!)3D-,541)3D<L"B`@(%=)5$A/550@3$E-251!5$E/3BP@5T%24D%.5$E%
M4R!42$%4(%1(12!33T945T%212!)4R!&4D5%($]&($1%1D5#5%,L"B`@($U%
M4D-(04Y404),12P@1DE4($9/4B!!(%!!4E1)0U5,05(@4%524$]312P@3U(@
M3D].+4E.1E))3D=)3D<N"B`@(%-E92!T:&4@3&EC96YS92!F;W(@=&AE('-P
M96-I9FEC('!R;W9I<VEO;G,@9V]V97)N:6YG('EO=7(@<FEG:'1S(&%N9`H@
M("!O8FQI9V%T:6]N<R!C;VYC97)N:6YG('1H92!3;V9T=V%R92X*"B`@(%1H
M92!);FET:6%L($1E=F5L;W!E<B!O9B!T:&4@3W)I9VEN86P@0V]D92!I<SH@
M4W5N($UI8W)O<WES=&5M<RP@26YC+@H*("`@0V]P>7)I9VAT(,*I(#(P,#(@
M8GD@4W5N($UI8W)O<WES=&5M<RP@26YC+@H*("`@06QL(%)I9VAT<R!297-E
M<G9E9"X*"B`@($-O;G1R:6)U=&]R*',I.B!?7U]?7U]?7U]?7U]?7U]?7U]?
M7U]?7U]?7U]?7U]?7U]?7U]?7U\*"BTM/@H\>'-L.G-T>6QE<VAE970@=F5R
M<VEO;CTB,2XP(@H@("`@("`@("`@("`@("`@>&UL;G,Z>'-L/2)H='1P.B\O
M=W=W+G<S+F]R9R\Q.3DY+UA33"]4<F%N<V9O<FTB"B`@("`@("`@("`@("`@
M("!X;6QN<SIO9F9I8V4](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V]F
M9FEC92(*("`@("`@("`@("`@("`@('AM;&YS.G-T>6QE/2)H='1P.B\O;W!E
M;F]F9FEC92YO<F<O,C`P,"]S='EL92(*("`@("`@("`@("`@("`@('AM;&YS
M.G1E>'0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W1E>'0B"B`@("`@
M("`@("`@("`@("!X;6QN<SIT86)L93TB:'1T<#HO+V]P96YO9F9I8V4N;W)G
M+S(P,#`O=&%B;&4B"B`@("`@("`@("`@("`@("!X;6QN<SID<F%W/2)H='1P
M.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]D<F%W:6YG(@H@("`@("`@("`@("`@
M("`@>&UL;G,Z9F\](FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3DO6%-,+T9O<FUA
M="(*("`@("`@("`@("`@("`@('AM;&YS.GAL:6YK/2)H='1P.B\O=W=W+G<S
M+F]R9R\Q.3DY+WAL:6YK(@H@("`@("`@("`@("`@("`@>&UL;G,Z;G5M8F5R
M/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]D871A<W1Y;&4B"B`@("`@
M("`@("`@("`@("!X;6QN<SIS=F<](FAT='`Z+R]W=W<N=S,N;W)G+S(P,#`O
M<W9G(@H@("`@("`@("`@("`@("`@>&UL;G,Z8VAA<G0](FAT='`Z+R]O<&5N
M;V9F:6-E+F]R9R\R,#`P+V-H87)T(@H@("`@("`@("`@("`@("`@>&UL;G,Z
M9'(S9#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O9'(S9"(*("`@("`@
M("`@("`@("`@('AM;&YS.FUA=&@](FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3@O
M36%T:"]-871H34PB"B`@("`@("`@("`@("`@("!X;6QN<SIF;W)M/2)H='1P
M.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]F;W)M(@H@("`@("`@("`@("`@("`@
M>&UL;G,Z<V-R:7!T/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]S8W)I
M<'0B"B`@("`@("`@("`@("`@("!O9F9I8V4Z8VQA<W,](G1E>'0B"B`@("`@
M("`@("`@("`@("!O9F9I8V4Z=F5R<VEO;CTB,2XP(@H@("`@("`@("`@("`@
M("`@>&UL;G,Z9&,](FAT='`Z+R]P=7)L+F]R9R]D8R]E;&5M96YT<R\Q+C$O
M(@H@("`@("`@("`@("`@("`@>&UL;G,Z;65T83TB:'1T<#HO+V]P96YO9F9I
M8V4N;W)G+S(P,#`O;65T82(*("`@("`@("`@("`@("`@('AM;&YS.F-O;F9I
M9STB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#$O8V]N9FEG(@H@("`@("`@
M("`@("`@("`@>&UL;G,Z:&5L<#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P
M,#`O:&5L<"(*("`@("`@("`@("`@("`@('AM;&YS.GAT/2)H='1P.B\O=W=W
M+FIC;&%R:RYC;VTO>'0B"B`@("`@("`@("`@("`@("!X;6QN<SIS>7-T96T]
M(FAT='`Z+R]W=W<N:F-L87)K+F-O;2]X="]J879A+VIA=F$N;&%N9RY3>7-T
M96TB"B`@("`@("`@("`@("`@("!X;6QN<SIX86QA;CTB:'1T<#HO+WAM;"YA
M<&%C:&4N;W)G+WAA;&%N(@H@("`@("`@("`@("`@("`@>&UL;G,Z:F%V83TB
M:'1T<#HO+WAM;"YA<&%C:&4N;W)G+WAS;'0O:F%V82(*("`@("`@("`@("`@
M("`@(&5X8VQU9&4M<F5S=6QT+7!R969I>&5S/2)J879A(CX*"@H*("`@(#PA
M+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ("TM/@H@("`@/"$M+2`J*BH@=W)I=&4@*&5X<&QI8VET*2!R97!E871I
M;F<@=&%B;&4@<F]W<R`J*BH@+2T^"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*"B`@("`\>'-L
M.G1E;7!L871E(&YA;64](G)E<&5A="UW<FET92UR;W<B/@H@("`@("`@(#QX
M<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@
M(#QX<VPZ<&%R86T@;F%M93TB86QL0V]L=6UN4W1Y;&5%;G1R:65S(B\^"B`@
M("`@("`@/'AS;#IP87)A;2!N86UE/2)N=6UB97(M<F]W<RUR97!E871E9"(@
M<V5L96-T/2(Q(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)M87A2;W=,
M96YG=&@B+SX*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#PA
M+2T@=W)I=&4@86X@96YT<GD@;V8@82!R;W<@86YD(')E<&5A="!C86QL:6YG
M('1H:7,@;65T:&]D('5N=&EL(&%L;"!E;&5M96YT<R!A<F4@=W)I='1E;B!O
M=70@+2T^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;G5M8F5R+7)O
M=W,M<F5P96%T960@/B`Q(&%N9"`H=&%B;&4Z=&%B;&4M8V5L;"]T97AT*"D@
M;W(@=&%B;&4Z=&%B;&4M8V5L;"\J*2(^"B`@("`@("`@("`@("`@("`\>'-L
M.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M<F]W(CX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L
M1&%T82(@("`@("`@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q#
M;VQU;6Y3='EL945N=')I97,B("`@('-E;&5C=#TB)&%L;$-O;'5M;E-T>6QE
M16YT<FEE<R(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)M87A2;W=,96YG=&@B("`@("`@("`@("`@('-E;&5C=#TB)&UA
M>%)O=TQE;F=T:"(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP
M;&%T93X*"B`@("`@("`@("`@("`@("`\(2TM(#)$3SH@=&%K92!V87)I86)L
M92!F<F]M('1H92!O=71P=70@;V8@<F5P96%T960@=W)I=&4M<F]W(&%N9"!I
M=&5R871E(&=I=FEN9R!O=70@=&AE('9A<FEA8FQE("TM/@H@("`@("`@("`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G)E<&5A="UW<FET92UR
M;W<B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)C;VQL96-T961';&]B86Q$871A(B`@("`@("!S96QE8W0](B1C;VQL96-T
M961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE<R(@("`@<V5L96-T
M/2(D86QL0V]L=6UN4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FUA>%)O=TQE;F=T:"(@("`@("`@
M("`@("`@<V5L96-T/2(D;6%X4F]W3&5N9W1H(B\^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FYU;6)E<BUR;W=S+7)E<&5A
M=&5D(B`@("`@<V5L96-T/2(D;G5M8F5R+7)O=W,M<F5P96%T960@+2`Q(B\^
M"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\(2TM('=R:71E(&$@<VEN
M9VQE(&5N=')Y(&]F(&$@<F]W("TM/@H@("`@("`@("`@("`\>'-L.F]T:&5R
M=VES93X*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE
M/2)W<FET92UR;W<B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B`@("`@("!S96QE8W0]
M(B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE<R(@
M("`@<V5L96-T/2(D86QL0V]L=6UN4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FUA>%)O=TQE;F=T
M:"(@("`@("`@("`@("`@<V5L96-T/2(D;6%X4F]W3&5N9W1H(B\^"B`@("`@
M("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`\
M+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X
M<VPZ=&5M<&QA=&4^"@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64](G=R:71E
M+7)O=R(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQL96-T961';&]B
M86Q$871A(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)A;&Q#;VQU;6Y3
M='EL945N=')I97,B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](FUA>%)O
M=TQE;F=T:"(O/@H*"B`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](G1R(CX*
M("`@("`@("`@("`@/"$M+2!W<FET:6YG('1H92!S='EL92!O9B!T:&4@<F]W
M("TM/@H@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TG861D
M+7-T>6QE+7!R;W!E<G1I97,G/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O
M;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@/"]X<VPZ8V%L;"UT
M96UP;&%T93X*"B`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB)&ES1&5B=6=-
M;V1E(CX*("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93X**BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*B=T<B<@96QE;65N="!H87,@8F5E;B!A9&1E9"$\
M+WAS;#IM97-S86=E/@H@("`@("`@("`@("`\+WAS;#II9CX*"B`@("`@("`@
M("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S('-E;&5C=#TB=&%B;&4Z=&%B;&4M
M8V5L;"(^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M8V]L;&5C=&5D1VQO8F%L1&%T82(@("`@("`@<V5L96-T/2(D8V]L;&5C=&5D
M1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE<R(@("`@<V5L96-T/2(D86QL
M0V]L=6UN4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB;6%X4F]W3&5N9W1H(B`@("`@("`@("`@("!S96QE
M8W0](B1M87A2;W=,96YG=&@B+SX*("`@("`@("`@("`@/"]X<VPZ87!P;'DM
M=&5M<&QA=&5S/@H*("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@/"]X<VPZ
M=&5M<&QA=&4^"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*B`M+3X*("`@(#PA+2T@*BHJ($A%3%!%4CH@=&%B;&4@<W1Y;&5S("HJ
M*B`M+3X*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M
M+3X*"B`@("`\>'-L.G1E;7!L871E(&YA;64](F%D9"US='EL92UP<F]P97)T
M:65S(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F%L;$-O;'5M;E-T
M>6QE16YT<FEE<R(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB;F]D92UP
M;W-I=&EO;B(O/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@
M/"$M+2LK*RLK($-34R`H0T%30T%$24Y'(%-43%E%(%-(1454*2!(14%$15(@
M4U193$4@5T%9("LK*RLK+2T^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2(D;W5T<'5T5'EP92`]("=#4U-?2$5!1$52)R(^"B`@("`@("`@("`@("`@
M("`\>'-L.F%T=')I8G5T92!N86UE/2)C;&%S<R(^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G1R86YS;&%T92A`=&%B;&4Z
M<W1Y;&4M;F%M92P@)RX@)2@I+UPG+"`G)RDB+SX*("`@("`@("`@("`@("`@
M(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*"B`@
M("`@("`@("`@(#PA+2TK*RLK*R!(5$U,(#0N,"!)3DQ)3D5$(%=!62`@*RLK
M*RLM+3X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1O=71P=714>7!E
M(#T@)T-34U])3DQ)3D5$)R(^"B`@("`@("`@("`@("`@("`\>'-L.F%T=')I
M8G5T92!N86UE/2)S='EL92(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IV
M86QU92UO9B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A+V%L;'-T>6QE
M<R\J6VYA;64H*3UC=7)R96YT*"DO0'1A8FQE.G-T>6QE+6YA;65=(B\^"B`@
M("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@(#PO
M>'-L.G=H96X^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M
M<&QA=&4^"@H\+WAS;#IS='EL97-H965T/@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M2&]R9&4O34E-12]6:65W97(O;V]O+W-T>6QE7VEN;&EN960N>'-L````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P-38S,C,@,3`U,34T,S,W,S8@,#(U-30P`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#PA+2T*"B`@(%1H
M92!#;VYT96YT<R!O9B!T:&ES(&9I;&4@87)E(&UA9&4@879A:6QA8FQE('-U
M8FIE8W0@=&\@=&AE('1E<FUS(&]F"B`@(&5I=&AE<B!O9B!T:&4@9F]L;&]W
M:6YG(&QI8V5N<V5S"@H@("`@("`@("`@+2!'3E4@3&5S<V5R($=E;F5R86P@
M4'5B;&EC($QI8V5N<V4@5F5R<VEO;B`R+C$*("`@("`@("`@("T@4W5N($EN
M9'5S=')Y(%-T86YD87)D<R!3;W5R8V4@3&EC96YS92!697)S:6]N(#$N,0H*
M("`@4W5N($UI8W)O<WES=&5M<R!);F,N+"!/8W1O8F5R+"`R,#`P"@H@("!'
M3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N<V4@5F5R<VEO;B`R+C$*
M("`@/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]"B`@($-O<'ER:6=H="`R,#`P(&)Y(%-U;B!-:6-R;W-Y<W1E;7,L($EN
M8RX*("`@.3`Q(%-A;B!!;G1O;FEO(%)O860L(%!A;&\@06QT;RP@0T$@.30S
M,#,L(%5300H*("`@5&AI<R!L:6)R87)Y(&ES(&9R964@<V]F='=A<F4[('EO
M=2!C86X@<F5D:7-T<FEB=71E(&ET(&%N9"]O<@H@("!M;V1I9GD@:70@=6YD
M97(@=&AE('1E<FUS(&]F('1H92!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC
M"B`@($QI8V5N<V4@=F5R<VEO;B`R+C$L(&%S('!U8FQI<VAE9"!B>2!T:&4@
M1G)E92!3;V9T=V%R92!&;W5N9&%T:6]N+@H*("`@5&AI<R!L:6)R87)Y(&ES
M(&1I<W1R:6)U=&5D(&EN('1H92!H;W!E('1H870@:70@=VEL;"!B92!U<V5F
M=6PL"B`@(&)U="!7251(3U54($%.62!705)204Y463L@=VET:&]U="!E=F5N
M('1H92!I;7!L:65D('=A<G)A;G1Y(&]F"B`@($U%4D-(04Y404))3$E462!O
M<B!&251.15-3($9/4B!!(%!!4E1)0U5,05(@4%524$]312X@(%-E92!T:&4@
M1TY5"B`@($QE<W-E<B!'96YE<F%L(%!U8FQI8R!,:6-E;G-E(&9O<B!M;W)E
M(&1E=&%I;',N"@H@("!9;W4@<VAO=6QD(&AA=F4@<F5C96EV960@82!C;W!Y
M(&]F('1H92!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC"B`@($QI8V5N<V4@
M86QO;F<@=VET:"!T:&ES(&QI8G)A<GD[(&EF(&YO="P@=W)I=&4@=&\@=&AE
M($9R964@4V]F='=A<F4*("`@1F]U;F1A=&EO;BP@26YC+BP@-3D@5&5M<&QE
M(%!L86-E+"!3=6ET92`S,S`L($)O<W1O;BP*("`@34$@(#`R,3$Q+3$S,#<@
M(%5300H*"B`@(%-U;B!);F1U<W1R>2!3=&%N9&%R9',@4V]U<F-E($QI8V5N
M<V4@5F5R<VEO;B`Q+C$*("`@/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@("!4:&4@8V]N=&5N=',@;V8@=&AI
M<R!F:6QE(&%R92!S=6)J96-T('1O('1H92!3=6X@26YD=7-T<GD@4W1A;F1A
M<F1S"B`@(%-O=7)C92!,:6-E;G-E(%9E<G-I;VX@,2XQ("AT:&4@(DQI8V5N
M<V4B*3L@66]U(&UA>2!N;W0@=7-E('1H:7,@9FEL90H@("!E>&-E<'0@:6X@
M8V]M<&QI86YC92!W:71H('1H92!,:6-E;G-E+B!9;W4@;6%Y(&]B=&%I;B!A
M(&-O<'D@;V8@=&AE"B`@($QI8V5N<V4@870@:'1T<#HO+W=W=RYO<&5N;V9F
M:6-E+F]R9R]L:6-E;G-E+FAT;6PN"@H@("!3;V9T=V%R92!P<F]V:61E9"!U
M;F1E<B!T:&ES($QI8V5N<V4@:7,@<')O=FED960@;VX@86X@(D%3($E3(B!B
M87-I<RP*("`@5TE42$]55"!705)204Y462!/1B!!3ED@2TE.1"P@14E42$52
M($584%)%4U,@3U(@24U03$E%1"P@24Y#3%5$24Y'+`H@("!7251(3U54($Q)
M34E4051)3TXL(%=!4E)!3E1)15,@5$A!5"!42$4@4T]&5%=!4D4@25,@1E)%
M12!/1B!$149%0U13+`H@("!-15)#2$%.5$%"3$4L($9)5"!&3U(@02!005)4
M24-53$%2(%!54E!/4T4L($]2($Y/3BU)3D9224Y'24Y'+@H@("!3964@=&AE
M($QI8V5N<V4@9F]R('1H92!S<&5C:69I8R!P<F]V:7-I;VYS(&=O=F5R;FEN
M9R!Y;W5R(')I9VAT<R!A;F0*("`@;V)L:6=A=&EO;G,@8V]N8V5R;FEN9R!T
M:&4@4V]F='=A<F4N"@H@("!4:&4@26YI=&EA;"!$979E;&]P97(@;V8@=&AE
M($]R:6=I;F%L($-O9&4@:7,Z(%-U;B!-:6-R;W-Y<W1E;7,L($EN8RX*"B`@
M($-O<'ER:6=H="#"J2`R,#`R(&)Y(%-U;B!-:6-R;W-Y<W1E;7,L($EN8RX*
M"B`@($%L;"!2:6=H=',@4F5S97)V960N"@H@("!#;VYT<FEB=71O<BAS*3H@
M7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?"@HM+3X*
M/'AS;#IS='EL97-H965T('9E<G-I;VX](C$N,"(*("`@("`@("`@("`@("`@
M('AM;&YS.GAS;#TB:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]84TPO5')A;G-F
M;W)M(@H@("`@("`@("`@("`@("`@>&UL;G,Z;V9F:6-E/2)H='1P.B\O;W!E
M;F]F9FEC92YO<F<O,C`P,"]O9F9I8V4B"B`@("`@("`@("`@("`@("!X;6QN
M<SIS='EL93TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O<W1Y;&4B"B`@
M("`@("`@("`@("`@("!X;6QN<SIT97AT/2)H='1P.B\O;W!E;F]F9FEC92YO
M<F<O,C`P,"]T97AT(@H@("`@("`@("`@("`@("`@>&UL;G,Z=&%B;&4](FAT
M='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W1A8FQE(@H@("`@("`@("`@("`@
M("`@>&UL;G,Z9')A=STB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O9')A
M=VEN9R(*("`@("`@("`@("`@("`@('AM;&YS.F9O/2)H='1P.B\O=W=W+G<S
M+F]R9R\Q.3DY+UA33"]&;W)M870B"B`@("`@("`@("`@("`@("!X;6QN<SIX
M;&EN:STB:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]X;&EN:R(*("`@("`@("`@
M("`@("`@('AM;&YS.FYU;6)E<CTB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P
M,#`O9&%T87-T>6QE(@H@("`@("`@("`@("`@("`@>&UL;G,Z<W9G/2)H='1P
M.B\O=W=W+G<S+F]R9R\R,#`P+W-V9R(*("`@("`@("`@("`@("`@('AM;&YS
M.F-H87)T/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]C:&%R="(*("`@
M("`@("`@("`@("`@('AM;&YS.F1R,V0](FAT='`Z+R]O<&5N;V9F:6-E+F]R
M9R\R,#`P+V1R,V0B"B`@("`@("`@("`@("`@("!X;6QN<SIM871H/2)H='1P
M.B\O=W=W+G<S+F]R9R\Q.3DX+TUA=&@O36%T:$U,(@H@("`@("`@("`@("`@
M("`@>&UL;G,Z9F]R;3TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O9F]R
M;2(*("`@("`@("`@("`@("`@('AM;&YS.G-C<FEP=#TB:'1T<#HO+V]P96YO
M9F9I8V4N;W)G+S(P,#`O<V-R:7!T(@H@("`@("`@("`@("`@("`@;V9F:6-E
M.F-L87-S/2)T97AT(@H@("`@("`@("`@("`@("`@;V9F:6-E.G9E<G-I;VX]
M(C$N,"(*("`@("`@("`@("`@("`@('AM;&YS.F1C/2)H='1P.B\O<'5R;"YO
M<F<O9&,O96QE;65N=',O,2XQ+R(*("`@("`@("`@("`@("`@('AM;&YS.FUE
M=&$](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+VUE=&$B"B`@("`@("`@
M("`@("`@("!X;6QN<SIC;VYF:6<](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R
M,#`Q+V-O;F9I9R(*("`@("`@("`@("`@("`@('AM;&YS.FAE;'`](FAT='`Z
M+R]O<&5N;V9F:6-E+F]R9R\R,#`P+VAE;'`B"B`@("`@("`@("`@("`@("!X
M;6QN<SIX=#TB:'1T<#HO+W=W=RYJ8VQA<FLN8V]M+WAT(@H@("`@("`@("`@
M("`@("`@>&UL;G,Z<WES=&5M/2)H='1P.B\O=W=W+FIC;&%R:RYC;VTO>'0O
M:F%V82]J879A+FQA;F<N4WES=&5M(@H@("`@("`@("`@("`@("`@>&UL;G,Z
M>&%L86X](FAT='`Z+R]X;6PN87!A8VAE+F]R9R]X86QA;B(*("`@("`@("`@
M("`@("`@('AM;&YS.FIA=F$](FAT='`Z+R]X;6PN87!A8VAE+F]R9R]X<VQT
M+VIA=F$B"B`@("`@("`@("`@("`@("!E>&-L=61E+7)E<W5L="UP<F5F:7AE
M<STB:F%V82(^"@H*"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ(&AA<F0@
M871T<FEB=71E9"`H:6YL:6YE9"D@<')O<&5R=&EE<R`@*BHJ("TM/@H@("`@
M/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BH@+2T^"@H*("`@(#PA+2T@4D535%))0U1)3TY3.@H@("`@("`@("`@
M("`Q*2`@07,@=&AE('-T>6QE<RUN;V1E+79A<FEA8FQE<R!A<F4@3D]4(&=L
M;V)A;"P@=&AE('-T>6QE('9A<FEA8FQE<R!A<F4@;F]T(&=L;V)A;"P@96ET
M:&5R(2$*("`@("`@("`@("`@,BD@($%S(&$@;&ES="!O9B!E;&5M96YT<R!C
M86X@;VYL>2!B92!A9&1E9"!T;R!A('9A<FEA8FQE(&%S(&$@<F5S=6QT('1R
M964@9G)A9VUE;G0@=&AE"B`@("`@("`@("`@("`@("!E>'1E;G-I;VX@:7,@
M;F5C8V5S<V%R>2$A"B`@("`M+3X*"B`@("`\(2TM(#)$3SH@26YL:6YE('-T
M>6QE<R!D;R!N;W0@:6YH97)I="!F<F]M(%A-3"!O9F9I8V4@9&5F875L=',@
M;F]R(&9O;G0Z9F%M:6QY(&1E9F%U;'1S(&%S('1H92!S='EL92!H96%D97(@
M9&]E<PH@("`@("`@("`@("`@("AC<"X@<W1Y;&5S:&5E="`G<W1Y;&5?:&5A
M9&5R+GAS;"<@86YD('1H92`G=W)I=&4M9&5F875L="US='EL97,G('1E;7!L
M871E*2`M+3X*"B`@("`\>'-L.G1E;7!L871E(&YA;64])V-R96%T92UA;&PM
M:6YL:6YE+7-T>6QE<R<^"@H@("`@("`@(#PA+2TJ*B!T<F%V97)S964@86QL
M('-T>6QE('1R965S(&%N9"!T:&5I<B!B<F%N8VAE<R!C;VQL96-T:6YG('-T
M>6QE('!R;W!E<G1I97,@*BHM+3X*("`@("`@("`\>'-L.F5L96UE;G0@;F%M
M93TB86QL<W1Y;&5S(CX*("`@("`@("`\(2TM*BH@=')A=F5R<V5E(&%L;"!O
M9F9I8V4Z<W1Y;&5S('1R965S(&)E9VEN;FEN9R!W:71H('1H92!T;W`M;&5V
M96P@<W1Y;&5S*BHM+3X*("`@("`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE
M8W0](B1O9F9I8V4Z<W1Y;&5S+W-T>6QE.G-T>6QE6VYO="A`<W1Y;&4Z<&%R
M96YT+7-T>6QE+6YA;64I72(^"@H@("`@("`@("`@("`@("`@/"$M+2HJ(&=I
M=F4@;W5T('1H92!S='EL92!P<F]P97)T:65S(&]F('1H92!P87)E;G0@;F]D
M92`J*BTM/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA
M;64])W=R:71E+6-U<G)E;G0M86YD+6EN:&5R:71E9"US='EL92UP<F]P97)T
M:65S)SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB<W1Y;&5S+6YO9&4B("`@("`@("`@("`@("`@("`@<V5L96-T/2(D;V9F
M:6-E.G-T>6QE<R(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)S='EL92UF86UI;'DB("`@("`@("`@("`@("`@("!S96QE
M8W0](D!S='EL93IF86UI;'DB+SX*("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB<W1Y;&4M;F%M92UT;VME;FEZ960B("`@("`@
M("`@<V5L96-T/2)T<F%N<VQA=&4H0'-T>6QE.FYA;64L("<N("4H*2]<)RP@
M)R<I(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H*
M("`@("`@("`@("`@("`@(#PA+2TJ*B!A;&P@;V9F:6-E.G-T>6QE<R!C:&EL
M9')E;B!O9B!T:&4@8W5R<F5N="!T;W`M;&5V96P@;V9F:6-E.G-T>6QE<R`J
M*BTM/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64]
M)V9O<BUA;&PM=&5M<&QA=&5S+6-H:6QD+7-T>6QE<R<^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G!A<F5N=%-T>6QE3F%M
M92(@("`@("`@("`@("`@('-E;&5C=#TB0'-T>6QE.FYA;64B+SX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<&%R96YT4W1Y
M;&5&86UI;'DB("`@("`@("`@("`@<V5L96-T/2)`<W1Y;&4Z9F%M:6QY(B\^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T
M>6QE+6YA;64M=&]K96YI>F5D(B`@("`@("`@('-E;&5C=#TB=')A;G-L871E
M*$!S='EL93IN86UE+"`G+B`E*"DO7"<L("<G*2(O/@H@("`@("`@("`@("`@
M("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*"B`@("`@("`@("`@("`@("`\(2TM
M*BH@86QL(&]F9FEC93IA=71O;6%T:6,M<W1Y;&5S(&-H:6QD<F5N(&]F('1H
M92!C=7)R96YT('1O<"UL979E;"!S='EL92`J*BTM/@H@("`@("`@("`@("`@
M("`@/'AS;#IC86QL+71E;7!L871E(&YA;64])V9O<BUA;&PM875T;VUA=&EC
M+6-H:6QD+7-T>6QE<R<^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](G!A<F5N=%-T>6QE3F%M92(@("`@("`@("`@("`@('-E
M;&5C=#TB0'-T>6QE.FYA;64B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB<&%R96YT4W1Y;&5&86UI;'DB("`@("`@("`@
M("`@<V5L96-T/2)`<W1Y;&4Z9F%M:6QY(B\^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE+6YA;64M=&]K96YI>F5D
M(B`@("`@("`@('-E;&5C=#TB=')A;G-L871E*$!S='EL93IN86UE+"`G+B`E
M*"DO7"<L("<G*2(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP
M;&%T93X*("`@("`@("`@("`@/"]X<VPZ9F]R+65A8V@^"@H@("`@("`@(#PA
M+2TJ*B!T<F%V97)S964@86QL(&]F9FEC93IA=71O;6%T:6,M<W1Y;&5S('1R
M965S(&)E9VEN;FEN9R!W:71H('1H92!T;W`M;&5V96P@<W1Y;&5S("HJ+2T^
M"B`@("`@("`@("`@(#QX<VPZ9F]R+65A8V@@<V5L96-T/2(D;V9F:6-E.F%U
M=&]M871I8RUS='EL97,O<W1Y;&4Z<W1Y;&5;;F]T*$!S='EL93IP87)E;G0M
M<W1Y;&4M;F%M92E=(CX*("`@("`@("`@("`@("`@(#PA+2TJ*B!G:79E(&]U
M="!T:&4@<W1Y;&4@<')O<&5R=&EE<R!O9B!T:&4@<&%R96YT(&YO9&4@*BHM
M+3X*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2=W
M<FET92UC=7)R96YT+6%N9"UI;FAE<FET960M<W1Y;&4M<')O<&5R=&EE<R<^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T
M>6QE<RUN;V1E(B`@("`@("`@("`@("`@("`@('-E;&5C=#TB)&]F9FEC93IA
M=71O;6%T:6,M<W1Y;&5S(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](G-T>6QE+69A;6EL>2(@("`@("`@("`@("`@("`@
M('-E;&5C=#TB0'-T>6QE.F9A;6EL>2(O/@H@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL92UN86UE+71O:V5N:7IE9"(@
M("`@("`@("!S96QE8W0](G1R86YS;&%T92A`<W1Y;&4Z;F%M92P@)RX@)2@I
M+UPG+"`G)RDB+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA
M=&4^"@H@("`@("`@("`@("`@("`@/"$M+2HJ(&%L;"!C:&EL9')E;B!O9B!T
M:&4@=&]P+6QE=F5L(&]F9FEC93IA=71O;6%T:6,M<W1Y;&5S<R`@*BHM+3X*
M("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2=F;W(M
M86QL+6%U=&]M871I8RUC:&EL9"US='EL97,G/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P87)E;G13='EL94YA;64B("`@
M("`@("`@("`@("!S96QE8W0](D!S='EL93IN86UE(B\^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G!A<F5N=%-T>6QE1F%M
M:6QY(B`@("`@("`@("`@('-E;&5C=#TB0'-T>6QE.F9A;6EL>2(O/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL92UN
M86UE+71O:V5N:7IE9"(@("`@("`@("!S96QE8W0](G1R86YS;&%T92A`<W1Y
M;&4Z;F%M92P@)RX@)2@I+UPG+"`G)RDB+SX*("`@("`@("`@("`@("`@(#PO
M>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L.F9O<BUE86-H
M/@H@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`\+WAS;#IT96UP;&%T93X*
M"@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TG9F]R+6%L;"UT96UP;&%T97,M
M8VAI;&0M<W1Y;&5S)SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G!A<F5N
M=%-T>6QE3F%M92(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB<&%R96YT
M4W1Y;&5&86UI;'DB+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G-T>6QE
M+6YA;64M=&]K96YI>F5D(B\^"@H@("`@("`@(#QX<VPZ9F]R+65A8V@@<V5L
M96-T/2(N+B]S='EL93IS='EL95M`<W1Y;&4Z9F%M:6QY/21P87)E;G13='EL
M949A;6EL>2!A;F0@0'-T>6QE.G!A<F5N="US='EL92UN86UE/21P87)E;G13
M='EL94YA;65=(CX*("`@("`@("`@("`@/"$M+2HJ(&=I=F4@;W5T('1H92!S
M='EL92!P<F]P97)T:65S(&]F('1H92!C=7)R96YT(&YO9&4@*BHM+3X*("`@
M("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](GLD<W1Y;&4M;F%M92UT;VME
M;FEZ961](CX*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N
M86UE/2=W<FET92UC=7)R96YT+6%N9"UI;FAE<FET960M<W1Y;&4M<')O<&5R
M=&EE<R<^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](G-T>6QE<RUN;V1E(B`@("`@("`@("`@("`@("`@('-E;&5C=#TB)&]F
M9FEC93IS='EL97,B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB<W1Y;&4M9F%M:6QY(B`@("`@("`@("`@("`@("`@<V5L
M96-T/2)`<W1Y;&4Z9F%M:6QY(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](G-T>6QE+6YA;64M=&]K96YI>F5D(B`@("`@
M("`@('-E;&5C=#TB=')A;G-L871E*$!S='EL93IN86UE+"`G+B`E*"DO7"<L
M("<G*2(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*
M("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*"B`@("`@("`@("`@(#PA+2TJ
M*B!F;W(@86QL('1E;7!L871E+6-H:6QD<F5N(&]F('1H92!C=7)R96YT(&]F
M9FEC93IS='EL97,@("HJ+2T^"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP
M;&%T92!N86UE/2=F;W(M86QL+71E;7!L871E<RUC:&EL9"US='EL97,G/@H@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE<RUN
M;V1E(B`@("`@("`@("`@("`@("`@('-E;&5C=#TB)&]F9FEC93IS='EL97,B
M+SX*("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P87)E
M;G13='EL94YA;64B("`@("`@("`@("`@("!S96QE8W0](D!S='EL93IN86UE
M(B\^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<&%R
M96YT4W1Y;&5&86UI;'DB("`@("`@("`@("`@<V5L96-T/2)`<W1Y;&4Z9F%M
M:6QY(B\^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M<W1Y;&4M;F%M92UT;VME;FEZ960B("`@("`@("`@<V5L96-T/2)T<F%N<VQA
M=&4H0'-T>6QE.FYA;64L("<N("4H*2]<)RP@)R<I(B\^"B`@("`@("`@("`@
M(#PO>'-L.F-A;&PM=&5M<&QA=&4^"@H@("`@("`@("`@("`\(2TM*BH@9F]R
M(&%L;"!A=71O;6%T:6,M8VAI;&1R96X@;V8@=&AE(&-U<G)E;G0@;V9F:6-E
M.G-T>6QE<R`@*BHM+3X*("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E
M(&YA;64])V9O<BUA;&PM875T;VUA=&EC+6-H:6QD+7-T>6QE<R<^"B`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y;&5S+6YO9&4B
M("`@("`@("`@("`@("`@("`@<V5L96-T/2(D;V9F:6-E.F%U=&]M871I8RUS
M='EL97,B+SX*("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)P87)E;G13='EL94YA;64B("`@("`@("`@("`@("!S96QE8W0](D!S='EL
M93IN86UE(B\^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB<&%R96YT4W1Y;&5&86UI;'DB("`@("`@("`@("`@<V5L96-T/2)`<W1Y
M;&4Z9F%M:6QY(B\^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB<W1Y;&4M;F%M92UT;VME;FEZ960B("`@("`@("`@<V5L96-T/2)T
M<F%N<VQA=&4H0'-T>6QE.FYA;64L("<N("4H*2]<)RP@)R<I(B\^"B`@("`@
M("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"@H@("`@("`@(#PO>'-L.F9O
M<BUE86-H/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@("`\>'-L.G1E;7!L
M871E(&YA;64])V9O<BUA;&PM875T;VUA=&EC+6-H:6QD+7-T>6QE<R<^"B`@
M("`@("`@/'AS;#IP87)A;2!N86UE/2)S='EL97,M;F]D92(O/@H@("`@("`@
M(#QX<VPZ<&%R86T@;F%M93TB<&%R96YT4W1Y;&5.86UE(B\^"B`@("`@("`@
M/'AS;#IP87)A;2!N86UE/2)P87)E;G13='EL949A;6EL>2(O/@H@("`@("`@
M(#QX<VPZ<&%R86T@;F%M93TB<W1Y;&4M;F%M92UT;VME;FEZ960B+SX*"B`@
M("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0](B1O9F9I8V4Z875T;VUA=&EC
M+7-T>6QE<R]S='EL93IS='EL95M`<W1Y;&4Z9F%M:6QY/21P87)E;G13='EL
M949A;6EL>2!A;F0@0'-T>6QE.G!A<F5N="US='EL92UN86UE/21P87)E;G13
M='EL94YA;65=(CX*("`@("`@("`@("`@/"$M+2HJ(&=I=F4@;W5T('1H92!S
M='EL92!P<F]P97)T:65S(&]F('1H92!C=7)R96YT(&YO9&4@*BHM+3X*("`@
M("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](GLD<W1Y;&4M;F%M92UT;VME
M;FEZ961](CX*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N
M86UE/2=W<FET92UC=7)R96YT+6%N9"UI;FAE<FET960M<W1Y;&4M<')O<&5R
M=&EE<R<^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](G-T>6QE<RUN;V1E(B`@("`@("`@("`@("`@("`@('-E;&5C=#TB)&]F
M9FEC93IA=71O;6%T:6,M<W1Y;&5S(B\^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE+69A;6EL>2(@("`@("`@("`@
M("`@("`@('-E;&5C=#TB0'-T>6QE.F9A;6EL>2(O/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL92UN86UE+71O:V5N
M:7IE9"(@("`@("`@("!S96QE8W0](G1R86YS;&%T92A`<W1Y;&4Z;F%M92P@
M)RX@)2@I+UPG+"`G)RDB+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM
M=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"@H@("`@("`@
M("`@("`\(2TM*BH@9F]R(&%L;"!A=71O;6%T:6,M8VAI;&1R96X@;V8@=&AE
M(&-U<G)E;G0@;V9F:6-E.F%U=&]M871I8RUS='EL97,@("HJ+2T^"B`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2=F;W(M86QL+6%U=&]M
M871I8RUC:&EL9"US='EL97,G/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](G-T>6QE<RUN;V1E(B`@("`@("`@("`@("`@("`@('-E
M;&5C=#TB)&]F9FEC93IA=71O;6%T:6,M<W1Y;&5S(B\^"B`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<&%R96YT4W1Y;&5.86UE(B`@
M("`@("`@("`@("`@<V5L96-T/2)`<W1Y;&4Z;F%M92(O/@H@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G!A<F5N=%-T>6QE1F%M:6QY
M(B`@("`@("`@("`@('-E;&5C=#TB0'-T>6QE.F9A;6EL>2(O/@H@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE+6YA;64M=&]K
M96YI>F5D(B`@("`@("`@('-E;&5C=#TB=')A;G-L871E*$!S='EL93IN86UE
M+"`G+B`E*"DO7"<L("<G*2(O/@H@("`@("`@("`@("`\+WAS;#IC86QL+71E
M;7!L871E/@H@("`@("`@(#PO>'-L.F9O<BUE86-H/@H@("`@/"]X<VPZ=&5M
M<&QA=&4^"@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TG=W)I=&4M8W5R<F5N
M="UA;F0M:6YH97)I=&5D+7-T>6QE+7!R;W!E<G1I97,G/@H@("`@("`@(#QX
M<VPZ<&%R86T@;F%M93TB<W1Y;&4M9F%M:6QY(B\^"B`@("`@("`@/'AS;#IP
M87)A;2!N86UE/2)S='EL97,M;F]D92(O/@H@("`@("`@(#QX<VPZ<&%R86T@
M;F%M93TB<W1Y;&4M;F%M92UT;VME;FEZ960B+SX*"B`@("`@("`@/'AS;#IE
M;&5M96YT(&YA;64](GLD<W1Y;&4M;F%M92UT;VME;FEZ961](CX*("`@("`@
M("`@("`@/'AS;#IV87)I86)L92!N86UE/2)C=7)R96YT+7-T>6QE+6YA;64B
M('-E;&5C=#TB0'-T>6QE.FYA;64B+SX*("`@("`@("`@("`@/'AS;#IV87)I
M86)L92!N86UE/2)P87)E;G0M<W1Y;&4M;F%M92(@<V5L96-T/2)`<W1Y;&4Z
M<&%R96YT+7-T>6QE+6YA;64B+SX*"B`@("`@("`@("`@(#QX<VPZ=F%R:6%B
M;&4@;F%M93TB;F5W+7!R;W!E<G1Y+6QI<W0B/@H@("`@("`@("`@("`@("`@
M/"$M+2HJ*B!#3TQ,14-4(%-464Q%($%45%))0E5415,@*&]N;'D@=&]P;&5V
M96PI("HJ*BTM/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E
M(&YA;64](G=R:71E+7-T>6QE+7!R;W!E<G1I97,B/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL94%T=')I8G5T95!A
M=&@B("`@<V5L96-T/2(D<W1Y;&5S+6YO9&4O<W1Y;&4Z<W1Y;&5;0'-T>6QE
M.F9A;6EL>3TD<W1Y;&4M9F%M:6QY(&%N9"!`<W1Y;&4Z;F%M93TD8W5R<F5N
M="US='EL92UN86UE72]S='EL93IP<F]P97)T:65S+T`J(B\^"B`@("`@("`@
M("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`\+WAS
M;#IV87)I86)L93X*("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@
M("`@("`@("`\(2TM*BHJ($!%;F0Z($=)5D4@3U54($%L;"!#3TQ,14-4140@
M4U193$4@05144DE"551%4R`H;VYL>2!T;W!L979E;"D@*BHJ+2T^"B`@("`@
M("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB<W1R:6YG+6QE;F=T:"@D<&%R
M96YT+7-T>6QE+6YA;64I/3`B/@H@("`@("`@("`@("`@("`@/"$M+2HJ(&EF
M(&YO('-T>6QE4&%R96YT(&ES(&=I=F5N+"!T:&4@<')O<&5R=&EE<R!A<F4@
M9VEV96X@;W5T(&%T(&]N8V4@*BHM+3X*("`@("`@("`@("`@("`@("`@("`\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB;F]R;6%L:7IE+7-P86-E*"1N97<M<')O
M<&5R='DM;&ES="DB+SX*("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@
M("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@
M("`@("`\>'-L.G9A<FEA8FQE(&YA;64](FYE=RUP<F]P97)T>2UN86UE<R(^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ9F]R+65A8V@@<V5L96-T
M/2(D<W1Y;&5S+6YO9&4O<W1Y;&4Z<W1Y;&5;0'-T>6QE.F9A;6EL>3TD<W1Y
M;&4M9F%M:6QY(&%N9"!`<W1Y;&4Z;F%M93TD8W5R<F5N="US='EL92UN86UE
M72]S='EL93IP<F]P97)T:65S+T`J(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)N86UE*"DB+SX*("`@("`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ=F%R:6%B;&4^"B`@("`@("`@("`@("`@("`@("`@
M/"$M+2HJ(&9U<G1H97(@871T<FEB=71E<R!O9B!T:&4@<&%R96YT('-T>6QE
M(&UU<W0@8F4@8V]L;&5C=&5D("HJ+2T^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IC86QL+71E;7!L871E(&YA;64](F%D9"UP87)E;G0M<W1Y;&4M871T
M<FEB=71E<R(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)P<F]P97)T>2UN86UE+6QI<W0B("`@("`@('-E;&5C=#TB
M)&YE=RUP<F]P97)T>2UN86UE<R(O/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]M<&QE=&4M<')O<&5R='DM;&ES
M="(@("!S96QE8W0](FYO<FUA;&EZ92US<&%C92@D;F5W+7!R;W!E<G1Y+6QI
M<W0I(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)C=7)R96YT+7-T>6QE+6YA;64B("`@("`@('-E;&5C=#TB)&-U
M<G)E;G0M<W1Y;&4M;F%M92(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB<&%R96YT+7-T>6QE+6YA;64B("`@("`@
M("!S96QE8W0](B1P87)E;G0M<W1Y;&4M;F%M92(O/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y;&4M9F%M:6QY
M(B`@("`@("`@("`@("!S96QE8W0](B1S='EL92UF86UI;'DB+SX*("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@
M("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`\+WAS;#IC:&]O
M<V4^"B`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@(#PO>'-L.G1E;7!L871E
M/@H*"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)A9&0M<&%R96YT+7-T>6QE
M+6%T=')I8G5T97,B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB<')O<&5R
M='DM;F%M92UL:7-T(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VUP
M;&5T92UP<F]P97)T>2UL:7-T(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE
M/2)C=7)R96YT+7-T>6QE+6YA;64B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA
M;64](G!A<F5N="US='EL92UN86UE(B\^"B`@("`@("`@/'AS;#IP87)A;2!N
M86UE/2)S='EL92UF86UI;'DB+SX*"B`@("`@("`@/"$M+2HJ*B!.97<@='=O
M(&)E(&%D9&5D('!R;W!E<G1Y(&YA;65S('=I;&P@8F4@8V]L;&5C=&5D("AO
M;FQY(&]N92!V87)I86)L92!P97(@=&5M<&QA=&4I("HJ*BTM/@H@("`@("`@
M(#QX<VPZ=F%R:6%B;&4@;F%M93TB;F5W+7!R;W!E<G1Y+6YA;65S(CX*("`@
M("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F=E="UN97<M<W1Y
M;&4M;F%M97,B/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](G!R;W!E<G1Y+6YA;64M;&ES="(@("`@("`@<V5L96-T/2(D<')O<&5R
M='DM;F%M92UL:7-T(B\^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB<&%R96YT+7-T>6QE+6YA;64B("`@("`@("!S96QE8W0](B1P
M87)E;G0M<W1Y;&4M;F%M92(O/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](F-U<G)E;G0M<W1Y;&4M;F%M92(@("`@("`@<V5L96-T
M/2(D8W5R<F5N="US='EL92UN86UE(B\^"B`@("`@("`@("`@(#PO>'-L.F-A
M;&PM=&5M<&QA=&4^"B`@("`@("`@/"]X<VPZ=F%R:6%B;&4^"@H@("`@("`@
M(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\(2TM*BHJ(&-H96-K(&EF('1H
M92!N97<@<&%R96YT('-T>6QE(&5X:7-T(&EN('1H92!O9F9I8V4Z875T;VUA
M=&EC+7-T>6QE<R!S96-T:6]N("AD969I;F5D(&)Y(&YA;64@86YD(&9A;6EL
M>2D@*BHJ+2T^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;V9F:6-E
M.F%U=&]M871I8RUS='EL97,O<W1Y;&4Z<W1Y;&5;0'-T>6QE.F9A;6EL>3TG
M<&%R86=R87!H)R!A;F0@0'-T>6QE.FYA;64])&-U<G)E;G0M<W1Y;&4M;F%M
M95TB/@H@("`@("`@("`@("`@("`@/"$M+2HJ*B!214-54E-)3TXZ(&%D9&EN
M9R!N97<@<&%R96YT('-T>6QE(&%T=')I8G5T97,@=&\@=&AE(&-U<G)E;G0@
M<W1Y;&4@*BHJ+2T^"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA
M;64](FYE=RUP<F]P97)T>2UA='1R:6)U=&5S(CX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB9V5T+6YE=RUS='EL92UA
M='1R:6)U=&5S(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](FYE=RUP<F]P97)T>2UN86UE<R(@("`@("`@("`@('-E
M;&5C=#TB)&YE=RUP<F]P97)T>2UN86UE<R(O/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8W5R<F5N="US='EL92UN
M86UE(B`@("`@("`@("`@<V5L96-T/2(D8W5R<F5N="US='EL92UN86UE(B\^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)P87)E;G0M<W1Y;&4M;F%M92(@("`@("`@("`@("!S96QE8W0](B1P87)E
M;G0M<W1Y;&4M;F%M92(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A
M;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`\+WAS;#IV87)I86)L93X*
M("`@("`@("`@("`@("`@(#PA+2TJ*BH@16YD($-/3D1)5$E/3CH@=&AE(&QA
M<W0@<W1Y;&4@<&%R96YT(&AA<R!A;')E861Y(&)E96X@97AE8W5T960@*BHJ
M+2T^"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](FYE=RUP
M87)E;G0M<W1Y;&4M;F%M92(@('-E;&5C=#TB)&]F9FEC93IA=71O;6%T:6,M
M<W1Y;&5S+W-T>6QE.G-T>6QE6T!S='EL93IF86UI;'D])W!A<F%G<F%P:"<@
M86YD($!S='EL93IN86UE/21P87)E;G0M<W1Y;&4M;F%M95TO0'-T>6QE.G!A
M<F5N="US='EL92UN86UE(B\^"B`@("`@("`@("`@("`@("`\>'-L.F-H;V]S
M93X*("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB<W1R:6YG
M+6QE;F=T:"@D;F5W+7!A<F5N="US='EL92UN86UE*3TP(CX*("`@("`@("`@
M("`@("`@("`@("`\(2TM*BH@;F\@9G5R=&AE<B!P87)E;G0@:7,@9F]U;F0L
M('1H92!G:79E;B!P87)A;65T97(@<')O<&5R='DM;F]D92!I<R!T:&4@9FEN
M86P@<W1Y;&4@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2)C;VYC870H)&-O;7!L971E+7!R;W!E<G1Y+6QI<W0L
M)&YE=RUP<F]P97)T>2UA='1R:6)U=&5S*2(O/@H@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE
M<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@/"$M+2HJ(&9U<G1H97(@871T
M<FEB=71E<R!O9B!T:&4@<&%R96YT('-T>6QE(&UU<W0@8F4@8V]L;&5C=&5D
M("HJ+2T^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP
M;&%T92!N86UE/2)A9&0M<&%R96YT+7-T>6QE+6%T=')I8G5T97,B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(G!R;W!E<G1Y+6YA;64M;&ES="(@("`@("`@<V5L96-T/2)C;VYC870H)'!R
M;W!E<G1Y+6YA;64M;&ES="P@)&YE=RUP<F]P97)T>2UN86UE<RDB+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)C;VUP;&5T92UP<F]P97)T>2UL:7-T(B`@('-E;&5C=#TB8V]N8V%T*"1C
M;VUP;&5T92UP<F]P97)T>2UL:7-T+"1N97<M<')O<&5R='DM871T<FEB=71E
M<RDB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)C=7)R96YT+7-T>6QE+6YA;64B("`@("`@('-E;&5C=#TB
M)'!A<F5N="US='EL92UN86UE(B\^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<&%R96YT+7-T>6QE+6YA;64B
M("`@("`@("!S96QE8W0](B1N97<M<&%R96YT+7-T>6QE+6YA;64B+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)S='EL92UF86UI;'DB("`@("`@("`@("`@('-E;&5C=#TB)'-T>6QE+69A
M;6EL>2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E
M;7!L871E/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*
M("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@/"]X
M<VPZ=VAE;CX*"B`@("`@("`@("`@(#PA+2TJ*B!T:&4@<W!E8VEF:6,@<W1Y
M;&4@*&1E9FEN960@8GD@;F%M92!A;F0@9F%M:6QY*2!M=7-T(&)E(&9O=6YD
M(&EN('1H92!O9F9I8V4Z<W1Y;&5S('-E8W1I;VX@+2T^"B`@("`@("`@("`@
M(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/"$M+2HJ*B!214-5
M4E-)3TXZ(&%D9&EN9R!N97<@<&%R96YT('-T>6QE(&%T=')I8G5T97,@=&\@
M=&AE(&-U<G)E;G0@<W1Y;&4@*BHJ+2T^"B`@("`@("`@("`@("`@("`\(2TM
M*BHJ(&%D9&EN9R!N97<@<&%R96YT('-T>6QE(&%T=')I8G5T97,@=&\@=&AE
M(&-U<G)E;G0@<W1Y;&4@*BHJ+2T^"B`@("`@("`@("`@("`@("`\>'-L.G9A
M<FEA8FQE(&YA;64](FYE=RUP<F]P97)T>2UA='1R:6)U=&5S(CX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB9V5T+6YE
M=RUS='EL92UA='1R:6)U=&5S(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](FYE=RUP<F]P97)T>2UN86UE<R(@("`@
M("`@("`@('-E;&5C=#TB)&YE=RUP<F]P97)T>2UN86UE<R(O/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8W5R<F5N
M="US='EL92UN86UE(B`@("`@("`@("`@<V5L96-T/2(D8W5R<F5N="US='EL
M92UN86UE(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)P87)E;G0M<W1Y;&4M;F%M92(@("`@("`@("`@("!S96QE
M8W0](B1P87)E;G0M<W1Y;&4M;F%M92(O/@H@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`\+WAS;#IV
M87)I86)L93X*("`@("`@("`@("`@("`@(#PA+2TJ*BH@16YD($-/3D1)5$E/
M3CH@=&AE(&QA<W0@<W1Y;&4@<&%R96YT(&AA<R!A;')E861Y(&)E96X@97AE
M8W5T960@*BHJ+2T^"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA
M;64](FYE=RUP87)E;G0M<W1Y;&4M;F%M92(@('-E;&5C=#TB)&]F9FEC93IS
M='EL97,O<W1Y;&4Z<W1Y;&5;0'-T>6QE.F9A;6EL>3TG<&%R86=R87!H)R!A
M;F0@0'-T>6QE.FYA;64])'!A<F5N="US='EL92UN86UE72]`<W1Y;&4Z<&%R
M96YT+7-T>6QE+6YA;64B+SX*("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)S=')I;F<M
M;&5N9W1H*"1N97<M<&%R96YT+7-T>6QE+6YA;64I/3`B/@H@("`@("`@("`@
M("`@("`@("`@(#PA+2TJ*B!N;R!F=7)T:&5R('!A<F5N="!I<R!F;W5N9"P@
M=&AE(&=I=F5N('!A<F%M971E<B!P<F]P97)T>2UN;V1E(&ES('1H92!F:6YA
M;"!S='EL92`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU
M92UO9B!S96QE8W0](F-O;F-A="@D8V]M<&QE=&4M<')O<&5R='DM;&ES="PD
M;F5W+7!R;W!E<G1Y+6%T=')I8G5T97,I(B\^"B`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R
M=VES93X*("`@("`@("`@("`@("`@("`@("`\(2TM*BH@9G5R=&AE<B!A='1R
M:6)U=&5S(&]F('1H92!P87)E;G0@<W1Y;&4@;75S="!B92!C;VQL96-T960@
M*BH@("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M
M<&QA=&4@;F%M93TB861D+7!A<F5N="US='EL92UA='1R:6)U=&5S(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)P<F]P97)T>2UN86UE+6QI<W0B("`@("`@('-E;&5C=#TB8V]N8V%T*"1P
M<F]P97)T>2UN86UE+6QI<W0L("1N97<M<')O<&5R='DM;F%M97,I(B\^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB8V]M<&QE=&4M<')O<&5R='DM;&ES="(@("!S96QE8W0](F-O;F-A="@D
M8V]M<&QE=&4M<')O<&5R='DM;&ES="PD;F5W+7!R;W!E<G1Y+6%T=')I8G5T
M97,I(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB8W5R<F5N="US='EL92UN86UE(B`@("`@("!S96QE8W0]
M(B1P87)E;G0M<W1Y;&4M;F%M92(O/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G!A<F5N="US='EL92UN86UE
M(B`@("`@("`@<V5L96-T/2(D;F5W+7!A<F5N="US='EL92UN86UE(B\^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB<W1Y;&4M9F%M:6QY(B`@("`@("`@("`@("!S96QE8W0](B1S='EL92UF
M86UI;'DB+SX*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT
M96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^
M"B`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@(#PO
M>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS
M;#IT96UP;&%T93X*"@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB9V5T+6YE
M=RUS='EL92UN86UE<R(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)P<F]P
M97)T>2UN86UE+6QI<W0B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G!A
M<F5N="US='EL92UN86UE(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C
M=7)R96YT+7-T>6QE+6YA;64B+SX*("`@("`@("`\(2TM*BH@=VAE<F4@=&\@
M9FEN9"!T:&4@<W!E8VEF:6,@<W1Y;&4@*&1E9FEN960@8GD@;F%M92!A;F0@
M9F%M:6QY*2!W:&5T97(@:6X@;V9F:6-E.F%U=&]M871I8RUS='EL97,@;W(@
M;V9F:6-E.G-T>6QE<R!S96-T:6]N("TM/@H@("`@("`@(#QX<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`\(2TM*BH@:68@=&AE('-P96-I9FEC('-T>6QE("AD
M969I;F5D(&)Y(&YA;64@86YD(&9A;6EL>2D@8V%N(&)E(&9O=6YD(&EN('1H
M92!O9F9I8V4Z875T;VUA=&EC+7-T>6QE<R!S96-T:6]N("TM/@H@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB)&]F9FEC93IA=71O;6%T:6,M<W1Y;&5S
M+W-T>6QE.G-T>6QE6T!S='EL93IF86UI;'D])W!A<F%G<F%P:"<@86YD($!S
M='EL93IN86UE/21P87)E;G0M<W1Y;&4M;F%M95TB/@H@("`@("`@("`@("`@
M("`@/'AS;#IV87)I86)L92!N86UE/2)P87)E;G0M<')O<&5R='DM;F]D92(@
M<V5L96-T/2(D;V9F:6-E.F%U=&]M871I8RUS='EL97,O<W1Y;&4Z<W1Y;&5;
M0'-T>6QE.F9A;6EL>3TG<&%R86=R87!H)R!A;F0@0'-T>6QE.FYA;64])'!A
M<F5N="US='EL92UN86UE72]S='EL93IP<F]P97)T:65S(B\^"@H@("`@("`@
M("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)N97<M<')O<&5R='DM;F%M
M92UL:7-T(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F9O<BUE86-H('-E
M;&5C=#TB)'!A<F5N="UP<F]P97)T>2UN;V1E+T`J6VYO="AC;VYT86EN<R@D
M<')O<&5R='DM;F%M92UL:7-T+"!N86UE*"DI*5TB/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB;F%M92@I(B\^"B`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@("`@("`@("`@
M("`@("`\+WAS;#IV87)I86)L93X*("`@("`@("`@("`@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2(D;F5W+7!R;W!E<G1Y+6YA;64M;&ES="(O/@H@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\(2TM*BH@=&AE('-P
M96-I9FEC('-T>6QE("AD969I;F5D(&)Y(&YA;64@86YD(&9A;6EL>2D@<VAO
M=6QD(&)E(&9O=6YD(&EN('1H92!O9F9I8V4Z<W1Y;&5S('-E8W1I;VX@+2T^
M"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@
M/'AS;#IV87)I86)L92!N86UE/2)P87)E;G0M<')O<&5R='DM;F]D92(@<V5L
M96-T/2(D;V9F:6-E.G-T>6QE<R]S='EL93IS='EL95M`<W1Y;&4Z9F%M:6QY
M/2=P87)A9W)A<&@G(&%N9"!`<W1Y;&4Z;F%M93TD<&%R96YT+7-T>6QE+6YA
M;65=+W-T>6QE.G!R;W!E<G1I97,B+SX*("`@("`@("`@("`@("`@(#QX<VPZ
M=F%R:6%B;&4@;F%M93TB;F5W+7!R;W!E<G1Y+6YA;64M;&ES="(^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0](B1P87)E;G0M
M<')O<&5R='DM;F]D92]`*EMN;W0H8V]N=&%I;G,H)'!R;W!E<G1Y+6YA;64M
M;&ES="P@;F%M92@I*2E=(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IV86QU92UO9B!S96QE8W0](FYA;64H*2(O/@H@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F9O<BUE86-H/@H@("`@("`@("`@("`@("`@/"]X<VPZ=F%R
M:6%B;&4^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M)&YE=RUP<F]P97)T>2UN86UE+6QI<W0B+SX*("`@("`@("`@("`@/"]X<VPZ
M;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E
M;7!L871E/@H*"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)G970M;F5W+7-T
M>6QE+6%T=')I8G5T97,B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB;F5W
M+7!R;W!E<G1Y+6YA;65S(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C
M=7)R96YT+7-T>6QE+6YA;64B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64]
M(G!A<F5N="US='EL92UN86UE(B\^"@H@("`@("`@(#PA+2TJ*B!W:&5R92!T
M;R!F:6YD('1H92!S<&5C:69I8R!S='EL92`H9&5F:6YE9"!B>2!N86UE(&%N
M9"!F86UI;'DI('=H971H97(@:6X@;V9F:6-E.F%U=&]M871I8RUS='EL97,@
M;W(@;V9F:6-E.G-T>6QE<R!S96-T:6]N("TM/@H@("`@("`@(#QX<VPZ8VAO
M;W-E/@H@("`@("`@("`@("`\(2TM*BH@:68@=&AE('-P96-I9FEC('-T>6QE
M("AD969I;F5D(&)Y(&YA;64@86YD(&9A;6EL>2D@8V%N(&)E(&9O=6YD(&EN
M('1H92!O9F9I8V4Z875T;VUA=&EC+7-T>6QE<R!S96-T:6]N("TM/@H@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&]F9FEC93IA=71O;6%T:6,M<W1Y
M;&5S+W-T>6QE.G-T>6QE6T!S='EL93IF86UI;'D])W!A<F%G<F%P:"<@86YD
M($!S='EL93IN86UE/21P87)E;G0M<W1Y;&4M;F%M95TB/@H@("`@("`@("`@
M("`@("`@/'AS;#IV87)I86)L92!N86UE/2)P87)E;G0M<')O<&5R='DM;F]D
M92(@<V5L96-T/2(D;V9F:6-E.F%U=&]M871I8RUS='EL97,O<W1Y;&4Z<W1Y
M;&5;0'-T>6QE.F9A;6EL>3TG<&%R86=R87!H)R!A;F0@0'-T>6QE.FYA;64]
M)'!A<F5N="US='EL92UN86UE72]S='EL93IP<F]P97)T:65S(B\^"B`@("`@
M("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](FYE=RUP<F]P97)T>2UN
M86UE+6QI<W0B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP
M;&%T92!N86UE/2)W<FET92US='EL92UP<F]P97)T:65S(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE071T
M<FEB=71E4&%T:"(@("!S96QE8W0](B1P87)E;G0M<')O<&5R='DM;F]D92]`
M*EMC;VYT86EN<R@D;F5W+7!R;W!E<G1Y+6YA;65S+"!N86UE*"DI72(O/@H@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@
M("`@("`@("`@("`\+WAS;#IV87)I86)L93X*("`@("`@("`@("`@("`@(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2)N;W)M86QI>F4M<W!A8V4H)&YE=RUP<F]P
M97)T>2UN86UE+6QI<W0I(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@
M("`@("`@("`@(#PA+2TJ*B!O=&AE<G=I<V4@=&AE('-P96-I9FEC('-T>6QE
M("AD969I;F5D(&)Y(&YA;64@86YD(&9A;6EL>2D@<VAO=6QD(&)E(&9O=6YD
M(&EN('1H92!O9F9I8V4Z<W1Y;&5S('-E8W1I;VX@+2T^"B`@("`@("`@("`@
M(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/'AS;#IV87)I86)L
M92!N86UE/2)P87)E;G0M<')O<&5R='DM;F]D92(@<V5L96-T/2(D;V9F:6-E
M.G-T>6QE<R]S='EL93IS='EL95M`<W1Y;&4Z9F%M:6QY/2=P87)A9W)A<&@G
M(&%N9"!`<W1Y;&4Z;F%M93TD<&%R96YT+7-T>6QE+6YA;65=+W-T>6QE.G!R
M;W!E<G1I97,B+SX*("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M
M93TB;F5W+7!R;W!E<G1Y+6YA;64M;&ES="(^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G=R:71E+7-T>6QE+7!R;W!E
M<G1I97,B/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB<W1Y;&5!='1R:6)U=&50871H(B`@('-E;&5C=#TB)'!A<F5N
M="UP<F]P97)T>2UN;V1E+T`J6V-O;G1A:6YS*"1N97<M<')O<&5R='DM;F%M
M97,L(&YA;64H*2E=(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L
M;"UT96UP;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L.G9A<FEA8FQE/@H@
M("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](FYO<FUA;&EZ
M92US<&%C92@D;F5W+7!R;W!E<G1Y+6YA;64M;&ES="DB+SX*("`@("`@("`@
M("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@
M(#PO>'-L.G1E;7!L871E/@H*"CPO>'-L.G-T>6QE<VAE970^"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O34E-12]6:65W97(O;V]O+W1A8FQE7V-O;'5M;G,N>'-L
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,C0V-#4@,3`U,34T,S,W,S8@,#(U-3(W`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#PA+2T*
M"B`@(%1H92!#;VYT96YT<R!O9B!T:&ES(&9I;&4@87)E(&UA9&4@879A:6QA
M8FQE('-U8FIE8W0@=&\@=&AE('1E<FUS(&]F"B`@(&5I=&AE<B!O9B!T:&4@
M9F]L;&]W:6YG(&QI8V5N<V5S"@H@("`@("`@("`@+2!'3E4@3&5S<V5R($=E
M;F5R86P@4'5B;&EC($QI8V5N<V4@5F5R<VEO;B`R+C$*("`@("`@("`@("T@
M4W5N($EN9'5S=')Y(%-T86YD87)D<R!3;W5R8V4@3&EC96YS92!697)S:6]N
M(#$N,0H*("`@4W5N($UI8W)O<WES=&5M<R!);F,N+"!/8W1O8F5R+"`R,#`P
M"@H@("!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N<V4@5F5R<VEO
M;B`R+C$*("`@/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]"B`@($-O<'ER:6=H="`R,#`P(&)Y(%-U;B!-:6-R;W-Y<W1E
M;7,L($EN8RX*("`@.3`Q(%-A;B!!;G1O;FEO(%)O860L(%!A;&\@06QT;RP@
M0T$@.30S,#,L(%5300H*("`@5&AI<R!L:6)R87)Y(&ES(&9R964@<V]F='=A
M<F4[('EO=2!C86X@<F5D:7-T<FEB=71E(&ET(&%N9"]O<@H@("!M;V1I9GD@
M:70@=6YD97(@=&AE('1E<FUS(&]F('1H92!'3E4@3&5S<V5R($=E;F5R86P@
M4'5B;&EC"B`@($QI8V5N<V4@=F5R<VEO;B`R+C$L(&%S('!U8FQI<VAE9"!B
M>2!T:&4@1G)E92!3;V9T=V%R92!&;W5N9&%T:6]N+@H*("`@5&AI<R!L:6)R
M87)Y(&ES(&1I<W1R:6)U=&5D(&EN('1H92!H;W!E('1H870@:70@=VEL;"!B
M92!U<V5F=6PL"B`@(&)U="!7251(3U54($%.62!705)204Y463L@=VET:&]U
M="!E=F5N('1H92!I;7!L:65D('=A<G)A;G1Y(&]F"B`@($U%4D-(04Y404))
M3$E462!O<B!&251.15-3($9/4B!!(%!!4E1)0U5,05(@4%524$]312X@(%-E
M92!T:&4@1TY5"B`@($QE<W-E<B!'96YE<F%L(%!U8FQI8R!,:6-E;G-E(&9O
M<B!M;W)E(&1E=&%I;',N"@H@("!9;W4@<VAO=6QD(&AA=F4@<F5C96EV960@
M82!C;W!Y(&]F('1H92!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC"B`@($QI
M8V5N<V4@86QO;F<@=VET:"!T:&ES(&QI8G)A<GD[(&EF(&YO="P@=W)I=&4@
M=&\@=&AE($9R964@4V]F='=A<F4*("`@1F]U;F1A=&EO;BP@26YC+BP@-3D@
M5&5M<&QE(%!L86-E+"!3=6ET92`S,S`L($)O<W1O;BP*("`@34$@(#`R,3$Q
M+3$S,#<@(%5300H*"B`@(%-U;B!);F1U<W1R>2!3=&%N9&%R9',@4V]U<F-E
M($QI8V5N<V4@5F5R<VEO;B`Q+C$*("`@/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@("!4:&4@8V]N=&5N=',@
M;V8@=&AI<R!F:6QE(&%R92!S=6)J96-T('1O('1H92!3=6X@26YD=7-T<GD@
M4W1A;F1A<F1S"B`@(%-O=7)C92!,:6-E;G-E(%9E<G-I;VX@,2XQ("AT:&4@
M(DQI8V5N<V4B*3L@66]U(&UA>2!N;W0@=7-E('1H:7,@9FEL90H@("!E>&-E
M<'0@:6X@8V]M<&QI86YC92!W:71H('1H92!,:6-E;G-E+B!9;W4@;6%Y(&]B
M=&%I;B!A(&-O<'D@;V8@=&AE"B`@($QI8V5N<V4@870@:'1T<#HO+W=W=RYO
M<&5N;V9F:6-E+F]R9R]L:6-E;G-E+FAT;6PN"@H@("!3;V9T=V%R92!P<F]V
M:61E9"!U;F1E<B!T:&ES($QI8V5N<V4@:7,@<')O=FED960@;VX@86X@(D%3
M($E3(B!B87-I<RP*("`@5TE42$]55"!705)204Y462!/1B!!3ED@2TE.1"P@
M14E42$52($584%)%4U,@3U(@24U03$E%1"P@24Y#3%5$24Y'+`H@("!7251(
M3U54($Q)34E4051)3TXL(%=!4E)!3E1)15,@5$A!5"!42$4@4T]&5%=!4D4@
M25,@1E)%12!/1B!$149%0U13+`H@("!-15)#2$%.5$%"3$4L($9)5"!&3U(@
M02!005)424-53$%2(%!54E!/4T4L($]2($Y/3BU)3D9224Y'24Y'+@H@("!3
M964@=&AE($QI8V5N<V4@9F]R('1H92!S<&5C:69I8R!P<F]V:7-I;VYS(&=O
M=F5R;FEN9R!Y;W5R(')I9VAT<R!A;F0*("`@;V)L:6=A=&EO;G,@8V]N8V5R
M;FEN9R!T:&4@4V]F='=A<F4N"@H@("!4:&4@26YI=&EA;"!$979E;&]P97(@
M;V8@=&AE($]R:6=I;F%L($-O9&4@:7,Z(%-U;B!-:6-R;W-Y<W1E;7,L($EN
M8RX*"B`@($-O<'ER:6=H="#"J2`R,#`R(&)Y(%-U;B!-:6-R;W-Y<W1E;7,L
M($EN8RX*"B`@($%L;"!2:6=H=',@4F5S97)V960N"@H@("!#;VYT<FEB=71O
M<BAS*3H@7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?
M"@HM+3X*/'AS;#IS='EL97-H965T('9E<G-I;VX](C$N,"(*("`@("`@("`@
M("`@("`@('AM;&YS.GAS;#TB:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]84TPO
M5')A;G-F;W)M(@H@("`@("`@("`@("`@("`@>&UL;G,Z;V9F:6-E/2)H='1P
M.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]O9F9I8V4B"B`@("`@("`@("`@("`@
M("!X;6QN<SIS='EL93TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O<W1Y
M;&4B"B`@("`@("`@("`@("`@("!X;6QN<SIT97AT/2)H='1P.B\O;W!E;F]F
M9FEC92YO<F<O,C`P,"]T97AT(@H@("`@("`@("`@("`@("`@>&UL;G,Z=&%B
M;&4](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W1A8FQE(@H@("`@("`@
M("`@("`@("`@>&UL;G,Z9')A=STB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P
M,#`O9')A=VEN9R(*("`@("`@("`@("`@("`@('AM;&YS.F9O/2)H='1P.B\O
M=W=W+G<S+F]R9R\Q.3DY+UA33"]&;W)M870B"B`@("`@("`@("`@("`@("!X
M;6QN<SIX;&EN:STB:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]X;&EN:R(*("`@
M("`@("`@("`@("`@('AM;&YS.FYU;6)E<CTB:'1T<#HO+V]P96YO9F9I8V4N
M;W)G+S(P,#`O9&%T87-T>6QE(@H@("`@("`@("`@("`@("`@>&UL;G,Z<W9G
M/2)H='1P.B\O=W=W+G<S+F]R9R\R,#`P+W-V9R(*("`@("`@("`@("`@("`@
M('AM;&YS.F-H87)T/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]C:&%R
M="(*("`@("`@("`@("`@("`@('AM;&YS.F1R,V0](FAT='`Z+R]O<&5N;V9F
M:6-E+F]R9R\R,#`P+V1R,V0B"B`@("`@("`@("`@("`@("!X;6QN<SIM871H
M/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DX+TUA=&@O36%T:$U,(@H@("`@("`@
M("`@("`@("`@>&UL;G,Z9F]R;3TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P
M,#`O9F]R;2(*("`@("`@("`@("`@("`@('AM;&YS.G-C<FEP=#TB:'1T<#HO
M+V]P96YO9F9I8V4N;W)G+S(P,#`O<V-R:7!T(@H@("`@("`@("`@("`@("`@
M;V9F:6-E.F-L87-S/2)T97AT(@H@("`@("`@("`@("`@("`@;V9F:6-E.G9E
M<G-I;VX](C$N,"(*("`@("`@("`@("`@("`@('AM;&YS.F1C/2)H='1P.B\O
M<'5R;"YO<F<O9&,O96QE;65N=',O,2XQ+R(*("`@("`@("`@("`@("`@('AM
M;&YS.FUE=&$](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+VUE=&$B"B`@
M("`@("`@("`@("`@("!X;6QN<SIC;VYF:6<](FAT='`Z+R]O<&5N;V9F:6-E
M+F]R9R\R,#`Q+V-O;F9I9R(*("`@("`@("`@("`@("`@('AM;&YS.FAE;'`]
M(FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+VAE;'`B"B`@("`@("`@("`@
M("`@("!X;6QN<SIX=#TB:'1T<#HO+W=W=RYJ8VQA<FLN8V]M+WAT(@H@("`@
M("`@("`@("`@("`@>&UL;G,Z<WES=&5M/2)H='1P.B\O=W=W+FIC;&%R:RYC
M;VTO>'0O:F%V82]J879A+FQA;F<N4WES=&5M(@H@("`@("`@("`@("`@("`@
M>&UL;G,Z>&%L86X](FAT='`Z+R]X;6PN87!A8VAE+F]R9R]X86QA;B(*("`@
M("`@("`@("`@("`@('AM;&YS.FIA=F$](FAT='`Z+R]X;6PN87!A8VAE+F]R
M9R]X<VQT+VIA=F$B"B`@("`@("`@("`@("`@("!E>&-L=61E+7)E<W5L="UP
M<F5F:7AE<STB:F%V82(^"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B!#
M<F5A=&4@=&%B;&4@8V]L=6UN<R!S='EL92!V87)I86)L92`@*BHJ("TM/@H@
M("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*B`M+3X*"B`@("`\>'-L.G1E;7!L871E(&YA;64](F%D9&EN9RUC
M;VQU;6XM<W1Y;&5S+65N=')I97,B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M
M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@(#QX<VPZ<&%R86T@
M;F%M93TB86QL5&%B;&5#;VQU;6YS(B\^"@H@("`@("`@(#QX<VPZ9F]R+65A
M8V@@<V5L96-T/2(D86QL5&%B;&5#;VQU;6YS(CX*"B`@("`@("`@("`@(#QX
M<VPZ=F%R:6%B;&4@;F%M93TB8V]L=6UN+7-T>6QE+65N=')Y(B!S96QE8W0]
M(B1C;VQL96-T961';&]B86Q$871A+V%L;'-T>6QE<R\J6VYA;64H*2`]('1R
M86YS;&%T92AC=7)R96YT*"DO0'1A8FQE.G-T>6QE+6YA;64L("<N("4H*2]<
M)RP@)R<I72(O/@H@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@
M("`@("`@(#QX<VPZ=VAE;B!T97-T/2)N;W0H0'1A8FQE.FYU;6)E<BUC;VQU
M;6YS+7)E<&5A=&5D*2(^"B`@("`@("`@("`@("`@("`@("`@/"$M+2!W<FET
M97,@86X@96YT<GD@;V8@82!C;VQU;6X@:6X@=&AE(&-O;'5M;G,M=F%R:6%B
M;&4@+2T^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E
M(&YA;64](F%D9&EN9RUC;VQU;6XM<W1Y;&4M96YT<GDB/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L=6UN+7-T
M>6QE+65N=')Y(B!S96QE8W0](B1C;VQU;6XM<W1Y;&4M96YT<GDB+SX*("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@(#PA+2T@3F\@
M:&EG:&5R(')E<&5T:71I;VX@;V8@8V5L;',@9W)E871E<B!T:&%N(#0@9F]R
M('1H92!L87-T(&%N9"!S96-O;F0@;&%S="!C;VQU;6X@+2T^"B`@("`@("`@
M("`@("`@("`\(2TM(&$@:&%C:R!F;W(@=&AE('-A;7!L92!D;V-U;65N="`G
M5V%E:')U;F=S=6UR96-H;F5R+G-X8R!H879I;F<@,C,P(')E<&5A=&5D(&-O
M;'5M;G,@:6X@=&AE('-E8V]N9"!L87-T(&-O;'5M;B`M+3X*("`@("`@("`@
M("`@("`@(#PA+2T@/S\_(#QX<VPZ=VAE;B!T97-T/2(H<&]S:71I;VXH*2`]
M(&QA<W0H*2!O<B`H<&]S:71I;VXH*2`]("AL87-T*"D@+2`Q*2D@86YD($!T
M86)L93IN=6UB97(M8V]L=6UN<RUR97!E871E9"`F;'0[(#4I(CX@/S\_+2T^
M"B`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB<&]S:71I;VXH*2`]
M(&QA<W0H*2!O<B!P;W-I=&EO;B@I(#T@*&QA<W0H*2`M(#$I(CX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](D!T86)L93IN=6UB97(M8V]L
M=6UN<RUR97!E871E9"`F;'0[(#4B/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\(2TM('=R:71E<R!A;B!E;G1R>2!O9B!A(&-O;'5M;B!I;B!T:&4@8V]L
M=6UN<RUV87)I86)L92`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IC86QL+71E;7!L871E(&YA;64](G)E<&5A="UA9&1I;F<M8V]L=6UN+7-T
M>6QE+65N=')Y(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)C;VQU;6XM<W1Y;&4M96YT<GDB("`@("`@('-E
M;&5C=#TB)&-O;'5M;BUS='EL92UE;G1R>2(O/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FYU;6)E<BUC;VQU
M;6YS+7)E<&5A=&5D(B`@<V5L96-T/2(Q(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ:68^"B`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@
M("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@
M("`@/"$M+2!R97!E871E9"!C;VQU;7,@=VEL;"!B92!W<FET=&5N(&5X<&QI
M8VET('-E=F5R86P@=&EM97,@:6X@=&AE('9A<FEA8FQE+2T^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G)E<&5A="UA
M9&1I;F<M8V]L=6UN+7-T>6QE+65N=')Y(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;'5M;BUS='EL92UE;G1R
M>2(@("`@("`@("`@('-E;&5C=#TB)&-O;'5M;BUS='EL92UE;G1R>2(O/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M;G5M8F5R+6-O;'5M;G,M<F5P96%T960B("`@("`@<V5L96-T/2)`=&%B;&4Z
M;G5M8F5R+6-O;'5M;G,M<F5P96%T960B+SX*("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@/"]X<VPZ
M;W1H97)W:7-E/@H@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@
M/"]X<VPZ9F]R+65A8V@^"B`@("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#PA
M+2T@5U))5$53(%1(12!215!%051%1"!#3TQ534X@4U193$4@15A03$E#250@
M05,@04X@14Q%345.5"!)3B!42$4@0T],54U.4RU605))04),12`M+3X*("`@
M(#QX<VPZ=&5M<&QA=&4@;F%M93TB<F5P96%T+6%D9&EN9RUC;VQU;6XM<W1Y
M;&4M96YT<GDB/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L=6UN+7-T
M>6QE+65N=')Y(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)N=6UB97(M
M8V]L=6UN<RUR97!E871E9"(O/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1N=6UB97(M8V]L=6UN<RUR97!E
M871E9"`^(#$B/@H@("`@("`@("`@("`@("`@/"$M+2!W<FET97,@86X@96YT
M<GD@;V8@82!C;VQU;6X@:6X@=&AE(&-O;'5M;G,M=F%R:6%B;&4@+2T^"B`@
M("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB861D:6YG
M+6-O;'5M;BUS='EL92UE;G1R>2(^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F-O;'5M;BUS='EL92UE;G1R>2(@("!S96QE
M8W0](B1C;VQU;6XM<W1Y;&4M96YT<GDB+SX*("`@("`@("`@("`@("`@(#PO
M>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`\(2TM(')E<&5A
M="!C86QL:6YG('1H:7,@;65T:&]D('5N=&EL(&%L;"!E;&5M96YT<R!W<FET
M=&5N(&]U="`M+3X*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T
M92!N86UE/2)R97!E870M861D:6YG+6-O;'5M;BUS='EL92UE;G1R>2(^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;'5M
M;BUS='EL92UE;G1R>2(@("`@("`@<V5L96-T/2(D8V]L=6UN+7-T>6QE+65N
M=')Y(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](FYU;6)E<BUC;VQU;6YS+7)E<&5A=&5D(B`@<V5L96-T/2(D;G5M8F5R
M+6-O;'5M;G,M<F5P96%T960@+2`Q(B\^"B`@("`@("`@("`@("`@("`\+WAS
M;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@
M("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#PA+2T@
M=W)I=&5S(&%N(&5N=')Y(&]F(&$@8V]L=6UN(&EN('1H92!C;VQU;6YS+79A
M<FEA8FQE("TM/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E
M(&YA;64](F%D9&EN9RUC;VQU;6XM<W1Y;&4M96YT<GDB/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQU;6XM<W1Y;&4M
M96YT<GDB("`@<V5L96-T/2(D8V]L=6UN+7-T>6QE+65N=')Y(B\^"B`@("`@
M("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`\
M+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X
M<VPZ=&5M<&QA=&4^"@H*("`@(#PA+2T@5$A%($-/3%5-3BU35%E,12!74DE4
M12U0051415).($9/4B!%04-(($-/3%5-3B!74DE45$5.($E.($$@5D%224%"
M3$4@+2T^"B`@("`\>'-L.G1E;7!L871E(&YA;64](F%D9&EN9RUC;VQU;6XM
M<W1Y;&4M96YT<GDB/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L=6UN
M+7-T>6QE+65N=')Y(B\^"@H@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)C
M;VQU;6XM<W1Y;&4M96YT<GDB/@H@("`@("`@("`@("`\>'-L.F-H;V]S93X*
M("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`=&%B;&4Z=FES:6)I
M;&ET>2`]("=C;VQL87!S92<@;W(@0'1A8FQE.G9I<VEB:6QI='D@/2`G9FEL
M=&5R)R(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M
M93TB8V]L=6UN+6AI9&1E;BUF;&%G(CYT<G5E/"]X<VPZ871T<FEB=71E/@H@
M("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@(#QX
M<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B
M;&4@(&YA;64](G1A8FQE.G-T>6QE+6YA;64B("`@("`@("`@<V5L96-T/2)T
M<F%N<VQA=&4H0'1A8FQE.G-T>6QE+6YA;64L("<N("4H*2]<)RP@)R<I(B\^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB<W1Y
M;&4M;F%M92(^/'AS;#IV86QU92UO9B!S96QE8W0](B1T86)L93IS='EL92UN
M86UE(B\^/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2(D8V]L=6UN+7-T>6QE+65N=')Y(B\^"B`@
M("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@(#PO
M>'-L.F-H;V]S93X*("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@/"]X<VPZ
M=&5M<&QA=&4^"@H*"B`@("`\(2TM:7-$96)U9TUO9&4M4U1!4E0M+3X*("`@
M(#PA+2T@9VEV:6YG(&]U="!T:&4@)V%L;$-O;'5M;E-T>6QE)R!V87)I86)L
M93H*("`@("`@("!&;W(@96%C:"`G8V]L=6UN+7-T>6QE+65N=')Y)R!O9B!T
M:&4@)V%L;$-O;'5M;E-T>6QE16YT<FEE<R<@=F%R:6%B;&4@=&AE('-T>6QE
M+6YA;64@:7,@9VEV96X@;W5T+@H@("`@("`@($EN(&-A<V4@;V8@)V-O;'5M
M;BUH:61D96XM9FQA9R<@871T<FEB=71E('1H92!T97AT("=#;VQU;6X@:7,@
M:&ED9&5N(&ES(&=I=F5N(&]U="XM+3X*("`@(#QX<VPZ=&5M<&QA=&4@;F%M
M93TB=&%B;&4M9&5B=6<M86QL0V]L=6UN4W1Y;&5%;G1R:65S(CX*("`@("`@
M("`\>'-L.G!A<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE<R(O/@H*
M("`@("`@("`\(2TM(&1E8G5G(&]U='!U="!A<R!T86)L92!S=6UM87)Y(&%T
M=')I8G5T(&EN(&AT;6P@+2T^"B`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M
M93TB<W5M;6%R>2(^"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N
M86UE/2)T86)L92UD96)U9RUC;VQU;6XM;W5T(CX*("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q#;VQU;6Y3='EL945N=')I97,B
M('-E;&5C=#TB)&%L;$-O;'5M;E-T>6QE16YT<FEE<R(O/@H@("`@("`@("`@
M("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@(#PO>'-L.F%T=')I8G5T
M93X*("`@("`@("`\(2TM(&1E8G5G(&]U='!U="!T;R!C;VYS;VQE("TM/@H@
M("`@("`@(#QX<VPZ;65S<V%G93X*("`@("`@("`@("`@/'AS;#IC86QL+71E
M;7!L871E(&YA;64](G1A8FQE+61E8G5G+6-O;'5M;BUO=70B/@H@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE
M16YT<FEE<R(@<V5L96-T/2(D86QL0V]L=6UN4W1Y;&5%;G1R:65S(B\^"B`@
M("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@/"]X<VPZ
M;65S<V%G93X*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\>'-L.G1E;7!L
M871E(&YA;64](G1A8FQE+61E8G5G+6-O;'5M;BUO=70B/@H@("`@("`@(#QX
M<VPZ<&%R86T@;F%M93TB86QL0V]L=6UN4W1Y;&5%;G1R:65S(B\^"B`@("`@
M("`@("`@(#QX<VPZ=&5X=#X*("`@("`@("`@("`@1&5B=6=);F9O<FUA=&EO
M;CH@1F]R(&5A8V@@)V-O;'5M;BUS='EL92UE;G1R>2<@;V8@=&AE("=A;&Q#
M;VQU;6Y3='EL945N=')I97,G('9A<FEA8FQE('1H92!S='EL92UN86UE(&ES
M(&=I=F5N(&]U="X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@26X@
M8V%S92!O9B`G8V]L=6UN+6AI9&1E;BUF;&%G)R!A='1R:6)U=&4@=&AE('1E
M>'0@)V-O;'5M;B!I<R!H:61D96XG(&ES(&=I=F5N(&]U="X*("`@("`@("`@
M("`@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@(#QX<VPZ9F]R+65A8V@@
M<V5L96-T/2(D86QL0V]L=6UN4W1Y;&5%;G1R:65S+V-O;'5M;BUS='EL92UE
M;G1R>2(^"B`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@
M("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`8V]L=6UN+6AI9&1E;BUF;&%G(CX*
M("`@("`@("`@("`@/'AS;#IT97AT/B`@/"]X<VPZ=&5X=#X\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB0'-T>6QE+6YA;64B+SX\>'-L.G1E>'0^8V]L=6UN(&ES
M(&AI9&1E;CPO>'-L.G1E>'0^/'AS;#IT97AT/@H@("`@("`@("`@("`\+WAS
M;#IT97AT/@H@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@
M("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`\>'-L.G1E>'0^
M("`\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)`<W1Y;&4M;F%M
M92(O/CQX<VPZ=&5X=#X@/2`\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L
M96-T/2(N(B\^/'AS;#IT97AT/@H@("`@("`@("`@("`\+WAS;#IT97AT/@H@
M("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@
M("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IF;W(M96%C:#X*("`@(#PO>'-L.G1E;7!L871E/@H@("`@/"$M+6ES
M1&5B=6=-;V1E+45.1"TM/@H*/"]X<VPZ<W1Y;&5S:&5E=#X*````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]O;V\O8V]M
M;6]N+GAS;```````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#$V-S`W,R`Q,#4Q-30S
M,S<S-B`P,C0Q-S,`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/"$M+0H*("`@5&AE($-O;G1E;G1S(&]F('1H:7,@9FEL92!A
M<F4@;6%D92!A=F%I;&%B;&4@<W5B:F5C="!T;R!T:&4@=&5R;7,@;V8*("`@
M96ET:&5R(&]F('1H92!F;VQL;W=I;F<@;&EC96YS97,*"B`@("`@("`@("`M
M($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,@3&EC96YS92!697)S:6]N(#(N
M,0H@("`@("`@("`@+2!3=6X@26YD=7-T<GD@4W1A;F1A<F1S(%-O=7)C92!,
M:6-E;G-E(%9E<G-I;VX@,2XQ"@H@("!3=6X@36EC<F]S>7-T96US($EN8RXL
M($]C=&]B97(L(#(P,#`*"B`@($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,@
M3&EC96YS92!697)S:6]N(#(N,0H@("`]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*("`@0V]P>7)I9VAT(#(P,#`@8GD@
M4W5N($UI8W)O<WES=&5M<RP@26YC+@H@("`Y,#$@4V%N($%N=&]N:6\@4F]A
M9"P@4&%L;R!!;'1O+"!#02`Y-#,P,RP@55-!"@H@("!4:&ES(&QI8G)A<GD@
M:7,@9G)E92!S;V9T=V%R93L@>6]U(&-A;B!R961I<W1R:6)U=&4@:70@86YD
M+V]R"B`@(&UO9&EF>2!I="!U;F1E<B!T:&4@=&5R;7,@;V8@=&AE($=.52!,
M97-S97(@1V5N97)A;"!0=6)L:6,*("`@3&EC96YS92!V97)S:6]N(#(N,2P@
M87,@<'5B;&ES:&5D(&)Y('1H92!&<F5E(%-O9G1W87)E($9O=6YD871I;VXN
M"@H@("!4:&ES(&QI8G)A<GD@:7,@9&ES=')I8G5T960@:6X@=&AE(&AO<&4@
M=&AA="!I="!W:6QL(&)E('5S969U;"P*("`@8G5T(%=)5$A/550@04Y9(%=!
M4E)!3E19.R!W:71H;W5T(&5V96X@=&AE(&EM<&QI960@=V%R<F%N='D@;V8*
M("`@34520TA!3E1!0DE,2519(&]R($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!
M4B!055)03U-%+B`@4V5E('1H92!'3E4*("`@3&5S<V5R($=E;F5R86P@4'5B
M;&EC($QI8V5N<V4@9F]R(&UO<F4@9&5T86EL<RX*"B`@(%EO=2!S:&]U;&0@
M:&%V92!R96-E:79E9"!A(&-O<'D@;V8@=&AE($=.52!,97-S97(@1V5N97)A
M;"!0=6)L:6,*("`@3&EC96YS92!A;&]N9R!W:71H('1H:7,@;&EB<F%R>3L@
M:68@;F]T+"!W<FET92!T;R!T:&4@1G)E92!3;V9T=V%R90H@("!&;W5N9&%T
M:6]N+"!);F,N+"`U.2!496UP;&4@4&QA8V4L(%-U:71E(#,S,"P@0F]S=&]N
M+`H@("!-02`@,#(Q,3$M,3,P-R`@55-!"@H*("`@4W5N($EN9'5S=')Y(%-T
M86YD87)D<R!3;W5R8V4@3&EC96YS92!697)S:6]N(#$N,0H@("`]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B`@
M(%1H92!C;VYT96YT<R!O9B!T:&ES(&9I;&4@87)E('-U8FIE8W0@=&\@=&AE
M(%-U;B!);F1U<W1R>2!3=&%N9&%R9',*("`@4V]U<F-E($QI8V5N<V4@5F5R
M<VEO;B`Q+C$@*'1H92`B3&EC96YS92(I.R!9;W4@;6%Y(&YO="!U<V4@=&AI
M<R!F:6QE"B`@(&5X8V5P="!I;B!C;VUP;&EA;F-E('=I=&@@=&AE($QI8V5N
M<V4N(%EO=2!M87D@;V)T86EN(&$@8V]P>2!O9B!T:&4*("`@3&EC96YS92!A
M="!H='1P.B\O=W=W+F]P96YO9F9I8V4N;W)G+VQI8V5N<V4N:'1M;"X*"B`@
M(%-O9G1W87)E('!R;W9I9&5D('5N9&5R('1H:7,@3&EC96YS92!I<R!P<F]V
M:61E9"!O;B!A;B`B05,@25,B(&)A<VES+`H@("!7251(3U54(%=!4E)!3E19
M($]&($%.62!+24Y$+"!%251(15(@15A04D534R!/4B!)35!,245$+"!)3D-,
M541)3D<L"B`@(%=)5$A/550@3$E-251!5$E/3BP@5T%24D%.5$E%4R!42$%4
M(%1(12!33T945T%212!)4R!&4D5%($]&($1%1D5#5%,L"B`@($U%4D-(04Y4
M04),12P@1DE4($9/4B!!(%!!4E1)0U5,05(@4%524$]312P@3U(@3D].+4E.
M1E))3D=)3D<N"B`@(%-E92!T:&4@3&EC96YS92!F;W(@=&AE('-P96-I9FEC
M('!R;W9I<VEO;G,@9V]V97)N:6YG('EO=7(@<FEG:'1S(&%N9`H@("!O8FQI
M9V%T:6]N<R!C;VYC97)N:6YG('1H92!3;V9T=V%R92X*"B`@(%1H92!);FET
M:6%L($1E=F5L;W!E<B!O9B!T:&4@3W)I9VEN86P@0V]D92!I<SH@4W5N($UI
M8W)O<WES=&5M<RP@26YC+@H*("`@0V]P>7)I9VAT(,*I(#(P,#(@8GD@4W5N
M($UI8W)O<WES=&5M<RP@26YC+@H*("`@06QL(%)I9VAT<R!297-E<G9E9"X*
M"B`@($-O;G1R:6)U=&]R*',I.B!?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?
M7U]?7U]?7U]?7U]?7U\*"BTM/@H\>'-L.G-T>6QE<VAE970@=F5R<VEO;CTB
M,2XP(@H@("`@("`@("`@("`@("`@>&UL;G,Z>'-L/2)H='1P.B\O=W=W+G<S
M+F]R9R\Q.3DY+UA33"]4<F%N<V9O<FTB"B`@("`@("`@("`@("`@("!X;6QN
M<SIO9F9I8V4](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V]F9FEC92(*
M("`@("`@("`@("`@("`@('AM;&YS.G-T>6QE/2)H='1P.B\O;W!E;F]F9FEC
M92YO<F<O,C`P,"]S='EL92(*("`@("`@("`@("`@("`@('AM;&YS.G1E>'0]
M(FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W1E>'0B"B`@("`@("`@("`@
M("`@("!X;6QN<SIT86)L93TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O
M=&%B;&4B"B`@("`@("`@("`@("`@("!X;6QN<SID<F%W/2)H='1P.B\O;W!E
M;F]F9FEC92YO<F<O,C`P,"]D<F%W:6YG(@H@("`@("`@("`@("`@("`@>&UL
M;G,Z9F\](FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3DO6%-,+T9O<FUA="(*("`@
M("`@("`@("`@("`@('AM;&YS.GAL:6YK/2)H='1P.B\O=W=W+G<S+F]R9R\Q
M.3DY+WAL:6YK(@H@("`@("`@("`@("`@("`@>&UL;G,Z;G5M8F5R/2)H='1P
M.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]D871A<W1Y;&4B"B`@("`@("`@("`@
M("`@("!X;6QN<SIS=F<](FAT='`Z+R]W=W<N=S,N;W)G+S(P,#`O<W9G(@H@
M("`@("`@("`@("`@("`@>&UL;G,Z8VAA<G0](FAT='`Z+R]O<&5N;V9F:6-E
M+F]R9R\R,#`P+V-H87)T(@H@("`@("`@("`@("`@("`@>&UL;G,Z9'(S9#TB
M:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O9'(S9"(*("`@("`@("`@("`@
M("`@('AM;&YS.FUA=&@](FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3@O36%T:"]-
M871H34PB"B`@("`@("`@("`@("`@("!X;6QN<SIF;W)M/2)H='1P.B\O;W!E
M;F]F9FEC92YO<F<O,C`P,"]F;W)M(@H@("`@("`@("`@("`@("`@>&UL;G,Z
M<V-R:7!T/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]S8W)I<'0B"B`@
M("`@("`@("`@("`@("!O9F9I8V4Z8VQA<W,](G1E>'0B"B`@("`@("`@("`@
M("`@("!O9F9I8V4Z=F5R<VEO;CTB,2XP(@H@("`@("`@("`@("`@("`@>&UL
M;G,Z9&,](FAT='`Z+R]P=7)L+F]R9R]D8R]E;&5M96YT<R\Q+C$O(@H@("`@
M("`@("`@("`@("`@>&UL;G,Z;65T83TB:'1T<#HO+V]P96YO9F9I8V4N;W)G
M+S(P,#`O;65T82(*("`@("`@("`@("`@("`@('AM;&YS.F-O;F9I9STB:'1T
M<#HO+V]P96YO9F9I8V4N;W)G+S(P,#$O8V]N9FEG(@H@("`@("`@("`@("`@
M("`@>&UL;G,Z:&5L<#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O:&5L
M<"(*("`@("`@("`@("`@("`@('AM;&YS.GAT/2)H='1P.B\O=W=W+FIC;&%R
M:RYC;VTO>'0B"B`@("`@("`@("`@("`@("!E>'1E;G-I;VXM96QE;65N="UP
M<F5F:7AE<STB>'0B"B`@("`@("`@("`@("`@("!X;6QN<SIX86QA;CTB:'1T
M<#HO+WAM;"YA<&%C:&4N;W)G+WAA;&%N(@H@("`@("`@("`@("`@("`@>&UL
M;G,Z:F%V83TB:'1T<#HO+WAM;"YA<&%C:&4N;W)G+WAS;'0O:F%V82(*("`@
M("`@("`@("`@("`@(&5X8VQU9&4M<F5S=6QT+7!R969I>&5S/2)J879A(CX*
M"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ("TM/@H@("`@/"$M+2`J*BH@8F]D
M>2`J*BH@+2T^"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*B`M+3X*"@H@("`@/'AS
M;#IT96UP;&%T92!M871C:#TB+RHO;V9F:6-E.F)O9'DB/@H@("`@("`@(#QX
M<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@("`@
M("`\(2TM(&ES1&5B=6=-;V1E+5-405)4.B!O;FQY(&ES1&5B=6=-;V1E('!U
M<G!O<V4Z('-H;W=S('1H92!I;FQI;F5D('-T>6QE(&%T=')I8G5T97,@;V8@
M=&AE('1E;7!O<F%R>2!V87)I86)L92`M+3X*("`@("`@("`\>'-L.FEF('1E
M<W0](B1I<T1E8G5G36]D92!A;F0@;F]T*"1O=71P=714>7!E(#T@)T-34U](
M14%$15(G*2(^"B`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)D96)U
M9U]T<F5E7V]F7W-T>6QE<R(^/'AS;#IT97AT/@H@("`@("`@("`@("`\+WAS
M;#IT97AT/CQX<VPZ9F]R+65A8V@@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L
M1&%T82]A;&QS='EL97,O*B(^"CQX<VPZ=&5X=#X@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB;F%M92@I
M(B\^/'AS;#IT97AT/B`](#PO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE
M8W0](BXB+SX\>'-L.G1E>'0^"B`@("`@("`@("`@(#PO>'-L.G1E>'0^"B`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@("`@("`@("`@
M(#PO>'-L.F5L96UE;G0^"B`@("`@("`@/"]X<VPZ:68^"B`@("`\(2TM(&ES
M1&5B=6=-;V1E+45.1"`M+3X*"@H)"3PA+2T@;F]T('5S:6YG(&]F("=A<'!L
M>2US='EL97,M86YD+6-O;G1E;G0G(&%S('1H92!C;VYT96YT('1A8FQE(&EN
M9F]R;6%T:6]N(&UI9W1H(&AA=F4@8F5E;B!A9&1E9"!T;R`G8V]L;&5C=&5D
M1VQO8F%L1&%T82<@=F%R:6%B;&4@+2T^"B`@("`@("`@/'AS;#IA<'!L>2UT
M96UP;&%T97,@<V5L96-T/2)`=&5X=#IS='EL92UN86UE('P@0&1R87<Z<W1Y
M;&4M;F%M92!\($!D<F%W.G1E>'0M<W1Y;&4M;F%M92!\($!T86)L93IS='EL
M92UN86UE(CX\(2TM('P@0'!R97-E;G1A=&EO;CIS='EL92UN86UE("TM/@H@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO
M8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@
M("`@(#PO>'-L.F%P<&QY+71E;7!L871E<SX*"@H@("`@("`@(#PA+2T@57-A
M8FEL:71Y(&9E871U<F4L(&$@;&EN:R!T;R!T:&4@0V]N=&5N="!T86QB92!A
M8F]V92!A;&P@;&5V96P@,2!H96%D97(@+2T^"B`@("`@("`@/'AS;#II9B!T
M97-T/2(D8V]N=&5N=%1A8FQE2&5A9&EN9W,B/@H@("`@("`@("`@("`\>'-L
M.F-A;&PM=&5M<&QA=&4@;F%M93TB861D+6-H:6QD+61O8W5M96YT+75S86)I
M;&ET>2UL:6YK<R(O/@H@("`@("`@(#PO>'-L.FEF/@H*"@D)/'AS;#IC:&]O
M<V4^"@D@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)N;W0H)&]U='!U=%1Y<&4@
M/2`G5TU,)RD@86YD(&YO="@D;W5T<'5T5'EP92`]("=004Q-)RDB/@H)("`@
M("`@("`)/'AS;#IC:&]O<V4^"@D)"2`@("`@("`@/"$M+4EF('1H92!I;G!U
M="!D;V-U;65N="!I<R!A(&=L;V)A;"!D;V-U;65N="!A;F0@96UB960@8VAI
M;&0@9&]C=6UE;G1S("AL:6YK<RD@=&AE('1R86YS9F]R;6%T:6]N(&]F('1H
M92!C:&EL9')E;B!W:6QL(&)E('-T87)T960@87,@=V5L;"X*"0D)("`@("`@
M("`@("`@5&AI<R!I<R!N96-E<W-A<GD@87,@8VAI;&0@9&]C=6UE;G1S(&1O
M(&YO="!K;F]W(&%N>71H:6YG(&%B;W5T('1H96ER(&5M8F5D9&EN9R!I;G1O
M(&$@9VQO8F%L(&1O8W5M96YT+B!#:&%P=&5R<R!O9B!C:&EL9',*"0D)("`@
M("`@("`@("`@86QW87ES('-T87)T('1O(&-O=6YT(&)Y('IE<F\@:6YS=&5A
M9"!O9B!C;VYT:6YO=7-L>2!N=6UB97)I;F<N"@D)"2`@("`@("`@("`@($9O
M<B!T:&ES+"!T:&4@8VAA<'1E<B!N=6UB97)S(&]F('1H92!C=7)R96YT(&1O
M8W5M96YT("AA<R!A('-E<75E;F-E(&]F(&$@9VQO8F%L(&1O8W5M96YT*2!I
M<R!D97!E;F1E;G0*"0D)("`@("`@("`@("`@;V8@=&AE(&YU;6)E<B!O9B!C
M:&%P=&5R(&]F('1H92!S86UE(&QE=F5L(&EN('!R96-E9&EN9R!D;V-U;65N
M=',N"@D)"2`@("`@("`@("`@($EN(&-A<V4@;V8@;75L=&EP;&4@8VAI;&1R
M96XL(&9O<B!U<V%B:6QI='D@<F5A<V]N<R!S;VUE(&QI;FMI;F<@:7,@9V]N
M;F$@8F4@;V9F97)E9"!A;F0@=&AE(%523',@;V8@=&AE(&-O;G1E;G0M=&%B
M;&4L"@D)"2`@("`@("`@("`@('!R96-E9&EN9R!A;F0@9F]L;&]W:6YG(&9I
M;&4@:&%V92!T;R!B92!G:79E;B!F;W(@=&AE('1R86YS9F]R;6%T:6]N+@H)
M"0D@("`@("`@("`@("`M+3X*"0D@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TB+RHO0&]F9FEC93IC;&%S<STG=&5X="UG;&]B86PG(&%N9"`O*B]O9F9I
M8V4Z8F]D>2]T97AT.G-E8W1I;VXO=&5X=#IS96-T:6]N+7-O=7)C92]`>&QI
M;FLZ:')E9B(^"@D)"0D)"3PA+2T@=&AE(&-H:6QD<F5N('=I;&P@8F4@8V%L
M;&5D(&QA=&5R('=I=&@@82!M;V1I9FEE9"`G8V]L;&5C=&5D1VQO8F%L1&%T
M82<@=F%R:6%B;&4@+2T^"@D)("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT
M96UP;&%T92!N86UE/2)T<F%N<V9O<FTM9VQO8F%L+61O8W5M96YT+6%N9"UC
M:&EL9')E;B(^"@D)("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C
M=&5D1VQO8F%L1&%T82(O/@H)"2`@("`@("`@("`@("`@("`\+WAS;#IC86QL
M+71E;7!L871E/@H)"2`@("`@("`@("`@(#PO>'-L.G=H96X^"@D)"0D)/'AS
M;#IO=&AE<G=I<V4^"@D)"0D@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S
M/@H)"0D)("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE
M8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B
M+SX*"0D)"2`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H)"0D)"3PO
M>'-L.F]T:&5R=VES93X*"0D)"3PO>'-L.F-H;V]S93X*"2`@("`@("`@/"]X
M<VPZ=VAE;CX*"0D)/'AS;#IO=&AE<G=I<V4^"@D)("`@("`@("`\>'-L.F%P
M<&QY+71E;7!L871E<SX*"0D@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D
M1VQO8F%L1&%T82(O/@H)"2`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S
M/@H)"0D\+WAS;#IO=&AE<G=I<V4^"@D)/"]X<VPZ8VAO;W-E/@H*"@H@("`@
M("`@(#PA+2T@57-A8FEL:71Y(&9E871U<F4L(&$@;&EN:R!T;R!T:&4@0V]N
M=&5N="!T86QB92!A8F]V92!A;&P@;&5V96P@,2!H96%D97(@+2T^"B`@("`@
M("`@/'AS;#II9B!T97-T/2(D8V]N=&5N=%1A8FQE2&5A9&EN9W,B/@H@("`@
M("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB861D+6-H:6QD+61O
M8W5M96YT+75S86)I;&ET>2UL:6YK<R(O/@H@("`@("`@(#PO>'-L.FEF/@H*
M"B`@("`\+WAS;#IT96UP;&%T93X*"@H*"B`@("`\(2TM(&1E86-T:79A=&EN
M9R!D969A=6QT('1E;7!L871E("TM/@H@("`@/'AS;#IT96UP;&%T92!M871C
M:#TB*B(O/@H*"B`@("`\(2TM(&%L;&]W:6YG(&%L;"!M871C:&5D('1E>'0@
M;F]D97,@+2T^"B`@("`\>'-L.G1E;7!L871E(&UA=&-H/2)T97AT*"DB/@H\
M(2TM(%=-3"`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)N;W)M86QI
M>F4M<W!A8V4H+BDB+SX@+2T^"B`@("`@("`@/'AS;#IV86QU92UO9B!S96QE
M8W0](BXB+SX*("`@(#PO>'-L.G1E;7!L871E/@H*"@H@("`@/"$M+2`C(R,C
M(R,C(R,C(R,C(R,C(R,C("TM/@H@("`@/"$M+2`C(R,@24Y,24Y%+51%6%0@
M(R,C("TM/@H@("`@/"$M+2`C(R,C(R,C(R,C(R,C(R,C(R,C("TM/@H*"B`@
M("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ(%=H
M:71E<W!A8V4@*BHJ("TM/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BH@
M+2T^"@H*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@](G1E>'0Z<R(^"B`@("`@
M("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G=R:71E+6)R96%K86)L92UW
M:&ET97-P86-E(CX*("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(G=H:71E<W!A8V5S(B!S96QE8W0](D!T97AT.F,B+SX*("`@("`@("`\+WAS
M;#IC86QL+71E;7!L871E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#PA
M+2UW<FET92!T:&4@;G5M8F5R(&]F("=W:&ET97-P86-E<R<@+2T^"B`@("`\
M>'-L.G1E;7!L871E(&YA;64](G=R:71E+6)R96%K86)L92UW:&ET97-P86-E
M(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G=H:71E<W!A8V5S(B\^"@H@
M("`@("`@(#PA+2UW<FET92!T=V\@<W!A8V4@8VAA<G,@87,@=&AE(&YO<FUA
M;"!W:&ET92!S<&%C92!C:&%R86-T97(@=VEL;"!B92!S=')I<'!E9`H@("`@
M("`@("`@("!A;F0@=&AE(&]T:&5R(&ES(&%B;&4@=&\@8G)E86L@+2T^"B`@
M("`@("`@/'AS;#IT97AT/B8C,38P.SPO>'-L.G1E>'0^"B`@("`@("`@/'AS
M;#II9B!T97-T/2(D=VAI=&5S<&%C97,@/CT@,B(^"B`@("`@("`@("`@(#QX
M<VPZ8V%L;"UT96UP;&%T92!N86UE/2)W<FET92UB<F5A:V%B;&4M=VAI=&5S
M<&%C92TR(CX*("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)W:&ET97-P86-E<R(@<V5L96-T/2(D=VAI=&5S<&%C97,@+2`Q(B\^"B`@
M("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@/"]X<VPZ
M:68^"B`@("`\+WAS;#IT96UP;&%T93X*"@H@("`@/"$M+7=R:71E('1H92!N
M=6UB97(@;V8@)W=H:71E<W!A8V5S)R`M+3X*("`@(#QX<VPZ=&5M<&QA=&4@
M;F%M93TB=W)I=&4M8G)E86MA8FQE+7=H:71E<W!A8V4M,B(^"B`@("`@("`@
M/'AS;#IP87)A;2!N86UE/2)W:&ET97-P86-E<R(O/@H@("`@("`@(#PA+2UW
M<FET92!T=V\@<W!A8V4@8VAA<G,@87,@=&AE(&YO<FUA;"!W:&ET92!S<&%C
M92!C:&%R86-T97(@=VEL;"!B92!S=')I<'!E9`H@("`@("`@("`@("!A;F0@
M=&AE(&]T:&5R(&ES(&%B;&4@=&\@8G)E86L@+2T^"B`@("`@("`@/'AS;#IT
M97AT/B`\+WAS;#IT97AT/@H@("`@("`@(#QX<VPZ:68@=&5S=#TB)'=H:71E
M<W!A8V5S(#X](#(B/@H@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@
M;F%M93TB=W)I=&4M8G)E86MA8FQE+7=H:71E<W!A8V4B/@H@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G=H:71E<W!A8V5S(B!S96QE
M8W0](B1W:&ET97-P86-E<R`M(#$B+SX*("`@("`@("`@("`@/"]X<VPZ8V%L
M;"UT96UP;&%T93X*("`@("`@("`\+WAS;#II9CX*("`@(#PO>'-L.G1E;7!L
M871E/@H*"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H@("`@/"$M
M+2`J*BH@5&5X=&)O>"`J*BH@+2T^"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ
M*B`M+3X*"B`@("`\>'-L.G1E;7!L871E(&UA=&-H/2)D<F%W.G1E>'0M8F]X
M(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A
M=&$B+SX*"B`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@
M("`@/"$M+2LK*RLK($-34R`H0T%30T%$24Y'(%-43%E%(%-(1454*2!(14%$
M15(@4U193$4@5T%9("LK*RLK+2T^"B`@("`@("`@("`@("`@("`\(2TM("`@
M("`@("`@("`@("`@(&]R("`@("`@("`@("`@("`@("`@+2T^"B`@("`@("`@
M("`@("`@("`\(2TM*RLK*RL@2%1-3"`T+C`@24Y,24Y%1"!705D@("LK*RLK
M+2T^"B`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&]U='!U=%1Y
M<&4@/2`G0U-37TA%041%4B<@;W(@)&]U='!U=%1Y<&4@/2`G0U-37TE.3$E.
M140G(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB
M<W!A;B(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB
M0&9O.FUI;BUH96EG:'0@?"!`<W9G.G=I9'1H(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](G-T>6QE(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E
M<W0](FYO="A`<W9G.G=I9'1H*2(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^:&5I9VAT.B`\+WAS;#IT97AT
M/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)`9F\Z;6EN+6AE:6=H="(O/CQX<VPZ
M=&5X=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)N;W0H0&9O.FUI;BUH96EG
M:'0I(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=&5X=#YW:61T:#H@/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB0'-V9SIW:61T:"(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H
M97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IT97AT/FAE:6=H=#H@/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB0&9O.FUI;BUH96EG:'0B+SX\>'-L.G1E>'0^.R`\+WAS;#IT
M97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IT97AT/G=I9'1H.B`\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L
M96-T/2)`<W9G.G=I9'1H(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W
M:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H
M;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I
M8G5T93X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ:68^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S('-E;&5C
M=#TB0&1R87<Z;F%M92(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T
M961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE
M;65N=#X*("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@
M("`@("`\(2TM(#)$3R!P<F]V92!B97-T('5S86=E(&9O<B!004Q-("TM/@H@
M("`@("`@("`@("`@("`@/"$M+2LK*RLK(%!!3$T@,RXR(%-50E-%5"!)3DQ)
M3D5$(%=!62`@*RLK*RLM+3X*("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2(D;W5T<'5T5'EP92`]("=004Q-)R(^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IE;&5M96YT(&YA;64](G-P86XB/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S
M+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE
M8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@("`@("`\(2TM(#)$3R!P<F]V92!B97-T('5S86=E(&9O
M<B!734P@+2T^"B`@("`@("`@("`@("`@("`\(2TM*RLK*RL@5TU,("\@5T%0
M("`K*RLK*RTM/@H@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@
M("`@("`@("`@("`@("`@("`@/"$M+2!N;R!N97-T960@<"!T86=S(&EN('=M
M;#$N,2!A;&QO=V5D("TM/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO
M;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB
M86YC97-T;W(Z.BI;8V]N=&%I;G,H)'=A<"UP87)A9W)A<&@M96QE;65N=',L
M(&YA;64H*2E=(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD+6-O;G1E;G0B
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL
M96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T
M:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE
M;65N="!N86UE/2)P(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC
M;VYT96YT(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E
M;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`\+WAS;#IO
M=&AE<G=I<V4^"B`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L
M.G1E;7!L871E/@H*("`@(#PA+2T@240@+R!.04U%(&]F('1E>'0M8F]X("TM
M/@H@("`@/'AS;#IT96UP;&%T92!M871C:#TB0&1R87<Z;F%M92(^"@H@("`@
M("`@(#QX<VPZ871T<FEB=71E(&YA;64](FED(CX*("`@("`@("`@("`@/'AS
M;#IV86QU92UO9B!S96QE8W0](BXB+SX*("`@("`@("`\+WAS;#IA='1R:6)U
M=&4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ("TM/@H@("`@/"$M+2`J*BH@4&%R86=R87!H<R`J*BH@+2T^
M"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*"B`@("`\>'-L.G1E
M;7!L871E(&UA=&-H/2)T97AT.G`@?"!D<F%W.G!A9V4B/@H@("`@("`@(#QX
M<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@("`@
M("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`\(2TM*RLK*RL@
M0U-3("A#05-#041)3D<@4U1,644@4TA%150I($A%041%4B!35%E,12!705D@
M*RLK*RLM+3X*("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T
M<'5T5'EP92`]("=#4U-?2$5!1$52)R(^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IE;&5M96YT(&YA;64](G`B/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC
M;VYT96YT(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C
M;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"@H@("`@
M("`@("`@("`@("`@/"$M+2LK*RLK($A434P@-"XP($E.3$E.140@5T%9("`K
M*RLK*RTM/@H@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1O=71P
M=714>7!E(#T@)T-34U])3DQ)3D5$)R(^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IE;&5M96YT(&YA;64](G`B/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC
M;VYT96YT(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C
M;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@("`@("`\(2TM*RLK*RL@4$%,32`S+C(@4U5"4T54($E.3$E.140@
M5T%9("`K*RLK*RTM/@H@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(B1O=71P=714>7!E(#T@)U!!3$TG(CX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!I;B!P
M86QM('!A<F%G<F%P:',@8VAI;&1R96X@;V8@=&5X=#IL:7-T+6ET96US(&%R
M92!B971T97(@<VAO=VX@=VET:&]U="`G<"<@=&%G+2T^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)N86UE*'!A<F5N=#HZ*BD@
M/2`G=&5X=#IL:7-T+6ET96TG(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD
M+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE
M8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ96QE;65N="!N86UE/2)P(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y
M;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`\(2TM*RLK*RL@5TU,("\@
M5T%0("`K*RLK*RTM/@H@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^
M"B`@("`@("`@("`@("`@("`@("`@/"$M+2!N;R!N97-T960@<"!T86=S(&EN
M('=M;#$N,2!A;&QO=V5D("TM/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TB86YC97-T;W(Z.BI;8V]N=&%I;G,H)'=A<"UP87)A9W)A<&@M96QE;65N
M=',L(&YA;64H*2E=(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD+6-O;G1E
M;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C
M;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M96QE;65N="!N86UE/2)P(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N
M9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B
M('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`\+WAS
M;#IO=&AE<G=I<V4^"B`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO
M>'-L.G1E;7!L871E/@H*"@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*B`M
M+3X*("`@(#PA+2T@*BHJ(%1E>'0@4W!A;B`J*BH@+2T^"B`@("`\(2TM("HJ
M*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@]
M(G1E>'0Z<W!A;B(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQL96-T
M961';&]B86Q$871A(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@
M("`@("`\(2TM*RLK*RL@0U-3("A#05-#041)3D<@4U1,644@4TA%150I($A%
M041%4B!35%E,12!705D@*RLK*RLM+3X*("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0](B1O=71P=714>7!E(#T@)T-34U](14%$15(G(CX*("`@("`@("`@
M("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)S<&%N(CX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S
M+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB
M)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@/"]X<VPZ96QE
M;65N=#X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*"B`@("`@("`@("`@(#PA
M+2TK*RLK*R!(5$U,(#0N,"!)3DQ)3D5$(%=!62`@*RLK*RLM+3X*("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0](B1O=71P=714>7!E(#T@)T-34U])3DQ)
M3D5$)R(^"B`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB<W!A
M;B(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA
M;64](F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B
M86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@
M("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@(#PA+2TK*RLK*R!004Q-(#,N,B!354)3150@24Y,24Y%
M1"!705D@("LK*RLK+2T^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D
M;W5T<'5T5'EP92`]("=004Q-)R(^"B`@("`@("`@("`@("`@("`\>'-L.F-A
M;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L
M;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T
M82(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/"$M+2LK*RLK(%=-
M3"`O(%=!4"`@*RLK*RLM+3X*("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^
M"B`@("`@("`@("`@("`@("`\(2TM(&YO(&YE<W1E9"!P('1A9W,@:6X@=VUL
M,2XQ(&%L;&]W960@+2T^"B`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB86YC97-T;W(Z
M.BI;8V]N=&%I;G,H)'=A<"UP87)A9W)A<&@M96QE;65N=',L(&YA;64H*2E=
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E
M(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C
M=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E
M/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ96QE;65N="!N86UE/2)P(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL
M97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A
M(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#PO>'-L
M.F-H;V]S93X*("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@
M(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*"@H@("`@/"$M
M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H@("`@/"$M+2`J*BH@2&5A9&EN9W,@
M*BHJ("TM/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H*("`@(#QX
M<VPZ=&5M<&QA=&4@;6%T8V@](G1E>'0Z:"(^"B`@("`@("`@/'AS;#IP87)A
M;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B\^"@H@("`@("`@(#PA+2T@
M179E<GD@:&5A9&EN9R!E;&5M96YT('=I;&P@9V5T(&%N('5N:7%U92!A;F-H
M;W(@9F]R(&ET<R!F:6QE+"!F<F]M(&ET<R!H:65A<F-H>2!L979E;"!A;F0@
M;F%M93H*("`@("`@("`@("`@1F]R(&5X86UP;&4Z("!4:&4@:&5A9&EN9R!T
M:71L92`G37D@9F%V;W)I=&4@:&5A9&EN9R<@;6EG:'0@9V5T(#QA(&YA;64]
M(C$K,BLR*TUY*V9A=F]R:71E*VAE861I;F<B+SX@+2T^"B`@("`@("`@/'AS
M;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D9&ES86)L
M94QI;FME9%1A8FQE3V9#;VYT96YT(&]R("1I<TIA=F%$:7-A8FQE9"!O<B!N
M;W0H)&]U='!U=%1Y<&4@/2`G0U-37TA%041%4B<I(CX*("`@("`@("`@("`@
M/"$M+2!4:&4@55),(&QI;FMI;F<@;V8@86X@=&%B;&4M;V8M8V]N=&5N="!I
M<R!D=64@=&\@82!B=6<@*&-M<"X@8G5G(&ED(R`Q,#(S,3$I(&YO="!M87!P
M960@87,@55),(&EN('1H92!834PN"B`@("`@("`@("`@("`@("`@3&EN:VEN
M9R!O9B!T:&4@=&%B;&4M;V8M8V]N=&5N="!C86X@=&AE<F5F;W)E(&]N;'D@
M8F4@87)C:&EE=F5D(&)Y(&$@=V]R:RUA<F]U;F0@:6X@2%1-3"`M+3X*("`@
M("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)C<F5A=&4M
M:&5A9&EN9R(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E
M9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M
M<&QA=&4^"B`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`\>'-L
M.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#PA+2T@;F5C97-S87)Y(&%S
M(&%N8VAO<B!F;W(@=&AE(&-O;G1E;G0@=&%B;&4@+2T^"B`@("`@("`@("`@
M("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB8W)E871E+6AE861I;F<M
M86YC:&]R(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D
M1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP
M;&%T93X*"B`@("`@("`@("`@("`@("`\(2TM(&YO(&5M8F5D9&EN9R!T:&4@
M;W)G:6YA;"!H96%D97(L(&%S(&%N(&5X<&QI8VET(&%N8VAO<B!M:6=H="!B
M92!A;')E861Y('-E="`M+3X*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT
M96UP;&%T92!N86UE/2)C<F5A=&4M:&5A9&EN9R(^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A
M=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@
M("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L
M.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT
M96UP;&%T93X*"@H@("`@/"$M+2!D969A=6QT(&UA=&-H:6YG(&9O<B!H96%D
M97(@96QE;65N=',@+2T^"B`@("`\>'-L.G1E;7!L871E(&YA;64](F-R96%T
M92UH96%D:6YG(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E
M9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@
M("`@(#PA+2TK*RLK*R!#4U,@*$-!4T-!1$E.1R!35$Q912!32$5%5"D@2$5!
M1$52(%-464Q%(%=!62`K*RLK*RTM/@H@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TB)&]U='!U=%1Y<&4@/2`G0U-37TA%041%4B<B/@H*("`@("`@("`@
M("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB:&5A9&5R='EP(B!S96QE8W0]
M(F-O;F-A="@G:"<L($!T97AT.FQE=F5L*2(O/@H@("`@("`@("`@("`@("`@
M/'AS;#IE;&5M96YT(&YA;64](GLD:&5A9&5R='EP?2(^"@H@("`@("`@("`@
M("`@("`@("`@(#PA+2T@;W5T;&EN92!S='EL92`G=&5X=#IM:6XM;&%B96PM
M=VED=&@G(&ES(&EN=&5R<')E=&5D(&%S(&$@0U-3("=M87)G:6XM;&5F="<@
M871T<FEB=71E("TM/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B
M;&4@;F%M93TB;6EN+6QA8F5L(B!S96QE8W0](B1O9F9I8V4Z<W1Y;&5S+W1E
M>'0Z;W5T;&EN92US='EL92]T97AT.F]U=&QI;F4M;&5V96PM<W1Y;&5;0'1E
M>'0Z;&5V96P@/2!C=7)R96YT*"DO0'1E>'0Z;&5V96Q=+W-T>6QE.G!R;W!E
M<G1I97,O0'1E>'0Z;6EN+6QA8F5L+7=I9'1H(B\^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#II9B!T97-T/2(D;6EN+6QA8F5L(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB<W1Y;&4B/CQX<VPZ
M=&5X=#YM87)G:6XM;&5F=#H\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L
M96-T/2(D;6EN+6QA8F5L(B\^/'AS;#IT97AT/CL\+WAS;#IT97AT/CPO>'-L
M.F%T=')I8G5T93X*("`@("`@("`@("`@("`@("`@("`\+WAS;#II9CX*"@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](F-L87-S
M(CX\>'-L.G9A;'5E+6]F('-E;&5C=#TB=')A;G-L871E*$!T97AT.G-T>6QE
M+6YA;64L("<N("4H*2]<)RP@)R<I(B\^/"]X<VPZ871T<FEB=71E/@H*("`@
M("`@("`@("`@("`@("`@("`\(2TM('=R:71I;F<@;W5T(&$@8VAA<'1E<B!N
M=6UB97(@:68@9&5S:7)E9"`H;F]T:6-A8FQE('=H96X@82!C;W)R97-P;VYD
M:6YG("=T97AT.F]U=&QI;F4M<W1Y;&4G(&5X:7-T("TM/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ:68@=&5S=#TB<W1R:6YG+6QE;F=T:"@D;V9F:6-E
M.G-T>6QE<R]T97AT.F]U=&QI;F4M<W1Y;&4O=&5X=#IO=71L:6YE+6QE=F5L
M+7-T>6QE6T!T97AT.FQE=F5L(#T@8W5R<F5N="@I+T!T97AT.FQE=F5L72]`
M<W1Y;&4Z;G5M+69O<FUA="D@(3T@,"(^"@H@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VAE;B!T97-T/2(D9&ES86)L94QI;FME9%1A8FQE3V9#;VYT96YT
M(&]R("1I<TIA=F%$:7-A8FQE9"!O<B!N;W0H)&]U='!U=%1Y<&4@/2`G0U-3
M7TA%041%4B<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M(2TM('1H92!C:&%P=&5R(&YU;6)E<B!I<R!T:&4@<W5M(&]F("=T97AT.G-T
M87)T+79A;'5E)R!A;F0@<')E8V5D:6YG('-I8FQI;F=S(&]F("=T97AT.F@G
M('=I=&@@=&AE('-A;64@)W1E>'0Z;&5V96PG+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@9G5R=&AE<FUO<F4@=VAE;B!T:&4@8W5R
M<F5N="!D;V-U;65N="!I<R!R969E<F5N8V5D(&)Y(&$@9VQO8F%L(&1O8W5M
M96YT("T@87,@<&%R="!O9B!A('=H;VQE('-E<75E;F-E(&]F(&1O8W5M96YT
M<R`M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE
M(&-H87!T97(@;F\N(&ES(&1E<&5N9&5N="!O9B!T:&4@86UO=6YT(&]F('-T
M87)T960@:&5A9&5R<R!I;B!P<F5C961I;F<@9&]C=6UE;G1S+@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@268@=&AE("=T97AT.G-T
M87)T+79A;'5E(&ES(&YO="!S970@=&AE(&1E9F%U;'0@=F%L=64@;V8@)S$G
M(&AA<R!T;R!B92!T86ME;BX@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)S=&%R=%9A;'5E(B!S96QE
M8W0](B1O9F9I8V4Z<W1Y;&5S+W1E>'0Z;W5T;&EN92US='EL92]T97AT.F]U
M=&QI;F4M;&5V96PM<W1Y;&5;0'1E>'0Z;&5V96P@/2!C=7)R96YT*"DO0'1E
M>'0Z;&5V96Q=+T!T97AT.G-T87)T+79A;'5E(B\^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D<W1A<G16
M86QU92(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB0'1E>'0Z;&5V96P])S$G
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O=6YT*'!R96-E9&EN9RUS
M:6)L:6YG.CIT97AT.FA;0'1E>'0Z;&5V96P@/2!C=7)R96YT*"DO0'1E>'0Z
M;&5V96Q=*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`K("1P<F5C961I;F=#:&%P=&5R3&5V
M96PQ"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("L@)'-T87)T5F%L=64B+SX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VAE;B!T97-T/2)`=&5X=#IL979E;#TG,B<B/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB8V]U;G0H<')E8V5D:6YG+7-I8FQI;F<Z.G1E>'0Z
M:%M`=&5X=#IL979E;"`](&-U<G)E;G0H*2]`=&5X=#IL979E;%TI"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("L@)'!R96-E9&EN9T-H87!T97),979E;#(*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@*R`D<W1A<G1686QU92(O/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E
M<W0](D!T97AT.FQE=F5L/2<S)R(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T
M/2)C;W5N="AP<F5C961I;F<M<VEB;&EN9SHZ=&5X=#IH6T!T97AT.FQE=F5L
M(#T@8W5R<F5N="@I+T!T97AT.FQE=F5L72D*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*R`D
M<')E8V5D:6YG0VAA<'1E<DQE=F5L,PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`K("1S=&%R
M=%9A;'5E(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB0'1E>'0Z;&5V
M96P])S0G(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O=6YT*'!R96-E
M9&EN9RUS:6)L:6YG.CIT97AT.FA;0'1E>'0Z;&5V96P@/2!C=7)R96YT*"DO
M0'1E>'0Z;&5V96Q=*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`K("1P<F5C961I;F=#:&%P
M=&5R3&5V96PT"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("L@)'-T87)T5F%L=64B+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`=&5X=#IL979E;#TG-2<B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]U;G0H<')E8V5D:6YG+7-I8FQI;F<Z
M.G1E>'0Z:%M`=&5X=#IL979E;"`](&-U<G)E;G0H*2]`=&5X=#IL979E;%TI
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("L@)'!R96-E9&EN9T-H87!T97),979E;#4*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@*R`D<W1A<G1686QU92(O/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:&5N('1E<W0](D!T97AT.FQE=F5L/2<V)R(^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@
M<V5L96-T/2)C;W5N="AP<F5C961I;F<M<VEB;&EN9SHZ=&5X=#IH6T!T97AT
M.FQE=F5L(#T@8W5R<F5N="@I+T!T97AT.FQE=F5L72D*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@*R`D<')E8V5D:6YG0VAA<'1E<DQE=F5L-@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`K
M("1S=&%R=%9A;'5E(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB0'1E
M>'0Z;&5V96P])S<G(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O=6YT
M*'!R96-E9&EN9RUS:6)L:6YG.CIT97AT.FA;0'1E>'0Z;&5V96P@/2!C=7)R
M96YT*"DO0'1E>'0Z;&5V96Q=*0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`K("1P<F5C961I
M;F=#:&%P=&5R3&5V96PW"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("L@)'-T87)T5F%L=64B
M+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`=&5X=#IL979E;#TG."<B
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]U;G0H<')E8V5D:6YG+7-I
M8FQI;F<Z.G1E>'0Z:%M`=&5X=#IL979E;"`](&-U<G)E;G0H*2]`=&5X=#IL
M979E;%TI"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("L@)'!R96-E9&EN9T-H87!T97),979E
M;#@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@*R`D<W1A<G1686QU92(O/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:&5N('1E<W0](D!T97AT.FQE=F5L/2<Y)R(^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2)C;W5N="AP<F5C961I;F<M<VEB;&EN9SHZ=&5X=#IH
M6T!T97AT.FQE=F5L(#T@8W5R<F5N="@I+T!T97AT.FQE=F5L72D*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@*R`D<')E8V5D:6YG0VAA<'1E<DQE=F5L.0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`K("1S=&%R=%9A;'5E(B\^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TB0'1E>'0Z;&5V96P])S$P)R(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T
M/2)C;W5N="AP<F5C961I;F<M<VEB;&EN9SHZ=&5X=#IH6T!T97AT.FQE=F5L
M(#T@8W5R<F5N="@I+T!T97AT.FQE=F5L72D*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*R`D
M<')E8V5D:6YG0VAA<'1E<DQE=F5L,3`*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*R`D<W1A
M<G1686QU92(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O
M<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0](D!T97AT.FQE=F5L/2<Q)R(^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=F%L=64M;V8@<V5L96-T/2)C;W5N="AP<F5C961I;F<M<VEB;&EN9SHZ=&5X
M=#IH6T!T97AT.FQE=F5L(#T@8W5R<F5N="@I+T!T97AT.FQE=F5L72D*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@*R`D<')E8V5D:6YG0VAA<'1E<DQE=F5L,0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`K(#$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`=&5X
M=#IL979E;#TG,B<B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]U;G0H
M<')E8V5D:6YG+7-I8FQI;F<Z.G1E>'0Z:%M`=&5X=#IL979E;"`](&-U<G)E
M;G0H*2]`=&5X=#IL979E;%TI"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("L@)'!R96-E9&EN
M9T-H87!T97),979E;#(*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*R`Q(B\^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=H96X@=&5S=#TB0'1E>'0Z;&5V96P])S,G(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV
M86QU92UO9B!S96QE8W0](F-O=6YT*'!R96-E9&EN9RUS:6)L:6YG.CIT97AT
M.FA;0'1E>'0Z;&5V96P@/2!C=7)R96YT*"DO0'1E>'0Z;&5V96Q=*0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`K("1P<F5C961I;F=#:&%P=&5R3&5V96PS"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("L@,2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](D!T97AT
M.FQE=F5L/2<T)R(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;W5N="AP
M<F5C961I;F<M<VEB;&EN9SHZ=&5X=#IH6T!T97AT.FQE=F5L(#T@8W5R<F5N
M="@I+T!T97AT.FQE=F5L72D*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*R`D<')E8V5D:6YG
M0VAA<'1E<DQE=F5L-`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`K(#$B+SX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VAE;B!T97-T/2)`=&5X=#IL979E;#TG-2<B/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB8V]U;G0H<')E8V5D:6YG+7-I8FQI;F<Z.G1E>'0Z
M:%M`=&5X=#IL979E;"`](&-U<G)E;G0H*2]`=&5X=#IL979E;%TI"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("L@)'!R96-E9&EN9T-H87!T97),979E;#4*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@*R`Q(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB0'1E>'0Z
M;&5V96P])S8G(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O=6YT*'!R
M96-E9&EN9RUS:6)L:6YG.CIT97AT.FA;0'1E>'0Z;&5V96P@/2!C=7)R96YT
M*"DO0'1E>'0Z;&5V96Q=*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`K("1P<F5C961I;F=#
M:&%P=&5R3&5V96PV"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("L@,2(O/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:&5N('1E<W0](D!T97AT.FQE=F5L/2<W)R(^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2)C;W5N="AP<F5C961I;F<M<VEB;&EN9SHZ=&5X=#IH
M6T!T97AT.FQE=F5L(#T@8W5R<F5N="@I+T!T97AT.FQE=F5L72D*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@*R`D<')E8V5D:6YG0VAA<'1E<DQE=F5L-PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`K(#$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`=&5X=#IL
M979E;#TG."<B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]U;G0H<')E
M8V5D:6YG+7-I8FQI;F<Z.G1E>'0Z:%M`=&5X=#IL979E;"`](&-U<G)E;G0H
M*2]`=&5X=#IL979E;%TI"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("L@)'!R96-E9&EN9T-H
M87!T97),979E;#@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@*R`Q(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=H96X@=&5S=#TB0'1E>'0Z;&5V96P])SDG(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU
M92UO9B!S96QE8W0](F-O=6YT*'!R96-E9&EN9RUS:6)L:6YG.CIT97AT.FA;
M0'1E>'0Z;&5V96P@/2!C=7)R96YT*"DO0'1E>'0Z;&5V96Q=*0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`K("1P<F5C961I;F=#:&%P=&5R3&5V96PY"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("L@,2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](D!T97AT.FQE
M=F5L/2<Q,"<B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]U;G0H<')E
M8V5D:6YG+7-I8FQI;F<Z.G1E>'0Z:%M`=&5X=#IL979E;"`](&-U<G)E;G0H
M*2]`=&5X=#IL979E;%TI"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("L@)'!R96-E9&EN9T-H
M87!T97),979E;#$P"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("L@,2(O/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IC86QL+71E;7!L871E(&YA;64](F=E="UA8G-O;'5T92UC:&%P=&5R
M+6YO(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](G!R96-E9&EN9T-H87!T97),979E;#$B("`@
M('-E;&5C=#TB)'!R96-E9&EN9T-H87!T97),979E;#$B+SX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B("`@("`@('-E;&5C=#TB)&-O;&QE
M8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=&5X=#X@)B,Q-C`[("8C,38P.SPO>'-L.G1E>'0^"B`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ:68^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IA
M<'!L>2UT96UP;&%T97,^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0]
M(B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H*("`@("`@("`@("`@("`@(#PO>'-L
M.F5L96UE;G0^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"@H*("`@("`@("`@
M("`@/"$M+2LK*RLK($A434P@-"XP($E.3$E.140@5T%9("`K*RLK*RTM/@H@
M("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G0U-3
M7TE.3$E.140G(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M
M93TB:&5A9&5R='EP(B!S96QE8W0](F-O;F-A="@G:"<L($!T97AT.FQE=F5L
M*2(O/@H@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](GLD:&5A
M9&5R='EP?2(^"@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ87!P;'DM=&5M
M<&QA=&5S('-E;&5C=#TB0'1E>'0Z<W1Y;&4M;F%M92(^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961'
M;&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H*("`@
M("`@("`@("`@("`@("`@("`\(2TM('=R:71I;F<@;W5T(&$@8VAA<'1E<B!N
M=6UB97(@:68@9&5S:7)E9"`H;F]T:6-A8FQE('=H96X@82!C;W)R97-P;VYD
M:6YG("=T97AT.F]U=&QI;F4M<W1Y;&4G(&5X:7-T("TM/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ:68@=&5S=#TB)&]F9FEC93IS='EL97,O=&5X=#IO
M=71L:6YE+7-T>6QE+W1E>'0Z;W5T;&EN92UL979E;"US='EL95M`=&5X=#IL
M979E;"`](&-U<G)E;G0H*2]`=&5X=#IL979E;%TO0'1E>'0Z<W1Y;&4M;F%M
M92(^"@H@("`@("`@("`@("`@("`@("`@("`@("`\(2TM('1H92!C:&%P=&5R
M(&YU;6)E<B!I<R!T:&4@<W5M(&]F("=T97AT.G-T87)T+79A;'5E)R!A;F0@
M<')E8V5D:6YG('-I8FQI;F=S(&]F("=T97AT.F@G('=I=&@@=&AE('-A;64@
M)W1E>'0Z;&5V96PG("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB8V]U;G0H<')E8V5D:6YG+7-I8FQI;F<Z.G1E
M>'0Z:%M`=&5X=#IL979E;"`](&-U<G)E;G0H*2]`=&5X=#IL979E;%TI"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*R`D
M;V9F:6-E.G-T>6QE<R]T97AT.F]U=&QI;F4M<W1Y;&4O=&5X=#IO=71L:6YE
M+6QE=F5L+7-T>6QE6T!T97AT.FQE=F5L(#T@8W5R<F5N="@I+T!T97AT.FQE
M=F5L72]`=&5X=#IS=&%R="UV86QU92(O/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G1E>'0^("8C,38P.R`F(S$V,#L\+WAS;#IT97AT/@H@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H*("`@("`@("`@("`@("`@(#PO
M>'-L.F5L96UE;G0^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"@H@("`@("`@
M("`@("`\(2TM(#)$3SH@861D($-H87!T97(@3F\N(&9O<B!004Q-(&%N9"!7
M34P@/"T^('!R;V)L96T@;F5S=&5D(&%P<&QY+71E;7!L871E<R`M+3X*"B`@
M("`@("`@("`@(#PA+2TK*RLK*R!004Q-(#,N,B!354)3150@24Y,24Y%1"!7
M05D@("LK*RLK+2T^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T
M<'5T5'EP92`]("=004Q-)R(^"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA
M8FQE(&YA;64](FAE861E<G1Y<"(@<V5L96-T/2)C;VYC870H)V@G+"!`=&5X
M=#IL979E;"DB+SX*("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE
M/2)[)&AE861E<G1Y<'TB/@H*"B`@("`@("`@("`@("`@("`@("`@/"$M+2!!
M;&P@8VAI;&1R96X@8V]N=&5N="!H879E('1O(&)E(&YE<W1E9"!I;B!T:&4@
M<W1Y;&5S("AE+F<N(#QI/CQB/D%.62!#3TY414Y4/"]B/CPO:3XI"B`@("`@
M("`@("`@("`@("`@("`@("`@("!F;W(@=&AI<R!X<VPZ87!P;'DM=&5M<&QA
M=&5S('=I;&P@8F4@8V%L;&5D(&QA=&5R("\@:6UP;&EC:70@+2T^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F-R96%T
M92UA='1R:6)U=&4M04Q)1TXB/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M(2TM(&=E='1I;F<@=&AE(&-S<R!S='EL97,@9F]R('1H92!S='EL92!N86UE
M("AM87!P960@8GD@<W1Y;&4M;6%P<&EN9RYX<VPI("TM/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y;&50<F]P
M97)T:65S(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A+V%L;'-T>6QE
M<R\J6VYA;64H*3UC=7)R96YT*"DO0'1E>'0Z<W1Y;&4M;F%M95TB+SX*("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@
M("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*"B`@("`@("`@("`@(#PA+2TK*RLK*R!734P@+R!705`@("LK*RLK+2T^
M"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@
M/"$M+2!N;R!N97-T960@<"!T86=S(&EN('=M;#$N,2!A;&QO=V5D("TM/@H@
M("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0](F%N8V5S=&]R.CHJ6V-O;G1A:6YS*"1W87`M
M<&%R86=R87!H+65L96UE;G1S+"!N86UE*"DI72(^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#PA+2T@<VEN8V4@;F\@:&5A9&5R('-T>6QE<R!E>&ES="P@
M86X@96UP:&%S:7,@:7,@=7-E9"`M+3X*("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IE;&5M96YT(&YA;64](F5M(CX*"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\(2TM('=R:71I;F<@;W5T(&$@8VAA<'1E<B!N=6UB97(@
M:68@9&5S:7)E9"`H;F]T:6-A8FQE('=H96X@82!C;W)R97-P;VYD:6YG("=T
M97AT.F]U=&QI;F4M<W1Y;&4G(&5X:7-T("TM/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#II9B!T97-T/2(D;V9F:6-E.G-T>6QE<R]T97AT
M.F]U=&QI;F4M<W1Y;&4O=&5X=#IO=71L:6YE+6QE=F5L+7-T>6QE6T!T97AT
M.FQE=F5L(#T@8W5R<F5N="@I+T!T97AT.FQE=F5L72]`=&5X=#IS='EL92UN
M86UE(CX*"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!T
M:&4@8VAA<'1E<B!N=6UB97(@:7,@=&AE('-U;2!O9B`G=&5X=#IS=&%R="UV
M86QU92<@86YD('!R96-E9&EN9R!S:6)L:6YG<R!O9B`G=&5X=#IH)R!W:71H
M('1H92!S86UE("=T97AT.FQE=F5L)R`M+3X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]U;G0H<')E
M8V5D:6YG+7-I8FQI;F<Z.G1E>'0Z:%M`=&5X=#IL979E;"`](&-U<G)E;G0H
M*2]`=&5X=#IL979E;%TI"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`K("1O9F9I8V4Z<W1Y;&5S+W1E>'0Z
M;W5T;&EN92US='EL92]T97AT.F]U=&QI;F4M;&5V96PM<W1Y;&5;0'1E>'0Z
M;&5V96P@/2!C=7)R96YT*"DO0'1E>'0Z;&5V96Q=+T!T97AT.G-T87)T+79A
M;'5E(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT
M97AT/B`F(S$V,#L@)B,Q-C`[/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.FEF/@H*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S('-E;&5C=#TB0'1E>'0Z<W1Y
M;&4M;F%M92(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C
M=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.F%P<&QY+71E;7!L871E<SX*"B`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R
M=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA
M;64](G`B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!S:6YC
M92!N;R!H96%D97(@<W1Y;&5S(&5X:7-T+"!A;B!E;7!H87-I<R!I<R!U<V5D
M("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT
M(&YA;64](F5M(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT
M96YT(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C
M=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\+WAS;#IC:&]O
M<V4^"B`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS
M;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H*("`@(#PA+2T@*BHJ
M*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ($QI;FL@("HJ*B`M+3X*("`@
M(#PA+2T@*BHJ*BHJ*BHJ*BHJ*B`M+3X*"B`@("`\>'-L.G1E;7!L871E(&UA
M=&-H/2)T97AT.F$@?"!D<F%W.F$B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M
M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@("`@("`\>'-L.F-A;&PM
M=&5M<&QA=&4@;F%M93TB8W)E871E+6-O;6UO;BUL:6YK(CX*("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B
M('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`\+WAS
M;#IC86QL+71E;7!L871E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#QX
M<VPZ=&5M<&QA=&4@;F%M93TB8W)E871E+6-O;6UO;BUL:6YK(CX*("`@("`@
M("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*"B`@
M("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2)N;W0H)&]U='!U=%1Y<&4@/2`G5TU,)RDB/@H@("`@("`@("`@("`@("`@
M/'AS;#IE;&5M96YT(&YA;64](F$B/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ871T<FEB=71E(&YA;64](FAR968B/CQX<VPZ=F%L=64M;V8@<V5L96-T
M/2)`>&QI;FLZ:')E9B(O/CPO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@
M("`@("`@("`\(2TM/'AS;#IA='1R:6)U=&4@;F%M93TB8VQA<W,B/D-O;G1E
M;G1,:6YK/"]X<VPZ871T<FEB=71E/BTM/@H@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD+6-O
M;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C
M=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A
M;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@
M("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.F]T:&5R
M=VES93X*("`@("`@("`@("`@("`@(#PA+2T@;F\@;F5S=&5D('`@=&%G<R!I
M;B!W;6PQ+C$@86QL;W=E9"`M+3X*("`@("`@("`@("`@("`@(#QX<VPZ8VAO
M;W-E/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)A;F-E
M<W1O<CHZ*EMC;VYT86EN<R@D=V%P+7!A<F%G<F%P:"UE;&5M96YT<RP@;F%M
M92@I*5TB/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@
M;F%M93TB82(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%T
M=')I8G5T92!N86UE/2)H<F5F(CX\>'-L.G9A;'5E+6]F('-E;&5C=#TB0'AL
M:6YK.FAR968B+SX\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E<R!S96QE8W0](F1E<V-E
M;F1A;G0Z.G1E>'0H*2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)P(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)A(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N
M86UE/2)H<F5F(CX\>'-L.G9A;'5E+6]F('-E;&5C=#TB0'AL:6YK.FAR968B
M+SX\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,@<V5L96-T/2)D97-C96YD86YT
M.CIT97AT*"DB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F5L96UE;G0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE
M;G0^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@
M("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`\+WAS;#IO
M=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M
M<&QA=&4^"@H*"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*
M("`@(#PA+2T@*BHJ($EM86=E($QI;FL@("HJ*B`M+3X*("`@(#PA+2T@*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*"B`@("`\>'-L.G1E;7!L871E(&UA=&-H
M/2)D<F%W.FEM86=E(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE
M8W1E9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@/"$M+2!.3R!)34%'15,@4U50
M4$Q)140@1D]2(%=!4"!/4B!004Q-("TM/@H@("`@("`@(#QX<VPZ:68@=&5S
M=#TB)&]U='!U=%1Y<&4@/2`G0U-37TA%041%4B<@;W(@)&]U='!U=%1Y<&4@
M/2`G0U-37TE.3$E.140G(CX*"B`@("`@("`@("`@(#QX<VPZ96QE;65N="!N
M86UE/2)I;6<B/@H@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2)`<W9G
M.G=I9'1H(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N
M86UE/2)W:61T:"(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L
M;"UT96UP;&%T92!N86UE/2)C;VYV97)T,G!I>&5L(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)V86QU92(@
M<V5L96-T/2)`<W9G.G=I9'1H(B\^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`@/"]X<VPZ:68^"B`@("`@
M("`@("`@("`@("`\>'-L.FEF('1E<W0](D!S=F<Z:&5I9VAT(CX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)H96EG:'0B/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M
M93TB8V]N=F5R=#)P:7AE;"(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=F%L=64B('-E;&5C=#TB0'-V9SIH
M96EG:'0B+SX*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT
M96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^
M"B`@("`@("`@("`@("`@("`\+WAS;#II9CX*("`@("`@("`@("`@("`@(#QX
M<VPZ:68@=&5S=#TB<W9G.F1E<V,B/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ871T<FEB=71E(&YA;64](F%L="(^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)S=F<Z9&5S8R(O/@H@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@
M(#PO>'-L.FEF/@H@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@
M("`@("`@("`@("`@("`@(#PA+2T@9F]R(&EM86=E<R!J87)E9"!I;B!O<&5N
M(&]F9FEC92!D;V-U;65N="`M+3X*("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB8V]N=&%I;G,H0'AL:6YK.FAR968L("<C4&EC='5R97,O
M)RDB/@H@("`@("`@("`@("`@("`@("`@("`@("`\(2TM(&-R96%T:6YG(&%N
M(&%B<V]L=71E(&AT='`@55),('1O('1H92!P86-K960@:6UA9V4@9FEL92`M
M+3X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M
M93TB<W)C(CX\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"1J87)E9%)O
M;W154DPL("<O4&EC='5R97,O)RP@<W5B<W1R:6YG+6%F=&5R*$!X;&EN:SIH
M<F5F+"`G(U!I8W1U<F5S+R<I+"`D;W!T:6]N86Q54DQ3=69F:7@I(B\^/"]X
M<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^
M"CPA+2T@("`@("`@("`@("`@("`@("`@($1U92!T;R!A(%A4(&)U9R!N;R!$
M3U,@)SHG(&)E9F]R92!$4DE612!L971T97(@:7,@86QL;W=E9"P@:70@=V]U
M;&0@<F5S=6QT(&EN(&$@=6YK;W=N('!R;W1O8V\@97AC97!T:6]N+"!B=70@
M82!F:6QE(%523"!F;W(@82!$3U,*"0D)"0D)<&%T:"!N965D<R!T:&4@1%))
M5D4@;&5T=&5R+"!T:&5R969O<F4@86QL(')E;&%T:79E(%523',@<F5M86EN
M(')E;&%T:78*"@D)"0D)/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*$!X;&EN
M:SIH<F5F+"<O+R<I(&]R("AS=6)S=')I;F<H0'AL:6YK.FAR968L,BPQ*2`]
M("<Z)RD@;W(@<W1A<G1S+7=I=&@H0'AL:6YK.FAR968L("<O)RDB/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)S<F,B
M/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)`>&QI;FLZ:')E9B(O/CPO>'-L.F%T
M=')I8G5T93X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\(7Y^(&-R96%T:6YG(&$@86)S;VQU=&4@<&%T:"]54DP@
M9F]R('1H92!R969E<F5N8V5D(')E<V]U<F-E('Y^/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)S<F,B/CQX<VPZ=F%L
M=64M;V8@<V5L96-T/2)C;VYC870H)&%B<V]L=71E4V]U<F-E1&ER4F5F+"!`
M>&QI;FLZ:')E9BP@)&]P=&EO;F%L55),4W5F9FEX*2(O/CPO>'-L.F%T=')I
M8G5T93X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"BTM
M/@H)"0D)"3QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F%T=')I8G5T92!N86UE/2)S<F,B/CQX<VPZ=F%L=64M;V8@<V5L
M96-T/2)`>&QI;FLZ:')E9B(O/CPO>'-L.F%T=')I8G5T93X*("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\
M+WAS;#IC:&]O<V4^"@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L
M871E(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L
M;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@
M("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@
M(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@(#PA+2T@861D:6YG(&$@;&EN
M92!B<F5A:R!T;R!M86ME('1H92!P<F5S96YT871I;VX@;6]R92!E=F5N('=I
M=&@@=&AE($]/;R!V:65W("TM/@H@("`@("`@("`@("`\>'-L.F5L96UE;G0@
M;F%M93TB8G(B+SX*("`@("`@("`\+WAS;#II9CX*("`@(#PO>'-L.G1E;7!L
M871E/@H*"@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@
M(#PA+2T@*BHJ(&]R9&5R960@;&ES="`J*BH@+2T^"B`@("`\(2TM("HJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@]
M(G1E>'0Z;W)D97)E9"UL:7-T(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64]
M(F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@("`@(#QX<VPZ8VAO
M;W-E/@H@("`@("`@("`@("`@("`@/"$M+2LK*RLK($-34R`H0T%30T%$24Y'
M(%-43%E%(%-(1454*2!(14%$15(@4U193$4@5T%9("LK*RLK+2T^"B`@("`@
M("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G0U-3
M7TA%041%4B<B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N
M86UE/2)O;"(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT
M96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD+6-O;G1E;G0B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT
M96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@
M("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@(#PA
M+2TK*RLK*R!(5$U,(#0N,"!)3DQ)3D5$(%=!62`@*RLK*RLM+3X*("`@("`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=#4U-?
M24Y,24Y%1"<B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N
M86UE/2)O;"(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT
M96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD+6-O;G1E;G0B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT
M96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@
M("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@(#PA
M+2TK*RLK*R!004Q-(#,N,B!354)3150@04Y$(%=!4"!)3DQ)3D5$(%=!62`@
M*RLK*RLM+3X*("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T
M<'5T5'EP92`]("=004Q-)R(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IE
M;&5M96YT(&YA;64](F]L(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N
M="(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C
M=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L
M96UE;G0^"B`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@
M("`@("`@/"$M+2LK*RLK(%=-3"`O(%=!4"`@*RLK*RLM+3X*("`@("`@("`@
M("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\(2TM('-I;75L
M871I;F<@8V]N=&5N="!B<F5A:R!O9B!C87!S=6QA=&5D(&QI<W0@96QE;65N
M=',@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2)A;F-E<W1O<CHZ=&5X=#IL:7-T+6ET96TB/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F%N8V5S=&]R.CHJ6V-O;G1A
M:6YS*"1W87`M<&%R86=R87!H+65L96UE;G1S+"!N86UE*"DI72(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@<VEM=6QA=&EN
M9R!C;VYT96YT(&)R96%K(&]F(&-A<'-U;&%T960@;&ES="!E;&5M96YT<R`M
M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IE
M;&5M96YT(&YA;64](F)R(CX\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M
M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B
M86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](G`B/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!S:6UU;&%T
M:6YG(&-O;G1E;G0@8G)E86L@;V8@8V%P<W5L871E9"!L:7-T(&5L96UE;G1S
M("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IE;&5M96YT(&YA;64](F)R(CX\+WAS;#IE;&5M96YT/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E
M;7!L871E(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB
M)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W
M:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L
M>2US='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B
M86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@
M/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@
M("`\+WAS;#IT96UP;&%T93X*"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ('5N;W)D97)E9"!L:7-T("HJ*B`M
M+3X*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*"B`@("`\
M>'-L.G1E;7!L871E(&UA=&-H/2)T97AT.G5N;W)D97)E9"UL:7-T(CX*("`@
M("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*
M"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#PA+2TK*RLK*R!#
M4U,@*$-!4T-!1$E.1R!35$Q912!32$5%5"D@2$5!1$52(%-464Q%(%=!62`K
M*RLK*RTM/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&]U='!U=%1Y
M<&4@/2`G0U-37TA%041%4B<B/@H@("`@("`@("`@("`@("`@/'AS;#IE;&5M
M96YT(&YA;64](G5L(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM
M=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O
M;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A
M=&$B+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E
M/@H@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@
M/"]X<VPZ=VAE;CX*"B`@("`@("`@("`@(#PA+2TK*RLK*R!(5$U,(#0N,"!)
M3DQ)3D5$(%=!62`@*RLK*RLM+3X*("`@("`@("`@("`@/'AS;#IW:&5N('1E
M<W0](B1O=71P=714>7!E(#T@)T-34U])3DQ)3D5$)R(^"B`@("`@("`@("`@
M("`@("`\>'-L.F5L96UE;G0@;F%M93TB=6PB/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD
M+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L
M;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT
M/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H*("`@("`@("`@("`@/"$M+2LK
M*RLK(%!!3$T@,RXR(%-50E-%5"!!3D0@5T%0($E.3$E.140@5T%9("`K*RLK
M*RTM/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&]U='!U=%1Y<&4@
M/2`G4$%,32<B/@H@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64]
M(G5L(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@
M;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L
M;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@
M("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*"B`@("`@("`@("`@(#PA+2TK*RLK*R!734P@+R!705`@("LK*RLK+2T^
M"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@
M/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@/"$M+2!S:6UU;&%T
M:6YG(&-O;G1E;G0@8G)E86L@;V8@8V%P<W5L871E9"!L:7-T(&5L96UE;G1S
M("TM/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)A;F-E
M<W1O<CHZ=&5X=#IL:7-T+6ET96TB/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2)A;F-E<W1O<CHZ*EMC;VYT86EN<R@D=V%P+7!A<F%G
M<F%P:"UE;&5M96YT<RP@;F%M92@I*5TB/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#PA+2T@<VEM=6QA=&EN9R!C;VYT96YT(&)R96%K(&]F
M(&-A<'-U;&%T960@;&ES="!E;&5M96YT<R`M+3X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB8G(B/CPO>'-L
M.F5L96UE;G0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N
M="(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0]
M(B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB<"(^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@<VEM=6QA=&EN9R!C
M;VYT96YT(&)R96%K(&]F(&-A<'-U;&%T960@;&ES="!E;&5M96YT<R`M+3X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M
M96YT(&YA;64](F)R(CX\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB
M87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C
M;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$
M871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L
M>2US='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A
M=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\
M+WAS;#IC:&]O<V4^"B`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@
M("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H*("`@
M(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H@("`@/"$M+2`J*BH@;&ES
M="!I=&5M("`J*BH@+2T^"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M
M+3X*"B`@("`\>'-L.G1E;7!L871E(&UA=&-H/2)T97AT.FQI<W0M:71E;2(^
M"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A
M(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\(2TM*RLK
M*RL@0U-3("A#05-#041)3D<@4U1,644@4TA%150I($A%041%4B!35%E,12!7
M05D@*RLK*RLM+3X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1O=71P
M=714>7!E(#T@)T-34U](14%$15(G(CX*("`@("`@("`@("`@("`@(#QX<VPZ
M96QE;65N="!N86UE/2)L:2(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IC
M86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N="(^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B
M86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP
M;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@
M("`@(#PO>'-L.G=H96X^"@H@("`@("`@("`@("`\(2TM*RLK*RL@2%1-3"`T
M+C`@24Y,24Y%1"!705D@("LK*RLK+2T^"B`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2(D;W5T<'5T5'EP92`]("=#4U-?24Y,24Y%1"<B/@H@("`@("`@
M("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](FQI(CX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S
M+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB
M)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@/"]X<VPZ96QE
M;65N=#X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*"B`@("`@("`@("`@(#PA
M+2TK*RLK*R!004Q-(#,N,B!354)3150@04Y$(%=!4"!)3DQ)3D5$(%=!62`@
M*RLK*RLM+3X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1O=71P=714
M>7!E(#T@)U!!3$TG(CX*("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N
M86UE/2)L:2(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L
M871E(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T
M961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^
M"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@
M("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@(#PO>'-L
M.G=H96X^"@H@("`@("`@("`@("`\(2TM*RLK*RL@5TU,("\@5T%0("`K*RLK
M*RTM/@H@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@
M("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2)A;F-E<W1O<CHZ*EMC;VYT86EN<R@D=V%P+7!A<F%G<F%P:"UE
M;&5M96YT<RP@;F%M92@I*5TB/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M(2TM('-I;75L871I;F<@;&ES="!E;&5M96YT<R`M+3X*("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0](F%N8V5S=&]R.CIT
M97AT.FQI<W0M:71E;2(^*CPO>'-L.F9O<BUE86-H/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G1E>'0^*B`\+WAS;#IT97AT/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM
M<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A
M(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#PA+2T@;&ES="!I=&5M(&)R96%K('-I;75L871I;VX@
M*&YO="!I;B!A('1A8FQE*2TM/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.FEF('1E<W0](FYO="AA;F-E<W1O<CHZ=&%B;&4Z=&%B;&4M8V5L;"D@
M;W(@9F]L;&]W:6YG+7-I8FQI;F<Z.G1E>'0Z;&ES="UI=&5M(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)B<B(O
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#II9CX*("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L
M96UE;G0@;F%M93TB<"(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M(2TM('-I;75L871I;F<@;&ES="!E;&5M96YT<R`M+3X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ9F]R+65A8V@@<V5L96-T/2)A;F-E<W1O
M<CHZ=&5X=#IL:7-T+6ET96TB/BH\+WAS;#IF;W(M96%C:#X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#XJ(#PO>'-L.G1E>'0^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@
M;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L
M;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T
M82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT
M96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@;&ES
M="!I=&5M(&)R96%K('-I;75L871I;VX@*&YO="!I;B!A('1A8FQE*2TM/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2)N;W0H
M86YC97-T;W(Z.G1A8FQE.G1A8FQE+6-E;&PI(&]R(&9O;&QO=VEN9RUS:6)L
M:6YG.CIT97AT.FQI<W0M:71E;2(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](F)R(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#II9CX*("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@
M("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O
M<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@
M(#PA+2T@*BHJ(%1E>'0@4V5C=&EO;B`H8V]N=&%I;G,Z(&1R87<Z=&5X="UB
M;W@I("HJ*B`M+3X*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*"B`@("`@("`@/'AS;#IT96UP
M;&%T92!M871C:#TB=&5X=#IS96-T:6]N(CX*("`@("`@("`\>'-L.G!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@/'AS;#II
M9B!T97-T/2)N;W0H8V]N=&%I;G,H0'1E>'0Z9&ES<&QA>2P@)VYO;F4G*2DB
M/@H@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@(#PA
M+2TK*RLK*R!#4U,@*$-!4T-!1$E.1R!35$Q912!32$5%5"D@2$5!1$52(%-4
M64Q%(%=!62`K*RLK*RTM/@H@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E
M<W0](B1O=71P=714>7!E(#T@)T-34U](14%$15(G(CX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB<W!A;B(^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US
M='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B
M('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@("`@(#PA+2TK*RLK*R!(5$U,(#0N,"!)3DQ)
M3D5$(%=!62`@*RLK*RLM+3X*("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2(D;W5T<'5T5'EP92`]("=#4U-?24Y,24Y%1"<B/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)S<&%N(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY
M+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T
M82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`\+WAS
M;#IW:&5N/@H@("`@("`@("`@("`@("`@/"$M+2LK*RLK(%!!3$T@,RXR(%-5
M0E-%5"!)3DQ)3D5$(%=!62`@*RLK*RLM+3X*("`@("`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=004Q-)R(^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VAE;B!T97-T/2)N86UE*'!A<F5N=#HZ*BD@/2`G=&5X=#IL
M:7-T+6ET96TG(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M
M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961'
M;&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC
M86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE
M/2)P(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A
M;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O
M;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@("`@("`\(2TM*RLK*RL@5TU,("\@5T%0("`K*RLK*RTM/@H@("`@
M("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2)N;W0H)&]U='!U=%1Y<&4@/2`G5TU,)RDB/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](F$B/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E
M(&YA;64](FAR968B/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)`>&QI;FLZ:')E
M9B(O/CPO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S
M+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A
M=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\(2TM(&YO(&YE<W1E9"!P('1A9W,@:6X@=VUL,2XQ(&%L
M;&]W960@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-H
M;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB86YC97-T;W(Z.BI;8V]N=&%I;G,H)'=A<"UP87)A9W)A<&@M
M96QE;65N=',L(&YA;64H*2E=(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T
M>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D
M1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL
M+71E;7!L871E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ96QE;65N="!N86UE/2)P(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE
M/2)A<'!L>2US='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961'
M;&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@(#PO>'-L.F]T
M:&5R=VES93X*("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@(#PO
M>'-L.FEF/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@("`\>'-L.G1E;7!L
M871E(&UA=&-H/2)T97AT.FQI;F4M8G)E86LB/@H@("`@("`@(#QX<VPZ96QE
M;65N="!N86UE/2)B<B(O/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*/"$M+0H@
M("`@5$%"2$%.1$Q)3D<@4%)/0DQ%33H@5&%B<R!A<F4@<&]S<VEB;&4@=&\@
M8F4@<VAO=VX@:6X@=&AE($A434P@=&5X="!F:6QE+"!B=70@=VEL;"!B92!L
M871E<B!S=')I<'!E9"!A<R!W:&ET97-P86-E<RX*("`@("`@("!4;R!P<F5V
M96YT('1H:7,@;VYE('=A>2!W;W5L9"!B92!T:&4@4%)%('1A9R!W:&EC:"!U
M;F9O<G1U;F%T96QY($%,5T%94R!R97-U;'0@:6YT;R!A(&QI;F4M8G)E86LN
M($YO('-U<G)O=6YD:6YG($Y/0E(@=&%G<R!H96QP+@H*("`@(#QX<VPZ=&5M
M<&QA=&4@;6%T8V@](G1E>'0Z=&%B+7-T;W`B/@H@("`@("`@(#QX<VPZ:68@
M=&5S=#TB;F]T*'!R96-E9&EN9RUS:6)L:6YG.CIT97AT.G1A8BUS=&]P*2(^
M"B`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)P<F4B/CQX<VPZ=&5X
M=#XF(SD[/"]X<VPZ=&5X=#X\>'-L.F9O<BUE86-H('-E;&5C=#TB9F]L;&]W
M:6YG+7-I8FQI;F<Z.G1E>'0Z=&%B+7-T;W`B/CQX<VPZ=&5X=#XF(SD[/"]X
M<VPZ=&5X=#X\+WAS;#IF;W(M96%C:#X\+WAS;#IE;&5M96YT/@H@("`@("`@
M(#PO>'-L.FEF/@H@("`@(#PO>'-L.G1E;7!L871E/@H*("`@(#QX<VPZ=&5M
M<&QA=&4@;6%T8V@](G1E>'0Z=&%B+7-T;W`B/CQX<VPZ=&5X=#XF(SD[/"]X
M<VPZ=&5X=#X\+WAS;#IT96UP;&%T93X*+2T^"B`@("`\(2TM($A/5$9)6#H@
M."!N;VXM8G)E86MA8FQE+7-P86-E<R!I;G-T96%D(&]F(&$@5$%"(&ES(&$@
M:&%C:R!S;VUE=&EM97,@;&5S<R!486)S(&%R92!N965D960@86YD('1H92!C
M;V1E(&UO<F4@9&EF9FEC=6QT('1O(')E860@+2T^"B`@("`\>'-L.G1E;7!L
M871E(&UA=&-H/2)T97AT.G1A8BUS=&]P(CX*("`@("`@("`\>'-L.F-A;&PM
M=&5M<&QA=&4@;F%M93TB=W)I=&4M8G)E86MA8FQE+7=H:71E<W!A8V4B/@H@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=VAI=&5S<&%C97,B
M('-E;&5C=#TB."(O/@H@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@
M("`\+WAS;#IT96UP;&%T93X*"B`@("`\(2TM(&-U<G)E;G1L>2!T:&5R92!H
M879E('1O(&)E(&%N(&5X<&QI8VET(&-A;&P@;V8@=&AE('-T>6QE(&%T=')I
M8G5T92!N;V1E<RP@;6%Y8F4@=&AE(&%T=')I8G5T97,@;F]D97,@:&%V92!N
M;R!P<FEO<FET>2!O;FQY(&]R9&5R(')E;&5V86YT+2T^"B`@("`\(2TM(%-4
M4D%.1T4Z(&-H96-K960@=VET:"!B:6]R>71H;2YS>&,@82!S:6UP;&4@>'-L
M.F%P<&QY+71E;7!L871E<R!D:60@;F]T(')E8V]G;FEC92!T:&4@<W1Y;&5S
M+B!-87EB92!C875S960@8GD@=&AE('1E;7!L871E(&UA=&-H(&]R9&5R/R`@
M+2T^"B`@("`\>'-L.G1E;7!L871E(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M
M8V]N=&5N="(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQL96-T961'
M;&]B86Q$871A(B\^"@H@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S('-E
M;&5C=#TB0'1E>'0Z<W1Y;&4M;F%M92!\($!D<F%W.G-T>6QE+6YA;64@?"!`
M9')A=SIT97AT+7-T>6QE+6YA;64@?"!`=&%B;&4Z<W1Y;&4M;F%M92(^/"$M
M+2!\($!P<F5S96YT871I;VXZ<W1Y;&4M;F%M92`M+3X*("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E
M;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`\+WAS;#IA
M<'!L>2UT96UP;&%T97,^"@H@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S
M/@H@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D
M1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@
M("`@("`@(#PO>'-L.F%P<&QY+71E;7!L871E<SX*("`@(#PO>'-L.G1E;7!L
M871E/@H*"B`@("`\>'-L.G1E;7!L871E(&UA=&-H/2)`=&5X=#IS='EL92UN
M86UE('P@0&1R87<Z<W1Y;&4M;F%M92!\($!D<F%W.G1E>'0M<W1Y;&4M;F%M
M92!\($!T86)L93IS='EL92UN86UE(CX\(2TM('P@0'!R97-E;G1A=&EO;CIS
M='EL92UN86UE+2T^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQL96-T
M961';&]B86Q$871A(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@
M("`@("`\(2TM*RLK*RL@0U-3("A#05-#041)3D<@4U1,644@4TA%150I($A%
M041%4B!35%E,12!705D@*RLK*RLM+3X*("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0](B1O=71P=714>7!E(#T@)T-34U](14%$15(G(CX*("`@("`@("`@
M("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](F-L87-S(CX\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB=')A;G-L871E*"XL("<N("4H*2]<)RP@)R<I(B\^/"]X
M<VPZ871T<FEB=71E/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H*("`@("`@
M("`@("`@/"$M+2LK*RLK($A434P@-"XP($E.3$E.140@5T%9("`K*RLK*RTM
M/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G
M0U-37TE.3$E.140G(CX*("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E
M(&YA;64](G-T>6QE(CX\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&-O;&QE8W1E
M9$=L;V)A;$1A=&$O86QL<W1Y;&5S+RI;;F%M92@I/6-U<G)E;G0H*2\N72(O
M/CPO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*"B`@
M("`@("`@("`@(#PA+2TK*RLK*R!004Q-(#,N,B!354)3150@24Y,24Y%1"!7
M05D@(&%N9"`@5TU,("\@5T%0("`@*RLK*RLM+3X*("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](B1O=71P=714>7!E(#T@)U!!3$TG(&]R("1O=71P=714
M>7!E(#T@)U=-3"<B/@H@("`@("`@("`@("`@("`@/"$M+2!G971T:6YG('1H
M92!C<W,@<W1Y;&5S(&9O<B!T:&4@<W1Y;&4@;F%M92`H;6%P<&5D(&)Y('-T
M>6QE+6UA<'!I;F<N>'-L*2`M+3X*("`@("`@("`@("`@("`@(#QX<VPZ=F%R
M:6%B;&4@;F%M93TB<W1Y;&50<F]P97)T:65S(B!S96QE8W0](B1C;VQL96-T
M961';&]B86Q$871A+V%L;'-T>6QE<R\J6VYA;64H*3UC=7)R96YT*"DO+ETB
M+SX*("`@("`@("`@("`@("`@(#PA+2T@8VAA;F=I;F<@=&AE(&-O;G1E>'0@
M;F]D92`M+3X*("`@("`@("`@("`@("`@(#QX<VPZ9F]R+65A8V@@<V5L96-T
M/2)P87)E;G0Z.BHB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT
M96UP;&%T92!N86UE/2)C<F5A=&4M;F5S=&5D+69O<FUA="UT86=S(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T
M>6QE4')O<&5R=&EE<R(@<V5L96-T/2(D<W1Y;&50<F]P97)T:65S(B\^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C
M;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$
M871A(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T
M93X*("`@("`@("`@("`@("`@(#PO>'-L.F9O<BUE86-H/@H@("`@("`@("`@
M("`\+WAS;#IW:&5N/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L
M.G1E;7!L871E/@H*"B`@("`\>'-L.G1E;7!L871E(&UA=&-H/2)T97AT.G-E
M<75E;F-E(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L
M;V)A;$1A=&$B+SX*"B`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,^"B`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B
M86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@
M("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@/"]X<VPZ=&5M<&QA=&4^
M"@H*/"]X<VPZ<W1Y;&5S:&5E=#X*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+V]O;R]T86)L92YX<VP`````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#0S-S`P(#$P-3$U-#,S-S,V(#`R,S<V,``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\(2TM
M"@H@("!4:&4@0V]N=&5N=',@;V8@=&AI<R!F:6QE(&%R92!M861E(&%V86EL
M86)L92!S=6)J96-T('1O('1H92!T97)M<R!O9@H@("!E:71H97(@;V8@=&AE
M(&9O;&QO=VEN9R!L:6-E;G-E<PH*("`@("`@("`@("T@1TY5($QE<W-E<B!'
M96YE<F%L(%!U8FQI8R!,:6-E;G-E(%9E<G-I;VX@,BXQ"B`@("`@("`@("`M
M(%-U;B!);F1U<W1R>2!3=&%N9&%R9',@4V]U<F-E($QI8V5N<V4@5F5R<VEO
M;B`Q+C$*"B`@(%-U;B!-:6-R;W-Y<W1E;7,@26YC+BP@3V-T;V)E<BP@,C`P
M,`H*("`@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8R!,:6-E;G-E(%9E<G-I
M;VX@,BXQ"B`@(#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/0H@("!#;W!Y<FEG:'0@,C`P,"!B>2!3=6X@36EC<F]S>7-T
M96US+"!);F,N"B`@(#DP,2!386X@06YT;VYI;R!2;V%D+"!086QO($%L=&\L
M($-!(#DT,S`S+"!54T$*"B`@(%1H:7,@;&EB<F%R>2!I<R!F<F5E('-O9G1W
M87)E.R!Y;W4@8V%N(')E9&ES=')I8G5T92!I="!A;F0O;W(*("`@;6]D:69Y
M(&ET('5N9&5R('1H92!T97)M<R!O9B!T:&4@1TY5($QE<W-E<B!'96YE<F%L
M(%!U8FQI8PH@("!,:6-E;G-E('9E<G-I;VX@,BXQ+"!A<R!P=6)L:7-H960@
M8GD@=&AE($9R964@4V]F='=A<F4@1F]U;F1A=&EO;BX*"B`@(%1H:7,@;&EB
M<F%R>2!I<R!D:7-T<FEB=71E9"!I;B!T:&4@:&]P92!T:&%T(&ET('=I;&P@
M8F4@=7-E9G5L+`H@("!B=70@5TE42$]55"!!3ED@5T%24D%.5%D[('=I=&AO
M=70@979E;B!T:&4@:6UP;&EE9"!W87)R86YT>2!O9@H@("!-15)#2$%.5$%"
M24Q)5%D@;W(@1DE43D534R!&3U(@02!005)424-53$%2(%!54E!/4T4N("!3
M964@=&AE($=.50H@("!,97-S97(@1V5N97)A;"!0=6)L:6,@3&EC96YS92!F
M;W(@;6]R92!D971A:6QS+@H*("`@66]U('-H;W5L9"!H879E(')E8V5I=F5D
M(&$@8V]P>2!O9B!T:&4@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8PH@("!,
M:6-E;G-E(&%L;VYG('=I=&@@=&AI<R!L:6)R87)Y.R!I9B!N;W0L('=R:71E
M('1O('1H92!&<F5E(%-O9G1W87)E"B`@($9O=6YD871I;VXL($EN8RXL(#4Y
M(%1E;7!L92!0;&%C92P@4W5I=&4@,S,P+"!";W-T;VXL"B`@($U!("`P,C$Q
M,2TQ,S`W("!54T$*"@H@("!3=6X@26YD=7-T<GD@4W1A;F1A<F1S(%-O=7)C
M92!,:6-E;G-E(%9E<G-I;VX@,2XQ"B`@(#T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*("`@5&AE(&-O;G1E;G1S
M(&]F('1H:7,@9FEL92!A<F4@<W5B:F5C="!T;R!T:&4@4W5N($EN9'5S=')Y
M(%-T86YD87)D<PH@("!3;W5R8V4@3&EC96YS92!697)S:6]N(#$N,2`H=&AE
M("),:6-E;G-E(BD[(%EO=2!M87D@;F]T('5S92!T:&ES(&9I;&4*("`@97AC
M97!T(&EN(&-O;7!L:6%N8V4@=VET:"!T:&4@3&EC96YS92X@66]U(&UA>2!O
M8G1A:6X@82!C;W!Y(&]F('1H90H@("!,:6-E;G-E(&%T(&AT='`Z+R]W=W<N
M;W!E;F]F9FEC92YO<F<O;&EC96YS92YH=&UL+@H*("`@4V]F='=A<F4@<')O
M=FED960@=6YD97(@=&AI<R!,:6-E;G-E(&ES('!R;W9I9&5D(&]N(&%N(")!
M4R!)4R(@8F%S:7,L"B`@(%=)5$A/550@5T%24D%.5%D@3T8@04Y9($M)3D0L
M($5)5$A%4B!%6%!215-3($]2($E-4$Q)140L($E.0TQ51$E.1RP*("`@5TE4
M2$]55"!,24U)5$%424].+"!705)204Y42453(%1(050@5$A%(%-/1E1705)%
M($E3($92144@3T8@1$5&14-44RP*("`@34520TA!3E1!0DQ%+"!&250@1D]2
M($$@4$%25$E#54Q!4B!055)03U-%+"!/4B!.3TXM24Y&4DE.1TE.1RX*("`@
M4V5E('1H92!,:6-E;G-E(&9O<B!T:&4@<W!E8VEF:6,@<')O=FES:6]N<R!G
M;W9E<FYI;F<@>6]U<B!R:6=H=',@86YD"B`@(&]B;&EG871I;VYS(&-O;F-E
M<FYI;F<@=&AE(%-O9G1W87)E+@H*("`@5&AE($EN:71I86P@1&5V96QO<&5R
M(&]F('1H92!/<FEG:6YA;"!#;V1E(&ES.B!3=6X@36EC<F]S>7-T96US+"!)
M;F,N"@H@("!#;W!Y<FEG:'0@PJD@,C`P,B!B>2!3=6X@36EC<F]S>7-T96US
M+"!);F,N"@H@("!!;&P@4FEG:'1S(%)E<V5R=F5D+@H*("`@0V]N=')I8G5T
M;W(H<RDZ(%]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?
M7PH*+2T^"CQX<VPZ<W1Y;&5S:&5E="!V97)S:6]N/2(Q+C`B"B`@("`@("`@
M("`@("`@("!X;6QN<SIX<VP](FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3DO6%-,
M+U1R86YS9F]R;2(*("`@("`@("`@("`@("`@('AM;&YS.F]F9FEC93TB:'1T
M<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O;V9F:6-E(@H@("`@("`@("`@("`@
M("`@>&UL;G,Z<W1Y;&4](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W-T
M>6QE(@H@("`@("`@("`@("`@("`@>&UL;G,Z=&5X=#TB:'1T<#HO+V]P96YO
M9F9I8V4N;W)G+S(P,#`O=&5X="(*("`@("`@("`@("`@("`@('AM;&YS.G1A
M8FQE/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]T86)L92(*("`@("`@
M("`@("`@("`@('AM;&YS.F1R87<](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R
M,#`P+V1R87=I;F<B"B`@("`@("`@("`@("`@("!X;6QN<SIF;STB:'1T<#HO
M+W=W=RYW,RYO<F<O,3DY.2]84TPO1F]R;6%T(@H@("`@("`@("`@("`@("`@
M>&UL;G,Z>&QI;FL](FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3DO>&QI;FLB"B`@
M("`@("`@("`@("`@("!X;6QN<SIN=6UB97(](FAT='`Z+R]O<&5N;V9F:6-E
M+F]R9R\R,#`P+V1A=&%S='EL92(*("`@("`@("`@("`@("`@('AM;&YS.G-V
M9STB:'1T<#HO+W=W=RYW,RYO<F<O,C`P,"]S=F<B"B`@("`@("`@("`@("`@
M("!X;6QN<SIC:&%R=#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O8VAA
M<G0B"B`@("`@("`@("`@("`@("!X;6QN<SID<C-D/2)H='1P.B\O;W!E;F]F
M9FEC92YO<F<O,C`P,"]D<C-D(@H@("`@("`@("`@("`@("`@>&UL;G,Z;6%T
M:#TB:'1T<#HO+W=W=RYW,RYO<F<O,3DY."]-871H+TUA=&A-3"(*("`@("`@
M("`@("`@("`@('AM;&YS.F9O<FT](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R
M,#`P+V9O<FTB"B`@("`@("`@("`@("`@("!X;6QN<SIS8W)I<'0](FAT='`Z
M+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W-C<FEP="(*("`@("`@("`@("`@("`@
M(&]F9FEC93IC;&%S<STB=&5X="(*("`@("`@("`@("`@("`@(&]F9FEC93IV
M97)S:6]N/2(Q+C`B"B`@("`@("`@("`@("`@("!X;6QN<SID8STB:'1T<#HO
M+W!U<FPN;W)G+V1C+V5L96UE;G1S+S$N,2\B"B`@("`@("`@("`@("`@("!X
M;6QN<SIM971A/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]M971A(@H@
M("`@("`@("`@("`@("`@>&UL;G,Z8V]N9FEG/2)H='1P.B\O;W!E;F]F9FEC
M92YO<F<O,C`P,2]C;VYF:6<B"B`@("`@("`@("`@("`@("!X;6QN<SIH96QP
M/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]H96QP(@H@("`@("`@("`@
M("`@("`@>&UL;G,Z>'0](FAT='`Z+R]W=W<N:F-L87)K+F-O;2]X="(*("`@
M("`@("`@("`@("`@('AM;&YS.G-Y<W1E;3TB:'1T<#HO+W=W=RYJ8VQA<FLN
M8V]M+WAT+VIA=F$O:F%V82YL86YG+E-Y<W1E;2(*("`@("`@("`@("`@("`@
M('AM;&YS.GAA;&%N/2)H='1P.B\O>&UL+F%P86-H92YO<F<O>&%L86XB"B`@
M("`@("`@("`@("`@("!X;6QN<SIJ879A/2)H='1P.B\O>&UL+F%P86-H92YO
M<F<O>'-L="]J879A(@H@("`@("`@("`@("`@("`@97AC;'5D92UR97-U;'0M
M<')E9FEX97,](FIA=F$B/@H*"B`@("`\(2TM('1A8FQE(')O=R!H86YD;&EN
M9R`M+3X*("`@(#QX<VPZ:6YC;'5D92!H<F5F/2)T86)L95]R;W=S+GAS;"(O
M/@H@("`@/"$M+2!T86)L92!C;VQU;6X@:&%N9&QI;F<@+2T^"B`@("`\>'-L
M.FEN8VQU9&4@:')E9CTB=&%B;&5?8V]L=6UN<RYX<VPB+SX*("`@(#PA+2T@
M=&%B;&4@8V5L;"!H86YD;&EN9R`M+3X*("`@(#QX<VPZ:6YC;'5D92!H<F5F
M/2)T86)L95]C96QL<RYX<VPB+SX*"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ(&UA:6X@=&%B;&4@("HJ*B`M+3X*
M("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*"B`@("`\>'-L.G1E
M;7!L871E(&UA=&-H/2)T86)L93IT86)L92!\('1A8FQE.G-U8BUT86)L92(^
M"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A
M(B\^"@H@("`@("`@(#PA+2T@82!T86)L92!W:6QL(&]N;'D@8F4@8W)E871E
M9"!I9B!T:&4@(G-C96YA<FEO(B!I<R!A8W1I=F4@+2T^"B`@("`@("`@/'AS
M;#II9B!T97-T/2)S=')I;F<M;&5N9W1H*'1A8FQE.G-C96YA<FEO+T!T86)L
M93II<RUA8W1I=F4I(#T@,"(^"B`@("`@("`@("`@(#PA+2T@8V]L;&5C=&EN
M9R!A;&P@=FES:6)L92`B=&%B;&4Z=&%B;&4M<F]W(B!E;&5M96YT<R!O9B!T
M:&4@=&%B;&4@+2T^"B`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB
M86QL5FES:6)L951A8FQE4F]W<R(@<V5L96-T/2)T86)L93IT86)L92UR;W=;
M;F]T*$!T86)L93IV:7-I8FEL:71Y(#T@)V-O;&QA<'-E)R!O<B!`=&%B;&4Z
M=FES:6)I;&ET>2`]("=F:6QT97(G*5T*("`@("`@("`@("`@("`@("`@("!\
M("`@('1A8FQE.G1A8FQE+6AE861E<BUR;W=S+V1E<V-E;F1A;G0Z.G1A8FQE
M.G1A8FQE+7)O=UMN;W0H0'1A8FQE.G9I<VEB:6QI='D@/2`G8V]L;&%P<V4G
M(&]R($!T86)L93IV:7-I8FEL:71Y(#T@)V9I;'1E<B<I70H@("`@("`@("`@
M("`@("`@("`@('P@("`@=&%B;&4Z=&%B;&4M<F]W+6=R;W5P+V1E<V-E;F1A
M;G0Z.G1A8FQE.G1A8FQE+7)O=UMN;W0H0'1A8FQE.G9I<VEB:6QI='D@/2`G
M8V]L;&%P<V4G(&]R($!T86)L93IV:7-I8FEL:71Y(#T@)V9I;'1E<B<I72(O
M/@H@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@(#PA
M+2T@9F]R(&%L;"!B=70@5T%0+U=-3"!D979I8V5S(&$@=&%B;&4@8F]R9&5R
M(&-H96-K(&ES(&1O;F4@*&-P+B`B8VAE8VLM9F]R+71A8FQE+6)O<F1E<B(I
M("TM/@H@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](FYO="@D;W5T
M<'5T5'EP92`]("=734PG*2(^"@H@("`@("`@("`@("`@("`@("`@(#PA+2T@
M07,@=&AE(&%L:6=N;65N="!O9B!A('1A8FQE(&ES(&)Y("=A;&EG;B<@871T
M<FEB=70@:7,@9&5P<F5C871E9"!A;F0@87,@=&AE($-34R`G9FQO870G(&%T
M=')I8G5T92!N;W0@=V5L;"!D:7-P;&%Y960L"B`@("`@("`@("`@("`@("`@
M("`@("`@("!W92!D;R!A(&QI='1L92!T<FEC:R!B>2!E;F-A<'-U;&%T:6YG
M('1H92!T86)L92!W:71H(&$@86QI9VYE9"`G9&EV)R!E;&5M96YT+2T^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)T86)L92UA
M;&EG;FUE;G0B('-E;&5C=#TB)&]F9FEC93IA=71O;6%T:6,M<W1Y;&5S+W-T
M>6QE.G-T>6QE6T!S='EL93IN86UE(#T@8W5R<F5N="@I+T!T86)L93IS='EL
M92UN86UE72]S='EL93IP<F]P97)T:65S+T!T86)L93IA;&EG;B(O/@H*("`@
M("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0](G-T<FEN9RUL96YG=&@H)'1A8FQE
M+6%L:6=N;65N="D@(3T@,"(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F5L96UE;G0@;F%M93TB9&EV(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)A;&EG;B(^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0])R1T86)L92UA;&EG;FUE;G0](FQE9G0B(&]R("1T86)L
M92UA;&EG;FUE;G0](FUA<F=I;G,B)SX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/FQE9G0\+WAS
M;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2<D=&%B;&4M86QI9VYM96YT/2)R
M:6=H="(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=&5X=#YR:6=H=#PO>'-L.G1E>'0^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0])R1T86)L92UA;&EG;FUE;G0](F-E;G1E<B(G/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YC
M96YT97(\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB=&%B;&4B
M/@H*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA
M<'!L>2UT96UP;&%T97,@<V5L96-T/2)`=&%B;&4Z<W1Y;&4M;F%M92(^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D
M8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^"@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\(2TM('=O<FMA<F]U;F0L
M('-E="!T86)L92!B;W)D97(@871T<FEB=70@:68@86YY(&-E;&PM8F]R9&5R
M(&5X:7-T<PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB8VAE8VLM9F]R+71A8FQE+6)O<F1E
M<B(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB86QL5FES:6)L951A8FQE4F]W<R(@<V5L
M96-T/2(D86QL5FES:6)L951A8FQE4F]W<R(O/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/B`M+3X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL
M+71E;7!L871E(&YA;64](F-R96%T92UC;VQU;6XM<W1Y;&4M=F%R:6%B;&4B
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F%L;%9I<VEB;&5486)L95)O=W,B('-E;&5C
M=#TB)&%L;%9I<VEB;&5486)L95)O=W,B+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C
M;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$
M871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W
M:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT
M(&YA;64](G1A8FQE(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F%P<&QY+71E;7!L871E<R!S96QE8W0](D!T86)L93IS='EL92UN
M86UE(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C
M=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^"@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@=V]R:V%R;W5N9"P@<V5T
M('1A8FQE(&)O<F1E<B!A='1R:6)U="!I9B!A;GD@8V5L;"UB;W)D97(@97AI
M<W1S"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL
M+71E;7!L871E(&YA;64](F-H96-K+69O<BUT86)L92UB;W)D97(B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB86QL5FES:6)L951A8FQE4F]W<R(@<V5L96-T/2(D86QL5FES
M:6)L951A8FQE4F]W<R(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^("`M+3X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB8W)E
M871E+6-O;'5M;BUS='EL92UV87)I86)L92(^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q6
M:7-I8FQE5&%B;&52;W=S(B!S96QE8W0](B1A;&Q6:7-I8FQE5&%B;&52;W=S
M(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T
M/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ8VAO;W-E/@H*("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@
M("`@(#PA+2T@9F]R(%=-3"!D979I8V5S(&]N;'D@05-#24D@=&%B;&4@87)E
M('=R:71T96X@87,@=&%B;&5S(&%R92!N;W0@:6UP;&5M96YT960@=VED;&5Y
M+@H@("`@("`@("`@("`@("`@("`@("!"96=I;FYI;F<@9G)O;2`G<F5P96%T
M+7=R:71E+7)O=R<@=&AE('1E;7!L871E<R!A<F4@:&%N9&QE9"!B>2!T:&4@
M=&%B;&5?=VUL+GAS;"!S='EL97-H965T("TM/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)C<F5A=&4M8V]L=6UN+7-T
M>6QE+79A<FEA8FQE(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B("`@<V5L96-T
M/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB86QL5FES:6)L951A8FQE4F]W
M<R(@('-E;&5C=#TB)&%L;%9I<VEB;&5486)L95)O=W,B+SX*("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@
M("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`\+WAS;#IC:&]O<V4^
M"B`@("`@("`@/"]X<VPZ:68^"B`@("`\+WAS;#IT96UP;&%T93X*"@H*("`@
M(#QX<VPZ=&5M<&QA=&4@;F%M93TB8W)E871E+6-O;'5M;BUS='EL92UV87)I
M86)L92(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQL96-T961';&]B
M86Q$871A(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)A;&Q6:7-I8FQE
M5&%B;&52;W=S(B\^"@H@("`@("`@(#PA+2T@86QL(&-O;'5M;G,@;V8@=&AE
M('1A8FQE("TM/@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB86QL5&%B
M;&5#;VQU;6YS(B!S96QE8W0](G1A8FQE.G1A8FQE+6-O;'5M;B!\"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@=&%B;&4Z=&%B;&4M8V]L=6UN+6=R;W5P+V1E<V-E;F1A;G0Z.G1A8FQE
M.G1A8FQE+6-O;'5M;B!\"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@=&%B;&4Z=&%B;&4M:&5A9&5R+6-O
M;'5M;G,O9&5S8V5N9&%N=#HZ=&%B;&4Z=&%B;&4M8V]L=6UN(B\^"B`@("`@
M("`@/"$M+2!A;&Q#;VQU;6Y3='EL945N=')I97,Z($-O;G1A:6YI;F<@86QL
M(&-O;'5M;G,@;V8@=&AE('1A8FQE+"!H:61D96X@86YD('9I97=E9"X*("`@
M("`@("`@("`@+2!I9B!A(&-O;'5M;B!I<R!H:61D96XL(&ET(&-O;G1A:6YS
M('1H92!H:61D96X@871T<FEB=71E+"!O=&AE<G=I<V4@=&AE('-T>6QE+7!R
M;W!E<G1I97,@=VEL;"!B92!S=&]R960*("`@("`@("`@("`@+2!I9B!A(&-O
M;'5M;B!I<R!B96EN9R!R97!E871E9"P@96%C:"!R97!E871E9"!C;VQU;6X@
M:7,@97AP;&EC:71L>2!W<FET=&5N(&%S(&5N=')Y(&EN('1H:7,@=F%R:6%B
M;&4N"B`@("`@("`@("`@("`@3&%T97(@*&1U<FEN9R!T96UP;&%T92`B=W)I
M=&4M8V5L;"(I('1H92!S='EL92!O9B!T:&4@8V]L=6UN('=I;&P@8F4@;6EX
M960@=VET:"!T:&4@8V5L;"US='EL92!B>2!U<VEN9PH@("`@("`@("`@("`@
M('1H92!P;W-I=&EO;B@I(&]F('1H92!C;VQU;6X@96YT<GD@86YD(&-O;7!A
M<FEN9R!I="!W:71H('1H92!I=&5R871I;F<@8V5L;"!N=6UB97(N("TM/@H@
M("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB86QL0V]L=6UN4W1Y;&5%;G1R
M:65S+5)41B(^"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE
M/2)A9&1I;F<M8V]L=6UN+7-T>6QE<RUE;G1R:65S(CX*("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A
M(B`@('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q486)L94-O;'5M;G,B
M("`@("`@<V5L96-T/2(D86QL5&%B;&5#;VQU;6YS(B\^"B`@("`@("`@("`@
M(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@/"]X<VPZ=F%R:6%B;&4^
M"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=X=#IN;V1E+7-E="<I(CX*("`@
M("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)C<F5A=&4M
M=&%B;&4B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)C;VQL96-T961';&]B86Q$871A(B`@("`@("!S96QE8W0](B1C;VQL
M96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F%L;%9I<VEB;&5486)L95)O=W,B("`@("`@<V5L
M96-T/2(D86QL5FES:6)L951A8FQE4F]W<R(O/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q#;VQU;6Y3='EL945N=')I
M97,B("`@('-E;&5C=#TB>'0Z;F]D92US970H)&%L;$-O;'5M;E-T>6QE16YT
M<FEE<RU25$8I(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L
M871E/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=X86QA;CIN;V1E<V5T
M)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64]
M(F-R96%T92UT86)L92(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B("`@("`@('-E;&5C
M=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB86QL5FES:6)L951A8FQE4F]W<R(@
M("`@("!S96QE8W0](B1A;&Q6:7-I8FQE5&%B;&52;W=S(B\^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%L;$-O;'5M;E-T
M>6QE16YT<FEE<R(@("`@<V5L96-T/2)X86QA;CIN;V1E<V5T*"1A;&Q#;VQU
M;6Y3='EL945N=')I97,M4E1&*2(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ
M8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`\+WAS;#IC:&]O<V4^"@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@("`\
M>'-L.G1E;7!L871E(&YA;64](F-R96%T92UT86)L92(^"B`@("`@("`@/'AS
M;#IP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@
M/'AS;#IP87)A;2!N86UE/2)A;&Q6:7-I8FQE5&%B;&52;W=S(B\^"B`@("`@
M("`@/'AS;#IP87)A;2!N86UE/2)A;&Q#;VQU;6Y3='EL945N=')I97,B+SX*
M"@H@("`@("`@(#PA+2T@4V]M92!/9F9I8V4@0V%L8R!D;V-U;65N=',@<VEM
M=6QA=&4@82!B86-K9W)O=6YD(&)Y(')E<&5A=&EN9R!T:&4@;&%S="!C96QL
M('5N=&EL(&5N9"!O9B!S<&%C90H@("`@("`@("`@("`@*%1H92!V86QU92!O
M9B`B=&%B;&4Z;G5M8F5R+6-O;'5M;G,M<F5P96%T960B(&ES(&5N;W5R;6]U
M<RDN(%=R:71I;F<@;W5T(&%L;"!T:&5S92!C96QL<R!W;W5L9"!B92!F871A
M;"X*("`@("`@("`@("`@(%1H97)E9F]R92P@=&AI<R!G;&]B86P@=F%R:6%B
M;&4@<VAO=W,@=7,@=&AE(&QO;F=E<W0@<F]W('=I=&@@8V]N=&5N="X*"B`@
M("`@("`@16%R;&EE<B!O;FQY('1H92!V:65W86)L92!C;VQU;6YS('=E<F4@
M;&ES=&5D+"!B=70@:70@:7,@96%S:65R('1O(&AA;F1L92!W:71H(&%L;"!C
M;VQU;6YS.@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB;6%X4F]W3&5N
M9W1H(B!S96QE8W0](F-O=6YT*"1A;&Q#;VQU;6Y3='EL945N=')I97,O8V]L
M=6UN+7-T>6QE+65N=')Y6VYO="A`8V]L=6UN+6AI9&1E;BUF;&%G*5TI(B\^
M("TM/@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB;6%X4F]W3&5N9W1H
M(B!S96QE8W0](F-O=6YT*"1A;&Q#;VQU;6Y3='EL945N=')I97,O8V]L=6UN
M+7-T>6QE+65N=')Y*2(O/@H*"B`@("`@("`@/"$M+6ES1&5B=6=-;V1E+5-4
M05)4+2T^"B`@("`@("`@/'AS;#II9B!T97-T/2(D:7-$96)U9TUO9&4B/@H@
M("`@("`@("`@("`\>'-L.FUE<W-A9V4^;6%X4F]W3&5N9W1H.B`\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB)&UA>%)O=TQE;F=T:"(O/CPO>'-L.FUE<W-A9V4^
M"B`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB;G5M8F5R3V9(:61D
M96Y#;VQU;6YS(B!S96QE8W0](F-O=6YT*"1A;&Q#;VQU;6Y3='EL945N=')I
M97,O8V]L=6UN+7-T>6QE+65N=')Y6T!C;VQU;6XM:&ED9&5N+69L86==*2(O
M/@H@("`@("`@("`@("`\>'-L.FUE<W-A9V4^;G5M8F5R3V9(:61D96Y#;VQU
M;6YS.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&YU;6)E<D]F2&ED9&5N0V]L
M=6UN<R(O/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT
M96UP;&%T92!N86UE/2)T86)L92UD96)U9RUA;&Q#;VQU;6Y3='EL945N=')I
M97,B/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%L
M;$-O;'5M;E-T>6QE16YT<FEE<R(@<V5L96-T/2(D86QL0V]L=6UN4W1Y;&5%
M;G1R:65S(B\^"B`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@
M("`@("`@/"]X<VPZ:68^"B`@("`@("`@/"$M+6ES1&5B=6=-;V1E+45.1"TM
M/@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TB)&]U='!U=%1Y<&4@/2`G5TU,)R(^"B`@("`@("`@("`@("`@("`\
M(2TM(&UA=&-H:6YG(&%L;"!R;W=S("T@=V4@8V%N(&YO="!U<V4@>'-L.F%P
M<&QY+71E;7!L871E('=I=&@@82!N;V1E+7-E="!P87)A;65T97(@87,@8GD@
M82!B=6<@:6X@6%0@*$IA;65S($-L87)K*0H@("`@("`@("`@("`@("`@("`@
M("`H:&5R93H@86QL0V]L=6UN4W1Y;&5%;G1R:65S*2!W:6QL(&)E(&EN=&5R
M<')E=&5D(&%S(&$@<F5S=6QT('1R964@9G)A9VUE;G0L('=H97)E(&YO('-E
M87)C:"!E>'!R97-S:6]N("A84&%T:"D@8V%N(&)E('5S960*("`@("`@("`@
M("`@("`@("`@("`@,D1/.D-(14-+(%=)5$@@6$%,04XM+3X*("`@("`@("`@
M("`@("`@(#QX<VPZ9F]R+65A8V@@<V5L96-T/2(D86QL5FES:6)L951A8FQE
M4F]W<R(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E
M(&YA;64](G=M;"UR97!E870M=W)I=&4M<F]W(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B("`@("`@('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F%L;$-O;'5M;E-T>6QE16YT<FEE<R(@("`@<V5L96-T/2(D86QL0V]L=6UN
M4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)N=6UB97(M<F]W<RUR97!E871E9"(@("`@('-E
M;&5C=#TB0'1A8FQE.FYU;6)E<BUR;W=S+7)E<&5A=&5D(B\^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)M87A2;W=,
M96YG=&@B("`@("`@("`@("`@('-E;&5C=#TB)&UA>%)O=TQE;F=T:"(O/@H@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@
M("`@("`@("`@("`\+WAS;#IF;W(M96%C:#X*("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@
M("`@("`\(2TM(&UA=&-H:6YG(&%L;"!R;W=S("T@=V4@8V%N(&YO="!U<V4@
M>'-L.F%P<&QY+71E;7!L871E('=I=&@@82!N;V1E+7-E="!P87)A;65T97(@
M87,@8GD@82!B=6<@:6X@6%0@*$IA;65S($-L87)K*0H@("`@("`@("`@("`@
M("`@("`@("`H:&5R93H@86QL0V]L=6UN4W1Y;&5%;G1R:65S*2!W:6QL(&)E
M(&EN=&5R<')E=&5D(&%S(&$@<F5S=6QT('1R964@9G)A9VUE;G0L('=H97)E
M(&YO('-E87)C:"!E>'!R97-S:6]N("A84&%T:"D@8V%N(&)E('5S960*("`@
M("`@("`@("`@("`@("`@("`@,D1/.D-(14-+(%=)5$@@6$%,04X@+2T^"B`@
M("`@("`@("`@("`@("`\>'-L.F9O<BUE86-H('-E;&5C=#TB)&%L;%9I<VEB
M;&5486)L95)O=W,B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT
M96UP;&%T92!N86UE/2)R97!E870M=W)I=&4M<F]W(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L
M;V)A;$1A=&$B("`@("`@('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B
M+SX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](F%L;$-O;'5M;E-T>6QE16YT<FEE<R(@("`@<V5L96-T/2(D86QL0V]L
M=6UN4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)N=6UB97(M<F]W<RUR97!E871E9"(@("`@
M('-E;&5C=#TB0'1A8FQE.FYU;6)E<BUR;W=S+7)E<&5A=&5D(B\^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)M87A2
M;W=,96YG=&@B("`@("`@("`@("`@('-E;&5C=#TB)&UA>%)O=TQE;F=T:"(O
M/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@
M("`@("`@("`@("`@("`\+WAS;#IF;W(M96%C:#X*("`@("`@("`@("`@/"]X
M<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L
M.G1E;7!L871E/@H*"@H*"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B!(14Q015(Z('1A8FQE(&)O<F1E
M<B`J*BH@+2T^"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BH@+2T^"@H@("`@/"$M+2!O;FQY(&]N92!T86)L92!B;W)D97(@9F]R($A4
M34PT(&]R($-34R!D979I8V5S('=H:6-H(&-O;G1A:6X@;VYE(&]R(&UO<F4@
M)V9O.F)O<F1E<BUT;W`G(&%T=')I8G5T97,@*'!A<G,@<')O('1O=&\L(&EF
M(&]N92!E>&ES="!T:&4@;W1H97(@=7-U86QL>2!E>&ES="P@=&]O*2`M+3X*
M("`@(#PA+2T@=&AI<R!W87,@82!W;W)K+6%R;W5N9"!F;W(@=&AE(&YE='-C
M87!E(#0N>'@@8G5T(&YO="!L;VYG97(@;F5C97-S87)Y(&9O<B!-;WII;&QA
M("TM/@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)C:&5C:RUF;W(M=&%B;&4M
M8F]R9&5R(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F%L;%9I<VEB;&54
M86)L95)O=W,B+SX*"B`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)S=&%R
M=%1I;64B/@H@("`@("`@("`@("`\>'-L.FEF('1E<W0](B1I<T1E8G5G36]D
M92!A;F0@;F]T*"1I<TIA=F%$:7-A8FQE9"DB/@H@("`@("`@("`@("`@("`@
M/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E
M<W0](F9U;F-T:6]N+6%V86EL86)L92@G<WES=&5M.F-U<G)E;G0M=&EM92UM
M:6QL:7,G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M
M;V8@<V5L96-T/2)S>7-T96TZ8W5R<F5N="UT:6UE+6UI;&QI<R@I(B\^"B`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=J879A
M.FIA=F$N;&%N9RY3>7-T96TN8W5R<F5N=%1I;65-:6QL:7,G*2(^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)J879A
M.FIA=F$N;&%N9RY3>7-T96TN8W5R<F5N=%1I;65-:6QL:7,H*2(O/@H@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`\
M+WAS;#IC:&]O<V4^"B`@("`@("`@("`@(#PO>'-L.FEF/@H@("`@("`@(#PO
M>'-L.G9A<FEA8FQE/@H*("`@("`@("`\(2TM(&-H96-K<R!I9B!O;F4@8V5L
M;"`H=&%B;&4Z=&%B;&4M8V5L;"D@;V8@=&AE(')O=W,@;V8@=&AI<R!T86)L
M92`H86QL5FES:6)L951A8FQE4F]W<RD@8V]N=&%I;G,@82!B;W)D97(@<W1Y
M;&4@*&DN92X@9F\Z8F]R9&5R+71O<"D*("`@("`@("`@("`@($EF(&]N;'D@
M;VYE('-I;F=L92!B;W)D97(@96QE;65N="!E>&ES="P@=&AE('=H;VQE('1A
M8FQE('=I;&P@9V5T<R!P<F4M9&5F:6YE9"!B;W)D97)S("AS:6UP;&4@:&5U
M<FES=&EC(&9O<B!B971T97(@8G)O=W-E<B!D:7-P;&%Y*2`M+3X*("`@("`@
M("`\>'-L.FEF('1E<W0](B1A;&Q6:7-I8FQE5&%B;&52;W=S+W1A8FQE.G1A
M8FQE+6-E;&Q;0'1A8FQE.G-T>6QE+6YA;64]+RHO*B]S='EL93IS='EL95MS
M='EL93IP<F]P97)T:65S+T!F;SIB;W)D97(M=&]P72]`<W1Y;&4Z;F%M95TB
M/@H@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)B;W)D97(B/C$\
M+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA
M;64](F)O<F1E<F-O;&]R(CXC,#`P,#`P/"]X<VPZ871T<FEB=71E/@H@("`@
M("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)C96QL<&%D9&EN9R(^,CPO
M>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M
M93TB8V5L;'-P86-I;F<B/C`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@
M(#QX<VPZ871T<FEB=71E(&YA;64](G!A9V4M8G)E86LM:6YS:61E(CYP86=E
M+6)R96%K+6EN<VED93IA=F]I9#PO>'-L.F%T=')I8G5T93X*("`@("`@("`\
M+WAS;#II9CX*"@H@("`@("`@(#PA+2T@8VAE8VL@=&AE('1I;64@9F]R(&)O
M<F1E<F-H96-K:6YG("AD96)U9RDM+3X*("`@("`@("`\>'-L.FEF('1E<W0]
M(B1I<T1E8G5G36]D92!A;F0@;F]T*"1I<TIA=F%$:7-A8FQE9"DB/@H@("`@
M("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F5N9%1I;64B/@H@("`@("`@
M("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G<WES=&5M.F-U<G)E
M;G0M=&EM92UM:6QL:7,G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2)S>7-T96TZ8W5R<F5N="UT:6UE+6UI;&QI
M<R@I(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA
M8FQE*"=J879A.FIA=F$N;&%N9RY3>7-T96TN8W5R<F5N=%1I;65-:6QL:7,G
M*2(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L
M96-T/2)J879A.FIA=F$N;&%N9RY3>7-T96TN8W5R<F5N=%1I;65-:6QL:7,H
M*2(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@
M("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@(#PO>'-L.G9A<FEA
M8FQE/@H@("`@("`@("`@("`\>'-L.FUE<W-A9V4^5&EM92!F;W(@8VAE8VMI
M;F<@0F]R9&5R4W1Y;&4Z(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(H)&5N9%1I
M;64@+2`D<W1A<G14:6UE*2(O/B!M<SPO>'-L.FUE<W-A9V4^"B`@("`@("`@
M/"]X<VPZ:68^"B`@("`\+WAS;#IT96UP;&%T93X*"CPO>'-L.G-T>6QE<VAE
M970^"@``````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O34E-12]6:65W97(O;V]O+W-T>6QE7VAE861E<BYX<VP`
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P-#(S,S8@,3`U,34T,S,W,S8@,#(U,S0U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#PA+2T*
M"B`@(%1H92!#;VYT96YT<R!O9B!T:&ES(&9I;&4@87)E(&UA9&4@879A:6QA
M8FQE('-U8FIE8W0@=&\@=&AE('1E<FUS(&]F"B`@(&5I=&AE<B!O9B!T:&4@
M9F]L;&]W:6YG(&QI8V5N<V5S"@H@("`@("`@("`@+2!'3E4@3&5S<V5R($=E
M;F5R86P@4'5B;&EC($QI8V5N<V4@5F5R<VEO;B`R+C$*("`@("`@("`@("T@
M4W5N($EN9'5S=')Y(%-T86YD87)D<R!3;W5R8V4@3&EC96YS92!697)S:6]N
M(#$N,0H*("`@4W5N($UI8W)O<WES=&5M<R!);F,N+"!/8W1O8F5R+"`R,#`P
M"@H@("!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N<V4@5F5R<VEO
M;B`R+C$*("`@/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]"B`@($-O<'ER:6=H="`R,#`P(&)Y(%-U;B!-:6-R;W-Y<W1E
M;7,L($EN8RX*("`@.3`Q(%-A;B!!;G1O;FEO(%)O860L(%!A;&\@06QT;RP@
M0T$@.30S,#,L(%5300H*("`@5&AI<R!L:6)R87)Y(&ES(&9R964@<V]F='=A
M<F4[('EO=2!C86X@<F5D:7-T<FEB=71E(&ET(&%N9"]O<@H@("!M;V1I9GD@
M:70@=6YD97(@=&AE('1E<FUS(&]F('1H92!'3E4@3&5S<V5R($=E;F5R86P@
M4'5B;&EC"B`@($QI8V5N<V4@=F5R<VEO;B`R+C$L(&%S('!U8FQI<VAE9"!B
M>2!T:&4@1G)E92!3;V9T=V%R92!&;W5N9&%T:6]N+@H*("`@5&AI<R!L:6)R
M87)Y(&ES(&1I<W1R:6)U=&5D(&EN('1H92!H;W!E('1H870@:70@=VEL;"!B
M92!U<V5F=6PL"B`@(&)U="!7251(3U54($%.62!705)204Y463L@=VET:&]U
M="!E=F5N('1H92!I;7!L:65D('=A<G)A;G1Y(&]F"B`@($U%4D-(04Y404))
M3$E462!O<B!&251.15-3($9/4B!!(%!!4E1)0U5,05(@4%524$]312X@(%-E
M92!T:&4@1TY5"B`@($QE<W-E<B!'96YE<F%L(%!U8FQI8R!,:6-E;G-E(&9O
M<B!M;W)E(&1E=&%I;',N"@H@("!9;W4@<VAO=6QD(&AA=F4@<F5C96EV960@
M82!C;W!Y(&]F('1H92!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC"B`@($QI
M8V5N<V4@86QO;F<@=VET:"!T:&ES(&QI8G)A<GD[(&EF(&YO="P@=W)I=&4@
M=&\@=&AE($9R964@4V]F='=A<F4*("`@1F]U;F1A=&EO;BP@26YC+BP@-3D@
M5&5M<&QE(%!L86-E+"!3=6ET92`S,S`L($)O<W1O;BP*("`@34$@(#`R,3$Q
M+3$S,#<@(%5300H*"B`@(%-U;B!);F1U<W1R>2!3=&%N9&%R9',@4V]U<F-E
M($QI8V5N<V4@5F5R<VEO;B`Q+C$*("`@/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@("!4:&4@8V]N=&5N=',@
M;V8@=&AI<R!F:6QE(&%R92!S=6)J96-T('1O('1H92!3=6X@26YD=7-T<GD@
M4W1A;F1A<F1S"B`@(%-O=7)C92!,:6-E;G-E(%9E<G-I;VX@,2XQ("AT:&4@
M(DQI8V5N<V4B*3L@66]U(&UA>2!N;W0@=7-E('1H:7,@9FEL90H@("!E>&-E
M<'0@:6X@8V]M<&QI86YC92!W:71H('1H92!,:6-E;G-E+B!9;W4@;6%Y(&]B
M=&%I;B!A(&-O<'D@;V8@=&AE"B`@($QI8V5N<V4@870@:'1T<#HO+W=W=RYO
M<&5N;V9F:6-E+F]R9R]L:6-E;G-E+FAT;6PN"@H@("!3;V9T=V%R92!P<F]V
M:61E9"!U;F1E<B!T:&ES($QI8V5N<V4@:7,@<')O=FED960@;VX@86X@(D%3
M($E3(B!B87-I<RP*("`@5TE42$]55"!705)204Y462!/1B!!3ED@2TE.1"P@
M14E42$52($584%)%4U,@3U(@24U03$E%1"P@24Y#3%5$24Y'+`H@("!7251(
M3U54($Q)34E4051)3TXL(%=!4E)!3E1)15,@5$A!5"!42$4@4T]&5%=!4D4@
M25,@1E)%12!/1B!$149%0U13+`H@("!-15)#2$%.5$%"3$4L($9)5"!&3U(@
M02!005)424-53$%2(%!54E!/4T4L($]2($Y/3BU)3D9224Y'24Y'+@H@("!3
M964@=&AE($QI8V5N<V4@9F]R('1H92!S<&5C:69I8R!P<F]V:7-I;VYS(&=O
M=F5R;FEN9R!Y;W5R(')I9VAT<R!A;F0*("`@;V)L:6=A=&EO;G,@8V]N8V5R
M;FEN9R!T:&4@4V]F='=A<F4N"@H@("!4:&4@26YI=&EA;"!$979E;&]P97(@
M;V8@=&AE($]R:6=I;F%L($-O9&4@:7,Z(%-U;B!-:6-R;W-Y<W1E;7,L($EN
M8RX*"B`@($-O<'ER:6=H="#"J2`R,#`R(&)Y(%-U;B!-:6-R;W-Y<W1E;7,L
M($EN8RX*"B`@($%L;"!2:6=H=',@4F5S97)V960N"@H@("!#;VYT<FEB=71O
M<BAS*3H@7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?
M"@HM+3X*/'AS;#IS='EL97-H965T('9E<G-I;VX](C$N,"(*("`@("`@("`@
M("`@("`@('AM;&YS.GAS;#TB:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]84TPO
M5')A;G-F;W)M(@H@("`@("`@("`@("`@("`@>&UL;G,Z;V9F:6-E/2)H='1P
M.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]O9F9I8V4B"B`@("`@("`@("`@("`@
M("!X;6QN<SIS='EL93TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O<W1Y
M;&4B"B`@("`@("`@("`@("`@("!X;6QN<SIT97AT/2)H='1P.B\O;W!E;F]F
M9FEC92YO<F<O,C`P,"]T97AT(@H@("`@("`@("`@("`@("`@>&UL;G,Z=&%B
M;&4](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W1A8FQE(@H@("`@("`@
M("`@("`@("`@>&UL;G,Z9')A=STB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P
M,#`O9')A=VEN9R(*("`@("`@("`@("`@("`@('AM;&YS.F9O/2)H='1P.B\O
M=W=W+G<S+F]R9R\Q.3DY+UA33"]&;W)M870B"B`@("`@("`@("`@("`@("!X
M;6QN<SIX;&EN:STB:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]X;&EN:R(*("`@
M("`@("`@("`@("`@('AM;&YS.FYU;6)E<CTB:'1T<#HO+V]P96YO9F9I8V4N
M;W)G+S(P,#`O9&%T87-T>6QE(@H@("`@("`@("`@("`@("`@>&UL;G,Z<W9G
M/2)H='1P.B\O=W=W+G<S+F]R9R\R,#`P+W-V9R(*("`@("`@("`@("`@("`@
M('AM;&YS.F-H87)T/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]C:&%R
M="(*("`@("`@("`@("`@("`@('AM;&YS.F1R,V0](FAT='`Z+R]O<&5N;V9F
M:6-E+F]R9R\R,#`P+V1R,V0B"B`@("`@("`@("`@("`@("!X;6QN<SIM871H
M/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DX+TUA=&@O36%T:$U,(@H@("`@("`@
M("`@("`@("`@>&UL;G,Z9F]R;3TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P
M,#`O9F]R;2(*("`@("`@("`@("`@("`@('AM;&YS.G-C<FEP=#TB:'1T<#HO
M+V]P96YO9F9I8V4N;W)G+S(P,#`O<V-R:7!T(@H@("`@("`@("`@("`@("`@
M;V9F:6-E.F-L87-S/2)T97AT(@H@("`@("`@("`@("`@("`@;V9F:6-E.G9E
M<G-I;VX](C$N,"(*("`@("`@("`@("`@("`@('AM;&YS.F1C/2)H='1P.B\O
M<'5R;"YO<F<O9&,O96QE;65N=',O,2XQ+R(*("`@("`@("`@("`@("`@('AM
M;&YS.FUE=&$](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+VUE=&$B"B`@
M("`@("`@("`@("`@("!X;6QN<SIC;VYF:6<](FAT='`Z+R]O<&5N;V9F:6-E
M+F]R9R\R,#`Q+V-O;F9I9R(*("`@("`@("`@("`@("`@('AM;&YS.FAE;'`]
M(FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+VAE;'`B"B`@("`@("`@("`@
M("`@("!X;6QN<SIX=#TB:'1T<#HO+W=W=RYJ8VQA<FLN8V]M+WAT(@H@("`@
M("`@("`@("`@("`@>&UL;G,Z<WES=&5M/2)H='1P.B\O=W=W+FIC;&%R:RYC
M;VTO>'0O:F%V82]J879A+FQA;F<N4WES=&5M(@H@("`@("`@("`@("`@("`@
M>&UL;G,Z>&%L86X](FAT='`Z+R]X;6PN87!A8VAE+F]R9R]X86QA;B(*("`@
M("`@("`@("`@("`@('AM;&YS.FIA=F$](FAT='`Z+R]X;6PN87!A8VAE+F]R
M9R]X<VQT+VIA=F$B"B`@("`@("`@("`@("`@("!E>&-L=61E+7)E<W5L="UP
M<F5F:7AE<STB:F%V82(^"@H*"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ('-T>6QE('-H965T('!R
M;V-E<W-I;F<@*BHJ("TM/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BH@+2T^"@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TG8W)E
M871E+6-S<RUS='EL96AE861E<B<^"B`@("`@("`@/'AS;#IC;VUM96YT/@H@
M("`@("`@("`@("`\>'-L.G1E>'0^5&AE($-34R!S='EL92!H96%D97(@;65T
M:&]D(&9O<B!S971T:6YG('-T>6QE<SPO>'-L.G1E>'0^"B`@("`@("`@/"]X
M<VPZ8V]M;65N=#X*("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB<W1Y;&4B
M/@H@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)T>7!E(CYT97AT
M+V-S<SPO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@/'AS;#IC;VUM96YT
M/@H@("`@("`@("`@("`@("`@/'AS;#IT97AT/@H*("`@("`@("`\+WAS;#IT
M97AT/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64]
M(G=R:71E+61E9F%U;'0M<W1Y;&5S(B\^"@H@("`@("`@("`@("`@("`@/"$M
M+2!42$4@4U193$4@4%)/4$525$E%4R!/1B!42$4@1DE24U0@5U))5%1%3B!3
M5%E,12`H4$%214Y4*2!)4R!'259%3B!/550@+2T^"@H@("`@("`@("`@("`@
M("`@/"$M+2`Q*2!S='EL97,@9G)O;2!O9F9I8V4Z<W1Y;&5S(&%R92!P;W-S
M:6)L92!P87)E;G0@9G)O;2!A;&P@*&ET<V5L9B!O<B!O9F9I8V4Z875T;VUA
M=&EC+7-T>6QE<RDN"B`@("`@("`@("`@("`@("`@("`@(%1H97)E9F]R92!T
M:&5Y(&%R92!C<F5A=&5D(&9I<G-T+@H@("`@("`@("`@("`@("`@("`@("!"
M96=I;FYI;F<@=VET:"!T:&4@=&]P+6QE=F5L('!A<F5N=',@*'1H92!S='EL
M97,@=VET:&]U="!A;GD@<&%R96YT*2X@+2T^"B`@("`@("`@("`@("`@("`\
M>'-L.F9O<BUE86-H('-E;&5C=#TB)&]F9FEC93IS='EL97,O<W1Y;&4Z<W1Y
M;&5;;F]T*$!S='EL93IP87)E;G0M<W1Y;&4M;F%M92E=(CX*"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G=R:71E+7-T
M>6QE<')O<&5R='DM;&EN92(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M8V%L;"UT96UP;&%T92!N86UE/2)W<FET92US='EL97!R;W!E<G1Y+6QI;F5S
M+69O<BUC:&EL9')E;B(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ9F]R+65A
M8V@^"@H@("`@("`@("`@("`@("`@/'AS;#IT97AT/B`\+WAS;#IT97AT/@H*
M("`@("`@("`@("`@("`@(#PA+2T@,BD@<W1Y;&5S(&9R;VT@;V9F:6-E.F%U
M=&]M871I8RUS='EL97,@8V%N(&]N;'D@8F4@<&%R96YT(&]F('-T>6QE<R!F
M<F]M('1H92!O9F9I8V4Z875T;VUA=&EC+7-T>6QE<R!S96-T:6]N+@H@("`@
M("`@("`@("`@("`@("`@("!"96=I;FYI;F<@=VET:"!T;W`M;&5V96P@<W1Y
M;&5S+"!A9V%I;BP@86QL(&-H:6QD<F5N('-T>6QE('=I;&P@8F4@<F5C=7)S
M:79L>2!T<F%V97)S960@+2T^"B`@("`@("`@("`@("`@("`\>'-L.F9O<BUE
M86-H('-E;&5C=#TB)&]F9FEC93IA=71O;6%T:6,M<W1Y;&5S+W-T>6QE.G-T
M>6QE6VYO="A`<W1Y;&4Z<&%R96YT+7-T>6QE+6YA;64I72(^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G=R:71E+7-T
M>6QE<')O<&5R='DM;&EN92(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)S96%R8VA/;FQY26Y!=71O;6%T:6-3='EL
M97,B('-E;&5C=#TB=')U92@I(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`\>'-L.F-A
M;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M<W1Y;&5P<F]P97)T>2UL:6YE<RUF
M;W(M8VAI;&1R96XB/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB<V5A<F-H3VYL>4EN075T;VUA=&EC4W1Y;&5S(B\^
M"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@
M("`@("`@("`@("`@(#PO>'-L.F9O<BUE86-H/@H@("`@("`@("`@("`O+SPO
M>'-L.F-O;6UE;G0^"B`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@(#PO>'-L
M.G1E;7!L871E/@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64])W=R:71E+7-T
M>6QE<')O<&5R='DM;&EN92<^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)S
M96%R8VA/;FQY26Y!=71O;6%T:6-3='EL97,B+SX*"B`@("`@("`@/'AS;#IV
M87)I86)L92!N86UE/2)S='EL95!R;W!E<G1I97,B/@H@("`@("`@("`@("`\
M>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M<W1Y;&4M<')O<&5R=&EE
M<R(^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y
M;&5!='1R:6)U=&50871H(B`@('-E;&5C=#TB8W5R<F5N="@I+W-T>6QE.G!R
M;W!E<G1I97,O0"HB+SX*("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T
M93X*("`@("`@("`\+WAS;#IV87)I86)L93X*"B`@("`@("`@/"$M+2!D;R!N
M;W0@=W)I=&4@<W1Y;&5S('=I=&@@;F\@8W-S('!R;W!E<G1Y("TM/@H@("`@
M("`@(#QX<VPZ:68@=&5S=#TB;F]T*'-T<FEN9RUL96YG=&@H)'-T>6QE4')O
M<&5R=&EE<RD@/2`P*2(^"B`@("`@("`@("`@(#PA+2T@=W)I=&4@;W5T('1H
M92!N86UE(&]F('1H92!C=7)R96YT("AP87)E;G0I('-T>6QE(&EN('1H92!#
M4U,@:&5A9&5R<V5C=&EO;B`H92YG+B`B<W!A;BYM>5-T>6QE(BD@+2T^"B`@
M("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)W<FET92US='EL
M92UN86UE(CX*("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)I<RUP87)E;G0M<W1Y;&4B('-E;&5C=#TB=')U92@I(B\^"B`@("`@("`@
M("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"@H@("`@("`@("`@("`\(2TM('1H
M92!N86UE<R!O9B!A;&P@<W1Y;&5S(&-H:6QD<F5N('=I;&P@8F4@=W)I='1E
M;B!O=70H;V9F:6-E.G-T>6QE($%.1"!O9F9I8V4Z875T;VUA=&EC+7-T>6QE
M*2`M+3X*("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G=R
M:71E+6-H:6QD<F5N+7-T>6QE+6YA;65S(CX*("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)P87)E;G13='EL94YA;64B("`@("`@("`@
M('-E;&5C=#TB0'-T>6QE.FYA;64B+SX*("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)P87)E;G13='EL949A;6EL>2(@("`@("`@('-E
M;&5C=#TB0'-T>6QE.F9A;6EL>2(O/@H@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](G-E87)C:$]N;'E);D%U=&]M871I8U-T>6QE<R(O
M/@H@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H*("`@("`@("`\
M(2TM('1H92!S='EL92!P<F]P97)T:65S(&]F('1H92!F:7)S="!W<FET=&5N
M('-T>6QE("AP87)E;G0I(&ES(&=I=F5N(&]U="`M+3X*("`@("`@("`\>'-L
M.G1E>'0^('L*("`@("`@("`@("`@("`@(#PO>'-L.G1E>'0^"B`@("`@("`@
M("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'-T>6QE4')O<&5R=&EE
M<R(O/@H@("`@("`@(#QX<VPZ=&5X=#Y]"B`@("`@("`@/"]X<VPZ=&5X=#X*
M"B`@("`@("`@/"]X<VPZ:68^"@H*"B`@("`\+WAS;#IT96UP;&%T93X*"@H*
M"B`@("`\(2TM(%)%0U524TE/3B!7251(($5.1$-/3D1)5$]..B!A9&1I;F<@
M<W1Y;&4@8VQA<W-E<R!F;W(@86QL(&5X:7-T:6YG(&-H:6QD<R`M+3X*("`@
M(#QX<VPZ=&5M<&QA=&4@;F%M93TG=W)I=&4M<W1Y;&5P<F]P97)T>2UL:6YE
M<RUF;W(M8VAI;&1R96XG/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB<V5A
M<F-H3VYL>4EN075T;VUA=&EC4W1Y;&5S(B\^"@H@("`@("`@(#QX<VPZ=F%R
M:6%B;&4@;F%M93TB<&%R96YT4W1Y;&5.86UE(B`@("!S96QE8W0](D!S='EL
M93IN86UE(B\^"B`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)P87)E;G13
M='EL949A;6EL>2(@('-E;&5C=#TB0'-T>6QE.F9A;6EL>2(O/@H*("`@("`@
M("`\>'-L.FEF('1E<W0](FYO="AS96%R8VA/;FQY26Y!=71O;6%T:6-3='EL
M97,I(CX*("`@("`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0](BXN+W-T
M>6QE.G-T>6QE6T!S='EL93IF86UI;'D])'!A<F5N=%-T>6QE1F%M:6QY(&%N
M9"!`<W1Y;&4Z<&%R96YT+7-T>6QE+6YA;64])'!A<F5N=%-T>6QE3F%M95TB
M/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G=R
M:71E+7-T>6QE<')O<&5R='DM;&EN92(O/@H@("`@("`@("`@("`@("`@/'AS
M;#IC86QL+71E;7!L871E(&YA;64](G=R:71E+7-T>6QE<')O<&5R='DM;&EN
M97,M9F]R+6-H:6QD<F5N(B\^"B`@("`@("`@("`@(#PO>'-L.F9O<BUE86-H
M/@H@("`@("`@(#PO>'-L.FEF/@H@("`@("`@(#QX<VPZ9F]R+65A8V@@<V5L
M96-T/2(D;V9F:6-E.F%U=&]M871I8RUS='EL97,O<W1Y;&4Z<W1Y;&5;0'-T
M>6QE.F9A;6EL>3TD<&%R96YT4W1Y;&5&86UI;'D@86YD($!S='EL93IP87)E
M;G0M<W1Y;&4M;F%M93TD<&%R96YT4W1Y;&5.86UE72(^"B`@("`@("`@("`@
M(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)W<FET92US='EL97!R;W!E<G1Y
M+6QI;F4B/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(G-E87)C:$]N;'E);D%U=&]M871I8U-T>6QE<R(O/@H@("`@("`@("`@("`\
M+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`\>'-L.F-A;&PM=&5M
M<&QA=&4@;F%M93TB=W)I=&4M<W1Y;&5P<F]P97)T>2UL:6YE<RUF;W(M8VAI
M;&1R96XB/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(G-E87)C:$]N;'E);D%U=&]M871I8U-T>6QE<R(O/@H@("`@("`@("`@("`\
M+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@(#PO>'-L.F9O<BUE86-H/@H@
M("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB
M=W)I=&4M9&5F875L="US='EL97,B/@H*("`@("`@("`\(2TM('-O;64@9&5F
M875L="!A='1R:6)U=&5S(&EN('AM;"!H879E('1O(&)E(&5X<&QI8VET;'D@
M<V5T(&EN($A434P@*&4N9RX@;6%R9VEN+71O<#TB,"(I("TM/@H@("`@("`@
M(#QX<VPZ=&5X=#XJ+D]/;U]D969A=6QT<SPO>'-L.G1E>'0^"@H@("`@("`@
M("`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0](B1O9F9I8V4Z<W1Y;&5S
M+W-T>6QE.G-T>6QE(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^
M+"`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M
M;V8@<V5L96-T/2)C;VYC870H)RHN)RP@=')A;G-L871E*$!S='EL93IN86UE
M+"`G+B`E*"DO7"<L("<G*2DB+SX*("`@("`@("`@("`@("`@(#PO>'-L.F9O
M<BUE86-H/@H*("`@("`@("`@("`@("`@(#QX<VPZ9F]R+65A8V@@<V5L96-T
M/2(D;V9F:6-E.F%U=&]M871I8RUS='EL97,O<W1Y;&4Z<W1Y;&4B/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#XL(#PO>'-L.G1E>'0^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O;F-A="@G
M*BXG+"!T<F%N<VQA=&4H0'-T>6QE.FYA;64L("<N("4H*2]<)RP@)R<I*2(O
M/@H@("`@("`@("`@("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@("`@("`@/"$M
M+2`R1$\Z('1H92!D969A=6QT<R!M:6=H="!B92!B971T97(@8V]L;&5C=&5D
M(&%N9"!W<FET=&5N(&EN(&$@<V5P87)A=&5D("A834PI(&9I;&4@+2T^"CQX
M<VPZ=&5X=#X@>PH@("`@("`@("`@("`@("`@;6%R9VEN+71O<#HP8VT[(&UA
M<F=I;BUB;W1T;VTZ,&-M.R!]"B`@("`@("`@/"]X<VPZ=&5X=#X*"B`@("`@
M("`@/'AS;#IF;W(M96%C:"!S96QE8W0](B1O9F9I8V4Z<W1Y;&5S+W-T>6QE
M.F1E9F%U;'0M<W1Y;&4B/@H@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA
M=&4@;F%M93TB=W)I=&4M9&5F875L="US='EL92(O/@H@("`@("`@(#PO>'-L
M.F9O<BUE86-H/@H*("`@("`@("`\>'-L.F9O<BUE86-H('-E;&5C=#TB)&]F
M9FEC93IA=71O;6%T:6,M<W1Y;&5S+W-T>6QE.F1E9F%U;'0M<W1Y;&4B/@H@
M("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M9&5F
M875L="US='EL92(O/@H@("`@("`@(#PO>'-L.F9O<BUE86-H/@H*("`@(#PO
M>'-L.G1E;7!L871E/@H*"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)W<FET
M92UD969A=6QT+7-T>6QE(CX*("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64]
M(F9A;6EL>2US='EL92(@<V5L96-T/2)`<W1Y;&4Z9F%M:6QY(B\^"@H@("`@
M("`@(#PA+2T@<V]M92!D969A=6QT(&%T=')I8G5T97,@9F]R(&9O<FUA="!F
M86UI;&EE<R`H92YG+B!G<F%P:&EC<RP@<&%R86=R87!H<RP@971C+BD@=W)I
M='1E;B!A<R!S='EL93ID969A=6QT+7-T>6QE("TM/@H@("`@("`@(#QX<VPZ
M=F%L=64M;V8@<V5L96-T/2)C;VYC870H)RHN)RP@=')A;G-L871E*"1F86UI
M;'DM<W1Y;&4L("<N("4H*2]<)RP@)R<I+"`G7V1E9F%U;'1S)RDB+SX*"B`@
M("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0](B1O9F9I8V4Z<W1Y;&5S+W-T
M>6QE.G-T>6QE6T!S='EL93IF86UI;'D@/2`D9F%M:6QY+7-T>6QE72(^"B`@
M("`@("`@("`@(#QX<VPZ=&5X=#XL(#PO>'-L.G1E>'0^"B`@("`@("`@("`@
M(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC870H)RHN)RP@=')A;G-L871E
M*$!S='EL93IN86UE+"`G+B`E*"DO7"<L("<G*2DB+SX*("`@("`@("`\+WAS
M;#IF;W(M96%C:#X*"B`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0](B1O
M9F9I8V4Z875T;VUA=&EC+7-T>6QE<R]S='EL93IS='EL95M`<W1Y;&4Z9F%M
M:6QY(#T@)&9A;6EL>2US='EL95TB/@H@("`@("`@("`@("`\>'-L.G1E>'0^
M+"`\+WAS;#IT97AT/@H@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB8V]N8V%T*"<J+B<L('1R86YS;&%T92A`<W1Y;&4Z;F%M92P@)RX@)2@I
M+UPG+"`G)RDI(B\^"B`@("`@("`@/"]X<VPZ9F]R+65A8V@^"@H*("`@("`@
M("`\>'-L.G9A<FEA8FQE(&YA;64](G-T>6QE4')O<&5R=&EE<R(^"B`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)W<FET92US='EL92UP
M<F]P97)T:65S(CX*("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)S='EL94%T=')I8G5T95!A=&@B("`@<V5L96-T/2)C=7)R96YT*"DO
M<W1Y;&4Z<')O<&5R=&EE<R]`*B(O/@H@("`@("`@("`@("`\+WAS;#IC86QL
M+71E;7!L871E/@H@("`@("`@(#PO>'-L.G9A<FEA8FQE/@H*("`@("`@("`\
M(2TM(&1O(&YO="!W<FET92!S='EL97,@=VET:"!N;R!C<W,@<')O<&5R='D@
M+2T^"B`@("`@("`@/'AS;#II9B!T97-T/2)N;W0H<W1R:6YG+6QE;F=T:"@D
M<W1Y;&50<F]P97)T:65S*2`](#`I(CX*("`@("`@("`\(2TM('1H92!S='EL
M92!P<F]P97)T:65S(&]F('1H92!F:7)S="!W<FET=&5N('-T>6QE("AP87)E
M;G0I(&ES(&=I=F5N(&]U="`M+3X*("`@("`@("`\>'-L.G1E>'0^('L*("`@
M("`@("`@("`@("`@(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB)'-T>6QE4')O<&5R=&EE<R(O/@H@("`@("`@
M(#QX<VPZ=&5X=#Y]"B`@("`@("`@/"]X<VPZ=&5X=#X*("`@("`@("`\+WAS
M;#II9CX*"B`@("`\+WAS;#IT96UP;&%T93X*"@H@("`@/"$M+2LK"B`@("`@
M("`@("!4:&4@<&%R96YT('-T>6QE('=I;&P@8F4@=W)I='1E;B!O=70A"B`@
M("`@("`@("!&;W(@96%C:"!3='EL93IF86UI;'D@82!P<F5F:7@@;75S="!B
M92!A9&1E9`H@("`@("`@("`@("`\(45.5$E462`E('-T>6QE1F%M:6QY"B`@
M("`@("`@("`@("(H<&%R86=R87!H?'1E>'1\<V5C=&EO;GQT86)L97QT86)L
M92UC;VQU;6Y\=&%B;&4M<F]W?'1A8FQE+6-E;&Q\=&%B;&4M<&%G97QC:&%R
M='QG<F%P:&EC<WQD969A=6QT?&1R87=I;F<M<&%G97QP<F5S96YT871I;VY\
M8V]N=')O;"DB/@H@("`@("`@("LK+2T^"B`@("`\>'-L.G1E;7!L871E(&YA
M;64](G=R:71E+7-T>6QE+6YA;64B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M
M93TB:7,M<&%R96YT+7-T>6QE(B\^"@H@("`@("`@(#PA+2T@5&AI<R!C;VYS
M=')U8W0@:7,@9F]R(&QI<W0@96QE;65N=',N(%=H96YE=F5R(&$@<&%R86=R
M87!H(&5L96UE;G0@:7,@8F5I;F<@=7-E9"!A<R!C:&EL9"!O9B!A(&QI<W0@
M96QE;65N="!T:&4@;F%M92!P87)A9W)A<&@@<W1Y;&4@:7,@8F5E;B!U<V5D
M(&9O<@H@("`@("`@("`@("!T:&4@;&ES="!I=&5M+B!4:&ES(&-A;B!B92!S
M=VET8VAE9"!A<R!T:&4@<&%R86=A<&@@<W1Y;&4M;F%M92!A;F0@=&AE(&QI
M<W0M<W1Y;&4M;F%M92!A<F4@:6X@=&AE('-A;64@96QE;65N="X*("`@("`@
M("`@("`@3W1H97)W:7-E('1H97)E('=O=6QD(&)E(&9O<FUA='1I;F<@97)R
M;W)S("AE+F<N(&UA<F=I;BUL969T('=I;&P@8F4@=7-E9"!F;W(@=&AE(&-O
M;G1E;G0@:6X@=&AE(&QI<W0@96QM96YT(&%N9"!N;W0@9F]R('1H92!L:7-T
M(&5L96UE;G0@:71S96QF*2X@+2T^"B`@("`@("`@/'AS;#IV87)I86)L92!N
M86UE/2)S='EL92UN86UE(CX*("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@
M("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB0'-T>6QE.FQI<W0M<W1Y
M;&4M;F%M92(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S
M96QE8W0](D!S='EL93IL:7-T+7-T>6QE+6YA;64B+SX*("`@("`@("`@("`@
M("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES
M93X*("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M0'-T>6QE.FYA;64B+SX*("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES
M93X*("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@(#PO>'-L.G9A
M<FEA8FQE/@H*("`@("`@("`\>'-L.FEF('1E<W0](FYO="@D:7,M<&%R96YT
M+7-T>6QE*2(^"B`@("`@("`@("`@(#QX<VPZ=&5X=#XL(#PO>'-L.G1E>'0^
M"B`@("`@("`@/"]X<VPZ:68^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@
M("`@("`@("`\(2TM(&YO<FUA;&QY("=P+B<@=V]U;&0@8F4@=7-E9"!A<R!#
M4U,@96QE;65N="P*("`@("`@("`@("`@("`@("!B=70@:&5A9&5R("AH,2P@
M:#(L+BXN*2!A<F4@86QS;R!F<F]M('1H92!S='EL93IF86UI;'D@<&%R86=R
M87!H("TM/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB0'-T>6QE.F9A
M;6EL>3TG<&%R86=R87!H)R(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB8V]N8V%T*"<J+B<L('1R86YS;&%T92@D<W1Y;&4M;F%M
M92P@)RX@)2@I+UPG+"`G)RDI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`<W1Y;&4Z9F%M:6QY/2=T
M97AT)R(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M8V]N8V%T*"<J+B<L('1R86YS;&%T92@D<W1Y;&4M;F%M92P@)RX@)2@I+UPG
M+"`G)RDI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@
M(#QX<VPZ=VAE;B!T97-T/2)`<W1Y;&4Z9F%M:6QY/2=S96-T:6]N)R(^"B`@
M("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"<J
M+B<L('1R86YS;&%T92@D<W1Y;&4M;F%M92P@)RX@)2@I+UPG+"`G)RDI(B\^
M"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2)`<W1Y;&4Z9F%M:6QY/2=T86)L92<B/@H@("`@("`@("`@("`@
M("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O;F-A="@G=&%B;&4N)RP@=')A
M;G-L871E*"1S='EL92UN86UE+"`G+B`E*"DO7"<L("<G*2DB+SX*("`@("`@
M("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(D!S='EL93IF86UI;'D])W1A8FQE+6-O;'5M;B<B/@H@("`@("`@("`@("`\
M(2TM(&%S(&-O;'5M;B!S='EL97,@:&%V92!T;R!B92!I;F-L=61E9"!A<R!S
M<&%N('-T>6QE<R!!1E1%4B!T:&4@=&%B;&4@*&YO('1W;R!C;&%S<R!A='1R
M:6)U=&5S(&EN(%1$(&%L;&]W960@+2T^"B`@("`@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"<J+B<L('1R86YS;&%T92@D<W1Y
M;&4M;F%M92P@)RX@)2@I+UPG+"`G)RDI(B\^"B`@("`@("`@("`@(#PO>'-L
M.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`<W1Y;&4Z9F%M
M:6QY/2=T86)L92UR;W<G(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M
M;V8@<V5L96-T/2)C;VYC870H)W1R+B<L('1R86YS;&%T92@D<W1Y;&4M;F%M
M92P@)RX@)2@I+UPG+"`G)RDI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`<W1Y;&4Z9F%M:6QY/2=T
M86)L92UC96QL)R(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB8V]N8V%T*"<J+B<L('1R86YS;&%T92@D<W1Y;&4M;F%M92P@)RX@
M)2@I+UPG+"`G)RDI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`<W1Y;&4Z9F%M:6QY/2=T86)L92UP
M86=E)R(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M8V]N8V%T*"<J+B<L('1R86YS;&%T92@D<W1Y;&4M;F%M92P@)RX@)2@I+UPG
M+"`G)RDI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@
M(#QX<VPZ=VAE;B!T97-T/2)`<W1Y;&4Z9F%M:6QY/2=C:&%R="<B/@H@("`@
M("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O;F-A="@G*BXG
M+"!T<F%N<VQA=&4H)'-T>6QE+6YA;64L("<N("4H*2]<)RP@)R<I*2(O/@H@
M("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TB0'-T>6QE.F9A;6EL>3TG9W)A<&AI8W,G(CX*("`@("`@("`@("`@
M("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC870H)RHN)RP@=')A;G-L
M871E*"1S='EL92UN86UE+"`G+B`E*"DO7"<L("<G*2DB+SX*("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](D!S
M='EL93IF86UI;'D])V1E9F%U;'0G(CX*("`@("`@("`@("`@("`@(#QX<VPZ
M=F%L=64M;V8@<V5L96-T/2)C;VYC870H)RHN)RP@=')A;G-L871E*"1S='EL
M92UN86UE+"`G+B`E*"DO7"<L("<G*2DB+SX*("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](D!S='EL93IF86UI
M;'D])V1R87=I;F<M<&%G92<B/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU
M92UO9B!S96QE8W0](F-O;F-A="@G*BXG+"!T<F%N<VQA=&4H)'-T>6QE+6YA
M;64L("<N("4H*2]<)RP@)R<I*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB0'-T>6QE.F9A;6EL>3TG
M<')E<V5N=&%T:6]N)R(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB8V]N8V%T*"<J+B<L('1R86YS;&%T92@D<W1Y;&4M;F%M92P@
M)RX@)2@I+UPG+"`G)RDI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`<W1Y;&4Z9F%M:6QY/2=C;VYT
M<F]L)R(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M8V]N8V%T*"<J+B<L('1R86YS;&%T92@D<W1Y;&4M;F%M92P@)RX@)2@I+UPG
M+"`G)RDI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@/"]X
M<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#PA+2T@9FEN
M9&EN9R!A;&P@<W1Y;&4@8VAI;&0@;V8@82!S96-T:6]N(&%N9"!G:79E('1H
M96ER('-T>6QE261E;G1I9FEE<B!T;R!T:&4@;W5T<'5T("TM/@H@("`@/'AS
M;#IT96UP;&%T92!N86UE/2=W<FET92UC:&EL9')E;BUS='EL92UN86UE<R<^
M"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)P87)E;G13='EL94YA;64B('-E
M;&5C=#TB0'-T>6QE.FYA;64B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64]
M(G!A<F5N=%-T>6QE1F%M:6QY(B!S96QE8W0](D!S='EL93IF86UI;'DB+SX*
M("`@("`@("`\>'-L.G!A<F%M(&YA;64](G-E87)C:$]N;'E);D%U=&]M871I
M8U-T>6QE<R(O/@H*"B`@("`@("`@/"$M+2HJ('1H92!N86UE<R!O9B!A;&P@
M;V9F:6-E.G-T>6QE<R!C:&EL9')E;B!W:6QL(&)E('=R:71T96X@;W5T"B`@
M("`@("`@("`@("HJ("AA(&%U=&]M871I8R!S='EL92!C86X@;VYL>2!H879E
M(&-H:6QD<F5N(&EN('1H92!O9F9I8V4Z875T;VUA=&EC+7-T>6QE('-E8W1I
M;VXI("TM/@H*("`@("`@("`\(2TM(&EF($Y/5"!C86QL960@9G)O;2!A(&]F
M9FEC93IA=71O;6%T:6,M<W1Y;&4@<&%R96YT("TM/@H@("`@("`@(#QX<VPZ
M:68@=&5S=#TB;F]T*'-E87)C:$]N;'E);D%U=&]M871I8U-T>6QE<RDB/@H@
M("`@("`@("`@("`\(2TM(&9O<B!A;&P@8VAI;&1R96X@:6X@=&AE(&]F9FEC
M93IS='EL92!S96-T:6]N("TM/@H@("`@("`@("`@("`\>'-L.F9O<BUE86-H
M('-E;&5C=#TB+BXO<W1Y;&4Z<W1Y;&5;0'-T>6QE.F9A;6EL>3TD<&%R96YT
M4W1Y;&5&86UI;'D@86YD($!S='EL93IP87)E;G0M<W1Y;&4M;F%M93TD<&%R
M96YT4W1Y;&5.86UE72(^"B`@("`@("`@("`@("`@("`\(2TM('=R:71E('1H
M92!S='EL92!N86UE(&EN('1H92!C<W,@:&5A9&5R("TM/@H@("`@("`@("`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G=R:71E+7-T>6QE+6YA
M;64B+SX*"B`@("`@("`@("`@("`@("`\(2TM('-E87)C:"!F;W(@8VAI;&0@
M<W1Y;&5S("TM/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E
M(&YA;64](G=R:71E+6-H:6QD<F5N+7-T>6QE+6YA;65S(CX*("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<&%R96YT4W1Y;&5.
M86UE(B!S96QE8W0](D!S='EL93IN86UE(B\^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G!A<F5N=%-T>6QE1F%M:6QY(B!S
M96QE8W0](D!S='EL93IF86UI;'DB+SX*("`@("`@("`@("`@("`@(#PO>'-L
M.F-A;&PM=&5M<&QA=&4^"@H@("`@("`@("`@("`\+WAS;#IF;W(M96%C:#X*
M("`@("`@("`\+WAS;#II9CX*"B`@("`@("`@/"$M+2HJ('1H92!N86UE<R!O
M9B!A;&P@;V9F:6-E.F%U=&]M871I8RUS='EL97,@8VAI;&1R96X@=VEL;"!B
M92!W<FET=&5N(&]U="`M+3X*"B`@("`@("`@/"$M+2!F;W(@86QL(&-H:6QD
M<F5N(&EN('1H92!O9F9I8V4Z875T;VUA=&EC+7-T>6QE('-E8W1I;VX@+2T^
M"B`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0](B1O9F9I8V4Z875T;VUA
M=&EC+7-T>6QE<R]S='EL93IS='EL95M`<W1Y;&4Z9F%M:6QY/21P87)E;G13
M='EL949A;6EL>2!A;F0@0'-T>6QE.G!A<F5N="US='EL92UN86UE/21P87)E
M;G13='EL94YA;65=(CX*("`@("`@("`@("`@/"$M+2!W<FET92!T:&4@<W1Y
M;&4@;F%M92!I;B!T:&4@8W-S(&AE861E<B`M+3X*("`@("`@("`@("`@/'AS
M;#IC86QL+71E;7!L871E(&YA;64](G=R:71E+7-T>6QE+6YA;64B+SX*"B`@
M("`@("`@("`@(#PA+2T@<V5A<F-H(&9O<B!C:&EL9"!S='EL97,@+2T^"B`@
M("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)W<FET92UC:&EL
M9')E;BUS='EL92UN86UE<R(^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB<&%R96YT4W1Y;&5.86UE(B!S96QE8W0](D!S='EL93IN
M86UE(B\^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M<&%R96YT4W1Y;&5&86UI;'DB('-E;&5C=#TB0'-T>6QE.F9A;6EL>2(O/@H@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-E87)C:$]N
M;'E);D%U=&]M871I8U-T>6QE<R(O/@H@("`@("`@("`@("`\+WAS;#IC86QL
M+71E;7!L871E/@H*("`@("`@("`\+WAS;#IF;W(M96%C:#X*("`@(#PO>'-L
M.G1E;7!L871E/@H*/"]X<VPZ<W1Y;&5S:&5E=#X*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6
M:65W97(O9&5B+G!H<```````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#,T,#<@,3`U,34T,S,W,S8@,#(R-C$P`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@34E-15]6
M:65W97)?9&5B(&-L87-S(')E;F1E<G,@;W5T(&QI<W1S(&]F(&9I;&5S(&EN
M($1E8FEA;B!P86-K86=E<R!B>0H@*B!U<VEN9R!T:&4@9'!K9R!T;V]L('1O
M('%U97)Y('1H92!P86-K86=E+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+V1E8BYP:'`L=B`Q+C$Q+C$P+C@@,C`P-B\P,2\P
M,2`R,3HR.#HR-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P
M-B!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("H*("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@/&%N:6Q`
M<F5C;VEL+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E
M($AO<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S<R!-24U%7U9I97=E<E]D96(@
M97AT96YD<R!-24U%7U9I97=E<B!["@H@("`@+RHJ"B`@("`@*B!296YD97(@
M=&AE(&1A=&$N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@
M($%N>2!P87)A;65T97)S('1H92!V:65W97(@;6%Y(&YE960N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!R96YD97)E9"!D871A+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!R96YD97(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@
M("!["B`@("`@("`@9VQO8F%L("1M:6UE7V1R:79E<G,["@H@("`@("`@("\J
M($-H96-K('1O(&UA:V4@<W5R92!T:&4@<')O9W)A;2!A8W1U86QL>2!E>&ES
M=',N("HO"B`@("`@("`@:68@*"%F:6QE7V5X:7-T<R@D;6EM95]D<FEV97)S
M6R=H;W)D92==6R=D96(G75LG;&]C871I;VXG72DI('L*("`@("`@("`@("`@
M<F5T=7)N("<\<')E/B<@+B!S<')I;G1F*%\H(E1H92!P<F]G<F%M('5S960@
M=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@
M=&AE('-Y<W1E;2XB*2P@)&UI;65?9')I=F5R<ULG:&]R9&4G75LG9&5B)UU;
M)VQO8V%T:6]N)UTI("X@)SPO<')E/B<["B`@("`@("`@?0H*("`@("`@("`D
M=&UP7V1E8B`]($AO<F1E.CIG971496UP1FEL92@G:&]R9&5?9&5B)RD["@H@
M("`@("`@("1F:"`](&9O<&5N*"1T;7!?9&5B+"`G=R<I.PH@("`@("`@(&9W
M<FET92@D9F@L("1T:&ES+3YM:6UE7W!A<G0M/F=E=$-O;G1E;G1S*"DI.PH@
M("`@("`@(&9C;&]S92@D9F@I.PH*("`@("`@("`D9F@@/2!P;W!E;B@D;6EM
M95]D<FEV97)S6R=H;W)D92==6R=D96(G75LG;&]C871I;VXG72`N("(@+68@
M)'1M<%]D96(@,CXF,2(L("=R)RD["B`@("`@("`@=VAI;&4@*"@D<F,@/2!F
M9V5T<R@D9F@L(#@Q.3(I*2D@>PH@("`@("`@("`@("`D9&%T82`N/2`D<F,[
M"B`@("`@("`@?0H@("`@("`@('!C;&]S92@D9F@I.PH*("`@("`@("!R971U
M<FX@)SQP<F4^)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&1A=&$I("X@)SPO<')E
M/B<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE($U)344@8V]N
M=&5N="!T>7!E(&]F('1H92!R96YD97)E9"!C;VYT96YT+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@8V]N=&5N="!T>7!E(&]F('1H92!O
M=71P=70N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@
M("`@("`@(')E='5R;B`G=&5X="]H=&UL.R!C:&%R<V5T/2<@+B!.3%,Z.F=E
M=$-H87)S970H*3L*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W)A<BYP:'``````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$V,3(V
M(#$P-3$U-#,S-S,V(#`R,C8T-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@5&AE($U)345?5FEE=V5R
M7W)A<B!C;&%S<R!R96YD97)S(&]U="!T:&4@8V]N=&5N=',@;V8@+G)A<B!A
M<F-H:79E<R!I;B!(5$U,"B`J(&9O<FUA="X*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP+'8@,2XQ."XQ,"XY(#(P
M,#8O,#$O,#$@,C$Z,C@Z,C4@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q
M.3DY+3(P,#8@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*
M("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L($-O8VAR86YE(#QM:6ME
M0&=R869T;VYH86QL+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H@0&%U
M=&AO<B`@36EC:&%E;"!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN
M>CX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E7TU)
M345?5FEE=V5R"B`J+PIC;&%S<R!-24U%7U9I97=E<E]R87(@97AT96YD<R!-
M24U%7U9I97=E<B!["@H@("`@+RHJ"B`@("`@*B!287(@8V]M<')E<W-I;VX@
M;65T:&]D<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@
M('9A<B`D7VUE=&AO9',@/2!A<G)A>2@*("`@("`@("`P>#,P("`]/B`@)U-T
M;W)E)RP*("`@("`@("`P>#,Q("`]/B`@)T9A<W1E<W0G+`H@("`@("`@(#!X
M,S(@(#T^("`G1F%S="<L"B`@("`@("`@,'@S,R`@/3X@("=.;W)M86PG+`H@
M("`@("`@(#!X,S0@(#T^("`G1V]O9"<L"B`@("`@("`@,'@S-2`@/3X@("="
M97-T)PH@("`@*3L*"B`@("`O*BH*("`@("`J(%)E;F1E<B!O=70@=&AE(&-U
M<G)E;G1L>2!S970@8V]N=&5N=',@=7-I;F<@<F%R+@H@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>2`D<&%R86US("!!;GD@<&%R86UE=&5R<R!T:&4@5FEE
M=V5R(&UA>2!N965D+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@<F5N9&5R960@8V]N=&5N=',N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E
M;F1E<B@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D8V]N=&5N
M=',@/2`D=&AI<RT^;6EM95]P87)T+3YG971#;VYT96YT<R@I.PH*("`@("`@
M("`O*B!-86ME('-U<F4@=&AI<R!I<R!A('9A;&ED(')A<B!F:6QE+B`J+PH@
M("`@("`@(&EF("@D=&AI<RT^8VAE8VM287)$871A*"1C;VYT96YT<RD@/3T]
M(&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;B`G/'!R93XG("X@7R@B5&AI
M<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92XB
M*2`N("<\+W!R93XG.PH@("`@("`@('T*"B`@("`@("`@<F5Q=6ER95]O;F-E
M("=(;W)D92]497AT+G!H<"<["@H@("`@("`@("1R87)$871A(#T@)'1H:7,M
M/F=E=%)A<D1A=&$H)&-O;G1E;G1S*3L*("`@("`@("`D9FEL94-O=6YT(#T@
M8V]U;G0H)')A<D1A=&$I.PH*("`@("`@("`D=&5X="`@/2`G/'-T<F]N9SXG
M("X@:'1M;'-P96-I86QC:&%R<RAS<')I;G1F*%\H(D-O;G1E;G1S(&]F(%PB
M)7-<(B(I+"`D=&AI<RT^;6EM95]P87)T+3YG971.86UE*"DI*2`N("<Z/"]S
M=')O;F<^)R`N(")<;B(["B`@("`@("`@)'1E>'0@+CT@)SQT86)L93X\='(^
M/'1D(&%L:6=N/2)L969T(CX\='0^/'-P86X@8VQA<W,](F9I>&5D(CXG.PH@
M("`@("`@("1T97AT("X](%1E>'0Z.FAT;6Q!;&Q3<&%C97,H7R@B07)C:&EV
M92!.86UE(BD@+B`G.B`@)R`N("1T:&ES+3YM:6UE7W!A<G0M/F=E=$YA;64H
M*2D@+B`B7&XB.PH@("`@("`@("1T97AT("X](%1E>'0Z.FAT;6Q!;&Q3<&%C
M97,H7R@B07)C:&EV92!&:6QE(%-I>F4B*2`N("<Z("<@+B!S=')L96XH)&-O
M;G1E;G1S*2`N("<@8GET97,G*2`N(")<;B(["B`@("`@("`@)'1E>'0@+CT@
M5&5X=#HZ:'1M;$%L;%-P86-E<R@H)&9I;&5#;W5N="`A/2`Q*2`_('-P<FEN
M=&8H7R@B1FEL92!#;W5N=#H@)7,@9FEL97,B*2P@)&9I;&5#;W5N="D@.B!S
M<')I;G1F*%\H(D9I;&4@0V]U;G0Z("5S(&9I;&4B*2P@)&9I;&5#;W5N="DI
M.PH@("`@("`@("1T97AT("X](")<;EQN(CL*("`@("`@("`D=&5X="`N/2!4
M97AT.CIH=&UL06QL4W!A8V5S*`H@("`@("`@("`@("`@("`@("`@("!S=')?
M<&%D*%\H(D9I;&4@3F%M92(I+"`@("`@-3`L("<@)RP@4U127U!!1%]224=(
M5"D@+@H@("`@("`@("`@("`@("`@("`@("!S=')?<&%D*%\H(D%T=')I8G5T
M97,B*2P@("`@,3`L("<@)RP@4U127U!!1%],1494*2`N"B`@("`@("`@("`@
M("`@("`@("`@('-T<E]P860H7R@B4VEZ92(I+"`@("`@("`@("`Q,"P@)R`G
M+"!35%)?4$%$7TQ%1E0I("X*("`@("`@("`@("`@("`@("`@("`@<W1R7W!A
M9"A?*")-;V1I9FEE9"!$871E(BDL(#$Y+"`G("<L(%-44E]0041?3$5&5"D@
M+@H@("`@("`@("`@("`@("`@("`@("!S=')?<&%D*%\H(DUE=&AO9"(I+"`@
M("`@("`@,3`L("<@)RP@4U127U!!1%],1494*2`N"B`@("`@("`@("`@("`@
M("`@("`@('-T<E]P860H7R@B4F%T:6\B*2P@("`@("`@("`@-RP@)R`G+"!3
M5%)?4$%$7TQ%1E0I"B`@("`@("`@("`@("`@("`@*2`N(")<;B(["@H@("`@
M("`@("1T97AT("X]('-T<E]R97!E870H)RTG+"`Q,#8I("X@(EQN(CL*"B`@
M("`@("`@9F]R96%C:"`H)')A<D1A=&$@87,@)'9A;"D@>PH@("`@("`@("`@
M("`D<F%T:6\@/2`H96UP='DH)'9A;%LG<VEZ92==*2D@/R`P(#H@,3`P("H@
M*"1V86Q;)V-S:7IE)UT@+R`D=F%L6R=S:7IE)UTI.PH@("`@("`@("`@("`D
M=&5X="`N/2!497AT.CIH=&UL06QL4W!A8V5S*`H@("`@("`@("`@("`@("`@
M("`@("`@("`@<W1R7W!A9"@D=F%L6R=N86UE)UTL(#4P+"`G("<L(%-44E]0
M041?4DE'2%0I("X*("`@("`@("`@("`@("`@("`@("`@("`@('-T<E]P860H
M)'9A;%LG871T<B==+"`Q,"P@)R`G+"!35%)?4$%$7TQ%1E0I("X*("`@("`@
M("`@("`@("`@("`@("`@("`@('-T<E]P860H)'9A;%LG<VEZ92==+"`Q,"P@
M)R`G+"!35%)?4$%$7TQ%1E0I("X*("`@("`@("`@("`@("`@("`@("`@("`@
M('-T<E]P860H<W1R9G1I;64H(B5D+25B+259("5(.B5-(BP@)'9A;%LG9&%T
M92==*2P@,3DL("<@)RP@4U127U!!1%],1494*2`N"B`@("`@("`@("`@("`@
M("`@("`@("`@("!S=')?<&%D*"1V86Q;)VUE=&AO9"==+"`Q,"P@)R`G+"!3
M5%)?4$%$7TQ%1E0I("X*("`@("`@("`@("`@("`@("`@("`@("`@('-T<E]P
M860H<W!R:6YT9B@B)3$N,68E)2(L("1R871I;RDL(#<L("<@)RP@4U127U!!
M1%],1494*0H@("`@("`@("`@("`@("`@("`@("`I("X@(EQN(CL*("`@("`@
M("!]"@H@("`@("`@("1T97AT("X]('-T<E]R97!E870H)RTG+"`Q,#8I("X@
M(EQN(CL*("`@("`@("`D=&5X="`N/2`G/"]S<&%N/CPO='0^/"]T9#X\+W1R
M/CPO=&%B;&4^)SL*"B`@("`@("`@<F5T=7)N(&YL,F)R*"1T97AT*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE($U)344@='EP92!O9B!T
M:&ES('!A<G0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!-
M24U%('1Y<&4@;V8@=&AI<R!P87)T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M9714>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)W1E>'0O:'1M;#L@8VAA
M<G-E=#TG("X@3DQ3.CIG971#:&%R<V5T*"D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#:&5C:W,@=&\@<V5E(&EF('1H92!D871A(&ES(&$@=F%L:60@4F%R
M(&%R8VAI=F4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`F)&1A=&$@
M(%1H92!R87(@87)C:&EV92!D871A+@H@("`@("H*("`@("`J($!R971U<FX@
M8F]O;&5A;B`@5')U92!I9B!V86QI9"P@9F%L<V4@:68@:6YV86QI9"X*("`@
M("`J+PH@("`@9G5N8W1I;VX@8VAE8VM287)$871A*"8D9&%T82D*("`@('L*
M("`@("`@("`D9FEL94AE861E<B`](")<>#4R7'@V,5QX-S)<>#(Q7'@Q85QX
M,#=<>#`P(CL*("`@("`@("!I9B`H<W1R<&]S*"1D871A+"`D9FEL94AE861E
M<BD@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE(&QI<W0@;V8@9FEL
M97,O9&%T82!F<F]M('1H92!R87(@87)C:&EV92X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("8D9&%T82`@5&AE(')A<B!A<F-H:79E(&1A=&$N"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@2T59.B!0;W-I=&EO;B!I;B!2
M05(@87)C:&EV90H@("`@("H@("`@("`@("`@("`@("`@5D%,5453.B`G871T
M<B<@("`@+2T@($9I;&4@871T<FEB=71E<PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`G9&%T92<@("`@+2T@($9I;&4@;6]D:69I8V%T:6]N('1I
M;64*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@)V-S:7IE)R`@("TM
M("!#;VUP<F5S<V5D(&9I;&4@<VEZ90H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`G;65T:&]D)R`@+2T@($-O;7!R97-S:6]N(&UE=&AO9`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`G;F%M92<@("`@+2T@($9I;&5N
M86UE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("=S:7IE)R`@("`M
M+2`@3W)I9VEN86P@9FEL92!S:7IE"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%)A<D1A=&$H)B1D871A*0H@("`@>PH@("`@("`@("1R971U<FY?87)R87D@
M/2!A<G)A>2@I.PH*("`@("`@("`D8FQO8VM3=&%R="`]('-T<G!O<R@D9&%T
M82P@(EQX-3)<>#8Q7'@W,EQX,C%<>#%A7'@P-UQX,#`B*3L*("`@("`@("`D
M<&]S:71I;VX@/2`D8FQO8VM3=&%R="`K(#<["@H@("`@("`@('=H:6QE("@D
M<&]S:71I;VX@/"!S=')L96XH)&1A=&$I*2!["B`@("`@("`@("`@("1H96%D
M7V-R8R`@(#T@<W5B<W1R*"1D871A+"`D<&]S:71I;VX@*R`P+"`R*3L*("`@
M("`@("`@("`@)&AE861?='EP92`@/2!O<F0H<W5B<W1R*"1D871A+"`D<&]S
M:71I;VX@*R`R+"`Q*2D["B`@("`@("`@("`@("1H96%D7V9L86=S(#T@=6YP
M86-K*"=V1FQA9W,G+"!S=6)S='(H)&1A=&$L("1P;W-I=&EO;B`K(#,L(#(I
M*3L*("`@("`@("`@("`@)&AE861?9FQA9W,@/2`D:&5A9%]F;&%G<ULG1FQA
M9W,G73L*("`@("`@("`@("`@)&AE861?<VEZ92`@/2!U;G!A8VLH)W93:7IE
M)RP@<W5B<W1R*"1D871A+"`D<&]S:71I;VX@*R`U+"`R*2D["B`@("`@("`@
M("`@("1H96%D7W-I>F4@(#T@)&AE861?<VEZ95LG4VEZ92==.PH*("`@("`@
M("`@("`@)'!O<VET:6]N("L](#<["B`@("`@("`@("`@("1H96%D7W-I>F4@
M+3T@-SL*"B`@("`@("`@("`@('-W:71C:"`H)&AE861?='EP92D@>PH*("`@
M("`@("`@("`@8V%S92`P>#<S.@H@("`@("`@("`@("`@("`@+RH@07)C:&EV
M92!H96%D97(@*B\*("`@("`@("`@("`@("`@("1P;W-I=&EO;B`K/2`D:&5A
M9%]S:7IE.PH*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M8V%S92`P>#<T.@H@("`@("`@("`@("`@("`@)&9I;&4@/2!A<G)A>2@I.PH*
M("`@("`@("`@("`@("`@("\J($9I;&4@2&5A9&5R("HO"B`@("`@("`@("`@
M("`@("`D:6YF;R`]('5N<&%C:R@G5E!A8VME9"]656YP86-K960O0T]3+U9#
M4D,S,B]65&EM92]#5F5R<VEO;B]#365T:&]D+W9,96YG=&@O=D%T=')I8B<L
M('-U8G-T<B@D9&%T82P@)'!O<VET:6]N*2D["@H@("`@("`@("`@("`@("`@
M)&9I;&5;)VYA;64G72`]('-U8G-T<B@D9&%T82P@)'!O<VET:6]N("L@,C4L
M("1I;F9O6R=,96YG=&@G72D["B`@("`@("`@("`@("`@("`D9FEL95LG<VEZ
M92==(#T@)&EN9F];)U5N<&%C:V5D)UT["B`@("`@("`@("`@("`@("`D9FEL
M95LG8W-I>F4G72`]("1I;F9O6R=086-K960G73L*"B`@("`@("`@("`@("`@
M("`D9FEL95LG9&%T92==(#T@;6MT:6UE*"@H)&EN9F];)U1I;64G72`^/B`Q
M,2D@)B`P>#%F*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@*"@D:6YF;ULG5&EM92==(#X^(#4I("8@,'@S9BDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("@H)&EN9F];)U1I;64G
M72`\/"`Q*2`F(#!X,V4I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`H*"1I;F9O6R=4:6UE)UT@/CX@,C$I("8@,'@P-RDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("@H)&EN9F];
M)U1I;64G72`^/B`Q-BD@)B`P>#%F*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@*"@H)&EN9F];)U1I;64G72`^/B`R-2D@)B`P
M>#=F*2`K(#@P*2D["@H@("`@("`@("`@("`@("`@)&9I;&5;)VUE=&AO9"==
M(#T@)'1H:7,M/E]M971H;V1S6R1I;F9O6R=-971H;V0G75T["@H@("`@("`@
M("`@("`@("`@)&9I;&5;)V%T='(G72`@/2`G)SL*("`@("`@("`@("`@("`@
M("1F:6QE6R=A='1R)UT@+CT@*"1I;F9O6R=!='1R:6(G72`F(#!X,3`I(#\@
M)T0G(#H@)RTG.PH@("`@("`@("`@("`@("`@)&9I;&5;)V%T='(G72`N/2`H
M)&EN9F];)T%T=')I8B==("8@,'@R,"D@/R`G02<@.B`G+2<["B`@("`@("`@
M("`@("`@("`D9FEL95LG871T<B==("X]("@D:6YF;ULG071T<FEB)UT@)B`P
M>#`S*2`_("=3)R`Z("<M)SL*("`@("`@("`@("`@("`@("1F:6QE6R=A='1R
M)UT@+CT@*"1I;F9O6R=!='1R:6(G72`F(#!X,#(I(#\@)T@G(#H@)RTG.PH@
M("`@("`@("`@("`@("`@)&9I;&5;)V%T='(G72`N/2`H)&EN9F];)T%T=')I
M8B==("8@,'@P,2D@/R`G4B<@.B`G+2<["@H@("`@("`@("`@("`@("`@)')E
M='5R;E]A<G)A>5M=(#T@)&9I;&4["@H@("`@("`@("`@("`@("`@)'!O<VET
M:6]N("L]("1H96%D7W-I>F4["B`@("`@("`@("`@("`@("`D<&]S:71I;VX@
M*ST@)&EN9F];)U!A8VME9"==.PH@("`@("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@)'!O<VET:6]N
M("L]("1H96%D7W-I>F4["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&%D
M9%]S:7IE*2D@>PH@("`@("`@("`@("`@("`@("`@("1P;W-I=&EO;B`K/2`D
M861D7W-I>F4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D<F5T=7)N7V%R<F%Y.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W
M97(O<F9C.#(R+G!H<```````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#8U
M,#`@,3`U,34T,S,W,S8@,#(S,#8Q`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B!4:&4@34E-15]6:65W
M97)?<F9C.#(R(&-L87-S(')E;F1E<G,@;W5T(&UE<W-A9V5S(&9R;VT@=&AE
M"B`J(&UE<W-A9V4O<F9C.#(R(&-O;G1E;G0@='EP92X*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP+'8@,2XX
M+C$P+C@@,C`P-B\P,2\P,2`R,3HR.#HR-2!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG
M=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A'4$PI+B!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]G<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@
M36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U
M/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?34E-
M15]6:65W97(*("HO"F-L87-S($U)345?5FEE=V5R7W)F8S@R,B!E>'1E;F1S
M($U)345?5FEE=V5R('L*"B`@("`O*BH*("`@("`J(%)E;F1E<B!O=70@=&AE
M(&-U<G)E;G1L>2!S970@8V]N=&5N=',N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P87)A;7,@($%N(&%R<F%Y('=I=&@@86YY('!A<F%M971E<G,@
M;F5E9&5D+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F5N
M9&5R960@=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R*"1P87)A
M;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1P87)T(#T@)'1H:7,M/FUI
M;65?<&%R=#L*("`@("`@("`D<&%R="T^=')A;G-F97)$96-O9&5#;VYT96YT
M<R@I.PH*("`@("`@("`D=&5X="`]("1P87)T+3YG971#;VYT96YT<R@I.PH@
M("`@("`@(&EF("@A)'1E>'0I('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E
M("=(;W)D92]-24U%+T-O;G1E;G1S+G!H<"<["B`@("`@("`@("`@("1C;VYT
M96YT<R`]("9N97<@34E-15]#;VYT96YT<RAN97<@34E-15]087)T*"DI.PH@
M("`@("`@("`@("!R971U<FX@)&-O;G1E;G1S+3YF;W)M8713=&%T=7--<V<H
M7R@B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E
M('!A<G0B*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M("1T97AT.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E;F1E
M<B!O=70@871T86-H;65N="!I;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)'!A<F%M<R`@06X@87)R87D@=VET:"!A;GD@<&%R86UE
M=&5R<R!N965D960N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!R96YD97)E9"!T97AT(&EN($A434PN"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E;F1E<D%T=&%C:&UE;G1);F9O*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@
M>PH@("`@("`@("1M<V<@/2`G)SL*"B`@("`@("`@+RH@1V5T('1H92!T97AT
M(&]F('1H92!P87)T+B`@4VEN8V4@=V4@;F5E9"!T;R!L;V]K(&9O<B!T:&4@
M96YD(&]F"B`@("`@("`@("H@=&AE(&AE861E<G,@8GD@<V5A<F-H:6YG(&9O
M<B!T:&4@0U),1D-23$8@<V5Q=65N8V4L('5S90H@("`@("`@("`J(&=E=$-A
M;F]N:6-A;$-O;G1E;G1S*"D@=&\@;6%K92!S=7)E('=E(&%R92!G971T:6YG
M('1H92!T97AT('=I=&@*("`@("`@("`@*B!#4DQ&)W,N("HO"B`@("`@("`@
M)'1E>'0@/2`D=&AI<RT^;6EM95]P87)T+3YG971#86YO;FEC86Q#;VYT96YT
M<R@I.PH*("`@("`@("`O*B!396%R8V@@9F]R('1H92!E;F0@;V8@=&AE(&AE
M861E<B!T97AT("A#4DQ&0U),1BDN("HO"B`@("`@("`@)'1E>'0@/2!S=6)S
M='(H)'1E>'0L(#`L('-T<G!O<R@D=&5X="P@(EQR7&Y<<EQN(BDI.PH*("`@
M("`@("`O*B!'970@=&AE(&QI<W0@;V8@:&5A9&5R<R!N;W<N("HO"B`@("`@
M("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+U-T<G5C='5R92YP:'`G.PH@
M("`@("`@("1H96%D97)S(#T@34E-15]3=')U8W1U<F4Z.G!A<G-E34E-14AE
M861E<G,H)'1E>'0L('1R=64L('1R=64I.PH*("`@("`@("!R97%U:7)E7V]N
M8V4@)TAO<F1E+TU)344O0V]N=&5N=',N<&AP)SL*("`@("`@("`D8V]N=&5N
M=',@/2`F;F5W($U)345?0V]N=&5N=',H;F5W($U)345?4&%R="@I*3L*("`@
M("`@("`D;7-G(#T@)&-O;G1E;G1S+3YF;W)M8713=&%T=7--<V<H7R@B5&AE
M(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R
M9F,X,C(@;65S<V%G92XB*2P@2&]R9&4Z.FEM9R@G:6YF;U]I8V]N+G!N9R<L
M(%\H(DEN9F\B*2P@)VAE:6=H=#TB,38B('=I9'1H/2(Q-B(G+"`D1TQ/0D%,
M4ULG<F5G:7-T<GDG72T^9V5T26UA9V5$:7(H)VAO<F1E)RDI+"!F86QS92D[
M"@H@("`@("`@("1M<V<@+CT@)SQS<&%N(&-L87-S/2)F:7AE9"(^)SL*"B`@
M("`@("`@)&AE861E<E]A<G)A>2`](&%R<F%Y*`H@("`@("`@("`@("`G9&%T
M92<@/3X@7R@B1&%T92(I+`H@("`@("`@("`@("`G<W5B:F5C="<@/3X@7R@B
M4W5B:F5C="(I+`H@("`@("`@("`@("`G9G)O;2<@/3X@7R@B1G)O;2(I+`H@
M("`@("`@("`@("`G=&\G(#T^(%\H(E1O(BD*("`@("`@("`I.PH@("`@("`@
M("1H96%D97)?;W5T<'5T(#T@87)R87DH*3L*"B`@("`@("`@9F]R96%C:"`H
M)&AE861E<E]A<G)A>2!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@
M:68@*&ES<V5T*"1H96%D97)S6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@
M:68@*&ES7V%R<F%Y*"1H96%D97)S6R1K97E=*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1H96%D97)S6R1K97E=(#T@)&AE861E<G-;)&ME>5U;,%T["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D:&5A9&5R7V]U='!U
M=%M=(#T@)SQS=')O;F<^)R`N("1V86P@+B`G.CPO<W1R;VYG/B`G("X@)&AE
M861E<G-;)&ME>5T["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(')E<75I<F5?;VYC92`G2&]R9&4O5&5X="]&:6QT97(N<&AP)SL*("`@("`@
M("`D;7-G("X](&EM<&QO9&4H(CQB<B`O/EQN(BP@5&5X=%]&:6QT97(Z.F9I
M;'1E<B@D:&5A9&5R7V]U='!U="P@)V5M86EL<R<I*2`N("<\+W-P86X^)SL*
M"B`@("`@("`@<F5T=7)N("1M<V<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FX@=&AE($U)344@8V]N=&5N="!T>7!E(&9O<B!T:&4@<F5N9&5R960@
M9&%T82X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O;G1E
M;G0@='EP92!O9B!T:&4@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=T97AT+W!L86EN.R!C:&%R
M<V5T/2<@+B!.3%,Z.F=E=$-H87)S970H*3L*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W!L86EN+G!H<```````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`U
M-#<V(#$P-3$U-#,S-S,V(#`R,S$W,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@5&AE($U)345?5FEE
M=V5R7W!L86EN(&-L87-S(')E;F1E<G,@;W5T('!L86EN('1E>'0@=VET:"!5
M4DQS(&UA9&4*("H@:6YT;R!H>7!E<FQI;FMS("AI9B!V:65W:6YG(&EN;&EN
M92DN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<&QA:6XN<&AP+'8@,2XQ."XV+C$P(#(P,#8O,#$O,C,@,34Z,S4Z,#8@<VQU
M<V%R>B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($%N:6P@36%D
M:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J($-O<'ER:6=H="`R,#`R
M+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&AO<F1E+F]R9SX*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA
M;FEL0')E8V]I;"YO<F<^"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\
M<VQU<V%R>D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`
M<&%C:V%G92!(;W)D95]-24U%7U9I97=E<@H@*B\*8VQA<W,@34E-15]6:65W
M97)?<&QA:6X@97AT96YD<R!-24U%7U9I97=E<B!["@H@("`@+RHJ"B`@("`@
M*B!296YD97(@;W5T('1H92!C;VYT96YT<RX*("`@("`J"B`@("`@*B!`<&%R
M86T@87)R87D@)'!A<F%M<R`@06YY('!A<F%M971E<G,@=&AE(%9I97=E<B!M
M87D@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E
M;F1E<F5D(&-O;G1E;G1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97(H
M)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E
M("=(;W)D92]-24U%+T-O;G1E;G1S+G!H<"<["@H@("`@("`@("1T97AT(#T@
M)'1H:7,M/FUI;65?<&%R="T^9V5T0V]N=&5N=',H*3L*"B`@("`@("`@+RH@
M0VAE8VL@9F]R("=F;&]W960G('1E>'0@9&%T82X@*B\*("`@("`@("`D9FQO
M=V5D(#T@*"1T:&ES+3YM:6UE7W!A<G0M/F=E=$-O;G1E;G14>7!E4&%R86UE
M=&5R*"=F;W)M870G*2`]/2`G9FQO=V5D)RD["B`@("`@("`@:68@*"1F;&]W
M960I('L*("`@("`@("`@("`@)'1E>'0@/2`D=&AI<RT^7V9O<FUA=$9L;W=E
M9"@D=&5X="D["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!C86QL:6YG(&%S
M(&%N(&%T=&%C:&UE;G0@9G)O;2!V:65W+G!H<"P@=V4@9&\@;F]T('=A;G0*
M("`@("`@("`@("!T;R!A;'1E<B!T:&4@=&5X="!I;B!A;GD@=V%Y('=I=&@@
M2%1-3"X@*B\*("`@("`@("!I9B`H34E-15]#;VYT96YT<SHZ=FEE=T%S071T
M86-H;65N="@I*2!["B`@("`@("`@("`@(')E='5R;B`D=&5X=#L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U1E
M>'0O1FEL=&5R+G!H<"<["B`@("`@("`@("`@(')E='5R;B!497AT7T9I;'1E
M<CHZ9FEL=&5R*"1T97AT+"`G=&5X=#)H=&UL)RP@87)R87DH)W!A<G-E;&5V
M96PG(#T^(%1%6%1?2%1-3%]-24-23RP@)V-H87)S970G(#T^(&YU;&PL("=C
M;&%S<R<@/3X@;G5L;"DI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;B!T:&4@34E-12!C;VYT96YT('1Y<&4@;V8@=&AE(')E;F1E
M<F5D(&-O;G1E;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!C;VYT96YT('1Y<&4@;V8@=&AE(&]U='!U="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=(
M;W)D92]-24U%+T-O;G1E;G1S+G!H<"<["B`@("`@("`@<F5T=7)N("A-24U%
M7T-O;G1E;G1S.CIV:65W07-!='1A8VAM96YT*"DI(#\@)'1H:7,M/FUI;65?
M<&%R="T^9V5T5'EP92AT<G5E*2`Z("=T97AT+VAT;6P[(&-H87)S970])R`N
M($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@?0H*("`@("\J*@H@("`@("H@1F]R
M;6%T(&9L;W=E9"!T97AT(&9O<B!(5$U,(&]U='!U="X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1T97AT("`@(%1H92!T97AT('1O(&9O<FUA="X*
M("`@("`J($!P87)A;2!I;G1E9V5R("1O<'0@("`@5&AE(&]P=&EM86P@;&5N
M9W1H('1O('=R87`N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;6%X("`@(%1H
M92!M87AI;75M(&QE;F=T:"!T;R!W<F%P+B`P(&UE86YS(&1O;B=T('=R87`N
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&5L<W`@(%=A<R!T97AT(&-R96%T
M960@=VET:"!$96Q3<"!F;W)M871T:6YG/PH@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@9F]R;6%T=&5D('1E>'0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]F;W)M871&;&]W960H)'1E>'0L("1O<'0@/2!N=6QL+"`D;6%X
M(#T@;G5L;"P@)&1E;'-P(#T@;G5L;"D*("`@('L*("`@("`@("!R97%U:7)E
M7V]N8V4@)U1E>'0O1FQO=V5D+G!H<"<["B`@("`@("`@)&9L;W=E9"`]("9N
M97<@5&5X=%]&;&]W960H)'1H:7,M/FUI;65?<&%R="T^<F5P;&%C945/3"@D
M=&5X="P@(EQN(BDL("1T:&ES+3YM:6UE7W!A<G0M/F=E=$-H87)S970H*2D[
M"B`@("`@("`@:68@*"%I<U]N=6QL*"1O<'0I*2!["B`@("`@("`@("`@("1F
M;&]W960M/G-E=$]P=$QE;F=T:"@D;W!T*3L*("`@("`@("!]"B`@("`@("`@
M:68@*"%I<U]N=6QL*"1M87@I*2!["B`@("`@("`@("`@("1F;&]W960M/G-E
M=$UA>$QE;F=T:"@D;6%X*3L*("`@("`@("!]"B`@("`@("`@:68@*"%I<U]N
M=6QL*"1D96QS<"DI('L*("`@("`@("`@("`@)&9L;W=E9"T^<V5T1&5L4W`H
M)&1E;'-P*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1F;&]W960M/G1O
M1FEX960H*3L*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O8W-S+G!H<```````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#8W,#4@,3`U,34T,S,W,S8@
M,#(R-C4R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"@IR97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G
M+W-O=7)C92YP:'`G.PH*+RHJ"B`J(%1H92!-24U%7U9I97=E<E]C<W,@8VQA
M<W,@<F5N9&5R<R!#4U,@<V]U<F-E(&%S($A434P@=VET:"!A;B!E9F9O<G0*
M("H@=&\@<F5M;W9E('!O=&5N=&EA;&QY(&UA;&EC:6]U<R!C;V1E+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V-S<RYP:'`L
M=B`Q+C$N,3`N."`R,#`V+S`V+S`Q(#`S.C`X.C4S(&-H=6-K($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C
M:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R
M9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S
M<R!-24U%7U9I97=E<E]C<W,@97AT96YD<R!-24U%7U9I97=E<E]S;W5R8V4@
M>PH*("`@("\J*@H@("`@("H@4F5N9&5R(&]U="!T:&4@8W5R<F5N=&QY('-E
M="!C;VYT96YT<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M
M<R`@06YY('!A<F%M971E<G,@=&AE('9I97=E<B!M87D@;F5E9"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D('1E>'0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<B@D<&%R86US(#T@;G5L;"D*("`@
M('L*("`@("`@("`D8W-S(#T@:'1M;'-P96-I86QC:&%R<R@D=&AI<RT^;6EM
M95]P87)T+3YG971#;VYT96YT<R@I+"!%3E1?3D]154]415,I.PH@("`@("`@
M("1C<W,@/2!P<F5G7W)E<&QA8V5?8V%L;&)A8VLH)R$H?7Q<*B\I+BH_*'M\
M+UPJ*2%S)RP@87)R87DH)'1H:7,L("=?:&%N9&QE<R<I+"`D8W-S*3L*("`@
M("`@("`D8W-S(#T@<')E9U]R97!L86-E7V-A;&QB86-K*"<A>UM>?5TJ?2%S
M)RP@87)R87DH)'1H:7,L("=?871T<FEB=71E<R<I+"`D8W-S*3L*("`@("`@
M("`D8W-S(#T@<')E9U]R97!L86-E7V-A;&QB86-K*"<A+UPJ+BH_7"HO(7,G
M+"!A<G)A>2@D=&AI<RP@)U]C;VUM96YT<R<I+"`D8W-S*3L*("`@("`@("`D
M8W-S(#T@=')I;2@D8W-S*3L*"B`@("`@("`@+R\@161U8V%T960@1W5E<W,@
M870@=VAE=&AE<B!W92!A<F4@:6YL:6YE(&]R(&YO="X*("`@("`@("!I9B`H
M:&5A9&5R<U]S96YT*"D@?'P@;V)?9V5T7VQE;F=T:"@I*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^;&EN94YU;6)E<B@D8W-S*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@571I;#HZ8G5F9F5R3W5T<'5T
M*"=R97%U:7)E)RP@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=&5M<&QA
M=&5S)RP@)VAO<F1E)RD@+B`G+V-O;6UO;BUH96%D97(N:6YC)RD@+@H@("`@
M("`@("`@("`@("`@)'1H:7,M/FQI;F5.=6UB97(H)&-S<RD@+@H@("`@("`@
M("`@("`@("`@571I;#HZ8G5F9F5R3W5T<'5T*"=R97%U:7)E)RP@)$=,3T)!
M3%-;)W)E9VES=')Y)UTM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G
M+V-O;6UO;BUF;V]T97(N:6YC)RD["B`@("`@("`@?0H@("`@?0H*("`@(&9U
M;F-T:6]N(%]C;VUM96YT<R@D;6%T8VAE<RD*("`@('L*("`@("`@("`D<&%T
M=&5R;G-;72`]("<A*&AT='`Z+R];+UQW+2Y=*RDA<R<["B`@("`@("`@)')E
M<&QA8V5S6UT@/2`G/&$@:')E9CTB7%PQ(CY<7#$\+V$^)SL*"B`@("`@("`@
M)&-O;6UE;G1S(#T@<')E9U]R97!L86-E*"1P871T97)N<RP@)')E<&QA8V5S
M+"`D;6%T8VAE<ULP72D["@H@("`@("`@(')E='5R;B`G/'-P86X@8VQA<W,]
M(F-O;6UE;G0B/B<@+B`D8V]M;65N=',@+B`G/"]S<&%N/B<["B`@("!]"@H@
M("`@9G5N8W1I;VX@7V%T=')I8G5T97,H)&UA=&-H97,I"B`@("!["B`@("`@
M("`@+R\@071T<FEB=71E<RX*("`@("`@("`D<&%T=&5R;G-;72`]("<A*%LM
M7'==*UQS*BDZ(7,G.PH@("`@("`@("1R97!L86-E<UM=(#T@)SQS<&%N(&-L
M87-S/2)A='1R(B(^7%PQ/"]S<&%N/CHG.PH*("`@("`@("`O+R!686QU97,N
M"B`@("`@("`@)'!A='1E<FYS6UT@/2`G(3HH7',J*2@N*S\I*%QS*CLI(7,G
M.PH@("`@("`@("1R97!L86-E<UM=(#T@)SI<7#$\<W!A;B!C;&%S<STB=F%L
M=64B/EQ<,CPO<W!A;CX\<W!A;B!C;&%S<STB96]L(CY<7#,\+W-P86X^)SL*
M"B`@("`@("`@+R\@55),<RX*("`@("`@("`D<&%T=&5R;G-;72`]("<A*'5R
M;%PH6UPG(ET_*2@N*C\I*%M<)R)=/UPI*2%S)SL*("`@("`@("`D<F5P;&%C
M97-;72`]("<\<W!A;B!C;&%S<STB=7)L(CY<7#$\<W!A;B!C;&%S<STB9FEL
M92(^7%PR/"]S<&%N/EQ<,SPO<W!A;CXG.PH*("`@("`@("`O+R!#;VQO<G,N
M"B`@("`@("`@)'!A='1E<FYS6UT@/2`G(2@C6ULZ>&1I9VET.EU=>S,L-GTI
M(7,G.PH@("`@("`@("1R97!L86-E<UM=(#T@)SQS<&%N(&-L87-S/2)C;VQO
M<B(^7%PQ/"]S<&%N/B<["@H@("`@("`@("\O(%!A<F5N=&AE<V5S+@H@("`@
M("`@("1P871T97)N<UM=(#T@)R$H>WQ]*2%S)SL*("`@("`@("`D<F5P;&%C
M97-;72`]("<\<W!A;B!C;&%S<STB<&%R96YT:&5S97,B/EQ<,3PO<W!A;CXG
M.PH*("`@("`@("`O+R!5;FET>2X*("`@("`@("`D<&%T=&5R;G-;72`]("<A
M*&5M?'!X?"4I7&(A<R<["B`@("`@("`@)')E<&QA8V5S6UT@/2`G/&5M/EQ<
M,3PO96T^)SL*"B`@("`@("`@<F5T=7)N('!R96=?<F5P;&%C92@D<&%T=&5R
M;G,L("1R97!L86-E<RP@)&UA=&-H97-;,%TI.PH@("`@?0H*("`@(&9U;F-T
M:6]N(%]H86YD;&5S*"1M871C:&5S*0H@("`@>PH@("`@("`@("\O($A434P@
M5&%G<RX*("`@("`@("`D<&%T=&5R;G-;72`]("<A7&(H8F]D>7QH7&1\87QS
M<&%N?&1I=GQA8W)O;GEM?'-M86QL?'-T<F]N9WQE;7QP<F5\=6Q\;VQ\;&E\
M<"E<8B%S)SL*("`@("`@("`D<F5P;&%C97-;72`]("<\<W!A;B!C;&%S<STB
M:'1A9R(^7%PQ/"]S<&%N/EQ<,B<["@H@("`@("`@("\O($E$<RX*("`@("`@
M("`D<&%T=&5R;G-;72`]("<A*"-;+5QW72LI(7,G.PH@("`@("`@("1R97!L
M86-E<UM=(#T@)SQS<&%N(&-L87-S/2)I9"(^7%PQ/"]S<&%N/B<["@H@("`@
M("`@("\O($-L87-S+@H@("`@("`@("1P871T97)N<UM=(#T@)R$H7"Y;+5QW
M72LI7&(A<R<["B`@("`@("`@)')E<&QA8V5S6UT@/2`G/'-P86X@8VQA<W,]
M(F-L87-S(CY<7#$\+W-P86X^)SL*"B`@("`@("`@+R\@345407,N"B`@("`@
M("`@)'!A='1E<FYS6UT@/2`G(2@Z;&EN:WPZ=FES:71E9'PZ:&]V97)\.F%C
M=&EV97PZ9FER<W0M;&5T=&5R*2%S)SL*("`@("`@("`D<F5P;&%C97-;72`]
M("<\<W!A;B!C;&%S<STB;65T86,B/EQ<,3PO<W!A;CXG.PH*("`@("`@("!R
M971U<FX@<')E9U]R97!L86-E*"1P871T97)N<RP@)')E<&QA8V5S+"`D;6%T
M8VAE<ULP72D["B`@("!]"@I]"@``````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H
M<````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`W-C4U(#$P-3$U-#,S-S,V
M(#`R,S<Q-@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`H*<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@
M)R]S;W5R8V4N<&AP)SL*"B\J*@H@*B!4:&4@34E-15]6:65W97)?96YS8W)I
M<'0@8VQA<W,@<F5N9&5R<R!O=70@=F%R:6]U<R!C;VYT96YT"B`J(&EN($A4
M34P@9F]R;6%T(&)Y('5S:6YG($=.52!%;G-C<FEP="X*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`L=B`Q
M+C,Y+C$P+C@@,C`P-B\P-B\P,2`P,SHP.#HU,R!C:'5C:R!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL
M0')E8V]I;"YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!!;FEL
M($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`<VEN8V4@("!(
M;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?34E-15]6:65W97(*("HO"F-L
M87-S($U)345?5FEE=V5R7V5N<V-R:7!T(&5X=&5N9',@34E-15]6:65W97)?
M<V]U<F-E('L*"B`@("`O*BH*("`@("`J(%)E;F1E<B!O=70@=&AE(&1A=&$@
M=7-I;F<@16YS8W)I<'0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P
M87)A;7,@($%N>2!P87)A;65T97)S('1H92!6:65W97(@;6%Y(&YE960N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!R96YD97)E9"!D871A
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97(H)'!A<F%M<R`](&%R<F%Y
M*"DI"B`@("!["B`@("`@("`@9VQO8F%L("1M:6UE7V1R:79E<G,["@H@("`@
M("`@("\J($-H96-K('1O(&UA:V4@<W5R92!T:&4@<')O9W)A;2!A8W1U86QL
M>2!E>&ES=',N("HO"B`@("`@("`@:68@*"%F:6QE7V5X:7-T<R@D;6EM95]D
M<FEV97)S6R=H;W)D92==6R=E;G-C<FEP="==6R=L;V-A=&EO;B==*2D@>PH@
M("`@("`@("`@("!R971U<FX@)SQP<F4^)R`N('-P<FEN=&8H7R@B5&AE('!R
M;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO
M="!F;W5N9"!O;B!T:&4@<WES=&5M+B(I+"`D;6EM95]D<FEV97)S6R=H;W)D
M92==6R=E;G-C<FEP="==6R=L;V-A=&EO;B==*2`N("<\+W!R93XG.PH@("`@
M("`@('T*"B`@("`@("`@+RH@0W)E871E('1E;7!O<F%R>2!F:6QE<R!F;W(@
M:6YP=70@=&\@16YS8W)I<'0N($YO=&4@=&AA="!W90H@("`@("`@("`@(&-A
M;FYO="!U<V4@82!P:7!E+"!S:6YC92!E;G-C<FEP="!M=7-T(&AA=F4@86-C
M97-S('1O('1H90H@("`@("`@("`@('=H;VQE(&9I;&4@=&\@9&5T97)M:6YE
M(&ET<R!T>7!E(&9O<B!C;VQO=7)E9"!S>6YT87@*("`@("`@("`@("!H:6=H
M;&EG:'1I;F<N("HO"B`@("`@("`@)'1M<&EN(#T@2&]R9&4Z.F=E=%1E;7!&
M:6QE*"=%;G-C<FEP=$EN)RD["@H@("`@("`@("\J(%=R:71E('1H92!C;VYT
M96YT<R!O9B!O=7(@8G5F9F5R('1O('1H92!T96UP;W)A<GD@:6YP=70@9FEL
M92X@*B\*("`@("`@("`D8V]N=&5N=',@/2`D=&AI<RT^;6EM95]P87)T+3YG
M971#;VYT96YT<R@I.PH@("`@("`@("1F:"`](&9O<&5N*"1T;7!I;BP@)W=B
M)RD["B`@("`@("`@9G=R:71E*"1F:"P@)&-O;G1E;G1S+"!S=')L96XH)&-O
M;G1E;G1S*2D["B`@("`@("`@9F-L;W-E*"1F:"D["@H@("`@("`@("\J($5X
M96-U=&4@=&AE(&5N<V-R:7!T(&-O;6UA;F0N("HO"B`@("`@("`@)&QA;F<@
M/2!E<V-A<&5S:&5L;&%R9R@D=&AI<RT^7W1Y<&54;TQA;F<H)'1H:7,M/FUI
M;65?<&%R="T^9V5T5'EP92@I*2D["B`@("`@("`@)')E<W5L=',@/2!S:&5L
M;%]E>&5C*"1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)V5N<V-R:7!T)UU;)VQO
M8V%T:6]N)UT@+B`B("U%)&QA;F<@+2UL86YG=6%G93UH=&UL("TM8V]L;W(@
M+2UO=71P=70]+2`\("1T;7!I;B(I.PH*("`@("`@("`O*B!3=')I<"!O=70@
M=&AE(&5X=')A;F5O=7,@2%1-3"!F<F]M($5N<V-R:7!T+"!A;F0@;W5T<'5T
M(&ET+B`J+PH@("`@("`@("1R97-?87)R(#T@<')E9U]S<&QI="@G+UP\7"\_
M<')E7#XO:2<L("1R97-U;'1S*3L*("`@("`@("!I9B`H8V]U;G0H)')E<U]A
M<G(I(#T](#,I('L*("`@("`@("`@("`@)')E<W5L=',@/2!T<FEM*"1R97-?
M87)R6S%=*3L*("`@("`@("!]"@H@("`@("`@("\J($5D=6-A=&5D($=U97-S
M(&%T('=H971H97(@=V4@87)E(&EN;&EN92!O<B!N;W0N("HO"B`@("`@("`@
M:68@*&AE861E<G-?<V5N="@I('Q\(&]B7V=E=%]L96YG=&@H*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/FQI;F5.=6UB97(H)')E<W5L=',I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!5=&EL.CIB=69F
M97)/=71P=70H)W)E<75I<F4G+"`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T
M*"=T96UP;&%T97,G+"`G:&]R9&4G*2`N("<O8V]M;6]N+6AE861E<BYI;F,G
M*2`N"B`@("`@("`@("`@("`@("`D=&AI<RT^;&EN94YU;6)E<B@D<F5S=6QT
M<RD@+@H@("`@("`@("`@("`@("`@571I;#HZ8G5F9F5R3W5T<'5T*"=R97%U
M:7)E)RP@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=&5M<&QA=&5S)RP@
M)VAO<F1E)RD@+B`G+V-O;6UO;BUF;V]T97(N:6YC)RD["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@9&5T97)M:6YE('=H
M870@;&%N9W5A9V4@=&\@=7-E(&9O<B!T:&4@96YS8W)I<'0@<')O9W)A;0H@
M("`@("H@9G)O;2!A($U)344@='EP92X*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E("!4
M:&4@34E-12!T>7!E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@96YS8W)I<'0@)VQA;F=U86=E)R!P87)A;65T97(@<W1R:6YG+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?='EP951O3&%N9R@D='EP92D*("`@('L*("`@
M("`@("!I;F-L=61E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN+TUA
M9VEC+G!H<"<["@H@("`@("`@("1E>'0@/2!-24U%7TUA9VEC.CI-24U%5&]%
M>'0H)'1Y<&4I.PH*("`@("`@("!S=VET8V@@*"1E>'0I('L*("`@("`@("!C
M87-E("=C<R<Z"B`@("`@("`@("`@(')E='5R;B`G:F%V82<["@H@("`@("`@
M(&-A<V4@)V5L)SH*("`@("`@("`@("`@<F5T=7)N("=E;&ES<"<["@H@("`@
M("`@(&-A<V4@)V@G.@H@("`@("`@("`@("!R971U<FX@)V,G.PH*("`@("`@
M("!C87-E("=#)SH*("`@("`@("!C87-E("=()SH*("`@("`@("!C87-E("=C
M8R<Z"B`@("`@("`@8V%S92`G:&@G.@H@("`@("`@(&-A<V4@)V,K*R<Z"B`@
M("`@("`@8V%S92`G8WAX)SH*("`@("`@("!C87-E("=C<'`G.@H@("`@("`@
M("`@("!R971U<FX@)V-P<"<["@H@("`@("`@(&-A<V4@)VAT;2<Z"B`@("`@
M("`@8V%S92`G<VAT;6PG.@H@("`@("`@(&-A<V4@)WAM;"<Z"B`@("`@("`@
M("`@(')E='5R;B`G:'1M;"<["@H@("`@("`@(&-A<V4@)VIS)SH*("`@("`@
M("`@("`@<F5T=7)N("=J879A<V-R:7!T)SL*"B`@("`@("`@8V%S92`G<&%S
M)SH*("`@("`@("`@("`@<F5T=7)N("=P87-C86PG.PH*("`@("`@("!C87-E
M("=A;"<Z"B`@("`@("`@8V%S92`G8V=I)SH*("`@("`@("!C87-E("=P;"<Z
M"B`@("`@("`@8V%S92`G<&TG.@H@("`@("`@("`@("!R971U<FX@)W!E<FPG
M.PH*("`@("`@("!C87-E("=P<R<Z"B`@("`@("`@("`@(')E='5R;B`G<&]S
M='-C<FEP="<["@H@("`@("`@(&-A<V4@)W9B)SH*("`@("`@("`@("`@<F5T
M=7)N("=V8F$G.PH*("`@("`@("!C87-E("=V:&0G.@H@("`@("`@("`@("!R
M971U<FX@)W9H9&PG.PH*("`@("`@("!C87-E("=P871C:"<Z"B`@("`@("`@
M8V%S92`G9&EF9B<Z"B`@("`@("`@("`@(')E='5R;B`G9&EF9G4G.PH*("`@
M("`@("!D969A=6QT.@H@("`@("`@("`@("!R971U<FX@)&5X=#L*("`@("`@
M("!]"B`@("!]"@I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O
M5FEE=V5R+VEM86=E<RYP:'``````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`V-C$Q(#$P-3$U-#,S-S,V(#`R,S,R,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@5&AE($U)345?
M5FEE=V5R7VEM86=E<R!C;&%S<R!A;&QO=W,@:6UA9V5S('1O(&)E(&1I<W!L
M87EE9"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I;6%G97,N<&AP+'8@,2XQ."XX+CD@,C`P-B\P,2\P,2`R,3HR.#HR-2!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L(%-L
M=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*@H@*B!`875T:&]R("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`
M8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J($!S:6YC92`@($AO<F1E(#(N,@H@
M*B!`<&%C:V%G92!(;W)D95]-24U%7U9I97=E<@H@*B\*8VQA<W,@34E-15]6
M:65W97)?:6UA9V5S(&5X=&5N9',@34E-15]6:65W97(@>PH*("`@("\J*@H@
M("`@("H@4F5T=7)N('1H92!C;VYT96YT+71Y<&4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!C;VYT96YT+71Y<&4@;V8@=&AE(&]U='!U
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@
M("`@)'1Y<&4@/2`D=&AI<RT^;6EM95]P87)T+3YG9714>7!E*"D["B`@("`@
M("`@:68@*"1'3$]"04Q36R=B<F]W<V5R)UTM/FES0G)O=W-E<B@G;6]Z:6QL
M82<I("8F"B`@("`@("`@("`@("@D='EP92`]/2`G:6UA9V4O<&IP96<G*2D@
M>PH@("`@("`@("`@("`O*B!I;6%G92]J<&5G(&%N9"!I;6%G92]P:G!E9R`J
M87!P96%R*B!T;R!B92!T:&4@<V%M90H@("`@("`@("`@("`@*B!E;G1I='DL
M(&)U="!-;WII;&QA(&1O;B=T('-E96T@=&\@=V%N="!T;R!A8V-E<'0@=&AE
M"B`@("`@("`@("`@("`J(&QA='1E<BX@($9O<B!O=7(@<'5R<&]S97,L('=E
M('=I;&P@=')E870@=&AE;2!T:&4*("`@("`@("`@("`@("H@<V%M92X@*B\*
M("`@("`@("`@("`@<F5T=7)N("=I;6%G92]J<&5G)SL*("`@("`@("!](&5L
M<V5I9B`H)'1Y<&4@/3T@)VEM86=E+W@M<&YG)RD@>PH@("`@("`@("`@("`O
M*B!I;6%G92]X+7!N9R!I<R!E<75I=F%L96YT('1O(&EM86=E+W!N9RX@*B\*
M("`@("`@("`@("`@<F5T=7)N("=I;6%G92]P;F<G.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E='5R;B`D='EP93L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T92!(5$U,(&]U='!U="!F;W(@82!J
M879A<V-R:7!T(&%U=&\M<F5S:7IE('9I97<@=VEN9&]W+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'5R;"`@("!4:&4@55),('=H:6-H(&-O;G1A:6YS('1H92!A8W1U86P@
M:6UA9V4@9&%T82X*("`@("`J($!P87)A;2!S=')I;F<@)'1I=&QE("!4:&4@
M=&ET;&4@=&\@=7-E(&9O<B!T:&4@<&%G92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE($A434P@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?<&]P=7!);6%G95=I;F1O=R@D=7)L+"`D=&ET;&4I"B`@("!["B`@
M("`@("`@9VQO8F%L("1B<F]W<V5R.PH*("`@("`@("`D<W1R(#T@/#P\14]$
M"CQH=&UL/@H\:&5A9#X*/'1I=&QE/B1T:71L93PO=&ET;&4^"CQS='EL92!T
M>7!E/2)T97AT+V-S<R(^/"$M+2!B;V1Y('L@;6%R9VEN.C!P>#L@<&%D9&EN
M9SHP<'@[('T@+2T^/"]S='EL93X*14]$.PH*("`@("`@("`O*B!/;FQY('5S
M92!J879A<V-R:7!T(&EF('=E(&%R92!U<VEN9R!A($1/32!C87!A8FQE(&)R
M;W=S97(N("HO"B`@("`@("`@:68@*"1B<F]W<V5R+3YG971&96%T=7)E*"=D
M;VTG*2D@>PH@("`@("`@("`@("`O*B!4<F%N<VQA=&4@)R9A;7`G(&5N=&ET
M:65S('1O("<F)R!F;W(@2E,@55),(&QI;FMS+B`J+PH@("`@("`@("`@("`D
M=7)L(#T@<W1R7W)E<&QA8V4H)R9A;7`[)RP@)R8G+"`D=7)L*3L*"B`@("`@
M("`@("`@("\J($UO>FEL;&$@86YD($E%(&1E=&5R;6EN92!W:6YD;W<@9&EM
M96YS:6]N<R!I;B!D:69F97)E;G0@=V%Y<RX@*B\*("`@("`@("`@("`@:68@
M*"1B<F]W<V5R+3YI<T)R;W=S97(H)VUS:64G*2D@>PH@("`@("`@("`@("`@
M("`@)&E7:61T:%]C;V1E(#T@)V1O8W5M96YT+F)O9'DN8VQI96YT5VED=&@[
M)SL*("`@("`@("`@("`@("`@("1I2&5I9VAT7V-O9&4@/2`G9&]C=6UE;G0N
M8F]D>2YC;&EE;G1(96EG:'0[)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1I5VED=&A?8V]D92`]("=W:6YD;W<N:6YN97)7:61T
M:#LG.PH@("`@("`@("`@("`@("`@)&E(96EG:'1?8V]D92`]("=W:6YD;W<N
M:6YN97)(96EG:'0[)SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@
M2F%V87-C<FEP="!D:7-P;&%Y+B`J+PH@("`@("`@("`@("`D;&]A9&EN9R`]
M(%\H(DQO861I;F<N+BXB*3L*("`@("`@("`@("`@)'-T<B`N/2`\/#Q%3T0*
M/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@IF=6YC=&EO;B!R97-I
M>F57:6YD;W<H*2!["B`@("!W:6YD;W<N;6]V951O*#`L(#`I.PH@("`@9&]C
M=6UE;G0N9V5T16QE;65N=$)Y260H)W-P;&%S:"<I+G-T>6QE+F1I<W!L87D@
M/2`G;F]N92<["B`@("!D;V-U;65N="YG971%;&5M96YT0GE)9"@G9&ES<%]I
M;6%G92<I+G-T>6QE+F1I<W!L87D@/2`G8FQO8VLG.PH@("`@=F%R(&E7:61T
M:"`](&1O8W5M96YT+FEM86=E<ULP72YW:61T:"`M("1I5VED=&A?8V]D90H@
M("`@=F%R(&E(96EG:'0@/2!D;V-U;65N="YI;6%G97-;,%TN:&5I9VAT("T@
M)&E(96EG:'1?8V]D90H@("`@=VEN9&]W+G)E<VEZ94)Y*&E7:61T:"P@:4AE
M:6=H="D["B`@("!S96QF+F9O8W5S*"D[(`I]"CPO<V-R:7!T/CPO:&5A9#X*
M/&)O9'D@;VYL;V%D/2)R97-I>F57:6YD;W<H*3LB/CQS<&%N(&ED/2)S<&QA
M<V@B('-T>6QE/2)C;VQO<CIG<F%Y.V9O;G0M9F%M:6QY.G-A;G,M<V5R:68[
M<&%D9&EN9SHR<'@[(CXD;&]A9&EN9SPO<W!A;CX\:6UG(&ED/2)D:7-P7VEM
M86=E(B!S='EL93TB9&ES<&QA>3IN;VYE.R(@<W)C/2(D=7)L(B`O/CPO8F]D
M>3X\+VAT;6P^"D5/1#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O
M*B!.;VXM:F%V87-C<FEP="!D:7-P;&%Y+B`J+PH@("`@("`@("`@("`D:6UG
M7W1X="`](%\H(DEM86=E(BD["B`@("`@("`@("`@("1S='(@+CT@/#P\14]$
M"CPO:&5A9#X*/&)O9'D@8F=C;VQO<CTB(V9F9F9F9B(@=&]P;6%R9VEN/2(P
M(B!M87)G:6YH96EG:'0](C`B(&QE9G1M87)G:6X](C`B(&UA<F=I;G=I9'1H
M/2(P(CX*/&EM9R!B;W)D97(](C`B('-R8STB)'5R;"(@86QT/2(D:6UG7W1X
M="(@+SX*/"]B;V1Y/@H\+VAT;6P^"D5/1#L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D<W1R.PH@("`@?0H*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%
M+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,S4Q,B`Q,#4Q-30S,S<S-B`P,C0V,C$`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!-24U%
M7U9I97=E<E]M<W!O=V5R<&]I;G0@8VQA<W,@<F5N9&5R<R!O=70@36EC<F]S
M;V9T(%!O=V5R<&]I;G0*("H@9&]C=6UE;G1S(&EN($A434P@9F]R;6%T(&)Y
M('5S:6YG('1H92!X;$AT;6P@<&%C:V%G92X*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP+'8@,2XQ
M,RXQ,"XW(#(P,#8O,#$O,#$@,C$Z,C@Z,C4@:F%N($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`Q.3DY+3(P,#8@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C
M;VEL+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($%N:6P@36%D
M:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J($!S:6YC92`@($AO<F1E
M(#$N,PH@*B!`<&%C:V%G92!(;W)D95]-24U%7U9I97=E<@H@*B\*8VQA<W,@
M34E-15]6:65W97)?;7-P;W=E<G!O:6YT(&5X=&5N9',@34E-15]6:65W97(@
M>PH*("`@("\J*@H@("`@("H@4F5N9&5R(&]U="!T:&4@8W5R<F5N="!D871A
M('5S:6YG('!P=&AT;6PN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P
M87)A;7,@($%N>2!P87)A;65T97)S('1H92!6:65W97(@;6%Y(&YE960N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!R96YD97)E9"!C;VYT
M96YT<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R*"1P87)A;7,@/2!A
M<G)A>2@I*0H@("`@>PH@("`@("`@(&=L;V)A;"`D;6EM95]D<FEV97)S.PH*
M("`@("`@("`O*B!#:&5C:R!T;R!M86ME('-U<F4@=&AE('!R;V=R86T@86-T
M=6%L;'D@97AI<W1S+B`J+PH@("`@("`@(&EF("@A9FEL95]E>&ES=',H)&UI
M;65?9')I=F5R<ULG:&]R9&4G75LG;7-P;W=E<G!O:6YT)UU;)VQO8V%T:6]N
M)UTI*2!["B`@("`@("`@("`@(')E='5R;B`G/'!R93XG("X@<W!R:6YT9BA?
M*")4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S
M*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(BDL("1M:6UE7V1R:79E
M<G-;)VAO<F1E)UU;)VUS<&]W97)P;VEN="==6R=L;V-A=&EO;B==*2`N("<\
M+W!R93XG.PH@("`@("`@('T*"B`@("`@("`@)&1A=&$@/2`G)SL*("`@("`@
M("`D=&UP7W!P="`]($AO<F1E.CIG971496UP1FEL92@G:&]R9&5?;7-P;W=E
M<G!O:6YT)RD["@H@("`@("`@("1F:"`](&9O<&5N*"1T;7!?<'!T+"`G=R<I
M.PH@("`@("`@(&9W<FET92@D9F@L("1T:&ES+3YM:6UE7W!A<G0M/F=E=$-O
M;G1E;G1S*"DI.PH@("`@("`@(&9C;&]S92@D9F@I.PH*("`@("`@("`D9F@@
M/2!P;W!E;B@D;6EM95]D<FEV97)S6R=H;W)D92==6R=M<W!O=V5R<&]I;G0G
M75LG;&]C871I;VXG72`N("(@)'1M<%]P<'0@,CXF,2(L("=R)RD["B`@("`@
M("`@=VAI;&4@*"@D<F,@/2!F9V5T<R@D9F@L(#@Q.3(I*2D@>PH@("`@("`@
M("`@("`D9&%T82`N/2`D<F,["B`@("`@("`@?0H@("`@("`@('!C;&]S92@D
M9F@I.PH*("`@("`@("!R971U<FX@)&1A=&$["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FX@=&AE($U)344@8V]N=&5N="!T>7!E(&]F('1H92!R96YD
M97)E9"!C;VYT96YT+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@8V]N=&5N="!T>7!E(&]F('1H92!O=71P=70N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G=&5X="]H
M=&UL.R!C:&%R<V5T/2<@+B!.3%,Z.F=E=$-H87)S970H*3L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W
M97(O;7-W;W)D+G!H<```````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#4Q
M,C0@,3`U,34T,S,W,S8@,#(S,S8W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B!4:&4@34E-15]6:65W
M97)?;7-W;W)D(&-L87-S(')E;F1E<G,@;W5T($UI8W)O<V]F="!7;W)D"B`J
M(&1O8W5M96YT<R!I;B!(5$U,(&9O<FUA="!B>2!U<VEN9R!T:&4@=W9787)E
M('!A8VMA9V4N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O;7-W;W)D+G!H<"QV(#$N,C4N,3`N."`R,#`V+S`Q+S`Q(#(Q.C(X
M.C(U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($%N:6P@
M36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B!`875T:&]R("!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN
M;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?
M34E-15]6:65W97(*("HO"F-L87-S($U)345?5FEE=V5R7VUS=V]R9"!E>'1E
M;F1S($U)345?5FEE=V5R('L*"B`@("`O*BH*("`@("`J(%)E;F1E<B!O=70@
M=&AE(&-U<G)E;G0@9&%T82!U<VEN9R!W=E=A<F4N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N>2!P87)A;65T97)S('1H92!6:65W
M97(@;6%Y(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!R96YD97)E9"!C;VYT96YT<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N
M9&5R*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&=L;V)A;"`D
M;6EM95]D<FEV97)S.PH*("`@("`@("`O*B!#:&5C:R!T;R!M86ME('-U<F4@
M=&AE('!R;V=R86T@86-T=6%L;'D@97AI<W1S+B`J+PH@("`@("`@(&EF("@A
M9FEL95]E>&ES=',H)&UI;65?9')I=F5R<ULG:&]R9&4G75LG;7-W;W)D)UU;
M)VQO8V%T:6]N)UTI*2!["B`@("`@("`@("`@(')E='5R;B`G/'!R93XG("X@
M<W!R:6YT9BA?*")4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A
M('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(BDL("1M
M:6UE7V1R:79E<G-;)VAO<F1E)UU;)VUS=V]R9"==6R=L;V-A=&EO;B==*2`N
M("<\+W!R93XG.PH@("`@("`@('T*"B`@("`@("`@)&1A=&$@/2`G)SL*("`@
M("`@("`D=&UP7W=O<F0@("`]($AO<F1E.CIG971496UP1FEL92@G;7-W;W)D
M)RD["B`@("`@("`@)'1M<%]O=71P=70@/2!(;W)D93HZ9V5T5&5M<$9I;&4H
M)VUS=V]R9"<I.PH@("`@("`@("1T;7!?9&ER("`@(#T@2&]R9&4Z.F=E=%1E
M;7!$:7(H*3L*("`@("`@("`D=&UP7V9I;&4@("`]('-T<E]R97!L86-E*"1T
M;7!?9&ER("X@)R\G+"`G)RP@)'1M<%]O=71P=70I.PH*("`@("`@("!I9B`H
M3U-?5TE.1$]74RD@>PH@("`@("`@("`@("`D87)G<R`]("<@+7@@)R`N(&1I
M<FYA;64H)&UI;65?9')I=F5R<ULG:&]R9&4G75LG;7-W;W)D)UU;)VQO8V%T
M:6]N)UTI("X@(EQ<=W9(=&UL+GAM;"`M9"`D=&UP7V1I<B`M,2`D=&UP7W=O
M<F0@/B`D=&UP7V]U='!U="(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'9E<G-I;VX@/2!E>&5C*"1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)VUS
M=V]R9"==6R=L;V-A=&EO;B==("X@)R`M+79E<G-I;VXG*3L*("`@("`@("`@
M("`@:68@*'9E<G-I;VY?8V]M<&%R92@D=F5R<VEO;BP@)S`N-RXP)RD@/CT@
M,"D@>PH@("`@("`@("`@("`@("`@)&%R9W,@/2`B("TM8VAA<G-E=#TB("X@
M3DQ3.CIG971#:&%R<V5T*"D@+B`B("TM=&%R9V5T9&ER/21T;7!?9&ER("1T
M;7!?=V]R9"`D=&UP7V9I;&4B.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@)&%R9W,@/2`B("1T;7!?=V]R9"`D=&UP7V]U='!U="([
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1F:"`](&9O<&5N
M*"1T;7!?=V]R9"P@)W<G*3L*("`@("`@("!F=W)I=&4H)&9H+"`D=&AI<RT^
M;6EM95]P87)T+3YG971#;VYT96YT<R@I*3L*("`@("`@("!F8VQO<V4H)&9H
M*3L*"B`@("`@("`@97AE8R@D;6EM95]D<FEV97)S6R=H;W)D92==6R=M<W=O
M<F0G75LG;&]C871I;VXG72`N("1A<F=S*3L*"B`@("`@("`@:68@*"%F:6QE
M7V5X:7-T<R@D=&UP7V]U='!U="DI('L*("`@("`@("`@("`@<F5T=7)N(%\H
M(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(BD["B`@
M("`@("`@?0H*("`@("`@("`D9F@@/2!F;W!E;B@D=&UP7V]U='!U="P@)W(G
M*3L*("`@("`@("!W:&EL92`H*"1R8R`](&9G971S*"1F:"P@.#$Y,BDI*2![
M"B`@("`@("`@("`@("1D871A("X]("1R8SL*("`@("`@("!]"B`@("`@("`@
M9F-L;W-E*"1F:"D["@H@("`@("`@(')E='5R;B`D9&%T83L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;B!T:&4@34E-12!C;VYT96YT('1Y<&4@;V8@
M=&AE(')E;F1E<F5D(&-O;G1E;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!C;VYT96YT('1Y<&4@;V8@=&AE(&]U='!U="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N
M("=T97AT+VAT;6P[(&-H87)S970])R`N($Y,4SHZ9V5T0VAA<G-E="@I.PH@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]H=&UL+G!H<```````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q-#4Q,2`Q,#4Q-30S,S<S-B`P
M,C,P,C``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J(%1H92!-24U%7U9I97=E<E]H=&UL(&-L87-S(')E
M;F1E<G,@;W5T($A434P@=&5X="!W:71H(&%N(&5F9F]R="!T;PH@*B!R96UO
M=F4@<&]T96YT:6%L;'D@;6%L:6-I;W5S(&-O9&4N"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`L=B`Q+C$T+C0N
M,C`@,C`P-B\P-B\P-R`Q,SHS-#HQ-B!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#$Y.3DM,C`P-B!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN
M;W)G/@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H
M;W)D92YO<F<^"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EC:&%E;"!3;'5S
M87)Z(#QS;'5S87)Z0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`
M875T:&]R("!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!`875T:&]R
M("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`:&]R9&4N;W)G/@H@*B!`<VEN
M8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?34E-15]6:65W97(*
M("HO"F-L87-S($U)345?5FEE=V5R7VAT;6P@97AT96YD<R!-24U%7U9I97=E
M<B!["@H@("`@+RHJ"B`@("`@*B!296YD97(@;W5T('1H92!C=7)R96YT;'D@
M<V5T(&-O;G1E;G1S+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R
M86US("!!;GD@<&%R86UE=&5R<R!T:&4@=FEE=V5R(&UA>2!N965D+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F5N9&5R960@=&5X="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R*"1P87)A;7,@/2!N=6QL*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V-L96%N2%1-3"@D=&AI<RT^
M;6EM95]P87)T+3YG971#;VYT96YT<R@I*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($9I;'1E<G,@86-T:79E(&-O;G1E;G0L(&1E<F5F97)E;F-E<R!E>'1E
M<FYA;"!L:6YK<RP@9&5T96-T<R!P:&ES:&EN9RP*("`@("`J(&5T8RX*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1D871A("!4:&4@2%1-3"!D871A+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@8VQE86YE9"!(5$U,(&1A=&$N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]C;&5A;DA434PH)&1A=&$I"B`@("!["B`@("`@
M("`@9VQO8F%L("1B<F]W<V5R+"`D<')E9G,["@H@("`@("`@("1P:&ES:%]W
M87)N(#T@9F%L<V4["@H@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O34E-
M12]#;VYT96YT<RYP:'`G.PH@("`@("`@("1A='1A8VAM96YT(#T@34E-15]#
M;VYT96YT<SHZ=FEE=T%S071T86-H;65N="@I.PH*("`@("`@("`O*B!$96%L
M('=I=&@@/&)A<V4^('1A9W,@:6X@=&AE($A434PL('-I;F-E('1H97D@=VEL
M;"!S8W)E=R!U<"!O=7(@;W=N"B`@("`@("`@("H@<F5L871I=F4@<&%T:',N
M("HO"B`@("`@("`@:68@*'!R96=?;6%T8V@H)R\\8F%S92!H<F5F/2(_*%M>
M(CX@72HI(C\@/UPO/SXO:2<L("1D871A+"`D;6%T8VAE<RDI('L*("`@("`@
M("`@("`@)&)A<V4@/2`D;6%T8VAE<ULQ73L*("`@("`@("`@("`@:68@*'-U
M8G-T<B@D8F%S92P@+3$L(#$I("$]("<O)RD@>PH@("`@("`@("`@("`@("`@
M)&)A<V4@+CT@)R\G.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!2
M96-U<G-I=F5L>2!C86QL(%]C;&5A;DA434PH*2!T;R!P<F5V96YT(&-L979E
M<B!F:65N9',@9G)O;0H@("`@("`@("`@("`@*B!S;F5A:VEN9R!N87-T>2!T
M:&EN9W,@:6YT;R!T:&4@<&%G92!V:6$@)&)A<V4N("HO"B`@("`@("`@("`@
M("1B87-E(#T@)'1H:7,M/E]C;&5A;DA434PH)&)A<V4I.PH@("`@("`@('T*
M"B`@("`@("`@+RH@071T96UP="!T;R!F:7@@<&%T:',@=&AA="!W97)E(')E
M;'EI;F<@;VX@82`\8F%S93X@=&%G+B`J+PH@("`@("`@(&EF("@A96UP='DH
M)&)A<V4I*2!["B`@("`@("`@("`@("1P871T97)N(#T@87)R87DH)WQS<F,]
M*%LB7"==*2A;7CHB7"==*RE<,7QI)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G?'-R8STH6UXZ(#XB7"==*RE\:2<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)WQH<F5F/2`J*%LB7"==*2A;7CHB7"==*RE<,7QI
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G?&AR968]*%M>.B`^
M(EPG72LI?&DG*3L*("`@("`@("`@("`@)')E<&QA8V4@/2!A<G)A>2@G<W)C
M/5PQ)R`N("1B87-E("X@)UPR7#$G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=S<F,])R`N("1B87-E("X@)UPQ)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G:')E9CU<,2<@+B`D8F%S92`N("=<,EPQ)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G:')E9CTG("X@)&)A<V4@+B`G
M7#$G*3L*("`@("`@("`@("`@)&1A=&$@/2!P<F5G7W)E<&QA8V4H)'!A='1E
M<FXL("1R97!L86-E+"`D9&%T82D["B`@("`@("`@?0H*("`@("`@("!R97%U
M:7)E7V]N8V4@)TAO<F1E+U1E>'0O1FEL=&5R+G!H<"<["B`@("`@("`@)'-T
M<FEP7W-T>6QE<R`]("$D871T86-H;65N="!\?`H@("`@("`@("`@("`H)&)R
M;W=S97(M/FES0G)O=W-E<B@G;6]Z:6QL82<I("8F"B`@("`@("`@("`@("`D
M8G)O=W-E<BT^9V5T36%J;W(H*2`]/2`T*2!\?`H@("`@("`@("`@("`D8G)O
M=W-E<BT^:7-"<F]W<V5R*"=M<VEE)RD["B`@("`@("`@)&1A=&$@/2!497AT
M7T9I;'1E<CHZ9FEL=&5R*"1D871A+"`G>'-S)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)V)O9'E?;VYL>2<@/3X@(21A
M='1A8VAM96YT+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G<W1R:7!?<W1Y;&5S)R`]/B`D<W1R:7!?<W1Y;&5S*2D["@H@
M("`@("`@("\J($-H96-K(&9O<B!P:&ES:&EN9R!E>'!L;VET<RX@*B\*("`@
M("`@("!I9B`H<')E9U]M871C:"@G+VAR969<<RH]7',J6R)<)UT_7',J*&AT
M='!\:'1T<'-\9G1P*3I<+UPO7&1[,2PS?5PN7&1[,2PS?5PN7&1[,2PS?5PN
M7&1[,2PS?2]I)RP@)&1A=&$I*2!["B`@("`@("`@("`@("\J($-H96-K(#$Z
M($-H96-K(&9O<B!)4"!A9&1R97-S(&QI;FMS+B`J+PH@("`@("`@("`@("`D
M<&AI<VA?=V%R;B`]('1R=64["B`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T
M8VA?86QL*"<O:')E9EQS*CU<<RI;(EPG73]<<RHH/SIH='1P?&AT='!S?&9T
M<"DZ7"]<+RA;7EQS(EPG/ETK*5LB7"==/UM>/ETJ/EQS*B@_.B@_.FAT='!\
M:'1T<'-\9G1P*3I<+UPO*3\H+BH_*3Q<+V$O:7,G+"`D9&%T82P@)&TI*2![
M"B`@("`@("`@("`@("\J("1M6S%=(#T@3&EN:SL@)&U;,ET@/2!487)G970*
M("`@("`@("`@("`@("H@0VAE8VL@,CH@0VAE8VL@9F]R(&QI;FMS('1H870@
M<&]I;G0@=&\@82!D:69F97)E;G0@:&]S="!T:&%N"B`@("`@("`@("`@("`J
M('1H92!T87)G970@=7)L.R!I9B!T87)G970@;&]O:W,@;&EK92!A(&1O;6%I
M;B!N86UE+"!C:&5C:R!I=`H@("`@("`@("`@("`@*B!A9V%I;G-T('1H92!L
M:6YK+B`J+PH@("`@("`@("`@("`D;&EN:W,@/2!C;W5N="@D;5LP72D["B`@
M("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1L:6YK<SL@)&DK*RD@>PH@
M("`@("`@("`@("`@("`@)&U;,5U;)&E=(#T@<W1R=&]L;W=E<BAU<FQD96-O
M9&4H)&U;,5U;)&E=*2D["B`@("`@("`@("`@("`@("`D;5LR75LD:5T@/2!S
M=')T;VQO=V5R*'!R96=?<F5P;&%C92@G+UXH:'1T<'QH='1P<WQF='`I.EPO
M7"\O)RP@)R<L('-T<FEP7W1A9W,H)&U;,EU;)&E=*2DI.PH@("`@("`@("`@
M("`@("`@:68@*'!R96=?;6%T8V@H)R]>6RTN7UQD82UZ72M<+EMA+7I=>S(L
M?2]I)RP@)&U;,EU;)&E=*2`F)@H@("`@("`@("`@("`@("`@("`@('-T<G!O
M<R@D;5LQ75LD:5TL("1M6S)=6R1I72D@(3T](#`@)B8*("`@("`@("`@("`@
M("`@("`@("!S=')P;W,H)&U;,EU;)&E=+"`D;5LQ75LD:5TI("$]/2`P*2![
M"B`@("`@("`@("`@("`@("`@("`@+RH@1&]N)W0@8V]N<VED97(@=&AE(&QI
M;FL@82!P:&ES:&EN9R!L:6YK(&EF('1H92!D;VUA:6X*("`@("`@("`@("`@
M("`@("`@("`@*B!I<R!T:&4@<V%M92!O;B!B;W1H(&QI;FMS("AE+F<N(&%D
M=')A8VMI;F<N97AA;7!L92YC;VT*("`@("`@("`@("`@("`@("`@("`@*B`F
M('=W=RYE>&%M<&QE+F-O;2DN("HO"B`@("`@("`@("`@("`@("`@("`@<')E
M9U]M871C:"@G+UPN/RA;7EPN7"]=*UPN6UY<+EPO72LI7"\O)RP@)&U;,5U;
M)&E=+"`D:&]S=#$I.PH@("`@("`@("`@("`@("`@("`@('!R96=?;6%T8V@H
M)R]<+C\H6UY<+EPO72M<+EM>7"Y<+UTK*2A<+RXJ*3\D+R<L("1M6S)=6R1I
M72P@)&AO<W0R*3L*("`@("`@("`@("`@("`@("`@("!I9B`H(2AC;W5N="@D
M:&]S=#$I("8F(&-O=6YT*"1H;W-T,BDI('Q\"B`@("`@("`@("`@("`@("`@
M("`@("`@('-T<F-A<V5C;7`H)&AO<W0Q6S%=+"`D:&]S=#);,5TI("$]/2`P
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1P:&ES:%]W87)N(#T@=')U
M93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J(%1R>2!T;R!D97)E
M9F5R(&%L;"!E>'1E<FYA;"!R969E<F5N8V5S+B`J+PH@("`@("`@("1D871A
M(#T@<')E9U]R97!L86-E7V-A;&QB86-K*"<O:')E9EQS*CU<<RHH6R)<)UTI
M/R@H/R@Q*5M>7#%=*C]\6UY<<SY=*RDI*#\H,2E<,7PI+VDG+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-R96%T95]F=6YC=&EO
M;B@G)&TG+"`G<F5T=7)N(%PG:')E9CTB7"<@+B`H<W1R;&5N*"1M6S)=*2`F
M)B`D;5LR77LP?2`]/2!<)R-<)R`_("1M6S)=(#H@2&]R9&4Z.F5X=&5R;F%L
M57)L*"1M6S)=*2D@+B!<)R)<)SLG*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9&%T82D["@H@("`@("`@("\J(%!R97!E;F0@
M<&AI<VAI;F<@=V%R;FEN9RX@*B\*("`@("`@("!I9B`H)'!H:7-H7W=A<FXI
M('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+T-O;G1E
M;G1S+G!H<"<["B`@("`@("`@("`@("1C;VYT96YT<R`]("9N97<@34E-15]#
M;VYT96YT<RAN97<@34E-15]087)T*"DI.PH@("`@("`@("`@("`D<&AI<VA?
M=V%R;FEN9R`]('-P<FEN=&8H7R@B)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T
M(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL
M;W=I;F<@86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N
M9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+B(I+"!?*")787)N
M:6YG(BDI.PH@("`@("`@("`@("!I9B`H)&-O;G1E;G1S+3YV:65W07-!='1A
M8VAM96YT*"DI('L*("`@("`@("`@("`@("`@("1P:&ES:%]W87)N:6YG(#T@
M)SQS<&%N('-T>6QE/2)B86-K9W)O=6YD+6-O;&]R.B-F9F0P868[8V]L;W(Z
M8FQA8VLB/B<@+B!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1P:&ES:%]W87)N
M:6YG+"!.3%,Z.F=E=$-H87)S970H*2P@)'1H:7,M/FUI;65?<&%R="T^9V5T
M0VAA<G-E="@I*2`N("<\+W-P86X^/&)R("\^)SL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D<&AI<VA?=V%R;FEN9R`]("1C;VYT96YT<RT^9F]R;6%T
M4W1A='5S37-G*"1P:&ES:%]W87)N:6YG+"!N=6QL+"!T<G5E+"`G;6EM95-T
M871U<U=A<FYI;F<G*3L*("`@("`@("`@("`@:68@*'-T<FES='(H)&1A=&$L
M("<\8F]D>2<I(#T]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@)&1A=&$@
M/2`D<&AI<VA?=V%R;FEN9R`N("1D871A.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)&1A=&$@/2!P<F5G7W)E<&QA8V4H)R\H+BH\
M8F]D>2XJ/SXI*"XJ*2]I)RP@)R0Q)R`N("1P:&ES:%]W87)N:6YG("X@)R0R
M)RP@)&1A=&$I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)&1A=&$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE
M(&-O;G1E;G0M='EP92!O9B!T:&4@<F5N9&5R960@=&5X="X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($U)344@0V]N=&5N="U4>7!E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+TU)344O0V]N=&5N=',N<&AP)SL*("`@("`@
M("!R971U<FX@34E-15]#;VYT96YT<SHZ=FEE=T%S071T86-H;65N="@I(#\@
M)'1H:7,M/FUI;65?<&%R="T^9V5T5'EP92AT<G5E*2`Z("=T97AT+VAT;6P[
M(&-H87)S970])R`N($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O
M9&5F875L="YP:'``````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$Q-S<@
M,3`U,34T,S,W,S8@,#(S-3`T`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B!4:&4@34E-15]6:65W97)?
M9&5F875L="!C;&%S<R!S:6UP;'D@<')I;G1S(&]U="!T:&4@96YC87!S=6QA
M=&5D"B`J(&-O;G1E;G0N("!)="!E>&ES=',@87,@82!F86QL8F%C:R!I9B!N
M;R!O=&AE<B!I;G1E;&QI9V5N="!R96YD97)I;F<*("H@;65C:&%N:7-M(&-O
M=6QD(&)E('5S960N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O9&5F875L="YP:'`L=B`Q+CDN,3(N-"`R,#`V+S`Q+S`Q(#(Q
M.C(X.C(U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($%N
M:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B!`875T:&]R("!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O
M:6PN;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R
M9&5?34E-15]6:65W97(*("HO"F-L87-S($U)345?5FEE=V5R7V1E9F%U;'0@
M97AT96YD<R!-24U%7U9I97=E<B!["@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,C<T-38@,3`U,34T,S,W,S8@,#(S,38W`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@34E-15]6
M:65W97)?=F-A<F0@8VQA<W,@<F5N9&5R<R!O=70@=D-A<F1S(&EN($A434P@
M9F]R;6%T+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<"QV(#$N,S0N,3`N-R`R,#`V+S`Q+S`Q(#(Q.C(X.C(U
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($IA;B!38VAN
M96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@
M("!(;W)D92`R+C`*("H@0'!A8VMA9V4@2&]R9&5?34E-15]6:65W97(*("HO
M"F-L87-S($U)345?5FEE=V5R7W9C87)D(&5X=&5N9',@34E-15]6:65W97(@
M>PH*("`@("\J*@H@("`@("H@4F5N9&5R(&]U="!T:&4@=F-A<F0@8V]N=&5N
M=',N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N>2!P
M87)A;65T97)S('1H92!6:65W97(@;6%Y(&YE960N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!R96YD97)E9"!C;VYT96YT<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@<F5N9&5R*"1P87)A;7,@/2!N=6QL*0H@("`@>PH@
M("`@("`@(&=L;V)A;"`D<F5G:7-T<GDL("1P<F5F<SL*"B`@("`@("`@<F5Q
M=6ER95]O;F-E("=(;W)D92]I0V%L96YD87(N<&AP)SL*"B`@("`@("`@)&%P
M<"`](&9A;'-E.PH@("`@("`@("1D871A(#T@)'1H:7,M/FUI;65?<&%R="T^
M9V5T0V]N=&5N=',H*3L*("`@("`@("`D:'1M;"`]("<G.PH@("`@("`@("1I
M;7!O<G1?;7-G(#T@;G5L;#L*("`@("`@("`D=&ET;&4@/2!?*")V0V%R9"(I
M.PH*("`@("`@("`D:4-A;"`]("9N97<@2&]R9&5?:4-A;&5N9&%R*"D["B`@
M("`@("`@:68@*"$D:4-A;"T^<&%R<V5V0V%L96YD87(H)&1A=&$I*2!["B`@
M("`@("`@("`@("1I;7!O<G1?;7-G(#T@7R@B5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(I.PH@("`@("`@('T*"B`@
M("`@("`@:68@*%5T:6PZ.F=E=$9O<FU$871A*"=I;7!O<G0G*2`F)@H@("`@
M("`@("`@("!5=&EL.CIG971&;W)M1&%T82@G<V]U<F-E)RD@)B8*("`@("`@
M("`@("`@)')E9VES=')Y+3YH87--971H;V0H)V-O;G1A8W1S+VEM<&]R="<I
M*2!["B`@("`@("`@("`@("1S;W5R8V4@/2!5=&EL.CIG971&;W)M1&%T82@G
M<V]U<F-E)RD["B`@("`@("`@("`@("1C;VYT86-T<R`]("1R96=I<W1R>2T^
M8V%L;"@G8V]N=&%C=',O:6UP;W)T)RP@87)R87DH)&1A=&$L("=T97AT+W@M
M=F-A<F0G+"`D<V]U<F-E*2D["B`@("`@("`@("`@(&EF("AI<U]A*"1C;VYT
M86-T<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)&EM<&]R
M=%]M<V<@/2!?*")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C
M;VYT86-T(&1A=&$N(BD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("!I9B`H)&E#86PM/F=E=$-O;7!O;F5N=$-O=6YT*"D@/3T@,2D@
M>PH@("`@("`@("`@("`@("`@("`@("1I;7!O<G1?;7-G(#T@7R@B5&AE(&-O
M;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@
M8F]O:RXB*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@)&EM<&]R=%]M<V<@/2!?*")#;VYT86-T<R!W97)E('-U8V-E
M<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M)&AT;6P@(#T@571I;#HZ8G5F9F5R3W5T<'5T*"=I;F-L=61E)RP@)')E9VES
M=')Y+3YG970H)W1E;7!L871E<R<L("=H;W)D92<I("X@)R]C;VUM;VXM:&5A
M9&5R+FEN8R<I.PH@("`@("`@("1H=&UL("X]("<\=&%B;&4@8V5L;'-P86-I
M;F<](C$B(&)O<F1E<CTB,"(@8V5L;'!A9&1I;F<](C$B/B<["B`@("`@("`@
M:68@*"%I<U]N=6QL*"1I;7!O<G1?;7-G*2D@>PH@("`@("`@("`@("`D:'1M
M;"`N/2`G/'1R/CQT9"!C;VQS<&%N/2(R(B!C;&%S<STB:&5A9&5R(CXG("X@
M)&EM<&]R=%]M<V<@+B`G/"]T9#X\+W1R/CQT<CX\=&0^)FYB<W`[/"]T9#X\
M+W1R/B<["B`@("`@("`@?2!E;'-E:68@*"1R96=I<W1R>2T^:&%S365T:&]D
M*"=C;VYT86-T<R]I;7!O<G0G*2`F)@H@("`@("`@("`@("`@("`@("`D<F5G
M:7-T<GDM/FAA<TUE=&AO9"@G8V]N=&%C=',O<V]U<F-E<R<I*2!["B`@("`@
M("`@("`@("1H=&UL("X]("<\='(^/'1D(&-O;'-P86X](C(B(&-L87-S/2)H
M96%D97(B/CQF;W)M(&%C=&EO;CTB)R`N("1?4T525D526R=02%!?4T5,1B==
M("X@)R(@;65T:&]D/2)G970B(&YA;64](G9C87)D7VEM<&]R="(^)R`N(%5T
M:6PZ.F9O<FU);G!U="@I.PH@("`@("`@("`@("!F;W)E86-H("@D7T=%5"!A
M<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@("`@("1H=&UL("X]("<\
M:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2(G("X@:'1M;'-P96-I86QC:&%R
M<R@D:V5Y*2`N("<B('9A;'5E/2(G("X@:'1M;'-P96-I86QC:&%R<R@D=F%L
M*2`N("<B("\^)SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'-O=7)C
M97,@/2`D<F5G:7-T<GDM/F-A;&PH)V-O;G1A8W1S+W-O=7)C97,G+"!A<G)A
M>2AT<G5E*2D["B`@("`@("`@("`@(&EF("AC;W5N="@D<V]U<F-E<RD@/B`Q
M*2!["B`@("`@("`@("`@("`@("`D:'1M;"`N/2`G/&EN<'5T('1Y<&4](G-U
M8FUI="(@8VQA<W,](F)U='1O;B(@;F%M93TB:6UP;W)T(B!V86QU93TB)R`N
M(%\H(D%D9"!T;R!A9&1R97-S(&)O;VLZ(BD@+B`G(B`O/B<["B`@("`@("`@
M("`@("`@("`D:'1M;"`N/2`G/'-E;&5C="!N86UE/2)S;W5R8V4B/B<["B`@
M("`@("`@("`@("`@("!F;W)E86-H("@D<V]U<F-E<R!A<R`D:V5Y(#T^("1L
M86)E;"D@>PH@("`@("`@("`@("`@("`@("`@("1S96QE8W1E9"`]("@D:V5Y
M(#T]("1P<F5F<RT^9V5T5F%L=64H)V%D9%]S;W5R8V4G*2D@/R`G('-E;&5C
M=&5D/2)S96QE8W1E9"(G(#H@)R<["B`@("`@("`@("`@("`@("`@("`@)&AT
M;6P@+CT@)SQO<'1I;VX@=F%L=64](B<@+B!H=&UL<W!E8VEA;&-H87)S*"1K
M97DI("X@)R(G("X@)'-E;&5C=&5D("X@)SXG("X@:'1M;'-P96-I86QC:&%R
M<R@D;&%B96PI("X@)SPO;W!T:6]N/B<["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D:'1M;"`N/2`G
M/&EN<'5T('1Y<&4](G-U8FUI="(@8VQA<W,](F)U='1O;B(@;F%M93TB:6UP
M;W)T(B!V86QU93TB)R`N(%\H(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB*2`N
M("<B("\^)SL*("`@("`@("`@("`@("`@("1S;W5R8V4@/2!A<G)A>5]K97ES
M*"1S;W5R8V5S*3L*("`@("`@("`@("`@("`@("1H=&UL("X]("<\:6YP=70@
M='EP93TB:&ED9&5N(B!N86UE/2)S;W5R8V4B('9A;'5E/2(G("X@:'1M;'-P
M96-I86QC:&%R<R@D<V]U<F-E6S!=*2`N("<B("\^)SL*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@)&AT;6P@+CT@)SPO9F]R;3X\+W1D/CPO='(^/'1R
M/CQT9#XF;F)S<#L\+W1D/CPO='(^)SL*("`@("`@("!]"@H@("`@("`@("1I
M(#T@,#L*("`@("`@("!F;W)E86-H("@D:4-A;"T^9V5T0V]M<&]N96YT<R@I
M(&%S("1V8RD@>PH@("`@("`@("`@("!I9B`H)&D@/B`P*2!["B`@("`@("`@
M("`@("`@("`D:'1M;"`N/2`G/'1R/CQT9#XF;F)S<#L\+W1D/CPO='(^)SL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`K*R1I.PH*("`@("`@("`@("`@
M)&AT;6P@+CT@)SQT<CX\=&0@8V]L<W!A;CTB,B(@8VQA<W,](FAE861E<B(^
M)SL*("`@("`@("`@("`@)&9U;&QN86UE(#T@)'9C+3YG971!='1R:6)U=&5$
M969A=6QT*"=&3B<L(&9A;'-E*3L*("`@("`@("`@("`@:68@*"1F=6QL;F%M
M92`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1H=&UL("X]("1F=6QL
M;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D:'1M;"`N/2`G/"]T
M9#X\+W1R/B<["@H@("`@("`@("`@("`D;B`]("1V8RT^<')I;G1A8FQE3F%M
M92@I.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1N*2D@>PH@("`@("`@("`@
M("`@("`@)&AT;6P@+CT@)'1H:7,M/E]R;W<H7R@B3F%M92(I+"`D;BD["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1A;&EA<V5S(#T@)'9C+3YG971!
M='1R:6)U=&5686QU97,H)T%,24%3)RD["B`@("`@("`@("`@(&EF("@A:7-?
M82@D86QI87-E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@
M)&AT;6P@+CT@)'1H:7,M/E]R;W<H7R@B06QI87,B*2P@:6UP;&]D92@G/&)R
M("\^)RP@)&%L:6%S97,I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M8FER=&AD87ES(#T@)'9C+3YG971!='1R:6)U=&5686QU97,H)T)$05DG*3L*
M("`@("`@("`@("`@:68@*"%I<U]A*"1B:7)T:&1A>7,L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@("1H=&UL("X]("1T:&ES+3Y?<F]W*%\H
M(D)I<G1H9&%Y(BDL(&1A=&4H)UDM;2UD)RP@)&)I<G1H9&%Y<ULP72DI.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`D;&%B96QS(#T@)'9C+3YG971!
M;&Q!='1R:6)U=&5S*"=,04)%3"<I.PH@("`@("`@("`@("!F;W)E86-H("@D
M;&%B96QS(&%S("1L86)E;"D@>PH@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1L86)E;%LG<&%R86US)UU;)U194$4G72DI('L*("`@("`@("`@("`@("`@
M("`@("!F;W)E86-H("@D;&%B96Q;)W!A<F%M<R==6R=465!%)UT@87,@)'1Y
M<&4I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&QA8F5L6R=P87)A;7,G
M75M3=')I;F<Z.G5P<&5R*"1T>7!E*5T@/2!T<G5E.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D;&%B96Q;)W!A<F%M<R==6R=(3TU%)UTI*2!["B`@("`@("`@
M("`@("`@("`@("`@)&AT;6P@+CT@)'1H:7,M/E]R;W<H7R@B2&]M92!!9&1R
M97-S(BDL(&YL,F)R*"1L86)E;%LG=F%L=64G72DI.PH@("`@("`@("`@("`@
M("`@?2!E;'-E:68@*&ES<V5T*"1L86)E;%LG<&%R86US)UU;)U=/4DLG72DI
M('L*("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7W)O=RA?
M*")7;W)K($%D9')E<W,B*2P@;FPR8G(H)&QA8F5L6R=V86QU92==*2D["B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1H
M=&UL("X]("1T:&ES+3Y?<F]W*%\H(D%D9')E<W,B*2P@;FPR8G(H)&QA8F5L
M6R=V86QU92==*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("\O($9O<B!V0V%R9"`S+C`N"B`@("`@("`@("`@("1A
M9')S(#T@)'9C+3YG971!;&Q!='1R:6)U=&5S*"=!1%(G*3L*("`@("`@("`@
M("`@9F]R96%C:"`H)&%D<G,@87,@)&ET96TI('L*("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D:71E;5LG<&%R86US)UU;)U194$4G72DI('L*("`@("`@
M("`@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1I=&5M6R=P87)A;7,G75LG
M5%E012==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D:71E;5LG<&%R
M86US)UU;)U194$4G72`](&%R<F%Y*"1I=&5M6R=P87)A;7,G75LG5%E012==
M*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("1I=&5M6R=P87)A;7,G75LG5%E0
M12==(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)&ET96U;)W!A<F%M<R==6R=73U)+)UTI*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1I=&5M6R=P87)A;7,G75LG5%E012==6UT@/2`G5T]22R<["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D:71E;5LG<&%R86US)UU;)TA/344G72DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&ET96U;)W!A<F%M<R==6R=465!%)UU;72`]("=(3TU%
M)SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`D861D<F5S<R`]("1I=&5M6R=V86QU97,G73L*("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1I=&5M6R=P87)A;7,G75LG5%E012==
M(&%S("1A9'(I('L*("`@("`@("`@("`@("`@("`@("!I9B`H4W1R:6YG.CIU
M<'!E<B@D861R*2`]/2`G2$]-12<I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&$@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)&%D9')E<W-;5D-!4D1?04127U-44D5%5%TI*2`@('L@)&%;72`]
M("1A9&1R97-S6U9#05)$7T%$4E]35%)%151=.R!]"B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D861D<F5S<UM60T%21%]!1%)?3$]#04Q)
M5%E=*2D@>R`D85M=(#T@)&%D9')E<W-;5D-!4D1?04127TQ/0T%,251973L@
M?0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&%D9')E<W-;
M5D-!4D1?04127U)%1TE/3ETI*2`@('L@)&%;72`]("1A9&1R97-S6U9#05)$
M7T%$4E]214=)3TY=.R!]"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D861D<F5S<UM60T%21%]!1%)?4$]35$-/1$5=*2D@>R`D85M=(#T@
M)&%D9')E<W-;5D-!4D1?04127U!/4U1#3T1%73L@?0H@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&%D9')E<W-;5D-!4D1?04127T-/54Y4
M4EE=*2D@('L@)&%;72`]("1A9&1R97-S6U9#05)$7T%$4E]#3U5.5%)973L@
M?0H@("`@("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7W)O
M=RA?*")(;VUE($%D9')E<W,B*2P@;FPR8G(H:6UP;&]D92@B7&XB+"`D82DI
M*3L*"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*%-T<FEN9SHZ=7!P
M97(H)&%D<BD@/3T@)U=/4DLG*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1A(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1A9&1R97-S6U9#05)$7T%$4E]35%)%151=*2D@("![("1A6UT@/2`D
M861D<F5S<UM60T%21%]!1%)?4U12145473L@?0H@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&%D9')E<W-;5D-!4D1?04127TQ/0T%,2519
M72DI('L@)&%;72`]("1A9&1R97-S6U9#05)$7T%$4E],3T-!3$E465T[('T*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A9&1R97-S6U9#
M05)$7T%$4E]214=)3TY=*2D@("![("1A6UT@/2`D861D<F5S<UM60T%21%]!
M1%)?4D5'24].73L@?0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&%D9')E<W-;5D-!4D1?04127U!/4U1#3T1%72DI('L@)&%;72`]("1A
M9&1R97-S6U9#05)$7T%$4E]03U-40T]$15T[('T*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1A9&1R97-S6U9#05)$7T%$4E]#3U5.5%)9
M72DI("![("1A6UT@/2`D861D<F5S<UM60T%21%]!1%)?0T]53E1265T[('T*
M("`@("`@("`@("`@("`@("`@("`@("`@)&AT;6P@+CT@)'1H:7,M/E]R;W<H
M7R@B5V]R:R!!9&1R97-S(BDL(&YL,F)R*&EM<&QO9&4H(EQN(BP@)&$I*2D[
M"@H@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1A(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1A9&1R97-S6U9#05)$7T%$4E]35%)%151=*2D@("![
M("1A6UT@/2`D861D<F5S<UM60T%21%]!1%)?4U12145473L@?0H@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&%D9')E<W-;5D-!4D1?0412
M7TQ/0T%,251972DI('L@)&%;72`]("1A9&1R97-S6U9#05)$7T%$4E],3T-!
M3$E465T[('T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A
M9&1R97-S6U9#05)$7T%$4E]214=)3TY=*2D@("![("1A6UT@/2`D861D<F5S
M<UM60T%21%]!1%)?4D5'24].73L@?0H@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)&%D9')E<W-;5D-!4D1?04127U!/4U1#3T1%72DI('L@
M)&%;72`]("1A9&1R97-S6U9#05)$7T%$4E]03U-40T]$15T[('T*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A9&1R97-S6U9#05)$7T%$
M4E]#3U5.5%)972DI("![("1A6UT@/2`D861D<F5S<UM60T%21%]!1%)?0T]5
M3E1265T[('T*("`@("`@("`@("`@("`@("`@("`@("`@)&AT;6P@+CT@)'1H
M:7,M/E]R;W<H7R@B061D<F5S<R(I+"!N;#)B<BAI;7!L;V1E*")<;B(L("1A
M*2DI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&YU;6)E<G,@/2`D=F,M/F=E
M=$%L;$%T=')I8G5T97,H)U1%3"<I.PH*("`@("`@("`@("`@9F]R96%C:"`H
M)&YU;6)E<G,@87,@)&YU;6)E<BD@>PH@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1N=6UB97);)W!A<F%M<R==6R=465!%)UTI*2!["B`@("`@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)&YU;6)E<ELG<&%R86US)UU;)U194$4G72!A
M<R`D='EP92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;G5M8F5R6R=P
M87)A;7,G75M3=')I;F<Z.G5P<&5R*"1T>7!E*5T@/2!T<G5E.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D;G5M8F5R6R=P87)A;7,G75LG1D%8)UTI*2!["B`@
M("`@("`@("`@("`@("`@("`@)&AT;6P@+CT@)'1H:7,M/E]R;W<H7R@B1F%X
M(BDL("1N=6UB97);)W9A;'5E)UTI.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&YU;6)E<ELG<&%R
M86US)UU;)TA/344G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&AT
M;6P@+CT@)'1H:7,M/E]R;W<H7R@B2&]M92!0:&]N92(I+"`D;G5M8F5R6R=V
M86QU92==*3L*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H:7-S970H
M)&YU;6)E<ELG<&%R86US)UU;)U=/4DLG72DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&AT;6P@+CT@)'1H:7,M/E]R;W<H7R@B5V]R:R!0:&]N92(I
M+"`D;G5M8F5R6R=V86QU92==*3L*("`@("`@("`@("`@("`@("`@("!](&5L
M<V5I9B`H:7-S970H)&YU;6)E<ELG<&%R86US)UU;)T-%3$PG72DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&AT;6P@+CT@)'1H:7,M/E]R;W<H7R@B
M0V5L;"!0:&]N92(I+"`D;G5M8F5R6R=V86QU92==*3L*("`@("`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D:'1M
M;"`N/2`D=&AI<RT^7W)O=RA?*")0:&]N92(I+"`D;G5M8F5R6R=V86QU92==
M*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1A9&1R97-S97,@/2`D=F,M/F=E
M=$%L;$%T=')I8G5T97,H)T5-04E,)RD["B`@("`@("`@("`@("1E;6%I;',@
M/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W)E86-H("@D861D<F5S<V5S(&%S
M("1A9&1R97-S*2!["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&%D9')E
M<W-;)W!A<F%M<R==6R=465!%)UTI*2!["B`@("`@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)&%D9')E<W-;)W!A<F%M<R==6R=465!%)UT@87,@)'1Y<&4I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)&%D9')E<W-;)W!A<F%M<R==
M6U-T<FEN9SHZ=7!P97(H)'1Y<&4I72`]('1R=64["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&5M
M86EL(#T@)SQA(&AR968](B<["B`@("`@("`@("`@("`@("!I9B`H)')E9VES
M=')Y+3YH87--971H;V0H)VUA:6PO8V]M<&]S92<I*2!["B`@("`@("`@("`@
M("`@("`@("`@)&5M86EL("X]("1R96=I<W1R>2T^8V%L;"@G;6%I;"]C;VUP
M;W-E)RP@87)R87DH87)R87DH)W1O)R`]/B`D861D<F5S<ULG=F%L=64G72DI
M*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@)&5M86EL("X]("=M86EL=&\Z)R`N("1A9&1R97-S6R=V86QU92==.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&5M86EL("X]("<B
M/B<@+B`D861D<F5S<ULG=F%L=64G72`N("<\+V$^)SL*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D861D<F5S<ULG<&%R86US)UU;)U!2148G72DI('L*
M("`@("`@("`@("`@("`@("`@("!A<G)A>5]U;G-H:69T*"1E;6%I;',L("1E
M;6%I;"D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("1E;6%I;'-;72`]("1E;6%I;#L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*&-O=6YT*"1E;6%I;',I
M*2!["B`@("`@("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7W)O=RA?*")%
M;6%I;"(I+"!I;7!L;V1E*"<\8G(@+SXG+"`D96UA:6QS*2D["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("1T:71L92`]("1V8RT^9V5T071T<FEB=71E
M5F%L=65S*"=4251,12<I.PH@("`@("`@("`@("!I9B`H(6ES7V$H)'1I=&QE
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D:'1M;"`N/2`D
M=&AI<RT^7W)O=RA?*")4:71L92(I+"`D=&ET;&5;,%TI.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`D<F]L92`]("1V8RT^9V5T071T<FEB=71E5F%L
M=65S*"=23TQ%)RD["B`@("`@("`@("`@(&EF("@A:7-?82@D<F]L92P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@)'1H:7,M
M/E]R;W<H7R@B4F]L92(I+"`D<F]L95LP72D["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("1O<F<@/2`D=F,M/F=E=$%T=')I8G5T959A;'5E<R@G3U)'
M)RD["B`@("`@("`@("`@(&EF("@A:7-?82@D;W)G+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7W)O=RA?*")#
M;VUP86YY(BDL("1O<F=;,%TI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`D;F]T97,@/2`D=F,M/F=E=$%T=')I8G5T959A;'5E<R@G3D]412<I.PH@
M("`@("`@("`@("!I9B`H(6ES7V$H)&YO=&5S+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7W)O=RA?*").;W1E
M<R(I+"!N;#)B<B@D;F]T97-;,%TI*3L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)'5R;"`]("1V8RT^9V5T071T<FEB=71E5F%L=65S*"=54DPG*3L*
M("`@("`@("`@("`@:68@*"%I<U]A*"1U<FPL("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@("`@("1H=&UL("X]("1T:&ES+3Y?<F]W*%\H(E523"(I
M+"`G/&$@:')E9CTB)R`N("1U<FQ;,%TN("<B('1A<F=E=#TB7V)L86YK(CXG
M("X@)'5R;%LP72`N("<\+V$^)RD["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("1H=&UL("X]("<\+W1A8FQE/B<["B`@("`@("`@)&AT;6P@
M+CT@571I;#HZ8G5F9F5R3W5T<'5T*"=I;F-L=61E)RP@)')E9VES=')Y+3YG
M970H)W1E;7!L871E<R<L("=H;W)D92<I("X@)R]C;VUM;VXM9F]O=&5R+FEN
M8R<I.PH*("`@("`@("!R971U<FX@)&AT;6P["B`@("!]"@H@("`@9G5N8W1I
M;VX@7W)O=R@D;&%B96PL("1V86QU92D*("`@('L*("`@("`@("!R971U<FX@
M)SQT<CX\=&0@8VQA<W,](FET96TB('9A;&EG;CTB=&]P(CXG("X@)&QA8F5L
M("X@)SPO=&0^/'1D(&-L87-S/2)I=&5M(B!V86QI9VX](G1O<"(^)R`N("1V
M86QU92`N("(\+W1D/CPO='(^7&XB.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N('1H92!-24U%(&-O;G1E;G0@='EP92!O9B!T:&4@<F5N9&5R960@
M8V]N=&5N="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O
M;G1E;G0@='EP92!O9B!T:&4@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G9714>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)W1E>'0O:'1M;#L@
M8VAA<G-E=#TG("X@3DQ3.CIG971#:&%R<V5T*"D["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]R<&TN<&AP````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,S0T-2`Q,#4Q-30S,S<S-B`P,C(V-38`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J(%1H92!-24U%7U9I97=E<E]R<&T@8VQA<W,@<F5N9&5R<R!O
M=70@;&ES=',@;V8@9FEL97,@:6X@4E!-"B`J('!A8VMA9V5S(&)Y('5S:6YG
M('1H92!R<&T@=&]O;"!T;R!Q=65R>2!T:&4@<&%C:V%G92X*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R<&TN<&AP+'8@,2XQ
M,BXQ,"XW(#(P,#8O,#$O,#$@,C$Z,C@Z,C4@:F%N($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`Q.3DY+3(P,#8@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C
M;VEL+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($%N:6P@36%D
M:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J($!S:6YC92`@($AO<F1E
M(#$N,PH@*B!`<&%C:V%G92!(;W)D95]-24U%7U9I97=E<@H@*B\*8VQA<W,@
M34E-15]6:65W97)?<G!M(&5X=&5N9',@34E-15]6:65W97(@>PH*("`@("\J
M*@H@("`@("H@4F5N9&5R(&]U="!T:&4@4E!-(&-O;G1E;G1S+@H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!;GD@<&%R86UE=&5R<R!T
M:&4@5FEE=V5R(&UA>2!N965D+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@<F5N9&5R960@8V]N=&5N=',N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(')E;F1E<B@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!G
M;&]B86P@)&UI;65?9')I=F5R<SL*"B`@("`@("`@+RH@0VAE8VL@=&\@;6%K
M92!S=7)E('1H92!P<F]G<F%M(&%C='5A;&QY(&5X:7-T<RX@*B\*("`@("`@
M("!I9B`H(69I;&5?97AI<W1S*"1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W)P
M;2==6R=L;V-A=&EO;B==*2D@>PH@("`@("`@("`@("!R971U<FX@)SQP<F4^
M)R`N('-P<FEN=&8H7R@B5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@
M9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(I
M+"`D;6EM95]D<FEV97)S6R=H;W)D92==6R=R<&TG75LG;&]C871I;VXG72D@
M+B`G/"]P<F4^)SL*("`@("`@("!]"@H@("`@("`@("1D871A(#T@)R<["B`@
M("`@("`@)'1M<%]R<&T@/2!(;W)D93HZ9V5T5&5M<$9I;&4H)VAO<F1E7W)P
M;2<I.PH*("`@("`@("`D9F@@/2!F;W!E;B@D=&UP7W)P;2P@)W<G*3L*("`@
M("`@("!F=W)I=&4H)&9H+"`D=&AI<RT^;6EM95]P87)T+3YG971#;VYT96YT
M<R@I*3L*("`@("`@("!F8VQO<V4H)&9H*3L*"B`@("`@("`@)&9H(#T@<&]P
M96XH)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<G!M)UU;)VQO8V%T:6]N)UT@
M+B`B("UQ:7`@)'1M<%]R<&T@,CXF,2(L("=R)RD["B`@("`@("`@=VAI;&4@
M*"@D<F,@/2!F9V5T<R@D9F@L(#@Q.3(I*2D@>PH@("`@("`@("`@("`D9&%T
M82`N/2`D<F,["B`@("`@("`@?0H@("`@("`@('!C;&]S92@D9F@I.PH*("`@
M("`@("!R971U<FX@)SQP<F4^)R`N(&AT;6QE;G1I=&EE<R@D9&%T82D@+B`G
M/"]P<F4^)SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@34E-
M12!C;VYT96YT('1Y<&4@;V8@=&AE(')E;F1E<F5D(&-O;G1E;G0N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C;VYT96YT('1Y<&4@;V8@
M=&AE(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@
M("!["B`@("`@("`@<F5T=7)N("=T97AT+VAT;6P[(&-H87)S970])R`N($Y,
M4SHZ9V5T0VAA<G-E="@I.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O34E-12]6:65W97(O<F5P;W)T+G!H<```````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#4P-S8@,3`U,34T,S,W,S8@,#(S,S<U`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B!4:&4@34E-15]6:65W97)?<F5P;W)T(&-L87-S(&ES(&$@=W)A<'!E
M<B!U<V5D('1O(&QO860@=&AE(&%P<')O<')I871E"B`J($U)345?5FEE=V5R
M(&9O<B!M=6QT:7!A<G0O<F5P;W)T(&1A=&$@*%)&0R`S-#8R*2X*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R97!O<G0N<&AP
M+'8@,2XV+C$P+C8@,C`P-B\P,2\P,2`R,3HR.#HR-2!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A
M<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,
M*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`
M875T:&]R("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO
M<F%D;RYE9'4^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(
M;W)D95]-24U%7U9I97=E<@H@*B\*8VQA<W,@34E-15]6:65W97)?<F5P;W)T
M(&5X=&5N9',@34E-15]6:65W97(@>PH*("`@("\J*@H@("`@("H@4W1O<F5S
M('1H92!-24U%7U9I97=E<B!O9B!T:&4@<W!E8VEF:65D('!R;W1O8V]L+@H@
M("`@("H*("`@("`J($!V87(@34E-15]6:65W97(*("`@("`J+PH@("`@=F%R
M("1?=FEE=V5R.PH*("`@("\J*@H@("`@("H@4F5N9&5R('1H92!M=6QT:7!A
M<G0O<F5P;W)T(&1A=&$N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P
M87)A;7,@($%N(&%R<F%Y(&]F('!A<F%M971E<G,@;F5E9&5D+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F5N9&5R960@9&%T82X*("`@
M("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R*"1P87)A;7,@/2!A<G)A>2@I*0H@
M("`@>PH@("`@("`@("\J($=E="!T:&4@87!P<F]P<FEA=&4@34E-15]6:65W
M97(@9F]R('1H92!P<F]T;V-O;"!S<&5C:69I960N("HO"B`@("`@("`@:68@
M*"$H)'1H:7,M/E]R97-O;'9E5FEE=V5R*"DI*2!["B`@("`@("`@("`@(')E
M='5R;CL*("`@("`@("!]"@H@("`@("`@("\J(%)E;F1E<B!U<VEN9R!T:&4@
M;&]A9&5D($U)345?5FEE=V5R(&]B:F5C="X@*B\*("`@("`@("!R971U<FX@
M)'1H:7,M/E]V:65W97(M/G)E;F1E<B@D<&%R86US*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE(&-O;G1E;G0M='EP92!O9B!T:&4@5FEE
M=V5R('5S960@=&\@=FEE=R!T:&4@<&%R="X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@02!C;VYT96YT+71Y<&4@<W1R:6YG+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@("`O*B!'970@=&AE
M(&%P<')O<')I871E($U)345?5FEE=V5R(&9O<B!T:&4@<')O=&]C;VP@<W!E
M8VEF:65D+B`J+PH@("`@("`@(&EF("@A*"1T:&ES+3Y?<F5S;VQV959I97=E
M<B@I*2D@>PH@("`@("`@("`@("!R971U<FX@)V%P<&QI8V%T:6]N+V]C=&5T
M+7-T<F5A;2<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?=FEE=V5R+3YG9714>7!E*"D["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@3&]A9"!A($U)345?5FEE=V5R(&%C8V]R9&EN9R!T
M;R!T:&4@<F5P;W)T+71Y<&4@<&%R86UE=&5R('-T;W)E9`H@("`@("H@:6X@
M=&AE($U)345?4&%R="!T;R!R96YD97(N($EF('5N<W5C8V5S<V9U;"P@=')Y
M('1O(&QO860@82!G96YE<FEC"B`@("`@*B!M=6QT:7!A<G0@34E-15]6:65W
M97(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]R97-O;'9E5FEE=V5R
M*"D*("`@('L*("`@("`@("`D=FEE=V5R(#T@;G5L;#L*"B`@("`@("`@:68@
M*&5M<'1Y*"1T:&ES+3Y?=FEE=V5R*2D@>PH@("`@("`@("`@("!I9B`H(2@D
M='EP92`]("1T:&ES+3YM:6UE7W!A<G0M/F=E=$-O;G1E;G14>7!E4&%R86UE
M=&5R*"=R97!O<G0M='EP92<I*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=FEE=V5R(#T@
M)DU)345?5FEE=V5R.CIF86-T;W)Y*"1T:&ES+3YM:6UE7W!A<G0L("=M97-S
M86=E+R<@+B!3=')I;F<Z.FQO=V5R*"1T>7!E*2D["B`@("`@("`@("`@(&EF
M("AE;7!T>2@D=FEE=V5R*2!\?`H@("`@("`@("`@("`@("`@*%-T<FEN9SHZ
M;&]W97(H9V5T7V-L87-S*"1V:65W97(I*2`]/2`G;6EM95]V:65W97)?9&5F
M875L="<I*2!["B`@("`@("`@("`@("`@("!I9B`H(2@D=FEE=V5R(#T@)DU)
M345?5FEE=V5R.CIF86-T;W)Y*"1T:&ES+3YM:6UE7W!A<G0L("1T:&ES+3YM
M:6UE7W!A<G0M/F=E=%!R:6UA<GE4>7!E*"D@+B`G+RHG*2DI('L*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]V:65W97(@/2`D
M=FEE=V5R.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I
M97=E<B]W96)C<'`N<&AP````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M-C,S-"`Q,#4Q-30S,S<S-B`P,C,S-#``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!-24U%7U9I
M97=E<E]W96)C<'`@8VQA<W,@<F5N9&5R<R!O=70@=F%R:6]U<R!C;VYT96YT
M"B`J(&EN($A434P@9F]R;6%T(&)Y('5S:6YG(%=E8B!#(%!L=7,@4&QU<RX*
M("H*("H@5V5B($,@4&QU<R!P;'5S.B!H='1P.B\O=V5B8W!P+G-O=7)C969O
M<F=E+FYE="\*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]W96)C<'`N<&AP+'8@,2XQ,2XQ,"XX(#(P,#8O,#$O,#$@,C$Z,C@Z
M,C4@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EK92!#
M;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA
M;&PN8V\N;GH^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(
M;W)D95]-24U%7U9I97=E<@H@*B\*8VQA<W,@34E-15]6:65W97)?=V5B8W!P
M(&5X=&5N9',@34E-15]6:65W97(@>PH*("`@("\J*@H@("`@("H@4F5N9&5R
M(&]U="!T:&4@8W5R<F5N=&QY('-E="!C;VYT96YT<R!U<VEN9R!796(@0R!0
M;'5S(%!L=7,N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@
M($%N>2!P87)A;65T97)S('1H92!6:65W97(@;6%Y(&YE960N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!R96YD97)E9"!C;VYT96YT<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R*"1P87)A;7,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@(&=L;V)A;"`D;6EM95]D<FEV97)S.PH*("`@("`@
M("!R97%U:7)E7V]N8V4@)TAO<F1E+TU)344O0V]N=&5N=',N<&AP)SL*("`@
M("`@("`D871T86-H;65N="`]($U)345?0V]N=&5N=',Z.G9I97=!<T%T=&%C
M:&UE;G0H*3L*"B`@("`@("`@+RH@0VAE8VL@=&\@;6%K92!S=7)E('1H92!P
M<F]G<F%M(&%C='5A;&QY(&5X:7-T<RX@*B\*("`@("`@("!I9B`H(69I;&5?
M97AI<W1S*"1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W=E8F-P<"==6R=L;V-A
M=&EO;B==*2D@>PH@("`@("`@("`@("!R971U<FX@)SQP<F4^)R`N('-P<FEN
M=&8H7R@B5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E
M("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(I+"`D;6EM95]D
M<FEV97)S6R=H;W)D92==6R=W96)C<'`G75LG;&]C871I;VXG72D@+B`G/"]P
M<F4^)SL*("`@("`@("!]"@H@("`@("`@("\J($-R96%T92!T96UP;W)A<GD@
M9FEL97,@9F]R(%=E8F-P<"X@*B\*("`@("`@("`D=&UP:6X@(#T@2&]R9&4Z
M.F=E=%1E;7!&:6QE*"=796)C<'!);B<I.PH@("`@("`@("1T;7!O=70@/2!(
M;W)D93HZ9V5T5&5M<$9I;&4H)U=E8F-P<$]U="<I.PH*("`@("`@("`O*B!7
M<FET92!T:&4@8V]N=&5N=',@;V8@;W5R(&)U9F9E<B!T;R!T:&4@=&5M<&]R
M87)Y(&EN<'5T(&9I;&4N("HO"B`@("`@("`@)&-O;G1E;G1S(#T@)'1H:7,M
M/FUI;65?<&%R="T^9V5T0V]N=&5N=',H*3L*("`@("`@("`D9F@@/2!F;W!E
M;B@D=&UP:6XL("=W8B<I.PH@("`@("`@(&9W<FET92@D9F@L("1C;VYT96YT
M<RP@<W1R;&5N*"1C;VYT96YT<RDI.PH@("`@("`@(&9C;&]S92@D9F@I.PH*
M("`@("`@("`O*B!'970@=&AE(&5X=&5N<VEO;B!F;W(@=&AE(&UI;64@='EP
M92X@*B\*("`@("`@("!I;F-L=61E7V]N8V4@)TAO<F1E+TU)344O36%G:6,N
M<&AP)SL*("`@("`@("`D97AT(#T@34E-15]-86=I8SHZ34E-151O17AT*"1T
M:&ES+3YM:6UE7W!A<G0M/F=E=%1Y<&4H*2D["@H@("`@("`@("\J($5X96-U
M=&4@5V5B($,@4&QU<R!0;'5S+B!3<&5C:69Y:6YG('1H92!I;B!A;F0@;W5T
M(&9I;&5S(&1I9&XG=`H@("`@("`@("`@('=O<FL@9F]R(&UE(&)U="!P:7!E
M<R!D:60N("HO"B`@("`@("`@97AE8R@D;6EM95]D<FEV97)S6R=H;W)D92==
M6R=W96)C<'`G75LG;&]C871I;VXG72`N("(@+2UP:7!E("TM<&EP92`M>#TD
M97AT("UL("UA("UT(#P@)'1M<&EN(#X@)'1M<&]U="(I.PH@("`@("`@("1R
M97-U;'1S(#T@9FEL95]G971?8V]N=&5N=',H)'1M<&]U="D["@H@("`@("`@
M("\J($EF('=E(&%R92!N;W0@9&ES<&QA>6EN9R!I;FQI;F4L(&%L;"!T:&4@
M9F]R;6%T=&EN9R!I<R!A;')E861Y"B`@("`@("`@("H@9&]N92!F;W(@=7,N
M("HO"B`@("`@("`@:68@*"1A='1A8VAM96YT*2!["B`@("`@("`@("`@("\J
M(%1H92!F:7)S="`R(&QI;F5S(&%R92!T:&4@0V]N=&5N="U4>7!E(&QI;F4@
M86YD(&$@8FQA;FL@;&EN90H@("`@("`@("`@("`@*B!S;R!W92!S:&]U;&0@
M<F5M;W9E('1H96T@8F5F;W)E(&]U='!U='1I;F<N("HO"B`@("`@("`@("`@
M(')E='5R;B!P<F5G7W)E<&QA8V4H(B\N*EQN+BI<;B\B+"`G)RP@)')E<W5L
M=',L(#$I.PH@("`@("`@('T*"B`@("`@("`@+RH@17AT<F%C="!T:&4@<W1Y
M;&4@<VAE970L(')E;6]V:6YG(&%N>2!G;&]B86P@8F]D>2!F;W)M871T:6YG
M"B`@("`@("`@("H@:68@=V4G<F4@9&ES<&QA>6EN9R!I;FQI;F4N("HO"B`@
M("`@("`@)')E<R`]('!R96=?<W!L:70H)SLH/"]S='EL93XI?"@\<W1Y;&4@
M='EP93TB=&5X="]C<W,B/BD[)RP@)')E<W5L=',I.PH@("`@("`@("1S='EL
M92`]("1R97-;,5T["B`@("`@("`@)'-T>6QE(#T@<')E9U]R97!L86-E*"<O
M7&YB;V1Y7',K/WLN*C]]+W,G+"`G)RP@)'-T>6QE*3L*"B`@("`@("`@+RH@
M17AT<F%C="!T:&4@8V]N=&5N="X@*B\*("`@("`@("`D<F5S(#T@<')E9U]S
M<&QI="@G+UP\7"\_<')E7#XO)RP@)')E<W5L=',I.PH@("`@("`@("1B;V1Y
M(#T@)')E<ULQ73L*"B`@("`@("`@<F5T=7)N("<\<W1Y;&4^)R`N("1S='EL
M92`N("<\+W-T>6QE/CQD:78@8VQA<W,](G=E8F-P<"(@<W1Y;&4](G=H:71E
M+7-P86-E.G!R93MF;VYT+69A;6EL>3IM;VYO<W!A8V4B/B<@+B`D8F]D>2`N
M("<\+V1I=CXG.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!-
M24U%(&-O;G1E;G0@='EP92!O9B!T:&4@<F5N9&5R960@8V]N=&5N="X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O;G1E;G0@='EP92!O
M9B!T:&4@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714>7!E*"D*
M("`@('L*("`@("`@("!R971U<FX@)W1E>'0O:'1M;#L@8VAA<G-E=#TG("X@
M3DQ3.CIG971#:&%R<V5T*"D["B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6
M:65W97(O>FEP+G!H<```````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,3`V-C<@,3`U,34T,S,W,S8@,#(R-C8V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@34E-15]6
M:65W97)?>FEP(&-L87-S(')E;F1E<G,@;W5T('1H92!C;VYT96YT<R!O9B!:
M25`@9FEL97,@:6X@2%1-3`H@*B!F;W)M870N"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<"QV(#$N,S`N,3`N,3`@
M,C`P-B\P,B\Q,"`Q,SHU-#HP-"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#`M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*
M("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L($-O8VAR86YE(#QM:6ME
M0&=R869T;VYH86QL+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!A=71H
M;W(@($UI8VAA96P@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^
M"B`J($!S:6YC92`@($AO<F1E(#(N,`H@*B!`<&%C:V%G92!(;W)D95]-24U%
M7U9I97=E<@H@*B\*8VQA<W,@34E-15]6:65W97)?>FEP(&5X=&5N9',@34E-
M15]6:65W97(@>PH*("`@("\J*@H@("`@("H@4F5N9&5R(&]U="!T:&4@8W5R
M<F5N="!Z:7`@8V]N=&5N=',N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;7,@($%N>2!P87)A;65T97)S('1H92!6:65W97(@;6%Y(&YE960N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!R96YD97)E9"!C
M;VYT96YT<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R*"1P87)A;7,@
M/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W)E;F1E
M<B@D=&AI<RT^;6EM95]P87)T+3YG971#;VYT96YT<R@I*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($]U='!U="!T:&4@9FEL92!L:7-T+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&-O;G1E;G1S("!4:&4@8V]N=&5N=',@;V8@=&AE('II<"!A<F-H:79E
M+@H@("`@("H@0'!A<F%M(&UI>&5D("1C86QL8F%C:R`@(%1H92!C86QL8F%C
M:R!F=6YC=&EO;B!T;R!U<V4@;VX@=&AE('II<&9I;&4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("!I;F9O<FUA=&EO;BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE(&9I;&4@;&ES="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@7W)E;F1E<B@D8V]N=&5N=',L("1C86QL8F%C:R`](&YU;&PI
M"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]#;VUP<F5S<RYP
M:'`G.PH*("`@("`@("`D>FEP(#T@)DAO<F1E7T-O;7!R97-S.CIS:6YG;&5T
M;VXH)WII<"<I.PH*("`@("`@("`O*B!-86ME('-U<F4@=&AI<R!I<R!A('9A
M;&ED('II<"!F:6QE+B`J+PH@("`@("`@(&EF("@D>FEP+3YC:&5C:UII<$1A
M=&$H)&-O;G1E;G1S*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T=7)N
M("<\<')E/B<@+B!?*")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A
M;&ED('II<"!F:6QE+B(I("X@)SPO<')E/B<["B`@("`@("`@?0H*("`@("`@
M("`D>FEP26YF;R`]("1Z:7`M/F1E8V]M<')E<W,H)&-O;G1E;G1S+"!A<G)A
M>2@G86-T:6]N)R`]/B!(3U)$15]#3TU04D534U]:25!?3$E35"DI.PH@("`@
M("`@(&EF("AI<U]A*"1Z:7!);F9O+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D>FEP26YF;RT^9V5T365S<V%G92@I.PH@("`@("`@
M('T*("`@("`@("`D9FEL94-O=6YT(#T@8V]U;G0H)'II<$EN9F\I.PH*("`@
M("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U1E>'0N<&AP)SL*"B`@("`@("`@
M)'1E>'0@/2`G/'-T<F]N9SXG("X@:'1M;'-P96-I86QC:&%R<RAS<')I;G1F
M*%\H(D-O;G1E;G1S(&]F(%PB)7-<(B(I+"`D=&AI<RT^;6EM95]P87)T+3YG
M971.86UE*"DI*2`N("<Z/"]S=')O;F<^)R`N(")<;B(["B`@("`@("`@)'1E
M>'0@+CT@)SQT86)L93X\='(^/'1D(&%L:6=N/2)L969T(CX\='0^/'-P86X@
M8VQA<W,](F9I>&5D(CXG.PH@("`@("`@("1T97AT("X](%1E>'0Z.FAT;6Q!
M;&Q3<&%C97,H7R@B07)C:&EV92!.86UE(BD@+B`G.B`G("X@)'1H:7,M/FUI
M;65?<&%R="T^9V5T3F%M92@I*2`N(")<;B(["B`@("`@("`@)'1E>'0@+CT@
M5&5X=#HZ:'1M;$%L;%-P86-E<RA?*")!<F-H:79E($9I;&4@4VEZ92(I("X@
M)SH@)R`N('-T<FQE;B@D8V]N=&5N=',I("X@)R!B>71E<R<I("X@(EQN(CL*
M("`@("`@("`D=&5X="`N/2!497AT.CIH=&UL06QL4W!A8V5S*"@D9FEL94-O
M=6YT("$](#$I(#\@<W!R:6YT9BA?*")&:6QE($-O=6YT.B`E<R!F:6QE<R(I
M+"`D9FEL94-O=6YT*2`Z('-P<FEN=&8H7R@B1FEL92!#;W5N=#H@)7,@9FEL
M92(I+"`D9FEL94-O=6YT*2D["B`@("`@("`@)'1E>'0@+CT@(EQN7&XB.PH@
M("`@("`@("1T97AT("X](%1E>'0Z.FAT;6Q!;&Q3<&%C97,H"B`@("`@("`@
M("`@("`@("`@("`@('-T<E]P860H7R@B1FEL92!.86UE(BDL("`@("`@-3`L
M("<@)RP@4U127U!!1%]224=(5"D@+@H@("`@("`@("`@("`@("`@("`@("!S
M=')?<&%D*%\H(D%T=')I8G5T97,B*2P@("`@(#$P+"`G("<L(%-44E]0041?
M3$5&5"D@+@H@("`@("`@("`@("`@("`@("`@("!S=')?<&%D*%\H(E-I>F4B
M*2P@("`@("`@("`@(#$P+"`G("<L(%-44E]0041?3$5&5"D@+@H@("`@("`@
M("`@("`@("`@("`@("!S=')?<&%D*%\H(DUO9&EF:65D($1A=&4B*2P@(#$Y
M+"`G("<L(%-44E]0041?3$5&5"D@+@H@("`@("`@("`@("`@("`@("`@("!S
M=')?<&%D*%\H(DUE=&AO9"(I+"`@("`@("`@(#$P+"`G("<L(%-44E]0041?
M3$5&5"D@+@H@("`@("`@("`@("`@("`@("`@("!S=')?<&%D*%\H(D-20R(I
M+"`@("`@("`@("`@(#$P+"`G("<L(%-44E]0041?3$5&5"D@+@H@("`@("`@
M("`@("`@("`@("`@("!S=')?<&%D*%\H(E)A=&EO(BDL("`@("`@("`@("`W
M+"`G("<L(%-44E]0041?3$5&5"D*("`@("`@("`@("`@("`@("`I("X@(EQN
M(CL*"B`@("`@("`@)'1E>'0@+CT@<W1R7W)E<&5A="@G+2<L(#$Q-BD@+B`B
M7&XB.PH*("`@("`@("!F;W)E86-H("@D>FEP26YF;R!A<R`D:V5Y(#T^("1V
M86PI('L*("`@("`@("`@("`@)')A=&EO(#T@*&5M<'1Y*"1V86Q;)W-I>F4G
M72DI(#\@,"`Z(#$P,"`J("@D=F%L6R=C<VEZ92==("\@)'9A;%LG<VEZ92==
M*3L*"B`@("`@("`@("`@("1V86Q;)VYA;64G72`]('-T<E]P860H)'9A;%LG
M;F%M92==+"`U,"P@)R`G+"!35%)?4$%$7U))1TA4*3L*("`@("`@("`@("`@
M)'9A;%LG871T<B==(#T@<W1R7W!A9"@D=F%L6R=A='1R)UTL(#$P+"`G("<L
M(%-44E]0041?3$5&5"D["B`@("`@("`@("`@("1V86Q;)W-I>F4G72`]('-T
M<E]P860H)'9A;%LG<VEZ92==+"`Q,"P@)R`G+"!35%)?4$%$7TQ%1E0I.PH@
M("`@("`@("`@("`D=F%L6R=D871E)UT@/2!S=')?<&%D*'-T<F9T:6UE*"(E
M9"TE8BTE62`E2#HE32(L("1V86Q;)V1A=&4G72DL(#$Y+"`G("<L(%-44E]0
M041?3$5&5"D["B`@("`@("`@("`@("1V86Q;)VUE=&AO9"==(#T@<W1R7W!A
M9"@D=F%L6R=M971H;V0G72P@,3`L("<@)RP@4U127U!!1%],1494*3L*("`@
M("`@("`@("`@)'9A;%LG8W)C)UT@/2!S=')?<&%D*"1V86Q;)V-R8R==+"`Q
M,"P@)R`G+"!35%)?4$%$7TQ%1E0I.PH@("`@("`@("`@("`D=F%L6R=R871I
M;R==(#T@<W1R7W!A9"AS<')I;G1F*"(E,2XQ9B4E(BP@)')A=&EO*2P@-RP@
M)R`G+"!35%)?4$%$7TQ%1E0I.PH*("`@("`@("`@("`@)'9A;"`](&%R<F%Y
M7VUA<"AA<G)A>2@G5&5X="<L("=H=&UL06QL4W!A8V5S)RDL("1V86PI.PH*
M("`@("`@("`@("`@:68@*"%I<U]N=6QL*"1C86QL8F%C:RDI('L*("`@("`@
M("`@("`@("`@("1V86P@/2!C86QL7W5S97)?9G5N8R@D8V%L;&)A8VLL("1K
M97DL("1V86PI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&5X="`N
M/2`D=F%L6R=N86UE)UT@+B`D=F%L6R=A='1R)UT@+B`D=F%L6R=S:7IE)UT@
M+@H@("`@("`@("`@("`@("`@("`@("`D=F%L6R=D871E)UT@+B`D=F%L6R=M
M971H;V0G72`N("1V86Q;)V-R8R==("X*("`@("`@("`@("`@("`@("`@("`@
M)'9A;%LG<F%T:6\G72`N(")<;B(["B`@("`@("`@?0H*("`@("`@("`D=&5X
M="`N/2!S=')?<F5P96%T*"<M)RP@,3$V*2`N(")<;B(["B`@("`@("`@)'1E
M>'0@+CT@)SPO<W!A;CX\+W1T/CPO=&0^/"]T<CX\+W1A8FQE/B<["@H@("`@
M("`@(')E='5R;B!N;#)B<B@D=&5X="D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FX@=&AE(&-O;G1E;G0M='EP90H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@8V]N=&5N="UT>7!E(&]F('1H92!O=71P=70N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@("`@("`@(')E
M='5R;B`G=&5X="]H=&UL.R!C:&%R<V5T/2<@+B!.3%,Z.F=E=$-H87)S970H
M*3L*("`@('T*"GT*````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]T9WHN
M<&AP````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,#0U-B`Q,#4Q
M-30S,S<S-B`P,C(V-C0`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J(%1H92!-24U%7U9I97=E<E]T9WH@
M8VQA<W,@<F5N9&5R<R!O=70@<&QA:6X@;W(@9WII<'!E9"!T87)B86QL<R!I
M;B!(5$U,+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`L=B`Q+C,W+C$P+C$S(#(P,#8O,#$O,C8@,3`Z,C(Z-#8@
M:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@06YI;"!-861H
M879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H@0V]P>7)I9VAT(#(P,#(M
M,C`P-B!-:6-H865L($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D
M9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H@0&%U=&AO<B`@36EC:&%E;"!#;V-H
M<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@2&]R
M9&4@,2XS"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S
M<R!-24U%7U9I97=E<E]T9WH@97AT96YD<R!-24U%7U9I97=E<B!["@H@("`@
M+RHJ"B`@("`@*B!296YD97(@;W5T('1H92!C=7)R96YT;'D@<V5T('1A<B!F
M:6QE(&-O;G1E;G1S+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R
M86US("!!;GD@<&%R86UE=&5R<R!T:&4@5FEE=V5R(&UA>2!N965D+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F5N9&5R960@8V]N=&5N
M=',N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<B@D<&%R86US(#T@87)R
M87DH*2D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T-O;7!R
M97-S+G!H<"<["@H@("`@("`@("1C;VYT96YT<R`]("1T:&ES+3YM:6UE7W!A
M<G0M/F=E=$-O;G1E;G1S*"D["@H@("`@("`@("\J($]N;'D@9&5C;VUP<F5S
M<R!G>FEP<&5D(&9I;&5S+B`J+PH@("`@("`@("1S=6)T>7!E(#T@)'1H:7,M
M/FUI;65?<&%R="T^9V5T4W5B5'EP92@I.PH@("`@("`@(&EF("@H)'-U8G1Y
M<&4@/3T@)W@M8V]M<')E<W-E9"UT87(G*2!\?`H@("`@("`@("`@("`H)'-U
M8G1Y<&4@/3T@)W1G>B<I('Q\"B`@("`@("`@("`@("@D<W5B='EP92`]/2`G
M>"UT9WHG*2!\?`H@("`@("`@("`@("`H)'-U8G1Y<&4@/3T@)V=Z:7`G*2!\
M?`H@("`@("`@("`@("`H)'-U8G1Y<&4@/3T@)W@M9WII<"<I('Q\"B`@("`@
M("`@("`@("@D<W5B='EP92`]/2`G>"UG>FEP+6-O;7!R97-S960G*2!\?`H@
M("`@("`@("`@("`H)'-U8G1Y<&4@/3T@)W@M9W1A<B<I*2!["B`@("`@("`@
M("`@("1G>FEP(#T@)DAO<F1E7T-O;7!R97-S.CIS:6YG;&5T;VXH)V=Z:7`G
M*3L*("`@("`@("`@("`@)&-O;G1E;G1S(#T@)&=Z:7`M/F1E8V]M<')E<W,H
M)&-O;G1E;G1S*3L*("`@("`@("`@("`@:68@*&5M<'1Y*"1C;VYT96YT<RDI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`G/'!R93XG("X@7R@B56YA8FQE
M('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(I("X@)SPO<')E/B<["B`@
M("`@("`@("`@('T@96QS96EF("AI<U]A*"1C;VYT96YT<RP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("<\<')E/B<@+B`D8V]N
M=&5N=',M/F=E=$UE<W-A9V4H*2`N("<\+W!R93XG.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!I9B`H)'-U8G1Y<&4@/3T@)V=Z:7`G('Q\
M"B`@("`@("`@("`@("1S=6)T>7!E(#T]("=X+6=Z:7`G('Q\"B`@("`@("`@
M("`@("1S=6)T>7!E(#T]("=X+6=Z:7`M8V]M<')E<W-E9"<I('L*("`@("`@
M("`@("`@9VQO8F%L("1C;VYF.PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M)TAO<F1E+TU)344O36%G:6,N<&AP)SL*("`@("`@("`@("`@)&UI;65?='EP
M92`]($U)345?36%G:6,Z.F%N86QY>F5$871A*"1C;VYT96YT<RP@:7-S970H
M)&-O;F9;)VUI;64G75LG;6%G:6-?9&(G72D@/R`D8V]N9ELG;6EM92==6R=M
M86=I8U]D8B==(#H@;G5L;"D["B`@("`@("`@("`@(&EF("@A)&UI;65?='EP
M92D@>PH@("`@("`@("`@("`@("`@)&UI;65?='EP92`](%\H(E5N:VYO=VXB
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)SQP<F4^)R`N
M(%\H(D-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z("(I("X@)&UI
M;65?='EP92`N("<\+W!R93XG.PH@("`@("`@('T*"B`@("`@("`@+RH@3V)T
M86EN('1H92!L:7-T(&]F(&9I;&5S+V1A=&$@:6X@=&AE('1A<B!F:6QE+B`J
M+PH@("`@("`@("1T87(@/2`F2&]R9&5?0V]M<')E<W,Z.G-I;F=L971O;B@G
M=&%R)RD["@H@("`@("`@("1T87)$871A(#T@)'1A<BT^9&5C;VUP<F5S<R@D
M8V]N=&5N=',I.PH@("`@("`@(&EF("AI<U]A*"1T87)$871A+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`G/'!R93XG("X@)'1A<D1A
M=&$M/F=E=$UE<W-A9V4H*2`N("<\+W!R93XG.PH@("`@("`@('T*"B`@("`@
M("`@)&9I;&5#;W5N="`](&-O=6YT*"1T87)$871A*3L*"B`@("`@("`@:6YC
M;'5D95]O;F-E("=(;W)D92]497AT+G!H<"<["@H@("`@("`@("1T97AT("`]
M("<\<W1R;VYG/B<@+B!H=&UL<W!E8VEA;&-H87)S*'-P<FEN=&8H7R@B0V]N
M=&5N=',@;V8@7"(E<UPB(BDL("1T:&ES+3YM:6UE7W!A<G0M/F=E=$YA;64H
M*2DI("X@)SH\+W-T<F]N9SXG("X@(EQN(CL*("`@("`@("`D=&5X="`N/2`G
M/'1A8FQE/CQT<CX\=&0@86QI9VX](FQE9G0B/CQT=#X\<W!A;B!C;&%S<STB
M9FEX960B/B<["B`@("`@("`@)'1E>'0@+CT@5&5X=#HZ:'1M;$%L;%-P86-E
M<RA?*")!<F-H:79E($YA;64B*2`N("<Z("`G("X@)'1H:7,M/FUI;65?<&%R
M="T^9V5T3F%M92@I*2`N(")<;B(["B`@("`@("`@)'1E>'0@+CT@5&5X=#HZ
M:'1M;$%L;%-P86-E<RA?*")!<F-H:79E($9I;&4@4VEZ92(I("X@)SH@)R`N
M('-T<FQE;B@D8V]N=&5N=',I("X@)R!B>71E<R<I("X@(EQN(CL*("`@("`@
M("`D=&5X="`N/2!497AT.CIH=&UL06QL4W!A8V5S*"@D9FEL94-O=6YT("$]
M(#$I(#\@<W!R:6YT9BA?*")&:6QE($-O=6YT.B`E<R!F:6QE<R(I+"`D9FEL
M94-O=6YT*2`Z('-P<FEN=&8H7R@B1FEL92!#;W5N=#H@)7,@9FEL92(I+"`D
M9FEL94-O=6YT*2D["B`@("`@("`@)'1E>'0@+CT@(EQN7&XB.PH@("`@("`@
M("1T97AT("X](%1E>'0Z.FAT;6Q!;&Q3<&%C97,H"B`@("`@("`@("`@("`@
M("`@("`@('-T<E]P860H7R@B1FEL92!.86UE(BDL("`@("`V,BP@)R`G+"!3
M5%)?4$%$7U))1TA4*2`N"B`@("`@("`@("`@("`@("`@("`@('-T<E]P860H
M7R@B071T<FEB=71E<R(I+"`@("`Q-2P@)R`G+"!35%)?4$%$7TQ%1E0I("X*
M("`@("`@("`@("`@("`@("`@("`@<W1R7W!A9"A?*")3:7IE(BDL("`@("`@
M("`@(#$P+"`G("<L(%-44E]0041?3$5&5"D@+@H@("`@("`@("`@("`@("`@
M("`@("!S=')?<&%D*%\H(DUO9&EF:65D($1A=&4B*2P@,3DL("<@)RP@4U12
M7U!!1%],1494*0H@("`@("`@("`@("`@("`@("D@+B`B7&XB.PH*("`@("`@
M("`D=&5X="`N/2!S=')?<F5P96%T*"<M)RP@,3`V*2`N(")<;B(["@H@("`@
M("`@(&9O<F5A8V@@*"1T87)$871A(&%S("1V86PI('L*("`@("`@("`@("`D
M=&5X="`N/2!497AT.CIH=&UL06QL4W!A8V5S*`H@("`@("`@("`@("`@("`@
M("`@("`@("!S=')?<&%D*"1V86Q;)VYA;64G72P@-C(L("<@)RP@4U127U!!
M1%]224=(5"D@+@H@("`@("`@("`@("`@("`@("`@("`@("!S=')?<&%D*"1V
M86Q;)V%T='(G72P@,34L("<@)RP@4U127U!!1%],1494*2`N"B`@("`@("`@
M("`@("`@("`@("`@("`@('-T<E]P860H)'9A;%LG<VEZ92==+"`Q,"P@)R`G
M+"!35%)?4$%$7TQ%1E0I("X*("`@("`@("`@("`@("`@("`@("`@("`@<W1R
M7W!A9"AS=')F=&EM92@B)60M)6(M)5D@)4@Z)4TB+"`D=F%L6R=D871E)UTI
M+"`Q.2P@)R`G+"!35%)?4$%$7TQ%1E0I"B`@("`@("`@("`@("`@("`@("`@
M*2`N(")<;B(["B`@("`@("`@?0H*("`@("`@("`D=&5X="`N/2!S=')?<F5P
M96%T*"<M)RP@,3`V*2`N(")<;B(["B`@("`@("`@)'1E>'0@+CT@)SPO<W!A
M;CX\+W1T/CPO=&0^/"]T<CX\+W1A8FQE/B<["@H@("`@("`@(')E='5R;B!N
M;#)B<B@D=&5X="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE
M(&-O;G1E;G0M='EP90H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@8V]N=&5N="UT>7!E(&]F('1H92!O=71P=70N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G=&5X="]H
M=&UL.R!C:&%R<V5T/2<@+B!.3%,Z.F=E=$-H87)S970H*3L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+W-O=7)C92YP:'``````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-#0W(#$P-3$U-#,S-S,V(#`R
M,S,V,0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@5&AE($U)345?5FEE=V5R7W-O=7)C92!C;&%S<R!I
M<R!A(&-L87-S(&9O<B!A;GD@=FEE=V5R('1H870@=V%N=',*("H@=&\@<')O
M=FED92!L:6YE(&YU;6)E<G,@=&\@97AT96YD+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W-O=7)C92YP:'`L=B`Q+CDN,3`N
M.2`R,#`V+S`Q+S`Q(#(Q.C(X.C(U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`
M<&%C:V%G92!(;W)D95]-24U%7U9I97=E<@H@*B\*8VQA<W,@34E-15]6:65W
M97)?<V]U<F-E(&5X=&5N9',@34E-15]6:65W97(@>PH*("`@("\J*@H@("`@
M("H@061D(&QI;F4@;G5M8F5R<R!T;R!A(&)L;V-K(&]F(&-O9&4N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]D92`@5&AE(&-O9&4@=&\@;G5M
M8F5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:6YE3G5M8F5R*"1C;V1E+"`D
M;&EN96)R96%K(#T@(EQN(BD*("`@('L*("`@("`@("`D;&EN97,@/2!S=6)S
M=')?8V]U;G0H)&-O9&4L("1L:6YE8G)E86LI("L@,3L*("`@("`@("`D:'1M
M;"`]("<\=&%B;&4@8VQA<W,](FQI;F5.=6UB97)E9"(@8V5L;'-P86-I;F<]
M(C`B/CQT<CX\=&@^)SL*("`@("`@("!F;W(@*"1L(#T@,3L@)&P@/#T@)&QI
M;F5S.R`D;"LK*2!["B`@("`@("`@("`@("1H=&UL("X]('-P<FEN=&8H)SQA
M(&ED/2)L)7,B(&AR968](B-L)7,B/B5S/"]A/CQB<B`O/B<L("1L+"`D;"P@
M)&PI("X@(EQN(CL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1H=&UL("X@
M)SPO=&@^/'1D/B<@+B`D8V]D92`N("<\+W1D/CPO='(^/"]T86)L93XG.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!-24U%(&-O;G1E;G0@
M='EP92!O9B!T:&4@<F5N9&5R960@8V]N=&5N="X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(&-O;G1E;G0@='EP92!O9B!T:&4@;W5T<'5T
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@
M("!R971U<FX@)W1E>'0O:'1M;#L@8VAA<G-E=#TG("X@3DQ3.CIG971#:&%R
M<V5T*"D["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-
M12]6:65W97(O=&YE9BYP:'``````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#,T-#`@,3`U,34T,S,W,S8@,#(S,#`W`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@34E-
M15]6:65W97)?=&YE9B!C;&%S<R!A;&QO=W,@35,M5$Y%1B!A='1A8VAM96YT
M<R!T;R!B92!D:7-P;&%Y960N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&YE9BYP:'`L=B`Q+C$S+C$P+CD@,C`P-B\P,2\P
M,2`R,3HR.#HR-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P
M-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@
M,C`P,BTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O
M;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA;B!3
M8VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!A=71H;W(@($UI8VAA96P@
M4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I
M;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE=V5R
M"B`J+PIC;&%S<R!-24U%7U9I97=E<E]T;F5F(&5X=&5N9',@34E-15]6:65W
M97(@>PH*("`@("\J*@H@("`@("H@4F5N9&5R(&]U="!T:&4@8W5R<F5N="!T
M;F5F(&1A=&$N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@
M($%N>2!P87)A;65T97)S('1H92!V:65W97(@;6%Y(&YE960N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!R96YD97)E9"!C;VYT96YT<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R*"1P87)A;7,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O0V]M<')E<W,N
M<&AP)SL*"B`@("`@("`@)'1N968@/2`F2&]R9&5?0V]M<')E<W,Z.G-I;F=L
M971O;B@G=&YE9B<I.PH*("`@("`@("`D9&%T82`]("<\=&%B;&4@8F]R9&5R
M/2(Q(CXG.PH@("`@("`@("1I;F9O(#T@)'1N968M/F1E8V]M<')E<W,H)'1H
M:7,M/FUI;65?<&%R="T^9V5T0V]N=&5N=',H*2D["B`@("`@("`@:68@*&5M
M<'1Y*"1I;F9O*2!\?"!I<U]A*"1I;F9O+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("1D871A("X]("<\='(^/'1D/B<@+B!?*")-4RU43D5&($%T
M=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(BD@+B`G/"]T9#X\+W1R/B<[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&1A=&$@+CT@)SQT<CX\
M=&0^)R`N(%\H(DYA;64B*2`N("<\+W1D/CQT9#XG("X@7R@B36EM92!4>7!E
M(BD@+B`G/"]T9#X\+W1R/B<["B`@("`@("`@("`@(&9O<F5A8V@@*"1I;F9O
M(&%S("1P87)T*2!["B`@("`@("`@("`@("`@("`D9&%T82`N/2`G/'1R/CQT
M9#XG("X@)'!A<G1;)VYA;64G72`N("<\+W1D/CQT9#XG("X@)'!A<G1;)W1Y
M<&4G72`N("<O)R`N("1P87)T6R=S=6)T>7!E)UT@+B`G/"]T9#X\+W1R/B<[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@)&1A=&$@+CT@)SPO
M=&%B;&4^)SL*"B`@("`@("`@<F5T=7)N("1D871A.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N('1H92!-24U%(&-O;G1E;G0@='EP92!O9B!T:&4@
M<F5N9&5R960@8V]N=&5N="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE(&-O;G1E;G0@='EP92!O9B!T:&4@;W5T<'5T+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)W1E
M>'0O:'1M;#L@8VAA<G-E=#TG("X@3DQ3.CIG971#:&%R<V5T*"D["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W-R8VAI9VAL:71E+G!H<```````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`V
M-C`W(#$P-3$U-#,S-S,V(#`R-#,W,``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E(&1I<FYA
M;64H7U]&24Q%7U\I("X@)R]S;W5R8V4N<&AP)SL*"B\J*@H@*B!4:&4@34E-
M15]6:65W97)?<W)C:&EG:&QI=&4@8VQA<W,@<F5N9&5R<R!O=70@=F%R:6]U
M<R!C;VYT96YT(&EN($A434P*("H@9F]R;6%T(&)Y('5S:6YG(%-O=7)C92UH
M:6=H;&EG:'0N"B`J"B`J(%-O=7)C92UH:6=H;&EG:'0Z(&AT='`Z+R]W=W<N
M9VYU+F]R9R]S;V9T=V%R92]S<F,M:&EG:&QI=&4O"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP+'8@
M,2XQ-"XQ,"XX(#(P,#8O,#8O,#$@,#,Z,#@Z-3,@8VAU8VL@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R
M869T;VYH86QL+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@
M36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I
M;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE=V5R
M"B`J+PIC;&%S<R!-24U%7U9I97=E<E]S<F-H:6=H;&ET92!E>'1E;F1S($U)
M345?5FEE=V5R7W-O=7)C92!["@H@("`@+RHJ"B`@("`@*B!296YD97(@;W5T
M('1H92!C=7)R96YT;'D@<V5T(&-O;G1E;G1S('5S:6YG(%-O=7)C92UH:6=H
M;&EG:'0*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06YY
M('!A<F%M971E<G,@=&AE('9I97=E<B!M87D@;F5E9"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D(&-O;G1E;G1S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!R96YD97(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@
M("!["B`@("`@("`@9VQO8F%L("1M:6UE7V1R:79E<G,["@H@("`@("`@("\J
M($-H96-K('1O(&UA:V4@<W5R92!T:&4@<')O9W)A;2!A8W1U86QL>2!E>&ES
M=',N("HO"B`@("`@("`@:68@*"%F:6QE7V5X:7-T<R@D;6EM95]D<FEV97)S
M6R=H;W)D92==6R=S<F-H:6=H;&ET92==6R=L;V-A=&EO;B==*2D@>PH@("`@
M("`@("`@("!R971U<FX@)SQP<F4^)R`N('-P<FEN=&8H7R@B5&AE('!R;V=R
M86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F
M;W5N9"!O;B!T:&4@<WES=&5M+B(I+"`D;6EM95]D<FEV97)S6R=H;W)D92==
M6R=S<F-H:6=H;&ET92==6R=L;V-A=&EO;B==*2`N("<\+W!R93XG.PH@("`@
M("`@('T*"B`@("`@("`@+RH@0W)E871E('1E;7!O<F%R>2!F:6QE<R!F;W(@
M5V5B8W!P+B`J+PH@("`@("`@("1T;7!I;B`@/2!(;W)D93HZ9V5T5&5M<$9I
M;&4H)U-R8TEN)RD["B`@("`@("`@)'1M<&]U="`]($AO<F1E.CIG971496UP
M1FEL92@G4W)C3W5T)RP@9F%L<V4I.PH*("`@("`@("`O*B!7<FET92!T:&4@
M8V]N=&5N=',@;V8@;W5R(&)U9F9E<B!T;R!T:&4@=&5M<&]R87)Y(&EN<'5T
M(&9I;&4N("HO"B`@("`@("`@)&-O;G1E;G1S(#T@)'1H:7,M/FUI;65?<&%R
M="T^9V5T0V]N=&5N=',H*3L*("`@("`@("`D9F@@/2!F;W!E;B@D=&UP:6XL
M("=W8B<I.PH@("`@("`@(&9W<FET92@D9F@L("1C;VYT96YT<RP@<W1R;&5N
M*"1C;VYT96YT<RDI.PH@("`@("`@(&9C;&]S92@D9F@I.PH*("`@("`@("`O
M*B!$971E<FUI;F4@=&AE(&QA;F=U86=E(&9R;VT@=&AE(&UI;64@='EP92X@
M*B\*("`@("`@("`D;&%N9R`]("<G.PH@("`@("`@('-W:71C:"`H)'1H:7,M
M/FUI;65?<&%R="T^9V5T5'EP92@I*2!["B`@("`@("`@8V%S92`G=&5X="]X
M+6IA=F$G.@H@("`@("`@("`@("`D;&%N9R`]("=J879A)SL*("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@(&-A<V4@)W1E>'0O>"UC<W)C)SH*("`@("`@
M("!C87-E("=T97AT+W@M8RLK<W)C)SH*("`@("`@("!C87-E("=T97AT+V-P
M<"<Z"B`@("`@("`@("`@("1L86YG(#T@)V-P<"<["B`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("!C87-E("=A<'!L:6-A=&EO;B]X+7!E<FPG.@H@("`@
M("`@("`@("`D;&%N9R`]("=P97)L)SL*("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@(&-A<V4@)V%P<&QI8V%T:6]N+W@M<&AP)SH*("`@("`@("!C87-E
M("=X+65X=&5N<VEO;B]P:'!S)SH*("`@("`@("!C87-E("=X+65X=&5N<VEO
M;B]P:'`S<R<Z"B`@("`@("`@8V%S92`G87!P;&EC871I;VXO>"UH='1P9"UP
M:'`G.@H@("`@("`@(&-A<V4@)V%P<&QI8V%T:6]N+W@M:'1T<&0M<&AP,R<Z
M"B`@("`@("`@8V%S92`G87!P;&EC871I;VXO>"UH='1P9"UP:'!S)SH*("`@
M("`@("`@("`@)&QA;F<@/2`G<&AP,R<["B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!C87-E("=A<'!L:6-A=&EO;B]X+7!Y=&AO;B<Z"B`@("`@("`@
M("`@("1L86YG(#T@)W!Y=&AO;B<["B`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@+R\@)&QA;F<@/2`G<')O;&]G)SL*("`@("`@("`@("`@+R\@
M8G)E86L["@H@("`@("`@("`@("`O+R`D;&%N9R`]("=F;&5X)SL*("`@("`@
M("`@("`@+R\@8G)E86L["@H@("`@("`@("`@("`O+R`D;&%N9R`]("=C:&%N
M9V5L;V<G.PH@("`@("`@("`@("`O+R!B<F5A:SL*"B`@("`@("`@("`@("\O
M("1L86YG(#T@)W)U8GDG.PH@("`@("`@("`@("`O+R!B<F5A:SL*("`@("`@
M("!]"@H@("`@("`@("\J($5X96-U=&4@4V]U<F-E+4AI9VAL:71E+B`J+PH@
M("`@("`@(&5X96,H)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<W)C:&EG:&QI
M=&4G75LG;&]C871I;VXG72`N("(@+2US<F,M;&%N9R`D;&%N9R`M+6]U="UF
M;W)M870@>&AT;6P@+2UI;G!U="`D=&UP:6X@+2UO=71P=70@)'1M<&]U="(I
M.PH@("`@("`@("1R97-U;'1S(#T@9FEL95]G971?8V]N=&5N=',H)'1M<&]U
M="D["B`@("`@("`@=6YL:6YK*"1T;7!O=70I.PH*("`@("`@("`O*B!%9'5C
M871E9"!'=65S<R!A="!W:&5T:&5R('=E(&%R92!I;FQI;F4@;W(@;F]T+B`J
M+PH@("`@("`@(&EF("AH96%D97)S7W-E;G0H*2!\?"!O8E]G971?;&5N9W1H
M*"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YL:6YE3G5M8F5R*"1R
M97-U;'1S*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@
M571I;#HZ8G5F9F5R3W5T<'5T*"=R97%U:7)E)RP@)$=,3T)!3%-;)W)E9VES
M=')Y)UTM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+V-O;6UO;BUH
M96%D97(N:6YC)RD@+@H@("`@("`@("`@("`@("`@)'1H:7,M/FQI;F5.=6UB
M97(H)')E<W5L=',I("X*("`@("`@("`@("`@("`@(%5T:6PZ.F)U9F9E<D]U
M='!U="@G<F5Q=6ER92<L("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W1E
M;7!L871E<R<L("=H;W)D92<I("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<I.PH@
M("`@("`@('T*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I
M97=E<B]P9&8N<&AP````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,34S,2`Q,#4Q-30S,S<S-B`P,C(V,C,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!-24U%7U9I
M97=E<E]P9&8@8VQA<W,@<VEM<&QY(&]U='!U=',@=&AE(%!$1B!F:6QE('=I
M=&@@=&AE(&-O;G1E;G0M='EP90H@*B`G87!P;&EC871I;VXO<&1F)R!E;F%B
M;&EN9R!W96(@8G)O=W-E<G,@=VET:"!A(%!$1B!V:65W97(@<&QU9VEN('1O
M('9I97<*("H@=&AE(%!$1B!F:6QE(&EN<VED92!T:&4@8G)O=W-E<BX*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]P9&8N<&AP
M+'8@,2XS+C$R+C4@,C`P-B\P,2\P,2`R,3HR.#HR-2!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A
M<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,
M*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`
M875T:&]R("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO
M<F%D;RYE9'4^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(
M;W)D95]-24U%7U9I97=E<@H@*B\*8VQA<W,@34E-15]6:65W97)?<&1F(&5X
M=&5N9',@34E-15]6:65W97(@>PH*("`@("\J*@H@("`@("H@4F5T=7)N('1H
M92!C;VYT96YT+71Y<&4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!C;VYT96YT+71Y<&4@;V8@=&AE(&]U='!U="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=A<'!L
M:6-A=&EO;B]P9&8G.PH@("`@?0H*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-
M24U%+U9I97=E<B]O;V\N<&AP````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P-S(R,2`Q,#4Q-30S,S<S-B`P,C(V-3``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!-
M24U%7U9I97=E<E]O;V\@8VQA<W,@<F5N9&5R<R!O=70@3W!E;D]F9FEC92YO
M<F<*("H@9&]C=6UE;G1S(&EN($A434P@9F]R;6%T+@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V]O;RYP:'`L=B`Q+C$T+C$P
M+C<@,C`P-B\P,2\P,2`R,3HR.#HR-2!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#,M,C`P-B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@
M*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D
M92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-87)K;R!$:G5K
M:6,@/&UA<FMO0&]B;&\N8V]M/@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R
M(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A
M8VMA9V4@2&]R9&5?34E-15]6:65W97(*("HO"F-L87-S($U)345?5FEE=V5R
M7V]O;R!E>'1E;F1S($U)345?5FEE=V5R('L*"B`@("`O*BH*("`@("`J(%)E
M;F1E<B!O=70@=&AE(&-U<G)E;G0@9&%T82X*("`@("`J"B`@("`@*B!`<&%R
M86T@87)R87D@)'!A<F%M<R`@06YY('!A<F%M971E<G,@=&AE(%9I97=E<B!M
M87D@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E
M;F1E<F5D(&-O;G1E;G1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97(H
M)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'5S95]X<VQT(#T@
M571I;#HZ97AT96YS:6]N17AI<W1S*"=X<VQT)RD@?'P@9G5N8W1I;VY?97AI
M<W1S*"=D;VUX;6Q?>'-L=%]S='EL97-H965T7V9I;&4G*3L*("`@("`@("!I
M9B`H)'5S95]X<VQT*2!["B`@("`@("`@("`@("1T;7!D:7(@/2!5=&EL.CIC
M<F5A=&5496UP1&ER*'1R=64I.PH@("`@("`@('T*"B`@("`@("`@<F5Q=6ER
M95]O;F-E("=(;W)D92]#;VUP<F5S<RYP:'`G.PH@("`@("`@("1X;6Q?=&%G
M<R`@/2!A<G)A>2@G=&5X=#IP)RP@)W1A8FQE.G1A8FQE("<L("=T86)L93IT
M86)L92UR;W<G+"`G=&%B;&4Z=&%B;&4M8V5L;"<L("=T86)L93IN=6UB97(M
M8V]L=6UN<RUS<&%N;F5D/2<I.PH@("`@("`@("1H=&UL7W1A9W,@/2!A<G)A
M>2@G<"<L("=T86)L92!B;W)D97(](C`B(&-E;&QS<&%C:6YG/2(Q(B!C96QL
M<&%D9&EN9STB,"(@)RP@)W1R(&)G8V]L;W(](B-C8V-C8V,B)RP@)W1D)RP@
M)V-O;'-P86X])RD["B`@("`@("`@)'II<"`]("9(;W)D95]#;VUP<F5S<SHZ
M<VEN9VQE=&]N*"=Z:7`G*3L*("`@("`@("`D;&ES="`]("1Z:7`M/F1E8V]M
M<')E<W,H)'1H:7,M/FUI;65?<&%R="T^9V5T0V]N=&5N=',H*2P*("`@("`@
M("`@("`@87)R87DH)V%C=&EO;B<@/3X@2$]21$5?0T]-4%)%4U-?6DE07TQ)
M4U0I*3L*("`@("`@("!F;W)E86-H("@D;&ES="!A<R`D:V5Y(#T^("1F:6QE
M*2!["B`@("`@("`@("`@(&EF("@D9FEL95LG;F%M92==(#T]("=C;VYT96YT
M+GAM;"<@?'P*("`@("`@("`@("`@("`@("1F:6QE6R=N86UE)UT@/3T@)W-T
M>6QE<RYX;6PG('Q\"B`@("`@("`@("`@("`@("`D9FEL95LG;F%M92==(#T]
M("=M971A+GAM;"<I('L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@)'II
M<"T^9&5C;VUP<F5S<R@D=&AI<RT^;6EM95]P87)T+3YG971#;VYT96YT<R@I
M+`H@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=A8W1I;VXG(#T^($A/4D1%
M7T-/35!215-37UI)4%]$051!+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("=I;F9O)R`@(#T^("1L:7-T+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("=K97DG("`@(#T^("1K97DI*3L*("`@("`@("`@("`@("`@(&EF("@D=7-E
M7WAS;'0I('L*("`@("`@("`@("`@("`@("`@("`D9G`@/2!F;W!E;B@D=&UP
M9&ER("X@)&9I;&5;)VYA;64G72P@)W<G*3L*("`@("`@("`@("`@("`@("`@
M("!F=W)I=&4H)&9P+"`D8V]N=&5N="D["B`@("`@("`@("`@("`@("`@("`@
M9F-L;W-E*"1F<"D["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&9I;&5;
M)VYA;64G72`]/2`G8V]N=&5N="YX;6PG*2!["B`@("`@("`@("`@("`@("`@
M("`@)&-O;G1E;G0@/2!S=')?<F5P;&%C92@D>&UL7W1A9W,L("1H=&UL7W1A
M9W,L("1C;VYT96YT*3L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)&-O
M;G1E;G0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@:68@*"%5=&EL.CIE>'1E;G-I;VY%>&ES=',H)WAS;'0G
M*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("!I
M9B`H9G5N8W1I;VY?97AI<W1S*"=D;VUX;6Q?>'-L=%]S='EL97-H965T7V9I
M;&4G*2D@>PH@("`@("`@("`@("`O+R!5<V4@1$]-6$U,"B`@("`@("`@("`@
M("1X<VQT(#T@9&]M>&UL7WAS;'1?<W1Y;&5S:&5E=%]F:6QE*&1I<FYA;64H
M7U]&24Q%7U\I("X@)R]O;V\O;6%I;E]H=&UL+GAS;"<I.PH@("`@("`@("`@
M("`D9&]M("`](&1O;7AM;%]O<&5N7V9I;&4H)'1M<&1I<B`N("=C;VYT96YT
M+GAM;"<I.PH@("`@("`@("`@("`D<F5S=6QT(#T@0"1X<VQT+3YP<F]C97-S
M*"1D;VTL(&%R<F%Y*"=M971A1FEL95523"<@/3X@)'1M<&1I<B`N("=M971A
M+GAM;"<L("=S='EL97-&:6QE55),)R`]/B`D=&UP9&ER("X@)W-T>6QE<RYX
M;6PG+"`G9&ES86)L94IA=F$G(#T^('1R=64I*3L*("`@("`@("`@("`@<F5T
M=7)N(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'AS;'0M/G)E<W5L=%]D=6UP
M7VUE;2@D<F5S=6QT*2P@)U541BTX)RP@3DQ3.CIG971#:&%R<V5T*"DI.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O(%5S92!84TQ4"B`@("`@
M("`@("`@("1X<VQT(#T@>'-L=%]C<F5A=&4H*3L*("`@("`@("`@("`@)')E
M<W5L="`]($!X<VQT7W!R;V-E<W,H)'AS;'0L("1T;7!D:7(@+B`G8V]N=&5N
M="YX;6PG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!D
M:7)N86UE*%]?1DE,15]?*2`N("<O;V]O+VUA:6Y?:'1M;"YX<VPG+"!N=6QL
M+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@G;65T849I;&554DPG(#T^("1T;7!D:7(@+B`G;65T82YX;6PG+"`G
M<W1Y;&5S1FEL95523"<@/3X@)'1M<&1I<B`N("=S='EL97,N>&UL)RP@)V1I
M<V%B;&5*879A)R`]/B!T<G5E*2D["B`@("`@("`@("`@(&EF("@A)')E<W5L
M="D@>PH@("`@("`@("`@("`@("`@)')E<W5L="`]('AS;'1?97)R;W(H)'AS
M;'0I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@('AS;'1?9G)E92@D>'-L
M="D["B`@("`@("`@("`@(')E='5R;B!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T
M*"1R97-U;'0L("=55$8M."<L($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE($U)344@8V]N
M=&5N="!T>7!E(&]F('1H92!R96YD97)E9"!C;VYT96YT+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@8V]N=&5N="!T>7!E(&]F('1H92!O
M=71P=70N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@
M("`@("`@(')E='5R;B`G=&5X="]H=&UL.R!C:&%R<V5T/2<@+B!.3%,Z.F=E
M=$-H87)S970H*3L*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]S96-U<FET>2YP:'``````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-34Q-"`Q,#4Q-30S,S<S-B`P,C,W
M,C8`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J(%1H92!-24U%7U9I97=E<E]S96-U<FET>2!C;&%S<R!I
M<R!A('=R87!P97(@=7-E9"!T;R!L;V%D('1H92!A<'!R;W!R:6%T90H@*B!-
M24U%7U9I97=E<B!F;W(@<V5C=7)E(&UU;'1I<&%R="!M97-S86=E<R`H9&5F
M:6YE9"!B>2!21D,@,3@T-RDN(%1H:7,*("H@8VQA<W,@:&%N9&QE<R!M=6QT
M:7!A<G0O<VEG;F5D(&%N9"!M=6QT:7!A<G0O96YC<GEP=&5D(&1A=&$N"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<V5C=7)I
M='DN<&AP+'8@,2XV+C$P+C4@,C`P-B\P,2\P,2`R,3HR.#HR-2!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L(%-L=7-A<GH@
M/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B!`875T:&]R("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R
M;2YC;VQO<F%D;RYE9'4^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C
M:V%G92!(;W)D95]-24U%7U9I97=E<@H@*B\*8VQA<W,@34E-15]6:65W97)?
M<V5C=7)I='D@97AT96YD<R!-24U%7U9I97=E<B!["@H@("`@+RHJ"B`@("`@
M*B!3=&]R97,@=&AE($U)345?5FEE=V5R(&]F('1H92!S<&5C:69I960@<V5C
M=7)I='D@<')O=&]C;VPN"B`@("`@*@H@("`@("H@0'9A<B!-24U%7U9I97=E
M<@H@("`@("HO"B`@("!V87(@)%]V:65W97(["@H@("`@+RHJ"B`@("`@*B!4
M:&4@)&UI;65?<&%R="!C;&%S<R!V87)I86)L92!H87,@=&AE(&EN9F]R;6%T
M:6]N('1O(')E;F1E<@H@("`@("H@;W5T+"!E;F-A<'-U;&%T960@:6X@82!-
M24U%7U!A<G0@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2`D<&%R86US
M(&UI>&5D("!4:&4@<&%R86UE=&5R<R`H:68@86YY*2!T;R!P87-S('1O('1H
M92!U;F1E<FQY:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@34E-
M15]6:65W97(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%)E;F1E
M<FEN9R!O9B!T:&4@8V]N=&5N="X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N
M9&5R*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("\J($=E="!T
M:&4@87!P<F]P<FEA=&4@34E-15]6:65W97(@9F]R('1H92!P<F]T;V-O;"!S
M<&5C:69I960N("HO"B`@("`@("`@:68@*"$H)'1H:7,M/E]R97-O;'9E5FEE
M=V5R*"DI*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@
M("`@("\J(%)E;F1E<B!U<VEN9R!T:&4@;&]A9&5D($U)345?5FEE=V5R(&]B
M:F5C="X@*B\*("`@("`@("!R971U<FX@)'1H:7,M/E]V:65W97(M/G)E;F1E
M<B@D<&%R86US*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE
M(&-O;G1E;G0M='EP92!O9B!T:&4@5FEE=V5R('5S960@=&\@=FEE=R!T:&4@
M<&%R="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@02!C;VYT96YT
M+71Y<&4@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714>7!E*"D*
M("`@('L*("`@("`@("`O*B!'970@=&AE(&%P<')O<')I871E($U)345?5FEE
M=V5R(&9O<B!T:&4@<')O=&]C;VP@<W!E8VEF:65D+B`J+PH@("`@("`@(&EF
M("@A*"1T:&ES+3Y?<F5S;VQV959I97=E<B@I*2D@>PH@("`@("`@("`@("!R
M971U<FX@)V%P<&QI8V%T:6]N+V]C=&5T+7-T<F5A;2<["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?=FEE=V5R+3YG9714
M>7!E*"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@3&]A9"!A
M($U)345?5FEE=V5R(&%C8V]R9&EN9R!T;R!T:&4@<')O=&]C;VP@<&%R86UE
M=&5R('-T;W)E9`H@("`@("H@:6X@=&AE($U)345?4&%R="!T;R!R96YD97(N
M($EF('5N<W5C8V5S<V9U;"P@=')Y('1O(&QO860@82!G96YE<FEC"B`@("`@
M*B!M=6QT:7!A<G0@34E-15]6:65W97(N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E
M(&]N('-U8V-E<W,L(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]R97-O;'9E5FEE=V5R*"D*("`@('L*("`@("`@("`D=FEE=V5R
M(#T@;G5L;#L*"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?=FEE=V5R*2D@
M>PH@("`@("`@("`@("`D<')O=&]C;VP@/2`D=&AI<RT^;6EM95]P87)T+3YG
M971#;VYT96YT5'EP95!A<F%M971E<B@G<')O=&]C;VPG*3L*("`@("`@("`@
M("`@:68@*&5M<'1Y*"1P<F]T;V-O;"DI('L*("`@("`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=FEE=V5R
M(#T@)DU)345?5FEE=V5R.CIF86-T;W)Y*"1T:&ES+3YM:6UE7W!A<G0L("1P
M<F]T;V-O;"D["B`@("`@("`@("`@(&EF("AE;7!T>2@D=FEE=V5R*2!\?`H@
M("`@("`@("`@("`@("`@*%-T<FEN9SHZ;&]W97(H9V5T7V-L87-S*"1V:65W
M97(I*2`]/2`G;6EM95]V:65W97)?9&5F875L="<I*2!["B`@("`@("`@("`@
M("`@("`D=FEE=V5R(#T@)DU)345?5FEE=V5R.CIF86-T;W)Y*"1T:&ES+3YM
M:6UE7W!A<G0L("1T:&ES+3YM:6UE7W!A<G0M/F=E=%!R:6UA<GE4>7!E*"D@
M+B`G+RHG*3L*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D=FEE=V5R*2D@
M>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7W9I
M97=E<B`]("1V:65W97(["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U
M93L*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W!H<"YP:'``````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`R-S`U(#$P-3$U-#,S-S,V(#`R,C8T-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`H*<F5Q=6ER95]O
M;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]S;W5R8V4N<&AP)SL*"B\J*@H@
M*B!4:&4@34E-15]6:65W97)?<&AP(&-L87-S(')E;F1E<G,@;W5T('-Y;G1A
M>"UH:6=H;&EG:'1E9"!02%`@8V]D90H@*B!I;B!(5$U,(&9O<FUA="X*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]P:'`N<&AP
M+'8@,2XR,BXQ,"XX(#(P,#8O,#8O,#$@,#,Z,#@Z-3,@8VAU8VL@17AP("0*
M("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H
M=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(
M;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?34E-15]6:65W97(*("HO"F-L
M87-S($U)345?5FEE=V5R7W!H<"!E>'1E;F1S($U)345?5FEE=V5R7W-O=7)C
M92!["@H@("`@+RHJ"B`@("`@*B!296YD97)S(&]U="!T:&4@8V]N=&5N=',N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N>2!P87)A
M;65T97)S('1H92!6:65W97(@;6%Y(&YE960N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!R96YD97)E9"!C;VYT96YT<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@<F5N9&5R*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@
M("`@("`@("1R97-U;'1S(#T@=')I;2AS=')?<F5P;&%C92AA<G)A>2@B7&XB
M+"`G/&)R("\^)RDL(&%R<F%Y*"<G+"`B7&XB*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:&EG:&QI9VAT7W-T<FEN9R@D=&AI<RT^
M;6EM95]P87)T+3YG971#;VYT96YT<R@I+"!T<G5E*2DI.PH*("`@("`@("`O
M+R!%9'5C871E9"!'=65S<R!A="!W:&5T:&5R('=E(&%R92!I;FQI;F4@;W(@
M;F]T+@H@("`@("`@(&EF("AH96%D97)S7W-E;G0H*2!\?"!O8E]G971?;&5N
M9W1H*"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YL:6YE3G5M8F5R
M*"1R97-U;'1S*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U
M<FX@571I;#HZ8G5F9F5R3W5T<'5T*"=R97%U:7)E)RP@)$=,3T)!3%-;)W)E
M9VES=')Y)UTM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+V-O;6UO
M;BUH96%D97(N:6YC)RD@+@H@("`@("`@("`@("`@("`@)'1H:7,M/FQI;F5.
M=6UB97(H)')E<W5L=',I("X*("`@("`@("`@("`@("`@(%5T:6PZ.F)U9F9E
M<D]U='!U="@G<F5Q=6ER92<L("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H
M)W1E;7!L871E<R<L("=H;W)D92<I("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<I
M.PH@("`@("`@('T*("`@('T*"GT*````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O<FEC:'1E>'0N
M<&AP````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,34T,S<@,3`U,34T,S,W
M,S8@,#(S-S$V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!4:&4@34E-15]6:65W97)?<FEC:'1E>'0@
M8VQA<W,@<F5N9&5R<R!O=70@2%1-3"!T97AT(&9R;VT@=&5X="]R:6-H=&5X
M=`H@*B!C;VYT96YT('1A9W,L("A21D,@,3@Y-B!;-RXQ+C-=*2X*("H*("H@
M02!M:6YI;6%L(')I8VAT97AT(&EM<&QE;65N=&%T:6]N(&ES(&]N92!T:&%T
M('-I;7!L>2!C;VYV97)T<R`B/&QT/B(@=&\*("H@(CPB+"!C;VYV97)T<R!#
M4DQ&<R!T;R!34$%#12P@8V]N=F5R=',@/&YL/B!T;R!A(&YE=VQI;F4@86-C
M;W)D:6YG('1O"B`J(&QO8V%L(&YE=VQI;F4@8V]N=F5N=&EO;BP@<F5M;W9E
M<R!E=F5R>71H:6YG(&)E='=E96X@82`\8V]M;65N=#X@8V]M;6%N9`H@*B!A
M;F0@=&AE(&YE>'0@8F%L86YC:6YG(#PO8V]M;65N=#X@8V]M;6%N9"P@86YD
M(')E;6]V97,@86QL(&]T:&5R"B`J(&]T:&5R(&9O<FUA='1I;F<@8V]M;6%N
M9',@*&%L;"!T97AT(&5N8VQO<V5D(&EN(&%N9VQE(&)R86-K971S*2X*("H*
M("H@5V4@:6UP;&5M96YT('1H92!F;VQL;W=I;F<@=&%G<SH*("H@/&)O;&0^
M+"`\:71A;&EC/BP@/&9I>&5D/BP@/'-M86QL97(^+"`\8FEG9V5R/BP@/'5N
M9&5R;&EN93XL(#QC96YT97(^+`H@*B`\9FQU<VAL969T/BP@/&9L=7-H<FEG
M:'0^+"`\:6YD96YT/BP@/'-U8G-C<FEP=#XL(#QE>&-E<G!T/BP@/'!A<F%G
M<F%P:#XL"B`J(#QS:6=N871U<F4^+"`\8V]M;65N=#XL(#QN;RUO<#XL(#QL
M=#XL(#QN;#X*("H*("H@5&AE(&9O;&QO=VEN9R!T86=S(&%R92!I;7!L96UE
M;G1E9"!D:69F97)E;G1L>2!T:&%N(&1E<V-R:6)E9"!I;B!T:&4@4D9#"B`J
M("AD=64@=&\@;&EM:71A=&EO;G,@:6X@2%1-3"!O=71P=70I.@H@*B`\:&5A
M9&EN9SX@+2!/=71P=70@87,@8V5N=&5R960L(&)O;&0@=&5X="X*("H@/&9O
M;W1I;F<^("T@3W5T<'5T(&%S(&-E;G1E<F5D+"!B;VQD('1E>'0N"B`J(#QN
M<#X@("`@("`M($]U='!U="!A<R!P87)A9W)A<&@@8G)E86LN"B`J"B`J(%1H
M92!F;VQL;W=I;F<@=&%G<R!A<F4@3D]4(&EM<&QE;65N=&5D.@H@*B`\:6YD
M96YT<FEG:'0^+"`\;W5T9&5N=#XL(#QO=71D96YT<FEG:'0^+"`\<V%M97!A
M9V4^+"`\:7-O+3@X-3DM6#XL"B`J(#QU<RUA<V-I:3XL"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<FEC:'1E>'0N<&AP+'8@
M,2XT+C$P+C<@,C`P-B\P,2\P,2`R,3HR.#HR-2!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#(P,#0M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`
M8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D
M;RYE9'4^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D
M95]-24U%7U9I97=E<@H@*B\*8VQA<W,@34E-15]6:65W97)?<FEC:'1E>'0@
M97AT96YD<R!-24U%7U9I97=E<B!["@H@("`@+RHJ"B`@("`@*B!296YD97(@
M;W5T('1H92!C=7)R96YT;'D@<V5T(&-O;G1E;G1S(&EN($A434P@9F]R;6%T
M+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!;GD@<&%R
M86UE=&5R<R!T:&4@5FEE=V5R(&UA>2!N965D+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@<F5N9&5R960@8V]N=&5N=',N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(')E;F1E<B@D<&%R86US(#T@87)R87DH*2D*("`@('L*
M("`@("`@("!I9B`H*"1T97AT(#T@)'1H:7,M/FUI;65?<&%R="T^9V5T0V]N
M=&5N=',H*2D@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"@H@("`@("`@(&EF("AT<FEM*"1T97AT*2`]/2`G)RD@
M>PH@("`@("`@("`@("!R971U<FX@)'1E>'0["B`@("`@("`@?0H*("`@("`@
M("`O*B!5<V4@<W1R7VER97!L86-E*"D@:68@=7-I;F<@4$A0(#4N,"LN("HO
M"B`@("`@("`@)&AA<U]S=')?:7)E<&QA8V4@/2!F=6YC=&EO;E]E>&ES=',H
M)W-T<E]I<F5P;&%C92<I.PH*("`@("`@("`O*B!792!A9&0@<W!A8V4@870@
M=&AE(&)E9VEN;FEN9R!A;F0@96YD(&]F('1H92!S=')I;F<@87,@:70@=VEL
M;`H@("`@("`@("`J(&UA:V4@<V]M92!R96=U;&%R(&5X<')E<W-I;VX@8VAE
M8VMS(&QA=&5R(&UU8V@@96%S:65R("AS;R!W90H@("`@("`@("`J(&1O;B=T
M(&AA=F4@=&\@=V]R<GD@86)O=70@<W1A<G0O96YD(&]F(&QI;F4@8VAA<F%C
M=&5R<RDN("HO"B`@("`@("`@)'1E>'0@/2`G("<@+B`D=&5X="`N("<@)SL*
M"B`@("`@("`@+RH@4F5M;W9E(&5V97)Y=&AI;F<@8F5T=V5E;B`\8V]M;65N
M=#X@=&%G<RX@*B\*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+SQC
M;VUM96YT+BH^+BH\7"]C;VUM96YT/B]5:7,G+"`G)RP@)'1E>'0I.PH*("`@
M("`@("`O*B!296UO=F4@86YY('5N<F5C;V=N:7IE9"!T86=S(&EN('1H92!T
M97AT+B`@5V4@9&]N)W0@;F5E9"`\;F\M;W`^"B`@("`@("`@("H@:6X@)'1A
M9W,@<VEN8V4@:70@9&]E<VXG="!D;R!A;GET:&EN9R!A;GEW87DN("!!;&P@
M/&-O;6UE;G0^('1A9W,*("`@("`@("`@*B!H879E(&%L<F5A9'D@8F5E;B!R
M96UO=F5D+B`J+PH@("`@("`@("1T86=S(#T@)SQB;VQD/CQI=&%L:6,^/&9I
M>&5D/CQS;6%L;&5R/CQB:6=G97(^/'5N9&5R;&EN93X\8V5N=&5R/CQF;'5S
M:&QE9G0^/&9L=7-H<FEG:'0^/&EN9&5N=#X\<W5B<V-R:7!T/CQE>&-E<G!T
M/CQP87)A9W)A<&@^/'-I9VYA='5R93X\;'0^/&YL/B<["B`@("`@("`@)'1E
M>'0@/2!S=')I<%]T86=S*"1T97AT+"`D=&%G<RD["@H@("`@("`@("\J(#QL
M=#X@8F5C;VUE<R!A("<\)RX@0U),1B!B96-O;65S(&$@4U!!0T4N("HO"B`@
M("`@("`@:68@*"1H87-?<W1R7VER97!L86-E*2!["B`@("`@("`@("`@("1T
M97AT(#T@<W1R7VER97!L86-E*&%R<F%Y*"<\;'0^)RP@(EQR7&XB*2P@87)R
M87DH)R9L=#LG+"`G("<I+"`D=&5X="D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H87)R87DH)R\\;'0^+VDG
M+"`B+UQR7&XO(BDL(&%R<F%Y*"<F;'0[)RP@)R`G*2P@)'1E>'0I.PH@("`@
M("`@('T*"B`@("`@("`@+RH@5V4@=')Y('1O('!R;W1E8W0@86=A:6YS="!B
M860@<W1U9F8@:&5R92X@*B\*("`@("`@("`D=&5X="`]($!H=&UL<W!E8VEA
M;&-H87)S*"1T97AT+"!%3E1?455/5$53+"`D=&AI<RT^;6EM95]P87)T+3YG
M971#:&%R<V5T*"DI.PH*("`@("`@("`O*B`\;FP^(&)E8V]M97,@82!N97=L
M:6YE("@\8G(@+SXI.PH@("`@("`@("`J(#QN<#X@8F5C;VUE<R!A('!A<F%G
M<F%P:"!B<F5A:R`H/'`@+SXI+B`J+PH@("`@("`@(&EF("@D:&%S7W-T<E]I
M<F5P;&%C92D@>PH@("`@("`@("`@("`D=&5X="`]('-T<E]I<F5P;&%C92AA
M<G)A>2@G)FQT.VYL)F=T.R<L("<F;'0[;G`F9W0[)RDL(&%R<F%Y*"<\8G(@
M+SXG+"`G/'`@+SXG*2P@)'1E>'0I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1T97AT(#T@<')E9U]R97!L86-E*&%R<F%Y*"<O*#\\(29L=#LI
M)FQT.VYL+BHF9W0[+U5I<R<L("<O*#\\(29L=#LI)FQT.VYP+BHF9W0[+U5I
M<R<I+"!A<G)A>2@G/&)R("\^)RP@)SQP("\^)RDL("1T97AT*3L*("`@("`@
M("!]"@H@("`@("`@("\J($YO=R!C;VYV97)T('1H92!K;F]W;B!T86=S('1O
M(&AT;6PN(%1R>2!T;R!R96UO=F4@86YY('1A9PH@("`@("`@("`J('!A<F%M
M971E<G,@=&\@<W1O<"!P96]P;&4@9G)O;2!T<GEI;F<@=&\@<'5L;"!A(&9A
M<W0@;VYE+B`J+PH@("`@("`@("1T97AT(#T@<')E9U]R97!L86-E*"<O*#\\
M(29L=#LI)FQT.V)O;&0N*B9G=#LH+BHI)FQT.UPO8F]L9"9G=#LO56ES)RP@
M)SQS<&%N('-T>6QE/2)F;VYT+7=E:6=H=#H@8F]L9"(^7#$\+W-P86X^)RP@
M)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E9U]R97!L86-E*"<O*#\\(29L
M=#LI)FQT.VET86QI8RXJ)F=T.R@N*BDF;'0[7"]I=&%L:6,F9W0[+U5I<R<L
M("<\<W!A;B!S='EL93TB9F]N="US='EL93H@:71A;&EC(CY<,3PO<W!A;CXG
M+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H/SPA
M)FQT.RDF;'0[9FEX960N*B9G=#LH+BHI)FQT.UPO9FEX960F9W0[+U5I<R<L
M("<\9F]N="!F86-E/2)F:7AE9"(^7#$\+V9O;G0^)RP@)'1E>'0I.PH@("`@
M("`@("1T97AT(#T@<')E9U]R97!L86-E*"<O*#\\(29L=#LI)FQT.W-M86QL
M97(N*B9G=#LO56ES)RP@)SQS<&%N('-T>6QE/2)F;VYT+7-I>F4Z('-M86QL
M97(B/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G
M+R@_/"$F;'0[*29L=#M<+W-M86QL97(F9W0[+U5I<R<L("<\+W-P86X^)RP@
M)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E9U]R97!L86-E*"<O*#\\(29L
M=#LI)FQT.V)I9V=E<BXJ)F=T.R]5:7,G+"`G/'-P86X@<W1Y;&4](F9O;G0M
M<VEZ93H@;&%R9V5R(CXG+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!P<F5G
M7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[7"]B:6=G97(F9W0[+U5I<R<L("<\
M+W-P86X^)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E9U]R97!L86-E
M*"<O*#\\(29L=#LI)FQT.W5N9&5R;&EN92XJ)F=T.R@N*BDF;'0[7"]U;F1E
M<FQI;F4F9W0[+U5I<R<L("<\<W!A;B!S='EL93TB=&5X="UD96-O<F%T:6]N
M.B!U;F1E<FQI;F4B/EPQ/"]S<&%N/B<L("1T97AT*3L*("`@("`@("`D=&5X
M="`]('!R96=?<F5P;&%C92@G+R@_/"$F;'0[*29L=#MC96YT97(N*B9G=#LH
M+BHI)FQT.UPO8V5N=&5R)F=T.R]5:7,G+"`G/&1I=B!A;&EG;CTB8V5N=&5R
M(CY<,3PO9&EV/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]('!R96=?<F5P
M;&%C92@G+R@_/"$F;'0[*29L=#MF;'5S:&QE9G0N*B9G=#LH+BHI)FQT.UPO
M9FQU<VAL969T)F=T.R]5:7,G+"`G/&1I=B!A;&EG;CTB;&5F="(^7#$\+V1I
M=CXG+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H
M/SPA)FQT.RDF;'0[9FQU<VAR:6=H="XJ)F=T.R@N*BDF;'0[7"]F;'5S:')I
M9VAT)F=T.R]5:7,G+"`G/&1I=B!A;&EG;CTB<FEG:'0B/EPQ/"]D:78^)RP@
M)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E9U]R97!L86-E*"<O*#\\(29L
M=#LI)FQT.VEN9&5N="XJ)F=T.R@N*BDF;'0[7"]I;F1E;G0F9W0[+U5I<R<L
M("<\8FQO8VMQ=6]T93Y<,3PO8FQO8VMQ=6]T93XG+"`D=&5X="D["B`@("`@
M("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[97AC97)P
M="XJ)F=T.R@N*BDF;'0[7"]E>&-E<G!T)F=T.R]5:7,G+"`G/&-I=&4^7#$\
M+V-I=&4^)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E9U]R97!L86-E
M*"<O*#\\(29L=#LI)FQT.W-U8G-C<FEP="XJ)F=T.R@N*BDF;'0[7"]S=6)S
M8W)I<'0F9W0[+U5I<R<L("<\<W5B/EPQ/"]S=6(^)RP@)'1E>'0I.PH@("`@
M("`@("1T97AT(#T@<')E9U]R97!L86-E*"<O*#\\(29L=#LI)FQT.W-U<&5R
M<V-R:7!T+BHF9W0[*"XJ*29L=#M<+W-U<&5R<V-R:7!T)F=T.R]5:7,G+"`G
M/'-U<#Y<,3PO<W5P/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]('!R96=?
M<F5P;&%C92@G+R@_/"$F;'0[*29L=#MH96%D:6YG+BHF9W0[*"XJ*29L=#M<
M+VAE861I;F<F9W0[+U5I<R<L("<\8G(@+SX\9&EV(&%L:6=N/2)C96YT97(B
M('-T>6QE/2)F;VYT+7=E:6=H=#H@8F]L9"(^7#$\+V1I=CX\8G(@+SXG+"`D
M=&5X="D["B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H/SPA)FQT
M.RDF;'0[9F]O=&EN9RXJ)F=T.R@N*BDF;'0[7"]F;V]T:6YG)F=T.R]5:7,G
M+"`G/&)R("\^/&1I=B!A;&EG;CTB8V5N=&5R(B!S='EL93TB9F]N="UW96EG
M:'0Z(&)O;&0B/EPQ/"]D:78^/&)R("\^)RP@)'1E>'0I.PH@("`@("`@("1T
M97AT(#T@<')E9U]R97!L86-E*"<O*#\\(29L=#LI)FQT.W!A<F%G<F%P:"XJ
M)F=T.R@N*BDF;'0[7"]P87)A9W)A<&@F9W0[+U5I<R<L("<\<#Y<,3PO<#XG
M+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H/SPA
M)FQT.RDF;'0[<VEG;F%T=7)E+BHF9W0[*"XJ*29L=#M<+W-I9VYA='5R929G
M=#LO56ES)RP@)SQA9&1R97-S/EPQ/"]A9&1R97-S/B<L("1T97AT*3L*"B`@
M("`@("`@+RH@3F]W('=E(')E;6]V92!T:&4@;&5A9&EN9R]T<F%I;&EN9R!S
M<&%C92!W92!A9&1E9"!A="!T:&4@<W1A<G0N("HO"B`@("`@("`@)'1E>'0@
M/2!S=6)S='(H)'1E>'0L(#$L("TQ*3L*"B`@("`@("`@+RH@5V]R9'=R87`N
M("HO"B`@("`@("`@)'1E>'0@/2!S=')?<F5P;&%C92@B7'0B+"`G("`@("`@
M("`G+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!S=')?<F5P;&%C92@G("`G
M+"`G("9N8G-P.R<L("1T97AT*3L*("`@("`@("`D=&5X="`]('-T<E]R97!L
M86-E*")<;B`B+"`B7&XF;F)S<#LB+"`D=&5X="D["B`@("`@("`@:68@*"1T
M97AT6S!=(#T]("<@)RD@>PH@("`@("`@("`@("`D=&5X="`]("<F;F)S<#LG
M("X@<W5B<W1R*"1T97AT+"`Q*3L*("`@("`@("!]"B`@("`@("`@)'1E>'0@
M/2!N;#)B<B@D=&5X="D["B`@("`@("`@)'1E>'0@/2`G/'`@8VQA<W,](F9I
M>&5D(CXG("X@)'1E>'0@+B`G/"]P/B<["@H@("`@("`@(')E='5R;B`D=&5X
M=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@34E-12!C;VYT
M96YT('1Y<&4@;V8@=&AE(')E;F1E<F5D(&-O;G1E;G0N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!C;VYT96YT('1Y<&4@;V8@=&AE(&]U
M='!U="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@
M("`@("`@<F5T=7)N("=T97AT+VAT;6P[(&-H87)S970])R`N($Y,4SHZ9V5T
M0VAA<G-E="@I.PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O34E-12]6:65W97(O96YR:6-H960N<&AP````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,C`Q,S$@,3`U,34T,S,W,S8@,#(S-C,P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B!4:&4@34E-15]6:65W97)?96YR:6-H960@8VQA<W,@<F5N9&5R<R!O
M=70@<&QA:6X@=&5X="!F<F]M"B`J(&5N<FEC:&5D(&-O;G1E;G0@=&%G<RP@
M86QA(%)&0R`Q.#DV+@H@*@H@*B!">2!21D,L('=E(&UU<W0@9&\@=&AE(&UI
M;FEM86P@8V]N9F]R;6%N8V4@;65A<W5R97,@;V8Z($$@;6EN:6UA;`H@*B!T
M97AT+V5N<FEC:&5D(&EM<&QE;65N=&%T:6]N(&ES(&]N92!T:&%T(&-O;G9E
M<G1S("(\/"(@=&\@(CPB+`H@*B!R96UO=F5S(&5V97)Y=&AI;F<@8F5T=V5E
M;B!A(#QP87)A;3X@8V]M;6%N9"!A;F0@=&AE(&YE>'0@8F%L86YC:6YG"B`J
M(#PO<&%R86T^(')E;6]V97,@86QL(&]T:&5R(&9O<FUA='1I;F<@8V]M;6%N
M9',@*&%L;"!T97AT(&5N8VQO<V5D"B`J(&EN(&%N9VQE(&)R86-K971S*2P@
M86YD(&]U='-I9&4@;V8@/&YO9FEL;#X@96YV:7)O;FUE;G1S(&-O;G9E<G1S
M"B`J(&%N>2!S97)I97,@;V8@;B!#4DQ&<R!T;R!N+3$@0U),1G,L(&%N9"!C
M;VYV97)T<R!A;GD@;&]N92!#4DQ&"B`J('!A:7)S('1O(%-004-%+@H@*@H@
M*B!792!D;VXG="!Q=6%L:69Y(&%S('=E(&1O;B=T(&-U<G)E;G1L>2!T<F%C
M:R!T:&4@/&YO9FEL;#X*("H@96YV:7)O;FUE;G0L('1H870@:7,@=V4@9&\@
M0U),1B!C;VYV97)S:6]N(&5V96X@:68@/&YO9FEL;#X@:7,*("H@<W!E8VEF
M:65D(&EN('1H92!T97AT+"!B=70@=V4G<F4@8VQO<V4@870@;&5A<W0N"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O96YR:6-H
M960N<&AP+'8@,2XR,RXQ,"XV(#(P,#8O,#$O,#$@,C$Z,C@Z,C4@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`Q+3(P,#8@17)I8R!2;W-T971T97(@
M/&5R:6,N<F]S=&5T=&5R0'!H>7-I8W,N=71E>&%S+F5D=3X*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($5R:6,@4F]S=&5T=&5R(#QE<FEC+G)O<W1E
M='1E<D!P:'ES:6-S+G5T97AA<RYE9'4^"B`J($!S:6YC92`@($AO<F1E(#(N
M,0H@*B!`<&%C:V%G92!(;W)D95]-24U%7U9I97=E<@H@*B\*8VQA<W,@34E-
M15]6:65W97)?96YR:6-H960@97AT96YD<R!-24U%7U9I97=E<B!["@H@("`@
M+RHJ"B`@("`@*B!296YD97(@;W5T('1H92!C=7)R96YT;'D@<V5T(&-O;G1E
M;G1S(&EN($A434P@9F]R;6%T+B!4:&4*("`@("`J("1M:6UE7W!A<G0@8VQA
M<W,@=F%R:6%B;&4@:&%S('1H92!I;F9O<FUA=&EO;B!T;R!R96YD97(@;W5T
M+`H@("`@("H@96YC87!S=6QA=&5D(&EN(&$@34E-15]087)T(&]B:F5C="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R*"D*("`@('L*("`@("`@("!I
M9B`H*"1T97AT(#T@)'1H:7,M/FUI;65?<&%R="T^9V5T0V]N=&5N=',H*2D@
M/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"@H@("`@("`@(&EF("AT<FEM*"1T97AT*2`]/2`G)RD@>PH@("`@("`@
M("`@("!R971U<FX@)'1E>'0["B`@("`@("`@?0H*("`@("`@("`O+R!792!A
M9&0@<W!A8V4@870@=&AE(&)E9VEN;FEN9R!A;F0@96YD(&]F('1H92!S=')I
M;F<@87,@:70@=VEL;`H@("`@("`@("\O(&UA:V4@<V]M92!R96=U;&%R(&5X
M<')E<W-I;VX@8VAE8VMS(&QA=&5R(&UU8V@@96%S:65R("AS;R!W90H@("`@
M("`@("\O(&1O;B=T(&AA=F4@=&\@=V]R<GD@86)O=70@<W1A<G0O96YD(&]F
M(&QI;F4@8VAA<F%C=&5R<RD*("`@("`@("`D=&5X="`]("<@)R`N("1T97AT
M("X@)R`G.PH*("`@("`@("`O+R!792!N965D('1O('!R97-E<G9E(#P\('1A
M9W,L('-O(&UA<"!T:&5M('1O(&%S8VEI(#$@;W(@87-C:6D@,C4U"B`@("`@
M("`@+R\@5V4@;6%K92!T:&4@87-S=6UP=&EO;B!H97)E('1H870@=&AE<F4@
M=V]U;&0@;F5V97(@8F4@86X@87-C:6D*("`@("`@("`O+R`Q(&EN(&%N(&5M
M86EL+"!W:&EC:"!M87D@;F]T(&)E('9A;&ED+"!B=70@<V5E;7,@<F5A<V]N
M86)L92XN+@H@("`@("`@("\O(&%S8VEI(#(U-2!W;W5L9"!W;W)K(&EF(&9O
M<B!S;VUE(')E87-O;B!Y;W4@9&]N)W0@;&EK92!A<V-I:2`Q"B`@("`@("`@
M+R\@87-C:6D@,"!D;V5S($Y/5"!S965M('1O('=O<FL@9F]R('1H:7,L('1H
M;W5G:"!))VT@;F]T('-U<F4@=VAY"B`@("`@("`@)'1E>'0@/2!S=')?<F5P
M;&%C92@G/#PG+"!C:'(H,2DL("1T97AT*3L*"B`@("`@("`@+R\@4F5M;W9E
M(&%N>2!U;G)E8V]G;FEZ960@=&%G<R!I;B!T:&4@=&5X="`H=FEA(%)&0R!M
M:6YI;6%L('-P96-S*0H@("`@("`@("\O(&%N>2!T86=S('=E(&IU<W0@9&]N
M)W0@=V%N="!T;R!I;7!L96UE;G0@8V%N(&%L<V\@8F4@<F5M;W9E9"!H97)E
M"B`@("`@("`@+R\@3F]T92!T:&%T('1H:7,@=VEL;"!R96UO=F4@86YY(&AT
M;6P@;&EN:W,L(&)U="!T:&ES(&ES(&EN=&5N9&5D"B`@("`@("`@)&EM<&QE
M;65N=&5D5&%G<R`]("<\<&%R86T^/&)O;&0^/&ET86QI8SX\=6YD97)L:6YE
M/CQF:7AE9#X\97AC97)P=#XG("X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)SQS;6%L;&5R/CQB:6=G97(^/&-E;G1E<CX\8V]L;W(^/&9O;G1F86UI
M;'D^)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("<\9FQU<VAL969T
M/CQF;'5S:')I9VAT/CQF;'5S:&)O=&@^/'!A<F%I;F1E;G0^)SL*("`@("`@
M("`O+R`D=6Y);7!L96UE;G1E9%1A9W,@/2`G/&YO9FEL;#X\;&%N9SXG.PH@
M("`@("`@("1T97AT(#T@<W1R:7!?=&%G<R@D=&5X="P@)&EM<&QE;65N=&5D
M5&%G<RD["@H@("`@("`@("\O(')E<W1O<F4@=&AE(#P\('1A9W,@87,@/"!T
M86=S(&YO=RXN+@H@("`@("`@("1T97AT(#T@<W1R7W)E<&QA8V4H8VAR*#$I
M+"`G/#PG+"`D=&5X="D["B`@("`@("`@+R\@)'1E>'0@/2!S=')?<F5P;&%C
M92AC:'(H,C4U*2P@)SPG+"`D=&5X="D["@H@("`@("`@("\O($=E="!C;VQO
M<B!P87)A;65T97)S(&EN=&\@82!M;W)E('5S96%B;&4@9F]R;6%T+@H@("`@
M("`@("1T97AT(#T@<')E9U]R97!L86-E*"<O/&-O;&]R/CQP87)A;3XH6UQD
M82UF02U&72LI+"A;7&1A+69!+49=*RDL*%M<9&$M9D$M1ETK*3Q<+W!A<F%M
M/B]5:7,G+"`G/&-O;&]R('(]7#$@9SU<,B!B/5PS/B<L("1T97AT*3L*("`@
M("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+SQC;VQO<CX\<&%R86T^*')E
M9'QB;'5E?&=R965N?'EE;&QO=WQC>6%N?&UA9V5N=&%\8FQA8VM\=VAI=&4I
M/%PO<&%R86T^+U5I<R<L("<\8V]L;W(@;CU<,3XG+"`D=&5X="D["@H@("`@
M("`@("\O($=E="!F;VYT(&9A;6EL>2!P87)A;65T97)S(&EN=&\@82!M;W)E
M('5S96%B;&4@9F]R;6%T+@H@("`@("`@("1T97AT(#T@<')E9U]R97!L86-E
M*"<O/&9O;G1F86UI;'D^/'!A<F%M/BA<=RLI/%PO<&%R86T^+U5I<R<L("<\
M9F]N=&9A;6EL>2!F/5PQ/B<L("1T97AT*3L*"B`@("`@("`@+R\@2G5S="!R
M96UO=F4@86YY(')E;6%I;FEN9R!P87)A;65T97)S("TM('=E('=O;B=T('5S
M90H@("`@("`@("\O('1H96TN($%N>2!T86=S('=I=&@@<&%R86UE=&5R<R!T
M:&%T('=E('=A;G0@=&\@:6UP;&5M96YT"B`@("`@("`@+R\@=VEL;"!H879E
M('1O(&-O;64@8F5F;W)E('1H:7,@4V]M961A>2!W92!H;W!E('1O('5S92!T
M:&5S90H@("`@("`@("\O('1A9W,@*&4N9RX@9F]R(#QC;VQO<CX\<&%R86T^
M('1A9W,I"B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\\<&%R86T^
M+BH\7"]P87)A;3XO56ES)RP@)R<L("1T97AT*3L*"B`@("`@("`@+R\@4VEN
M9VQE(&QI;F4@8G)E86MS(&)E8V]M92!S<&%C97,L(&1O=6)L92!L:6YE(&)R
M96%K<R!A<F4@80H@("`@("`@("\O(')E86P@8G)E86LN(%1H:7,@;F5E9',@
M=&\@9&\@/&YO9FEL;#X@=')A8VMI;F<@=&\@8F4*("`@("`@("`O+R!C;VUP
M;&EA;G0@8G5T('=E(&1O;B=T('=A;G0@=&\@9&5A;"!W:71H('-T871E(&%T
M('1H:7,*("`@("`@("`O+R!T:6UE+"!S;R!W92!F86ME(&ET('-O;64@9&%Y
M('=E('-H;W5L9"!R97=R:71E('1H:7,@=&\*("`@("`@("`O+R!H86YD;&4@
M/&YO9FEL;#X@8V]R<F5C=&QY+@H@("`@("`@("1T97AT(#T@<')E9U]R97!L
M86-E*"<O*%M>7&Y=*5QR7&XH6UY<<ETI+R<L("=<,2!<,B<L("1T97AT*3L*
M("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+RA<<EQN*5QR7&XO)RP@
M)UPQ)RP@)'1E>'0I.PH*("`@("`@("`O+R!792!T<GD@=&\@<')O=&5C="!A
M9V%I;G-T(&)A9"!S='5F9B!H97)E+@H@("`@("`@("1T97AT(#T@0&AT;6QS
M<&5C:6%L8VAA<G,H)'1E>'0L($5.5%]154]415,L("1T:&ES+3YM:6UE7W!A
M<G0M/F=E=$-H87)S970H*2D["@H@("`@("`@("\O($YO=R!C;VYV97)T('1H
M92!K;F]W;B!T86=S('1O(&AT;6PN(%1R>2!T;R!R96UO=F4@86YY('1A9PH@
M("`@("`@("\O('!A<F%M971E<G,@=&\@<W1O<"!P96]P;&4@9G)O;2!T<GEI
M;F<@=&\@<'5L;"!A(&9A<W0@;VYE"B`@("`@("`@)'1E>'0@/2!P<F5G7W)E
M<&QA8V4H)R\H/SPA)FQT.RDF;'0[8F]L9"XJ)F=T.R@N*BDF;'0[7"]B;VQD
M)F=T.R]5:7,G+"`G/'-P86X@<W1Y;&4](F9O;G0M=V5I9VAT.B!B;VQD(CY<
M,3PO<W!A;CXG+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA
M8V4H)R\H/SPA)FQT.RDF;'0[:71A;&EC+BHF9W0[*"XJ*29L=#M<+VET86QI
M8R9G=#LO56ES)RP@)SQS<&%N('-T>6QE/2)F;VYT+7-T>6QE.B!I=&%L:6,B
M/EPQ/"]S<&%N/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]('!R96=?<F5P
M;&%C92@G+R@_/"$F;'0[*29L=#MU;F1E<FQI;F4N*B9G=#LH+BHI)FQT.UPO
M=6YD97)L:6YE)F=T.R]5:7,G+"`G/'-P86X@<W1Y;&4](G1E>'0M9&5C;W)A
M=&EO;CH@=6YD97)L:6YE(CY<,3PO<W!A;CXG+"`D=&5X="D["B`@("`@("`@
M)'1E>'0@/2!P<F5G7W)E<&QA8V5?8V%L;&)A8VLH)R\H/SPA)FQT.RDF;'0[
M8V]L;W(@<CTH6UQD82UF02U&72LI(&<]*%M<9&$M9D$M1ETK*2!B/2A;7&1A
M+69!+49=*RDF9W0[*"XJ*29L=#M<+V-O;&]R)F=T.R]5:7,G+"!A<G)A>2@D
M=&AI<RP@)V-O;&]R:7IE)RDL("1T97AT*3L*("`@("`@("`D=&5X="`]('!R
M96=?<F5P;&%C92@G+R@_/"$F;'0[*29L=#MC;VQO<B!N/2AR961\8FQU97QG
M<F5E;GQY96QL;W=\8WEA;GQM86=E;G1A?&)L86-K?'=H:71E*29G=#LH+BHI
M)FQT.UPO8V]L;W(F9W0[+U5I<R<L("<\<W!A;B!S='EL93TB8V]L;W(Z(%PQ
M(CY<,CPO<W!A;CXG+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!P<F5G7W)E
M<&QA8V4H)R\H/SPA)FQT.RDF;'0[9F]N=&9A;6EL>29G=#LH+BHI)FQT.UPO
M9F]N=&9A;6EL>29G=#LO56ES)RP@)UPQ)RP@)'1E>'0I.PH@("`@("`@("1T
M97AT(#T@<')E9U]R97!L86-E*"<O*#\\(29L=#LI)FQT.V9O;G1F86UI;'D@
M9CTH7'<K*29G=#LH+BHI)FQT.UPO9F]N=&9A;6EL>29G=#LO56ES)RP@)SQS
M<&%N('-T>6QE/2)F;VYT+69A;6EL>3H@7#$B/EPR/"]S<&%N/B<L("1T97AT
M*3L*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+R@_/"$F;'0[*29L
M=#MS;6%L;&5R+BHF9W0[+U5I<R<L("<\<W!A;B!S='EL93TB9F]N="US:7IE
M.B!S;6%L;&5R(CXG+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!P<F5G7W)E
M<&QA8V4H)R\H/SPA)FQT.RDF;'0[7"]S;6%L;&5R)F=T.R]5:7,G+"`G/"]S
M<&%N/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G
M+R@_/"$F;'0[*29L=#MB:6=G97(N*B9G=#LO56ES)RP@)SQS<&%N('-T>6QE
M/2)F;VYT+7-I>F4Z(&QA<F=E<B(^)RP@)'1E>'0I.PH@("`@("`@("1T97AT
M(#T@<')E9U]R97!L86-E*"<O*#\\(29L=#LI)FQT.UPO8FEG9V5R)F=T.R]5
M:7,G+"`G/"]S<&%N/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]('!R96=?
M<F5P;&%C92@G+R@_/"$F;'0[*29L=#MF:7AE9"XJ)F=T.R@N*BDF;'0[7"]F
M:7AE9"9G=#LO56ES)RP@)SQF;VYT(&9A8V4](F9I>&5D(CY<,3PO9F]N=#XG
M+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H/SPA
M)FQT.RDF;'0[8V5N=&5R+BHF9W0[*"XJ*29L=#M<+V-E;G1E<B9G=#LO56ES
M)RP@)SQD:78@86QI9VX](F-E;G1E<B(^7#$\+V1I=CXG+"`D=&5X="D["B`@
M("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[9FQU
M<VAL969T+BHF9W0[*"XJ*29L=#M<+V9L=7-H;&5F="9G=#LO56ES)RP@)SQD
M:78@86QI9VX](FQE9G0B/EPQ/"]D:78^)RP@)'1E>'0I.PH@("`@("`@("1T
M97AT(#T@<')E9U]R97!L86-E*"<O*#\\(29L=#LI)FQT.V9L=7-H<FEG:'0N
M*B9G=#LH+BHI)FQT.UPO9FQU<VAR:6=H="9G=#LO56ES)RP@)SQD:78@86QI
M9VX](G)I9VAT(CY<,3PO9&EV/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]
M('!R96=?<F5P;&%C92@G+R@_/"$F;'0[*29L=#MF;'5S:&)O=&@N*B9G=#LH
M+BHI)FQT.UPO9FQU<VAB;W1H)F=T.R]5:7,G+"`G/&1I=B!A;&EG;CTB:G5S
M=&EF>2(^7#$\+V1I=CXG+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!P<F5G
M7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[<&%R86EN9&5N="XJ)F=T.R@N*BDF
M;'0[7"]P87)A:6YD96YT)F=T.R]5:7,G+"`G/&)L;V-K<75O=&4^7#$\+V)L
M;V-K<75O=&4^)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E9U]R97!L
M86-E*"<O*#\\(29L=#LI)FQT.V5X8V5R<'0N*B9G=#LH+BHI)FQT.UPO97AC
M97)P="9G=#LO56ES)RP@)SQB;&]C:W%U;W1E/EPQ/"]B;&]C:W%U;W1E/B<L
M("1T97AT*3L*"B`@("`@("`@+R\@4F5P;&%C92`\/"!W:71H(#P@;F]W("AF
M<F]M('1R86YS;&%T960@2%1-3"!F;W)M*2X*("`@("`@("`D=&5X="`]('-T
M<E]R97!L86-E*"<F;'0[)FQT.R<L("<F;'0[)RP@)'1E>'0I.PH*("`@("`@
M("`O+R!.;W<@=V4@<F5M;W9E('1H92!L96%D:6YG+W1R86EL:6YG('-P86-E
M('=E(&%D9&5D(&%T('1H90H@("`@("`@("\O('-T87)T+@H@("`@("`@("1T
M97AT(#T@<')E9U]R97!L86-E*"<O7B`H+BHI("0O<R<L("=<,2<L("1T97AT
M*3L*"B`@("`@("`@+R\@36%K92!54DQS(&-L:6-K86)L92X*("`@("`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+U1E>'0O1FEL=&5R+G!H<"<["B`@("`@("`@
M)'1E>'0@/2!497AT7T9I;'1E<CHZ9FEL=&5R*"1T97AT+"`G;&EN:W5R;',G
M+"!A<G)A>2@G8V%L;&)A8VLG(#T^("=(;W)D93HZ97AT97)N86Q5<FPG*2D[
M"@H@("`@("`@("\O(%=O<F1W<F%P("TM(&YO=&4@=&AI<R!C;W5L9"!I;7!A
M8W0@;VX@;W5R(&%B;W9E(%)&0PH@("`@("`@("\O(&-O;7!L:6%N8V4@*DE&
M*B!W92!H;VYO<F5D(&YO9FEL;"!T86=S("AW:&EC:"!W92!D;VXG=`H@("`@
M("`@("\O('EE="DN"B`@("`@("`@)'1E>'0@/2!S=')?<F5P;&%C92@B7'0B
M+"`G("`@("`@("`G+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!S=')?<F5P
M;&%C92@G("`G+"`G("9N8G-P.R<L("1T97AT*3L*("`@("`@("`D=&5X="`]
M('-T<E]R97!L86-E*")<;B`B+"`B7&XF;F)S<#LB+"`D=&5X="D["B`@("`@
M("`@:68@*"1T97AT6S!=(#T]("<@)RD@>PH@("`@("`@("`@("`D=&5X="`]
M("<F;F)S<#LG("X@<W5B<W1R*"1T97AT+"`Q*3L*("`@("`@("!]"B`@("`@
M("`@)'1E>'0@/2!N;#)B<B@D=&5X="D["B`@("`@("`@)'1E>'0@/2`G/'`@
M8VQA<W,](F9I>&5D(CXG("X@)'1E>'0@+B`G/"]P/B<["@H@("`@("`@(')E
M='5R;B`D=&5X=#L*("`@('T*"B`@("!F=6YC=&EO;B!C;VQO<FEZ92@D8V]L
M;W)S*0H@("`@>PH@("`@("`@(&9O<B`H)&D@/2`Q.R`D:2`\(#0[("1I*RLI
M('L*("`@("`@("`@("`@)&-O;&]R<ULD:5T@/2!S<')I;G1F*"<E,#)8)RP@
M<F]U;F0H:&5X9&5C*"1C;VQO<G-;)&E=*2`O(#(U-2DI.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@)SQS<&%N('-T>6QE/2)C;VQO<CH@(R<@+B`D8V]L
M;W)S6S%=("X@)&-O;&]R<ULR72`N("1C;VQO<G-;,UT@+B`G(CXG("X@)&-O
M;&]R<ULT72`N("<\+W-P86X^)SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;B!T:&4@34E-12!C;VYT96YT('1Y<&4@;V8@=&AE(')E;F1E<F5D(&-O
M;G1E;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C;VYT
M96YT('1Y<&4@;V8@=&AE(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=T97AT+VAT;6P[(&-H
M87)S970])R`N($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M34E-12]6:65W97(O;7-E>&-E;"YP:'``````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#,T-#`@,3`U,34T,S,W,S8@,#(S-3$S`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@
M34E-15]6:65W97)?;7-E>&-E;"!C;&%S<R!R96YD97)S(&]U="!-:6-R;W-O
M9G0@17AC96P*("H@9&]C=6UE;G1S(&EN($A434P@9F]R;6%T(&)Y('5S:6YG
M('1H92!X;$AT;6P@<&%C:V%G92X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]M<V5X8V5L+G!H<"QV(#$N,C`N,3`N-R`R,#`V
M+S`Q+S`Q(#(Q.C(X.C(U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY
M.2TR,#`V($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!!;FEL($UA9&AA=F%P961D>2`\
M86YI;$!R96-O:6PN;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A
M8VMA9V4@2&]R9&5?34E-15]6:65W97(*("HO"F-L87-S($U)345?5FEE=V5R
M7VUS97AC96P@97AT96YD<R!-24U%7U9I97=E<B!["@H@("`@+RHJ"B`@("`@
M*B!296YD97(@;W5T('1H92!C=7)R96YT;'D@9&%T82!U<VEN9R!X;&AT;6PN
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N>2!P87)A
M;7,@=&AI<R!6:65W97(@;6%Y(&YE960N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!R96YD97)E9"!D871A+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!R96YD97(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M9VQO8F%L("1M:6UE7V1R:79E<G,["@H@("`@("`@("\J($-H96-K('1O(&UA
M:V4@<W5R92!T:&4@<')O9W)A;2!A8W1U86QL>2!E>&ES=',N("HO"B`@("`@
M("`@:68@*"%F:6QE7V5X:7-T<R@D;6EM95]D<FEV97)S6R=H;W)D92==6R=M
M<V5X8V5L)UU;)VQO8V%T:6]N)UTI*2!["B`@("`@("`@("`@(')E='5R;B`G
M/'!R93XG("X@<W!R:6YT9BA?*")4:&4@<')O9W)A;2!U<V5D('1O('9I97<@
M=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T
M96TN(BDL("1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)VUS97AC96PG75LG;&]C
M871I;VXG72D@+B`G/"]P<F4^)SL*("`@("`@("!]"@H@("`@("`@("1D871A
M(#T@)R<["B`@("`@("`@)'1M<%]X;',@/2!(;W)D93HZ9V5T5&5M<$9I;&4H
M)VAO<F1E7VUS97AC96PG*3L*"B`@("`@("`@)&9H(#T@9F]P96XH)'1M<%]X
M;',L("=W)RD["B`@("`@("`@9G=R:71E*"1F:"P@)'1H:7,M/FUI;65?<&%R
M="T^9V5T0V]N=&5N=',H*2D["B`@("`@("`@9F-L;W-E*"1F:"D["@H@("`@
M("`@("1F:"`]('!O<&5N*"1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)VUS97AC
M96PG75LG;&]C871I;VXG72`N("(@+6YH("1T;7!?>&QS(#(^)C$B+"`G<B<I
M.PH@("`@("`@('=H:6QE("@H)')C(#T@9F=E=',H)&9H+"`X,3DR*2DI('L*
M("`@("`@("`@("`@)&1A=&$@+CT@)')C.PH@("`@("`@('T*("`@("`@("!P
M8VQO<V4H)&9H*3L*"B`@("`@("`@<F5T=7)N("1D871A.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N('1H92!-24U%(&-O;G1E;G0@='EP92!O9B!T
M:&4@<F5N9&5R960@8V]N=&5N="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE(&-O;G1E;G0@='EP92!O9B!T:&4@;W5T<'5T+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@("!R971U<FX@
M)W1E>'0O:'1M;#L@8VAA<G-E=#TG("X@3DQ3.CIG971#:&%R<V5T*"D["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W-I;7!L92YP:'``````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`Q,S4W(#$P-3$U-#,S-S,V(#`R,S,U,0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@5&AE($U)345?
M5FEE=V5R7W-I;7!L92!C;&%S<R!R96YD97)S(&]U="!P;&%I;B!T97AT('=I
M=&AO=70@86YY"B`J(&UO9&EF:6-A=&EO;G,N"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<VEM<&QE+G!H<"QV(#$N,2XV+C4@
M,C`P-B\P,2\P,2`R,3HR.#HR-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#0M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`:&]R9&4N;W)G
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z
M(#QS;'5S87)Z0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J
M($!P86-K86=E($AO<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S<R!-24U%7U9I
M97=E<E]S:6UP;&4@97AT96YD<R!-24U%7U9I97=E<B!["@H@("`@+RHJ"B`@
M("`@*B!2971U<FX@=&AE($U)344@='EP92!O9B!T:&4@<F5N9&5R960@8V]N
M=&5N="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@34E-12UT>7!E
M(&]F('1H92!O=71P=70@8V]N=&5N="X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=T97AT+W!L86EN)SL*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+TU)344O4&%R="YP:'``````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,3(S,C$Q(#$P-3$U-#,S-S,W(#`R,34R,``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`H*<F5Q=6ER95]O
M;F-E("=(;W)D92]3=')I;F<N<&AP)SL*<F5Q=6ER95]O;F-E(&1I<FYA;64H
M7U]&24Q%7U\I("X@)R\N+B]-24U%+G!H<"<["@HO*BH*("H@5&AE(&-H87)A
M8W1E<BAS*2!U<V5D(&EN=&5R;F%L;'D@9F]R($5/3',N"B`J+PID969I;F4H
M)TU)345?4$%25%]%3TPG+"`B7&XB*3L*"B\J*@H@*B!4:&4@8VAA<F%C=&5R
M('-T<FEN9R!D97-I9VYA=&5D(&)Y(%)&0W,@.#(R+S(P-#4@=&\@9&5S:6=N
M871E($5/3',@:6X@34E-10H@*B!M97-S86=E<RX*("HO"F1E9FEN92@G34E-
M15]005)47U)&0U]%3TPG+"`B7')<;B(I.PH*+RH@1&5F875L="!-24U%('!A
M<F%M971E<G,N("HO"@HO*BH*("H@5&AE(&1E9F%U;'0@34E-12!C:&%R86-T
M97(@<V5T+@H@*B\*9&5F:6YE*"=-24U%7T1%1D%53%1?0TA!4E-%5"<L("=U
M<RUA<V-I:2<I.PH*+RHJ"B`J(%1H92!D969A=6QT($U)344@9&5S8W)I<'1I
M;VXN"B`J+PID969I;F4H)TU)345?1$5&055,5%]$15-#4DE05$E/3B<L(%\H
M(G5N;F%M960B*2D["@HO*BH*("H@5&AE(&1E9F%U;'0@34E-12!D:7-P;W-I
M=&EO;BX*("HO"F1E9FEN92@G34E-15]$149!54Q47T1)4U!/4TE424].)RP@
M)VEN;&EN92<I.PH*+RHJ"B`J(%1H92!D969A=6QT($U)344@96YC;V1I;F<N
M"B`J+PID969I;F4H)TU)345?1$5&055,5%]%3D-/1$E.1R<L("<W8FET)RD[
M"@HO*BH*("H@5&AE($U)345?4&%R=#HZ(&-L87-S('!R;W9I9&5S(&$@=W)A
M<'!E<B!A<F]U;F0@34E-12!P87)T<R!A;F0@;65T:&]D<PH@*B!F;W(@9&5A
M;&EN9R!W:71H('1H96TN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TU)344O
M34E-12]087)T+G!H<"QV(#$N,3<W+C0N,C`@,C`P-B\P,R\P.2`R,3HU.3HS
M,2!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K
M($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,C`P
M,BTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R
M861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("!-:6-H865L
M(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J($!S
M:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]-24U%"B`J+PIC
M;&%S<R!-24U%7U!A<G0@>PH*("`@("\J*@H@("`@("H@5&AE('1Y<&4@*&5X
M+CH@=&5X="D@;V8@=&AI<R!P87)T+@H@("`@("H@4&5R(%)&0R`R,#0U+"!T
M:&4@9&5F875L="!I<R`G87!P;&EC871I;VXG+@H@("`@("H*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W1Y<&4@/2`G87!P;&EC871I
M;VXG.PH*("`@("\J*@H@("`@("H@5&AE('-U8G1Y<&4@*&5X+CH@<&QA:6XI
M(&]F('1H:7,@<&%R="X*("`@("`J(%!E<B!21D,@,C`T-2P@=&AE(&1E9F%U
M;'0@:7,@)V]C=&5T+7-T<F5A;2<N"B`@("`@*@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1?<W5B='EP92`]("=O8W1E="US=')E86TG
M.PH*("`@("\J*@H@("`@("H@5&AE(&)O9'D@;V8@=&AE('!A<G0N"B`@("`@
M*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?8V]N=&5N
M=',@/2`G)SL*"B`@("`O*BH*("`@("`J(%1H92!D97-I<F5D('1R86YS9F5R
M(&5N8V]D:6YG(&]F('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)%]T<F%N<V9E<D5N8V]D:6YG(#T@34E-
M15]$149!54Q47T5.0T]$24Y'.PH*("`@("\J*@H@("`@("H@5&AE(&-U<G)E
M;G0@=')A;G-F97(@96YC;V1I;F<@;V8@=&AE(&-O;G1E;G1S(&]F('1H:7,@
M<&%R="X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)%]C=7)R96YT16YC;V1I;F<@/2!N=6QL.PH*("`@("\J*@H@("`@("H@
M4VAO=6QD('1H92!M97-S86=E(&)E(&5N8V]D960@=FEA(#<M8FET/PH@("`@
M("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]E;F-O
M9&4W8FET(#T@=')U93L*"B`@("`O*BH*("`@("`J(%1H92!D97-C<FEP=&EO
M;B!O9B!T:&ES('!A<G0N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@
M("`J+PH@("`@=F%R("1?9&5S8W)I<'1I;VX@/2`G)SL*"B`@("`O*BH*("`@
M("`J(%1H92!D:7-P;W-I=&EO;B!O9B!T:&ES('!A<G0@*&EN;&EN92!O<B!A
M='1A8VAM96YT*2X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO
M"B`@("!V87(@)%]D:7-P;W-I=&EO;B`]($U)345?1$5&055,5%]$25-03U-)
M5$E/3CL*"B`@("`O*BH*("`@("`J(%1H92!D:7-P;W-I=&EO;B!P87)A;65T
M97)S(&]F('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B\*("`@('9A<B`D7V1I<W!O<VET:6]N4&%R86UE=&5R<R`](&%R<F%Y
M*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@8V]N=&5N="!T>7!E('!A<F%M971E
M<G,@;V8@=&AI<R!P87)T+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1?8V]N=&5N=%1Y<&5087)A;65T97)S(#T@87)R87DH
M*3L*"B`@("`O*BH*("`@("`J(%1H92!S=6)P87)T<R!O9B!T:&ES('!A<G0N
M"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P
M87)T<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!);F9O<FUA=&EO;B]3
M=&%T:7-T:6-S(&]N('1H92!S=6)P87)T+@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1?:6YF;W)M871I;VX@/2!A<G)A>2@I
M.PH*("`@("\J*@H@("`@("H@5&AE(&QI<W0@;V8@0TE$<R!F;W(@=&AI<R!P
M87)T+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R
M("1?8VED<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@34E-12!)
M1"!O9B!T:&ES('!A<G0N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@
M("`J+PH@("`@=F%R("1?;6EM96ED(#T@;G5L;#L*"B`@("`O*BH*("`@("`J
M(%1H92!S97%U96YC92!T;R!U<V4@87,@14],(&9O<B!T:&ES('!A<G0N"B`@
M("`@*B!4:&4@9&5F875L="!I<R!C=7)R96YT;'D@=&\@;W5T<'5T('1H92!%
M3TP@<V5Q=65N8V4@:6YT97)N86QL>2!A<PH@("`@("H@:G5S="`B7&XB(&EN
M<W1E860@;V8@=&AE(&-A;F]N:6-A;"`B7')<;B(@<F5Q=6ER960@:6X@4D9#
M(#@R,B`F(#(P-#4N"B`@("`@*B!4;R!B92!21D,@8V]M<&QA:6YT+"!T:&4@
M9G5L;"`\0U(^/$Q&/B!%3TP@8V]M8FEN871I;VX@<VAO=6QD(&)E('5S960*
M("`@("`J('=H96X@<V5N9&EN9R!A(&UE<W-A9V4N"B`@("`@*B!)="!I<R!N
M;W0@8W)U8VEA;"!H97)E('-I;F-E('1H92!02%`O4$5!4B!M86EL:6YG(&9U
M;F-T:6]N<R!W:6QL(&AA;F1L90H@("`@("H@=&AE($5/3"!D971A:6QS+@H@
M("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V5O
M;"`]($U)345?4$%25%]%3TP["@H@("`@+RHJ"B`@("`@*B!);G1E<FYA;"!C
M;&%S<R!F;&%G<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*
M("`@('9A<B`D7V9L86=S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%!A
M<G0@+3X@240@;6%P<&EN9R!C86-H92X*("`@("`J"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D7VED;6%P(#T@87)R87DH*3L*"B`@("`O
M*BH*("`@("`J(%5N:7%U92!-24U%7U!A<G0@8F]U;F1A<GD@<W1R:6YG+@H@
M("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V)O
M=6YD87)Y(#T@;G5L;#L*"B`@("`O*BH*("`@("`J($1E9F%U;'0@=F%L=64@
M9F]R('1H:7,@4&%R="=S('-I>F4N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E
M9V5R"B`@("`@*B\*("`@('9A<B`D7V)Y=&5S(#T@,#L*"B`@("`O*BH*("`@
M("`J(%1H92!C;VYT96YT+4E$(&9O<B!T:&ES('!A<G0N"B`@("`@*@H@("`@
M("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?8V]N=&5N=&ED(#T@
M;G5L;#L*"B`@("`O*BH*("`@("`J($U)345?4&%R="!C;VYS=')U8W1O<BX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1M:6UE='EP92`@("`@5&AE
M(&-O;G1E;G0@='EP92!O9B!T:&4@<&%R="X*("`@("`J($!P87)A;2!S=')I
M;F<@)&-O;G1E;G1S("`@("!4:&4@8F]D>2!O9B!T:&4@<&%R="X*("`@("`J
M($!P87)A;2!S=')I;F<@)&-H87)S970@("`@("!4:&4@8VAA<F%C=&5R('-E
M="!O9B!T:&4@<&%R="X*("`@("`J($!P87)A;2!S=')I;F<@)&1I<W!O<VET
M:6]N("!4:&4@8V]N=&5N="!D:7-P;W-I=&EO;B!O9B!T:&4@<&%R="X*("`@
M("`J($!P87)A;2!S=')I;F<@)&5N8V]D:6YG("`@("!4:&4@8V]N=&5N="!E
M;F-O9&EN9R!O9B!T:&4@8V]N=&5N=',N"B`@("`@*B\*("`@(&9U;F-T:6]N
M($U)345?4&%R="@D;6EM971Y<&4@/2!N=6QL+"`D8V]N=&5N=',@/2!N=6QL
M+`H@("`@("`@("`@("`@("`@("`@("`@("1C:&%R<V5T(#T@34E-15]$149!
M54Q47T-(05)3150L("1D:7-P;W-I=&EO;B`](&YU;&PL"B`@("`@("`@("`@
M("`@("`@("`@("`@)&5N8V]D:6YG(#T@;G5L;"D*("`@('L*("`@("`@("`O
M*B!#<F5A=&4@=&AE('5N:7%U92!-24U%7U!A<G0@8F]U;F1A<GD@<W1R:6YG
M+B`J+PH@("`@("`@("1T:&ES+3Y?9V5N97)A=&5";W5N9&%R>2@I.PH*("`@
M("`@("`O*B!4:&4@8VAA<F%C=&5R('-E="!S:&]U;&0@86QW87ES(&)E('-E
M="P@979E;B!I9B!W92!A<F4@9&5A;&EN9PH@("`@("`@("`J('=I=&@@0V]N
M=&5N="U4>7!E<R!O=&AE<B!T:&%N('1E>'0O*BX@*B\*("`@("`@("`D=&AI
M<RT^<V5T0VAA<G-E="@D8VAA<G-E="D["@H@("`@("`@(&EF("@A:7-?;G5L
M;"@D;6EM971Y<&4I*2!["B`@("`@("`@("`@("1T:&ES+3YS9714>7!E*"1M
M:6UE='EP92D["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-?;G5L;"@D8V]N
M=&5N=',I*2!["B`@("`@("`@("`@("1T:&ES+3YS971#;VYT96YT<R@D8V]N
M=&5N=',L("1E;F-O9&EN9RD["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-?
M;G5L;"@D9&ES<&]S:71I;VXI*2!["B`@("`@("`@("`@("1T:&ES+3YS971$
M:7-P;W-I=&EO;B@D9&ES<&]S:71I;VXI.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E="!T:&4@8V]N=&5N="UD:7-P;W-I=&EO;B!O9B!T
M:&ES('!A<G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&ES<&]S
M:71I;VX@(%1H92!C;VYT96YT+61I<W!O<VET:6]N('1O('-E="`H:6YL:6YE
M(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@871T86-H
M;65N="DN"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$1I<W!O<VET:6]N*"1D
M:7-P;W-I=&EO;BD*("`@('L*("`@("`@("`D9&ES<&]S:71I;VX@/2!3=')I
M;F<Z.FQO=V5R*"1D:7-P;W-I=&EO;BD["@H@("`@("`@(&EF("@H)&1I<W!O
M<VET:6]N(#T]("=I;FQI;F4G*2!\?"`H)&1I<W!O<VET:6]N(#T]("=A='1A
M8VAM96YT)RDI('L*("`@("`@("`@("`@)'1H:7,M/E]D:7-P;W-I=&EO;B`]
M("1D:7-P;W-I=&EO;CL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!'970@=&AE(&-O;G1E;G0M9&ES<&]S:71I;VX@;V8@=&AI<R!P87)T+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<&%R="=S(&-O;G1E
M;G0M9&ES<&]S:71I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1I<W!O
M<VET:6]N*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]D:7-P;W-I
M=&EO;CL*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@;F%M92!O9B!T
M:&ES('!A<G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92!4
M:&4@;F%M92!T;R!S970N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$YA;64H
M)&YA;64I"B`@("!["B`@("`@("`@)'1H:7,M/G-E=$-O;G1E;G14>7!E4&%R
M86UE=&5R*"=N86UE)RP@)&YA;64I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1V5T('1H92!N86UE(&]F('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D9&5C;V1E("`@34E-12!D96-O9&4@9&5S8W)I<'1I;VX_
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&5F875L="`@268@=&AE(&YA;64@
M<&%R86UE=&5R(&1O97-N)W0@97AI<W0L('-H;W5L9"!W90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@('5S92!T:&4@9&5F875L="!N86UE(&9R
M;VT@=&AE(&1E<V-R:7!T:6]N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@<&%R86UE=&5R/PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@;F%M92!O9B!T:&4@<&%R="X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T3F%M92@D9&5C;V1E(#T@9F%L<V4L("1D969A=6QT(#T@9F%L<V4I"B`@
M("!["B`@("`@("`@)&YA;64@/2`D=&AI<RT^9V5T0V]N=&5N=%1Y<&5087)A
M;65T97(H)VYA;64G*3L*"B`@("`@("`@:68@*"1D969A=6QT("8F(&5M<'1Y
M*"1N86UE*2D@>PH@("`@("`@("`@("`D;F%M92`]('!R96=?<F5P;&%C92@G
M?%Q7?"<L("=?)RP@)'1H:7,M/F=E=$1E<V-R:7!T:6]N*&9A;'-E+"!T<G5E
M*2D["B`@("`@("`@?0H*("`@("`@("!I9B`H)&1E8V]D92D@>PH@("`@("`@
M("`@("!R971U<FX@=')I;2A-24U%.CID96-O9&4H)&YA;64I*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)&YA;64["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!B;V1Y(&-O;G1E;G1S
M(&]F('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C
M;VYT96YT<R`@5&AE('!A<G0@8F]D>2X*("`@("`J($!P87)A;2!S=')I;F<@
M)&5N8V]D:6YG("!4:&4@8W5R<F5N="!E;F-O9&EN9R!O9B!T:&4@8V]N=&5N
M=',N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$-O;G1E;G1S*"1C;VYT96YT
M<RP@)&5N8V]D:6YG(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^7V-O
M;G1E;G1S(#T@)&-O;G1E;G1S.PH@("`@("`@("1T:&ES+3Y?9FQA9W-;)V-O
M;G1E;G1S4V5T)UT@/2!T<G5E.PH@("`@("`@("1T:&ES+3Y?8W5R<F5N=$5N
M8V]D:6YG(#T@*&ES7VYU;&PH)&5N8V]D:6YG*2D@/R`D=&AI<RT^9V5T0W5R
M<F5N=$5N8V]D:6YG*"D@.B!-24U%.CIE;F-O9&EN9R@D96YC;V1I;F<L($U)
M345?4U1224Y'*3L*("`@('T*"B`@("`O*BH*("`@("`J($%D9"!T;R!T:&4@
M8F]D>2!C;VYT96YT<R!O9B!T:&ES('!A<G0N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D8V]N=&5N=',@(%1H92!C;VYT96YT<R!T;R!A<'!E;F0@
M=&\@=&AE(&-U<G)E;G0@<&%R=`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@(&)O9'DN"B`@("`@*B!`<&%R86T@<W1R:6YG("1E;F-O9&EN9R`@
M5&AE(&-U<G)E;G0@96YC;V1I;F<@;V8@=&AE(&-O;G1E;G1S+B!)9B!N;W0*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!S<&5C:69I960L('=I
M;&P@=')Y('1O(&%U=&\@9&5T97)M:6YE('1H90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@(&5N8V]D:6YG+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!A<'!E;F1#;VYT96YT<R@D8V]N=&5N=',L("1E;F-O9&EN9R`](&YU;&PI
M"B`@("!["B`@("`@("`@)'1H:7,M/G-E=$-O;G1E;G1S*"1T:&ES+3Y?8V]N
M=&5N=',@+B`D8V]N=&5N=',L("1E;F-O9&EN9RD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#;&5A<G,@=&AE(&)O9'D@8V]N=&5N=',@;V8@=&AI<R!P87)T
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;&5A<D-O;G1E;G1S*"D*("`@('L*
M("`@("`@("`D=&AI<RT^7V-O;G1E;G1S(#T@)R<["B`@("`@("`@)'1H:7,M
M/E]F;&%G<ULG8V]N=&5N='-3970G72`](&9A;'-E.PH@("`@("`@("1T:&ES
M+3Y?8W5R<F5N=$5N8V]D:6YG(#T@;G5L;#L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;B!T:&4@8F]D>2!O9B!T:&4@<&%R="X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE(')A=R!B;V1Y(&]F('1H92!P87)T+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971#;VYT96YT<R@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?8V]N=&5N=',["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!C;VYT96YT<R!I;B!S=')I8W0@4D9#(#@R,B`F
M(#(P-#4@;W5T<'5T("T@;F%M96QY+"!A;&P*("`@("`J(&YE=VQI;F5S(&5N
M9"!W:71H('1H92!C86YO;FEC86P@/$-2/CQ,1CX@<V5Q=65N8V4N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!E;G1I<F4@34E-12!P87)T
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971#86YO;FEC86Q#;VYT96YT<R@I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YR97!L86-E14],*"1T:&ES
M+3Y?8V]N=&5N=',L($U)345?4$%25%]21D-?14],*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%1R86YS9F5R(&5N8V]D92!T:&4@8V]N=&5N=',@*'1O('1H
M92!T<F%N<V9E<B!E;F-O9&EN9R!I9&5N=&EF:65D('9I80H@("`@("H@9V5T
M5')A;G-F97)%;F-O9&EN9R@I*2!A;F0@<V5T(&%S('1H92!P87)T)W,@;F5W
M(&-O;G1E;G1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!T<F%N<V9E<D5N8V]D
M94-O;G1E;G1S*"D*("`@('L*("`@("`@("`D8V]N=&5N=',@/2`D=&AI<RT^
M=')A;G-F97)%;F-O9&4H*3L*("`@("`@("`D=&AI<RT^7V-U<G)E;G1%;F-O
M9&EN9R`]("1T:&ES+3Y?9FQA9W-;)VQA<W14<F%N<V9E<D5N8V]D92==.PH@
M("`@("`@("1T:&ES+3YS971#;VYT96YT<R@D8V]N=&5N=',L("1T:&ES+3Y?
M8W5R<F5N=$5N8V]D:6YG*3L*("`@("`@("`D=&AI<RT^<V5T5')A;G-F97)%
M;F-O9&EN9R@D=&AI<RT^7V-U<G)E;G1%;F-O9&EN9RD["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!4<F%N<V9E<B!D96-O9&4@=&AE(&-O;G1E;G1S(&%N9"!S
M970@=&AE;2!A<R!T:&4@;F5W(&-O;G1E;G1S+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!T<F%N<V9E<D1E8V]D94-O;G1E;G1S*"D*("`@('L*("`@("`@("`D
M8V]N=&5N=',@/2`D=&AI<RT^=')A;G-F97)$96-O9&4H*3L*("`@("`@("`D
M=&AI<RT^7V-U<G)E;G1%;F-O9&EN9R`]("1T:&ES+3Y?9FQA9W-;)VQA<W14
M<F%N<V9E<D1E8V]D92==.PH@("`@("`@("1T:&ES+3YS9714<F%N<V9E<D5N
M8V]D:6YG*"1T:&ES+3Y?8W5R<F5N=$5N8V]D:6YG*3L*"B`@("`@("`@+RH@
M1&]N)W0@<V5T(&-O;G1E;G1S(&EF('1H97D@87)E(&5M<'1Y+"!B96-A=7-E
M('1H:7,@=VEL;"!D;R!S='5F9@H@("`@("`@("`@(&QI:V4@<F5S970@=&AE
M(&EN=&5R;F%L(&)Y=&5S(&9I96QD+"!E=F5N('1H;W5G:"!W92!S:&]U;&1N
M)W0@9&\*("`@("`@("`@("!T:&%T("AT:&4@=7-E<B!H87,@=&AE:7(@<F5A
M<V]N<R!T;R!S970@=&AE(&)Y=&5S(&9I96QD('1O(&$*("`@("`@("`@("!N
M;VXM>F5R;R!V86QU92!W:71H;W5T('!U='1I;F<@=&AE(&-O;G1E;G1S(&EN
M=&\@=&AI<R!P87)T+B`J+PH@("`@("`@(&EF("AS=')L96XH)&-O;G1E;G1S
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T0V]N=&5N=',H)&-O;G1E;G1S
M+"`D=&AI<RT^7V-U<G)E;G1%;F-O9&EN9RD["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@4V5T('1H92!M:6UE='EP92!O9B!T:&ES('!A<G0N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;6EM971Y<&4@(%1H92!M
M:6UE='EP92!T;R!S970@*&5X+CH@=&5X="]P;&%I;BDN"B`@("`@*B\*("`@
M(&9U;F-T:6]N('-E=%1Y<&4H)&UI;65T>7!E*0H@("`@>PH@("`@("`@("\J
M(%)&0R`R,#0U.B!!;GD@96YT:71Y('=I=&@@=6YR96-O9VYI>F5D(&5N8V]D
M:6YG(&UU<W0@8F4@=')E871E9`H@("`@("`@("`@(&%S(&EF(&ET(&AA<R!A
M($-O;G1E;G0M5'EP92!O9B`B87!P;&EC871I;VXO;V-T970M<W1R96%M(@H@
M("`@("`@("`@(')E9V%R9&QE<W,@;V8@=VAA="!T:&4@0V]N=&5N="U4>7!E
M(&9I96QD(&%C='5A;&QY('-A>7,N("HO"B`@("`@("`@:68@*"1T:&ES+3Y?
M=')A;G-F97)%;F-O9&EN9R`]/2`G>"UU;FMN;W=N)RD@>PH@("`@("`@("`@
M("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`O*B!3970@=&AE("=S9714
M>7!E)R!F;&%G+B`J+PH@("`@("`@("1T:&ES+3Y?9FQA9W-;)W-E=%1Y<&4G
M72`]('1R=64["@H@("`@("`@(&QI<W0H)'1H:7,M/E]T>7!E+"`D=&AI<RT^
M7W-U8G1Y<&4I(#T@97AP;&]D92@G+R<L(%-T<FEN9SHZ;&]W97(H)&UI;65T
M>7!E*2D["B`@("`@("`@:68@*"@D='EP92`]($U)344Z.G1Y<&4H)'1H:7,M
M/E]T>7!E+"!-24U%7U-44DE.1RDI*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M='EP92`]("1T>7!E.PH*("`@("`@("`@("`@+RH@4V5T('1H92!B;W5N9&%R
M>2!S=')I;F<@9F]R("=M=6QT:7!A<G0O*B<@<&%R=',N("HO"B`@("`@("`@
M("`@(&EF("@D='EP92`]/2`G;75L=&EP87)T)RD@>PH@("`@("`@("`@("`@
M("`@:68@*"$D=&AI<RT^9V5T0V]N=&5N=%1Y<&5087)A;65T97(H)V)O=6YD
M87)Y)RDI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T0V]N=&5N
M=%1Y<&5087)A;65T97(H)V)O=6YD87)Y)RP@)'1H:7,M/E]G96YE<F%T94)O
M=6YD87)Y*"DI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/F-L96%R0V]N=&5N=%1Y<&50
M87)A;65T97(H)V)O=6YD87)Y)RD["B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7W1Y<&4@/2`G>"UU;FMN;W=N
M)SL*("`@("`@("`@("`@)'1H:7,M/F-L96%R0V]N=&5N=%1Y<&5087)A;65T
M97(H)V)O=6YD87)Y)RD["B`@("`@("`@?0H@("`@?0H*("`@("`O*BH*("`@
M("`@*B!'970@=&AE(&9U;&P@34E-12!#;VYT96YT+51Y<&4@;V8@=&AI<R!P
M87)T+@H@("`@("`J"B`@("`@("H@0'!A<F%M(&)O;VQE86X@)&-H87)S970@
M($%P<&5N9"!C:&%R86-T97(@<V5T(&EN9F]R;6%T:6]N('1O('1H92!E;F0@
M;V8*("`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&-O;G1E
M;G0@='EP92!I9B!T:&ES(&ES(&$@=&5X="\J('!A<G0N"B`@("`@("H*("`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&UI;65T>7!E(&]F('1H:7,@<&%R
M=`H@("`@("`J("`@("`@("`@("`@("`@("`H97@N.B!T97AT+W!L86EN.R!C
M:&%R<V5T/75S+6%S8VEI*2X*("`@("`@*B\*("`@("!F=6YC=&EO;B!G9714
M>7!E*"1C:&%R<V5T(#T@9F%L<V4I"B`@("`@>PH@("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3Y?='EP92D@?'P@(6ES<V5T*"1T:&ES+3Y?<W5B='EP92DI
M('L*("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@?0H@("`@
M("`@("`D<'1Y<&4@/2`D=&AI<RT^9V5T4')I;6%R>51Y<&4H*3L*("`@("`@
M("`@)'1Y<&4@/2`D<'1Y<&4@+B`G+R<@+B`D=&AI<RT^9V5T4W5B5'EP92@I
M.PH@("`@("`@("!I9B`H)&-H87)S970@)B8@*"1P='EP92`]/2`G=&5X="<I
M*2!["B`@("`@("`@("`@("`D='EP92`N/2`G.R!C:&%R<V5T/2<@+B`D=&AI
M<RT^9V5T0VAA<G-E="@I.PH@("`@("`@("!]"B`@("`@("`@(')E='5R;B`D
M='EP93L*("`@("!]"@H@("`@+RHJ"B`@("`@*B!)9B!T:&4@<W5B='EP92!O
M9B!A($U)344@<&%R="!I<R!U;G)E8V]G;FEZ960@8GD@86X@87!P;&EC871I
M;VXL('1H90H@("`@("H@9&5F875L="!T>7!E('-H;W5L9"!B92!U<V5D(&EN
M<W1E860@*%-E92!21D,@,C`T-BDN("!4:&ES(&UE=&AO9`H@("`@("H@<F5T
M=7)N<R!T:&4@9&5F875L="!S=6)T>7!E(&9O<B!A('!A<G1I8W5L87(@<')I
M;6%R>2!-24U%(%1Y<&4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!D969A=6QT(&UI;65T>7!E(&]F('1H:7,@<&%R="`H97@N.B!T97AT
M+W!L86EN*2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&5F875L=%1Y<&4H
M*0H@("`@>PH@("`@("`@('-W:71C:"`H)'1H:7,M/F=E=%!R:6UA<GE4>7!E
M*"DI('L*("`@("`@("!C87-E("=T97AT)SH*("`@("`@("`@("`@+RH@4D9#
M(#(P-#8@*#0N,2XT*3H@=&5X="!P87)T<R!D969A=6QT('1O('1E>'0O<&QA
M:6XN("HO"B`@("`@("`@("`@(')E='5R;B`G=&5X="]P;&%I;B<["@H@("`@
M("`@(&-A<V4@)VUU;'1I<&%R="<Z"B`@("`@("`@("`@("\J(%)&0R`R,#0V
M("@U+C$N,RDZ(&UU;'1I<&%R="!P87)T<R!D969A=6QT('1O(&UU;'1I<&%R
M="]M:7AE9"X@*B\*("`@("`@("`@("`@<F5T=7)N("=M=6QT:7!A<G0O;6EX
M960G.PH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`O*B!21D,@,C`T
M-B`H-"XR+"`T+C,L(#0N-"P@-"XU+C,L(#4N,BXT*3H@86QL(&]T:&5R<R!D
M969A=6QT('1O"B`@("`@("`@("`@("`@(&%P<&QI8V%T:6]N+V]C=&5T+7-T
M<F5A;2X@*B\*("`@("`@("`@("`@<F5T=7)N("=A<'!L:6-A=&EO;B]O8W1E
M="US=')E86TG.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=E
M="!T:&4@<')I;6%R>2!T>7!E(&]F('1H:7,@<&%R="X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE('!R:6UA<GD@34E-12!T>7!E(&]F('1H
M:7,@<&%R="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4')I;6%R>51Y<&4H
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W1Y<&4["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!'970@=&AE('-U8G1Y<&4@;V8@=&AI<R!P87)T+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@34E-12!S=6)T>7!E
M(&]F('1H:7,@<&%R="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4W5B5'EP
M92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<W5B='EP93L*("`@
M('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@8VAA<F%C=&5R('-E="!O9B!T
M:&ES('!A<G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VAA<G-E
M="`@5&AE(&-H87)A8W1E<B!S970@;V8@=&AI<R!P87)T+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!S971#:&%R<V5T*"1C:&%R<V5T*0H@("`@>PH@("`@("`@
M("1T:&ES+3YS971#;VYT96YT5'EP95!A<F%M971E<B@G8VAA<G-E="<L("1C
M:&%R<V5T*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@8VAA<F%C
M=&5R('-E="!T;R!U<V4@9F]R(&]F('1H:7,@<&%R="X@(%)E='5R;G,@82!C
M:&%R<V5T(&9O<@H@("`@("H@86QL('1Y<&5S("AN;W0@:G5S="`G=&5X="\J
M)RD@<VEN8V4@=V4@=7-E('1H:7,@8VAA<G-E="!T;R!D971E<FUI;F4*("`@
M("`J(&AO=R!T;R!E;F-O9&4@=&5X="!I;B!-24U%(&AE861E<G,N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C:&%R86-T97(@<V5T(&]F
M('1H:7,@<&%R="X@(%)E='5R;G,@;G5L;"!I9B!T:&5R90H@("`@("H@("`@
M("`@("`@("`@("`@(&ES(&YO(&-H87)A8W1E<B!S970N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$-H87)S970H*0H@("`@>PH@("`@("`@("1C:&%R<V5T
M(#T@)'1H:7,M/F=E=$-O;G1E;G14>7!E4&%R86UE=&5R*"=C:&%R<V5T)RD[
M"B`@("`@("`@<F5T=7)N("AE;7!T>2@D8VAA<G-E="DI(#\@;G5L;"`Z("1C
M:&%R<V5T.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!D97-C<FEP
M=&EO;B!O9B!T:&ES('!A<G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9&5S8W)I<'1I;VX@(%1H92!D97-C<FEP=&EO;B!O9B!T:&ES('!A<G0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$1E<V-R:7!T:6]N*"1D97-C<FEP
M=&EO;BD*("`@('L*("`@("`@("`D=&AI<RT^7V1E<V-R:7!T:6]N(#T@34E-
M13HZ96YC;V1E*"1D97-C<FEP=&EO;BP@)'1H:7,M/F=E=$-H87)S970H*2D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE(&1E<V-R:7!T:6]N(&]F
M('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&5C
M;V1E("`@34E-12!D96-O9&4@9&5S8W)I<'1I;VX_"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`D9&5F875L="`@268@=&AE(&YA;64@<&%R86UE=&5R(&1O97-N
M)W0@97AI<W0L('-H;W5L9"!W90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@('5S92!T:&4@9&5F875L="!N86UE(&9R;VT@=&AE(&1E<V-R:7!T
M:6]N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@<&%R86UE=&5R
M/PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9&5S8W)I<'1I
M;VX@;V8@=&AI<R!P87)T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971$97-C
M<FEP=&EO;B@D9&5C;V1E(#T@9F%L<V4L("1D969A=6QT(#T@9F%L<V4I"B`@
M("!["B`@("`@("`@)&1E<V,@/2`D=&AI<RT^7V1E<V-R:7!T:6]N.PH*("`@
M("`@("!I9B`H)&1E9F%U;'0@)B8@96UP='DH)&1E<V,I*2!["B`@("`@("`@
M("`@("1D97-C(#T@)'1H:7,M/F=E=$YA;64H*3L*("`@("`@("`@("`@:68@
M*&5M<'1Y*"1D97-C*2D@>PH@("`@("`@("`@("`@("`@)&1E<V,@/2!-24U%
M7T1%1D%53%1?1$530U))4%1)3TX["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(&EF("@D9&5C;V1E*2!["B`@("`@("`@("`@(')E='5R;B!-
M24U%.CID96-O9&4H)&1E<V,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B`D9&5S8SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3970@=&AE('1R86YS9F5R(&5N8V]D:6YG('1O('5S92!F;W(@=&AI
M<R!P87)T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&5N8V]D:6YG
M("!4:&4@=')A;G-F97(@96YC;V1I;F<@=&\@=7-E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!S9714<F%N<V9E<D5N8V]D:6YG*"1E;F-O9&EN9RD*("`@('L*
M("`@("`@("!I9B`H*"1M:6UE7V5N8V]D:6YG(#T@34E-13HZ96YC;V1I;F<H
M)&5N8V]D:6YG+"!-24U%7U-44DE.1RDI*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?=')A;G-F97)%;F-O9&EN9R`]("1M:6UE7V5N8V]D:6YG.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("\J(%)&0R`R,#0U.B!!;GD@96YT:71Y
M('=I=&@@=6YR96-O9VYI>F5D(&5N8V]D:6YG(&UU<W0@8F4@=')E871E9`H@
M("`@("`@("`@("`@("!A<R!I9B!I="!H87,@82!#;VYT96YT+51Y<&4@;V8@
M(F%P<&QI8V%T:6]N+V]C=&5T+7-T<F5A;2(*("`@("`@("`@("`@("`@<F5G
M87)D;&5S<R!O9B!W:&%T('1H92!#;VYT96YT+51Y<&4@9FEE;&0@86-T=6%L
M;'D@<V%Y<RX@*B\*("`@("`@("`@("`@)'1H:7,M/G-E=%1Y<&4H)V%P<&QI
M8V%T:6]N+V]C=&5T+7-T<F5A;2<I.PH@("`@("`@("`@("`D=&AI<RT^7W1R
M86YS9F5R16YC;V1I;F<@/2`G>"UU;FMN;W=N)SL*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!9&0@82!-24U%('-U8G!A<G0N"B`@("`@*@H@
M("`@("H@0'!A<F%M($U)345?4&%R="`D;6EM95]P87)T("!!9&0@82!-24U%
M7U!A<G0@<W5B<&%R="!T;R!T:&4@8W5R<F5N=`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!-24U%7U!A<G0N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1I;F1E>"`@("`@("`@(%1H92!I;F1E>"!O9B!T:&4@861D960@
M34E-15]087)T+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1087)T*"1M:6UE
M7W!A<G0L("1I;F1E>"`](&YU;&PI"B`@("!["B`@("`@("`@+RH@061D('1H
M92!P87)T('1O('1H92!P87)T<R!L:7-T+B`J+PH@("`@("`@(&EF("AI<U]N
M=6QL*"1I;F1E>"DI('L*("`@("`@("`@("`@96YD*"1T:&ES+3Y?<&%R=',I
M.PH@("`@("`@("`@("`D:60@/2!K97DH)'1H:7,M/E]P87)T<RD@*R`Q.PH@
M("`@("`@("`@("`D<'1R(#T@)B1T:&ES+3Y?<&%R=',["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'!T<B`]("8D=&AI<RT^7W!A<G1&:6YD*"1I
M;F1E>"P@)'1H:7,M/E]P87)T<RP@=')U92D["B`@("`@("`@("`@(&EF("@H
M)'!O<R`]('-T<G)P;W,H)&EN9&5X+"`G+B<I*2D@>PH@("`@("`@("`@("`@
M("`@)&ED(#T@<W5B<W1R*"1I;F1E>"P@)'!O<R`K(#$I.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&ED(#T@)&EN9&5X.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!3970@=&AE($U)344@
M240@:68@:70@:&%S(&YO="!A;')E861Y(&)E96X@<V5T+B`J+PH@("`@("`@
M(&EF("@D;6EM95]P87)T+3YG971-24U%260H*2`]/3T@;G5L;"D@>PH@("`@
M("`@("`@("`D;6EM95]P87)T+3YS971-24U%260H)&ED*3L*("`@("`@("!]
M"@H@("`@("`@("\J(%-T;W)E('1H92!P87)T(&YO=RX@*B\*("`@("`@("`D
M<'1R6R1I9%T@/2`D;6EM95]P87)T.PH*("`@("`@("`O*B!#;&5A<B!T:&4@
M240@+3X@4&%R="!M87!P:6YG(&-A8VAE+B`J+PH@("`@("`@("1T:&ES+3Y?
M:61M87`@/2!A<G)A>2@I.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T(&$@
M;&ES="!O9B!A;&P@34E-12!S=6)P87)T<RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("!!;B!A<G)A>2!O9B!T:&4@34E-15]087)T('-U8G!A<G1S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971087)T<R@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?<&%R=',["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971R:65V92!A('-P96-I9FEC($U)344@<&%R="X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE($U)345?4&%R="!)1"!S=')I;F<N
M"B`@("`@*@H@("`@("H@0')E='5R;B!-24U%7U!A<G0@(%1H92!-24U%7U!A
M<G0@<F5Q=65S=&5D+"!O<B!F86QS92!I9B!T:&4@<&%R=`H@("`@("H@("`@
M("`@("`@("`@("`@("`@(&1O97-N)W0@97AI<W0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%!A<G0H)&ED*0H@("`@>PH@("`@("`@("1M:6UE:60@/2`D
M=&AI<RT^9V5T34E-14ED*"D["@H@("`@("`@("\J(%1H:7,@=VEL;"!C;VYV
M97)T("<C+C`G('1O('-I;7!L>2`G(R<L('=H:6-H(&ES(&AO=R!T:&4@<&%R
M="!I<PH@("`@("`@("`J(&EN=&5R;F%L;'D@<W1O<F5D+B`J+PH@("`@("`@
M("1S96%R8VA?:60@/2`D:60["B`@("`@("`@:68@*"@D<W1R(#T@<W1R<F-H
M<B@D:60L("<N)RDI("8F"B`@("`@("`@("`@("@D<W1R(#T]("<N,"<I*2![
M"B`@("`@("`@("`@("1S96%R8VA?:60@/2!S=6)S='(H)'-E87)C:%]I9"P@
M,"P@+3(I.PH@("`@("`@('T*"B`@("`@("`@+RH@4F5T=7)N('1H:7,@<&%R
M="!I9CH*("`@("`@("`@("`Q*2!4:&5R92!I<R!O;FQY(&]N92!P87)T("AE
M+F<N('1H92!-24U%($E$(&ES(#`L(&]R('1H90H@("`@("`@("`@("`@($U)
M344@240@:7,@,2!A;F0@=&AE<F4@87)E(&YO('-U8G!A<G1S+@H@("`@("`@
M("`@(#(I("1I9"!M871C:&5S('1H:7,@<&%R=',@34E-12!)1"X@*B\*("`@
M("`@("!I9B`H*"1S96%R8VA?:60@/3T@,"D@?'P*("`@("`@("`@("`@*"@D
M<V5A<F-H7VED(#T](#$I("8F("%C;W5N="@D=&AI<RT^7W!A<G1S*2D@?'P*
M("`@("`@("`@("`@*"%E;7!T>2@D;6EM96ED*2`F)B`H)'-E87)C:%]I9"`]
M/2`D;6EM96ED*2DI('L*("`@("`@("`@("`@)'!A<G0@/2`D=&AI<SL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<&%R="`]("1T:&ES+3Y?<&%R
M=$9I;F0H)&ED+"`D=&AI<RT^7W!A<G1S*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("@D<&%R="`F)@H@("`@("`@("`@("`H)'-E87)C:%]I9"`A/2`D:60I
M("8F"B`@("`@("`@("`@("@D<&%R="T^9V5T5'EP92@I(#T]("=M97-S86=E
M+W)F8S@R,B<I*2!["B`@("`@("`@("`@("1R971?<&%R="`](%5T:6PZ.F-L
M;VYE3V)J96-T*"1P87)T*3L*("`@("`@("`@("`@)')E=%]P87)T+3Y?<&%R
M=',@/2!A<G)A>2@I.PH@("`@("`@("`@("!R971U<FX@)')E=%]P87)T.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1P87)T.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5M;W9E(&$@34E-15]087)T('-U8G!A<G0N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D:60@(%1H92!-24U%(%!A<G0@=&\@9&5L
M971E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F5087)T*"1I9"D*("`@
M('L*("`@("`@("!I9B`H*"1P='(@/2`F)'1H:7,M/E]P87)T1FEN9"@D:60L
M("1T:&ES+3Y?<&%R=',I*2D@>PH@("`@("`@("`@("!U;G-E="@D<'1R*3L*
M("`@("`@("`@("`@)'1H:7,M/E]I9&UA<"`](&%R<F%Y*"D["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@06QT97(@82!C=7)R96YT($U)344@
M<W5B<&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@("`@
M("`@("`@(%1H92!-24U%(%!A<G0@240@=&\@86QT97(N"B`@("`@*B!`<&%R
M86T@34E-15]087)T("1M:6UE7W!A<G0@(%1H92!-24U%(%!A<G0@=&\@<W1O
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%L=&5R4&%R="@D:60L("1M:6UE
M7W!A<G0I"B`@("!["B`@("`@("`@:68@*"@D<'1R(#T@)B1T:&ES+3Y?<&%R
M=$9I;F0H)&ED+"`D=&AI<RT^7W!A<G1S*2DI('L*("`@("`@("`@("`@)'!T
M<B`]("1M:6UE7W!A<G0["B`@("`@("`@("`@("1T:&ES+3Y?:61M87`@/2!A
M<G)A>2@I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($9U;F-T
M:6]N('5S960@=&\@9FEN9"!A('-P96-I9FEC($U)344@4&%R="!B>2!)1"X*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1I9"`@("`@("`@(%1H92!-24U%7U!A<G0@240@<W1R
M:6YG+@H@("`@("H@0'!A<F%M(&%R<F%Y("8D<&%R=',@("`@("!!(&QI<W0@
M;V8@34E-15]087)T(&]B:F5C=',N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M<F5T87)R87D@(%)E='5R;B!A('!O:6YT97(@=&\@=&AE(&%R<F%Y('1H870@
M<W1O<F5S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("AW;W5L
M9"!S=&]R92D@=&AE('!A<G0@<F%T:&5R('1H86X@=&AE('!A<G0*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:71S96QF/PH@("`@("HO"B`@
M("!F=6YC=&EO;B`F7W!A<G1&:6YD*"1I9"P@)B1P87)T<RP@)')E=&%R<F%Y
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@+RH@4&]I;G1E<G,@9&]N)W0@<&5R
M<VES="!T:')O=6=H('-E<W-I;VYS.R!T:&5R969O<F4L('=E(&UU<W0@;6%K
M90H@("`@("`@("`J('-U<F4@=&AA="!T:&4@261-87`@:7,@9&5S=')O>65D
M(&%T('1H92!E;F0@;V8@96%C:"!R97%U97-T+@H@("`@("`@("`J($AO=R!C
M86X@=V4@9&\@=&AI<S\@5V4@8VAE8VL@=&\@<V5E(&EF("1?:61M87`@8V]N
M=&%I;G,@86X@87)R87D*("`@("`@("`@*B!O9B!-24U%7U!A<G1S(&]R(&%N
M(&%R<F%Y(&]F(&%R<F%Y<RX@*B\*("`@("`@("`D8VAE8VL@/2!R97-E="@D
M=&AI<RT^7VED;6%P*3L*("`@("`@("!I9B`H96UP='DH)&-H96-K*2!\?"`A
M:7-?82@D8VAE8VLL("=-24U%7U!A<G0G*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^7VED;6%P(#T@87)R87DH*3L*("`@("`@("`@("`@)'1H:7,M/E]G96YE
M<F%T94ED36%P*"1T:&ES+3Y?<&%R=',I.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"1R971A<G)A>2D@>PH@("`@("`@("`@("!I9B`H)'!O<R`]('-T<G)P
M;W,H)&ED+"`G+B<I*2!["B`@("`@("`@("`@("`@("`D:60@/2!S=6)S='(H
M)&ED+"`P+"`D<&]S*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D<&%R=',["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VED;6%P6R1I9%TI*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7VED;6%P6R1I9%T["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)'!A<G0@/2!F86QS93L*("`@("`@("`@
M("`@<F5T=7)N("1P87)T.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($=E;F5R871E<R!A(&UA<'!I;F<@;V8@34E-15]087)T<R!W:71H('1H
M96ER($U)344@241S+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`F)'!A<G1S("!!;B!A<G)A>2!O
M9B!-24U%7U!A<G1S('1O(&UA<"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E
M;F5R871E261-87`H)B1P87)T<RD*("`@('L*("`@("`@("!I9B`H(65M<'1Y
M*"1P87)T<RDI('L*("`@("`@("`@("`@9F]R96%C:"`H87)R87E?:V5Y<R@D
M<&%R=',I(&%S("1K97DI('L*("`@("`@("`@("`@("`@("1P='(@/2`F)'!A
M<G1S6R1K97E=.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]I9&UA<%LD<'1R
M+3YG971-24U%260H*5T@/2`F)'!T<CL*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?9V5N97)A=&5)9$UA<"@D<'1R+3Y?<&%R=',I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@061D(&EN9F]R;6%T
M:6]N(&%B;W5T('1H92!-24U%7U!A<G0N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;&%B96P@(%1H92!I;F9O<FUA=&EO;B!L86)E;"X*("`@("`J
M($!P87)A;2!M:7AE9"`D9&%T82`@("!4:&4@:6YF;W)M871I;VX@=&\@<W1O
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$EN9F]R;6%T:6]N*"1L86)E
M;"P@)&1A=&$I"B`@("!["B`@("`@("`@)'1H:7,M/E]I;F9O<FUA=&EO;ELD
M;&%B96Q=(#T@)&1A=&$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V
M92!I;F9O<FUA=&EO;B!A8F]U="!T:&4@34E-15]087)T+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&QA8F5L("!4:&4@:6YF;W)M871I;VX@;&%B
M96PN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&EN9F]R;6%T
M:6]N(')E<75E<W1E9"X*("`@("`J("`@("`@("`@("`@("`@(%)E='5R;G,@
M9F%L<V4@:68@)&QA8F5L(&ES(&YO="!S970N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$EN9F]R;6%T:6]N*"1L86)E;"D*("`@('L*("`@("`@("!R971U
M<FX@*&ES<V5T*"1T:&ES+3Y?:6YF;W)M871I;VY;)&QA8F5L72DI(#\@)'1H
M:7,M/E]I;F9O<FUA=&EO;ELD;&%B96Q=(#H@9F%L<V4["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!9&0@82!D:7-P;W-I=&EO;B!P87)A;65T97(@=&\@=&AI
M<R!P87)T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&QA8F5L("!4
M:&4@9&ES<&]S:71I;VX@<&%R86UE=&5R(&QA8F5L+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D9&%T82`@(%1H92!D:7-P;W-I=&EO;B!P87)A;65T97(@9&%T
M82X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T1&ES<&]S:71I;VY087)A;65T
M97(H)&QA8F5L+"`D9&%T82D*("`@('L*("`@("`@("`D=&AI<RT^7V1I<W!O
M<VET:6]N4&%R86UE=&5R<ULD;&%B96Q=(#T@)&1A=&$["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!'970@82!D:7-P;W-I=&EO;B!P87)A;65T97(@9G)O;2!T
M:&ES('!A<G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;&%B96P@
M(%1H92!D:7-P;W-I=&EO;B!P87)A;65T97(@;&%B96PN"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!D871A(')E<75E<W1E9"X*("`@("`J
M("`@("`@("`@("`@("`@("!2971U<FYS(&9A;'-E(&EF("1L86)E;"!I<R!N
M;W0@<V5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971$:7-P;W-I=&EO;E!A
M<F%M971E<B@D;&%B96PI"B`@("!["B`@("`@("`@<F5T=7)N("AI<W-E="@D
M=&AI<RT^7V1I<W!O<VET:6]N4&%R86UE=&5R<ULD;&%B96Q=*2D@/R`D=&AI
M<RT^7V1I<W!O<VET:6]N4&%R86UE=&5R<ULD;&%B96Q=(#H@9F%L<V4["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!'970@86QL('!A<F%M971E<G,@9G)O;2!T
M:&4@0V]N=&5N="U$:7-P;W-I=&EO;B!H96%D97(N"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@06X@87)R87D@;V8@86QL('1H92!P87)A;65T97)S
M"B`@("`@*B`@("`@("`@("`@("`@("!2971U<FYS('1H92!E;7!T>2!A<G)A
M>2!I9B!N;R!P87)A;65T97)S('-E="X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T06QL1&ES<&]S:71I;VY087)A;65T97)S*"D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]D:7-P;W-I=&EO;E!A<F%M971E<G,["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!!9&0@82!C;VYT96YT('1Y<&4@<&%R86UE=&5R('1O
M('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1L86)E
M;"`@5&AE(&1I<W!O<VET:6]N('!A<F%M971E<B!L86)E;"X*("`@("`J($!P
M87)A;2!S=')I;F<@)&1A=&$@("!4:&4@9&ES<&]S:71I;VX@<&%R86UE=&5R
M(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$-O;G1E;G14>7!E4&%R
M86UE=&5R*"1L86)E;"P@)&1A=&$I"B`@("!["B`@("`@("`@)'1H:7,M/E]C
M;VYT96YT5'EP95!A<F%M971E<G-;)&QA8F5L72`]("1D871A.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0VQE87)S(&$@8V]N=&5N="!T>7!E('!A<F%M971E
M<B!F<F]M('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1L86)E;"`@5&AE(&1I<W!O<VET:6]N('!A<F%M971E<B!L86)E;"X*("`@
M("`J($!P87)A;2!S=')I;F<@)&1A=&$@("!4:&4@9&ES<&]S:71I;VX@<&%R
M86UE=&5R(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L96%R0V]N=&5N
M=%1Y<&5087)A;65T97(H)&QA8F5L*0H@("`@>PH@("`@("`@('5N<V5T*"1T
M:&ES+3Y?8V]N=&5N=%1Y<&5087)A;65T97)S6R1L86)E;%TI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1V5T(&$@8V]N=&5N="!T>7!E('!A<F%M971E<B!F
M<F]M('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1L
M86)E;"`@5&AE(&-O;G1E;G0@='EP92!P87)A;65T97(@;&%B96PN"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!D871A(')E<75E<W1E9"X*
M("`@("`J("`@("`@("`@("`@("`@("!2971U<FYS(&9A;'-E(&EF("1L86)E
M;"!I<R!N;W0@<V5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971#;VYT96YT
M5'EP95!A<F%M971E<B@D;&%B96PI"B`@("!["B`@("`@("`@<F5T=7)N("AI
M<W-E="@D=&AI<RT^7V-O;G1E;G14>7!E4&%R86UE=&5R<ULD;&%B96Q=*2D@
M/R`D=&AI<RT^7V-O;G1E;G14>7!E4&%R86UE=&5R<ULD;&%B96Q=(#H@9F%L
M<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@86QL('!A<F%M971E<G,@
M9G)O;2!T:&4@0V]N=&5N="U4>7!E(&AE861E<BX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!O9B!A;&P@=&AE('!A<F%M971E<G,*
M("`@("`J("`@("`@("`@("`@("`@(%)E='5R;G,@=&AE(&5M<'1Y(&%R<F%Y
M(&EF(&YO('!A<F%M971E<G,@<V5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971!;&Q#;VYT96YT5'EP95!A<F%M971E<G,H*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7V-O;G1E;G14>7!E4&%R86UE=&5R<SL*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E=',@82!N97<@<W1R:6YG('1O('5S92!F;W(@14],
M<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1E;VP@(%1H92!S=')I
M;F<@=&\@=7-E(&9O<B!%3TQS+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971%
M3TPH)&5O;"D*("`@('L*("`@("`@("`D=&AI<RT^7V5O;"`]("1E;VP["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE('-T<FEN9R!T;R!U<V4@9F]R
M($5/3',N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!S=')I
M;F<@=&\@=7-E(&9O<B!%3TQS+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971%
M3TPH*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V5O;#L*("`@('T*
M"B`@("`O*BH*("`@("`J($%D9"!T:&4@87!P<F]P<FEA=&4@34E-12!H96%D
M97)S(&9O<B!T:&ES('!A<G0@=&\@86X@97AI<W1I;F<@87)R87DN"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("1H96%D97)S("!!;B!A<G)A>2!O9B!A
M;GD@;W1H97(@:&5A9&5R<R!F;W(@=&AE('!A<G0N"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@5&AE(&AE861E<G,L('=I=&@@=&AE($U)344@:&5A
M9&5R<R!A9&1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@:&5A9&5R*"1H96%D
M97)S(#T@87)R87DH*2D*("`@('L*("`@("`@("`D96]L(#T@)'1H:7,M/F=E
M=$5/3"@I.PH@("`@("`@("1P='EP92`]("1T:&ES+3YG9710<FEM87)Y5'EP
M92@I.PH@("`@("`@("1S='EP92`]("1T:&ES+3YG9713=6)4>7!E*"D["@H@
M("`@("`@("\J($=E="!T:&4@8VAA<F%C=&5R('-E="!F;W(@=&AI<R!P87)T
M+B`J+PH@("`@("`@("1C:&%R<V5T(#T@)'1H:7,M/F=E=$-H87)S970H*3L*
M"B`@("`@("`@+RH@1V5T('1H92!#;VYT96YT+51Y<&4@+2!T:&ES(&ES($%,
M5T%94R!R97%U:7)E9"X@*B\*("`@("`@("`D8W1Y<&4@/2`D=&AI<RT^9V5T
M5'EP92AT<G5E*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^9V5T06QL0V]N
M=&5N=%1Y<&5087)A;65T97)S*"D@87,@)&ME>2`]/B`D=F%L=64I('L*("`@
M("`@("`@("`@+RH@4VMI<"!T:&4@8VAA<G-E="!K97D@<VEN8V4@=&AA="!W
M;W5L9"!H879E(&%L<F5A9'D@8F5E;@H@("`@("`@("`@("`@*B!A9&1E9"!T
M;R`D8W1Y<&4@8GD@9V5T5'EP92@I+B`J+PH@("`@("`@("`@("!I9B`H)&ME
M>2`]/2`G8VAA<G-E="<I('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1C='EP92`N/2`G.R`G("X@)&ME
M>2`N("<](B<@+B!S=')?<F5P;&%C92@G(B<L("=<(B<L($U)344Z.F5N8V]D
M92@D=F%L=64L("1C:&%R<V5T*2D@+B`G(B<["B`@("`@("`@?0H@("`@("`@
M("1H96%D97)S6R=#;VYT96YT+51Y<&4G72`]($U)344Z.G=R87!(96%D97)S
M*"=#;VYT96YT+51Y<&4G+"`D8W1Y<&4L("1E;VPI.PH*("`@("`@("`O*B!'
M970@=&AE(&1E<V-R:7!T:6]N+"!I9B!A;GDN("HO"B`@("`@("`@:68@*"@D
M9&5S8W)I<"`]("1T:&ES+3YG971$97-C<FEP=&EO;B@I*2D@>PH@("`@("`@
M("`@("`D:&5A9&5R<ULG0V]N=&5N="U$97-C<FEP=&EO;B==(#T@34E-13HZ
M=W)A<$AE861E<G,H)T-O;G1E;G0M1&5S8W)I<'1I;VXG+"!-24U%.CIE;F-O
M9&4H)&1E<V-R:7`L("1C:&%R<V5T*2P@)&5O;"D["B`@("`@("`@?0H*("`@
M("`@("`O*B!21D,@,C`T-2!;-%T@+2!M97-S86=E+W)F8S@R,B!A;F0@;65S
M<V%G92]P87)T:6%L(')E<75I<F4@=&AE"B`@("`@("`@("`@34E-12U697)S
M:6]N(&AE861E<B!O;FQY(&EF('1H97D@=&AE;7-E;'9E<R!C;&%I;2!T;R!B
M92!-24U%"B`@("`@("`@("`@8V]M<&QI86YT+B`J+PH@("`@("`@(&EF("@H
M)'!T>7!E(#T]("=M97-S86=E)RD@)B8*("`@("`@("`@("`@*"@D<W1Y<&4@
M/3T@)W)F8S@R,B<I('Q\("@D<W1Y<&4@/3T@)W!A<G1I86PG*2D@)B8*("`@
M("`@("`@("`@*'-T<G!O<R@D=&AI<RT^7V-O;G1E;G1S+"`G34E-12U697)S
M:6]N.B`Q+C`G*2`A/3T@9F%L<V4I*2!["B`@("`@("`@("`@("1H96%D97)S
M6R=-24U%+59E<G-I;VXG72`]("<Q+C`G.PH@("`@("`@('T*"B`@("`@("`@
M+RH@;65S<V%G92\J('!A<G1S(')E<75I<F4@;F\@861D:71I;VYA;"!H96%D
M97(@:6YF;W)M871I;VXN("HO"B`@("`@("`@:68@*"1P='EP92`]/2`G;65S
M<V%G92<I('L*("`@("`@("`@("`@<F5T=7)N("1H96%D97)S.PH@("`@("`@
M('T*"B`@("`@("`@+RH@1&]N)W0@<VAO=R!#;VYT96YT+41I<W!O<VET:6]N
M(&9O<B!M=6QT:7!A<G0@;65S<V%G97,@=6YL97-S"B`@("`@("`@("`@=&AE
M<F4@:7,@82!N86UE('!A<F%M971E<BX@*B\*("`@("`@("`D;F%M92`]("1T
M:&ES+3YG971.86UE*"D["B`@("`@("`@:68@*"@D<'1Y<&4@(3T@)VUU;'1I
M<&%R="<I('Q\("%E;7!T>2@D;F%M92DI('L*("`@("`@("`@("`@)&1I<W`@
M/2`D=&AI<RT^9V5T1&ES<&]S:71I;VXH*3L*"B`@("`@("`@("`@("\J($%D
M9"!A;GD@9&ES<&]S:71I;VX@<&%R86UE=&5R(&EN9F]R;6%T:6]N+"!I9B!A
M=F%I;&%B;&4N("HO"B`@("`@("`@("`@(&EF("@A96UP='DH)&YA;64I*2![
M"B`@("`@("`@("`@("`@("`D9&ES<"`N/2`G.R`G("X@)V9I;&5N86UE/2(G
M("X@34E-13HZ96YC;V1E*"1N86UE+"`D8VAA<G-E="D@+B`G(B<["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1H96%D97)S6R=#;VYT96YT+41I<W!O
M<VET:6]N)UT@/2!-24U%.CIW<F%P2&5A9&5R<R@G0V]N=&5N="U$:7-P;W-I
M=&EO;B<L("1D:7-P+"`D96]L*3L*("`@("`@("!]"@H@("`@("`@("\J($%D
M9"!T<F%N<V9E<B!E;F-O9&EN9R!I;F9O<FUA=&EO;BX@*B\*("`@("`@("`D
M:&5A9&5R<ULG0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9R==(#T@)'1H:7,M
M/F=E=%1R86YS9F5R16YC;V1I;F<H*3L*"B`@("`@("`@+RH@061D(&-O;G1E
M;G0@240@:6YF;W)M871I;VXN("HO"B`@("`@("`@:68@*"%I<U]N=6QL*"1T
M:&ES+3Y?8V]N=&5N=&ED*2D@>PH@("`@("`@("`@("`D:&5A9&5R<ULG0V]N
M=&5N="U)1"==(#T@)'1H:7,M/E]C;VYT96YT:60["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)&AE861E<G,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FX@=&AE(&5N=&ER92!P87)T(&EN($U)344@9F]R;6%T+B!);F-L=61E
M<R!H96%D97)S(&]N(')E<75E<W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O
M;VQE86X@)&AE861E<G,@($EN8VQU9&4@=&AE($U)344@:&5A9&5R<S\*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($U)344@<W1R:6YG+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!T;U-T<FEN9R@D:&5A9&5R<R`]('1R=64I
M"B`@("!["B`@("`@("`@)&5O;"`]("1T:&ES+3YG971%3TPH*3L*("`@("`@
M("`D<'1Y<&4@/2`D=&AI<RT^9V5T4')I;6%R>51Y<&4H*3L*"B`@("`@("`@
M:68@*"1H96%D97)S*2!["B`@("`@("`@("`@("1T97AT(#T@)R<["B`@("`@
M("`@("`@(&9O<F5A8V@@*"1T:&ES+3YH96%D97(H*2!A<R`D:V5Y(#T^("1V
M86PI('L*("`@("`@("`@("`@("`@("1T97AT("X]("1K97D@+B`G.B`G("X@
M)'9A;"`N("1E;VP["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1E>'0@
M+CT@)&5O;#L*("`@("`@("!]"@H@("`@("`@("\J($%N>2!I;F9O<FUA=&EO
M;B!A8F]U="!A(&UE<W-A9V4O*B!I<R!E;6)E9&1E9"!I;B!T:&4@;65S<V%G
M90H@("`@("`@("`@(&-O;G1E;G1S('1H96US96QF+B!3:6UP;'D@;W5T<'5T
M('1H92!C;VYT96YT<R!O9B!T:&4@<&%R=`H@("`@("`@("`@(&1I<F5C=&QY
M(&%N9"!R971U<FXN("HO"B`@("`@("`@:68@*"1P='EP92`]/2`G;65S<V%G
M92<I('L*("`@("`@("`@("`@:68@*&ES<V5T*"1T97AT*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1T97AT("X@)'1H:7,M/E]C;VYT96YT<SL*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7V-O;G1E;G1S.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!I9B`H:7-S970H)'1E>'0I*2!["B`@("`@("`@("`@("1T97AT("X]("1T
M:&ES+3YT<F%N<V9E<D5N8V]D92@I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1T97AT(#T@)'1H:7,M/G1R86YS9F5R16YC;V1E*"D["B`@("`@
M("`@?0H*("`@("`@("`O*B!$96%L('=I=&@@;75L=&EP87)T(&UE<W-A9V5S
M+B`J+PH@("`@("`@(&EF("@D<'1Y<&4@/3T@)VUU;'1I<&%R="<I('L*("`@
M("`@("`@("`@)&)O=6YD87)Y(#T@=')I;2@D=&AI<RT^9V5T0V]N=&5N=%1Y
M<&5087)A;65T97(H)V)O=6YD87)Y)RDL("<B)RD["B`@("`@("`@("`@(&EF
M("@A<W1R;&5N*"1T:&ES+3Y?8V]N=&5N=',I*2!["B`@("`@("`@("`@("`@
M("`D=&5X="`N/2`G5&AI<R!M97-S86=E(&ES(&EN($U)344@9F]R;6%T+B<@
M+B`D96]L.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&9O<F5A8V@@*"1T
M:&ES+3YG971087)T<R@I(&%S("1P87)T*2!["B`@("`@("`@("`@("`@("`D
M=&5X="`N/2`D96]L("X@)RTM)R`N("1B;W5N9&%R>2`N("1E;VP["B`@("`@
M("`@("`@("`@("`D;VQD14],(#T@)'!A<G0M/F=E=$5/3"@I.PH@("`@("`@
M("`@("`@("`@)'!A<G0M/G-E=$5/3"@D96]L*3L*("`@("`@("`@("`@("`@
M("1T97AT("X]("1P87)T+3YT;U-T<FEN9RAT<G5E*3L*("`@("`@("`@("`@
M("`@("1P87)T+3YS971%3TPH)&]L9$5/3"D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)'1E>'0@+CT@)&5O;"`N("<M+2<@+B`D8F]U;F1A<GD@+B`G
M+2TG("X@)&5O;#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&5X=#L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&5N8V]D960@<&%R
M="!I;B!S=')I8W0@4D9#(#@R,B`F(#(P-#4@;W5T<'5T("T@;F%M96QY+"!A
M;&P*("`@("`J(&YE=VQI;F5S(&5N9"!W:71H('1H92!C86YO;FEC86P@/$-2
M/CQ,1CX@<V5Q=65N8V4N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)&AE861E<G,@($EN8VQU9&4@=&AE($U)344@:&5A9&5R<S\*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&5N=&ER92!-24U%('!A<G0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N('1O0V%N;VYI8V%L4W1R:6YG*"1H96%D97)S
M(#T@=')U92D*("`@('L*("`@("`@("`D<W1R:6YG(#T@)'1H:7,M/G1O4W1R
M:6YG*"1H96%D97)S*3L*("`@("`@("!R971U<FX@)'1H:7,M/G)E<&QA8V5%
M3TPH)'-T<FEN9RP@34E-15]005)47U)&0U]%3TPI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4VAO=6QD('=E(&UA:V4@<W5R92!T:&4@;65S<V%G92!I<R!E
M;F-O9&5D('9I82`W+6)I="`H92YG+B!T;R!A9&AE<F4*("`@("`J('1O(&UA
M:6P@9&5L:79E<GD@<W1A;F1A<F1S('-U8V@@87,@4D9#(#(X,C$I/PH@("`@
M("H*("`@("`J($!P87)A;2!B;V]L96%N("1U<V4W8FET("!5<V4@-RUB:70@
M96YC;V1I;F<_"B`@("`@*B\*("`@(&9U;F-T:6]N('-T<FEC=#=B:70H)'5S
M93=B:70I"B`@("!["B`@("`@("`@)'1H:7,M/E]E;F-O9&4W8FET(#T@)'5S
M93=B:70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE('1R86YS9F5R
M(&5N8V]D:6YG(&9O<B!T:&4@<&%R="!B87-E9"!O;B!T:&4@=7-E<B!R97%U
M97-T960*("`@("`J('1R86YS9F5R(&5N8V]D:6YG(&%N9"!T:&4@8W5R<F5N
M="!C;VYT96YT<R!O9B!T:&4@<&%R="X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE('1R86YS9F5R+65N8V]D:6YG(&]F('1H:7,@<&%R="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5')A;G-F97)%;F-O9&EN9R@I"B`@
M("!["B`@("`@("`@)&5N8V]D:6YG(#T@)'1H:7,M/E]T<F%N<V9E<D5N8V]D
M:6YG.PH@("`@("`@("1P='EP92`]("1T:&ES+3YG9710<FEM87)Y5'EP92@I
M.PH@("`@("`@("1T97AT(#T@<W1R7W)E<&QA8V4H)'1H:7,M/F=E=$5/3"@I
M+"`G("<L("1T:&ES+3Y?8V]N=&5N=',I.PH*("`@("`@("`O*B!)9B!T:&5R
M92!A<F4@;F\@8V]N=&5N=',L(')E='5R;B!W:&%T979E<B!T:&4@8W5R<F5N
M="!V86QU92!O9@H@("`@("`@("`@("1?=')A;G-F97)%;F-O9&EN9R!I<RX@
M*B\*("`@("`@("!I9B`H96UP='DH)'1E>'0I*2!["B`@("`@("`@("`@(')E
M='5R;B`D96YC;V1I;F<["B`@("`@("`@?0H*("`@("`@("!S=VET8V@@*"1P
M='EP92D@>PH@("`@("`@(&-A<V4@)VUE<W-A9V4G.@H@("`@("`@("`@("`O
M*B!21D,@,C`T-B!;-2XR+C%=("T@;65S<V%G92]R9F,X,C(@;65S<V%G97,@
M;VYL>2!A;&QO=R`W8FET+`H@("`@("`@("`@("`@("`X8FET+"!A;F0@8FEN
M87)Y(&5N8V]D:6YG<RX@268@=&AE(&-U<G)E;G0@96YC;V1I;F<@:7,@96ET
M:&5R"B`@("`@("`@("`@("`@(&)A<V4V-"!O<B!Q+7`L('-W:71C:"!I="!T
M;R`X8FET(&EN<W1E860N"B`@("`@("`@("`@("`@(%)&0R`R,#0V(%LU+C(N
M,BP@-2XR+C,L(#4N,BXT72`M($%L;"!O=&AE<B!M97-S86=E+RH@;65S<V%G
M97,*("`@("`@("`@("`@("`@;VYL>2!A;&QO=R`W8FET(&5N8V]D:6YG<RX@
M*B\*("`@("`@("`@("`@)&5N8V]D:6YG(#T@*"1T:&ES+3YG9713=6)4>7!E
M*"D@/3T@)W)F8S@R,B<I(#\@)SAB:70G(#H@)S=B:70G.PH@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@8V%S92`G=&5X="<Z"B`@("`@("`@("`@(&EF
M("A-24U%.CII<SAB:70H)'1E>'0I*2!["B`@("`@("`@("`@("`@("`D96YC
M;V1I;F<@/2`H)'1H:7,M/E]E;F-O9&4W8FET*2`_("=Q=6]T960M<')I;G1A
M8FQE)R`Z("<X8FET)SL*("`@("`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T
M8V@H(B\H/SI<;GQ>*5M>7&Y=>SDY.2Q]*#\Z7&Y\)"DO(BP@)'1E>'0I*2![
M"B`@("`@("`@("`@("`@("`O*B!)9B!T:&4@=&5X="!I<R!L;VYG97(@=&AA
M;B`Y.3@@8VAA<F%C=&5R<R!B971W965N"B`@("`@("`@("`@("`@("`@*B!L
M:6YE8G)E86MS+"!U<V4@<75O=&5D+7!R:6YT86)L92!E;F-O9&EN9R!T;R!E
M;G-U<F4@=&AE"B`@("`@("`@("`@("`@("`@*B!T97AT('=I;&P@;F]T(&)E
M(&-H;W!P960@*&DN92X@8GD@<V5N9&UA:6P@:68@8F5I;F<@<V5N=`H@("`@
M("`@("`@("`@("`@("H@87,@;6%I;"!T97AT*2X@*B\*("`@("`@("`@("`@
M("`@("1E;F-O9&EN9R`]("=Q=6]T960M<')I;G1A8FQE)SL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@
M("`@("`@("`@:68@*$U)344Z.FES.&)I="@D=&5X="DI('L*("`@("`@("`@
M("`@("`@("1E;F-O9&EN9R`]("@D=&AI<RT^7V5N8V]D93=B:70I(#\@)V)A
M<V4V-"<@.B`G.&)I="<["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@?0H*("`@("`@("`O*B!.965D('1O(&1O(&]N92!L87-T
M(&-H96-K(&9O<B!B:6YA<GD@9&%T82!I9B!E;F-O9&EN9R!I<R`W8FET(&]R
M"B`@("`@("`@("H@.&)I="X@($EF('1H92!M97-S86=E(&-O;G1A:6YS(&$@
M3E5,3"!C:&%R86-T97(@870@86QL+"!T:&4@;65S<V%G90H@("`@("`@("`J
M($U54U0@8F4@:6X@8FEN87)Y(&9O<FUA="X@4D9#(#(P-#8@6S(N-RP@,BXX
M+"`R+CE=+B!1+5`@86YD(&)A<V4V-`H@("`@("`@("`J(&-A;B!H86YD;&4@
M8FEN87)Y(&1A=&$@9FEN92!S;R!N;R!N965D('1O('-W:71C:"!T:&]S92!E
M;F-O9&EN9W,N("HO"B`@("`@("`@:68@*"@H)&5N8V]D:6YG(#T]("<X8FET
M)RD@?'P@*"1E;F-O9&EN9R`]/2`G-V)I="<I*2`F)@H@("`@("`@("`@("!P
M<F5G7VUA=&-H*"<O7'@P,"\G+"`D=&5X="DI('L*("`@("`@("`@("`@)&5N
M8V]D:6YG(#T@*"1T:&ES+3Y?96YC;V1E-V)I="D@/R`G8F%S938T)R`Z("=B
M:6YA<GDG.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1E;F-O9&EN9SL*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E<R!T:&4@8W5R<F5N="!E
M;F-O9&EN9R!O9B!T:&4@8V]N=&5N=',@:6X@=&AE(&]B:F5C="X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-U<G)E;G0@96YC;V1I;F<N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-U<G)E;G1%;F-O9&EN9R@I"B`@
M("!["B`@("`@("`@<F5T=7)N("AI<U]N=6QL*"1T:&ES+3Y?8W5R<F5N=$5N
M8V]D:6YG*2D@/R`D=&AI<RT^7W1R86YS9F5R16YC;V1I;F<@.B`D=&AI<RT^
M7V-U<G)E;G1%;F-O9&EN9SL*("`@('T*"B`@("`O*BH*("`@("`J($5N8V]D
M97,@=&AE(&-O;G1E;G1S('=I=&@@=&AE('!A<G0G<R!T<F%N<V9E<B!E;F-O
M9&EN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&5N8V]D
M960@=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@=')A;G-F97)%;F-O9&4H
M*0H@("`@>PH@("`@("`@("1E;F-O9&EN9R`]("1T:&ES+3YG9714<F%N<V9E
M<D5N8V]D:6YG*"D["B`@("`@("`@)&5O;"`]("1T:&ES+3YG971%3TPH*3L*
M"B`@("`@("`@+RH@4V5T('1H92`G;&%S=%1R86YS9F5R16YC;V1E)R!F;&%G
M('-O('1H870@=')A;G-F97)%;F-O9&5#;VYT96YT<R@I"B`@("`@("`@("`@
M8V%N('-A=F4@82!C86QL('1O(&=E=%1R86YS9F5R16YC;V1I;F<H*2X@*B\*
M("`@("`@("`D=&AI<RT^7V9L86=S6R=L87-T5')A;G-F97)%;F-O9&4G72`]
M("1E;F-O9&EN9SL*"B`@("`@("`@+RH@268@8V]N=&5N=',@87)E(&5M<'1Y
M+"!O<B!C;VYT96YT<R!A<F4@86QR96%D>2!E;F-O9&5D('1O('1H90H@("`@
M("`@("`@(&-O<G)E8W0@96YC;V1I;F<L(')E='5R;B!N;W<N("HO"B`@("`@
M("`@:68@*"%S=')L96XH)'1H:7,M/E]C;VYT96YT<RD@?'P*("`@("`@("`@
M("`@*"1E;F-O9&EN9R`]/2`D=&AI<RT^7V-U<G)E;G1%;F-O9&EN9RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?8V]N=&5N=',["B`@("`@("`@
M?0H*("`@("`@("!S=VET8V@@*"1E;F-O9&EN9RD@>PH@("`@("`@("\J($)A
M<V4V-"!%;F-O9&EN9SH@4V5E(%)&0R`R,#0U+"!S96-T:6]N(#8N."`J+PH@
M("`@("`@(&-A<V4@)V)A<V4V-"<Z"B`@("`@("`@("`@("\J($ME97!I;F<@
M=&AE<V4@='=O(&QI;F5S('-E<&%R871E('-E96US('1O('5S92!M=6-H(&QE
M<W,*("`@("`@("`@("`@("`@;65M;W)Y('1H86X@8V]M8FEN:6YG('1H96T@
M*&%S(&]F(%!(4"`T+C,I+B`J+PH@("`@("`@("`@("`D96YC;V1E9%]C;VYT
M96YT<R`](&)A<V4V-%]E;F-O9&4H)'1H:7,M/E]C;VYT96YT<RD["B`@("`@
M("`@("`@(')E='5R;B!C:'5N:U]S<&QI="@D96YC;V1E9%]C;VYT96YT<RP@
M-S8L("1E;VPI.PH*("`@("`@("`O*B!1=6]T960M4')I;G1A8FQE($5N8V]D
M:6YG.B!3964@4D9#(#(P-#4L('-E8W1I;VX@-BXW("HO"B`@("`@("`@8V%S
M92`G<75O=&5D+7!R:6YT86)L92<Z"B`@("`@("`@("`@("1O=71P=70@/2!-
M24U%.CIQ=6]T9610<FEN=&%B;&5%;F-O9&4H)'1H:7,M/E]C;VYT96YT<RP@
M)&5O;"D["B`@("`@("`@("`@(&EF("@H)&5O;&QE;F=T:"`](%-T<FEN9SHZ
M;&5N9W1H*"1E;VPI*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N('-U8G-T
M<B@D;W5T<'5T+"`P+"`D96]L;&5N9W1H("H@+3$I.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1O=71P=70["B`@("`@
M("`@("`@('T*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR97!L86-E14],*"1T:&ES+3Y?8V]N=&5N=',I.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($1E8V]D97,@=&AE(&-O;G1E;G1S
M(&]F('1H92!P87)T('1O(&5I=&AE<B!A(#=B:70@;W(@.&)I="!E;F-O9&EN
M9RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&1E8V]D960@
M=&5X="X*("`@("`J("`@("`@("`@("`@("`@("!2971U<FYS('1H92!E;7!T
M>2!S=')I;F<@:68@=&AE<F4@:7,@;F\@=&5X="!T;R!D96-O9&4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('1R86YS9F5R1&5C;V1E*"D*("`@('L*("`@("`@
M("`D96YC;V1I;F<@/2`D=&AI<RT^9V5T0W5R<F5N=$5N8V]D:6YG*"D["@H@
M("`@("`@("\J($EF('1H92!C;VYT96YT<R!A<F4@96UP='DL(')E='5R;B!N
M;W<N("HO"B`@("`@("`@:68@*"%S=')L96XH)'1H:7,M/E]C;VYT96YT<RDI
M('L*("`@("`@("`@("`@)'1H:7,M/E]F;&%G<ULG;&%S=%1R86YS9F5R1&5C
M;V1E)UT@/2`D96YC;V1I;F<["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7V-O;G1E;G1S.PH@("`@("`@('T*"B`@("`@("`@<W=I=&-H("@D96YC;V1I
M;F<I('L*("`@("`@("!C87-E("=B87-E-C0G.@H@("`@("`@("`@("`D;65S
M<V%G92`](&)A<V4V-%]D96-O9&4H)'1H:7,M/E]C;VYT96YT<RD["B`@("`@
M("`@("`@("1T:&ES+3Y?9FQA9W-;)VQA<W14<F%N<V9E<D1E8V]D92==(#T@
M)SAB:70G.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G<75O
M=&5D+7!R:6YT86)L92<Z"B`@("`@("`@("`@("1M97-S86=E(#T@<')E9U]R
M97!L86-E*"(O/5QR/UQN+R(L("<G+"`D=&AI<RT^7V-O;G1E;G1S*3L*("`@
M("`@("`@("`@)&UE<W-A9V4@/2`D=&AI<RT^<F5P;&%C945/3"@D;65S<V%G
M92D["B`@("`@("`@("`@("1M97-S86=E(#T@<75O=&5D7W!R:6YT86)L95]D
M96-O9&4H)&UE<W-A9V4I.PH@("`@("`@("`@("`D=&AI<RT^7V9L86=S6R=L
M87-T5')A;G-F97)$96-O9&4G72`]("A-24U%.CII<SAB:70H)&UE<W-A9V4I
M*2`_("<X8FET)R`Z("<W8FET)SL*("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("\J(%-U<'!O<G0@9F]R('5U96YC;V1E9"!E;F-O9&EN9R`M(&%L=&AO
M=6=H(&YO="!R97%U:7)E9"!B>2!21D-S+`H@("`@("`@("`@('-O;64@;6%I
M;&5R<R!M87D@<W1I;&P@96YC;V1E('1H:7,@=V%Y+B`J+PH@("`@("`@(&-A
M<V4@)W5U96YC;V1E)SH*("`@("`@("!C87-E("=X+75U96YC;V1E)SH*("`@
M("`@("!C87-E("=X+75U92<Z"B`@("`@("`@("`@(&EF("AF=6YC=&EO;E]E
M>&ES=',H)V-O;G9E<G1?=75D96-O9&4G*2D@>PH@("`@("`@("`@("`@("`@
M)&UE<W-A9V4@/2!C;VYV97)T7W5U96YC;V1E*"1T:&ES+3Y?8V]N=&5N=',I
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5Q=6ER
M95]O;F-E("=-86EL+VUI;65$96-O9&4N<&AP)SL*("`@("`@("`@("`@("`@
M("1F:6QE<R`]("9-86EL7VUI;65$96-O9&4Z.G5U9&5C;V1E*"1T:&ES+3Y?
M8V]N=&5N=',I.PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2`D9FEL97-;
M,%U;)V9I;&5D871A)UT["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5Q
M=6ER95]O;F-E("=-86EL+VUI;65$96-O9&4N<&AP)SL*("`@("`@("`@("`@
M)&9I;&5S(#T@)DUA:6Q?;6EM941E8V]D93HZ=75D96-O9&4H)'1H:7,M/E]C
M;VYT96YT<RD["B`@("`@("`@("`@("1M97-S86=E(#T@)&9I;&5S6S!=6R=F
M:6QE9&%T82==.PH@("`@("`@("`@("`D=&AI<RT^7V9L86=S6R=L87-T5')A
M;G-F97)$96-O9&4G72`]("<X8FET)SL*("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M7V9L86=S6R=L87-T5')A;G-F97)$96-O9&4G72D@)B8*("`@("`@("`@("`@
M("`@("@D=&AI<RT^7V9L86=S6R=L87-T5')A;G-F97)$96-O9&4G72`A/2`D
M96YC;V1I;F<I*2!["B`@("`@("`@("`@("`@("`D;65S<V%G92`]("1T:&ES
M+3YR97!L86-E14],*"1T:&ES+3Y?8V]N=&5N=',I.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2`D=&AI<RT^7V-O
M;G1E;G1S.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?9FQA
M9W-;)VQA<W14<F%N<V9E<D1E8V]D92==(#T@)&5N8V]D:6YG.PH@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;65S<V%G
M93L*("`@('T*"B`@("`O*BH*("`@("`J(%-P;&ET('1H92!C;VYT96YT<R!O
M9B!T:&4@8W5R<F5N="!087)T(&EN=&\@:71S(')E<W!E8W1I=F4@<W5B<&%R
M=',L"B`@("`@*B!I9B!I="!I<R!M=6QT:7!A<G0@34E-12!E;F-O9&EN9RX@
M56YL:6ME('1H92!I;6%P7RHH*2!F=6YC=&EO;G,L('1H:7,*("`@("`J('=I
M;&P@<')E<V5R=F4@86QL($U)344@:&5A9&5R(&EN9F]R;6%T:6]N+@H@("`@
M("H*("`@("`J(%1H92!B;W5N9&%R>2!C;VYT96YT+71Y<&4@<&%R86UE=&5R
M(&UU<W0@8F4@<V5T(&9O<B!T:&ES(&9U;F-T:6]N('1O"B`@("`@*B!W;W)K
M(&-O<G)E8W1L>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R
M=64@:68@=&AE(&-O;G1E;G1S('=E<F4@<W5C8V5S<V9U;&QY('-P;&ET+@H@
M("`@("H@("`@("`@("`@("`@("`@("!&86QS92!I9B!A;GD@97)R;W(@;V-C
M=7)R960N"B`@("`@*B\*("`@(&9U;F-T:6]N('-P;&ET0V]N=&5N=',H*0H@
M("`@>PH@("`@("`@(&EF("@A*"1B;W5N9&%R>2`]("1T:&ES+3YG971#;VYT
M96YT5'EP95!A<F%M971E<B@G8F]U;F1A<GDG*2DI('L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@*"%S=')L96XH
M)'1H:7,M/E]C;VYT96YT<RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*"B`@("`@("`@)&5O;"`]("1T:&ES+3YG971%3TPH*3L*
M("`@("`@("`D<F5T=F%L=64@/2!F86QS93L*"B`@("`@("`@9F]R96%C:"`H
M97AP;&]D92@D96]L+"`D=&AI<RT^7V-O;G1E;G1S*2!A<R`D;&EN92D@>PH@
M("`@("`@("`@("`D<&]S(#T@<W1R<&]S*"1L:6YE+"`G+2TG("X@)&)O=6YD
M87)Y*3L*("`@("`@("`@("`@:68@*"@D<&]S(#T]/2!F86QS92D@)B8@:7-S
M970H)'!A<G1?<'1R*2D@>PH@("`@("`@("`@("`@("`@)&1A=&%;72`]("1L
M:6YE.PH@("`@("`@("`@("!](&5L<V5I9B`H)'!O<R`]/3T@,"D@>PH@("`@
M("`@("`@("`@("`@)')E='9A;'5E(#T@=')U93L*("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D<&%R=%]P='(I*2!["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P87)T<ULD<&%R=%]P=')=+3YS971#;VYT96YT<RAI;7!L;V1E
M*"1E;VPL("1D871A*2D["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)T<ULD<&%R=%]P=')=+3YS<&QI=$-O;G1E;G1S*"D["B`@("`@("`@("`@
M("`@("`@("`@;F5X="@D=&AI<RT^7W!A<G1S*3L*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@<F5S970H)'1H:7,M/E]P
M87)T<RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)&1A=&$I*2!["B`@("`@("`@("`@("`@("`@("`@=6YS970H)&1A
M=&$I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&1A=&$@
M/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@)'!A<G1?<'1R(#T@:V5Y*"1T
M:&ES+3Y?<&%R=',I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)')E='9A;'5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5P
M;&%C92!N97=L:6YE<R!I;B!T:&ES('!A<G0G<R!C;VYT96YT<R!W:71H('1H
M;W-E('-P96-I9FEE9"!B>2!E:71H97(*("`@("`J('1H92!G:79E;B!N97=L
M:6YE('-E<75E;F-E(&]R('1H92!P87)T)W,@8W5R<F5N="!%3TP@<V5T=&EN
M9RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("!4:&4@=&5X
M="!T;R!R97!L86-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D96]L("`@5&AE
M($5/3"!S97%U96YC92!T;R!U<V4N($EF(&YO="!P<F5S96YT+"!U<V5S('1H
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@<&%R="=S(&-U<G)E;G0@
M14],('-E='1I;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!T97AT('=I=&@@=&AE(&YE=VQI;F5S(')E<&QA8V5D(&)Y('1H92!D97-I
M<F5D"B`@("`@*B`@("`@("`@("`@("`@("`@;F5W;&EN92!S97%U96YC92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<F5P;&%C945/3"@D=&5X="P@)&5O;"`]
M(&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)&5O;"DI('L*("`@
M("`@("`@("`@)&5O;"`]("1T:&ES+3YG971%3TPH*3L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N('!R96=?<F5P;&%C92@B+UQR/UQN+R(L("1E;VPL("1T
M97AT*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@=6YI<75E
M($U)345?4&%R="!B;W5N9&%R>2!S=')I;F<@9V5N97)A=&5D(&9O<B!T:&ES
M(&]B:F5C="X*("`@("`J(%1H:7,@;6%Y(&YO="!B92!T:&4@8F]U;F1A<GD@
M<W1R:6YG('5S960@=VAE;B!B=6EL9&EN9R!T:&4@;65S<V%G90H@("`@("H@
M<VEN8V4@82!U<V5R(&1E9FEN960@)V)O=6YD87)Y)R!#;VYT96YT+51Y<&4@
M<&%R86UE=&5R('=I;&P@;W9E<G)I9&4*("`@("`J('1H:7,@=F%L=64N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!U;FEQ=64@8F]U;F1A
M<GD@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9715;FEQ=65)1"@I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8F]U;F1A<GD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F4@=&AE('-I>F4@;V8@82!-24U%
M7U!A<G0@86YD(&ET<R!C:&EL9"!M96UB97)S+@H@("`@("H*("`@("`J($!R
M971U<FX@:6YT96=E<B`@4VEZ92!O9B!T:&4@34E-15]087)T+"!I;B!B>71E
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0GET97,H*0H@("`@>PH@("`@
M("`@("1B>71E<R`](#`["@H@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7V9L
M86=S6R=C;VYT96YT<U-E="==*2`F)B`D=&AI<RT^7V)Y=&5S*2!["B`@("`@
M("`@("`@("1B>71E<R`]("1T:&ES+3Y?8GET97,["B`@("`@("`@?2!E;'-E
M:68@*"1T:&ES+3YG9710<FEM87)Y5'EP92@I(#T]("=M=6QT:7!A<G0G*2![
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YG971087)T<R@I(&%S("1P
M87)T*2!["B`@("`@("`@("`@("`@("`O*B!3:VEP(&UU;'1I<&%R="!E;G1R
M:65S("AS:6YC92!T:&ES(&UA>2!R97-U;'0@:6X@9&]U8FQE"B`@("`@("`@
M("`@("`@("`@("!C;W5N=&EN9RDN("HO"B`@("`@("`@("`@("`@("!I9B`H
M)'!A<G0M/F=E=%!R:6UA<GE4>7!E*"D@(3T@)VUU;'1I<&%R="<I('L*("`@
M("`@("`@("`@("`@("`@("`D8GET97,@*ST@)'!A<G0M/F=E=$)Y=&5S*"D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/F=E=%!R:6UA<GE4>7!E*"D@
M/3T@)W1E>'0G*2!["B`@("`@("`@("`@("`@("`D8GET97,@/2!3=')I;F<Z
M.FQE;F=T:"@D=&AI<RT^7V-O;G1E;G1S+"`D=&AI<RT^9V5T0VAA<G-E="@I
M*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1B>71E
M<R`]('-T<FQE;B@D=&AI<RT^7V-O;G1E;G1S*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1B>71E<SL*("`@('T*"B`@("`O
M*BH*("`@("`J($5X<&QI8VET;'D@<V5T('1H92!S:7IE("AI;B!B>71E<RD@
M;V8@=&AI<R!P87)T+B!4:&ES('9A;'5E('=I;&P@;VYL>0H@("`@("H@8F4@
M<F5T=7)N960@*'9I82!G971">71E<R@I*2!I9B!T:&5R92!A<F4@;F\@8V]N
M=&5N=',@8W5R<F5N=&QY('-E="X*("`@("`J(%1H:7,@9G5N8W1I;VX@:7,@
M=7-E9G5L(&9O<B!S971T:6YG('1H92!S:7IE(&]F('1H92!P87)T('=H96X@
M=&AE"B`@("`@*B!C;VYT96YT<R!O9B!T:&4@<&%R="!A<F4@;F]T(&9U;&QY
M(&QO861E9"`H:2YE+B!C<F5A=&EN9R!A($U)345?4&%R=`H@("`@("H@;V)J
M96-T(&9R;VT@24U!4"!H96%D97(@:6YF;W)M871I;VX@=VET:&]U="!L;V%D
M:6YG('1H92!D871A(&]F('1H90H@("`@("H@<&%R="DN"B`@("`@*@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&)Y=&5S("!4:&4@<VEZ92!O9B!T:&ES('!A
M<G0@:6X@8GET97,N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$)Y=&5S*"1B
M>71E<RD*("`@('L*("`@("`@("`D=&AI<RT^7V)Y=&5S(#T@)&)Y=&5S.PH@
M("`@?0H*("`@("\J*@H@("`@("H@3W5T<'5T('1H92!S:7IE(&]F('1H:7,@
M34E-15]087)T(&EN($M"+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!3:7IE(&]F('1H92!-24U%7U!A<G0L(&EN('-T<FEN9R!F;W)M870N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=%-I>F4H*0H@("`@>PH@("`@("`@("1B
M>71E<R`]("1T:&ES+3YG971">71E<R@I.PH@("`@("`@(&EF("AE;7!T>2@D
M8GET97,I*2!["B`@("`@("`@("`@(')E='5R;B`D8GET97,["B`@("`@("`@
M?0H*("`@("`@("`D;&]C86QE:6YF;R`]($Y,4SHZ9V5T3&]C86QE26YF;R@I
M.PH@("`@("`@(')E='5R;B!N=6UB97)?9F]R;6%T*"1B>71E<R`O(#$P,C0L
M(#(L("1L;V-A;&5I;F9O6R=D96-I;6%L7W!O:6YT)UTL("1L;V-A;&5I;F9O
M6R=T:&]U<V%N9'-?<V5P)UTI.PH@("`@('T*"B`@("`O*BH*("`@("`J($%D
M9"!T;R!T:&4@;&ES="!O9B!#241S(&9O<B!T:&ES('!A<G0N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1C:61S("!!(&QI<W0@;V8@34E-12!)1',@
M;V8@=&AE('!A<G0N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@($ME>2`M
M($U)344@240*("`@("`J("`@("`@("`@("`@("`@("`@("`@5F%L=64@+2!#
M240@9F]R('1H92!P87)T"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$-)1"@D
M8VED<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]C:61S("L]
M("1C:61S.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;&ES
M="!O9B!#241S(&9O<B!T:&ES('!A<G0N"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@5&AE(&QI<W0@;V8@0TE$<R!F;W(@=&AI<R!P87)T+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971#241,:7-T*"D*("`@('L*("`@("`@("!A
M<V]R="@D=&AI<RT^7V-I9',L(%-/4E1?4U1224Y'*3L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]C:61S.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T
M:&4@0V]N=&5N="U)1"!H96%D97(@9F]R('1H:7,@<&%R="X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1C:60@(%5S92!T:&ES($-)1"`H:68@;F]T
M(&%L<F5A9'D@<V5T*2X@($5L<V4L(&=E;F5R871E(&$*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@<F%N9&]M($-)1"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<V5T0V]N=&5N=$E$*"1C:60@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF
M("AI<U]N=6QL*"1T:&ES+3Y?8V]N=&5N=&ED*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7V-O;G1E;G1I9"`]("AI<U]N=6QL*"1C:60I*2`_("AB87-E7V-O
M;G9E<G0H;6EC<F]T:6UE*"DL(#$P+"`S-BD@+B`G0"<@+B`D7U-%4E9%4ELG
M4T525D527TY!344G72D@.B`D8VED.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@)'1H:7,M/E]C;VYT96YT:60["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!#;VYT96YT+4E$(&9O<B!T:&ES('!A<G0N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!#;VYT96YT+4E$(&9O<B!T:&ES
M('!A<G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-O;G1E;G1)1"@I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8V]N=&5N=&ED.PH@("`@?0H*
M("`@("\J*@H@("`@("H@06QT97(@=&AE($U)344@240@;V8@=&AI<R!P87)T
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&UI;65I9"`@5&AE($U)
M344@240N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$U)345)9"@D;6EM96ED
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;6EM96ED(#T@)&UI;65I9#L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE($U)344@240@;V8@=&AI
M<R!P87)T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@34E-
M12!)1"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T34E-14ED*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]M:6UE:60["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92!R96QA=&EV92!-24U%($E$(&]F('1H:7,@
M<&%R="X*("`@("`J(&4N9RXL(&EF('1H92!B87-E('!A<G0@:&%S($U)344@
M240@;V8@,BP@86YD('EO=2!W86YT('1H92!F:7)S=`H@("`@("H@<W5B<&%R
M="!O9B!T:&4@8F%S92!P87)T+"!T:&4@<F5L871I=F4@34E-12!)1"!I<R`R
M+C$N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@(%1H92!R96QA
M=&EV92!P87)T($E$+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@<F5L871I=F4@34E-12!)1"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M4F5L871I=F5-24U%260H)&ED*0H@("`@>PH@("`@("`@("1R96P@/2`D=&AI
M<RT^9V5T34E-14ED*"D["B`@("`@("`@<F5T=7)N("AE;7!T>2@D<F5L*2D@
M/R`D:60@.B`D<F5L("X@)RXG("X@)&ED.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!A(&UA<'!I;F<@;V8@86QL($U)344@241S('1O('1H96ER
M(&-O;G1E;G0M='EP97,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@
M2T59.B!-24U%($E$+"!604Q513H@0V]N=&5N="!T>7!E"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-O;G1E;G14>7!E36%P*"D*("`@('L*("`@("`@("`D;6%P
M(#T@87)R87DH)'1H:7,M/F=E=$U)345)9"@I(#T^("1T:&ES+3YG9714>7!E
M*"DI.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<&%R=',@87,@)'9A;"D@
M>PH@("`@("`@("`@("`D;6%P("L]("1V86PM/F-O;G1E;G14>7!E36%P*"D[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D;6%P.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1V5N97)A=&4@=&AE('5N:7%U92!B;W5N9&%R>2!S=')I;F<@
M*&EF(&YO="!A;')E861Y(&1O;F4I+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8F]U
M;F1A<GD@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5N97)A=&5"
M;W5N9&%R>2@I"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)'1H:7,M/E]B
M;W5N9&%R>2DI('L*("`@("`@("`@("`@)'1H:7,M/E]B;W5N9&%R>2`]("<]
M7R<@+B!B87-E7V-O;G9E<G0H;6EC<F]T:6UE*"DL(#$P+"`S-BD["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^7V)O=6YD87)Y.PH@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M2&]R9&4O34E-12]-86=I8RYP:'``````````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,C`U-C4@,3`U,34T,S,W,S<@,#(Q-C0R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B!4:&4@34E-15]-86=I8SHZ(&-L87-S('!R;W9I9&5S(&%N(&EN=&5R9F%C
M92!T;R!D971E<FUI;F4@80H@*B!-24U%('1Y<&4@9F]R('9A<FEO=7,@8V]N
M=&5N="P@:68@:70@<')O=FED960@=VET:"!D:69F97)E;G0*("H@;&5V96QS
M(&]F(&EN9F]R;6%T:6]N+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%
M+TU)344O36%G:6,N<&AP+'8@,2XU,BXX+C$R(#(P,#8O,#$O,#$@,C$Z,C@Z
M,C0@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@06YI;"!-
M861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H@0V]P>7)I9VAT(#(P
M,#(M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO
M<F%D;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!!;FEL($UA
M9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`875T:&]R("!-:6-H
M865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J
M($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]-24U%"B`J
M+PIC;&%S<R!-24U%7TUA9VEC('L*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M82!C;W!Y(&]F('1H92!-24U%(&5X=&5N<VEO;B!M87`N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A
M>2`@5&AE($U)344@97AT96YS:6]N(&UA<"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@)E]G971-:6UE17AT96YS:6]N36%P*"D*("`@('L*("`@("`@("!S=&%T
M:6,@)&UI;65?97AT96YS:6]N7VUA<#L*"B`@("`@("`@:68@*"%I<W-E="@D
M;6EM95]E>'1E;G-I;VY?;6%P*2D@>PH@("`@("`@("`@("!R97%U:7)E(&1I
M<FYA;64H7U]&24Q%7U\I("X@)R]M:6UE+FUA<'!I;F<N<&AP)SL*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D;6EM95]E>'1E;G-I;VY?;6%P.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&-O<'D@;V8@=&AE($U)344@
M;6%G:6,@9FEL92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@34E-12!M86=I8R!F:6QE
M+@H@("`@("HO"B`@("!F=6YC=&EO;B`F7V=E=$UI;65-86=I8T9I;&4H*0H@
M("`@>PH@("`@("`@('-T871I8R`D;6EM95]M86=I8SL*"B`@("`@("`@:68@
M*"%I<W-E="@D;6EM95]M86=I8RDI('L*("`@("`@("`@("`@<F5Q=6ER92!D
M:7)N86UE*%]?1DE,15]?*2`N("<O;6EM92YM86=I8RYP:'`G.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1M:6UE7VUA9VEC.PH@("`@?0H*("`@("\J
M*@H@("`@("H@071T96UP="!T;R!C;VYV97)T(&$@9FEL92!E>'1E;G-I;VX@
M=&\@82!-24U%('1Y<&4L(&)A<V5D"B`@("`@*B!O;B!T:&4@9VQO8F%L($AO
M<F1E(&%N9"!A<'!L:6-A=&EO;B!S<&5C:69I8R!C;VYF:6<@9FEL97,N"B`@
M("`@*@H@("`@("H@268@=V4@8V%N;F]T(&UA<"!T:&4@9FEL92!E>'1E;G-I
M;VX@=&\@82!S<&5C:69I8R!T>7!E+"!T:&5N"B`@("`@*B!W92!F86QL(&)A
M8VL@=&\@82!C=7-T;VT@34E-12!H86YD;&5R("=X+65X=&5N<VEO;B\D97AT
M)RP@=VAI8V@*("`@("`J(&-A;B!B92!U<V5D(&%S(&$@;F]R;6%L($U)344@
M='EP92!I;G1E<FYA;&QY('1H<F]U9VAO=70@2&]R9&4N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D97AT("!4:&4@9FEL92!E>'1E;G-I;VX@=&\@
M8F4@;6%P<&5D('1O(&$@34E-12!T>7!E+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@34E-12!T>7!E(&]F('1H92!F:6QE(&5X=&5N<VEO
M;BX*("`@("`J+PH@("`@9G5N8W1I;VX@97AT5&]-24U%*"1E>'0I"B`@("![
M"B`@("`@("`@:68@*&5M<'1Y*"1E>'0I*2!["B`@("`@("`@("`@<F5T=7)N
M("=A<'!L:6-A=&EO;B]O8W1E="US=')E86TG.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1E>'0@/2!3=')I;F<Z.FQO=V5R*"1E>'0I.PH@("`@
M("`@("`@("`D;6%P(#T@)DU)345?36%G:6,Z.E]G971-:6UE17AT96YS:6]N
M36%P*"D["B`@("`@("`@("`@("1P;W,@/2`P.PH@("`@("`@("`@("!W:&EL
M92`H(6ES<V5T*"1M87!;)&5X=%TI("8F("1P;W,@(3T](&9A;'-E*2!["B`@
M("`@("`@("`@("`@("`D<&]S(#T@<W1R<&]S*"1E>'0L("<N)RD["B`@("`@
M("`@("`@("`@("!I9B`H)'!O<R`A/3T@9F%L<V4I('L*("`@("`@("`@("`@
M("`@("`@("`D97AT(#T@<W5B<W1R*"1E>'0L("1P;W,@*R`Q*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*&ES
M<V5T*"1M87!;)&5X=%TI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&UA
M<%LD97AT73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M(')E='5R;B`G>"UE>'1E;G-I;VXO)R`N("1E>'0["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T('1O(&-O
M;G9E<G0@82!F:6QE;F%M92!T;R!A($U)344@='EP92P@8F%S960@;VX@=&AE
M(&=L;V)A;"!(;W)D90H@("`@("H@86YD(&%P<&QI8V%T:6]N('-P96-I9FEC
M(&-O;F9I9R!F:6QE<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F
M:6QE;F%M92`@5&AE(&9I;&5N86UE('1O(&)E(&UA<'!E9"!T;R!A($U)344@
M='EP92X*("`@("`J($!P87)A;2!B;V]L96%N("1U;FMN;W=N("!(;W<@<VAO
M=6QD('5N:VYO=VX@97AT96YS:6]N<R!B92!H86YD;&5D/R!)9@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@('1R=64L('=I;&P@<F5T=7)N("=X
M+65X=&5N<VEO;B\J)R!T>7!E<RX@($EF"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@9F%L<V4L('=I;&P@<F5T=7)N("=A<'!L:6-A=&EO;B]O
M8W1E="US=')E86TG+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@34E-12!T>7!E(&]F('1H92!F:6QE;F%M92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9FEL96YA;654;TU)344H)&9I;&5N86UE+"`D=6YK;F]W;B`]('1R
M=64I"B`@("!["B`@("`@("`@)'!O<R`]('-T<FQE;B@D9FEL96YA;64I("L@
M,3L*("`@("`@("`D='EP92`]("<G.PH*("`@("`@("`D;6%P(#T@)DU)345?
M36%G:6,Z.E]G971-:6UE17AT96YS:6]N36%P*"D["B`@("`@("`@9F]R("@D
M:2`](#`["B`@("`@("`@("`@("`D:2`\/2`D;6%P6R=?7TU!6%!%4DE/1%]?
M)UT@)B8*("`@("`@("`@("`@("`@("!S=')R<&]S*'-U8G-T<B@D9FEL96YA
M;64L(#`L("1P;W,@+2`Q*2P@)RXG*2`A/3T@9F%L<V4["B`@("`@("`@("`@
M("`D:2LK*2!["B`@("`@("`@("`@("1P;W,@/2!S=')R<&]S*'-U8G-T<B@D
M9FEL96YA;64L(#`L("1P;W,@+2`Q*2P@)RXG*2`K(#$["B`@("`@("`@?0H@
M("`@("`@("1T>7!E(#T@34E-15]-86=I8SHZ97AT5&]-24U%*'-U8G-T<B@D
M9FEL96YA;64L("1P;W,I*3L*"B`@("`@("`@:68@*&5M<'1Y*"1T>7!E*2!\
M?`H@("`@("`@("`@("`H(21U;FMN;W=N("8F("AS=')P;W,H)'1Y<&4L("=X
M+65X=&5N<VEO;B<I("$]/2!F86QS92DI*2!["B`@("`@("`@("`@(')E='5R
M;B`G87!P;&EC871I;VXO;V-T970M<W1R96%M)SL*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@)'1Y<&4["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@071T96UP="!T;R!C;VYV97)T(&$@34E-12!T>7!E
M('1O(&$@9FEL92!E>'1E;G-I;VXL(&)A<V5D"B`@("`@*B!O;B!T:&4@9VQO
M8F%L($AO<F1E(&%N9"!A<'!L:6-A=&EO;B!S<&5C:69I8R!C;VYF:6<@9FEL
M97,N"B`@("`@*@H@("`@("H@268@=V4@8V%N;F]T(&UA<"!T:&4@='EP92!T
M;R!A(&9I;&4@97AT96YS:6]N+"!W92!R971U<FX@9F%L<V4N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@5&AE($U)344@='EP92!T;R!B
M92!M87!P960@=&\@82!F:6QE(&5X=&5N<VEO;BX*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(&9I;&4@97AT96YS:6]N(&]F('1H92!-24U%
M('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N($U)3454;T5X="@D='EP92D*
M("`@('L*("`@("`@("!I9B`H96UP='DH)'1Y<&4I*2!["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1K97D@/2!A<G)A
M>5]S96%R8V@H)'1Y<&4L($U)345?36%G:6,Z.E]G971-:6UE17AT96YS:6]N
M36%P*"DI.PH@("`@("`@(&EF("@D:V5Y(#T]/2!F86QS92D@>PH@("`@("`@
M("`@("!L:7-T*"1M86IO<BP@)&UI;F]R*2`](&5X<&QO9&4H)R\G+"`D='EP
M92D["B`@("`@("`@("`@(&EF("@D;6%J;W(@/3T@)W@M97AT96YS:6]N)RD@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1M:6YO<CL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!I9B`H<W1R<&]S*"1M:6YO<BP@)W@M)RD@/3T](#`I
M('L*("`@("`@("`@("`@("`@(')E='5R;B!S=6)S='(H)&UI;F]R+"`R*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1K97D["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@57-E<R!V87)I86YT<R!O9B!T:&4@
M54Y)6"`B9FEL92(@8V]M;6%N9"!T;R!A='1E;7!T('1O(&1E=&5R;6EN92!T
M:&4*("`@("`J($U)344@='EP92!O9B!A;B!U;FMN;W=N(&9I;&4N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@(%1H92!P871H('1O
M('1H92!F:6QE('1O(&%N86QY>F4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1M
M86=I8U]D8B`@4&%T:"!T;R!T:&4@;6EM92!M86=I8R!D871A8F%S92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($U)344@='EP92!O9B!T
M:&4@9FEL92X@(%)E='5R;G,@9F%L<V4@:68@=&AE(&9I;&4*("`@("`J("`@
M("`@("`@("`@("`@("!T>7!E(&ES;B=T(')E8V]G;FEZ960@;W(@86X@97)R
M;W(@:&%P<&5N960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%N86QY>F5&:6QE
M*"1P871H+"`D;6%G:6-?9&(@/2!N=6QL*0H@("`@>PH@("`@("`@("\J($EF
M('1H92!02%`@36EM971Y<&4@97AT96YS:6]N(&ES(&%V86EL86)L92P@=7-E
M('1H870N("HO"B`@("`@("`@:68@*%5T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G
M9FEL96EN9F\G*2D@>PH@("`@("`@("`@("!I9B`H96UP='DH)&UA9VEC7V1B
M*2D@>PH@("`@("`@("`@("`@("`@)')E<R`]($!F:6YF;U]O<&5N*$9)3$5)
M3D9/7TU)344I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)')E<R`]($!F:6YF;U]O<&5N*$9)3$5)3D9/7TU)344L("1M86=I8U]D
M8BD["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1R97,I('L*("`@
M("`@("`@("`@("`@("1T>7!E(#T@9FEN9F]?9FEL92@D<F5S+"`D<&%T:"D[
M"B`@("`@("`@("`@("`@("!F:6YF;U]C;&]S92@D<F5S*3L*"B`@("`@("`@
M("`@("`@("`O*B!296UO=F4@86YY(&%D9&ET:6]N86P@:6YF;W)M871I;VXN
M("HO"B`@("`@("`@("`@("`@("!F;W)E86-H("AA<G)A>2@G.R<L("<L)RP@
M)UQ<,"<I(&%S("1S97!A<F%T;W(I('L*("`@("`@("`@("`@("`@("`@("`D
M<&]S(#T@<W1R<&]S*"1T>7!E+"`D<V5P87)A=&]R*3L*("`@("`@("`@("`@
M("`@("`@("!I9B`H)'!O<R`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)'1Y<&4@/2!R=')I;2AS=6)S='(H)'1Y<&4L(#`L("1P;W,I
M*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)WQ>6V$M>C`M.5TK+ULN
M+6$M>C`M.5TK)'QI)RP@)'1Y<&4I*2!["B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1T>7!E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!I9B`H571I;#HZ97AT96YS:6]N17AI<W1S
M*"=M:6UE7VUA9VEC)RDI('L*("`@("`@("`@("`@<F5T=7)N('1R:6TH;6EM
M95]C;VYT96YT7W1Y<&4H)'!A=&@I*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`O*B!5<V4@82!B=6EL="UI;B!M86=I8R!F:6QE+B`J+PH@("`@
M("`@("`@("`D;6EM95]M86=I8R`]("9-24U%7TUA9VEC.CI?9V5T36EM94UA
M9VEC1FEL92@I.PH@("`@("`@("`@("!I9B`H(2@D9G`@/2!`9F]P96XH)'!A
M=&@L("=R8B<I*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&9O<F5A8V@@*"1M:6UE7VUA9VEC
M(&%S("1O9F9S970@/3X@)&]D871A*2!["B`@("`@("`@("`@("`@("!F;W)E
M86-H("@D;V1A=&$@87,@)&QE;F=T:"`]/B`D;&1A=&$I('L*("`@("`@("`@
M("`@("`@("`@("!`9G-E96LH)&9P+"`D;V9F<V5T+"!3145+7U-%5"D["B`@
M("`@("`@("`@("`@("`@("`@)&QO;VMU<"`]($!F<F5A9"@D9G`L("1L96YG
M=&@I.PH@("`@("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&QD871A6R1L
M;V]K=7!=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!F8VQO<V4H)&9P
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1L9&%T85LD;&]O
M:W5P73L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@9F-L;W-E*"1F<"D["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H*("`@("\J*@H@
M("`@("H@57-E<R!V87)I86YT<R!O9B!T:&4@54Y)6"`B9FEL92(@8V]M;6%N
M9"!T;R!A='1E;7!T('1O(&1E=&5R;6EN92!T:&4*("`@("`J($U)344@='EP
M92!O9B!A;B!U;FMN;W=N(&)Y=&4@<W1R96%M+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&1A=&$@("`@("!4:&4@9FEL92!D871A('1O(&%N86QY
M>F4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1M86=I8U]D8B`@4&%T:"!T;R!T
M:&4@;6EM92!M86=I8R!D871A8F%S92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE($U)344@='EP92!O9B!T:&4@9FEL92X@(%)E='5R;G,@
M9F%L<V4@:68@=&AE(&9I;&4*("`@("`J("`@("`@("`@("`@("`@("!T>7!E
M(&ES;B=T(')E8V]G;FEZ960@;W(@86X@97)R;W(@:&%P<&5N960N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&%N86QY>F5$871A*"1D871A+"`D;6%G:6-?9&(@
M/2!N=6QL*0H@("`@>PH@("`@("`@("\J($EF('1H92!02%`@36EM971Y<&4@
M97AT96YS:6]N(&ES(&%V86EL86)L92P@=7-E('1H870N("HO"B`@("`@("`@
M:68@*%5T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G9FEL96EN9F\G*2D@>PH@("`@
M("`@("`@("!I9B`H96UP='DH)&UA9VEC7V1B*2D@>PH@("`@("`@("`@("`@
M("`@)')E<R`]($!F:6YF;U]O<&5N*$9)3$5)3D9/7TU)344I.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)')E<R`]($!F:6YF;U]O
M<&5N*$9)3$5)3D9/7TU)344L("1M86=I8U]D8BD["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@:68@*"$D<F5S*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T>7!E(#T@
M9FEN9F]?8G5F9F5R*"1R97,L("1D871A*3L*("`@("`@("`@("`@9FEN9F]?
M8VQO<V4H)')E<RD["@H@("`@("`@("`@("`O*B!296UO=F4@86YY(&%D9&ET
M:6]N86P@:6YF;W)M871I;VXN("HO"B`@("`@("`@("`@("1P;W,@/2!S=')P
M;W,H)'1Y<&4L("<[)RD["B`@("`@("`@("`@(&EF("@D<&]S("$]/2!F86QS
M92D@>PH@("`@("`@("`@("`@("`@)'1Y<&4@/2!R=')I;2AS=6)S='(H)'1Y
M<&4L(#`L("1P;W,I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<&]S
M(#T@<W1R<&]S*"1T>7!E+"`G+"<I.PH@("`@("`@("`@("!I9B`H)'!O<R`A
M/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1T>7!E(#T@<G1R:6TH<W5B
M<W1R*"1T>7!E+"`P+"`D<&]S*2D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@<F5T=7)N("1T>7!E.PH@("`@("`@('T*"B`@("`@("`@+RH@57-E(&$@
M8G5I;'0M:6X@;6%G:6,@9FEL92X@*B\*("`@("`@("`D;6EM95]M86=I8R`]
M("9-24U%7TUA9VEC.CI?9V5T36EM94UA9VEC1FEL92@I.PH@("`@("`@(&9O
M<F5A8V@@*"1M:6UE7VUA9VEC(&%S("1O9F9S970@/3X@)&]D871A*2!["B`@
M("`@("`@("`@(&9O<F5A8V@@*"1O9&%T82!A<R`D;&5N9W1H(#T^("1L9&%T
M82D@>PH@("`@("`@("`@("`@("`@)&QO;VMU<"`]('-U8G-T<B@D9&%T82P@
M)&]F9G-E="P@)&QE;F=T:"D["B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y
M*"1L9&%T85LD;&]O:W5P72DI('L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)&QD871A6R1L;V]K=7!=.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-
M12]-1$XN<&AP````````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,C(W,S(@,3`U,34T,S,W,S<@,#(Q,C,V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@34E-
M15]-1$XZ.B!C;&%S<R!I;7!L96UE;G1S($UE<W-A9V4@1&ES<&]S:71I;VX@
M3F]T:69I8V%T:6]N<R!A<PH@*B!D97-C<FEB960@8GD@4D9#(#(R.3@N"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP+'8@,2XT
M+C$P+C@@,C`P-B\P,2\R-"`R,3HS,CHU-B!S;'5S87)Z($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`T+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z
M0&-U<F5C86YT:2YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-
M:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8W5R96-A;G1I+F]R9SX*("H@0'-I
M;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TU)344*("HO"F-L
M87-S($U)345?341.('L*"B`@("`O*BH*("`@("`J(%1H92!-24U%7TAE861E
M<G,@;V)J96-T+@H@("`@("H*("`@("`J($!V87(@34E-15](96%D97)S"B`@
M("`@*B\*("`@('9A<B`D7VAE861E<G,["@H@("`@+RHJ"B`@("`@*B!4:&4@
M=&5X="!O9B!T:&4@;W)I9VEN86P@;65S<V%G92X*("`@("`J"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]M<V=T97AT(#T@9F%L<V4[
M"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`
M<&%R86T@34E-15](96%D97)S("1M:6UE7VAE861E<G,@($$@34E-15](96%D
M97)S(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@34E-15]-1$XH)&UI
M;65?:&5A9&5R<R`](&YU;&PI"B`@("!["B`@("`@("`@)'1H:7,M/E]H96%D
M97)S(#T@)&UI;65?:&5A9&5R<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE(&%D9')E<W,@=&\@<F5T=7)N('1H92!-1$X@=&\N"B`@("`@
M*B!2971U<FYS(&YU;&P@:68@;F\@341.(&ES(')E<75E<W1E9"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&%D9')E<W,@=&\@<V5N9"!T
M:&4@341.('1O+B!2971U<FYS(&YU;&P@:68@;F\*("`@("`J("`@("`@("`@
M("`@("`@("!-1$X@:7,@<F5Q=65S=&5D+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971-1$Y2971U<FY!9&1R*"D*("`@('L*("`@("`@("`O*B!21D,@,C(Y
M."!;,BXQ72!R97%U:7)E<R!T:&4@1&ES<&]S:71I;VXM3F]T:69I8V%I;VXM
M5&\@:&5A9&5R"B`@("`@("`@("H@9F]R(&%N($U$3B!T;R!B92!C<F5A=&5D
M+B`J+PH@("`@("`@(')E='5R;B`D=&AI<RT^7VAE861E<G,M/F=E=%9A;'5E
M*"=$:7-P;W-I=&EO;BU.;W1I9FEC871I;VXM5&\G*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($ES('5S97(@:6YP=70@<F5Q=6ER960@=&\@<V5N9"!T:&4@
M341./PH@("`@("H@17AP;&EC:70@8V]N9FER;6%T:6]N(&ES(&YE961E9"!I
M;B!S;VUE(&-A<V5S('1O('!R979E;G0@;6%I;"!L;V]P<PH@("`@("H@86YD
M('1H92!U<V4@;V8@341.<R!F;W(@;6%I;"!B;VUB:6YG+@H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@27,@97AP;&EC:70@=7-E<B!I;G!U="!R
M97%U:7)E9"!T;R!S96YD('1H92!-1$X_"B`@("`@*B\*("`@(&9U;F-T:6]N
M('5S97)#;VYF:7)M871I;VY.965D960H*0H@("`@>PH@("`@("`@("1R971U
M<FY?<&%T:"`]("1T:&ES+3Y?:&5A9&5R<RT^9V5T5F%L=64H)U)E='5R;BU0
M871H)RD["@H@("`@("`@("\J(%)&0R`R,CDX(%LR+C%=.B!%>'!L:6-I="!C
M;VYF:7)M871I;VX@:7,@;F5E9&5D(&EF('1H97)E(&ES(&YO"B`@("`@("`@
M("H@4F5T=7)N+5!A=&@@:6X@=&AE(&AE861E<BX@06QS;RP@(FEF('1H92!M
M97-S86=E(&-O;G1A:6YS(&UO<F4*("`@("`@("`@*B!T:&%N(&]N92!2971U
M<FXM4&%T:"!H96%D97(L('1H92!I;7!L96UE;G1A=&EO;B!M87D@6UT@=')E
M870@=&AE"B`@("`@("`@("H@<VET=6%T:6]N(&%S(&$@9F%I;'5R92!O9B!T
M:&4@8V]M<&%R:7-O;BX@*B\*("`@("`@("!I9B`H96UP='DH)')E='5R;E]P
M871H*2!\?"!I<U]A<G)A>2@D<F5T=7)N7W!A=&@I*2!["B`@("`@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@<F5Q=6ER95]O;F-E
M("=-86EL+U)&0S@R,BYP:'`G.PH@("`@("`@("1P87)S97(@/2`F;F5W($UA
M:6Q?4D9#.#(R*"D["@H@("`@("`@("\J(%)&0R`R,CDX(%LR+C%=.B!%>'!L
M:6-I="!C;VYF:7)M871I;VX@:7,@;F5E9&5D(&EF('1H97)E(&ES(&UO<F4*
M("`@("`@("`@*B!T:&%N(&]N92!D:7-T:6YC="!A9&1R97-S(&EN('1H92!$
M:7-P;W-I=&EO;BU.;W1I9FEC871I;VXM5&\*("`@("`@("`@*B!H96%D97(N
M("HO"B`@("`@("`@)&%D9')?87)R(#T@)'!A<G-E<BT^<&%R<V5!9&1R97-S
M3&ES="@D=&AI<RT^9V5T341.4F5T=7)N061D<B@I+"!N=6QL+"!N=6QL+"!F
M86QS92D["B`@("`@("`@:68@*&ES7V$H)&%D9')?87)R+"`G4$5!4E]%<G)O
M<B<I('Q\("AC;W5N="@D861D<E]A<G(I(#X@,2DI('L*("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`O*B!21D,@,C(Y."!;
M,BXQ72!S=&%T97,@=&AA="`B341.<R!32$]53$0@3D]4(&)E('-E;G0@875T
M;VUA=&EC86QL>0H@("`@("`@("`J(&EF('1H92!A9&1R97-S(&EN('1H92!$
M:7-P;W-I=&EO;BU.;W1I9FEC871I;VXM5&\@:&5A9&5R(&1I9F9E<G,*("`@
M("`@("`@*B!F<F]M('1H92!A9&1R97-S(&EN('1H92!2971U<FXM4&%T:"!H
M96%D97(N(B!4:&ES(&-O;7!A<FES;VX@:7,*("`@("`@("`@*B!C87-E+7-E
M;G-I=&EV92!F;W(@=&AE(&UA:6QB;W@@<&%R="!A;F0@8V%S92UI;G-E;G-I
M=&EV92!F;W(@=&AE"B`@("`@("`@("H@:&]S="!P87)T+B`J+PH@("`@("`@
M("1R971?87)R(#T@)'!A<G-E<BT^<&%R<V5!9&1R97-S3&ES="@D<F5T=7)N
M7W!A=&@L(&YU;&PL(&YU;&PL(&9A;'-E*3L*("`@("`@("!I9B`H(6ES7V$H
M)')E=%]A<G(L("=014%27T5R<F]R)RD@)B8*("`@("`@("`@("`@*"@D861D
M<E]A<G);,%TM/FUA:6QB;W@@(3T@)')E=%]A<G);,%TM/FUA:6QB;W@I('Q\
M"B`@("`@("`@("`@("A3=')I;F<Z.FQO=V5R*"1A9&1R7V%R<ELP72T^:&]S
M="D@(3T@4W1R:6YG.CIL;W=E<B@D<F5T7V%R<ELP72T^:&]S="DI*2D@>PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%=H96X@9V5N97)A
M=&EN9R!T:&4@341.+"!S:&]U;&0@=V4@<F5T=7)N('1H92!E;FET<F4@=&5X
M="!O9B!T:&4*("`@("`J(&]R:6=I;F%L(&UE<W-A9V4_("!4:&4@9&5F875L
M="!I<R!N;R`M('=E(&]N;'D@<F5T=7)N('1H92!H96%D97)S(&]F"B`@("`@
M*B!T:&4@;W)I9VEN86P@;65S<V%G92X@268@=&AE('1E>'0@:7,@<&%S<V5D
M(&EN('9I82!T:&ES(&UE=&AO9"P@=V4*("`@("`J('=I;&P@<F5T=7)N('1H
M92!E;G1I<F4@;65S<V%G92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1T97AT("!4:&4@=&5X="!O9B!T:&4@;W)I9VEN86P@;65S<V%G92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@;W)I9VEN86Q-97-S86=E5&5X="@D=&5X="D*
M("`@('L*("`@("`@("`D=&AI<RT^7VUS9W1E>'0@/2`D=&5X=#L*("`@('T*
M"B`@("`O*BH*("`@("`J($=E;F5R871E('1H92!-1$X@86-C;W)D:6YG('1O
M('1H92!S<&5C:69I8V%T:6]N<R!L:7-T960@:6X@4D9#"B`@("`@*B`R,CDX
M(%LS72X*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D86-T:6]N("`@
M5V%S('1H:7,@341.('1Y<&4@82!R97-U;'0@;V8@82!M86YU86P@86-T:6]N
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@;VX@<&%R="!O9B!T
M:&4@=7-E<C\*("`@("`J($!P87)A;2!B;V]L96%N("1S96YD:6YG("!787,@
M=&AI<R!-1$X@<V5N="!A<R!A(')E<W5L="!O9B!A(&UA;G5A;`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%C=&EO;B!O;B!P87)T(&]F('1H
M92!U<V5R/PH@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@("`@(%1H92!T
M>7!E(&]F(&%C=&EO;B!P97)F;W)M960@8GD@=&AE('5S97(N"B`@("`@*B`\
M<')E/@H@("`@("H@4&5R(%)&0R`R,CDX(%LS+C(N-BXR72!T:&4@9F]L;&]W
M:6YG('1Y<&5S(&%R92!V86QI9#H*("`@("`J(#T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*("`@("`J("=D
M:7-P;&%Y960G"B`@("`@*B`G9&ES<&%T8VAE9"<*("`@("`J("=P<F]C97-S
M960G"B`@("`@*B`G9&5L971E9"<*("`@("`J("=D96YI960G"B`@("`@*B`G
M9F%I;&5D)PH@("`@("H@/"]P<F4^"B`@("`@*B!`<&%R86T@87)R87D@)&UO
M9"`@("`@("`@5&AE(&QI<W0@;V8@;6]D:69I8V%T:6]N<RX*("`@("`J(#QP
M<F4^"B`@("`@*B!097(@4D9#(#(R.3@@6S,N,BXV+C-=('1H92!F;VQL;W=I
M;F<@;6]D:69I8V%T:6]N<R!A<F4@=F%L:60Z"B`@("`@*B`]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T*("`@("`J("=E<G)O<B<*("`@("`J("=W87)N:6YG)PH@("`@("H@
M)W-U<&5R<V5D960G"B`@("`@*B`G97AP:7)E9"<*("`@("`J("=M86EL8F]X
M+71E<FUI;F%T960G"B`@("`@*B`\+W!R93X*("`@("`J($!P87)A;2!A<G)A
M>2`D97)R("`@("`@("!)9B`D='EP92!I<R`G9F%I;'5E)R!O<B`D;6]D(&ES
M(&5I=&AE<B`G97)R;W(G"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@;W(@)W=A<FYI;F<G+"!T:&4@861D:71I;VYA;"!I;F9O<FUA=&EO;B!T
M;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('!R;W9I9&4N("!+
M97D@:7,@=&AE('1Y<&4@;V8@;6]D:69I8V%T:6]N+`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@('9A;'5E(&ES('1H92!T97AT+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<RP@4$5!4E]%
M<G)O<B!O8FIE8W0@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M;F5R871E*"1A8W1I;VXL("1S96YD:6YG+"`D='EP92P@)&UO9"`](&%R<F%Y
M*"DL("1E<G(@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC
M92`G2&]R9&4O34E-12](96%D97)S+G!H<"<["B`@("`@("`@<F5Q=6ER95]O
M;F-E("=(;W)D92]-24U%+TUE<W-A9V4N<&AP)SL*("`@("`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+TED96YT:71Y+G!H<"<["B`@("`@("`@<F5Q=6ER95]O
M;F-E("=(;W)D92]497AT+G!H<"<["@H@("`@("`@("\J(%-E="!U<"!S;VUE
M('9A<FEA8FQE<R!W92!U<V4@;&%T97(N("HO"B`@("`@("`@)&ED96YT:71Y
M(#T@)DED96YT:71Y.CIS:6YG;&5T;VXH*3L*("`@("`@("`D9G)O;5]A9&1R
M(#T@)&ED96YT:71Y+3YG971$969A=6QT1G)O;4%D9')E<W,H*3L*"B`@("`@
M("`@)'1O(#T@)'1H:7,M/F=E=$U$3E)E='5R;D%D9'(H*3L*"B`@("`@("`@
M)'5A(#T@)'1H:7,M/E]H96%D97)S+3YG971!9V5N=$AE861E<B@I.PH*("`@
M("`@("`D;W)I9U]R96-I<"`]("1T:&ES+3Y?:&5A9&5R<RT^9V5T5F%L=64H
M)T]R:6=I;F%L+5)E8VEP:65N="<I.PH@("`@("`@(&EF("@A96UP='DH)&]R
M:6=?<F5C:7`I("8F(&ES7V%R<F%Y*"1O<FEG7W)E8VEP*2D@>PH@("`@("`@
M("`@("`D;W)I9U]R96-I<"`]("1O<FEG7W)E8VEP6S!=.PH@("`@("`@('T*
M"B`@("`@("`@)&US9U]I9"`]("1T:&ES+3Y?:&5A9&5R<RT^9V5T5F%L=64H
M)TUE<W-A9V4M240G*3L*"B`@("`@("`@+RH@0W)E871E('1H92!$:7-P;W-I
M=&EO;B!F:65L9"!N;W<@*%)&0R`R,CDX(%LS+C(N-ETI+B`J+PH@("`@("`@
M("1D:7-P;R`]("=$:7-P;W-I=&EO;CH@)R`N"B`@("`@("`@("`@("`@("`@
M*"@D86-T:6]N*2`_("=M86YU86PM86-T:6]N)R`Z("=A=71O;6%T:6,M86-T
M:6]N)RD@+@H@("`@("`@("`@("`@("`@("<O)R`N"B`@("`@("`@("`@("`@
M("`@*"@D<V5N9&EN9RD@/R`G341.+7-E;G0M;6%N=6%L;'DG(#H@)TU$3BUS
M96YT+6%U=&]M871I8V%L;'DG*2`N"B`@("`@("`@("`@("`@("`@)SL@)R`N
M"B`@("`@("`@("`@("`@("`@)'1Y<&4["B`@("`@("`@:68@*"%E;7!T>2@D
M;6]D*2D@>PH@("`@("`@("`@("`D9&ES<&\@+CT@)R\G("X@:6UP;&]D92@G
M+"`G+"`D;6]D*3L*("`@("`@("!]"@H@("`@("`@("\J(%-E="!U<"!T:&4@
M;6%I;"!H96%D97)S+B`J+PH@("`@("`@("1M<V=?:&5A9&5R<R`]("9N97<@
M34E-15](96%D97)S*"D["B`@("`@("`@)&US9U]H96%D97)S+3YA9&1-97-S
M86=E261(96%D97(H*3L*("`@("`@("`D;7-G7VAE861E<G,M/F%D9$%G96YT
M2&5A9&5R*"1U82D["B`@("`@("`@)&US9U]H96%D97)S+3YA9&1(96%D97(H
M)T1A=&4G+"!D871E*"=R)RDI.PH@("`@("`@("1M<V=?:&5A9&5R<RT^861D
M2&5A9&5R*"=&<F]M)RP@)&9R;VU?861D<BD["B`@("`@("`@)&US9U]H96%D
M97)S+3YA9&1(96%D97(H)U1O)RP@)'1H:7,M/F=E=$U$3E)E='5R;D%D9'(H
M*2D["B`@("`@("`@)&US9U]H96%D97)S+3YA9&1(96%D97(H)U-U8FIE8W0G
M+"!?*")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB*2D["@H@("`@("`@("\J
M($U$3G,@87)E(&$@<W5B='EP92!O9B`G;75L=&EP87)T+W)E<&]R="<N("HO
M"B`@("`@("`@)&US9R`]("9N97<@34E-15]-97-S86=E*"D["B`@("`@("`@
M)&US9RT^<V5T5'EP92@G;75L=&EP87)T+W)E<&]R="<I.PH@("`@("`@("1M
M<V<M/G-E=$-O;G1E;G14>7!E4&%R86UE=&5R*"=R97!O<G0M='EP92<L("=D
M:7-P;W-I=&EO;BUN;W1I9FEC871I;VXG*3L*"B`@("`@("`@+RH@5&AE(&9I
M<G-T('!A<G0@:7,@82!H=6UA;B!R96%D86)L92!M97-S86=E+B`J+PH@("`@
M("`@("1P87)T7V]N92`]("9N97<@34E-15]087)T*"=T97AT+W!L86EN)RD[
M"B`@("`@("`@)'!A<G1?;VYE+3YS971#:&%R<V5T*$Y,4SHZ9V5T0VAA<G-E
M="@I*3L*("`@("`@("!I9B`H)'1Y<&4@/3T@)V1I<W!L87EE9"<I('L*("`@
M("`@("`@("`@)'!A<G1?;VYE+3YS971#;VYT96YT<RAS<')I;G1F*%\H(E1H
M92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<
M(B!H87,@8F5E;B!D:7-P;&%Y960N7&Y4:&ES(&ES(&YO(&=U87)A;G1E92!T
M:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB
M*2P@)'1H:7,M/E]H96%D97)S+3YG971686QU92@G1&%T92<I+"`D=&AI<RT^
M7VAE861E<G,M/F=E=%9A;'5E*"=4;R<I+"`D=&AI<RT^7VAE861E<G,M/F=E
M=%9A;'5E*"=3=6)J96-T)RDI*3L*("`@("`@("!]"B`@("`@("`@+R\@5$]$
M3SH@365S<V%G97,@9F]R(&]T:&5R(&YO=&EF:6-A=&EO;B!T>7!E<RX*("`@
M("`@("`D;7-G+3YA9&1087)T*"1P87)T7V]N92D["@H@("`@("`@("\J(%1H
M92!S96-O;F0@<&%R="!I<R!A(&UA8VAI;F4M<&%R<V5A8FQE(&1E<V-R:7!T
M:6]N+B`J+PH@("`@("`@("1P87)T7W1W;R`]("9N97<@34E-15]087)T*"=M
M97-S86=E+V1I<W!O<VET:6]N+6YO=&EF:6-A=&EO;B<I.PH@("`@("`@("1P
M87)T7W1W;RT^<V5T0V]N=&5N=',H)U)E<&]R=&EN9RU503H@)R`N("1'3$]"
M04Q36R=C;VYF)UU;)W-E<G9E<B==6R=N86UE)UT@+B`G.R`G("X@)'5A("X@
M(EQN(BD["B`@("`@("`@:68@*"%E;7!T>2@D;W)I9U]R96-I<"DI('L*("`@
M("`@("`@("`@)'!A<G1?='=O+3YA<'!E;F1#;VYT96YT<R@G3W)I9VEN86PM
M4F5C:7!I96YT.B!R9F,X,C([)R`N("1O<FEG7W)E8VEP("X@(EQN(BD["B`@
M("`@("`@?0H@("`@("`@("1P87)T7W1W;RT^87!P96YD0V]N=&5N=',H)T9I
M;F%L+5)E8VEP:65N=#H@<F9C.#(R.R<@+B`D9G)O;5]A9&1R("X@(EQN(BD[
M"B`@("`@("`@:68@*"%E;7!T>2@D;7-G7VED*2D@>PH@("`@("`@("`@("`D
M<&%R=%]T=V\M/F%P<&5N9$-O;G1E;G1S*"=/<FEG:6YA;"U-97-S86=E+4E$
M.B!R9F,X,C([)R`N("1M<V=?:60@+B`B7&XB*3L*("`@("`@("!]"B`@("`@
M("`@)'!A<G1?='=O+3YA<'!E;F1#;VYT96YT<R@D9&ES<&\@+B`B7&XB*3L*
M("`@("`@("!I9B`H*"1T>7!E(#T]("=F86EL960G*2`F)B!I<W-E="@D97)R
M6R=F86EL960G72DI('L*("`@("`@("`@("`@)'!A<G1?='=O+3YA<'!E;F1#
M;VYT96YT<R@G1F%I;'5R93H@)R`N("1E<G);)V9A:6QE9"==("X@(EQN(BD[
M"B`@("`@("`@?0H@("`@("`@(&EF("AI;E]A<G)A>2@G97)R;W(G+"`D;6]D
M*2`F)B!I<W-E="@D97)R6R=E<G)O<B==*2D@>PH@("`@("`@("`@("`D<&%R
M=%]T=V\M/F%P<&5N9$-O;G1E;G1S*"=%<G)O<CH@)R`N("1E<G);)V5R<F]R
M)UT@+B`B7&XB*3L*("`@("`@("!]"B`@("`@("`@:68@*&EN7V%R<F%Y*"=W
M87)N:6YG)RP@)&UO9"D@)B8@:7-S970H)&5R<ELG=V%R;FEN9R==*2D@>PH@
M("`@("`@("`@("`D<&%R=%]T=V\M/F%P<&5N9$-O;G1E;G1S*"=787)N:6YG
M.B`G("X@)&5R<ELG=V%R;FEN9R==("X@(EQN(BD["B`@("`@("`@?0H@("`@
M("`@("1M<V<M/F%D9%!A<G0H)'!A<G1?='=O*3L*"B`@("`@("`@+RH@5&AE
M('1H:7)D('!A<G0@:7,@=&AE('1E>'0@;V8@=&AE(&]R:6=I;F%L(&UE<W-A
M9V4N("!21D,@,C(Y."!;,UT*("`@("`@("`@*B!A;&QO=W,@=7,@=&\@<F5T
M=7)N(&]N;'D@82!P;W)T:6]N(&]F('1H92!E;G1I<F4@;65S<V%G92`M('1H
M:7,*("`@("`@("`@*B!I<R!L969T('5P('1O('1H92!U<V5R+B`J+PH@("`@
M("`@("1P87)T7W1H<F5E(#T@)FYE=R!-24U%7U!A<G0H)VUE<W-A9V4O<F9C
M.#(R)RD["B`@("`@("`@)'!A<G1?=&AR964M/G-E=$-O;G1E;G1S*"1T:&ES
M+3Y?:&5A9&5R<RT^=&]3=')I;F<H*2D["B`@("`@("`@:68@*"%E;7!T>2@D
M=&AI<RT^7VUS9W1E>'0I*2!["B`@("`@("`@("`@("1P87)T7W1H<F5E+3YA
M<'!E;F1#;VYT96YT<R@B7&XB("X@)'1H:7,M/E]M<V=T97AT*3L*("`@("`@
M("!]"B`@("`@("`@)&US9RT^861D4&%R="@D<&%R=%]T:')E92D["@H@("`@
M("`@("1M<V=?:&5A9&5R<RT^861D34E-14AE861E<G,H)&US9RD["@H@("`@
M("`@(')E='5R;B`D;7-G+3YS96YD*"1T;RP@)&US9U]H96%D97)S*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($%D9"!A($U$3B`H<F5A9"!R96-E:7!T*2!R
M97%U97-T(&AE861E<G,@=&\@=&AE($U)345?2&5A9&5R<R!O8FIE8W0N"B`@
M("`@*@H@("`@("H@0'!A<F%M($U)345?2&5A9&5R<R`F)&AE861O8B`@5&AE
M($U)345?2&5A9&5R<R!O8FIE8W0@=&\@861D('1H92!H96%D97)S"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T;RX*("`@("`J($!P
M87)A;2!S=')I;F<@)'1O("`@("`@("`@("`@(%1H92!A9&1R97-S('1H92!R
M96-E:7!T('-H;W5L9"!B92!M86EL960*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('1O+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1-
M1$Y297%U97-T2&5A9&5R<R@F)&AE861O8BP@)'1O*0H@("`@>PH@("`@("`@
M("\J(%1H:7,@:7,@=&AE(%)&0R`R,CDX('=A>2!O9B!R97%U97-T:6YG(&$@
M<F5C96EP="X@*B\*("`@("`@("`D:&5A9&]B+3YA9&1(96%D97(H)T1I<W!O
M<VET:6]N+4YO=&EF:6-A=&EO;BU4;R<L("1T;RD["B`@("!]"@I]"@``````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP````````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,3`U,#<P(#$P-3$U-#,S-S,W
M(#`R,C0Q,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`H*<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@
M)R]-97-S86=E+G!H<"<["@HO*BH*("H@5&AE(&YA;64@;V8@=&AE(%523"!P
M87)A;65T97(@=&AA="!H;VQD<R!T:&4@34E-15]#;VYT96YT<R!C86-H90H@
M*B!I9&5N=&EF:65R+@H@*B\*9&5F:6YE*"=-24U%7T-/3E1%3E137T-!0TA%
M)RP@)VUI;65C86-H92<I.PH*+RHJ"B`J($1I<W!L87D@871T86-H;65N="!I
M;F9O<FUA=&EO;B!I;B!L:7-T(&9O<FUA="X*("HO"F1E9FEN92@G34E-15]#
M3TY414Y44U]$25-03$%97U194$5?3$E35"<L(#`I.PH*+RHJ"B`J($1I<W!L
M87D@871T86-H;65N="!I;F9O<FUA=&EO;B!I;FQI;F4@=VET:"!A='1A8VAM
M96YT+@H@*B\*9&5F:6YE*"=-24U%7T-/3E1%3E137T1)4U!,05E?5%E015])
M3DQ)3D4G+"`Q*3L*"B\J*@H@*B!$:7-P;&%Y(&%T=&%C:&UE;G0@:6YF;W)M
M871I;VX@8F]T:"!I;B!L:7-T(&9O<FUA="!A;F0@:6YL:6YE('=I=&@*("H@
M871T86-H;65N="X*("HO"F1E9FEN92@G34E-15]#3TY414Y44U]$25-03$%9
M7U194$5?0D]42"<L(#(I.PH*+RHJ"B`J(%1H92!-24U%7T-O;G1E;G1S.CH@
M8VQA<W,@8V]N=&%I;G,@9G5N8W1I;VYS(')E;&%T960@=&\@:&%N9&QI;F<@
M=&AE(&]U='!U=`H@*B!O9B!-24U%(&-O;G1E;G0N"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`L=B`Q+C$R.2XT+C,U
M(#(P,#8O,#4O,#4@,#,Z,S`Z,C(@<VQU<V%R>B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,C`P,BTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W
M;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN($EF('EO
M=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-
M:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^
M"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]-24U%
M"B`J+PIC;&%S<R!-24U%7T-O;G1E;G1S('L*"B`@("`O*BH*("`@("`J(%1H
M92!-24U%7TUE<W-A9V4@;V)J96-T(&9O<B!T:&4@;65S<V%G92X*("`@("`J
M"B`@("`@*B!`=F%R($U)345?365S<V%G90H@("`@("HO"B`@("!V87(@)%]M
M97-S86=E.PH*("`@("\J*@H@("`@("H@5&AE($U)345?365S<V%G92!O8FIE
M8W0@=V4@=7-E('=H96X@8V%C:&EN9RX*("`@("`J"B`@("`@*B!`=F%R($U)
M345?365S<V%G90H@("`@("HO"B`@("!V87(@)%]C86-H96UE<W-A9V4["@H@
M("`@+RHJ"B`@("`@*B!4:&4@871T86-H;65N=',@;&ES="X*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V%T8R`](&%R<F%Y
M*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@;65S<V%G92!P87)T<R!L:7-T+@H@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<&%R
M=',@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@5&AE('-U;6UA<GD@<&%R
M=',@;&ES="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@
M('9A<B`D7W-U;6UA<GD@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@5&AE
M('-U;6UA<GD@='EP92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)%]S=6UM87)Y5'EP92`](&YU;&P["@H@("`@+RHJ"B`@
M("`@*B!4:&4@0V%C:&5?<V5S<VEO;B!I9&5N=&EF:65R+@H@("`@("H*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W-E<W-I;VY#86-H
M94E$(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%1H92!-24U%7U9I97=E<B!O
M8FIE8W0@8V%C:&4N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)%]V:65W97)#86-H92`](&%R<F%Y*"D["@H@("`@+RHJ"B`@
M("`@*B!4:&4@871T86-H;65N="!D:7-P;&%Y('1Y<&4@=&\@=7-E+@H@("`@
M("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]D:7-P
M;&%Y5'EP92`]($U)345?0T].5$5.5%-?1$E34$Q!65]465!%7T)/5$@["@H@
M("`@+RHJ"B`@("`@*B!4:&4@34E-12!I;F1E>"!K97D@=&\@=7-E+@H@("`@
M("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VUI;65K
M97D@/2!N=6QL.PH*("`@("\J*@H@("`@("H@5&AE(&%C=&EO;DE$('9A;'5E
M(&9O<B!V87)I;W5S(&%C=&EO;G,N"B`@("`@*B`G9&]W;FQO860G("`M+2`@
M1&]W;FQO861I;F<@82!P87)T+V%T=&%C:&UE;G0N"B`@("`@*B`G=FEE=R<@
M("`@("`M+2`@5FEE=VEN9R!A('!A<G0O871T86-H;65N="X*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W9I97=)1"`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!3:&]W('1H92!L:6YK<R!I;B!T:&4@
M<W5M;6%R:65S/PH@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO
M"B`@("!V87(@)%]L:6YK<R`]('1R=64["@H@("`@+RHJ"B`@("`@*B!4:&4@
M8F%S92!-24U%7T-O;G1E;G1S(&]B:F5C="X*("`@("`J"B`@("`@*B!`=F%R
M($U)345?0V]N=&5N=',*("`@("`J+PH@("`@=F%R("1?8F%S92`](&YU;&P[
M"@H@("`@+RHJ"B`@("`@*B!4:&4@;G5M8F5R(&]F(&UE<W-A9V4O<F9C.#(R
M(&QE=F5L<R!L86)E;&5D(&%S("=A='1A8VAM96YT<R<@;V8@=&AE"B`@("`@
M*B!C=7)R96YT('!A<G0N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@
M("`@*B\*("`@('9A<B`D7V%T=&%C:#@R,B`](#`["@H@("`@+RHJ"B`@("`@
M*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@34E-15]-97-S
M86=E("1M97-S86=E3V(@(%1H92!O8FIE8W0@=&\@=V]R:R!W:71H+@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1V:65W240@("`@("`@("`@("!4:&4@86-T:6]N
M240@=F%L=65S(&9O<B!V:65W:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('!A<G1S+V%T=&%C:&UE;G1S+@H@("`@("H@0'!A
M<F%M(&%R<F%Y("8D8V]N=&5N=',@("`@("`@("!!<G)A>2!C;VYT86EN:6YG
M(&$@<VEN9VQE('9A;'5E.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A(')E9F5R96YC92!T;R!T:&4@8F%S92!O8FIE8W0N"B`@
M("`@*B`H5&AI<R!L87-T('!A<F%M971E<B!N965D<R!T;R!B92!H86YD;&5D
M('9I82!A;B!A<G)A>2!B96-A=7-E(%!(4"`\"B`@("`@*B`@-2XP(&1O97-N
M)W0@:&%N9&QE(&]P=&EO;F%L('!O:6YT97(@<&%R86UE=&5R<R!O=&AE<G=I
M<V4N*0H@("`@("HO"B`@("!F=6YC=&EO;B!-24U%7T-O;G1E;G1S*"1M97-S
M86=E3V(L("1V:65W240@/2!A<G)A>2@I+"`D8V]N=&5N=',@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;65S<V%G92`]("1M97-S86=E3V([
M"B`@("`@("`@)'1H:7,M/E]C86-H96UE<W-A9V4@/2!5=&EL.CIC;&]N94]B
M:F5C="@D;65S<V%G94]B*3L*("`@("`@("`D=&AI<RT^7W9I97=)1"`]("1V
M:65W240["@H@("`@("`@("\J($-R96%T92!T:&4@<&]I;G1E<B!T;R!T:&4@
M8F%S92!O8FIE8W0N("HO"B`@("`@("`@:68@*"%E;7!T>2@D8V]N=&5N=',I
M*2!["B`@("`@("`@("`@("1P='(@/2!R97-E="@D8V]N=&5N=',I.PH@("`@
M("`@("`@("`D;VQD7W!T<B`]("8D<'1R+3YG971"87-E3V)J96-T4'1R*"D[
M"B`@("`@("`@("`@("1T:&ES+3Y?8F%S92`]("1O;&1?<'1R.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&5N=&ER92!B
M;V1Y(&]F('1H92!M97-S86=E+@H@("`@("H@66]U('!R;V)A8FQY('=A;G0@
M=&\@;W9E<G)I9&4@=&AI<R!F=6YC=&EO;B!I;B!A;GD@<W5B8VQA<W,N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!T97AT(&]F('1H92!B
M;V1Y(&]F('1H92!M97-S86=E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971"
M;V1Y*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]M97-S86=E+3YT
M;U-T<FEN9R@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M<F%W('1E>'0@9F]R(&]N92!S96-T:6]N(&]F('1H92!M97-S86=E+@H@("`@
M("H@66]U('!R;V)A8FQY('=A;G0@=&\@;W9E<G)I9&4@=&AI<R!F=6YC=&EO
M;B!I;B!A;GD@<W5B8VQA<W,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D:60@(%1H92!)1"!O9B!T:&4@34E-15]087)T+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@=&5X="!O9B!T:&4@<&%R="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T0F]D>5!A<G0H)&ED*0H@("`@>PH@("`@("`@
M(&EF("@H)'!A<G0@/2`F)'1H:7,M/F=E=$U)345087)T*"1I9"DI*2!["B`@
M("`@("`@("`@(')E='5R;B`D<&%R="T^9V5T0V]N=&5N=',H*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@34E-15]-97-S86=E
M(&]B:F5C="!F;W(@=&AE(&UA:6P@;65S<V%G92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N($U)345?365S<V%G92`@02!-24U%7TUE<W-A9V4@;V)J96-T+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971-24U%365S<V%G92@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?;65S<V%G93L*("`@('T*"B`@("`O*BH*
M("`@("`J($9E=&-H(&$@<&%R="!O9B!A($U)344@;65S<V%G92X*("`@("`J
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:60@(%1H92!-24U%(&EN9&5X(&]F
M('1H92!P87)T(')E<75E<W1E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N($U)
M345?4&%R="`@5&AE(')A=R!-24U%('!A<G0@87-K960@9F]R+@H@("`@("HO
M"B`@("!F=6YC=&EO;B`F9V5T34E-15!A<G0H)&ED*0H@("`@>PH@("`@("`@
M("1P87)T(#T@)'1H:7,M/E]M97-S86=E+3YG971087)T*"1I9"D["B`@("`@
M("`@<F5T=7)N("1P87)T.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5B=6EL
M9"!T:&4@34E-15]087)T('-T<G5C='5R92!O9B!A(&UE<W-A9V4N"B`@("`@
M*B!9;W4@<')O8F%B;'D@=V%N="!T;R!O=F5R<FED92!T:&ES(&9U;F-T:6]N
M(&EN(&%N>2!S=6)C;&%S<RX*("`@("`J"B`@("`@*B!`<F5T=7)N($U)345?
M365S<V%G92`@02!-24U%7TUE<W-A9V4@;V)J96-T('=I=&@@86QL(&]F('1H
M92!B;V1Y('1E>'0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!S=&]R
M960@:6X@=&AE(&EN9&EV:61U86P@34E-15]087)T<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@<F5B=6EL9$UE<W-A9V4H*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7VUE<W-A9V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&971C
M:"!P87)T(&]F(&$@34E-12!M97-S86=E+@H@("`@("H*("`@("`J($!P87)A
M;2!I;G1E9V5R("1I9"`@(%1H92!-24U%($E$(&]F('1H92!P87)T(')E<75E
M<W1E9"X*("`@("`J($!P87)A;2!B;V]L96%N("1A;&P@($EF('1H:7,@:7,@
M82!H96%D97(@<&%R="P@<VAO=6QD('=E(')E='5R;B!A;&P@=&5X=`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@:6X@=&AE(&)O9'D_"B`@("`@*@H@
M("`@("H@0')E='5R;B!-24U%7U!A<G0@(%1H92!-24U%7U!A<G0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N("9G971287=-24U%4&%R="@D:60L("1A;&P@/2!F
M86QS92D*("`@('L*("`@("`@("`D;6EM95]P87)T(#T@)B1T:&ES+3YG971-
M24U%4&%R="@D:60I.PH@("`@("`@(&EF("@A:7-?82@D;6EM95]P87)T+"`G
M34E-15]087)T)RDI('L*("`@("`@("`@("`@)&UI;65?<&%R="`](&YU;&P[
M"B`@("`@("`@("`@(')E='5R;B`D;6EM95]P87)T.PH@("`@("`@('T*"B`@
M("`@("`@+RH@268@86QL('1E>'0@:7,@<F5Q=65S=&5D+"!C:&%N9V4@=&AE
M($E$(&YO=RX@*B\*("`@("`@("!I9B`H)&%L;"`F)B`D;6EM95]P87)T+3YG
M971);F9O<FUA=&EO;B@G:&5A9&5R)RDI('L*("`@("`@("`@("`@)&ED(#T@
M<W5B<W1R*"1I9"P@,"P@<W1R<G!O<R@D:60L("<N)RDI.PH@("`@("`@('T*
M"B`@("`@("`@+RH@3VYL>2!S970@8V]N=&5N=',@:68@=&AE<F4@:7,@8W5R
M<F5N=&QY(&YO;F4@:6X@=&AE($U)344@4&%R="X@*B\*("`@("`@("!I9B`H
M(21M:6UE7W!A<G0M/F=E=$-O;G1E;G1S*"DI('L*("`@("`@("`@("`@)&UI
M;65?<&%R="T^<V5T0V]N=&5N=',H)'1H:7,M/F=E=$)O9'E087)T*"1I9"DI
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1M:6UE7W!A<G0["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!&971C:"!P87)T(&]F(&$@34E-12!M97-S86=E
M(&%N9"!D96-O9&4@:70L(&EF(&ET(&ES(&)A<V5?-C0@;W(*("`@("`J('%P
M<FEN="!E;F-O9&5D+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1I
M9"`@(%1H92!-24U%($E$(&]F('1H92!P87)T(')E<75E<W1E9"X*("`@("`J
M($!P87)A;2!B;V]L96%N("1A;&P@($EF('1H:7,@:7,@82!H96%D97(@<&%R
M="P@<VAO=6QD('=E(')E='5R;B!A;&P@=&5X=`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@:6X@=&AE(&)O9'D_"B`@("`@*@H@("`@("H@0')E='5R
M;B!-24U%7U!A<G0@(%1H92!-24U%7U!A<G0@=VET:"!I=',@8V]N=&5N=',@
M9&5C;V1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=$1E8V]D961-24U%
M4&%R="@D:60L("1A;&P@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H*"1M
M:6UE7W!A<G0@/2`F)'1H:7,M/F=E=%)A=TU)345087)T*"1I9"P@)&%L;"DI
M*2!["B`@("`@("`@("`@("1M:6UE7W!A<G0M/G1R86YS9F5R1&5C;V1E0V]N
M=&5N=',H*3L*("`@("`@("`@("`@+R\@3F]O<"X*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D;6EM95]P87)T(#T@;G5L;#L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N("1M:6UE7W!A<G0["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FX@=&AE(&%T=&%C:&UE;G0@;&ES="`H2%1-3"!T86)L92!F;W)M
M870I+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;&ES="!O
M9B!A='1A8VAM96YT<R!F;W)M871T960@:6YT;R!(5$U,+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971!='1A8VAM96YT<R@I"B`@("!["B`@("`@("`@)&US
M9R`]("<G.PH*("`@("`@("`D86ME>7,@/2!A<G)A>5]K97ES*"1T:&ES+3Y?
M871C*3L*("`@("`@("!N871S;W)T*"1A:V5Y<RD["B`@("`@("`@9F]R96%C
M:"`H)&%K97ES(&%S("1K97DI('L*("`@("`@("`@("`@)&US9R`N/2`D=&AI
M<RT^7V%R<F%Y5&]486)L95)O=R@D=&AI<RT^7V%T8ULD:V5Y72D["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&US9SL*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;B!T:&4@;65S<V%G92!L:7-T("A(5$U,('1A8FQE(&9O<FUA
M="DN"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&]N969R86UE("!3
M:&]U;&0@=&AE(&]U='!U="!B92!D97-I9VYE9"!F;W(@9&ES<&QA>2!I;B!A
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@('-I;F=L92!F<F%M
M93\*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&UE<W-A9V4@
M9F]R;6%T=&5D(&EN=&\@2%1-3"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M365S<V%G92@D;VYE9G)A;64@/2!F86QS92D*("`@('L*("`@("`@("`D;7-G
M(#T@)R<["B`@("`@("`@)&US9T-O=6YT(#T@8V]U;G0H)'1H:7,M/E]P87)T
M<RD["B`@("`@("`@)'!A<G1$:7-P;&%Y960@/2!F86QS93L*"B`@("`@("`@
M:68@*"1O;F5F<F%M92D@>PH@("`@("`@("`@("`D;7-G("X]("<\<W1Y;&4@
M='EP93TB=&5X="]C<W,B/BYO;F5F<B![<&%D9&EN9SHQ<'@[(&UA<F=I;BUB
M;W1T;VTZ,7!X.R!B;W)D97(Z,7!X(&1A<VAE9"`C,#!C.R!B86-K9W)O=6YD
M.B-E968[(&-O;&]R.B,P,#9]/"]S='EL93XG("X@(EQN(CL*("`@("`@("!]
M"@H@("`@("`@("\O(%1/1$\Z(%1E;7!O<F%R>2!H86-K('1O(&1I<W!L87D@
M:&5A9&5R(&EN9F\@9F]R(&$@;65S<V%G92!W:71H(&]N90H@("`@("`@("\O
M($U)344@<&%R="!T:&%T(&-A;FYO="!B92!D:7-P;&%Y960@:6YL:6YE+@H@
M("`@("`@(&EF("@A)&US9T-O=6YT('Q\("@D;7-G0V]U;G0@/3T@,2`F)B`A
M<F5S970H)'1H:7,M/E]P87)T<RDI*2!["B`@("`@("`@("`@("1T:&ES+3YS
M9713=6UM87)Y*"1T:&ES+3Y?;65S<V%G92P@)W!A<G0G*3L*("`@("`@("`@
M("`@)&US9T-O=6YT(#T@,3L*("`@("`@("!]"B`@("`@("`@("`@(`H@("`@
M("`@(&9O<F5A8V@@*"1T:&ES+3Y?<&%R=',@87,@)&ME>2`]/B`D=F%L=64I
M('L*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<W5M;6%R>5LD:V5Y
M72D@)B8*("`@("`@("`@("`@("`@("@H*"1M<V=#;W5N="`]/2`Q*2`F)B!E
M;7!T>2@D=F%L=64I*2!\?"`H)&US9T-O=6YT(#X@,2DI*2!["B`@("`@("`@
M("`@("`@("`D;7-G("X]("<\='(^/'1D/B<["B`@("`@("`@("`@("`@("!I
M9B`H)&]N969R86UE*2!["B`@("`@("`@("`@("`@("`@("`@)&US9R`N/2`G
M/'1A8FQE(&-L87-S/2)O;F5F<B(^)SL*("`@("`@("`@("`@("`@("`@("`D
M<W5M;6%R>2`]("1T:&ES+3Y?<W5M;6%R>5LD:V5Y73L*("`@("`@("`@("`@
M("`@("`@("`D<W5M;6%R>2`](&%R<F%Y7VUE<F=E*&%R<F%Y7W-P;&EC92@D
M<W5M;6%R>2P@,"P@,2DL(&%R<F%Y7W-P;&EC92@D<W5M;6%R>2P@,2DI.PH@
M("`@("`@("`@("`@("`@("`@("1M<V<@+CT@)'1H:7,M/E]A<G)A>51O5&%B
M;&52;W<H)'-U;6UA<GDI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`D;7-G("X]("<\=&%B;&4^)SL*("`@("`@("`@
M("`@("`@("`@("`D;7-G("X]("1T:&ES+3Y?87)R87E4;U1A8FQE4F]W*"1T
M:&ES+3Y?<W5M;6%R>5LD:V5Y72D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D;7-G("X]("<\+W1A8FQE/CPO=&0^/"]T<CXG.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&EF("@A96UP='DH)'9A;'5E*2D@>PH@
M("`@("`@("`@("`@("`@)&US9R`N/2`G/'1R/CQT9"!C;&%S<STB=&5X="(^
M)R`N("1V86QU92`N("<\+W1D/CPO='(^)SL*("`@("`@("`@("`@("`@("1P
M87)T1&ES<&QA>65D(#T@=')U93L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@:68@*"$D<&%R=$1I<W!L87EE9"D@>PH@("`@("`@("`@("`D
M;7-G("X]("<\='(^/'1D(&-L87-S/2)T97AT(B!A;&EG;CTB;&5F="(^/&5M
M/B<@+B!?*")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA
M>65D(&EN;&EN92XB*2`N("<\+V5M/CPO=&0^/"]T<CXG.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1M<V<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%
M>'!A;F1S(&%N(&%R<F%Y(&EN=&\@82!T86)L92!R;W<N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1A<G)A>2`@5&AE(&%R<F%Y('1O(&5X<&%N9"X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(&%R<F%Y(&5X<&%N9&5D('1O(&$@2%1-3"!T
M86)L92!R;W<N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A<G)A>51O5&%B;&52
M;W<H)&%R<F%Y*0H@("`@>PH@("`@("`@("1T97AT(#T@)SQT<B!V86QI9VX]
M(FUI9&1L92(^)SL*"B`@("`@("`@9F]R96%C:"`H)&%R<F%Y(&%S("1E;&5M
M*2!["B`@("`@("`@("`@(&EF("@A96UP='DH)&5L96TI*2!["B`@("`@("`@
M("`@("`@("`D=&5X="`N/2`B/'1D/B1E;&5M)FYB<W`[/"]T9#Y<;B(["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&5X="`N
M("(\+W1R/EQN(CL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE
M(&1A=&$@9F]R(&$@<W!E8VEF:6,@34E-12!I;F1E>"X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1I9"`@("`@5&AE($U)344@:6YD97@N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1F:65L9"`@5&AE(&9I96QD('1O(')E='5R;B`H
M;65S<V%G92P@871C+"!S=6UM87)Y*0H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@=&5X="!C=7)R96YT;'D@<V5T(&9O<B!T:&%T(&EN9&5X
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971);F1E>"@D:60L("1F:65L9"D*
M("`@('L*("`@("`@("`D9FEE;&0@/2`G7R<@+B`D9FEE;&0["B`@("`@("`@
M:68@*&ES7V%R<F%Y*"1T:&ES+3XD9FEE;&0I("8F(&%R<F%Y7VME>5]E>&ES
M=',H)&ED+"`D=&AI<RT^)&9I96QD*2D@>PH@("`@("`@("`@("`D96YT<GD@
M/2`D=&AI<RT^)&9I96QD.PH@("`@("`@("`@("!R971U<FX@)&5N=')Y6R1I
M9%T["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E<R!T:&4@
M;65S<V%G92!T97AT(&%N9"!S=6UM87)Y(&9O<B!A('-P96-I9FEC($U)344@
M:6YD97@N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@(%1H92!-
M24U%(&EN9&5X+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F5);F1E>"@D
M:60I"B`@("!["B`@("`@("`@=6YS970H)'1H:7,M/E]P87)T<ULD:61=*3L*
M("`@("`@("!U;G-E="@D=&AI<RT^7W-U;6UA<GE;)&ED72D["B`@("`@("`@
M=6YS970H)'1H:7,M/E]A=&-;)&ED72D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!$971E<FUI;F4@:68@=V4@8V%N("AA;F0@:VYO=R!H;W<@=&\I(&EN;&EN
M92!A($U)344@4&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@34E-15]087)T
M("8D;6EM95]P87)T("!!($U)345?4&%R="!O8FIE8W0N"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('!A<G0@8V%N(&)E(&EN;&EN
M960N"B`@("`@*B`@("`@("`@("`@("`@("`@($9A;'-E(&EF(&ET(&-A;FYO
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@8V%N1&ES<&QA>4EN;&EN92@F)&UI
M;65?<&%R="D*("`@('L*("`@("`@("`D=FEE=V5R(#T@)B1T:&ES+3YG971-
M24U%5FEE=V5R*"1M:6UE7W!A<G0I.PH*("`@("`@("`O*B!&:7)S="!C:&5C
M:SH@5&AE($U)344@:&5A9&5R<R!A;&QO=R!T:&4@<&%R="!T;R!B92!I;FQI
M;F5D+@H@("`@("`@("`J($AO=V5V97(L(&EF('=E(&%R92!A;')E861Y(&EN
M('9I97<@;6]D92P@=&AE;B!W92!C86X@<VMI<"!T:&ES"B`@("`@("`@("H@
M8VAE8VLN("HO"B`@("`@("`@:68@*"$D=&AI<RT^=FEE=T%S071T86-H;65N
M="@I("8F"B`@("`@("`@("`@("@D;6EM95]P87)T+3YG971$:7-P;W-I=&EO
M;B@I("$]("=I;FQI;F4G*2`F)@H@("`@("`@("`@("`A)'9I97=E<BT^9F]R
M8V5);FQI;F56:65W*"DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@+RH@4V5C;VYD(&-H96-K("AS879E('1H92!M
M;W-T(&5X<&5N<VEV92!F;W(@;&%S="DZ"B`@("`@("`@("H@0VAE8VL@=&\@
M<V5E(&EF('1H92!D<FEV97(@:7,@<V5T('1O(&EN;&EN92X@*B\*("`@("`@
M("!R971U<FX@*&ES7V$H)'9I97=E<BP@)TU)345?5FEE=V5R)RD@)B8@)'9I
M97=E<BT^8V%N1&ES<&QA>4EN;&EN92@I*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($=E="!-24U%7U9I97=E<B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A
M<F%M($U)345?4&%R="`F)&UI;65?<&%R="`@02!-24U%7U!A<G0@;V)J96-T
M+@H@("`@("H*("`@("`J($!R971U<FX@34E-15]6:65W97(@(%1H92!-24U%
M7U9I97=E<B!O8FIE8W0L(&]R(&9A;'-E(&]N(&5R<F]R+@H@("`@("HO"B`@
M("!F=6YC=&EO;B`F9V5T34E-159I97=E<B@F)&UI;65?<&%R="D*("`@('L*
M("`@("`@("`O*B!-86ME('-U<F4@=V4@:&%V92!A($U)345?4&%R="!T;R!P
M<F]C97-S+B`J+PH@("`@("`@(&EF("AE;7!T>2@D;6EM95]P87)T*2D@>PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R
M97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+U9I97=E<BYP:'`G
M.PH*("`@("`@("`D:V5Y(#T@)&UI;65?<&%R="T^9V5T56YI<75E240H*2`N
M("=\)R`N("1M:6UE7W!A<G0M/F=E=%1Y<&4H*3L*("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3Y?=FEE=V5R0V%C:&5;)&ME>5TI*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?=FEE=V5R0V%C:&5;)&ME>5T@/2`F34E-15]6:65W97(Z.F9A
M8W1O<GDH)&UI;65?<&%R="D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)'1H:7,M/E]V:65W97)#86-H95LD:V5Y73L*("`@('T*"B`@("`O*BH*("`@
M("`J($=E="!T:&4@34E-12!#;VYT96YT+51Y<&4@;W5T<'5T(&)Y(&$@34E-
M15]6:65W97(@9F]R(&$@<&%R=&EC=6QA<@H@("`@("H@34E-15]087)T+@H@
M("`@("H*("`@("`J($!P87)A;2!-24U%7U!A<G0@)B1M:6UE7W!A<G0@($$@
M34E-15]087)T(&]B:F5C="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE($U)344@='EP92!O=71P=70@8GD@=&AE($U)345?5FEE=V5R+"!O
M<B!F86QS92!O;@H@("`@("H@("`@("`@("`@("`@("`@(&5R<F]R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971-24U%5FEE=V5R5'EP92@F)&UI;65?<&%R
M="D*("`@('L*("`@("`@("!I9B`H*"1V:65W97(@/2`F)'1H:7,M/F=E=$U)
M3456:65W97(H)&UI;65?<&%R="DI*2!["B`@("`@("`@("`@(')E='5R;B`D
M=FEE=V5R+3YG9714>7!E*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE(&ME>2!T;R!U<V4@9F]R(&$@<&%R=&EC=6QA<B!-
M24U%7U!A<G0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0'!A<F%M($U)345?4&%R="`F)&UI;65?<&%R="`@02!-24U%
M7U!A<G0@;V)J96-T+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&]V97)R:61E
M("`@("`@4F5S<&5C="!T:&4@34E-12!K97D@;W9E<G)I9&4@=F%L=64_"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!U;FEQ=64@:61E;G1I
M9FEE<B!O9B!T:&4@34E-15]087)T+@H@("`@("H@("`@("`@("`@("`@("`@
M(%)E='5R;G,@9F%L<V4@:68@;F\@:V5Y(&9O=6YD+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?9V5T34E-14ME>2@F)&UI;65?<&%R="P@)&]V97)R:61E(#T@
M=')U92D*("`@('L*("`@("`@("`D:60@/2`D=&AI<RT^9V5T34E-14ME>4]V
M97)R:61E*"D["@H@("`@("`@(&EF("@D;W9E<G)I9&4@)B8@(6ES7VYU;&PH
M)&ED*2D@>PH@("`@("`@("`@("!R971U<FX@)&ED.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1I9"`]("1M:6UE7W!A<G0M/F=E=$U)345)9"@I
M.PH@("`@("`@("`@("!I9B`H:7-?;G5L;"@D:60I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("!R971U<FX@)&ED.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@34E-12!K97D@;W9E
M<G)I9&4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!-24U%
M(&ME>2!O=F5R<FED92`M(&YU;&P@:68@;F\@;W9E<G)I9&4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=$U)345+97E/=F5R<FED92@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?;6EM96ME>3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%-E=',@86X@;W9E<G)I9&4@9F]R('1H92!-24U%(&ME>2X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1M:6UE:V5Y"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-E=$U)345+97E/=F5R<FED92@D;6EM96ME>2`](&YU;&PI"B`@
M("!["B`@("`@("`@)'1H:7,M/E]M:6UE:V5Y(#T@)&UI;65K97D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!3:&]U;&0@=V4@9&ES<&QA>2!L:6YK<R!F;W(@
M=&AE('-U;6UA<FEE<S\*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M<VAO=R`@4VAO=R!T:&4@<W5M;6%R>2!L:6YK<S\*("`@("`J+PH@("`@9G5N
M8W1I;VX@<VAO=U-U;6UA<GE,:6YK<R@D<VAO=R`](&YU;&PI"B`@("!["B`@
M("`@("`@:68@*"%I<U]N=6QL*"1S:&]W*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^7VQI;FMS(#T@)'-H;W<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)'1H:7,M/E]L:6YK<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E;F1E<B!A
M($U)344@4&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@34E-15]087)T("8D
M;6EM95]P87)T("!!($U)345?4&%R="!O8FIE8W0N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!R96YD97)E9"!D871A+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!R96YD97)-24U%4&%R="@F)&UI;65?<&%R="D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]R96YD97)-24U%4&%R="@D;6EM95]P
M87)T+"!F86QS92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296YD97(@34E-
M12!087)T(&%T=&%C:&UE;G0@:6YF;RX*("`@("`J"B`@("`@*B!`<&%R86T@
M34E-15]087)T("8D;6EM95]P87)T("!!($U)345?4&%R="!O8FIE8W0N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!R96YD97)E9"!D871A
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97)-24U%071T86-H;65N=$EN
M9F\H)B1M:6UE7W!A<G0I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M<F5N9&5R34E-15!A<G0H)&UI;65?<&%R="P@=')U92D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!296YD97(@34E-12!087)T(&1A=&$N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M($U)345?
M4&%R="`F)&UI;65?<&%R="`@02!-24U%7U!A<G0@;V)J96-T+@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)&%T=&%C:&UE;G0@("`@4F5N9&5R($U)344@4&%R
M="!A='1A8VAM96YT(&EN9F\_"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!R96YD97)E9"!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M<F5N9&5R34E-15!A<G0H)B1M:6UE7W!A<G0L("1A='1A8VAM96YT(#T@9F%L
M<V4I"B`@("!["B`@("`@("`@+RH@1V5T('1H92!-24U%7U9I97=E<B!O8FIE
M8W0@9F]R('1H:7,@34E-12!P87)T("HO"B`@("`@("`@)'9I97=E<B`]("8D
M=&AI<RT^9V5T34E-159I97=E<B@D;6EM95]P87)T*3L*("`@("`@("!I9B`H
M(6ES7V$H)'9I97=E<BP@)TU)345?5FEE=V5R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("<G.PH@("`@("`@('T*"B`@("`@("`@)&US9R`]("<G.PH*("`@
M("`@("`D;6EM95]P87)T+3YT<F%N<V9E<D1E8V]D94-O;G1E;G1S*"D["@H@
M("`@("`@("\J($EF('1H:7,@:7,@82!T97AT+RH@<&%R="P@04Y$('1H92!T
M97AT(&ES(&EN(&$@9&EF9F5R96YT(&-H87)A8W1E<@H@("`@("`@("`J('-E
M="!T:&%N('1H92!B<F]W<V5R+"!C;VYV97)T('1O('1H92!C=7)R96YT(&-H
M87)A8W1E<B!S970N"B`@("`@("`@("H@061D:71I;VYA;&QY+"!I9B!T:&4@
M8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T(%541BTX+"!G:79E('1H90H@("`@
M("`@("`J('5S97(@82!L:6YK('1O(&]P96X@=&AE('!A<G0@:6X@82!N97<@
M=VEN9&]W('=I=&@@=&AE(&-O<G)E8W0*("`@("`@("`@*B!C:&%R86-T97(@
M<V5T+B`J+PH@("`@("`@("1C:&%R<V5T(#T@)&UI;65?<&%R="T^9V5T0VAA
M<G-E="@I.PH@("`@("`@(&EF("@D8VAA<G-E="D@>PH@("`@("`@("`@("`D
M8VAA<G-E=%]U<'!E<B`](%-T<FEN9SHZ=7!P97(H)&-H87)S970I.PH@("`@
M("`@("`@("!I9B`H*"1C:&%R<V5T7W5P<&5R("$]("=54RU!4T-)22<I("8F
M"B`@("`@("`@("`@("`@("`A)'1H:7,M/G9I97=!<T%T=&%C:&UE;G0H*2D@
M>PH@("`@("`@("`@("`@("`@)&1E9F%U;'1?8VAA<G-E="`](%-T<FEN9SHZ
M=7!P97(H3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@("`@("`@("`@("`@:68@
M*"1C:&%R<V5T7W5P<&5R("$]("1D969A=6QT7V-H87)S970I('L*("`@("`@
M("`@("`@("`@("`@("`D;6EM95]P87)T+3YS971#;VYT96YT<RA3=')I;F<Z
M.F-O;G9E<G1#:&%R<V5T*"1M:6UE7W!A<G0M/F=E=$-O;G1E;G1S*"DL("1C
M:&%R<V5T+"`D9&5F875L=%]C:&%R<V5T*2D["B`@("`@("`@("`@("`@("`@
M("`@)&UI;65?<&%R="T^<V5T0VAA<G-E="@D9&5F875L=%]C:&%R<V5T*3L*
M("`@("`@("`@("`@("`@("`@("!I9B`H)&1E9F%U;'1?8VAA<G-E="`A/2`G
M551&+3@G*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1S=&%T=7,@/2!A
M<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@('-P<FEN=&8H7R@B
M5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H
M)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(BDL(&AT;6QS<&5C:6%L8VAA<G,H
M)&-H87)S970I*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@('-P<FEN
M=&8H7R@B268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O
M(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(I+"`D=&AI<RT^;&EN:U9I97=*
M4R@D;6EM95]P87)T+"`G=FEE=U]A='1A8V@G+"!?*")C;&EC:R!H97)E(BDI
M*0H@("`@("`@("`@("`@("`@("`@("`@("`I.PH@("`@("`@("`@("`@("`@
M("`@("`@("`D;7-G(#T@)'1H:7,M/F9O<FUA=%-T871U<TUS9R@D<W1A='5S
M+"!N=6QL+"!F86QS92D@+B`D;7-G.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@)'9I97=E<BT^<V5T34E-15!A<G0H)&UI;65?<&%R="D["B`@("`@
M("`@)'!A<F%M<R`](&%R<F%Y*"8D=&AI<RD["B`@("`@("`@:68@*"1A='1A
M8VAM96YT*2!["B`@("`@("`@("`@("1M<V<@+CT@)'9I97=E<BT^<F5N9&5R
M071T86-H;65N=$EN9F\H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&US9R`N/2`D=FEE=V5R+3YR96YD97(H)'!A<F%M<RD["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&US9SL*("`@('T*"B`@("`O*BH*
M("`@("`J($)U:6QD('1H92!M97-S86=E(&1E8VED:6YG('=H870@34E-12!0
M87)T<R!T;R!S:&]W+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@
M1F%L<V4@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&)U:6QD365S
M<V%G92@I"B`@("!["B`@("`@("`@)'1H:7,M/E]A=&,@/2!A<G)A>2@I.PH@
M("`@("`@("1T:&ES+3Y?<&%R=',@/2!A<G)A>2@I.PH@("`@("`@("1T:&ES
M+3Y?<W5M;6%R>2`](&%R<F%Y*"D["@H@("`@("`@(&EF("@A:7-?82@D=&AI
M<RT^7VUE<W-A9V4L("=-24U%7TUE<W-A9V4G*2D@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O*B!.;W<@9&ES<&QA
M>2!T:&4@<&%R=',N("HO"B`@("`@("`@)&UI;65?<&%R="`]("1T:&ES+3Y?
M;65S<V%G92T^9V5T0F%S95!A<G0H*3L*("`@("`@("`D=&AI<RT^8G5I;&1-
M97-S86=E4&%R="@D;6EM95]P87)T*3L*"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!0<F]C97-S97,@82!-24U%7U!A<G0@
M86YD('-T;W)E<R!T:&4@9&ES<&QA>2!I;F9O<FUA=&EO;B!I;B!T:&4@:6YT
M97)N86P*("`@("`J(&-L87-S('9A<FEA8FQE<RX*("`@("`J"B`@("`@*B!`
M<&%R86T@34E-15]087)T("8D;6EM95]P87)T("!4:&4@34E-15]087)T(&]B
M:F5C="!T;R!P<F]C97-S+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@<F5N9&5R960@=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@8G5I
M;&1-97-S86=E4&%R="@F)&UI;65?<&%R="D*("`@('L*("`@("`@("`D;7-G
M(#T@)R<["@H@("`@("`@("\J($EF('=E(&-A;B=T(&1I<W!L87D@=&AE('!A
M<G0@:6YL:6YE+"!A9&0@:70@=&\@=&AE(&%T=&%C:&UE;G0*("`@("`@("`@
M("!L:7-T+B!)9B!T:&4@34E-12!)1"!O9B!T:&4@8W5R<F5N="!P87)T(&ES
M("<P)RP@=&AE;B!F;W)C92!A"B`@("`@("`@("`@<F5N9&5R(&]F('1H92!P
M87)T("AS:6YC92!I="!I<R!T:&4@8F%S92!P87)T(&%N9"P@=VET:&]U=`H@
M("`@("`@("`@(&%T=&5M<'1I;F<@=&\@<F5N9&5R+"!T:&4@;65S<V%G92!W
M:6QL($%,5T%94R!A<'!E87(@96UP='DN("HO"B`@("`@("`@:68@*"$D=&AI
M<RT^8V%N1&ES<&QA>4EN;&EN92@D;6EM95]P87)T*2`F)@H@("`@("`@("`@
M("`H)&UI;65?<&%R="T^9V5T34E-14ED*"D@(3T@,"DI('L*("`@("`@("`@
M("`@+RH@3F]T(&1I<W!L87EI;F<@:6YL:6YE.R!A9&0@=&\@=&AE(&%T=&%C
M:&UE;G1S(&QI<W0N("HO"B`@("`@("`@("`@(&EF("@H)'1H:7,M/E]D:7-P
M;&%Y5'EP92`]/2!-24U%7T-/3E1%3E137T1)4U!,05E?5%E015],25-4*2!\
M?`H@("`@("`@("`@("`@("`@*"1T:&ES+3Y?9&ES<&QA>51Y<&4@/3T@34E-
M15]#3TY414Y44U]$25-03$%97U194$5?0D]42"DI('L*("`@("`@("`@("`@
M("`@("1T:&ES+3YS9713=6UM87)Y*"1M:6UE7W!A<G0L("=A='1A8VAM96YT
M)RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"@D=&AI<RT^7V1I
M<W!L87E4>7!E(#T]($U)345?0T].5$5.5%-?1$E34$Q!65]465!%7TE.3$E.
M12D@?'P*("`@("`@("`@("`@("`@("@D=&AI<RT^7V1I<W!L87E4>7!E(#T]
M($U)345?0T].5$5.5%-?1$E34$Q!65]465!%7T)/5$@I*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^<V5T4W5M;6%R>2@D;6EM95]P87)T+"`G<&%R="<I
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!#:&5C:R!T;R!S964@
M:68@86YY(&%T=&%C:&UE;G0@:6YF;W)M871I;VX@8V%N(&)E(')E;F1E<F5D
M(&)Y"B`@("`@("`@("`@("`@('1H92!-24U%7U9I97=E<BX@*B\*("`@("`@
M("`@("`@)&US9R`]("1T:&ES+3YR96YD97)-24U%071T86-H;65N=$EN9F\H
M)&UI;65?<&%R="D["B`@("`@("`@("`@(&EF("@A96UP='DH)&US9RDI('L*
M("`@("`@("`@("`@("`@("1K97D@/2`D=&AI<RT^7V=E=$U)345+97DH)&UI
M;65?<&%R="D["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<G1S6R1K97E=
M(#T@)&US9SL*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1M<V<@/2`D=&AI<RT^<F5N9&5R34E-15!A<G0H)&UI;65?<&%R
M="D["B`@("`@("`@("`@("1K97D@/2`D=&AI<RT^7V=E=$U)345+97DH)&UI
M;65?<&%R="D["B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]A='1A8V@X,C(I
M('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R='-;)&ME>5T@/2`D;7-G
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("\J(%-O;64@34E-15]6:65W
M97)S('-E="!T:&4@<W5M;6%R>2!B>2!T:&5M96QV97,L('-O(&]N;'D*("`@
M("`@("`@("`@("H@861D('1O(&%T=&%C:&UE;G0O:6YL:6YE(&QI<W1S(&EF
M(&YO=&AI;F<@:&%S(&)E96X@<V5T"B`@("`@("`@("`@("`J(&%S(&]F('EE
M="X@*B\*("`@("`@("`@("`@:68@*"@H)&UI;65?<&%R="T^9V5T5'EP92@I
M("$]("=M=6QT:7!A<G0O;6EX960G*2!\?`H@("`@("`@("`@("`@("`@("%E
M;7!T>2@D;7-G*2D@)B8*("`@("`@("`@("`@("`@("%E;7!T>2@D:V5Y*2`F
M)@H@("`@("`@("`@("`@("`@(21T:&ES+3YG971);F1E>"@D:V5Y+"`G<W5M
M;6%R>2<I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T4W5M;6%R>2@D
M;6EM95]P87)T+"`G<&%R="<I.PH@("`@("`@("`@("`@("`@:68@*"1T:&ES
M+3Y?871T86-H.#(R("8F"B`@("`@("`@("`@("`@("`@("`@*"@D=&AI<RT^
M7V1I<W!L87E4>7!E(#T]($U)345?0T].5$5.5%-?1$E34$Q!65]465!%7TQ)
M4U0I('Q\"B`@("`@("`@("`@("`@("`@("`@*"1T:&ES+3Y?9&ES<&QA>51Y
M<&4@/3T@34E-15]#3TY414Y44U]$25-03$%97U194$5?0D]42"DI*2!["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=%-U;6UA<GDH)&UI;65?<&%R
M="P@)V%T=&%C:&UE;G0G*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1M:6UE7W!A<G0M/F=E=$EN
M9F]R;6%T:6]N*"=H96%D97(G*2D@>PH@("`@("`@("`@("`O*B!)9B!T:&ES
M(&ES(&UE<W-A9V4O<F9C.#(R('!A<G0L(&%N9"!I="!I<R!M87)K960@87,@
M86X*("`@("`@("`@("`@("H@871T86-H;65N="P@=V4@;F5E9"!T;R!L970@
M9G5T=7)E(&-A;&QS('1O(&)U:6QD365S<V%G95!A<G0H*0H@("`@("`@("`@
M("`@*B!K;F]W('1H870@:70@<VAO=6QD(&UA<FL@96UB961D960@<&%R=',@
M87,@;F]T('9I97=A8FQE"B`@("`@("`@("`@("`J(&EN;&EN92X@*B\*("`@
M("`@("`@("`@)&EN8W)E;65N=%\X,C(@/2!F86QS93L*("`@("`@("`@("`@
M:68@*"@D;6EM95]P87)T+3YG9714>7!E*"D@/3T@)VUE<W-A9V4O<F9C.#(R
M)RD@)B8*("`@("`@("`@("`@("`@("@D;6EM95]P87)T+3YG971$:7-P;W-I
M=&EO;B@I(#T]("=A='1A8VAM96YT)RDI('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?871T86-H.#(R*RL["B`@("`@("`@("`@("`@("`D:6YC<F5M96YT
M7S@R,B`]('1R=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1M:6UE7W!A<G0M/F=E=%!A<G1S*"D@87,@)'!A<G0I('L*("`@("`@
M("`@("`@("`@("1M<V<@+CT@)'1H:7,M/F)U:6QD365S<V%G95!A<G0H)'!A
M<G0I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)&EN8W)E;65N
M=%\X,C(I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?871T86-H.#(R+2T[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;7-G
M.PH@("`@?0H*("`@("\J*@H@("`@("H@07)E('=E('9I97=I;F<@=&AI<R!P
M86=E(&%S(&%N(&%T=&%C:&UE;G0@=&AR;W5G:"!V:65W+G!H<#\*("`@("`J
M(%1H:7,@;65T:&]D(&-A;B!A;'-O(&)E(&-A;&QE9"!V:6$@34E-15]#;VYT
M96YT<SHZ=FEE=T%S071T86-H;65N="@I+@H@("`@("H*("`@("`J($!P87)A
M;2!B;V]L96%N("1P;W!U<"`@268@=')U92P@86QS;R!C:&5C:R!I9B!W92!A
M<F4@=FEE=VEN9R!A='1A8VAM96YT"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@(&EN('!O<'5P('9I97<@=VEN9&]W+@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;&5A;B`@5')U92!I9B!W92!A<F4@=FEE=VEN9R!T:&ES('!A
M<G0@87,@86X@871T86-H;65N=`H@("`@("H@("`@("`@("`@("`@("`@("!T
M:')O=6=H('9I97<N<&AP+@H@("`@("HO"B`@("!F=6YC=&EO;B!V:65W07-!
M='1A8VAM96YT*"1P;W!U<"`](&9A;'-E*0H@("`@>PH@("`@("`@(')E='5R
M;B`H*'-T<G!O<R@D7U-%4E9%4ELG4$A07U-%3$8G72P@)W9I97<N<&AP)RD@
M(3T](&9A;'-E*2`F)@H@("`@("`@("`@("`@("`@*"$D<&]P=7`@?'P@571I
M;#HZ9V5T1F]R;41A=&$H)W!O<'5P7W9I97<G*2DI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4V5T<R!A('-U;6UA<GD@96YT<GDN"B`@("`@*@H@("`@("H@
M0'!A<F%M($U)345?4&%R="`F)&UI;65?<&%R="`@5&AE($U)345?4&%R="!O
M8FIE8W0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E("`@("`@("`@("!4
M:&4@<W5M;6%R>2!C86-H92!T;R!U<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-E=%-U;6UA<GDH)B1M:6UE7W!A<G0L("1T>7!E*0H@("`@>PH@("`@("`@
M(&EF("@D='EP92`]/2`G871T86-H;65N="<I('L*("`@("`@("`@("`@)&-A
M8VAE(#T@)B1T:&ES+3Y?871C.PH@("`@("`@('T@96QS96EF("@D='EP92`]
M/2`G<&%R="<I('L*("`@("`@("`@("`@)&-A8VAE(#T@)B1T:&ES+3Y?<W5M
M;6%R>3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX["B`@
M("`@("`@?0H*("`@("`@("`D:V5Y(#T@)'1H:7,M/E]G971-24U%2V5Y*"1M
M:6UE7W!A<G0I.PH*("`@("`@("`D=&AI<RT^7W-U;6UA<GE4>7!E(#T@)'1Y
M<&4["B`@("`@("`@)'-U;6UA<GD@/2`D=&AI<RT^<&%R=%-U;6UA<GDH)&UI
M;65?<&%R="P@;G5L;"D["B`@("`@("`@)'1H:7,M/E]S=6UM87)Y5'EP92`]
M(&YU;&P["@H@("`@("`@(&EF("@A96UP='DH)'-U;6UA<GDI*2!["B`@("`@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)T<ULD:V5Y72DI('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%R='-;)&ME>5T@/2!N=6QL.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1C86-H95LD:V5Y72`]("1S=6UM87)Y
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86X@
M87)R87D@<W5M;6%R:7II;F<@82!P87)T(&]F(&$@34E-12!M97-S86=E+@H@
M("`@("H*("`@("`J($!P87)A;2!-24U%7U!A<G0@)B1M:6UE7W!A<G0@(%1H
M92!-24U%7U!A<G0@=&\@<W5M;6%R:7IE+@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)&=U97-S("`@("`@("`@27,@=&AI<R!A('1E;7!O<F%R>2!G=65S<V5D
M+71Y<&4@<&%R=#\*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@
M<W5M;6%R>2!O9B!T:&4@<&%R="X*("`@("`J("`@("`@("`@("`@("`@(%LP
M72`]($EC;VX*("`@("`J("`@("`@("`@("`@("`@(%LQ72`]($E-05`@240*
M("`@("`J("`@("`@("`@("`@("`@(%LR72`]($1E<V-R:7!T:6]N"B`@("`@
M*B`@("`@("`@("`@("`@("!;,UT@/2!-24U%(%1Y<&4*("`@("`J("`@("`@
M("`@("`@("`@(%LT72`](%-I>F4*("`@("`J("`@("`@("`@("`@("`@(%LU
M72`]($1O=VYL;V%D(&QI;FLO:6-O;@H@("`@("HO"B`@("!F=6YC=&EO;B!P
M87)T4W5M;6%R>2@F)&UI;65?<&%R="P@)&=U97-S(#T@9F%L<V4I"B`@("![
M"B`@("`@("`@)&%T=&%C:&UE;G0@/2`H)&UI;65?<&%R="T^9V5T1&ES<&]S
M:71I;VXH*2`]/2`G871T86-H;65N="<I.PH@("`@("`@("1B>71E<R`]("1M
M:6UE7W!A<G0M/F=E=$)Y=&5S*"D["B`@("`@("`@)&1E<V-R:7!T:6]N(#T@
M:'1M;'-P96-I86QC:&%R<R@D;6EM95]P87)T+3YG971$97-C<FEP=&EO;BAT
M<G5E+"!T<G5E*2D["B`@("`@("`@)'-U;6UA<GD@/2!A<G)A>2@I.PH@("`@
M("`@("1T>7!E(#T@:'1M;'-P96-I86QC:&%R<R@D;6EM95]P87)T+3YG9714
M>7!E*"DI.PH@("`@("`@("1V:65W97(@/2`F)'1H:7,M/F=E=$U)3456:65W
M97(H)&UI;65?<&%R="D["B`@("`@("`@:68@*"$D=FEE=V5R*2!["B`@("`@
M("`@("`@(')E='5R;B`D<W5M;6%R>3L*("`@("`@("!]"@H@("`@("`@("\J
M(%)E='5R;B!I9B!W92!S=&EL;"!D:61N)W0@9FEN9"!A(&YA=&EV92!M:6UE
M('9I97=E<@H@("`@("`@("`J(&9O<B!A(&=U97-S960@;6EM92!T>7!E+B`J
M+PH@("`@("`@(&EF("@D9W5E<W,@)B8@:7-?82@D=FEE=V5R+"`G34E-15]6
M:65W97)?9&5F875L="<I*2!["B`@("`@("`@("`@(')E='5R;B`D<W5M;6%R
M>3L*("`@("`@("!]"@H@("`@("`@("\J($=E="!T:&4@34E-12!I9"!I;F1E
M>"X@*B\*("`@("`@("`D:60@/2`D=&AI<RT^7V=E=$U)345+97DH)&UI;65?
M<&%R="D["@H@("`@("`@("\J($EC;VX@8V]L=6UN+B`J+PH@("`@("`@("1S
M=6UM87)Y6UT@/2!(;W)D93HZ:6UG*"1V:65W97(M/F=E=$EC;VXH)'1Y<&4I
M+"!N=6QL+"!N=6QL+"`G)RD["@H@("`@("`@("\J($YU;6)E<B!C;VQU;6XN
M("HO"B`@("`@("`@:68@*"@D=&AI<RT^7V1I<W!L87E4>7!E(#T]($U)345?
M0T].5$5.5%-?1$E34$Q!65]465!%7T)/5$@I("8F"B`@("`@("`@("`@("%I
M<U]N=6QL*"1T:&ES+3Y?<W5M;6%R>51Y<&4I*2!["B`@("`@("`@("`@("1S
M=6UM87)Y6UT@/2`G/&$@:60](FUI;65?8V]N=&5N='-?)R`N("1T:&ES+3Y?
M<W5M;6%R>51Y<&4@+B`G7R<@+B`D:60@+B`G(B!H<F5F/2(C;6EM95]C;VYT
M96YT<U\G("X@*"@D=&AI<RT^7W-U;6UA<GE4>7!E(#T]("=A='1A8VAM96YT
M)RD@/R=P87)T)R`Z("=A='1A8VAM96YT)RD@+B`G7R<@+B`D:60@+B`G(CXG
M("X@)&ED("X@)SPO83XG.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1S=6UM87)Y6UT@/2`D:60["B`@("`@("`@?0H*("`@("`@("`O*B!.86UE
M+W1E>'0@<&%R="!C;VQU;6XN("HO"B`@("`@("`@:68@*"$D=&AI<RT^7VQI
M;FMS('Q\"B`@("`@("`@("`@("@A)&%T=&%C:&UE;G0@)B8@96UP='DH)&)Y
M=&5S*2D@('Q\"B`@("`@("`@("`@("%I<W-E="@D=&AI<RT^7W9I97=)1%LG
M=FEE=R==*2!\?`H@("`@("`@("`@("!I<U]A*"1V:65W97(L("=-24U%7U9I
M97=E<E]D969A=6QT)RDI('L*("`@("`@("`@("`@)'-U;6UA<GE;72`]("1D
M97-C<FEP=&EO;CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<&%R
M86U?87)R87D@/2!A<G)A>2@I.PH@("`@("`@("`@("!I9B`H)&=U97-S(#T]
M/2!T<G5E*2!["B`@("`@("`@("`@("`@("`D<&%R86U?87)R87E;)V-T>7!E
M)UT@/2`D='EP93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<W5M;6%R
M>5M=(#T@)'1H:7,M/FQI;FM6:65W2E,H)&UI;65?<&%R="P@)'1H:7,M/E]V
M:65W241;)W9I97<G72P@)&1E<V-R:7!T:6]N+"!N=6QL+"!N=6QL+"`D<&%R
M86U?87)R87DI.PH@("`@("`@('T*"B`@("`@("`@+RH@34E-12!T>7!E(&-O
M;'5M;BX@*B\*("`@("`@("!I9B`H)&=U97-S*2!["B`@("`@("`@("`@("1S
M=6UM87)Y6UT@/2`G/&5M/B<@+B!S<')I;G1F*%\H(E9I97<@87,@)7,B*2P@
M)'1Y<&4I("X@)SPO96T^)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D<W5M;6%R>5M=(#T@)ULG("X@)'1Y<&4@+B`G72<["B`@("`@("`@?0H*
M("`@("`@("`O*B!3:7IE($-O;'5M;BX@*B\*("`@("`@("`D<VEZ92`]("1M
M:6UE7W!A<G0M/F=E=%-I>F4H=')U92D["B`@("`@("`@:68@*"%E;7!T>2@D
M8GET97,I("8F"B`@("`@("`@("`@("@D;6EM95]P87)T+3YG971#=7)R96YT
M16YC;V1I;F<H*2`]/2`G8F%S938T)RDI('L*("`@("`@("`@("`@+RH@1G)O
M;2!21D,@,C`T-2!;-BXX73H@(BXN+G1H92!E;F-O9&5D(&1A=&$@87)E(&-O
M;G-I<W1E;G1L>0H@("`@("`@("`@("`@("!O;FQY(&%B;W5T(#,S('!E<F-E
M;G0@;&%R9V5R('1H86X@=&AE('5N96YC;V1E9"!D871A+B(@*B\*("`@("`@
M("`@("`@)'-I>F4@/2!N=6UB97)?9F]R;6%T*&UA>"@H*"1B>71E<R`J(#`N
M-S4I("\@,3`R-"DL(#$I*3L*("`@("`@("`@("`@)'-U;6UA<GE;72`]("<\
M86-R;VYY;2!T:71L93TB)R`N(%\H(D%P<')O>&EM871E(%-I>F4B*2`N("<B
M/B<@+B!S<')I;G1F*%\H(B5S($M"(BDL("1S:7IE*2`N("<\+V%C<F]N>6T^
M)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<W5M;6%R>5M=(#T@
M<W!R:6YT9BA?*"(E<R!+0B(I+"`D<VEZ92D["B`@("`@("`@?0H*("`@("`@
M("`O*B!$;W=N;&]A9"!C;VQU;6XN("HO"B`@("`@("`@:68@*"$D=&AI<RT^
M7VQI;FMS('Q\"B`@("`@("`@("`@(&ES7VYU;&PH)'-I>F4I('Q\"B`@("`@
M("`@("`@("%I<W-E="@D=&AI<RT^7W9I97=)1%LG9&]W;FQO860G72DI('L*
M("`@("`@("`@("`@)'-U;6UA<GE;72`](&YU;&P["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'-U;6UA<GE;72`]("1T:&ES+3YL:6YK5FEE=R@D
M;6EM95]P87)T+"`D=&AI<RT^7W9I97=)1%LG9&]W;FQO860G72P@2&]R9&4Z
M.FEM9R@G9&]W;FQO860N<&YG)RP@7R@B1&]W;FQO860B*2P@;G5L;"P@)$=,
M3T)!3%-;)W)E9VES=')Y)UTM/F=E=$EM86=E1&ER*"=H;W)D92<I*2P@87)R
M87DH)VIS=&5X="<@/3X@<W!R:6YT9BA?*")$;W=N;&]A9"`E<R(I+"`D;6EM
M95]P87)T+3YG971$97-C<FEP=&EO;BAT<G5E+"!T<G5E*2DI+"!T<G5E*3L*
M("`@("`@("!]"@H@("`@("`@("\J($EF('1H92!-24U%(%1Y<&4@:7,@87!P
M;&EC871I;VXO;V-T970M<W1R96%M+"!T<GD@=&\@=7-E"B`@("`@("`@("`@
M=&AE(&9I;&4@97AT96YS:6]N('1O(&1E=&5R;6EN92!T:&4@86-T=6%L($U)
M344@='EP92X@*B\*("`@("`@("!I9B`H)'1H:7,M/E]L:6YK<R`F)@H@("`@
M("`@("`@("`A)&=U97-S("8F"B`@("`@("`@("`@("%I<U]N=6QL*"1S:7IE
M*2`F)@H@("`@("`@("`@("`H)'1Y<&4@/3T@)V%P<&QI8V%T:6]N+V]C=&5T
M+7-T<F5A;2<I('Q\"B`@("`@("`@("`@("@D='EP92`]/2`G87!P;&EC871I
M;VXO8F%S938T)RDI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA
M;64H7U]&24Q%7U\I("X@)R]-86=I8RYP:'`G.PH@("`@("`@("`@("`D;F5W
M7W1Y<&4@/2!-24U%7TUA9VEC.CIF:6QE;F%M951O34E-12A-24U%.CID96-O
M9&4H)&UI;65?<&%R="T^9V5T3F%M92@I*2D["B`@("`@("`@("`@(&EF("@D
M;F5W7W1Y<&4@(3T@)V%P<&QI8V%T:6]N+V]C=&5T+7-T<F5A;2<I('L*("`@
M("`@("`@("`@("`@("1T96UP7W!A<G0@/2`D;6EM95]P87)T.PH@("`@("`@
M("`@("`@("`@)'1E;7!?<&%R="T^<V5T5'EP92@D;F5W7W1Y<&4I.PH@("`@
M("`@("`@("`@("`@)'-U;6UA<GD@/2!A<G)A>5]M87`H"B`@("`@("`@("`@
M("`@("`@("`@8W)E871E7V9U;F-T:6]N*"<D82P@)&(G+"`G<F5T=7)N(&5M
M<'1Y*"1B*2`_("1A(#H@)&$@+B!<)SQB<B`O/EPG("X@)&([)RDL"B`@("`@
M("`@("`@("`@("`@("`@)'-U;6UA<GDL"B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/G!A<G13=6UM87)Y*"1T96UP7W!A<G0L('1R=64I*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1S=6UM87)Y.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!54DP@=&\@=&AE('9I
M97<N<&AP('!A9V4N"B`@("`@*@H@("`@("H@0'!A<F%M($U)345?4&%R="`F
M)&UI;65?<&%R="`@5&AE($U)345?4&%R="!O8FIE8W0@=&\@=FEE=RX*("`@
M("`J($!P87)A;2!I;G1E9V5R("1A8W1I;VY)1"`@("`@(%1H92!!8W1I;VY)
M1"!T;R!P97)F;W)M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("`@
M("`@("`@02!L:7-T(&]F(&%N>2!A9&1I=&EO;F%L('!A<F%M971E<G,@=&AA
M=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;F5E9"!T
M;R!B92!P87-S960@=&\@=FEE=RYP:'`N("AK97D@/0H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@;F%M92D*("`@("`J($!P87)A;2!B
M;V]L96%N("1D;&]A9"`@("`@("`@(%-H;W5L9"!W92!G96YE<F%T92!A(&1O
M=VYL;V%D(&QI;FL_"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!54DP@=&\@=FEE=RYP:'`N"B`@("`@*B\*("`@(&9U;F-T:6]N('5R;%9I
M97<H)B1M:6UE7W!A<G0L("1A8W1I;VY)1"P@)'!A<F%M<R`](&%R<F%Y*"DL
M("1D;&]A9"`](&9A;'-E*0H@("`@>PH@("`@("`@("\J($=E="!T:&4@34E-
M12!)1"!F;W(@=&AI<R!P87)T+B`J+PH@("`@("`@("1I9"`]("AI<W-E="@D
M<&%R86US6R=I9"==*2D@/R`D<&%R86US6R=I9"==(#H@)&UI;65?<&%R="T^
M9V5T34E-14ED*"D["@H@("`@("`@("\J($%D9"!T:&4@;F5C97-S87)Y(&QO
M8V%L('!A<F%M971E<G,N("HO"B`@("`@("`@)'!A<F%M<ULG86-T:6]N240G
M72`]("1A8W1I;VY)1#L*("`@("`@("`D<&%R86US6R=I9"==(#T@)&ED.PH@
M("`@("`@("1P87)A;7,@/2!A<G)A>5]M97)G92@D<&%R86US+"`D=&AI<RT^
M8V%C:&5)1%523%!A<F%M*"DI.PH*("`@("`@("!I9B`H)&1L;V%D*2!["B`@
M("`@("`@("`@("1U<FP@/2!(;W)D93HZ9&]W;FQO8615<FPH)&UI;65?<&%R
M="T^9V5T3F%M92AT<G5E+"!T<G5E*2P@)'!A<F%M<RD["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<BA(
M;W)D93HZ87!P;&EC871I;VY5<FPH)W9I97<N<&AP)RDL("1P87)A;7,I.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1U<FP["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'96YE<F%T92!A(&QI;FL@=&\@=&AE('9I97<N<&AP('!A9V4N
M"B`@("`@*@H@("`@("H@0'!A<F%M($U)345?4&%R="`F)&UI;65?<&%R="`@
M5&AE($U)345?4&%R="!O8FIE8W0@=&\@=FEE=RX*("`@("`J($!P87)A;2!I
M;G1E9V5R("1A8W1I;VY)1"`@("`@(%1H92!A8W1I;VY)1"!V86QU92X*("`@
M("`J($!P87)A;2!S=')I;F<@)'1E>'0@("`@("`@("`@(%1H92!L:6YK('1E
M>'0N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@("`@("`@("!!(&QI
M<W0@;V8@861D:71I;VYA;"!P87)A;65T97)S+@H@("`@("H@("`G8VQA<W,G
M("`@("`@("T@(%1H92!#4U,@8VQA<W,@=&\@=7-E+@H@("`@("H@("`G:G-T
M97AT)R`@("`@("T@(%1H92!*4R!T97AT('1O('5S92X*("`@("`J("`@)W9I
M97=P87)A;7,G("`M("!!(&QI<W0@;V8@86YY(&%D9&ET:6]N86P@<&%R86UE
M=&5R<R!T:&%T(&YE960@=&\@8F4*("`@("`J("`@("`@("`@("`@("`@("`@
M("!P87-S960@=&\@=FEE=RYP:'`N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M9&QO860@("`@("`@("!3:&]U;&0@=V4@9V5N97)A=&4@82!D;W=N;&]A9"!L
M:6YK/PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!!($A434P@:')E
M9B!L:6YK('1O('9I97<N<&AP+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:6YK
M5FEE=R@F)&UI;65?<&%R="P@)&%C=&EO;DE$+"`D=&5X="P@)'!A<F%M<R`]
M(&%R<F%Y*"DL"B`@("`@("`@("`@("`@("`@("`@("`D9&QO860@/2!F86QS
M92D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1P87)A;7-;)V-L87-S)UTI
M*2!["B`@("`@("`@("`@("1P87)A;7-;)V-L87-S)UT@/2!N=6QL.PH@("`@
M("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1P87)A;7-;)VIS=&5X="==*2D@
M>PH@("`@("`@("`@("`D<&%R86US6R=J<W1E>'0G72`]("1T97AT.PH@("`@
M("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1P87)A;7-;)W9I97=P87)A;7,G
M72DI('L*("`@("`@("`@("`@)'!A<F%M<ULG=FEE=W!A<F%M<R==(#T@87)R
M87DH*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D9&QO860I('L*("`@("`@
M("`@("`@)'=I;F1O=R`](&YU;&P["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'=I;F1O=R`]("=V:65W7R<@+B!A8G,H8W)C,S(H;6EC<F]T:6UE
M*"DI*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!(;W)D93HZ;&EN:R@D
M=&AI<RT^=7)L5FEE=R@D;6EM95]P87)T+"`D86-T:6]N240L("1P87)A;7-;
M)W9I97=P87)A;7,G72P@)&1L;V%D*2P@)'!A<F%M<ULG:G-T97AT)UTL("1P
M87)A;7-;)V-L87-S)UTL("1W:6YD;W<I("X@)'1E>'0@+B`G/"]A/B<["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T92!A(&IA=F%S8W)I<'0@;&EN
M:R!T;R!T:&4@=FEE=RYP:'`@<&%G92X*("`@("`J"B`@("`@*B!`<&%R86T@
M34E-15]087)T("8D;6EM95]P87)T("!4:&4@34E-15]087)T(&]B:F5C="!T
M;R!V:65W+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&%C=&EO;DE$("`@("`@
M5&AE($%C=&EO;DE$('1O('!E<F9O<FTN"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1T97AT("`@("`@("`@("!4:&4@;&EN:R!T97AT+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D:G-T97AT("`@("`@("`@5&AE($IA=F%S8W)I<'0@;&EN:R!T
M97AT+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8W-S("`@("`@("`@("`@5&AE
M($-34R!C;&%S<R!T;R!U<V4N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M
M<R`@("`@("`@("!!(&QI<W0@;V8@86YY(&%D9&ET:6]N86P@<&%R86UE=&5R
M<R!T:&%T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N
M965D('1O(&)E('!A<W-E9"!T;R!V:65W+G!H<"X@*&ME>2`]"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N86UE*0H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)'=I9&=E="`@("`@("`@268@=')U92!U<V4@2&]R9&4Z
M.G=I9&=E="@I('1O(&=E;F5R871E+`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@2&]R9&4Z.FQI;FLH*2!O=&AE<G=I<V4N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@($$@2%1-3"!H<F5F(&QI;FL@=&\@
M=FEE=RYP:'`N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI;FM6:65W2E,H)B1M
M:6UE7W!A<G0L("1A8W1I;VY)1"P@)'1E>'0L("1J<W1E>'0@/2!N=6QL+`H@
M("`@("`@("`@("`@("`@("`@("`@("`D8W-S(#T@;G5L;"P@)'!A<F%M<R`]
M(&%R<F%Y*"DL("1W:61G970@/2!F86QS92D*("`@('L*("`@("`@("`O*B!)
M9B!V:65W:6YG('9I82!V:65W+G!H<"P@=V4@9&]N)W0@=V%N="!A($I3(&QI
M;FLN("HO"B`@("`@("`@:68@*"1T:&ES+3YV:65W07-!='1A8VAM96YT*"DI
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YL:6YK5FEE=R@D;6EM95]P
M87)T+"`D86-T:6]N240L("1T97AT+"`D<&%R86US*3L*("`@("`@("!]"@H@
M("`@("`@(&EF("AE;7!T>2@D:G-T97AT*2D@>PH@("`@("`@("`@("`D:G-T
M97AT(#T@<W!R:6YT9BA?*")6:65W("5S(BDL("1M:6UE7W!A<G0M/F=E=$1E
M<V-R:7!T:6]N*'1R=64L('1R=64I*3L*("`@("`@("!]"B`@("`@("`@)'!A
M<F%M<ULG<&]P=7!?=FEE=R==(#T@,3L*"B`@("`@("`@)'5R;"`]("1T:&ES
M+3YU<FQ6:65W*"1M:6UE7W!A<G0L("1A8W1I;VY)1"P@)'!A<F%M<RD["@H@
M("`@("`@(&EF("@A*"1I9"`]("1M:6UE7W!A<G0M/F=E=$U)345)9"@I*2D@
M>PH@("`@("`@("`@("`D:60@/2!A8G,H8W)C,S(H<V5R:6%L:7IE*"1M:6UE
M7W!A<G0I*2D["B`@("`@("`@?0H*("`@("`@("!I9B`H)'=I9&=E="D@>PH@
M("`@("`@("`@("!R971U<FX@2&]R9&4Z.G=I9&=E="@G(R<L("1J<W1E>'0L
M("1C<W,L(&YU;&PL(")V:65W*"<B("X@)'5R;"`N("(G+"`G(B`N("1I9"`N
M("(G*3L@<F5T=7)N(&9A;'-E.R(L("1T97AT*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@2&]R9&4Z.FQI;FLH)R,G+"`D:G-T97AT
M+"`D8W-S+"!N=6QL+"`B=FEE=R@G(B`N("1U<FP@+B`B)RP@)R(@+B`D:60@
M+B`B)RD[(')E='5R;B!F86QS93LB*2`N("1T97AT("X@)SPO83XG.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%!R:6YT<R!O=70@=&AE('-T
M871U<R!M97-S86=E(&9O<B!A(&=I=F5N($U)344@4&%R="X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1M<V<@("`@(%1H92!M97-S86=E('1O(&]U
M='!U="X*("`@("`J($!P87)A;2!S=')I;F<@)&EM9R`@("`@06X@:6UA9V4@
M;&EN:R!T;R!A9&0@=&\@=&AE(&)E9VEN;FEN9R!O9B!T:&4*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@;65S<V%G92X*("`@("`J($!P87)A;2!B
M;V]L96%N("1P<FEN="`@3W5T<'5T('1H:7,@;65S<V%G92!W:&5N(&EN(&$@
M<')I;G0@=FEE=S\*("`@("`J($!P87)A;2!S=')I;F<@)&-L87-S("`@06X@
M;W!T:6]N86P@<W1Y;&4@9F]R('1H92!S=&%T=7,@8F]X+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@9F]R;6%T=&5D('-T871U<R!M97-S
M86=E('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@9F]R;6%T4W1A='5S
M37-G*"1M<V<L("1I;6<@/2!N=6QL+"`D<')I;G1A8FQE(#T@=')U92P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D8VQA<W,@/2!N=6QL*0H@("`@
M>PH@("`@("`@(&EF("@A:7-?87)R87DH)&US9RDI('L*("`@("`@("`@("`@
M)&US9R`](&%R<F%Y*"1M<V<I.PH@("`@("`@('T*"B`@("`@("`@+RH@268@
M=V4@87)E('9I97=I;F<@87,@86X@871T86-H;65N="P@9&]N)W0@<')I;G0@
M2%1-3"!C;V1E+B`J+PH@("`@("`@(&EF("@D=&AI<RT^=FEE=T%S071T86-H
M;65N="@I*2!["B`@("`@("`@("`@(')E='5R;B!I;7!L;V1E*")<;B(L("1M
M<V<I.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7VYU;&PH)&-L87-S*2D@
M>PH@("`@("`@("`@("`D8VQA<W,@/2`G;6EM95-T871U<TUE<W-A9V4G.PH@
M("`@("`@('T*("`@("`@("`D=&5X="`]("<\=&%B;&4@8VQA<W,](B<@+B`D
M8VQA<W,@+B`G(CXG.PH*("`@("`@("`O*B!)9B!N;R!I;6%G92P@<VEM<&QY
M('!R:6YT(&]U="!T:&4@;65S<V%G92X@*B\*("`@("`@("!I9B`H:7-?;G5L
M;"@D:6UG*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D;7-G(&%S("1V86PI
M('L*("`@("`@("`@("`@("`@("1T97AT("X]("<\='(^/'1D/B<@+B`D=F%L
M("X@)SPO=&0^/"]T<CXG("X@(EQN(CL*("`@("`@("`@("`@?0H@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1T97AT("X]("<\='(^/'1D('9A;&EG
M;CTB;6ED9&QE(CXG("X@)&EM9R`N("<F;F)S<#L\+W1D/B<["B`@("`@("`@
M("`@("1T97AT("X]("<\=&0^)SL*"B`@("`@("`@("`@(&EF("AC;W5N="@D
M;7-G*2`]/2`Q*2!["B`@("`@("`@("`@("`@("`D=&5X="`N/2`D;7-G6S!=
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1E>'0@
M+CT@)SQT86)L93XG.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&US9R!A
M<R`D=F%L*2!["B`@("`@("`@("`@("`@("`@("`@)'1E>'0@+CT@)SQT<CX\
M=&0^)R`N("1V86P@+B`G/"]T9#X\+W1R/B<@+B`B7&XB.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@)'1E>'0@+CT@)SPO=&%B;&4^)SL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&5X="`N/2`G/"]T9#X\+W1R
M/B<@+B`B7&XB.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T97AT("X@
M)SPO=&%B;&4^)SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!A('!O
M:6YT97(@=&\@=&AE(&)A<V4@;V)J96-T+@H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@(%)E='5R;G,@82!P;VEN=&5R('1O('1H92!B87-E(&]B:F5C
M="X*("`@("`J("`@("`@("`@("`@("`@(%)E='5R;G,@9F%L<V4@:68@=&AE
M<F4@:7,@;F\@8F%S92!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N("9G
M971"87-E3V)J96-T4'1R*"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D
M=&AI<RT^7V)A<V4I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<SL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]B87-E
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@34E-
M15]#;VYT96YT<SHZ(&]B:F5C="!T;R!B92!C86-H960N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`@5&AE(&-A8VAE($])1"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V%D9$-A
M8VAE*"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^7W-E<W-I
M;VY#86-H94E$*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W-E<W-I;VY#86-H
M94E$(#T@)'1H:7,M/E]C<F5A=&5#86-H94E$*"D["B`@("`@("`@("`@(')E
M9VES=&5R7W-H=71D;W=N7V9U;F-T:6]N*&%R<F%Y*"8D=&AI<RP@)U]A9&1#
M86-H95-H=71D;W=N)RDI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<V5S<VEO;D-A8VAE240["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M<F5A=&5S(&$@=6YI<75E(&-A8VAE($E$(&9O<B!T:&ES(&]B:F5C="X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@02!U;FEQ=64@8V%C:&4@240N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]C<F5A=&5#86-H94E$*"D*("`@('L*("`@("`@("!R971U<FX@
M;60U*&UI8W)O=&EM92@I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-A=F5S
M(&$@8V]P>2!O9B!T:&4@34E-15]#;VYT96YT<R!O8FIE8W0@870@=&AE(&5N
M9"!O9B!A(')E<75E<W0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A9&1#86-H95-H=71D;W=N*"D*("`@
M('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U-E<W-I;VY/8FIE8W1S
M+G!H<"<["B`@("`@("`@)&-A8VAE(#T@)DAO<F1E7U-E<W-I;VY/8FIE8W1S
M.CIS:6YG;&5T;VXH*3L*"B`@("`@("`@+RH@1&]N)W0@<V%V92!T:&4@34E-
M15]6:65W97(@8V%C:&5D(&]B:F5C=',@<VEN8V4@=&AE<F4@:7,@;F\@96%S
M>0H@("`@("`@("`@('=A>2!T;R!R96=E;F5R871E('1H96T@;VX@8V%C:&4@
M<F5L;V%D+B`J+PH@("`@("`@("1T:&ES+3Y?=FEE=V5R0V%C:&4@/2!A<G)A
M>2@I.PH*("`@("`@("`O*B!#;W!Y('1H92!-24U%7TUE<W-A9V4@8V%C:&4@
M;V)J96-T('1O('1H92!?;65S<V%G92!V87)I86)L92X@*B\*("`@("`@("`D
M=&AI<RT^7VUE<W-A9V4@/2`D=&AI<RT^7V-A8VAE;65S<V%G93L*"B`@("`@
M("`@)&-A8VAE+3YS=&]R92@D=&AI<RT^7W-E<W-I;VY#86-H94E$+"`D=&AI
M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C86-H960@
M34E-15]#;VYT96YT<SHZ(&]B:F5C="X*("`@("`J(%1H:7,@9G5N8W1I;VX@
M<VAO=6QD(&)E(&-A;&QE9"!S=&%T:6-A;&QY(&4N9RXZ"B`@("`@*B`D<'1R
M(#T@)DU)345?0V]N=&5N=',Z.F=E=$-A8VAE*"DN"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D8V%C:&5I9"`@5&AE(&-A8VAE($E$('1O('5S92X@
M($EF(&5M<'1Y+"!W:6QL('5S92!T:&4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@(&-A8VAE($E$(&QO8V%T960@:6X@=&AE(%523"!P87)A;65T
M97(@;F%M960*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@($U)345?
M0T].5$5.5%-?0T%#2$4N"B`@("`@*@H@("`@("H@0')E='5R;B!-24U%7T-O
M;G1E;G1S("!4:&4@34E-15]#;VYT96YT<R!O8FIE8W0L(&]R(&YU;&P@:68@
M:70@9&]E<R!N;W0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@97AI
M<W0N"B`@("`@*B\*("`@(&9U;F-T:6]N("9G971#86-H92@D8V%C:&5I9"`]
M(&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)&-A8VAE:60I*2![
M"B`@("`@("`@("`@("1C86-H96ED(#T@571I;#HZ9V5T1F]R;41A=&$H34E-
M15]#3TY414Y44U]#04-(12D["B`@("`@("`@?0H*("`@("`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+U-E<W-I;VY/8FIE8W1S+G!H<"<["B`@("`@("`@)&-A
M8VAE(#T@)DAO<F1E7U-E<W-I;VY/8FIE8W1S.CIS:6YG;&5T;VXH*3L*("`@
M("`@("`D8V]N=&5N=',@/2`F)&-A8VAE+3YQ=65R>2@D8V%C:&5I9"D["B`@
M("`@("`@<F5T=7)N("1C;VYT96YT<SL*("`@('T*"B`@("`O*BH*("`@("`J
M($%D9"!T:&4@8W5R<F5N="!O8FIE8W0@=&\@=&AE(&-A8VAE+"!A;F0@<F5T
M=7)N('1H92!C86-H92!I9&5N=&EF:65R"B`@("`@*B!T;R!B92!U<V5D(&EN
M(%523',N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE('!A<F%M
M971E<B!K97DO=F%L=64@<V5T('1O('5S92!I;B!54DQS+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!C86-H94E$55),4&%R86TH*0H@("`@>PH@("`@("`@(')E
M='5R;B!A<G)A>2A-24U%7T-/3E1%3E137T-!0TA%(#T^("1T:&ES+3Y?861D
M0V%C:&4H*2D["B`@("!]"@I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B](;W)D92]-24U%+TAE861E<G,N<&AP````````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`U,#`S,"`Q,#4Q-30S,S<S-R`P,C(Q-C,`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J(%1H92!D97-C<FEP=&EO;B!O9B!(;W)D92!T;R!U<V4@:6X@
M=&AE("=5<V5R+4%G96YT.B<@:&5A9&5R+@H@*B\*9&5F:6YE*"=(3U)$15]!
M1T5.5%](14%$15(G+"`G2&]R9&4@07!P;&EC871I;VX@1G)A;65W;W)K(#,N
M,2<I.PH*+RHJ"B`J(%1H92!-24U%7TAE861E<G,Z.B!C;&%S<R!C;VYT86EN
M<R!G96YE<FEC(&9U;F-T:6]N<R!R96QA=&5D('1O"B`J(&AA;F1L:6YG('1H
M92!H96%D97)S(&]F(&UA:6P@;65S<V%G97,N"B`J"B`J(%1H92!D969A=6QT
M(&-H87)A8W1E<B!S970@=&\@=7-E(&9O<B!H96%D97)S('-H;W5L9"!B92!D
M969I;F5D(&EN('1H90H@*B!V87)I86)L92`D1TQ/0D%,4ULG;6EM95]H96%D
M97)S)UU;)V1E9F%U;'1?8VAA<G-E="==("AD969A=6QT<R!T;R!54RU!4T-)
M20H@*B!P97(@4D9#(#(P-#4I+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-
M24U%+TU)344O2&5A9&5R<RYP:'`L=B`Q+C(Y+C$P+C(P(#(P,#8O,#0O,34@
M,3<Z,C0Z,3D@<VQU<V%R>B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR
M,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O
M+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI8VAA96P@4VQU
M<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E
M("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TU)344*("HO"F-L87-S
M($U)345?2&5A9&5R<R!["@H@("`@+RHJ"B`@("`@*B!4:&4@:6YT97)N86P@
M:&5A9&5R<R!A<G)A>2X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D7VAE861E<G,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@
M("H@0V%C:&5D(&]U='!U="!O9B!T:&4@34E-15]3=')U8W1U<F4Z.G!A<G-E
M34E-14AE861E<G,H*2!C;VUM86YD+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?86QL2&5A9&5R<SL*"B`@("`O*BH*("`@
M("`J($-A8VAE9"!O=71P=70@;V8@=&AE(&EM87!?9F5T8VAH96%D97(H*2!C
M;VUM86YD+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@
M('9A<B`D7VAE861E<E1E>'0["@H@("`@+RHJ"B`@("`@*B!4:&4@:&5A9&5R
M(&]B:F5C="!R971U<FYE9"!F<F]M(&EM87!?:&5A9&5R:6YF;R@I+@H@("`@
M("H*("`@("`J($!V87(@<W1D0VQA<W,*("`@("`J+PH@("`@=F%R("1?:&5A
M9&5R3V)J96-T.PH*("`@("\J*@H@("`@("H@5&AE(&EN=&5R;F%L(&9L86=S
M(&%R<F%Y+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1?9FQA9W,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@5&AE(%5S
M97(M06=E;G0@<W1R:6YG('1O('5S92X*("`@("`J(%1(25,@5D%,544@4TA/
M54Q$($)%($]615)2241%3B!"62!!3$P@4U5"0TQ!4U-%4RX*("`@("`J"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]A9V5N="`]($A/
M4D1%7T%'14Y47TA%041%4CL*"B`@("`O*BH*("`@("`J(%1H92!S97%U96YC
M92!T;R!U<V4@87,@14],(&9O<B!T:&4@:&5A9&5R<RX*("`@("`J(%1H92!D
M969A=6QT(&ES(&-U<G)E;G1L>2!T;R!O=71P=70@=&AE($5/3"!S97%U96YC
M92!I;G1E<FYA;&QY(&%S"B`@("`@*B!J=7-T(")<;B(@:6YS=&5A9"!O9B!T
M:&4@8V%N;VYI8V%L(")<<EQN(B!R97%U:7)E9"!I;B!21D,@.#(R("8@,C`T
M-2X*("`@("`J(%1O(&)E(%)&0R!C;VUP;&%I;G0L('1H92!F=6QL(#Q#4CX\
M3$8^($5/3"!C;VUB:6YA=&EO;B!S:&]U;&0@8F4@=7-E9`H@("`@("H@=VAE
M;B!S96YD:6YG(&$@;65S<V%G92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("HO"B`@("!V87(@)%]E;VP@/2`B7&XB.PH*("`@("\J*@H@("`@
M("H@5&AE(&EN9&5X(&]F('1H92!M97-S86=E+@H@("`@("H*("`@("`J($!V
M87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]I;F1E>#L*"B`@("`O*BH*
M("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E
M9V5R("1I;F1E>"`@5&AE(&UE<W-A9V4@:6YD97@@=&\@<&%R<V4@:&5A9&5R
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@34E-15](96%D97)S*"1I;F1E>"`]
M(&YU;&PI"B`@("!["B`@("`@("`@)'1H:7,M/E]I;F1E>"`]("1I;F1E>#L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!R969E<F5N8V4@=&\@
M82!C=7)R96YT;'D@;W!E;B!)34%0('-T<F5A;2X*("`@("`J(%1(25,@5D%,
M544@4TA/54Q$($)%($]615)2241%3B!"62!!3$P@4U5"0TQ!4U-%4RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(')E<V]U<F-E("!!;B!)34%0(')E<V]U<F-E
M('-T<F5A;2X*("`@("`J+PH@("`@9G5N8W1I;VX@)E]G9713=')E86TH*0H@
M("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;B!T:&4@9G5L;"!L:7-T(&]F(&AE861E<G,@9G)O;2!T:&4@
M:6UA<%]F971C:&AE861E<B@I(&9U;F-T:6]N+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!3964@:6UA<%]F971C:&AE861E<B@I+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971(96%D97)497AT*"D*("`@('L*("`@("`@("!I
M9B`H(6ES7VYU;&PH)'1H:7,M/E]I;F1E>"D@)B8@96UP='DH)'1H:7,M/E]H
M96%D97)497AT*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VAE861E<E1E>'0@
M/2!`:6UA<%]F971C:&AE861E<B@D=&AI<RT^7V=E=%-T<F5A;2@I+"`D=&AI
M<RT^7VEN9&5X+"!&5%]5240I.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1'
M3$]"04Q36R=M:6UE7VAE861E<G,G75LG9&5F875L=%]C:&%R<V5T)UTI*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7VAE861E<E1E>'0@/2!3=')I;F<Z
M.F-O;G9E<G1#:&%R<V5T*"1T:&ES+3Y?:&5A9&5R5&5X="P@)$=,3T)!3%-;
M)VUI;65?:&5A9&5R<R==6R=D969A=6QT7V-H87)S970G72D["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^7VAE861E
M<E1E>'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&9U;&P@
M;&ES="!O9B!H96%D97)S+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N
M("1D96-O9&4@($1E8V]D92!T:&4@:&5A9&5R<S\*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!3964@34E-15]3=')U8W1U<F4Z.G!A<G-E34E-14AE
M861E<G,H*2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T06QL2&5A9&5R<R@D
M9&5C;V1E(#T@=')U92D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO
M<F1E+TU)344O4W1R=6-T=7)E+G!H<"<["@H@("`@("`@(&EF("@A:7-?;G5L
M;"@D=&AI<RT^7VEN9&5X*2`F)B!E;7!T>2@D=&AI<RT^7V%L;$AE861E<G,I
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?86QL2&5A9&5R<R`]($U)345?4W1R
M=6-T=7)E.CIP87)S94U)345(96%D97)S*"1T:&ES+3YG971(96%D97)497AT
M*"DL("1D96-O9&4I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?86QL2&5A9&5R<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T
M:&4@:&5A9&5R(&]B:F5C="!F<F]M(&EM87!?:&5A9&5R:6YF;R@I+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1D0VQA<W,@(%-E92!I;6%P7VAE861E<FEN
M9F\H*2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T2&5A9&5R3V)J96-T*"D*
M("`@('L*("`@("`@("!I9B`H(6ES7VYU;&PH)'1H:7,M/E]I;F1E>"D@)B8@
M96UP='DH)'1H:7,M/E]H96%D97)/8FIE8W0I*2!["B`@("`@("`@("`@("1S
M=')E86T@/2`D=&AI<RT^7V=E=%-T<F5A;2@I.PH@("`@("`@("`@("`D=&AI
M<RT^7VAE861E<D]B:F5C="`]($!I;6%P7VAE861E<FEN9F\H)'-T<F5A;2P@
M0&EM87!?;7-G;F\H)'-T<F5A;2P@)'1H:7,M/E]I;F1E>"DI.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?:&5A9&5R3V)J96-T.PH@("`@
M?0H*("`@("\J*@H@("`@("H@0G5I;&0@=&AE(&AE861E<B!A<G)A>2X*("`@
M("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&5C;V1E("!-24U%(&1E8V]D
M92!T:&4@:&5A9&5R<S\*("`@("`J+PH@("`@9G5N8W1I;VX@8G5I;&1(96%D
M97)S*"1D96-O9&4@/2!T<G5E*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH
M)'1H:7,M/E]H96%D97)S*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@
M("`@?0H*("`@("`@("`O*B!087)S92!T:')O=6=H('1H92!L:7-T(&]F(&%L
M;"!H96%D97)S+B`J+PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YG971!;&Q(
M96%D97)S*"1D96-O9&4I(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@
M("`D=&AI<RT^861D2&5A9&5R*"1K97DL("1V86PI.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($)U:6QD('1H92!F;&%G<R!A<G)A>2X*("`@
M("`J+PH@("`@9G5N8W1I;VX@8G5I;&1&;&%G<R@I"B`@("!["B`@("`@("`@
M:68@*"%E;7!T>2@D=&AI<RT^7V9L86=S*2D@>PH@("`@("`@("`@("!R971U
M<FX["B`@("`@("`@?0H*("`@("`@("`O*B!'970@=&AE($E-05`@:&5A9&5R
M(&]B:F5C="X@*B\*("`@("`@("`D;V(@/2`D=&AI<RT^9V5T2&5A9&5R3V)J
M96-T*"D["B`@("`@("`@:68@*"%I<U]O8FIE8W0H)&]B*2D@>PH@("`@("`@
M("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`O*B!5;G-E96X@9FQA
M9R`J+PH@("`@("`@(&EF("@H)&]B+3Y5;G-E96X@/3T@)U4G*2!\?"`H)&]B
M+3Y296-E;G0@/3T@)TXG*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V9L86=S
M6R=U;G-E96XG72`]('1R=64["B`@("`@("`@?0H*("`@("`@("`O*B!296-E
M;G0@9FQA9R`J+PH@("`@("`@(&EF("@H)&]B+3Y296-E;G0@/3T@)TXG*2!\
M?"`H)&]B+3Y296-E;G0@/3T@)U(G*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7V9L86=S6R=R96-E;G0G72`]('1R=64["B`@("`@("`@?0H*("`@("`@("`O
M*B!!;G-W97)E9"!F;&%G("HO"B`@("`@("`@:68@*"1O8BT^06YS=V5R960@
M/3T@)T$G*2!["B`@("`@("`@("`@("1T:&ES+3Y?9FQA9W-;)V%N<W=E<F5D
M)UT@/2!T<G5E.PH@("`@("`@('T*"B`@("`@("`@+RH@1')A9G0@9FQA9R`J
M+PH@("`@("`@(&EF("AI<W-E="@D;V(M/D1R869T*2`F)B`H)&]B+3Y$<F%F
M="`]/2`G6"<I*2!["B`@("`@("`@("`@("1T:&ES+3Y?9FQA9W-;)V1R869T
M)UT@/2!T<G5E.PH@("`@("`@('T*"B`@("`@("`@+RH@1FQA9V=E9"!F;&%G
M("HO"B`@("`@("`@:68@*"1O8BT^1FQA9V=E9"`]/2`G1B<I('L*("`@("`@
M("`@("`@)'1H:7,M/E]F;&%G<ULG9FQA9V=E9"==(#T@=')U93L*("`@("`@
M("!]"@H@("`@("`@("\J($1E;&5T960@9FQA9R`J+PH@("`@("`@(&EF("@D
M;V(M/D1E;&5T960@/3T@)T0G*2!["B`@("`@("`@("`@("1T:&ES+3Y?9FQA
M9W-;)V1E;&5T960G72`]('1R=64["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!T:&4@:6YT97)N86P@:&5A9&5R(&%R<F%Y(&EN
M(&%R<F%Y(&9O<FUA="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4
M:&4@:&5A9&5R<R!I;B!A<G)A>2!F;W)M870N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('1O07)R87DH*0H@("`@>PH@("`@("`@("1R971U<FY?87)R87D@/2!A
M<G)A>2@I.PH*("`@("`@("!F;W)E86-H("@D=&AI<RT^7VAE861E<G,@87,@
M)&]B*2!["B`@("`@("`@("`@("1E;VP@/2`D=&AI<RT^9V5T14],*"D["B`@
M("`@("`@("`@("1H96%D97(@/2`D;V);)VAE861E<B==.PH@("`@("`@("`@
M("!I9B`H:7-?87)R87DH)&]B6R=V86QU92==*2D@>PH@("`@("`@("`@("`@
M("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B]-24U%
M+G!H<"<["B`@("`@("`@("`@("`@("`D<F5T=7)N7V%R<F%Y6R1H96%D97)=
M(#T@34E-13HZ=W)A<$AE861E<G,H)&AE861E<BP@<F5S970H)&]B6R=V86QU
M92==*2D["B`@("`@("`@("`@("`@("!N97AT*"1O8ELG=F%L=64G72D["B`@
M("`@("`@("`@("`@("!W:&EL92`H;&ES="@L)'9A;"D@/2!E86-H*"1O8ELG
M=F%L=64G72DI('L*("`@("`@("`@("`@("`@("`@("`D<F5T=7)N7V%R<F%Y
M6R1H96%D97)=("X]("1E;VP@+B`D:&5A9&5R("X@)SH@)R`N($U)344Z.G=R
M87!(96%D97)S*"1H96%D97(L("1V86PL("1E;VPI.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)')E
M='5R;E]A<G)A>5LD:&5A9&5R72`]("1O8ELG=F%L=64G73L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R971U<FY?87)R87D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!I;G1E<FYA;"!H
M96%D97(@87)R87D@:6X@<W1R:6YG(&9O<FUA="X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(&AE861E<G,@:6X@<W1R:6YG(&9O<FUA="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@=&]3=')I;F<H*0H@("`@>PH@("`@("`@
M("1E;VP@/2`D=&AI<RT^9V5T14],*"D["B`@("`@("`@)'1E>'0@/2`G)SL*
M"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]H96%D97)S(&%S("1O8BD@>PH@
M("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1O8ELG=F%L=64G72DI('L*("`@
M("`@("`@("`@("`@("1O8ELG=F%L=64G72`](&%R<F%Y*"1O8ELG=F%L=64G
M72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@9F]R96%C:"`H)&]B6R=V
M86QU92==(&%S("1E;G1R>2D@>PH@("`@("`@("`@("`@("`@)'1E>'0@+CT@
M)&]B6R=H96%D97(G72`N("<Z("<@+B`D96YT<GD@+B`D96]L.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1E>'0@+B`D96]L
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5N97)A=&4@=&AE("=296-E:79E
M9"<@:&5A9&5R(&9O<B!T:&4@5V5B(&)R;W=S97(M/DAO<F1E(&AO<`H@("`@
M("H@*&%T=&5M<'1S('1O(&-O;F9O<FT@=&\@9W5I9&5L:6YE<R!I;B!21D,@
M,C@R,2DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9%)E8V5I=F5D2&5A9&5R
M*"D*("`@('L*("`@("`@("!I9B`H:7-S970H)%]315)615);)TA45%!?6%]&
M3U)705)$141?1D]2)UTI*2!["B`@("`@("`@("`@("\J(%1H:7,@:6YD:6-A
M=&5S('1H92!U<V5R(&ES(&-O;FYE8W1I;F<@=&AR;W5G:"!A('!R;WAY+B`J
M+PH@("`@("`@("`@("`D<F5M;W1E7W!A=&@@/2!E>'!L;V1E*"<L)RP@)%]3
M15)615);)TA45%!?6%]&3U)705)$141?1D]2)UTI.PH@("`@("`@("`@("`D
M<F5M;W1E7V%D9'(@/2`D<F5M;W1E7W!A=&A;,%T["B`@("`@("`@("`@("1R
M96UO=&4@/2!`9V5T:&]S=&)Y861D<B@D<F5M;W1E7V%D9'(I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1R96UO=&5?861D<B`]("1?4T525D52
M6R=214U/5$5?041$4B==.PH@("`@("`@("`@("!I9B`H96UP='DH)%]315)6
M15);)U)%34]415](3U-4)UTI*2!["B`@("`@("`@("`@("`@("`D<F5M;W1E
M(#T@0&=E=&AO<W1B>6%D9'(H)')E;6]T95]A9&1R*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1R96UO=&4@/2`D7U-%4E9%4ELG
M4D5-3U1%7TA/4U0G73L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("`D<F5C96EV960@/2`G9G)O;2`G("X@)')E;6]T92`N("<@*"<["@H@("`@
M("`@(&EF("@A96UP='DH)%]315)615);)U)%34]415])1$5.5"==*2D@>PH@
M("`@("`@("`@("`D<F5C96EV960@+CT@)%]315)615);)U)%34]415])1$5.
M5"==("X@)T`G("X@)')E;6]T92`N("<@)SL*("`@("`@("!](&5L<V5I9B`H
M)')E;6]T92`A/2`D7U-%4E9%4ELG4D5-3U1%7T%$1%(G72D@>PH@("`@("`@
M("`@("`D<F5C96EV960@+CT@)')E;6]T92`N("<@)SL*("`@("`@("!]"B`@
M("`@("`@)')E8V5I=F5D("X]("=;)R`N("1R96UO=&5?861D<B`N("==*2`G
M.PH*("`@("`@("!I9B`H(65M<'1Y*"1'3$]"04Q36R=C;VYF)UU;)W-E<G9E
M<B==6R=N86UE)UTI*2!["B`@("`@("`@("`@("1S97)V97)?;F%M92`]("1'
M3$]"04Q36R=C;VYF)UU;)W-E<G9E<B==6R=N86UE)UT["B`@("`@("`@?2!E
M;'-E:68@*"%E;7!T>2@D7U-%4E9%4ELG4T525D527TY!344G72DI('L*("`@
M("`@("`@("`@)'-E<G9E<E]N86UE(#T@)%]315)615);)U-%4E9%4E].04U%
M)UT["B`@("`@("`@?2!E;'-E:68@*"%E;7!T>2@D7U-%4E9%4ELG2%144%](
M3U-4)UTI*2!["B`@("`@("`@("`@("1S97)V97)?;F%M92`]("1?4T525D52
M6R=(5%107TA/4U0G73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M<V5R=F5R7VYA;64@/2`G=6YK;F]W;B<["B`@("`@("`@?0H@("`@("`@("1R
M96-E:79E9"`N/2`G8GD@)R`N("1S97)V97)?;F%M92`N("<@*$AO<F1E($U)
M344@;&EB<F%R>2D@=VET:"!(5%10.R`G.PH*("`@("`@("`D<F5C96EV960@
M+CT@9&%T92@G<B<I.PH*("`@("`@("`D=&AI<RT^861D2&5A9&5R*"=296-E
M:79E9"<L("1R96-E:79E9"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE
M<F%T92!T:&4@)TUE<W-A9V4M240G(&AE861E<BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@861D365S<V%G94ED2&5A9&5R*"D*("`@('L*("`@("`@("!R97%U
M:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN+TU)344N<&AP)SL*
M("`@("`@("`D=&AI<RT^861D2&5A9&5R*"=-97-S86=E+4E$)RP@34E-13HZ
M9V5N97)A=&5-97-S86=E240H*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'
M96YE<F%T92!T:&4@)U)E<V5N="<@:&5A9&5R<R`H8V]N9F]R;7,@=&\@9W5I
M9&5L:6YE<R!I;@H@("`@("H@4D9#(#(X,C(@6S,N-BXV72DN"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D9G)O;2`@5&AE(&%D9')E<W,@=&\@=7-E
M(&9O<B`G4F5S96YT+49R;VTG+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&\@
M("`@5&AE(&%D9')E<W,@=&\@=7-E(&9O<B`G4F5S96YT+51O)RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@861D4F5S96YT2&5A9&5R<R@D9G)O;2P@)'1O*0H@
M("`@>PH@("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N
M("<O+BXO34E-12YP:'`G.PH*("`@("`@("`O*B!792!D;VXG="!S970@4F5S
M96YT+5-E;F1E<BP@4F5S96YT+4-C+"!O<B!297-E;G0M0F-C+B`J+PH@("`@
M("`@("1T:&ES+3YA9&1(96%D97(H)U)E<V5N="U$871E)RP@9&%T92@G<B<I
M*3L*("`@("`@("`D=&AI<RT^861D2&5A9&5R*"=297-E;G0M1G)O;2<L("1F
M<F]M*3L*("`@("`@("`D=&AI<RT^861D2&5A9&5R*"=297-E;G0M5&\G+"`D
M=&\I.PH@("`@("`@("1T:&ES+3YA9&1(96%D97(H)U)E<V5N="U-97-S86=E
M+4E$)RP@34E-13HZ9V5N97)A=&5-97-S86=E240H*2D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!'96YE<F%T92!D96QI=F5R>2!R96-E:7!T(&AE861E<G,N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&\@(%1H92!A9&1R97-S
M('1H92!R96-E:7!T('-H;W5L9"!B92!M86EL960@=&\N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&%D9$1E;&EV97)Y4F5C96EP=$AE861E<G,H)'1O*0H@("`@
M>PH@("`@("`@("\J(%1H:7,@:7,@;VQD('-E;F1M86EL("AP<F4M."XW*2!B
M96AA=FEO<BX@*B\*("`@("`@("`D=&AI<RT^861D2&5A9&5R*"=2971U<FXM
M4F5C96EP="U4;R<L("1T;RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE
M<F%T92!T:&4@=7-E<B!A9V5N="!D97-C<FEP=&EO;B!H96%D97(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&%D9$%G96YT2&5A9&5R*"D*("`@('L*("`@("`@
M("`D=&AI<RT^861D2&5A9&5R*"=5<V5R+4%G96YT)RP@)'1H:7,M/E]A9V5N
M="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!U<V5R(&%G
M96YT(&1E<V-R:7!T:6]N(&AE861E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE('5S97(@86=E;G0@:&5A9&5R+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971!9V5N=$AE861E<B@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?86=E;G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@82!H
M96%D97(@=&\@=&AE(&AE861E<B!A<G)A>2X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1H96%D97(@(%1H92!H96%D97(@;F%M92X*("`@("`J($!P
M87)A;2!S=')I;F<@)'9A;'5E("`@5&AE(&AE861E<B!V86QU92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@861D2&5A9&5R*"1H96%D97(L("1V86QU92D*("`@
M('L*("`@("`@("`D:&5A9&5R(#T@=')I;2@D:&5A9&5R*3L*("`@("`@("`D
M;&-(96%D97(@/2!3=')I;F<Z.FQO=V5R*"1H96%D97(I.PH*("`@("`@("!I
M9B`H(6ES<V5T*"1T:&ES+3Y?:&5A9&5R<ULD;&-(96%D97)=*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7VAE861E<G-;)&QC2&5A9&5R72`](&%R<F%Y*"D[
M"B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?:&5A9&5R<ULD;&-(96%D97)=
M6R=H96%D97(G72`]("1H96%D97(["B`@("`@("`@)'1H:7,M/E]H96%D97)S
M6R1L8TAE861E<EU;)W9A;'5E)UT@/2`D=F%L=64["B`@("`@("`@)'1H:7,M
M/E]H96%D97)S6R1L8TAE861E<EU;)U]A;'1E<B==(#T@9F%L<V4["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!296UO=F4@82!H96%D97(@9G)O;2!T:&4@:&5A
M9&5R(&%R<F%Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&AE861E
M<B`@5&AE(&AE861E<B!N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO
M=F5(96%D97(H)&AE861E<BD*("`@('L*("`@("`@("`D:&5A9&5R(#T@=')I
M;2@D:&5A9&5R*3L*("`@("`@("`D;&-(96%D97(@/2!3=')I;F<Z.FQO=V5R
M*"1H96%D97(I.PH@("`@("`@('5N<V5T*"1T:&ES+3Y?:&5A9&5R<ULD;&-(
M96%D97)=*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!A('9A;'5E(&9O
M<B!A('!A<G1I8W5L87(@:&5A9&5R($].3%D@:68@=&AA="!H96%D97(@:7,@
M<V5T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&AE861E<B`@5&AE
M(&AE861E<B!N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=F%L=64@("!4
M:&4@:&5A9&5R('9A;'5E+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5')U92!I9B!V86QU92!W87,@<V5T+"!F86QS92!I9B!N;W0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E=%9A;'5E*"1H96%D97(L("1V86QU92D*("`@
M('L*("`@("`@("`D;&-(96%D97(@/2!3=')I;F<Z.FQO=V5R*"1H96%D97(I
M.PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VAE861E<G-;)&QC2&5A9&5R
M72DI('L*("`@("`@("`@("`@)'1H:7,M/E]H96%D97)S6R1L8TAE861E<EU;
M)W9A;'5E)UT@/2`D=F%L=64["B`@("`@("`@("`@("1T:&ES+3Y?:&5A9&5R
M<ULD;&-(96%D97)=6R=?86QT97(G72`]('1R=64["B`@("`@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E
M;7!T<R!T;R!R971U<FX@=&AE(&AE861E<B!I;B!T:&4@8V]R<F5C="!C87-E
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&AE861E<B`@5&AE(&AE
M861E<B!T;R!S96%R8V@@9F]R+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@=F%L=64@9F]R('1H92!G:79E;B!H96%D97(N"B`@("`@*B`@
M("`@("`@("`@("`@("`@268@=&AE(&AE861E<B!I<R!N;W0@9F]U;F0L(')E
M='5R;G,@;G5L;"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4W1R:6YG*"1H
M96%D97(I"B`@("!["B`@("`@("`@)&QC2&5A9&5R(#T@4W1R:6YG.CIL;W=E
M<B@D:&5A9&5R*3L*("`@("`@("!R971U<FX@*&ES<V5T*"1T:&ES+3Y?:&5A
M9&5R<ULD;&-(96%D97)=*2D@/R`D=&AI<RT^7VAE861E<G-;)&QC2&5A9&5R
M75LG:&5A9&5R)UT@.B!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@071T
M96UP="!T;R!R971U<FX@=&AE('9A;'5E(&9O<B!A(&=I=F5N(&AE861E<BX*
M("`@("`J(%1H92!F;VQL;W=I;F<@:&5A9&5R(&9I96QD<R!C86X@;VYL>2!H
M879E(#$@96YT<GDL('-O(&EF(&1U<&QI8V%T90H@("`@("H@96YT<FEE<R!E
M>&ES="P@=&AE(&9I<G-T('9A;'5E('=I;&P@8F4@=7-E9#H*("`@("`J("`@
M*B!4;RP@1G)O;2P@0V,L($)C8RP@1&%T92P@4V5N9&5R+"!297!L>2UT;RP@
M365S<V%G92U)1"P@26XM4F5P;'DM5&\L"B`@("`@*B`@("`@4F5F97)E;F-E
M<RP@4W5B:F5C="`H4D9#(#(X,C(@6S,N-ETI"B`@("`@*B`@("H@06QL($QI
M<W0@2&5A9&5R<R`H4D9#(#(S-CD@6S-=*0H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&AE861E<B`@5&AE(&AE861E<B!T;R!S96%R8V@@9F]R+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!V86QU92!F;W(@=&AE
M(&=I=F5N(&AE861E<BX*("`@("`J("`@("`@("`@("`@("`@($EF('1H92!H
M96%D97(@:7,@;F]T(&9O=6YD+"!R971U<FYS(&YU;&PN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%9A;'5E*"1H96%D97(I"B`@("!["B`@("`@("`@)&AE
M861E<B`](%-T<FEN9SHZ;&]W97(H)&AE861E<BD["@H@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7VAE861E<G-;)&AE861E<ETI*2!["B`@("`@("`@("`@
M("1S:6YG;&4@/2!A<G)A>2@G=&\G+"`G9G)O;2<L("=C8R<L("=B8V,G+"`G
M9&%T92<L("=S96YD97(G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W)E<&QY+71O)RP@)VUE<W-A9V4M:60G+"`G:6XM<F5P;'DM=&\G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W)E9F5R96YC97,G+"`G<W5B:F5C
M="<L("=X+7!R:6]R:71Y)RD["B`@("`@("`@("`@("1S:6YG;&4@/2!A<G)A
M>5]M97)G92@D<VEN9VQE+"!A<G)A>5]K97ES*"1T:&ES+3YL:7-T2&5A9&5R
M<R@I*2D["B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D=&AI<RT^7VAE861E
M<G-;)&AE861E<EU;)W9A;'5E)UTI("8F"B`@("`@("`@("`@("`@("!I;E]A
M<G)A>2@D:&5A9&5R+"`D<VEN9VQE*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?:&5A9&5R<ULD:&5A9&5R75LG=F%L=64G75LP73L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7VAE861E<G-;)&AE861E<EU;)W9A;'5E)UT["B`@("`@("`@("`@('T*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!(87,@=&AE(&AE861E<B!B
M965N(&%L=&5R960@9G)O;2!T:&4@;W)I9VEN86P_"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D:&5A9&5R("!4:&4@:&5A9&5R('1O(&%N86QY>F4N
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!H
M96%D97(@:&%S(&)E96X@86QT97)E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M86QT97)E9$AE861E<B@D:&5A9&5R*0H@("`@>PH@("`@("`@("1L8TAE861E
M<B`](%-T<FEN9SHZ;&]W97(H)&AE861E<BD["B`@("`@("`@<F5T=7)N("AI
M<W-E="@D=&AI<RT^7VAE861E<G-;)&QC2&5A9&5R72DI(#\@)'1H:7,M/E]H
M96%D97)S6R1L8TAE861E<EU;)U]A;'1E<B==(#H@9F%L<V4["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!4<F%N<V9O<FUS(&$@2&5A9&5R('9A;'5E('5S:6YG
M('1H92!L:7-T(&]F(&9U;F-T:6]N<R!P<F]V:61E9"X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1H96%D97(@(%1H92!H96%D97(@=&\@86QT97(N
M"B`@("`@*B!`<&%R86T@;6EX960@)&9U;F-S("`@($$@9G5N8W1I;VXL(&]R
M(&%N(&%R<F%Y(&]F(&9U;F-T:6]N<RX*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@5&AE(&9U;F-T:6]N<R!W:6QL(&)E('!E<F9O<FUE9"!F<F]M
M(')I9VAT('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&QE9G0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%9A;'5E0GE&=6YC=&EO;B@D:&5A
M9&5R+"`D9G5N8W,I"B`@("!["B`@("`@("`@)&AE861E<B`](%-T<FEN9SHZ
M;&]W97(H)&AE861E<BD["@H@("`@("`@(&EF("AI<U]A<G)A>2@D9G5N8W,I
M*2!["B`@("`@("`@("`@("1F=6YC<R`](&%R<F%Y7W)E=F5R<V4H)&9U;F-S
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9G5N8W,@/2!A<G)A
M>2@D9G5N8W,I.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?:&5A9&5R<ULD:&5A9&5R72DI('L*("`@("`@("`@("`@)'9A;"`]("1T
M:&ES+3YG971686QU92@D:&5A9&5R*3L*("`@("`@("`@("`@:68@*&ES7V%R
M<F%Y*"1V86PI*2!["B`@("`@("`@("`@("`@("`D=F%L(#T@:6UP;&]D92@B
M7&XB+"`D=F%L*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!F;W)E86-H
M("@D9G5N8W,@87,@)&9U;F,I('L*("`@("`@("`@("`@("`@("1V86P@/2!C
M86QL7W5S97)?9G5N8R@D9G5N8RP@)'9A;"D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)'1H:7,M/G-E=%9A;'5E*"1H96%D97(L("1V86PI.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%D9"!A;GD@34E-12!H96%D
M97)S(')E<75I<F5D(&9O<B!T:&4@34E-15]087)T+@H@("`@("H*("`@("`J
M($!P87)A;2!-24U%7U!A<G0@)B1M:6UE7W!A<G0@(%1H92!-24U%7U!A<G0@
M;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1-24U%2&5A9&5R<R@F
M)&UI;65?<&%R="D*("`@('L*("`@("`@("!F;W)E86-H("@D;6EM95]P87)T
M+3YH96%D97(H87)R87DH*2D@87,@)&AE860@/3X@)'9A;"D@>PH@("`@("`@
M("`@("`D=&AI<RT^861D2&5A9&5R*"1H96%D+"`D=F%L*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&QI<W0@;V8@861D
M<F5S<V5S(&9O<B!A(&AE861E<B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1O8G,@($%N(&%R<F%Y(&]F(&AE861E<B!O8FIE8W1S("A3
M964@:6UA<%]H96%D97)I;F9O*"D*("`@("`J("`@("`@("`@("`@("`@("`@
M("!F;W(@=&AE(&]B:F5C="!S=')U8W1U<F4I+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@($%N(&%R<F%Y(&]F(&]B:F5C=',N"B`@("`@*B`\<')E
M/@H@("`@("H@3V)J96-T(&5L96UE;G1S.@H@("`@("H@)V%D9')E<W,G("`@
M+2`@1G5L;"!A9&1R97-S"B`@("`@*B`G:&]S="<@("`@("`M("!(;W-T(&YA
M;64*("`@("`J("=I;FYE<B<@("`@("T@(%1R:6UM960L(&)A<F4@861D<F5S
M<PH@("`@("H@)W!E<G-O;F%L)R`@+2`@4&5R<V]N86P@<W1R:6YG"B`@("`@
M*B`\+W!R93X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T061D<F5S<V5S1G)O
M;4]B:F5C="@D;V)S*0H@("`@>PH@("`@("`@("1R971!<G)A>2`](&%R<F%Y
M*"D["@H@("`@("`@(&EF("@A:7-?87)R87DH)&]B<RD@?'P@96UP='DH)&]B
M<RDI('L*("`@("`@("`@("`@<F5T=7)N("1R971!<G)A>3L*("`@("`@("!]
M"@H@("`@("`@(&9O<F5A8V@@*"1O8G,@87,@)&]B*2!["B`@("`@("`@("`@
M("\J($5N<W5R92!W92=R92!W;W)K:6YG('=I=&@@:6YI=&EA;&EZ960@=F%L
M=65S+B`J+PH@("`@("`@("`@("!I9B`H:7-S970H)&]B+3YP97)S;VYA;"DI
M('L*("`@("`@("`@("`@("`@("1O8BT^<&5R<V]N86P@/2!-24U%.CID96-O
M9&4H)&]B+3YP97)S;VYA;"D["B`@("`@("`@("`@("`@("!I9B`H*'-U8G-T
M<B@D;V(M/G!E<G-O;F%L+"`P+"`Q*2`]/2`G(B<I("8F"B`@("`@("`@("`@
M("`@("`@("`@*'-U8G-T<B@D;V(M/G!E<G-O;F%L+"`M,2D@/3T@)R(G*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1O8BT^<&5R<V]N86P@/2!S=6)S='(H
M)&]B+3YP97)S;VYA;"P@,2P@+3$I.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&]B+3YP97)S;VYA
M;"`]("<G.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H:7-S970H
M)&]B+3YM86EL8F]X*2D@>PH@("`@("`@("`@("`@("`@+RH@1&]N)W0@<')O
M8V5S<R!I;G9A;&ED(&%D9')E<W-E<RX@*B\*("`@("`@("`@("`@("`@(&EF
M("AS=')P;W,H)&]B+3YM86EL8F]X+"`G54Y%6%!%0U1%1%]$051!7T%&5$52
M7T%$1%)%4U,G*2`A/3T@9F%L<V4@?'P*("`@("`@("`@("`@("`@("`@("!S
M=')P;W,H)&]B+3YM86EL8F]X+"`G24Y604Q)1%]!1$1215-3)RD@(3T](&9A
M;'-E*2!["B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D;V(M/FUA:6QB;W@@/2`G)SL*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@:68@*"%I<W-E="@D;V(M/FAO<W0I*2!["B`@("`@("`@("`@("`@("`D
M;V(M/FAO<W0@/2`G)SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@
M1V5N97)A=&4@=&AE(&YE=R!O8FIE8W0N("HO"B`@("`@("`@("`@("1N97=/
M8B`]("9N97<@<W1D0VQA<W,["B`@("`@("`@("`@("1N97=/8BT^861D<F5S
M<R`]($U)344Z.F%D9')/8FIE8W0R4W1R:6YG*"1O8BP@87)R87DH)W5N9&ES
M8VQO<V5D+7)E8VEP:65N='-`)RP@)U5N9&ES8VQO<V5D(')E8VEP:65N='-`
M)RDI.PH@("`@("`@("`@("`D;F5W3V(M/FAO<W0@/2`D;V(M/FAO<W0["B`@
M("`@("`@("`@("1N97=/8BT^:6YN97(@/2!-24U%.CIT<FEM16UA:6Q!9&1R
M97-S*$U)344Z.G)F8S@R,E=R:71E061D<F5S<R@D;V(M/FUA:6QB;W@L("1O
M8BT^:&]S="P@)R<I*3L*("`@("`@("`@("`@)&YE=T]B+3YP97)S;VYA;"`]
M("1O8BT^<&5R<V]N86P["@H@("`@("`@("`@("`D<F5T07)R87E;72`]("8D
M;F5W3V(["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E=$%R<F%Y.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;&ES="!O9B!V86QI
M9"!M86EL:6YG(&QI<W0@:&5A9&5R<RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("!4:&4@;&ES="!O9B!V86QI9"!M86EL:6YG(&QI<W0@:&5A9&5R
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=$AE861E<G,H*0H@("`@>PH@
M("`@("`@(')E='5R;B!A<G)A>2@*("`@("`@("`@("`@+RH@4D9#(#(S-CD@
M*B\*("`@("`@("`@("`@)VQI<W0M:&5L<"<@("`@("`@("`]/B`@7R@B3&ES
M="U(96QP(BDL"B`@("`@("`@("`@("=L:7-T+75N<W5B<V-R:6)E)R`@/3X@
M(%\H(DQI<W0M56YS=6)S8W)I8F4B*2P*("`@("`@("`@("`@)VQI<W0M<W5B
M<V-R:6)E)R`@("`]/B`@7R@B3&ES="U3=6)S8W)I8F4B*2P*("`@("`@("`@
M("`@)VQI<W0M;W=N97(G("`@("`@("`]/B`@7R@B3&ES="U/=VYE<B(I+`H@
M("`@("`@("`@("`G;&ES="UP;W-T)R`@("`@("`@(#T^("!?*"),:7-T+5!O
M<W0B*2P*("`@("`@("`@("`@)VQI<W0M87)C:&EV92<@("`@("`]/B`@7R@B
M3&ES="U!<F-H:79E(BDL"B`@("`@("`@("`@("\J(%)&0R`R.3$Y("HO"B`@
M("`@("`@("`@("=L:7-T+6ED)R`@("`@("`@("`@/3X@(%\H(DQI<W0M260B
M*0H@("`@("`@("D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$;R!A;GD@;6%I
M;&EN9R!L:7-T(&AE861E<G,@97AI<W0_"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!4<G5E(&EF(&%N>2!M86EL:6YG(&QI<W0@:&5A9&5R<R!E
M>&ES="X*("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=$AE861E<G-%>&ES="@I
M"B`@("!["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/FQI<W1(96%D97)S*"D@
M87,@)'9A;"`]/B`D<W1R*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^7VAE861E<G-;)'9A;%TI*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M=')U93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!A(&YE=R!S=')I
M;F<@=&\@=7-E(&9O<B!%3TQS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&5O;"`@5&AE('-T<FEN9R!T;R!U<V4@9F]R($5/3',N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-E=$5/3"@D96]L*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?96]L(#T@)&5O;#L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@
M<W1R:6YG('1O('5S92!F;W(@14],<RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE('-T<FEN9R!T;R!U<V4@9F]R($5/3',N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=$5/3"@I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?96]L.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M9FQA9R!S=&%T=7,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FQA
M9R`@27,@=&AI<R!F;&%G('-E=#\*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@($9L86=S.B!R96-E;G0L('5N<V5E;BP@86YS=V5R960L(&1R869T+"!I
M;7!O<G1A;G0L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M9&5L971E9`H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I
M9B!T:&4@9FQA9R!H87,@8F5E;B!S970L(&9A;'-E(&EF(&YO="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T1FQA9R@D9FQA9RD*("`@('L*("`@("`@("!I
M9B`H(65M<'1Y*"1T:&ES+3Y?9FQA9W-;4W1R:6YG.CIL;W=E<B@D9FQA9RE=
M*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@1V5T('1H92!P<FEM87)Y(&9R;VT@861D<F5S<R`H
M9FER<W0@861D<F5S<R!I;B!T:&4@1G)O;3H@:&5A9&5R*2X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&9R;VT@861D<F5S<R`H=7-E<D!H
M;W-T*2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1G)O;4%D9')E<W,H*0H@
M("`@>PH@("`@("`@(&EF("@A*"1O8B`]("1T:&ES+3YG971/8B@G9G)O;2<I
M*2D@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"@H@("`@
M("`@(')E<75I<F5?;VYC92`G2&]R9&4O34E-12YP:'`G.PH*("`@("`@("!R
M971U<FX@=')I;2A-24U%.CIT<FEM16UA:6Q!9&1R97-S*$U)344Z.G)F8S@R
M,E=R:71E061D<F5S<R@D;V);,%TM/FUA:6QB;W@L("AI<W-E="@D;V);,%TM
M/FAO<W0I*2`_("1O8ELP72T^:&]S="`Z("<G+"`G)RDI*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($=E="!A(&AE861E<B!F<F]M('1H92!H96%D97(@;V)J
M96-T+@H@("`@("H*("`@("`J($!T;V1O(%)E<&QA8V4@=VET:"!G971/8B@I
M(&9R;VT@24U0)W,@24U07TAE861E<G,@9F]R($AO<F1E(#0N,"X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:65L9"`@("!4:&4@;V)J96-T(&9I
M96QD('1O(')E=')I979E("AS964*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@(&EM87!?:&5A9&5R:6YF;R@I(&9O<B!T:&4@;&ES="!O9B!F:65L
M9',I+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&1E8V]D92`@4VAO=6QD('1H
M92!R971U<FX@=F%L=64@8F4@34E-12!D96-O9&5D/PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@270@=VEL;"!O;FQY(&)E(&1E8V]D960@:68@
M:70@:7,@;F]T(&%N(&]B:F5C=`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@:71S96QF+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H
M92!F:65L9"!R97%U97-T960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$]B
M*"1F:65L9"P@)&1E8V]D92`](&9A;'-E*0H@("`@>PH@("`@("`@("1D871A
M(#T@87)R87DH*3L*"B`@("`@("`@)&]B(#T@)'1H:7,M/F=E=$AE861E<D]B
M:F5C="@I.PH@("`@("`@(&EF("@A:7-?;V)J96-T*"1O8BDI('L*("`@("`@
M("`@("`@<F5T=7)N("1D871A.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES
M<V5T*"1O8BT^)&9I96QD*2D@>PH@("`@("`@("`@("`D9&%T82`]("1O8BT^
M)&9I96QD.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1D96-O9&4I("8F("%I
M<U]O8FIE8W0H)&1A=&$I("8F("%I<U]A<G)A>2@D9&%T82DI('L*("`@("`@
M("`@("`@("`@(&EN8VQU9&5?;VYC92`G2&]R9&4O34E-12YP:'`G.PH@("`@
M("`@("`@("`@("`@:68@*"%E;7!T>2@D1TQ/0D%,4ULG;6EM95]H96%D97)S
M)UU;)V1E9F%U;'1?8VAA<G-E="==*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1D871A(#T@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D9&%T82P@)$=,3T)!
M3%-;)VUI;65?:&5A9&5R<R==6R=D969A=6QT7V-H87)S970G72D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D9&%T82`]($U)344Z.F1E
M8V]D92@D9&%T82D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`H:7-?<W1R:6YG*"1D871A*2D@/R!S=')T<B@D9&%T82P@(EQT
M(BP@)R`G*2`Z("1D871A.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92]-24U%+U-T<G5C='5R92YP:'``````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`S-3`V-"`Q,#4Q-30S,S<S-R`P,C(V,C(`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*"G)E
M<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O365S<V%G92YP:'`G
M.PIR97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+U!A<G0N<&AP
M)SL*<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B]-24U%
M+G!H<"<["@HO*BH*("H@)$AO<F1E.B!F<F%M97=O<FLO34E-12]-24U%+U-T
M<G5C='5R92YP:'`L=B`Q+C@W+C$P+C$Y(#(P,#8O,#4O,#0@,3@Z,#,Z,C4@
M<VQU<V%R>B!%>'`@)`H@*@H@*B!4:&4@34E-15]3=')U8W1U<F4Z.B!C;&%S
M<R!P<F]V:61E<R!M971H;V1S(&9O<B!D96%L:6YG('=I=&@@34E-12!M86EL
M+@H@*@H@*B!4:&4@9&5F875L="!C:&%R86-T97(@<V5T('1O('5S92!F;W(@
M;65S<V%G97,@<VAO=6QD(&)E(&1E9FEN960@:6X@=&AE"B`J('9A<FEA8FQE
M("1'3$]"04Q36R=M:6UE7W-T<G5C='5R92==6R=D969A=6QT7V-H87)S970G
M72`H9&5F875L=',@=&\@55,M05-#24D*("H@<&5R(%)&0R`R,#0U*2X*("H*
M("H@5$]$3SH@0V]N=F5R="!T;R!/3PH@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR
M,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y
M<FEG:'0@,C`P,BTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W
M;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R
M("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE
M9'4^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]-
M24U%"B`J+PIC;&%S<R!-24U%7U-T<G5C='5R92!["@H@("`@+RHJ"B`@("`@
M*B!':79E;B!T:&4@<F5S=6QT<R!O9B!I;6%P7V9E=&-H<W1R=6-T=7)E*"DL
M('!A<G-E('1H92!S=')U8W1U<F4*("`@("`J(&]F('1H92!M97-S86=E+"!F
M:6=U<FEN9R!O=70@8V]R<F5C="!B;V1Y<&%R="!N=6UB97)S+"!E=&,N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T9$-L87-S("1B;V1Y("!4:&4@<F5S=6QT
M(&]F(&EM87!?9F5T8VAS=')U8W1U<F4H*2X*("`@("`J"B`@("`@*B!`<F5T
M=7)N("9-24U%7TUE<W-A9V4@(%1H92!M97-S86=E('!A<G-E9"!I;G1O(&$@
M34E-15]-97-S86=E(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@)G!A
M<G-E*"1B;V1Y*0H@("`@>PH@("`@("`@("1M<V=/8B`]("9N97<@34E-15]-
M97-S86=E*"D["B`@("`@("`@)&US9T]B+3YA9&1087)T*$U)345?4W1R=6-T
M=7)E.CI?<&%R<V4H)&)O9'DI*3L*("`@("`@("`D;7-G3V(M/F)U:6QD365S
M<V%G92@I.PH*("`@("`@("`D<'1R(#T@87)R87DH)B1M<V=/8BD["B`@("`@
M("`@34E-15]3=')U8W1U<F4Z.E]A9&1-=6QT:7!A<G1);F9O*"1P='(I.PH*
M("`@("`@("!R971U<FX@)&US9T]B.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1VEV96X@=&AE(')E<W5L=',@;V8@:6UA<%]F971C:'-T<G5C='5R92@I+"!P
M87)S92!T:&4@<W1R=6-T=7)E"B`@("`@*B!O9B!T:&4@;65S<V%G92P@9FEG
M=7)I;F<@;W5T(&-O<G)E8W0@8F]D>7!A<G0@;G5M8F5R<RP@971C+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A
M;2!S=&1#;&%S<R`D8F]D>2`@5&AE(')E<W5L="!O9B!I;6%P7V9E=&-H<W1R
M=6-T=7)E*"DN"B`@("`@*B!`<&%R86T@<W1R:6YG("1R968@("`@(%1H92!C
M=7)R96YT(&)O9'EP87)T+@H@("`@("H*("`@("`J($!R971U<FX@34E-15]0
M87)T("!!($U)345?4&%R="!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9?<&%R<V4H)&)O9'DL("1R968@/2`P*0H@("`@>PH@("`@("`@('-T871I
M8R`D;65S<V%G92P@)&UU;'1I<&%R=#L*"B`@("`@("`@:68@*"%I<W-E="@D
M;65S<V%G92DI('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!-24U%.CIT>7!E
M*"=M97-S86=E)RD["B`@("`@("`@("`@("1M=6QT:7!A<G0@/2!-24U%.CIT
M>7!E*"=M=6QT:7!A<G0G*3L*("`@("`@("!]"@H@("`@("`@("1M:6UE7W!A
M<G0@/2`F;F5W($U)345?4&%R="@I.PH*("`@("`@("`O*B!4;W`@;75L=&EP
M87)T<R!D;VXG="!G970@=&AE:7(@;W=N(&QI;F4N("HO"B`@("`@("`@:68@
M*&5M<'1Y*"1R968I("8F"B`@("`@("`@("`@("@A:7-S970H)&)O9'DM/G1Y
M<&4I('Q\("@D8F]D>2T^='EP92`A/2`D;75L=&EP87)T*2DI('L*("`@("`@
M("`@("`@)')E9B`](#$["B`@("`@("`@?0H*("`@("`@("!-24U%7U-T<G5C
M='5R93HZ7W-E=$EN9F\H)&)O9'DL("1M:6UE7W!A<G0L("1R968I.PH*("`@
M("`@("!I9B`H:7-S970H)&)O9'DM/G1Y<&4I("8F("@D8F]D>2T^='EP92`]
M/2`D;65S<V%G92D@)B8*("`@("`@("`@("`@)&)O9'DM/FEF<W5B='EP92`F
M)B`H)&)O9'DM/G-U8G1Y<&4@/3T@)U)&0S@R,B<I*2!["B`@("`@("`@("`@
M("1M:6UE7W!A<G0M/G-E=$U)345)9"@D<F5F("X@)RXP)RD["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&UI;65?<&%R="T^<V5T34E-14ED*"1R
M968I.PH@("`@("`@('T*"B`@("`@("`@+RH@1&5A;"!W:71H(&UU;'1I<&%R
M="!D871A+B`J+PH@("`@("`@(&EF("AI<W-E="@D8F]D>2T^<&%R=',I*2![
M"B`@("`@("`@("`@("1S=6)?:60@/2`Q.PH@("`@("`@("`@("!F;W)E86-H
M("@D8F]D>2T^<&%R=',@87,@)'-U8E]P87)T*2!["B`@("`@("`@("`@("`@
M("`O*B!!<F4@=V4@9&5A;&EN9R!W:71H(&$@;75L=&EP87)T(&UE<W-A9V4_
M("HO"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&)O9'DM/G1Y<&4I("8F
M("@D8F]D>2T^='EP92`]/2`D;65S<V%G92D@)B8*("`@("`@("`@("`@("`@
M("`@("!I<W-E="@D<W5B7W!A<G0M/G1Y<&4I("8F("@D<W5B7W!A<G0M/G1Y
M<&4@/3T@)&UU;'1I<&%R="DI('L*("`@("`@("`@("`@("`@("`@("`D<W5B
M7W)E9B`]("1R968["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("1S=6)?<F5F(#T@*&5M<'1Y*"1R968I*2`_("1S=6)?
M:60@.B`D<F5F("X@)RXG("X@)'-U8E]I9#L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("1M:6UE7W!A<G0M/F%D9%!A<G0H34E-15]3=')U
M8W1U<F4Z.E]P87)S92@D<W5B7W!A<G0L("1S=6)?<F5F*2P@)'-U8E]I9"LK
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1M
M:6UE7W!A<G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!':79E;B!A(&UI;64@
M<&%R="!F<F]M(&EM87!?9F5T8VAS=')U8W1U<F4H*2P@;75N9V4@:70@:6YT
M;R!A"B`@("`@*B!U<V5F=6P@9F]R;2!A;F0@;6%K92!S=7)E('1H870@86YY
M('!A<F%M971E<G,@=VAI8V@@87)E(&UI<W-I;F<*("`@("`J(&%R92!G:79E
M;B!D969A=6QT('9A;'5E<RX*("`@("`J"B`@("`@*B!4;R!S<&5C:69Y('1H
M92!D969A=6QT(&-H87)A8W1E<B!S970L(&1E9FEN92!T:&4@9VQO8F%L('9A
M<FEA8FQE"B`@("`@*B`D1TQ/0D%,4ULG;6EM95]S=')U8W5T<F4G75LG9&5F
M875L=%]C:&%R<V5T)UTN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T9$-L87-S("1P87)T("!4:&4@;W)I
M9VEN86P@<&%R="!I;F9O+@H@("`@("H@0'!A<F%M($U)345?4&%R="`F)&]B
M("!!($U)345?4&%R="!O8FIE8W0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1R
M968@("`@(%1H92!)1"!O9B!T:&ES('!A<G0N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]S971);F9O*"1P87)T+"`F)&]B+"`D<F5F*0H@("`@>PH@("`@("`@
M("\J(%-T;W)E($-O;G1E;G0M='EP92!I;F9O<FUA=&EO;BX@*B\*("`@("`@
M("`D<')I;6%R>5]T>7!E(#T@*&ES<V5T*"1P87)T+3YT>7!E*2D@/R!3=')I
M;F<Z.FQO=V5R*"1P87)T+3YT>7!E*2`Z($U)344Z.G1Y<&4H)W1E>'0G*3L*
M("`@("`@("`D<V5C7W1Y<&4@/2`H)'!A<G0M/FEF<W5B='EP92`F)B`D<&%R
M="T^<W5B='EP92D@/R!3=')I;F<Z.FQO=V5R*"1P87)T+3YS=6)T>7!E*2`Z
M("=X+75N:VYO=VXG.PH@("`@("`@("1O8BT^<V5T5'EP92@D<')I;6%R>5]T
M>7!E("X@)R\G("X@)'-E8U]T>7!E*3L*"B`@("`@("`@+RH@4V5T('1R86YS
M9F5R(&5N8V]D:6YG+B`J+PH@("`@("`@(&EF("AI<W-E="@D<&%R="T^96YC
M;V1I;F<I*2!["B`@("`@("`@("`@("1E;F-O9&EN9R`]("1P87)T+3YE;F-O
M9&EN9SL*("`@("`@("`@("`@)&]B+3YS9714<F%N<V9E<D5N8V]D:6YG*"1E
M;F-O9&EN9RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&5N8V]D
M:6YG(#T@;G5L;#L*("`@("`@("!]"@H@("`@("`@("\J(%-E="!T<F%N<V9E
M<B!D:7-P;W-I=&EO;BX@*B\*("`@("`@("`D;V(M/G-E=$1I<W!O<VET:6]N
M*"@D<&%R="T^:69D:7-P;W-I=&EO;BD@/R!3=')I;F<Z.FQO=V5R*"1P87)T
M+3YD:7-P;W-I=&EO;BD@.B!-24U%7T1%1D%53%1?1$E34$]3251)3TXI.PH*
M("`@("`@("`O*B!)9B`G8F]D>2<@:7,@<V5T+"!S970@87,@=&AE(&-O;G1E
M;G1S(&]F('1H92!P87)T+B`J+PH@("`@("`@(&EF("AI<W-E="@D<&%R="T^
M8F]D>2DI('L*("`@("`@("`@("`@)&]B+3YS971#;VYT96YT<R@D<&%R="T^
M8F]D>2P@)&5N8V]D:6YG*3L*("`@("`@("!]"@H@("`@("`@("\J($EF("=B
M>71E<R<@:7,@<V5T+"!S=&]R92!A<R!I;F9O<FUA=&EO;B!V87)I86)L92X@
M*B\*("`@("`@("!I9B`H:7-S970H)'!A<G0M/F)Y=&5S*2D@>PH@("`@("`@
M("`@("`D;V(M/G-E=$)Y=&5S*"1P87)T+3YB>71E<RD["B`@("`@("`@?0H*
M("`@("`@("`O*B!3970@=&AE('!A<G0G<R!I9&5N=&EF:6-A=&EO;B!S=')I
M;F<L(&EF(&%V86EL86)L92X@*B\*("`@("`@("!I9B`H(65M<'1Y*"1R968I
M("8F("1P87)T+3YI9FED*2!["B`@("`@("`@("`@("1O8BT^<V5T0V]N=&5N
M=$E$*"1P87)T+3YI9"D["B`@("`@("`@?0H*("`@("`@("`O*B!';R!T:')O
M=6=H('1H92!C;VYT96YT+71Y<&4@<&%R86UE=&5R<RP@:68@86YY+B`J+PH@
M("`@("`@(&9O<F5A8V@@*$U)345?4W1R=6-T=7)E.CI?9V5T4&%R86UE=&5R
M<R@D<&%R="P@,2D@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@(&EF
M("@D:V5Y(#T]("=C:&%R<V5T)RD@>PH@("`@("`@("`@("`@("`@)&]B+3YS
M971#:&%R<V5T*"1V86PI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)&]B+3YS971#;VYT96YT5'EP95!A<F%M971E<B@D:V5Y+"`D
M=F%L*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@4V5T
M('1H92!D969A=6QT(&-H87)A8W1E<B!S970N("HO"B`@("`@("`@:68@*"@D
M;V(M/F=E=$-H87)S970H*2`]/2`G=7,M87-C:6DG*2`F)@H@("`@("`@("`@
M("!I<W-E="@D1TQ/0D%,4ULG;6EM95]S=')U8W1U<F4G75LG9&5F875L=%]C
M:&%R<V5T)UTI*2!["B`@("`@("`@("`@("1O8BT^<V5T0VAA<G-E="@D1TQ/
M0D%,4ULG;6EM95]S=')U8W1U<F4G75LG9&5F875L=%]C:&%R<V5T)UTI.PH@
M("`@("`@('T*"B`@("`@("`@+RH@1V\@=&AR;W5G:"!T:&4@9&ES<&]S:71I
M;VX@<&%R86UE=&5R<RP@:68@86YY+B`J+PH@("`@("`@(&9O<F5A8V@@*$U)
M345?4W1R=6-T=7)E.CI?9V5T4&%R86UE=&5R<R@D<&%R="P@,BD@87,@)&ME
M>2`]/B`D=F%L*2!["B`@("`@("`@("`@("1O8BT^<V5T1&ES<&]S:71I;VY0
M87)A;65T97(H)&ME>2P@)'9A;"D["B`@("`@("`@?0H*("`@("`@("`O*B!3
M970@=&AE(&YA;64N("HO"B`@("`@("`@:68@*"1O8BT^9V5T0V]N=&5N=%1Y
M<&5087)A;65T97(H)V9I;&5N86UE)RDI('L*("`@("`@("`@("`@)&]B+3YS
M971.86UE*"1O8BT^9V5T0V]N=&5N=%1Y<&5087)A;65T97(H)V9I;&5N86UE
M)RDI.PH@("`@("`@('T@96QS96EF("@D;V(M/F=E=$1I<W!O<VET:6]N4&%R
M86UE=&5R*"=F:6QE;F%M92<I*2!["B`@("`@("`@("`@("1O8BT^<V5T3F%M
M92@D;V(M/F=E=$1I<W!O<VET:6]N4&%R86UE=&5R*"=F:6QE;F%M92<I*3L*
M("`@("`@("!]"@H@("`@("`@("\J(%-E="!T:&4@9&5S8W)I<'1I;VXN("HO
M"B`@("`@("`@:68@*&ES<V5T*"1P87)T+3YD97-C<FEP=&EO;BDI('L*("`@
M("`@("`@("`@)&]B+3YS971$97-C<FEP=&EO;B@D<&%R="T^9&5S8W)I<'1I
M;VXI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A;&P@
M<&%R86UE=&5R<R!F;W(@82!G:79E;B!P;W)T:6]N(&]F(&$@;65S<V%G92X*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1D0VQA<W,@)'!A<G0@(%1H92!O<FEG:6YA;"!P87)T(&EN9F\N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D='EP92`@(%1H92!P87)A;65T97(@
M='EP92!T;R!R971R:65V92X*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@,2`](&-O;G1E;G0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M,B`](&1I<W!O<VET:6]N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@
M06X@87)R87D@;V8@<&%R86UE=&5R(&ME>2]V86QU92!P86ER<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V=E=%!A<F%M971E<G,H)'!A<G0L("1T>7!E*0H@
M("`@>PH@("`@("`@("1P87)A;5]L:7-T(#T@87)R87DH*3L*"B`@("`@("`@
M:68@*"1T>7!E(#T](#$I('L*("`@("`@("`@("`@)'!T>7!E(#T@)W!A<F%M
M971E<G,G.PH@("`@("`@('T@96QS96EF("@D='EP92`]/2`R*2!["B`@("`@
M("`@("`@("1P='EP92`]("=D<&%R86UE=&5R<R<["B`@("`@("`@?0H@("`@
M("`@("1P97AI<W1S(#T@)VEF)R`N("1P='EP93L*"B`@("`@("`@:68@*"1P
M87)T+3XD<&5X:7-T<RD@>PH@("`@("`@("`@("!F;W)E86-H("@D<&%R="T^
M)'!T>7!E(&%S("1P87)A;2D@>PH@("`@("`@("`@("`@("`@)'!A<F%M+3YV
M86QU92`]('-T<E]R97!L86-E*&%R<F%Y*")<="(L("=<(B<I+"!A<G)A>2@G
M("<L("<B)RDL("1P87)A;2T^=F%L=64I.PH*("`@("`@("`@("`@("`@("1R
M97,@/2!-24U%.CID96-O9&521D,R,C,Q*"1P87)A;2T^871T<FEB=71E("X@
M)STG("X@)'!A<F%M+3YV86QU92D["B`@("`@("`@("`@("`@("!I9B`H)')E
M<RD@>PH@("`@("`@("`@("`@("`@("`@("1P87)A;2T^871T<FEB=71E(#T@
M)')E<ULG871T<FEB=71E)UT["B`@("`@("`@("`@("`@("`@("`@)'!A<F%M
M+3YV86QU92`]("1R97-;)W9A;'5E)UT["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`D9FEE;&0@/2!3=')I;F<Z.FQO=V5R*"1P87)A;2T^
M871T<FEB=71E*3L*("`@("`@("`@("`@("`@(&EF("@D9FEE;&0@/3T@)W1Y
M<&4G*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"@D='EP92`]($U)344Z
M.G1Y<&4H)'!A<F%M+3YV86QU92DI*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1P87)A;5]L:7-T6R=T>7!E)UT@/2`D='EP93L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1P87)A;5]L:7-T6R1F:65L9%T@/2`D<&%R86TM/G9A;'5E
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)'!A<F%M7VQI<W0["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3970@=&AE('-P96-I86P@:6YF;W)M871I;VX@9F]R(&-E<G1A:6X@
M34E-12!T>7!E<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@87)R87D@)B1P87)T<R`@5&AE(&QI<W0@;V8@
M<&%R=',@8V]N=&%I;F5D('=I=&AI;B!T:&4@;75L=&EP87)T"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@;V)J96-T+@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1I;F9O("`@($EN9F]R;6%T:6]N(&%B;W5T('1H92!M=6QT:7!A<G0@
M<W1R=6-T=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?861D375L=&EP87)T
M26YF;R@F)'!A<G1S+"`D:6YF;R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M:68@*&5M<'1Y*"1P87)T<RDI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@
M("`@('T*"B`@("`@("`@9F]R96%C:"`H87)R87E?:V5Y<R@D<&%R=',I(&%S
M("1K97DI('L*("`@("`@("`@("`@)'!T<B`]("8D<&%R='-;)&ME>5T["B`@
M("`@("`@("`@("1N97=?:6YF;R`]("1I;F9O.PH*("`@("`@("`@("`@:68@
M*&ES<V5T*"1I;F9O6R=A;'0G72DI('L*("`@("`@("`@("`@("`@("1P='(M
M/G-E=$EN9F]R;6%T:6]N*"=A;'1E<FYA=&EV92<L("AI<U]N=6QL*"1I;F9O
M6R=A;'0G72DI(#\@)RTG(#H@)&EN9F];)V%L="==*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!I9B`H:7-S970H)&EN9F];)W)E;&%T960G72DI('L*
M("`@("`@("`@("`@("`@("1P='(M/G-E=$EN9F]R;6%T:6]N*"=R96QA=&5D
M7W!A<G0G+"`D:6YF;ULG<F5L871E9"==+3YG971-24U%260H*2D["B`@("`@
M("`@("`@("`@("!I9B`H)&ED(#T@)'!T<BT^9V5T0V]N=&5N=$E$*"DI('L*
M("`@("`@("`@("`@("`@("`@("`D:6YF;ULG<F5L871E9"==+3YA9&1#240H
M87)R87DH)'!T<BT^9V5T34E-14ED*"D@/3X@)&ED*2D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES<V5T*"1I
M;F9O6R=R9F,X,C(G72DI('L*("`@("`@("`@("`@("`@("1P='(M/G-E=$EN
M9F]R;6%T:6]N*"=R9F,X,C)?<&%R="<L("1I;F9O6R=R9F,X,C(G72D["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@('-W:71C:"`H)'!T<BT^9V5T5'EP
M92@I*2!["B`@("`@("`@("`@(&-A<V4@)VUU;'1I<&%R="]A;'1E<FYA=&EV
M92<Z"B`@("`@("`@("`@("`@("`D;F5W7VEN9F];)V%L="==(#T@)'!T<BT^
M9V5T34E-14ED*"D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&-A<V4@)VUU;'1I<&%R="]R96QA=&5D)SH*("`@("`@("`@("`@("`@
M("1N97=?:6YF;ULG<F5L871E9"==(#T@)B1P='(["B`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)VUE<W-A9V4O<F9C.#(R)SH*
M("`@("`@("`@("`@("`@("1N97=?:6YF;ULG<F9C.#(R)UT@/2`D<'1R+3YG
M971-24U%260H*3L*("`@("`@("`@("`@("`@("1P='(M/G-E=$EN9F]R;6%T
M:6]N*"=H96%D97(G+"!T<G5E*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!-24U%7U-T<G5C='5R93HZ7V%D
M9$UU;'1I<&%R=$EN9F\H)'!T<BT^7W!A<G1S+"`D;F5W7VEN9F\I.PH@("`@
M("`@('T*("`@('T*"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!B=6EL
M9"!A($U)345?365S<V%G92!O8FIE8W0@9G)O;2!A('1E>'0@;65S<V%G92X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("!4:&4@=&5X="!O
M9B!T:&4@34E-12!M97-S86=E+@H@("`@("H*("`@("`J($!R971U<FX@34E-
M15]-97-S86=E("!!($U)345?365S<V%G92!O8FIE8W0L(&]R(&9A;'-E(&]N
M(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<&%R<V5497AT34E-14UE
M<W-A9V4H)'1E>'0I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=-86EL
M+VUI;65$96-O9&4N<&AP)SL*"B`@("`@("`@+RH@4V5T('5P('1H92!O<'1I
M;VYS(&9O<B!T:&4@;6EM941E8V]D92!C;&%S<RX@*B\*("`@("`@("`D9&5C
M;V1E7V%R9W,@/2!A<G)A>2@I.PH@("`@("`@("1D96-O9&5?87)G<ULG:6YC
M;'5D95]B;V1I97,G72`]('1R=64["B`@("`@("`@)&1E8V]D95]A<F=S6R=D
M96-O9&5?8F]D:65S)UT@/2!F86QS93L*("`@("`@("`D9&5C;V1E7V%R9W-;
M)V1E8V]D95]H96%D97)S)UT@/2!F86QS93L*"B`@("`@("`@)&UI;65$96-O
M9&4@/2`F;F5W($UA:6Q?;6EM941E8V]D92@D=&5X="P@34E-15]005)47T5/
M3"D["B`@("`@("`@:68@*"$H)'-T<G5C='5R92`]("1M:6UE1&5C;V1E+3YD
M96-O9&4H)&1E8V]D95]A<F=S*2DI('L*("`@("`@("`@("`@)&UE<W-A9V4@
M/2!F86QS93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!0=70@
M=&AE(&]B:F5C="!I;G1O(&EM87!?<&%R<V5S=')U8W1U<F4H*2!F;W)M+B`J
M+PH@("`@("`@("`@("!-24U%7U-T<G5C='5R93HZ7V-O;G9E<G1-:6UE1&5C
M;V1E1&%T82@D<W1R=6-T=7)E*3L*"B`@("`@("`@("`@("1M97-S86=E(#T@
M34E-15]3=')U8W1U<F4Z.G!A<G-E*"1S=')U8W1U<F4I.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1M97-S86=E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0V]N=F5R="!T:&4@;W5T<'5T(&9R;VT@;6EM941E8V]D93HZ9&5C;V1E
M*"D@:6YT;R!A('-T<G5C='5R92!T:&%T"B`@("`@*B!M871C:&5S(&EM87!?
M9F5T8VAS=')U8W1U<F4H*2!O=71P=70N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T9$-L87-S("8D;V(@
M(%1H92!O=71P=70@9G)O;2!M:6UE1&5C;V1E.CID96-O9&4H*2X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V-O;G9E<G1-:6UE1&5C;V1E1&%T82@F)&]B*0H@
M("`@>PH@("`@("`@("\J(%!R:6UA<GD@8V]N=&5N="UT>7!E+B`J+PH@("`@
M("`@("1O8BT^='EP92`](&EN='9A;"A-24U%.CIT>7!E*"1O8BT^8W1Y<&5?
M<')I;6%R>2DI.PH*("`@("`@("`O*B!396-O;F1A<GD@8V]N=&5N="UT>7!E
M+B`J+PH@("`@("`@(&EF("AI<W-E="@D;V(M/F-T>7!E7W-E8V]N9&%R>2DI
M('L*("`@("`@("`@("`@)&]B+3YS=6)T>7!E(#T@4W1R:6YG.CIU<'!E<B@D
M;V(M/F-T>7!E7W-E8V]N9&%R>2D["B`@("`@("`@("`@("1O8BT^:69S=6)T
M>7!E(#T@,3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;V(M/FEF
M<W5B='EP92`](#`["B`@("`@("`@?0H*("`@("`@("`O*B!#;VYT96YT('1R
M86YS9F5R(&5N8V]D:6YG+B`J+PH@("`@("`@(&EF("AI<W-E="@D;V(M/FAE
M861E<G-;)V-O;G1E;G0M=')A;G-F97(M96YC;V1I;F<G72DI('L*("`@("`@
M("`@("`@)&]B+3YE;F-O9&EN9R`]($U)344Z.F5N8V]D:6YG*"1O8BT^:&5A
M9&5R<ULG8V]N=&5N="UT<F%N<V9E<BUE;F-O9&EN9R==*3L*("`@("`@("!]
M"@H@("`@("`@("\J($-O;G1E;G0M='EP92!A;F0@1&ES<&]S:71I;VX@<&%R
M86UE=&5R<RX@*B\*("`@("`@("`D<&%R86U?='EP97,@/2!A<G)A>2`H)V-T
M>7!E7W!A<F%M971E<G,G(#T^("=P87)A;65T97)S)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V1?<&%R86UE=&5R<R<@/3X@)V1P87)A;65T
M97)S)RD["B`@("`@("`@9F]R96%C:"`H)'!A<F%M7W1Y<&5S(&%S("1P87)A
M;5]K97D@/3X@)'!A<F%M7W9A;'5E*2!["B`@("`@("`@("`@("1I9E]V87(@
M/2`G:68G("X@)'!A<F%M7W9A;'5E.PH@("`@("`@("`@("!I9B`H:7-S970H
M)&]B+3XD<&%R86U?:V5Y*2D@>PH@("`@("`@("`@("`@("`@)&]B+3XD:69?
M=F%R(#T@,3L*("`@("`@("`@("`@("`@("1O8BT^)'!A<F%M7W9A;'5E(#T@
M87)R87DH*3L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1O8BT^)'!A<F%M
M7VME>2!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@("`@("`@("`D
M;F5W3V(@/2`F;F5W('-T9$-L87-S.PH@("`@("`@("`@("`@("`@("`@("1N
M97=/8BT^871T<FEB=71E(#T@)&ME>3L*("`@("`@("`@("`@("`@("`@("`D
M;F5W3V(M/G9A;'5E(#T@)'9A;#L*("`@("`@("`@("`@("`@("`@("!A<G)A
M>5]P=7-H*"1O8BT^)'!A<F%M7W9A;'5E+"`D;F5W3V(I.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)&]B+3XD:69?=F%R(#T@,#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@+RH@0V]N=&5N="U$:7-P;W-I=&EO;BX@*B\*("`@("`@("!I9B`H
M:7-S970H)&]B+3YH96%D97)S6R=C;VYT96YT+61I<W!O<VET:6]N)UTI*2![
M"B`@("`@("`@("`@("1O8BT^:69D:7-P;W-I=&EO;B`](#$["B`@("`@("`@
M("`@("1H9'(@/2`D;V(M/FAE861E<G-;)V-O;G1E;G0M9&ES<&]S:71I;VXG
M73L*("`@("`@("`@("`@)'!O<R`]('-T<G!O<R@D:&1R+"`G.R<I.PH@("`@
M("`@("`@("!I9B`H)'!O<R`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@
M("1H9'(@/2!S=6)S='(H)&AD<BP@,"P@)'!O<RD["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)&]B+3YD:7-P;W-I=&EO;B`]("1H9'(["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&]B+3YI9F1I<W!O<VET:6]N(#T@,#L*
M("`@("`@("!]"@H@("`@("`@("\J($-O;G1E;G0M240N("HO"B`@("`@("`@
M:68@*&ES<V5T*"1O8BT^:&5A9&5R<ULG8V]N=&5N="UI9"==*2D@>PH@("`@
M("`@("`@("`D;V(M/FEF:60@/2`Q.PH@("`@("`@("`@("`D;V(M/FED(#T@
M)&]B+3YH96%D97)S6R=C;VYT96YT+6ED)UT["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&]B+3YI9FED(#T@,#L*("`@("`@("!]"@H@("`@("`@
M("\J($=E="!F:6QE('-I>F4@*&EF("=B;V1Y)R!T97AT(&ES('-E="DN("HO
M"B`@("`@("`@:68@*&ES<V5T*"1O8BT^8F]D>2DI('L*("`@("`@("`@("`@
M)&]B+3YB>71E<R`]('-T<FQE;B@D;V(M/F)O9'DI.PH@("`@("`@('T*"B`@
M("`@("`@+RH@4')O8V5S<R!P87)T<R!A;'-O+B`J+PH@("`@("`@(&EF("AI
M<W-E="@D;V(M/G!A<G1S*2D@>PH@("`@("`@("`@("!F;W)E86-H("AA<G)A
M>5]K97ES*"1O8BT^<&%R=',I(&%S("1K97DI('L*("`@("`@("`@("`@("`@
M($U)345?4W1R=6-T=7)E.CI?8V]N=F5R=$UI;65$96-O9&5$871A*"1O8BT^
M<&%R='-;)&ME>5TI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@0G5I;&1S(&%N(&%R<F%Y(&-O;G-I<W1I;F<@;V8@
M34E-12!H96%D97(O=F%L=64@<&%I<G,N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D:&5A9&5R<R`@("`@02!T97AT('-T<FEN9R!C;VYT86EN:6YG
M('1H92!H96%D97)S("AE+F<N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!O=71P=70@9G)O;2!I;6%P7V9E=&-H:&5A9&5R*"DI+@H@("`@
M("H@0'!A<F%M(&)O;VQE86X@)&1E8V]D92`@("`@4VAO=6QD('1H92!H96%D
M97)S(&)E(&1E8V]D960_"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;&]W97)C
M87-E("!3:&]U;&0@=&AE(&ME>7,@8F4@:6X@;&]W97)C87-E/PH@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y(&-O;G-I<W1I;F<@;V8@
M=&AE(&AE861E<B!N86UE(&%S('1H92!K97D@86YD"B`@("`@*B`@("`@("`@
M("`@("`@("!T:&4@:&5A9&5R('9A;'5E(&%S('1H92!V86QU92X*("`@("`J
M("`@("`@("`@("`@("`@($$@:&5A9&5R('=I=&@@;75L=&EP;&4@96YT<FEE
M<R!W:6QL(&)E('-T;W)E9"!I;@H@("`@("H@("`@("`@("`@("`@("`@)W9A
M;'5E)R!A<R!A;B!A<G)A>2X*("`@("`J+PH@("`@9G5N8W1I;VX@<&%R<V5-
M24U%2&5A9&5R<R@D:&5A9&5R<RP@)&1E8V]D92`]('1R=64L("1L;W=E<F-A
M<V4@/2!F86QS92D*("`@('L*("`@("`@("`D:&5A9&5R(#T@)R<["B`@("`@
M("`@)&]B(#T@87)R87DH*3L*"B`@("`@("`@9F]R96%C:"`H97AP;&]D92@B
M7&XB+"`D:&5A9&5R<RD@87,@)'9A;"D@>PH@("`@("`@("`@("!I9B`H)&1E
M8V]D92D@>PH@("`@("`@("`@("`@("`@)'9A;"`]($U)344Z.F1E8V]D92@D
M=F%L*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H<')E9U]M871C
M:"@B+UXH6UY<<UTK*5PZ*"XJ*2\B+"`D=F%L+"`D;6%T8VAE<RDI('L*("`@
M("`@("`@("`@("`@("1V86P@/2!T<FEM*"1M871C:&5S6S)=*3L*("`@("`@
M("`@("`@("`@("1H96%D97(@/2`D;6%T8VAE<ULQ73L*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D;V);)&AE861E<ETI*2!["B`@("`@("`@("`@("`@
M("`@("`@:68@*"%I<U]A<G)A>2@D;V);)&AE861E<ETI*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1T96UP(#T@)&]B6R1H96%D97)=.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D;V);)&AE861E<ET@/2!A<G)A>2@I.PH@("`@
M("`@("`@("`@("`@("`@("`@("`D;V);)&AE861E<EU;72`]("1T96UP.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D;V);
M)&AE861E<EU;72`]("1V86P["B`@("`@("`@("`@("`@("`@("`@8V]N=&EN
M=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D=F%L(#T@)R`G("X@=')I;2@D=F%L*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@:68@*"%E;7!T>2@D:&5A9&5R*2D@>PH@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1O8ELD:&5A9&5R72DI('L*("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)&]B6R1H96%D97)=*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("!E;F0H)&]B6R1H96%D97)=*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&]B6R1H96%D97)=6VME>2@D;V);
M)&AE861E<ETI72`N/2`D=F%L.PH@("`@("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@("`@("1O8ELD:&5A9&5R72`N/2`D
M=F%L.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@)&]B6R1H96%D97)=(#T@)'9A
M;#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("@D;&]W97)C87-E*2`_(&%R<F%Y7V-H86YG95]K
M97E?8V%S92@D;V(L($-!4T5?3$]715(I(#H@)&]B.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O
M5FEE=V5R+G!H<```````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#,V,S`S(#$P-3$U-#,S-S,W(#`R,C`V,``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@5&AE($U)345?
M5FEE=V5R.CH@8VQA<W,@<')O=FED97,@86X@86)S=')A8W1E9"!I;G1E<F9A
M8V4@=&\*("H@<F5N9&5R(&]U="!-24U%('1Y<&5S(&EN=&\@2%1-3"!F;W)M
M870N("!)="!D97!E;F1S(&]N(&$*("H@<V5T(&]F($U)345?5FEE=V5R7RH@
M9')I=F5R<R!W:&EC:"!H86YD;&4@=&AE(&%C='5A;"!R96YD97)I;F<L"B`J
M(&%N9"!A;'-O(&$@8V]N9FEG=7)A=&EO;B!F:6QE('1O(&UA<"!-24U%('1Y
M<&5S('1O(&1R:79E<G,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(N<&AP+'8@,2XV-"XQ,"XQ,"`R,#`V+S`U+S`U(#`S.C,P
M.C(S('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!!
M;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("H*("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C
M;VEL+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO
M<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S<R!-24U%7U9I97=E<B!["@H@("`@
M+RHJ"B`@("`@*B!4:&4@34E-15]087)T(&]B:F5C="!T;R!R96YD97(N"B`@
M("`@*@H@("`@("H@0'9A<B!-24U%7U!A<G0*("`@("`J+PH@("`@=F%R("1M
M:6UE7W!A<G0["@H@("`@+RHJ"B`@("`@*B!#;VYF:6=U<F%T:6]N('!A<F%M
M971E<G,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)%]C;VYF(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(&=E=$1R:79E
M<B!C86-H92X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@
M('9A<B`D7V1R:79E<D-A8VAE(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J
M($9O<F-E('9I97=I;F<@;V8@82!P87)T(&EN;&EN92P@<F5G87)D;&5S<R!O
M9B!T:&4@0V]N=&5N="U$:7-P;W-I=&EO;@H@("`@("H@;V8@=&AE($U)344@
M4&%R="X*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@
M=F%R("1?9F]R8V5I;FQI;F4@/2!F86QS93L*"B`@("`O*BH*("`@("`J($%T
M=&5M<'1S('1O(')E='5R;B!A(&-O;F-R971E($U)345?5FEE=V5R7RH@;V)J
M96-T(&)A<V5D(&]N('1H90H@("`@("H@='EP92!O9B!-24U%7U!A<G0@<&%S
M<V5D(&]N=&\@:70N"B`@("`@*@H@("`@("H@0'!A<F%M($U)345?4&%R="`F
M)&UI;65?<&%R="`@4F5F97)E;F-E('1O(&$@34E-15]087)T(&]B:F5C="!W
M:71H('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:6YF;W)M871I;VX@=&\@8F4@<F5N9&5R960N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1M:6UE7W1Y<&4@("`@("!5<V4@=&AI<R!-24U%('1Y<&4@:6YS=&5A
M9"!O9B!T:&4@='EP90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<W1O<F5D(&EN('1H92`D;6EM95]P87)T+@H@("`@("H*("`@("`J
M($!R971U<FX@34E-15]6:65W97(@(%1H92!-24U%7U9I97=E<B!O8FIE8W0L
M(&]R(&9A;'-E(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9F%C
M=&]R>2@F)&UI;65?<&%R="P@)&UI;65?='EP92`](&YU;&PI"B`@("!["B`@
M("`@("`@+RH@0VAE8VL@=&AA="!W92!H879E(&$@=F%L:60@34E-15]087)T
M(&]B:F5C="`J+PH@("`@("`@(&EF("@A:7-?82@D;6EM95]P87)T+"`G34E-
M15]087)T)RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T*"B`@("`@("`@+RH@1&5T97)M:6YE(&1R:79E<B!T>7!E(&9R;VT@=&AE
M($U)344@='EP92`J+PH@("`@("`@(&EF("AE;7!T>2@D;6EM95]T>7!E*2D@
M>PH@("`@("`@("`@("`D;6EM95]T>7!E(#T@)&UI;65?<&%R="T^9V5T5'EP
M92@I.PH@("`@("`@("`@("!I9B`H96UP='DH)&UI;65?='EP92DI('L*("`@
M("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@)'9I97=E<B`](&9A;'-E.PH*("`@("`@("`O*B!3
M<&%W;B!T:&4@<F5L979A;G0@9')I=F5R+"!A;F0@<F5T=7)N(&ET("AO<B!F
M86QS92!O;B!F86EL=7)E*2`J+PH@("`@("`@(&EF("@H)&]B(#T@34E-15]6
M:65W97(Z.FEN8VQU9&5$<FEV97(H)&UI;65?='EP92DI*2!["B`@("`@("`@
M("`@("1C;&%S<R`]("@H)&]B+3YM;V1U;&4@/3T@)VAO<F1E)RD@/R`G)R`Z
M("1O8BT^;6]D=6QE("X@)U\G*2`N("=-24U%7U9I97=E<E\G("X@)&]B+3YD
M<FEV97(["B`@("`@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@
M>PH@("`@("`@("`@("`@("`@)'9I97=E<B`]("9N97<@)&-L87-S*"1M:6UE
M7W!A<G0L("1'3$]"04Q36R=M:6UE7V1R:79E<G,G75LD;V(M/FUO9'5L95U;
M)&]B+3YD<FEV97)=*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1V:65W97(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!);F-L
M=61E('1H92!C;V1E(&9O<B!T:&4@<F5L979A;G0@9')I=F5R+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&UI;65?='EP92`@5&AE($-O;G1E;G0M
M='EP92!O9B!T:&4@<&%R="!T;R!B92!R96YD97)E9"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T9$-L87-S("!3964@34E-15]$<FEV97(Z.F=E=$1R:79E
M<B@I+@H@("`@("HO"B`@("!F=6YC=&EO;B!I;F-L=61E1')I=F5R*"1M:6UE
M7W1Y<&4I"B`@("!["B`@("`@("`@+R\@5$]$3SH@0D,@+2!S=VET8V@@=&\@
M<F5Q=6ER95]O;F-E(&9O<B!(;W)D92`T+C`[(&1O;B=T(&YE960@)&-O;F9I
M9SL*("`@("`@("`O+R`@("`@("!D;VXG="!N965D('1O(&UA:V4@<W5R92!T
M:&4@,B!V87)I86)L97,@87)E('5N<V5T+@H@("`@("`@('-T871I8R`D8V]N
M9FEG(#T@9F%L<V4["B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@
M("`@)&%P<"`]("1R96=I<W1R>2T^9V5T07!P*"D["@H@("`@("`@(&EF("@A
M)&-O;F9I9RD@>PH@("`@("`@("`@("`D1TQ/0D%,4ULG;6EM95]D<FEV97)S
M)UT@/2`D1TQ/0D%,4ULG;6EM95]D<FEV97)S7VUA<"==(#T@87)R87DH*3L*
M("`@("`@("`@("`@<F5Q=6ER92`D<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G
M+"`G:&]R9&4G*2`N("<O8V]N9FEG+VUI;65?9')I=F5R<RYP:'`G.PH@("`@
M("`@("`@("!I9B`H)&%P<"`A/2`G:&]R9&4G*2!["B`@("`@("`@("`@("`@
M("`D8F%S92`]("1R96=I<W1R>2T^9V5T*"=F:6QE<F]O="<L("1A<'`I.PH@
M("`@("`@("`@("`@("`@:68@*&ES7W)E861A8FQE*"1B87-E("X@)R]C;VYF
M:6<O;6EM95]D<FEV97)S+G!H<"<I*2!["B`@("`@("`@("`@("`@("`@("`@
M<F5Q=6ER92`D8F%S92`N("<O8V]N9FEG+VUI;65?9')I=F5R<RYP:'`G.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1'
M3$]"04Q36R=M:6UE7V1R:79E<G,G72`]("1M:6UE7V1R:79E<G,["B`@("`@
M("`@("`@("1'3$]"04Q36R=M:6UE7V1R:79E<G-?;6%P)UT@/2`D;6EM95]D
M<FEV97)S7VUA<#L*("`@("`@("`@("`@)&-O;F9I9R`]('1R=64["B`@("`@
M("`@?0H*("`@("`@("`O*B!&:6=U<F4@=&AE(&-O<G)E8W0@9')I=F5R(&9O
M<B!T:&ES($U)344@='EP92X@268@=&AE<F4@:7,@;F\*("`@("`@("`@("!A
M<'!L:6-A=&EO;BUS<&5C:69I8R!M;V1U;&4L(&$@9V5N97)A;"!(;W)D92!O
M;F4@=VEL;"!A='1E;7!T('1O"B`@("`@("`@("`@8F4@=7-E9"X@*B\*("`@
M("`@("!I9B`H*"1O8B`]($U)345?5FEE=V5R.CIG971$<FEV97(H)&UI;65?
M='EP92P@)')E9VES=')Y+3YG971!<'`H*2DI*2!["B`@("`@("`@("`@("\J
M($EN8VQU9&4@=&AE(&-L87-S+B`J+PH@("`@("`@("`@("!R97%U:7)E7V]N
M8V4@34E-15]6:65W97(Z.G)E<V]L=F5$<FEV97(H)&]B+3YD<FEV97(L("1O
M8BT^;6]D=6QE*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;V(["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<B!F;W(@34E-15]6:65W
M97(*("`@("`J"B`@("`@*B!`<&%R86T@34E-15]087)T("8D;6EM95]P87)T
M("!2969E<F5N8V4@=&\@82!-24U%7U!A<G0@;V)J96-T('=I=&@@=&AE"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I;F9O<FUA=&EO
M;B!T;R!B92!R96YD97)E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@34E-15]6
M:65W97(H)B1M:6UE7W!A<G0L("1C;VYF(#T@87)R87DH*2D*("`@('L*("`@
M("`@("`D=&AI<RT^;6EM95]P87)T(#T@)B1M:6UE7W!A<G0["B`@("`@("`@
M)'1H:7,M/E]C;VYF(#T@)&-O;F8["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M971S('1H92!-24U%7U!A<G0@;V)J96-T(&9O<B!T:&4@8VQA<W,N"B`@("`@
M*@H@("`@("H@0'!A<F%M($U)345?4&%R="`F)&UI;65?<&%R="`@4F5F97)E
M;F-E('1O(&$@34E-15]087)T(&]B:F5C="!W:71H('1H90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:6YF;W)M871I;VX@=&\@8F4@
M<F5N9&5R960N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$U)345087)T*"8D
M;6EM95]P87)T*0H@("`@>PH@("`@("`@("1T:&ES+3YM:6UE7W!A<G0@/2`F
M)&UI;65?<&%R=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@
M34E-12!T>7!E(&]F('1H92!R96YD97)E9"!C;VYT96YT+B`@5&AI<R!C86X@
M8F4*("`@("`J(&]V97)R:61D96X@8GD@=&AE(&EN9&EV:61U86P@9')I=F5R
M<RP@9&5P96YD:6YG(&]N('=H870@9F]R;6%T"B`@("`@*B!T:&5Y(&]U='!U
M="!I;BX@0GD@9&5F875L="P@:70@<&%S<V5S('1H<F]U9V@@=&AE($U)344@
M='EP92!O9@H@("`@("H@=&AE(&]B:F5C="P@;W(@<F5P;&%C97,@8W5S=&]M
M(&5X=&5N<VEO;B!T>7!E<R!W:71H"B`@("`@*B`G=&5X="]P;&%I;B<@=&\@
M;&5T('1H92!B<F]W<V5R(&1O(&$@8F5S="UG=65S<R!R96YD97(N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@($U)344M='EP92!O9B!T:&4@;W5T
M<'5T(&-O;G1E;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@
M("`@>PH@("`@("`@(&EF("@D=&AI<RT^;6EM95]P87)T+3YG9710<FEM87)Y
M5'EP92@I(#T]("=X+65X=&5N<VEO;B<I('L*("`@("`@("`@("`@<F5T=7)N
M("=T97AT+W!L86EN)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/FUI;65?<&%R="T^9V5T5'EP92AT<G5E*3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(')E;F1E<F5D
M('9E<G-I;VX@;V8@=&AE(&]B:F5C="X*("`@("`J"B`@("`@*B!3:&]U;&0@
M8F4@;W9E<G)I9&1E;B!B>2!I;F1I=FED=6%L(&1R:79E<G,@=&\@<&5R9F]R
M;2!C=7-T;VT@=&%S:W,N"B`@("`@*B!4:&4@)&UI;65?<&%R="!C;&%S<R!V
M87)I86)L92!H87,@=&AE(&EN9F]R;6%T:6]N('1O(')E;F1E<BP*("`@("`J
M(&5N8V%P<W5L871E9"!I;B!A($U)345?4&%R="!O8FIE8W0N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&UI>&5D("1P87)A;7,@($%N>2!O<'1I;VYA;"!P87)A
M;65T97)S('1H:7,@9')I=F5R(&YE961S(&%T"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@<G5N=&EM92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@4F5N9&5R960@=F5R<VEO;B!O9B!T:&4@;V)J96-T+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!R96YD97(H)'!A<F%M<R`](&YU;&PI"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3YM:6UE7W!A<G0M/F=E=$-O;G1E;G1S*"D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&5X="]H=&UL(&]U='!U
M="!U<V5D(&%S(&%L=&5R;F%T:79E(&]U='!U="!W:&5N('1H92!F=6QL>0H@
M("`@("H@<F5N9&5R960@;V)J96-T(&-A;FYO="`H;W(@<VAO=6QD(&YO="D@
M8F4@9&ES<&QA>65D+B`@1F]R(&5X86UP;&4L"B`@("`@*B!T:&ES(&9U;F-T
M:6]N('-H;W5L9"!B92!U<V5D(&9O<B!-24U%(&%T=&%C:&UE;G1S('1H870@
M8V%N;F]T(&)E"B`@("`@*B!V:65W960@:6YL:6YE+"!W:&5R92!T:&4@=7-E
M<B!M87D@8F4@9VEV96X@;W!T:6]N<R!O;B!H;W<@=&\@=FEE=PH@("`@("H@
M=&AE(&%T=&%C:&UE;G0N"B`@("`@*B!3:&]U;&0@8F4@;W9E<G)I9&1E;B!B
M>2!I;F1I=FED=6%L(&1R:79E<G,@=&\@<&5R9F]R;2!C=7-T;VT@=&%S:W,N
M"B`@("`@*B!4:&4@)&UI;65?<&%R="!C;&%S<R!V87)I86)L92!H87,@=&AE
M(&EN9F]R;6%T:6]N('1O(')E;F1E<BP*("`@("`J(&5N8V%P<W5L871E9"!I
M;B!A($U)345?4&%R="!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI
M>&5D("1P87)A;7,@($%N>2!O<'1I;VYA;"!P87)A;65T97)S('1H:7,@9')I
M=F5R(&YE961S(&%T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<G5N
M=&EM92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&5X="]H=&UL
M(')E;F1E<F5D(&EN9F]R;6%T:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!R
M96YD97)!='1A8VAM96YT26YF;R@I"B`@("!["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#86X@=&AI<R!D<FEV97(@<F5N9&5R('1H92!T:&4@9&%T82!I;FQI
M;F4_"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H
M92!D<FEV97(@8V%N(&1I<W!L87D@:6YL:6YE+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!C86Y$:7-P;&%Y26YL:6YE*"D*("`@('L*("`@("`@("!I9B`H)'1H
M:7,M/F=E=$-O;F9I9U!A<F%M*"=I;FQI;F4G*2D@>PH@("`@("`@("`@("!R
M971U<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1VEV
M96X@82!D<FEV97(@86YD(&%N(&%P<&QI8V%T:6]N+"!T:&ES(')E='5R;G,@
M=&AE(&9U;&QY"B`@("`@*B!Q=6%L:69I960@9FEL97-Y<W1E;2!P871H('1O
M('1H92!D<FEV97(@<V]U<F-E(&9I;&4N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D9')I=F5R("!$<FEV97(@;F%M92X*("`@("`J($!P87)A;2!S
M=')I;F<@)&%P<"`@("`@07!P;&EC871I;VX@;F%M92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@1FEL97-Y<W1E;2!P871H(&]F('1H92!D<FEV
M97(O87!P;&EC871I;VX@<75E<FEE9"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<F5S;VQV941R:79E<B@D9')I=F5R(#T@)V1E9F%U;'0G+"`D87!P(#T@)VAO
M<F1E)RD*("`@('L*("`@("`@("!I9B`H)&%P<"`]/2`G:&]R9&4G*2!["B`@
M("`@("`@("`@(')E='5R;B!D:7)N86UE*%]?1DE,15]?*2`N("<O5FEE=V5R
M+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(')E='5R;B`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^87!P;&EC871I
M;VYS6R1A<'!=6R=F:6QE<F]O="==("X@)R]L:6(O34E-12]6:65W97(O)R`N
M("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@1VEV96X@86X@:6YP=70@34E-12!T>7!E(&%N9"!A(&UO9'5L92!N
M86UE+"!T:&ES(&9U;F-T:6]N"B`@("`@*B!R97-O;'9E<R!I="!I;G1O(&$@
M<W!E8VEF:6,@;W5T<'5T(&1R:79E<B!W:&EC:"!C86X@:&%N9&QE(&ET+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&UI;654>7!E("!-24U%('1Y
M<&4@=&\@<F5S;VQV92X*("`@("`J($!P87)A;2!S=')I;F<@)&UO9'5L92`@
M("!-;V1U;&4@:6X@=VAI8V@@=&\@<V5A<F-H(&9O<B!T:&4@9')I=F5R+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1D0VQA<W,@($]B:F5C="!W:71H('1H
M92!F;VQL;W=I;F<@:71E;7,Z"B`@("`@*B`\<')E/@H@("`@("H@)V1R:79E
M<B<@("TM("!.86UE(&]F(&1R:79E<B`H92YG+B`G96YS8W)I<'0G*0H@("`@
M("H@)V5X86-T)R`@("TM("!787,@=&AE(&1R:79E<B!A;F0@97AA8W0@;6%T
M8V@_("AT<G5E+V9A;'-E*0H@("`@("H@)VUO9'5L92<@("TM("!4:&4@;6]D
M=6QE(&-O;G1A:6YI;F<@9')I=F5R("AE+F<N("=H;W)D92<I"B`@("`@*B`\
M+W!R93X*("`@("`J(%)E='5R;G,@9F%L<V4@:68@9')I=F5R(&-O=6QD(&YO
M="!B92!F;W5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1')I=F5R*"1M
M:6UE5'EP92P@)&UO9'5L92`]("=H;W)D92<I"B`@("!["B`@("`@("`@9VQO
M8F%L("1M:6UE7V1R:79E<G,L("1M:6UE7V1R:79E<G-?;6%P.PH*("`@("`@
M("`D8V%C:&5.86UE(#T@)&UI;654>7!E("X@)WPG("X@)&UO9'5L93L*("`@
M("`@("!I9B`H:7-S970H)'1H:7,I("8F(&ES<V5T*"1T:&ES+3Y?9')I=F5R
M0V%C:&5;)&-A8VAE3F%M95TI*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7V1R:79E<D-A8VAE6R1C86-H94YA;65=.PH@("`@("`@('T*"B`@("`@
M("`@)&1R:79E<B`]("<G.PH@("`@("`@("1E>&%C=$1R:79E<B`](&9A;'-E
M.PH*("`@("`@("!L:7-T*"1P<FEM87)Y7W1Y<&4L("D@/2!E>'!L;V1E*"<O
M)RP@)&UI;654>7!E+"`R*3L*("`@("`@("`D86QL4W5B(#T@)'!R:6UA<GE?
M='EP92`N("<O*B<["@H@("`@("`@("\J($EF('1H92!M;V1U;&4@9&]E<VXG
M="!E>&ES="!I;B`D;6EM95]D<FEV97)S7VUA<"P@8VAE8VL@9F]R"B`@("`@
M("`@("`@2&]R9&4@=FEE=V5R<RX@*B\*("`@("`@("!I9B`H(6ES<V5T*"1M
M:6UE7V1R:79E<G-?;6%P6R1M;V1U;&5=*2`F)B`D;6]D=6QE("$]("=H;W)D
M92<I('L*("`@("`@("`@("`@<F5T=7)N($U)345?5FEE=V5R.CIG971$<FEV
M97(H)&UI;654>7!E+"`G:&]R9&4G*3L*("`@("`@("!]"@H@("`@("`@("1D
M<B`]("8D;6EM95]D<FEV97)S6R1M;V1U;&5=.PH@("`@("`@("1M87`@/2`F
M)&UI;65?9')I=F5R<U]M87!;)&UO9'5L95T["@H@("`@("`@("\J($EF(&%N
M(&]V97)R:61E(&5X:7-T<R!F;W(@=&AI<R!-24U%('1Y<&4L('1H96X@=7-E
M('1H870@*B\*("`@("`@("!I9B`H:7-S970H)&UA<%LG;W9E<G)I9&5S)UU;
M)&UI;654>7!E72DI('L*("`@("`@("`@("`@)&1R:79E<B`]("1M87!;)V]V
M97)R:61E<R==6R1M:6UE5'EP95T["B`@("`@("`@("`@("1E>&%C=$1R:79E
M<B`]('1R=64["B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1M87!;)V]V97)R
M:61E<R==6R1A;&Q3=6)=*2D@>PH@("`@("`@("`@("`D9')I=F5R(#T@)&UA
M<%LG;W9E<G)I9&5S)UU;)&%L;%-U8ET["B`@("`@("`@("`@("1E>&%C=$1R
M:79E<B`]('1R=64["B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1M87!;)W)E
M9VES=&5R960G72DI('L*("`@("`@("`@("`@+RH@271E<F%T92!T:')O=6=H
M('1H92!L:7-T(&]F(')E9VES=&5R960@9')I=F5R<RP@86YD('-E92!I9@H@
M("`@("`@("`@("`@("!T:&ES($U)344@='EP92!E>&ES=',@:6X@=&AE($U)
M344@='EP97,@=&AA="!T:&5Y(&-L86EM('1O"B`@("`@("`@("`@("`@(&AA
M;F1L92X@268@=&AE(&1R:79E<B!H86YD;&5S(&ET+"!T:&5N(&%S<VEG;B!I
M="!A<R!T:&4*("`@("`@("`@("`@("`@<F5N9&5R:6YG(&1R:79E<BX@268@
M=V4@9FEN9"!A(&=E;F5R:6,@:&%N9&QE<BP@:V5E<"!I=&5R871I;F<*("`@
M("`@("`@("`@("`@=&\@<V5E(&EF('=E(&-A;B!F:6YD(&$@<W!E8VEF:6,@
M:&%N9&QE<BX@*B\*("`@("`@("`@("`@9F]R96%C:"`H)&UA<%LG<F5G:7-T
M97)E9"==(&%S("1V86PI('L*("`@("`@("`@("`@("`@(&EF("AI;E]A<G)A
M>2@D;6EM951Y<&4L("1D<ELD=F%L75LG:&%N9&QE<R==*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1D<FEV97(@/2`D=F%L.PH@("`@("`@("`@("`@("`@
M("`@("1E>&%C=$1R:79E<B`]('1R=64["B`@("`@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H:6Y?87)R87DH)&%L
M;%-U8BP@)&1R6R1V86Q=6R=H86YD;&5S)UTI*2!["B`@("`@("`@("`@("`@
M("`@("`@)&1R:79E<B`]("1V86P["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J($EF('1H:7,@:7,@86X@
M87!P;&EC871I;VX@<W!E8VEF:6,@;6]D=6QE+"!A;F0@86X@97AA8W0@;6%T
M8V@@=V%S"B`@("`@("`@("`@;F]T(&9O=6YD+"!S96%R8V@@9F]R(&$@2&]R
M9&4M=VED92!S<&5C:69I8R!D<FEV97(N($]N;'D@=7-E('1H90H@("`@("`@
M("`@($AO<F1E+7-P96-I9FEC(&1R:79E<B!I9B!I="!I<R!.3U0@=&AE("=D
M969A=6QT)R!D<FEV97(@04Y$('1H90H@("`@("`@("`@($AO<F1E(&1R:79E
M<B!I<R!A;B!E>&%C="!M871C:"X@*B\*("`@("`@("!I9B`H(21E>&%C=$1R
M:79E<B`F)B`D;6]D=6QE("$]("=H;W)D92<I('L*("`@("`@("`@("`@)&]B
M(#T@34E-15]6:65W97(Z.F=E=$1R:79E<B@D;6EM951Y<&4L("=H;W)D92<I
M.PH@("`@("`@("`@("!I9B`H96UP='DH)&1R:79E<BD@?'P*("`@("`@("`@
M("`@("`@("@H)&]B+3YD<FEV97(@(3T@)V1E9F%U;'0G*2`F)B`D;V(M/F5X
M86-T*2D@>PH@("`@("`@("`@("`@("`@)&1R:79E<B`]("1O8BT^9')I=F5R
M.PH@("`@("`@("`@("`@("`@)&UO9'5L92`]("=H;W)D92<["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("\J($EF('1H92`G9&5F875L="<@
M9')I=F5R(&5X:7-T<R!I;B!T:&ES(&UO9'5L92P@9F%L;"!B86-K('1O('1H
M870N("HO"B`@("`@("`@:68@*&5M<'1Y*"1D<FEV97(I("8F"B`@("`@("`@
M("`@($!I<U]F:6QE*$U)345?5FEE=V5R.CIR97-O;'9E1')I=F5R*"=D969A
M=6QT)RP@)&UO9'5L92DI*2!["B`@("`@("`@("`@("1D<FEV97(@/2`G9&5F
M875L="<["B`@("`@("`@?0H*("`@("`@("!I9B`H96UP='DH)&1R:79E<BDI
M('L*("`@("`@("`@("`@)'1H:7,M/E]D<FEV97)#86-H95LD8V%C:&5.86UE
M72`](&9A;'-E.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&]B(#T@;F5W('-T9$-L87-S.PH@("`@
M("`@("`@("`D;V(M/F1R:79E<B`]("1D<FEV97(["B`@("`@("`@("`@("1O
M8BT^97AA8W0@(#T@)&5X86-T1')I=F5R.PH@("`@("`@("`@("`D;V(M/FUO
M9'5L92`]("1M;V1U;&4["B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RDI
M('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?9')I=F5R0V%C:&5;)&-A8VAE
M3F%M95T@/2`D;V(["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N
M("1O8CL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!':79E;B!A
M($U)344@='EP92P@=&AI<R!F=6YC=&EO;B!W:6QL(')E='5R;B!A;B!A<'!R
M;W!R:6%T90H@("`@("H@:6-O;BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1M:6UE5'EP92`@5&AE($U)344@='EP92!T:&%T('=E(&YE960@86X@
M:6-O;B!F;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!5
M4DP@=&\@=&AE(&%P<')O<')I871E(&EC;VXN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$EC;VXH)&UI;654>7!E*0H@("`@>PH@("`@("`@("1A<'`@/2`D
M1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T07!P*"D["B`@("`@("`@)&]B(#T@
M34E-15]6:65W97(Z.E]G971)8V]N*"1M:6UE5'EP92P@)&%P<"D["@H@("`@
M("`@(&EF("@D;V(@/3T](&YU;&PI('L*("`@("`@("`@("`@:68@*"1A<'`@
M(3T@)VAO<F1E)RD@>PH@("`@("`@("`@("`@("`@)&]B2&]R9&4@/2!-24U%
M7U9I97=E<CHZ7V=E=$EC;VXH)&UI;654>7!E+"`G:&]R9&4G*3L*("`@("`@
M("`@("`@("`@(')E='5R;B`H)&]B2&]R9&4@/3T](&YU;&PI(#\@;G5L;"`Z
M("1O8DAO<F1E+3YU<FP["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("`@("`@?0H@("`@("`@('T@
M96QS96EF("@H)&]B+3YM871C:"`A/3T@,"D@)B8@*"1A<'`@(3T@)VAO<F1E
M)RDI('L*("`@("`@("`@("`@)&]B2&]R9&4@/2!-24U%7U9I97=E<CHZ7V=E
M=$EC;VXH)&UI;654>7!E+"`G:&]R9&4G*3L*("`@("`@("`@("`@:68@*"1O
M8BT^;6%T8V@@(3T](&YU;&P@)B8@)&]B+3YM871C:"`\/2`D;V)(;W)D92T^
M;6%T8V@I('L*("`@("`@("`@("`@("`@(')E='5R;B`D;V(M/G5R;#L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B`D;V)(
M;W)D92T^=7)L.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<F5T=7)N("1O8BT^=7)L.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($=I=F5N(&%N(&EN<'5T($U)344@='EP92!A;F0@;6]D
M=6QE+"!T:&ES(&9U;F-T:6]N(')E='5R;G,@=&AE"B`@("`@*B!54DP@;V8@
M86X@:6-O;B!T:&%T(&-A;B!B92!A<W-O8VEA=&5D('=I=&@@:70*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1M:6UE5'EP92`@34E-12!T>7!E('1O(&=E="!T:&4@:6-O;B!F
M;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=&1#;&%S<R`@=7)L.B`@(%52
M3"!T;R!A;B!I8V]N+"!O<B!N=6QL(&EF(&YO;F4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("!C;W5L9"!B92!F;W5N9"X*("`@("`J("`@("`@
M("`@("`@("`@("`@(&5X86-T.B!(;W<@97AA8W0@=&AE(&UA=&-H(&ES+@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(#`@/3X@)V5X86-T)RP@
M,2`]/B`G<')I;6%R>2<L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@,B`]/B`G9')I=F5R)RP@,R`]/B`G9&5F875L="<*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("!O<B!N=6QL+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?9V5T26-O;B@D;6EM951Y<&4L("1M;V1U;&4@/2`G:&]R9&4G*0H@
M("`@>PH@("`@("`@(&=L;V)A;"`D;6EM95]D<FEV97)S.PH*("`@("`@("`D
M;V(@/2!-24U%7U9I97=E<CHZ9V5T1')I=F5R*"1M:6UE5'EP92P@)&UO9'5L
M92D["B`@("`@("`@:68@*"%I<U]O8FIE8W0H)&]B*2D@>PH@("`@("`@("`@
M("!R971U<FX@87)R87DH9F%L<V4L(&YU;&PI.PH@("`@("`@('T*("`@("`@
M("`D9')I=F5R(#T@)&]B+3YD<FEV97(["@H@("`@("`@(&QI<W0H)'!R:6UA
M<GE?='EP92PI(#T@97AP;&]D92@G+R<L("1M:6UE5'EP92P@,BD["B`@("`@
M("`@)&%L;%-U8B`]("1P<FEM87)Y7W1Y<&4@+B`G+RHG.PH@("`@("`@("1R
M971/8B`]("9N97<@<W1D0VQA<W,H*3L*("`@("`@("`D<F5T3V(M/FUA=&-H
M(#T@;G5L;#L*("`@("`@("`D<F5T3V(M/G5R;"`](&YU;&P["@H@("`@("`@
M("\J($EF('1H92!M;V1U;&4@9&]E<VXG="!E>&ES="!I;B`D;6EM95]D<FEV
M97)S+"!R971U<FX@;F]W+B`J+PH@("`@("`@(&EF("@A:7-S970H)&UI;65?
M9')I=F5R<ULD;6]D=6QE72DI('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P[
M"B`@("`@("`@?0H@("`@("`@("1D<B`]("8D;6EM95]D<FEV97)S6R1M;V1U
M;&5=.PH*("`@("`@("`O*B!)9B!A('-P96-I9FEC(&EC;VX@9F]R('1H:7,@
M9')I=F5R(&%N9"!M:6UE='EP92!I<R!D969I;F5D+`H@("`@("`@("`@('1H
M96X@=7-E('1H870N("HO"B`@("`@("`@:68@*&ES<V5T*"1D<ELD9')I=F5R
M75LG:6-O;G,G72DI('L*("`@("`@("`@("`@)&EC;VYD<B`]("8D;6EM95]D
M<FEV97)S6R1M;V1U;&5=6R1D<FEV97)=6R=I8V]N<R==.PH@("`@("`@("`@
M("`D:6-O;DQI<W0@/2!A<G)A>2@D;6EM951Y<&4@/3X@,"P@)&%L;%-U8B`]
M/B`Q+"`G9&5F875L="<@/3X@,BD["B`@("`@("`@("`@(&9O<F5A8V@@*"1I
M8V]N3&ES="!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D:6-O;F1R6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1R971/8BT^=7)L(#T@)&EC;VYD<ELD:V5Y73L*("`@("`@("`@("`@("`@
M("`@("`D<F5T3V(M/FUA=&-H(#T@)'9A;#L*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@+RH@5')Y('1O('5S92!A(&1E9F%U;'0@:6-O;B!I
M9B!N;VYE(&%L<F5A9'D@;V)T86EN960N("HO"B`@("`@("`@:68@*&ES7VYU
M;&PH)')E=$]B+3YU<FPI("8F(&ES<V5T*"1D<ELG9&5F875L="==*2D@>PH@
M("`@("`@("`@("`D9'(@/2`F)&UI;65?9')I=F5R<ULD;6]D=6QE75LG9&5F
M875L="==.PH@("`@("`@("`@("!I9B`H:7-S970H)&1R6R=I8V]N<R==6R=D
M969A=6QT)UTI*2!["B`@("`@("`@("`@("`@("`D<F5T3V(M/G5R;"`]("1D
M<ELG9&5F875L="==6R=I8V]N<R==6R=D969A=6QT)UT["B`@("`@("`@("`@
M("`@("`D<F5T3V(M/FUA=&-H(#T@,SL*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@:68@*"%I<U]N=6QL*"1R971/8BT^=7)L*2D@>PH@("`@
M("`@("`@("`D<F5T3V(M/G5R;"`]("1'3$]"04Q36R=R96=I<W1R>2==+3YG
M971);6%G941I<B@D;6]D=6QE*2`N("<O;6EM92\G("X@)')E=$]B+3YU<FP[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E=$]B.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8VAA<F%C=&5R('-E="!U<V5D(&9O
M<B!T:&4@5FEE=V5R+@H@("`@("H@4VAO=6QD(&)E(&]V97)R:61D96X@8GD@
M:6YD:79I9'5A;"!D<FEV97)S('1O('!E<F9O<FT@8W5S=&]M('1A<VMS+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8VAA<F%C=&5R('-E
M="!U<V5D(&)Y('1H:7,@5FEE=V5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971#:&%R<V5T*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/FUI;65?
M<&%R="T^9V5T0VAA<G-E="@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N(&$@8V]N9FEG=7)A=&EO;B!P87)A;65T97(@9F]R('1H92!C=7)R96YT
M('9I97=E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P87)A;2`@
M5&AE('!A<F%M971E<B!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@(%1H92!V86QU92!O9B!T:&4@<&%R86UE=&5R.R!R971U<FYS(&YU;&P@
M:68@=&AE('!A<F%M971E<@H@("`@("H@("`@("`@("`@("`@("`@9&]E<VXG
M="!E>&ES="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0V]N9FEG4&%R86TH
M)'!A<F%M*0H@("`@>PH@("`@("`@(')E='5R;B`H:7-S970H)'1H:7,M/E]C
M;VYF6R1P87)A;5TI*2`_("1T:&ES+3Y?8V]N9ELD<&%R86U=(#H@;G5L;#L*
M("`@('T*"B`@("`O*BH*("`@("`J(%-H;W5L9"!W92!F;W)C92!V:65W:6YG
M(&]F('1H:7,@34E-12!087)T(&EN;&EN92P@<F5G87)D;&5S<R!O9B!T:&4*
M("`@("`J($-O;G1E;G0M1&ES<&]S:71I;VX@;V8@=&AE($U)344@4&%R=#\*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@($9O<F-E('9I97=I;F<@
M:6YL:6YE/PH@("`@("HO"B`@("!F=6YC=&EO;B!F;W)C94EN;&EN959I97<H
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V9O<F-E:6YL:6YE.PH@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-
M24U%+TUE<W-A9V4N<&AP````````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`R-#(T,2`Q,#4Q-30S,S<S-R`P,C(R,#$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC
M92!D:7)N86UE*%]?1DE,15]?*2`N("<O4&%R="YP:'`G.PH*+RHJ"B`J(%1H
M92!-24U%7TUE<W-A9V4Z.B!C;&%S<R!P<F]V:61E<R!M971H;V1S(&9O<B!C
M<F5A=&EN9R!A;F0@;6%N:7!U;&%T:6YG"B`J($U)344@96UA:6P@;65S<V%G
M97,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<"QV(#$N-S8N,3`N,3(@,C`P-B\P,2\P,2`R,3HR.#HR-"!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H
M865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS
M;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!(;W)D
M92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?34E-10H@*B\*8VQA<W,@34E-15]-
M97-S86=E(&5X=&5N9',@34E-15]087)T('L*"B`@("`O*BH*("`@("`J($AA
M<R!T:&4@;65S<V%G92!B965N('!A<G-E9"!V:6$@8G5I;&1-97-S86=E*"D_
M"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D
M7V)U:6QD(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!4:&4@<V5R=F5R('1O
M(&1E9F%U;'0@=6YQ=6%L:69I960@861D<F5S<V5S('1O+@H@("`@("H*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V1E9F%U;'1397)V
M97(@/2!N=6QL.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(@+2!C<F5A
M=&5S(&$@;F5W($U)344@96UA:6P@;65S<V%G92X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1D969A=6QT4V5R=F5R("!4:&4@<V5R=F5R('1O(&1E
M9F%U;'0@=6YQ=6%L:69I960*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%D9')E<W-E<R!T;RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M34E-15]-97-S86=E*"1D969A=6QT4V5R=F5R(#T@;G5L;"D*("`@('L*("`@
M("`@("!I9B`H:7-?;G5L;"@D9&5F875L=%-E<G9E<BDI('L*("`@("`@("`@
M("`@)'1H:7,M/E]D969A=6QT4V5R=F5R(#T@)%]315)615);)U-%4E9%4E].
M04U%)UT["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]D
M969A=6QT4V5R=F5R(#T@)&1E9F%U;'1397)V97(["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@0W)E871E(&$@34E-15]-97-S86=E(&]B:F5C
M="!F<F]M(&$@34E-15]087)T(&]B:F5C="X*("`@("`J(%1H:7,@9G5N8W1I
M;VX@8V%N(&)E(&-A;&QE9"!S=&%T:6-A;&QY('9I83H*("`@("`J("`@($U)
M345?365S<V%G93HZ8V]N=F5R=$U)345087)T*"D["B`@("`@*@H@("`@("H@
M0'!A<F%M($U)345?4&%R="`F)&UI;65?<&%R="`@5&AE($U)345?4&%R="!O
M8FIE8W0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1S97)V97(@("`@("`@("!4
M:&4@<V5R=F5R('1O(&1E9F%U;'0@=6YQ=6%L:69I960*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%D9')E<W-E<R!T;RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N($U)345?365S<V%G92`@5&AE(&YE=R!-24U%7TUE
M<W-A9V4@;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO;B`F8V]N=F5R=$U)
M345087)T*"8D;6EM95]P87)T+"`D<V5R=F5R(#T@;G5L;"D*("`@('L*("`@
M("`@("!I9B`H(21M:6UE7W!A<G0M/F=E=$U)345)9"@I*2!["B`@("`@("`@
M("`@("1M:6UE7W!A<G0M/G-E=$U)345)9"@Q*3L*("`@("`@("!]"@H@("`@
M("`@("1M:6UE7VUE<W-A9V4@/2`F;F5W($U)345?365S<V%G92@D<V5R=F5R
M*3L*("`@("`@("`D;6EM95]M97-S86=E+3YA9&1087)T*"1M:6UE7W!A<G0I
M.PH@("`@("`@("1M:6UE7VUE<W-A9V4M/F)U:6QD365S<V%G92@I.PH*("`@
M("`@("!R971U<FX@)&UI;65?;65S<V%G93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%-E;F1S('1H:7,@;65S<V%G92X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1E;6%I;"`@("!4:&4@861D<F5S<R!L:7-T('1O('-E;F0@=&\N
M"B`@("`@*B!`<&%R86T@;6EX960@)B1H96%D97)S("!4:&4@34E-15](96%D
M97)S(&]B:F5C="!H;VQD:6YG('1H:7,@;65S<V%G92=S"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("!H96%D97)S+"!O<B!A(&AA<V@@=VET:"!H
M96%D97(M/G9A;'5E(&UA<'!I;F=S+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M9')I=F5R("`@5&AE($UA:6P@9')I=F5R('1O('5S92`H<VEN8V4@2&]R9&4@
M,RXP+C0I+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("`@06YY('!A
M<F%M971E<G,@;F5C97-S87)Y(&9O<B!T:&4@36%I;"!D<FEV97(*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("AS:6YC92!(;W)D92`S+C`N-"DN
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S
M+"!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!S
M96YD*"1E;6%I;"P@)B1H96%D97)S+"`D9')I=F5R(#T@;G5L;"P@)'!A<F%M
M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF.PH@("`@
M("`@('-T871I8R`D;6%I;&5R.PH*("`@("`@("!I9B`H(6ES<V5T*"1M86EL
M97(I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G36%I;"YP:'`G.PH@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1D<FEV97(I*2!["B`@("`@("`@("`@
M("`@("`D9')I=F5R(#T@)&-O;F9;)VUA:6QE<B==6R=T>7!E)UT["B`@("`@
M("`@("`@("`@("`D<&%R86US(#T@)&-O;F9;)VUA:6QE<B==6R=P87)A;7,G
M73L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D;6%I;&5R(#T@36%I;#HZ
M9F%C=&]R>2@D9')I=F5R+"`D<&%R86US*3L*("`@("`@("!]"@H@("`@("`@
M("1M<V<@/2`D=&AI<RT^=&]3=')I;F<H*3L*("`@("`@("!I9B`H:7-?;V)J
M96-T*"1H96%D97)S*2D@>PH@("`@("`@("`@("`D:&5A9&5R07)R87D@/2`D
M=&AI<RT^96YC;V1E*"1H96%D97)S+3YT;T%R<F%Y*"DL("1T:&ES+3YG971#
M:&%R<V5T*"DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1H96%D
M97)!<G)A>2`]("1T:&ES+3YE;F-O9&4H)&AE861E<G,L("1T:&ES+3YG971#
M:&%R<V5T*"DI.PH@("`@("`@('T*"B`@("`@("`@+RH@36%K92!S=7)E('1H
M92!M97-S86=E(&AA<R!A('1R86EL:6YG(&YE=VQI;F4N("HO"B`@("`@("`@
M:68@*'-U8G-T<B@D;7-G+"`M,2D@(3T@(EQN(BD@>PH@("`@("`@("`@("`D
M;7-G("X](")<;B(["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@)&UA
M:6QE<BT^<V5N9"A-24U%.CIE;F-O9&5!9&1R97-S*"1E;6%I;"DL("1H96%D
M97)!<G)A>2P@)&US9RD["@H@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=0
M14%27T5R<F]R)RD@)B8*("`@("`@("`@("`@)&-O;F9;)VUA:6QE<B==6R=T
M>7!E)UT@/3T@)W-E;F1M86EL)RD@>PH@("`@("`@("`@("`O+R!);G1E<G!R
M970@<F5T=7)N('9A;'5E<R!A<R!D969I;F5D(&EN("]U<W(O:6YC;'5D92]S
M>7-E>&ET<RYH"B`@("`@("`@("`@('-W:71C:"`H)')E<W5L="T^9V5T0V]D
M92@I*2!["B`@("`@("`@("`@(&-A<V4@-C0Z("\O($587U5304=%"B`@("`@
M("`@("`@("`@("`D97)R;W(@/2`G<V5N9&UA:6PZ("<@+B!?*")C;VUM86YD
M(&QI;F4@=7-A9V4@97)R;W(B*2`N("<@*#8T*2<["B`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@-C4Z("\O($587T1!5$%%4E(*
M("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@)R`N(%\H(F1A
M=&$@9F]R;6%T(&5R<F]R(BD@+B`G("@V-2DG.PH@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("!C87-E(#8V.B`O+R!%6%].3TE.4%54"B`@
M("`@("`@("`@("`@("`D97)R;W(@/2`G<V5N9&UA:6PZ("<@+B!?*")C86YN
M;W0@;W!E;B!I;G!U="(I("X@)R`H-C8I)SL*("`@("`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("`@("`@8V%S92`V-SH@+R\@15A?3D]54T52"B`@("`@
M("`@("`@("`@("`D97)R;W(@/2`G<V5N9&UA:6PZ("<@+B!?*")A9&1R97-S
M964@=6YK;F]W;B(I("X@)R`H-C<I)SL*("`@("`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("`@("`@8V%S92`V.#H@+R\@15A?3D](3U-4"B`@("`@("`@
M("`@("`@("`D97)R;W(@/2`G<V5N9&UA:6PZ("<@+B!?*")H;W-T(&YA;64@
M=6YK;F]W;B(I("X@)R`H-C@I)SL*("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@8V%S92`V.3H@+R\@15A?54Y!5D%)3$%"3$4*("`@("`@
M("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@)R`N(%\H(G-E<G9I8V4@
M=6YA=F%I;&%B;&4B*2`N("<@*#8Y*2<["B`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@(&-A<V4@-S`Z("\O($587U-/1E1705)%"B`@("`@
M("`@("`@("`@("`D97)R;W(@/2`G<V5N9&UA:6PZ("<@+B!?*")I;G1E<FYA
M;"!S;V9T=V%R92!E<G)O<B(I("X@)R`H-S`I)SL*("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@8V%S92`W,3H@+R\@15A?3U-%4E(*("`@
M("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@)R`N(%\H(G-Y<W1E
M;2!E<G)O<B(I("X@)R`H-S$I)SL*("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@8V%S92`W,CH@+R\@15A?3U-&24Q%"B`@("`@("`@("`@
M("`@("`D97)R;W(@/2`G<V5N9&UA:6PZ("<@+B!?*")C<FET:6-A;"!S>7-T
M96T@9FEL92!M:7-S:6YG(BD@+B`G("@W,BDG.PH@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("!C87-E(#<S.B`O+R!%6%]#04Y40U)%050*
M("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@)R`N(%\H(F-A
M;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B*2`N("<@*#<S*2<["B`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@-S0Z("\O($587TE/
M15)2"B`@("`@("`@("`@("`@("`D97)R;W(@/2`G<V5N9&UA:6PZ("<@+B!?
M*")I;G!U="]O=71P=70@97)R;W(B*2`N("<@*#<T*2<["B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@-S4Z("\O($587U1%35!&
M04E,"B`@("`@("`@("`@("`@("`D97)R;W(@/2`G<V5N9&UA:6PZ("<@+B!?
M*")T96UP;W)A<GD@9F%I;'5R92(I("X@)R`H-S4I)SL*("`@("`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`W-CH@+R\@15A?4%)/5$]#
M3TP*("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@)R`N(%\H
M(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(I("X@)R`H-S8I)SL*("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`W-SH@+R\@15A?
M3D]015)-"B`@("`@("`@("`@("`@("`D97)R;W(@/2`G<V5N9&UA:6PZ("<@
M+B!?*")P97)M:7-S:6]N(&1E;FEE9"(I("X@)R`H-S<I)SL*("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`W.#H@+R\@15A?0T].
M1DE'"B`@("`@("`@("`@("`@("`D97)R;W(@/2`G<V5N9&UA:6PZ("<@+B!?
M*")C;VYF:6=U<F%T:6]N(&5R<F]R(BD@+B`G("@W."DG.PH@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#<Y.B`O+R!%6%].3U1&
M3U5.1`H@("`@("`@("`@("`@("`@)&5R<F]R(#T@)W-E;F1M86EL.B`G("X@
M7R@B96YT<GD@;F]T(&9O=6YD(BD@+B`G("@W.2DG.PH@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@
M("`@)&5R<F]R(#T@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D97)R;W(I.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!486ME(&$@<V5T(&]F(&AE861E<G,@86YD(&UA:V4@<W5R92!T:&5Y(&%R
M92!E;F-O9&5D('!R;W!E<FQY+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A
M>2`D:&5A9&5R<R`@(%1H92!H96%D97)S('1O(&5N8V]D92X*("`@("`J($!P
M87)A;2!S=')I;F<@)&-H87)S970@(%1H92!C:&%R86-T97(@<V5T('1O('5S
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@87)R87D@;V8@
M96YC;V1E9"!H96%D97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!E;F-O9&4H
M)&AE861E<G,L("1C:&%R<V5T*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC
M92`G2&]R9&4O34E-12YP:'`G.PH*("`@("`@("`D861D<F5S<TME>7,@/2!A
M<G)A>2@G5&\G+"`G0V,G+"`G0F-C)RP@)T9R;VTG*3L*("`@("`@("!F;W)E
M86-H("@D:&5A9&5R<R!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@
M:68@*&EN7V%R<F%Y*"1K97DL("1A9&1R97-S2V5Y<RDI('L*("`@("`@("`@
M("`@("`@("1T97AT(#T@34E-13HZ96YC;V1E061D<F5S<R@D=F%L+"`D8VAA
M<G-E="P@)'1H:7,M/E]D969A=6QT4V5R=F5R*3L*("`@("`@("`@("`@("`@
M(&EF("AI<U]A*"1T97AT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("`@("`@)'1E>'0@/2`D=F%L.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1E>'0@/2!-24U%
M.CIE;F-O9&4H)'9A;"P@)&-H87)S970I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1H96%D97)S6R1K97E=(#T@34E-13HZ=W)A<$AE861E<G,H)&ME
M>2P@)'1E>'0L("1T:&ES+3YG971%3TPH*2D["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)&AE861E<G,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@
M=&AE('!R;W!E<B!S970@;V8@34E-12!H96%D97)S(&9O<B!T:&ES(&UE<W-A
M9V4@=&\@86X@87)R87DN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1H
M96%D97)S("!4:&4@:&5A9&5R<R!T;R!A9&0@=&AE($U)344@:&5A9&5R<R!T
M;RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@9G5L;"!S970@
M;V8@:&5A9&5R<R!I;F-L=61I;F<@34E-12!H96%D97)S+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!H96%D97(H)&AE861E<G,@/2!A<G)A>2@I*0H@("`@>PH@
M("`@("`@("\J(%!E<B!21D,@,C`T-2!;-%TL('1H:7,@35535"!A<'!E87(@
M:6X@=&AE(&UE<W-A9V4@:&5A9&5R<RX@*B\*("`@("`@("`D:&5A9&5R<ULG
M34E-12U697)S:6]N)UT@/2`G,2XP)SL*"B`@("`@("`@:68@*"1T:&ES+3Y?
M8G5I;&0I('L*("`@("`@("`@("`@<F5T=7)N('!A<F5N=#HZ:&5A9&5R*"1H
M96%D97)S*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^
M8G5I;&1-97-S86=E*"D["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^96YC
M;V1E*"1T:&ES+3YH96%D97(H)&AE861E<G,I+"`D=&AI<RT^9V5T0VAA<G-E
M="@I*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@
M=&AE(&5N=&ER92!M97-S86=E(&-O;G1E;G1S+"!I;F-L=61I;F<@:&5A9&5R
M<RP@87,@82!S=')I;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!E;F-O9&5D+"!G96YE<F%T960@;65S<V%G92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@=&]3=')I;F<H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^
M7V)U:6QD*2!["B`@("`@("`@("`@(')E='5R;B!P87)E;G0Z.G1O4W1R:6YG
M*&9A;'-E*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^
M8G5I;&1-97-S86=E*"D["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^=&]3
M=')I;F<H*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL
M9"!M97-S86=E(&9R;VT@8W5R<F5N="!C;VYT96YT<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@8G5I;&1-97-S86=E*"D*("`@('L*("`@("`@("!I9B`H)'1H
M:7,M/E]B=6EL9"D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*
M("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]F;&%G<ULG<V5T5'EP92==*2D@
M>PH@("`@("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/E]P87)T<RD@/B`Q*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T5'EP92@G;75L=&EP87)T+VUI
M>&5D)RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O
M*B!#;W!Y('1H92!I;F9O<FUA=&EO;B!F<F]M('1H92!S:6YG;&4@<&%R="!T
M;R!T:&4@8W5R<F5N=`H@("`@("`@("`@("`@("`@("`@8F%S92!P87)T+B`J
M+PH@("`@("`@("`@("`@("`@:68@*"@D;V)687)S(#T@9V5T7V]B:F5C=%]V
M87)S*')E<V5T*"1T:&ES+3Y?<&%R=',I*2DI('L*("`@("`@("`@("`@("`@
M("`@("!F;W)E86-H("@D;V)687)S(&%S("1K97D@/3X@)'9A;"D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^)&ME>2`]("1V86P["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("`O*B!3970@=&AE(&)U:6QD(&9L86<@
M;F]W+B`J+PH@("`@("`@("1T:&ES+3Y?8G5I;&0@/2!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1V5T(&$@;&ES="!O9B!A;&P@34E-12!S=6)P87)T
M<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!O9B!T
M:&4@34E-15]087)T('-U8G!A<G1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971087)T<R@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?8G5I;&0I('L*
M("`@("`@("`@("`@<F5T=7)N('!A<F5N=#HZ9V5T4&%R=',H*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^8G5I;&1-97-S86=E*"D[
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9V5T4&%R=',H*3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&)A<V4@<&%R
M="!O9B!T:&4@;65S<V%G92X@5&AI<R!F=6YC=&EO;B!D;V5S($Y/5`H@("`@
M("H@<F5T=7)N(&$@<F5F97)E;F-E('1O(&UA:V4@<W5R92!T:&%T('1H92!W
M:&]L92!-24U%7TUE<W-A9V4*("`@("`J(&]B:F5C="!I<VXG="!A8V-I9&5N
M=&%L;'D@;6]D:69I960N"B`@("`@*@H@("`@("H@0')E='5R;B!-24U%7TUE
M<W-A9V4@(%1H92!B87-E($U)345?4&%R="!O9B!T:&4@;65S<V%G92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T0F%S95!A<G0H*0H@("`@>PH@("`@("`@
M("1T:&ES+3YB=6EL9$UE<W-A9V4H*3L*("`@("`@("!R971U<FX@)'1H:7,[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V92!A('-P96-I9FEC($U)
M344@<&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE
M($U)345?4&%R="!)1"!S=')I;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!-
M24U%7U!A<G0@(%1H92!-24U%7U!A<G0@<F5Q=65S=&5D+"!O<B!F86QS92!I
M9B!T:&4@<&%R=`H@("`@("H@("`@("`@("`@("`@("`@("`@(&1O97-N)W0@
M97AI<W0N"B`@("`@*B\*("`@(&9U;F-T:6]N("9G971087)T*"1I9"D*("`@
M('L*("`@("`@("!I9B`H)'1H:7,M/E]B=6EL9"D@>PH@("`@("`@("`@("`D
M<&%R="`]('!A<F5N=#HZ9V5T4&%R="@D:60I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1T:&ES+3YB=6EL9$UE<W-A9V4H*3L*("`@("`@("`@
M("`@)'!A<G0@/2`D=&AI<RT^9V5T4&%R="@D:60I.PH@("`@("`@('T*("`@
M("`@("!I9B`H:7-?82@D<&%R="P@)TU)345?365S<V%G92<I*2!["B`@("`@
M("`@("`@("1N97=P87)T(#T@)FYE=R!-24U%7U!A<G0H*3L*("`@("`@("`@
M("`@)'-K:7`@/2!A<G)A>2@G7V)U:6QD)RP@)U]D969A=6QT4V5R=F5R)RD[
M"B`@("`@("`@("`@(&9O<F5A8V@@*&%R<F%Y7VME>7,H9V5T7V]B:F5C=%]V
M87)S*"1P87)T*2D@87,@)&ME>2D@>PH@("`@("`@("`@("`@("`@+RH@26=N
M;W)E(&QO8V%L('9A<FEA8FQE<R!T:&%T(&%R96XG="!A('!A<G0@;V8@=&AE
M(&]R:6=I;F%L"B`@("`@("`@("`@("`@("`@*B!C;&%S<RX@*B\*("`@("`@
M("`@("`@("`@(&EF("@A:6Y?87)R87DH)&ME>2P@)'-K:7`I*2!["B`@("`@
M("`@("`@("`@("`@("`@)&YE=W!A<G0M/B1K97D@/2`F)'!A<G0M/B1K97D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@
M<F5T=7)N("1N97=P87)T.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(')E='5R;B`D<&%R=#L*("`@("`@('T*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+TU)344O;6EM92YM87!P:6YG+G!H<```````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#4S,S0P(#$P-3$U-#,S-S,W(#`R,S(P,``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@5&AI<R!F:6QE(&-O;G1A:6YS(&$@;6%P<&EN9R!O9B!C;VUM
M;VX@9FEL92!E>'1E;G-I;VYS('1O"B`J($U)344@='EP97,N($ET(&AA<R!B
M965N(&%U=&]M871I8V%L;'D@9V5N97)A=&5D(&9R;VT@=&AE"B`J(&AO<F1E
M+W-C<FEP=',O;6EM95]M87!P:6YG(&1I<F5C=&]R>2X*("H*("H@04Q,(&-H
M86YG97,@<VAO=6QD(&)E(&UA9&4@=&\@:&]R9&4O<V-R:7!T<R]M:6UE7VUA
M<'!I;F<O;6EM92YT>7!E<RYH;W)D90H@*B!O<B!E;'-E('1H97D@=VEL;"!B
M92!L;W-T('=H96X@=&AI<R!F:6QE(&ES(')E9V5N97)A=&5D+@H@*@H@*B!!
M;GD@=6YK;F]W;B!F:6QE(&5X=&5N<VEO;G,@=VEL;"!A=71O;6%T:6-A;&QY
M(&)E(&UA<'!E9"!T;PH@*B`G>"UE>'1E;G-I;VXO/&5X=#XG('=H97)E(#QE
M>'0^(&ES('1H92!U;FMN;W=N(&9I;&4@97AT96YS:6]N+@H@*@H@*B!`<&%C
M:V%G92!(;W)D95]-24U%"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TU)344O
M34E-12]M:6UE+FUA<'!I;F<N<&AP+'8@,2XQ,2XR+C,@,C`P-B\P,B\Q,"`Q
M,#HS-SHS,R!J86X@17AP("0*("H*("H@1V5N97)A=&5D.B`P,B\Q,"\P-B`P
M,#HQ.#HT-2!B>2!S;'5S87)Z(&]N(&)I9W=O<FTN8W5R96-A;G1I+F]R9PH@
M*B\*)&UI;65?97AT96YS:6]N7VUA<"`](&%R<F%Y*`HG7U]-05A015))3T1?
M7R<@/3X@)S$G+`H@("`@)S-D<R<@("`@("`@("`@(#T^("=I;6%G92]X+3-D
M<R<L"B`@("`G0DQ%3D0G("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M8FQE
M;F1E<B<L"B`@("`G0R<@("`@("`@("`@("`@/3X@)W1E>'0O>"UC*RMS<F,G
M+`H@("`@)T-34TPG("`@("`@("`@(#T^("=T97AT+V-S<R<L"B`@("`G3E-6
M)R`@("`@("`@("`@/3X@)W9I9&5O+W@M;G-V)RP*("`@("=005(R)R`@("`@
M("`@("`]/B`G87!P;&EC871I;VXO>"UP87(R)RP*("`@("=832<@("`@("`@
M("`@("`]/B`G875D:6\O>"UM;V0G+`H@("`@)UHG("`@("`@("`@("`@(#T^
M("=A<'!L:6-A=&EO;B]X+6-O;7!R97-S)RP*("`@("=A)R`@("`@("`@("`@
M("`]/B`G87!P;&EC871I;VXO>"UA<F-H:79E)RP*("`@("=A8G<G("`@("`@
M("`@("`]/B`G87!P;&EC871I;VXO>"UA8FEW;W)D)RP*("`@("=A8G<N0U)!
M4TA%1"<@("`]/B`G87!P;&EC871I;VXO>"UA8FEW;W)D)RP*("`@("=A8G<N
M9WHG("`@("`@("`]/B`G87!P;&EC871I;VXO>"UA8FEW;W)D)RP*("`@("=A
M8S,G("`@("`@("`@("`]/B`G875D:6\O86,S)RP*("`@("=A9&(G("`@("`@
M("`@("`]/B`G=&5X="]X+6%D87-R8R<L"B`@("`G861S)R`@("`@("`@("`@
M/3X@)W1E>'0O>"UA9&%S<F,G+`H@("`@)V%F;2<@("`@("`@("`@(#T^("=A
M<'!L:6-A=&EO;B]X+69O;G0M869M)RP*("`@("=A9R<@("`@("`@("`@("`]
M/B`G:6UA9V4O>"UA<'!L:7@M9W)A<&AI8W,G+`H@("`@)V%I)R`@("`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]I;&QU<W1R871O<B<L"B`@("`G86EF)R`@
M("`@("`@("`@/3X@)V%U9&EO+W@M86EF9B<L"B`@("`G86EF8R<@("`@("`@
M("`@/3X@)V%U9&EO+W@M86EF9B<L"B`@("`G86EF9B<@("`@("`@("`@/3X@
M)V%U9&EO+W@M86EF9B<L"B`@("`G86PG("`@("`@("`@("`@/3X@)V%P<&QI
M8V%T:6]N+W@M<&5R;"<L"B`@("`G87)J)R`@("`@("`@("`@/3X@)V%P<&QI
M8V%T:6]N+W@M87)J)RP*("`@("=A<R<@("`@("`@("`@("`]/B`G87!P;&EC
M871I;VXO>"UA<'!L:7@M<W!R96%D<VAE970G+`H@("`@)V%S8R<@("`@("`@
M("`@(#T^("=T97AT+W!L86EN)RP*("`@("=A<V8G("`@("`@("`@("`]/B`G
M=FED96\O>"UM<RUA<V8G+`H@("`@)V%S<"<@("`@("`@("`@(#T^("=A<'!L
M:6-A=&EO;B]X+6%S<"<L"B`@("`G87-X)R`@("`@("`@("`@/3X@)W9I9&5O
M+W@M;7,M87-F)RP*("`@("=A=&]M)R`@("`@("`@("`]/B`G87!P;&EC871I
M;VXO871O;2MX;6PG+`H@("`@)V%U)R`@("`@("`@("`@(#T^("=A=61I;R]B
M87-I8R<L"B`@("`G879I)R`@("`@("`@("`@/3X@)W9I9&5O+W@M;7-V:61E
M;R<L"B`@("`G87<G("`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M87!P
M;&EX+7=O<F0G+`H@("`@)V)A:R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO
M;B]X+71R87-H)RP*("`@("=B8W!I;R<@("`@("`@("`]/B`G87!P;&EC871I
M;VXO>"UB8W!I;R<L"B`@("`G8F1F)R`@("`@("`@("`@/3X@)V%P<&QI8V%T
M:6]N+W@M9F]N="UB9&8G+`H@("`@)V)I8B<@("`@("`@("`@(#T^("=T97AT
M+W@M8FEB=&5X)RP*("`@("=B:6XG("`@("`@("`@("`]/B`G87!P;&EC871I
M;VXO;V-T970M<W1R96%M)RP*("`@("=B;&5N9"<@("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UB;&5N9&5R)RP*("`@("=B;&5N9&5R)R`@("`@("`]/B`G
M87!P;&EC871I;VXO>"UB;&5N9&5R)RP*("`@("=B;7`G("`@("`@("`@("`]
M/B`G:6UA9V4O8FUP)RP*("`@("=B>B<@("`@("`@("`@("`]/B`G87!P;&EC
M871I;VXO>"UB>FEP)RP*("`@("=B>C(G("`@("`@("`@("`]/B`G87!P;&EC
M871I;VXO>"UB>FEP)RP*("`@("=C)R`@("`@("`@("`@("`]/B`G=&5X="]X
M+6-S<F,G+`H@("`@)V,K*R<@("`@("`@("`@(#T^("=T97AT+W@M8RLK<W)C
M)RP*("`@("=C8R<@("`@("`@("`@("`]/B`G=&5X="]X+6,K*W-R8R<L"B`@
M("`G8V1F)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M;F5T8V1F)RP*
M("`@("=C9'(G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+F-O<F5L
M+61R87<G+`H@("`@)V-E<B<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X
M+7@U,#DM8V$M8V5R="<L"B`@("`G8V5R="<@("`@("`@("`@/3X@)V%P<&QI
M8V%T:6]N+W@M>#4P.2UC82UC97)T)RP*("`@("=C9VDG("`@("`@("`@("`]
M/B`G87!P;&EC871I;VXO>"UC9VDG+`H@("`@)V-G;2<@("`@("`@("`@(#T^
M("=I;6%G92]C9VTG+`H@("`@)V-H;2<@("`@("`@("`@(#T^("=A<'!L:6-A
M=&EO;B]X+6-H;2<L"B`@("`G8VAR="<@("`@("`@("`@/3X@)V%P<&QI8V%T
M:6]N+W@M:V-H87)T)RP*("`@("=C;&%S<R<@("`@("`@("`]/B`G87!P;&EC
M871I;VXO>"UJ879A)RP*("`@("=C;',G("`@("`@("`@("`]/B`G=&5X="]X
M+71E>"<L"B`@("`G8W!I;R<@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M
M8W!I;R<L"B`@("`G8W!I;RYG>B<@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M
M8W!I;RUC;VUP<F5S<V5D)RP*("`@("=C<'`G("`@("`@("`@("`]/B`G=&5X
M="]X+6,K*W-R8R<L"B`@("`G8W!T)R`@("`@("`@("`@/3X@)V%P<&QI8V%T
M:6]N+VUA8RUC;VUP86-T<')O)RP*("`@("=C<G0G("`@("`@("`@("`]/B`G
M87!P;&EC871I;VXO>"UX-3`Y+6-A+6-E<G0G+`H@("`@)V-S)R`@("`@("`@
M("`@(#T^("=T97AT+W@M8W-H87)P)RP*("`@("=C<V@G("`@("`@("`@("`]
M/B`G87!P;&EC871I;VXO>"UC<V@G+`H@("`@)V-S<R<@("`@("`@("`@(#T^
M("=T97AT+V-S<R<L"B`@("`G8W-V)R`@("`@("`@("`@/3X@)W1E>'0O>"UC
M;VUM82US97!A<F%T960M=F%L=65S)RP*("`@("=C=7(G("`@("`@("`@("`]
M/B`G:6UA9V4O>"UW:6XM8FET;6%P)RP*("`@("=C>'@G("`@("`@("`@("`]
M/B`G=&5X="]X+6,K*W-R8R<L"B`@("`G9"<@("`@("`@("`@("`@/3X@)W1E
M>'0O>"UD<W)C)RP*("`@("=D870G("`@("`@("`@("`]/B`G=FED96\O;7!E
M9R<L"B`@("`G9&)F)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M9&)A
M<V4G+`H@("`@)V1C)R`@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+61C
M+7)O;2<L"B`@("`G9&-L)R`@("`@("`@("`@/3X@)W1E>'0O>"UD8VPG+`H@
M("`@)V1C;2<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]D:6-O;2<L"B`@
M("`G9&-R)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M9&ER96-T;W(G
M+`H@("`@)V1E8B<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+61E8B<L
M"B`@("`G9&5R)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M>#4P.2UC
M82UC97)T)RP*("`@("=D97-K=&]P)R`@("`@("`]/B`G87!P;&EC871I;VXO
M>"UD97-K=&]P)RP*("`@("=D:6$G("`@("`@("`@("`]/B`G87!P;&EC871I
M;VXO>"UD:6$M9&EA9W)A;2<L"B`@("`G9&EF9B<@("`@("`@("`@/3X@)W1E
M>'0O>"UP871C:"<L"B`@("`G9&ER)R`@("`@("`@("`@/3X@)V%P<&QI8V%T
M:6]N+W@M9&ER96-T;W(G+`H@("`@)V1J=B<@("`@("`@("`@(#T^("=I;6%G
M92]V;F0N9&IV=2<L"B`@("`G9&IV=2<@("`@("`@("`@/3X@)VEM86=E+W9N
M9"YD:G9U)RP*("`@("=D;&PG("`@("`@("`@("`]/B`G87!P;&EC871I;VXO
M;V-T970M<W1R96%M)RP*("`@("=D;6<G("`@("`@("`@("`]/B`G87!P;&EC
M871I;VXO;V-T970M<W1R96%M)RP*("`@("=D;7,G("`@("`@("`@("`]/B`G
M87!P;&EC871I;VXO;V-T970M<W1R96%M)RP*("`@("=D;V,G("`@("`@("`@
M("`]/B`G87!P;&EC871I;VXO;7-W;W)D)RP*("`@("=D<VPG("`@("`@("`@
M("`]/B`G=&5X="]X+61S;"<L"B`@("`G9'1D)R`@("`@("`@("`@/3X@)W1E
M>'0O>"UD=&0G+`H@("`@)V1V:2<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO
M;B]X+61V:2<L"B`@("`G9'=G)R`@("`@("`@("`@/3X@)VEM86=E+W9N9"YD
M=V<G+`H@("`@)V1X9B<@("`@("`@("`@(#T^("=I;6%G92]V;F0N9'AF)RP*
M("`@("=D>'(G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UD:7)E8W1O
M<B<L"B`@("`G96=O;B<@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M96=O
M;B<L"B`@("`G96PG("`@("`@("`@("`@/3X@)W1E>'0O>"UE;6%C<RUL:7-P
M)RP*("`@("=E<',G("`@("`@("`@("`]/B`G:6UA9V4O>"UE<',G+`H@("`@
M)V5P<V8G("`@("`@("`@(#T^("=I;6%G92]X+65P<R<L"B`@("`G97!S:2<@
M("`@("`@("`@/3X@)VEM86=E+W@M97!S)RP*("`@("=E=&AE;64G("`@("`@
M("`]/B`G87!P;&EC871I;VXO>"UE+71H96UE)RP*("`@("=E='@G("`@("`@
M("`@("`]/B`G=&5X="]X+7-E=&5X="<L"B`@("`G97AE)R`@("`@("`@("`@
M/3X@)V%P<&QI8V%T:6]N+W@M;7,M9&]S+65X96-U=&%B;&4G+`H@("`@)V5Z
M)R`@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]A;F1R97<M:6YS970G+`H@
M("`@)V8G("`@("`@("`@("`@(#T^("=T97AT+W@M9F]R=')A;B<L"B`@("`G
M9FEG)R`@("`@("`@("`@/3X@)VEM86=E+W@M>&9I9R<L"B`@("`G9FET<R<@
M("`@("`@("`@/3X@)VEM86=E+W@M9FET<R<L"B`@("`G9FQA8R<@("`@("`@
M("`@/3X@)V%U9&EO+W@M9FQA8R<L"B`@("`G9FQC)R`@("`@("`@("`@/3X@
M)W9I9&5O+W@M9FQI8R<L"B`@("`G9FQI)R`@("`@("`@("`@/3X@)W9I9&5O
M+W@M9FQI8R<L"B`@("`G9FQW)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N
M+W@M:VEV:6\G+`H@("`@)V9O)R`@("`@("`@("`@(#T^("=T97AT+W@M>'-L
M9F\G+`H@("`@)V<S)R`@("`@("`@("`@(#T^("=I;6%G92]F87@M9S,G+`H@
M("`@)V=B)R`@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6=A;65B;WDM
M<F]M)RP*("`@("=G8W)D)R`@("`@("`@("`]/B`G=&5X="]D:7)E8W1O<GDG
M+`H@("`@)V=E;B<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6=E;F5S
M:7,M<F]M)RP*("`@("=G9R<@("`@("`@("`@("`]/B`G87!P;&EC871I;VXO
M>"US;7,M<F]M)RP*("`@("=G:68G("`@("`@("`@("`]/B`G:6UA9V4O9VEF
M)RP*("`@("=G;&%D92<@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UG;&%D
M92<L"B`@("`G9VUO)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M9V5T
M=&5X="UT<F%N<VQA=&EO;B<L"B`@("`G9VYC)R`@("`@("`@("`@/3X@)V%P
M<&QI8V%T:6]N+W@M9VYU8V%S:"<L"B`@("`G9VYU8V%S:"<@("`@("`@/3X@
M)V%P<&QI8V%T:6]N+W@M9VYU8V%S:"<L"B`@("`G9VYU;65R:6,G("`@("`@
M/3X@)V%P<&QI8V%T:6]N+W@M9VYU;65R:6,G+`H@("`@)V=R82<@("`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]X+6=R87!H:71E)RP*("`@("=G<F%M)R`@
M("`@("`@("`]/B`G87!P;&EC871I;VXO<W)G<R<L"B`@("`G9W)X;6PG("`@
M("`@("`@/3X@)V%P<&QI8V%T:6]N+W-R9W,K>&UL)RP*("`@("=G<V8G("`@
M("`@("`@("`]/B`G87!P;&EC871I;VXO>"UF;VYT+71Y<&4Q)RP*("`@("=G
M<VTG("`@("`@("`@("`]/B`G875D:6\O>"UG<VTG+`H@("`@)V=T87(G("`@
M("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6=T87(G+`H@("`@)V=Z)R`@("`@
M("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6=Z:7`G+`H@("`@)V@G("`@("`@
M("`@("`@(#T^("=T97AT+W@M8VAD<B<L"B`@("`G:"LK)R`@("`@("`@("`@
M/3X@)W1E>'0O>"UC:&1R)RP*("`@("=H9&8G("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UH9&8G+`H@("`@)VAH)R`@("`@("`@("`@(#T^("=T97AT
M+W@M8RLK:&1R)RP*("`@("=H<"<@("`@("`@("`@("`]/B`G=&5X="]X+6-H
M9'(G+`H@("`@)VAP9VPG("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N
M:'`M:'!G;"<L"B`@("`G:'%X)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N
M+VUA8RUB:6YH97@T,"<L"B`@("`G:',G("`@("`@("`@("`@/3X@)W1E>'0O
M>"UH87-K96QL)RP*("`@("=H=&TG("`@("`@("`@("`]/B`G=&5X="]H=&UL
M)RP*("`@("=H=&UL)R`@("`@("`@("`]/B`G=&5X="]H=&UL)RP*("`@("=I
M8V(G("`@("`@("`@("`]/B`G:6UA9V4O>"UI8V(G+`H@("`@)VEC92<@("`@
M("`@("`@(#T^("=X+6-O;F9E<F5N8V4O>"UC;V]L=&%L:R<L"B`@("`G:6-O
M)R`@("`@("`@("`@/3X@)VEM86=E+W@M:6-O)RP*("`@("=I8W,G("`@("`@
M("`@("`]/B`G=&5X="]C86QE;F1A<B<L"B`@("`G:61L)R`@("`@("`@("`@
M/3X@)W1E>'0O>"UI9&PG+`H@("`@)VEE9B<@("`@("`@("`@(#T^("=I;6%G
M92]I968G+`H@("`@)VEF8B<@("`@("`@("`@(#T^("=T97AT+V-A;&5N9&%R
M)RP*("`@("=I9F8G("`@("`@("`@("`]/B`G:6UA9V4O>"UI9F8G+`H@("`@
M)VEG97,G("`@("`@("`@(#T^("=M;V1E;"]I9V5S)RP*("`@("=I9W,G("`@
M("`@("`@("`]/B`G;6]D96PO:6=E<R<L"B`@("`G:6QB;2<@("`@("`@("`@
M/3X@)VEM86=E+W@M:6QB;2<L"B`@("`G:7-O)R`@("`@("`@("`@/3X@)V%P
M<&QI8V%T:6]N+W@M8V0M:6UA9V4G+`H@("`@)VET)R`@("`@("`@("`@(#T^
M("=A=61I;R]X+6ET)RP*("`@("=J87(G("`@("`@("`@("`]/B`G87!P;&EC
M871I;VXO>"UJ87(G+`H@("`@)VIA=F$G("`@("`@("`@(#T^("=T97AT+W@M
M:F%V82<L"B`@("`G:FYG)R`@("`@("`@("`@/3X@)VEM86=E+W@M:FYG)RP*
M("`@("=J;FQP)R`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UJ879A+6IN
M;'`M9FEL92<L"B`@("`G:G`R)R`@("`@("`@("`@/3X@)VEM86=E+VIP96<R
M,#`P)RP*("`@("=J<&<G("`@("`@("`@("`]/B`G:6UA9V4O:G!E9R<L"B`@
M("`G:G!E)R`@("`@("`@("`@/3X@)VEM86=E+VIP96<G+`H@("`@)VIP96<G
M("`@("`@("`@(#T^("=I;6%G92]J<&5G)RP*("`@("=J<'(G("`@("`@("`@
M("`]/B`G87!P;&EC871I;VXO>"UJ8G5I;&1E<BUP<F]J96-T)RP*("`@("=J
M<'@G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UJ8G5I;&1E<BUP<F]J
M96-T)RP*("`@("=J<R<@("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UJ
M879A<V-R:7!T)RP*("`@("=K87(G("`@("`@("`@("`]/B`G875D:6\O;6ED
M:2<L"B`@("`G:V%R8F]N)R`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M:V%R
M8F]N)RP*("`@("=K9&5L;FLG("`@("`@("`]/B`G87!P;&EC871I;VXO>"UD
M97-K=&]P)RP*("`@("=K9F\G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO
M>"UK9F]R;75L82<L"B`@("`G:VEL)R`@("`@("`@("`@/3X@)V%P<&QI8V%T
M:6]N+W@M:VEL;'5S=')A=&]R)RP*("`@("=K;VXG("`@("`@("`@("`]/B`G
M87!P;&EC871I;VXO>"UK;VYT;W5R)RP*("`@("=K<&TG("`@("`@("`@("`]
M/B`G87!P;&EC871I;VXO>"UK<&]V;6]D96QE<B<L"B`@("`G:W!R)R`@("`@
M("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M:W!R97-E;G1E<B<L"B`@("`G:W!T
M)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M:W!R97-E;G1E<B<L"B`@
M("`G:W)A)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M:W)I=&$G+`H@
M("`@)VMS<"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6MS<')E860G
M+`H@("`@)VMU9"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6MU9V%R
M)RP*("`@("=K=V0G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UK=V]R
M9"<L"B`@("`G:W=T)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M:W=O
M<F0G+`H@("`@)VQA)R`@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+7-H
M87)E9"UL:6)R87)Y+6QA)RP*("`@("=L871E>"<@("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UL871E>"<L"B`@("`G;&AA)R`@("`@("`@("`@/3X@)V%P
M<&QI8V%T:6]N+W@M;&AA)RP*("`@("=L:',G("`@("`@("`@("`]/B`G=&5X
M="]X+6QI=&5R871E+6AA<VME;&PG+`H@("`@)VQH>B<@("`@("`@("`@(#T^
M("=A<'!L:6-A=&EO;B]X+6QH>B<L"B`@("`G;&]G)R`@("`@("`@("`@/3X@
M)W1E>'0O>"UL;V<G+`H@("`@)VQT>"<@("`@("`@("`@(#T^("=T97AT+W@M
M=&5X)RP*("`@("=L=V\G("`@("`@("`@("`]/B`G:6UA9V4O>"UL=V\G+`H@
M("`@)VQW;V(G("`@("`@("`@(#T^("=I;6%G92]X+6QW;R<L"B`@("`G;'=S
M)R`@("`@("`@("`@/3X@)VEM86=E+W@M;'=S)RP*("`@("=L>7@G("`@("`@
M("`@("`]/B`G87!P;&EC871I;VXO>"UL>7@G+`H@("`@)VQZ:"<@("`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]X+6QH82<L"B`@("`G;'IO)R`@("`@("`@
M("`@/3X@)V%P<&QI8V%T:6]N+W@M;'IO<"<L"B`@("`G;2<@("`@("`@("`@
M("`@/3X@)W1E>'0O>"UO8FIC<W)C)RP*("`@("=M,34G("`@("`@("`@("`]
M/B`G875D:6\O>"UM;V0G+`H@("`@)VTS=2<@("`@("`@("`@(#T^("=A=61I
M;R]X+6UP96=U<FPG+`H@("`@)VTT82<@("`@("`@("`@(#T^("=A=61I;R]X
M+6TT82<L"B`@("`G;31U)R`@("`@("`@("`@/3X@)W9I9&5O+W9N9"YM<&5G
M=7)L)RP*("`@("=M86XG("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UT
M<F]F9BUM86XG+`H@("`@)VUA=&AM;"<@("`@("`@(#T^("=A<'!L:6-A=&EO
M;B]M871H;6PK>&UL)RP*("`@("=M9"<@("`@("`@("`@("`]/B`G87!P;&EC
M871I;VXO>"UG96YE<VES+7)O;2<L"B`@("`G;64G("`@("`@("`@("`@/3X@
M)W1E>'0O>"UT<F]F9BUM92<L"B`@("`G;65S:"<@("`@("`@("`@/3X@)VUO
M9&5L+VUE<V@G+`H@("`@)VUG<"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO
M;B]X+6UA9VEC<&]I;G0G+`H@("`@)VUI9"<@("`@("`@("`@(#T^("=A=61I
M;R]M:61I)RP*("`@("=M:61I)R`@("`@("`@("`]/B`G875D:6\O;6ED:2<L
M"B`@("`G;6EF)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M;6EF)RP*
M("`@("=M:W8G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UM871R;W-K
M82<L"B`@("`G;6TG("`@("`@("`@("`@/3X@)W1E>'0O>"UT<F]F9BUM;2<L
M"B`@("`G;6UL)R`@("`@("`@("`@/3X@)W1E>'0O;6%T:&UL)RP*("`@("=M
M;F<G("`@("`@("`@("`]/B`G=FED96\O>"UM;F<G+`H@("`@)VUO8R<@("`@
M("`@("`@(#T^("=T97AT+W@M;6]C)RP*("`@("=M;V0G("`@("`@("`@("`]
M/B`G875D:6\O>"UM;V0G+`H@("`@)VUO;W8G("`@("`@("`@(#T^("=V:61E
M;R]Q=6EC:W1I;64G+`H@("`@)VUO=B<@("`@("`@("`@(#T^("=V:61E;R]Q
M=6EC:W1I;64G+`H@("`@)VUO=FEE)R`@("`@("`@(#T^("=V:61E;R]X+7-G
M:2UM;W9I92<L"B`@("`G;7`R)R`@("`@("`@("`@/3X@)W9I9&5O+VUP96<G
M+`H@("`@)VUP,R<@("`@("`@("`@(#T^("=A=61I;R]M<&5G)RP*("`@("=M
M<&4G("`@("`@("`@("`]/B`G=FED96\O;7!E9R<L"B`@("`G;7!E9R<@("`@
M("`@("`@/3X@)W9I9&5O+VUP96<G+`H@("`@)VUP9R<@("`@("`@("`@(#T^
M("=V:61E;R]M<&5G)RP*("`@("=M<&=A)R`@("`@("`@("`]/B`G875D:6\O
M;7!E9R<L"B`@("`G;7,G("`@("`@("`@("`@/3X@)W1E>'0O>"UT<F]F9BUM
M<R<L"B`@("`G;7-H)R`@("`@("`@("`@/3X@)VUO9&5L+VUE<V@G+`H@("`@
M)VUS;V0G("`@("`@("`@(#T^("=I;6%G92]X+6US;V0G+`H@("`@)VUS>"<@
M("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6US>"UR;VTG+`H@("`@)VUT
M;2<@("`@("`@("`@(#T^("=A=61I;R]X+6UO9"<L"B`@("`G;7AU)R`@("`@
M("`@("`@/3X@)W9I9&5O+W9N9"YM<&5G=7)L)RP*("`@("=N-C0G("`@("`@
M("`@("`]/B`G87!P;&EC871I;VXO>"UN-C0M<F]M)RP*("`@("=N8B<@("`@
M("`@("`@("`]/B`G87!P;&EC871I;VXO;6%T:&5M871I8V$G+`H@("`@)VYC
M)R`@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6YE=&-D9B<L"B`@("`G
M;F5S)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M;F5S+7)O;2<L"B`@
M("`G;G-V)R`@("`@("`@("`@/3X@)W9I9&5O+W@M;G-V)RP*("`@("=O)R`@
M("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UO8FIE8W0G+`H@("`@)V]B
M:B<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+71G:68G+`H@("`@)V]D
M82<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]O9&$G+`H@("`@)V]D8B<@
M("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N;V%S:7,N;W!E;F1O8W5M
M96YT+F1A=&%B87-E)RP*("`@("=O9&,G("`@("`@("`@("`]/B`G87!P;&EC
M871I;VXO=FYD+F]A<VES+F]P96YD;V-U;65N="YC:&%R="<L"B`@("`G;V1F
M)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YO87-I<RYO<&5N9&]C
M=6UE;G0N9F]R;75L82<L"B`@("`G;V1G)R`@("`@("`@("`@/3X@)V%P<&QI
M8V%T:6]N+W9N9"YO87-I<RYO<&5N9&]C=6UE;G0N9W)A<&AI8W,G+`H@("`@
M)V]D:2<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N;V%S:7,N;W!E
M;F1O8W5M96YT+FEM86=E)RP*("`@("=O9&TG("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO=FYD+F]A<VES+F]P96YD;V-U;65N="YT97AT+6UA<W1E<B<L
M"B`@("`G;V1P)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YO87-I
M<RYO<&5N9&]C=6UE;G0N<')E<V5N=&%T:6]N)RP*("`@("=O9',G("`@("`@
M("`@("`]/B`G87!P;&EC871I;VXO=FYD+F]A<VES+F]P96YD;V-U;65N="YS
M<')E861S:&5E="<L"B`@("`G;V1T)R`@("`@("`@("`@/3X@)V%P<&QI8V%T
M:6]N+W9N9"YO87-I<RYO<&5N9&]C=6UE;G0N=&5X="<L"B`@("`G;V=G)R`@
M("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+V]G9R<L"B`@("`G;VQD)R`@("`@
M("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M=')A<V@G+`H@("`@)V]L96\G("`@
M("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6]L96\G+`H@("`@)V]O="<@("`@
M("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N;V%S:7,N;W!E;F1O8W5M96YT
M+G1E>'0G+`H@("`@)V]T9R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V
M;F0N;V%S:7,N;W!E;F1O8W5M96YT+F=R87!H:6-S+71E;7!L871E)RP*("`@
M("=O=&@G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+F]A<VES+F]P
M96YD;V-U;65N="YT97AT+7=E8B<L"B`@("`G;W1P)R`@("`@("`@("`@/3X@
M)V%P<&QI8V%T:6]N+W9N9"YO87-I<RYO<&5N9&]C=6UE;G0N<')E<V5N=&%T
M:6]N+71E;7!L871E)RP*("`@("=O=',G("`@("`@("`@("`]/B`G87!P;&EC
M871I;VXO=FYD+F]A<VES+F]P96YD;V-U;65N="YS<')E861S:&5E="UT96UP
M;&%T92<L"B`@("`G;W1T)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N
M9"YO87-I<RYO<&5N9&]C=6UE;G0N=&5X="UT96UP;&%T92<L"B`@("`G<"<@
M("`@("`@("`@("`@/3X@)W1E>'0O>"UP87-C86PG+`H@("`@)W`Q,B<@("`@
M("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+7!K8W,Q,B<L"B`@("`G<#=S)R`@
M("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W!K8W,W+7-I9VYA='5R92<L"B`@
M("`G<&%R,B<@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<&%R,B<L"B`@
M("`G<&%S)R`@("`@("`@("`@/3X@)W1E>'0O>"UP87-C86PG+`H@("`@)W!A
M=&-H)R`@("`@("`@(#T^("=T97AT+W@M<&%T8V@G+`H@("`@)W!B;2<@("`@
M("`@("`@(#T^("=I;6%G92]X+7!O<G1A8FQE+6)I=&UA<"<L"B`@("`G<&-D
M)R`@("`@("`@("`@/3X@)VEM86=E+W@M<&AO=&\M8V0G+`H@("`@)W!C9B<@
M("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+69O;G0M<&-F)RP*("`@("=P
M8V8N6B<@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UF;VYT+71Y<&4Q)RP*
M("`@("=P8VPG("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+FAP+7!C
M;"<L"B`@("`G<&1B)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YP
M86QM)RP*("`@("=P9&8G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO<&1F
M)RP*("`@("=P96TG("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UX-3`Y
M+6-A+6-E<G0G+`H@("`@)W!E<FPG("`@("`@("`@(#T^("=A<'!L:6-A=&EO
M;B]X+7!E<FPG+`H@("`@)W!F82<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO
M;B]X+69O;G0M='EP93$G+`H@("`@)W!F8B<@("`@("`@("`@(#T^("=A<'!L
M:6-A=&EO;B]X+69O;G0M='EP93$G+`H@("`@)W!F>"<@("`@("`@("`@(#T^
M("=A<'!L:6-A=&EO;B]X+7!K8W,Q,B<L"B`@("`G<&=M)R`@("`@("`@("`@
M/3X@)VEM86=E+W@M<&]R=&%B;&4M9W)A>6UA<"<L"B`@("`G<&=N)R`@("`@
M("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M8VAE<W,M<&=N)RP*("`@("=P9W`G
M("`@("`@("`@("`]/B`G87!P;&EC871I;VXO<&=P)RP*("`@("=P:'`G("`@
M("`@("`@("`]/B`G87!P;&EC871I;VXO>"UP:'`G+`H@("`@)W!H<#,G("`@
M("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+7!H<"<L"B`@("`G<&AP-"<@("`@
M("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<&AP)RP*("`@("=P:6-T)R`@("`@
M("`@("`]/B`G:6UA9V4O>"UP:6-T)RP*("`@("=P:6-T,2<@("`@("`@("`]
M/B`G:6UA9V4O>"UP:6-T)RP*("`@("=P:6-T,B<@("`@("`@("`]/B`G:6UA
M9V4O>"UP:6-T)RP*("`@("=P;"<@("`@("`@("`@("`]/B`G87!P;&EC871I
M;VXO>"UP97)L)RP*("`@("=P;',G("`@("`@("`@("`]/B`G875D:6\O>"US
M8W!L<R<L"B`@("`G<&TG("`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M
M<&5R;"<L"B`@("`G<&YG)R`@("`@("`@("`@/3X@)VEM86=E+W!N9R<L"B`@
M("`G<&YM)R`@("`@("`@("`@/3X@)VEM86=E+W@M<&]R=&%B;&4M86YY;6%P
M)RP*("`@("=P;R<@("`@("`@("`@("`]/B`G=&5X="]X+6=E='1E>'0M=')A
M;G-L871I;VXG+`H@("`@)W!O="<@("`@("`@("`@(#T^("=T97AT+W@M9V5T
M=&5X="UT<F%N<VQA=&EO;BUT96UP;&%T92<L"B`@("`G<'!M)R`@("`@("`@
M("`@/3X@)VEM86=E+W@M<&]R=&%B;&4M<&EX;6%P)RP*("`@("=P<',G("`@
M("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+FUS+7!O=V5R<&]I;G0G+`H@
M("`@)W!P="<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N;7,M<&]W
M97)P;VEN="<L"B`@("`G<'!Z)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N
M+W9N9"YM<RUP;W=E<G!O:6YT)RP*("`@("=P<R<@("`@("`@("`@("`]/B`G
M87!P;&EC871I;VXO<&]S='-C<FEP="<L"B`@("`G<',N9WHG("`@("`@("`@
M/3X@)V%P<&QI8V%T:6]N+W@M9WIP;W-T<V-R:7!T)RP*("`@("=P<V0G("`@
M("`@("`@("`]/B`G:6UA9V4O>"UP<V0G+`H@("`@)W!S9B<@("`@("`@("`@
M(#T^("=A<'!L:6-A=&EO;B]X+69O;G0M;&EN=7@M<'-F)RP*("`@("=P<VED
M)R`@("`@("`@("`]/B`G875D:6\O<')S+G-I9"<L"B`@("`G<'<G("`@("`@
M("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<'<G+`H@("`@)W!Y)R`@("`@("`@
M("`@(#T^("=T97AT+W@M<'ET:&]N)RP*("`@("=P>6,G("`@("`@("`@("`]
M/B`G87!P;&EC871I;VXO>"UP>71H;VXM8GET96-O9&4G+`H@("`@)W!Y;R<@
M("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+7!Y=&AO;BUB>71E8V]D92<L
M"B`@("`G<6EF)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<7<G+`H@
M("`@)W%T)R`@("`@("`@("`@(#T^("=V:61E;R]Q=6EC:W1I;64G+`H@("`@
M)W%T=G(G("`@("`@("`@(#T^("=V:61E;R]Q=6EC:W1I;64G+`H@("`@)W)A
M)R`@("`@("`@("`@(#T^("=A=61I;R]X+7!N+7)E86QA=61I;R<L"B`@("`G
M<F%M)R`@("`@("`@("`@/3X@)V%U9&EO+W@M<&XM<F5A;&%U9&EO)RP*("`@
M("=R87(G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UR87(G+`H@("`@
M)W)A<R<@("`@("`@("`@(#T^("=I;6%G92]X+6-M=2UR87-T97(G+`H@("`@
M)W)D9B<@("`@("`@("`@(#T^("=T97AT+W)D9B<L"B`@("`G<F5J)R`@("`@
M("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<F5J96-T)RP*("`@("=R9V(G("`@
M("`@("`@("`]/B`G:6UA9V4O>"UR9V(G+`H@("`@)W)L92<@("`@("`@("`@
M(#T^("=I;6%G92]R;&4G+`H@("`@)W)M)R`@("`@("`@("`@(#T^("=A=61I
M;R]X+7!N+7)E86QA=61I;R<L"B`@("`G<F]F9B<@("`@("`@("`@/3X@)V%P
M<&QI8V%T:6]N+W@M=')O9F8G+`H@("`@)W)P;2<@("`@("`@("`@(#T^("=A
M<'!L:6-A=&EO;B]X+7)P;2<L"B`@("`G<G-S)R`@("`@("`@("`@/3X@)W1E
M>'0O<G-S)RP*("`@("=R=&8G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO
M<G1F)RP*("`@("=R='@G("`@("`@("`@("`]/B`G=&5X="]R:6-H=&5X="<L
M"B`@("`G<S-M)R`@("`@("`@("`@/3X@)V%U9&EO+W@M<S-M)RP*("`@("=S
M86TG("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UA;6EP<F\G+`H@("`@
M)W-C;2<@("`@("`@("`@(#T^("=T97AT+W@M<V-H96UE)RP*("`@("=S9&$G
M("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+G-T87)D:79I<VEO;BYD
M<F%W)RP*("`@("=S9&,G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD
M+G-T87)D:79I<VEO;BYC86QC)RP*("`@("=S9&0G("`@("`@("`@("`]/B`G
M87!P;&EC871I;VXO=FYD+G-T87)D:79I<VEO;BYI;7!R97-S)RP*("`@("=S
M9'`G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+G-T87)D:79I<VEO
M;BYI;7!R97-S)RP*("`@("=S9',G("`@("`@("`@("`]/B`G87!P;&EC871I
M;VXO=FYD+G-T87)D:79I<VEO;BYC:&%R="<L"B`@("`G<V1W)R`@("`@("`@
M("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YS=&%R9&EV:7-I;VXN=W)I=&5R)RP*
M("`@("=S9VDG("`@("`@("`@("`]/B`G:6UA9V4O>"US9VDG+`H@("`@)W-G
M;"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N<W1A<F1I=FES:6]N
M+G=R:71E<B<L"B`@("`G<V=M)R`@("`@("`@("`@/3X@)W1E>'0O<V=M;"<L
M"B`@("`G<V=M;"<@("`@("`@("`@/3X@)W1E>'0O<V=M;"<L"B`@("`G<V@G
M("`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<VAE;&QS8W)I<'0G+`H@
M("`@)W-H87(G("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+7-H87(G+`H@
M("`@)W-H=&UL)R`@("`@("`@(#T^("=T97AT+VAT;6PG+`H@("`@)W-I86<G
M("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+7-I86<G+`H@("`@)W-I9"<@
M("`@("`@("`@(#T^("=A=61I;R]P<G,N<VED)RP*("`@("=S:6LG("`@("`@
M("`@("`]/B`G87!P;&EC871I;VXO>"UT<F%S:"<L"B`@("`G<VEL;R<@("`@
M("`@("`@/3X@)VUO9&5L+VUE<V@G+`H@("`@)W-I="<@("`@("`@("`@(#T^
M("=A<'!L:6-A=&EO;B]S='5F9FET)RP*("`@("=S:V0G("`@("`@("`@("`]
M/B`G87!P;&EC871I;VXO>"UK;V%N)RP*("`@("=S:VTG("`@("`@("`@("`]
M/B`G87!P;&EC871I;VXO>"UK;V%N)RP*("`@("=S:W`G("`@("`@("`@("`]
M/B`G87!P;&EC871I;VXO>"UK;V%N)RP*("`@("=S:W0G("`@("`@("`@("`]
M/B`G87!P;&EC871I;VXO>"UK;V%N)RP*("`@("=S;&LG("`@("`@("`@("`]
M/B`G=&5X="]S<')E861S:&5E="<L"B`@("`G<VUD)R`@("`@("`@("`@/3X@
M)V%P<&QI8V%T:6]N+W9N9"YS=&%R9&EV:7-I;VXN;6%I;"<L"B`@("`G<VUF
M)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YS=&%R9&EV:7-I;VXN
M;6%T:"<L"B`@("`G<VUI)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W-M
M:6PG+`H@("`@)W-M:6PG("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]S;6EL
M)RP*("`@("=S;6PG("`@("`@("`@("`]/B`G87!P;&EC871I;VXO<VUI;"<L
M"B`@("`G<VUS)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<VUS+7)O
M;2<L"B`@("`G<VYD)R`@("`@("`@("`@/3X@)V%U9&EO+V)A<VEC)RP*("`@
M("=S;R<@("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"US:&%R961L:6(G
M+`H@("`@)W-P9"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+69O;G0M
M<W!E961O)RP*("`@("=S<&PG("`@("`@("`@("`]/B`G87!P;&EC871I;VXO
M>"UF=71U<F5S<&QA<V@G+`H@("`@)W-Q;"<@("`@("`@("`@(#T^("=T97AT
M+W@M<W%L)RP*("`@("=S<F,G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO
M>"UW86ES+7-O=7)C92<L"B`@("`G<W1C)R`@("`@("`@("`@/3X@)V%P<&QI
M8V%T:6]N+W9N9"YS=6XN>&UL+F-A;&,N=&5M<&QA=&4G+`H@("`@)W-T9"<@
M("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N<W5N+GAM;"YD<F%W+G1E
M;7!L871E)RP*("`@("=S=&DG("`@("`@("`@("`]/B`G87!P;&EC871I;VXO
M=FYD+G-U;BYX;6PN:6UP<F5S<RYT96UP;&%T92<L"B`@("`G<W1M)R`@("`@
M("`@("`@/3X@)V%U9&EO+W@M<W1M)RP*("`@("=S='<G("`@("`@("`@("`]
M/B`G87!P;&EC871I;VXO=FYD+G-U;BYX;6PN=W)I=&5R+G1E;7!L871E)RP*
M("`@("=S='DG("`@("`@("`@("`]/B`G=&5X="]X+71E>"<L"B`@("`G<W5N
M)R`@("`@("`@("`@/3X@)VEM86=E+W@M<W5N+7)A<W1E<B<L"B`@("`G<W8T
M8W!I;R<@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<W8T8W!I;R<L"B`@("`G
M<W8T8W)C)R`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<W8T8W)C)RP*("`@
M("=S=F<G("`@("`@("`@("`]/B`G:6UA9V4O<W9G*WAM;"<L"B`@("`G<W=F
M)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<VAO8VMW879E+69L87-H
M)RP*("`@("=S>&,G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+G-U
M;BYX;6PN8V%L8R<L"B`@("`G<WAD)R`@("`@("`@("`@/3X@)V%P<&QI8V%T
M:6]N+W9N9"YS=6XN>&UL+F1R87<G+`H@("`@)W-X9R<@("`@("`@("`@(#T^
M("=A<'!L:6-A=&EO;B]V;F0N<W5N+GAM;"YW<FET97(N9VQO8F%L)RP*("`@
M("=S>&DG("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+G-U;BYX;6PN
M:6UP<F5S<R<L"B`@("`G<WAM)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N
M+W9N9"YS=6XN>&UL+FUA=&@G+`H@("`@)W-X=R<@("`@("`@("`@(#T^("=A
M<'!L:6-A=&EO;B]V;F0N<W5N+GAM;"YW<FET97(G+`H@("`@)W-Y;&LG("`@
M("`@("`@(#T^("=T97AT+W-P<F5A9'-H965T)RP*("`@("=T)R`@("`@("`@
M("`@("`]/B`G87!P;&EC871I;VXO>"UT<F]F9B<L"B`@("`G=&%R)R`@("`@
M("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M=&%R)RP*("`@("=T87(N6B<@("`@
M("`@("`]/B`G87!P;&EC871I;VXO>"UT87)Z)RP*("`@("=T87(N8GHG("`@
M("`@("`]/B`G87!P;&EC871I;VXO>"UB>FEP+6-O;7!R97-S960M=&%R)RP*
M("`@("=T87(N8GHR)R`@("`@("`]/B`G87!P;&EC871I;VXO>"UB>FEP+6-O
M;7!R97-S960M=&%R)RP*("`@("=T87(N9WHG("`@("`@("`]/B`G87!P;&EC
M871I;VXO>"UC;VUP<F5S<V5D+71A<B<L"B`@("`G=&%R+FQZ;R<@("`@("`@
M/3X@)V%P<&QI8V%T:6]N+W@M='IO)RP*("`@("=T8VPG("`@("`@("`@("`]
M/B`G=&5X="]X+71C;"<L"B`@("`G=&5X)R`@("`@("`@("`@/3X@)W1E>'0O
M>"UT97@G+`H@("`@)W1E>&DG("`@("`@("`@(#T^("=T97AT+W@M=&5X:6YF
M;R<L"B`@("`G=&5X:6YF;R<@("`@("`@/3X@)W1E>'0O>"UT97AI;F9O)RP*
M("`@("=T9V$G("`@("`@("`@("`]/B`G:6UA9V4O>"UT9V$G+`H@("`@)W1G
M>B<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6-O;7!R97-S960M=&%R
M)RP*("`@("=T:&5M92<@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UT:&5M
M92<L"B`@("`G=&EF)R`@("`@("`@("`@/3X@)VEM86=E+W1I9F8G+`H@("`@
M)W1I9F8G("`@("`@("`@(#T^("=I;6%G92]T:69F)RP*("`@("=T:R<@("`@
M("`@("`@("`]/B`G=&5X="]X+71C;"<L"B`@("`G=&]R<F5N="<@("`@("`@
M/3X@)V%P<&QI8V%T:6]N+W@M8FET=&]R<F5N="<L"B`@("`G='(G("`@("`@
M("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M=')O9F8G+`H@("`@)W1S)R`@("`@
M("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6QI;F=U:7-T)RP*("`@("=T<W8G
M("`@("`@("`@("`]/B`G=&5X="]T86(M<V5P87)A=&5D+79A;'5E<R<L"B`@
M("`G='1F)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M9F]N="UT=&8G
M+`H@("`@)W1X="<@("`@("`@("`@(#T^("=T97AT+W!L86EN)RP*("`@("=T
M>F\G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UT>F\G+`H@("`@)W5I
M)R`@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+61E<VEG;F5R)RP*("`@
M("=U:6PG("`@("`@("`@("`]/B`G=&5X="]X+75I;"<L"B`@("`G=6QT)R`@
M("`@("`@("`@/3X@)V%U9&EO+W@M;6]D)RP*("`@("=U;FDG("`@("`@("`@
M("`]/B`G875D:6\O>"UM;V0G+`H@("`@)W5R:2<@("`@("`@("`@(#T^("=T
M97AT+W@M=7)I)RP*("`@("=U<FPG("`@("`@("`@("`]/B`G=&5X="]X+75R
M:2<L"B`@("`G=7-T87(G("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M=7-T
M87(G+`H@("`@)W9C9"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6-D
M;&EN:R<L"B`@("`G=F-F)R`@("`@("`@("`@/3X@)W1E>'0O9&ER96-T;W)Y
M)RP*("`@("=V8W,G("`@("`@("`@("`]/B`G=&5X="]C86QE;F1A<B<L"B`@
M("`G=F-T)R`@("`@("`@("`@/3X@)W1E>'0O9&ER96-T;W)Y)RP*("`@("=V
M9F(G("`@("`@("`@("`]/B`G=&5X="]C86QE;F1A<B<L"B`@("`G=F]B)R`@
M("`@("`@("`@/3X@)W9I9&5O+VUP96<G+`H@("`@)W9O8R<@("`@("`@("`@
M(#T^("=A=61I;R]X+79O8R<L"B`@("`G=F]R)R`@("`@("`@("`@/3X@)V%P
M<&QI8V%T:6]N+W9N9"YS=&%R9&EV:7-I;VXN=W)I=&5R)RP*("`@("=V<FUL
M)R`@("`@("`@("`]/B`G;6]D96PO=G)M;"<L"B`@("`G=G-D)R`@("`@("`@
M("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YV:7-I;R<L"B`@("`G=GAM;"<@("`@
M("`@("`@/3X@)V%P<&QI8V%T:6]N+W9O:6-E>&UL*WAM;"<L"B`@("`G=V%V
M)R`@("`@("`@("`@/3X@)V%U9&EO+W@M=V%V)RP*("`@("=W87@G("`@("`@
M("`@("`]/B`G875D:6\O>"UM<RUW87@G+`H@("`@)W=B,2<@("`@("`@("`@
M(#T^("=A<'!L:6-A=&EO;B]X+7%U871T<F]P<F\G+`H@("`@)W=B,B<@("`@
M("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+7%U871T<F]P<F\G+`H@("`@)W=B
M,R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+7%U871T<F]P<F\G+`H@
M("`@)W=B;7`G("`@("`@("`@(#T^("=I;6%G92]V;F0N=V%P+G=B;7`G+`H@
M("`@)W=B>&UL)R`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N=V%P+G=B
M>&UL)RP*("`@("=W:S$G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD
M+FQO='5S+3$M,BTS)RP*("`@("=W:S,G("`@("`@("`@("`]/B`G87!P;&EC
M871I;VXO=FYD+FQO='5S+3$M,BTS)RP*("`@("=W:S0G("`@("`@("`@("`]
M/B`G87!P;&EC871I;VXO=FYD+FQO='5S+3$M,BTS)RP*("`@("=W:W,G("`@
M("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+FQO='5S+3$M,BTS)RP*("`@
M("=W;2<@("`@("`@("`@("`]/B`G=FED96\O>"UM<RUW;2<L"B`@("`G=VUA
M)R`@("`@("`@("`@/3X@)V%U9&EO+W@M;7,M=VUA)RP*("`@("=W;60G("`@
M("`@("`@("`]/B`G87!P;&EC871I;VXO>"UM<RUW;60G+`H@("`@)W=M9B<@
M("`@("`@("`@(#T^("=I;6%G92]X+7=M9B<L"B`@("`G=VUL)R`@("`@("`@
M("`@/3X@)W1E>'0O=FYD+G=A<"YW;6PG+`H@("`@)W=M;&,G("`@("`@("`@
M(#T^("=A<'!L:6-A=&EO;B]V;F0N=V%P+G=M;&,G+`H@("`@)W=M;',G("`@
M("`@("`@(#T^("=T97AT+W9N9"YW87`N=VUL<V-R:7!T)RP*("`@("=W;6QS
M8R<@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+G=A<"YW;6QS8W)I<'1C
M)RP*("`@("=W;78G("`@("`@("`@("`]/B`G=FED96\O>"UM<RUW;78G+`H@
M("`@)W=M>"<@("`@("`@("`@(#T^("=V:61E;R]X+6US+7=M>"<L"B`@("`G
M=VUZ)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M;7,M=VUZ)RP*("`@
M("=W<&0G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+G=O<F1P97)F
M96-T)RP*("`@("=W<&<G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UW
M<&<G+`H@("`@)W=R:2<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6US
M=W)I=&4G+`H@("`@)W=R;"<@("`@("`@("`@(#T^("=M;V1E;"]V<FUL)RP*
M("`@("=W=G@G("`@("`@("`@("`]/B`G=FED96\O>"UM<RUW=G@G+`H@("`@
M)WAA8R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6=N=6-A<V@G+`H@
M("`@)WAB96PG("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+7AB96PG+`H@
M("`@)WAB;2<@("`@("`@("`@(#T^("=I;6%G92]X+7AB:71M87`G+`H@("`@
M)WAC9B<@("`@("`@("`@(#T^("=I;6%G92]X+7AC9B<L"B`@("`G>&-F+F)Z
M,B<@("`@("`@/3X@)VEM86=E+W@M8V]M<')E<W-E9"UX8V8G+`H@("`@)WAC
M9BYG>B<@("`@("`@(#T^("=I;6%G92]X+6-O;7!R97-S960M>&-F)RP*("`@
M("=X:'0G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>&AT;6PK>&UL)RP*
M("`@("=X:'1M;"<@("`@("`@("`]/B`G87!P;&EC871I;VXO>&AT;6PK>&UL
M)RP*("`@("=X:2<@("`@("`@("`@("`]/B`G875D:6\O>"UX:2<L"B`@("`G
M>&QA)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YM<RUE>&-E;"<L
M"B`@("`G>&QC)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YM<RUE
M>&-E;"<L"B`@("`G>&QD)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N
M9"YM<RUE>&-E;"<L"B`@("`G>&QL)R`@("`@("`@("`@/3X@)V%P<&QI8V%T
M:6]N+W9N9"YM<RUE>&-E;"<L"B`@("`G>&QM)R`@("`@("`@("`@/3X@)V%P
M<&QI8V%T:6]N+W9N9"YM<RUE>&-E;"<L"B`@("`G>&QS)R`@("`@("`@("`@
M/3X@)V%P<&QI8V%T:6]N+W9N9"YM<RUE>&-E;"<L"B`@("`G>&QT)R`@("`@
M("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YM<RUE>&-E;"<L"B`@("`G>&QW
M)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YM<RUE>&-E;"<L"B`@
M("`G>&TG("`@("`@("`@("`@/3X@)V%U9&EO+W@M>&TG+`H@("`@)WAM:2<@
M("`@("`@("`@(#T^("=T97AT+W@M>&UI)RP*("`@("=X;6PG("`@("`@("`@
M("`]/B`G=&5X="]X;6PG+`H@("`@)WAP;2<@("`@("`@("`@(#T^("=I;6%G
M92]X+7AP:7AM87`G+`H@("`@)WAS;"<@("`@("`@("`@(#T^("=T97AT+W@M
M>'-L="<L"B`@("`G>'-L9F\G("`@("`@("`@/3X@)W1E>'0O>"UX<VQF;R<L
M"B`@("`G>'-L="<@("`@("`@("`@/3X@)W1E>'0O>"UX<VQT)RP*("`@("=X
M=6PG("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+FUO>FEL;&$N>'5L
M*WAM;"<L"B`@("`G>'=D)R`@("`@("`@("`@/3X@)VEM86=E+W@M>'=I;F1O
M=V1U;7`G+`H@("`@)WAY>B<@("`@("`@("`@(#T^("=C:&5M:6-A;"]X+7AY
M>B<L"B`@("`G>F%B=R<@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M86)I
M=V]R9"<L"B`@("`G>FEP)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+WII
M<"<L"B`@("`G>F]O)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M>F]O
M)RP*("`@("<Q,C,G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+FQO
M='5S+3$M,BTS)RP*("`@("<V-CDG("`@("`@("`@("`]/B`G875D:6\O>"UM
M;V0G"BD[````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+TU)344O;6EM92YM86=I8RYP:'``````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#8W-#,U(#$P-3$U-#,S-S,W(#`R,C8S-P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@1&%T82!F:6QE('5S960@8GD@34E-15]-86=I8SHZ+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)344O;6EM92YM86=I8RYP:'`L
M=B`Q+C4@,C`P-"\P,R\R,"`R,CHT-3HS-R!J86X@17AP("0*("H*("H@0'!A
M8VMA9V4@2&]R9&5?34E-10H@*B\*)&UI;65?;6%G:6-;,%U;,S!=6R)<,30U
M7#$V-EPQ-#%<,34T7#0P7#0R7#$T-5PQ-S!<,30U7#$T,UPT,%PU-UPQ-C5<
M,38S7#$V,EPU-UPQ-31<,34W7#$T,UPQ-#%<,34T7#4W7#$T,EPQ-3%<,34V
M7#4W7#$V,%PQ-#5<,38R7#$U-")=(#T@)V%P<&QI8V%T:6]N+W@M<&5R;"<[
M"B1M:6UE7VUA9VEC6S!=6S(T75LB7#$T-5PQ-C9<,30Q7#$U-%PT,%PT,EPQ
M-#5<,3<P7#$T-5PQ-#-<-#!<-3=<,38U7#$V,UPQ-C)<-3=<,30R7#$U,5PQ
M-39<-3=<,38P7#$T-5PQ-C)<,34T(ET@/2`G87!P;&EC871I;VXO>"UP97)L
M)SL*)&UI;65?;6%G:6-;,%U;,C-=6R)<,3`S7#$U-UPQ-35<,34U7#$U-UPQ
M-39<-#!<,38S7#$V-5PQ-#)<,30T7#$U,5PQ-C)<,30U7#$T,UPQ-C1<,34W
M7#$V,EPQ-3%<,30U7#$V,UPW,EPT,")=(#T@)W1E>'0O>"UP871C:"<["B1M
M:6UE7VUA9VEC6S!=6S(S75LB7#<U7#<T7#$U-%PQ-3%<,38S7#$V-%PW-EPQ
M-39<-S1<,38P7#$V,EPQ-3=<,38T7#$U-UPQ-#-<,34W7#$U-%PT,%PQ-#)<
M,30R7#$U-EPU-5PQ-34B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?
M;6%G:6-;,%U;,C)=6R)<,3`Q7#$Q-5PQ,#%<,3$V7#$P-%PQ,#%<-S)<-#!<
M,3(T7#$P,5PQ,C!<,3`U7#$R,UPQ,C1<,3`Q7#$R,EPQ,C1<-#!<,3`T7#$P
M,5PQ,C1<,3`U(ET@/2`G87!P;&EC871I;VXO>"UA;6%N9&$M:&5A9&5R)SL*
M)&UI;65?;6%G:6-;,%U;,C)=6R)<,3`W7#$P-EPV,5PQ,C!<,3`Q7#$R-%PQ
M,#-<,3$P7#8Q7#8P7#8P7#8P7#$Q,5PQ,#1<-#-<-C!<-C!<-C!<-C!<-C!<
M-C)<-C`B72`]("=A=61I;R]X+6=U<RUP871C:"<["B1M:6UE7VUA9VEC6S!=
M6S(R75LB7#$P-UPQ,#9<-C%<,3(P7#$P,5PQ,C1<,3`S7#$Q,%PV,5PV,5PV
M,%PV,%PQ,3%<,3`T7#0S7#8P7#8P7#8P7#8P7#8P7#8R7#8P(ET@/2`G875D
M:6\O>"UG=7,M<&%T8V@G.PHD;6EM95]M86=I8ULP75LR,EU;(EPT,UPT,5PQ
M,5PU-UPQ-C5<,38S7#$V,EPU-UPQ-31<,34W7#$T,UPQ-#%<,34T7#4W7#$T
M,EPQ-3%<,34V7#4W7#$T,EPQ-#%<,38S7#$U,")=(#T@)V%P<&QI8V%T:6]N
M+W@M<V@G.PHD;6EM95]M86=I8ULP75LR,EU;(EPT,UPT,5PQ,5PU-UPQ-C5<
M,38S7#$V,EPU-UPQ-31<,34W7#$T,UPQ-#%<,34T7#4W7#$T,EPQ-3%<,34V
M7#4W7#$T-UPQ-#%<,38W7#$U,R)=(#T@)V%P<&QI8V%T:6]N+W@M87=K)SL*
M)&UI;65?;6%G:6-;,%U;,C)=6R)<-#-<-#%<,3%<-3=<,38U7#$V,UPQ-C)<
M-3=<,34T7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ-#)<,34Q7#$U-EPU-UPQ-39<
M,30Q7#$V-UPQ-3,B72`]("=A<'!L:6-A=&EO;B]X+6%W:R<["B1M:6UE7VUA
M9VEC6S!=6S(R75LB7#0S7#0Q7#$Q7#4W7#$V-5PQ-C-<,38R7#4W7#$U-%PQ
M-3=<,30S7#$T,5PQ-31<-3=<,30R7#$U,5PQ-39<-3=<,38P7#$T-5PQ-C)<
M,34T(ET@/2`G87!P;&EC871I;VXO>"UP97)L)SL*)&UI;65?;6%G:6-;,%U;
M,C)=6R)<-#-<-#%<,3%<-3=<,38U7#$V,UPQ-C)<-3=<,34T7#$U-UPQ-#-<
M,30Q7#$U-%PU-UPQ-#)<,34Q7#$U-EPU-UPQ-C1<,30S7#$V,UPQ-3`B72`]
M("=A<'!L:6-A=&EO;B]X+6-S:"<["B1M:6UE7VUA9VEC6S!=6S(R75LB7#0S
M7#0Q7#0P7#4W7#$V-5PQ-C-<,38R7#4W7#$U-%PQ-3=<,30S7#$T,5PQ-31<
M-3=<,30R7#$U,5PQ-39<-3=<,30R7#$T,5PQ-C-<,34P(ET@/2`G87!P;&EC
M871I;VXO>"US:"<["B1M:6UE7VUA9VEC6S!=6S(R75LB7#0S7#0Q7#0P7#4W
M7#$V-5PQ-C-<,38R7#4W7#$U-%PQ-3=<,30S7#$T,5PQ-31<-3=<,30R7#$U
M,5PQ-39<-3=<,30W7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC871I;VXO>"UA
M=VLG.PHD;6EM95]M86=I8ULP75LR,EU;(EPT,UPT,5PT,%PU-UPQ-C5<,38S
M7#$V,EPU-UPQ-31<,34W7#$T,UPQ-#%<,34T7#4W7#$T,EPQ-3%<,34V7#4W
M7#$U-EPQ-#%<,38W7#$U,R)=(#T@)V%P<&QI8V%T:6]N+W@M87=K)SL*)&UI
M;65?;6%G:6-;,%U;,C)=6R)<-#-<-#%<-#!<-3=<,38U7#$V,UPQ-C)<-3=<
M,34T7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ-#)<,34Q7#$U-EPU-UPQ-C!<,30U
M7#$V,EPQ-30B72`]("=A<'!L:6-A=&EO;B]X+7!E<FPG.PHD;6EM95]M86=I
M8ULP75LR,EU;(EPT,UPT,5PT,%PU-UPQ-C5<,38S7#$V,EPU-UPQ-31<,34W
M7#$T,UPQ-#%<,34T7#4W7#$T,EPQ-3%<,34V7#4W7#$V-%PQ-#-<,38S7#$U
M,")=(#T@)V%P<&QI8V%T:6]N+W@M8W-H)SL*)&UI;65?;6%G:6-;,%U;,C%=
M6R)<-#-<-#%<,3%<-3=<,38U7#$V,UPQ-C)<-3=<,34T7#$U-UPQ-#-<,30Q
M7#$U-%PU-UPQ-#)<,34Q7#$U-EPU-UPQ-#%<,38S7#$U,")=(#T@)V%P<&QI
M8V%T:6]N+W@M>G-H)SL*)&UI;65?;6%G:6-;,%U;,C%=6R)<-#-<-#%<,3%<
M-3=<,38U7#$V,UPQ-C)<-3=<,34T7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ-#)<
M,34Q7#$U-EPU-UPQ-S)<,38S7#$U,")=(#T@)V%P<&QI8V%T:6]N+W@M>G-H
M)SL*)&UI;65?;6%G:6-;,%U;,C%=6R)<-#-<-#%<-#!<-3=<,38U7#$V,UPQ
M-C)<-3=<,34T7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ-#)<,34Q7#$U-EPU-UPQ
M-#%<,38S7#$U,")=(#T@)V%P<&QI8V%T:6]N+W@M>G-H)SL*)&UI;65?;6%G
M:6-;,%U;,C%=6R)<-#-<-#%<-#!<-3=<,38U7#$V,UPQ-C)<-3=<,34T7#$U
M-UPQ-#-<,30Q7#$U-%PU-UPQ-#)<,34Q7#$U-EPU-UPQ-S)<,38S7#$U,")=
M(#T@)V%P<&QI8V%T:6]N+W@M>G-H)SL*)&UI;65?;6%G:6-;,%U;,C%=6R)<
M-#-<-#%<-3=<,38U7#$V,UPQ-C)<-3=<,34T7#$U-UPQ-#-<,30Q7#$U-%PU
M-UPQ-#)<,34Q7#$U-EPU-UPQ-#)<,30Q7#$V,UPQ-3`B72`]("=A<'!L:6-A
M=&EO;B]X+7-H)SL*)&UI;65?;6%G:6-;,%U;,C%=6R)<-#-<-#%<-3=<,38U
M7#$V,UPQ-C)<-3=<,34T7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ-#)<,34Q7#$U
M-EPU-UPQ-#=<,30Q7#$V-UPQ-3,B72`]("=A<'!L:6-A=&EO;B]X+6%W:R<[
M"B1M:6UE7VUA9VEC6S!=6S(Q75LB7#0S7#0Q7#4W7#$V-5PQ-C-<,38R7#4W
M7#$U-%PQ-3=<,30S7#$T,5PQ-31<-3=<,30R7#$U,5PQ-39<-3=<,34V7#$T
M,5PQ-C=<,34S(ET@/2`G87!P;&EC871I;VXO>"UA=VLG.PHD;6EM95]M86=I
M8ULP75LR,5U;(EPT,UPT,5PU-UPQ-C5<,38S7#$V,EPU-UPQ-31<,34W7#$T
M,UPQ-#%<,34T7#4W7#$T,EPQ-3%<,34V7#4W7#$V,%PQ-#5<,38R7#$U-")=
M(#T@)V%P<&QI8V%T:6]N+W@M<&5R;"<["B1M:6UE7VUA9VEC6S!=6S(Q75LB
M7#0S7#0Q7#4W7#$V-5PQ-C-<,38R7#4W7#$U-%PQ-3=<,30S7#$T,5PQ-31<
M-3=<,30R7#$U,5PQ-39<-3=<,38T7#$T,UPQ-C-<,34P(ET@/2`G87!P;&EC
M871I;VXO>"UC<V@G.PHD;6EM95]M86=I8ULP75LR,%U;(EPQ-#5<,38V7#$T
M,5PQ-31<-#!<-#)<,30U7#$W,%PQ-#5<,30S7#0P7#4W7#$T,EPQ-3%<,34V
M7#4W7#$V,%PQ-#5<,38R7#$U-")=(#T@)V%P<&QI8V%T:6]N+W@M<&5R;"<[
M"B1M:6UE7VUA9VEC6S!=6S(P75LB7#0S7#0Q7#$Q7#4W7#$V-5PQ-C-<,38R
M7#4W7#$U-%PQ-3=<,30S7#$T,5PQ-31<-3=<,30R7#$U,5PQ-39<-3=<,30Q
M7#$T-2)=(#T@)W1E>'0O<V-R:7!T)SL*)&UI;65?;6%G:6-;,%U;,C!=6R)<
M-#-<-#%<-#!<-3=<,38U7#$V,UPQ-C)<-3=<,34T7#$U-UPQ-#-<,30Q7#$U
M-%PU-UPQ-#)<,34Q7#$U-EPU-UPQ-#%<,30U(ET@/2`G=&5X="]S8W)I<'0G
M.PHD;6EM95]M86=I8ULP75LR,%U;(EPT,UPT,5PU-UPQ-C5<,38S7#$V,EPU
M-UPQ-31<,34W7#$T,UPQ-#%<,34T7#4W7#$T,EPQ-3%<,34V7#4W7#$T,5PQ
M-C-<,34P(ET@/2`G87!P;&EC871I;VXO>"US:"<["B1M:6UE7VUA9VEC6S!=
M6S(P75LB7#0S7#0Q7#4W7#$V-5PQ-C-<,38R7#4W7#$U-%PQ-3=<,30S7#$T
M,5PQ-31<-3=<,30R7#$U,5PQ-39<-3=<,3<R7#$V,UPQ-3`B72`]("=A<'!L
M:6-A=&EO;B]X+7IS:"<["B1M:6UE7VUA9VEC6S!=6S$Y75LB7#$P,UPQ-C)<
M,30U7#$T,5PQ-C1<,34Q7#$V-EPQ-#5<-#!<,3(V7#$U-UPQ-3%<,30S7#$T
M-5PT,%PQ,#9<,34Q7#$U-%PQ-#4B72`]("=A=61I;R]X+79O8R<["B1M:6UE
M7VUA9VEC6S!=6S$Y75LB7#0Q7#<T7#$T,5PQ-C)<,30S7#$U,%PW-EPQ-39<
M,3,W7#$S-UPQ,S=<,3,W7#$S-UPQ,S=<,3,W7#$S-UPQ,S=<,3,W7#$P-2)=
M(#T@)V%P<&QI8V%T:6]N+W@M87(G.PHD;6EM95]M86=I8ULP75LQ.5U;(EPT
M,5PW-%PQ-#%<,38R7#$T,UPQ-3!<-S9<,34V7#$S-UPQ,S=<,3,W7#$S-UPQ
M,S=<,3,W7#$S-UPQ,S=<-C9<-C1<,3`U(ET@/2`G87!P;&EC871I;VXO9&%T
M82<["B1M:6UE7VUA9VEC6S!=6S$Y75LB7#0S7#0Q7#4W7#$V-5PQ-C-<,38R
M7#4W7#$U-%PQ-3=<,30S7#$T,5PQ-31<-3=<,30R7#$U,5PQ-39<-3=<,30Q
M7#$T-2)=(#T@)W1E>'0O<V-R:7!T)SL*)&UI;65?;6%G:6-;,%U;,3A=6R)<
M,3`V7#$U,5PQ,31<,30U7#$R,UPQ-C1<,3`Q7#$V,EPQ,C1<,30V7#$Q,5PQ
M-31<,3`U7#$V,UPQ,C1<,30Q7#$R,EPQ-C0B72`]("=T97AT+W@M87!P;&4M
M8FEN<V-I:2<["B1M:6UE7VUA9VEC6S!=6S$X75LB7#0S7#0Q7#0P7#4W7#$V
M-5PQ-C-<,38R7#4W7#$U-%PQ-3=<,30S7#$T,5PQ-31<-3=<,38T7#$T,UPQ
M-C-<,34P(ET@/2`G87!P;&EC871I;VXO>"UC<V@G.PHD;6EM95]M86=I8ULP
M75LQ.%U;(EPT-5PT,5PQ,C!<,3(S7#4U7#$P,5PQ-#1<,34W7#$T,EPQ-#5<
M,3`V7#$U-UPQ-39<,38T7#4U7#8Q7#4V7#8P(ET@/2`G9F]N="]T>7!E,2<[
M"B1M:6UE7VUA9VEC6S!=6S$W75LB7#0S7#0Q7#4W7#$V-5PQ-C-<,38R7#4W
M7#$U-%PQ-3=<,30S7#$T,5PQ-31<-3=<,38T7#$T,UPQ-C-<,34P(ET@/2`G
M87!P;&EC871I;VXO>"UC<V@G.PHD;6EM95]M86=I8ULP75LQ-EU;(EPQ,#5<
M,3<P7#$V-%PQ-#5<,34V7#$T-%PQ-#5<,30T7#0P7#$Q-5PQ-3=<,30T7#$V
M-5PQ-31<,30U7#<R(ET@/2`G875D:6\O>"UF=#(M;6]D)SL*)&UI;65?;6%G
M:6-;,%U;,39=6R)<,3(S7#$V-%PQ-#%<,38R7#$V-%PQ,#9<,34W7#$U-EPQ
M-C1<,3$U7#$T-5PQ-C1<,38R7#$U,5PQ-#-<,38S(ET@/2`G9F]N="]X+7-U
M;F]S+6YE=W,G.PHD;6EM95]M86=I8ULP75LQ-EU;(EPT,UPT,5PQ,5PU-UPQ
M-C5<,38S7#$V,EPU-UPQ-#)<,34Q7#$U-EPU-UPQ-#=<,30Q7#$V-UPQ-3,B
M72`]("=A<'!L:6-A=&EO;B]X+6%W:R<["B1M:6UE7VUA9VEC6S!=6S$V75LB
M7#0S7#0Q7#$Q7#4W7#$V-5PQ-C-<,38R7#4W7#$T,EPQ-3%<,34V7#4W7#$U
M-EPQ-#%<,38W7#$U,R)=(#T@)V%P<&QI8V%T:6]N+W@M87=K)SL*)&UI;65?
M;6%G:6-;,%U;,39=6R)<-#-<-#%<,3%<-3=<,38U7#$V,UPQ-C)<-3=<,30R
M7#$U,5PQ-39<-3=<,38P7#$T-5PQ-C)<,34T(ET@/2`G87!P;&EC871I;VXO
M>"UP97)L)SL*)&UI;65?;6%G:6-;,%U;,39=6R)<-#-<-#%<-#!<-3=<,38U
M7#$V,UPQ-C)<-3=<,30R7#$U,5PQ-39<-3=<,30W7#$T,5PQ-C=<,34S(ET@
M/2`G87!P;&EC871I;VXO>"UA=VLG.PHD;6EM95]M86=I8ULP75LQ-EU;(EPT
M,UPT,5PT,%PU-UPQ-C5<,38S7#$V,EPU-UPQ-#)<,34Q7#$U-EPU-UPQ-39<
M,30Q7#$V-UPQ-3,B72`]("=A<'!L:6-A=&EO;B]X+6%W:R<["B1M:6UE7VUA
M9VEC6S!=6S$V75LB7#0S7#0Q7#0P7#4W7#$V-5PQ-C-<,38R7#4W7#$T,EPQ
M-3%<,34V7#4W7#$V,%PQ-#5<,38R7#$U-")=(#T@)V%P<&QI8V%T:6]N+W@M
M<&5R;"<["B1M:6UE7VUA9VEC6S!=6S$V75LB7#<T7#$Q-5PQ-#%<,34S7#$T
M-5PQ-C)<,3`T7#$U,5PQ-#-<,38T7#$U,5PQ-3=<,34V7#$T,5PQ-C)<,3<Q
M(ET@/2`G87!P;&EC871I;VXO>"UF<F%M96UA:V5R)SL*)&UI;65?;6%G:6-;
M,%U;,39=6R)<-S1<,3$U7#$T,5PQ-3-<,30U7#$V,EPQ,C-<,30S7#$V,EPQ
M-#5<,30U7#$U-EPQ,#9<,34W7#$U-EPQ-C0B72`]("=F;VYT+W@M9G)A;65M
M86ME<B<["B1M:6UE7VUA9VEC6S!=6S$U75LB7#0S7#0Q7#$Q7#4W7#$V-5PQ
M-C-<,38R7#4W7#$T,EPQ-3%<,34V7#4W7#$T,5PQ-C=<,34S(ET@/2`G87!P
M;&EC871I;VXO>"UA=VLG.PHD;6EM95]M86=I8ULP75LQ-5U;(EPT,UPT,5PT
M,%PU-UPQ-C5<,38S7#$V,EPU-UPQ-#)<,34Q7#$U-EPU-UPQ-#%<,38W7#$U
M,R)=(#T@)V%P<&QI8V%T:6]N+W@M87=K)SL*)&UI;65?;6%G:6-;,%U;,35=
M6R)<-#-<-#%<-3=<,38U7#$V,UPQ-C)<-3=<,30R7#$U,5PQ-39<-3=<,30W
M7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC871I;VXO>"UA=VLG.PHD;6EM95]M
M86=I8ULP75LQ-5U;(EPT,UPT,5PU-UPQ-C5<,38S7#$V,EPU-UPQ-#)<,34Q
M7#$U-EPU-UPQ-39<,30Q7#$V-UPQ-3,B72`]("=A<'!L:6-A=&EO;B]X+6%W
M:R<["B1M:6UE7VUA9VEC6S!=6S$U75LB7#0S7#0Q7#4W7#$V-5PQ-C-<,38R
M7#4W7#$T,EPQ-3%<,34V7#4W7#$V,%PQ-#5<,38R7#$U-")=(#T@)V%P<&QI
M8V%T:6]N+W@M<&5R;"<["B1M:6UE7VUA9VEC6S!=6S$T75LB7#0Q7#<T7#$T
M,5PQ-C)<,30S7#$U,%PW-EPQ-39<,30T7#$T-5PQ-#)<,34Q7#$T,5PQ-38B
M72`]("=A<'!L:6-A=&EO;B]X+61P:V<G.PHD;6EM95]M86=I8ULP75LQ-%U;
M(EPT,UPT,5PU-UPQ-C5<,38S7#$V,EPU-UPQ-#)<,34Q7#$U-EPU-UPQ-#%<
M,38W7#$U,R)=(#T@)V%P<&QI8V%T:6]N+W@M87=K)SL*)&UI;65?;6%G:6-;
M,%U;,31=6R)<-S1<-#%<,3`T7#$Q-UPQ,#-<,3(T7#$S,5PQ,C!<,3`U7#0P
M7#$Q,%PQ,C1<,3$U7#$Q-")=(#T@)W1E>'0O:'1M;"<["B1M:6UE7VUA9VEC
M6S!=6S$T75LB7#<T7#0Q7#$T-%PQ-3=<,30S7#$V-%PQ-S%<,38P7#$T-5PT
M,%PQ-3!<,38T7#$U-5PQ-30B72`]("=T97AT+VAT;6PG.PHD;6EM95]M86=I
M8ULP75LQ,UU;(EPQ,#=<,3$Q7#$Q-5PQ,C!<-#!<,3`W7#$V,EPQ-#%<,30T
M7#$U,5PQ-#5<,34V7#$V-")=(#T@)V%P<&QI8V%T:6]N+W@M9VEM<"UG<F%D
M:65N="<["B1M:6UE7VUA9VEC6S!=6S$R75LB7#$R,EPQ-#5<,38T7#$V-5PQ
M-C)<,34V7#4U7#$R,%PQ-#%<,38T7#$U,%PW,B)=(#T@)VUE<W-A9V4O<F9C
M.#(R)SL*)&UI;65?;6%G:6-;,%U;,3)=6R)<-#-<-#%<,3%<-3=<,30R7#$U
M,5PQ-39<-3=<,30R7#$T,5PQ-C-<,34P(ET@/2`G87!P;&EC871I;VXO>"US
M:"<["B1M:6UE7VUA9VEC6S!=6S$R75LB7#0S7#0Q7#$Q7#4W7#$T,EPQ-3%<
M,34V7#4W7#$T-UPQ-#%<,38W7#$U,R)=(#T@)V%P<&QI8V%T:6]N+W@M87=K
M)SL*)&UI;65?;6%G:6-;,%U;,3)=6R)<-#-<-#%<,3%<-3=<,30R7#$U,5PQ
M-39<-3=<,34V7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC871I;VXO>"UA=VLG
M.PHD;6EM95]M86=I8ULP75LQ,EU;(EPT,UPT,5PQ,5PU-UPQ-#)<,34Q7#$U
M-EPU-UPQ-C!<,30U7#$V,EPQ-30B72`]("=A<'!L:6-A=&EO;B]X+7!E<FPG
M.PHD;6EM95]M86=I8ULP75LQ,EU;(EPT,UPT,5PQ,5PU-UPQ-#)<,34Q7#$U
M-EPU-UPQ-C1<,30S7#$V,UPQ-3`B72`]("=A<'!L:6-A=&EO;B]X+6-S:"<[
M"B1M:6UE7VUA9VEC6S!=6S$R75LB7#0S7#0Q7#0P7#4W7#$T,EPQ-3%<,34V
M7#4W7#$T,EPQ-#%<,38S7#$U,")=(#T@)V%P<&QI8V%T:6]N+W@M<V@G.PHD
M;6EM95]M86=I8ULP75LQ,EU;(EPT,UPT,5PT,%PU-UPQ-#)<,34Q7#$U-EPU
M-UPQ-#=<,30Q7#$V-UPQ-3,B72`]("=A<'!L:6-A=&EO;B]X+6%W:R<["B1M
M:6UE7VUA9VEC6S!=6S$R75LB7#0S7#0Q7#0P7#4W7#$T,EPQ-3%<,34V7#4W
M7#$U-EPQ-#%<,38W7#$U,R)=(#T@)V%P<&QI8V%T:6]N+W@M87=K)SL*)&UI
M;65?;6%G:6-;,%U;,3)=6R)<-#-<-#%<-#!<-3=<,30R7#$U,5PQ-39<-3=<
M,38P7#$T-5PQ-C)<,34T(ET@/2`G87!P;&EC871I;VXO>"UP97)L)SL*)&UI
M;65?;6%G:6-;,%U;,3)=6R)<-#-<-#%<-#!<-3=<,30R7#$U,5PQ-39<-3=<
M,38T7#$T,UPQ-C-<,34P(ET@/2`G87!P;&EC871I;VXO>"UC<V@G.PHD;6EM
M95]M86=I8ULP75LQ,5U;(EPT,UPT,5PQ,5PU-UPQ-#)<,34Q7#$U-EPU-UPQ
M-#%<,38W7#$U,R)=(#T@)V%P<&QI8V%T:6]N+W@M87=K)SL*)&UI;65?;6%G
M:6-;,%U;,3%=6R)<-#-<-#%<,3%<-3=<,30R7#$U,5PQ-39<-3=<,30S7#$V
M,UPQ-3`B72`]("=A<'!L:6-A=&EO;B]X+6-S:"<["B1M:6UE7VUA9VEC6S!=
M6S$Q75LB7#0S7#0Q7#$Q7#4W7#$T,EPQ-3%<,34V7#4W7#$U,UPQ-C-<,34P
M(ET@/2`G87!P;&EC871I;VXO>"UK<V@G.PHD;6EM95]M86=I8ULP75LQ,5U;
M(EPT,UPT,5PT,%PU-UPQ-#)<,34Q7#$U-EPU-UPQ-#%<,38W7#$U,R)=(#T@
M)V%P<&QI8V%T:6]N+W@M87=K)SL*)&UI;65?;6%G:6-;,%U;,3%=6R)<-#-<
M-#%<-#!<-3=<,30R7#$U,5PQ-39<-3=<,30S7#$V,UPQ-3`B72`]("=A<'!L
M:6-A=&EO;B]X+6-S:"<["B1M:6UE7VUA9VEC6S!=6S$Q75LB7#0S7#0Q7#0P
M7#4W7#$T,EPQ-3%<,34V7#4W7#$U,UPQ-C-<,34P(ET@/2`G87!P;&EC871I
M;VXO>"UK<V@G.PHD;6EM95]M86=I8ULP75LQ,5U;(EPT,UPT,5PU-UPQ-#)<
M,34Q7#$U-EPU-UPQ-#)<,30Q7#$V,UPQ-3`B72`]("=A<'!L:6-A=&EO;B]X
M+7-H)SL*)&UI;65?;6%G:6-;,%U;,3%=6R)<-#-<-#%<-3=<,30R7#$U,5PQ
M-39<-3=<,30W7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC871I;VXO>"UA=VLG
M.PHD;6EM95]M86=I8ULP75LQ,5U;(EPT,UPT,5PU-UPQ-#)<,34Q7#$U-EPU
M-UPQ-39<,30Q7#$V-UPQ-3,B72`]("=A<'!L:6-A=&EO;B]X+6%W:R<["B1M
M:6UE7VUA9VEC6S!=6S$Q75LB7#0S7#0Q7#4W7#$T,EPQ-3%<,34V7#4W7#$V
M,%PQ-#5<,38R7#$U-")=(#T@)V%P<&QI8V%T:6]N+W@M<&5R;"<["B1M:6UE
M7VUA9VEC6S!=6S$Q75LB7#0S7#0Q7#4W7#$T,EPQ-3%<,34V7#4W7#$V-%PQ
M-#-<,38S7#$U,")=(#T@)V%P<&QI8V%T:6]N+W@M8W-H)SL*)&UI;65?;6%G
M:6-;,%U;,3!=6R)<,3`R7#$U,5PQ-C1<,34U7#$T,5PQ-C!<,30V7#$U,5PQ
M-31<,30U(ET@/2`G:6UA9V4O=6YK;F]W;B<["B1M:6UE7VUA9VEC6S!=6S$P
M75LB7#$R,UPQ,C1<,3`Q7#$R,EPQ,C1<,3`V7#$Q-UPQ,39<,3(T7#0P(ET@
M/2`G9F]N="]X+6)D9B<["B1M:6UE7VUA9VEC6S!=6S$P75LB7#0S7#0Q7#$Q
M7#4W7#$T,EPQ-3%<,34V7#4W7#$V,EPQ-#,B72`]("=T97AT+W-C<FEP="<[
M"B1M:6UE7VUA9VEC6S!=6S$P75LB7#0S7#0Q7#$Q7#4W7#$T,EPQ-3%<,34V
M7#4W7#$V,UPQ-3`B72`]("=A<'!L:6-A=&EO;B]X+7-H)SL*)&UI;65?;6%G
M:6-;,%U;,3!=6R)<-#-<-#%<-#!<-3=<,30R7#$U,5PQ-39<-3=<,38R7#$T
M,R)=(#T@)W1E>'0O<V-R:7!T)SL*)&UI;65?;6%G:6-;,%U;,3!=6R)<-#-<
M-#%<-#!<-3=<,30R7#$U,5PQ-39<-3=<,38S7#$U,")=(#T@)V%P<&QI8V%T
M:6]N+W@M<V@G.PHD;6EM95]M86=I8ULP75LQ,%U;(EPT,UPT,5PU-UPQ-#)<
M,34Q7#$U-EPU-UPQ-#%<,38W7#$U,R)=(#T@)V%P<&QI8V%T:6]N+W@M87=K
M)SL*)&UI;65?;6%G:6-;,%U;,3!=6R)<-#-<-#%<-3=<,30R7#$U,5PQ-39<
M-3=<,30S7#$V,UPQ-3`B72`]("=A<'!L:6-A=&EO;B]X+6-S:"<["B1M:6UE
M7VUA9VEC6S!=6S$P75LB7#0S7#0Q7#4W7#$T,EPQ-3%<,34V7#4W7#$U,UPQ
M-C-<,34P(ET@/2`G87!P;&EC871I;VXO>"UK<V@G.PHD;6EM95]M86=I8ULP
M75LQ,%U;(EPW-%PQ,35<,30Q7#$U,UPQ-#5<,38R7#$P-EPQ-3%<,34T7#$T
M-2)=(#T@)V%P<&QI8V%T:6]N+W@M9G)A;65M86ME<B<["B1M:6UE7VUA9VEC
M6S!=6SE=6R)<,3(R7#$T-5PQ-#-<,30U7#$U,5PQ-C9<,30U7#$T-%PW,B)=
M(#T@)VUE<W-A9V4O<F9C.#(R)SL*)&UI;65?;6%G:6-;,%U;.5U;(EPQ,C-<
M,38T7#$T,5PQ-C)<,38T7#$P-EPQ-3=<,34V7#$V-")=(#T@)V9O;G0O>"US
M=6YO<RUN97=S)SL*)&UI;65?;6%G:6-;,%U;.5U;(EPR,3%<,3$T7#$S,EPQ
M,3=<,%PQ-5PQ,EPS,EPQ,B)=(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM
M95]M86=I8ULP75LY75LB7#0S7#0Q7#4W7#$T,EPQ-3%<,34V7#4W7#$V,EPQ
M-#,B72`]("=T97AT+W-C<FEP="<["B1M:6UE7VUA9VEC6S!=6SE=6R)<-#-<
M-#%<-3=<,30R7#$U,5PQ-39<-3=<,38S7#$U,")=(#T@)V%P<&QI8V%T:6]N
M+W@M<V@G.PHD;6EM95]M86=I8ULP75LY75LB7#4U7#$V,EPQ-3=<,34U7#8Q
M7#$T-EPQ-C-<-35<-C`B72`]("=A<'!L:6-A=&EO;B]X+69I;&5S>7-T96TG
M.PHD;6EM95]M86=I8ULP75LY75LB7#<T7#$P,EPQ-3=<,34W7#$U,UPQ,#9<
M,34Q7#$U-%PQ-#4B72`]("=A<'!L:6-A=&EO;B]X+69R86UE;6%K97(G.PHD
M;6EM95]M86=I8ULP75LX75LB7#$Q-UPQ-39<,34T7#$W,5PT,%PQ-3%<,34V
M7#0P(ET@/2`G=&5X="]X+7!A=&-H)SL*)&UI;65?;6%G:6-;,%U;.%U;(EPQ
M-#=<,34Q7#$U-5PQ-C!<-#!<,3<P7#$T,UPQ-#8B72`]("=A<'!L:6-A=&EO
M;B]X+6=I;7`M:6UA9V4G.PHD;6EM95]M86=I8ULP75LX75LB7#$U-5PQ-C-<
M,30W7#$T,UPQ-#%<,38T7#8P7#8Q(ET@/2`G87!P;&EC871I;VXO>"UL;V-A
M;&4G.PHD;6EM95]M86=I8ULP75LX75LB7#,R7#$T,5PQ-C)<,30S7#$U,%PQ
M-3%<,38V7#$T-2)=(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I
M8ULP75LX75LB7#0Q7#<T7#$R,%PQ,#1<,3`V7#<V7#0Q7#$U-B)=(#T@)V%P
M<&QI8V%T:6]N+W@M<')O9B<["B1M:6UE7VUA9VEC6S!=6SA=6R)<-S1<,3$U
M7#$Q,5PQ,#9<,3`V7#$U,5PQ-31<,30U(ET@/2`G87!P;&EC871I;VXO>"UF
M<F%M96UA:V5R)SL*)&UI;65?;6%G:6-;,%U;-UU;(EPQ,#%<,38R7#$V-%PQ
M-3%<,30S7#$U-%PQ-#4B72`]("=M97-S86=E+VYE=W,G.PHD;6EM95]M86=I
M8ULP75LW75LB7#$R,%PQ,#-<,3`T7#$S-UPQ,3=<,3(P7#$P,2)=(#T@)W@O
M>"UP:&]T;RUC9"UO=F5R9FEE=RUF:6QE)SL*)&UI;65?;6%G:6-;,%U;-UU;
M(EPS-3%<-31<,5PQ,3)<,3`Q7#$Q-5PQ,2)=(#T@)V%P<&QI8V%T:6]N+V1A
M=&$G.PHD;6EM95]M86=I8ULP75LW75LB7#0Q7#<T7#$T,5PQ-C)<,30S7#$U
M,%PW-B)=(#T@)V%P<&QI8V%T:6]N+W@M87(G.PHD;6EM95]M86=I8ULP75LW
M75LB7#<R7#0P7#$V,UPQ-3!<,30U7#$U-%PQ-30B72`]("=A<'!L:6-A=&EO
M;B]D871A)SL*)&UI;65?;6%G:6-;,%U;-EU;(EPQ,39<,38U7#$P-EPQ-3%<
M,34T7#$T-2)=(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP
M75LV75LB7#$Q-EPS-C5<,3`V7#,U,5PQ-31<,S0U(ET@/2`G87!P;&EC871I
M;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S9=6R)<-C!<-C=<-C!<-C=<-C!<
M-C$B72`]("=A<'!L:6-A=&EO;B]X+6-P:6\G.PHD;6EM95]M86=I8ULP75LV
M75LB7#8P7#8W7#8P7#8W7#8P7#8R(ET@/2`G87!P;&EC871I;VXO>"UC<&EO
M)SL*)&UI;65?;6%G:6-;,%U;-EU;(EPV,%PV-UPV,%PV-UPV,%PV-R)=(#T@
M)V%P<&QI8V%T:6]N+W@M8W!I;R<["B1M:6UE7VUA9VEC6S!=6S9=6R)<-S1<
M,3$U7#$T,5PQ-3-<,30U7#$V,B)=(#T@)V%P<&QI8V%T:6]N+W@M9G)A;65M
M86ME<B<["B1M:6UE7VUA9VEC6S!=6S9=6R)<-S1<,3(T7#$Q,5PQ,C1<,3$T
M7#$P-2)=(#T@)W1E>'0O:'1M;"<["B1M:6UE7VUA9VEC6S!=6S9=6R)<-S1<
M,38T7#$U,5PQ-C1<,34T7#$T-2)=(#T@)W1E>'0O:'1M;"<["B1M:6UE7VUA
M9VEC6S!=6S5=6R)<,%PQ7#!<,%PP(ET@/2`G9F]N="]T=&8G.PHD;6EM95]M
M86=I8ULP75LU75LB7#!<-%PS-EPR,3)<,C`P(ET@/2`G87!P;&EC871I;VXO
M8V]R92<["B1M:6UE7VUA9VEC6S!=6S5=6R)<,3`R7#$P,5PQ,#)<,3,Q7#$Q
M-")=(#T@)VUE<W-A9V4O>"UG;G4M<FUA:6PG.PHD;6EM95]M86=I8ULP75LU
M75LB7#$P,EPQ,#5<,3`W7#$Q,5PQ,38B72`]("=A<'!L:6-A=&EO;B]X+6%W
M:R<["B1M:6UE7VUA9VEC6S!=6S5=6R)<,3`S7#$U-UPQ-C)<,30U7#$B72`]
M("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC
M6S!=6S5=6R)<,3`T7#8Q7#4V7#8P7#$U(ET@/2`G9F]N="]X+7-P965D;R<[
M"B1M:6UE7VUA9VEC6S!=6S5=6R)<,3`V7#$V,EPQ-3=<,34U7#<R(ET@/2`G
M;65S<V%G92]R9F,X,C(G.PHD;6EM95]M86=I8ULP75LU75LB7#$Q-5PQ,#%<
M,3(S7#$S-UPQ,C4B72`]("=A=61I;R]X+6UU;'1I;6%T92UM;V0G.PHD;6EM
M95]M86=I8ULP75LU75LB7#$R,%PQ,3=<,3,V7#$R,5PQ-#`B72`]("=T97AT
M+W9N9"YM<RUW;W)D)SL*)&UI;65?;6%G:6-;,%U;-5U;(EPQ,C!<,30Q7#$V
M-%PQ-3!<-S(B72`]("=M97-S86=E+VYE=W,G.PHD;6EM95]M86=I8ULP75LU
M75LB7#$S,%PQ-C)<,30U7#$T-EPW,B)=(#T@)VUE<W-A9V4O;F5W<R<["B1M
M:6UE7VUA9VEC6S!=6S5=6R)<,30T7#$U,5PQ-#9<,30V7#0P(ET@/2`G=&5X
M="]X+7!A=&-H)SL*)&UI;65?;6%G:6-;,%U;-5U;(EPR,C5<-C1<-C)<-C)<
M,S,V(ET@/2`G87!P;&EC871I;VXO>"UL;V-A;&4G.PHD;6EM95]M86=I8ULP
M75LU75LB7#,S-EPV,EPV,EPV-%PR,C4B72`]("=A<'!L:6-A=&EO;B]X+6QO
M8V%L92<["B1M:6UE7VUA9VEC6S!=6S5=6R)<-S1<,3$P7#$P-5PQ,#%<,3`T
M(ET@/2`G=&5X="]H=&UL)SL*)&UI;65?;6%G:6-;,%U;-5U;(EPW-%PQ,3!<
M,3(T7#$Q-5PQ,30B72`]("=T97AT+VAT;6PG.PHD;6EM95]M86=I8ULP75LU
M75LB7#<T7#$U,%PQ-#5<,30Q7#$T-")=(#T@)W1E>'0O:'1M;"<["B1M:6UE
M7VUA9VEC6S!=6S5=6R)<-S1<,34P7#$V-%PQ-35<,34T(ET@/2`G=&5X="]H
M=&UL)SL*)&UI;65?;6%G:6-;,%U;-5U;(EPW-5PW-%PQ-#%<,38R7#<V(ET@
M/2`G87!P;&EC871I;VXO>"UA<B<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,%PP
M7#!<,S$T(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD
M;6EM95]M86=I8ULP75LT75LB7#!<,%PP7#0B72`]("=F;VYT+W@M<VYF)SL*
M)&UI;65?;6%G:6-;,%U;-%U;(EPP7#!<,5PQ,#<B72`]("=A<'!L:6-A=&EO
M;B]X+6]B:F5C="UF:6QE)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPP7#!<,5PQ
M,3,B72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE
M7VUA9VEC6S!=6S1=6R)<,%PP7#%<,3$U(ET@/2`G87!P;&EC871I;VXO>"UE
M>&5C=71A8FQE+69I;&4G.PHD;6EM95]M86=I8ULP75LT75LB7#!<,%PQ7#$Q
M-R)=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?
M;6%G:6-;,%U;-%U;(EPP7#!<,5PR,#$B72`]("=A<'!L:6-A=&EO;B]X+6]B
M:F5C="UF:6QE)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPP7#!<,5PR,#<B72`]
M("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPP7#!<
M,5PR-C,B72`]("=V:61E;R]M<&5G)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPP
M7#!<,5PR-S(B72`]("=V:61E;R]M<&5G)SL*)&UI;65?;6%G:6-;,%U;-%U;
M(EPP7#!<,5PV(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G
M.PHD;6EM95]M86=I8ULP75LT75LB7#!<,%PR,#%<,34T(ET@/2`G87!P;&EC
M871I;VXO>"UA<&PM=V]R:W-P86-E)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPP
M7#!<,S<W7#$T-2)=(#T@)V%P<&QI8V%T:6]N+W@M;&EB<F%R>2UF:6QE)SL*
M)&UI;65?;6%G:6-;,%U;-%U;(EPP7#!<,S<W7#$U-2)=(#T@)V%P<&QI8V%T
M:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LT75LB7#!<,%PS7#,T-R)=(#T@
M)V%P<&QI8V%T:6]N+W@M;&EB<F%R>2UF:6QE)SL*)&UI;65?;6%G:6-;,%U;
M-%U;(EPP7#!<,UPS-C,B72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M
M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,%PQ-#1<,38S7#4V(ET@/2`G
M875D:6\O8F%S:6,G.PHD;6EM95]M86=I8ULP75LT75LB7#!<,5PR,EPQ,C<B
M72`]("=A<'!L:6-A=&EO;B]C;W)E)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPP
M7#(R7#,R-EPR,#<B72`]("=I;6%G92]X,3$G.PHD;6EM95]M86=I8ULP75LT
M75LB7#!<,UPR,S-<,S4U(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE
M7VUA9VEC6S!=6S1=6R)<,%PS7#(S,UPS-38B72`]("=A<'!L:6-A=&EO;B]D
M871A)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPP7#5<,C9<,")=(#T@)V%P<&QI
M8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LT75LB7#!<-5PR-EPW(ET@
M/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,%PU
M7#8Q7#$T,B)=(#T@)V%P<&QI8V%T:6]N+W@M9&(G.PHD;6EM95]M86=I8ULP
M75LT75LB7#!<-EPR-5PQ-#$B72`]("=A<'!L:6-A=&EO;B]X+61B)SL*)&UI
M;65?;6%G:6-;,%U;-%U;(EPQ,#-<,3(T7#$Q-5PQ,#8B72`]("=A=61I;R]X
M+6-M9B<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,3`U7#$Q-5PQ,3=<,3`T(ET@
M/2`G875D:6\O>"UE;6]D)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPQ,#9<,3`V
M7#$Q,5PQ,30B72`]("=F;VYT+W1T9B<["B1M:6UE7VUA9VEC6S!=6S1=6R)<
M,3`V7#$Q-UPQ,39<,3(T(ET@/2`G9F]N="]X+79F;VYT)SL*)&UI;65?;6%G
M:6-;,%U;-%U;(EPQ,#=<,3`T7#$P,EPQ,34B72`]("=A<'!L:6-A=&EO;B]X
M+6=D8FTG.PHD;6EM95]M86=I8ULP75LT75LB7#$P-UPQ,3%<,3`V7#<P(ET@
M/2`G:6UA9V4O9VEF)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPQ,%PQ-EPQ,EPQ
M-R)=(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LT75LB
M7#$Q,%PQ,C!<,3`Q7#$Q,R)=(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM
M95]M86=I8ULP75LT75LB7#$Q,5PQ,3%<,3$V7#8Q(ET@/2`G:6UA9V4O=&EF
M9B<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,3$Q7#$Q,5PU,EPP(ET@/2`G:6UA
M9V4O=&EF9B<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,3$T7#$P-%PQ,3!<,34Q
M(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S1=6R)<
M,3$T7#$R-UPQ,#9<,3$V(ET@/2`G9F]N="]T>7!E,2<["B1M:6UE7VUA9VEC
M6S!=6S1=6R)<,3$U7#$Q-5PP7#4R(ET@/2`G:6UA9V4O=&EF9B<["B1M:6UE
M7VUA9VEC6S!=6S1=6R)<,3$U7#$Q-UPQ,C9<,3$Q(ET@/2`G=FED96\O>"US
M9VDM;6]V:64G.PHD;6EM95]M86=I8ULP75LT75LB7#$Q-5PQ,C1<,34P7#$T
M-")=(#T@)V%U9&EO+VUI9&DG.PHD;6EM95]M86=I8ULP75LT75LB7#$Q-5PR
M-#=<,S4V7#,U,")=(#T@)V9O;G0O>"UH<"UW:6YD;W=S)SL*)&UI;65?;6%G
M:6-;,%U;-%U;(EPQ,39<,3(T7#$R,EPQ,3,B72`]("=A=61I;R]X+6UU;'1I
M=')A8VLG.PHD;6EM95]M86=I8ULP75LT75LB7#$R,%PQ,3-<,UPT(ET@/2`G
M87!P;&EC871I;VXO>FEP)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPQ,C)<,3$Q
M7#$P-EPQ,#8B72`]("=A=61I;R]X+7=A=B<["B1M:6UE7VUA9VEC6S!=6S1=
M6R)<,3(R7#$T,5PQ-C)<-#$B72`]("=A<'!L:6-A=&EO;B]X+7)A<B<["B1M
M:6UE7VUA9VEC6S!=6S1=6R)<,3(S7#$R,5PQ,C-<,3$P(ET@/2`G87!P;&EC
M871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,3(T7#$P,5PQ,#1<
M,3(S(ET@/2`G87!P;&EC871I;VXO>"UT861S+6=A;64G.PHD;6EM95]M86=I
M8ULP75LT75LB7#$R-5PQ,#-<-C)<,S(B72`]("=A<'!L:6-A=&EO;B]D871A
M)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPQ,C5<,3$V7#8P7#8U(ET@/2`G875D
M:6\O>"UM:6MM;V0M=6YI)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPQ,EPQ-UPQ
M,%PQ-B)=(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LT
M75LB7#$S,5PR-#9<,34R7#(R-2)=(#T@)W@O>"UI;6%G92US=6XM<F%S=&5R
M)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPQ-#5<,S<W7#!<,")=(#T@)V%P<&QI
M8V%T:6]N+W@M87(G.PHD;6EM95]M86=I8ULP75LT75LB7#$U,%PQ-C-<,34Q
M7#8Q(ET@/2`G:6UA9V4O>"UJ<&5G+7!R;W!R:65T87)Y)SL*)&UI;65?;6%G
M:6-;,%U;-%U;(EPQ-EPQ,%PQ-UPQ,B)=(#T@)V%P<&QI8V%T:6]N+V1A=&$G
M.PHD;6EM95]M86=I8ULP75LT75LB7#$W-UPQ,#5<,3$T7#$P-B)=(#T@)V%P
M<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;
M-%U;(EPQ-UPQ,EPQ-EPQ,")=(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM
M95]M86=I8ULP75LT75LB7#%<,3,P7#0Q7#(T-B)=(#T@)V%P<&QI8V%T:6]N
M+V-O<F4G.PHD;6EM95]M86=I8ULP75LT75LB7#%<,30V7#$T,UPQ-C`B72`]
M("=F;VYT+W@M<&-F)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR,3%<,3(P7#$Q
M-EPQ,#<B72`]("=I;6%G92]X+7!N9R<["B1M:6UE7VUA9VEC6S!=6S1=6R)<
M,C-<,3(W7#(S,EPS,38B72`]("=A<'!L:6-A=&EO;B]X+6=D8FTG.PHD;6EM
M95]M86=I8ULP75LT75LB7#(S7#$W,EPU,5PQ,#0B72`]("=F;VYT+W@M<W5N
M;W,M;F5W<R<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,C-<,3<R7#4Q7#$P-R)=
M(#T@)V9O;G0O>"US=6YO<RUN97=S)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR
M,UPQ-S)<-3%<,3(P(ET@/2`G9F]N="]X+7-U;F]S+6YE=W,G.PHD;6EM95]M
M86=I8ULP75LT75LB7#(S7#$W,EPU,5PQ,C$B72`]("=F;VYT+W@M<W5N;W,M
M;F5W<R<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,C1<,EPQ,S%<,S$B72`]("=F
M;VYT+W@M;&EB9W)X)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR-C!<-C%<-C-<
M,30P(ET@/2`G87!P;&EC871I;VXO>"UB;V]T86)L92<["B1M:6UE7VUA9VEC
M6S!=6S1=6R)<,EPQ,%PQ7#$P(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A
M8FQE+69I;&4G.PHD;6EM95]M86=I8ULP75LT75LB7#)<,3!<,5PV(ET@/2`G
M87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD;6EM95]M86=I8ULP
M75LT75LB7#)<,3!<,5PW(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE
M+69I;&4G.PHD;6EM95]M86=I8ULP75LT75LB7#)<,3!<,S<W7#$T-2)=(#T@
M)V%P<&QI8V%T:6]N+W@M;&EB<F%R>2UF:6QE)SL*)&UI;65?;6%G:6-;,%U;
M-%U;(EPR7#$R7#%<,3`B72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M
M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPQ,EPQ7#<B72`]("=A<'!L
M:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=
M6R)<,EPQ,EPS-S=<,30U(ET@/2`G87!P;&EC871I;VXO>"UL:6)R87)Y+69I
M;&4G.PHD;6EM95]M86=I8ULP75LT75LB7#)<,3-<,5PQ,")=(#T@)V%P<&QI
M8V%T:6]N+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;-%U;
M(EPR7#$S7#%<,3,B72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL
M92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPQ,UPQ7#$U(ET@/2`G87!P;&EC
M871I;VXO>"UL:6)R87)Y+69I;&4G.PHD;6EM95]M86=I8ULP75LT75LB7#)<
M,3-<,5PQ-B)=(#T@)V%P<&QI8V%T:6]N+W@M;&EB<F%R>2UF:6QE)SL*)&UI
M;65?;6%G:6-;,%U;-%U;(EPR7#$S7#%<-B)=(#T@)V%P<&QI8V%T:6]N+W@M
M;V)J96-T+69I;&4G.PHD;6EM95]M86=I8ULP75LT75LB7#)<,3-<,5PW(ET@
M/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD;6EM95]M86=I
M8ULP75LT75LB7#)<,31<,5PQ,")=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T
M86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR7#$T7#%<,3,B72`]
M("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC
M6S!=6S1=6R)<,EPQ-%PQ7#$T(ET@/2`G87!P;&EC871I;VXO>"UL:7-P)SL*
M)&UI;65?;6%G:6-;,%U;-%U;(EPR7#$T7#%<,34B72`]("=A<'!L:6-A=&EO
M;B]X+6QI8G)A<GDM9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPQ-%PQ
M7#$V(ET@/2`G87!P;&EC871I;VXO>"UL:6)R87)Y+69I;&4G.PHD;6EM95]M
M86=I8ULP75LT75LB7#)<,31<,5PV(ET@/2`G87!P;&EC871I;VXO>"UE>&5C
M=71A8FQE+69I;&4G.PHD;6EM95]M86=I8ULP75LT75LB7#)<,31<,5PW(ET@
M/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD;6EM95]M86=I
M8ULP75LT75LB7#)<,31<,S<W7#$T-2)=(#T@)V%P<&QI8V%T:6]N+W@M;&EB
M<F%R>2UF:6QE)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR7#(P7#%<,3`B72`]
M("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC
M6S!=6S1=6R)<,EPR,%PQ7#$S(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A
M8FQE+69I;&4G.PHD;6EM95]M86=I8ULP75LT75LB7#)<,C!<,5PQ-2)=(#T@
M)V%P<&QI8V%T:6]N+W@M;&EB<F%R>2UF:6QE)SL*)&UI;65?;6%G:6-;,%U;
M-%U;(EPR7#(P7#%<,38B72`]("=A<'!L:6-A=&EO;B]X+6QI8G)A<GDM9FEL
M92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPR,%PQ7#8B72`]("=A<'!L:6-A
M=&EO;B]X+6]B:F5C="UF:6QE)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR7#(P
M7#%<-R)=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE)SL*)&UI
M;65?;6%G:6-;,%U;-%U;(EPR7#(T7#%<,3`B72`]("=A<'!L:6-A=&EO;B]X
M+65X96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPR-%PQ
M7#$S(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD;6EM
M95]M86=I8ULP75LT75LB7#)<,C1<,5PQ-2)=(#T@)V%P<&QI8V%T:6]N+W@M
M;V)J96-T+69I;&4G.PHD;6EM95]M86=I8ULP75LT75LB7#)<,C1<,5PQ-B)=
M(#T@)V%P<&QI8V%T:6]N+W@M;&EB<F%R>2UF:6QE)SL*)&UI;65?;6%G:6-;
M,%U;-%U;(EPR7#(T7#%<-B)=(#T@)V%P<&QI8V%T:6]N+W@M;V)J96-T+69I
M;&4G.PHD;6EM95]M86=I8ULP75LT75LB7#)<,C1<,5PW(ET@/2`G87!P;&EC
M871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD;6EM95]M86=I8ULP75LT75LB
M7#,V,5PV,%PQ,#!<,C<S(ET@/2`G:6UA9V4O>"UC;74M<F%S=&5R)SL*)&UI
M;65?;6%G:6-;,%U;-%U;(EPS-C9<,S8V7#,V-EPS-C8B72`]("=A<'!L:6-A
M=&EO;B]X+7!C+69L;W!P>2<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,S<W7#$P
M-EPQ,3=<,3$V(ET@/2`G9F]N="]X+61O<R<["B1M:6UE7VUA9VEC6S!=6S1=
M6R)<-#%<-S1<,30Q7#$V,B)=(#T@)V%P<&QI8V%T:6]N+W@M87(G.PHD;6EM
M95]M86=I8ULP75LT75LB7#0S7#0Q7#$Q7#4W(ET@/2`G=&5X="]S8W)I<'0G
M.PHD;6EM95]M86=I8ULP75LT75LB7#0S7#0Q7#0P7#4W(ET@/2`G=&5X="]S
M8W)I<'0G.PHD;6EM95]M86=I8ULP75LT75LB7#4R7#$R,UPQ,C1<,3`Q(ET@
M/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S1=6R)<-3)<
M-3)<-3)<-#`B72`]("=T97AT+W@M<&%T8V@G.PHD;6EM95]M86=I8ULP75LT
M75LB7#4V7#$V,EPQ-#%<,S<U(ET@/2`G875D:6\O>"UP;BUR96%L875D:6\G
M.PHD;6EM95]M86=I8ULP75LT75LB7#4V7#$V,UPQ-39<,30T(ET@/2`G875D
M:6\O8F%S:6,G.PHD;6EM95]M86=I8ULP75LT75LB7#8Q7#$T,UPQ-C=<-#`B
M72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPV
M,5PR-S9<,%PP(ET@/2`G=&5X="]V;F0N;7,M=V]R9"<["B1M:6UE7VUA9VEC
M6S!=6S1=6R)<-C)<-C)<-C=<-S`B72`]("=A<'!L:6-A=&EO;B]D871A)SL*
M)&UI;65?;6%G:6-;,%U;-%U;(EPW-%PQ,35<,3$U7#$Q-")=(#T@)V%P<&QI
M8V%T:6]N+W@M9G)A;65M86ME<B<["B1M:6UE7VUA9VEC6S!=6S1=6R)<-S1<
M,30Q7#$V,EPW-B)=(#T@)V%P<&QI8V%T:6]N+W@M87(G.PHD;6EM95]M86=I
M8ULP75LS75LB7#$P,EPQ,S)<,34P(ET@/2`G87!P;&EC871I;VXO>"UB>FEP
M,B<["B1M:6UE7VUA9VEC6S!=6S-=6R)<,3`V7#$P,5PQ,C(B72`]("=A=61I
M;R]M;V0G.PHD;6EM95]M86=I8ULP75LS75LB7#$Q-5PQ,C1<,3$U(ET@/2`G
M875D:6\O>"UM=6QT:71R86-K)SL*)&UI;65?;6%G:6-;,%U;,UU;(EPQ,C-<
M,3`R7#$Q,2)=(#T@)V%U9&EO+W@M<V)I)SL*)&UI;65?;6%G:6-;,%U;,UU;
M(EPQ,C1<,3$W7#$P,R)=(#T@)V%U9&EO+W@M=&]C)SL*)&UI;65?;6%G:6-;
M,%U;,UU;(EPQ,EPQ,#=<,3$T(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M
M:6UE7VUA9VEC6S!=6S-=6R)<,30V7#$U-%PQ-#,B72`]("=A<'!L:6-A=&EO
M;B]X+69O;G0G.PHD;6EM95]M86=I8ULP75LS75LB7#$T-EPQ-31<,30V(ET@
M/2`G9F]N="]X+69I9VQE="<["B1M:6UE7VUA9VEC6S!=6S-=6R)<,S-<,3`U
M7#,S(ET@/2`G:6UA9V4O>"UP8VPM:'`G.PHD;6EM95]M86=I8ULP75LS75LB
M7#,S7#$T,UPS,R)=(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I
M8ULP75LS75LB7#,W-UPS-S=<,3<T(ET@/2`G87!P;&EC871I;VXO9&%T82<[
M"B1M:6UE7VUA9VEC6S!=6S-=6R)<,S<W7#,W-UPQ-S8B72`]("=A<'!L:6-A
M=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;,UU;(EPS-S=<,S<W7#$W-R)=
M(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LS75LB7#0S
M7#0Q7#0P(ET@/2`G=&5X="]S8W)I<'0G.PHD;6EM95]M86=I8ULP75LS75LB
M7#0S7#0Q7#4W(ET@/2`G=&5X="]S8W)I<'0G.PHD;6EM95]M86=I8ULP75LS
M75LB7#1<-#5<-#$B72`]("=A<'!L:6-A=&EO;B]P;W-T<V-R:7!T)SL*)&UI
M;65?;6%G:6-;,%U;,UU;(EPU-5PQ-3!<-34B72`]("=A<'!L:6-A=&EO;B]D
M871A)SL*)&UI;65?;6%G:6-;,%U;,UU;(EPV,5PQ-#-<,38W(ET@/2`G87!P
M;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S)=6R)<,%PP(ET@/2`G
M87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD;6EM95]M86=I8ULP
M75LR75LB7#$P,EPQ,34B72`]("=I;6%G92]X+6)M<"<["B1M:6UE7VUA9VEC
M6S!=6S)=6R)<,3`R7#$S,B)=(#T@)V%P<&QI8V%T:6]N+W@M8GII<"<["B1M
M:6UE7VUA9VEC6S!=6S)=6R)<,3$Q7#$P,R)=(#T@)VEM86=E+W@M:6-O)SL*
M)&UI;65?;6%G:6-;,%U;,EU;(EPQ,3)<,3$V(ET@/2`G875D:6\O>"TV-CDM
M;6]D)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPQ,35<,3,R(ET@/2`G87!P;&EC
M871I;VXO>"UM<RUD;W,M97AE8W5T86)L92<["B1M:6UE7VUA9VEC6S!=6S)=
M6R)<,3(P7#8Q(ET@/2`G:6UA9V4O>"UP;W)T86)L92UB:71M87`G.PHD;6EM
M95]M86=I8ULP75LR75LB7#$R,%PV,B)=(#T@)VEM86=E+W@M<&]R=&%B;&4M
M9W)A>6UA<"<["B1M:6UE7VUA9VEC6S!=6S)=6R)<,3(P7#8S(ET@/2`G:6UA
M9V4O>"UP;W)T86)L92UP:7AM87`G.PHD;6EM95]M86=I8ULP75LR75LB7#$R
M,%PV-")=(#T@)VEM86=E+W@M<&]R=&%B;&4M8FET;6%P)SL*)&UI;65?;6%G
M:6-;,%U;,EU;(EPQ,C!<-C4B72`]("=I;6%G92]X+7!O<G1A8FQE+6=R87EM
M87`G.PHD;6EM95]M86=I8ULP75LR75LB7#$R,%PV-B)=(#T@)VEM86=E+W@M
M<&]R=&%B;&4M<&EX;6%P)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPQ-3%<,30V
M(ET@/2`G875D:6\O>"TV-CDM;6]D)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPQ
M-C%<,S`W(ET@/2`G87!P;&EC871I;VXO>"UC<&EO)SL*)&UI;65?;6%G:6-;
M,%U;,EU;(EPQ-C9<,S<W(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE
M7VUA9VEC6S!=6S)=6R)<,5PQ,3`B72`]("=A<'!L:6-A=&EO;B]X+65X96-U
M=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S)=6R)<,5PQ,3$B72`]("=A
M<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=
M6S)=6R)<,5PQ,C0B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G
M:6-;,%U;,EU;(EPQ7#$R-2)=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L
M92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPQ7#$V,")=(#T@)V%P<&QI
M8V%T:6]N+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;,EU;
M(EPQ7#$V,2)=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE)SL*
M)&UI;65?;6%G:6-;,%U;,EU;(EPQ7#$W-2)=(#T@)V%P<&QI8V%T:6]N+W@M
M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPQ7#$W-R)=
M(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G
M:6-;,%U;,EU;(EPQ7#(P(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE
M+69I;&4G.PHD;6EM95]M86=I8ULP75LR75LB7#%<,C`S(ET@/2`G87!P;&EC
M871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD;6EM95]M86=I8ULP75LR75LB
M7#%<,C$B72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M
M:6UE7VUA9VEC6S!=6S)=6R)<,5PR,3`B72`]("=A<'!L:6-A=&EO;B]X+65X
M96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S)=6R)<,5PR,3<B72`]
M("=A<'!L:6-A=&EO;B]X+6]B:F5C="UF:6QE)SL*)&UI;65?;6%G:6-;,%U;
M,EU;(EPQ7#(R-")=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE
M)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPQ7#(R-R)=(#T@)V%P<&QI8V%T:6]N
M+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPQ7#,S
M,B)=(#T@)W@O>"UI;6%G92US9VDG.PHD;6EM95]M86=I8ULP75LR75LB7#%<
M,S8B72`]("=F;VYT+W@M=F9O;G0G.PHD;6EM95]M86=I8ULP75LR75LB7#%<
M-B)=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?
M;6%G:6-;,%U;,EU;(EPS,#=<,38Q(ET@/2`G87!P;&EC871I;VXO>"UB8W!I
M;R<["B1M:6UE7VUA9VEC6S!=6S)=6R)<,S$S7#4B72`]("=A<'!L:6-A=&EO
M;B]D871A)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPS-3)<,30P(ET@/2`G87!P
M;&EC871I;VXO>"UA<FHG.PHD;6EM95]M86=I8ULP75LR75LB7#,V-UPQ,S$B
M72`]("=F;VYT+W@M=&5X)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPS-C=<,C`S
M(ET@/2`G9F]N="]X+71E>"<["B1M:6UE7VUA9VEC6S!=6S)=6R)<,S8W7#,Q
M,B)=(#T@)V9O;G0O>"UT97@G.PHD;6EM95]M86=I8ULP75LR75LB7#,V7#$B
M72`]("=F;VYT+W@M=F9O;G0G.PHD;6EM95]M86=I8ULP75LR75LB7#,W-5PQ
M-C8B72`]("=A<'!L:6-A=&EO;B]X+6QZ:"<["B1M:6UE7VUA9VEC6S!=6S)=
M6R)<,S<V7#$V-B)=(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I
M8ULP75LR75LB7#,W-UPQ-#4B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI
M;65?;6%G:6-;,%U;,EU;(EPS-S=<,34U(ET@/2`G87!P;&EC871I;VXO9&%T
M82<["B1M:6UE7VUA9VEC6S!=6S)=6R)<,S<W7#$V-B)=(#T@)V%P<&QI8V%T
M:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LR75LB7#,W-UPS,S`B72`]("=I
M;6%G92]J<&5G)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPS-S=<,S<B72`]("=A
M<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPS-UPR,3,B
M72`]("=A<'!L:6-A=&EO;B]X+6=Z:7`G.PHD;6EM95]M86=I8ULP75LR75LB
M7#,W7#(S-2)=(#T@)V%P<&QI8V%T:6]N+V-O;7!R97-S)SL*)&UI;65?;6%G
M:6-;,%U;,EU;(EPS-UPR,S8B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI
M;65?;6%G:6-;,%U;,EU;(EPS-UPR,S<B72`]("=A<'!L:6-A=&EO;B]D871A
M)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPS-UPR-#`B72`]("=A<'!L:6-A=&EO
M;B]D871A)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPS-UPS-B)=(#T@)V%P<&QI
M8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LR75LB7#,W7#,W(ET@/2`G
M87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S)=6R)<,S=<,S<W
M(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S)=6R)<
M-#5<-#$B72`]("=A<'!L:6-A=&EO;B]P;W-T<V-R:7!T)SL*)&UI;65?;6%G
M:6-;,%U;,EU;(EPT7#8V(ET@/2`G9F]N="]L:6YU>"UP<V8G.PHD;6EM95]M
M86=I8ULP75LR75LB7#4W7#4W(ET@/2`G=&5X="]C<'`G.PHD;6EM95]M86=I
M8ULP75LR75LB7#5<,2)=(#T@)V%P<&QI8V%T:6]N+W@M;&]C86QE)SL*)&UI
M;65?;6%G:6-;,%U;,EU;(EPV7#$B72`]("=A<'!L:6-A=&EO;B]X+65X96-U
M=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S)=6R)<-EPR(ET@/2`G87!P
M;&EC871I;VXO>"UA;&%N+6%D=F5N='5R92UG86UE)SL*)&UI;65?;6%G:6-;
M,%U;,EU;(EPW7#$B72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL
M92<["B1M:6UE7VUA9VEC6S%=6S-=6R)<,3(P7#$Q-EPQ,#<B72`]("=I;6%G
M92]X+7!N9R<["B1M:6UE7VUA9VEC6S%=6S-=6R)<,3(W7#$R,%PQ,#,B72`]
M("=A<'!L:6-A=&EO;B]V;F0N=V]R9'!E<F9E8W0G.PHD;6EM95]M86=I8ULR
M75LV75LB7#4U7#$U-%PQ-3!<-C1<-C!<-34B72`]("=A<'!L:6-A=&EO;B]X
M+6QH82<["B1M:6UE7VUA9VEC6S)=6S5=6R)<-35<,34T7#$U,%PQ-#1<-34B
M72`]("=A<'!L:6-A=&EO;B]X+6QH82<["B1M:6UE7VUA9VEC6S)=6S5=6R)<
M-35<,34T7#$U,%PV,%PU-2)=(#T@)V%P<&QI8V%T:6]N+W@M;&AA)SL*)&UI
M;65?;6%G:6-;,EU;-5U;(EPU-5PQ-31<,34P7#8Q7#4U(ET@/2`G87!P;&EC
M871I;VXO>"UL:&$G.PHD;6EM95]M86=I8ULR75LU75LB7#4U7#$U-%PQ-3!<
M-C)<-34B72`]("=A<'!L:6-A=&EO;B]X+6QH82<["B1M:6UE7VUA9VEC6S)=
M6S5=6R)<-35<,34T7#$U,%PV,UPU-2)=(#T@)V%P<&QI8V%T:6]N+W@M;&AA
M)SL*)&UI;65?;6%G:6-;,EU;-5U;(EPU-5PQ-31<,34P7#8T7#4U(ET@/2`G
M87!P;&EC871I;VXO>"UL:&$G.PHD;6EM95]M86=I8ULR75LU75LB7#4U7#$U
M-%PQ-3!<-C5<-34B72`]("=A<'!L:6-A=&EO;B]X+6QH82<["B1M:6UE7VUA
M9VEC6S)=6S5=6R)<-35<,34T7#$W,EPQ-C-<-34B72`]("=A<'!L:6-A=&EO
M;B]X+6QH82<["B1M:6UE7VUA9VEC6S)=6S5=6R)<-35<,34T7#$W,EPV-%PU
M-2)=(#T@)V%P<&QI8V%T:6]N+W@M;&AA)SL*)&UI;65?;6%G:6-;,EU;-5U;
M(EPU-5PQ-31<,3<R7#8U7#4U(ET@/2`G87!P;&EC871I;VXO>"UL:&$G.PHD
M;6EM95]M86=I8ULR75LR75LB7#!<,C$B72`]("=F;VYT+W@M=&5X+71F;2<[
M"B1M:6UE7VUA9VEC6S)=6S)=6R)<,%PR,B)=(#T@)V9O;G0O>"UT97@M=&9M
M)SL*)&UI;65?;6%G:6-;-%U;-%U;(EPQ-35<,30T7#$T,5PQ-C0B72`]("=V
M:61E;R]Q=6EC:W1I;64G.PHD;6EM95]M86=I8ULT75LT75LB7#$U-5PQ-3=<
M,34W7#$V-B)=(#T@)W9I9&5O+W%U:6-K=&EM92<["B1M:6UE7VUA9VEC6S1=
M6S1=6R)<,38P7#$U,5PQ-C!<,30U(ET@/2`G87!P;&EC871I;VXO9&%T82<[
M"B1M:6UE7VUA9VEC6S1=6S1=6R)<,38P7#$V,EPQ-3=<,30V(ET@/2`G87!P
M;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S1=6S)=6R)<,C4W7#(Q(ET@
M/2`G=FED96\O9FQI)SL*)&UI;65?;6%G:6-;-%U;,EU;(EPR-3=<,C(B72`]
M("=V:61E;R]F;&,G.PHD;6EM95]M86=I8ULV75LQ.%U;(EPT-5PT,5PQ,C!<
M,3(S7#4U7#$P,5PQ-#1<,34W7#$T,EPQ-#5<,3`V7#$U-UPQ-39<,38T7#4U
M7#8Q7#4V7#8P(ET@/2`G9F]N="]T>7!E,2<["B1M:6UE7VUA9VEC6S==6S(R
M75LB7#,U-UPR,%PV,%PV,%PV,%PV,%PV,%PV,%PV,%PV,%PV,%PV,%PV,%PV
M,%PV,%PV,%PV,%PV,%PV,%PV,%PV,%PV,")=(#T@)V%P<&QI8V%T:6]N+V-O
M<F4G.PHD;6EM95]M86=I8ULW75LT75LB7#!<,3`U7#$P-UPQ,#$B72`]("=F
M;VYT+W@M9&]S)SL*)&UI;65?;6%G:6-;-UU;-%U;(EPP7#$R-EPQ,3%<,3`T
M(ET@/2`G9F]N="]X+61O<R<["B1M:6UE7VUA9VEC6SA=6S1=6R)<,C-<,3<R
M7#4S7#$P-2)=(#T@)V9O;G0O>"US=6YO<RUN97=S)SL*)&UI;65?;6%G:6-;
M.%U;-%U;(EPR,UPQ-S)<-3-<,3$P(ET@/2`G9F]N="]X+7-U;F]S+6YE=W,G
M.PHD;6EM95]M86=I8ULQ,%U;,C5=6R)<-#-<-#!<,3(T7#$U,%PQ-3%<,38S
M7#0P7#$U,5PQ-C-<-#!<,30Q7#0P7#$V,UPQ-3!<,30U7#$U-%PQ-31<-#!<
M,30Q7#$V,EPQ-#-<,34P7#$U,5PQ-C9<,30U(ET@/2`G87!P;&EC871I;VXO
M>"US:&%R)SL*)&UI;65?;6%G:6-;,C!=6S1=6R)<,3`W7#$Q,5PQ,35<,3(P
M(ET@/2`G87!P;&EC871I;VXO>"UG:6UP+6)R=7-H)SL*)&UI;65?;6%G:6-;
M,C!=6S1=6R)<,3`W7#$R,%PQ,#%<,3(T(ET@/2`G87!P;&EC871I;VXO>"UG
M:6UP+7!A='1E<FXG.PHD;6EM95]M86=I8ULR,%U;-%U;(EPS-S5<,S`T7#(T
M-UPS,S0B72`]("=A<'!L:6-A=&EO;B]X+7IO;R<["B1M:6UE7VUA9VEC6S(Q
M75LX75LB7#0Q7#$R,UPQ,#-<,3(R7#$P-5PQ,#%<,3$U7#0Q(ET@/2`G875D
M:6\O>"US=#(M;6]D)SL*)&UI;65?;6%G:6-;,C1=6S1=6R)<,%PP7#,U,EPQ
M-3,B72`]("=A<'!L:6-A=&EO;B]X+61U;7`G.PHD;6EM95]M86=I8ULR-%U;
M-%U;(EPP7#!<,S4R7#$U-")=(#T@)V%P<&QI8V%T:6]N+W@M9'5M<"<["B1M
M:6UE7VUA9VEC6S(T75LT75LB7#!<,%PS-3)<,34U(ET@/2`G87!P;&EC871I
M;VXO9&%T82<["B1M:6UE7VUA9VEC6S(T75LT75LB7#!<,%PS-3)<,34V(ET@
M/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S8U75LT75LB7#$P
M-EPQ,#9<,3$Q7#$Q-")=(#T@)V9O;G0O='1F)SL*)&UI;65?;6%G:6-;-C5=
M6S1=6R)<,3$T7#$R-UPQ,#9<,3$V(ET@/2`G9F]N="]T>7!E,2<["B1M:6UE
M7VUA9VEC6S(U-UU;.%U;(EPQ-C5<,38S7#$V-%PQ-#%<,38R7#0P7#0P7#8P
M(ET@/2`G87!P;&EC871I;VXO>"UG=&%R)SL*)&UI;65?;6%G:6-;,C4W75LV
M75LB7#$V-5PQ-C-<,38T7#$T,5PQ-C)<-C`B72`]("=A<'!L:6-A=&EO;B]X
M+71A<B<["B1M:6UE7VUA9VEC6S`W-S1=6S)=6R)<,S,R7#(W-B)=(#T@)V%P
M<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULQ,#@P75LT75LB7#$P,UPQ
M,#1<-S!<-C$B72`]("=A=61I;R]X+6]K=&%L>7IE<BUM;V0G.PHD;6EM95]M
M86=I8ULQ,#@P75LT75LB7#$P-EPQ,31<,3(T7#8T(ET@/2`G875D:6\O>"US
M=&%R=')A8VME<BUM;V0G.PHD;6EM95]M86=I8ULQ,#@P75LT75LB7#$Q-5PT
M,5PQ,3-<-#$B72`]("=A=61I;R]X+7!R;W1R86-K97(M;6]D)SL*)&UI;65?
M;6%G:6-;,3`X,%U;-%U;(EPQ,35<-39<,3$S7#4V(ET@/2`G875D:6\O>"UP
M<F]T<F%C:V5R+6UO9"<["B1M:6UE7VUA9VEC6S$P.#!=6S1=6R)<,3$W7#$Q
M,UPQ,C1<,3`Q(ET@/2`G875D:6\O>"UO:W1A;'EZ97(M;6]D)SL*)&UI;65?
M;6%G:6-;,3`X,%U;-%U;(EPV,5PV-EPQ,#-<,3$V(ET@/2`G875D:6\O>"UT
M86ME=')A8VME<BUM;V0G.PHD;6EM95]M86=I8ULQ,#@P75LT75LB7#8S7#8R
M7#$P,UPQ,38B72`]("=A=61I;R]X+71A:V5T<F%C:V5R+6UO9"<["B1M:6UE
M7VUA9VEC6S$P.#!=6S1=6R)<-C1<,3`S7#$Q,%PQ,38B72`]("=A=61I;R]X
M+69A<W1T<F%C:V5R+6UO9"<["B1M:6UE7VUA9VEC6S$P.#!=6S1=6R)<-C9<
M,3`S7#$Q,%PQ,38B72`]("=A=61I;R]X+69A<W1T<F%C:V5R+6UO9"<["B1M
M:6UE7VUA9VEC6S$P.#!=6S1=6R)<-S!<,3`S7#$Q,%PQ,38B72`]("=A=61I
M;R]X+69A<W1T<F%C:V5R+6UO9"<["B1M:6UE7VUA9VEC6S(P-#A=6S==6R)<
M,3(P7#$P,UPQ,#1<,3,W7#$Q,5PQ,C!<,3$Q(ET@/2`G>"]X+7!H;W1O+6-D
M+7!A8VLM9FEL92<["B1M:6UE7VUA9VEC6S(P.#!=6S(Y75LB7#$Q-5PQ-3%<
M,30S7#$V,EPQ-3=<,38S7#$U-UPQ-#9<,38T7#0P7#$P-5PQ-S!<,30S7#$T
M-5PQ-31<-#!<-C5<-39<-C!<-#!<,3(W7#$U-UPQ-C)<,34S7#$V,UPQ-3!<
M,30U7#$T-5PQ-C0B72`]("=A<'!L:6-A=&EO;B]V;F0N;7,M97AC96PG.PHD
M;6EM95]M86=I8ULR,#@P75LR-UU;(EPQ,35<,34Q7#$T,UPQ-C)<,34W7#$V
M,UPQ-3=<,30V7#$V-%PT,%PQ,C=<,34W7#$V,EPQ-#1<-#!<-C9<-39<-C!<
M-#!<,3`T7#$U-UPQ-#-<,38U7#$U-5PQ-#5<,34V7#$V-")=(#T@)W1E>'0O
M=FYD+FUS+7=O<F0G.PHD;6EM95]M86=I8ULR,#@P75LR-EU;(EPQ,#1<,34W
M7#$T,UPQ-C5<,34U7#$T-5PQ-39<,38T7#$U-UPT,%PQ,35<,34Q7#$T,UPQ
M-C)<,34W7#$V,UPQ-3=<,30V7#$V-%PT,%PQ,C=<,34W7#$V,EPQ-#1<-#!<
M-C8B72`]("=T97AT+W9N9"YM<RUW;W)D)SL*)&UI;65?;6%G:6-;,C$Q,EU;
M.5U;(EPQ,35<,3(S7#$R-UPQ-3=<,38R7#$T-%PQ,#1<,34W7#$T,R)=(#T@
M)W1E>'0O=FYD+FUS+7=O<F0G.PHD;6EM95]M86=I8ULR,3$T75LU75LB7#$P
M,EPQ-3%<,30V7#$T-EPV-2)=(#T@)V%P<&QI8V%T:6]N+W9N9"YM<RUE>&-E
M;"<["B1M:6UE7VUA9VEC6S0P.3A=6S==6R)<,3`T7#$Q-UPQ,C-<,3`V7#$Q
M-UPQ,39<,3(T(ET@/2`G9F]N="]X+61O<R<["B1M:6UE7VUA9VEC6S8X,34X
M-#@P75LR75LB7#(S7#$W-R)=(#T@)V%P<&QI8V%T:6]N+W@M9FEL97-Y<W1E
M;2<["B1M:6UE7VUA9VEC6S8X,34X-#@P75LR75LB7#(S7#(Q-R)=(#T@)V%P
M<&QI8V%T:6]N+W@M9FEL97-Y<W1E;2<["B1M:6UE7VUA9VEC6S8X,34X-#@P
M75LR75LB7#0T7#$U,")=(#T@)V%P<&QI8V%T:6]N+W@M9FEL97-Y<W1E;2<[
M"B1M:6UE7VUA9VEC6S8X,34X-#@P75LR75LB7#0T7#$W,")=(#T@)V%P<&QI
M8V%T:6]N+W@M9FEL97-Y<W1E;2<["B1M:6UE7VUA9VEC6S<P-S<Y.38P75LR
M75LB7#,U-UPQ,C,B72`]("=A<'!L:6-A=&EO;B]X+6QI;G5X+65X=#)F<R<[
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0`````
M````````````````````````````````````````````````````````````
M`````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M,#`P(#$P-3$U-#,S-S,W(#`R,#(Q-P`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O5&5X="]&:6QT97(`````````````````````````````````
M````````````````````````````````````````,#`P-S4U(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S<@,#(Q-#0T`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]497AT+T9I;'1E<B]H:6=H;&EG
M:'1Q=6]T97,N<&AP````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q-C$W,2`Q,#4Q-30S
M,S<S-R`P,C4T-3(`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4N<&AP)SL*<F5Q
M=6ER95]O;F-E("=(;W)D92]3=')I;F<N<&AP)SL*"B\J*@H@*B!(:6=H;&EG
M:'1S('%U;W1E9"!M97-S86=E<R!W:71H(&1I9F9E<F5N="!C;VQO<G,@9F]R
M('1H92!D:69F97)E;G0@<75O=&EN9PH@*B!L979E;',N"B`J"B`J($-34R!C
M;&%S<R!N86UE<R!C86QL960@(G%U;W1E9#$B("XN+B`B<75O=&5D>R1C<W-,
M979E;'-](B!M=7-T(&)E('!R97-E;G0N"B`J(%1H92!T97AT('1O(&)E('!A
M<W-E9"!I;B!M=7-T(&AA=F4@86QR96%D>2!B965N('!A<W-E9"!T:')O=6=H
M"B`J(&AT;6QS<&5C:6%L8VAA<G,H*2X*("H*("H@4&%R86UE=&5R<SH*("H@
M/'!R93X*("H@)V-I=&5B;&]C:R<@("TM($1I<W!L87D@8VET92!B;&]C:W,_
M($1E9F%U;'1S('1O('1R=64N"B`J("=C<W-,979E;',G("`M+2!.=6UB97(@
M;V8@9&5F:6YE9"!#4U,@8VQA<W,@;F%M97,N($1E9F%U;'1S('1O(#4N"B`J
M("=H:61E0FQO8VMS)R`M+2!(:61E('%U;W1E9"!T97AT(&)L;V-K<R!B>2!D
M969A=6QT/R!$969A=6QT<R!T;R!F86QS92X*("H@/"]P<F4^"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q
M=6]T97,N<&AP+'8@,2XV+C@N,38@,C`P-B\P."\Q-B`Q-CHU-CHP,"!S;'5S
M87)Z($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@36EC:&%E;"!3
M;'5S87)Z(#QS;'5S87)Z0&-U<F5C86YT:2YO<F<^"B`J($-O<'ER:6=H="`R
M,#`T+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R
M>D!C=7)E8V%N=&DN;W)G/@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ
M86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA
M9V4@2&]R9&5?5&5X=`H@*B\*8VQA<W,@5&5X=%]&:6QT97)?:&EG:&QI9VAT
M<75O=&5S(&5X=&5N9',@5&5X=%]&:6QT97(@>PH*("`@("\J*@H@("`@("H@
M1FEL=&5R('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A>2@*("`@("`@("`G8VET
M96)L;V-K)R`]/B!T<G5E+`H@("`@("`@("=C<W-,979E;',G(#T^(#4L"B`@
M("`@("`@)VAI9&5";&]C:W,G(#T^(&9A;'-E"B`@("`I.PH*("`@("\J*@H@
M("`@("H@17AE8W5T97,@86YY(&-O9&4@;F5C97-S87)A>2!B969O<F4@87!P
M;'EI;F<@=&AE(&9I;'1E<B!P871T97)N<RX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1T97AT("!4:&4@=&5X="!B969O<F4@=&AE(&9I;'1E<FEN
M9RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&UO9&EF:65D
M('1E>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N('!R95!R;V-E<W,H)'1E>'0I
M"B`@("!["B`@("`@("`@+RH@5&%C:R!A(&YE=VQI;F4@;VYT;R!T:&4@8F5G
M:6YN:6YG(&]F('1H92!S=')I;F<@<V\@=&AA="!W90H@("`@("`@("`J(&-O
M<G)E8W1L>2!H:6=H;&EG:'0@=VAE;B!T:&4@9FER<W0@8VAA<F%C=&5R(&EN
M('1H92!S=')I;F<@:7,@80H@("`@("`@("`J('%U;W1E(&-H87)A8W1E<BX@
M*B\*("`@("`@("!R971U<FX@(EQN)'1E>'0B.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!A(&AA<V@@=VET:"!R97!L86-E('!A='1E<FYS+@H@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@(%!A='1E<FYS(&AA<V@N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A='1E<FYS*"D*("`@('L*("`@("`@
M("`O*B!296UO=F4@97AT<F$@<W!A8V5S(&)E9F]R92!Q=6]T960@=&5X="!A
M<R!T:&4@0U-3(&9O<FUA='1I;F<@=VEL;`H@("`@("`@("`J(&%U=&]M871I
M8V%L;'D@861D(&$@8FET(&]F('-P86-E(&9O<B!U<RX@*B\*("`@("`@("!I
M9B`H)'1H:7,M/E]P87)A;7-;)V-I=&5B;&]C:R==*2!["B`@("`@("`@("`@
M(')E='5R;B!A<G)A>2@G<F5G97AP)R`]/B!A<G)A>2@B+SQB<B!<+SY<<RI<
M;EQS*CQB<B!<+SY<<RI<;EQS*B@H)F=T.UQS/RDK*2]M(B`]/B`B/&)R("\^
M7&Y<7#$B*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@87)R87DH*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($5X96-U=&5S(&%N>2!C;V1E(&YE8V5S
M<V%R87D@869T97(@87!P;'EI;F<@=&AE(&9I;'1E<B!P871T97)N<RX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("!4:&4@=&5X="!A9G1E
M<B!T:&4@9FEL=&5R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@;6]D:69I960@=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@<&]S
M=%!R;V-E<W,H)'1E>'0I"B`@("!["B`@("`@("`@+RH@27,@=&AE<F4@82!B
M;&%N:R!L:6YE*',I(&)E9F]R92!T:&4@8W5R<F5N="!L:6YE/R`J+PH@("`@
M("`@("1B;&%N:VQI;F4@/2!F86QS93L*"B`@("`@("`@+RH@57-E(&-I=&4@
M8FQO8VMS('1O(&1I<W!L87D@=&AE(&1I9F9E<F5N="!Q=6]T:6YG(&QE=F5L
M<S\@*B\*("`@("`@("`D8V(@/2`D=&AI<RT^7W!A<F%M<ULG8VET96)L;V-K
M)UT["@H@("`@("`@("\J($-I=&4@;&5V96P@8F5F;W)E('!A<G-I;F<@=&AE
M(&-U<G)E;G0@;&EN92X@*B\*("`@("`@("`D<6QE=F5L(#T@,#L*"B`@("`@
M("`@+RH@1V5N97)A=&5D(&]U='!U="X@*B\*("`@("`@("`D=&5X=%]O=70@
M/2`G)SL*"B`@("`@("`@+RH@061D('-H;W<O:&ED92!T;V=G;&5S(&9O<B!W
M:&]L92!Q=6]T92!B;&]C:W,N("HO"B`@("`@("`@)'1E>'0@/2!P<F5G7W)E
M<&QA8V5?8V%L;&)A8VLH)R\H7&XI*"@@*B@F9W0[7',_*2LH/R$@/R9G=#LI
M+BH_*2A<;GPD*2@_(2`J*"9G=#L@/RDK*2DO<R<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)'1H:7,L("=?861D475O
M=&54;V=G;&5S)RDL("1T97AT*3L*"B`@("`@("`@+RH@4&%R<V4@=&5X="!L
M:6YE(&)Y(&QI;F4N("HO"B`@("`@("`@9F]R96%C:"`H97AP;&]D92@B7&XB
M+"`D=&5X="D@87,@)&QI;F4I('L*("`@("`@("`@("`@+RH@0VET92!L979E
M;"!O9B!C=7)R96YT(&QI;F4N("HO"B`@("`@("`@("`@("1C;&5V96P@/2`D
M8VQO<V5L979E;"`](#`["B`@("`@("`@("`@("1M871C:&5S(#T@87)R87DH
M*3L*("`@("`@("`@("`@+RH@1&\@=V4@:&%V92!A(&-I=&%T:6]N(&QI;F4_
M("HO"B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7EQS*B@H)F=T.UQS
M/RDK*2]M)RP@)&QI;F4L("1M871C:&5S*2D@>PH@("`@("`@("`@("`@("`@
M+RH@0V]U;G0@;G5M8F5R(&]F(#X@8VAA<F%C=&5R<R`]/B!C:71E(&QE=F5L
M("HO"B`@("`@("`@("`@("`@("`D8VQE=F5L(#T@)&-L;W-E;&5V96P@/2!C
M;W5N="AP<F5G7W-P;&ET*"<O)F=T.UQS/R\G+"`D;6%T8VAE<ULQ72DI("T@
M,3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1C8B`F)B!I<W-E
M="@D;6%T8VAE<ULQ72DI('L*("`@("`@("`@("`@("`@("\J(%-T<FEP(&%L
M;"`^(&-H87)A8W1E<G,N("HO"B`@("`@("`@("`@("`@("`D;&EN92`]('-U
M8G-T<B@D;&EN92P@4W1R:6YG.CIL96YG=&@H)&UA=&-H97-;,5TI*3L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@+RH@27,@=&AI<R!C:71E(&QE=F5L
M(&QO=V5R('1H86X@=&AE(&-U<G)E;G0@;&5V96P_("HO"B`@("`@("`@("`@
M(&EF("@D8VQE=F5L(#P@)'%L979E;"D@>PH@("`@("`@("`@("`@("`@+RH@
M4W1R:7`@;6]R92!T:&%N(&]N92!B;&%N:R!L:6YE(&EN(&9R;VYT(&]F('1H
M92!C:71E"B`@("`@("`@("`@("`@("`@*B!B;&]C:W,N("HO"B`@("`@("`@
M("`@("`@("!I9B`H)&)L86YK;&EN92D@>PH@("`@("`@("`@("`@("`@("`@
M('=H:6QE("@H)&)R7W-T<B`]('-U8G-T<B@D=&5X=%]O=70L("TW*2D@/3T@
M(CQB<B`O/EQN(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&5X=%]O
M=70@/2!S=6)S='(H)'1E>'1?;W5T+"`P+"`M-RD["B`@("`@("`@("`@("`@
M("`@("`@?3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("\J
M($%D9"!Q=6]T92!B;&]C:R!E;F0@=&%G<R!F;W(@96%C:"!C:71E(&QE=F5L
M+B`J+PH@("`@("`@("`@("`@("`@9F]R("@D:2`]("1C;&5V96P[("1I(#P@
M)'%L979E;#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("1T97AT7V]U
M="`N/2`H)&-B*2`_("<\+V1I=CXG(#H@)SPO9F]N=#XG.PH@("`@("`@("`@
M("`@("`@("`@("TM)&-L;W-E;&5V96P["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`O*B!3=')I<"!T<F%I;&EN9R!L:6YE(&)R96%K(&EF
M('5S:6YG(&-I=&4@8FQO8VMS+"!W92!A;')E861Y"B`@("`@("`@("`@("`@
M("`@*B!H879E(&$@9&EV('1A9RX@*B\*("`@("`@("`@("`@("`@(&EF("@D
M8V(@)B8@<')E9U]M871C:"@G+UP\8G(@7"\^)"\G+"`D;&EN92DI('L*("`@
M("`@("`@("`@("`@("`@("`D;&EN92`]('-U8G-T<B@D;&EN92P@,"P@+38I
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`O*B!)<R!T:&ES(&-I
M=&4@;&5V96P@:&EG:&5R('1H86X@=&AE(&-U<G)E;G0@;&5V96P_("HO"B`@
M("`@("`@("`@('T@96QS96EF("@D8VQE=F5L(#X@)'%L979E;"D@>PH@("`@
M("`@("`@("`@("`@+RH@4W1R:7`@;6]R92!T:&%N(&]N92!B;&%N:R!L:6YE
M(&EN(&9R;VYT(&]F('1H92!C:71E"B`@("`@("`@("`@("`@("`@*B!B;&]C
M:W,N("HO"B`@("`@("`@("`@("`@("!I9B`H)&)L86YK;&EN92D@>PH@("`@
M("`@("`@("`@("`@("`@('=H:6QE("@H)&)R7W-T<B`]('-U8G-T<B@D=&5X
M=%]O=70L("TW*2D@/3T@(CQB<B`O/EQN(BD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D=&5X=%]O=70@/2!S=6)S='(H)'1E>'1?;W5T+"`P+"`M-RD[
M"B`@("`@("`@("`@("`@("`@("`@?3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&9O<B`H)&D@/2`D<6QE=F5L.R`D:2`\("1C;&5V96P[
M("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`O*B!!9&0@<75O=&4@8FQO
M8VL@<W1A<G0@=&%G<R!F;W(@96%C:"!C:71E(&QE=F5L+B`J+PH@("`@("`@
M("`@("`@("`@("`@("1T97AT7V]U="`N/2`H)&-B*2`_("<\9&EV(&-L87-S
M/2)C:71A=&EO;B`G(#H@)SQF;VYT(&-L87-S/2(G.PH@("`@("`@("`@("`@
M("`@("`@("1T97AT7V]U="`N/2`G<75O=&5D)R`N("@H)&D@)2`D=&AI<RT^
M7W!A<F%M<ULG8W-S3&5V96QS)UTI("L@,2D@+B`G(CXG.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!#;W5N="!B
M;&%N:R!L:6YE<RX@*B\*("`@("`@("`@("`@)&)L86YK;&EN92`]("@D;&EN
M92`]/2`G/&)R("\^)RD["@H@("`@("`@("`@("`D=&5X=%]O=70@+CT@)&QI
M;F4@+B`B7&XB.PH@("`@("`@("`@("`D<6QE=F5L(#T@)&-L979E;#L*("`@
M("`@("!]"@H@("`@("`@("\J($UA:V4@<W5R92!A;&P@9&EV+V9O;G0@=&%G
M<R!A<F4@8VQO<V5D+B`J+PH@("`@("`@(&EF("@D8VQO<V5L979E;"`^(#`I
M('L*("`@("`@("`@("`@)'1E>'1?;W5T(#T@<')E9U]R97!L86-E*"<O/%PO
M9&EV/B0O)RP@<W1R7W)E<&5A="@H)&-B*2`_("<\+V1I=CXG(#H@)SPO9F]N
M=#XG+"`D8VQO<V5L979E;"D@+B`G/"]D:78^)RP@)'1E>'1?;W5T*3L*("`@
M("`@("!]"@H@("`@("`@("\J(%)E;6]V92!T:&4@;&5A9&EN9R!N97=L:6YE
M('=E(&%D9&5D(&%B;W9E+"!I9B!I="=S('-T:6QL('1H97)E+B`J+PH@("`@
M("`@(&EF("@D=&5X=%]O=71;,%T@/3T@(EQN(BD@>PH@("`@("`@("`@("`D
M=&5X=%]O=70@/2!S=6)S='(H)'1E>'1?;W5T+"`Q*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D=&5X=%]O=70["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!9&1S(&QI;FMS('1O('-H;W<@86YD(&AI9&4@<75O=&5D(&)L;V-K<RP@
M:&ED:6YG('1H96T@8GD@9&5F875L="!I9@H@("`@("H@=&AE("=H:61E0FQO
M8VMS)R!P87)A;65T97(@:7,@=')U92X*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&UA=&-H97,@
M(%1H92!M871C:&5S(&9R;VT@=&AE(')E9V5X<"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@7V%D9%%U;W1E5&]G9VQE<R@D;6%T8VAE<RD*("`@('L*("`@("`@
M("!S=&%T:6,@)&D@/2`P.PH*("`@("`@("`O*B!$;VXG="!T;V=G;&4@<VUA
M;&P@8FQO8VMS.R!D;V5S;B=T('!R;W9I9&4@82!522!B96YE9FET(&%N9"!L
M;V]K<PH@("`@("`@("`J(&%N;F]Y:6YG+B`J+PH@("`@("`@("1L:6YE<R`]
M('-U8G-T<E]C;W5N="@D;6%T8VAE<ULP72P@(EQN(BD["B`@("`@("`@:68@
M*"1L:6YE<R`\(#@I('L*("`@("`@("`@("`@<F5T=7)N("1M871C:&5S6S!=
M.PH@("`@("`@('T*"B`@("`@("`@2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)VAI
M9&5A8FQE+FIS)RP@)VAO<F1E)RP@=')U92D["B`@("`@("`@2&]R9&4Z.F%D
M9%-C<FEP=$9I;&4H)W%U;W1E0FQO8VMS+FIS)RP@)VAO<F1E)RD["@H@("`@
M("`@("1T97AT(#T@)R<["B`@("`@("`@:68@*"1T:&ES+3Y?<&%R86US6R=C
M:71E8FQO8VLG72D@>PH@("`@("`@("`@("`D=&5X="`]("<\8G(@+SXG.PH@
M("`@("`@('T["B`@("`@("`@)'1E>'0@+CT@)SQD:78@:60](G%T7R<@+B`D
M:2`N("<B/B<@+@H@("`@("`@("`@("!(;W)D93HZ;&EN:R@G(R<L("<G+"`G
M=VED9V5T('1O9V=L97%U;W1E)RP@)R<L("=T;V=G;&51=6]T94)L;V-K*%PG
M)R`N("1I("X@)UPG+"!<)R<@+B`D;&EN97,@+B`G7"<I.R!R971U<FX@9F%L
M<V4[)RP@)R<L("<G+"!A<G)A>2@G<W1Y;&4G(#T^("=F;VYT+7-I>F4Z-S`E
M)RDI("X*("`@("`@("`@("`@*"1T:&ES+3Y?<&%R86US6R=H:61E0FQO8VMS
M)UT@/R!S<')I;G1F*%\H(EM3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=
M(BDL("1L:6YE<RD@.B!?*");2&ED92!1=6]T960@5&5X=%TB*2D@+@H@("`@
M("`@("`@("`G/"]A/CPO9&EV/CQD:78@:60](G%B7R<@+B`D:2`N("<B)R`N
M("@D=&AI<RT^7W!A<F%M<ULG:&ED94)L;V-K<R==(#\@)R!S='EL93TB9&ES
M<&QA>3IN;VYE.R(G(#H@)R<I("X@)SXG("X@)&UA=&-H97-;,%T@+B`G/"]D
M:78^)SL*"B`@("`@("`@)&DK*SL*"B`@("`@("`@<F5T=7)N("1T97AT.PH@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R+WAS<RYP
M:'``````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$W-C(U(#$P-3$U
M-#,S-S,W(#`R,S`V-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@5&AI<R!F:6QT97(@871T96UP=',@
M=&\@;6%K92!(5$U,('-A9F4@9F]R('9I97=I;F<N($E4($E3($Y/5"!015)&
M14-4+B!)9@H@*B!Y;W4@96YA8FQE($A434P@=FEE=VEN9RP@>6]U(&%R92!O
M<&5N:6YG(&$@<V5C=7)I='D@:&]L92X@5VET:"!T:&4@8W5R<F5N=`H@*B!S
M=&%T92!O9B!T:&4@=V5B+"!)(&)E;&EE=F4@=&AA="!T:&4@8F5S="!W92!C
M86X@9&\@:7,@=&\@;6%K92!S=7)E('1H870*("H@<&5O<&QE("I+3D]7*B!(
M5$U,(&ES(&$@<V5C=7)I='D@:&]L92P@8VQE86X@=7`@=VAA="!W92!C86XL
M(&%N9"!L96%V92!I=`H@*B!A="!T:&%T+@H@*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]497AT7T9I;'1E<B]&:6QT97(O>'-S+G!H<"QV(#$N,2XR+C,@,C`P
M-B\P,B\P.2`Q-CHT,#HT,2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P
M,#0M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("H*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E
M+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXQ"B`J($!P86-K86=E($AO<F1E
M7U1E>'0*("HO"F-L87-S(%1E>'1?1FEL=&5R7WAS<R!E>'1E;F1S(%1E>'1?
M1FEL=&5R('L*"B`@("`O*BH*("`@("`J($9I;'1E<B!P87)A;65T97)S+@H@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<&%R
M86US(#T@87)R87DH)V)O9'E?;VYL>2<@/3X@=')U92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("=R97!L86-E)R`]/B`G6%-30VQE86YE9"<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`G<W1R:7!?<W1Y;&5S)R`]/B!T<G5E*3L*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!H87-H('=I=&@@<F5P;&%C92!P
M871T97)N<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!0871T97)N
M<R!H87-H+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9710871T97)N<R@I"B`@
M("!["B`@("`@("`@)'!A='1E<FYS(#T@87)R87DH*3L*"B`@("`@("`@+RH@
M4F5M;W9E<R!(5$U,(&-O;6UE;G1S("AI;F-L=61I;F<@<V]M92!S8W)I<'1S
M("8@<W1Y;&5S*2X@*B\*("`@("`@("!I9B`H)'1H:7,M/E]P87)A;7-;)W-T
M<FEP7W-T>6QE<R==*2!["B`@("`@("`@("`@("1P871T97)N<ULG+SPA+2TN
M*C\M+3XO<R==(#T@)R<["B`@("`@("`@?0H*("`@("`@("`O*B!#:&%N9V4@
M<W!A8V4@96YT:71I97,@=&\@<W!A8V4@8VAA<F%C=&5R<RX@*B\*("`@("`@
M("`D<&%T=&5R;G-;)R\F(RAX,"HR,'PP*C,R*3L_+VDG72`]("<@)SL*"B`@
M("`@("`@+RH@3G5K92!N;VXM<')I;G1A8FQE(&-H87)A8W1E<G,@*&$@<&QA
M>2!I;B!T:')E92!A8W1S*2X@*B\*"B`@("`@("`@+RH@4G5L92`Q*2X@4F5M
M;W9E(&%L;"!C;VYT<F]L(&-H87)A8W1E<G,N("HO"B`@("`@("`@+R\D9&%T
M82`]('!R96=?<F5P;&%C92@G+UM<>#`P+5QX,#A<>#!E+5QX,69=+R<L("<G
M+"`D9&%T82D["@H@("`@("`@("\J(%)U;&4@,2DN($EF('=E(&AA=F4@82!S
M96UI8V]L;VXL(&ET(&ES(&1E=&5R;6EN:7-T:6-A;&QY(&1E=&5C=&%B;&4*
M("`@("`@("`@*B!A;F0@9FEX86)L92P@=VET:&]U="!I;G1R;V1U8VEN9R!C
M;VQL871E<F%L(&1A;6%G92X@*B\*("`@("`@("`D<&%T=&5R;G-;)R\F(W@_
M,"HH6SE!+41=?#%;,"TS72D[+VDG72`]("<F;F)S<#LG.PH*("`@("`@("`O
M*B!2=6QE(#(I+B!(97@@;G5M8F5R<R`H=7-U86QL>2!H879I;F<@86X@>"!P
M<F5F:7@I(&%R92!A;'-O"B`@("`@("`@("H@9&5T97)M:6YI<W1I8RP@979E
M;B!I9B!W92!D;VXG="!H879E('1H92!S96UI+B!.;W1E('1H870@<V]M90H@
M("`@("`@("`J(&)R;W=S97)S('=I;&P@=')E870@)B-A(&]R("8C,&$@87,@
M82!H97@@;G5M8F5R(&5V96X@=VET:&]U="!T:&4@>`H@("`@("`@("`J('!R
M969I>#L@:&5N8V4@+W@_+R!W:&EC:"!W:6QL(&-O=F5R('1H;W-E(&-A<V5S
M(&EN('1H:7,@<G5L92X@*B\*("`@("`@("`D<&%T=&5R;G-;)R\F(W@_,"I;
M.4$M1%TH6UXP+3E!+49=?"0I+VDG72`]("<F;F)S<%Q<,2<["@H@("`@("`@
M("\J(%)U;&4@,RDN($1E8VEM86P@;G5M8F5R<R!W:71H;W5T('1R86EL:6YG
M('-E;6EC;VQO;G,N(%1H92!P<F]B;&5M"B`@("`@("`@("H@:7,@=&AA="!S
M;VUE(&)R;W=S97)S('=I;&P@:6YT97)P<F5T("8C,3!A(&%S(")<;F$B+"!S
M;VUE(&%S"B`@("`@("`@("H@(B8C>#$P82(@<V\@=V4@:&%V92!T;R!C;&5A
M;B!T:&4@)B,Q,"!T;R!B92!S869E(&9O<B!T:&4@(EQN82(@8V%S90H@("`@
M("`@("`J(&%T('1H92!E>'!E;G-E(&]F(&UA;F=L:6YG(&$@=F%L:60@96YT
M:71Y(&EN(&]T:&5R(&-A<V5S+B`H4V]L=71I;VX*("`@("`@("`@*B!F;W(@
M=F%L:60@2%1-3"!A=71H;W)S.B!A;'=A>7,@=7-E('1H92!S96UI8V]L;VXN
M*2`J+PH@("`@("`@("1P871T97)N<ULG+R8C,"HH.7PQ6S`M,UTI*%M>,"TY
M77PD*2]I)UT@/2`G)FYB<W!<7#(G.PH*("`@("`@("`O*B!296UO=F4@;W9E
M<FQY(&QO;F<@;G5M97)I8R!E;G1I=&EE<RX@*B\*("`@("`@("`D<&%T=&5R
M;G-;)R\F(W@_,"I;,"TY02U&77LV+'T[/R]I)UT@/2`G)FYB<W`[)SL*"B`@
M("`@("`@+RH@4F5M;W9E(&5V97)Y=&AI;F<@;W5T<VED92!O9B!A;F0@:6YC
M;'5D:6YG('1H92`\8F]D>3X@=&%G+B`J+PH@("`@("`@(&EF("@D=&AI<RT^
M7W!A<F%M<ULG8F]D>5]O;FQY)UTI('L*("`@("`@("`@("`@)'!A='1E<FYS
M6R<O+BH\8F]D>5M>/ETJ/B]S:2==(#T@)R<["B`@("`@("`@("`@("1P871T
M97)N<ULG+SQ<+V)O9'D^+BHO<VDG72`]("<G.PH@("`@("`@('T*"B`@("`@
M("`@+RH@1V5T(&%L;"!A='1R:6)U=&4](FIA=F%S8W)I<'0Z9F]O*"DB('1A
M9W,N(%1H:7,@:7,@97-S96YT:6%L;'D@=&AE"B`@("`@("`@("H@<F5G97@@
M+R@]?'5R;%PH*2@B/RE;7CY=*G-C<FEP=#HO(&)U="!E>'!A;F1E9"!T;R!C
M871C:"!C86UO=69L86=E"B`@("`@("`@("H@=VET:"!S<&%C97,@86YD(&5N
M=&ET:65S+B`J+PH@("`@("`@("1P<F5G(#T@)R\H*"8C,"HV,3L_?"8C>#`J
M,T0[/WP]*7PG("X*("`@("`@("`@("`@("`@("<H*'5\)B,P*C@U.S]\)B-X
M,"HU-3L_?"8C,"HQ,3<[/WPF(W@P*C<U.S\I7',J)R`N"B`@("`@("`@("`@
M("`@("`G*')\)B,P*C@R.S]\)B-X,"HU,CL_?"8C,"HQ,30[/WPF(W@P*C<R
M.S\I7',J)R`N"B`@("`@("`@("`@("`@("`G*&Q\)B,P*C<V.S]\)B-X,"HT
M8SL_?"8C,"HQ,#@[/WPF(W@P*C9C.S\I7',J)R`N"B`@("`@("`@("`@("`@
M("`G*%PH*2DI7',J)R`N"B`@("`@("`@("`@("`@("`G*"8C,"HS-#L_?"8C
M>#`J,C([/WPB?"8C,"HS.3L_?"8C>#`J,C<[/WQ<)RD_)R`N"B`@("`@("`@
M("`@("`@("`G6UX^72I<<RHG("X*("`@("`@("`@("`@("`@("<H<WPF(S`J
M.#,[/WPF(W@P*C4S.S]\)B,P*C$Q-3L_?"8C>#`J-S,[/RE<<RHG("X*("`@
M("`@("`@("`@("`@("<H8WPF(S`J-C<[/WPF(W@P*C0S.S]\)B,P*CDY.S]\
M)B-X,"HV,SL_*5QS*B<@+@H@("`@("`@("`@("`@("`@)RAR?"8C,"HX,CL_
M?"8C>#`J-3([/WPF(S`J,3$T.S]\)B-X,"HW,CL_*5QS*B<@+@H@("`@("`@
M("`@("`@("`@)RAI?"8C,"HW,SL_?"8C>#`J-#D[/WPF(S`J,3`U.S]\)B-X
M,"HV.3L_*5QS*B<@+@H@("`@("`@("`@("`@("`@)RAP?"8C,"HX,#L_?"8C
M>#`J-3`[/WPF(S`J,3$R.S]\)B-X,"HW,#L_*5QS*B<@+@H@("`@("`@("`@
M("`@("`@)RAT?"8C,"HX-#L_?"8C>#`J-30[/WPF(S`J,3$V.S]\)B-X,"HW
M-#L_*5QS*B<@+@H@("`@("`@("`@("`@("`@)R@Z?"8C,"HU.#L_?"8C>#`J
M,V$[/RDO:2<["B`@("`@("`@)'!A='1E<FYS6R1P<F5G72`]("=<,5PX)R`N
M("1T:&ES+3Y?<&%R86US6R=R97!L86-E)UT["@H@("`@("`@("\J($=E="!A
M;&P@;VX\9F]O/CTB8F%R*"DB+B!.159%4B!A;&QO=R!T:&5S92X@*B\*("`@
M("`@("`D<&%T=&5R;G-;)R\H6UQS(EPG72LG("X*("`@("`@("`@("`@("`@
M("`@)RAO?"8C,"HW.3L_?"8C,"HT9CL_?"8C,"HQ,3$[/WPF(S`J-F8[/RDG
M("X*("`@("`@("`@("`@("`@("`@)RAN?"8C,"HW.#L_?"8C,"HT93L_?"8C
M,"HQ,3`[/WPF(S`J-F4[/RDG("X*("`@("`@("`@("`@("`@("`@)UQW*RE<
M<RH]+VDG72`]("=<,2<@+B`D=&AI<RT^7W!A<F%M<ULG<F5P;&%C92==("X@
M)STG.PH*("`@("`@("`O*B!296UO=F4@86QL('-C<FEP=',@<VEN8V4@=&AE
M>2!M:6=H="!I;G1R;V1U8V4@9V%R8F%G92!I9B!T:&5Y(&%R90H@("`@("`@
M("`J(&YO="!Q=6]T960@<')O<&5R;'DN("HO"B`@("`@("`@)'!A='1E<FYS
M6R=\/'-C<FEP=%M>/ETJ/BXJ/SPO<V-R:7!T/GQI<R==(#T@)SPG("X@)'1H
M:7,M/E]P87)A;7-;)W)E<&QA8V4G72`N("=?<V-R:7!T("\^)SL*"B`@("`@
M("`@+RH@1V5T(&%L;"!T86=S('1H870@;6EG:'0@8V%U<V4@=')O=6)L92`M
M(#QO8FIE8W0^+"`\96UB960^+"`\8F%S93XL"B`@("`@("`@("H@971C+B!-
M971A(')E9G)E<VAE<R!A;F0@:69R86UE<RP@=&]O+B`J+PH@("`@("`@("1M
M86QI8VEO=7,@/2!A<G)A>2@*("`@("`@("`@("`@)R\\*%M>/F$M>ETJ*2<@
M+@H@("`@("`@("`@("`G*'-\)B,P*C@S.S]\)B-X,"HU,SL_?"8C,"HQ,34[
M/WPF(W@P*C<S.S\I7',J)R`N"B`@("`@("`@("`@("<H8WPF(S`J-C<[/WPF
M(W@P*C0S.S]\)B,P*CDY.S]\)B-X,"HV,SL_*5QS*B<@+@H@("`@("`@("`@
M("`G*')\)B,P*C@R.S]\)B-X,"HU,CL_?"8C,"HQ,30[/WPF(W@P*C<R.S\I
M7',J)R`N"B`@("`@("`@("`@("<H:7PF(S`J-S,[/WPF(W@P*C0Y.S]\)B,P
M*C$P-3L_?"8C>#`J-CD[/RE<<RHG("X*("`@("`@("`@("`@)RAP?"8C,"HX
M,#L_?"8C>#`J-3`[/WPF(S`J,3$R.S]\)B-X,"HW,#L_*5QS*B<@+@H@("`@
M("`@("`@("`G*'1\)B,P*C@T.S]\)B-X,"HU-#L_?"8C,"HQ,38[/WPF(W@P
M*C<T.S\I7',J+VDG+`H*("`@("`@("`@("`@)R\\*%M>/F$M>ETJ*2<@+@H@
M("`@("`@("`@("`G*&5\)B,P*C8Y.S]\)B,P*C0U.S]\)B,P*C$P,3L_?"8C
M,"HV-3L_*5QS*B<@+@H@("`@("`@("`@("`G*&U\)B,P*C<W.S]\)B,P*C1D
M.S]\)B,P*C$P.3L_?"8C,"HV9#L_*5QS*B<@+@H@("`@("`@("`@("`G*&)\
M)B,P*C8V.S]\)B,P*C0R.S]\)B,P*CDX.S]\)B,P*C8R.S\I7',J)R`N"B`@
M("`@("`@("`@("<H97PF(S`J-CD[/WPF(S`J-#4[/WPF(S`J,3`Q.S]\)B,P
M*C8U.S\I7',J)R`N"B`@("`@("`@("`@("<H9'PF(S`J-C@[/WPF(S`J-#0[
M/WPF(S`J,3`P.S]\)B,P*C8T.S\I7',J+VDG+`H*("`@("`@("`@("`@)R\\
M*%M>/F$M>ETJ*2<@+@H@("`@("`@("`@("`G*'A\)B,P*C@X.S]\)B,P*C4X
M.S]\)B,P*C$R,#L_?"8C,"HW.#L_*5QS*B<@+@H@("`@("`@("`@("`G*&U\
M)B,P*C<W.S]\)B,P*C1D.S]\)B,P*C$P.3L_?"8C,"HV9#L_*5QS*B<@+@H@
M("`@("`@("`@("`G*&Q\)B,P*C<V.S]\)B-X,"HT8SL_?"8C,"HQ,#@[/WPF
M(W@P*C9C.S\I7',J+VDG+`H*("`@("`@("`@("`@)R\\*%M>/F$M>ETJ*2<@
M+@H@("`@("`@("`@("`G*&)\)B,P*C8V.S]\)B,P*C0R.S]\)B,P*CDX.S]\
M)B,P*C8R.S\I7',J)R`N"B`@("`@("`@("`@("<H87PF(S`J-C4[/WPF(S`J
M-#$[/WPF(S`J.3<[/WPF(S`J-C$[/RE<<RHG("X*("`@("`@("`@("`@)RAS
M?"8C,"HX,SL_?"8C>#`J-3,[/WPF(S`J,3$U.S]\)B-X,"HW,SL_*5QS*B<@
M+@H@("`@("`@("`@("`G*&5\)B,P*C8Y.S]\)B,P*C0U.S]\)B,P*C$P,3L_
M?"8C,"HV-3L_*5QS*B<@+@H@("`@("`@("`@("`G6UYL:6YE72]I)RP*"B`@
M("`@("`@("`@("<O/"A;7CYA+7I=*BDG("X*("`@("`@("`@("`@)RAM?"8C
M,"HW-SL_?"8C,"HT9#L_?"8C,"HQ,#D[/WPF(S`J-F0[/RE<<RHG("X*("`@
M("`@("`@("`@)RAE?"8C,"HV.3L_?"8C,"HT-3L_?"8C,"HQ,#$[/WPF(S`J
M-C4[/RE<<RHG("X*("`@("`@("`@("`@)RAT?"8C,"HX-#L_?"8C>#`J-30[
M/WPF(S`J,3$V.S]\)B-X,"HW-#L_*5QS*B<@+@H@("`@("`@("`@("`G*&%\
M)B,P*C8U.S]\)B,P*C0Q.S]\)B,P*CDW.S]\)B,P*C8Q.S\I7',J+VDG+`H*
M("`@("`@("`@("`@)R\\*%M>/F$M>ETJ*2<@+@H@("`@("`@("`@("`G*&I\
M)B,P*C<T.S]\)B,P*C1A.S]\)B,P*C$P-CL_?"8C,"HV83L_*5QS*B<@+@H@
M("`@("`@("`@("`G*&%\)B,P*C8U.S]\)B,P*C0Q.S]\)B,P*CDW.S]\)B,P
M*C8Q.S\I7',J)R`N"B`@("`@("`@("`@("<H=GPF(S`J.#8[/WPF(S`J-38[
M/WPF(S`J,3$X.S]\)B,P*C<V.S\I7',J)R`N"B`@("`@("`@("`@("<H87PF
M(S`J-C4[/WPF(S`J-#$[/WPF(S`J.3<[/WPF(S`J-C$[/RE<<RHO:2<L"@H@
M("`@("`@("`@("`G+SPH6UX^82UZ72HI)R`N"B`@("`@("`@("`@("<H;WPF
M(S`J-SD[/WPF(S`J-&8[/WPF(S`J,3$Q.S]\)B,P*C9F.S\I7',J)R`N"B`@
M("`@("`@("`@("<H8GPF(S`J-C8[/WPF(S`J-#([/WPF(S`J.3@[/WPF(S`J
M-C([/RE<<RHG("X*("`@("`@("`@("`@)RAJ?"8C,"HW-#L_?"8C,"HT83L_
M?"8C,"HQ,#8[/WPF(S`J-F$[/RE<<RHG("X*("`@("`@("`@("`@)RAE?"8C
M,"HV.3L_?"8C,"HT-3L_?"8C,"HQ,#$[/WPF(S`J-C4[/RE<<RHG("X*("`@
M("`@("`@("`@)RAC?"8C,"HV-SL_?"8C>#`J-#,[/WPF(S`J.3D[/WPF(W@P
M*C8S.S\I7',J)R`N"B`@("`@("`@("`@("<H='PF(S`J.#0[/WPF(W@P*C4T
M.S]\)B,P*C$Q-CL_?"8C>#`J-S0[/RE<<RHO:2<L"@H@("`@("`@("`@("`G
M+SPH6UX^82UZ72HI)R`N"B`@("`@("`@("`@("<H:7PF(S`J-S,[/WPF(W@P
M*C0Y.S]\)B,P*C$P-3L_?"8C>#`J-CD[/RE<<RHG("X*("`@("`@("`@("`@
M)RAF?"8C,"HW,#L_?"8C,"HT-CL_?"8C,"HQ,#([/WPF(S`J-C8[/RE<<RHG
M("X*("`@("`@("`@("`@)RAR?"8C,"HX,CL_?"8C>#`J-3([/WPF(S`J,3$T
M.S]\)B-X,"HW,CL_*5QS*B<@+@H@("`@("`@("`@("`G*&%\)B,P*C8U.S]\
M)B,P*C0Q.S]\)B,P*CDW.S]\)B,P*C8Q.S\I7',J)R`N"B`@("`@("`@("`@
M("<H;7PF(S`J-S<[/WPF(S`J-&0[/WPF(S`J,3`Y.S]\)B,P*C9D.S\I7',J
M)R`N"B`@("`@("`@("`@("<H97PF(S`J-CD[/WPF(S`J-#4[/WPF(S`J,3`Q
M.S]\)B,P*C8U.S\I7',J+VDG*3L*"B`@("`@("`@9F]R96%C:"`H)&UA;&EC
M:6]U<R!A<R`D<&%T=&5R;BD@>PH@("`@("`@("`@("`D<&%T=&5R;G-;)'!A
M='1E<FY=(#T@)SPG("X@)'1H:7,M/E]P87)A;7-;)W)E<&QA8V4G72`N("=?
M=&%G)SL*("`@("`@("!]"@H@("`@("`@("\J($-O;6UE;G0@;W5T('-T>6QE
M+VQI;FL@=&%G<RX@*B\*("`@("`@("!I9B`H)'1H:7,M/E]P87)A;7-;)W-T
M<FEP7W-T>6QE<R==*2!["B`@("`@("`@("`@("1P871T97)N<ULG+UQS*W-T
M>6QE7',J/2]I)UT@/2`G("<@+B`D=&AI<RT^7W!A<F%M<ULG<F5P;&%C92==
M("X@)STG.PH@("`@("`@("`@("`D<&%T=&5R;G-;)WP\<W1Y;&5;7CY=*CXH
M/SI<<RH\7"$M+2DJ?&DG72`]("<\(2TM)SL*("`@("`@("`@("`@)'!A='1E
M<FYS6R=\*#\Z+2T^7',J*2H\+W-T>6QE/GQI)UT@/2`G+2T^)SL*("`@("`@
M("`@("`@)'!A='1E<FYS6R=\*#QL:6YK6UX^72H^*7QI)UT@/2`G/"$M+2`D
M,2`M+3XG.PH@("`@("`@('T*"B`@("`@("`@+RH@02!F97<@;W1H97(@;6%T
M8VAE<RX@*B\*("`@("`@("`D<&%T=&5R;G-;)WP\*%M>/ETJ*29[+BI]*%M>
M/ETJ*3Y\)UT@/2`G/"9[.WU<,SXG.PH@("`@("`@("1P871T97)N<ULG?#PH
M6UX^72HI;6]C:&$Z*%M>/ETJ*3Y\:2==(#T@)SQ<,2<@+B`D=&AI<RT^7W!A
M<F%M<ULG<F5P;&%C92==("X@)SI<,CXG.PH@("`@("`@("1P871T97)N<ULG
M?#PH6UX^72HI8FEN9&EN9SHH6UX^72HI/GQI)UT@/2`G/%PQ)R`N("1T:&ES
M+3Y?<&%R86US6R=R97!L86-E)UT@+B`G.EPR/B<["@H@("`@("`@(')E='5R
M;B!A<G)A>2@G<F5G97AP)R`]/B`D<&%T=&5R;G,I.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]497AT+T9I;'1E<B]C;&5A;F%S8VEI+G!H<```````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P-3$V,R`Q,#4Q-30S,S<S-R`P,C0S,S0`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%)E
M;6]V97,@<V]M92!C;VUM;VX@96YT:71I97,@86YD(&AI9V@M87-C:6D@;W(@
M;W1H97)W:7-E(&YO;G-T86YD87)D"B`J(&-H87)A8W1E<G,@8V]M;6]N(&EN
M('1E>'0@<&%S=&5D(&9R;VT@36EC<F]S;V9T(%=O<F0@:6YT;R!A(&)R;W=S
M97(N"B`J"B`J(%1H:7,@9G5N8W1I;VX@<VAO=6QD($Y/5"!B92!U<V5D(&]N
M(&YO;BU!4T-)22!T97AT.R!I="!M87D@86YD('!R;V)A8FQY"B`J('=I;&P@
M8G5T8VAE<B!O=&AE<B!C:&%R86-T97(@<V5T<R!I;F1E<V-R:6UI;F%T96QY
M+B`@57-E(&ET(&]N;'D@=&\@8VQE86X*("H@55,M05-#24D@*#<M8FET*2!T
M97AT('=H:6-H('EO=2!S=7-P96-T("AO<B!K;F]W*2!M87D@:&%V92!I;G9A
M;&ED(&]R"B`J(&YO;BUP<FEN=&EN9R!C:&%R86-T97)S(&EN(&ET+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O8VQE86YA
M<V-I:2YP:'`L=B`Q+C,N,BXT(#(P,#8O,#$O,#$@,C$Z,C@Z,S@@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@2F%N(%-C:&YE:61E<B`\
M:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@
M9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA
M;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E
M(#,N,`H@*B!`<&%C:V%G92!(;W)D95]497AT"B`J+PIC;&%S<R!497AT7T9I
M;'1E<E]C;&5A;F%S8VEI(&5X=&5N9',@5&5X=%]&:6QT97(@>PH*("`@("\J
M*@H@("`@("H@17AE8W5T97,@86YY(&-O9&4@;F5C97-S87)Y(&)E9F]R92!A
M<'!L>6EN9R!T:&4@9FEL=&5R('!A='1E<FYS+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'1E>'0@(%1H92!T97AT(&)E9F]R92!T:&4@9FEL=&5R
M:6YG+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;6]D:69I
M960@=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@<')E4')O8V5S<R@D=&5X
M="D*("`@('L*("`@("`@("!I9B`H<')E9U]M871C:"@G+WPH6UXC72HI(RXJ
M+R<L("1T97AT+"`D<F5G<RDI('L*("`@("`@("`@("`@)'1E>'0@/2`D<F5G
M<ULQ73L*"B`@("`@("`@("`@(&EF("@A96UP='DH)'1E>'0I*2!["B`@("`@
M("`@("`@("`@("`D=&5X="`]("1T97AT("X@(EQN(CL*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T97AT.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!A(&AA<V@@=VET:"!R97!L86-E('!A='1E
M<FYS+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%!A='1E<FYS(&AA
M<V@N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A='1E<FYS*"D*("`@('L*
M("`@("`@("`O*B!296UO=F4@8V]N=')O;"!C:&%R86-T97)S+B`J+PH@("`@
M("`@("1R96=E>'`@/2!A<G)A>2@G+UM<>#`P+5QX,69=*R\G(#T^("<G*3L*
M"B`@("`@("`@+RH@5&AE(">2)R!E;G1R>2!M87D@;&]O:R!W<F]N9RP@9&5P
M96YD:6YG(&]N('EO=7(@961I=&]R+`H@("`@("`@("`J(&)U="!I="=S(&YO
M="`M('1H870G<R!N;W0@<F5A;&QY(&$@<VEN9VQE('%U;W1E+B`J+PH@("`@
M("`@("1R97!L86-E(#T@87)R87DH8VAR*#$U,"D@/3X@)RTG+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@8VAR*#$V-RD@/3X@)RHG+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@)X&W)R`]/B`G*B<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`GA2<@/3X@)RXN+B<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`GD2<@/3X@(B<B+`H@("`@("`@("`@("`@("`@("`@("`@("`@)Y(G(#T^
M("(G(BP*("`@("`@("`@("`@("`@("`@("`@("`@(">3)R`]/B`G(B<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`GE"<@/3X@)R(G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@)Y4G(#T^("<J)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@(">6)R`]/B`G+2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`G
MER<@/3X@)RTG+`H@("`@("`@("`@("`@("`@("`@("`@("`@)Y\G(#T^("<J
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("<F(S8Q-#<Y.R<@/3X@)RXG
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@)R8C-C$U-S([)R`]/B`G*B<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`G)B,V,34Y-#LG(#T^("<J)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("<F(S8Q-C0P.R<@/3X@)RTG+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@)R8C-C$V,C,[)R`]/B`G+2<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`G)B,V,38P-SLG(#T^("<J)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("<F(S8Q-34S.R<@/3X@)RHG+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@)R8C-C$U-3@[)R`]/B`G*B<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`G)B,X,C(V.R<@/3X@)RHG+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@)R8C.38U.#LG(#T^("<^)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("D["@H@("`@("`@(')E='5R;B!A<G)A>2@G<F5G
M97AP)R`]/B`D<F5G97AP+"`G<F5P;&%C92<@/3X@)')E<&QA8V4I.PH@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R+W=O
M<F1S+G!H<```````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S,3$Q(#$P
M-3$U-#,S-S,W(#`R,S,V-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@1FEL=&5R<R!T:&4@9VEV96X@
M=&5X="!B87-E9"!O;B!T:&4@=V]R9',@9F]U;F0@:6X@82!W;W)D(&QI<W0*
M("H@9FEL92X*("H*("H@4&%R86UE=&5R<SH*("H@/'!R93X*("H@=V]R9'-?
M9FEL92`@+2T@1FEL96YA;64@8V]N=&%I;FEN9R!T:&4@=V]R9',@=&\@<F5P
M;&%C92X*("H@<F5P;&%C96UE;G0@+2T@5&AE(')E<&QA8V5M96YT('-T<FEN
M9RX@($1E9F%U;'1S('1O("(J*BHJ*B(N"B`J(#PO<')E/@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O=V]R9',N<&AP+'8@
M,2XR+C$P+C4@,C`P-B\P,2\P,2`R,3HR.#HS."!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#(P,#0M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N
M;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E
M<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P
M86-K86=E($AO<F1E7U1E>'0*("HO"F-L87-S(%1E>'1?1FEL=&5R7W=O<F1S
M(&5X=&5N9',@5&5X=%]&:6QT97(@>PH*("`@("\J*@H@("`@("H@1FEL=&5R
M('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)%]P87)A;7,@/2!A<G)A>2@G<F5P;&%C96UE;G0G(#T^("<J
M*BHJ*B<I.PH*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&AA<V@@=VET:"!R
M97!L86-E('!A='1E<FYS+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M(%!A='1E<FYS(&AA<V@N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A='1E
M<FYS*"D*("`@('L*("`@("`@("`D<F5G97AP(#T@87)R87DH*3L*"B`@("`@
M("`@:68@*$!I<U]R96%D86)L92@D=&AI<RT^7W!A<F%M<ULG=V]R9'-?9FEL
M92==*2D@>PH@("`@("`@("`@("`O*B!296%D('1H92!F:6QE(&%N9"!I=&5R
M871E('1H<F]U9V@@=&AE(&QI;F5S+B`J+PH@("`@("`@("`@("`D;&EN97,@
M/2!F:6QE*"1T:&ES+3Y?<&%R86US6R=W;W)D<U]F:6QE)UTI.PH@("`@("`@
M("`@("!F;W)E86-H("@D;&EN97,@87,@)&QI;F4I('L*("`@("`@("`@("`@
M("`@("\J(%-T<FEP('=H:71E<W!A8V4@86YD(&-O;6UE;G1S+B`J+PH@("`@
M("`@("`@("`@("`@)&QI;F4@/2!T<FEM*"1L:6YE*3L*("`@("`@("`@("`@
M("`@("1L:6YE(#T@<')E9U]R97!L86-E*"=\(RXJ)'PG+"`G)RP@)&QI;F4I
M.PH*("`@("`@("`@("`@("`@("\J($9I;'1E<B!T:&4@=&5X="X@*B\*("`@
M("`@("`@("`@("`@(&EF("@A96UP='DH)&QI;F4I*2!["B`@("`@("`@("`@
M("`@("`@("`@)')E9V5X<%LB+RA<8BA<=RHI)&QI;F5<8GQ<8B1L:6YE*%QW
M*BE<8BDO:2)=(#T@)'1H:7,M/E]P87)A;7-;)W)E<&QA8V5M96YT)UT["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!A<G)A>2@G<F5G97AP)R`]/B`D<F5G97AP*3L*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]497AT+T9I;'1E<B]R<W0N<&AP
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3<U-B`Q,#4Q-30S
M,S<S-R`P,C,P-34`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"G)E<75I<F5?;VYC92`G5&5X="]R95-4+G!H<"<[
M"G)E<75I<F5?;VYC92`G5&5X="]R95-4+T9O<FUA='1E<BYP:'`G.PH*+RHJ
M"B`J(%1H92!497AT7T9I;'1E<E]R<W0Z.B!C;&%S<R!C;VYV97)T<R!R95-T
M<G5C='5R961497AT('1O($A434PN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+U1E>'1?1FEL=&5R+T9I;'1E<B]R<W0N<&AP+'8@,2XY+C$P+C0@,C`P-B\P
M,2\P,2`R,3HR.#HS."!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M
M,C`P-B!*87-O;B!-+B!&96QI8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F%S;VX@32X@1F5L:6-E(#QJ
M9F5L:6-E0&-R;VYO<WES+F-O;3X*("H@0'!A8VMA9V4@2&]R9&5?5&5X=`H@
M*B\*8VQA<W,@5&5X=%]&:6QT97)?<G-T(&5X=&5N9',@5&5X=%]&:6QT97(@
M>PH*("`@("\J*@H@("`@("H@17AE8W5T97,@86YY(&-O9&4@;F5C97-S87)A
M>2!A9G1E<B!A<'!L>6EN9R!T:&4@9FEL=&5R"B`@("`@*B!P871T97)N<RX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("!4:&4@=&5X="!A
M9G1E<B!T:&4@9FEL=&5R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@;6]D:69I960@=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<&]S=%!R;V-E<W,H)'1E>'0I"B`@("!["B`@("`@("`@)&1O8W5M96YT(#T@
M)E1E>'1?<F535#HZ<&%R<V4H)'1E>'0I.PH@("`@("`@("1F;W)M871T97(@
M/2`F5&5X=%]R95-47T9O<FUA='1E<CHZ9F%C=&]R>2@G:'1M;"<I.PH@("`@
M("`@(')E='5R;B`D9F]R;6%T=&5R+3YF;W)M870H)&1O8W5M96YT+"!.3%,Z
M.F=E=$-H87)S970H*2D["B`@("!]"@I]"@```````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]497AT+T9I;'1E<B]S
M<&%C93)H=&UL+G!H<```````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-#(R-R`Q
M,#4Q-30S,S<S-R`P,C0S,#,`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J(%1H92!S<&%C93)H=&UL(&9I
M;'1E<B!C;VYV97)T<R!H;W)I>F]N=&%L('=H:71E<W!A8V4@=&\@2%1-3"!C
M;V1E+@H@*@H@*B!087)A;65T97)S.@H@*B`\<')E/@H@*B!E;F-O9&4@("`@
M("TM($A434P@96YC;V1E('1H92!T97AT/R`@1&5F875L=',@=&\@9F%L<V4N
M"B`J(&-H87)S970@("`@+2T@0VAA<G-E="!O9B!T:&4@=&5X="X@($1E9F%U
M;'1S('1O($E33RTX.#4Y+3$N"B`J(&5N8V]D95]A;&P@+2T@4F5P;&%C92!A
M;&P@<W!A8V5S('=I=&@@)FYB<W`[/R`@1&5F875L=',@=&\@9F%L<V4N"B`J
M(#PO<')E/@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&
M:6QT97(O<W!A8V4R:'1M;"YP:'`L=B`Q+C$N,3`N-2`R,#`V+S`Q+S`Q(#(Q
M.C(X.C,X(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,2!-871H:65U
M($%R;F]L9"`\87)N7VUA=$!C;'5B+6EN=&5R;F5T+F9R/@H@*B!#;W!Y<FEG
M:'0@,C`P-"TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9`H@*B!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`
M:&]R9&4N;W)G/@H@*B!`875T:&]R("!-871H:65U($%R;F]L9"`\87)N7VUA
M=$!C;'5B+6EN=&5R;F5T+F9R/@H@*B!`<&%C:V%G92!(;W)D95]497AT"B`J
M+PIC;&%S<R!497AT7T9I;'1E<E]S<&%C93)H=&UL(&5X=&5N9',@5&5X=%]&
M:6QT97(@>PH*("`@("\J*@H@("`@("H@1FEL=&5R('!A<F%M971E<G,N"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P87)A
M;7,@/2!A<G)A>2@G96YC;V1E)R`]/B!F86QS92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("=C:&%R<V5T)R`]/B`G25-/+3@X-3DM,2<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`G96YC;V1E7V%L;"<@/3X@9F%L<V4I.PH*("`@
M("\J*@H@("`@("H@17AE8W5T97,@86YY(&-O9&4@;F5C97-S87)Y(&)E9F]R
M92!A<'!L>6EN9R!T:&4@9FEL=&5R('!A='1E<FYS+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!T97AT(&)E9F]R92!T:&4@9FEL
M=&5R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;6]D
M:69I960@=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@<')E4')O8V5S<R@D
M=&5X="D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]P87)A;7-;)V5N8V]D
M92==*2!["B`@("`@("`@("`@("1T97AT(#T@0&AT;6QS<&5C:6%L8VAA<G,H
M)'1E>'0L($5.5%]#3TU0050L("1T:&ES+3Y?<&%R86US6R=C:&%R<V5T)UTI
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1E>'0["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS(&$@:&%S:"!W:71H(')E<&QA8V4@<&%T=&5R
M;G,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@4&%T=&5R;G,@:&%S
M:"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%T=&5R;G,H*0H@("`@>PH@
M("`@("`@("1R97!L86-E(#T@87)R87DH(EQT(B`]/B`G)FYB<W`[("9N8G-P
M.R`F;F)S<#L@)FYB<W`[("<L"B`@("`@("`@("`@("`@("`@("`@("`@("`G
M("`G(#T^("<F;F)S<#L@)RD["B`@("`@("`@<F5T=7)N(&%R<F%Y*"=R97!L
M86-E)R`]/B`D<F5P;&%C92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>&5C
M=71E<R!A;GD@8V]D92!N96-E<W-A<F%Y(&%F=&5R(&%P<&QY:6YG('1H92!F
M:6QT97(@<&%T=&5R;G,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=&5X="`@5&AE('1E>'0@869T97(@=&AE(&9I;'1E<FEN9RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&UO9&EF:65D('1E>'0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('!O<W10<F]C97-S*"1T97AT*0H@("`@>PH@("`@
M("`@("1T97AT(#T@<W1R7W)E<&QA8V4H)R`@)RP@)R`F;F)S<#LG+"`D=&5X
M="D["B`@("`@("`@:68@*"1T:&ES+3Y?<&%R86US6R=E;F-O9&5?86QL)UTI
M('L*("`@("`@("`@("`@)'1E>'0@/2!S=')?<F5P;&%C92@G("<L("<F;F)S
M<#LG+"`D=&5X="D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&5X=#L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]4
M97AT+T9I;'1E<B]S:6UP;&5M87)K=7`N<&AP````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,C$Q-2`Q,#4Q-30S,S<S-R`P,C0W-#0`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J($AI9VAL
M:6=H=',@<VEM<&QE(&UA<FMU<"!A<R!U<V5D(&EN(&5M86EL<R!O<B!U<V5N
M970@<&]S=&EN9W,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1E>'1?1FEL
M=&5R+T9I;'1E<B]S:6UP;&5M87)K=7`N<&AP+'8@,2XQ+C$P+C4@,C`P-B\P
M-R\R-"`Q-3HU-#HU-"!S;'5S87)Z($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`T+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D
M92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D
M95]497AT"B`J+PIC;&%S<R!497AT7T9I;'1E<E]S:6UP;&5M87)K=7`@97AT
M96YD<R!497AT7T9I;'1E<B!["@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@
M:&%S:"!W:71H(')E<&QA8V4@<&%T=&5R;G,N"B`@("`@*@H@("`@("H@0')E
M='5R;B!A<G)A>2`@4&%T=&5R;G,@:&%S:"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T4&%T=&5R;G,H*0H@("`@>PH@("`@("`@("1R96=E>'`@/2!A<G)A
M>2@*("`@("`@("`@("`@+R\@0F]L9"X*("`@("`@("`@("`@)R\H7GQ<<WPF
M;F)S<#M\/&)R(%PO/BDH7"I;7BI<<UTK7"HI*%QS?"9N8G-P.WP\8G)\7"XI
M+VDG(#T^("=<,3QS=')O;F<^7#(\+W-T<F]N9SY<,R<L"@H@("`@("`@("`@
M("`O+R!5;F1E<FQI;F4N"B`@("`@("`@("`@("<O*%Y\7'-\)FYB<W`[?#QB
M<B!<+SXI*%];7E]<<UTK7RDH7'-\)FYB<W`[?#QB<GQ<+BDO:2<@/3X@)UPQ
M/'4^7#(\+W4^7#,G+`H*("`@("`@("`@("`@+R\@271A;&EC+@H@("`@("`@
M("`@("`G.RA>?%QS?"9N8G-P7#M\/&)R("\^*2@O6UXO7'-=*R\I*%QS?"9N
M8G-P7#M\/&)R?%PN*3MI)R`]/B`G7#$\96T^7#(\+V5M/EPS)RD["@H@("`@
M("`@(')E='5R;B!A<G)A>2@G<F5G97AP)R`]/B`D<F5G97AP*3L*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V1I;7-I9VYA='5R
M92YP:'```````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,S8S(#$P-3$U-#,S-S,W
M(#`R-#<S,P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@1&ES<&QA>7,@;65S<V%G92!S:6=N871U<F5S
M(&UA<FME9"!B>2!A("<M+2`G(&EN('1H92!S='EL92!O9B!T:&4*("H@0U-3
M(&-L87-S(")S:6=N871U<F4B+B!#;&%S<R!N86UE<R!I;G-I9&4@=&AE('-I
M9VYA='5R92!A<F4*("H@<')E9FEX960@=VET:"`B<VEG;F%T=7)E+2(N"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]D:6US
M:6=N871U<F4N<&AP+'8@,2XR+C$P+C8@,C`P-B\P."\Q-R`Q,CHR.3HU-2!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!*86X@4V-H;F5I
M9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@
M2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7U1E>'0*("HO"F-L87-S(%1E
M>'1?1FEL=&5R7V1I;7-I9VYA='5R92!E>'1E;F1S(%1E>'1?1FEL=&5R('L*
M"B`@("`O*BH*("`@("`J($5X96-U=&5S(&%N>2!C;V1E(&YE8V5S<V%R87D@
M869T97(@87!P;'EI;F<@=&AE(&9I;'1E<@H@("`@("H@<&%T=&5R;G,N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@5&AE('1E>'0@869T
M97(@=&AE(&9I;'1E<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE(&UO9&EF:65D('1E>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N('!O
M<W10<F]C97-S*"1T97AT*0H@("`@>PH@("`@("`@("1P87)T<R`]('!R96=?
M<W!L:70H)WPH7&XM+5QS*B@\8G(@+SXI/UQR/UQN*7PG+"`D=&5X="P@,BP@
M4%)%1U]34$Q)5%]$14Q)35]#05!455)%*3L*("`@("`@("!I9B`H8V]U;G0H
M)'!A<G1S*2`^(#,I('L*("`@("`@("`@("`@)'1E>'0@/2!A<G)A>5]S:&EF
M="@D<&%R=',I.PH@("`@("`@("`@("`D=&5X="`N/2`G/'-P86X@8VQA<W,]
M(G-I9VYA='5R92(^)R`N("1P87)T<ULP73L*("`@("`@("`@("`@)'1E>'0@
M+CT@<')E9U]R97!L86-E*"=\8VQA<W,](BA;7B)=*RDB?"<L("=C;&%S<STB
M<VEG;F%T=7)E+5PQ(B<L("1P87)T<ULR72D["B`@("`@("`@("`@("1T97AT
M("X]("<\+W-P86X^)SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&5X
M=#L*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M5&5X="]&:6QT97(O8F)C;V1E+G!H<```````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,3$P-S,@,3`U,34T,S,W,S<@,#(S-#4T`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"@IR97%U:7)E7V]N
M8V4@)TAO<F1E+G!H<"<["@HO*BH*("H@5&AE(%1E>'1?1FEL=&5R7V)B8V]D
M93HZ(&-L87-S(&9I;F1S(&)B8V]D92US='EL92!M87)K=7`@*'-E92!B96QO
M=RD@:6X@80H@*B!B;&]C:R!O9B!T97AT(&%N9"!T=7)N<R!I="!I;G1O($A4
M34PN"B`J"B`J(%!A<F%M971E<G,Z"B`J(#QP<F4^"B`J(&5N=&ET:65S("TM
M($EF('1R=64@8F5F;W)E(')E<&QA8VEN9R!B8F-O9&4@=VET:"!(5$U,('1A
M9W,L(&%N>2!(5$U,"B`J("`@("`@("`@("`@(&5N=&ET:65S('=I;&P@8F4@
M<F5P;&%C960N"B`J(#PO<')E/@H@*@H@*B!3=7!P;W)T960@8F)C;V1E.@H@
M*B`\<')E/@H@*B`@("`@6V)=0F]L9"!497AT6R]B70H@*B`@("`@6VE=271A
M;&EC<R!497AT6R]I70H@*B`@("`@6W5=56YD97)L:6YE9"!497AT6R]U70H@
M*B`@("`@6W%U;W1E75%U;W1E9"!497AT6R]Q=6]T95T*("H@("`@(%MC96YT
M97)=0V5N=&5R960@5&5X=%LO8V5N=&5R70H@*@H@*B`@("`@3&ES="!O9B!I
M=&5M<PH@*B`@("`@6VQI<W1="B`J("`@("!;*ET@271E;2!O;F4*("H@("`@
M(%LJ72!)=&5M('1W;PH@*B`@("`@6R]L:7-T70H@*@H@*B`@("`@3G5M8F5R
M960@;&ES=`H@*B`@("`@6VYU;6QI<W1="B`J("`@("!;*ET@271E;2!O;F4*
M("H@("`@(%LJ72!)=&5M('1W;PH@*B`@("`@6R]N=6UL:7-T70H@*@H@*B`@
M("`@6W5R;%UH='1P.B\O=W=W+FAO<F1E+F]R9ULO=7)L72`M/B!,:6YK('1O
M('1H92!A9&1R97-S('5S:6YG('1H90H@*B`@("`@("`@(&%D9')E<W,@:71S
M96QF(&9O<B!T:&4@=&5X="X@(%EO=2!C86X@<W!E8VEF>2!T:&4@<')O=&]C
M;VPZ(&AT='`@;W(*("H@("`@("`@("!H='1P<R!A;F0@=&AE('!O<G0N"B`J
M("`@("!;=7)L77=W=RYH;W)D92YO<F=;+W5R;%T@+3X@3&EN:R!T;R!T:&4@
M861D<F5S<R!U<VEN9R!T:&4@861D<F5S<PH@*B`@("`@("`@(&ET<V5L9B!F
M;W(@=&AE('1E>'0N("!9;W4@8V%N('-P96-I9GD@=&AE('!O<G0N("!4:&4@
M<')O=&]C;VP@:7,@8GD*("H@("`@("`@("!D969A=6QT(&AT='`N"B`J("`@
M("!;=7)L/6AT='`Z+R]W=W<N:&]R9&4N;W)G74QI;FL@=&\@2&]R9&5;+W5R
M;%T@+3X@3&EN:R!T;R!T:&4@861D<F5S<PH@*B`@("`@("`@('5S:6YG("),
M:6YK('1O($AO<F1E(B!F;W(@=&AE('1E>'0N("!9;W4@8V%N('-P96-I9GD@
M=&AE('!R;W1O8V]L.@H@*B`@("`@("`@(&AT='`@;W(@:'1T<',@86YD('1H
M92!P;W)T+@H@*B`@("`@6W5R;#UW=W<N:&]R9&4N;W)G74QI;FL@=&\@2&]R
M9&5;+W5R;%T@+3X@3&EN:R!T;R!T:&4@861D<F5S<R!U<VEN9PH@*B`@("`@
M("`@("),:6YK('1O($AO<F1E(B!F;W(@=&AE('1E>'0N("!9;W4@8V%N('-P
M96-I9GD@=&AE('!O<G0N("!4:&4*("H@("`@("`@("!P<F]T;V-O;"!I<R!B
M>2!D969A=6QT(&AT='`*("H@("`@(%ME;6%I;%UC<&5D<FEN86-I0'EA:&]O
M+F5S6R]E;6%I;%T@+3X@<V5T<R!A(&UA:6QT;R!L:6YK+@H@*B`@("`@6V5M
M86EL/6-P961R:6YA8VE`>6%H;V\N97-=36%I;"!T;R!#87)L;W-;+V5M86EL
M72`M/B!3971S(&$@;6%I;'1O(&QI;FL*("H@("`@("`@("!A;F0@=&AE('1E
M>'0@:7,@(DUA:6P@=&\@0V%R;&]S(BX*("H@/"]P<F4^"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]B8F-O9&4N<&AP+'8@
M,2XX+C$P+C4@,C`P-B\P,2\P,2`R,3HR.#HS."!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#(P,#,M,C`P-B!#87)L;W,@4&5D<FEN86-I(#QC<&5D<FEN
M86-I0'EA:&]O+F5S/@H@*@H@*B!%;6%I;"!V86QI9&%T:6]N(&)A<V5D(&]N
M($-H=6-K($AA9V5N8G5C:"=S"B`J($UA:6Q?4D9#.#(R.CII<U9A;&ED26YE
M=$%D9')E<W,N"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9`H@
M*B!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#87)L;W,@
M4&5D<FEN86-I(#QC<&5D<FEN86-I0'EA:&]O+F5S/@H@*B!`<&%C:V%G92!(
M;W)D95]497AT"B`J+PIC;&%S<R!497AT7T9I;'1E<E]B8F-O9&4@97AT96YD
M<R!497AT7T9I;'1E<B!["@H@("`@+RHJ"B`@("`@*B!&:6QT97(@<&%R86UE
M=&5R<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D7W!A<F%M<R`](&%R<F%Y*"=E;G1I=&EE<R<@/3X@9F%L<V4I.PH*("`@
M("\J*@H@("`@("H@17AE8W5T97,@86YY(&-O9&4@;F5C97-S87)Y(&)E9F]R
M92!A<'!L>6EN9R!T:&4@9FEL=&5R('!A='1E<FYS+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!T97AT(&)E9F]R92!T:&4@9FEL
M=&5R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;6]D
M:69I960@=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@<')E4')O8V5S<R@D
M=&5X="D*("`@('L*("`@(`EI9B`H)'1H:7,M/E]P87)A;7-;)V5N=&ET:65S
M)UTI('L*("`@("`@("`@("`@)'1E>'0@/2!`:'1M;'-P96-I86QC:&%R<R@D
M=&5X="D["B`@("`)?0H*("`@("`@("!R971U<FX@)'1E>'0["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS(&$@:&%S:"!W:71H(')E<&QA8V4@<&%T
M=&5R;G,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@4&%T=&5R;G,@
M:&%S:"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%T=&5R;G,H*0H@("`@
M>PH@("`@"21R97!L86-E(#T@87)R87DH"B`@("`)("`@("=;:5TG(#T^("<\
M96T^)RP@)ULO:5TG(#T^("<\+V5M/B<L"B`@("`@("`@("`@("=;=5TG(#T^
M("<\=3XG+"`G6R]U72<@/3X@)SPO=3XG+`H@("`@("`@("`@("`G6V)=)R`]
M/B`G/'-T<F]N9SXG+"`G6R]B72<@/3X@)SPO<W1R;VYG/B<L"B`@("`@("`@
M("`@("=;8V5N=&5R72<@/3X@)SQC96YT97(^)RP@)ULO8V5N=&5R72<@/3X@
M)SPO8V5N=&5R/B<L"B`@("`@("`@("`@("=;<75O=&5=)R`]/B`G/&)L;V-K
M<75O=&4^)RP@)ULO<75O=&5=)R`]/B`G/"]B;&]C:W%U;W1E/B<L"B`@("`@
M("`@("`@("=;;&ES=%TG(#T^("<\=6P^)RP@)ULO;&ES=%TG(#T^("<\+W5L
M/B<L"B`@("`@("`@("`@("=;;G5M;&ES=%TG(#T^("<\;VP^)RP@)ULO;G5M
M;&ES=%TG(#T^("<\+V]L/B<L"B`@("`@("`@("`@("=;*ETG(#T^("<\;&D^
M)RD["@H@("`@("`@("\J(%=H96X@8VAE8VMI;F<@55),<R!W92!V86QI9&%T
M92!P87)T(&]F('1H96TL(&)U="!I="!I<R!U<`H@("`@("`@("`J('1O('1H
M92!U<V5R('1O('=R:71E('1H96T@8V]R<F5C=&QY("AI;B!P87)T:6-U;&%R
M('1H90H@("`@("`@("`J('%U97)Y('-T<FEN9RDN($-O;F-E<FYI;F<@;6%I
M;',@=V4@=7-E('1H92!R96=U;&%R"B`@("`@("`@("H@97AP<F5S<VEO;B!I
M;B!-86EL7U)&0S@R,B=S(&ES5F%L:61);F5T061D<F5S<R@I(&9U;F-T:6]N
M+`H@("`@("`@("`J('-L:6=H=&QY(&UO9&EF:65D+B`J+PH@("`@("`@("1R
M96=E>'`@/2!A<G)A>2@*("`@("`@("`@("`@(B-<6W5R;%Q=*"AH='1P?&AT
M='!S*3HO+RA;82UZ02U:7&1=6UQW+5TJ*2A<+EMA+7I!+5I<9%U;7'<M72HI
M*R@Z*%QD*RDI/R@O*%M>/#Y=*RDI*BE<6R]U<FQ<72-5(B`]/@H@("`@("`@
M("`@("!(;W)D93HZ;&EN:R@B)#$B+"`B)#$B*2`N("(D,3PO83XB+`H*("`@
M("`@("`@("`@(B-<6W5R;%P]*"AH='1P?&AT='!S*3HO+RA;82UZ02U:7&1=
M6UQW+5TJ*2A<+EMA+7I!+5I<9%U;7'<M72HI*R@Z*%QD*RDI/R@O*%M>/#Y=
M*RDI*BE<72A;7CP^72LI7%LO=7)L7%TC52(@/3X*("`@("`@("`@("`@2&]R
M9&4Z.FQI;FLH(B0Q(BP@(B0Q(BD@+B`B)#D\+V$^(BP*"B`@("`@("`@("`@
M("(C7%MU<FQ<72@H6V$M>D$M6EQD75M<=RU=*BDH7"Y;82UZ02U:7&1=6UQW
M+5TJ*2LH.BA<9"LI*3\H+RA;7CP^72LI*2HI7%LO=7)L7%TC52(@/3X*("`@
M("`@("`@("`@2&]R9&4Z.FQI;FLH(FAT='`Z+R\D,2(L(")H='1P.B\O)#$B
M*2`N("(D,3PO83XB+`H*("`@("`@("`@("`@(B-<6W5R;%P]*"A;82UZ02U:
M7&1=6UQW+5TJ*2A<+EMA+7I!+5I<9%U;7'<M72HI*R@Z*%QD*RDI/R@O*%M>
M/#Y=*RDI*BE<72A;7CP^72LI7%LO=7)L7%TC52(@/3X*("`@("`@("`@("`@
M2&]R9&4Z.FQI;FLH(FAT='`Z+R\D,2(L(")H='1P.B\O)#$B*2`N("(D.#PO
M83XB+`H*("`@("`@("`@("`@(B-<6V5M86EL7%TH*%LJ*R$N)EPC)'Q<)UQ<
M)5PO,"TY82UZ02U:7E]@>WT]/WXZ+5TK*4`H*%LP+3EA+7I!+5HM72M<+BDK
M6S`M.6$M>D$M6EU[,BPT?2DI7%LO96UA:6Q<72-5(B`]/@H@("`@("`@("`@
M("!(;W)D93HZ;&EN:R@B;6%I;'1O.B0Q(BP@(FUA:6QT;SHD,2(I("X@(B0Q
M/"]A/B(L"@H@("`@("`@("`@("`B(UQ;96UA:6Q</2@H6RHK(2XF7",D?%PG
M7%PE7"\P+3EA+7I!+5I>7V![?3T_?CHM72LI0"@H6S`M.6$M>D$M6BU=*UPN
M*2M;,"TY82UZ02U:77LR+#1]*2E<72A;7CP^72LI7%LO96UA:6Q<72-5(B`]
M/@H@("`@("`@("`@("!(;W)D93HZ;&EN:R@B;6%I;'1O.B0Q(BP@(FUA:6QT
M;SHD,2(I("X@(B0U/"]A/B(*("`@("`@("`I.PH*("`@("`@("!R971U<FX@
M87)R87DH)W)E<&QA8V4G(#T^("1R97!L86-E+"`G<F5G97AP)R`]/B`D<F5G
M97AP*3L*("`@('T*"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+U1E>'0O1FEL=&5R+VQI;FMU<FQS+G!H<```````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`U,C$V(#$P-3$U-#,S-S,W(#`R-#$P,P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@5&AE(%1E>'1?1FEL=&5R7VQI;FMU<FQS.CH@8VQA<W,@='5R;G,@86QL
M(%523',@:6X@=&AE('1E>'0@:6YT;R!H>7!E<FQI;FMS+@H@*@H@*B!087)A
M;65T97)S.@H@*B`\<')E/@H@*B!T87)G970@("`M+2!4:&4@;&EN:R!T87)G
M970N("!$969A=6QT<R!T;R!?8FQA;FLN"B`J(&-L87-S("`@("TM(%1H92!#
M4U,@8VQA<W,@;V8@=&AE(&=E;F5R871E9"!L:6YK<RX@($1E9F%U;'1S('1O
M(&YO;F4N"B`J(&YO9F]L;&]W("TM(%=H971H97(@=&\@<V5T('1H92`G<F5L
M/2)N;V9O;&QO=R(G(&%T=')I8G5T92!O;B!L:6YK<RX*("H@8V%P:71A;"`@
M+2T@9V5N97)A=&4@=7!P97)C87-E(#Q!/B!T86=S('-O('EO=2!C86X@:VYO
M=R!W:&EC:"!T86=S('EO=2!J=7-T"B`J("`@("`@("`@("`@(&=E;F5R871E
M9"X@($1E9F%U;'1S('1O(&9A;'-E+@H@*B!C86QL8F%C:R`M+2!!;B!O<'1I
M;VYA;"!C86QL8F%C:R!F=6YC=&EO;B!T:&%T('1H92!54DP@:7,@<&%S<V5D
M('1H<F]U9V@*("H@("`@("`@("`@("`@8F5F;W)E(&)E:6YG('-E="!A<R!T
M:&4@:')E9B!A='1R:6)U=&4N("!-=7-T(&)E(&$@<W1R:6YG('=I=&@*("H@
M("`@("`@("`@("`@=&AE(&9U;F-T:6]N(&YA;64L('1H92!F=6YC=&EO;B!M
M=7-T('1A:V4@=&AE(&]R:6=I;F%L(&%S('1H90H@*B`@("`@("`@("`@("!F
M:7)S="!A;F0@;VYL>2!P87)A;65T97(N"B`J(#PO<')E/@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O;&EN:W5R;',N<&AP
M+'8@,2XQ,2XQ,"XU(#(P,#8O,#$O,#$@,C$Z,C@Z,S@@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@5'EL97(@0V]L8F5R="`\='EL97(M
M:&]R9&5M;$!C;VQB97)T<RYU<SX*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!*
M86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@0&%U=&AO<B`@5'EL97(@0V]L8F5R="`\='EL97(M:&]R9&5M;$!C;VQB
M97)T<RYU<SX*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E
M+F]R9SX*("H@0'!A8VMA9V4@2&]R9&5?5&5X=`H@*B\*8VQA<W,@5&5X=%]&
M:6QT97)?;&EN:W5R;',@97AT96YD<R!497AT7T9I;'1E<B!["@H@("`@+RHJ
M"B`@("`@*B!&:6QT97(@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A<F%M<R`](&%R<F%Y*"=T87)G
M970G(#T^("=?8FQA;FLG+`H@("`@("`@("`@("`@("`@("`@("`@("`@)V-L
M87-S)R`]/B`G)RP*("`@("`@("`@("`@("`@("`@("`@("`@("=N;V9O;&QO
M=R<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`G8V%P:71A
M;"<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`G8V%L;&)A
M8VLG(#T^(&YU;&PI.PH*("`@("\J*@H@("`@("H@17AE8W5T97,@86YY(&-O
M9&4@;F5C97-S87)Y(&)E9F]R92!A<'!L>6EN9R!T:&4@9FEL=&5R('!A='1E
M<FYS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!T
M97AT(&)E9F]R92!T:&4@9FEL=&5R:6YG+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@;6]D:69I960@=&5X="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<')E4')O8V5S<R@D=&5X="D*("`@('L*("`@("`@("!I9B`H)'1H
M:7,M/E]P87)A;7-;)V-A<&ET86PG72D@>PH@("`@("`@("`@("`D=&5X="`]
M('-T<E]R97!L86-E*&%R<F%Y*"<\+T$^)RP@)SQ!)RDL(&%R<F%Y*"<\+V$^
M)RP@)SQA)RDL("1T97AT*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M=&5X=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!H87-H('=I
M=&@@<F5P;&%C92!P871T97)N<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!0871T97)N<R!H87-H+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9710
M871T97)N<R@I"B`@("!["B`@("`@("`@)&$@/2`D=&AI<RT^7W!A<F%M<ULG
M8V%P:71A;"==(#\@)T$G(#H@)V$G.PH*("`@("`@("`D8VQA<W,@/2`D=&AI
M<RT^7W!A<F%M<ULG8VQA<W,G73L*("`@("`@("!I9B`H(65M<'1Y*"1C;&%S
M<RDI('L*("`@("`@("`@("`@)&-L87-S(#T@)R!C;&%S<STB)R`N("1C;&%S
M<R`N("<B)SL*("`@("`@("!]"B`@("`@("`@)&YO9F]L;&]W(#T@)'1H:7,M
M/E]P87)A;7-;)VYO9F]L;&]W)UT@/R`G(')E;#TB;F]F;VQL;W<B)R`Z("<G
M.PH*("`@("`@("`D=7)L(#T@)'1H:7,M/E]P87)A;7-;)V-A;&QB86-K)UT@
M/R`G7"<@+B`G("X@)'1H:7,M/E]P87)A;7-;)V-A;&QB86-K)UT@+B`G*%PG
M)#!<)RD@+B!<)R<@.B`G)#`G.PH*("`@("`@("`D<F5G97AP(#T@87)R87DH
M)WPH7'<K*3HO+RA;7EQS(CQ=*EM<=RLC/R\F/5TI?&4G(#T^"B`@("`@("`@
M("`@("`@("`@("`@("`@("=<)SPG("X@)&$@+B`G(&AR968](B<@+B`D=7)L
M("X@)R(G("X@)&YO9F]L;&]W("X@)R!T87)G970](E]B;&%N:R(G("X@)&-L
M87-S("X@)SXD,#PO)R`N("1A("X@)SY<)R<I.PH*("`@("`@("!R971U<FX@
M87)R87DH)W)E9V5X<"<@/3X@)')E9V5X<"D["B`@("!]"@I]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O5&5X="]&:6QT
M97(O96UA:6QS+G!H<```````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3`T
M,#`@,3`U,34T,S,W,S<@,#(S-3`Q`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B!4:&4@5&5X=%]&:6QT
M97)?96UA:6QS.CH@8VQA<W,@9FEN9',@96UA:6P@861D<F5S<V5S(&EN(&$@
M8FQO8VL@;V8@=&5X="!A;F0*("H@='5R;G,@=&AE;2!I;G1O(&QI;FMS+@H@
M*@H@*B!087)A;65T97)S.@H@*B`\<')E/@H@*B!A;'=A>7-?;6%I;'1O("TM
M($EF('1R=64L(&$@;6%I;'1O.B!L:6YK(&ES(&=E;F5R871E9"!A;'=A>7,N
M("!/;FQY(&EF(&YO"B`J("`@("`@("`@("`@("`@("`@;6%I;"]C;VUP;W-E
M(')E9VES=')Y($%022!M971H;V0@97AI<W1S(&]T:&5R=VES92X*("H@8VQA
M<W,@("`@("`@("`M+2!#4U,@8VQA<W,@;V8@=&AE(&=E;F5R871E9"`\83X@
M=&%G+B`@1&5F875L=',@=&\@;F]N92X*("H@/"]P<F4^"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP+'8@
M,2XQ-2XQ,"XX(#(P,#8O,#(O,3<@,C`Z,#4Z-#D@8VAU8VL@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!4>6QE<B!#;VQB97)T(#QT>6QE<BUH
M;W)D96UL0&-O;&)E<G1S+G5S/@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($IA
M;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@268@>6]U(&1I9"!N;W0*("H@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@
M*B!`875T:&]R(%1Y;&5R($-O;&)E<G0@/'1Y;&5R+6AO<F1E;6Q`8V]L8F5R
M=',N=7,^"B`J($!A=71H;W(@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R
M9SX*("H@0'!A8VMA9V4@2&]R9&5?5&5X=`H@*B\*8VQA<W,@5&5X=%]&:6QT
M97)?96UA:6QS(&5X=&5N9',@5&5X=%]&:6QT97(@>PH*("`@("\J*@H@("`@
M("H@1FEL=&5R('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A>2@G86QW87ES7VUA
M:6QT;R<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`G8VQA
M<W,G(#T^("<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)V-A<&ET86Q?
M=&%G<R<@/3X@9F%L<V4I.PH*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&AA
M<V@@=VET:"!R97!L86-E('!A='1E<FYS+@H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@(%!A='1E<FYS(&AA<V@N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=%!A='1E<FYS*"D*("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y
M.PH*("`@("`@("`D8VQA<W,@/2!E;7!T>2@D=&AI<RT^7W!A<F%M<ULG8VQA
M<W,G72D@/R`G)R`Z("<@8VQA<W,](B<@+B`D=&AI<RT^7W!A<F%M<ULG8VQA
M<W,G72`N("<B)SL*("`@("`@("`D=&%G(#T@)'1H:7,M/E]P87)A;7-;)V-A
M<&ET86Q?=&%G<R==(#\@)T$G(#H@)V$G.PH*("`@("`@("`D<F5G97AP(#T@
M/#P\14]2"B`@("`@("`@("`@("\*("`@("`@("`@("`@(R!697)S:6]N(#$Z
M(&UA:6QT;SH@;&EN:W,@=VET:"!A;GD@=F%L:60@96UA:6P@8VAA<F%C=&5R
M<RX*("`@("`@("`@("`@(R!0871T97)N(#$Z($]U=&QO;VL@<&%R96YT:&5S
M:7IE<R!I;B!S<6%R92!B<F%C:V5T<PH@("`@("`@("`@("`H7%M<<RHI/PH@
M("`@("`@("`@("`C(%!A='1E<FX@,CH@;6%I;'1O.B!P<F]T;V-O;"!P<F5F
M:7@*("`@("`@("`@("`@*&UA:6QT;SI<<S\I"B`@("`@("`@("`@(",@4&%T
M=&5R;B`S.B!E;6%I;"!A9&1R97-S"B`@("`@("`@("`@("A;7EQS7#\B/%TJ
M*0H@("`@("`@("`@("`C(%!A='1E<FX@-"!T;R`V.B!/<'1I;VYA;"!P87)A
M;65T97)S"B`@("`@("`@("`@("@H7#\I*%M>7',B/%TJ6UQW*R,_7"\F/5TI
M*3\*("`@("`@("`@("`@(R!0871T97)N(#<Z($-L;W-I;F<@3W5T;&]O:R!S
M<75A<F4@8G)A8VME=`H@("`@("`@("`@("`H*#\H,2E<<RI<72DI"@H@("`@
M("`@("`@("!\"B`@("`@("`@("`@(",@5F5R<VEO;B`R(%!A='1E<FX@.#H@
M<VEM<&QE(&5M86EL(&%D9')E<W-E<RX*("`@("`@("`@("`@*%QB6UQW+2LN
M/5TK0%LM02U:,"TY+ETJ6T$M6C`M.5TI"B`@("`@("`@("`@(",@4&%T=&5R
M;B`Y('1O(#$Q.B!/<'1I;VYA;"!P87)A;65T97)S"B`@("`@("`@("`@("@H
M7#\I*%M>7',B/%TJ6UQW*R,_7"\F/5TI*3\*"B`@("`@("`@("`@("]E:7@*
M14]2.PH*("`@("`@("!I9B`H:7-?82@D<F5G:7-T<GDL("=296=I<W1R>2<I
M("8F"B`@("`@("`@("`@("1R96=I<W1R>2T^:&%S365T:&]D*"=M86EL+V-O
M;7!O<V4G*2`F)@H@("`@("`@("`@("`A)'1H:7,M/E]P87)A;7-;)V%L=V%Y
M<U]M86EL=&\G72D@>PH@("`@("`@("`@("`O*B!)9B!W92!H879E(&$@;6%I
M;"]C;VUP;W-E(')E9VES=')Y(&UE=&AO9"P@=7-E(&ET+B`J+PH@("`@("`@
M("`@("`D<F5P;&%C96UE;G0@/2`G5&5X=%]&:6QT97)?96UA:6QS.CIC86QL
M8F%C:RA<)R<@+B`D=&%G("X*("`@("`@("`@("`@("`@("=<)RP@7"<G("X@
M)&-L87-S("X@)UPG+"!<)R0Q7"<L(%PG)#)<)RP@7"<D,UPG+"!<)R0T7"<L
M(%PG)#9<)RP@7"<D-UPG+"!<)R0X7"<L(%PG)#E<)RP@7"<D,3%<)RDG.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J($]T:&5R=VES92P@9V5N
M97)A=&4@82!S=&%N9&%R9"!M86EL=&\Z(&%N9"!L970@=&AE"B`@("`@("`@
M("`@("`J(&)R;W=S97(@:&%N9&QE(&ET+B`J+PH@("`@("`@("`@("`D<F5P
M;&%C96UE;G0@/2`\/#Q%3U`*("`@("`@("`@("`@("`@("<D."<@/3T]("<G
M(#\*"B`@("`@("`@("`@("`@("`G)#$D,CPD=&%G)&-L87-S(&AR968](FUA
M:6QT;SHD,R0T(B!T:71L93TB)R`N('-P<FEN=&8H7R@B3F5W($UE<W-A9V4@
M=&\@)7,B*2P@:'1M;'-P96-I86QC:&%R<R@G)#,G*2D@+@H@("`@("`@("`@
M("`@("`@)R(^)#,D-#PO)'1A9SXD-R<@.@H*("`@("`@("`@("`@("`@("<\
M)'1A9R1C;&%S<R!H<F5F/2)M86EL=&\Z)#@D.2(@=&ET;&4](B<@+B!S<')I
M;G1F*%\H(DYE=R!-97-S86=E('1O("5S(BDL(&AT;6QS<&5C:6%L8VAA<G,H
M)R0X)RDI("X*("`@("`@("`@("`@("`@("<B/B0X)#D\+R1T86<^)PI%3U`[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@87)R87DH)W)E9V5X<"<@/3X@
M87)R87DH)')E9V5X<"`]/B`D<F5P;&%C96UE;G0I*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!C86QL8F%C:R@D=&%G+"`D8VQA<W,L("1B<F%C:V5T,2P@)'!R
M;W1O8V]L+"`D96UA:6PL("1A<F=S7VQO;F<L"B`@("`@("`@("`@("`@("`@
M("`@("`D87)G<RP@)&)R86-K970R+"`D96UA:6PR+"`D87)G<U]L;VYG,BP@
M)&%R9W,R*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)&5M86EL,BDI('L*
M("`@("`@("`@("`@)&%R9W,@/2`D87)G<S(["B`@("`@("`@("`@("1E;6%I
M;"`]("1E;6%I;#(["B`@("`@("`@("`@("1A<F=S7VQO;F<@/2`D87)G<U]L
M;VYG,CL*("`@("`@("!]"B`@("`@("`@)&5X=')A(#T@8V%L;%]U<V5R7V9U
M;F,H8W)E871E7V9U;F-T:6]N*"<D82<L("<D<#UA<G)A>2@I.V9O<F5A8V@H
M)&$@87,@)&(I>R1B/65X<&QO9&4H(CTB+"1B+#(I.R1P6R1B6S!=73U`)&);
M,5T[?7)E='5R;B`D<#LG*2P@97AP;&]D92@G)B<L("1A<F=S*2D["B`@("`@
M("`@)'5R;"`]("1'3$]"04Q36R=R96=I<W1R>2==+3YC86QL*"=M86EL+V-O
M;7!O<V4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2AA<G)A>2@G=&\G(#T^("1E;6%I;"DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E>'1R82DI.PH@("`@
M("`@("1U<FP@/2!S=')?<F5P;&%C92@G)F%M<#LG+"`G)B<L("1U<FPI.PH@
M("`@("`@(&EF("AS=6)S='(H)'5R;"P@,"P@,3$I(#T]("=J879A<V-R:7!T
M.B<I('L*("`@("`@("`@("`@)&AR968@/2`G(R<["B`@("`@("`@("`@("1O
M;F-L:6-K(#T@)R!O;F-L:6-K/2(G("X@<W5B<W1R*"1U<FPL(#$Q*2`N("<B
M)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D:')E9B`]("1U<FP[
M"B`@("`@("`@("`@("1O;F-L:6-K(#T@)R<["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)&)R86-K970Q("X@)'!R;W1O8V]L("X@)SPG("X@)'1A9R`N
M("1C;&%S<R`N("<@:')E9CTB)R`N"B`@("`@("`@("`@("1H<F5F("X@)R(@
M=&ET;&4](B<@+B!S<')I;G1F*%\H(DYE=R!-97-S86=E('1O("5S(BDL(&AT
M;6QS<&5C:6%L8VAA<G,H)&5M86EL*2D@+B`G(B<@+@H@("`@("`@("`@("`D
M;VYC;&EC:R`N("<^)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&5M86EL*2`N("1A
M<F=S7VQO;F<@+B`G/"\G("X@)'1A9R`N("<^)R`N("1B<F%C:V5T,CL*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]497AT+T9I;'1E<B]E;G9I<F]N
M;65N="YP:'``````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3<P-R`Q,#4Q-30S
M,S<S-R`P,C0V,#4`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J(%)E<&QA8V5S(&]C8W5R96YC97,@;V8@
M)59!4B4@=VET:"!605(L(&EF(%9!4B!E>&ES=',@:6X@=&AE('=E8G-E<G9E
M<B=S"B`J(&5N=FER;VYM96YT+B`@26=N;W)E<R!A;&P@=&5X="!A9G1E<B!A
M("<C)R!C:&%R86-T97(@*'-H96QL+7-T>6QE"B`J(&-O;6UE;G1S*2X*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5N=FER
M;VYM96YT+G!H<"QV(#$N,RXQ,"XT(#(P,#8O,#$O,#$@,C$Z,C@Z,S@@:F%N
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@2F%N(%-C:&YE:61E
M<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y
M;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO
M<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]497AT"B`J+PIC;&%S<R!497AT
M7T9I;'1E<E]E;G9I<F]N;65N="!E>'1E;F1S(%1E>'1?1FEL=&5R('L*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@82!H87-H('=I=&@@<F5P;&%C92!P871T
M97)N<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!0871T97)N<R!H
M87-H+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9710871T97)N<R@I"B`@("![
M"B`@("`@("`@)')E9V5X<"`](&%R<F%Y*"<O7B,N*B1<;B]M)R`]/B`G)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@)R]>*%M>(UTJ*2,N*B0O;2<@/3X@
M)R0Q)RP*("`@("`@("`@("`@("`@("`@("`@("`@)R\E*%M!+5IA+7I?72LI
M)2]E)R`]/B`G9V5T96YV*"(D,2(I)RD["B`@("`@("`@<F5T=7)N(&%R<F%Y
M*"=R96=E>'`G(#T^("1R96=E>'`I.PH@("`@?0H*?0``````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]497AT+T9I;'1E<B]H
M=&UL,G1E>'0N<&AP````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q-C$S,"`Q
M,#4Q-30S,S<S-R`P,C0Q-S``(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O4W1R
M:6YG+G!H<"<["@HO*BH*("H@5&%K97,@2%1-3"!A;F0@8V]N=F5R=',@:70@
M=&\@9F]R;6%T=&5D+"!P;&%I;B!T97AT+@H@*@H@*B!087)A;65T97)S.@H@
M*B`\<')E/@H@*B!C:&%R<V5T("TM(%1H92!C:&%R<V5T('1O('5S92!F;W(@
M:'1M;%]E;G1I='E?9&5C;V1E*"D@8V%L;',N"B`J('=I9'1H("`@+2T@5&AE
M('=R87!P:6YG('=I9'1H+@H@*B!W<F%P("`@("TM(%=H971H97(@=&\@=W)A
M<"!T:&4@=&5X="!O<B!N;W0N"B`J(#PO<')E/@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:'1M;#)T97AT+G!H<"QV(#$N
M-"XQ,"XQ,B`R,#`V+S`Q+S`Q(#(Q.C(X.C,X(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,RTR,#`V($IO;B!!8F5R;F%T:'D@/&IO;D!C:'5G9VYU
M='0N8V]M/@H@*B!/<FEG:6YA;"!S;W5R8V4Z(&AT='`Z+R]W=W<N8VAU9V=N
M=71T+F-O;2]H=&UL,G1E>'0N<&AP"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@
M2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($IO;B!!8F5R;F%T:'D@/&IO;D!C:'5G9VYU='0N8V]M
M/@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@
M*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?5&5X=`H@
M*B\*8VQA<W,@5&5X=%]&:6QT97)?:'1M;#)T97AT(&5X=&5N9',@5&5X=%]&
M:6QT97(@>PH*("`@("\J*@H@("`@("H@1FEL=&5R('!A<F%M971E<G,N"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P87)A
M;7,@/2!A<G)A>2@G8VAA<G-E="<@/3X@;G5L;"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("=W:61T:"<@/3X@-S`L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`G=W)A<"<@/3X@=')U92D["@H@("`@+RHJ"B`@("`@*B!%>&5C=71E
M<R!A;GD@8V]D92!N96-E<W-A<F%Y(&)E9F]R92!A<'!L>6EN9R!T:&4@9FEL
M=&5R('!A='1E<FYS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E
M>'0@(%1H92!T97AT(&)E9F]R92!T:&4@9FEL=&5R:6YG+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@;6]D:69I960@=&5X="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<')E4')O8V5S<R@D=&5X="D*("`@('L*("`@("`@
M("!G;&]B86P@)%]H=&UL,G1E>'1?<W1A=&4["@H@("`@("`@(&EF("AI<U]N
M=6QL*"1T:&ES+3Y?<&%R86US6R=C:&%R<V5T)UTI*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=C:&%R<V5T)UT@/2!I<W-E="@D1TQ/0D%,4ULG
M7TA/4D1%7U-44DE.1U]#2$%24T54)UTI(#\@)$=,3T)!3%-;)U](3U)$15]3
M5%))3D=?0TA!4E-%5"==(#H@)TE33RTX.#4Y+3$G.PH@("`@("`@('T*"B`@
M("`@("`@)%]H=&UL,G1E>'1?<W1A=&5;)VQI;FM,:7-T)UT@/2`G)SL*("`@
M("`@("`D7VAT;6PR=&5X=%]S=&%T95LG;&EN:T-O=6YT)UT@/2`P.PH*("`@
M("`@("!R971U<FX@=')I;2@D=&5X="D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&$@:&%S:"!W:71H(')E<&QA8V4@<&%T=&5R;G,N"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@4&%T=&5R;G,@:&%S:"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T4&%T=&5R;G,H*0H@("`@>PH@("`@("`@("1R
M96=E>'`@/2!A<G)A>2@*("`@("`@("`@("`@+R\@3F]N+6QE9V%L(&-A<G)I
M86=E(')E='5R;BX*("`@("`@("`@("`@)R]<<B\G(#T^("<G+`H*("`@("`@
M("`@("`@+R\@3&5A9&EN9R!A;F0@=')A:6QI;F<@=VAI=&5S<&%C92X*("`@
M("`@("`@("`@)R]>7',J*"XJ/RE<<RHD+VTG(#T^("=<,2<L"@H@("`@("`@
M("`@("`O+R!.;W)M86QI>F4@/&)R/BX*("`@("`@("`@("`@)R\\8G);7CY=
M*CXH6UY<;ETI+VDG(#T^("(\8G(^7&Y<7#$B+`H*("`@("`@("`@("`@+R\@
M3F5W;&EN97,@86YD('1A8G,N"B`@("`@("`@("`@("<O6UQN7'1=*R\G(#T^
M("<@)RP*"B`@("`@("`@("`@("\O(#QS8W)I<'0^<R`M+2!W:&EC:"!S=')I
M<%]T86=S*"D@<W5P<&]S961L>2!H87,@<')O8FQE;7,@=VET:"X*("`@("`@
M("`@("`@)R\\<V-R:7!T6UX^72H^+BH_/%PO<V-R:7!T/B]I)R`]/B`G)RP*
M"B`@("`@("`@("`@("\O(#QS='EL93YS("TM('=H:6-H('-T<FEP7W1A9W,H
M*2!S=7!P;W-E9&QY(&AA<R!P<F]B;&5M<R!W:71H+@H@("`@("`@("`@("`G
M+SQS='EL95M>/ETJ/BXJ/SQ<+W-T>6QE/B]I)R`]/B`G)RP*"B`@("`@("`@
M("`@("\O($-O;6UE;G1S("TM('=H:6-H('-T<FEP7W1A9W,H*2!M:6=H="!H
M879E(&$@<')O8FQE;2!W:71H+@H@("`@("`@("`@("`O+R`O+R<O/"$M+2`N
M*B`M+3XO)R`]/B`G)RP*"B`@("`@("`@("`@("\O(&@Q("T@:#,*("`@("`@
M("`@("`@)R\\:%LQ,C-=6UX^72H^*"XK/RD\7"]H6S$R,UT^(#\O:64G(#T^
M("=S=')T;W5P<&5R*")<;EQN(B`N(%PG7#%<)R`N(")<;EQN(BDG+`H*("`@
M("`@("`@("`@+R\@:#0@+2!H-@H@("`@("`@("`@("`G+SQH6S0U-EU;7CY=
M*CXH+BL_*3Q<+VA;-#4V73X@/R]I92<@/3X@)W5C=V]R9',H(EQN7&XB("X@
M7"=<,5PG("X@(EQN7&XB*2<L"@H@("`@("`@("`@("`O+R`\<#X*("`@("`@
M("`@("`@)R\\<%M>/ETJ/B`_+VDG(#T^(")<;EQN("`B+`H*("`@("`@("`@
M("`@+R\@/&)R/@H@("`@("`@("`@("`G+SQB<EM>/ETJ/B`_+VDG(#T^(")<
M;B(L"@H@("`@("`@("`@("`O+R`\8CX*("`@("`@("`@("`@)R\\8EM>/ETJ
M/B@N*S\I/%PO8CXO:64G(#T^("=S=')T;W5P<&5R*%PG7#%<)RDG+`H*("`@
M("`@("`@("`@+R\@/'-T<F]N9SX*("`@("`@("`@("`@)R\\<W1R;VYG6UX^
M72H^*"XK/RD\7"]S=')O;F<^+VEE)R`]/B`G<W1R=&]U<'!E<BA<)UPQ7"<I
M)RP*("`@("`@("`@("`@)R\\<W!A;EQ<<RMS='EL93TB9F]N="UW96EG:'0Z
M7%QS*F)O;&0N*B(^*"XK/RD\7"]S<&%N/B]I92<@/3X@)W-T<G1O=7!P97(H
M7"=<,5PG*2<L"@H@("`@("`@("`@("`O+R`\:3X*("`@("`@("`@("`@)R\\
M:5M>/ETJ/B@N*S\I/%PO:3XO:2<@/3X@)R]<7#$O)RP*"B`@("`@("`@("`@
M("\O(#QE;3X*("`@("`@("`@("`@)R\\96U;7CY=*CXH+BL_*3Q<+V5M/B]I
M)R`]/B`G+UQ<,2\G+`H*("`@("`@("`@("`@+R\@/'4^"B`@("`@("`@("`@
M("<O/'5;7CY=*CXH+BL_*3Q<+W4^+VDG(#T^("=?7%PQ7R<L"@H@("`@("`@
M("`@("`O+R`\=6P^+SQO;#X@86YD(#PO=6P^+SPO;VP^"B`@("`@("`@("`@
M("<O*#PH=7QO*6Q;7CY=*CY\(#\\7"\H=7QO*6P^*2`_+VDG(#T^(")<;EQN
M(BP*"B`@("`@("`@("`@("\O(#QL:3X*("`@("`@("`@("`@)R\@/SQL:5M>
M/ETJ/B]I)R`]/B`B7&X@("H@(BP*"B`@("`@("`@("`@("\O(#QA(&AR968]
M(B(^"B`@("`@("`@("`@("<O/&$@:')E9CTB*%M>(ETK*2);7CY=*CXH+BL_
M*3Q<+V$^+VEE)R`]/B`G5&5X=%]&:6QT97)?:'1M;#)T97AT.CI?8G5I;&1,
M:6YK3&ES="@D1TQ/0D%,4ULB7VAT;6PR=&5X=%]S=&%T92)=6R)L:6YK0V]U
M;G0B72P@7"=<,5PG+"!<)UPR7"<I)RP*"B`@("`@("`@("`@("\O(#QH<CX*
M("`@("`@("`@("`@)R\\:');7CY=*CX@/R]I)R`]/B`B7&XM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM7&XB+`H*("`@("`@("`@("`@+R\@/'1A8FQE/B!A
M;F0@/"]T86)L93X*("`@("`@("`@("`@)R\H/'1A8FQE6UX^72H^?"`_/%PO
M=&%B;&4^*2`_+VDG(#T^(")<;EQN(BP*"B`@("`@("`@("`@("\O(#QT<CX*
M("`@("`@("`@("`@)R\@/SQT<EM>/ETJ/B`_+VDG(#T^(")<;EQT(BP*"B`@
M("`@("`@("`@("\O(#QT9#X@86YD(#PO=&0^"B`@("`@("`@("`@("<O(#\\
M=&1;7CY=*CXH+BL_*3Q<+W1D/B`_+VDG(#T^("=<,2<@+B`B7'1<="(L"B`@
M("`@("`@("`@("<O7'1<=#Q<+W1R/B]I)R`]/B`G)RP*"B`@("`@("`@("`@
M("\O(&5N=&ET:65S"B`@("`@("`@("`@("<O)FYB<W`[+VDG(#T^("<@)RP*
M("`@("`@("`@("`@)R\F=')A9&4[+VDG(#T^("<H=&TI)RP*("`@("`@("`@
M("`@)R\F(RA<9"LI.R]E)R`]/B`G4W1R:6YG.CIC;VYV97)T0VAA<G-E="A4
M97AT7T9I;'1E<E]H=&UL,G1E>'0Z.E]I;G0R=71F."A<)UPQ7"<I+"`B551&
M+3@B+"`B)R`N("1T:&ES+3Y?<&%R86US6R=C:&%R<V5T)UT@+B`G(BDG+`H*
M("`@("`@("`@("`@+R\@4V]M92!M86EL97)S("AE+F<N($AO=&UA:6PI('5S
M92!T:&4@9F]L;&]W:6YG(&1I=B!T86<@87,@82!W87D*("`@("`@("`@("`@
M+R\@=&\@9&5F:6YE(&$@8FQO8VL@;V8@=&5X="X*("`@("`@("`@("`@)R\\
M9&EV(&-L87-S/7)T93XH+BL_*3Q<+V1I=CX@/R]I)R`]/B`G7#$G("X@(EQN
M(@H@("`@("`@("D["@H@("`@("`@(')E='5R;B!A<G)A>2@G<F5G97AP)R`]
M/B`D<F5G97AP*3L*("`@('T*"B`@("`O*BH*("`@("`J($5X96-U=&5S(&%N
M>2!C;V1E(&YE8V5S<V%R87D@869T97(@87!P;'EI;F<@=&AE(&9I;'1E<@H@
M("`@("H@<&%T=&5R;G,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=&5X="`@5&AE('1E>'0@869T97(@=&AE(&9I;'1E<FEN9RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&UO9&EF:65D('1E>'0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('!O<W10<F]C97-S*"1T97AT*0H@("`@>PH@("`@
M("`@(&=L;V)A;"`D7VAT;6PR=&5X=%]S=&%T93L*"B`@("`@("`@+RH@4W1R
M:7`@86YY(&]T:&5R($A434P@=&%G<RX@*B\*("`@("`@("`D=&5X="`]('-T
M<FEP7W1A9W,H)'1E>'0I.PH*("`@("`@("`O*B!#;VYV97)T(&AT;6P@96YT
M:71I97,N("HO"B`@("`@("`@)'1E>'0@/2!`:'1M;%]E;G1I='E?9&5C;V1E
M*"1T97AT+"!%3E1?455/5$53+"`D=&AI<RT^7W!A<F%M<ULG8VAA<G-E="==
M*3L*"B`@("`@("`@+RH@0G)I;F<@9&]W;B!N=6UB97(@;V8@96UP='D@;&EN
M97,@=&\@,B!M87@N("HO"B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H
M(B]<;EM;.G-P86-E.EU=*UQN+R(L(")<;EQN(BP@)'1E>'0I.PH@("`@("`@
M("1T97AT(#T@<')E9U]R97!L86-E*"(O6UQN77LS+'TO(BP@(EQN7&XB+"`D
M=&5X="D["@H@("`@("`@("\J(%=R87`@=&AE('1E>'0@=&\@82!R96%D86)L
M92!F;W)M870N("HO"B`@("`@("`@:68@*"1T:&ES+3Y?<&%R86US6R=W<F%P
M)UTI('L*("`@("`@("`@("`@)'1E>'0@/2!W;W)D=W)A<"@D=&5X="P@)'1H
M:7,M/E]P87)A;7-;)W=I9'1H)UTI.PH@("`@("`@('T*"B`@("`@("`@+RH@
M061D(&QI;FL@;&ES="X@*B\*("`@("`@("!I9B`H(65M<'1Y*"1?:'1M;#)T
M97AT7W-T871E6R=L:6YK3&ES="==*2D@>PH@("`@("`@("`@("`D=&5X="`N
M/2`B7&Y<;B(@+B!?*"),:6YK<R(I("X@(CI<;B(@+B!S=')?<F5P96%T*"<M
M)RP@4W1R:6YG.CIL96YG=&@H7R@B3&EN:W,B*2D@*R`Q*2`N(")<;B(@+B`D
M7VAT;6PR=&5X=%]S=&%T95LG;&EN:TQI<W0G73L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D=&5X=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE(%541BTX(&-H87)A8W1E<B!S97%U96YC92!O9B!A(%5N:6-O9&4@
M=F%L=64N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&YU;2`@02!5
M;FEC;V1E('9A;'5E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@551&+3@@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!?:6YT,G5T
M9C@H)&YU;2D*("`@('L*("`@("`@("!I9B`H)&YU;2`\(#$R."D@>PH@("`@
M("`@("`@("!R971U<FX@8VAR*"1N=6TI.PH@("`@("`@('T*("`@("`@("!I
M9B`H)&YU;2`\(#(P-#@I('L*("`@("`@("`@("`@<F5T=7)N(&-H<B@H)&YU
M;2`^/B`V*2`K(#$Y,BD@+B!C:'(H*"1N=6T@)B`V,RD@*R`Q,C@I.PH@("`@
M("`@('T*("`@("`@("!I9B`H)&YU;2`\(#8U-3,V*2!["B`@("`@("`@("`@
M(')E='5R;B!C:'(H*"1N=6T@/CX@,3(I("L@,C(T*2`N(&-H<B@H*"1N=6T@
M/CX@-BD@)B`V,RD@*R`Q,C@I("X*("`@("`@("`@("`@("`@(&-H<B@H)&YU
M;2`F(#8S*2`K(#$R."D["B`@("`@("`@?0H@("`@("`@(&EF("@D;G5M(#P@
M,C`Y-S$U,BD@>PH@("`@("`@("`@("!R971U<FX@8VAR*"@D;G5M(#X^(#$X
M*2`K(#(T,"D@+B!C:'(H*"@D;G5M(#X^(#$R*2`F(#8S*2`K(#$R."D@+@H@
M("`@("`@("`@("`@("`@8VAR*"@H)&YU;2`^/B`V*2`F(#8S*2`K(#$R."D@
M+B!C:'(H*"1N=6T@)B`V,RD@*R`Q,C@I.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@)R<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!(96QP97(@9G5N8W1I
M;VX@8V%L;&5D(&)Y('!R96=?<F5P;&%C92@I(&]N(&QI;FL@<F5P;&%C96UE
M;G0N"B`@("`@*@H@("`@("H@36%I;G1A:6YS(&%N(&EN=&5R;F%L(&QI<W0@
M;V8@;&EN:W,@=&\@8F4@9&ES<&QA>65D(&%T('1H92!E;F0*("`@("`J(&]F
M('1H92!T97AT+"!W:71H(&YU;65R:6,@:6YD:6-E<R!T;R!T:&4@;W)I9VEN
M86P@<&]I;G0@:6X@=&AE"B`@("`@*B!T97AT('1H97D@87!P96%R960N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&QI;FM?8V]U;G0@($-O=6YT97(@=')A8VMI;F<@8W5R
M<F5N="!L:6YK(&YU;6)E<BX*("`@("`J($!P87)A;2!S=')I;F<@("1L:6YK
M("`@("`@("!54DP@;V8@=&AE(&QI;FLN"B`@("`@*B!`<&%R86T@<W1R:6YG
M("`D9&ES<&QA>2`@("`@4&%R="!O9B!T:&4@=&5X="!T;R!A<W-O8VEA=&4@
M;G5M8F5R('=I=&@N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!L:6YK(')E<&QA8V5M96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8G5I
M;&1,:6YK3&ES="@D;&EN:U]C;W5N="P@)&QI;FLL("1D:7-P;&%Y*0H@("`@
M>PH@("`@("`@(&=L;V)A;"`D7VAT;6PR=&5X=%]S=&%T93L*"B`@("`@("`@
M)%]H=&UL,G1E>'1?<W1A=&5;)VQI;FM#;W5N="==*RL["B`@("`@("`@)%]H
M=&UL,G1E>'1?<W1A=&5;)VQI;FM,:7-T)UT@+CT@)ULG("X@)%]H=&UL,G1E
M>'1?<W1A=&5;)VQI;FM#;W5N="==("X@(ET@)&QI;FM<;B(["B`@("`@("`@
M<F5T=7)N("1D:7-P;&%Y("X@)ULG("X@)%]H=&UL,G1E>'1?<W1A=&5;)VQI
M;FM#;W5N="==("X@)UTG.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R
M+V5M;W1I8V]N<RYP:'``````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$P-#<V
M(#$P-3$U-#,S-S,W(#`R-#(T-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D92YP
M:'`G.PH*+RHJ"B`J(%1H92!497AT7T9I;'1E<E]E;6]T:6-O;G,Z.B!C;&%S
M<R!F:6YD<R!E;6]T:6-O;B!S=')I;F=S("@@.BDL(&5T8RXI(&EN(&$*("H@
M8FQO8VL@;V8@=&5X="!A;F0@='5R;G,@=&AE;2!I;G1O(&EM86=E(&QI;FMS
M+@H@*@H@*B!087)A;65T97)S.@H@*B`\<')E/@H@*B!E;G1I=&EE<R`M+2!)
M9B!T<G5E('1H92!H=&UL(&5N=&ET>2!V97)S:6]N<R!O9B!T:&4@<&%T=&5R
M;G,@=VEL;"!B92!U<V5D+@H@*B`\+W!R93X*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M;W1I8V]N<RYP:'`L=B`Q+C$W
M+C$P+C$P(#(P,#8O,#<O,C0@,#0Z-#@Z,3<@<VQU<V%R>B!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L
M;RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9"!N;W0*
M("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-87)K;R!$:G5K
M:6,@/&UA<FMO0&]B;&\N8V]M/@H@*B!`<&%C:V%G92!(;W)D95]497AT"B`J
M+PIC;&%S<R!497AT7T9I;'1E<E]E;6]T:6-O;G,@97AT96YD<R!497AT7T9I
M;'1E<B!["@H@("`@+RHJ"B`@("`@*B!&:6QT97(@<&%R86UE=&5R<RX*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A<F%M
M<R`](&%R<F%Y*"=E;G1I=&EE<R<@/3X@9F%L<V4I.PH*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!A(&AA<V@@=VET:"!R97!L86-E('!A='1E<FYS+@H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@(%!A='1E<FYS(&AA<V@N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=%!A='1E<FYS*"D*("`@('L*("`@("`@("`D
M<F5G97AP(#T@87)R87DH*3L*("`@("`@("`D:6-O;G!A=&@@/2`D1TQ/0D%,
M4ULG<F5G:7-T<GDG72T^9V5T26UA9V5$:7(H)VAO<F1E)RD@+B`G+V5M;W1I
M8V]N<R<["@H@("`@("`@("\J($QO;W`@=&AR;W5G:"!P;W-S:6)L92!S=')I
M;F<@96UO=&EC;VYS(&%N9"!C;VYV97)T('1O(&=R87!H:6-S+B`J+PH@("`@
M("`@(&9O<F5A8V@@*"1T:&ES+3YG971)8V]N<R@I(&%S("1S=')I;F<@/3X@
M)&EC;VXI('L*("`@("`@("`@("`@)&)E9U]P871T97)N(#T@)RA>?%QS*2<[
M"B`@("`@("`@("`@("1E;F1?<&%T=&5R;B`]("<H/SU<<RDG.PH@("`@("`@
M("`@("!I9B`H)'1H:7,M/E]P87)A;7-;)V5N=&ET:65S)UTI('L*("`@("`@
M("`@("`@("`@("1S=')I;F<@/2!H=&UL<W!E8VEA;&-H87)S*"1S=')I;F<I
M.PH@("`@("`@("`@("`@("`@)&)E9U]P871T97)N(#T@)RA>?%QS?#QB<B`O
M/GPF;F)S<#LI)SL*("`@("`@("`@("`@("`@("1E;F1?<&%T=&5R;B`]("<H
M/SU<<WP\8G(@+SY\)FYB<W`[*2<["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("\J($-H96-K(&9O<B!A('-M:6QE>2!E:71H97(@:6UM961I871E;'D@
M870@=&AE('-T87)T(&]F(&$@;&EN92!O<@H@("`@("`@("`@("`@*B!F;VQL
M;W=I;F<@82!S<&%C92X@57-E('M](&%S('1H92!P<F5G(&1E;&EM:71E<G,@
M87,@=&AI<R!I<R!N;W0*("`@("`@("`@("`@("H@9F]U;F0@:6X@86YY('-M
M:6QE>2X@*B\*("`@("`@("`@("`@)')E9V5X<%LG>R<@+B`D8F5G7W!A='1E
M<FX@+B!P<F5G7W%U;W1E*"1S=')I;F<I("X@)&5N9%]P871T97)N("X@)WTG
M72`]("=<7#$G("X@2&]R9&4Z.FEM9R@D:6-O;B`N("<N<&YG)RP@)'-T<FEN
M9RP@87)R87DH)V%L:6=N)R`]/B`G;6ED9&QE)RP@)W1I=&QE)R`]/B`D<W1R
M:6YG*2P@)&EC;VYP871H*2`N("@H)'1H:7,M/E]P87)A;7-;)V5N=&ET:65S
M)UTI(#\@)UQ<,B<@.B`G)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M87)R87DH)W)E9V5X<"<@/3X@)')E9V5X<"D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS(&$@:&%S:"!W:71H(&5M;W1I8V]N<R!A;F0@;F%M97,N
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@4&%T=&5R;G,@:&%S:"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T26-O;G,H*0H@("`@>PH@("`@("`@
M("\J($QI<W0@8V]M<&QE>"!S=')I;F=S(&)E9F]R92!S:6UP;&5R(&]N97,L
M(&]T:&5R=VES92!F;W(@97AA;7!L92`Z*"@*("`@("`@("`@*B!W;W5L9"!B
M92!M871C:&5D(&%G86EN<W0@.B@@8F5F;W)E(#HH*"!I<R!F;W5N9"X@*B\*
M("`@("`@("!R971U<FX@87)R87DH"B`@("`@("`@("`@("<Z+R<@/3X@)V9R
M=7-T<F%T960G+"`G.BTO)R`]/B`G9G)U<W1R871E9"<L"B`@("`@("`@("`@
M("\O("<Z*CXG(#T^("=B;'5S:"<L"B`@("`@("`@("`@("<Z92<@/3X@)V1I
M<V%P<&]I;G1E9"<L"B`@("`@("`@("`@("<].BDD)R`]/B`G;7)T)RP*("`@
M("`@("`@("`@)R-\)R`]/B`G:&%N9V]V97(G+"`G(RU\)R`]/B`G:&%N9V]V
M97(G+`H@("`@("`@("`@("`G.BU`)R`]/B`G<VAO=70G+`H@("`@("`@("`@
M("`G.B@H)R`]/B`G8FEG9G)O=VXG+"`G.D,G(#T^("=B:6=F<F]W;B<L"B`@
M("`@("`@("`@("<Z4R<@/3X@)V1A>F5D)RP@)SHM4R<@/3X@)V1A>F5D)RP*
M("`@("`@("`@("`@)UA`)R`]/B`G86YG<GDG+`H@("`@("`@("`@("`G6"@G
M(#T^("=M860G+`H@("`@("`@("`@("`O+R`G/CHI)R`]/B`G9&5V:6PG+"`G
M/CHM*2<@/3X@)V1E=FEL)RP*("`@("`@("`@("`@+R\@)SXZ<"<@/3X@)V1E
M=FEL=&]N9W5E)RP@)SXZ+7`G(#T^("=D979I;'1O;F=U92<L"B`@("`@("`@
M("`@("\O("<^.G`G(#T^("=R87-P8F5R<GDG+"`G/CI0)R`]/B`G<F%S<&)E
M<G)Y)RP*("`@("`@("`@("`@+R\@)R8I)R`]/B`G<'5N:R<L"B`@("`@("`@
M("`@("\O("<F<"<@/3X@)W!U;FMT;VYG=64G+`H@("`@("`@("`@("`O+R`G
M/28I)R`]/B`G<'5N:VUO:&%W:R<L"B`@("`@("`@("`@("<Z72<@/3X@)V=R
M:6XG+`H@("`@("`@("`@("`G(ULG(#T^("=H=7)T)RP@)R,H)R`]/B`G:'5R
M="<L("<C+5LG(#T^("=H=7)T)RP@)R,M*"<@/3X@)VAU<G0G+`H@("`@("`@
M("`@("`G.D\G(#T^("=E;6)A<G)A<W-E9"<L("<Z+4\G(#T^("=E;6)A<G)A
M<W-E9"<L"B`@("`@("`@("`@("<Z6R<@/3X@)W-A9"<L"B`@("`@("`@("`@
M("\O("<^.D`G(#T^("=E;G)A9V5D)RP*("`@("`@("`@("`@+R\@)SHF)R`]
M/B`G86YN;WEE9"<L"B`@("`@("`@("`@("<]*"<@/3X@)W=O<G)I960G+"`G
M/2TH)R`]/B`G=V]R<FEE9"<L"B`@("`@("`@("`@("<Z?#TG(#T^("=V86UP
M:7)E)RP*("`@("`@("`@("`@)SHM*"<@/3X@)V9R;W=N)RP*("`@("`@("`@
M("`@)SI$)R`]/B`G8FEG9W)I;B<L"B`@("`@("`@("`@("<X*2<@/3X@)V-O
M;VPG+`H@("`@("`@("`@("`O+R!);B!%;F=L:7-H+"`X4$T@;V-C=7)S('-U
M9F9I8VEE;G1L>2!O9G1E;B!T;R!S<&5C:69I8V%L;'D*("`@("`@("`@("`@
M+R\@<V5A<F-H(&9O<B!A;F0@97AC;'5D90H@("`@("`@("`@("`G.'`H/SPA
M6TUM75QS*RDG(#T^("=C;V]L=&]N9W5E)RP@+R\@)SC>)R`]/B`G8V]O;'1O
M;F=U92<L"B`@("`@("`@("`@("<X1"<@/3X@)V-O;VQG<FEN)RP*("`@("`@
M("`@("`@)SIP)R`]/B`G=&]N9W5E;W5T)RP@)SI0)R`]/B`G=&]N9W5E;W5T
M)RP@+R\@)SK>)R`]/B`G=&]N9W5E;W5T)RP*("`@("`@("`@("`@)S\Z*"<@
M/3X@)V-O;F9U<V5D)RP@)R4M*"<@/3X@)V-O;F9U<V5D)RP*("`@("`@("`@
M("`@+R\@)SHI)B<@/3X@)VQO=F4G+`H@("`@("`@("`@("`G3SLM*2<@/3X@
M)V%N9V5L=VEN:R<L"B`@("`@("`@("`@("<[72<@/3X@)W=I;FMG<FEN)RP*
M("`@("`@("`@("`@)SMP)R`]/B`G=VEN:W1O;F=U92<L("<[4"<@/3X@)W=I
M;FMT;VYG=64G+"`O+R`G.]XG(#T^("=W:6YK=&]N9W5E)RP*("`@("`@("`@
M("`@)SI\)R`]/B`G:6YD:69F97)E;G0G+"`G.BU\)R`]/B`G:6YD:69F97)E
M;G0G+`H@("`@("`@("`@("`G(7PG(#T^("=T:7)E9"<L("<A+4DG(#T^("=T
M:7)E9"<L"B`@("`@("`@("`@("=\22<@/3X@)V%S;&5E<"<L("=\+4DG(#T^
M("=A<VQE97`G+`H@("`@("`@("`@("`G3SHI)R`]/B`G86YG96PG+"`G3SHM
M*2<@/3X@)V%N9V5L)RP*("`@("`@("`@("`@)T\[*2<@/3X@)V%N9V5L=VEN
M:R<L"B`@("`@("`@("`@("<[+2DG(#T^("=W:6YK)RP*("`@("`@("`@("`@
M)SHC*2<@/3X@)V-L;W=N)RP@)SIO*2<@/3X@)V-L;W=N)RP*("`@("`@("`@
M("`@)SHI)R`]/B`G<VUI;&4G+`H@("`@("`@("`@("`G.RDG(#T^("=W:6YK
M)RP*("`@("`@("`@("`@)SHM*2<@/3X@)W-M:6QE)RP*("`@("`@("`@("`@
M)SI`)R`]/B`G<VAO=70G+`H@("`@("`@("`@("`G.B@G(#T^("=F<F]W;B<L
M"B`@("`@("`@*3L*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O5&5X="]&:6QT97(O=&%B<S)S<&%C
M97,N<&AP````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(U,#,@,3`U,34T,S,W
M,S<@,#(T-#0V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!4:&4@5&5X=%]&:6QT97)?=&%B<S)S<&%C
M97,Z.B!C;VYV97)T<R!T86)S(&EN=&\@<W!A8V5S+@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O=&%B<S)S<&%C97,N<&AP
M+'8@,2XS+C$P+C8@,C`P-B\P,2\P,2`R,3HR.#HS."!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED
M(&YO=`H@*B!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K
M($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!(;W)D
M95]497AT"B`J+PIC;&%S<R!497AT7T9I;'1E<E]T86)S,G-P86-E<R!E>'1E
M;F1S(%1E>'1?1FEL=&5R('L*"B`@("`O*BH*("`@("`J($9I;'1E<B!P87)A
M;65T97)S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1?<&%R86US(#T@87)R87DH)W1A8G-T;W`G(#T^(#@L("=B<F5A:V-H
M87(G(#T^(")<;B(I.PH*("`@("\J*@H@("`@("H@17AE8W5T97,@86YY(&-O
M9&4@;F5C97-S87)Y(&)E9F]R92!A<'!L>6EN9R!T:&4@9FEL=&5R('!A='1E
M<FYS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!T
M97AT(&)E9F]R92!T:&4@9FEL=&5R:6YG+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@;6]D:69I960@=&5X="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<')E4')O8V5S<R@D=&5X="D*("`@('L*("`@("`@("`D;&EN97,@
M/2!E>'!L;V1E*"1T:&ES+3Y?<&%R86US6R=B<F5A:V-H87(G72P@)'1E>'0I
M.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1L:6YE<RD[("1I
M*RLI('L*("`@("`@("`@("`@=VAI;&4@*"@D<&]S(#T@<W1R<&]S*"1L:6YE
M<ULD:5TL(")<="(I*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1N
M7W-P86-E(#T@)'1H:7,M/E]P87)A;7-;)W1A8G-T;W`G72`M("@D<&]S("4@
M)'1H:7,M/E]P87)A;7-;)W1A8G-T;W`G72D["B`@("`@("`@("`@("`@("`D
M;F5W7W-T<B`]('-T<E]R97!E870H)R`G+"`D;E]S<&%C92D["B`@("`@("`@
M("`@("`@("`D;&EN97-;)&E=(#T@<W5B<W1R7W)E<&QA8V4H)&QI;F5S6R1I
M72P@)&YE=U]S='(L("1P;W,L(#$I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@("`@(')E='5R;B!I;7!L;V1E*")<;B(L("1L:6YE<RD["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]497AT+T9I;'1E<B]T97AT,FAT;6PN<&AP````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`Q,C0V-R`Q,#4Q-30S,S<S-R`P,C0R,#$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*"G)E<75I<F5?
M;VYC92`G2&]R9&4N<&AP)SL*"B\J*@H@*B!4=7)N('1E>'0@:6YT;R!(5$U,
M('=I=&@@=F%R>6EN9R!L979E;',@;V8@<&%R<VEN9RX@($9O<B!N;R!H=&UL
M"B`J('=H871S;V5V97(L('5S92!H=&UL<W!E8VEA;&-H87)S*"D@:6YS=&5A
M9"X*("H*("H@4&%R86UE=&5R<SH*("H@/'!R93X*("H@<&%R<V5L979E;"`M
M+2!4:&4@<&%R<V5L979E;"!O9B!T:&4@;W5T<'5T+B!3964@=&AE(&QI<W0@
M;V8@8V]N<W1A;G1S(&)E;&]W+@H@*B!C:&%R<V5T("`@("TM(%1H92!C:&%R
M<V5T('1O('5S92!F;W(@:'1M;'-P96-I86QC:&%R<R@I(&-A;&QS+@H@*B!C
M;&%S<R`@("`@("TM(%1H92!#4U,@8VQA<W,@;F%M92!F;W(@=&AE(&QI;FMS
M+@H@*B!N;V9O;&QO=R`@("TM(%=H971H97(@=&\@<V5T('1H92`G<F5L/2)N
M;V9O;&QO=R(G(&%T=')I8G5T92!O;B!L:6YK<RX*("H@8V%L;&)A8VL@("`M
M+2!!;B!O<'1I;VYA;"!C86QL8F%C:R!F=6YC=&EO;B!T:&%T('1H92!54DP@
M:7,@<&%S<V5D('1H<F]U9V@*("H@("`@("`@("`@("`@("!B969O<F4@8F5I
M;F<@<V5T(&%S('1H92!H<F5F(&%T=')I8G5T92X@($UU<W0@8F4@82!S=')I
M;F<@=VET:`H@*B`@("`@("`@("`@("`@('1H92!F=6YC=&EO;B!N86UE+"!T
M:&4@9G5N8W1I;VX@;75S="!T86ME('1H92!O<FEG:6YA;"!A<R!T:&4*("H@
M("`@("`@("`@("`@("!F:7)S="!A;F0@;VYL>2!P87)A;65T97(N"B`J(#PO
M<')E/@H@*@H@*B`\<')E/@H@*B!,:7-T(&]F('9A;&ED(&-O;G-T86YT<R!F
M;W(@=&AE('!A<G-E(&QE=F5L.@H@*B`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H@*B!415A47TA434Q?4$%34U1(4E4@
M("`@("`@(#T@($YO(&%C=&EO;BX@4&%S<RUT:')O=6=H+B!);F-L=61E9"!F
M;W(*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C;VUP;&5T96YE
M<W,N"B`J(%1%6%1?2%1-3%]364Y405@@("`@("`@("`@/2`@06QL;W<@9G5L
M;"!H=&UL+"!A;'-O(&1O(&QI;F4M8G)E86MS+`H@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&EN+6QI;FEN9RP@<WEN=&%X+7!A<G-I;F<N"B`J
M(%1%6%1?2%1-3%]-24-23R`@("`@("`@("`@/2`@36EC<F\@:'1M;"`H;VYL
M>2!L:6YE+6)R96%K<RP@:6XM;&EN92!L:6YK:6YG*2X*("H@5$585%](5$U,
M7TU)0U)/7TQ)3DM54DP@("`]("!-:6-R;R!H=&UL("AO;FQY(&QI;F4M8G)E
M86MS+"!I;BUL:6YE(&QI;FMI;F<*("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!O9B!54DQ3<SL@;F\@96UA:6P@861D<F5S<V5S(&%R92!L:6YK
M960I+@H@*B!415A47TA434Q?3D](5$U,("`@("`@("`@(#T@($YO(&AT;6P@
M*&%L;"!S=')I<'!E9"P@;VYL>2!L:6YE+6)R96%K<RD*("H@5$585%](5$U,
M7TY/2%1-3%].3T)214%+("`]("!.;R!H=&UL('=H871S;V5V97(L(&YO(&QI
M;F4@8G)E86MS(&%D9&5D+@H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@($EN8VQU9&5D(&9O<B!C;VUP;&5T96YE<W,N"B`J(#PO<')E/@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O=&5X=#)H
M=&UL+G!H<"QV(#$N-"XR+C8@,C`P-B\P,B\Q-R`R,#HP-3HT.2!C:'5C:R!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($IA
M;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@268@>6]U(&1I9`H@*B!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@
M*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*
M("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@
M0'!A8VMA9V4@2&]R9&5?5&5X=`H@*B\*8VQA<W,@5&5X=%]&:6QT97)?=&5X
M=#)H=&UL(&5X=&5N9',@5&5X=%]&:6QT97(@>PH*("`@("\J*@H@("`@("H@
M1FEL=&5R('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A>2@G8VAA<G-E="<@/3X@
M;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("=C;&%S<R<@/3X@)V9I
M>&5D)RP*("`@("`@("`@("`@("`@("`@("`@("`@("=N;V9O;&QO=R<@/3X@
M9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`G8V%L;&)A8VLG(#T^
M("=(;W)D93HZ97AT97)N86Q5<FPG*3L*"B`@("`O*BH*("`@("`J($5X96-U
M=&5S(&%N>2!C;V1E(&YE8V5S<V%R>2!B969O<F4@87!P;'EI;F<@=&AE(&9I
M;'1E<B!P871T97)N<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T
M97AT("!4:&4@=&5X="!B969O<F4@=&AE(&9I;'1E<FEN9RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&UO9&EF:65D('1E>'0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('!R95!R;V-E<W,H)'1E>'0I"B`@("!["B`@("`@
M("`@:68@*&ES7VYU;&PH)'1H:7,M/E]P87)A;7-;)V-H87)S970G72DI('L*
M("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V-H87)S970G72`](&ES<V5T
M*"1'3$]"04Q36R=?2$]21$5?4U1224Y'7T-(05)3150G72D@/R`D1TQ/0D%,
M4ULG7TA/4D1%7U-44DE.1U]#2$%24T54)UT@.B`G25-/+3@X-3DM,2<["B`@
M("`@("`@?0H*("`@("`@("`O*B!!8F]R="!O=70@;VX@<VEM<&QE(&-A<V5S
M+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7W!A<F%M<ULG<&%R<V5L979E;"==
M(#T](%1%6%1?2%1-3%]005-35$A252D@>PH@("`@("`@("`@("!R971U<FX@
M)'1E>'0["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^7W!A<F%M<ULG
M<&%R<V5L979E;"==(#T](%1%6%1?2%1-3%].3TA434Q?3D]"4D5!2RD@>PH@
M("`@("`@("`@("!R971U<FX@0&AT;6QS<&5C:6%L8VAA<G,H)'1E>'0L($5.
M5%]#3TU0050L("1T:&ES+3Y?<&%R86US6R=C:&%R<V5T)UTI.PH@("`@("`@
M('T*"B`@("`@("`@+RH@1&\@:6XM;&EN:6YG(&]F(&AT='`Z+R]X>'@N>'AX
M('1O(&QI;FLL('AX>$!X>'@N>'AX('1O(&5M86EL+"!P87)T"B`@("`@("`@
M("H@;VYE+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7W!A<F%M<ULG<&%R<V5L
M979E;"==(#P@5$585%](5$U,7TY/2%1-3"D@>PH@("`@("`@("`@("`O*B!-
M86ME('-U<F4@=&AA="!T:&4@;W)I9VEN86P@;65S<V%G92!D;V5S;B=T(&-O
M;G1A:6X@86YY(&-A<&ET86P*("`@("`@("`@("`@("H@/"]!/B!T86=S(&]R
M(&]P96X@/$$^('1A9W,@+"!S;R!W92!C86X@87-S=6UE('=E(&=E;F5R871E
M9`H@("`@("`@("`@("`@*B!T:&5M+B`J+PH@("`@("`@("`@("`D=&5X="`]
M('-T<E]R97!L86-E*&%R<F%Y*"<\+T$^)RP@)SQ!)RDL(&%R<F%Y*"<\+V$^
M)RP@)SQA)RDL("1T97AT*3L*("`@("`@("`@("`@)&9I;'1E<E]A<G)A>2`]
M(&%R<F%Y*"=L:6YK=7)L<R<I.PH@("`@("`@("`@("`D9FEL=&5R7W!A<F%M
M<R`](&%R<F%Y*&%R<F%Y*"=C86QL8F%C:R<@/3X@)'1H:7,M/E]P87)A;7-;
M)V-A;&QB86-K)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)VYO9F]L;&]W)R`]/B`D=&AI<RT^7W!A<F%M<ULG;F]F;VQL
M;W<G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G8V%P:71A;"<@/3X@=')U92DI.PH@("`@("`@("`@("!I9B`H)'1H:7,M
M/E]P87)A;7-;)W!A<G-E;&5V96PG72`\(%1%6%1?2%1-3%]-24-23U],24Y+
M55),*2!["B`@("`@("`@("`@("`@("`D9FEL=&5R7V%R<F%Y6UT@/2`G96UA
M:6QS)SL*("`@("`@("`@("`@("`@("1F:6QT97)?<&%R86US6UT@/2!A<G)A
M>2@G8V%P:71A;%]T86=S)R`]/B!T<G5E*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D=&5X="`](%1E>'1?1FEL=&5R.CIF:6QT97(H)'1E>'0L("1F
M:6QT97)?87)R87DL("1F:6QT97)?<&%R86US*3L*("`@("`@("!]"@H@("`@
M("`@("\J($9O<B!L979E;"!415A47TA434Q?34E#4D\L(%1%6%1?2%1-3%].
M3TA434PL('-T87)T('=I=&@*("`@("`@("`@*B!H=&UL<W!E8VEA;&-H87)S
M*"DN("HO"B`@("`@("`@)'1E>'0@/2!`:'1M;'-P96-I86QC:&%R<R@D=&5X
M="P@14Y47T-/35!!5"P@)'1H:7,M/E]P87)A;7-;)V-H87)S970G72D["@H@
M("`@("`@("\J($1O(&EN+6QI;FEN9R!O9B!H='1P.B\O>'AX+GAX>"!T;R!L
M:6YK+"!X>'A`>'AX+GAX>"!T;R!E;6%I;"P@<&%R=`H@("`@("`@("`J('1W
M;RX@*B\*("`@("`@("!I9B`H)'1H:7,M/E]P87)A;7-;)W!A<G-E;&5V96PG
M72`\(%1%6%1?2%1-3%].3TA434PI('L*("`@("`@("`@("`@)'-Y;G1A>"`]
M(&%R<F%Y*`H@("`@("`@("`@("`@("`@)R9L=#M!(&AR968])G%U;W0[)R`]
M/B`G/&$G("X@*&5M<'1Y*"1T:&ES+3Y?<&%R86US6R=C;&%S<R==*2`_("<G
M(#H@)R!C;&%S<STB)R`N("1T:&ES+3Y?<&%R86US6R=C;&%S<R==("X@)R(G
M*2`N("<@:')E9CTB)RP*("`@("`@("`@("`@("`@("<F<75O=#L@<F5L/29Q
M=6]T.R<@/3X@)R(@<F5L/2(G+`H@("`@("`@("`@("`@("`@)R9Q=6]T.R!T
M:71L93TF<75O=#LG(#T^("<B('1I=&QE/2(G+`H@("`@("`@("`@("`@("`@
M)R9Q=6]T.R!T87)G970])G%U;W0[7V)L86YK)G%U;W0[)F=T.R<@(#T^("<B
M('1A<F=E=#TB7V)L86YK(CXG+`H@("`@("`@("`@("`@("`@)R9Q=6]T.R!O
M;F-L:6-K/29Q=6]T.R<@/3X@)R(@;VYC;&EC:STB)RP*("`@("`@("`@("`@
M("`@("=<)RD[)G%U;W0[)F=T.R<@/3X@)UPG*3LB/B<L"B`@("`@("`@("`@
M("`@("`G)G%U;W0[)F=T.R<@/3X@("<B/B<L"B`@("`@("`@("`@("`@("`O
M*B!/;FQY(')E8V]N=F5R="!C87!I=&%L("]!('1A9W,@+2!T:&4@;VYE<R!W
M92!G96YE<F%T960N("HO"B`@("`@("`@("`@("`@("`G)FQT.R]!)F=T.R<@
M/3X@)SPO83XG"B`@("`@("`@("`@("`@("`I.PH*("`@("`@("`@("`@)'1E
M>'0@/2!S=')?<F5P;&%C92AA<G)A>5]K97ES*"1S>6YT87@I+"`D<WEN=&%X
M+"`D=&5X="D["B`@("`@("`@("`@("1T97AT(#T@5&5X=%]&:6QT97(Z.F9I
M;'1E<B@D=&5X="P@)W-P86-E,FAT;6PG*3L*("`@("`@("!]"@H@("`@("`@
M("\J($1O('1H92!B;&%N:RUL:6YE("TM+3X@/&)R("\^('-U8G-T:71U=&EO
M;BX@($5V97)Y8F]D>2!G971S('1H:7,["B`@("`@("`@("H@:68@>6]U(&1O
M;B=T('=A;G0@979E;B!T:&%T+"!J=7-T('-A=F4@=&AE(&AT;6QS<&5C:6%L
M8VAA<G,H*0H@("`@("`@("`J('9E<G-I;VX@;V8@=&AE(&EN<'5T+B`J+PH@
M("`@("`@("1T97AT(#T@;FPR8G(H)'1E>'0I.PH*("`@("`@("!R971U<FX@
M)'1E>'0["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]497AT+T9I;'1E<BYP:'``````
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,34T-2`Q,#4Q-30S
M,S<S-R`P,C(R-#(`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PH*9&5F
M:6YE*"=415A47TA434Q?4$%34U1(4E4G+"`P*3L*9&5F:6YE*"=415A47TA4
M34Q?4UE.5$%8)RP@,2D["F1E9FEN92@G5$585%](5$U,7TU)0U)/)RP@,BD[
M"F1E9FEN92@G5$585%](5$U,7TU)0U)/7TQ)3DM54DPG+"`S*3L*9&5F:6YE
M*"=415A47TA434Q?3D](5$U,)RP@-"D["F1E9FEN92@G5$585%](5$U,7TY/
M2%1-3%].3T)214%+)RP@-2D["@HO*BH*("H@5&5X=%]&:6QT97(Z.B!I<R!A
M('!A<F5N="!C;&%S<R!F;W(@9&5F:6YI;F<@<W1A8VMA8FQE('1E>'0@9FEL
M=&5R<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL
M=&5R+G!H<"QV(#$N,34N,BXY(#(P,#8O,#4O,3$@,3DZ-#DZ,30@8VAU8VL@
M17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U
M8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!*
M86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J
M($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]497AT"B`J
M+PIC;&%S<R!497AT7T9I;'1E<B!["@H@("`@+RHJ"B`@("`@*B!&:6QT97(@
M<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*
M("`@('9A<B`D7W!A<F%M<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#
M;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M
M<R`@06YY('!A<F%M971E<G,@=&AA="!T:&4@9FEL=&5R(&EN<W1A;F-E(&YE
M961S+@H@("`@("HO"B`@("!F=6YC=&EO;B!497AT7T9I;'1E<B@D<&%R86US
M(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^7W!A<F%M<R`](&%R
M<F%Y7VUE<F=E*"1T:&ES+3Y?<&%R86US+"`D<&%R86US*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($%P<&QI97,@82!S970@;V8@<&%T=&5R;G,@=&\@82!B
M;&]C:R!O9B!T97AT+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E
M>'0@("`@(%1H92!T97AT('1O(&9I;'1E<BX*("`@("`J($!P87)A;2!A<G)A
M>2`D<&%T=&5R;G,@(%1H92!A<G)A>2!O9B!P871T97)N<R!T;R!F:6QT97(@
M=VET:"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('1R86YS
M9F]R;65D('1E>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&9I;'1E<B@D=&5X
M="P@)&9I;'1E<G,@/2!A<G)A>2@I+"`D<&%R86US(#T@87)R87DH*2D*("`@
M('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1F:6QT97)S*2D@>PH@("`@("`@
M("`@("`D9FEL=&5R<R`](&%R<F%Y*"1F:6QT97)S*3L*("`@("`@("`@("`@
M)'!A<F%M<R`](&%R<F%Y*"1P87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@
M9F]R96%C:"`H)&9I;'1E<G,@87,@)&YU;2`]/B`D9FEL=&5R*2!["B`@("`@
M("`@("`@("1F:6QT97)/8B`](%1E>'1?1FEL=&5R.CIF86-T;W)Y*"1F:6QT
M97(L(&ES<V5T*"1P87)A;7-;)&YU;5TI(#\@)'!A<F%M<ULD;G5M72`Z(&%R
M<F%Y*"DI.PH@("`@("`@("`@("!I9B`H:7-?82@D9FEL=&5R3V(L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D9FEL=&5R3V(M
M/F=E=$UE<W-A9V4H*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<&%T
M=&5R;G,@/2`D9FEL=&5R3V(M/F=E=%!A='1E<FYS*"D["@H@("`@("`@("`@
M("`O*B!0<F4M<')O8V5S<VEN9RX@*B\*("`@("`@("`@("`@)'1E>'0@/2`D
M9FEL=&5R3V(M/G!R95!R;V-E<W,H)'1E>'0I.PH*("`@("`@("`@("`@+RH@
M<W1R7W)E<&QA8V4H*2!S:6UP;&4@<&%T=&5R;G,N("HO"B`@("`@("`@("`@
M(&EF("AI<W-E="@D<&%T=&5R;G-;)W)E<&QA8V4G72DI('L*("`@("`@("`@
M("`@("`@("1F<F]M(#T@87)R87E?:V5Y<R@D<&%T=&5R;G-;)W)E<&QA8V4G
M72D["B`@("`@("`@("`@("`@("`D=&\@/2!A<G)A>5]V86QU97,H)'!A='1E
M<FYS6R=R97!L86-E)UTI.PH@("`@("`@("`@("`@("`@)'1E>'0@/2!S=')?
M<F5P;&%C92@D9G)O;2P@)'1O+"`D=&5X="D["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("\J('!R96=?<F5P;&%C92!C;VUP;&5X('!A='1E<FYS+B`J
M+PH@("`@("`@("`@("!I9B`H:7-S970H)'!A='1E<FYS6R=R96=E>'`G72DI
M('L*("`@("`@("`@("`@("`@("1F<F]M(#T@87)R87E?:V5Y<R@D<&%T=&5R
M;G-;)W)E9V5X<"==*3L*("`@("`@("`@("`@("`@("1T;R`](&%R<F%Y7W9A
M;'5E<R@D<&%T=&5R;G-;)W)E9V5X<"==*3L*("`@("`@("`@("`@("`@("1T
M97AT(#T@<')E9U]R97!L86-E*"1F<F]M+"`D=&\L("1T97AT*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@+RH@4&]S="UP<F]C97-S:6YG+B`J+PH@
M("`@("`@("`@("`D=&5X="`]("1F:6QT97)/8BT^<&]S=%!R;V-E<W,H)'1E
M>'0I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T97AT.PH@("`@?0H*
M("`@("\J*@H@("`@("H@17AE8W5T97,@86YY(&-O9&4@;F5C97-S87)A>2!B
M969O<F4@87!P;'EI;F<@=&AE(&9I;'1E<@H@("`@("H@<&%T=&5R;G,N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@5&AE('1E>'0@8F5F
M;W)E('1H92!F:6QT97)I;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!M;V1I9FEE9"!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!P
M<F50<F]C97-S*"1T97AT*0H@("`@>PH@("`@("`@(')E='5R;B`D=&5X=#L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!H87-H('=I=&@@<F5P
M;&%C92!P871T97)N<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!0
M871T97)N<R!H87-H+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9710871T97)N
M<R@I"B`@("!["B`@("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!%>&5C=71E<R!A;GD@8V]D92!N96-E<W-A<F%Y(&%F=&5R
M(&%P<&QY:6YG('1H92!F:6QT97(*("`@("`J('!A='1E<FYS+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!T97AT(&%F=&5R('1H
M92!F:6QT97)I;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!M;V1I9FEE9"!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!P;W-T4')O
M8V5S<R@D=&5X="D*("`@('L*("`@("`@("!R971U<FX@)'1E>'0["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC<F5T
M92!497AT7V9I;'1E<B!I;G-T86YC92!B87-E9"!O;@H@("`@("H@)&1R:79E
M<BX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&1R:79E<B`@5&AE('1Y
M<&4@;V8@8V]N8W)E=&4@5&5X=%]&:6QT97(@<W5B8VQA<W,@=&\*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("!R971U<FXN(%1H:7,@:7,@8F%S960@
M;VX@=&AE(&9I;'1E<B!D<FEV97(*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`H)&1R:79E<BDN(%1H92!C;V1E(&ES(&1Y;F%M:6-A;&QY(&EN8VQU
M9&5D+B!)9@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("1D<FEV97(@
M:7,@86X@87)R87DL('1H96X@=V4@=VEL;"!L;V]K(&EN"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@)&1R:79E<ELP72!F;W(@=&AE('-U8F-L87-S
M(&EM<&QE;65N=&%T:6]N(&YA;65D"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@)&1R:79E<ELQ72YP:'`N"B`@("`@*B!`<&%R86T@87)R87D@)'!A
M<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@8V]N9FEG
M=7)A=&EO;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('!A<F%M971E
M<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@("`J($!R971U
M<FX@5&5X=%]&:6QT97(@(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R971E(%1E
M>'1?1FEL=&5R(&EN<W1A;F-E+`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@;W(@9F%L<V4@;VX@86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9F86-T;W)Y*"1D<FEV97(L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@
M("`@("`@(&EF("AI<U]A<G)A>2@D9')I=F5R*2D@>PH@("`@("`@("`@("!L
M:7-T*"1D:7(L("1D<FEV97(I(#T@)&1R:79E<CL*("`@("`@("!]"@H@("`@
M("`@(&EF("@A96UP='DH)&1I<BDI('L*("`@("`@("`@("`@<F5Q=6ER95]O
M;F-E("1D:7(@+B`G+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T@
M96QS96EF("A`9FEL95]E>&ES=',H9&ER;F%M92A?7T9)3$5?7RD@+B`G+T9I
M;'1E<B\G("X@)&1R:79E<B`N("<N<&AP)RDI('L*("`@("`@("`@("`@<F5Q
M=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]&:6QT97(O)R`N("1D
M<FEV97(@+B`G+G!H<"<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M0&EN8VQU9&5?;VYC92`G2&]R9&4O5&5X="]&:6QT97(O)R`N("1D<FEV97(@
M+B`G+G!H<"<["B`@("`@("`@?0H*("`@("`@("`D8VQA<W,@/2`G5&5X=%]&
M:6QT97)?)R`N("1D<FEV97(["B`@("`@("`@:68@*&-L87-S7V5X:7-T<R@D
M8VQA<W,I*2!["B`@("`@("`@("`@("1F:6QT97(@/2`F;F5W("1C;&%S<R@D
M<&%R86US*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9FEL=&5R
M(#T@4$5!4CHZ<F%I<V5%<G)O<B@G0VQA<W,@9&5F:6YI=&EO;B!O9B`G("X@
M)&-L87-S("X@)R!N;W0@9F]U;F0N)RD["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)&9I;'1E<CL*("`@('T*"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O5')E90``````````
M````````````````````````````````````````````````````````````
M````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@
M,3`U,34T,S,W,S<@,#(P,3<R`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92]4<F5E+VAT;6PN<&AP````````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`T,C$R-2`Q,#4Q-30S,S<S-R`P,C$W,S(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M(%1H92!(;W)D95]4<F5E7VAT;6PZ.B!C;&%S<R!E>'1E;F1S('1H92!(;W)D
M95]4<F5E(&-L87-S('1O('!R;W9I9&4*("H@2%1-3"!S<&5C:69I8R!R96YD
M97)I;F<@9G5N8W1I;VYS+@H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UA
M<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]4<F5E+U1R964O:'1M;"YP:'`L=B`Q+C4Q
M+C(N,3(@,C`P-B\P,2\Q-2`Q-CHS,SHR.2!C:'5C:R!%>'`@)`H@*@H@*B!`
M875T:&]R("!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*B!`<&%C
M:V%G92!(;W)D95]4<F5E"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B\*8VQA
M<W,@2&]R9&5?5')E95]H=&UL(&5X=&5N9',@2&]R9&5?5')E92!["@H@("`@
M+RHJ"B`@("`@*B!);6%G92!D:7)E8W1O<GD@;&]C871I;VXN"B`@("`@*@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?:6UG7V1I<B`]
M("<G.PH*("`@("\J*@H@("`@("H@1&5F875L="!T<F5E(&=R87!H:6,@9F]R
M(&$@;&EN92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)%]I;6=?;&EN92`]("=L:6YE+G!N9R<["@H@("`@+RHJ"B`@("`@
M*B!$969A=6QT('1R964@9W)A<&AI8R!F;W(@82!B;&%N:RX*("`@("`J"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]I;6=?8FQA;FL@
M/2`G8FQA;FLN<&YG)SL*"B`@("`O*BH*("`@("`J($1E9F%U;'0@=')E92!G
M<F%P:&EC(&9O<B!A(&IO:6XN"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J+PH@("`@=F%R("1?:6UG7VIO:6X@/2`G:F]I;BYP;F<G.PH*("`@
M("\J*@H@("`@("H@1&5F875L="!T<F5E(&=R87!H:6,@9F]R(&$@8F]T=&]M
M(&IO:6XN"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1?:6UG7VIO:6Y?8F]T=&]M(#T@)VIO:6YB;W1T;VTN<&YG)SL*"B`@
M("`O*BH*("`@("`J($1E9F%U;'0@=')E92!G<F%P:&EC(&9O<B!A('!L=7,N
M"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?
M:6UG7W!L=7,@/2`G<&QU<RYP;F<G.PH*("`@("\J*@H@("`@("H@1&5F875L
M="!T<F5E(&=R87!H:6,@9F]R(&$@8F]T=&]M('!L=7,N"B`@("`@*@H@("`@
M("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?:6UG7W!L=7-?8F]T
M=&]M(#T@)W!L=7-B;W1T;VTN<&YG)SL*"B`@("`O*BH*("`@("`J($1E9F%U
M;'0@=')E92!G<F%P:&EC(&9O<B!A('!L=7,@;VYL>2X*("`@("`J"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]I;6=?<&QU<U]O;FQY
M(#T@)W!L=7-O;FQY+G!N9R<["@H@("`@+RHJ"B`@("`@*B!$969A=6QT('1R
M964@9W)A<&AI8R!F;W(@82!M:6YU<RX*("`@("`J"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)%]I;6=?;6EN=7,@/2`G;6EN=7,N<&YG
M)SL*"B`@("`O*BH*("`@("`J($1E9F%U;'0@=')E92!G<F%P:&EC(&9O<B!A
M(&)O='1O;2!M:6YU<RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)%]I;6=?;6EN=7-?8F]T=&]M(#T@)VUI;G5S8F]T=&]M
M+G!N9R<["@H@("`@+RHJ"B`@("`@*B!$969A=6QT('1R964@9W)A<&AI8R!F
M;W(@82!M:6YU<R!O;FQY+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D7VEM9U]M:6YU<U]O;FQY(#T@)VUI;G5S;VYL>2YP
M;F<G.PH*("`@("\J*@H@("`@("H@1&5F875L="!T<F5E(&=R87!H:6,@9F]R
M(&$@;G5L;"!O;FQY+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B\*("`@('9A<B`D7VEM9U]N=6QL7V]N;'D@/2`G;G5L;&]N;'DN<&YG)SL*
M"B`@("`O*BH*("`@("`J($1E9F%U;'0@=')E92!G<F%P:&EC(&9O<B!A(&9O
M;&1E<BX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)%]I;6=?9F]L9&5R(#T@)V9O;&1E<BYP;F<G.PH*("`@("\J*@H@("`@
M("H@1&5F875L="!T<F5E(&=R87!H:6,@9F]R(&%N(&]P96X@9F]L9&5R+@H@
M("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VEM
M9U]F;VQD97)?;W!E;B`]("=F;VQD97)O<&5N+G!N9R<["@H@("`@+RHJ"B`@
M("`@*B!$969A=6QT('1R964@9W)A<&AI8R!F;W(@82!L96%F+@H@("`@("H*
M("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VEM9U]L96%F
M(#T@)VQE868N<&YG)SL*"B`@("`O*BH*("`@("`J(%1/1$\*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7VYO9&5S(#T@87)R
M87DH*3L*"B`@("`O*BH*("`@("`J(%1/1$\*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7VYO9&5?<&]S(#T@87)R87DH*3L*
M"B`@("`O*BH*("`@("`J(%1/1$\*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*B\*("`@('9A<B`D7V1R;W!L:6YE(#T@87)R87DH*3L*"B`@("`O
M*BH*("`@("`J($-U<G)E;G0@=F%L=64@;V8@=&AE(&%L="!T86<@8V]U;G0N
M"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D
M7V%L=%]C;W5N="`](#`["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@
M("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]4<F5E7VAT;6PH)'1R965?;F%M
M92P@)'!A<F%M<RD*("`@('L*("`@("`@("!P87)E;G0Z.DAO<F1E7U1R964H
M)'1R965?;F%M92P@)'!A<F%M<RD["@H@("`@("`@("1T:&ES+3Y?:6UG7V1I
M<B`]("1'3$]"04Q36R=R96=I<W1R>2==+3YG971);6%G941I<B@G:&]R9&4G
M*2`N("<O=')E92<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!T<F5E+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1S=&%T:6,@
M($EF('1R=64@=&AE('1R964@;F]D97,@8V%N)W0@8F4@97AP86YD960@86YD
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!C;VQL87!S960@86YD
M('1H92!T<F5E(&=E=',@<F5N9&5R960@97AP86YD960N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!(5$U,(&-O9&4@;V8@=&AE(')E;F1E
M<F5D('1R964N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1R964H)'-T871I
M8R`](&9A;'-E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<W1A=&EC(#T@)'-T
M871I8SL*("`@("`@("`D=&AI<RT^7V)U:6QD26YD96YT<R@D=&AI<RT^7W)O
M;W1?;F]D97,I.PH*("`@("`@("`D=')E92`]("1T:&ES+3Y?8G5I;&1(96%D
M97(H*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7W)O;W1?;F]D97,@87,@
M)&YO9&5?:60I('L*("`@("`@("`@("`@)'1R964@+CT@)'1H:7,M/E]B=6EL
M9%1R964H)&YO9&5?:60I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1R
M964["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:R!T:&4@8W5R<F5N="!E
M;G9I<F]N;65N="!T;R!S964@:68@=V4@8V%N(')E;F1E<B!T:&4@2%1-3`H@
M("`@("H@=')E92X@2%1-3"!I<R!A;'=A>7,@<F5N9&5R86)L92P@870@;&5A
M<W0@=6YT:6P@=V4@861D(&$*("`@("`J('!H<"UG=&L@=')E92!B86-K96YD
M+"!I;B!W:&EC:"!C87-E('1H:7,@:6UP;&5M96YT871I;VX@=VEL;`H@("`@
M("H@86-T=6%L;'D@;F5E9"!A(&)O9'DN"B`@("`@*@H@("`@("H@0'-T871I
M8PH@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N
M;W0@=&AI<R!4<F5E.CH@8F%C:V5N9"!W:6QL(&9U;F-T:6]N+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!I<U-U<'!O<G1E9"@I"B`@("!["B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&IU<W0@
M=&AE($I3(&YO9&4@9&5F:6YI=&EO;G,@87,@82!S=')I;F<N(%1H:7,@:7,@
M80H@("`@("H@;F\M;W`@9F]R('1H92!(5$U,(')E;F1E<F5R+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!R96YD97).;V1E1&5F:6YI=&EO;G,H*0H@("`@>PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@2%1-3"!C;V1E(&9O
M<B!A(&AE861E<B!R;W<L(&EF(&YE8V5S<V%R>2X*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE($A434P@8V]D92!O9B!T:&4@:&5A9&5R(')O=R!O<B!A;B!E;7!T>2!S
M=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]B=6EL9$AE861E<B@I"B`@
M("!["B`@("`@("`@:68@*"%C;W5N="@D=&AI<RT^7VAE861E<BDI('L*("`@
M("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@('T*"B`@("`@("`@)&AT;6P@
M/2`G/&1I=B<["B`@("`@("`@+RH@268@=7-I;F<@86QT97)N871I;F<@<F]W
M('-H861I;F<L('=O<FL@;W5T(&-O<G)E8W0*("`@("`@("`@*B!S:&%D92X@
M*B\*("`@("`@("!I9B`H)'1H:7,M/F=E=$]P=&EO;B@G86QT97)N871E)RDI
M('L*("`@("`@("`@("`@)&AT;6P@+CT@)R!C;&%S<STB:71E;2<@+B`D=&AI
M<RT^7V%L=%]C;W5N="`N("<B)SL*("`@("`@("`@("`@)'1H:7,M/E]A;'1?
M8V]U;G0@/2`Q("T@)'1H:7,M/E]A;'1?8V]U;G0["B`@("`@("`@?0H@("`@
M("`@("1H=&UL("X]("<^)SL*"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]H
M96%D97(@87,@)&AE861E<BD@>PH@("`@("`@("`@("`D:'1M;"`N/2`G/&1I
M=B!C;&%S<STB;&5F=$9L;V%T)SL*("`@("`@("`@("`@:68@*"%E;7!T>2@D
M:&5A9&5R6R=C;&%S<R==*2D@>PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@
M)R`G("X@)&AE861E<ELG8VQA<W,G73L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D:'1M;"`N/2`G(B<["@H@("`@("`@("`@("`D<W1Y;&4@/2`G)SL*
M("`@("`@("`@("`@:68@*"%E;7!T>2@D:&5A9&5R6R=W:61T:"==*2D@>PH@
M("`@("`@("`@("`@("`@)'-T>6QE("X]("=W:61T:#HG("X@)&AE861E<ELG
M=VED=&@G72`N("<[)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1H96%D97);)V%L:6=N)UTI*2!["B`@("`@("`@("`@("`@("`D
M<W1Y;&4@+CT@)W1E>'0M86QI9VXZ)R`N("1H96%D97);)V%L:6=N)UT@+B`G
M.R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%E;7!T>2@D<W1Y
M;&4I*2!["B`@("`@("`@("`@("`@("`D:'1M;"`N/2`G('-T>6QE/2(G("X@
M)'-T>6QE("X@)R(G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1H=&UL
M("X]("<^)SL*("`@("`@("`@("`@)&AT;6P@+CT@96UP='DH)&AE861E<ELG
M:'1M;"==*2`_("<F;F)S<#LG(#H@)&AE861E<ELG:'1M;"==.PH@("`@("`@
M("`@("`D:'1M;"`N/2`G/"]D:78^)SL*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D:'1M;"`N("<\+V1I=CXG.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5C=7)S:79E(&9U;F-T:6]N('1O('=A;&L@=&AR;W5G:"!T:&4@=')E92!A
M<G)A>2!A;F0@8G5I;&0@=&AE(&]U='!U="X*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N;V1E
M7VED("!4:&4@3F]D92!)1"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE('1R964@<F5N9&5R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M8G5I;&14<F5E*"1N;V1E7VED*0H@("`@>PH@("`@("`@("1O=71P=70@/2`D
M=&AI<RT^7V)U:6QD3&EN92@D;F]D95]I9"D["@H@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG8VAI;&1R96XG72D@)B8*("`@
M("`@("`@("`@)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)V5X<&%N9&5D)UTI
M('L*("`@("`@("`@("`@)&YU;5]S=6)N;V1E<R`](&-O=6YT*"1T:&ES+3Y?
M;F]D97-;)&YO9&5?:61=6R=C:&EL9')E;B==*3L*("`@("`@("`@("`@9F]R
M("@D8R`](#`[("1C(#P@)&YU;5]S=6)N;V1E<SL@)&,K*RD@>PH@("`@("`@
M("`@("`@("`@)&-H:6QD7VYO9&5?:60@/2`D=&AI<RT^7VYO9&5S6R1N;V1E
M7VED75LG8VAI;&1R96XG75LD8UT["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7VYO9&5?<&]S6R1C:&EL9%]N;V1E7VED72`](&%R<F%Y*"D["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7VYO9&5?<&]S6R1C:&EL9%]N;V1E7VED75LG<&]S
M)UT@/2`D8R`K(#$["B`@("`@("`@("`@("`@("`D=&AI<RT^7VYO9&5?<&]S
M6R1C:&EL9%]N;V1E7VED75LG8V]U;G0G72`]("1N=6U?<W5B;F]D97,["B`@
M("`@("`@("`@("`@("`D;W5T<'5T("X]("1T:&ES+3Y?8G5I;&14<F5E*"1C
M:&EL9%]N;V1E7VED*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1O=71P=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC
M=&EO;B!T;R!C<F5A=&4@82!S:6YG;&4@;&EN92!O9B!T:&4@=')E92X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1N;V1E7VED("!4:&4@3F]D92!)1"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D(&QI;F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]B=6EL9$QI;F4H)&YO9&5?:60I"B`@("!["B`@("`@
M("`@)&-L87-S3F%M92`]("=T<F5E4F]W)SL*("`@("`@("!I9B`H(65M<'1Y
M*"1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=C;&%S<R==*2D@>PH@("`@("`@
M("`@("`D8VQA<W-.86UE("X]("<@)R`N("1T:&ES+3Y?;F]D97-;)&YO9&5?
M:61=6R=C;&%S<R==.PH@("`@("`@('T*("`@("`@("`O*B!)9B!U<VEN9R!A
M;'1E<FYA=&EN9R!R;W<@<VAA9&EN9RP@=V]R:R!O=70@8V]R<F5C=`H@("`@
M("`@("`J('-H861E+B`J+PH@("`@("`@(&EF("@D=&AI<RT^9V5T3W!T:6]N
M*"=A;'1E<FYA=&4G*2D@>PH@("`@("`@("`@("`D8VQA<W-.86UE("X]("<@
M:71E;2<@+B`D=&AI<RT^7V%L=%]C;W5N=#L*("`@("`@("`@("`@)'1H:7,M
M/E]A;'1?8V]U;G0@/2`Q("T@)'1H:7,M/E]A;'1?8V]U;G0["B`@("`@("`@
M?0H*("`@("`@("`D;&EN92`]("<\9&EV(&-L87-S/2(G("X@)&-L87-S3F%M
M92`N("<B/B<["@H@("`@("`@("\J($EF('=E(&AA=F4@:&5A9&5R<RP@=')A
M8VL@=VAI8V@@;&]G:6-A;"`B8V]L=6UN(B!W92=R92!I;@H@("`@("`@("`J
M(&9O<B!A;GD@9VEV96X@8V5L;"!O9B!C;VYT96YT+B`J+PH@("`@("`@("1C
M;VQU;6X@/2`P.PH*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]N;V1E<ULD
M;F]D95]I9%U;)V5X=')A)UU;2$]21$5?5%)%15]%6%1205],149472DI('L*
M("`@("`@("`@("`@)&5X=')A(#T@)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;
M)V5X=')A)UU;2$]21$5?5%)%15]%6%1205],149473L*("`@("`@("`@("`@
M)&--87@@/2!C;W5N="@D97AT<F$I.PH@("`@("`@("`@("!F;W(@*"1C(#T@
M,#L@)&,@/"`D8TUA>#L@)&,K*RD@>PH@("`@("`@("`@("`@("`@)'-T>6QE
M(#T@)R<["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]H96%D
M97);)&-O;'5M;EU;)W=I9'1H)UTI*2!["B`@("`@("`@("`@("`@("`@("`@
M)'-T>6QE("X]("=W:61T:#HG("X@)'1H:7,M/E]H96%D97);)&-O;'5M;EU;
M)W=I9'1H)UT@+B`G.R<["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`@("`@)&QI;F4@+CT@)SQD:78@8VQA<W,](FQE9G1&;&]A="(G.PH@("`@
M("`@("`@("`@("`@:68@*"%E;7!T>2@D<W1Y;&4I*2!["B`@("`@("`@("`@
M("`@("`@("`@)&QI;F4@+CT@)R!S='EL93TB)R`N("1S='EL92`N("<B)SL*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1L:6YE("X]("<^
M)R`N("1E>'1R85LD8UT@+B`G/"]D:78^)SL*"B`@("`@("`@("`@("`@("`D
M8V]L=6UN*RL["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1S
M='EL92`]("<G.PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VAE861E<ELD
M8V]L=6UN75LG=VED=&@G72DI('L*("`@("`@("`@("`@)'-T>6QE("X]("=W
M:61T:#HG("X@)'1H:7,M/E]H96%D97);)&-O;'5M;EU;)W=I9'1H)UT@+B`G
M.R<["B`@("`@("`@?0H@("`@("`@("1L:6YE("X]("<\9&EV(&-L87-S/2)L
M969T1FQO870B)SL*("`@("`@("!I9B`H(65M<'1Y*"1S='EL92DI('L*("`@
M("`@("`@("`@)&QI;F4@+CT@)R!S='EL93TB)R`N("1S='EL92`N("<B)SL*
M("`@("`@("!]"B`@("`@("`@)&QI;F4@+CT@)SXG.PH*("`@("`@("!I9B`H
M)'1H:7,M/F=E=$]P=&EO;B@G;75L=&EL:6YE)RDI('L*("`@("`@("`@("`@
M)&QI;F4@+CT@)SQT86)L92!C96QL<W!A8VEN9STB,"(^/'1R/CQT9#XG.PH@
M("`@("`@('T*"B`@("`@("`@9F]R("@D:2`]("1T:&ES+3Y?<W1A=&EC(#\@
M,2`Z(#`[("1I(#P@)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)VEN9&5N="==
M.R`D:2LK*2!["B`@("`@("`@("`@("1L:6YE("X]("<\:6UG('-R8STB)R`N
M("1T:&ES+3Y?:6UG7V1I<B`N("<O)SL*("`@("`@("`@("`@:68@*"1T:&ES
M+3Y?9')O<&QI;F5;)&E=("8F("1T:&ES+3YG971/<'1I;VXH)VQI;F5S)RP@
M9F%L<V4L('1R=64I*2!["B`@("`@("`@("`@("`@("`D;&EN92`N/2`D=&AI
M<RT^7VEM9U]L:6YE("X@)R(@)PH@("`@("`@("`@("`@("`@("`@("X@)V%L
M=#TB?"9N8G-P.R9N8G-P.R9N8G-P.R(@)SL*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1L:6YE("X]("1T:&ES+3Y?:6UG7V)L86YK
M("X@)R(@)PH@("`@("`@("`@("`@("`@("`@("X@)V%L=#TB)FYB<W`[)FYB
M<W`[)FYB<W`[(B`G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1L:6YE
M("X]("=H96EG:'0](C(P(B!W:61T:#TB,C`B('-T>6QE/2)V97)T:6-A;"UA
M;&EG;CIM:61D;&4B("\^)SL*("`@("`@("!]"B`@("`@("`@)&QI;F4@+CT@
M)'1H:7,M/E]S971.;V1E5&]G9VQE*"1N;V1E7VED*2`N("1T:&ES+3Y?<V5T
M3F]D94EC;VXH)&YO9&5?:60I.PH@("`@("`@(&EF("@D=&AI<RT^9V5T3W!T
M:6]N*"=M=6QT:6QI;F4G*2D@>PH@("`@("`@("`@("`D;&EN92`N/2`G/"]T
M9#X\=&0^)SL*("`@("`@("!]"B`@("`@("`@)&QI;F4@+CT@)'1H:7,M/E]S
M971,86)E;"@D;F]D95]I9"D["@H@("`@("`@(&EF("@D=&AI<RT^9V5T3W!T
M:6]N*"=M=6QT:6QI;F4G*2D@>PH@("`@("`@("`@("`D;&EN92`N/2`G/"]T
M9#X\+W1R/CPO=&%B;&4^)SL*("`@("`@("!]"@H@("`@("`@("1L:6YE("X]
M("<\+V1I=CXG.PH@("`@("`@("1C;VQU;6XK*SL*"B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=E>'1R82==6TA/4D1%7U12
M145?15A44D%?4DE'2%1=*2D@>PH@("`@("`@("`@("`D97AT<F$@/2`D=&AI
M<RT^7VYO9&5S6R1N;V1E7VED75LG97AT<F$G75M(3U)$15]44D5%7T585%)!
M7U))1TA473L*("`@("`@("`@("`@)&--87@@/2!C;W5N="@D97AT<F$I.PH@
M("`@("`@("`@("!F;W(@*"1C(#T@,#L@)&,@/"`D8TUA>#L@)&,K*RD@>PH@
M("`@("`@("`@("`@("`@)'-T>6QE(#T@)R<["B`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/E]H96%D97);)&-O;'5M;EU;)W=I9'1H)UTI*2![
M"B`@("`@("`@("`@("`@("`@("`@)'-T>6QE("X]("=W:61T:#HG("X@)'1H
M:7,M/E]H96%D97);)&-O;'5M;EU;)W=I9'1H)UT@+B`G.R<["B`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`@("`@)&QI;F4@+CT@)SQD:78@8VQA
M<W,](FQE9G1&;&]A="(G.PH@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D
M<W1Y;&4I*2!["B`@("`@("`@("`@("`@("`@("`@)&QI;F4@+CT@)R!S='EL
M93TB)R`N("1S='EL92`N("<B)SL*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("1L:6YE("X]("<^)R`N("1E>'1R85LD8UT@+B`G/"]D:78^
M)SL*"B`@("`@("`@("`@("`@("`D8V]L=6UN*RL["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;&EN92`N("(\+V1I=CY<;B([
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!L86)E;"!O;B!T:&4@
M=')E92!L:6YE+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&YO9&5?:60@(%1H92!.;V1E($E$
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;&%B96P@9F]R
M('1H92!T<F5E(&QI;F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S971,86)E
M;"@D;F]D95]I9"D*("`@('L*("`@("`@("`D;B`]("1T:&ES+3Y?;F]D97-;
M)&YO9&5?:61=.PH*("`@("`@("`D;W5T<'5T(#T@)SQS<&%N)SL*("`@("`@
M("!I9B`H(65M<'1Y*"1N6R=O;F-L:6-K)UTI*2!["B`@("`@("`@("`@("1O
M=71P=70@+CT@)R!O;F-L:6-K/2(G("X@)&Y;)V]N8VQI8VLG72`N("<B)SL*
M("`@("`@("!]"B`@("`@("`@)&]U='!U="`N/2`G/B<["@H@("`@("`@("1L
M86)E;"`]("1N6R=L86)E;"==.PH@("`@("`@(&EF("@A96UP='DH)&Y;)W5R
M;"==*2D@>PH@("`@("`@("`@("`D=&%R9V5T(#T@)R<["B`@("`@("`@("`@
M(&EF("@A96UP='DH)&Y;)W1A<F=E="==*2D@>PH@("`@("`@("`@("`@("`@
M)'1A<F=E="`]("<@=&%R9V5T/2(G("X@)&Y;)W1A<F=E="==("X@)R(G.PH@
M("`@("`@("`@("!](&5L<V5I9B`H)'1A<F=E="`]("1T:&ES+3YG971/<'1I
M;VXH)W1A<F=E="<I*2!["B`@("`@("`@("`@("`@("`D=&%R9V5T(#T@)R!T
M87)G970](B<@+B`D=&%R9V5T("X@)R(G.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1O=71P=70@+CT@)SQA)R`N("@A96UP='DH)&Y;)W5R;&-L87-S
M)UTI(#\@)R!C;&%S<STB)R`N("1N6R=U<FQC;&%S<R==("X@)R(G(#H@)R<I
M("X@)R!H<F5F/2(G("X@)&Y;)W5R;"==("X@)R(G("X@)'1A<F=E="`N("<^
M)R`N("1L86)E;"`N("<\+V$^)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D;W5T<'5T("X]("1L86)E;#L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D;W5T<'5T("X@)SPO<W!A;CXG.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4V5T<R!T:&4@;F]D92!T;V=G;&4@;VX@=&AE('1R964@;&EN92X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1N;V1E7VED("!4:&4@3F]D92!)1"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE(&YO9&4@=&]G9VQE(&9O<B!T:&4@=')E
M92!L:6YE+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<V5T3F]D951O9V=L92@D
M;F]D95]I9"D*("`@('L*("`@("`@("`D;&EN:U]S=&%R="`]("<G.PH*("`@
M("`@("!I9B`H*"1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=I;F1E;G0G72`]
M/2`P*2`F)@H@("`@("`@("`@("!I<W-E="@D=&AI<RT^7VYO9&5S6R1N;V1E
M7VED75LG8VAI;&1R96XG72DI('L*("`@("`@("`@("`@+RH@5&]P(&QE=F5L
M(&YO9&4@=VET:"!C:&EL9')E;BX@*B\*("`@("`@("`@("`@)'1H:7,M/E]D
M<F]P;&EN95LP72`](&9A;'-E.PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]S
M=&%T:6,I('L*("`@("`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("`@
M("`@?2!E;'-E:68@*"$D=&AI<RT^9V5T3W!T:6]N*"=L:6YE<R<L(&9A;'-E
M+"!T<G5E*2D@>PH@("`@("`@("`@("`@("`@)&EM9R`]("1T:&ES+3Y?:6UG
M7V)L86YK.PH@("`@("`@("`@("`@("`@)&%L="`]("<F;F)S<#LF;F)S<#LF
M;F)S<#LG.PH@("`@("`@("`@("!](&5L<V5I9B`H)'1H:7,M/E]N;V1E<ULD
M;F]D95]I9%U;)V5X<&%N9&5D)UTI('L*("`@("`@("`@("`@("`@("1I;6<@
M/2`D=&AI<RT^7VEM9U]M:6YU<U]O;FQY.PH@("`@("`@("`@("`@("`@)&%L
M="`]("<M)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1I;6<@/2`D=&AI<RT^7VEM9U]P;'5S7V]N;'D["B`@("`@("`@("`@("`@
M("`D86QT(#T@)RLG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A
M)'1H:7,M/E]S=&%T:6,I('L*("`@("`@("`@("`@("`@("1U<FP@/2!5=&EL
M.CIA9&1087)A;65T97(H2&]R9&4Z.G-E;&95<FPH*2P@2$]21$5?5%)%15]4
M3T='3$4@+B`D=&AI<RT^7VEN<W1A;F-E+"`D;F]D95]I9"D["B`@("`@("`@
M("`@("`@("`D;&EN:U]S=&%R="`]($AO<F1E.CIL:6YK*"1U<FPI.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2!E;'-E:68@*"@D=&AI<RT^7VYO9&5S6R1N
M;V1E7VED75LG:6YD96YT)UT@(3T@,"D@)B8*("`@("`@("`@("`@(6ES<V5T
M*"1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=C:&EL9')E;B==*2D@>PH@("`@
M("`@("`@("`O*B!.;V1E('=I=&AO=70@8VAI;&1R96XN("HO"B`@("`@("`@
M("`@(&EF("@D=&AI<RT^7VYO9&5?<&]S6R1N;V1E7VED75LG<&]S)UT@/"`D
M=&AI<RT^7VYO9&5?<&]S6R1N;V1E7VED75LG8V]U;G0G72D@>PH@("`@("`@
M("`@("`@("`@+RH@3F]T(&QA<W0@;F]D92X@*B\*("`@("`@("`@("`@("`@
M(&EF("@D=&AI<RT^9V5T3W!T:6]N*"=L:6YE<R<L(&9A;'-E+"!T<G5E*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1I;6<@/2`D=&AI<RT^7VEM9U]J;VEN
M.PH@("`@("`@("`@("`@("`@("`@("1A;'0@/2`G?"TG.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D:6UG(#T@)'1H
M:7,M/E]I;6=?8FQA;FL["B`@("`@("`@("`@("`@("`@("`@)&%L="`]("<F
M;F)S<#LF;F)S<#LF;F)S<#LG.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@)'1H:7,M/E]D<F]P;&EN95LD=&AI<RT^7VYO9&5S6R1N;V1E
M7VED75LG:6YD96YT)UU=(#T@=')U93L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("\J($QA<W0@;F]D92X@*B\*("`@("`@("`@("`@
M("`@(&EF("@D=&AI<RT^9V5T3W!T:6]N*"=L:6YE<R<L(&9A;'-E+"!T<G5E
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1I;6<@/2`D=&AI<RT^7VEM9U]J
M;VEN7V)O='1O;3L*("`@("`@("`@("`@("`@("`@("`D86QT(#T@)V`M)SL*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M)&EM9R`]("1T:&ES+3Y?:6UG7V)L86YK.PH@("`@("`@("`@("`@("`@("`@
M("1A;'0@/2`G)FYB<W`[)FYB<W`[)FYB<W`[)SL*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("1T:&ES+3Y?9')O<&QI;F5;)'1H:7,M/E]N
M;V1E<ULD;F]D95]I9%U;)VEN9&5N="==72`](&9A;'-E.PH@("`@("`@("`@
M("!]"B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES+3Y?;F]D97-;)&YO
M9&5?:61=6R=C:&EL9')E;B==*2D@>PH@("`@("`@("`@("`O*B!.;V1E('=I
M=&@@8VAI;&1R96XN("HO"B`@("`@("`@("`@(&EF("@D=&AI<RT^7VYO9&5?
M<&]S6R1N;V1E7VED75LG<&]S)UT@/"`D=&AI<RT^7VYO9&5?<&]S6R1N;V1E
M7VED75LG8V]U;G0G72D@>PH@("`@("`@("`@("`@("`@+RH@3F]T(&QA<W0@
M;F]D92X@*B\*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/F=E=$]P=&EO
M;B@G;&EN97,G+"!F86QS92P@=')U92DI('L*("`@("`@("`@("`@("`@("`@
M("`D:6UG(#T@)'1H:7,M/E]I;6=?8FQA;FL["B`@("`@("`@("`@("`@("`@
M("`@)&%L="`]("<F;F)S<#LF;F)S<#LF;F)S<#LG.PH@("`@("`@("`@("`@
M("`@?2!E;'-E:68@*"1T:&ES+3Y?<W1A=&EC*2!["B`@("`@("`@("`@("`@
M("`@("`@)&EM9R`]("1T:&ES+3Y?:6UG7VIO:6X["B`@("`@("`@("`@("`@
M("`@("`@)&%L="`]("=\+2<["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H
M)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)V5X<&%N9&5D)UTI('L*("`@("`@
M("`@("`@("`@("`@("`D:6UG(#T@)'1H:7,M/E]I;6=?;6EN=7,["B`@("`@
M("`@("`@("`@("`@("`@)&%L="`]("<M)SL*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@)&EM9R`]("1T:&ES+3Y?:6UG
M7W!L=7,["B`@("`@("`@("`@("`@("`@("`@)&%L="`]("<K)SL*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1T:&ES+3Y?9')O<&QI;F5;
M)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)VEN9&5N="==72`]('1R=64["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O*B!,87-T(&YO
M9&4N("HO"B`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3YG971/<'1I;VXH
M)VQI;F5S)RP@9F%L<V4L('1R=64I*2!["B`@("`@("`@("`@("`@("`@("`@
M)&EM9R`]("1T:&ES+3Y?:6UG7V)L86YK.PH@("`@("`@("`@("`@("`@("`@
M("1A;'0@/2`G)FYB<W`[)FYB<W`[)FYB<W`[)SL*("`@("`@("`@("`@("`@
M('T@96QS96EF("@D=&AI<RT^7W-T871I8RD@>PH@("`@("`@("`@("`@("`@
M("`@("1I;6<@/2`D=&AI<RT^7VEM9U]J;VEN7V)O='1O;3L*("`@("`@("`@
M("`@("`@("`@("`D86QT(#T@)V`M)SL*("`@("`@("`@("`@("`@('T@96QS
M96EF("@D=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG97AP86YD960G72D@>PH@
M("`@("`@("`@("`@("`@("`@("1I;6<@/2`D=&AI<RT^7VEM9U]M:6YU<U]B
M;W1T;VT["B`@("`@("`@("`@("`@("`@("`@)&%L="`]("<M)SL*("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&EM9R`]
M("1T:&ES+3Y?:6UG7W!L=7-?8F]T=&]M.PH@("`@("`@("`@("`@("`@("`@
M("1A;'0@/2`G*R<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D=&AI<RT^7V1R;W!L:6YE6R1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=I
M;F1E;G0G75T@/2!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I
M9B`H(21T:&ES+3Y?<W1A=&EC*2!["B`@("`@("`@("`@("`@("`D=7)L(#T@
M571I;#HZ861D4&%R86UE=&5R*$AO<F1E.CIS96QF57)L*"DL($A/4D1%7U12
M145?5$]'1TQ%("X@)'1H:7,M/E]I;G-T86YC92P@)&YO9&5?:60I.PH@("`@
M("`@("`@("`@("`@)&QI;FM?<W1A<G0@/2!(;W)D93HZ;&EN:R@D=7)L*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J
M(%1O<"!L979E;"!N;V1E('=I=&@@;F\@8VAI;&1R96XN("HO"B`@("`@("`@
M("`@(&EF("@D=&AI<RT^7W-T871I8RD@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("<G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D=&AI<RT^
M9V5T3W!T:6]N*"=L:6YE<R<L(&9A;'-E+"!T<G5E*2D@>PH@("`@("`@("`@
M("`@("`@)&EM9R`]("1T:&ES+3Y?:6UG7VYU;&Q?;VYL>3L*("`@("`@("`@
M("`@("`@("1A;'0@/2`G)FYB<W`[)FYB<W`[)SL*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1I;6<@/2`D=&AI<RT^7VEM9U]B;&%N
M:SL*("`@("`@("`@("`@("`@("1A;'0@/2`G)FYB<W`[)FYB<W`[)FYB<W`[
M)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7V1R;W!L:6YE
M6S!=(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D;&EN:U]E;F0@/2`H
M)&QI;FM?<W1A<G0I(#\@)SPO83XG(#H@)R<["@H@("`@("`@("1I;6<@/2`D
M;&EN:U]S=&%R="`N("<\:6UG('-R8STB)R`N("1T:&ES+3Y?:6UG7V1I<B`N
M("<O)R`N("1I;6<@+B`G(B<*("`@("`@("`@("`@+B`H:7-S970H)&%L="D@
M/R`G(&%L=#TB)R`N("1A;'0@+B`G(B<@.B`G)RD*("`@("`@("`@("`@+B`G
M(&AE:6=H=#TB,C`B('=I9'1H/2(R,"(@<W1Y;&4](G9E<G1I8V%L+6%L:6=N
M.FUI9&1L92(@8F]R9&5R/2(P(B`O/B<*("`@("`@("`@("`@+B`D;&EN:U]E
M;F0["@H@("`@("`@(')E='5R;B`D:6UG.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4V5T<R!T:&4@:6-O;B!F;W(@=&AE(&YO9&4N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;F]D95]I9"`@5&AE($YO9&4@240N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!N;V1E(&EC;VX@9F]R('1H92!T<F5E(&QI;F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]S971.;V1E26-O;B@D;F]D95]I9"D*("`@('L*
M("`@("`@("`D:6UG7V1I<B`](&ES<V5T*"1T:&ES+3Y?;F]D97-;)&YO9&5?
M:61=6R=I8V]N9&ER)UTI(#\@)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)VEC
M;VYD:7(G72`Z("1T:&ES+3Y?:6UG7V1I<CL*("`@("`@("!I9B`H)&EM9U]D
M:7(I('L*("`@("`@("`@("`@)&EM9U]D:7(@+CT@)R\G.PH@("`@("`@('T*
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=I
M8V]N)UTI*2!["B`@("`@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7VYO9&5S
M6R1N;V1E7VED75LG:6-O;B==*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("<G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("\J($YO9&4@:&%S(&$@
M=7-E<B!D969I;F5D(&EC;VXN("HO"B`@("`@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG:6-O;F]P96XG72D@)B8*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=E>'!A;F1E9"==
M*2!["B`@("`@("`@("`@("`@("`D:6UG(#T@)'1H:7,M/E]N;V1E<ULD;F]D
M95]I9%U;)VEC;VYO<&5N)UT["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D:6UG(#T@)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)VEC
M;VXG73L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("\J(%5S92!S=&%N9&%R9"!I8V]N('-E="X@*B\*("`@("`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=C:&EL9')E;B==
M*2D@>PH@("`@("`@("`@("`@("`@+RH@3F]D92!W:71H(&-H:6QD<F5N+B`J
M+PH@("`@("`@("`@("`@("`@)&EM9R`]("@D=&AI<RT^7VYO9&5S6R1N;V1E
M7VED75LG97AP86YD960G72D@/R`D=&AI<RT^7VEM9U]F;VQD97)?;W!E;B`Z
M("1T:&ES+3Y?:6UG7V9O;&1E<CL*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("\J($QE868@;F]D92`H;F\@8VAI;&1R96XI+B`J+PH@
M("`@("`@("`@("`@("`@)&EM9R`]("1T:&ES+3Y?:6UG7VQE868["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1I;6=T>'0@/2`G/&EM9R!S
M<F,](B<@+B`D:6UG7V1I<B`N("1I;6<@+B`G(B<["@H@("`@("`@("\J($1O
M97,@=&AE(&YO9&4@:&%V92!U<V5R(&1E9FEN960@86QT('1E>'0_("HO"B`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=I8V]N
M86QT)UTI*2!["B`@("`@("`@("`@("1I;6=T>'0@+CT@)R!A;'0](B<@+B!H
M=&UL<W!E8VEA;&-H87)S*"1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=I8V]N
M86QT)UTI("X@)R(G.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;6=T
M>'0@+B`G("\^)SL*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]4<F5E+W-E;&5C="YP
M:'``````````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-C8P,2`Q
M,#4Q-30S,S<S-R`P,C(R-#0`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J(%1H92!(;W)D95]4<F5E7W-E
M;&5C=#HZ(&-L87-S(&5X=&5N9',@=&AE($AO<F1E7U1R964@8VQA<W,@=&\@
M<')O=FED90H@*B`\;W!T:6]N/B!T86<@<F5N9&5R:6YG+@H@*@H@*B!#;W!Y
M<FEG:'0@,C`P-2TR,#`V($)E;B!#:&%V970@/&)E;D!H;W)D92YO<F<^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9`H@*B!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]4<F5E+U1R964O
M<V5L96-T+G!H<"QV(#$N,BXR+C<@,C`P-B\P,2\P,2`R,3HR.#HT,"!J86X@
M17AP("0*("H*("H@0&%U=&AO<B`@0F5N($-H879E="`\8F5N0&AO<F1E+F]R
M9SX*("H@0'!A8VMA9V4@2&]R9&5?5')E90H@*B!`<VEN8V4@("!(;W)D92`S
M+C$*("HO"F-L87-S($AO<F1E7U1R965?<V5L96-T(&5X=&5N9',@2&]R9&5?
M5')E92!["@H@("`@+RHJ"B`@("`@*B!43T1/"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]N;V1E<R`](&%R<F%Y*"D["@H@
M("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@2&]R9&5?5')E95]S96QE8W0H)'1R965?;F%M92P@)'!A<F%M<RD*("`@
M('L*("`@("`@("!P87)E;G0Z.DAO<F1E7U1R964H)'1R965?;F%M92P@)'!A
M<F%M<RD["B`@("`@("`@)'1H:7,M/E]S=&%T:6,@/2!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@=')E92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE($A434P@8V]D92!O9B!T:&4@<F5N9&5R
M960@=')E92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5')E92@I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]B=6EL9$EN9&5N=',H)'1H:7,M/E]R;V]T7VYO
M9&5S*3L*"B`@("`@("`@)'1R964@/2`G)SL*("`@("`@("!F;W)E86-H("@D
M=&AI<RT^7W)O;W1?;F]D97,@87,@)&YO9&5?:60I('L*("`@("`@("`@("`@
M)'1R964@+CT@)'1H:7,M/E]B=6EL9%1R964H)&YO9&5?:60I.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)'1R964["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#:&5C:W,@=&AE(&-U<G)E;G0@96YV:7)O;FUE;G0@=&\@<V5E(&EF('=E
M(&-A;B!R96YD97(@=&AE($A434P@=')E92X*("`@("`J($A434P@:7,@86QW
M87ES(')E;F1E<F%B;&4L(&%T(&QE87-T('5N=&EL('=E(&%D9"!A('!H<"UG
M=&L@=')E90H@("`@("H@8F%C:V5N9"P@:6X@=VAI8V@@8V%S92!T:&ES(&EM
M<&QE;65N=&%T:6]N('=I;&P@86-T=6%L;'D@;F5E9"!A(&)O9'DN"B`@("`@
M*@H@("`@("H@0'-T871I8PH@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5VAE=&AE<B!O<B!N;W0@=&AI<R!4<F5E.CH@8F%C:V5N9"!W:6QL(&9U
M;F-T:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<U-U<'!O<G1E9"@I"B`@
M("!["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&IU<W0@=&AE($I3(&YO9&4@9&5F:6YI=&EO;G,@87,@82!S
M=')I;F<N(%1H:7,@:7,@82!N;RUO<"!F;W(*("`@("`J('1H92!S96QE8W0@
M<F5N9&5R97(N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<DYO9&5$969I
M;FET:6]N<R@I"B`@("!["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&%D
M9&ET:6]N86P@<&%R86UE=&5R<R!T;R!A(&YO9&4N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D:60@("`@(%1H92!U;FEQ=64@;F]D92!I9"X*("`@
M("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!;GD@;W1H97(@<&%R86UE=&5R
M<R!T;R!S970N"B`@("`@*B`\<')E/@H@("`@("H@<V5L96-T960@+2T@(%=H
M971H97(@=&AI<R!N;V1E(&ES('-E;&5C=&5D"B`@("`@*B`\+W!R93X*("`@
M("`J+PH@("`@9G5N8W1I;VX@861D3F]D95!A<F%M<R@D:60L("1P87)A;7,@
M/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("@A:7-?87)R87DH)'!A<F%M
M<RDI('L*("`@("`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"1P87)A;7,I.PH@
M("`@("`@('T*"B`@("`@("`@)&%L;&]W960@/2!A<G)A>2@G<V5L96-T960G
M*3L*"B`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D<&%R86U?:60@/3X@
M)'!A<F%M7W9A;"D@>PH@("`@("`@("`@("`O*B!3970@;VYL>2!A;&QO=V5D
M(&%N9"!N;VXM;G5L;"!P87)A;7,N("HO"B`@("`@("`@("`@(&EF("AI;E]A
M<G)A>2@D<&%R86U?:60L("1A;&QO=V5D*2`F)B`A:7-?;G5L;"@D<&%R86U?
M=F%L*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]N;V1E<ULD:61=6R1P
M87)A;5]I9%T@/2`D<&%R86U?=F%L.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5C=7)S:79E(&9U;F-T:6]N('1O
M('=A;&L@=&AR;W5G:"!T:&4@=')E92!A<G)A>2!A;F0@8G5I;&0@=&AE(&]U
M='!U="X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1N;V1E7VED("!4:&4@3F]D92!)1"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('1R964@<F5N9&5R:6YG
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8G5I;&14<F5E*"1N;V1E7VED*0H@
M("`@>PH@("`@("`@("1S96QE8W1E9"`]("1T:&ES+3Y?;F]D97-;)&YO9&5?
M:61=6R=S96QE8W1E9"==(#\@)R!S96QE8W1E9#TB<V5L96-T960B)R`Z("<G
M.PH*("`@("`@("`D;W5T<'5T(#T@)SQO<'1I;VX@=F%L=64](B<@+B!H=&UL
M<W!E8VEA;&-H87)S*"1N;V1E7VED*2`N("<B)R`N("1S96QE8W1E9"`N("<^
M)R`N"B`@("`@("`@("`@('-T<E]R97!E870H)R9N8G-P.R9N8G-P.R<L("AI
M;G0I)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)VEN9&5N="==*2`N(&AT;6QS
M<&5C:6%L8VAA<G,H)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)VQA8F5L)UTI
M("X*("`@("`@("`@("`@)SPO;W!T:6]N/B<["@H@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG8VAI;&1R96XG72D@)B8*("`@
M("`@("`@("`@)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)V5X<&%N9&5D)UTI
M('L*("`@("`@("`@("`@)&YU;5]S=6)N;V1E<R`](&-O=6YT*"1T:&ES+3Y?
M;F]D97-;)&YO9&5?:61=6R=C:&EL9')E;B==*3L*("`@("`@("`@("`@9F]R
M("@D8R`](#`[("1C(#P@)&YU;5]S=6)N;V1E<SL@)&,K*RD@>PH@("`@("`@
M("`@("`@("`@)&-H:6QD7VYO9&5?:60@/2`D=&AI<RT^7VYO9&5S6R1N;V1E
M7VED75LG8VAI;&1R96XG75LD8UT["B`@("`@("`@("`@("`@("`D;W5T<'5T
M("X]("1T:&ES+3Y?8G5I;&14<F5E*"1C:&EL9%]N;V1E7VED*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O=71P=70["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O5')E92]J879A<V-R
M:7!T+G!H<```````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3,Q-#<@
M,3`U,34T,S,W,S<@,#(S,3,V`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B!4:&4@2&]R9&5?5')E95]J
M879A<V-R:7!T.CH@8VQA<W,@97AT96YD<R!T:&4@2&]R9&5?5')E92!C;&%S
M<R!T;R!P<F]V:61E"B`J(&IA=F%S8W)I<'0@<W!E8VEF:6,@<F5N9&5R:6YG
M(&9U;F-T:6]N<RX*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-87)K;R!$
M:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO5')E92]4<F5E+VIA=F%S8W)I<'0N<&AP+'8@,2XS
M-"XR+CD@,C`P-B\P,2\P,2`R,3HR.#HT,"!J86X@17AP("0*("H*("H@0&%U
M=&AO<B`@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H@0'!A8VMA
M9V4@2&]R9&5?5')E90H@*B!`<VEN8V4@("!(;W)D92`S+C`*("HO"F-L87-S
M($AO<F1E7U1R965?:F%V87-C<FEP="!E>'1E;F1S($AO<F1E7U1R964@>PH*
M("`@("\J*@H@("`@("H@5&AE(&YA;64@;V8@=&AE('-O=7)C92!F;W(@=&AE
M('1R964@9&%T82X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO
M"B`@("!V87(@)%]S;W5R8V5?;F%M92`](&YU;&P["@H@("`@+RHJ"B`@("`@
M*B!4:&4@;F%M92!O9B!T:&4@=&%R9V5T(&5L96UE;G0@=&\@;W5T<'5T('1H
M92!J879A<V-R:7!T('1R964N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J+PH@("`@=F%R("1?;W!T:6]N<U]N86UE(#T@;G5L;#L*"B`@("`O
M*BH*("`@("`J(%1H92!N86UE(&]F('1H92!T87)G970@96QE;65N="!T;R!O
M=71P=70@=&AE(&IA=F%S8W)I<'0@=')E92X*("`@("`J"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]T87)G971?;F%M92`](&YU;&P[
M"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("HO"B`@("!F=6YC
M=&EO;B!(;W)D95]4<F5E7VIA=F%S8W)I<'0H)'1R965?;F%M92P@)'!A<F%M
M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<&%R96YT.CI(;W)D95]4<F5E
M*"1T<F5E7VYA;64L("1P87)A;7,I.PH*("`@("`@("!I9B`H(6ES<V5T*"1'
M3$]"04Q36R=B<F]W<V5R)UTI*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC
M92`G2&]R9&4O0G)O=W-E<BYP:'`G.PH@("`@("`@("`@("`D1TQ/0D%,4ULG
M8G)O=W-E<B==(#T@)D)R;W=S97(Z.G-I;F=L971O;B@I.PH@("`@("`@('T*
M"B`@("`@("`@+RH@0VAE8VL@9F]R(&$@:F%V87-C<FEP="!S97-S:6]N('-T
M871E+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7W5S97-E<W-I;VX@)B8*("`@
M("`@("`@("`@:7-S970H)%]#3T]+245;)'1H:7,M/E]I;G-T86YC92`N("=?
M97AP86YD960G72DI('L*("`@("`@("`@("`@+RH@4F5M;W9E(")E>'`B('!R
M969I>"!F<F]M(&-O;VMI92!V86QU92X@*B\*("`@("`@("`@("`@)&YO9&5S
M(#T@97AP;&]D92@G+"<L('-U8G-T<B@D7T-/3TM)15LD=&AI<RT^7VEN<W1A
M;F-E("X@)U]E>'!A;F1E9"==+"`S*2D["@H@("`@("`@("`@("`O*B!-86ME
M('-U<F4@=&AE<F4@87)E(&YO('!R979I;W5S(&YO9&5S('-T;W)E9"!I;B!T
M:&4*("`@("`@("`@("`@("H@<V5S<VEO;BX@*B\*("`@("`@("`@("`@)%]3
M15-324].6R=H;W)D95]T<F5E)UU;)'1H:7,M/E]I;G-T86YC95U;)V5X<&%N
M9&5D)UT@/2!A<G)A>2@I.PH*("`@("`@("`@("`@+RH@4V%V92!N;V1E<R!T
M;R!T:&4@<V5S<VEO;BX@*B\*("`@("`@("`@("`@9F]R96%C:"`H)&YO9&5S
M(&%S("1I9"D@>PH@("`@("`@("`@("`@("`@)%]315-324].6R=H;W)D95]T
M<F5E)UU;)'1H:7,M/E]I;G-T86YC95U;)V5X<&%N9&5D)UU;)&ED72`]('1R
M=64["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!T<F5E+@H@("`@("H*("`@("`J($!P87)A;2!B
M;V]L96%N("1S=&%T:6,@($EF('1R=64@=&AE('1R964@;F]D97,@8V%N)W0@
M8F4@97AP86YD960@86YD"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("!C;VQL87!S960@86YD('1H92!T<F5E(&=E=',@<F5N9&5R960@97AP86YD
M960N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!(5$U,(&-O
M9&4@;V8@=&AE(')E;F1E<F5D('1R964N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=%1R964H)'-T871I8R`](&9A;'-E*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?<W1A=&EC(#T@)'-T871I8SL*("`@("`@("`D=&AI<RT^7W-O=7)C95]N
M86UE(#T@)VY?)R`N("1T:&ES+3Y?:6YS=&%N8V4["B`@("`@("`@)'1H:7,M
M/E]H96%D97)?;F%M92`]("=H7R<@+B`D=&AI<RT^7VEN<W1A;F-E.PH@("`@
M("`@("1T:&ES+3Y?;W!T:6]N<U]N86UE(#T@)V]?)R`N("1T:&ES+3Y?:6YS
M=&%N8V4["B`@("`@("`@)'1H:7,M/E]T87)G971?;F%M92`]("=T7R<@+B`D
M=&AI<RT^7VEN<W1A;F-E.PH@("`@("`@("1T:&ES+3Y?8G5I;&1);F1E;G1S
M*"1T:&ES+3Y?<F]O=%]N;V1E<RD["@H@("`@("`@("1T<F5E(#T@)'1H:7,M
M/E]G9714<F5E4V]U<F-E*"D@+@H@("`@("`@("`@("`@)SQD:78@:60](B<@
M+B`D=&AI<RT^7W1A<F=E=%]N86UE("X@)R(^/"]D:78^)R`N"B`@("`@("`@
M("`@("`D=&AI<RT^7V=E=%1R965);FET*"D["@H@("`@("`@($AO<F1E.CIA
M9&138W)I<'1&:6QE*"=T<F5E+FIS)RP@)VAO<F1E)RD["B`@("`@("`@<F5T
M=7)N("1T<F5E.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VL@=&AE(&-U
M<G)E;G0@96YV:7)O;FUE;G0@=&\@<V5E(&EF('=E(&-A;B!R96YD97(@=&AE
M($A434P*("`@("`J('1R964N(%=E(&-H96-K(&9O<B!$3TT@<W5P<&]R="!I
M;B!T:&4@8G)O=W-E<BX*("`@("`J"B`@("`@*B!`<W1A=&EC"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&ES(%1R
M964Z.B!B86-K96YD('=I;&P@9G5N8W1I;VXN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&ES4W5P<&]R=&5D*"D*("`@('L*("`@("`@("!R971U<FX@)$=,3T)!
M3%-;)V)R;W=S97(G72T^:&%S1F5A='5R92@G9&]M)RD["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS(&IU<W0@=&AE($I3(&YO9&4@9&5F:6YI=&EO
M;G,@87,@82!S=')I;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!*879A<V-R:7!T(&YO9&4@87)R87D@9&5F:6YI=&EO;G,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(')E;F1E<DYO9&5$969I;FET:6]N<R@I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]B=6EL9$EN9&5N=',H)'1H:7,M/E]R;V]T7VYO
M9&5S*3L*"B`@("`@("`@)&YO9&5*<R`]("<G.PH@("`@("`@(&9O<F5A8V@@
M*"1T:&ES+3Y?;F]D97,@87,@)&YO9&5?:60@/3X@)&YO9&4I('L*("`@("`@
M("`@("`@)&YO9&5*<R`N/2`D=&AI<RT^7V=E=$IS07)R87E%;&5M96YT*'-P
M<FEN=&8H)R5S6UPG)7-<)UTG+"`G;E\G("X@)'1H:7,M/E]I;G-T86YC92P@
M)&YO9&5?:60I+"`D;F]D92D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&YO9&5*<R`N("1T:&ES+3Y?:6YS=&%N8V4@+B`G+G)E;F1E<E1R964H<F]O
M=%]N;V1E<RD[)SL*("`@('T*"B`@("`O*BH*("`@("`J($]U='!U=',@=&AE
M(&1A=&$@9F]R('1H92!T<F5E(&%S(&$@:F%V87-C<FEP="!A<G)A>2X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V=E=%1R9653;W5R8V4H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8G)O
M=W-E<CL*"B`@("`@("`@)&IS("`]("<\<V-R:7!T('1Y<&4](G1E>'0O:F%V
M87-C<FEP="(^)R`N(")<;B(["B`@("`@("`@)&IS("X]("=V87(@97AT<F%#
M;VQS3&5F="`]("<@+B`D=&AI<RT^7V5X=')A7V-O;'-?;&5F="`N("([7&XB
M.PH@("`@("`@("1J<R`N/2`G=F%R(&5X=')A0V]L<U)I9VAT(#T@)R`N("1T
M:&ES+3Y?97AT<F%?8V]L<U]R:6=H="`N("([7&XB.PH@("`@("`@("1J<R`N
M/2`G=F%R("<@+B`D=&AI<RT^7W-O=7)C95]N86UE("X@)R`](&YE=R!!<G)A
M>2@I.R<@+B`B7&XB.PH*("`@("`@("!F;W)E86-H("@D=&AI<RT^7VYO9&5S
M(&%S("1N;V1E7VED(#T^("1N;V1E*2!["B`@("`@("`@("`@("1J<R`N/2`D
M=&AI<RT^7V=E=$IS07)R87E%;&5M96YT*'-P<FEN=&8H)R5S6UPG)7-<)UTG
M+"`D=&AI<RT^7W-O=7)C95]N86UE+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1B<F]W<V5R+3YE<V-A
M<&5*4T-O9&4H861D<VQA<VAE<R@D;F]D95]I9"DI*2P@)&YO9&4I.PH@("`@
M("`@('T*("`@("`@("`D:G,@+CT@)'1H:7,M/E]G971*<T%R<F%Y16QE;65N
M="@D=&AI<RT^7VAE861E<E]N86UE+"`D=&AI<RT^7VAE861E<BD["B`@("`@
M("`@)&IS("X]("1T:&ES+3Y?9V5T2G-!<G)A>45L96UE;G0H)'1H:7,M/E]O
M<'1I;VYS7VYA;64L("1T:&ES+3Y?;W!T:6]N<RD["B`@("`@("`@)&IS("X]
M("<\+W-C<FEP=#XG("X@(EQN(CL*"B`@("`@("`@<F5T=7)N("1J<SL*("`@
M('T*"B`@("`O*BH*("`@("`J($]U='!U=',@=&AE(&IA=F%S8W)I<'0@=&\@
M:6YI=&EA;&ES92!T:&4@=')E92X*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=%1R965);FET*"D*("`@
M('L*("`@("`@("`D:G,@(#T@)SQS8W)I<'0@='EP93TB=&5X="]J879A<V-R
M:7!T(CXG("X@(EQN(CL*("`@("`@("`D:G,@+CT@<W!R:6YT9B@G)3$D<R`]
M(&YE=R!(;W)D95]4<F5E*%PG)3$D<UPG*3LG("X@(EQN(BP*("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7VEN<W1A;F-E*3L*"B`@("`@("`@)&IS
M("X]("1T:&ES+3Y?9V5T2G-!<G)A>45L96UE;G0H)W)O;W1?;F]D97,G+"`D
M=&AI<RT^7W)O;W1?;F]D97,I.PH*("`@("`@("`D:G,@+CT@<W!R:6YT9B@B
M)7,N<F5N9&5R5')E92AR;V]T7VYO9&5S+"`E<RD[7&X\+W-C<FEP=#Y<;B(L
M"B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I;G-T86YC92P*("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-T871I8R`_("=T<G5E)R`Z
M("=F86QS92<I.PH*("`@("`@("!R971U<FX@)&IS.PH@("`@?0H*("`@(&9U
M;F-T:6]N(%]G971*<T%R<F%Y16QE;65N="@D=F%R+"`D=F%L=64I"B`@("![
M"B`@("`@("`@:68@*&ES7V%R<F%Y*"1V86QU92DI('L*("`@("`@("`@("`@
M)&IS(#T@)'9A<B`N("<@/2!N97<@07)R87DH*3LG("X@(EQN(CL*("`@("`@
M("`@("`@9F]R96%C:"`H)'9A;'5E(&%S("1K97D@/3X@)'9A;"D@>PH@("`@
M("`@("`@("`@("`@:68@*&ES7VYU;65R:6,H)&ME>2DI('L*("`@("`@("`@
M("`@("`@("`@("`D;F5W5F%R(#T@)'9A<B`N("=;)R`N("1K97D@+B`G72<[
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("1N97=687(@/2`D=F%R("X@)UM<)R<@+B`D:V5Y("X@)UPG72<["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D:G,@+CT@)'1H:7,M/E]G
M971*<T%R<F%Y16QE;65N="@D;F5W5F%R+"`D=F%L*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!R971U<FX@)&IS.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E='5R;B`D=F%R("X@(B`]("<B("X@861D<VQA<VAE<R@D
M=F%L=64I("X@(B<[7&XB.PH@("`@("`@('T*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]#<GEP=```````````````
M````````````````````````````````````````````````````````````
M```````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q
M-30S,S<S-R`P,C`S-S0`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<```````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,30T-3(Q(#$P-3$U-#,S-S,W(#`R,C,P-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`H*<F5Q=6ER95]O
M;F-E("=(;W)D92]#<GEP="YP:'`G.PH*+RHJ"B`J($AO<F1E7T-R>7!T7W-M
M:6UE.CH@<')O=FED97,@82!F<F%M97=O<FL@9F]R($AO<F1E(&%P<&QI8V%T
M:6]N<R!T;PH@*B!I;G1E<F%C="!W:71H('1H92!/<&5N4U-,(&QI8G)A<GD@
M86YD(&EM<&QE;65N="!3+TU)344N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<"QV(#$N-#DN,BXQ,B`R,#`V+S`R+S`S
M(#$U.C4R.C4U('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M
M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EK92!#;V-H<F%N92`\;6EK
M94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J
M($!P86-K86=E($AO<F1E7T-R>7!T"B`J+PIC;&%S<R!(;W)D95]#<GEP=%]S
M;6EM92!E>'1E;F1S($AO<F1E7T-R>7!T('L*"B`@("`O*BH*("`@("`J($]B
M:F5C="!)9&5N=&EF97)S('1O(&YA;64@87)R87DN"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]O:61S(#T@87)R87DH"B`@
M("`@("`@)S(N-2XT+C,G(#T^("=#;VUM;VY.86UE)RP*("`@("`@("`G,BXU
M+C0N-"<@/3X@)U-U<FYA;64G+`H@("`@("`@("<R+C4N-"XV)R`]/B`G0V]U
M;G1R>2<L"B`@("`@("`@)S(N-2XT+C<G(#T^("=,;V-A=&EO;B<L"B`@("`@
M("`@)S(N-2XT+C@G(#T^("=3=&%T94]R4')O=FEN8V4G+`H@("`@("`@("<R
M+C4N-"XY)R`]/B`G4W1R965T061D<F5S<R<L"B`@("`@("`@)S(N-2XT+C$P
M)R`]/B`G3W)G86YI<V%T:6]N)RP*("`@("`@("`G,BXU+C0N,3$G(#T^("=/
M<F=A;FES871I;VYA;%5N:70G+`H@("`@("`@("<R+C4N-"XQ,B<@/3X@)U1I
M=&QE)RP*("`@("`@("`G,BXU+C0N,C`G(#T^("=496QE<&AO;F5.=6UB97(G
M+`H@("`@("`@("<R+C4N-"XT,B<@/3X@)T=I=F5N3F%M92<L"@H@("`@("`@
M("<R+C4N,CDN,30G(#T^("=I9"UC92US=6)J96-T2V5Y261E;G1I9FEE<B<L
M"@H@("`@("`@("<R+C4N,CDN,30G(#T^("=I9"UC92US=6)J96-T2V5Y261E
M;G1I9FEE<B<L"B`@("`@("`@)S(N-2XR.2XQ-2<@/3X@)VED+6-E+6ME>55S
M86=E)RP*("`@("`@("`G,BXU+C(Y+C$W)R`]/B`G:60M8V4M<W5B:F5C=$%L
M=$YA;64G+`H@("`@("`@("<R+C4N,CDN,3DG(#T^("=I9"UC92UB87-I8T-O
M;G-T<F%I;G1S)RP*("`@("`@("`G,BXU+C(Y+C,Q)R`]/B`G:60M8V4M0U),
M1&ES=')I8G5T:6]N4&]I;G1S)RP*("`@("`@("`G,BXU+C(Y+C,R)R`]/B`G
M:60M8V4M8V5R=&EF:6-A=&50;VQI8VEE<R<L"B`@("`@("`@)S(N-2XR.2XS
M-2<@/3X@)VED+6-E+6%U=&AO<FET>4ME>4ED96YT:69I97(G+`H@("`@("`@
M("<R+C4N,CDN,S<G(#T^("=I9"UC92UE>'1+97E5<V%G92<L"@H@("`@("`@
M("<Q+C(N.#0P+C$Q,S4T.2XQ+CDN,2<@/3X@)T5M86EL)RP*("`@("`@("`G
M,2XR+C@T,"XQ,3,U-#DN,2XQ+C$G(#T^("=24T%%;F-R>7!T:6]N)RP*("`@
M("`@("`G,2XR+C@T,"XQ,3,U-#DN,2XQ+C(G(#T^("=M9#)7:71H4E-!16YC
M<GEP=&EO;B<L"B`@("`@("`@)S$N,BXX-#`N,3$S-30Y+C$N,2XT)R`]/B`G
M;60U=VET:%)3045N8W)Y<'1I;VXG+`H@("`@("`@("<Q+C(N.#0P+C$Q,S4T
M.2XQ+C$N-2<@/3X@)U-(02TQ5VET:%)3045N8W)Y<'1I;VXG+`H@("`@("`@
M("<Q+C(N.#0P+C$P,#0P+C0N,R<@/3X@)VED+61S82UW:71H+7-H82TQ)RP*
M"B`@("`@("`@)S$N,RXV+C$N-2XU+C<N,RXR)R`]/B`G:61?:W!?8VQI96YT
M075T:"<L"@H@("`@("`@("<R+C$V+C@T,"XQ+C$Q,S<S,"XQ+C$G(#T^("=N
M971S8V%P92UC97)T+71Y<&4G+`H@("`@("`@("<R+C$V+C@T,"XQ+C$Q,S<S
M,"XQ+C(G(#T^("=N971S8V%P92UB87-E+75R;"<L"B`@("`@("`@)S(N,38N
M.#0P+C$N,3$S-S,P+C$N,R<@/3X@)VYE='-C87!E+7)E=F]C871I;VXM=7)L
M)RP*("`@("`@("`G,BXQ-BXX-#`N,2XQ,3,W,S`N,2XT)R`]/B`G;F5T<V-A
M<&4M8V$M<F5V;V-A=&EO;BUU<FPG+`H@("`@("`@("<R+C$V+C@T,"XQ+C$Q
M,S<S,"XQ+C<G(#T^("=N971S8V%P92UC97)T+7)E;F5W86PM=7)L)RP*("`@
M("`@("`G,BXQ-BXX-#`N,2XQ,3,W,S`N,2XX)R`]/B`G;F5T<V-A<&4M8V$M
M<&]L:6-Y+75R;"<L"B`@("`@("`@)S(N,38N.#0P+C$N,3$S-S,P+C$N,3(G
M(#T^("=N971S8V%P92US<VPM<V5R=F5R+6YA;64G+`H@("`@("`@("<R+C$V
M+C@T,"XQ+C$Q,S<S,"XQ+C$S)R`]/B`G;F5T<V-A<&4M8V]M;65N="<L"B`@
M("`I.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@(%!A<F%M971E<B!A<G)A>2X*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`G=&5M<"<@/3X@3&]C871I;VX@
M;V8@=&5M<&]R87)Y(&1I<F5C=&]R>2X*("`@("`J+PH@("`@9G5N8W1I;VX@
M2&]R9&5?0W)Y<'1?<VUI;64H)'!A<F%M<RD*("`@('L*("`@("`@("`D=&AI
M<RT^7W1E;7!D:7(@/2`D<&%R86US6R=T96UP)UT["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!697)I9GD@82!P87-S<&AR87-E(&9O<B!A(&=I=F5N('!R:79A
M=&4@:V5Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!R:79A=&5?
M:V5Y("!4:&4@=7-E<B=S('!R:79A=&4@:V5Y+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<&%S<W!H<F%S92`@(%1H92!U<V5R)W,@<&%S<W!H<F%S92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%)E='5R;G,@=')U92!O;B!V
M86QI9"!P87-S<&AR87-E+"!F86QS92!O;B!I;G9A;&ED"B`@("`@*B`@("`@
M("`@("`@("`@("`@('!A<W-P:')A<V4N"B`@("`@*B`@("`@("`@("`@("`@
M("`@(%)E='5R;G,@4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@=F5R:69Y4&%S<W!H<F%S92@D<')I=F%T95]K97DL("1P87-S
M<&AR87-E*0H@("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1P87-S<&AR87-E
M*2D@>PH@("`@("`@("`@("`D<F5S(#T@;W!E;G-S;%]P:V5Y7V=E=%]P<FEV
M871E*"1P<FEV871E7VME>2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)')E<R`](&]P96YS<VQ?<&ME>5]G971?<')I=F%T92@D<')I=F%T95]K
M97DL("1P87-S<&AR87-E*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!I
M<U]R97-O=7)C92@D<F5S*3L*("`@('T*"B`@("`O*BH*("`@("`J($5N8W)Y
M<'0@=&5X="!U<VEN9R!3+TU)344N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D=&5X="`@(%1H92!T97AT('1O(&)E(&5N8W)Y<'1E9"X*("`@("`J
M($!P87)A;2!A<G)A>2`D<&%R86US("!4:&4@<&%R86UE=&5R<R!N965D960@
M9F]R(&5N8W)Y<'1I;VXN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M4V5E('1H92!I;F1I=FED=6%L(%]E;F-R>7!T*B@I(&9U;F-T:6]N<R!F;W(*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!T:&4@<&%R86UE=&5R(')E
M<75I<F5M96YT<RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M(&5N8W)Y<'1E9"!M97-S86=E+@H@("`@("H@("`@("`@("`@("`@("`@(%)E
M='5R;G,@4$5!4E]%<G)O<B!O8FIE8W0@;VX@97)R;W(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&5N8W)Y<'0H)'1E>'0L("1P87)A;7,@/2!A<G)A>2@I*0H@
M("`@>PH@("`@("`@("\J($-H96-K(&9O<B!A=F%I;&%B:6QI='D@;V8@3W!E
M;E-33"!02%`@97AT96YS:6]N+B`J+PH@("`@("`@("1O<&5N<W-L(#T@)'1H
M:7,M/F-H96-K1F]R3W!E;E-33"@I.PH@("`@("`@(&EF("AI<U]A*"1O<&5N
M<W-L+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D;W!E
M;G-S;#L*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D<&%R86US6R=T
M>7!E)UTI*2!["B`@("`@("`@("`@(&EF("@D<&%R86US6R=T>7!E)UT@/3T]
M("=M97-S86=E)RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M96YC<GEP=$UE<W-A9V4H)'1E>'0L("1P87)A;7,I.PH@("`@("`@("`@("!]
M(&5L<V5I9B`H)'!A<F%M<ULG='EP92==(#T]/2`G<VEG;F%T=7)E)RD@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?96YC<GEP=%-I9VYA='5R
M92@D=&5X="P@)'!A<F%M<RD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!$96-R>7!T('1E>'0@=FEA(%,O34E-12X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("`@5&AE('1E>'0@
M=&\@8F4@<VUI;64@9&5C<GEP=&5D+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P
M87)A;7,@(%1H92!P87)A;65T97)S(&YE961E9"!F;W(@9&5C<GEP=&EO;BX*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!3964@=&AE(&EN9&EV:61U
M86P@7V1E8W)Y<'0J*"D@9G5N8W1I;VYS(&9O<@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@('1H92!P87)A;65T97(@<F5Q=6ER96UE;G1S+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9&5C<GEP=&5D(&UE<W-A
M9V4N"B`@("`@*B`@("`@("`@("`@("`@("`@4F5T=7)N<R!014%27T5R<F]R
M(&]B:F5C="!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@9&5C<GEP
M="@D=&5X="P@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@+RH@
M0VAE8VL@9F]R(&%V86EL86)I;&ET>2!O9B!/<&5N4U-,(%!(4"!E>'1E;G-I
M;VXN("HO"B`@("`@("`@)&]P96YS<VP@/2`D=&AI<RT^8VAE8VM&;W)/<&5N
M4U-,*"D["B`@("`@("`@:68@*&ES7V$H)&]P96YS<VPL("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1O<&5N<W-L.PH@("`@("`@('T*
M"B`@("`@("`@:68@*&ES<V5T*"1P87)A;7-;)W1Y<&4G72DI('L*("`@("`@
M("`@("`@:68@*"1P87)A;7-;)W1Y<&4G72`]/3T@)VUE<W-A9V4G*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]D96-R>7!T365S<V%G92@D
M=&5X="P@)'!A<F%M<RD["B`@("`@("`@("`@('T@96QS96EF("@H)'!A<F%M
M<ULG='EP92==(#T]/2`G<VEG;F%T=7)E)RD@?'P*("`@("`@("`@("`@("`@
M("`@("`@("@D<&%R86US6R=T>7!E)UT@/3T]("=D971A8VAE9"US:6=N871U
M<F4G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&5C<GEP
M=%-I9VYA='5R92@D=&5X="P@)'!A<F%M<RD["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!697)I9GD@82!S:6=N871U
M<F4@=7-I;F<@=FEA(%,O34E-12X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1T97AT("!4:&4@;75L=&EP87)T+W-I9VYE9"!D871A('1O(&)E('9E
M<FEF:65D+@H@("`@("H@0'!A<F%M(&UI>&5D("1C97)T<R`@16ET:&5R(&$@
M<VEN9VQE(&]R(&%R<F%Y(&]F(')O;W0@8V5R=&EF:6-A=&5S+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1D0VQA<W,@($]B:F5C="!W:71H('1H92!F;VQL
M;W=I;F<@96QE;65N=',Z"B`@("`@*B`@("`@("`@("`@("`@("`@("`G<F5S
M=6QT)R`M/B!2971U<FYS('1R=64@;VX@<W5C8V5S<SL*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?17)R;W(@;V)J96-T(&]N
M(&5R<F]R+@H@("`@("H@("`@("`@("`@("`@("`@("`@)V-E<G0G("T^(%1H
M92!C97)T:69I8V%T92!O9B!T:&4@<VEG;F5R('-T;W)E9`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EN('1H92!M97-S86=E("AI;B!0
M14T@9F]R;6%T*2X*("`@("`J("`@("`@("`@("`@("`@("`@("=E;6%I;"<@
M+3X@5&AE(&5M86EL(&]F('1H92!S:6=N:6YG('!E<G-O;BX*("`@("`J+PH@
M("`@9G5N8W1I;VX@=F5R:69Y*"1T97AT+"`D8V5R=',I"B`@("!["B`@("`@
M("`@+RH@0VAE8VL@9F]R(&%V86EL86)I;&ET>2!O9B!/<&5N4U-,(%!(4"!E
M>'1E;G-I;VXN("HO"B`@("`@("`@)&]P96YS<VP@/2`D=&AI<RT^8VAE8VM&
M;W)/<&5N4U-,*"D["B`@("`@("`@:68@*&ES7V$H)&]P96YS<VPL("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1O<&5N<W-L.PH@("`@
M("`@('T*"B`@("`@("`@+RH@0W)E871E('1E;7`@9FEL97,@9F]R(&EN<'5T
M+V]U='!U="X@*B\*("`@("`@("`D:6YP=70@/2`D=&AI<RT^7V-R96%T951E
M;7!&:6QE*"=H;W)D92US;6EM92<I.PH@("`@("`@("1O=71P=70@/2`D=&AI
M<RT^7V-R96%T951E;7!&:6QE*"=H;W)D92US;6EM92<I.PH*("`@("`@("`O
M*B!7<FET92!T97AT('1O(&9I;&4@*B\*("`@("`@("`D9G`@/2!F;W!E;B@D
M:6YP=70L("=W*R<I.PH@("`@("`@(&9W<FET92@D9G`L("1T97AT*3L*("`@
M("`@("!F8VQO<V4H)&9P*3L*"B`@("`@("`@)')O;W1?8V5R=',@/2!A<G)A
M>2@I.PH@("`@("`@(&EF("@A:7-?87)R87DH)&-E<G1S*2D@>PH@("`@("`@
M("`@("`D8V5R=',@/2!A<G)A>2@D8V5R=',I.PH@("`@("`@('T*("`@("`@
M("!F;W)E86-H("@D8V5R=',@87,@)&9I;&4I('L*("`@("`@("`@("`@:68@
M*&9I;&5?97AI<W1S*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@)')O;W1?
M8V5R='-;72`]("1F:6QE.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("`D;V(@/2`F;F5W('-T9$-L87-S.PH*("`@("`@("!I9B`H(65M<'1Y
M*"1R;V]T7V-E<G1S*2D@>PH@("`@("`@("`@("`D<F5S=6QT(#T@;W!E;G-S
M;%]P:V-S-U]V97)I9GDH)&EN<'5T+"`P+"`D;W5T<'5T+"`D<F]O=%]C97)T
M<RD["B`@("`@("`@("`@("\J($UE<W-A9V4@=F5R:69I960@*B\*("`@("`@
M("`@("`@:68@*"1R97-U;'0@/3T]('1R=64I('L*("`@("`@("`@("`@("`@
M("1O8BT^<F5S=6QT(#T@=')U93L*("`@("`@("`@("`@("`@("1O8BT^8V5R
M="`](&9I;&5?9V5T7V-O;G1E;G1S*"1O=71P=70I.PH@("`@("`@("`@("`@
M("`@)&]B+3YE;6%I;"`]("1T:&ES+3YG971%;6%I;$9R;VU+97DH)&]B+3YC
M97)T*3L*("`@("`@("`@("`@("`@(')E='5R;B`D;V(["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@("\J(%1R>2!A9V%I;B!W:71H;W5T('9E
M<F9Y:6YG('1H92!S:6=N97(G<R!C97)T("HO"B`@("`@("`@)')E<W5L="`]
M(&]P96YS<VQ?<&MC<S=?=F5R:69Y*"1I;G!U="P@4$M#4S=?3D]615))1EDL
M("1O=71P=70I.PH*("`@("`@("!I9B`H*"1R97-U;'0@/3T]('1R=64I('Q\
M("@D<F5S=6QT(#T]/2`M,2DI('L*("`@("`@("`@("`@)&]B+3YR97-U;'0@
M/2!014%2.CIR86ES945R<F]R*%\H(DUE<W-A9V4@5F5R:69I960@4W5C8V5S
M<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T
M(&)E('9E<FEF:65D+B(I+"`G:&]R9&4N=V%R;FEN9R<I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1O8BT^<F5S=6QT(#T@4$5!4CHZ<F%I<V5%
M<G)O<BA?*")697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA
M>2!H879E(&)E96X@=&%M<&5R960@=VET:"XB*2P@)VAO<F1E+F5R<F]R)RD[
M"B`@("`@("`@?0H*("`@("`@("`D;V(M/F-E<G0@/2!F:6QE7V=E=%]C;VYT
M96YT<R@D;W5T<'5T*3L*("`@("`@("`D;V(M/F5M86EL(#T@)'1H:7,M/F=E
M=$5M86EL1G)O;4ME>2@D;V(M/F-E<G0I.PH*("`@("`@("!R971U<FX@)&]B
M.PH@("`@?0H*("`@("\J*@H@("`@("H@17AT<F%C="!T:&4@8V]N=&5N=',@
M9G)O;2!S:6=N960@4R]-24U%(&1A=&$N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D9&%T82`@("`@5&AE('-I9VYE9"!3+TU)344@9&%T82X*("`@
M("`J($!P87)A;2!S=')I;F<@)'-S;'!A=&@@(%1H92!P871H('1O('1H92!/
M<&5N4U-,(&)I;F%R>2X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE(&-O;G1E;G1S(&5M8F5D9&5D(&EN('1H92!S:6=N960@9&%T82X*("`@
M("`J("`@("`@("`@("`@("`@("!2971U<FYS(%!%05)?17)R;W(@;VX@97)R
M;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X=')A8W13:6=N961#;VYT96YT
M<R@D9&%T82P@)'-S;'!A=&@I"B`@("!["B`@("`@("`@)'!I<&5S7V1E<V,@
M/2!A<G)A>2@*("`@("`@("`@("`@,"`]/B!A<G)A>2@G<&EP92<L("=R)RDL
M"B`@("`@("`@("`@(#$@/3X@87)R87DH)W!I<&4G+"`G=R<I"B`@("`@("`@
M*3L*"B`@("`@("`@)&9P(#T@<')O8U]O<&5N*"1S<VQP871H("X@)R!S;6EM
M92`M=F5R:69Y("UN;W9E<FEF>2`M;F]C:&%I;B<L("1P:7!E<U]D97-C+"`D
M<&EP97,I.PH@("`@("`@(&EF("@A:7-?<F5S;W5R8V4H)&9P*2D@>PH@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")/<&5N4U-,(&5R
M<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-
M12!P87)T+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!]"@H@("`@("`@
M("1O=71P=70@/2`G)SL*"B`@("`@("`@+RH@)'!I<&5S6S!=(#T^('=R:71E
M86)L92!H86YD;&4@8V]N;F5C=&5D('1O(&-H:6QD('-T9&EN"B`@("`@("`@
M("`@)'!I<&5S6S%=(#T^(')E861A8FQE(&AA;F1L92!C;VYN96-T960@=&\@
M8VAI;&0@<W1D;W5T("HO"B`@("`@("`@9G=R:71E*"1P:7!E<ULP72P@)&1A
M=&$I.PH@("`@("`@(&9C;&]S92@D<&EP97-;,%TI.PH*("`@("`@("!W:&EL
M92`H(69E;V8H)'!I<&5S6S%=*2D@>PH@("`@("`@("`@("`D;W5T<'5T("X]
M(&9G971S*"1P:7!E<ULQ72P@,3`R-"D["B`@("`@("`@?0H@("`@("`@(&9C
M;&]S92@D<&EP97-;,5TI.PH@("`@("`@('!R;V-?8VQO<V4H)&9P*3L*"B`@
M("`@("`@<F5T=7)N("1O=71P=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M:6=N(&$@34E-15]087)T('5S:6YG(%,O34E-12X*("`@("`J"B`@("`@*B!`
M<&%R86T@34E-15]087)T("1M:6UE7W!A<G0@(%1H92!-24U%7U!A<G0@;V)J
M96-T('1O('-I9VXN"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@("`@
M("`@(%1H92!P87)A;65T97)S(')E<75I<F5D(&9O<B!S:6=N:6YG+@H@("`@
M("H*("`@("`J($!R971U<FX@34E-15]087)T("!!($U)345?4&%R="!O8FIE
M8W0@=&AA="!I<R!S:6=N960N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M4F5T=7)N<R!014%27T5R<F]R(&]B:F5C="!O;B!E<G)O<BX*("`@("`J+PH@
M("`@9G5N8W1I;VX@<VEG;DU)345087)T*"1M:6UE7W!A<G0L("1P87)A;7,I
M"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+U!A<G0N
M<&AP)SL*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TU)344O4W1R=6-T
M=7)E+G!H<"<["@H@("`@("`@("\J(%-I9VX@=&AE('!A<G0@87,@82!M97-S
M86=E("HO"B`@("`@("`@)&UE<W-A9V4@/2`D=&AI<RT^96YC<GEP="@D;6EM
M95]P87)T+3YT;T-A;F]N:6-A;%-T<FEN9R@I+"`D<&%R86US*3L*"B`@("`@
M("`@+RH@0G)E86L@=&AE(')E<W5L="!I;G1O(&ET<R!C;VUP;VYE;G1S("HO
M"B`@("`@("`@)&UI;65?;65S<V%G92`]($U)345?4W1R=6-T=7)E.CIP87)S
M951E>'1-24U%365S<V%G92@D;65S<V%G92D["@H@("`@("`@("1S;6EM95]S
M:6=N(#T@)&UI;65?;65S<V%G92T^9V5T4&%R="@R*3L*("`@("`@("`D<VUI
M;65?<VEG;BT^<V5T1&5S8W)I<'1I;VXH7R@B4R]-24U%($-R>7!T;V=R87!H
M:6,@4VEG;F%T=7)E(BDI.PH@("`@("`@("1S;6EM95]S:6=N+3YT<F%N<V9E
M<D1E8V]D94-O;G1E;G1S*"D["B`@("`@("`@)'-M:6UE7W-I9VXM/G-E=%1R
M86YS9F5R16YC;V1I;F<H)V)A<V4V-"<I.PH*("`@("`@("`D<VUI;65?<&%R
M="`]("9N97<@34E-15]087)T*"=M=6QT:7!A<G0O<VEG;F5D)RD["B`@("`@
M("`@)'-M:6UE7W!A<G0M/G-E=$-O;G1E;G1S*"=4:&ES(&ES(&$@8W)Y<'1O
M9W)A<&AI8V%L;'D@<VEG;F5D(&UE<W-A9V4@:6X@34E-12!F;W)M870N)R`N
M(")<;B(I.PH@("`@("`@("1S;6EM95]P87)T+3YA9&1087)T*"1M:6UE7W!A
M<G0I.PH@("`@("`@("1S;6EM95]P87)T+3YA9&1087)T*"1S;6EM95]S:6=N
M*3L*("`@("`@("`D<VUI;65?<&%R="T^<V5T0V]N=&5N=%1Y<&5087)A;65T
M97(H)W!R;W1O8V]L)RP@)V%P<&QI8V%T:6]N+W!K8W,W+7-I9VYA='5R92<I
M.PH@("`@("`@("1S;6EM95]P87)T+3YS971#;VYT96YT5'EP95!A<F%M971E
M<B@G;6EC86QG)RP@)W-H83$G*3L*"B`@("`@("`@<F5T=7)N("1S;6EM95]P
M87)T.PH@("`@?0H*("`@("\J*@H@("`@("H@16YC<GEP="!A($U)345?4&%R
M="!U<VEN9R!3+TU)344N"B`@("`@*@H@("`@("H@0'!A<F%M($U)345?4&%R
M="`D;6EM95]P87)T("!4:&4@34E-15]087)T(&]B:F5C="!T;R!E;F-R>7!T
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("`@("`@("!4:&4@<&%R
M86UE=&5R<R!R97%U:7)E9"!F;W(@96YC<GEP=&EO;BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N($U)345?4&%R="`@02!-24U%7U!A<G0@;V)J96-T('1H870@
M:7,@96YC<GEP=&5D+@H@("`@("H@("`@("`@("`@("`@("`@("`@(%)E='5R
M;G,@4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M96YC<GEP=$U)345087)T*"1M:6UE7W!A<G0L("1P87)A;7,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O34E-12]087)T
M+G!H<"<["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+U-T<G5C
M='5R92YP:'`G.PH*("`@("`@("`O*B!3:6=N('1H92!P87)T(&%S(&$@;65S
M<V%G92`J+PH@("`@("`@("1M97-S86=E(#T@)'1H:7,M/F5N8W)Y<'0H)&UI
M;65?<&%R="T^=&]#86YO;FEC86Q3=')I;F<H*2P@)'!A<F%M<RD["B`@("`@
M("`@:68@*&ES7V$H)&UE<W-A9V4L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1M97-S86=E.PH@("`@("`@('T*"B`@("`@("`@+RH@
M0G)E86L@=&AE(')E<W5L="!I;G1O(&ET<R!C;VUP;VYE;G1S("HO"B`@("`@
M("`@)&UI;65?;65S<V%G92`]($U)345?4W1R=6-T=7)E.CIP87)S951E>'1-
M24U%365S<V%G92@D;65S<V%G92D["@H@("`@("`@("1S;6EM95]P87)T(#T@
M)&UI;65?;65S<V%G92T^9V5T0F%S95!A<G0H*3L*("`@("`@("`D<VUI;65?
M<&%R="T^<V5T1&5S8W)I<'1I;VXH7R@B4R]-24U%($5N8W)Y<'1E9"!-97-S
M86=E(BDI.PH@("`@("`@("1S;6EM95]P87)T+3YT<F%N<V9E<D1E8V]D94-O
M;G1E;G1S*"D["B`@("`@("`@)'-M:6UE7W!A<G0M/G-E=%1R86YS9F5R16YC
M;V1I;F<H)V)A<V4V-"<I.PH@("`@("`@("1S;6EM95]P87)T+3YS971$:7-P
M;W-I=&EO;B@G:6YL:6YE)RD["@H@("`@("`@("\J($)Y(&1E9F%U;'0L(&5N
M8W)Y<'0H*2!P<F]D=6-E<R!A(&UE<W-A9V4@=VET:"!T>7!E"B`@("`@("`@
M("H@)V%P<&QI8V%T:6]N+W@M<&MC<S<M;6EM92<@86YD(&YO("=S;6EM92UT
M>7!E)R!P87)A;65T97(N(%!E<@H@("`@("`@("`J(%)&0R`R,S$Q+"!T:&4@
M;6]R92!C;W)R96-T($U)344@='EP92!I<R`G87!P;&EC871I;VXO<&MC<S<M
M;6EM92<*("`@("`@("`@*B!A;F0@=&AE('-M:6UE+71Y<&4@<VAO=6QD(&)E
M("=E;G9E;&]P960M9&%T82<N("HO"B`@("`@("`@)'-M:6UE7W!A<G0M/G-E
M=%1Y<&4H)V%P<&QI8V%T:6]N+W!K8W,W+6UI;64G*3L*("`@("`@("`D<VUI
M;65?<&%R="T^<V5T0V]N=&5N=%1Y<&5087)A;65T97(H)W-M:6UE+71Y<&4G
M+"`G96YV96QO<&5D+61A=&$G*3L*"B`@("`@("`@<F5T=7)N("1S;6EM95]P
M87)T.PH@("`@?0H*("`@("\J*@H@("`@("H@16YC<GEP="!A(&UE<W-A9V4@
M:6X@4R]-24U%(&9O<FUA="!U<VEN9R!A('!U8FQI8R!K97DN"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D=&5X="`@(%1H92!T97AT('1O(&)E(&5N8W)Y<'1E9"X*("`@("`J
M($!P87)A;2!A<G)A>2`D<&%R86US("!4:&4@<&%R86UE=&5R<R!N965D960@
M9F]R(&5N8W)Y<'1I;VXN"B`@("`@*B`\<')E/@H@("`@("H@4&%R86UE=&5R
M<SH*("`@("`J(#T]/3T]/3T]/3T]"B`@("`@*B`G='EP92<@("`@/3X@("=M
M97-S86=E)R`H4D5154E2140I"B`@("`@*B`G<'5B:V5Y)R`@/3X@('!U8FQI
M8R!K97DN("A215%525)%1"D*("`@("`J("=E;6%I;"<@("`]/B`@12UM86EL
M(&%D9')E<W,@;V8@<F5C:7!I96YT+B!)9B!N;W0@<')E<V5N="P@;W(@;F]T
M(&9O=6YD"B`@("`@*B`@("`@("`@("`@("`@(&EN('1H92!P=6)L:6,@:V5Y
M+"!T:&4@9FER<W0@92UM86EL(&%D9')E<W,@9F]U;F0@:6X@=&AE"B`@("`@
M*B`@("`@("`@("`@("`@(&ME>2!W:6QL(&)E('5S960@:6YS=&5A9"X@*$]P
M=&EO;F%L*0H@("`@("H@/"]P<F4^"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!E;F-R>7!T960@;65S<V%G92X*("`@("`J("`@("`@("`@
M("`@("`@("!2971U<FX@4$5!4E]%<G)O<B!O8FIE8W0@;VX@97)R;W(N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]E;F-R>7!T365S<V%G92@D=&5X="P@)'!A
M<F%M<RD*("`@('L*("`@("`@("`D96UA:6P@/2!N=6QL.PH*("`@("`@("`O
M*B!#:&5C:R!F;W(@<F5Q=6ER960@<&%R86UE=&5R<RX@*B\*("`@("`@("!I
M9B`H(6ES<V5T*"1P87)A;7-;)W!U8FME>2==*2D@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")!('!U8FQI8R!334E-12!K97D@
M:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(BDL("=H;W)D92YE
M<G)O<B<I.PH@("`@("`@('T*"B`@("`@("`@+RH@0W)E871E('1E;7`@9FEL
M97,@9F]R(&EN<'5T+V]U='!U="X@*B\*("`@("`@("`D:6YP=70@/2`D=&AI
M<RT^7V-R96%T951E;7!&:6QE*"=H;W)D92US;6EM92<I.PH@("`@("`@("1O
M=71P=70@/2`D=&AI<RT^7V-R96%T951E;7!&:6QE*"=H;W)D92US;6EM92<I
M.PH*("`@("`@("`O*B!3=&]R92!M97-S86=E(&EN(&9I;&4N("HO"B`@("`@
M("`@)&9P,2`](&9O<&5N*"1I;G!U="P@)W<K)RD["B`@("`@("`@9G!U=',H
M)&9P,2P@)'1E>'0I.PH@("`@("`@(&9C;&]S92@D9G`Q*3L*"B`@("`@("`@
M:68@*&ES<V5T*"1P87)A;7-;)V5M86EL)UTI*2!["B`@("`@("`@("`@("1E
M;6%I;"`]("1P87)A;7-;)V5M86EL)UT["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&5M86EL(#T@)'1H:7,M/F=E=$5M86EL1G)O;4ME>2@D<&%R
M86US6R=P=6)K97DG72D["B`@("`@("`@("`@(&EF("AI<U]N=6QL*"1E;6%I
M;"DI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I
M;"!A9&1R97-S+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@+RH@16YC<GEP="!T:&4@9&]C=6UE;G0N("HO
M"B`@("`@("`@:68@*&]P96YS<VQ?<&MC<S=?96YC<GEP="@D:6YP=70L("1O
M=71P=70L("1P87)A;7-;)W!U8FME>2==+"!A<G)A>2@G5&\G(#T^("1E;6%I
M;"DI*2!["B`@("`@("`@("`@("1R97-U;'0@/2!F:6QE7V=E=%]C;VYT96YT
M<R@D;W5T<'5T*3L*("`@("`@("`@("`@:68@*"%E;7!T>2@D<F5S=6QT*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9FEX0V]N=&5N=%1Y
M<&4H)')E<W5L="P@)V5N8W)Y<'0G*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V]U;&0@
M;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(BDL("=H;W)D92YE<G)O<B<I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4VEG;B!A(&UE<W-A9V4@:6X@4R]-
M24U%(&9O<FUA="!U<VEN9R!A('!R:79A=&4@:V5Y+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'1E>'0@("!4:&4@=&5X="!T;R!B92!S:6=N960N"B`@("`@*B!`<&%R86T@
M87)R87D@)'!A<F%M<R`@5&AE('!A<F%M971E<G,@;F5E9&5D(&9O<B!S:6=N
M:6YG+@H@("`@("H@/'!R93X*("`@("`J(%!A<F%M971E<G,Z"B`@("`@*B`]
M/3T]/3T]/3T]/0H@("`@("H@)V-E<G1S)R`@("`@("`]/B`@061D:71I;VYA
M;"!S:6=N:6YG(&-E<G1S("A/<'1I;VYA;"D*("`@("`J("=P87-S<&AR87-E
M)R`@/3X@(%!A<W-P:')A<V4@9F]R(&ME>2`H4D5154E2140I"B`@("`@*B`G
M<')I=FME>2<@("`@(#T^("!0<FEV871E(&ME>2`H4D5154E2140I"B`@("`@
M*B`G<'5B:V5Y)R`@("`@(#T^("!0=6)L:6,@:V5Y("A215%525)%1"D*("`@
M("`J("=S:6=T>7!E)R`@("`@/3X@($1E=&5R;6EN92!T:&4@<VEG;F%T=7)E
M('1Y<&4@=&\@=7-E+B`H3W!T:6]N86PI"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`G8VQE87)T97AT)R`@+2T@($UA:V4@82!C;&5A<B!T97AT('-I9VYA
M='5R90H@("`@("H@("`@("`@("`@("`@("`@("`@)V1E=&%C:"<@("`@("TM
M("!-86ME(&$@9&5T86-H960@<VEG;F%T=7)E("A$149!54Q4*0H@("`@("H@
M)W1Y<&4G("`@("`@("`]/B`@)W-I9VYA='5R92<@*%)%455)4D5$*0H@("`@
M("H@/"]P<F4^"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!S
M:6=N960@;65S<V%G92X*("`@("`J("`@("`@("`@("`@("`@("!2971U<FX@
M4$5!4E]%<G)O<B!O8FIE8W0@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]E;F-R>7!T4VEG;F%T=7)E*"1T97AT+"`D<&%R86US*0H@("`@>PH@
M("`@("`@("\J($-H96-K(&9O<B!S96-U<F4@8V]N;F5C=&EO;BX@*B\*("`@
M("`@("`D<V5C=7)E7V-H96-K(#T@)'1H:7,M/G)E<75I<F5396-U<F5#;VYN
M96-T:6]N*"D["B`@("`@("`@:68@*&ES7V$H)'-E8W5R95]C:&5C:RP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'-E8W5R95]C:&5C
M:SL*("`@("`@("!]"@H@("`@("`@("\J($-H96-K(&9O<B!R97%U:7)E9"!P
M87)A;65T97)S+B`J+PH@("`@("`@(&EF("@A:7-S970H)'!A<F%M<ULG<'5B
M:V5Y)UTI('Q\"B`@("`@("`@("`@("%I<W-E="@D<&%R86US6R=P<FEV:V5Y
M)UTI('Q\"B`@("`@("`@("`@("%A<G)A>5]K97E?97AI<W1S*"=P87-S<&AR
M87-E)RP@)'!A<F%M<RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H7R@B02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)
M344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A
M(&UE<W-A9V4N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T*"B`@("`@
M("`@+RH@0W)E871E('1E;7`@9FEL97,@9F]R(&EN<'5T+V]U='!U="]C97)T
M:69I8V%T97,N("HO"B`@("`@("`@)&EN<'5T(#T@)'1H:7,M/E]C<F5A=&54
M96UP1FEL92@G:&]R9&4M<VUI;64G*3L*("`@("`@("`D;W5T<'5T(#T@)'1H
M:7,M/E]C<F5A=&5496UP1FEL92@G:&]R9&4M<VUI;64G*3L*("`@("`@("`D
M8V5R=',@/2`D=&AI<RT^7V-R96%T951E;7!&:6QE*"=H;W)D92US;6EM92<I
M.PH*("`@("`@("`O*B!3=&]R92!M97-S86=E(&EN('1E;7!O<F%R>2!F:6QE
M+B`J+PH@("`@("`@("1F<"`](&9O<&5N*"1I;G!U="P@)W<K)RD["B`@("`@
M("`@9G!U=',H)&9P+"`D=&5X="D["B`@("`@("`@9F-L;W-E*"1F<"D["@H@
M("`@("`@("\J(%-T;W)E(&%D9&ET:6]N86P@8V5R=',@:6X@=&5M<&]R87)Y
M(&9I;&4N("HO"B`@("`@("`@:68@*"%E;7!T>2@D<&%R86US6R=C97)T<R==
M*2D@>PH@("`@("`@("`@("`D9G`@/2!F;W!E;B@D8V5R=',L("=W*R<I.PH@
M("`@("`@("`@("!F<'5T<R@D9G`L("1P87)A;7-;)V-E<G1S)UTI.PH@("`@
M("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@("!]"@H@("`@("`@("\J($1E
M=&5R;6EN92!T:&4@<VEG;F%T=7)E('1Y<&4@=&\@=7-E+B`J+PH@("`@("`@
M(&EF("AI<W-E="@D<&%R86US6R=S:6=T>7!E)UTI("8F("@D<&%R86US6R=S
M:6=T>7!E)UT@/3T@)V-L96%R=&5X="<I*2!["B`@("`@("`@("`@("1F;&%G
M<R`](%!+0U,W7U1%6%0["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)&9L86=S(#T@4$M#4S=?1$5404-(140["B`@("`@("`@?0H*("`@("`@("`D
M<')I=FME>2`]("AI<U]N=6QL*"1P87)A;7-;)W!A<W-P:')A<V4G72DI(#\@
M)'!A<F%M<ULG<')I=FME>2==(#H@87)R87DH)'!A<F%M<ULG<')I=FME>2==
M+"`D<&%R86US6R=P87-S<&AR87-E)UTI.PH*("`@("`@("!I9B`H96UP='DH
M)'!A<F%M<ULG8V5R=',G72DI('L*("`@("`@("`@("`@)')E<R`](&]P96YS
M<VQ?<&MC<S=?<VEG;B@D:6YP=70L("1O=71P=70L("1P87)A;7-;)W!U8FME
M>2==+"`D<')I=FME>2P@87)R87DH*2P@)&9L86=S*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D<F5S(#T@;W!E;G-S;%]P:V-S-U]S:6=N*"1I
M;G!U="P@)&]U='!U="P@)'!A<F%M<ULG<'5B:V5Y)UTL("1P<FEV:V5Y+"!A
M<G)A>2@I+"`D9FQA9W,L("1C97)T<RD["B`@("`@("`@?0H*("`@("`@("!I
M9B`H(21R97,I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(BDL("=H;W)D
M92YE<G)O<B<I.PH@("`@("`@('T*"B`@("`@("`@)&1A=&$@/2!F:6QE7V=E
M=%]C;VYT96YT<R@D;W5T<'5T*3L*("`@("`@("!R971U<FX@)'1H:7,M/E]F
M:7A#;VYT96YT5'EP92@D9&%T82P@)W-I9VYA='5R92<I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1&5C<GEP="!A;B!3+TU)344@96YC<GEP=&5D(&UE<W-A
M9V4@=7-I;F<@82!P<FEV871E+W!U8FQI8R!K97EP86ER"B`@("`@*B!A;F0@
M82!P87-S:'!R87-E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@("!4:&4@=&5X="!T
M;R!B92!D96-R>7!T960N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@
M5&AE('!A<F%M971E<G,@;F5E9&5D(&9O<B!D96-R>7!T:6]N+@H@("`@("H@
M/'!R93X*("`@("`J(%!A<F%M971E<G,Z"B`@("`@*B`]/3T]/3T]/3T]/0H@
M("`@("H@)W1Y<&4G("`@("`@("`]/B`@)VUE<W-A9V4G("A215%525)%1"D*
M("`@("`J("=P=6)K97DG("`@("`@/3X@('!U8FQI8R!K97DN("A215%525)%
M1"D*("`@("`J("=P<FEV:V5Y)R`@("`@/3X@('!R:79A=&4@:V5Y+B`H4D51
M54E2140I"B`@("`@*B`G<&%S<W!H<F%S92<@(#T^("!087-S<&AR87-E(&9O
M<B!+97DN("A215%525)%1"D*("`@("`J(#PO<')E/@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@9&5C<GEP=&5D(&UE<W-A9V4N"B`@("`@
M*B`@("`@("`@("`@("`@("`@4F5T=7)N<R!014%27T5R<F]R(&]B:F5C="!O
M;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@7V1E8W)Y<'1-97-S86=E
M*"1T97AT+"`D<&%R86US*0H@("`@>PH@("`@("`@("\J($-H96-K(&9O<B!S
M96-U<F4@8V]N;F5C=&EO;BX@*B\*("`@("`@("`D<V5C=7)E7V-H96-K(#T@
M)'1H:7,M/G)E<75I<F5396-U<F5#;VYN96-T:6]N*"D["B`@("`@("`@:68@
M*&ES7V$H)'-E8W5R95]C:&5C:RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'-E8W5R95]C:&5C:SL*("`@("`@("!]"@H@("`@("`@
M("\J($-H96-K(&9O<B!R97%U:7)E9"!P87)A;65T97)S+B`J+PH@("`@("`@
M(&EF("@A:7-S970H)'!A<F%M<ULG<'5B:V5Y)UTI('Q\"B`@("`@("`@("`@
M("%I<W-E="@D<&%R86US6R=P<FEV:V5Y)UTI('Q\"B`@("`@("`@("`@("%A
M<G)A>5]K97E?97AI<W1S*"=P87-S<&AR87-E)RP@)'!A<F%M<RDI('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B02!P=6)L:6,@
M4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N(BDL("=H;W)D
M92YE<G)O<B<I.PH@("`@("`@('T*"B`@("`@("`@+RH@0W)E871E('1E;7`@
M9FEL97,@9F]R(&EN<'5T+V]U='!U="X@*B\*("`@("`@("`D:6YP=70@/2`D
M=&AI<RT^7V-R96%T951E;7!&:6QE*"=H;W)D92US;6EM92<I.PH@("`@("`@
M("1O=71P=70@/2`D=&AI<RT^7V-R96%T951E;7!&:6QE*"=H;W)D92US;6EM
M92<I.PH*("`@("`@("`O*B!3=&]R92!M97-S86=E(&EN(&9I;&4N("HO"B`@
M("`@("`@)&9P(#T@9F]P96XH)&EN<'5T+"`G=RLG*3L*("`@("`@("!F<'5T
M<R@D9G`L('1R:6TH)'1E>'0I*3L*("`@("`@("!F8VQO<V4H)&9P*3L*"B`@
M("`@("`@)'!R:79K97D@/2`H:7-?;G5L;"@D<&%R86US6R=P87-S<&AR87-E
M)UTI*2`_("1P87)A;7-;)W!R:79K97DG72`Z(&%R<F%Y*"1P87)A;7-;)W!R
M:79K97DG72P@)'!A<F%M<ULG<&%S<W!H<F%S92==*3L*("`@("`@("!I9B`H
M;W!E;G-S;%]P:V-S-U]D96-R>7!T*"1I;G!U="P@)&]U='!U="P@)'!A<F%M
M<ULG<'5B:V5Y)UTL("1P<FEV:V5Y*2D@>PH@("`@("`@("`@("!R971U<FX@
M9FEL95]G971?8V]N=&5N=',H)&]U='!U="D["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#;W5L9"!N;W0@9&5C<GEP
M="!3+TU)344@9&%T82XB*2P@)VAO<F1E+F5R<F]R)RD["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!3:6=N(&%N9"!%;F-R>7!T(&$@34E-15]087)T('5S:6YG
M(%,O34E-12X*("`@("`J"B`@("`@*B!`<&%R86T@34E-15]087)T("1M:6UE
M7W!A<G0@("!4:&4@34E-15]087)T(&]B:F5C="!T;R!S:6=N(&%N9"!E;F-R
M>7!T+@H@("`@("H@0'!A<F%M(&%R<F%Y("1S:6=N7W!A<F%M<R`@("`@5&AE
M('!A<F%M971E<G,@<F5Q=6ER960@9F]R('-I9VYI;F<N(%-E90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7V5N8W)Y<'13:6=N871U
M<F4H*2X*("`@("`J($!P87)A;2!A<G)A>2`D96YC<GEP=%]P87)A;7,@(%1H
M92!P87)A;65T97)S(')E<75I<F5D(&9O<B!E;F-R>7!T:6]N+@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@4V5E(%]E;F-R>7!T365S
M<V%G92@I+@H@("`@("H*("`@("`J($!R971U<FX@34E-15]087)T("!!($U)
M345?4&%R="!O8FIE8W0@=&AA="!I<R!S:6=N960@86YD(&5N8W)Y<'1E9"X*
M("`@("`J("`@("`@("`@("`@("`@("`@("!2971U<FYS(%!%05)?17)R;W(@
M;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N('-I9VY!;F1%;F-R>7!T
M34E-15!A<G0H)&UI;65?<&%R="P@)'-I9VY?<&%R86US(#T@87)R87DH*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5N8W)Y<'1?
M<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!I;F-L=61E7V]N8V4@
M)TAO<F1E+TU)344O4&%R="YP:'`G.PH*("`@("`@("`D<&%R="`]("1T:&ES
M+3YS:6=N34E-15!A<G0H)&UI;65?<&%R="P@)'-I9VY?<&%R86US*3L*("`@
M("`@("!I9B`H:7-?82@D<&%R="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'!A<G0["B`@("`@("`@?0H@("`@("`@("1P87)T(#T@
M)'1H:7,M/F5N8W)Y<'1-24U%4&%R="@D<&%R="P@)&5N8W)Y<'1?<&%R86US
M*3L*("`@("`@("!I9B`H:7-?82@D<&%R="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'!A<G0["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)'!A<G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T(&$@
M4$5-(&9O<FUA="!C97)T:69I8V%T92!T;R!R96%D86)L92!(5$U,('9E<G-I
M;VX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C97)T("`@4$5-(&9O
M<FUA="!C97)T:69I8V%T90H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!(5$U,(&1E=&%I;&EN9R!T:&4@8V5R=&EF:6-A=&4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-E<G14;TA434PH)&-E<G0I"B`@("!["B`@("`@("`@+RH@
M0V]M;6]N($9I96QD<R`J+PH@("`@("`@("1F:65L9&YA;65S(#T@87)R87DH
M"B`@("`@("`@("`@("=%;6%I;"<@/3X@7R@B16UA:6P@061D<F5S<R(I+`H@
M("`@("`@("`@("`G0V]M;6]N3F%M92<@/3X@7R@B0V]M;6]N($YA;64B*2P*
M("`@("`@("`@("`@)T]R9V%N:7-A=&EO;B<@/3X@7R@B3W)G86YI<V%T:6]N
M(BDL"B`@("`@("`@("`@("=/<F=A;FES871I;VYA;%5N:70G(#T^(%\H(D]R
M9V%N:7-A=&EO;F%L(%5N:70B*2P*("`@("`@("`@("`@)T-O=6YT<GDG(#T^
M(%\H(D-O=6YT<GDB*2P*("`@("`@("`@("`@)U-T871E3W)0<F]V:6YC92<@
M/3X@7R@B4W1A=&4@;W(@4')O=FEN8V4B*2P*("`@("`@("`@("`@)TQO8V%T
M:6]N)R`]/B!?*"),;V-A=&EO;B(I+`H@("`@("`@("`@("`G4W1R965T061D
M<F5S<R<@/3X@7R@B4W1R965T($%D9')E<W,B*2P*("`@("`@("`@("`@)U1E
M;&5P:&]N94YU;6)E<B<@/3X@7R@B5&5L97!H;VYE($YU;6)E<B(I+`H@("`@
M("`@("`@("`G4W5R;F%M92<@/3X@7R@B4W5R;F%M92(I+`H@("`@("`@("`@
M("`G1VEV96Y.86UE)R`]/B!?*")':79E;B!.86UE(BD*("`@("`@("`I.PH*
M("`@("`@("`O*B!.971S8V%P92!%>'1E;G-I;VYS("HO"B`@("`@("`@)&9I
M96QD;F%M97,@*ST@87)R87DH"B`@("`@("`@("`@("=N971S8V%P92UC97)T
M+71Y<&4G(#T^(%\H(DYE='-C87!E(&-E<G1I9FEC871E('1Y<&4B*2P*("`@
M("`@("`@("`@)VYE='-C87!E+6)A<V4M=7)L)R`]/B!?*").971S8V%P92!"
M87-E(%523"(I+`H@("`@("`@("`@("`G;F5T<V-A<&4M<F5V;V-A=&EO;BUU
M<FPG(#T^(%\H(DYE='-C87!E(%)E=F]C871I;VX@55),(BDL"B`@("`@("`@
M("`@("=N971S8V%P92UC82UR979O8V%T:6]N+75R;"<@/3X@7R@B3F5T<V-A
M<&4@0T$@4F5V;V-A=&EO;B!54DPB*2P*("`@("`@("`@("`@)VYE='-C87!E
M+6-E<G0M<F5N97=A;"UU<FPG(#T^(%\H(DYE='-C87!E(%)E;F5W86P@55),
M(BDL"B`@("`@("`@("`@("=N971S8V%P92UC82UP;VQI8WDM=7)L)R`]/B!?
M*").971S8V%P92!#02!P;VQI8WD@55),(BDL"B`@("`@("`@("`@("=N971S
M8V%P92US<VPM<V5R=F5R+6YA;64G(#T^(%\H(DYE='-C87!E(%-33"!S97)V
M97(@;F%M92(I+`H@("`@("`@("`@("`G;F5T<V-A<&4M8V]M;65N="<@/3X@
M7R@B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(I"B`@("`@("`@*3L*
M"B`@("`@("`@+RH@6#4Y,'8S($5X=&5N<VEO;G,@*B\*("`@("`@("`D9FEE
M;&1N86UE<R`K/2!A<G)A>2@*("`@("`@("`@("`@)VED+6-E+65X=$ME>55S
M86=E)R`]/B!?*")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(BDL"B`@("`@
M("`@("`@("=I9"UC92UB87-I8T-O;G-T<F%I;G1S)R`]/B!?*")8-3`Y=C,@
M0F%S:6,@0V]N<W1R86EN=',B*2P*("`@("`@("`@("`@)VED+6-E+7-U8FIE
M8W1!;'1.86UE)R`]/B!?*")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.
M86UE(BDL"B`@("`@("`@("`@("=I9"UC92US=6)J96-T2V5Y261E;G1I9FEE
M<B<@/3X@7R@B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(B*2P*("`@
M("`@("`@("`@)VED+6-E+6-E<G1I9FEC871E4&]L:6-I97,G(#T^(%\H(D-E
M<G1I9FEC871E(%!O;&EC:65S(BDL"B`@("`@("`@("`@("=I9"UC92U#4DQ$
M:7-T<FEB=71I;VY0;VEN=',G(#T^(%\H(D-23"!$:7-T<FEB=71I;VX@4&]I
M;G1S(BDL"B`@("`@("`@("`@("=I9"UC92UK97E5<V%G92<@/3X@7R@B2V5Y
M(%5S86=E(BD*("`@("`@("`I.PH*("`@("`@("`D8V5R=%]D971A:6QS(#T@
M)'1H:7,M/G!A<G-E0V5R="@D8V5R="D["B`@("`@("`@:68@*"%I<U]A<G)A
M>2@D8V5R=%]D971A:6QS*2D@>PH@("`@("`@("`@("!R971U<FX@)SQP<F4@
M8VQA<W,](F9I>&5D(CXG("X@7R@B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF
M:6-A=&4@9&5T86EL<R(I("X@)SPO<')E/B<["B`@("`@("`@?0H@("`@("`@
M("1C97)T:69I8V%T92`]("1C97)T7V1E=&%I;'-;)V-E<G1I9FEC871E)UT[
M"@H@("`@("`@("1T97AT(#T@)SQP<F4@8VQA<W,](F9I>&5D(CXG.PH*("`@
M("`@("`O*B!3=6)J96-T("AA+VLO82!#97)T:69I8V%T92!/=VYE<BD@*B\*
M("`@("`@("!I9B`H:7-S970H)&-E<G1I9FEC871E6R=S=6)J96-T)UTI*2![
M"B`@("`@("`@("`@("1T97AT("X]("(\<W1R;VYG/B(@+B!?*")#97)T:69I
M8V%T92!/=VYE<B(I("X@(CH\+W-T<F]N9SY<;B(["@H@("`@("`@("`@("!F
M;W)E86-H("@D8V5R=&EF:6-A=&5;)W-U8FIE8W0G72!A<R`D:V5Y(#T^("1V
M86QU92D@>PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1F:65L9&YA;65S
M6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@("`@("1T97AT("X]('-P<FEN
M=&8H(B9N8G-P.R9N8G-P.R5S.B`E<UQN(BP@)&9I96QD;F%M97-;)&ME>5TL
M("1V86QU92D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1T97AT("X]('-P<FEN=&8H(B9N8G-P.R9N8G-P.RHE<SH@
M)7-<;B(L("1K97DL("1V86QU92D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)'1E>'0@+CT@(EQN(CL*("`@("`@("!]
M"@H@("`@("`@("\J($ES<W5E<B`J+PH@("`@("`@(&EF("AI<W-E="@D8V5R
M=&EF:6-A=&5;)VES<W5E<B==*2D@>PH@("`@("`@("`@("`D=&5X="`N/2`B
M/'-T<F]N9SXB("X@7R@B27-S=65R(BD@+B`B.CPO<W1R;VYG/EQN(CL*"B`@
M("`@("`@("`@(&9O<F5A8V@@*"1C97)T:69I8V%T95LG:7-S=65R)UT@87,@
M)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M9FEE;&1N86UE<ULD:V5Y72DI('L*("`@("`@("`@("`@("`@("`@("`D=&5X
M="`N/2!S<')I;G1F*"(F;F)S<#LF;F)S<#LE<SH@)7-<;B(L("1F:65L9&YA
M;65S6R1K97E=+"`D=F%L=64I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`D=&5X="`N/2!S<')I;G1F*"(F;F)S<#LF
M;F)S<#LJ)7,Z("5S7&XB+"`D:V5Y+"`D=F%L=64I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1T97AT("X](")<;B([
M"B`@("`@("`@?0H*("`@("`@("`O*B!$871E<R`@*B\*("`@("`@("`D=&5X
M="`N/2`B/'-T<F]N9SXB("X@7R@B5F%L:61I='DB*2`N("(Z/"]S=')O;F<^
M7&XB.PH@("`@("`@("1T97AT("X]('-P<FEN=&8H(B9N8G-P.R9N8G-P.R5S
M.B`E<UQN(BP@7R@B3F]T($)E9F]R92(I+"!S=')F=&EM92@B)7@@)5@B+"`D
M8V5R=&EF:6-A=&5;)W9A;&ED:71Y)UU;)VYO=&)E9F]R92==*2D["B`@("`@
M("`@)'1E>'0@+CT@<W!R:6YT9B@B)FYB<W`[)FYB<W`[)7,Z("5S7&XB+"!?
M*").;W0@069T97(B*2P@<W1R9G1I;64H(B5X("58(BP@)&-E<G1I9FEC871E
M6R=V86QI9&ET>2==6R=N;W1A9G1E<B==*2D["B`@("`@("`@)'1E>'0@+CT@
M(EQN(CL*"B`@("`@("`@+RH@0V5R=&EF:6-A=&4@3W=N97(@+2!0=6)L:6,@
M2V5Y($EN9F\@*B\*("`@("`@("`D=&5X="`N/2`B/'-T<F]N9SXB("X@7R@B
M4'5B;&EC($ME>2!);F9O(BD@+B`B.CPO<W1R;VYG/EQN(CL*("`@("`@("`D
M=&5X="`N/2!S<')I;G1F*"(F;F)S<#LF;F)S<#LE<SH@)7-<;B(L(%\H(E!U
M8FQI8R!+97D@06QG;W)I=&AM(BDL("1C97)T:69I8V%T95LG<W5B:F5C=%!U
M8FQI8TME>4EN9F\G75LG86QG;W)I=&AM)UTI.PH@("`@("`@(&EF("@D8V5R
M=&EF:6-A=&5;)W-U8FIE8W10=6)L:6-+97E);F9O)UU;)V%L9V]R:71H;2==
M(#T]("=R<V%%;F-R>7!T:6]N)RD@>PH@("`@("`@("`@("!I9B`H571I;#HZ
M97AT96YS:6]N17AI<W1S*"=B8VUA=&@G*2D@>PH@("`@("`@("`@("`@("`@
M)&UO9'5L=7,@/2`D8V5R=&EF:6-A=&5;)W-U8FIE8W10=6)L:6-+97E);F9O
M)UU;)W-U8FIE8W10=6)L:6-+97DG75LG;6]D=6QU<R==.PH@("`@("`@("`@
M("`@("`@)&UO9'5L=7-?:&5X(#T@)R<["B`@("`@("`@("`@("`@("!W:&EL
M92`H)&UO9'5L=7,@(3T@)S`G*2!["B`@("`@("`@("`@("`@("`@("`@)&UO
M9'5L=7-?:&5X(#T@9&5C:&5X*&)C;6]D*"1M;V1U;'5S+"`G,38G*2D@+B`D
M;6]D=6QU<U]H97@["B`@("`@("`@("`@("`@("`@("`@)&UO9'5L=7,@/2!B
M8V1I=B@D;6]D=6QU<RP@)S$V)RP@,"D["B`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`@("`@:68@*"AS=')L96XH)&UO9'5L=7-?:&5X*2`^(#8T
M*2`F)@H@("`@("`@("`@("`@("`@("`@("AS=')L96XH)&UO9'5L=7-?:&5X
M*2`\(#$R."DI('L*("`@("`@("`@("`@("`@("`@("!S=')?<&%D*"1M;V1U
M;'5S7VAE>"P@,3(X+"`G,"<L(%-44E]0041?4DE'2%0I.PH@("`@("`@("`@
M("`@("`@?2!E;'-E:68@*"AS=')L96XH)&UO9'5L=7-?:&5X*2`^(#$R."D@
M)B8*("`@("`@("`@("`@("`@("`@("`@("`@("`H<W1R;&5N*"1M;V1U;'5S
M7VAE>"D@/"`R-38I*2!["B`@("`@("`@("`@("`@("`@("`@<W1R7W!A9"@D
M;6]D=6QU<U]H97@L(#(U-BP@)S`G+"!35%)?4$%$7U))1TA4*3L*("`@("`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D=&5X="`N/2`B)FYB<W`[
M)FYB<W`[(B`N('-P<FEN=&8H7R@B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB
M*2P@<W1R;&5N*"1M;V1U;'5S7VAE>"D@*B`T*2`N("(Z7&XB.PH*("`@("`@
M("`@("`@("`@("1M;V1U;'5S7W-T<B`]("<G.PH@("`@("`@("`@("`@("`@
M9F]R("@D:2`](#`[("1I(#P@<W1R;&5N*"1M;V1U;'5S7VAE>"D[("1I("L]
M(#(I('L*("`@("`@("`@("`@("`@("`@("!I9B`H*"1I("4@,S(I(#T](#`I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)&UO9'5L=7-?<W1R("X](")<
M;B9N8G-P.R9N8G-P.R9N8G-P.R9N8G-P.R9N8G-P.R9N8G-P.R(["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1M;V1U;'5S
M7W-T<B`N/2!S=6)S='(H)&UO9'5L=7-?:&5X+"`D:2P@,BD@+B`G.B<["B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)'1E>'0@+CT@<W!R
M:6YT9B@B)FYB<W`[)FYB<W`[)FYB<W`[)FYB<W`[)7,Z("5S7&XB+"!?*")-
M;V1U;'5S(BDL("1M;V1U;'5S7W-T<BD["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("1T97AT("X]('-P<FEN=&8H(B9N8G-P.R9N8G-P.R9N8G-P.R9N
M8G-P.R5S.B`E<UQN(BP@7R@B17AP;VYE;G0B*2P@)&-E<G1I9FEC871E6R=S
M=6)J96-T4'5B;&EC2V5Y26YF;R==6R=S=6)J96-T4'5B;&EC2V5Y)UU;)W!U
M8FQI8T5X<&]N96YT)UTI.PH@("`@("`@('T*("`@("`@("`D=&5X="`N/2`B
M7&XB.PH*("`@("`@("`O*B!8-3`Y=C,@97AT96YS:6]N<R`J+PH@("`@("`@
M(&EF("AI<W-E="@D8V5R=&EF:6-A=&5;)V5X=&5N<VEO;G,G72DI('L*("`@
M("`@("`@("`@)'1E>'0@+CT@(CQS=')O;F<^(B`N(%\H(E@U,#EV,R!E>'1E
M;G-I;VYS(BD@+B`B.CPO<W1R;VYG/EQN(CL*"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1C97)T:69I8V%T95LG97AT96YS:6]N<R==(&%S("1K97D@/3X@)'9A
M;'5E*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)'9A;'5E*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1V86QU92`](%\H(E5N<W5P<&]R=&5D
M($5X=&5N<VEO;B(I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1F:65L9&YA;65S6R1K97E=*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1T97AT("X]('-P<FEN=&8H(B9N8G-P.R9N8G-P.R5S.EQN
M)FYB<W`[)FYB<W`[)FYB<W`[)FYB<W`[)7-<;B(L("1F:65L9&YA;65S6R1K
M97E=+"!W;W)D=W)A<"@D=F%L=64L(#0P+"`B7&XF;F)S<#LF;F)S<#LF;F)S
M<#LF;F)S<#LB*2D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("1T97AT("X]('-P<FEN=&8H(B9N8G-P.R9N8G-P.R5S
M.EQN)FYB<W`[)FYB<W`[)FYB<W`[)FYB<W`[)7-<;B(L("1K97DL('=O<F1W
M<F%P*"1V86QU92P@-C`L(")<;B9N8G-P.R9N8G-P.R9N8G-P.R9N8G-P.R(I
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@)'1E>'0@+CT@(EQN(CL*("`@("`@("!]"@H@("`@("`@("\J($-E<G1I
M9FEC871E($1E=&%I;',@*B\*("`@("`@("`D=&5X="`N/2`B/'-T<F]N9SXB
M("X@7R@B0V5R=&EF:6-A=&4@1&5T86EL<R(I("X@(CH\+W-T<F]N9SY<;B([
M"B`@("`@("`@)'1E>'0@+CT@<W!R:6YT9B@B)FYB<W`[)FYB<W`[)7,Z("5D
M7&XB+"!?*")697)S:6]N(BDL("1C97)T:69I8V%T95LG=F5R<VEO;B==*3L*
M("`@("`@("`D=&5X="`N/2!S<')I;G1F*"(F;F)S<#LF;F)S<#LE<SH@)61<
M;B(L(%\H(E-E<FEA;"!.=6UB97(B*2P@)&-E<G1I9FEC871E6R=S97)I86Q.
M=6UB97(G72D["@H@("`@("`@(&9O<F5A8V@@*"1C97)T7V1E=&%I;'-;)V9I
M;F=E<G!R:6YT<R==(&%S("1H87-H(#T^("1F:6YG97)P<FEN="D@>PH@("`@
M("`@("`@("`D;&%B96P@/2!S<')I;G1F*%\H(B5S($9I;F=E<G!R:6YT(BDL
M(%-T<FEN9SHZ=7!P97(H)&AA<V@I*3L*("`@("`@("`@("`@)&9I;F=E<G!R
M:6YT7W-T<B`]("<G.PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S
M=')L96XH)&9I;F=E<G!R:6YT*3L@)&D@*ST@,BD@>PH@("`@("`@("`@("`@
M("`@)&9I;F=E<G!R:6YT7W-T<B`N/2!S=6)S='(H)&9I;F=E<G!R:6YT+"`D
M:2P@,BD@+B`G.B<["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1E>'0@
M+CT@<W!R:6YT9B@B)FYB<W`[)FYB<W`[)7,Z7&XF;F)S<#LF;F)S<#LF;F)S
M<#LF;F)S<#LF;F)S<#LF;F)S<#LE<UQN(BP@)&QA8F5L+"`D9FEN9V5R<')I
M;G1?<W1R*3L*("`@("`@("!]"B`@("`@("`@)'1E>'0@+CT@<W!R:6YT9B@B
M)FYB<W`[)FYB<W`[)7,Z("5S7&XB+"!?*")3:6=N871U<F4@06QG;W)I=&AM
M(BDL("1C97)T7V1E=&%I;'-;)W-I9VYA='5R94%L9V]R:71H;2==*3L*("`@
M("`@("`D=&5X="`N/2!S<')I;G1F*"(F;F)S<#LF;F)S<#LE<SHB+"!?*")3
M:6=N871U<F4B*2D["@H@("`@("`@("1S:6=?<W1R(#T@)R<["B`@("`@("`@
M9F]R("@D:2`](#`[("1I(#P@<W1R;&5N*"1C97)T7V1E=&%I;'-;)W-I9VYA
M='5R92==*3L@)&DK*RD@>PH@("`@("`@("`@("!I9B`H*"1I("4@,38I(#T]
M(#`I('L*("`@("`@("`@("`@("`@("1S:6=?<W1R("X](")<;B9N8G-P.R9N
M8G-P.R9N8G-P.R9N8G-P.R9N8G-P.R9N8G-P.R(["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)'-I9U]S='(@+CT@<W!R:6YT9B@B)3`R>#HB+"!O<F0H
M)&-E<G1?9&5T86EL<ULG<VEG;F%T=7)E)UU;)&E=*2D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)'1E>'0@+B`D<VEG7W-T<B`N(")<;CPO<')E/B([
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>'1R86-T('1H92!C;VYT96YT<R!O
M9B!A(%!%32!F;W)M870@8V5R=&EF:6-A=&4@=&\@86X@87)R87DN"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V5R="`@4$5-(&9O<FUA="!C97)T
M:69I8V%T90H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%R<F%Y(&-O
M;G1A:6YI;F<@86QL(&5X=')A8W1A8FQE(&EN9F]R;6%T:6]N(&%B;W5T"B`@
M("`@*B`@("`@("`@("`@("`@("!T:&4@8V5R=&EF:6-A=&4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('!A<G-E0V5R="@D8V5R="D*("`@('L*("`@("`@("`D
M8V5R=%]S<&QI="`]('!R96=?<W!L:70H)R\H+2TM+2TH*$)%1TE.*7PH14Y$
M*2D@0T525$E&24-!5$4M+2TM+2DO)RP@)&-E<G0I.PH@("`@("`@(&EF("@A
M:7-S970H)&-E<G1?<W!L:71;,5TI*2!["B`@("`@("`@("`@("1R87=?8V5R
M="`](&)A<V4V-%]D96-O9&4H)&-E<G0I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1R87=?8V5R="`](&)A<V4V-%]D96-O9&4H)&-E<G1?<W!L
M:71;,5TI.PH@("`@("`@('T*"B`@("`@("`@)&-E<G1?9&%T82`]("1T:&ES
M+3Y?<&%R<V5!4TXH)')A=U]C97)T*3L*("`@("`@("!I9B`H(6ES7V%R<F%Y
M*"1C97)T7V1A=&$I('Q\("@D8V5R=%]D871A6S!=(#T]("=53DM.3U=.)RDI
M('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@
M("`@)&-E<G1?9&5T86EL<R`](&%R<F%Y*"D["B`@("`@("`@)&-E<G1?9&5T
M86EL<ULG9FEN9V5R<')I;G1S)UU;)VUD-2==(#T@;60U*"1R87=?8V5R="D[
M"B`@("`@("`@:68@*%5T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G;6AA<V@G*2D@
M>PH@("`@("`@("`@("`D8V5R=%]D971A:6QS6R=F:6YG97)P<FEN=',G75LG
M<VAA,2==(#T@8FEN,FAE>"AM:&%S:"A-2$%32%]32$$Q+"`D<F%W7V-E<G0I
M*3L*("`@("`@("!]"@H@("`@("`@("1C97)T7V1E=&%I;'-;)V-E<G1I9FEC
M871E)UU;)V5X=&5N<VEO;G,G72`](&%R<F%Y*"D["B`@("`@("`@)&-E<G1?
M9&5T86EL<ULG8V5R=&EF:6-A=&4G75LG=F5R<VEO;B==(#T@)&-E<G1?9&%T
M85LQ75LP75LQ75LP75LQ72`K(#$["B`@("`@("`@)&-E<G1?9&5T86EL<ULG
M8V5R=&EF:6-A=&4G75LG<V5R:6%L3G5M8F5R)UT@/2`D8V5R=%]D871A6S%=
M6S!=6S%=6S%=6S%=.PH@("`@("`@("1C97)T7V1E=&%I;'-;)V-E<G1I9FEC
M871E)UU;)W-I9VYA='5R92==(#T@)&-E<G1?9&%T85LQ75LP75LQ75LR75LQ
M75LP75LQ73L*("`@("`@("`D8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==
M6R=I<W-U97(G72`]("1C97)T7V1A=&%;,5U;,%U;,5U;,UU;,5T["B`@("`@
M("`@)&-E<G1?9&5T86EL<ULG8V5R=&EF:6-A=&4G75LG=F%L:61I='DG72`]
M("1C97)T7V1A=&%;,5U;,%U;,5U;-%U;,5T["B`@("`@("`@)&-E<G1?9&5T
M86EL<ULG8V5R=&EF:6-A=&4G75LG<W5B:F5C="==(#T@0"1C97)T7V1A=&%;
M,5U;,%U;,5U;-5U;,5T["B`@("`@("`@)&-E<G1?9&5T86EL<ULG8V5R=&EF
M:6-A=&4G75LG<W5B:F5C=%!U8FQI8TME>4EN9F\G72`]("1C97)T7V1A=&%;
M,5U;,%U;,5U;-EU;,5T["@H@("`@("`@("1C97)T7V1E=&%I;'-;)W-I9VYA
M='5R94%L9V]R:71H;2==(#T@)&-E<G1?9&%T85LQ75LQ75LQ75LP75LQ73L*
M("`@("`@("`D8V5R=%]D971A:6QS6R=S:6=N871U<F4G72`]("1C97)T7V1A
M=&%;,5U;,EU;,5T["@H@("`@("`@("\O(&ES<W5E<@H@("`@("`@("1I<W-U
M97(@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1C97)T7V1E=&%I;'-;
M)V-E<G1I9FEC871E)UU;)VES<W5E<B==(&%S("1V86QU92D@>PH@("`@("`@
M("`@("`D:7-S=65R6R1V86QU95LQ75LQ75LP75LQ75T@/2`D=F%L=65;,5U;
M,5U;,5U;,5T["B`@("`@("`@?0H@("`@("`@("1C97)T7V1E=&%I;'-;)V-E
M<G1I9FEC871E)UU;)VES<W5E<B==(#T@)&ES<W5E<CL*"B`@("`@("`@+R\@
M<W5B:F5C=`H@("`@("`@("1S=6)J96-T(#T@87)R87DH*3L*("`@("`@("!F
M;W)E86-H("@D8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==6R=S=6)J96-T
M)UT@87,@)'9A;'5E*2!["B`@("`@("`@("`@("1S=6)J96-T6R1V86QU95LQ
M75LQ75LP75LQ75T@/2`D=F%L=65;,5U;,5U;,5U;,5T["B`@("`@("`@?0H@
M("`@("`@("1C97)T7V1E=&%I;'-;)V-E<G1I9FEC871E)UU;)W-U8FIE8W0G
M72`]("1S=6)J96-T.PH*("`@("`@("`O+R!V86QI9&ET>0H@("`@("`@("1V
M86QS(#T@)&-E<G1?9&5T86EL<ULG8V5R=&EF:6-A=&4G75LG=F%L:61I='DG
M73L*("`@("`@("`D8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==6R=V86QI
M9&ET>2==(#T@87)R87DH*3L*("`@("`@("`D8V5R=%]D971A:6QS6R=C97)T
M:69I8V%T92==6R=V86QI9&ET>2==6R=N;W1B969O<F4G72`]("1V86QS6S!=
M6S%=.PH@("`@("`@("1C97)T7V1E=&%I;'-;)V-E<G1I9FEC871E)UU;)W9A
M;&ED:71Y)UU;)VYO=&%F=&5R)UT@/2`D=F%L<ULQ75LQ73L*("`@("`@("!F
M;W)E86-H("@D8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==6R=V86QI9&ET
M>2==(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`D>65A<B`]('-U
M8G-T<B@D=F%L+"`P+"`R*3L*("`@("`@("`@("`@)&UO;G1H(#T@<W5B<W1R
M*"1V86PL(#(L(#(I.PH@("`@("`@("`@("`D9&%Y(#T@<W5B<W1R*"1V86PL
M(#0L(#(I.PH@("`@("`@("`@("`D:&]U<B`]('-U8G-T<B@D=F%L+"`V+"`R
M*3L*("`@("`@("`@("`@)&UI;G5T92`]('-U8G-T<B@D=F%L+"`X+"`R*3L*
M("`@("`@("`@("`@:68@*"@D=F%L6S$Q72`]/2`G+2<I('Q\("@D=F%L6SE=
M(#T]("<K)RDI('L*("`@("`@("`@("`@("`@("\O(&AA;F1L92!T:6UE('IO
M;F4@;V9F<V5T(&AE<F4*("`@("`@("`@("`@("`@("1S96-O;F1S(#T@,#L*
M("`@("`@("`@("`@?2!E;'-E:68@*%-T<FEN9SHZ=7!P97(H)'9A;%LQ,5TI
M(#T]("=:)RD@>PH@("`@("`@("`@("`@("`@)'-E8V]N9',@/2`P.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'-E8V]N9',@/2!S
M=6)S='(H)'9A;"P@,3`L(#(I.PH@("`@("`@("`@("`@("`@:68@*"@D=F%L
M6S$Q72`]/2`G+2<I('Q\("@D=F%L6SE=(#T]("<K)RDI('L*("`@("`@("`@
M("`@("`@("`@("`O+R!H86YD;&4@=&EM92!Z;VYE(&]F9G-E="!H97)E"B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&-E
M<G1?9&5T86EL<ULG8V5R=&EF:6-A=&4G75LG=F%L:61I='DG75LD:V5Y72`]
M(&UK=&EM92`H)&AO=7(L("1M:6YU=&4L("1S96-O;F1S+"`D;6]N=&@L("1D
M87DL("1Y96%R*3L*("`@("`@("!]"@H@("`@("`@("\O(%-P;&ET('1H92!0
M=6)L:6,@2V5Y(&EN=&\@8V]M<&]N96YT<RX*("`@("`@("`D<W5B:F5C=%!U
M8FQI8TME>4EN9F\@/2!A<G)A>2@I.PH@("`@("`@("1S=6)J96-T4'5B;&EC
M2V5Y26YF;ULG86QG;W)I=&AM)UT@/2`D8V5R=%]D971A:6QS6R=C97)T:69I
M8V%T92==6R=S=6)J96-T4'5B;&EC2V5Y26YF;R==6S!=6S%=6S!=6S%=.PH@
M("`@("`@(&EF("@D<W5B:F5C=%!U8FQI8TME>4EN9F];)V%L9V]R:71H;2==
M(#T]("=R<V%%;F-R>7!T:6]N)RD@>PH@("`@("`@("`@("`D<W5B:F5C=%!U
M8FQI8TME>2`]("1T:&ES+3Y?<&%R<V5!4TXH)&-E<G1?9&5T86EL<ULG8V5R
M=&EF:6-A=&4G75LG<W5B:F5C=%!U8FQI8TME>4EN9F\G75LQ75LQ72D["B`@
M("`@("`@("`@("1S=6)J96-T4'5B;&EC2V5Y26YF;ULG<W5B:F5C=%!U8FQI
M8TME>2==6R=M;V1U;'5S)UT@/2`D<W5B:F5C=%!U8FQI8TME>5LQ75LP75LQ
M73L*("`@("`@("`@("`@)'-U8FIE8W10=6)L:6-+97E);F9O6R=S=6)J96-T
M4'5B;&EC2V5Y)UU;)W!U8FQI8T5X<&]N96YT)UT@/2`D<W5B:F5C=%!U8FQI
M8TME>5LQ75LQ75LQ73L*("`@("`@("!]"B`@("`@("`@)&-E<G1?9&5T86EL
M<ULG8V5R=&EF:6-A=&4G75LG<W5B:F5C=%!U8FQI8TME>4EN9F\G72`]("1S
M=6)J96-T4'5B;&EC2V5Y26YF;SL*"B`@("`@("`@:68@*&ES<V5T*"1C97)T
M7V1A=&%;,5U;,%U;,5U;-UTI("8F"B`@("`@("`@("`@(&ES7V%R<F%Y*"1C
M97)T7V1A=&%;,5U;,%U;,5U;-UU;,5TI*2!["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1C97)T7V1A=&%;,5U;,%U;,5U;-UU;,5T@87,@)&5X="D@>PH@("`@
M("`@("`@("`@("`@)&]I9"`]("1E>'1;,5U;,%U;,5T["B`@("`@("`@("`@
M("`@("`D8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==6R=E>'1E;G-I;VYS
M)UU;)&]I9%T@/2`D97AT6S%=6S%=.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("`D:2`](#D["B`@("`@("`@=VAI;&4@*&ES<V5T*"1C97)T
M7V1A=&%;,5U;,%U;,5U;)&E=*2D@>PH@("`@("`@("`@("`D;VED(#T@)&-E
M<G1?9&%T85LQ75LP75LQ75LD:5U;,5U;,%U;,5T["B`@("`@("`@("`@("1C
M97)T7V1E=&%I;'-;)V-E<G1I9FEC871E)UU;)V5X=&5N<VEO;G,G75LD;VED
M72`]("1C97)T7V1A=&%;,5U;,%U;,5U;)&E=6S%=6S%=.PH@("`@("`@("`@
M("`D:2LK.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)&-E<G1?9&5T
M86EL<ULG8V5R=&EF:6-A=&4G75LG97AT96YS:6]N<R==(&%S("1O:60@/3X@
M)'9A;"D@>PH@("`@("`@("`@("!S=VET8V@@*"1O:60I('L*("`@("`@("`@
M("`@8V%S92`G;F5T<V-A<&4M8F%S92UU<FPG.@H@("`@("`@("`@("!C87-E
M("=N971S8V%P92UR979O8V%T:6]N+75R;"<Z"B`@("`@("`@("`@(&-A<V4@
M)VYE='-C87!E+6-A+7)E=F]C871I;VXM=7)L)SH*("`@("`@("`@("`@8V%S
M92`G;F5T<V-A<&4M8V5R="UR96YE=V%L+75R;"<Z"B`@("`@("`@("`@(&-A
M<V4@)VYE='-C87!E+6-A+7!O;&EC>2UU<FPG.@H@("`@("`@("`@("!C87-E
M("=N971S8V%P92US<VPM<V5R=F5R+6YA;64G.@H@("`@("`@("`@("!C87-E
M("=N971S8V%P92UC;VUM96YT)SH*("`@("`@("`@("`@("`@("1V86P@/2`D
M=&AI<RT^7W!A<G-E05-.*"1V86Q;,5TI.PH@("`@("`@("`@("`@("`@)&-E
M<G1?9&5T86EL<ULG8V5R=&EF:6-A=&4G75LG97AT96YS:6]N<R==6R1O:61=
M(#T@)'9A;%LQ73L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@8V%S92`G:60M8V4M<W5B:F5C=$%L=$YA;64G.@H@("`@("`@("`@("`@
M("`@)'9A;"`]("1T:&ES+3Y?<&%R<V5!4TXH)'9A;%LQ72D["B`@("`@("`@
M("`@("`@("`D8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==6R=E>'1E;G-I
M;VYS)UU;)&]I9%T@/2`G)SL*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1V
M86Q;,5T@87,@)&YA;64I('L*("`@("`@("`@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1C97)T7V1E=&%I;'-;)V-E<G1I9FEC871E)UU;)V5X=&5N<VEO;G,G
M75LD;VED72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&-E<G1?9&5T
M86EL<ULG8V5R=&EF:6-A=&4G75LG97AT96YS:6]N<R==6R1O:61=("X]("<L
M("<["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M("1C97)T7V1E=&%I;'-;)V-E<G1I9FEC871E)UU;)V5X=&5N<VEO;G,G75LD
M;VED72`N/2`D;F%M95LQ73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G;F5T<V-A<&4M8V5R
M="UT>7!E)SH*("`@("`@("`@("`@("`@("1V86P@/2`D=&AI<RT^7W!A<G-E
M05-.*"1V86Q;,5TI.PH@("`@("`@("`@("`@("`@)'9A;"`](&]R9"@D=F%L
M6S%=*3L*("`@("`@("`@("`@("`@("1N97=686P@/2`G)SL*"B`@("`@("`@
M("`@("`@("!I9B`H)'9A;"`F(#!X.#`I('L*("`@("`@("`@("`@("`@("`@
M("`D;F5W5F%L("X](&5M<'1Y*"1N97=686PI(#\@)U-33"!C;&EE;G0G(#H@
M)RP@4U-,(&-L:65N="<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!I9B`H)'9A;"`F(#!X-#`I('L*("`@("`@("`@("`@("`@("`@("`D
M;F5W5F%L("X](&5M<'1Y*"1N97=686PI(#\@)U-33"!S97)V97(G(#H@)RP@
M4U-,('-E<G9E<B<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!I9B`H)'9A;"`F(#!X,C`I('L*("`@("`@("`@("`@("`@("`@("`D;F5W
M5F%L("X](&5M<'1Y*"1N97=686PI(#\@)U,O34E-12<@.B`G+"!3+TU)344G
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"1V86P@
M)B`P>#$P*2!["B`@("`@("`@("`@("`@("`@("`@)&YE=U9A;"`N/2!E;7!T
M>2@D;F5W5F%L*2`_("=/8FIE8W0@4VEG;FEN9R<@.B`G+"!/8FIE8W0@4VEG
M;FEN9R<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H
M)'9A;"`F(#!X,#0I('L*("`@("`@("`@("`@("`@("`@("`D;F5W5F%L("X]
M(&5M<'1Y*"1N97=686PI(#\@)U-33"!#02<@.B`G+"!34TP@0T$G.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"1V86P@)B`P>#`R
M*2!["B`@("`@("`@("`@("`@("`@("`@)&YE=U9A;"`N/2!E;7!T>2@D;F5W
M5F%L*2`_("=3+TU)344@0T$G(#H@)RP@4R]-24U%($-!)SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@D=F%L("8@,'@P,2D@>PH@
M("`@("`@("`@("`@("`@("`@("1N97=686P@+CT@96UP='DH)&YE=U9A;"D@
M/R`G3V)J96-T(%-I9VYI;F<@0T$G(#H@)RP@3V)J96-T(%-I9VYI;F<@0T$G
M.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1C97)T7V1E
M=&%I;'-;)V-E<G1I9FEC871E)UU;)V5X=&5N<VEO;G,G75LD;VED72`]("1N
M97=686P["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A
M<V4@)VED+6-E+65X=$ME>55S86=E)SH*("`@("`@("`@("`@("`@("1V86P@
M/2`D=&AI<RT^7W!A<G-E05-.*"1V86Q;,5TI.PH@("`@("`@("`@("`@("`@
M)'9A;"`]("1V86Q;,5T["@H@("`@("`@("`@("`@("`@)&YE=U9A;"`]("<G
M.PH@("`@("`@("`@("`@("`@:68@*"1V86Q;,%U;,5T@(3T@)W-E<75E;F-E
M)RD@>PH@("`@("`@("`@("`@("`@("`@("1V86P@/2!A<G)A>2@D=F%L*3L*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M)'9A;"`]("1V86Q;,5U;,5T["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!F;W)E86-H("@D=F%L(&%S("1U<V%G92D@>PH@("`@("`@("`@
M("`@("`@("`@(&EF("@D=7-A9V5;,5T@/3T@)VED7VMP7V-L:65N=$%U=&@G
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1N97=686P@+CT@96UP='DH
M)&YE=U9A;"D@/R`G5$Q3(%=E8B!#;&EE;G0@075T:&5N=&EC871I;VXG(#H@
M)RP@5$Q3(%=E8B!#;&EE;G0@075T:&5N=&EC871I;VXG.PH@("`@("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1N
M97=686P@+CT@96UP='DH)&YE=U9A;"D@/R`D=7-A9V5;,5T@.B`G+"`G("X@
M)'5S86=E6S%=.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("1C97)T7V1E=&%I;'-;)V-E<G1I9FEC
M871E)UU;)V5X=&5N<VEO;G,G75LD;VED72`]("1N97=686P["B`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)VED+6-E+7-U8FIE
M8W1+97E)9&5N=&EF:65R)SH*("`@("`@("`@("`@("`@("1V86P@/2`D=&AI
M<RT^7W!A<G-E05-.*"1V86Q;,5TI.PH@("`@("`@("`@("`@("`@)'9A;"`]
M("1V86Q;,5T["@H@("`@("`@("`@("`@("`@)&YE=U9A;"`]("<G.PH*("`@
M("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-T<FQE;B@D=F%L*3L@
M)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("1N97=686P@+CT@<W!R:6YT
M9B@B)3`R>#HB+"!O<F0H)'9A;%LD:5TI*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("1C97)T7V1E=&%I;'-;)V-E<G1I9FEC871E)UU;
M)V5X=&5N<VEO;G,G75LD;VED72`]("1N97=686P["B`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)VED+6-E+6%U=&AO<FET>4ME
M>4ED96YT:69I97(G.@H@("`@("`@("`@("`@("`@)'9A;"`]("1T:&ES+3Y?
M<&%R<V5!4TXH)'9A;%LQ72D["B`@("`@("`@("`@("`@("!I9B`H)'9A;%LP
M72`]/2`G<W1R:6YG)RD@>PH@("`@("`@("`@("`@("`@("`@("1V86P@/2`D
M=F%L6S%=.PH*("`@("`@("`@("`@("`@("`@("`D;F5W5F%L(#T@)R<["B`@
M("`@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<W1R;&5N*"1V
M86PI.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1N97=686P@
M+CT@<W!R:6YT9B@B)3`R>#HB+"!O<F0H)'9A;%LD:5TI*3L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&-E<G1?9&5T86EL
M<ULG8V5R=&EF:6-A=&4G75LG97AT96YS:6]N<R==6R1O:61=(#T@)&YE=U9A
M;#L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@)&-E<G1?9&5T86EL<ULG8V5R=&EF:6-A=&4G75LG97AT96YS:6]N<R==
M6R1O:61=(#T@7R@B56YS=7!P;W)T960@17AT96YS:6]N(BD["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M(&-A<V4@)VED+6-E+6)A<VEC0V]N<W1R86EN=',G.@H@("`@("`@("`@("!C
M87-E("=D969A=6QT)SH*("`@("`@("`@("`@("`@("1C97)T7V1E=&%I;'-;
M)V-E<G1I9FEC871E)UU;)V5X=&5N<VEO;G,G75LD;VED72`](%\H(E5N<W5P
M<&]R=&5D($5X=&5N<VEO;B(I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D8V5R=%]D
M971A:6QS.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP="!T;R!P87)S
M92!!4TXN,2!F;W)M871E9"!D871A+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1A=&$@($%3
M3BXQ(&9O<FUA=&5D(&1A=&$*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!!<G)A>2!C;VYT86EN960@=&AE(&5X=')A8W1E9"!V86QU97,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]P87)S94%33B@D9&%T82D*("`@('L*("`@("`@
M("`D<F5S=6QT(#T@87)R87DH*3L*"B`@("`@("`@=VAI;&4@*'-T<FQE;B@D
M9&%T82D@/B`Q*2!["B`@("`@("`@("`@("1C;&%S<R`](&]R9"@D9&%T85LP
M72D["B`@("`@("`@("`@('-W:71C:"`H)&-L87-S*2!["B`@("`@("`@("`@
M(&-A<V4@,'@S,#H*("`@("`@("`@("`@("`@("\O(%-E<75E;F-E"B`@("`@
M("`@("`@("`@("`D;&5N(#T@;W)D*"1D871A6S%=*3L*("`@("`@("`@("`@
M("`@("1B>71E<R`](#`["B`@("`@("`@("`@("`@("!I9B`H)&QE;B`F(#!X
M.#`I('L*("`@("`@("`@("`@("`@("`@("`D8GET97,@/2`D;&5N("8@,'@P
M9CL*("`@("`@("`@("`@("`@("`@("`D;&5N(#T@,#L*("`@("`@("`@("`@
M("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D8GET97,[("1I*RLI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&QE;B`]("@D;&5N(#P\(#@I('P@;W)D
M*"1D871A6R1I("L@,ETI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1S97%U96YC95]D871A(#T@
M<W5B<W1R*"1D871A+"`R("L@)&)Y=&5S+"`D;&5N*3L*("`@("`@("`@("`@
M("`@("1D871A(#T@<W5B<W1R*"1D871A+"`R("L@)&)Y=&5S("L@)&QE;BD[
M"@H@("`@("`@("`@("`@("`@)'9A;'5E<R`]("1T:&ES+3Y?<&%R<V5!4TXH
M)'-E<75E;F-E7V1A=&$I.PH@("`@("`@("`@("`@("`@:68@*"%I<U]A<G)A
M>2@D=F%L=65S*2!\?"!I<U]S=')I;F<H)'9A;'5E<ULP72DI('L*("`@("`@
M("`@("`@("`@("`@("`D=F%L=65S(#T@87)R87DH)'9A;'5E<RD["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<V5Q=65N8V5?=F%L=65S
M(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("1I(#T@,#L*("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1V86QU97,@87,@)'9A;"D@>PH@("`@("`@("`@
M("`@("`@("`@(&EF("@D=F%L6S!=(#T]("=E>'1E;G-I;VXG*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1S97%U96YC95]V86QU97-;)V5X=&5N<VEO
M;G,G75M=(#T@)'9A;#L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D<V5Q=65N8V5?=F%L=65S6R1I*RM=
M(#T@)'9A;#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`D<F5S=6QT6UT@/2!A<G)A>2@G<V5Q=65N
M8V4G+"`D<V5Q=65N8V5?=F%L=65S*3L*("`@("`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("`@("`@8V%S92`P>#,Q.@H@("`@("`@("`@("`@("`@+R\@
M4V5T(&]F"B`@("`@("`@("`@("`@("`D;&5N(#T@;W)D*"1D871A6S%=*3L*
M("`@("`@("`@("`@("`@("1B>71E<R`](#`["B`@("`@("`@("`@("`@("!I
M9B`H)&QE;B`F(#!X.#`I('L*("`@("`@("`@("`@("`@("`@("`D8GET97,@
M/2`D;&5N("8@,'@P9CL*("`@("`@("`@("`@("`@("`@("`D;&5N(#T@,#L*
M("`@("`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D8GET97,[
M("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&QE;B`]("@D;&5N
M(#P\(#@I('P@;W)D*"1D871A6R1I("L@,ETI.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1S97%U
M96YC95]D871A(#T@<W5B<W1R*"1D871A+"`R("L@)&)Y=&5S+"`D;&5N*3L*
M("`@("`@("`@("`@("`@("1D871A(#T@<W5B<W1R*"1D871A+"`R("L@)&)Y
M=&5S("L@)&QE;BD["B`@("`@("`@("`@("`@("`D<F5S=6QT6UT@/2!A<G)A
M>2@G<V5T)RP@)'1H:7,M/E]P87)S94%33B@D<V5Q=65N8V5?9&%T82DI.PH@
M("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#!X,#$Z
M"B`@("`@("`@("`@("`@("`O+R!";V]L96%N('1Y<&4*("`@("`@("`@("`@
M("`@("1B;V]L96%N7W9A;'5E(#T@*&]R9"@D9&%T85LR72D@/3T@,'AF9BD[
M"B`@("`@("`@("`@("`@("`D9&%T82`]('-U8G-T<B@D9&%T82P@,RD["B`@
M("`@("`@("`@("`@("`D<F5S=6QT6UT@/2!A<G)A>2@G8F]O;&5A;B<L("1B
M;V]L96%N7W9A;'5E*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@8V%S92`P>#`R.@H@("`@("`@("`@("`@("`@+R\@26YT96=E<B!T
M>7!E"B`@("`@("`@("`@("`@("`D;&5N(#T@;W)D*"1D871A6S%=*3L*("`@
M("`@("`@("`@("`@("1B>71E<R`](#`["B`@("`@("`@("`@("`@("!I9B`H
M)&QE;B`F(#!X.#`I('L*("`@("`@("`@("`@("`@("`@("`D8GET97,@/2`D
M;&5N("8@,'@P9CL*("`@("`@("`@("`@("`@("`@("`D;&5N(#T@,#L*("`@
M("`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D8GET97,[("1I
M*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&QE;B`]("@D;&5N(#P\
M(#@I('P@;W)D*"1D871A6R1I("L@,ETI.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D:6YT96=E
M<E]D871A(#T@<W5B<W1R*"1D871A+"`R("L@)&)Y=&5S+"`D;&5N*3L*("`@
M("`@("`@("`@("`@("1D871A(#T@<W5B<W1R*"1D871A+"`R("L@)&)Y=&5S
M("L@)&QE;BD["@H@("`@("`@("`@("`@("`@)'9A;'5E(#T@,#L*("`@("`@
M("`@("`@("`@(&EF("@D;&5N(#P](#0I('L*("`@("`@("`@("`@("`@("`@
M("`O*B!-971H;V0@=V]R:W,@9FEN92!F;W(@<VUA;&P@:6YT96=E<G,@*B\*
M("`@("`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S=')L96XH
M)&EN=&5G97)?9&%T82D[("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)'9A;'5E(#T@*"1V86QU92`\/"`X*2!\(&]R9"@D:6YT96=E<E]D871A
M6R1I72D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`O*B!-971H;V0@=V]R:W,@
M9F]R(&%R8FET<F%R>2!L96YG=&@@:6YT96=E<G,@*B\*("`@("`@("`@("`@
M("`@("`@("!I9B`H571I;#HZ97AT96YS:6]N17AI<W1S*"=B8VUA=&@G*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S
M=')L96XH)&EN=&5G97)?9&%T82D[("1I*RLI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1V86QU92`](&)C861D*&)C;75L*"1V86QU92P@,C4V
M*2P@;W)D*"1I;G1E9V5R7V1A=&%;)&E=*2D["B`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D=F%L=64@/2`M,3L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<F5S
M=6QT6UT@/2!A<G)A>2@G:6YT96=E<B@G("X@)&QE;B`N("<I)RP@)'9A;'5E
M*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`P
M>#`S.@H@("`@("`@("`@("`@("`@+R\@0FET<W1R:6YG('1Y<&4*("`@("`@
M("`@("`@("`@("1L96X@/2!O<F0H)&1A=&%;,5TI.PH@("`@("`@("`@("`@
M("`@)&)Y=&5S(#T@,#L*("`@("`@("`@("`@("`@(&EF("@D;&5N("8@,'@X
M,"D@>PH@("`@("`@("`@("`@("`@("`@("1B>71E<R`]("1L96X@)B`P>#!F
M.PH@("`@("`@("`@("`@("`@("`@("1L96X@/2`P.PH@("`@("`@("`@("`@
M("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1B>71E<SL@)&DK*RD@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D;&5N(#T@*"1L96X@/#P@."D@?"!O<F0H
M)&1A=&%;)&D@*R`R72D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&)I='-T<FEN9U]D871A(#T@
M<W5B<W1R*"1D871A+"`S("L@)&)Y=&5S+"`D;&5N*3L*("`@("`@("`@("`@
M("`@("1D871A(#T@<W5B<W1R*"1D871A+"`R("L@)&)Y=&5S("L@)&QE;BD[
M"B`@("`@("`@("`@("`@("`D<F5S=6QT6UT@/2!A<G)A>2@G8FET('-T<FEN
M9R<L("1B:71S=')I;F=?9&%T82D["B`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@(&-A<V4@,'@P-#H*("`@("`@("`@("`@("`@("\O($]C
M=&5T<W1R:6YG('1Y<&4*("`@("`@("`@("`@("`@("1L96X@/2!O<F0H)&1A
M=&%;,5TI.PH@("`@("`@("`@("`@("`@)&)Y=&5S(#T@,#L*("`@("`@("`@
M("`@("`@(&EF("@D;&5N("8@,'@X,"D@>PH@("`@("`@("`@("`@("`@("`@
M("1B>71E<R`]("1L96X@)B`P>#!F.PH@("`@("`@("`@("`@("`@("`@("1L
M96X@/2`P.PH@("`@("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M("1B>71E<SL@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;&5N
M(#T@*"1L96X@/#P@."D@?"!O<F0H)&1A=&%;)&D@*R`R72D["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@)&]C=&5C='-T<FEN9U]D871A(#T@<W5B<W1R*"1D871A+"`R("L@)&)Y
M=&5S+"`D;&5N*3L*("`@("`@("`@("`@("`@("1D871A(#T@<W5B<W1R*"1D
M871A+"`R("L@)&)Y=&5S("L@)&QE;BD["B`@("`@("`@("`@("`@("`D<F5S
M=6QT6UT@/2!A<G)A>2@G;V-T970@<W1R:6YG)RP@)&]C=&5C='-T<FEN9U]D
M871A*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S
M92`P>#`U.@H@("`@("`@("`@("`@("`@+R\@3G5L;"!T>7!E"B`@("`@("`@
M("`@("`@("`D9&%T82`]('-U8G-T<B@D9&%T82P@,BD["B`@("`@("`@("`@
M("`@("`D<F5S=6QT6UT@/2!A<G)A>2@G;G5L;"<L(&YU;&PI.PH@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#!X,#8Z"B`@("`@
M("`@("`@("`@("`O+R!/8FIE8W0@:61E;G1I9FEE<B!T>7!E"B`@("`@("`@
M("`@("`@("`D;&5N(#T@;W)D*"1D871A6S%=*3L*("`@("`@("`@("`@("`@
M("1B>71E<R`](#`["B`@("`@("`@("`@("`@("!I9B`H)&QE;B`F(#!X.#`I
M('L*("`@("`@("`@("`@("`@("`@("`D8GET97,@/2`D;&5N("8@,'@P9CL*
M("`@("`@("`@("`@("`@("`@("`D;&5N(#T@,#L*("`@("`@("`@("`@("`@
M("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D8GET97,[("1I*RLI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&QE;B`]("@D;&5N(#P\(#@I('P@;W)D*"1D
M871A6R1I("L@,ETI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1O:61?9&%T82`]('-U8G-T<B@D
M9&%T82P@,B`K("1B>71E<RP@)&QE;BD["B`@("`@("`@("`@("`@("`D9&%T
M82`]('-U8G-T<B@D9&%T82P@,B`K("1B>71E<R`K("1L96XI.PH*("`@("`@
M("`@("`@("`@("\O(%5N<&%C:R!T:&4@3TE$"B`@("`@("`@("`@("`@("`D
M<&QA:6X@(#T@9FQO;W(H;W)D*"1O:61?9&%T85LP72D@+R`T,"D["B`@("`@
M("`@("`@("`@("`D<&QA:6X@+CT@)RXG("X@;W)D*"1O:61?9&%T85LP72D@
M)2`T,#L*"B`@("`@("`@("`@("`@("`D=F%L=64@/2`P.PH@("`@("`@("`@
M("`@("`@)&D@/2`Q.PH@("`@("`@("`@("`@("`@=VAI;&4@*"1I(#P@<W1R
M;&5N*"1O:61?9&%T82DI('L*("`@("`@("`@("`@("`@("`@("`D=F%L=64@
M/2`D=F%L=64@/#P@-SL*("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2`D
M=F%L=64@?"`H;W)D*"1O:61?9&%T85LD:5TI("8@,'@W9BD["@H@("`@("`@
M("`@("`@("`@("`@(&EF("@A*&]R9"@D;VED7V1A=&%;)&E=*2`F(#!X.#`I
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1P;&%I;B`N/2`G+B<@+B`D
M=F%L=64["B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU92`](#`["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1I*RL[
M"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?;VED<ULD<&QA:6Y=*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1R97-U;'1;72`](&%R<F%Y*"=O:60G+"`D=&AI<RT^7V]I9'-;)'!L86EN
M72D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("1R97-U;'1;72`](&%R<F%Y*"=O:60G+"`D<&QA:6XI.PH@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@8V%S92`P>#$R.@H@("`@("`@("`@("!C87-E(#!X,3,Z"B`@("`@("`@
M("`@(&-A<V4@,'@Q-#H*("`@("`@("`@("`@8V%S92`P>#$U.@H@("`@("`@
M("`@("!C87-E(#!X,38Z"B`@("`@("`@("`@(&-A<V4@,'@X,3H*("`@("`@
M("`@("`@8V%S92`P>#@P.@H@("`@("`@("`@("`@("`@+R\@0VAA<F%C=&5R
M('-T<FEN9R!T>7!E"B`@("`@("`@("`@("`@("`D;&5N(#T@;W)D*"1D871A
M6S%=*3L*("`@("`@("`@("`@("`@("1B>71E<R`](#`["B`@("`@("`@("`@
M("`@("!I9B`H)&QE;B`F(#!X.#`I('L*("`@("`@("`@("`@("`@("`@("`D
M8GET97,@/2`D;&5N("8@,'@P9CL*("`@("`@("`@("`@("`@("`@("`D;&5N
M(#T@,#L*("`@("`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D
M8GET97,[("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&QE;B`]
M("@D;&5N(#P\(#@I('P@;W)D*"1D871A6R1I("L@,ETI.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("1S=')I;F=?9&%T82`]('-U8G-T<B@D9&%T82P@,B`K("1B>71E<RP@)&QE
M;BD["B`@("`@("`@("`@("`@("`D9&%T82`]('-U8G-T<B@D9&%T82P@,B`K
M("1B>71E<R`K("1L96XI.PH@("`@("`@("`@("`@("`@)')E<W5L=%M=(#T@
M87)R87DH)W-T<FEN9R<L("1S=')I;F=?9&%T82D["B`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@,'@Q-SH*("`@("`@("`@("`@
M("`@("\O(%1I;64@='EP97,*("`@("`@("`@("`@("`@("1L96X@/2!O<F0H
M)&1A=&%;,5TI.PH@("`@("`@("`@("`@("`@)&)Y=&5S(#T@,#L*("`@("`@
M("`@("`@("`@(&EF("@D;&5N("8@,'@X,"D@>PH@("`@("`@("`@("`@("`@
M("`@("1B>71E<R`]("1L96X@)B`P>#!F.PH@("`@("`@("`@("`@("`@("`@
M("1L96X@/2`P.PH@("`@("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D
M:2`\("1B>71E<SL@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M;&5N(#T@*"1L96X@/#P@."D@?"!O<F0H)&1A=&%;)&D@*R`R72D["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@)'1I;65?9&%T82`]('-U8G-T<B@D9&%T82P@,B`K("1B>71E<RP@
M)&QE;BD["B`@("`@("`@("`@("`@("`D9&%T82`]('-U8G-T<B@D9&%T82P@
M,B`K("1B>71E<R`K("1L96XI.PH@("`@("`@("`@("`@("`@)')E<W5L=%M=
M(#T@87)R87DH)W5T8W1I;64G+"`D=&EM95]D871A*3L*("`@("`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`P>#@R.@H@("`@("`@("`@
M("`@("`@+R\@6#4P.78S(&5X=&5N<VEO;G,_"B`@("`@("`@("`@("`@("`D
M;&5N(#T@;W)D*"1D871A6S%=*3L*("`@("`@("`@("`@("`@("1B>71E<R`]
M(#`["B`@("`@("`@("`@("`@("!I9B`H)&QE;B`F(#!X.#`I('L*("`@("`@
M("`@("`@("`@("`@("`D8GET97,@/2`D;&5N("8@,'@P9CL*("`@("`@("`@
M("`@("`@("`@("`D;&5N(#T@,#L*("`@("`@("`@("`@("`@("`@("!F;W(@
M*"1I(#T@,#L@)&D@/"`D8GET97,[("1I*RLI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&QE;B`]("@D;&5N(#P\(#@I('P@;W)D*"1D871A6R1I("L@
M,ETI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("1S97%U96YC95]D871A(#T@<W5B<W1R*"1D871A
M+"`R("L@)&)Y=&5S+"`D;&5N*3L*("`@("`@("`@("`@("`@("1D871A(#T@
M<W5B<W1R*"1D871A+"`R("L@)&)Y=&5S("L@)&QE;BD["B`@("`@("`@("`@
M("`@("`D<F5S=6QT6UT@/2!A<G)A>2@G97AT96YS:6]N)RP@)U@U,#EV,R!E
M>'1E;G-I;VYS)RD["B`@("`@("`@("`@("`@("`D<F5S=6QT6UT@/2`D=&AI
M<RT^7W!A<G-E05-.*"1S97%U96YC95]D871A*3L*("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@8V%S92`P>&$P.@H@("`@("`@("`@("!C
M87-E(#!X83,Z"B`@("`@("`@("`@("`@("`O+R!%>'1E;G-I;VYS"B`@("`@
M("`@("`@("`@("`D97AT96YS:6]N7V1A=&$@/2!S=6)S='(H)&1A=&$L(#`L
M(#(I.PH@("`@("`@("`@("`@("`@)&1A=&$@/2!S=6)S='(H)&1A=&$L(#(I
M.PH@("`@("`@("`@("`@("`@)')E<W5L=%M=(#T@87)R87DH)V5X=&5N<VEO
M;B<L(&1E8VAE>"@D97AT96YS:6]N7V1A=&$I*3L*("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@8V%S92`P>&4V.@H@("`@("`@("`@("`@
M("`@)&5X=&5N<VEO;E]D871A(#T@<W5B<W1R*"1D871A+"`P+"`Q*3L*("`@
M("`@("`@("`@("`@("1D871A(#T@<W5B<W1R*"1D871A+"`Q*3L*("`@("`@
M("`@("`@("`@("1R97-U;'1;72`](&%R<F%Y*"=E>'1E;G-I;VXG+"!D96-H
M97@H)&5X=&5N<VEO;E]D871A*2D["B`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@(&-A<V4@,'AA,3H*("`@("`@("`@("`@("`@("1E>'1E
M;G-I;VY?9&%T82`]('-U8G-T<B@D9&%T82P@,"P@,2D["B`@("`@("`@("`@
M("`@("`D9&%T82`]('-U8G-T<B@D9&%T82P@-BD["B`@("`@("`@("`@("`@
M("`D<F5S=6QT6UT@/2!A<G)A>2@G97AT96YS:6]N)RP@9&5C:&5X*"1E>'1E
M;G-I;VY?9&%T82DI.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@+R\@56YK;F]W;@H@("`@
M("`@("`@("`@("`@)')E<W5L=%M=(#T@87)R87DH)U5.2TY/5TXG+"!D96-H
M97@H)&1A=&$I*3L*("`@("`@("`@("`@("`@("1D871A(#T@)R<["B`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("AC;W5N="@D<F5S=6QT*2`^(#$I(#\@)')E<W5L="`Z
M(&%R<F%Y7W!O<"@D<F5S=6QT*3L*("`@('T*"B`@("`O*BH*("`@("`J($1E
M8W)Y<'0@86X@4S]-24U%('-I9VYE9"!M97-S86=E('5S:6YG(&$@<'5B;&EC
M(&ME>2X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1T97AT("`@5&AE('1E>'0@=&\@8F4@=F5R
M:69I960N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@5&AE('!A<F%M
M971E<G,@;F5E9&5D(&9O<B!V97)I9FEC871I;VXN"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!V97)I9FEC871I;VX@;65S<V%G92X*("`@
M("`J("`@("`@("`@("`@("`@("!2971U<FYS(%!%05)?17)R;W(@;V)J96-T
M(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9&5C<GEP=%-I9VYA
M='5R92@D=&5X="P@)'!A<F%M<RD*("`@('L*("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@G7V1E8W)Y<'13:6=N871U<F4H*2`G("X@7R@B;F]T
M('EE="!I;7!L96UE;G1E9"(I*3L*("`@('T*"B`@("`O*BH*("`@("`J($-H
M96-K(&9O<B!T:&4@<')E<V5N8V4@;V8@=&AE($]P96Y34TP@97AT96YS:6]N
M('1O(%!(4"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%)E='5R
M;G,@=')U92!I9B!T:&4@;W!E;G-S;"!E>'1E;G-I;VX@:7,@879A:6QA8FQE
M+@H@("`@("H@("`@("`@("`@("`@("`@("!2971U<FYS(&$@4$5!4E]%<G)O
M<B!I9B!N;W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-H96-K1F]R3W!E;E-3
M3"@I"B`@("!["B`@("`@("`@:68@*"%5=&EL.CIE>'1E;G-I;VY%>&ES=',H
M)V]P96YS<VPG*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BA?*")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H
M92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(I*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!%>'1R86-T('1H92!E;6%I;"!A9&1R97-S
M(&9R;VT@82!P=6)L:6,@:V5Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&ME>2`@5&AE('!U8FQI8R!K97DN"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%)E='5R;G,@=&AE(&5M86EL(&%D9')E<W,L(&]R(&YU;&P@
M:68@;F]N92!I<R!F;W5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T16UA
M:6Q&<F]M2V5Y*"1K97DI"B`@("!["B`@("`@("`@)&ME>5]I;F9O(#T@;W!E
M;G-S;%]X-3`Y7W!A<G-E*"1K97DI.PH@("`@("`@(&EF("AI<U]A<G)A>2@D
M:V5Y7VEN9F\I("8F(&ES<V5T*"1K97E?:6YF;ULG<W5B:F5C="==*2D@>PH@
M("`@("`@("`@("!I9B`H:7-S970H)&ME>5]I;F9O6R=S=6)J96-T)UU;)T5M
M86EL)UTI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&ME>5]I;F9O6R=S
M=6)J96-T)UU;)T5M86EL)UT["B`@("`@("`@("`@('T@96QS96EF("AI<W-E
M="@D:V5Y7VEN9F];)W-U8FIE8W0G75LG96UA:6Q!9&1R97-S)UTI*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)&ME>5]I;F9O6R=S=6)J96-T)UU;)V5M
M86EL061D<F5S<R==.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@;G5L;#L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E<G0@
M82!02T-3(#$R(&5N8W)Y<'1E9"!C97)T:69I8V%T92!P86-K86=E(&EN=&\@
M82!P<FEV871E(&ME>2P*("`@("`J('!U8FQI8R!K97DL(&%N9"!A;GD@861D
M:71I;VYA;"!K97ES+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E
M>'0@("!4:&4@4$M#4R`Q,B!D871A+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P
M87)A;7,@(%1H92!P87)A;65T97)S(&YE961E9"!F;W(@<&%R<VEN9RX*("`@
M("`J(#QP<F4^"B`@("`@*B!087)A;65T97)S.@H@("`@("H@/3T]/3T]/3T]
M/3T*("`@("`J("=S<VQP871H)R`]/B!4:&4@<&%T:"!T;R!T:&4@3W!E;E-3
M3"!B:6YA<GDN("A215%525)%1"D*("`@("`J("=P87-S=V]R9"<@/3X@5&AE
M('!A<W-W;W)D('1O('5S92!T;R!D96-R>7!T('1H92!D871A+B`H3W!T:6]N
M86PI"B`@("`@*B`G;F5W<&%S<W=O<F0G(#T^(%1H92!P87-S=V]R9"!T;R!U
M<V4@=&\@96YC<GEP="!T:&4@<')I=F%T92!K97DN"B`@("`@*B`@("`@("`@
M("`@("`@("`@("A/<'1I;VYA;"D*("`@("`J(#PO<')E/@H@("`@("H*("`@
M("`J($!R971U<FX@<W1D0VQA<W,@($%N(&]B:F5C="X*("`@("`J("`@("`@
M("`@("`@("`@("`@("=P<FEV871E)R`M("!4:&4@<')I=F%T92!K97D@:6X@
M4$5-(&9O<FUA="X*("`@("`J("`@("`@("`@("`@("`@("`@("=P=6)L:6,G
M("`M("!4:&4@<'5B;&EC(&ME>2!I;B!014T@9F]R;6%T+@H@("`@("H@("`@
M("`@("`@("`@("`@("`@)V-E<G1S)R`@("T@($%N(&%R<F%Y(&]F(&%D9&ET
M:6]N86P@8V5R=',N"B`@("`@*B`@("`@("`@("`@("`@("`@("!2971U<FYS
M(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N('!A
M<G-E4$M#4S$R1&%T82@D<&MC<S$R+"`D<&%R86US*0H@("`@>PH@("`@("`@
M("\J($-H96-K(&9O<B!A=F%I;&%B:6QI='D@;V8@3W!E;E-33"!02%`@97AT
M96YS:6]N+B`J+PH@("`@("`@("1O<&5N<W-L(#T@)'1H:7,M/F-H96-K1F]R
M3W!E;E-33"@I.PH@("`@("`@(&EF("AI<U]A*"1O<&5N<W-L+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D;W!E;G-S;#L*("`@("`@
M("!]"@H@("`@("`@(&EF("@A:7-S970H)'!A<F%M<ULG<W-L<&%T:"==*2D@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;R!P
M871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y3
M4TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D
M871A+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!]"B`@("`@("`@)'-S
M;'!A=&@@/2!E<V-A<&5S:&5L;&-M9"@D<&%R86US6R=S<VQP871H)UTI.PH*
M("`@("`@("`O*B!#<F5A=&4@=&5M<"!F:6QE<R!F;W(@:6YP=70O;W5T<'5T
M+B`J+PH@("`@("`@("1I;G!U="`]("1T:&ES+3Y?8W)E871E5&5M<$9I;&4H
M)VAO<F1E+7-M:6UE)RD["B`@("`@("`@)&]U='!U="`]("1T:&ES+3Y?8W)E
M871E5&5M<$9I;&4H)VAO<F1E+7-M:6UE)RD["@H@("`@("`@("1O8B`]("9N
M97<@<W1D0VQA<W,["@H@("`@("`@("\J(%=R:71E('1E>'0@=&\@9FEL92`J
M+PH@("`@("`@("1F<"`](&9O<&5N*"1I;G!U="P@)W<K)RD["B`@("`@("`@
M9G=R:71E*"1F<"P@)'!K8W,Q,BD["B`@("`@("`@9F-L;W-E*"1F<"D["@H@
M("`@("`@("\J($5X=')A8W0@=&AE('!R:79A=&4@:V5Y(&9R;VT@=&AE(&9I
M;&4@9FER<W0N("HO"B`@("`@("`@)&-M9&QI;F4@/2`D<W-L<&%T:"`N("<@
M<&MC<S$R("UI;B`G("X@)&EN<'5T("X@)R`M;W5T("<@+B`D;W5T<'5T("X@
M)R`M;F]C97)T<R<["B`@("`@("`@:68@*&ES<V5T*"1P87)A;7-;)W!A<W-W
M;W)D)UTI*2!["B`@("`@("`@("`@("1C;61L:6YE("X]("<@+7!A<W-I;B!S
M=&1I;B<["B`@("`@("`@("`@(&EF("@A96UP='DH)'!A<F%M<ULG;F5W<&%S
M<W=O<F0G72DI('L*("`@("`@("`@("`@("`@("1C;61L:6YE("X]("<@+7!A
M<W-O=70@<W1D:6XG.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)&-M9&QI;F4@+CT@)R`M;F]D97,G.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1F9"`]('!O<&5N*"1C;61L:6YE+"`G=R<I.PH@("`@("`@
M("`@("!F=W)I=&4H)&9D+"`D<&%R86US6R=P87-S=V]R9"==("X@(EQN(BD[
M"B`@("`@("`@("`@(&EF("@A96UP='DH)'!A<F%M<ULG;F5W<&%S<W=O<F0G
M72DI('L*("`@("`@("`@("`@("`@(&9W<FET92@D9F0L("1P87)A;7-;)VYE
M=W!A<W-W;W)D)UT@+B`B7&XB*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!P8VQO<V4H)&9D*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M8VUD;&EN92`N/2`G("UN;V1E<R<["B`@("`@("`@("`@(&5X96,H)&-M9&QI
M;F4I.PH@("`@("`@('T*("`@("`@("`D;V(M/G!R:79A=&4@/2!T<FEM*&9I
M;&5?9V5T7V-O;G1E;G1S*"1O=71P=70I*3L*("`@("`@("!I9B`H96UP='DH
M)&]B+3YP<FEV871E*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BA?*")087-S=V]R9"!I;F-O<G)E8W0B*2P@)VAO<F1E+F5R<F]R
M)RD["B`@("`@("`@?0H*("`@("`@("`O*B!%>'1R86-T('1H92!P=6)L:6,@
M:V5Y(&YE>'0N("HO"B`@("`@("`@)&-M9&QI;F4@/2`D<W-L<&%T:"`N("<@
M<&MC<S$R("UI;B`G("X@)&EN<'5T("X@)R`M;W5T("<@+B`D;W5T<'5T("X@
M)R`M;F]K97ES("UC;&-E<G1S)SL*("`@("`@("!I9B`H:7-S970H)'!A<F%M
M<ULG<&%S<W=O<F0G72DI('L*("`@("`@("`@("`@)&-M9&QI;F4@+CT@)R`M
M<&%S<VEN('-T9&EN)SL*("`@("`@("`@("`@)&9D(#T@<&]P96XH)&-M9&QI
M;F4L("=W)RD["B`@("`@("`@("`@(&9W<FET92@D9F0L("1P87)A;7-;)W!A
M<W-W;W)D)UT@+B`B7&XB*3L*("`@("`@("`@("`@<&-L;W-E*"1F9"D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@97AE8R@D8VUD;&EN92D["B`@
M("`@("`@?0H@("`@("`@("1O8BT^<'5B;&EC(#T@=')I;2AF:6QE7V=E=%]C
M;VYT96YT<R@D;W5T<'5T*2D["@H@("`@("`@("\J($5X=')A8W0@=&AE('!U
M8FQI8R!K97D@;F5X="X@*B\*("`@("`@("`D8VUD;&EN92`]("1S<VQP871H
M("X@)R!P:V-S,3(@+6EN("<@+B`D:6YP=70@+B`G("UO=70@)R`N("1O=71P
M=70@+B`G("UN;VME>7,@+6-A8V5R=',G.PH@("`@("`@(&EF("AI<W-E="@D
M<&%R86US6R=P87-S=V]R9"==*2D@>PH@("`@("`@("`@("`D8VUD;&EN92`N
M/2`G("UP87-S:6X@<W1D:6XG.PH@("`@("`@("`@("`D9F0@/2!P;W!E;B@D
M8VUD;&EN92P@)W<G*3L*("`@("`@("`@("`@9G=R:71E*"1F9"P@)'!A<F%M
M<ULG<&%S<W=O<F0G72`N(")<;B(I.PH@("`@("`@("`@("!P8VQO<V4H)&9D
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!E>&5C*"1C;61L:6YE
M*3L*("`@("`@("!]"B`@("`@("`@)&]B+3YC97)T<R`]('1R:6TH9FEL95]G
M971?8V]N=&5N=',H)&]U='!U="DI.PH*("`@("`@("!R971U<FX@)&]B.PH@
M("`@?0H*("`@("\J*@H@("`@("H@5&AE($-O;G1E;G0M5'EP92!P87)A;65T
M97)S(%!(4"=S(&]P96YS<VQ?<&MC<S=?*B!F=6YC=&EO;G,@<F5T=7)N(&%R
M90H@("`@("H@9&5P<F5C871E9"X@($9I>"!T:&5S92!H96%D97)S('1O('1H
M92!C;W)R96-T(&]N97,@*'-E92!21D,@,C,Q,2DN"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=&5X="`@5&AE(%!+0U,W(&1A=&$N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T
M>7!E("!)<R!T:&ES("=M97-S86=E)R!O<B`G<VEG;F%T=7)E)R!D871A/PH@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@4$M#4S<@9&%T82!W
M:71H('1H92!C;W)R96-T($-O;G1E;G0M5'EP92!P87)A;65T97(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]F:7A#;VYT96YT5'EP92@D=&5X="P@)'1Y<&4I
M"B`@("!["B`@("`@("`@:68@*"1T>7!E(#T]("=M97-S86=E)RD@>PH@("`@
M("`@("`@("`D9G)O;2`]("=A<'!L:6-A=&EO;B]X+7!K8W,W+6UI;64G.PH@
M("`@("`@("`@("`D=&\@/2`G87!P;&EC871I;VXO<&MC<S<M;6EM92<["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&9R;VT@/2`G87!P;&EC871I
M;VXO>"UP:V-S-RUS:6=N871U<F4G.PH@("`@("`@("`@("`D=&\@/2`G87!P
M;&EC871I;VXO<&MC<S<M<VEG;F%T=7)E)SL*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N('-T<E]R97!L86-E*"=#;VYT96YT+51Y<&4Z("<@+B`D9G)O;2P@
M)T-O;G1E;G0M5'EP93H@)R`N("1T;RP@)'1E>'0I.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'``````````
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,30V,C`V(#$P-3$U-#,S
M-S,W(#`R,3<V,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D92]#<GEP="YP:'`G
M.PH*+RHJ"B`J($%R;6]R($AE861E<B!,:6YE<R`M($9R;VT@4D9#(#(T-#`*
M("H*("H@($%N($%R;6]R($AE861E<B!,:6YE(&-O;G-I<W1S(&]F('1H92!A
M<'!R;W!R:6%T92!H96%D97(@;&EN92!T97AT"B`J("!S=7)R;W5N9&5D(&)Y
M(&9I=F4@*#4I(&1A<VAE<R`H)RTG+"`P>#)$*2!O;B!E:71H97(@<VED92!O
M9B!T:&4@:&5A9&5R"B`J("!L:6YE('1E>'0N(%1H92!H96%D97(@;&EN92!T
M97AT(&ES(&-H;W-E;B!B87-E9"!U<&]N('1H92!T>7!E(&]F(&1A=&$@=&AA
M=`H@*B`@:7,@8F5I;F<@96YC;V1E9"!I;B!!<FUO<BP@86YD(&AO=R!I="!I
M<R!B96EN9R!E;F-O9&5D+B!(96%D97(@;&EN92!T97AT<PH@*B`@:6YC;'5D
M92!T:&4@9F]L;&]W:6YG('-T<FEN9W,Z"B`J"B`J("!!;&P@07)M;W(@2&5A
M9&5R($QI;F5S(&%R92!P<F5F:7AE9"!W:71H("=01U`G+@H@*@H@*B`@5&AE
M($%R;6]R(%1A:6P@3&EN92!I<R!C;VUP;W-E9"!I;B!T:&4@<V%M92!M86YN
M97(@87,@=&AE($%R;6]R($AE861E<@H@*B`@3&EN92P@97AC97!T('1H92!S
M=')I;F<@(D)%1TE.(B!I<R!R97!L86-E9"!B>2!T:&4@<W1R:6YG(")%3D0N
M(@H@*B\*"B\J*B!5<V5D(&9O<B!S:6=N960L(&5N8W)Y<'1E9"P@;W(@8V]M
M<')E<W-E9"!F:6QE<RX@*B\*9&5F:6YE*"=01U!?05)-3U)?34534T%'12<L
M(#$I.PH*+RHJ(%5S960@9F]R('-I9VYE9"!F:6QE<RX@*B\*9&5F:6YE*"=0
M1U!?05)-3U)?4TE'3D5$7TU%4U-!1T4G+"`R*3L*"B\J*B!5<V5D(&9O<B!A
M<FUO<FEN9R!P=6)L:6,@:V5Y<RX@*B\*9&5F:6YE*"=01U!?05)-3U)?4%5"
M3$E#7TM%62<L(#,I.PH*+RHJ(%5S960@9F]R(&%R;6]R:6YG('!R:79A=&4@
M:V5Y<RX@*B\*9&5F:6YE*"=01U!?05)-3U)?4%))5D%415]+15DG+"`T*3L*
M"B\J*@H@*B!5<V5D(&9O<B!D971A8VAE9"!S:6=N871U<F5S+"!01U`O34E-
M12!S:6=N871U<F5S+"!A;F0@;F%T=7)E<R!F;VQL;W=I;F<*("H@8VQE87)S
M:6=N960@;65S<V%G97,N"B`J+PID969I;F4H)U!'4%]!4DU/4E]324=.0515
M4D4G+"`U*3L*"B\J*B!296=U;&%R('1E>'0@8V]N=&%I;F5D(&EN(&%N(%!'
M4"!M97-S86=E+B`J+PID969I;F4H)U!'4%]!4DU/4E]415A4)RP@-BD["@H*
M+RHJ(%1H92!D969A=6QT('!U8FQI8R!01U`@:V5Y<V5R=F5R('1O('5S92X@
M*B\*9&5F:6YE*"=01U!?2T594T525D527U!50DQ)0R<L("=W=W=K97ES+G!G
M<"YN970G*3L*"B\J*@H@*B!4:&4@;G5M8F5R(&]F('1I;65S('1H92!K97ES
M97)V97(@<F5F=7-E<R!C;VYN96-T:6]N(&)E9F]R92!A;B!E<G)O<B!I<PH@
M*B!R971U<FYE9"X*("HO"F1E9FEN92@G4$=07TM%65-%4E9%4E]214954T4G
M+"`S*3L*"B\J*@H@*B!4:&4@;G5M8F5R(&]F('-E8V]N9',@=&AA="!02%`@
M=VEL;"!A='1E;7!T('1O(&-O;FYE8W0@=&\@=&AE(&ME>7-E<G9E<@H@*B!B
M969O<F4@:70@=VEL;"!S=&]P('!R;V-E<W-I;F<@=&AE(')E<75E<W0N"B`J
M+PID969I;F4H)U!'4%]+15E315)615)?5$E-14]55"<L(#$P*3L*"@HO*BH*
M("H@2&]R9&5?0W)Y<'1?<&=P.CH@<')O=FED97,@82!F<F%M97=O<FL@9F]R
M($AO<F1E(&%P<&QI8V%T:6]N<R!T;R!I;G1E<F%C=`H@*B!W:71H('1H92!'
M3E4@4')I=F%C>2!'=6%R9"!P<F]G<F%M("@B1VYU4$<B*2X@($=N=5!'(&EM
M<&QE;65N=',@=&AE($]P96Y01U`*("H@<W1A;F1A<F0@*%)&0R`R-#0P*2X*
M("H*("H@1VYU4$<@5V5B<VET93H@:'1T<#HO+W=W=RYG;G5P9RYO<F<O"B`J
M"B`J(%1H:7,@8VQA<W,@:&%S(&)E96X@9&5V96QO<&5D('=I=&@L(&%N9"!I
M<R!O;FQY(&=U87)A;G1E960@=&\@=V]R:R!W:71H+`H@*B!697)S:6]N(#$N
M,C$@;W(@86)O=F4@;V8@1VYU4$<N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`L=B`Q+C@U+C(N,34@,C`P-B\P-R\R,"`P
M.3HP,CHS."!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-
M:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6-H865L(%-L=7-A<GH@
M/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J($!S:6YC92`@($AO
M<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]#<GEP=`H@*B\*8VQA<W,@2&]R
M9&5?0W)Y<'1?<&=P(&5X=&5N9',@2&]R9&5?0W)Y<'0@>PH*("`@("\J*@H@
M("`@("H@4W1R:6YG<R!I;B!A<FUO<B!H96%D97(@;&EN97,@=7-E9"!T;R!D
M:7-T:6YG=6ES:"!B971W965N('1H92!D:69F97)E;G0*("`@("`J('1Y<&5S
M(&]F(%!'4"!D96-R>7!T:6]N+V5N8W)Y<'1I;VXN"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]A<FUO<B`](&%R<F%Y*`H@
M("`@("`@("=-15-304=%)R`@("`@("`@("`@(#T^("!01U!?05)-3U)?3453
M4T%'12P*("`@("`@("`G4TE'3D5$($U%4U-!1T4G("`@("`]/B`@4$=07T%2
M34]27U-)1TY%1%]-15-304=%+`H@("`@("`@("=054),24,@2T59($),3T-+
M)R`@(#T^("!01U!?05)-3U)?4%5"3$E#7TM%62P*("`@("`@("`G4%))5D%4
M12!+15D@0DQ/0TLG("`]/B`@4$=07T%234]27U!2259!5$5?2T59+`H@("`@
M("`@("=324=.05154D4G("`@("`@("`@(#T^("!01U!?05)-3U)?4TE'3D%4
M55)%"B`@("`I.PH*("`@("\J*@H@("`@("H@5&AE(&QI<W0@;V8@4$=0(&AA
M<V@@86QG;W)I=&AM<R`H9G)O;2!21D,@,S$U-BDN"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]H87-H06QG(#T@87)R87DH
M"B`@("`@("`@,2`@/3X@("=P9W`M;60U)RP*("`@("`@("`R("`]/B`@)W!G
M<"US:&$Q)RP*("`@("`@("`S("`]/B`@)W!G<"UR:7!E;60Q-C`G+`H@("`@
M("`@(#4@(#T^("`G<&=P+6UD,B<L"B`@("`@("`@-B`@/3X@("=P9W`M=&EG
M97(Q.3(G+`H@("`@("`@(#<@(#T^("`G<&=P+6AA=F%L+34M,38P)RP*("`@
M("`@("`X("`]/B`@)W!G<"US:&$R-38G+`H@("`@("`@(#D@(#T^("`G<&=P
M+7-H83,X-"<L"B`@("`@("`@,3`@/3X@("=P9W`M<VAA-3$R)RP*("`@("D[
M"@H@("`@+RHJ"B`@("`@*B!';G501R!P<F]G<F%M(&QO8V%T:6]N+V-O;6UO
M;B!O<'1I;VYS+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1?9VYU<&<["@H@("`@+RHJ"B`@("`@*B!&:6QE;F%M92!O9B!T
M:&4@=&5M<&]R87)Y('!U8FQI8R!K97ER:6YG+@H@("`@("H*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W!U8FQI8TME>7)I;F<["@H@
M("`@+RHJ"B`@("`@*B!&:6QE;F%M92!O9B!T:&4@=&5M<&]R87)Y('!R:79A
M=&4@:V5Y<FEN9RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO
M"B`@("!V87(@)%]P<FEV871E2V5Y<FEN9SL*"B`@("`O*BH*("`@("`J(%1H
M92!E>&ES=&5N8V4@;V8@=&AI<R!P<F]P97)T>2!I;F1I8V%T97,@=&AA="!M
M=6QT:7!L92!R96-I<&EE;G0*("`@("`J(&5N8W)Y<'1I;VX@:7,@879A:6QA
M8FQE+@H@("`@("H*("`@("`J($!S:6YC92!(;W)D92`S+C$*("`@("`J"B`@
M("`@*B!`9&5P<F5C871E9`H@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@
M("`@("HO"B`@("!V87(@)&UU;'1I<&QE4F5C:7!I96YT16YC<GEP=&EO;B`]
M('1R=64["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@4&%R86UE=&5R(&%R<F%Y(&-O
M;G1A:6YI;F<@=&AE('!A=&@@=&\@=&AE($=N=5!'"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@8FEN87)Y("AK97D@/2`G<')O9W)A;2<I(&%N9"!T
M;R!A('1E;7!O<F%R>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&1I
M<F5C=&]R>2X*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?0W)Y<'1?<&=P
M*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=&5M
M<&1I<B`](%5T:6PZ.F-R96%T951E;7!$:7(H=')U92P@)'!A<F%M<ULG=&5M
M<"==*3L*"B`@("`@("`@:68@*&5M<'1Y*"1P87)A;7-;)W!R;V=R86TG72DI
M('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*%!%05(Z.G)A:7-E17)R;W(H
M7R@B5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G
M:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(BDI+"!?7T9)3$5?7RP@
M7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@+RH@4W1O<F4@=&AE(&QO
M8V%T:6]N(&]F($=N=5!'(&%N9"!S970@8V]M;6]N(&]P=&EO;G,N("HO"B`@
M("`@("`@)'1H:7,M/E]G;G5P9R`](&%R<F%Y*`H@("`@("`@("`@("`D<&%R
M86US6R=P<F]G<F%M)UTL"B`@("`@("`@("`@("<M+6YO+71T>2<L"B`@("`@
M("`@("`@("<M+6YO+7-E8VUE;2UW87)N:6YG)RP*("`@("`@("`@("`@)RTM
M;F\M;W!T:6]N<R<L"B`@("`@("`@("`@("<M+6YO+61E9F%U;'0M:V5Y<FEN
M9R<L"B`@("`@("`@("`@("<M+7%U:65T)RP*("`@("`@("`@("`@)RTM>65S
M)RP*("`@("`@("`@("`@)RTM:&]M961I<B`G("X@)'1H:7,M/E]T96UP9&ER
M"B`@("`@("`@*3L*"B`@("`@("`@:68@*'-U8G-T<BA02%!?3U,L(#`L(#,I
M("$]("=724XG*2!["B`@("`@("`@("`@(&%R<F%Y7W5N<VAI9G0H)'1H:7,M
M/E]G;G5P9RP@)TQ!3D<](#LG*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'96YE<F%T97,@82!P97)S;VYA;"!0=6)L:6,O4')I=F%T92!K
M97EP86ER(&-O;6)I;F%T:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)')E86QN86UE("`@(%1H92!N86UE('1O('5S92!F;W(@=&AE(&ME>2X*
M("`@("`J($!P87)A;2!S=')I;F<@)&5M86EL("`@("`@(%1H92!E;6%I;"!T
M;R!U<V4@9F]R('1H92!K97DN"B`@("`@*B!`<&%R86T@<W1R:6YG("1P87-S
M<&AR87-E("!4:&4@<&%S<W!H<F%S92!T;R!U<V4@9F]R('1H92!K97DN"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1C;VUM96YT("`@("!4:&4@8V]M;65N="!T
M;R!U<V4@9F]R('1H92!K97DN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:V5Y
M;&5N9W1H("!4:&4@:V5Y;&5N9W1H('1O('5S92!F;W(@=&AE(&ME>2X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!C;VYS:7-T:6YG
M(&]F('1H92!P=6)L:6,@:V5Y(&%N9"!T:&4@<')I=F%T90H@("`@("H@("`@
M("`@("`@("`@("`@:V5Y+"!O<B!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@
M("H@/'!R93X*("`@("`J(%)E='5R;B!A<G)A>3H*("`@("`J($ME>2`@("`@
M("`@("`@(%9A;'5E"B`@("`@*B`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+0H@("`@("H@)W!U8FQI8R<@("`]/B`@4'5B;&EC($ME>0H@("`@("H@)W!R
M:79A=&4G("`]/B`@4')I=F%T92!+97D*("`@("`J(#PO<')E/@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G96YE<F%T94ME>2@D<F5A;&YA;64L("1E;6%I;"P@
M)'!A<W-P:')A<V4L("1C;VUM96YT(#T@)R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`D:V5Y;&5N9W1H(#T@,3`R-"D*("`@('L*("`@("`@("`O*B!#
M:&5C:R!F;W(@<V5C=7)E(&-O;FYE8W1I;VXN("HO"B`@("`@("`@)'-E8W5R
M95]C:&5C:R`]("1T:&ES+3YR97%U:7)E4V5C=7)E0V]N;F5C=&EO;B@I.PH@
M("`@("`@(&EF("AI<U]A*"1S96-U<F5?8VAE8VLL("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1S96-U<F5?8VAE8VL["B`@("`@("`@
M?0H*("`@("`@("`O*B!#<F5A=&4@=&5M<"!F:6QE<R!T;R!H;VQD('1H92!G
M96YE<F%T960@:V5Y<RX@*B\*("`@("`@("`D<'5B7V9I;&4@/2`D=&AI<RT^
M7V-R96%T951E;7!&:6QE*"=H;W)D92UP9W`G*3L*("`@("`@("`D<V5C<F5T
M7V9I;&4@/2`D=&AI<RT^7V-R96%T951E;7!&:6QE*"=H;W)D92UP9W`G*3L*
M"B`@("`@("`@+RH@0W)E871E('1H92!C;VYF:6<@9FEL92!N96-E<W-A<GD@
M9F]R($=N=5!'('1O(')U;B!I;B!B871C:"!M;V1E+B`J+PH@("`@("`@("\J
M(%1/1$\Z(%-A;FET:7IE(&EN<'5T+"!-;W)E('5S97(@8W5S=&]M:7IA8FQE
M/R`J+PH@("`@("`@("1I;G!U="`](&%R<F%Y*"D["B`@("`@("`@)&EN<'5T
M6UT@/2`G)7!U8G)I;F<@)R`N("1P=6)?9FEL93L*("`@("`@("`D:6YP=71;
M72`]("<E<V5C<FEN9R`G("X@)'-E8W)E=%]F:6QE.PH@("`@("`@("1I;G!U
M=%M=(#T@)TME>2U4>7!E.B!$4T$G.PH@("`@("`@("1I;G!U=%M=(#T@)TME
M>2U,96YG=&@Z(#$P,C0G.PH@("`@("`@("1I;G!U=%M=(#T@)U-U8FME>2U4
M>7!E.B!%3$<M12<["B`@("`@("`@)&EN<'5T6UT@/2`G4W5B:V5Y+4QE;F=T
M:#H@)R`N("1K97EL96YG=&@["B`@("`@("`@)&EN<'5T6UT@/2`G3F%M92U2
M96%L.B`G("X@)')E86QN86UE.PH@("`@("`@(&EF("@A96UP='DH)&-O;6UE
M;G0I*2!["B`@("`@("`@("`@("1I;G!U=%M=(#T@)TYA;64M0V]M;65N=#H@
M)R`N("1C;VUM96YT.PH@("`@("`@('T*("`@("`@("`D:6YP=71;72`]("=.
M86UE+45M86EL.B`G("X@)&5M86EL.PH@("`@("`@("1I;G!U=%M=(#T@)T5X
M<&ER92U$871E.B`P)SL*("`@("`@("`D:6YP=71;72`]("=087-S<&AR87-E
M.B`G("X@)'!A<W-P:')A<V4["B`@("`@("`@)&EN<'5T6UT@/2`G)6-O;6UI
M="<["@H@("`@("`@("\J(%)U;B!T:')O=6=H(&=P9R!B:6YA<GDN("HO"B`@
M("`@("`@)&-M9&QI;F4@/2!A<G)A>2@*("`@("`@("`@("`@)RTM9V5N+6ME
M>2<L"B`@("`@("`@("`@("<M+6)A=&-H)RP*("`@("`@("`@("`@)RTM87)M
M;W(G"B`@("`@("`@*3L*("`@("`@("`D=&AI<RT^7V-A;&Q'<&<H)&-M9&QI
M;F4L("=W)RP@)&EN<'5T*3L*"B`@("`@("`@+RH@1V5T('1H92!K97ES(&9R
M;VT@=&AE('1E;7`@9FEL97,N("HO"B`@("`@("`@)'!U8FQI8U]K97D@/2!F
M:6QE*"1P=6)?9FEL92D["B`@("`@("`@)'-E8W)E=%]K97D@/2!F:6QE*"1S
M96-R971?9FEL92D["@H@("`@("`@("\J($EF(&5I=&AE<B!K97D@:7,@96UP
M='DL('-O;65T:&EN9R!W96YT('=R;VYG+B`J+PH@("`@("`@(&EF("AE;7!T
M>2@D<'5B;&EC7VME>2D@?'P@96UP='DH)'-E8W)E=%]K97DI*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E!U8FQI8R]0<FEV
M871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(BDL("=H
M;W)D92YE<G)O<B<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&%R<F%Y
M*"=P=6)L:6,G(#T^("1P=6)L:6-?:V5Y+"`G<')I=F%T92<@/3X@)'-E8W)E
M=%]K97DI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!I;F9O<FUA
M=&EO;B!O;B!A(%!'4"!D871A(&)L;V-K+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'!G<&1A=&$@(%1H92!01U`@9&%T82!B;&]C:RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!W:71H(&EN9F]R;6%T
M:6]N(&]N('1H92!01U`@9&%T82!B;&]C:RX@268@86X*("`@("`J("`@("`@
M("`@("`@("`@(&5L96UE;G0@:7,@;F]T('!R97-E;G0@:6X@=&AE(&1A=&$@
M8FQO8VLL(&ET('=I;&P*("`@("`J("`@("`@("`@("`@("`@(&QI:V5W:7-E
M(&YO="!B92!S970@:6X@=&AE(&%R<F%Y+@H@("`@("H@/'!R93X*("`@("`J
M($%R<F%Y($9O<FUA=#H*("`@("`J("TM+2TM+2TM+2TM+2T*("`@("`J(%MP
M=6)L:6-?:V5Y72];<V5C<F5T7VME>5T@/3X@07)R87D*("`@("`J("`@*`H@
M("`@("H@("`@(%MC<F5A=&5D72`]/B!+97D@8W)E871I;VX@+2!53DE8('1I
M;65S=&%M<`H@("`@("H@("`@(%ME>'!I<F5S72`]/B!+97D@97AP:7)A=&EO
M;B`M(%5.25@@=&EM97-T86UP("@P(#T@;F5V97(@97AP:7)E<RD*("`@("`J
M("`@("!;<VEZ95T@("`@/3X@4VEZ92!O9B!T:&4@:V5Y(&EN(&)I=',*("`@
M("`J("`@*0H@("`@("H*("`@("`J(%MF:6YG97)P<FEN=%T@/3X@1FEN9V5R
M<')I;G0@;V8@=&AE(%!'4"!D871A("AI9B!A=F%I;&%B;&4I"B`@("`@*B`@
M("`@("`@("`@("`@("`@(#$V+6)I="!H97@@=F%L=64*("`@("`J"B`@("`@
M*B!;<VEG;F%T=7)E72`]/B!!<G)A>2`H"B`@("`@*B`@("`@6VED>VY]+R=?
M4TE'3D%455)%)UT@/3X@07)R87D@*`H@("`@("H@("`@("`@("!;;F%M95T@
M("`@("`@(#T^($9U;&P@3F%M90H@("`@("H@("`@("`@("!;8V]M;65N=%T@
M("`@(#T^($-O;6UE;G0*("`@("`J("`@("`@("`@6V5M86EL72`@("`@("`]
M/B!%+6UA:6P@061D<F5S<PH@("`@("H@("`@("`@("!;9FEN9V5R<')I;G1=
M(#T^(#$V+6)I="!H97@@=F%L=64*("`@("`J("`@("`@("`@6V-R96%T961=
M("`@("`]/B!3:6=N871U<F4@8W)E871I;VX@+2!53DE8('1I;65S=&%M<`H@
M("`@("H@("`@("`@("!;;6EC86QG72`@("`@(#T^(%1H92!H87-H('5S960@
M=&\@8W)E871E('1H92!S:6=N871U<F4*("`@("`J("`@("`@("`@6W-I9U][
M:&5X?5T@("`]/B!!<G)A>2!;9&5T86EL<R!O9B!A('-I9R!V97)I9GEI;F<@
M=&AE($E$72`H"B`@("`@*B`@("`@("`@("`@("!;8W)E871E9%T@("`@(#T^
M(%-I9VYA='5R92!C<F5A=&EO;B`M(%5.25@@=&EM97-T86UP"B`@("`@*B`@
M("`@("`@("`@("!;9FEN9V5R<')I;G1=(#T^(#$V+6)I="!H97@@=F%L=64*
M("`@("`J("`@("`@("`@("`@(%MM:6-A;&==("`@("`@/3X@5&AE(&AA<V@@
M=7-E9"!T;R!C<F5A=&4@=&AE('-I9VYA='5R90H@("`@("H@("`@("`@("`I
M"B`@("`@*B`@("`@*0H@("`@("H@*0H@("`@("H@/"]P<F4^"B`@("`@*@H@
M("`@("H@16%C:"!U<V5R($E$('=I;&P@8F4@<W1O<F5D(&EN('1H92!A<G)A
M>2`G<VEG;F%T=7)E)R!A;F0@:&%V92!D871A"B`@("`@*B!A<W-O8VEA=&5D
M('=I=&@@:70L(&EN8VQU9&EN9R!A;B!A<G)A>2!F;W(@:6YF;W)M871I;VX@
M;VX@96%C:`H@("`@("H@<VEG;F%T=7)E('1H870@:&%S('-I9VYE9"!T:&%T
M(%5)1"X@4VEG;F%T=7)E<R!N;W0@87-S;V-I871E9"!W:71H(&$*("`@("`J
M(%5)1"`H92YG+B!R979O8V%T:6]N('-I9VYA='5R97,@86YD('-U8B!K97ES
M*2!W:6QL(&)E('-T;W)E9"!U;F1E<B!T:&4*("`@("`J('-P96-I86P@:V5Y
M=V]R9"`G7U-)1TY!5%5212<N"B`@("`@*B\*("`@(&9U;F-T:6]N('!G<%!A
M8VME=$EN9F]R;6%T:6]N*"1P9W!D871A*0H@("`@>PH@("`@("`@("1D871A
M7V%R<F%Y(#T@87)R87DH*3L*("`@("`@("`D9FEN9V5R<')I;G0@/2`G)SL*
M("`@("`@("`D:&5A9&5R(#T@;G5L;#L*("`@("`@("`D:6YP=70@/2`D=&AI
M<RT^7V-R96%T951E;7!&:6QE*"=H;W)D92UP9W`G*3L*("`@("`@("`D<VEG
M7VED(#T@)'5I9%]I9'@@/2`P.PH*("`@("`@("`O*B!3=&]R92!M97-S86=E
M(&EN('1E;7!O<F%R>2!F:6QE+B`J+PH@("`@("`@("1F<"`](&9O<&5N*"1I
M;G!U="P@)W<K)RD["B`@("`@("`@9G!U=',H)&9P+"`D<&=P9&%T82D["B`@
M("`@("`@9F-L;W-E*"1F<"D["@H@("`@("`@("1C;61L:6YE(#T@87)R87DH
M"B`@("`@("`@("`@("<M+6QI<W0M<&%C:V5T<R<L"B`@("`@("`@("`@("1I
M;G!U=`H@("`@("`@("D["B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?8V%L
M;$=P9R@D8VUD;&EN92P@)W(G*3L*"B`@("`@("`@9F]R96%C:"`H97AP;&]D
M92@B7&XB+"`D<F5S=6QT+3YS=&1O=70I(&%S("1L:6YE*2!["B`@("`@("`@
M("`@("\J($AE861E<G,@87)E('!R969A8V5D('=I=&@@82`G.B<@87,@=&AE
M(&9I<G-T(&-H87)A8W1E<B!O;B!T:&4*("`@("`@("`@("`@("`@;&EN92X@
M*B\*("`@("`@("`@("`@:68@*'-T<G!O<R@D;&EN92P@)SHG*2`]/3T@,"D@
M>PH@("`@("`@("`@("`@("`@)&QO=V5R3&EN92`](%-T<FEN9SHZ;&]W97(H
M)&QI;F4I.PH*("`@("`@("`@("`@("`@("\J($EF('=E(&AA=F4@82!K97D@
M*')A=&AE<B!T:&%N(&$@<VEG;F%T=7)E(&)L;V-K*2P@9V5T('1H90H@("`@
M("`@("`@("`@("`@("`@:V5Y)W,@9FEN9V5R<')I;G0@*B\*("`@("`@("`@
M("`@("`@(&EF("AS=')P;W,H)&QO=V5R3&EN92P@)SIP=6)L:6,@:V5Y('!A
M8VME=#HG*2`A/3T@9F%L<V4@?'P*("`@("`@("`@("`@("`@("`@("!S=')P
M;W,H)&QO=V5R3&EN92P@)SIS96-R970@:V5Y('!A8VME=#HG*2`A/3T@9F%L
M<V4I('L*("`@("`@("`@("`@("`@("`@("`D8VUD;&EN92`](&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("`@("`G+2UW:71H+6-O;&]N<R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("1I;G!U=`H@("`@("`@("`@("`@("`@("`@
M("D["B`@("`@("`@("`@("`@("`@("`@)&1A=&$@/2`D=&AI<RT^7V-A;&Q'
M<&<H)&-M9&QI;F4L("=R)RD["B`@("`@("`@("`@("`@("`@("`@:68@*'!R
M96=?;6%T8V@H(B\H<V5C?'!U8BDZ+BHZ+BHZ+BHZ*%M!+48P+3E=>S$V?2DZ
M+R(L("1D871A+3YS=&1O=70L("1M871C:&5S*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D9FEN9V5R<')I;G0@/2`D;6%T8VAE<ULR73L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`@("`@:68@*'-T<G!O<R@D;&]W97),:6YE+"`G.G!U8FQI8R!K97D@<&%C
M:V5T.B<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@("1H96%D
M97(@/2`G<'5B;&EC7VME>2<["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H
M<W1R<&]S*"1L;W=E<DQI;F4L("<Z<V5C<F5T(&ME>2!P86-K970Z)RD@(3T]
M(&9A;'-E*2!["B`@("`@("`@("`@("`@("`@("`@)&AE861E<B`]("=S96-R
M971?:V5Y)SL*("`@("`@("`@("`@("`@('T@96QS96EF("AS=')P;W,H)&QO
M=V5R3&EN92P@)SIU<V5R(&ED('!A8VME=#HG*2`A/3T@9F%L<V4I('L*("`@
M("`@("`@("`@("`@("`@("`D=6ED7VED>"LK.PH@("`@("`@("`@("`@("`@
M("`@("1L:6YE(#T@<')E9U]R97!L86-E7V-A;&QB86-K*"<O7%Q<7'@H6S`M
M.6$M9EU[,GTI+R<L(&-R96%T95]F=6YC=&EO;B@G)&$G+"`G<F5T=7)N(&-H
M<BAH97AD96,H)&%;,5TI*3LG*2P@)&QI;F4I.PH@("`@("`@("`@("`@("`@
M("`@(&EF("AP<F5G7VUA=&-H*"(O7"(H6UY</%TK*5P\*%M>7#Y=*RE</EPB
M+R(L("1L:6YE+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&AE861E<B`]("=I9"<@+B`D=6ED7VED>#L*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*'!R96=?;6%T8V@H)R\H6UY<*%TK*5PH*"XK*5PI)"\G
M+"!T<FEM*"1M871C:&5S6S%=*2P@)&-O;6UE;G1?;6%T8VAE<RDI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1D871A7V%R<F%Y6R=S:6=N871U
M<F4G75LD:&5A9&5R75LG;F%M92==(#T@=')I;2@D8V]M;65N=%]M871C:&5S
M6S%=*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D871A7V%R<F%Y
M6R=S:6=N871U<F4G75LD:&5A9&5R75LG8V]M;65N="==(#T@)&-O;6UE;G1?
M;6%T8VAE<ULR73L*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D871A7V%R<F%Y6R=S:6=N
M871U<F4G75LD:&5A9&5R75LG;F%M92==(#T@=')I;2@D;6%T8VAE<ULQ72D[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&%T85]A<G)A>5LG<VEG
M;F%T=7)E)UU;)&AE861E<EU;)V-O;6UE;G0G72`]("<G.PH@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("1D871A
M7V%R<F%Y6R=S:6=N871U<F4G75LD:&5A9&5R75LG96UA:6PG72`]("1M871C
M:&5S6S)=.PH@("`@("`@("`@("`@("`@("`@("`@("`D9&%T85]A<G)A>5LG
M<VEG;F%T=7)E)UU;)&AE861E<EU;)V9I;F=E<G!R:6YT)UT@/2`D9FEN9V5R
M<')I;G0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M?2!E;'-E:68@*'-T<G!O<R@D;&]W97),:6YE+"`G.G-I9VYA='5R92!P86-K
M970Z)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&5M
M<'1Y*"1H96%D97(I('Q\(&5M<'1Y*"1U:61?:61X*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D:&5A9&5R(#T@)U]324=.05154D4G.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H<')E9U]M
M871C:"@B+VME>6ED7',K*%LP+3E!+49=*RDO:2(L("1L:6YE+"`D;6%T8VAE
M<RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'-I9U]I9"`]("1M871C
M:&5S6S%=.PH@("`@("`@("`@("`@("`@("`@("`@("`D9&%T85]A<G)A>5LG
M<VEG;F%T=7)E)UU;)&AE861E<EU;)W-I9U\G("X@)'-I9U]I9%U;)V9I;F=E
M<G!R:6YT)UT@/2`D;6%T8VAE<ULQ73L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&1A=&%?87)R87E;)V9I;F=E<G!R:6YT)UT@/2`D;6%T8VAE<ULQ73L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("1H96%D97(@/2!N=6QL.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@:68@*"@D:&5A9&5R(#T]("=S96-R971?:V5Y)RD@?'P@*"1H96%D97(@
M/3T@)W!U8FQI8U]K97DG*2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AP
M<F5G7VUA=&-H*"(O8W)E871E9%QS*RA<9"LI+%QS*V5X<&ER97-<<RLH7&0K
M*2]I(BP@)&QI;F4L("1M871C:&5S*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D9&%T85]A<G)A>5LD:&5A9&5R75LG8W)E871E9"==(#T@)&UA=&-H
M97-;,5T["B`@("`@("`@("`@("`@("`@("`@("`@("1D871A7V%R<F%Y6R1H
M96%D97)=6R=E>'!I<F5S)UT@/2`D;6%T8VAE<ULR73L*("`@("`@("`@("`@
M("`@("`@("!](&5L<V5I9B`H<')E9U]M871C:"@B+UQS*UMS<%UK97E<6S!<
M73I<<RM<6RA<9"LI+VDB+"`D;&EN92P@)&UA=&-H97,I*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1D871A7V%R<F%Y6R1H96%D97)=6R=S:7IE)UT@
M/2`D;6%T8VAE<ULQ73L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!](&5L<V5I9B`H)&AE861E<BD@>PH@("`@("`@("`@("`@("`@
M("`@(&EF("AP<F5G7VUA=&-H*"(O=F5R<VEO;EQS*UQD*RQ<<RMC<F5A=&5D
M7',K*%QD*RDO:2(L("1L:6YE+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&1A=&%?87)R87E;)W-I9VYA='5R92==6R1H96%D97)=
M6R=S:6=?)R`N("1S:6=?:61=6R=C<F5A=&5D)UT@/2`D;6%T8VAE<ULQ73L*
M("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H<')E9U]M871C:"@B+V1I
M9V5S="!A;&=O7',K*%QD>S%]*2\B+"`D;&EN92P@)&UA=&-H97,I*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1M:6-A;&<@/2`D=&AI<RT^7VAA<VA!
M;&=;)&UA=&-H97-;,5U=.PH@("`@("`@("`@("`@("`@("`@("`@("`D9&%T
M85]A<G)A>5LG<VEG;F%T=7)E)UU;)&AE861E<EU;)W-I9U\G("X@)'-I9U]I
M9%U;)VUI8V%L9R==(#T@)&UI8V%L9SL*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"1H96%D97(@/3T@)U]324=.05154D4G*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`O*B!,:6ME;'D@82!S:6=N871U<F4@8FQO8VLL
M(&YO="!A(&ME>2X@*B\*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D
M871A7V%R<F%Y6R=S:6=N871U<F4G75LG7U-)1TY!5%5212==6R=M:6-A;&<G
M72`]("1M:6-A;&<["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"1S:6=?:60@/3T@)&9I;F=E<G!R:6YT
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O*B!396QF('-I9VYI
M;F<@<VEG;F%T=7)E("T@=V4@8V%N(&%S<W5M92!T:&4*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&UI8V%L9R!V86QU92!F<F]M('1H:7,@<VEG
M;F%T=7)E(&ES('1H870@9F]R"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!T:&4@:V5Y("HO"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M9&%T85]A<G)A>5LG<VEG;F%T=7)E)UU;)U]324=.05154D4G75LG;6EC86QG
M)UT@/2`D;6EC86QG.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A
M=&%?87)R87E;)W-I9VYA='5R92==6R1H96%D97)=6R=M:6-A;&<G72`]("1M
M:6-A;&<["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@("1F:6YG97)P<FEN="`F)B`D9&%T85]A<G)A>5LG
M9FEN9V5R<')I;G0G72`]("1F:6YG97)P<FEN=#L*"B`@("`@("`@<F5T=7)N
M("1D871A7V%R<F%Y.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!H
M=6UA;B!R96%D86)L92!I;F9O<FUA=&EO;B!O;B!A(%!'4"!K97DN"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&=P9&%T82`@5&AE(%!'4"!D871A
M(&)L;V-K+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!486)U;&%R
M(&EN9F]R;6%T:6]N(&]N('1H92!01U`@:V5Y+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!P9W!0<F5T='E+97DH)'!G<&1A=&$I"B`@("!["B`@("`@("`@)&US
M9R`]("<G.PH@("`@("`@("1P86-K971?:6YF;R`]("1T:&ES+3YP9W!086-K
M971);F9O<FUA=&EO;B@D<&=P9&%T82D["@H@("`@("`@(&EF("@A96UP='DH
M)'!A8VME=%]I;F9O6R=S:6=N871U<F4G72DI('L*("`@("`@("`@("`@+RH@
M36%K:6YG('1H92!P<F]P97)T>2!N86UE<R!T:&4@<V%M92!W:61T:"!F;W(@
M86QL"B`@("`@("`@("`@("`J(&QO8V%L:7IA=&EO;G,@+BHO"B`@("`@("`@
M("`@("1L969T<F]W(#T@87)R87DH7R@B3F%M92(I+"!?*")+97D@5'EP92(I
M+"!?*")+97D@0W)E871I;VXB*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!?*")%>'!I<F%T:6]N($1A=&4B*2P@7R@B2V5Y($QE;F=T:"(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%\H(D-O;6UE;G0B*2P@7R@B
M12U-86EL(BDL(%\H(DAA<V@M06QG;W)I=&AM(BDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@7R@B2V5Y($9I;F=E<G!R:6YT(BDI.PH@("`@("`@
M("`@("`D;&5F='=I9'1H(#T@87)R87E?;6%P*"=S=')L96XG+"`D;&5F=')O
M=RD["B`@("`@("`@("`@("1M87AW:61T:"`@/2!M87@H)&QE9G1W:61T:"D@
M*R`R.PH@("`@("`@("`@("!A<G)A>5]W86QK*"1L969T<F]W+"!C<F5A=&5?
M9G5N8W1I;VXH)R8D<RP@)&LL("1M)RP@)R1S(#T@)',@+B`B.B(@+B!S=')?
M<F5P96%T*"(@(BP@)&T@+2!3=')I;F<Z.FQE;F=T:"@D<RDI.R<I+"`D;6%X
M=VED=&@I.PH*("`@("`@("`@("`@9F]R96%C:"`H87)R87E?:V5Y<R@D<&%C
M:V5T7VEN9F];)W-I9VYA='5R92==*2!A<R`D=6ED7VED>"D@>PH@("`@("`@
M("`@("`@("`@:68@*"1U:61?:61X(#T]("=?4TE'3D%455)%)RD@8V]N=&EN
M=64["B`@("`@("`@("`@("`@("`D:V5Y7VEN9F\@/2`D=&AI<RT^<&=P4&%C
M:V5T4VEG;F%T=7)E0GE5:61);F1E>"@D<&=P9&%T82P@)'5I9%]I9'@I.PH@
M("`@("`@("`@("`@("`@)&US9R`N/2`D;&5F=')O=ULP72`N('-T<FEP8W-L
M87-H97,H)&ME>5]I;F9O6R=N86UE)UTI("X@(EQN(CL*("`@("`@("`@("`@
M("`@("1M<V<@+CT@)&QE9G1R;W=;,5T@+B`H*"1K97E?:6YF;ULG:V5Y7W1Y
M<&4G72`]/2`G<'5B;&EC7VME>2<I(#\@7R@B4'5B;&EC($ME>2(I(#H@7R@B
M4')I=F%T92!+97DB*2D@+B`B7&XB.PH@("`@("`@("`@("`@("`@)&US9R`N
M/2`D;&5F=')O=ULR72`N('-T<F9T:6UE*"(E1"(L("1K97E?:6YF;ULG:V5Y
M7V-R96%T960G72D@+B`B7&XB.PH@("`@("`@("`@("`@("`@)&US9R`N/2`D
M;&5F=')O=ULS72`N("AE;7!T>2@D:V5Y7VEN9F];)VME>5]E>'!I<F5S)UTI
M(#\@)ULG("X@7R@B3F5V97(B*2`N("==)R`Z('-T<F9T:6UE*"(E1"(L("1K
M97E?:6YF;ULG:V5Y7V5X<&ER97,G72DI("X@(EQN(CL*("`@("`@("`@("`@
M("`@("1M<V<@+CT@)&QE9G1R;W=;-%T@+B`D:V5Y7VEN9F];)VME>5]S:7IE
M)UT@+B`B($)Y=&5S7&XB.PH@("`@("`@("`@("`@("`@)&US9R`N/2`D;&5F
M=')O=ULU72`N("AE;7!T>2@D:V5Y7VEN9F];)V-O;6UE;G0G72D@/R`G6R<@
M+B!?*").;VYE(BD@+B`G72<@.B`D:V5Y7VEN9F];)V-O;6UE;G0G72D@+B`B
M7&XB.PH@("`@("`@("`@("`@("`@)&US9R`N/2`D;&5F=')O=ULV72`N("1K
M97E?:6YF;ULG96UA:6PG72`N(")<;B(["B`@("`@("`@("`@("`@("`D;7-G
M("X]("1L969T<F]W6S==("X@*&5M<'1Y*"1K97E?:6YF;ULG;6EC86QG)UTI
M(#\@)ULG("X@7R@B56YK;F]W;B(I("X@)UTG(#H@)&ME>5]I;F9O6R=M:6-A
M;&<G72D@+B`B7&XB.PH@("`@("`@("`@("`@("`@)&US9R`N/2`D;&5F=')O
M=ULX72`N("AE;7!T>2@D:V5Y7VEN9F];)V9I;F=E<G!R:6YT)UTI(#\@)ULG
M("X@7R@B56YK;F]W;B(I("X@)UTG(#H@)&ME>5]I;F9O6R=F:6YG97)P<FEN
M="==*2`N(")<;EQN(CL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1M<V<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M(&]N;'D@:6YF;W)M871I;VX@;VX@=&AE(&9I<G-T($E$('1H870@;6%T8VAE
M<R!T:&4@96UA:6P@861D<F5S<PH@("`@("H@:6YP=70N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<&=P9&%T82`@5&AE(%!'4"!D871A(&)L;V-K
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D96UA:6P@("`@06X@92UM86EL(&%D
M9')E<W,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@
M=VET:"!I;F9O<FUA=&EO;B!O;B!T:&4@4$=0(&1A=&$@8FQO8VLN($EF(&%N
M"B`@("`@*B`@("`@("`@("`@("`@("!E;&5M96YT(&ES(&YO="!P<F5S96YT
M(&EN('1H92!D871A(&)L;V-K+"!I="!W:6QL"B`@("`@*B`@("`@("`@("`@
M("`@("!L:6ME=VES92!N;W0@8F4@<V5T(&EN('1H92!A<G)A>2X*("`@("`J
M(#QP<F4^"B`@("`@*B!!<G)A>2!&:65L9',Z"B`@("`@*B`M+2TM+2TM+2TM
M+2TM"B`@("`@*B!K97E?8W)E871E9"`@/3X@($ME>2!C<F5A=&EO;B`M(%5.
M25@@=&EM97-T86UP"B`@("`@*B!K97E?97AP:7)E<R`@/3X@($ME>2!E>'!I
M<F%T:6]N("T@54Y)6"!T:6UE<W1A;7`@*#`@/2!N979E<B!E>'!I<F5S*0H@
M("`@("H@:V5Y7W-I>F4@("`@(#T^("!3:7IE(&]F('1H92!K97D@:6X@8FET
M<PH@("`@("H@:V5Y7W1Y<&4@("`@(#T^("!4:&4@:V5Y('1Y<&4@*'!U8FQI
M8U]K97D@;W(@<V5C<F5T7VME>2D*("`@("`J(&YA;64@("`@("`@("`]/B`@
M1G5L;"!.86UE"B`@("`@*B!C;VUM96YT("`@("`@/3X@($-O;6UE;G0*("`@
M("`J(&5M86EL("`@("`@("`]/B`@12UM86EL($%D9')E<W,*("`@("`J(&9I
M;F=E<G!R:6YT("`]/B`@,38M8FET(&AE>"!V86QU90H@("`@("H@8W)E871E
M9"`@("`@(#T^("!3:6=N871U<F4@8W)E871I;VX@+2!53DE8('1I;65S=&%M
M<`H@("`@("H@;6EC86QG("`@("`@(#T^("!4:&4@:&%S:"!U<V5D('1O(&-R
M96%T92!T:&4@<VEG;F%T=7)E"B`@("`@*B`\+W!R93X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<&=P4&%C:V5T4VEG;F%T=7)E*"1P9W!D871A+"`D96UA:6PI
M"B`@("!["B`@("`@("`@)&1A=&$@/2`D=&AI<RT^<&=P4&%C:V5T26YF;W)M
M871I;VXH)'!G<&1A=&$I.PH@("`@("`@("1K97E?='EP92`](&YU;&P["B`@
M("`@("`@)')E='5R;E]A<G)A>2`](&%R<F%Y*"D["@H@("`@("`@("\J($-H
M96-K('1H870@6W-I9VYA='5R95T@:V5Y(&5X:7-T<RX@*B\*("`@("`@("!I
M9B`H(6ES<V5T*"1D871A6R=S:6=N871U<F4G72DI('L*("`@("`@("`@("`@
M<F5T=7)N("1R971U<FY?87)R87D["B`@("`@("`@?0H*("`@("`@("`O*B!3
M=&]R92!T:&4@<VEG;F%T=7)E(&EN9F]R;6%T:6]N(&YO=RX@*B\*("`@("`@
M("!I9B`H*"1E;6%I;"`]/2`G7U-)1TY!5%5212<I("8F"B`@("`@("`@("`@
M(&ES<V5T*"1D871A6R=S:6=N871U<F4G75LG7U-)1TY!5%5212==*2D@>PH@
M("`@("`@("`@("!F;W)E86-H("@D9&%T85LG<VEG;F%T=7)E)UU;)&5M86EL
M72!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("`@("`@)')E='5R
M;E]A<G)A>5LD:V5Y72`]("1V86QU93L*("`@("`@("`@("`@?0H@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1U:61?:61X(#T@,3L*"B`@("`@("`@
M("`@('=H:6QE("AI<W-E="@D9&%T85LG<VEG;F%T=7)E)UU;)VED)R`N("1U
M:61?:61X72DI('L*("`@("`@("`@("`@("`@(&EF("@D9&%T85LG<VEG;F%T
M=7)E)UU;)VED)R`N("1U:61?:61X75LG96UA:6PG72`]/2`D96UA:6PI('L*
M("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D9&%T85LG<VEG;F%T=7)E
M)UU;)VED)R`N("1U:61?:61X72!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)')E='5R;E]A<G)A>5LD:V5Y72`]("1V86P[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'5I9%]I
M9'@K*SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?<&=P4&%C:V5T4VEG;F%T=7)E*"1D871A+"`D<F5T=7)N7V%R
M<F%Y*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@:6YF;W)M871I
M;VX@;VX@82!01U`@<VEG;F%T=7)E(&5M8F5D9&5D(&EN(%!'4"!D871A+B`@
M4VEM:6QA<@H@("`@("H@=&\@<&=P4&%C:V5T4VEG;F%T=7)E*"DL(&)U="!R
M971U<FYS(&EN9F]R;6%T:6]N(&)Y('5N:7%U92!5<V5R($E$"B`@("`@*B!)
M;F1E>"`H9F]R;6%T(&ED>VY]('=H97)E(&X@:7,@86X@:6YT96=E<B!O9B`Q
M(&]R(&=R96%T97(I+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!G
M<&1A=&$@("!3964@<&=P4&%C:V5T4VEG;F%T=7)E*"DN"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D=6ED7VED>"`@5&AE(%5)1"!I;F1E>"X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y("!3964@<&=P4&%C:V5T4VEG;F%T=7)E*"DN
M"B`@("`@*B\*("`@(&9U;F-T:6]N('!G<%!A8VME=%-I9VYA='5R94)Y56ED
M26YD97@H)'!G<&1A=&$L("1U:61?:61X*0H@("`@>PH@("`@("`@("1D871A
M(#T@)'1H:7,M/G!G<%!A8VME=$EN9F]R;6%T:6]N*"1P9W!D871A*3L*("`@
M("`@("`D:V5Y7W1Y<&4@/2!N=6QL.PH@("`@("`@("1R971U<FY?87)R87D@
M/2!A<G)A>2@I.PH*("`@("`@("`O*B!396%R8V@@9F]R('1H92!5240@:6YD
M97@N("HO"B`@("`@("`@:68@*"%I<W-E="@D9&%T85LG<VEG;F%T=7)E)UTI
M('Q\"B`@("`@("`@("`@("%I<W-E="@D9&%T85LG<VEG;F%T=7)E)UU;)'5I
M9%]I9'A=*2D@>PH@("`@("`@("`@("!R971U<FX@)')E='5R;E]A<G)A>3L*
M("`@("`@("!]"@H@("`@("`@("\J(%-T;W)E('1H92!S:6=N871U<F4@:6YF
M;W)M871I;VX@;F]W+B`J+PH@("`@("`@(&9O<F5A8V@@*"1D871A6R=S:6=N
M871U<F4G75LD=6ED7VED>%T@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@
M("`@("`@)')E='5R;E]A<G)A>5LD:V5Y72`]("1V86QU93L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D=&AI<RT^7W!G<%!A8VME=%-I9VYA='5R92@D
M9&%T82P@)')E='5R;E]A<G)A>2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!
M9&1S('-O;64@9&%T82!T;R!T:&4@<&=P4&%C:V5T4VEG;F%T=7)E*B@I(&9U
M;F-T:6]N(&%R<F%Y+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D9&%T82`@("`@(%-E92!P9W!0
M86-K9713:6=N871U<F4H*2X*("`@("`J($!P87)A;2!A<G)A>2`D<F5T87)R
M87D@(%1H92!R971U<FX@87)R87DN"B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>2`@5&AE(')E='5R;B!A<G)A>2X*("`@("`J+PH@("`@9G5N8W1I;VX@
M7W!G<%!A8VME=%-I9VYA='5R92@D9&%T82P@)')E=&%R<F%Y*0H@("`@>PH@
M("`@("`@("\J($EF(&5M<'1Y+"!R971U<FX@;F]W+B`J+PH@("`@("`@(&EF
M("AE;7!T>2@D<F5T87)R87DI*2!["B`@("`@("`@("`@(')E='5R;B`D<F5T
M87)R87D["B`@("`@("`@?0H*("`@("`@("`D:V5Y7W1Y<&4@/2!N=6QL.PH*
M("`@("`@("`O*B!3=&]R92!A;GD@<'5B;&EC+W!R:79A=&4@:V5Y(&EN9F]R
M;6%T:6]N+B`J+PH@("`@("`@(&EF("AI<W-E="@D9&%T85LG<'5B;&EC7VME
M>2==*2D@>PH@("`@("`@("`@("`D:V5Y7W1Y<&4@/2`G<'5B;&EC7VME>2<[
M"B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1D871A6R=S96-R971?:V5Y)UTI
M*2!["B`@("`@("`@("`@("1K97E?='EP92`]("=S96-R971?:V5Y)SL*("`@
M("`@("!]"@H@("`@("`@(&EF("@D:V5Y7W1Y<&4I('L*("`@("`@("`@("`@
M)')E=&%R<F%Y6R=K97E?='EP92==(#T@)&ME>5]T>7!E.PH@("`@("`@("`@
M("!I9B`H:7-S970H)&1A=&%;)&ME>5]T>7!E75LG8W)E871E9"==*2D@>PH@
M("`@("`@("`@("`@("`@)')E=&%R<F%Y6R=K97E?8W)E871E9"==(#T@)&1A
M=&%;)&ME>5]T>7!E75LG8W)E871E9"==.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&EF("AI<W-E="@D9&%T85LD:V5Y7W1Y<&5=6R=E>'!I<F5S)UTI
M*2!["B`@("`@("`@("`@("`@("`D<F5T87)R87E;)VME>5]E>'!I<F5S)UT@
M/2`D9&%T85LD:V5Y7W1Y<&5=6R=E>'!I<F5S)UT["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@:68@*&ES<V5T*"1D871A6R1K97E?='EP95U;)W-I>F4G
M72DI('L*("`@("`@("`@("`@("`@("1R971A<G)A>5LG:V5Y7W-I>F4G72`]
M("1D871A6R1K97E?='EP95U;)W-I>F4G73L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1R971A<G)A>3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE('-H;W)T(&9I;F=E<G!R:6YT("A+97D@
M240I(&]F('1H92!K97D@=7-E9"!T;R!S:6=N(&$@8FQO8VL*("`@("`J(&]F
M(%!'4"!D871A+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@
M(%1H92!01U`@<VEG;F5D('1E>'0@8FQO8VLN"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!S:&]R="!F:6YG97)P<FEN="!O9B!T:&4@:V5Y
M('5S960@=&\@<VEG;B`D=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M4VEG;F5R<T9I;F=E<G!R:6YT*"1T97AT*0H@("`@>PH@("`@("`@("1F:6YG
M97)P<FEN="`](&YU;&P["@H@("`@("`@("1I;G!U="`]("1T:&ES+3Y?8W)E
M871E5&5M<$9I;&4H)VAO<F1E+7!G<"<I.PH*("`@("`@("`D9G`@/2!F;W!E
M;B@D:6YP=70L("=W*R<I.PH@("`@("`@(&9P=71S*"1F<"P@)'1E>'0I.PH@
M("`@("`@(&9C;&]S92@D9G`I.PH*("`@("`@("`D8VUD;&EN92`](&%R<F%Y
M*`H@("`@("`@("`@("`G+2UV97)I9GDG+`H@("`@("`@("`@("`D:6YP=70L
M"B`@("`@("`@("`@("<R/B8Q)PH@("`@("`@("D["B`@("`@("`@)')E<W5L
M="`]("1T:&ES+3Y?8V%L;$=P9R@D8VUD;&EN92P@)W(G*3L*("`@("`@("!I
M9B`H<')E9U]M871C:"@G+V=P9SI<<U-I9VYA='5R95QS;6%D92XJ241<<RLH
M6T$M1C`M.5U[.'TI7',K+R<L("1R97-U;'0M/G-T9&]U="P@)&UA=&-H97,I
M*2!["B`@("`@("`@("`@("1F:6YG97)P<FEN="`]("1M871C:&5S6S%=.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1F:6YG97)P<FEN=#L*("`@('T*
M"B`@("`O*BH*("`@("`J(%9E<FEF>2!A('!A<W-P:')A<V4@9F]R(&$@9VEV
M96X@<'5B;&EC+W!R:79A=&4@:V5Y<&%I<BX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1P=6)L:6-?:V5Y("`@5&AE('5S97(G<R!01U`@<'5B;&EC
M(&ME>2X*("`@("`J($!P87)A;2!S=')I;F<@)'!R:79A=&5?:V5Y("!4:&4@
M=7-E<B=S(%!'4"!P<FEV871E(&ME>2X*("`@("`J($!P87)A;2!S=')I;F<@
M)'!A<W-P:')A<V4@("!4:&4@=7-E<B=S('!A<W-P:')A<V4N"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N("!2971U<FYS('1R=64@;VX@=F%L:60@
M<&%S<W!H<F%S92P@9F%L<V4@;VX@:6YV86QI9`H@("`@("H@("`@("`@("`@
M("`@("`@("!P87-S<&AR87-E+"!A;F0@4$5!4E]%<G)O<B!O;B!E<G)O<BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@=F5R:69Y4&%S<W!H<F%S92@D<'5B;&EC
M7VME>2P@)'!R:79A=&5?:V5Y+"`D<&%S<W!H<F%S92D*("`@('L*("`@("`@
M("`O*B!#:&5C:R!F;W(@<V5C=7)E(&-O;FYE8W1I;VXN("HO"B`@("`@("`@
M)'-E8W5R95]C:&5C:R`]("1T:&ES+3YR97%U:7)E4V5C=7)E0V]N;F5C=&EO
M;B@I.PH@("`@("`@(&EF("AI<U]A*"1S96-U<F5?8VAE8VLL("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1S96-U<F5?8VAE8VL["B`@
M("`@("`@?0H*("`@("`@("`O*B!%;F-R>7!T(&$@=&5S="!M97-S86=E+B`J
M+PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^96YC<GEP="@G5&5S="<L(&%R
M<F%Y*"=T>7!E)R`]/B`G;65S<V%G92<L("=P=6)K97DG(#T^("1P=6)L:6-?
M:V5Y*2D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("`O*B!4<GD@=&\@9&5C<GEP="!T:&4@;65S<V%G92X@*B\*("`@("`@
M("`D<F5S=6QT(#T@)'1H:7,M/F1E8W)Y<'0H)')E<W5L="P@87)R87DH)W1Y
M<&4G(#T^("=M97-S86=E)RP@)W!U8FME>2<@/3X@)'!U8FQI8U]K97DL("=P
M<FEV:V5Y)R`]/B`D<')I=F%T95]K97DL("=P87-S<&AR87-E)R`]/B`D<&%S
M<W!H<F%S92DI.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!0
M87)S97,@82!M97-S86=E(&EN=&\@=&5X="!A;F0@4$=0(&-O;7!O;F5N=',N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@5&AE('1E>'0@
M=&\@<&%R<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R
M87D@=VET:"!T:&4@<&%R<V5D('1E>'0L(')E='5R;F5D(&EN(&)L;V-K<R!O
M9@H@("`@("H@("`@("`@("`@("`@("`@=&5X="!C;W)R97-P;VYD:6YG('1O
M('1H96ER(&%C='5A;"!O<F1E<BX*("`@("`J(#QP<F4^"B`@("`@*B!2971U
M<FX@87)R87DZ"B`@("`@*B!+97D@("`@("`@("!686QU90H@("`@("H@+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+0H@("`@("H@)W1Y<&4G("`]/B`@5&AE('1Y<&4@;V8@9&%T82!C;VYT86EN
M960@:6X@8FQO8VLN"B`@("`@*B`@("`@("`@("`@("!686QI9"!T>7!E<R!A
M<F4@9&5F:6YE9"!A="!T:&4@=&]P(&]F('1H:7,@8VQA<W,*("`@("`J("`@
M("`@("`@("`@("AT:&4@4$=07T%234]27RH@8V]N<W1A;G1S*2X*("`@("`J
M("=D871A)R`@/3X@(%1H92!A8W1U86P@9&%T82!F;W(@96%C:"!S96-T:6]N
M+@H@("`@("H@/"]P<F4^"B`@("`@*B\*("`@(&9U;F-T:6]N('!A<G-E4$=0
M1&%T82@D=&5X="D*("`@('L*("`@("`@("`D9&%T82`](&%R<F%Y*"D["@H@
M("`@("`@("1B=69F97(@/2!E>'!L;V1E*")<;B(L("1T97AT*3L*"B`@("`@
M("`@+RH@4V5T("1T96UP7V%R<F%Y('1O(&)E(&]F('1Y<&4@4$=07T%234]2
M7U1%6%0N("HO"B`@("`@("`@)'1E;7!?87)R87D@/2!A<G)A>2@I.PH@("`@
M("`@("1T96UP7V%R<F%Y6R=T>7!E)UT@/2!01U!?05)-3U)?5$585#L*"B`@
M("`@("`@9F]R96%C:"`H)&)U9F9E<B!A<R`D=F%L=64I('L*("`@("`@("`@
M("`@:68@*'!R96=?;6%T8V@H)R]>+2TM+2TH0D5'24Y\14Y$*2!01U`@*%M>
M+5TK*2TM+2TM7',J)"\G+"`D=F%L=64L("1M871C:&5S*2D@>PH@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1T96UP7V%R<F%Y6R=D871A)UTI*2!["B`@
M("`@("`@("`@("`@("`@("`@)&1A=&%;72`]("1T96UP7V%R<F%Y.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@=6YS970H)'1E;7!?87)R
M87DI.PH@("`@("`@("`@("`@("`@)'1E;7!?87)R87D@/2!A<G)A>2@I.PH*
M("`@("`@("`@("`@("`@(&EF("@D;6%T8VAE<ULQ72`]/3T@)T)%1TE.)RD@
M>PH@("`@("`@("`@("`@("`@("`@("1T96UP7V%R<F%Y6R=T>7!E)UT@/2`D
M=&AI<RT^7V%R;6]R6R1M871C:&5S6S)=73L*("`@("`@("`@("`@("`@("`@
M("`D=&5M<%]A<G)A>5LG9&%T82==6UT@/2`D=F%L=64["B`@("`@("`@("`@
M("`@("!](&5L<V5I9B`H)&UA=&-H97-;,5T@/3T]("=%3D0G*2!["B`@("`@
M("`@("`@("`@("`@("`@)'1E;7!?87)R87E;)W1Y<&4G72`](%!'4%]!4DU/
M4E]415A4.PH@("`@("`@("`@("`@("`@("`@("1D871A6V-O=6YT*"1D871A
M*2`M(#%=6R=D871A)UU;72`]("1V86QU93L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T96UP7V%R
M<F%Y6R=D871A)UU;72`]("1V86QU93L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@:68@*&ES<V5T*"1T96UP7V%R<F%Y6R=D871A)UTI*2![
M"B`@("`@("`@("`@("1D871A6UT@/2`D=&5M<%]A<G)A>3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D9&%T83L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@82!01U`@<'5B;&EC(&ME>2!F<F]M(&$@<'5B;&EC(&ME>7-E
M<G9E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F<')I;G0@(%1H
M92!F:6YG97)P<FEN="!O9B!T:&4@4$=0(&ME>2X*("`@("`J($!P87)A;2!S
M=')I;F<@)'-E<G9E<B`@5&AE(&ME>7-E<G9E<B!T;R!U<V4N"B`@("`@*B!`
M<&%R86T@9FQO870@)'1I;65O=70@(%1H92!K97ES97)V97(@=&EM96]U="X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(%!'4"!P=6)L:6,@
M:V5Y+"!O<B!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G9710=6)L:6-+97ES97)V97(H)&9P<FEN="P@)'-E<G9E<B`](%!'
M4%]+15E315)615)?4%5"3$E#+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:6UE;W5T(#T@4$=07TM%65-%4E9%4E]424U%3U54*0H@("`@
M>PH@("`@("`@("\J($=E="!T:&4@."!C:&%R86-T97(@9FEN9V5R<')I;G0@
M<W1R:6YG+B`J+PH@("`@("`@(&EF("AS=')P;W,H)&9P<FEN="P@)S!X)RD@
M/3T](#`I('L*("`@("`@("`@("`@)&9P<FEN="`]('-U8G-T<B@D9G!R:6YT
M+"`R*3L*("`@("`@("!]"B`@("`@("`@:68@*'-T<FQE;B@D9G!R:6YT*2`^
M(#@I('L*("`@("`@("`@("`@)&9P<FEN="`]('-U8G-T<B@D9G!R:6YT+"`X
M*3L*("`@("`@("!]"B`@("`@("`@)&9P<FEN="`]("<P>"<@+B`D9G!R:6YT
M.PH*("`@("`@("`O*B!#;VYN96-T('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R
M+B`J+PH@("`@("`@("1C;60@/2`G1T54("]P:W,O;&]O:W5P/V]P/6=E="9E
M>&%C=#UO;B9S96%R8V@])R`N("1F<')I;G0@+B`G($A45%`O,2XP)SL*("`@
M("`@("`D;W5T<'5T(#T@)'1H:7,M/E]C;VYN96-T2V5Y<V5R=F5R*"1C;60L
M("1S97)V97(L("1T:6UE;W5T*3L*("`@("`@("!I9B`H:7-?82@D;W5T<'5T
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D;W5T<'5T
M.PH@("`@("`@('T*"B`@("`@("`@+RH@4W1R:7`@2%1-3"!486=S(&9R;VT@
M;W5T<'5T+B`J+PH@("`@("`@(&EF("@H)'-T87)T(#T@<W1R<W1R*"1O=71P
M=70L("<M+2TM+4)%1TE.)RDI*2!["B`@("`@("`@("`@("1L96YG=&@@/2!S
M=')P;W,H)'-T87)T+"`G+2TM+2U%3D0G*2`K(#,T.PH@("`@("`@("`@("!R
M971U<FX@<W5B<W1R*"1S=&%R="P@,"P@)&QE;F=T:"D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E
M<BXB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@4V5N9',@82!01U`@<'5B;&EC(&ME>2!T;R!A('!U8FQI8R!K
M97ES97)V97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<'5B:V5Y
M("!4:&4@4$=0('!U8FQI8R!K97D*("`@("`J($!P87)A;2!S=')I;F<@)'-E
M<G9E<B`@5&AE(&ME>7-E<G9E<B!T;R!U<V4N"B`@("`@*B!`<&%R86T@9FQO
M870@)'1I;65O=70@(%1H92!K97ES97)V97(@=&EM96]U="X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(%!%05)?17)R;W(@(%!%05)?17)R;W(@;VX@97)R;W(O
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<'5T4'5B;&EC2V5Y<V5R
M=F5R*"1P=6)K97DL("1S97)V97(@/2!01U!?2T594T525D527U!50DQ)0RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&EM96]U="`](%!'
M4%]+15E315)615)?5$E-14]55"D*("`@('L*("`@("`@("`O*B!'970@=&AE
M(&9I;F=E<G!R:6YT(&]F('1H92!P=6)L:6,@:V5Y+B`J+PH@("`@("`@("1I
M;F9O(#T@)'1H:7,M/G!G<%!A8VME=$EN9F]R;6%T:6]N*"1P=6)K97DI.PH*
M("`@("`@("`O*B!3964@:68@=&AE('!U8FQI8R!K97D@86QR96%D>2!E>&ES
M=',@;VX@=&AE(&ME>7-E<G9E<BX@*B\*("`@("`@("!I9B`H(6ES7V$H)'1H
M:7,M/F=E=%!U8FQI8TME>7-E<G9E<B@D:6YF;ULG9FEN9V5R<')I;G0G72P@
M)'-E<G9E<BP@)'1I;65O=70I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DME>2!A;')E861Y(&5X
M:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB*2P@)VAO<F1E+G=A<FYI
M;F<G*3L*("`@("`@("!]"@H@("`@("`@("\J($-O;FYE8W0@=&\@=&AE('!U
M8FQI8R!K97ES97)V97(N(%]C;VYN96-T2V5Y<V5R=F5R*"D@<F5T=7)N<R!A
M"B`@("`@("`@("`@4$5!4E]%<G)O<B!O8FIE8W0@;VX@97)R;W(@86YD('1H
M92!O=71P=70@=&5X="!O;B!S=6-C97-S+B`J+PH@("`@("`@("1P=6)K97D@
M/2`G:V5Y=&5X=#TG("X@=7)L96YC;V1E*')T<FEM*"1P=6)K97DI*3L*("`@
M("`@("`D8VUD(#T@87)R87DH"B`@("`@("`@("`@("=03U-4("]P:W,O861D
M($A45%`O,2XP)RP*("`@("`@("`@("`@)TAO<W0Z("<@+B`D<V5R=F5R("X@
M)SHQ,3,W,2<L"B`@("`@("`@("`@("=5<V5R+4%G96YT.B!(;W)D92!!<'!L
M:6-A=&EO;B!&<F%M97=O<FL@,RXQ)RP*("`@("`@("`@("`@)T-O;G1E;G0M
M5'EP93H@87!P;&EC871I;VXO>"UW=W<M9F]R;2UU<FQE;F-O9&5D)RP*("`@
M("`@("`@("`@)T-O;G1E;G0M3&5N9W1H.B`G("X@<W1R;&5N*"1P=6)K97DI
M+`H@("`@("`@("`@("`G0V]N;F5C=&EO;CH@8VQO<V4G+`H@("`@("`@("`@
M("`G)RP*("`@("`@("`@("`@)'!U8FME>0H@("`@("`@("D["B`@("`@("`@
M)')E<W5L="`]("1T:&ES+3Y?8V]N;F5C=$ME>7-E<G9E<BAI;7!L;V1E*")<
M<EQN(BP@)&-M9"DL("1S97)V97(L("1T:6UE;W5T*3L*("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($-O;FYE8W1S('1O(&$@<'5B;&EC(&ME>2!S97)V97(@=FEA($A+4"`H2&]R
M<F]W:71Z($ME>7-E<G9E<B!0<F]T;V-O;"DN"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]M
M;6%N9"`@5&AE(%!'4"!C;VUM86YD('1O(')U;BX*("`@("`J($!P87)A;2!S
M=')I;F<@)'-E<G9E<B`@(%1H92!K97ES97)V97(@=&\@=7-E+@H@("`@("H@
M0'!A<F%M(&9L;V%T("1T:6UE;W5T("`@5&AE('1I;65O=70@=F%L=64N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!T97AT(&9R;VT@<W1A
M;F1A<F0@;W5T<'5T(&]N('-U8V-E<W,L(&]R(%!%05)?17)R;W(*("`@("`J
M("`@("`@("`@("`@("`@("!O;B!E<G)O<B]F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?8V]N;F5C=$ME>7-E<G9E<B@D8V]M;6%N9"P@)'-E<G9E
M<BP@)'1I;65O=70I"B`@("!["B`@("`@("`@)&-O;FY2969U<V4@/2`P.PH@
M("`@("`@("1O=71P=70@/2`G)SL*"B`@("`@("`@+RH@071T96UP="!T;R!G
M970@=&AE(&ME>2!F<F]M('1H92!K97ES97)V97(N("HO"B`@("`@("`@9&\@
M>PH@("`@("`@("`@("`D8V]N;D5R<F]R(#T@9F%L<V4["B`@("`@("`@("`@
M("1E<G)N;R`]("1E<G)S='(@/2!N=6QL.PH*("`@("`@("`@("`@+RH@5&AE
M($A+4"!S97)V97(@:7,@;&]C871E9"!O;B!P;W)T(#$Q,S<Q+B`J+PH@("`@
M("`@("`@("`D9G`@/2!`9G-O8VMO<&5N*"1S97)V97(L("<Q,3,W,2<L("1E
M<G)N;RP@)&5R<G-T<BP@)'1I;65O=70I.PH@("`@("`@("`@("!I9B`H(21F
M<"D@>PH@("`@("`@("`@("`@("`@)&-O;FY%<G)O<B`]('1R=64["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!F<'5T<R@D9G`L("1C
M;VUM86YD("X@(EQN7&XB*3L*("`@("`@("`@("`@("`@('=H:6QE("@A9F5O
M9B@D9G`I*2!["B`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2!F9V5T
M<R@D9G`L(#$P,C0I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@9F-L;W-E*"1F<"D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF
M("@D8V]N;D5R<F]R*2!["B`@("`@("`@("`@("`@("!I9B`H*RLD8V]N;E)E
M9G5S92`]/3T@4$=07TM%65-%4E9%4E]214954T4I('L*("`@("`@("`@("`@
M("`@("`@("!I9B`H)&5R<FYO(#T](#`I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&]U='!U="`](%!%05(Z.G)A:7-E17)R;W(H7R@B0V]N;F5C=&EO
M;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(I+"`G:&]R9&4N
M97)R;W(G*3L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D;W5T<'5T(#T@4$5!4CHZ<F%I<V5%<G)O<BAS
M<')I;G1F*%\H(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME
M>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I(BDL(%-T<FEN9SHZ8V]N=F5R=$-H
M87)S970H)&5R<G-T<BP@3DQ3.CIG971%>'1E<FYA;$-H87)S970H*2DL("1E
M<G)N;RDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@('T@=VAI;&4@*"1C;VYN17)R;W(I.PH*
M("`@("`@("!R971U<FX@)&]U='!U=#L*("`@('T*"B`@("`O*BH*("`@("`J
M($5N8W)Y<'1S('1E>'0@=7-I;F<@4$=0+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'1E>'0@("!4:&4@=&5X="!T;R!B92!01U`@96YC<GEP=&5D
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@(%1H92!P87)A;65T97)S
M(&YE961E9"!F;W(@96YC<GEP=&EO;BX*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!3964@=&AE(&EN9&EV:61U86P@7V5N8W)Y<'0J*"D@9G5N8W1I
M;VYS(&9O<B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!P87)A
M;65T97(@<F5Q=6ER96UE;G1S+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@96YC<GEP=&5D(&UE<W-A9V4L(&]R(%!%05)?17)R;W(@;VX@
M97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N8W)Y<'0H)'1E>'0L("1P
M87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D<&%R
M86US6R=T>7!E)UTI*2!["B`@("`@("`@("`@(&EF("@D<&%R86US6R=T>7!E
M)UT@/3T]("=M97-S86=E)RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?96YC<GEP=$UE<W-A9V4H)'1E>'0L("1P87)A;7,I.PH@("`@("`@
M("`@("!](&5L<V5I9B`H)'!A<F%M<ULG='EP92==(#T]/2`G<VEG;F%T=7)E
M)RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?96YC<GEP=%-I
M9VYA='5R92@D=&5X="P@)'!A<F%M<RD["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96-R>7!T<R!T97AT('5S:6YG
M(%!'4"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("`@5&AE
M('1E>'0@=&\@8F4@4$=0(&1E8W)Y<'1E9"X*("`@("`J($!P87)A;2!A<G)A
M>2`D<&%R86US("!4:&4@<&%R86UE=&5R<R!N965D960@9F]R(&1E8W)Y<'1I
M;VXN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@4V5E('1H92!I;F1I
M=FED=6%L(%]D96-R>7!T*B@I(&9U;F-T:6]N<R!F;W(@=&AE"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@<&%R86UE=&5R(')E<75I<F5M96YT<RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&1E8W)Y<'1E9"!M
M97-S86=E+"!O<B!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!D96-R>7!T*"1T97AT+"`D<&%R86US(#T@87)R87DH*2D*("`@
M('L*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG='EP92==*2D@>PH@("`@
M("`@("`@("!I9B`H)'!A<F%M<ULG='EP92==(#T]/2`G;65S<V%G92<I('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1E8W)Y<'1-97-S86=E
M*"1T97AT+"`D<&%R86US*3L*("`@("`@("`@("`@?2!E;'-E:68@*"@D<&%R
M86US6R=T>7!E)UT@/3T]("=S:6=N871U<F4G*2!\?`H@("`@("`@("`@("`@
M("`@("`@("`@*"1P87)A;7-;)W1Y<&4G72`]/3T@)V1E=&%C:&5D+7-I9VYA
M='5R92<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]D96-R
M>7!T4VEG;F%T=7)E*"1T97AT+"`D<&%R86US*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@82!T96UP
M;W)A<GD@9W!G(&ME>7)I;F<N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@5&AE('1Y
M<&4@;V8@:V5Y('1O(&%N86QY>F4N($5I=&AE<B`G<'5B;&EC)PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@*$1E9F%U;'0I(&]R("=P<FEV871E)PH@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!#;VUM86YD(&QI;F4@:V5Y
M<W1R:6YG(&]P=&EO;B!T;R!U<V4@=VET:"!G<&<@<')O9W)A;2X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V-R96%T94ME>7)I;F<H)'1Y<&4@/2`G<'5B;&EC
M)RD*("`@('L*("`@("`@("`D='EP92`](%-T<FEN9SHZ;&]W97(H)'1Y<&4I
M.PH*("`@("`@("!I9B`H)'1Y<&4@/3T]("=P=6)L:6,G*2!["B`@("`@("`@
M("`@(&EF("AE;7!T>2@D=&AI<RT^7W!U8FQI8TME>7)I;F<I*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!U8FQI8TME>7)I;F<@/2`D=&AI<RT^7V-R
M96%T951E;7!&:6QE*"=H;W)D92UP9W`G*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!R971U<FX@)RTM:V5Y<FEN9R`G("X@)'1H:7,M/E]P=6)L:6-+
M97ER:6YG.PH@("`@("`@('T@96QS96EF("@D='EP92`]/3T@)W!R:79A=&4G
M*2!["B`@("`@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W!R:79A=&5+97ER
M:6YG*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P<FEV871E2V5Y<FEN
M9R`]("1T:&ES+3Y?8W)E871E5&5M<$9I;&4H)VAO<F1E+7!G<"<I.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`G+2US96-R970M:V5Y<FEN
M9R`G("X@)'1H:7,M/E]P<FEV871E2V5Y<FEN9SL*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!9&1S(%!'4"!K97ES('1O('1H92!K97ER:6YG
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!P87)A;2!M:7AE9"`D:V5Y<R`@($$@<VEN9VQE(&ME>2!O<B!A;B!A<G)A
M>2!O9B!K97DH<RD@=&\@861D('1O('1H90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@:V5Y<FEN9RX*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@
M(%1H92!T>7!E(&]F(&ME>2AS*2!T;R!A9&0N($5I=&AE<B`G<'5B;&EC)PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@*$1E9F%U;'0I(&]R("=P<FEV
M871E)PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!#;VUM86YD(&QI
M;F4@:V5Y<W1R:6YG(&]P=&EO;B!T;R!U<V4@=VET:"!G<&<@<')O9W)A;2X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7W!U=$EN2V5Y<FEN9R@D:V5Y<R`](&%R
M<F%Y*"DL("1T>7!E(#T@)W!U8FQI8R<I"B`@("!["B`@("`@("`@)'1Y<&4@
M/2!3=')I;F<Z.FQO=V5R*"1T>7!E*3L*"B`@("`@("`@:68@*"%I<U]A<G)A
M>2@D:V5Y<RDI('L*("`@("`@("`@("`@)&ME>7,@/2!A<G)A>2@D:V5Y<RD[
M"B`@("`@("`@?0H*("`@("`@("`O*B!#<F5A=&4@=&AE(&ME>7)I;F=S(&EF
M('1H97D@9&]N)W0@86QR96%D>2!E>&ES="X@*B\*("`@("`@("`D:V5Y<FEN
M9R`]("1T:&ES+3Y?8W)E871E2V5Y<FEN9R@D='EP92D["@H@("`@("`@("\J
M(%-T;W)E('1H92!K97DH<RD@:6X@=&AE(&ME>7)I;F<N("HO"B`@("`@("`@
M)&-M9&QI;F4@/2!A<G)A>2@*("`@("`@("`@("`@)RTM86QL;W<M<V5C<F5T
M+6ME>2UI;7!O<G0G+`H@("`@("`@("`@("`G+2UF87-T+6EM<&]R="<L"B`@
M("`@("`@("`@("1K97ER:6YG"B`@("`@("`@*3L*("`@("`@("`D=&AI<RT^
M7V-A;&Q'<&<H)&-M9&QI;F4L("=W)RP@87)R87E?=F%L=65S*"1K97ES*2D[
M"@H@("`@("`@(')E='5R;B`D:V5Y<FEN9SL*("`@('T*"B`@("`O*BH*("`@
M("`J($5N8W)Y<'1S(&$@;65S<V%G92!I;B!01U`@9F]R;6%T('5S:6YG(&$@
M<'5B;&EC(&ME>2X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("`@5&AE('1E>'0@=&\@
M8F4@96YC<GEP=&5D+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@(%1H
M92!P87)A;65T97)S(&YE961E9"!F;W(@96YC<GEP=&EO;BX*("`@("`J(#QP
M<F4^"B`@("`@*B!087)A;65T97)S.@H@("`@("H@/3T]/3T]/3T]/3T*("`@
M("`J("=T>7!E)R`@("`]/B`@)VUE<W-A9V4G("A215%525)%1"D*("`@("`J
M("=P=6)K97DG("`]/B`@4$=0('!U8FQI8R!K97DN("A/<'1I;VYA;"D@*$1%
M4%)%0T%4140I"B`@("`@*B`G96UA:6PG("`@/3X@($4M;6%I;"!A9&1R97-S
M(&]F(')E8VEP:65N="X@268@;F]T('!R97-E;G0L(&]R(&YO="!F;W5N9`H@
M("`@("H@("`@("`@("`@("`@("!I;B!T:&4@<'5B;&EC(&ME>2P@=&AE(&9I
M<G-T(&4M;6%I;"!A9&1R97-S(&9O=6YD(&EN('1H90H@("`@("H@("`@("`@
M("`@("`@("!K97D@=VEL;"!B92!U<V5D(&EN<W1E860N("A/<'1I;VYA;"D@
M*$1%4%)%0T%4140I"B`@("`@*B`G<F5C:7!S)R`@/3X@($%N(&%R<F%Y('=I
M=&@@=&AE(&4M;6%I;"!A9&1R97-S(&]F('1H92!R96-I<&EE;G0@87,*("`@
M("`J("`@("`@("`@("`@("`@=&AE(&ME>2!A;F0@=&AA="!P97)S;VXG<R!P
M=6)L:6,@:V5Y(&%S('1H92!V86QU92X*("`@("`J("`@("`@("`@("`@("`@
M*%)%455)4D5$*0H@("`@("H@/"]P<F4^"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!E;F-R>7!T960@;65S<V%G92P@;W(@4$5!4E]%<G)O
M<B!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@7V5N8W)Y<'1-97-S
M86=E*"1T97AT+"`D<&%R86US*0H@("`@>PH@("`@("`@("1E;6%I;"`](&YU
M;&P["@H@("`@("`@(&EF("@A:7-S970H)'!A<F%M<ULG<F5C:7!S)UTI*2![
M"B`@("`@("`@("`@("\J($-H96-K(&9O<B!R97%U:7)E9"!P87)A;65T97)S
M+B`J+PH@("`@("`@("`@("!I9B`H(6ES<V5T*"1P87)A;7-;)W!U8FME>2==
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M7R@B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@
M;65S<V%G92XB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("\J($=E="!I;F9O<FUA=&EO;B!O;B!T:&4@:V5Y+B`J+PH@
M("`@("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG96UA:6PG72DI('L*("`@
M("`@("`@("`@("`@("1K97E?:6YF;R`]("1T:&ES+3YP9W!086-K9713:6=N
M871U<F4H)'!A<F%M<ULG<'5B:V5Y)UTL("1P87)A;7-;)V5M86EL)UTI.PH@
M("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D:V5Y7VEN9F\I*2!["B`@("`@
M("`@("`@("`@("`@("`@)&5M86EL(#T@)&ME>5]I;F9O6R=E;6%I;"==.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`O
M*B!)9B!W92!H879E(&YO(&5M86EL(&%D9')E<W,@870@=&AI<R!P;VEN="P@
M=7-E('1H92!F:7)S="!E;6%I;`H@("`@("`@("`@("`@("!A9&1R97-S(&9O
M=6YD(&EN('1H92!P=6)L:6,@:V5Y+B`J+PH@("`@("`@("`@("!I9B`H96UP
M='DH)&5M86EL*2D@>PH@("`@("`@("`@("`@("`@)&ME>5]I;F9O(#T@)'1H
M:7,M/G!G<%!A8VME=$EN9F]R;6%T:6]N*"1P87)A;7-;)W!U8FME>2==*3L*
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D:V5Y7VEN9F];)W-I9VYA='5R
M92==6R=I9#$G75LG96UA:6PG72DI('L*("`@("`@("`@("`@("`@("`@("`D
M96UA:6P@/2`D:V5Y7VEN9F];)W-I9VYA='5R92==6R=I9#$G75LG96UA:6PG
M73L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V]U;&0@;F]T(&1E=&5R
M;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N(BDL("=H;W)D
M92YE<G)O<B<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`D<&%R86US6R=R96-I<',G72`](&%R<F%Y*"1E;6%I;"`]
M/B`D<&%R86US6R=P=6)K97DG72D["B`@("`@("`@?0H*("`@("`@("`O*B!3
M=&]R92!P=6)L:6,@:V5Y(&EN('1E;7!O<F%R>2!K97ER:6YG+B`J+PH@("`@
M("`@("1K97ER:6YG(#T@)'1H:7,M/E]P=71);DME>7)I;F<H87)R87E?=F%L
M=65S*"1P87)A;7-;)W)E8VEP<R==*2D["@H@("`@("`@("\J($5N8W)Y<'0@
M=&AE(&1O8W5M96YT+B`J+PH@("`@("`@("1C;61L:6YE(#T@87)R87DH"B`@
M("`@("`@("`@("<M+6%R;6]R)RP*("`@("`@("`@("`@)RTM8F%T8V@G+`H@
M("`@("`@("`@("`G+2UA;'=A>7,M=')U<W0G+`H@("`@("`@("`@("`D:V5Y
M<FEN9RP*("`@("`@("`@("`@)RTM96YC<GEP="<*("`@("`@("`I.PH@("`@
M("`@(&9O<F5A8V@@*&%R<F%Y7VME>7,H)'!A<F%M<ULG<F5C:7!S)UTI(&%S
M("1V86PI('L*("`@("`@("`@("`@)&-M9&QI;F5;72`]("<M+7)E8VEP:65N
M="`G("X@)'9A;#L*("`@("`@("!]"B`@("`@("`@)')E<W5L="`]("1T:&ES
M+3Y?8V%L;$=P9R@D8VUD;&EN92P@)W<G+"`D=&5X="P@=')U92P@=')U92D[
M"B`@("`@("`@:68@*&5M<'1Y*"1R97-U;'0M/F]U='!U="DI('L*("`@("`@
M("`@("`@)&5R<F]R(#T@<')E9U]R97!L86-E*"<O7&XN*B\G+"`G)RP@)')E
M<W5L="T^<W1D97)R*3L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H7R@B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z("(I("X@
M)&5R<F]R+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D<F5S=6QT+3YO=71P=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M:6=N<R!A(&UE<W-A9V4@:6X@4$=0(&9O<FUA="!U<VEN9R!A('!R:79A=&4@
M:V5Y+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'1E>'0@("!4:&4@=&5X="!T;R!B92!S:6=N
M960N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@5&AE('!A<F%M971E
M<G,@;F5E9&5D(&9O<B!S:6=N:6YG+@H@("`@("H@/'!R93X*("`@("`J(%!A
M<F%M971E<G,Z"B`@("`@*B`]/3T]/3T]/3T]/0H@("`@("H@)W1Y<&4G("`@
M("`@("`]/B`@)W-I9VYA='5R92<@*%)%455)4D5$*0H@("`@("H@)W!U8FME
M>2<@("`@("`]/B`@4$=0('!U8FQI8R!K97DN("A215%525)%1"D*("`@("`J
M("=P<FEV:V5Y)R`@("`@/3X@(%!'4"!P<FEV871E(&ME>2X@*%)%455)4D5$
M*0H@("`@("H@)W!A<W-P:')A<V4G("`]/B`@4&%S<W!H<F%S92!F;W(@4$=0
M($ME>2X@*%)%455)4D5$*0H@("`@("H@)W-I9W1Y<&4G("`@("`]/B`@1&5T
M97)M:6YE('1H92!S:6=N871U<F4@='EP92!T;R!U<V4N("A/<'1I;VYA;"D*
M("`@("`J("`@("`@("`@("`@("`@("`@("=C;&5A<G1E>'0G("`M+2`@36%K
M92!A(&-L96%R('1E>'0@<VEG;F%T=7)E"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`G9&5T86-H)R`@("`@+2T@($UA:V4@82!D971A8VAE9"!S:6=N871U
M<F4@*$1%1D%53%0I"B`@("`@*B`\+W!R93X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE('-I9VYE9"!M97-S86=E+"!O<B!014%27T5R<F]R
M(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!?96YC<GEP=%-I9VYA
M='5R92@D=&5X="P@)'!A<F%M<RD*("`@('L*("`@("`@("`O*B!#:&5C:R!F
M;W(@<V5C=7)E(&-O;FYE8W1I;VXN("HO"B`@("`@("`@)'-E8W5R95]C:&5C
M:R`]("1T:&ES+3YR97%U:7)E4V5C=7)E0V]N;F5C=&EO;B@I.PH@("`@("`@
M(&EF("AI<U]A*"1S96-U<F5?8VAE8VLL("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1S96-U<F5?8VAE8VL["B`@("`@("`@?0H*("`@
M("`@("`O*B!#:&5C:R!F;W(@<F5Q=6ER960@<&%R86UE=&5R<RX@*B\*("`@
M("`@("!I9B`H(6ES<V5T*"1P87)A;7-;)W!U8FME>2==*2!\?`H@("`@("`@
M("`@("`A:7-S970H)'!A<F%M<ULG<')I=FME>2==*2!\?`H@("`@("`@("`@
M("`A:7-S970H)'!A<F%M<ULG<&%S<W!H<F%S92==*2D@>PH@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")!('!U8FQI8R!01U`@:V5Y
M+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R!S:6=N(&$@;65S<V%G92XB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@
M("`@?0H*("`@("`@("`O*B!#<F5A=&4@=&5M<"!F:6QE<R!F;W(@:6YP=70N
M("HO"B`@("`@("`@)&EN<'5T(#T@)'1H:7,M/E]C<F5A=&5496UP1FEL92@G
M:&]R9&4M<&=P)RD["@H@("`@("`@("\J($5N8W)Y<'1I;VX@<F5Q=6ER97,@
M8F]T:"!K97ER:6YG<RX@*B\*("`@("`@("`D<'5B7VME>7)I;F<@/2`D=&AI
M<RT^7W!U=$EN2V5Y<FEN9RAA<G)A>2@D<&%R86US6R=P=6)K97DG72DI.PH@
M("`@("`@("1S96-?:V5Y<FEN9R`]("1T:&ES+3Y?<'5T26Y+97ER:6YG*&%R
M<F%Y*"1P87)A;7-;)W!R:79K97DG72DL("=P<FEV871E)RD["@H@("`@("`@
M("\J(%-T;W)E(&UE<W-A9V4@:6X@=&5M<&]R87)Y(&9I;&4N("HO"B`@("`@
M("`@)&9P(#T@9F]P96XH)&EN<'5T+"`G=RLG*3L*("`@("`@("!F<'5T<R@D
M9G`L("1T97AT*3L*("`@("`@("!F8VQO<V4H)&9P*3L*"B`@("`@("`@+RH@
M1&5T97)M:6YE('1H92!S:6=N871U<F4@='EP92!T;R!U<V4N("HO"B`@("`@
M("`@)&-M9&QI;F4@/2!A<G)A>2@I.PH@("`@("`@(&EF("AI<W-E="@D<&%R
M86US6R=S:6=T>7!E)UTI("8F"B`@("`@("`@("`@("1P87)A;7-;)W-I9W1Y
M<&4G72`]/2`G8VQE87)T97AT)RD@>PH@("`@("`@("`@("`D<VEG;E]T>7!E
M(#T@)RTM8VQE87)S:6=N)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D<VEG;E]T>7!E(#T@)RTM9&5T86-H+7-I9VXG.PH@("`@("`@('T*"B`@
M("`@("`@+RH@061D:71I;VYA;"!'4$<@;W!T:6]N<RX@*B\*("`@("`@("`D
M8VUD;&EN92`K/2!A<G)A>2@*("`@("`@("`@("`@)RTM87)M;W(G+`H@("`@
M("`@("`@("`G+2UB871C:"<L"B`@("`@("`@("`@("<M+7!A<W-P:')A<V4M
M9F0@,"<L"B`@("`@("`@("`@("1S96-?:V5Y<FEN9RP*("`@("`@("`@("`@
M)'!U8E]K97ER:6YG+`H@("`@("`@("`@("`D<VEG;E]T>7!E+`H@("`@("`@
M("`@("`D:6YP=70*("`@("`@("`I.PH*("`@("`@("`O*B!3:6=N('1H92!D
M;V-U;65N="X@*B\*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]C86QL1W!G
M*"1C;61L:6YE+"`G=R<L("1P87)A;7-;)W!A<W-P:')A<V4G72P@=')U92P@
M=')U92D["B`@("`@("`@:68@*&5M<'1Y*"1R97-U;'0M/F]U='!U="DI('L*
M("`@("`@("`@("`@)&5R<F]R(#T@<')E9U]R97!L86-E*"<O7&XN*B\G+"`G
M)RP@)')E<W5L="T^<W1D97)R*3L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H7R@B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z("(I
M("X@)&5R<F]R+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!R971U<FX@)')E<W5L="T^;W5T<'5T.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($1E8W)Y<'1S(&%N(%!'4"!E;F-R>7!T
M960@;65S<V%G92!U<VEN9R!A('!R:79A=&4O<'5B;&EC(&ME>7!A:7(@86YD
M(&$*("`@("`J('!A<W-H<')A<V4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@(%1H
M92!T97AT('1O(&)E(&1E8W)Y<'1E9"X*("`@("`J($!P87)A;2!A<G)A>2`D
M<&%R86US("!4:&4@<&%R86UE=&5R<R!N965D960@9F]R(&1E8W)Y<'1I;VXN
M"B`@("`@*B`\<')E/@H@("`@("H@4&%R86UE=&5R<SH*("`@("`J(#T]/3T]
M/3T]/3T]"B`@("`@*B`G='EP92<@("`@("`@(#T^("`G;65S<V%G92<@*%)%
M455)4D5$*0H@("`@("H@)W!U8FME>2<@("`@("`]/B`@4$=0('!U8FQI8R!K
M97DN("A215%525)%1"D*("`@("`J("=P<FEV:V5Y)R`@("`@/3X@(%!'4"!P
M<FEV871E(&ME>2X@*%)%455)4D5$*0H@("`@("H@)W!A<W-P:')A<V4G("`]
M/B`@4&%S<W!H<F%S92!F;W(@4$=0($ME>2X@*%)%455)4D5$*0H@("`@("H@
M/"]P<F4^"B`@("`@*@H@("`@("H@0')E='5R;B!S=&1#;&%S<R`@06X@;V)J
M96-T('=I=&@@=&AE(&9O;&QO=VEN9R!P<F]P97)T:65S+"!O<B!014%27T5R
M<F]R"B`@("`@*B`@("`@("`@("`@("`@("`@("!O;B!E<G)O<CH*("`@("`J
M(#QP<F4^"B`@("`@*B`G;65S<V%G92<@("`@("T@(%1H92!D96-R>7!T960@
M;65S<V%G92X*("`@("`J("=S:6=?<F5S=6QT)R`@+2`@5&AE(')E<W5L="!O
M9B!T:&4@<VEG;F%T=7)E('1E<W0N"B`@("`@*B`\+W!R93X*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V1E8W)Y<'1-97-S86=E*"1T97AT+"`D<&%R86US*0H@
M("`@>PH@("`@("`@("\J($-H96-K(&9O<B!S96-U<F4@8V]N;F5C=&EO;BX@
M*B\*("`@("`@("`D<V5C=7)E7V-H96-K(#T@)'1H:7,M/G)E<75I<F5396-U
M<F5#;VYN96-T:6]N*"D["B`@("`@("`@:68@*&ES7V$H)'-E8W5R95]C:&5C
M:RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'-E8W5R
M95]C:&5C:SL*("`@("`@("!]"@H@("`@("`@("1G;V]D7W-I9U]F;&%G(#T@
M9F%L<V4["@H@("`@("`@("\J($-H96-K(&9O<B!R97%U:7)E9"!P87)A;65T
M97)S+B`J+PH@("`@("`@(&EF("@A:7-S970H)'!A<F%M<ULG<'5B:V5Y)UTI
M('Q\"B`@("`@("`@("`@("%I<W-E="@D<&%R86US6R=P<FEV:V5Y)UTI('Q\
M"B`@("`@("`@("`@("%I<W-E="@D<&%R86US6R=P87-S<&AR87-E)UTI*2![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D$@<'5B
M;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+B(I+"`G:&]R9&4N
M97)R;W(G*3L*("`@("`@("!]"@H@("`@("`@("\J($-R96%T92!T96UP(&9I
M;&5S+B`J+PH@("`@("`@("1I;G!U="`]("1T:&ES+3Y?8W)E871E5&5M<$9I
M;&4H)VAO<F1E+7!G<"<I.PH*("`@("`@("`O*B!$96-R>7!T:6]N(')E<75I
M<F5S(&)O=&@@:V5Y<FEN9W,N("HO"B`@("`@("`@)'!U8E]K97ER:6YG(#T@
M)'1H:7,M/E]P=71);DME>7)I;F<H87)R87DH)'!A<F%M<ULG<'5B:V5Y)UTI
M*3L*("`@("`@("`D<V5C7VME>7)I;F<@/2`D=&AI<RT^7W!U=$EN2V5Y<FEN
M9RAA<G)A>2@D<&%R86US6R=P<FEV:V5Y)UTI+"`G<')I=F%T92<I.PH*("`@
M("`@("`O*B!3=&]R92!M97-S86=E(&EN(&9I;&4N("HO"B`@("`@("`@)&9P
M(#T@9F]P96XH)&EN<'5T+"`G=RLG*3L*("`@("`@("!F<'5T<R@D9G`L("1T
M97AT*3L*("`@("`@("!F8VQO<V4H)&9P*3L*"B`@("`@("`@+RH@1&5C<GEP
M="!T:&4@9&]C=6UE;G0@;F]W+B`J+PH@("`@("`@("1C;61L:6YE(#T@87)R
M87DH"B`@("`@("`@("`@("<M+6%L=V%Y<RUT<G5S="<L"B`@("`@("`@("`@
M("<M+6%R;6]R)RP*("`@("`@("`@("`@)RTM8F%T8V@G+`H@("`@("`@("`@
M("`G+2UP87-S<&AR87-E+69D(#`G+`H@("`@("`@("`@("`D<V5C7VME>7)I
M;F<L"B`@("`@("`@("`@("1P=6)?:V5Y<FEN9RP*("`@("`@("`@("`@)RTM
M9&5C<GEP="<L"B`@("`@("`@("`@("1I;G!U=`H@("`@("`@("D["B`@("`@
M("`@)')E<W5L="`]("1T:&ES+3Y?8V%L;$=P9R@D8VUD;&EN92P@)W<G+"`D
M<&%R86US6R=P87-S<&AR87-E)UTL('1R=64L('1R=64I.PH@("`@("`@(&EF
M("AE;7!T>2@D<F5S=6QT+3YO=71P=70I*2!["B`@("`@("`@("`@("1E<G)O
M<B`]('!R96=?<F5P;&%C92@G+UQN+BHO)RP@)R<L("1R97-U;'0M/G-T9&5R
M<BD["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-O
M=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B`B*2`N("1E<G)O<BP@)VAO<F1E
M+F5R<F]R)RD["B`@("`@("`@?0H*("`@("`@("`O*B!#<F5A=&4@=&AE(')E
M='5R;B!O8FIE8W0N("HO"B`@("`@("`@)&]B(#T@)FYE=R!S=&1#;&%S<SL*
M("`@("`@("`D;V(M/FUE<W-A9V4@/2`D<F5S=6QT+3YO=71P=70["@H@("`@
M("`@("\J($-H96-K('1H92!01U`@<VEG;F%T=7)E+B`J+PH@("`@("`@("1S
M:6=?8VAE8VL@/2`D=&AI<RT^7V-H96-K4VEG;F%T=7)E4F5S=6QT*"1R97-U
M;'0M/G-T9&5R<BD["B`@("`@("`@:68@*&ES7V$H)'-I9U]C:&5C:RP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D;V(M/G-I9U]R97-U;'0@/2`D
M<VEG7V-H96-K.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1O8BT^
M<VEG7W)E<W5L="`]("@D<VEG7V-H96-K*2`_("1R97-U;'0M/G-T9&5R<B`Z
M("<G.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O8CL*("`@('T*"B`@
M("`O*BH*("`@("`J($1E8W)Y<'1S(&%N(%!'4"!S:6=N960@;65S<V%G92!U
M<VEN9R!A('!U8FQI8R!K97DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@(%1H92!T
M97AT('1O(&)E('9E<FEF:65D+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A
M;7,@(%1H92!P87)A;65T97)S(&YE961E9"!F;W(@=F5R:69I8V%T:6]N+@H@
M("`@("H@/'!R93X*("`@("`J(%!A<F%M971E<G,Z"B`@("`@*B`]/3T]/3T]
M/3T]/0H@("`@("H@)W1Y<&4G("`@("`@(#T^("`G<VEG;F%T=7)E)R!O<B`G
M9&5T86-H960M<VEG;F%T=7)E)R`H4D5154E2140I"B`@("`@*B`G<'5B:V5Y
M)R`@("`@/3X@(%!'4"!P=6)L:6,@:V5Y+B`H4D5154E2140I"B`@("`@*B`G
M<VEG;F%T=7)E)R`@/3X@(%!'4"!S:6=N871U<F4@8FQO8VLN("A215%525)%
M1"!F;W(@9&5T86-H960@<VEG;F%T=7)E*0H@("`@("H@/"]P<F4^"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!V97)I9FEC871I;VX@;65S
M<V%G92!F<F]M(&=P9RX@268@;F\@<VEG;F%T=7)E+`H@("`@("H@("`@("`@
M("`@("`@("`@(')E='5R;G,@96UP='D@<W1R:6YG+"!A;F0@4$5!4E]%<G)O
M<B!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@7V1E8W)Y<'13:6=N
M871U<F4H)'1E>'0L("1P87)A;7,I"B`@("!["B`@("`@("`@+RH@0VAE8VL@
M9F]R(')E<75I<F5D('!A<F%M971E<G,N("HO"B`@("`@("`@:68@*"%I<W-E
M="@D<&%R86US6R=P=6)K97DG72DI('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H7R@B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E
M9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB*2P@)VAO<F1E+F5R<F]R
M)RD["B`@("`@("`@?0H@("`@("`@(&EF("@H)'!A<F%M<ULG='EP92==(#T]
M/2`G9&5T86-H960M<VEG;F%T=7)E)RD@)B8*("`@("`@("`@("`@(6ES<V5T
M*"1P87)A;7-;)W-I9VYA='5R92==*2D@>PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BA?*")4:&4@9&5T86-H960@4$=0('-I9VYA='5R
M92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S
M86=E+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!]"@H@("`@("`@("1G
M;V]D7W-I9U]F;&%G(#T@,#L*"B`@("`@("`@+RH@0W)E871E('1E;7`@9FEL
M97,@9F]R(&EN<'5T+B`J+PH@("`@("`@("1I;G!U="`]("1T:&ES+3Y?8W)E
M871E5&5M<$9I;&4H)VAO<F1E+7!G<"<I.PH*("`@("`@("`O*B!3=&]R92!P
M=6)L:6,@:V5Y(&EN('1E;7!O<F%R>2!K97ER:6YG+B`J+PH@("`@("`@("1K
M97ER:6YG(#T@)'1H:7,M/E]P=71);DME>7)I;F<H)'!A<F%M<ULG<'5B:V5Y
M)UTI.PH*("`@("`@("`O*B!3=&]R92!T:&4@;65S<V%G92!I;B!A('1E;7!O
M<F%R>2!F:6QE+B`J+PH@("`@("`@("1F<"`](&9O<&5N*"1I;G!U="P@)W<K
M)RD["B`@("`@("`@9G!U=',H)&9P+"`D=&5X="D["B`@("`@("`@9F-L;W-E
M*"1F<"D["@H@("`@("`@("\J($]P=&EO;G,@9F]R('1H92!'4$<@8FEN87)Y
M+B`J+PH@("`@("`@("1C;61L:6YE(#T@87)R87DH"B`@("`@("`@("`@("<M
M+6%R;6]R)RP*("`@("`@("`@("`@)RTM86QW87ES+71R=7-T)RP*("`@("`@
M("`@("`@)RTM8F%T8V@G+`H@("`@("`@("`@("`G+2UC:&%R<V5T("<@+B!.
M3%,Z.F=E=$-H87)S970H*2P*("`@("`@("`@("`@)&ME>7)I;F<L"B`@("`@
M("`@("`@("<M+79E<FEF>2<*("`@("`@("`I.PH*("`@("`@("`O*B!%>'1R
M82!S='5F9B!T;R!D;R!I9B!W92!A<F4@=7-I;F<@82!D971A8VAE9"!S:6=N
M871U<F4N("HO"B`@("`@("`@:68@*"1P87)A;7-;)W1Y<&4G72`]/3T@)V1E
M=&%C:&5D+7-I9VYA='5R92<I('L*("`@("`@("`@("`@)'-I9V9I;&4@/2`D
M=&AI<RT^7V-R96%T951E;7!&:6QE*"=H;W)D92UP9W`G*3L*("`@("`@("`@
M("`@)&-M9&QI;F5;72`]("1S:6=F:6QE("X@)R`G("X@)&EN<'5T.PH*("`@
M("`@("`@("`@)&9P(#T@9F]P96XH)'-I9V9I;&4L("=W*R<I.PH@("`@("`@
M("`@("!F<'5T<R@D9G`L("1P87)A;7-;)W-I9VYA='5R92==*3L*("`@("`@
M("`@("`@9F-L;W-E*"1F<"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&-M9&QI;F5;72`]("1I;G!U=#L*("`@("`@("!]"B`@("`@("`@)&-M
M9&QI;F5;72`]("<R/B8Q)SL*"B`@("`@("`@+RH@5F5R:69Y('1H92!S:6=N
M871U<F4N"B`@("`@("`@("`@5V4@;F5E9"!T;R!C871C:"!S=&%N9&%R9"!E
M<G)O<B!O=71P=70L('-I;F-E('1H:7,@:7,@=VAE<F4*("`@("`@("`@("!T
M:&4@<VEG;F%T=7)E(&EN9F]R;6%T:6]N(&ES('-E;G0N("HO"B`@("`@("`@
M)')E<W5L="`]("1T:&ES+3Y?8V%L;$=P9R@D8VUD;&EN92P@)W(G*3L*("`@
M("`@("`D<VEG7W)E<W5L="`]("1T:&ES+3Y?8VAE8VM3:6=N871U<F5297-U
M;'0H)')E<W5L="T^<W1D;W5T*3L*("`@("`@("!I9B`H:7-?82@D<VEG7W)E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'-I
M9U]R97-U;'0["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M("@D<VEG7W)E<W5L="D@/R`D<F5S=6QT+3YS=&1O=70@.B`G)SL*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@<VEG;F%T=7)E(')E
M<W5L="!F<F]M('1H92!';G501R!B:6YA<GDN"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<F5S
M=6QT("!4:&4@<VEG;F%T=7)E(')E<W5L="X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%1R=64@:68@<VEG;F%T=7)E(&ES(&=O;V0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]C:&5C:U-I9VYA='5R95)E<W5L="@D<F5S=6QT
M*0H@("`@>PH@("`@("`@("\J($=O;V0@<VEG;F%T=7)E.@H@("`@("`@("`J
M("`@9W!G.B!';V]D('-I9VYA='5R92!F<F]M(")B;&%H(&)L86@@8FQA:"`H
M0V]M;65N="DB"B`@("`@("`@("H@0F%D('-I9VYA='5R93H*("`@("`@("`@
M*B`@(&=P9SH@0D%$('-I9VYA='5R92!F<F]M(")B;&%H(&)L86@@8FQA:"`H
M0V]M;65N="DB("HO"B`@("`@("`@:68@*'-T<G!O<R@D<F5S=6QT+"`G9W!G
M.B!"040@<VEG;F%T=7)E)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*"1R97-U;'0L("=H;W)D92YE<G)O<B<I
M.PH@("`@("`@('T@96QS96EF("AS=')P;W,H)')E<W5L="P@)V=P9SH@1V]O
M9"!S:6=N871U<F4G*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T=7)N
M('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-I9VYS(&$@
M34E-15]087)T('5S:6YG(%!'4"X*("`@("`J"B`@("`@*B!`<&%R86T@34E-
M15]087)T("1M:6UE7W!A<G0@(%1H92!-24U%7U!A<G0@;V)J96-T('1O('-I
M9VXN"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@("`@("`@(%1H92!P
M87)A;65T97)S(')E<75I<F5D(&9O<B!S:6=N:6YG+@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!`<V5E(%]E;F-R>7!T4VEG;F%T=7)E
M*"DN"B`@("`@*@H@("`@("H@0')E='5R;B!-24U%7U!A<G0@($$@34E-15]0
M87)T(&]B:F5C="!T:&%T(&ES('-I9VYE9"!A8V-O<F1I;F<@=&\@4D9#"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@,C`Q-2\S,34V+"!O<B!014%27T5R
M<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!S:6=N34E-15!A
M<G0H)&UI;65?<&%R="P@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@
M("`@:6YC;'5D95]O;F-E("=(;W)D92]-24U%+U!A<G0N<&AP)SL*"B`@("`@
M("`@)'!A<F%M<R`](&%R<F%Y7VUE<F=E*"1P87)A;7,L(&%R<F%Y*"=T>7!E
M)R`]/B`G<VEG;F%T=7)E)RP@)W-I9W1Y<&4G(#T^("=D971A8V@G*2D["@H@
M("`@("`@("\J(%)&0R`R,#$U(%)E<75I<F5M96YT<R!F;W(@82!01U`@<VEG
M;F5D(&UE<W-A9V4Z"B`@("`@("`@("H@*R!#;VYT96YT+51Y<&4@<&%R86US
M("=M:6-A;&<G("8@)W!R;W1O8V]L)R!A<F4@4D5154E2140N"B`@("`@("`@
M("H@*R!4:&4@9&EG:71A;&QY('-I9VYE9"!M97-S86=E($U54U0@8F4@8V]N
M<W1R86EN960@=&\@-R!B:71S+@H@("`@("`@("`J("L@5&AE($U)344@:&5A
M9&5R<R!-55-4(&)E(&$@<&%R="!O9B!T:&4@<VEG;F5D(&1A=&$N("HO"@H@
M("`@("`@("1M:6UE7W!A<G0M/G-T<FEC=#=B:70H=')U92D["B`@("`@("`@
M)&US9U]S:6=N(#T@)'1H:7,M/F5N8W)Y<'0H)&UI;65?<&%R="T^=&]#86YO
M;FEC86Q3=')I;F<H*2P@)'!A<F%M<RD["B`@("`@("`@:68@*&ES7V$H)&US
M9U]S:6=N+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M;7-G7W-I9VX["B`@("`@("`@?0H*("`@("`@("`O*B!!9&0@=&AE(%!'4"!S
M:6=N871U<F4N("HO"B`@("`@("`@)'!G<%]S:6=N(#T@)FYE=R!-24U%7U!A
M<G0H)V%P<&QI8V%T:6]N+W!G<"US:6=N871U<F4G+"`D;7-G7W-I9VXL(&YU
M;&PL("=I;FQI;F4G*3L*("`@("`@("`D<&=P7W-I9VXM/G-E=$1E<V-R:7!T
M:6]N*%\H(E!'4"!$:6=I=&%L(%-I9VYA='5R92(I*3L*"B`@("`@("`@+RH@
M1V5T('1H92!A;&=O<FET:&EM(&EN9F]R;6%T:6]N(&9R;VT@=&AE('-I9VYA
M='5R92X@4VEN8V4@=V4@87)E"B`@("`@("`@("H@86YA;'EZ:6YG(&$@<VEG
M;F%T=7)E('!A8VME="P@=V4@;F5E9"!T;R!U<V4@=&AE('-P96-I86P@:V5Y
M=V]R9`H@("`@("`@("`J("=?4TE'3D%455)%)R`M('-E92!(;W)D95]#<GEP
M=%]P9W`N("HO"B`@("`@("`@)'-I9U]I;F9O(#T@)'1H:7,M/G!G<%!A8VME
M=%-I9VYA='5R92@D;7-G7W-I9VXL("=?4TE'3D%455)%)RD["@H@("`@("`@
M("\J(%-E='5P('1H92!M=6QT:7!A<G0@34E-12!087)T+B`J+PH@("`@("`@
M("1P87)T(#T@)FYE=R!-24U%7U!A<G0H)VUU;'1I<&%R="]S:6=N960G*3L*
M("`@("`@("`D<&%R="T^<V5T0V]N=&5N=',H)U1H:7,@;65S<V%G92!I<R!I
M;B!-24U%(&9O<FUA="!A;F0@:&%S(&)E96X@4$=0('-I9VYE9"XG("X@(EQN
M(BD["B`@("`@("`@)'!A<G0M/F%D9%!A<G0H)&UI;65?<&%R="D["B`@("`@
M("`@)'!A<G0M/F%D9%!A<G0H)'!G<%]S:6=N*3L*("`@("`@("`D<&%R="T^
M<V5T0V]N=&5N=%1Y<&5087)A;65T97(H)W!R;W1O8V]L)RP@)V%P<&QI8V%T
M:6]N+W!G<"US:6=N871U<F4G*3L*("`@("`@("`D<&%R="T^<V5T0V]N=&5N
M=%1Y<&5087)A;65T97(H)VUI8V%L9R<L("1S:6=?:6YF;ULG;6EC86QG)UTI
M.PH*("`@("`@("!R971U<FX@)'!A<G0["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!%;F-R>7!T<R!A($U)345?4&%R="!U<VEN9R!01U`N"B`@("`@*@H@("`@
M("H@0'!A<F%M($U)345?4&%R="`D;6EM95]P87)T("!4:&4@34E-15]087)T
M(&]B:F5C="!T;R!E;F-R>7!T+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A
M;7,@("`@("`@("!4:&4@<&%R86UE=&5R<R!R97%U:7)E9"!F;W(@96YC<GEP
M=&EO;BX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($!S
M964@7V5N8W)Y<'1-97-S86=E*"DN"B`@("`@*@H@("`@("H@0')E='5R;B!-
M24U%7U!A<G0@($$@34E-15]087)T(&]B:F5C="!T:&%T(&ES(&5N8W)Y<'1E
M9"!A8V-O<F1I;F<@=&\@4D9#"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M,C`Q-2\S,34V+"!O<B!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!E;F-R>7!T34E-15!A<G0H)&UI;65?<&%R="P@)'!A<F%M
M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:6YC;'5D95]O;F-E("=(;W)D
M92]-24U%+U!A<G0N<&AP)SL*"B`@("`@("`@)'!A<F%M<R`](&%R<F%Y7VUE
M<F=E*"1P87)A;7,L(&%R<F%Y*"=T>7!E)R`]/B`G;65S<V%G92<I*3L*"B`@
M("`@("`@)'-I9VYE;F-?8F]D>2`]("1M:6UE7W!A<G0M/G1O0V%N;VYI8V%L
M4W1R:6YG*"D["B`@("`@("`@)&UE<W-A9V5?96YC<GEP="`]("1T:&ES+3YE
M;F-R>7!T*"1S:6=N96YC7V)O9'DL("1P87)A;7,I.PH@("`@("`@(&EF("AI
M<U]A*"1M97-S86=E7V5N8W)Y<'0L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1M97-S86=E7V5N8W)Y<'0["B`@("`@("`@?0H*("`@
M("`@("`O*B!3970@=7`@34E-12!3=')U8W1U<F4@86-C;W)D:6YG('1O(%)&
M0R`R,#$U+B`J+PH@("`@("`@("1P87)T(#T@)FYE=R!-24U%7U!A<G0H)VUU
M;'1I<&%R="]E;F-R>7!T960G*3L*("`@("`@("`D<&%R="T^<V5T0V]N=&5N
M=',H)U1H:7,@;65S<V%G92!I<R!I;B!-24U%(&9O<FUA="!A;F0@:&%S(&)E
M96X@4$=0(&5N8W)Y<'1E9"XG("X@(EQN(BD["B`@("`@("`@)'!A<G0M/F%D
M9%!A<G0H;F5W($U)345?4&%R="@G87!P;&EC871I;VXO<&=P+65N8W)Y<'1E
M9"<L(")697)S:6]N.B`Q7&XB+"!N=6QL*2D["B`@("`@("`@)'!A<G0M/F%D
M9%!A<G0H;F5W($U)345?4&%R="@G87!P;&EC871I;VXO;V-T970M<W1R96%M
M)RP@)&UE<W-A9V5?96YC<GEP="P@;G5L;"P@)VEN;&EN92<I*3L*("`@("`@
M("`D<&%R="T^<V5T0V]N=&5N=%1Y<&5087)A;65T97(H)W!R;W1O8V]L)RP@
M)V%P<&QI8V%T:6]N+W!G<"UE;F-R>7!T960G*3L*("`@("`@("`D<&%R="T^
M<V5T1&5S8W)I<'1I;VXH7R@B4$=0($5N8W)Y<'1E9"!$871A(BDI.PH*("`@
M("`@("!R971U<FX@)'!A<G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3:6=N
M<R!A;F0@96YC<GEP=',@82!-24U%7U!A<G0@=7-I;F<@4$=0+@H@("`@("H*
M("`@("`J($!P87)A;2!-24U%7U!A<G0@)&UI;65?<&%R="`@(%1H92!-24U%
M7U!A<G0@;V)J96-T('1O('-I9VX@86YD(&5N8W)Y<'0N"B`@("`@*B!`<&%R
M86T@87)R87D@)'-I9VY?<&%R86US("`@("!4:&4@<&%R86UE=&5R<R!R97%U
M:7)E9"!F;W(@<VEG;FEN9RX*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@($!S964@7V5N8W)Y<'13:6=N871U<F4H*2X*("`@("`J($!P
M87)A;2!A<G)A>2`D96YC<GEP=%]P87)A;7,@(%1H92!P87)A;65T97)S(')E
M<75I<F5D(&9O<B!E;F-R>7!T:6]N+@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@0'-E92!?96YC<GEP=$UE<W-A9V4H*2X*("`@("`J
M"B`@("`@*B!`<F5T=7)N($U)345?4&%R="`@02!-24U%7U!A<G0@;V)J96-T
M('1H870@:7,@<VEG;F5D(&%N9"!E;F-R>7!T960*("`@("`J("`@("`@("`@
M("`@("`@("`@("!A8V-O<F1I;F<@=&\@4D9#(#(P,34O,S$U-BP@;W(@4$5!
M4E]%<G)O<B!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@<VEG;D%N
M9$5N8W)Y<'1-24U%4&%R="@D;6EM95]P87)T+"`D<VEG;E]P87)A;7,@/2!A
M<G)A>2@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M96YC<GEP=%]P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EN8VQU
M9&5?;VYC92`G2&]R9&4O34E-12]087)T+G!H<"<["@H@("`@("`@("\J(%)&
M0R`R,#$U(')E<75I<F5S('1H870@=&AE(&5N=&ER92!S:6=N960@;65S<V%G
M92!B92!E;F-R>7!T960N("!790H@("`@("`@("`J(&YE960@=&\@97AP;&EC
M:71L>2!C86QL('5S:6YG($AO<F1E7T-R>7!T7W!G<#HZ(&)E8V%U<V4@=V4@
M9&]N)W0*("`@("`@("`@*B!K;F]W('=H971H97(@82!S=6)C;&%S<R!H87,@
M97AT96YD960@=&AE<V4@;65T:&]D<RX@*B\*("`@("`@("`D<&%R="`]("1T
M:&ES+3YS:6=N34E-15!A<G0H)&UI;65?<&%R="P@)'-I9VY?<&%R86US*3L*
M("`@("`@("!I9B`H:7-?82@D<&%R="P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'!A<G0["B`@("`@("`@?0H@("`@("`@("1P87)T
M(#T@)'1H:7,M/F5N8W)Y<'1-24U%4&%R="@D<&%R="P@)&5N8W)Y<'1?<&%R
M86US*3L*("`@("`@("!I9B`H:7-?82@D<&%R="P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)'!A<G0["B`@("`@("`@?0H@("`@("`@
M("1P87)T+3YS971#;VYT96YT<R@G5&AI<R!M97-S86=E(&ES(&EN($U)344@
M9F]R;6%T(&%N9"!H87,@8F5E;B!01U`@<VEG;F5D(&%N9"!E;F-R>7!T960N
M)R`N(")<;B(I.PH@("`@("`@("1P87)T+3YS971$97-C<FEP=&EO;BA?*")0
M1U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(BDI.PH*("`@("`@("!R971U<FX@
M)'!A<G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T97,@82!-24U%
M7U!A<G0@;V)J96-T+"!I;B!A8V-O<F1A;F-E('=I=&@@4D9#(#(P,34O,S$U
M-BP@=&AA=`H@("`@("H@8V]N=&%I;G,@82!P=6)L:6,@:V5Y+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&ME>2`@5&AE('!U8FQI8R!K97DN"B`@
M("`@*@H@("`@("H@0')E='5R;B!-24U%7U!A<G0@($$@34E-15]087)T(&]B
M:F5C="!T:&%T(&-O;G1A:6YS('1H92!P=6)L:6,@:V5Y+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!P=6)L:6-+97E-24U%4&%R="@D:V5Y*0H@("`@>PH@("`@
M("`@(&EN8VQU9&5?;VYC92`G2&]R9&4O34E-12]087)T+G!H<"<["@H@("`@
M("`@("1P87)T(#T@)FYE=R!-24U%7U!A<G0H)V%P<&QI8V%T:6]N+W!G<"UK
M97ES)RP@)&ME>2P@3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@("`@("1P87)T
M+3YS971$97-C<FEP=&EO;BA?*")01U`@4'5B;&EC($ME>2(I*3L*"B`@("`@
M("`@<F5T=7)N("1P87)T.PH@("`@?0H*("`@("\J*@H@("`@("H@1G5N8W1I
M;VX@=&AA="!H86YD;&5S(&EN=&5R9F%C:6YG('=I=&@@=&AE($=N=5!'(&)I
M;F%R>2X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@)&]P=&EO;G,@("!43T1/"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1M;V1E("`@("!43T1/"B`@("`@*B!`<&%R86T@87)R87D@
M)&EN<'5T("`@("!43T1/"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;W5T<'5T
M("!43T1/"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<W1D97)R("!43T1/"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=&1#;&%S<R`@5$]$3PH@("`@("HO"B`@
M("!F=6YC=&EO;B!?8V%L;$=P9R@D;W!T:6]N<RP@)&UO9&4L("1I;G!U="`]
M(&%R<F%Y*"DL("1O=71P=70@/2!F86QS92P*("`@("`@("`@("`@("`@("`@
M("`@("1S=&1E<G(@/2!F86QS92D*("`@('L*("`@("`@("`D8VUD;&EN92`]
M(&%R<F%Y7VUE<F=E*"1T:&ES+3Y?9VYU<&<L("1O<'1I;VYS*3L*("`@("`@
M("`D9&%T82`]("9N97<@<W1D0VQA<W,["B`@("`@("`@)&1A=&$M/F]U='!U
M="`](&YU;&P["B`@("`@("`@)&1A=&$M/G-T9&5R<B`](&YU;&P["B`@("`@
M("`@)&1A=&$M/G-T9&]U="`](&YU;&P["@H@("`@("`@("\J($-R96%T92!T
M96UP(&9I;&5S(&9O<B!O=71P=70N("HO"B`@("`@("`@:68@*"1O=71P=70I
M('L*("`@("`@("`@("`@)&]U='!U=%]F:6QE(#T@)'1H:7,M/E]C<F5A=&54
M96UP1FEL92@G:&]R9&4M<&=P)RP@9F%L<V4I.PH@("`@("`@("`@("!A<G)A
M>5]U;G-H:69T*"1O<'1I;VYS+"`G+2UO=71P=70@)R`N("1O=71P=71?9FEL
M92D["@H@("`@("`@("`@("`O*B!$;R!W92!N965D('-T86YD87)D(&5R<F]R
M(&]U='!U=#\@*B\*("`@("`@("`@("`@:68@*"1S=&1E<G(I('L*("`@("`@
M("`@("`@("`@("1S=&1E<G)?9FEL92`]("1T:&ES+3Y?8W)E871E5&5M<$9I
M;&4H)VAO<F1E+7!G<"<L(&9A;'-E*3L*("`@("`@("`@("`@("`@("1O<'1I
M;VYS6UT@/2`G,CX@)R`N("1S=&1E<G)?9FEL93L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@+RH@0G5I;&0@=&AE(&-O;6UA;F0@;&EN92!S
M=')I;F<@;F]W+B`J+PH@("`@("`@("1C;61L:6YE(#T@:6UP;&]D92@G("<L
M(&%R<F%Y7VUE<F=E*"1T:&ES+3Y?9VYU<&<L("1O<'1I;VYS*2D["@H@("`@
M("`@(&EF("@D;6]D92`]/2`G=R<I('L*("`@("`@("`@("`@)&9P(#T@<&]P
M96XH)&-M9&QI;F4L("=W)RD["B`@("`@("`@("`@("1W:6XS,B`]('-U8G-T
M<BA02%!?3U,L(#`L(#,I(#T]("=724XG.PH*("`@("`@("`@("`@:68@*"%I
M<U]A<G)A>2@D:6YP=70I*2!["B`@("`@("`@("`@("`@("`D:6YP=70@/2!A
M<G)A>2@D:6YP=70I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1I;G!U="!A<R`D;&EN92D@>PH@("`@("`@("`@("`@("`@:68@*"1W
M:6XS,B`F)B`H<W1R<&]S*"1L:6YE+"`B7'@P9%QX,&$B*2`A/3T@9F%L<V4I
M*2!["B`@("`@("`@("`@("`@("`@("`@)&-H=6YK<R`](&5X<&QO9&4H(EQX
M,&1<>#!A(BP@)&QI;F4I.PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1C:'5N:W,@87,@)&-H=6YK*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M(&9P=71S*"1F<"P@)&-H=6YK("X@(EQN(BD["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("!F<'5T<R@D9G`L("1L:6YE("X@(EQN(BD["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V5I9B`H)&UO9&4@/3T@
M)W(G*2!["B`@("`@("`@("`@("1F<"`]('!O<&5N*"1C;61L:6YE+"`G<B<I
M.PH@("`@("`@("`@("!W:&EL92`H(69E;V8H)&9P*2D@>PH@("`@("`@("`@
M("`@("`@)&1A=&$M/G-T9&]U="`N/2!F9V5T<R@D9G`L(#$P,C0I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@('!C;&]S92@D9G`I.PH*("`@
M("`@("!I9B`H)&]U='!U="D@>PH@("`@("`@("`@("`D9&%T82T^;W5T<'5T
M(#T@9FEL95]G971?8V]N=&5N=',H)&]U='!U=%]F:6QE*3L*("`@("`@("`@
M("`@=6YL:6YK*"1O=71P=71?9FEL92D["B`@("`@("`@("`@(&EF("@D<W1D
M97)R*2!["B`@("`@("`@("`@("`@("`D9&%T82T^<W1D97)R(#T@9FEL95]G
M971?8V]N=&5N=',H)'-T9&5R<E]F:6QE*3L*("`@("`@("`@("`@("`@('5N
M;&EN:R@D<W1D97)R7V9I;&4I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&1A=&$["B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]#;VUP<F5S
M<P``````````````````````````````````````````````````````````
M```````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,#`P,"`Q,#4Q-30S,S<S-R`P,C$P-C8`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP:'``````````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#(Q,#<T(#$P-3$U-#,S-S,W(#`R,C0S-P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@5&AE($AO<F1E7T-O;7!R97-S7V1B>"!C;&%S<R!A;&QO=W,@9&)X
M(&9I;&5S("AE+F<N(&9R;VT@3W5T;&]O:R!%>'!R97-S*0H@*B!T;R!B92!R
M96%D+@H@*@H@*B!4:&ES(&-L87-S(&ES(&)A<V5D(&]N(&-O9&4@8GDZ"B`J
M($%N=&]N>2!286EJ96MO=B`\9&5V0'-T<F%T96=M82YB9SX*("H@:'1T<#HO
M+W5R=61S+F=A=&5W87DN8F<O>F5O<R\*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<"QV(#$N,RXQ,BXY(#(P,#8O
M,#$O,#$@,C$Z,C@Z,3$@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S
M+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO
M<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]#
M;VUP<F5S<PH@*B\*8VQA<W,@2&]R9&5?0V]M<')E<W-?9&)X(&5X=&5N9',@
M2&]R9&5?0V]M<')E<W,@>PH*("`@("\J*@H@("`@("H@5$]$3PH@("`@("H*
M("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?;6%I;',@/2!A
M<G)A>2@I.PH*("`@("\J*@H@("`@("H@5$]$3PH@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1?=&UP(#T@87)R87DH*3L*"B`@
M("`O*BH*("`@("`J($1E8V]M<')E<W-E<R!A($1"6"!F:6QE(&%N9"!G971S
M(&EN9F]R;6%T:6]N(&9R;VT@:70N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9&%T82`@5&AE(&1B>"!F:6QE(&1A=&$N"B`@("`@*B!`<&%R86T@
M87)R87D@)'!A<F%M<R`@06YY"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@5&AE(')E<75E<W1E9"!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!D
M96-O;7!R97-S*"8D9&%T82P@)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@
M("`@)'1H:7,M/E]M86EL<R`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/E]T
M;7`@/2!A<G)A>2@I.PH@("`@("`@("1P;W-I=&EO;B`](#!X0S0["B`@("`@
M("`@)&AE861E<E]I;F9O(#T@=6YP86-K*"=,<&]S:71I;VXO3$1A=&%,96YG
M=&@O;DAE861E<DQE;F=T:"]N1FQA9T-O=6YT)RP@<W5B<W1R*"1D871A+"`D
M<&]S:71I;VXL(#$R*2D["B`@("`@("`@)'!O<VET:6]N("L](#$R.PH@("`@
M("`@("\O($=O('1O('1H92!F:7)S="!T86)L92!O9F9E<W0@86YD('!R;V-E
M<W,@:70N"B`@("`@("`@:68@*"1H96%D97)?:6YF;ULG<&]S:71I;VXG72`^
M(#`I('L*("`@("`@("`@("`@)'!O<VET:6]N(#T@,'@S,#L*("`@("`@("`@
M("`@)&)U9B`]('5N<&%C:R@G3'!O<VET:6]N)RP@<W5B<W1R*"1D871A+"`D
M<&]S:71I;VXL(#0I*3L*("`@("`@("`@("`@)'!O<VET:6]N(#T@)&)U9ELG
M<&]S:71I;VXG73L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?<F5A
M9$EN9&5X*"1D871A+"`D<&]S:71I;VXI.PH@("`@("`@("`@("!I9B`H:7-?
M82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!R971U<FX@)'1H:7,M/E]M86EL<SL*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@82!N=6QL+71E<FUI;F%T960@<W1R:6YG(&9R;VT@=&AE('-P
M96-I9FEE9"!D871A+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)B1B=68@(%1/1$\*("`@("`J
M($!P87)A;2!I;G1E9V5R("1P;W,@(%1/1$\*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5$]$3PH@("`@("HO"B`@("!F=6YC=&EO;B!?<F5A9%-T
M<FEN9R@F)&)U9BP@)'!O<RD*("`@('L*("`@("`@("!I9B`H)&QE;B`]('-T
M<G!O<RAS=6)S='(H)&)U9BP@)'!O<RDL(&-H<B@P*2DI('L*("`@("`@("`@
M("`@<F5T=7)N('-U8G-T<B@D8G5F+"`D<&]S+"`D;&5N*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("<G.PH@("`@?0H*("`@("\J*@H@("`@("H@5$]$
M3PH@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)B1D871A("`@("`@5$]$3PH@("`@("H@0'!A<F%M
M(&EN=&5G97(@)'!O<VET:6]N("!43T1/"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1/1$\*("`@("`J+PH@("`@9G5N8W1I;VX@7W)E861-97-S
M86=E*"8D9&%T82P@)'!O<VET:6]N*0H@("`@>PH@("`@("`@("1M<V<@/2`G
M)SL*("`@("`@("`D<&%R="`](#`["@H@("`@("`@(&EF("@D<&]S:71I;VX@
M/B`P*2!["B`@("`@("`@("`@("1);F1E>$ET96US0V]U;G0@/2!A<G)A>5]P
M;W`H=6YP86-K*"=3)RP@<W5B<W1R*"1D871A+"`P>$,T+"`T*2DI.PH@("`@
M("`@("`@("!I9B`H)$EN9&5X271E;7-#;W5N="`^(#`I('L*("`@("`@("`@
M("`@("`@('=H:6QE("@D<&]S:71I;VX@/"!S=')L96XH)&1A=&$I*2!["B`@
M("`@("`@("`@("`@("`@("`@)'!A<G0K*SL*("`@("`@("`@("`@("`@("`@
M("`D<R`]('-U8G-T<B@D9&%T82P@)'!O<VET:6]N+"`U,C@I.PH@("`@("`@
M("`@("`@("`@("`@(&EF("AS=')L96XH)',I(#T](#`I('L*("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@("1M<V=?:71E;2`]('5N<&%C:R@G3$9I;&50
M;W,O3%5N:VYO=VXO3$ET96U3:7IE+TQ.97AT271E;2]A-3$R0V]N=&5N="<L
M("1S*3L*("`@("`@("`@("`@("`@("`@("!I9B`H)&US9U]I=&5M6R=&:6QE
M4&]S)UT@(3T@)'!O<VET:6]N*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DEN=F%L:60@9FEL92!F;W)M
M870B*2D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@("1P;W-I=&EO;B`K/2`U,C@["B`@("`@("`@("`@("`@("`@("`@)&US
M9R`N/2!S=6)S='(H)&US9U]I=&5M6R=#;VYT96YT)UTL(#`L("1M<V=?:71E
M;5LG271E;5-I>F4G72D["B`@("`@("`@("`@("`@("`@("`@)'!O<VET:6]N
M(#T@)&US9U]I=&5M6R=.97AT271E;2==.PH@("`@("`@("`@("`@("`@("`@
M(&EF("@D<&]S:71I;VX@/3T@,"D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M;7-G.PH@("`@?0H*("`@("\J*@H@("`@("H@5$]$3PH@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)B1D871A("`@("`@5$]$3PH@("`@("H@0'!A<F%M(&EN=&5G97(@)'!O<VET
M:6]N("!43T1/"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5$]$3PH@
M("`@("HO"B`@("!F=6YC=&EO;B!?<F5A9$UE<W-A9V5);F9O*"8D9&%T82P@
M)'!O<VET:6]N*0H@("`@>PH@("`@("`@("1M97-S86=E7VEN9F\@/2!A<G)A
M>2@I.PH@("`@("`@("1M<V=?:&5A9&5R(#T@=6YP86-K*"=,<&]S:71I;VXO
M3$1A=&%,96YG=&@O4TAE861E<DQE;F=T:"]31FQA9T-O=6YT)RP@<W5B<W1R
M*"1D871A+"`D<&]S:71I;VXL(#$R*2D["B`@("`@("`@:68@*"1M<V=?:&5A
M9&5R6R=P;W-I=&EO;B==("$]("1P;W-I=&EO;BD@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*"));G9A;&ED(&9I;&4@9F]R;6%T
M(BDI.PH@("`@("`@('T*("`@("`@("`D<&]S:71I;VX@*ST@,3(["B`@("`@
M("`@)&UE<W-A9V5?:6YF;ULG2&5A9&5R4&]S:71I;VXG72`]("1M<V=?:&5A
M9&5R6R=P;W-I=&EO;B==.PH@("`@("`@("1F;&%G<R`]("1M<V=?:&5A9&5R
M6R=&;&%G0V]U;G0G72`F(#!X1D8["B`@("`@("`@)$1A=&%3:7IE(#T@)&US
M9U]H96%D97);)T1A=&%,96YG=&@G72`M("1F;&%G<R`J(#0["B`@("`@("`@
M)'-I>F4@/2`T("H@)&9L86=S.PH@("`@("`@("1&;&%G<T)U9F9E<B`]('-U
M8G-T<B@D9&%T82P@)'!O<VET:6]N+"`D<VEZ92D["B`@("`@("`@)'!O<VET
M:6]N("L]("1S:7IE.PH@("`@("`@("1S:7IE(#T@)$1A=&%3:7IE.PH@("`@
M("`@("1$871A0G5F9F5R(#T@<W5B<W1R*"1D871A+"`D<&]S:71I;VXL("1S
M:7IE*3L*("`@("`@("`D<&]S:71I;VX@*ST@)'-I>F4["B`@("`@("`@)&UE
M<W-A9V5?:6YF;R`](&%R<F%Y*"D["@H@("`@("`@("1F;&%G7V%R<F%Y(#T@
M87)R87DH"B`@("`@("`@("`@(#!X,2`]/B`G37-G1FQA9W,G+`H@("`@("`@
M("`@("`P>#(@/3X@)U-E;G0G+`H@("`@("`@("`@("`P>#0@/3X@)W!O<VET
M:6]N)RP*("`@("`@("`@("`@,'@W(#T^("=-97-S86=E240G+`H@("`@("`@
M("`@("`P>#@@/3X@)U-U8FIE8W0G+`H@("`@("`@("`@("`P>#D@/3X@)T9R
M;VU?<F5P;'DG+`H@("`@("`@("`@("`P>$$@/3X@)U)E9F5R96YC97,G+`H@
M("`@("`@("`@("`P>$(@/3X@)TYE=W-G<F]U<"<L"B`@("`@("`@("`@(#!X
M1"`]/B`G1G)O;2<L"B`@("`@("`@("`@(#!X12`]/B`G4F5P;'E?5&\G+`H@
M("`@("`@("`@("`P>#$R(#T^("=296-E:79E9"<L"B`@("`@("`@("`@(#!X
M,3,@/3X@)U)E8V5I<'0G+`H@("`@("`@("`@("`P>#%!(#T^("=!8V-O=6YT
M)RP*("`@("`@("`@("`@,'@Q0B`]/B`G06-C;W5N=$E$)RP*("`@("`@("`@
M("`@,'@X,"`]/B`G37-G)RP*("`@("`@("`@("`@,'@X,2`]/B`G37-G1FQA
M9W,G+`H@("`@("`@("`@("`P>#@T(#T^("=P;W-I=&EO;B<L"B`@("`@("`@
M("`@(#!X.3$@/3X@)W-I>F4G+`H@("`@("`@("D["@H@("`@("`@("\J(%!R
M;V-E<W,@9FQA9W,@*B\*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D9FQA
M9W,[("1I*RLI('L*("`@("`@("`@("`@)'!O<R`](#`["B`@("`@("`@("`@
M("1F(#T@87)R87E?<&]P*'5N<&%C:R@G3"<L('-U8G-T<B@D1FQA9W-"=69F
M97(L("1I("H@-"P@-"DI*3L*"B`@("`@("`@("`@("1M87-K(#T@)&8@)B`P
M>$9&.PH@("`@("`@("`@("!S=VET8V@@*"1M87-K*2!["B`@("`@("`@("`@
M(&-A<V4@,'@Q.@H@("`@("`@("`@("`@("`@)'!O<R`]("1P;W,@*R`H)&8@
M/CX@."D["B`@("`@("`@("`@("`@("`D;65S<V%G95]I;F9O6R=-<V=&;&%G
M<R==(#T@87)R87E?<&]P*'5N<&%C:R@G0R<L('-U8G-T<B@D1&%T84)U9F9E
M<BP@)'!O<RLK+"`Q*2DI.PH@("`@("`@("`@("`@("`@)&UE<W-A9V5?:6YF
M;ULG37-G1FQA9W,G72`K/2!A<G)A>5]P;W`H=6YP86-K*"=#)RP@<W5B<W1R
M*"1$871A0G5F9F5R+"`D<&]S*RLL(#$I*2D@*B`R-38["B`@("`@("`@("`@
M("`@("`D;65S<V%G95]I;F9O6R=-<V=&;&%G<R==("L](&%R<F%Y7W!O<"AU
M;G!A8VLH)T,G+"!S=6)S='(H)$1A=&%"=69F97(L("1P;W,L(#$I*2D@*B`V
M-34S-CL*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S
M92`P>#(Z"B`@("`@("`@("`@(&-A<V4@,'@T.@H@("`@("`@("`@("`@("`@
M)'!O<R`K/2!A<G)A>5]P;W`H=6YP86-K*"=,)RP@<W5B<W1R*"1&;&%G<T)U
M9F9E<BP@)&D@*B`T+"`T*2DI(#X^(#@["B`@("`@("`@("`@("`@("`D;65S
M<V%G95]I;F9O6R1F;&%G7V%R<F%Y6R1M87-K75T@/2!A<G)A>5]P;W`H=6YP
M86-K*"=,)RP@<W5B<W1R*"1$871A0G5F9F5R+"`D<&]S+"`T*2DI.PH@("`@
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#!X-SH*("`@
M("`@("`@("`@8V%S92`P>#@Z"B`@("`@("`@("`@(&-A<V4@,'@Y.@H@("`@
M("`@("`@("!C87-E(#!X03H*("`@("`@("`@("`@8V%S92`P>$(Z"B`@("`@
M("`@("`@(&-A<V4@,'A$.@H@("`@("`@("`@("!C87-E(#!X13H*("`@("`@
M("`@("`@8V%S92`P>#$S.@H@("`@("`@("`@("!C87-E(#!X,4$Z"B`@("`@
M("`@("`@("`@("`D<&]S("L](&%R<F%Y7W!O<"AU;G!A8VLH)TPG+"!S=6)S
M='(H)$9L86=S0G5F9F5R+"`D:2`J(#0L(#0I*2D@/CX@.#L*("`@("`@("`@
M("`@("`@("1M97-S86=E7VEN9F];)&9L86=?87)R87E;)&UA<VM=72`]("1T
M:&ES+3Y?<F5A9%-T<FEN9R@D1&%T84)U9F9E<BP@)'!O<RD["B`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@,'@Q,CH*("`@("`@
M("`@("`@("`@("1P;W,@*ST@87)R87E?<&]P*'5N<&%C:R@G3"<L('-U8G-T
M<B@D1FQA9W-"=69F97(L("1I("H@-"P@-"DI*2`^/B`X.PH@("`@("`@("`@
M("`@("`@)&UE<W-A9V5?:6YF;ULG4F5C96EV960G72`](&%R<F%Y7W!O<"AU
M;G!A8VLH)TPG+"!S=6)S='(H)$1A=&%"=69F97(L("1P;W,L(#0I*2D["B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@,'@Q0CH*
M("`@("`@("`@("`@("`@("1P;W,@*ST@87)R87E?<&]P*'5N<&%C:R@G3"<L
M('-U8G-T<B@D1FQA9W-"=69F97(L("1I("H@-"P@-"DI*2`^/B`X.PH@("`@
M("`@("`@("`@("`@)&UE<W-A9V5?:6YF;ULG06-C;W5N=$E$)UT@/2!I;G1V
M86PH)'1H:7,M/E]R96%D4W1R:6YG*"1$871A0G5F9F5R+"`D<&]S*2D["B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@,'@X,#H*
M("`@("`@("`@("`@8V%S92`P>#@Q.@H@("`@("`@("`@("!C87-E(#!X.#0Z
M"B`@("`@("`@("`@(&-A<V4@,'@Y,3H*("`@("`@("`@("`@("`@("1M97-S
M86=E7VEN9F];)&9L86=?87)R87E;)&UA<VM=72`](&%R<F%Y7W!O<"AU;G!A
M8VLH)TPG+"!S=6)S='(H)$9L86=S0G5F9F5R+"`D:2`J(#0L(#0I*2D@/CX@
M.#L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&UE<W-A9V5?:6YF;SL*("`@('T*"B`@
M("`O*BH*("`@("`J(%1/1$\*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("8D9&%T82`@("`@(%1/
M1$\*("`@("`J($!P87)A;2!I;G1E9V5R("1P;W-I=&EO;B`@5$]$3PH@("`@
M("HO"B`@("!F=6YC=&EO;B!?<F5A9$EN9&5X*"8D9&%T82P@)'!O<VET:6]N
M*0H@("`@>PH@("`@("`@("1I;F1E>%]H96%D97(@/2!U;G!A8VLH)TQ&:6QE
M4&]S+TQ5;FMN;W=N,2],4')E=DEN9&5X+TQ.97AT26YD97@O3$-O=6YT+TQ5
M;FMN;W=N)RP@<W5B<W1R*"1D871A+"`D<&]S:71I;VXL(#(T*2D["B`@("`@
M("`@:68@*"1I;F1E>%]H96%D97);)T9I;&50;W,G72`A/2`D<&]S:71I;VXI
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B26YV
M86QI9"!F:6QE(&9O<FUA="(I*3L*("`@("`@("!]"@H@("`@("`@("\O(%!U
M<V@@:70@:6YT;R!L:7-T(&]F('!R;V-E<W-E9"!I=&5M<RX*("`@("`@("`D
M=&AI<RT^7W1M<%LD<&]S:71I;VY=(#T@=')U93L*("`@("`@("!I9B`H*"1I
M;F1E>%]H96%D97);)TYE>'1);F1E>"==(#X@,"D@)B8*("`@("`@("`@("`@
M96UP='DH)'1H:7,M/E]T;7!;)&EN9&5X7VAE861E<ELG3F5X=$EN9&5X)UU=
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W)E861);F1E>"@D9&%T82P@)&EN
M9&5X7VAE861E<ELG3F5X=$EN9&5X)UTI.PH@("`@("`@('T*("`@("`@("!I
M9B`H*"1I;F1E>%]H96%D97);)U!R979);F1E>"==(#X@,"D@)B8*("`@("`@
M("`@("`@96UP='DH)'1H:7,M/E]T;7!;)&EN9&5X7VAE861E<ELG4')E=DEN
M9&5X)UU=*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W)E861);F1E>"@D9&%T
M82P@)&EN9&5X7VAE861E<ELG4')E=DEN9&5X)UTI.PH@("`@("`@('T*("`@
M("`@("`D<&]S:71I;VX@*ST@,C0["B`@("`@("`@)&EC;W5N="`]("1I;F1E
M>%]H96%D97);)T-O=6YT)UT@/CX@.#L*("`@("`@("!I9B`H)&EC;W5N="`^
M(#`I('L*("`@("`@("`@("`@)&)U9B`]('-U8G-T<B@D9&%T82P@)'!O<VET
M:6]N+"`Q,B`J("1I8V]U;G0I.PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@
M)&D@/"`D:6-O=6YT.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D:&1R7V)U
M9B`]('-U8G-T<B@D8G5F+"`D:2`J(#$R+"`Q,BD["B`@("`@("`@("`@("`@
M("`D26YD97A)=&5M(#T@=6YP86-K*"=,2&5A9&5R4&]S+TQ#:&EL9$EN9&5X
M+TQ5;FMN;W=N)RP@)&AD<E]B=68I.PH@("`@("`@("`@("`@("`@:68@*"1)
M;F1E>$ET96U;)TAE861E<E!O<R==(#X@,"D@>PH@("`@("`@("`@("`@("`@
M("`@("1M86EL6R=I;F9O)UT@/2`D=&AI<RT^7W)E861-97-S86=E26YF;R@D
M9&%T82P@)$EN9&5X271E;5LG2&5A9&5R4&]S)UTI.PH@("`@("`@("`@("`@
M("`@("`@("1M86EL6R=C;VYT96YT)UT@/2`D=&AI<RT^7W)E861-97-S86=E
M*"1D871A+"`D;6%I;%LG:6YF;R==6R=P;W-I=&EO;B==*3L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7VUA:6QS6UT@/2`D;6%I;#L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@H)$EN9&5X271E;5LG0VAI
M;&1);F1E>"==(#X@,"D@)B8*("`@("`@("`@("`@("`@("`@("!E;7!T>2@D
M=&AI<RT^7W1M<%LD26YD97A)=&5M6R=#:&EL9$EN9&5X)UU=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5A9$EN9&5X*"1F<"P@)$EN9&5X
M271E;5LG0VAI;&1);F1E>"==*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@('T*"GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<```````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,S0W,S,@,3`U,34T,S,W,S<@,#(R
M-#<R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"@HO*BH*("H@1F]R(&1E8V]M<')E<W,H*2P@<F5T=7)N(&$@;&ES
M="!O9B!F:6QE<R]I;F9O<FUA=&EO;B!A8F]U="!T:&4@>FEP9FEL92X*("HO
M"F1E9FEN92@G2$]21$5?0T]-4%)%4U-?6DE07TQ)4U0G+"`Q*3L*"B\J*@H@
M*B!&;W(@9&5C;VUP<F5S<R@I+"!R971U<FX@=&AE(&1A=&$@9F]R(&%N(&EN
M9&EV:61U86P@9FEL92!I;B!T:&4@>FEP9FEL92X*("HO"F1E9FEN92@G2$]2
M1$5?0T]-4%)%4U-?6DE07T1!5$$G+"`R*3L*"B\J*@H@*B!4:&4@2&]R9&5?
M0V]M<')E<W-?>FEP(&-L87-S(&%L;&]W<R!:25`@9FEL97,@=&\@8F4@8W)E
M871E9"!A;F0*("H@<F5A9"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O>FEP+G!H<"QV(#$N,3$N,3(N,38@,C`P-B\P-B\R
M.2`P.#HS-#HS,"!J86X@17AP("0*("H*("H@5&AE(%I)4"!C;VUP<F5S<VEO
M;B!C;V1E(&ES('!A<G1I86QL>2!B87-E9"!O;B!C;V1E(&9R;VTZ"B`J("`@
M17)I8R!-=65L;&5R(#QE<FEC0'1H96UE<&%R:RYC;VT^"B`J("`@:'1T<#HO
M+W=W=RYZ96YD+F-O;2]C;V1E>"YP:'`_:60]-3,U)G-I;F=L93TQ"B`J"B`J
M("`@1&5I;G,Q,C4@/'=E8FUA<W1E<D!A=&QA;G0N<G4^"B`J("`@:'1T<#HO
M+W=W=RYZ96YD+F-O;2]C;V1E>"YP:'`_:60]-#<P)G-I;F=L93TQ"B`J"B`J
M(%1H92!:25`@8V]M<')E<W-I;VX@9&%T92!C;V1E(&ES('!A<G1I86QL>2!B
M87-E9"!O;B!C;V1E(&9R;VT*("H@("!0971E<B!,:7-T:6%K(#QM;&%D>4!U
M<V5R<RYS;W5R8V5F;W)G92YN970^"B`J"B`J($-O<'ER:6=H="`R,#`P+3(P
M,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER
M:6=H="`R,#`R+3(P,#8@36EC:&%E;"!#;V-H<F%N92`\;6EK94!G<F%F=&]N
M:&%L;"YC;RYN>CX*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6-H865L(%-L
M=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO
M<F1E+F]R9SX*("H@0&%U=&AO<B`@36EC:&%E;"!#;V-H<F%N92`\;6EK94!G
M<F%F=&]N:&%L;"YC;RYN>CX*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z
M(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!(
M;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?0V]M<')E<W,*("HO"F-L87-S
M($AO<F1E7T-O;7!R97-S7WII<"!E>'1E;F1S($AO<F1E7T-O;7!R97-S('L*
M"B`@("`O*BH*("`@("`J(%I)4"!C;VUP<F5S<VEO;B!M971H;V1S+@H@("`@
M("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?;65T:&]D
M<R`](&%R<F%Y*`H@("`@("`@(#!X,"`]/B`G3F]N92<L"B`@("`@("`@,'@Q
M(#T^("=3:')U;FLG+`H@("`@("`@(#!X,B`]/B`G4W5P97(@1F%S="<L"B`@
M("`@("`@,'@S(#T^("=&87-T)RP*("`@("`@("`P>#0@/3X@)TYO<FUA;"<L
M"B`@("`@("`@,'@U(#T^("=-87AI;75M)RP*("`@("`@("`P>#8@/3X@)TEM
M<&QO9&5D)RP*("`@("`@("`P>#@@/3X@)T1E9FQA=&5D)PH@("`@*3L*"B`@
M("`O*BH*("`@("`J($)E9VEN;FEN9R!O9B!C96YT<F%L(&1I<F5C=&]R>2!R
M96-O<F0N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1?8W1R;$1I<DAE861E<B`](")<>#4P7'@T8EQX,#%<>#`R(CL*"B`@
M("`O*BH*("`@("`J($5N9"!O9B!C96YT<F%L(&1I<F5C=&]R>2!R96-O<F0N
M"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?
M8W1R;$1I<D5N9"`](")<>#4P7'@T8EQX,#5<>#`V7'@P,%QX,#!<>#`P7'@P
M,"(["@H@("`@+RHJ"B`@("`@*B!"96=I;FYI;F<@;V8@9FEL92!C;VYT96YT
M<RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@
M)%]F:6QE2&5A9&5R(#T@(EQX-3!<>#1B7'@P,UQX,#0B.PH*("`@("\J*@H@
M("`@("H@0W)E871E(&$@6DE0(&-O;7!R97-S960@9FEL92!F<F]M(&%N(&%R
M<F%Y(&]F(&9I;&4@9&%T82X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)&1A=&$@("`@5&AE(&1A=&$@=&\@8V]M<')E<W,N"B`@("`@*B`\<')E/@H@
M("`@("H@4F5Q=6ER97,@86X@87)R87D@;V8@87)R87ES("T@96%C:"!S=6)A
M<G)A>2!S:&]U;&0@8V]N=&%I;B!T:&4*("`@("`J(&9O;&QO=VEN9R!F:65L
M9',Z"B`@("`@*B`G9&%T82<@*'-T<FEN9RD@("`M+2`@5&AE(&1A=&$@=&\@
M8V]M<')E<W,N"B`@("`@*B`G;F%M92<@*'-T<FEN9RD@("`M+2`@5&AE('!A
M=&AN86UE('1O('1H92!F:6QE+@H@("`@("H@)W1I;64G("AI;G1E9V5R*2`@
M+2T@(%MO<'1I;VYA;%T@5&AE('1I;65S=&%M<"!T;R!U<V4@9F]R('1H92!F
M:6QE+@H@("`@("H@/"]P<F4^"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M
M<R`@5&AE('!A<F%M971E<B!A<G)A>2`H56YU<V5D*2X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE(%I)4"!F:6QE+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!C;VUP<F5S<R@D9&%T82P@)'!A<F%M<R`](&%R<F%Y*"DI"B`@
M("!["B`@("`@("`@)&-O;G1E;G1S(#T@)&-T<FQD:7(@/2!A<G)A>2@I.PH*
M("`@("`@("!F;W)E86-H("@D9&%T82!A<R`D=F%L*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?861D5&]:25!&:6QE*"1V86PL("1C;VYT96YT<RP@)&-T<FQD
M:7(I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8W)E871E
M6DE01FEL92@D8V]N=&5N=',L("1C=')L9&ER*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($1E8V]M<')E<W,@82!:25`@9FEL92!A;F0@9V5T(&EN9F]R;6%T
M:6]N(&9R;VT@:70N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&%T
M82`@(%1H92!Z:7!F:6QE(&1A=&$N"B`@("`@*B!`<&%R86T@87)R87D@)'!A
M<F%M<R`@5&AE('!A<F%M971E<B!A<G)A>2X*("`@("`J(#QP<F4^"B`@("`@
M*B!4:&4@9F]L;&]W:6YG('!A<F%M971E<G,@87)E(%)%455)4D5$.@H@("`@
M("H@)V%C=&EO;B<@*&EN=&5G97(I("`]/B`@5&AE(&%C=&EO;B!T;R!T86ME
M(&]N('1H92!D871A+B`@16ET:&5R"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("!(3U)$15]#3TU04D534U]:25!?3$E35"!O<@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@2$]21$5?0T]-4%)%4U-?6DE07T1!5$$N
M"B`@("`@*@H@("`@("H@5&AE(&9O;&QO=VEN9R!P87)A;65T97)S(&%R92!2
M15%525)%1"!F;W(@2$]21$5?0T]-4%)%4U-?6DE07T1!5$$@86QS;SH*("`@
M("`J("=I;F9O)R`H87)R87DI("`@/3X@(%1H92!Z:7!F:6QE(&QI<W0N"B`@
M("`@*B`G:V5Y)R`H:6YT96=E<BD@(#T^("!4:&4@<&]S:71I;VX@;V8@=&AE
M(&9I;&4@:6X@=&AE(&%R8VAI=F4@;&ES="X*("`@("`J(#PO<')E/@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!R97%U97-T960@9&%T82X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9&5C;VUP<F5S<R@D9&%T82P@)'!A<F%M
M<RD*("`@('L*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG86-T:6]N)UTI
M*2!["B`@("`@("`@("`@(&EF("@D<&%R86US6R=A8W1I;VXG72`]/2!(3U)$
M15]#3TU04D534U]:25!?3$E35"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?9V5T6FEP26YF;R@D9&%T82D["B`@("`@("`@("`@('T@96QS
M96EF("@D<&%R86US6R=A8W1I;VXG72`]/2!(3U)$15]#3TU04D534U]:25!?
M1$%402D@>PH@("`@("`@("`@("`@("`@+R\@5$]$3SH@0VAE8VL@9F]R('!A
M<F%M971E<G,N"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]G971:
M:7!$871A*"1D871A+"`D<&%R86US6R=I;F9O)UTL("1P87)A;7-;)VME>2==
M*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G
M:79E;BXB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(EEO=2!M
M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB*2P@)VAO<F1E
M+F5R<F]R)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE(&QI<W0@
M;V8@9FEL97,O9&%T82!F<F]M('1H92!Z:7`@87)C:&EV92X*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("8D9&%T82`@5&AE('II<&9I;&4@9&%T82X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!+15DZ(%!O<VET:6]N(&EN('II<&9I;&4*("`@("`J
M("`@("`@("`@("`@("`@(%9!3%5%4SH@)V%T='(G("`@("TM("!&:6QE(&%T
M=')I8G5T97,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@)V-R8R<@
M("`@("TM("!#4D,@8VAE8VMS=6T*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@)V-S:7IE)R`@("TM("!#;VUP<F5S<V5D(&9I;&4@<VEZ90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`G9&%T92<@("`@+2T@($9I;&4@
M;6]D:69I8V%T:6]N('1I;64*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@)VYA;64G("`@("TM("!&:6QE;F%M90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`G;65T:&]D)R`@+2T@($-O;7!R97-S:6]N(&UE=&AO9`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`G<VEZ92<@("`@+2T@($]R
M:6=I;F%L(&9I;&4@<VEZ90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`G='EP92<@("`@+2T@($9I;&4@='EP90H@("`@("HO"B`@("!F=6YC=&EO
M;B!?9V5T6FEP26YF;R@F)&1A=&$I"B`@("!["B`@("`@("`@)&5N=')I97,@
M/2!A<G)A>2@I.PH*("`@("`@("`O*B!'970@9&5T86EL<R!F<F]M($-E;G1R
M86P@9&ER96-T;W)Y('-T<G5C='5R92X@*B\*("`@("`@("`D9FA3=&%R="`]
M('-T<G!O<R@D9&%T82P@)'1H:7,M/E]C=')L1&ER2&5A9&5R*3L*"B`@("`@
M("`@9&\@>PH@("`@("`@("`@("!I9B`H<W1R;&5N*"1D871A*2`\("1F:%-T
M87)T("L@,S$I('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*%\H(DEN=F%L:60@6DE0(&1A=&$B*2D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)&EN9F\@/2!U;G!A8VLH)W9-971H;V0O5E1I;64O5D-2
M0S,R+U9#;VUP<F5S<V5D+U95;F-O;7!R97-S960O=DQE;F=T:"<L('-U8G-T
M<B@D9&%T82P@)&9H4W1A<G0@*R`Q,"P@,C`I*3L*("`@("`@("`@("`@)&YA
M;64@/2!S=6)S='(H)&1A=&$L("1F:%-T87)T("L@-#8L("1I;F9O6R=,96YG
M=&@G72D["@H@("`@("`@("`@("`D96YT<FEE<ULD;F%M95T@/2!A<G)A>2@*
M("`@("`@("`@("`@("`@("=A='1R)R`]/B!N=6QL+`H@("`@("`@("`@("`@
M("`@)V-R8R<@/3X@<W!R:6YT9B@B)3`X<R(L(&1E8VAE>"@D:6YF;ULG0U)#
M,S(G72DI+`H@("`@("`@("`@("`@("`@)V-S:7IE)R`]/B`D:6YF;ULG0V]M
M<')E<W-E9"==+`H@("`@("`@("`@("`@("`@)V1A=&4G(#T^(&YU;&PL"B`@
M("`@("`@("`@("`@("`G7V1A=&%3=&%R="<@/3X@;G5L;"P*("`@("`@("`@
M("`@("`@("=N86UE)R`]/B`D;F%M92P*("`@("`@("`@("`@("`@("=M971H
M;V0G(#T^("1T:&ES+3Y?;65T:&]D<ULD:6YF;ULG365T:&]D)UU=+`H@("`@
M("`@("`@("`@("`@)U]M971H;V0G(#T^("1I;F9O6R=-971H;V0G72P*("`@
M("`@("`@("`@("`@("=S:7IE)R`]/B`D:6YF;ULG56YC;VUP<F5S<V5D)UTL
M"B`@("`@("`@("`@("`@("`G='EP92<@/3X@;G5L;`H@("`@("`@("`@("`I
M.PH*("`@("`@("`@("`@)&5N=')I97-;)&YA;65=6R=D871E)UT@/0H@("`@
M("`@("`@("`@("`@;6MT:6UE*"@H)&EN9F];)U1I;64G72`^/B`Q,2D@)B`P
M>#%F*2P*("`@("`@("`@("`@("`@("`@("`@("`H*"1I;F9O6R=4:6UE)UT@
M/CX@-2D@)B`P>#-F*2P*("`@("`@("`@("`@("`@("`@("`@("`H*"1I;F9O
M6R=4:6UE)UT@/#P@,2D@)B`P>#-E*2P*("`@("`@("`@("`@("`@("`@("`@
M("`H*"1I;F9O6R=4:6UE)UT@/CX@,C$I("8@,'@P-RDL"B`@("`@("`@("`@
M("`@("`@("`@("`@*"@D:6YF;ULG5&EM92==(#X^(#$V*2`F(#!X,68I+`H@
M("`@("`@("`@("`@("`@("`@("`@("@H*"1I;F9O6R=4:6UE)UT@/CX@,C4I
M("8@,'@W9BD@*R`Q.3@P*2D["@H@("`@("`@("`@("!I9B`H<W1R;&5N*"1D
M871A*2`\("1F:%-T87)T("L@-#,I('L*("`@("`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(DEN=F%L:60@6DE0(&1A=&$B*2D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)&EN9F\@/2!U;G!A8VLH)W9);G1E
M<FYA;"]617AT97)N86PG+"!S=6)S='(H)&1A=&$L("1F:%-T87)T("L@,S8L
M(#8I*3L*"B`@("`@("`@("`@("1E;G1R:65S6R1N86UE75LG='EP92==(#T@
M*"1I;F9O6R=);G1E<FYA;"==("8@,'@P,2D@/R`G=&5X="<@.B`G8FEN87)Y
M)SL*("`@("`@("`@("`@)&5N=')I97-;)&YA;65=6R=A='1R)UT@/0H@("`@
M("`@("`@("`@("`@*"@D:6YF;ULG17AT97)N86PG72`F(#!X,3`I(#\@)T0G
M(#H@)RTG*2`N"B`@("`@("`@("`@("`@("`H*"1I;F9O6R=%>'1E<FYA;"==
M("8@,'@R,"D@/R`G02<@.B`G+2<I("X*("`@("`@("`@("`@("`@("@H)&EN
M9F];)T5X=&5R;F%L)UT@)B`P>#`S*2`_("=3)R`Z("<M)RD@+@H@("`@("`@
M("`@("`@("`@*"@D:6YF;ULG17AT97)N86PG72`F(#!X,#(I(#\@)T@G(#H@
M)RTG*2`N"B`@("`@("`@("`@("`@("`H*"1I;F9O6R=%>'1E<FYA;"==("8@
M,'@P,2D@/R`G4B<@.B`G+2<I.PH@("`@("`@('T@=VAI;&4@*"@D9FA3=&%R
M="`]('-T<G!O<R@D9&%T82P@)'1H:7,M/E]C=')L1&ER2&5A9&5R+"`D9FA3
M=&%R="`K(#0V*2D@(3T](&9A;'-E*3L*"B`@("`@("`@+RH@1V5T(&1E=&%I
M;',@9G)O;2!L;V-A;"!F:6QE(&AE861E<BX@*B\*("`@("`@("`D9FA3=&%R
M="`]('-T<G!O<R@D9&%T82P@)'1H:7,M/E]F:6QE2&5A9&5R*3L*"B`@("`@
M("`@9&\@>PH@("`@("`@("`@("!I9B`H<W1R;&5N*"1D871A*2`\("1F:%-T
M87)T("L@,S0I('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*%\H(DEN=F%L:60@6DE0(&1A=&$B*2D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)&EN9F\@/2!U;G!A8VLH)W9-971H;V0O5E1I;64O5D-2
M0S,R+U9#;VUP<F5S<V5D+U95;F-O;7!R97-S960O=DQE;F=T:"]V17AT<F%,
M96YG=&@G+"!S=6)S='(H)&1A=&$L("1F:%-T87)T("L@."P@,C4I*3L*("`@
M("`@("`@("`@)&YA;64@/2!S=6)S='(H)&1A=&$L("1F:%-T87)T("L@,S`L
M("1I;F9O6R=,96YG=&@G72D["B`@("`@("`@("`@("1E;G1R:65S6R1N86UE
M75LG7V1A=&%3=&%R="==(#T@)&9H4W1A<G0@*R`S,"`K("1I;F9O6R=,96YG
M=&@G72`K("1I;F9O6R=%>'1R84QE;F=T:"==.PH@("`@("`@('T@=VAI;&4@
M*'-T<FQE;B@D9&%T82D@/B`D9FA3=&%R="`K(#,P("L@)&EN9F];)TQE;F=T
M:"==("8F"B`@("`@("`@("`@("`@("`@*"1F:%-T87)T(#T@<W1R<&]S*"1D
M871A+"`D=&AI<RT^7V9I;&5(96%D97(L("1F:%-T87)T("L@,S`@*R`D:6YF
M;ULG3&5N9W1H)UTI*2`A/3T@9F%L<V4I.PH*("`@("`@("!R971U<FX@87)R
M87E?=F%L=65S*"1E;G1R:65S*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE(&1A=&$@9F]R(&$@<W!E8VEF:6,@87)C:&EV960@9FEL92X*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("8D9&%T82`@5&AE('II<"!A<F-H:79E(&-O;G1E;G1S
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("8D:6YF;R`@(%1H92!I;F9O<FUA=&EO
M;B!A<G)A>2!F<F]M(%]G971::7!);F9O*"DN"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D:V5Y("`@5&AE('!O<VET:6]N(&]F('1H92!F:6QE(&EN('1H92!A
M<F-H:79E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9FEL
M92!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T6FEP1&%T82@F)&1A
M=&$L("8D:6YF;RP@)&ME>2D*("`@('L*("`@("`@("!I9B`H*"1I;F9O6R1K
M97E=6R=?;65T:&]D)UT@/3T@,'@X*2`F)B!5=&EL.CIE>'1E;G-I;VY%>&ES
M=',H)WIL:6(G*2D@>PH@("`@("`@("`@("`O*B!)9B!T:&4@9FEL92!H87,@
M8F5E;B!D969L871E9"P@86YD('IL:6(@:7,@:6YS=&%L;&5D+`H@("`@("`@
M("`@("`@("!T:&5N(&EN9FQA=&4@=&AE(&1A=&$@86=A:6XN("HO"B`@("`@
M("`@("`@(')E='5R;B!`9WII;F9L871E*'-U8G-T<B@D9&%T82P@)&EN9F];
M)&ME>5U;)U]D871A4W1A<G0G72P@)&EN9F];)&ME>5U;)V-S:7IE)UTI*3L*
M("`@("`@("!](&5L<V5I9B`H)&EN9F];)&ME>5U;)U]M971H;V0G72`]/2`P
M>#`I('L*("`@("`@("`@("`@+RH@1FEL97,@=&AA="!A<F5N)W0@8V]M<')E
M<W-E9"X@*B\*("`@("`@("`@("`@<F5T=7)N('-U8G-T<B@D9&%T82P@)&EN
M9F];)&ME>5U;)U]D871A4W1A<G0G72P@)&EN9F];)&ME>5U;)V-S:7IE)UTI
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("<G.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0VAE8VMS('1O('-E92!I9B!T:&4@9&%T82!I<R!A('9A;&ED
M(%I)4"!F:6QE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)B1D871A
M("!4:&4@6DE0(&9I;&4@9&%T82X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%1R=64@:68@=F%L:60L(&9A;'-E(&EF(&EN=F%L:60N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-H96-K6FEP1&%T82@F)&1A=&$I"B`@("!["B`@
M("`@("`@:68@*'-T<G!O<R@D9&%T82P@)'1H:7,M/E]F:6QE2&5A9&5R*2`]
M/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E<G1S(&$@54Y)6"!T:6UE<W1A
M;7`@=&\@82`T+6)Y=&4@1$]3(&1A=&4@86YD('1I;64@9F]R;6%T"B`@("`@
M*B`H9&%T92!I;B!H:6=H(#(M8GET97,L('1I;64@:6X@;&]W(#(M8GET97,@
M86QL;W=I;F<@;6%G;FET=61E"B`@("`@*B!C;VUP87)I<V]N*2X*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D=6YI>'1I;64@(%1H92!C=7)R96YT(%5.25@@=&EM97-T86UP
M+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(&-U<G)E;G0@
M9&%T92!I;B!A(#0M8GET92!$3U,@9F]R;6%T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?=6YI>#)$3U-4:6UE*"1U;FEX=&EM92`](&YU;&PI"B`@("!["B`@
M("`@("`@)'1I;65A<G)A>2`]("AI<U]N=6QL*"1U;FEX=&EM92DI(#\@9V5T
M9&%T92@I(#H@9V5T9&%T92@D=6YI>'1I;64I.PH*("`@("`@("!I9B`H)'1I
M;65A<G)A>5LG>65A<B==(#P@,3DX,"D@>PH@("`@("`@("`@("`D=&EM96%R
M<F%Y6R=Y96%R)UT@("`@/2`Q.3@P.PH@("`@("`@("`@("`D=&EM96%R<F%Y
M6R=M;VXG72`@("`@/2`Q.PH@("`@("`@("`@("`D=&EM96%R<F%Y6R=M9&%Y
M)UT@("`@/2`Q.PH@("`@("`@("`@("`D=&EM96%R<F%Y6R=H;W5R<R==("`@
M/2`P.PH@("`@("`@("`@("`D=&EM96%R<F%Y6R=M:6YU=&5S)UT@/2`P.PH@
M("`@("`@("`@("`D=&EM96%R<F%Y6R=S96-O;F1S)UT@/2`P.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("@H)'1I;65A<G)A>5LG>65A<B==("T@,3DX
M,"D@/#P@,C4I('P*("`@("`@("`@("`@("`@("@D=&EM96%R<F%Y6R=M;VXG
M72`\/"`R,2D@?`H@("`@("`@("`@("`@("`@*"1T:6UE87)R87E;)VUD87DG
M72`\/"`Q-BD@?`H@("`@("`@("`@("`@("`@*"1T:6UE87)R87E;)VAO=7)S
M)UT@/#P@,3$I('P*("`@("`@("`@("`@("`@("@D=&EM96%R<F%Y6R=M:6YU
M=&5S)UT@/#P@-2D@?`H@("`@("`@("`@("`@("`@*"1T:6UE87)R87E;)W-E
M8V]N9',G72`^/B`Q*3L*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@82`B
M9FEL92(@=&\@=&AE(%I)4"!A<F-H:79E+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`F)&9I;&4@
M("`@("!3964@2&]R9&5?0V]M<')E<W-?>FEP.CIC<F5A=&5::7!&:6QE*"DN
M"B`@("`@*B!`<&%R86T@87)R87D@)B1C;VYT96YT<R`@06X@87)R87D@;V8@
M97AI<W1I;F<@>FEP<&5D(&9I;&5S+@H@("`@("H@0'!A<F%M(&%R<F%Y("8D
M8W1R;&1I<B`@($%N(&%R<F%Y(&]F(&-E;G1R86P@9&ER96-T;W)Y(&EN9F]R
M;6%T:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!?861D5&]:25!&:6QE*"8D
M9FEL92P@)B1C;VYT96YT<RP@)B1C=')L9&ER*0H@("`@>PH@("`@("`@("1D
M871A(#T@)B1F:6QE6R=D871A)UT["B`@("`@("`@)&YA;64@/2!S=')?<F5P
M;&%C92@G7%PG+"`G+R<L("1F:6QE6R=N86UE)UTI.PH*("`@("`@("`O*B!3
M964@:68@=&EM92]D871E(&EN9F]R;6%T:6]N(&AA<R!B965N('!R;W9I9&5D
M+B`J+PH@("`@("`@("1F=&EM92`](&YU;&P["B`@("`@("`@:68@*&ES<V5T
M*"1F:6QE6R=T:6UE)UTI*2!["B`@("`@("`@("`@("1F=&EM92`]("1F:6QE
M6R=T:6UE)UT["B`@("`@("`@?0H*("`@("`@("`O*B!'970@=&AE(&AE>"!T
M:6UE+B`J+PH@("`@("`@("1D=&EM92`@("`](&1E8VAE>"@D=&AI<RT^7W5N
M:7@R1&]S5&EM92@D9G1I;64I*3L*("`@("`@("`D:&5X9'1I;64@/2!C:'(H
M:&5X9&5C*"1D=&EM95LV72`N("1D=&EM95LW72DI("X*("`@("`@("`@("`@
M("`@("`@("!C:'(H:&5X9&5C*"1D=&EM95LT72`N("1D=&EM95LU72DI("X*
M("`@("`@("`@("`@("`@("`@("!C:'(H:&5X9&5C*"1D=&EM95LR72`N("1D
M=&EM95LS72DI("X*("`@("`@("`@("`@("`@("`@("!C:'(H:&5X9&5C*"1D
M=&EM95LP72`N("1D=&EM95LQ72DI.PH*("`@("`@("`D9G(@(#T@)'1H:7,M
M/E]F:6QE2&5A9&5R.R`@("\J($)E9VEN(&-R96%T:6YG('1H92!:25`@9&%T
M82X@*B\*("`@("`@("`D9G(@+CT@(EQX,31<>#`P(CL@("`@("`@("`@("\J
M(%9E<G-I;VX@;F5E9&5D('1O(&5X=')A8W0N("HO"B`@("`@("`@)&9R("X]
M(")<>#`P7'@P,"([("`@("`@("`@("`O*B!'96YE<F%L('!U<G!O<V4@8FET
M(&9L86<N("HO"B`@("`@("`@)&9R("X](")<>#`X7'@P,"([("`@("`@("`@
M("`O*B!#;VUP<F5S<VEO;B!M971H;V0N("HO"B`@("`@("`@)&9R("X]("1H
M97AD=&EM93L@("`@("`@("`@("`O*B!,87-T(&UO9&EF:6-A=&EO;B!T:6UE
M+V1A=&4N("HO"@H@("`@("`@("\J("),;V-A;"!F:6QE(&AE861E<B(@<V5G
M;65N="X@*B\*("`@("`@("`D=6YC7VQE;B`]('-T<FQE;B@D9&%T82D["B`@
M("`@("`@)&-R8R`@("`@/2!C<F,S,B@D9&%T82D["B`@("`@("`@)'ID871A
M("`@/2!G>F-O;7!R97-S*"1D871A*3L*("`@("`@("`D>F1A=&$@("`]('-U
M8G-T<BAS=6)S='(H)'ID871A+"`P+"!S=')L96XH)'ID871A*2`M(#0I+"`R
M*3L*("`@("`@("`D8U]L96X@("`]('-T<FQE;B@D>F1A=&$I.PH*("`@("`@
M("`D9G(@+CT@<&%C:R@G5B<L("1C<F,I.R`@("`@("`@("`@("\J($-20R`S
M,B!I;F9O<FUA=&EO;BX@*B\*("`@("`@("`D9G(@+CT@<&%C:R@G5B<L("1C
M7VQE;BD[("`@("`@("`@("\J($-O;7!R97-S960@9FEL97-I>F4N("HO"B`@
M("`@("`@)&9R("X]('!A8VLH)U8G+"`D=6YC7VQE;BD[("`@("`@("`O*B!5
M;F-O;7!R97-S960@9FEL97-I>F4N("HO"B`@("`@("`@)&9R("X]('!A8VLH
M)W8G+"!S=')L96XH)&YA;64I*3L@("`O*B!,96YG=&@@;V8@9FEL96YA;64N
M("HO"B`@("`@("`@)&9R("X]('!A8VLH)W8G+"`P*3L@("`@("`@("`@("`@
M("`O*B!%>'1R82!F:65L9"!L96YG=&@N("HO"B`@("`@("`@)&9R("X]("1N
M86UE.R`@("`@("`@("`@("`@("`@("`@("`O*B!&:6QE(&YA;64N("HO"@H@
M("`@("`@("\J(")&:6QE(&1A=&$B('-E9VUE;G0N("HO"B`@("`@("`@)&9R
M("X]("1Z9&%T83L*"B`@("`@("`@+RH@(D1A=&$@9&5S8W)I<'1O<B(@<V5G
M;65N="`H;W!T:6]N86P@8G5T(&YE8V5S<V%R>2!I9B!A<F-H:79E(&ES"B`@
M("`@("`@("`@;F]T('-E<G9E9"!A<R!F:6QE*2X@*B\*("`@("`@("`D9G(@
M+CT@<&%C:R@G5B<L("1C<F,I.PH@("`@("`@("1F<B`N/2!P86-K*"=6)RP@
M)&-?;&5N*3L*("`@("`@("`D9G(@+CT@<&%C:R@G5B<L("1U;F-?;&5N*3L*
M"B`@("`@("`@+RH@061D('1H:7,@96YT<GD@=&\@87)R87DN("HO"B`@("`@
M("`@)&]L9%]O9F9S970@/2!S=')L96XH:6UP;&]D92@G)RP@)&-O;G1E;G1S
M*2D["B`@("`@("`@)&-O;G1E;G1S6UT@/2`F)&9R.PH*("`@("`@("`O*B!!
M9&0@=&\@8V5N=')A;"!D:7)E8W1O<GD@<F5C;W)D+B`J+PH@("`@("`@("1C
M9')E8R`@/2`D=&AI<RT^7V-T<FQ$:7)(96%D97(["B`@("`@("`@)&-D<F5C
M("X](")<>#`P7'@P,"([("`@("`@("`@("`@("`@("\J(%9E<G-I;VX@;6%D
M92!B>2X@*B\*("`@("`@("`D8V1R96,@+CT@(EQX,31<>#`P(CL@("`@("`@
M("`@("`@("`@+RH@5F5R<VEO;B!N965D960@=&\@97AT<F%C="`J+PH@("`@
M("`@("1C9')E8R`N/2`B7'@P,%QX,#`B.R`@("`@("`@("`@("`@("`O*B!'
M96YE<F%L('!U<G!O<V4@8FET(&9L86<@*B\*("`@("`@("`D8V1R96,@+CT@
M(EQX,#A<>#`P(CL@("`@("`@("`@("`@("`@+RH@0V]M<')E<W-I;VX@;65T
M:&]D("HO"B`@("`@("`@)&-D<F5C("X]("1H97AD=&EM93L@("`@("`@("`@
M("`@("`@("\J($QA<W0@;6]D('1I;64O9&%T92X@*B\*("`@("`@("`D8V1R
M96,@+CT@<&%C:R@G5B<L("1C<F,I.R`@("`@("`@("`@+RH@0U)#(#,R(&EN
M9F]R;6%T:6]N+B`J+PH@("`@("`@("1C9')E8R`N/2!P86-K*"=6)RP@)&-?
M;&5N*3L@("`@("`@("`O*B!#;VUP<F5S<V5D(&9I;&5S:7IE+B`J+PH@("`@
M("`@("1C9')E8R`N/2!P86-K*"=6)RP@)'5N8U]L96XI.R`@("`@("`O*B!5
M;F-O;7!R97-S960@9FEL97-I>F4N("HO"B`@("`@("`@)&-D<F5C("X]('!A
M8VLH)W8G+"!S=')L96XH)&YA;64I*3L@("\J($QE;F=T:"!O9B!F:6QE;F%M
M92X@*B\*("`@("`@("`D8V1R96,@+CT@<&%C:R@G=B<L(#`I.R`@("`@("`@
M("`@("`@+RH@17AT<F$@9FEE;&0@;&5N9W1H+B`J+PH@("`@("`@("1C9')E
M8R`N/2!P86-K*"=V)RP@,"D[("`@("`@("`@("`@("`O*B!&:6QE(&-O;6UE
M;G0@;&5N9W1H+B`J+PH@("`@("`@("1C9')E8R`N/2!P86-K*"=V)RP@,"D[
M("`@("`@("`@("`@("`O*B!$:7-K(&YU;6)E<B!S=&%R="X@*B\*("`@("`@
M("`D8V1R96,@+CT@<&%C:R@G=B<L(#`I.R`@("`@("`@("`@("`@+RH@26YT
M97)N86P@9FEL92!A='1R:6)U=&5S+B`J+PH@("`@("`@("1C9')E8R`N/2!P
M86-K*"=6)RP@,S(I.R`@("`@("`@("`@("`O*B!%>'1E<FYA;"!F:6QE(&%T
M=')I8G5T97,@+0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G87)C:&EV92<@8FET('-E="X@*B\*("`@("`@("`D
M8V1R96,@+CT@<&%C:R@G5B<L("1O;&1?;V9F<V5T*3L@("`@+RH@4F5L871I
M=F4@;V9F<V5T(&]F(&QO8V%L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&AE861E<BX@*B\*("`@("`@("`D8V1R
M96,@+CT@)&YA;64[("`@("`@("`@("`@("`@("`@("`@+RH@1FEL92!N86UE
M+B`J+PH@("`@("`@("\J($]P=&EO;F%L(&5X=')A(&9I96QD+"!F:6QE(&-O
M;6UE;G0@9V]E<R!H97)E+B`J+PH*("`@("`@("`O+R!3879E('1O(&-E;G1R
M86P@9&ER96-T;W)Y(&%R<F%Y+B`J+PH@("`@("`@("1C=')L9&ER6UT@/2`F
M)&-D<F5C.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E<R!T:&4@6DE0
M(&9I;&4N"B`@("`@*B!/9F9I8VEA;"!:25`@9FEL92!F;W)M870Z(&AT='`Z
M+R]W=W<N<&MW87)E+F-O;2]A<'!N;W1E+G1X=`H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@6DE0(&9I;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C<F5A=&5:25!&
M:6QE*"8D8V]N=&5N=',L("8D8W1R;$1I<BD*("`@('L*("`@("`@("`D9&%T
M82`](&EM<&QO9&4H)R<L("1C;VYT96YT<RD["B`@("`@("`@)&1I<B`](&EM
M<&QO9&4H)R<L("1C=')L1&ER*3L*"B`@("`@("`@<F5T=7)N("1D871A("X@
M)&1I<B`N("1T:&ES+3Y?8W1R;$1I<D5N9"`N"B`@("`@("`@("`@("\J(%1O
M=&%L(",@;V8@96YT<FEE<R`B;VX@=&AI<R!D:7-K(BX@*B\*("`@("`@("`@
M("`@<&%C:R@G=B<L(&-O=6YT*"1C=')L1&ER*2D@+@H@("`@("`@("`@("`O
M*B!4;W1A;"`C(&]F(&5N=')I97,@;W9E<F%L;"X@*B\*("`@("`@("`@("`@
M<&%C:R@G=B<L(&-O=6YT*"1C=')L1&ER*2D@+@H@("`@("`@("`@("`O*B!3
M:7IE(&]F(&-E;G1R86P@9&ER96-T;W)Y+B`J+PH@("`@("`@("`@("!P86-K
M*"=6)RP@<W1R;&5N*"1D:7(I*2`N"B`@("`@("`@("`@("\J($]F9G-E="!T
M;R!S=&%R="!O9B!C96YT<F%L(&1I<BX@*B\*("`@("`@("`@("`@<&%C:R@G
M5B<L('-T<FQE;B@D9&%T82DI("X*("`@("`@("`@("`@+RH@6DE0(&9I;&4@
M8V]M;65N="!L96YG=&@N("HO"B`@("`@("`@("`@(")<>#`P7'@P,"(["B`@
M("!]"@I]"@````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O0V]M<')E<W,O=&%R
M+G!H<```````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#<W-30@
M,3`U,34T,S,W,S<@,#(R-#8Q`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B!4:&4@2&]R9&5?0V]M<')E
M<W-?=&%R(&-L87-S(&%L;&]W<R!T87(@9FEL97,@=&\@8F4@<F5A9"X*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O=&%R+G!H
M<"QV(#$N-"XQ,BXY(#(P,#8O,#0O,S`@,C(Z,C@Z,CD@8VAU8VL@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L($-O8VAR86YE(#QM
M:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V
M($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D
M=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI8VAA96P@0V]C:')A
M;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!A=71H;W(@($UI8VAA
M96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@
M0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T-O;7!R97-S
M"B`J+PIC;&%S<R!(;W)D95]#;VUP<F5S<U]T87(@97AT96YD<R!(;W)D95]#
M;VUP<F5S<R!["@H@("`@+RHJ"B`@("`@*B!487(@9FEL92!T>7!E<RX*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W1Y<&5S
M(#T@87)R87DH"B`@("`@("`@,'@P("`@/3X@("=5;FEX(&9I;&4G+`H@("`@
M("`@(#!X,S`@(#T^("`G1FEL92<L"B`@("`@("`@,'@S,2`@/3X@("=,:6YK
M)RP*("`@("`@("`P>#,R("`]/B`@)U-Y;6)O;&EC(&QI;FLG+`H@("`@("`@
M(#!X,S,@(#T^("`G0VAA<F%C=&5R('-P96-I86P@9FEL92<L"B`@("`@("`@
M,'@S-"`@/3X@("=";&]C:R!S<&5C:6%L(&9I;&4G+`H@("`@("`@(#!X,S4@
M(#T^("`G1&ER96-T;W)Y)RP*("`@("`@("`P>#,V("`]/B`@)T9)1D\@<W!E
M8VEA;"!F:6QE)RP*("`@("`@("`P>#,W("`]/B`@)T-O;G1I9W5O=7,@9FEL
M92<*("`@("D["@H@("`@+RHJ"B`@("`@*B!487(@9FEL92!F;&%G<RX*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V9L86=S
M(#T@87)R87DH"B`@("`@("`@)T9415A4)R`@("`@/3X@(#!X,#$L"B`@("`@
M("`@)T9(0U)#)R`@("`@/3X@(#!X,#(L"B`@("`@("`@)T9%6%1202<@("`@
M/3X@(#!X,#0L"B`@("`@("`@)T9.04U%)R`@("`@/3X@(#!X,#@L"B`@("`@
M("`@)T9#3TU-14Y4)R`@/3X@(#!X,3`*("`@("D["@H@("`@+RHJ"B`@("`@
M*B!$96-O;7!R97-S(&$@=&%R(&9I;&4@86YD(&=E="!I;F9O<FUA=&EO;B!F
M<F]M(&ET+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)B1D871A("`@
M5&AE('1A<B!F:6QE(&1A=&$N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M
M<R`@5&AE('!A<F%M971E<B!A<G)A>2`H56YU<V5D*2X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("!4:&4@<F5Q=65S=&5D(&1A=&$@;W(@4$5!4E]%
M<G)O<B!O;B!E<G)O<BX*("`@("`J(#QP<F4^"B`@("`@*B!+15DZ(%!O<VET
M:6]N(&EN('1H92!A<G)A>0H@("`@("H@5D%,5453.B`G871T<B<@("TM("!&
M:6QE(&%T=')I8G5T97,*("`@("`J("`@("`@("`@)V1A=&$G("`M+2`@4F%W
M(&9I;&4@8V]N=&5N=',*("`@("`J("`@("`@("`@)V1A=&4G("`M+2`@1FEL
M92!M;V1I9FEC871I;VX@=&EM90H@("`@("H@("`@("`@("`G;F%M92<@("TM
M("!&:6QE;F%M90H@("`@("H@("`@("`@("`G<VEZ92<@("TM("!/<FEG:6YA
M;"!F:6QE('-I>F4*("`@("`J("`@("`@("`@)W1Y<&4G("`M+2`@1FEL92!T
M>7!E"B`@("`@*B`\+W!R93X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5C;VUP
M<F5S<R@F)&1A=&$L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@
M("1P;W-I=&EO;B`](#`["B`@("`@("`@)')E='5R;E]A<G)A>2`](&%R<F%Y
M*"D["@H@("`@("`@('=H:6QE("@D<&]S:71I;VX@/"!S=')L96XH)&1A=&$I
M*2!["B`@("`@("`@("`@("1I;F9O(#T@0'5N<&%C:R@B83$P,&9I;&5N86UE
M+V$X;6]D92]A.'5I9"]A.&=I9"]A,3)S:7IE+V$Q,FUT:6UE+V$X8VAE8VMS
M=6TO0W1Y<&5F;&%G+V$Q,#!L:6YK+V$V;6%G:6,O83)V97)S:6]N+V$S,G5N
M86UE+V$S,F=N86UE+V$X9&5V;6%J;W(O83AD979M:6YO<B(L('-U8G-T<B@D
M9&%T82P@)'!O<VET:6]N*2D["B`@("`@("`@("`@(&EF("@A)&EN9F\I('L*
M("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N
M86)L92!T;R!D96-O;7!R97-S(&1A=&$N(BDI.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`D<&]S:71I;VX@*ST@-3$R.PH@("`@("`@("`@("`D8V]N
M=&5N=',@/2!S=6)S='(H)&1A=&$L("1P;W-I=&EO;BP@;V-T9&5C*"1I;F9O
M6R=S:7IE)UTI*3L*("`@("`@("`@("`@)'!O<VET:6]N("L](&-E:6PH;V-T
M9&5C*"1I;F9O6R=S:7IE)UTI("\@-3$R*2`J(#4Q,CL*"B`@("`@("`@("`@
M(&EF("@D:6YF;ULG9FEL96YA;64G72D@>PH@("`@("`@("`@("`@("`@)&9I
M;&4@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G871T<B<@/3X@;G5L
M;"P*("`@("`@("`@("`@("`@("`@("`G9&%T82<@/3X@;G5L;"P*("`@("`@
M("`@("`@("`@("`@("`G9&%T92<@/3X@;V-T9&5C*"1I;F9O6R=M=&EM92==
M*2P*("`@("`@("`@("`@("`@("`@("`G;F%M92<@/3X@=')I;2@D:6YF;ULG
M9FEL96YA;64G72DL"B`@("`@("`@("`@("`@("`@("`@)W-I>F4G(#T^(&]C
M=&1E8R@D:6YF;ULG<VEZ92==*2P*("`@("`@("`@("`@("`@("`@("`G='EP
M92<@/3X@:7-S970H)'1H:7,M/E]T>7!E<ULD:6YF;ULG='EP969L86<G75TI
M(#\@)'1H:7,M/E]T>7!E<ULD:6YF;ULG='EP969L86<G75T@.B!N=6QL"B`@
M("`@("`@("`@("`@("`I.PH*("`@("`@("`@("`@("`@(&EF("@H)&EN9F];
M)W1Y<&5F;&%G)UT@/3T@,"D@?'P*("`@("`@("`@("`@("`@("`@("`H)&EN
M9F];)W1Y<&5F;&%G)UT@/3T@,'@S,"D@?'P*("`@("`@("`@("`@("`@("`@
M("`H)&EN9F];)W1Y<&5F;&%G)UT@/3T@,'@S-2DI('L*("`@("`@("`@("`@
M("`@("`@("`O*B!&:6QE(&]R(&9O;&1E<BX@*B\*("`@("`@("`@("`@("`@
M("`@("`D9FEL95LG9&%T82==(#T@)&-O;G1E;G1S.PH*("`@("`@("`@("`@
M("`@("`@("`D;6]D92`](&AE>&1E8RAS=6)S='(H)&EN9F];)VUO9&4G72P@
M-"P@,RDI.PH@("`@("`@("`@("`@("`@("`@("1F:6QE6R=A='1R)UT@/0H@
M("`@("`@("`@("`@("`@("`@("`@("`H*"1I;F9O6R=T>7!E9FQA9R==(#T]
M(#!X,S4I(#\@)V0G(#H@)RTG*2`N"B`@("`@("`@("`@("`@("`@("`@("`@
M("@H)&UO9&4@)B`P>#0P,"D@/R`G<B<@.B`G+2<I("X*("`@("`@("`@("`@
M("`@("`@("`@("`@*"@D;6]D92`F(#!X,C`P*2`_("=W)R`Z("<M)RD@+@H@
M("`@("`@("`@("`@("`@("`@("`@("`H*"1M;V1E("8@,'@Q,#`I(#\@)W@G
M(#H@)RTG*2`N"B`@("`@("`@("`@("`@("`@("`@("`@("@H)&UO9&4@)B`P
M>#`T,"D@/R`G<B<@.B`G+2<I("X*("`@("`@("`@("`@("`@("`@("`@("`@
M*"@D;6]D92`F(#!X,#(P*2`_("=W)R`Z("<M)RD@+@H@("`@("`@("`@("`@
M("`@("`@("`@("`H*"1M;V1E("8@,'@P,3`I(#\@)W@G(#H@)RTG*2`N"B`@
M("`@("`@("`@("`@("`@("`@("`@("@H)&UO9&4@)B`P>#`P-"D@/R`G<B<@
M.B`G+2<I("X*("`@("`@("`@("`@("`@("`@("`@("`@*"@D;6]D92`F(#!X
M,#`R*2`_("=W)R`Z("<M)RD@+@H@("`@("`@("`@("`@("`@("`@("`@("`H
M*"1M;V1E("8@,'@P,#$I(#\@)W@G(#H@)RTG*3L*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@+RH@4V]M92!O=&AE<B!T
M>7!E+B`J+PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1R
M971U<FY?87)R87E;72`]("1F:6QE.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)')E='5R;E]A<G)A>3L*("`@('T*"GT*````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M2&]R9&4O0V]M<')E<W,O9WII<"YP:'``````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#4T,3,@,3`U,34T,S,W,S<@,#(R-C,R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B!4:&4@2&]R9&5?0V]M<')E<W-?9WII<"!C;&%S<R!A;&QO=W,@9WII<"!F
M:6QE<R!T;R!B92!R96%D+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]#;VUP
M<F5S<R]#;VUP<F5S<R]G>FEP+G!H<"QV(#$N-RXQ,BXY(#(P,#8O,#0O,S`@
M,C(Z,C@Z,CD@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P
M-B!-:6-H865L($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@
M*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R
M>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($UI8VAA96P@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N
M;GH^"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W
M;W)M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P
M86-K86=E($AO<F1E7T-O;7!R97-S"B`J+PIC;&%S<R!(;W)D95]#;VUP<F5S
M<U]G>FEP(&5X=&5N9',@2&]R9&5?0V]M<')E<W,@>PH*("`@("\J*@H@("`@
M("H@1WII<"!F:6QE(&9L86=S+@H@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1?9FQA9W,@/2!A<G)A>2@*("`@("`@("`G1E1%
M6%0G("`@("`]/B`@,'@P,2P*("`@("`@("`G1DA#4D,G("`@("`]/B`@,'@P
M,BP*("`@("`@("`G1D585%)!)R`@("`]/B`@,'@P-"P*("`@("`@("`G1DY!
M344G("`@("`]/B`@,'@P."P*("`@("`@("`G1D-/34U%3E0G("`]/B`@,'@Q
M,`H@("`@*3L*"B`@("`O*BH*("`@("`J($1E8V]M<')E<W,@82!G>FEP(&9I
M;&4@86YD(&=E="!I;F9O<FUA=&EO;B!F<F]M(&ET+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)B1D871A("!4:&4@=&%R(&9I;&4@9&%T82X*("`@
M("`J($!P87)A;2!A<G)A>2`D<&%R86US("!4:&4@<&%R86UE=&5R(&%R<F%Y
M("A5;G5S960I+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M=6YC;VUP<F5S<V5D(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E8V]M
M<')E<W,H)B1D871A+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@
M("`O*B!)9B!G>FEP(&ES(&YO="!C;VUP:6QE9"!I;G1O(%!(4"P@<F5T=7)N
M(&YO=RX@*B\*("`@("`@("!I9B`H(55T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G
M>FQI8B<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP
M(&9I;&5S+B(I*3L*("`@("`@("!]"@H@("`@("`@("\J($=Z:7!P960@1FEL
M92`M(&1E8V]M<')E<W,@:70@9FER<W0N("HO"B`@("`@("`@)'!O<VET:6]N
M(#T@,#L*("`@("`@("`D:6YF;R`]($!U;G!A8VLH)T-#32]#1DQ'+U94:6UE
M+T-81DPO0T]3)RP@<W5B<W1R*"1D871A+"`D<&]S:71I;VX@*R`R*2D["B`@
M("`@("`@:68@*"$D:6YF;RD@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(I*3L*
M("`@("`@("!]"B`@("`@("`@)'!O<VET:6]N("L](#$P.PH*("`@("`@("!I
M9B`H)&EN9F];)T9,1R==("8@)'1H:7,M/E]F;&%G<ULG1D585%)!)UTI('L*
M("`@("`@("`@("`@)%A,14X@/2!U;G!A8VLH)W9,96YG=&@G+"!S=6)S='(H
M)&1A=&$L("1P;W-I=&EO;B`K(#`L(#(I*3L*("`@("`@("`@("`@)%A,14X@
M/2`D6$Q%3ELG3&5N9W1H)UT["B`@("`@("`@("`@("1P;W-I=&EO;B`K/2`D
M6$Q%3B`K(#(["B`@("`@("`@?0H*("`@("`@("!I9B`H)&EN9F];)T9,1R==
M("8@)'1H:7,M/E]F;&%G<ULG1DY!344G72D@>PH@("`@("`@("`@("`D9FEL
M96YA;650;W,@/2!S=')P;W,H)&1A=&$L(")<>#`B+"`D<&]S:71I;VXI.PH@
M("`@("`@("`@("`D9FEL96YA;64@/2!S=6)S='(H)&1A=&$L("1P;W-I=&EO
M;BP@)&9I;&5N86UE4&]S("T@)'!O<VET:6]N*3L*("`@("`@("`@("`@)'!O
M<VET:6]N(#T@)&9I;&5N86UE4&]S("L@,3L*("`@("`@("!]"@H@("`@("`@
M(&EF("@D:6YF;ULG1DQ')UT@)B`D=&AI<RT^7V9L86=S6R=&0T]-345.5"==
M*2!["B`@("`@("`@("`@("1C;VUM96YT4&]S(#T@<W1R<&]S*"1D871A+"`B
M7'@P(BP@)'!O<VET:6]N*3L*("`@("`@("`@("`@)&-O;6UE;G0@/2!S=6)S
M='(H)&1A=&$L("1P;W-I=&EO;BP@)&-O;6UE;G10;W,@+2`D<&]S:71I;VXI
M.PH@("`@("`@("`@("`D<&]S:71I;VX@/2`D8V]M;65N=%!O<R`K(#$["B`@
M("`@("`@?0H*("`@("`@("!I9B`H)&EN9F];)T9,1R==("8@)'1H:7,M/E]F
M;&%G<ULG1DA#4D,G72D@>PH@("`@("`@("`@("`D:&-R8R`]('5N<&%C:R@G
M=D-20R<L('-U8G-T<B@D9&%T82P@)'!O<VET:6]N("L@,"P@,BDI.PH@("`@
M("`@("`@("`D:&-R8R`]("1H8W)C6R=#4D,G73L*("`@("`@("`@("`@)'!O
M<VET:6]N("L](#(["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@0&=Z
M:6YF;&%T92AS=6)S='(H)&1A=&$L("1P;W-I=&EO;BP@<W1R;&5N*"1D871A
M*2`M("1P;W-I=&EO;BDI.PH@("`@("`@(&EF("AE;7!T>2@D<F5S=6QT*2D@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B
M;&4@=&\@9&5C;VUP<F5S<R!D871A+B(I*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]#;VUP<F5S<R]T
M;F5F+G!H<```````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R-3,R
M-"`Q,#4Q-30S,S<S-R`P,C(V,C``(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*"F1E9FEN92@G5$Y%1E]324=.0515
M4D4G+"`@("`@(#!X,C(S93EF-S@I.PID969I;F4H)U1.149?3%9,7TU%4U-!
M1T4G+"`@("`P>#`Q*3L*9&5F:6YE*"=43D5&7TQ63%]!5%1!0TA-14Y4)RP@
M,'@P,BD["@ID969I;F4H)U1.149?4U1224Y')RP@,'@P,#`Q,#`P,"D["F1E
M9FEN92@G5$Y%1E]"651%)RP@("`P>#`P,#8P,#`P*3L*9&5F:6YE*"=43D5&
M7U=/4D0G+"`@(#!X,#`P-S`P,#`I.PID969I;F4H)U1.149?1%=/4D0G+"`@
M,'@P,#`X,#`P,"D["@ID969I;F4H)U1.149?05-50DI%0U0G+"`@(%1.149?
M1%=/4D0@('P@,'@X,#`T*3L*9&5F:6YE*"=43D5&7T%-0TQ!4U,G+"`@("!4
M3D5&7U=/4D0@("!\(#!X.#`P."D["F1E9FEN92@G5$Y%1E]!5%1!0TA$051!
M)RP@5$Y%1E]"651%("`@?"`P>#@P,&8I.PID969I;F4H)U1.149?049)3$5.
M04U%)RP@(%1.149?4U1224Y'('P@,'@X,#$P*3L*9&5F:6YE*"=43D5&7T%2
M14Y$1$%402<L("!43D5&7T)95$4@("!\(#!X.3`P,BD["F1E9FEN92@G5$Y%
M1E]!34%024%45%)3)RP@5$Y%1E]"651%("`@?"`P>#DP,#4I.PID969I;F4H
M)U1.149?059%4E-)3TXG+"`@(%1.149?1%=/4D0@('P@,'@Y,#`V*3L*"F1E
M9FEN92@G5$Y%1E]-05!)7TY53$PG+"`@("`@("`@("`@,'@P,#`Q*3L*9&5F
M:6YE*"=43D5&7TU!4$E?4TA/4E0G+"`@("`@("`@("`P>#`P,#(I.PID969I
M;F4H)U1.149?34%025])3E0G+"`@("`@("`@("`@(#!X,#`P,RD["F1E9FEN
M92@G5$Y%1E]-05!)7T9,3T%4)RP@("`@("`@("`@,'@P,#`T*3L*9&5F:6YE
M*"=43D5&7TU!4$E?1$]50DQ%)RP@("`@("`@("`P>#`P,#4I.PID969I;F4H
M)U1.149?34%025]#55)214Y#62<L("`@("`@(#!X,#`P-BD["F1E9FEN92@G
M5$Y%1E]-05!)7T%04%1)344G+"`@("`@("`@,'@P,#`W*3L*9&5F:6YE*"=4
M3D5&7TU!4$E?15)23U(G+"`@("`@("`@("`P>#`P,&$I.PID969I;F4H)U1.
M149?34%025]"3T],14%.)RP@("`@("`@(#!X,#`P8BD["F1E9FEN92@G5$Y%
M1E]-05!)7T]"2D5#5"<L("`@("`@("`@,'@P,#!D*3L*9&5F:6YE*"=43D5&
M7TU!4$E?24Y4.$)95$4G+"`@("`@("`P>#`P,30I.PID969I;F4H)U1.149?
M34%025]35%))3D<G+"`@("`@("`@(#!X,#`Q92D["F1E9FEN92@G5$Y%1E]-
M05!)7U5.24-/1$5?4U1224Y')RP@,'@P,#%F*3L*9&5F:6YE*"=43D5&7TU!
M4$E?4UE35$E-12<L("`@("`@("`P>#`P-#`I.PID969I;F4H)U1.149?34%0
M25]#3%-)1"<L("`@("`@("`@(#!X,#`T."D["F1E9FEN92@G5$Y%1E]-05!)
M7T))3D%262<L("`@("`@("`@,'@P,3`R*3L*"F1E9FEN92@G5$Y%1E]-05!)
M7T%45$%#2%],3TY'7T9)3$5.04U%)RP@,'@S-S`W*3L*9&5F:6YE*"=43D5&
M7TU!4$E?051404-(7TU)345?5$%')RP@("`@("`P>#,W,$4I.PH*9&5F:6YE
M*"=43D5&7TU!4$E?3D%-141?5%E015])1"<L("`@("`P>#`P,#`I.PID969I
M;F4H)U1.149?34%025].04U%1%]465!%7U-44DE.1R<L(#!X,#`P,2D["F1E
M9FEN92@G5$Y%1E]-05!)7TU67T9,04<G+"`@("`@("`@("`@,'@Q,#`P*3L*
M"B\J*@H@*B!4:&4@2&]R9&5?0V]M<')E<W-?=&YE9B!C;&%S<R!A;&QO=W,@
M35,M5$Y%1B!D871A('1O(&)E(&1I<W!L87EE9"X*("H*("H@5&AE(%1.148@
M<F5N9&5R:6YG(&ES(&)A<V5D(&]N(&-O9&4@8GDZ"B`J("`@1W)A:&%M($YO
M<F)U<GD@/&=N;W)B=7)Y0&)O;F1C87(N8V]M/@H@*B!/<FEG:6YA;"!D97-I
M9VX@8GDZ"B`J("`@5&AO;6%S($)O;&P@/'1B0&)O;&PN8V@^+"!-87)K(%-I
M;7!S;VX@/&1A;6YE9$!W;W)L9"YS=&0N8V]M/@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T;F5F+G!H<"QV(#$N-BXQ,BXY
M(#(P,#8O,#$O,#$@,C$Z,C@Z,3$@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`R+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@
M0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`
M8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`875T:&]R
M("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE
M9'4^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]#
M;VUP<F5S<PH@*B\*8VQA<W,@2&]R9&5?0V]M<')E<W-?=&YE9B!E>'1E;F1S
M($AO<F1E7T-O;7!R97-S('L*"B`@("`O*BH*("`@("`J($1E8V]M<')E<W,@
M=&AE(&1A=&$N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&%T82`@
M(%1H92!D871A('1O(&1E8V]M<')E<W,N"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R`@06X@87)R87D@;V8@87)G=6UE;G1S(&YE961E9"!T;R!D96-O
M;7!R97-S('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&1A=&$N
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&1E8V]M<')E<W-E
M9"!D871A+@H@("`@("H@("`@("`@("`@("`@("`@4F5T=7)N<R!A(%!%05)?
M17)R;W(@;V)J96-T(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!D
M96-O;7!R97-S*"1D871A+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@
M("`@("`D;W5T(#T@87)R87DH*3L*"B`@("`@("`@:68@*"1T:&ES+3Y?9V5T
M:2@D9&%T82P@,S(I(#T](%1.149?4TE'3D%455)%*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?9V5T:2@D9&%T82P@,38I.PH*("`@("`@("`@("`@=VAI;&4@
M*'-T<FQE;B@D9&%T82D@/B`P*2!["B`@("`@("`@("`@("`@("!S=VET8V@@
M*"1T:&ES+3Y?9V5T:2@D9&%T82P@."DI('L*("`@("`@("`@("`@("`@(&-A
M<V4@5$Y%1E],5DQ?34534T%'13H*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7V1E8V]D94UE<W-A9V4H)&1A=&$I.PH@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@5$Y%1E],5DQ?051404-(
M345.5#H*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1E8V]D94%T=&%C
M:&UE;G0H)&1A=&$L("1O=70I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@87)R87E?<F5V97)S92@D;W5T*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%1/1$\*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("8D9&%T82`@5&AE(&1A
M=&$@<W1R:6YG+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&)I=',@($AO=R!M
M86YY(&)I=',@=&\@<F5T<FEE=F4N"B`@("`@*@H@("`@("H@0')E='5R;B!4
M3T1/"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971X*"8D9&%T82P@)&)I=',I
M"B`@("!["B`@("`@("`@)'9A;'5E(#T@;G5L;#L*"B`@("`@("`@:68@*'-T
M<FQE;B@D9&%T82D@/CT@)&)I=',I('L*("`@("`@("`@("`@)'9A;'5E(#T@
M<W5B<W1R*"1D871A+"`P+"`D8FET<RD["B`@("`@("`@("`@("1D871A(#T@
M<W5B<W1R7W)E<&QA8V4H)&1A=&$L("<G+"`P+"`D8FET<RD["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)'9A;'5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@5$]$3PH@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)B1D871A("!4:&4@9&%T82!S=')I;F<N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8FET<R`@2&]W(&UA;GD@8FET<R!T
M;R!R971R:65V92X*("`@("`J"B`@("`@*B!`<F5T=7)N(%1/1$\*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V=E=&DH)B1D871A+"`D8FET<RD*("`@('L*("`@
M("`@("`D8GET97,@/2`D8FET<R`O(#@["B`@("`@("`@)'9A;'5E(#T@;G5L
M;#L*"B`@("`@("`@:68@*'-T<FQE;B@D9&%T82D@/CT@)&)Y=&5S*2!["B`@
M("`@("`@("`@("1V86QU92`](&]R9"@D9&%T85LP72D["B`@("`@("`@("`@
M(&EF("@D8GET97,@/CT@,BD@>PH@("`@("`@("`@("`@("`@)'9A;'5E("L]
M("AO<F0H)&1A=&%;,5TI(#P\(#@I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&EF("@D8GET97,@/CT@-"D@>PH@("`@("`@("`@("`@("`@)'9A;'5E
M("L]("AO<F0H)&1A=&%;,ETI(#P\(#$V*2`K("AO<F0H)&1A=&%;,UTI(#P\
M(#(T*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D9&%T82`]('-U8G-T
M<E]R97!L86-E*"1D871A+"`G)RP@,"P@)&)Y=&5S*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D=F%L=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4
M3T1/"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`F)&1A=&$@("`@("!4:&4@9&%T82!S=')I;F<N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1A='1R:6)U=&4@(%1/1$\*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V1E8V]D94%T=')I8G5T92@F)&1A=&$L("1A='1R
M:6)U=&4I"B`@("!["B`@("`@("`@+RH@1&%T82X@*B\*("`@("`@("`D=&AI
M<RT^7V=E='@H)&1A=&$L("1T:&ES+3Y?9V5T:2@D9&%T82P@,S(I*3L*"B`@
M("`@("`@+RH@0VAE8VMS=6TN("HO"B`@("`@("`@)'1H:7,M/E]G971I*"1D
M871A+"`Q-BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!43T1/"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9&%T82`@("`@("`@("`@("!4:&4@9&%T82!S=')I;F<N"B`@("`@
M*B!`<&%R86T@87)R87D@)B1A='1A8VAM96YT7V1A=&$@(%1/1$\*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V5X=')A8W1-87!I071T<FEB=71E<R@D9&%T82P@
M)B1A='1A8VAM96YT7V1A=&$I"B`@("!["B`@("`@("`@+RH@3G5M8F5R(&]F
M(&%T=')I8G5T97,N("HO"B`@("`@("`@)&YU;6)E<B`]("1T:&ES+3Y?9V5T
M:2@D9&%T82P@,S(I.PH*("`@("`@("!W:&EL92`H*'-T<FQE;B@D9&%T82D@
M/B`P*2`F)B`D;G5M8F5R+2TI('L*("`@("`@("`@("`@)&AA=F5?;79A;"`]
M(&9A;'-E.PH@("`@("`@("`@("`D;G5M7VUV86P@/2`Q.PH@("`@("`@("`@
M("`D;F%M961?:60@/2`D=F%L=64@/2!N=6QL.PH@("`@("`@("`@("`D871T
M<E]T>7!E(#T@)'1H:7,M/E]G971I*"1D871A+"`Q-BD["B`@("`@("`@("`@
M("1A='1R7VYA;64@/2`D=&AI<RT^7V=E=&DH)&1A=&$L(#$V*3L*"B`@("`@
M("`@("`@(&EF("@H)&%T=')?='EP92`F(%1.149?34%025]-5E]&3$%'*2`A
M/2`P*2!["B`@("`@("`@("`@("`@("`D:&%V95]M=F%L(#T@=')U93L*("`@
M("`@("`@("`@("`@("1A='1R7W1Y<&4@/2`D871T<E]T>7!E("8@?E1.149?
M34%025]-5E]&3$%'.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H
M*"1A='1R7VYA;64@/CT@,'@X,#`P*2`F)B`H)&%T=')?;F%M92`\(#!X1D9&
M12DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T>"@D9&%T82P@,38I
M.PH@("`@("`@("`@("`@("`@)&YA;65D7W1Y<&4@/2`D=&AI<RT^7V=E=&DH
M)&1A=&$L(#,R*3L*"B`@("`@("`@("`@("`@("!S=VET8V@@*"1N86UE9%]T
M>7!E*2!["B`@("`@("`@("`@("`@("!C87-E(%1.149?34%025].04U%1%]4
M65!%7TE$.@H@("`@("`@("`@("`@("`@("`@("1N86UE9%]I9"`]("1T:&ES
M+3Y?9V5T:2@D9&%T82P@,S(I.PH@("`@("`@("`@("`@("`@("`@("1A='1R
M7VYA;64@/2`D;F%M961?:60["B`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("`@("`@8V%S92!43D5&7TU!4$E?3D%-141?5%E015]3
M5%))3D<Z"B`@("`@("`@("`@("`@("`@("`@)&%T=')?;F%M92`](#!X.3DY
M.3L*("`@("`@("`@("`@("`@("`@("`D:61L96X@/2`D=&AI<RT^7V=E=&DH
M)&1A=&$L(#,R*3L*("`@("`@("`@("`@("`@("`@("`D9&%T86QE;B`]("1I
M9&QE;B`K("@H-"`M("@D:61L96X@)2`T*2D@)2`T*3L*("`@("`@("`@("`@
M("`@("`@("`D;F%M961?:60@/2!S=6)S='(H)'1H:7,M/E]G971X*"1D871A
M+"`D9&%T86QE;BDL(#`L("1I9&QE;BD["B`@("`@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@(&EF("@D:&%V95]M=F%L*2!["B`@("`@("`@("`@("`@("`D;G5M
M7VUV86P@/2`D=&AI<RT^7V=E=&DH)&1A=&$L(#,R*3L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@<W=I=&-H("@D871T<E]T>7!E*2!["B`@("`@("`@
M("`@(&-A<V4@5$Y%1E]-05!)7U-(3U)4.@H@("`@("`@("`@("`@("`@)'9A
M;'5E(#T@)'1H:7,M/E]G971I*"1D871A+"`Q-BD["B`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@5$Y%1E]-05!)7TE.5#H*("`@
M("`@("`@("`@8V%S92!43D5&7TU!4$E?0D]/3$5!3CH*("`@("`@("`@("`@
M("`@(&9O<B`H)&D@/2`P.R`D:2`\("1N=6U?;79A;#L@)&DK*RD@>PH@("`@
M("`@("`@("`@("`@("`@("1V86QU92`]("1T:&ES+3Y?9V5T:2@D9&%T82P@
M,S(I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("!C87-E(%1.149?34%025]&3$]!5#H*("`@("`@("`@
M("`@8V%S92!43D5&7TU!4$E?15)23U(Z"B`@("`@("`@("`@("`@("`D=F%L
M=64@/2`D=&AI<RT^7V=E='@H)&1A=&$L(#0I.PH@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("!C87-E(%1.149?34%025]$3U5"3$4Z"B`@
M("`@("`@("`@(&-A<V4@5$Y%1E]-05!)7T%04%1)344Z"B`@("`@("`@("`@
M(&-A<V4@5$Y%1E]-05!)7T-54E)%3D-9.@H@("`@("`@("`@("!C87-E(%1.
M149?34%025])3E0X0EE413H*("`@("`@("`@("`@8V%S92!43D5&7TU!4$E?
M4UE35$E-13H*("`@("`@("`@("`@("`@("1V86QU92`]("1T:&ES+3Y?9V5T
M>"@D9&%T82P@."D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&-A<V4@5$Y%1E]-05!)7U-44DE.1SH*("`@("`@("`@("`@8V%S92!4
M3D5&7TU!4$E?54Y)0T]$15]35%))3D<Z"B`@("`@("`@("`@(&-A<V4@5$Y%
M1E]-05!)7T))3D%263H*("`@("`@("`@("`@8V%S92!43D5&7TU!4$E?3T)*
M14-4.@H@("`@("`@("`@("`@("`@)&YU;5]V86QS(#T@*"1H879E7VUV86PI
M(#\@)&YU;5]M=F%L(#H@)'1H:7,M/E]G971I*"1D871A+"`S,BD["B`@("`@
M("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D;G5M7W9A;',[("1I*RLI
M('L*("`@("`@("`@("`@("`@("`@("`D;&5N9W1H(#T@)'1H:7,M/E]G971I
M*"1D871A+"`S,BD["@H@("`@("`@("`@("`@("`@("`@("\J(%!A9"!T;R!N
M97AT(#0@8GET92!B;W5N9&%R>2X@*B\*("`@("`@("`@("`@("`@("`@("`D
M9&%T86QE;B`]("1L96YG=&@@*R`H*#0@+2`H)&QE;F=T:"`E(#0I*2`E(#0I
M.PH*("`@("`@("`@("`@("`@("`@("!I9B`H)&%T=')?='EP92`]/2!43D5&
M7TU!4$E?4U1224Y'*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1L96YG
M=&@@+3T@,3L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@
M("`@("`@("\J(%)E860@86YD('1R=6YC871E('1O(&QE;F=T:"X@*B\*("`@
M("`@("`@("`@("`@("`@("`D=F%L=64@/2!S=6)S='(H)'1H:7,M/E]G971X
M*"1D871A+"`D9&%T86QE;BDL(#`L("1L96YG=&@I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("\J(%-T;W)E(&%N>2!I;G1E<F5S=&EN9R!A='1R:6)U=&5S
M+B`J+PH@("`@("`@("`@("!S=VET8V@@*"1A='1R7VYA;64I('L*("`@("`@
M("`@("`@8V%S92!43D5&7TU!4$E?051404-(7TQ/3D=?1DE,14Y!344Z"B`@
M("`@("`@("`@("`@("`O*B!5<V5D(&EN('!R969E<F5N8V4@=&\@049)3$5.
M04U%('9A;'5E+B`J+PH@("`@("`@("`@("`@("`@)&%T=&%C:&UE;G1?9&%T
M85LP75LG;F%M92==(#T@<')E9U]R97!L86-E*"<O+BI;7"]=*"XJ*20O)RP@
M)UPQ)RP@)'9A;'5E*3L*("`@("`@("`@("`@("`@("1A='1A8VAM96YT7V1A
M=&%;,%U;)VYA;64G72`]('-T<E]R97!L86-E*")<,"(L("<G+"`D871T86-H
M;65N=%]D871A6S!=6R=N86UE)UTI.PH@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("!C87-E(%1.149?34%025]!5%1!0TA?34E-15]404<Z
M"B`@("`@("`@("`@("`@("`O*B!)<R!T:&ES(&5V97(@<V5T+"!A;F0@=VAA
M="!I<R!F;W)M870_("HO"B`@("`@("`@("`@("`@("`D871T86-H;65N=%]D
M871A6S!=6R=T>7!E)UT@/2!P<F5G7W)E<&QA8V4H)R]>*"XJ*5PO+BHO)RP@
M)UPQ)RP@)'9A;'5E*3L*("`@("`@("`@("`@("`@("1A='1A8VAM96YT7V1A
M=&%;,%U;)W-U8G1Y<&4G72`]('!R96=?<F5P;&%C92@G+RXJ7"\H+BHI)"\G
M+"`G7#$G+"`D=F%L=64I.PH@("`@("`@("`@("`@("`@)&%T=&%C:&UE;G1?
M9&%T85LP75LG<W5B='EP92==(#T@<W1R7W)E<&QA8V4H(EPP(BP@)R<L("1A
M='1A8VAM96YT7V1A=&%;,%U;)W-U8G1Y<&4G72D["B`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%1/1$\*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("8D9&%T82`@5&AE(&1A=&$@
M<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9&5C;V1E365S<V%G92@F
M)&1A=&$I"B`@("!["B`@("`@("`@)'1H:7,M/E]D96-O9&5!='1R:6)U=&4H
M)&1A=&$L("1T:&ES+3Y?9V5T:2@D9&%T82P@,S(I*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%1/1$\*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("8D9&%T82`@("`@("`@("`@
M(%1H92!D871A('-T<FEN9RX*("`@("`J($!P87)A;2!A<G)A>2`F)&%T=&%C
M:&UE;G1?9&%T82`@5$]$3PH@("`@("HO"B`@("!F=6YC=&EO;B!?9&5C;V1E
M071T86-H;65N="@F)&1A=&$L("8D871T86-H;65N=%]D871A*0H@("`@>PH@
M("`@("`@("1A='1R:6)U=&4@/2`D=&AI<RT^7V=E=&DH)&1A=&$L(#,R*3L*
M"B`@("`@("`@<W=I=&-H("@D871T<FEB=71E*2!["B`@("`@("`@8V%S92!4
M3D5&7T%214Y$1$%403H*("`@("`@("`@("`@+RH@36%R:W,@<W1A<G0@;V8@
M;F5W(&%T=&%C:&UE;G0N("HO"B`@("`@("`@("`@("1T:&ES+3Y?9V5T>"@D
M9&%T82P@)'1H:7,M/E]G971I*"1D871A+"`S,BDI.PH*("`@("`@("`@("`@
M+RH@0VAE8VMS=6T@*B\*("`@("`@("`@("`@)'1H:7,M/E]G971I*"1D871A
M+"`Q-BD["@H@("`@("`@("`@("`O*B!!9&0@82!N97<@9&5F875L="!D871A
M(&)L;V-K('1O(&AO;&0@9&5T86EL<R!O9B!T:&ES"B`@("`@("`@("`@("`@
M(&%T=&%C:&UE;G0N(%)E=F5R<V4@;W)D97(@:7,@96%S:65R('1O(&AA;F1L
M92!L871E<B$@*B\*("`@("`@("`@("`@87)R87E?=6YS:&EF="@D871T86-H
M;65N=%]D871A+"!A<G)A>2@G='EP92<@("`@/3X@)V%P<&QI8V%T:6]N)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G<W5B='EP92<@/3X@)V]C=&5T+7-T<F5A;2<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYA;64G
M("`@(#T^("=U;FMN;W=N)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G<W1R96%M)R`@/3X@)R<I*3L*("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@5$Y%1E]!1DE,14Y!344Z
M"B`@("`@("`@("`@("\J(%-T<FEP('!A=&@N("HO"B`@("`@("`@("`@("1A
M='1A8VAM96YT7V1A=&%;,%U;)VYA;64G72`]('!R96=?<F5P;&%C92@G+RXJ
M6UPO72@N*BDD+R<L("=<,2<L("1T:&ES+3Y?9V5T>"@D9&%T82P@)'1H:7,M
M/E]G971I*"1D871A+"`S,BDI*3L*("`@("`@("`@("`@)&%T=&%C:&UE;G1?
M9&%T85LP75LG;F%M92==(#T@<W1R7W)E<&QA8V4H(EPP(BP@)R<L("1A='1A
M8VAM96YT7V1A=&%;,%U;)VYA;64G72D["@H@("`@("`@("`@("`O*B!#:&5C
M:W-U;2`J+PH@("`@("`@("`@("`D=&AI<RT^7V=E=&DH)&1A=&$L(#$V*3L*
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@5$Y%1E]!5%1!0TA$
M051!.@H@("`@("`@("`@("`O*B!4:&4@871T86-H;65N="!I='-E;&8N("HO
M"B`@("`@("`@("`@("1L96YG=&@@/2`D=&AI<RT^7V=E=&DH)&1A=&$L(#,R
M*3L*("`@("`@("`@("`@)&%T=&%C:&UE;G1?9&%T85LP75LG<VEZ92==(#T@
M)&QE;F=T:#L*("`@("`@("`@("`@)&%T=&%C:&UE;G1?9&%T85LP75LG<W1R
M96%M)UT@/2`D=&AI<RT^7V=E='@H)&1A=&$L("1L96YG=&@I.PH*("`@("`@
M("`@("`@+RH@0VAE8VMS=6T@*B\*("`@("`@("`@("`@)'1H:7,M/E]G971I
M*"1D871A+"`Q-BD["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E
M(%1.149?04U!4$E!5%124SH*("`@("`@("`@("`@)&QE;F=T:"`]("1T:&ES
M+3Y?9V5T:2@D9&%T82P@,S(I.PH@("`@("`@("`@("`D=F%L=64@/2`D=&AI
M<RT^7V=E='@H)&1A=&$L("1L96YG=&@I.PH*("`@("`@("`@("`@+RH@0VAE
M8VMS=6T@*B\*("`@("`@("`@("`@)'1H:7,M/E]G971I*"1D871A+"`Q-BD[
M"B`@("`@("`@("`@("1T:&ES+3Y?97AT<F%C=$UA<&E!='1R:6)U=&5S*"1V
M86QU92P@)&%T=&%C:&UE;G1?9&%T82D["B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`D=&AI<RT^7V1E8V]D94%T
M=')I8G5T92@D9&%T82P@)&%T=')I8G5T92D["B`@("`@("`@?0H@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O5D,`````````````````````````````
M````````````````````````````````````````````````````````,#`P
M-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S<@
M,#$W-C`S`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]60R]R8W,N
M<&AP````````````````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q
M-C(S-B`Q,#4Q-30S,S<S-R`P,C$Q-S(`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%9#7W)C<R!I;7!L
M96UE;G1A=&EO;BX*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!*969F(%-C
M:'=E;G1N97(@/&IE9F9R97DN<V-H=V5N=&YE<D!L;6-O+F-O;3X*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO5D,O5D,O<F-S+G!H<"QV(#$N,RXX+C4@,C`P
M-B\P,2\P,2`R,3HR.#HT,B!J86X@17AP("0*("H*("H@0&%U=&AO<B`@2F5F
M9B!38VAW96YT;F5R(#QJ969F<F5Y+G-C:'=E;G1N97)`;&UC;RYC;VT^"B`J
M($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@
M*B!`<&%C:V%G92!60PH@*B\*8VQA<W,@5D-?<F-S(&5X=&5N9',@5D,@>PH*
M("`@("\J*@H@("`@("H@0VAE8VMS(&%N(%)#4R!F:6QE(&EN('=I=&@@82!S
M<&5C:69I960@8VAA;F=E(&QO9RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1F:6QE<&%T:"`@("!,;V-A=&EO;B!O9B!F:6QE('1O(&-H96-K(&EN
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;65S<V%G92`@("`@3&]G(&]F(&-H
M86YG97,@<VEN8V4@;&%S="!V97)S:6]N+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=7-E<B`@("`@("`@5&AE('5S97(@;F%M92!T;R!U<V4@9F]R('1H92!C
M:&5C:R!I;BX*("`@("`J($!P87)A;2!B;V]L96%N("1N97=":6YA<GD@($1O
M97,@=&AE(&-H86YG92!I;G9O;'9E(&)I;F%R>2!D871A/PH@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG?&]B:F5C="`@5&AE(&YE=R!R979I<VEO;B!N
M=6UB97(@;VX@<W5C8V5S<RP@;W(@80H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!C:2@D9FEL97!A=&@L("1M97-S86=E+"`D=7-E<B`]
M(&YU;&PL("1N97=":6YA<GD@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H
M)'5S97(I('L*("`@("`@("`@("`@<'5T96YV*"=,3T=.04U%/2<@+B`D=7-E
M<BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<'5T96YV*"=,3T=.
M04U%/6=U97-T)RD["B`@("`@("`@?0H*("`@("`@("`D42`](%9#7U=)3D1/
M5U,@/R`G(B<@.B`B)R(@.PH*("`@("`@("`D8VE?8VUD(#T@)'1H:7,M/F=E
M=%!A=&@H)V-I)RD@+B`G("<@+B`D42`N("1F:6QE<&%T:"`N("11+B<@,CXF
M,2<["B`@("`@("`@)')C<U]C;60@/2`D=&AI<RT^9V5T4&%T:"@G<F-S)RD@
M+B`G("UI("UK8B`G("X@)%$@+B`D9FEL97!A=&@@+B`D42XG(#(^)C$G.PH@
M("`@("`@("1O=71P=70@/2`G)SL*"B`@("`@("`@)&UE<W-A9V5?;&EN97,@
M/2!E>'!L;V1E*")<;B(L("1M97-S86=E*3L*"B`@("`@("`@)'!I<&5?9&5F
M(#T@87)R87DH,"`]/B!A<G)A>2@B<&EP92(L("=R)RDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@,2`]/B!A<G)A>2@B<&EP92(L("=W)RDI.PH*("`@
M("`@("!I9B`H)&YE=T)I;F%R>2D@>PH@("`@("`@("`@("`D<')O8V5S<R`]
M('!R;V-?;W!E;B@D<F-S7V-M9"P@)'!I<&5?9&5F+"`D<&EP97,I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1P<F]C97-S(#T@<')O8U]O<&5N
M*"1C:5]C;60L("1P:7!E7V1E9BP@)'!I<&5S*3L*("`@("`@("!]"@H@("`@
M("`@(&EF("AI<U]R97-O=7)C92@D<')O8V5S<RDI('L*("`@("`@("`@("`@
M9F]R96%C:"`H)&UE<W-A9V5?;&EN97,@87,@)&QI;F4I('L*("`@("`@("`@
M("`@("`@(&EF("@D;&EN92`]/2`G+EQN)RD@>PH@("`@("`@("`@("`@("`@
M("`@("1L:6YE(#T@)RX@7&XG.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@9G=R:71E*"1P:7!E<ULP72P@)&QI;F4I.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!F=W)I=&4H)'!I<&5S6S!=+"`B7&XN7&XB*3L*
M("`@("`@("`@("`@9F-L;W-E*"1P:7!E<ULP72D["@H@("`@("`@("`@("!W
M:&EL92`H(69E;V8H)'!I<&5S6S%=*2D@>PH@("`@("`@("`@("`@("`@)&]U
M='!U="`N/2!F<F5A9"@D<&EP97-;,5TL(#@Q.3(I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&9C;&]S92@D<&EP97-;,5TI.PH@("`@("`@("`@("!P
M<F]C7V-L;W-E*"1P<F]C97-S*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G1F%I;&5D('1O(&]P96X@
M<&EP92!I;B!C:2@I)RD["B`@("`@("`@?0H*("`@("`@("!I9B`H)&YE=T)I
M;F%R>2D@>PH@("`@("`@("`@("!E>&5C*"1C:5]C;60@+B`G(#(^)C$G+"`D
M<F5T=7)N7V%R<F%Y+"`D<F5T=F%L*3L*"B`@("`@("`@("`@(&EF("@D<F5T
M=F%L*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@B56YA8FQE('1O('-P87=N(&-I(&]N("1F:6QE<&%T:"!F<F]M(&-I*"DB
M*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1R971U<FY?87)R87D@87,@)&QI;F4I('L*("`@("`@("`@("`@("`@
M("`@("`D;W5T<'5T("X]("1L:6YE.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<F5V7W-T87)T(#T@<W1R
M<&]S*"1O=71P=70L("=N97<@<F5V:7-I;VXZ("<I.PH*("`@("`@("`O+R!)
M9B!N;R!N97<@<F5V:7-I;VXL('-E92!I9B!T:&ES(&ES(&%N(&EN:71I86P@
M8VAE8VMI;BX*("`@("`@("!I9B`H)')E=E]S=&%R="`]/3T@9F%L<V4I('L*
M("`@("`@("`@("`@)')E=E]S=&%R="`]('-T<G!O<R@D;W5T<'5T+"`G:6YI
M=&EA;"!R979I<VEO;CH@)RD["B`@("`@("`@("`@("1R979?96YD(#T@<W1R
M<&]S*"1O=71P=70L("<@)RP@)')E=E]S=&%R="D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)')E=E]E;F0@/2!S=')P;W,H)&]U='!U="P@)SLG
M+"`D<F5V7W-T87)T*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D<F5V7W-T
M87)T("$]/2!F86QS92`F)B`D<F5V7V5N9"`A/3T@9F%L<V4I('L*("`@("`@
M("`@("`@)')E=E]S=&%R="`K/2`Q-#L*("`@("`@("`@("`@<F5T=7)N('-U
M8G-T<B@D;W5T<'5T+"`D<F5V7W-T87)T+"`D<F5V7V5N9"`M("1R979?<W1A
M<G0I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@('5N;&]C:R@D9FEL
M97!A=&@I.PH@("`@("`@("`@("`D=&5M<%]P;W,@/2!S=')P;W,H)&]U='!U
M="P@)V9I;&4@:7,@=6YC:&%N9V5D)RD["B`@("`@("`@("`@(&EF("@D=&5M
M<%]P;W,@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@G0VAE8VLM:6X@1F%I;'5R93H@)R`N(&)A<V5N86UE
M*"1F:6QE<&%T:"D@+B`G(&AA<R!N;W0@8F5E;B!M;V1I9FEE9"<I.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H(D9A:6QE9"!T;R!C:&5C:VEN("1F:6QE<&%T:"P@)&-I
M7V-M9"P@)&]U='!U="(I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@0VAE8VMS('1H92!L;V-K<R!O;B!A($-64R]2
M0U,@9FEL92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QE<&%T
M:"`@("!,;V-A=&EO;B!O9B!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`F
M)&QO8VME9%]B>2`@4F5T=7)N<R!T:&4@=7-E<FYA;64@:&]L9&EN9R!T:&4@
M;&]C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86Y\;V)J96-T("!4
M<G5E(&]N('-U8V-E<W,L(&]R(&$@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!I<TQO8VME9"@D9FEL97!A=&@L("8D;&]C
M:V5D7V)Y*0H@("`@>PH@("`@("`@("1R;&]G7V-M9"`@/2`D=&AI<RT^9V5T
M4&%T:"@G<FQO9R<I.PH@("`@("`@("1R;&]G7V9L86<@/2`G("U,("<["@H@
M("`@("`@("11(#T@5D-?5TE.1$]74R`_("<B)R`Z("(G(CL*"B`@("`@("`@
M)&-M9"`]("1R;&]G7V-M9"`N("1R;&]G7V9L86<@+B`D42`N("1F:6QE<&%T
M:"`N("11.PH*("`@("`@("!E>&5C*"1C;60N)R`R/B8Q)RP@)')E='5R;E]A
M<G)A>2P@)')E='9A;"D["@H@("`@("`@(&EF("@D<F5T=F%L*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")5;F%B;&4@=&\@<W!A
M=VX@<FQO9R!O;B`D9FEL97!A=&@@9G)O;2!I<TQO8VME9"@I(BD["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&]U='!U="`]("<G.PH*("`@("`@
M("`@("`@9F]R96%C:"`H)')E='5R;E]A<G)A>2!A<R`D;&EN92D@>PH@("`@
M("`@("`@("`@("`@)&]U='!U="`N/2`D;&EN93L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@)'-T87)T7VYA;64@/2!S=')P;W,H)&]U='!U="P@)VQO
M8VME9"!B>3H@)RD["B`@("`@("`@("`@("1E;F1?;F%M92`]('-T<G!O<R@D
M;W5T<'5T+"`G.R<L("1S=&%R=%]N86UE*3L*"B`@("`@("`@("`@(&EF("@D
M<W1A<G1?;F%M92`A/3T@9F%L<V4@)B8@)&5N9%]N86UE("$]/2!F86QS92D@
M>PH@("`@("`@("`@("`@("`@)'-T87)T7VYA;64@*ST@,3$["B`@("`@("`@
M("`@("`@("`D;&]C:V5D7V)Y(#T@<W5B<W1R*"1O=71P=70L("1S=&%R=%]N
M86UE+"`D96YD7VYA;64@+2`D<W1A<G1?;F%M92D["B`@("`@("`@("`@("`@
M("!R971U<FX@=')U93L*("`@("`@("`@("`@?2`@96QS96EF("AS=')L96XH
M)&]U='!U="D@/3T@,"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H)T9A:6QU<F4@<G5N;FEN9R!R;&]G(&EN(&ES
M3&]C:V5D*"DG*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($QO8VMS(&$@0U93+U)#4R!F:6QE+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&9I;&5P871H("!,;V-A=&EO;B!O9B!F:6QE
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<B`@("`@(%5S97(@;F%M92!T
M;R!L;V-K('1H92!F:6QE('=I=&@*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86Y\;V)J96-T("!4<G5E(&]N('-U8V-E<W,L(&]R(&$@4$5!4E]%<G)O
M<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!L;V-K*"1F:6QE
M<&%T:"P@)'5S97(@/2!N=6QL*0H@("`@>PH@("`@("`@("\O($=E="!U<V5R
M;F%M92!F;W(@4D-3('1A9RX*("`@("`@("!I9B`H)'5S97(I('L*("`@("`@
M("`@("`@<'5T96YV*"=,3T=.04U%/2<@+B`D=7-E<BD["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<'5T96YV*"=,3T=.04U%/6=U97-T)RD["B`@
M("`@("`@?0H*("`@("`@("`D<F-S7V-M9"`]("1T:&ES+3YG9710871H*"=R
M8W,G*3L*("`@("`@("`D<F-S7V9L86<@/2`G("UL("<["@H@("`@("`@("11
M(#T@5D-?5TE.1$]74R`_("<B)R`Z("(G(B`["B`@("`@("`@)&-M9"`]("1R
M8W-?8VUD("X@)')C<U]F;&%G("X@)%$@+B`D9FEL97!A=&@@+B`D43L*("`@
M("`@("!E>&5C*"1C;60N)R`R/B8Q)RP@)')E='5R;E]A<G)A>2P@)')E='9A
M;"D["@H@("`@("`@(&EF("@D<F5T=F%L*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"=&86EL960@=&\@<W!A=VX@<F-S("@B)R`N
M("1C;60@+B`G(BD@;VX@(B<@+B`D9FEL97!A=&@@+B`G(B`H<F5T=7)N960@
M)R`N("1R971V86P@+B`G*2<I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1O=71P=70@/2`G)SL*("`@("`@("`@("`@9F]R96%C:"`H)')E='5R
M;E]A<G)A>2!A<R`D;&EN92D@>PH@("`@("`@("`@("`@("`@)&]U='!U="`N
M/2`D;&EN93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&QO8VME9%]P
M;W,@/2!S=')P;W,H)&]U='!U="P@)VQO8VME9"<I.PH@("`@("`@("`@("!I
M9B`H)&QO8VME9%]P;W,@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@=')U93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=&86EL960@=&\@;&]C:R`B
M)R`N("1F:6QE<&%T:"`N("<B("A286X@(B<@+B`D8VUD("X@)R(L(&=O="!R
M971U<FX@8V]D92`G("X@)')E='9A;"`N("<L(&]U='!U=#H@)R`N("1O=71P
M=70@+B`G*2<I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@56YL;V-K<R!A($-64R]20U,@9FEL92X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1F:6QE<&%T:"`@3&]C871I;VX@;V8@9FEL
M92X*("`@("`J($!P87)A;2!S=')I;F<@)'5S97(@("`@("!5<V5R(&YA;64@
M=&\@=6YL;V-K('1H92!F:6QE('=I=&@*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86Y\;V)J96-T("!4<G5E(&]N('-U8V-E<W,L(&]R(&$@4$5!4E]%
M<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!U;FQO8VLH
M)&9I;&5P871H+"`D=7-E<B`](&YU;&PI"B`@("!["B`@("`@("`@+R\@1V5T
M('5S97)N86UE(&9O<B!20U,@=&%G+@H@("`@("`@(&EF("@D=7-E<BD@>PH@
M("`@("`@("`@("!P=71E;G8H)TQ/1TY!344])R`N("1U<V5R*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!P=71E;G8H)TQ/1TY!344]9W5E<W0G
M*3L*("`@("`@("!]"@H@("`@("`@("1R8W-?8VUD(#T@)'1H:7,M/F=E=%!A
M=&@H)W)C<R<I.PH@("`@("`@("1R8W-?9FQA9R`]("<@+74@)SL*"B`@("`@
M("`@)%$@/2!60U]724Y$3U=3(#\@)R(G(#H@(B<B(#L*("`@("`@("`D8VUD
M(#T@)')C<U]C;60@+B`D<F-S7V9L86<@+B`D42`N("1F:6QE<&%T:"`N("11
M.PH@("`@("`@(&5X96,H)&-M9"`N("<@,CXF,2<L("1R971U<FY?87)R87DL
M("1R971V86PI.PH*("`@("`@("!I9B`H)')E='9A;"D@>PH@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G1F%I;&5D('1O('-P87=N(')C
M<R`H(B<@+B`D8VUD("X@)R(I(&]N("(G("X@)&9I;&5P871H("X@)R(@*')E
M='5R;F5D("<@+B`D<F5T=F%L("X@)RDG*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D;W5T<'5T(#T@)R<["@H@("`@("`@("`@("!F;W)E86-H
M("@D<F5T=7)N7V%R<F%Y(&%S("1L:6YE*2!["B`@("`@("`@("`@("`@("`D
M;W5T<'5T("X]("1L:6YE.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M=6YL;V-K961?<&]S(#T@<W1R<&]S*"1O=71P=70L("=U;FQO8VME9"<I.PH*
M("`@("`@("`@("`@:68@*"1U;FQO8VME9%]P;W,@(3T](&9A;'-E*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("\O($%L<F5A9'D@=6YL;V-K960N"B`@("`@
M("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U9#+V-V
M<RYP:'``````````````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,3`R,C4U(#$P-3$U-#,S-S,W(#`R,3$W,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E(&1I
M<FYA;64H7U]&24Q%7U\I("X@)R]R8W,N<&AP)SL*"B\J*@H@*B!60U]C=G,@
M:6UP;&5M96YT871I;VXN"B`J"B`J($-O<'ER:6=H="`R,#`P+3(P,#8@06YI
M;"!-861H879A<&5D9'DL(#QA;FEL0')E8V]I;"YO<F<^"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+U9#+U9#+V-V<RYP:'`L=B`Q+C,R+C(N,C0@,C`P-B\P
M-2\Q,B`P-#HT-SHP."!C:'5C:R!%>'`@)`H@*@H@*B!`875T:&]R("!!;FEL
M($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`<&%C:V%G92!6
M0PH@*B\*8VQA<W,@5D-?8W9S(&5X=&5N9',@5D-?<F-S('L*"B`@("`O*BH*
M("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A
M>2`D<&%R86US("!!;GD@<&%R86UE=&5R('1H92!C;&%S<R!E>'!E8W1S+@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@(#QP<F4^"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@0W5R<F5N="!P87)A;65T97)S.@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("=S;W5R8V5R;V]T)SH@5&AE('-O=7)C
M92!R;V]T(&9O<B!T:&ES"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!R97!O<VET;W)Y"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@)W!A=&AS)SH@2&%S:"!W:71H('1H92!L;V-A=&EO;G,@;V8@
M86QL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;F5C
M97-S87)Y(&)I;F%R:65S.B`G<F-S9&EF9B<L("=R;&]G)RP*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8W9S<',G+"`G8W9S<'-?
M:&]M92<@86YD('1H92!T96UP"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<&%T:#H@)W1E;7`G"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@/"]P<F4^"B`@("`@*B\*("`@(&9U;F-T:6]N(%9#7V-V<R@D
M<&%R86US*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<V]U<F-E<F]O="`]("1P
M87)A;7-;)W-O=7)C97)O;W0G73L*("`@("`@("`D=&AI<RT^7W!A=&AS(#T@
M)'!A<F%M<ULG<&%T:',G73L*("`@('T*"B`@("!F=6YC=&EO;B!I<T9I;&4H
M)'=H97)E*0H@("`@>PH@("`@("`@(')E='5R;B!`:7-?9FEL92@D=VAE<F4@
M+B`G+'8G*3L*("`@('T*"B`@("!F=6YC=&EO;B`F<75E<GE$:7(H)'=H97)E
M*0H@("`@>PH@("`@("`@("1D:7(@/2!N97<@5D-?1&ER96-T;W)Y7V-V<R@D
M=&AI<RP@)'=H97)E*3L*("`@("`@("!R971U<FX@)&1I<CL*("`@('T*"B`@
M("!F=6YC=&EO;B!G971#:&5C:V]U="@D9FEL92P@)')E=BD*("`@('L*("`@
M("`@("!R971U<FX@5D-?0VAE8VMO=71?8W9S.CIG970H)'1H:7,L("1F:6QE
M+3YQ=65R>49U;&Q0871H*"DL("1R978I.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&=E=$1I9F8H)&9I;&4L("1R978Q+"`D<F5V,BP@)'1Y<&4@/2`G8V]N=&5X
M="<L("1N=6T@/2`S+"`D=W,@/2!T<G5E*0H@("`@>PH@("`@("`@(')E='5R
M;B!60U]$:69F7V-V<SHZ9V5T*"1T:&ES+"`D9FEL92P@)')E=C$L("1R978R
M+"`D='EP92P@)&YU;2P@)'=S*3L*("`@('T*"B`@("!F=6YC=&EO;B`F9V5T
M1FEL94]B:F5C="@D9FEL96YA;64L("1C86-H92`](&YU;&PL("1Q=6EC:VQO
M9R`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("AS=6)S='(H)&9I;&5N86UE
M+"`P+"`Q*2`A/2`G+R<I('L*("`@("`@("`@("`@)&9I;&5N86UE(#T@)R\G
M("X@)&9I;&5N86UE.PH@("`@("`@('T*("`@("`@("`D9F\@/2`F5D-?1FEL
M95]C=G,Z.F=E=$9I;&5/8FIE8W0H)'1H:7,L("1T:&ES+3YS;W5R8V5R;V]T
M*"D@+B`D9FEL96YA;64L("1C86-H92P@)'%U:6-K;&]G*3L*("`@("`@("!R
M971U<FX@)&9O.PH@("`@?0H*("`@(&9U;F-T:6]N("9G971!;FYO=&%T94]B
M:F5C="@D9FEL96YA;64I"B`@("!["B`@("`@("`@)&)L86UE(#T@;F5W(%9#
M7T%N;F]T871E7V-V<R@D=&AI<RP@)&9I;&5N86UE+"!5=&EL.CIG971496UP
M1FEL92@G=F,G+"!T<G5E+"`D=&AI<RT^7W!A=&AS6R=T96UP)UTI*3L*("`@
M("`@("!R971U<FX@)&)L86UE.PH@("`@?0H*("`@(&9U;F-T:6]N("9G9710
M871C:'-E=$]B:F5C="@D9FEL96YA;64L("1C86-H92`](&YU;&PI"B`@("![
M"B`@("`@("`@)'!O(#T@)E9#7U!A=&-H<V5T7V-V<SHZ9V5T4&%T8VAS971/
M8FIE8W0H)'1H:7,L("1T:&ES+3YS;W5R8V5R;V]T*"D@+B`G+R<@+B`D9FEL
M96YA;64L("1C86-H92D["B`@("`@("`@<F5T=7)N("1P;SL*("`@('T*"GT*
M"B\J*@H@*B!60U]C=G,@86YN;W1A=&4@8VQA<W,N"B`J"B`J($%N:6P@36%D
M:&%V87!E9&1Y+"`\86YI;$!R96-O:6PN;W)G/@H@*@H@*B!`875T:&]R("!!
M;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`<&%C:V%G
M92!60PH@*B\*8VQA<W,@5D-?06YN;W1A=&5?8W9S('L*"B`@("!V87(@)&9I
M;&4["B`@("!V87(@)')E<#L*("`@('9A<B`D=&UP9FEL93L*"B`@("!F=6YC
M=&EO;B!60U]!;FYO=&%T95]C=G,H)')E<"P@)&9I;&4L("1T;7!F:6QE*0H@
M("`@>PH@("`@("`@("1T:&ES+3YR97`@/2`D<F5P.PH@("`@("`@("1T:&ES
M+3YF:6QE(#T@)&9I;&4["B`@("`@("`@)'1H:7,M/G1M<&9I;&4@/2`D=&UP
M9FEL93L*("`@('T*"B`@("!F=6YC=&EO;B!D;T%N;F]T871E*"1R978I"B`@
M("!["B`@("`@("`@+RH@36%K92!S=7)E('1H870@=&AE(&9I;&4@=F%L=65S
M(&9O<B!T:&ES(&]B:F5C="!I<R!V86QI9"X@*B\*("`@("`@("!I9B`H:7-?
M82@D=&AI<RT^9FEL92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O*B!-86ME('-U<F4@
M=&AA="!T:&4@8W9S<F5P('!A<F%M971E<B!I<R!V86QI9"X@*B\*("`@("`@
M("!I9B`H:7-?82@D=&AI<RT^<F5P+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(&EF("@A
M5D-?4F5V:7-I;VXZ.G9A;&ED*"1R978I*2!["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1W:&5R92`]("1T:&ES+3YF
M:6QE+3YQ=65R>4UO9'5L95!A=&@H*3L*("`@("`@("`D<V]U<F-E<F]O="`]
M("1T:&ES+3YR97`M/G-O=7)C97)O;W0H*3L*"B`@("`@("`@)'!I<&4@/2!P
M;W!E;B@D=&AI<RT^<F5P+3YG9710871H*"=C=G,G*2`N("<@+6X@<V5R=F5R
M(#X@)R`N("1T:&ES+3YT;7!F:6QE+"!60U]724Y$3U=3(#\@)W=B)R`Z("=W
M)RD["@H@("`@("`@("1O=70@/2!A<G)A>2@I.PH@("`@("`@("1O=71;72`]
M(")2;V]T("1S;W5R8V5R;V]T(CL*("`@("`@("`D;W5T6UT@/2`G5F%L:60M
M<F5S<&]N<V5S(&]K(&5R<F]R(%9A;&ED+7)E<75E<W1S($-H96-K960M:6X@
M57!D871E9"!-97)G960@4F5M;W9E9"!-($4G.PH@("`@("`@("1O=71;72`]
M("=5<V55;F-H86YG960G.PH@("`@("`@("1O=71;72`]("=!<F=U;65N="`M
M<B<["B`@("`@("`@)&]U=%M=(#T@(D%R9W5M96YT("1R978B.PH@("`@("`@
M("1O=71;72`](")!<F=U;65N="`D=VAE<F4B.PH@("`@("`@("1D:7)S(#T@
M97AP;&]D92@G+R<L(&1I<FYA;64H)'=H97)E*2D["B`@("`@("`@=VAI;&4@
M*&-O=6YT*"1D:7)S*2D@>PH@("`@("`@("`@("`D;W5T6UT@/2`G1&ER96-T
M;W)Y("<@+B!I;7!L;V1E*"<O)RP@)&1I<G,I.PH@("`@("`@("`@("`D;W5T
M6UT@/2`B)'-O=7)C97)O;W0O(B`N(&EM<&QO9&4H)R\G+"`D9&ER<RD["B`@
M("`@("`@("`@(&%R<F%Y7W!O<"@D9&ER<RD["B`@("`@("`@?0H@("`@("`@
M("1O=71;72`]("=$:7)E8W1O<GD@+B<["B`@("`@("`@)&]U=%M=(#T@)'-O
M=7)C97)O;W0["B`@("`@("`@)&]U=%M=(#T@)V%N;F]T871E)SL*"B`@("`@
M("`@9F]R96%C:"`H)&]U="!A<R`D;&EN92D@>PH@("`@("`@("`@("!F=W)I
M=&4H)'!I<&4L("(D;&EN95QN(BD["B`@("`@("`@?0H@("`@("`@('!C;&]S
M92@D<&EP92D["@H@("`@("`@(&EF("@A*"1F;"`](&9O<&5N*"1T:&ES+3YT
M;7!F:6QE+"!60U]724Y$3U=3(#\@)W)B)R`Z("=R)RDI*2!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1L:6YE<R`]
M(&%R<F%Y*"D["B`@("`@("`@)&QI;F4@/2!F9V5T<R@D9FPL(#0P.38I.PH*
M("`@("`@("`O+R!7:6YD;W=S('9E<G-I;VYS(&]F(&-V<R!A;'=A>7,@<F5T
M=7)N("1W:&5R92!W:71H(&9O<G=A<F1S('-L87-H97,N"B`@("`@("`@:68@
M*%9#7U=)3D1/5U,I('L*("`@("`@("`@("`@)'=H97)E(#T@<W1R7W)E<&QA
M8V4H1$E214-43U)97U-%4$%2051/4BP@)R\G+"`D=VAE<F4I.PH@("`@("`@
M('T*"B`@("`@("`@=VAI;&4@*"1L:6YE("8F("%P<F5G7VUA=&-H*")\7D5<
M<RM!;FYO=&%T:6]N<R!F;W(@)'=H97)E?"(L("1L:6YE*2D@>PH@("`@("`@
M("`@("`D;&EN92`](&9G971S*"1F;"P@-#`Y-BD["B`@("`@("`@?0H*("`@
M("`@("!I9B`H(21L:6YE*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"=5;F%B;&4@=&\@86YN;W1A=&4[('-E<G9E<B!S86ED.B`G
M("X@)&QI;F4I.PH@("`@("`@('T*"B`@("`@("`@)&QI;F5N;R`](#$["B`@
M("`@("`@=VAI;&4@*"1L:6YE(#T@9F=E=',H)&9L+"`T,#DV*2D@>PH@("`@
M("`@("`@("!I9B`H<')E9U]M871C:"@G+UY-7',K*%M<9%PN72LI7',K7"@H
M+BLI7',K*%QD*RU<=RLM7&0K*5PI.BXH+BHI)"\G+"`D;&EN92P@)')E9W,I
M*2!["B`@("`@("`@("`@("`@("`D96YT<GD@/2!A<G)A>2@I.PH@("`@("`@
M("`@("`@("`@)&5N=')Y6R=R978G72`@("`]("1R96=S6S%=.PH@("`@("`@
M("`@("`@("`@)&5N=')Y6R=A=71H;W(G72`]('1R:6TH)')E9W-;,ETI.PH@
M("`@("`@("`@("`@("`@)&5N=')Y6R=D871E)UT@("`]("1R96=S6S-=.PH@
M("`@("`@("`@("`@("`@)&5N=')Y6R=L:6YE)UT@("`]("1R96=S6S1=.PH@
M("`@("`@("`@("`@("`@)&5N=')Y6R=L:6YE;F\G72`]("1L:6YE;F\K*SL*
M("`@("`@("`@("`@("`@("1L:6YE<UM=(#T@)&5N=')Y.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!F8VQO<V4H)&9L*3L*("`@("`@("!R
M971U<FX@)&QI;F5S.PH@("`@?0H*?0H*+RHJ"B`J(%9#7V-V<R!C:&5C:V]U
M="!C;&%S<RX*("H*("H@4V5E('1H92!214%$344@9FEL92!T:&%T(&-A;64@
M=VET:"!T:&ES(&QI8G)A<GD@9F]R(&UO<F4*("H@:6YF;W)M871I;VXL(&%N
M9"!R96%D('1H92!I;FQI;F4@9&]C=6UE;G1A=&EO;BX*("H*("H@06YI;"!-
M861H879A<&5D9'DL(#QA;FEL0')E8V]I;"YO<F<^"B`J"B`J($!A=71H;W(@
M($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J($!P86-K
M86=E(%9#"B`J+PIC;&%S<R!60U]#:&5C:V]U=%]C=G,@>PH*("`@("\J*@H@
M("`@("H@4W1A=&EC(&9U;F-T:6]N('=H:6-H(')E='5R;G,@82!F:6QE('!O
M:6YT:6YG('1O('1H92!H96%D(&]F('1H90H@("`@("H@<F5Q=65S=&5D(')E
M=FES:6]N(&]F(&%N(%)#4R!F:6QE+@H@("`@("H*("`@("`J($!P87)A;2!6
M0U]C=G,@)')E<"`@("`@("!!(')E<&]S:71O<GD@;V)J96-T"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1F=6QL;F%M92`@1G5L;'D@<75A;&EF:65D('!A=&AN
M86UE(&]F('1H92!D97-I<F5D(%)#4PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@(&9I;&4@=&\@8VAE8VMO=70*("`@("`J($!P87)A;2!S=')I
M;F<@)')E=B`@("`@("!20U,@<F5V:7-I;VX@;G5M8F5R('1O(&-H96-K(&]U
M=`H@("`@("H*("`@("`J($!R971U<FX@<F5S;W5R8V5\;V)J96-T("!%:71H
M97(@82!014%27T5R<F]R(&]B:F5C="P@;W(@82!S=')E86T*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("!P;VEN=&5R('1O('1H92!H96%D(&]F
M('1H92!C:&5C:V]U=`H@("`@("HO"B`@("!F=6YC=&EO;B!G970H)')E<"P@
M)&9U;&QN86UE+"`D<F5V*0H@("`@>PH@("`@("`@(&EF("@A5D-?4F5V:7-I
M;VXZ.G9A;&ED*"1R978I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"=);G9A;&ED(')E=FES:6]N(&YU;6)E<B<I.PH@("`@("`@
M('T*"B`@("`@("`@:68@*%9#7U=)3D1/5U,I('L*("`@("`@("`@("`@)&UO
M9&4@/2`G<F(G.PH@("`@("`@("`@("`D<5]N86UE(#T@)R(G("X@97-C87!E
M<VAE;&QC;60H<W1R7W)E<&QA8V4H)UQ<)RP@)R\G+"`D9G5L;&YA;64I*2`N
M("<B)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;6]D92`]("=R
M)SL*("`@("`@("`@("`@)'%?;F%M92`](&5S8V%P97-H96QL87)G*"1F=6QL
M;F%M92D["B`@("`@("`@?0H*("`@("`@("!I9B`H(2@D4D-3(#T@<&]P96XH
M)')E<"T^9V5T4&%T:"@G8V\G*2`N("(@+7`D<F5V("1Q7VYA;64@,CXF,2(L
M("1M;V1E*2DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H)T-O=6QD;EPG="!P97)F;W)M(&-H96-K;W5T(&]F('1H92!R97%U97-T
M960@9FEL92<I.PH@("`@("`@('T*"B`@("`@("`@+RH@1FER<W0@;&EN92!F
M<F]M(&-O('-H;W5L9"!B92!O9B!T:&4@9F]R;2`Z"B`@("`@("`@("H@+W!A
M=&@O=&\O9FEL96YA;64L=B`@+2T^("!S=&%N9&%R9"!O=70*("`@("`@("`@
M*B!A;F0@=V4@8VAE8VL@=&AA="!T:&ES(&ES('1H92!C87-E(&%N9"!E<G)O
M<B!O=&AE<G=I<V4*("`@("`@("`@*B\*"B`@("`@("`@)&-O(#T@9F=E=',H
M)%)#4RP@,3`R-"D["B`@("`@("`@:68@*"%P<F5G7VUA=&-H*"<O7BA;7%,@
M72LI+'9<<RLM+3Y<<RMS="AA;F1A<BD_9"`_;W5T*'!U="D_7',J)"\G+"`D
M8V\L("1R96=S*2!\?"`D<F5G<ULQ72XG+'8G("$]("1F=6QL;F%M92D@>PH@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G56YE>'!E8W1E
M9"!O=71P=70@9G)O;2!C:&5C:V]U=#H@)R`N("1C;RD["B`@("`@("`@?0H*
M("`@("`@("`O*B!.97AT(&QI;F4@9G)O;2!C;R!I<R!O9B!T:&4@9F]R;3H*
M("`@("`@("`@*B!R979I<VEO;B`Q+C(N,PH@("`@("`@("`J(%1/1$\Z(&-O
M;7!A<F4@=&AI<R!T;R`D<F5V(&9O<B!C;VYS:7-T96YC>2P@871M('=E(&IU
M<W0*("`@("`@("`@*B`@("`@("!D:7-C87)D('1H92!V86QU92!T;R!M;W9E
M(&EN<'5T('!O:6YT97(@86QO;F<@+2!A=G-M"B`@("`@("`@("HO"B`@("`@
M("`@)&-O(#T@9F=E=',H)%)#4RP@,3`R-"D["@H@("`@("`@(')E='5R;B`D
M4D-3.PH@("`@?0H*?0H*+RHJ"B`J(%9#7V-V<R!D:69F(&-L87-S+@H@*@H@
M*B!#;W!Y<FEG:'0@06YI;"!-861H879A<&5D9'DL(#QA;FEL0')E8V]I;"YO
M<F<^"B`J"B`J($!A=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E
M8V]I;"YO<F<^"B`J($!P86-K86=E(%9#"B`J+PIC;&%S<R!60U]$:69F7V-V
M<R!["@H@("`@+RHJ"B`@("`@*B!/8G1A:6X@=&AE(&1I9F9E<F5N8V5S(&)E
M='=E96X@='=O(')E=FES:6]N<R!O9B!A(&9I;&4N"B`@("`@*@H@("`@("H@
M0'!A<F%M(%9#7V-V<R`D<F5P("`@("`@("!!(')E<&]S:71O<GD@;V)J96-T
M+@H@("`@("H@0'!A<F%M(%9#7T9I;&5?8W9S("1F:6QE("!4:&4@9&5S:7)E
M9"!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<F5V,2`@("`@("!/<FEG
M:6YA;"!R979I<VEO;B!N=6UB97(@=&\@8V]M<&%R92!F<F]M+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<F5V,B`@("`@("!.97<@<F5V:7-I;VX@;G5M8F5R
M('1O(&-O;7!A<F4@86=A:6YS="X*("`@("`J($!P87)A;2!S=')I;F<@)'1Y
M<&4@("`@("`@5&AE('1Y<&4@;V8@9&EF9B`H92YG+B`G=6YI9FEE9"<I+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&YU;2`@("`@("!.=6UB97(@;V8@;&EN
M97,@=&\@8F4@=7-E9"!I;B!C;VYT97AT(&%N9`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("!U;FEF:65D(&1I9F9S+@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)'=S("`@("`@("!3:&]W('=H:71E<W!A8V4@:6X@=&AE(&1I
M9F8_"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F=\8F]O;&5A;B`@1F%L
M<V4@;VX@9F%I;'5R92P@;W(@82!S=')I;F<@8V]N=&%I;FEN9R!T:&4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@(&1I9F8@;VX@<W5C8V5S<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T*"1R97`L("1F:6QE+"`D<F5V,2P@
M)')E=C(L("1T>7!E(#T@)V-O;G1E>'0G+"`D;G5M(#T@,RP*("`@("`@("`@
M("`@("`@("`D=W,@/2!T<G5E*0H@("`@>PH@("`@("`@("\J($UA:V4@<W5R
M92!T:&%T('1H92!F:6QE('!A<F%M971E<B!I<R!V86QI9"X@*B\*("`@("`@
M("!I9B`H:7-?82@D9FEL92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O*B!#:&5C:R!T
M:&%T('1H92!R979I<VEO;B!N=6UB97)S(&%R92!V86QI9"X@*B\*("`@("`@
M("`D<F5V,2`](%9#7U)E=FES:6]N.CIV86QI9"@D<F5V,2D@/R`D<F5V,2`Z
M("<Q+C$G.PH@("`@("`@("1R978R(#T@5D-?4F5V:7-I;VXZ.G9A;&ED*"1R
M978Q*2`_("1R978R(#H@)S$N,2<["@H@("`@("`@("1F=6QL3F%M92`]("1F
M:6QE+3YQ=65R>49U;&Q0871H*"D["B`@("`@("`@)&1I9F8@/2!A<G)A>2@I
M.PH@("`@("`@("1O<'1I;VYS(#T@)RUK:R`G.PH@("`@("`@(&EF("@A)'=S
M*2!["B`@("`@("`@("`@("1O<'1S(#T@)R`M8D(@)SL*("`@("`@("`@("`@
M)&]P=&EO;G,@+CT@)&]P=',["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&]P=',@/2`G)SL*("`@("`@("!]"B`@("`@("`@<W=I=&-H("@D='EP
M92D@>PH@("`@("`@(&-A<V4@)V-O;G1E>'0G.@H@("`@("`@("`@("`D;W!T
M:6]N<R`]("1O<'1S("X@)RUP("TM8V]N=&5X=#TG("X@*&EN="DD;G5M.PH@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G=6YI9FEE9"<Z"B`@
M("`@("`@("`@("1O<'1I;VYS(#T@)&]P=',@+B`G+7`@+2UU;FEF:65D/2<@
M+B`H:6YT*21N=6T["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E
M("=C;VQU;6XG.@H@("`@("`@("`@("`D;W!T:6]N<R`]("1O<'1S("X@)RTM
M<VED92UB>2US:61E("TM=VED=&@],3(P)SL*("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@(&-A<V4@)V5D)SH*("`@("`@("`@("`@)&]P=&EO;G,@/2`D
M;W!T<R`N("<M92<["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@
M("`@("`@+R\@5VEN9&]W<R!V97)S:6]N<R!O9B!C=G,@86QW87ES(')E='5R
M;B`D=VAE<F4@=VET:"!F;W)W87)D<R!S;&%S:&5S+@H@("`@("`@(&EF("A6
M0U]724Y$3U=3*2!["B`@("`@("`@("`@("1F=6QL3F%M92`]('-T<E]R97!L
M86-E*$1)4D5#5$]265]315!!4D%43U(L("<O)RP@)&9U;&Q.86UE*3L*("`@
M("`@("!]"@H@("`@("`@("\O(%1/1$\Z(&%D9"!O<'1I;VYS(&9O<B`D:'(@
M;W!T:6]N<R`M(&AO=V5V97(@=&AE<V4@;6%Y(&YO="!B90H@("`@("`@("\O
M(&-O;7!A=&EB;&4@=VET:"!S;VUE(&1I9F9S+@H@("`@("`@("1C;VUM86YD
M(#T@)')E<"T^9V5T4&%T:"@G<F-S9&EF9B<I("X@(B`D;W!T:6]N<R`M<B1R
M978Q("UR)')E=C(@7"(B("X@97-C87!E<VAE;&QC;60H)&9U;&Q.86UE*2`N
M("<B(#(^)C$G.PH@("`@("`@(&EF("A60U]724Y$3U=3*2!["B`@("`@("`@
M("`@("1C;VUM86YD("X]("<@/"`B)R`N(%]?1DE,15]?("X@)R(G.PH@("`@
M("`@('T*"B`@("`@("`@97AE8R@D8V]M;6%N9"P@)&1I9F8L("1R971V86PI
M.PH@("`@("`@(')E='5R;B`H)')E='9A;"`^(#`I(#\@)&1I9F8@.B!A<G)A
M>2@I.PH@("`@?0H*?0H*+RHJ"B`J(%9#7V-V<R!D:7)E8W1O<GD@8VQA<W,N
M"B`J"B`J($-O<'ER:6=H="!!;FEL($UA9&AA=F%P961D>2P@/&%N:6Q`<F5C
M;VEL+F]R9SX*("H*("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@/&%N
M:6Q`<F5C;VEL+F]R9SX*("H@0'!A8VMA9V4@5D,*("HO"F-L87-S(%9#7T1I
M<F5C=&]R>5]C=G,@>PH*("`@('9A<B`D<F5P.PH@("`@=F%R("1D:7).86UE
M.PH@("`@=F%R("1F:6QE<SL*("`@('9A<B`D871T:6-&:6QE<SL*("`@('9A
M<B`D;65R9V5D1FEL97,["B`@("!V87(@)&1I<G,["B`@("!V87(@)'!A<F5N
M=#L*("`@('9A<B`D;6]D=6QE3F%M93L*("`@('9A<B`D<V]R=$1I<CL*"B`@
M("`O*BH*("`@("`J($-R96%T97,@82!#5E,@1&ER96-T;W)Y(&]B:F5C="!T
M;R!S=&]R92!I;F9O<FUA=&EO;@H@("`@("H@86)O=70@=&AE(&9I;&5S(&EN
M(&$@<VEN9VQE(&1I<F5C=&]R>2!I;B!T:&4@<F5P;W-I=&]R>2X*("`@("`J
M"B`@("`@*B!`<&%R86T@5D-?8W9S("1R97`@("`@("`@("`@($$@<F5P;W-I
M=&]R>2!O8FIE8W0*("`@("`J($!P87)A;2!S=')I;F<@)&1N("`@("`@("`@
M("`@4&%T:"!T;R!T:&4@9&ER96-T;W)Y+@H@("`@("H@0'!A<F%M(%9#7T1I
M<F5C=&]R>5]C=G,@)'!N("!4:&4@<&%R96YT(%9#7T1I<F5C=&]R>2!T;R!T
M:&ES(&]N92X*("`@("`J+PH@("`@9G5N8W1I;VX@5D-?1&ER96-T;W)Y7V-V
M<R@D<F5P+"`D9&XL("1P;B`]("<G*0H@("`@>PH@("`@("`@("1T:&ES+3YR
M97`@/2`D<F5P.PH@("`@("`@("1T:&ES+3YP87)E;G0@/2`D<&X["B`@("`@
M("`@)'1H:7,M/FUO9'5L94YA;64@/2`D9&X["B`@("`@("`@)'1H:7,M/F1I
M<DYA;64@/2`D<F5P+3YS;W5R8V5R;V]T*"D@+B`B+R1D;B(["B`@("`@("`@
M)'1H:7,M/F9I;&5S(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^9&ER<R`]
M(&%R<F%Y*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@9G5L;'D@
M<75A;&EF:65D('!A=&AN86UE('1O('1H:7,@9&ER96-T;W)Y('=I=&@@;F\*
M("`@("`J('1R86EL:6YG("\N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%!A=&AN86UE(&]F('1H:7,@9&ER96-T;W)Y"B`@("`@*B\*("`@(&9U
M;F-T:6]N('%U97)Y1&ER*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/F1I<DYA;64["B`@("!]"@H@("`@9G5N8W1I;VX@)G%U97)Y1&ER3&ES="@I
M"B`@("!["B`@("`@("`@<F5S970H)'1H:7,M/F1I<G,I.PH@("`@("`@(')E
M='5R;B`D=&AI<RT^9&ER<SL*("`@('T*"B`@("!F=6YC=&EO;B`F<75E<GE&
M:6QE3&ES="@D<VAO=V%T=&EC(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@
M*"1S:&]W871T:6,@)B8@:7-S970H)'1H:7,M/FUE<F=E9$9I;&5S*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/FUE<F=E9$9I;&5S.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9FEL97,["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@5&5L;"!T:&4@;V)J96-T
M('1O(&]P96X@86YD(&)R;W=S92!I=',@8W5R<F5N="!D:7)E8W1O<GDL(&%N
M9`H@("`@("H@<F5T<FEE=F4@82!L:7-T(&]F(&%L;"!T:&4@;V)J96-T<R!I
M;B!T:&5R92X@($ET('1H96X@<&]P=6QA=&5S"B`@("`@*B!T:&4@9FEL92]D
M:7)E8W1O<GD@<W1A8VL@86YD(&UA:V5S(&ET(&%V86EL86)L92!F;W(@<F5T
M<FEE=F%L+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;GQO8FIE8W0@
M(%!%05)?17)R;W(@;V)J96-T(&]N(&%N(&5R<F]R+"!T<G5E(&]N('-U8V-E
M<W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&)R;W=S941I<B@D8V%C:&4@/2!N
M=6QL+"`D<75I8VML;V<@/2!T<G5E+"`D<VAO=V%T=&EC(#T@9F%L<V4I"B`@
M("!["B`@("`@("`@+RH@36%K92!S=7)E('=E(&%R92!T<GEI;F<@=&\@;&ES
M="!A(&1I<F5C=&]R>2`J+PH@("`@("`@(&EF("@A0&ES7V1I<B@D=&AI<RT^
M9&ER3F%M92DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H)U5N86)L92!T;R!F:6YD(&1I<F5C=&]R>2`G("X@)'1H:7,M/F1I<DYA
M;64I.PH@("`@("`@('T*"B`@("`@("`@+RH@3W!E;B!T:&4@9&ER96-T;W)Y
M(&9O<B!R96%D:6YG(&ET<R!C;VYT96YT<R`J+PH@("`@("`@(&EF("@A*"1$
M25(@/2!`;W!E;F1I<B@D=&AI<RT^9&ER3F%M92DI*2!["B`@("`@("`@("`@
M("1E<G)M<V<@/2`H(65M<'1Y*"1P:'!?97)R;W)M<V<I*2`_("1P:'!?97)R
M;W)M<V<@.B`G4&5R;6ES<VEO;B!D96YI960G.PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@D97)R;7-G*3L*("`@("`@("!]"@H@("`@
M("`@("\J($-R96%T92!T=V\@87)R87ES("T@;VYE(&]F(&%L;"!T:&4@9FEL
M97,L(&%N9"!T:&4@;W1H97(@;V8*("`@("`@("`@*B!A;&P@=&AE(&1I<F5C
M=&]R:65S+B`J+PH@("`@("`@('=H:6QE("@H)&YA;64@/2!R96%D9&ER*"1$
M25(I*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@:68@*"1N86UE(#T]("<N
M)R!\?"`D;F%M92`]/2`G+BXG*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU
M93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'!A=&@@/2`D=&AI<RT^
M9&ER3F%M92`N("<O)R`N("1N86UE.PH@("`@("`@("`@("!I9B`H0&ES7V1I
M<B@D<&%T:"DI('L*("`@("`@("`@("`@("`@("\J(%-K:7`@071T:6,@9&ER
M96-T;W)Y+B`J+PH@("`@("`@("`@("`@("`@:68@*"1N86UE("$]("=!='1I
M8R<I('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9&ER<UM=(#T@)&YA
M;64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS96EF("A`
M:7-?9FEL92@D<&%T:"D@)B8@<W5B<W1R*"1N86UE+"`M,BD@/3T@)RQV)RD@
M>PH@("`@("`@("`@("`@("`@+RH@4W!A=VX@82!N97<@9FEL92!O8FIE8W0@
M=&\@<F5P<F5S96YT('1H:7,@9FEL92X@*B\*("`@("`@("`@("`@("`@("1F
M;"`]("1T:&ES+3YR97`M/F=E=$9I;&5/8FIE8W0H<W5B<W1R*"1P871H+"!S
M=')L96XH)'1H:7,M/G)E<"T^<V]U<F-E<F]O="@I*2P@+3(I+"`D8V%C:&4L
M("1Q=6EC:VQO9RD["B`@("`@("`@("`@("`@("!I9B`H:7-?82@D9FPL("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)&9L
M.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^9FEL97-;72`]("1F;#L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@0VQO<V4@=&AE(&9I
M;&5H86YD;&4[('=E)W9E(&YO=R!G;W0@82!L:7-T(&]F(&1I<G,@86YD"B`@
M("`@("`@("H@9FEL97,N("HO"B`@("`@("`@8VQO<V5D:7(H)$1)4BD["@H@
M("`@("`@("\J($EF('=E('=A;G0@=&\@;65R9V4@=&AE(&%T=&EC+"!A9&0@
M:70@:6X@:&5R92X@*B\*("`@("`@("!I9B`H)'-H;W=A='1I8RD@>PH@("`@
M("`@("`@("`D871T:6-$:7(@/2!N97<@5D-?1&ER96-T;W)Y7V-V<R@D=&AI
M<RT^<F5P+"`D=&AI<RT^;6]D=6QE3F%M92`N("<O071T:6,G+"`D=&AI<RD[
M"B`@("`@("`@("`@(&EF("@A:7-?82@D871T:6-$:7(M/F)R;W=S941I<B@D
M8V%C:&4L("1Q=6EC:VQO9RDL("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@("`@("1T:&ES+3YA='1I8T9I;&5S(#T@)&%T=&EC1&ER+3YQ=65R>49I
M;&5,:7-T*"D["B`@("`@("`@("`@("`@("`D=&AI<RT^;65R9V5D1FEL97,@
M/2!A<G)A>5]M97)G92@D=&AI<RT^9FEL97,L("1T:&ES+3YA='1I8T9I;&5S
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3;W)T('1H92!C;VYT96YT<R!O
M9B!T:&4@9&ER96-T;W)Y(&EN(&$@9VEV96X@9F%S:&EO;B!A;F0*("`@("`J
M(&]R9&5R+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1H;W<@($]F
M('1H92!F;W)M(%9#7U-/4E1?*B!W:&5R92`J(&-A;B!B93H*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@($Y/3D4L($Y!344L($%'12P@4D56(&9O<B!S
M;W)T:6YG(&)Y(&YA;64L(&%G92!O<@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@<F5V:7-I;VXN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9&ER("!/
M9B!T:&4@9F]R;2!60U]33U)47RH@=VAE<F4@*B!C86X@8F4Z"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("!!4T-%3D1)3D<L($1%4T-%3D1)3D<@9F]R
M('1H92!O<F1E<B!O9B!T:&4@<V]R="X*("`@("`J+PH@("`@9G5N8W1I;VX@
M87!P;'E3;W)T*"1H;W<@/2!60U]33U)47TY/3D4L("1D:7(@/2!60U]33U)4
M7T%30T5.1$E.1RD*("`@('L*("`@("`@("`O+R!!;'=A>7,@<V]R="!D:7)E
M8W1O<FEE<R!B>2!N86UE+@H@("`@("`@(&YA=&-A<V5S;W)T*"1T:&ES+3YD
M:7)S*3L*"B`@("`@("`@)'1H:7,M/F1O1FEL95-O<G0H)'1H:7,M/F9I;&5S
M+"`D:&]W+"`D9&ER*3L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/F%T=&EC
M1FEL97,I*2!["B`@("`@("`@("`@("1T:&ES+3YD;T9I;&53;W)T*"1T:&ES
M+3YA='1I8T9I;&5S+"`D:&]W+"`D9&ER*3L*("`@("`@("!]"B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3YM97)G961&:6QE<RDI('L*("`@("`@("`@("`@
M)'1H:7,M/F1O1FEL95-O<G0H)'1H:7,M/FUE<F=E9$9I;&5S+"`D:&]W+"`D
M9&ER*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@9&]&:6QE4V]R
M="@F)&9I;&5,:7-T+"`D:&]W(#T@5D-?4T]25%].3TY%+"`D9&ER(#T@5D-?
M4T]25%]!4T-%3D1)3D<I"B`@("!["B`@("`@("`@)'1H:7,M/G-O<G1$:7(@
M/2`D9&ER.PH*("`@("`@("!S=VET8V@@*"1H;W<I('L*("`@("`@("!C87-E
M(%9#7U-/4E1?04=%.@H@("`@("`@("`@("!U<V]R="@D9FEL94QI<W0L(&%R
M<F%Y*"1T:&ES+"`G9FEL94%G95-O<G0G*2D["B`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("!C87-E(%9#7U-/4E1?3D%-13H*("`@("`@("`@("`@=7-O
M<G0H)&9I;&5,:7-T+"!A<G)A>2@D=&AI<RP@)V9I;&5.86UE4V]R="<I*3L*
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@5D-?4T]25%]!551(
M3U(Z"B`@("`@("`@("`@('5S;W)T*"1F:6QE3&ES="P@87)R87DH)'1H:7,L
M("=F:6QE075T:&]R4V]R="<I*3L*("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@(&-A<V4@5D-?4T]25%]2158Z"B`@("`@("`@("`@('5S;W)T*"1F:6QE
M3&ES="P@87)R87DH)'1H:7,L("=F:6QE4F5V4V]R="<I*3L*("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("!U;G-E="@D=&AI<RT^<V]R
M=$1I<BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3;W)T(&9U;F-T:6]N(&9O
M<B!F:6QE(&%G92X*("`@("`J+PH@("`@9G5N8W1I;VX@9FEL94%G95-O<G0H
M)&$L("1B*0H@("`@>PH@("`@("`@("1A82`]("1A+3YQ=65R>4QA<W1,;V<H
M*3L*("`@("`@("`D8F(@/2`D8BT^<75E<GE,87-T3&]G*"D["B`@("`@("`@
M:68@*"1A82T^<75E<GE$871E*"D@/3T@)&)B+3YQ=65R>41A=&4H*2D@>PH@
M("`@("`@("`@("!R971U<FX@,#L*("`@("`@("!](&5L<V5I9B`H)'1H:7,M
M/G-O<G1$:7(@/3T@5D-?4T]25%]!4T-%3D1)3D<I('L*("`@("`@("`@("`@
M<F5T=7)N("@D86$M/G%U97)Y1&%T92@I(#P@)&)B+3YQ=65R>41A=&4H*2D@
M/R`Q(#H@+3$["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M("@D8F(M/G%U97)Y1&%T92@I(#P@)&%A+3YQ=65R>41A=&4H*2D@/R`Q(#H@
M+3$["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4V]R="!F=6YC
M=&EO;B!B>2!A=71H;W(@;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9FEL
M94%U=&AO<E-O<G0H)&$L("1B*0H@("`@>PH@("`@("`@("1A82`]("1A+3YQ
M=65R>4QA<W1,;V<H*3L*("`@("`@("`D8F(@/2`D8BT^<75E<GE,87-T3&]G
M*"D["B`@("`@("`@:68@*"1A82T^<75E<GE!=71H;W(H*2`]/2`D8F(M/G%U
M97)Y075T:&]R*"DI('L*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@
M?2!E;'-E:68@*"1T:&ES+3YS;W)T1&ER(#T](%9#7U-/4E1?05-#14Y$24Y'
M*2!["B`@("`@("`@("`@(')E='5R;B`H)&%A+3YQ=65R>4%U=&AO<B@I(#X@
M)&)B+3YQ=65R>4%U=&AO<B@I*2`_(#$@.B`M,3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@*"1B8BT^<75E<GE!=71H;W(H*2`^("1A
M82T^<75E<GE!=71H;W(H*2D@/R`Q(#H@+3$["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@4V]R="!F=6YC=&EO;B!F;W(@9FEL96YA;64N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&9I;&5.86UE4V]R="@D82P@)&(I"B`@("![
M"B`@("`@("`@:68@*"1T:&ES+3YS;W)T1&ER(#T](%9#7U-/4E1?05-#14Y$
M24Y'*2!["B`@("`@("`@("`@(')E='5R;B!S=')C87-E8VUP*"1A+3YN86UE
M+"`D8BT^;F%M92D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N('-T<F-A<V5C;7`H)&(M/FYA;64L("1A+3YN86UE*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3;W)T(&9U;F-T:6]N(&9O<B!R979I
M<VEO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@9FEL95)E=E-O<G0H)&$L("1B
M*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^<V]R=$1I<B`]/2!60U]33U)4
M7T%30T5.1$E.1RD@>PH@("`@("`@("`@("!R971U<FX@5D-?4F5V:7-I;VXZ
M.F-M<"@D82T^<75E<GE(96%D*"DL("1B+3YQ=65R>4AE860H*2D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(%9#7U)E=FES:6]N.CIC
M;7`H)&(M/G%U97)Y2&5A9"@I+"`D82T^<75E<GE(96%D*"DI.PH@("`@("`@
M('T*("`@('T*"GT*"B\J*@H@*B!60U]C=G,@9FEL92!C;&%S<RX*("H*("H@
M0V]P>7)I9VAT($%N:6P@36%D:&%V87!E9&1Y+"`\86YI;$!R96-O:6PN;W)G
M/@H@*@H@*B!`875T:&]R("!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O
M:6PN;W)G/@H@*B!`<&%C:V%G92!60PH@*B\*8VQA<W,@5D-?1FEL95]C=G,@
M97AT96YD<R!60U]&:6QE('L*"B`@("`O*BH*("`@("`J($-R96%T92!A(')E
M<&]S:71O<GD@9FEL92!O8FIE8W0L(&%N9"!G:79E(&ET(&EN9F]R;6%T:6]N
M(&%B;W5T"B`@("`@*B!W:&%T(&ET<R!P87)E;G0@9&ER96-T;W)Y(&%N9"!R
M97!O<VET;W)Y(&]B:F5C=',@87)E+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&9L("!&=6QL('!A=&@@=&\@=&AI<R!F:6QE+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!60U]&:6QE7V-V<R@D9FPL("1Q=6EC:VQO9R`](&9A;'-E
M*0H@("`@>PH@("`@("`@("1F;"`N/2`G+'8G.PH@("`@("`@("1T:&ES+3YN
M86UE(#T@8F%S96YA;64H)&9L*3L*("`@("`@("`D=&AI<RT^9&ER(#T@9&ER
M;F%M92@D9FPI.PH@("`@("`@("1T:&ES+3YL;V=S(#T@87)R87DH*3L*("`@
M("`@("`D=&AI<RT^<75I8VML;V<@/2`D<75I8VML;V<["B`@("`@("`@)'1H
M:7,M/G)E=G,@/2!A<G)A>2@I.PH@("`@("`@("1T:&ES+3YB<F%N8VAE<R`]
M(&%R<F%Y*"D["B`@("!]"@H@("`@9G5N8W1I;VX@)F=E=$9I;&5/8FIE8W0H
M)')E<"P@)&9I;&5N86UE+"`D8V%C:&4@/2!N=6QL+"`D<75I8VML;V<@/2!F
M86QS92D*("`@('L*("`@("`@("`O*B!4:&4@=F5R<VEO;B!O9B!T:&4@8V%C
M:&5D(&1A=&$N($EN8W)E;65N="!T:&ES('=H96YE=F5R('1H90H@("`@("`@
M("`J(&EN=&5R;F%L('-T;W)A9V4@9F]R;6%T(&-H86YG97,L('-U8V@@=&AA
M="!W92!M=7-T"B`@("`@("`@("H@:6YV86QI9&%T92!P<FEO<B!C86-H960@
M9&%T82X@*B\*("`@("`@("`D8V%C:&5697)S:6]N(#T@,CL*("`@("`@("`D
M8V%C:&5)9"`]("1R97`M/G-O=7)C97)O;W0H*2`N("=?;B<@+B`D9FEL96YA
M;64@+B`G7V8G("X@*&EN="DD<75I8VML;V<@+B`G7W8G("X@)&-A8VAE5F5R
M<VEO;CL*"B`@("`@("`@)&-T:6UE(#T@=&EM92@I("T@0&9I;&5M=&EM92@D
M9FEL96YA;64@+B`G+'8G*3L*("`@("`@("!I9B`H)&-A8VAE("8F"B`@("`@
M("`@("`@("1C86-H92T^97AI<W1S*"1C86-H94ED+"`D8W1I;64I*2!["B`@
M("`@("`@("`@("1F:6QE3V(@/2!U;G-E<FEA;&EZ92@D8V%C:&4M/F=E="@D
M8V%C:&5)9"P@)&-T:6UE*2D["B`@("`@("`@("`@("1F:6QE3V(M/G-E=%)E
M<&]S:71O<GDH)')E<"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)&9I;&5/8B`](&YE=R!60U]&:6QE7V-V<R@D9FEL96YA;64L("1Q=6EC:VQO
M9RD["B`@("`@("`@("`@("1F:6QE3V(M/G-E=%)E<&]S:71O<GDH)')E<"D[
M"B`@("`@("`@("`@(&EF("AI<U]A*"@D<F5S=6QT(#T@)&9I;&5/8BT^9V5T
M0G)O=W-E26YF;R@I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)&9I;&5/8BT^87!P;'E3;W)T*%9#7U-/4E1?04=%*3L*"B`@("`@("`@("`@
M(&EF("@D8V%C:&4I('L*("`@("`@("`@("`@("`@("1C86-H92T^<V5T*"1C
M86-H94ED+"!S97)I86QI>F4H)&9I;&5/8BDI.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&9I;&5/8CL*("`@('T*"B`@("`O
M*BH*("`@("`J($EF('1H:7,@9FEL92!I<R!P<F5S96YT(&EN(&%N($%T=&EC
M(&1I<F5C=&]R>2P@=&AI<R!I;F1I8V%T97,*("`@("`J(&ET+@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!F:6QE(&ES(&EN('1H
M92!!='1I8RP@86YD(&9A;'-E(&]T:&5R=VES90H@("`@("HO"B`@("!F=6YC
M=&EO;B!I<T%T=&EC1FEL92@I"B`@("!["B`@("`@("`@<F5T=7)N('-U8G-T
M<B@D=&AI<RT^9&ER+"`M-2D@/3T@)T%T=&EC)SL*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE(&YA;64@;V8@=&AE(&-U<G)E;G0@9FEL92!A
M<R!I;B!T:&4@<F5P;W-I=&]R>0H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!&:6QE;F%M92`H=VET:&]U="!T:&4@<&%T:"D*("`@("`J+PH@("`@
M9G5N8W1I;VX@<75E<GE297!O<VET;W)Y3F%M92@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3YN86UE.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!N86UE(&]F('1H92!C=7)R96YT(&9I;&4@=VET:&]U="!T:&4@<F5P
M;W-I=&]R>0H@("`@("H@97AT96YS:6]N<R`H=7-U86QL>2`L=BD*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@1FEL96YA;64@=VET:&]U="!R97!O
M<VET;W)Y(&5X=&5N<VEO;@H@("`@("HO"B`@("!F=6YC=&EO;B!Q=65R>4YA
M;64H*0H@("`@>PH@("`@("`@(')E='5R;B!P<F5G7W)E<&QA8V4H)R\L=B0O
M)RP@)R<L("1T:&ES+3YN86UE*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;B!T:&4@;&%S="!R979I<VEO;B!O9B!T:&4@8W5R<F5N="!F:6QE(&]N
M('1H92!(14%$(&)R86YC:`H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M?&]B:F5C="`@3&%S="!R979I<VEO;B!O9B!T:&4@8W5R<F5N="!F:6QE(&]R
M(%!%05)?17)R;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@;VX@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<75E<GE2979I<VEO;B@I
M"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^<F5V<ULP72DI('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TYO(')E=FES
M:6]N<R<I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/G)E=G-;
M,%T["B`@("!]"@H@("`@9G5N8W1I;VX@<75E<GE0<F5V:6]U<U)E=FES:6]N
M*"1R978I"B`@("!["B`@("`@("`@<F5T=7)N(%9#7U)E=FES:6]N.CIP<F5V
M*"1R978I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!(14%$
M("AM;W-T(')E8V5N="D@<F5V:7-I;VX@;G5M8F5R(&9O<B!T:&ES(&9I;&4N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($A%040@<F5V:7-I;VX@
M;G5M8F5R"B`@("`@*B\*("`@(&9U;F-T:6]N('%U97)Y2&5A9"@I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YH96%D.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N('1H92!L87-T(%9#7VQO9R!O8FIE8W0@:6X@=&AE(&9I
M;&4N"B`@("`@*@H@("`@("H@0')E='5R;B!60U]L;V<@;V8@=&AE(&QA<W0@
M96YT<GD@:6X@=&AE(&9I;&4*("`@("`J+PH@("`@9G5N8W1I;VX@<75E<GE,
M87-T3&]G*"D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YR979S
M6S!=*2!\?"`A:7-S970H)'1H:7,M/FQO9W-;)'1H:7,M/G)E=G-;,%U=*2D@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G3F\@<F5V
M:7-I;VYS)RD["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^;&]G
M<ULD=&AI<RT^<F5V<ULP75T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3;W)T
M('1H92!L:7-T(&]F(%9#7VQO9R!O8FIE8W1S('1H870@=&AI<R!F:6QE(&-O
M;G1A:6YS+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1H;W<@(%9#
M7U-/4E1?4D56("AS;W)T(&)Y(')E=FES:6]N*2P*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@(%9#7U-/4E1?3D%-12`H<V]R="!B>2!A=71H;W(@;F%M
M92DL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!60U]33U)47T%'12`H
M<V]R="!B>2!C;VUM:70@9&%T92D*("`@("`J+PH@("`@9G5N8W1I;VX@87!P
M;'E3;W)T*"1H;W<@/2!60U]33U)47U)%5BD*("`@('L*("`@("`@("!S=VET
M8V@@*"1H;W<I('L*("`@("`@("!C87-E(%9#7U-/4E1?3D%-13H*("`@("`@
M("`@("`@)&9U;F,@/2`G3F%M92<["B`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("!C87-E(%9#7U-/4E1?04=%.@H@("`@("`@("`@("`D9G5N8R`]("=!
M9V4G.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!60U]33U)4
M7U)%5CH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`D9G5N8R`]("=2
M979I<VEO;B<["B`@("`@("`@?0H*("`@("`@("!U87-O<G0H)'1H:7,M/FQO
M9W,L(&%R<F%Y*"1T:&ES+"`B<V]R=$)Y)&9U;F,B*2D["B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@<V]R=$)Y*B@I
M(&9U;F-T:6]N<R!A<F4@:6YT97)N86QL>2!U<V5D(&)Y(&%P<&QY4V]R="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<V]R=$)Y4F5V:7-I;VXH)&$L("1B*0H@
M("`@>PH@("`@("`@(')E='5R;B!60U]2979I<VEO;CHZ8VUP*"1B+3YR978L
M("1A+3YR978I.PH@("`@?0H*("`@(&9U;F-T:6]N('-O<G1">4%G92@D82P@
M)&(I"B`@("!["B`@("`@("`@<F5T=7)N("1B+3YD871E("T@)&$M/F1A=&4[
M"B`@("!]"@H@("`@9G5N8W1I;VX@<V]R=$)Y3F%M92@D82P@)&(I"B`@("![
M"B`@("`@("`@<F5T=7)N('-T<F-M<"@D82T^875T:&]R+"`D8BT^875T:&]R
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%!O<'5L871E('1H92!O8FIE8W0@
M=VET:"!I;F9O<FUA=&EO;B!A8F]U="!T:&4@<F5V:7-I;VYS(&QO9W,@86YD
M(&1A=&5S"B`@("`@*B!O9B!T:&4@9FEL92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86Y\;V)J96-T("!014%27T5R<F]R(&]B:F5C="!O;B!E<G)O
M<BP@;W(@=')U92!O;B!S=6-C97-S"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$)R;W=S94EN9F\H*0H@("`@>PH@("`@("`@("\J($-H96-K('1H870@=V4@
M87)E(&%C='5A;&QY(&EN('1H92!F:6QE<WES=&5M+B`J+PH@("`@("`@("1F
M:6QE(#T@)'1H:7,M/G%U97)Y1G5L;%!A=&@H*3L*("`@("`@("!I9B`H(6ES
M7V9I;&4H)&9I;&4I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*"=&:6QE($YO="!&;W5N9#H@)R`N("1F:6QE*3L*("`@("`@("!]
M"@H@("`@("`@("\J($-A;&P@=&AE(%)#4R!R;&]G(&-O;6UA;F0@=&\@<F5T
M<FEE=F4@=&AE(&9I;&4*("`@("`@("`@*B!I;F9O<FUA=&EO;BX@*B\*("`@
M("`@("`D9FQA9R`]("1T:&ES+3YQ=6EC:VQO9R`_("<@+7(@)R`Z("<@)SL*
M("`@("`@("`D<5]F:6QE(#T@5D-?5TE.1$]74R`_("<B)R`N(&5S8V%P97-H
M96QL8VUD*"1F:6QE*2`N("<B)R`Z(&5S8V%P97-H96QL87)G*"1F:6QE*3L*
M"B`@("`@("`@)&-M9"`]("1T:&ES+3YR97`M/F=E=%!A=&@H)W)L;V<G*2`N
M("1F;&%G("X@)'%?9FEL93L*("`@("`@("!E>&5C*"1C;60L("1R971U<FY?
M87)R87DL("1R971V86PI.PH*("`@("`@("!I9B`H)')E='9A;"D@>PH@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G1F%I;&5D('1O('-P
M87=N(')L;V<@=&\@<F5T<FEE=F4@9FEL92!L;V<@:6YF;W)M871I;VX@9F]R
M("<@+B`D9FEL92D["B`@("`@("`@?0H*("`@("`@("`D86-C=6T@/2!A<G)A
M>2@I.PH@("`@("`@("1S>6UR978@/2!A<G)A>2@I.PH@("`@("`@("1R979S
M>6T@/2!A<G)A>2@I.PH@("`@("`@("1S=&%T92`]("=I;FET)SL*("`@("`@
M("!F;W)E86-H("@D<F5T=7)N7V%R<F%Y(&%S("1L:6YE*2!["B`@("`@("`@
M("`@('-W:71C:"`H)'-T871E*2!["B`@("`@("`@("`@(&-A<V4@)VEN:70G
M.@H@("`@("`@("`@("`@("`@:68@*"%S=')N8VUP*"=H96%D.B`G+"`D;&EN
M92P@-BDI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^:&5A9"`]('-U
M8G-T<B@D;&EN92P@-BD["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H(7-T
M<FYC;7`H)V)R86YC:#HG+"`D;&EN92P@-RDI('L*("`@("`@("`@("`@("`@
M("`@("`D<W1A=&4@/2`G<F5V)SL*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G<F5V)SH*("`@
M("`@("`@("`@("`@(&EF("@A<W1R;F-M<"@G+2TM+2TM+2TM+2<L("1L:6YE
M+"`Q,"DI('L*("`@("`@("`@("`@("`@("`@("`D<W1A=&4@/2`G:6YF;R<[
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-Y;7)E=B`]("1S>6UR978[
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G)E=G-Y;2`]("1R979S>6T[
M"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H<')E9U]M871C:"@B+UY<<RLH
M6UXZ72LI.EQS*RA;7&1<+ETK*2\B+"`D;&EN92P@)')E9W,I*2!["B`@("`@
M("`@("`@("`@("`@("`@+R\@0VAE8VL@=&\@<V5E(&EF('1H:7,@:7,@82!B
M<F%N8V@*("`@("`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+UXH
M7&0K*%PN7&0K*2LI7"XP7"XH7&0K*20O)RPD<F5G<ULR72DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&)R86YC:%)E=B`](%9#7U)E=FES:6]N.CIT
M;T)R86YC:"@D<F5G<ULR72D["B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/F)R86YC:&5S6R1B<F%N8VA2979=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F)R86YC:&5S6R1B<F%N
M8VA2979=(#T@)')E9W-;,5T["B`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D<WEM<F5V6R1R96=S6S%=72`]("1R96=S6S)=.PH@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H96UP='DH)')E=G-Y;5LD<F5G<ULR75TI
M*2`D<F5V<WEM6R1R96=S6S)=73UA<G)A>2@I.PH@("`@("`@("`@("`@("`@
M("`@("`@("`D<F5V<WEM6R1R96=S6S)=75M=(#T@)')E9W-;,5T["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=I;F9O)SH*("`@("`@
M("`@("`@("`@(&EF("AS=')N8VUP*"<]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3TG+"`D;&EN92P@,S`I("8F"B`@("`@("`@("`@("`@("`@("`@
M<W1R8VUP*"<M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM)RP@)&QI;F4I
M*2!["B`@("`@("`@("`@("`@("`@("`@)&%C8W5M6UT@/2`D;&EN93L*("`@
M("`@("`@("`@("`@('T@96QS96EF("AC;W5N="@D86-C=6TI*2!["B`@("`@
M("`@("`@("`@("`@("`@+R\@<W!A=VX@82!N97<@5D-?;&]G(&]B:F5C="!A
M;F0@861D(&ET('1O('1H92!L;V=S(&AA<V@*("`@("`@("`@("`@("`@("`@
M("`D;&]G(#T@;F5W(%9#7TQO9U]C=G,H)'1H:7,I.PH@("`@("`@("`@("`@
M("`@("`@("1E<G(@/2`D;&]G+3YP<F]C97-S3&]G*"1A8V-U;2D["B`@("`@
M("`@("`@("`@("`@("`@+R\@5$]$3SH@97)R;W(@8VAE8VMS("T@879S;0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V=S6R1L;V<M/G%U97)Y4F5V
M:7-I;VXH*5T@/2`D;&]G.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YR
M979S6UT@/2`D;&]G+3YQ=65R>5)E=FES:6]N*"D["B`@("`@("`@("`@("`@
M("`@("`@)&%C8W5M(#T@87)R87DH*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;B!T:&4@9G5L;'D@<75A;&EF:65D(&9I;&5N86UE(&]F('1H:7,@;V)J
M96-T+@H@("`@("H*("`@("`J($!R971U<FX@1G5L;'D@<75A;&EF:65D(&9I
M;&5N86UE(&]F('1H:7,@;V)J96-T"B`@("`@*B\*("`@(&9U;F-T:6]N('%U
M97)Y1G5L;%!A=&@H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^9&ER
M("X@)R\G("X@)'1H:7,M/FYA;64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FX@=&AE(&YA;64@;V8@=&AI<R!F:6QE(')E;&%T:79E('1O(&ET<R!S
M;W5R8V5R;V]T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!0871H
M;F%M92!R96QA=&EV92!T;R!T:&4@<V]U<F-E<F]O="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<75E<GE-;V1U;&50871H*"D*("`@('L*("`@("`@("!R971U
M<FX@<')E9U]R97!L86-E*"=\7B<N("1T:&ES+3YR97`M/G-O=7)C97)O;W0H
M*2`N("<O/R@N*BDL=B1\)RP@)UPQ)RP@)'1H:7,M/G%U97)Y1G5L;%!A=&@H
M*2D["B`@("!]"@I]"@HO*BH*("H@5D-?8W9S(&QO9R!C;&%S<RX*("H*("H@
M0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*
M("H@0'!A8VMA9V4@5D,*("HO"F-L87-S(%9#7TQO9U]C=G,@>PH*("`@('9A
M<B`D<F5P.PH@("`@=F%R("1F:6QE.PH@("`@=F%R("1T86=S.PH@("`@=F%R
M("1R978["B`@("!V87(@)&1A=&4["B`@("!V87(@)&QO9SL*("`@('9A<B`D
M875T:&]R.PH@("`@=F%R("1S=&%T93L*("`@('9A<B`D;&EN97,["B`@("!V
M87(@)&)R86YC:&5S.PH*("`@("\J*@H@("`@("H*("`@("`J+PH@("`@9G5N
M8W1I;VX@5D-?3&]G7V-V<R@D9FPI"B`@("!["B`@("`@("`@)'1H:7,M/F9I
M;&4@/2`D9FP["B`@("`@("`@)'1H:7,M/F)R86YC:&5S(#T@87)R87DH*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!P<F]C97-S3&]G*"1R87<I"B`@("!["B`@
M("`@("`@+RH@26YI=&EA;&ES92!A('-I;7!L92!S=&%T92!M86-H:6YE('1O
M('!A<G-E('1H92!O=71P=70@;V8@<FQO9R`J+PH@("`@("`@("1S=&%T92`]
M("=I;FET)SL*("`@("`@("!W:&EL92`H(65M<'1Y*"1R87<I("8F("1S=&%T
M92`A/2`G9&]N92<I('L*("`@("`@("`@("`@<W=I=&-H("@D<W1A=&4I('L*
M("`@("`@("`@("`@+RH@1F]U;F0@9FEL96YA;64L(&YO=R!L;V]K:6YG(&9O
M<B!T:&4@<F5V:7-I;VX@;G5M8F5R("HO"B`@("`@("`@("`@(&-A<V4@)VEN
M:70G.@H@("`@("`@("`@("`@("`@)&QI;F4@/2!A<G)A>5]S:&EF="@D<F%W
M*3L*("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"(O<F5V:7-I;VX@
M*"XK*20O(BP@)&QI;F4L("1P87)T<RDI('L*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^<F5V(#T@)'!A<G1S6S%=.PH@("`@("`@("`@("`@("`@("`@
M("1S=&%T92`]("=D871E)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@+RH@1F]U;F0@<F5V:7-I;VX@
M86YD(&9I;&5N86UE+"!N;W<@;&]O:VEN9R!F;W(@9&%T92`J+PH@("`@("`@
M("`@("!C87-E("=D871E)SH*("`@("`@("`@("`@("`@("1L:6YE(#T@87)R
M87E?<VAI9G0H)')A=RD["B`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C
M:"@B?%YD871E.EQS*RA<9"LI6RTO72A<9"LI6RTO72A<9"LI7',K*%QD*RDZ
M*%QD*RDZ*%QD*RDN*C\[7',K875T:&]R.EQS*R@N*RD[7',K<W1A=&4Z7',K
M*%Q3*RD[*%QS*VQI;F5S.EQS*RA;,"TY7',K+5TK*2D_?"(L("1L:6YE+"`D
M<&%R=',I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F1A=&4@/2!G
M;6UK=&EM92@D<&%R='-;-%TL("1P87)T<ULU72P@)'!A<G1S6S9=+"`D<&%R
M='-;,ETL("1P87)T<ULS72P@)'!A<G1S6S%=*3L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^875T:&]R(#T@)'!A<G1S6S==.PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YS=&%T92`]("1P87)T<ULX73L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^;&EN97,@/2!I<W-E="@D<&%R='-;,3!=*2`_("1P
M87)T<ULQ,%T@.B`G)SL*("`@("`@("`@("`@("`@("`@("`D<W1A=&4@/2`G
M8G)A;F-H97,G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("`O*B!,;V]K(&9O<B!A(&)R86YC:"!P;VEN
M="!H97)E("T@9F]R;6%T(&ES("=B<F%N8VAE<SH@('@N>2YZ.R`@82YB+F,[
M)R`J+PH@("`@("`@("`@("!C87-E("=B<F%N8VAE<R<Z"B`@("`@("`@("`@
M("`@("`O*B!)9B!W92!F:6YD(&$@8G)A;F-H('1A9RP@<')O8V5S<R!A;F0@
M<&]P(&ET+`H@("`@("`@("`@("`@("`@("`@;W1H97)W:7-E(&QE879E(&EN
M<'5T('-T<F5A;2!U;G1O=6-H960@*B\*("`@("`@("`@("`@("`@(&EF("@A
M96UP='DH)')A=RD@)B8@<')E9U]M871C:"@B+UYB<F%N8VAE<SI<<RLH+BHI
M+R(L("1R87=;,%TL("1B<BDI('L*("`@("`@("`@("`@("`@("`@("`O*B!'
M970@=&AE(&QI<W0@;V8@8G)A;F-H97,@9G)O;2!T:&4@<W1R:6YG+"!A;F0*
M("`@("`@("`@("`@("`@("`@("`@*B!P=7-H('9A;&ED(')E=FES:6]N<R!I
M;G1O('1H92!B<F%N8VAE<R!A<G)A>2`J+PH@("`@("`@("`@("`@("`@("`@
M("1B<G,@/2!P<F5G7W-P;&ET*"<O.UQS*B\G+"`D8G);,5TI.PH@("`@("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1B<G,@87,@)&)R<&]I;G0I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*%9#7U)E=FES:6]N.CIV86QI9"@D
M8G)P;VEN="DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YB<F%N8VAE<UM=(#T@)&)R<&]I;G0["B`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@87)R87E?<VAI9G0H)')A=RD["@H@("`@("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@("`@("1S=&%T92`]("=D;VYE)SL*("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!!
M<W-U;64@=&AE(')E<W0@;V8@=&AE(&QI;F5S(&%R92!T:&4@;&]G(&UE<W-A
M9V4@*B\*("`@("`@("`D=&AI<RT^;&]G(#T@:6UP;&]D92@B7&XB+"`D<F%W
M*3L*("`@("`@("`D=&AI<RT^=&%G<R`]($`D=&AI<RT^9FEL92T^<F5V<WEM
M6R1T:&ES+3YR979=.PH@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^=&%G<RDI
M('L*("`@("`@("`@("`@)'1H:7,M/G1A9W,@/2!A<G)A>2@I.PH@("`@("`@
M('T*("`@('T*"B`@("!F=6YC=&EO;B!Q=65R>41A=&4H*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^9&%T93L*("`@('T*"B`@("!F=6YC=&EO;B!Q
M=65R>5)E=FES:6]N*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G)E
M=CL*("`@('T*"B`@("!F=6YC=&EO;B!Q=65R>4%U=&AO<B@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3YA=71H;W(["B`@("!]"@H@("`@9G5N8W1I
M;VX@<75E<GE,;V<H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^;&]G
M.PH@("`@?0H*("`@(&9U;F-T:6]N('%U97)Y0VAA;F=E9$QI;F5S*"D*("`@
M('L*("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/FQI;F5S*2`_("@D=&AI
M<RT^;&EN97,I(#H@)R<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!':79E;B!A
M(&)R86YC:"!R979I<VEO;B!N=6UB97(L('1H:7,@9G5N8W1I;VX@<F5M87!S
M(&ET"B`@("`@*B!A8V-O<F1I;F=L>2P@86YD('!E<F9O<FUS(&$@;&]O:W5P
M(&]N('1H92!F:6QE(&]B:F5C="!T;PH@("`@("H@<F5T=7)N('1H92!S>6UB
M;VQI8R!N86UE*',I(&]F('1H870@8G)A;F-H(&EN('1H92!T<F5E+@H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@($AA<V@@;V8@<WEM8F]L:6,@;F%M
M97,@/3X@8G)A;F-H(&YU;6)E<G,*("`@("`J+PH@("`@9G5N8W1I;VX@<75E
M<GE3>6UB;VQI8T)R86YC:&5S*"D*("`@('L*("`@("`@("`D<WEM0G)A;F-H
M97,@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YB<F%N8VAE
M<R!A<R`D8G)A;F-H*2!["B`@("`@("`@("`@("1P87)T<R`](&5X<&QO9&4H
M)RXG+"`D8G)A;F-H*3L*("`@("`@("`@("`@)&QA<W0@/2!A<G)A>5]P;W`H
M)'!A<G1S*3L*("`@("`@("`@("`@)'!A<G1S6UT@/2`G,"<["B`@("`@("`@
M("`@("1P87)T<UM=(#T@)&QA<W0["B`@("`@("`@("`@("1R978@/2!I;7!L
M;V1E*"<N)RP@)'!A<G1S*3L*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3YF:6QE+3YB<F%N8VAE<ULD8G)A;F-H72DI('L*("`@("`@("`@("`@("`@
M("1S>6U"<F%N8VAE<ULD=&AI<RT^9FEL92T^8G)A;F-H97-;)&)R86YC:%U=
M(#T@)&)R86YC:#L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R
M971U<FX@)'-Y;4)R86YC:&5S.PH@("`@?0H*?0H*+RHJ"B`J(%9#7V-V<R!0
M871C:'-E="!C;&%S<RX*("H*("H@0V]P>7)I9VAT($%N:6P@36%D:&%V87!E
M9&1Y+"`\86YI;$!R96-O:6PN;W)G/@H@*@H@*B!`875T:&]R("!!;FEL($UA
M9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`<&%C:V%G92!60PH@
M*B\*8VQA<W,@5D-?4&%T8VAS971?8W9S(&5X=&5N9',@5D-?4&%T8VAS970@
M>PH*("`@('9A<B`D7V1I<CL*("`@('9A<B`D7VYA;64["@H@("`@+RHJ"B`@
M("`@*B!#<F5A=&4@82!P871C:'-E="!O8FIE8W0N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D9FEL92`@5&AE(&9I;&5N86UE('1O(&=E="!P871C
M:'-E=',@9F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!60U]0871C:'-E=%]C
M=G,H)&9I;&4I"B`@("!["B`@("`@("`@)'1H:7,M/E]N86UE(#T@8F%S96YA
M;64H)&9I;&4I.PH@("`@("`@("1T:&ES+3Y?9&ER(#T@9&ER;F%M92@D9FEL
M92D["B`@("!]"@H@("`@9G5N8W1I;VX@)F=E=%!A=&-H<V5T3V)J96-T*"1R
M97`L("1F:6QE;F%M92P@)&-A8VAE(#T@;G5L;"D*("`@('L*("`@("`@("`O
M*B!4:&4@=F5R<VEO;B!O9B!T:&4@8V%C:&5D(&1A=&$N($EN8W)E;65N="!T
M:&ES('=H96YE=F5R('1H90H@("`@("`@("`J(&EN=&5R;F%L('-T;W)A9V4@
M9F]R;6%T(&-H86YG97,L('-U8V@@=&AA="!W92!M=7-T"B`@("`@("`@("H@
M:6YV86QI9&%T92!P<FEO<B!C86-H960@9&%T82X@*B\*("`@("`@("`D8V%C
M:&5697)S:6]N(#T@,3L*("`@("`@("`D8V%C:&5)9"`]("1R97`M/G-O=7)C
M97)O;W0H*2`N("=?;B<@+B`D9FEL96YA;64@+B`G7V9?=B<@+B`D8V%C:&56
M97)S:6]N.PH*("`@("`@("`D8W1I;64@/2!T:6UE*"D@+2!`9FEL96UT:6UE
M*"1F:6QE;F%M92`N("<L=B<I.PH@("`@("`@(&EF("@D8V%C:&4@)B8*("`@
M("`@("`@("`@)&-A8VAE+3YE>&ES=',H)&-A8VAE260L("1C=&EM92DI('L*
M("`@("`@("`@("`@)'!S3V(@/2!U;G-E<FEA;&EZ92@D8V%C:&4M/F=E="@D
M8V%C:&5)9"P@)&-T:6UE*2D["B`@("`@("`@("`@("1P<T]B+3YS971297!O
M<VET;W)Y*"1R97`I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P
M<T]B(#T@;F5W(%9#7U!A=&-H<V5T7V-V<R@D9FEL96YA;64I.PH@("`@("`@
M("`@("`D<'-/8BT^<V5T4F5P;W-I=&]R>2@D<F5P*3L*("`@("`@("`@("`@
M:68@*&ES7V$H*"1R97-U;'0@/2`D<'-/8BT^9V5T4&%T8VAS971S*"DI+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1C86-H92D@>PH@
M("`@("`@("`@("`@("`@)&-A8VAE+3YS970H)&-A8VAE260L('-E<FEA;&EZ
M92@D<'-/8BDI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)'!S3V(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!0;W!U;&%T92!T
M:&4@;V)J96-T('=I=&@@:6YF;W)M871I;VX@86)O=70@=&AE('!A=&-H<V5T
M<R!T:&%T"B`@("`@*B!T:&ES(&9I;&4@:7,@:6YV;VQV960@:6XN"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N?&]B:F5C="`@4$5!4E]%<G)O<B!O
M8FIE8W0@;VX@97)R;W(L(&]R('1R=64@;VX@<W5C8V5S<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T4&%T8VAS971S*"D*("`@('L*("`@("`@("`O*B!#
M:&5C:R!T:&%T('=E(&%R92!A8W1U86QL>2!I;B!T:&4@9FEL97-Y<W1E;2X@
M*B\*("`@("`@("!I9B`H(6ES7V9I;&4H)'1H:7,M/F=E=$9U;&Q0871H*"D@
M+B`G+'8G*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@G1FEL92!.;W0@1F]U;F0G*3L*("`@("`@("!]"@H@("`@("`@("\J($-A
M;&P@8W9S<',@=&\@<F5T<FEE=F4@86QL('!A=&-H<V5T<R!F;W(@=&AI<R!F
M:6QE+B`J+PH@("`@("`@("1Q7W)O;W0@/2`D=&AI<RT^7W)E<"T^<V]U<F-E
M<F]O="@I.PH@("`@("`@("1Q7W)O;W0@/2!60U]724Y$3U=3(#\@)R(G("X@
M97-C87!E<VAE;&QC;60H)'%?<F]O="D@+B`G(B<@.B!E<V-A<&5S:&5L;&%R
M9R@D<5]R;V]T*3L*"B`@("`@("`@)&-V<W!S7VAO;64@/2`D=&AI<RT^7W)E
M<"T^9V5T4&%T:"@G8W9S<'-?:&]M92<I.PH@("`@("`@("1(3TU%(#T@(65M
M<'1Y*"1C=G-P<U]H;VUE*2`_"B`@("`@("`@("`@("=(3TU%/2<@+B`D8W9S
M<'-?:&]M92`N("<@)R`Z"B`@("`@("`@("`@("<G.PH*("`@("`@("`D8VUD
M(#T@)$A/344@+B`D=&AI<RT^7W)E<"T^9V5T4&%T:"@G8W9S<',G*2`N("<@
M+74@+2UC=G,M9&ER96-T("TM<F]O="`G("X@)'%?<F]O="`N("<@+68@)R`N
M(&5S8V%P97-H96QL87)G*"1T:&ES+3Y?;F%M92D@+B`G("<@+B!E<V-A<&5S
M:&5L;&%R9R@D=&AI<RT^7V1I<BD["B`@("`@("`@97AE8R@D8VUD+"`D<F5T
M=7)N7V%R<F%Y+"`D<F5T=F%L*3L*("`@("`@("!I9B`H)')E='9A;"D@>PH@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G1F%I;&5D('1O
M('-P87=N(&-V<W!S('1O(')E=')I979E('!A=&-H<V5T(&EN9F]R;6%T:6]N
M)RD["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7W!A=&-H<V5T<R`](&%R
M<F%Y*"D["B`@("`@("`@)'-T871E(#T@)V)E9VEN)SL*("`@("`@("!F;W)E
M86-H("@D<F5T=7)N7V%R<F%Y(&%S("1L:6YE*2!["B`@("`@("`@("`@("1L
M:6YE(#T@=')I;2@D;&EN92D["B`@("`@("`@("`@(&EF("@D;&EN92`]/2`G
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM)RD@>PH@("`@("`@("`@("`@("`@)'-T
M871E(#T@)V)E9VEN)SL*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!S=VET8V@@*"1S=&%T92D@>PH@("`@
M("`@("`@("!C87-E("=B96=I;B<Z"B`@("`@("`@("`@("`@("`D:60@/2!S
M=')?<F5P;&%C92@G4&%T8VA3970@)RP@)R<L("1L:6YE*3L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%T8VAS971S6R1I9%T@/2!A<G)A>2@I.PH@("`@
M("`@("`@("`@("`@)'-T871E(#T@)VEN9F\G.PH@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("!C87-E("=I;F9O)SH*("`@("`@("`@("`@
M("`@("1I;F9O(#T@97AP;&]D92@G.B<L("1L:6YE+"`R*3L*("`@("`@("`@
M("`@("`@('-W:71C:"`H)&EN9F];,%TI('L*("`@("`@("`@("`@("`@(&-A
M<V4@)T1A=&4G.@H@("`@("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H
M*"=\*%QD>S1]*2\H7&1[,GTI+RA<9'LR?2D@*%QD>S)]*3HH7&1[,GTI.BA<
M9'LR?2E\)RP@)&EN9F];,5TL("1D871E*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A=&-H<V5T<ULD:61=6R=D871E)UT@/2!G;6UK
M=&EM92@D9&%T95LT72P@)&1A=&5;-5TL("1D871E6S9=+"`D9&%T95LR72P@
M)&1A=&5;,UTL("1D871E6S%=*3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S
M92`G075T:&]R)SH*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A=&-H
M<V5T<ULD:61=6R=A=71H;W(G72`]('1R:6TH)&EN9F];,5TI.PH@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)T)R
M86YC:"<Z"B`@("`@("`@("`@("`@("`@("`@:68@*'1R:6TH)&EN9F];,5TI
M("$]("=(14%$)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A=&-H<V5T<ULD:61=6R=B<F%N8V@G72`]('1R:6TH)&EN9F];,5TI.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@("`@("!C87-E("=486<G.@H@("`@("`@("`@("`@
M("`@("`@(&EF("AT<FEM*"1I;F9O6S%=*2`A/2`G*&YO;F4I)RD@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A=&-H<V5T<ULD:61=6R=T
M86<G72`]('1R:6TH)&EN9F];,5TI.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C
M87-E("=,;V<G.@H@("`@("`@("`@("`@("`@("`@("1S=&%T92`]("=L;V<G
M.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%T8VAS971S6R1I9%U;
M)VQO9R==(#T@)R<["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&-A<V4@)VQO9R<Z"B`@("`@("`@("`@("`@("!I9B`H)&QI;F4@/3T@
M)TUE;6)E<G,Z)RD@>PH@("`@("`@("`@("`@("`@("`@("1S=&%T92`]("=M
M96UB97)S)SL*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A=&-H<V5T
M<ULD:61=6R=L;V<G72`]('1R:6TH)'1H:7,M/E]P871C:'-E='-;)&ED75LG
M;&]G)UTI.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%T8VAS971S
M6R1I9%U;)VUE;6)E<G,G72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%T8VAS971S
M6R1I9%U;)VQO9R==("X]("1L:6YE("X@(EQN(CL*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G
M;65M8F5R<R<Z"B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1L:6YE*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1P87)T<R`](&5X<&QO9&4H)SHG+"`D
M;&EN92D["B`@("`@("`@("`@("`@("`@("`@)')E=G,@/2!E>'!L;V1E*"<M
M/B<L("1P87)T<ULQ72D["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M871C:'-E='-;)&ED75LG;65M8F5R<R==6UT@/2!A<G)A>2@G9FEL92<@/3X@
M)'!A<G1S6S!=+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V9R;VTG(#T^("1R979S
M6S!=+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W1O)R`]/B`D<F5V<ULQ72D["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&9U;&QY('%U86QI9FEE9"!F
M:6QE;F%M92!O9B!T:&ES(&]B:F5C="X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@1G5L;'D@<75A;&EF:65D(&9I;&5N86UE(&]F('1H:7,@;V)J
M96-T"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$9U;&Q0871H*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]D:7(@+B`G+R<@+B`D=&AI<RT^7VYA
M;64["B`@("!]"@I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]60R]S=FXN<&AP````````````
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`V,#4S-R`Q,#4Q-30S
M,S<S-R`P,C$R,30`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J(%9#7W-V;B!I;7!L96UE;G1A=&EO;BX*
M("H*("H@0V]P>7)I9VAT(#(P,#`M,C`P-B!!;FEL($UA9&AA=F%P961D>2P@
M/&%N:6Q`<F5C;VEL+F]R9SX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5D,O
M5D,O<W9N+G!H<"QV(#$N,C@N-"XQ."`R,#`V+S`U+S$R(#`T.C0W.C`X(&-H
M=6-K($5X<"`D"B`J"B`J($!A=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA
M;FEL0')E8V]I;"YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C
M:V%G92!60PH@*B\*8VQA<W,@5D-?<W9N(&5X=&5N9',@5D,@>PH*("`@("\J
M*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1P87)A;7,@($%N>2!P87)A;65T97(@=&AE(&-L87-S(&5X<&5C=',N
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@0W5R<F5N="!P87)A;65T
M97)S.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("=S;W5R8V5R;V]T
M)SH@5&AE('-O=7)C92!R;V]T(&9O<B!T:&ES"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!R97!O<VET;W)Y"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@)W!A=&AS)SH@2&%S:"!W:71H('1H92!L
M;V-A=&EO;G,@;V8@86QL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@;F5C97-S87)Y(&)I;F%R:65S.B`G<W9N)RP@)V1I9F8G"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%9#7W-V;B@D<&%R86US*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?<V]U<F-E<F]O="`]("1P87)A;7-;)W-O=7)C97)O;W0G
M73L*("`@("`@("`D=&AI<RT^7W!A=&AS(#T@)'!A<F%M<ULG<&%T:',G73L*
M("`@('T*"B`@("!F=6YC=&EO;B!I<T9I;&4H)'=H97)E*0H@("`@>PH@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N("9Q=65R>41I
M<B@D=VAE<F4I"B`@("!["B`@("`@("`@)&1I<B`](&YE=R!60U]$:7)E8W1O
M<GE?<W9N*"1T:&ES+"`D=VAE<F4I.PH@("`@("`@(')E='5R;B`D9&ER.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&=E=$-H96-K;W5T*"1F:6QE+"`D<F5V*0H@
M("`@>PH@("`@("`@(')E='5R;B!60U]#:&5C:V]U=%]S=FXZ.F=E="@D=&AI
M<RP@)&9I;&4M/G%U97)Y1G5L;%!A=&@H*2P@)')E=BD["B`@("!]"@H@("`@
M9G5N8W1I;VX@9V5T1&EF9B@D9FEL92P@)')E=C$L("1R978R+"`D='EP92`]
M("=C;VYT97AT)RP@)&YU;2`](#,L("1W<R`]('1R=64I"B`@("!["B`@("`@
M("`@<F5T=7)N(%9#7T1I9F9?<W9N.CIG970H)'1H:7,L("1F:6QE+"`D<F5V
M,2P@)')E=C(L("1T>7!E+"`D;G5M+"`D=W,I.PH@("`@?0H*("`@(&9U;F-T
M:6]N("9G971&:6QE3V)J96-T*"1F:6QE;F%M92P@)&-A8VAE(#T@;G5L;"P@
M)'%U:6-K;&]G(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&9O(#T@)E9#7T9I
M;&5?<W9N.CIG971&:6QE3V)J96-T*"1T:&ES+"`D9FEL96YA;64L("1C86-H
M92P@)'%U:6-K;&]G*3L*("`@("`@("!R971U<FX@)&9O.PH@("`@?0H*("`@
M(&9U;F-T:6]N("9G971!;FYO=&%T94]B:F5C="@D9FEL96YA;64I"B`@("![
M"B`@("`@("`@)&)L86UE(#T@;F5W(%9#7T%N;F]T871E7W-V;B@D=&AI<RP@
M)&9I;&5N86UE*3L*("`@("`@("!R971U<FX@)&)L86UE.PH@("`@?0H*("`@
M(&9U;F-T:6]N("9G9710871C:'-E=$]B:F5C="@D9FEL96YA;64L("1C86-H
M92`](&YU;&PI"B`@("!["B`@("`@("`@)'!O(#T@)E9#7U!A=&-H<V5T7W-V
M;CHZ9V5T4&%T8VAS971/8FIE8W0H)'1H:7,L("1F:6QE;F%M92P@)&-A8VAE
M*3L*("`@("`@("!R971U<FX@)'!O.PH@("`@?0H*?0H*+RHJ"B`J(%9#7W-V
M;B!A;FYO=&%T92!C;&%S<RX*("H*("H@06YI;"!-861H879A<&5D9'DL(#QA
M;FEL0')E8V]I;"YO<F<^"B`J"B`J($!A=71H;W(@($%N:6P@36%D:&%V87!E
M9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J($!P86-K86=E(%9#"B`J+PIC;&%S
M<R!60U]!;FYO=&%T95]S=FX@>PH*("`@('9A<B`D9FEL93L*("`@('9A<B`D
M4U9..PH@("`@=F%R("1T;7!F:6QE.PH*("`@(&9U;F-T:6]N(%9#7T%N;F]T
M871E7W-V;B@D<F5P+"`D9FEL92D*("`@('L*("`@("`@("`D=&AI<RT^4U9.
M(#T@)')E<#L*("`@("`@("`D=&AI<RT^9FEL92`]("1F:6QE.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&1O06YN;W1A=&4H)')E=BD*("`@('L*("`@("`@("`O
M*B!-86ME('-U<F4@=&AA="!T:&4@9FEL92!V86QU97,@9F]R('1H:7,@;V)J
M96-T(&ES('9A;&ED+B`J+PH@("`@("`@(&EF("AI<U]A*"1T:&ES+3YF:6QE
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!]"@H@("`@("`@(&EF("@A5D-?4F5V:7-I;VXZ.G9A;&ED*"1R
M978I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@
M("`@("`@("11(#T@5D-?5TE.1$]74R`_("<B)R`Z("(G(CL*("`@("`@("`D
M8V]M;6%N9"`]("1T:&ES+3Y35DXM/F=E=%!A=&@H)W-V;B<I("X@)R!A;FYO
M=&%T92`M<B`Q.B<@+B`D<F5V("X@)R`G("X@)%$@+B!S=')?<F5P;&%C92@D
M42P@)UQ<)R`N("11+"`D=&AI<RT^9FEL92T^<75E<GE&=6QL4&%T:"@I*2`N
M("11("X@)R`R/B8Q)SL*("`@("`@("`D<&EP92`]('!O<&5N*"1C;VUM86YD
M+"`G<B<I.PH@("`@("`@(&EF("@A)'!I<&4I('L*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H)T9A:6QE9"!T;R!E>&5C=71E('-V;B!A
M;FYO=&%T93H@)R`N("1C;VUM86YD*3L*("`@("`@("!]"@H@("`@("`@("1L
M:6YE<R`](&%R<F%Y*"D["B`@("`@("`@)&QI;F5N;R`](#$["B`@("`@("`@
M=VAI;&4@*"%F96]F*"1P:7!E*2D@>PH@("`@("`@("`@("`D;&EN92`](&9G
M971S*"1P:7!E+"`T,#DV*3L*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H
M)R]>7',K*%QD*RE<<RLH6UQW7"Y=*RE<<R@N*BDD+R<L("1L:6YE+"`D<F5G
M<RDI('L*("`@("`@("`@("`@("`@("1E;G1R>2`](&%R<F%Y*"D["B`@("`@
M("`@("`@("`@("`D96YT<GE;)W)E=B==("`@(#T@)')E9W-;,5T["B`@("`@
M("`@("`@("`@("`D96YT<GE;)V%U=&AO<B==(#T@=')I;2@D<F5G<ULR72D[
M"B`@("`@("`@("`@("`@("`D96YT<GE;)V1A=&4G72`@(#T@)R<["B`@("`@
M("`@("`@("`@("`D96YT<GE;)VQI;F4G72`@(#T@)')E9W-;,UT["B`@("`@
M("`@("`@("`@("`D96YT<GE;)VQI;F5N;R==(#T@)&QI;F5N;RLK.PH@("`@
M("`@("`@("`@("`@)&QI;F5S6UT@/2`D96YT<GD["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@('!C;&]S92@D<&EP92D["B`@("`@("`@<F5T
M=7)N("1L:6YE<SL*("`@('T*"GT*"B\J*@H@*B!60U]S=FX@8VAE8VMO=70@
M8VQA<W,N"B`J"B`J($%N:6P@36%D:&%V87!E9&1Y+"`\86YI;$!R96-O:6PN
M;W)G/@H@*@H@*B!`875T:&]R("!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R
M96-O:6PN;W)G/@H@*B!`<&%C:V%G92!60PH@*B\*8VQA<W,@5D-?0VAE8VMO
M=71?<W9N('L*"B`@("`O*BH*("`@("`J(%-T871I8R!F=6YC=&EO;B!W:&EC
M:"!R971U<FYS(&$@9FEL92!P;VEN=&EN9R!T;R!T:&4@:&5A9"!O9B!T:&4@
M<F5Q=65S=&5D"B`@("`@*B!R979I<VEO;B!O9B!A;B!20U,@9FEL92X*("`@
M("`J($!P87)A;2!F=6QL;F%M92!&=6QL>2!Q=6%L:69I960@<&%T:&YA;64@
M;V8@=&AE(&1E<VER960@4D-3(&9I;&4@=&\@8VAE8VMO=70*("`@("`J($!P
M87)A;2!R978@4D-3(')E=FES:6]N(&YU;6)E<B!T;R!C:&5C:R!O=70*("`@
M("`J($!R971U<FX@16ET:&5R(&$@4$5!4E]%<G)O<B!O8FIE8W0L(&]R(&$@
M<W1R96%M('!O:6YT97(@=&\@=&AE(&AE860@;V8@=&AE(&-H96-K;W5T"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E="@D<F5P+"`D9G5L;&YA;64L("1R978I
M"B`@("!["B`@("`@("`@:68@*"%60U]2979I<VEO;CHZ=F%L:60H)')E=BDI
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TEN=F%L
M:60@<F5V:7-I;VX@;G5M8F5R)RD["B`@("`@("`@?0H*("`@("`@("!I9B`H
M5D-?5TE.1$]74RD@>PH@("`@("`@("`@("`D42`]("<B)SL*("`@("`@("`@
M("`@)&UO9&4@/2`G<F(G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("11(#T@(B<B.PH@("`@("`@("`@("`D;6]D92`]("=R)SL*("`@("`@("!]
M"@H@("`@("`@(&EF("@A*"120U,@/2!P;W!E;B@D<F5P+3YG9710871H*"=S
M=FXG*2`N("<@8V%T("UR("<@+B`D<F5V("X@)R`G("X@)%$@+B!S=')?<F5P
M;&%C92@D42P@)UQ<)R`N("11+"`D9G5L;&YA;64I("X@)%$@+B`G(#(^)C$G
M+"`D;6]D92DI*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*"=#;W5L9&Y<)W0@<&5R9F]R;2!C:&5C:V]U="!O9B!T:&4@<F5Q=65S
M=&5D(&9I;&4G*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D4D-3.PH@
M("`@?0H*?0H*+RHJ"B`J(%9#7W-V;B!D:69F(&-L87-S+@H@*@H@*B!#;W!Y
M<FEG:'0@06YI;"!-861H879A<&5D9'DL(#QA;FEL0')E8V]I;"YO<F<^"B`J
M"B`J($!A=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO
M<F<^"B`J($!P86-K86=E(%9#"B`J+PIC;&%S<R!60U]$:69F7W-V;B!["@H@
M("`@+RHJ"B`@("`@*B!/8G1A:6X@=&AE(&1I9F9E<F5N8V5S(&)E='=E96X@
M='=O(')E=FES:6]N<R!O9B!A(&9I;&4N"B`@("`@*@H@("`@("H@0'!A<F%M
M(%9#7W-V;B`D<F5P("`@("`@("!!(')E<&]S:71O<GD@;V)J96-T+@H@("`@
M("H@0'!A<F%M(%9#7T9I;&5?<W9N("1F:6QE("!4:&4@9&5S:7)E9"!F:6QE
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<F5V,2`@("`@("!/<FEG:6YA;"!R
M979I<VEO;B!N=6UB97(@=&\@8V]M<&%R92!F<F]M+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<F5V,B`@("`@("!.97<@<F5V:7-I;VX@;G5M8F5R('1O(&-O
M;7!A<F4@86=A:6YS="X*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@("`@
M("`@5&AE('1Y<&4@;V8@9&EF9B`H92YG+B`G=6YI9FEE9"<I+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&YU;2`@("`@("!.=6UB97(@;V8@;&EN97,@=&\@
M8F4@=7-E9"!I;B!C;VYT97AT(&%N9`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("!U;FEF:65D(&1I9F9S+@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)'=S("`@("`@("!3:&]W('=H:71E<W!A8V4@:6X@=&AE(&1I9F8_"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F=\8F]O;&5A;B`@1F%L<V4@;VX@
M9F%I;'5R92P@;W(@82!S=')I;F<@8V]N=&%I;FEN9R!T:&4*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@(&1I9F8@;VX@<W5C8V5S<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T*"1R97`L("1F:6QE+"`D<F5V,2P@)')E=C(L
M("1T>7!E(#T@)V-O;G1E>'0G+"`D;G5M(#T@,RP*("`@("`@("`@("`@("`@
M("`D=W,@/2!T<G5E*0H@("`@>PH@("`@("`@("\J($UA:V4@<W5R92!T:&%T
M('1H92!F:6QE('!A<F%M971E<B!I<R!V86QI9"`J+PH@("`@("`@(&EF("AI
M<U]A*"1F:6QE+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("\J($-H96-K('1H870@=&AE
M(')E=FES:6]N(&YU;6)E<G,@87)E('9A;&ED("HO"B`@("`@("`@)')E=C$@
M/2!60U]2979I<VEO;CHZ=F%L:60H)')E=C$I(#\@)')E=C$@.B`P.PH@("`@
M("`@("1R978R(#T@5D-?4F5V:7-I;VXZ.G9A;&ED*"1R978Q*2`_("1R978R
M(#H@,#L*"B`@("`@("`@)&9U;&Q.86UE(#T@)&9I;&4M/G%U97)Y1G5L;%!A
M=&@H*3L*("`@("`@("`D9&EF9B`](&%R<F%Y*"D["B`@("`@("`@)&]P=&EO
M;G,@/2`G)SL*("`@("`@("!I9B`H(21W<RD@>PH@("`@("`@("`@("`D;W!T
M:6]N<R`N/2`G("UB0B`G.PH@("`@("`@('T*"B`@("`@("`@<W=I=&-H("@D
M='EP92D@>PH@("`@("`@(&-A<V4@)V-O;G1E>'0G.@H@("`@("`@("`@("`D
M;W!T:6]N<R`N/2`G+2UC;VYT97AT/2<@+B`H:6YT*21N=6T["B`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("!C87-E("=U;FEF:65D)SH*("`@("`@("`@
M("`@)&]P=&EO;G,@+CT@)RTM=6YI9FEE9#TG("X@*&EN="DD;G5M.PH@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G8V]L=6UN)SH*("`@("`@
M("`@("`@)&]P=&EO;G,@+CT@)RTM<VED92UB>2US:61E("TM=VED=&@],3(P
M)SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)V5D)SH*("`@
M("`@("`@("`@)&]P=&EO;G,@+CT@)RUE)SL*("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@?0H*("`@("`@("`O+R!43T1/.B!A9&0@;W!T:6]N<R!F;W(@
M)&AR(&]P=&EO;G,@+2!H;W=E=F5R('1H97-E(&UA>2!N;W0*("`@("`@("`O
M+R!B92!C;VUP871I8FQE('=I=&@@<V]M92!D:69F<RX*("`@("`@("`D42`]
M(%9#7U=)3D1/5U,@/R`G(B<@.B`B)R(["B`@("`@("`@)&-O;6UA;F0@/2`D
M<F5P+3YG9710871H*"=S=FXG*2`N("(@9&EF9B`M+61I9F8M8VUD("(@+B`D
M<F5P+3YG9710871H*"=D:69F)RD@+B`B("UR("1R978Q.B1R978R("UX("(@
M+B`D42`N("1O<'1I;VYS("X@)%$@+B`G("<@+B`D9FEL92T^<75E<GE&=6QL
M4&%T:"@I("X@)R`R/B8Q)SL*"B`@("`@("`@97AE8R@D8V]M;6%N9"P@)&1I
M9F8L("1R971V86PI.PH@("`@("`@(')E='5R;B`D9&EF9CL*("`@('T*"GT*
M"B\J*@H@*B!60U]S=FX@9&ER96-T;W)Y(&-L87-S+@H@*@H@*B!#;W!Y<FEG
M:'0@06YI;"!-861H879A<&5D9'DL(#QA;FEL0')E8V]I;"YO<F<^"B`J"B`J
M($!A=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^
M"B`J($!P86-K86=E(%9#"B`J+PIC;&%S<R!60U]$:7)E8W1O<GE?<W9N('L*
M"B`@("!V87(@)')E<#L*("`@('9A<B`D9&ER3F%M93L*("`@('9A<B`D9FEL
M97,["B`@("!V87(@)&%T=&EC1FEL97,["B`@("!V87(@)&UE<F=E9$9I;&5S
M.PH@("`@=F%R("1D:7)S.PH@("`@=F%R("1P87)E;G0["B`@("!V87(@)&UO
M9'5L94YA;64["@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@82!35DX@1&ER96-T
M;W)Y(&]B:F5C="!T;R!S=&]R92!I;F9O<FUA=&EO;B!A8F]U="!T:&4*("`@
M("`J(&9I;&5S(&EN(&$@<VEN9VQE(&1I<F5C=&]R>2!I;B!T:&4@<F5P;W-I
M=&]R>0H@("`@("H*("`@("`J($!P87)A;2!60U]297!O<VET;W)Y7W-V;B`D
M<G`@(%1H92!60U]297!O<VET;W)Y(&]B:F5C="!T:&ES(&1I<F5C=&]R>0H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:7,@<&%R="!O
M9BX*("`@("`J($!P87)A;2!S=')I;F<@)&1N("`@("`@("`@("`@(%!A=&@@
M=&\@=&AE(&1I<F5C=&]R>2X*("`@("`J($!P87)A;2!60U]$:7)E8W1O<GE?
M<W9N("1P;B`@(%1H92!P87)E;G0@5D-?1&ER96-T;W)Y('1O('1H:7,@;VYE
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!60U]$:7)E8W1O<GE?<W9N*"1R97`L
M("1D;BP@)'!N(#T@)R<I"B`@("!["B`@("`@("`@)'1H:7,M/G)E<"`]("1R
M97`["B`@("`@("`@)'1H:7,M/G!A<F5N="`]("1P;CL*("`@("`@("`D=&AI
M<RT^;6]D=6QE3F%M92`]("1D;CL*("`@("`@("`D=&AI<RT^9&ER3F%M92`]
M("(O)&1N(CL*("`@("`@("`D=&AI<RT^9FEL97,@/2!A<G)A>2@I.PH@("`@
M("`@("1T:&ES+3YD:7)S(#T@87)R87DH*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;B!F=6QL>2!Q=6%L:69I960@<&%T:&YA;64@=&\@=&AI<R!D
M:7)E8W1O<GD@=VET:"!N;PH@("`@("H@=')A:6QI;F<@+RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(%!A=&AN86UE(&]F('1H:7,@9&ER96-T;W)Y"B`@("`@
M*B\*("`@(&9U;F-T:6]N('%U97)Y1&ER*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/F1I<DYA;64["B`@("!]"@H@("`@9G5N8W1I;VX@)G%U97)Y
M1&ER3&ES="@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YD:7)S.PH@
M("`@?0H*("`@(&9U;F-T:6]N("9Q=65R>49I;&5,:7-T*"1S:&]W871T:6,@
M/2!F86QS92D*("`@('L*("`@("`@("!I9B`H)'-H;W=A='1I8R`F)B!I<W-E
M="@D=&AI<RT^;65R9V5D1FEL97,I*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^;65R9V5D1FEL97,["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YF:6QE<SL*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!496QL('1H92!O8FIE8W0@=&\@;W!E;B!A;F0@8G)O=W-E
M(&ET<R!C=7)R96YT(&1I<F5C=&]R>2P@86YD"B`@("`@*B!R971R:65V92!A
M(&QI<W0@;V8@86QL('1H92!O8FIE8W1S(&EN('1H97)E+B`@270@=&AE;B!P
M;W!U;&%T97,*("`@("`J('1H92!F:6QE+V1I<F5C=&]R>2!S=&%C:R!A;F0@
M;6%K97,@:70@879A:6QA8FQE(&9O<B!R971R:65V86PN"B`@("`@*@H@("`@
M("H@0')E='5R;B!014%27T5R<F]R(&]B:F5C="!O;B!A;B!E<G)O<BP@,2!O
M;B!S=6-C97-S+@H@("`@("HO"B`@("!F=6YC=&EO;B!B<F]W<V5$:7(H)&-A
M8VAE(#T@;G5L;"P@)'%U:6-K;&]G(#T@=')U92P@)'-H;W=A='1I8R`](&9A
M;'-E*0H@("`@>PH@("`@("`@("11(#T@5D-?5TE.1$]74R`_("<B)R`Z("(G
M(B`["B`@("`@("`@)&-M9"`]("1T:&ES+3YR97`M/F=E=%!A=&@H)W-V;B<I
M("X@)R!L<R`G("X@)%$@+B!S=')?<F5P;&%C92@D42P@)UQ<)R`N("11+"`D
M=&AI<RT^<F5P+3YS;W5R8V5R;V]T*"D@+B`D=&AI<RT^<75E<GE$:7(H*2D@
M+B`D42`N("<@,CXF,2<["B`@("`@("`@)&1I<B`]('!O<&5N*"1C;60L("=R
M)RD["B`@("`@("`@:68@*"$D9&ER*2!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"=&86EL960@=&\@97AE8W5T92!S=FX@;',Z("<@
M+B`D8VUD*3L*("`@("`@("!]"@H@("`@("`@("\J($-R96%T92!T=V\@87)R
M87ES("T@;VYE(&]F(&%L;"!T:&4@9FEL97,L(&%N9"!T:&4@;W1H97(@;V8*
M("`@("`@("`@*B!A;&P@=&AE(&1I<G,N("HO"B`@("`@("`@)&5R<F]R<R`]
M(&%R<F%Y*"D["B`@("`@("`@=VAI;&4@*"%F96]F*"1D:7(I*2!["B`@("`@
M("`@("`@("1L:6YE(#T@8VAO<"AF9V5T<R@D9&ER+"`Q,#(T*2D["B`@("`@
M("`@("`@(&EF("@A<W1R;&5N*"1L:6YE*2D@>PH@("`@("`@("`@("`@("`@
M8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("AS=6)S
M='(H)&QI;F4L(#`L(#0I(#T]("=S=FXZ)RD@>PH@("`@("`@("`@("`@("`@
M)&5R<F]R<UM=(#T@)&QI;F4["B`@("`@("`@("`@('T@96QS96EF("AS=6)S
M='(H)&QI;F4L("TQ*2`]/2`G+R<I('L*("`@("`@("`@("`@("`@("1T:&ES
M+3YD:7)S6UT@/2!S=6)S='(H)&QI;F4L(#`L("TQ*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1F;"`]("1T:&ES+3YR97`M/F=E
M=$9I;&5/8FIE8W0H)'1H:7,M/G%U97)Y1&ER*"D@+B`B+R1L:6YE(BP@)&-A
M8VAE+"`D<75I8VML;V<I.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)&9L
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M("1F;#L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/F9I;&5S6UT@/2`D9FP["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@('!C;&]S92@D9&ER
M*3L*"B`@("`@("`@:68@*"1E<G)O<G,I('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H:6UP;&]D92@B7&XB+"`D97)R;W)S*2D["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*
M("`@("`J(%-O<G0@=&AE(&-O;G1E;G1S(&]F('1H92!D:7)E8W1O<GD@:6X@
M82!G:79E;B!F87-H:6]N(&%N9`H@("`@("H@;W)D97(N"B`@("`@*@H@("`@
M("H@0'!A<F%M("1H;W<@3V8@=&AE(&9O<FT@5D-?4T]25%\J('=H97)E("H@
M8V%N(&)E.@H@("`@("H@("`@("`@("`@("`@3D].12P@3D%-12P@04=%+"!2
M158@9F]R('-O<G1I;F<@8GD@;F%M92P@86=E(&]R(')E=FES:6]N+@H@("`@
M("H@0'!A<F%M("1D:7(@3V8@=&AE(&9O<FT@5D-?4T]25%\J('=H97)E("H@
M8V%N(&)E.@H@("`@("H@("`@("`@("`@("`@05-#14Y$24Y'+"!$15-#14Y$
M24Y'(&9O<B!T:&4@;W)D97(@;V8@=&AE('-O<G0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&%P<&QY4V]R="@D:&]W(#T@5D-?4T]25%].3TY%+"`D9&ER(#T@
M5D-?4T]25%]!4T-%3D1)3D<I"B`@("!["B`@("`@("`@+RH@5$]$3SH@=&AI
M<R!C;V1E(&QO;VMS('9E<GD@:6YE9F9I8VEE;G0A(&]P=&EM:7-E+BXN("T*
M("`@("`@("`@*B!A=G-M+B`J+PH*("`@("`@("`O+R!!<W-U;64@8GD@;F%M
M92!F;W(@=&AE(&UO;65N="X*("`@("`@("!N871C87-E<V]R="@D=&AI<RT^
M9&ER<RD["B`@("`@("`@)'1H:7,M/F1O1FEL95-O<G0H)'1H:7,M/F9I;&5S
M+"`D:&]W+"`D9&ER*3L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/F%T=&EC
M1FEL97,I*2!["B`@("`@("`@("`@("1T:&ES+3YD;T9I;&53;W)T*"1T:&ES
M+3YA='1I8T9I;&5S+"`D:&]W+"`D9&ER*3L*("`@("`@("!]"B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3YM97)G961&:6QE<RDI('L*("`@("`@("`@("`@
M)'1H:7,M/F1O1FEL95-O<G0H)'1H:7,M/FUE<F=E9$9I;&5S+"`D:&]W+"`D
M9&ER*3L*("`@("`@("!]"B`@("`@("`@:68@*"1D:7(@/3T@5D-?4T]25%]$
M15-#14Y$24Y'*2!["B`@("`@("`@("`@("1T:&ES+3YD:7)S(#T@87)R87E?
M<F5V97)S92@D=&AI<RT^9&ER<RD["B`@("`@("`@("`@("1T:&ES+3YF:6QE
M<R`](&%R<F%Y7W)E=F5R<V4H)'1H:7,M/F9I;&5S*3L*("`@("`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3YM97)G961&:6QE<RDI('L*("`@("`@("`@("`@
M("`@("1T:&ES+3YM97)G961&:6QE<R`](&%R<F%Y7W)E=F5R<V4H)'1H:7,M
M/FUE<F=E9$9I;&5S*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*
M"B`@("!F=6YC=&EO;B!D;T9I;&53;W)T*"8D9FEL94QI<W0L("1H;W<@/2!6
M0U]33U)47TY/3D4L("1D:7(@/2!60U]33U)47T%30T5.1$E.1RD*("`@('L*
M("`@("`@("!S=VET8V@@*"1H;W<I('L*("`@("`@("!C87-E(%9#7U-/4E1?
M04=%.@H@("`@("`@("`@("!U<V]R="@D9FEL94QI<W0L(&%R<F%Y*"1T:&ES
M+"`G9FEL94%G95-O<G0G*2D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!C87-E(%9#7U-/4E1?3D%-13H*("`@("`@("`@("`@=7-O<G0H)&9I;&5,
M:7-T+"!A<G)A>2@D=&AI<RP@)V9I;&5.86UE4V]R="<I*3L*("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@(&-A<V4@5D-?4T]25%]!551(3U(Z"B`@("`@
M("`@("`@('5S;W)T*"1F:6QE3&ES="P@87)R87DH)'1H:7,L("=F:6QE075T
M:&]R4V]R="<I*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@
M5D-?4T]25%]2158Z"B`@("`@("`@("`@('5S;W)T*"1F:6QE3&ES="P@87)R
M87DH)'1H:7,L("=F:6QE4F5V4V]R="<I*3L*("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@(&-A<V4@5D-?4T]25%].3TY%.@H@("`@("`@(&1E9F%U;'0Z
M"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%-O<G0@9G5N8W1I;VX@9F]R(&%S8V5N9&EN9R!A9V4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&9I;&5!9V53;W)T*"1A+"`D8BD*("`@('L*("`@
M("`@("`D86$@/2`D82T^<75E<GE,87-T3&]G*"D["B`@("`@("`@)&)B(#T@
M)&(M/G%U97)Y3&%S=$QO9R@I.PH@("`@("`@(&EF("@D86$M/G%U97)Y1&%T
M92@I(#T]("1B8BT^<75E<GE$871E*"DI('L*("`@("`@("`@("`@<F5T=7)N
M(#`["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("@D86$M
M/G%U97)Y1&%T92@I(#P@)&)B+3YQ=65R>41A=&4H*2D@/R`Q(#H@+3$["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4V]R="!F=6YC=&EO;B!B
M>2!A=71H;W(@;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9FEL94%U=&AO
M<E-O<G0H)&$L("1B*0H@("`@>PH@("`@("`@("1A82`]("1A+3YQ=65R>4QA
M<W1,;V<H*3L*("`@("`@("`D8F(@/2`D8BT^<75E<GE,87-T3&]G*"D["B`@
M("`@("`@:68@*"1A82T^<75E<GE!=71H;W(H*2`]/2`D8F(M/G%U97)Y075T
M:&]R*"DI('L*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@<F5T=7)N("@D86$M/G%U97)Y075T:&]R*"D@/B`D
M8F(M/G%U97)Y075T:&]R*"DI(#\@,2`Z("TQ.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J(%-O<G0@9G5N8W1I;VX@9F]R(&%S8V5N9&EN9R!F
M:6QE;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9FEL94YA;653;W)T*"1A
M+"`D8BD*("`@('L*("`@("`@("!R971U<FX@<W1R8V%S96-M<"@D82T^;F%M
M92P@)&(M/FYA;64I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V]R="!F=6YC
M=&EO;B!F;W(@87-C96YD:6YG(')E=FES:6]N+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!F:6QE4F5V4V]R="@D82P@)&(I"B`@("!["B`@("`@("`@<F5T=7)N
M(%9#7U)E=FES:6]N.CIC;7`H)&$M/G%U97)Y2&5A9"@I+"`D8BT^<75E<GE(
M96%D*"DI.PH@("`@?0H*?0H*+RHJ"B`J(%9#7W-V;B!F:6QE(&-L87-S+@H@
M*@H@*B!#;W!Y<FEG:'0@06YI;"!-861H879A<&5D9'DL(#QA;FEL0')E8V]I
M;"YO<F<^"B`J"B`J($!A=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL
M0')E8V]I;"YO<F<^"B`J($!P86-K86=E(%9#"B`J+PIC;&%S<R!60U]&:6QE
M7W-V;B!E>'1E;F1S(%9#7T9I;&4@>PH*("`@("\J*@H@("`@("H@0W)E871E
M(&$@<F5P;W-I=&]R>2!F:6QE(&]B:F5C="P@86YD(&=I=F4@:70@:6YF;W)M
M871I;VX@86)O=70*("`@("`J('=H870@:71S('!A<F5N="!D:7)E8W1O<GD@
M86YD(')E<&]S:71O<GD@;V)J96-T<R!A<F4N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D9FP@($9U;&P@<&%T:"!T;R!T:&ES(&9I;&4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%9#7T9I;&5?<W9N*"1R97`L("1F;"P@)'%U:6-K
M;&]G(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1H:7,M/G)E<"`]("1R97`[
M"B`@("`@("`@)'1H:7,M/FYA;64@/2!B87-E;F%M92@D9FPI.PH@("`@("`@
M("1T:&ES+3YD:7(@/2!D:7)N86UE*"1F;"D["B`@("`@("`@)'1H:7,M/FQO
M9W,@/2!A<G)A>2@I.PH@("`@("`@("1T:&ES+3YQ=6EC:VQO9R`]("1Q=6EC
M:VQO9SL*("`@("`@("`D=&AI<RT^<F5V<R`](&%R<F%Y*"D["B`@("`@("`@
M)'1H:7,M/G)E=G-Y;2`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/G-Y;7)E
M=B`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/F)R86YC:&5S(#T@87)R87DH
M*3L*("`@('T*"B`@("!F=6YC=&EO;B`F9V5T1FEL94]B:F5C="@D<F5P+"`D
M9FEL96YA;64L("1C86-H92`](&YU;&PL("1Q=6EC:VQO9R`](&9A;'-E*0H@
M("`@>PH@("`@("`@("\J(%1H92!V97)S:6]N(&]F('1H92!C86-H960@9&%T
M82X@26YC<F5M96YT('1H:7,@=VAE;F5V97(@=&AE"B`@("`@("`@("H@:6YT
M97)N86P@<W1O<F%G92!F;W)M870@8VAA;F=E<RP@<W5C:"!T:&%T('=E(&UU
M<W0*("`@("`@("`@*B!I;G9A;&ED871E('!R:6]R(&-A8VAE9"!D871A+B`J
M+PH@("`@("`@("1C86-H959E<G-I;VX@/2`R.PH@("`@("`@("1C86-H94ED
M(#T@)')E<"T^<V]U<F-E<F]O="@I("X@)U]N)R`N("1F:6QE;F%M92`N("=?
M9B<@+B`H:6YT*21Q=6EC:VQO9R`N("=?=B<@+B`D8V%C:&5697)S:6]N.PH*
M("`@("`@("!I9B`H)&-A8VAE("8F"B`@("`@("`@("`@("\O(%1H92!F:6QE
M(&ES(&-A8VAE9"!F;W(@;VYE(&AO=7(@;F\@;6%T=&5R('=H870L(&)E8V%U
M<V4*("`@("`@("`@("`@+R\@=&AE<F4@:7,@;F\@=V%Y('1O(&1E=&5R;6EN
M92!W:71H(%-U8G9E<G-I;VX@=&AE('1I;64*("`@("`@("`@("`@+R\@=&AE
M(&9I;&4@;&%S="!C:&%N9V5D+@H@("`@("`@("`@("`D8V%C:&4M/F5X:7-T
M<R@D8V%C:&5)9"P@,S8P,"DI('L*("`@("`@("`@("`@)&9I;&5/8B`]('5N
M<V5R:6%L:7IE*"1C86-H92T^9V5T*"1C86-H94ED+"`S-C`P*2D["B`@("`@
M("`@("`@("1F:6QE3V(M/G-E=%)E<&]S:71O<GDH)')E<"D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&9I;&5/8B`](&YE=R!60U]&:6QE7W-V
M;B@D<F5P+"`D9FEL96YA;64L("1Q=6EC:VQO9RD["B`@("`@("`@("`@("1F
M:6QE3V(M/G-E=%)E<&]S:71O<GDH)')E<"D["B`@("`@("`@("`@(&EF("AI
M<U]A*"@D<F5S=6QT(#T@)&9I;&5/8BT^9V5T0G)O=W-E26YF;R@I*2P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&9I;&5/8BT^87!P;'E3;W)T
M*%9#7U-/4E1?04=%*3L*"B`@("`@("`@("`@(&EF("@D8V%C:&4I('L*("`@
M("`@("`@("`@("`@("1C86-H92T^<V5T*"1C86-H94ED+"!S97)I86QI>F4H
M)&9I;&5/8BDI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)&9I;&5/8CL*("`@('T*"B`@("`O*BH*("`@("`J($EF('1H:7,@
M9FEL92!I<R!P<F5S96YT(&EN(&%N($%T=&EC(&1I<F5C=&]R>2P@=&AI<R!I
M;F1I8V%T97,*("`@("`J(&ET+@H@("`@("H*("`@("`J($!R971U<FX@=')U
M92!I9B!F:6QE(&ES(&EN('1H92!!='1I8RP@86YD(&9A;'-E(&]T:&5R=VES
M90H@("`@("HO"B`@("!F=6YC=&EO;B!I<T%T=&EC1FEL92@I"B`@("!["B`@
M("`@("`@+R\@3F]T(&EM<&QE;65N=&5D('EE=`H@("`@("`@(')E='5R;B!F
M86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&YA;64@
M;V8@=&AE(&-U<G)E;G0@9FEL92!A<R!I;B!T:&4@<F5P;W-I=&]R>0H@("`@
M("H*("`@("`J($!R971U<FX@1FEL96YA;64@*'=I=&AO=70@=&AE('!A=&@I
M"B`@("`@*B\*("`@(&9U;F-T:6]N('%U97)Y4F5P;W-I=&]R>4YA;64H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^;F%M93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@;F%M92!O9B!T:&4@8W5R<F5N="!F:6QE('=I
M=&AO=70@=&AE(')E<&]S:71O<GD*("`@("`J(&5X=&5N<VEO;G,@*'5S=6%L
M;'D@+'8I"B`@("`@*@H@("`@("H@0')E='5R;B!&:6QE;F%M92!W:71H;W5T
M(')E<&]S:71O<GD@97AT96YS:6]N"B`@("`@*B\*("`@(&9U;F-T:6]N('%U
M97)Y3F%M92@I"B`@("!["B`@("`@("!R971U<FX@<')E9U]R97!L86-E*"<O
M+'8D+R<L("<G+"`D=&AI<RT^;F%M92D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FX@=&AE(&QA<W0@<F5V:7-I;VX@;V8@=&AE(&-U<G)E;G0@9FEL
M92!O;B!T:&4@2$5!1"!B<F%N8V@*("`@("`J"B`@("`@*B!`<F5T=7)N($QA
M<W0@<F5V:7-I;VX@;V8@=&AE(&-U<G)E;G0@9FEL90H@("`@("HO"B`@("!F
M=6YC=&EO;B!Q=65R>5)E=FES:6]N*"D*("`@('L*("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3YR979S6S!=*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@G3F\@<F5V:7-I;VYS)RD["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D=&AI<RT^<F5V<ULP73L*("`@('T*"B`@("!F=6YC=&EO
M;B!Q=65R>5!R979I;W5S4F5V:7-I;VXH)')E=BD*("`@('L*("`@("`@("`D
M;&%S="`](&9A;'-E.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YR979S(&%S
M("1E;G1R>2D@>PH@("`@("`@("`@("!I9B`H)&QA<W0I"B`@("`@("`@("`@
M("`@("!R971U<FX@)&5N=')Y.PH@("`@("`@("`@("!I9B`H)&5N=')Y(#T]
M("1R978I"B`@("`@("`@("`@("`@("`D;&%S="`]('1R=64["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FX@=&AE($A%040@*&UO<W0@<F5C96YT*2!R979I<VEO;B!N=6UB
M97(@9F]R('1H:7,@9FEL92X*("`@("`J"B`@("`@*B!`<F5T=7)N($A%040@
M<F5V:7-I;VX@;G5M8F5R"B`@("`@*B\*("`@(&9U;F-T:6]N('%U97)Y2&5A
M9"@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YQ=65R>5)E=FES:6]N
M*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&QA<W0@5D-?
M3&]G(&]B:F5C="!I;B!T:&4@9FEL92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(%9#7TQO9R!O9B!T:&4@;&%S="!E;G1R>2!I;B!T:&4@9FEL90H@("`@("HO
M"B`@("!F=6YC=&EO;B!Q=65R>4QA<W1,;V<H*0H@("`@>PH@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/G)E=G-;,%TI('Q\("%I<W-E="@D=&AI<RT^;&]G
M<ULD=&AI<RT^<F5V<ULP75TI*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*"=.;R!R979I<VEO;G,G*3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1T:&ES+3YL;V=S6R1T:&ES+3YR979S6S!=73L*("`@('T*
M"B`@("`O*BH*("`@("`J(%-O<G0@=&AE(&QI<W0@;V8@5D-?3&]G(&]B:F5C
M=',@=&AA="!T:&ES(&9I;&4@8V]N=&%I;G,N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&AO=R!60U]33U)47U)%5B`H<V]R="!B>2!R979I<VEO;BDL"B`@("`@
M*B`@("`@("`@("`@(%9#7U-/4E1?3D%-12`H<V]R="!B>2!A=71H;W(@;F%M
M92DL"B`@("`@*B`@("`@("`@("`@(%9#7U-/4E1?04=%("AS;W)T(&)Y(&-O
M;6UI="!D871E*0H@("`@("HO"B`@("!F=6YC=&EO;B!A<'!L>5-O<G0H)&AO
M=R`](%9#7U-/4E1?4D56*0H@("`@>PH@("`@("`@('-W:71C:"`H)&AO=RD@
M>PH@("`@("`@(&-A<V4@5D-?4T]25%]2158Z"B`@("`@("`@("`@("1F=6YC
M(#T@)U)E=FES:6]N)SL*("`@("`@("`@("`@8G)E86L["B`@("`@("`@8V%S
M92!60U]33U)47TY!344Z"B`@("`@("`@("`@("1F=6YC(#T@)TYA;64G.PH@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("!C87-E(%9#7U-/4E1?04=%.@H@
M("`@("`@("`@("`D9G5N8R`]("=!9V4G.PH@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`D9G5N8R`]("=2979I<VEO
M;B<["B`@("`@("`@?0H@("`@("`@('5A<V]R="@D=&AI<RT^;&]G<RP@87)R
M87DH)'1H:7,L(")S;W)T0GDD9G5N8R(I*3L*("`@("`@("!R971U<FX@=')U
M93L*("`@('T*"B`@("`O*BH*("`@("`J(%1H92!S;W)T0GDJ*"D@9G5N8W1I
M;VYS(&%R92!I;G1E<FYA;&QY('5S960@8GD@87!P;'E3;W)T+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!S;W)T0GE2979I<VEO;B@D82P@)&(I"B`@("!["B`@
M("`@("`@<F5T=7)N(%9#7U)E=FES:6]N.CIC;7`H)&(M/G)E=BP@)&$M/G)E
M=BD["B`@("!]"@H@("`@9G5N8W1I;VX@<V]R=$)Y06=E*"1A+"`D8BD*("`@
M('L*("`@("`@("!R971U<FX@)&(M/F1A=&4@+2`D82T^9&%T93L*("`@('T*
M"B`@("!F=6YC=&EO;B!S;W)T0GE.86UE*"1A+"`D8BD*("`@('L*("`@("`@
M("!R971U<FX@<W1R8VUP*"1A+3YA=71H;W(L("1B+3YA=71H;W(I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4&]P=6QA=&4@=&AE(&]B:F5C="!W:71H(&EN
M9F]R;6%T:6]N(&%B;W5T('1H92!R979I<VEO;G,@;&]G<PH@("`@("H@86YD
M(&1A=&5S(&]F('1H92!F:6QE+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@8F]O;&5A;B`@("`@("`@("`@(%1R=64@;VX@<W5C8V5S<RP*("`@("`J
M("`@("`@("`@("`@("`@4$5!4E]%<G)O<B`@("`@("`@($]N(&5R<F]R+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971"<F]W<V5);F9O*"D*("`@('L*("`@
M("`@("`O*B!4:&ES(&1O97-N)W0@=V]R:SL@;F5E9"!T;R!F:6YD(&%N;W1H
M97(@=V%Y('1O('-I;7!L>0H@("`@("`@("`J(')E<75E<W0@=&AE(&UO<W0@
M<F5C96YT(')E=FES:6]N.@H@("`@("`@("`J"B`@("`@("`@("H@)&9L86<@
M/2`D=&AI<RT^<75I8VML;V<@/R`G+7(@2$5!1"`G(#H@)R<[("HO"B`@("`@
M("`@)&9L86<@/2`G)SL*("`@("`@("`D42`](%9#7U=)3D1/5U,@/R`G(B<@
M.B`B)R(["B`@("`@("`@)&-M9"`]("1T:&ES+3YR97`M/F=E=%!A=&@H)W-V
M;B<I("X@)R!L;V<@+78@)R`N("1F;&%G("X@)%$@+B!S=')?<F5P;&%C92@D
M42P@)UQ<)R`N("11+"`D=&AI<RT^<75E<GE&=6QL4&%T:"@I*2`N("11("X@
M)R`R/B8Q)SL*("`@("`@("`D<&EP92`]('!O<&5N*"1C;60L("=R)RD["B`@
M("`@("`@:68@*"$D<&EP92D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@G1F%I;&5D('1O(&5X96-U=&4@<W9N(&QO9SH@)R`N("1C
M;60I.PH@("`@("`@('T*"B`@("`@("`@9F=E=',H)'!I<&4I.PH@("`@("`@
M('=H:6QE("@A9F5O9B@D<&EP92DI('L*("`@("`@("`@("`@)&QO9R`](&YE
M=R!60U],;V=?<W9N*"1T:&ES+3YR97`L("1T:&ES*3L*("`@("`@("`@("`@
M)&5R<B`]("1L;V<M/G!R;V-E<W-,;V<H)'!I<&4I.PH@("`@("`@("`@("!I
M9B`H)&5R<BD@>PH@("`@("`@("`@("`@("`@)')E=B`]("1L;V<M/G%U97)Y
M4F5V:7-I;VXH*3L*("`@("`@("`@("`@("`@("1T:&ES+3YL;V=S6R1R979=
M(#T@)&QO9SL*("`@("`@("`@("`@("`@("1T:&ES+3YR979S6UT@/2`D<F5V
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)'1H:7,M/G%U:6-K
M;&]G*2!["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<&-L;W-E*"1P:7!E*3L*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@9G5L
M;'D@<75A;&EF:65D(&9I;&5N86UE(&]F('1H:7,@;V)J96-T+@H@("`@("H*
M("`@("`J($!R971U<FX@1G5L;'D@<75A;&EF:65D(&9I;&5N86UE(&]F('1H
M:7,@;V)J96-T"B`@("`@*B\*("`@(&9U;F-T:6]N('%U97)Y1G5L;%!A=&@H
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<F5P+3YS;W5R8V5R;V]T
M*"D@+B`G+R<@+B`D=&AI<RT^<75E<GE-;V1U;&50871H*"D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&YA;64@;V8@=&AI<R!F:6QE(')E
M;&%T:79E('1O(&ET<R!S;W5R8V5R;V]T+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!0871H;F%M92!R96QA=&EV92!T;R!T:&4@<V]U<F-E<F]O
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@<75E<GE-;V1U;&50871H*"D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/F1I<B`N("<O)R`N("1T:&ES+3YN
M86UE.PH@("`@?0H*?0H*+RHJ"B`J(%9#7W-V;B!L;V<@8VQA<W,N"B`J"B`J
M($%N:6P@36%D:&%V87!E9&1Y+"`\86YI;$!R96-O:6PN;W)G/@H@*@H@*B!`
M875T:&]R("!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@
M*B!`<&%C:V%G92!60PH@*B\*8VQA<W,@5D-?3&]G7W-V;B!["@H@("`@=F%R
M("1R97`["B`@("!V87(@)&5R<CL*("`@('9A<B`D9FEL93L*("`@('9A<B`D
M9FEL97,["B`@("!V87(@)'1A9W,["B`@("!V87(@)')E=CL*("`@('9A<B`D
M9&%T93L*("`@('9A<B`D;&]G.PH@("`@=F%R("1A=71H;W(["B`@("!V87(@
M)'-T871E.PH@("`@=F%R("1L:6YE<SL*("`@('9A<B`D8G)A;F-H97,["@H@
M("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@5D-?3&]G7W-V;B@D<F5P+"`D9FPI"B`@("!["B`@("`@("`@)'1H:7,M
M/G)E<"`]("1R97`["B`@("`@("`@)'1H:7,M/F9I;&4@/2`D9FP["B`@("`@
M("`@)'1H:7,M/F)R86YC:&5S(#T@87)R87DH*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!P<F]C97-S3&]G*"1P:7!E*0H@("`@>PH@("`@("`@("1L:6YE(#T@
M9F=E=',H)'!I<&4I.PH*("`@("`@("!I9B`H9F5O9B@D<&EP92DI('L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@
M*'!R96=?;6%T8V@H)R]><BA;,"TY72HI(%Q\("@N*C\I(%Q\("@N*BD@7"@N
M*EPI(%Q\("A;,"TY72HI(&QI;F5S/R0O)RP@)&QI;F4L("1M871C:&5S*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^<F5V(#T@)&UA=&-H97-;,5T["B`@("`@
M("`@("`@("1T:&ES+3YA=71H;W(@/2`D;6%T8VAE<ULR73L*("`@("`@("`@
M("`@)'1H:7,M/F1A=&4@/2!S=')T;W1I;64H)&UA=&-H97-;,UTI.PH@("`@
M("`@("`@("`D<VEZ92`]("1M871C:&5S6S1=.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1T:&ES+3YE<G(@/2`D;&EN93L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@9F=E=',H)'!I<&4I
M.PH*("`@("`@("`D=&AI<RT^9FEL97,@/2!A<G)A>2@I.PH@("`@("`@('=H
M:6QE("@H)&QI;F4@/2!T<FEM*&9G971S*"1P:7!E*2DI("$]("<G*2!["B`@
M("`@("`@("`@("1T:&ES+3YF:6QE<UM=(#T@)&QI;F4["B`@("`@("`@?0H*
M("`@("`@("!F;W(@*"1I(#T@,#L@)&D@(3T@)'-I>F4[("LK)&DI('L*("`@
M("`@("`@("`@)'1H:7,M/FQO9R`]("1T:&ES+3YL;V<@+B!C:&]P*&9G971S
M*"1P:7!E*2D@+B`B7&XB.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/FQO
M9R`](&-H;W`H)'1H:7,M/FQO9RD["B`@("`@("`@9F=E=',H)'!I<&4I.PH*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!Q=65R
M>41A=&4H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^9&%T93L*("`@
M('T*"B`@("!F=6YC=&EO;B!Q=65R>5)E=FES:6]N*"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/G)E=CL*("`@('T*"B`@("!F=6YC=&EO;B!Q=65R
M>4%U=&AO<B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YA=71H;W([
M"B`@("!]"@H@("`@9G5N8W1I;VX@<75E<GE,;V<H*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^;&]G.PH@("`@?0H*("`@(&9U;F-T:6]N('%U97)Y
M0VAA;F=E9$QI;F5S*"D*("`@('L*("`@("`@("!R971U<FX@:7-S970H)'1H
M:7,M/FQI;F5S*2`_("@D=&AI<RT^;&EN97,I(#H@)R<["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!':79E;B!A(&)R86YC:"!R979I<VEO;B!N=6UB97(L('1H
M:7,@9G5N8W1I;VX@<F5M87!S(&ET"B`@("`@*B!A8V-O<F1I;F=L>2P@86YD
M('!E<F9O<FUS(&$@;&]O:W5P(&]N('1H92!F:6QE(&]B:F5C="!T;PH@("`@
M("H@<F5T=7)N('1H92!S>6UB;VQI8R!N86UE*',I(&]F('1H870@8G)A;F-H
M(&EN('1H92!T<F5E+@H@("`@("H*("`@("`J($!R971U<FX@:&%S:"!O9B!S
M>6UB;VQI8R!N86UE<R`]/B!B<F%N8V@@;G5M8F5R<PH@("`@("HO"B`@("!F
M=6YC=&EO;B!Q=65R>5-Y;6)O;&EC0G)A;F-H97,H*0H@("`@>PH@("`@("`@
M("1S>6U"<F%N8VAE<R`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)'1H
M:7,M/F)R86YC:&5S(&%S("1B<F%N8V@I('L*("`@("`@("`@("`@)'!A<G1S
M(#T@97AP;&]D92@G+B<L("1B<F%N8V@I.PH@("`@("`@("`@("`D;&%S="`]
M(&%R<F%Y7W!O<"@D<&%R=',I.PH@("`@("`@("`@("`D<&%R='-;72`]("<P
M)SL*("`@("`@("`@("`@)'!A<G1S6UT@/2`D;&%S=#L*("`@("`@("`@("`@
M)')E=B`](&EM<&QO9&4H)RXG+"`D<&%R=',I.PH@("`@("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/F9I;&4M/F)R86YC:&5S6R1B<F%N8VA=*2D@>PH@("`@
M("`@("`@("`@("`@)'-Y;4)R86YC:&5S6R1T:&ES+3YF:6QE+3YB<F%N8VAE
M<ULD8G)A;F-H75T@/2`D8G)A;F-H.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D<WEM0G)A;F-H97,["B`@("!]"@I]"@HO*BH*
M("H@5D-?<W9N(%!A=&-H<V5T(&-L87-S+@H@*@H@*B!#;W!Y<FEG:'0@06YI
M;"!-861H879A<&5D9'DL(#QA;FEL0')E8V]I;"YO<F<^"B`J"B`J($!A=71H
M;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J($!P
M86-K86=E(%9#"B`J+PIC;&%S<R!60U]0871C:'-E=%]S=FX@97AT96YD<R!6
M0U]0871C:'-E="!["@H@("`@=F%R("1?9FEL93L*"B`@("`O*BH*("`@("`J
M($-R96%T92!A('!A=&-H<V5T(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1F:6QE("!4:&4@9FEL96YA;64@=&\@9V5T('!A=&-H<V5T
M<R!F;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(%9#7U!A=&-H<V5T7W-V;B@D
M9FEL92D*("`@('L*("`@("`@("`D=&AI<RT^7V9I;&4@/2`D9FEL93L*("`@
M('T*"B`@("!F=6YC=&EO;B`F9V5T4&%T8VAS971/8FIE8W0H)')E<"P@)&9I
M;&5N86UE+"`D8V%C:&4@/2!N=6QL*0H@("`@>PH@("`@("`@("\J(%1H92!V
M97)S:6]N(&]F('1H92!C86-H960@9&%T82X@26YC<F5M96YT('1H:7,@=VAE
M;F5V97(@=&AE"B`@("`@("`@("H@:6YT97)N86P@<W1O<F%G92!F;W)M870@
M8VAA;F=E<RP@<W5C:"!T:&%T('=E(&UU<W0*("`@("`@("`@*B!I;G9A;&ED
M871E('!R:6]R(&-A8VAE9"!D871A+B`J+PH@("`@("`@("1C86-H959E<G-I
M;VX@/2`Q.PH@("`@("`@("1C86-H94ED(#T@)')E<"T^<V]U<F-E<F]O="@I
M("X@)U]N)R`N("1F:6QE;F%M92`N("=?9E]V)R`N("1C86-H959E<G-I;VX[
M"@H@("`@("`@(&EF("@D8V%C:&4@)B8*("`@("`@("`@("`@+R\@5&AE(&9I
M;&4@:7,@8V%C:&5D(&9O<B!O;F4@:&]U<B!N;R!M871T97(@=VAA="P@8F5C
M875S90H@("`@("`@("`@("`O+R!T:&5R92!I<R!N;R!W87D@=&\@9&5T97)M
M:6YE('=I=&@@<W9N('1H92!T:6UE('1H92!F:6QE"B`@("`@("`@("`@("\O
M(&QA<W0@8VAA;F=E9"X*("`@("`@("`@("`@)&-A8VAE+3YE>&ES=',H)&-A
M8VAE260L(#,V,#`I*2!["B`@("`@("`@("`@("1P<T]B(#T@=6YS97)I86QI
M>F4H)&-A8VAE+3YG970H)&-A8VAE260L(#,V,#`I*3L*("`@("`@("`@("`@
M)'!S3V(M/G-E=%)E<&]S:71O<GDH)')E<"D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'!S3V(@/2!N97<@5D-?4&%T8VAS971?<W9N*"1F:6QE
M;F%M92D["B`@("`@("`@("`@("1P<T]B+3YS971297!O<VET;W)Y*"1R97`I
M.PH@("`@("`@("`@("!I9B`H:7-?82@H)')E<W5L="`]("1P<T]B+3YG9710
M871C:'-E=',H*2DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I
M9B`H)&-A8VAE*2!["B`@("`@("`@("`@("`@("`D8V%C:&4M/G-E="@D8V%C
M:&5)9"P@<V5R:6%L:7IE*"1P<T]B*2D["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D<'-/8CL*("`@('T*"B`@("`O*BH*("`@
M("`J(%!O<'5L871E('1H92!O8FIE8W0@=VET:"!I;F9O<FUA=&EO;B!A8F]U
M="!T:&4@<&%T8VAS971S('1H870*("`@("`J('1H:7,@9FEL92!I<R!I;G9O
M;'9E9"!I;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!014%27T5R
M<F]R(&]B:F5C="!O;B!E<G)O<BP@;W(@=')U92!O;B!S=6-C97-S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G9710871C:'-E=',H*0H@("`@>PH@("`@("`@
M("1F:6QE3V(@/2!N97<@5D-?1FEL95]S=FXH)'1H:7,M/E]R97`L("1T:&ES
M+3Y?9FEL92D["B`@("`@("`@:68@*&ES7V$H*"1R97-U;'0@/2`D9FEL94]B
M+3YG971"<F]W<V5);F9O*"DI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M
M/E]P871C:'-E=',@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1F:6QE
M3V(M/FQO9W,@87,@)')E=B`]/B`D;&]G*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?<&%T8VAS971S6R1R979=(#T@87)R87DH*3L*("`@("`@("`@("`@)'1H
M:7,M/E]P871C:'-E='-;)')E=EU;)V1A=&4G72`]("1L;V<M/G%U97)Y1&%T
M92@I.PH@("`@("`@("`@("`D=&AI<RT^7W!A=&-H<V5T<ULD<F5V75LG875T
M:&]R)UT@/2`D;&]G+3YQ=65R>4%U=&AO<B@I.PH@("`@("`@("`@("`D=&AI
M<RT^7W!A=&-H<V5T<ULD<F5V75LG8G)A;F-H)UT@/2`G)SL*("`@("`@("`@
M("`@)'1H:7,M/E]P871C:'-E='-;)')E=EU;)W1A9R==(#T@)R<["B`@("`@
M("`@("`@("1T:&ES+3Y?<&%T8VAS971S6R1R979=6R=L;V<G72`]("1L;V<M
M/G%U97)Y3&]G*"D["B`@("`@("`@("`@("1T:&ES+3Y?<&%T8VAS971S6R1R
M979=6R=M96UB97)S)UT@/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W)E86-H
M("@D;&]G+3YF:6QE<R!A<R`D9FEL92D@>PH@("`@("`@("`@("`@("`@)&%C
M=&EO;B`]('-U8G-T<B@D9FEL92P@,"P@,2D["B`@("`@("`@("`@("`@("`D
M9FEL92`]('!R96=?<F5P;&%C92@G+RXJ/UQS*"XJ/RDH7'-\)"DN*B\G+"`G
M7%PQ)RP@)&9I;&4I.PH@("`@("`@("`@("`@("`@)'1O(#T@)')E=CL*("`@
M("`@("`@("`@("`@(&EF("@D86-T:6]N(#T]("=!)RD@>PH@("`@("`@("`@
M("`@("`@("`@("1F<F]M(#T@)TE.251)04PG.PH@("`@("`@("`@("`@("`@
M?2!E;'-E:68@*"1A8W1I;VX@/3T@)T0G*2!["B`@("`@("`@("`@("`@("`@
M("`@)&9R;VT@/2`D=&\["B`@("`@("`@("`@("`@("`@("`@)'1O(#T@)RA$
M14%$*2<["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("\O(%1H:7,@=&5C:&YI8V%L;'D@:7-N)W0@=&AE('!R979I;W5S
M(')E=FES:6]N+`H@("`@("`@("`@("`@("`@("`@("\O(&)U="!I="!W;W)K
M<R!F;W(@9&EF9FEN9R!P=7)P;W-E<RX*("`@("`@("`@("`@("`@("`@("`D
M9G)O;2`]("1T;R`M(#$["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P871C:'-E='-;)')E=EU;)VUE;6)E<G,G75M=(#T@
M87)R87DH)V9I;&4G(#T^("1F:6QE+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V9R;VTG
M(#T^("1F<F]M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1O)R`]/B`D=&\I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O3DQ3````````````````````````````
M````````````````````````````````````````````````````````,#`P
M-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S<@
M,#$W-S(W`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92].3%,O8V]O
M<F1I;F%T97,N<&AP````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#<V
M-3,S-"`Q,#4Q-30S,S<S-R`P,C,P-3,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%1H:7,@9FEL92!L
M:7-T<R!T:&4@;&]C871I;VYS(&]F(&-I=&EE<R!A<F]U;F0@=&AE('=O<FQD
M+B!4:&4*("H@9F]R;6%T(&ES.@H@*@H@*B`@("1C;V]R9&EN871E<ULG8V]U
M;G1R>6YA;64G75LG;&%T.FQO;F<G72`]("=C:71Y;F%M92<["B`J"B`J($QA
M=&ET=61E(&%N9"!L;VYG:71U9&4@87)E(&1E8VEM86QS("AS;W5T:"!A;F0@
M=V5S="!A<F4@;F5G871I=F4I+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R].
M3%,O3DQ3+V-O;W)D:6YA=&5S+G!H<"QV(#$N,BXQ,BXS(#(P,#4O,3`O,3@@
M,3$Z,#$Z,3@@:F%N($5X<"`D"B`J"B`J($!P86-K86=E($AO<F1E7TY,4PH@
M*B\*"B1C;V]R9&EN871E<ULG069G:&%N:7-T86XG75LG,S$N,#`P.C8Q+C@U
M,"==(#T@)UIA<F%N:B<["B1C;V]R9&EN871E<ULG069G:&%N:7-T86XG75LG
M,S(N,S8W.C8R+C$X,R==(#T@)T9A<F%H)SL*)&-O;W)D:6YA=&5S6R=!9F=H
M86YI<W1A;B==6R<S,RXT,#`Z-C(N,C@S)UT@/2`G4VAI;F1A;F0G.PHD8V]O
M<F1I;F%T97-;)T%F9VAA;FES=&%N)UU;)S,T+C(Q-SHV,BXR,3<G72`]("=(
M97)A="<["B1C;V]R9&EN871E<ULG069G:&%N:7-T86XG75LG,S0N-#,S.C<P
M+C0V-R==(#T@)TIA;&%L86)A9"<["B1C;V]R9&EN871E<ULG069G:&%N:7-T
M86XG75LG,S0N-C,S.C8Y+C(P,"==(#T@)TMA8G5L($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)T%F9VAA;FES=&%N)UU;)S,U+C$S,SHV.2XR-3`G72`]("=*
M86)U;"U387)A:B<["B1C;V]R9&EN871E<ULG069G:&%N:7-T86XG75LG,S8N
M-3`P.C<Q+C(U,"==(#T@)UIE8F%K)SL*)&-O;W)D:6YA=&5S6R=!9F=H86YI
M<W1A;B==6R<S-BXV-C<Z-C4N-S$W)UT@/2`G4VAE8FER9VAA;B<["B1C;V]R
M9&EN871E<ULG069G:&%N:7-T86XG75LG,S8N-S`P.C8W+C(P,"==(#T@)TUA
M>F%R+4DM4VAA<FEF)SL*)&-O;W)D:6YA=&5S6R=!9F=H86YI<W1A;B==6R<S
M-RXQ,3<Z-S`N-3$W)UT@/2`G1F%I>F%B860G.PHD8V]O<F1I;F%T97-;)T%L
M8F%N:6$G75LG-#$N,S,S.C$Y+C<X,R==(#T@)U1I<F%N82<["B1C;V]R9&EN
M871E<ULG06QG97)I82==6R<R-"XU-3`Z.2XT-C<G72`]("=$:F%N970G.PHD
M8V]O<F1I;F%T97-;)T%L9V5R:6$G75LG,C8N-3`P.C@N-#$W)UT@/2`G26QL
M:7II)SL*)&-O;W)D:6YA=&5S6R=!;&=E<FEA)UU;)S(W+C8V-SHM."XQ,S,G
M72`]("=4:6YD;W5F)SL*)&-O;W)D:6YA=&5S6R=!;&=E<FEA)UU;)S(W+C@X
M,SHM,"XR.#,G72`]("=!9')A<B<["B1C;V]R9&EN871E<ULG06QG97)I82==
M6R<R."XP-3`Z.2XV,S,G72`]("=);B!!;65N87,G.PHD8V]O<F1I;F%T97-;
M)T%L9V5R:6$G75LG,CDN,C4P.C`N,C@S)UT@/2`G5&EM:6UO=6XG.PHD8V]O
M<F1I;F%T97-;)T%L9V5R:6$G75LG,S`N-38W.C(N.#8W)UT@/2`G16P@1V]L
M96$G.PHD8V]O<F1I;F%T97-;)T%L9V5R:6$G75LG,S$N-C$W.BTR+C(S,R==
M(#T@)T)E8VAA<B<["B1C;V]R9&EN871E<ULG06QG97)I82==6R<S,2XV-C<Z
M-BXQ-3`G72`]("=(87-S:2U-97-S86]U9"<["B1C;V]R9&EN871E<ULG06QG
M97)I82==6R<S,2XY,3<Z-2XT,#`G72`]("=/=6%R9VQA)SL*)&-O;W)D:6YA
M=&5S6R=!;&=E<FEA)UU;)S,R+C,X,SHS+C@Q-R==(#T@)T=H87)D86EA)SL*
M)&-O;W)D:6YA=&5S6R=!;&=E<FEA)UU;)S,S+C$Q-SHV+C$S,R==(#T@)U1O
M=6=G;W5R="<["B1C;V]R9&EN871E<ULG06QG97)I82==6R<S,RXU,#`Z-BXQ
M,3<G72`]("=%;"!/=65D)SL*)&-O;W)D:6YA=&5S6R=!;&=E<FEA)UU;)S,S
M+C<V-SHR+CDS,R==(#T@)TQA9VAO=6%T)SL*)&-O;W)D:6YA=&5S6R=!;&=E
M<FEA)UU;)S,T+C8X,SHS+C(U,"==(#T@)T1J96QF82<["B1C;V]R9&EN871E
M<ULG06QG97)I82==6R<S-"XX,#`Z-2XW,S,G72`]("=":7-K<F$G.PHD8V]O
M<F1I;F%T97-;)T%L9V5R:6$G75LG,S0N.3,S.BTP+C0S,R==(#T@)TUE8VAE
M<FEA)SL*)&-O;W)D:6YA=&5S6R=!;&=E<FEA)UU;)S,U+C`Q-SHM,2XT-C<G
M72`]("=4;&5M8V5N(%IE;F%T82<["B1C;V]R9&EN871E<ULG06QG97)I82==
M6R<S-2XR,#`Z+3`N,3,S)UT@/2`G36%S8V%R82U':')I<W,G.PHD8V]O<F1I
M;F%T97-;)T%L9V5R:6$G75LG,S4N,C4P.C$N-#,S)UT@/2`G5&EA<F5T)SL*
M)&-O;W)D:6YA=&5S6R=!;&=E<FEA)UU;)S,U+C,S,SHT+C(P,"==(#T@)T)O
M=2U386%D82<["B1C;V]R9&EN871E<ULG06QG97)I82==6R<S-2XT.#,Z."XQ
M,S,G72`]("=496)E<W-A)SL*)&-O;W)D:6YA=&5S6R=!;&=E<FEA)UU;)S,U
M+C4U,#HV+C$X,R==(#T@)T)A=&YA)SL*)&-O;W)D:6YA=&5S6R=!;&=E<FEA
M)UU;)S,U+C8S,SHM,"XV,#`G72`]("=/<F%N("\@17,@4V5N:6$G.PHD8V]O
M<F1I;F%T97-;)T%L9V5R:6$G75LG,S8N,3@S.C4N-#$W)UT@/2`G4V5T:68G
M.PHD8V]O<F1I;F%T97-;)T%L9V5R:6$G75LG,S8N,C$W.C$N,S,S)UT@/2`G
M0VAL968G.PHD8V]O<F1I;F%T97-;)T%L9V5R:6$G75LG,S8N,C@S.C8N-C$W
M)UT@/2`G0V]N<W1A;G1I;F4G.PHD8V]O<F1I;F%T97-;)T%L9V5R:6$G75LG
M,S8N-S$W.C,N,C4P)UT@/2`G1&%R+45L+4)E:61A)SL*)&-O;W)D:6YA=&5S
M6R=!;&=E<FEA)UU;)S,V+C<Q-SHU+C`V-R==(#T@)T)E:F%I82<["B1C;V]R
M9&EN871E<ULG06QG97)I82==6R<S-BXX,S,Z-RXX,3<G72`]("=!;FYA8F$G
M.PHD8V]O<F1I;F%T97-;)T%L9V5R:6$G75LG,S8N.#@S.C4N.#$W)UT@/2`G
M2FEJ96P@06-H;W5A="<["B1C;V]R9&EN871E<ULG06QG97)I82==6R<S-BXY
M,S,Z-BXY-3`G72`]("=3:VEK9&$G.PHD8V]O<F1I;F%T97-;)T%N9V]L82==
M6R<M,3(N,S@S.C$V+CDU,"==(#T@)T)I92!3:6QV82!0;W)T;R<["B1C;V]R
M9&EN871E<ULG06YG;VQA)UU;)RTQ,BXU.#,Z,3,N-#$W)UT@/2`G36]N8F%C
M82!"96YG=65L82<["B1C;V]R9&EN871E<ULG06YG;VQA)UU;)RTQ,BXX,#`Z
M,34N-S4P)UT@/2`G2'5A;6)O($YO=F$@3&ES8F]A)SL*)&-O;W)D:6YA=&5S
M6R=!;F=O;&$G75LG+34N-34P.C$R+C$X,R==(#T@)T-A8FEN9&$G.PHD8V]O
M<F1I;F%T97-;)T%N9V]L82==6R<M."XX-3`Z,3,N,C,S)UT@/2`G3'5A;F1A
M)SL*)&-O;W)D:6YA=&5S6R=!;G1A<F-T:6-A)UU;)RTW-RXX-C<Z,38V+CDV
M-R==(#T@)U=I;&QI86US($9I96QD)SL*)&-O;W)D:6YA=&5S6R=!;G1A<F-T
M:6-A)UU;)RTY,"XP,#`Z,"XP,#`G72`]("=!;75N9'-E;BU38V]T="!3;W5T
M:"!0;VQE(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)T%N=&EG=6$@86YD($)A
M<F)U9&$G75LG,3<N,3$W.BTV,2XW.#,G72`]("=68R!":7)D($EN=&5R;F%T
M:6]N86P@06ER<&]R="!!;G1I9W5A)SL*)&-O;W)D:6YA=&5S6R=!;G1I9W5A
M(&%N9"!"87)B=61A)UU;)S$W+C(P,#HM-C(N-3@S)UT@/2`G0VAA<FQE<W1O
M=VX@+R!.97=C87-T)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3(R
M+C$P,#HM-C4N-C`P)UT@/2`G3&$@475I86-A($]B<V5R=F%T;W)I;R<["B1C
M;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTR,BXV-3`Z+38S+C@Q-R==(#T@
M)U1A<G1A9V%L($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA
M)UU;)RTR,RXQ-3`Z+38T+C,Q-R==(#T@)T]R86X@065R;V1R;VUE)SL*)&-O
M;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3(T+C$V-SHM-C(N.3`P)UT@/2`G
M4FEV861A=FEA)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3(T+C,X
M,SHM-C4N,#@S)UT@/2`G2G5J=7D@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S
M6R=!<F=E;G1I;F$G75LG+3(T+C<P,#HM-C`N-3@S)UT@/2`G3&%S($QO;6ET
M87,G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,C0N.#4P.BTV-2XT
M.#,G72`]("=386QT82!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N
M=&EN82==6R<M,C4N-S,S.BTU-"XT-C<G72`]("=)9W5A>G4@065R;V1R;VUE
M)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3(V+C(P,#HM-3@N,C,S
M)UT@/2`G1F]R;6]S82!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N
M=&EN82==6R<M,C8N.#$W.BTV,"XT-3`G72`]("=0<F5S:61E;F-I82!2;W%U
M92!3865N>B!096YA($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT
M:6YA)UU;)RTR-BXX-3`Z+38U+C$P,"==(#T@)U1U8W5M86X@065R;V1R;VUE
M)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3(W+C,V-SHM-34N.38W
M)UT@/2`G4&]S861A<R!!97)O+B<["B1C;V]R9&EN871E<ULG07)G96YT:6YA
M)UU;)RTR-RXT-3`Z+34X+C<V-R==(#T@)T-O<G)I96YT97,@065R;RXG.PHD
M8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,C<N-#4P.BTU.2XP-3`G72`]
M("=297-I<W1E;F-I82!!97)O+B<["B1C;V]R9&EN871E<ULG07)G96YT:6YA
M)UU;)RTR-RXW-C<Z+38T+C,P,"==(#T@)U-A;G1I86=O($1E;"!%<W1E<F\@
M065R;RXG.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,C@N,#8W.BTV
M-RXU-C<G72`]("=4:6YO9V%S=&$G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN
M82==6R<M,C@N-C`P.BTV-2XW-C<G72`]("=#871A;6%R8V$@065R;RXG.PHD
M8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,CDN,C$W.BTV-RXT,S,G72`]
M("=#:&EL96-I=&\G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,CDN
M,S@S.BTV-BXX,3<G72`]("=,82!2:6]J82!!97)O+B<["B1C;V]R9&EN871E
M<ULG07)G96YT:6YA)UU;)RTR.2XV.#,Z+34W+C$U,"==(#T@)U!A<V\@1&4@
M3&]S($QI8G)E<R!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN
M82==6R<M,CDN-S@S.BTU-RXY.#,G72`]("=#=7)U>G4@0W5A=&EA($%E<F]D
M<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTR.2XX.#,Z+38Q
M+CDU,"==(#T@)T-E<F5S($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G
M96YT:6YA)UU;)RTR.2XY,#`Z+38S+C8X,R==(#T@)U9I;&QA($1E($UA<FEA
M($1E;"!2:6\@4V5C;R<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS
M,"XR-3`Z+38X+C<U,"==(#T@)TIA8VAA;"<["B1C;V]R9&EN871E<ULG07)G
M96YT:6YA)UU;)RTS,"XR-C<Z+34W+C8U,"==(#T@)TUO;G1E($-A<V5R;W,@
M065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,Q+C,P
M,#HM-3@N,#$W)UT@/2`G0V]N8V]R9&EA($%E<F]D<F]M92<["B1C;V]R9&EN
M871E<ULG07)G96YT:6YA)UU;)RTS,2XS,3<Z+38T+C(Q-R==(#T@)T-O<F1O
M8F$@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,Q
M+C,S,SHM-C8N-C`P)UT@/2`G0VAE<&5S)SL*)&-O;W)D:6YA=&5S6R=!<F=E
M;G1I;F$G75LG+3,Q+C4V-SHM-C@N.#8W)UT@/2`G4V%N($IU86X@065R;V1R
M;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,Q+C8V-SHM-C,N
M.#@S)UT@/2`G4&EL87(@3V)S97)V871O<FEO)SL*)&-O;W)D:6YA=&5S6R=!
M<F=E;G1I;F$G75LG+3,Q+C<P,#HM-C`N.#$W)UT@/2`G4V%U8V4@5FEE:F\@
M065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,Q+C<X
M,SHM-C`N-#@S)UT@/2`G4&%R86YA($%E<F]D<F]M92<["B1C;V]R9&EN871E
M<ULG07)G96YT:6YA)UU;)RTS,2XX-3`Z+34Y+C`X,R==(#T@)U9I;&QA9W5A
M>2!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S$N
M.34P.BTV-2XQ,S,G72`]("=6:6QL82!$;VQO<F5S($%E<F]D<F]M92<["B1C
M;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS,BXV,#`Z+38Y+C,S,R==(#T@
M)U5S<&%L;&%T82<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS,BXW
M,#`Z+38R+C$U,"==(#T@)TUA<F-O<R!*=6%R97H@065R;V1R;VUE)SL*)&-O
M;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,R+C@S,SHM-C@N-S@S)UT@/2`G
M365N9&]Z82!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==
M6R<M,S(N.3$W.BTV,"XW.#,G72`]("=2;W-A<FEO($%E<F]D<F]M92<["B1C
M;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS,RXP,#`Z+34X+C8Q-R==(#T@
M)T=U86QE9W5A>6-H=2!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N
M=&EN82==6R<M,S,N,#@S.BTV."XT,3<G72`]("=386X@36%R=&EN)SL*)&-O
M;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,S+C$Q-SHM-C0N,C,S)UT@/2`G
M4FEO($-U87)T;R!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN
M82==6R<M,S,N,C8W.BTV-BXS-3`G72`]("=386X@3'5I<R!!97)O9')O;64G
M.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S,N-S,S.BTV-2XS.#,G
M72`]("=6:6QL82!297EN;VQD<R!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;
M)T%R9V5N=&EN82==6R<M,S,N-S8W.BTV.2XP,S,G72`]("=386X@0V%R;&]S
M)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,T+C$S,SHM-C,N,S8W
M)UT@/2`G3&%B;W5L87EE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG
M+3,T+C0X,SHM-3@N-C$W)UT@/2`G1&]N(%1O<F-U871O($%E<F]D<F]M92<[
M"B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS-"XU-3`Z+38P+CDQ-R==
M(#T@)TIU;FEN($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA
M)UU;)RTS-"XU-C<Z+34X+C0Q-R==(#T@)T%E<F]P87)Q=64@0G,N($%S+B!!
M97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S0N-3@S
M.BTU."XT.#,G72`]("="=65N;W,@06ER97,@3V)S97)V871O<FEO)SL*)&-O
M;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,T+C4X,SHM-C@N-#`P)UT@/2`G
M4V%N(%)A9F%E;"!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN
M82==6R<M,S0N-C`P.BTU."XV,#`G72`]("=%;"!086QO;6%R($%E<F]D<F]M
M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS-"XX,3<Z+34X+C4S
M,R==(#T@)T5Z96EZ82!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N
M=&EN82==6R<M,S0N.38W.BTU-RXY,#`G72`]("=,82!0;&%T82!!97)O9')O
M;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S4N-3`P.BTV.2XU
M.#,G72`]("=-86QA<F=U92!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R
M9V5N=&EN82==6R<M,S4N-S`P.BTV,RXW-3`G72`]("='96YE<F%L(%!I8V\@
M065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,U+C@V
M-SHM-C$N.3`P)UT@/2`G4&5H=6%J;R!!97)O9')O;64G.PHD8V]O<F1I;F%T
M97-;)T%R9V5N=&EN82==6R<M,S8N,S4P.BTU-RXW,S,G72`]("=$;VQO<F5S
M($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS-BXU
M-C<Z+38T+C(V-R==(#T@)U-A;G1A(%)O<V$@065R;V1R;VUE)SL*)&-O;W)D
M:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,V+C<U,#HM-3DN.#,S)UT@/2`G07IU
M;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,W+C(S
M,SHM-3<N,#,S)UT@/2`G5FEL;&$@1V5S96QL)SL*)&-O;W)D:6YA=&5S6R=!
M<F=E;G1I;F$G75LG+3,W+C(S,SHM-3DN,C4P)UT@/2`G5&%N9&EL($%E<F]D
M<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS-RXV,#`Z+38R
M+C,X,R==(#T@)U!I9W5E($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G
M96YT:6YA)UU;)RTS-RXY,S,Z+34W+C4X,R==(#T@)TUA<B!$96P@4&QA=&$@
M065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,X+C,S
M,SHM-C`N,C4P)UT@/2`G5')E<R!!<G)O>6]S)SL*)&-O;W)D:6YA=&5S6R=!
M<F=E;G1I;F$G75LG+3,X+C<S,SHM-C(N,38W)UT@/2`G0F%H:6$@0FQA;F-A
M($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS."XY
M-3`Z+38X+C$S,R==(#T@)TYE=7%U96X@065R;V1R;VUE)SL*)&-O;W)D:6YA
M=&5S6R=!<F=E;G1I;F$G75LG+3,Y+C`Q-SHM-C0N,#@S)UT@/2`G4FEO($-O
M;&]R861O)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+30P+C`X,SHM
M-S$N,3,S)UT@/2`G0VAA<&5L8V\G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN
M82==6R<M-#`N-S@S.BTV-2XQ,#`G72`]("=386X@06YT;VYI;R!/97-T92!!
M97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M-#`N.#4P
M.BTV,RXP,3<G72`]("=6:65D;6$@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S
M6R=!<F=E;G1I;F$G75LG+30Q+C$U,#HM-S$N,38W)UT@/2`G0F%R:6QO8VAE
M($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTT,2XY
M-C<Z+3<Q+C4Q-R==(#T@)T5L($)O;'-O;B!!97)O9')O;64G.PHD8V]O<F1I
M;F%T97-;)T%R9V5N=&EN82==6R<M-#(N.3,S.BTW,2XQ-3`G72`]("=%<W%U
M96P@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+30S
M+C(P,#HM-C4N,C8W)UT@/2`G5')E;&5W($%E<F]D<F]M92<["B1C;V]R9&EN
M871E<ULG07)G96YT:6YA)UU;)RTT,RXX,3<Z+38X+C@X,R==(#T@)U!A<V\@
M1&4@26YD:6]S)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+30U+C<X
M,SHM-C<N-3`P)UT@/2`G0V]M;V1O<F\@4FEV861A=FEA($%E<F]D<F]M92<[
M"B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTT-BXU,3<Z+3<Q+C`Q-R==
M(#T@)U!E<FET;R!-;W)E;F\@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!
M<F=E;G1I;F$G75LG+30W+C<S,SHM-C4N.3$W)UT@/2`G4'5E<G1O($1E<V5A
M9&\@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+30X
M+C<X,SHM-S`N,38W)UT@/2`G1V]B97)N861O<B!'<F5G;W)E<R!!97)O9')O
M;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M-#DN,S$W.BTV-RXW
M-3`G72`]("=386X@2G5L:6%N($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG
M07)G96YT:6YA)UU;)RTU,"XP,3<Z+38X+C4V-R==(#T@)U-A;G1A($-R=7H@
M065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+34P+C,S
M,SHM-S(N,S`P)UT@/2`G3&%G;R!!<F=E;G1I;F\@065R;V1R;VUE)SL*)&-O
M;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+34Q+C8Q-SHM-CDN,C@S)UT@/2`G
M4FEO($=A;&QE9V]S($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT
M:6YA)UU;)RTU,RXX,#`Z+38W+C<U,"==(#T@)U)I;R!'<F%N9&4@0BX@02XG
M.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M-30N.#`P.BTV."XS,3<G
M72`]("=5<VAU86EA($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)M96YI
M82==6R<T,"XQ,S,Z-#0N-#8W)UT@/2`G665R979A;B<["B1C;V]R9&EN871E
M<ULG07)U8F$G75LG,3(N-3`P.BTW,"XP,3<G72`]("=1=65E;B!"96%T<FEX
M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,3(N,C8W
M.C$S-BXX,3<G72`]("=';W9E($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T%U
M<W1R86QI82==6R<M,3(N-#`P.C$S,"XX-C<G72`]("=$87)W:6X@06ER<&]R
M="<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTQ,BXV,S,Z,30Q+C@X
M,R==(#T@)U=E:7!A($-I='DG.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==
M6R<M,34N-S8W.C$R."XW,#`G72`]("=+=6YU;G5R<F$@2W5N=6YU<G)A($%W
M<R<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTQ-BXX.#,Z,30U+C<U
M,"==(#T@)T-A:7)N<R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L
M:6$G75LG+3$W+C,P,#HQ,C,N-C$W)UT@/2`G1&5R8GDG.PHD8V]O<F1I;F%T
M97-;)T%U<W1R86QI82==6R<M,3<N.34P.C$R,BXR,3<G72`]("="<F]O;64@
M06ER<&]R="<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTQ.2XR-3`Z
M,30V+C<U,"==(#T@)U1O=VYS=FEL;&4@06UO)SL*)&-O;W)D:6YA=&5S6R=!
M=7-T<F%L:6$G75LG+3$Y+C8S,SHQ,S0N,38W)UT@/2`G5&5N;F%N="!#<F5E
M:R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3(P+C$P
M,#HQ,3DN-38W)UT@/2`G4&]R="!(961L86YD(%!A<F1O;R<["B1C;V]R9&EN
M871E<ULG075S=')A;&EA)UU;)RTR,"XT.#,Z,30X+C4S,R==(#T@)U!R;W-E
M<G!I;F4@06ER<&]R="<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTR
M,"XV-C<Z,3,Y+C0V-R==(#T@)TUO=6YT($ES82!!;6\G.PHD8V]O<F1I;F%T
M97-;)T%U<W1R86QI82==6R<M,C$N,3$W.C$T.2XR,#`G72`]("=-86-K87D@
M36\G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,C(N,C,S.C$Q-"XP
M.#,G72`]("=,96%R;6]N=&@@06ER<&]R="<["B1C;V]R9&EN871E<ULG075S
M=')A;&EA)UU;)RTR,RXS.#,Z,34P+C0V-R==(#T@)U)O8VMH86UP=&]N($%I
M<G!O<G0G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,C,N-#,S.C$T
M-"XR-C<G72`]("=,;VYG<F5A8V@@06ER<&]R="<["B1C;V]R9&EN871E<ULG
M075S=')A;&EA)UU;)RTR,RXX,#`Z,3,S+C@X,R==(#T@)T%L:6-E(%-P<FEN
M9W,@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3(S
M+C@U,#HQ-3$N,C4P)UT@/2`G1VQA9'-T;VYE)SL*)&-O;W)D:6YA=&5S6R=!
M=7-T<F%L:6$G75LG+3(U+C$X,SHQ,S`N.38W)UT@/2`G675L87)A($%W<R<[
M"B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTR-BXT,#`Z,30V+C(V-R==
M(#T@)T-H87)L979I;&QE($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T%U<W1R
M86QI82==6R<M,C8N-C`P.C$Q."XU,S,G72`]("=-965K871H87)R82!!:7)P
M;W)T)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3(W+C,X,SHQ-3,N
M,3`P)UT@/2`G0G)I<V)A;F4@06ER<&]R="!-+B!/)SL*)&-O;W)D:6YA=&5S
M6R=!=7-T<F%L:6$G75LG+3(W+C0Q-SHQ-3$N-S,S)UT@/2`G3V%K97D@065R
M;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3(W+C4V-SHQ
M-3,N,#`P)UT@/2`G07)C:&5R9FEE;&0@065R;V1R;VUE)SL*)&-O;W)D:6YA
M=&5S6R=!=7-T<F%L:6$G75LG+3(W+C8S,SHQ-3(N-S$W)UT@/2`G06UB97)L
M97D@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3(X
M+C$V-SHQ-3,N-3`P)UT@/2`G0V]O;&%N9V%T=&$@06ER<&]R="!!=W,G.PHD
M8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,C@N-S@S.C$Q-"XW,#`G72`]
M("='97)A;&1T;VX@06ER<&]R="<["B1C;V]R9&EN871E<ULG075S=')A;&EA
M)UU;)RTR.2XP,S,Z,38W+CDS,R==(#T@)TYO<F9O;&L@27-L86YD($%I<G!O
M<G0G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,S`N,S$W.C$U,RXQ
M,3<G72`]("=#;V9F<R!(87)B;W5R($UO)SL*)&-O;W)D:6YA=&5S6R=!=7-T
M<F%L:6$G75LG+3,P+C4X,SHQ,S@N-#$W)UT@/2`G3&5I9V@@0W)E96L@06ER
M<&]R="<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTS,"XW.#,Z,3(Q
M+C0U,"==(#T@)TMA;&=O;W)L:64@0F]U;&1E<B!!;6\G.PHD8V]O<F1I;F%T
M97-;)T%U<W1R86QI82==6R<M,S`N.#,S.C$R."XQ,#`G72`]("=&;W)R97-T
M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,S$N,#@S
M.C$U,"XX,S,G72`]("=486UW;W)T:"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S
M6R=!=7-T<F%L:6$G75LG+3,Q+C$S,SHQ,S8N.#$W)UT@/2`G5V]O;65R82!!
M97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,S$N-C8W
M.C$Q-BXP,3<G72`]("="=6QL<V)R;V]K(%!E87)C92!!;6\G.PHD8V]O<F1I
M;F%T97-;)T%U<W1R86QI82==6R<M,S$N.3,S.C$Q-2XY-3`G72`]("="96QM
M;VYT(%!E<G1H($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==
M6R<M,S$N.38W.C$T,2XT-C<G72`]("="<F]K96X@2&EL;"!0871T;VX@4W1R
M965T)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3,R+C$Q-SHQ,S,N
M-S`P)UT@/2`G0V5D=6YA($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T%U<W1R
M86QI82==6R<M,S(N,C`P.C$T."XU-C<G72`]("=$=6)B;R<["B1C;V]R9&EN
M871E<ULG075S=')A;&EA)UU;)RTS,BXW.#,Z,34Q+C@Q-R==(#T@)U=I;&QI
M86UT;W=N($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;
M)RTS,RXV,#`Z,34P+C<X,R==(#T@)U)I8VAM;VYD($%U<RU!9F(G.PHD8V]O
M<F1I;F%T97-;)T%U<W1R86QI82==6R<M,S,N.3$W.C$U,"XY.#,G72`]("="
M86YK<W1O=VX@06ER<&]R="!!=W,G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI
M82==6R<M,S,N.34P.C$U,2XQ.#,G72`]("=3>61N97D@06ER<&]R="<["B1C
M;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTS-"XP,S,Z,34P+C8X,R==(#T@
M)T-A;61E;B!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG
M+3,T+C(Q-SHQ-#(N,#@S)UT@/2`G36EL9'5R82!!:7)P;W)T)SL*)&-O;W)D
M:6YA=&5S6R=!=7-T<F%L:6$G75LG+3,T+C<P,#HQ,S@N-C$W)UT@/2`G161I
M;F)U<F=H($TN($\N)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3,T
M+C<X,SHQ,S@N-C,S)UT@/2`G4&%R869I96QD($%I<G!O<G0G.PHD8V]O<F1I
M;F%T97-;)T%U<W1R86QI82==6R<M,S0N.3,S.C$Q-RXX,#`G72`]("=!;&)A
M;GD@06ER<&]R="<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTS-"XY
M,S,Z,3,X+C4Q-R==(#T@)T%D96QA:61E($%I<G!O<G0G.PHD8V]O<F1I;F%T
M97-;)T%U<W1R86QI82==6R<M,S0N.34P.C$U,"XU,S,G72`]("=.;W=R82!2
M86X@06ER(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M
M,S4N,34P.C$T-RXT-3`G72`]("=786=G82!!:7)P;W)T)SL*)&-O;W)D:6YA
M=&5S6R=!=7-T<F%L:6$G75LG+3,U+C,P,#HQ-#DN,3@S)UT@/2`G0V%N8F5R
M<F$G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,S8N,#8W.C$T-BXY
M-3`G72`]("=!;&)U<GD@06ER<&]R="<["B1C;V]R9&EN871E<ULG075S=')A
M;&EA)UU;)RTS-BXR,S,Z,30Y+C`X,R==(#T@)T-O;VUA)SL*)&-O;W)D:6YA
M=&5S6R=!=7-T<F%L:6$G75LG+3,W+C8V-SHQ-#0N.#,S)UT@/2`G365L8F]U
M<FYE($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,S<N
M-S,S.C$T,"XW.#,G72`]("=-;W5N="!'86UB:65R($%E<F]D<F]M92<["B1C
M;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTS-RXW,S,Z,30U+C0P,"==(#T@
M)T=O;&1S=')E86T@07=S)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG
M+3,W+C@U,#HQ-#0N-S,S)UT@/2`G3&%V97)T;VX@065R;V1R;VUE)SL*)&-O
M;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3,W+CDV-SHQ-#4N,3`P)UT@/2`G
M36]O<F%B8FEN($%I<G!O<G0@07=S)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L
M:6$G75LG+3,X+C$P,#HQ-#<N,3,S)UT@/2`G16%S="!386QE($%E<F]D<F]M
M92<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTT,"XY.#,Z,30U+C<Q
M-R==(#T@)U=Y;GEA<F0@5V5S="<["B1C;V]R9&EN871E<ULG075S=')A;&EA
M)UU;)RTT,2XQ-C<Z,30V+C,V-R==(#T@)T1E=F]N<&]R="!%87-T)SL*)&-O
M;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+30Q+C4S,SHQ-#<N,C`P)UT@/2`G
M3&%U;F-E<W1O;B!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G
M75LG+30R+C@S,SHQ-#<N-#@S)UT@/2`G2&]B87)T($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)T%U<W1R86QI82==6R<M-30N-#@S.C$U."XY-3`G72`]("=-
M86-Q=6%R:64@27-L86YD)SL*)&-O;W)D:6YA=&5S6R=!=7-T<FEA)UU;)S0V
M+C8U,#HQ-"XS,S,G72`]("=+;&%G96YF=7)T+49L=6=H869E;B<["B1C;V]R
M9&EN871E<ULG075S=')I82==6R<T-RXP,#`Z,34N-#,S)UT@/2`G1W)A>BU4
M:&%L97)H;V8M1FQU9VAA9F5N)SL*)&-O;W)D:6YA=&5S6R=!=7-T<FEA)UU;
M)S0W+C(P,#HQ-"XW-3`G72`]("=:96QT=V5G)SL*)&-O;W)D:6YA=&5S6R=!
M=7-T<FEA)UU;)S0W+C(V-SHQ,2XS-3`G72`]("=);FYS8G)U8VLM1FQU9VAA
M9F5N)SL*)&-O;W)D:6YA=&5S6R=!=7-T<FEA)UU;)S0W+C,S,SHQ,2XW,#`G
M72`]("=38VAW87H@2&5L:7!O<G0G.PHD8V]O<F1I;F%T97-;)T%U<W1R:6$G
M75LG-#<N-3,S.C$T+C$S,R==(#T@)T%I9V5N($EM($5N;G-T86PG.PHD8V]O
M<F1I;F%T97-;)T%U<W1R:6$G75LG-#<N.#`P.C$S+C`P,"==(#T@)U-A;'IB
M=7)G+49L=6=H869E;B<["B1C;V]R9&EN871E<ULG075S=')I82==6R<T-RXY
M-C0Z,38N,C4Y)UT@/2`G3FEE9&5R;W-T97)R96EC:"`O($QU9W!L871Z("!6
M;W-L874G.PHD8V]O<F1I;F%T97-;)T%U<W1R:6$G75LG-#@N,3$W.C$V+C4V
M-R==(#T@)U=I96X@+R!38VAW96-H870M1FQU9VAA9F5N)SL*)&-O;W)D:6YA
M=&5S6R=!=7-T<FEA)UU;)S0X+C(S,SHQ-"XQ.#,G72`]("=(;W)S8VAI;F<@
M075S+4%F8B<["B1C;V]R9&EN871E<ULG075S=')I82==6R<T."XR,S,Z,30N
M,3@S)UT@/2`G3&EN>B`O($AO97)S8VAI;F<M1FQU9VAA9F5N)SL*)&-O;W)D
M:6YA=&5S6R=!=7-T<FEA)UU;)S0X+C,Q-SHQ-BXQ,3<G72`]("=4=6QL;B<[
M"B1C;V]R9&EN871E<ULG07IE<F)A:6IA;B==6R<T,"XT-3`Z-3`N,#8W)UT@
M/2`G0F%K=2`O($)I;F4@06ER<&]R="<["B1C;V]R9&EN871E<ULG0F%H86UA
M<R==6R<R,"XY-3`Z+3<S+C8X,R==(#T@)TUA='1H97<@5&]W;BP@26YA9W5A
M)SL*)&-O;W)D:6YA=&5S6R="86AA;6%S)UU;)S(S+C0W-3HM-S4N-S8W)UT@
M/2`G1V5O<F=E=&]W;BP@17AU;6$G.PHD8V]O<F1I;F%T97-;)T)A:&%M87,G
M75LG,C0N,#4P.BTW-"XU,S,G72`]("=#;V-K8G5R;B!4;W=N+"!386X@4V%L
M=F%D;W(G.PHD8V]O<F1I;F%T97-;)T)A:&%M87,G75LG,C4N,#4P.BTW-RXT
M-C<G72`]("=.87-S874@06ER<&]R="<["B1C;V]R9&EN871E<ULG0F%H86UA
M<R==6R<R-2XW,S,Z+3<Y+C,P,"==(#T@)T%L:6-E(%1O=VXL($)I;6EN:2<[
M"B1C;V]R9&EN871E<ULG0F%H86UA<R==6R<R-BXU-3`Z+3<X+C<P,"==(#T@
M)T9R965P;W)T+"!'<F%N9"!"86AA;6$G.PHD8V]O<F1I;F%T97-;)T)A:&%M
M87,G75LG,C8N-S`P.BTW."XY-C<G72`]("=797-T($5N9"P@1W)A;F0@0F%H
M86UA)SL*)&-O;W)D:6YA=&5S6R="86AR86EN)UU;)S(V+C(V-SHU,"XV-3`G
M72`]("="86AR86EN($EN=&5R;F%T:6]N86P@06ER<&]R="<["B1C;V]R9&EN
M871E<ULG0F%N9VQA9&5S:"==6R<R,2XT,S,Z.3$N.38W)UT@/2`G0V]X7"=S
M($)A>F%R)SL*)&-O;W)D:6YA=&5S6R="86YG;&%D97-H)UU;)S(R+C(V-SHY
M,2XX,3<G72`]("=#:&ET=&%G;VYG(%!A=&5N9V$G.PHD8V]O<F1I;F%T97-;
M)T)A;F=L861E<V@G75LG,C,N,3@S.C@Y+C$V-R==(#T@)TIE<W-O<F4G.PHD
M8V]O<F1I;F%T97-;)T)A;F=L861E<V@G75LG,C,N-S8W.CDP+C,X,R==(#T@
M)T1H86MA)SL*)&-O;W)D:6YA=&5S6R="86YG;&%D97-H)UU;)S(S+C@U,#HY
M,"XT,#`G72`]("=+=7)M:71O;&$L($1I82<["B1C;V]R9&EN871E<ULG0F%N
M9VQA9&5S:"==6R<R-"XQ,S,Z.#DN,#4P)UT@/2`G27-H=7)D:2<["B1C;V]R
M9&EN871E<ULG0F%N9VQA9&5S:"==6R<R-"XS-C<Z.#@N-S`P)UT@/2`G4F%J
M<VAA:&DG.PHD8V]O<F1I;F%T97-;)T)A;F=L861E<V@G75LG,C0N.3`P.CDQ
M+C@X,R==(#T@)U-Y;&AE="<["B1C;V]R9&EN871E<ULG0F%R8F%D;W,G75LG
M,3,N,#8W.BTU.2XT.#,G72`]("='<F%N=&QE>2!!9&%M<R<["B1C;V]R9&EN
M871E<ULG0F5L87)U<R==6R<U,RXY,S,Z,C<N-C,S)UT@/2`G36EN<VLG.PHD
M8V]O<F1I;F%T97-;)T)E;&%R=7,G75LG-34N,38W.C,P+C(Q-R==(#T@)U9I
M=&5B<VLG.PHD8V]O<F1I;F%T97-;)T)E;&=I=6TG75LG-#DN.3`P.C4N,C$W
M)UT@/2`G0F5R=')I>"!"96PM069B)SL*)&-O;W)D:6YA=&5S6R="96QG:75M
M)UU;)S4P+C`S,SHU+C0P,"==(#T@)U-T+4AU8F5R="<["B1C;V]R9&EN871E
M<ULG0F5L9VEU;2==6R<U,"XR,S,Z-"XV-3`G72`]("=&;&]R96YN97,G.PHD
M8V]O<F1I;F%T97-;)T)E;&=I=6TG75LG-3`N-#8W.C0N-#4P)UT@/2`G0VAA
M<FQE<F]I("\@1V]S<V5L:65S)SL*)&-O;W)D:6YA=&5S6R="96QG:75M)UU;
M)S4P+C0V-SHV+C$X,R==(#T@)T5L<V5N8F]R;B<["B1C;V]R9&EN871E<ULG
M0F5L9VEU;2==6R<U,"XT.#,Z-2XY,3<G72`]("=3<&$@+R!,82!3875V96YI
M97)E)SL*)&-O;W)D:6YA=&5S6R="96QG:75M)UU;)S4P+C4V-SHS+C@S,R==
M(#T@)T-H:65V<F5S)SL*)&-O;W)D:6YA=&5S6R="96QG:75M)UU;)S4P+C8U
M,#HU+C0U,"==(#T@)T)I97)S970G.PHD8V]O<F1I;F%T97-;)T)E;&=I=6TG
M75LG-3`N-S4P.C0N-S8W)UT@/2`G0F5A=79E8VAA:6XG.PHD8V]O<F1I;F%T
M97-;)T)E;&=I=6TG75LG-3`N-S@S.C0N.34P)UT@/2`G1V]E='-E;FAO=F5N
M)SL*)&-O;W)D:6YA=&5S6R="96QG:75M)UU;)S4P+C@P,#HU+C(P,"==(#T@
M)U-I;G0M5')U:61E;B<["B1C;V]R9&EN871E<ULG0F5L9VEU;2==6R<U,"XY
M,#`Z-"XU,#`G72`]("=-96QS8G)O96L@0F5L+4%F8B<["B1C;V]R9&EN871E
M<ULG0F5L9VEU;2==6R<U,"XY,#`Z-"XU,S,G72`]("="<G5X96QL97,@3F%T
M:6]N86PG.PHD8V]O<F1I;F%T97-;)T)E;&=I=6TG75LG-3`N.3,S.C,N-S,S
M)UT@/2`G375N=&4G.PHD8V]O<F1I;F%T97-;)T)E;&=I=6TG75LG-3`N.3,S
M.C4N-3`P)UT@/2`G1V5N:R<["B1C;V]R9&EN871E<ULG0F5L9VEU;2==6R<U
M,2XP,#`Z-2XP-C<G72`]("=38VAA9F9E;B<["B1C;V]R9&EN871E<ULG0F5L
M9VEU;2==6R<U,2XP.#,Z,BXV-3`G72`]("=+;VMS:6ID92<["B1C;V]R9&EN
M871E<ULG0F5L9VEU;2==6R<U,2XQ-C<Z-2XT-C<G72`]("=+;&5I;F4@0G)O
M9V5L)SL*)&-O;W)D:6YA=&5S6R="96QG:75M)UU;)S4Q+C$X,SHS+C@Q-R==
M(#T@)T=E;G0@+R!);F1U<W1R:64M6F]N92<["B1C;V]R9&EN871E<ULG0F5L
M9VEU;2==6R<U,2XR,#`Z,BXX-C<G72`]("=/;W-T96YD92!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R="96QG:75M)UU;)S4Q+C(P,#HT+C0V-R==(#T@)T%N
M='=E<G!E;B`O($1E=7)N92<["B1C;V]R9&EN871E<ULG0F5L9VEU;2==6R<U
M,2XS,S,Z-"XU,#`G72`]("="<F%S<V-H86%T)SL*)&-O;W)D:6YA=&5S6R="
M96QG:75M)UU;)S4Q+C0Q-SHU+C`P,"==(#T@)U=E96QD92!-:6QI=&%R>2<[
M"B1C;V]R9&EN871E<ULG0F5L:7IE)UU;)S$W+C4S,SHM.#@N,S`P)UT@/2`G
M0F5L:7IE("\@4&AI;&QI<"!';VQD<W1O;B!);G1L+B!!:7)P;W)T)SL*)&-O
M;W)D:6YA=&5S6R="96YI;B==6R<Q,"XS,3<Z,2XS.#,G72`]("=.871I=&EN
M9V]U)SL*)&-O;W)D:6YA=&5S6R="96YI;B==6R<Q,2XQ,S,Z,BXY,S,G72`]
M("=+86YD:2<["B1C;V]R9&EN871E<ULG0F5N:6XG75LG-BXS-3`Z,BXS.#,G
M72`]("=#;W1O;F]U)SL*)&-O;W)D:6YA=&5S6R="96YI;B==6R<W+C$V-SHR
M+C`V-R==(#T@)T)O:&EC;VXG.PHD8V]O<F1I;F%T97-;)T)E;FEN)UU;)S@N
M,#,S.C(N-#8W)UT@/2`G4V%V92<["B1C;V]R9&EN871E<ULG0F5N:6XG75LG
M.2XS-3`Z,BXV,3<G72`]("=087)A:V]U)SL*)&-O;W)D:6YA=&5S6R="97)M
M=61A)UU;)S,R+C,V-SHM-C0N-C@S)UT@/2`G0F5R;75D82<["B1C;V]R9&EN
M871E<ULG0F]L:79I82==6R<M,3`N.#$W.BTV-2XS-3`G72`]("='=6%Y87)A
M;65R:6XG.PHD8V]O<F1I;F%T97-;)T)O;&EV:6$G75LG+3$Q+C`P,#HM-C8N
M,3$W)UT@/2`G4FEB97)A;'1A)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;
M)RTQ,2XP,S,Z+38X+C<X,R==(#T@)T-O8FEJ82<["B1C;V]R9&EN871E<ULG
M0F]L:79I82==6R<M,3,N,#8W.BTV-"XX,3<G72`]("=386X@2F]A<75I;B<[
M"B1C;V]R9&EN871E<ULG0F]L:79I82==6R<M,3,N,S,S.BTV-"XQ,3<G72`]
M("=-86=D86QE;F$G.PHD8V]O<F1I;F%T97-;)T)O;&EV:6$G75LG+3$S+C<V
M-SHM-C4N-#,S)UT@/2`G4V%N=&$@06YA)SL*)&-O;W)D:6YA=&5S6R=";VQI
M=FEA)UU;)RTQ-"XS,3<Z+38W+C,X,R==(#T@)U)E>65S)SL*)&-O;W)D:6YA
M=&5S6R=";VQI=FEA)UU;)RTQ-"XT-C<Z+38W+C4V-R==(#T@)U)U<G)E;F%B
M87%U92<["B1C;V]R9&EN871E<ULG0F]L:79I82==6R<M,30N-S,S.BTV."XU
M,#`G72`]("=!<&]L;R<["B1C;V]R9&EN871E<ULG0F]L:79I82==6R<M,30N
M.#$W.BTV-"XY,3<G72`]("=4<FEN:61A9"<["B1C;V]R9&EN871E<ULG0F]L
M:79I82==6R<M,30N.#8W.BTV-BXX-C<G72`]("=386X@0F]R:F$G.PHD8V]O
M<F1I;F%T97-;)T)O;&EV:6$G75LG+3$T+CDQ-SHM-C4N-C`P)UT@/2`G4V%N
M($EG;F%C:6\@1&4@36]X;W,G.PHD8V]O<F1I;F%T97-;)T)O;&EV:6$G75LG
M+3$U+C<Q-SHM-C,N,3`P)UT@/2`G07-C96YC:6]N($1E($=U87)A>6]S)SL*
M)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTQ-BXQ-3`Z+38R+C`Q-R==(#T@
M)T-O;F-E<&-I;VXG.PHD8V]O<F1I;F%T97-;)T)O;&EV:6$G75LG+3$V+C(V
M-SHM-C(N-#8W)UT@/2`G4V%N($IA=FEE<B<["B1C;V]R9&EN871E<ULG0F]L
M:79I82==6R<M,38N,S@S.BTV,"XY-C<G72`]("=386X@26=N86-I;R!$92!6
M96QA<V-O)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTQ-BXU,3<Z+38X
M+C$X,R==(#T@)TQA(%!A>B`O($%L=&\G.PHD8V]O<F1I;F%T97-;)T)O;&EV
M:6$G75LG+3$W+C0Q-SHM-C8N,3@S)UT@/2`G0V]C:&%B86UB82<["B1C;V]R
M9&EN871E<ULG0F]L:79I82==6R<M,3<N-3@S.BTV.2XV,#`G72`]("=#:&%R
M86YA)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTQ-RXV,S,Z+38S+C$S
M,R==(#T@)U9I<G4M5FER=2<["B1C;V]R9&EN871E<ULG0F]L:79I82==6R<M
M,3<N.#`P.BTV,"XW,S,G72`]("=386X@2F]S92!$92!#:&EQ=6ET;W,G.PHD
M8V]O<F1I;F%T97-;)T)O;&EV:6$G75LG+3$W+C@P,#HM-C,N,3@S)UT@/2`G
M4V%N=&$@0W)U>B`O($5L(%1R;VUP:6QL;R<["B1C;V]R9&EN871E<ULG0F]L
M:79I82==6R<M,3<N.38W.BTV-RXP-C<G72`]("=/<G5R;R<["B1C;V]R9&EN
M871E<ULG0F]L:79I82==6R<M,3@N,S$W.BTU.2XW-C<G72`]("=2;V)O<F4G
M.PHD8V]O<F1I;F%T97-;)T)O;&EV:6$G75LG+3$X+CDX,SHM-3<N.#$W)UT@
M/2`G4'5E<G1O(%-U87)E>B<["B1C;V]R9&EN871E<ULG0F]L:79I82==6R<M
M,3DN,#$W.BTV-2XS,#`G72`]("=3=6-R92<["B1C;V]R9&EN871E<ULG0F]L
M:79I82==6R<M,3DN-34P.BTV-2XW,S,G72`]("=0;W1O<VDG.PHD8V]O<F1I
M;F%T97-;)T)O;&EV:6$G75LG+3(P+C`P,#HM-C,N-3,S)UT@/2`G0V%M:7)I
M)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTR,2XR-3`Z+38S+C0U,"==
M(#T@)U9I;&QA;6]N=&5S)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTR
M,2XU-3`Z+38T+C<P,"==(#T@)U1A<FEJ82<["B1C;V]R9&EN871E<ULG0F]L
M:79I82==6R<M,C$N.34P.BTV,RXV-3`G72`]("=986-U:6)A)SL*)&-O;W)D
M:6YA=&5S6R=";W-N:6$@86YD($AE<GIE9V]V:6YA)UU;)S0S+C@S,SHQ-RXP
M,3<G72`]("=,:79N;R<["B1C;V]R9&EN871E<ULG0F]T<W=A;F$G75LG+3$W
M+C@Q-SHR-2XQ-3`G72`]("=+87-A;F4G.PHD8V]O<F1I;F%T97-;)T)O='-W
M86YA)UU;)RTQ."XS-C<Z,C$N.#4P)UT@/2`G4VAA:V%W92<["B1C;V]R9&EN
M871E<ULG0F]T<W=A;F$G75LG+3$Y+CDX,SHR,RXT,3<G72`]("=-875N)SL*
M)&-O;W)D:6YA=&5S6R=";W1S=V%N82==6R<M,C`N-#8W.C(U+CDX,R==(#T@
M)U-U82U086XG.PHD8V]O<F1I;F%T97-;)T)O='-W86YA)UU;)RTR,2XR,3<Z
M,C<N-3`P)UT@/2`G1G)A;F-I<W1O=VXG.PHD8V]O<F1I;F%T97-;)T)O='-W
M86YA)UU;)RTR,2XT,3<Z,C4N-C`P)UT@/2`G3&5T;&AA:V%N92<["B1C;V]R
M9&EN871E<ULG0F]T<W=A;F$G75LG+3(Q+C<P,#HR,2XV-3`G72`]("=':&%N
M>FDG.PHD8V]O<F1I;F%T97-;)T)O='-W86YA)UU;)RTR-"XP,3<Z,C$N.#@S
M)UT@/2`G5'-H86YE)SL*)&-O;W)D:6YA=&5S6R=";W1S=V%N82==6R<M,C0N
M,C$W.C(U+CDQ-R==(#T@)U-E<F5T<V4@2VAA;6$@26YT97)N871I;VYA;"!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=";W1S=V%N82==6R<M,C0N-C`P.C(T
M+C8V-R==(#T@)TIW86YE;F<G.PHD8V]O<F1I;F%T97-;)T)O='-W86YA)UU;
M)RTR-BXP-3`Z,C(N-#4P)UT@/2`G5'-A8F]N9R<["B1C;V]R9&EN871E<ULG
M0G)A>FEL)UU;)S`N,#,S.BTU,"XP-3`G72`]("=-86-A<&$G.PHD8V]O<F1I
M;F%T97-;)T)R87II;"==6R<M,"XQ,S,Z+38W+C`X,R==(#T@)U-A;R!'86)R
M:65L($1A($-A8VAO96ER82<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)S`N
M-C$W.BTV.2XR,#`G72`]("=)875A<F5T92<["B1C;V]R9&EN871E<ULG0G)A
M>FEL)UU;)RTP+CDX,SHM-C(N-3@S)UT@/2`G0F%R8V5L;W,G.PHD8V]O<F1I
M;F%T97-;)T)R87II;"==6R<M,2XS.#,Z+30X+C0X,R==(#T@)T)E;&5M($%E
M<F]P;W)T;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTQ,"XP,#`Z+38W
M+C@P,"==(#T@)U)I;R!"<F%N8V\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==
M6R<M,3`N-S`P.BTT."XT,#`G72`]("=0;W)T;R!.86-I;VYA;"!!97)O<&]R
M=&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,3`N.3@S.BTS-RXP-C<G
M72`]("=!<F%C86IU($%E<F]P;W)T;R<["B1C;V]R9&EN871E<ULG0G)A>FEL
M)UU;)RTQ,BXW,#`Z+38P+C$P,"==(#T@)U9I;&AE;F$@065R;W!O<G1O)SL*
M)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3$R+CDP,#HM,S@N,S,S)UT@/2`G
M4V%L=F%D;W(@065R;W!O<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG
M+3$S+C(V-SHM-#,N-#$W)UT@/2`G0F]M($IE<W5S($1A($QA<&$G.PHD8V]O
M<F1I;F%T97-;)T)R87II;"==6R<M,30N-S`P.BTU,BXS-3`G72`]("=8879A
M;G1I;F$G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,30N.#$W.BTS.2XP
M,S,G72`]("=);&AE=7,@065R;W!O<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z
M:6PG75LG+3$T+CDU,#HM-#`N.#@S)UT@/2`G5FET;W)I82!$82!#;VYQ=6ES
M=&$G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,34N-C4P.BTU-BXQ,#`G
M72`]("=#=6EA8F$@065R;W!O<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG
M75LG+3$U+C@V-SHM-#<N.3,S)UT@/2`G0G)A<VEL:6$@065R;W!O<G1O)SL*
M)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3$U+C@V-SHM-3(N,S@S)UT@/2`G
M0F%R<F$@1&\@1V%R8V%S)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3$V
M+C`U,#HM-#@N,#4P)UT@/2`G1V%M82<["B1C;V]R9&EN871E<ULG0G)A>FEL
M)UU;)RTQ-BXR,S,Z+30X+CDV-R==(#T@)T%N87!O;&ES($)R87HM069B)SL*
M)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3$V+C8S,SHM-#DN,C$W)UT@/2`G
M1V]I86YI82!!97)O<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M
M,38N-S$W.BTT,RXX-C<G72`]("=-;VYT97,@0VQA<F]S)SL*)&-O;W)D:6YA
M=&5S6R="<F%Z:6PG75LG+3$W+C8S,SHM,SDN,C4P)UT@/2`G0V%R879E;&%S
M($%E<F]P;W(M5&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,3DN,#@S
M.BTU-RXU,#`G72`]("=#;W)U;6)A)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG
M75LG+3$Y+C<X,SHM-#<N.38W)UT@/2`G56)E<F%B82<["B1C;V]R9&EN871E
M<ULG0G)A>FEL)UU;)RTQ.2XX-3`Z+30S+CDU,"==(#T@)T)E;&\@2&]R:7IO
M;G1E($%E<F]P;W)T;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTQ.2XY
M,S,Z+30S+CDS,R==(#T@)T)E;&\@2&]R:7IO;G1E)SL*)&-O;W)D:6YA=&5S
M6R="<F%Z:6PG75LG+3(N-#,S.BTU-"XW,3<G72`]("=386YT87)E;2U!97)O
M<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,BXV,#`Z+30T+C(S
M,R==(#T@)U-A;R!,=6EZ($%E<F]P;W)T;R<["B1C;V]R9&EN871E<ULG0G)A
M>FEL)UU;)S(N.#,S.BTV,"XW,#`G72`]("=";V$@5FES=&$@065R;W!O<BU4
M;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTR+CDQ-SHM-#$N-S4P)UT@
M/2`G4&%R;F%I8F$@065R;W!O<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG
M75LG+3(P+C(V-SHM-#`N,C@S)UT@/2`G5FET;W)I82!!97)O<&]R=&\G.PHD
M8V]O<F1I;F%T97-;)T)R87II;"==6R<M,C`N-#8W.BTU-"XV-C<G72`]("=#
M86UP;R!'<F%N9&4@065R;W!O<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG
M75LG+3(Q+C(U,#HM-#,N-S8W)UT@/2`G0F%R8F%C96YA)SL*)&-O;W)D:6YA
M=&5S6R="<F%Z:6PG75LG+3(Q+C<U,#HM-#$N,S,S)UT@/2`G0V%M<&]S)SL*
M)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3(Q+C<V-SHM-#,N,S4P)UT@/2`G
M2G5I>B!$92!&;W)A)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3(Q+C@U
M,#HM-#8N-38W)UT@/2`G4&]C;W,@1&4@0V%L9&%S)SL*)&-O;W)D:6YA=&5S
M6R="<F%Z:6PG75LG+3(Q+CDX,SHM-#<N,S,S)UT@/2`G4&ER87-S=6YU;F=A
M)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3(R+C`Q-SHM-#<N.#@S)UT@
M/2`G4V%O($-A<FQO<R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTR,BXQ
M,3<Z+34Q+C,X,R==(#T@)U!R97-I9&5N=&4@4')U9&5N=&4G.PHD8V]O<F1I
M;F%T97-;)T)R87II;"==6R<M,C(N,S$W.BTT.2XP-C<G72`]("="875R=2<[
M"B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTR,BXT.#,Z+30T+C0V-R==(#T@
M)U)E<V5N9&4G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,C(N-34P.BTU
M-2XW,#`G72`]("=0;VYT82!0;W)A($%E<F]P;W(M5&\G.PHD8V]O<F1I;F%T
M97-;)T)R87II;"==6R<M,C(N-S@S.BTT-2XR,#`G72`]("='=6%R871I;F=U
M971A)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3(R+C@Q-SHM-#(N,3`P
M)UT@/2`G4RX@4"X@06QD96EA($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG
M0G)A>FEL)UU;)RTR,BXX,3<Z+30S+C(U,"==(#T@)T=A;&5A;R<["B1C;V]R
M9&EN871E<ULG0G)A>FEL)UU;)RTR,BXX-C<Z+30S+C,V-R==(#T@)T%F;VYS
M;W,@065R;W!O<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3(R+CDP
M,#HM-#,N,38W)UT@/2`G4FEO($1E($IA;F5I<F\@065R;W!O<G1O)SL*)&-O
M;W)D:6YA=&5S6R="<F%Z:6PG75LG+3(R+CDS,SHM-#,N-S$W)UT@/2`G4V%N
M=&$@0W)U>B!!97)O<&]R+51O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG
M+3(R+CDX,SHM-#,N,S8W)UT@/2`G4FEO("\@2F%C87)E<&%G=6$G.PHD8V]O
M<F1I;F%T97-;)T)R87II;"==6R<M,C,N,#`P.BTT-RXQ,S,G72`]("=#86UP
M:6YA<R!!97)O<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,C,N
M,S,S.BTU,2XQ,S,G72`]("=,;VYD<FEN82!!97)O<&]R=&\G.PHD8V]O<F1I
M;F%T97-;)T)R87II;"==6R<M,C,N-#$W.BTU,2XY-3`G72`]("=-87)I;F=A
M)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3(S+C4Q-SHM-#8N-C,S)UT@
M/2`G36%R=&4@0VEV("\@36EL)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG
M+3(S+C8Q-SHM-#8N-C4P)UT@/2`G4V%O(%!A=6QO($%E<F]P;W(M5&\G.PHD
M8V]O<F1I;F%T97-;)T)R87II;"==6R<M,C,N.3,S.BTT-BXS,#`G72`]("=3
M86YT;W,@065R;W!O<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3(U
M+C0S,SHM-#DN,C8W)UT@/2`G0W5R:71I8F$G.PHD8V]O<F1I;F%T97-;)T)R
M87II;"==6R<M,C4N-3$W.BTT."XU,3<G72`]("=087)A;F%G=6$G.PHD8V]O
M<F1I;F%T97-;)T)R87II;"==6R<M,C4N-3$W.BTT.2XQ-C<G72`]("=#=7)I
M=&EB82!!97)O<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,C4N
M-3$W.BTU-"XU.#,G72`]("=&;WH@1&\@26=U86-U($%E<F]P;W)T;R<["B1C
M;V]R9&EN871E<ULG0G)A>FEL)UU;)RTR-RXV-C<Z+30X+C4U,"==(#T@)T9L
M;W)I86YO<&]L:7,@065R;W!O<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG
M75LG+3(X+C(U,#HM-3(N-#`P)UT@/2`G4&%S<V\@1G5N9&\G.PHD8V]O<F1I
M;F%T97-;)T)R87II;"==6R<M,CDN-S$W.BTU,RXW,#`G72`]("=386YT82!-
M87)I82!!97)O+5!O<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3(Y
M+C<X,SHM-3<N,#,S)UT@/2`G57)U9W5A:6%N82!!97)O<&]R=&\G.PHD8V]O
M<F1I;F%T97-;)T)R87II;"==6R<M,RXP,S,Z+38P+C`U,"==(#T@)T5D=6%R
M9&\@1V]M97,@26YT97)N871I;VYA;"<["B1C;V]R9&EN871E<ULG0G)A>FEL
M)UU;)RTS+C$U,#HM-3DN.3@S)UT@/2`G36%N875S($%E<F]P;W)T;R<["B1C
M;V]R9&EN871E<ULG0G)A>FEL)UU;)RTS+C(P,#HM-3(N,C`P)UT@/2`G06QT
M86UI<F$G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,RXS-C<Z+38T+C8X
M,R==(#T@)U1E9F4G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,RXV-C<Z
M+38Y+C8V-R==(#T@)U1A8F%T:6YG82<["B1C;V]R9&EN871E<ULG0G)A>FEL
M)UU;)RTS+C<Q-SHM-#DN-S$W)UT@/2`G5'5C=7)U:2<["B1C;V]R9&EN871E
M<ULG0G)A>FEL)UU;)RTS+C<X,SHM,S@N-3,S)UT@/2`G1F]R=&%L97IA($%E
M<F]P;W(M5&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<S+C@S,SHM-3$N
M.#,S)UT@/2`G3VEA<&]Q=64G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M
M,RXX-3`Z+3,R+C0Q-R==(#T@)T9E<FYA;F1O($1E($YO<F]N:&$G.PHD8V]O
M<F1I;F%T97-;)T)R87II;"==6R<M,S`N,#`P.BTU,2XQ.#,G72`]("=0;W)T
M;R!!;&5G<F4@065R;RU0;W)T;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;
M)RTS,"XP,3<Z+34Q+C(Q-R==(#T@)U!O<G1O($%L96=R92<["B1C;V]R9&EN
M871E<ULG0G)A>FEL)UU;)RTS,2XS-3`Z+34T+C$Q-R==(#T@)T)A9V4@065R
M;W!O<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3,Q+C@V-SHM-3(N
M,S4P)UT@/2`G4&5L;W1A<R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTT
M+C(U,#HM-38N,#`P)UT@/2`G271A:71U8F$G.PHD8V]O<F1I;F%T97-;)T)R
M87II;"==6R<M-"XS.#,Z+3<P+C`S,R==(#T@)T)E;FIA;6EN($-O;G-T86YT
M)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+34N,#4P.BTT,BXX,3<G72`]
M("=497)E<VEN82!!97)O<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==
M6R<M-2XR,#`Z+3,W+C,V-R==(#T@)TUO8V]R;R`O(#$W(%)O<V%D;R<["B1C
M;V]R9&EN871E<ULG0G)A>FEL)UU;)RTU+C,U,#HM-#DN,34P)UT@/2`G36%R
M86)A)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+34N-3,S.BTT-RXU,#`G
M72`]("=);7!E<F%T<FEZ)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+34N
M.#$W.BTV,2XS,#`G72`]("=-86YI8V]R92<["B1C;V]R9&EN871E<ULG0G)A
M>FEL)UU;)RTU+CDQ-SHM,S4N,C4P)UT@/2`G3F%T86P@065R;W!O<G1O)SL*
M)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+38N,C8W.BTU-RXW,S,G72`]("=*
M86-A<F5A8V%N9V$G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M-RXQ,#`Z
M+3,T+C@V-R==(#T@)TIO86\@4&5S<V]A)SL*)&-O;W)D:6YA=&5S6R="<F%Z
M:6PG75LG+3<N,C$W.BTS-2XX.#,G72`]("=#86UP:6YA($=R86YD92<["B1C
M;V]R9&EN871E<ULG0G)A>FEL)UU;)RTW+C,Q-SHM-#<N-#8W)UT@/2`G36%R
M86YH86\@+R!#87)O;&EN82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R="<F%Z
M:6PG75LG+3<N-C,S.BTW,BXV-C<G72`]("=#<G5Z96ER;R!$;R!3=6PG.PHD
M8V]O<F1I;F%T97-;)T)R87II;"==6R<M."XP-C<Z+3,T+C@U,"==(#T@)U)E
M8VEF92!!97)O<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M."XQ
M-C<Z+3<P+C<V-R==(#T@)U1A<F%U86-A)SL*)&-O;W)D:6YA=&5S6R="<F%Z
M:6PG75LG+3@N,C4P.BTT.2XR.#,G72`]("=#;VYC96EC86\@1&\@07)A9W5A
M:6$G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M."XW-C<Z+38S+CDQ-R==
M(#T@)U!O<G1O(%9E;&AO($%E<F]P;W)T;R<["B1C;V]R9&EN871E<ULG0G)A
M>FEL)UU;)RTY+C,U,#HM-#`N-34P)UT@/2`G4&5T<F]L:6YA($%E<F]P;W(M
M5&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M.2XT,#`Z+3,X+C(Q-R==
M(#T@)U!A=6QO($%F;VYS;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTY
M+C4Q-SHM,S4N-S@S)UT@/2`G36%C96EO($%E<F]P;W)T;R<["B1C;V]R9&EN
M871E<ULG0G)A>FEL)UU;)RTY+C@V-SHM-38N,3`P)UT@/2`G06QT82!&;&]R
M97-T82!!97)O<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R:71I<V@@26YD:6%N
M($]C96%N(%1E<G)I=&]R>2==6R<M-RXS,#`Z-S(N-#`P)UT@/2`G1&EE9V\@
M1V%R8VEA)SL*)&-O;W)D:6YA=&5S6R="<G5N96D@1&%R=7-S86QA;2==6R<T
M+CDS,SHQ,30N.3,S)UT@/2`G0G)U;F5I($%I<G!O<G0G.PHD8V]O<F1I;F%T
M97-;)T)U;&=A<FEA)UU;)S0R+C$S,SHR-"XW-3`G72`]("=0;&]V9&EV)SL*
M)&-O;W)D:6YA=&5S6R="=6QG87)I82==6R<T,BXT.#,Z,C<N-#@S)UT@/2`G
M0G5R9V%S)SL*)&-O;W)D:6YA=&5S6R="=6QG87)I82==6R<T,BXV-3`Z,C,N
M,S@S)UT@/2`G4V]F:6$@3V)S97)V+B<["B1C;V]R9&EN871E<ULG0G5L9V%R
M:6$G75LG-#,N,C`P.C(W+CDQ-R==(#T@)U9A<FYA)SL*)&-O;W)D:6YA=&5S
M6R="=6QG87)I82==6R<T,RXX-3`Z,C4N.34P)UT@/2`G4F]U<W-E)SL*)&-O
M;W)D:6YA=&5S6R="=7)K:6YA($9A<V\G75LG,3`N,S,S.BTS+C$X,R==(#T@
M)T=A;W5A)SL*)&-O;W)D:6YA=&5S6R="=7)K:6YA($9A<V\G75LG,3$N,34P
M.BTQ+C$U,"==(#T@)U!O)SL*)&-O;W)D:6YA=&5S6R="=7)K:6YA($9A<V\G
M75LG,3$N,38W.BTT+C,Q-R==(#T@)T)O8F\M1&EO=6QA<W-O)SL*)&-O;W)D
M:6YA=&5S6R="=7)K:6YA($9A<V\G75LG,3$N-S4P.BTR+CDS,R==(#T@)T)O
M<F]M;R<["B1C;V]R9&EN871E<ULG0G5R:VEN82!&87-O)UU;)S$R+C`S,SHP
M+C,V-R==(#T@)T9A9&$@3EPG1V]U<FUA)SL*)&-O;W)D:6YA=&5S6R="=7)K
M:6YA($9A<V\G75LG,3(N,S4P.BTQ+C4Q-R==(#T@)T]U86=A9&]U9V]U)SL*
M)&-O;W)D:6YA=&5S6R="=7)K:6YA($9A<V\G75LG,3(N-#8W.BTS+C0X,R==
M(#T@)T1E9&]U9V]U)SL*)&-O;W)D:6YA=&5S6R="=7)K:6YA($9A<V\G75LG
M,3,N-38W.BTR+C0Q-R==(#T@)T]U86AI9V]U>6$G.PHD8V]O<F1I;F%T97-;
M)T)U<FMI;F$@1F%S;R==6R<Q-"XP,S,Z+3`N,#,S)UT@/2`G1&]R:2<["B1C
M;V]R9&EN871E<ULG0G5R=6YD:2==6R<M,RXS,3<Z,CDN,S$W)UT@/2`G0G5J
M=6UB=7)A)SL*)&-O;W)D:6YA=&5S6R=#86UB;V1I82==6R<Q,2XU-3`Z,3`T
M+C@U,"==(#T@)U!H;F]M+5!E;F@@+R!0;V-H96YT;VYG)SL*)&-O;W)D:6YA
M=&5S6R=#86UB;V1I82==6R<Q,BXP,#`Z,3`U+C0U,"==(#T@)TMO;7!O;F<M
M0VAA;2<["B1C;V]R9&EN871E<ULG0V%M8F]D:6$G75LG,3,N,S8W.C$P,RXX
M-3`G72`]("=3:65M<F5A<"<["B1C;V]R9&EN871E<ULG0V%M97)O;VXG75LG
M,3`N-#4P.C$T+C(U,"==(#T@)TUA<F]U82U386QA:R<["B1C;V]R9&EN871E
M<ULG0V%M97)O;VXG75LG,BXY-3`Z.2XY,#`G72`]("=+<FEB:2<["B1C;V]R
M9&EN871E<ULG0V%M97)O;VXG75LG,RXQ-3`Z,3,N-C$W)UT@/2`G3&]M:64G
M.PHD8V]O<F1I;F%T97-;)T-A;65R;V]N)UU;)S,N.#,S.C$Q+C4Q-R==(#T@
M)UEA;W5N9&4G.PHD8V]O<F1I;F%T97-;)T-A;65R;V]N)UU;)S,N.38W.C$S
M+C(P,"==(#T@)T%B;VYG+4UB86YG)SL*)&-O;W)D:6YA=&5S6R=#86UE<F]O
M;B==6R<T+C`P,#HY+C<S,R==(#T@)T1O=6%L82!/8G,N)SL*)&-O;W)D:6YA
M=&5S6R=#86UE<F]O;B==6R<T+C`X,SHY+C,V-R==(#T@)U1I:V\G.PHD8V]O
M<F1I;F%T97-;)T-A;65R;V]N)UU;)S0N-#8W.C$T+C,V-R==(#T@)T)A=&]U
M<FDG.PHD8V]O<F1I;F%T97-;)T-A;65R;V]N)UU;)S0N-S,S.C$Q+C(U,"==
M(#T@)T)A9FEA)SL*)&-O;W)D:6YA=&5S6R=#86UE<F]O;B==6R<T+CDU,#HY
M+CDS,R==(#T@)TYK;VYG<V%M8F$G.PHD8V]O<F1I;F%T97-;)T-A;65R;V]N
M)UU;)S4N-34P.C$R+C,V-R==(#T@)UEO:V\G.PHD8V]O<F1I;F%T97-;)T-A
M;65R;V]N)UU;)S4N-C`P.C$T+C`V-R==(#T@)T)E=&%R92U/>6$G.PHD8V]O
M<F1I;F%T97-;)T-A;65R;V]N)UU;)S4N-C4P.C$P+C<U,"==(#T@)TMO=6YD
M:F$G.PHD8V]O<F1I;F%T97-;)T-A;65R;V]N)UU;)S4N-S$W.CDN,C@S)UT@
M/2`G36%M9F4G.PHD8V]O<F1I;F%T97-;)T-A;65R;V]N)UU;)S8N,#4P.C$P
M+C$Q-R==(#T@)T)A;65N9&$G.PHD8V]O<F1I;F%T97-;)T-A;65R;V]N)UU;
M)S8N-3,S.C$T+C,V-R==(#T@)TUE:6=A;F=A)SL*)&-O;W)D:6YA=&5S6R=#
M86UE<F]O;B==6R<V+C<X,SHQ,2XX,3<G72`]("="86YY;R<["B1C;V]R9&EN
M871E<ULG0V%M97)O;VXG75LG-RXS-3`Z,3,N-38W)UT@/2`G3F=A;W5N9&5R
M92<["B1C;V]R9&EN871E<ULG0V%M97)O;VXG75LG.2XS,S,Z,3,N,S@S)UT@
M/2`G1V%R;W5A)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#$N.#,S.BTX
M,BXT-C<G72`]("=3+B!%+B!3:&]A;"!-971E;W)O;&]G:6-A;"!!97)O;F%U
M=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0R+C(U,#HM.#$N.3`P)UT@/2`G17)I96%U($UE=&5O<F]L;V=I
M8V%L($%E<F]N875T:6-A;"!0<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-#(N,C8W.BTX,BXY-C<G72`]("=7:6YD<V]R
M+"!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#(N,S`P.BTX,BXW
M,#`G72`]("="96QL92!2:79E<B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S0R+C4V-SHM.#`N,#4P)UT@/2`G3&]N9R!0;VEN="!-971E;W)O;&]G:6-A
M;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S0R+C@U,#HM.#`N,C8W)UT@/2`G4VEM8V]E+"!/
M;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#(N.#8W.BTW.2XR-3`G
M72`]("=0;W)T($-O;&)O<FYE($%U=&]M871E9"!297!O<G1I;F<@4W1A=&EO
M;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0R+C@V-SHM.#`N-34P)UT@
M/2`G1&5L:&D@0U,L($]N="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T
M,RXP,#`Z+3@R+C,Q-R==(#T@)U-A<FYI82!!:7)P;W)T)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-#,N,#,S.BTX,2XQ-3`G72`]("=,;VYD;VXL($]N
M="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T,RXQ-C<Z+3<Y+CDS,R==
M(#T@)TAA;6EL=&]N($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<T,RXR-3`Z+3<Y+C(Q-R==(#T@)U!O<G0@5V5L;&5R+"!/;G0N)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-#,N,S`P.BTW.2XX,#`G72`]("="=7)L
M:6YG=&]N(%!I97)S)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#,N-#8W
M.BTX,"XS.#,G72`]("=7871E<FQO;R!796QL)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-#,N-C$W.BTW.2XS-3`G72`]("=4;W)O;G1O($AE861L86YD
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#,N-C,S.BTW.2XT,#`G72`]
M("=4;W)O;G1O($ES;&%N9"!!:7)P;W)T($%U=&]M871E9"!297!O<G1I;F<@
M4W1A=&EO;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0S+C8V-SHM-SDN
M-C,S)UT@/2`G5&]R;VYT;R!096%R<V]N($EN=%PG3"X@3VYT+B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0S+C<V-SHM.#$N-S$W)UT@/2`G1V]D97)I
M8V@@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0S+C<X,SHM-SDN-#8W)UT@/2`G5&]R;VYT
M;R!!97,@2'$G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T,RXX,S,Z+38V
M+C`X,R==(#T@)UEA<FUO=71H+"!.+B!3+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0S+C@S,SHM-S<N,34P)UT@/2`G4&]I;G0@4&5T<F4L($]N="XG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T,RXY,S,Z+38P+C`Q-R==(#T@
M)U-A8FQE($ES;&%N9"P@3BX@4RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<T,RXY-3`Z+3<X+C$V-R==(#T@)T-O8F]U<F<L($]N="XG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<T,RXY.#,Z+38T+C8V-R==(#T@)U=E<W1E<FX@
M2&5A9"P@3BX@4RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T,RXY.#,Z
M+3@P+C<U,"==(#T@)TUO=6YT($9O<F5S="P@3VYT+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0T+C$Q-SHM-S<N-3,S)UT@/2`G5')E;G1O;BP@3VYT
M+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0T+C(Q-SHM-S8N-C`P)UT@
M/2`G2VEN9W-T;VXL($]N="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T
M-"XR,S,Z+3<X+C,V-R==(#T@)U!E=&5R8F]R;W5G:"!!:7)P;W)T)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-#0N,C@V.BTV-BXS-#<G72`]("="<FEE
M<B!)<VQA;F0L($XN(%,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#0N
M,S@S.BTW.2XW.#,G72`]("="87)R:64L($]N="XG.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<T-"XT,3<Z+3<U+C@U,"==(#T@)T=R96YA9&EE<B!)<VQA
M;F0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-"XT,S,Z+38U+C(P,"==
M(#T@)TME:FEM:W5J:6L@,2P@3BX@4RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<T-"XU,#`Z+3@P+C(Q-R==(#T@)T-O;&QI;F=W;V]D($%U=&]M871I
M8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<T-"XU,S,Z+3<Y+C(Q-R==(#T@)TQA9V]O;B!#:71Y)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-#0N-C,S.BTV,RXU,#`G72`]("=3:&5A
M<G=A=&5R+"!.+B!3+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0T+C<P
M,#HM-S8N,S`P)UT@/2`G57!P97(@4FED96%U($QA:V4G.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<T-"XW,S,Z+3@Q+C(X,R==(#T@)T]L:7!H86YT(%P@
M3VYT)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#0N-S4P.BTX,2XQ,#`G
M72`]("=7:6%R=&]N+"!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#0N.#$W.BTV,BXS,S,G72`]("="96%V96X@27-L86YD+"!.+B!3+B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S0T+C@U,#HM-SDN.#8W)UT@/2`G0F5A
M=7-O;&5I;"!)<VQA;F0@075T;VUA=&5D(%)E<&]R=&EN9R!3=&%T:6]N)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#0N.#@S.BTV,RXU,#`G72`]("=(
M86QI9F%X($EN=&5R;F%T:6]N86P@06ER<&]R="<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S0T+CDV-SHM-SDN,S`P)UT@/2`G375S:V]K82P@3VYT+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0T+CDX,SHM-C0N.3$W)UT@/2`G
M1W)E96YW;V]D+"!.+B!3+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0U
M+C`S,SHM.#`N,S8W)UT@/2`G5V5S=&5R;B!)<VQA;F0@365T96]R;VQO9VEC
M86P@065R;VYA=71I8V%L(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<T-2XP-3`Z+3<R+C@S,R==(#T@)T9R96QI9VAS
M8G5R9R<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0U+C`V-SHM-C0N-#@S
M)UT@/2`G2V5N='9I;&QE+"!.+B!3+B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0U+C$Q-SHM-S0N,C@S)UT@/2`G4W0@06YI8V5T)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-#4N,38W.BTW,RXV.#,G72`]("=386EN="!#;&]T
M:&EL9&4@075T;VUA=&5D(%)E<&]R=&EN9R!3=&%T:6]N)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-#4N,C$W.BTV-RXR-3`G72`]("=3="X@4W1E<&AE
M;BP@3BX@0BXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-2XS,#`Z+3<S
M+C,U,"==(#T@)TQ<)T%C861I92<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S0U+C,Q-SHM-S(N,C4P)UT@/2`G36]N="U/<F9O<F0G.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<T-2XS,3<Z+3<U+C8V-R==(#T@)T]T=&%W82!);G1<
M)TPN($]N="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-2XS,S,Z+38U
M+C@X,R==(#T@)U-A:6YT($IO:&XL($XN($(N)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-#4N,S,S.BTX,2XW,S,G72`]("=#;W9E($ES;&%N9"!-971E
M;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0U+C,U,#HM-C`N.3@S)UT@/2`G
M2&%R="!)<VQA;F0@365T96]R;VQO9VEC86P@065R;VYA=71I8V%L(%!R97-E
M;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-2XS
M-C<Z+38S+C(V-R==(#T@)U1R=7)O+"!.+B!3+B<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S0U+C,V-SHM-S$N.#$W)UT@/2`G3&5N;F]X=FEL;&4G.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-2XT,#`Z+3<Q+C@X,R==(#T@)U-H
M97)B<F]O:V4L(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-2XT
M,3<Z+3<S+CDS,R==(#T@)TUC9VEL;"!2861A<B!3:71E)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-#4N-#,S.BTW,RXY,S,G72`]("=3=&4@06YN92!$
M92!"96QL(#$G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-2XT-C<Z+3<S
M+C<U,"==(#T@)TUO;G1R96%L("\@1&]R=F%L($EN=&5R;F%T:6]N86PL(%%U
M92<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0U+C4P,#HM-S,N-3@S)UT@
M/2`G36,@5&%V:7-H($%U=&]M871E9"!297!O<G1I;F<@4W1A=&EO;B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S0U+C4Q-SHM-S,N-#$W)UT@/2`G4V%I
M;G0@2'5B97)T($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T
M-2XV,S,Z+3<P+C4U,"==(#T@)TUO;G1R96%L+45S="<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0U+C8S,SHM.#(N.38W)UT@/2`G1W)E870@1'5C:R!)
M<VQA;F0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-2XW,3<Z+38P+C(S
M,R==(#T@)T9O=7)C:'4@2&5A9"!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC
M86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0U+C<Q-SHM-S,N,S@S)UT@/2`G5F%R96YN97,G.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<T-2XW-C<Z+38R+C8X,R==(#T@)T-A<FEB;W4@4&]I
M;G0@365T96]R;VQO9VEC86P@065R;VYA=71I8V%L(%!R97-E;G1A=&EO;B!3
M>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-2XX,#`Z+3@P+C4S
M,R==(#T@)T)R:71T+"!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#4N.#$W.BTW,RXT,S,G72`]("=,7"=!<W-O;7!T:6]N)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-#4N.#,S.BTV-BXT,S,G72`]("='86=E=&]W;B!#
M86XM36EL)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#4N.#,S.BTW-2XV
M-3`G72`]("=(:6=H($9A;&QS+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#4N.#4P.BTV-"XR-C<G72`]("=!;6AE<G-T+"!.+B!3+B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S0U+C@V-SHM-C8N-3,S)UT@/2`G1G)E
M9&5R:6-T;VXL($XN($(N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#4N
M.#@S.BTX,BXU-C<G72`]("=';W)E($)A>2P@3VYT+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0U+CDU,#HM-S<N,S$W)UT@/2`G4&5T87=A=V$L($]N
M="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-2XY-C<Z+3@Q+C0X,R==
M(#T@)TMI;&QA<FYE>2!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E
M<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0V
M+C`U,#HM-S0N,C@S)UT@/2`G4W1E($%G871H92!$97,@36]N="<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0V+C`V-SHM-S0N-3,S)UT@/2`G4W0@2F]V
M:71E($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T-BXQ,3<Z+38T+C8X,R==(#T@)TUO;F-T
M;VXL($XN($(N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#8N,38W.BTV
M,"XP-3`G72`]("=3>61N97DL($XN(%,N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#8N,C`P.BTW,"XW.#,G72`]("="96%U8V5V:6QL92<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0V+C(Q-SHM-S(N-C4P)UT@/2`G3FEC;VQE
M="!!=71O;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-#8N,C@S.BTV,RXQ,S,G72`]("=#:&%R;&]T
M=&5T;W=N+"!0+B!%+B!)+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0V
M+C(X,SHM-S8N,#`P)UT@/2`G36%N:7=A:VDG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<T-BXS,3<Z+3<Y+C0V-R==(#T@)TYI<&ES<VEN9R<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0V+C,U,#HM-S(N-3$W)UT@/2`G5')O:7,@
M4FEV:65R97,G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-BXS-3`Z+3<Y
M+C0S,R==(#T@)TYO<G1H($)A>2P@3VYT+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0V+C,X,SHM-S4N.38W)UT@/2`G36%N:7=A:VDL(%%U92XG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-BXT,S,Z+38S+C@S,R==(#T@)U-U
M;6UE<G-I9&4@0V%N+4UI;"<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0V
M+C0S,SHM-S$N.3,S)UT@/2`G5FEL;&5R;WD@4F%D87(@4VET92<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0V+C0U,#HM-C$N.38W)UT@/2`G16%S="!0
M;VEN="P@4"X@12X@22<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0V+C0X
M,SHM.#0N-3`P)UT@/2`G4V%U;'0@4W1E($UA<FEE+"!/;G0N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-#8N-34P.BTV,2XP-3`G72`]("='<F%N9"!%
M=&%N9RP@3BX@4RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-BXU.#,Z
M+3<R+C4X,R==(#T@)U-H87=I;FEG86X@0U,L(%%U92XG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<T-BXV,3<Z+3@P+C@P,"==(#T@)U-U9&)U<GDL($]N
M="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-BXV-3`Z+34S+C`V-R==
M(#T@)T-A<&4@4F%C92P@3F9L9"<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S0V+C8X,SHM-S$N.34P)UT@/2`G1&5S8VAA;6)A=6QT<RP@475E+B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S0V+C@P,#HM-S$N,S@S)UT@/2`G475E
M8F5C+"!1=64G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-BXX,3<Z+38P
M+C8V-R==(#T@)TYO<G1H($UO=6YT86EN+"!.+B!3+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0V+C@S,SHM-S$N,C`P)UT@/2`G0F5A=7!O<G0@0U,L
M(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-BXY,#`Z+3<Q+C4P
M,"==(#T@)U9A;&-A<G1I97(@06ER<&]R="<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0V+CDP,#HM-S$N-3`P)UT@/2`G5F%L8V%R=&EE<B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0V+CDQ-SHM-34N,S@S)UT@/2`G4W0N($QA
M=W)E;F-E+"!.9FQD+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0W+C`P
M,#HM-C4N-#4P)UT@/2`G0VAA=&AA;2!#86XM36EL)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-#<N,#`P.BTW,"XX,3<G72`]("=);&4@1%PG3W)L96%N
M<R!!=71O;6%T960@4F5P;W)T:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<T-RXP-C<Z+38T+C@P,"==(#T@)U!O:6YT($5S8W5M:6YA
M8R!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y
M<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0W+C`V-SHM-S`N.#`P
M)UT@/2`G0V%P(%1O=7)M96YT92<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S0W+C$U,#HM-C<N.#,S)UT@/2`G4V%I;G0@3&5O;F%R9"!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#<N,C,S.BTV,"XQ,S,G72`]("=3
M86EN="!0875L($ES;&%N9"!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@
M4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S0W+C(X,SHM-S`N-C,S)UT@/2`G0VAA<FQE=F]I>"!#4RP@475E+B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S0W+C,P,#HM-30N,#`P)UT@/2`G07)G
M96YT:6$L($YF;&0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-RXS,#`Z
M+3<Q+C(V-R==(#T@)U-T92!&;WD@0U,L(%%U92XG.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<T-RXS,S,Z+3@U+C@S,R==(#T@)T-A<FEB;W4@27-L86YD
M+"!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#<N,S4P.BTW,"XP
M,S,G72`]("=,82!0;V-A=&EE<F4G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<T-RXS-C<Z+34U+C@P,"==(#T@)U-A9V]N82!)<VQA;F0@365T96]R;VQO
M9VEC86P@065R;VYA=71I8V%L(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T-RXT,3<Z+38Q+C<X,R==(#T@)TEL97,@
M1&4@3&$@36%D96QE:6YE<75E+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S0W+C0Q-SHM-C$N.#`P)UT@/2`G26QE<RU$92U,82U-861E;&5I;B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S0W+C0Q-SHM-S(N.#`P)UT@/2`G3&$@
M5'5Q=64G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-RXU,38Z+34R+C<X
M-2==(#T@)U-T+B!*;VAN7"=S(%=E<W0@0T1!($-3+"!.9FQD+B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0W+C4V-SHM-3DN,38W)UT@/2`G4&]R="U!
M=7@M0F%S<75E<RP@3F9L9"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T
M-RXU-C<Z+3<Q+C(S,R==(#T@)U!A<F,@1&5S($QA=7)E;G1I9"<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0W+C8Q-SHM-3(N-S,S)UT@/2`G4W0N($IO
M:&Y<)W,L($YF;&0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-RXW,#`Z
M+3<Y+C@U,"==(#T@)T5A<FQT;VXL($]N="XG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<T-RXX,#`Z+38Y+C4U,"==(#T@)U)I=FEE<F4@1'4@3&]U<"P@
M475E+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0W+CDQ-SHM-S0N-C$W
M)UT@/2`G4&%R96YT+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#<N.38W.BTX-"XW.#,G72`]("=787=A+"!/;G0N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-#<N.3@S.BTV-BXS,S,G72`]("=#:&%R;&\L($XN($(N
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N,#$W.BTV-"XU,#`G72`]
M("=-:7-C;W4@27-L86YD+"!.+B!"+B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0X+C`Q-SHM-C4N,S,S)UT@/2`G3F5W($-A<FQI<VQE,2<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0X+C`V-SHM-S<N-S@S)UT@/2`G5F%L($1<
M)T]R+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N,#@S.BTV
M.2XU-3`G72`]("=);&4@4F]U9V4@365T96]R;VQO9VEC86P@065R;VYA=71I
M8V%L(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<T."XR-3`Z+3<Y+C`S,R==(#T@)U)O=7EN)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-#@N,C8W.BTW,"XQ,3<G72`]("=0=6EN=&4@0VQA=F5A
M=2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0X+C,P,#HM,3(S+C4S,R==
M(#T@)U)A8V4@4F]C:W,@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y
M<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0X+C,P,#HM-S`N.3,S
M)UT@/2`G3&$@0F%I92P@475E+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S0X+C,S,SHM-S$N,#`P)UT@/2`G0F%G;W1V:6QL92P@475E+B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0X+C,V-SHM.#DN,3$W)UT@/2`G5V5L8V]M
M92!)<VQA;F0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XS-C<Z+3@Y
M+C,Q-R==(#T@)U1H=6YD97(@0F%Y+"!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-#@N,S@S.BTQ,C,N.3$W)UT@/2`G4VAE<FEN9VAA;2!!=71O
M;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-#@N,S@S.BTW,"XU,S,G72`]("=#87`@4F]U9V4G.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XT,38Z+38X+C@Y,R==(#T@)TEL
M92!":6-Q=65T=&4L(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T
M."XT,3<Z+3$R,RXS,3<G72`]("=6:6-T;W)I82!!=71O;6%T:6,@5V5A=&AE
M<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#@N-#$W.BTV-"XS,3<G72`]("=#87`@1%PG17-P;VER+"!1=64N)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N-#$W.BTW,2XR,3<G72`]("=*;VYQ
M=6EE<F4@075T;VUA=&5D(%)E<&]R=&EN9R!3=&%T:6]N)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-#@N-#,S.BTQ,C,N-#,S)UT@/2`G17-Q=6EM86QT
M($AA<F)O=7(L($(N($,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N
M-#4P.BTQ,C,N,S`P)UT@/2`G5FEC=&]R:6$@56YI=F5R<VET>2<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0X+C0V-SHM-C<N-#,S)UT@/2`G06UQ=6DL
M(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XU,3<Z+3<R+C(V
M-R==(#T@)U)O8F5R=F%L+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-#@N-3,S.BTU."XU-3`G72`]("=3=&5P:&5N=FEL;&4L($YF;&0N)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N-34W.BTU,RXY-S0G72`]("=4
M97)R82!.;W9A($YA=&EO;F%L(%!A<FL@0U,L($YF;&0N)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-#@N-38W.BTX,2XS-C<G72`]("=4:6UM:6YS+"!/
M;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N-3@S.BTQ,C,N-3@S
M)UT@/2`G36%L86AA="!!=71O;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@4WES
M=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N-C`P.BTV."XR,3<G
M72`]("=-;VYT($IO;&DL(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<T."XV,#`Z+3@V+C,P,"==(#T@)U!U:V%S:W=A)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-#@N-C,S.BTW.2XT-3`G72`]("=2;W%U96UA=7)E)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N-C4P.BTQ,C,N-#,S)UT@/2`G
M5FEC=&]R:6$@26YT+B!!:7)P;W)T+"!"+B!#+B<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S0X+C8V-SHM,3(T+C@S,R==(#T@)TYI=&EN870@3&%K92!-
M971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E
M;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0X+C8V-SHM-3,N,3$W)UT@
M/2`G0F]N879I<W1A+"!.9FQD+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S0X+C<U,#HM.3$N-C$W)UT@/2`G071I:V]K86X@075T;VUA=&5D(%)E<&]R
M=&EN9R!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N-S8W
M.BTV-"XT.#,G72`]("='87-P92P@475E+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0X+C<V-SHM-S$N-S$W)UT@/2`G36ES=&]O:R!!=71O;6%T960@
M4F5P;W)T:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T
M."XW.#,Z+3$R,RXP-3`G72`]("=3871U<FYA($ES;&%N9"!-971E;W)O;&]G
M:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0X+C@S,SHM-S(N-34P)UT@/2`G3F]R;6%N
M9&EN)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N.#@S.BTW,2XP,S,G
M72`]("=/;F%T8VAI=V%Y+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-#@N.3$W.BTQ,C4N-34P)UT@/2`G06UP:&ET<FET92!0;VEN="<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S0X+CDU,#HM-30N-38W)UT@/2`G1V%N
M9&5R($EN="X@06ER<&]R="P@3F9L9"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<T."XY-C<Z+34V+C`V-R==(#T@)T)A9&=E<BP@3F9L9"<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0Y+C`Q-SHM,3(R+C<X,R==(#T@)U=H:71E
M(%)O8VL@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C`S,SHM,3$Y+C0S,R==(#T@)T]S
M;WEO;W,@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C`S,SHM,3(R+C,V-R==(#T@)T%B
M8F]T<V9O<F0L($(N($,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN
M,#,S.BTY,"XT-C<G72`]("=5<'-A;&$L($]N="XG.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<T.2XP,S,Z+3DW+C4V-R==(#T@)T=R971N82P@36%N+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C`U,#HM,3`U+C0X,R==(#T@
M)T-O<F]N86-H(%-P8R<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C`U
M,#HM,3(S+C@V-R==(#T@)TYA;F%I;6\@06ER<&]R="<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0Y+C`V-SHM,3`W+C4X,R==(#T@)U9A;"!-87)I92!3
M;W5T:&5A<W0L(%-A<VLG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XP
M.#,Z+3$Q-BXU,#`G72`]("=#<F5S=&]N($%U=&]M871I8R!796%T:&5R(%)E
M<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XP
M.#,Z+3$R-2XW-C<G72`]("=4;V9I;F\@06ER<&]R="<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0Y+C`X,SHM-C$N-S`P)UT@/2`G2&5A=&@@4&]I;G0@
M365T96]R;VQO9VEC86P@065R;VYA=71I8V%L(%!R97-E;G1A=&EO;B!3>7-T
M96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XQ,3<Z+3$Q,"XT-C<G
M72`]("=/;F5F;W5R($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T
M96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XQ,3<Z+38V+C8U,"==
M(#T@)T-A<"!#:&%T($-3+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-#DN,3,S.BTQ,3(N,#4P)UT@/2`G36EL:R!2:79E<B<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S0Y+C$S,SHM-C@N,C`P)UT@/2`G0F%I92!#;VUE
M874L(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XQ-C<Z+3$P
M-2XY.#,G72`]("=2;V-K9VQE;BP@4V%S:RXG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<T.2XQ.#,Z+3$R,RXQ-C<G72`]("=686YC;W5V97(@26YT97)N
M871I;VYA;"!!:7(M4&]R="P@0BX@0RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<T.2XQ.#,Z+3DX+C`X,R==(#T@)TUO<F1E;B!#1$$@0U,L($UA;BXG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XR,#`Z+3$Q,RXR.#,G72`]
M("=#87)D<W1O;B!!=71O;6%T960@4F5P;W)T:6YG(%-T871I;VXG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T.2XR,#`Z+3$R,BXV.#,G72`]("=0+B!-
M96%D;W=S($-O87-T86P@4W1A=&EO;B!!=71O;6%T:6,@5V5A=&AE<B!297!O
M<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN,C`P
M.BTY."XY,#`G72`]("=0:6QO="!-;W5N9"P@36%N+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0Y+C(Q-SHM,3`R+CDV-R==(#T@)T5S=&5V86XL(%-A
M<VLN)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN,C$W.BTQ,C,N.#`P
M)UT@/2`G16YT<F%N8V4@27-L86YD($%U=&]M871I8R!796%T:&5R(%)E<&]R
M=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XR,3<Z
M+34W+C0P,"==(#T@)T1E97(@3&%K92P@3F9L9"XG.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<T.2XR-3`Z+3$R,2XW-C<G72`]("=!9V%S<VEZ($%U=&]M
M871E9"!297!O<G1I;F<@4W1A=&EO;B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0Y+C(U,#HM,3(T+C@S,R==(#T@)U!O<G0@06QB97)N:2P@0BX@0RXG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XR-3`Z+38U+C,S,R==(#T@
M)T-A<"!-861E;&5I;F4@365T96]R;VQO9VEC86P@065R;VYA=71I8V%L(%!R
M97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T
M.2XR-C<Z+34T+C@X,R==(#T@)T-O;69O<G0@0V]V92P@3F9L9"XG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T.2XR-C<Z+38X+C$U,"==(#T@)T)A:64@
M0V]M96%U)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN,C@S.BTQ,#`N
M.3@S)UT@/2`G365L:71A+"!-86XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<T.2XR.#,Z+3<S+C,U,"==(#T@)T-H86UO=6-H;W5A;F4@075T;VUA=&EC
M(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0Y+C,P,#HM,3$W+C8S,R==(#T@)T-A<W1L96=A<B!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN,S`P.BTQ,C,N,3$W)UT@
M/2`G5F%N8V]U=F5R($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T
M96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XS,3<Z+38W+C,X,R==
M(#T@)U!O:6YT92U$97,M36]N=',L(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<T.2XS-3`Z+3$R,RXQ.#,G72`]("=7(%9A;F-O=79E<B!!=71O
M;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-#DN,S4P.BTQ,C0N,38W)UT@/2`G0F%L;&5N87,@27-L
M86YD($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T.2XS-C<Z+3$R,2XT.#,G72`]("=(;W!E
M+"!"+B!#+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C,X,SHM,3(V
M+C4U,"==(#T@)T5S=&5V86X@4&]I;G0L($(N($,N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-#DN-#`P.BTY."XS,3<G72`]("=$965R=V]O9"!20U,L
M($UA;BXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XT,3<Z+3@R+C0V
M-R==(#T@)TMA<'5S:V%S:6YG+"!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#DN-#,S.BTQ,#@N.3@S)UT@/2`G16%S=&5N9"!#>7!R97-S+"!3
M87-K)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN-#8W.BTQ,3DN-C`P
M)UT@/2`G4&5N=&EC=&]N+"!"+B!#+B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0Y+C0V-SHM,3(P+C4Q-R==(#T@)U!R:6YC971O;B!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN-#@S.BTQ,C,N,S`P)UT@/2`G
M4&%M(%)O8VMS)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN-#@S.BTQ
M,C0N-#,S)UT@/2`G4VES=&5R<R!)<VQA;F0@075T;VUA=&EC(%=E871H97(@
M4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y
M+C4P,#HM,3$W+C,P,"==(#T@)TYE;'-O;B!!=71O;6%T:6,@5V5A=&AE<B!2
M97!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN
M-3`P.BTY."XP,S,G72`]("=#87)M86X@52!/9B!-)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-#DN-38W.BTQ,3DN-C4P)UT@/2`G4W5M;65R;&%N9"!!
M=71O;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-#DN-38W.BTU-RXX.#,G72`]("=2;V-K>2!(87)B
M;W5R($-3+"!.9FQD+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C4X
M,SHM,3$T+C0Q-R==(#T@)U1U<G1L92!-;W5N=&%I;B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0Y+C8Q-SHM,3$U+C<X,R==(#T@)T-R86YB<F]O:RP@
M0BX@0RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XV,S,Z+3$Q,2XT
M-3`G72`]("=";W<@27-L86YD)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#DN-C,S.BTQ,3(N.#`P)UT@/2`G3&5T:&)R:61G92P@06QT82XG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T.2XV,S,Z+3$Q-"XT.#,G72`]("=#<F]W
M<VYE<W0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XV-3`Z+3$P.2XU
M,3<G72`]("=#>7!R97-S($AI;&QS(%!A<FLG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<T.2XV.#,Z+34T+C@P,"==(#T@)U1W:6QL:6YG871E($UE=&5O
M<F]L;V=I8V%L($%E<F]N875T:6-A;"!0<F5S96YT871I;VX@4WES=&5M)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN-S`P.BTQ,#,N.#`P)UT@/2`G
M5V5Y8G5R;B!!=71O;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@4WES=&5M)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN-S`P.BTQ,3(N-S@S)UT@/2`G
M3&5T:&)R:61G92!!=71O;6%T960@4F5P;W)T:6YG(%-T871I;VXG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T.2XW,3<Z+3$R-"XY,#`G72`]("=#;VUO
M>"P@0BX@0RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XW,3<Z+3@X
M+C,S,R==(#T@)TMA=&%T;W1A($ES;&%N9"<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0Y+C<S,SHM,3`U+CDS,R==(#T@)T%S<VEN:6)O:6$@06ER<&]R
M="!!=71O;6%T960@4F5P;W)T:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<T.2XW-3`Z+3$Q-"XY,#`G72`]("=3<&%R=V]O9"!!=71O
M;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-#DN-S4P.BTX-"XQ-C<G72`]("=.86=A9V%M:2P@3VYT
M+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C<V-SHM-S0N-3,S)UT@
M/2`G0VAI8F]U9V%M874M0VAA<&%I<RP@475E)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-#DN-S8W.BTW-RXX,3<G72`]("=-871A9V%M:2P@475E+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C<X,SHM,3(S+C$V-R==(#T@
M)U-Q=6%M:7-H($%I<G!O<G0L($(N($,G.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<T.2XW.#,Z+3@V+CDS,R==(#T@)T=E<F%L9'1O;BP@3VYT+B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C<X,SHM.30N,S8W)UT@/2`G2V5N
M;W)A+"!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN-S@S.BTY
M.2XV,S,G72`]("=3:&EL;R<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y
M+C@S,SHM,3(T+C4P,"==(#T@)U!O=V5L;"!2:79E<B!!:7)P;W)T)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN.#,S.BTV-"XS,#`G72`]("=0;W)T
M($UE;FEE<BP@475E+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C@X
M,SHM.3<N,3,S)UT@/2`G5VEN;FEP96<@5&AE($9O<FMS+"!-86XN)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN.3`P.BTQ,#DN-#8W)UT@/2`G36%P
M;&5C<F5E:R!!=71O;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@4WES=&5M)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN.3`P.BTW,2XR-3`G72`]("=#
M:'5T92!$97,@4&%S<V5S)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN
M.3`P.BTY-RXR,S,G72`]("=7:6YN:7!E9R!);G0N($%I<G!O<G1M86XN)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN.3`P.BTY."XR-C<G72`]("=0
M;W)T86=E(%-O=71H<&]R="!!)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#DN.3`P.BTY.2XS-3`G72`]("=#87)B97)R>2!-8V1C)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-#DN.3$W.BTU-2XV-C<G72`]("=,82!38VEE+"!.
M9FQD+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+CDQ-SHM.3DN.34P
M)UT@/2`G0G)A;F1O;BP@36%N+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S0Y+CDV-SHM,3$Y+C,X,R==(#T@)TME;&]W;F$@06ER<&]R="<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S4P+C`Q-SHM,3$P+C<Q-R==(#T@)TUE9&EC
M:6YE($AA="P@06QT82XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XP
M,3<Z+3$Q,RXV,S,G72`]("=#;&%R97-H;VQM($%U=&]M871I8R!796%T:&5R
M(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U
M,"XP-3`Z+3$Q,BXQ,S,G72`]("=6875X:&%L;"!#9&$G.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<U,"XQ,3<Z+3$R-RXY,S,G72`]("=3;VQA;F1E<B!)
M<VQA;F0@365T96]R;VQO9VEC86P@065R;VYA=71I8V%L(%!R97-E;G1A=&EO
M;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XQ,3<Z+3DQ
M+CDP,"==(#T@)U-I;W5X($QO;VMO=70L($]N="XG.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<U,"XQ-C<Z+38P+C`V-R==(#T@)T-A<&4@5VAI='1L92<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C$V-SHM-C8N-#,S)UT@/2`G
M4&]I;G1E($YO:7)E+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-3`N,3@S.BTV,2XX,3<G72`]("=.871A<VAQ=6%N+"!1=64N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-3`N,3@S.BTY-BXP-C<G72`]("=0:6YA=V$@
M075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S4P+C(P,#HM,3`T+C<P,"==(#T@)T)R871T<R!,
M86ME+"!387-K+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C(Q-SHM
M-C8N,C8W)UT@/2`G4V5P="U);&5S+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-3`N,C(T.BTV-"XR,#@G72`]("=);&4@075X(%!E<G)O<75E
M=',L(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XR,S,Z+3$Q
M.2XR.#,G72`]("=697)N;VXL($(N($,N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-3`N,C,S.BTQ,C$N-3@S)UT@/2`G3'ET=&]N+"!"+B!#+B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C(S,SHM-3<N-3@S)UT@/2`G1&%N
M:65L7"=S($AA<F)O=7(L($YF;&0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<U,"XR-C<Z+3$P-RXW,S,G72`]("=3=VEF="!#=7)R96YT($%U=&]M871I
M8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<U,"XR-C<Z+3$Q,2XQ.#,G72`]("=3=69F:65L9"!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N,C8W.BTQ,3<N.#$W)UT@
M/2`G3F%K=7-P($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XR-C<Z+38T+C(S,R==(#T@
M)TQO;F=U92!0;VEN="!$92!-:6YG86XL(%%U92XG.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<U,"XR.#,Z+3$P-RXV.#,G72`]("=3=VEF="!#=7)R96YT
M+"!387-K+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C(X,SHM-C,N
M-C$W)UT@/2`G2&%V<F4@4W0@4&EE<G)E)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-3`N,S`P.BTQ,C(N-S,S)UT@/2`G4&5M8F5R=&]N($%U=&]M871I
M8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<U,"XS,#`Z+3@Y+C`S,R==(#T@)T%R;7-T<F]N9RP@3VYT+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C,S,SHM,3`U+C4U,"==(#T@
M)TUO;W-E($IA=RP@4V%S:RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U
M,"XS.#,Z+3$P,BXV.#,G72`]("="<F]A9'9I97<L(%-A<VLN)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-3`N-#`P.BTQ,#0N-3@S)UT@/2`G4F5G:6YA
M(%5N:79E<G-I='DG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XT,#`Z
M+3$R-2XX-C<G72`]("=(96QM8VME;B!)<VQA;F0@365T96]R;VQO9VEC86P@
M065R;VYA=71I8V%L(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<U,"XT,S,Z+3$P-"XV-C<G72`]("=296=I;F$L(%-A
M<VLN)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N-#4P.BTQ,#`N-C`P
M)UT@/2`G4VAO86P@3&%K92!!:7)P;W)T($%U=&]M871E9"!297!O<G1I;F<@
M4W1A=&EO;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C0V-SHM-3DN
M-C,S)UT@/2`G0VAE=F5R>2P@475E+B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S4P+C4U,#HM,3$Q+C@U,"==(#T@)T)R;V]K<R!!=71O;6%T:6,@5V5A
M=&AE<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-3`N-C`P.BTQ,C`N-3$W)UT@/2`G4')I;F-E=&]N($%U=&]M871I8R!7
M96%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<U,"XV,3<Z+3DW+C`S,R==(#T@)T=I;6QI($EN9'5S=')I86PL($UA
M;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C8S,3HM.38N.3@R)UT@
M/2`G1VEM;&D@2&%R8F]U<B!#4RP@36%N+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S4P+C8S,SHM,3(X+C$Q-R==(#T@)TAO;&)E<F<L($(N($,N)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N-C4P.BTY.2XY,S,G72`]("=7
M87-A9V%M:6YG+"!-86XN)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N
M-C8W.BTW,"XU,S,G72`]("=-86YO=6%N92U%<W0@075T;VUA=&5D(%)E<&]R
M=&EN9R!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N-C@S
M.BTQ,C<N,S8W)UT@/2`G4&]R="!(87)D>2P@0BX@0RXG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<U,"XW,#`Z+3$Q.2XR.#,G72`]("=386QM;VX@07)M
M($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<U,"XW,#`Z+3$R,"XT-3`G72`]("=+86UL;V]P
M<RP@0BX@0RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XW,#`Z+3DV
M+C4V-R==(#T@)U9I8W1O<FEA($)E86-H)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-3`N-S$W.BTU-BXQ,3<G72`]("=%;F=L964@365T96]R;VQO9VEC
M86P@065R;VYA=71I8V%L(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<U,"XW,S,Z+3<Q+C`Q-R==(#T@)T)O;FYA<F0@
M,2P@475E+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C<X,SHM,3(X
M+C0S,R==(#T@)T-A<&4@4V-O='0@3&EG:'0G.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<U,"XX,3<Z+3$R."XY,#`G72`]("=387)T:6YE($ES;&%N9"!-
M971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E
M;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+CDP,#HM,3`Y+C4P,"==
M(#T@)TQE861E<B!!:7)P;W)T($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN
M9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XY,S,Z+3$R
M-RXV,S,G72`]("=(97)B97)T($ES;&%N9"!-971E;W)O;&]G:6-A;"!!97)O
M;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S4P+CDU,#HM,3`W+C$U,"==(#T@)TQU8VMY($QA:V4@075T
M;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4P+CDU,#HM,3$U+C$X,R==(#T@)TYA:VES:V$@4FED
M9V5T;W`G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XY-C<Z+3$Q."XQ
M.#,G72`]("=2979E;'-T;VME+"!"+B!#+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S4P+CDX,SHM,3(W+C<S,R==(#T@)U!I;F4@27-L86YD($UE=&5O
M<F]L;V=I8V%L($%E<F]N875T:6-A;"!0<F5S96YT871I;VX@4WES=&5M)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3$N,#8W.BTY,RXX,#`G72`]("=2
M960@3&%K92P@3VYT+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4Q+C`X
M,SHM,3$T+C(Q-R==(#T@)T-O<"!5<'!E<B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S4Q+C`X,SHM,3$U+C`V-R==(#T@)T)O=R!686QL97DG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<U,2XP.#,Z+3DW+C4U,"==(#T@)T9I<VAE
M<B!"<F%N8V@@36%R:6YE($%V:6%T:6]N(%)E<&]R=&EN9R!3=&%T:6]N)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3$N,3`P.BTQ,#`N,#4P)UT@/2`G
M1&%U<&AI;B!#;V%S=&%L(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<U,2XQ,#`Z+3$P,"XP-3`G72`]("=$875P:&EN+"!-86XN)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-3$N,3$W.BTQ,30N,#$W)UT@/2`G0V%L
M9V%R>2!);G1E<FYA=&EO;F%L+"!!;'1A+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S4Q+C$S,SHM,3`V+C4X,R==(#T@)T5L8F]W($UA<FEN92!!=FEA
M=&EO;B!297!O<G1I;F<@4W1A=&EO;B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S4Q+C$U,#HM,3(Q+C4P,"==(#T@)T-L:6YT;VXL($(N($,N)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-3$N,3@S.BTQ,34N-38W)UT@/2`G0F%N
M9F8L($%L=&$N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3$N,C4P.BTQ
M,C,N,#@S)UT@/2`G0FEG($-R965K)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-3$N,C8W.BTQ,#(N-#8W)UT@/2`G66]R:W1O;BP@4V%S:RXG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<U,2XR-C<Z+3@P+C8U,"==(#T@)TUO;W-O
M;F5E+"!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3$N,S8W.BTU
M-2XV,S,G72`]("=3="X@06YT:&]N>2P@3F9L9"XG.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<U,2XT-3`Z+3$Q-BXS,S,G72`]("=9;VAO(%!A<FL@075T
M;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4Q+C0U,#HM-3<N,3@S)UT@/2`G0FQA;F,@4V%B;&]N
M+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3$N-#4P.BTY,"XR
M,#`G72`]("=0:6-K;&4@3&%K92P@3VYT+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S4Q+C0X,SHM,3`W+C`U,"==(#T@)T]U=&QO;VL@4&9R82<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S4Q+C4Q-SHM,3`Y+C$V-R==(#T@)TMI
M;F1E<G-L97DL(%-A<VLN)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3$N
M-34P.BTW,2XQ,3<G72`]("=,86,@0F5N;VET)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-3$N-38W.BTQ,#<N.3$W)UT@/2`G4F]S971O=VX@16%S="P@
M4V%S:R<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4Q+C8V-SHM,3`U+C0P
M,"==(#T@)U=A=')O=7,@16%S="!!=71O;6%T960@4F5P;W)T:6YG(%-T871I
M;VXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,2XV-C<Z+3$Q,"XR,#`G
M72`]("=%<W1H97(@,2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4Q+C8V
M-SHM.3@N-S4P)UT@/2`G1WEP<W5M=FEL;&4G.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<U,2XW,#`Z+3$Q,RXR,3<G72`]("=4:')E92!(:6QL<R<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S4Q+C<U,#HM.3DN.3`P)UT@/2`G0F%C
M:&5L;W)S($ES;&%N9"!!=71O;6%T960@4F5P;W)T:6YG(%-T871I;VXG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,2XW-C<Z+3$P-"XR,#`G72`]("=7
M>6YY87)D+"!387-K+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4Q+C<V
M-SHM,3$T+C8X,R==(#T@)U-U;F1R92<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S4Q+C@V-SHM-C,N,C@S)UT@/2`G3&%C($5O;BP@475E)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-3(N,#8W.BTQ,3$N-#4P)UT@/2`G0V]R;VYA
M=&EO;B!-87)I;F4@079I871I;VX@4F5P;W)T:6YG(%-T871I;VXG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<U,BXQ,3<Z+3$P,2XR,S,G72`]("=3=V%N
M(%)I=F5R+"!-86XN)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3(N,3$W
M.BTQ,C0N,3,S)UT@/2`G4'5N='II($UO=6YT86EN+"!"+B!#+B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S4R+C$S,SHM,3$Y+C,P,"==(#T@)T)L=64@
M4FEV97(L($(N($,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3(N,34P
M.BTQ,#8N-34P)UT@/2`G4V%S:V%T;V]N($ME<FYE;B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4R+C$V-SHM,3`V+C8X,R==(#T@)U-A<VMA=&]O;BP@
M4V%S:RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,BXQ.#,Z+3$Q,RXY
M,#`G72`]("=2960@1&5E<BP@06QT82XG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<U,BXQ.#,Z+3$R,BXP-3`G72`]("=7:6QL:6%M<R!,86ME+"!"+B!#
M+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4R+C$X,SHM,3(W+C0V-R==
M(#T@)T-A=&AE9')A;"!0;VEN="!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC
M86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S4R+C(S,SHM.#<N.#@S)UT@/2`G3&%N<V1O=VYE($AO=7-E)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-3(N,C8W.BTQ,C@N-S$W)UT@/2`G36-I
M;FYE<R!)<VQA;F0L($(N($,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-3(N,S`P.BTU-2XX,S,G72`]("=-87)Y7"=S($AA<F)O=7(L($YF;&0N)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3(N,S4P.BTY-RXP,S,G72`]("="
M97)E;G,@4FEV97(@06ER<&]R="<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S4R+C,U,#HM.3<N,#,S)UT@/2`G0F5R96YS(%)I=F5R($-3+"!-86XN)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3(N,S@S.BTQ,C8N-3@S)UT@/2`G
M0F5L;&$@0V]O;&$@06ER<&]R="<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S4R+C0S,SHM,3$T+CDQ-R==(#T@)U)O8VMY($UO=6YT86EN($AO=7-E+"!!
M;'1A)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3(N-#4P.BTQ,3,N-S4P
M)UT@/2`G3&%C;VUB92!#9&$G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U
M,BXV-3`Z+34V+C@V-R==(#T@)T%L97AI<R!2:79E<B!-971E;W)O;&]G:6-A
M;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S4R+C<V-SHM,3`X+C(U,"==(#T@)TYO<G1H($)A
M='1L969O<F0L(%-A<VLN)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3(N
M.#`P.BTY-RXV,3<G72`]("='96]R9V4@27-L86YD($UE=&5O<F]L;V=I8V%L
M($%E<F]N875T:6-A;"!0<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-3(N.#$W.BTQ,#(N,S$W)UT@/2`G2'5D<V]N($)A
M>2P@4V%S:RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,BXX,3<Z+3$P
M-"XV,#`G72`]("=-96QF;W)T($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN
M9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,BXX.#,Z+3$Q
M."XP-C<G72`]("=*87-P97(L($%L=&$N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-3(N.3,S.BTQ,3@N,S$W)UT@/2`G2F%S<&5R(%=A<F1E;B!!=71O
M;6%T960@4F5P;W)T:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<U,BXY,S,Z+38V+C@V-R==(#T@)U=A8G5S:"!,86ME+"!.9FQD+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C`S,SHM,3`P+CDS,R==(#T@
M)TAU;G1E<G,@4&]I;G0@36%R)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-3,N,#,S.BTQ,3(N.#$W)UT@/2`G0V%M<F]S92<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S4S+C`S,SHM,3(R+C4Q-R==(#T@)U%U97-N96P@06ER<&]R
M="<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C`U,#HM,3(Y+C8X,R==
M(#T@)T5T:&5L9&$@0F%Y)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N
M,3@S.BTY.2XR-C<G72`]("='<F%N9"!287!I9',L($UA;BXG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<U,RXR,3<Z+3$P-2XV.#,G72`]("=0<FEN8V4@
M06QB97)T+"!387-K+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C(U
M,#HM,3,Q+C@Q-R==(#T@)U-A;F1S<&ET+"!"+B!#+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4S+C,P,#HM,3$S+C4X,R==(#T@)T5D;6]N=&]N($EN
M=&5R;F%T:6]N86PL($%L=&$N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-3,N,S`P.BTQ,3,N-C`P)UT@/2`G161M;VYT;VX@26YT97)N871I;VYA;"!#
M4RP@06QT82XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,RXS,3<Z+3$Q
M,"XP-C<G72`]("=,;&]Y9&UI;FES=&5R+"!!;'1A+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4S+C,Q-SHM,3,R+C<U,"==(#T@)TMI;F1A:W5N(%)O
M8VMS+"!"+B!#+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C,Q-SHM
M-C`N-#$W)UT@/2`G1V]O<V4L($YF;&0N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-3,N,S,S.BTQ,#0N,#`P)UT@/2`G3FEP87=I;BP@4V%S:RXG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,RXS-C<Z+3$P-RXU-3`G72`]("=3
M<&ER:71W;V]D(%=E<W0L(%-A<VLG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<U,RXS.#,Z+3$Q."XS,S,G72`]("=7:6QL;W<@0W)E96LG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<U,RXT,3<Z+3$Q,RXR,#`G72`]("=%;&QE<G-L
M:64G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,RXT-3`Z+3$Q-"XT-C<G
M72`]("=(:6=H=F%L92<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C4P
M,#HM,3,P+C8S,R==(#T@)T)O;FEL;&$@27-L86YD($UE=&5O<F]L;V=I8V%L
M($%E<F]N875T:6-A;"!0<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-3,N-3,S.BTQ,30N,3`P)UT@/2`G161M;VYT;VX@
M4W1O;GD@4&QA:6X@06QT82XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U
M,RXU-3`Z+38T+C$P,"==(#T@)T-H=7)C:&EL;"!&86QL<RP@3F9L9"XG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,RXU-C<Z+3$Q,RXU,3<G72`]("=%
M9&UO;G1O;B!-=6YI8VEP86P@06QT82XG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<U,RXU-C<Z+3$Q,RXU,3<G72`]("=%9&UO;G1O;B!-=6YI8VEP86P@
M0U(Q,"P@06QT82XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,RXU-C<Z
M+38T+C$P,"==(#T@)T-H=7)C:&EL;"!&86QL<R<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S4S+C4X,SHM,3$V+C0V-R==(#T@)T5D<V]N+"!!;'1A+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C8Q-SHM,3$R+C`S,R==(#T@
M)U9E9W)E=FEL;&4@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E
M;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C8S,SHM-S<N-S`P)UT@
M/2`G3&$@1W)A;F1E(%)I=FEE<F4L(%%U92<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S4S+C8V-SHM,3$S+C0V-R==(#T@)T5D;6]N=&]N($YA;6%O($%L
M=&$N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N-C@S.BTQ,3(N.#8W
M)UT@/2`G16QK($ES;&%N9"!.871I;VYA;"!087)K)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-3,N-C@S.BTQ,C0N.#,S)UT@/2`G3F5C:&%K;R!2:79E
M<B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C<P,#HM-3<N,#,S)UT@
M/2`G0V%R='=R:6=H="P@3F9L9"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<U,RXW,S,Z+3$P-2XR-C<G72`]("=#86YD;&4@3&%K92<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S4S+C<U,#HM-S,N-C8W)UT@/2`G3&$@1W)A;F1E
M($EV+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N-S@S.BTQ
M,3@N-#,S)UT@/2`G2&5N9&5R:6-K<V]N($%U=&]M871I8R!796%T:&5R(%)E
M<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,RXX
M,S,Z+3@Y+C@V-R==(#T@)T)I9R!4<F]U="!,86ME)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-3,N.#4P.BTY-"XV-3`G72`]("=)<VQA;F0@3&%K92P@
M36%N+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C@X,SHM,3(R+C8X
M,R==(#T@)U!R:6YC92!'96]R9V4L($(N($,N)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-3,N.3$W.BTQ,#8N,#8W)UT@/2`G5V%S:V5S:74@3&%K92!!
M=71O;6%T960@4F5P;W)T:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<U,RXY-C<Z+3$P,2XQ,#`G72`]("=4:&4@4&%S+"!-86XN)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N.38W.BTY-RXX,S,G72`]("=.
M;W)W87D@2&]U<V4L($UA;BXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U
M-"XQ,S,Z+3$P."XU,3<G72`]("=-96%D;W<@3&%K92P@4V%S:RXG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<U-"XQ-3`Z+3$Q-2XW.#,G72`]("=7:&ET
M96-O=7)T+"!!;'1A+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4T+C$U
M,#HM,3$U+C<X,R==(#T@)U=H:71E8V]U<G0L($%L=&$N)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-30N,38W.BTQ,S`N,S8W)UT@/2`G2&]L;&%N9"!2
M;V-K($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<U-"XQ-C<Z+3$S,2XV-C<G72`]("=2;W-E
M(%-P:70@365T96]R;VQO9VEC86P@065R;VYA=71I8V%L(%!R97-E;G1A=&EO
M;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U-"XR-3`Z+3$S
M,RXQ,S,G72`]("=,86YG87)A+"!"+B!#+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S4T+C,P,#HM,3,P+C0S,R==(#T@)U!R:6YC92!2=7!E<G0L($(N
M($,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-30N,S@S.BTQ,C4N.34P
M)UT@/2`G0G5R;G,@3&%K92<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4T
M+C0Q-SHM,3$P+C(X,R==(#T@)T-O;&0@3&%K92P@06QT82XG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<U-"XT-C<Z+3$R."XU.#,G72`]("=497)R86-E
M+"!"+B!#+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4T+C4X,SHM,3,P
M+C<P,"==(#T@)T=R97D@27-L970@365T96]R;VQO9VEC86P@065R;VYA=71I
M8V%L(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<U-"XW-3`Z+3$Q,"XP-3`G72`]("=0<FEM<F]S92!,86ME)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-30N-S8W.BTQ,3(N,#$W)UT@/2`G3&%C
M($QA($)I8VAE+"!!;'1A+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4T
M+C<X,SHM,3$P+C`V-R==(#T@)U!R:6UR;W-E($QA:V4@,B<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S4T+C@P,#HM-C8N.#`P)UT@/2`G4V-H969F97)V
M:6QL92P@475E+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4T+C@Q-SHM
M,3(W+C$X,R==(#T@)U-M:71H97)S+"!"+B!#+B<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S4T+CDX,SHM.#4N-#,S)UT@/2`G4&5A=V%N=6-K($UE=&5O
M<F]L;V=I8V%L($%E<F]N875T:6-A;"!0<F5S96YT871I;VX@4WES=&5M)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-34N,34P.BTQ,#4N,C8W)UT@/2`G
M3&$@4F]N9V4L(%-A<VLN)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-34N
M,34P.BTQ,#4N,C8W)UT@/2`G3&$@4F]N9V4L(%-A<VLG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<U-2XQ.#,Z+3$Q."XX.#,G72`]("='<F%N9&4@4')A
M:7)I92P@06QT82XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U-2XR,#`Z
M+3$Q.2XT,#`G72`]("="96%V97)L;V1G92<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S4U+C(X,SHM-S<N-S8W)UT@/2`G2W5U:FIU87)A<&EK+"!1=64N
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-34N,S`P.BTQ,30N-S@S)UT@
M/2`G4VQA=F4@3&%K92P@06QT82<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S4U+C,P,#HM,3(S+C$S,R==(#T@)TUA8VME;GII92P@0BX@0RXG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<U-2XS,S,Z+38S+C(Q-R==(#T@)T)O<F1E
M<BP@475E+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4U+C0U,#HM-C`N
M,C,S)UT@/2`G2&]P961A;&4@365T96]R;VQO9VEC86P@065R;VYA=71I8V%L
M(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<U-2XV.34Z+3$Q.2XR,S0G72`]("=3<&ER:70@4FEV97(@075T;R!3=&%T
M:6]N+"!!;'1A)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-34N.#`P.BTY
M-RXX-3`G72`]("=4:&]M<'-O;B!796%T:&5R($]F9FEC92P@36%N)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-34N.#,S.BTQ,#@N-#,S)UT@/2`G0G5F
M9F%L;R!.87)R;W=S+"!387-K+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S4U+CDS,SHM,3(Y+CDX,R==(#T@)U-T97=A<G0@06ER<&]R="<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S4V+C(S,SHM,3$W+C0S,R==(#T@)U!E86-E
M(%)I=F5R+"!!;'1A+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4V+C(S
M,SHM,3(P+C<S,R==(#T@)T9O<G0@4W0@2F]H;BP@0BX@0RXG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<U-BXS,S,Z+3$P,RXR.#,G72`]("=3;W5T:&5N
M9"!!=71O;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-38N,S4P.BTY-"XW,#`G72`]("=':6QL86TL
M($UA;BXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U-BXU,S,Z+3$Q-2XR
M-C<G72`]("=2960@16%R=&@G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U
M-BXU-3`Z+38Q+C8X,R==(#T@)TYA:6XL($YF;&0G.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<U-BXV-3`Z+3$Q,2XR,3<G72`]("=&;W)T($UC375R<F%Y
M($-3+"!!;'1A+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4V+C8U,#HM
M,3$Q+C(Q-R==(#T@)T9O<G0@36-M=7)R87DL($%L=&$N)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-38N-S,S.BTQ,S$N-C8W)UT@/2`G27-K=70@4FEV
M97(G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U-BXX-C<Z+3$P,2XP.#,G
M72`]("=,>6YN($QA:V4L($UA;BXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<U-RXQ,S,Z+38Q+C0X,R==(#T@)T-A<&4@2VEG;&%P86ET+"!.9FQD+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4W+C(U,#HM,3`U+C8Q-R==(#T@
M)TME>2!,86ME)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3<N,S4P.BTQ
M,#<N,3,S)UT@/2`G0W)E92!,86ME($UE=&5O<F]L;V=I8V%L($%E<F]N875T
M:6-A;"!0<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-3<N-3,S.BTQ,3$N-38W)UT@/2`G36EL9')E9"!,86ME)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-3@N,3`P.BTV."XT,3<G72`]("=+=75J
M:G5A<2P@475E+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4X+C$X,SHM
M,3`S+C<P,"==(#T@)T-O;&QI;G,@0F%Y($%U=&]M871I8R!796%T:&5R(%)E
M<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U."XS
M,S,Z+38R+C4X,R==(#T@)U-A9VQE:R!"87DG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<U."XS.#,Z+3$P.2XU,#`G72`]("=#;'5F9B!,86ME+"!387-K
M+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4X+C0Q-SHM,3,P+C`P,"==
M(#T@)T1E87-E($QA:V4@0BX@0RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<U."XT,3<Z+3$S,"XP,#`G72`]("=$96%S92!,86ME($-O87-T86P@4W1A
M=&EO;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4X+C0U,#HM-S@N,3$W
M)UT@/2`G26YU:VIU86LL(%%U92<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S4X+C4X,SHM,3$X+C4P,"==(#T@)U-O=7-A($-R:R!!=G0G.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<U."XV,3<Z+3$Q-RXQ-C<G72`]("=(:6=H($QE
M=F5L+"!!;'1A)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3@N-C(R.BTQ
M,3$N-C<R)UT@/2`G4')A:7)I92!2:79E<BP@06QT82<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4X+C8X,SHM,3$S+C@X,R==(#T@)T=A<F1E;B!2:79E
M<B!!=71O;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-3@N-S,S.BTY-"XP-C<G72`]("=#:'5R8VAI
M;&PL($UA;BXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U."XW-C<Z+3$Q
M,2XQ,3<G72`]("=&;W)T($-H:7!E=WEA;BP@06QT82XG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<U."XX,S,Z+3$R,BXU.#,G72`]("=&;W)T($YE;'-O
M;BP@0BX@0RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U.2XQ,S,Z+3$Q
M,RXX,#`G72`]("=7871E<G1O;B!087)K($=A=&4G.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<U.2XR,3<Z+3$P.2XW,#`G72`]("="96%R=&]O=&@@27-L
M86YD)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3DN,C4P.BTQ,#4N.#,S
M)UT@/2`G4W1O;GD@4F%P:61S($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<U.2XU-C<Z+3$P."XT.#,G72`]("=5<F%N:75M($-I='DL(%-A
M<VLN)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3DN.3@S.BTV-"XQ-C<G
M72`]("=#87!E($MA:VMI=FEA:R<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S8P+C`Q-SHM,3$Q+CDU,"==(#T@)T9O<G0@4VUI=&@L($XN(%<N(%0N)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C`N,3$W.BTQ,C@N.#$W)UT@/2`G
M5V%T<V]N($QA:V4L(%DN(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-C`N,38W.BTQ,S(N-S,S)UT@/2`G5&5S;&EN+"!9+B!4+B<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S8P+C0Q-SHM-C0N.#4P)UT@/2`G2VEL;&EN96L@
M365T96]R;VQO9VEC86P@065R;VYA=71I8V%L(%!R97-E;G1A=&EO;B!3>7-T
M96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,"XT,S,Z+3$R,2XR,S,G
M72`]("=4<F]U="!,86ME)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C`N
M-S$W.BTQ,S4N,#8W)UT@/2`G5VAI=&5H;W)S92P@62X@5"XG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<V,"XW-C<Z+3$S-RXU.#,G72`]("=(86EN97,@
M2G5N8W1I;VXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,"XX,S,Z+3$Q
M-2XW.#,G72`]("=(87D@4FEV97(L($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-C$N,#4P.BTQ,#DN,S,S)UT@/2`G4&]W9&5R($QA:V4G
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,2XP-3`Z+38Y+C8S,R==(#T@
M)U%U87%T87$@06ER<&]R="<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8Q
M+C$Q-SHM,3(R+C@U,"==(#T@)TQI;F1B97)G($QA;F1I;F<L($XN(%<N(%0N
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C$N,3,S.BTQ,#`N.3`P)UT@
M/2`G16YN861A:2!,86ME($UE=&5O<F]L;V=I8V%L($%E<F]N875T:6-A;"!0
M<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-C$N,S$W.BTQ,3<N-C`P)UT@/2`G1F]R="!0<F]V:61E;F-E)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-C$N,S8W.BTQ,SDN,#4P)UT@/2`G0G5R=V%S
M:"!!=71O;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-C$N-3@S.BTV-"XV-3`G72`]("=297-O;'5T
M:6]N($ES;&%N9"P@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<V,2XV,S,Z+3$R-2XX,#`G72`]("=6:7)G:6YI82!&86QL<R<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S8Q+C8V-SHM,3`X+C0Q-R==(#T@)U!O<G1E
M<B!,86ME)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C$N-S4P.BTQ,C$N
M,C,S)UT@/2`G1F]R="!3:6UP<V]N+"!.+B!7+B!4+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S8Q+CDQ-SHM,3$S+C<S,R==(#T@)TEN;F5R(%=H86QE
M8F%C:W,G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,2XY-C<Z+3$R-RXR
M,3<G72`]("=286)B:70@2V5T=&QE($%U=&]M871E9"!297!O<G1I;F<@4W1A
M=&EO;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8R+C$Q-SHM,3,V+C$X
M,R==(#T@)T-A<FUA8VMS($-3+"!9+B!4+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S8R+C(S,SHM,3,S+C,U,"==(#T@)T9A<F\L(%DN(%0N)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-C(N-#8W.BTQ,30N-#4P)UT@/2`G665L
M;&]W:VYI9F4L($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-C(N-S`P.BTY."XS,#`G72`]("=9871H:WEE9"!,86ME($UE=&5O<F]L;V=I
M8V%L($%E<F]N875T:6-A;"!0<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-C(N-S$W.BTQ,#DN,3@S)UT@/2`G1F]R="!2
M96QI86YC92P@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V
M,BXX,3<Z+3DR+C$Q-R==(#T@)U)A;FMI;B!);FQE="P@3BX@5RX@5"XG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,RXQ-3`Z+3$Q-RXR-C<G72`]("=,
M86,@3&$@36%R=')E)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C,N,C,S
M.BTQ,#$N-S8W)UT@/2`G1'5B87=N="!,86ME($UE=&5O<F]L;V=I8V%L($%E
M<F]N875T:6-A;"!0<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-C,N,S,S.BTV-"XQ-3`G72`]("="<F5V;V]R="!)<VQA
M;F0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,RXU.#,Z+3$P-2XQ-3`G
M72`]("=(86YB=7)Y(%)I=F5R($%U=&]M871E9"!297!O<G1I;F<@4W1A=&EO
M;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8S+C8P,#HM,3$S+C@V-R==
M(#T@)TQO=V5R($-A<G`@3&%K92P@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<V,RXV,3<Z+3$S-2XX-C<G72`]("=-87EO($%I<G!O<G0G
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,RXW-3`Z+38X+C4U,"==(#T@
M)TEQ86QU:70L($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-C0N,#4P.BTQ,SDN,3,S)UT@/2`G1&%W<V]N+"!9+B!4+B<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S8T+C$Q-SHM,3$W+C,V-R==(#T@)U)A92!,86ME
M<R<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8T+C(P,#HM.#,N,S8W)UT@
M/2`G0V]R86P@2&%R8F]U<BP@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<V-"XR,3<Z+3<V+C4S,R==(#T@)T-A<&4@1&]R<V5T+"!.+B!7
M+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8T+C,P,#HM.38N,#@S
M)UT@/2`G0F%K97(@3&%K92P@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<V-"XS.#,Z+3$Q-2XP,3<G72`]("=);F1I86X@4FEV97(G.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<V-"XW-3`Z+3$R-"XR,3<G72`]("=3
M="!#:&%R;&5S($-R965K)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C0N
M.34P.BTV,RXU.#,G72`]("=#87!E($UE<F-Y)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-C4N,3`P.BTQ,#(N-#,S)UT@/2`G4F]B97)T<V]N($QA:V4@
M075T;VUA=&5D(%)E<&]R=&EN9R!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-C4N,C$W.BTQ,C,N-#,S)UT@/2`G1&5L:6YE+"!.+B!7+B!4
M+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8U+C(X,SHM,3(V+C@P,"==
M(#T@)TYO<FUA;B!796QL<RP@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<V-2XV,3<Z+3$Q."XQ,3<G72`]("=#86US96QL(%)I=F5R+"!.
M+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8U+C<V-SHM,3$Q
M+C(S,R==(#T@)TQU<&EN+"!.+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S8U+CDU,#HM,3,P+C0V-R==(#T@)U)A;7!A<G0@4FEV97(@075T
M;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S8V+C`P,#HM,3$W+C<V-R==(#T@)T-L=70@3&%K92!!
M=71O;6%T960@4F5P;W)T:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<V-BXP,S,Z+3DQ+C@S,R==(#T@)T(L(%(G.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<V-BXP.#,Z+3DV+C4P,"==(#T@)T)A8VL@4FEV97(@
M365T96]R;VQO9VEC86P@065R;VYA=71I8V%L(%!R97-E;G1A=&EO;B!3>7-T
M96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V-BXQ-3`Z+38U+C<S,R==
M(#T@)U!A;F=N:7)T=6YG)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C8N
M-3@S.BTV,2XV,3<G72`]("=#87!E($1Y97(L($XN(%<N(%0N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-C8N.#8W.BTQ,S0N,C`P)UT@/2`G4V%T86@@
M4FEV97(@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S8W+C`S,SHM,3(V+C`X,R==(#T@)T-O
M;'9I;&QE($QA:V4G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V-RXP-C<Z
M+3$R,2XQ,#`G72`]("=(86QD86YE(%)I=F5R($%U=&]M871I8R!796%T:&5R
M(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V
M-RXR,#`Z+3$S,"XR,3<G72`]("=,:71T;&4@0VAI8V%G;R<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S8W+C4S,SHM-C,N-S@S)UT@/2`G0G)O=6=H=&]N
M($ES;&%N9"<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8W+C4V-SHM,3,Y
M+C@S,R==(#T@)T]L9"!#<F]W($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN
M9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V-RXW,#`Z+3$P
M-"XT-C<G72`]("=%;&QI8V4@4FEV97(@075T;VUA=&5D(%)E<&]R=&EN9R!3
M=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C<N.#$W.BTQ,34N
M,3,S)UT@/2`G0V]P<&5R;6EN92P@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<V."XR-3@Z+3$R,BXQ,#0G72`]("=1879V:6L@3&%K92P@
M3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V."XS,#`Z+3$S
M,RXT.#,G72`]("=);G5V:6LL($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-C@N,S`P.BTX-2XV-C<G72`]("=-86-K87(@26YL970G.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<V."XS,3<Z+3$P,"XP.#,G72`]("=(
M870@27-L86YD+"!.+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S8X+C0S,SHM.#DN-S$W)UT@/2`G4&5L;'D@0F%Y)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-C@N-#8W.BTV-BXX,#`G72`]("=#87!E($AO;W!E<BP@
M3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V."XU,#`Z+3$Q
M,RXR,3<G72`]("=,861Y($9R86YK;&EN(%!O:6YT+"!.+B!7+B!4+B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S8X+C8U,#HM,3`Q+C<S,R==(#T@)TIE
M;FYY($QI;F0@27-L86YD($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<V."XV-3`Z+3<Q+C$V-R==(#T@)T1E=V%R($QA:V5S+"!.+B!7+B!4
M+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8X+C<U,#HM,3`Y+C`V-R==
M(#T@)T)Y<F]N($)A>2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-C@N-S4P.BTQ,S,N-3`P)UT@/2`G5')A:6P@5F%L;&5Y+"!.+B!7+B!4
M+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8X+C<X,SHM,3$T+C@S,R==
M(#T@)T)E<FYA<F0@2&%R8F]U<B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S8X+C<X,SHM.#$N,C4P)UT@/2`G2&%L;"!"96%C:"P@3BX@5RX@5"XG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<V."XX,3<Z+3DS+C0S,R==(#T@)U-H
M97!H97)D($)A>2P@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<V."XX.#,Z+3<U+C$S,R==(#T@)TQO;F=S=&%F9B!";'5F9BP@3BX@5RX@
M5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V."XY,#`Z+3$S,RXY,S,G
M72`]("=3=&]R;2!(:6QL<RP@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<V."XY,S,Z+3$Q-BXY,3<G72`]("=#87!E(%EO=6YG($%I<G!O
M<G0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V."XY-3`Z+3$S-RXR,3<G
M72`]("=3:&EN9VQE(%!O:6YT+"!9+B!4+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S8Y+C$P,#HM,3`U+C$Q-R==(#T@)T-A;6)R:61G92!"87DL($XN
M(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-CDN,34P.BTQ-#`N
M,34P)UT@/2`G279V879I:R!087)K($%U=&]M871I8R!796%T:&5R(%)E<&]R
M=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V.2XQ.#,Z
M+3$R,BXS-3`G72`]("=4=6MT=70@3F]G86ET+"!.+B!7+B!4+B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S8Y+C,U,#HM,3(T+C`U,"==(#T@)U!A=6QA
M='5K($%U=&]M871E9"!297!O<G1I;F<@4W1A=&EO;B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S8Y+C0S,SHM,3,S+C`S,R==(#T@)U1U:W1O>6%K='5K
M($%U=&]M871E9"!297!O<G1I;F<@4W1A=&EO;B<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S8Y+C0S,SHM.#DN-S,S)UT@/2`G4&5L;'D@0F%Y(#$G.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<V.2XT-3`Z+3$S,RXP,3<G72`]("=4
M=6MT;WEA:W1U:R<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8Y+C4V-SHM
M,3,X+CDQ-R==(#T@)TAE<G-C:&5L($ES;&%N9"!!=71O;6%T:6,@5V5A=&AE
M<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-CDN-3@S.BTQ-#`N,3@S)UT@/2`G2V]M86MU:R!"96%C:"!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-CDN-C`P.BTQ,S`N.3`P)UT@/2`G
M3&EV97)P;V]L($)A>2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8Y+C8Q
M-SHM,30P+C(P,"==(#T@)TMO;6%K=6L@0F5A8V@L(%DN(%0N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-CDN-C,S.BTQ,S4N-#,S)UT@/2`G4&5L;'D@
M27-L86YD($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<V.2XY,S,Z+3$R."XY-C<G72`]("=.
M:6-H;VQS;VX@4&5N:6YS=6PG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<W
M,"XQ-C<Z+3$R-"XW,#`G72`]("=#87!E(%!A<G)Y+"!.+B!7+B!4+B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S<P+C0X,SHM-C@N-3$W)UT@/2`G0VQY
M9&4L($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-S(N,#`P
M.BTQ,C4N,C8W)UT@/2`G4V%C:',@2&%R8F]U<BP@3BX@5RX@5"XG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<W,BXW,#`Z+3<W+CDV-R==(#T@)U!O;F0@
M26YL970L($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-S0N
M,3,S.BTQ,3DN.3@S)UT@/2`G075L=FEK($YA=&EO;F%L(%!A<FLG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<W-"XW,3<Z+3DT+CDX,R==(#T@)U)E<V]L
M=71E+"!.+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S<V+C(S
M,SHM,3$Y+C,S,R==(#T@)TUO=6QD($)A>2P@3BX@5RX@5"XG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<W."XW.#,Z+3$P,RXU-3`G72`]("=)<V%C:'-E
M;B!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y
M<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S<Y+CDX,SHM.#4N.3,S
M)UT@/2`G175R96MA+"!.+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S@R+C4P,#HM-C(N,S,S)UT@/2`G06QE<G0L($XN(%<N(%0N)SL*)&-O
M;W)D:6YA=&5S6R=#87!E(%9E<F1E)UU;)S$V+C<S,SHM,C(N.34P)UT@/2`G
M4V%L)SL*)&-O;W)D:6YA=&5S6R=#87EM86X@27-L86YD<R==6R<Q.2XR.#,Z
M+3@Q+C,U,"==(#T@)T]W96X@4F]B97)T<R!!:7)P;W)T9W)A;F0@0V%Y;6%N
M)SL*)&-O;W)D:6YA=&5S6R=#96YT<F%L($%F<FEC86X@4F5P=6)L:6,G75LG
M,3`N,C@S.C(R+C<X,R==(#T@)T)I<F%O)SL*)&-O;W)D:6YA=&5S6R=#96YT
M<F%L($%F<FEC86X@4F5P=6)L:6,G75LG-"XR-3`Z,34N.#`P)UT@/2`G0F5R
M8F5R871I)SL*)&-O;W)D:6YA=&5S6R=#96YT<F%L($%F<FEC86X@4F5P=6)L
M:6,G75LG-"XT,#`Z,3@N-3$W)UT@/2`G0F%N9W5I)SL*)&-O;W)D:6YA=&5S
M6R=#96YT<F%L($%F<FEC86X@4F5P=6)L:6,G75LG-"XW,S,Z,C(N.#,S)UT@
M/2`G0F%N9V%S<V]U)SL*)&-O;W)D:6YA=&5S6R=#96YT<F%L($%F<FEC86X@
M4F5P=6)L:6,G75LG-2XP-3`Z,C$N,C`P)UT@/2`G06QI;F1A;R<["B1C;V]R
M9&EN871E<ULG0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC)UU;)S4N,C8W.C$W
M+C8S,R==(#T@)T)O<W-E;6)E;&4G.PHD8V]O<F1I;F%T97-;)T-E;G1R86P@
M069R:6-A;B!297!U8FQI8R==6R<U+C0P,#HR-BXU,#`G72`]("=/8F\G.PHD
M8V]O<F1I;F%T97-;)T-E;G1R86P@069R:6-A;B!297!U8FQI8R==6R<U+C@U
M,#HR,"XV-3`G72`]("="86UB87)I)SL*)&-O;W)D:6YA=&5S6R=#96YT<F%L
M($%F<FEC86X@4F5P=6)L:6,G75LG-2XY-C<Z,34N-C,S)UT@/2`G0F]U87(G
M.PHD8V]O<F1I;F%T97-;)T-E;G1R86P@069R:6-A;B!297!U8FQI8R==6R<V
M+C0X,SHQ-RXT,S,G72`]("=";W-S86YG;V$G.PHD8V]O<F1I;F%T97-;)T-E
M;G1R86P@069R:6-A;B!297!U8FQI8R==6R<V+C4P,#HR,RXR-C<G72`]("=9
M86QI;F=A)SL*)&-O;W)D:6YA=&5S6R=#96YT<F%L($%F<FEC86X@4F5P=6)L
M:6,G75LG-BXU,S,Z,C$N.3@S)UT@/2`G0G)I82<["B1C;V]R9&EN871E<ULG
M0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC)UU;)S@N-#`P.C(P+C8U,"==(#T@
M)TY<)T1E;&4G.PHD8V]O<F1I;F%T97-;)T-H860G75LG,3$N,#,S.C(P+C(X
M,R==(#T@)T%M+51I;6%N)SL*)&-O;W)D:6YA=&5S6R=#:&%D)UU;)S$R+C$S
M,SHQ-2XP,S,G72`]("=.9&IA;65N82<["B1C;V]R9&EN871E<ULG0VAA9"==
M6R<Q,BXS.#,Z,3<N,#4P)UT@/2`G0F]K;W)O)SL*)&-O;W)D:6YA=&5S6R=#
M:&%D)UU;)S$S+C0S,SHQ-"XW,S,G72`]("=";VPM0F5R:6TG.PHD8V]O<F1I
M;F%T97-;)T-H860G75LG,3,N.#4P.C(P+C@U,"==(#T@)T%B96-H92<["B1C
M;V]R9&EN871E<ULG0VAA9"==6R<Q."XP,#`Z,3DN,38W)UT@/2`G1F%Y82<[
M"B1C;V]R9&EN871E<ULG0VAA9"==6R<X+C8Q-SHQ-BXP-C<G72`]("=-;W5N
M9&]U)SL*)&-O;W)D:6YA=&5S6R=#:&%D)UU;)SDN,34P.C$X+C,X,R==(#T@
M)U-A<F@G.PHD8V]O<F1I;F%T97-;)T-H860G75LG.2XS-C<Z,30N.3$W)UT@
M/2`G4&%L82<["B1C;V]R9&EN871E<ULG0VAI;&4G75LG+3$X+C,S,SHM-S`N
M,S,S)UT@/2`G07)I8V$G.PHD8V]O<F1I;F%T97-;)T-H:6QE)UU;)RTR,"XU
M,S,Z+3<P+C$X,R==(#T@)TEQ=6EQ=64@+R!$:65G;R!!<F%C)SL*)&-O;W)D
M:6YA=&5S6R=#:&EL92==6R<M,C,N-#,S.BTW,"XT,S,G72`]("=!;G1O9F%G
M87-T82<["B1C;V]R9&EN871E<ULG0VAI;&4G75LG+3(V+C,Q-SHM-S`N-C$W
M)UT@/2`G0VAA;F%R86PG.PHD8V]O<F1I;F%T97-;)T-H:6QE)UU;)RTR-RXQ
M-3`Z+3$P.2XT,3<G72`]("=)<VQA($1E(%!A<V-U82<["B1C;V]R9&EN871E
M<ULG0VAI;&4G75LG+3(W+C,P,#HM-S`N-#$W)UT@/2`G0V]P:6%P;R<["B1C
M;V]R9&EN871E<ULG0VAI;&4G75LG+3(X+C8P,#HM-S`N-S8W)UT@/2`G5F%L
M;&5N87(G.PHD8V]O<F1I;F%T97-;)T-H:6QE)UU;)RTR.2XY,#`Z+3<Q+C(P
M,"==(#T@)TQA(%-E<F5N82<["B1C;V]R9&EN871E<ULG0VAI;&4G75LG+3,R
M+C<X,SHM-S$N-3$W)UT@/2`G475I;G1E<F\@4V%N=&EA9V\G.PHD8V]O<F1I
M;F%T97-;)T-H:6QE)UU;)RTS,RXS.#,Z+3<P+C<X,R==(#T@)U!U9&%H=65L
M)SL*)&-O;W)D:6YA=&5S6R=#:&EL92==6R<M,S0N.38W.BTW,2XR,S,G72`]
M("=#=7)I8V\G.PHD8V]O<F1I;F%T97-;)T-H:6QE)UU;)RTS-BXU-C<Z+3<R
M+C`S,R==(#T@)T-H:6QL86XG.PHD8V]O<F1I;F%T97-;)T-H:6QE)UU;)RTS
M-BXW-C<Z+3<S+C`U,"==(#T@)T-O;F-E<&-I;VXG.PHD8V]O<F1I;F%T97-;
M)T-H:6QE)UU;)RTS."XW-3`Z+3<R+C8S,R==(#T@)U1E;75C;R<["B1C;V]R
M9&EN871E<ULG0VAI;&4G75LG+3,Y+C8Q-SHM-S,N,#@S)UT@/2`G5F%L9&EV
M:6$G.PHD8V]O<F1I;F%T97-;)T-H:6QE)UU;)RTT,2XT,3<Z+3<S+C`X,R==
M(#T@)U!U97)T;R!-;VYT="<["B1C;V]R9&EN871E<ULG0VAI;&4G75LG+30U
M+C4X,SHM-S(N,3$W)UT@/2`G0V]Y:&%I<75E)SL*)&-O;W)D:6YA=&5S6R=#
M:&EL92==6R<M-#4N.3$W.BTW,2XV.#,G72`]("="86QM86-E9&$G.PHD8V]O
M<F1I;F%T97-;)T-H:6QE)UU;)RTT-BXU-3`Z+3<Q+C<P,"==(#T@)T-H:6QE
M($-H:6-O)SL*)&-O;W)D:6YA=&5S6R=#:&EL92==6R<M-#<N,C,S.BTW,BXU
M-3`G72`]("=#;V-H<F%N92<["B1C;V]R9&EN871E<ULG0VAI;&4G75LG+34S
M+C`P,#HM-S`N.#4P)UT@/2`G4'5N=&$@07)E;F%S)SL*)&-O;W)D:6YA=&5S
M6R=#:&EN82==6R<R,"XP,S,Z,3$P+C,U,"==(#T@)TAA:6MO=2<["B1C;V]R
M9&EN871E<ULG0VAI;F$G75LG,C$N,C$W.C$Q,"XT,#`G72`]("=::&%N:FEA
M;F<G.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S(R+C4U,#HQ,30N,3`P)UT@
M/2`G4VAE;GIH96XG.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S(R+C@Q-SHQ
M,#@N,S4P)UT@/2`G3F%N;FEN9R<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG
M,C,N,38W.C$Q,RXS,S,G72`]("='=6%N9WIH;W4G.PHD8V]O<F1I;F%T97-;
M)T-H:6YA)UU;)S(S+C0P,#HQ,38N-C@S)UT@/2`G4VAA;G1O=2<["B1C;V]R
M9&EN871E<ULG0VAI;F$G75LG,C0N-#@S.C$Q."XP.#,G72`]("=8:6%M96XG
M.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S(U+C`Q-SHQ,#(N-C@S)UT@/2`G
M2W5N;6EN9R<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG,C4N,S,S.C$Q,"XS
M,#`G72`]("='=6EL:6XG.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S(U+C@U
M,#HQ,30N.34P)UT@/2`G1V%N>FAO=2<["B1C;V]R9&EN871E<ULG0VAI;F$G
M75LG,C8N,#@S.C$Q.2XR.#,G72`]("=&=7IH;W4G.PHD8V]O<F1I;F%T97-;
M)T-H:6YA)UU;)S(V+C4X,SHQ,#8N-S$W)UT@/2`G1W5I>6%N9R<["B1C;V]R
M9&EN871E<ULG0VAI;F$G75LG,C@N,C`P.C$Q,RXP.#,G72`]("=#:&%N9W-H
M82<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG,C@N-C`P.C$Q-2XY,3<G72`]
M("=.86YC:&%N9R<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG,CDN-3$W.C$P
M-BXT.#,G72`]("=#:&]N9W%I;F<G.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;
M)S(Y+C8V-SHY,2XQ,S,G72`]("=,:&%S82<["B1C;V]R9&EN871E<ULG0VAI
M;F$G75LG,S`N,C,S.C$R,"XQ-C<G72`]("=(86YG>FAO=2<["B1C;V]R9&EN
M871E<ULG0VAI;F$G75LG,S`N-C$W.C$Q-"XQ,S,G72`]("=7=6AA;B<["B1C
M;V]R9&EN871E<ULG0VAI;F$G75LG,S`N-C8W.C$P-"XP,3<G72`]("=#:&5N
M9V1U)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==6R<S,2XQ-C<Z,3(Q+C0S,R==
M(#T@)U-H86YG:&%I("\@2&]N9W%I86\G.PHD8V]O<F1I;F%T97-;)T-H:6YA
M)UU;)S,Q+C@V-SHQ,3<N,C,S)UT@/2`G2&5F96DG.PHD8V]O<F1I;F%T97-;
M)T-H:6YA)UU;)S,R+C`P,#HQ,3@N.#`P)UT@/2`G3F%N:FEN9R<["B1C;V]R
M9&EN871E<ULG0VAI;F$G75LG,S0N,S`P.C$P."XY,S,G72`]("=8:5PG06XG
M.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S,T+C<Q-SHQ,3,N-C4P)UT@/2`G
M6FAE;F=Z:&]U)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==6R<S-BXP-C<Z,3(P
M+C,S,R==(#T@)U%I;F=D86\G.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S,V
M+C8P,#HQ,#DN-3`P)UT@/2`G66%N($%N)SL*)&-O;W)D:6YA=&5S6R=#:&EN
M82==6R<S-BXV,3<Z,3`Q+C<V-R==(#T@)UAI;FEN9R<["B1C;V]R9&EN871E
M<ULG0VAI;F$G75LG,S8N-C@S.C$Q-BXY.#,G72`]("=*:6YA;B<["B1C;V]R
M9&EN871E<ULG0VAI;F$G75LG,S<N,3,S.C<Y+CDS,R==(#T@)TAO=&%N)SL*
M)&-O;W)D:6YA=&5S6R=#:&EN82==6R<S-RXW.#,Z,3$R+C4U,"==(#T@)U1A
M:7EU86XG.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S,X+C0X,SHQ,#8N,C$W
M)UT@/2`G66EN8VAU86XG.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S,X+CDP
M,#HQ,C$N-C,S)UT@/2`G1&%L:6%N)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==
M6R<S.2XT-C<Z-S4N.3@S)UT@/2`G2V%S:&DG.PHD8V]O<F1I;F%T97-;)T-H
M:6YA)UU;)S,Y+C<V-SHY."XT.#,G72`]("=*:75Q=6%N)SL*)&-O;W)D:6YA
M=&5S6R=#:&EN82==6R<S.2XY,S,Z,3$V+C(X,R==(#T@)T)E:6II;F<G.PHD
M8V]O<F1I;F%T97-;)T-H:6YA)UU;)S0P+C@Q-SHQ,3$N-C@S)UT@/2`G2&]H
M:&]T)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==6R<T,BXX,3<Z.3,N-3$W)UT@
M/2`G2&%M:2<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG-#,N.3`P.C$R-2XR
M,3<G72`]("=#:&%N9V-H=6XG.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S0S
M+CDU,#HX,2XS,S,G72`]("=9:6YI;F<G.PHD8V]O<F1I;F%T97-;)T-H:6YA
M)UU;)S0W+C,X,SHQ,C,N.3$W)UT@/2`G46EQ:6AA<B<["B1C;V]R9&EN871E
M<ULG0VAR:7-T;6%S($ES;&%N9"==6R<M,3`N-#,S.C$P-2XV.#,G72`]("=#
M:')I<W1M87,@27-L86YD($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG0VAR
M:7-T;6%S($ES;&%N9"==6R<M,3(N,3@S.CDV+C@Q-R==(#T@)T-O8V]S($ES
M;&%N9"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=#;VQO;6)I82==6R<P+C4P
M,#HM-S8N-3`P)UT@/2`G4'5E<G1O($%S:7,G.PHD8V]O<F1I;F%T97-;)T-O
M;&]M8FEA)UU;)S`N.#$W.BTW-RXV,S,G72`]("=)<&EA;&5S("\@4V%N($QU
M:7,G.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;)S$N,3,S.BTW,"XP-3`G
M72`]("=-:71U)SL*)&-O;W)D:6YA=&5S6R=#;VQO;6)I82==6R<Q+C0Q-SHM
M-S<N,C8W)UT@/2`G4&%S=&\@+R!!;G1O;FEO($YA<FEN)SL*)&-O;W)D:6YA
M=&5S6R=#;VQO;6)I82==6R<Q,"XT,S,Z+3<S+C(U,"==(#T@)U9A;&QE9'5P
M87(@+R!!;&9O;G-O($QO<&5Z)SL*)&-O;W)D:6YA=&5S6R=#;VQO;6)I82==
M6R<Q,"XT-3`Z+3<U+C4Q-R==(#T@)T-A<G1A9V5N82`O(%)A9F%E;"!.=6YE
M>B<["B1C;V]R9&EN871E<ULG0V]L;VUB:6$G75LG,3`N.#@S.BTW-"XW.#,G
M72`]("="87)R86YQ=6EL;&$@+R!%<FYE<W1O8V]R=&ES<V]Z)SL*)&-O;W)D
M:6YA=&5S6R=#;VQO;6)I82==6R<Q,2XQ,S,Z+3<T+C(S,R==(#T@)U-A;G1A
M($UA<G1A("\@4VEM;VX@0F]L:79A<B<["B1C;V]R9&EN871E<ULG0V]L;VUB
M:6$G75LG,3$N-3,S.BTW,BXY,S,G72`]("=2:6]H86-H82`O($%L;6ER86YT
M92!0861I;&QA)SL*)&-O;W)D:6YA=&5S6R=#;VQO;6)I82==6R<Q,BXU.#,Z
M+3@Q+C<Q-R==(#T@)U-A;B!!;F1R97,@27-L82`O(%-E<W%U:6-E;G1E;F%R
M:6\G.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;)S$S+C,V-SHM.#$N,S4P
M)UT@/2`G4')O=FED96YC:6$@27-L82`O($5L($5M8G)U:F\G.PHD8V]O<F1I
M;F%T97-;)T-O;&]M8FEA)UU;)S(N-#8W.BTW-BXV,#`G72`]("=0;W!A>6%N
M("\@1W5I;&QE<FUO)SL*)&-O;W)D:6YA=&5S6R=#;VQO;6)I82==6R<R+C4V
M-SHM-S(N-C,S)UT@/2`G4V%N($IO<V4@1&5L($=U879I87)E)SL*)&-O;W)D
M:6YA=&5S6R=#;VQO;6)I82==6R<R+CDV-SHM-S4N,S`P)UT@/2`G3F5I=F$@
M+R!"96YI=&\@4V%L87,G.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;)S,N
M-34P.BTW-BXS.#,G72`]("=#86QI("\@06QF;VYS;R!";VYI;&QA87)A9V]N
M)SL*)&-O;W)D:6YA=&5S6R=#;VQO;6)I82==6R<S+C@U,#HM-S8N.38W)UT@
M/2`G0G5E;F%V96YT=7)A)SL*)&-O;W)D:6YA=&5S6R=#;VQO;6)I82==6R<M
M-"XQ-C<Z+38Y+CDU,"==(#T@)TQE=&EC:6$@+R!687-Q=65Z($-O8F\G.PHD
M8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;)S0N,38W.BTW,RXV,3<G72`]("=6
M:6QL879I8V5N8VEO("\@5F%N9W5A<F1I82<["B1C;V]R9&EN871E<ULG0V]L
M;VUB:6$G75LG-"XT,S,Z+3<U+C$U,"==(#T@)TEB86=U92`O(%!E<F%L97,G
M.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;)S0N-3`P.BTW-2XW,3<G72`]
M("=!<FUE;FEA("\@16P@161E;B<["B1C;V]R9&EN871E<ULG0V]L;VUB:6$G
M75LG-"XW,3<Z+3<T+C$U,"==(#T@)T)O9V]T82`O($5L9&]R861O)SL*)&-O
M;W)D:6YA=&5S6R=#;VQO;6)I82==6R<T+C@Q-SHM-S4N-S,S)UT@/2`G4&5R
M96ER82`O($UA=&5C86YA)SL*)&-O;W)D:6YA=&5S6R=#;VQO;6)I82==6R<U
M+C<Q-SHM-S8N-C$W)UT@/2`G475I8F1O("\@16P@0V%R86YO)SL*)&-O;W)D
M:6YA=&5S6R=#;VQO;6)I82==6R<V+C$S,SHM-S4N-#,S)UT@/2`G4FEO;F5G
M<F\@+R!*+B!-+B!#;W)D;W9A)SL*)&-O;W)D:6YA=&5S6R=#;VQO;6)I82==
M6R<V+C$V-SHM-C<N-3`P)UT@/2`G4'5E<G1O($-A<G)E;F\@+R!!+B!'=6%U
M<75E82<["B1C;V]R9&EN871E<ULG0V]L;VUB:6$G75LG-BXR,3<Z+3<U+C8P
M,"==(#T@)TUE9&5L;&EN("\@3VQA>6$@2&5R<F5R82<["B1C;V]R9&EN871E
M<ULG0V]L;VUB:6$G75LG-RXP,3<Z+3<S+C@P,"==(#T@)T)A<G)A;F-A8F5R
M;65J82`O(%EA<FEG=6EE<R<["B1C;V]R9&EN871E<ULG0V]L;VUB:6$G75LG
M-RXP-C<Z+3<P+C<S,R==(#T@)T%R875C82`O(%-A;G1I86=O(%!E<F5Z)SL*
M)&-O;W)D:6YA=&5S6R=#;VQO;6)I82==6R<W+C$P,#HM-S,N,C`P)UT@/2`G
M0G5C87)A;6%N9V$@+R!086QO;F5G<F\G.PHD8V]O<F1I;F%T97-;)T-O;&]M
M8FEA)UU;)S<N.#$W.BTW-BXW,#`G72`]("=!<&%R=&%D;R`O($QO<R!#961R
M;W,G.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;)S<N.3,S.BTW,BXU,3<G
M72`]("=#=6-U=&$@+R!#86UI;&\@1&%Z82<["B1C;V]R9&EN871E<ULG0V]L
M;VUB:6$G75LG."XX,3<Z+3<U+C@U,"==(#T@)TUO;G1E<FEA("\@3&]S($=A
M<GIO;F5S)SL*)&-O;W)D:6YA=&5S6R=#;VUO<F]S)UU;)RTQ,2XU,S,Z-#,N
M,C8W)UT@/2`G2&%H87EA($EN=&5R;F%T:6]N86P@06ER<&]R="<["B1C;V]R
M9&EN871E<ULG0V]M;W)O<R==6R<M,3(N,3$W.C0T+C0S,R==(#T@)T]U86YI
M($%N:F]U86XG.PHD8V]O<F1I;F%T97-;)T-O;6]R;W,G75LG+3$R+C@P,#HT
M-2XR.#,G72`]("=$>F%O=61Z:2`O(%!A;6%N>FD@36%Y;W1T92<["B1C;V]R
M9&EN871E<ULG0V]N9V\G75LG+3`N,#$W.C$U+C4X,R==(#T@)TUA:V]U82<[
M"B1C;V]R9&EN871E<ULG0V]N9V\G75LG,2XV,3<Z,38N,#4P)UT@/2`G3W5E
M<W-O)SL*)&-O;W)D:6YA=&5S6R=#;VYG;R==6R<Q+C8Q-SHQ."XP-C<G72`]
M("=);7!F;VYD;R<["B1C;V]R9&EN871E<ULG0V]N9V\G75LG+3$N.#8W.C$U
M+C@V-R==(#T@)T=A;6)O;6$G.PHD8V]O<F1I;F%T97-;)T-O;F=O)UU;)S(N
M,#8W.C$T+C$S,R==(#T@)U-O=6%N:V4G.PHD8V]O<F1I;F%T97-;)T-O;F=O
M)UU;)RTR+C4S,SHQ-"XW-C<G72`]("=$:F%M8F%L82<["B1C;V]R9&EN871E
M<ULG0V]N9V\G75LG+3(N-C$W.C$V+C(Q-R==(#T@)TU<)U!O=7EA)SL*)&-O
M;W)D:6YA=&5S6R=#;VYG;R==6R<M,RXT.#,Z,3(N-C$W)UT@/2`G36%K86)A
M;F$G.PHD8V]O<F1I;F%T97-;)T-O;F=O)UU;)RTS+C8X,SHQ,RXS-3`G72`]
M("=3:6)I=&DG.PHD8V]O<F1I;F%T97-;)T-O;F=O)UU;)RTS+CDX,SHQ,RXY
M,3<G72`]("=-;W5Y;VYD>FDG.PHD8V]O<F1I;F%T97-;)T-O;F=O)UU;)RTT
M+C(P,#HQ,BXW,#`G72`]("=,;W5B;VUO)SL*)&-O;W)D:6YA=&5S6R=#;VYG
M;R==6R<M-"XR-3`Z,34N,C4P)UT@/2`G0G)A>GIA=FEL;&4@+R!-87EA+4UA
M>6$G.PHD8V]O<F1I;F%T97-;)T-O;F=O)UU;)RTT+C@Q-SHQ,2XY,#`G72`]
M("=0;VEN=&4M3F]I<F4G.PHD8V]O<F1I;F%T97-;)T-O;VL@27-L86YD<R==
M6R<M,3DN,#8W.BTQ-CDN.3$W)UT@/2`G06QO9FD@+R!.:75E)SL*)&-O;W)D
M:6YA=&5S6R=#;V]K($ES;&%N9',G75LG+3(Q+C(P,#HM,34Y+C@Q-R==(#T@
M)U)A<F]T;VYG82<["B1C;V]R9&EN871E<ULG0V]S=&$@4FEC82==6R<Q,"XP
M,#`Z+3@S+C`U,"==(#T@)U!U97)T;R!,:6UO;B<["B1C;V]R9&EN871E<ULG
M0V]S=&$@4FEC82==6R<Q,"XP,#`Z+3@T+C(Q-R==(#T@)TIU86X@4V%N=&%M
M87)I82<["B1C;V]R9&EN871E<ULG0V]S=&$@4FEC82==6R<Q,"XQ-3`Z+3@U
M+C0U,"==(#T@)TYI8V]Y82<["B1C;V]R9&EN871E<ULG0V]S=&$@4FEC82==
M6R<Q,"XV,3<Z+3@U+C0S,R==(#T@)TQI8F5R:6$G.PHD8V]O<F1I;F%T97-;
M)T-O<W1A(%)I8V$G75LG."XY-3`Z+3@S+C0V-R==(#T@)U!A;&UA<B!3=7(G
M.PHD8V]O<F1I;F%T97-;)T-O=&4@1%PG279O:7)E)UU;)S0N-#$W.BTW+C,V
M-R==(#T@)U1A8F]U)SL*)&-O;W)D:6YA=&5S6R=#;W1E($1<)TEV;VER92==
M6R<T+C<U,#HM-BXV-3`G72`]("=386X@4&5D<F\G.PHD8V]O<F1I;F%T97-;
M)T-O=&4@1%PG279O:7)E)UU;)S0N.34P.BTV+C`X,R==(#T@)U-A<W-A;F1R
M82<["B1C;V]R9&EN871E<ULG0V]T92!$7"=)=F]I<F4G75LG-2XR-3`Z+3,N
M.3,S)UT@/2`G06)I9&IA;B<["B1C;V]R9&EN871E<ULG0V]T92!$7"=)=F]I
M<F4G75LG-2XS,#`Z+3,N,S`P)UT@/2`G061I86ME)SL*)&-O;W)D:6YA=&5S
M6R=#;W1E($1<)TEV;VER92==6R<V+C$S,SHM-2XY-3`G72`]("='86=N;V$G
M.PHD8V]O<F1I;F%T97-;)T-O=&4@1%PG279O:7)E)UU;)S8N-C4P.BTT+C<P
M,"==(#T@)T1I;6)O:W)O)SL*)&-O;W)D:6YA=&5S6R=#;W1E($1<)TEV;VER
M92==6R<V+C@V-SHM-BXT-C<G72`]("=$86QO82<["B1C;V]R9&EN871E<ULG
M0V]T92!$7"=)=F]I<F4G75LG-BXY,#`Z+34N,S4P)UT@/2`G66%M;W5S<V]U
M:W)O)SL*)&-O;W)D:6YA=&5S6R=#;W1E($1<)TEV;VER92==6R<W+C,X,SHM
M-RXU,3<G72`]("=-86XG.PHD8V]O<F1I;F%T97-;)T-O=&4@1%PG279O:7)E
M)UU;)S<N-S,S.BTU+C`V-R==(#T@)T)O=6%K92<["B1C;V]R9&EN871E<ULG
M0V]T92!$7"=)=F]I<F4G75LG."XP-3`Z+3(N-S@S)UT@/2`G0F]N9&]U:V]U
M)SL*)&-O;W)D:6YA=&5S6R=#;W1E($1<)TEV;VER92==6R<Y+C0Q-SHM-2XV
M,3<G72`]("=+;W)H;V=O)SL*)&-O;W)D:6YA=&5S6R=#;W1E($1<)TEV;VER
M92==6R<Y+C4P,#HM-RXU-C<G72`]("=/9&EE;FYE)SL*)&-O;W)D:6YA=&5S
M6R=#<F]A=&EA)UU;)S0R+C4V-SHQ."XR-C<G72`]("=$=6)R;W9N:6L@+R!#
M:6QI<&DG.PHD8V]O<F1I;F%T97-;)T-R;V%T:6$G75LG-#,N,38W.C$V+C0U
M,"==(#T@)TAV87(G.PHD8V]O<F1I;F%T97-;)T-R;V%T:6$G75LG-#,N-3,S
M.C$V+C,P,"==(#T@)U-P;&ET("\@4F5S;FEK)SL*)&-O;W)D:6YA=&5S6R=#
M<F]A=&EA)UU;)S0T+C$P,#HQ-2XS-3`G72`]("=:861A<B`O(%IE;75N:6LG
M.PHD8V]O<F1I;F%T97-;)T-R;V%T:6$G75LG-#4N,#,S.C$X+C@P,"==(#T@
M)T]S:6IE:R`O($-E<&EN)SL*)&-O;W)D:6YA=&5S6R=#<F]A=&EA)UU;)S0U
M+C$V-SHQ."XP,#`G72`]("=3;&%V;VYS:VD@0G)O9"<["B1C;V]R9&EN871E
M<ULG0W)O871I82==6R<T-2XR,3<Z,30N-3@S)UT@/2`G4FEJ96MA("\@3VUI
M<V%L:B<["B1C;V]R9&EN871E<ULG0W)O871I82==6R<T-2XW,S,Z,38N,#8W
M)UT@/2`G6F%G<F5B("\@4&QE<V\G.PHD8V]O<F1I;F%T97-;)T-R;V%T:6$G
M75LG-#4N.#$W.C$V+C`S,R==(#T@)UIA9W)E8B`O($UA:W-I;6ER)SL*)&-O
M;W)D:6YA=&5S6R=#<F]A=&EA)UU;)S0U+CDP,#HQ,RXY,3<G72`]("=0=6QA
M($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG0W)O871I82==6R<T-BXS,#`Z
M,38N,S@S)UT@/2`G5F%R87ID:6XG.PHD8V]O<F1I;F%T97-;)T-U8F$G75LG
M,3DN.3`P.BTW-2XQ,S,G72`]("='=6%N=&%N86UO+"!/<FEE;G1E)SL*)&-O
M;W)D:6YA=&5S6R=#=6)A)UU;)S$Y+CDV-SHM-S4N.#4P)UT@/2`G4V%N=&EA
M9V\@1&4@0W5B82P@3W)I96YT92<["B1C;V]R9&EN871E<ULG0W5B82==6R<R
M,"XP.#,Z+3<U+C$U,"==(#T@)T=U86YT86YA;6\L($]R:65N=&4G.PHD8V]O
M<F1I;F%T97-;)T-U8F$G75LG,C`N,S,S.BTW-RXQ,3<G72`]("=-86YZ86YI
M;&QO+"!/<FEE;G1E)SL*)&-O;W)D:6YA=&5S6R=#=6)A)UU;)S(P+C,U,#HM
M-S0N-3`P)UT@/2`G0F%R86-O82P@3W)I96YT92<["B1C;V]R9&EN871E<ULG
M0W5B82==6R<R,"XY-3`Z+3<V+CDU,"==(#T@)TQA<R!4=6YA<RP@3&%S(%1U
M;F%S)SL*)&-O;W)D:6YA=&5S6R=#=6)A)UU;)S(Q+C0Q-SHM-S<N.#4P)UT@
M/2`G0V%M86=U97D@065R;W!U97)T;R<["B1C;V]R9&EN871E<ULG0W5B82==
M6R<R,2XW.#,Z+3<X+C<X,R==(#T@)U9E;F5Z=65L82P@0VEE9V\@1&4@079I
M;&$G.PHD8V]O<F1I;F%T97-;)T-U8F$G75LG,C$N.#,S.BTX,BXW.#,G72`]
M("=.=65V82!'97)O;F$L($ES;&$@1&4@4&EN;W,G.PHD8V]O<F1I;F%T97-;
M)T-U8F$G75LG,C(N,34P.BTX,"XT,#`G72`]("=#:65N9G5E9V]S+"!,87,@
M5FEL;&%S)SL*)&-O;W)D:6YA=&5S6R=#=6)A)UU;)S(R+C0Q-SHM.#,N-C@S
M)UT@/2`G4&EN87(@1&5L(%)I;RP@4&EN87(@1&5L(%)I;R<["B1C;V]R9&EN
M871E<ULG0W5B82==6R<R,BXY.#,Z+3@R+C0P,"==(#T@)T%E<F]P=65R=&\@
M2F]S92!-87)T:2P@4F%N8VAO+4)O>65R;W,L($AA8F%N82<["B1C;V]R9&EN
M871E<ULG0W5B82==6R<R,RXQ,S,Z+3@Q+C(X,R==(#T@)U9A<F%D97)O+"!-
M871A;GIA<R<["B1C;V]R9&EN871E<ULG0WEP<G5S)UU;)S,T+C4X,SHS,BXY
M.#,G72`]("=!:W)O=&ER:2<["B1C;V]R9&EN871E<ULG0WEP<G5S)UU;)S,T
M+C<Q-SHS,BXT.#,G72`]("=087!H;W,@06ER<&]R="<["B1C;V]R9&EN871E
M<ULG0WEP<G5S)UU;)S,T+C@X,SHS,RXV,S,G72`]("=,87)N86-A($%I<G!O
M<G0G.PHD8V]O<F1I;F%T97-;)T-Y<')U<R==6R<S-2XQ-3`Z,S,N-#`P)UT@
M/2`G071H86QA<W-A)SL*)&-O;W)D:6YA=&5S6R=#>F5C:"!297!U8FQI8R==
M6R<T.2XQ-3`Z,38N-S`P)UT@/2`G0G)N;R`O(%1U<F%N>2<["B1C;V]R9&EN
M871E<ULG0WIE8V@@4F5P=6)L:6,G75LG-#DN,S$W.C$W+C4V-R==(#T@)TAO
M;&5S;W8G.PHD8V]O<F1I;F%T97-;)T-Z96-H(%)E<'5B;&EC)UU;)S0Y+C8X
M,SHQ."XQ,3<G72`]("=/<W1R879A("\@36]S;F]V)SL*)&-O;W)D:6YA=&5S
M6R=#>F5C:"!297!U8FQI8R==6R<U,"XQ,#`Z,30N,C4P)UT@/2`G4')A:&$@
M+R!2=7IY;F4G.PHD8V]O<F1I;F%T97-;)T-Z96-H(%)E<'5B;&EC)UU;)S4P
M+C(P,#HQ,BXY,3<G72`]("=+87)L;W9Y(%9A<GDG.PHD8V]O<F1I;F%T97-;
M)T1E;FUA<FLG75LG-30N-S`P.C$Q+C0U,"==(#T@)TUA<FEB;R!,=69T:&%V
M;B<["B1C;V]R9&EN871E<ULG1&5N;6%R:R==6R<U-"XY-C<Z.2XW.#,G72`]
M("=3;V5N9&5R8F]R9R!,=69T:&%V;B<["B1C;V]R9&EN871E<ULG1&5N;6%R
M:R==6R<U-2XP,3<Z,3`N-38W)UT@/2`G4WED9GEN<R!&;'EV97!L861S)SL*
M)&-O;W)D:6YA=&5S6R=$96YM87)K)UU;)S4U+C`V-SHQ-"XW-3`G72`]("=2
M;V5N;F4G.PHD8V]O<F1I;F%T97-;)T1E;FUA<FLG75LG-34N,#@S.C$Q+C<X
M,R==(#T@)T%V;F\@1&%N:7-H($%I<B!&;W)C92!"87-E)SL*)&-O;W)D:6YA
M=&5S6R=$96YM87)K)UU;)S4U+C(S,SHY+C(V-R==(#T@)U-K<GED<W1R=7`G
M.PHD8V]O<F1I;F%T97-;)T1E;FUA<FLG75LG-34N-#,S.CDN,S,S)UT@/2`G
M5F%M9')U<"<["B1C;V]R9&EN871E<ULG1&5N;6%R:R==6R<U-2XT.#,Z,3`N
M,S,S)UT@/2`G3V1E;G-E("\@0F5L9')I;F=E)SL*)&-O;W)D:6YA=&5S6R=$
M96YM87)K)UU;)S4U+C4S,SHX+C4V-R==(#T@)T5S8FIE<F<G.PHD8V]O<F1I
M;F%T97-;)T1E;FUA<FLG75LG-34N-3@S.C$R+C$S,R==(#T@)TMO96)E;FAA
M=FX@+R!2;W-K:6QD92<["B1C;V]R9&EN871E<ULG1&5N;6%R:R==6R<U-2XV
M,3<Z,3(N-C4P)UT@/2`G2V]E8F5N:&%V;B`O($MA<W1R=7`G.PHD8V]O<F1I
M;F%T97-;)T1E;FUA<FLG75LG-34N-S`P.CDN,C`P)UT@/2`G5F%N9&5L)SL*
M)&-O;W)D:6YA=&5S6R=$96YM87)K)UU;)S4U+C<S,SHY+C$V-R==(#T@)T)I
M;&QU;F0@3'5F=&AA=FXG.PHD8V]O<F1I;F%T97-;)T1E;FUA<FLG75LG-34N
M-S8W.C$R+C,S,R==(#T@)U9A97)L;V5S92<["B1C;V]R9&EN871E<ULG1&5N
M;6%R:R==6R<U-BXP,#`Z."XS-3`G72`]("=3=&%U;FEN9R!,=69T:&%V;B<[
M"B1C;V]R9&EN871E<ULG1&5N;6%R:R==6R<U-BXS,#`Z,3`N-C$W)UT@/2`G
M5&ER<W1R=7`G.PHD8V]O<F1I;F%T97-;)T1E;FUA<FLG75LG-38N,S`P.CDN
M,3$W)UT@/2`G2V%R=7`G.PHD8V]O<F1I;F%T97-;)T1E;FUA<FLG75LG-38N
M-#`P.C@N-#4P)UT@/2`G3&EN9'1O<G`@06ER<&]R="<["B1C;V]R9&EN871E
M<ULG1&5N;6%R:R==6R<U-BXU-3`Z.2XQ-C<G72`]("=3:VEV92!,=69T:&%V
M;B<["B1C;V]R9&EN871E<ULG1&5N;6%R:R==6R<U-BXW,#`Z,3$N-34P)UT@
M/2`G06YH;VQT($ES;&%N9"!!=71O;6%T960@4F5P;W)T:6YG(%-T871I;VXG
M.PHD8V]O<F1I;F%T97-;)T1E;FUA<FLG75LG-38N-S$W.C$P+C$Q-R==(#T@
M)TAA9'-U;F0G.PHD8V]O<F1I;F%T97-;)T1E;FUA<FLG75LG-3<N,#8W.C@N
M-S$W)UT@/2`G5&AI<W1E9"!,=69T:&%V;B<["B1C;V]R9&EN871E<ULG1&5N
M;6%R:R==6R<U-RXQ,#`Z.2XX-3`G72`]("=!86QB;W)G)SL*)&-O;W)D:6YA
M=&5S6R=$96YM87)K)UU;)S4W+C4P,#HQ,"XR,3<G72`]("=3:6YD86P@1FQY
M=F5P;&%D<R<["B1C;V]R9&EN871E<ULG1&5N;6%R:R==6R<V,BXP-C<Z+3<N
M,C@S)UT@/2`G4V]E<G9A86<@+R!686=A<B<["B1C;V]R9&EN871E<ULG1&II
M8F]U=&DG75LG,3$N-34P.C0S+C$U,"==(#T@)T1J:6)O=71I)SL*)&-O;W)D
M:6YA=&5S6R=$;VUI;FEC82==6R<Q-2XS,#`Z+38Q+C0P,"==(#T@)U)O<V5A
M=2<["B1C;V]R9&EN871E<ULG1&]M:6YI8V$G75LG,34N-3,S.BTV,2XS,#`G
M72`]("=-96QV:6QL92!(86QL($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T1O
M;6EN:6-A)UU;)S$U+C4S,SHM-C$N-#`P)UT@/2`G0V%N969I96QD($%I<G!O
M<G0G.PHD8V]O<F1I;F%T97-;)T1O;6EN:6-A;B!297!U8FQI8R==6R<Q."XR
M,#`Z+3<Q+C$P,"==(#T@)T)A<F%H;VYA)SL*)&-O;W)D:6YA=&5S6R=$;VUI
M;FEC86X@4F5P=6)L:6,G75LG,3@N-#,S.BTV.2XV-C<G72`]("=,87,@06UE
M<FEC87,G.PHD8V]O<F1I;F%T97-;)T1O;6EN:6-A;B!297!U8FQI8R==6R<Q
M."XT-C<Z+38Y+CDV-R==(#T@)TAE<G)E<F$G.PHD8V]O<F1I;F%T97-;)T1O
M;6EN:6-A;B!297!U8FQI8R==6R<Q."XU-C<Z+38X+C,V-R==(#T@)U!U;G1A
M($-A;F$G.PHD8V]O<F1I;F%T97-;)T1O;6EN:6-A;B!297!U8FQI8R==6R<Q
M.2XT-3`Z+3<P+C<P,"==(#T@)U-A;G1I86=O)SL*)&-O;W)D:6YA=&5S6R=$
M;VUI;FEC86X@4F5P=6)L:6,G75LG,3DN-S4P.BTW,"XU-3`G72`]("=0=65R
M=&\@4&QA=&$@26YT97)N871I;VYA;"<["B1C;V]R9&EN871E<ULG16%S="!4
M:6UO<B==6R<M."XU,#`Z,3(V+C0P,"==(#T@)T)A=6-A=2<["B1C;V]R9&EN
M871E<ULG16%S="!4:6UO<B==6R<M."XU-C<Z,3(U+C4V-R==(#T@)T1I;&QI
M("\@1&EL;&D@06ER<&]R="<["B1C;V]R9&EN871E<ULG16%S="!4:6UO<B==
M6R<M.2XR,#`Z,3(T+C,V-R==(#T@)T]E+4-U<W-E("\@3V4@0W5S<V4G.PHD
M8V]O<F1I;F%T97-;)T5C=6%D;W(G75LG+3`N,34P.BTW."XT.#,G72`]("=1
M=6ET;R`O($UA<FES8V%L(%-U8W)E)SL*)&-O;W)D:6YA=&5S6R=%8W5A9&]R
M)UU;)S`N,S4P.BTW."XQ,S,G72`]("=)8F%R<F$@+R!!=&%H=6%L<&$G.PHD
M8V]O<F1I;F%T97-;)T5C=6%D;W(G75LG+3`N-3@S.BTX,"XT,#`G72`]("="
M86AI82!$92!#87)A<75E>B<["B1C;V]R9&EN871E<ULG16-U861O<B==6R<M
M,"XW.#,Z+3<U+C4Q-R==(#T@)U1I<'5T:6YI)SL*)&-O;W)D:6YA=&5S6R=%
M8W5A9&]R)UU;)S`N.#$W.BTW-RXW,#`G72`]("=4=6QC86X@+R!%;"!2;W-A
M;"<["B1C;V]R9&EN871E<ULG16-U861O<B==6R<M,"XY,#`Z+3@Y+C8P,"==
M(#T@)U-A;B!#<FES=&]B86P@1V%L87!A9V]S)SL*)&-O;W)D:6YA=&5S6R=%
M8W5A9&]R)UU;)RTP+CDQ-SHM-S@N-C$W)UT@/2`G3&%T86-U;F=A)SL*)&-O
M;W)D:6YA=&5S6R=%8W5A9&]R)UU;)RTP+CDU,#HM.#`N-C@S)UT@/2`G36%N
M=&$G.PHD8V]O<F1I;F%T97-;)T5C=6%D;W(G75LG,"XY-C<Z+3<Y+C8S,R==
M(#T@)T5S;65R86QD87,M5&%C:&EN82<["B1C;V]R9&EN871E<ULG16-U861O
M<B==6R<M,2XR,#`Z+3<X+C4V-R==(#T@)T%M8F%T;R`O($-H86-H;V%N)SL*
M)&-O;W)D:6YA=&5S6R=%8W5A9&]R)UU;)RTQ+C4P,#HM-S@N,#4P)UT@/2`G
M4&%S=&%Z82`O(%)I;R!!;6%Z;VYA<R<["B1C;V]R9&EN871E<ULG16-U861O
M<B==6R<M,BXQ-3`Z+3<Y+C@X,R==(#T@)T=U87EA<75I;"`O(%-I;6]N($)O
M;&EV87(G.PHD8V]O<F1I;F%T97-;)T5C=6%D;W(G75LG+3(N,C`P.BTX,"XY
M.#,G72`]("=386QI;F%S("\@1V5N97)A;"!5;'!I86YO(%!A97HG.PHD8V]O
M<F1I;F%T97-;)T5C=6%D;W(G75LG+3(N.#@S.BTW."XY.#,G72`]("=#=65N
M8V$@+R!-87)I<V-A;"!,86UA<B<["B1C;V]R9&EN871E<ULG16-U861O<B==
M6R<M,RXR-3`Z+3<Y+CDV-R==(#T@)TUA8VAA;&$@+R!'96YE<F%L($TN(%-E
M<G)A;F\G.PHD8V]O<F1I;F%T97-;)T5C=6%D;W(G75LG+30N,#`P.BTW.2XS
M-C<G72`]("=#871A;6%Y;R`O($-A;6EL;R!0;VYC92!%;G)I<75E>B<["B1C
M;V]R9&EN871E<ULG16-U861O<B==6R<M-"XS-C<Z+3<Y+CDS,R==(#T@)TUA
M8V%R82`O($HN($TN(%9E;&%S8V\@22XG.PHD8V]O<F1I;F%T97-;)T5G>7!T
M)UU;)S(S+CDV-SHS,BXW.#,G72`]("=!<W-W86XG.PHD8V]O<F1I;F%T97-;
M)T5G>7!T)UU;)S(U+C8V-SHS,BXW,#`G72`]("=,=7AO<B<["B1C;V]R9&EN
M871E<ULG16=Y<'0G75LG,C<N,#4P.C,Q+C`Q-R==(#T@)T%S>75T)SL*)&-O
M;W)D:6YA=&5S6R=%9WEP="==6R<R-RXQ-3`Z,S,N-S$W)UT@/2`G2'5R9W5A
M9&$G.PHD8V]O<F1I;F%T97-;)T5G>7!T)UU;)S(X+C(S,SHS,BXV,3<G72`]
M("=%;"!4;W(G.PHD8V]O<F1I;F%T97-;)T5G>7!T)UU;)S,P+C$S,SHS,2XT
M,#`G72`]("=#86ER;R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=%9WEP="==
M6R<S,2XP.#,Z,S,N.#$W)UT@/2`G16P@07)I<V@G.PHD8V]O<F1I;F%T97-;
M)T5G>7!T)UU;)S,Q+C(P,#HR.2XY-3`G72`]("=!;&5X86YD<FEA("\@3F]U
M>FAA)SL*)&-O;W)D:6YA=&5S6R=%9WEP="==6R<S,2XR-C<Z,S(N,S`P)UT@
M/2`G4&]R="!386ED)SL*)&-O;W)D:6YA=&5S6R=%9WEP="==6R<S,2XS,S,Z
M,C<N,C$W)UT@/2`G365R<V$@36%T<G5H)SL*)&-O;W)D:6YA=&5S6R=%;"!3
M86QV861O<B==6R<Q,RXT,S,Z+3@Y+C`U,"==(#T@)T5L(%-A;'9A9&]R($EN
M=&PN($%I<G!O<G0@+R!#;VUA;&%P82<["B1C;V]R9&EN871E<ULG16P@4V%L
M=F%D;W(G75LG,3,N-#4P.BTX."XQ,3<G72`]("=386X@36EG=65L("\@16P@
M4&%P86QO;B<["B1C;V]R9&EN871E<ULG16P@4V%L=F%D;W(G75LG,3,N-38W
M.BTX.2XX,S,G72`]("=!8V%J=71L82<["B1C;V]R9&EN871E<ULG16P@4V%L
M=F%D;W(G75LG,3,N-S`P.BTX.2XQ,3<G72`]("=386X@4V%L=F%D;W(@+R!)
M;&]P86YG;R<["B1C;V]R9&EN871E<ULG16P@4V%L=F%D;W(G75LG,3,N.3@S
M.BTX.2XU-C<G72`]("=386YT82!!;F$@+R!%;"!086QM87(G.PHD8V]O<F1I
M;F%T97-;)T5Q=6%T;W)I86P@1W5I;F5A)UU;)S,N-S4P.C@N-S8W)UT@/2`G
M36%L86)O+T9E<FYA;F1O(%!O;R<["B1C;V]R9&EN871E<ULG17-T;VYI82==
M6R<U."XY.#,Z,C(N.#$W)UT@/2`G2V%R9&QA)SL*)&-O;W)D:6YA=&5S6R=%
M<W1O;FEA)UU;)S4Y+C,X,SHR-"XU.#,G72`]("=486QL:6YN)SL*)&-O;W)D
M:6YA=&5S6R=%=&AI;W!I82==6R<Q,"XS-3`Z,S<N-S$W)UT@/2`G1&5B<F5M
M87)C;W,G.PHD8V]O<F1I;F%T97-;)T5T:&EO<&EA)UU;)S$Q+C`X,SHS.2XW
M,3<G72`]("=#;VUB;VQC:&$G.PHD8V]O<F1I;F%T97-;)T5T:&EO<&EA)UU;
M)S$Q+C8P,#HS-RXT,#`G72`]("="86AA<B!$87(G.PHD8V]O<F1I;F%T97-;
M)T5T:&EO<&EA)UU;)S$R+C4S,SHS-RXT,S,G72`]("=';VYD87(G.PHD8V]O
M<F1I;F%T97-;)T5T:&EO<&EA)UU;)S$S+C`V-SHT,BXW,3<G72`]("=!<W-A
M8B<["B1C;V]R9&EN871E<ULG171H:6]P:6$G75LG,3,N-3`P.C,Y+C0X,R==
M(#T@)TUA:V%L92<["B1C;V]R9&EN871E<ULG171H:6]P:6$G75LG,34N,C@S
M.C,X+CDQ-R==(#T@)T%S;6%R82<["B1C;V]R9&EN871E<ULG171H:6]P:6$G
M75LG,34N-C$W.C,Y+C0U,"==(#T@)TUA<W-A=V$G.PHD8V]O<F1I;F%T97-;
M)T5T:&EO<&EA)UU;)S4N,3`P.C0T+C4X,R==(#T@)T=O9&4G.PHD8V]O<F1I
M;F%T97-;)T5T:&EO<&EA)UU;)S4N,C@S.C,Y+C<U,"==(#T@)TYE9VAE;&QI
M)SL*)&-O;W)D:6YA=&5S6R=%=&AI;W!I82==6R<V+C`V-SHS-RXV-C<G72`]
M("=!<F)A($UI;F-H)SL*)&-O;W)D:6YA=&5S6R=%=&AI;W!I82==6R<W+C`V
M-SHS."XU,#`G72`]("=!=V%S<V$G.PHD8V]O<F1I;F%T97-;)T5T:&EO<&EA
M)UU;)S<N-C8W.C,V+C@S,R==(#T@)TII;6UA)SL*)&-O;W)D:6YA=&5S6R=%
M=&AI;W!I82==6R<X+C$V-SHS-2XU-3`G72`]("=';W)E)SL*)&-O;W)D:6YA
M=&5S6R=%=&AI;W!I82==6R<X+C<S,SHS.2XP,#`G72`]("=(87)A<B!-961A
M)SL*)&-O;W)D:6YA=&5S6R=%=&AI;W!I82==6R<X+CDX,SHS."XX,#`G72`]
M("=!9&1I<R!!8F%B82<["B1C;V]R9&EN871E<ULG171H:6]P:6$G75LG.2XS
M,S,Z-#(N-S$W)UT@/2`G2FEG9VEG82<["B1C;V]R9&EN871E<ULG171H:6]P
M:6$G75LG.2XV,#`Z-#$N.#8W)UT@/2`G1&ER92!$87=A)SL*)&-O;W)D:6YA
M=&5S6R=&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDG75LG+34Q+C8X,SHM
M-3<N-S8W)UT@/2`G4W1A;FQE>2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=&
M:6II)UU;)RTQ,BXU,#`Z,3<W+C`U,"==(#T@)U)O='5M82<["B1C;V]R9&EN
M871E<ULG1FEJ:2==6R<M,3<N-S4P.C$W-RXT-3`G72`]("=.86YD:2<["B1C
M;V]R9&EN871E<ULG1FEJ:2==6R<M,3@N,#4P.C$W."XU-C<G72`]("=.875S
M;W)I)SL*)&-O;W)D:6YA=&5S6R=&:6II)UU;)RTQ."XR,S,Z+3$W."XX,#`G
M72`]("=,86ME;6)A)SL*)&-O;W)D:6YA=&5S6R=&:6YL86YD)UU;)S8P+C$Q
M-SHQ.2XY,#`G72`]("=-87)I96AA;6X@+R!!;&%N9"!)<VQA;F0G.PHD8V]O
M<F1I;F%T97-;)T9I;FQA;F0G75LG-C`N,C4P.C(U+C`U,"==(#T@)TAE;'-I
M;FMI+4UA;&UI)SL*)&-O;W)D:6YA=&5S6R=&:6YL86YD)UU;)S8P+C,Q-SHR
M-"XY-C<G72`]("=(96QS:6YK:2U686YT86$G.PHD8V]O<F1I;F%T97-;)T9I
M;FQA;F0G75LG-C`N-3$W.C(R+C(V-R==(#T@)U1U<FMU)SL*)&-O;W)D:6YA
M=&5S6R=&:6YL86YD)UU;)S8P+CDP,#HR-BXY,S,G72`]("=5='1I)SL*)&-O
M;W)D:6YA=&5S6R=&:6YL86YD)UU;)S8Q+C`T-CHR."XQ-#DG72`]("=,87!P
M965N<F%N=&$G.PHD8V]O<F1I;F%T97-;)T9I;FQA;F0G75LG-C$N-#$W.C(S
M+C4X,R==(#T@)U1A;7!E<F4@+R!0:7)K:V%L82<["B1C;V]R9&EN871E<ULG
M1FEN;&%N9"==6R<V,2XT-C<Z,C$N.#`P)UT@/2`G4&]R:2<["B1C;V]R9&EN
M871E<ULG1FEN;&%N9"==6R<V,2XW,S,Z,C<N,S`P)UT@/2`G36EK:V5L:2<[
M"B1C;V]R9&EN871E<ULG1FEN;&%N9"==6R<V,2XX-3`Z,C0N.#`P)UT@/2`G
M2&%L;&DG.PHD8V]O<F1I;F%T97-;)T9I;FQA;F0G75LG-C$N.34P.C(X+CDU
M,"==(#T@)U-A=F]N;&EN;F$G.PHD8V]O<F1I;F%T97-;)T9I;FQA;F0G75LG
M-C(N-#`P.C(U+C8X,R==(#T@)TIY=F%S:WEL82<["B1C;V]R9&EN871E<ULG
M1FEN;&%N9"==6R<V,BXU,S,Z,C0N,C$W)UT@/2`G06AT87)I)SL*)&-O;W)D
M:6YA=&5S6R=&:6YL86YD)UU;)S8R+C8V-SHR.2XV,S,G72`]("=*;V5N<W5U
M)SL*)&-O;W)D:6YA=&5S6R=&:6YL86YD)UU;)S8S+C`Q-SHR-RXX,#`G72`]
M("=+=6]P:6\G.PHD8V]O<F1I;F%T97-;)T9I;FQA;F0G75LG-C,N,#4P.C(Q
M+C<V-R==(#T@)U9A87-A)SL*)&-O;W)D:6YA=&5S6R=&:6YL86YD)UU;)S8S
M+C`X,SHR-2XX-C<G72`]("=6:6ET87-A87)I)SL*)&-O;W)D:6YA=&5S6R=&
M:6YL86YD)UU;)S8S+C$P,#HR,RXP,S,G72`]("=+875H879A)SL*)&-O;W)D
M:6YA=&5S6R=&:6YL86YD)UU;)S8S+C<Q-SHR,RXQ-3`G72`]("=+<G5U;G5P
M>7DG.PHD8V]O<F1I;F%T97-;)T9I;FQA;F0G75LG-C0N,C@S.C(W+C8X,R==
M(#T@)TMA:F%A;FDG.PHD8V]O<F1I;F%T97-;)T9I;FQA;F0G75LG-C0N.3`P
M.C(Y+C`Q-R==(#T@)U-U;VUU<W-A;&UI)SL*)&-O;W)D:6YA=&5S6R=&:6YL
M86YD)UU;)S8T+CDS,SHR-2XS-C<G72`]("=/=6QU)SL*)&-O;W)D:6YA=&5S
M6R=&:6YL86YD)UU;)S8U+C`S,SHR-"XX,#`G72`]("=(86EL=6]T;R<["B1C
M;V]R9&EN871E<ULG1FEN;&%N9"==6R<V-2XS-C<Z,C<N,#$W)UT@/2`G4'5D
M87-J87)V:2<["B1C;V]R9&EN871E<ULG1FEN;&%N9"==6R<V-2XW.#,Z,C0N
M-3@S)UT@/2`G2V5M:2<["B1C;V]R9&EN871E<ULG1FEN;&%N9"==6R<V-2XY
M-C<Z,CDN,3@S)UT@/2`G2W5U<V%M;R<["B1C;V]R9&EN871E<ULG1FEN;&%N
M9"==6R<V-BXU-C<Z,C4N.#,S)UT@/2`G4F]V86YI96UI)SL*)&-O;W)D:6YA
M=&5S6R=&:6YL86YD)UU;)S8V+C@P,#HR-"XP,#`G72`]("=096QL;R<["B1C
M;V]R9&EN871E<ULG1FEN;&%N9"==6R<V-RXS-C<Z,C8N-C4P)UT@/2`G4V]D
M86YK>6QA)SL*)&-O;W)D:6YA=&5S6R=&:6YL86YD)UU;)S8X+C8Q-SHR-RXT
M,3<G72`]("=)=F%L;R<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)RTQ,RXR
M,S,Z+3$W-BXQ-C<G72`]("=(:6AI9F\@26QE(%=A;&QI<R<["B1C;V]R9&EN
M871E<ULG1G)A;F-E)UU;)RTQ-"XS,3<Z+3$W."XQ,3<G72`]("=-86]P;V]P
M;R!);&4@1G5T=6YA)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#$N-3`P
M.CDN,3`P)UT@/2`G1FEG87)I)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG
M-#$N.3$W.C@N.#`P)UT@/2`G06IA8V-I;R<["B1C;V]R9&EN871E<ULG1G)A
M;F-E)UU;)S0Q+CDQ-SHY+C0P,"==(#T@)U-O;&5N>F%R82<["B1C;V]R9&EN
M871E<ULG1G)A;F-E)UU;)S0R+C4S,SHX+C@P,"==(#T@)T-A;'9I)SL*)&-O
M;W)D:6YA=&5S6R=&<F%N8V4G75LG-#(N-34P.CDN-#@S)UT@/2`G0F%S=&EA
M)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#(N-S,S.C(N.#8W)UT@/2`G
M4&5R<&EG;F%N)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#,N,#`P.C$N
M,3`P)UT@/2`G4W0M1VER;VYS)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG
M-#,N,3`P.C8N,34P)UT@/2`G2'EE<F5S)SL*)&-O;W)D:6YA=&5S6R=&<F%N
M8V4G75LG-#,N,3@S.C`N,#`P)UT@/2`G5&%R8F5S("\@3W-S=6XG.PHD8V]O
M<F1I;F%T97-;)T9R86YC92==6R<T,RXR,3<Z,BXS,3<G72`]("=#87)C87-S
M;VYN92<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0S+C,X,SHM,"XT,3<G
M72`]("=0874G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T,RXS.#,Z-BXS
M.#,G72`]("=,92!,=6,G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T,RXT
M,3<Z-BXW-3`G72`]("=3="U287!H865L)SL*)&-O;W)D:6YA=&5S6R=&<F%N
M8V4G75LG-#,N-#4P.C4N,C,S)UT@/2`G36%R<V5I;&QE("\@36%R:6=N86YE
M)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#,N-#8W.BTQ+C4S,R==(#T@
M)T)I87)R:71Z)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#,N-3`P.C4N
M,S8W)UT@/2`G06EX($QE<R!-:6QL97,G.PHD8V]O<F1I;F%T97-;)T9R86YC
M92==6R<T,RXU,3<Z-"XY,S,G72`]("=)<W1R97,G.PHD8V]O<F1I;F%T97-;
M)T9R86YC92==6R<T,RXU,S,Z,2XS-C<G72`]("=4;W5L;W5S92`O($9R86YC
M87IA;"<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0S+C4U,#HV+CDU,"==
M(#T@)T-A;FYE<R<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0S+C4X,SHS
M+CDV-R==(#T@)TUO;G1P96QL:65R)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G
M75LG-#,N-C`P.C4N,3`P)UT@/2`G4V%L;VXG.PHD8V]O<F1I;F%T97-;)T9R
M86YC92==6R<T,RXV,S,Z,2XS-C<G72`]("=4;W5L;W5S92`O($)L86=N86,G
M.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T,RXV-3`Z-RXR,#`G72`]("=.
M:6-E)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#,N-C@S.C`N-C`P)UT@
M/2`G075C:"<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0S+C8X,SHM,2XP
M-C<G72`]("=$87@G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T,RXW-3`Z
M-"XT,3<G72`]("=.:6UE<R`O($=A<F]N<R<["B1C;V]R9&EN871E<ULG1G)A
M;F-E)UU;)S0S+C@V-SHT+C0P,"==(#T@)TYI;65S("\@0V]U<F)E<W-A8R<[
M"B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0S+CDQ-SHM,"XU,#`G72`]("=-
M;VYT+41E+4UA<G-A;B<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0S+CDQ
M-SHR+C$Q-R==(#T@)T%L8FDG.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T
M-"XP-C<Z-BXP,#`G72`]("=3="U!=6)A;BU3=7(M1'5R86YC92<["B1C;V]R
M9&EN871E<ULG1G)A;F-E)UU;)S0T+C$S,SHT+C@S,R==(#T@)T]R86YG92<[
M"B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0T+C$X,SHP+C8P,"==(#T@)T%G
M96XG.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-"XQ.#,Z,BXU,3<G72`]
M("=#87-S86=N97,M0F5G;VYH97,G.PHD8V]O<F1I;F%T97-;)T9R86YC92==
M6R<T-"XT,#`Z,BXT.#,G72`]("=2;V1E>B<["B1C;V]R9&EN871E<ULG1G)A
M;F-E)UU;)S0T+C0S,SHM,2XR-3`G72`]("=":7-C87)O<W-E)SL*)&-O;W)D
M:6YA=&5S6R=&<F%N8V4G75LG-#0N-3,S.BTQ+C$S,R==(#T@)T-A>F%U>"<[
M"B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0T+C4X,SHT+C<S,R==(#T@)TUO
M;G1E;&EM87(G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-"XX,3<Z,"XU
M,3<G72`]("="97)G97)A8R<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0T
M+C@S,SHM,"XW,#`G72`]("=";W)D96%U>"`O($UE<FEG;F%C)SL*)&-O;W)D
M:6YA=&5S6R=&<F%N8V4G75LG-#0N.3`P.C(N-#$W)UT@/2`G075R:6QL86,G
M.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-2XP.#,Z,RXW-C<G72`]("=,
M92!0=7DG.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-2XQ-3`Z,2XT-C<G
M72`]("="<FEV92<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0U+C(P,#HP
M+C@Q-R==(#T@)U!E<FEG=65U>"<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;
M)S0U+C,V-SHU+C,S,R==(#T@)T=R96YO8FQE("\@4W0N($=E;VER<R<["B1C
M;V]R9&EN871E<ULG1G)A;F-E)UU;)S0U+C4S,SHT+C,P,"==(#T@)U-T+45T
M:65N;F4@0F]U=&AE;VXG.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-2XV
M-3`Z-2XX.#,G72`]("=#:&%M8F5R>2`O($%I>"U,97,M0F%I;G,G.PHD8V]O
M<F1I;F%T97-;)T9R86YC92==6R<T-2XV-C<Z+3`N,S$W)UT@/2`G0V]G;F%C
M)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#4N-S$W.C0N.34P)UT@/2`G
M3'EO;B`O($)R;VXG.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-2XW,S,Z
M-2XP.#,G72`]("=,>6]N("\@4V%T;VQA<R<["B1C;V]R9&EN871E<ULG1G)A
M;F-E)UU;)S0U+C<X,SHS+C$V-R==(#T@)T-L97)M;VYT+49E<G)A;F0G.PHD
M8V]O<F1I;F%T97-;)T9R86YC92==6R<T-2XX-C<Z,2XQ.#,G72`]("=,:6UO
M9V5S)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#4N.3@S.C4N,S,S)UT@
M/2`G06UB97)I974G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-BXQ-3`Z
M+3$N,34P)UT@/2`G3&$@4F]C:&5L;&4G.PHD8V]O<F1I;F%T97-;)T9R86YC
M92==6R<T-BXQ-C<Z,RXT,#`G72`]("=6:6-H>2<["B1C;V]R9&EN871E<ULG
M1G)A;F-E)UU;)S0V+C,P,#HT+C@P,"==(#T@)TUA8V]N)SL*)&-O;W)D:6YA
M=&5S6R=&<F%N8V4G75LG-#8N,S$W.BTP+C0P,"==(#T@)TYI;W)T)SL*)&-O
M;W)D:6YA=&5S6R=&<F%N8V4G75LG-#8N-#$W.C0N,#$W)UT@/2`G4V%I;G0M
M66%N)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#8N-3@S.C`N,S$W)UT@
M/2`G4&]I=&EE<G,G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-BXW,#`Z
M+3$N,S@S)UT@/2`G3&$@4F]C:&4M4W5R+5EO;B<["B1C;V]R9&EN871E<ULG
M1G)A;F-E)UU;)S0V+C@U,#HQ+C<Q-R==(#T@)T-H871E875R;W5X)SL*)&-O
M;W)D:6YA=&5S6R=&<F%N8V4G75LG-#<N,#`P.C,N,3`P)UT@/2`G3F5V97)S
M)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#<N,#8W.C(N,S8W)UT@/2`G
M0F]U<F=E<R<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0W+C$V-SHM,2XV
M,#`G72`]("=.86YT97,G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-RXR
M-3`Z-2XY.#,G72`]("="97-A;F-O;B<["B1C;V]R9&EN871E<ULG1G)A;F-E
M)UU;)S0W+C(V-SHU+C`X,R==(#T@)T1I:F]N)SL*)&-O;W)D:6YA=&5S6R=&
M<F%N8V4G75LG-#<N,S$W.C$N-C@S)UT@/2`G4F]M;W)A;G1I;B<["B1C;V]R
M9&EN871E<ULG1G)A;F-E)UU;)S0W+C,Q-SHM,BXQ-C<G72`]("=3="U.87IA
M:7)E)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#<N-#4P.C`N-S$W)UT@
M/2`G5&]U<G,G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-RXU,#`Z+3`N
M-38W)UT@/2`G06YG97)S)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#<N
M-C`P.C<N-3$W)UT@/2`G0F%L92U-=6QH;W5S92<["B1C;V]R9&EN871E<ULG
M1G)A;F-E)UU;)S0W+C8S,SHV+C@V-R==(#T@)T)E;&9O<G0G.PHD8V]O<F1I
M;F%T97-;)T9R86YC92==6R<T-RXW-C<Z+3,N-#4P)UT@/2`G3&%N;B!":6AO
M=64G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-RXW.#,Z-BXS-3`G72`]
M("=,=7AE=6EL)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#<N.#`P.C,N
M-34P)UT@/2`G075X97)R92<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0W
M+C@U,#HT+C4U,"==(#T@)T-H871I;&QO;BU3=7(M4V5I;F4G.PHD8V]O<F1I
M;F%T97-;)T9R86YC92==6R<T-RXY,3<Z-RXT,#`G72`]("=#;VQM87(G.PHD
M8V]O<F1I;F%T97-;)T9R86YC92==6R<T-RXY,S,Z,"XR,#`G72`]("=,92!-
M86YS)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#<N.38W.BTT+C$V-R==
M(#T@)U%U:6UP97(G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-RXY.#,Z
M,2XW-3`G72`]("=/<FQE86YS)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG
M-#@N,#4P.C$N,S@S)UT@/2`G0VAA=&5A=61U;B<["B1C;V]R9&EN871E<ULG
M1G)A;F-E)UU;)S0X+C`V-SHM,2XW,S,G72`]("=296YN97,G.PHD8V]O<F1I
M;F%T97-;)T9R86YC92==6R<T."XR.#,Z+30N-#,S)UT@/2`G3&%N=F5O8R!0
M;W5L;6EC)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#@N,S,S.C0N,#$W
M)UT@/2`G5')O>65S)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#@N-#4P
M.C`N,3$W)UT@/2`G06QE;F-O;B<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;
M)S0X+C0U,#HM-"XT,3<G72`]("="<F5S="<["B1C;V]R9&EN871E<ULG1G)A
M;F-E)UU;)S0X+C0V-SHQ+C4Q-R==(#T@)T-H87)T<F5S)SL*)&-O;W)D:6YA
M=&5S6R=&<F%N8V4G75LG-#@N-3$W.BTT+C$U,"==(#T@)TQA;F1I=FES:6%U
M)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#@N-3,S.BTR+C@U,"==(#T@
M)U-A:6YT+4)R:65U8R<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0X+C4U
M,#HW+C8S,R==(#T@)U-T<F%S8F]U<F<G.PHD8V]O<F1I;F%T97-;)T9R86YC
M92==6R<T."XU.#,Z+3(N,#8W)UT@/2`G1&EN87)D)SL*)&-O;W)D:6YA=&5S
M6R=&<F%N8V4G75LG-#@N-3@S.C4N.38W)UT@/2`G3F%N8WD@+R!/8VAE>2<[
M"B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0X+C8Q-SHR+C8X,R==(#T@)TUE
M;'5N)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#@N-C,S.C0N.3`P)UT@
M/2`G4W0M1&EZ:65R)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#@N-C@S
M.C8N,C$W)UT@/2`G3F%N8WD@+R!%<W-E>2<["B1C;V]R9&EN871E<ULG1G)A
M;F-E)UU;)S0X+C<S,SHR+C0P,"==(#T@)U!A<FES+4]R;'DG.PHD8V]O<F1I
M;F%T97-;)T9R86YC92==6R<T."XW-C<Z,2XQ,#`G72`]("=4;W5S<W5S($QE
M($YO8FQE)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#@N-S8W.C(N,C`P
M)UT@/2`G5FEL;&%C;W5B;&%Y)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG
M-#@N-S@S.C4N-#@S)UT@/2`G5&]U;"`O(%)O<VEE<F5S)SL*)&-O;W)D:6YA
M=&5S6R=&<F%N8V4G75LG-#@N.38W.C(N-#4P)UT@/2`G4&%R:7,@+R!,92!"
M;W5R9V5T)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#@N.3@S.C8N,C4P
M)UT@/2`G365T>BU.86YC>2U,;W)R86EN92<["B1C;V]R9&EN871E<ULG1G)A
M;F-E)UU;)S0Y+C`Q-SHQ+C(Q-R==(#T@)T5V<F5U>"<["B1C;V]R9&EN871E
M<ULG1G)A;F-E)UU;)S0Y+C`Q-SHR+C4S,R==(#T@)U!A<FES+4%E<F]P;W)T
M($-H87)L97,@1&4@1V%U;&QE)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG
M-#DN,#@S.C8N,3,S)UT@/2`G365T>B`O($9R97-C871Y)SL*)&-O;W)D:6YA
M=&5S6R=&<F%N8V4G75LG-#DN,3@S.BTP+C0U,"==(#T@)T-A96XG.PHD8V]O
M<F1I;F%T97-;)T9R86YC92==6R<T.2XR-3`Z,BXU,3<G72`]("=#<F5I;"!&
M869B)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#DN,S`P.C0N,#,S)UT@
M/2`G4F5I;7,G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T.2XS.#,Z,2XQ
M.#,G72`]("=2;W5E;B<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0Y+C0V
M-SHR+C$Q-R==(#T@)T)E875V86ES)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G
M75LG-#DN-3$W.C`N,#8W)UT@/2`G3&$@2&5V92<["B1C;V]R9&EN871E<ULG
M1G)A;F-E)UU;)S0Y+C8U,#HM,2XT-C<G72`]("=#:&5R8F]U<F<@+R!-875P
M97)T=7,G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T.2XW.#,Z-"XV,S,G
M72`]("=#:&%R;&5V:6QL92<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0Y
M+C@Q-SHS+C(P,"==(#T@)U-A:6YT+5%U96YT:6XG.PHD8V]O<F1I;F%T97-;
M)T9R86YC92==6R<T.2XX,S,Z,"XV-3`G72`]("=6:71T969L975R("\@4W0N
M(%9A;&4G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<U,"XQ,S,Z,2XX,S,G
M72`]("=!8F)E=FEL;&4G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<U,"XR
M,3<Z,RXQ-3`G72`]("=#86UB<F%I)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G
M75LG-3`N-3$W.C$N-C$W)UT@/2`G3&4@5&]U<75E="<["B1C;V]R9&EN871E
M<ULG1G)A;F-E)UU;)S4P+C4V-SHS+C$P,"==(#T@)TQI;&QE)SL*)&-O;W)D
M:6YA=&5S6R=&<F5N8V@@1W5I86YA)UU;)S0N.#,S.BTU,BXS-C<G72`]("=#
M87EE;FYE("\@4F]C:&%M8F5A=2<["B1C;V]R9&EN871E<ULG1G)E;F-H($=U
M:6%N82==6R<U+C4P,#HM-30N,#,S)UT@/2`G4V%I;G0M3&%U<F5N="U$=2U-
M87)O;FDG.PHD8V]O<F1I;F%T97-;)T9R96YC:"!0;VQY;F5S:6$G75LG+3$T
M+CDV-SHM,30W+C8V-R==(#T@)U)A;F=I<F]A("\@5'5A;6]T;R!)<VQA;F0G
M.PHD8V]O<F1I;F%T97-;)T9R96YC:"!0;VQY;F5S:6$G75LG+3$V+C0U,#HM
M,34Q+C<U,"==(#T@)T)O<F$M0F]R82<["B1C;V]R9&EN871E<ULG1G)E;F-H
M(%!O;'EN97-I82==6R<M,3<N-34P.BTQ-#DN-C$W)UT@/2`G5&%H:71I+49A
M86$G.PHD8V]O<F1I;F%T97-;)T9R96YC:"!0;VQY;F5S:6$G75LG+3$X+C`V
M-SHM,30P+CDU,"==(#T@)TAA;R<["B1C;V]R9&EN871E<ULG1G)E;F-H(%!O
M;'EN97-I82==6R<M,C$N.#$W.BTQ,S@N.#`P)UT@/2`G375R=7)O82<["B1C
M;V]R9&EN871E<ULG1G)E;F-H(%!O;'EN97-I82==6R<M,C,N,S4P.BTQ-#DN
M-#@S)UT@/2`G5'5B=6%I)SL*)&-O;W)D:6YA=&5S6R='86)O;B==6R<P+C0U
M,#HY+C0Q-R==(#T@)TQI8G)E=FEL;&4G.PHD8V]O<F1I;F%T97-;)T=A8F]N
M)UU;)S`N-38W.C$R+C@V-R==(#T@)TUA:V]K;W4G.PHD8V]O<F1I;F%T97-;
M)T=A8F]N)UU;)RTP+C<P,#HX+C<U,"==(#T@)U!O<G0M1V5N=&EL)SL*)&-O
M;W)D:6YA=&5S6R='86)O;B==6R<M,"XW,3<Z,3`N,C,S)UT@/2`G3&%M8F%R
M96YE)SL*)&-O;W)D:6YA=&5S6R='86)O;B==6R<P+C<X,SHQ,2XU,S,G72`]
M("=-:71Z:6,G.PHD8V]O<F1I;F%T97-;)T=A8F]N)UU;)RTP+C@S,SHQ,BXW
M,3<G72`]("=,87-T;W5R<W9I;&QE)SL*)&-O;W)D:6YA=&5S6R='86)O;B==
M6R<Q+C`P,#HY+C8P,"==(#T@)T-O8V]B96%C:"<["B1C;V]R9&EN871E<ULG
M1V%B;VXG75LG,2XP,3<Z,3,N.3,S)UT@/2`G365K86UB;R<["B1C;V]R9&EN
M871E<ULG1V%B;VXG75LG+3$N-3,S.C$S+C(V-R==(#T@)TUO86YD82<["B1C
M;V]R9&EN871E<ULG1V%B;VXG75LG+3$N.#8W.C$Q+C`Q-R==(#T@)TUO=6EL
M82<["B1C;V]R9&EN871E<ULG1V%B;VXG75LG,BXP.#,Z,3$N-#@S)UT@/2`G
M0FET86TG.PHD8V]O<F1I;F%T97-;)T=A8F]N)UU;)RTR+C@U,#HQ,2XP,3<G
M72`]("=48VAI8F%N9V$G.PHD8V]O<F1I;F%T97-;)T=A8F]N)UU;)RTS+C0Q
M-SHQ,"XV-3`G72`]("=-87EU;6)A)SL*)&-O;W)D:6YA=&5S6R='86UB:6$G
M75LG,3,N,S4P.BTQ-BXX,#`G72`]("="86YJ=6P@+R!9=6YD=6TG.PHD8V]O
M<F1I;F%T97-;)T=E;W)G:6$G75LG-#$N-C@S.C0T+CDU,"==(#T@)U1B:6QI
M<VDG.PHD8V]O<F1I;F%T97-;)T=E;W)G:6$G75LG-#$N.3,S.C0T+C4X,R==
M(#T@)TUU:')A;FDG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#<N-C8W
M.CDN-3$W)UT@/2`G1G)I961R:6-H<VAA9F5N)SL*)&-O;W)D:6YA=&5S6R='
M97)M86YY)UU;)S0W+C8X,SHY+C$X,R==(#T@)TMO;G-T86YZ)SL*)&-O;W)D
M:6YA=&5S6R='97)M86YY)UU;)S0W+C@S,SHQ,"XX-C<G72`]("=!;'1E;G-T
M861T)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S0W+CDV-SHX+C4Q-R==
M(#T@)T1O;F%U97-C:&EN9V5N("\@5FEL;&EN9V5N)SL*)&-O;W)D:6YA=&5S
M6R='97)M86YY)UU;)S0W+CDX,SHQ,"XR,S,G72`]("=-96UM:6YG96XG.PHD
M8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#@N,#8W.C$P+CDP,"==(#T@)TQA
M;F1S8F5R9R<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<T."XQ,S,Z,3$N
M-S`P)UT@/2`G375N:6-H("\@4FEE;2<["B1C;V]R9&EN871E<ULG1V5R;6%N
M>2==6R<T."XQ.#,Z,3`N.#8W)UT@/2`G3&5C:&9E;&0G.PHD8V]O<F1I;F%T
M97-;)T=E<FUA;GDG75LG-#@N,3@S.CDN,#`P)UT@/2`G365S<W-T971T96XG
M.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#@N,C`P.C$Q+C(V-R==(#T@
M)T9U97)S=&5N9F5L9&)R=6-K)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;
M)S0X+C(Q-SHY+CDQ-R==(#T@)TQA=7!H96EM)SL*)&-O;W)D:6YA=&5S6R='
M97)M86YY)UU;)S0X+C,Q-SHQ,2XY-3`G72`]("=%<F1I;F<G.PHD8V]O<F1I
M;F%T97-;)T=E<FUA;GDG75LG-#@N-#,S.C$P+CDS,R==(#T@)T%U9W-B=7)G
M)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S0X+C8X,SHY+C(Q-R==(#T@
M)U-T=71T9V%R="U%8VAT97)D:6YG96XG.PHD8V]O<F1I;F%T97-;)T=E<FUA
M;GDG75LG-#@N-S$W.C$Q+C(Q-R==(#T@)TYE=6)U<F<@+R!$;VYA=2<["B1C
M;V]R9&EN871E<ULG1V5R;6%N>2==6R<T."XW,3<Z,3$N-3,S)UT@/2`G26YG
M;VQS=&%D="<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<T.2XR,3<Z,3$N
M,3`P)UT@/2`G4F]T:"<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<T.2XR
M,3<Z,3$N.#,S)UT@/2`G2&]H96YF96QS)SL*)&-O;W)D:6YA=&5S6R='97)M
M86YY)UU;)S0Y+C(Q-SHW+C$Q-R==(#T@)U-A87)B<G5E8VME;B`O($5N<VAE
M:6TG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#DN,S$W.C$P+C8S,R==
M(#T@)T%N<V)A8V@@+R!+871T97)B86-H)SL*)&-O;W)D:6YA=&5S6R='97)M
M86YY)UU;)S0Y+C0P,#HX+C8U,"==(#T@)TAE:61E;&)E<F<G.PHD8V]O<F1I
M;F%T97-;)T=E<FUA;GDG75LG-#DN-#`P.CDN.38W)UT@/2`G3FEE9&5R<W1E
M='1E;B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<T.2XT,S,Z,3$N.3`P
M)UT@/2`G2W5E;6UE<G-R=6-K)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;
M)S0Y+C0S,SHW+C8P,"==(#T@)U)A;7-T96EN)SL*)&-O;W)D:6YA=&5S6R='
M97)M86YY)UU;)S0Y+C0V-SHQ,"XS.#,G72`]("=);&QE<VAE:6TG.PHD8V]O
M<F1I;F%T97-;)T=E<FUA;GDG75LG-#DN-#<S.C@N-3$V)UT@/2`G0F%D96X@
M5W5R='1E;6)E<F<L($YE=6]S=&AE:6TG.PHD8V]O<F1I;F%T97-;)T=E<FUA
M;GDG75LG-#DN-3`P.C$Q+C`U,"==(#T@)TYU97)N8F5R9R<["B1C;V]R9&EN
M871E<ULG1V5R;6%N>2==6R<T.2XU,#`Z-RXX-C<G72`]("=396UB86-H(%5N
M:71E9"!3=&%T97,@06ER($9O<F-E($]P97)A=&5D($)A<V4@26X@1F]R96EG
M;B!#;W5N=')Y)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S0Y+C4V-SHX
M+C0V-R==(#T@)T-O;&5M86X@36%N;FAE:6TG.PHD8V]O<F1I;F%T97-;)T=E
M<FUA;GDG75LG-#DN-C4P.CDN.38W)UT@/2`G1VEE8F5L<W1A9'0G.PHD8V]O
M<F1I;F%T97-;)T=E<FUA;GDG75LG-#DN-S`P.C$Q+CDU,"==(#T@)T=R869E
M;G=O96AR)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S0Y+C<P,#HW+C,S
M,R==(#T@)TED87(M3V)E<G-T96EN)SL*)&-O;W)D:6YA=&5S6R='97)M86YY
M)UU;)S0Y+C<U,#HQ,"XR,#`G72`]("=+:71Z:6YG96X@57-A(%P@068G.PHD
M8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#DN.#4P.C<N-C`P)UT@/2`G4&9E
M<F1S9F5L9"<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<T.2XX-3`Z-RXX
M.#,G72`]("="860@2W)E=7IN86-H)SL*)&-O;W)D:6YA=&5S6R='97)M86YY
M)UU;)S0Y+CDU,#HW+C(V-R==(#T@)TAA:&XG.PHD8V]O<F1I;F%T97-;)T=E
M<FUA;GDG75LG-#DN.3@S.C$Q+C8S,R==(#T@)T)A>7)E=71H)SL*)&-O;W)D
M:6YA=&5S6R='97)M86YY)UU;)S0Y+CDX,SHV+C<P,"==(#T@)U-P86YG9&%H
M;&5M)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4P+C`U,#HX+C,S,R==
M(#T@)U=I97-B861E;B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,"XP
M-3`Z."XV,#`G72`]("=&<F%N:V9U<G0@+R!-+49L=6=H869E;B<["B1C;V]R
M9&EN871E<ULG1V5R;6%N>2==6R<U,"XQ-C<Z-RXP-C<G72`]("="=65C:&5L
M)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4P+C$V-SHX+CDV-R==(#T@
M)TAA;F%U)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4P+C,Q-SHQ,2XX
M.#,G72`]("=(;V8G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3`N,S8W
M.C<N,S$W)UT@/2`G365N9&EG)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;
M)S4P+C@Q-SHV+C$X,R==(#T@)T%A8VAE;B`O($UE<GIB<G5C:R<["B1C;V]R
M9&EN871E<ULG1V5R;6%N>2==6R<U,"XX,S,Z-BXV-C<G72`]("=.;V5R=F5N
M:6-H)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4P+C@V-SHW+C$V-R==
M(#T@)TMO96QN("\@0F]N;B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U
M,"XY-C<Z-BXP-3`G72`]("='96EL96YK:7)C:&5N)SL*)&-O;W)D:6YA=&5S
M6R='97)M86YY)UU;)S4P+CDX,SHQ,"XY-C<G72`]("=%<F9U<G0M0FEN9&5R
M<VQE8F5N)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4Q+C$Q-SHY+C(X
M,R==(#T@)T9R:71Z;&%R)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4Q
M+C$S,SHQ,RXW-3`G72`]("=$<F5S9&5N+4ML;W1Z<V-H92<["B1C;V]R9&EN
M871E<ULG1V5R;6%N>2==6R<U,2XR,#`Z-BXQ,S,G72`]("="<G5E9V=E;B<[
M"B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,2XS,#`Z-BXW-C<G72`]("=$
M=65S<V5L9&]R9B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,2XT,#`Z
M-BXY-C<G72`]("=%<W-E;B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U
M,2XT,#`Z.2XS.#,G72`]("=+87-S96P@+R!#86QD96XG.PHD8V]O<F1I;F%T
M97-;)T=E<FUA;GDG75LG-3$N-#$W.C$R+C(S,R==(#T@)TQE:7!Z:6<M4V-H
M:V5U9&ET>B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,2XU,3<Z-RXV
M,3<G72`]("=$;W)T;75N9"`O(%=I8VME9&4G.PHD8V]O<F1I;F%T97-;)T=E
M<FUA;GDG75LG-3$N-C`P.C8N,34P)UT@/2`G3&%A<F)R=6-H)SL*)&-O;W)D
M:6YA=&5S6R='97)M86YY)UU;)S4Q+C8Q-SHX+C8Q-R==(#T@)U!A9&5R8F]R
M;B`O($QI<'!S=&%D="<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,2XV
M-C<Z,30N-C,S)UT@/2`G4')E<V-H96XG.PHD8V]O<F1I;F%T97-;)T=E<FUA
M;GDG75LG-3$N-S,S.C8N,C8W)UT@/2`G2V%L:V%R)SL*)&-O;W)D:6YA=&5S
M6R='97)M86YY)UU;)S4Q+C<V-SHQ,RXQ.#,G72`]("=(;VQZ9&]R9B<["B1C
M;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,2XW-C<Z,30N,S`P)UT@/2`G0V]T
M=&)U<R!&;'5G<&QA='HG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3$N
M.3$W.C@N,S`P)UT@/2`G1W5E=&5R<VQO:"<["B1C;V]R9&EN871E<ULG1V5R
M;6%N>2==6R<U,BXQ,S,Z-RXW,#`G72`]("=-=65N<W1E<B`O($]S;F%B<G5E
M8VLG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3(N,C@S.CDN,#@S)UT@
M/2`G0G5E8VME8G5R9R<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,BXS
M,#`Z,3`N-#4P)UT@/2`G0G)A=6YS8VAW96EG)SL*)&-O;W)D:6YA=&5S6R='
M97)M86YY)UU;)S4R+C,P,#HW+C,X,R==(#T@)U)H96EN92U"96YT;&%G92<[
M"B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,BXS,S,Z-RXU,S,G72`]("=(
M;W!S=&5N)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4R+C,X,SHQ,RXU
M,3<G72`]("="97)L:6XM4V-H;V5N969E;&0G.PHD8V]O<F1I;F%T97-;)T=E
M<FUA;GDG75LG-3(N-#4P.C<N,38W)UT@/2`G3F]R9&AO<FXG.PHD8V]O<F1I
M;F%T97-;)T=E<FUA;GDG75LG-3(N-#4P.CDN-#,S)UT@/2`G5W5N<W1O<F8G
M.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3(N-#8W.C$S+C0P,"==(#T@
M)T)E<FQI;BU496UP96QH;V8G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG
M-3(N-#8W.CDN-C@S)UT@/2`G2&%N;F]V97(G.PHD8V]O<F1I;F%T97-;)T=E
M<FUA;GDG75LG-3(N-38W.C$S+C,Q-R==(#T@)T)E<FQI;BU496=E;"<["B1C
M;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,BXU.#,Z."XS-3`G72`]("=$:65P
M:&]L>B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,BXV,#`Z,3`N,#$W
M)UT@/2`G0V5L;&4G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3(N.#$W
M.CDN.3,S)UT@/2`G0F5R9V5N)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;
M)S4R+CDQ-SHQ,"XQ.#,G72`]("=&87-S8F5R9R<["B1C;V]R9&EN871E<ULG
M1V5R;6%N>2==6R<U,RXP-3`Z."XX,#`G72`]("="<F5M96XG.PHD8V]O<F1I
M;F%T97-;)T=E<FUA;GDG75LG-3,N,C`P.C$R+C4Q-R==(#T@)U=I='1S=&]C
M:R<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,RXT,C<Z,3$N-S@T)UT@
M/2`G365C:VQE;F)U<F<M5F]R<&]M;65R;BP@4&%R8VAI;2<["B1C;V]R9&EN
M871E<ULG1V5R;6%N>2==6R<U,RXU,S,Z-RXX.#,G72`]("=*979E<B<["B1C
M;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,RXU,S,Z.2XX,S,G72`]("=(86UB
M=7)G+49I;FME;G=E<F1E<B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U
M,RXU-3`Z-RXV-C<G72`]("=7:71T;75N9&AA=F5N)SL*)&-O;W)D:6YA=&5S
M6R='97)M86YY)UU;)S4S+C8P,#HQ,RXS,3<G72`]("=4<F]L;&5N:&%G96XG
M.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3,N-C,S.C$P+C`P,"==(#T@
M)TAA;6)U<F<M1G5H;'-B=65T=&5L)SL*)&-O;W)D:6YA=&5S6R='97)M86YY
M)UU;)S4S+C<V-SHX+C8V-R==(#T@)TYO<F1H;VQZ)SL*)&-O;W)D:6YA=&5S
M6R='97)M86YY)UU;)S4S+C@Q-SHQ,"XW,#`G72`]("=,=65B96-K+4)L86YK
M96YS964G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3,N.3$W.C$R+C(X
M,R==(#T@)TQA86=E)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4T+C`P
M,#HY+C4X,R==(#T@)TET>F5H;V4G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG
M75LG-30N,S$W.CDN-3,S)UT@/2`G2&]H;B<["B1C;V]R9&EN871E<ULG1V5R
M;6%N>2==6R<U-"XS.#,Z,3`N,34P)UT@/2`G2VEE;"U(;VQT96YA=2<["B1C
M;V]R9&EN871E<ULG1V5R;6%N>2==6R<U-"XT-C<Z.2XU,3<G72`]("=38VAL
M97-W:6<M2F%G96PG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-30N-C,S
M.CDN,S4P)UT@/2`G16=G96)E:R<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==
M6R<U-"XX,S,Z.2XU,#`G72`]("=';'5E8VMS8G5R9R`O($UE:65R=VEK)SL*
M)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4T+CDQ-SHX+C,U,"==(#T@)U=E
M<W1E<FQA;F0@+R!3>6QT)SL*)&-O;W)D:6YA=&5S6R=':&%N82==6R<Q,"XP
M-3`Z+3(N-3`P)UT@/2`G5V$G.PHD8V]O<F1I;F%T97-;)T=H86YA)UU;)S$P
M+CDP,#HM,2XQ,#`G72`]("=.879R;VYG;R<["B1C;V]R9&EN871E<ULG1VAA
M;F$G75LG-"XX-C<Z+3(N,C,S)UT@/2`G07AI;2<["B1C;V]R9&EN871E<ULG
M1VAA;F$G75LG-"XX.#,Z+3$N-S8W)UT@/2`G5&%K;W)A9&DG.PHD8V]O<F1I
M;F%T97-;)T=H86YA)UU;)S4N,C`P.BTQ+C`V-R==(#T@)U-A;'1P;VYD)SL*
M)&-O;W)D:6YA=&5S6R=':&%N82==6R<U+C8P,#HM,"XQ-C<G72`]("=!8V-R
M82<["B1C;V]R9&EN871E<ULG1VAA;F$G75LG-2XV,3<Z,"XP,#`G72`]("=4
M96UA)SL*)&-O;W)D:6YA=&5S6R=':&%N82==6R<U+C<X,SHP+C8S,R==(#T@
M)T%D82<["B1C;V]R9&EN871E<ULG1VAA;F$G75LG-2XY,S,Z+3`N.3@S)UT@
M/2`G06MI;2!/9&$G.PHD8V]O<F1I;F%T97-;)T=H86YA)UU;)S8N,#@S.BTP
M+C(U,"==(#T@)TMO9F]R:61U82<["B1C;V]R9&EN871E<ULG1VAA;F$G75LG
M-BXQ,#`Z,"XQ,3<G72`]("=!:W5S92<["B1C;V]R9&EN871E<ULG1VAA;F$G
M75LG-BXR,#`Z+3(N,S,S)UT@/2`G4V5F=VD@0F5K=V%I)SL*)&-O;W)D:6YA
M=&5S6R=':&%N82==6R<V+C8P,#HP+C0V-R==(#T@)TAO)SL*)&-O;W)D:6YA
M=&5S6R=':&%N82==6R<V+C<Q-SHM,2XV,#`G72`]("=+=6UA<VDG.PHD8V]O
M<F1I;F%T97-;)T=H86YA)UU;)S<N,S,S.BTR+C,S,R==(#T@)U-U;GEA;FDG
M.PHD8V]O<F1I;F%T97-;)T=H86YA)UU;)S<N-S4P.BTR+C$P,"==(#T@)U=E
M;F-H:2<["B1C;V]R9&EN871E<ULG1VAA;F$G75LG.2XP,S,Z+3(N-#@S)UT@
M/2`G0F]L92<["B1C;V]R9&EN871E<ULG1VAA;F$G75LG.2XT-3`Z+3`N,#$W
M)UT@/2`G665N9&DG.PHD8V]O<F1I;F%T97-;)T=H86YA)UU;)SDN-3`P.BTP
M+C@U,"==(#T@)U1A;6%L92<["B1C;V]R9&EN871E<ULG1VEB<F%L=&%R)UU;
M)S,V+C$U,#HM-2XS-3`G72`]("=':6)R86QT87(G.PHD8V]O<F1I;F%T97-;
M)T=R965C92==6R<S-2XS,S,Z,C4N,3@S)UT@/2`G2&5R86ML:6]N($%I<G!O
M<G0G.PHD8V]O<F1I;F%T97-;)T=R965C92==6R<S-2XT,30Z,C<N,30X)UT@
M/2`G2V%R<&%T:&]S($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T=R965C92==
M6R<S-2XT.#,Z,C0N,3$W)UT@/2`G4V]U9&$@06ER<&]R="<["B1C;V]R9&EN
M871E<ULG1W)E96-E)UU;)S,V+C0P,#HR."XP.#,G72`]("=2:&]D97,@06ER
M<&]R="<["B1C;V]R9&EN871E<ULG1W)E96-E)UU;)S,V+C<X,SHR-RXP-C<G
M72`]("=+;W,@06ER<&]R="<["B1C;V]R9&EN871E<ULG1W)E96-E)UU;)S,W
M+C`V-SHR,BXP,3<G72`]("=+86QA;6%T82!!:7)P;W)T)SL*)&-O;W)D:6YA
M=&5S6R='<F5E8V4G75LG,S<N-3,S.C(R+C0P,"==(#T@)U1R:7!O;&ES($%I
M<G!O<G0G.PHD8V]O<F1I;F%T97-;)T=R965C92==6R<S-RXW,#`Z,C8N.3$W
M)UT@/2`G4V%M;W,@06ER<&]R="<["B1C;V]R9&EN871E<ULG1W)E96-E)UU;
M)S,W+CDP,#HR,RXW,S,G72`]("=!=&AI;F%I($%I<G!O<G0G.PHD8V]O<F1I
M;F%T97-;)T=R965C92==6R<S-RXY,3<Z,C$N,C@S)UT@/2`G06YD<F%V:61A
M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T=R965C92==6R<S."XP-C<Z,C,N
M-34P)UT@/2`G16QE9G-I<R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R='<F5E
M8V4G75LG,S@N,3`P.C(S+C<X,R==(#T@)U1A=&]I)SL*)&-O;W)D:6YA=&5S
M6R='<F5E8V4G75LG,S@N,3$W.C(P+C4P,"==(#T@)TME9F%L:&YI82!!:7)P
M;W)T)SL*)&-O;W)D:6YA=&5S6R='<F5E8V4G75LG,S@N,34P.C(Q+C0Q-R==
M(#T@)T%R87AO<R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R='<F5E8V4G75LG
M,S@N,S$W.C(S+C4S,R==(#T@)U1A;F%G<F$@06ER<&]R="<["B1C;V]R9&EN
M871E<ULG1W)E96-E)UU;)S,X+C,S,SHR-BXQ,S,G72`]("=#:&EO<R!!:7)P
M;W)T)SL*)&-O;W)D:6YA=&5S6R='<F5E8V4G75LG,S@N-C$W.C(P+C<V-R==
M(#T@)T%K=&EO;B!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R='<F5E8V4G75LG
M,SDN,#8W.C(V+C8P,"==(#T@)TUY=&EL:6YI($%I<G!O<G0G.PHD8V]O<F1I
M;F%T97-;)T=R965C92==6R<S.2XR,3<Z,C(N.#`P)UT@/2`G06YC:&EA;&]S
M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T=R965C92==6R<S.2XV,3<Z,3DN
M.3$W)UT@/2`G2V5R:WER82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R='<F5E
M8V4G75LG,SDN-C,S.C(R+C0Q-R==(#T@)TQA<FES<V$@06ER<&]R="<["B1C
M;V]R9&EN871E<ULG1W)E96-E)UU;)S,Y+CDQ-SHR-2XR,S,G72`]("=,:6UN
M;W,@06ER<&]R="<["B1C;V]R9&EN871E<ULG1W)E96-E)UU;)S0P+C,P,#HR
M,2XW.#,G72`]("=+;WIA;FD@06ER<&]R="<["B1C;V]R9&EN871E<ULG1W)E
M96-E)UU;)S0P+C0U,#HR,2XR.#,G72`]("=+87-T;W)I82!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R='<F5E8V4G75LG-#`N-3$W.C(R+CDV-R==(#T@)U1H
M97-S86QO;FEK:2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R='<F5E8V4G75LG
M-#`N.#4P.C(U+CDQ-R==(#T@)T%L97AA;F1R;W5P;VQI($%I<G!O<G0G.PHD
M8V]O<F1I;F%T97-;)T=R965C92==6R<T,"XY.#,Z,C0N-C`P)UT@/2`G0VAR
M>7-O=7!O;&D@06ER<&]R="<["B1C;V]R9&EN871E<ULG1W)E96YL86YD)UU;
M)S4Y+CDX,SHM-#4N,C`P)UT@/2`G06YG:7-O<2<["B1C;V]R9&EN871E<ULG
M1W)E96YL86YD)UU;)S8P+C`U,#HM-#,N,38W)UT@/2`G4')I;G,@0VAR:7-T
M:6%N(%-U;F0G.PHD8V]O<F1I;F%T97-;)T=R965N;&%N9"==6R<V,"XW,3<Z
M+30V+C`U,"==(#T@)TIU;&EA;F5H86%B)SL*)&-O;W)D:6YA=&5S6R='<F5E
M;FQA;F0G75LG-C$N,38W.BTT-2XT,3<G72`]("=.87)S87)S=6%Q)SL*)&-O
M;W)D:6YA=&5S6R='<F5E;FQA;F0G75LG-C$N,C,S.BTT."XQ,#`G72`]("='
M<F]E;FYE9&%L)SL*)&-O;W)D:6YA=&5S6R='<F5E;FQA;F0G75LG-C(N,#`P
M.BTT.2XV-C<G72`]("=&<F5D97)I:W-H86%B)SL*)&-O;W)D:6YA=&5S6R='
M<F5E;FQA;F0G75LG-C0N,38W.BTU,2XW-3`G72`]("=';V1T:&%A8B`O($YU
M=6LG.PHD8V]O<F1I;F%T97-;)T=R965N;&%N9"==6R<V-2XU.#,Z+3,W+C$U
M,"==(#T@)TMU;'5S=6L@3'5F=&AA=FXG.PHD8V]O<F1I;F%T97-;)T=R965N
M;&%N9"==6R<V-2XV,#`Z+3,W+C8S,R==(#T@)U1A<VEI;&%Q)SL*)&-O;W)D
M:6YA=&5S6R='<F5E;FQA;F0G75LG-C8N.3$W.BTU,RXV-C<G72`]("=(;VQS
M=&5I;G-B;W)G)SL*)&-O;W)D:6YA=&5S6R='<F5E;FQA;F0G75LG-C<N,#$W
M.BTU,"XW,#`G72`]("=39'(@4W1R;V5M9FIO<F0G.PHD8V]O<F1I;F%T97-;
M)T=R965N;&%N9"==6R<V-RXW.#,Z+3,R+C,P,"==(#T@)T%P=71I=&5E<2<[
M"B1C;V]R9&EN871E<ULG1W)E96YL86YD)UU;)S8X+C<P,#HM-3(N-S4P)UT@
M/2`G16=E9&5S;6EN9&4G.PHD8V]O<F1I;F%T97-;)T=R965N;&%N9"==6R<V
M.2XR,S,Z+34Q+C`V-R==(#T@)TIA8V]B<VAA=FX@3'5F=&AA=FXG.PHD8V]O
M<F1I;F%T97-;)T=R965N;&%N9"==6R<W,"XT,3<Z+3(Q+CDV-R==(#T@)T-A
M<&4@5&]B:6X@075T;VUA=&5D(%)E<&]R=&EN9R!3=&%T:6]N)SL*)&-O;W)D
M:6YA=&5S6R='<F5E;FQA;F0G75LG-S`N-#@S.BTR,2XY-3`G72`]("=38V]R
M97-B>7-U;F0G.PHD8V]O<F1I;F%T97-;)T=R965N;&%N9"==6R<W,"XW-3`Z
M+3(R+C8U,"==(#T@)T-O;G-T86)L92!0>6YT)SL*)&-O;W)D:6YA=&5S6R='
M<F5E;FQA;F0G75LG-S0N,S`P.BTR,"XR,3<G72`]("=$86YE8F]R9R<["B1C
M;V]R9&EN871E<ULG1W)E96YL86YD)UU;)S<V+C4S,SHM-C@N-S4P)UT@/2`G
M5&AU;&4@02X@0BXG.PHD8V]O<F1I;F%T97-;)T=R965N;&%N9"==6R<W-BXW
M-C<Z+3$X+C8V-R==(#T@)T1A;FUA<FMS:&%V;B<["B1C;V]R9&EN871E<ULG
M1W)E;F%D82==6R<Q,BXP,#`Z+38Q+C<X,R==(#T@)U!O:6YT(%-A;&EN97,@
M06ER<&]R="<["B1C;V]R9&EN871E<ULG1W5A9&5L;W5P92==6R<Q-BXR-C<Z
M+38Q+C4Q-R==(#T@)TQE(%)A:7IE="P@1W5A9&5L;W5P92<["B1C;V]R9&EN
M871E<ULG1W5A9&5L;W5P92==6R<Q-RXY,#`Z+38R+C@U,"==(#T@)T=U<W1A
M=FEA+"!386EN="!"87)T:&5L96UY)SL*)&-O;W)D:6YA=&5S6R='=6%T96UA
M;&$G75LG,3,N.3$W.BTY,"XX,3<G72`]("=386X@2F]S92<["B1C;V]R9&EN
M871E<ULG1W5A=&5M86QA)UU;)S$T+C4S,SHM.3$N-C8W)UT@/2`G4F5T86QH
M=6QE=2<["B1C;V]R9&EN871E<ULG1W5A=&5M86QA)UU;)S$T+C4X,SHM.3`N
M-3$W)UT@/2`G1W5A=&5M86QA($%E<F]P=65R=&]L82!!=7)O<F$G.PHD8V]O
M<F1I;F%T97-;)T=U871E;6%L82==6R<Q-2XS,3<Z+3DQ+C0V-R==(#T@)TAU
M96AU971E;F%N9V\G.PHD8V]O<F1I;F%T97-;)T=U871E;6%L82==6R<Q-2XT
M-C<Z+3DP+C,Q-R==(#T@)T-O8F%N)SL*)&-O;W)D:6YA=&5S6R='=6%T96UA
M;&$G75LG,34N-S$W.BTX."XV,#`G72`]("=0=65R=&\@0F%R<FEO<R<["B1C
M;V]R9&EN871E<ULG1W5A=&5M86QA)UU;)S$V+CDQ-SHM.#DN.#@S)UT@/2`G
M1FQO<F5S)SL*)&-O;W)D:6YA=&5S6R='=6EN96$G75LG,3`N,#,S.BTQ,"XW
M-3`G72`]("=&87)A;F%H("\@0F%D86QA)SL*)&-O;W)D:6YA=&5S6R='=6EN
M96$G75LG,3`N,#4P.BTQ,BXX-C<G72`]("=+:6YD:6$G.PHD8V]O<F1I;F%T
M97-;)T=U:6YE82==6R<Q,"XS.#,Z+3DN,S`P)UT@/2`G2V%N:V%N)SL*)&-O
M;W)D:6YA=&5S6R='=6EN96$G75LG,3`N.3,S.BTQ-"XS,3<G72`]("=";VME
M)SL*)&-O;W)D:6YA=&5S6R='=6EN96$G75LG,3$N,S$W.BTQ,BXS,#`G72`]
M("=,86)E)SL*)&-O;W)D:6YA=&5S6R='=6EN96$G75LG,3$N-#,S.BTY+C$V
M-R==(#T@)U-I9W5I<FDG.PHD8V]O<F1I;F%T97-;)T=U:6YE82==6R<W+C<S
M,SHM."XX,S,G72`]("=.7"=:97)E:V]R92<["B1C;V]R9&EN871E<ULG1W5I
M;F5A)UU;)S@N-3,S.BTY+C0V-R==(#T@)TUA8V5N=&$G.PHD8V]O<F1I;F%T
M97-;)T=U:6YE82==6R<Y+C$X,SHM,3`N,3`P)UT@/2`G2VES<VED;W5G;W4G
M.PHD8V]O<F1I;F%T97-;)T=U:6YE82==6R<Y+C4V-SHM,3,N-C$W)UT@/2`G
M0V]N86MR>2`O($=B97-S:6$G.PHD8V]O<F1I;F%T97-;)T=U:6YE82U":7-S
M874G75LG,3$N.#@S.BTQ-2XV-3`G72`]("=":7-S874@065R;W!O<G0G.PHD
M8V]O<F1I;F%T97-;)T=U:6YE82U":7-S874G75LG,3(N,38W.BTQ-"XV-C<G
M72`]("="869A=&$G.PHD8V]O<F1I;F%T97-;)T=U>6%N82==6R<V+C4P,#HM
M-3@N,C4P)UT@/2`G5&EM96AR:2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R='
M=7EA;F$G75LG-BXX,#`Z+34X+C$U,"==(#T@)T=E;W)G971O=VXG.PHD8V]O
M<F1I;F%T97-;)TAA:71I)UU;)S$X+C4V-SHM-S(N,S`P)UT@/2`G4&]R="U!
M=2U0<FEN8V4@+R!!97)O<&]R="!);G1E<FYA=&EO;F%L)SL*)&-O;W)D:6YA
M=&5S6R=(86ET:2==6R<Q.2XW-3`Z+3<R+C$X,R==(#T@)T-A<"U(86ET:65N
M)SL*)&-O;W)D:6YA=&5S6R=(;VYD=7)A<R==6R<Q,RXR-C<Z+3@W+C8U,"==
M(#T@)T%M87!A;&$G.PHD8V]O<F1I;F%T97-;)TAO;F1U<F%S)UU;)S$S+C,P
M,#HM.#<N,3@S)UT@/2`G0VAO;'5T96-A)SL*)&-O;W)D:6YA=&5S6R=(;VYD
M=7)A<R==6R<Q-"XP-3`Z+3@W+C(Q-R==(#T@)U1E9W5C:6=A;'!A)SL*)&-O
M;W)D:6YA=&5S6R=(;VYD=7)A<R==6R<Q-"XS,3<Z+3@X+C$U,"==(#T@)TQA
M($5S<&5R86YZ82<["B1C;V]R9&EN871E<ULG2&]N9'5R87,G75LG,30N,S@S
M.BTX-RXV,3<G72`]("=#;W)O;F5L($5N<FEQ=64@4V]T;R!#86YO($%I<B!"
M87-E)SL*)&-O;W)D:6YA=&5S6R=(;VYD=7)A<R==6R<Q-"XW.#,Z+3@X+C<X
M,R==(#T@)U-A;G1A(%)O<V$@1&4@0V]P86XG.PHD8V]O<F1I;F%T97-;)TAO
M;F1U<F%S)UU;)S$T+CDP,#HM.#4N.3,S)UT@/2`G0V%T86-A;6%S)SL*)&-O
M;W)D:6YA=&5S6R=(;VYD=7)A<R==6R<Q-2XQ-C<Z+3@W+C$Q-R==(#T@)UEO
M<F\G.PHD8V]O<F1I;F%T97-;)TAO;F1U<F%S)UU;)S$U+C(Q-SHM.#,N.#`P
M)UT@/2`G4'5E<G1O($QE;7!I<F$G.PHD8V]O<F1I;F%T97-;)TAO;F1U<F%S
M)UU;)S$U+C0U,#HM.#<N.3,S)UT@/2`G3&$@365S82!386X@4&5D<F\@4W5L
M82<["B1C;V]R9&EN871E<ULG2&]N9'5R87,G75LG,34N-S$W.BTX-RXT.#,G
M72`]("=496QA)SL*)&-O;W)D:6YA=&5S6R=(;VYD=7)A<R==6R<Q-2XW,S,Z
M+3@V+C@V-R==(#T@)TQA($-E:6)A($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;
M)TAO;F1U<F%S)UU;)S$V+C,Q-SHM.#8N-3$W)UT@/2`G4F]A=&%N)SL*)&-O
M;W)D:6YA=&5S6R=(;VYD=7)A<R==6R<Q-BXT-C<Z+3@V+C`V-R==(#T@)T=U
M86YA:F$G.PHD8V]O<F1I;F%T97-;)TAO;F1U<F%S)UU;)S$W+C0P,#HM.#,N
M.3,S)UT@/2`G27-L87,@1&5L($-I<VYE)SL*)&-O;W)D:6YA=&5S6R=(;VYG
M($MO;F<G75LG,C(N,C`P.C$Q-"XP,3<G72`]("=#:&5U;F<@0VAA=2<["B1C
M;V]R9&EN871E<ULG2&]N9R!+;VYG)UU;)S(R+C,S,SHQ,30N,3@S)UT@/2`G
M2&]N9R!+;VYG($EN=&5R+4YA=&EO;F%L($%I<G!O<G0G.PHD8V]O<F1I;F%T
M97-;)TAU;F=A<GDG75LG-#8N,3`P.C$X+C(S,R==(#T@)U!E8W,@+R!0;V=A
M;GDG.PHD8V]O<F1I;F%T97-;)TAU;F=A<GDG75LG-#8N,C4P.C(P+C$P,"==
M(#T@)U-Z96=E9"<["B1C;V]R9&EN871E<ULG2'5N9V%R>2==6R<T-BXS.#,Z
M,3<N.#,S)UT@/2`G2V%P;W-V87(G.PHD8V]O<F1I;F%T97-;)TAU;F=A<GDG
M75LG-#8N-C@S.C(Q+C$V-R==(#T@)T)E:V5S8W-A8F$G.PHD8V]O<F1I;F%T
M97-;)TAU;F=A<GDG75LG-#8N.3$W.C$X+C`U,"==(#T@)U-I;V9O:R<["B1C
M;V]R9&EN871E<ULG2'5N9V%R>2==6R<T-BXY,3<Z,3DN-S4P)UT@/2`G2V5C
M<VME;65T)SL*)&-O;W)D:6YA=&5S6R=(=6YG87)Y)UU;)S0W+C$Q-SHR,"XR
M,S,G72`]("=3>F]L;F]K)SL*)&-O;W)D:6YA=&5S6R=(=6YG87)Y)UU;)S0W
M+C(P,#HQ-RXU,#`G72`]("=087!A)SL*)&-O;W)D:6YA=&5S6R=(=6YG87)Y
M)UU;)S0W+C(V-SHQ-BXV,S,G72`]("=3>F]M8F%T:&5L>2<["B1C;V]R9&EN
M871E<ULG2'5N9V%R>2==6R<T-RXT,S,Z,3DN,C8W)UT@/2`G0G5D87!E<W0@
M+R!&97)I:&5G>2<["B1C;V]R9&EN871E<ULG2'5N9V%R>2==6R<T-RXT-3`Z
M,3@N.38W)UT@/2`G0G5D86]R<R<["B1C;V]R9&EN871E<ULG2'5N9V%R>2==
M6R<T-RXT.#,Z,C$N-C`P)UT@/2`G1&5B<F5C96XG.PHD8V]O<F1I;F%T97-;
M)TAU;F=A<GDG75LG-#<N-3$W.C$Y+C`S,R==(#T@)T)U9&%P97-T($UE="!#
M96YT97(G.PHD8V]O<F1I;F%T97-;)TAU;F=A<GDG75LG-#<N.38W.C(Q+CDX
M,R==(#T@)TYY:7)E9WEH87IA("\@3F%P:V]R)SL*)&-O;W)D:6YA=&5S6R=(
M=6YG87)Y)UU;)S0X+C`X,SHR,"XW-C<G72`]("=-:7-K;VQC)SL*)&-O;W)D
M:6YA=&5S6R=)8V5L86YD)UU;)S8S+C0P,#HM,C`N,C@S)UT@/2`G5F5S=&UA
M;FYA97EJ87(G.PHD8V]O<F1I;F%T97-;)TEC96QA;F0G75LG-C,N.38W.BTR
M,BXV,#`G72`]("=+969L879I:W5R9FQU9W9O;&QU<B<["B1C;V]R9&EN871E
M<ULG26-E;&%N9"==6R<V-"XQ,S,Z+3(Q+CDP,"==(#T@)U)E>6MJ879I:R<[
M"B1C;V]R9&EN871E<ULG26-E;&%N9"==6R<V-"XS,#`Z+3$U+C(Q-R==(#T@
M)T%K=7)N97,G.PHD8V]O<F1I;F%T97-;)TEC96QA;F0G75LG-C4N,#@S.BTR
M,BXW,S,G72`]("=3='EK:VES:&]L;75R)SL*)&-O;W)D:6YA=&5S6R=)8V5L
M86YD)UU;)S8U+C(X,SHM,30N-#`P)UT@/2`G16=I;'-S=&%D:7(G.PHD8V]O
M<F1I;F%T97-;)TEC96QA;F0G75LG-C4N-C@S.BTQ."XP.#,G72`]("=!:W5R
M97ER:2<["B1C;V]R9&EN871E<ULG26-E;&%N9"==6R<V-2XW,#`Z+3$T+C@Q
M-R==(#T@)U-K:F%L9'1H:6YG<W-T861I<B<["B1C;V]R9&EN871E<ULG26-E
M;&%N9"==6R<V-BXT-3`Z+3$U+CDU,"==(#T@)U)A=69A<FAO9FXG.PHD8V]O
M<F1I;F%T97-;)TEC96QA;F0G75LG-C8N-3,S.BTQ."XP,3<G72`]("='<FEM
M<V5Y)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<Q,"XW-C<Z-S@N-S$W)UT@
M/2`G5&ER=6-H8VAI<F%P86QL:2<["B1C;V]R9&EN871E<ULG26YD:6$G75LG
M,3$N,#,S.C<W+C`U,"==(#T@)T-O:6UB871O<F4@+R!0965L86UE9'4G.PHD
M8V]O<F1I;F%T97-;)TEN9&EA)UU;)S$Q+C8V-SHY,BXW,3<G72`]("=0;W)T
M($)L86ER)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<Q,BXY,3<Z-S0N.#@S
M)UT@/2`G36%N9V%L;W)E("\@0F%J<&4G.PHD8V]O<F1I;F%T97-;)TEN9&EA
M)UU;)S$R+CDQ-SHW.2XQ-3`G72`]("=696QL;W)E)SL*)&-O;W)D:6YA=&5S
M6R=);F1I82==6R<Q,RXP,#`Z.#`N,3@S)UT@/2`G36%D<F%S("\@36EN86UB
M86MK86TG.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S$T+C0X,SHW."XX,S,G
M72`]("=#=61D87!A:"<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,34N,34P
M.C<V+C@U,"==(#T@)T)E;&QA<GDG.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;
M)S$U+C,X,SHW,RXX,3<G72`]("=';V$@+R!$86)O;&EM($%I<G!O<G0G.PHD
M8V]O<F1I;F%T97-;)TEN9&EA)UU;)S$U+C@U,#HW-"XV,3<G72`]("="96QG
M875M("\@4V%M8G)A)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<Q-BXU,S,Z
M.#`N.#`P)UT@/2`G5FEJ87EA=V%D82`O($=A;FYA=F%R86TG.PHD8V]O<F1I
M;F%T97-;)TEN9&EA)UU;)S$V+C<P,#HW-"XR,S,G72`]("=+;VQH87!U<B<[
M"B1C;V]R9&EN871E<ULG26YD:6$G75LG,3<N-#4P.C<X+C0V-R==(#T@)TAY
M9&5R86)A9"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<Q-RXV
M-C<Z-S4N.3`P)UT@/2`G4VAO;&%P=7(G.PHD8V]O<F1I;F%T97-;)TEN9&EA
M)UU;)S$Y+C$Q-SHW,BXX-3`G72`]("=";VUB87D@+R!386YT86-R=7HG.PHD
M8V]O<F1I;F%T97-;)TEN9&EA)UU;)S$Y+C@U,#HW-2XT,#`G72`]("=!=7)A
M;F=A8F%D($-H:6MA;'1H86X@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=)
M;F1I82==6R<R,"XR-3`Z.#4N.#,S)UT@/2`G0FAU8F%N97-W87(G.PHD8V]O
M<F1I;F%T97-;)TEN9&EA)UU;)S(P+C<P,#HW-RXP-C<G72`]("=!:V]L82<[
M"B1C;V]R9&EN871E<ULG26YD:6$G75LG,C$N,3`P.C<Y+C`U,"==(#T@)TYA
M9W!U<B!3;VYE9V%O;B<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,C$N-S4P
M.C<R+C(P,"==(#T@)T)H875N86=A<B<["B1C;V]R9&EN871E<ULG26YD:6$G
M75LG,C$N.#,S.C<V+C,V-R==(#T@)TMH86YD=V$G.PHD8V]O<F1I;F%T97-;
M)TEN9&EA)UU;)S(Q+CDQ-SHX-"XP.#,G72`]("=*:&%R<W5G=61A)SL*)&-O
M;W)D:6YA=&5S6R=);F1I82==6R<R,BXS,#`Z-S`N-S@S)UT@/2`G4F%J:V]T
M)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R,BXV-3`Z.#@N-#4P)UT@/2`G
M0V%L8W5T=&$@+R!$=6T@1'5M)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R
M,BXW,3<Z-S4N.#`P)UT@/2`G26YD;W)E)SL*)&-O;W)D:6YA=&5S6R=);F1I
M82==6R<R,BXX,3<Z.#8N,3@S)UT@/2`G2F%M<VAE9'!U<B<["B1C;V]R9&EN
M871E<ULG26YD:6$G75LG,C,N,#8W.C<R+C8S,R==(#T@)T%H;6%D86)A9"<[
M"B1C;V]R9&EN871E<ULG26YD:6$G75LG,C,N,C`P.C<Y+CDU,"==(#T@)TIA
M8F%L<'5R)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R,RXR-3`Z-CDN-C8W
M)UT@/2`G0FAU:BU2=61R86UA=&$G.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;
M)S(S+C(X,SHW-RXS-3`G72`]("=":&]P86P@+R!"86ER86=A<F@G.PHD8V]O
M<F1I;F%T97-;)TEN9&EA)UU;)S(S+C,Q-SHX-2XS,3<G72`]("=-+B!/+B!2
M86YC:&DG.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(S+C@X,SHY,2XR-3`G
M72`]("=!9V%R=&%L82<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,C0N-38W
M.C@P+C@S,R==(#T@)U-A=&YA)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R
M-"XV,3<Z-S,N.#@S)UT@/2`G561A:7!U<B!$86)O:R<["B1C;V]R9&EN871E
M<ULG26YD:6$G75LG,C0N-S4P.C@T+CDU,"==(#T@)T=A>6$G.PHD8V]O<F1I
M;F%T97-;)TEN9&EA)UU;)S(T+C<V-SHY,RXY,#`G72`]("=);7!H86P@5'5L
M:6AA;"<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,C4N,34P.C<U+C@U,"==
M(#T@)TMO=&$@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R
M-2XT-3`Z-S@N-3@S)UT@/2`G2FAA;G-I)SL*)&-O;W)D:6YA=&5S6R=);F1I
M82==6R<R-2XT-3`Z.#$N-S,S)UT@/2`G06QL86AA8F%D("\@0F%M:')A=6QI
M)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R-2XT-3`Z.#(N.#8W)UT@/2`G
M5F%R86YA<VD@+R!"86)A='!U<B<["B1C;V]R9&EN871E<ULG26YD:6$G75LG
M,C4N-C`P.C@U+C$P,"==(#T@)U!A=&YA)SL*)&-O;W)D:6YA=&5S6R=);F1I
M82==6R<R-BXQ,#`Z.3$N-3@S)UT@/2`G1V%U:&%T:2<["B1C;V]R9&EN871E
M<ULG26YD:6$G75LG,C8N,C,S.C<X+C(U,"==(#T@)T=W86QI;W(G.PHD8V]O
M<F1I;F%T97-;)TEN9&EA)UU;)S(V+C,P,#HW,RXP,3<G72`]("=*;V1H<'5R
M)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R-BXT,#`Z.#`N-#`P)UT@/2`G
M2V%N<'5R("\@0VAA:V5R:2<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,C8N
M-C,S.C@X+C,Q-R==(#T@)U-I;&EG=7)I)SL*)&-O;W)D:6YA=&5S6R=);F1I
M82==6R<R-BXW-3`Z.#`N.#@S)UT@/2`G3'5C:VYO=R`O($%M875S:2<["B1C
M;V]R9&EN871E<ULG26YD:6$G75LG,C8N-S4P.C@S+C,V-R==(#T@)T=O<F%K
M:'!U<B<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,C8N.#$W.C<U+C@P,"==
M(#T@)TIA:7!U<B`O(%-A;F=A;F5R)SL*)&-O;W)D:6YA=&5S6R=);F1I82==
M6R<R-RXQ-3`Z-S<N.38W)UT@/2`G06=R82<["B1C;V]R9&EN871E<ULG26YD
M:6$G75LG,C<N,C,S.CDT+C$Q-R==(#T@)TYO<G1H($QA:VAI;7!U<B<["B1C
M;V]R9&EN871E<ULG26YD:6$G75LG,C<N-#@S.CDU+C`Q-R==(#T@)T1I8G)U
M9V%R:"`O($UO:&%N8F%R:2<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,C@N
M,S8W.C<Y+C0P,"==(#T@)T)A<F5I;&QY)SL*)&-O;W)D:6YA=&5S6R=);F1I
M82==6R<R."XU-C<Z-S<N,3$W)UT@/2`G3F5W($1E;&AI("\@4&%L86TG.PHD
M8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(X+C4X,SHW-RXR,#`G72`]("=.97<@
M1&5L:&D@+R!3869D87)J=6YG)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R
M.2XQ-C<Z-S4N-S,S)UT@/2`G2&ES<V%R)SL*)&-O;W)D:6YA=&5S6R=);F1I
M82==6R<S,2XR-3`Z-S8N-C8W)UT@/2`G0FEL87-P=7(G.PHD8V]O<F1I;F%T
M97-;)TEN9&EA)UU;)S,Q+C8S,SHW-"XX-C<G72`]("=!;7)I='-A<B<["B1C
M;V]R9&EN871E<ULG26YD:6$G75LG."XT-C<Z-S8N.34P)UT@/2`G5&AI<G5V
M86YA;G1H87!U<F%M)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<Y+C$U,#HY
M,BXX,3<G72`]("=#87(@3FEC;V)A<B<["B1C;V]R9&EN871E<ULG26YD:6$G
M75LG.2XX,S,Z-S@N,#@S)UT@/2`G36%D=7)A:2<["B1C;V]R9&EN871E<ULG
M26YD:6$G75LG.2XY-3`Z-S8N,C8W)UT@/2`G0V]C:&EN("\@5VEL;&EN9V1O
M;B<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)S`N,3$W.C$Q,2XU,S,G
M72`]("=3:6YT86YG)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3`N
M,34P.C$P.2XT,#`G72`]("=0;VYT:6%N86L@+R!3=7!A9&EO)SL*)&-O;W)D
M:6YA=&5S6R=);F1O;F5S:6$G75LG,"XT-C<Z,3`Q+C0U,"==(#T@)U!A:V%N
M8F%R=2`O(%-I;7!A;F=T:6=A)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G
M75LG,"XT-C<Z,3`R+C,Q-R==(#T@)U)E;F=A="`O($IA<'5R82<["B1C;V]R
M9&EN871E<ULG26YD;VYE<VEA)UU;)RTP+C0X,SHQ,#0N-3@S)UT@/2`G4VEN
M9VME<"`O($1A8F\G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<P+C4Q
M-SHQ,C,N,#8W)UT@/2`G1V]R;VYT86QO("\@2F%L86QU9&1I;B<["B1C;V]R
M9&EN871E<ULG26YD;VYE<VEA)UU;)RTP+C8Q-SHQ,3<N,34P)UT@/2`G4V%M
M87)I;F1A("\@5&5M:6YD=6YG)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G
M75LG+3`N-C@S.C$Q.2XW,S,G72`]("=086QU("\@375T:6%R82<["B1C;V]R
M9&EN871E<ULG26YD;VYE<VEA)UU;)S`N-S@S.C$R-RXS.#,G72`]("=497)N
M871E("\@0F%B=6QL86@G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M
M,"XX.#,Z,3`P+C,U,"==(#T@)U!A9&%N9R`O(%1A8FEN9R<["B1C;V]R9&EN
M871E<ULG26YD;VYE<VEA)UU;)RTP+C@X,SHQ,S0N,#4P)UT@/2`G36%N;VMW
M87)I("\@4F5N9&%N:2<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTP
M+CDP,#HQ,C(N-S@S)UT@/2`G3'5W=6L@+R!"=6)U;F<G.PHD8V]O<F1I;F%T
M97-;)TEN9&]N97-I82==6R<P+CDQ-SHQ,#0N-3,S)UT@/2`G5&%N:G5N9W!I
M;F%N9R`O($MI:F%N9R<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTP
M+CDS,SHQ,S$N,3$W)UT@/2`G4V]R;VYG("\@2F5F;6%N)SL*)&-O;W)D:6YA
M=&5S6R=);F1O;F5S:6$G75LG+3`N.34P.C$Q-"XY,#`G72`]("=-=6%R871E
M=V4@+R!"97)I;F=I;B<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTQ
M+C`P,#HQ,30N,#`P)UT@/2`G4&%L86YG:V%R87EA("\@4&%N87)U;F<G.PHD
M8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<Q+C`Q-SHQ,C`N.#`P)UT@/2`G
M5&]L:2U4;VQI("\@3&%L;W,G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==
M6R<Q+C`X,SHQ,#DN-C8W)UT@/2`G4VEN9VMA=V%N9R!):2<["B1C;V]R9&EN
M871E<ULG26YD;VYE<VEA)UU;)S$N,3$W.C$P-"XQ,3<G72`]("="871A;B`H
M4W5M871R82DG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,2XQ.#,Z
M,3,V+C$Q-R==(#T@)T)I86L@+R!-;VMM97(G.PHD8V]O<F1I;F%T97-;)TEN
M9&]N97-I82==6R<M,2XR-C<Z,3$V+CDP,"==(#T@)T)A;&EK<&%P86X@+R!3
M97!I;F=G86XG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,2XS.#,Z
M,3(P+C<S,R==(#T@)U!O<V\@+R!+87-I9W5N8W4G.PHD8V]O<F1I;F%T97-;
M)TEN9&]N97-I82==6R<Q+C4P,#HY-RXV,S,G72`]("='=6YU;F<@4VET;VQI
M("\@0FEN86MA)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG,2XU,S,Z
M,3(T+CDQ-R==(#T@)TUE;F%D;R`O($1R+B!386T@4F%T=6QA;F=I)SL*)&-O
M;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG,2XU-3`Z.3@N.#@S)UT@/2`G4VEB
M;VQG82`O(%!I;F%N9W-O<FDG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==
M6R<M,2XV,3<Z,3(T+C4U,"==(#T@)TQA8G5H82`O(%1A;&EA8G4G.PHD8V]O
M<F1I;F%T97-;)TEN9&]N97-I82==6R<M,2XV,S,Z,3`S+C8U,"==(#T@)TIA
M;6)I("\@4W5L=&%N(%1A:&$G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==
M6R<Q+C@Q-SHQ,C<N.#,S)UT@/2`G1V%L96QA("\@1V%M87)M86QA;74G.PHD
M8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,2XX,S,Z,3,X+C<Q-R==(#T@
M)U-A<FUI)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3$N.#4P.C$P
M.2XY-C<G72`]("=+971A<&%N9R`O(%)A:&%D:2!5<VUA;6%N)SL*)&-O;W)D
M:6YA=&5S6R=);F1O;F5S:6$G75LG+3$N.#8W.C$S-BXR,S,G72`]("=397)U
M:2`O(%EE;F1O<V$G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,3`N
M,38W.C$R,RXV-C<G72`]("=+=7!A;F<@+R!%;"!487)I)SL*)&-O;W)D:6YA
M=&5S6R=);F1O;F5S:6$G75LG+3$P+C4P,#HQ,C$N.#,S)UT@/2`G4V%B=2`O
M(%1A<F1A;74G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,3`N-S,S
M.C$R,RXP-C<G72`]("=2;W1E("\@0F%A)SL*)&-O;W)D:6YA=&5S6R=);F1O
M;F5S:6$G75LG+3(N,#@S.C$R-BXP,#`G72`]("=386YA;F$G.PHD8V]O<F1I
M;F%T97-;)TEN9&]N97-I82==6R<R+C$Q-SHQ,3<N-#4P)UT@/2`G5&%N:G5N
M9R!2961E<"`O($)E<F%U)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG
M+3(N,38W.C$P-BXQ,S,G72`]("=086YG:V%L<&EN86YG("\@4&%N9VMA;'!I
M;F%N9R<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTR+C4V-SHQ-#`N
M-#@S)UT@/2`G2F%Y87!U<F$@+R!396YT86YI)SL*)&-O;W)D:6YA=&5S6R=)
M;F1O;F5S:6$G75LG+3(N-S`P.C$Q,"XW,#`G72`]("=086YG:V%L86X@0G5N
M("\@27-K86YD87(G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,BXW
M-3`Z,3`W+C<U,"==(#T@)U1A;FIU;F=P86YD86X@+R!"=6QU:"!4=6UB86YG
M)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3(N-S8W.C$P,2XS-C<G
M72`]("=+97)I;F-I("\@1&5P871I(%!A<F)O)SL*)&-O;W)D:6YA=&5S6R=)
M;F1O;F5S:6$G75LG,BXX-3`Z,3$W+C,S,R==(#T@)U1A;FIU;F<@4V5L;W(G
M.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,BXX.#,Z,3,R+C(U,"==
M(#T@)T9A:RU&86L@+R!4;W)E82<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA
M)UU;)RTR+CDP,#HQ,#0N-S`P)UT@/2`G4&%L96UB86YG("\@5&%L86YG8F5T
M=71U)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3,N,C4P.C$R-RXP
M.#,G72`]("=.86UL96$G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<S
M+C,S,SHQ,3<N-38W)UT@/2`G5&%R86MA;B`O($IU=V%T82<["B1C;V]R9&EN
M871E<ULG26YD;VYE<VEA)UU;)RTS+C,S,SHQ,S4N-3`P)UT@/2`G3F%B:7)E
M)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3,N,S4P.C$R."XX.#,G
M72`]("=!;6%H86DG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,RXT
M,#`Z,3$V+C(Q-R==(#T@)TMO=&%B87)U)SL*)&-O;W)D:6YA=&5S6R=);F1O
M;F5S:6$G75LG+3,N-#,S.C$Q-"XW-3`G72`]("="86YJ87)M87-I;B`O(%-Y
M86US=61D:6X@3F]O<B<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)S,N
M-38W.CDX+C8X,R==(#T@)TUE9&%N("\@4&]L;VYI82<["B1C;V]R9&EN871E
M<ULG26YD;VYE<VEA)UU;)S,N-3@S.C$R-2XT-C<G72`]("=486AU;F$G.PHD
M8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,RXV-C<Z,3,S+C<U,"==(#T@
M)TMA:6UA;F$@+R!5=&%R;VTG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==
M6R<M,RXW,#`Z,3(X+C`X,R==(#T@)T%M8F]N("\@4&%T=&EM=7)A)SL*)&-O
M;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG,RXW,S,Z,3$U+C8X,R==(#T@)TQO
M;F=B87=A;B`O($IU=F%I(%-E;6%R:6YG)SL*)&-O;W)D:6YA=&5S6R=);F1O
M;F5S:6$G75LG+3,N.#@S.C$P,BXS,S,G72`]("="96YG:W5L=2`O(%!A9&%N
M9VME;6EL:6YG)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3,N.3$W
M.C$S-BXS-C<G72`]("=%;F%R;W1A;&DG.PHD8V]O<F1I;F%T97-;)TEN9&]N
M97-I82==6R<S+CDU,#HQ,#@N,S@S)UT@/2`G4F%N86D@+R!286YA:2<["B1C
M;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTT+C`V-SHQ,S@N.34P)UT@/2`G
M5V%M96YA("\@5V%M96YA)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG
M+30N,3`P.C$R,BXT,S,G72`]("=+96YD87)I("\@5V]L=&5R;6]N+4=I;G-I
M9&DG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<T+C(U,#HY-BXQ,3<G
M72`]("=-975L86)O:"`O($-U="!.>6%K($1H:65N)SL*)&-O;W)D:6YA=&5S
M6R=);F1O;F5S:6$G75LG+30N-#4P.C$P-2XQ.#,G72`]("=-96YG9V%L82`O
M($%S=')A($MS971R82<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTT
M+C<Q-SHQ,S8N-#,S)UT@/2`G2V]K;VYA;R`O(%1I;75K82<["B1C;V]R9&EN
M871E<ULG26YD;VYE<VEA)UU;)RTU+C`V-SHQ,3DN-34P)UT@/2`G56IU;F<@
M4&%N9&%N9R`O($AA<V%N=61D:6XG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I
M82==6R<U+C(S,SHY-RXR,#`G72`]("=,:&]K<V5U;6%W92`O($UA;&EK=7-S
M86QE:"<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTU+C(V-SHQ,#4N
M,3@S)UT@/2`G5&5L=6MB971U;F<@+R!"97)A;G1I)SL*)&-O;W)D:6YA=&5S
M6R=);F1O;F5S:6$G75LG+34N-#8W.C$R,BXV,3<G72`]("="874M0F%U("\@
M0F5T;R!!;6)I<FDG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<U+C4Q
M-SHY-2XT,3<G72`]("="86YD82!!8V5H("\@0FQA;F=B:6YT86YG)SL*)&-O
M;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG-2XX-C<Z.34N,S$W)UT@/2`G4V%B
M86YG("\@0W5T($)A=2<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTV
M+C$P,#HQ-#`N,S`P)UT@/2`G5&%N86@@365R86@@+R!486YA:"!-97)A:"<[
M"B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTV+C$Q-SHQ,#8N-C4P)UT@
M/2`G2F%K87)T82`O(%-O96MA<FYO+4AA='1A)SL*)&-O;W)D:6YA=&5S6R=)
M;F1O;F5S:6$G75LG+38N,C,S.C$P-BXV-3`G72`]("=#=7)U9R`O($)U9&EA
M<G1O)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+38N,C4P.C$P-BXY
M,#`G72`]("=*86MA<G1A($AA;&EM(%!E<F1A;F%K=7-U;6$G.PHD8V]O<F1I
M;F%T97-;)TEN9&]N97-I82==6R<M-BXU-3`Z,3`W+C8V-R==(#T@)TMA;&EJ
M871I)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+38N.3`P.C$P-RXU
M.#,G72`]("="86YD=6YG("\@2'5S96EN)SL*)&-O;W)D:6YA=&5S6R=);F1O
M;F5S:6$G75LG+38N.3@S.C$Q,"XS.#,G72`]("=396UA<F%N9R`O($%H;6%D
M>6%N:2<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTW+C(Q-SHQ,3(N
M-S$W)UT@/2`G4W5R86)A>6$@+R!097)A:R<["B1C;V]R9&EN871E<ULG26YD
M;VYE<VEA)UU;)RTW+C(Q-SHQ,3,N-S$W)UT@/2`G4W5R86)A>6$G.PHD8V]O
M<F1I;F%T97-;)TEN9&]N97-I82==6R<M-RXS,S,Z,3`X+C(U,"==(#T@)U1A
M<VEK;6%L87EA("\@0VEB975R975M)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S
M:6$G75LG+3<N,S8W.C$Q,BXW-C<G72`]("=3=7)A8F%Y82`O($IU86YD82<[
M"B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTW+C8Q-SHQ,3$N-3$W)UT@
M/2`G36%D:75N("\@27-W86AY=61I)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S
M:6$G75LG+3<N-S,S.C$P.2XP,3<G72`]("=#:6QA8V%P)SL*)&-O;W)D:6YA
M=&5S6R=);F1O;F5S:6$G75LG+3<N-S@S.C$Q,"XT,S,G72`]("=*;V=Y86MA
M<G1A("\@061I<W5C:7!T;R<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;
M)RTW+C@V-SHQ,3`N.3$W)UT@/2`G4W5R86MA<G1A("\@061I<W5M87)M;R<[
M"B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTW+CDV-SHQ,3(N-S`P)UT@
M/2`G36%L86YG("\@06)D=6P@4F%H:VUA;G-A;&5H)SL*)&-O;W)D:6YA=&5S
M6R=);F1O;F5S:6$G75LG+3<N.3@S.C$S,2XS,#`G72`]("=3875M;&%K:2<[
M"B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTX+C(Q-SHQ,C0N-38W)UT@
M/2`G06QO<B`O($UA;&DG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M
M."XR-C<Z,3(R+CDV-R==(#T@)TQA<F%N='5K82<["B1C;V]R9&EN871E<ULG
M26YD;VYE<VEA)UU;)RTX+C0S,SHQ,3<N-#$W)UT@/2`G4W5M8F%W82!"97-A
M<B`O(%-U;6)A=V$@0F5S87(G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==
M6R<M."XT-C<Z,30P+C,X,R==(#T@)TUE<F%U:V4@+R!-;W!A:"<["B1C;V]R
M9&EN871E<ULG26YD;VYE<VEA)UU;)RTX+C4S,SHQ,38N,#8W)UT@/2`G06UP
M96YA;B`O(%-E;&%P87)A;F<G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==
M6R<M."XU-3`Z,3$X+C<P,"==(#T@)T)I;6$G.PHD8V]O<F1I;F%T97-;)TEN
M9&]N97-I82==6R<M."XV,S,Z,3(R+C(U,"==(#T@)TUA=6UE<F4@+R!786D@
M3W1I)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3@N-S4P.C$Q-2XQ
M-C<G72`]("=$96YP87-A<B`O($YG=7)A:"U286DG.PHD8V]O<F1I;F%T97-;
M)TEN9&]N97-I82==6R<M.2XV-C<Z,3(P+C,S,R==(#T@)U=A:6YG87!U("\@
M36%U($AA=2<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI
M8R!O9B==6R<R-2XT,3<Z-C`N-S4P)UT@/2`G0VAA:&)A:&%R)SL*)&-O;W)D
M:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S(V+C4X,SHU
M-"XX,S,G72`]("="86YD87(@3&5N9V5H)SL*)&-O;W)D:6YA=&5S6R=)<F%N
M+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S(V+C8S,SHU-RXW-C<G72`]("=*
M87-K)SL*)&-O;W)D:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F
M)UU;)S(W+C(P,#HV,"XW,#`G72`]("=)<F%N<VAA:'(G.PHD8V]O<F1I;F%T
M97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G75LG,C<N,C$W.C4V+C,V
M-R==(#T@)T)A;F1A<F%B8F%S<R<["B1C;V]R9&EN871E<ULG27)A;BP@27-L
M86UI8R!297!U8FQI8R!O9B==6R<R."XY-C<Z-3,N-C@S)UT@/2`G1F%S82<[
M"B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<R
M."XY.#,Z-3`N.#,S)UT@/2`G0G5S:&5H<B!#:78@+R!!9F(G.PHD8V]O<F1I
M;F%T97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G75LG,CDN,3`P.C4X
M+C0P,"==(#T@)T)A;2<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!2
M97!U8FQI8R!O9B==6R<R.2XT-C<Z-C`N.#@S)UT@/2`G6F%H961A;B<["B1C
M;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<R.2XU
M,S,Z-3(N-3@S)UT@/2`G4VAI<F%Z)SL*)&-O;W)D:6YA=&5S6R=)<F%N+"!)
M<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S,P+C(U,#HU-BXY-C<G72`]("=+97)M
M86XG.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G
M75LG,S`N,S8W.C0X+C(U,"==(#T@)T%B861A;B<["B1C;V]R9&EN871E<ULG
M27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S,"XT,S,Z-3`N-S8W)UT@
M/2`G1V%C:"!387)A;B!$=2!'=6YB861A;B<["B1C;V]R9&EN871E<ULG27)A
M;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S,"XW-C<Z-#DN-C8W)UT@/2`G
M3VUI9&EE:"<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI
M8R!O9B==6R<S,2XQ.#,Z-3(N-C8W)UT@/2`G06)A9&5H)SL*)&-O;W)D:6YA
M=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S,Q+C,S,SHT."XV
M-C<G72`]("=!:'=A>B<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!2
M97!U8FQI8R!O9B==6R<S,2XS,S,Z-C$N-#@S)UT@/2`G6F%B;VPG.PHD8V]O
M<F1I;F%T97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G75LG,S$N.3`P
M.C4T+C0P,"==(#T@)UEA>F0G.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M
M:6,@4F5P=6)L:6,@;V8G75LG,S$N.3@S.C0Y+C(V-R==(#T@)TUA<VIE9"U3
M;VQE>6UA;B<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI
M8R!O9B==6R<S,BXS,S,Z-3`N.#4P)UT@/2`G4VAA:')E+4MO<F0G.PHD8V]O
M<F1I;F%T97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G75LG,S(N-#8W
M.C4Q+C<Q-R==(#T@)T5S9F%H86XG.PHD8V]O<F1I;F%T97-;)TER86XL($ES
M;&%M:6,@4F5P=6)L:6,@;V8G75LG,S(N.#8W.C4Y+C(P,"==(#T@)T)I<FIA
M;F0G.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G
M75LG,S,N-C`P.C4V+CDQ-R==(#T@)U1A8F%S)SL*)&-O;W)D:6YA=&5S6R=)
M<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S,S+CDX,SHU,2XT-3`G72`]
M("=+87-H86XG.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M:6,@4F5P=6)L
M:6,@;V8G75LG,S0N,3`P.C0Y+C0P,"==(#T@)T%R86LG.PHD8V]O<F1I;F%T
M97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G75LG,S0N,C8W.C0W+C$Q
M-R==(#T@)TME<FUA;G-H86@G.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M
M:6,@4F5P=6)L:6,@;V8G75LG,S0N-3$W.C0U+C4X,R==(#T@)T=H87-R92U3
M:&ER:6XG.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@
M;V8G75LG,S4N,C8W.C4Y+C(Q-R==(#T@)U1O<F)A="U(97ED87)I96@G.PHD
M8V]O<F1I;F%T97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G75LG,S4N
M,S,S.C0W+C`P,"==(#T@)U-A;F%N9&%J)SL*)&-O;W)D:6YA=&5S6R=)<F%N
M+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S,U+C4U,#HU,RXS.#,G72`]("=3
M96UN86XG.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@
M;V8G75LG,S4N-C@S.C4Q+C,U,"==(#T@)U1E:')A;BU-96AR86)A9"<["B1C
M;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S-BXR
M,3<Z-3<N-C8W)UT@/2`G4V%B>F5V87(G.PHD8V]O<F1I;F%T97-;)TER86XL
M($ES;&%M:6,@4F5P=6)L:6,@;V8G75LG,S8N,C4P.C0V+C(V-R==(#T@)U-A
M9VAE>B<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O
M9B==6R<S-BXR-3`Z-3`N,#`P)UT@/2`G1VAA>G9I;B<["B1C;V]R9&EN871E
M<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S-BXR-C<Z-3DN-C,S
M)UT@/2`G36%S:&AA9"<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!2
M97!U8FQI8R!O9B==6R<S-BXV.#,Z-#@N-#@S)UT@/2`G6F%N:F%N)SL*)&-O
M;W)D:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S,V+C@Q
M-SHU-"XT-C<G72`]("=';W)G86XG.PHD8V]O<F1I;F%T97-;)TER86XL($ES
M;&%M:6,@4F5P=6)L:6,@;V8G75LG,S8N.3`P.C4P+C8V-R==(#T@)U)A;7-A
M<B<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==
M6R<S-RXR,#`Z-#DN-C,S)UT@/2`G4F%S:'0G.PHD8V]O<F1I;F%T97-;)TER
M86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G75LG,S<N-#8W.C4W+C,S,R==(#T@
M)T)O:FYO=7)D)SL*)&-O;W)D:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B
M;&EC(&]F)UU;)S,W+C4S,SHT-2XP.#,G72`]("=/<G5M:65H)SL*)&-O;W)D
M:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S,X+C`X,SHT
M-BXR.#,G72`]("=486)R:7HG.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M
M:6,@4F5P=6)L:6,@;V8G75LG,S@N-34P.C0T+CDV-R==(#T@)TMH;WDG.PHD
M8V]O<F1I;F%T97-;)TER87$G75LG,S`N-#$W.C0W+C8U,"==(#T@)U-H86EB
M86@@+R!"87-R86@G.PHD8V]O<F1I;F%T97-;)TER87$G75LG,S,N,C,S.C0T
M+C(S,R==(#T@)T)A9VAD860G.PHD8V]O<F1I;F%T97-;)TER87$G75LG,S8N
M,S$W.C0S+C$U,"==(#T@)TUO<W5L)SL*)&-O;W)D:6YA=&5S6R=)<F5L86YD
M)UU;)S4Q+C@U,#HM."XT.#,G72`]("=#;W)K($%I<G!O<G0G.PHD8V]O<F1I
M;F%T97-;)TER96QA;F0G75LG-3(N-S`P.BTX+CDQ-R==(#T@)U-H86YN;VX@
M06ER<&]R="<["B1C;V]R9&EN871E<ULG27)E;&%N9"==6R<U,RXS,#`Z+38N
M-#,S)UT@/2`G0V%S96UE;G0@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=)
M<F5L86YD)UU;)S4S+C0S,SHM-BXR-3`G72`]("=$=6)L:6X@06ER<&]R="<[
M"B1C;V]R9&EN871E<ULG27-R865L)UU;)S(Y+C4U,#HS-"XY-3`G72`]("=%
M:6QA="<["B1C;V]R9&EN871E<ULG27-R865L)UU;)S,P+C`P,#HS-"XX,S,G
M72`]("=/=F1A)SL*)&-O;W)D:6YA=&5S6R=)<W)A96PG75LG,S$N,C,S.C,T
M+C<X,R==(#T@)T)E97(M4VAE=F$G.PHD8V]O<F1I;F%T97-;)TES<F%E;"==
M6R<S,2XX-C<Z,S4N,C$W)UT@/2`G2F5R=7-A;&5M($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)TES<F%E;"==6R<S,BXP,#`Z,S0N.3`P)UT@/2`G0F5N+4=U
M<FEO;B!);G1E<FYA=&EO;F%L($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TES
M<F%E;"==6R<S,BXX,#`Z,S4N,#,S)UT@/2`G4V1E+4AA:69A($AA:69A)SL*
M)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<S-2XU,#`Z,3(N-C`P)UT@/2`G3&%M
M<&5D=7-A)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<S-BXV.#,Z,34N,3,S
M)UT@/2`G0V]Z>F\@4W!A9&%R;R<["B1C;V]R9&EN871E<ULG271A;'DG75LG
M,S8N.#$W.C$Q+CDV-R==(#T@)U!A;G1E;&QE<FEA)SL*)&-O;W)D:6YA=&5S
M6R=)=&%L>2==6R<S-RXP.#,Z,30N,C$W)UT@/2`G1V5L82<["B1C;V]R9&EN
M871E<ULG271A;'DG75LG,S<N-#`P.C$T+CDQ-R==(#T@)T-A=&%N:6$@+R!3
M:6=O;F5L;&$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S,W+C0V-SHQ-2XP
M-3`G72`]("=#871A;FEA("\@1F]N=&%N87)O<W-A)SL*)&-O;W)D:6YA=&5S
M6R=)=&%L>2==6R<S-RXU-C<Z,30N,C@S)UT@/2`G16YN82<["B1C;V]R9&EN
M871E<ULG271A;'DG75LG,S<N.3$W.C$R+C4P,"==(#T@)U1R87!A;FD@+R!"
M:7)G:2<["B1C;V]R9&EN871E<ULG271A;'DG75LG,S@N,#8W.C$U+C8U,"==
M(#T@)U)E9V=I;R!#86QA8G)I82<["B1C;V]R9&EN871E<ULG271A;'DG75LG
M,S@N,3`P.C$S+C,P,"==(#T@)U!A;&5R;6\@0F]C8V%D:69A;&-O)SL*)&-O
M;W)D:6YA=&5S6R=)=&%L>2==6R<S."XQ.#,Z,3,N,3`P)UT@/2`G4&%L97)M
M;R`O(%!U;G1A(%)A:7-I)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<S."XR
M,#`Z,34N-34P)UT@/2`G365S<VEN82<["B1C;V]R9&EN871E<ULG271A;'DG
M75LG,S@N-S`P.C$S+C$X,R==(#T@)U5S=&EC82<["B1C;V]R9&EN871E<ULG
M271A;'DG75LG,S@N.3`P.C$V+C(U,"==(#T@)TQA;65Z:6$@5&5R;64G.PHD
M8V]O<F1I;F%T97-;)TET86QY)UU;)S,Y+C`P,#HQ-RXP-C<G72`]("=#<F]T
M;VYE)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<S.2XQ,#`Z.2XU,3<G72`]
M("=#87!O($-A<F)O;F%R82<["B1C;V]R9&EN871E<ULG271A;'DG75LG,SDN
M,C4P.CDN,#8W)UT@/2`G0V%G;&EA<FD@+R!%;&UA<R<["B1C;V]R9&EN871E
M<ULG271A;'DG75LG,SDN,S,S.C$V+C0P,"==(#T@)TUO;G1E(%-C=7)O)SL*
M)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<S.2XS-3`Z."XY-C<G72`]("=$96-I
M;6]M86YN=2<["B1C;V]R9&EN871E<ULG271A;'DG75LG,SDN-3`P.CDN-C,S
M)UT@/2`G0V%P;R!3+B!,;W)E;GIO)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==
M6R<S.2XU.#,Z,34N.#@S)UT@/2`G0F]N:69A=&DG.PHD8V]O<F1I;F%T97-;
M)TET86QY)UU;)S,Y+C8V-SHY+C0S,R==(#T@)U!E<F1A<V1E9F]G=2<["B1C
M;V]R9&EN871E<ULG271A;'DG75LG,SDN-S4P.C@N-#8W)UT@/2`G0V%P;R!&
M<F%S8V$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S,Y+C@Q-SHQ."XS-3`G
M72`]("=3+B!-87)I82!$:2!,975C82<["B1C;V]R9&EN871E<ULG271A;'DG
M75LG,SDN.3,S.CDN-S$W)UT@/2`G0V%P;R!"96QL879I<W1A)SL*)&-O;W)D
M:6YA=&5S6R=)=&%L>2==6R<T,"XP,3<Z,34N,C@S)UT@/2`G0V%P;R!086QI
M;G5R;R<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#`N,#@S.C$V+C`Q-R==
M(#T@)TQA=')O;FEC;R<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#`N,3$W
M.CDN,C4P)UT@/2`G1F]N;FDG.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0P
M+C(S,SHQ."XQ-3`G72`]("=,96-C92<["B1C;V]R9&EN871E<ULG271A;'DG
M75LG-#`N-#,S.C$V+C@X,R==(#T@)TUA<FEN82!$:2!':6YO<V$G.PHD8V]O
M<F1I;F%T97-;)TET86QY)UU;)S0P+C4Q-SHQ-RXT,#`G72`]("='<F]T=&%G
M;&EE)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,"XU-3`Z,30N,C`P)UT@
M/2`G0V%P<FDG.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0P+C4V-SHX+C$V
M-R==(#T@)T-A<&\@0V%C8VEA)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T
M,"XV,S,Z,34N.#`P)UT@/2`G4&]T96YZ82<["B1C;V]R9&EN871E<ULG271A
M;'DG75LG-#`N-C,S.C@N,C@S)UT@/2`G06QG:&5R;R<["B1C;V]R9&EN871E
M<ULG271A;'DG75LG-#`N-C4P.C$W+CDU,"==(#T@)T)R:6YD:7-I)SL*)&-O
M;W)D:6YA=&5S6R=)=&%L>2==6R<T,"XW-C<Z,38N.3,S)UT@/2`G1VEO:6$@
M1&5L($-O;&QE)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,"XX-3`Z,30N
M,S`P)UT@/2`G3F%P;VQI("\@0V%P;V1I8VAI;F\G.PHD8V]O<F1I;F%T97-;
M)TET86QY)UU;)S0P+CDP,#HY+C4Q-R==(#T@)T]L8FEA("\@0V]S=&$@4VUE
M<F%L9&$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0P+CDQ-SHQ,BXY-3`G
M72`]("=0;VYZ82<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#$N,#4P.C$T
M+C`V-R==(#T@)T=R87IZ86YI<V4G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;
M)S0Q+C`U,#HQ-2XR,S,G72`]("=4<F5V:6-O)SL*)&-O;W)D:6YA=&5S6R=)
M=&%L>2==6R<T,2XQ,S,Z,38N-S@S)UT@/2`G0F%R:2`O(%!A;&5S92!-86-C
M:&EE)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,2XR,3<Z.2XT,#`G72`]
M("='=6%R9&EA=F5C8VAI82<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#$N
M-3,S.C$U+C<Q-R==(#T@)T%M96YD;VQA)SL*)&-O;W)D:6YA=&5S6R=)=&%L
M>2==6R<T,2XU-3`Z,3(N.3`P)UT@/2`G3&%T:6YA)SL*)&-O;W)D:6YA=&5S
M6R=)=&%L>2==6R<T,2XU-C<Z,30N-C4P)UT@/2`G0V%M<&]B87-S;R<["B1C
M;V]R9&EN871E<ULG271A;'DG75LG-#$N-C,S.C$S+C,P,"==(#T@)T9R;W-I
M;F]N92<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#$N-C4P.C$R+C0U,"==
M(#T@)U!R871I8V$@1&D@36%R92<["B1C;V]R9&EN871E<ULG271A;'DG75LG
M-#$N-S`P.C$U+CDU,"==(#T@)TUO;G1E(%,N($%N9V5L;R<["B1C;V]R9&EN
M871E<ULG271A;'DG75LG-#$N-S@S.C$R+C4X,R==(#T@)U)O;6$@+R!#:6%M
M<&EN;R<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#$N.#`P.C$R+C(S,R==
M(#T@)U)O;6$@1FEU;6EC:6YO)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T
M,2XY-3`Z,3(N-3`P)UT@/2`G4F]M82`O(%5R8F4G.PHD8V]O<F1I;F%T97-;
M)TET86QY)UU;)S0R+C`P,#HQ,BXW,S,G72`]("='=6ED;VYI82<["B1C;V]R
M9&EN871E<ULG271A;'DG75LG-#(N,#`P.C$U+C`P,"==(#T@)U1E<FUO;&DG
M.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0R+C`S,SHQ,2XX,S,G72`]("=#
M:79I=&%V96-C:&EA)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,BXP.#,Z
M,3(N,C$W)UT@/2`G5FEG;F$@1&D@5F%L;&4G.PHD8V]O<F1I;F%T97-;)TET
M86QY)UU;)S0R+C,X,SHQ,2XQ-C<G72`]("=-;VYT92!!<F=E;G1A<FEO)SL*
M)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,BXT,3<Z,3(N.#4P)UT@/2`G4FEE
M=&DG.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0R+C0S,SHQ,BXP-3`G72`]
M("=6:71E<F)O)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,BXT,S,Z,30N
M,C`P)UT@/2`G4&5S8V%R82<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#(N
M-#8W.C$R+CDX,R==(#T@)TUO;G1E(%1E<FUI;FEL;&\G.PHD8V]O<F1I;F%T
M97-;)TET86QY)UU;)S0R+C<S,SHQ,"XT,#`G72`]("=-+B!#86QA;6ET82<[
M"B1C;V]R9&EN871E<ULG271A;'DG75LG-#(N-S4P.C$Q+C`V-R==(#T@)T=R
M;W-S971O)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,BXY,#`Z,3$N-S8W
M)UT@/2`G4F%D:6-O9F%N:2<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#,N
M,#@S.C$R+C4P,"==(#T@)U!E<G5G:6$G.PHD8V]O<F1I;F%T97-;)TET86QY
M)UU;)S0S+C0P,#HQ,"XX-C<G72`]("=6;VQT97)R82<["B1C;V]R9&EN871E
M<ULG271A;'DG75LG-#,N-#8W.C$Q+C@U,"==(#T@)T%R97IZ;R<["B1C;V]R
M9&EN871E<ULG271A;'DG75LG-#,N-3$W.C$R+C<S,R==(#T@)T9R;VYT;VYE
M)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,RXV,3<Z,3,N,S8W)UT@/2`G
M1F%L8V]N87)A)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,RXV.#,Z,3`N
M,S@S)UT@/2`G4&ES82`O(%,N($=I=7-T;R<["B1C;V]R9&EN871E<ULG271A
M;'DG75LG-#,N.#`P.C$Q+C(P,"==(#T@)T9I<F5N>F4@+R!097)E=&]L82<[
M"B1C;V]R9&EN871E<ULG271A;'DG75LG-#,N.34P.C@N,38W)UT@/2`G0V%P
M;R!-96QE)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T-"XP,S,Z,3(N-C$W
M)UT@/2`G4FEM:6YI)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T-"XP,S,Z
M.2XX,S,G72`]("=)<V]L82!$:2!086QM87)I82<["B1C;V]R9&EN871E<ULG
M271A;'DG75LG-#0N,#4P.C@N,3$W)UT@/2`G06QB96YG82<["B1C;V]R9&EN
M871E<ULG271A;'DG75LG-#0N,#@S.CDN.3@S)UT@/2`G4V%R>F%N82`O($QU
M;FDG.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0T+C(P,#HQ,"XW,#`G72`]
M("=-;VYT92!#:6UO;F4G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0T+C(P
M,#HQ,BXP-C<G72`]("=&;W)L:2<["B1C;V]R9&EN871E<ULG271A;'DG75LG
M-#0N,C$W.C$R+C,P,"==(#T@)T-E<G9I82<["B1C;V]R9&EN871E<ULG271A
M;'DG75LG-#0N,C4P.C<N.#`P)UT@/2`G36]N=&4@36%L86YO='1E)SL*)&-O
M;W)D:6YA=&5S6R=)=&%L>2==6R<T-"XT,3<Z."XX-3`G72`]("='96YO=F$@
M+R!397-T<FDG.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0T+C0S,SHY+CDS
M,R==(#T@)U!A<W-O($1E;&QA($-I<V$G.PHD8V]O<F1I;F%T97-;)TET86QY
M)UU;)S0T+C0U,#HQ,BXS,#`G72`]("=0=6YT82!-87)I;F$G.PHD8V]O<F1I
M;F%T97-;)TET86QY)UU;)S0T+C4S,SHQ,2XS,#`G72`]("=";VQO9VYA("\@
M0F]R9V\@4&%N:6=A;&4G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0T+C8S
M,SHX+CDS,R==(#T@)U!A<W-O($1E:2!':6]V:2<["B1C;V]R9&EN871E<ULG
M271A;'DG75LG-#0N.#,S.C$Q+C8Q-R==(#T@)T9E<G)A<F$G.PHD8V]O<F1I
M;F%T97-;)TET86QY)UU;)S0T+CDQ-SHY+C<S,R==(#T@)U!I86-E;GIA)SL*
M)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T-2XP,S,Z-RXW,S,G72`]("=4;W)I
M;F\@+R!"<FEC($1E;&QA($-R;V-E)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==
M6R<T-2XR,3<Z-RXV-3`G72`]("=4;W)I;F\@+R!#87-E;&QE)SL*)&-O;W)D
M:6YA=&5S6R=)=&%L>2==6R<T-2XS.#,Z,3`N.#8W)UT@/2`G5F5R;VYA("\@
M5FEL;&%F<F%N8V$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0U+C0Q-SHQ
M,"XR.#,G72`]("="<F5S8VEA("\@1VAE9&DG.PHD8V]O<F1I;F%T97-;)TET
M86QY)UU;)S0U+C0S,SHY+C(X,R==(#T@)TUI;&%N;R`O($QI;F%T92<["B1C
M;V]R9&EN871E<ULG271A;'DG75LG-#4N-3`P.C$R+C,S,R==(#T@)U9E;F5Z
M:6$@+R!497-S97)A)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T-2XU,3<Z
M."XV-C<G72`]("=.;W9A<F$@+R!#86UE<FDG.PHD8V]O<F1I;F%T97-;)TET
M86QY)UU;)S0U+C4V-SHQ,2XU,3<G72`]("=6:6-E;GIA)SL*)&-O;W)D:6YA
M=&5S6R=)=&%L>2==6R<T-2XV,3<Z."XW,S,G72`]("=-:6QA;F\@+R!-86QP
M96YS82<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#4N-C4P.C$R+C$X,R==
M(#T@)U1R979I<V\@+R!3+B!!;F=E;&\G.PHD8V]O<F1I;F%T97-;)TET86QY
M)UU;)S0U+C8U,#HQ,RXW-3`G72`]("=4<FEE<W1E)SL*)&-O;W)D:6YA=&5S
M6R=)=&%L>2==6R<T-2XV-C<Z.2XW,#`G72`]("="97)G86UO("\@3W)I;R!!
M;"!397)I;R<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#4N-C@S.C$R+C$P
M,"==(#T@)U1R979I<V\@+R!)<W1R86YA)SL*)&-O;W)D:6YA=&5S6R=)=&%L
M>2==6R<T-2XX,3<Z,3,N-#@S)UT@/2`G4F]N8VAI($1E:2!,96=I;VYA<FDG
M.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0U+C@V-SHY+C`V-R==(#T@)TUO
M;G1E($)I<V)I;F\G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0U+CDS,SHW
M+C<P,"==(#T@)U!I86X@4F]S82<["B1C;V]R9&EN871E<ULG271A;'DG75LG
M-#4N.3@S.C$S+C`S,R==(#T@)U5D:6YE("\@4FEV;VQT;R<["B1C;V]R9&EN
M871E<ULG271A;'DG75LG-#8N,#,S.C$R+C8P,"==(#T@)T%V:6%N;R<["B1C
M;V]R9&EN871E<ULG271A;'DG75LG-#8N,#,S.C$R+C8Q-R==(#T@)T%V:6%N
M;R!5<V%F)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T-BXP,S,Z,3,N,3@S
M)UT@/2`G561I;F4@+R!#86UP;V9O<FUI9&\G.PHD8V]O<F1I;F%T97-;)TET
M86QY)UU;)S0V+C$U,#HQ,2XP,S,G72`]("=086=A;F5L;&$G.PHD8V]O<F1I
M;F%T97-;)TET86QY)UU;)S0V+C,P,#HQ,2XW.#,G72`]("=087-S;R!2;VQL
M92<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#8N-#8W.C$Q+C,S,R==(#T@
M)T)O;'IA;F\G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0V+C4P,#HQ,RXU
M.#,G72`]("=487)V:7-I;R<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#8N
M-S,S.C$R+C(Q-R==(#T@)T1O8F)I86-O)SL*)&-O;W)D:6YA=&5S6R=*86UA
M:6-A)UU;)S$W+CDS,SHM-S8N-S@S)UT@/2`G2VEN9W-T;VX@+R!.;W)M86X@
M36%N;&5Y)SL*)&-O;W)D:6YA=&5S6R=*86UA:6-A)UU;)S$X+C4P,#HM-S<N
M.3$W)UT@/2`G36]N=&5G;R!"87D@+R!386YG<W1E<B<["B1C;V]R9&EN871E
M<ULG2F%P86XG75LG,C0N,S`P.C$U,RXY-C<G72`]("=-:6YA;6ET;W)I<VAI
M;6$G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S(T+C,S,SHQ,C0N,38W)UT@
M/2`G27-H:6=A:VEJ:6UA)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<R-"XT
M-C<Z,3(R+CDX,R==(#T@)UEO;F%G=6YI($%I<G!O<G0G.PHD8V]O<F1I;F%T
M97-;)TIA<&%N)UU;)S(T+C<X,SHQ,C4N,C@S)UT@/2`G36EY86MO:FEM82<[
M"B1C;V]R9&EN871E<ULG2F%P86XG75LG,C0N-S@S.C$T,2XS,3<G72`]("=)
M=V]J:6UA)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<R-2XX,S,Z,3,Q+C(S
M,R==(#T@)TUI;F%M:61A:71O:FEM82<["B1C;V]R9&EN871E<ULG2F%P86XG
M75LG,C8N,3@S.C$R-RXV-3`G72`]("=.86AA($%I<G!O<G0G.PHD8V]O<F1I
M;F%T97-;)TIA<&%N)UU;)S(V+C(V-SHQ,C<N-S4P)UT@/2`G1G5T96YM82!-
M87)I;F4@0V]R<',@06ER($9A8VEL:71Y)SL*)&-O;W)D:6YA=&5S6R=*87!A
M;B==6R<R-BXS,#`Z,3(W+C<V-R==(#T@)TAA;6)Y(%4N(%,N($%R;7D@06ER
M9FEE;&0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S(V+C,S,SHQ,C8N.#`P
M)UT@/2`G2W5M96II;6$G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S(V+C,U
M,#HQ,C<N-S8W)UT@/2`G2V%D96YA($%B)SL*)&-O;W)D:6YA=&5S6R=*87!A
M;B==6R<R-BXW,3<Z,3(W+C<X,R==(#T@)TEE:FEM82!!=7AI;&EA<GD@06(G
M.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S(W+C`X,SHQ-#(N,3@S)UT@/2`G
M0VAI8VAI:FEM82<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,C<N-#,S.C$R
M."XW,#`G72`]("=/:VEN;V5R86)U)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==
M6R<R-RXX,S,Z,3(X+C@X,R==(#T@)U1O:W5N;W-H:6UA($ES;&%N9"<["B1C
M;V]R9&EN871E<ULG2F%P86XG75LG,C@N-#,S.C$R.2XW,3<G72`]("=!;6%M
M:2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S,"XS.#,Z,3,P
M+C8V-R==(#T@)UEA:W5S:&EM82<["B1C;V]R9&EN871E<ULG2F%P86XG75LG
M,S`N-34P.C$S,"XY-3`G72`]("=486YE9V%S:&EM82!!:7)P;W)T)SL*)&-O
M;W)D:6YA=&5S6R=*87!A;B==6R<S,2XS-C<Z,3,P+C@S,R==(#T@)TMA;F]Y
M82!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S$N.#`P.C$S,"XW,3<G
M72`]("=+86=O<VAI;6$@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG
M75LG,S$N.#8W.C$S,2XT-3`G72`]("=-:7EA>F%K:2!!:7)P;W)T)SL*)&-O
M;W)D:6YA=&5S6R=*87!A;B==6R<S,BXP.#,Z,3,Q+C0U,"==(#T@)TYY=71A
M8F%R=2!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S(N-C8W.C$R."XX
M,S,G72`]("=&=6MU92!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==
M6R<S,BXX,S,Z,3,P+C@U,"==(#T@)TMU;6%M;W1O($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)TIA<&%N)UU;)S,R+CDQ-SHQ,CDN.3$W)UT@/2`G3F%G87-A
M:VD@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S,N,3$W.C$S
M.2XW.#,G72`]("=(86-H:6IO:FEM82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S
M6R=*87!A;B==6R<S,RXQ-3`Z,3(Y+C<Q-R==(#T@)U-A<V5B;R!5<VXG.PHD
M8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,S+C,Q-SHQ,S`N-#$W)UT@/2`G365T
M86)A<G4@06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,S+C0X,SHQ,S$N
M-S,S)UT@/2`G3VET82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==
M6R<S,RXU,S,Z,3,S+C8V-R==(#T@)TMO8VAI($%I<G!O<G0G.PHD8V]O<F1I
M;F%T97-;)TIA<&%N)UU;)S,S+C4X,SHQ,S`N-#4P)UT@/2`G1G5K=6]K82!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S,RXV-C<Z,3,U+C,U
M,"==(#T@)TYA;FMI<VAI<F%H86UA($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;
M)TIA<&%N)UU;)S,S+C8X,SHQ,S$N,#4P)UT@/2`G5'-U:6MI($%B)SL*)&-O
M;W)D:6YA=&5S6R=*87!A;B==6R<S,RXW-3`Z,3(Y+C<X,R==(#T@)TEK:2!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S,RXX,3<Z,3,R+C<P
M,"==(#T@)TUA='-U>6%M82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A
M;B==6R<S,RXX,S,Z,3,P+CDU,"==(#T@)TMI=&%K>75S:'4@06ER<&]R="<[
M"B1C;V]R9&EN871E<ULG2F%P86XG75LG,S,N.#@S.C$S,"XV-3`G72`]("=!
M<VAI>6$@06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,S+CDS,SHQ,S$N
M,C@S)UT@/2`G66%M86=U8VAI(%5B92!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S
M6R=*87!A;B==6R<S-"XP,#`Z,3,T+C8S,R==(#T@)TMO;6%T<W5J:6UA($%B
M)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-"XP,S,Z,3,Q+C4U,"==(#T@
M)TAO9G4@06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,T+C`U,#HQ,S$N
M,#4P)UT@/2`G3WIU:VD@06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,T
M+C`V-SHQ,SDN-38W)UT@/2`G36EY86ME:FEM82!!:7)P;W)T)SL*)&-O;W)D
M:6YA=&5S6R=*87!A;B==6R<S-"XQ,S,Z,3,R+C(S,R==(#T@)TEW86MU;FD@
M36%R:6YE($-O<G!S($%I<B!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=*87!A
M;B==6R<S-"XQ,S,Z,3,T+C8Q-R==(#T@)U1O:W5S:&EM82!!8B<["B1C;V]R
M9&EN871E<ULG2F%P86XG75LG,S0N,C$W.C$S-"XP,3<G72`]("=486MA;6%T
M<W4@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S0N,C@S.C$R
M.2XS,S,G72`]("=4<W5S:&EM82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*
M87!A;B==6R<S-"XT,3<Z,3,U+C(U,"==(#T@)TMA;G-A:2!);G1E<FYA=&EO
M;F%L($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,T+C0S,SHQ
M,S(N.3$W)UT@/2`G2&ER;W-H:6UA($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;
M)TIA<&%N)UU;)S,T+C4S,SHQ,S8N-C@S)UT@/2`G06ME;F\@06(G.PHD8V]O
M<F1I;F%T97-;)TIA<&%N)UU;)S,T+C8P,#HQ,S4N-C`P)UT@/2`G66%O($%I
M<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,T+C8V-SHQ,S$N.#`P
M)UT@/2`G27=A;6D@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG
M,S0N-S4P.C$S,RXX-3`G72`]("=/:V%Y86UA($%I<G!O<G0G.PHD8V]O<F1I
M;F%T97-;)TIA<&%N)UU;)S,T+C<U,#HQ,S<N-S`P)UT@/2`G2&%M86UA='-U
M($%B)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-"XW.#,Z,3,U+C0U,"==
M(#T@)T]S86MA($EN=&5R;F%T:6]N86P@06ER<&]R="<["B1C;V]R9&EN871E
M<ULG2F%P86XG75LG,S0N-S@S.C$S.2XS-C<G72`]("=/<VAI;6$@06ER<&]R
M="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S0N.#$W.C$S."XS,#`G72`]
M("=3:&EZ=6AA;6$@06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,T+CDX
M,SHQ,SDN.#,S)UT@/2`G5&%T97EA;6$@06(G.PHD8V]O<F1I;F%T97-;)TIA
M<&%N)UU;)S,U+C(U,#HQ,S8N.3,S)UT@/2`G3F%G;WEA($%I<G!O<G0G.PHD
M8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,U+C(X,SHQ,SDN-C8W)UT@/2`G66]K
M;W-U:V$@1G=F)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-2XS,3<Z,3,X
M+C@V-R==(#T@)T9U:FD@06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,U
M+C,X,SHQ,S8N.#8W)UT@/2`G1VEF=2!!8B<["B1C;V]R9&EN871E<ULG2F%P
M86XG75LG,S4N-#`P.C$S.2XY,3<G72`]("=+:7-A<F%Z=2!!8B<["B1C;V]R
M9&EN871E<ULG2F%P86XG75LG,S4N-#$W.C$S,BXY,#`G72`]("=)>G5M;R!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-2XT-3`Z,3,Y+C0U
M,"==(#T@)T%T<W5G:2!5;FET960@4W1A=&5S($YA=F%L($%I<B!3=&%T:6]N
M)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-2XT.#,Z,3,S+C(U,"==(#T@
M)TUI:&\@06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,U+C4Q-SHQ,SDN
M-#`P)UT@/2`G6F%M82!!:7)F:65L9"<["B1C;V]R9&EN871E<ULG2F%P86XG
M75LG,S4N-3,S.C$S-"XQ-C<G72`]("=4;W1T;W)I($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)TIA<&%N)UU;)S,U+C4U,#HQ,SDN-S@S)UT@/2`G5&]K>6\@
M26YT97)N871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==
M6R<S-2XV,S,Z,3,Y+C@U,"==(#T@)U1O:WEO($AE;&EP;W)T)SL*)&-O;W)D
M:6YA=&5S6R=*87!A;B==6R<S-2XV-C<Z,3,Y+C4S,R==(#T@)T-H;V9U($%I
M<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,U+C8X,SHQ,SDN-S8W
M)UT@/2`G5&]K>6\G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,U+C<P,#HQ
M,SDN-#`P)UT@/2`G5&%C:&EK87=A($%B)SL*)&-O;W)D:6YA=&5S6R=*87!A
M;B==6R<S-2XW-3`Z,3,Y+C,U,"==(#T@)UEO:V]T82!!8B<["B1C;V]R9&EN
M871E<ULG2F%P86XG75LG,S4N-S8W.C$T,"XS.#,G72`]("=.97<@5&]K>6\@
M26YT97(M3F%T:6]N86P@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG
M75LG,S4N.#`P.C$T,"XP,3<G72`]("=3:&EM;V9U<V$@06(G.PHD8V]O<F1I
M;F%T97-;)TIA<&%N)UU;)S,U+C@S,SHQ,SDN-#$W)UT@/2`G27)U;6$@06(G
M.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,V+C`S,SHQ-#`N,C`P)UT@/2`G
M2V%S=6UI9V%U<F$@06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,V+C$S
M,SHQ,S8N,C,S)UT@/2`G1G5K=6D@06ER<&]R="<["B1C;V]R9&EN871E<ULG
M2F%P86XG75LG,S8N,38W.C$S-RXY,S,G72`]("=-871S=6UO=&\@06ER<&]R
M="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S8N,3@S.C$S,RXS,S,G72`]
M("=/:VD@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S8N,3@S
M.C$T,"XT,3<G72`]("=(>6%K=7)I($%B)SL*)&-O;W)D:6YA=&5S6R=*87!A
M;B==6R<S-BXS.#,Z,3,V+C0Q-R==(#T@)TMO;6%T<W4@06(G.PHD8V]O<F1I
M;F%T97-;)TIA<&%N)UU;)S,V+C4Q-SHQ,SDN.#8W)UT@/2`G571S=6YO;6EY
M82!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S8N-C4P.C$S-RXQ.#,G
M72`]("=4;WEA;6$@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG
M,S<N,C,S.C$T,"XT,S,G72`]("=&=6MU<VAI;6$@06ER<&]R="<["B1C;V]R
M9&EN871E<ULG2F%P86XG75LG,S<N.34P.C$S.2XQ,3<G72`]("=.:6EG871A
M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,X+C`U,#HQ,S@N
M-#$W)UT@/2`G4V%D;R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==
M6R<S."XQ,S,Z,30P+CDQ-R==(#T@)U-E;F1A:2!!:7)P;W)T)SL*)&-O;W)D
M:6YA=&5S6R=*87!A;B==6R<S."XR,S,Z,30P+CDQ-R==(#T@)TMA<W5M:6YO
M;64@06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,X+C0P,#HQ-#$N,C$W
M)UT@/2`G36%T<W5S:&EM82!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG
M,S@N-#$W.C$T,"XS-C<G72`]("=986UA9V%T82!!:7)P;W)T)SL*)&-O;W)D
M:6YA=&5S6R=*87!A;B==6R<S.2XT,S,Z,30Q+C$S,R==(#T@)TAA;F%M86MI
M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,Y+C8Q-SHQ-#`N
M,C$W)UT@/2`G06MI=&$@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG
M75LG-#`N-34P.C$T,2XT-C<G72`]("=(86-H:6YO:&4@06(G.PHD8V]O<F1I
M;F%T97-;)TIA<&%N)UU;)S0P+C<P,#HQ-#$N,S@S)UT@/2`G36ES87=A($%B
M)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<T,"XW,S,Z,30P+C<P,"==(#T@
M)T%O;6]R:2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<T,2XR
M,S,Z,30Q+C$S,R==(#T@)T]M:6YA=&\@06(G.PHD8V]O<F1I;F%T97-;)TIA
M<&%N)UU;)S0Q+C<V-SHQ-#`N.#$W)UT@/2`G2&%K;V1A=&4@06ER<&]R="<[
M"B1C;V]R9&EN871E<ULG2F%P86XG75LG-#(N,S$W.C$T,"XY.#,G72`]("=-
M=7)O<F%N)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<T,BXW,S,Z,30S+C(Q
M-R==(#T@)T]B:6AI<F\@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG
M75LG-#(N.#`P.C$T,2XV-C<G72`]("=#:&ET;W-E($%B)SL*)&-O;W)D:6YA
M=&5S6R=*87!A;B==6R<T,BXX,3<Z,30Q+C8X,R==(#T@)T-H:71O<V4@2F%P
M86YE<V4@06ER(%-E;&8@1&5F96YS92!&;W)C92<["B1C;V]R9&EN871E<ULG
M2F%P86XG75LG-#(N.3@S.C$T-"XT,#`G72`]("=+=7-H:7)O)SL*)&-O;W)D
M:6YA=&5S6R=*87!A;B==6R<T,RXP,S,Z,30T+C(P,"==(#T@)TMU<VAI<F\@
M06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG-#,N,3$W.C$T,2XS
M.#,G72`]("=387!P;W)O($%B)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<T
M,RXU-C<Z,30T+CDV-R==(#T@)TYA:V%S:&EB971S=2!!:7)P;W)T)SL*)&-O
M;W)D:6YA=&5S6R=*87!A;B==6R<T,RXV-C<Z,30R+C0U,"==(#T@)T%S86AI
M:V%W82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<T,RXX,#`Z
M,30R+C,V-R==(#T@)T%S86AI:V%W82!!8B<["B1C;V]R9&EN871E<ULG2F%P
M86XG75LG-#,N.#@S.C$T-"XQ-C<G72`]("=-96UA;6)E='-U($%I<G!O<G0G
M.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S0T+C(U,#HQ-#,N-3,S)UT@/2`G
M36]M8F5T<W4@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG-#4N
M-#`P.C$T,2XX,#`G72`]("=786MK86YA:2!!:7)P;W)T)SL*)&-O;W)D:6YA
M=&5S6R=*;W)D86XG75LG,CDN-C,S.C,U+C`Q-R==(#T@)T%Q86)A($%I<G!O
M<G0G.PHD8V]O<F1I;F%T97-;)TIO<F1A;B==6R<S,"XQ-C<Z,S4N-S@S)UT@
M/2`G36%<)T%N)SL*)&-O;W)D:6YA=&5S6R=*;W)D86XG75LG,S$N-C8W.C,U
M+CDV-R==(#T@)U%U965N($%L:6$@06ER<&]R="<["B1C;V]R9&EN871E<ULG
M2F]R9&%N)UU;)S,Q+CDX,SHS-2XY.#,G72`]("=!;6UA;B!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R=*;W)D86XG75LG,S(N,C`P.C,W+C$S,R==(#T@)T@M
M-5PG4V%F87=I)SL*)&-O;W)D:6YA=&5S6R=*;W)D86XG75LG,S(N,S8W.C,V
M+C(U,"==(#T@)TUA9G)A<2<["B1C;V]R9&EN871E<ULG2F]R9&%N)UU;)S,R
M+C4P,#HS."XR,#`G72`]("=(+31<)TER=V%I<VAE9"<["B1C;V]R9&EN871E
M<ULG2F]R9&%N)UU;)S,R+C4U,#HS-2XX-3`G72`]("=)<F)I9"<["B1C;V]R
M9&EN871E<ULG2V%Z86MH<W1A;B==6R<T,BXS,3<Z-CDN-S`P)UT@/2`G4VAY
M;6ME;G0G.PHD8V]O<F1I;F%T97-;)TMA>F%K:'-T86XG75LG-#,N,C,S.C<V
M+CDS,R==(#T@)T%L;6%T>2<["B1C;V]R9&EN871E<ULG2V%Z86MH<W1A;B==
M6R<T-"XX-3`Z-C4N-3`P)UT@/2`G2WIY;"U/<F1A)SL*)&-O;W)D:6YA=&5S
M6R=+87IA:VAS=&%N)UU;)S0V+C<X,SHV,2XV-3`G72`]("=!<F%L<VMO92!-
M;W)E)SL*)&-O;W)D:6YA=&5S6R=+87IA:VAS=&%N)UU;)S4P+C(X,SHU-RXQ
M-3`G72`]("=!:W1J=6)I;G-K)SL*)&-O;W)D:6YA=&5S6R=+87IA:VAS=&%N
M)UU;)S4Q+C(U,#HU,2XR.#,G72`]("=5<F%L<VLG.PHD8V]O<F1I;F%T97-;
M)TMA>F%K<W1A;B==6R<T.2XX,#`Z-S,N,34P)UT@/2`G2V%R86=A;F1A)SL*
M)&-O;W)D:6YA=&5S6R=+96YY82==6R<P+C`X,SHS-RXV-3`G72`]("=-97)U
M)SL*)&-O;W)D:6YA=&5S6R=+96YY82==6R<M,"XQ,#`Z,S0N-S4P)UT@/2`G
M2VES=6UU)SL*)&-O;W)D:6YA=&5S6R=+96YY82==6R<M,"XR-C<Z,S8N,3`P
M)UT@/2`G3F%K=7)U)SL*)&-O;W)D:6YA=&5S6R=+96YY82==6R<P+C(X,SHS
M-"XW.#,G72`]("=+86MA;65G82<["B1C;V]R9&EN871E<ULG2V5N>6$G75LG
M+3`N,S8W.C,U+C,U,"==(#T@)TME<FEC:&\G.PHD8V]O<F1I;F%T97-;)TME
M;GEA)UU;)RTP+C0V-SHS.2XV,S,G72`]("='87)I<W-A)SL*)&-O;W)D:6YA
M=&5S6R=+96YY82==6R<M,"XU,#`Z,S8N.38W)UT@/2`G3GEE<FDG.PHD8V]O
M<F1I;F%T97-;)TME;GEA)UU;)RTP+C4P,#HS-RXT-3`G72`]("=%;6)U)SL*
M)&-O;W)D:6YA=&5S6R=+96YY82==6R<P+C4S,SHS-2XR.#,G72`]("=%;&1O
M<F5T)SL*)&-O;W)D:6YA=&5S6R=+96YY82==6R<M,"XV-C<Z,S0N-S@S)UT@
M/2`G2VES:6DG.PHD8V]O<F1I;F%T97-;)TME;GEA)UU;)S$N,#$W.C,U+C`P
M,"==(#T@)TMI=&%L92<["B1C;V]R9&EN871E<ULG2V5N>6$G75LG+3$N,3,S
M.C,U+C@S,R==(#T@)TYA<F]K)SL*)&-O;W)D:6YA=&5S6R=+96YY82==6R<M
M,2XS,#`Z,S8N-S4P)UT@/2`G3F%I<F]B:2`O($1A9V]R971T:2<["B1C;V]R
M9&EN871E<ULG2V5N>6$G75LG+3$N,S$W.C,V+C@Q-R==(#T@)TYA:7)O8FD@
M+R!7:6QS;VXG.PHD8V]O<F1I;F%T97-;)TME;GEA)UU;)RTQ+C,Q-SHS-BXY
M,S,G72`]("=.86ER;V)I($%#0R]&24,O4D-#+TU%5"]#3TTO)SL*)&-O;W)D
M:6YA=&5S6R=+96YY82==6R<Q+C<U,#HT,"XP-C<G72`]("=786II<B<["B1C
M;V]R9&EN871E<ULG2V5N>6$G75LG+3(N,C8W.C0P+C@S,R==(#T@)TQA;74G
M.PHD8V]O<F1I;F%T97-;)TME;GEA)UU;)RTR+C(X,SHS-RXX,S,G72`]("=-
M86MI;F1U)SL*)&-O;W)D:6YA=&5S6R=+96YY82==6R<R+C,P,#HS-RXY,#`G
M72`]("=-87)S86)I="<["B1C;V]R9&EN871E<ULG2V5N>6$G75LG,RXQ,3<Z
M,S4N-C$W)UT@/2`G3&]D=V%R)SL*)&-O;W)D:6YA=&5S6R=+96YY82==6R<M
M,RXR,S,Z-#`N,3`P)UT@/2`G36%L:6YD:2<["B1C;V]R9&EN871E<ULG2V5N
M>6$G75LG+3,N-#`P.C,X+C4V-R==(#T@)U9O:2<["B1C;V]R9&EN871E<ULG
M2V5N>6$G75LG,RXU,S,Z,SDN,#4P)UT@/2`G36]Y86QE)SL*)&-O;W)D:6YA
M=&5S6R=+96YY82==6R<S+CDS,SHT,2XX-C<G72`]("=-86YD97)A)SL*)&-O
M;W)D:6YA=&5S6R=+96YY82==6R<M-"XP,S,Z,SDN-C$W)UT@/2`G36]M8F%S
M82<["B1C;V]R9&EN871E<ULG2VER:6)A=&DG75LG,2XS-3`Z,3<R+CDQ-R==
M(#T@)U1A<F%W82<["B1C;V]R9&EN871E<ULG2VER:6)A=&DG75LG+3$N,S4P
M.C$W-BXP,#`G72`]("="97)U)SL*)&-O;W)D:6YA=&5S6R=+:7)I8F%T:2==
M6R<M,BXV-C<Z,3<V+C@S,R==(#T@)T%R;W)A92<["B1C;V]R9&EN871E<ULG
M2VER:6)A=&DG75LG,RXP,S,Z,3<R+C<X,R==(#T@)T)U=&%R:71A<FDG.PHD
M8V]O<F1I;F%T97-;)TMO<F5A+"!$96UO8W)A=&EC(%!E;W!L95PG<R!297!U
M8FQI8R!O9B==6R<S.2XP,S,Z,3(U+C<X,R==(#T@)U!Y;VYG>6%N9R<["B1C
M;V]R9&EN871E<ULG2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE7"=S(%)E<'5B
M;&EC(&]F)UU;)S0P+C8V-SHQ,CDN,C`P)UT@/2`G2VEM8VAA96LG.PHD8V]O
M<F1I;F%T97-;)TMO<F5A+"!297!U8FQI8R!O9B==6R<S,RXR,#`Z,3(V+C(V
M-R==(#T@)TUO<W5L<&\@06(G.PHD8V]O<F1I;F%T97-;)TMO<F5A+"!297!U
M8FQI8R!O9B==6R<S,RXU,#`Z,3(V+C4P,"==(#T@)T-H96IU($EN=&5R;F%T
M:6]N86P@06ER<&]R="<["B1C;V]R9&EN871E<ULG2V]R96$L(%)E<'5B;&EC
M(&]F)UU;)S,T+C@S,SHQ,C<N-C$W)UT@/2`G66]S=2!!:7)P;W)T)SL*)&-O
M;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S4N,#@S.C$R."XP
M.#,G72`]("=386-H7"=/;B!!8B<["B1C;V]R9&EN871E<ULG2V]R96$L(%)E
M<'5B;&EC(&]F)UU;)S,U+C$Q-SHQ,C8N.#$W)UT@/2`G2W=A;F=J=2!!8B<[
M"B1C;V]R9&EN871E<ULG2V]R96$L(%)E<'5B;&EC(&]F)UU;)S,U+C$X,SHQ
M,C@N.3,S)UT@/2`G4'5S86X@+R!+:6UH864@26YT97)N871I;VYA;"!!:7)P
M;W)T)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S4N
M-34P.C$R.2XS,3<G72`]("=5;'-A;B<["B1C;V]R9&EN871E<ULG2V]R96$L
M(%)E<'5B;&EC(&]F)UU;)S,U+C@X,SHQ,C@N-C$W)UT@/2`G5&%E9W4G.PHD
M8V]O<F1I;F%T97-;)TMO<F5A+"!297!U8FQI8R!O9B==6R<S-2XY,#`Z,3(X
M+C8U,"==(#T@)U1A96=U($%B)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P
M=6)L:6,@;V8G75LG,S4N.3$W.C$R-BXV,3<G72`]("=+=6YS86X@06(G.PHD
M8V]O<F1I;F%T97-;)TMO<F5A+"!297!U8FQI8R!O9B==6R<S-2XY.#,Z,3(Y
M+C0Q-R==(#T@)U!O:&%N9R!!8B<["B1C;V]R9&EN871E<ULG2V]R96$L(%)E
M<'5B;&EC(&]F)UU;)S,V+C,P,#HQ,C<N-#`P)UT@/2`G5&%E:F]N)SL*)&-O
M;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S8N,S,S.C$R-RXS
M.#,G72`]("=4865J;VX@2V]R+4%F8B<["B1C;V]R9&EN871E<ULG2V]R96$L
M(%)E<'5B;&EC(&]F)UU;)S,V+C0P,#HQ,C<N-3`P)UT@/2`G4V]N9VUU($%B
M)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S8N-34P
M.C$R."XW,3<G72`]("=!;F1O;F<G.PHD8V]O<F1I;F%T97-;)TMO<F5A+"!2
M97!U8FQI8R!O9B==6R<S-BXV,S,Z,3(X+C,U,"==(#T@)UEE8VAO;B!!8B<[
M"B1C;V]R9&EN871E<ULG2V]R96$L(%)E<'5B;&EC(&]F)UU;)S,V+C<P,#HQ
M,C<N-3`P)UT@/2`G0VAO;F=J=2!!8B<["B1C;V]R9&EN871E<ULG2V]R96$L
M(%)E<'5B;&EC(&]F)UU;)S,V+CDS,SHQ,C8N-#4P)UT@/2`G36%N9VEL<V%N
M($%B)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S8N
M.3,S.C$R-RXP,#`G72`]("=0>6]N9W1A96L@06(G.PHD8V]O<F1I;F%T97-;
M)TMO<F5A+"!297!U8FQI8R!O9B==6R<S-RXP,S,Z,3(V+C<U,"==(#T@)TMO
M;VXM3FD@4F%N9V4G.PHD8V]O<F1I;F%T97-;)TMO<F5A+"!297!U8FQI8R!O
M9B==6R<S-RXP,S,Z,3(W+C@X,R==(#T@)TIU;F<@5V]N(%)O:RU!8B<["B1C
M;V]R9&EN871E<ULG2V]R96$L(%)E<'5B;&EC(&]F)UU;)S,W+C$P,#HQ,C<N
M,#,S)UT@/2`G3W-A;B!!8B<["B1C;V]R9&EN871E<ULG2V]R96$L(%)E<'5B
M;&EC(&]F)UU;)S,W+C(U,#HQ,C<N,#`P)UT@/2`G4W5W;VX@06(G.PHD8V]O
M<F1I;F%T97-;)TMO<F5A+"!297!U8FQI8R!O9B==6R<S-RXS,S,Z,3(W+CDU
M,"==(#T@)U=O;FIU)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@
M;V8G75LG,S<N-#,S.C$R-RXQ,3<G72`]("=396]U;"!%($%B)SL*)&-O;W)D
M:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S<N-#,S.C$R-RXY-3`G
M72`]("=(;V5N9W-O;F<@06(G.PHD8V]O<F1I;F%T97-;)TMO<F5A+"!297!U
M8FQI8R!O9B==6R<S-RXT-C<Z,3(V+C0U,"==(#T@)TEN8VAE;VX@26YT97)N
M871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L
M:6,@;V8G75LG,S<N-3`P.C$R-BXY,S,G72`]("=396]U;"`O(%EO;F=D=6YG
M<%PG3R!2;VMA9B!78R<["B1C;V]R9&EN871E<ULG2V]R96$L(%)E<'5B;&EC
M(&]F)UU;)S,W+C4P,#HQ,CDN,3,S)UT@/2`G5&]N9VAA92!2861A<B!3:71E
M)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S<N-34P
M.C$R-BXX,#`G72`]("=396]U;"`O($MI;7!<)T\@26YT97)N871I;VYA;"!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG
M,S<N-38W.C$R-BXY-C<G72`]("=396]U;"<["B1C;V]R9&EN871E<ULG2V]R
M96$L(%)E<'5B;&EC(&]F)UU;)S,W+C<U,#HQ,C@N.34P)UT@/2`G2V%N9VYU
M;F<@06(G.PHD8V]O<F1I;F%T97-;)TMO<F5A+"!297!U8FQI8R!O9B==6R<S
M-RXX-C<Z,3(W+C<Q-R==(#T@)T-H=6YC:&]N($%B)SL*)&-O;W)D:6YA=&5S
M6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S<N.38W.C$R-"XV-C<G72`]("=0
M865N9VYY;VYG9&\@06(G.PHD8V]O<F1I;F%T97-;)TMU=V%I="==6R<R.2XR
M,3<Z-#<N.3@S)UT@/2`G2W5W86ET($EN=&5R;F%T:6]N86QA:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R=,86\@4&5O<&QE7"=S($1E;6]C<F%T:6,@4F5P=6)L
M:6,G75LG,30N.#`P.C$P-BXX,S,G72`]("=!='1O<&5U)SL*)&-O;W)D:6YA
M=&5S6R=,86\@4&5O<&QE7"=S($1E;6]C<F%T:6,@4F5P=6)L:6,G75LG,34N
M,3$W.C$P-2XQ-C<G72`]("=086MS92<["B1C;V]R9&EN871E<ULG3&%O(%!E
M;W!L95PG<R!$96UO8W)A=&EC(%)E<'5B;&EC)UU;)S$U+C8X,SHQ,#8N-#,S
M)UT@/2`G4V%R879A;F4G.PHD8V]O<F1I;F%T97-;)TQA;R!096]P;&5<)W,@
M1&5M;V-R871I8R!297!U8FQI8R==6R<Q-BXU-3`Z,3`T+C8U,"==(#T@)U-A
M=F%N;F%K:&5T)SL*)&-O;W)D:6YA=&5S6R=,86\@4&5O<&QE7"=S($1E;6]C
M<F%T:6,@4F5P=6)L:6,G75LG,3<N,S@S.C$P-"XV-3`G72`]("=4:&%K:&5K
M)SL*)&-O;W)D:6YA=&5S6R=,86\@4&5O<&QE7"=S($1E;6]C<F%T:6,@4F5P
M=6)L:6,G75LG,3<N.34P.C$P,BXU-C<G72`]("=6:65N=&EA;F4G.PHD8V]O
M<F1I;F%T97-;)TQA;R!096]P;&5<)W,@1&5M;V-R871I8R!297!U8FQI8R==
M6R<Q.2XR,S,Z,3`Q+C<S,R==(#T@)U-A>6%B;W5R>2<["B1C;V]R9&EN871E
M<ULG3&%O(%!E;W!L95PG<R!$96UO8W)A=&EC(%)E<'5B;&EC)UU;)S$Y+C@X
M,SHQ,#(N,3,S)UT@/2`G3'5A;F<M4')A8F%N9R<["B1C;V]R9&EN871E<ULG
M3&%T=FEA)UU;)S4V+CDV-SHR-"XP-3`G72`]("=2:6=A)SL*)&-O;W)D:6YA
M=&5S6R=,871V:6$G75LG-3<N-#`P.C(Q+C4S,R==(#T@)U9E;G1S<&EL<R<[
M"B1C;V]R9&EN871E<ULG3&5B86YO;B==6R<S,RXX,3<Z,S4N-#@S)UT@/2`G
M0F5Y<F]U=&@@065R;W!O<G0G.PHD8V]O<F1I;F%T97-;)TQE<V]T:&\G75LG
M+3(Y+C0U,#HR-RXU-3`G72`]("=-87-E<G4M36EA)SL*)&-O;W)D:6YA=&5S
M6R=,:6)E<FEA)UU;)S8N,C4P.BTQ,"XS-3`G72`]("='<F%N9"!"87-S82P@
M4F]B97)T<R!&:65L9"<["B1C;V]R9&EN871E<ULG3&EB>6%N($%R86(@2F%M
M86AI<FEY82==6R<R-"XR,3<Z,C,N,S`P)UT@/2`G2W5F<F$G.PHD8V]O<F1I
M;F%T97-;)TQI8GEA;B!!<F%B($IA;6%H:7)I>6$G75LG,C4N,3,S.C$P+C$U
M,"==(#T@)T=H870G.PHD8V]O<F1I;F%T97-;)TQI8GEA;B!!<F%B($IA;6%H
M:7)I>6$G75LG,C<N,#$W.C$T+C0U,"==(#T@)U-E8FAA)SL*)&-O;W)D:6YA
M=&5S6R=,:6)Y86X@07)A8B!*86UA:&ER:7EA)UU;)S,P+C$S,SHY+C4P,"==
M(#T@)T=H861A;65S)SL*)&-O;W)D:6YA=&5S6R=,:6)Y86X@07)A8B!*86UA
M:&ER:7EA)UU;)S,R+C$P,#HR,"XR-C<G72`]("="96YI;F$G.PHD8V]O<F1I
M;F%T97-;)TQI8GEA;B!!<F%B($IA;6%H:7)I>6$G75LG,S(N-C8W.C$S+C$U
M,"==(#T@)U1R:7!O;&D@26YT97(M3F%T:6]N86P@06ER<&]R="<["B1C;V]R
M9&EN871E<ULG3&ET:'5A;FEA)UU;)S4T+C8S,SHR-2XQ,#`G72`]("=6:6QN
M:75S)SL*)&-O;W)D:6YA=&5S6R=,=7AE;6)O=7)G)UU;)S0Y+C8Q-SHV+C(Q
M-R==(#T@)TQU>&5M8F]U<F<@+R!,=7AE;6)O=7)G)SL*)&-O;W)D:6YA=&5S
M6R=-86-A=2==6R<R,BXQ-C<Z,3$S+C4V-R==(#T@)U1A:7!A)SL*)&-O;W)D
M:6YA=&5S6R=-86-E9&]N:6$L('1H92!&;W)M97(@675G;W-L878@4F5P=6)L
M:6,@;V8G75LG-#$N,3$W.C(P+C@P,"==(#T@)T]H<FED)SL*)&-O;W)D:6YA
M=&5S6R=-86-E9&]N:6$L('1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@
M;V8G75LG-#$N.38W.C(Q+C8U,"==(#T@)U-K;W!J92U0971R;W9E8R<["B1C
M;V]R9&EN871E<ULG36%D86=A<V-A<B==6R<M,3(N,S4P.C0Y+C,P,"==(#T@
M)T1I96=O+5-U87)E>B<["B1C;V]R9&EN871E<ULG36%D86=A<V-A<B==6R<M
M,3,N,S$W.C0X+C,Q-R==(#T@)T9A<V-E;F4@3F]S<VDM0F4G.PHD8V]O<F1I
M;F%T97-;)TUA9&%G87-C87(G75LG+3$S+C,V-SHU,"XP,#`G72`]("=6;VAE
M;6%R)SL*)&-O;W)D:6YA=&5S6R=-861A9V%S8V%R)UU;)RTQ-"XR.#,Z-3`N
M,38W)UT@/2`G4V%M8F%V82<["B1C;V]R9&EN871E<ULG36%D86=A<V-A<B==
M6R<M,30N-C,S.C0W+C<V-R==(#T@)T%N86QA;&%V82<["B1C;V]R9&EN871E
M<ULG36%D86=A<V-A<B==6R<M,30N-C4P.C0Y+C8Q-R==(#T@)T%N9&%P82<[
M"B1C;V]R9&EN871E<ULG36%D86=A<V-A<B==6R<M,30N.#@S.C4P+C(U,"==
M(#T@)T%N=&%L86AA)SL*)&-O;W)D:6YA=&5S6R=-861A9V%S8V%R)UU;)RTQ
M-2XV-C<Z-#8N,S4P)UT@/2`G36%J=6YG82<["B1C;V]R9&EN871E<ULG36%D
M86=A<V-A<B==6R<M,38N-S4P.C0T+C0X,R==(#T@)T)E<V%L86UP>2<["B1C
M;V]R9&EN871E<ULG36%D86=A<V-A<B==6R<M,3<N,#@S.C0Y+C@Q-R==(#T@
M)U-A:6YT92U-87)I92!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)TUA9&%G
M87-C87(G75LG+3$X+C`U,#HT-"XP,S,G72`]("=-86EN=&ER86YO)SL*)&-O
M;W)D:6YA=&5S6R=-861A9V%S8V%R)UU;)RTQ."XQ,3<Z-#DN-#`P)UT@/2`G
M5&%M871A=F4G.PHD8V]O<F1I;F%T97-;)TUA9&%G87-C87(G75LG+3$X+C@P
M,#HT-RXT.#,G72`]("=!;G1A;F%N87)I=F\@+R!)=F%T;R<["B1C;V]R9&EN
M871E<ULG36%D86=A<V-A<B==6R<M,3DN.#$W.C0W+C`V-R==(#T@)T%N='-I
M<F%B92<["B1C;V]R9&EN871E<ULG36%D86=A<V-A<B==6R<M,3DN.#,S.C0X
M+C@P,"==(#T@)TUA:&%N;W)O)SL*)&-O;W)D:6YA=&5S6R=-861A9V%S8V%R
M)UU;)RTR,"XR.#,Z-#0N,S$W)UT@/2`G36]R;VYD879A)SL*)&-O;W)D:6YA
M=&5S6R=-861A9V%S8V%R)UU;)RTR,2XR,#`Z-#@N,S8W)UT@/2`G36%N86YJ
M87)Y)SL*)&-O;W)D:6YA=&5S6R=-861A9V%S8V%R)UU;)RTR,2XT-3`Z-#<N
M,3`P)UT@/2`G1FEA;F%R86YT<V]A)SL*)&-O;W)D:6YA=&5S6R=-861A9V%S
M8V%R)UU;)RTR,2XW-3`Z-#,N,S8W)UT@/2`G36]R;VUB92<["B1C;V]R9&EN
M871E<ULG36%D86=A<V-A<B==6R<M,C(N-34P.C0U+C0P,"==(#T@)U)A;F]H
M:7)A)SL*)&-O;W)D:6YA=&5S6R=-861A9V%S8V%R)UU;)RTR,BXX,#`Z-#<N
M.#,S)UT@/2`G1F%R869A;F=A;F$G.PHD8V]O<F1I;F%T97-;)TUA9&%G87-C
M87(G75LG+3(S+C,X,SHT,RXW,S,G72`]("=4=6QE87(G.PHD8V]O<F1I;F%T
M97-;)TUA9&%G87-C87(G75LG+3(U+C`S,SHT-BXY-3`G72`]("=&;W)T+41A
M=7!H:6XG.PHD8V]O<F1I;F%T97-;)TUA;&%W:2==6R<M,3$N-#4P.C,T+C`Q
M-R==(#T@)TUZ=7IU)SL*)&-O;W)D:6YA=&5S6R=-86QA=VDG75LG+3$Q+C@X
M,SHS,RXV,3<G72`]("=->FEM8F$G.PHD8V]O<F1I;F%T97-;)TUA;&%W:2==
M6R<M,3(N.3$W.C,T+C(V-R==(#T@)TYK:&]T82!+;W1A)SL*)&-O;W)D:6YA
M=&5S6R=-86QA=VDG75LG+3$S+C<U,#HS-"XU.#,G72`]("=386QI;6$G.PHD
M8V]O<F1I;F%T97-;)TUA;&%W:2==6R<M,3,N-S@S.C,S+C<V-R==(#T@)TQI
M;&]N9W=E($EN=&5R;F%T:6]N86P@06ER<&]R="<["B1C;V]R9&EN871E<ULG
M36%L87=I)UU;)RTQ-"XP.#,Z,S0N.3$W)UT@/2`G36]N:V5Y($)A>2<["B1C
M;V]R9&EN871E<ULG36%L87=I)UU;)RTQ-"XS,3<Z,S0N,C8W)UT@/2`G1&5D
M>F$G.PHD8V]O<F1I;F%T97-;)TUA;&%W:2==6R<M,30N-#,S.C,U+C(U,"==
M(#T@)TUA;F=O8VAI)SL*)&-O;W)D:6YA=&5S6R=-86QA=VDG75LG+3$U+C8X
M,SHS-"XY-C<G72`]("=#:&EL96MA)SL*)&-O;W)D:6YA=&5S6R=-86QA=VDG
M75LG+3DN-S`P.C,S+C(V-R==(#T@)T-H:71I<&$G.PHD8V]O<F1I;F%T97-;
M)TUA;&%W:2==6R<M.2XY-3`Z,S,N.#@S)UT@/2`G2V%R;VYG82<["B1C;V]R
M9&EN871E<ULG36%L87ES:6$G75LG,2XT.#,Z,3$P+C,S,R==(#T@)TMU8VAI
M;F<G.PHD8V]O<F1I;F%T97-;)TUA;&%Y<VEA)UU;)S$N-C,S.C$P,RXV-C<G
M72`]("=*;VAO<F4@0FAA<G4@+R!396YA:2<["B1C;V]R9&EN871E<ULG36%L
M87ES:6$G75LG,BXR-C<Z,3`R+C(U,"==(#T@)TUA;&%C8V$G.PHD8V]O<F1I
M;F%T97-;)TUA;&%Y<VEA)UU;)S(N,S,S.C$Q,2XX,S,G72`]("=3:6)U)SL*
M)&-O;W)D:6YA=&5S6R=-86QA>7-I82==6R<S+C$Q-SHQ,#$N-34P)UT@/2`G
M2W5A;&$@3'5M<'5R("\@4W5B86YG)SL*)&-O;W)D:6YA=&5S6R=-86QA>7-I
M82==6R<S+C(P,#HQ,3,N,#,S)UT@/2`G0FEN='5L=2<["B1C;V]R9&EN871E
M<ULG36%L87ES:6$G75LG,RXV,3<Z,3`S+C(Q-R==(#T@)TMU86YT86XG.PHD
M8V]O<F1I;F%T97-;)TUA;&%Y<VEA)UU;)S0N,C$W.C$P,"XW,#`G72`]("=3
M:71I87=A;B<["B1C;V]R9&EN871E<ULG36%L87ES:6$G75LG-"XR-C<Z,3$W
M+C@X,R==(#T@)U1A=V%U)SL*)&-O;W)D:6YA=&5S6R=-86QA>7-I82==6R<T
M+C,S,SHQ,3,N.3@S)UT@/2`G36ER:2<["B1C;V]R9&EN871E<ULG36%L87ES
M:6$G75LG-2XS,#`Z,3`P+C(V-R==(#T@)U!E;F%N9R`O($)A>6%N($QE<&%S
M)SL*)&-O;W)D:6YA=&5S6R=-86QA>7-I82==6R<U+C,P,#HQ,34N,C4P)UT@
M/2`G3&%B=6%N)SL*)&-O;W)D:6YA=&5S6R=-86QA>7-I82==6R<U+CDP,#HQ
M,3@N,#8W)UT@/2`G4V%N9&%K86XG.PHD8V]O<F1I;F%T97-;)TUA;&%Y<VEA
M)UU;)S4N.3,S.C$Q-BXP-3`G72`]("=+;W1A($MI;F%B86QU)SL*)&-O;W)D
M:6YA=&5S6R=-86QA>7-I82==6R<V+C$V-SHQ,#(N,C@S)UT@/2`G2V]T82!"
M:&%R=2<["B1C;V]R9&EN871E<ULG36%L87ES:6$G75LG-BXS,S,Z.3DN-S,S
M)UT@/2`G3&%N9VMA=VDG.PHD8V]O<F1I;F%T97-;)TUA;&%Y<VEA)UU;)S8N
M.3$W.C$Q-BXX,S,G72`]("=+=61A="<["B1C;V]R9&EN871E<ULG36%L9&EV
M97,G75LG+3`N-C@S.C<S+C$U,"==(#T@)T=A;B<["B1C;V]R9&EN871E<ULG
M36%L9&EV97,G75LG-"XR,#`Z-S,N-3,S)UT@/2`G36%L92<["B1C;V]R9&EN
M871E<ULG36%L:2==6R<Q,2XS-3`Z+34N-C@S)UT@/2`G4VEK87-S;R<["B1C
M;V]R9&EN871E<ULG36%L:2==6R<Q,2XT,3<Z+3<N-3`P)UT@/2`G0F]U9V]U
M;FDG.PHD8V]O<F1I;F%T97-;)TUA;&DG75LG,3(N,S@S.BTU+C0V-R==(#T@
M)TMO=71I86QA)SL*)&-O;W)D:6YA=&5S6R=-86QI)UU;)S$R+C4S,SHM-RXY
M-3`G72`]("="86UA:V\@+R!396YO=2<["B1C;V]R9&EN871E<ULG36%L:2==
M6R<Q,BXX-3`Z+3$Q+C(S,R==(#T@)TME;FEE8F$G.PHD8V]O<F1I;F%T97-;
M)TUA;&DG75LG,3,N,#8W.BTY+C0V-R==(#T@)TMI=&$G.PHD8V]O<F1I;F%T
M97-;)TUA;&DG75LG,3,N,S,S.BTT+C@S,R==(#T@)U-A;B<["B1C;V]R9&EN
M871E<ULG36%L:2==6R<Q,RXT,#`Z+38N,34P)UT@/2`G4V5G;W4G.PHD8V]O
M<F1I;F%T97-;)TUA;&DG75LG,30N-#,S.BTQ,2XT,S,G72`]("=+87EE<R<[
M"B1C;V]R9&EN871E<ULG36%L:2==6R<Q-"XU,3<Z+30N,3`P)UT@/2`G36]P
M=&DG.PHD8V]O<F1I;F%T97-;)TUA;&DG75LG,34N,38W.BTW+C(X,R==(#T@
M)TYA<F$G.PHD8V]O<F1I;F%T97-;)TUA;&DG75LG,34N,C,S.BTY+C,U,"==
M(#T@)TYI;W)O($1U(%-A:&5L)SL*)&-O;W)D:6YA=&5S6R=-86QI)UU;)S$U
M+C,S,SHM,2XV.#,G72`]("=(;VUB;W)I)SL*)&-O;W)D:6YA=&5S6R=-86QI
M)UU;)S$U+C@V-SHR+C(Q-R==(#T@)TUE;F%K82<["B1C;V]R9&EN871E<ULG
M36%L:2==6R<Q-BXR-C<Z+3`N,#4P)UT@/2`G1V%O)SL*)&-O;W)D:6YA=&5S
M6R=-86QI)UU;)S$V+C<Q-SHM,RXP,#`G72`]("=4;VUB;W5C=&]U)SL*)&-O
M;W)D:6YA=&5S6R=-86QI)UU;)S$X+C0S,SHQ+C,U,"==(#T@)TMI9&%L)SL*
M)&-O;W)D:6YA=&5S6R=-86QI)UU;)S(P+C(P,#HP+CDX,R==(#T@)U1E<W-A
M;&ET)SL*)&-O;W)D:6YA=&5S6R=-86QT82==6R<S-2XX-3`Z,30N-#@S)UT@
M/2`G3'5Q82<["B1C;V]R9&EN871E<ULG36%R<VAA;&P@27-L86YD<R==6R<W
M+C`V-SHQ-S$N,C@S)UT@/2`G36%J=7)O($%T;VQL+"!-87)S:&%L;"!)<VQA
M;F1S($EN="X@06ER<"XG.PHD8V]O<F1I;F%T97-;)TUA<G-H86QL($ES;&%N
M9',G75LG."XW,3<Z,38W+C<S,R==(#T@)TMW86IA;&5I;BP@0G5C:&]L>B!!
M048H2W=A:F%L96EN($M-4BDH051/3"D@06ER<"XG.PHD8V]O<F1I;F%T97-;
M)TUA<G1I;FEQ=64G75LG,30N-C`P.BTV,2XP,#`G72`]("=,92!,86UE;G1I
M;B<["B1C;V]R9&EN871E<ULG36%U<FET86YI82==6R<Q-BXQ-3`Z+3$S+C4Q
M-R==(#T@)TMA961I)SL*)&-O;W)D:6YA=&5S6R=-875R:71A;FEA)UU;)S$V
M+C4P,#HM,34N.#$W)UT@/2`G4F]S<V\G.PHD8V]O<F1I;F%T97-;)TUA=7)I
M=&%N:6$G75LG,38N-C`P.BTW+C(V-R==(#T@)TYE;6$G.PHD8V]O<F1I;F%T
M97-;)TUA=7)I=&%N:6$G75LG,38N-C,S.BTQ,2XT,#`G72`]("=+:69F82<[
M"B1C;V]R9&EN871E<ULG36%U<FET86YI82==6R<Q-BXW,#`Z+3DN-C`P)UT@
M/2`G06EO=6X@16P@071R;W5S<R<["B1C;V]R9&EN871E<ULG36%U<FET86YI
M82==6R<Q-RXU,S,Z+3$T+C8X,R==(#T@)T)O=71I;&EM:70G.PHD8V]O<F1I
M;F%T97-;)TUA=7)I=&%N:6$G75LG,3@N,3`P.BTQ-2XY-3`G72`]("=.;W5A
M:V-H;W1T)SL*)&-O;W)D:6YA=&5S6R=-875R:71A;FEA)UU;)S$X+C4V-SHM
M,3$N-#,S)UT@/2`G5&ED:FEK:F$G.PHD8V]O<F1I;F%T97-;)TUA=7)I=&%N
M:6$G75LG,3DN-S4P.BTQ-"XS-C<G72`]("=!:VIO=6IT)SL*)&-O;W)D:6YA
M=&5S6R=-875R:71A;FEA)UU;)S(P+C4Q-SHM,3,N,#8W)UT@/2`G071A<B<[
M"B1C;V]R9&EN871E<ULG36%U<FET86YI82==6R<R,"XY,S,Z+3$W+C`S,R==
M(#T@)TYO=6%D:&EB;W4G.PHD8V]O<F1I;F%T97-;)TUA=7)I=&%N:6$G75LG
M,C4N,C,S.BTQ,2XV,3<G72`]("=":7(@36]G:')E:6XG.PHD8V]O<F1I;F%T
M97-;)TUA=7)I=&EU<R==6R<M,3DN-C@S.C8S+C0Q-R==(#T@)U)O9')I9W5E
M<R<["B1C;V]R9&EN871E<ULG36%U<FET:75S)UU;)RTR,"XT,S,Z-3<N-C8W
M)UT@/2`G4&QA:7-A;F-E($UA=7)I=&EU<R<["B1C;V]R9&EN871E<ULG365X
M:6-O)UU;)S$V+C<U,#HM.3,N,3$W)UT@/2`G5'5X=&QA($=U=&EE<G)E>BP@
M0VAI<RXG.PHD8V]O<F1I;F%T97-;)TUE>&EC;R==6R<Q."XT.#,Z+3@X+C,P
M,"==(#T@)T-H971U;6%L+"!1+B!2;V\G.PHD8V]O<F1I;F%T97-;)TUE>&EC
M;R==6R<Q."XX.#,Z+3DY+C(S,R==(#T@)T-U97)N879A8V$L($UO<BXG.PHD
M8V]O<F1I;F%T97-;)TUE>&EC;R==6R<Q.2XP-3`Z+3DX+C$V-R==(#T@)U!U
M96)L82P@4'5E+B<["B1C;V]R9&EN871E<ULG365X:6-O)UU;)S$Y+C(V-SHM
M,3`S+C4X,R==(#T@)T-O;&EM82<["B1C;V]R9&EN871E<ULG365X:6-O)UU;
M)S$Y+C@U,#HM.3`N-34P)UT@/2`G0V%M<&5C:&4L($-A;7`N)SL*)&-O;W)D
M:6YA=&5S6R=-97AI8V\G75LG,C`N,#@S.BTY."XS-C<G72`]("=4=6QA;F-I
M;F=O)SL*)&-O;W)D:6YA=&5S6R=-97AI8V\G75LG,C`N-C`P.BTQ,#`N,S@S
M)UT@/2`G475E<F5T87)O+"!1<F\N)SL*)&-O;W)D:6YA=&5S6R=-97AI8V\G
M75LG,C`N.3,S.BTX.2XV-3`G72`]("=-97)I9&$@+R!L:6,@36%N=65L($-R
M96-E;F-I;R<["B1C;V]R9&EN871E<ULG365X:6-O)UU;)S(Q+C4Q-SHM,3`T
M+CDP,"==(#T@)U1E<&EC+"!.87DN)SL*)&-O;W)D:6YA=&5S6R=-97AI8V\G
M75LG,C$N.#@S.BTQ,#(N,S`P)UT@/2`G06=U87-C86QI96YT97,L($%G<RXG
M.PHD8V]O<F1I;F%T97-;)TUE>&EC;R==6R<R,BXQ-3`Z+3$P,"XY.#,G72`]
M("=386X@3'5I<R!0;W1O<VDL(%,N($PN(%`N)SL*)&-O;W)D:6YA=&5S6R=-
M97AI8V\G75LG,C0N.#$W.BTQ,#<N-#`P)UT@/2`G0W5L:6%C86XL(%-I;BXG
M.PHD8V]O<F1I;F%T97-;)TUE>&EC;R==6R<R-2XT-3`Z+3$P,"XY.#,G72`]
M("=386QT:6QL;RP@0V]A:"XG.PHD8V]O<F1I;F%T97-;)TUE>&EC;R==6R<R
M-2XU,S,Z+3$P,RXT-3`G72`]("=4;W)R96]N+"!#;V%H+B<["B1C;V]R9&EN
M871E<ULG365X:6-O)UU;)S(U+C@V-SHM,3`P+C(S,R==(#T@)T%E<F]P+B!)
M;G1E<FYA8VEO;F%L($UO;G1E<G)E>2P@3BX@3"XG.PHD8V]O<F1I;F%T97-;
M)TUE>&EC;R==6R<R-BXP,3<Z+3$Q,2XS-3`G72`]("=,;W)E=&\L($(N($,N
M(%,N)SL*)&-O;W)D:6YA=&5S6R=-97AI8V\G75LG,C8N.#@S.BTQ,#$N-#$W
M)UT@/2`G36]N8VQO=F$L($-O86@N)SL*)&-O;W)D:6YA=&5S6R=-97AI8V\G
M75LG,C<N,S$W.BTQ,3(N,S`P)UT@/2`G4V%N=&$@4F]S86QI82P@0BX@0RX@
M4RXG.PHD8V]O<F1I;F%T97-;)TUE>&EC;R==6R<R."XW,#`Z+3$P,"XU,3<G
M72`]("=0:65D<F%S($YE9W)A<RP@0V]A:"XG.PHD8V]O<F1I;F%T97-;)TUE
M>&EC;R==6R<R.2XP-C<Z+3$Q,"XY-3`G72`]("=(97)M;W-I;&QO+"!3;VXN
M)SL*)&-O;W)D:6YA=&5S6R=-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S
M(&]F)UU;)S4N,S4P.C$V,BXY-3`G72`]("=+;W-R864@0V%R;VQI;F5S("\@
M5B<["B1C;V]R9&EN871E<ULG36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E
M<R!O9B==6R<U+C,U,#HQ-C(N.34P)UT@/2`G2V]S<F%E($ES;&%N9"P@2V]S
M<F%E($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TUI8W)O;F5S:6$L($9E9&5R
M871E9"!3=&%T97,@;V8G75LG-BXY.#,Z,34X+C(P,"==(#T@)U!O:&YP96D@
M27-L86YD+"!0;VAN<&5I($EN="X@06ER<"XG.PHD8V]O<F1I;F%T97-;)TUI
M8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8G75LG-RXT-C<Z,34Q+C@U
M,"==(#T@)U=E;F\@27-L86YD+"!#:'5U:R!);G0N($%I<G`N)SL*)&-O;W)D
M:6YA=&5S6R=-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F)UU;)SDN
M-#@S.C$S."XP.#,G72`]("=987`@27-L86YD+"!987`@26YT+B!!:7)P+B<[
M"B1C;V]R9&EN871E<ULG36]L9&]V82P@4F5P=6)L:6,@;V8G75LG-#<N,#$W
M.C(X+CDX,R==(#T@)TMI<VEN978G.PHD8V]O<F1I;F%T97-;)TUO<F]C8V\G
M75LG,C@N-#4P.BTQ,2XQ-3`G72`]("=486XM5&%N)SL*)&-O;W)D:6YA=&5S
M6R=-;W)O8V-O)UU;)S(Y+C,V-SHM,3`N,3@S)UT@/2`G4VED:2!)9FYI)SL*
M)&-O;W)D:6YA=&5S6R=-;W)O8V-O)UU;)S,P+C,S,SHM.2XT,#`G72`]("=!
M9V%D:7(@06P@36%S<VER82<["B1C;V]R9&EN871E<ULG36]R;V-C;R==6R<S
M,"XS.#,Z+3DN-38W)UT@/2`G06=A9&ER)SL*)&-O;W)D:6YA=&5S6R=-;W)O
M8V-O)UU;)S,P+CDS,SHM-BXY,#`G72`]("=/=6%R>F%Z871E)SL*)&-O;W)D
M:6YA=&5S6R=-;W)O8V-O)UU;)S,Q+C4Q-SHM.2XW.#,G72`]("=%<W-A;W5I
M<F$G.PHD8V]O<F1I;F%T97-;)TUO<F]C8V\G75LG,S$N-C$W.BTX+C`S,R==
M(#T@)TUA<G)A:V5C:"<["B1C;V]R9&EN871E<ULG36]R;V-C;R==6R<S,2XY
M,S,Z+30N-#`P)UT@/2`G17)R86-H:61I82<["B1C;V]R9&EN871E<ULG36]R
M;V-C;R==6R<S,BXR.#,Z+3DN,C,S)UT@/2`G4V%F:2<["B1C;V]R9&EN871E
M<ULG36]R;V-C;R==6R<S,RXS-C<Z+3<N-3@S)UT@/2`G3F]U87-S975R)SL*
M)&-O;W)D:6YA=&5S6R=-;W)O8V-O)UU;)S,S+C4P,#HM-2XQ-C<G72`]("=)
M9G)A;F4G.PHD8V]O<F1I;F%T97-;)TUO<F]C8V\G75LG,S,N-38W.BTW+C8V
M-R==(#T@)T-A<V%B;&%N8V$G.PHD8V]O<F1I;F%T97-;)TUO<F]C8V\G75LG
M,S,N.#@S.BTU+C4S,R==(#T@)TUE:VYE<R<["B1C;V]R9&EN871E<ULG36]R
M;V-C;R==6R<S,RXY,S,Z+30N.3@S)UT@/2`G1F5S+5-A:7,G.PHD8V]O<F1I
M;F%T97-;)TUO<F]C8V\G75LG,S0N,#4P.BTV+C<V-R==(#T@)U)A8F%T+5-A
M;&4G.PHD8V]O<F1I;F%T97-;)TUO<F]C8V\G75LG,S0N,C$W.BTT+C`P,"==
M(#T@)U1A>F$G.PHD8V]O<F1I;F%T97-;)TUO<F]C8V\G75LG,S0N,S`P.BTV
M+C8P,"==(#T@)TME;FET<F$G.PHD8V]O<F1I;F%T97-;)TUO<F]C8V\G75LG
M,S0N-S@S.BTQ+CDS,R==(#T@)T]U:F1A)SL*)&-O;W)D:6YA=&5S6R=-;W)O
M8V-O)UU;)S,U+C$U,#HM,BXY,3<G72`]("=.861O<B<["B1C;V]R9&EN871E
M<ULG36]R;V-C;R==6R<S-2XQ.#,Z+3,N.#4P)UT@/2`G06P@2&]C96EM82<[
M"B1C;V]R9&EN871E<ULG36]R;V-C;R==6R<S-2XU.#,Z+34N,S,S)UT@/2`G
M5&5T=6%N("\@4V%N:6$@4F%M96PG.PHD8V]O<F1I;F%T97-;)TUO<F]C8V\G
M75LG,S4N-S,S.BTU+CDP,"==(#T@)U1A;F=E<B!!97)O9')O;64G.PHD8V]O
M<F1I;F%T97-;)TUO>F%M8FEQ=64G75LG+3$Q+C,U,#HT,"XS-C<G72`]("=-
M;V-I;6)O82!$82!0<F%I82<["B1C;V]R9&EN871E<ULG36]Z86UB:7%U92==
M6R<M,3(N.3@S.C0P+C4S,R==(#T@)U!E;6)A)SL*)&-O;W)D:6YA=&5S6R=-
M;WIA;6)I<75E)UU;)RTQ,RXS,#`Z,S4N,C,S)UT@/2`G3&EC:&EN9V$G.PHD
M8V]O<F1I;F%T97-;)TUO>F%M8FEQ=64G75LG+3$T+C@Q-SHS-BXU,S,G72`]
M("=#=6%M8F$G.PHD8V]O<F1I;F%T97-;)TUO>F%M8FEQ=64G75LG+3$U+C`S
M,SHT,"XV-C<G72`]("=,=6UB;R<["B1C;V]R9&EN871E<ULG36]Z86UB:7%U
M92==6R<M,34N,3`P.C,Y+C(X,R==(#T@)TYA;7!U;&$G.PHD8V]O<F1I;F%T
M97-;)TUO>F%M8FEQ=64G75LG+3$V+C$X,SHS,RXU.#,G72`]("=4971E)SL*
M)&-O;W)D:6YA=&5S6R=-;WIA;6)I<75E)UU;)RTQ-RXX.#,Z,S8N.#@S)UT@
M/2`G475E;&EM86YE)SL*)&-O;W)D:6YA=&5S6R=-;WIA;6)I<75E)UU;)RTQ
M.2XQ,3<Z,S,N-#8W)UT@/2`G0VAI;6]I;R<["B1C;V]R9&EN871E<ULG36]Z
M86UB:7%U92==6R<M,3DN.#`P.C,T+CDP,"==(#T@)T)E:7)A)SL*)&-O;W)D
M:6YA=&5S6R=-;WIA;6)I<75E)UU;)RTR,BXP,#`Z,S4N,S$W)UT@/2`G5FEL
M86YC=6QO<R<["B1C;V]R9&EN871E<ULG36]Z86UB:7%U92==6R<M,C,N.#8W
M.C,U+C,X,R==(#T@)TEN:&%M8F%N92<["B1C;V]R9&EN871E<ULG36]Z86UB
M:7%U92==6R<M,C4N,#4P.C,S+C8S,R==(#T@)UAA:2!886DG.PHD8V]O<F1I
M;F%T97-;)TUO>F%M8FEQ=64G75LG+3(U+CDQ-SHS,BXU-C<G72`]("=-87!U
M=&\@+R!-879A;&%N92<["B1C;V]R9&EN871E<ULG37EA;FUA<B==6R<Q,BXT
M,S,Z.3@N-C`P)UT@/2`G365R9W5I)SL*)&-O;W)D:6YA=&5S6R=->6%N;6%R
M)UU;)S$T+C$P,#HY."XR,3<G72`]("=$87=E:2<["B1C;V]R9&EN871E<ULG
M37EA;FUA<B==6R<Q-"XQ,3<Z.3,N,S8W)UT@/2`G0V]C;R!)<VQA;F0G.PHD
M8V]O<F1I;F%T97-;)TUY86YM87(G75LG,38N-3`P.CDW+C8Q-R==(#T@)TUO
M=6QM96EN)SL*)&-O;W)D:6YA=&5S6R=->6%N;6%R)UU;)S$V+C<U,#HY-RXV
M-C<G72`]("=(<&$M06XG.PHD8V]O<F1I;F%T97-;)TUY86YM87(G75LG,38N
M-S8W.CDT+C<V-R==(#T@)U!A=&AE:6XG.PHD8V]O<F1I;F%T97-;)TUY86YM
M87(G75LG,38N-S8W.CDV+C$V-R==(#T@)UEA;F=O;B<["B1C;V]R9&EN871E
M<ULG37EA;FUA<B==6R<Q-BXY,#`Z.38N,3@S)UT@/2`G36EN9V%L861O;B<[
M"B1C;V]R9&EN871E<ULG37EA;FUA<B==6R<Q."XT-C<Z.30N,S4P)UT@/2`G
M4V%N9&]W87DG.PHD8V]O<F1I;F%T97-;)TUY86YM87(G75LG,3@N.#`P.CDU
M+C(Q-R==(#T@)U!R;VUE)SL*)&-O;W)D:6YA=&5S6R=->6%N;6%R)UU;)S$Y
M+C0Q-SHY,RXU-3`G72`]("=+>6%U:W!Y=2<["B1C;V]R9&EN871E<ULG37EA
M;FUA<B==6R<R,"XQ,S,Z.3(N.#@S)UT@/2`G4VET='=E)SL*)&-O;W)D:6YA
M=&5S6R=->6%N;6%R)UU;)S(P+C@S,SHY-2XX,S,G72`]("=-96EK=&EL82<[
M"B1C;V]R9&EN871E<ULG37EA;FUA<B==6R<R,2XS,#`Z.3DN-C$W)UT@/2`G
M2V5N9W1U;F<G.PHD8V]O<F1I;F%T97-;)TUY86YM87(G75LG,C$N.3@S.CDV
M+C$P,"==(#T@)TUA;F1A;&%Y)SL*)&-O;W)D:6YA=&5S6R=->6%N;6%R)UU;
M)S(R+CDS,SHY-RXW-3`G72`]("=,87-H:6\G.PHD8V]O<F1I;F%T97-;)TUY
M86YM87(G75LG,C0N,C8W.CDW+C(P,"==(#T@)T)H86UO)SL*)&-O;W)D:6YA
M=&5S6R=->6%N;6%R)UU;)S(T+C@V-SHY-"XY,3<G72`]("=(;VUA;&EN)SL*
M)&-O;W)D:6YA=&5S6R=->6%N;6%R)UU;)S(U+C,V-SHY-RXT,#`G72`]("=-
M>6ET:WEI;F$G.PHD8V]O<F1I;F%T97-;)TUY86YM87(G75LG,C<N,S,S.CDW
M+C0Q-R==(#T@)U!U=&%O)SL*)&-O;W)D:6YA=&5S6R=.86UI8FEA)UU;)RTQ
M-RXY,3<Z,3DN-S8W)UT@/2`G4G5N9'4G.PHD8V]O<F1I;F%T97-;)TYA;6EB
M:6$G75LG+3$Y+C8P,#HQ."XQ,3<G72`]("='<F]O=&9O;G1E:6XG.PHD8V]O
M<F1I;F%T97-;)TYA;6EB:6$G75LG+3(R+C0V-SHQ."XY-C<G72`]("=';V)A
M8FES)SL*)&-O;W)D:6YA=&5S6R=.86UI8FEA)UU;)RTR,BXT.#,Z,3<N-#8W
M)UT@/2`G2BX@1RX@4W1R:6ID;VTG.PHD8V]O<F1I;F%T97-;)TYA;6EB:6$G
M75LG+3(V+C4S,SHQ."XQ,3<G72`]("=+965T;6%N<VAO;W`G.PHD8V]O<F1I
M;F%T97-;)TYA=7)U)UU;)RTP+C4S,SHQ-C8N.3$W)UT@/2`G3F%U<G4@06ER
M<&]R="<["B1C;V]R9&EN871E<ULG3F5P86PG75LG,C8N-#@S.C@W+C(V-R==
M(#T@)T)I<F%T;F%G87(@06ER<&]R="<["B1C;V]R9&EN871E<ULG3F5P86PG
M75LG,C<N,38W.C@T+CDX,R==(#T@)U-I;7)A($%I<G!O<G0G.PHD8V]O<F1I
M;F%T97-;)TYE<&%L)UU;)S(W+C,U,#HX-RXV-C<G72`]("=487!L96IU;F<G
M.PHD8V]O<F1I;F%T97-;)TYE<&%L)UU;)S(W+C4Q-SHX,RXT-3`G72`]("="
M:&%I<F%W82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=.97!A;"==6R<R-RXW
M,#`Z.#4N,S8W)UT@/2`G2V%T:&UA;F1U($%I<G!O<G0G.PHD8V]O<F1I;F%T
M97-;)TYE<&%L)UU;)S(X+C(Q-SHX-"XP,#`G72`]("=0;VMH87)A($%I<G!O
M<G0G.PHD8V]O<F1I;F%T97-;)TYE<&%L)UU;)S(X+C8P,#HX,2XV,3<G72`]
M("=3=7)K:&5T)SL*)&-O;W)D:6YA=&5S6R=.97!A;"==6R<R.2XR.#,Z.#(N
M,38W)UT@/2`G2G5M;&$G.PHD8V]O<F1I;F%T97-;)TYE=&AE<FQA;F1S($%N
M=&EL;&5S)UU;)S$R+C$U,#HM-C@N,C@S)UT@/2`G1FQA;6EN9V\@06ER<&]R
M="P@0F]N86ER92<["B1C;V]R9&EN871E<ULG3F5T:&5R;&%N9',@06YT:6QL
M97,G75LG,3(N,C`P.BTV."XY-C<G72`]("=(871O($%I<G!O<G0L($-U<F%C
M86\G.PHD8V]O<F1I;F%T97-;)TYE=&AE<FQA;F1S($%N=&EL;&5S)UU;)S$W
M+C0X,SHM-C(N.3@S)UT@/2`G4F]O<V5V96QT($%I<G!O<G0@4V%I;G0@175S
M=&%T:75S)SL*)&-O;W)D:6YA=&5S6R=.971H97)L86YD<R!!;G1I;&QE<R==
M6R<Q."XP-3`Z+38S+C$Q-R==(#T@)TIU;&EA;F$@06ER<&]R="P@4V%I;G0@
M36%A<G1E;B<["B1C;V]R9&EN871E<ULG3F5T:&5R;&%N9',G75LG-3`N.3$W
M.C4N-S@S)UT@/2`G36%A<W1R:6-H="!!:7)P;W)T(%IU:60@3&EM8G5R9R<[
M"B1C;V]R9&EN871E<ULG3F5T:&5R;&%N9',G75LG-3$N-#4P.C0N,S,S)UT@
M/2`G5V]E;G-D<F5C:'0G.PHD8V]O<F1I;F%T97-;)TYE=&AE<FQA;F1S)UU;
M)S4Q+C0U,#HU+C0Q-R==(#T@)T5I;F1H;W9E;B<["B1C;V]R9&EN871E<ULG
M3F5T:&5R;&%N9',G75LG-3$N-38W.C0N.3,S)UT@/2`G1VEL>F4M4FEJ96XG
M.PHD8V]O<F1I;F%T97-;)TYE=&AE<FQA;F1S)UU;)S4Q+C8U,#HU+C<P,"==
M(#T@)U9O;&ME;"<["B1C;V]R9&EN871E<ULG3F5T:&5R;&%N9',G75LG-3$N
M.34P.C0N-#4P)UT@/2`G4F]T=&5R9&%M($%I<G!O<G0@6F5S=&EE;FAO=F5N
M)SL*)&-O;W)D:6YA=&5S6R=.971H97)L86YD<R==6R<U,BXP-C<Z-2XX.#,G
M72`]("=$965L96XG.PHD8V]O<F1I;F%T97-;)TYE=&AE<FQA;F1S)UU;)S4R
M+C$P,#HU+C$X,R==(#T@)T1E($)I;'0G.PHD8V]O<F1I;F%T97-;)TYE=&AE
M<FQA;F1S)UU;)S4R+C$S,SHU+C(X,R==(#T@)U-O97-T97)B97)G)SL*)&-O
M;W)D:6YA=&5S6R=.971H97)L86YD<R==6R<U,BXQ.#,Z-"XT,3<G72`]("=6
M86QK96YB=7)G)SL*)&-O;W)D:6YA=&5S6R=.971H97)L86YD<R==6R<U,BXR
M-C<Z-BXY,#`G72`]("=4=V5N=&AE)SL*)&-O;W)D:6YA=&5S6R=.971H97)L
M86YD<R==6R<U,BXS,#`Z-"XW-C<G72`]("=!;7-T97)D86T@06ER<&]R="!3
M8VAI<&AO;"<["B1C;V]R9&EN871E<ULG3F5T:&5R;&%N9',G75LG-3(N-#4P
M.C4N-3$W)UT@/2`G3&5L>7-T860G.PHD8V]O<F1I;F%T97-;)TYE=&AE<FQA
M;F1S)UU;)S4R+CDQ-SHT+C<X,R==(#T@)T1E($MO;WDG.PHD8V]O<F1I;F%T
M97-;)TYE=&AE<FQA;F1S)UU;)S4S+C$S,SHV+C4X,R==(#T@)T=R;VYI;F=E
M;B!!:7)P;W)T($5E;&1E)SL*)&-O;W)D:6YA=&5S6R=.971H97)L86YD<R==
M6R<U,RXR,3<Z-2XW-C<G72`]("=,965U=V%R9&5N)SL*)&-O;W)D:6YA=&5S
M6R=.971H97)L86YD<R==6R<U,RXR-3`Z-"XY,3<G72`]("=6;&EE;&%N9"<[
M"B1C;V]R9&EN871E<ULG3F5W($-A;&5D;VYI82==6R<M,C`N-38W.C$V-"XR
M.#,G72`]("=+;W5M86,@3FQL92U#86QE9&]N:64G.PHD8V]O<F1I;F%T97-;
M)TYE=R!#86QE9&]N:6$G75LG+3(P+C8U,#HQ-C8N-3@S)UT@/2`G3W5L;W5P
M($EL92!/=79E82<["B1C;V]R9&EN871E<ULG3F5W($-A;&5D;VYI82==6R<M
M,C`N-S8W.C$V-RXR,S,G72`]("=/=6%N86AA;2!);&4@3&EF;W4G.PHD8V]O
M<F1I;F%T97-;)TYE=R!#86QE9&]N:6$G75LG+3(Q+C0X,SHQ-C@N,#,S)UT@
M/2`G3&$@4F]C:&4@26QE($UA<F4G.PHD8V]O<F1I;F%T97-;)TYE=R!#86QE
M9&]N:6$G75LG+3(R+C`Q-SHQ-C8N,C$W)UT@/2`G3&$@5&]N=&]U=&$@3FQL
M92U#86QE9&]N:64G.PHD8V]O<F1I;F%T97-;)TYE=R!#86QE9&]N:6$G75LG
M+3(R+C(V-SHQ-C8N-#4P)UT@/2`G3F]U;65A($YL;&4M0V%L961O;FEE)SL*
M)&-O;W)D:6YA=&5S6R=.97<@0V%L961O;FEA)UU;)RTR,BXV,#`Z,38W+C0U
M,"==(#T@)TUO=64@26QE($1E<R!0:6YS)SL*)&-O;W)D:6YA=&5S6R=.97<@
M6F5A;&%N9"==6R<Q+CDX,SHM,34W+C0X,R==(#T@)T-H<FES=&UA<R`O($-A
M<W-I9'DG.PHD8V]O<F1I;F%T97-;)TYE=R!:96%L86YD)UU;)RTR.2XR-3`Z
M+3$W-RXY,3<G72`]("=286]U;"!)<VQA;F0L($ME<FUA9&5C($ES;&%N9"<[
M"B1C;V]R9&EN871E<ULG3F5W(%IE86QA;F0G75LG,RXX-3`Z+3$U.2XS-C<G
M72`]("=&86YN:6YG($ES;&%N9"<["B1C;V]R9&EN871E<ULG3F5W(%IE86QA
M;F0G75LG+3,V+C<X,SHQ-S0N-C,S)UT@/2`G5VAE;G5A<&%I)SL*)&-O;W)D
M:6YA=&5S6R=.97<@6F5A;&%N9"==6R<M,S<N,#$W.C$W-"XX,#`G72`]("=!
M=6-K;&%N9"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=.97<@6F5A;&%N9"==
M6R<M,S<N-C8W.C$W-BXR,#`G72`]("=4875R86YG82!!97)O9')O;64@07=S
M)SL*)&-O;W)D:6YA=&5S6R=.97<@6F5A;&%N9"==6R<M,S@N,3$W.C$W-BXS
M,3<G72`]("=2;W1O<G5A($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG3F5W
M(%IE86QA;F0G75LG+3,X+C8V-SHQ-S<N.3@S)UT@/2`G1VES8F]R;F4@065R
M;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=.97<@6F5A;&%N9"==6R<M,SDN,#$W
M.C$W-"XQ.#,G72`]("=.97<@4&QY;6]U=&@@065R;V1R;VUE)SL*)&-O;W)D
M:6YA=&5S6R=.97<@6F5A;&%N9"==6R<M-#`N,C`P.C$W-2XS-C<G72`]("=/
M:&%K96$G.PHD8V]O<F1I;F%T97-;)TYE=R!:96%L86YD)UU;)RTT,"XY,#`Z
M,3<T+CDX,R==(#T@)U!A<F%P87)A=6UU($%E<F]D<F]M92<["B1C;V]R9&EN
M871E<ULG3F5W(%IE86QA;F0G75LG+30Q+C,S,SHQ-S0N.#`P)UT@/2`G5V5L
M;&EN9W1O;B!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=.97<@6F5A;&%N9"==
M6R<M-#(N-#$W.C$W,RXW,#`G72`]("=+86EK;W5R82<["B1C;V]R9&EN871E
M<ULG3F5W(%IE86QA;F0G75LG+30R+C<Q-SHQ-S`N.3@S)UT@/2`G2&]K:71I
M:V$@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=.97<@6F5A;&%N9"==6R<M
M-#,N-#@S.C$W,BXU-3`G72`]("=#:')I<W1C:'5R8V@G.PHD8V]O<F1I;F%T
M97-;)TYE=R!:96%L86YD)UU;)RTT,RXY-3`Z+3$W-BXU-C<G72`]("=#:&%T
M:&%M($ES;&%N9"<["B1C;V]R9&EN871E<ULG3F5W(%IE86QA;F0G75LG+30U
M+CDS,SHQ-S`N,C`P)UT@/2`G1'5N961I;B!!97)O9')O;64G.PHD8V]O<F1I
M;F%T97-;)TYE=R!:96%L86YD)UU;)RTT-BXW,#`Z,38X+C4U,"==(#T@)TEN
M=F5R8V%R9VEL;"!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)TYI8V%R86=U
M82==6R<Q,2XT,3<Z+3@U+C@S,R==(#T@)U)I=F%S)SL*)&-O;W)D:6YA=&5S
M6R=.:6-A<F%G=6$G75LG,3(N,#`P.BTX-BXW-C<G72`]("=";'5E9FEE;&1S
M)SL*)&-O;W)D:6YA=&5S6R=.:6-A<F%G=6$G75LG,3(N,3`P.BTX-2XS-C<G
M72`]("=*=6EG86QP82<["B1C;V]R9&EN871E<ULG3FEC87)A9W5A)UU;)S$R
M+C$U,#HM.#8N,38W)UT@/2`G36%N86=U82!!+B!#+B!386YD:6YO)SL*)&-O
M;W)D:6YA=&5S6R=.:6-A<F%G=6$G75LG,3(N-C,S.BTX-RXQ,S,G72`]("=#
M:&EN86YD96=A)SL*)&-O;W)D:6YA=&5S6R=.:6-A<F%G=6$G75LG,3,N,#@S
M.BTX-2XY.#,G72`]("=*:6YO=&5G82<["B1C;V]R9&EN871E<ULG3FEC87)A
M9W5A)UU;)S$T+C`U,#HM.#,N,S8W)UT@/2`G4'5E<G1O($-A8F5Z87,G.PHD
M8V]O<F1I;F%T97-;)TYI9V5R)UU;)S$Q+C@X,SHS+C0U,"==(#T@)T=A>6$G
M.PHD8V]O<F1I;F%T97-;)TYI9V5R)UU;)S$S+C(S,SHQ,2XY.#,G72`]("=-
M86EN92U3;W)O82<["B1C;V]R9&EN871E<ULG3FEG97(G75LG,3,N-#$W.C$R
M+C<X,R==(#T@)T1I9F9A)SL*)&-O;W)D:6YA=&5S6R=.:6=E<B==6R<Q,RXT
M-C<Z-RXP.#,G72`]("=-87)A9&DG.PHD8V]O<F1I;F%T97-;)TYI9V5R)UU;
M)S$S+C0X,SHR+C$V-R==(#T@)TYI86UE>2U!97)O)SL*)&-O;W)D:6YA=&5S
M6R=.:6=E<B==6R<Q,RXW.#,Z."XY.#,G72`]("=::6YD97(G.PHD8V]O<F1I
M;F%T97-;)TYI9V5R)UU;)S$S+C@P,#HU+C(U,"==(#T@)T)I<FYI+4Y<)TMO
M;FYI)SL*)&-O;W)D:6YA=&5S6R=.:6=E<B==6R<Q,RXY.#,Z,3`N,S`P)UT@
M/2`G1V]U<F4G.PHD8V]O<F1I;F%T97-;)TYI9V5R)UU;)S$T+C(P,#HQ+C0U
M,"==(#T@)U1I;&QA8F5R>2<["B1C;V]R9&EN871E<ULG3FEG97(G75LG,30N
M.3`P.C4N,C4P)UT@/2`G5&%H;W5A)SL*)&-O;W)D:6YA=&5S6R=.:6=E<B==
M6R<Q-BXY-C<Z-RXY.#,G72`]("=!9V%D97HG.PHD8V]O<F1I;F%T97-;)TYI
M9V5R)UU;)S$X+C8X,SHQ,BXY,3<G72`]("=":6QM82<["B1C;V]R9&EN871E
M<ULG3FEG97)I82==6R<Q,"XV,#`Z-RXT-3`G72`]("=+861U;F$G.PHD8V]O
M<F1I;F%T97-;)TYI9V5R:6$G75LG,3$N,3,S.C<N-C@S)UT@/2`G6F%R:6$G
M.PHD8V]O<F1I;F%T97-;)TYI9V5R:6$G75LG,3$N.#4P.C$S+C`X,R==(#T@
M)TUA:61U9W5R:2<["B1C;V]R9&EN871E<ULG3FEG97)I82==6R<Q,BXP-3`Z
M."XU,S,G72`]("=+86YO)SL*)&-O;W)D:6YA=&5S6R=.:6=E<FEA)UU;)S$R
M+C$V-SHV+C<P,"==(#T@)T=U<V%U)SL*)&-O;W)D:6YA=&5S6R=.:6=E<FEA
M)UU;)S$S+C`Q-SHU+C(U,"==(#T@)U-O:V]T;R<["B1C;V]R9&EN871E<ULG
M3FEG97)I82==6R<T+C@U,#HW+C`Q-R==(#T@)U!O<G0@2&%R8V]U<G0G.PHD
M8V]O<F1I;F%T97-;)TYI9V5R:6$G75LG-"XY-C<Z."XS-3`G72`]("=#86QA
M8F%R)SL*)&-O;W)D:6YA=&5S6R=.:6=E<FEA)UU;)S8N-#8W.C<N-34P)UT@
M/2`G16YU9W4G.PHD8V]O<F1I;F%T97-;)TYI9V5R:6$G75LG-BXU.#,Z,RXS
M,S,G72`]("=,86=O<R`O($EK96IA)SL*)&-O;W)D:6YA=&5S6R=.:6=E<FEA
M)UU;)S<N-#,S.C,N.3`P)UT@/2`G26)A9&%N)SL*)&-O;W)D:6YA=&5S6R=.
M:6=E<FEA)UU;)S<N-C@S.C@N-C$W)UT@/2`G36%K=7)D:2<["B1C;V]R9&EN
M871E<ULG3FEG97)I82==6R<W+C<X,SHT+C0X,R==(#T@)T]S:&]G8F\G.PHD
M8V]O<F1I;F%T97-;)TYI9V5R:6$G75LG."XT.#,Z-"XU.#,G72`]("=);&]R
M:6XG.PHD8V]O<F1I;F%T97-;)TYI9V5R:6$G75LG.2XQ,#`Z-BXP,3<G72`]
M("=":61A)SL*)&-O;W)D:6YA=&5S6R=.:6=E<FEA)UU;)SDN,C,S.C$R+C0V
M-R==(#T@)UEO;&$G.PHD8V]O<F1I;F%T97-;)TYI9V5R:6$G75LG.2XX-C<Z
M."XY,#`G72`]("=*;W,G.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<U."XQ
M,#`Z-BXV,S,G72`]("=,:7-T82!&;'EP;&%S<R<["B1C;V]R9&EN871E<ULG
M3F]R=V%Y)UU;)S4X+C(P,#HX+C`X,R==(#T@)TMR:7-T:6%N<V%N9"`O($MJ
M979I:R<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S4X+C@X,SHU+C8S,R==
M(#T@)U-T879A;F=E<B`O(%-O;&$G.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==
M6R<U.2XQ.#,Z.2XU-C<G72`]("=3:VEE;BU'96ET97)Y9V=E;B<["B1C;V]R
M9&EN871E<ULG3F]R=V%Y)UU;)S4Y+C(P,#HQ,"XR-C<G72`]("=4;W)P)SL*
M)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-3DN,S4P.C4N,C$W)UT@/2`G2&%U
M9V5S=6YD("\@2V%R;6]Y)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-3DN
M,S@S.C$P+C<X,R==(#T@)U)Y9V=E)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG
M75LG-3DN.3`P.C$P+C8S,R==(#T@)T]S;&\@+R!&;W)N96)U)SL*)&-O;W)D
M:6YA=&5S6R=.;W)W87DG75LG-C`N,C`P.C$Q+C`X,R==(#T@)T]S;&\@+R!'
M87)D97)M;V5N)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-C`N,C@S.C4N
M,C,S)UT@/2`G0F5R9V5N("\@1FQE<VQA;F0G.PHD8V]O<F1I;F%T97-;)TYO
M<G=A>2==6R<V,"XV-3`Z-BXU,#`G72`]("=6;W-S+4)O)SL*)&-O;W)D:6YA
M=&5S6R=.;W)W87DG75LG-C$N,#`P.CDN,S`P)UT@/2`G1F%G97)N97,@3&5I
M<FEN)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-C$N,34P.C<N,3,S)UT@
M/2`G4V]G;F1A;"`O($AA=6MA<V5N)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG
M75LG-C$N-3@S.C4N,#,S)UT@/2`G1FQO<F\G.PHD8V]O<F1I;F%T97-;)TYO
M<G=A>2==6R<V,2XX,S,Z-BXQ,3<G72`]("=386YD86YE("\@06YD82<["B1C
M;V]R9&EN871E<ULG3F]R=V%Y)UU;)S8R+C$X,SHV+C`V-R==(#T@)T]R<W1A
M+59O;&1A("\@2&]V9&5N)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-C(N
M-38W.C8N,3$W)UT@/2`G06QE<W5N9"`O(%9I9W)A)SL*)&-O;W)D:6YA=&5S
M6R=.;W)W87DG75LG-C(N-3@S.C$Q+C,U,"==(#T@)U)O<F]S($QU9G1H879N
M)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-C(N-S4P.C<N,C8W)UT@/2`G
M36]L9&4@+R!!<F\G.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V,RXQ,3<Z
M-RXX,S,G72`]("=+<FES=&EA;G-U;F0@+R!+=F5R;F)E<F=E="<["B1C;V]R
M9&EN871E<ULG3F]R=V%Y)UU;)S8S+C0V-SHQ,"XY,S,G72`]("=4<F]N9&AE
M:6T@+R!6865R;F5S)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-C,N-S`P
M.CDN-C`P)UT@/2`G3W)L86YD($EI:2<["B1C;V]R9&EN871E<ULG3F]R=V%Y
M)UU;)S8T+C0V-SHQ,2XU.#,G72`]("=.86US;W,@3'5F=&AA=FXG.PHD8V]O
M<F1I;F%T97-;)TYO<G=A>2==6R<V-"XX,S,Z,3$N,34P)UT@/2`G4F]R=FEK
M("\@4GEU;2<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S8U+C0V-SHQ,BXR
M,3<G72`]("="<F]N;F]Y<W5N9"`O($)R;VYN;WDG.PHD8V]O<F1I;F%T97-;
M)TYO<G=A>2==6R<V-2XX,#`Z,3,N,3,S)UT@/2`G36]S:F]E;B!+:F%E<G-T
M860G.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V-2XY-C<Z,3(N-#8W)UT@
M/2`G4V%N9&YE<W-J;V5N("\@4W1O:VMA)SL*)&-O;W)D:6YA=&5S6R=.;W)W
M87DG75LG-C8N,S8W.C$T+C,P,"==(#T@)TUO($D@4F%N82`O(%)O<W-V;VQL
M)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-C<N,C8W.C$T+C,V-R==(#T@
M)T)O9&\@5FDG.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V-RXU,3<Z,3(N
M,3`P)UT@/2`G4F]S="!&;'EP;&%S<R<["B1C;V]R9&EN871E<ULG3F]R=V%Y
M)UU;)S8X+C$U,#HQ,RXV,3<G72`]("=,96MN97,G.PHD8V]O<F1I;F%T97-;
M)TYO<G=A>2==6R<V."XR-3`Z,30N-C8W)UT@/2`G4W9O;'9A97(@+R!(96QL
M92<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S8X+C0V-SHQ-RXU,#`G72`]
M("=.87)V:6L@26EI)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-C@N-3$W
M.C$V+C8X,R==(#T@)T5V96YE<R<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;
M)S8X+C4X,SHQ-2XP,3<G72`]("=3=&]R:VUA<FMN97,@+R!3:V%G96XG.PHD
M8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V.2XP,#`Z,C,N,#,S)UT@/2`G2V%U
M=&]K96EN;R<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S8Y+C`V-SHQ."XU
M,S,G72`]("="87)D=69O<W,G.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V
M.2XS,#`Z,38N,34P)UT@/2`G06YD;WEA)SL*)&-O;W)D:6YA=&5S6R=.;W)W
M87DG75LG-CDN-C@S.C$X+CDQ-R==(#T@)U1R;VUS;R`O($QA;F=N97,G.PHD
M8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V.2XW,S,Z,CDN.3`P)UT@/2`G2VER
M:V5N97,@3'5F=&AA=FXG.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V.2XW
M.#,Z,C`N.38W)UT@/2`G4V]R:VIO<V5N)SL*)&-O;W)D:6YA=&5S6R=.;W)W
M87DG75LG-CDN.3@S.C(S+C,V-R==(#T@)T%L=&$@3'5F=&AA=FXG.PHD8V]O
M<F1I;F%T97-;)TYO<G=A>2==6R<W,"XP-C<Z,C0N.3@S)UT@/2`G0F%N86LG
M.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<W,"XP-C<Z,CDN.#4P)UT@/2`G
M5F%D<V\G.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<W,"XS-3`Z,S$N,#4P
M)UT@/2`G4W9A<G1N97,G.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<W,"XV
M-C<Z,C,N-C8W)UT@/2`G2&%M;65R9F5S="<["B1C;V]R9&EN871E<ULG3F]R
M=V%Y)UU;)S<P+C@V-SHR.2XP,S,G72`]("="97)L979A9R<["B1C;V]R9&EN
M871E<ULG3F]R=V%Y)UU;)S<P+CDS,SHM."XV-C<G72`]("=*86X@36%Y96XG
M.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<W,2XP,3<Z,C4N.3@S)UT@/2`G
M2&]N;FEN9W-V86<@+R!686QA;B<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;
M)S<Q+C`S,SHR-RXX,S,G72`]("=-96AA;6XG.PHD8V]O<F1I;F%T97-;)TYO
M<G=A>2==6R<W-"XU,3<Z,3DN,#$W)UT@/2`G0FIO<FYO>6$G.PHD8V]O<F1I
M;F%T97-;)TYO<G=A>2==6R<W-BXU,#`Z,C4N,#8W)UT@/2`G2&]P96XG.PHD
M8V]O<F1I;F%T97-;)TYO<G=A>2==6R<W."XR-3`Z,34N-#8W)UT@/2`G4W9A
M;&)A<F0@3'5F=&AA=FXG.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<W."XY
M,3<Z,3$N.3,S)UT@/2`G3GDM06QE<W5N9"!):2<["B1C;V]R9&EN871E<ULG
M3VUA;B==6R<Q-RXP,S,Z-30N,#@S)UT@/2`G4V%L86QA:"<["B1C;V]R9&EN
M871E<ULG3VUA;B==6R<Q-RXV-C<Z-30N,#,S)UT@/2`G5&AU;7)A:70G.PHD
M8V]O<F1I;F%T97-;)T]M86XG75LG,C`N-C8W.C4X+CDP,"==(#T@)TUA<VER
M86@G.PHD8V]O<F1I;F%T97-;)T]M86XG75LG,C(N,S4P.C4V+C0X,R==(#T@
M)T9A:'5D)SL*)&-O;W)D:6YA=&5S6R=/;6%N)UU;)S(R+C4S,SHU.2XT.#,G
M72`]("=3=7(G.PHD8V]O<F1I;F%T97-;)T]M86XG75LG,C,N,#8W.C4W+C8U
M,"==(#T@)U-A:7$G.PHD8V]O<F1I;F%T97-;)T]M86XG75LG,C,N-3@S.C4X
M+C(X,R==(#T@)U-E96(L($EN=&5R;F%T:6]N86P@06ER<&]R="<["B1C;V]R
M9&EN871E<ULG3VUA;B==6R<R-"XR,S,Z-34N-S@S)UT@/2`G0G5R86EM:2<[
M"B1C;V]R9&EN871E<ULG3VUA;B==6R<R-"XT-C<Z-38N-C,S)UT@/2`G4V]H
M87(@36%J:7,G.PHD8V]O<F1I;F%T97-;)T]M86XG75LG,C8N,C$W.C4V+C(S
M,R==(#T@)TMH87-S86(G.PHD8V]O<F1I;F%T97-;)U!A:VES=&%N)UU;)S(T
M+CDP,#HV-RXQ,S,G72`]("=+87)A8VAI($%I<G!O<G0G.PHD8V]O<F1I;F%T
M97-;)U!A:VES=&%N)UU;)S(U+C`V-SHV,2XX,#`G72`]("=*:7=A;FDG.PHD
M8V]O<F1I;F%T97-;)U!A:VES=&%N)UU;)S(U+C,X,SHV."XT,3<G72`]("=(
M>61E<F%B860@06ER<&]R="<["B1C;V]R9&EN871E<ULG4&%K:7-T86XG75LG
M,C8N,C4P.C8X+C,V-R==(#T@)TYA=V%B<VAA:"<["B1C;V]R9&EN871E<ULG
M4&%K:7-T86XG75LG,C8N.38W.C8T+C$P,"==(#T@)U!A;FIG=7(G.PHD8V]O
M<F1I;F%T97-;)U!A:VES=&%N)UU;)S(X+C,P,#HV."XT-C<G72`]("=*86-O
M8F%B860G.PHD8V]O<F1I;F%T97-;)U!A:VES=&%N)UU;)S(Y+C4U,#HV-RXX
M.#,G72`]("=3:6)I)SL*)&-O;W)D:6YA=&5S6R=086MI<W1A;B==6R<S,"XR
M,#`Z-S$N-#,S)UT@/2`G375L=&%N)SL*)&-O;W)D:6YA=&5S6R=086MI<W1A
M;B==6R<S,"XR-3`Z-C8N.#@S)UT@/2`G475E='1A($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)U!A:VES=&%N)UU;)S,Q+C4Q-SHW-"XT,#`G72`]("=,86AO
M<F4@06ER<&]R="<["B1C;V]R9&EN871E<ULG4&%K:7-T86XG75LG,S$N-34P
M.C<T+C,S,R==(#T@)TQA:&]R92!#:71Y)SL*)&-O;W)D:6YA=&5S6R=086MI
M<W1A;B==6R<S,2XX,3<Z-S`N.3$W)UT@/2`G1&5R82!)<VUA:6P@2VAA;B<[
M"B1C;V]R9&EN871E<ULG4&%K:7-T86XG75LG,S(N,#4P.C<R+C8V-R==(#T@
M)U-A<F=O9&AA)SL*)&-O;W)D:6YA=&5S6R=086MI<W1A;B==6R<S,BXU-3`Z
M-S$N-3$W)UT@/2`G36EA;G=A;&DG.PHD8V]O<F1I;F%T97-;)U!A:VES=&%N
M)UU;)S,S+C8Q-SHW,RXQ,#`G72`]("=)<VQA;6%B860@06ER<&]R="<["B1C
M;V]R9&EN871E<ULG4&%K:7-T86XG75LG,S0N,#$W.C<Q+C4X,R==(#T@)U!E
M<VAA=V%R)SL*)&-O;W)D:6YA=&5S6R=086MI<W1A;B==6R<S-"XP-C<Z-S$N
M.3@S)UT@/2`G4FES86QP=7(G.PHD8V]O<F1I;F%T97-;)U!A;&%U)UU;)S<N
M,S8W.C$S-"XU,S,G72`]("="86)E;'1H=6%P($ES;&%N9"P@0F%B96QT:'5A
M<"]+;W)O<B!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=086YA;6$G75LG."XP
M.#,Z+3@P+CDU,"==(#T@)U-A;G1I86=O)SL*)&-O;W)D:6YA=&5S6R=086YA
M;6$G75LG."XT,#`Z+3@R+C0Q-R==(#T@)T1A=FED)SL*)&-O;W)D:6YA=&5S
M6R=086YA;6$G75LG."XY,3<Z+3<Y+C8P,"==(#T@)TAO=V%R9"!!:7(@1F]R
M8V4@0F%S92<["B1C;V]R9&EN871E<ULG4&%N86UA)UU;)SDN,#4P.BTW.2XS
M-C<G72`]("=4;V-U;65N)SL*)&-O;W)D:6YA=&5S6R=086YA;6$G75LG.2XS
M,S,Z+3<Y+CDX,R==(#T@)T9T(%-H97)M86X@4F]C;V(G.PHD8V]O<F1I;F%T
M97-;)U!A<'5A($YE=R!'=6EN96$G75LG+3,N-38W.C$T,RXV,S,G72`]("=7
M97=A:R<["B1C;V]R9&EN871E<ULG4&%P=6$@3F5W($=U:6YE82==6R<M-2XR
M,3<Z,30U+C<X,R==(#T@)TUA9&%N9R<["B1C;V]R9&EN871E<ULG4&%P=6$@
M3F5W($=U:6YE82==6R<M.2XT,S,Z,30W+C(Q-R==(#T@)TUO<F5S8GDG.PHD
M8V]O<F1I;F%T97-;)U!A<F%G=6%Y)UU;)RTR,"XW,3<Z+38Q+CDQ-R==(#T@
M)TYU979A($%S=6YC:6]N)SL*)&-O;W)D:6YA=&5S6R=087)A9W5A>2==6R<M
M,C(N,#$W.BTV,"XV,#`G72`]("=-87)I<V-A;"!%<W1I9V%R<FEB:6$G.PHD
M8V]O<F1I;F%T97-;)U!A<F%G=6%Y)UU;)RTR,RXT,3<Z+34W+C,P,"==(#T@
M)T-O;F-E<&-I;VXG.PHD8V]O<F1I;F%T97-;)U!A<F%G=6%Y)UU;)RTR-2XR
M-C<Z+34W+C8S,R==(#T@)T%S=6YC:6]N("\@065R;W!U97)T;R<["B1C;V]R
M9&EN871E<ULG4&%R86=U87DG75LG+3(W+C,Q-SHM-34N.#,S)UT@/2`G16YC
M87)N86-I;VXG.PHD8V]O<F1I;F%T97-;)U!E<G4G75LG+3$P+C<S,SHM-S,N
M-S@S)UT@/2`G071A;&%Y82<["B1C;V]R9&EN871E<ULG4&5R=2==6R<M,3(N
M,#`P.BTW-RXQ,3<G72`]("=,:6UA+4-A;&QA;R`O($%E<F]P+B!);G1E<FYA
M8VEO;F%L($IO<F=E8VAA=F5Z)SL*)&-O;W)D:6YA=&5S6R=097)U)UU;)RTQ
M,BXV,S,Z+38Y+C(P,"==(#T@)U!U97)T;R!-86QD;VYA9&\G.PHD8V]O<F1I
M;F%T97-;)U!E<G4G75LG+3$S+C$S,SHM-S0N,C$W)UT@/2`G07EA8W5C:&\G
M.PHD8V]O<F1I;F%T97-;)U!E<G4G75LG+3$S+C4U,#HM-S$N.3@S)UT@/2`G
M0W5Z8V\G.PHD8V]O<F1I;F%T97-;)U!E<G4G75LG+3$S+C<Q-SHM-S,N,S4P
M)UT@/2`G06YD86AU87EL82<["B1C;V]R9&EN871E<ULG4&5R=2==6R<M,3,N
M-S4P.BTW-BXR.#,G72`]("=0:7-C;R<["B1C;V]R9&EN871E<ULG4&5R=2==
M6R<M,34N,S@S.BTW-2XQ-C<G72`]("=386X@2G5A;B<["B1C;V]R9&EN871E
M<ULG4&5R=2==6R<M,34N-#@S.BTW,"XQ-3`G72`]("=*=6QI86-A)SL*)&-O
M;W)D:6YA=&5S6R=097)U)UU;)RTQ-BXS,3<Z+3<Q+C4U,"==(#T@)T%R97%U
M:7!A)SL*)&-O;W)D:6YA=&5S6R=097)U)UU;)RTQ."XP-C<Z+3<P+C,P,"==
M(#T@)U1A8VYA)SL*)&-O;W)D:6YA=&5S6R=097)U)UU;)RTS+C4U,#HM.#`N
M-#`P)UT@/2`G5'5M8F5S)SL*)&-O;W)D:6YA=&5S6R=097)U)UU;)RTS+C<U
M,#HM-S,N,C4P)UT@/2`G27%U:71O<R<["B1C;V]R9&EN871E<ULG4&5R=2==
M6R<M-"XU-C<Z+3@Q+C(U,"==(#T@)U1A;&%R82<["B1C;V]R9&EN871E<ULG
M4&5R=2==6R<M-2XQ.#,Z+3@P+C8P,"==(#T@)U!I=7)A)SL*)&-O;W)D:6YA
M=&5S6R=097)U)UU;)RTU+CDP,#HM-S8N,#@S)UT@/2`G675R:6UA9W5A<R<[
M"B1C;V]R9&EN871E<ULG4&5R=2==6R<M-BXP-3`Z+3<W+C$U,"==(#T@)U)I
M;VIA)SL*)&-O;W)D:6YA=&5S6R=097)U)UU;)RTV+C(Q-SHM-S<N.#,S)UT@
M/2`G0VAA8VAA<&]Y87,G.PHD8V]O<F1I;F%T97-;)U!E<G4G75LG+38N-#4P
M.BTW-BXS.#,G72`]("=487)A<&]T;R<["B1C;V]R9&EN871E<ULG4&5R=2==
M6R<M-BXW.#,Z+3<Y+C@S,R==(#T@)T-H:6-L87EO)SL*)&-O;W)D:6YA=&5S
M6R=097)U)UU;)RTW+C$S,SHM-S@N-#8W)UT@/2`G0V%J86UA<F-A)SL*)&-O
M;W)D:6YA=&5S6R=097)U)UU;)RTW+C(Q-SHM-S8N-S$W)UT@/2`G2G5A;FIU
M:2<["B1C;V]R9&EN871E<ULG4&5R=2==6R<M."XQ,#`Z+3<Y+C`S,R==(#T@
M)U1R=6II;&QO)SL*)&-O;W)D:6YA=&5S6R=097)U)UU;)RTX+C0Q-SHM-S0N
M-C`P)UT@/2`G4'5C86QL<&$G.PHD8V]O<F1I;F%T97-;)U!E<G4G75LG+3DN
M,3,S.BTW-2XY-3`G72`]("=4:6YG;R!-87)I82<["B1C;V]R9&EN871E<ULG
M4&5R=2==6R<M.2XQ-C<Z+3<X+C4Q-R==(#T@)T-H:6UB;W1E)SL*)&-O;W)D
M:6YA=&5S6R=097)U)UU;)RTY+C,U,#HM-S<N-C`P)UT@/2`G06YT82!(=6%R
M87HG.PHD8V]O<F1I;F%T97-;)U!E<G4G75LG+3DN.3`P.BTW-2XW-3`G72`]
M("=(=6%N=6-O)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<Q,"XS
M,#`Z,3(S+CDV-R==(#T@)TUA8W1A;B<["B1C;V]R9&EN871E<ULG4&AI;&EP
M<&EN97,G75LG,3`N-S`P.C$R,BXU-C<G72`]("=);&]I;&\G.PHD8V]O<F1I
M;F%T97-;)U!H:6QI<'!I;F5S)UU;)S$Q+C`S,SHQ,C8N-S,S)UT@/2`G1W5I
M=6%N)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<Q,2XR-3`Z,3(U
M+C`P,"==(#T@)U1A8VQO8F%N)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE
M<R==6R<Q,2XU.#,Z,3(R+C<U,"==(#T@)U)O>&%S)SL*)&-O;W)D:6YA=&5S
M6R=0:&EL:7!P:6YE<R==6R<Q,BXS-3`Z,3(Q+C`S,R==(#T@)U-A;B!*;W-E
M)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<Q,BXS-C<Z,3(S+C8Q
M-R==(#T@)TUA<V)A=&4G.PHD8V]O<F1I;F%T97-;)U!H:6QI<'!I;F5S)UU;
M)S$R+C0X,SHQ,C0N-C,S)UT@/2`G0V%T87)M86XG.PHD8V]O<F1I;F%T97-;
M)U!H:6QI<'!I;F5S)UU;)S$R+C4X,SHQ,C(N,C8W)UT@/2`G4F]M8FQO;B<[
M"B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG,3,N,3,S.C$R,RXW,S,G
M72`]("=,96=A<W!I)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<Q
M,RXT,3<Z,3(Q+C$X,R==(#T@)T-A;&%P86XG.PHD8V]O<F1I;F%T97-;)U!H
M:6QI<'!I;F5S)UU;)S$S+C4X,SHQ,C0N,C,S)UT@/2`G5FER86,G.PHD8V]O
M<F1I;F%T97-;)U!H:6QI<'!I;F5S)UU;)S$T+C`X,SHQ,C(N,#$W)UT@/2`G
M06QA8F%T)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<Q-"XQ,S,Z
M,3(R+CDX,R==(#T@)T1A970G.PHD8V]O<F1I;F%T97-;)U!H:6QI<'!I;F5S
M)UU;)S$T+C4P,#HQ,C`N.3$W)UT@/2`G4V%N9VQE>2!0;VEN="<["B1C;V]R
M9&EN871E<ULG4&AI;&EP<&EN97,G75LG,30N-3$W.C$R,2XP,#`G72`]("=.
M:6YO>2!!<75I;F\@26YT97(M3F%T:6]N86P@06ER<&]R="<["B1C;V]R9&EN
M871E<ULG4&AI;&EP<&EN97,G75LG,30N.#`P.C$R,"XR-C<G72`]("=3=6)I
M8R!"87D@5V5A=&AE<B!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P
M:6YE<R==6R<Q-2XQ-C<Z,3(P+C4V-R==(#T@)T-L87)K($%B)SL*)&-O;W)D
M:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<Q-2XS,S,Z,3$Y+CDV-R==(#T@)TEB
M82<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG,34N-S8W.C$R,2XU
M-C<G72`]("="86QE<B<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG
M,38N-#$W.C$R,"XV,#`G72`]("="86=U:6\G.PHD8V]O<F1I;F%T97-;)U!H
M:6QI<'!I;F5S)UU;)S$W+C4V-SHQ,C`N,S@S)UT@/2`G5FEG86XG.PHD8V]O
M<F1I;F%T97-;)U!H:6QI<'!I;F5S)UU;)S$W+C8Q-SHQ,C$N-S,S)UT@/2`G
M5'5G=65G87)A;R<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG,3@N
M,3@S.C$R,"XU,S,G72`]("=,86]A9R<["B1C;V]R9&EN871E<ULG4&AI;&EP
M<&EN97,G75LG,3@N,S8W.C$R,2XV,S,G72`]("=!<&%R<FDG.PHD8V]O<F1I
M;F%T97-;)U!H:6QI<'!I;F5S)UU;)S(P+C0U,#HQ,C$N.38W)UT@/2`G0F%S
M8V\G.PHD8V]O<F1I;F%T97-;)U!H:6QI<'!I;F5S)UU;)S8N,3$W.C$R-2XQ
M.#,G72`]("='96XN(%-A;G1O<R<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN
M97,G75LG-BXY,#`Z,3(R+C`V-R==(#T@)UIA;6)O86YG82<["B1C;V]R9&EN
M871E<ULG4&AI;&EP<&EN97,G75LG-RXQ,3<Z,3(U+C8U,"==(#T@)T1A=F%O
M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U!H:6QI<'!I;F5S)UU;)S<N,38W
M.C$R-"XR,3<G72`]("=#;W1O8F%T;R<["B1C;V]R9&EN871E<ULG4&AI;&EP
M<&EN97,G75LG."XQ-3`Z,3(U+C`X,R==(#T@)TUA;&%Y8F%L87DG.PHD8V]O
M<F1I;F%T97-;)U!H:6QI<'!I;F5S)UU;)S@N-#@S.C$R-"XV,S,G72`]("=#
M86=A>6%N($1E($]R;R<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG
M."XV,#`Z,3(S+C,U,"==(#T@)T1I<&]L;V<G.PHD8V]O<F1I;F%T97-;)U!H
M:6QI<'!I;F5S)UU;)SDN,S`P.C$R,RXS,#`G72`]("=$=6UA9W5E=&4G.PHD
M8V]O<F1I;F%T97-;)U!H:6QI<'!I;F5S)UU;)SDN-C`P.C$R,RXX-3`G72`]
M("=486=B:6QA<F%N)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<Y
M+C<U,#HQ,3@N-S,S)UT@/2`G4'5E<G1O(%!R:6YC97-A)SL*)&-O;W)D:6YA
M=&5S6R=0:&EL:7!P:6YE<R==6R<Y+C@P,#HQ,C4N-3`P)UT@/2`G4W5R:6=A
M;R<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG.2XY,S,Z,3(U+C4Q
M-R==(#T@)T)U='5A;B<["B1C;V]R9&EN871E<ULG4&]L86YD)UU;)S4P+C`X
M,SHQ.2XX,#`G72`]("=+<F%K;W<G.PHD8V]O<F1I;F%T97-;)U!O;&%N9"==
M6R<U,"XQ,#`Z,C(N,#4P)UT@/2`G4GIE<WIO=RU*87-I;VYK82<["B1C;V]R
M9&EN871E<ULG4&]L86YD)UU;)S4P+C(S,SHQ.2XP,S,G72`]("=+871O=VEC
M92<["B1C;V]R9&EN871E<ULG4&]L86YD)UU;)S4Q+C$P,#HQ-BXX.#,G72`]
M("=7<F]C;&%W($EI)SL*)&-O;W)D:6YA=&5S6R=0;VQA;F0G75LG-3$N.3,S
M.C$U+C4S,R==(#T@)UII96QO;F$@1V]R82<["B1C;V]R9&EN871E<ULG4&]L
M86YD)UU;)S4R+C$V-SHR,"XY-C<G72`]("=787)S>F%W82U/:V5C:64G.PHD
M8V]O<F1I;F%T97-;)U!O;&%N9"==6R<U,BXT,3<Z,38N.#,S)UT@/2`G4&]Z
M;F%N)SL*)&-O;W)D:6YA=&5S6R=0;VQA;F0G75LG-3,N-#`P.C$T+C8Q-R==
M(#T@)U-Z8WIE8VEN)SL*)&-O;W)D:6YA=&5S6R=0;VQA;F0G75LG-30N,C`P
M.C$V+C$U,"==(#T@)TMO<WIA;&EN)SL*)&-O;W)D:6YA=&5S6R=0;VQA;F0G
M75LG-30N,S@S.C$X+C0V-R==(#T@)T=D86YS:RU296)I96-H;W=O)SL*)&-O
M;W)D:6YA=&5S6R=0;W)T=6=A;"==6R<S,BXV.#,Z+3$V+C<V-R==(#T@)T9U
M;F-H86P@+R!3+B!#871A<FEN82<["B1C;V]R9&EN871E<ULG4&]R='5G86PG
M75LG,S,N,#8W.BTQ-BXS-3`G72`]("=0;W)T;R!386YT;R<["B1C;V]R9&EN
M871E<ULG4&]R='5G86PG75LG,S8N.38W.BTR-2XQ-C<G72`]("=386YT82!-
M87)I82!!8V]R97,G.PHD8V]O<F1I;F%T97-;)U!O<G1U9V%L)UU;)S,W+C`Q
M-SHM-RXY-C<G72`]("=&87)O("\@065R;W!O<G1O)SL*)&-O;W)D:6YA=&5S
M6R=0;W)T=6=A;"==6R<S-RXW,S,Z+3(U+C<P,"==(#T@)U!O;G1A($1E;&=A
M9&$@+R!.;W)D96QA($%C;W)E<R<["B1C;V]R9&EN871E<ULG4&]R='5G86PG
M75LG,S@N,#$W.BTW+C@V-R==(#T@)T)E:F$G.PHD8V]O<F1I;F%T97-;)U!O
M<G1U9V%L)UU;)S,X+C4Q-SHM,C@N-S$W)UT@/2`G2&]R=&$@+R!#87-T96QO
M($)R86YC;R!!8V]R97,G.PHD8V]O<F1I;F%T97-;)U!O<G1U9V%L)UU;)S,X
M+C<V-SHM,C<N,3`P)UT@/2`G3&%J97,@06-O<F5S)SL*)&-O;W)D:6YA=&5S
M6R=0;W)T=6=A;"==6R<S."XW-C<Z+3DN,3,S)UT@/2`G3&ES8F]A("\@4&]R
M=&5L82<["B1C;V]R9&EN871E<ULG4&]R='5G86PG75LG,SDN-#4P.BTS,2XQ
M,S,G72`]("=&;&]R97,@06-O<F5S)SL*)&-O;W)D:6YA=&5S6R=0;W)T=6=A
M;"==6R<T,2XR,S,Z+3@N-C@S)UT@/2`G4&]R=&\@+R!0961R87,@4G5B<F%S
M)SL*)&-O;W)D:6YA=&5S6R=0;W)T=6=A;"==6R<T,2XR-C<Z+3<N-S$W)UT@
M/2`G5FEL82!296%L)SL*)&-O;W)D:6YA=&5S6R=0;W)T=6=A;"==6R<T,2XX
M,#`Z+38N-S,S)UT@/2`G0G)A9V%N8V$G.PHD8V]O<F1I;F%T97-;)U%A=&%R
M)UU;)S(U+C(U,#HU,2XU-C<G72`]("=$;VAA($EN=&5R;F%T:6]N86P@06ER
M<&]R="<["B1C;V]R9&EN871E<ULG4F5U;FEO;B==6R<M,C`N.#@S.C4U+C4Q
M-R==(#T@)U-A:6YT+41E;FES("\@1VEL;&]T)SL*)&-O;W)D:6YA=&5S6R=2
M975N:6]N)UU;)RTR,2XS,S,Z-34N-#@S)UT@/2`G4V%I;G0M4&EE<G)E)SL*
M)&-O;W)D:6YA=&5S6R=2;VUA;FEA)UU;)S0T+C(S,SHR,RXX-C<G72`]("=#
M<F%I;W9A)SL*)&-O;W)D:6YA=&5S6R=2;VUA;FEA)UU;)S0T+C,S,SHR."XT
M,S,G72`]("=+;V=A;&YI8V5A;G4G.PHD8V]O<F1I;F%T97-;)U)O;6%N:6$G
M75LG-#0N-3`P.C(V+C$S,R==(#T@)T)U8W5R97-T:2`O($EM:"<["B1C;V]R
M9&EN871E<ULG4F]M86YI82==6R<T-"XU-3`Z,C8N,3`P)UT@/2`G0G5C=7)E
M<W1I($]T;W!E;FDG.PHD8V]O<F1I;F%T97-;)U)O;6%N:6$G75LG-#4N,3@S
M.C(X+C@Q-R==(#T@)U1U;&-E82<["B1C;V]R9&EN871E<ULG4F]M86YI82==
M6R<T-2XT,3<Z,C(N,C4P)UT@/2`G0V%R86YS96)E<R<["B1C;V]R9&EN871E
M<ULG4F]M86YI82==6R<T-2XW-C<Z,C$N,C4P)UT@/2`G5&EM:7-O87)A)SL*
M)&-O;W)D:6YA=&5S6R=2;VUA;FEA)UU;)S0U+C@P,#HR-"XQ-3`G72`]("=3
M:6)I=2<["B1C;V]R9&EN871E<ULG4F]M86YI82==6R<T-BXR,#`Z,C$N-#`P
M)UT@/2`G07)A9"<["B1C;V]R9&EN871E<ULG4F]M86YI82==6R<T-BXU,S,Z
M,C0N-3,S)UT@/2`G5&ER9W4@375R97,G.PHD8V]O<F1I;F%T97-;)U)O;6%N
M:6$G75LG-#8N-3@S.C(V+CDV-R==(#T@)T)A8V%U)SL*)&-O;W)D:6YA=&5S
M6R=2;VUA;FEA)UU;)S0V+C<X,SHR,RXU-C<G72`]("=#;'5J+4YA<&]C82<[
M"B1C;V]R9&EN871E<ULG4F]M86YI82==6R<T-RXP-3`Z,C$N.3,S)UT@/2`G
M3W)A9&5A)SL*)&-O;W)D:6YA=&5S6R=2;VUA;FEA)UU;)S0W+C$V-SHR-RXV
M,S,G72`]("=)87-I)SL*)&-O;W)D:6YA=&5S6R=2;VUA;FEA)UU;)S0W+C8U
M,#HR-BXR-3`G72`]("=3=6-E879A("\@4V%L8V5A)SL*)&-O;W)D:6YA=&5S
M6R=2;VUA;FEA)UU;)S0W+C8V-SHR,RXU.#,G72`]("="86EA($UA<F4G.PHD
M8V]O<F1I;F%T97-;)U)O;6%N:6$G75LG-#<N.#`P.C(R+C@X,R==(#T@)U-A
M='4@36%R92<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;
M)S0S+C$Q-SHQ,S$N.3,S)UT@/2`G5FQA9&EV;W-T;VLG.PHD8V]O<F1I;F%T
M97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<T,RXT,S,Z,SDN.3`P)UT@/2`G
M061L97(G.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<T
M-"XR,S,Z-#,N,#8W)UT@/2`G36EN97)A;%PG3GEE(%9O9'DG.PHD8V]O<F1I
M;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<T-2XP,S,Z,SDN,34P)UT@
M/2`G2W)A<VYO9&%R)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I
M;VXG75LG-#8N,S8W.C0T+C,S,R==(#T@)T5L:7-T82<["B1C;V]R9&EN871E
M<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S0V+CDU,#HQ-#(N-S$W)UT@/2`G
M675Z:&YO+5-A:VAA;&EN<VLG.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D
M97)A=&EO;B==6R<T-RXR-C<Z,SDN.#$W)UT@/2`G4F]S=&]V+4YA+41O;G4G
M.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<T."XU,3<Z
M,3,U+C$V-R==(#T@)TAA8F%R;W9S:R<["B1C;V]R9&EN871E<ULG4G5S<VEA
M;B!&961E<F%T:6]N)UU;)S0X+C<X,SHT-"XS-C<G72`]("=6;VQG;V=R860G
M.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<T.2XT-3`Z
M,3,V+C4V-R==(#T@)U1R;VEC:V]E)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N
M($9E9&5R871I;VXG75LG-3$N-C4P.C,Y+C(U,"==(#T@)U9O<F]N97HG.PHD
M8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<U,2XX,S,Z,3`W
M+C8P,"==(#T@)U5L86XM561E)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E
M9&5R871I;VXG75LG-3(N,#@S.C$Q,RXT.#,G72`]("=#:&ET82<["B1C;V]R
M9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S4R+C$V-SHQ,#DN-S@S
M)UT@/2`G2&]R:6YS:R<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T
M:6]N)UU;)S4R+C(V-SHQ,#0N,S$W)UT@/2`G27)K=71S:R<["B1C;V]R9&EN
M871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S4R+C@Q-SHQ,#0N-S8W)UT@
M/2`G57-T7"=/<F1Y;G-K:6HG.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D
M97)A=&EO;B==6R<U,RXP-C<Z,3,R+CDX,R==(#T@)T5K:6UC:&%N)SL*)&-O
M;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG-3,N,#@S.C$U."XU
M.#,G72`]("=0971R;W!A=FQO=G-K+4MA;6-H871S:VEJ)SL*)&-O;W)D:6YA
M=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG-3,N,3$W.C0U+C`Q-R==(#T@
M)U!E;GIA)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG
M-3,N,C`P.C4P+C$U,"==(#T@)U-A;6%R82<["B1C;V]R9&EN871E<ULG4G5S
M<VEA;B!&961E<F%T:6]N)UU;)S4S+C(U,#HS-"XS,3<G72`]("="<FIA;G-K
M)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG-3,N-#,S
M.C@S+C4Q-R==(#T@)T)A<FYA=6PG.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@
M1F5D97)A=&EO;B==6R<U-"XX.#,Z.3DN,#,S)UT@/2`G3FEZ:&YE=61I;G-K
M)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG-34N,#@S
M.C@R+CDP,"==(#T@)TYO=F]S:6)I<G-K)SL*)&-O;W)D:6YA=&5S6R=2=7-S
M:6%N($9E9&5R871I;VXG75LG-38N,S4P.C,P+C8Q-R==(#T@)U9E;&EK:64@
M3'5K:2<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S4V
M+C@S,SHQ,C0N.#8W)UT@/2`G0W5L7"=-86XG.PHD8V]O<F1I;F%T97-;)U)U
M<W-I86X@1F5D97)A=&EO;B==6R<U-BXX,S,Z-C`N-C,S)UT@/2`G16MA=&5R
M:6YB=7)G)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG
M-38N.3`P.C,U+C@X,R==(#T@)U1V97(G.PHD8V]O<F1I;F%T97-;)U)U<W-I
M86X@1F5D97)A=&EO;B==6R<U-RXW-C<Z,3`X+C`V-R==(#T@)TMI<F5N<VLG
M.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<U-RXX-3`Z
M,3$T+C(S,R==(#T@)T)O9&%J8F\G.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@
M1F5D97)A=&EO;B==6R<U."XT-3`Z.3(N,34P)UT@/2`G16YI<V5J<VLG.PHD
M8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<U.2XS,3<Z,SDN
M.3$W)UT@/2`G5F]L;V=D82<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E
M<F%T:6]N)UU;)S4Y+C4U,#HQ-3`N-S@S)UT@/2`G36%G861A;B<["B1C;V]R
M9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S4Y+C@X,SHT,BXW-3`G
M72`]("=4;W1<)TUA)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I
M;VXG75LG-3DN.38W.C,P+C,P,"==(#T@)U-T+B!0971E<F)U<F<G.PHD8V]O
M<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<V,2XP,3<Z-CDN,#,S
M)UT@/2`G2&%N='DM36%N<VEJ<VLG.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@
M1F5D97)A=&EO;B==6R<V,2XR,S,Z-#8N-S$W)UT@/2`G2V]T;&%S)SL*)&-O
M;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG-C$N,C4P.C<S+C4P
M,"==(#T@)U-U<F=U="<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T
M:6]N)UU;)S8Q+C8X,SHU,RXV.#,G72`]("=5<W1<)RT@2W5L;VTG.PHD8V]O
M<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<V,2XW,3<Z-3`N.#,S
M)UT@/2`G4WEK='EV:V%R)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R
M871I;VXG75LG-C(N,#$W.C$R.2XW,3<G72`]("=*86MU='-K)SL*)&-O;W)D
M:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG-C0N-#$W.BTQ-S,N,C,S
M)UT@/2`G0G5H=&$@4')O=FED96YJ82<["B1C;V]R9&EN871E<ULG4G5S<VEA
M;B!&961E<F%T:6]N)UU;)S8T+C4P,#HT,"XW,S,G72`]("=!<FAA;F=E;%PG
M4VLG.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<V-"XW
M.#,Z,3<W+C4V-R==(#T@)T%N861Y<B<["B1C;V]R9&EN871E<ULG4G5S<VEA
M;B!&961E<F%T:6]N)UU;)S8X+CDV-SHS,RXP-3`G72`]("=-=7)M86YS:R<[
M"B1C;V]R9&EN871E<ULG4G=A;F1A)UU;)RTQ+C8V-SHR.2XR-3`G72`]("='
M:7-E;GEI)SL*)&-O;W)D:6YA=&5S6R=2=V%N9&$G75LG+3$N.38W.C,P+C$Q
M-R==(#T@)TMI9V%L:2<["B1C;V]R9&EN871E<ULG4V%I;G0@2&5L96YA)UU;
M)RTW+CDV-SHM,30N-#`P)UT@/2`G5VED92!!=V%K92!&:65L9"!!<V-E;G-I
M;VX@27-L86YD)SL*)&-O;W)D:6YA=&5S6R=386EN="!+:71T<R!A;F0@3F5V
M:7,G75LG,3<N,S`P.BTV,BXV.#,G72`]("=';VQD96X@4F]C:R<["B1C;V]R
M9&EN871E<ULG4V%I;G0@3'5C:6$G75LG,3,N-S4P.BTV,"XY-3`G72`]("=(
M97=A;F]R<F$@26YT97)N871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S
M6R=386EN="!,=6-I82==6R<Q-"XP,3<Z+38Q+C`P,"==(#T@)U9I9VEE)SL*
M)&-O;W)D:6YA=&5S6R=386EN="!0:65R<F4@86YD($UI<75E;&]N)UU;)S0V
M+C<V-SHM-38N,38W)UT@/2`G4V%I;G0M4&EE<G)E)SL*)&-O;W)D:6YA=&5S
M6R=386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R==6R<Q,RXQ,S,Z
M+38Q+C(P,"==(#T@)T%R;F]S(%9A;&4G.PHD8V]O<F1I;F%T97-;)U-A;6]A
M)UU;)RTQ,RXX,#`Z+3$W,2XW.#,G72`]("=!<&EA("\@57!O;'4@27-L86YD
M)SL*)&-O;W)D:6YA=&5S6R=386UO82==6R<M,3,N.#$W.BTQ-S(N,#`P)UT@
M/2`G1F%L96]L;R!);G1L("\@07!I82<["B1C;V]R9&EN871E<ULG4V%O(%1O
M;64@86YD(%!R:6YC:7!E)UU;)S`N,S@S.C8N-S$W)UT@/2`G4RX@5&]M92<[
M"B1C;V]R9&EN871E<ULG4V%O(%1O;64@86YD(%!R:6YC:7!E)UU;)S$N-C4P
M.C<N-#$W)UT@/2`G4')I;F-I<&4G.PHD8V]O<F1I;F%T97-;)U-A=61I($%R
M86)I82==6R<Q-BXY,#`Z-#(N-3@S)UT@/2`G1VEZ86XG.PHD8V]O<F1I;F%T
M97-;)U-A=61I($%R86)I82==6R<Q-RXT-C<Z-#<N,3$W)UT@/2`G4VAA<G5R
M86@G.PHD8V]O<F1I;F%T97-;)U-A=61I($%R86)I82==6R<Q-RXV,3<Z-#0N
M-#$W)UT@/2`G3F%J<F%N)SL*)&-O;W)D:6YA=&5S6R=3875D:2!!<F%B:6$G
M75LG,3@N,C,S.C0R+C8U,"==(#T@)T%B:&$G.PHD8V]O<F1I;F%T97-;)U-A
M=61I($%R86)I82==6R<Q."XS,#`Z-#(N.#`P)UT@/2`G2VAA;6ES($UU<VAA
M:70G.PHD8V]O<F1I;F%T97-;)U-A=61I($%R86)I82==6R<Q.2XY.#,Z-#(N
M-C$W)UT@/2`G0FES:&$G.PHD8V]O<F1I;F%T97-;)U-A=61I($%R86)I82==
M6R<R,"XS,#`Z-#$N-C,S)UT@/2`G06P@0F%H82<["B1C;V]R9&EN871E<ULG
M4V%U9&D@07)A8FEA)UU;)S(P+C4P,#HT-2XR,#`G72`]("=7861I($%L($1A
M=V%S<V5R($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U-A=61I($%R86)I82==
M6R<R,2XT,S,Z,SDN-S8W)UT@/2`G36%K:V%H)SL*)&-O;W)D:6YA=&5S6R=3
M875D:2!!<F%B:6$G75LG,C$N-#@S.C0P+C4U,"==(#T@)U1A:68G.PHD8V]O
M<F1I;F%T97-;)U-A=61I($%R86)I82==6R<R,2XU,#`Z,SDN,C`P)UT@/2`G
M2F5D9&%H)SL*)&-O;W)D:6YA=&5S6R=3875D:2!!<F%B:6$G75LG,C$N-S`P
M.C,Y+C$X,R==(#T@)TIE9&1A:"!+:6YG($%B9'5L($%Z:7H@26YT97)N871I
M;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=3875D:2!!<F%B:6$G75LG
M,C0N,34P.C,X+C`V-R==(#T@)UEE;F)O)SL*)&-O;W)D:6YA=&5S6R=3875D
M:2!!<F%B:6$G75LG,C0N-3`P.C0T+C,U,"==(#T@)T1A=V%D;6DG.PHD8V]O
M<F1I;F%T97-;)U-A=61I($%R86)I82==6R<R-"XU-3`Z,SDN-S`P)UT@/2`G
M36%D:6YA:"<["B1C;V]R9&EN871E<ULG4V%U9&D@07)A8FEA)UU;)S(T+C<Q
M-SHT-BXW,S,G72`]("=2:7EA9&@G.PHD8V]O<F1I;F%T97-;)U-A=61I($%R
M86)I82==6R<R-"XY,S,Z-#8N-S$W)UT@/2`G2VEN9R!+:&%L960@26YT97)N
M871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=3875D:2!!<F%B:6$G
M75LG,C4N,S`P.C0Y+C0X,R==(#T@)T%L($%H<V$G.PHD8V]O<F1I;F%T97-;
M)U-A=61I($%R86)I82==6R<R-BXR,#`Z,S8N-#8W)UT@/2`G5V5J:"<["B1C
M;V]R9&EN871E<ULG4V%U9&D@07)A8FEA)UU;)S(V+C(V-SHU,"XQ-3`G72`]
M("=$:&%H<F%N)SL*)&-O;W)D:6YA=&5S6R=3875D:2!!<F%B:6$G75LG,C8N
M,S`P.C0S+C<V-R==(#T@)T=A<W-I;2<["B1C;V]R9&EN871E<ULG4V%U9&D@
M07)A8FEA)UU;)S(V+C0V-SHT.2XW.#,G72`]("=$86UM86TM2VEN9R!&86AD
M($EN=&5R;F%T:6]N86P@06ER<&]R="<["B1C;V]R9&EN871E<ULG4V%U9&D@
M07)A8FEA)UU;)S(W+C0S,SHT,2XV.#,G72`]("=(86EL)SL*)&-O;W)D:6YA
M=&5S6R=3875D:2!!<F%B:6$G75LG,C<N.3`P.C0U+C4S,R==(#T@)TAA9G(@
M06PM0F%T:6XG.PHD8V]O<F1I;F%T97-;)U-A=61I($%R86)I82==6R<R."XS
M,3<Z-#8N,3$W)UT@/2`G06P@46%Y<W5M86@G.PHD8V]O<F1I;F%T97-;)U-A
M=61I($%R86)I82==6R<R."XS-C<Z,S8N-C`P)UT@/2`G5&%B=6LG.PHD8V]O
M<F1I;F%T97-;)U-A=61I($%R86)I82==6R<R.2XV,3<Z-#,N-#@S)UT@/2`G
M4F%F:&$G.PHD8V]O<F1I;F%T97-;)U-A=61I($%R86)I82==6R<R.2XW.#,Z
M-#`N,3`P)UT@/2`G06PM2F]U9B<["B1C;V]R9&EN871E<ULG4V%U9&D@07)A
M8FEA)UU;)S,P+CDP,#HT,2XQ,S,G72`]("=!<F%R)SL*)&-O;W)D:6YA=&5S
M6R=3875D:2!!<F%B:6$G75LG,S$N-#`P.C,W+C(V-R==(#T@)T=U<FEA="<[
M"B1C;V]R9&EN871E<ULG4V%U9&D@07)A8FEA)UU;)S,Q+C8X,SHS."XW,S,G
M72`]("=4=7)A:68G.PHD8V]O<F1I;F%T97-;)U-E;F5G86PG75LG,3(N-#`P
M.BTQ-BXW-3`G72`]("=#87`M4VMI<G)I;F<G.PHD8V]O<F1I;F%T97-;)U-E
M;F5G86PG75LG,3(N-34P.BTQ-BXR-C<G72`]("=::6=U:6YC:&]R)SL*)&-O
M;W)D:6YA=&5S6R=396YE9V%L)UU;)S$R+C4V-SHM,3(N,C$W)UT@/2`G2V5D
M;W5G;W4G.PHD8V]O<F1I;F%T97-;)U-E;F5G86PG75LG,3(N.#@S.BTQ-"XY
M-C<G72`]("=+;VQD82<["B1C;V]R9&EN871E<ULG4V5N96=A;"==6R<Q,RXW
M-C<Z+3$S+C8X,R==(#T@)U1A;6)A8V]U;F1A)SL*)&-O;W)D:6YA=&5S6R=3
M96YE9V%L)UU;)S$T+C$S,SHM,38N,#8W)UT@/2`G2V%O;&%C:R<["B1C;V]R
M9&EN871E<ULG4V5N96=A;"==6R<Q-"XV-3`Z+3$V+C(S,R==(#T@)T1I;W5R
M8F5L)SL*)&-O;W)D:6YA=&5S6R=396YE9V%L)UU;)S$T+C<S,SHM,3<N-3`P
M)UT@/2`G1&%K87(@+R!9;V9F)SL*)&-O;W)D:6YA=&5S6R=396YE9V%L)UU;
M)S$U+C,X,SHM,34N,3$W)UT@/2`G3&EN9W5E<F4G.PHD8V]O<F1I;F%T97-;
M)U-E;F5G86PG75LG,34N-C4P.BTQ,RXR-3`G72`]("=-871A;2<["B1C;V]R
M9&EN871E<ULG4V5N96=A;"==6R<Q-BXP-3`Z+3$V+C0U,"==(#T@)U-A:6YT
M+4QO=6ES)SL*)&-O;W)D:6YA=&5S6R=396YE9V%L)UU;)S$V+C8U,#HM,30N
M.38W)UT@/2`G4&]D;W(G.PHD8V]O<F1I;F%T97-;)U-E>6-H96QL97,G75LG
M+30N-C8W.C4U+C4Q-R==(#T@)U-E>6-H96QL97,@26YT97(M3F%T:6]N86P@
M06ER<&]R="<["B1C;V]R9&EN871E<ULG4V5Y8VAE;&QE<R==6R<M-"XV.#,Z
M-34N-3,S)UT@/2`G4V5Y8VAE;&QE<R!);G1E<FYA=&EO;F%L($%I<G!O<G0@
M4F%W:6YS;VYD92!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=3:65R<F$@3&5O
M;F4G75LG."XV,3<Z+3$S+C(P,"==(#T@)TQU;F=I)SL*)&-O;W)D:6YA=&5S
M6R=3:6YG87!O<F4G75LG,2XS-C<Z,3`S+CDQ-R==(#T@)U-I;F=A<&]R92`O
M(%!A>6$@3&5B87(G.PHD8V]O<F1I;F%T97-;)U-I;F=A<&]R92==6R<Q+C,V
M-SHQ,#,N.3@S)UT@/2`G4VEN9V%P;W)E("\@0VAA;F=I($%I<G!O<G0G.PHD
M8V]O<F1I;F%T97-;)U-L;W9A:VEA)UU;)S0X+C(P,#HQ-RXR,#`G72`]("="
M<F%T:7-L879A($EV86YK82<["B1C;V]R9&EN871E<ULG4VQO=F%K:6$G75LG
M-#@N,S,S.C$Y+C<S,R==(#T@)TQU8V5N96,G.PHD8V]O<F1I;F%T97-;)U-L
M;W9A:VEA)UU;)S0X+C8Q-SHQ-RXX,S,G72`]("=0:65S=&%N>2<["B1C;V]R
M9&EN871E<ULG4VQO=F%K:6$G75LG-#@N-C4P.C$Y+C$U,"==(#T@)U-L:6%C
M)SL*)&-O;W)D:6YA=&5S6R=3;&]V86MI82==6R<T."XV-C<Z,C$N,C$W)UT@
M/2`G2V]S:6-E)SL*)&-O;W)D:6YA=&5S6R=3;&]V86MI82==6R<T."XY,S,Z
M,C(N,#`P)UT@/2`G2V%M96YI8V$@3F%D($-I<F]C:&]U)SL*)&-O;W)D:6YA
M=&5S6R=3;&]V86MI82==6R<T.2XP-C<Z,C`N,C4P)UT@/2`G4&]P<F%D("\@
M5&%T<GDG.PHD8V]O<F1I;F%T97-;)U-L;W9E;FEA)UU;)S0U+C0X,SHQ,RXV
M,3<G72`]("=0;W)T;W)O>B`O(%-E8V]V;&IE)SL*)&-O;W)D:6YA=&5S6R=3
M;&]V96YI82==6R<T-2XU,3<Z,3,N-38W)UT@/2`G4&]R=&]R;WHG.PHD8V]O
M<F1I;F%T97-;)U-L;W9E;FEA)UU;)S0V+C(Q-SHQ-"XT.#,G72`]("=,:G5B
M;&IA;F$@+R!"<FYI:R<["B1C;V]R9&EN871E<ULG4VQO=F5N:6$G75LG-#8N
M,C$W.C$T+C0X,R==(#T@)TQJ=6)L:F%N82`O($)R;FEK)SL*)&-O;W)D:6YA
M=&5S6R=3;&]V96YI82==6R<T-BXT.#,Z,34N-C@S)UT@/2`G36%R:6)O<B`O
M(%-L:79N:6-A)SL*)&-O;W)D:6YA=&5S6R=3;&]V96YI82==6R<T-BXV-3`Z
M,38N,3@S)UT@/2`G375R<VMA(%-O8F]T82<["B1C;V]R9&EN871E<ULG4V]L
M;VUO;B!)<VQA;F1S)UU;)RTQ,"XW,#`Z,38U+C@P,"==(#T@)U-A;G1A($-R
M=7HG.PHD8V]O<F1I;F%T97-;)U-O;&]M;VX@27-L86YD<R==6R<M."XS,S,Z
M,34W+C(V-R==(#T@)TUU;F1A)SL*)&-O;W)D:6YA=&5S6R=3;VQO;6]N($ES
M;&%N9',G75LG+3DN-#$W.C$V,"XP-3`G72`]("=(;VYI87)A("\@2&5N9&5R
M<V]N)SL*)&-O;W)D:6YA=&5S6R=3;VUA;&EA)UU;)S$P+C0Q-SHT-2XP,3<G
M72`]("="97)B97)A)SL*)&-O;W)D:6YA=&5S6R=3;VUA;&EA)UU;)S(N,#,S
M.C0U+C,U,"==(#T@)TUO9V%D:7-C:6\G.PHD8V]O<F1I;F%T97-;)U-O;6%L
M:6$G75LG-"XW,#`Z-#4N,C$W)UT@/2`G0F5L970@565N)SL*)&-O;W)D:6YA
M=&5S6R=3;VUA;&EA)UU;)SDN-3`P.C0T+C`X,R==(#T@)TAA<F=E:7-A)SL*
M)&-O;W)D:6YA=&5S6R=3;VUA;&EA)UU;)SDN-3`P.C0U+C4V-R==(#T@)T)U
M<F%O)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3(S+C<R-CHR
M-RXV.#@G72`]("=%;&QI<W)A<R<["B1C;V]R9&EN871E<ULG4V]U=&@@069R
M:6-A)UU;)RTR,RXX-C<Z,CDN-#4P)UT@/2`G4&EE=&5R<V)U<F<G.PHD8V]O
M<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M,C,N.3,S.C,Q+C$U,"==(#T@
M)U!H86QA8F]R=V$G.PHD8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M
M,C0N,S8W.C,Q+C`S,R==(#T@)TAO961S<')U:70G.PHD8V]O<F1I;F%T97-;
M)U-O=71H($%F<FEC82==6R<M,C4N-#,S.C,P+CDX,R==(#T@)TYE;'-P<G5I
M="<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTR-2XW,S,Z,C@N
M,3@S)UT@/2`G4')E=&]R:6$G.PHD8V]O<F1I;F%T97-;)U-O=71H($%F<FEC
M82==6R<M,C4N-S@S.C(U+C4S,R==(#T@)TUM86)A=&AO($%I<G!O<G0G.PHD
M8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M,C4N.#,S.C(X+C(Q-R==
M(#T@)U=A=&5R:VQO;V8@3&UB)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I
M8V$G75LG+3(U+CDQ-SHR."XR,3<G72`]("=0<F5T;W)I82!)<F5N92<["B1C
M;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTR-BXP-C<Z,S`N,3$W)UT@
M/2`G0V%R;VQI;F$G.PHD8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M
M,C8N,3,S.C(X+C(S,R==(#T@)TIA;B!3;75T<R<["B1C;V]R9&EN871E<ULG
M4V]U=&@@069R:6-A)UU;)RTR-BXX-C<Z,C8N-S$W)UT@/2`G2VQE<FMS9&]R
M<"<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTR-BXY-3`Z,C0N
M-C,S)UT@/2`G5G)Y8G5R9R<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A
M)UU;)RTR-RXR-C<Z,C@N-3`P)UT@/2`G1G)A;FMF;W)T)SL*)&-O;W)D:6YA
M=&5S6R=3;W5T:"!!9G)I8V$G75LG+3(X+C`P,#HR-BXV-C<G72`]("=796QK
M;VTG.PHD8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M,C@N,C4P.C(X
M+C,S,R==(#T@)T)E=&AL96AE;2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=3
M;W5T:"!!9G)I8V$G75LG+3(X+C0P,#HR,2XR-C<G72`]("=5<&EN9W1O;B<[
M"B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTR."XU-C<Z,38N-3,S
M)UT@/2`G06QE>&%N9&5R($)A>2<["B1C;V]R9&EN871E<ULG4V]U=&@@069R
M:6-A)UU;)RTR."XU-C<Z,CDN-S8W)UT@/2`G3&%D>7-M:71H)SL*)&-O;W)D
M:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3(X+C@P,#HR-"XW-C<G72`]("=+
M:6UB97)L97DG.PHD8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M,C@N
M.#`P.C,R+C$P,"==(#T@)U)I8VAA<F0@0F%Y)SL*)&-O;W)D:6YA=&5S6R=3
M;W5T:"!!9G)I8V$G75LG+3(Y+C$P,#HR-BXS,#`G72`]("=";&]E;69O;G1E
M:6X@2BX@0BX@32X@2&5R='IO9R<["B1C;V]R9&EN871E<ULG4V]U=&@@069R
M:6-A)UU;)RTR.2XV-C<Z,3<N.#8W)UT@/2`G4W!R:6YG8F]K)SL*)&-O;W)D
M:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3(Y+CDV-SHS,"XY-3`G72`]("=$
M=7)B86X@3&]U:7,@0F]T:&$G.PHD8V]O<F1I;F%T97-;)U-O=71H($%F<FEC
M82==6R<M,S`N-C,S.C(S+CDQ-R==(#T@)T1E($%A<B<["B1C;V]R9&EN871E
M<ULG4V]U=&@@069R:6-A)UU;)RTS,"XV-3`Z,C0N,#$W)UT@/2`G1&4@06%R
M)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3,P+C<Q-SHR-BXW
M,3<G72`]("=!;&EW86P@3F]R=&@G.PHD8V]O<F1I;F%T97-;)U-O=71H($%F
M<FEC82==6R<M,S$N-#8W.C$Y+C<V-R==(#T@)T-A;'9I;FEA)SL*)&-O;W)D
M:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3,Q+C0X,SHR-2XP,S,G72`]("=-
M:61D96QB=7)G)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3,Q
M+C4S,SHR."XV-C<G72`]("=5;71A=&$G.PHD8V]O<F1I;F%T97-;)U-O=71H
M($%F<FEC82==6R<M,S$N-C,S.C(Y+C4U,"==(#T@)U!O<G0@4W0@2F]H;G,G
M.PHD8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M,S$N-C8W.C$X+C4P
M,"==(#T@)U9R961E;F1A;"<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A
M)UU;)RTS,2XY,#`Z,C8N.#8W)UT@/2`G475E96YS=&]W;B<["B1C;V]R9&EN
M871E<ULG4V]U=&@@069R:6-A)UU;)RTS,2XY,3<Z,C$N-3$W)UT@/2`G1G)A
M<V5R8G5R9R<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTS,BXR
M-3`Z,C0N-3,S)UT@/2`G1W)A869F(%)E:6YE="<["B1C;V]R9&EN871E<ULG
M4V]U=&@@069R:6-A)UU;)RTS,BXS-3`Z,C(N-3@S)UT@/2`G0F5A=69O<G0@
M5V5S="<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTS,BXY-C<Z
M,3@N,38W)UT@/2`G3&%N9V5B86%N=V5G)SL*)&-O;W)D:6YA=&5S6R=3;W5T
M:"!!9G)I8V$G75LG+3,S+C`S,SHR-RXX,S,G72`]("=%87-T($QO;F1O;B<[
M"B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTS,RXU-C<Z,C(N,C$W
M)UT@/2`G3W5D='-H;V]R;B<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A
M)UU;)RTS,RXY.#,Z,3@N-C`P)UT@/2`G0V%P92!4;W=N($0N($8N($UA;&%N
M)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3,S+CDX,SHR-2XV
M,#`G72`]("=0;W)T($5L:7IA8F5T:"<["B1C;V]R9&EN871E<ULG4V]U=&@@
M069R:6-A)UU;)RTS-"XP,#`Z,C(N,S@S)UT@/2`G1V5O<F=E($%I<G!O<G0G
M.PHD8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M,S0N,3@S.C(R+C$U
M,"==(#T@)TUO<W-E;"!"87D@0V%P92!386EN="!";&%I>F4G.PHD8V]O<F1I
M;F%T97-;)U-O=71H($%F<FEC82==6R<M,S<N,#4P.BTQ,BXS,3<G72`]("=4
M<FES=&%N($1A($-U;FAA)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G
M75LG+30P+C,U,#HM.2XX.#,G72`]("=';W5G:"!)<VQA;F0G.PHD8V]O<F1I
M;F%T97-;)U-O=71H($%F<FEC82==6R<M-#8N.#@S.C,W+C@V-R==(#T@)TUA
M<FEO;B!)<VQA;F0G.PHD8V]O<F1I;F%T97-;)U-O=71H($=E;W)G:6$@86YD
M('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S)UU;)RTU,2XX,3<Z+34X+C0U
M,"==(#T@)TUO=6YT(%!L96%S86YT($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;
M)U-P86EN)UU;)S(W+C@Q-SHM,3<N.#@S)UT@/2`G2&EE<G)O("\@065R;W!U
M97)T;R<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG,C<N.3,S.BTQ-2XS.#,G
M72`]("=,87,@4&%L;6%S($1E($=R86X@0V%N87)I82`O($=A;F1O)SL*)&-O
M;W)D:6YA=&5S6R=3<&%I;B==6R<R."XP-3`Z+3$V+C4V-R==(#T@)U1E;F5R
M:69E(%-U<B<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG,C@N-#4P.BTQ,RXX
M-C<G72`]("=&=65R=&5V96YT=7)A("\@065R;W!U97)T;R<["B1C;V]R9&EN
M871E<ULG4W!A:6XG75LG,C@N-#8W.BTQ-BXS,3<G72`]("=496YE<FEF92`O
M($QO<R!2;V1E;W,G.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;)S(X+C8Q-SHM
M,3<N-S4P)UT@/2`G3&$@4&%L;6$@+R!!97)O<'5E<G1O)SL*)&-O;W)D:6YA
M=&5S6R=3<&%I;B==6R<R."XY-3`Z+3$S+C8P,"==(#T@)TQA;GIA<F]T92`O
M($%E<F]P=65R=&\G.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;)S,U+C(X,SHM
M,BXY-3`G72`]("=-96QI;&QA)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<S
M-BXV-3`Z+38N,S4P)UT@/2`G4F]T82<["B1C;V]R9&EN871E<ULG4W!A:6XG
M75LG,S8N-C8W.BTT+C0X,R==(#T@)TUA;&%G82`O($%E<F]P=65R=&\G.PHD
M8V]O<F1I;F%T97-;)U-P86EN)UU;)S,V+C<U,#HM-BXP-C<G72`]("=*97)E
M>B!$92!,82!&<F]N=&5R86%E<F]P=65R=&\G.PHD8V]O<F1I;F%T97-;)U-P
M86EN)UU;)S,V+C@U,#HM,BXS.#,G72`]("=!;&UE<FEA("\@065R;W!U97)T
M;R<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG,S<N,34P.BTU+C8Q-R==(#T@
M)TUO<F]N($1E($QA($9R;VYT97)A)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==
M6R<S-RXQ.#,Z+3,N-S@S)UT@/2`G1W)A;F%D82`O($%E<F]P=65R=&\G.PHD
M8V]O<F1I;F%T97-;)U-P86EN)UU;)S,W+C0Q-SHM-2XY,#`G72`]("=3979I
M;&QA("\@4V%N(%!A8FQO)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<S-RXW
M.#,Z+3`N.#`P)UT@/2`G375R8VEA("\@4V%N($IA=FEE<B<["B1C;V]R9&EN
M871E<ULG4W!A:6XG75LG,S<N.#4P.BTT+C@U,"==(#T@)T-O<F1O8F$@+R!!
M97)O<'5E<G1O)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<S-RXY-3`Z+3$N
M,C,S)UT@/2`G375R8VEA("\@06QC86YT87)I;&QA)SL*)&-O;W)D:6YA=&5S
M6R=3<&%I;B==6R<S."XR.#,Z+3`N-34P)UT@/2`G06QI8V%N=&4@+R!%;"!!
M;'1E="<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG,S@N-3$W.BTU+C$Q-R==
M(#T@)TAI;F]J;W-A($1E;"!$=7%U92<["B1C;V]R9&EN871E<ULG4W!A:6XG
M75LG,S@N.#8W.C$N,S@S)UT@/2`G26)I>F$@+R!%<R!#;V1O;&$G.PHD8V]O
M<F1I;F%T97-;)U-P86EN)UU;)S,X+C@X,SHM-BXX,3<G72`]("="861A:F]Z
M("\@5&%L879E<F$@3&$@4F5A;"<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG
M,S@N.34P.BTQ+C@U,"==(#T@)T%L8F%C971E("\@3&]S($QL86YO<R<["B1C
M;V]R9&EN871E<ULG4W!A:6XG75LG,SDN-3`P.BTP+C0V-R==(#T@)U9A;&5N
M8VEA("\@065R;W!U97)T;R<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG,SDN
M-34P.C(N-S,S)UT@/2`G4&%L;6$@1&4@36%L;&]R8V$@+R!3;VX@4V%N($IU
M86XG.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;)S,Y+C@V-SHT+C(S,R==(#T@
M)TUE;F]R8V$@+R!-86AO;B<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG-#`N
M,S`P.BTS+C<Q-R==(#T@)TUA9')I9"`O($=E=&%F92<["B1C;V]R9&EN871E
M<ULG4W!A:6XG75LG-#`N,S@S.BTS+C<X,R==(#T@)TUA9')I9"`O($-U871R
M;R!6:65N=&]S)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<T,"XT-3`Z+3,N
M-34P)UT@/2`G36%D<FED("\@0F%R86IA<R<["B1C;V]R9&EN871E<ULG4W!A
M:6XG75LG-#`N-#@S.BTS+C0U,"==(#T@)TUA9')I9"`O(%1O<G)E:F]N)SL*
M)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<T,"XV-3`Z+3,N-S,S)UT@/2`G36%D
M<FDM0V]L;65N87(G.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;)S0P+CDS,SHM
M,2XS,#`G72`]("=#86QA;6]C:&$G.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;
M)S0P+CDU,#HM-2XU,#`G72`]("=386QA;6%N8V$@+R!-871A8V%N)SL*)&-O
M;W)D:6YA=&5S6R=3<&%I;B==6R<T,2XQ-3`Z,2XQ-C<G72`]("=2975S("\@
M065R;W!U97)T;R<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG-#$N,C@S.C(N
M,#8W)UT@/2`G0F%R8V5L;VYA("\@065R;W!U97)T;R<["B1C;V]R9&EN871E
M<ULG4W!A:6XG75LG-#$N-C8W.BTQ+C`Q-R==(#T@)UIA<F%G;WIA("\@065R
M;W!U97)T;R<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG-#$N-S$W.BTT+C@U
M,"==(#T@)U9A;&QA9&]L:60@+R!6:6QL86YU8FQA)SL*)&-O;W)D:6YA=&5S
M6R=3<&%I;B==6R<T,2XY,#`Z,BXW-C<G72`]("='97)O;F$@+R!#;W-T82!"
M<F%V82<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG-#(N,C$W.BTX+C8S,R==
M(#T@)U9I9V\@+R!096EN861O<B<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG
M-#(N,S8W.BTS+C8S,R==(#T@)T)U<F=O<R`O(%9I;&QA9G)I82<["B1C;V]R
M9&EN871E<ULG4W!A:6XG75LG-#(N-#4P.BTR+C,S,R==(#T@)TQO9W)O;F\@
M+R!!9V]N8VEL;&\G.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;)S0R+C4X,SHM
M-2XV-3`G72`]("=,96]N("\@5FER9V5N($1E;"!#86UI;F\G.PHD8V]O<F1I
M;F%T97-;)U-P86EN)UU;)S0R+C<V-SHM,2XV,S,G72`]("=086UP;&]N82`O
M($YO86EN)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<T,BXX.#,Z+3(N-S$W
M)UT@/2`G5FET;W)I82<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG-#(N.3`P
M.BTX+C0S,R==(#T@)U-A;G1I86=O("\@3&%B86-O;&QA)SL*)&-O;W)D:6YA
M=&5S6R=3<&%I;B==6R<T,RXS,#`Z+3(N.3,S)UT@/2`G0FEL8F%O("\@4V]N
M9&EC82<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG-#,N,S`P.BTX+C,X,R==
M(#T@)TQA($-O<G5N82`O($%L=F5D<F\G.PHD8V]O<F1I;F%T97-;)U-P86EN
M)UU;)S0S+C,U,#HM,2XX,#`G72`]("=386X@4V5B87-T:6%N("\@1G5E;G1E
M<G)A8FEA)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<T,RXT,S,Z+3,N.#$W
M)UT@/2`G4V%N=&%N9&5R("\@4&%R87EA<R<["B1C;V]R9&EN871E<ULG4W!A
M:6XG75LG-#,N-34P.BTV+C`S,R==(#T@)T%S='5R:6%S("\@079I;&5S)SL*
M)&-O;W)D:6YA=&5S6R=3<FD@3&%N:V$G75LG-BXX,3<Z-SDN.#@S)UT@/2`G
M4F%T;6%L86YA)SL*)&-O;W)D:6YA=&5S6R=3<FD@3&%N:V$G75LG-RXQ-C<Z
M-SDN.#@S)UT@/2`G2V%T=6YA>6%K92<["B1C;V]R9&EN871E<ULG4W)I($QA
M;FMA)UU;)S<N-S$W.C@Q+C<P,"==(#T@)T)A='1I8V%L;V$G.PHD8V]O<F1I
M;F%T97-;)U-R:2!,86YK82==6R<X+C,S,SHX,"XT,3<G72`]("=!;G5R861H
M87!U<F$G.PHD8V]O<F1I;F%T97-;)U-R:2!,86YK82==6R<X+C4X,SHX,2XR
M-3`G72`]("=4<FEN8V]M86QE92<["B1C;V]R9&EN871E<ULG4W5D86XG75LG
M,3$N,#`P.C(Y+C<Q-R==(#T@)TMA9'5G;&DG.PHD8V]O<F1I;F%T97-;)U-U
M9&%N)UU;)S$Q+C<U,#HS,BXW.#,G72`]("=296YK)SL*)&-O;W)D:6YA=&5S
M6R=3=61A;B==6R<Q,2XW.#,Z,S0N,S@S)UT@/2`G1&%M87II;F4G.PHD8V]O
M<F1I;F%T97-;)U-U9&%N)UU;)S$R+C`U,#HR-"XX.#,G72`]("=.>6%L82<[
M"B1C;V]R9&EN871E<ULG4W5D86XG75LG,3,N,38W.C,P+C(S,R==(#T@)T5L
M($]B96ED)SL*)&-O;W)D:6YA=&5S6R=3=61A;B==6R<Q,RXQ-C<Z,S(N-C8W
M)UT@/2`G2V]S=&DG.PHD8V]O<F1I;F%T97-;)U-U9&%N)UU;)S$S+C0X,SHR
M,BXT-3`G72`]("='96YE:6YA)SL*)&-O;W)D:6YA=&5S6R=3=61A;B==6R<Q
M,RXU-3`Z,S,N-C$W)UT@/2`G4V5N;F%R)SL*)&-O;W)D:6YA=&5S6R=3=61A
M;B==6R<Q,RXV,3<Z,C4N,S,S)UT@/2`G16P@1F%S:&5R)SL*)&-O;W)D:6YA
M=&5S6R=3=61A;B==6R<Q-"XP,S,Z,S4N-#`P)UT@/2`G1V5D87)E9B<["B1C
M;V]R9&EN871E<ULG4W5D86XG75LG,34N-#8W.C,V+C0P,"==(#T@)TMA<W-A
M;&$G.PHD8V]O<F1I;F%T97-;)U-U9&%N)UU;)S$U+C8P,#HS,BXU-3`G72`]
M("=+:&%R=&]U;2<["B1C;V]R9&EN871E<ULG4W5D86XG75LG,3<N-S`P.C,S
M+CDV-R==(#T@)T%T8F%R82<["B1C;V]R9&EN871E<ULG4W5D86XG75LG,3DN
M,38W.C,P+C0X,R==(#T@)T1O;F=O;&$G.PHD8V]O<F1I;F%T97-;)U-U9&%N
M)UU;)S$Y+C4X,SHS-RXR,3<G72`]("=0;W)T(%-U9&%N)SL*)&-O;W)D:6YA
M=&5S6R=3=61A;B==6R<R,2XX,3<Z,S$N-#@S)UT@/2`G5V%D:2!(86QF82<[
M"B1C;V]R9&EN871E<ULG4W5D86XG75LG-"XX-C<Z,S$N-C`P)UT@/2`G2G5B
M82<["B1C;V]R9&EN871E<ULG4W5D86XG75LG.2XU-3`Z,S$N-C4P)UT@/2`G
M36%L86MA;"<["B1C;V]R9&EN871E<ULG4W5R:6YA;64G75LG-2XT-3`Z+34U
M+C(P,"==(#T@)UIA;F1E<FEJ)SL*)&-O;W)D:6YA=&5S6R=3=V%Z:6QA;F0G
M75LG+3(V+C4S,SHS,2XS,#`G72`]("=-86YZ:6YI("\@36%T<V%P82!!:7)P
M;W)T)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG-34N-34P.C$S+C,V-R==
M(#T@)TUA;&UO("\@4W1U<G5P)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG
M-34N.3$W.C$T+C`X,R==(#T@)TMR:7-T:6%N<W1A9"`O($5V97)O9"<["B1C
M;V]R9&EN871E<ULG4W=E9&5N)UU;)S4V+C`X-3HQ,RXR,#<G72`]("=,:G5N
M9V)Y:&5D+"!,:G5N9V)Y:&5D("A35T4M049"*2<["B1C;V]R9&EN871E<ULG
M4W=E9&5N)UU;)S4V+C(V-SHQ-2XR.#,G72`]("=2;VYN96)Y)SL*)&-O;W)D
M:6YA=&5S6R=3=V5D96XG75LG-38N,S`P.C$R+C@U,"==(#T@)T%N9V5L:&]L
M;2<["B1C;V]R9&EN871E<ULG4W=E9&5N)UU;)S4V+C8X,SHQ,BXX,S,G72`]
M("=(86QM<W1A9"!3=V5D:7-H($%I<B!&;W)C92!"87-E)SL*)&-O;W)D:6YA
M=&5S6R=3=V5D96XG75LG-38N-S,S.C$V+C,P,"==(#T@)TMA;&UA<B<["B1C
M;V]R9&EN871E<ULG4W=E9&5N)UU;)S4V+C@U,#HQ-"XX,S,G72`]("=687AJ
M;R<["B1C;V]R9&EN871E<ULG4W=E9&5N)UU;)S4W+C,P,#HQ-"XQ,S,G72`]
M("=(86=S:'5L="<["B1C;V]R9&EN871E<ULG4W=E9&5N)UU;)S4W+C4Q-SHQ
M-2XX,S,G72`]("=(=6QT<V9R960@4W=E9&ES:"!!:7(@1F]R8V4@0F%S92<[
M"B1C;V]R9&EN871E<ULG4W=E9&5N)UU;)S4W+C8V-SHQ,BXS,#`G72`]("='
M;W1E8F]R9R`O($QA;F1V971T97(G.PHD8V]O<F1I;F%T97-;)U-W961E;B==
M6R<U-RXV-C<Z,3@N,S4P)UT@/2`G5FES8GD@1FQY9W!L871S)SL*)&-O;W)D
M:6YA=&5S6R=3=V5D96XG75LG-3<N-S8W.C$T+C`X,R==(#T@)TIO;FMO<&EN
M9R!&;'EG<&QA=',G.PHD8V]O<F1I;F%T97-;)U-W961E;B==6R<U-RXW.#,Z
M,3$N.#@S)UT@/2`G1V]T96)O<F<@+R!3879E)SL*)&-O;W)D:6YA=&5S6R=3
M=V5D96XG75LG-3@N-#`P.C$U+C4Q-R==(#T@)TQI;FMO<&EN9R`O($UA;&UE
M;B<["B1C;V]R9&EN871E<ULG4W=E9&5N)UU;)S4X+C0S,SHQ,BXW,#`G72`]
M("=3871E;F%S)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG-3@N-#4P.C$S
M+CDV-R==(#T@)U-K;W9D92!&;'EG<&QA=',G.PHD8V]O<F1I;F%T97-;)U-W
M961E;B==6R<U."XU.#,Z,38N,34P)UT@/2`G3F]R<FMO<&EN9R<["B1C;V]R
M9&EN871E<ULG4W=E9&5N)UU;)S4Y+C,U,#HQ-RXY-3`G72`]("=3=&]C:VAO
M;&T@+R!"<F]M;6$G.PHD8V]O<F1I;F%T97-;)U-W961E;B==6R<U.2XS-C<Z
M,3,N-#8W)UT@/2`G2V%R;'-T860@1FQY9W!L871S)SL*)&-O;W)D:6YA=&5S
M6R=3=V5D96XG75LG-3DN-3@S.C$V+C8S,R==(#T@)U9A<W1E<F%S("\@2&%S
M<VQO)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG-3DN-C4P.C$W+CDU,"==
M(#T@)U-T;V-K:&]L;2`O($%R;&%N9&$G.PHD8V]O<F1I;F%T97-;)U-W961E
M;B==6R<U.2XX.#,Z,3<N-C`P)UT@/2`G57!P<V%L82<["B1C;V]R9&EN871E
M<ULG4W=E9&5N)UU;)S8P+C0S,SHQ-2XU,3<G72`]("=";W)L86YG92<["B1C
M;V]R9&EN871E<ULG4W=E9&5N)UU;)S8P+C8P,#HQ-BXY-3`G72`]("='879L
M92`O(%-A;F1V:6ME;B!!:7(@1F]R8V4@0F%S92<["B1C;V]R9&EN871E<ULG
M4W=E9&5N)UU;)S8Q+C(V-SHQ-RXQ,#`G72`]("=3;V1E<FAA;6XG.PHD8V]O
M<F1I;F%T97-;)U-W961E;B==6R<V,BXU,S,Z,3<N-#4P)UT@/2`G4W5N9'-V
M86QL+4AA<FYO<V%N9"!&;'EG<&QA=',G.PHD8V]O<F1I;F%T97-;)U-W961E
M;B==6R<V,RXP-3`Z,3<N-S8W)UT@/2`G2W)A;69O<G,@1FQY9W!L871S)SL*
M)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG-C,N,3@S.C$T+C4P,"==(#T@)T]S
M=&5R<W5N9"`O($9R;W-O;B<["B1C;V]R9&EN871E<ULG4W=E9&5N)UU;)S8S
M+C0P,#HQ."XY-C<G72`]("=/<FYS:V]L9'-V:6L@06ER<&]R="<["B1C;V]R
M9&EN871E<ULG4W=E9&5N)UU;)S8S+C@P,#HR,"XR.#,G72`]("=5;65A($9L
M>6=P;&%T<R<["B1C;V]R9&EN871E<ULG4W=E9&5N)UU;)S8T+C8S,SHR,2XP
M.#,G72`]("=3:V5L;&5F=&5A($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U-W
M961E;B==6R<V-"XY-C<Z,3<N-S`P)UT@/2`G1W5N;F%R;B<["B1C;V]R9&EN
M871E<ULG4W=E9&5N)UU;)S8U+C4U,#HR,BXQ,S,G72`]("=,=6QE82`O($MA
M;&QA>"<["B1C;V]R9&EN871E<ULG4W=E9&5N)UU;)S8U+C@V-SHR,"XQ,S,G
M72`]("=6:61S96PG.PHD8V]O<F1I;F%T97-;)U-W961E;B==6R<V-BXV,S,Z
M,3DN-C4P)UT@/2`G2F]K:VUO:VLG.PHD8V]O<F1I;F%T97-;)U-W961E;B==
M6R<V-RXQ-3`Z,C`N-C4P)UT@/2`G1V%L;&EV87)E)SL*)&-O;W)D:6YA=&5S
M6R=3=V5D96XG75LG-C<N.#$W.C(P+C,S,R==(#T@)TMI<G5N82!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R=3=VET>F5R;&%N9"==6R<T-BXP,#`Z."XY-C<G
M72`]("=,=6=A;F\G.PHD8V]O<F1I;F%T97-;)U-W:71Z97)L86YD)UU;)S0V
M+C(Q-SHW+C,S,R==(#T@)U-I;VXG.PHD8V]O<F1I;F%T97-;)U-W:71Z97)L
M86YD)UU;)S0V+C(U,#HV+C$S,R==(#T@)T=E;F5V92U#;VEN=')I;B<["B1C
M;V]R9&EN871E<ULG4W=I='IE<FQA;F0G75LG-#8N-34P.C8N-C$W)UT@/2`G
M3&%U<V%N;F4G.PHD8V]O<F1I;F%T97-;)U-W:71Z97)L86YD)UU;)S0V+C@Q
M-SHV+CDU,"==(#T@)U!A>65R;F4G.PHD8V]O<F1I;F%T97-;)U-W:71Z97)L
M86YD)UU;)S0W+C`P,#HV+CDU,"==(#T@)TYE=6-H871E;"<["B1C;V]R9&EN
M871E<ULG4W=I='IE<FQA;F0G75LG-#<N,3@Q.C<N-#$V)UT@/2`G1W)E;F-H
M96XG.PHD8V]O<F1I;F%T97-;)U-W:71Z97)L86YD)UU;)S0W+C0X,SHX+C4S
M,R==(#T@)UIU<FEC:"U+;&]T96XG.PHD8V]O<F1I;F%T97-;)U-W:71Z97)L
M86YD)UU;)S0W+C0X-3HY+C4V,B==(#T@)U-A:6YT($=A;&QE;BU!;'1E;G)H
M96EN)SL*)&-O;W)D:6YA=&5S6R=3>7)I86X@07)A8B!297!U8FQI8R==6R<S
M,RXT,3<Z,S8N-3$W)UT@/2`G1&%M87-C=7,@26YT+B!!:7)P;W)T)SL*)&-O
M;W)D:6YA=&5S6R=3>7)I86X@07)A8B!297!U8FQI8R==6R<S-"XU-3`Z,S@N
M,S`P)UT@/2`G4&%L;7ER82<["B1C;V]R9&EN871E<ULG4WER:6%N($%R86(@
M4F5P=6)L:6,G75LG,S4N,S$W.C0P+C$U,"==(#T@)T1E:7(@17IZ;W(G.PHD
M8V]O<F1I;F%T97-;)U-Y<FEA;B!!<F%B(%)E<'5B;&EC)UU;)S,U+C4S,SHS
M-2XW-C<G72`]("=,871T86MI82<["B1C;V]R9&EN871E<ULG4WER:6%N($%R
M86(@4F5P=6)L:6,G75LG,S8N,3@S.C,W+C(P,"==(#T@)T%L97!P;R!);G1E
M<FYA=&EO;F%L($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U-Y<FEA;B!!<F%B
M(%)E<'5B;&EC)UU;)S,W+C`U,#HT,2XR,3<G72`]("=+86UI<VAL:2<["B1C
M;V]R9&EN871E<ULG5&%I=V%N)UU;)S(P+C8V-SHQ,38N-S$W)UT@/2`G1&]N
M9W-H82<["B1C;V]R9&EN871E<ULG5&%I=V%N)UU;)S(Q+CDS,SHQ,C`N.#,S
M)UT@/2`G2&5N9V-H=6XG.PHD8V]O<F1I;F%T97-;)U1A:7=A;B==6R<R,BXP
M,S,Z,3(Q+C4U,"==(#T@)TQA;B!9=2<["B1C;V]R9&EN871E<ULG5&%I=V%N
M)UU;)S(R+C0Q-SHQ,C`N-34P)UT@/2`G0VAI82!4=6YG)SL*)&-O;W)D:6YA
M=&5S6R=486EW86XG75LG,C(N-#8W.C$R,"XT,S,G72`]("=$;VYG9V%N9R<[
M"B1C;V]R9&EN871E<ULG5&%I=V%N)UU;)S(R+C4X,SHQ,C`N,S4P)UT@/2`G
M2V%O:'-I=6YG($EN=&5R;F%T:6]N86P@06ER<&]R="<["B1C;V]R9&EN871E
M<ULG5&%I=V%N)UU;)S(R+C8X,SHQ,C`N-#8W)UT@/2`G4&EN9W1U;F<@4V]U
M=&@@06ER($9O<F-E($)A<V4G.PHD8V]O<F1I;F%T97-;)U1A:7=A;B==6R<R
M,BXW,#`Z,3(P+C0X,R==(#T@)U!I;F=T=6YG($YO<G1H($%I<B!&;W)C92!"
M87-E)SL*)&-O;W)D:6YA=&5S6R=486EW86XG75LG,C(N-S@S.C$R,"XR-C<G
M72`]("=+86YG<VAA;B!4=RU!9F(G.PHD8V]O<F1I;F%T97-;)U1A:7=A;B==
M6R<R,BXX,#`Z,3(Q+C$X,R==(#T@)T-H:6AH86YG(%1W+4%F8B<["B1C;V]R
M9&EN871E<ULG5&%I=V%N)UU;)S(R+CDU,#HQ,C`N,C`P)UT@/2`G5&%I;F%N
M(%1W+4%F8B<["B1C;V]R9&EN871E<ULG5&%I=V%N)UU;)S(S+C(V-SHQ,3DN
M-C8W)UT@/2`G1&]N9W-H:2<["B1C;V]R9&EN871E<ULG5&%I=V%N)UU;)S(S
M+C0V-SHQ,C`N,S@S)UT@/2`G0VAI87EI(%1W+4%F8B<["B1C;V]R9&EN871E
M<ULG5&%I=V%N)UU;)S(S+C4X,SHQ,3DN-C$W)UT@/2`G36%K=6YG($%B)SL*
M)&-O;W)D:6YA=&5S6R=486EW86XG75LG,C0N,#,S.C$R,2XV,3<G72`]("=(
M=6QI96X@06(G.PHD8V]O<F1I;F%T97-;)U1A:7=A;B==6R<R-"XQ.#,Z,3(P
M+C8U,"==(#T@)U1A:6-H=6YG(%1W+4%F8B<["B1C;V]R9&EN871E<ULG5&%I
M=V%N)UU;)S(T+C(V-SHQ,C`N-C$W)UT@/2`G5W5C:&EA($]B<V5R=F%T;W)Y
M)SL*)&-O;W)D:6YA=&5S6R=486EW86XG75LG,C0N-#,S.C$Q."XS-C<G72`]
M("=#:&EN;65M("\@4VAA=&]U($%I<B!&;W)C92!"87-E)SL*)&-O;W)D:6YA
M=&5S6R=486EW86XG75LG,C0N-S4P.C$R,2XW-C<G72`]("=);&%N)SL*)&-O
M;W)D:6YA=&5S6R=486EW86XG75LG,C0N.#$W.C$R,"XY,S,G72`]("=(<VEN
M8VAU(%1W+4%F8B<["B1C;V]R9&EN871E<ULG5&%I=V%N)UU;)S(T+CDS,SHQ
M,C$N,S`P)UT@/2`G4&$@2W5E:2`O($)A:W5A:2<["B1C;V]R9&EN871E<ULG
M5&%I=V%N)UU;)S(U+C`V-SHQ,C$N,C,S)UT@/2`G5&%O>75A;B!!8B`](#4X
M.38U,"<["B1C;V]R9&EN871E<ULG5&%I=V%N)UU;)S(U+C`V-SHQ,C$N-34P
M)UT@/2`G4W5N9W-H86X@+R!486EP96DG.PHD8V]O<F1I;F%T97-;)U1A:7=A
M;B==6R<R-2XP.#,Z,3(Q+C(Q-R==(#T@)T-H:6%N9R!+86D@4VAE:R<["B1C
M;V]R9&EN871E<ULG5&%I=V%N)UU;)S(V+C$V-SHQ,3DN.3,S)UT@/2`G36%Z
M=2<["B1C;V]R9&EN871E<ULG5&%J:6MI<W1A;B==6R<S."XU-3`Z-C@N-S@S
M)UT@/2`G1'5S:&%N8F4G.PHD8V]O<F1I;F%T97-;)U1A;GIA;FEA+"!5;FET
M960@4F5P=6)L:6,@;V8G75LG+3$N,S,S.C,Q+C@Q-R==(#T@)T)U:V]B82<[
M"B1C;V]R9&EN871E<ULG5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B==
M6R<M,2XU,#`Z,S,N.#`P)UT@/2`G375S;VUA)SL*)&-O;W)D:6YA=&5S6R=4
M86YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F)UU;)RTQ,"XR-C<Z-#`N,3@S
M)UT@/2`G371W87)A)SL*)&-O;W)D:6YA=&5S6R=486YZ86YI82P@56YI=&5D
M(%)E<'5B;&EC(&]F)UU;)RTQ,"XS-3`Z,S@N-S4P)UT@/2`G3F%C:&EN9W=E
M82<["B1C;V]R9&EN871E<ULG5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O
M9B==6R<M,3`N-C@S.C,U+C4X,R==(#T@)U-O;F=E82<["B1C;V]R9&EN871E
M<ULG5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B==6R<M,BXT-C<Z,S(N
M.3$W)UT@/2`G37=A;GIA)SL*)&-O;W)D:6YA=&5S6R=486YZ86YI82P@56YI
M=&5D(%)E<'5B;&EC(&]F)UU;)RTS+C,S,SHS-BXV,3<G72`]("=!<G5S:&$G
M.PHD8V]O<F1I;F%T97-;)U1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8G
M75LG+3,N,S4P.C,W+C,S,R==(#T@)TUO<VAI)SL*)&-O;W)D:6YA=&5S6R=4
M86YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F)UU;)RTS+C0Q-SHS-RXP-C<G
M72`]("=+:6QI;6%N:F%R;R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=486YZ
M86YI82P@56YI=&5D(%)E<'5B;&EC(&]F)UU;)RTT+C`X,SHS-RXW,3<G72`]
M("=386UE)SL*)&-O;W)D:6YA=&5S6R=486YZ86YI82P@56YI=&5D(%)E<'5B
M;&EC(&]F)UU;)RTT+C@X,SHR.2XV,S,G72`]("=+:6=O;6$G.PHD8V]O<F1I
M;F%T97-;)U1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8G75LG+30N.#@S
M.C,X+C(X,R==(#T@)TUO;6)O)SL*)&-O;W)D:6YA=&5S6R=486YZ86YI82P@
M56YI=&5D(%)E<'5B;&EC(&]F)UU;)RTU+C`X,SHS,BXX,S,G72`]("=486)O
M<F$@06ER<&]R="<["B1C;V]R9&EN871E<ULG5&%N>F%N:6$L(%5N:71E9"!2
M97!U8FQI8R!O9B==6R<M-2XP.#,Z,SDN,#8W)UT@/2`G5&%N9V$G.PHD8V]O
M<F1I;F%T97-;)U1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8G75LG+34N
M,C4P.C,Y+C@Q-R==(#T@)U!E;6)A("\@2V%R=6UE($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)U1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8G75LG+38N
M,38W.C,U+C<V-R==(#T@)T1O9&]M82<["B1C;V]R9&EN871E<ULG5&%N>F%N
M:6$L(%5N:71E9"!297!U8FQI8R!O9B==6R<M-BXR,3<Z,SDN,C$W)UT@/2`G
M6F%N>FEB87(@+R!+:7-A=6YI)SL*)&-O;W)D:6YA=&5S6R=486YZ86YI82P@
M56YI=&5D(%)E<'5B;&EC(&]F)UU;)RTV+C@S,SHS-RXV-3`G72`]("=-;W)O
M9V]R;R<["B1C;V]R9&EN871E<ULG5&%N>F%N:6$L(%5N:71E9"!297!U8FQI
M8R!O9B==6R<M-BXX-C<Z,SDN,C`P)UT@/2`G1&%R($5S(%-A;&%A;2!!:7)P
M;W)T)SL*)&-O;W)D:6YA=&5S6R=486YZ86YI82P@56YI=&5D(%)E<'5B;&EC
M(&]F)UU;)RTW+C8V-SHS-2XW-3`G72`]("=)<FEN9V$G.PHD8V]O<F1I;F%T
M97-;)U1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8G75LG+3@N.3,S.C,S
M+C0V-R==(#T@)TUB97EA)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q
M,"XT.#,Z.3DN,3@S)UT@/2`G0VAU;7!H;VXG.PHD8V]O<F1I;F%T97-;)U1H
M86EL86YD)UU;)S$Q+C@S,SHY.2XX,S,G72`]("=0<F%C:'5A<"!+:&ER:6MH
M86XG.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)S$R+C4X,SHY.2XY-3`G
M72`]("=(=6$@2&EN)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q,BXV
M,#`Z,3`R+C$Q-R==(#T@)T-H86YT:&%B=7)I)SL*)&-O;W)D:6YA=&5S6R=4
M:&%I;&%N9"==6R<Q,BXV,S,Z,3`Q+C,U,"==(#T@)U)A>6]N9R<["B1C;V]R
M9&EN871E<ULG5&AA:6QA;F0G75LG,3,N,34P.C$P,"XP-C<G72`]("=0:&5T
M8VAA8G5R:2<["B1C;V]R9&EN871E<ULG5&AA:6QA;F0G75LG,3,N,S8W.C$P
M,"XY.#,G72`]("=#:&]N($)U<FDG.PHD8V]O<F1I;F%T97-;)U1H86EL86YD
M)UU;)S$S+CDQ-SHQ,#`N-C`P)UT@/2`G1&]N($UU86YG)SL*)&-O;W)D:6YA
M=&5S6R=4:&%I;&%N9"==6R<Q-"XP,3<Z.3DN-3,S)UT@/2`G2V%N8VAA;F%B
M=7)I)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q-"XP-3`Z,3`Q+C,V
M-R==(#T@)U!R86-H:6X@0G5R:2<["B1C;V]R9&EN871E<ULG5&AA:6QA;F0G
M75LG,30N.38W.C$P,BXP.#,G72`]("=.86MH;VX@4F%T8VAA<VEM82<["B1C
M;V]R9&EN871E<ULG5&AA:6QA;F0G75LG,34N,C4P.C$P-"XX-C<G72`]("=5
M8F]N(%)A=&-H871H86YI)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q
M-2XX,#`Z,3`P+C$V-R==(#T@)TYA:VAO;B!387=A;B<["B1C;V]R9&EN871E
M<ULG5&AA:6QA;F0G75LG,34N.#`P.C$P,BXP,S,G72`]("=#:&%I>6%P:'5M
M)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q-BXP-3`Z,3`S+C8X,R==
M(#T@)U)O:2!%="<["B1C;V]R9&EN871E<ULG5&AA:6QA;F0G75LG,38N-#,S
M.C$P,BXX,S,G72`]("=+:&]N($MA96XG.PHD8V]O<F1I;F%T97-;)U1H86EL
M86YD)UU;)S$V+C4S,SHQ,#0N-S$W)UT@/2`G375K9&%H86XG.PHD8V]O<F1I
M;F%T97-;)U1H86EL86YD)UU;)S$V+C8V-SHY."XU-3`G72`]("=-864@4V]T
M)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q-BXW.#,Z,3`P+C(V-R==
M(#T@)U!H:71S86YU;&]K)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q
M-BXX.#,Z.3DN,34P)UT@/2`G5&%K)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N
M9"==6R<Q-RXQ-3`Z,3`T+C$S,R==(#T@)U-A:V]N($YA:VAO;B<["B1C;V]R
M9&EN871E<ULG5&AA:6QA;F0G75LG,3<N,S@S.C$P,BXX,#`G72`]("=59&]N
M(%1H86YI)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q-RXT,3<Z,3`T
M+C<X,R==(#T@)TYA:VAO;B!0:&%N;VTG.PHD8V]O<F1I;F%T97-;)U1H86EL
M86YD)UU;)S$W+C0U,#HQ,#$N-S,S)UT@/2`G3&]E:2<["B1C;V]R9&EN871E
M<ULG5&AA:6QA;F0G75LG,3<N-C$W.C$P,"XQ,#`G72`]("=5='1A<F%D:70G
M.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)S$W+C@V-SHQ,#(N-S$W)UT@
M/2`G3F]N9R!+:&%I)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q."XQ
M-C<Z,3`P+C$V-R==(#T@)U!H<F%E)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N
M9"==6R<Q."XQ-C<Z.3<N.3,S)UT@/2`G36%E(%-A<FEA;F<G.PHD8V]O<F1I
M;F%T97-;)U1H86EL86YD)UU;)S$X+C(X,SHY.2XU,3<G72`]("=,86UP86YG
M)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q."XW-C<Z,3`P+C<V-R==
M(#T@)TYA;B<["B1C;V]R9&EN871E<ULG5&AA:6QA;F0G75LG,3@N-S@S.CDX
M+CDX,R==(#T@)T-H:6%N9R!-86DG.PHD8V]O<F1I;F%T97-;)U1H86EL86YD
M)UU;)S$Y+C,P,#HY-RXX,S,G72`]("=-864@2&]N9R!3;VXG.PHD8V]O<F1I
M;F%T97-;)U1H86EL86YD)UU;)S$Y+CDQ-SHY.2XX,S,G72`]("=#:&EA;F<@
M4F%I)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<V+C8U,#HQ,#`N,#@S
M)UT@/2`G4V%T=6XG.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)S8N-S@S
M.C$P,2XQ-3`G72`]("=0871T86YI)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N
M9"==6R<V+CDQ-SHQ,#`N-#,S)UT@/2`G2&%T(%EA:2<["B1C;V]R9&EN871E
M<ULG5&AA:6QA;F0G75LG-RXR,#`Z,3`P+C8P,"==(#T@)U-O;F=K:&QA)SL*
M)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<W+C4Q-SHY.2XV,3<G72`]("=4
M<F%N9R<["B1C;V]R9&EN871E<ULG5&AA:6QA;F0G75LG."XQ,3<Z.3@N,S$W
M)UT@/2`G4&AU:V5T($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U1H86EL86YD
M)UU;)S@N-#8W.CDY+CDV-R==(#T@)TYA:VAO;B!3:2!4:&%M;6%R870G.PHD
M8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)SDN,3$W.CDY+C,U,"==(#T@)U-U
M<F%T(%1H86YI)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Y+CDX,SHY
M."XV,3<G72`]("=286YO;F<G.PHD8V]O<F1I;F%T97-;)U1O9V\G75LG,3`N
M,S8W.C`N-#8W)UT@/2`G36%N9V\G.PHD8V]O<F1I;F%T97-;)U1O9V\G75LG
M-BXQ-C<Z,2XR-3`G72`]("=,;VUE)SL*)&-O;W)D:6YA=&5S6R=4;V=O)UU;
M)S8N-3@S.C$N-3`P)UT@/2`G5&%B;&EG8F\G.PHD8V]O<F1I;F%T97-;)U1O
M9V\G75LG-RXU.#,Z,2XQ,3<G72`]("=!=&%K<&%M92<["B1C;V]R9&EN871E
M<ULG5&]G;R==6R<X+CDX,SHQ+C$U,"==(#T@)U-O:V]D92<["B1C;V]R9&EN
M871E<ULG5&]G;R==6R<Y+C<V-SHQ+C$P,"==(#T@)TYI86UT;W5G;W4G.PHD
M8V]O<F1I;F%T97-;)U1O;F=A)UU;)RTQ.2XX,#`Z+3$W-"XS-3`G72`]("=(
M86%P86DG.PHD8V]O<F1I;F%T97-;)U1O;F=A)UU;)RTR,2XR,S,Z+3$W-2XQ
M-3`G72`]("=&=6%<)T%M;W1U)SL*)&-O;W)D:6YA=&5S6R=4<FEN:61A9"!A
M;F0@5&]B86=O)UU;)S$P+C8Q-SHM-C$N,S4P)UT@/2`G4&EA<F-O($EN=&5R
M;F%T:6]N86P@06ER<&]R="P@5')I;FED860G.PHD8V]O<F1I;F%T97-;)U1R
M:6YI9&%D(&%N9"!4;V)A9V\G75LG,3$N,34P.BTV,"XX,S,G72`]("=#<F]W
M;B!0;VEN="!!:7)P;W)T+"!4;V)A9V\G.PHD8V]O<F1I;F%T97-;)U1U;FES
M:6$G75LG,S$N-C@S.CDN,38W)UT@/2`G16P@0F]R;6$G.PHD8V]O<F1I;F%T
M97-;)U1U;FES:6$G75LG,S(N,S$W.C$P+C0P,"==(#T@)U)E;6%D82<["B1C
M;V]R9&EN871E<ULG5'5N:7-I82==6R<S,RXX-C<Z,3`N-S8W)UT@/2`G1&IE
M<F)A($UE;&QI=&$G.PHD8V]O<F1I;F%T97-;)U1U;FES:6$G75LG,S,N.#@S
M.C$P+C$P,"==(#T@)T=A8F5S)SL*)&-O;W)D:6YA=&5S6R=4=6YI<VEA)UU;
M)S,S+CDQ-SHX+C$P,"==(#T@)U1O>F5U<B<["B1C;V]R9&EN871E<ULG5'5N
M:7-I82==6R<S-"XT,3<Z."XX,3<G72`]("='869S82<["B1C;V]R9&EN871E
M<ULG5'5N:7-I82==6R<S-"XW,3<Z,3`N-C@S)UT@/2`G4V9A>"!%;"U-86]U
M)SL*)&-O;W)D:6YA=&5S6R=4=6YI<VEA)UU;)S,U+C8V-SHQ,"XQ,#`G72`]
M("=+86ER;W5A;B<["B1C;V]R9&EN871E<ULG5'5N:7-I82==6R<S-2XV-C<Z
M,3`N-S4P)UT@/2`G36]N87-T:7(M4VMA;F5S)SL*)&-O;W)D:6YA=&5S6R=4
M=6YI<VEA)UU;)S,V+C0X,SHX+C@P,"==(#T@)TIE;F1O=6)A)SL*)&-O;W)D
M:6YA=&5S6R=4=6YI<VEA)UU;)S,V+C@S,SHQ,"XR,S,G72`]("=4=6YI<RU#
M87)T:&%G92<["B1C;V]R9&EN871E<ULG5'5N:7-I82==6R<S-BXX-3`Z,3$N
M,#@S)UT@/2`G2V5L:6)I82<["B1C;V]R9&EN871E<ULG5'5N:7-I82==6R<S
M-BXY-3`Z."XW-3`G72`]("=486)A<FMA)SL*)&-O;W)D:6YA=&5S6R=4=6YI
M<VEA)UU;)S,W+C(U,#HY+C@P,"==(#T@)T)I>F5R=&4G.PHD8V]O<F1I;F%T
M97-;)U1U<FME>2==6R<S-BXU.#,Z,S8N,38W)UT@/2`G27-K96YD97)U;B<[
M"B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,V+C<P,#HR."XW.#,G72`]("=$
M86QA;6%N)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG,S8N-S`P.C,P+C<S
M,R==(#T@)T%N=&%L>6$G.PHD8V]O<F1I;F%T97-;)U1U<FME>2==6R<S-BXY
M.#,Z,S4N,S`P)UT@/2`G061A;F$@+R!386MI<G!A<V$G.PHD8V]O<F1I;F%T
M97-;)U1U<FME>2==6R<S-RXP,#`Z,S4N-#$W)UT@/2`G061A;F$@+R!);F-I
M<FQI:R<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,W+C`S,SHR-RXT,3<G
M72`]("=";V1R=6TG.PHD8V]O<F1I;F%T97-;)U1U<FME>2==6R<S-RXP.#,Z
M,S<N,S8W)UT@/2`G1V%Z:6%N=&5P)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG
M75LG,S<N,3,S.C,X+C<V-R==(#T@)U5R9F$G.PHD8V]O<F1I;F%T97-;)U1U
M<FME>2==6R<S-RXW-3`Z,S`N-34P)UT@/2`G27-P87)T82<["B1C;V]R9&EN
M871E<ULG5'5R:V5Y)UU;)S,W+C@U,#HR-RXX-3`G72`]("=!>61I;B<["B1C
M;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,W+C@V-SHT,2XQ-C<G72`]("="871M
M86XG.PHD8V]O<F1I;F%T97-;)U1U<FME>2==6R<S-RXX.#,Z-#`N,3@S)UT@
M/2`G1&EY87)B86MI<B<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,W+CDV
M-SHS,BXU-3`G72`]("=+;VYY82<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;
M)S,X+C(V-SHR-RXQ-3`G72`]("=)>FUI<B`O($%D;F%N($UE;F1E<F5S)SL*
M)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG,S@N-#,S.C,X+C`X,R==(#T@)TUA
M;&%T>6$@+R!%<FAA8R<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,X+C0U
M,#HT,RXS,3<G72`]("=686XG.PHD8V]O<F1I;F%T97-;)U1U<FME>2==6R<S
M."XU,#`Z,C<N,#$W)UT@/2`G27IM:7(@+R!#:6=L:2<["B1C;V]R9&EN871E
M<ULG5'5R:V5Y)UU;)S,X+C8P,#HS.2XR.#,G72`]("=%;&%Z:6<G.PHD8V]O
M<F1I;F%T97-;)U1U<FME>2==6R<S."XV-C<Z,CDN-#$W)UT@/2`G57-A:R<[
M"B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,X+C<U,#HS,"XU,S,G72`]("=!
M9GEO;B<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,X+C<X,SHS-2XT.#,G
M72`]("=+87ES97)I("\@17)K:6QE="<["B1C;V]R9&EN871E<ULG5'5R:V5Y
M)UU;)S,X+CDQ-SHR-RXX-3`G72`]("=!:VAI<V%R)SL*)&-O;W)D:6YA=&5S
M6R=4=7)K97DG75LG,SDN-C$W.C(W+CDQ-R==(#T@)T)A;&EK97-I<B<["B1C
M;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,Y+C<S,SHS.2XU,#`G72`]("=%<GII
M;F-A;B<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,Y+C<U,#HS-RXP,3<G
M72`]("=3:79A<R<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,Y+C<X,SHS
M,"XU-C<G72`]("=%<VMI<V5H:7(G.PHD8V]O<F1I;F%T97-;)U1U<FME>2==
M6R<S.2XY,3<Z-#$N,C8W)UT@/2`G17)Z=7)U;2<["B1C;V]R9&EN871E<ULG
M5'5R:V5Y)UU;)S,Y+CDU,#HS,BXV.#,G72`]("=!;FMA<F$@+R!%=&EM97-G
M=70G.PHD8V]O<F1I;F%T97-;)U1U<FME>2==6R<T,"XP.#,Z,S(N-38W)UT@
M/2`G375R=&5D(%1U<BU!9F(G.PHD8V]O<F1I;F%T97-;)U1U<FME>2==6R<T
M,"XQ,3<Z,S(N.3@S)UT@/2`G06YK87)A("\@17-E;F)O9V$G.PHD8V]O<F1I
M;F%T97-;)U1U<FME>2==6R<T,"XQ,S,Z,C8N-#`P)UT@/2`G0V%N86MK86QE
M)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG-#`N,3@S.C(Y+C`V-R==(#T@
M)T)U<G-A)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG-#`N,S`P.C,V+C4V
M-R==(#T@)U1O:V%T)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG-#`N,S$W
M.C(W+CDV-R==(#T@)T)A;F1I<FUA)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG
M75LG-#`N-C`P.C0S+C`X,R==(#T@)TMA<G,G.PHD8V]O<F1I;F%T97-;)U1U
M<FME>2==6R<T,"XX-3`Z,S4N-3@S)UT@/2`G365R>FEF;VXG.PHD8V]O<F1I
M;F%T97-;)U1U<FME>2==6R<T,"XY-C<Z,C@N.#$W)UT@/2`G27-T86YB=6P@
M+R!!=&%T=7)K)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG-#$N,#`P.C,Y
M+C<Q-R==(#T@)U1R86)Z;VXG.PHD8V]O<F1I;F%T97-;)U1U<FME>2==6R<T
M,2XR-C<Z,S8N,S`P)UT@/2`G4V%M<W5N)SL*)&-O;W)D:6YA=&5S6R=4=7)K
M97DG75LG-#$N-#4P.C,Q+C@P,"==(#T@)UIO;F=U;&1A:R<["B1C;V]R9&EN
M871E<ULG5'5V86QU)UU;)RTU+C8V-SHQ-S8N,3,S)UT@/2`G3F%N=6UE82<[
M"B1C;V]R9&EN871E<ULG5'5V86QU)UU;)RTX+C4Q-SHQ-SDN,C$W)UT@/2`G
M1G5N869U=&DG.PHD8V]O<F1I;F%T97-;)U5G86YD82==6R<P+C`U,#HS,BXT
M-3`G72`]("=%;G1E8F)E($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U5G86YD
M82==6R<P+C$X,SHS,"XQ,#`G72`]("=+87-E<V4G.PHD8V]O<F1I;F%T97-;
M)U5G86YD82==6R<P+C0U,#HS,RXQ.#,G72`]("=*:6YJ82<["B1C;V]R9&EN
M871E<ULG56=A;F1A)UU;)RTP+C8Q-SHS,"XV-3`G72`]("=-8F%R87)A)SL*
M)&-O;W)D:6YA=&5S6R=59V%N9&$G75LG,"XV.#,Z,S0N,38W)UT@/2`G5&]R
M;W)O)SL*)&-O;W)D:6YA=&5S6R=59V%N9&$G75LG+3$N,C4P.C(Y+CDX,R==
M(#T@)TMA8F%L92<["B1C;V]R9&EN871E<ULG56=A;F1A)UU;)S$N-C@S.C,Q
M+C<Q-R==(#T@)TUA<VEN9&DG.PHD8V]O<F1I;F%T97-;)U5G86YD82==6R<Q
M+C<Q-SHS,RXV,3<G72`]("=3;W)O=&DG.PHD8V]O<F1I;F%T97-;)U5G86YD
M82==6R<R+C<U,#HS,BXS,S,G72`]("='=6QU)SL*)&-O;W)D:6YA=&5S6R=5
M9V%N9&$G75LG,RXP-3`Z,S`N.3$W)UT@/2`G07)U82<["B1C;V]R9&EN871E
M<ULG56MR86EN92==6R<T-"XV.#,Z,S0N,3,S)UT@/2`G4VEM9F5R;W!O;"<[
M"B1C;V]R9&EN871E<ULG56MR86EN92==6R<T-BXT,S,Z,S`N-S8W)UT@/2`G
M3V1E<V$G.PHD8V]O<F1I;F%T97-;)U5K<F%I;F4G75LG-#DN.#$W.C(S+CDU
M,"==(#T@)TQ<)U9I=B<["B1C;V]R9&EN871E<ULG56MR86EN92==6R<T.2XY
M-C<Z,S8N,3,S)UT@/2`G2VAA<FMI=B<["B1C;V]R9&EN871E<ULG56MR86EN
M92==6R<U,"XS,S,Z,S`N.38W)UT@/2`G0F]R>7-P:6PG.PHD8V]O<F1I;F%T
M97-;)U5K<F%I;F4G75LG-3`N-#`P.C,P+C4V-R==(#T@)TMY:78G.PHD8V]O
M<F1I;F%T97-;)U5K<F%I;F4G75LG-3`N-3@S.C(V+C$S,R==(#T@)U)I=FYE
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@07)A8B!%;6ER871E<R==6R<R-"XR
M-C<Z-34N-C`P)UT@/2`G06P@06EN($EN=&5R;F%T:6]N86P@06ER<&]R="<[
M"B1C;V]R9&EN871E<ULG56YI=&5D($%R86(@16UI<F%T97,G75LG,C0N-#,S
M.C4T+C0V-R==(#T@)T%B=2!$:&%B:2!"871E96X@06ER<&]R="<["B1C;V]R
M9&EN871E<ULG56YI=&5D($%R86(@16UI<F%T97,G75LG,C0N-#,S.C4T+C8U
M,"==(#T@)T%B=2!$:&%B:2!);G1E<FYA=&EO;F%L($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!!<F%B($5M:7)A=&5S)UU;)S(U+C$P,#HU-BXS
M,S,G72`]("=&=6IA:7)A:"<["B1C;V]R9&EN871E<ULG56YI=&5D($%R86(@
M16UI<F%T97,G75LG,C4N,C4P.C4U+C,S,R==(#T@)T1U8F%I($EN=&5R;F%T
M:6]N86P@06ER<&]R="<["B1C;V]R9&EN871E<ULG56YI=&5D($%R86(@16UI
M<F%T97,G75LG,C4N,S,S.C4U+C4Q-R==(#T@)U-H87)J86@@26YT97)N871I
M;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=5;FET960@07)A8B!%;6ER
M871E<R==6R<R-2XV,3<Z-34N.3,S)UT@/2`G4F%S($%L($MH86EM86@@26YT
M97)N871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN
M9V1O;2==6R<T.2XR,3<Z+3(N,C`P)UT@/2`G2F5R<V5Y($%I<G!O<G0G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S0Y+C0S,SHM,BXV,#`G
M72`]("='=65R;G-E>2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M2VEN9V1O;2==6R<T.2XY,3<Z+38N,S`P)UT@/2`G4V-I;&QY+"!386EN="!-
M87)Y7"=3)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,"XP
M.#,Z+34N,C4P)UT@/2`G0W5L9')O<V4G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!+:6YG9&]M)UU;)S4P+C,U,#HM-"XQ,3<G72`]("=0;'EM;W5T:"<["B1C
M;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3`N-#,S.BTU+C`P,"==
M(#T@)U-A:6YT($UA=V=A;B<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D
M;VTG75LG-3`N-38W.BTR+C0U,"==(#T@)U!O<G1L86YD("\@4FYA<R<["B1C
M;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3`N-S,S.BTS+C0Q-R==
M(#T@)T5X971E<B!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN
M9V1O;2==6R<U,"XW.#,Z+3$N.#,S)UT@/2`G0F]U<FYE;6]U=&@@06ER<&]R
M="<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3`N.#,S.BTP
M+C(X,R==(#T@)U-H;W)E:&%M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!+:6YG9&]M)UU;)S4P+CDP,#HM,2XT,#`G72`]("=3;W5T:&%M<'1O
M;B`O(%=E871H97(@0V5N=')E)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN
M9V1O;2==6R<U,2XP,#`Z+3(N-C,S)UT@/2`G665O=FEL=&]N)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,2XP.#,Z+30N,34P)UT@/2`G
M0VAI=F5N;W(G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4Q
M+C$U,#HM,"XQ.#,G72`]("=,;VYD;VX@+R!'871W:6-K($%I<G!O<G0G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4Q+C$U,#HM,2XU-C<G
M72`]("=-:61D;&4@5V%L;&]P)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN
M9V1O;2==6R<U,2XQ-C<Z+3$N-S4P)UT@/2`G0F]S8V]M8F4@1&]W;B<["B1C
M;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3$N,C,S.BTP+CDU,"==
M(#T@)T]D:6AA;2<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG
M-3$N,C@S.BTP+C<V-R==(#T@)T9A<FYB;W)O=6=H($UI;&ET87)Y)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,2XR.#,Z+3`N-S8W)UT@
M/2`G1F%R;F)O<F]U9V@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M
M)UU;)S4Q+C,U,#HQ+C,U,"==(#T@)TUA;G-T;VXG.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!+:6YG9&]M)UU;)S4Q+C,X,SHM,"XW.#,G72`]("="<F%C:VYE
M;&P@+R!"96%U9F]R="!087)K)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN
M9V1O;2==6R<U,2XT,#`Z+3,N,S4P)UT@/2`G0V%R9&EF9BU786QE<R!!:7)P
M;W)T)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,2XT.#,Z
M+3`N-#4P)UT@/2`G3&]N9&]N("\@2&5A=&AR;W<@06ER<&]R="<["B1C;V]R
M9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3$N-3`P.BTQ+CDX,R==(#T@
M)TQY;F5H86TG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4Q
M+C4Q-SHM,"XQ,3<G72`]("=,;VYD;VX@5V5A=&AE<B!#96YT<F4G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4Q+C4U,#HM,"XT,3<G72`]
M("=.;W)T:&]L="<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG
M-3$N-C$W.BTQ+C`X,R==(#T@)T)E;G-O;B<["B1C;V]R9&EN871E<ULG56YI
M=&5D($MI;F=D;VTG75LG-3$N-C@S.BTQ+C<X,R==(#T@)T9A:7)F;W)D(%)O
M>6%L($%I<B!&;W)C92!"87-E)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN
M9V1O;2==6R<U,2XW,3<Z+30N,S8W)UT@/2`G4&5M8G)E>2!386YD<R<["B1C
M;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3$N-S4P.BTQ+C4X,R==
M(#T@)T)R:7IE($YO<G1O;B<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D
M;VTG75LG-3$N.#@S.C`N,C,S)UT@/2`G4W1A;G-T960@06ER<&]R="<["B1C
M;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3(N,3$W.C`N.38W)UT@
M/2`G5V%T=&ES:&%M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==
M6R<U,BXQ,S,Z+30N-38W)UT@/2`G06)E<G!O<G1H)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@2VEN9V1O;2==6R<U,BXS,S,Z,"XW-C<G72`]("=(;VYI;F=T
M;VX@4F]Y86P@06ER($9O<F-E($)A<V4G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!+:6YG9&]M)UU;)S4R+C,U,#HM,"XQ,3<G72`]("=7>71O;B!2;WEA;"!!
M:7(@1F]R8V4@0F%S92<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG
M75LG-3(N,S8W.BTP+C(Q-R==(#T@)T%L8V]N8G5R>2!2;WEA;"!!:7(@1F]R
M8V4@0F%S92<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3(N
M,S8W.C`N-#@S)UT@/2`G36EL9&5N:&%L;"!2;WEA;"!!:7(@1F]R8V4@0F%S
M92<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3(N-#$W.C`N
M-38W)UT@/2`G3&%K96YH96%T:"!2;WEA;"!!:7(@1F]R8V4@0F%S92<["B1C
M;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3(N-#,S.C$N,S4P)UT@
M/2`G0V]L=&ES:&%L;"<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG
M75LG-3(N-#4P.BTQ+C<S,R==(#T@)T)I<FUI;F=H86T@+R!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,BXV,3<Z+3`N-#8W
M)UT@/2`G5VET=&5R:6YG)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O
M;2==6R<U,BXV,S,Z,2XS,#`G72`]("=.;W)W:6-H(%=E871H97(@0V5N=')E
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,BXV-3`Z,"XU
M-C<G72`]("=-87)H86TG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M
M)UU;)S4R+C<S,SHM,"XV-3`G72`]("=#;W1T97-M;W)E)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@2VEN9V1O;2==6R<U,BXX,#`Z+3(N-C8W)UT@/2`G4VAA
M=V)U<GDG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4R+C@V
M-SHP+C$U,"==(#T@)TAO;&)E86-H)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M2VEN9V1O;2==6R<U,RXP,S,Z+3`N-3`P)UT@/2`G0W)A;G=E;&PG.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4S+C`X,SHM,"XQ-C<G72`]
M("=#;VYI;F=S8GD@4F]Y86P@06ER($9O<F-E($)A<V4G.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!+:6YG9&]M)UU;)S4S+C`X,SHP+C(V-R==(#T@)U=A:6YF
M;&5E="<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3,N,38W
M.BTP+C4Q-R==(#T@)U=A9&1I;F=T;VXG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!+:6YG9&]M)UU;)S4S+C$V-SHM,BXY.#,G72`]("=(87=A<F1E;B<["B1C
M;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3,N,C4P.BTT+C4S,R==
M(#T@)U9A;&QE>2<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG
M-3,N,S4P.BTR+C(X,R==(#T@)TUA;F-H97-T97(@06ER<&]R="<["B1C;V]R
M9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3,N-S8W.BTS+C`S,R==(#T@
M)T)L86-K<&]O;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN
M9V1O;2==6R<U,RXX,S,Z+3$N,C`P)UT@/2`G0VAU<F-H($9E;G1O;B<["B1C
M;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3,N.#8W.BTP+C0S,R==
M(#T@)TQE8V]N9FEE;&0G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M
M)UU;)S4T+C`U,#HM,2XR-3`G72`]("=,:6YT;VXM3VXM3W5S92<["B1C;V]R
M9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-30N,#@S.BTT+C8S,R==(#T@
M)TES;&4@3V8@36%N("\@4F]N86QD<W=A>2!!:7)P;W)T)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@2VEN9V1O;2==6R<U-"XQ,3<Z+3,N,C4P)UT@/2`G5V%L
M;F5Y($ES;&%N9"<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG
M-30N,3,S.BTQ+C0Q-R==(#T@)T1I<V9O<G1H)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@2VEN9V1O;2==6R<U-"XS,#`Z+3$N-3,S)UT@/2`G3&5E;6EN9R<[
M"B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-30N-C`P.BTU+C@X
M,R==(#T@)T)E;&9A<W0@+R!(87)B;W5R)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@2VEN9V1O;2==6R<U-"XV-3`Z+38N,C$W)UT@/2`G0F5L9F%S="`O($%L
M9&5R9W)O=F4@06ER<&]R="<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D
M;VTG75LG-30N.#4P.BTT+CDU,"==(#T@)U=E<W0@1G)E=6=H)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U-"XY,S,Z+3(N.34P)UT@/2`G
M0V%R;&ES;&4G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4U
M+C`U,#HM,BXU-3`G72`]("=3<&%D96%D86TG.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!+:6YG9&]M)UU;)S4U+C0Q-SHM,2XV,#`G72`]("=";W5L;65R)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U-2XT,S,Z+34N-S`P
M)UT@/2`G36%C:')I:&%N:7-H)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN
M9V1O;2==6R<U-2XU,#`Z+30N-3@S)UT@/2`G4')E<W1W:6-K($%I<G!O<G0G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4U+C@V-SHM-"XT
M,S,G72`]("=';&%S9V]W($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!+:6YG9&]M)UU;)S4U+CDU,#HM,RXS-3`G72`]("=%9&EN8G5R9V@@06ER
M<&]R="<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-38N,S@S
M.BTR+C@V-R==(#T@)TQE=6-H87)S)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M2VEN9V1O;2==6R<U-BXU,#`Z+38N.#@S)UT@/2`G5&ER964G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4W+C(P,#HM,BXR,3<G72`]("=!
M8F5R9&5E;B`O($1Y8V4G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M
M)UU;)S4W+C0V-SHM-RXS-C<G72`]("="96YB96-U;&$G.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!+:6YG9&]M)UU;)S4W+C4S,SHM-"XP-3`G72`]("=);G9E
M<FYE<W,@+R!$86QC<F]S<R<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D
M;VTG75LG-3<N-C4P.BTS+C4V-R==(#T@)TMI;FQO<W,G.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!+:6YG9&]M)UU;)S4W+C<Q-SHM,RXS,3<G72`]("=,;W-S
M:65M;W5T:"<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3<N
M.#$W.BTS+CDV-R==(#T@)U1A:6X@4F%N9V4G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!+:6YG9&]M)UU;)S4X+C(Q-SHM-BXS,3<G72`]("=3=&]R;F]W87DG
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4X+C0U,#HM,RXP
M.#,G72`]("=7:6-K)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==
M6R<U."XY-3`Z+3(N.3`P)UT@/2`G2VER:W=A;&P@06ER<&]R="<["B1C;V]R
M9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3DN.#@S.BTQ+C,P,"==(#T@
M)U-U;6)U<F=H($-A<&4G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,@
M36EN;W(@3W5T;'EI;F<@27-L86YD<R==6R<M,30N,S,S.BTQ-S`N-S$W)UT@
M/2`G4&%G;R!086=O("\@26YT+B!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',G75LG,38N-S,S
M.BTQ-CDN-3,S)UT@/2`G2F]H;G-T;VX@27-L86YD+"!*;VAN<W1O;B!!=&]L
M;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S$S
M+C0X,SHQ-#0N.#`P)UT@/2`G06=A;F$L($=U86T@26YT97)N871I;VYA;"!!
M:7)P;W)T+"!'52<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<Q
M,RXU.#,Z,30T+CDS,R==(#T@)T%N9&5R<V5N("A-87)I86YA($ES*2P@06YD
M97)S96X@06ER($9O<F-E($)A<V4L($=5)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S$S+CDQ-SHQ-#0N.#,S)UT@/2`G1W5A;2P@36%R:6%N
M82!)<VQA;F0L($=5)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S$T+C$X,SHQ-#4N,C4P)UT@/2`G4F]T82!)<VQA;F0@*$XN($UA<FEA;F$@
M27,I+"!2;W1A($EN=&5R;F%T:6]N86P@06ER<&]R="P@1U4G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG,30N.3@S.C$T-2XV,3<G72`]("=4
M:6YI86X@27-L86YD("A.+B!-87)I86YA($ES*2P@5V5S="!4:6YI86X@06ER
M<&]R="P@1U4G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,34N
M,3$W.C$T-2XW,S,G72`]("=386EP86X@27-L86YD+"!386EP86X@26YT97)N
M871I;VYA;"!!:7)P;W)T+"!.;W)T:&5R;B!-87)I86YA($ES;&%N9',G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,3@N,C4U.BTV-2XV-#,G
M72`]("=2;V]S979E;'0@4F]A9',L(%)O;W-E=F5L="!2;V%D<R!.879A;"!3
M=&%T:6]N("A/9G-T:64@1FEE;&0I+"!04B<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<Q."XU,#`Z+38W+C$S,R==(#T@)T%Q=6%D:6QL82P@
M4F%F865L($AE<FYA;F1E>B!!:7)P;W)T+"!04B<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<Q.2XQ,#`Z+3$U-2XW-3`G72`]("=3;W5T:"!+
M;VYA("\@2&%W86EI+"!(22<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<Q.2XR.#,Z,38V+C8U,"==(#T@)U=A:V4@27-L86YD+"!786ME($ES
M;&%N9"!!<FUY($%I<F9I96QD($%I<G!O<G0L($=5)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S$Y+C<R,CHM,34U+C`U-B==(#T@)TAI;&\L
M($AI;&\@26YT97)N871I;VYA;"!!:7)P;W)T+"!(22<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<R,"XX.3(Z+3$U-BXT,S<G72`]("=+86AU
M;'5I+"!+86AU;'5I($%I<G!O<G0L($A))SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S(Q+C$U,#HM,34W+C$P,"==(#T@)TUO;&]K86D@075T
M;VUA=&EC($UE=&5O<F]L;V=I8V%L($]B<V5R=FEN9R!3>7-T96TL($A))SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(Q+C,P.#HM,34X+C`V
M."==(#T@)T]A:'4L($MA;&%E;&]A($%I<G!O<G0L($A))SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S(Q+C,R.#HM,34W+CDT,R==(#T@)TAO
M;F]L=6QU+"!(;VYO;'5L=2!);G1E<FYA=&EO;F%L($%I<G!O<G0L($A))SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(Q+C0U-#HM,34W+C<V
M-B==(#T@)TMA;F5O:&4L($UA<FEN92!#;W)P<R!!:7(@4W1A=&EO;BP@2$DG
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,C$N-#@S.BTQ-3@N
M,#,S)UT@/2`G5VAE96QE<B!!:7(@1F]R8V4@0F%S92`O($]A:'4L($A))SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(Q+CDX-#HM,34Y+C,T
M,2==(#T@)TQI:'5E+"!,:6AU92!!:7)P;W)T+"!(22<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<R,BXP,S8Z+3$U.2XW.#8G72`]("=+96MA
M:&$L(%!A8VEF:6,@36ES<VEL92!497-T($9A8VEL:71Y($)A<FMI;F<@4V%N
M9',L($A))SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(T+C4U
M-#HM.#$N-S4T)UT@/2`G2V5Y(%=E<W0L($ME>2!797-T($EN=&5R;F%T:6]N
M86P@06ER<&]R="P@1DPG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG,C4N-SDQ.BTX,"XS,38G72`]("=-:6%M:2P@36EA;6D@26YT97)N871I
M;VYA;"!!:7)P;W)T+"!&3"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<R-2XY,30Z+3DW+C0R,R==(#T@)T)R;W=N<W9I;&QE+"!"<F]W;G-V
M:6QL92`O(%-O=71H(%!A9')E($ES;&%N9"!);G1E<FYA=&EO;F%L($%I<G!O
M<G0L(%18)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(V+C8X
M-3HM.#`N,#DY)UT@/2`G5V5S="!086QM($)E86-H+"!086QM($)E86-H($EN
M=&5R;F%T:6]N86P@06ER<&]R="P@1DPG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,C<N-34P.BTY.2XT-C<G72`]("=,87)E9&\@26YT97)N
M871I;VYA;"!!:7)P;W)T+"!46"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<R-RXV-3`Z+3@Q+C,S,R==(#T@)T%V;VX@4&%R:R!'=6YN97)Y
M(%)A;F=E+"!&3"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<R
M-RXW,#`Z+3@R+C0P,"==(#T@)U1A;7!A($)A>2!!<F5A+"!&3"<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<R-RXW-S,Z+3DW+C4Q,R==(#T@
M)T-O<G!U<R!#:')I<W1I+"!#;W)P=7,@0VAR:7-T:2!);G1E<FYA=&EO;F%L
M($%I<G!O<G0L(%18)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S(W+C@U,#HM.#(N-3`P)UT@/2`G36%C9&EL;"!!:7(@1F]R8V4@0F%S92P@
M1FPN+"!&3"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<R-RXY
M-C$Z+3@R+C4T,"==(#T@)U1A;7!A+"!486UP82!);G1E<FYA=&EO;F%L($%I
M<G!O<G0L($9,)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(X
M+C$P,SHM.#`N-C0V)UT@/2`G365L8F]U<FYE+"!-96QB;W5R;F4@26YT97)N
M871I;VYA;"!!:7)P;W)T+"!&3"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<R."XR,3<Z+3$W-RXS-C<G72`]("=386YD($ES;&%N9"P@2&5N
M9&5R<V]N($9I96QD($%I<G!O<G0L($A))SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S(X+C(S,SHM.#`N-C`P)UT@/2`G0V]C;V$@+R!0871R
M:6-K($%I<B!&;W)C92!"87-E+"!&3"<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<R."XT,3<Z+3@Q+C,R-2==(#T@)T]R;&%N9&\L($]R;&%N
M9&\@26YT97)N871I;VYA;"!!:7)P;W)T+"!&3"<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<R."XT-C<Z+3@P+C4U,"==(#T@)T-A<&4@2V5N
M;F5D>2P@1DPG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,C@N
M.#8S.BTY-BXY,S`G72`]("=6:6-T;W)I82P@5FEC=&]R:6$@4F5G:6]N86P@
M06ER<&]R="P@5%@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M,CDN,C<P.BTY-"XX-C0G72`]("='86QV97-T;VXL(%-C:&]L97,@1FEE;&0L
M(%18)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(Y+C,S,SHM
M.#DN-#`P)UT@/2`G0F]O=&AV:6QL92P@3$$G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,CDN,S<U.BTQ,#`N.3(T)UT@/2`G1&5L(%)I;RP@
M1&5L(%)I;R!);G1E<FYA=&EO;F%L($%I<G!O<G0L(%18)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S(Y+C4S,SHM.3@N-#8T)UT@/2`G4V%N
M($%N=&]N:6\L(%-A;B!!;G1O;FEO($EN=&5R;F%T:6]N86P@06ER<&]R="P@
M5%@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,CDN-34P.BTX
M,RXQ,#4G72`]("=#<F]S<R!#:71Y+"!#<F]S<R!#:71Y($%I<G!O<G0L($9,
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(Y+C<R-SHM.#4N
M,#(U)UT@/2`G07!A;&%C:&EC;VQA+"!!<&%L86-H:6-O;&$L($9,)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(Y+CDU,3HM.30N,#(Q)UT@
M/2`G0F5A=6UO;G0@+R!0;W)T($%R=&AU<BP@4V]U=&AE87-T(%1E>&%S(%)E
M9VEO;F%L($%I<G!O<G0L(%18)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S(Y+CDY,CHM.34N,S8T)UT@/2`G2&]U<W1O;BP@2&]U<W1O;B!)
M;G1E<F-O;G1I;F5N=&%L($%I<G!O<G0L(%18)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S(Y+CDY,SHM.3`N,C4Q)UT@/2`G3F5W($]R;&5A
M;G,L($YE=R!/<FQE86YS($EN=&5R;F%T:6]N86P@06ER<&]R="P@3$$G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S`N,#8W.BTX-2XU.#,G
M72`]("=4>6YD86QL($%I<B!&;W)C92!"87-E+"!&3"<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<S,"XQ,C8Z+3DS+C(R,R==(#T@)TQA:V4@
M0VAA<FQE<RP@3&%K92!#:&%R;&5S(%)E9VEO;F%L($%I<G!O<G0L($Q!)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,P+C$V-SHM,3`R+C0Q
M-R==(#T@)U-A;F1E<G-O;BP@5%@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG,S`N,S,S.BTX.2XX,3<G72`]("=3;&ED96QL+"!,02<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,"XS-C<Z+3$P-"XP,3<G
M72`]("=-87)F82P@5%@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG,S`N,SDS.BTX-"XS-3,G72`]("=486QL86AA<W-E92P@5&%L;&%H87-S
M964@4F5G:6]N86P@06ER<&]R="P@1DPG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,S`N-#$W.BTX-BXV.#,G72`]("=(=7)L8G5R="!&:65L
M9"P@1DPG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S`N-#@S
M.BTX-BXU,3<G72`]("=686QP87)A:7-O("\@16=L:6X@06ER($9O<F-E($)A
M<V4L($9,)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,P+C0Y
M-#HM.#$N-CDS)UT@/2`G2F%C:W-O;G9I;&QE+"!*86-K<V]N=FEL;&4@26YT
M97)N871I;VYA;"!!:7)P;W)T+"!&3"<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<S,"XU,3$Z+3DY+C<V-B==(#T@)TIU;F-T:6]N+"!+:6UB
M;&4@0V]U;G1Y($%I<G!O<G0L(%18)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S,P+C8X.#HM.#@N,C0V)UT@/2`G36]B:6QE+"!-;V)I;&4@
M4F5G:6]N86P@06ER<&]R="P@04PG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG,S`N.38W.BTX,RXR,#`G72`]("=-;V]D>2!!:7(@1F]R8V4@
M0F%S92P@1T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S$N
M,#,S.BTY,RXP,S,G72`]("=&;W)T(%!O;&LL($Q!)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S,Q+C$P,#HM.3<N,S,S)UT@/2`G1F]R="!(
M;V]D+"!46"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,2XQ
M,S,Z+3DR+C4V-R==(#T@)T-L86EB;W)N92!286YG92P@06ER=V%Y<R!&86-I
M;&ET:65S(%-E8W1O<BP@3$$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG,S$N,C4P.BTX,BXT,#`G72`]("=787EC<F]S<R`O(%=A<F4@0V]U
M;G1Y+"!'82P@1T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M,S$N,S,U.BTY,BXU-3DG72`]("=!;&5X86YD<FEA+"!!;&5X86YD<FEA($EN
M=&5R;F%T:6]N86P@06ER<&]R="P@3$$G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,S$N,S4Q.BTQ,#`N-#DT)UT@/2`G4V%N($%N9V5L;RP@
M36%T:&ES($9I96QD+"!46"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<S,2XU,S8Z+3@T+C$Y-"==(#T@)T%L8F%N>2P@4V]U=&AW97-T($=E
M;W)G:6$@4F5G:6]N86P@06ER<&]R="P@1T$G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,S$N-3@S.BTQ,3`N,S,S)UT@/2`G1F]R="!(=6%C
M:'5C82P@05HG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S$N
M-C$W.BTY-RXR,C@G72`]("=786-O+"!786-O(%)E9VEO;F%L($%I<G!O<G0L
M(%18)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,Q+C@Q,3HM
M,3`V+C,W-B==(#T@)T5L(%!A<V\L($5L(%!A<V\@26YT97)N871I;VYA;"!!
M:7)P;W)T+"!46"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S
M,2XX,S$Z+3$P-"XX,#DG72`]("=0:6YE(%-P<FEN9W,L($=U861A;'5P92!-
M;W5N=&%I;G,@3F%T:6]N86P@4&%R:RP@5%@G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,S$N.#8W.BTQ,#8N-S`P)UT@/2`G4V%N=&$@5&5R
M97-A+"!.32<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,2XX
M.#,Z+3@Q+C4V-R==(#T@)T9T+B!3=&5W87)T+"!'02<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<S,2XY-#@Z+3$P,BXR,#DG72`]("=-:61L
M86YD+"!-:61L86YD($EN=&5R;F%T:6]N86P@06ER<&]R="P@5%@G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S(N,3$Y.BTX,2XR,#(G72`]
M("=3879A;FYA:"P@4V%V86YN86@@26YT97)N871I;VYA;"!!:7)P;W)T+"!'
M02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,BXQ,S$Z+3$Q
M,"XY-34G72`]("=4=6-S;VXL(%1U8W-O;B!);G1E<FYA=&EO;F%L($%I<G!O
M<G0L($%:)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,R+C(Q
M-SHM.3@N,3@S)UT@/2`G4W1E<&AE;G9I;&QE("\@0VQA<FL@1FEE;&0@375N
M:6-I<&%L+"!4>"XL(%18)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S,R+C,P,#HM.#8N-#`V)UT@/2`G36]N=&=O;65R>2P@1&%N;F5L;'D@
M1FEE;&0L($%,)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,R
M+C,R,#HM.3`N,#<X)UT@/2`G2F%C:W-O;BP@2F%C:W-O;B!);G1E<FYA=&EO
M;F%L($%I<G!O<G0L($U3)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S,R+C,S,SHM.#0N.#,S)UT@/2`G1F]R="!"96YN:6YG+"!'02<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,BXS,S@Z+3@X+C<T."==
M(#T@)TUE<FED:6%N+"!+97D@1FEE;&0L($U3)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S,R+C,X,SHM,3`V+C0X,R==(#T@)U=H:71E(%-A
M;F1S+"!.32<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,BXS
M.3$Z+3DT+C<Q-"==(#T@)TQO;F=V:65W+"!'<F5G9R!#;W5N='D@06ER<&]R
M="P@5%@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S(N-#$P
M.BTY.2XV.#(G72`]("=!8FEL96YE+"!!8FEL96YE(%)E9VEO;F%L($%I<G!O
M<G0L(%18)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,R+C0S
M,SHM,3$R+C8X,R==(#T@)T=I;&$@0F5N9"!5+B!3+B!!<FUY($%I<F9I96QD
M+"!!6B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,BXT-#<Z
M+3DS+C@R-"==(#T@)U-H<F5V97!O<G0L(%-H<F5V97!O<G0@4F5G:6]N86P@
M06ER<&]R="P@3$$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M,S(N-C,S.BTQ,#@N,34P)UT@/2`G4VEL=F5R($-I='D@+R!'<F%N="P@3DTG
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S(N-C4P.BTQ,30N
M-C`P)UT@/2`G675M82`O(%EU;6$@26YT97)N871I;VYA;"P@05HG.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S(N-C@X.BTX,RXV-30G72`]
M("=-86-O;BP@36ED9&QE($=E;W)G:6$@4F5G:6]N86P@06ER<&]R="P@1T$G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S(N-S,T.BTQ,3<N
M,3@S)UT@/2`G4V%N($1I96=O+"!386X@1&EE9V\@26YT97)N871I;VYA;"U,
M:6YD8F5R9V@@1FEE;&0L($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S,R+C@R-3HM,3$U+C8V,2==(#T@)T5L($-E;G1R;RP@3F%V86P@
M06ER($9A8VEL:71Y+"!#02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<S,BXX,S,Z+3DW+C,P,"==(#T@)T9O<G0@5V]R=&@L(%18)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,R+C@U,#HM,3`V+C$P,"==
M(#T@)TAO;&QO;6%N($%I<B!&;W)C92!"87-E+"!.32<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<S,BXX-C@Z+3$Q-RXQ-#,G72`]("=386X@
M1&EE9V\L($UI<F%M87(@34-!4R]-:71S8VAE<B!&:65L9"!!:7)P;W)T+"!#
M02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,BXX.3<Z+3DW
M+C`R,B==(#T@)T1A;&QA<R`O($9O<G0@5V]R=&@L($1A;&QA<R`O($9O<G0@
M5V]R=&@@26YT97)N871I;VYA;"!!:7)P;W)T+"!46"<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<S,BXX.3DZ+3@P+C`T,2==(#T@)T-H87)L
M97-T;VXL($-H87)L97-T;VX@06ER($9O<F-E($)A<V4L(%-#)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,R+CDP,#HM.#<N,C4P)UT@/2`G
M0V5N=')E=FEL;&4L($%,)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S,S+C(S-3HM,3$Y+C0U,R==(#T@)U-A;B!.:6-H;VQA<R!)<VQA;F0L
M($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,S+C(S-SHM
M,3`W+C(V."==(#T@)U1R=71H($]R($-O;G-E<75E;F-E<RP@5')U=&@@3W(@
M0V]N<V5Q=65N8V5S($UU;FEC:7!A;"!!:7)P;W)T+"!.32<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<S,RXS,#@Z+3$P-"XU,#@G72`]("=2
M;W-W96QL+"!2;W-W96QL($EN9'5S=')I86P@06ER($-E;G1E<B!!:7)P;W)T
M+"!.32<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,RXS-C0Z
M+3@Q+CDV,R==(#T@)T%U9W5S=&$L($)U<V@@1FEE;&0L($=!)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,S+C0P-3HM,3$X+C0Q-B==(#T@
M)T%V86QO;BP@0V%T86QI;F$@06ER<&]R="P@0T$G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG,S,N-#,T.BTQ,3(N,#4Q)UT@/2`G4&AO96YI
M>"P@4&AO96YI>"!3:WD@2&%R8F]R($EN=&5R;F%T:6]N86P@06ER<&]R="P@
M05HG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S,N-38V.BTX
M-BXW-#4G72`]("=":7)M:6YG:&%M+"!":7)M:6YG:&%M($EN=&5R;F%T:6]N
M86P@06ER<&]R="P@04PG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG,S,N-C,P.BTX-"XT-#(G72`]("=!=&QA;G1A+"!(87)T<V9I96QD($%T
M;&%N=&$@26YT97)N871I;VYA;"!!:7)P;W)T+"!'02<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<S,RXV-C<Z+3$P,2XX,C$G72`]("=,=6)B
M;V-K+"!,=6)B;V-K($EN=&5R;F%T:6]N86P@06ER<&]R="P@5%@G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S,N-C@S.BTW."XY,S,G72`]
M("=->7)T;&4@0F5A8V@@06ER($9O<F-E($)A<V4L(%-#)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S,S+C@Q,CHM,3$X+C$T-B==(#T@)TQO
M;F<@0F5A8V@L($QO;F<@0F5A8V@@06ER<&]R="P@0T$G.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG,S,N.#4P.BTX,"XT.#,G72`]("=0;VEN
M<V5T="!286YG92P@4W5M<'1E<BP@4T,G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,S,N.3`P.BTQ,#8N-#`P)UT@/2`G3F]R=&AR=7`@3&%N
M9&EN9R!3=')I<"P@3DTG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG,S,N.3`P.BTQ,3<N,C4P)UT@/2`G4FEV97)S:61E("\@36%R8V@@06ER
M($9O<F-E($)A<V4L($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S,S+CDQ-SHM.#0N-3$W)UT@/2`G36%R:65T=&$@+R!$;V)B:6YS($%I
M<B!&;W)C92!"87-E+"!'02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<S,RXY,S@Z+3$Q."XS.#DG72`]("=,;W,@06YG96QE<RP@3&]S($%N
M9V5L97,@26YT97)N871I;VYA;"!!:7)P;W)T+"!#02<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<S,RXY-#(Z+3@Q+C$Q."==(#T@)T-O;'5M
M8FEA+"!#;VQU;6)I82!-971R;W!O;&ET86X@06ER<&]R="P@4T,G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S,N.34Q.BTX,RXS,C@G72`]
M("=!=&AE;G,L($%T:&5N<R!!:7)P;W)T+"!'02<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<S,RXY-C<Z+3@P+C0X,R==(#T@)U-H87<@06ER
M($9O<F-E($)A<V4L(%-#)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S,S+CDW.3HM.3@N-#DS)UT@/2`G5VEC:&ET82!&86QL<RP@4VAE<'!A
M<F0@06ER($9O<F-E($)A<V4L(%18)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S,T+C`Q-SHM,3`V+CDP,"==(#T@)U-O8V]R<F\@375N:6-I
M<&%L+"!.32<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-"XQ
M,C0Z+3$Q.2XQ,C(G72`]("=0;VEN="!-=6=U+"!.879A;"!!:7(@5V%R9F%R
M92!#96YT97(L($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S,T+C(P,#HM,3$X+C,V-2==(#T@)T)U<F)A;FLL($)U<F)A;FLM1VQE;F1A
M;&4M4&%S861E;F$@06ER<&]R="P@0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,S0N,C,S.BTQ,3@N,#8W)UT@/2`G36]U;G0@5VEL<V]N
M+"!#02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-"XR-C@Z
M+3@X+C<W,"==(#T@)U1U<&5L;RP@5'5P96QO(%)E9VEO;F%L($%I<G!O<G0L
M($U3)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,T+C,P,#HM
M,3`S+C@P,"==(#T@)TUE;')O<V4@1W5N;F5R>2!286YG92P@3DTG.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S0N,S0X.BTX-2XQ-C$G72`]
M("=2;VUE+"!2+B!"+B!2=7-S96QL($%I<G!O<G0L($=!)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S,T+C4Q-SHM.38N.3@S)UT@/2`G4W5L
M<&AU<B!-=6YI8VEP86PL($]+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S,T+C8P,#HM.3@N-#`P)UT@/2`G1F]R="!3:6QL+"!/2R<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-"XV,S`Z+3$Q."XP.#$G
M72`]("=086QM9&%L92P@4&%L;61A;&4@4')O9'5C=&EO;B!&;&EG:'0@4&QA
M;G0L($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,T+C8T
M-#HM.#8N-S@V)UT@/2`G2'5N='-V:6QL92P@2'5N='-V:6QL92!);G1E<FYA
M=&EO;F%L("\@2F]N97,@1FEE;&0L($%,)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S,T+C8U,#HM.3DN,C8W)UT@/2`G06QT=7,@06ER($9O
M<F-E($)A<V4L($]+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S,T+C<S.3HM.3(N,C<X)UT@/2`G3&ET=&QE(%)O8VLL($AE:6=H=',L($%2
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,T+C<T-#HM,3$X
M+C<R-"==(#T@)U-A;F1B97)G+"!#02<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<S-"XW-3`Z+3$R,"XU-C<G72`]("=686YD96YB97)G($%I
M<B!&;W)C92!"87-E+"!#02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<S-"XW.#,Z+3<V+C@X,R==(#T@)TYE=W!O<G0L($Y#)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,T+C@S,SHM.3(N,C4P)UT@/2`G
M3F]R=&@@3&ET=&QE(%)O8VLL($YO<G1H($QI='1L92!2;V-K($%I<G!O<G0L
M($%2)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,T+C@X-#HM
M.#(N,C(Q)UT@/2`G1W)E97(L($=R965N=FEL;&4M4W!A<G1A;F)U<F<@06ER
M<&]R="P@4T,G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S0N
M.#DX.BTW-BXX.#$G72`]("=#:&5R<GD@4&]I;G0L($UA<FEN92!#;W)P<R!!
M:7(@4W1A=&EO;BP@3D,G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG,S0N.#DY.BTQ,C`N-#0Y)UT@/2`G4V%N=&$@36%R:6$L(%-A;G1A($UA
M<FEA(%!U8FQI8R!!:7)P;W)T+"!#02<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<S-"XY,3<Z+3$Q-RXY,#`G72`]("=%9'=A<F1S($%I<B!&
M;W)C92!"87-E+"!#02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<S-2XP,C@Z+3$Q,"XW,C$G72`]("=7:6YS;&]W+"!7:6YS;&]W($UU;FEC
M:7!A;"!!:7)P;W)T+"!!6B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<S-2XP,S,Z+3@U+C(P,"==(#T@)T-H871T86YO;V=A+"!,;W9E;&P@
M1FEE;&0L(%1.)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,U
M+C`T,CHM,3`V+C8Q-2==(#T@)T%L8G5Q=65R<75E+"!!;&)U<75E<G%U92!)
M;G1E<FYA=&EO;F%L($%I<G!O<G0L($Y-)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S,U+C`V,3HM.#DN.3@U)UT@/2`G365M<&AI<RP@365M
M<&AI<R!);G1E<FYA=&EO;F%L($%I<G!O<G0L(%1.)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S,U+C$S,SHM-S@N.3,S)UT@/2`G1F]R="!"
M<F%G9R`O(%-I;6UO;G,@07)M>2!!:7)F:65L9"P@3D,G.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG,S4N,34P.BTW-2XS,#`G72`]("=$:6%M
M;VYD(%-H;V%L<R!#;V%S="!'=6%R9"!3=&%T:6]N+"!.0R<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<S-2XQ-C<Z+3<Y+C`S,R==(#T@)U!O
M<&4@06ER($9O<F-E($)A<V4L($Y#)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S,U+C(Q,SHM.#`N.30Y)UT@/2`G0VAA<FQO='1E+"!#:&%R
M;&]T=&4@+R!$;W5G;&%S($EN=&5R;F%T:6]N86P@06ER<&]R="P@3D,G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S4N,C$W.BTY-RXT-3`G
M72`]("=.;W)M86X@+R!-87@@5V5S=&AE:6UE<BP@3TLG.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG,S4N,C(P.BTQ,#$N-S$W)UT@/2`G06UA
M<FEL;&\L($%M87)I;&QO($EN=&5R;F%T:6]N86P@06ER<&]R="P@5%@G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S4N,C4X.BTQ,3,N.3,S
M)UT@/2`G2VEN9VUA;BP@2VEN9VUA;B!!:7)P;W)T+"!!6B<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<S-2XR-3DZ+3DS+C`Y,R==(#T@)U)U
M<W-E;&QV:6QL92P@4G5S<V5L;'9I;&QE(%)E9VEO;F%L($%I<G!O<G0L($%2
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,U+C(V-SHM,3$W
M+C0S,R==(#T@)T-U9&1L96)A8VL@1W5N;F5R>2!286YG92P@0T$G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S4N,C8W.BTW-2XU-3`G72`]
M("=#87!E($AA='1E<F%S+"!.0R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<S-2XR.#,Z+3$Q-BXV,3<G72`]("=":6-Y8VQE($QA:V4@52X@
M4RX@07)M>2!!:7)F:65L9"P@0V$L($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S,U+C,S-#HM.30N,S8U)UT@/2`G1F]R="!3;6ET:"P@
M1F]R="!3;6ET:"!296=I;VYA;"!!:7)P;W)T+"!!4B<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<S-2XS.#DZ+3DW+C8P,"==(#T@)T]K;&%H
M;VUA($-I='DL(%=I;&P@4F]G97)S(%=O<FQD($%I<G!O<G0L($]+)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,U+C0P,#HM.38N,#$W)UT@
M/2`G2&5N<GEE='1A($UU;FEC:7!A;"P@3TLG.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,S4N-#$W.BTY-RXS.#,G72`]("=4:6YK97(@06ER
M($9O<F-E($)A<V4L($]+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S,U+C0S,CHM.#(N-3,W)UT@/2`G07-H979I;&QE+"!!<VAE=FEL;&4@
M4F5G:6]N86P@06ER<&]R="P@3D,G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG,S4N-#,T.BTQ,3DN,#4W)UT@/2`G0F%K97)S9FEE;&0L($UE
M861O=W,@1FEE;&0@06ER<&]R="P@0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,S4N-C4P.BTQ,#DN,#8W)UT@/2`G5VEN9&]W(%)O8VLL
M(%=I;F1O=R!2;V-K($%I<G!O<G0L($%:)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S,U+C8V-CHM,3(Q+C(X-2==(#T@)U!O:6YT(%!I961R
M87,@0FQA;F-A+"!#02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<S-2XV-C<Z+3<U+CDP,"==(#T@)T1A<F4@0V]U;G1Y($=U;FYE<GD@4F%N
M9V4L($Y#)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,U+C8X
M-CHM,3$W+C8Y,"==(#T@)T-H:6YA($QA:V4L($YA=F%L($%I<B!&86-I;&ET
M>2P@0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S4N.#$X
M.BTX,RXY.#8G72`]("=+;F]X=FEL;&4L($UC1VAE92!4>7-O;B!!:7)P;W)T
M+"!43B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-2XX-S$Z
M+3<X+C<X-B==(#T@)U)A;&5I9V@@+R!$=7)H86TL(%)A;&5I9V@M1'5R:&%M
M($EN=&5R;F%T:6]N86P@06ER<&]R="P@3D,G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,S8N,#<Y.BTQ,34N,34U)UT@/2`G3&%S(%9E9V%S
M+"!-8T-A<G)A;B!);G1E<FYA=&EO;F%L($%I<G!O<G0L($Y6)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,V+C`Y.#HM-SDN.30T)UT@/2`G
M1W)E96YS8F]R;RP@4&EE9&UO;G0@5')I860@26YT97)N871I;VYA;"!!:7)P
M;W)T+"!.0R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-BXQ
M,3DZ+3@V+C8X.2==(#T@)TYA<VAV:6QL92P@3F%S:'9I;&QE($EN=&5R;F%T
M:6]N86P@06ER<&]R="P@5$XG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG,S8N,3DW.BTY-2XX.#8G72`]("=4=6QS82P@5'5L<V$@26YT97)N
M871I;VYA;"!!:7)P;W)T+"!/2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<S-BXS,#0Z+3$Q.2XY,S@G72`]("=,96UO;W)E+"!.879A;"!!
M:7(@4W1A=&EO;BP@0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG,S8N,S,S.BTQ,3<N,3`P)UT@/2`G4W5P97)I;W(@5F%L;&5Y($=U;FYE
M<GD@4F%N9V4L($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S,V+C0S,SHM.38N,S@S)UT@/2`G2&]M:6YY($UU;FEC:7!A;"P@3TLG.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S8N-#,W.BTY.2XU,C$G
M72`]("=7;V]D=V%R9"P@5V5S="!7;V]D=V%R9"!!:7)P;W)T+"!/2R<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-BXT-#@Z+3$P,RXQ-3,G
M72`]("=#;&%Y=&]N+"!#;&%Y=&]N($UU;FEC:7!A;"!!:7)P87)K+"!.32<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-BXU,S,Z+3$Q-2XY
M,#`G72`]("=);F1I86X@4W!R:6YG<R!'=6YN97)Y(%)A;F=E+"!.5B<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-BXV,C$Z+3$Q-BXP,C@G
M72`]("=-97)C=7)Y+"!$97-E<G0@4F]C:R!!:7)P;W)T+"!.5B<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-BXV-C<Z+3@W+C4P,"==(#T@
M)T9O<G0@0V%M<&)E;&P@52X@4RX@07)M>2!!:7)F:65L9"P@2UDG.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S8N-S@P.BTQ,3DN-S$Y)UT@
M/2`G1G)E<VYO+"!&<F5S;F\@06ER(%1E<FUI;F%L+"!#02<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<S-BXY,#0Z+3<V+C$Y,B==(#T@)TYO
M<F9O;&LL($YO<F9O;&L@26YT97)N871I;VYA;"!!:7)P;W)T+"!602<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-BXY,C$Z+3$Q,2XT-#@G
M72`]("=086=E+"!086=E($UU;FEC:7!A;"!!:7)P;W)T+"!!6B<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-RXP,#`Z+3$P,2XX.#,G72`]
M("=%;&MH87)T("\@16QK:&%R="U-;W)T;VX@0V]U;G1Y($%I<G!O<G0L($M3
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,W+C`U-CHM.#@N
M-S<T)UT@/2`G4&%D=6-A:"P@0F%R:VQE>2!296=I;VYA;"!!:7)P;W)T+"!+
M62<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-RXP.#,Z+3<V
M+C,U,"==(#T@)TQA;F=L97D@06ER($9O<F-E($)A<V4L(%9!)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,W+C(T,#HM.3,N,SDP)UT@/2`G
M4W!R:6YG9FEE;&0L(%-P<FEN9V9I96QD(%)E9VEO;F%L($%I<G!O<G0L($U/
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,W+C(X-#HM.3@N
M-34S)UT@/2`G365D:6-I;F4@3&]D9V4L($UE9&EC:6YE($QO9&=E+"!+4R<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-RXS,3<Z+3<Y+CDW
M-"==(#T@)U)O86YO:V4L(%)O86YO:V4@4F5G:6]N86P@06ER<&]R="P@5D$G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S<N,S(Q.BTW.2XR
M,#<G72`]("=,>6YC:&)U<F<L($QY;F-H8G5R9R!296=I;VYA;"!!:7)P;W)T
M+"!602<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-RXS-C<Z
M+3$R,"XU-C<G72`]("=-97)C960@+R!#87-T;&4@06ER($9O<F-E($)A<V4L
M($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,W+C,W,3HM
M,3$X+C,U."==(#T@)T)I<VAO<"P@0FES:&]P($%I<G!O<G0L($-!)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,W+C0P-CHM,3(R+C`T."==
M(#T@)TUO=6YT86EN(%9I97<L($UO9F9E='0@1FEE;&0L($-!)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,W+C0S.3HM,3`U+C@V,2==(#T@
M)T%L86UO<V$L(%-A;B!,=6ES(%9A;&QE>2!296=I;VYA;"!!:7)P;W)T+"!#
M3R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-RXU,3$Z+3<W
M+C,R,R==(#T@)U)I8VAM;VYD+"!2:6-H;6]N9"!);G1E<FYA=&EO;F%L($%I
M<G!O<G0L(%9!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,W
M+C8Q,CHM,3$T+C4R-B==(#T@)T-A;&EE;G1E+"!.5B<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<S-RXV,C`Z+3$R,BXS-C4G72`]("=386X@
M1G)A;F-I<V-O+"!386X@1G)A;F-I<V-O($EN=&5R;F%T:6]N86P@06ER<&]R
M="P@0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S<N-C0W
M.BTY-RXT,CDG72`]("=7:6-H:71A+"!7:6-H:71A($UI9"U#;VYT:6YE;G0@
M06ER<&]R="P@2U,G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M,S<N-S`P.BTQ,C,N,#`P)UT@/2`G1F%R86QL;VX@27-L86YD+"!#02<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-RXW,#`Z+3DX+C<U,"==
M(#T@)U!R871T($UU;FEC:7!A;"P@2U,G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,S<N-S$Y.BTQ,C(N,C,U)UT@/2`G3V%K;&%N9"P@365T
M<F\@3V%K;&%N9"!);G1E<FYA=&EO;F%L($%I<G!O<G0L($-!)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,W+C<W,SHM.3DN.3<P)UT@/2`G
M1&]D9V4@0VET>2P@1&]D9V4@0VET>2!296=I;VYA;"!!:7)P;W)T+"!+4R<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-RXW.#,Z+3$R,BXS
M,3<G72`]("=!;&%M961A($YA=F%L($%I<B!3=&%T:6]N+"!#02<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-RXW.34Z+3@Q+C$R-2==(#T@
M)T)E8VML97DL(%)A;&5I9V@@0V]U;G1Y($UE;6]R:6%L($%I<G!O<G0L(%=6
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,W+C@Y,#HM,3(Q
M+C(R-"==(#T@)U-T;V-K=&]N+"!3=&]C:W1O;B!-971R;W!O;&ET86X@06ER
M<&]R="P@0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S<N
M.3`P.BTX-2XY-C<G72`]("=&;W)T($MN;W@L($M9)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S,W+CDT,3HM-S4N-#8S)UT@/2`G5V%L;&]P
M<R!)<VQA;F0L(%=A;&QO<',@1FQI9VAT($9A8VEL:71Y($%I<G!O<G0L(%9!
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,X+C`T,3HM.#0N
M-C`V)UT@/2`G3&5X:6YG=&]N+"!";'5E($=R87-S($%I<G!O<G0L($M9)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,X+C`T,SHM.#<N-3(P
M)UT@/2`G179A;G-V:6QL92P@179A;G-V:6QL92!296=I;VYA;"!!:7)P;W)T
M+"!)3B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S."XQ-S<Z
M+3@U+C<S,"==(#T@)TQO=6ES=FEL;&4L(%-T86YD:69O<F0@1FEE;&0L($M9
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,X+C(V-SHM,3(Q
M+CDU,"==(#T@)T9A:7)F:65L9"`O(%1R879I<R!!:7(@1F]R8V4@0F%S92P@
M0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S@N,C<Y.BTW
M-BXT,30G72`]("=0871U>&5N="!2:79E<BP@3F%V86P@06ER(%-T871I;VXL
M($U$)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,X+C(Y,#HM
M,3`T+C0Y."==(#T@)U!U96)L;RP@4'5E8FQO($UE;6]R:6%L($%I<G!O<G0L
M($-/)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,X+C,S,SHM
M-S4N,#@S)UT@/2`G3V-E86X@0VET>2P@340G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,S@N,S8U.BTX,BXU-34G72`]("=(=6YT:6YG=&]N
M+"!4<FDM4W1A=&4@06ER<&]R="P@5U8G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,S@N,S<Y.BTX,2XU.3$G72`]("=#:&%R;&5S=&]N+"!9
M96%G97(@06ER<&]R="P@5U8G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG,S@N-3`W.BTQ,C$N-#DU)UT@/2`G4V%C<F%M96YT;RP@4V%C<F%M
M96YT;R!%>&5C=71I=F4@06ER<&]R="P@0T$G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,S@N-C0S.BTX."XY-C0G72`]("=386QE;2P@4V%L
M96TM3&5C:W)O;F4@06ER<&]R="P@24PG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,S@N-S`P.BTQ,#0N-S8W)UT@/2`G1F]R="!#87)S;VXL
M($-/)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,X+C<U,CHM
M.3`N,S<T)UT@/2`G4W0N($QO=6ES+"!,86UB97)T+5-T+B!,;W5I<R!);G1E
M<FYA=&EO;F%L($%I<G!O<G0L($U/)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S,X+C@Q-CHM,3`T+C<Q,2==(#T@)T-O;&]R861O(%-P<FEN
M9W,L($-I='D@3V8@0V]L;W)A9&\@4W!R:6YG<R!-=6YI8VEP86P@06ER<&]R
M="P@0T\G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S@N.#$W
M.BTW-BXX-3`G72`]("=#86UP(%-P<FEN9W,@+R!!;F1R97=S($%I<B!&;W)C
M92!"87-E+"!-1"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S
M."XX,3<Z+3DR+C(Q."==(#T@)T-O;'5M8FEA+"!#;VQU;6)I82!296=I;VYA
M;"!!:7)P;W)T+"!-3R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<S."XX-#@Z+3<W+C`S-"==(#T@)U=A<VAI;F=T;VX@1$,L(%)E86=A;B!.
M871I;VYA;"!!:7)P;W)T+"!602<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<S."XX.#4Z+3<Y+C@U,R==(#T@)T5L:VEN<RP@16QK:6YS+5)A
M;F1O;'!H($-O=6YT>2U*96YN:6YG<R!286YD;VQP:"!&:65L9"P@5U8G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S@N.3,U.BTW-RXT-#@G
M72`]("=787-H:6YG=&]N($1#+"!787-H:6YG=&]N+41U;&QE<R!);G1E<FYA
M=&EO;F%L($%I<G!O<G0L(%9!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S,X+CDV-SHM,3`T+C@Q-R==(#T@)T%I<B!&;W)C92!!8V%D96UY
M+"!#3R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S.2XP-#,Z
M+3@T+C8W,B==(#T@)T-O=FEN9W1O;B`O($-I;F-I;FYA=&DL($-I;F-I;FYA
M=&D@+R!.;W)T:&5R;B!+96YT=6-K>2!);G1E<FYA=&EO;F%L($%I<G!O<G0L
M($M9)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,Y+C`W,SHM
M.34N-C(V)UT@/2`G5&]P96MA+"!0:&EL:7`@0FEL;&%R9"!-=6YI8VEP86P@
M06ER<&]R="P@2U,G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M,SDN,3`P.BTY-BXW-C<G72`]("=&;W)T(%)I;&5Y+"!+4R<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<S.2XQ,S0Z+3$P."XU,SDG72`]("='
M<F%N9"!*=6YC=&EO;BP@5V%L:V5R($9I96QD+"!#3R<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<S.2XQ-C<Z+3<V+C8X,R==(#T@)T)A;'1I
M;6]R92P@0F%L=&EM;W)E+5=A<VAI;F=T;VX@26YT97)N871I;VYA;"!!:7)P
M;W)T+"!-1"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S.2XR
M.34Z+3$Q-"XX-#4G72`]("=%;'DL($5L>2!!:7)P;W)T+"!.5B<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S.2XR.3<Z+3DT+C<S,2==(#T@
M)TMA;G-A<R!#:71Y+"!+86YS87,@0VET>2!);G1E<FYA=&EO;F%L($%I<G!O
M<G0L($U/)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,Y+C,V
M-SHM,3`Q+C8Y,R==(#T@)T=O;V1L86YD+"!296YN97(@1FEE;&0L($M3)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,Y+C0P,#HM,3(S+C@Q
M-R==(#T@)T9O<G0@0G)A9V<L($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S,Y+C0V-3HM-S0N-3@W)UT@/2`G071L86YT:6,@0VET>2P@
M071L86YT:6,@0VET>2!);G1E<FYA=&EO;F%L($%I<G!O<G0L($Y*)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,Y+C0X-#HM,3$Y+C<W,2==
M(#T@)U)E;F\L(%)E;F\@5&%H;V4@26YT97)N871I;VYA;"!!:7)P;W)T+"!.
M5B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S.2XU-3$Z+3DW
M+C8U,2==(#T@)T-O;F-O<F1I82P@0FQO<W-E<B!-=6YI8VEP86P@06ER<&]R
M="P@2U,G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,SDN-C`Y
M.BTQ,3`N-S4U)UT@/2`G4')I8V4L($-A<F)O;B!#;W5N='D@06ER<&]R="P@
M550G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,SDN-S(U.BTX
M-BXR.#(G72`]("=);F1I86YA<&]L:7,L($EN9&EA;F%P;VQI<R!);G1E<FYA
M=&EO;F%L($%I<G!O<G0L($E.)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S,Y+C<V-SHM-S0N,3`P)UT@/2`G0F%R;F5G870@0V]A<W0@1W5A
M<F0@4W1A=&EO;BP@3DHG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG,SDN-S8X.BTY-"XY,#DG72`]("=3="X@2F]S97!H+"!2;W-E8W)A;G,@
M365M;W)I86P@06ER<&]R="P@34\G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG,SDN-S@S.BTQ,#0N.#8W)UT@/2`G1&5N=F5R("\@4W1A<&QE
M=&]N($EN=&5R;F%T:6]N86PL($-O+BP@0T\G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,SDN.#,S.BTQ,#0N-C4W)UT@/2`G1&5N=F5R+"!$
M96YV97(@26YT97)N871I;VYA;"!!:7)P;W)T+"!#3R<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<S.2XX,S,Z+3@T+C`U,"==(#T@)T1A>71O
M;B`O(%=R:6=H="U0871T97)S;VX@06ER($9O<F-E($)A<V4L($]()SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,Y+C@T-3HM.#DN-C@T)UT@
M/2`G4W!R:6YG9FEE;&0L($-A<&ET86P@06ER<&]R="P@24PG.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG,SDN.#8X.BTW-2XR,S$G72`]("=0
M:&EL861E;'!H:6$L(%!H:6QA9&5L<&AI82!);G1E<FYA=&EO;F%L($%I<G!O
M<G0L(%!!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,Y+CDP
M-CHM.#0N,C$Y)UT@/2`G1&%Y=&]N+"!#;W@@1&%Y=&]N($EN=&5R;F%T:6]N
M86P@06ER<&]R="P@3T@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG,SDN.3DU.BTX,BXX-S8G72`]("=#;VQU;6)U<RP@4&]R="!#;VQU;6)U
M<R!);G1E<FYA=&EO;F%L($%I<G!O<G0L($]()SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S0P+C`S,SHM-S0N,S$W)UT@/2`G3&%K96AU<G-T
M($YA=F%L($%I<B!3=&%T:6]N+"!.2B<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<T,"XQ-3$Z+3$R,BXR-3(G72`]("=2960@0FQU9F8L(%)E
M9"!";'5F9B!-=6YI8VEP86P@06ER<&]R="P@0T$G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG-#`N,38W.BTQ,3(N.3,S)UT@/2`G1'5G=V%Y
M(%!R;W9I;F<@1W)O=6YD<RP@550G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG-#`N,C4P.BTY,RXW,3<G72`]("=3<&EC:V%R9"P@34\G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#`N,S`P.BTQ,#DN.3@S
M)UT@/2`G4F]O<V5V96QT+"!55"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<T,"XT.3,Z+3$P-RXU,C0G72`]("=#<F%I9RP@0W)A:6<M36]F
M9F%T($%I<G!O<G0L($-/)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S0P+C4P-#HM.#`N,C8V)UT@/2`G4&ET='-B=7)G:"P@4&ET='-B=7)G
M:"!);G1E<FYA=&EO;F%L($%I<G!O<G0L(%!!)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S0P+C4Q-3HM,3(R+C(Y-R==(#T@)U)E9&1I;F<L
M(%)E9&1I;F<@375N:6-I<&%L($%I<G!O<G0L($-!)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S0P+C8S.3HM-S,N-S8R)UT@/2`G3F5W(%EO
M<FLL($ME;FYE9'D@26YT97)N871I;VYA;"!!:7)P;W)T+"!.62<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,"XV-3$Z+3<U+C0T.2==(#T@
M)T%L;&5N=&]W;BP@3&5H:6=H(%9A;&QE>2!);G1E<FYA=&EO;F%L($%I<G!O
M<G0L(%!!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0P+C8V
M-SHM.#DN-C@T)UT@/2`G4&5O<FEA+"!'<F5A=&5R(%!E;W)I82!296=I;VYA
M;"!!:7)P;W)T+"!)3"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<T,"XV.#(Z+3<T+C$V.2==(#T@)TYE=V%R:RP@3F5W87)K($EN=&5R;F%T
M:6]N86P@06ER<&]R="P@3DHG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG-#`N-S,S.BTQ,30N,#,S)UT@/2`G5V5N9&]V97(@+R!!:7(@1F]R
M8V4@075X:6QL87)Y($9I96QD+"!55"<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<T,"XW-S@Z+3$Q,2XY-CDG72`]("=386QT($QA:V4@0VET
M>2P@4V%L="!,86ME($-I='D@26YT97)N871I;VYA;"!!:7)P;W)T+"!55"<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,"XW-SDZ+3<S+C@X
M,"==(#T@)TYE=R!9;W)K+"!,82!'=6%R9&EA($%I<G!O<G0L($Y9)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0P+C@P,#HM,3(T+C$V-R==
M(#T@)T5U<F5K82P@0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG-#`N.#,Q.BTY-BXW-C0G72`]("=,:6YC;VQN+"!,:6YC;VQN($UU;FEC
M:7!A;"!!:7)P;W)T+"!.12<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<T,"XY,#(Z+3$Q-RXX,#<G72`]("=7:6YN96UU8V-A+"!7:6YN96UU
M8V-A($UU;FEC:7!A;"!!:7)P;W)T+"!.5B<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<T,"XY,3@Z+3@Q+C0T,R==(#T@)T%K<F]N+"!!:W)O
M;BU#86YT;VX@4F5G:6]N86P@06ER<&]R="P@3T@G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG-#`N.34X.BTY."XS,3,G72`]("='<F%N9"!)
M<VQA;F0L($-E;G1R86P@3F5B<F%S:V$@4F5G:6]N86P@06ER<&]R="P@3D4G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#`N.3<X.BTX-2XQ
M.34G72`]("=&;W)T(%=A>6YE+"!&;W)T(%=A>6YE($EN=&5R;F%T:6]N86P@
M06ER<&]R="P@24XG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M-#$N,#DY.BTQ,#(N.3@V)UT@/2`G4VED;F5Y+"!3:61N97D@375N:6-I<&%L
M($%I<G!O<G0L($Y%)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S0Q+C$Q-SHM.34N.3`P)UT@/2`G3VUA:&$@+R!/9F9U='0@06ER($9O<F-E
M($)A<V4L($Y%)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0Q
M+C$R,CHM,3`P+C8V."==(#T@)TYO<G1H(%!L871T92P@3F]R=&@@4&QA='1E
M(%)E9VEO;F%L($%I<G!O<G0L($Y%)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S0Q+C$U.#HM,3`T+C@P-R==(#T@)T-H97EE;FYE+"!#:&5Y
M96YN92!!:7)P;W)T+"!762<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<T,2XQ-3@Z+3<S+C$R.2==(#T@)T)R:61G97!O<G0L(%-I:V]R<VMY
M($UE;6]R:6%L($%I<G!O<G0L($-4)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S0Q+C$Y-#HM,3$R+C`Q-B==(#T@)T]G9&5N+"!/9V1E;BU(
M:6YC:VQE>2!!:7)P;W)T+"!55"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<T,2XR-#,Z+3<V+CDR,B==(#T@)U=I;&QI86US<&]R="P@5VEL
M;&EA;7-P;W)T+4QY8V]M:6YG($-O=6YT>2!!:7)P;W)T+"!002<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,2XR-30Z+3@P+C8W-"==(#T@
M)UEO=6YG<W1O=VXL(%EO=6YG<W1O=VXM5V%R<F5N(%)E9VEO;F%L($%I<G!O
M<G0L($]()SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0Q+C,Q
M,#HM.34N.#DY)UT@/2`G3VUA:&$L($5P<&QE>2!!:7)F:65L9"P@3D4G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#$N,S$W.BTY-BXS-C<G
M72`]("=686QL97DL($Y%)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S0Q+C,S.3HM-S4N-S(W)UT@/2`G5VEL:V5S+4)A<G)E("T@4V-R86YT
M;VXL(%=I;&ME<RU"87)R92`O(%-C<F%N=&]N($EN=&5R;F%T:6]N86P@06ER
M<&]R="P@4$$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#$N
M,S8W.BTX."XV.#,G72`]("=-87)S96EL;&5S($ES;&%N9"P@24PG.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#$N-#`U.BTX,2XX-3,G72`]
M("=#;&5V96QA;F0L($-L979E;&%N9"U(;W!K:6YS($EN=&5R;F%T:6]N86P@
M06ER<&]R="P@3T@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M-#$N-#4Q.BTY,"XU,34G72`]("=-;VQI;F4L(%%U860M0VET>2!!:7)P;W)T
M+"!)3"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,2XU,S@Z
M+3DS+C8V-B==(#T@)T1E<R!-;VEN97,L($1E<R!-;VEN97,@26YT97)N871I
M;VYA;"!!:7)P;W)T+"!)02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<T,2XU.#DZ+3@S+C@P,2==(#T@)U1O;&5D;RP@5&]L961O($5X<')E
M<W,@06ER<&]R="P@3T@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG-#$N-3DT.BTQ,#DN,#8U)UT@/2`G4F]C:R!3<')I;F=S+"!2;V-K(%-P
M<FEN9W,M4W=E971W871E<B!#;W5N='D@06ER<&]R="P@5UDG.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#$N-C4P.BTW,"XU,3<G72`]("=/
M=&ES($%I<B!.871I;VYA;"!'=6%R9"!"87-E+"!-02<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<T,2XV-C<Z+38Y+CDV-R==(#T@)T-H871H
M86TL($U!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0Q+C<P
M.3HM.#8N,S$Y)UT@/2`G4V]U=&@@0F5N9"P@4V]U=&@@0F5N9"!296=I;VYA
M;"!!:7)P;W)T+"!)3B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<T,2XW,C0Z+3<Q+C0R."==(#T@)U!R;W9I9&5N8V4L(%1H96]D;W)E($9R
M86YC:7,@1W)E96X@4W1A=&4@06ER<&]R="P@4DDG.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG-#$N-S@T.BTX-RXW-34G72`]("=#:&EC86=O
M+"!#:&EC86=O($UI9'=A>2!!:7)P;W)T+"!)3"<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<T,2XX-C<Z+3$P,RXU.#8G72`]("=38V]T='-B
M;'5F9BP@2&5I;&EG($9I96QD+"!.12<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<T,2XX.#,Z+3DQ+C<R-"==(#T@)T-E9&%R(%)A<&ED<RP@
M0V5D87(@4F%P:61S($UU;FEC:7!A;"!!:7)P;W)T+"!)02<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<T,2XY,S@Z+3<R+C8X,R==(#T@)U=I
M;F1S;W(@3&]C:W,L($)R861L97D@26YT97)N871I;VYA;"!!:7)P;W)T+"!#
M5"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,2XY.#`Z+3@W
M+CDP-"==(#T@)T-H:6-A9V\L($-H:6-A9V\M3UPG2&%R92!);G1E<FYA=&EO
M;F%L($%I<G!O<G0L($E,)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S0Q+CDX,3HM.3<N-#,W)UT@/2`G3F]R9F]L:RP@4W1E9F%N($UE;6]R
M:6%L($%I<G!O<G0L($Y%)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S0R+C`X,#HM.#`N,3@S)UT@/2`G17)I92P@17)I92!);G1E<FYA=&EO
M;F%L($%I<G!O<G0L(%!!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S0R+C$Y,SHM.#DN,#DS)UT@/2`G4F]C:V9O<F0L($=R96%T97(@4F]C
M:V9O<F0@06ER<&]R="P@24PG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG-#(N,C`P.BTW,BXU,S,G72`]("=#:&EC;W!E92!&86QL<R`O(%=E
M<W1O=F5R($%I<B!&;W)C92!"87-E+"!-02<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<T,BXR,#@Z+3<U+CDX,2==(#T@)T)I;F=H86UT;VXL
M($)I;F=H86UT;VX@4F5G:6]N86P@06ER<&]R="P@3EDG.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG-#(N,C,Q.BTX,RXS,S$G72`]("=$971R
M;VET+"!$971R;VET($UE=')O<&]L:71A;B!787EN92!#;W5N='D@06ER<&]R
M="P@34DG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#(N,S8Q
M.BTW,2XP,3$G72`]("=";W-T;VXL($QO9V%N($EN=&5R;F%T:6]N86P@06ER
M<&]R="P@34$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#(N
M,S@Q.BTQ,C(N.#<R)UT@/2`G365D9F]R9"P@4F]G=64@5F%L;&5Y($EN=&5R
M;F%T:6]N86P@06ER<&]R="P@3U(G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG-#(N,SDX.BTY,"XW,#0G72`]("=$=6)U<75E+"!$=6)U<75E
M(%)E9VEO;F%L($%I<G!O<G0L($E!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S0R+C0P,CHM.38N,S@T)UT@/2`G4VEO=7@@0VET>2P@4VEO
M=7@@1V%T97=A>2!!:7)P;W)T+"!)02<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<T,BXT-C@Z+3<Q+C(Y-"==(#T@)T)E9&9O<F0L($AA;G-C
M;VT@1FEE;&0L($U!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S0R+C4U,#HM.30N,3@S)UT@/2`G1F]R="!$;V1G92P@24$G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#(N-34T.BTY,BXT,#$G72`]("=7
M871E<FQO;RP@5V%T97)L;V\@375N:6-I<&%L($%I<G!O<G0L($E!)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0R+C4W.3HM,3$P+C$P,R==
M(#T@)T)I9R!0:6YE>2P@0FEG(%!I;F5Y+4UA<F)L971O;B!!:7)P;W)T+"!7
M62<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,BXW-#<Z+3<S
M+C<Y.2==(#T@)T%L8F%N>2P@06QB86YY($-O=6YT>2!!:7)P;W)T+"!.62<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,BXW.#`Z+3@T+C4W
M.2==(#T@)TQA;G-I;F<L($-A<&ET86P@0VET>2!!:7)P;W)T+"!-22<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,BXW.30Z+3$P-2XS.#(G
M72`]("=$;W5G;&%S+"!#;VYV97)S92!#;W5N='D@06ER<&]R="P@5UDG.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#(N.#$U.BTQ,#@N-S(X
M)UT@/2`G3&%N9&5R+"!762<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<T,BXX-3DZ+3$P,"XU-3$G72`]("=686QE;G1I;F4L($UI;&QE<B!&
M:65L9"P@3D4G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#(N
M.#@Q.BTX-2XU,C,G72`]("='<F%N9"!287!I9',L($=E<F%L9"!2+B!&;W)D
M($EN=&5R;F%T:6]N86P@06ER<&]R="P@34DG.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG-#(N.#DX.BTQ,#8N-#<S)UT@/2`G0V%S<&5R+"!.
M871R;VYA($-O=6YT>2!);G1E<FYA=&EO;F%L($%I<G!O<G0L(%=9)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0R+CDR,#HM,3$R+C4W,2==
M(#T@)U!O8V%T96QL;RP@4&]C871E;&QO(%)E9VEO;F%L($%I<G!O<G0L($E$
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0R+CDT,3HM-S@N
M-S,V)UT@/2`G0G5F9F%L;RP@1W)E871E<B!"=69F86QO($EN=&5R;F%T:6]N
M86P@06ER<&]R="P@3EDG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG-#(N.34U.BTX-RXY,#0G72`]("=-:6QW875K964L($=E;F5R86P@36ET
M8VAE;&P@26YT97)N871I;VYA;"!!:7)P;W)T+"!722<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<T,BXY-C<Z+3@S+C<T.2==(#T@)T9L:6YT
M+"!":7-H;W`@26YT97)N871I;VYA;"!!:7)P;W)T+"!-22<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<T,RXP-C(Z+3$P."XT-#8G72`]("=2
M:79E<G1O;BP@4FEV97)T;VX@4F5G:6]N86P@06ER<&]R="P@5UDG.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#,N,3`Y.BTW-BXQ,#,G72`]
M("=3>7)A8W5S92P@4WER86-U<V4@2&%N8V]C:R!);G1E<FYA=&EO;F%L($%I
M<G!O<G0L($Y9)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0S
M+C$Q-SHM-S<N-C<W)UT@/2`G4F]C:&5S=&5R+"!'<F5A=&5R(%)O8VAE<W1E
M<B!);G1E<FYA=&EO;F%L($%I<G!O<G0L($Y9)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S0S+C$T,3HM.#DN,S0U)UT@/2`G36%D:7-O;BP@
M1&%N92!#;W5N='D@4F5G:6]N86PM5')U87@@1FEE;&0L(%=))SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0S+C$W,3HM.#8N,C,W)UT@/2`G
M375S:V5G;VXL($UU<VME9V]N($-O=6YT>2!!:7)P;W)T+"!-22<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,RXQ.34Z+3<Q+C4P,2==(#T@
M)T-O;F-O<F0L($-O;F-O<F0@375N:6-I<&%L($%I<G!O<G0L($Y()SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0S+C,Y,3HM.3DN.#0S)UT@
M/2`G5VEN;F5R+"!";V(@5VEL97D@1FEE;&0@06ER<&]R="P@4T0G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#,N-38W.BTQ,38N,C0Q)UT@
M/2`G0F]I<V4L($)O:7-E($%I<B!497)M:6YA;"P@240G.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG-#,N-3<W.BTY-BXW-30G72`]("=3:6]U
M>"!&86QL<RP@1F]S<R!&:65L9"P@4T0G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG-#,N-3DU.BTQ,3@N.34V)UT@/2`G0G5R;G,L($)U<FYS
M($UU;FEC:7!A;"!!:7)P;W)T+"!/4B<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<T,RXV-#(Z+3<P+C,P-"==(#T@)U!O<G1L86YD+"!0;W)T
M;&%N9"!);G1E<FYA=&EO;F%L($IE='!O<G0L($U%)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S0S+C<V-SHM.3DN,S$X)UT@/2`G0VAA;6)E
M<FQA:6XL($-H86UB97)L86EN($UU;FEC:7!A;"!!:7)P;W)T+"!31"<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,RXX-SDZ+3DQ+C(U-R==
M(#T@)TQA($-R;W-S92P@3&$@0W)O<W-E($UU;FEC:7!A;"!!:7)P;W)T+"!7
M22<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,RXY,#`Z+38Y
M+CDS-2==(#T@)T)R=6YS=VEC:RP@3F%V86P@06ER(%-T871I;VXL($U%)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0S+CDP-#HM.3(N-#DR
M)UT@/2`G4F]C:&5S=&5R+"!2;V-H97-T97(@26YT97)N871I;VYA;"!!:7)P
M;W)T+"!-3B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-"XP
M-#8Z+3$P,RXP-30G72`]("=287!I9"!#:71Y+"!287!I9"!#:71Y(%)E9VEO
M;F%L($%I<G!O<G0L(%-$)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S0T+C`U,#HM-S4N-S,S)UT@/2`G1F]R="!$<G5M("\@5VAE96QE<BU3
M86-K(%4N(%,N($%R;7D@06ER9FEE;&0L($Y9)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S0T+C$S,SHM,3(S+C(Q-"==(#T@)T5U9V5N92P@
M36%H;&]N(%-W965T($9I96QD+"!/4B<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<T-"XR-C<Z+3<Q+C,P,"==(#T@)TUO=6YT(%=A<VAI;F=T
M;VXL($Y()SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0T+C,S
M.3HM,3`U+C4T,B==(#T@)T=I;&QE='1E+"!':6QL971T92U#86UP8F5L;"!#
M;W5N='D@06ER<&]R="P@5UDG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG-#0N,S4Q.BTX-"XV-S0G72`]("=(;W5G:'1O;B!,86ME+"!2;W-C
M;VUM;VX@0V]U;G1Y($%I<G!O<G0L($U))SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S0T+C,X.#HM.3@N,C(X)UT@/2`G2'5R;VXL($AU<F]N
M(%)E9VEO;F%L($%I<G!O<G0L(%-$)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S0T+C0Q.3HM-S(N,#$Y)UT@/2`G4V%I;G0@2F]H;G-B=7)Y
M+"!65"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-"XT-C@Z
M+3<S+C$U,"==(#T@)T)U<FQI;F=T;VXL($)U<FQI;F=T;VX@26YT97)N871I
M;VYA;"!!:7)P;W)T+"!65"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<T-"XT-SDZ+3@X+C$S-R==(#T@)T=R965N($)A>2P@075S=&EN(%-T
M<F%U8F5L($EN=&5R;F%T:6]N86P@06ER<&]R="P@5TDG.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG-#0N-3$W.BTQ,#DN,#$W)UT@/2`G0V]D
M>2P@5UDG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#0N-3,S
M.BTW,"XU,S,G72`]("=2=6UF;W)D+"!-12<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<T-"XU-S8Z+3<Q+C$W.2==(#T@)T)E<FQI;BP@0F5R
M;&EN($UU;FEC:7!A;"!!:7)P;W)T+"!.2"<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<T-"XW-CDZ+3$P-BXY-CDG72`]("=3:&5R:61A;BP@
M4VAE<FED86X@0V]U;G1Y($%I<G!O<G0L(%=9)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S0T+C@S,SHM.#0N-34P)UT@/2`G1W)A>6EN9R!!
M:7(@1F]R8V4@4F%N9V4L($U))SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S0T+C@X,SHM.3,N,C(Y)UT@/2`G36EN;F5A<&]L:7,L($UI;FYE
M87!O;&ES+5-T+B!0875L($EN=&5R;F%T:6]N86P@06ER<&]R="P@34XG.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#0N.3`X.BTQ,C(N.3DU
M)UT@/2`G4V%L96TL($UC3F%R>2!&:65L9"P@3U(G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG-#0N.3$W.BTV-RXP,#`G72`]("=%87-T<&]R
M="P@344G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#0N.3,S
M.BTW,BXR,#`G72`]("=.97=P;W)T+"!65"<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<T-2XP-S(Z+3@S+C4V-"==(#T@)T%L<&5N82P@06QP
M96YA($-O=6YT>2!296=I;VYA;"!!:7)P;W)T+"!-22<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<T-2XT-#,Z+3DX+C0Q,R==(#T@)T%B97)D
M965N+"!!8F5R9&5E;B!296=I;VYA;"!!:7)P;W)T+"!31"<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<T-2XU-#4Z+3DT+C`U,B==(#T@)U-T
M+B!#;&]U9"P@4W0N($-L;W5D($UU;FEC:7!A;"!!:7)P;W)T+"!-3B<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-2XU.3$Z+3$R,BXV,#`G
M72`]("=0;W)T;&%N9"P@4&]R=&QA;F0@26YT97)N871I;VYA;"!!:7)P;W)T
M+"!/4B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-2XV.3@Z
M+3$Q."XX,S0G72`]("=096YD;&5T;VXL($5A<W1E<FX@3W)E9V]N(%)E9VEO
M;F%L($%T(%!E;F1L971O;B!!:7)P;W)T+"!/4B<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<T-2XW-3`Z+3@W+C`S,R==(#T@)T5S8V%N86)A
M+"!-22<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-2XX,#<Z
M+3$P."XU-#(G72`]("=":6QL:6YG<RP@0FEL;&EN9W,@3&]G86X@26YT97)N
M871I;VYA;"!!:7)P;W)T+"!-5"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<T-2XY,S,Z+3DP+C0U,"==(#T@)U!A<FL@1F%L;',L(%=))SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0V+C$U-SHM,3(S+C@X
M,B==(#T@)T%S=&]R:6$L($%S=&]R:6$@4F5G:6]N86P@06ER<&]R="P@3U(G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#8N,S<U.BTQ,3<N
M,#$T)UT@/2`G3&5W:7-T;VXL($QE=VES=&]N+4YE>B!097)C92!#;W5N='D@
M06ER<&]R="P@240G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M-#8N-#(X.BTQ,#4N.#@V)UT@/2`G36EL97,@0VET>2P@1G)A;FL@5VEL97D@
M1FEE;&0@06ER<&]R="P@350G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG-#8N-#<Y.BTX-"XS-3<G72`]("=3875L="!3=&4N($UA<FEE+"!-
M22<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-BXU,S,Z+3@W
M+C4U,"==(#T@)TUA<G%U971T92P@34DG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG-#8N-38T.BTQ,C`N-3,T)UT@/2`G66%K:6UA+"!986MI
M;6$@06ER(%1E<FUI;F%L+"!702<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<T-BXU-C<Z+3$Q.2XV,#`G72`]("=(86YF;W)D+"!702<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-BXV,#`Z+3DT+C,Q-R==
M(#T@)U!E<75O="!,86ME+"!-3B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<T-BXV,#8Z+3$Q,2XY-C0G72`]("=(96QE;F$L($AE;&5N82!2
M96=I;VYA;"!!:7)P;W)T+"!-5"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<T-BXV.#,Z+38X+C`U,"==(#T@)U!R97-Q=64@27-L92P@344G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#8N-S@R.BTQ,#`N
M-S4W)UT@/2`G0FES;6%R8VLL($)I<VUA<F-K($UU;FEC:7!A;"!!:7)P;W)T
M+"!.1"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-BXX-#,Z
M+3DR+C(R-B==(#T@)T1U;'5T:"P@1'5L=71H($EN=&5R;F%T:6]N86P@06ER
M<&]R="P@34XG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#8N
M.#8W.BTV."XP,3,G72`]("=#87)I8F]U+"!#87)I8F]U($UU;FEC:7!A;"!!
M:7)P;W)T+"!-12<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T
M-BXY,C$Z+3$Q-"XP.3,G72`]("=-:7-S;W5L82P@36ES<V]U;&$@26YT97)N
M871I;VYA;"!!:7)P;W)T+"!-5"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<T-BXY,C4Z+3DV+C@Q,2==(#T@)T9A<F=O+"!(96-T;W(@26YT
M97)N871I;VYA;"!!:7)P;W)T+"!.1"<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<T-BXY-S,Z+3$R,BXY,#,G72`]("=/;'EM<&EA+"!/;'EM
M<&EA($%I<G!O<G0L(%=!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S0W+C$Q-SHM,3(R+C4U,"==(#T@)T9O<G0@3&5W:7,@+R!'<F%Y(%4N
M(%,N($%R;7D@06ER9FEE;&0L(%=!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S0W+C$U,#HM,3(R+C0X,R==(#T@)U1A8V]M82`O($UC0VAO
M<F0@06ER($9O<F-E($)A<V4L(%=!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S0W+C$V.#HM.#@N-#@Y)UT@/2`G2&%N8V]C:RP@2&]U9VAT
M;VX@0V]U;G1Y($UE;6]R:6%L($%I<G!O<G0L($U))SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S0W+C0T-3HM,3(R+C,Q-"==(#T@)U-E871T
M;&4L(%-E871T;&4M5&%C;VUA($EN=&5R;F%T:6]N86P@06ER<&]R="P@5T$G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#<N-#<S.BTQ,3$N
M,S@R)UT@/2`G1W)E870@1F%L;',L($=R96%T($9A;&QS($EN=&5R;F%T:6]N
M86P@06ER<&]R="P@350G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG-#<N-3`P.BTY-"XY,S,G72`]("="96UI9&II+"!-3B<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<T-RXV,C$Z+3$Q-RXU,C@G72`]("=3
M<&]K86YE+"!3<&]K86YE($EN=&5R;F%T:6]N86P@06ER<&]R="P@5T$G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#<N-S4P.BTQ,#$N.#,S
M)UT@/2`G4F]S96=L96XL($Y$)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S0W+CDS.#HM,3(T+C4U-2==(#T@)U%U:6QL87EU=&4L(%%U:6QL
M87EU=&4@4W1A=&4@06ER<&]R="P@5T$G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG-#@N,3`P.BTY."XX-C<G72`]("=$979I;',@3&%K92P@
M3D0G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#@N,3,S.BTQ
M,C,N-#`P)UT@/2`G4&]R="!!;F=E;&5S($-O87-T($=U87)D($%I<B!3=&%T
M:6]N+"!702<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T."XQ
M-S0Z+3$P,RXV,S<G72`]("=7:6QL:7-T;VXL(%-L;W5L:6X@1FEE;&0@26YT
M97)N871I;VYA;"!!:7)P;W)T+"!.1"<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<T."XR,30Z+3$P-BXV,C$G72`]("=';&%S9V]W+"!';&%S
M9V]W($EN=&5R;F%T:6]N86P@06ER<&]R="P@350G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG-#@N,S`T.BTQ,30N,C8T)UT@/2`G2V%L:7-P
M96QL+"!';&%C:65R(%!A<FL@26YT97)N871I;VYA;"!!:7)P;W)T+"!-5"<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T."XU-#,Z+3$P.2XW
M-C,G72`]("=(879R92P@2&%V<F4@0VET>2U#;W5N='D@06ER<&]R="P@350G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#@N-38R.BTY,RXS
M.3@G72`]("=);G1E<FYA=&EO;F%L($9A;&QS+"!&86QL<R!);G1E<FYA=&EO
M;F%L($%I<G!O<G0L($U.)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S0X+CDS,SHM.34N,S4P)UT@/2`G5V%R<F]A9"P@34XG.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG-3$N.#DP.BTQ-S8N-C(U)UT@/2`G
M061A:RP@3F%V86P@06ER(%-T871I;VXL($%+)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S4R+C<Q-SHQ-S0N,3$W)UT@/2`G4VAE;7EA+"!%
M87)E8VMS;VX@07,L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S4R+CDU,#HM,38X+C@U,"==(#T@)TYI:V]L<VMI+"!!2R<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<U,RXY,#`Z+3$V-BXU-3`G72`]
M("=$=71C:"!(87)B;W(L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S4U+C`S,SHM,3,Q+C4V-R==(#T@)T%N;F5T=&4@27-L86YD+"!!
M2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<U-2XR,C$Z+3$V
M,BXW,C@G72`]("=#;VQD($)A>2P@0V]L9"!"87D@06ER<&]R="P@04LG.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-34N,S4S.BTQ,S$N-S(R
M)UT@/2`G2V5T8VAI:V%N+"!+971C:&EK86X@26YT97)N871I;VYA;"!!:7)P
M;W)T+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<U-2XU
M.#,Z+3$S,RXP.#,G72`]("=+;&%W;V-K+"!+;&%W;V-K($%I<G!O<G0L($%+
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S4V+C0X,SHM,3,R
M+C,V-R==(#T@)U=R86YG96QL+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<U-BXX,3<Z+3$S,BXY-C<G72`]("=0971E<G-B=7)G+"!!
M2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<U-BXY-3`Z+3$U
M."XV,3<G72`]("=0;W)T($AE:61E;BP@04LG.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG-3<N,#0X.BTQ,S4N,S8U)UT@/2`G4VET:V$L(%-I
M=&MA($%I<G!O<G0L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S4W+C$U,#HM,3<P+C(Q-R==(#T@)U-A:6YT(%!A=6PL($%+)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S4W+C4P,#HM,3,T+C4X,R==
M(#T@)T%N9V]O;BP@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG-3<N-S4P.BTQ-3(N-3`P)UT@/2`G2V]D:6%K+"!!2R<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<U."XS-38Z+3$S-"XU-C,G72`]("=*
M=6YE874L($IU;F5A=2!);G1E<FYA=&EO;F%L($%I<G!O<G0L($%+)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S4X+C0Q-SHM,3,U+C<S,R==
M(#T@)T=U<W1A=G5S+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<U."XV-3`Z+3$V,BXP-C<G72`]("=#87!E($YE=V5N:&%M($%I<G=A
M>7,@1F%C:6QI=&EE<R!396-T;W(L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S4X+C8X-#HM,34V+C8U-"==(#T@)TMI;F<@4V%L;6]N
M+"!+:6YG(%-A;&UO;B!!:7)P;W)T+"!!2R<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<U.2XP-3`Z+3$U."XU,3<G72`]("=$:6QL:6YG:&%M
M($UU;FEC:7!A;"P@06LL($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S4Y+C0S,SHM,30V+C,S,R==(#T@)TUI9&1L971O;B!)<VQA;F0L
M($%K+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<U.2XT
M-C<Z+3$S-2XS,#`G72`]("=3:V%G=V%Y+"!!2R<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<U.2XU,3<Z+3$S.2XV-C<G72`]("=986MU=&%T
M+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<U.2XV,S,Z
M+3$U,2XU,#`G72`]("=(;VUE<B`O($UU;FEC:7!A;"P@04LG.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG-3DN-S4P.BTQ-30N.3$W)UT@/2`G
M26QI86UN82`O($EL:6%M;F$@06ER<&]R="P@04LG.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG-3DN.#`P.BTQ-#0N-C`P)UT@/2`G0V%P92!3
M86EN="!%;&EA<RP@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG-C`N,#@S.BTQ-#(N-3`P)UT@/2`G66%K871A9V$L($%+)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S8P+C$Q-SHM,30Y+C0U,"==(#T@
M)U-E=V%R9"P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M-C`N-#DR.BTQ-#4N-#<X)UT@/2`G0V]R9&]V82P@365R;&4@2RX@*$UU9&AO
M;&4I(%-M:71H($%I<G!O<G0L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S8P+C4X,#HM,34Q+C(S.2==(#T@)TME;F%I+"!+96YA:2!-
M=6YI8VEP86P@06ER<&]R="P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG-C`N-S@S.BTQ-C$N.#,S)UT@/2`G0F5T:&5L("\@0F5T:&5L
M($%I<G!O<G0L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S8Q+C$P,#HM,34U+C4V-R==(#T@)U-P87)R979O:&X@06ER=V%Y<R!&86-I
M;&ET:65S(%-E8W1O<BP@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG-C$N,3<T.BTQ-#DN.3DV)UT@/2`G06YC:&]R86=E+"!4960@4W1E
M=F5N<R!!;F-H;W)A9V4@26YT97)N871I;VYA;"!!:7)P;W)T+"!!2R<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V,2XR-3`Z+3$T.2XX,#`G
M72`]("=!;F-H;W)A9V4@+R!%;&UE;F1O<F8@06ER($9O<F-E($)A<V4L($%+
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S8Q+C(V-SHM,30Y
M+C8U,"==(#T@)T9T+B!2:6-H87)D<V]N("\@0G)Y86YT(%4N(%,N($%R;7D@
M2&5L:7!O<G0L($%K+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<V,2XU.#,Z+3$U.2XU,S,G72`]("=!;FEA:RP@04LG.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG-C$N-C`P.BTQ-#DN,#@S)UT@/2`G
M4&%L;65R+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V
M,2XW.#,Z+3$V-BXP,S,G72`]("=#87!E(%)O;6%N>F]F9B!!:7)W87ES($9A
M8VEL:71I97,@4V5C=&]R+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<V,2XY-C<Z+3$U,2XQ.#,G72`]("=3:W=E;G1N82P@04LG.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-C(N,3`P.BTQ-3(N-S4P
M)UT@/2`G4'5N=&EL;&$L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S8R+C$U,#HM,30U+C0U,"==(#T@)T=U;&MA;F$L($=U;&MA;F$@
M06ER<&]R="P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M-C(N,S(Q.BTQ-3`N,#DT)UT@/2`G5&%L:V5E=&YA+"!486QK965T;F$@06ER
M<&]R="P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-C(N
M.38S.BTQ-#$N.3,V)UT@/2`G3F]R=&AW87DL($YO<G1H=V%Y($%I<G!O<G0L
M($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S8R+CDV-SHM
M,34U+C8Q-R==(#T@)TUC1W)A=&@L($UC1W)A=&@@06ER<&]R="P@04LG.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-C,N-S8W.BTQ-S$N-S,S
M)UT@/2`G1V%M8F5L;"!!=71O;6%T:6,@5V5A=&AE<B!/8G-E<G9I;F<@+R!2
M97!O<G1I;F<@4WES=&5M+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<V,RXX.#,Z+3$V,"XX,#`G72`]("=5;F%L86ML965T+"!!2R<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V,RXY,#`Z+3$U,BXR
M-C<G72`]("=-:6YC:'5M:6YA+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<V-"XP,#`Z+3$T-2XW,S,G72`]("=&;W)T($=R965L>2`O
M($%L;&5N(%4N(%,N($%R;7D@06ER9FEE;&0L($%K+"!!2R<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<V-"XU,3(Z+3$V-2XT,S8G72`]("=.
M;VUE+"!.;VUE($%I<G!O<G0L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S8T+C4U,#HM,30Y+C`X,R==(#T@)TYE;F%N82`O($UU;BXL
M($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S8T+C8U,#HM
M,30W+C`V-R==(#T@)T9A:7)B86YK<R`O($5I96QS;VX@06ER($9O<F-E($)A
M<V4L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S8T+C<S
M,SHM,34V+CDS,R==(#T@)T=A;&5N82!!+BP@04LG.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG-C0N.#`T.BTQ-#<N.#<V)UT@/2`G1F%I<F)A
M;FMS+"!&86ER8F%N:W,@26YT97)N871I;VYA;"!!:7)P;W)T+"!!2R<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V-2XQ-C<Z+3$U,BXQ,#`G
M72`]("=486YA;F$L($-A;&AO=6X@365M;W)I86P@06ER<&]R="P@04LG.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-C4N,C4P.BTQ-C8N.#8W
M)UT@/2`G4&]R="!#;&%R96YC92P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG-C4N-38W.BTQ-C<N.3$W)UT@/2`G5&EN($-I='D@06ER
M=V%Y<R!&86-I;&ET:65S(%-E8W1O<BP@04LG.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG-C4N.3@R.BTQ-C$N,34R)UT@/2`G0G5C:VQA;F0L
M($)U8VML86YD($%I<G!O<G0L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S8V+C`P,#HM,34S+C<P,"==(#T@)TEN9&EA;B!-;W5N=&%I
M;B!!:7)W87ES($9A8VEL:71I97,@4V5C=&]R+"!!2R<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<V-BXU-C<Z+3$T-2XR-C<G72`]("=&;W)T
M(%EU:V]N+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V
M-BXX.#8Z+3$V,BXV,#0G72`]("=+;W1Z96)U92P@5VEE;B!-96UO<FEA;"!!
M:7)P;W)T+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V
M-BXY,3<Z+3$U,2XU,3<G72`]("="971T;&5S+"!"971T;&5S($%I<G!O<G0L
M($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S8W+C$P,#HM
M,34W+C@U,"==(#T@)T%M8FQE<BP@06UB;&5R($%I<G!O<G0L($%+)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S8X+C@X,SHM,38V+C$S,R==
M(#T@)T-A<&4@3&ES8G5R;F4@06ER=V%Y<R!&86-I;&ET:65S(%-E8W1O<BP@
M04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-CDN,S8W.BTQ
M-3(N,3,S)UT@/2`G56UI870L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S8Y+C@Q-SHM,38R+CDQ-R==(#T@)U!O:6YT($QA>2P@04LG
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-S`N,3,S.BTQ-#,N
M-C,S)UT@/2`G0F%R=&5R($ES;&%N9"P@04LG.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG-S`N,C$P.BTQ-3$N,#`V)UT@/2`G3G5I<7-U="P@
M3G5I<7-U="!!:7)P;W)T+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<W,"XU,#`Z+3$T.2XX.#,G72`]("=/;&EK=&]K($1I<W1A;G0@
M16%R;'D@5V%R;FEN9RP@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG-S`N-C,S.BTQ-3DN.#4P)UT@/2`G5V%I;G=R:6=H="P@5V%I;G=R
M:6=H="!!:7)P;W)T+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<W,2XR.#0Z+3$U-BXW-S@G72`]("="87)R;W<L(%!O<W0@4F]G97)S
M($UE;6]R:6%L($%I<G!O<G0L($%+)SL*)&-O;W)D:6YA=&5S6R=5<G5G=6%Y
M)UU;)RTS,"XS.#,Z+34V+C4P,"==(#T@)T%R=&EG87,G.PHD8V]O<F1I;F%T
M97-;)U5R=6=U87DG75LG+3,P+C@X,SHM-34N-3,S)UT@/2`G4FEV97)A)SL*
M)&-O;W)D:6YA=&5S6R=5<G5G=6%Y)UU;)RTS,2XS.#,Z+34W+CDU,"==(#T@
M)U-A;'1O)SL*)&-O;W)D:6YA=&5S6R=5<G5G=6%Y)UU;)RTS,2XW,#`Z+34U
M+CDX,R==(#T@)U1A8W5A<F5M8F\G.PHD8V]O<F1I;F%T97-;)U5R=6=U87DG
M75LG+3,R+C,S,SHM-3@N,#,S)UT@/2`G4&%Y<V%N9'4G.PHD8V]O<F1I;F%T
M97-;)U5R=6=U87DG75LG+3,R+C,V-SHM-30N,C$W)UT@/2`G365L;R<["B1C
M;V]R9&EN871E<ULG57)U9W5A>2==6R<M,S,N,C$W.BTU-"XS.#,G72`]("=4
M<F5I;G1A(%D@5')E<R<["B1C;V]R9&EN871E<ULG57)U9W5A>2==6R<M,S,N
M,C4P.BTU."XP-C<G72`]("=-97)C961E<R<["B1C;V]R9&EN871E<ULG57)U
M9W5A>2==6R<M,S,N,S4P.BTU-BXU,#`G72`]("=$=7)A>FYO)SL*)&-O;W)D
M:6YA=&5S6R=5<G5G=6%Y)UU;)RTS-"XT-3`Z+34W+C@S,R==(#T@)T-O;&]N
M:6$G.PHD8V]O<F1I;F%T97-;)U5R=6=U87DG75LG+3,T+C<X,SHM-38N,C4P
M)UT@/2`G365L:6QL82<["B1C;V]R9&EN871E<ULG57)U9W5A>2==6R<M,S0N
M.#,S.BTU-BXP,#`G72`]("=#87)R87-C;R<["B1C;V]R9&EN871E<ULG57IB
M96MI<W1A;B==6R<S-RXR,S,Z-C<N,C8W)UT@/2`G5&5R;65Z)SL*)&-O;W)D
M:6YA=&5S6R=5>F)E:VES=&%N)UU;)S,Y+C4V-SHV-BXY-3`G72`]("=386UA
M<FMA;F0G.PHD8V]O<F1I;F%T97-;)U5Z8F5K:7-T86XG75LG-#`N,3$W.C8W
M+C@S,R==(#T@)T1Z:7IA:R<["B1C;V]R9&EN871E<ULG57IB96MI<W1A;B==
M6R<T,2XR-C<Z-CDN,C8W)UT@/2`G5&%S:&ME;G0G.PHD8V]O<F1I;F%T97-;
M)U5Z8F5K:7-T86XG75LG-#$N-S,S.C8T+C8Q-R==(#T@)U1A;61Y)SL*)&-O
M;W)D:6YA=&5S6R=686YU871U)UU;)RTQ,RXX-3`Z,38W+C4U,"==(#T@)U-O
M;&$@5F%N=6$@3&%V82<["B1C;V]R9&EN871E<ULG5F%N=6%T=2==6R<M,34N
M-3$W.C$V-RXR,3<G72`]("=096MO82!!:7)P;W)T(%-A;G1O)SL*)&-O;W)D
M:6YA=&5S6R=686YU871U)UU;)RTQ-BXT,3<Z,38W+C@P,"==(#T@)TQA;6%P
M($UA;&5K=6QA)SL*)&-O;W)D:6YA=&5S6R=686YU871U)UU;)RTQ-RXW,#`Z
M,38X+C,P,"==(#T@)T)A=65R9FEE;&0@169A=&4G.PHD8V]O<F1I;F%T97-;
M)U9E;F5Z=65L82==6R<Q,"XP-C<Z+38Y+C,Q-R==(#T@)T)A<G%U:7-I;65T
M;R<["B1C;V]R9&EN871E<ULG5F5N97IU96QA)UU;)S$P+C$Q-SHM-C0N-C@S
M)UT@/2`G0F%R8V5L;VYA)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G75LG
M,3`N,38W.BTV-RXY,S,G72`]("=686QE;F-I82<["B1C;V]R9&EN871E<ULG
M5F5N97IU96QA)UU;)S$P+C(U,#HM-C<N-C4P)UT@/2`G36%R86-A>2U"+B!!
M+B!3=6-R92<["B1C;V]R9&EN871E<ULG5F5N97IU96QA)UU;)S$P+C0U,#HM
M-C0N,3@S)UT@/2`G0W5M86YA)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G
M75LG,3`N-3`P.BTV-BXX.#,G72`]("=#87)A8V%S("\@3&$@0V%R;&]T82<[
M"B1C;V]R9&EN871E<ULG5F5N97IU96QA)UU;)S$P+C4P,#HM-C@N,#`P)UT@
M/2`G4'1O+B!#86)E;&QO)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G75LG
M,3`N-38W.BTW,2XW,S,G72`]("=-87)A8V%I8F\M3&$@0VAI;FET82<["B1C
M;V]R9&EN871E<ULG5F5N97IU96QA)UU;)S$P+C4X,SHM-C(N,S$W)UT@/2`G
M1W5I<FEA)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G75LG,3`N-C`P.BTV
M-BXY.#,G72`]("=#87)A8V%S("\@36%I<75E=&EA($%E<F]P+B!);G1L+B!3
M:6UO;B!";VQI=F%R)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G75LG,3$N
M-#$W.BTV.2XV.#,G72`]("=#;W)O)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E
M;&$G75LG,3$N.#`P.BTV-BXQ.#,G72`]("=,82!/<F-H:6QA)SL*)&-O;W)D
M:6YA=&5S6R=696YE>G5E;&$G75LG-"XV,#`Z+38Q+C$Q-R==(#T@)U-A;G1A
M($5L96YA($1E(%5A:7)E;B<["B1C;V]R9&EN871E<ULG5F5N97IU96QA)UU;
M)S4N-C`P.BTV-RXU,#`G72`]("=0=65R=&\@07EA8W5C:&\G.PHD8V]O<F1I
M;F%T97-;)U9E;F5Z=65L82==6R<W+C(S,SHM-S`N.#`P)UT@/2`G1W5A<V1U
M86QI=&\G.PHD8V]O<F1I;F%T97-;)U9E;F5Z=65L82==6R<W+C,P,#HM-C$N
M-#4P)UT@/2`G5'5M97)E;6\G.PHD8V]O<F1I;F%T97-;)U9E;F5Z=65L82==
M6R<W+C4X,SHM-S(N,#8W)UT@/2`G4W1O+B!$;VUI;F=O)SL*)&-O;W)D:6YA
M=&5S6R=696YE>G5E;&$G75LG-RXX-3`Z+3<R+C0U,"==(#T@)U-A;B!!;G1O
M;FEO($1E;"!486-H:7)A)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G75LG
M-RXY,#`Z+38W+C0Q-R==(#T@)U-A;B!&97)N86YD;R!$92!!<'5R92<["B1C
M;V]R9&EN871E<ULG5F5N97IU96QA)UU;)S@N,34P.BTV,RXU-3`G72`]("=#
M:75D860@0F]L:79A<B<["B1C;V]R9&EN871E<ULG5F5N97IU96QA)UU;)S@N
M-C`P.BTW,2XQ.#,G72`]("=-97)I9&$G.PHD8V]O<F1I;F%T97-;)U9E;F5Z
M=65L82==6R<X+C8Q-SHM-S`N,C$W)UT@/2`G0F%R:6YA<R<["B1C;V]R9&EN
M871E<ULG5F5N97IU96QA)UU;)S@N.3,S.BTV-RXT,3<G72`]("=#86QA8F]Z
M;R<["B1C;V]R9&EN871E<ULG5F5N97IU96QA)UU;)SDN,#$W.BTV,BXV,3<G
M72`]("=496UB;&%D;W(G.PHD8V]O<F1I;F%T97-;)U9E;F5Z=65L82==6R<Y
M+C`Q-SHM-CDN-S,S)UT@/2`G1W5A;F%R92<["B1C;V]R9&EN871E<ULG5F5N
M97IU96QA)UU;)SDN,C$W.BTV-BXP,3<G72`]("=686QL92!$92!,82!087-C
M=6$G.PHD8V]O<F1I;F%T97-;)U9E;F5Z=65L82==6R<Y+C,U,#HM-S`N-C$W
M)UT@/2`G5F%L97)A)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G75LG.2XU
M-3`Z+38Y+C(S,R==(#T@)T%C87)I9W5A)SL*)&-O;W)D:6YA=&5S6R=696YE
M>G5E;&$G75LG.2XW-3`Z+38S+C$X,R==(#T@)TUA='5R:6XG.PHD8V]O<F1I
M;F%T97-;)U9E;F5Z=65L82==6R<Y+C@Q-SHM-S`N.3,S)UT@/2`G365N92!'
M<F%N9&4G.PHD8V]O<F1I;F%T97-;)U9E;F5Z=65L82==6R<Y+CDQ-SHM-C<N
M,S,S)UT@/2`G4V%N($IU86X@1&4@3&]S($UO<G)O<R<["B1C;V]R9&EN871E
M<ULG5FEE="!.86TG75LG,3`N.#$W.C$P-BXV-C<G72`]("=(;R!#:&D@36EN
M:"<["B1C;V]R9&EN871E<ULG5FEE="!.86TG75LG,3(N,C4P.C$P.2XR,#`G
M72`]("=.:&$@5')A;F<G.PHD8V]O<F1I;F%T97-;)U9I970@3F%M)UU;)S$S
M+C<V-SHQ,#DN,C$W)UT@/2`G475Y($YH;VXG.PHD8V]O<F1I;F%T97-;)U9I
M970@3F%M)UU;)S$S+CDX,SHQ,#@N,#`P)UT@/2`G4&QE:6MU($-I='DG.PHD
M8V]O<F1I;F%T97-;)U9I970@3F%M)UU;)S$V+C`S,SHQ,#@N,3@S)UT@/2`G
M1&$@3F%N9R<["B1C;V]R9&EN871E<ULG5FEE="!.86TG75LG,38N-#`P.C$P
M-RXV.#,G72`]("=(=64G.PHD8V]O<F1I;F%T97-;)U9I970@3F%M)UU;)S$X
M+C<P,#HQ,#4N-C8W)UT@/2`G5FEN:"<["B1C;V]R9&EN871E<ULG5FEE="!.
M86TG75LG,C$N,#$W.C$P-2XX,#`G72`]("=(82!.;VDG.PHD8V]O<F1I;F%T
M97-;)U9I<F=I;B!)<VQA;F1S+"!"<FET:7-H)UU;)S$X+C0U,#HM-C0N-3,S
M)UT@/2`G0F5E9B!)<VQA;F0L(%1O<G1O;&$G.PHD8V]O<F1I;F%T97-;)U9I
M<F=I;B!)<VQA;F1S+"!5;FET960@4W1A=&5S)UU;)S$W+C<P,#HM-C0N.#`P
M)UT@/2`G0VAR:7-T:6%N<W1E9"P@2&5N<GD@12X@4F]H;'-E;B!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R=6:7)G:6X@27-L86YD<RP@56YI=&5D(%-T871E
M<R==6R<Q."XS,S,Z+38T+CDX,R==(#T@)T-H87)L;W1T92!!;6%L:64@4W0N
M(%1H;VUA<RP@0WER:6P@12X@2VEN9R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S
M6R=797-T97)N(%-A:&%R82==6R<R,RXW,#`Z+3$U+C@V-R==(#T@)U9I;&QA
M($-I<VYE<F]S)SL*)&-O;W)D:6YA=&5S6R=996UE;B==6R<Q,BXV,S,Z-3,N
M.3`P)UT@/2`G4V]C;W1R82<["B1C;V]R9&EN871E<ULG665M96XG75LG,3(N
M-C8W.C0U+C`S,R==(#T@)T%D96XG.PHD8V]O<F1I;F%T97-;)UEE;65N)UU;
M)S$S+C(U,#HT,RXR.#,G72`]("=-;VMH82<["B1C;V]R9&EN871E<ULG665M
M96XG75LG,3,N,C4P.C0T+C$S,R==(#T@)TUO:VAA)SL*)&-O;W)D:6YA=&5S
M6R=996UE;B==6R<Q,RXV.#,Z-#0N,3,S)UT@/2`G5&%I>B<["B1C;V]R9&EN
M871E<ULG665M96XG75LG,30N-3$W.C0V+C@U,"==(#T@)T%T87$G.PHD8V]O
M<F1I;F%T97-;)UEE;65N)UU;)S$T+C8U,#HT.2XS.#,G72`]("=2:7EA;B<[
M"B1C;V]R9&EN871E<ULG665M96XG75LG,30N-S4P.C0R+CDX,R==(#T@)TAO
M9&5I9&%H)SL*)&-O;W)D:6YA=&5S6R=996UE;B==6R<Q-2XT,S,Z-#4N,S,S
M)UT@/2`G36%R:6(G.PHD8V]O<F1I;F%T97-;)UEE;65N)UU;)S$U+C4Q-SHT
M-"XQ.#,G72`]("=386YA7"=!)SL*)&-O;W)D:6YA=&5S6R=996UE;B==6R<Q
M-BXR,#`Z-#0N-S@S)UT@/2`G06PM2&%Z;2<["B1C;V]R9&EN871E<ULG675G
M;W-L879I82==6R<T,BXS-C<Z,3DN,C4P)UT@/2`G4&]D9V]R:6-A("\@1V]L
M=6)O=F-I)SL*)&-O;W)D:6YA=&5S6R=9=6=O<VQA=FEA)UU;)S0R+C0P,#HQ
M."XW,S,G72`]("=4:79A="<["B1C;V]R9&EN871E<ULG675G;W-L879I82==
M6R<T,BXV-3`Z,C$N,34P)UT@/2`G4')I<W1I;F$G.PHD8V]O<F1I;F%T97-;
M)UEU9V]S;&%V:6$G75LG-#,N,S,S.C(Q+CDP,"==(#T@)TYI<R<["B1C;V]R
M9&EN871E<ULG675G;W-L879I82==6R<T,RXS-3`Z,3<N.#`P)UT@/2`G36]S
M=&%R)SL*)&-O;W)D:6YA=&5S6R=9=6=O<VQA=FEA)UU;)S0S+C@Q-SHQ."XS
M,S,G72`]("=387)A:F5V;R`O($)U=&UI<B<["B1C;V]R9&EN871E<ULG675G
M;W-L879I82==6R<T-"XU-3`Z,3@N-S`P)UT@/2`G5'5Z;&$G.PHD8V]O<F1I
M;F%T97-;)UEU9V]S;&%V:6$G75LG-#0N-S@S.C$W+C(Q-R==(#T@)T)A;FIA
M($QU:V$G.PHD8V]O<F1I;F%T97-;)UEU9V]S;&%V:6$G75LG-#0N.#$W.C$U
M+C@X,R==(#T@)T)I:&%C)SL*)&-O;W)D:6YA=&5S6R=9=6=O<VQA=FEA)UU;
M)S0T+C@Q-SHR,"XR.#,G72`]("="96]G<F%D("\@4W5R8VEN)SL*)&-O;W)D
M:6YA=&5S6R=9=6=O<VQA=FEA)UU;)S0U+C$U,#HR,2XS,3<G72`]("=6<G-A
M8R<["B1C;V]R9&EN871E<ULG6F%I<F4G75LG,"XP-3`Z,3@N,C8W)UT@/2`G
M36)A;F1A:V$G.PHD8V]O<F1I;F%T97-;)UIA:7)E)UU;)S`N,3,S.C(Y+C(V
M-R==(#T@)T)U=&5M8F\G.PHD8V]O<F1I;F%T97-;)UIA:7)E)UU;)RTP+C(Q
M-SHR,"XX-3`G72`]("=";V5N9&4G.PHD8V]O<F1I;F%T97-;)UIA:7)E)UU;
M)S`N-3$W.C(U+C$X,R==(#T@)TMI<V%N9V%N:2<["B1C;V]R9&EN871E<ULG
M6F%I<F4G75LG+3$N,3@S.C(Y+C0U,"==(#T@)U)U='-H=7)U)SL*)&-O;W)D
M:6YA=&5S6R=:86ER92==6R<M,2XV.#,Z,CDN,C,S)UT@/2`G1V]M82<["B1C
M;V]R9&EN871E<ULG6F%I<F4G75LG+3$N.38W.C$X+C(V-R==(#T@)TEN;VYG
M;R<["B1C;V]R9&EN871E<ULG6F%I<F4G75LG+3$P+C<Q-SHR-2XT-3`G72`]
M("=+;VQW97II)SL*)&-O;W)D:6YA=&5S6R=:86ER92==6R<M,3$N-C8W.C(W
M+C0X,R==(#T@)TQU8G5M8F%S:&DM3'5A;F\G.PHD8V]O<F1I;F%T97-;)UIA
M:7)E)UU;)RTR+CDU,#HR-2XY,3<G72`]("=+:6YD=2<["B1C;V]R9&EN871E
M<ULG6F%I<F4G75LG,RXR.#,Z,3DN-S@S)UT@/2`G1V5M96YA)SL*)&-O;W)D
M:6YA=&5S6R=:86ER92==6R<M,RXS,#`Z,3<N,S4P)UT@/2`G0F%N9'5N9'4G
M.PHD8V]O<F1I;F%T97-;)UIA:7)E)UU;)RTS+C0X,SHR,RXT-C<G72`]("=,
M;V1J82<["B1C;V]R9&EN871E<ULG6F%I<F4G75LG+30N,S,S.C(P+C4X,R==
M(#T@)TEL96)O)SL*)&-O;W)D:6YA=&5S6R=:86ER92==6R<M-"XS.#,Z,34N
M-#,S)UT@/2`G2VEN<VAA<V$@+R!.7"=$:FEL:2<["B1C;V]R9&EN871E<ULG
M6F%I<F4G75LG+30N.3$W.C$W+C`V-R==(#T@)TME;F=E)SL*)&-O;W)D:6YA
M=&5S6R=:86ER92==6R<M-"XY-C<Z,C,N-#,S)UT@/2`G3'5S86UB;R<["B1C
M;V]R9&EN871E<ULG6F%I<F4G75LG+34N,#,S.C$X+C@P,"==(#T@)TMI:W=I
M="<["B1C;V]R9&EN871E<ULG6F%I<F4G75LG+34N,S4P.C(W+C`P,"==(#T@
M)TMO;F=O;&\G.PHD8V]O<F1I;F%T97-;)UIA:7)E)UU;)RTU+C4Q-SHQ,RXU
M.#,G72`]("=);F=A)SL*)&-O;W)D:6YA=&5S6R=:86ER92==6R<M-2XX,#`Z
M,3,N-#,S)UT@/2`G36%T861I)SL*)&-O;W)D:6YA=&5S6R=:86ER92==6R<M
M-2XX.#,Z,C(N-#$W)UT@/2`G2V%N86YG82<["B1C;V]R9&EN871E<ULG6F%I
M<F4G75LG+34N.#@S.C(Y+C$X,R==(#T@)TMA;&5M:64G.PHD8V]O<F1I;F%T
M97-;)UIA:7)E)UU;)RTV+C`P,#HQ,BXT,3<G72`]("=-;V%N9&$G.PHD8V]O
M<F1I;F%T97-;)UIA:7)E)UU;)RTV+C$V-SHR,RXV,3<G72`]("=-8G5J:2U-
M87EI)SL*)&-O;W)D:6YA=&5S6R=:86ER92==6R<M-BXT,3<Z,C`N.#4P)UT@
M/2`G5'-H:6MA<&$G.PHD8V]O<F1I;F%T97-;)UIA:7)E)UU;)RTW+C(X,SHR
M-RXT,S,G72`]("=-86YO;F\G.PHD8V]O<F1I;F%T97-;)UIA:7)E)UU;)RTX
M+C8S,SHR-2XR-3`G72`]("=+86UI;F$@+R!"87-E)SL*)&-O;W)D:6YA=&5S
M6R=:86UB:6$G75LG+3$P+C$Q-SHS,BXV,S,G72`]("=)<V]K82<["B1C;V]R
M9&EN871E<ULG6F%M8FEA)UU;)RTQ,"XR,3<Z,S$N,3,S)UT@/2`G2V%S86UA
M)SL*)&-O;W)D:6YA=&5S6R=:86UB:6$G75LG+3$Q+C$P,#HR."XX-3`G72`]
M("=-86YS82<["B1C;V]R9&EN871E<ULG6F%M8FEA)UU;)RTQ,2XW-3`Z,C0N
M-#,S)UT@/2`G37=I;FEL=6YG82<["B1C;V]R9&EN871E<ULG6F%M8FEA)UU;
M)RTQ,2XY,#`Z,S$N-#,S)UT@/2`G37!I:V$G.PHD8V]O<F1I;F%T97-;)UIA
M;6)I82==6R<M,3(N,3@S.C(V+C,X,R==(#T@)U-O;'=E>FDG.PHD8V]O<F1I
M;F%T97-;)UIA;6)I82==6R<M,3(N,C@S.C,S+C(P,"==(#T@)TQU;F1A>FDG
M.PHD8V]O<F1I;F%T97-;)UIA;6)I82==6R<M,3,N,#`P.C(X+C8U,"==(#T@
M)TYD;VQA)SL*)&-O;W)D:6YA=&5S6R=:86UB:6$G75LG+3$S+C(S,SHS,"XR
M,3<G72`]("=397)E;FIE)SL*)&-O;W)D:6YA=&5S6R=:86UB:6$G75LG+3$S
M+C4S,SHR,RXQ,3<G72`]("=:86UB97II)SL*)&-O;W)D:6YA=&5S6R=:86UB
M:6$G75LG+3$S+C4S,SHR-2XX-3`G72`]("=+87-E;7!A)SL*)&-O;W)D:6YA
M=&5S6R=:86UB:6$G75LG+3$S+C4U,#HS,BXU.#,G72`]("=#:&EP871A)SL*
M)&-O;W)D:6YA=&5S6R=:86UB:6$G75LG+3$S+C8P,#HR-"XR,#`G72`]("=+
M86)O;7!O)SL*)&-O;W)D:6YA=&5S6R=:86UB:6$G75LG+3$T+C(U,#HS,2XR
M.#,G72`]("=0971A=6ME)SL*)&-O;W)D:6YA=&5S6R=:86UB:6$G75LG+3$T
M+C0U,#HR."XT-C<G72`]("=+86)W92<["B1C;V]R9&EN871E<ULG6F%M8FEA
M)UU;)RTQ-"XT-3`Z,C@N-#8W)UT@/2`G3'5S86MA($-I='D@06ER<&]R="<[
M"B1C;V]R9&EN871E<ULG6F%M8FEA)UU;)RTQ-"XX,#`Z,C0N.#`P)UT@/2`G
M2V%O;6$G.PHD8V]O<F1I;F%T97-;)UIA;6)I82==6R<M,34N,C4P.C(S+C$U
M,"==(#T@)TUO;F=U)SL*)&-O;W)D:6YA=&5S6R=:86UB:6$G75LG+3$U+C,Q
M-SHR."XT-3`G72`]("=,=7-A:V$@26YT97)N871I;VYA;&%I<G!O<G0G.PHD
M8V]O<F1I;F%T97-;)UIA;6)I82==6R<M,38N,3`P.C(S+C(V-R==(#T@)U-E
M;F%N9V$G.PHD8V]O<F1I;F%T97-;)UIA;6)I82==6R<M,38N.#,S.C(W+C`V
M-R==(#T@)T-H;VUA)SL*)&-O;W)D:6YA=&5S6R=:86UB:6$G75LG+3$W+C0V
M-SHR-"XS,#`G72`]("=397-H96ME)SL*)&-O;W)D:6YA=&5S6R=:86UB:6$G
M75LG+3$W+C@Q-SHR-2XX,3<G72`]("=,:79I;F=S=&]N92<["B1C;V]R9&EN
M871E<ULG6F%M8FEA)UU;)RTX+C@U,#HS,2XS,S,G72`]("=-8F%L82<["B1C
M;V]R9&EN871E<ULG6F%M8FEA)UU;)RTY+C@P,#HR.2XP.#,G72`]("=+87=A
M;6)W82<["B1C;V]R9&EN871E<ULG6FEM8F%B=V4G75LG+3$V+C4Q-SHR."XX
M.#,G72`]("=+87)I8F$G.PHD8V]O<F1I;F%T97-;)UII;6)A8G=E)UU;)RTQ
M-BXX,S,Z,CDN-C$W)UT@/2`G2V%R;VDG.PHD8V]O<F1I;F%T97-;)UII;6)A
M8G=E)UU;)RTQ-RXT,3<Z,S(N,C$W)UT@/2`G375T;VMO)SL*)&-O;W)D:6YA
M=&5S6R=::6UB86)W92==6R<M,3<N-C$W.C(W+C,S,R==(#T@)T)I;F=A)SL*
M)&-O;W)D:6YA=&5S6R=::6UB86)W92==6R<M,3<N.3$W.C,Q+C$S,R==(#T@
M)TAA<F%R92!+=71S86=A)SL*)&-O;W)D:6YA=&5S6R=::6UB86)W92==6R<M
M,3@N,3`P.C(U+C@U,"==(#T@)U9I8W1O<FEA($9A;&QS)SL*)&-O;W)D:6YA
M=&5S6R=::6UB86)W92==6R<M,3@N,C$W.C(X+CDS,R==(#T@)T=O:W=E)SL*
M)&-O;W)D:6YA=&5S6R=::6UB86)W92==6R<M,3@N-3,S.C,R+C$S,R==(#T@
M)U)U<V%P92<["B1C;V]R9&EN871E<ULG6FEM8F%B=V4G75LG+3$X+C8S,SHR
M-RXP,#`G72`]("=(=V%N9V4@3F%T:6]N86P@4&%R:R<["B1C;V]R9&EN871E
M<ULG6FEM8F%B=V4G75LG+3$Y+C0U,#HR.2XX-3`G72`]("='=V5R=2<["B1C
M;V]R9&EN871E<ULG6FEM8F%B=V4G75LG+3(P+C`Q-SHR."XV,3<G72`]("="
M=6QA=V%Y;R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=::6UB86)W92==6R<M
M,C`N,#8W.C,P+C@V-R==(#T@)TUA<W9I;F=O)SL*)&-O;W)D:6YA=&5S6R=:
M:6UB86)W92==6R<M,C`N,C`P.C,R+C8Q-R==(#T@)T-H:7!I;F=E)SL*)&-O
M;W)D:6YA=&5S6R=::6UB86)W92==6R<M,C$N,#$W.C,Q+C4X,R==(#T@)T)U
M9F9A;&\@4F%N9V4G.PHD8V]O<F1I;F%T97-;)UII;6)A8G=E)UU;)RTR,BXR
M,3<Z,S`N,#`P)UT@/2`G0F5I=&)R:61G92<["@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O3DQ3+V-A
M<G-I9VYS+G!H<```````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#<S,C(@,3`U,34T,S,W,S<@,#(R,S,T`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@;&ES="!O
M9B!I;G1E<FYA=&EO;F%L(&QI8V5N<V4@<&QA=&4@8V]D97,N"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+TY,4R].3%,O8V%R<VEG;G,N<&AP+'8@,2XQ(#(P
M,#0O,#DO,#@@,34Z,3@Z-3<@:F%N($5X<"`D"B`J"B`J($!P86-K86=E($AO
M<F1E7TY,4PH@*B\*"B1C87)S:6=N<R`](&%R<F%Y*`H@("`@)V%T)R`]/B`G
M02<L"B`@("`G868G(#T^("=!1D<G+`H@("`@)V%G)R`]/B`G04<G+`H@("`@
M)V%L)R`]/B`G04PG+`H@("`@)V%D)R`]/B`G04Y$)RP*("`@("=A;R<@/3X@
M)T%.1R<L"B`@("`G86TG(#T^("=!4DTG+`H@("`@)V%U)R`]/B`G0553)RP*
M("`@("=A>B<@/3X@)T%:)RP*("`@("=B92<@/3X@)T(G+`H@("`@)V)D)R`]
M/B`G0D0G+`H@("`@)V)B)R`]/B`G0D13)RP*("`@("=B9B<@/3X@)T)&)RP*
M("`@("=B9R<@/3X@)T)')RP*("`@("=B>B<@/3X@)T)()RP*("`@("=B="<@
M/3X@)T)(5"<L"B`@("`G8F$G(#T^("="24@G+`H@("`@)V)O)R`]/B`G0D],
M)RP*("`@("=B<B<@/3X@)T)2)RP*("`@("=B:"<@/3X@)T)23B<L"B`@("`G
M8FXG(#T^("="4E4G+`H@("`@)V)S)R`]/B`G0E,G+`H@("`@)V)I)R`]/B`G
M0E4G+`H@("`@)W9G)R`]/B`G0E9))RP*("`@("=B>2<@/3X@)T)9)RP*("`@
M("=B>B<@/3X@)T):)RP*("`@("=C=2<@/3X@)T,G+`H@("`@)V-M)R`]/B`G
M0T%-)RP*("`@("=C9"<@/3X@)T-$)RP*("`@("=C82<@/3X@)T-$3B<L"B`@
M("`G8V@G(#T^("=#2"<L"B`@("`G8VDG(#T^("=#22<L"B`@("`G;&LG(#T^
M("=#3"<L"B`@("`G8V\G(#T^("=#3R<L"B`@("`G:VTG(#T^("=#3TTG+`H@
M("`@)V-R)R`]/B`G0U(G+`H@("`@)V-V)R`]/B`G0U8G+`H@("`@)V-Y)R`]
M/B`G0UDG+`H@("`@)V-Z)R`]/B`G0UHG+`H@("`@)V1E)R`]/B`G1"<L"B`@
M("`G9&HG(#T^("=$2DDG+`H@("`@)V1K)R`]/B`G1$LG+`H@("`@)V1O)R`]
M/B`G1$]-)RP*("`@("=K<"<@/3X@)T164DLG+`H@("`@)V)J)R`]/B`G1%DG
M+`H@("`@)V1Z)R`]/B`G1%HG+`H@("`@)V5S)R`]/B`G12<L"B`@("`G:V4G
M(#T^("=%04LG+`H@("`@)W1Z)R`]/B`G14%4)RP*("`@("=U9R<@/3X@)T5!
M52<L"B`@("`G96,G(#T^("=%0R<L"B`@("`G97(G(#T^("=%4B<L"B`@("`G
M<W8G(#T^("=%4R<L"B`@("`G964G(#T^("=%4U0G+`H@("`@)V5G)R`]/B`G
M150G+`H@("`@)V5T)R`]/B`G151()RP*("`@("=F<B<@/3X@)T8G+`H@("`@
M)V9I)R`]/B`G1DE.)RP*("`@("=F:B<@/3X@)T9*22<L"B`@("`G;&DG(#T^
M("=&3"<L"B`@("`G9F\G(#T^("=&3R<L"B`@("`G9FTG(#T^("=&4TTG+`H@
M("`@)V=A)R`]/B`G1R<L"B`@("`G9V(G(#T^("='0B<L"B`@("`G9VDG(#T^
M("='0EHG+`H@("`@)V=T)R`]/B`G1T-!)RP*("`@("=G92<@/3X@)T=%)RP*
M("`@("=G:"<@/3X@)T=()RP*("`@("=G<2<@/3X@)T=1)RP*("`@("=G<B<@
M/3X@)T=2)RP*("`@("=G>2<@/3X@)T=562<L"B`@("`G:'4G(#T^("=()RP*
M("`@("=H:R<@/3X@)TA+)RP*("`@("=H;B<@/3X@)TA.)RP*("`@("=H<B<@
M/3X@)TA2)RP*("`@("=I="<@/3X@)TDG+`H@("`@)VEL)R`]/B`G24PG+`H@
M("`@)VEN)R`]/B`G24Y$)RP*("`@("=I<B<@/3X@)TE2)RP*("`@("=I92<@
M/3X@)TE23"<L"B`@("`G:7$G(#T^("=)4E$G+`H@("`@)VES)R`]/B`G25,G
M+`H@("`@)VIP)R`]/B`G2B<L"B`@("`G:FTG(#T^("=*02<L"B`@("`G:F\G
M(#T^("=*3U(G+`H@("`@)VMH)R`]/B`G2R<L"B`@("`G:VDG(#T^("=+25(G
M+`H@("`@)V=L)R`]/B`G2TXG+`H@("`@)VMG)R`]/B`G2U,G+`H@("`@)W-A
M)R`]/B`G2U-!)RP*("`@("=K=R<@/3X@)TM75"<L"B`@("`G:WHG(#T^("=+
M6B<L"B`@("`G;'4G(#T^("=,)RP*("`@("=L82<@/3X@)TQ!3R<L"B`@("`G
M;'DG(#T^("=,05(G+`H@("`@)VQR)R`]/B`G3$(G+`H@("`@)VQS)R`]/B`G
M3%,G+`H@("`@)VQT)R`]/B`G3%0G+`H@("`@)VQV)R`]/B`G3%8G+`H@("`@
M)VUT)R`]/B`G32<L"B`@("`G;6$G(#T^("=-02<L"B`@("`G;7DG(#T^("=-
M04PG+`H@("`@)VUC)R`]/B`G34,G+`H@("`@)VUD)R`]/B`G340G+`H@("`@
M)VUX)R`]/B`G3458)RP*("`@("=M;B<@/3X@)TU'3"<L"B`@("`G;6@G(#T^
M("=-2"<L"B`@("`G;6LG(#T^("=-2R<L"B`@("`G;7HG(#T^("=-3T,G+`H@
M("`@)VUU)R`]/B`G35,G+`H@("`@)VUV)R`]/B`G358G+`H@("`@)VUW)R`]
M/B`G35<G+`H@("`@)VUM)R`]/B`G35E!)RP*("`@("=N;R<@/3X@)TXG+`H@
M("`@)V%N)R`]/B`G3D$G+`H@("`@)VYL)R`]/B`G3DPG+`H@("`@)VYZ)R`]
M/B`G3EHG+`H@("`@)V]M)R`]/B`G3TTG+`H@("`@)W!T)R`]/B`G4"<L"B`@
M("`G<&$G(#T^("=002<L"B`@("`G<'<G(#T^("=004PG+`H@("`@)W!E)R`]
M/B`G4$4G+`H@("`@)W!K)R`]/B`G4$LG+`H@("`@)W!L)R`]/B`G4$PG+`H@
M("`@)W!G)R`]/B`G4$Y')RP*("`@("=C;B<@/3X@)U!20R<L"B`@("`G<',G
M(#T^("=04R<L"B`@("`G<'DG(#T^("=062<L"B`@("`G<6$G(#T^("=1)RP*
M("`@("=A<B<@/3X@)U)!)RP*("`@("=B=R<@/3X@)U)")RP*("`@("=T=R<@
M/3X@)U)#)RP*("`@("=C9B<@/3X@)U)#02<L"B`@("`G8V0G(#T^("=20T(G
M+`H@("`@)V-L)R`]/B`G4D-()RP*("`@("=R92<@/3X@)U)%)RP*("`@("=G
M;B<@/3X@)U)')RP*("`@("=H="<@/3X@)U)()RP*("`@("=I9"<@/3X@)U))
M)RP*("`@("=M<B<@/3X@)U))32<L"B`@("`G;&(G(#T^("=23"<L"B`@("`G
M;6<G(#T^("=232<L"B`@("`G;6PG(#T^("=234TG+`H@("`@)VYE)R`]/B`G
M4DXG+`H@("`@)W)O)R`]/B`G4D\G+`H@("`@)VMR)R`]/B`G4D]+)RP*("`@
M("=U>2<@/3X@)U)/52<L"B`@("`G<&@G(#T^("=24"<L"B`@("`G<VTG(#T^
M("=24TTG+`H@("`@)W1G)R`]/B`G4E0G+`H@("`@)W)U)R`]/B`G4E53)RP*
M("`@("=R=R<@/3X@)U)702<L"B`@("`G<V4G(#T^("=3)RP*("`@("=C<R<@
M/3X@)U-#1R<L"B`@("`G:VXG(#T^("=30TXG+`H@("`@)W-Z)R`]/B`G4T0G
M+`H@("`@)W-G)R`]/B`G4T=0)RP*("`@("=S:R<@/3X@)U-+)RP*("`@("=S
M:2<@/3X@)U-,3R<L"B`@("`G<W(G(#T^("=3344G+`H@("`@)W-N)R`]/B`G
M4TXG+`H@("`@)W-B)R`]/B`G4T],)RP*("`@("=S;R<@/3X@)U-0)RP*("`@
M("=S="<@/3X@)U-44"<L"B`@("`G<V0G(#T^("=3540G+`H@("`@)W-C)R`]
M/B`G4UDG+`H@("`@)W-Y)R`]/B`G4UE2)RP*("`@("=T9"<@/3X@)U1#2"<L
M"B`@("`G=&@G(#T^("=42$$G+`H@("`@)W1J)R`]/B`G5$HG+`H@("`@)W1L
M)R`]/B`G5$PG+`H@("`@)W1M)R`]/B`G5$TG+`H@("`@)W1N)R`]/B`G5$XG
M+`H@("`@)W1O)R`]/B`G5$\G+`H@("`@)W1R)R`]/B`G5%(G+`H@("`@)W1T
M)R`]/B`G5%0G+`H@("`@)W1V)R`]/B`G5%56)RP*("`@("=U82<@/3X@)U5!
M)RP*("`@("=A92<@/3X@)U5!12<L"B`@("`G=7,G(#T^("=54T$G+`H@("`@
M)W5Z)R`]/B`G55HG+`H@("`@)W9A)R`]/B`G5B<L"B`@("`G=FXG(#T^("=6
M3B<L"B`@("`G=G4G(#T^("=652<L"B`@("`G1TTG(#T^("=704<G+`H@("`@
M)W-L)R`]/B`G5T%,)RP*("`@("=N9R<@/3X@)U=!3B<L"B`@("`G9&TG(#T^
M("=71"<L"B`@("`G9V0G(#T^("=71R<L"B`@("`G;&,G(#T^("=73"<L"B`@
M("`G=W,G(#T^("=74R<L"B`@("`G=F,G(#T^("=75B<L"B`@("`G>64G(#T^
M("=905(G+`H@("`@)W9E)R`]/B`G658G+`H@("`@)WIM)R`]/B`G6B<L"B`@
M("`G>F$G(#T^("=:02<L"B`@("`G>G<G(#T^("=:5R<**3L*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O3DQ3+W1L9"YP:'``````````````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,38W,C4@,3`U,34T,S,W,S<@,#(Q,S$U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B!4;W`@;&5V96P@9&]M86EN("A43$0I(&QI<W0@9F]R(&-O=6YT
M<GD@8V]D97,N"B`J($=E;F5R871E9"!F<F]M($E!3D$@*$EN=&5R;F5T($%S
M<VEG;F5D($YU;6)E<G,@075T:&]R:71Y*2!D871A(&QO8V%T960*("H@870@
M:'1T<#HO+W=W=RYI86YA+F]R9R]C8W1L9"]C8W1L9"UW:&]I<RYH=&T*("H*
M("H@1F]R;6%T.@H@*B`@("1T;&1;)V-O=6YT<GEC;V1E)UT@/2`G8V]U;G1R
M>6YA;64G.PH@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`L=B`Q+C4@,C`P-"\P,2\P-"`P,CHR-#HP-2!M9&IU:VEC($5X<"`D"B`J
M"B`J($!P86-K86=E($AO<F1E7TY,4PH@*B\*)'1L9"`](&%R<F%Y*`H@("`@
M)V%C)R`]/B!?*")!<V-E;G-I;VX@27-L86YD(BDL"B`@("`G860G(#T^(%\H
M(D%N9&]R<F$B*2P*("`@("=A92<@/3X@7R@B56YI=&5D($%R86(@16UI<F%T
M97,B*2P*("`@("=A9B<@/3X@7R@B069G:&%N:7-T86XB*2P*("`@("=A9R<@
M/3X@7R@B06YT:6=U82!A;F0@0F%R8G5D82(I+`H@("`@)V%I)R`]/B!?*")!
M;F=U:6QL82(I+`H@("`@)V%L)R`]/B!?*")!;&)A;FEA(BDL"B`@("`G86TG
M(#T^(%\H(D%R;65N:6$B*2P*("`@("=A;B<@/3X@7R@B3F5T:&5R;&%N9',@
M06YT:6QL97,B*2P*("`@("=A;R<@/3X@7R@B06YG;VQA(BDL"B`@("`G87$G
M(#T^(%\H(D%N=&%R8W1I8V$B*2P*("`@("=A<B<@/3X@7R@B07)G96YT:6YA
M(BDL"B`@("`G87,G(#T^(%\H(D%M97)I8V%N(%-A;6]A(BDL"B`@("`G870G
M(#T^(%\H(D%U<W1R:6$B*2P*("`@("=A=2<@/3X@7R@B075S=')A;&EA(BDL
M"B`@("`G87<G(#T^(%\H(D%R=6)A(BDL"B`@("`G87HG(#T^(%\H(D%Z97)B
M86EJ86XB*2P*("`@("=B82<@/3X@7R@B0F]S;FEA(&%N9"!(97)Z96=O=FEN
M82(I+`H@("`@)V)B)R`]/B!?*")"87)B861O<R(I+`H@("`@)V)D)R`]/B!?
M*")"86YG;&%D97-H(BDL"B`@("`G8F4G(#T^(%\H(D)E;&=I=6TB*2P*("`@
M("=B9B<@/3X@7R@B0G5R:VEN82!&87-O(BDL"B`@("`G8F<G(#T^(%\H(D)U
M;&=A<FEA(BDL"B`@("`G8F@G(#T^(%\H(D)A:')A:6XB*2P*("`@("=B:2<@
M/3X@7R@B0G5R=6YD:2(I+`H@("`@)V)J)R`]/B!?*")"96YI;B(I+`H@("`@
M)V)M)R`]/B!?*")"97)M=61A(BDL"B`@("`G8FXG(#T^(%\H(D)R=6YE:2!$
M87)U<W-A;&%M(BDL"B`@("`G8F\G(#T^(%\H(D)O;&EV:6$B*2P*("`@("=B
M<B<@/3X@7R@B0G)A>FEL(BDL"B`@("`G8G,G(#T^(%\H(D)A:&%M87,B*2P*
M("`@("=B="<@/3X@7R@B0FAU=&%N(BDL"B`@("`G8G8G(#T^(%\H(D)O=79E
M="!)<VQA;F0B*2P*("`@("=B=R<@/3X@7R@B0F]T<W=A;F$B*2P*("`@("=B
M>2<@/3X@7R@B0F5L87)U<R(I+`H@("`@)V)Z)R`]/B!?*")"96QI>F4B*2P*
M("`@("=C82<@/3X@7R@B0V%N861A(BDL"B`@("`G8V,G(#T^(%\H(D-O8V]S
M("A+965L:6YG*2!)<VQA;F1S(BDL"B`@("`G8V0G(#T^(%\H(D-O;F=O+"!4
M:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4B*2P*("`@("=C9B<@/3X@
M7R@B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(BDL"B`@("`G8V<G(#T^(%\H
M(D-O;F=O(BDL"B`@("`G8V@G(#T^(%\H(E-W:71Z97)L86YD(BDL"B`@("`G
M8VDG(#T^(%\H(D-O=&4@9"=)=F]I<F4B*2P*("`@("=C:R<@/3X@7R@B0V]O
M:R!)<VQA;F1S(BDL"B`@("`G8VPG(#T^(%\H(D-H:6QE(BDL"B`@("`G8VTG
M(#T^(%\H(D-A;65R;V]N(BDL"B`@("`G8VXG(#T^(%\H(D-H:6YA(BDL"B`@
M("`G8V\G(#T^(%\H(D-O;&]M8FEA(BDL"B`@("`G8W(G(#T^(%\H(D-O<W1A
M(%)I8V$B*2P*("`@("=C=2<@/3X@7R@B0W5B82(I+`H@("`@)V-V)R`]/B!?
M*")#87!E(%9E<F1E(BDL"B`@("`G8W@G(#T^(%\H(D-H<FES=&UA<R!)<VQA
M;F0B*2P*("`@("=C>2<@/3X@7R@B0WEP<G5S(BDL"B`@("`G8WHG(#T^(%\H
M(D-Z96-H(%)E<'5B;&EC(BDL"B`@("`G9&4G(#T^(%\H(D=E<FUA;GDB*2P*
M("`@("=D:B<@/3X@7R@B1&II8F]U=&DB*2P*("`@("=D:R<@/3X@7R@B1&5N
M;6%R:R(I+`H@("`@)V1M)R`]/B!?*")$;VUI;FEC82(I+`H@("`@)V1O)R`]
M/B!?*")$;VUI;FEC86X@4F5P=6)L:6,B*2P*("`@("=D>B<@/3X@7R@B06QG
M97)I82(I+`H@("`@)V5C)R`]/B!?*")%8W5A9&]R(BDL"B`@("`G964G(#T^
M(%\H(D5S=&]N:6$B*2P*("`@("=E9R<@/3X@7R@B16=Y<'0B*2P*("`@("=E
M:"<@/3X@7R@B5V5S=&5R;B!386AA<F$B*2P*("`@("=E<B<@/3X@7R@B17)I
M=')E82(I+`H@("`@)V5S)R`]/B!?*")3<&%I;B(I+`H@("`@)V5T)R`]/B!?
M*")%=&AI;W!I82(I+`H@("`@)V9I)R`]/B!?*")&:6YL86YD(BDL"B`@("`G
M9FHG(#T^(%\H(D9I:FDB*2P*("`@("=F:R<@/3X@7R@B1F%L:VQA;F0@27-L
M86YD<R`H36%L=FEN87,I(BDL"B`@("`G9FTG(#T^(%\H(DUI8W)O;F5S:6$L
M($9E9&5R871E9"!3=&%T97,@;V8B*2P*("`@("=F;R<@/3X@7R@B1F%R;V4@
M27-L86YD<R(I+`H@("`@)V9R)R`]/B!?*")&<F%N8V4B*2P*("`@("=G82<@
M/3X@7R@B1V%B;VXB*2P*("`@("=G9"<@/3X@7R@B1W)E;F%D82(I+`H@("`@
M)V=E)R`]/B!?*")'96]R9VEA(BDL"B`@("`G9V8G(#T^(%\H(D9R96YC:"!'
M=6EA;F$B*2P*("`@("=G9R<@/3X@7R@B1W5E<FYS97DB*2P*("`@("=G:"<@
M/3X@7R@B1VAA;F$B*2P*("`@("=G:2<@/3X@7R@B1VEB<F%L=&%R(BDL"B`@
M("`G9VPG(#T^(%\H(D=R965N;&%N9"(I+`H@("`@)V=M)R`]/B!?*")'86UB
M:6$B*2P*("`@("=G;B<@/3X@7R@B1W5I;F5A(BDL"B`@("`G9W`G(#T^(%\H
M(D=U861E;&]U<&4B*2P*("`@("=G<2<@/3X@7R@B17%U871O<FEA;"!'=6EN
M96$B*2P*("`@("=G<B<@/3X@7R@B1W)E96-E(BDL"B`@("`G9W,G(#T^(%\H
M(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S
M(BDL"B`@("`G9W0G(#T^(%\H(D=U871E;6%L82(I+`H@("`@)V=U)R`]/B!?
M*")'=6%M(BDL"B`@("`G9W<G(#T^(%\H(D=U:6YE82U":7-S874B*2P*("`@
M("=G>2<@/3X@7R@B1W5Y86YA(BDL"B`@("`G:&LG(#T^(%\H(DAO;F<@2V]N
M9R(I+`H@("`@)VAM)R`]/B!?*")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD
M($ES;&%N9',B*2P*("`@("=H;B<@/3X@7R@B2&]N9'5R87,B*2P*("`@("=H
M<B<@/3X@7R@B0W)O871I82(I+`H@("`@)VAT)R`]/B!?*")(86ET:2(I+`H@
M("`@)VAU)R`]/B!?*")(=6YG87)Y(BDL"B`@("`G:60G(#T^(%\H(DEN9&]N
M97-I82(I+`H@("`@)VEE)R`]/B!?*"))<F5L86YD(BDL"B`@("`G:6PG(#T^
M(%\H(DES<F%E;"(I+`H@("`@)VEM)R`]/B!?*"))<VQE(&]F($UA;B(I+`H@
M("`@)VEN)R`]/B!?*"));F1I82(I+`H@("`@)VEO)R`]/B!?*")"<FET:7-H
M($EN9&EA;B!/8V5A;B!497)R:71O<GDB*2P*("`@("=I<2<@/3X@7R@B27)A
M<2(I+`H@("`@)VER)R`]/B!?*"))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F
M(BDL"B`@("`G:7,G(#T^(%\H(DEC96QA;F0B*2P*("`@("=I="<@/3X@7R@B
M271A;'DB*2P*("`@("=J92<@/3X@7R@B2F5R<V5Y(BDL"B`@("`G:FTG(#T^
M(%\H(DIA;6%I8V$B*2P*("`@("=J;R<@/3X@7R@B2F]R9&%N(BDL"B`@("`G
M:G`G(#T^(%\H(DIA<&%N(BDL"B`@("`G:V4G(#T^(%\H(DME;GEA(BDL"B`@
M("`G:V<G(#T^(%\H(DMY<F=Y>G-T86XB*2P*("`@("=K:"<@/3X@7R@B0V%M
M8F]D:6$B*2P*("`@("=K:2<@/3X@7R@B2VER:6)A=&DB*2P*("`@("=K;2<@
M/3X@7R@B0V]M;W)O<R(I+`H@("`@)VMN)R`]/B!?*")386EN="!+:71T<R!A
M;F0@3F5V:7,B*2P*("`@("=K<"<@/3X@7R@B2V]R96$L($1E;6]C<F%T:6,@
M4&5O<&QE)W,@4F5P=6)L:6,@;V8B*2P*("`@("=K<B<@/3X@7R@B2V]R96$L
M(%)E<'5B;&EC(&]F(BDL"B`@("`G:W<G(#T^(%\H(DMU=V%I="(I+`H@("`@
M)VMY)R`]/B!?*")#87EM86X@27-L86YD<R(I+`H@("`@)VMZ)R`]/B!?*")+
M87IA:VAS=&%N(BDL"B`@("`G;&$G(#T^(%\H(DQA;R!096]P;&4G<R!$96UO
M8W)A=&EC(%)E<'5B;&EC(BDL"B`@("`G;&(G(#T^(%\H(DQE8F%N;VXB*2P*
M("`@("=L8R<@/3X@7R@B4V%I;G0@3'5C:6$B*2P*("`@("=L:2<@/3X@7R@B
M3&EE8VAT96YS=&5I;B(I+`H@("`@)VQK)R`]/B!?*")3<FD@3&%N:V$B*2P*
M("`@("=L<B<@/3X@7R@B3&EB97)I82(I+`H@("`@)VQS)R`]/B!?*"),97-O
M=&AO(BDL"B`@("`G;'0G(#T^(%\H(DQI=&AU86YI82(I+`H@("`@)VQU)R`]
M/B!?*"),=7AE;6)O=7)G(BDL"B`@("`G;'8G(#T^(%\H(DQA='9I82(I+`H@
M("`@)VQY)R`]/B!?*"),:6)Y86X@07)A8B!*86UA:&ER:7EA(BDL"B`@("`G
M;6$G(#T^(%\H(DUO<F]C8V\B*2P*("`@("=M8R<@/3X@7R@B36]N86-O(BDL
M"B`@("`G;60G(#T^(%\H(DUO;&1O=F$L(%)E<'5B;&EC(&]F(BDL"B`@("`G
M;6<G(#T^(%\H(DUA9&%G87-C87(B*2P*("`@("=M:"<@/3X@7R@B36%R<VAA
M;&P@27-L86YD<R(I+`H@("`@)VUK)R`]/B!?*")-86-E9&]N:6$L(%1H92!&
M;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B*2P*("`@("=M;"<@/3X@7R@B
M36%L:2(I+`H@("`@)VUM)R`]/B!?*")->6%N;6%R(BDL"B`@("`G;6XG(#T^
M(%\H(DUO;F=O;&EA(BDL"B`@("`G;6\G(#T^(%\H(DUA8V%O(BDL"B`@("`G
M;7`G(#T^(%\H(DYO<G1H97)N($UA<FEA;F$@27-L86YD<R(I+`H@("`@)VUQ
M)R`]/B!?*")-87)T:6YI<75E(BDL"B`@("`G;7(G(#T^(%\H(DUA=7)I=&%N
M:6$B*2P*("`@("=M<R<@/3X@7R@B36]N='-E<G)A="(I+`H@("`@)VUT)R`]
M/B!?*")-86QT82(I+`H@("`@)VUU)R`]/B!?*")-875R:71I=7,B*2P*("`@
M("=M=B<@/3X@7R@B36%L9&EV97,B*2P*("`@("=M=R<@/3X@7R@B36%L87=I
M(BDL"B`@("`G;7@G(#T^(%\H(DUE>&EC;R(I+`H@("`@)VUY)R`]/B!?*")-
M86QA>7-I82(I+`H@("`@)VUZ)R`]/B!?*")-;WIA;6)I<75E(BDL"B`@("`G
M;F$G(#T^(%\H(DYA;6EB:6$B*2P*("`@("=N8R<@/3X@7R@B3F5W($-A;&5D
M;VYI82(I+`H@("`@)VYE)R`]/B!?*").:6=E<B(I+`H@("`@)VYF)R`]/B!?
M*").;W)F;VQK($ES;&%N9"(I+`H@("`@)VYG)R`]/B!?*").:6=E<FEA(BDL
M"B`@("`G;FDG(#T^(%\H(DYI8V%R86=U82(I+`H@("`@)VYL)R`]/B!?*").
M971H97)L86YD<R(I+`H@("`@)VYO)R`]/B!?*").;W)W87DB*2P*("`@("=N
M<"<@/3X@7R@B3F5P86PB*2P*("`@("=N<B<@/3X@7R@B3F%U<G4B*2P*("`@
M("=N=2<@/3X@7R@B3FEU92(I+`H@("`@)VYZ)R`]/B!?*").97<@6F5A;&%N
M9"(I+`H@("`@)V]M)R`]/B!?*")/;6%N(BDL"B`@("`G<&$G(#T^(%\H(E!A
M;F%M82(I+`H@("`@)W!E)R`]/B!?*")097)U(BDL"B`@("`G<&8G(#T^(%\H
M(D9R96YC:"!0;VQY;F5S:6$B*2P*("`@("=P9R<@/3X@7R@B4&%P=6$@3F5W
M($=U:6YE82(I+`H@("`@)W!H)R`]/B!?*")0:&EL:7!P:6YE<R(I+`H@("`@
M)W!K)R`]/B!?*")086MI<W1A;B(I+`H@("`@)W!L)R`]/B!?*")0;VQA;F0B
M*2P*("`@("=P;2<@/3X@7R@B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(I
M+`H@("`@)W!N)R`]/B!?*")0:71C86ER;B(I+`H@("`@)W!R)R`]/B!?*")0
M=65R=&\@4FEC;R(I+`H@("`@)W!S)R`]/B!?*")086QE<W1I;FEA;B!497)R
M:71O<GDL($]C8W5P:65D(BDL"B`@("`G<'0G(#T^(%\H(E!O<G1U9V%L(BDL
M"B`@("`G<'<G(#T^(%\H(E!A;&%U(BDL"B`@("`G<'DG(#T^(%\H(E!A<F%G
M=6%Y(BDL"B`@("`G<6$G(#T^(%\H(E%A=&%R(BDL"B`@("`G<F4G(#T^(%\H
M(E)E=6YI;VXB*2P*("`@("=R;R<@/3X@7R@B4F]M86YI82(I+`H@("`@)W)U
M)R`]/B!?*")2=7-S:6%N($9E9&5R871I;VXB*2P*("`@("=R=R<@/3X@7R@B
M4G=A;F1A(BDL"B`@("`G<V$G(#T^(%\H(E-A=61I($%R86)I82(I+`H@("`@
M)W-B)R`]/B!?*")3;VQO;6]N($ES;&%N9',B*2P*("`@("=S8R<@/3X@7R@B
M4V5Y8VAE;&QE<R(I+`H@("`@)W-D)R`]/B!?*")3=61A;B(I+`H@("`@)W-E
M)R`]/B!?*")3=V5D96XB*2P*("`@("=S9R<@/3X@7R@B4VEN9V%P;W)E(BDL
M"B`@("`G<V@G(#T^(%\H(E-A:6YT($AE;&5N82(I+`H@("`@)W-I)R`]/B!?
M*")3;&]V96YI82(I+`H@("`@)W-J)R`]/B!?*")3=F%L8F%R9"!A;F0@2F%N
M($UA>65N(BDL"B`@("`G<VLG(#T^(%\H(E-L;W9A:VEA(BDL"B`@("`G<VPG
M(#T^(%\H(E-I97)R82!,96]N92(I+`H@("`@)W-M)R`]/B!?*")386X@36%R
M:6YO(BDL"B`@("`G<VXG(#T^(%\H(E-E;F5G86PB*2P*("`@("=S;R<@/3X@
M7R@B4V]M86QI82(I+`H@("`@)W-R)R`]/B!?*")3=7)I;F%M92(I+`H@("`@
M)W-T)R`]/B!?*")386\@5&]M92!A;F0@4')I;F-I<&4B*2P*("`@("=S=B<@
M/3X@7R@B16P@4V%L=F%D;W(B*2P*("`@("=S>2<@/3X@7R@B4WER:6%N($%R
M86(@4F5P=6)L:6,B*2P*("`@("=S>B<@/3X@7R@B4W=A>FEL86YD(BDL"B`@
M("`G=&,G(#T^(%\H(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(I+`H@("`@
M)W1D)R`]/B!?*")#:&%D(BDL"B`@("`G=&8G(#T^(%\H(D9R96YC:"!3;W5T
M:&5R;B!497)R:71O<FEE<R(I+`H@("`@)W1G)R`]/B!?*")4;V=O(BDL"B`@
M("`G=&@G(#T^(%\H(E1H86EL86YD(BDL"B`@("`G=&HG(#T^(%\H(E1A:FEK
M:7-T86XB*2P*("`@("=T:R<@/3X@7R@B5&]K96QA=2(I+`H@("`@)W1M)R`]
M/B!?*")4=7)K;65N:7-T86XB*2P*("`@("=T;B<@/3X@7R@B5'5N:7-I82(I
M+`H@("`@)W1O)R`]/B!?*")4;VYG82(I+`H@("`@)W1P)R`]/B!?*")4:6UO
M<BU,97-T92(I+`H@("`@)W1R)R`]/B!?*")4=7)K97DB*2P*("`@("=T="<@
M/3X@7R@B5')I;FED860@86YD(%1O8F%G;R(I+`H@("`@)W1V)R`]/B!?*")4
M=79A;'4B*2P*("`@("=T=R<@/3X@7R@B5&%I=V%N(BDL"B`@("`G='HG(#T^
M(%\H(E1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8B*2P*("`@("=U82<@
M/3X@7R@B56MR86EN92(I+`H@("`@)W5G)R`]/B!?*")59V%N9&$B*2P*("`@
M("=U:R<@/3X@7R@B56YI=&5D($MI;F=D;VTB*2P*("`@("=U;2<@/3X@7R@B
M56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(BDL"B`@("`G
M=7,G(#T^(%\H(E5N:71E9"!3=&%T97,B*2P*("`@("=U>2<@/3X@7R@B57)U
M9W5A>2(I+`H@("`@)W5Z)R`]/B!?*")5>F)E:VES=&%N(BDL"B`@("`G=F$G
M(#T^(%\H(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I(BDL"B`@("`G
M=F,G(#T^(%\H(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(BDL
M"B`@("`G=F4G(#T^(%\H(E9E;F5Z=65L82(I+`H@("`@)W9G)R`]/B!?*")6
M:7)G:6X@27-L86YD<RP@0G)I=&ES:"(I+`H@("`@)W9I)R`]/B!?*")6:7)G
M:6X@27-L86YD<RP@52Y3+B(I+`H@("`@)W9N)R`]/B!?*")6:65T($YA;2(I
M+`H@("`@)W9U)R`]/B!?*")686YU871U(BDL"B`@("`G=V8G(#T^(%\H(E=A
M;&QI<R!A;F0@1G5T=6YA(BDL"B`@("`G=W,G(#T^(%\H(E-A;6]A(BDL"B`@
M("`G>64G(#T^(%\H(EEE;65N(BDL"B`@("`G>70G(#T^(%\H(DUA>6]T=&4B
M*2P*("`@("=Y=2<@/3X@7R@B675G;W-L879I82(I+`H@("`@)WIA)R`]/B!?
M*")3;W5T:"!!9G)I8V$B*2P*("`@("=Z;2<@/3X@7R@B6F%M8FEA(BDL"B`@
M("`G>G<G(#T^(%\H(EII;6)A8G=E(BD**3L*````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<```````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`Q-C,P-2`Q,#4Q-30S,S<S-R`P,C(U,S<`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J(%1H92!)4T\M,S$V-B!C;W5N=')Y(&QI<W0N"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<"QV(#$N,RXQ
M,BXQ(#(P,#4O,3`O,3@@,3$Z,#$Z,3@@:F%N($5X<"`D"B`J"B`J($!P86-K
M86=E($AO<F1E7TY,4PH@*B\*"B1C;W5N=')I97,@/2!A<G)A>2@*("`@("=!
M1B<@/3X@7R@B069G:&%N:7-T86XB*2P*("`@("=!3"<@/3X@7R@B06QB86YI
M82(I+`H@("`@)T1:)R`]/B!?*")!;&=E<FEA(BDL"B`@("`G05,G(#T^(%\H
M(D%M97)I8V%N(%-A;6]A(BDL"B`@("`G040G(#T^(%\H(D%N9&]R<F$B*2P*
M("`@("=!3R<@/3X@7R@B06YG;VQA(BDL"B`@("`G04DG(#T^(%\H(D%N9W5I
M;&QA(BDL"B`@("`G05$G(#T^(%\H(D%N=&%R8W1I8V$B*2P*("`@("=!1R<@
M/3X@7R@B06YT:6=U82!A;F0@0F%R8G5D82(I+`H@("`@)T%2)R`]/B!?*")!
M<F=E;G1I;F$B*2P*("`@("=!32<@/3X@7R@B07)M96YI82(I+`H@("`@)T%7
M)R`]/B!?*")!<G5B82(I+`H@("`@)T%5)R`]/B!?*")!=7-T<F%L:6$B*2P*
M("`@("=!5"<@/3X@7R@B075S=')I82(I+`H@("`@)T%:)R`]/B!?*")!>F5R
M8F%I:F%N(BDL"B`@("`G0E,G(#T^(%\H(D)A:&%M87,B*2P*("`@("="2"<@
M/3X@7R@B0F%H<F%I;B(I+`H@("`@)T)$)R`]/B!?*")"86YG;&%D97-H(BDL
M"B`@("`G0D(G(#T^(%\H(D)A<F)A9&]S(BDL"B`@("`G0EDG(#T^(%\H(D)E
M;&%R=7,B*2P*("`@("="12<@/3X@7R@B0F5L9VEU;2(I+`H@("`@)T):)R`]
M/B!?*")"96QI>F4B*2P*("`@("="2B<@/3X@7R@B0F5N:6XB*2P*("`@("="
M32<@/3X@7R@B0F5R;75D82(I+`H@("`@)T)4)R`]/B!?*")":'5T86XB*2P*
M("`@("="3R<@/3X@7R@B0F]L:79I82(I+`H@("`@)T)!)R`]/B!?*")";W-N
M:6$@86YD($AE<GIE9V]V:6YA(BDL"B`@("`G0E<G(#T^(%\H(D)O='-W86YA
M(BDL"B`@("`G0E8G(#T^(%\H(D)O=79E="!)<VQA;F0B*2P*("`@("="4B<@
M/3X@7R@B0G)A>FEL(BDL"B`@("`G24\G(#T^(%\H(D)R:71I<V@@26YD:6%N
M($]C96%N(%1E<G)I=&]R>2(I+`H@("`@)T).)R`]/B!?*")"<G5N96D@1&%R
M=7-S86QA;2(I+`H@("`@)T)')R`]/B!?*")"=6QG87)I82(I+`H@("`@)T)&
M)R`]/B!?*")"=7)K:6YA($9A<V\B*2P*("`@("="22<@/3X@7R@B0G5R=6YD
M:2(I+`H@("`@)TM()R`]/B!?*")#86UB;V1I82(I+`H@("`@)T--)R`]/B!?
M*")#86UE<F]O;B(I+`H@("`@)T-!)R`]/B!?*")#86YA9&$B*2P*("`@("=#
M5B<@/3X@7R@B0V%P92!697)D92(I+`H@("`@)TM9)R`]/B!?*")#87EM86X@
M27-L86YD<R(I+`H@("`@)T-&)R`]/B!?*")#96YT<F%L($%F<FEC86X@4F5P
M=6)L:6,B*2P*("`@("=41"<@/3X@7R@B0VAA9"(I+`H@("`@)T-,)R`]/B!?
M*")#:&EL92(I+`H@("`@)T-.)R`]/B!?*")#:&EN82(I+`H@("`@)T-8)R`]
M/B!?*")#:')I<W1M87,@27-L86YD(BDL"B`@("`G0T,G(#T^(%\H(D-O8V]S
M("A+965L:6YG*2!)<VQA;F1S(BDL"B`@("`G0T\G(#T^(%\H(D-O;&]M8FEA
M(BDL"B`@("`G2TTG(#T^(%\H(D-O;6]R;W,B*2P*("`@("=#1R<@/3X@7R@B
M0V]N9V\B*2P*("`@("=#1"<@/3X@7R@B0V]N9V\L(%1H92!$96UO8W)A=&EC
M(%)E<'5B;&EC(&]F('1H92(I+`H@("`@)T-+)R`]/B!?*")#;V]K($ES;&%N
M9',B*2P*("`@("=#4B<@/3X@7R@B0V]S=&$@4FEC82(I+`H@("`@)T-))R`]
M/B!?*")#;W1E(&0G279O:7)E(BDL"B`@("`G2%(G(#T^(%\H(D-R;V%T:6$B
M*2P*("`@("=#52<@/3X@7R@B0W5B82(I+`H@("`@)T-9)R`]/B!?*")#>7!R
M=7,B*2P*("`@("=#6B<@/3X@7R@B0WIE8V@@4F5P=6)L:6,B*2P*("`@("=$
M2R<@/3X@7R@B1&5N;6%R:R(I+`H@("`@)T1*)R`]/B!?*")$:FEB;W5T:2(I
M+`H@("`@)T1-)R`]/B!?*")$;VUI;FEC82(I+`H@("`@)T1/)R`]/B!?*")$
M;VUI;FEC86X@4F5P=6)L:6,B*2P*("`@("=%0R<@/3X@7R@B16-U861O<B(I
M+`H@("`@)T5')R`]/B!?*")%9WEP="(I+`H@("`@)U-6)R`]/B!?*")%;"!3
M86QV861O<B(I+`H@("`@)T=1)R`]/B!?*")%<75A=&]R:6%L($=U:6YE82(I
M+`H@("`@)T52)R`]/B!?*")%<FET<F5A(BDL"B`@("`G144G(#T^(%\H(D5S
M=&]N:6$B*2P*("`@("=%5"<@/3X@7R@B171H:6]P:6$B*2P*("`@("=&2R<@
M/3X@7R@B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I(BDL"B`@("`G1D\G
M(#T^(%\H(D9A<F]E($ES;&%N9',B*2P*("`@("=&2B<@/3X@7R@B1FEJ:2(I
M+`H@("`@)T9))R`]/B!?*")&:6YL86YD(BDL"B`@("`G1E(G(#T^(%\H(D9R
M86YC92(I+`H@("`@)T=&)R`]/B!?*")&<F5N8V@@1W5I86YA(BDL"B`@("`G
M4$8G(#T^(%\H(D9R96YC:"!0;VQY;F5S:6$B*2P*("`@("=41B<@/3X@7R@B
M1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S(BDL"B`@("`G1T$G(#T^(%\H
M(D=A8F]N(BDL"B`@("`G1TTG(#T^(%\H(D=A;6)I82(I+`H@("`@)T=%)R`]
M/B!?*")'96]R9VEA(BDL"B`@("`G1$4G(#T^(%\H(D=E<FUA;GDB*2P*("`@
M("='2"<@/3X@7R@B1VAA;F$B*2P*("`@("='22<@/3X@7R@B1VEB<F%L=&%R
M(BDL"B`@("`G1U(G(#T^(%\H(D=R965C92(I+`H@("`@)T=,)R`]/B!?*")'
M<F5E;FQA;F0B*2P*("`@("='1"<@/3X@7R@B1W)E;F%D82(I+`H@("`@)T=0
M)R`]/B!?*")'=6%D96QO=7!E(BDL"B`@("`G1U4G(#T^(%\H(D=U86TB*2P*
M("`@("='5"<@/3X@7R@B1W5A=&5M86QA(BDL"B`@("`G1TXG(#T^(%\H(D=U
M:6YE82(I+`H@("`@)T=7)R`]/B!?*")'=6EN96$M0FES<V%U(BDL"B`@("`G
M1UDG(#T^(%\H(D=U>6%N82(I+`H@("`@)TA4)R`]/B!?*")(86ET:2(I+`H@
M("`@)TA-)R`]/B!?*")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N
M9',B*2P*("`@("=602<@/3X@7R@B2&]L>2!3964@*%9A=&EC86X@0VET>2!3
M=&%T92DB*2P*("`@("=(3B<@/3X@7R@B2&]N9'5R87,B*2P*("`@("=(2R<@
M/3X@7R@B2&]N9R!+;VYG(BDL"B`@("`G2%4G(#T^(%\H(DAU;F=A<GDB*2P*
M("`@("=)4R<@/3X@7R@B26-E;&%N9"(I+`H@("`@)TE.)R`]/B!?*"));F1I
M82(I+`H@("`@)TE$)R`]/B!?*"));F1O;F5S:6$B*2P*("`@("=)4B<@/3X@
M7R@B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(I+`H@("`@)TE1)R`]/B!?
M*"))<F%Q(BDL"B`@("`G244G(#T^(%\H(DER96QA;F0B*2P*("`@("=)3"<@
M/3X@7R@B27-R865L(BDL"B`@("`G250G(#T^(%\H(DET86QY(BDL"B`@("`G
M2DTG(#T^(%\H(DIA;6%I8V$B*2P*("`@("=*4"<@/3X@7R@B2F%P86XB*2P*
M("`@("=*3R<@/3X@7R@B2F]R9&%N(BDL"B`@("`G2UHG(#T^(%\H(DMA>F%K
M:'-T86XB*2P*("`@("=+12<@/3X@7R@B2V5N>6$B*2P*("`@("=+22<@/3X@
M7R@B2VER:6)A=&DB*2P*("`@("=+4"<@/3X@7R@B2V]R96$L($1E;6]C<F%T
M:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B*2P*("`@("=+4B<@/3X@7R@B2V]R
M96$L(%)E<'5B;&EC(&]F(BDL"B`@("`G2U<G(#T^(%\H(DMU=V%I="(I+`H@
M("`@)TM')R`]/B!?*")+>7)G>7IS=&%N(BDL"B`@("`G3$$G(#T^(%\H(DQA
M;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(BDL"B`@("`G3%8G(#T^
M(%\H(DQA='9I82(I+`H@("`@)TQ")R`]/B!?*"),96)A;F]N(BDL"B`@("`G
M3%,G(#T^(%\H(DQE<V]T:&\B*2P*("`@("=,4B<@/3X@7R@B3&EB97)I82(I
M+`H@("`@)TQ9)R`]/B!?*"),:6)Y86X@07)A8B!*86UA:&ER:7EA(BDL"B`@
M("`G3$DG(#T^(%\H(DQI96-H=&5N<W1E:6XB*2P*("`@("=,5"<@/3X@7R@B
M3&ET:'5A;FEA(BDL"B`@("`G3%4G(#T^(%\H(DQU>&5M8F]U<F<B*2P*("`@
M("=-3R<@/3X@7R@B36%C86\B*2P*("`@("=-2R<@/3X@7R@B36%C961O;FEA
M+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(BDL"B`@("`G34<G
M(#T^(%\H(DUA9&%G87-C87(B*2P*("`@("=-5R<@/3X@7R@B36%L87=I(BDL
M"B`@("`G35DG(#T^(%\H(DUA;&%Y<VEA(BDL"B`@("`G358G(#T^(%\H(DUA
M;&1I=F5S(BDL"B`@("`G34PG(#T^(%\H(DUA;&DB*2P*("`@("=-5"<@/3X@
M7R@B36%L=&$B*2P*("`@("=-2"<@/3X@7R@B36%R<VAA;&P@27-L86YD<R(I
M+`H@("`@)TU1)R`]/B!?*")-87)T:6YI<75E(BDL"B`@("`G35(G(#T^(%\H
M(DUA=7)I=&%N:6$B*2P*("`@("=-52<@/3X@7R@B36%U<FET:75S(BDL"B`@
M("`G650G(#T^(%\H(DUA>6]T=&4B*2P*("`@("=-6"<@/3X@7R@B365X:6-O
M(BDL"B`@("`G1DTG(#T^(%\H(DUI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T
M97,@;V8B*2P*("`@("=-1"<@/3X@7R@B36]L9&]V82P@4F5P=6)L:6,@;V8B
M*2P*("`@("=-0R<@/3X@7R@B36]N86-O(BDL"B`@("`G34XG(#T^(%\H(DUO
M;F=O;&EA(BDL"B`@("`G35,G(#T^(%\H(DUO;G1S97)R870B*2P*("`@("=-
M02<@/3X@7R@B36]R;V-C;R(I+`H@("`@)TU:)R`]/B!?*")-;WIA;6)I<75E
M(BDL"B`@("`G34TG(#T^(%\H(DUY86YM87(B*2P*("`@("=.02<@/3X@7R@B
M3F%M:6)I82(I+`H@("`@)TY2)R`]/B!?*").875R=2(I+`H@("`@)TY0)R`]
M/B!?*").97!A;"(I+`H@("`@)TY,)R`]/B!?*").971H97)L86YD<R(I+`H@
M("`@)T%.)R`]/B!?*").971H97)L86YD<R!!;G1I;&QE<R(I+`H@("`@)TY#
M)R`]/B!?*").97<@0V%L961O;FEA(BDL"B`@("`G3EHG(#T^(%\H(DYE=R!:
M96%L86YD(BDL"B`@("`G3DDG(#T^(%\H(DYI8V%R86=U82(I+`H@("`@)TY%
M)R`]/B!?*").:6=E<B(I+`H@("`@)TY')R`]/B!?*").:6=E<FEA(BDL"B`@
M("`G3E4G(#T^(%\H(DYI=64B*2P*("`@("=.1B<@/3X@7R@B3F]R9F]L:R!)
M<VQA;F0B*2P*("`@("=-4"<@/3X@7R@B3F]R=&AE<FX@36%R:6%N82!)<VQA
M;F1S(BDL"B`@("`G3D\G(#T^(%\H(DYO<G=A>2(I+`H@("`@)T]-)R`]/B!?
M*")/;6%N(BDL"B`@("`G4$LG(#T^(%\H(E!A:VES=&%N(BDL"B`@("`G4%<G
M(#T^(%\H(E!A;&%U(BDL"B`@("`G4%,G(#T^(%\H(E!A;&5S=&EN:6%N(%1E
M<G)I=&]R>2P@3V-C=7!I960B*2P*("`@("=002<@/3X@7R@B4&%N86UA(BDL
M"B`@("`G4$<G(#T^(%\H(E!A<'5A($YE=R!'=6EN96$B*2P*("`@("=062<@
M/3X@7R@B4&%R86=U87DB*2P*("`@("=012<@/3X@7R@B4&5R=2(I+`H@("`@
M)U!()R`]/B!?*")0:&EL:7!P:6YE<R(I+`H@("`@)U!.)R`]/B!?*")0:71C
M86ER;B(I+`H@("`@)U!,)R`]/B!?*")0;VQA;F0B*2P*("`@("=05"<@/3X@
M7R@B4&]R='5G86PB*2P*("`@("=04B<@/3X@7R@B4'5E<G1O(%)I8V\B*2P*
M("`@("=102<@/3X@7R@B46%T87(B*2P*("`@("=212<@/3X@7R@B4F5U;FEO
M;B(I+`H@("`@)U)/)R`]/B!?*")2;VUA;FEA(BDL"B`@("`G4E4G(#T^(%\H
M(E)U<W-I86X@1F5D97)A=&EO;B(I+`H@("`@)U)7)R`]/B!?*")2=V%N9&$B
M*2P*("`@("=32"<@/3X@7R@B4V%I;G0@2&5L96YA(BDL"B`@("`G2TXG(#T^
M(%\H(E-A:6YT($MI='1S(&%N9"!.979I<R(I+`H@("`@)TQ#)R`]/B!?*")3
M86EN="!,=6-I82(I+`H@("`@)U!-)R`]/B!?*")386EN="!0:65R<F4@86YD
M($UI<75E;&]N(BDL"B`@("`G5D,G(#T^(%\H(E-A:6YT(%9I;F-E;G0@86YD
M('1H92!'<F5N861I;F5S(BDL"B`@("`G5U,G(#T^(%\H(E-A;6]A(BDL"B`@
M("`G4TTG(#T^(%\H(E-A;B!-87)I;F\B*2P*("`@("=35"<@/3X@7R@B4V%O
M(%1O;64@86YD(%!R:6YC:7!E(BDL"B`@("`G4T$G(#T^(%\H(E-A=61I($%R
M86)I82(I+`H@("`@)U-.)R`]/B!?*")396YE9V%L(BDL"B`@("`G0U,G(#T^
M(%\H(E-E<F)I82!A;F0@36]N=&5N96=R;R(I+`H@("`@)U-#)R`]/B!?*")3
M97EC:&5L;&5S(BDL"B`@("`G4TPG(#T^(%\H(E-I97)R82!,96]N92(I+`H@
M("`@)U-')R`]/B!?*")3:6YG87!O<F4B*2P*("`@("=32R<@/3X@7R@B4VQO
M=F%K:6$B*2P*("`@("=322<@/3X@7R@B4VQO=F5N:6$B*2P*("`@("=30B<@
M/3X@7R@B4V]L;VUO;B!)<VQA;F1S(BDL"B`@("`G4T\G(#T^(%\H(E-O;6%L
M:6$B*2P*("`@("=:02<@/3X@7R@B4V]U=&@@069R:6-A(BDL"B`@("`G1U,G
M(#T^(%\H(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)
M<VQA;F1S(BDL"B`@("`G15,G(#T^(%\H(E-P86EN(BDL"B`@("`G3$LG(#T^
M(%\H(E-R:2!,86YK82(I+`H@("`@)U-$)R`]/B!?*")3=61A;B(I+`H@("`@
M)U-2)R`]/B!?*")3=7)I;F%M92(I+`H@("`@)U-*)R`]/B!?*")3=F%L8F%R
M9"!A;F0@2F%N($UA>65N(BDL"B`@("`G4UHG(#T^(%\H(E-W87II;&%N9"(I
M+`H@("`@)U-%)R`]/B!?*")3=V5D96XB*2P*("`@("=#2"<@/3X@7R@B4W=I
M='IE<FQA;F0B*2P*("`@("=362<@/3X@7R@B4WER:6%N($%R86(@4F5P=6)L
M:6,B*2P*("`@("=45R<@/3X@7R@B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN
M82(I+`H@("`@)U1*)R`]/B!?*")486II:VES=&%N(BDL"B`@("`G5%HG(#T^
M(%\H(E1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8B*2P*("`@("=42"<@
M/3X@7R@B5&AA:6QA;F0B*2P*("`@("=43"<@/3X@7R@B5&EM;W(M3&5S=&4B
M*2P*("`@("=41R<@/3X@7R@B5&]G;R(I+`H@("`@)U1+)R`]/B!?*")4;VME
M;&%U(BDL"B`@("`G5$\G(#T^(%\H(E1O;F=A(BDL"B`@("`G5%0G(#T^(%\H
M(E1R:6YI9&%D(&%N9"!4;V)A9V\B*2P*("`@("=43B<@/3X@7R@B5'5N:7-I
M82(I+`H@("`@)U12)R`]/B!?*")4=7)K97DB*2P*("`@("=432<@/3X@7R@B
M5'5R:VUE;FES=&%N(BDL"B`@("`G5$,G(#T^(%\H(E1U<FMS(&%N9"!#86EC
M;W,@27-L86YD<R(I+`H@("`@)U16)R`]/B!?*")4=79A;'4B*2P*("`@("=5
M1R<@/3X@7R@B56=A;F1A(BDL"B`@("`G54$G(#T^(%\H(E5K<F%I;F4B*2P*
M("`@("=!12<@/3X@7R@B56YI=&5D($%R86(@16UI<F%T97,B*2P*("`@("='
M0B<@/3X@7R@B56YI=&5D($MI;F=D;VTB*2P*("`@("=54R<@/3X@7R@B56YI
M=&5D(%-T871E<R(I+`H@("`@)U5-)R`]/B!?*")5;FET960@4W1A=&5S($UI
M;F]R($]U=&QY:6YG($ES;&%N9',B*2P*("`@("=562<@/3X@7R@B57)U9W5A
M>2(I+`H@("`@)U5:)R`]/B!?*")5>F)E:VES=&%N(BDL"B`@("`G5E4G(#T^
M(%\H(E9A;G5A='4B*2P*("`@("=612<@/3X@7R@B5F5N97IU96QA(BDL"B`@
M("`G5DXG(#T^(%\H(E9I970@3F%M(BDL"B`@("`G5D<G(#T^(%\H(E9I<F=I
M;B!)<VQA;F1S+"!"<FET:7-H(BDL"B`@("`G5DDG(#T^(%\H(E9I<F=I;B!)
M<VQA;F1S+"!5+E,N(BDL"B`@("`G5T8G(#T^(%\H(E=A;&QI<R!A;F0@1G5T
M=6YA(BDL"B`@("`G14@G(#T^(%\H(E=E<W1E<FX@4V%H87)A(BDL"B`@("`G
M644G(#T^(%\H(EEE;65N(BDL"B`@("`G6DTG(#T^(%\H(EIA;6)I82(I+`H@
M("`@)UI7)R`]/B!?*")::6UB86)W92(I*3L*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+TY,4R]'96])4"YP:'``````````````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#,Q-30S(#$P-3$U-#,S-S,W(#`R,30W
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@2&]R9&4@;W!T:6UI>F5D(&EN=&5R9F%C92!T;R!T:&4@
M36%X36EN9"!)4"!!9&1R97-S+3Y#;W5N=')Y"B`J(&QI<W1I;F<N"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP+'8@,2XQ,"XQ
M,"XW(#(P,#8O,#8O,C<@,34Z,3DZ,3(@<VQU<V%R>B!%>'`@)`H@*@H@*B!"
M87-E9"!O;B!02%`@9V5O:7`N:6YC(&QI8G)A<GD@8GD@36%X36EN9"!,3$,Z
M"B`J("`@:'1T<#HO+W=W=RYM87AM:6YD+F-O;2]D;W=N;&]A9"]G96]I<"]A
M<&DO<&AP+PH@*@H@*B!/<FEG:6YA;&QY(&)A<V5D(&]N('!H<"!V97)S:6]N
M(&]F('1H92!G96]I<"!L:6)R87)Y('=R:71T96X@:6X@36%Y"B`J(#(P,#(@
M8GD@:FEM('=I;G-T96%D(#QJ:6UW0&%P86-H92YO<F<^"B`J"B`J($-O<'ER
M:6=H="`H0RD@,C`P,R!-87A-:6YD($Q,0PH@*B!#;W!Y<FEG:'0@,C`P,RTR
M,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O
M+F5D=3X*("H*("H@5&AI<R!L:6)R87)Y(&ES(&9R964@<V]F='=A<F4[('EO
M=2!C86X@<F5D:7-T<FEB=71E(&ET(&%N9"]O<@H@*B!M;V1I9GD@:70@=6YD
M97(@=&AE('1E<FUS(&]F('1H92!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC
M"B`J($QI8V5N<V4@87,@<'5B;&ES:&5D(&)Y('1H92!&<F5E(%-O9G1W87)E
M($9O=6YD871I;VX[(&5I=&AE<@H@*B!V97)S:6]N(#(N,2!O9B!T:&4@3&EC
M96YS92P@;W(@*&%T('EO=7(@;W!T:6]N*2!A;GD@;&%T97(@=F5R<VEO;BX*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\
M<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@2&]R
M9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TY,4PH@*B\*"B\J($-O=6YT<GD@
M;&ES="X@*B\*)$=,3T)!3%-;)T=%3TE07T-/54Y44EE?0T]$15,G72`](&%R
M<F%Y*`HG)RP@)T%0)RP@)T55)RP@)T%$)RP@)T%%)RP@)T%&)RP@)T%')RP@
M)T%))RP@)T%,)RP@)T%-)RP@)T%.)RP@)T%/)RP@)T%1)RP*)T%2)RP@)T%3
M)RP@)T%4)RP@)T%5)RP@)T%7)RP@)T%:)RP@)T)!)RP@)T)")RP@)T)$)RP@
M)T)%)RP@)T)&)RP@)T)')RP@)T)()RP*)T)))RP@)T)*)RP@)T)-)RP@)T).
M)RP@)T)/)RP@)T)2)RP@)T)3)RP@)T)4)RP@)T)6)RP@)T)7)RP@)T)9)RP@
M)T):)RP@)T-!)RP*)T-#)RP@)T-$)RP@)T-&)RP@)T-')RP@)T-()RP@)T-)
M)RP@)T-+)RP@)T-,)RP@)T--)RP@)T-.)RP@)T-/)RP@)T-2)RP@)T-5)RP*
M)T-6)RP@)T-8)RP@)T-9)RP@)T-:)RP@)T1%)RP@)T1*)RP@)T1+)RP@)T1-
M)RP@)T1/)RP@)T1:)RP@)T5#)RP@)T5%)RP@)T5')RP*)T5()RP@)T52)RP@
M)T53)RP@)T54)RP@)T9))RP@)T9*)RP@)T9+)RP@)T9-)RP@)T9/)RP@)T92
M)RP@)T98)RP@)T=!)RP@)U5+)RP*)T=$)RP@)T=%)RP@)T=&)RP@)T=()RP@
M)T=))RP@)T=,)RP@)T=-)RP@)T=.)RP@)T=0)RP@)T=1)RP@)T=2)RP@)T=3
M)RP@)T=4)RP*)T=5)RP@)T=7)RP@)T=9)RP@)TA+)RP@)TA-)RP@)TA.)RP@
M)TA2)RP@)TA4)RP@)TA5)RP@)TE$)RP@)TE%)RP@)TE,)RP@)TE.)RP*)TE/
M)RP@)TE1)RP@)TE2)RP@)TE3)RP@)TE4)RP@)TI-)RP@)TI/)RP@)TI0)RP@
M)TM%)RP@)TM')RP@)TM()RP@)TM))RP@)TM-)RP*)TM.)RP@)TM0)RP@)TM2
M)RP@)TM7)RP@)TM9)RP@)TM:)RP@)TQ!)RP@)TQ")RP@)TQ#)RP@)TQ))RP@
M)TQ+)RP@)TQ2)RP@)TQ3)RP*)TQ4)RP@)TQ5)RP@)TQ6)RP@)TQ9)RP@)TU!
M)RP@)TU#)RP@)TU$)RP@)TU')RP@)TU()RP@)TU+)RP@)TU,)RP@)TU-)RP@
M)TU.)RP*)TU/)RP@)TU0)RP@)TU1)RP@)TU2)RP@)TU3)RP@)TU4)RP@)TU5
M)RP@)TU6)RP@)TU7)RP@)TU8)RP@)TU9)RP@)TU:)RP@)TY!)RP*)TY#)RP@
M)TY%)RP@)TY&)RP@)TY')RP@)TY))RP@)TY,)RP@)TY/)RP@)TY0)RP@)TY2
M)RP@)TY5)RP@)TY:)RP@)T]-)RP@)U!!)RP*)U!%)RP@)U!&)RP@)U!')RP@
M)U!()RP@)U!+)RP@)U!,)RP@)U!-)RP@)U!.)RP@)U!2)RP@)U!3)RP@)U!4
M)RP@)U!7)RP@)U!9)RP*)U%!)RP@)U)%)RP@)U)/)RP@)U)5)RP@)U)7)RP@
M)U-!)RP@)U-")RP@)U-#)RP@)U-$)RP@)U-%)RP@)U-')RP@)U-()RP@)U-)
M)RP*)U-*)RP@)U-+)RP@)U-,)RP@)U--)RP@)U-.)RP@)U-/)RP@)U-2)RP@
M)U-4)RP@)U-6)RP@)U-9)RP@)U-:)RP@)U1#)RP@)U1$)RP*)U1&)RP@)U1'
M)RP@)U1()RP@)U1*)RP@)U1+)RP@)U1-)RP@)U1.)RP@)U1/)RP@)U10)RP@
M)U12)RP@)U14)RP@)U16)RP@)U17)RP*)U1:)RP@)U5!)RP@)U5')RP@)U5-
M)RP@)U53)RP@)U59)RP@)U5:)RP@)U9!)RP@)U9#)RP@)U9%)RP@)U9')RP@
M)U9))RP@)U9.)RP*)U95)RP@)U=&)RP@)U=3)RP@)UE%)RP@)UE4)RP@)UE5
M)RP@)UI!)RP@)UI-)RP@)UI2)RP@)UI7)RP@)T$Q)RP@)T$R)RP@)T\Q)PHI
M.PH*+RH@0V]U;G1R>2!.86UE<RX@*B\*)$=,3T)!3%-;)T=%3TE07T-/54Y4
M4EE?3D%-15,G72`](&%R<F%Y*`HB(BP@7R@B07-I82]086-I9FEC(%)E9VEO
M;B(I+"!?*")%=7)O<&4B*2P@7R@B06YD;W)R82(I+`I?*")5;FET960@07)A
M8B!%;6ER871E<R(I+"!?*")!9F=H86YI<W1A;B(I+"!?*")!;G1I9W5A(&%N
M9"!"87)B=61A(BDL"E\H(D%N9W5I;&QA(BDL(%\H(D%L8F%N:6$B*2P@7R@B
M07)M96YI82(I+"!?*").971H97)L86YD<R!!;G1I;&QE<R(I+`I?*")!;F=O
M;&$B*2P@7R@B06YT87)C=&EC82(I+"!?*")!<F=E;G1I;F$B*2P@7R@B06UE
M<FEC86X@4V%M;V$B*2P*7R@B075S=')I82(I+"!?*")!=7-T<F%L:6$B*2P@
M7R@B07)U8F$B*2P@7R@B07IE<F)A:6IA;B(I+`I?*")";W-N:6$@86YD($AE
M<GIE9V]V:6YA(BDL(%\H(D)A<F)A9&]S(BDL(%\H(D)A;F=L861E<V@B*2P@
M7R@B0F5L9VEU;2(I+`I?*")"=7)K:6YA($9A<V\B*2P@7R@B0G5L9V%R:6$B
M*2P@7R@B0F%H<F%I;B(I+"!?*")"=7)U;F1I(BDL(%\H(D)E;FEN(BDL"E\H
M(D)E<FUU9&$B*2P@7R@B0G)U;F5I($1A<G5S<V%L86TB*2P@7R@B0F]L:79I
M82(I+"!?*")"<F%Z:6PB*2P@7R@B0F%H86UA<R(I+`I?*")":'5T86XB*2P@
M7R@B0F]U=F5T($ES;&%N9"(I+"!?*")";W1S=V%N82(I+"!?*")"96QA<G5S
M(BDL(%\H(D)E;&EZ92(I+`I?*")#86YA9&$B*2P@7R@B0V]C;W,@*$ME96QI
M;F<I($ES;&%N9',B*2P*7R@B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B
M;&EC(&]F('1H92(I+"!?*")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B*2P*
M7R@B0V]N9V\B*2P@7R@B4W=I='IE<FQA;F0B*2P@7R@B0V]T92!D)TEV;VER
M92(I+"!?*")#;V]K($ES;&%N9',B*2P*7R@B0VAI;&4B*2P@7R@B0V%M97)O
M;VXB*2P@7R@B0VAI;F$B*2P@7R@B0V]L;VUB:6$B*2P@7R@B0V]S=&$@4FEC
M82(I+`I?*")#=6)A(BDL(%\H(D-A<&4@5F5R9&4B*2P@7R@B0VAR:7-T;6%S
M($ES;&%N9"(I+"!?*")#>7!R=7,B*2P*7R@B0WIE8V@@4F5P=6)L:6,B*2P@
M7R@B1V5R;6%N>2(I+"!?*")$:FEB;W5T:2(I+"!?*")$96YM87)K(BDL(%\H
M(D1O;6EN:6-A(BDL"E\H(D1O;6EN:6-A;B!297!U8FQI8R(I+"!?*")!;&=E
M<FEA(BDL(%\H(D5C=6%D;W(B*2P@7R@B17-T;VYI82(I+"!?*")%9WEP="(I
M+`I?*")797-T97)N(%-A:&%R82(I+"!?*")%<FET<F5A(BDL(%\H(E-P86EN
M(BDL(%\H(D5T:&EO<&EA(BDL(%\H(D9I;FQA;F0B*2P*7R@B1FEJ:2(I+"!?
M*")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB*2P@7R@B36EC<F]N97-I
M82P@1F5D97)A=&5D(%-T871E<R!O9B(I+`I?*")&87)O92!)<VQA;F1S(BDL
M(%\H(D9R86YC92(I+"!?*")&<F%N8V4L($UE=')O<&]L:71A;B(I+"!?*")'
M86)O;B(I+`I?*")5;FET960@2VEN9V1O;2(I+"!?*")'<F5N861A(BDL(%\H
M(D=E;W)G:6$B*2P@7R@B1G)E;F-H($=U:6%N82(I+`I?*")':&%N82(I+"!?
M*")':6)R86QT87(B*2P@7R@B1W)E96YL86YD(BDL(%\H(D=A;6)I82(I+"!?
M*")'=6EN96$B*2P*7R@B1W5A9&5L;W5P92(I+"!?*")%<75A=&]R:6%L($=U
M:6YE82(I+"!?*")'<F5E8V4B*2P*7R@B4V]U=&@@1V5O<F=I82!A;F0@=&AE
M(%-O=71H(%-A;F1W:6-H($ES;&%N9',B*2P@7R@B1W5A=&5M86QA(BDL(%\H
M(D=U86TB*2P*7R@B1W5I;F5A+4)I<W-A=2(I+"!?*")'=7EA;F$B*2P@7R@B
M2&]N9R!+;VYG(BDL"E\H(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L
M86YD<R(I+"!?*")(;VYD=7)A<R(I+"!?*")#<F]A=&EA(BDL"E\H(DAA:71I
M(BDL(%\H(DAU;F=A<GDB*2P@7R@B26YD;VYE<VEA(BDL(%\H(DER96QA;F0B
M*2P@7R@B27-R865L(BDL"E\H(DEN9&EA(BDL(%\H(D)R:71I<V@@26YD:6%N
M($]C96%N(%1E<G)I=&]R>2(I+"!?*"))<F%Q(BDL"E\H(DER86XL($ES;&%M
M:6,@4F5P=6)L:6,@;V8B*2P@7R@B26-E;&%N9"(I+"!?*"))=&%L>2(I+"!?
M*")*86UA:6-A(BDL"E\H(DIO<F1A;B(I+"!?*")*87!A;B(I+"!?*")+96YY
M82(I+"!?*")+>7)G>7IS=&%N(BDL(%\H(D-A;6)O9&EA(BDL"E\H(DMI<FEB
M871I(BDL(%\H(D-O;6]R;W,B*2P@7R@B4V%I;G0@2VET=',@86YD($YE=FES
M(BDL"E\H(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F
M(BDL(%\H(DMO<F5A+"!297!U8FQI8R!O9B(I+`I?*")+=7=A:70B*2P@7R@B
M0V%Y;6%N($ES;&%N9',B*2P@7R@B2V%Z86MH<W1A;B(I+`I?*"),86\@4&5O
M<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(I+"!?*"),96)A;F]N(BDL(%\H
M(E-A:6YT($QU8VEA(BDL"E\H(DQI96-H=&5N<W1E:6XB*2P@7R@B4W)I($QA
M;FMA(BDL(%\H(DQI8F5R:6$B*2P@7R@B3&5S;W1H;R(I+`I?*"),:71H=6%N
M:6$B*2P@7R@B3'5X96UB;W5R9R(I+"!?*"),871V:6$B*2P@7R@B3&EB>6%N
M($%R86(@2F%M86AI<FEY82(I+`I?*")-;W)O8V-O(BDL(%\H(DUO;F%C;R(I
M+"!?*")-;VQD;W9A+"!297!U8FQI8R!O9B(I+"!?*")-861A9V%S8V%R(BDL
M"E\H(DUA<G-H86QL($ES;&%N9',B*2P@7R@B36%C961O;FEA+"!4:&4@1F]R
M;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(BDL"E\H(DUA;&DB*2P@7R@B37EA
M;FUA<B(I+"!?*")-;VYG;VQI82(I+"!?*")-86-A;R(I+`I?*").;W)T:&5R
M;B!-87)I86YA($ES;&%N9',B*2P@7R@B36%R=&EN:7%U92(I+"!?*")-875R
M:71A;FEA(BDL"E\H(DUO;G1S97)R870B*2P@7R@B36%L=&$B*2P@7R@B36%U
M<FET:75S(BDL(%\H(DUA;&1I=F5S(BDL(%\H(DUA;&%W:2(I+`I?*")-97AI
M8V\B*2P@7R@B36%L87ES:6$B*2P@7R@B36]Z86UB:7%U92(I+"!?*").86UI
M8FEA(BDL(%\H(DYE=R!#86QE9&]N:6$B*2P*7R@B3FEG97(B*2P@7R@B3F]R
M9F]L:R!)<VQA;F0B*2P@7R@B3FEG97)I82(I+"!?*").:6-A<F%G=6$B*2P*
M7R@B3F5T:&5R;&%N9',B*2P@7R@B3F]R=V%Y(BDL(%\H(DYE<&%L(BDL(%\H
M(DYA=7)U(BDL(%\H(DYI=64B*2P*7R@B3F5W(%IE86QA;F0B*2P@7R@B3VUA
M;B(I+"!?*")086YA;6$B*2P@7R@B4&5R=2(I+"!?*")&<F5N8V@@4&]L>6YE
M<VEA(BDL"E\H(E!A<'5A($YE=R!'=6EN96$B*2P@7R@B4&AI;&EP<&EN97,B
M*2P@7R@B4&%K:7-T86XB*2P@7R@B4&]L86YD(BDL"E\H(E-A:6YT(%!I97)R
M92!A;F0@36EQ=65L;VXB*2P@7R@B4&ET8V%I<FXB*2P@7R@B4'5E<G1O(%)I
M8V\B*2P*7R@B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(I+"!?
M*")0;W)T=6=A;"(I+"!?*")086QA=2(I+`I?*")087)A9W5A>2(I+"!?*")1
M871A<B(I+"!?*")2975N:6]N(BDL(%\H(E)O;6%N:6$B*2P*7R@B4G5S<VEA
M;B!&961E<F%T:6]N(BDL(%\H(E)W86YD82(I+"!?*")3875D:2!!<F%B:6$B
M*2P@7R@B4V]L;VUO;B!)<VQA;F1S(BDL"E\H(E-E>6-H96QL97,B*2P@7R@B
M4W5D86XB*2P@7R@B4W=E9&5N(BDL(%\H(E-I;F=A<&]R92(I+"!?*")386EN
M="!(96QE;F$B*2P*7R@B4VQO=F5N:6$B*2P@7R@B4W9A;&)A<F0@86YD($IA
M;B!-87EE;B(I+"!?*")3;&]V86MI82(I+"!?*")3:65R<F$@3&5O;F4B*2P*
M7R@B4V%N($UA<FEN;R(I+"!?*")396YE9V%L(BDL(%\H(E-O;6%L:6$B*2P@
M7R@B4W5R:6YA;64B*2P*7R@B4V%O(%1O;64@86YD(%!R:6YC:7!E(BDL(%\H
M(D5L(%-A;'9A9&]R(BDL(%\H(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(BDL"E\H
M(E-W87II;&%N9"(I+"!?*")4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B*2P@
M7R@B0VAA9"(I+`I?*")&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B*2P@
M7R@B5&]G;R(I+"!?*")4:&%I;&%N9"(I+"!?*")486II:VES=&%N(BDL"E\H
M(E1O:V5L874B*2P@7R@B5'5R:VUE;FES=&%N(BDL(%\H(E1U;FES:6$B*2P@
M7R@B5&]N9V$B*2P@7R@B5&EM;W(M3&5S=&4B*2P*7R@B5'5R:V5Y(BDL(%\H
M(E1R:6YI9&%D(&%N9"!4;V)A9V\B*2P@7R@B5'5V86QU(BDL(%\H(E1A:7=A
M;B(I+`I?*")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(BDL(%\H(E5K
M<F%I;F4B*2P@7R@B56=A;F1A(BDL"E\H(E5N:71E9"!3=&%T97,@36EN;W(@
M3W5T;'EI;F<@27-L86YD<R(I+"!?*")5;FET960@4W1A=&5S(BDL(%\H(E5R
M=6=U87DB*2P*7R@B57IB96MI<W1A;B(I+"!?*")(;VQY(%-E92`H5F%T:6-A
M;B!#:71Y(%-T871E*2(I+`I?*")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E
M;F%D:6YE<R(I+"!?*")696YE>G5E;&$B*2P*7R@B5FER9VEN($ES;&%N9',L
M($)R:71I<V@B*2P@7R@B5FER9VEN($ES;&%N9',L(%4N4RXB*2P@7R@B5FEE
M="!.86TB*2P*7R@B5F%N=6%T=2(I+"!?*")786QL:7,@86YD($9U='5N82(I
M+"!?*")386UO82(I+"!?*")996UE;B(I+"!?*")-87EO='1E(BDL"E\H(EEU
M9V]S;&%V:6$B*2P@7R@B4V]U=&@@069R:6-A(BDL(%\H(EIA;6)I82(I+"!?
M*"):86ER92(I+"!?*")::6UB86)W92(I+`I?*")!;F]N>6UO=7,@4')O>'DB
M*2P@7R@B4V%T96QL:71E(%!R;W9I9&5R(BDL(%\H(D]T:&5R(BD**3L*"F1E
M9FEN92@G1T5/25!?0T]53E1265]"14=)3B<L(#$V-S<V.38P*3L*9&5F:6YE
M*"=35%)50U154D5?24Y&3U]-05A?4TE:12<L(#(P*3L*9&5F:6YE*"=35$%.
M1$%21%]214-/4D1?3$5.1U1()RP@,RD["@IC;&%S<R!.3%-?1V5O25`@>PH*
M("`@("\J*@H@("`@("H@5&AE(&QO8V%T:6]N(&]F('1H92!'96])4"!D871A
M8F%S92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)%]D871A9FEL93L*"B`@("`O*BH*("`@("`J(%1H92!O<&5N(&9I;&5H
M86YD;&4@=&\@=&AE($=E;TE0(&1A=&%B87-E+@H@("`@("H*("`@("`J($!V
M87(@<F5S;W5R8V4*("`@("`J+PH@("`@=F%R("1?9FEL96AA;F1L93L*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@82!R969E<F5N8V4@=&\@=&AE(&=L;V)A
M;"!.3%-?1V5O25`@;V)J96-T+"!O;FQY(&-R96%T:6YG(&ET"B`@("`@*B!I
M9B!I="!D;V5S;B=T(&%L<F5A9'D@97AI<W0N"B`@("`@*@H@("`@("H@5&AI
M<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.@H@("`@("H@("`D9V5O:7`@
M/2`F1V5O25`Z.G-I;F=L971O;B@D9&%T869I;&4I.PH@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&1A=&%F:6QE("!4:&4@;&]C871I;VX@;V8@=&AE
M($=E;TE0(&1A=&%B87-E+@H@("`@("H*("`@("`J($!R971U<FX@;V)J96-T
M($Y,4U]'96])4"`@5&AE($Y,4U]'96])4"!I;G-T86YC92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@)G-I;F=L971O;B@D9&%T869I;&4I"B`@("!["B`@("`@
M("`@<W1A=&EC("1I;G-T86YC93L*"B`@("`@("`@:68@*"%I<W-E="@D:6YS
M=&%N8V4I*2!["B`@("`@("`@("`@("1I;G-T86YC92`](&YE=R!.3%-?1V5O
M25`H)&1A=&%F:6QE*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6YS
M=&%N8V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@82!.3%-?1V5O
M25`@:6YS=&%N8V4@*$-O;G-T<G5C=&]R*2X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1D871A9FEL92`@5&AE(&QO8V%T:6]N(&]F('1H92!'96])
M4"!D871A8F%S92X*("`@("`J+PH@("`@9G5N8W1I;VX@3DQ37T=E;TE0*"1D
M871A9FEL92D*("`@('L*("`@("`@("`D=&AI<RT^7V1A=&%F:6QE(#T@)&1A
M=&%F:6QE.PH@("`@?0H*("`@("\J*@H@("`@("H@3W!E;B!T:&4@1V5O25`@
M9&%T86)A<V4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!&86QS92!O;B!E<G)O<BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V]P96XH*0H@("`@>PH@("`@("`@("\J(%)E
M='5R;B!I9B!W92!A;')E861Y(&AA=F4@86X@;V)J96-T+B`J+PH@("`@("`@
M(&EF("@A96UP='DH)'1H:7,M/E]F:6QE:&%N9&QE*2D@>PH@("`@("`@("`@
M("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("\J(%)E='5R;B!I
M9B!N;R!D871A9FEL92!S<&5C:69I960N("HO"B`@("`@("`@:68@*&5M<'1Y
M*"1T:&ES+3Y?9&%T869I;&4I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?9FEL96AA;F1L92`](&9O
M<&5N*"1T:&ES+3Y?9&%T869I;&4L("=R8B<I.PH*("`@("`@("`D9FEL97!O
M<R`](&9T96QL*"1T:&ES+3Y?9FEL96AA;F1L92D["B`@("`@("`@9G-E96LH
M)'1H:7,M/E]F:6QE:&%N9&QE+"`M,RP@4T5%2U]%3D0I.PH@("`@("`@(&9O
M<B`H)&D@/2`P.R`D:2`\(%-44E5#5%5215])3D9/7TU!6%]325I%.R`D:2LK
M*2!["B`@("`@("`@("`@("1D96QI;2`](&9R96%D*"1T:&ES+3Y?9FEL96AA
M;F1L92P@,RD["B`@("`@("`@("`@(&EF("@D9&5L:6T@/3T@*&-H<B@R-34I
M("X@8VAR*#(U-2D@+B!C:'(H,C4U*2DI('L*("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@9G-E
M96LH)'1H:7,M/E]F:6QE:&%N9&QE+"`M-"P@4T5%2U]#55(I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(&9S965K*"1T:&ES+3Y?9FEL96AA
M;F1L92P@)&9I;&5P;W,L(%-%14M?4T54*3L*"B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C;W5N=')Y
M($E$(&9O<B!A(&AO<W1N86UE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&YA;64@(%1H92!H;W-T;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&EN=&5G97(@(%1H92!'96])4"!C;W5N=')Y($E$+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!C;W5N=')Y261">4YA;64H)&YA;64I"B`@("!["B`@("`@("`@
M:68@*"$D=&AI<RT^7V]P96XH*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H@("`@("`@("1A9&1R(#T@9V5T:&]S=&)Y;F%M92@D
M;F%M92D["B`@("`@("`@:68@*"$D861D<B!\?"`H)&%D9'(@/3T@)&YA;64I
M*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1T:&ES+3YC;W5N=')Y261">4%D9'(H)&%D9'(I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8V]U;G1R>2!A8F)R979I
M871I;VX@*#(M;&5T=&5R*2!F;W(@82!H;W-T;F%M92X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@:&]S=&YA;64N"B`@("`@*@H@
M("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@8V]U;G1R>2!A8F)R979I871I
M;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O=6YT<GE#;V1E0GE.86UE*"1N
M86UE*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V]P96XH*2D@>PH@("`@
M("`@("`@("`D8V]U;G1R>5]I9"`]("1T:&ES+3YC;W5N=')Y261">4YA;64H
M)&YA;64I.PH@("`@("`@("`@("!I9B`H)&-O=6YT<GE?:60@(3T](&9A;'-E
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)$=,3T)!3%-;)T=%3TE07T-/
M54Y44EE?0T]$15,G75LD8V]U;G1R>5]I9%T["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@8V]U;G1R>2!N86UE(&9O<B!A(&AO<W1N86UE
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!H;W-T
M;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!C;W5N
M=')Y(&YA;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O=6YT<GE.86UE0GE.
M86UE*"1N86UE*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V]P96XH*2D@
M>PH@("`@("`@("`@("`D8V]U;G1R>5]I9"`]("1T:&ES+3YC;W5N=')Y261"
M>4YA;64H)&YA;64I.PH@("`@("`@("`@("!I9B`H)&-O=6YT<GE?:60@(3T]
M(&9A;'-E*2!["B`@("`@("`@("`@("`@("!R971U<FX@)$=,3T)!3%-;)T=%
M3TE07T-/54Y44EE?3D%-15,G75LD8V]U;G1R>5]I9%T["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8V]U;G1R>2!)1"!F;W(@86X@25`@
M061D<F5S<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A9&1R("!4
M:&4@25`@061D<F5S<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@
M(%1H92!'96])4"!C;W5N=')Y($E$+@H@("`@("HO"B`@("!F=6YC=&EO;B!C
M;W5N=')Y261">4%D9'(H)&%D9'(I"B`@("!["B`@("`@("`@:68@*"$D=&AI
M<RT^7V]P96XH*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H@("`@("`@("1I<&YU;2`](&EP,FQO;F<H)&%D9'(I.PH@("`@("`@
M(')E='5R;B`H)'1H:7,M/E]S965K0V]U;G1R>2@D:7!N=6TI("T@1T5/25!?
M0T]53E1265]"14=)3BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!C;W5N=')Y(&%B8G)E=FEA=&EO;B`H,BUL971T97(I(&9O<B!A;B!)
M4"!!9&1R97-S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%D9'(@
M(%1H92!)4"!!9&1R97-S+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E
M<B`@5&AE(&-O=6YT<GD@86)B<F5V:6%T:6]N+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!C;W5N=')Y0V]D94)Y061D<B@D861D<BD*("`@('L*("`@("`@("!I
M9B`H)'1H:7,M/E]O<&5N*"DI('L*("`@("`@("`@("`@)&-O=6YT<GE?:60@
M/2`D=&AI<RT^8V]U;G1R>4ED0GE!9&1R*"1A9&1R*3L*("`@("`@("`@("`@
M:68@*"1C;W5N=')Y7VED("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1'3$]"04Q36R='14])4%]#3U5.5%)97T-/1$53)UU;)&-O=6YT
M<GE?:61=.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R
M;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-O
M=6YT<GD@;F%M92!F;W(@86X@25`@861D<F5S<RX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1A9&1R("!4:&4@25`@861D<F5S<RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@8V]U;G1R>2!N86UE+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!C;W5N=')Y3F%M94)Y061D<B@D861D<BD*("`@('L*
M("`@("`@("!I9B`H)'1H:7,M/E]O<&5N*"DI('L*("`@("`@("`@("`@)&-O
M=6YT<GE?:60@/2`D=&AI<RT^8V]U;G1R>4ED0GE!9&1R*"1A9&1R*3L*("`@
M("`@("`@("`@:68@*"1C;W5N=')Y7VED("$]/2!F86QS92D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1'3$]"04Q36R='14])4%]#3U5.5%)97TY!3453
M)UU;)&-O=6YT<GE?:61=.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J($9I;F1S
M(&$@8V]U;G1R>2!B>2!)4"!!9&1R97-S(&EN('1H92!'96])4"!D871A8F%S
M92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1I<&YU;2`@5&AE($E0($%D9')E<W,@=&\@<V5A
M<F-H(&9O<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@8V]U
M;G1R>2!)1"!O<B!F86QS92!I9B!N;W0@9F]U;F0N"B`@("`@*B`@("`@("`@
M("`@("`@("!2971U<FYS(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]S965K0V]U;G1R>2@D:7!N=6TI"B`@("!["B`@("`@
M("`@)&]F9G-E="`](#`["B`@("`@("`@9F]R("@D9&5P=&@@/2`S,3L@)&1E
M<'1H(#X](#`[("TM)&1E<'1H*2!["B`@("`@("`@("`@(&EF("AF<V5E:R@D
M=&AI<RT^7V9I;&5H86YD;&4L(#(@*B!35$%.1$%21%]214-/4D1?3$5.1U1(
M("H@)&]F9G-E="P@4T5%2U]3150I("$](#`I('L*("`@("`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*"=F<V5E:R!F86EL960G*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D8G5F(#T@9G)E860H)'1H:7,M/E]F
M:6QE:&%N9&QE+"`R("H@4U1!3D1!4D1?4D5#3U)$7TQ%3D=42"D["B`@("`@
M("`@("`@("1X(#T@87)R87DH,"P@,"D["B`@("`@("`@("`@(&9O<B`H)&D@
M/2`P.R`D:2`\(#([("LK)&DI('L*("`@("`@("`@("`@("`@(&9O<B`H)&H@
M/2`P.R`D:B`\(%-404Y$05)$7U)%0T]21%],14Y'5$@[("LK)&HI('L*("`@
M("`@("`@("`@("`@("`@("`D>%LD:5T@*ST@;W)D*"1B=69;4U1!3D1!4D1?
M4D5#3U)$7TQ%3D=42"`J("1I("L@)&I=*2`\/"`H)&H@*B`X*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&EP
M;G5M("8@*#$@/#P@)&1E<'1H*2D@>PH@("`@("`@("`@("`@("`@:68@*"1X
M6S%=(#X]($=%3TE07T-/54Y44EE?0D5'24XI('L*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)'A;,5T["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`D;V9F<V5T(#T@)'A;,5T["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("!I9B`H)'A;,%T@/CT@1T5/25!?0T]53E1265]"
M14=)3BD@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D>%LP73L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1O9F9S970@/2`D>%LP
M73L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@?0H*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T1A=&%4<F5E````````````````
M````````````````````````````````````````````````````````````
M`#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S
M-S,W(#`R,#<V-``@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O1&%T
M851R964O<W%L+G!H<```````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`Q-S0R-C4@,3`U,34T,S,W,S<@,#(R,S<R`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@1&%T
M851R965?<W%L.CH@8VQA<W,@<')O=FED97,@86X@4U%,(&EM<&QE;65N=&%T
M:6]N(&]F('1H92!(;W)D90H@*B!$871A5')E92!S>7-T96TN"B`J"B`J(%)E
M<75I<F5D('!A<F%M971E<G,Z/'!R93X*("H@("`G<&AP='EP92<@("!4:&4@
M9&%T86)A<V4@='EP92`H:64N("=P9W-Q;"<L("=M>7-Q;"<L(&5T8RXI+@H@
M*B`@("=C:&%R<V5T)R`@(%1H92!C:&%R<V5T('5S960@8GD@=&AE(&1A=&%B
M87-E+CPO<')E/@H@*@H@*B!/<'1I;VYA;"!P87)A;65T97)S.CQP<F4^"B`J
M("`@)W1A8FQE)R`@("`@5&AE(&YA;64@;V8@=&AE(&1A=&$@=&%B;&4@:6X@
M)V1A=&%B87-E)RX*("H@("`@("`@("`@("`@("!$149!54Q4.B`G:&]R9&5?
M9&%T871R964G/"]P<F4^"B`J"B`J(%)E<75I<F5D(&)Y('-O;64@9&%T86)A
M<V4@:6UP;&5M96YT871I;VYS.CQP<F4^"B`J("`@)V1A=&%B87-E)R`@5&AE
M(&YA;64@;V8@=&AE(&1A=&%B87-E+@H@*B`@("=U<V5R;F%M92<@(%1H92!U
M<V5R;F%M92!W:71H('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E
M+@H@*B`@("=P87-S=V]R9"<@(%1H92!P87-S=V]R9"!A<W-O8VEA=&5D('=I
M=&@@)W5S97)N86UE)RX*("H@("`G:&]S='-P96,G("!4:&4@:&]S=&YA;64@
M;V8@=&AE(&1A=&%B87-E('-E<G9E<BX*("H@("`G<')O=&]C;VPG("!4:&4@
M8V]M;75N:6-A=&EO;B!P<F]T;V-O;"`H)W1C<"<L("=U;FEX)RP@971C+BDN
M"B`J("`@)V]P=&EO;G,G("`@061D:71I;VYA;"!O<'1I;VYS('1O('!A<W,@
M=&\@=&AE(&1A=&%B87-E+@H@*B`@("=P;W)T)R`@("`@(%1H92!P;W)T(&]N
M('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+@H@*B`@("=T='DG
M("`@("`@(%1H92!45%D@;VX@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T
M86)A<V4N/"]P<F4^"B`J"B`J(%1H92!T86)L92!S=')U8W1U<F4@9F]R('1H
M92!$871A5')E92!S>7-T96T@:7,@:6X*("H@<V-R:7!T<R]S<6PO:&]R9&5?
M9&%T871R964N<W%L+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]$871A5')E
M92]$871A5')E92]S<6PN<&AP+'8@,2XQ-38N,BXS,"`R,#`V+S`W+S$S(#`Y
M.C`T.C(P(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V(%-T
M97!H86YE($AU=&AE<B`\<VAU=&AE<D!B:6=F;V]T+F-O;3X*("H@0V]P>7)I
M9VAT(#(P,#$M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H@0V]P>7)I9VAT(#(P,#4M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`
M:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF"B`J('EO=2!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964*("H@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU
M8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!A=71H;W(@($IA
M;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!A=71H;W(@(%-T97!H
M86YE($AU=&AE<B`\<VAU=&AE<D!B:6=F;V]T+F-O;3X*("H@0'-I;F-E("`@
M2&]R9&4@,BXQ"B`J($!P86-K86=E($AO<F1E7T1A=&%4<F5E"B`J+PIC;&%S
M<R!$871A5')E95]S<6P@97AT96YD<R!$871A5')E92!["@H@("`@+RHJ"B`@
M("`@*B!(86YD;&4@9F]R('1H92!C=7)R96YT(&1A=&%B87-E(&-O;FYE8W1I
M;VXN"B`@("`@*@H@("`@("H@0'9A<B!$0@H@("`@("HO"B`@("!V87(@)%]D
M8CL*"B`@("`O*BH*("`@("`J(%1H92!N=6UB97(@;V8@8V]P:65S(&]F('1H
M92!H;W)D95]D871A=')E95]A='1R:6)U=&5S('1A8FQE"B`@("`@*B!T:&%T
M('=E(&YE960@=&\@:F]I;B!O;B!I;B!T:&4@8W5R<F5N="!Q=65R>2X*("`@
M("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?=&%B
M;&5#;W5N="`](#$["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W
M(%-13"!$871A5')E92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R
M86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@1&%T851R965?<W%L*"1P
M87)A;7,I"B`@("!["B`@("`@("`@<&%R96YT.CI$871A5')E92@D<&%R86US
M*3L*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@82!L:7-T(&]F(&%L;"!G<F]U<',@*')O;W0@;F]D
M97,I(&]F('1H92!D871A('1R964N"B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>2`@5&AE('1H92!G<F]U<"!)1',*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T1W)O=7!S*"D*("`@('L*("`@("`@("`D<75E<GD@/2`G4T5,14-4($1)
M4U1)3D-4(&=R;W5P7W5I9"!&4D]-("<@+B`@)'1H:7,M/E]P87)A;7-;)W1A
M8FQE)UT["@H@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@
M8GD@1&%T851R965?<W%L.CIG971'<F]U<',H*3H@)R`N("1Q=65R>2P@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@(')E
M='5R;B`D=&AI<RT^7V1B+3YG971#;VPH)'%U97)Y*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($QO861S("AA('-U8G-E="!O9BD@=&AE(&1A=&%T<F5E(&EN
M=&\@=&AE("1?9&%T82!A<G)A>2X*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<F]O="`@("`@
M("`@(%=H:6-H('!O<G1I;VX@;V8@=&AE('1R964@=&\@;&]A9"X*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1&5F875L=',@=&\@86QL
M(&]F(&ET+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&QO8614<F5E("`@("!,
M;V%D(&$@=')E92!S=&%R=&EN9R!A="`D<F]O="P@;W(@:G5S="!T:&4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5Q=65S=&5D(&QE
M=F5L(&%N9"!D:7)E8W0@<&%R96YT<S\*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@1&5F875L=',@=&\@<VEN9VQE(&QE=F5L+@H@("`@
M("H@0'!A<F%M(&)O;VQE86X@)')E;&]A9"`@("`@("!292UL;V%D(&%L<F5A
M9'D@;&]A9&5D('9A;'5E<S\*("`@("`J($!P87)A;2!S=')I;F<@("1S;W)T
M8GE?;F%M92`@071T<FEB=71E(&YA;64@=&\@=7-E(&9O<B!S;W)T:6YG+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`@)'-O<G1B>5]K97D@("!!='1R:6)U=&4@
M:V5Y('1O('5S92!F;W(@<V]R=&EN9RX*("`@("`J($!P87)A;2!I;G1E9V5R
M("1D:7)E8W1I;VX@("`@4V]R="!D:7)E8W1I;VXZ"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#`@+2!A<V-E;F1I;F<*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@,2`M(&1E<V-E;F1I;F<*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@
M82!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]L;V%D*"1R;V]T(#T@1$%40512145?4D]/5"P@)&QO8614<F5E(#T@9F%L
M<V4L("1R96QO860@/2!F86QS92P*("`@("`@("`@("`@("`@("`@("1S;W)T
M8GE?;F%M92`](&YU;&PL("1S;W)T8GE?:V5Y(#T@;G5L;"P@)&1I<F5C=&EO
M;B`](#`I"B`@("!["B`@("`@("`@+RH@1&\@3D]4('5S92!$871A5')E93HZ
M97AI<W1S*"D@:&5R93L@=&AA="!W;W5L9"!C875S92!A;B!I;F9I;FET90H@
M("`@("`@("`J(&QO;W`N("HO"B`@("`@("`@:68@*"$D<F5L;V%D("8F"B`@
M("`@("`@("`@("AI;E]A<G)A>2@D<F]O="P@)'1H:7,M/E]N86UE36%P*2!\
M?`H@("`@("`@("`@("`@*&-O=6YT*"1T:&ES+3Y?9&%T82D@)B8@)')O;W0@
M/3T@1$%40512145?4D]/5"DI('Q\"B`@("`@("`@("`@("@A:7-?;G5L;"@D
M=&AI<RT^7W-O<G1(87-H*2`F)@H@("`@("`@("`@("`@:7-S970H)'1H:7,M
M/E]D871A6R1R;V]T75LG<V]R=&5R)UU;)'1H:7,M/E]S;W)T2&%S:%TI*2D@
M>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@
M("1Q=65R>2`]("1T:&ES+3Y?8G5I;&1,;V%D475E<GDH)')O;W0L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;&]A9%1R964L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!$051!
M5%)%15]"54E,1%]314Q%0U0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<V]R=&)Y7VYA;64L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<V]R=&)Y7VME>2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D:7)E8W1I;VXI.PH@
M("`@("`@(&EF("AI<U]A*"1Q=65R>2P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'%U97)Y.PH@("`@("`@('T*("`@("`@("!I9B`H
M96UP='DH)'%U97)Y*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@
M("`@("!]"@H@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@
M8GD@1&%T851R965?<W%L.CI?;&]A9"@I.B`G("X@)'%U97)Y+"!?7T9)3$5?
M7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`D9&%T82`]
M("1T:&ES+3Y?9&(M/F=E=$%L;"@D<75E<GDI.PH@("`@("`@(&EF("AI<U]A
M*"1D871A+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M9&%T83L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3YS970H)&1A
M=&$L("1T:&ES+3Y?<&%R86US6R=C:&%R<V5T)UTI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0V]U;G1S("AA('-U8G-E="!O9BD@=&AE(&1A=&%T<F5E('=H
M:6-H('=O=6QD(&)E(&QO861E9"!I;G1O('1H92`D7V1A=&$*("`@("`J(&%R
M<F%Y(&EF(%]L;V%D*"D@:7,@8V%L;&5D('=I=&@@=&AE('-A;64@=F%L=64@
M;V8@)')O;W0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<F]O="`@5VAI8V@@<&]R=&EO;B!O
M9B!T:&4@=')E92!T;R!L;V%D+B!$969A=6QT<R!T;R!A;&P*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@(&]F(&ET+@H@("`@("H*("`@("`J($!R971U
M<FX@:6YT96=E<B`@3G5M8F5R(&]F(&]B:F5C=',*("`@("`J+PH@("`@9G5N
M8W1I;VX@7V-O=6YT*"1R;V]T(#T@1$%40512145?4D]/5"D*("`@('L*("`@
M("`@("`D<75E<GD@/2`D=&AI<RT^7V)U:6QD3&]A9%%U97)Y*"1R;V]T+"!T
M<G5E+"!$051!5%)%15]"54E,1%]#3U5.5"D["B`@("`@("`@:68@*&ES7V$H
M)'%U97)Y+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<75E<GD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D<75E<GDI*2![
M"B`@("`@("`@("`@(')E='5R;B`P.PH@("`@("`@('T*("`@("`@("!(;W)D
M93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($1A=&%4<F5E7W-Q;#HZ7V-O
M=6YT*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],
M3T=?1$5"54<I.PH@("`@("`@(')E='5R;B`H:6YT*21T:&ES+3Y?9&(M/F=E
M=$]N92@D<75E<GDI.PH@("`@?0H*("`@("\J*@H@("`@("H@3&]A9',@*&$@
M<W5B<V5T(&]F*2!T:&4@9&%T871R964@:6YT;R!T:&4@)%]D871A(&%R<F%Y
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@("1R;V]T("`@("`@("`@5VAI8V@@<&]R=&EO;B!O
M9B!T:&4@=')E92!T;R!L;V%D+@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!$969A=6QT<R!T;R!A;&P@;V8@:70N"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D;&]A9%1R964@("`@($QO860@82!T<F5E('-T87)T:6YG
M(&%T("1R;V]T+"!O<B!J=7-T('1H90H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!R97%U97-T960@;&5V96P@86YD(&1I<F5C="!P87)E
M;G1S/PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!$969A
M=6QT<R!T;R!S:6YG;&4@;&5V96PN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M;W!E<F%T:6]N("`@(%1Y<&4@;V8@<75E<GD@=&\@8G5I;&0*("`@("`J($!P
M87)A;2!S=')I;F<@("1S;W)T8GE?;F%M92`@071T<FEB=71E(&YA;64@=&\@
M=7-E(&9O<B!S;W)T:6YG+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'-O<G1B
M>5]K97D@("!!='1R:6)U=&4@:V5Y('1O('5S92!F;W(@<V]R=&EN9RX*("`@
M("`J($!P87)A;2!I;G1E9V5R("1D:7)E8W1I;VX@("`@4V]R="!D:7)E8W1I
M;VXZ"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#`@+2!A
M<V-E;F1I;F<*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M,2`M(&1E<V-E;F1I;F<*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4
M<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]B=6EL9$QO8611=65R>2@D<F]O="`]($1!
M5$%44D5%7U)/3U0L("1L;V%D5')E92`](&9A;'-E+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1O<&5R871I;VX@/2!$051!5%)%15]"54E,1%]3
M14Q%0U0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-O<G1B>5]N
M86UE(#T@;G5L;"P@)'-O<G1B>5]K97D@/2!N=6QL+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1D:7)E8W1I;VX@/2`P*0H@("`@>PH@("`@("`@
M("1S;W)T960@/2!F86QS93L*("`@("`@("`D=VAE<F4@/2!S<')I;G1F*"=C
M+F=R;W5P7W5I9"`]("5S("<L("1T:&ES+3Y?9&(M/G%U;W1E*"1T:&ES+3Y?
M<&%R86US6R=G<F]U<"==*2D["@H@("`@("`@(&EF("@A96UP='DH)')O;W0I
M("8F("1R;V]T("$]($1!5$%44D5%7U)/3U0I('L*("`@("`@("`@("`@)'!A
M<F5N=%]W:&5R92`]("1T:&ES+3Y?8G5I;&1087)E;G1)9',H)')O;W0L("1L
M;V%D5')E92P@)V,N)RD["B`@("`@("`@("`@(&EF("@A96UP='DH)'!A<F5N
M=%]W:&5R92D@)B8@(6ES7V$H)'!A<F5N=%]W:&5R92P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@)'=H97)E(#T@<W!R:6YT9B@G)7,@04Y$
M("@E<RDG+"`D=VAE<F4L("1P87)E;G1?=VAE<F4I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@("`@(&EF("@A:7-?;G5L;"@D<V]R=&)Y7VYA;64I
M*2!["B`@("`@("`@("`@("1W:&5R92`]('-P<FEN=&8H)R5S($%.1"!A+F%T
M=')I8G5T95]N86UE(#T@)7,@)RP@)'=H97)E+"`D=&AI<RT^7V1B+3YQ=6]T
M92@D<V]R=&)Y7VYA;64I*3L*("`@("`@("`@("`@)'-O<G1E9"`]('1R=64[
M"B`@("`@("`@?0H@("`@("`@(&EF("@A:7-?;G5L;"@D<V]R=&)Y7VME>2DI
M('L*("`@("`@("`@("`@)'=H97)E(#T@<W!R:6YT9B@G)7,@04Y$(&$N871T
M<FEB=71E7VME>2`]("5S("<L("1W:&5R92P@)'1H:7,M/E]D8BT^<75O=&4H
M)'-O<G1B>5]K97DI*3L*("`@("`@("`@("`@)'-O<G1E9"`]('1R=64["B`@
M("`@("`@?0H*("`@("`@("!S=VET8V@@*"1O<&5R871I;VXI('L*("`@("`@
M("!C87-E($1!5$%44D5%7T)524Q$7T-/54Y4.@H@("`@("`@("`@("`D=VAA
M="`]("=#3U5.5"@J*2<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!D
M969A=6QT.@H@("`@("`@("`@("`D=VAA="`]("=C+F1A=&%T<F5E7VED+"!C
M+F1A=&%T<F5E7VYA;64L(&,N9&%T871R965?<&%R96YT<RP@8RYD871A=')E
M95]O<F1E<B<["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"1S;W)T960I('L*("`@("`@("`@("`@)'%U97)Y(#T@<W!R:6YT
M9B@G4T5,14-4("5S($923TT@)7,@8R!,1494($I/24X@)7,@82!/3B`H8RYD
M871A=')E95]I9"`](&$N9&%T871R965?:60@3U(@8RYD871A=')E95]N86UE
M/25S*2`G+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=72$5212`E
M<R!'4D]54"!"62!C+F1A=&%T<F5E7VED+"!C+F1A=&%T<F5E7VYA;64L(&,N
M9&%T871R965?<&%R96YT<RP@8RYD871A=')E95]O<F1E<B!/4D1%4B!"62!A
M+F%T=')I8G5T95]V86QU92`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'=H870L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE7V%T=')I8G5T97,G72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1B+3YQ=6]T92@D
M<F]O="DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=H97)E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("@D9&ER96-T:6]N(#T](#$I
M(#\@)T1%4T,G(#H@)T%30R<I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1Q=65R>2`]('-P<FEN=&8H)U-%3$5#5"`E<R!&4D]-("5S(&,@5TA%
M4D4@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W:&%T+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T
M86)L92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W:&5R92D[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'%U97)Y.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0G5I;&1S('!A<F5N="!)1"!S=')I;F<@9F]R('-E;&5C
M=&EN9R!T<F5E<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<F]O="`@("`@(%=H:6-H('!O
M<G1I;VX@;V8@=&AE('1R964@=&\@;&]A9"X*("`@("`J($!P87)A;2!B;V]L
M96%N("1L;V%D5')E92`@3&]A9"!A('1R964@<W1A<G1I;F<@870@)')O;W0L
M(&]R(&IU<W0@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M(')E<75E<W1E9"!L979E;"!A;F0@9&ER96-T('!A<F5N=',_"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@($1E9F%U;'1S('1O('-I;F=L92!L
M979E;"X*("`@("`J($!P87)A;2!S=')I;F<@("1J;VEN7VYA;64@5&%B;&4@
M:F]I;B!N86UE"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($ED(&QI
M<W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]B=6EL9%!A<F5N=$ED<R@D<F]O
M="P@)&QO8614<F5E(#T@9F%L<V4L("1J;VEN7VYA;64@/2`G)RD*("`@('L*
M("`@("`@("!I9B`H<W1R<&]S*"1R;V]T+"`G.B<I("$]/2!F86QS92D@>PH@
M("`@("`@("`@("`D<&%R=',@/2!E>'!L;V1E*"<Z)RP@)')O;W0I.PH@("`@
M("`@("`@("`D<F]O="`](&%R<F%Y7W!O<"@D<&%R=',I.PH@("`@("`@('T*
M("`@("`@("`D<F]O="`]("AS=')I;F<I)')O;W0["@H@("`@("`@("1Q=65R
M>2`]("=314Q%0U0@9&%T871R965?:60L(&1A=&%T<F5E7W!A<F5N=',G("X*
M("`@("`@("`@("`@)R!&4D]-("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G
M72`N"B`@("`@("`@("`@("<@5TA%4D4@9&%T871R965?;F%M92`](#\@04Y$
M(&=R;W5P7W5I9"`](#\G("X*("`@("`@("`@("`@)R!/4D1%4B!"62!D871A
M=')E95]I9"<["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"1R;V]T+`H@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG9W)O=7`G72D[
M"@H@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@1&%T
M851R965?<W%L.CI?8G5I;&1087)E;G1)9',H*3H@)R`N("1Q=65R>2P@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@)')O
M;W0@/2`D=&AI<RT^7V1B+3YG971!<W-O8R@D<75E<GDL(&9A;'-E+"`D=F%L
M=65S*3L*("`@("`@("!I9B`H:7-?82@D<F]O="P@)U!%05)?17)R;W(G*2!\
M?"`A8V]U;G0H)')O;W0I*2!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@
M("`@("!]"@H@("`@("`@("1W:&5R92`]("<G.PH@("`@("`@("1F:7)S=%]T
M:6UE(#T@=')U93L*("`@("`@("!F;W)E86-H("@D<F]O="!A<R`D;V)J96-T
M7VED(#T^("1O8FIE8W1?<&%R96YT<RD@>PH@("`@("`@("`@("`D<'-T<FEN
M9R`]("1O8FIE8W1?<&%R96YT<R`N("<Z)R`N("1O8FIE8W1?:60@+B`G)2<[
M"B`@("`@("`@("`@("1P<75E<GD@/2`G)SL*("`@("`@("`@("`@:68@*"%E
M;7!T>2@D;V)J96-T7W!A<F5N=',I*2!["B`@("`@("`@("`@("`@("`D:61S
M(#T@<W5B<W1R*"1O8FIE8W1?<&%R96YT<RP@,2D["B`@("`@("`@("`@("`@
M("`D<'%U97)Y(#T@)R!/4B`G("X@)&IO:6Y?;F%M92`N("=D871A=')E95]I
M9"!)3B`H)R`N('-T<E]R97!L86-E*"<Z)RP@)RP@)RP@)&ED<RD@+B`G*2<[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1L;V%D5')E92D@>PH@
M("`@("`@("`@("`@("`@)'!Q=65R>2`N/2`G($]2("<@+B`D:F]I;E]N86UE
M("X@)V1A=&%T<F5E7W!A<F5N=',@/2`G("X@)'1H:7,M/E]D8BT^<75O=&4H
M<W5B<W1R*"1P<W1R:6YG+"`P+"`M,BDI.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!I9B`H(21F:7)S=%]T:6UE*2!["B`@("`@("`@("`@("`@("`D
M=VAE<F4@+CT@)R!/4B`G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1W
M:&5R92`N/2!S<')I;G1F*"1J;VEN7VYA;64@+B`G9&%T871R965?<&%R96YT
M<R!,24M%("5S($]2("<@+B`D:F]I;E]N86UE("X@)V1A=&%T<F5E7VED(#T@
M)7,E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M9&(M/G%U;W1E*"1P<W1R:6YG*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&]B:F5C=%]I9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'!Q=65R>2D["@H@("`@("`@("`@("`D9FER<W1?=&EM92`](&9A;'-E
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1W:&5R93L*("`@('T*"B`@
M("`O*BH*("`@("`J($QO861S(&$@<V5T(&]F(&]B:F5C=',@:61E;G1I9FEE
M9"!B>2!T:&5I<B!U;FEQ=64@241S+"!A;F0@=&AE:7(*("`@("`J('!A<F5N
M=',L(&EN=&\@=&AE("1?9&%T82!A<G)A>2X*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&-I9',@
M(%1H92!U;FEQ=64@240@;V8@=&AE(&]B:F5C="!T;R!L;V%D+"!O<B!A;B!A
M<G)A>2!O9@H@("`@("H@("`@("`@("`@("`@("`@("`@("!O8FIE8W0@:61S
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S
M<R!O<B!A(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@7VQO861">4ED*"1C:61S*0H@("`@>PH@("`@("`@("\J($UA:V4@
M<W5R92!W92!H879E(&%N(&%R<F%Y+B`J+PH@("`@("`@(&EF("@A:7-?87)R
M87DH)&-I9',I*2!["B`@("`@("`@("`@("1C:61S(#T@87)R87DH*&EN="DD
M8VED<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@87)R87E?=V%L
M:R@D8VED<RP@)VEN='9A;"<I.PH@("`@("`@('T*"B`@("`@("`@+RH@0F%I
M;"!O=70@;F]W(&EF('1H97)E)W,@;F]T:&EN9R!T;R!L;V%D+B`J+PH@("`@
M("`@(&EF("@A8V]U;G0H)&-I9',I*2!["B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@('T*"B`@("`@("`@+RH@1&]N)W0@;&]A9"!A;GD@=&AA
M="!A<F4@86QR96%D>2!L;V%D960N($%L<V\L(&UA:V4@<W5R92!T:&%T"B`@
M("`@("`@("H@979E<GET:&EN9R!I;B!T:&4@)&ED<R!A<G)A>2!T:&%T('=E
M(&%R92!B=6EL9&EN9R!I<R!A;B!I;G1E9V5R+B`J+PH@("`@("`@("1I9',@
M/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1C:61S(&%S("1C:60I('L*
M("`@("`@("`@("`@+RH@1&\@3D]4('5S92!$871A5')E93HZ97AI<W1S*"D@
M:&5R93L@=&AA="!W;W5L9"!C875S92!A;@H@("`@("`@("`@("`@*B!I;F9I
M;FET92!L;V]P+B`J+PH@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?
M9&%T85LD8VED72DI('L*("`@("`@("`@("`@("`@("1I9'-;72`]("AI;G0I
M)&-I9#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@268@
M=&AE<F4@87)E(&YO;F4@;&5F="!T;R!L;V%D+"!R971U<FXN("HO"B`@("`@
M("`@:68@*"%C;W5N="@D:61S*2D@>PH@("`@("`@("`@("!R971U<FX@=')U
M93L*("`@("`@("!]"@H@("`@("`@("1I;B`](&%R<F%Y7W-E87)C:"A$051!
M5%)%15]23T]4+"`D:61S*2`]/3T@9F%L<V4@/R!S<')I;G1F*"=D871A=')E
M95]I9"!)3B`H)7,I($%.1"`G+"!I;7!L;V1E*"<L("<L("1I9',I*2`Z("<G
M.PH@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)U-%3$5#5"!D871A=')E95]I
M9"P@9&%T871R965?<&%R96YT<R!&4D]-("5S)R`N"B`@("`@("`@("`@("`@
M("`@("`@("`@("`G(%=(15)%("5S9W)O=7!?=6ED(#T@)7,G("X*("`@("`@
M("`@("`@("`@("`@("`@("`@("<@3U)$15(@0ED@9&%T871R965?:60G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE
M)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`D:6XL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7V1B+3YQ=6]T92@D=&AI<RT^7W!A<F%M
M<ULG9W)O=7`G72DI.PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@
M475E<GD@8GD@1&%T851R965?<W%L.CI?;&]A9$)Y260H*3H@)R`N("1Q=65R
M>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@
M("`@)'!A<F5N=',@/2`D=&AI<RT^7V1B+3YG971!<W-O8R@D<75E<GDI.PH@
M("`@("`@(&EF("AI<U]A*"1P87)E;G1S+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<&%R96YT<SL*("`@("`@("!]"B`@("`@("`@
M:68@*&5M<'1Y*"1P87)E;G1S*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BA?*").;W0@9F]U;F0N(BDL(&YU;&PL(&YU;&PL(&YU
M;&PL("=$871A5')E92!I9',@)R`N(&EM<&QO9&4H)RP@)RP@)&ED<RD@+B`G
M(&YO="!F;W5N9"XG*3L*("`@("`@("!]"@H@("`@("`@("1I9',@/2!A<G)A
M>2@I.PH@("`@("`@(&9O<F5A8V@@*"1P87)E;G1S(&%S("1C:60@/3X@)'!A
M<F5N="D@>PH@("`@("`@("`@("`D:61S6RAI;G0I)&-I9%T@/2`H:6YT*21C
M:60["@H@("`@("`@("`@("`D<&ED<R`](&5X<&QO9&4H)SHG+"!S=6)S='(H
M)'!A<F5N="P@,2DI.PH@("`@("`@("`@("!F;W)E86-H("@D<&ED<R!A<R`D
M<&ED*2!["B`@("`@("`@("`@("`@("`D<&ED(#T@*&EN="DD<&ED.PH@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V1A=&%;)'!I9%TI*2![
M"B`@("`@("`@("`@("`@("`@("`@)&ED<ULD<&ED72`]("1P:60["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("\J($EF("1I9',@:7,@96UP='DL('=E(&AA=F4@;F]T:&EN9R!T;R!L;V%D
M+B`J+PH@("`@("`@(&EF("@A8V]U;G0H)&ED<RDI('L*("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`D<75E<GD@/2`G4T5,
M14-4(&1A=&%T<F5E7VED+"!D871A=')E95]N86UE+"!D871A=')E95]P87)E
M;G1S+"!D871A=')E95]O<F1E<B<@+@H@("`@("`@("`@("`@("`@("<@1E)/
M32`G("X@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT@+@H@("`@("`@("`@("`@
M("`@("<@5TA%4D4@9&%T871R965?:60@24X@*#\G("X@<W1R7W)E<&5A="@G
M+"`_)RP@8V]U;G0H)&ED<RD@+2`Q*2`N("<I)R`N"B`@("`@("`@("`@("`@
M("`@)R!!3D0@9W)O=7!?=6ED(#T@/R!/4D1%4B!"62!D871A=')E95]I9"<[
M"B`@("`@("`@)'9A;'5E<R`](&%R<F%Y7VUE<F=E*"1I9',L(&%R<F%Y*"1T
M:&ES+3Y?<&%R86US6R=G<F]U<"==*2D["@H@("`@("`@($AO<F1E.CIL;V=-
M97-S86=E*"=344P@475E<GD@8GD@1&%T851R965?<W%L.CI?;&]A9$)Y260H
M*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$
M14)51RD["B`@("`@("`@)&1A=&$@/2`D=&AI<RT^7V1B+3YG971!;&PH)'%U
M97)Y+"`D=F%L=65S*3L*("`@("`@("!I9B`H:7-?82@D9&%T82P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&1A=&$["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)'1H:7,M/G-E="@D9&%T82P@)'1H:7,M/E]P
M87)A;7-;)V-H87)S970G72D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS(&$@=')E92!S;W)T960@8GD@=&AE('-P96-I9FEE9"!A='1R:6)U=&4@
M;F%M92!A;F0O;W(@:V5Y+@H@("`@("H*("`@("`J($!S:6YC92!(;W)D92`S
M+C$*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1R;V]T("`@("`@("`@
M5VAI8V@@<&]R=&EO;B!O9B!T:&4@=')E92!T;R!S;W)T+@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@($1E9F%U;'1S('1O(&%L;"!O9B!I
M="X*("`@("`J($!P87)A;2!B;V]L96%N("1L;V%D5')E92`@("!3;W)T('1H
M92!T<F5E('-T87)T:6YG(&%T("1R;V]T+"!O<B!J=7-T('1H90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E<75E<W1E9"!L979E;"!A
M;F0@9&ER96-T('!A<F5N=',_"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@1&5F875L=',@=&\@<VEN9VQE(&QE=F5L+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<V]R=&)Y7VYA;64@($%T=')I8G5T92!N86UE('1O('5S
M92!F;W(@<V]R=&EN9RX*("`@("`J($!P87)A;2!S=')I;F<@)'-O<G1B>5]K
M97D@("!!='1R:6)U=&4@:V5Y('1O('5S92!F;W(@<V]R=&EN9RX*("`@("`J
M($!P87)A;2!I;G1E9V5R("1D:7)E8W1I;VX@("!3;W)T(&1I<F5C=&EO;CH*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`P("T@87-C96YD
M:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@,2`M(&1E
M<V-E;F1I;F<*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4V]R=&5D5')E92@D
M<F]O="P@)&QO8614<F5E(#T@9F%L<V4L("1S;W)T8GE?;F%M92`](&YU;&PL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1S;W)T8GE?:V5Y(#T@;G5L
M;"P@)&1I<F5C=&EO;B`](#`I"B`@("!["B`@("`@("`@)'%U97)Y(#T@)'1H
M:7,M/E]B=6EL9$QO8611=65R>2@D<F]O="P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1L;V%D5')E92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@($1!5$%44D5%7T)524Q$7U-%
M3$5#5"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1S;W)T8GE?;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1S;W)T8GE?:V5Y+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&1I<F5C=&EO;BD["@H@("`@("`@(')E='5R
M;B`D=&AI<RT^7V1B+3YG971!;&PH)'%U97)Y*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($%D9',@86X@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!M
M:7AE9"`D;V)J96-T("`@("`@("!4:&4@;V)J96-T('1O(&%D9"`H<W1R:6YG
M(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1&%T851R
M965/8FIE8W0I+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&ED7V%S7VYA;64@
M(%=H971H97(@=&AE(&]B:F5C="!)1"!I<R!T;R!B92!U<V5D(&%S"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;V)J96-T(&YA;64N("!5
M<V5D(&EN('-I='5A=&EO;G,@=VAE<F4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!T:&5R92!I<R!N;R!A=F%I;&%B;&4@=6YI<75E(&EN
M<'5T(&9O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&]B
M:F5C="!N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&0H)&]B:F5C="P@
M)&ED7V%S7VYA;64@/2!F86QS92D*("`@('L*("`@("`@("`D871T<FEB=71E
M<R`](&9A;'-E.PH@("`@("`@(&EF("AI<U]A*"1O8FIE8W0L("=$871A5')E
M94]B:F5C="<I*2!["B`@("`@("`@("`@("1F=6QL;F%M92`]("1O8FIE8W0M
M/F=E=$YA;64H*3L*("`@("`@("`@("`@)&]R9&5R(#T@)&]B:F5C="T^;W)D
M97(["@H@("`@("`@("`@("`O*B!792!H86YD;&4@9&%T82!D:69F97)E;G1L
M>2!I9B!W92!C86X@;6%P(&ET('1O('1H90H@("`@("`@("`@("`@*B!H;W)D
M95]D871A=')E95]A='1R:6)U=&5S('1A8FQE+B`J+PH@("`@("`@("`@("!I
M9B`H;65T:&]D7V5X:7-T<R@D;V)J96-T+"`G7W1O071T<FEB=71E<R<I*2![
M"B`@("`@("`@("`@("`@("`D9&%T82`]("<G.PH@("`@("`@("`@("`@("`@
M)'-E<B`](&YU;&P["@H@("`@("`@("`@("`@("`@+RH@4V5T(&$@9FQA9R!F
M;W(@;&%T97(@<V\@=&AA="!W92!K;F]W('1O(&EN<V5R="!T:&4*("`@("`@
M("`@("`@("`@("`J(&%T=')I8G5T92!R;W=S+B`J+PH@("`@("`@("`@("`@
M("`@)&%T=')I8G5T97,@/2!T<G5E.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]397)I86QI>F4N
M<&AP)SL*("`@("`@("`@("`@("`@("1S97(@/2!315))04Q)6D5?551&-U]"
M05-)0SL*("`@("`@("`@("`@("`@("1D871A(#T@2&]R9&5?4V5R:6%L:7IE
M.CIS97)I86QI>F4H)&]B:F5C="T^9V5T1&%T82@I+"`D<V5R+"!.3%,Z.F=E
M=$-H87)S970H*2D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D9G5L;&YA;64@/2`D;V)J96-T.PH@("`@("`@("`@("`D
M;W)D97(@/2!N=6QL.PH@("`@("`@("`@("`D9&%T82`]("<G.PH@("`@("`@
M("`@("`D<V5R(#T@;G5L;#L*("`@("`@("!]"@H@("`@("`@("\J($=E="!T
M:&4@;F5X="!U;FEQ=64@240N("HO"B`@("`@("`@)&ED(#T@)'1H:7,M/E]D
M8BT^;F5X=$ED*"1T:&ES+3Y?<&%R86US6R=T86)L92==*3L*("`@("`@("!I
M9B`H:7-?82@D:60L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R
M9&4Z.FQO9TUE<W-A9V4H)&ED+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B`D:60["B`@("`@("`@?0H*
M("`@("`@("!I9B`H<W1R<&]S*"1F=6QL;F%M92P@)SHG*2`A/3T@9F%L<V4I
M('L*("`@("`@("`@("`@)'!A<G1S(#T@97AP;&]D92@G.B<L("1F=6QL;F%M
M92D["B`@("`@("`@("`@("1P87)E;G1S(#T@)R<["B`@("`@("`@("`@("1P
M<W1R:6YG(#T@)R<["B`@("`@("`@("`@(&EF("@D:61?87-?;F%M92D@>PH@
M("`@("`@("`@("`@("`@+RH@4F5Q=65S=&5D('5S92!O9B!)1"!A<R!N86UE
M+"!S;R!D:7-C87)D(&-U<G)E;G0@;F%M92X@*B\*("`@("`@("`@("`@("`@
M(&%R<F%Y7W!O<"@D<&%R=',I.PH@("`@("`@("`@("`@("`@+RH@4V5T(&YA
M;64@=&\@240N("HO"B`@("`@("`@("`@("`@("`D;F%M92`]("1I9#L*("`@
M("`@("`@("`@("`@("\J($UO9&EF>2!F=6QL;F%M92!T;R!R969L96-T(&YE
M=R!N86UE+B`J+PH@("`@("`@("`@("`@("`@)&9U;&QN86UE(#T@:6UP;&]D
M92@G.B<L("1P87)T<RD@+B`G.B<@+B`D:60["B`@("`@("`@("`@("`@("!I
M9B`H:7-?82@D;V)J96-T+"`G1&%T851R965/8FIE8W0G*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1O8FIE8W0M/G-E=$YA;64H)&9U;&QN86UE*3L*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&]B
M:F5C="`]("1F=6QL;F%M93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1N86UE(#T@87)R87E?<&]P
M*"1P87)T<RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@9F]R96%C:"`H
M)'!A<G1S(&%S("1P87(I('L*("`@("`@("`@("`@("`@("1P<W1R:6YG("X]
M("AE;7!T>2@D<'-T<FEN9RD@/R`G)R`Z("<Z)RD@+B`D<&%R.PH@("`@("`@
M("`@("`@("`@)'!I9"`]("1T:&ES+3YG971)9"@D<'-T<FEN9RD["B`@("`@
M("`@("`@("`@("!I9B`H:7-?82@D<&ED+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("`@("`@+RH@075T;RUC<F5A=&4@<&%R96YT<RX@*B\*
M("`@("`@("`@("`@("`@("`@("`D<&ED(#T@)'1H:7,M/F%D9"@D<'-T<FEN
M9RD["B`@("`@("`@("`@("`@("`@("`@:68@*&ES7V$H)'!I9"P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'!I
M9#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`D<&%R96YT<R`N/2`G.B<@+B`D<&ED.PH@("`@("`@
M("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*"1I9%]A
M<U]N86UE*2!["B`@("`@("`@("`@("`@("`O*B!297%U97-T960@=7-E(&]F
M($E$(&%S(&YA;64L('-E="!F=6QL;F%M92!A;F0@;F%M92!T;R!)1"X@*B\*
M("`@("`@("`@("`@("`@("1F=6QL;F%M92`]("1I9#L*("`@("`@("`@("`@
M("`@("1N86UE(#T@)&ED.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)&]B
M:F5C="P@)T1A=&%4<F5E3V)J96-T)RDI('L*("`@("`@("`@("`@("`@("`@
M("`D;V)J96-T+3YS971.86UE*"1F=6QL;F%M92D["B`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1O8FIE8W0@/2`D9G5L
M;&YA;64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D;F%M92`]("1F=6QL;F%M93L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D<&%R96YT<R`]("<G.PH@("`@("`@("`@("`D
M<&ED(#T@1$%40512145?4D]/5#L*("`@("`@("!]"@H@("`@("`@(&EF("AP
M87)E;G0Z.F5X:7-T<R@D9G5L;&YA;64I*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(D%L<F5A9'D@97AI<W1S(BDI.PH@("`@
M("`@('T*"B`@("`@("`@)'%U97)Y(#T@)TE.4T525"!)3E1/("<@+B`D=&AI
M<RT^7W!A<F%M<ULG=&%B;&4G72`N"B`@("`@("`@("`@("`@("`@)R`H9&%T
M871R965?:60L(&=R;W5P7W5I9"P@9&%T871R965?;F%M92P@9&%T871R965?
M;W)D97(L)R`N"B`@("`@("`@("`@("`@("`@)R!D871A=')E95]D871A+"!U
M<V5R7W5I9"P@9&%T871R965?<V5R:6%L:7IE9"PG("X*("`@("`@("`@("`@
M("`@("`G(&1A=&%T<F5E7W!A<F5N=',I)R`N"B`@("`@("`@("`@("`@("`@
M)R!604Q515,@*#\L(#\L(#\L(#\L(#\L(#\L(#\L(#\I)SL*("`@("`@("`D
M=F%L=65S(#T@87)R87DH*&EN="DD:60L"B`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=G<F]U<"==+`H@("`@("`@("`@("`@("`@
M("`@("`@("!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1N86UE+"!.3%,Z.F=E
M=$-H87)S970H*2P@)'1H:7,M/E]P87)A;7-;)V-H87)S970G72DL"B`@("`@
M("`@("`@("`@("`@("`@("`@(&ES7VYU;&PH)&]R9&5R*2`_($Y53$P@.B`H
M:6YT*21O<F1E<BP*("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&$L"B`@
M("`@("`@("`@("`@("`@("`@("`@("AS=')I;F<I075T:#HZ9V5T075T:"@I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`H:6YT*21S97(L"B`@("`@("`@
M("`@("`@("`@("`@("`@("1P87)E;G1S*3L*"B`@("`@("`@2&]R9&4Z.FQO
M9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ.F%D9"@I.B`G
M("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'
M*3L*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y
M+"`D=F%L=65S*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1R97-U
M;'0L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`D<F5O
M<F1E<B`]("1T:&ES+3YR96]R9&5R*"1P87)E;G1S+"`D;W)D97(L("1I9"D[
M"B`@("`@("`@:68@*&ES7V$H)')E;W)D97(L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)')E;W)D97(L(%]?1DE,
M15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T
M=7)N("1R96]R9&5R.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]('!A
M<F5N=#HZ7V%D9"@D9G5L;&YA;64L("1I9"P@)'!I9"P@)&]R9&5R*3L*("`@
M("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@+RH@
M268@=V4@<W5C8V5S9G5L;'D@:6YS97)T960@=&AE(&]B:F5C="!A;F0@:70@
M<W5P<&]R=',*("`@("`@("`@*B!B96EN9R!M87!P960@=&\@=&AE(&%T=')I
M8G5T97,@=&%B;&4L(&1O('1H870@;F]W.B`J+PH@("`@("`@(&EF("@A96UP
M='DH)&%T=')I8G5T97,I*2!["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI
M<RT^=7!D871E1&%T82@D;V)J96-T*3L*("`@("`@("`@("`@:68@*&ES7V$H
M)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D:60["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&%N9V5S('1H
M92!O<F1E<B!O9B!T:&4@8VAI;&1R96X@;V8@86X@;V)J96-T+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'!A<F5N="`@5&AE(&9U;&P@:60@<&%T
M:"!O9B!T:&4@<&%R96YT(&]B:F5C="X*("`@("`J($!P87)A;2!M:7AE9"`D
M;W)D97(@("`@268@86X@87)R87D@:70@<W!E8VEF:65S('1H92!N97<@<&]S
M:71I;VYS(&9O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!A;&P@
M8VAI;&0@;V)J96-T<RX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M268@86X@:6YT96=E<B!A;F0@)&-I9"!I<R!S<&5C:69I960L('1H92!P;W-I
M=&EO;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!W:&5R92!T:&4@
M8VAI;&0@<W!E8VEF:65D(&)Y("1C:60@:7,@:6YS97)T960N($EF"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("1C:60@:7,@;F]T('-P96-I9FEE
M9"P@=&AE('!O<VET:6]N(&=E=',@9&5L971E9"P*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@8V%U<VEN9R!T:&4@9F]L;&]W:6YG('!O<VET:6]N
M<R!T;R!S:&EF="!U<"X*("`@("`J($!P87)A;2!I;G1E9V5R("1C:60@("`@
M4V5E("1O<F1E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@<F5O<F1E<B@D<&%R
M96YT+"`D;W)D97(@/2!N=6QL+"`D8VED(#T@;G5L;"D*("`@('L*("`@("`@
M("!I9B`H(21P87)E;G0@?'P@:7-?82@D<&%R96YT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("\O($%B;W)T(&EM;65D:6%T96QY(&EF('1H92!P
M87)E;G0@<W1R:6YG(&ES(&5M<'1Y.R!W90H@("`@("`@("`@("`O+R!C86YN
M;W0@<V%F96QY(')E;W)D97(@86QL('1O<"UL979E;"!E;&5M96YT<RX*("`@
M("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@)'!Q=65R>2`]
M("<G.PH@("`@("`@(&EF("@A:7-?87)R87DH)&]R9&5R*2`F)B`A:7-?;G5L
M;"@D;W)D97(I*2!["B`@("`@("`@("`@("\J(%-I;F=L92!U<&1A=&4@*&%D
M9"]D96PI+B`J+PH@("`@("`@("`@("!I9B`H:7-?;G5L;"@D8VED*2D@>PH@
M("`@("`@("`@("`@("`@+RH@3F\@;V)J96-T(&ED(&=I=F5N('-O('-H=69F
M;&4@9&]W;BX@*B\*("`@("`@("`@("`@("`@("1D:7)E8W1I;VX@/2`G+2<[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O*B!792!H
M879E(&%N(&]B:F5C="!I9"!S;R!S:'5F9FQE('5P+B`J+PH@("`@("`@("`@
M("`@("`@)&1I<F5C=&EO;B`]("<K)SL*"B`@("`@("`@("`@("`@("`O*B!,
M96%V:6YG('1H92!N97=L>2!I;G-E<G1E9"!O8FIE8W0@86QO;F4N("HO"B`@
M("`@("`@("`@("`@("`D<'%U97)Y(#T@<W!R:6YT9B@G($%.1"!D871A=')E
M95]I9"`A/2`E<R<L("AI;G0I)&-I9"D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G55!$051%("5S(%-%5"!D871A=')E
M95]O<F1E<B`](&1A=&%T<F5E7V]R9&5R("5S(#$@5TA%4D4@9W)O=7!?=6ED
M(#T@)7,@04Y$(&1A=&%T<F5E7W!A<F5N=',@/2`E<R!!3D0@9&%T871R965?
M;W)D97(@/CT@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%R86US6R=T86)L92==+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1D:7)E8W1I;VXL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]D8BT^<75O=&4H)'1H:7,M/E]P87)A;7-;)V=R;W5P)UTI
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&(M/G%U
M;W1E*"1P87)E;G0I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&ES
M7VYU;&PH)&]R9&5R*2`_("=.54Q,)R`Z("AI;G0I)&]R9&5R*2`N("1P<75E
M<GD["@H@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y
M(&)Y($1A=&%4<F5E7W-Q;#HZ<F5O<F1E<B@I.B`G("X@)'%U97)Y+"!?7T9)
M3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@
M)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2D["B`@("`@("`@
M?2!E;'-E:68@*&ES7V%R<F%Y*"1O<F1E<BDI('L*("`@("`@("`@("`@+RH@
M375L=&D@=7!D871E+B`J+PH@("`@("`@("`@("`D<75E<GD@/2`G4T5,14-4
M($-/54Y4*&1A=&%T<F5E7VED*2<@+@H@("`@("`@("`@("`@("`@("`@("`G
M($923TT@)R`N("1T:&ES+3Y?<&%R86US6R=T86)L92==("X*("`@("`@("`@
M("`@("`@("`@("`@)R!72$5212!G<F]U<%]U:60@/2`_($%.1"!D871A=')E
M95]P87)E;G1S(#T@/R<@+@H@("`@("`@("`@("`@("`@("`@("`G($=23U50
M($)9(&1A=&%T<F5E7W!A<F5N=',G.PH@("`@("`@("`@("`D=F%L=65S(#T@
M87)R87DH)'1H:7,M/E]P87)A;7-;)V=R;W5P)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<&%R96YT*3L*"B`@("`@("`@("`@($AO<F1E.CIL
M;V=-97-S86=E*"=344P@475E<GD@8GD@1&%T851R965?<W%L.CIR96]R9&5R
M*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?
M1$5"54<I.PH*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/F=E
M=$]N92@D<75E<GDL("1V86QU97,I.PH@("`@("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("`@("`@?2!E;'-E:68@*&-O=6YT*"1O<F1E
M<BD@(3T@)')E<W5L="D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H7R@B0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R
M:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E
M<B!S=&]R960N(BDI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D;U]K
M97D@/2`P.PH@("`@("`@("`@("!F;W)E86-H("@D;W)D97(@87,@)&]?8VED
M*2!["B`@("`@("`@("`@("`@("`D<75E<GD@/2`G55!$051%("<@+B`D=&AI
M<RT^7W!A<F%M<ULG=&%B;&4G72`N"B`@("`@("`@("`@("`@("`@("`@("`@
M("`G(%-%5"!D871A=')E95]O<F1E<B`](#\@5TA%4D4@9&%T871R965?:60@
M/2`_)SL*("`@("`@("`@("`@("`@("1V86QU97,@/2!A<G)A>2@D;U]K97DL
M(&ES7VYU;&PH)&]?8VED*2`_($Y53$P@.B`H:6YT*21O7V-I9"D["@H@("`@
M("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$
M871A5')E95]S<6PZ.G)E;W)D97(H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L
M(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@("`@("`@("`D
M<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*
M("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D;U]K97DK*SL*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)'!I9"`]("1T:&ES+3YG971)9"@D
M<&%R96YT*3L*"B`@("`@("`@("`@("\J(%)E+6]R9&5R(&]U<B!C86-H92X@
M*B\*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F5O<F1E<B@D<&ED+"`D
M;W)D97(I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($5X<&QI
M8VET;'D@<V5T('1H92!O<F1E<B!F;W(@82!D871A=')E92!O8FIE8W0N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&ED("`@("!4:&4@9&%T871R
M964@;V)J96-T(&ED('1O(&-H86YG92X*("`@("`J($!P87)A;2!I;G1E9V5R
M("1O<F1E<B`@5&AE(&YE=R!O<F1E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M<V5T3W)D97(H)&ED+"`D;W)D97(I"B`@("!["B`@("`@("`@)'%U97)Y(#T@
M)U501$%412`G("X@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT@+@H@("`@("`@
M("`@("`@("`@("<@4T54(&1A=&%T<F5E7V]R9&5R(#T@/R!72$5212!D871A
M=')E95]I9"`](#\G.PH@("`@("`@("1V86QU97,@/2!A<G)A>2AI<U]N=6QL
M*"1O<F1E<BD@/R!.54Q,(#H@*&EN="DD;W)D97(L"B`@("`@("`@("`@("`@
M("`@("`@("`@("AI;G0I)&ED*3L*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A
M9V4H)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ.G-E=$]R9&5R*"DZ("<@
M+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I
M.PH@("`@("`@(')E='5R;B`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V
M86QU97,I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E<R!A;B!O8FIE
M8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("`@)&]B:F5C="`@5&AE
M(&]B:F5C="!T;R!R96UO=F4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9F]R
M8V4@("!&;W)C92!R96UO=F%L(&]F(&5V97)Y(&-H:6QD(&]B:F5C=#\*("`@
M("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E*"1O8FIE8W0L("1F;W)C92`](&9A
M;'-E*0H@("`@>PH@("`@("`@("1I9"`]("1T:&ES+3YG971)9"@D;V)J96-T
M*3L*("`@("`@("`D;W)D97(@/2`D=&AI<RT^9V5T3W)D97(H)&]B:F5C="D[
M"@H@("`@("`@("1Q=65R>2`]("=314Q%0U0@9&%T871R965?:60@1E)/32`G
M("X@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT@+@H@("`@("`@("`@("`@("`@
M("<@5TA%4D4@9W)O=7!?=6ED(#T@/R!!3D0@9&%T871R965?<&%R96YT<R!,
M24M%(#\G("X*("`@("`@("`@("`@("`@("`G($]21$52($)9(&1A=&%T<F5E
M7VED)SL*("`@("`@("`D=F%L=65S(#T@87)R87DH)'1H:7,M/E]P87)A;7-;
M)V=R;W5P)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("<E.B<@+B`H:6YT
M*21I9"`N("<G*3L*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1
M=65R>2!B>2!$871A5')E95]S<6PZ.G)E;6]V92@I.B`G("X@)'%U97)Y+"!?
M7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`D
M8VAI;&1R96X@/2`D=&AI<RT^7V1B+3YG971!;&PH)'%U97)Y+"`D=F%L=65S
M+"!$0E]&151#2$U/1$5?05-33T,I.PH*("`@("`@("!I9B`H8V]U;G0H)&-H
M:6QD<F5N*2D@>PH@("`@("`@("`@("!I9B`H)&9O<F-E*2!["B`@("`@("`@
M("`@("`@("!F;W)E86-H("@D8VAI;&1R96X@87,@)&-H:6QD*2!["B`@("`@
M("`@("`@("`@("`@("`@)&-A="`]("1T:&ES+3YG971.86UE*"1C:&EL9%LG
M9&%T871R965?:60G72D["B`@("`@("`@("`@("`@("`@("`@)')E<W5L="`]
M("1T:&ES+3YR96UO=F4H)&-A="P@=')U92D["B`@("`@("`@("`@("`@("`@
M("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS
M<')I;G1F*%\H(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(I
M+"!C;W5N="@D8VAI;&1R96XI*2D["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("\J(%)E;6]V92!A='1R:6)U=&5S(&9O<B!T:&ES(&]B:F5C
M="X@*B\*("`@("`@("`D<75E<GD@/2`G1$5,151%($923TT@)R`N("1T:&ES
M+3Y?<&%R86US6R=T86)L95]A='1R:6)U=&5S)UT@+@H@("`@("`@("`@("`@
M("`@("<@5TA%4D4@9&%T871R965?:60@/2`_)SL*("`@("`@("`D=F%L=65S
M(#T@87)R87DH*&EN="DD:60I.PH*("`@("`@("!(;W)D93HZ;&]G365S<V%G
M92@G4U%,(%%U97)Y(&)Y($1A=&%4<F5E7W-Q;#HZ<F5M;W9E*"DZ("<@+B`D
M<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V
M86QU97,I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*
M("`@("`@("`D<75E<GD@/2`G1$5,151%($923TT@)R`N("1T:&ES+3Y?<&%R
M86US6R=T86)L92==("X*("`@("`@("`@("`@("`@("`G(%=(15)%(&1A=&%T
M<F5E7VED(#T@/R<["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"AI;G0I)&ED
M*3L*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$
M871A5')E95]S<6PZ.G)E;6]V92@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@
M7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`D<F5S=6QT(#T@
M)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*("`@("`@("!I
M9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@)'!A<F5N=',@
M/2`D=&AI<RT^9V5T4&%R96YT2613=')I;F<H)&]B:F5C="D["B`@("`@("`@
M:68@*&ES7V$H)'!A<F5N=',L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1P87)E;G1S.PH@("`@("`@('T*"B`@("`@("`@)')E;W)D
M97(@/2`D=&AI<RT^<F5O<F1E<B@D<&%R96YT<RP@)&]R9&5R*3L*("`@("`@
M("!I9B`H:7-?82@D<F5O<F1E<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)')E;W)D97(["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@:7-?82AP87)E;G0Z.G)E;6]V92@D;V)J96-T*2P@)U!%05)?17)R;W(G
M*2`_("1I9"`Z('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S
M(&]N92!O<B!M;W)E(&]B:F5C=',@8GD@:60N"B`@("`@*@H@("`@("H@5&AI
M<R!F=6YC=&EO;B!D;V5S("IN;W0J(&1O('1H92!V86QI9&%T:6]N+"!R96]R
M9&5R:6YG+"!E=&,N('1H870*("`@("`J(')E;6]V92@I(&1O97,N($EF('EO
M=2!N965D('1O(&-H96-K(&9O<B!C:&EL9')E;BP@<F4M9&\@;W)D97)I;F<L
M(&5T8RXL"B`@("`@*B!T:&5N('EO=2!M=7-T(')E;6]V92@I(&]B:F5C=',@
M;VYE+6)Y+6]N92X@5&AI<R!I<R!F;W(@8V]D92!T:&%T(&MN;W=S"B`@("`@
M*B!I="=S(&1E86QI;F<@=VET:"!S:6YG;&4@*&YO;BUP87)E;G1E9"D@;V)J
M96-T<R!A;F0@;F5E9',@=&\@9&5L971E(&$*("`@("`J(&)A=&-H(&]F('1H
M96T@<75I8VML>2X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&ED<R`@
M5&AE(&]B:F5C=',@=&\@<F5M;W9E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R
M96UO=F5">4ED<R@D:61S*0H@("`@>PH@("`@("`@("\J(%-A;FET:7IE(&EN
M<'5T+B`J+PH@("`@("`@(&EF("@A:7-?87)R87DH)&ED<RDI('L*("`@("`@
M("`@("`@)&ED<R`](&%R<F%Y*"AI;G0I)&ED<RD["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@87)R87E?=V%L:R@D:61S+"`G:6YT=F%L)RD["B`@
M("`@("`@?0H*("`@("`@("`O*B!296UO=FEN9R!Z97)O(&]B:F5C=',@86QW
M87ES('-U8V-E961S+B`J+PH@("`@("`@(&EF("@A)&ED<RD@>PH@("`@("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("\J(%)E;6]V
M92!A='1R:6)U=&5S(&9O<B`D:61S+B`J+PH@("`@("`@("1Q=65R>2`]("=$
M14Q%5$4@1E)/32`G("X@)'1H:7,M/E]P87)A;7-;)W1A8FQE7V%T=')I8G5T
M97,G72`N"B`@("`@("`@("`@("`@("`@)R!72$5212!D871A=')E95]I9"!)
M3B`H/R<@+B!S=')?<F5P96%T*"<L(#\G+"!C;W5N="@D:61S*2`M(#$I("X@
M)RDG.PH@("`@("`@("1V86QU97,@/2`D:61S.PH*("`@("`@("!(;W)D93HZ
M;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($1A=&%4<F5E7W-Q;#HZ<F5M;W9E
M0GE)9',H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%2
M7TQ/1U]$14)51RD["B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U
M97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@("`@("`@:68@*&ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@("`@("!]"@H@("`@("`@("1Q=65R>2`]("=$14Q%5$4@1E)/32`G
M("X@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT@+@H@("`@("`@("`@("`@("`@
M("<@5TA%4D4@9&%T871R965?:60@24X@*#\G("X@<W1R7W)E<&5A="@G+"`_
M)RP@8V]U;G0H)&ED<RD@+2`Q*2`N("<I)SL*("`@("`@("`D=F%L=65S(#T@
M)&ED<SL*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B
M>2!$871A5')E95]S<6PZ.G)E;6]V94)Y261S*"DZ("<@+B`D<75E<GDL(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5M;W9E<R!O;F4@;W(@;6]R92!O8FIE8W1S
M(&)Y(&YA;64N"B`@("`@*@H@("`@("H@5&AI<R!F=6YC=&EO;B!D;V5S("IN
M;W0J(&1O('1H92!V86QI9&%T:6]N+"!R96]R9&5R:6YG+"!E=&,N('1H870*
M("`@("`J(')E;6]V92@I(&1O97,N($EF('EO=2!N965D('1O(&-H96-K(&9O
M<B!C:&EL9')E;BP@<F4M9&\@;W)D97)I;F<L(&5T8RXL"B`@("`@*B!T:&5N
M('EO=2!M=7-T(')E;6]V92@I(&]B:F5C=',@;VYE+6)Y+6]N92X@5&AI<R!I
M<R!F;W(@8V]D92!T:&%T(&MN;W=S"B`@("`@*B!I="=S(&1E86QI;F<@=VET
M:"!S:6YG;&4@*&YO;BUP87)E;G1E9"D@;V)J96-T<R!A;F0@;F5E9',@=&\@
M9&5L971E(&$*("`@("`J(&)A=&-H(&]F('1H96T@<75I8VML>2X*("`@("`J
M"B`@("`@*B!`<&%R86T@87)R87D@)&YA;65S("!4:&4@;V)J96-T<R!T;R!R
M96UO=F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V94)Y3F%M97,H)&YA
M;65S*0H@("`@>PH@("`@("`@(&EF("@A:7-?87)R87DH)&YA;65S*2D@>PH@
M("`@("`@("`@("`D;F%M97,@/2!A<G)A>2@D;F%M97,I.PH@("`@("`@('T*
M"B`@("`@("`@+RH@4F5M;W9I;F<@>F5R;R!O8FIE8W1S(&%L=V%Y<R!S=6-C
M965D<RX@*B\*("`@("`@("!I9B`H(21N86UE<RD@>PH@("`@("`@("`@("!R
M971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("1Q=65R>2`]("=314Q%
M0U0@9&%T871R965?:60@1E)/32`G("X@)'1H:7,M/E]P87)A;7-;)W1A8FQE
M)UT@+@H@("`@("`@("`@("`@("`@("<@5TA%4D4@9&%T871R965?;F%M92!)
M3B`H/R<@+B!S=')?<F5P96%T*"<L(#\G+"!C;W5N="@D;F%M97,I("T@,2D@
M+B`G*2<["B`@("`@("`@)'9A;'5E<R`]("1N86UE<SL*"B`@("`@("`@2&]R
M9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ.G)E
M;6]V94)Y3F%M97,H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?
M+"!014%27TQ/1U]$14)51RD["B`@("`@("`@)&ED<R`]("1T:&ES+3Y?9&(M
M/F=E=$-O;"@D<75E<GDL(#`L("1V86QU97,I.PH@("`@("`@(&EF("AI<U]A
M*"1I9',L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1I
M9',["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/G)E;6]V94)Y
M261S*"1I9',I.PH@("`@?0H*("`@("\J*@H@("`@("H@36]V92!A;B!O8FIE
M8W0@=&\@82!N97<@<&%R96YT+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE
M9"`@)&]B:F5C="`@("`@5&AE(&]B:F5C="!T;R!M;W9E+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;F5W<&%R96YT("!4:&4@;F5W('!A<F5N="!O8FIE8W0N
M($1E9F%U;'1S('1O('1H92!R;V]T+@H@("`@("HO"B`@("!F=6YC=&EO;B!M
M;W9E*"1O8FIE8W0L("1N97=P87)E;G0@/2!N=6QL*0H@("`@>PH@("`@("`@
M("1O;&1?<&%R96YT7W!A=&@@/2`D=&AI<RT^9V5T4&%R96YT2613=')I;F<H
M)&]B:F5C="D["B`@("`@("`@)')E<W5L="`]('!A<F5N=#HZ;6]V92@D;V)J
M96-T+"`D;F5W<&%R96YT*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@
M("`@("`@('T*("`@("`@("`D:60@/2`D=&AI<RT^9V5T260H)&]B:F5C="D[
M"B`@("`@("`@)&YE=U]P87)E;G1?<&%T:"`]("1T:&ES+3YG971087)E;G1)
M9%-T<FEN9R@D;V)J96-T*3L*"B`@("`@("`@+RH@1F5T8V@@=&AE(&]B:F5C
M="!B96EN9R!M;W9E9"!A;F0@86QL(&]F(&ET<R!C:&EL9')E;BP@<VEN8V4*
M("`@("`@("`@*B!W92!A;'-O(&YE960@=&\@=7!D871E('1H96ER('!A<F5N
M="!P871H<R!T;R!A=F]I9"!C<F5A=&EN9PH@("`@("`@("`J(&]R<&AA;G,N
M("HO"B`@("`@("`@)'%U97)Y(#T@)U-%3$5#5"!D871A=')E95]I9"P@9&%T
M871R965?<&%R96YT<R<@+@H@("`@("`@("`@("`@("`@("<@1E)/32`G("X@
M)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT@+@H@("`@("`@("`@("`@("`@("<@
M5TA%4D4@9&%T871R965?<&%R96YT<R`](#\@3U(@9&%T871R965?<&%R96YT
M<R!,24M%(#\G("X*("`@("`@("`@("`@("`@("`G($]2(&1A=&%T<F5E7VED
M(#T@/R<["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"1O;&1?<&%R96YT7W!A
M=&@@+B`G.B<@+B`D:60L"B`@("`@("`@("`@("`@("`@("`@("`@("1O;&1?
M<&%R96YT7W!A=&@@+B`G.B<@+B`D:60@+B`G.B4G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`H:6YT*21I9"D["@H@("`@("`@($AO<F1E.CIL;V=-97-S
M86=E*"=344P@475E<GD@8GD@1&%T851R965?<W%L.CIM;W9E*"DZ("<@+B`D
M<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@
M("`@("`@("1R;W=S970@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V
M86QU97,I.PH@("`@("`@(&EF("AI<U]A*"1R;W=S970L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R;W=S970["B`@("`@("`@?0H*
M("`@("`@("`O*B!5<&1A=&4@96%C:"!O8FIE8W0L(')E<&QA8VEN9R!T:&4@
M;VQD('!A<F5N="!P871H('=I=&@@=&AE"B`@("`@("`@("H@;F5W(&]N92X@
M*B\*("`@("`@("!W:&EL92`H)')O=R`]("1R;W=S970M/F9E=&-H4F]W*$1"
M7T9%5$-(34]$15]!4U-/0RDI('L*("`@("`@("`@("`@:68@*&ES7V$H)')O
M=RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R
M;W<["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1O<75E<GD@/2`G)SL*
M("`@("`@("`@("`@:68@*"1R;W=;)V1A=&%T<F5E7VED)UT@/3T@)&ED*2![
M"B`@("`@("`@("`@("`@("`D;W%U97)Y(#T@)RP@9&%T871R965?;W)D97(@
M/2`P("<["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($1O('-T<E]R
M97!L86-E*"D@;VYL>2!I9B!T:&ES(&ES(&YO="!A(&9I<G-T(&QE=F5L"B`@
M("`@("`@("`@("`J(&]B:F5C="X@*B\*("`@("`@("`@("`@:68@*"%E;7!T
M>2@D<F]W6R=D871A=')E95]P87)E;G1S)UTI*2!["B`@("`@("`@("`@("`@
M("`D<'!A=&@@/2!S=')?<F5P;&%C92@D;VQD7W!A<F5N=%]P871H+"`D;F5W
M7W!A<F5N=%]P871H+"`D<F]W6R=D871A=')E95]P87)E;G1S)UTI.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'!P871H(#T@)&YE
M=U]P87)E;G1?<&%T:#L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<75E
M<GD@/2!S<')I;G1F*"=54$1!5$4@)7,@4T54(&1A=&%T<F5E7W!A<F5N=',@
M/2`E<R<@+B`D;W%U97)Y("X@)R!72$5212!D871A=')E95]I9"`]("5S)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG
M=&%B;&4G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V1B+3YQ=6]T92@D<'!A=&@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("AI;G0I)')O=ULG9&%T871R965?:60G72D["@H@("`@("`@("`@("!(
M;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($1A=&%4<F5E7W-Q;#HZ
M;6]V92@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T1%0E5'*3L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M
M/G%U97)Y*"1Q=65R>2D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D;W)D97(@
M/2`D=&AI<RT^9V5T3W)D97(H)&]B:F5C="D["@H@("`@("`@("\J(%-H=69F
M;&4@9&]W;B!T:&4@;VQD(&]R9&5R('!O<VET:6]N<RX@*B\*("`@("`@("`D
M<F5O<F1E<B`]("1T:&ES+3YR96]R9&5R*"1O;&1?<&%R96YT7W!A=&@L("1O
M<F1E<BD["@H@("`@("`@("\J(%-H=69F;&4@=7`@=&AE(&YE=R!O<F1E<B!P
M;W-I=&EO;G,N("HO"B`@("`@("`@)')E;W)D97(@/2`D=&AI<RT^<F5O<F1E
M<B@D;F5W7W!A<F5N=%]P871H+"`P+"`D:60I.PH*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($-H86YG92!A;B!O8FIE8W0G
M<R!N86UE+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`@)&]L9%]O8FIE
M8W0@("`@("`@5&AE(&]L9"!O8FIE8W0N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N97=?;V)J96-T7VYA;64@(%1H92!N97<@;V)J96-T(&YA;64N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(')E;F%M92@D;VQD7V]B:F5C="P@)&YE=U]O8FIE
M8W1?;F%M92D*("`@('L*("`@("`@("`O*B!$;R!T:&4@8V%C:&4@<F5N86UI
M;F<@9FER<W0@*B\*("`@("`@("`D<F5S=6QT(#T@<&%R96YT.CIR96YA;64H
M)&]L9%]O8FIE8W0L("1N97=?;V)J96-T7VYA;64I.PH@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`O*B!'970@=&AE(&]B
M:F5C="!I9"!A;F0@<V5T('5P('1H92!S<6P@<75E<GDN("HO"B`@("`@("`@
M)&ED(#T@)'1H:7,M/F=E=$ED*"1O;&1?;V)J96-T*3L*("`@("`@("`D<75E
M<GD@/2`G55!$051%("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`N"B`@
M("`@("`@("`@("`@("`@)R!3150@9&%T871R965?;F%M92`](#\@5TA%4D4@
M9&%T871R965?:60@/2`_)SL*("`@("`@("`D=F%L=65S(#T@87)R87DH4W1R
M:6YG.CIC;VYV97)T0VAA<G-E="@D;F5W7V]B:F5C=%]N86UE+"!.3%,Z.F=E
M=$-H87)S970H*2P@)'1H:7,M/E]P87)A;7-;)V-H87)S970G72DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("AI;G0I)&ED*3L*"B`@("`@("`@2&]R9&4Z
M.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ.G)E;F%M
M92@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'
M7T1%0E5'*3L*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH
M)'%U97)Y+"`D=F%L=65S*3L*"B`@("`@("`@<F5T=7)N(&ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2`_("1R97-U;'0@.B!T<G5E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T<FEE=F5S(&1A=&$@9F]R(&%N(&]B:F5C="!F<F]M
M('1H92!D871A=')E95]D871A(&9I96QD+@H@("`@("H*("`@("`J($!P87)A
M;2!I;G1E9V5R("1C:60@(%1H92!O8FIE8W0@:60@=&\@9F5T8V@L(&]R(&%N
M(&%R<F%Y(&]F(&]B:F5C="!I9',N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$1A=&$H)&-I9"D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E
M+U-E<FEA;&EZ92YP:'`G.PH*("`@("`@("!I9B`H:7-?87)R87DH)&-I9"DI
M('L*("`@("`@("`@("`@:68@*"%C;W5N="@D8VED*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1Q=65R>2`]('-P<FEN=&8H)U-%3$5#5"!D871A=')E95]I9"P@9&%T
M871R965?9&%T82P@9&%T871R965?<V5R:6%L:7IE9"!&4D]-("5S(%=(15)%
M(&1A=&%T<F5E7VED($E.("@E<RDG+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&EM<&QO9&4H)RP@)RP@)&-I9"DI.PH*("`@("`@
M("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$871A5')E
M95]S<6PZ.F=E=$1A=&$H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@("`@("1R97-U;'0@/2`D
M=&AI<RT^7V1B+3YG971!<W-O8R@D<75E<GDI.PH@("`@("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@
M("!(;W)D93HZ;&]G365S<V%G92@D<F5S=6QT+"!?7T9)3$5?7RP@7U],24Y%
M7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&1A=&$@/2!A<G)A
M>2@I.PH@("`@("`@("`@("!F;W)E86-H("@D<F5S=6QT(&%S("1I9"`]/B`D
M<F]W*2!["B`@("`@("`@("`@("`@("`D9&%T85LD:61=(#T@2&]R9&5?4V5R
M:6%L:7IE.CIU;G-E<FEA;&EZ92@D<F]W6S!=+"`D<F]W6S%=+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@("`@("`@("`@("`@+RH@
M0V]N=F5R="!O;&0@9&%T82!T;R!T:&4@;F5W(&9O<FUA="X@*B\*("`@("`@
M("`@("`@("`@(&EF("@D<F]W6S%=(#T](%-%4DE!3$E:15]"05-)0RD@>PH@
M("`@("`@("`@("`@("`@("`@("1D871A6R1I9%T@/2!3=')I;F<Z.F-O;G9E
M<G1#:&%R<V5T*"1D871A6R1I9%TL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@3DQ3.CIG971#:&%R
M<V5T*'1R=64I*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@
M("`D9&%T85LD:61=(#T@*&ES7VYU;&PH)&1A=&%;)&ED72D@?'P@(6ES7V%R
M<F%Y*"1D871A6R1I9%TI*0H@("`@("`@("`@("`@("`@("`@(#\@87)R87DH
M*0H@("`@("`@("`@("`@("`@("`@(#H@)&1A=&%;)&ED73L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@<F5T=7)N("1D871A.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1Q=65R>2`]("=314Q%0U0@9&%T871R965?9&%T
M82P@9&%T871R965?<V5R:6%L:7IE9"<@+@H@("`@("`@("`@("`@("`@("`@
M("`G($923TT@)R`N("1T:&ES+3Y?<&%R86US6R=T86)L92==("X*("`@("`@
M("`@("`@("`@("`@("`@)R!72$5212!D871A=')E95]I9"`](#\G.PH@("`@
M("`@("`@("`D=F%L=65S(#T@87)R87DH*&EN="DD8VED*3L*"B`@("`@("`@
M("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@1&%T851R965?
M<W%L.CIG971$871A*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?
M7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("`D<F]W(#T@)'1H:7,M
M/E]D8BT^9V5T4F]W*"1Q=65R>2P@)'9A;'5E<RP@1$)?1D540TA-3T1%7T%3
M4T]#*3L*"B`@("`@("`@("`@("1D871A(#T@2&]R9&5?4V5R:6%L:7IE.CIU
M;G-E<FEA;&EZ92@D<F]W6R=D871A=')E95]D871A)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F]W6R=D
M871A=')E95]S97)I86QI>F5D)UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!.3%,Z.F=E=$-H87)S970H*2D[
M"B`@("`@("`@("`@("\J($-O;G9E<G0@;VQD(&1A=&$@=&\@=&AE(&YE=R!F
M;W)M870N("HO"B`@("`@("`@("`@(&EF("@D<F]W6R=D871A=')E95]S97)I
M86QI>F5D)UT@/3T@4T5224%,25I%7T)!4TE#*2!["B`@("`@("`@("`@("`@
M("`D9&%T82`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&1A=&$L($Y,4SHZ
M9V5T0VAA<G-E="AT<G5E*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M<F5T=7)N("AI<U]N=6QL*"1D871A*2!\?"`A:7-?87)R87DH)&1A=&$I*2`_
M(&%R<F%Y*"D@.B`D9&%T83L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971R:65V97,@9&%T82!F;W(@86X@;V)J96-T(&9R;VT@=&AE(&AO
M<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@=&%B;&4N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN=&5G97)\87)R87D@)&-I9"`@5&AE(&]B:F5C="!I9"!T;R!F
M971C:"P@;W(@86X@87)R87D@;V8*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&]B:F5C="!I9',N"B`@("`@*B!`<&%R86T@87)R87D@)&ME
M>7,@("`@("`@("!4:&4@871T<FEB=71E<R!K97ES('1O(&9E=&-H+@H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@($$@:&%S:"!O9B!A='1R:6)U=&5S
M+"!O<B!A(&UU;'1I+6QE=F5L(&AA<V@@;V8@;V)J96-T"B`@("`@*B`@("`@
M("`@("`@("`@("!I9',@/3X@=&AE:7(@871T<FEB=71E<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T071T<FEB=71E<R@D8VED+"`D:V5Y<R`](&9A;'-E
M*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D8VED*2D@>PH@("`@("`@("`@
M("!R971U<FX@87)R87DH*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D:V5Y
M<RD@>PH@("`@("`@("`@("`D9FEL=&5R(#T@<W!R:6YT9B@G($%.1"!A='1R
M:6)U=&5?:V5Y($E.("A<)R5S7"<I)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:6UP;&]D92@B)RP@)R(L("1K97ES*2D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)&9I;'1E<B`]("<G.PH@("`@("`@('T*"B`@
M("`@("`@:68@*&ES7V%R<F%Y*"1C:60I*2!["B`@("`@("`@("`@("1Q=65R
M>2`]('-P<FEN=&8H)U-%3$5#5"!D871A=')E95]I9"P@871T<FEB=71E7VYA
M;64@05,@;F%M92P@871T<FEB=71E7VME>2!!4R`B:V5Y(BP@871T<FEB=71E
M7W9A;'5E($%3('9A;'5E($923TT@)7,@5TA%4D4@9&%T871R965?:60@24X@
M*"5S*25S)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG=&%B;&5?871T<FEB=71E<R==+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&EM<&QO9&4H)RP@)RP@)&-I9"DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&9I;'1E<BD["@H@("`@("`@("`@("!(;W)D
M93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($1A=&%4<F5E7W-Q;#HZ9V5T
M071T<FEB=71E<R@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L
M(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@)')O=W,@/2`D=&AI<RT^
M7V1B+3YG971!;&PH)'%U97)Y+"!$0E]&151#2$U/1$5?05-33T,I.PH@("`@
M("`@("`@("!I9B`H:7-?82@D<F]W<RP@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1R;W=S.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`D9&%T82`](&%R<F%Y*"D["B`@("`@("`@("`@(&9O<F5A8V@@
M*"1R;W=S(&%S("1R;W<I('L*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D
M9&%T85LD<F]W6R=D871A=')E95]I9"==72DI('L*("`@("`@("`@("`@("`@
M("`@("`D9&%T85LD<F]W6R=D871A=')E95]I9"==72`](&%R<F%Y*"D["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D9&%T85LD<F]W6R=D
M871A=')E95]I9"==75M=(#T@87)R87DH)VYA;64G(#T^("1R;W=;)VYA;64G
M72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G:V5Y)R`]/B`D<F]W6R=K97DG72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=F%L
M=64G(#T^(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)')O=ULG=F%L=64G72P@
M)'1H:7,M/E]P87)A;7-;)V-H87)S970G72P@3DQ3.CIG971#:&%R<V5T*"DI
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)&1A=&$["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G
M4T5,14-4(&%T=')I8G5T95]N86UE($%3(&YA;64L(&%T=')I8G5T95]K97D@
M05,@(FME>2(L(&%T=')I8G5T95]V86QU92!!4R!V86QU92!&4D]-("5S(%=(
M15)%(&1A=&%T<F5E7VED(#T@)7,E<R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE7V%T=')I8G5T97,G72P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`H:6YT*21C:60L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&9I;'1E<BD["@H@("`@("`@("`@
M("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($1A=&%4<F5E7W-Q
M;#HZ9V5T071T<FEB=71E<R@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],
M24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@)')O=W,@/2`D
M=&AI<RT^7V1B+3YG971!;&PH)'%U97)Y+"!$0E]&151#2$U/1$5?05-33T,I
M.PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D<F]W<RD[
M("1I*RLI('L*("`@("`@("`@("`@("`@("1R;W=S6R1I75LG=F%L=64G72`]
M(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)')O=W-;)&E=6R=V86QU92==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG8VAA<G-E="==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!.3%,Z.F=E=$-H87)S970H*2D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@<F5T=7)N("1R;W=S.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&YU;6)E<B!O9B!O8FIE8W1S(&UA
M=&-H:6YG(&$@<V5T(&]F(&%T=')I8G5T92!C<FET97)I82X*("`@("`J"B`@
M("`@*B!`<V5E(&)U:6QD071T<FEB=71E475E<GDH*0H@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>2`@("1C<FET97)I82`@(%1H92!A<G)A>2!O9B!C<FET
M97)I82X*("`@("`J($!P87)A;2!S=')I;F<@("1P87)E;G0@("`@(%1H92!P
M87)E;G0@;F]D92!T;R!S=&%R="!S96%R8VAI;F<@9G)O;2X*("`@("`J($!P
M87)A;2!B;V]L96%N("1A;&Q,979E;',@(%)E='5R;B!A;&P@;&5V96QS+"!O
M<B!J=7-T('1H92!D:7)E8W0*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&-H:6QD<F5N(&]F("1P87)E;G0_($1E9F%U;'1S('1O(&%L;"!L
M979E;',N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<F5S=')I8W0@("!/;FQY
M(')E='5R;B!A='1R:6)U=&5S('=I=&@@=&AE('-A;64*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%T=')I8G5T95]N86UE(&]R(&%T=')I
M8G5T95]I9"X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]U;G1">4%T=')I8G5T
M97,H)&-R:71E<FEA+"`D<&%R96YT(#T@1$%40512145?4D]/5"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1A;&Q,979E;',@/2!T<G5E+"`D
M<F5S=')I8W0@/2`G;F%M92<I"B`@("!["B`@("`@("`@:68@*"%C;W5N="@D
M8W)I=&5R:6$I*2!["B`@("`@("`@("`@(')E='5R;B`P.PH@("`@("`@('T*
M"B`@("`@("`@)&%Q(#T@)'1H:7,M/F)U:6QD071T<FEB=71E475E<GDH)&-R
M:71E<FEA+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1P87)E;G0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&%L;$QE=F5L<RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<F5S=')I8W0L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@1$%40512145?0E5)3$1?0T]53E0I
M.PH@("`@("`@(&EF("AI<U]A*"1A<2P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)&%Q.PH@("`@("`@('T*("`@("`@("!L:7-T*"1Q
M=65R>2P@)'9A;'5E<RD@/2`D87$["@H@("`@("`@($AO<F1E.CIL;V=-97-S
M86=E*"=344P@475E<GD@8GD@1&%T851R965?<W%L.CIC;W5N=$)Y071T<FEB
M=71E<R@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T1%0E5'*3L*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U
M97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@("`@("`@:68@*&ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S
M<V%G92@D<F5S=6QT+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T52
M4BD["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@
M("`@("`D<F]W(#T@)B1R97-U;'0M/F9E=&-H4F]W*"D["B`@("`@("`@:68@
M*&ES7V$H)')O=RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(;W)D
M93HZ;&]G365S<V%G92@D<F]W+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B`D<F]W.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1R;W=;,%T["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&$@<V5T(&]F(&]B:F5C="!I9',@8F%S960@;VX@82!S970@
M;V8@871T<FEB=71E(&-R:71E<FEA+@H@("`@("H*("`@("`J($!S964@8G5I
M;&1!='1R:6)U=&51=65R>2@I"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("`@)&-R:71E<FEA("`@("!4:&4@87)R87D@;V8@8W)I=&5R:6$N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("`D<&%R96YT("`@("`@(%1H92!P87)E;G0@;F]D
M92!T;R!S=&%R="!S96%R8VAI;F<@9G)O;2X*("`@("`J($!P87)A;2!B;V]L
M96%N("1A;&Q,979E;',@("`@4F5T=7)N(&%L;"!L979E;',L(&]R(&IU<W0@
M=&AE(&1I<F5C=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!C:&EL9')E;B!O9B`D<&%R96YT/R!$969A=6QT<R!T;R!A;&P@;&5V96QS
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)')E<W1R:6-T("`@("!/;FQY(')E
M='5R;B!A='1R:6)U=&5S('=I=&@@=&AE('-A;64*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@871T<FEB=71E7VYA;64@;W(@871T<FEB
M=71E7VED+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&9R;VT@("`@("`@("!4
M:&4@;V)J96-T('1O('-T87)T('1O(&9E=&-H:6YG"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D8V]U;G0@("`@("`@(%1H92!N=6UB97(@;V8@;V)J96-T<R!T
M;R!F971C:`H@("`@("H@0'!A<F%M('-T<FEN9R`@)'-O<G1B>5]N86UE("!!
M='1R:6)U=&4@;F%M92!T;R!U<V4@9F]R('-O<G1I;F<N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("`D<V]R=&)Y7VME>2`@($%T=')I8G5T92!K97D@=&\@=7-E
M(&9O<B!S;W)T:6YG+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&1I<F5C=&EO
M;B`@("!3;W)T(&1I<F5C=&EO;CH*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`P("T@87-C96YD:6YG"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@,2`M(&1E<V-E;F1I;F<*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T0GE!='1R:6)U=&5S*"1C<FET97)I82P@)'!A<F5N
M="`]($1!5$%44D5%7U)/3U0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&%L;$QE=F5L<R`]('1R=64L("1R97-T<FEC="`]("=N86UE)RP@)&9R
M;VT@/2`P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;W5N="`]
M(#`L("1S;W)T8GE?;F%M92`](&YU;&PL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'-O<G1B>5]K97D@/2!N=6QL+"`D9&ER96-T:6]N(#T@,"D*
M("`@('L*("`@("`@("!I9B`H(6-O=6YT*"1C<FET97)I82DI('L*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)VYO(&-R:71E<FEA)RD[
M"B`@("`@("`@?0H*("`@("`@("`D87$@/2`D=&AI<RT^8G5I;&1!='1R:6)U
M=&51=65R>2@D8W)I=&5R:6$L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'!A<F5N="P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D86QL3&5V96QS+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R97-T<FEC="P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!$051!5%)%15]"
M54E,1%]314Q%0U0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'-O<G1B>5]N86UE+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1S;W)T8GE?:V5Y+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D:7)E8W1I;VXI.PH@("`@
M("`@(&EF("AI<U]A*"1A<2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&%Q.PH@("`@("`@('T*("`@("`@("!L:7-T*"1Q=65R>2P@
M)'9A;'5E<RD@/2`D87$["@H@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=3
M44P@475E<GD@8GD@1&%T851R965?<W%L.CIG971">4%T=')I8G5T97,H*3H@
M)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)5
M1RD["@H@("`@("`@(&EF("@D8V]U;G0I('L*("`@("`@("`@("`@)')E<W5L
M="`]("1T:&ES+3Y?9&(M/FQI;6ET475E<GDH)'%U97)Y+"`D9G)O;2P@)&-O
M=6YT+"`D=F%L=65S*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*
M("`@("`@("!]"@H@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)')E<W5L
M="P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"B`@("`@("`@)')O=W,@
M/2!A<G)A>2@I.PH@("`@("`@('=H:6QE("@D<F]W(#T@)B1R97-U;'0M/F9E
M=&-H4F]W*"DI('L*("`@("`@("`@("`@)')O=W-;)')O=ULP75T@/2!3=')I
M;F<Z.F-O;G9E<G1#:&%R<V5T*"1R;W=;,5TL("1T:&ES+3Y?<&%R86US6R=C
M:&%R<V5T)UTI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R;W=S.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4V]R=',@241S(&)Y(&%T=')I8G5T92!V
M86QU97,N($E$<R!W:71H;W5T(&%T=')I8G5T97,@=VEL;"!B92!A9&1E9"!T
M;PH@("`@("H@=&AE(&5N9"!O9B!T:&4@<V]R=&5D(&QI<W0N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1U;F]R9&5R961?:61S("!!<G)A>2!O9B!I
M9',@=&\@<V]R="X*("`@("`J($!P87)A;2!A<G)A>2`D<V]R=&)Y7VYA;64@
M("`@071T<FEB=71E(&YA;64@=&\@=7-E(&9O<B!S;W)T:6YG+@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1S;W)T8GE?:V5Y("`@("!!='1R:6)U=&4@:V5Y('1O
M('5S92!F;W(@<V]R=&EN9RX*("`@("`J($!P87)A;2!A<G)A>2`D9&ER96-T
M:6]N("`@("`@4V]R="!D:7)E8W1I;VXZ"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@,"`M(&%S8V5N9&EN9PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#$@+2!D97-C96YD:6YG"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@4V]R=&5D(&ED<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@<V]R=$)Y071T<FEB=71E<R@D=6YO<F1E<F5D7VED<RP@
M)'-O<G1B>5]N86UE(#T@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'-O<G1B>5]K97D@/2!N=6QL+"`D9&ER96-T:6]N(#T@,"D*("`@
M('L*("`@("`@("`O*B!396QE8W0@:61S(&]R9&5R960@8GD@871T<FEB=71E
M('9A;'5E+B`J+PH@("`@("`@("1W:&5R92`]("<G.PH@("`@("`@(&EF("@A
M:7-?;G5L;"@D<V]R=&)Y7VYA;64I*2!["B`@("`@("`@("`@("1W:&5R92`]
M('-P<FEN=&8H)R!!3D0@871T<FEB=71E7VYA;64@/2`E<R`G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&(M/G%U;W1E*"1S;W)T
M8GE?;F%M92DI.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES7VYU;&PH)'-O
M<G1B>5]K97DI*2!["B`@("`@("`@("`@("1W:&5R92`]('-P<FEN=&8H)R5S
M($%.1"!A='1R:6)U=&5?:V5Y(#T@)7,@)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=VAE<F4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]D8BT^<75O=&4H)'-O<G1B>5]K97DI*3L*("`@("`@("!]
M"@H@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)U-%3$5#5"!D871A=')E95]I
M9"!&4D]-("5S(%=(15)%(&1A=&%T<F5E7VED($E.("@E<RD@)7,@3U)$15(@
M0ED@871T<FEB=71E7W9A;'5E("5S)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=T86)L95]A='1R:6)U=&5S)UTL"B`@("`@
M("`@("`@("`@("`@("`@("`@("!I;7!L;V1E*"<L)RP@)'5N;W)D97)E9%]I
M9',I+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'=H97)E+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@*"1D:7)E8W1I;VX@/3T@,2D@/R`G1$530R<@
M.B`G05-#)RD["@H@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E
M<GD@8GD@1&%T851R965?<W%L.CIS;W)T0GE!='1R:6)U=&5S*"DZ("<@+B`D
M<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@
M("`@("`@("1O<F1E<F5D7VED<R`]("1T:&ES+3Y?9&(M/F=E=$-O;"@D<75E
M<GDI.PH*("`@("`@("`O*B!-86ME('-U<F4@=&AA="!S;VUE(&ED<R!D:61N
M)W0@9V5T(&QO<W0@8F5C875S92!H87,@;F\@<W5C:`H@("`@("`@("`J(&%T
M=')I8G5T92!N86UE+VME>2X@07!P96YD('1H96T@=&\@=&AE(&5N9"X@*B\*
M("`@("`@("!I9B`H8V]U;G0H)&]R9&5R961?:61S*2`A/2!C;W5N="@D=6YO
M<F1E<F5D7VED<RDI('L*("`@("`@("`@("`@)&]R9&5R961?:61S(#T@87)R
M87E?=6YI<75E*&%R<F%Y7VUE<F=E*"1O<F1E<F5D7VED<RP@)'5N;W)D97)E
M9%]I9',I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;W)D97)E9%]I
M9',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@;&ES="!O9B!A
M;&P@;V8@=&AE(&%V86EL86)L92!V86QU97,@;V8@=&AE(&=I=F5N(&%T=')I
M8G5T90H@("`@("H@;F%M92]K97D@8V]M8FEN871I;VXN($5I=&AE<B!A='1R
M:6)U=&5?;F%M92!O<B!A='1R:6)U=&5?:V5Y($U54U0@8F4*("`@("`J('-U
M<'!L:65D+"!A;F0@8F]T:"!-05D@8F4@<W5P<&QI960N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@)&%T=')I8G5T95]N86UE("!4:&4@;F%M92!O
M9B!T:&4@871T<FEB=71E+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&%T=')I
M8G5T95]K97D@("!4:&4@:V5Y('9A;'5E(&]F('1H92!A='1R:6)U=&4N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("`D<&%R96YT("`@("`@("`@(%1H92!P87)E
M;G0@;F]D92!T;R!S=&%R="!S96%R8VAI;F<@9G)O;2X*("`@("`J($!P87)A
M;2!B;V]L96%N("1A;&Q,979E;',@("`@("`@4F5T=7)N(&%L;"!L979E;',L
M(&]R(&IU<W0@=&AE(&1I<F5C=`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!C:&EL9')E;B!O9B`D<&%R96YT/R!$969A=6QT<R!T
M;R!A;&P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M;&5V96QS+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y
M(&]F(&%L;"!O9B!T:&4@879A:6QA8FQE('9A;'5E<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T071T<FEB=71E5F%L=65S*"1A='1R:6)U=&5?;F%M92`]
M(&YU;&PL("1A='1R:6)U=&5?:V5Y(#T@;G5L;"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<&%R96YT(#T@1$%40512145?4D]/5"P@)&%L
M;$QE=F5L<R`]('1R=64I"B`@("!["B`@("`@("`@+R\@0G5I;&0@=&AE(&YA
M;64O:V5Y(&9I;'1E<BX*("`@("`@("`D=VAE<F4@/2`G)SL*("`@("`@("!I
M9B`H(6ES7VYU;&PH)&%T=')I8G5T95]N86UE*2D@>PH@("`@("`@("`@("`D
M=VAE<F4@+CT@)V$N871T<FEB=71E7VYA;64@/2`G("X@)'1H:7,M/E]D8BT^
M<75O=&4H)&%T=')I8G5T95]N86UE*3L*("`@("`@("!]"B`@("`@("`@:68@
M*"%I<U]N=6QL*"1A='1R:6)U=&5?:V5Y*2D@>PH@("`@("`@("`@("!I9B`H
M)'=H97)E*2!["B`@("`@("`@("`@("`@("`D=VAE<F4@+CT@)R!!3D0@)SL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D=VAE<F4@+CT@)V$N871T<FEB
M=71E7VME>2`]("<@+B`D=&AI<RT^7V1B+3YQ=6]T92@D871T<FEB=71E7VME
M>2D["B`@("`@("`@?0H*("`@("`@("`O+R!2971U<FX@:68@=V4@:&%V92!N
M;R!C<FET97)I82X*("`@("`@("!I9B`H(21W:&5R92D@>PH@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G;F\@8W)I=&5R:6$G*3L*("`@
M("`@("!]"@H@("`@("`@("\O($%D9"!F:6QT97)I;F<@8GD@<&%R96YT+"!A
M;F0@9F]R(&]N92!O<B!A;&P@;&5V96QS+@H@("`@("`@("1L979E;%%U97)Y
M(#T@)R<["B`@("`@("`@:68@*"1P87)E;G0@(3T@1$%40512145?4D]/5"D@
M>PH@("`@("`@("`@("`D<&%R=',@/2!E>'!L;V1E*"<Z)RP@)'!A<F5N="D[
M"B`@("`@("`@("`@("1P87)E;G1S(#T@)R<["B`@("`@("`@("`@("1P<W1R
M:6YG(#T@)R<["B`@("`@("`@("`@(&9O<F5A8V@@*"1P87)T<R!A<R`D<&%R
M="D@>PH@("`@("`@("`@("`@("`@)'!S=')I;F<@+CT@*&5M<'1Y*"1P<W1R
M:6YG*2`_("<G(#H@)SHG*2`N("1P87)T.PH@("`@("`@("`@("`@("`@)'!I
M9"`]("1T:&ES+3YG971)9"@D<'-T<FEN9RD["B`@("`@("`@("`@("`@("!I
M9B`H:7-?82@D<&ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1P:60["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`D<&%R96YT<R`N/2`G.B<@+B`D<&ED.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!I9B`H)&%L;$QE=F5L<RD@>PH@("`@("`@("`@("`@
M("`@)&QE=F5L475E<GD@/2!S<')I;G1F*"=!3D0@*&1A=&%T<F5E7W!A<F5N
M=',@/2`E<R!/4B!D871A=')E95]P87)E;G1S($Q)2T4@)7,I)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1B+3YQ
M=6]T92@D<&%R96YT<RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]D8BT^<75O=&4H)'!A<F5N=',@+B`G.B4G*2D[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D;&5V96Q1
M=65R>2`]('-P<FEN=&8H)T%.1"!D871A=')E95]P87)E;G1S(#T@)7,G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M9&(M/G%U;W1E*"1P87)E;G1S*2D["B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V5I9B`H(21A;&Q,979E;',I('L*("`@("`@("`@("`@)&QE=F5L475E
M<GD@/2`B04Y$(&1A=&%T<F5E7W!A<F5N=',@/2`G)R(["B`@("`@("`@?0H*
M("`@("`@("`O+R!"=6EL9"!T:&4@1E)/32]*3TE.(&-L875S97,N"B`@("`@
M("`@)&IO:6YS(#T@)TQ%1E0@2D])3B`G("X@)'1H:7,M/E]P87)A;7-;)W1A
M8FQE)UT@+@H@("`@("`@("`@("`G(&,@3TX@82YD871A=')E95]I9"`](&,N
M9&%T871R965?:60G.PH*("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=314Q%
M0U0@1$E35$E.0U0@82YA='1R:6)U=&5?=F%L=64@1E)/32`E<R!A("5S(%=(
M15)%(&,N9W)O=7!?=6ED(#T@)7,@04Y$("5S("5S)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L95]A='1R:6)U=&5S
M)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`D:F]I;G,L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7V1B+3YQ=6]T92@D=&AI<RT^7W!A
M<F%M<ULG9W)O=7`G72DL"B`@("`@("`@("`@("`@("`@("`@("`@("`D=VAE
M<F4L"B`@("`@("`@("`@("`@("`@("`@("`@("`D;&5V96Q1=65R>2D["@H@
M("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@1&%T851R
M965?<W%L.CIG971!='1R:6)U=&5686QU97,H*3H@)R`N("1Q=65R>2P@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("1R
M;W=S(#T@)'1H:7,M/E]D8BT^9V5T0V]L*"1Q=65R>2D["B`@("`@("`@:68@
M*&ES7V$H)')O=W,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R
M9&4Z.FQO9TUE<W-A9V4H)')O=W,L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!
M4E],3T=?15)2*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F]W<SL*
M("`@('T*"B`@("`O*BH*("`@("`J($)U:6QD<R!A;B!A='1R:6)U=&4@<75E
M<GDN($AE<F4@:7,@86X@97AA;7!L92`D8W)I=&5R:6$@87)R87DZ"B`@("`@
M*@H@("`@("H@/&-O9&4^"B`@("`@*B`D8W)I=&5R:6%;)T]2)UT@/2!A<G)A
M>2@*("`@("`J("`@("!A<G)A>2@G04Y$)R`]/B!A<G)A>2@*("`@("`J("`@
M("`@("`@87)R87DH)V9I96QD)R`]/B`G;F%M92<L"B`@("`@*B`@("`@("`@
M("`@("`@("=O<"<@("`@/3X@)STG+`H@("`@("H@("`@("`@("`@("`@("`G
M=&5S="<@(#T^("=F;V\G*2P*("`@("`J("`@("`@("`@87)R87DH)V9I96QD
M)R`]/B`G:V5Y)RP*("`@("`J("`@("`@("`@("`@("`@)V]P)R`@("`]/B`G
M/2<L"B`@("`@*B`@("`@("`@("`@("`@("=T97-T)R`@/3X@)V%B8R<I*2DL
M"B`@("`@*B`@("`@("`@(&%R<F%Y*"=!3D0G(#T^(&%R<F%Y*`H@("`@("H@
M("`@("`@("`@("`@87)R87DH)V9I96QD)R`]/B`G;F%M92<L"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`G;W`G("`@(#T^("<])RP*("`@("`J("`@("`@
M("`@("`@("`@("`@("=T97-T)R`@/3X@)V)A<B<I+`H@("`@("H@("`@("`@
M("`@("`@87)R87DH)V9I96QD)R`]/B`G:V5Y)RP*("`@("`J("`@("`@("`@
M("`@("`@("`@("=O<"<@("`@/3X@)STG+`H@("`@("H@("`@("`@("`@("`@
M("`@("`@)W1E<W0G("`]/B`G>'EZ)RDI*2D["B`@("`@*B`\+V-O9&4^"B`@
M("`@*@H@("`@("H@5&AI<R!W;W5L9"!F971C:"!A;&P@;V)J96-T(&ED<R!W
M:&5R92!A='1R:6)U=&4@;F%M92!I<R`B9F]O(B!!3D0@:V5Y"B`@("`@*B!I
M<R`B86)C(BP@3U(@(F)A<B(@04Y$(")X>7HB+@H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`@("1C<FET97)I82`@("`@5&AE(&%R<F%Y(&]F(&-R:71E
M<FEA+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'!A<F5N="`@("`@("!4:&4@
M<&%R96YT(&YO9&4@=&\@<W1A<G0@<V5A<F-H:6YG(&9R;VTN"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D86QL3&5V96QS("`@(%)E='5R;B!A;&P@;&5V96QS
M+"!O<B!J=7-T('1H92!D:7)E8W0*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8VAI;&1R96X@;V8@)'!A<F5N=#\@1&5F875L=',@=&\@
M86QL(&QE=F5L<RX*("`@("`J($!P87)A;2!S=')I;F<@("1R97-T<FEC="`@
M("`@3VYL>2!R971U<FX@871T<FEB=71E<R!W:71H('1H92!S86UE"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%T=')I8G5T95]N86UE
M(&]R(&%T=')I8G5T95]I9"X*("`@("`J($!P87)A;2!I;G1E9V5R("1O<&5R
M871I;VX@("`@5'EP92!O9B!Q=65R>2!T;R!B=6EL9`H@("`@("H@0'!A<F%M
M('-T<FEN9R`@)'-O<G1B>5]N86UE("!!='1R:6)U=&4@;F%M92!T;R!U<V4@
M9F]R('-O<G1I;F<N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<V]R=&)Y7VME
M>2`@($%T=')I8G5T92!K97D@=&\@=7-E(&9O<B!S;W)T:6YG+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&1I<F5C=&EO;B`@("!3;W)T(&1I<F5C=&EO;CH*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`P("T@87-C
M96YD:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M,2`M(&1E<V-E;F1I;F<*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!
M;B!344P@<75E<GD@86YD(&$@;&ES="!O9B!V86QU97,@<W5I=&%B;&4@9F]R
M(&)I;F1I;F<*("`@("`J("`@("`@("`@("`@("`@(&%S(&%N(&%R<F%Y+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!B=6EL9$%T=')I8G5T95%U97)Y*"1C<FET
M97)I82P@)'!A<F5N="`]($1!5$%44D5%7U)/3U0L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1A;&Q,979E;',@/2!T<G5E+"`D<F5S=')I
M8W0@/2`G;F%M92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1O<&5R871I;VX@/2!$051!5%)%15]"54E,1%]314Q%0U0L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1S;W)T8GE?;F%M92`](&YU;&PL
M("1S;W)T8GE?:V5Y(#T@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&1I<F5C=&EO;B`](#`I"B`@("!["B`@("`@("`@:68@*"%C
M;W5N="@D8W)I=&5R:6$I*2!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@G
M)RP@87)R87DH*2D["B`@("`@("`@?0H*("`@("`@("`O*B!"=6EL9"!T:&4@
M<75E<GDN("HO"B`@("`@("`@)'1H:7,M/E]T86)L94-O=6YT(#T@,3L*("`@
M("`@("`D<75E<GD@/2`G)SL*("`@("`@("`D=F%L=65S(#T@87)R87DH*3L*
M("`@("`@("!F;W)E86-H("@D8W)I=&5R:6$@87,@)&ME>2`]/B`D=F%L<RD@
M>PH@("`@("`@("`@("!I9B`H)&ME>2`]/2`G3U(G('Q\("1K97D@/3T@)T%.
M1"<I('L*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'%U97)Y*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1Q=65R>2`N/2`G("<@+B`D:V5Y("X@)R`G
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&)I;F1S(#T@
M)'1H:7,M/E]B=6EL9$%T=')I8G5T95%U97)Y*"1K97DL("1V86QS*3L*("`@
M("`@("`@("`@("`@("1Q=65R>2`N/2`G*"<@+B`D8FEN9'-;,%T@+B`G*2<[
M"B`@("`@("`@("`@("`@("`D=F%L=65S("L]("1B:6YD<ULQ73L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@061D(&9I;'1E<FEN9R!B
M>2!P87)E;G0L(&%N9"!F;W(@;VYE(&]R(&%L;"!L979E;',N"B`@("`@("`@
M)&QE=F5L475E<GD@/2`G)SL*("`@("`@("`D;&5V96Q686QU97,@/2!A<G)A
M>2@I.PH@("`@("`@(&EF("@D<&%R96YT("$]($1!5$%44D5%7U)/3U0I('L*
M("`@("`@("`@("`@)'!A<G1S(#T@97AP;&]D92@G.B<L("1P87)E;G0I.PH@
M("`@("`@("`@("`D<&%R96YT<R`]("<G.PH@("`@("`@("`@("`D<'-T<FEN
M9R`]("<G.PH@("`@("`@("`@("!F;W)E86-H("@D<&%R=',@87,@)'!A<G0I
M('L*("`@("`@("`@("`@("`@("1P<W1R:6YG("X]("AE;7!T>2@D<'-T<FEN
M9RD@/R`G)R`Z("<Z)RD@+B`D<&%R=#L*("`@("`@("`@("`@("`@("1P:60@
M/2`D=&AI<RT^9V5T260H)'!S=')I;F<I.PH@("`@("`@("`@("`@("`@:68@
M*&ES7V$H)'!I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`D<&ED.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@)'!A<F5N=',@+CT@)SHG("X@)'!I9#L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@:68@*"1A;&Q,979E;',I('L*("`@("`@("`@("`@("`@
M("1L979E;%%U97)Y(#T@)T%.1"`H9&%T871R965?<&%R96YT<R`](#\@3U(@
M9&%T871R965?<&%R96YT<R!,24M%(#\I)SL*("`@("`@("`@("`@("`@("1L
M979E;%9A;'5E<R`](&%R<F%Y*"1P87)E;G1S+"`D<&%R96YT<R`N("<Z)2<I
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&QE=F5L
M475E<GD@/2`G04Y$(&1A=&%T<F5E7W!A<F5N=',@/2`_)SL*("`@("`@("`@
M("`@("`@("1L979E;%9A;'5E<R`](&%R<F%Y*"1P87)E;G1S*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS96EF("@A)&%L;$QE=F5L<RD@>PH@("`@
M("`@("`@("`D;&5V96Q1=65R>2`](")!3D0@9&%T871R965?<&%R96YT<R`]
M("<G(CL*("`@("`@("!]"@H@("`@("`@("\O($)U:6QD('1H92!&4D]-+TI/
M24X@8VQA=7-E<RX*("`@("`@("`D:F]I;G,@/2!A<G)A>2@I.PH@("`@("`@
M("1P86ER<R`](&%R<F%Y*"D["B`@("`@("`@9F]R("@D:2`](#$[("1I(#P]
M("1T:&ES+3Y?=&%B;&5#;W5N=#L@)&DK*RD@>PH@("`@("`@("`@("`D:F]I
M;G-;72`]("=,1494($I/24X@)R`N("1T:&ES+3Y?<&%R86US6R=T86)L95]A
M='1R:6)U=&5S)UT@+@H@("`@("`@("`@("`@("`@)R!A)R`N("1I("X@)R!/
M3B!A)R`N("1I("X@)RYD871A=')E95]I9"`](&,N9&%T871R965?:60G.PH*
M("`@("`@("`@("`@:68@*"1I("$](#$I('L*("`@("`@("`@("`@("`@(&EF
M("@D<F5S=')I8W0@/3T@)VYA;64G*2!["B`@("`@("`@("`@("`@("`@("`@
M)'!A:7)S6UT@/2`G04Y$(&$Q+F%T=')I8G5T95]N86UE(#T@82<@+B`D:2`N
M("<N871T<FEB=71E7VYA;64G.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@
M*"1R97-T<FEC="`]/2`G:60G*2!["B`@("`@("`@("`@("`@("`@("`@)'!A
M:7)S6UT@/2`G04Y$(&$Q+F1A=&%T<F5E7VED(#T@82<@+B`D:2`N("<N9&%T
M871R965?:60G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`O+R!/=F5R<FED92!S;W)T:6YG+@H@("`@("`@
M("1S;W)T(#T@87)R87DH*3L*("`@("`@("!I9B`H(6ES7VYU;&PH)'-O<G1B
M>5]N86UE*2!\?"`A:7-?;G5L;"@D<V]R=&)Y7VME>2DI('L*("`@("`@("`@
M("`@)&]R9&5R7W1A8FQE(#T@)V$G("X@)&D["B`@("`@("`@("`@("1J;VEN
M<UM=(#T@)TQ%1E0@2D])3B`G("X@)'1H:7,M/E]P87)A;7-;)W1A8FQE7V%T
M=')I8G5T97,G72`N"B`@("`@("`@("`@("`@("`G("<@+B`D;W)D97)?=&%B
M;&4@+B`G($].("<@+B`D;W)D97)?=&%B;&4@+@H@("`@("`@("`@("`@("`@
M)RYD871A=')E95]I9"`](&,N9&%T871R965?:60G.PH*("`@("`@("`@("`@
M:68@*"%I<U]N=6QL*"1S;W)T8GE?;F%M92DI('L*("`@("`@("`@("`@("`@
M("1P86ER<UM=(#T@<W!R:6YT9B@G04Y$("5S+F%T=')I8G5T95]N86UE(#T@
M/R`G+"`D;W)D97)?=&%B;&4I.PH@("`@("`@("`@("`@("`@)'-O<G1;72`]
M("1S;W)T8GE?;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M(6ES7VYU;&PH)'-O<G1B>5]K97DI*2!["B`@("`@("`@("`@("`@("`D<&%I
M<G-;72`]('-P<FEN=&8H)T%.1"`E<RYA='1R:6)U=&5?:V5Y(#T@/R`G+"`D
M;W)D97)?=&%B;&4I.PH@("`@("`@("`@("`@("`@)'-O<G1;72`]("1S;W)T
M8GE?:V5Y.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D;W)D97(@/2!S
M<')I;G1F*"<E<RYA='1R:6)U=&5?=F%L=64@)7,G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1O<F1E<E]T86)L92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`H)&1I<F5C=&EO;B`]/2`Q*2`_("=$15-#)R`Z("=!
M4T,G*3L*("`@("`@("`@("`@)&=R;W5P7V)Y(#T@)V,N9&%T871R965?:60L
M(&,N9&%T871R965?;F%M92P@8RYD871A=')E95]O<F1E<BP@)R`N"B`@("`@
M("`@("`@("`@("`D;W)D97)?=&%B;&4@+B`G+F%T=')I8G5T95]V86QU92<[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&]R9&5R(#T@)V,N9&%T
M871R965?;W)D97(L(&,N9&%T871R965?;F%M92P@8RYD871A=')E95]I9"<[
M"B`@("`@("`@("`@("1G<F]U<%]B>2`]("=C+F1A=&%T<F5E7VED+"!C+F1A
M=&%T<F5E7VYA;64L(&,N9&%T871R965?;W)D97(G.PH@("`@("`@('T*"B`@
M("`@("`@)&IO:6YS(#T@:6UP;&]D92@G("<L("1J;VEN<RD["B`@("`@("`@
M)'!A:7)S(#T@:6UP;&]D92@G("<L("1P86ER<RD["B`@("`@("`@)'1A:6P@
M/2!S<')I;G1F*"='4D]54"!"62`E<R!/4D1%4B!"62`E<R<L("1G<F]U<%]B
M>2P@)&]R9&5R*3L*"B`@("`@("`@<W=I=&-H("@D;W!E<F%T:6]N*2!["B`@
M("`@("`@8V%S92!$051!5%)%15]"54E,1%]#3U5.5#H*("`@("`@("`@("`@
M)'=H870@/2`G0T]53E0H1$E35$E.0U0@8RYD871A=')E95]I9"DG.PH@("`@
M("`@("`@("`D=&%I;"`]("<G.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@9&5F875L=#H*("`@("`@("`@("`@)'=H870@/2`G8RYD871A=')E95]I
M9"P@8RYD871A=')E95]N86UE)SL*("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@87)R87DH<W!R:6YT9B@G4T5,14-4("5S
M($923TT@)7,@8R`E<R!72$5212!C+F=R;W5P7W5I9"`](#\@04Y$("5S("5S
M("5S("5S)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=VAA="P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG
M=&%B;&4G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:F]I;G,L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'%U97)Y+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1L979E;%%U97)Y+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1P86ER<RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&%I;"DL"B`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M7VUE<F=E*&%R<F%Y*"1T:&ES+3Y?<&%R86US6R=G<F]U<"==*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E<RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&QE=F5L5F%L=65S+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<V]R="DI.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0G5I;&1S(&$@<&EE8V4@;V8@86X@871T<FEB=71E('%U
M97)Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&=L=64@("`@(%1H
M92!G;'5E('1O(&IO:6X@=&AE(&-R:71E<FEA("A/4B]!3D0I+@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1C<FET97)I82`@5&AE(&%R<F%Y(&]F(&-R:71E<FEA
M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&IO:6X@("`@4VAO=6QD('=E(&IO
M:6X@;VX@82!C;&5A;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M:&]R9&5?9&%T871R965?871T<FEB=71E<R!T86)L93\@1&5F875L=',@=&\*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&9A;'-E+@H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@($%N(%-13"!F<F%G;65N="!A;F0@82!L
M:7-T(&]F('9A;'5E<R!S=6ET86)L92!F;W(@8FEN9&EN9PH@("`@("H@("`@
M("`@("`@("`@("`@87,@86X@87)R87DN"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]B=6EL9$%T=')I8G5T95%U97)Y*"1G;'5E+"`D8W)I=&5R:6$L("1J;VEN
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]3
M44PN<&AP)SL*"B`@("`@("`@+R\@26YI=&EA;&EZ92!T:&4@8VQA=7-E('1H
M870@=V4G<F4@8G5I;&1I;F<N"B`@("`@("`@)&-L875S92`]("<G.PH@("`@
M("`@("1V86QU97,@/2!A<G)A>2@I.PH*("`@("`@("`O+R!'970@=&AE('1A
M8FQE(&%L:6%S('1O('5S92!F;W(@=&AI<R!S970@;V8@8W)I=&5R:6$N"B`@
M("`@("`@)&%L:6%S(#T@)'1H:7,M/E]G971!;&EA<R@D:F]I;BD["@H@("`@
M("`@(&9O<F5A8V@@*"1C<FET97)I82!A<R`D:V5Y(#T^("1V86QS*2!["B`@
M("`@("`@("`@(&EF("@A96UP='DH)&-L875S92DI('L*("`@("`@("`@("`@
M("`@("1C;&%U<V4@+CT@)R`G("X@)&=L=64@+B`G("<["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@:68@*"%E;7!T>2@D=F%L<ULG3U(G72D@?'P@(65M
M<'1Y*"1V86QS6R=!3D0G72DI('L*("`@("`@("`@("`@("`@("1B:6YD<R`]
M("1T:&ES+3Y?8G5I;&1!='1R:6)U=&51=65R>2@D9VQU92P@)'9A;',I.PH@
M("`@("`@("`@("`@("`@)&-L875S92`N/2`G*"<@+B`D8FEN9'-;,%T@+B`G
M*2<["B`@("`@("`@("`@("`@("`D=F%L=65S(#T@87)R87E?;65R9V4H)'9A
M;'5E<RP@)&)I;F1S6S%=*3L*("`@("`@("`@("`@?2!E;'-E:68@*"%E;7!T
M>2@D=F%L<ULG2D])3B==*2D@>PH@("`@("`@("`@("`@("`@)&)I;F1S(#T@
M)'1H:7,M/E]B=6EL9$%T=')I8G5T95%U97)Y*"1G;'5E+"`D=F%L<ULG2D])
M3B==+"!T<G5E*3L*("`@("`@("`@("`@("`@("1C;&%U<V4@+CT@)&)I;F1S
M6S!=.PH@("`@("`@("`@("`@("`@)'9A;'5E<R`](&%R<F%Y7VUE<F=E*"1V
M86QU97,L("1B:6YD<ULQ72D["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)'9A;'-;)V9I96QD)UTI*2!["B`@("`@
M("`@("`@("`@("`@("`@)&)I;F1S(#T@2&]R9&5?4U%,.CIB=6EL9$-L875S
M92@D=&AI<RT^7V1B+"`D86QI87,@+B`G+F%T=')I8G5T95\G("X@)'9A;'-;
M)V9I96QD)UTL("1V86QS6R=O<"==+"`D=F%L<ULG=&5S="==+"!T<G5E*3L*
M("`@("`@("`@("`@("`@("`@("`D8VQA=7-E("X]("1B:6YD<ULP73L*("`@
M("`@("`@("`@("`@("`@("`D=F%L=65S(#T@87)R87E?;65R9V4H)'9A;'5E
M<RP@)&)I;F1S6S%=*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@)&)I;F1S(#T@)'1H:7,M/E]B=6EL9$%T=')I8G5T
M95%U97)Y*"1K97DL("1V86QS*3L*("`@("`@("`@("`@("`@("`@("`D8VQA
M=7-E("X]("1B:6YD<ULP73L*("`@("`@("`@("`@("`@("`@("`D=F%L=65S
M(#T@87)R87E?;65R9V4H)'9A;'5E<RP@)&)I;F1S6S%=*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N(&%R<F%Y*"1C;&%U<V4L("1V86QU97,I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1V5T(&%N(&%L:6%S('1O(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T
M97,L(&EN8W)E;65N=&EN9R!I="!I9@H@("`@("H@;F5C97-S87)Y+@H@("`@
M("H*("`@("`J($!P87)A;2!B;V]L96%N("1I;F-R96UE;G0@($EN8W)E;65N
M="!T:&4@86QI87,@8V]U;G0_($1E9F%U;'1S('1O(&YO+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?9V5T06QI87,H)&EN8W)E;65N="`](&9A;'-E*0H@("`@
M>PH@("`@("`@('-T871I8R`D<V5E;B`](&%R<F%Y*"D["@H@("`@("`@(&EF
M("@D:6YC<F5M96YT("8F("%E;7!T>2@D<V5E;ELD=&AI<RT^7W1A8FQE0V]U
M;G1=*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W1A8FQE0V]U;G0K*SL*("`@
M("`@("!]"@H@("`@("`@("1S965N6R1T:&ES+3Y?=&%B;&5#;W5N=%T@/2!T
M<G5E.PH@("`@("`@(')E='5R;B`G82<@+B`D=&AI<RT^7W1A8FQE0V]U;G0[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!5<&1A=&4@=&AE(&1A=&$@:6X@86X@
M;V)J96-T+B!$;V5S(&YO="!C:&%N9V4@=&AE(&]B:F5C="=S"B`@("`@*B!P
M87)E;G0@;W(@;F%M92P@:G5S="!S97)I86QI>F5D(&1A=&$@;W(@871T<FEB
M=71E<RX*("`@("`J"B`@("`@*B!`<&%R86T@1&%T851R964@)&]B:F5C="`@
M02!$871A5')E92!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N('5P9&%T
M941A=&$H)&]B:F5C="D*("`@('L*("`@("`@("!I9B`H(6ES7V$H)&]B:F5C
M="P@)T1A=&%4<F5E3V)J96-T)RDI('L*("`@("`@("`@("`@+RH@3F]T:&EN
M9R!T;R!D;R!F;W(@;F]N(&]B:F5C=',N("HO"B`@("`@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@+RH@1V5T('1H92!O8FIE8W0@
M:60N("HO"B`@("`@("`@)&ED(#T@)'1H:7,M/F=E=$ED*"1O8FIE8W0M/F=E
M=$YA;64H*2D["B`@("`@("`@:68@*&ES7V$H)&ED+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D:60["B`@("`@("`@?0H*("`@("`@
M("`O*B!3964@:68@=V4@8V%N(&)R96%K('1H92!O8FIE8W0@;W5T('1O(&1A
M=&%T<F5E7V%T=')I8G5T97,@=&%B;&4N("HO"B`@("`@("`@:68@*&UE=&AO
M9%]E>&ES=',H)&]B:F5C="P@)U]T;T%T=')I8G5T97,G*2D@>PH@("`@("`@
M("`@("`O*B!)9B!W92!C86XL(&-L96%R(&]U="!T:&4@9&%T871R965?9&%T
M82!F:65L9"!T;R!M86ME('-U<F4@:70*("`@("`@("`@("`@("H@9&]E<VXG
M="!G970@<&EC:V5D('5P(&)Y(&=E=$1A=&$H*2X@26YT96YT:6]N86QL>2!D
M;VXG="!C:&5C:PH@("`@("`@("`@("`@*B!F;W(@97)R;W)S(&AE<F4@:6X@
M8V%S92!D871A=')E95]D871A(&=O97,@87=A>2!I;B!T:&4*("`@("`@("`@
M("`@("H@9G5T=7)E+B`J+PH@("`@("`@("`@("`D<75E<GD@/2`G55!$051%
M("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`N"B`@("`@("`@("`@("`@
M("`@("`@("<@4T54(&1A=&%T<F5E7V1A=&$@/2`_(%=(15)%(&1A=&%T<F5E
M7VED(#T@/R<["B`@("`@("`@("`@("1V86QU97,@/2!A<G)A>2A.54Q,+"`H
M:6YT*21I9"D["@H@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,
M(%%U97)Y(&)Y($1A=&%4<F5E7W-Q;#HZ=7!D871E1&%T82@I.B`G("X@)'%U
M97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@
M("`@("`@("`@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*
M"B`@("`@("`@("`@("\J(%-T87)T(&$@=')A;G-A8W1I;VXN("HO"B`@("`@
M("`@("`@("1T:&ES+3Y?9&(M/F%U=&]#;VUM:70H9F%L<V4I.PH*("`@("`@
M("`@("`@+RH@1&5L971E(&]L9"!A='1R:6)U=&5S+B`J+PH@("`@("`@("`@
M("`D<75E<GD@/2`G1$5,151%($923TT@)R`N("1T:&ES+3Y?<&%R86US6R=T
M86)L95]A='1R:6)U=&5S)UT@+@H@("`@("`@("`@("`@("`@("`@("`G(%=(
M15)%(&1A=&%T<F5E7VED(#T@/R<["B`@("`@("`@("`@("1V86QU97,@/2!A
M<G)A>2@H:6YT*21I9"D["@H@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G
M92@G4U%,(%%U97)Y(&)Y($1A=&%4<F5E7W-Q;#HZ=7!D871E1&%T82@I.B`G
M("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'
M*3L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q
M=65R>2P@)'9A;'5E<RD["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?9&(M
M/G)O;&QB86-K*"D["B`@("`@("`@("`@("`@("`D=&AI<RT^7V1B+3YA=71O
M0V]M;6ET*'1R=64I.PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($=E="!T:&4@;F5W(&%T
M=')I8G5T92!S970L(&%N9"!I;G-E<G0@96%C:"!I;G1O('1H92!$0BX@268*
M("`@("`@("`@("`@("H@86YY=&AI;F<@9F%I;',@:6X@:&5R92P@<F]L;&)A
M8VL@=&AE('1R86YS86-T:6]N+"!R971U<FX@=&AE"B`@("`@("`@("`@("`J
M(')E;&5V86YT(&5R<F]R+"!A;F0@8F%I;"!O=70N("HO"B`@("`@("`@("`@
M("1A='1R:6)U=&5S(#T@)&]B:F5C="T^7W1O071T<FEB=71E<R@I.PH@("`@
M("`@("`@("`D<75E<GD@/2`G24Y315)4($E.5$\@)R`N("1T:&ES+3Y?<&%R
M86US6R=T86)L95]A='1R:6)U=&5S)UT@+@H@("`@("`@("`@("`@("`@("`@
M("`G("AD871A=')E95]I9"P@871T<FEB=71E7VYA;64L(&%T=')I8G5T95]K
M97DL(&%T=')I8G5T95]V86QU92DG("X*("`@("`@("`@("`@("`@("`@("`@
M)R!604Q515,@*#\L(#\L(#\L(#\I)SL*("`@("`@("`@("`@)'-T871E;65N
M="`]("1T:&ES+3Y?9&(M/G!R97!A<F4H)'%U97)Y*3L*("`@("`@("`@("`@
M9F]R96%C:"`H)&%T=')I8G5T97,@87,@)&%T='(I('L*("`@("`@("`@("`@
M("`@("1V86QU97,@/2!A<G)A>2@H:6YT*21I9"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D871T<ELG;F%M92==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1A='1R6R=K97DG72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1A
M='1R6R=V86QU92==+"!.3%,Z.F=E=$-H87)S970H*2P@)'1H:7,M/E]P87)A
M;7-;)V-H87)S970G72DI.PH*("`@("`@("`@("`@("`@($AO<F1E.CIL;V=-
M97-S86=E*"=344P@475E<GD@8GD@1&%T851R965?<W%L.CIU<&1A=&5$871A
M*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?
M1$5"54<I.PH*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B
M+3YE>&5C=71E*"1S=&%T96UE;G0L("1V86QU97,I.PH@("`@("`@("`@("`@
M("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?9&(M/G)O;&QB86-K*"D["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]D8BT^875T;T-O;6UI="AT<G5E*3L*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@0V]M;6ET('1H
M92!T<F%N<V%C=&EO;BP@86YD('1U<FX@875T;V-O;6UI="!B86-K(&]N+B`J
M+PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^8V]M;6ET*"D[
M"B`@("`@("`@("`@("1T:&ES+3Y?9&(M/F%U=&]#;VUM:70H=')U92D["@H@
M("`@("`@("`@("!R971U<FX@:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M(#\@)')E<W5L="`Z('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@+RH@5W)I=&4@=&\@=&AE(&1A=&%T<F5E7V1A=&$@9FEE;&0N("HO"B`@
M("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O4V5R:6%L:7IE+G!H<"<[
M"B`@("`@("`@("`@("1S97(@/2!315))04Q)6D5?551&-U]"05-)0SL*("`@
M("`@("`@("`@)&1A=&$@/2!(;W)D95]397)I86QI>F4Z.G-E<FEA;&EZ92@D
M;V)J96-T+3YG971$871A*"DL("1S97(L($Y,4SHZ9V5T0VAA<G-E="@I*3L*
M"B`@("`@("`@("`@("1Q=65R>2`]("=54$1!5$4@)R`N("1T:&ES+3Y?<&%R
M86US6R=T86)L92==("X*("`@("`@("`@("`@("`@("`@("`@)R!3150@9&%T
M871R965?9&%T82`](#\L(&1A=&%T<F5E7W-E<FEA;&EZ960@/2`_)R`N"B`@
M("`@("`@("`@("`@("`@("`@("<@5TA%4D4@9&%T871R965?:60@/2`_)SL*
M("`@("`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"1D871A+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@*&EN="DD<V5R+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@*&EN="DD:60I.PH*("`@("`@("`@("`@2&]R9&4Z.FQO
M9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ.G5P9&%T941A
M=&$H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/
M1U]$14)51RD["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ
M=65R>2@D<75E<GDL("1V86QU97,I.PH*("`@("`@("`@("`@<F5T=7)N(&ES
M7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2`_("1R97-U;'0@.B!T<G5E.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(&]P
M96X@82!C;VYN96-T:6]N('1O('1H92!344P@<V5R=F5R+@H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@5')U92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V-O;FYE8W0H*0H@("`@>PH@("`@("`@($AO<F1E.CIA<W-E<G1$<FEV
M97)#;VYF:6<H)'1H:7,M/E]P87)A;7,L("=S=&]R86=E)RP*("`@("`@("`@
M("`@87)R87DH)W!H<'1Y<&4G+"`G8VAA<G-E="<I+`H@("`@("`@("`@("`G
M1&%T851R964@4U%,)RD["@H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P
M87)A;7-;)V1A=&%B87-E)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=D871A8F%S92==(#T@)R<["B`@("`@("`@?0H@("`@("`@(&EF("@A
M:7-S970H)'1H:7,M/E]P87)A;7-;)W5S97)N86UE)UTI*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=U<V5R;F%M92==(#T@)R<["B`@("`@("`@
M?0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D
M)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=P87-S=V]R9"==
M(#T@)R<["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P
M87)A;7-;)VAO<W1S<&5C)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=H;W-T<W!E8R==(#T@)R<["B`@("`@("`@?0H@("`@("`@(&EF("@A
M:7-S970H)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=T86)L92==(#T@)VAO<F1E7V1A=&%T<F5E)SL*
M("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG
M=&%B;&5?871T<FEB=71E<R==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A
M<F%M<ULG=&%B;&5?871T<FEB=71E<R==(#T@)VAO<F1E7V1A=&%T<F5E7V%T
M=')I8G5T97,G.PH@("`@("`@('T*"B`@("`@("`@+RH@0V]N;F5C="!T;R!T
M:&4@4U%,('-E<G9E<B!U<VEN9R!T:&4@<W5P<&QI960@<&%R86UE=&5R<RX@
M*B\*("`@("`@("!R97%U:7)E7V]N8V4@)T1"+G!H<"<["B`@("`@("`@)'1H
M:7,M/E]D8B`]("9$0CHZ8V]N;F5C="@D=&AI<RT^7W!A<F%M<RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=P97)S:7-T96YT
M)R`]/B`A96UP='DH)'1H:7,M/E]P87)A;7-;)W!E<G-I<W1E;G0G72DI*3L*
M("`@("`@("!I9B`H:7-?82@D=&AI<RT^7V1B+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@($AO<F1E.CIF871A;"@D=&AI<RT^7V1B+"!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@+R\@4V5T($1"('!O
M<G1A8FEL:71Y(&]P=&EO;G,*("`@("`@("!S=VET8V@@*"1T:&ES+3Y?9&(M
M/G!H<'1Y<&4I('L*("`@("`@("!C87-E("=M<W-Q;"<Z"B`@("`@("`@("`@
M("1T:&ES+3Y?9&(M/G-E=$]P=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]03U)4
M04))3$E465],3U=%4D-!4T4@?"!$0E]03U)404))3$E465]%4E)/4E,@?"!$
M0E]03U)404))3$E465]25%))32D["B`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("1T:&ES+3Y?9&(M/G-E=$]P=&EO
M;B@G<&]R=&%B:6QI='DG+"!$0E]03U)404))3$E465],3U=%4D-!4T4@?"!$
M0E]03U)404))3$E465]%4E)/4E,I.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O1&%T851R964O;G5L;"YP:'``````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,C<S-S<@,3`U,34T,S,W
M,S<@,#(R-30V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!4:&4@1&%T851R965?;G5L;#HZ(&-L87-S
M('!R;W9I9&5S(&$@9'5M;7D@:6UP;&5M96YT871I;VX@;V8@=&AE"B`J($1A
M=&%4<F5E.CH@05!).R!N;R!D871A('=I;&P@;&%S="!B97EO;F0@82!S:6YG
M;&4@<&%G92!R97%U97-T+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]$871A
M5')E92]$871A5')E92]N=6QL+G!H<"QV(#$N,34N,BXT(#(P,#4O,3`O,3@@
M,3$Z,#$Z,#4@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+"`R,#`P
M+"`R,#`Q+"`R,#`R(%-T97!H86YE($AU=&AE<B`\<VAU=&AE<D!B:6=F;V]T
M+F-O;3X*("H@0V]P>7)I9VAT(#(P,#$L(#(P,#(@0VAU8VL@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC
M92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]$871A5')E90H@*B\*
M8VQA<W,@1&%T851R965?;G5L;"!E>'1E;F1S($1A=&%4<F5E('L*"B`@("`O
M*BH*("`@("`J($-A8VAE(&]F(&%T=')I8G5T97,@9F]R(&%N>2!O8FIE8W1S
M(&-R96%T960@9'5R:6YG('1H:7,@<&%G92!R97%U97-T+@H@("`@("H*("`@
M("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?871T<FEB=71E0V%C
M:&4@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0V%C:&4@;V8@9&%T82!F
M;W(@86YY(&]B:F5C=',@8W)E871E9"!D=7)I;F<@=&AI<R!P86=E(')E<75E
M<W0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@
M)%]D871A0V%C:&4@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@3&]A9"`H
M82!S=6)S970@;V8I('1H92!D871A=')E92!I;G1O('1H92`D7V1A=&$@87)R
M87DN(%!A<G0@;V8@=&AE"B`@("`@*B!$871A5')E92!!4$D@=&AA="!M=7-T
M(&)E(&]V97)R:61D96X@8GD@<W5B8VQA<W-E<RX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`D<F]O="`@("!7:&EC:"!P;W)T:6]N(&]F('1H92!T
M<F5E('1O(&QO860N($1E9F%U;'1S('1O"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("!A;&P@;V8@:70N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M<F5L;V%D("!292UL;V%D(&%L<F5A9'D@;&]A9&5D('9A;'5E<S\*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!0
M14%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]L;V%D*"1R;V]T(#T@;G5L
M;"P@)')E;&]A9"`](&9A;'-E*0H@("`@>PH@("`@?0H*("`@("\J*@H@("`@
M("H@3&]A9"!A('-P96-I9FEC(&]B:F5C="!I9&5N=&EF:65D(&)Y(&ET<R!U
M;FEQ=64@240@*"1I9"DL(&%N9`H@("`@("H@:71S('!A<F5N=',L(&EN=&\@
M=&AE("1?9&%T82!A<G)A>2X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D8VED("!4:&4@=6YI<75E($E$(&]F('1H92!O8FIE8W0@=&\@;&]A9"X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@
M;W(@82!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]L;V%D0GE)9"@D
M8VED*0H@("`@>PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T(&$@=')E92!S
M;W)T960@8GD@=&AE('-P96-I9FEE9"!A='1R:6)U=&4@;F%M92!A;F0O;W(@
M:V5Y+@H@("`@("H*("`@("`J($!S:6YC92!(;W)D92`S+C$*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("`D<F]O="`@("`@("!7:&EC:"!P;W)T:6]N
M(&]F('1H92!T<F5E('1O('-O<G0N"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!$969A=6QT<R!T;R!A;&P@;V8@:70N"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D;&]A9%1R964@("!3;W)T('1H92!T<F5E('-T87)T:6YG
M(&%T("1R;V]T+"!O<B!J=7-T('1H90H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<F5Q=65S=&5D(&QE=F5L(&%N9"!D:7)E8W0@<&%R96YT
M<S\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@($1E9F%U;'1S
M('1O('-I;F=L92!L979E;"X*("`@("`J($!P87)A;2!A<G)A>2`D<V]R=&)Y
M7VYA;64@($%T=')I8G5T92!N86UE('1O('5S92!F;W(@<V]R=&EN9RX*("`@
M("`J($!P87)A;2!A<G)A>2`D<V]R=&)Y7VME>2`@($%T=')I8G5T92!K97D@
M=&\@=7-E(&9O<B!S;W)T:6YG+@H@("`@("H@0'!A<F%M(&%R<F%Y("1D:7)E
M8W1I;VX@("`@4V]R="!D:7)E8W1I;VXZ"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#`@+2!A<V-E;F1I;F<*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@,2`M(&1E<V-E;F1I;F<*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T4V]R=&5D5')E92@D<F]O="P@)&QO8614<F5E(#T@
M9F%L<V4L("1S;W)T8GE?;F%M92`](&YU;&PL("1S;W)T8GE?:V5Y(#T@;G5L
M;"P@)&1I<F5C=&EO;B`](#`I"B`@("!["B`@("`@("`@<F5T=7)N(&%R<F%Y
M*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@86X@;V)J96-T+B!087)T
M(&]F('1H92!$871A5')E92!!4$D@=&AA="!M=7-T(&)E"B`@("`@*B!O=F5R
M<FED9&5N(&)Y('-U8F-L87-S97,N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI
M>&5D("1F=6QL;F%M92`@5&AE(&]B:F5C="!T;R!A9&0@*'-T<FEN9R!O<B!$
M871A5')E94]B:F5C="DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9"@D;V)J
M96-T*0H@("`@>PH@("`@("`@(&EF("AI<U]A*"1O8FIE8W0L("=$871A5')E
M94]B:F5C="<I*2!["B`@("`@("`@("`@("1F=6QL;F%M92`]("1O8FIE8W0M
M/F=E=$YA;64H*3L*("`@("`@("`@("`@)&]R9&5R(#T@)&]B:F5C="T^;W)D
M97(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&9U;&QN86UE(#T@
M)&]B:F5C=#L*("`@("`@("`@("`@)&]R9&5R(#T@;G5L;#L*("`@("`@("!]
M"@H@("`@("`@("1I9"`](&UD-2AM=%]R86YD*"DI.PH@("`@("`@(&EF("AS
M=')P;W,H)&9U;&QN86UE+"`G.B<I("$]/2!F86QS92D@>PH@("`@("`@("`@
M("`D<&%R=',@/2!E>'!L;V1E*"<Z)RP@)&9U;&QN86UE*3L*("`@("`@("`@
M("`@)&YA;64@/2!A<G)A>5]P;W`H)'!A<G1S*3L*("`@("`@("`@("`@)'!A
M<F5N="`](&EM<&QO9&4H)SHG+"`D<&%R=',I.PH@("`@("`@("`@("`D<&ED
M(#T@)'1H:7,M/F=E=$ED*"1P87)E;G0I.PH@("`@("`@("`@("!I9B`H:7-?
M82@D<&ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^861D*"1P87)E;G0I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'!I9"`]($1!5$%44D5%7U)/3U0["B`@("`@("`@
M?0H*("`@("`@("!I9B`H<&%R96YT.CIE>&ES=',H)&9U;&QN86UE*2D@>PH@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G06QR96%D>2!E
M>&ES=',G*3L*("`@("`@("!]"@H@("`@("`@("1A9&1E9"`]('!A<F5N=#HZ
M7V%D9"@D9G5L;&YA;64L("1I9"P@)'!I9"P@)&]R9&5R*3L*("`@("`@("!I
M9B`H:7-?82@D861D960L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1A9&1E9#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES
M+3YU<&1A=&5$871A*"1O8FIE8W0I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0VAA;F=E(&]R9&5R(&]F('1H92!C:&EL9')E;B!O9B!A;B!O8FIE8W0N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%R96YT<R`@5&AE('!A<F5N
M="!I9"!S=')I;F<@<&%T:"X*("`@("`J($!P87)A;2!M:7AE9"`D;W)D97(@
M("`@($$@<W!E8VEF:6,@;F5W(&]R9&5R('!O<VET:6]N(&]R(&%N(&%R<F%Y
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT86EN:6YG('1H
M92!N97<@<&]S:71I;VYS(&9O<B!T:&4@9VEV96X*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("1P87)E;G1S(&]B:F5C="X*("`@("`J($!P87)A
M;2!I;G1E9V5R("1C:60@("`@($EF('!R;W9I9&5D(&EN9&EC871E<R!I;G-E
M<G1I;VX@;V8@82!N97<@8VAI;&0*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@('1O('1H92!O8FIE8W0L(&%N9"!W:6QL(&)E('5S960@=&\@879O
M:60*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&EN8W)E;65N=&EN
M9R!I="!W:&5N('-H:69T:6YG('5P(&%L;"!O=&AE<@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@8VAI;&1R96XG<R!O<F1E<BX@268@;F]T('!R
M;W9I9&5D(&EN9&EC871E<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@9&5L971I;VXL(&AE;F-E('-H:69T(&%L;"!O=&AE<B!P;W-I=&EO;G,@
M9&]W;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@;VYE+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!R96]R9&5R*"1P87)E;G1S+"`D;W)D97(@/2!N
M=6QL+"`D8VED(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH
M)&]R9&5R*2`F)B`A96UP='DH)&]R9&5R*2D@>PH@("`@("`@("`@("`O+R!-
M=6QT:2!U<&1A=&4N"B`@("`@("`@("`@("1T:&ES+3Y?<F5O<F1E<B@D<&ED
M+"`D;W)D97(I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($5X
M<&QI8VET;'D@<V5T('1H92!O<F1E<B!F;W(@82!D871A=')E92!O8FIE8W0N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&ED("`@("!4:&4@9&%T
M871R964@;V)J96-T(&ED('1O(&-H86YG92X*("`@("`J($!P87)A;2!I;G1E
M9V5R("1O<F1E<B`@5&AE(&YE=R!O<F1E<BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@<V5T3W)D97(H)&ED+"`D;W)D97(I"B`@("!["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!296UO=F5S(&%N(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R
M86T@;6EX960@("`D;V)J96-T("!4:&4@;V)J96-T('1O(')E;6]V92X*("`@
M("`J($!P87)A;2!B;V]L96%N("1F;W)C92`@($9O<F-E(')E;6]V86P@;V8@
M979E<GD@8VAI;&0@;V)J96-T/PH@("`@("HO"B`@("!F=6YC=&EO;B!R96UO
M=F4H)&]B:F5C="P@)&9O<F-E(#T@9F%L<V4I"B`@("!["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!296UO=F4@;VYE(&]R(&UO<F4@;V)J96-T<R!B>2!I9"X@
M5&AI<R!F=6YC=&EO;B!D;V5S("IN;W0J(&1O"B`@("`@*B!T:&4@=F%L:61A
M=&EO;BP@<F5O<F1E<FEN9RP@971C+B!T:&%T(')E;6]V92@I(&1O97,N($EF
M('EO=0H@("`@("H@;F5E9"!T;R!C:&5C:R!F;W(@8VAI;&1R96XL(')E+61O
M(&]R9&5R:6YG+"!E=&,N+"!T:&5N('EO=2!M=7-T"B`@("`@*B!R96UO=F4H
M*2!O8FIE8W1S(&]N92UB>2UO;F4N(%1H:7,@:7,@9F]R(&-O9&4@=&AA="!K
M;F]W<R!I="=S"B`@("`@*B!D96%L:6YG('=I=&@@<VEN9VQE("AN;VXM<&%R
M96YT960I(&]B:F5C=',@86YD(&YE961S('1O(&1E;&5T90H@("`@("H@82!B
M871C:"!O9B!T:&5M('%U:6-K;'DN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1I9',@(%1H92!O8FIE8W1S('1O(')E;6]V92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<F5M;W9E0GE)9',H)&ED<RD*("`@('L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E;6]V92!O;F4@;W(@;6]R92!O8FIE8W1S(&)Y(&YA;64N
M(%1H:7,@9G5N8W1I;VX@9&]E<R`J;F]T*B!D;PH@("`@("H@=&AE('9A;&ED
M871I;VXL(')E;W)D97)I;F<L(&5T8RX@=&AA="!R96UO=F4H*2!D;V5S+B!)
M9B!Y;W4*("`@("`J(&YE960@=&\@8VAE8VL@9F]R(&-H:6QD<F5N+"!R92UD
M;R!O<F1E<FEN9RP@971C+BP@=&AE;B!Y;W4@;75S=`H@("`@("H@<F5M;W9E
M*"D@;V)J96-T<R!O;F4M8GDM;VYE+B!4:&ES(&ES(&9O<B!C;V1E('1H870@
M:VYO=W,@:70G<PH@("`@("H@9&5A;&EN9R!W:71H('-I;F=L92`H;F]N+7!A
M<F5N=&5D*2!O8FIE8W1S(&%N9"!N965D<R!T;R!D96QE=&4*("`@("`J(&$@
M8F%T8V@@;V8@=&AE;2!Q=6EC:VQY+@H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`D;F%M97,@(%1H92!O8FIE8W1S('1O(')E;6]V92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<F5M;W9E0GE.86UE<R@D;F%M97,I"B`@("!["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!-;W9E(&%N(&]B:F5C="!T;R!A(&YE=R!P87)E
M;G0N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("`D;V)J96-T("`@("!4
M:&4@;V)J96-T('1O(&UO=F4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=P
M87)E;G0@(%1H92!N97<@<&%R96YT(&]B:F5C="X@1&5F875L=',@=&\@=&AE
M(')O;W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&UO=F4H)&]B:F5C="P@)&YE
M=W!A<F5N="`](&YU;&PI"B`@("!["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M:&%N9V4@86X@;V)J96-T)W,@;F%M92X*("`@("`J"B`@("`@*B!`<&%R86T@
M;6EX960@("1O;&1?;V)J96-T("`@("`@(%1H92!O;&0@;V)J96-T+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;F5W7V]B:F5C=%]N86UE("!4:&4@;F5W(&]B
M:F5C="!N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YA;64H)&]L9%]O
M8FIE8W0L("1N97=?;V)J96-T7VYA;64I"B`@("!["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971R:65V92!D871A(&9O<B!A;B!O8FIE8W0@9G)O;2!T:&4@
M9&%T871R965?9&%T82!F:65L9"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D8VED("!4:&4@;V)J96-T(&ED('1O(&9E=&-H+"!O<B!A;B!A<G)A
M>2!O9B!O8FIE8W0@:61S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971$871A
M*"1C:60I"B`@("!["B`@("`@("`@<F5T=7)N(&ES<V5T*"1T:&ES+3Y?9&%T
M84-A8VAE6R1C:61=*2`_"B`@("`@("`@("`@("1T:&ES+3Y?9&%T84-A8VAE
M6R1C:61=(#H*("`@("`@("`@("`@87)R87DH*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E=')I979E(&1A=&$@9F]R(&%N(&]B:F5C="X*("`@("`J"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D8VED("!4:&4@;V)J96-T(&ED('1O(&9E
M=&-H+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971!='1R:6)U=&5S*"1C:60I
M"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1C:60I*2!["B`@("`@("`@
M("`@("1D871A(#T@87)R87DH*3L*("`@("`@("`@("`@9F]R96%C:"`H)&-I
M9"!A<R`D:60I('L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M7V%T=')I8G5T94-A8VAE6R1I9%TI*2!["B`@("`@("`@("`@("`@("`@("`@
M)&1A=&%;)&ED72`]("1T:&ES+3Y?871T<FEB=71E0V%C:&5;)&ED73L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@<F5T
M=7)N("1D871A.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R
M;B!I<W-E="@D=&AI<RT^7V%T=')I8G5T94-A8VAE6R1C:61=*2`_"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7V%T=')I8G5T94-A8VAE6R1C:61=(#H*("`@
M("`@("`@("`@("`@(&%R<F%Y*"D["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!T:&4@;G5M8F5R(&]F(&]B:F5C=',@;6%T8VAI
M;F<@82!S970@;V8@871T<FEB=71E"B`@("`@*B!C<FET97)I82X*("`@("`J
M"B`@("`@*B!`<V5E(&)U:6QD071T<FEB=71E475E<GDH*0H@("`@("H*("`@
M("`J($!P87)A;2!A<G)A>2`@("1C<FET97)I82`@(%1H92!A<G)A>2!O9B!C
M<FET97)I82X*("`@("`J($!P87)A;2!S=')I;F<@("1P87)E;G0@("`@(%1H
M92!P87)E;G0@;F]D92!T;R!S=&%R="!S96%R8VAI;F<@9G)O;2X*("`@("`J
M($!P87)A;2!B;V]L96%N("1A;&Q,979E;',@(%)E='5R;B!A;&P@;&5V96QS
M+"!O<B!J=7-T('1H92!D:7)E8W0*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&-H:6QD<F5N(&]F("1P87)E;G0_($1E9F%U;'1S('1O(&%L
M;"!L979E;',N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<F5S=')I8W0@("!/
M;FQY(')E='5R;B!A='1R:6)U=&5S('=I=&@@=&AE('-A;64*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%T=')I8G5T95]N86UE(&]R(&%T
M=')I8G5T95]I9"X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]U;G1">4%T=')I
M8G5T97,H)&-R:71E<FEA+"`D<&%R96YT(#T@1$%40512145?4D]/5"P@)&%L
M;$QE=F5L<R`]('1R=64L("1R97-T<FEC="`]("=N86UE)RD*("`@('L*("`@
M("`@("!I9B`H(6-O=6YT*"1C<FET97)I82DI('L*("`@("`@("`@("`@<F5T
M=7)N(#`["B`@("`@("`@?0H*("`@("`@("!R971U<FX@8V]U;G0H)'1H:7,M
M/E]A='1R:6)U=&5#86-H92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS(&$@<V5T(&]F(&]B:F5C="!I9',@8F%S960@;VX@82!S970@;V8@871T
M<FEB=71E(&-R:71E<FEA+@H@("`@("H*("`@("`J($!S964@8G5I;&1!='1R
M:6)U=&51=65R>2@I"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("`@)&-R
M:71E<FEA("`@("!4:&4@87)R87D@;V8@8W)I=&5R:6$N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("`D<&%R96YT("`@("`@(%1H92!P87)E;G0@;F]D92!T;R!S
M=&%R="!S96%R8VAI;F<@9G)O;2X*("`@("`J($!P87)A;2!B;V]L96%N("1A
M;&Q,979E;',@("`@4F5T=7)N(&%L;"!L979E;',L(&]R(&IU<W0@=&AE(&1I
M<F5C=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C:&EL
M9')E;B!O9B`D<&%R96YT/R!$969A=6QT<R!T;R!A;&P@;&5V96QS+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@)')E<W1R:6-T("`@("!/;FQY(')E='5R;B!A
M='1R:6)U=&5S('=I=&@@=&AE('-A;64*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@871T<FEB=71E7VYA;64@;W(@871T<FEB=71E7VED
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&9R;VT@("`@("`@("!4:&4@;V)J
M96-T('1O('-T87)T('1O(&9E=&-H:6YG"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D8V]U;G0@("`@("`@(%1H92!N=6UB97(@;V8@;V)J96-T<R!T;R!F971C
M:`H@("`@("H@0'!A<F%M('-T<FEN9R`@)'-O<G1B>5]N86UE("!!='1R:6)U
M=&4@;F%M92!T;R!U<V4@9F]R('-O<G1I;F<N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("`D<V]R=&)Y7VME>2`@($%T=')I8G5T92!K97D@=&\@=7-E(&9O<B!S
M;W)T:6YG+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&1I<F5C=&EO;B`@("!3
M;W)T(&1I<F5C=&EO;CH*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`P("T@87-C96YD:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@,2`M(&1E<V-E;F1I;F<*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T0GE!='1R:6)U=&5S*"1C<FET97)I82P@)'!A<F5N="`]($1!
M5$%44D5%7U)/3U0L("1A;&Q,979E;',@/2!T<G5E+"`D<F5S=')I8W0@/2`G
M;F%M92<L("1F<F]M(#T@,"P@)&-O=6YT(#T@,"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<V]R=&)Y7VYA;64@/2!N=6QL+"`D<V]R=&)Y7VME
M>2`](&YU;&PL("1D:7)E8W1I;VX@/2`P*0H@("`@>PH@("`@("`@(&EF("@A
M8V]U;G0H)&-R:71E<FEA*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@G;F\@8W)I=&5R:6$G*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!A<G)A>5]K97ES*"1T:&ES+3Y?871T<FEB=71E0V%C:&4I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4V]R=',@241S(&)Y(&%T=')I8G5T92!V
M86QU97,N($E$<R!W:71H;W5T(&%T=')I8G5T97,@=VEL;"!B90H@("`@("H@
M861D960@=&\@=&AE(&5N9"!O9B!T:&4@<V]R=&5D(&QI<W0N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1U;F]R9&5R961?:61S("!!<G)A>2!O9B!I
M9',@=&\@<V]R="X*("`@("`J($!P87)A;2!A<G)A>2`D<V]R=&)Y7VYA;64@
M("`@071T<FEB=71E(&YA;64@=&\@=7-E(&9O<B!S;W)T:6YG+@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1S;W)T8GE?:V5Y("`@("!!='1R:6)U=&4@:V5Y('1O
M('5S92!F;W(@<V]R=&EN9RX*("`@("`J($!P87)A;2!A<G)A>2`D9&ER96-T
M:6]N("`@("`@4V]R="!D:7)E8W1I;VXZ"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@,"`M(&%S8V5N9&EN9PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#$@+2!D97-C96YD:6YG"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@4V]R=&5D(&ED<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@<V]R=$)Y071T<FEB=71E<R@D=6YO<F1E<F5D7VED<RP@
M)'-O<G1B>5]N86UE(#T@;G5L;"P@)'-O<G1B>5]K97D@/2!N=6QL+"`D9&ER
M96-T:6]N(#T@,"D*("`@('L*("`@("`@("!R971U<FX@)'5N;W)D97)E9%]I
M9',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@;&ES="!O9B!A
M;&P@;V8@=&AE(&%V86EL86)L92!V86QU97,@;V8@=&AE(&=I=F5N"B`@("`@
M*B!A='1R:6)U=&4@;F%M92]K97D@8V]M8FEN871I;VXN($5I=&AE<B!A='1R
M:6)U=&5?;F%M92!O<@H@("`@("H@871T<FEB=71E7VME>2!-55-4(&)E('-U
M<'!L:65D+"!A;F0@8F]T:"!-05D@8F4@<W5P<&QI960N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D871T<FEB=71E7VYA;64@(%1H92!N86UE(&]F
M('1H92!A='1R:6)U=&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1A='1R:6)U
M=&5?:V5Y("`@5&AE(&ME>2!V86QU92!O9B!T:&4@871T<FEB=71E+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<&%R96YT("`@("`@("`@(%1H92!P87)E;G0@
M;F]D92!T;R!S=&%R="!S96%R8VAI;F<@9G)O;2X*("`@("`J($!P87)A;2!B
M;V]L96%N("1A;&Q,979E;',@("`@("!2971U<FX@86QL(&QE=F5L<RP@;W(@
M:G5S="!T:&4@9&ER96-T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8VAI;&1R96X@;V8@)'!A<F5N=#\*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!O9B!A;&P@;V8@=&AE(&%V86EL86)L
M92!V86QU97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%T=')I8G5T959A
M;'5E<R@D871T<FEB=71E7VYA;64@/2!N=6QL+"`D871T<FEB=71E7VME>2`]
M(&YU;&PL("1P87)E;G0@/2!$051!5%)%15]23T]4+"`D86QL3&5V96QS(#T@
M=')U92D*("`@('L*("`@("`@("!R971U<FX@87)R87DH*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%5P9&%T92!T:&4@9&%T82!I;B!A;B!O8FIE8W0N($1O
M97,@;F]T(&-H86YG92!T:&4@;V)J96-T)W,*("`@("`J('!A<F5N="!O<B!N
M86UE+"!J=7-T('-E<FEA;&EZ960@9&%T82X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1O8FIE8W0@(%1H92!O8FIE8W0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('5P9&%T941A=&$H)&]B:F5C="D*("`@('L*("`@("`@("!I9B`H
M(6ES7V$H)&]B:F5C="P@)T1A=&%4<F5E3V)J96-T)RDI('L*("`@("`@("`@
M("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`D8VED(#T@)'1H
M:7,M/F=E=$ED*"1O8FIE8W0M/F=E=$YA;64H*2D["B`@("`@("`@:68@*&ES
M7V$H)&-I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)&-I9#L*("`@("`@("!]"@H@("`@("`@("\O(%=E(&AA;F1L92!D871A(&1I
M9F9E<F5N=&QY(&EF('=E(&-A;B!M87`@:70@=&\*("`@("`@("`O+R!A='1R
M:6)U=&5S+@H@("`@("`@(&EF("AM971H;V1?97AI<W1S*"1O8FIE8W0L("=?
M=&]!='1R:6)U=&5S)RDI('L*("`@("`@("`@("`@)'1H:7,M/E]A='1R:6)U
M=&5#86-H95LD8VED72`]("1O8FIE8W0M/E]T;T%T=')I8G5T97,H*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7V1A=&%#86-H95LD
M8VED72`]("1O8FIE8W0M/F=E=$1A=&$H*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]#
M:7!H97(`````````````````````````````````````````````````````
M```````````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#`P,"`Q,#4Q-30S,S<S-R`P,C`U,#4`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+T-I<&AE<B]";&]C:TUO9&4`````````````````
M`````````````````````````````````````````````````#`P,#<U-2``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S,W(#`R,C,T
M-``@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O0VEP:&5R+T)L;V-K
M36]D92]E8V(N<&AP````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#0S,S8@
M,3`U,34T,S,W,S<@,#(S-C<S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B!4:&4@2&]R9&5?0VEP:&5R
M7T)L;V-K36]D95]E8V(Z.B!4:&ES(&-L87-S(&EM<&QE;65N=',@=&AE"B`J
M($AO<F1E7T-I<&AE<E]";&]C:TUO9&4@=7-I;F<@=&AE($5L96-T<F]N:6,@
M0V]D92!";V]K(&UE=&AO9"!O9@H@*B!E;F-R>7!T:6YG(&)L;V-K<R!O9B!D
M871A+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]#:7!H97(O0VEP:&5R+T)L
M;V-K36]D92]E8V(N<&AP+'8@,2XW+C$R+C4@,C`P-B\P,2\P,2`R,3HR.#HQ
M,2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6ME($-O
M8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L
M;"YC;RYN>CX*("H@0'-I;F-E("`@2&]R9&4@,BXR"B`J($!P86-K86=E($AO
M<F1E7T-I<&AE<@H@*B\*8VQA<W,@2&]R9&5?0VEP:&5R7T)L;V-K36]D95]E
M8V(@97AT96YD<R!(;W)D95]#:7!H97)?0FQO8VM-;V1E('L*"B`@("`O*BH*
M("`@("`J($5N8W)Y<'0@82!S=')I;F<N"B`@("`@*@H@("`@("H@0'!A<F%M
M($AO<F1E7T-I<&AE<B`D8VEP:&5R("!#:7!H97(@86QG;W)I=&AM('1O('5S
M92!F;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@96YC
M<GEP=&EO;BX*("`@("`J($!P87)A;2!S=')I;F<@)'!L86EN=&5X="`@("`@
M5&AE(&1A=&$@=&\@96YC<GEP="X*("`@("`J"B`@("`@*B!`<F5T=7)N("!4
M:&4@96YC<GEP=&5D(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N8W)Y
M<'0H)B1C:7!H97(L("1P;&%I;G1E>'0I"B`@("!["B`@("`@("`@)&5N8W)Y
M<'1E9"`]("<G.PH@("`@("`@("1B;&]C:W-I>F4@/2`D8VEP:&5R+3YG971"
M;&]C:U-I>F4H*3L*"B`@("`@("`@)&I-87@@/2!S=')L96XH)'!L86EN=&5X
M="D["B`@("`@("`@9F]R("@D:B`](#`[("1J(#P@)&I-87@[("1J("L]("1B
M;&]C:W-I>F4I('L*("`@("`@("`@("`@)'!L86EN(#T@<W5B<W1R*"1P;&%I
M;G1E>'0L("1J+"`D8FQO8VMS:7IE*3L*"B`@("`@("`@("`@(&EF("AS=')L
M96XH)'!L86EN*2`\("1B;&]C:W-I>F4I('L*("`@("`@("`@("`@("`@("\O
M('!A9"!T:&4@8FQO8VL@=VET:"!<,"=S(&EF(&ET)W,@;F]T(&QO;F<@96YO
M=6=H"B`@("`@("`@("`@("`@("`D<&QA:6X@/2!S=')?<&%D*"1P;&%I;BP@
M."P@(EPP(BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1E;F-R>7!T
M960@+CT@)&-I<&AE<BT^96YC<GEP=$)L;V-K*"1P;&%I;BD["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&5N8W)Y<'1E9#L*("`@('T*"B`@("`O*BH*
M("`@("`J($1E8W)Y<'0@82!S=')I;F<N"B`@("`@*@H@("`@("H@0'!A<F%M
M($AO<F1E7T-I<&AE<B`D8VEP:&5R("!#:7!H97(@86QG;W)I=&AM('1O('5S
M92!F;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9&5C
M<GEP=&EO;BX*("`@("`J($!P87)A;2!S=')I;F<@)&-I<&AE<G1E>'0@("`@
M5&AE(&1A=&$@=&\@9&5C<GEP="X*("`@("`J"B`@("`@*B!`<F5T=7)N("!4
M:&4@9&5C<GEP=&5D(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E8W)Y
M<'0H)B1C:7!H97(L("1C:7!H97)T97AT*0H@("`@>PH@("`@("`@("1D96-R
M>7!T960@/2`G)SL*("`@("`@("`D8FQO8VMS:7IE(#T@)&-I<&AE<BT^9V5T
M0FQO8VM3:7IE*"D["@H@("`@("`@("1J36%X(#T@<W1R;&5N*"1C:7!H97)T
M97AT*3L*("`@("`@("!F;W(@*"1J(#T@,#L@)&H@/"`D:DUA>#L@)&H@*ST@
M)&)L;V-K<VEZ92D@>PH@("`@("`@("`@("`D<&QA:6X@/2!S=6)S='(H)&-I
M<&AE<G1E>'0L("1J+"`D8FQO8VMS:7IE*3L*("`@("`@("`@("`@)&1E8W)Y
M<'1E9"`N/2`D8VEP:&5R+3YD96-R>7!T0FQO8VLH)'!L86EN*3L*("`@("`@
M("!]"@H@("`@("`@("\O(%)E;6]V92!T<F%I;&EN9R!<,"=S('5S960@=&\@
M<&%D('1H92!L87-T(&)L;V-K+@H@("`@("`@('=H:6QE("AS=6)S='(H)&1E
M8W)Y<'1E9"P@+3$L(#$I(#T](")<,"(I('L*("`@("`@("`@("`@)&1E8W)Y
M<'1E9"`]('-U8G-T<B@D9&5C<GEP=&5D+"`P+"`M,2D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&1E8W)Y<'1E9#L*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M0VEP:&5R+T)L;V-K36]D92]O9F(V-"YP:'``````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#0P-S8@,3`U,34T,S,W,S<@,#(T,#8S`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@
M2&]R9&5?0VEP:&5R7T)L;V-K36]D95]O9F(V-#HZ(%1H:7,@8VQA<W,@:6UP
M;&5M96YT<R!T:&4*("H@2&]R9&5?0VEP:&5R7T)L;V-K36]D92!U<VEN9R!A
M(#8T(&)I="!O=71P=70@9F5E9&)A8VLN"B`J"B`J(%1H:7,@8V%N('5S960@
M=&\@96YC<GEP="!A;GD@;&5N9W1H('-T<FEN9R!A;F0@=&AE(&5N8W)Y<'1E
M9"!V97)S:6]N"B`J('=I;&P@8F4@=&AE('-A;64@;&5N9W1H+@H@*@H@*B`D
M2&]R9&4Z(&9R86UE=V]R:R]#:7!H97(O0VEP:&5R+T)L;V-K36]D92]O9F(V
M-"YP:'`L=B`Q+C<N,3(N-2`R,#`V+S`Q+S`Q(#(Q.C(X.C$Q(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI:V4@0V]C:')A;F4@/&UI
M:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@
M*B!`<VEN8V4@("!(;W)D92`R+C(*("H@0'!A8VMA9V4@2&]R9&5?0VEP:&5R
M"B`J+PIC;&%S<R!(;W)D95]#:7!H97)?0FQO8VM-;V1E7V]F8C8T(&5X=&5N
M9',@2&]R9&5?0VEP:&5R7T)L;V-K36]D92!["@H@("`@+RHJ"B`@("`@*B!%
M;F-R>7!T(&$@<W1R:6YG+@H@("`@("H*("`@("`J($!P87)A;2!(;W)D95]#
M:7!H97(@)&-I<&AE<B`@0VEP:&5R(&%L9V]R:71H;2!T;R!U<V4@9F]R"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&5N8W)Y<'1I;VXN
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1P;&%I;G1E>'0@("`@(%1H92!D871A
M('1O(&5N8W)Y<'0N"B`@("`@*@H@("`@("H@0')E='5R;B`@5&AE(&5N8W)Y
M<'1E9"!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!E;F-R>7!T*"8D8VEP
M:&5R+"`D<&QA:6YT97AT*0H@("`@>PH@("`@("`@("1E;F-R>7!T960@/2`G
M)SL*"B`@("`@("`@)&X@/2`P.PH@("`@("`@("1J36%X(#T@<W1R;&5N*"1P
M;&%I;G1E>'0I.PH@("`@("`@(&9O<B`H)&H@/2`P.R`D:B`\("1J36%X.R`D
M:BLK*2!["B`@("`@("`@("`@(&EF("@D;B`]/2`P*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7VEV(#T@)&-I<&AE<BT^96YC<GEP=$)L;V-K*"1T:&ES
M+3Y?:78I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D8R`]("1P;&%I
M;G1E>'1;)&I=(%X@)'1H:7,M/E]I=ELD;ET["B`@("`@("`@("`@("1E;F-R
M>7!T960@+CT@)&,["@H@("`@("`@("`@("`D;B`]("@K*R1N*2`F(#!X,#<[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&5N8W)Y<'1E9#L*("`@('T*
M"B`@("`O*BH*("`@("`J($1E8W)Y<'0@82!S=')I;F<N"B`@("`@*@H@("`@
M("H@0'!A<F%M($AO<F1E7T-I<&AE<B`D8VEP:&5R("!#:7!H97(@86QG;W)I
M=&AM('1O('5S92!F;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@9&5C<GEP=&EO;BX*("`@("`J($!P87)A;2!S=')I;F<@)&-I<&AE
M<G1E>'0@("`@5&AE(&1A=&$@=&\@9&5C<GEP="X*("`@("`J"B`@("`@*B!`
M<F5T=7)N("!4:&4@9&5C<GEP=&5D(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&1E8W)Y<'0H)B1C:7!H97(L("1C:7!H97)T97AT*0H@("`@>PH@("`@
M("`@("1D96-R>7!T960@/2`G)SL*"B`@("`@("`@)&X@/2`P.PH@("`@("`@
M("1J36%X(#T@<W1R;&5N*"1C:7!H97)T97AT*3L*("`@("`@("!F;W(@*"1J
M(#T@,#L@)&H@/"`D:DUA>#L@)&HK*RD@>PH@("`@("`@("`@("!I9B`H)&X@
M/3T@,"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]I=B`]("1C:7!H97(M
M/F5N8W)Y<'1";&]C:R@D=&AI<RT^7VEV*3L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@)&,@/2`D8VEP:&5R=&5X=%LD:ET@7B`D=&AI<RT^7VEV6R1N
M73L*("`@("`@("`@("`@)&1E8W)Y<'1E9"`N/2`D8SL*"B`@("`@("`@("`@
M("1N(#T@*"LK)&XI("8@,'@P-SL*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D9&5C<GEP=&5D.PH@("`@?0H*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O0VEP:&5R+T)L;V-K36]D92]C9F(V-"YP:'``````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#0V-C0@,3`U,34T,S,W,S<@,#(T,#4R`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B!4:&4@2&]R9&5?0VEP:&5R7T)L;V-K36]D95]C9F(V-#HZ(%1H
M:7,@8VQA<W,@:6UP;&5M96YT<R!T:&4*("H@2&]R9&5?0VEP:&5R7T)L;V-K
M36]D92!U<VEN9R!A(#8T(&)I="!C:7!H97(@9F5E9&)A8VLN"B`J"B`J(%1H
M:7,@8V%N(&)E('5S960@=&\@96YC<GEP="!A;GD@;&5N9W1H('-T<FEN9R!A
M;F0@=&AE(&5N8W)Y<'1E9`H@*B!V97)S:6]N('=I;&P@8F4@=&AE('-A;64@
M;&5N9W1H+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]#:7!H97(O0VEP:&5R
M+T)L;V-K36]D92]C9F(V-"YP:'`L=B`Q+C<N,3(N-2`R,#`V+S`Q+S`Q(#(Q
M.C(X.C$Q(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI
M:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T
M;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!(;W)D92`R+C(*("H@0'!A8VMA
M9V4@2&]R9&5?0VEP:&5R"B`J+PIC;&%S<R!(;W)D95]#:7!H97)?0FQO8VM-
M;V1E7V-F8C8T(&5X=&5N9',@2&]R9&5?0VEP:&5R7T)L;V-K36]D92!["@H@
M("`@+RHJ"B`@("`@*B!%;F-R>7!T(&$@<W1R:6YG+@H@("`@("H*("`@("`J
M($!P87)A;2!(;W)D95]#:7!H97(@)&-I<&AE<B`@0VEP:&5R(&%L9V]R:71H
M;2!T;R!U<V4@9F]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&5N8W)Y<'1I;VXN"B`@("`@*B!`<&%R86T@<W1R:6YG("1P;&%I;G1E
M>'0@("`@(%1H92!D871A('1O(&5N8W)Y<'0N"B`@("`@*@H@("`@("H@0')E
M='5R;B`@5&AE(&5N8W)Y<'1E9"!D871A+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!E;F-R>7!T*"8D8VEP:&5R+"`D<&QA:6YT97AT*0H@("`@>PH@("`@("`@
M("1E;F-R>7!T960@/2`G)SL*"B`@("`@("`@)&X@/2`P.PH@("`@("`@("1J
M36%X(#T@<W1R;&5N*"1P;&%I;G1E>'0I.PH@("`@("`@(&9O<B`H)&H@/2`P
M.R`D:B`\("1J36%X.R`D:BLK*2!["B`@("`@("`@("`@(&EF("@D;B`]/2`P
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VEV(#T@)&-I<&AE<BT^96YC
M<GEP=$)L;V-K*"1T:&ES+3Y?:78I.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`D8R`]("1P;&%I;G1E>'1;)&I=(%X@)'1H:7,M/E]I=ELD;ET["B`@
M("`@("`@("`@("1T:&ES+3Y?:78@/2!S=6)S='(H)'1H:7,M/E]I=BP@,"P@
M)&XI("X@)&,@+B!S=6)S='(H)'1H:7,M/E]I=BP@)&X@*R`Q*3L*("`@("`@
M("`@("`@)&5N8W)Y<'1E9"`N/2`D8SL*"B`@("`@("`@("`@("1N(#T@*"LK
M)&XI("8@,'@P-SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D96YC<GEP
M=&5D.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5C<GEP="!A('-T<FEN9RX*
M("`@("`J"B`@("`@*B!`<&%R86T@2&]R9&5?0VEP:&5R("1C:7!H97(@($-I
M<&AE<B!A;&=O<FET:&T@=&\@=7-E(&9O<@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!D96-R>7!T:6]N+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D8VEP:&5R=&5X="`@("!4:&4@9&%T82!T;R!D96-R>7!T+@H@("`@
M("H*("`@("`J($!R971U<FX@(%1H92!D96-R>7!T960@9&%T82X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9&5C<GEP="@F)&-I<&AE<BP@)&-I<&AE<G1E>'0I
M"B`@("!["B`@("`@("`@)&1E8W)Y<'1E9"`]("<G.PH*("`@("`@("`D;B`]
M(#`["B`@("`@("`@)&I-87@@/2!S=')L96XH)&-I<&AE<G1E>'0I.PH@("`@
M("`@(&9O<B`H)&H@/2`P.R`D:B`\("1J36%X.R`D:BLK*2!["B`@("`@("`@
M("`@(&EF("@D;B`]/2`P*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VEV
M(#T@)&-I<&AE<BT^96YC<GEP=$)L;V-K*"1T:&ES+3Y?:78I.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`D8R`]("1C:7!H97)T97AT6R1J72!>("1T
M:&ES+3Y?:79;)&Y=.PH@("`@("`@("`@("`D=&AI<RT^7VEV(#T@<W5B<W1R
M*"1T:&ES+3Y?:78L(#`L("1N*2`N('-U8G-T<B@D8VEP:&5R=&5X="P@)&HL
M(#$I("X@<W5B<W1R*"1T:&ES+3Y?:78L("1N("L@,2D["B`@("`@("`@("`@
M("1D96-R>7!T960@+CT@)&,["@H@("`@("`@("`@("`D;B`]("@K*R1N*2`F
M(#!X,#<["B`@("`@("`@?0H*("`@("`@("`O+R!296UO=F4@=')A:6QI;F<@
M7#`G<R!U<V5D('1O('!A9"!T:&4@;&%S="!B;&]C:RX*("`@("`@("!W:&EL
M92`H<W5B<W1R*"1D96-R>7!T960L("TQ+"`Q*2`]/2`B7#`B*2!["B`@("`@
M("`@("`@("1D96-R>7!T960@/2!S=6)S='(H)&1E8W)Y<'1E9"P@,"P@+3$I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1D96-R>7!T960["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O0VEP:&5R+T)L;V-K36]D92]C8F,N
M<&AP````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#0W,#,@,3`U,34T,S,W
M,S<@,#(S-C8W`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!4:&4@2&]R9&5?0VEP:&5R7T)L;V-K36]D
M95]C8F,Z.B!4:&ES(&-L87-S(&EM<&QE;65N=',@=&AE"B`J($AO<F1E7T-I
M<&AE<E]";&]C:TUO9&4@=7-I;F<@=&AE($-I<&AE<B!";&]C:R!#:&%I;FEN
M9R!M971H;V0@;V8*("H@96YC<GEP=&EN9R!B;&]C:W,@;V8@9&%T82X*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO0VEP:&5R+T-I<&AE<B]";&]C:TUO9&4O
M8V)C+G!H<"QV(#$N-RXQ,BXU(#(P,#8O,#$O,#$@,C$Z,C@Z,3$@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EK92!#;V-H<F%N92`\
M;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^
M"B`J($!S:6YC92`@($AO<F1E(#(N,@H@*B!`<&%C:V%G92!(;W)D95]#:7!H
M97(*("HO"F-L87-S($AO<F1E7T-I<&AE<E]";&]C:TUO9&5?8V)C(&5X=&5N
M9',@2&]R9&5?0VEP:&5R7T)L;V-K36]D92!["@H@("`@+RHJ"B`@("`@*B!%
M;F-R>7!T(&$@<W1R:6YG+@H@("`@("H*("`@("`J($!P87)A;2!(;W)D95]#
M:7!H97(@)&-I<&AE<B`@0VEP:&5R(&%L9V]R:71H;2!T;R!U<V4@9F]R"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&5N8W)Y<'1I;VXN
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1P;&%I;G1E>'0@("`@(%1H92!D871A
M('1O(&5N8W)Y<'0N"B`@("`@*@H@("`@("H@0')E='5R;B`@5&AE(&5N8W)Y
M<'1E9"!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!E;F-R>7!T*"8D8VEP
M:&5R+"`D<&QA:6YT97AT*0H@("`@>PH@("`@("`@("1E;F-R>7!T960@/2`G
M)SL*"B`@("`@("`@)&)L;V-K<VEZ92`]("1C:7!H97(M/F=E=$)L;V-K4VEZ
M92@I.PH@("`@("`@("1P<F5V:6]U<T-I<&AE<B`]("1T:&ES+3Y?:78["@H@
M("`@("`@("1J36%X(#T@<W1R;&5N*"1P;&%I;G1E>'0I.PH@("`@("`@(&9O
M<B`H)&H@/2`P.R`D:B`\("1J36%X.R`D:B`K/2`D8FQO8VMS:7IE*2!["B`@
M("`@("`@("`@("1P;&%I;B`]('-U8G-T<B@D<&QA:6YT97AT+"`D:BP@)&)L
M;V-K<VEZ92D["@H@("`@("`@("`@("!I9B`H<W1R;&5N*"1P;&%I;BD@/"`D
M8FQO8VMS:7IE*2!["B`@("`@("`@("`@("`@("`O+R!P860@=&AE(&)L;V-K
M('=I=&@@7#`G<R!I9B!I="=S(&YO="!L;VYG(&5N;W5G:`H@("`@("`@("`@
M("`@("`@)'!L86EN(#T@<W1R7W!A9"@D<&QA:6XL(#@L(")<,"(I.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`D<&QA:6X@/2`D<&QA:6X@7B`D<')E
M=FEO=7-#:7!H97(["B`@("`@("`@("`@("1P<F5V:6]U<T-I<&AE<B`]("1C
M:7!H97(M/F5N8W)Y<'1";&]C:R@D<&QA:6XI.PH@("`@("`@("`@("`D96YC
M<GEP=&5D("X]("1P<F5V:6]U<T-I<&AE<CL*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D96YC<GEP=&5D.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5C
M<GEP="!A('-T<FEN9RX*("`@("`J"B`@("`@*B!`<&%R86T@2&]R9&5?0VEP
M:&5R("1C:7!H97(@($-I<&AE<B!A;&=O<FET:&T@=&\@=7-E(&9O<@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!D96-R>7!T:6]N+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D8VEP:&5R=&5X="`@("!4:&4@9&%T82!T
M;R!D96-R>7!T+@H@("`@("H*("`@("`J($!R971U<FX@(%1H92!D96-R>7!T
M960@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5C<GEP="@F)&-I<&AE
M<BP@)&-I<&AE<G1E>'0I"B`@("!["B`@("`@("`@)&1E8W)Y<'1E9"`]("<G
M.PH*("`@("`@("`D8FQO8VMS:7IE(#T@)&-I<&AE<BT^9V5T0FQO8VM3:7IE
M*"D["B`@("`@("`@)'!R979I;W5S0VEP:&5R(#T@)'1H:7,M/E]I=CL*"B`@
M("`@("`@)&I-87@@/2!S=')L96XH)&-I<&AE<G1E>'0I.PH@("`@("`@(&9O
M<B`H)&H@/2`P.R`D:B`\("1J36%X.R`D:B`K/2`D8FQO8VMS:7IE*2!["B`@
M("`@("`@("`@("1P;&%I;B`]('-U8G-T<B@D8VEP:&5R=&5X="P@)&HL("1B
M;&]C:W-I>F4I.PH@("`@("`@("`@("`D9&5C<GEP=&5D("X]("1C:7!H97(M
M/F1E8W)Y<'1";&]C:R@D<&QA:6XI(%X@)'!R979I;W5S0VEP:&5R.PH@("`@
M("`@("`@("`D<')E=FEO=7-#:7!H97(@/2`D<&QA:6X["B`@("`@("`@?0H*
M("`@("`@("`O+R!296UO=F4@=')A:6QI;F<@7#`G<R!U<V5D('1O('!A9"!T
M:&4@;&%S="!B;&]C:RX*("`@("`@("!W:&EL92`H<W5B<W1R*"1D96-R>7!T
M960L("TQ+"`Q*2`]/2`B7#`B*2!["B`@("`@("`@("`@("1D96-R>7!T960@
M/2!S=6)S='(H)&1E8W)Y<'1E9"P@,"P@+3$I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1D96-R>7!T960["B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O0VEP:&5R+V)L
M;W=F:7-H+G!H<```````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-3<U
M,#0@,3`U,34T,S,W,S<@,#(S,3(U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B!4:&4@0VEP:&5R7V)L
M;W=F:7-H.CH@8VQA<W,@:6UP;&5M96YT<R!T:&4@0VEP:&5R(&EN=&5R9F%C
M92!E;F-R>7!T:6]N(&1A=&$*("H@=7-I;F<@=&AE($)L;W=F:7-H(&%L9V]R
M:71H;2X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO0VEP:&5R+T-I<&AE<B]B
M;&]W9FES:"YP:'`L=B`Q+C$T+C$R+CD@,C`P-B\P,2\P,2`R,3HR.#HQ,"!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6ME($-O8VAR
M86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@0&%U=&AO<B`@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC
M;RYN>CX*("H@0'-I;F-E("`@2&]R9&4@,BXR"B`J($!P86-K86=E($AO<F1E
M7T-I<&AE<@H@*B\*8VQA<W,@2&]R9&5?0VEP:&5R7V)L;W=F:7-H(&5X=&5N
M9',@2&]R9&5?0VEP:&5R('L*"B`@("`O*BH*("`@("`J(%!I($%R<F%Y"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)'`@/2!A
M<G)A>2@*("`@("`@("`P>#(T,T8V03@X+"`P>#@U03,P.$0S+"`P>#$S,3DX
M03)%+"`P>#`S-S`W,S0T+`H@("`@("`@(#!X030P.3,X,C(L(#!X,CDY1C,Q
M1#`L(#!X,#@R149!.3@L(#!X14,T139#.#DL"B`@("`@("`@,'@T-3(X,C%%
M-BP@,'@S.$0P,3,W-RP@,'A"134T-C9#1BP@,'@S-$4Y,$,V0RP*("`@("`@
M("`P>$,P04,R.4(W+"`P>$,Y-T,U,$1$+"`P>#-&.#1$-4(U+"`P>$(U-#<P
M.3$W+`H@("`@("`@(#!X.3(Q-D0U1#DL(#!X.#DW.49",4(I.PH*("`@("\J
M*@H@("`@("H@4R!";W@@*',Q*0H@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1S,2`](&%R<F%Y*`H@("`@("`@(#!X1#$S,3!"
M038L(#!X.3A$1D(U04,L(#!X,D9&1#<R1$(L(#!X1#`Q041&0C<L"B`@("`@
M("`@,'A".$4Q049%1"P@,'@V03(V-T4Y-BP@,'A"03=#.3`T-2P@,'A&,3)#
M-T8Y.2P*("`@("`@("`P>#(T03$Y.30W+"`P>$(S.3$V0T8W+"`P>#`X,#%&
M,D4R+"`P>#@U.$5&0S$V+`H@("`@("`@(#!X-C,V.3(P1#@L(#!X-S$U-S1%
M-CDL(#!X030U.$9%03,L(#!X1C0Y,S-$-T4L"B`@("`@("`@,'@P1#DU-S0X
M1BP@,'@W,CA%0C8U."P@,'@W,3A"0T0U."P@,'@X,C$U-$%%12P*("`@("`@
M("`P>#="-31!-#%$+"`P>$,R-4$U.4(U+"`P>#E#,S!$-3,Y+"`P>#)!1C(V
M,#$S+`H@("`@("`@(#!X0S5$,4(P,C,L(#!X,C@V,#@U1C`L(#!X0T$T,3<Y
M,3@L(#!X0CA$0C,X148L"B`@("`@("`@,'@X13<Y1$-","P@,'@V,#-!,3@P
M12P@,'@V0SE%,$4X0BP@,'A",#%%.$$S12P*("`@("`@("`P>$0W,34W-T,Q
M+"`P>$)$,S$T0C(W+"`P>#<X048R1D1!+"`P>#4U-C`U0S8P+`H@("`@("`@
M(#!X138U-3(U1C,L(#!X04$U-4%".30L(#!X-3<T.#DX-C(L(#!X-C-%.#$T
M-#`L"B`@("`@("`@,'@U-4-!,SDV02P@,'@R04%",3!"-BP@,'A"-$-#-4,S
M-"P@,'@Q,30Q13A#12P*("`@("`@("`P>$$Q-30X-D%&+"`P>#=#-S)%.3DS
M+"`P>$(S144Q-#$Q+"`P>#8S-D9"0S)!+`H@("`@("`@(#!X,D)!.4,U-40L
M(#!X-S0Q.#,Q1C8L(#!X0T4U0S-%,38L(#!X.4(X-SDS,44L"B`@("`@("`@
M,'A!1D0V0D$S,RP@,'@V0S(T0T8U0RP@,'@W03,R-3,X,2P@,'@R.#DU.#8W
M-RP*("`@("`@("`P>#-".$8T.#DX+"`P>#9"-$)".4%&+"`P>$,T0D9%.#%"
M+"`P>#8V,C@R,3DS+`H@("`@("`@(#!X-C%$.#`Y0T,L(#!X1D(R,4$Y.3$L
M(#!X-#@W0T%#-C`L(#!X-41%0S@P,S(L"B`@("`@("`@,'A%1C@T-40U1"P@
M,'A%.3@U-S5",2P@,'A$0S(V,C,P,BP@,'A%0C8U,4(X."P*("`@("`@("`P
M>#(S.#DS13@Q+"`P>$0S.39!0T,U+"`P>#!&-D0V1D8S+"`P>#@S1C0T,C,Y
M+`H@("`@("`@(#!X,D4P0C0T.#(L(#!X030X-#(P,#0L(#!X-CE#.$8P-$$L
M(#!X.44Q1CE"-44L"B`@("`@("`@,'@R,4,V-C@T,BP@,'A&-D4Y-D,Y02P@
M,'@V-S!#.4,V,2P@,'A!0D0S.#A&,"P*("`@("`@("`P>#9!-3%!,$0R+"`P
M>$0X-30R1C8X+"`P>#DV,$9!-S(X+"`P>$%"-3$S,T$S+`H@("`@("`@(#!X
M-D5%1C!"-D,L(#!X,3,W03-"130L(#!X0D$S0D8P-3`L(#!X-T5&0C)!.3@L
M"B`@("`@("`@,'A!,48Q-C4Q1"P@,'@S.4%&,#$W-BP@,'@V-D-!-3DS12P@
M,'@X,C0S,$4X."P*("`@("`@("`P>#A#144X-C$Y+"`P>#0U-D8Y1D(T+"`P
M>#=$.#1!-4,S+"`P>#-".$(U14)%+`H@("`@("`@(#!X13`V1C<U1#@L(#!X
M.#5#,3(P-S,L(#!X-#`Q030T.48L(#!X-39#,39!038L"B`@("`@("`@,'@T
M140S04$V,BP@,'@S-C-&-S<P-BP@,'@Q0D9%1$8W,BP@,'@T,CE",#(S1"P*
M("`@("`@("`P>#,W1#!$-S(T+"`P>$0P,$$Q,C0X+"`P>$1",$9%040S+"`P
M>#0Y1C%#,#E"+`H@("`@("`@(#!X,#<U,S<R0SDL(#!X.#`Y.3%"-T(L(#!X
M,C5$-#<Y1#@L(#!X1C9%.$1%1C<L"B`@("`@("`@,'A%,T9%-3`Q02P@,'A"
M-C<Y-$,S0BP@,'@Y-S9#13!"1"P@,'@P-$,P,#9"02P*("`@("`@("`P>$,Q
M03DT1D(V+"`P>#0P.48V,$,T+"`P>#5%-4,Y14,R+"`P>#$Y-D$R-#8S+`H@
M("`@("`@(#!X-CA&0C9&048L(#!X,T4V0S4S0C4L(#!X,3,S.4(R14(L(#!X
M,T(U,D5#-D8L"B`@("`@("`@,'@V1$9#-3$Q1BP@,'@Y0C,P.34R0RP@,'A#
M0S@Q-#4T-"P@,'A!1C5%0D0P.2P*("`@("`@("`P>$)%13-$,#`T+"`P>$1%
M,S,T049$+"`P>#8V,$8R.#`W+"`P>#$Y,D4T0D(S+`H@("`@("`@(#!X0S!#
M0D$X-3<L(#!X-#5#.#<T,$8L(#!X1#(P0C5&,SDL(#!X0CE$,T9"1$(L"B`@
M("`@("`@,'@U-3<Y0S!"1"P@,'@Q038P,S(P02P@,'A$-D$Q,#!#-BP@,'@T
M,#)#-S(W.2P*("`@("`@("`P>#8W.48R-49%+"`P>$9",49!,T-#+"`P>#A%
M035%.48X+"`P>$1",S(R,D8X+`H@("`@("`@(#!X,T,W-3$V1$8L(#!X1D0V
M,39",34L(#!X,D8U,#%%0S@L(#!X040P-34R04(L"B`@("`@("`@,'@S,C-$
M0C5&02P@,'A&1#(S.#<V,"P@,'@U,S,Q-T(T."P@,'@S13`P1$8X,BP*("`@
M("`@("`P>#E%-4,U-T)"+"`P>$-!-D8X0T$P+"`P>#%!.#<U-C)%+"`P>$1&
M,3<V.41"+`H@("`@("`@(#!X1#4T,D$X1C8L(#!X,C@W149&0S,L(#!X04,V
M-S,R0S8L(#!X.$,T1C4U-S,L"B`@("`@("`@,'@V.35",C=","P@,'A"0D-!
M-3A#."P@,'A%,49&03,U1"P@,'A".$8P,3%!,"P*("`@("`@("`P>#$P1D$S
M1#DX+"`P>$9$,C$X,T(X+"`P>#1!1D-"-39#+"`P>#)$1#%$,S5"+`H@("`@
M("`@(#!X.4$U,T4T-SDL(#!X0C9&.#0U-C4L(#!X1#(X130Y0D,L(#!X-$)&
M0CDW.3`L"B`@("`@("`@,'A%,41$1C)$02P@,'A!-$-"-T4S,RP@,'@V,D9"
M,3,T,2P@,'A#144T0S9%."P*("`@("`@("`P>$5&,C!#041!+"`P>#,V-S<T
M0S`Q+"`P>$0P-T4Y149%+"`P>#)"1C$Q1D(T+`H@("`@("`@(#!X.35$0D1!
M-$0L(#!X044Y,#DQ.3@L(#!X14%!1#A%-S$L(#!X-D(Y,T0U03`L"B`@("`@
M("`@,'A$,#A%1#%$,"P@,'A!1D,W,C5%,"P@,'@X13-#-4(R1BP@,'@X13<U
M.31"-RP*("`@("`@("`P>#A&1C9%,D9"+"`P>$8R,3(R0C8T+"`P>#@X.#A"
M.#$R+"`P>#DP,$1&,#%#+`H@("`@("`@(#!X-$9!1#5%03`L(#!X-C@X1D,S
M,4,L(#!X1#%#1D8Q.3$L(#!X0C-!.$,Q040L"B`@("`@("`@,'@R1C)&,C(Q
M."P@,'A"13!%,3<W-RP@,'A%03<U,D1&12P@,'@X0C`R,49!,2P*("`@("`@
M("`P>$4U03!#0S!&+"`P>$(U-D8W-$4X+"`P>#$X04-&,T0V+"`P>$-%.#E%
M,CDY+`H@("`@("`@(#!X0C1!.#1&13`L(#!X1D0Q,T4P0C<L(#!X-T-#-#-"
M.#$L(#!X1#)!1$$X1#DL"B`@("`@("`@,'@Q-C5&03(V-BP@,'@X,#DU-S<P
M-2P@,'@Y,T-#-S,Q-"P@,'@R,3%!,30W-RP*("`@("`@("`P>$4V040R,#8U
M+"`P>#<W0C5&03@V+"`P>$,W-30T,D8U+"`P>$9".40S-4-&+`H@("`@("`@
M(#!X14)#1$%&,$,L(#!X-T(S13@Y03`L(#!X1#8T,3%"1#,L(#!X044Q13=%
M-#DL"B`@("`@("`@,'@P,#(U,$4R1"P@,'@R,#<Q0C,U12P@,'@R,C8X,#!"
M0BP@,'@U-T(X13!!1BP*("`@("`@("`P>#(T-C0S-CE"+"`P>$8P,#E".3%%
M+"`P>#4U-C,Y,3%$+"`P>#4Y1$9!-D%!+`H@("`@("`@(#!X-SA#,30S.#DL
M(#!X1#DU034S-T8L(#!X,C`W1#5"03(L(#!X,#)%-4(Y0S4L"B`@("`@("`@
M,'@X,S(V,#,W-BP@,'@V,CDU0T9!.2P@,'@Q,4,X,3DV."P@,'@T13<S-$$T
M,2P*("`@("`@("`P>$(S-#<R1$-!+"`P>#=",31!.31!+"`P>#%"-3$P,#4R
M+"`P>#E!-3,R.3$U+`H@("`@("`@(#!X1#8P1C4W,T8L(#!X0D,Y0D,V130L
M(#!X,D(V,$$T-S8L(#!X.#%%-C<T,#`L"B`@("`@("`@,'@P.$)!-D9"-2P@
M,'@U-S%"13DQ1BP@,'A&,CDV14,V0BP@,'@R03!$1#DQ-2P*("`@("`@("`P
M>$(V-C,V-3(Q+"`P>$4W0CE&.4(V+"`P>$9&,S0P-3)%+"`P>$,U.#4U-C8T
M+`H@("`@("`@(#!X-3-",#)$-40L(#!X03DY1CA&03$L(#!X,#A"030W.3DL
M(#!X-D4X-3`W-D$I.PH*("`@("\J*@H@("`@("H@4R!";W@@*',R*0H@("`@
M("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1S,B`](&%R
M<F%Y*`H@("`@("`@(#!X-$(W03<P13DL(#!X0C5",S(Y-#0L(#!X1$(W-3`Y
M,D4L(#!X0S0Q.3(V,C,L"B`@("`@("`@,'A!1#9%039","P@,'@T.4$W1$8W
M1"P@,'@Y0T5%-C!"."P@,'@X1D5$0C(V-BP*("`@("`@("`P>$5#04$X0S<Q
M+"`P>#8Y.4$Q-T9&+"`P>#4V-C0U,C9#+"`P>$,R0C$Y144Q+`H@("`@("`@
M(#!X,3DS-C`R034L(#!X-S4P.31#,CDL(#!X03`U.3$S-#`L(#!X130Q.#-!
M,T4L"B`@("`@("`@,'@S1C4T.3@Y02P@,'@U0C0R.40V-2P@,'@V0CA&131$
M-BP@,'@Y.48W,T9$-BP*("`@("`@("`P>$$Q1#(Y0S`W+"`P>$5&13@S,$8U
M+"`P>#1$,D0S.$4V+"`P>$8P,C4U1$,Q+`H@("`@("`@(#!X-$-$1#(P.#8L
M(#!X.#0W,$5",C8L(#!X-C,X,D4Y0S8L(#!X,#(Q14-#-44L"B`@("`@("`@
M,'@P.38X-D(S1BP@,'@S14)!149#.2P@,'@S0SDW,3@Q-"P@,'@V0C9!-S!!
M,2P*("`@("`@("`P>#8X-T8S-3@T+"`P>#4R03!%,C@V+"`P>$(W.4,U,S`U
M+"`P>$%!-3`P-S,W+`H@("`@("`@(#!X,T4P-S@T,4,L(#!X-T9$14%%-4,L
M(#!X.$4W1#0T14,L(#!X-3<Q-D8R0C@L"B`@("`@("`@,'A",#-!1$$S-RP@
M,'A&,#4P,$,P1"P@,'A&,#%#,48P-"P@,'@P,C`P0C-&1BP*("`@("`@("`P
M>$%%,$-&-3%!+"`P>#-#0C4W-$(R+"`P>#(U.#,W034X+"`P>$1#,#DR,4)$
M+`H@("`@("`@(#!X1#$Y,3$S1CDL(#!X-T-!.3)&1C8L(#!X.30S,C0W-S,L
M(#!X,C)&-30W,#$L"B`@("`@("`@,'@S044U134X,2P@,'@S-T,R1$%$0RP@
M,'A#.$(U-S8S-"P@,'@Y048S1$1!-RP*("`@("`@("`P>$$Y-#0V,30V+"`P
M>#!&1#`P,S!%+"`P>$5#0SA#-S-%+"`P>$$T-S4Q130Q+`H@("`@("`@(#!X
M13(S.$-$.3DL(#!X,T)%03!%,D8L(#!X,S(X,$)"03$L(#!X,3@S14(S,S$L
M"B`@("`@("`@,'@T134T.$(S."P@,'@T1C9$0CDP."P@,'@V1C0R,$0P,RP@
M,'A&-C!!,#1"1BP*("`@("`@("`P>#)#0C@Q,CDP+"`P>#(T.3<W0S<Y+"`P
M>#4V-SE",#<R+"`P>$)#048X.4%&+`H@("`@("`@(#!X1$4Y03<W,48L(#!X
M1#DY,S`X,3`L(#!X0C,X0D%%,3(L(#!X1$-#1C-&,D4L"B`@("`@("`@,'@U
M-3$R-S(Q1BP@,'@R139"-S$R-"P@,'@U,#%!1$1%-BP@,'@Y1C@T0T0X-RP*
M("`@("`@("`P>#=!-3@T-S$X+"`P>#<T,#A$03$W+"`P>$)#.48Y04)#+"`P
M>$4Y-$(W1#A#+`H@("`@("`@(#!X14,W045#,T$L(#!X1$(X-3%$1D$L(#!X
M-C,P.30S-C8L(#!X0S0V-$,S1#(L"B`@("`@("`@,'A%1C%#,3@T-RP@,'@S
M,C$U1#DP."P@,'A$1#0S,T(S-RP@,'@R-$,R0D$Q-BP*("`@("`@("`P>#$R
M03$T1#0S+"`P>#)!-C5#-#4Q+"`P>#4P.30P,#`R+"`P>#$S,T%%-$1$+`H@
M("`@("`@(#!X-S%$1D8X.44L(#!X,3`S,31%-34L(#!X.#%!0S<W1#8L(#!X
M-48Q,3$Y.4(L"B`@("`@("`@,'@P-#,U-39&,2P@,'A$-T$S0S<V0BP@,'@S
M0S$Q,3@S0BP@,'@U.3(T034P.2P*("`@("`@("`P>$8R.$9%-D5$+"`P>#DW
M1C%&0D9!+"`P>#E%0D%"1C)#+"`P>#%%,34S0S9%+`H@("`@("`@(#!X.#9%
M,S0U-S`L(#!X14%%.39&0C$L(#!X.#8P135%,$$L(#!X-4$S13)!0C,L"B`@
M("`@("`@,'@W-S%&13<Q0RP@,'@T13-$,#9&02P@,'@R.38U1$-".2P@,'@Y
M.44W,40P1BP*("`@("`@("`P>#@P,T4X.40V+"`P>#4R-C9#.#(U+"`P>#)%
M-$-#.3<X+"`P>#E#,3!",S9!+`H@("`@("`@(#!X0S8Q-3!%0D$L(#!X.31%
M,D5!-S@L(#!X035&0S-#-3,L(#!X,44P03)$1C0L"B`@("`@("`@,'A&,D8W
M-$5!-RP@,'@S-C%$,D(S1"P@,'@Q.3,Y,C8P1BP@,'@Q.4,R-SDV,"P*("`@
M("`@("`P>#4R,C-!-S`X+"`P>$8W,3,Q,D(V+"`P>$5"041&139%+"`P>$5!
M0S,Q1C8V+`H@("`@("`@(#!X13-"0S0U.34L(#!X038W0D,X.#,L(#!X0C$W
M1C,W1#$L(#!X,#$X0T9&,C@L"B`@("`@("`@,'A#,S,R1$1%1BP@,'A"139#
M-4%!-2P@,'@V-34X,C$X-2P@,'@V.$%".3@P,BP*("`@("`@("`P>$5%0T5!
M-3!&+"`P>$1",D8Y-3-"+"`P>#)!148W1$%$+"`P>#5"-D4R1C@T+`H@("`@
M("`@(#!X,34R,4(V,C@L(#!X,CDP-S8Q-S`L(#!X14-$1#0W-S4L(#!X-C$Y
M1C$U,3`L"B`@("`@("`@,'@Q,T-#03@S,"P@,'A%0C8Q0D0Y-BP@,'@P,S,T
M1D4Q12P@,'A!03`S-C-#1BP*("`@("`@("`P>$(U-S,U0SDP+"`P>#1#-S!!
M,C,Y+"`P>$0U.44Y13!"+"`P>$-"04%$13$T+`H@("`@("`@(#!X145#0S@V
M0D,L(#!X-C`V,C)#03<L(#!X.4-!0C5#04(L(#!X0C)&,S@T-D4L"B`@("`@
M("`@,'@V-#A",45!1BP@,'@Q.4)$1C!#02P@,'A!,#(S-CE".2P@,'@V-35!
M0D(U,"P*("`@("`@("`P>#0P-C@U03,R+"`P>#-#,D%"-$(S+"`P>#,Q.45%
M.40U+"`P>$,P,C%".$8W+`H@("`@("`@(#!X.4(U-#!",3DL(#!X.#<U1D$P
M.3DL(#!X.35&-SDY-T4L(#!X-C(S1#=$03@L"B`@("`@("`@,'A&.#,W.#@Y
M02P@,'@Y-T4S,D0W-RP@,'@Q,45$.3,U1BP@,'@Q-C8X,3(X,2P*("`@("`@
M("`P>#!%,S4X.#(Y+"`P>$,W138Q1D0V+"`P>#DV1$5$1D$Q+"`P>#<X-3A"
M03DY+`H@("`@("`@(#!X-3=&-3@T034L(#!X,4(R,C<R-C,L(#!X.4(X,T,S
M1D8L(#!X,4%#,C0V.38L"B`@("`@("`@,'A#1$(S,$%%0BP@,'@U,S)%,S`U
M-"P@,'@X1D0Y-#A%-"P@,'@V1$)#,S$R."P*("`@("`@("`P>#4X14)&,D5&
M+"`P>#,T0S9&1D5!+"`P>$9%,CA%1#8Q+"`P>$5%-T,S0S<S+`H@("`@("`@
M(#!X-40T03$T1#DL(#!X13@V-$(W13,L(#!X-#(Q,#5$,30L(#!X,C`S13$S
M13`L"B`@("`@("`@,'@T-45%13)"-BP@,'A!,T%!04)%02P@,'A$0C9#-$8Q
M-2P@,'A&04-"-$9$,"P*("`@("`@("`P>$,W-#)&-#0R+"`P>$5&-D%"0D(U
M+"`P>#8U-$8S0C%$+"`P>#0Q0T0R,3`U+`H@("`@("`@(#!X1#@Q13<Y.44L
M(#!X.#8X-31$0S<L(#!X130T0C0W-D$L(#!X,T0X,38R-3`L"B`@("`@("`@
M,'A#1C8R03%&,BP@,'@U0CA$,C8T-BP@,'A&0S@X.#-!,"P@,'A#,4,W0C9!
M,RP*("`@("`@("`P>#=&,34R-$,S+"`P>#8Y0T(W-#DR+"`P>#0W.#0X03!"
M+"`P>#4V.3)",C@U+`H@("`@("`@(#!X,#DU0D)&,#`L(#!X040Q.30X.40L
M(#!X,30V,D(Q-S0L(#!X,C,X,C!%,#`L"B`@("`@("`@,'@U.#0R.$0R02P@
M,'@P0S4U1C5%02P@,'@Q1$%$1C0S12P@,'@R,S-&-S`V,2P*("`@("`@("`P
M>#,S-S)&,#DR+"`P>#A$.3,W130Q+"`P>$0V-49%0T8Q+"`P>#9#,C(S0D1"
M+`H@("`@("`@(#!X-T-$13,W-3DL(#!X0T)%13<T-C`L(#!X-#`X-48R03<L
M(#!X0T4W-S,R-D4L"B`@("`@("`@,'A!-C`W.#`X-"P@,'@Q.48X-3`Y12P@
M,'A%.$5&1#@U-2P@,'@V,40Y.3<S-2P*("`@("`@("`P>$$Y-CE!-T%!+"`P
M>$,U,$,P-D,R+"`P>#5!,#1!0D9#+"`P>#@P,$)#041#+`H@("`@("`@(#!X
M.44T-#=!,D4L(#!X0S,T-3,T.#0L(#!X1D1$-38W,#4L(#!X,$4Q13E%0SDL
M"B`@("`@("`@,'A$0C<S1$)$,RP@,'@Q,#4U.#A#1"P@,'@V-S5&1$$W.2P@
M,'A%,S8W-#,T,"P*("`@("`@("`P>$,U0S0S-#8U+"`P>#<Q,T4S.$0X+"`P
M>#-$,CA&.#E%+"`P>$8Q-D1&1C(P+`H@("`@("`@(#!X,34S13(Q13<L(#!X
M.$9",#-$-$$L(#!X139%,SE&,D(L(#!X1$(X,T%$1C<I.PH*("`@("\J*@H@
M("`@("H@4R!";W@@*',S*0H@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1S,R`](&%R<F%Y*`H@("`@("`@(#!X13DS1#5!-C@L
M(#!X.30X,30P1C<L(#!X1C8T0S(V,4,L(#!X.30V.3(Y,S0L"B`@("`@("`@
M,'@T,3$U,C!&-RP@,'@W-C`R1#1&-RP@,'A"0T8T-D(R12P@,'A$-$$R,#`V
M."P*("`@("`@("`P>$0T,#@R-#<Q+"`P>#,S,C!&-#9!+"`P>#0S0C=$-$(W
M+"`P>#4P,#`V,4%&+`H@("`@("`@(#!X,44S.48V,D4L(#!X.3<R-#0U-#8L
M(#!X,30R,31&-S0L(#!X0D8X0C@X-#`L"B`@("`@("`@,'@T1#DU1D,Q1"P@
M,'@Y-D(U.3%!1BP@,'@W,$8T1$1$,RP@,'@V-D$P,D8T-2P*("`@("`@("`P
M>$)&0D,P.45#+"`P>#`S0D0Y-S@U+"`P>#=&04,V1$0P+"`P>#,Q0T(X-3`T
M+`H@("`@("`@(#!X.39%0C(W0C,L(#!X-35&1#,Y-#$L(#!X1$$R-30W138L
M(#!X04)#03!!.4$L"B`@("`@("`@,'@R.#4P-S@R-2P@,'@U,S`T,CE&-"P@
M,'@P03)#.#9$02P@,'A%.4(V-D1&0BP*("`@("`@("`P>#8X1$,Q-#8R+"`P
M>$0W-#@V.3`P+"`P>#8X,$5#,$$T+"`P>#(W03$X1$5%+`H@("`@("`@(#!X
M-$8S1D9%03(L(#!X13@X-T%$.$,L(#!X0C4X0T4P,#8L(#!X-T%&-$0V0C8L
M"B`@("`@("`@,'A!04-%,44W0RP@,'A$,S,W-49%0RP@,'A#13<X03,Y.2P@
M,'@T,#9",D$T,BP*("`@("`@("`P>#(P1D4Y13,U+"`P>$0Y1C,X-4(Y+"`P
M>$5%,SE$-T%"+"`P>#-",3(T13A"+`H@("`@("`@(#!X,41#.49!1C<L(#!X
M-$(V1#$X-38L(#!X,C9!,S8V,S$L(#!X14%%,SDW0C(L"B`@("`@("`@,'@S
M039%1D$W-"P@,'A$1#5"-#,S,BP@,'@V.#0Q13=&-RP@,'A#03<X,C!&0BP*
M("`@("`@("`P>$9",$%&-31%+"`P>$0X1D5",SDW+"`P>#0U-#`U-D%#+"`P
M>$)!-#@Y-3(W+`H@("`@("`@(#!X-34U,S-!,T$L(#!X,C`X,SA$.#<L(#!X
M1D4V0D$Y0C<L(#!X1#`Y-CDU-$(L"B`@("`@("`@,'@U-4$X-C="0RP@,'A!
M,3$U.4$U."P@,'A#0T$Y,CDV,RP@,'@Y.44Q1$(S,RP*("`@("`@("`P>$$V
M,D$T034V+"`P>#-&,S$R-48Y+"`P>#5%1C0W13%#+"`P>#DP,CDS,3=#+`H@
M("`@("`@(#!X1D1&.$4X,#(L(#!X,#0R-S)&-S`L(#!X.#!"0C$U-4,L(#!X
M,#4R.#)#13,L"B`@("`@("`@,'@Y-4,Q,34T."P@,'A%-$,V-D0R,BP@,'@T
M.$,Q,3,S1BP@,'A#-S!&.#9$0RP*("`@("`@("`P>#`W1CE#.45%+"`P>#0Q
M,#0Q1C!&+"`P>#0P-#<W.4$T+"`P>#5$.#@V13$W+`H@("`@("`@(#!X,S(U
M1C4Q14(L(#!X1#4Y0D,P1#$L(#!X1C)"0T,Q.$8L(#!X-#$Q,3,U-C0L"B`@
M("`@("`@,'@R-3="-S@S-"P@,'@V,#)!.4,V,"P@,'A$1D8X13A!,RP@,'@Q
M1C8S-D,Q0BP*("`@("`@("`P>#!%,3)"-$,R+"`P>#`R13$S,CE%+"`P>$%&
M-C8T1D0Q+"`P>$-!1#$X,3$U+`H@("`@("`@(#!X-D(R,SDU13`L(#!X,S,S
M13DR13$L(#!X,T(R-#!"-C(L(#!X145"14(Y,C(L"B`@("`@("`@,'@X-4(R
M03(P12P@,'A%-D)!,$0Y.2P@,'A$13<R,$,X0RP@,'@R1$$R1C<R."P*("`@
M("`@("`P>$0P,3(W.#0U+"`P>#DU0C<Y-$9$+"`P>#8T-T0P.#8R+"`P>$4W
M0T-&-48P+`H@("`@("`@(#!X-30T.4$S-D8L(#!X.#<W1#0X1D$L(#!X0S,Y
M1$9$,C<L(#!X1C,S13A$,44L"B`@("`@("`@,'@P030W-C,T,2P@,'@Y.3)%
M1D8W-"P@,'@S039&-D5!0BP@,'A&-$8X1D0S-RP*("`@("`@("`P>$$X,3)$
M0S8P+"`P>$$Q14)$1$8X+"`P>#DY,4)%,31#+"`P>$1"-D4V0C!$+`H@("`@
M("`@(#!X0S8W0C4U,3`L(#!X-D0V-S)#,S<L(#!X,C<V-40T,T(L(#!X1$-$
M,$4X,#0L"B`@("`@("`@,'A&,3(Y,$1#-RP@,'A#0S`P1D9!,RP@,'A"-3,Y
M,$8Y,BP@,'@V.3!&140P0BP*("`@("`@("`P>#8V-T(Y1D9"+"`P>$-%1$(W
M1#E#+"`P>$$P.3%#1C!"+"`P>$0Y,34U14$S+`H@("`@("`@(#!X0D(Q,S)&
M.#@L(#!X-3$U0D%$,C0L(#!X-T(Y-#<Y0D8L(#!X-S8S0D0V14(L"B`@("`@
M("`@,'@S-S,Y,D5",RP@,'A#0S$Q-3DW.2P@,'@X,#(V13(Y-RP@,'A&-#)%
M,S$R1"P*("`@("`@("`P>#8X-#)!1$$W+"`P>$,V-D$R0C-"+"`P>#$R-S4T
M0T-#+"`P>#<X,D5&,3%#+`H@("`@("`@(#!X-D$Q,C0R,S<L(#!X0C<Y,C4Q
M13<L(#!X,#9!,4)"138L(#!X-$)&0C8S-3`L"B`@("`@("`@,'@Q039",3`Q
M."P@,'@Q,4-!141&02P@,'@S1#(U0D1$."P@,'A%,D4Q0S-#.2P*("`@("`@
M("`P>#0T-#(Q-C4Y+"`P>#!!,3(Q,S@V+"`P>$0Y,$-%0S9%+"`P>$0U04)%
M03)!+`H@("`@("`@(#!X-C1!1C8W-$4L(#!X1$$X-D$X-48L(#!X0D5"1D4Y
M.#@L(#!X-C1%-$,S1D4L"B`@("`@("`@,'@Y1$)#.#`U-RP@,'A&,$8W0S`X
M-BP@,'@V,#<X-T)&."P@,'@V,#`S-C`T1"P*("`@("`@("`P>$0Q1D0X,S0V
M+"`P>$8V,S@Q1D(P+"`P>#<W-#5!13`T+"`P>$0W,S9&0T-#+`H@("`@("`@
M(#!X.#,T,C9",S,L(#!X1C`Q14%"-S$L(#!X0C`X,#0Q.#<L(#!X,T,P,#5%
M-48L"B`@("`@("`@,'@W-T$P-3="12P@,'A"1$4X044R-"P@,'@U-30V-#(Y
M.2P@,'A"1C4X,D4V,2P*("`@("`@("`P>#1%-3A&-#A&+"`P>$8R1$1&1$$R
M+"`P>$8T-S1%1C,X+"`P>#@W.#E"1$,R+`H@("`@("`@(#!X-3,V-D8Y0S,L
M(#!X0SA",SA%-S0L(#!X0C0W-48R-34L(#!X-#9&0T0Y0CDL"B`@("`@("`@
M,'@W045",C8V,2P@,'@X0C%$1$8X-"P@,'@X-#9!,$4W.2P@,'@Y,35&.35%
M,BP*("`@("`@("`P>#0V-D4U.3A%+"`P>#(P0C0U-S<P+"`P>#A#1#4U-3DQ
M+"`P>$,Y,#)$131#+`H@("`@("`@(#!X0CDP0D%#13$L(#!X0D(X,C`U1#`L
M(#!X,3%!.#8R-#@L(#!X-S4W-$$Y.44L"B`@("`@("`@,'A"-S=&,3E"-BP@
M,'A%,$$Y1$,P.2P@,'@V-C)$,#E!,2P@,'A#-#,R-#8S,RP*("`@("`@("`P
M>$4X-4$Q1C`R+"`P>#`Y1C!"13A#+"`P>#1!.3E!,#(U+"`P>#%$-D5&13$P
M+`H@("`@("`@(#!X,4%".3-$,40L(#!X,$)!-4$T1$8L(#!X03$X-D8R,$8L
M(#!X,C@V.$8Q-CDL"B`@("`@("`@,'A$0T(W1$$X,RP@,'@U-S,Y,#9&12P@
M,'A!,44R0T4Y0BP@,'@T1D-$-T8U,BP*("`@("`@("`P>#4P,3$U13`Q+"`P
M>$$W,#8X,T9!+"`P>$$P,#)"-4,T+"`P>#!$139$,#(W+`H@("`@("`@(#!X
M.4%&.#A#,C<L(#!X-S<S1C@V-#$L(#!X0S,V,#1#,#8L(#!X-C%!.#`V0C4L
M"B`@("`@("`@,'A&,#$W-T$R."P@,'A#,$8U.#9%,"P@,'@P,#8P-3A!02P@
M,'@S,$1#-T0V,BP*("`@("`@("`P>#$Q138Y140W+"`P>#(S,SA%038S+"`P
M>#4S0S)$1#DT+"`P>$,R0S(Q-C,T+`H@("`@("`@(#!X0D)#0D5%-38L(#!X
M.3!"0T(V1$4L(#!X14)&0S=$03$L(#!X0T4U.3%$-S8L"B`@("`@("`@,'@V
M1C`U130P.2P@,'@T0C=#,#$X."P@,'@S.3<R,$$S1"P@,'@W0SDR-T,R-"P*
M("`@("`@("`P>#@V13,W,C5&+"`P>#<R-$0Y1$(Y+"`P>#%!0S$U0D(T+"`P
M>$0S.45".$9#+`H@("`@("`@(#!X140U-#4U-S@L(#!X,#A&0T$U0C4L(#!X
M1#@S1#=#1#,L(#!X-$1!1#!&0S0L"B`@("`@("`@,'@Q134P148U12P@,'A"
M,38Q139&."P@,'A!,C@U,31$.2P@,'@V0S4Q,3,S0RP*("`@("`@("`P>#9&
M1#5#-T4W+"`P>#4V13$T14,T+"`P>#,V,D%"1D-%+"`P>$1$0S9#.#,W+`H@
M("`@("`@(#!X1#<Y03,R,S0L(#!X.3(V,S@R,3(L(#!X-C<P149!.$4L(#!X
M-#`V,#`P13`I.PH*("`@("\J*@H@("`@("H@4R!";W@@*',T*0H@("`@("H*
M("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1S-"`](&%R<F%Y
M*`H@("`@("`@(#!X,T$S.4-%,S<L(#!X1#-&048U0T8L(#!X04)#,C<W,S<L
M(#!X-4%#-3)$,4(L"B`@("`@("`@,'@U0T(P-C<Y12P@,'@T1D$S,S<T,BP@
M,'A$,S@R,C<T,"P@,'@Y.4)#.4)"12P*("`@("`@("`P>$0U,3$X13E$+"`P
M>$)&,$8W,S$U+"`P>$0V,D0Q0S=%+"`P>$,W,#!#-#="+`H@("`@("`@(#!X
M0C<X0S%"-D(L(#!X,C%!,3DP-#4L(#!X0C(V14(Q0D4L(#!X-D$S-C9%0C0L
M"B`@("`@("`@,'@U-S0X04(R1BP@,'A"0SDT-D4W.2P@,'A#-D$S-S9$,BP@
M,'@V-30Y0S)#."P*("`@("`@("`P>#4S,$9&.$5%+"`P>#0V.$1$13=$+"`P
M>$0U-S,P03%$+"`P>#1#1#`T1$,V+`H@("`@("`@(#!X,CDS.4)"1$(L(#!X
M03E"030V-3`L(#!X04,Y-3(V13@L(#!X0D4U144S,#0L"B`@("`@("`@,'A!
M,49!1#5&,"P@,'@V03)$-3$Y02P@,'@V,T5&.$-%,BP@,'@Y03@V144R,BP*
M("`@("`@("`P>$,P.#E#,D(X+"`P>#0S,C0R148V+"`P>$$U,44P,T%!+"`P
M>#E#1C)$,$$T+`H@("`@("`@(#!X.#-#,#8Q0D$L(#!X.4)%.39!-$0L(#!X
M.$9%-3$U-3`L(#!X0D$V-#5"1#8L"B`@("`@("`@,'@R.#(V03)&.2P@,'A!
M-S-!,T%%,2P@,'@T0D$Y.34X-BP@,'A%1C4U-C)%.2P*("`@("`@("`P>$,W
M,D9%1D0S+"`P>$8W-3)&-T1!+"`P>#-&,#0V1C8Y+"`P>#<W1D$P034Y+`H@
M("`@("`@(#!X.#!%-$$Y,34L(#!X.#=",#@V,#$L(#!X.4(P.44V040L(#!X
M,T(S144U.3,L"B`@("`@("`@,'A%.3DP1D0U02P@,'@Y13,T1#<Y-RP@,'@R
M0T8P0C=$.2P@,'@P,C)".$(U,2P*("`@("`@("`P>#DV1#5!0S-!+"`P>#`Q
M-T1!-C=$+"`P>$0Q0T8S140V+"`P>#=#-T0R1#(X+`H@("`@("`@(#!X,48Y
M1C(U0T8L(#!X041&,D(X.4(L(#!X-4%$-D(T-S(L(#!X-4$X.$8U-$,L"B`@
M("`@("`@,'A%,#(Y04,W,2P@,'A%,#$Y035%-BP@,'@T-T(P04-&1"P@,'A%
M1#DS1D$Y0BP*("`@("`@("`P>$4X1#-#-#A$+"`P>#(X,T(U-T-#+"`P>$8X
M1#4V-C(Y+"`P>#<Y,3,R13(X+`H@("`@("`@(#!X-S@U1C`Q.3$L(#!X140W
M-38P-34L(#!X1C<Y-C!%-#0L(#!X13-$,S5%.$,L"B`@("`@("`@,'@Q-3`U
M-D1$-"P@,'@X.$8T-D1"02P@,'@P,T$Q-C$R-2P@,'@P-38T1C!"1"P*("`@
M("`@("`P>$,S14(Y13$U+"`P>#-#.3`U-T$R+"`P>#DW,C<Q045#+"`P>$$Y
M,T$P-S)!+`H@("`@("`@(#!X,4(S1C9$.4(L(#!X,44V,S(Q1C4L(#!X1C4Y
M0S8V1D(L(#!X,C9$0T8S,3DL"B`@("`@("`@,'@W-3,S1#DR."P@,'A",34U
M1D1&-2P@,'@P,S4V,S0X,BP@,'@X04)!,T-"0BP*("`@("`@("`P>#(X-3$W
M-S$Q+"`P>$,R,$%$.48X+"`P>$%"0T,U,38W+"`P>$-#040Y,C5&+`H@("`@
M("`@(#!X-$1%.#$W-3$L(#!X,S@S,$1#.$4L(#!X,S<Y1#4X-C(L(#!X.3,R
M,$8Y.3$L"B`@("`@("`@,'A%03=!.3!#,BP@,'A&0C-%-T)#12P@,'@U,3(Q
M0T4V-"P@,'@W-S1&0D4S,BP*("`@("`@("`P>$$X0C9%,S=%+"`P>$,S,CDS
M1#0V+"`P>#0X1$4U,S8Y+"`P>#8T,3-%-C@P+`H@("`@("`@(#!X03)!13`X
M,3`L(#!X1$0V1$(R,C0L(#!X-CDX-3)$1D0L(#!X,#DP-S(Q-C8L"B`@("`@
M("`@,'A",SE!-#8P02P@,'@V-#0U0S!$1"P@,'@U.#9#1$5#1BP@,'@Q0S(P
M0SA!12P*("`@("`@("`P>#5"0D5&-T1$+"`P>#%"-3@X1#0P+"`P>$-#1#(P
M,3=&+"`P>#9"0C1%,T)"+`H@("`@("`@(#!X1$1!,C9!-T4L(#!X,T$U.49&
M-#4L(#!X,T4S-3!!-#0L(#!X0D-"-$-$1#4L"B`@("`@("`@,'@W,D5!0T5!
M."P@,'A&038T.#1"0BP@,'@X1#8V,3)!12P@,'A"1C-#-D8T-RP*("`@("`@
M("`P>$0R.4)%-#8S+"`P>#4T,D8U1#E%+"`P>$%%0S(W-S%"+"`P>$8V-$4V
M,S<P+`H@("`@("`@(#!X-S0P13!$.$0L(#!X13<U0C$S-3<L(#!X1C@W,C$V
M-S$L(#!X048U,S=$-40L"B`@("`@("`@,'@T,#0P0T(P."P@,'@T14(T13)#
M0RP@,'@S-$0R-#8V02P@,'@P,3$U048X-"P*("`@("`@("`P>$4Q0C`P-#(X
M+"`P>#DU.3@S03%$+"`P>#`V0C@Y1D(T+"`P>$-%-D5!,#0X+`H@("`@("`@
M(#!X-D8S1C-".#(L(#!X,S4R,$%".#(L(#!X,#$Q03%$-$(L(#!X,C<W,C(W
M1C@L"B`@("`@("`@,'@V,3$U-C!",2P@,'A%-SDS,T9$0RP@,'A"0C-!-SDR
M0BP@,'@S-#0U,C5"1"P*("`@("`@("`P>$$P.#@S.44Q+"`P>#4Q0T4W.31"
M+"`P>#)&,S)#.4(W+"`P>$$P,49"04,Y+`H@("`@("`@(#!X13`Q0T,X-T4L
M(#!X0D-#-T0Q1C8L(#!X0T8P,3$Q0S,L(#!X03%%.$%!0S<L"B`@("`@("`@
M,'@Q03DP.#<T.2P@,'A$-#1&0D0Y02P@,'A$,$1!1$5#0BP@,'A$-3!!1$$S
M."P*("`@("`@("`P>#`S,SE#,S)!+"`P>$,V.3$S-C8W+"`P>#A$1CDS,3=#
M+"`P>$4P0C$R0C1&+`H@("`@("`@(#!X1C<Y134Y0C<L(#!X-#-&-4)",T$L
M(#!X1C)$-3$Y1D8L(#!X,C=$.30U.4,L"B`@("`@("`@,'A"1CDW,C(R0RP@
M,'@Q-44V1D,R02P@,'@P1CDQ1D,W,2P@,'@Y0CDT,34R-2P*("`@("`@("`P
M>$9!134Y,S8Q+"`P>$-%0C8Y0T5"+"`P>$,R03@V-#4Y+"`P>#$R0D%!.$0Q
M+`H@("`@("`@(#!X0C9#,3`W-44L(#!X13,P-39!,$,L(#!X,3!$,C4P-C4L
M(#!X0T(P,T$T-#(L"B`@("`@("`@,'A%,$5#-D4P12P@,'@Q-CDX1$(S0BP@
M,'@T0SDX03!"12P@,'@S,C<X13DV-"P*("`@("`@("`P>#E&,48Y-3,R+"`P
M>$4P1#,Y,D1&+"`P>$0S03`S-#)"+"`P>#@Y-S%&,C%%+`H@("`@("`@(#!X
M,4(P03<T-#$L(#!X-$)!,S,T.$,L(#!X0S5"13<Q,C`L(#!X0S,W-C,R1#@L
M"B`@("`@("`@,'A$1C,U.48X1"P@,'@Y0CDY,D8R12P@,'A%-C!"-D8T-RP@
M,'@P1D4S1C$Q1"P*("`@("`@("`P>$4U-$-$034T+"`P>#%%1$%$.#DQ+"`P
M>$-%-C(W.4-&+"`P>$-$,T4W139&+`H@("`@("`@(#!X,38Q.$(Q-C8L(#!X
M1D0R0S%$,#4L(#!X.#0X1D0R0S4L(#!X1C9&0C(R.3DL"B`@("`@("`@,'A&
M-3(S1C,U-RP@,'A!-C,R-S8R,RP@,'@Y,T$X,S4S,2P@,'@U-D-#0T0P,BP*
M("`@("`@("`P>$%#1C`X,38R+"`P>#5!-S5%0D(U+"`P>#9%,38S-CDW+"`P
M>#@X1#(W,T-#+`H@("`@("`@(#!X1$4Y-C8R.3(L(#!X.#%".30Y1#`L(#!X
M-$,U,#DP,4(L(#!X-S%#-C4V,30L"B`@("`@("`@,'A%-D,V0S="1"P@,'@S
M,C=!,30P02P@,'@T-44Q1#`P-BP@,'A#,T8R-T(Y02P*("`@("`@("`P>$,Y
M04$U,T9$+"`P>#8R03@P1C`P+"`P>$)",C5"1D4R+"`P>#,U0D1$,D8V+`H@
M("`@("`@(#!X-S$Q,C8Y,#4L(#!X0C(P-#`R,C(L(#!X0C9#0D-&-T,L(#!X
M0T0W-CE#,D(L"B`@("`@("`@,'@U,S$Q,T5#,"P@,'@Q-C0P13-$,RP@,'@S
M.$%"0D0V,"P@,'@R-30W041&,"P*("`@("`@("`P>$)!,S@R,#E#+"`P>$8W
M-#9#13<V+"`P>#<W049!,4,U+"`P>#(P-S4V,#8P+`H@("`@("`@(#!X.#5#
M0D9%-$4L(#!X.$%%.#A$1#@L(#!X-T%!048Y0C`L(#!X-$-&.4%!-T4L"B`@
M("`@("`@,'@Q.30X0S(U0RP@,'@P,D9".$$X0RP@,'@P,4,S-D%%-"P@,'A$
M-D5"13%&.2P*("`@("`@("`P>#DP1#1&.#8Y+"`P>$$V-4-$14$P+"`P>#-&
M,#DR-3)$+"`P>$,R,#A%-CE&+`H@("`@("`@(#!X0C<T138Q,S(L(#!X0T4W
M-T4R-4(L(#!X-3<X1D1&13,L(#!X,T%#,S<R138I.PH*("`@("\J*@H@("`@
M("H@5&AE(&YU;6)E<B!O9B!R;W5N9',@=&\@9&\*("`@("`J"B`@("`@*B!`
M=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?<F]U;F1S(#T@,38["@H@
M("`@+RHJ"B`@("`@*B!3970@=&AE(&ME>2!T;R!B92!U<V5D(&9O<B!E;B]D
M96-R>7!T:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ME>2`@
M5&AE(&ME>2!T;R!U<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$ME>2@D
M:V5Y*0H@("`@>PH@("`@("`@("1K97D@/2`D=&AI<RT^7V9O<FUA=$ME>2@D
M:V5Y*3L*("`@("`@("`D:V5Y4&]S(#T@,#L*("`@("`@("`D:V5Y6&]R(#T@
M,#L*"B`@("`@("`@)&E-87@@/2!C;W5N="@D=&AI<RT^<"D["B`@("`@("`@
M)&ME>4QE;B`](&-O=6YT*"1K97DI.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D
M:2`\("1I36%X.R`D:2LK*2!["B`@("`@("`@("`@(&9O<B`H)'0@/2`P.R`D
M="`\(#0[("1T*RLI('L*("`@("`@("`@("`@("`@("1K97E8;W(@/2`H)&ME
M>5AO<B`\/"`X*2!\("@H)&ME>5LD:V5Y4&]S72D@)B`P>#!F9BD["B`@("`@
M("`@("`@("`@("!I9B`H*RLD:V5Y4&]S(#T]("1K97E,96XI('L*("`@("`@
M("`@("`@("`@("`@("`D:V5Y4&]S(#T@,#L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^<%LD:5T@/2`D=&AI
M<RT^<%LD:5T@7B`D:V5Y6&]R.PH@("`@("`@('T*"B`@("`@("`@)&5N8UIE
M<F\@/2!A<G)A>2@G3"<@/3X@,"P@)U(G(#T^(#`I.PH@("`@("`@(&9O<B`H
M)&D@/2`P.R`D:2`K(#$@/"`D:4UA>#L@)&D@*ST@,BD@>PH@("`@("`@("`@
M("`D96YC6F5R;R`]("1T:&ES+3Y?96YC<GEP=$)L;V-K*"1E;F-:97)O6R=,
M)UTL("1E;F-:97)O6R=2)UTI.PH@("`@("`@("`@("`D=&AI<RT^<%LD:5T@
M/2`D96YC6F5R;ULG3"==.PH@("`@("`@("`@("`D=&AI<RT^<%LD:2`K(#%=
M(#T@)&5N8UIE<F];)U(G73L*("`@("`@("!]"@H@("`@("`@("1I36%X(#T@
M8V]U;G0H)'1H:7,M/G,Q*3L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D
M:4UA>#L@)&D@*ST@,BD@>PH@("`@("`@("`@("`D96YC6F5R;R`]("1T:&ES
M+3Y?96YC<GEP=$)L;V-K*"1E;F-:97)O6R=,)UTL("1E;F-:97)O6R=2)UTI
M.PH@("`@("`@("`@("`D=&AI<RT^<S%;)&E=(#T@)&5N8UIE<F];)TPG73L*
M("`@("`@("`@("`@)'1H:7,M/G,Q6R1I("L@,5T@/2`D96YC6F5R;ULG4B==
M.PH@("`@("`@('T*"B`@("`@("`@)&E-87@@/2!C;W5N="@D=&AI<RT^<S(I
M.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1I36%X.R`D:2`K/2`R*2![
M"B`@("`@("`@("`@("1E;F-:97)O(#T@)'1H:7,M/E]E;F-R>7!T0FQO8VLH
M)&5N8UIE<F];)TPG72P@)&5N8UIE<F];)U(G72D["B`@("`@("`@("`@("1T
M:&ES+3YS,ELD:5T@/2`D96YC6F5R;ULG3"==.PH@("`@("`@("`@("`D=&AI
M<RT^<S);)&D@*R`Q72`]("1E;F-:97)O6R=2)UT["B`@("`@("`@?0H*("`@
M("`@("`D:4UA>"`](&-O=6YT*"1T:&ES+3YS,RD["B`@("`@("`@9F]R("@D
M:2`](#`[("1I(#P@)&E-87@[("1I("L](#(I('L*("`@("`@("`@("`@)&5N
M8UIE<F\@/2`D=&AI<RT^7V5N8W)Y<'1";&]C:R@D96YC6F5R;ULG3"==+"`D
M96YC6F5R;ULG4B==*3L*("`@("`@("`@("`@)'1H:7,M/G,S6R1I72`]("1E
M;F-:97)O6R=,)UT["B`@("`@("`@("`@("1T:&ES+3YS,ULD:2`K(#%=(#T@
M)&5N8UIE<F];)U(G73L*("`@("`@("!]"@H@("`@("`@("1I36%X(#T@8V]U
M;G0H)'1H:7,M/G,T*3L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D:4UA
M>#L@)&D@*ST@,BD@>PH@("`@("`@("`@("`D96YC6F5R;R`]("1T:&ES+3Y?
M96YC<GEP=$)L;V-K*"1E;F-:97)O6R=,)UTL("1E;F-:97)O6R=2)UTI.PH@
M("`@("`@("`@("`D=&AI<RT^<S1;)&E=(#T@)&5N8UIE<F];)TPG73L*("`@
M("`@("`@("`@)'1H:7,M/G,T6R1I("L@,5T@/2`D96YC6F5R;ULG4B==.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@<VEZ
M92!O9B!T:&4@8FQO8VMS('1H870@=&AI<R!C:7!H97(@;F5E9',N"B`@("`@
M*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@;G5M8F5R(&]F(&-H87)A
M8W1E<G,@<&5R(&)L;V-K+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971";&]C
M:U-I>F4H*0H@("`@>PH@("`@("`@(')E='5R;B`X.PH@("`@?0H*("`@("\J
M*@H@("`@("H@16YC<GEP="!A(&)L;V-K(&]F(&1A=&$N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D8FQO8VL@("`@("!4:&4@9&%T82!T;R!E;F-R
M>7!T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("`@("`@("!4:&4@:V5Y
M('1O('5S92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&5N
M8W)Y<'1E9"!O=71P=70N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N8W)Y<'1"
M;&]C:R@D8FQO8VLL("1K97D@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A
M:7-?;G5L;"@D:V5Y*2D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T2V5Y*"1K
M97DI.PH@("`@("`@('T*"B`@("`@("`@;&ES="@D3"P@)%(I(#T@87)R87E?
M=F%L=65S*'5N<&%C:R@G3BHG+"`D8FQO8VLI*3L*("`@("`@("`D<&%R=',@
M/2`D=&AI<RT^7V5N8W)Y<'1";&]C:R@D3"P@)%(I.PH@("`@("`@(')E='5R
M;B!P86-K*"=.3B<L("1P87)T<ULG3"==+"`D<&%R='-;)U(G72D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!%;F-R>7!T(&QE9G0@86YD(')I9VAT(&AA;'9E
M<R!O9B!A(&)L;V-K(&]F(&1A=&$N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)$P@($QE9G0@
M:&%L9B!O9B!T:&4@9&%T82X*("`@("`J($!P87)A;2!I;G1E9V5R("12("!2
M:6=H="!H86QF(&]F('1H92!D871A+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@($$@:&%S:"P@=VET:"!K97ES("=,)R!A;F0@)U(G+"!A;F0@=&AE
M(&5N8W)Y<'1E9"!D871A(&%S"B`@("`@*B`@("`@("`@("`@("`@("!T:&4@
M=F%L=65S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?96YC<GEP=$)L;V-K*"1,
M+"`D4BD*("`@('L*("`@("`@("`D3"!>/2`D=&AI<RT^<%LP73L*("`@("`@
M("`D4B!>/2`H*"@D=&AI<RT^<S%;*"1,(#X^(#(T*2`F(#!X1D9=("L@)'1H
M:7,M/G,R6R@D3"`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H:7,M/G,S6R@D3"`^
M/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;)$P@)B`P>#!F9ETI(%X@)'1H
M:7,M/G!;,5T["B`@("`@("`@)$P@7CT@*"@H)'1H:7,M/G,Q6R@D4B`^/B`R
M-"D@)B`P>$9&72`K("1T:&ES+3YS,ELH)%(@/CX@,38I("8@,'@P9F9=*2!>
M("1T:&ES+3YS,ULH)%(@/CX@."D@)B`P>#!F9ETI("L@)'1H:7,M/G,T6R12
M("8@,'@P9F9=*2!>("1T:&ES+3YP6S)=.PH@("`@("`@("12(%X]("@H*"1T
M:&ES+3YS,5LH)$P@/CX@,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);*"1,(#X^
M(#$V*2`F(#!X,&9F72D@7B`D=&AI<RT^<S-;*"1,(#X^(#@I("8@,'@P9F9=
M*2`K("1T:&ES+3YS-%LD3"`F(#!X,&9F72D@7B`D=&AI<RT^<%LS73L*("`@
M("`@("`D3"!>/2`H*"@D=&AI<RT^<S%;*"12(#X^(#(T*2`F(#!X1D9=("L@
M)'1H:7,M/G,R6R@D4B`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H:7,M/G,S6R@D
M4B`^/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;)%(@)B`P>#!F9ETI(%X@
M)'1H:7,M/G!;-%T["B`@("`@("`@)%(@7CT@*"@H)'1H:7,M/G,Q6R@D3"`^
M/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS,ELH)$P@/CX@,38I("8@,'@P9F9=
M*2!>("1T:&ES+3YS,ULH)$P@/CX@."D@)B`P>#!F9ETI("L@)'1H:7,M/G,T
M6R1,("8@,'@P9F9=*2!>("1T:&ES+3YP6S5=.PH@("`@("`@("1,(%X]("@H
M*"1T:&ES+3YS,5LH)%(@/CX@,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);*"12
M(#X^(#$V*2`F(#!X,&9F72D@7B`D=&AI<RT^<S-;*"12(#X^(#@I("8@,'@P
M9F9=*2`K("1T:&ES+3YS-%LD4B`F(#!X,&9F72D@7B`D=&AI<RT^<%LV73L*
M("`@("`@("`D4B!>/2`H*"@D=&AI<RT^<S%;*"1,(#X^(#(T*2`F(#!X1D9=
M("L@)'1H:7,M/G,R6R@D3"`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H:7,M/G,S
M6R@D3"`^/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;)$P@)B`P>#!F9ETI
M(%X@)'1H:7,M/G!;-UT["B`@("`@("`@)$P@7CT@*"@H)'1H:7,M/G,Q6R@D
M4B`^/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS,ELH)%(@/CX@,38I("8@,'@P
M9F9=*2!>("1T:&ES+3YS,ULH)%(@/CX@."D@)B`P>#!F9ETI("L@)'1H:7,M
M/G,T6R12("8@,'@P9F9=*2!>("1T:&ES+3YP6SA=.PH@("`@("`@("12(%X]
M("@H*"1T:&ES+3YS,5LH)$P@/CX@,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);
M*"1,(#X^(#$V*2`F(#!X,&9F72D@7B`D=&AI<RT^<S-;*"1,(#X^(#@I("8@
M,'@P9F9=*2`K("1T:&ES+3YS-%LD3"`F(#!X,&9F72D@7B`D=&AI<RT^<%LY
M73L*("`@("`@("`D3"!>/2`H*"@D=&AI<RT^<S%;*"12(#X^(#(T*2`F(#!X
M1D9=("L@)'1H:7,M/G,R6R@D4B`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H:7,M
M/G,S6R@D4B`^/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;)%(@)B`P>#!F
M9ETI(%X@)'1H:7,M/G!;,3!=.PH@("`@("`@("12(%X]("@H*"1T:&ES+3YS
M,5LH)$P@/CX@,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);*"1,(#X^(#$V*2`F
M(#!X,&9F72D@7B`D=&AI<RT^<S-;*"1,(#X^(#@I("8@,'@P9F9=*2`K("1T
M:&ES+3YS-%LD3"`F(#!X,&9F72D@7B`D=&AI<RT^<%LQ,5T["B`@("`@("`@
M)$P@7CT@*"@H)'1H:7,M/G,Q6R@D4B`^/B`R-"D@)B`P>$9&72`K("1T:&ES
M+3YS,ELH)%(@/CX@,38I("8@,'@P9F9=*2!>("1T:&ES+3YS,ULH)%(@/CX@
M."D@)B`P>#!F9ETI("L@)'1H:7,M/G,T6R12("8@,'@P9F9=*2!>("1T:&ES
M+3YP6S$R73L*("`@("`@("`D4B!>/2`H*"@D=&AI<RT^<S%;*"1,(#X^(#(T
M*2`F(#!X1D9=("L@)'1H:7,M/G,R6R@D3"`^/B`Q-BD@)B`P>#!F9ETI(%X@
M)'1H:7,M/G,S6R@D3"`^/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;)$P@
M)B`P>#!F9ETI(%X@)'1H:7,M/G!;,3-=.PH@("`@("`@("1,(%X]("@H*"1T
M:&ES+3YS,5LH)%(@/CX@,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);*"12(#X^
M(#$V*2`F(#!X,&9F72D@7B`D=&AI<RT^<S-;*"12(#X^(#@I("8@,'@P9F9=
M*2`K("1T:&ES+3YS-%LD4B`F(#!X,&9F72D@7B`D=&AI<RT^<%LQ-%T["B`@
M("`@("`@)%(@7CT@*"@H)'1H:7,M/G,Q6R@D3"`^/B`R-"D@)B`P>$9&72`K
M("1T:&ES+3YS,ELH)$P@/CX@,38I("8@,'@P9F9=*2!>("1T:&ES+3YS,ULH
M)$P@/CX@."D@)B`P>#!F9ETI("L@)'1H:7,M/G,T6R1,("8@,'@P9F9=*2!>
M("1T:&ES+3YP6S$U73L*("`@("`@("`D3"!>/2`H*"@D=&AI<RT^<S%;*"12
M(#X^(#(T*2`F(#!X1D9=("L@)'1H:7,M/G,R6R@D4B`^/B`Q-BD@)B`P>#!F
M9ETI(%X@)'1H:7,M/G,S6R@D4B`^/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^
M<S1;)%(@)B`P>#!F9ETI(%X@)'1H:7,M/G!;,39=.PH@("`@("`@("12(%X]
M("1T:&ES+3YP6S$W73L*"B`@("`@("`@<F5T=7)N(&%R<F%Y*"=,)R`]/B`D
M4BP@)U(G(#T^("1,*3L*("`@('T*"B`@("`O*BH*("`@("`J($1E8W)Y<'0@
M82!B;&]C:R!O9B!D871A+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&)L;V-K("!4:&4@9&%T82!T;R!D96-R>7!T+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D:V5Y("`@(%1H92!K97D@=&\@=7-E+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@9&5C<GEP=&5D(&]U='!U="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9&5C<GEP=$)L;V-K*"1B;&]C:RP@)&ME>2`](&YU;&PI
M"B`@("!["B`@("`@("`@:68@*"%I<U]N=6QL*"1K97DI*2!["B`@("`@("`@
M("`@("1T:&ES+3YS971+97DH)&ME>2D["B`@("`@("`@?0H*("`@("`@("!L
M:7-T*"1,+"`D4BD@/2!A<G)A>5]V86QU97,H=6YP86-K*"=.*B<L("1B;&]C
M:RDI.PH*("`@("`@("`D3"!>/2`D=&AI<RT^<%LQ-UT["B`@("`@("`@)%(@
M7CT@*"@H)'1H:7,M/G,Q6R@D3"`^/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS
M,ELH)$P@/CX@,38I("8@,'@P9F9=*2!>("1T:&ES+3YS,ULH)$P@/CX@."D@
M)B`P>#!F9ETI("L@)'1H:7,M/G,T6R1,("8@,'@P9F9=*2!>("1T:&ES+3YP
M6S$V73L*("`@("`@("`D3"!>/2`H*"@D=&AI<RT^<S%;*"12(#X^(#(T*2`F
M(#!X1D9=("L@)'1H:7,M/G,R6R@D4B`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H
M:7,M/G,S6R@D4B`^/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;)%(@)B`P
M>#!F9ETI(%X@)'1H:7,M/G!;,35=.PH@("`@("`@("12(%X]("@H*"1T:&ES
M+3YS,5LH)$P@/CX@,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);*"1,(#X^(#$V
M*2`F(#!X,&9F72D@7B`D=&AI<RT^<S-;*"1,(#X^(#@I("8@,'@P9F9=*2`K
M("1T:&ES+3YS-%LD3"`F(#!X,&9F72D@7B`D=&AI<RT^<%LQ-%T["B`@("`@
M("`@)$P@7CT@*"@H)'1H:7,M/G,Q6R@D4B`^/B`R-"D@)B`P>$9&72`K("1T
M:&ES+3YS,ELH)%(@/CX@,38I("8@,'@P9F9=*2!>("1T:&ES+3YS,ULH)%(@
M/CX@."D@)B`P>#!F9ETI("L@)'1H:7,M/G,T6R12("8@,'@P9F9=*2!>("1T
M:&ES+3YP6S$S73L*("`@("`@("`D4B!>/2`H*"@D=&AI<RT^<S%;*"1,(#X^
M(#(T*2`F(#!X1D9=("L@)'1H:7,M/G,R6R@D3"`^/B`Q-BD@)B`P>#!F9ETI
M(%X@)'1H:7,M/G,S6R@D3"`^/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;
M)$P@)B`P>#!F9ETI(%X@)'1H:7,M/G!;,3)=.PH@("`@("`@("1,(%X]("@H
M*"1T:&ES+3YS,5LH)%(@/CX@,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);*"12
M(#X^(#$V*2`F(#!X,&9F72D@7B`D=&AI<RT^<S-;*"12(#X^(#@I("8@,'@P
M9F9=*2`K("1T:&ES+3YS-%LD4B`F(#!X,&9F72D@7B`D=&AI<RT^<%LQ,5T[
M"B`@("`@("`@)%(@7CT@*"@H)'1H:7,M/G,Q6R@D3"`^/B`R-"D@)B`P>$9&
M72`K("1T:&ES+3YS,ELH)$P@/CX@,38I("8@,'@P9F9=*2!>("1T:&ES+3YS
M,ULH)$P@/CX@."D@)B`P>#!F9ETI("L@)'1H:7,M/G,T6R1,("8@,'@P9F9=
M*2!>("1T:&ES+3YP6S$P73L*("`@("`@("`D3"!>/2`H*"@D=&AI<RT^<S%;
M*"12(#X^(#(T*2`F(#!X1D9=("L@)'1H:7,M/G,R6R@D4B`^/B`Q-BD@)B`P
M>#!F9ETI(%X@)'1H:7,M/G,S6R@D4B`^/B`X*2`F(#!X,&9F72D@*R`D=&AI
M<RT^<S1;)%(@)B`P>#!F9ETI(%X@)'1H:7,M/G!;.5T["B`@("`@("`@)%(@
M7CT@*"@H)'1H:7,M/G,Q6R@D3"`^/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS
M,ELH)$P@/CX@,38I("8@,'@P9F9=*2!>("1T:&ES+3YS,ULH)$P@/CX@."D@
M)B`P>#!F9ETI("L@)'1H:7,M/G,T6R1,("8@,'@P9F9=*2!>("1T:&ES+3YP
M6SA=.PH@("`@("`@("1,(%X]("@H*"1T:&ES+3YS,5LH)%(@/CX@,C0I("8@
M,'A&1ET@*R`D=&AI<RT^<S);*"12(#X^(#$V*2`F(#!X,&9F72D@7B`D=&AI
M<RT^<S-;*"12(#X^(#@I("8@,'@P9F9=*2`K("1T:&ES+3YS-%LD4B`F(#!X
M,&9F72D@7B`D=&AI<RT^<%LW73L*("`@("`@("`D4B!>/2`H*"@D=&AI<RT^
M<S%;*"1,(#X^(#(T*2`F(#!X1D9=("L@)'1H:7,M/G,R6R@D3"`^/B`Q-BD@
M)B`P>#!F9ETI(%X@)'1H:7,M/G,S6R@D3"`^/B`X*2`F(#!X,&9F72D@*R`D
M=&AI<RT^<S1;)$P@)B`P>#!F9ETI(%X@)'1H:7,M/G!;-ET["B`@("`@("`@
M)$P@7CT@*"@H)'1H:7,M/G,Q6R@D4B`^/B`R-"D@)B`P>$9&72`K("1T:&ES
M+3YS,ELH)%(@/CX@,38I("8@,'@P9F9=*2!>("1T:&ES+3YS,ULH)%(@/CX@
M."D@)B`P>#!F9ETI("L@)'1H:7,M/G,T6R12("8@,'@P9F9=*2!>("1T:&ES
M+3YP6S5=.PH@("`@("`@("12(%X]("@H*"1T:&ES+3YS,5LH)$P@/CX@,C0I
M("8@,'A&1ET@*R`D=&AI<RT^<S);*"1,(#X^(#$V*2`F(#!X,&9F72D@7B`D
M=&AI<RT^<S-;*"1,(#X^(#@I("8@,'@P9F9=*2`K("1T:&ES+3YS-%LD3"`F
M(#!X,&9F72D@7B`D=&AI<RT^<%LT73L*("`@("`@("`D3"!>/2`H*"@D=&AI
M<RT^<S%;*"12(#X^(#(T*2`F(#!X1D9=("L@)'1H:7,M/G,R6R@D4B`^/B`Q
M-BD@)B`P>#!F9ETI(%X@)'1H:7,M/G,S6R@D4B`^/B`X*2`F(#!X,&9F72D@
M*R`D=&AI<RT^<S1;)%(@)B`P>#!F9ETI(%X@)'1H:7,M/G!;,UT["B`@("`@
M("`@)%(@7CT@*"@H)'1H:7,M/G,Q6R@D3"`^/B`R-"D@)B`P>$9&72`K("1T
M:&ES+3YS,ELH)$P@/CX@,38I("8@,'@P9F9=*2!>("1T:&ES+3YS,ULH)$P@
M/CX@."D@)B`P>#!F9ETI("L@)'1H:7,M/G,T6R1,("8@,'@P9F9=*2!>("1T
M:&ES+3YP6S)=.PH@("`@("`@("1,(%X]("@H*"1T:&ES+3YS,5LH)%(@/CX@
M,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);*"12(#X^(#$V*2`F(#!X,&9F72D@
M7B`D=&AI<RT^<S-;*"12(#X^(#@I("8@,'@P9F9=*2`K("1T:&ES+3YS-%LD
M4B`F(#!X,&9F72D@7B`D=&AI<RT^<%LQ73L*"B`@("`@("`@)&1E8W)Y<'1E
M9"`]('!A8VLH(DY.(BP@)%(@7B`D=&AI<RT^<%LP72P@)$PI.PH@("`@("`@
M(')E='5R;B`D9&5C<GEP=&5D.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N
M=F5R=',@82!T97AT(&ME>2!I;G1O(&%N(&%R<F%Y+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&ME>2`@2V5Y(&EN('1E>'0@9F]R;6%T+@H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!K97D@:6X@87)R87D@9F]R
M;6%T+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9F]R;6%T2V5Y*"1K97DI"B`@
M("!["B`@("`@("`@<F5T=7)N(&%R<F%Y7W9A;'5E<RAU;G!A8VLH)T,J)RP@
M)&ME>2DI.PH@("`@?0H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B](;W)D92]#:7!H97(O0FQO8VM-;V1E+G!H<```````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,S8R,B`Q,#4Q-30S,S<S-R`P,C,Q,S<`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J(%1H92!(;W)D95]#:7!H97)?0FQO8VM-;V1E.CH@8VQA<W,@
M<')O=FED97,@82!C;VUM;VX@86)S=')A8W1E9`H@*B!I;G1E<F9A8V4@=&\@
M=F%R:6]U<R!B;&]C:R!M;V1E(&AA;F1L97)S(&9O<B!C:7!H97)S+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]#:7!H97(O0VEP:&5R+T)L;V-K36]D92YP
M:'`L=B`Q+C$T+C$R+CD@,C`P-B\P,2\P,2`R,3HR.#HQ,"!J86X@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME
M0&=R869T;VYH86QL+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@
M0'-I;F-E("`@2&]R9&4@,BXR"B`J($!P86-K86=E($AO<F1E7T-I<&AE<@H@
M*B\*8VQA<W,@2&]R9&5?0VEP:&5R7T)L;V-K36]D92!["@H@("`@+RHJ"B`@
M("`@*B!4:&4@:6YI=&EA;&EZ871I;VX@=F5C=&]R+@H@("`@("H*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VEV(#T@(EPP7#!<,%PP
M7#!<,%PP7#`B.PH*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N
M(&$@8V]N8W)E=&4@2&]R9&5?0VEP:&5R7T)L;V-K36]D92!I;G-T86YC92!B
M87-E9"!O;@H@("`@("H@)&UO9&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;6]D92`@(%1H92!T>7!E(&]F(&-O;F-R971E($AO<F1E7T-I<&AE
M<E]";&]C:TUO9&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!S=6)C
M;&%S<R!T;R!R971U<FXN"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@
M02!H87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@<&%R86UE=&5R<R!A
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<W5B8VQA<W,@;6EG:'0@
M;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N($AO<F1E7T-I<&AE<E]";&]C
M:TUO9&4@(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R971E"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@($-I<&AE<D)L;V-K36]D92!I
M;G-T86YC92P@;W(@4$5!4E]%<G)O<@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@)F9A8W1O<GDH)&UO9&4L("1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@
M("`@("1M;V1E(#T@8F%S96YA;64H)&UO9&4I.PH@("`@("`@(&EF("A`9FEL
M95]E>&ES=',H9&ER;F%M92A?7T9)3$5?7RD@+B`G+T)L;V-K36]D92\G("X@
M)&UO9&4@+B`G+G!H<"<I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92!D
M:7)N86UE*%]?1DE,15]?*2`N("<O0FQO8VM-;V1E+R<@+B`D;6]D92`N("<N
M<&AP)SL*("`@("`@("!]"@H@("`@("`@("1C;&%S<R`]("=(;W)D95]#:7!H
M97)?0FQO8VM-;V1E7R<@+B`D;6]D93L*("`@("`@("!I9B`H8VQA<W-?97AI
M<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@)&)L;V-K;6]D92`]("9N97<@
M)&-L87-S*"1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1B;&]C:VUO9&4@/2!014%2.CIR86ES945R<F]R*"=#;&%S<R!D969I;FET
M:6]N(&]F("<@+B`D8VQA<W,@+B`G(&YO="!F;W5N9"XG*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D8FQO8VMM;V1E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4V5T('1H92!)5@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&EV("!4:&4@;F5W($E6+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971)5B@D
M:78I"B`@("!["B`@("`@("`@)'1H:7,M/E]I=B`]("1I=CL*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O0VEP:&5R+V1E<RYP:'``````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,C<R,#(@,3`U,34T,S,W,S<@,#(R,#4S`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B!4:&4@0VEP:&5R7V1E<SHZ(&-L87-S(&EM<&QE;65N=',@=&AE($-I
M<&AE<B!I;G1E<F9A8V4@96YC<GEP=&EO;B!D871A"B`J('5S:6YG('1H92!$
M871A($5N8W)Y<'1I;VX@4W1A;F1A<F0@*$1%4RD@86QG;W)I=&AM(&%S(&1E
M9FEN92!I;B!&25!3-#8M,RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO0VEP
M:&5R+T-I<&AE<B]D97,N<&AP+'8@,2XT+C$R+C<@,C`P-B\P,2\P,2`R,3HR
M.#HQ,"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6ME
M($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("H*("H@0&%U=&AO<B`@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N
M:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E
M($AO<F1E7T-I<&AE<@H@*B\*8VQA<W,@2&]R9&5?0VEP:&5R7V1E<R!E>'1E
M;F1S($AO<F1E7T-I<&AE<B!["@H@("`@+RHJ"B`@("`@*B!);FET:6%L(%!E
M<FUU=&%T:6]N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)&EP(#T@87)R87DH"B`@("`@("`@-3@L(#4P+"`T,BP@,S0L(#(V
M+"`Q."P@,3`L("`R+`H@("`@("`@(#8P+"`U,BP@-#0L(#,V+"`R."P@,C`L
M(#$R+"`@-"P*("`@("`@("`V,BP@-30L(#0V+"`S."P@,S`L(#(R+"`Q-"P@
M(#8L"B`@("`@("`@-C0L(#4V+"`T."P@-#`L(#,R+"`R-"P@,38L("`X+`H@
M("`@("`@(#4W+"`T.2P@-#$L(#,S+"`R-2P@,3<L("`Y+"`@,2P*("`@("`@
M("`U.2P@-3$L(#0S+"`S-2P@,C<L(#$Y+"`Q,2P@(#,L"B`@("`@("`@-C$L
M(#4S+"`T-2P@,S<L(#(Y+"`R,2P@,3,L("`U+`H@("`@("`@(#8S+"`U-2P@
M-#<L(#,Y+"`S,2P@,C,L(#$U+"`@-PH@("`@*3L*"B`@("`O*BH*("`@("`J
M($9I;F%L(%!E<FUU=&%T:6]N($E07BTQ"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)&9P(#T@87)R87DH"B`@("`@("`@-#`L
M("`X+"`T."P@,38L(#4V+"`R-"P@-C0L(#,R+`H@("`@("`@(#,Y+"`@-RP@
M-#<L(#$U+"`U-2P@,C,L(#8S+"`S,2P*("`@("`@("`S."P@(#8L(#0V+"`Q
M-"P@-30L(#(R+"`V,BP@,S`L"B`@("`@("`@,S<L("`U+"`T-2P@,3,L(#4S
M+"`R,2P@-C$L(#(Y+`H@("`@("`@(#,V+"`@-"P@-#0L(#$R+"`U,BP@,C`L
M(#8P+"`R."P*("`@("`@("`S-2P@(#,L(#0S+"`Q,2P@-3$L(#$Y+"`U.2P@
M,C<L"B`@("`@("`@,S0L("`R+"`T,BP@,3`L(#4P+"`Q."P@-3@L(#(V+`H@
M("`@("`@(#,S+"`@,2P@-#$L("`Y+"`T.2P@,3<L(#4W+"`R-0H@("`@*3L*
M"B`@("`O*BH*("`@("`J($4@0FET(%-E;&5C=&EO;B!486)L90H@("`@("H*
M("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1E(#T@87)R87DH
M"B`@("`@("`@,S(L("`Q+"`@,BP@(#,L("`T+"`@-2P*("`@("`@("`@-"P@
M(#4L("`V+"`@-RP@(#@L("`Y+`H@("`@("`@("`X+"`@.2P@,3`L(#$Q+"`Q
M,BP@,3,L"B`@("`@("`@,3(L(#$S+"`Q-"P@,34L(#$V+"`Q-RP*("`@("`@
M("`Q-BP@,3<L(#$X+"`Q.2P@,C`L(#(Q+`H@("`@("`@(#(P+"`R,2P@,C(L
M(#(S+"`R-"P@,C4L"B`@("`@("`@,C0L(#(U+"`R-BP@,C<L(#(X+"`R.2P*
M("`@("`@("`R."P@,CDL(#,P+"`S,2P@,S(L("`Q"B`@("`I.PH*("`@("\J
M*@H@("`@("H@4R!B;WAE<PH@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1?<R`](&%R<F%Y*`H@("`@("`@("\J(%,Q("HO"B`@
M("`@("`@,2`]/B!A<G)A>2@*("`@("`@("`@("`Q-"P@(#0L(#$S+"`@,2P@
M(#(L(#$U+"`Q,2P@(#@L("`S+"`Q,"P@(#8L(#$R+"`@-2P@(#DL("`P+"`@
M-RP*("`@("`@("`@("`@,"P@,34L("`W+"`@-"P@,30L("`R+"`Q,RP@(#$L
M(#$P+"`@-BP@,3(L(#$Q+"`@.2P@(#4L("`S+"`@."P*("`@("`@("`@("`@
M-"P@(#$L(#$T+"`@."P@,3,L("`V+"`@,BP@,3$L(#$U+"`Q,BP@(#DL("`W
M+"`@,RP@,3`L("`U+"`@,"P*("`@("`@("`@("`Q-2P@,3(L("`X+"`@,BP@
M(#0L("`Y+"`@,2P@(#<L("`U+"`Q,2P@(#,L(#$T+"`Q,"P@(#`L("`V+"`Q
M,PH@("`@("`@("DL"@H@("`@("`@("\J(%,R("HO"B`@("`@("`@,B`]/B!A
M<G)A>2@*("`@("`@("`@("`Q-2P@(#$L("`X+"`Q-"P@(#8L(#$Q+"`@,RP@
M(#0L("`Y+"`@-RP@(#(L(#$S+"`Q,BP@(#`L("`U+"`Q,"P*("`@("`@("`@
M("`@,RP@,3,L("`T+"`@-RP@,34L("`R+"`@."P@,30L(#$R+"`@,"P@(#$L
M(#$P+"`@-BP@(#DL(#$Q+"`@-2P*("`@("`@("`@("`@,"P@,30L("`W+"`Q
M,2P@,3`L("`T+"`Q,RP@(#$L("`U+"`@."P@,3(L("`V+"`@.2P@(#,L("`R
M+"`Q-2P*("`@("`@("`@("`Q,RP@(#@L(#$P+"`@,2P@(#,L(#$U+"`@-"P@
M(#(L(#$Q+"`@-BP@(#<L(#$R+"`@,"P@(#4L(#$T+"`@.2P*("`@("`@("`I
M+`H*("`@("`@("`O*B!3,R`J+PH@("`@("`@(#,@/3X@87)R87DH"B`@("`@
M("`@("`@,3`L("`P+"`@.2P@,30L("`V+"`@,RP@,34L("`U+"`@,2P@,3,L
M(#$R+"`@-RP@,3$L("`T+"`@,BP@(#@L"B`@("`@("`@("`@,3,L("`W+"`@
M,"P@(#DL("`S+"`@-"P@(#8L(#$P+"`@,BP@(#@L("`U+"`Q-"P@,3(L(#$Q
M+"`Q-2P@(#$L"B`@("`@("`@("`@,3,L("`V+"`@-"P@(#DL("`X+"`Q-2P@
M(#,L("`P+"`Q,2P@(#$L("`R+"`Q,BP@(#4L(#$P+"`Q-"P@(#<L"B`@("`@
M("`@("`@(#$L(#$P+"`Q,RP@(#`L("`V+"`@.2P@(#@L("`W+"`@-"P@,34L
M(#$T+"`@,RP@,3$L("`U+"`@,BP@,3(L"B`@("`@("`@*2P*"B`@("`@("`@
M+RH@4S0@*B\*("`@("`@("`T(#T^(&%R<F%Y*`H@("`@("`@("`@("`W+"`Q
M,RP@,30L("`S+"`@,"P@(#8L("`Y+"`Q,"P@(#$L("`R+"`@."P@(#4L(#$Q
M+"`Q,BP@(#0L(#$U+`H@("`@("`@("`@(#$S+"`@."P@,3$L("`U+"`@-BP@
M,34L("`P+"`@,RP@(#0L("`W+"`@,BP@,3(L("`Q+"`Q,"P@,30L("`Y+`H@
M("`@("`@("`@(#$P+"`@-BP@(#DL("`P+"`Q,BP@,3$L("`W+"`Q,RP@,34L
M("`Q+"`@,RP@,30L("`U+"`@,BP@(#@L("`T+`H@("`@("`@("`@("`S+"`Q
M-2P@(#`L("`V+"`Q,"P@(#$L(#$S+"`@."P@(#DL("`T+"`@-2P@,3$L(#$R
M+"`@-RP@(#(L(#$T+`H@("`@("`@("DL"@H@("`@("`@("\J(%,U("HO"B`@
M("`@("`@-2`]/B!A<G)A>2@*("`@("`@("`@("`@,BP@,3(L("`T+"`@,2P@
M(#<L(#$P+"`Q,2P@(#8L("`X+"`@-2P@(#,L(#$U+"`Q,RP@(#`L(#$T+"`@
M.2P*("`@("`@("`@("`Q-"P@,3$L("`R+"`Q,BP@(#0L("`W+"`Q,RP@(#$L
M("`U+"`@,"P@,34L(#$P+"`@,RP@(#DL("`X+"`@-BP*("`@("`@("`@("`@
M-"P@(#(L("`Q+"`Q,2P@,3`L(#$S+"`@-RP@(#@L(#$U+"`@.2P@,3(L("`U
M+"`@-BP@(#,L("`P+"`Q-"P*("`@("`@("`@("`Q,2P@(#@L(#$R+"`@-RP@
M(#$L(#$T+"`@,BP@,3,L("`V+"`Q-2P@(#`L("`Y+"`Q,"P@(#0L("`U+"`@
M,RP*("`@("`@("`I+`H*("`@("`@("`O*B!3-B`J+PH@("`@("`@(#8@/3X@
M87)R87DH"B`@("`@("`@("`@,3(L("`Q+"`Q,"P@,34L("`Y+"`@,BP@(#8L
M("`X+"`@,"P@,3,L("`S+"`@-"P@,30L("`W+"`@-2P@,3$L"B`@("`@("`@
M("`@,3`L(#$U+"`@-"P@(#(L("`W+"`Q,BP@(#DL("`U+"`@-BP@(#$L(#$S
M+"`Q-"P@(#`L(#$Q+"`@,RP@(#@L"B`@("`@("`@("`@(#DL(#$T+"`Q-2P@
M(#4L("`R+"`@."P@,3(L("`S+"`@-RP@(#`L("`T+"`Q,"P@(#$L(#$S+"`Q
M,2P@(#8L"B`@("`@("`@("`@(#0L("`S+"`@,BP@,3(L("`Y+"`@-2P@,34L
M(#$P+"`Q,2P@,30L("`Q+"`@-RP@(#8L("`P+"`@."P@,3,L"B`@("`@("`@
M*2P*"B`@("`@("`@+RH@4S<@*B\*("`@("`@("`W(#T^(&%R<F%Y*`H@("`@
M("`@("`@("`T+"`Q,2P@(#(L(#$T+"`Q-2P@(#`L("`X+"`Q,RP@(#,L(#$R
M+"`@.2P@(#<L("`U+"`Q,"P@(#8L("`Q+`H@("`@("`@("`@(#$S+"`@,"P@
M,3$L("`W+"`@-"P@(#DL("`Q+"`Q,"P@,30L("`S+"`@-2P@,3(L("`R+"`Q
M-2P@(#@L("`V+`H@("`@("`@("`@("`Q+"`@-"P@,3$L(#$S+"`Q,BP@(#,L
M("`W+"`Q-"P@,3`L(#$U+"`@-BP@(#@L("`P+"`@-2P@(#DL("`R+`H@("`@
M("`@("`@("`V+"`Q,2P@,3,L("`X+"`@,2P@(#0L(#$P+"`@-RP@(#DL("`U
M+"`@,"P@,34L(#$T+"`@,BP@(#,L(#$R+`H@("`@("`@("DL"@H@("`@("`@
M("\J(%,X("HO"B`@("`@("`@."`]/B!A<G)A>2@*("`@("`@("`@("`@,3,L
M("`R+"`@."P@(#0L("`V+"`Q-2P@,3$L("`Q+"`Q,"P@(#DL("`S+"`Q-"P@
M(#4L("`P+"`Q,BP@(#<L"B`@("`@("`@("`@("`Q+"`Q-2P@,3,L("`X+"`Q
M,"P@(#,L("`W+"`@-"P@,3(L("`U+"`@-BP@,3$L("`P+"`Q-"P@(#DL("`R
M+`H@("`@("`@("`@("`@-RP@,3$L("`T+"`@,2P@(#DL(#$R+"`Q-"P@(#(L
M("`P+"`@-BP@,3`L(#$S+"`Q-2P@(#,L("`U+"`@."P*("`@("`@("`@("`@
M(#(L("`Q+"`Q-"P@(#<L("`T+"`Q,"P@(#@L(#$S+"`Q-2P@,3(L("`Y+"`@
M,"P@(#,L("`U+"`@-BP@,3$*("`@("`@("`I"B`@("`I.PH*("`@("\J*@H@
M("`@("H@4')I;6ET:79E(&9U;F-T:6]N"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)'`@/2!A<G)A>2@*("`@("`@("`Q-BP@
M(#<L(#(P+"`R,2P*("`@("`@("`R.2P@,3(L(#(X+"`Q-RP*("`@("`@("`@
M,2P@,34L(#(S+"`R-BP*("`@("`@("`@-2P@,3@L(#,Q+"`Q,"P*("`@("`@
M("`@,BP@(#@L(#(T+"`Q-"P*("`@("`@("`S,BP@,C<L("`S+"`@.2P*("`@
M("`@("`Q.2P@,3,L(#,P+"`@-BP*("`@("`@("`R,BP@,3$L("`T+"`R-0H@
M("`@*3L*"B`@("`O*BH*("`@("`J(%!E<FUU=&5D($-H;VEC92!486)L90H@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1P8S$@
M/2!A<G)A>2@*("`@("`@("`U-RP@-#DL(#0Q+"`S,RP@,C4L(#$W+"`@.2P*
M("`@("`@("`@,2P@-3@L(#4P+"`T,BP@,S0L(#(V+"`Q."P*("`@("`@("`Q
M,"P@(#(L(#4Y+"`U,2P@-#,L(#,U+"`R-RP*("`@("`@("`Q.2P@,3$L("`S
M+"`V,"P@-3(L(#0T+"`S-BP*"B`@("`@("`@-C,L(#4U+"`T-RP@,SDL(#,Q
M+"`R,RP@,34L"B`@("`@("`@(#<L(#8R+"`U-"P@-#8L(#,X+"`S,"P@,C(L
M"B`@("`@("`@,30L("`V+"`V,2P@-3,L(#0U+"`S-RP@,CDL"B`@("`@("`@
M,C$L(#$S+"`@-2P@,C@L(#(P+"`Q,BP@(#0*("`@("D["@H@("`@+RHJ"B`@
M("`@*B!.=6UB97(@;&5F="!R;W1A=&EO;G,@;V8@<&,Q"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)'-H:69T<R`](&%R<F%Y
M*`H@("`@("`@(#$L(#$L(#(L(#(L(#(L(#(L(#(L(#(L"B`@("`@("`@,2P@
M,BP@,BP@,BP@,BP@,BP@,BP@,0H@("`@*3L*"B`@("`O*BH*("`@("`J(%!E
M<FUU=&5D($-H;VEC92!486)L92`R"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)'!C,B`](&%R<F%Y*`H@("`@("`@(#$T+"`Q
M-RP@,3$L(#(T+"`@,2P@(#4L"B`@("`@("`@(#,L(#(X+"`Q-2P@(#8L(#(Q
M+"`Q,"P*("`@("`@("`R,RP@,3DL(#$R+"`@-"P@,C8L("`X+`H@("`@("`@
M(#$V+"`@-RP@,C<L(#(P+"`Q,RP@(#(L"B`@("`@("`@-#$L(#4R+"`S,2P@
M,S<L(#0W+"`U-2P*("`@("`@("`S,"P@-#`L(#4Q+"`T-2P@,S,L(#0X+`H@
M("`@("`@(#0T+"`T.2P@,SDL(#4V+"`S-"P@-3,L"B`@("`@("`@-#8L(#0R
M+"`U,"P@,S8L(#(Y+"`S,@H@("`@*3L*"B`@("`O*BH*("`@("`J($ME>2!3
M8VAE9'5L90H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1?2W,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@4V5T('1H92!K
M97D@=&\@8F4@=7-E9"!F;W(@96XO9&5C<GEP=&EO;BX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1K97D@(%1H92!K97D@=&\@=7-E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!S971+97DH)&ME>2D*("`@('L*("`@("`@("!I9B`H
M(6ES7VYU;&PH)&ME>2DI('L*("`@("`@("`@("`@)'1H:7,M/E]+<R`]("1T
M:&ES+3Y?:V5Y4V-H961U;&4H)&ME>2D["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N('1H92!S:7IE(&]F('1H92!B;&]C:W,@=&AA
M="!T:&ES(&-I<&AE<B!N965D<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN
M=&5G97(@(%1H92!N=6UB97(@;V8@8VAA<F%C=&5R<R!P97(@8FQO8VLN"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$)L;V-K4VEZ92@I"B`@("!["B`@("`@
M("`@<F5T=7)N(#@["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%;F-R>7!T(&$@
M8FQO8VL@;V8@9&%T82X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1B
M;&]C:R`@5&AE(&1A=&$@=&\@96YC<GEP="X*("`@("`J($!P87)A;2!S=')I
M;F<@)&ME>2`@("!4:&4@:V5Y('1O('5S92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(&5N8W)Y<'1E9"!O=71P=70N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&5N8W)Y<'1";&]C:R@D8FQO8VLL("1K97D@/2!N=6QL*0H@
M("`@>PH@("`@("`@(&EF("@A:7-?;G5L;"@D:V5Y*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7TMS(#T@)'1H:7,M/E]K97E38VAE9'5L92@D:V5Y*3L*("`@
M("`@("!]"@H@("`@("`@("1B;&]C:R`]("1T:&ES+3Y?:6YI=&EA;%!E<FTH
M)&)L;V-K*3L*"B`@("`@("`@)$P@/2!S=6)S='(H)&)L;V-K+"`P+"`T*3L*
M("`@("`@("`D4B`]('-U8G-T<B@D8FQO8VLL(#0L(#0I.PH*("`@("`@("!F
M;W(@*"1I(#T@,3L@)&D@/#T@,38[("1I*RL@*2!["B`@("`@("`@("`@("12
M7W!R978@/2`D4CL*("`@("`@("`@("`@)$Q?<')E=B`]("1,.PH*("`@("`@
M("`@("`@)$P@/2`D4CL*("`@("`@("`@("`@)%(@/2`D3%]P<F5V(%X@)'1H
M:7,M/E]F*"127W!R978L("1I*3L*("`@("`@("!]"@H@("`@("`@("1B;&]C
M:R`]("12("X@)$P["B`@("`@("`@)&)L;V-K(#T@)'1H:7,M/E]F:6YA;%!E
M<FTH)&)L;V-K*3L*"B`@("`@("`@<F5T=7)N("1B;&]C:SL*("`@('T*"B`@
M("`O*BH*("`@("`J($1E8W)Y<'0@82!B;&]C:R!O9B!D871A+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&)L;V-K("!4:&4@9&%T82!T;R!D96-R
M>7!T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("`@(%1H92!K97D@=&\@
M=7-E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9&5C<GEP
M=&5D(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5C<GEP=$)L;V-K
M*"1B;&]C:RP@)&ME>2`](&YU;&PI"B`@("!["B`@("`@("`@)&)L;V-K(#T@
M)'1H:7,M/E]I;FET:6%L4&5R;2@D8FQO8VLI.PH*("`@("`@("!I9B`H(6ES
M7VYU;&PH)&ME>2DI('L*("`@("`@("`@("`@)'1H:7,M/E]+<R`]("1T:&ES
M+3Y?:V5Y4V-H961U;&4H)&ME>2D["B`@("`@("`@?0H*("`@("`@("`D3"`]
M('-U8G-T<B@D8FQO8VLL(#`L(#0I.PH@("`@("`@("12(#T@<W5B<W1R*"1B
M;&]C:RP@-"P@-"D["@H@("`@("`@(&9O<B`H)&D@/2`Q-CL@)&D@/CT@,3L@
M)&DM+2`I('L*("`@("`@("`@("`@)%)?<')E=B`]("12.PH@("`@("`@("`@
M("`D3%]P<F5V(#T@)$P["@H@("`@("`@("`@("`D3"`]("127W!R978["B`@
M("`@("`@("`@("12(#T@)$Q?<')E=B!>("1T:&ES+3Y?9B@D4E]P<F5V+"`D
M:2D["B`@("`@("`@?0H*("`@("`@("`D8FQO8VL@/2`D4B`N("1,.PH@("`@
M("`@("1B;&]C:R`]("1T:&ES+3Y?9FEN86Q097)M*"1B;&]C:RD["@H@("`@
M("`@(')E='5R;B`D8FQO8VL["B`@("!]"@H@("`@+RHJ"B`@("`@*B!0=70@
M86X@:6YP=70@<W1R:6YG('1H<F]U9V@@86X@:6YI=&EA;"!P97)M=71A=&EO
M;@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&EN<'5T("!);G!U="!S
M=')I;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%!E<FUU=&%T
M960@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!?:6YI=&EA;%!E<FTH
M)&EN<'5T*0H@("`@>PH@("`@("`@("\O(%1/1$\Z(%-O;64@<W1Y;&EE(&)I
M='=I<V4@=&AI;F<@:6YS=&5A9"X*"B`@("`@("`@)&EN<'5T7V)I;B`]("<G
M.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(#@[("1I*RLI('L*("`@("`@
M("`@("`@)&EN<'5T7V)I;B`N/2!S=')?<&%D*&1E8V)I;BAO<F0H)&EN<'5T
M6R1I72DI+"`X+"`G,"<L(%-44E]0041?3$5&5"D["B`@("`@("`@?0H*("`@
M("`@("`D;W5T<'5T7V)I;B`]("<G.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES
M+3YI<"!A<R`D;V9F<V5T*2!["B`@("`@("`@("`@("1O=71P=71?8FEN("X]
M("1I;G!U=%]B:6Y;)&]F9G-E="`M(#%=.PH@("`@("`@('T*"B`@("`@("`@
M)&]U='!U="`]("<G.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(#@[("1I
M*RLI('L*("`@("`@("`@("`@)&]U='!U="`N/2!C:'(H8FEN9&5C*'-U8G-T
M<B@D;W5T<'5T7V)I;BP@."`J("1I+"`X*2DI.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1O=71P=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!0=70@
M86X@:6YP=70@<W1R:6YG('1H<F]U9V@@82!F:6YA;"!P97)M=71A=&EO;BX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I;G!U="`@26YP=70@<W1R
M:6YG+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!097)M=71A=&5D
M('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V9I;F%L4&5R;2@D:6YP
M=70I"B`@("!["B`@("`@("`@+R\@5$]$3SH@4V]M92!S='EL:64@8FET=VES
M92!T:&EN9R!I;G-T96%D+@H@("`@("`@("1I;G!U=%]B:6X@/2`G)SL*("`@
M("`@("!F;W(@*"1I(#T@,#L@)&D@/"`X.R`D:2LK*2!["B`@("`@("`@("`@
M("1I;G!U=%]B:6X@+CT@<W1R7W!A9"AD96-B:6XH;W)D*"1I;G!U=%LD:5TI
M*2P@."P@)S`G+"!35%)?4$%$7TQ%1E0I.PH@("`@("`@('T*"B`@("`@("`@
M)&]U='!U=%]B:6X@/2`G)SL*("`@("`@("!F;W)E86-H("@D=&AI<RT^9G`@
M87,@)&]F9G-E="D@>PH@("`@("`@("`@("`D;W5T<'5T7V)I;B`N/2`D:6YP
M=71?8FEN6R1O9F9S970@+2`Q73L*("`@("`@("!]"@H@("`@("`@("1O=71P
M=70@/2`G)SL*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`X.R`D:2LK*2![
M"B`@("`@("`@("`@("1O=71P=70@+CT@8VAR*&)I;F1E8RAS=6)S='(H)&]U
M='!U=%]B:6XL(#@@*B`D:2P@."DI*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D;W5T<'5T.PH@("`@?0H*"B`@("`O*BH*("`@("`J(&8H*2!4:&4@
M<&5R;75T871I;VX@9G5N8W1I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D:6YP=70@($EN<'5T('-T<FEN9RX*("`@("`J($!P87)A;2!I;G1E
M9V5R("1R;W5N9"`@5&AE(')O=6YD+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@;W5T<'5T('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V8H)&EN<'5T+"`D<F]U;F0I"B`@("!["B`@("`@("`@+R\@5$]$3SH@
M4V]M92!S='EL:64@8FET=VES92!T:&EN9R!I;G-T96%D+@H@("`@("`@("1K
M97D@/2`D=&AI<RT^7TMS6R1R;W5N9%T["@H@("`@("`@("1I;G!U=%]B:6X@
M/2`G)SL*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`T.R`D:2LK*2!["B`@
M("`@("`@("`@("1I;G!U=%]B:6X@+CT@<W1R7W!A9"AD96-B:6XH;W)D*"1I
M;G!U=%LD:5TI*2P@."P@)S`G+"!35%)?4$%$7TQ%1E0I.PH@("`@("`@('T*
M"B`@("`@("`@)&5X<&%N9&5D7V)I;B`]("<G.PH@("`@("`@(&9O<F5A8V@@
M*"1T:&ES+3YE(&%S("1O9F9S970I('L*("`@("`@("`@("`@)&5X<&%N9&5D
M7V)I;B`N/2`D:6YP=71?8FEN6R1O9F9S970@+2`Q73L*("`@("`@("!]"@H@
M("`@("`@("1E>'!A;F1E9"`](&%R<F%Y*"D["B`@("`@("`@9F]R("@D:2`]
M(#`[("1I(#P@.#L@)&DK*RD@>PH@("`@("`@("`@("`D97AP86YD961;)&E=
M(#T@8FEN9&5C*"<P,"<@+B!S=6)S='(H)&5X<&%N9&5D7V)I;BP@)&D@*B`V
M+"`V*2D@7B`D:V5Y6R1I73L*("`@("`@("!]"@H@("`@("`@("1C;VUB:6YE
M9%]B:6X@/2`G)SL*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`X.R`D:2LK
M*2!["B`@("`@("`@("`@("1S7VEN9&5X(#T@*"@D97AP86YD961;)&E=("8@
M,'@R,"D@/CX@-"D@?"`H)&5X<&%N9&5D6R1I72`F(#!X,#$I.PH@("`@("`@
M("`@("`D<U]I;F1E>"`](#$V("H@)'-?:6YD97@@*R`H*"1E>'!A;F1E9%LD
M:5T@)B`P>#%%*2`^/B`Q*3L*("`@("`@("`@("`@)'9A;"`]("1T:&ES+3Y?
M<ULD:2`K(#%=6R1S7VEN9&5X73L*("`@("`@("`@("`@)&-O;6)I;F5D7V)I
M;B`N/2!S=')?<&%D*&1E8V)I;B@D=F%L*2P@-"P@)S`G+"!35%)?4$%$7TQ%
M1E0I.PH@("`@("`@('T*"B`@("`@("`@)&]U='!U=%]B:6X@/2`G)SL*("`@
M("`@("!F;W)E86-H("@D=&AI<RT^<"!A<R`D;V9F<V5T*2!["B`@("`@("`@
M("`@("1O=71P=71?8FEN("X]("1C;VUB:6YE9%]B:6Y;)&]F9G-E="`M(#%=
M.PH@("`@("`@('T*"B`@("`@("`@)&]U='!U="`]("<G.PH@("`@("`@(&9O
M<B`H)&D@/2`P.R`D:2`\(#0[("1I*RLI('L*("`@("`@("`@("`@)&]U='!U
M="`N/2!C:'(H8FEN9&5C*'-U8G-T<B@D;W5T<'5T7V)I;BP@)&D@*B`X+"`X
M*2DI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O=71P=70["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@=&AE(&-O;7!L971E(&ME>2!S:&5D
M=6QE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ME>2`@5&AE(&ME
M>2!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2!+97D@<V-H
M961U;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]K97E38VAE9'5L92@D:V5Y
M*0H@("`@>PH@("`@("`@("1K97D@/2!S=')?<&%D*"1K97DL(#@L(")<,"(I
M.PH@("`@("`@("1K<R`](&%R<F%Y*"D["@H@("`@("`@("1K97E?8FEN(#T@
M)R<["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@.#L@)&DK*RD@>PH@("`@
M("`@("`@("`D:V5Y7V)I;B`N/2!S=')?<&%D*&1E8V)I;BAO<F0H)&ME>5LD
M:5TI*2P@."P@)S`G+"!35%)?4$%$7TQ%1E0I.PH@("`@("`@('T*"B`@("`@
M("`@)&,@/2`G)SL*("`@("`@("`D9"`]("<G.PH@("`@("`@(&9O<B`H)&D@
M/2`P.R`D:2`\(#(X.R`D:2LK*2!["B`@("`@("`@("`@("1C("X]("1K97E?
M8FEN6R1T:&ES+3YP8S%;)&E=("T@,5T["B`@("`@("`@("`@("1D("X]("1K
M97E?8FEN6R1T:&ES+3YP8S%;,C@@*R`D:5T@+2`Q73L*("`@("`@("!]"@H@
M("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(#$V.R`D:2LK*2!["B`@("`@("`@
M("`@("1C(#T@<W5B<W1R*"1C+"`D=&AI<RT^<VAI9G1S6R1I72D@+B!S=6)S
M='(H)&,L(#`L("1T:&ES+3YS:&EF='-;)&E=*3L*("`@("`@("`@("`@)&0@
M/2!S=6)S='(H)&0L("1T:&ES+3YS:&EF='-;)&E=*2`N('-U8G-T<B@D9"P@
M,"P@)'1H:7,M/G-H:69T<ULD:5TI.PH*("`@("`@("`@("`@)&-D(#T@)&,@
M+B`D9#L*"B`@("`@("`@("`@("1P97)M=71A=&5D7V)I;B`]("<G.PH@("`@
M("`@("`@("!F;W)E86-H("@D=&AI<RT^<&,R(&%S("1O9F9S970I('L*("`@
M("`@("`@("`@("`@("1P97)M=71A=&5D7V)I;B`N/2`D8V1;)&]F9G-E="`M
M(#%=.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!F;W(@*"1J(#T@,#L@
M)&H@/"`X.R`D:BLK*2!["B`@("`@("`@("`@("`@("`D:W-;)&D@*R`Q75M=
M(#T@8FEN9&5C*"<P,"<@+B!S=6)S='(H)'!E<FUU=&%T961?8FEN+"`D:B`J
M(#8L(#8I*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1K<SL*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]#:7!H97(O8V%S=#$R."YP
M:'``````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#$S,C4S-B`Q,#4Q
M-30S,S<S-R`P,C(T-S0`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J(%1H92!#:7!H97)?8V%S=#$R.#HZ
M(&-L87-S(&EM<&QE;65N=',@=&AE($-I<&AE<B!I;G1E<F9A8V4@96YC<GEP
M=&EO;B!D871A"B`J('5S:6YG('1H92!#05-4,3(X("AA:V$@0V%S=#4I(&%L
M9V]R:71H;2!A<R!D969I;F5D(&EN(%)&0S(Q-#0N"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+T-I<&AE<B]#:7!H97(O8V%S=#$R."YP:'`L=B`Q+C<N,3(N
M."`R,#`V+S`Q+S`Q(#(Q.C(X.C$P(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P,BTR,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN
M8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6ME($-O8VAR
M86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!(;W)D
M92`R+C(*("H@0'!A8VMA9V4@2&]R9&5?0VEP:&5R"B`J+PIC;&%S<R!(;W)D
M95]#:7!H97)?8V%S=#$R."!E>'1E;F1S($AO<F1E7T-I<&AE<B!["@H@("`@
M+RHJ"B`@("`@*B!3(&)O>"`H<S$I"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)',Q(#T@87)R87DH"B`@("`@("`@,'@S,&9B
M-#!D-"P@,'@Y9F$P9F8P8BP@,'@V8F5C8V0R9BP@,'@S9C(U.&,W82P@,'@Q
M93(Q,V8R9BP@,'@Y8S`P-&1D,RP@,'@V,#`S934T,"P@,'AC9CEF8SDT.2P*
M("`@("`@("`P>&)F9#1A9C(W+"`P>#@X8F)B9&(U+"`P>&4R,#,T,#DP+"`P
M>#DX9#`Y-C<U+"`P>#9E-C-A,&4P+"`P>#$U8S,V,60R+"`P>&,R93<V-C%D
M+"`P>#(R9#1F9CAE+`H@("`@("`@(#!X,C@V.#-B-F8L(#!X8S`W9F0P-3DL
M(#!X9F8R,S<Y8S@L(#!X-S<U9C4P93(L(#!X-#-C,S0P9#,L(#!X9&8R9C@V
M-38L(#!X.#@W8V$T,6$L(#!X83)D,F)D,F0L"B`@("`@("`@,'AA,6,Y93!D
M-BP@,'@S-#9C-#@Q.2P@,'@V,6(W-F0X-RP@,'@R,C4T,&8R9BP@,'@R86)E
M,S)E,2P@,'AA834T,38V8BP@,'@R,C4V.&4S82P@,'AA,F0S-#%D,"P*("`@
M("`@("`P>#8V9&(T,&,X+"`P>&$W.#0S.3)F+"`P>#`P-&1F9C)F+"`P>#)D
M8CED,F1E+"`P>#DW.30S9F%C+"`P>#1A.3=C,60X+"`P>#4R-S8T-&(W+"`P
M>&(U9C0S-V$W+`H@("`@("`@(#!X8C@R8V)A968L(#!X9#<U,60Q-3DL(#!X
M-F9F-V8P960L(#!X-6$P.3=A,68L(#!X.#(W8C8X9#`L(#!X.3!E8V8U,F4L
M(#!X,C)B,&,P-30L(#!X8F,X934Y,S4L"B`@("`@("`@,'@T8C9D,F8W9BP@
M,'@U,&)B-C1A,BP@,'AD,C8V-#DQ,"P@,'AB964U.#$R9"P@,'AB-S,S,C(Y
M,"P@,'AE.3-B,34Y9BP@,'AB-#AE930Q,2P@,'@T8F9F,S0U9"P*("`@("`@
M("`P>&9D-#5C,C0P+"`P>&%D,S$Y-S-F+"`P>&,T9C9D,#)E+"`P>#4U9F,X
M,38U+"`P>&0U8C%C86%D+"`P>&$Q86,R9&%E+"`P>&$R9#1B-S9D+"`P>&,Q
M.6(P8S4P+`H@("`@("`@(#!X.#@R,C0P9C(L(#!X,&,V931F,S@L(#!X831E
M-&)F9#<L(#!X-&8U8F$R-S(L(#!X-38T8S%D,F8L(#!X8S4Y8S4S,3DL(#!X
M8CDT.64S-30L(#!X8C`T-C8Y9F4L"B`@("`@("`@,'AB,6(V86(X82P@,'AC
M-S$S-3AD9"P@,'@V,S@U8S4T-2P@,'@Q,3!F.3,U9"P@,'@U-S4S.&%D-2P@
M,'@V83,Y,#0Y,RP@,'AE-C-D,S=E,"P@,'@R834T9C9B,RP*("`@("`@("`P
M>#-A-S@W9#5F+"`P>#8R-S9A,&(U+"`P>#$Y839F8V1F+"`P>#=A-#(R,#9A
M+"`P>#(Y9CED-&0U+"`P>&8V,6(Q.#DQ+"`P>&)B-S(R-S5E+"`P>&%A-3`X
M,38W+`H@("`@("`@(#!X,S@Y,#$P.3$L(#!X8S9B-3`U96(L(#!X.#1C-V-B
M.&,L(#!X,F%D-S5A,&8L(#!X.#<T83$T,C<L(#!X83)D,3DS-F(L(#!X,F%D
M,C@V868L(#!X86$U-F0R.3$L"B`@("`@("`@,'AD-S@Y-#,V,"P@,'@T,C5C
M-S4P9"P@,'@Y,V(S.64R-BP@,'@Q.#<Q.#1C.2P@,'@V8S`P8C,R9"P@,'@W
M,V4R8F(Q-"P@,'AA,&)E8F,S8RP@,'@U-#8R,S<W.2P*("`@("`@("`P>#8T
M-#4Y96%B+"`P>#-F,S(X8C@R+"`P>#<W,3AC9C@R+"`P>#4Y83)C96$V+"`P
M>#`T964P,#)E+"`P>#@Y9F4W.&4V+"`P>#-F86(P.34P+"`P>#,R-69F-F,R
M+`H@("`@("`@(#!X.#$S.#-F,#4L(#!X-CDV,V,U8S@L(#!X-S9C8C5A9#8L
M(#!X9#0Y.3<T8SDL(#!X8V$Q.#!D8V8L(#!X,S@P-S@R9#4L(#!X8S=F835C
M9C8L(#!X.&%C,S$U,3$L"B`@("`@("`@,'@S-64W.64Q,RP@,'@T-V1A.3%D
M,"P@,'AF-#!F.3`X-BP@,'AA-V4R-#$Y92P@,'@S,3,V-C(T,2P@,'@P-3%E
M9C0Y-2P@,'AA834W,V(P-"P@,'@T83@P-60X9"P*("`@("`@("`P>#4T.#,P
M,&0P+"`P>#`P,S(R83-C+"`P>&)F-C1C9&1F+"`P>&)A-3=A-CAE+"`P>#<U
M8S8S-S)B+"`P>#4P869D,S0Q+"`P>&$W8S$S,C<U+"`P>#DQ-6$P8F8U+`H@
M("`@("`@(#!X-F(U-&)F86(L(#!X,F(P8C$T,C8L(#!X86(T8V,Y9#<L(#!X
M-#0Y8V-D.#(L(#!X9C=F8F8R-C4L(#!X86(X-6,U9C,L(#!X,6(U-61B.30L
M(#!X86%D-&4S,C0L"B`@("`@("`@,'AC9F$T8F0S9BP@,'@R9&5A83-E,BP@
M,'@Y93(P-&0P,BP@,'AC.&)D,C5A8RP@,'AE861F-35B,RP@,'AD-6)D.64Y
M."P@,'AE,S$R,S%B,BP@,'@R860U860V8RP*("`@("`@("`P>#DU-#,R.61E
M+"`P>&%D8F4T-3(X+"`P>&0X-S$P9C8Y+"`P>&%A-3%C.3!F+"`P>&%A-S@V
M8F8V+"`P>#(R-3$S9C%E+"`P>&%A-3%A-SEB+"`P>#)A9#,T-&-C+`H@("`@
M("`@(#!X-V(U830Q9C`L(#!X9#,W8V9B860L(#!X,6(P-CDU,#4L(#!X-#%E
M8V4T.3$L(#!X8C1C,S,R938L(#!X,#,R,C8X9#0L(#!X8SDV,#!A8V,L(#!X
M8V4S.#=E-F0L"B`@("`@("`@,'AB9C9B8C$V8RP@,'@V83<P9F(W."P@,'@P
M9#`S9#EC.2P@,'AD-&1F,SED92P@,'AE,#$P-C-D82P@,'@T-S,V9C0V-"P@
M,'@U860S,CAD."P@,'AB,S0W8V,Y-BP*("`@("`@("`P>#<U8F(P9F,S+"`P
M>#DX-3$Q8F9B+"`P>#1F9F)C8S,U+"`P>&(U.&)C9C9A+"`P>&4Q,68P86)C
M+"`P>&)F8S5F931A+"`P>&$W,&%E8S$P+"`P>&%C,SDU-S!A+`H@("`@("`@
M(#!X,V8P-#0T,F8L(#!X-C$X.&(Q-3,L(#!X93`S.3=A,F4L(#!X-3<R-V-B
M-SDL(#!X.6-E8C0Q.&8L(#!X,6-A8V0V.&0L(#!X,F%D,S=C.38L(#!X,#$W
M-6-B.60L"B`@("`@("`@,'AC-CED9F8P.2P@,'AC-S5B-C5F,"P@,'AD.61B
M-#!D."P@,'AE8S!E-S<W.2P@,'@T-S0T96%D-"P@,'AB,3%C,S(W-"P@,'AD
M9#(T8V(Y92P@,'@W93%C-31B9"P*("`@("`@("`P>&8P,3$T-&8Y+"`P>&0R
M,C0P96(Q+"`P>#DV-S5B,V9D+"`P>&$S86,S-S4U+"`P>&0T-V,R-V%F+"`P
M>#4Q8S@U9C1D+"`P>#4V.3`W-3DV+"`P>&$U8F(Q-64V+`H@("`@("`@(#!X
M-3@P,S`T9C`L(#!X8V$P-#)C9C$L(#!X,#$Q83,W96$L(#!X.&1B9F%A9&(L
M(#!X,S5B83-E-&$L(#!X,S4R-F9F83`L(#!X8S,W8C1D,#DL(#!X8F,S,#9E
M9#DL"B`@("`@("`@,'@Y.&$U,C8V-BP@,'@U-C0X9C<R-2P@,'AF9C5E-38Y
M9"P@,'@P8V5D-C-D,"P@,'@W8S8S8C)C9BP@,'@W,#!B-#5E,2P@,'AD-65A
M-3!F,2P@,'@X-6$Y,C@W,BP*("`@("`@("`P>&%F,69B9&$W+"`P>&0T,C,T
M.#<P+"`P>&$W.#<P8F8S+"`P>#)D,V(T9#<Y+"`P>#0R93`T,3DX+"`P>#!C
M9#!E9&4W+"`P>#(V-#<P9&(X+"`P>&8X.#$X,31C+`H@("`@("`@(#!X-#<T
M9#9A9#<L(#!X-V,P8S5E-6,L(#!X9#$R,S$Y-3DL(#!X,S@Q8C<R.3@L(#!X
M9C5D,F8T9&(L(#!X86(X,S@V-3,L(#!X-F4R9C%E,C,L(#!X.#,W,3EC.64L
M"B`@("`@("`@,'AB9#DQ93`T-BP@,'@Y834V-#4V92P@,'AD8S,Y,C`P8RP@
M,'@R,&,X8S4W,2P@,'@Y-C)B9&$Q8RP@,'AE,64V.39F9BP@,'AB,30Q86(P
M."P@,'@W8V-A.#EB.2P*("`@("`@("`P>#%A-CEE-S@S+"`P>#`R8V,T.#0S
M+"`P>&$R9C=C-3<Y+"`P>#0R.65F-#=D+"`P>#0R-V(Q-CEC+"`P>#5A8SEF
M,#0Y+"`P>&1D.&8P9C`P+"`P>#5C.#$V-6)F*3L*"B`@("`O*BH*("`@("`J
M(%,@8F]X("AS,BD*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*
M("`@('9A<B`D<S(@/2!A<G)A>2@*("`@("`@("`P>#%F,C`Q,#DT+"`P>&5F
M,&)A-S5B+"`P>#8Y93-C9C=E+"`P>#,Y,V8T,S@P+"`P>&9E-C%C9C=A+"`P
M>&5E8S4R,#=A+"`P>#4U.#@Y8SDT+"`P>#<R9F,P-C4Q+`H@("`@("`@(#!X
M861A-V5F-SDL(#!X-&4Q9#<R,S4L(#!X9#4U838S8V4L(#!X9&4P-#,V8F$L
M(#!X.3EC-#,P968L(#!X-68P8S`W.30L(#!X,3AD8V1B-V0L(#!X83%D-F5F
M9C,L"B`@("`@("`@,'AA,&(U,F8W8BP@,'@U.64X,S8P-2P@,'AE93$U8C`Y
M-"P@,'AE.69F9#DP.2P@,'AD8S0T,#`X-BP@,'AE9CDT-#0U.2P@,'AB83@S
M8V-B,RP@,'AE,&,S8V1F8BP*("`@("`@("`P>&0Q9&$T,3@Q+"`P>#-B,#DR
M86(Q+"`P>&8Y.3=F,6,Q+"`P>&$U939C9C=B+"`P>#`Q-#(P9&1B+"`P>&4T
M93=E9C5B+"`P>#(U83%F9C0Q+"`P>&4Q.#!F.#`V+`H@("`@("`@(#!X,69C
M-#$P.#`L(#!X,3<Y8F5E-V$L(#!X9#,W86,V83DL(#!X9F4U.#,P830L(#!X
M.3AD93AB-V8L(#!X-S=E.#-F-&4L(#!X-SDY,CDR-CDL(#!X,C1F83EF-V(L
M"B`@("`@("`@,'AE,3$S8S@U8BP@,'AA8V,T,#`X,RP@,'AD-S4P,S4R-2P@
M,'AF-V5A-C$U9BP@,'@V,C$T,S$U-"P@,'@P9#4U-&(V,RP@,'@U9#8X,3$R
M,2P@,'AC.#8V8S,U.2P*("`@("`@("`P>#-D-C-C9C<S+"`P>&-E93(S-&,P
M+"`P>&0T9#@W93@W+"`P>#5C-C<R8C(Q+"`P>#`W,68V,3@Q+"`P>#,Y9C<V
M,C=F+"`P>#,V,64S,#@T+"`P>&4T96(U-S-B+`H@("`@("`@(#!X-C`R9C8T
M830L(#!X9#8S86-D.6,L(#!X,6)B8S0V,S4L(#!X.64X,3`S,F0L(#!X,C<P
M,68U,&,L(#!X.3DX-#=A8C0L(#!X83!E,V1F-SDL(#!X8F$V8V8S.&,L"B`@
M("`@("`@,'@Q,#@T,S`Y-"P@,'@R-3,W83DU92P@,'AF-#9F-F9F92P@,'AA
M,69F,V(Q9BP@,'@R,#AC9F(V82P@,'@X9C0U.&,W-"P@,'AD.64P83(R-RP@
M,'@T96,W,V$S-"P*("`@("`@("`P>&9C.#@T9C8Y+"`P>#-E-&1E.&1F+"`P
M>&5F,&4P,#@X+"`P>#,U-3DV-#AD+"`P>#AA-#4S.#AC+"`P>#%D.#`T,S8V
M+"`P>#<R,60Y8F9D+"`P>&$U.#8X-&)B+`H@("`@("`@(#!X93@R-38S,S,L
M(#!X.#0T93@R,3(L(#!X,3(X9#@P.3@L(#!X9F5D,S-F8C0L(#!X8V4R.#!A
M93$L(#!X,C=E,3EB834L(#!X9#5A-F,R-3(L(#!X930Y-S4T8F0L"B`@("`@
M("`@,'AC-60V-35D9"P@,'AE8C8V-S`V-"P@,'@W-S@T,&(T9"P@,'AA,6(V
M83@P,2P@,'@X-&1B,C9A.2P@,'AE,&(U-C<Q-"P@,'@R,68P-#-B-RP@,'AE
M-60P-3@V,"P*("`@("`@("`P>#4T9C`S,#@T+"`P>#`V-F9F-#<R+"`P>&$S
M,6%A,34S+"`P>&1A9&,T-S4U+"`P>&(U-C(U9&)F+"`P>#8X-38Q8F4V+"`P
M>#@S8V$V8CDT+"`P>#)D-F5D,C-B+`H@("`@("`@(#!X96-C9C`Q9&(L(#!X
M839D,V0P8F$L(#!X8C8X,#-D-6,L(#!X868W-V$W,#DL(#!X,S-B-&$S-&,L
M(#!X,SDW8F,X9#8L(#!X-65E,C)B.34L(#!X-68P934S,#0L"B`@("`@("`@
M,'@X,65D-F8V,2P@,'@R,&4W-#,V-"P@,'AB-#5E,3,W."P@,'AD93$X-C,Y
M8BP@,'@X.#%C83$R,BP@,'AB.38W,C9D,2P@,'@X,#0Y83=E."P@,'@R,F(W
M9&$W8BP*("`@("`@("`P>#5E-34R9#(U+"`P>#4R-S)D,C,W+"`P>#<Y9#(Y
M-3%C+"`P>&,V,&0X.31C+"`P>#0X.&-B-#`R+"`P>#%B831F935B+"`P>&$T
M8C`Y9C9B+"`P>#%C83@Q-6-F+`H@("`@("`@(#!X83(P8S,P,#4L(#!X.#@W
M,61F-C,L(#!X8CED93)F8V(L(#!X,&-C-F,Y93DL(#!X,&)E969F-3,L(#!X
M93,R,30U,3<L(#!X8C0U-#(X,S4L(#!X.68V,S(Y,V,L"B`@("`@("`@,'AE
M930Q93<R.2P@,'@V93%D,F0W8RP@,'@U,#`T-3(X-BP@,'@Q938V.#5F,RP@
M,'AF,S,T,#%C-BP@,'@S,&$R,F,Y-2P@,'@S,6$W,#@U,"P@,'@V,#DS,&8Q
M,RP*("`@("`@("`P>#<S9CDX-#$W+"`P>&$Q,C8Y.#4Y+"`P>&5C-C0U8S0T
M+"`P>#4R8S@W-V$Y+"`P>&-D9F8S,V$V+"`P>&$P,F(Q-S0Q+"`P>#=C8F%D
M.6$R+"`P>#(Q.#`P,S9F+`H@("`@("`@(#!X-3!D.3EC,#@L(#!X8V(S9C0X
M-C$L(#!X8S(V8F0W-C4L(#!X-C1A,V8V86(L(#!X.#`S-#(V-S8L(#!X,C5A
M-S5E-V(L(#!X931E-F0Q9F,L(#!X,C!C-S$P938L"B`@("`@("`@,'AC9&8P
M8C8X,"P@,'@Q-S@T-&0S8BP@,'@S,65E9C@T9"P@,'@W93`X,C1E-"P@,'@R
M8V-B-#EE8BP@,'@X-#9A,V)A92P@,'@X9F8W-S@X."P@,'AE935D-C!F-BP*
M("`@("`@("`P>#=A9C<U-C<S+"`P>#)F9&0U8V1B+"`P>&$Q,38S,6,Q+"`P
M>#,P9C8V9C0S+"`P>&(S9F%E8S4T+"`P>#$U-V9D-V9A+"`P>&5F.#4W.6-C
M+"`P>&0Q-3)D934X+`H@("`@("`@(#!X9&(R9F9D-64L(#!X.&8S,F-E,3DL
M(#!X,S`V868Y-V$L(#!X,#)F,#-E9C@L(#!X.3DS,3EA9#4L(#!X8S(T,F9A
M,&8L(#!X83=E,V5B8C`L(#!X8S8X930Y,#8L"B`@("`@("`@,'AB.&1A,C,P
M8RP@,'@X,#@R,S`R."P@,'AD8V1E9C-C."P@,'AD,S5F8C$W,2P@,'@P.#AA
M,6)C."P@,'AB96,P8S4V,"P@,'@V,6$S8SEE."P@,'AB8V$X9C4T9"P*("`@
M("`@("`P>&,W,F9E9F9A+"`P>#(R.#(R93DY+"`P>#@R8S4W,&(T+"`P>&0X
M9#DT93@Y+"`P>#AB,6,S-&)C+"`P>#,P,64Q-F4V+"`P>#(W,V)E.3<Y+"`P
M>&(P9F9E86$V+`H@("`@("`@(#!X-C%D.6(X8S8L(#!X,#!B,C0X-CDL(#!X
M8C=F9F-E,V8L(#!X,#AD8S(X,V(L(#!X-#-D868V-6$L(#!X9C=E,3DW.3@L
M(#!X-S8Q.6(W,F8L(#!X.&8Q8SEB830L"B`@("`@("`@,'AD8S@V,S=A,"P@
M,'@Q-F$W9#-B,2P@,'@Y9F,S.3-B-RP@,'AA-S$S-F5E8BP@,'AC-F)C8S8S
M92P@,'@Q834Q,S<T,BP@,'AE9C8X,CAB8RP@,'@U,C`S-C5D-BP*("`@("`@
M("`P>#)D-F$W-V%B+"`P>#,U,C=E9#1B+"`P>#@R,69D,C$V+"`P>#`Y-6,V
M93)E+"`P>&1B.3)F,F9B+"`P>#5E96$R.6-B+"`P>#$T-3@Y,F8U+"`P>#DQ
M-3@T9C=F+`H@("`@("`@(#!X-30X,S8Y-V(L(#!X,C8V-V$X8V,L(#!X.#4Q
M.38P-#@L(#!X.&,T8F%C96$L(#!X.#,S.#8P9#0L(#!X,&0R,V4P9CDL(#!X
M-F,S.#=E.&$L(#!X,&%E-F0R-#DL"B`@("`@("`@,'AB,C@T-C`P8RP@,'AD
M.#,U-S,Q9"P@,'AD8V(Q8S8T-RP@,'AA8S1C-39E82P@,'@S96)D.#%B,RP@
M,'@R,S!E86)B,"P@,'@V-#,X8F,X-RP@,'AF,&(U8C%F82P*("`@("`@("`P
M>#AF-65A,F(S+"`P>&9C,3@T-C0R+"`P>#!A,#,V8C=A+"`P>#1F8C`X.6)D
M+"`P>#8T.61A-3@Y+"`P>&$S-#4T,35E+"`P>#5C,#,X,S(S+"`P>#-E-60S
M8F(Y+`H@("`@("`@(#!X-#-D-SDU-S(L(#!X-V4V9&0P-V,L(#!X,#9D9F1F
M,64L(#!X-F,V8V,T968L(#!X-S$V,&$U,SDL(#!X-S-B9F)E-S`L(#!X.#,X
M-S<V,#4L(#!X-#4R,V5C9C$I.PH*("`@("\J*@H@("`@("H@4R!B;W@@*',S
M*0H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1S
M,R`](&%R<F%Y*`H@("`@("`@(#!X.&1E9F,R-#`L(#!X,C5F835D.68L(#!X
M96(Y,#-D8F8L(#!X93@Q,&,Y,#<L(#!X-#<V,#=F9F8L(#!X,S8Y9F4T-&(L
M(#!X.&,Q9F,V-#0L(#!X865C96-A.3`L"B`@("`@("`@,'AB96(Q9CEB9BP@
M,'AE969B8V%E82P@,'AE.&-F,3DU,"P@,'@U,61F,#=A92P@,'@Y,C!E.#@P
M-BP@,'AF,&%D,#4T."P@,'AE,3-C.&0X,RP@,'@Y,C<P,3!D-2P*("`@("`@
M("`P>#$Q,3`W9#EF+"`P>#`W-C0W9&(Y+"`P>&(R93-E-&0T+"`P>#-D-&8R
M.#5E+"`P>&(Y869A.#(P+"`P>&9A9&4X,F4P+"`P>&$P-C<R-CAB+"`P>#@R
M-S(W.3)E+`H@("`@("`@(#!X-34S9F(R8S`L(#!X-#@Y864R,F(L(#!X9#1E
M9CDW.30L(#!X,3(U93-F8F,L(#!X,C%F9F9C964L(#!X.#(U8C%B9F0L(#!X
M.3(U-6,U960L(#!X,3(U-V$R-#`L"B`@("`@("`@,'@T93%A.#,P,BP@,'AB
M864P-V9F9BP@,'@U,C@R-#9E-RP@,'@X934W,30P92P@,'@S,S<S9C=B9BP@
M,'@X8SEF.#$X."P@,'AA-F9C-&5E."P@,'AC.3@R8C5A-2P*("`@("`@("`P
M>&$X8S`Q9&(W+"`P>#4W.69C,C8T+"`P>#8W,#DT9C,Q+"`P>&8R8F0S9C5F
M+"`P>#0P9F9F-V,Q+"`P>#%F8C<X9&9C+"`P>#AE-F)D,F,Q+"`P>#0S-V)E
M-3EB+`H@("`@("`@(#!X.3EB,#-D8F8L(#!X8C5D8F,V-&(L(#!X-C,X9&,P
M938L(#!X-34X,3ED.3DL(#!X83$Y-V,X,6,L(#!X-&$P,3)D-F4L(#!X8S4X
M.#1A,C@L(#!X8V-C,S9F-S$L"B`@("`@("`@,'AB.#0S8S(Q,RP@,'@V8S`W
M-#-F,2P@,'@X,S`Y.#DS8RP@,'@P9F5D9&0U9BP@,'@R9C=F93@U,"P@,'AD
M-V,P-V8W92P@,'@P,C4P-V9B9BP@,'@U869B.6$P-"P*("`@("`@("`P>&$W
M-#=D,F0P+"`P>#$V-3$Q.3)E+"`P>&%F-S!B9C-E+"`P>#4X8S,Q,S@P+"`P
M>#5F.3@S,#)E+"`P>#<R-V-C,V,T+"`P>#!A,&9B-#`R+"`P>#!F-V9E9C@R
M+`H@("`@("`@(#!X.&,Y-F9D860L(#!X-60R8S)A864L(#!X.&5E.3EA-#DL
M(#!X-3!D83@X8C@L(#!X.#0R-V8T83`L(#!X,65A8S4W.3`L(#!X-SDV9F(T
M-#DL(#!X.#(U,F1C,34L"B`@("`@("`@,'AE9F)D-V0Y8BP@,'AA-C<R-3DW
M9"P@,'AA9&$X-#!D."P@,'@T-68U-#4P-"P@,'AF835D-S0P,RP@,'AE.#-E
M8S,P-2P@,'@T9CDQ-S4Q82P@,'@Y,C4V-CEC,BP*("`@("`@("`P>#(S969E
M.30Q+"`P>&$Y,#-F,3)E+"`P>#8P,C<P9&8R+"`P>#`R-S9E-&(V+"`P>#DT
M9F0V-3<T+"`P>#DR-SDX-6(R+"`P>#@R-S9D8F-B+"`P>#`R-S<X,3<V+`H@
M("`@("`@(#!X9CAA9CDQ.&0L(#!X-&4T.&8W.64L(#!X.&8V,39D9&8L(#!X
M93(Y9#@T,&4L(#!X.#0R9C=D.#,L(#!X,S0P8V4U8S@L(#!X.39B8F(V.#(L
M(#!X.3-B-&(Q-#@L"B`@("`@("`@,'AE9C,P,V-A8BP@,'@Y.#1F868R."P@
M,'@W-SEF868Y8BP@,'@Y,F1C-38P9"P@,'@R,C1D,64R,"P@,'@X-#,W86$X
M."P@,'@W9#(Y9&,Y-BP@,'@R-S4V9#-D8RP*("`@("`@("`P>#AB.3`W8V5E
M+"`P>&(U,69D,C0P+"`P>&4W8S`W8V4S+"`P>&4U-C9B-&$Q+"`P>&,S93DV
M,35E+"`P>#-C9C@R,#ED+"`P>#8P.31D,64S+"`P>&-D.6-A,S0Q+`H@("`@
M("`@(#!X-6,W-C0V,&4L(#!X,#!E83DX,V(L(#!X9#1D-C<X.#$L(#!X9F0T
M-S4W,F,L(#!X9C<V8V5D9#DL(#!X8F1A.#(R.6,L(#!X,3(W9&%D86$L(#!X
M-#,X83`W-&4L"B`@("`@("`@,'@Q9CDW8S`Y,"P@,'@P.#%B9&(X82P@,'@Y
M,V$P-V5B92P@,'AB.3,X8V$Q-2P@,'@Y-V(P,V-F9BP@,'@S9&,R8S!F."P@
M,'@X9#%A8C)E8RP@,'@V-#,X,&4U,2P*("`@("`@("`P>#8X8V,W8F9B+"`P
M>&0Y,&8R-S@X+"`P>#$R-#DP,3@Q+"`P>#5D935F9F0T+"`P>&1D-V5F.#9A
M+"`P>#<V83)E,C$T+"`P>&(Y830P,S8X+"`P>#DR-60Y-3AF+`H@("`@("`@
M(#!X-&(S.69F9F$L(#!X8F$S.6%E93DL(#!X831F9F0S,&(L(#!X9F%F-SDS
M,V(L(#!X-F0T.3@V,C,L(#!X,3DS8V)C9F$L(#!X,C<V,C<U-#4L(#!X.#(U
M8V8T-V$L"B`@("`@("`@,'@V,6)D.&)A,"P@,'AD,3%E-#)D,2P@,'AC96%D
M,#1F-"P@,'@Q,C=E83,Y,BP@,'@Q,#0R.&1B-RP@,'@X,C<R83DW,BP@,'@Y
M,C<P8S1A."P@,'@Q,C=D934P8BP*("`@("`@("`P>#(X-6)A,6,X+"`P>#-C
M-C)F-#1F+"`P>#,U8S!E86$U+"`P>&4X,#5D,C,Q+"`P>#0R.#DR.69B+"`P
M>&(T9F-D9C@R+"`P>#1F8C8V834S+"`P>#!E-V1C,35B+`H@("`@("`@(#!X
M,68P.#%F86(L(#!X,3`X-C$X864L(#!X9F-F9#`X-F0L(#!X9CEF9C(X.#DL
M(#!X-CDT8F-C,3$L(#!X,C,V835C864L(#!X,3)D96-A-&0L(#!X,F,S9CAC
M8S4L"B`@("`@("`@,'AD,F0P,F1F92P@,'AF.&5F-3@Y-BP@,'AE-&-F-3)D
M82P@,'@Y-3$U-6(V-RP@,'@T.31A-#@X8RP@,'AB.6(V83@P8RP@,'@U8SAF
M.#)B8RP@,'@X.60S-F(T-2P*("`@("`@("`P>#-A-C`Y-#,W+"`P>&5C,#!C
M.6$Y+"`P>#0T-S$U,C4S+"`P>#!A.#<T8C0Y+"`P>&0W-S-B8S0P+"`P>#=C
M,S0V-S%C+"`P>#`R-S$W968V+"`P>#1F96(U-3,V+`H@("`@("`@(#!X83)D
M,#)F9F8L(#!X9#)B9C8P8S0L(#!X9#0S9C`S8S`L(#!X-3!B-&5F-F0L(#!X
M,#<T-SAC9#$L(#!X,#`V93$X.#@L(#!X83)E-3-F-34L(#!X8CEE-F0T8F,L
M"B`@("`@("`@,'AA,C`T.#`Q-BP@,'@Y-S4W,S@S,RP@,'AD-S(P-V0V-RP@
M,'AD93!F.&8S9"P@,'@W,F8X-V(S,RP@,'AA8F-C-&8S,RP@,'@W-C@X8S4U
M9"P@,'@W8C`P839B,"P*("`@("`@("`P>#DT-V(P,#`Q+"`P>#4W,#`W-60R
M+"`P>&8Y8F(X.&8X+"`P>#@Y-#(P,3EE+"`P>#0R-C1A-69F+"`P>#@U-C,P
M,F4P+"`P>#<R9&)D.3)B+"`P>&5E.3<Q8C8Y+`H@("`@("`@(#!X-F5A,C)F
M9&4L(#!X-68P.&%E,F(L(#!X868W838Q-F0L(#!X935C.3@W-C<L(#!X8V8Q
M9F5B9#(L(#!X-C%E9F,X8S(L(#!X9C%A8S(U-S$L(#!X8V,X,C,Y8S(L"B`@
M("`@("`@,'@V-S(Q-&-B."P@,'AB,64U.#-D,2P@,'AB-V1C,V4V,BP@,'@W
M9C$P8F1C92P@,'AF.3!A-6,S."P@,'@P9F8P-#0S9"P@,'@V,#9E-F1C-BP@
M,'@V,#4T,V$T.2P*("`@("`@("`P>#4W,C=C,30X+"`P>#)B93DX83%D+"`P
M>#AA8C0Q-S,X+"`P>#(P93%B93(T+"`P>&%F.39D83!F+"`P>#8X-#4X-#(U
M+"`P>#DY.#,S8F4U+"`P>#8P,&0T-3=D+`H@("`@("`@(#!X,C@R9CDS-3`L
M(#!X.#,S-&(S-C(L(#!X9#DQ9#$Q,C`L(#!X,F(V9#AD83`L(#!X-C0R8C%E
M,S$L(#!X.6,S,#5A,#`L(#!X-3)B8V4V.#@L(#!X,6(P,S4X.&$L"B`@("`@
M("`@,'AF-V)A969D-2P@,'@T,30R960Y8RP@,'AA-#,Q-6,Q,2P@,'@X,S,R
M,V5C-2P@,'AD9F5F-#8S-BP@,'AA,3,S8S4P,2P@,'AE.60S-3,Q8RP@,'AE
M93,U,S<X,RD["@H@("`@+RHJ"B`@("`@*B!3(&)O>"`H<S0I"B`@("`@*@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)',T(#T@87)R87DH
M"B`@("`@("`@,'@Y9&(S,#0R,"P@,'@Q9F(V93ED92P@,'AA-V)E-V)E9BP@
M,'AD,C<S83(Y."P@,'@T831F-V)D8BP@,'@V-&%D.&,U-RP@,'@X-34Q,#0T
M,RP@,'AF83`R,&5D,2P*("`@("`@("`P>#=E,C@W869F+"`P>&4V,&9B-C8S
M+"`P>#`Y-68S-6$Q+"`P>#<Y96)F,3(P+"`P>&9D,#4Y9#0S+"`P>#8T.3=B
M-V(Q+"`P>&8S-C0Q9C8S+"`P>#(T,64T861F+`H@("`@("`@(#!X,C@Q-#=F
M-68L(#!X-&9A,F(X8V0L(#!X8SDT,S`P-#`L(#!X,&-C,S(R,C`L(#!X9F1D
M,S!B,S`L(#!X8S!A-3,W-&8L(#!X,60R9#`P9#DL(#!X,C0Q-#=B,34L"B`@
M("`@("`@,'AE931D,3$Q82P@,'@P9F-A-3$V-RP@,'@W,69F.3`T8RP@,'@R
M9#$Y-69F92P@,'@Q83`U-C0U9BP@,'@P8S$S9F5F92P@,'@P.#%B,#AC82P@
M,'@P-3$W,#$R,2P*("`@("`@("`P>#@P-3,P,3`P+"`P>&4X,V4U969E+"`P
M>&%C.6%F-&8X+"`P>#=F93<R-S`Q+"`P>&0R8CAE935F+"`P>#`V9&8T,C8Q
M+"`P>&)B.64Y8CAA+"`P>#<R.3-E83(U+`H@("`@("`@(#!X8V4X-&9F9&8L
M(#!X9C4W,3@X,#$L(#!X,V1D-C1B,#0L(#!X83(V9C(V,V(L(#!X-V5D-#@T
M,#`L(#!X-30W965B938L(#!X-#0V9#1C83`L(#!X-F-F,V0V9C4L"B`@("`@
M("`@,'@R-C0Y86)D9BP@,'AA96$P8S=F-2P@,'@S-C,S.&-C,2P@,'@U,#-F
M-V4Y,RP@,'AD,S<W,C`V,2P@,'@Q,6(V,SAE,2P@,'@W,C4P,&4P,RP@,'AF
M.#!E8C)B8BP*("`@("`@("`P>&%B93`U,#)E+"`P>&5C.&0W-V1E+"`P>#4W
M.3<Q93@Q+"`P>&4Q-&8V-S0V+"`P>&,Y,S,U-#`P+"`P>#8Y,C`S,3AF+"`P
M>#`X,61B8CDY+"`P>&9F8S,P-&$U+`H@("`@("`@(#!X-&0S-3$X,#4L(#!X
M-V8S9#5C93,L(#!X839C.#8V8S8L(#!X-60U8F-C83DL(#!X9&%E8S9F96$L
M(#!X.68Y,C9F.3$L(#!X.68T-C(R,F8L(#!X,SDY,30V-V0L"B`@("`@("`@
M,'AA-6)F-F0X92P@,'@Q,30S8S0T9BP@,'@T,SDU.#,P,BP@,'AD,#(Q-&5E
M8BP@,'@P,C(P.#-B."P@,'@S9F(V,3@P8RP@,'@Q.&8X.3,Q92P@,'@R.#$V
M-3AE-BP*("`@("`@("`P>#(V-#@V93-E+"`P>#AB9#<X83<P+"`P>#<T-S=E
M-&,Q+"`P>&(U,#9E,#=C+"`P>&8S,F0P83(U+"`P>#<Y,#DX8C`R+"`P>&4T
M96%B8C@Q+"`P>#(X,3(S8C(S+`H@("`@("`@(#!X-CED96%D,S@L(#!X,34W
M-&-A,38L(#!X9&8X-S%B-C(L(#!X,C$Q8S0P8C<L(#!X834Q83EE9CDL(#!X
M,#`Q-#,W-V(L(#!X,#0Q93AA8S@L(#!X,#DQ,30P,#,L"B`@("`@("`@,'AB
M9#4Y931D,BP@,'AE,V0Q-39D-2P@,'@T9F4X-S9D-2P@,'@R9CDQ83,T,"P@
M,'@U-3=B93AD92P@,'@P,&5A931A-RP@,'@P8V4U8S)E8RP@,'@T9&(T8F)A
M-BP*("`@("`@("`P>&4W-39B9&9F+"`P>&1D,S,V.6%C+"`P>&5C,3=B,#,U
M+"`P>#`V-3<R,S(W+"`P>#DY869C.&(P+"`P>#4V8SAC,SDQ+"`P>#9B-C4X
M,3%C+"`P>#5E,30V,3$Y+`H@("`@("`@(#!X-F4X-6-B-S4L(#!X8F4P-V,P
M,#(L(#!X8S(S,C4U-S<L(#!X.#DS9F8T96,L(#!X-6)B9F,Y,F0L(#!X9#!E
M8S-B,C4L(#!X8C<X,#%A8C<L(#!X.&0V9#-B,C0L"B`@("`@("`@,'@R,&,W
M-C-E9BP@,'AC,S8V835F8RP@,'@Y8S,X,C@X,"P@,'@P86-E,S(P-2P@,'AA
M86,Y-30X82P@,'AE8V$Q9#=C-RP@,'@P-#%A9F$S,BP@,'@Q9#$V-C(U82P*
M("`@("`@("`P>#8W,#$Y,#)C+"`P>#EB-S4W834T+"`P>#,Q9#0W-V8W+"`P
M>#DQ,C9B,#,Q+"`P>#,V8V,V9F1B+"`P>&,W,&(X8C0V+"`P>&0Y938V830X
M+"`P>#4V934U83<Y+`H@("`@("`@(#!X,#(V831C96(L(#!X-3(T,S=E9F8L
M(#!X,F8X9C<V8C0L(#!X,&1F.3@P834L(#!X.#8W-&-D93,L(#!X961D83`T
M96(L(#!X,3=A.6)E,#0L(#!X,F,Q.&8T9&8L"B`@("`@("`@,'AB-S<T-V8Y
M9"P@,'AA8C)A9C=B-"P@,'AE9F,S-&0R,"P@,'@R93`Y-F(W8RP@,'@Q-S0Q
M83(U-"P@,'AE-6(V83`S-2P@,'@R,3-D-#)F-BP@,'@R8S%C-V,R-BP*("`@
M("`@("`P>#8Q8S)F-3!F+"`P>#8U-3)D868Y+"`P>&0R8S(S,68X+"`P>#(U
M,3,P9C8Y+"`P>&0X,38W9F$R+"`P>#`T,3AF,F,X+"`P>#`P,6$Y-F$V+"`P
M>#!D,34R-F%B+`H@("`@("`@(#!X-C,S,35C,C$L(#!X-64P83<R96,L(#!X
M-#EB869E9F0L(#!X,3@W.3`X9#DL(#!X.&0P9&)D.#8L(#!X,S$Q,3<P83<L
M(#!X,V4Y8C8T,&,L(#!X8V,S93$P9#<L"B`@("`@("`@,'AD-6-A9#-B-BP@
M,'@P8V%E8S,X."P@,'AF-S,P,#%E,2P@,'@V8S<R.&%F9BP@,'@W,65A93)A
M,2P@,'@Q9CEA9C,V92P@,'AC9F-B9#$R9BP@,'AC,61E.#0Q-RP*("`@("`@
M("`P>&%C,#=B939B+"`P>&-B-#1A,60X+"`P>#AB.6(P9C4V+"`P>#`Q,SDX
M.&,S+"`P>&(Q8S4R9F-A+"`P>&(T8F4S,6-D+"`P>&0X-S@R.#`V+"`P>#$R
M83-A-&4R+`H@("`@("`@(#!X-F8W9&4U,S(L(#!X-3AF9#=E8C8L(#!X9#`Q
M964Y,#`L(#!X,C1A9&9F8S(L(#!X9C0Y.3!F8S4L(#!X.3<Q,6%A8S4L(#!X
M,#`Q9#=B.34L(#!X.#)E-64W9#(L"B`@("`@("`@,'@Q,#DX-S-F-BP@,'@P
M,#8Q,S`Y-BP@,'AC,S)D.34R,2P@,'AA9&$Q,C%F9BP@,'@R.3DP.#0Q-2P@
M,'@W9F)B.3<W9BP@,'AA9CEE8C-D8BP@,'@R.6,Y960R82P*("`@("`@("`P
M>#5C93)A-#8U+"`P>&$W,S!F,S)C+"`P>&0P86$S9F4X+"`P>#AA-6-C,#DQ
M+"`P>&0T.64R8V4W+"`P>#!C930U-&$Y+"`P>&0V,&%C9#@V+"`P>#`Q-68Q
M.3$Y+`H@("`@("`@(#!X-S<P-SDQ,#,L(#!X9&5A,#-A9C8L(#!X-SAA.#4V
M-64L(#!X9&5E,S4V9&8L(#!X,C%F,#5C8F4L(#!X.&(W-64S.#<L(#!X8C-C
M-3`V-3$L(#!X8CAA-6,S968L"B`@("`@("`@,'AD.&5E8C9D,BP@,'AE-3(S
M8F4W-RP@,'AC,C$U-#4R.2P@,'@R9C8Y969D9BP@,'AA9F4V-V%F8BP@,'AF
M-#<P8S1B,BP@,'AF,V4P96(U8BP@,'AD-F-C.3@W-BP*("`@("`@("`P>#,Y
M930T-C!C+"`P>#%F9&$X-3,X+"`P>#$Y.#<X,S)F+"`P>&-A,#`W,S8W+"`P
M>&$Y.3$T-&8X+"`P>#(Y-F(R.3EE+"`P>#0Y,F9C,CDU+"`P>#DR-C9B96%B
M+`H@("`@("`@(#!X8C4V-S9E-CDL(#!X.6)D,V1D9&$L(#!X9&8W93`U,F8L
M(#!X9&(R-3<P,6,L(#!X,6(U934Q964L(#!X9C8U,S(T938L(#!X-F%F8V4S
M-F,L(#!X,#,Q-F-C,#0L"B`@("`@("`@,'@X-C0T,C$S92P@,'AB-V1C-3ED
M,"P@,'@W.38U,CDQ9BP@,'AC8V0V9F0T,RP@,'@T,3@R,SDW.2P@,'@Y,S)B
M8V1F-BP@,'AB-C4W8S,T9"P@,'@T961F9#(X,BP*("`@("`@("`P>#=A934R
M.3!C+"`P>#-C8CDU,S9B+"`P>#@U,64R,&9E+"`P>#DX,S,U-3=E+"`P>#$S
M96-F,&(P+"`P>&0S9F9B,S<R+"`P>#-F.#5C-6,Q+"`P>#!A968W960R*3L*
M"B`@("`O*BH*("`@("`J(%,@8F]X("AS-2D*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D<S4@/2!A<G)A>2@*("`@("`@("`P
M>#=E8SDP8S`T+"`P>#)C-F4W-&(Y+"`P>#EB,&4V-F1F+"`P>&$V,S,W.3$Q
M+"`P>&(X-F$W9F9F+"`P>#%D9#,U.&8U+"`P>#0T9&0Y9#0T+"`P>#$W,S$Q
M-C=F+`H@("`@("`@(#!X,#AF8F8Q9F$L(#!X93=F-3$Q8V,L(#!X9#(P-3%B
M,#`L(#!X-S,U86)A,#`L(#!X,F%B-S(R9#@L(#!X,S@V,S@Q8V(L(#!X86-F
M-C(T,V$L(#!X-CEB969D-V$L"B`@("`@("`@,'AE-F$R93<W9BP@,'AF,&,W
M,C!C9"P@,'AC-#0Y-#@Q-BP@,'AC8V8U8S$X,"P@,'@S.#@U,38T,"P@,'@Q
M-6(P83@T."P@,'AE-CAB,3AC8BP@,'@T8V%A9&5F9BP*("`@("`@("`P>#5F
M-#@P83`Q+"`P>#`T,3)B,F%A+"`P>#(U.3@Q-&9C+"`P>#0Q9#!E9F4R+"`P
M>#1E-#!B-#AD+"`P>#(T.&5B-F9B+"`P>#AD8F$Q8V9E+"`P>#0Q83DY8C`R
M+`H@("`@("`@(#!X,6$U-3!A,#0L(#!X8F$X9C8U8V(L(#!X-S(U,68T93<L
M(#!X.35A-3$W,C4L(#!X8S$P-F5C9#<L(#!X.3=A-3DX,&$L(#!X8S4S.6(Y
M86$L(#!X-&0W.69E-F$L"B`@("`@("`@,'AF,F8S9C<V,RP@,'@V.&%F.#`T
M,"P@,'AE9#!C.64U-BP@,'@Q,6(T.34X8BP@,'AE,65B-6$X."P@,'@X-S`Y
M939B,"P@,'AD-V4P-S$U-BP@,'@T93(Y9F5A-RP*("`@("`@("`P>#8S-C9E
M-3)D+"`P>#`R9#%C,#`P+"`P>&,T86,X93`U+"`P>#DS-S=F-3<Q+"`P>#!C
M,#4S-S)A+"`P>#4W.#4S-68R+"`P>#(R-C%B93`R+"`P>&0V-#)A,&,Y+`H@
M("`@("`@(#!X9&8Q,V$R.#`L(#!X-S1B-35B9#(L(#!X-C@R,3DY8S`L(#!X
M9#0R,64U96,L(#!X-3-F8C-C93@L(#!X8SAA9&5D8C,L(#!X,CAA.#=F8SDL
M(#!X,V0Y-3DY.#$L"B`@("`@("`@,'@U8S%F9CDP,"P@,'AF93,X9#,Y.2P@
M,'@P8S1E9F8P8BP@,'@P-C(T,#=E82P@,'AA83)F-&9B,2P@,'@T9F(Y-CDW
M-BP@,'@Y,&,W.34P-2P@,'AB,&$X83<W-"P*("`@("`@("`P>&5F-35A,69F
M+"`P>&4U.6-A,F,R+"`P>&$V8C8R9#(W+"`P>&4V-F$T,C8S+"`P>&1F-C4P
M,#%F+"`P>#!E8S4P.38V+"`P>&1F9&0U-6)C+"`P>#(Y9&4P-C4U+`H@("`@
M("`@(#!X.3$Q93<S.6$L(#!X,3=A9C@Y-S4L(#!X,S)C-SDQ,6,L(#!X.#EF
M.#DT-C@L(#!X,&0P,64Y.#`L(#!X-3(T-S4U9C0L(#!X,#-B-C-C8SDL(#!X
M,&-C.#0T8C(L"B`@("`@("`@,'AB8V8S9C!A82P@,'@X-V%C,S9E.2P@,'AE
M-3-A-S0R-BP@,'@P,6(S9#@R8BP@,'@Q83EE-S0T.2P@,'@V-&5E,F0W92P@
M,'AC9&1B8C%D82P@,'@P,6,Y-#DQ,"P*("`@("`@("`P>&(X-CAB9C@P+"`P
M>#!D,C9F,V9D+"`P>#DS-#)E9&4W+"`P>#`T835C,C@T+"`P>#8S-C<S-V(V
M+"`P>#4P9C5B-C$V+"`P>&8R-#<V-F4S+"`P>#AE8V$S-F,Q+`H@("`@("`@
M(#!X,3,V93`U9&(L(#!X9F5F,3@S.3$L(#!X9F(X.#=A,S<L(#!X9#9E-V8W
M9#0L(#!X8S=F8C=D8SDL(#!X,S`V,V9C9&8L(#!X8C9F-3@Y9&4L(#!X96,R
M.30Q9&$L"B`@("`@("`@,'@R-F4T-C8Y-2P@,'AB-S4V-C0Q.2P@,'AF-C4T
M969C-2P@,'AD,#AD-3AB-RP@,'@T.#DR-30P,2P@,'AC,6)A8V(W9BP@,'AE
M-69F-34P9BP@,'AB-C`X,S`T.2P*("`@("`@("`P>#5B8C5D,&4X+"`P>#@W
M9#<R935A+"`P>&%B-F$V964Q+"`P>#(R,V$V-F-E+"`P>&,V,F)F,V-D+"`P
M>#EE,#@X-68Y+"`P>#8X8V(S930W+"`P>#`X-F,P,3!F+`H@("`@("`@(#!X
M83(Q9&4X,C`L(#!X9#$X8C8Y9&4L(#!X9C-F-C4W-S<L(#!X9F$P,F,S9C8L
M(#!X-#`W961A8S,L(#!X8V)B,V0U-3`L(#!X,3<Y,S`X-&0L(#!X8C!D-S!E
M8F$L"B`@("`@("`@,'@P86(S-SAD-2P@,'AD.34Q9F(P8RP@,'AD960W9&$U
M-BP@,'@T,3(T8F)E-"P@,'@Y-&-A,&(U-BP@,'@P9C4W-35D,2P@,'AE,&4Q
M934V92P@,'@V,3@T8C5B92P*("`@("`@("`P>#4X,&$R-#EF+"`P>#DT9C<T
M8F,P+"`P>&4S,C<X.#AE+"`P>#EF-V(U-38Q+"`P>&,S9&,P,C@P+"`P>#`U
M-C@W-S$U+"`P>#8T-F,V8F0W+"`P>#0T.3`T9&(S+`H@("`@("`@(#!X-C9B
M-&8P83,L(#!X8S!F,38T.&$L(#!X-CDW960U868L(#!X-#EE.3)F9C8L(#!X
M,S`Y93,W-&8L(#!X,F-B-C,U-F$L(#!X.#4X,#@U-S,L(#!X-#DY,68X-#`L
M"B`@("`@("`@,'@W-F8P864P,BP@,'@P.#-B93@T9"P@,'@R.#0R,6,Y82P@
M,'@T-#0X.30P-BP@,'@W,S9E-&-B."P@,'AC,3`Y,CDQ,"P@,'@X8F,Y-69C
M-BP@,'@W9#@V.6-F-"P*("`@("`@("`P>#$S-&8V,39F+"`P>#)E-S<Q,3AD
M+"`P>&(S,6(R8F4Q+"`P>&%A.3!B-#<R+"`P>#-C835D-S$W+"`P>#=D,38Q
M8F)A+"`P>#EC860Y,#$P+"`P>&%F-#8R8F$R+`H@("`@("`@(#!X.69E-#4Y
M9#(L(#!X-#5D,S0U-3DL(#!X9#EF,F1A,3,L(#!X9&)C-C4T.#<L(#!X9C-E
M-&8Y-&4L(#!X,3<V9#0X-F8L(#!X,#DW8S$S96$L(#!X-C,Q9&$U8S<L"B`@
M("`@("`@,'@T-#5F-S,X,BP@,'@Q-S4V.#-F-"P@,'AC9&,V-F$Y-RP@,'@W
M,&)E,#(X."P@,'AB,V-D8V8W,BP@,'@V935D9#)F,RP@,'@R,#DS-C`W.2P@
M,'@T-3EB.#!A-2P*("`@("`@("`P>&)E-C!E,F1B+"`P>&$Y8S(S,3`Q+"`P
M>&5B834S,35C+"`P>#(R-&4T,F8R+"`P>#%C-6,Q-3<R+"`P>&8V-S(Q8C)C
M+"`P>#%A9#)F9F8S+"`P>#AC,C4T,#1E+`H@("`@("`@(#!X,S(T960W,F8L
M(#!X-#`V-V(W9F0L(#!X,#4R,S$S.&4L(#!X-6-A,V)C-S@L(#!X9&,P9F0V
M-F4L(#!X-S4Y,C(R.#,L(#!X-S@T9#9B,3<L(#!X-3AE8F(Q-F4L"B`@("`@
M("`@,'@T-#`Y-&8X-2P@,'@S9C0X,60X-RP@,'AF8V9E864W8BP@,'@W-V(U
M9F8W-BP@,'@X8S(S,#)B9BP@,'AA868T-S4U-BP@,'@U9C0V8C`R82P@,'@R
M8C`Y,C@P,2P*("`@("`@("`P>#-D,SAF-68W+"`P>#!C83@Q9C,V+"`P>#4R
M868T83AA+"`P>#8V9#5E-V,P+"`P>&1F,V(P.#<T+"`P>#DU,#4U,3$P+"`P
M>#%B-6%D-V$X+"`P>&8V,65D-6%D+`H@("`@("`@(#!X-F-F-F4T-SDL(#!X
M,C`W-3@Q.#0L(#!X9#!C969A-C4L(#!X.#AF-V)E-3@L(#!X-&$P-#8X,C8L
M(#!X,&9F-F8X9C,L(#!X83`Y8S=F-S`L(#!X-3,T-F%B83`L"B`@("`@("`@
M,'@U8V4Y-F,R."P@,'AE,3<V961A,RP@,'@V8F%C,S`W9BP@,'@S-S8X,CED
M,BP@,'@X-3,V,&9A.2P@,'@Q-V4S9F4R82P@,'@R-&(W.3<V-RP@,'AF-6$Y
M-F(R,"P*("`@("`@("`P>&0V8V0R-3DU+"`P>#8X9F8Q96)F+"`P>#<U-34T
M-#)C+"`P>&8Q.68P-F)E+"`P>&8Y93`V-3EA+"`P>&5E8CDT.3%D+"`P>#,T
M,#$P-S$X+"`P>&)B,S!C86(X+`H@("`@("`@(#!X93@R,F9E,34L(#!X.#@U
M-S`Y.#,L(#!X-S4P938R-#DL(#!X9&$V,C=E-34L(#!X-64W-F9F83@L(#!X
M8C$U,S0U-#8L(#!X-F0T-V1E,#@L(#!X969E.64W9#0I.PH*("`@("\J*@H@
M("`@("H@4R!B;W@@*',V*0H@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1S-B`](&%R<F%Y*`H@("`@("`@(#!X9C9F83AF.60L
M(#!X,F-A8S9C93$L(#!X-&-A,S0X-C<L(#!X93(S,S=F-V,L(#!X.35D8C`X
M93<L(#!X,#$V.#0S8C0L(#!X96-E9#5C8F,L(#!X,S(U-34S86,L"B`@("`@
M("`@,'AB9CEF,#DV,"P@,'AD9F$Q93)E9"P@,'@X,V8P-3<Y9"P@,'@V,V5D
M.#9B.2P@,'@Q86(V839B."P@,'AD935E8F4S.2P@,'AF,SAF9C<S,BP@,'@X
M.3@Y8C$S."P*("`@("`@("`P>#,S9C$T.38Q+"`P>&,P,3DS-V)D+"`P>&8U
M,#9C-F1A+"`P>&4T-C(U93=E+"`P>&$S,#AE83DY+"`P>#1E,C-E,S-C+"`P
M>#<Y8V)D-V-C+"`P>#0X83$T,S8W+`H@("`@("`@(#!X83,Q-#DV,3DL(#!X
M9F5C.31B9#4L(#!X83$Q-#$W-&$L(#!X96%A,#$X-C8L(#!X83`X-&1B,F0L
M(#!X,#EA.#0X-F8L(#!X83@X.#8Q-&$L(#!X,CDP,&%F.3@L"B`@("`@("`@
M,'@P,38V-3DY,2P@,'AE,3DY,C@V,RP@,'AC.&8S,&,V,"P@,'@R93<X968S
M8RP@,'AD,&0U,3DS,BP@,'AC9C!F96,Q-"P@,'AF-V-A,#=D,BP@,'AD,&$X
M,C`W,BP*("`@("`@("`P>&9D-#$Q.3=E+"`P>#DS,#5A-F(P+"`P>&4X-F)E
M,V1A+"`P>#<T8F5D,V-D+"`P>#,W,F1A-3-C+"`P>#1C-V8T-#0X+"`P>&1A
M8C5D-#0P+"`P>#9D8F$P96,S+`H@("`@("`@(#!X,#@S.3$Y83<L(#!X.69B
M865E9#DL(#!X-#ED8F-F8C`L(#!X-&4V-S!C-3,L(#!X-6,S9#EC,#$L(#!X
M-C1B9&(Y-#$L(#!X,F,P938S-F$L(#!X8F$W9&0Y8V0L"B`@("`@("`@,'AE
M839F-S,X."P@,'AE-S!B8S<V,BP@,'@S-68R.6%D8BP@,'@U8S1C9&0X9"P@
M,'AF,&0T.&0X8RP@,'AB.#@Q-3-E,BP@,'@P.&$Q.3@V-BP@,'@Q864R96%C
M."P*("`@("`@("`P>#(X-&-A9C@Y+"`P>&%A.3(X,C(S+"`P>#DS,S1B934S
M+"`P>#-B,V$R,6)F+"`P>#$V-#,T8F4S+"`P>#EA96$S.3`V+"`P>&5F93AC
M,S9E+"`P>&8X.3!C9&0Y+`H@("`@("`@(#!X.#`R,C9D864L(#!X8S,T,&$T
M83,L(#!X9&8W93EC,#DL(#!X838Y-&$X,#<L(#!X-6(W8S5E8V,L(#!X,C(Q
M9&(S838L(#!X.6$V.6$P,F8L(#!X-C@X,3AA-30L"B`@("`@("`@,'AC96(R
M,CDV9BP@,'@U,V,P.#0S82P@,'AF93@Y,S8U-2P@,'@R-6)F938X82P@,'AB
M-#8R.&%B8RP@,'AC9C(R,F5B9BP@,'@R-6%C-F8T."P@,'AA.6$Y.3,X-RP*
M("`@("`@("`P>#4S8F1D8C8U+"`P>&4W-F9F8F4W+"`P>&4Y-C=F9#<X+"`P
M>#!B83DS-38S+"`P>#AE,S0R8F,Q+"`P>&4X83$Q8F4Y+"`P>#0Y.#`W-#!D
M+"`P>&,X,#@W9&9C+`H@("`@("`@(#!X.&1E-&)F.3DL(#!X83$Q,3`Q83`L
M(#!X-V9D,S<Y-S4L(#!X9&$U83(V8S`L(#!X93@Q9CDY-&8L(#!X.34R.&-D
M.#DL(#!X9F0S,SEF960L(#!X8C@W.#,T8F8L"B`@("`@("`@,'@U9C`T-#4V
M9"P@,'@R,C(U.#8Y."P@,'AC.6,T8S@S8BP@,'@R9&,Q-39B92P@,'@T9C8R
M.&1A82P@,'@U-V8U-65C-2P@,'AE,C(R,&%B92P@,'AD,CDQ-F5B9BP*("`@
M("`@("`P>#1E8S<U8CDU+"`P>#(T9C)C,V,P+"`P>#0R9#$U9#DY+"`P>&-D
M,&0W9F$P+"`P>#=B-F4R-V9F+"`P>&$X9&,X868P+"`P>#<S-#5C,3`V+"`P
M>&8T,64R,S)F+`H@("`@("`@(#!X,S4Q-C(S.#8L(#!X939E83@Y,C8L(#!X
M,S,S,V(P.30L(#!X,34W96,V9C(L(#!X,S<R8C<T868L(#!X-CDR-3<S930L
M(#!X93EA.60X-#@L(#!X9C,Q-C`R.#DL"B`@("`@("`@,'@S838R968Q9"P@
M,'AA-S@W93(S."P@,'AF,V$U9C8W-BP@,'@W-#,V-#@U,RP@,'@R,#DU,3`V
M,RP@,'@T-3<V-CDX9"P@,'AB-F9A9#0P-RP@,'@U.3)A9CDU,"P*("`@("`@
M("`P>#,V9C<S-3(S+"`P>#1C9F(V93@W+"`P>#=D831C96,P+"`P>#9C,34R
M9&%A+"`P>&-B,#,Y-F$X+"`P>&,U,&1F935D+"`P>&9C9#<P-V%B+"`P>#`Y
M,C%C-#)F+`H@("`@("`@(#!X.#ED9F8P8F(L(#!X-69E,F)E-S@L(#!X-#0X
M9C1F,S,L(#!X-S4T-C$S8SDL(#!X,F(P-60P.&0L(#!X-#AB.60U.#4L(#!X
M9&,P-#DT-#$L(#!X8S@P.3AF.6(L"B`@("`@("`@,'@W9&5D93<X-BP@,'AC
M,SEA,S,W,RP@,'@T,C0Q,#`P-2P@,'@V83`Y,3<U,2P@,'@P968S8SAA-BP@
M,'@X.3`P-S)D-BP@,'@R.#(P-S8X,BP@,'AA.6$Y9C=B92P*("`@("`@("`P
M>&)F,S(V-SED+"`P>&0T-6(U8C<U+"`P>&(S-3-F9#`P+"`P>&-B8C!E,S4X
M+"`P>#@S,&8R,C!A+"`P>#%F.&9B,C$T+"`P>&0S-S)C9C`X+"`P>&-C,V,T
M83$S+`H@("`@("`@(#!X.&-F-C,Q-C8L(#!X,#8Q8S@W8F4L(#!X.#AC.3AF
M.#@L(#!X-C`V,F4S.3<L(#!X-#=C9CAE-V$L(#!X8C9C.#4R.#,L(#!X,V-C
M,F%C9F(L(#!X,V9C,#8Y-S8L"B`@("`@("`@,'@T93AF,#(U,BP@,'@V-&0X
M,S$T9"P@,'AD83,X-S!E,RP@,'@Q938V-30U.2P@,'AC,3`Y,#AF,"P@,'@U
M,3,P,C%A-2P@,'@V8S5B-CAB-RP@,'@X,C)F.&%A,"P*("`@("`@("`P>#,P
M,#=C9#-E+"`P>#<T-S$Y965F+"`P>&1C.#<R-C@Q+"`P>#`W,S,T,&0T+"`P
M>#=E-#,R9F0Y+"`P>#!C-65C,C0Q+"`P>#@X,#DR.#9C+"`P>&8U.3)D.#DQ
M+`H@("`@("`@(#!X,#AA.3,P9C8L(#!X.34W968S,#4L(#!X8C=F8F9F8F0L
M(#!X8S(V-F4Y-F8L(#!X-F9E-&%C.3@L(#!X8C$W,V5C8S`L(#!X8F,V,&(T
M,F$L(#!X.34S-#DX9&$L"B`@("`@("`@,'AF8F$Q864Q,BP@,'@R9#1B9#<S
M-BP@,'@P9C(U9F%A8BP@,'AA-&8S9F-E8BP@,'AE,CDV.3$R,RP@,'@R-3=F
M,&,S9"P@,'@Y,S0X868T.2P@,'@S-C$T,#!B8RP*("`@("`@("`P>&4X.#$V
M9C1A+"`P>#,X,31F,C`P+"`P>&$S9CDT,#0S+"`P>#EC-V$U-&,R+"`P>&)C
M-S`T9C4W+"`P>&1A-#%E-V8Y+"`P>&,R-6%D,S-A+"`P>#4T9C1A,#@T+`H@
M("`@("`@(#!X8C$W9C4U,#4L(#!X-3DS-3=C8F4L(#!X961B9#$U8S@L(#!X
M-V8Y-V,U86(L(#!X8F$U86,W8C4L(#!X8C9F-F1E868L(#!X,V$T-SEC,V$L
M(#!X-3,P,F1A,C4L"B`@("`@("`@,'@V-3-D-V4V82P@,'@U-#(V.&0T.2P@
M,'@U,6$T-S=E82P@,'@U,#$W9#4U8BP@,'AD-V0R-60X."P@,'@T-#$S-F,W
M-BP@,'@P-#`T83AC."P@,'AB.&4U83$R,2P*("`@("`@("`P>&(X,6$Y,CAA
M+"`P>#8P960U.#8Y+"`P>#DW8S4U8CDV+"`P>&5A96,Y.3%B+"`P>#(Y.3,U
M.3$S+"`P>#`Q9F1B-V8Q+"`P>#`X.&4X9&9A+"`P>#EA8C9F-F8U+`H@("`@
M("`@(#!X,V(T8V)F.68L(#!X-&$U9&4S86(L(#!X938P-3%D,S4L(#!X83!E
M,60X-34L(#!X9#,V8C1C9C$L(#!X9C4T-&5D96(L(#!X8C!E.3,U,C0L(#!X
M8F5B8CAF8F0L"B`@("`@("`@,'AA,F0W-C)C9BP@,'@T.6,Y,F8U-"P@,'@S
M.&(U9C,S,2P@,'@W,3(X830U-"P@,'@T.#,Y,CDP-2P@,'AA-C5B,61B."P@
M,'@X-3%C.3=B9"P@,'AD-C<U8V8R9BD["@H@("`@+RHJ"B`@("`@*B!3(&)O
M>"`H<S<I"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)',W(#T@87)R87DH"B`@("`@("`@,'@X-64P-#`Q.2P@,'@S,S)B9C4V
M-RP@,'@V-C)D8F9F9BP@,'AC9F,V-38Y,RP@,'@R83AD-V8V9BP@,'AA8CEB
M8SDQ,BP@,'AD938P,#AA,2P@,'@R,#(X9&$Q9BP*("`@("`@("`P>#`R,C=B
M8V4W+"`P>#1D-C0R.3$V+"`P>#$X9F%C,S`P+"`P>#4P9C$X8C@R+"`P>#)C
M8C)C8C$Q+"`P>&(R,S)E-S5C+"`P>#1B,S8Y-68R+"`P>&(R.#<P-V1E+`H@
M("`@("`@(#!X83`U9F)C9C8L(#!X8V0T,3@Q93DL(#!X93$U,#(Q,&,L(#!X
M93(T968Q8F0L(#!X8C$V.&,S.#$L(#!X9F1E-&4W.#DL(#!X-6,W.6(P9#@L
M(#!X,64X8F9D-#,L"B`@("`@("`@,'@T9#0Y-3`P,2P@,'@S.&)E-#,T,2P@
M,'@Y,3-C964Q9"P@,'@Y,F$W.6,S9BP@,'@P.#DW-C9B92P@,'AB865E861F
M-"P@,'@Q,C@V8F5C9BP@,'AB-F5A8V(Q.2P*("`@("`@("`P>#(V-C!C,C`P
M+"`P>#<U-C5B9&4T+"`P>#8T,C0Q9C=A+"`P>#@R-#AD8V$Y+"`P>&,S8C-A
M9#8V+"`P>#(X,3,V,#@V+"`P>#!B9#AD9F$X+"`P>#,U-F0Q8V8R+`H@("`@
M("`@(#!X,3`W-S@Y8F4L(#!X8C-B,F4Y8V4L(#!X,#4P,F%A.&8L(#!X,&)C
M,#,U,64L(#!X,38V8F8U,F$L(#!X96(Q,F9F.#(L(#!X93,T.#8Y,3$L(#!X
M9#,T9#<U,38L"B`@("`@("`@,'@T93=B,V%F9BP@,'@U9C0S-C<Q8BP@,'@Y
M8V8V93`S-RP@,'@T.3@Q86,X,RP@,'@S,S0R-C9C92P@,'@X8SDS-#%B-RP@
M,'AD,&0X-31C,"P@,'AC8C-A-F,X."P*("`@("`@("`P>#0W8F,R.#(Y+"`P
M>#0W,C5B83,W+"`P>&$V-F%D,C)B+"`P>#=A9#8Q9C%E+"`P>#!C-6-B869A
M+"`P>#0T,S=F,3`W+"`P>&(V93<Y.38R+"`P>#0R9#)D.#$V+`H@("`@("`@
M(#!X,&$Y-C$R.#@L(#!X93%A-6,P-F4L(#!X,3,W-#EE-C<L(#!X-S)F8S`X
M,6$L(#!X8C%D,3,Y9C<L(#!X9CDU.#,W-#4L(#!X8V8Q.61F-3@L(#!X8F5C
M,V8W-38L"B`@("`@("`@,'AC,#9E8F$S,"P@,'@P-S(Q,6(R-"P@,'@T-6,R
M.#@R.2P@,'AC.35E,S$W9BP@,'AB8SAE8S4Q,2P@,'@S.&)C-#9E.2P@,'AC
M-F4V9F$Q-"P@,'AB864X-3@T82P*("`@("`@("`P>&%D-&5B8S0V+"`P>#0V
M.&8U,#AB+"`P>#<X,CDT,S5F+"`P>&8Q,C0Q.#-B+"`P>#@R,61B83EF+"`P
M>&%F9C8P9F8T+"`P>&5A,F,T939D+"`P>#$V93,Y,C8T+`H@("`@("`@(#!X
M.3(U-#1A.&(L(#!X,#`Y8C1F8S,L(#!X86)A-CAC960L(#!X.6%C.39F-S@L
M(#!X,#9A-6(W.6$L(#!X8C(X-39E-F4L(#!X,6%E8S-C83DL(#!X8F4X,S@V
M.#@L"B`@("`@("`@,'@P93`X,#1E.2P@,'@U-68Q8F4U-BP@,'AE-V4U,S8S
M8BP@,'AB,V$Q9C(U9"P@,'AF-V1E8F(X-2P@,'@V,69E,#,S8RP@,'@Q-C<T
M-C(S,RP@,'@S8S`S-&,R."P*("`@("`@("`P>&1A-F0P8S<T+"`P>#<Y86%C
M-39C+"`P>#-C931E,6%D+"`P>#4Q9C!C.#`R+"`P>#DX9CAF,S5A+"`P>#$V
M,C9A-#EF+"`P>&5E9#@R8C(Y+"`P>#%D,S@R9F4S+`H@("`@("`@(#!X,&,T
M9F(Y.6$L(#!X8F(S,C4W-S@L(#!X,V5C-F0Y-V(L(#!X-F4W-V$V83DL(#!X
M8V(V-3AB-6,L(#!X9#0U,C,P8S<L(#!X,F)D,30P.&(L(#!X-C!C,#-E8C<L
M"B`@("`@("`@,'AB.3`V.&0W."P@,'AA,S,W-31F-"P@,'AF-#,P8S@W9"P@
M,'AC.&$W,3,P,BP@,'AB.39D.&,S,BP@,'AE8F0T93=B92P@,'AB93AB.60R
M9"P@,'@W.3<Y9F(P-BP*("`@("`@("`P>&4W,C(U,S`X+"`P>#AB-S5C9C<W
M+"`P>#$Q968X9&$T+"`P>&4P.#-C.#4X+"`P>#AD-F(W.#9F+"`P>#5A-C,Q
M-V$V+"`P>&9A-6-F-V$P+"`P>#5D9&$P,#,S+`H@("`@("`@(#!X9C(X96)F
M8C`L(#!X9C5B.6,S,3`L(#!X83!E86,R.#`L(#!X,#AB.3<V-V$L(#!X83-D
M.60R8C`L(#!X-SED,S0R,3<L(#!X,#(Q83<Q.&0L(#!X.6%C-C,S-F$L"B`@
M("`@("`@,'@R-S$Q9F0V,"P@,'@T,S@P-3!E,RP@,'@P-CDY,#AA."P@,'@S
M9#=F961C-"P@,'@X,C9D,F)E9BP@,'@T965B.#0W-BP@,'@T.#AD8V8R-2P@
M,'@S-F,Y9#4V-BP*("`@("`@("`P>#(X93<T930Q+"`P>&,R-C$P86-A+"`P
M>#-D-#EA.6-F+"`P>&)A93-B.61F+"`P>&(V-68X9&4V+"`P>#DR865A9C8T
M+"`P>#-A8S=D-64V+"`P>#EE83@P-3`Y+`H@("`@("`@(#!X9C(R8C`Q-V0L
M(#!X830Q-S-F-S`L(#!X9&0Q93$V8S,L(#!X,35E,&0W9CDL(#!X-3!B,6(X
M.#<L(#!X,F(Y9C1F9#4L(#!X-C(U86)A.#(L(#!X-F$P,3<Y-C(L"B`@("`@
M("`@,'@R96,P,6(Y8RP@,'@Q-30X.&%A.2P@,'AD-S$V93<T,"P@,'@T,#`U
M-6$R8RP@,'@Y,V0R.6$R,BP@,'AE,S)D8F8Y82P@,'@P-3@W-#5B.2P@,'@S
M-#4S9&,Q92P*("`@("`@("`P>&0V.3DR.39E+"`P>#0Y-F-F9C9F+"`P>#%C
M.68T.3@V+"`P>&1F93)E9#`W+"`P>&(X-S(T,F0Q+"`P>#$Y9&4W96%E+"`P
M>#`U,V4U-C%A+"`P>#$U860V9CAC+`H@("`@("`@(#!X-C8V,C9C,6,L(#!X
M-S$U-&,R-&,L(#!X96$P.#)B,F$L(#!X.3-E8C(Y,SDL(#!X,3=D8V(P9C`L
M(#!X-3AD-&8R864L(#!X.65A,CDT9F(L(#!X-3)C9C4V-&,L"B`@("`@("`@
M,'@Y.#@S9F4V-BP@,'@R96,T,#4X,2P@,'@W-C,Y-3-C,RP@,'@P,60V-CDR
M92P@,'AD,V$P8S$P."P@,'AA,64W,38P92P@,'AE-&8R9&9A-BP@,'@V.3-E
M9#(X-2P*("`@("`@("`P>#<T.3`T-CDX+"`P>#1C,F(P961D+"`P>#1F-S4W
M-C4V+"`P>#5D,SDS,S<X+"`P>&$Q,S(R,S1F+"`P>#-D,S(Q8S5D+"`P>&,S
M9C5E,3DT+"`P>#1B,C8Y,S`Q+`H@("`@("`@(#!X8S<Y9C`R,F8L(#!X,V,Y
M.3=E-V4L(#!X-64T9CDU,#0L(#!X,V9F869B8F0L(#!X-S9F-V%D,&4L(#!X
M,CDV-CDS9C0L(#!X,V0Q9F-E-F8L(#!X8S8Q930U8F4L"B`@("`@("`@,'AD
M,V(U86(S-"P@,'AF-S)B9CEB-RP@,'@Q8C`T,S1C,"P@,'@T93<R8C4V-RP@
M,'@U-3DR83,S9"P@,'AB-3(R.3,P,2P@,'AC9F0R83@W9BP@,'@V,&%E8C<V
M-RP*("`@("`@("`P>#$X,30S.#9B+"`P>#,P8F-C,S-D+"`P>#,X83!C,#=D
M+"`P>&9D,38P-F8R+"`P>&,S-C,U,3EB+"`P>#4X.61D,SDP+"`P>#4T-SEF
M.&4V+"`P>#%C8CAD-C0W+`H@("`@("`@(#!X.3=F9#8Q83DL(#!X96$W-S4Y
M9C0L(#!X,F0U-S4S.60L(#!X-38Y834X8V8L(#!X93@T938S860L(#!X-#8R
M93%B-S@L(#!X-C4X,&8X-V4L(#!X9C,X,3<Y,30L"B`@("`@("`@,'@Y,61A
M-35F-"P@,'@T,&$R,S!F,RP@,'AD,3DX.&8S-2P@,'AB-F4S,3AD,BP@,'@S
M9F9A-3!B8RP@,'@S9#0P9C`R,2P@,'AC,V,P8F1A92P@,'@T.34X8S(T8RP*
M("`@("`@("`P>#4Q.&8S-F(R+"`P>#@T8C%D,S<P+"`P>#!F961C93@S+"`P
M>#@W.&1D861A+"`P>&8R83(W.6,W+"`P>#DT93`Q8F4X+"`P>#DP-S$V9C1B
M+"`P>#DU-&(X86$S*3L*"B`@("`O*BH*("`@("`J(%,@8F]X("AS."D*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D<S@@/2!A
M<G)A>2@*("`@("`@("`P>&4R,38S,#!D+"`P>&)B9&1F9F9C+"`P>&$W96)D
M86)D+"`P>#,U-C0X,#DU+"`P>#<W.#EF.&(W+"`P>&4V8S$Q,C%B+"`P>#!E
M,C0Q-C`P+"`P>#`U,F-E.&(U+`H@("`@("`@(#!X,3%A.6-F8C`L(#!X934Y
M-3)F,3$L(#!X96-E-SDY,&$L(#!X.3,X-F0Q-S0L(#!X,F$T,CDS,6,L(#!X
M-S9E,S@Q,3$L(#!X8C$R9&5F,V$L(#!X,S=D9&1D9F,L"B`@("`@("`@,'AD
M93EA9&5B,2P@,'@P83!C8S,R8RP@,'AB93$Y-S`R.2P@,'@X-&$P,#DT,"P@
M,'AB8C(T,V$P9BP@,'AB-&0Q,S=C9BP@,'AB-#1E-SEF,"P@,'@P-#EE961F
M9"P*("`@("`@("`P>#!B,35A,35D+"`P>#0X,&0S,38X+"`P>#AB8F)D935A
M+"`P>#8V.61E9#0R+"`P>&,W96-E.#,Q+"`P>#-F.&8Y-64W+"`P>#<R9&8Q
M.3%B+"`P>#<U.#`S,S!D+`H@("`@("`@(#!X.30P-S0R-3$L(#!X-6,W9&-D
M9F$L(#!X86)B939D-C,L(#!X86$T,#(Q-C0L(#!X8C,P,60T,&$L(#!X,#)E
M-V0Q8V$L(#!X-3,U-S%D864L(#!X-V$S,3@R83(L"B`@("`@("`@,'@Q,F$X
M9&1E8RP@,'AF9&%A,S,U9"P@,'@Q-S9F-#-E."P@,'@W,69B-#9D-"P@,'@S
M.#$R.3`R,BP@,'AC93DT.6%D-"P@,'AB.#0W-CEA9"P@,'@Y-C5B9#@V,BP*
M("`@("`@("`P>#@R9C-D,#4U+"`P>#8V9F(Y-S8W+"`P>#$U8C@P8C1E+"`P
M>#%D-6(T-V$P+"`P>#1C9F1E,#9F+"`P>&,R.&5C-&(X+"`P>#4W93@W,C9E
M+"`P>#8T-V$W.&9C+`H@("`@("`@(#!X.3DX-C5D-#0L(#!X-C`X8F0U.3,L
M(#!X-F,R,#!E,#,L(#!X,SED8S5F9C8L(#!X-60P8C`P83,L(#!X864V,V%F
M9C(L(#!X-V4X8F0V,S(L(#!X-S`Q,#AC,&,L"B`@("`@("`@,'AB8F0S-3`T
M.2P@,'@R.3DX9&8P-"P@,'@Y.#!C9C0R82P@,'@Y8C9D9C0Y,2P@,'@Y93=E
M9&0U,RP@,'@P-CDQ.#4T."P@,'@U.&-B-V4P-RP@,'@S8C<T968R92P*("`@
M("`@("`P>#4R,F9F9F(Q+"`P>&0R-#<P.&-C+"`P>#%C-V4R-V-D+"`P>&$T
M96(R,35B+"`P>#-C9C%D,F4R+"`P>#$Y8C0W83,X+"`P>#0R-&8W-C$X+"`P
M>#,U.#4V,#,Y+`H@("`@("`@(#!X.60Q-V1E93<L(#!X,C=E8C,U938L(#!X
M8SEA9F8V-V(L(#!X,S9B868U8C@L(#!X,#EC-#8W8V0L(#!X8S$X.3$P8C$L
M(#!X93$Q9&)F-V(L(#!X,#9C9#%A9C@L"B`@("`@("`@,'@W,3<P8S8P."P@
M,'@R9#5E,S,U-"P@,'AD-&1E-#DU82P@,'@V-&,V9#`P-BP@,'AB8V,P8S8R
M8RP@,'@S9&0P,&1B,RP@,'@W,#AF.&8S-"P@,'@W-V0U,6(T,BP*("`@("`@
M("`P>#(V-&8V,C!F+"`P>#(T8CAD,F)F+"`P>#$U8S%B-SEE+"`P>#0V834R
M-38T+"`P>&8X9#=E-31E+"`P>#-E,S<X,38P+"`P>#<X.35C9&$U+"`P>#@U
M.6,Q-6$U+`H@("`@("`@(#!X938T-3DW.#@L(#!X8S,W8F,W-68L(#!X9&(P
M-V)A,&,L(#!X,#8W-F$S86(L(#!X-V8R,CEB,64L(#!X,S$X-#)E-V(L(#!X
M,C0R-3EF9#<L(#!X9CAB968T-S(L"B`@("`@("`@,'@X,S5F9F-B."P@,'@V
M9&8T8S%F,BP@,'@Y-F8U8C$Y-2P@,'AF9#!A9C!F8RP@,'AB,&9E,3,T8RP@
M,'AE,C4P-F0S9"P@,'@T9CEB,3)E82P@,'AF,C$U9C(R-2P*("`@("`@("`P
M>&$R,C,W,S9F+"`P>#EF8C1C-#(X+"`P>#(U9#`T.3<Y+"`P>#,T8S<Q,V8X
M+"`P>&,T-C$X,3@W+"`P>&5A-V$V93DX+"`P>#=C9#$V969C+"`P>#$T,S8X
M-S9C+`H@("`@("`@(#!X9C$U-#0Q,#<L(#!X8F5D965E,30L(#!X-39E.6%F
M,C<L(#!X83`T86$T-#$L(#!X,V-F-V,X.3DL(#!X.3)E8V)A938L(#!X9&0V
M-S`Q-F0L(#!X,34Q-C@R96(L"B`@("`@("`@,'AA.#0R965D9BP@,'AF9&)A
M-C!B-"P@,'AF,3DP-V(W-2P@,'@R,&4S,#,P9BP@,'@R-&0X8S(Y92P@,'AE
M,3,Y-C<S8BP@,'AE9F$V,V9B."P@,'@W,3@W,S`U-"P*("`@("`@("`P>&(V
M9C)C9C-B+"`P>#EF,S(V-#0R+"`P>&-B,35A-&-C+"`P>&(P,6$T-3`T+"`P
M>&8Q930W9#AD+"`P>#@T-&$Q8F4U+"`P>&)A93=D9F1C+"`P>#0R8V)D83<P
M+`H@("`@("`@(#!X8V0W9&%E,&$L(#!X-3=E.#5B-V$L(#!X9#4S9C5A9C8L
M(#!X,C!C9C1D.&,L(#!X8V5A-&0T,C@L(#!X-SED,3,P830L(#!X,S0X-F5B
M9F(L(#!X,S-D,V-D9&,L"B`@("`@("`@,'@W-S@U,V(U,RP@,'@S-V5F9F-B
M-2P@,'AC-3`V.#<W."P@,'AE-3@P8C-E-BP@,'@T938X8CAF-"P@,'AC-6,X
M8C,W92P@,'@P9#@P.65A,BP@,'@S.3AF96(W8RP*("`@("`@("`P>#$S,F$T
M9CDT+"`P>#0S8C<Y-3!E+"`P>#)F964W9#%C+"`P>#(R,S8Q,V)D+"`P>&1D
M,#9C86$R+"`P>#,W9&8Y,S)B+"`P>&,T,C0X,C@Y+"`P>&%C9C-E8F,S+`H@
M("`@("`@(#!X-3<Q-68V8C<L(#!X968S-#<X9&0L(#!X9C(V-S8Q-F8L(#!X
M8S$T.&-B930L(#!X.3`U,C@Q-64L(#!X-64T,3!F86(L(#!X8C0X83(T-C4L
M(#!X,F5D83=F830L"B`@("`@("`@,'AE.#=B-#!E-"P@,'AE.3AE83`X-"P@
M,'@U.#@Y93EE,2P@,'AE9F0S.3!F8RP@,'AD9#`W9#,U8BP@,'AD8C0X-38Y
M-"P@,'@S.&0W935B,BP@,'@U-S<R,#$P,2P*("`@("`@("`P>#<S,&5D96)C
M+"`P>#5B-C0S,3$S+"`P>#DT.3$W931F+"`P>#4P,V,R9F)A+"`P>#8T-F8Q
M,C@R+"`P>#<U,C-D,C1A+"`P>&4P-S<Y-CDU+"`P>&8Y8S$W83AF+`H@("`@
M("`@(#!X-V$U8C(Q,C$L(#!X9#$X-V(X.38L(#!X,CDR-C-A-&0L(#!X8F$U
M,3!C9&8L(#!X.#%F-#=C.68L(#!X860Q,38S960L(#!X96$W8C4Y-C4L(#!X
M,6$P,#<R-F4L"B`@("`@("`@,'@Q,30P,S`Y,BP@,'@P,&1A-F0W-RP@,'@T
M83!C9&0V,2P@,'AA9#%F-#8P,RP@,'@V,#5B9&9B,"P@,'@Y965D8S,V-"P@
M,'@R,F5B939A."P@,'AC964W9#(X82P*("`@("`@("`P>&$P93<S-F$P+"`P
M>#4U-C1A-F(Y+"`P>#$P.#4S,C`Y+"`P>&,W96(X9C,W+"`P>#)D93<P-6-A
M+"`P>#@Y-3$U-S!F+"`P>&1F,#DX,C)B+"`P>&)D-CDQ839C+`H@("`@("`@
M(#!X86$Q,F4T9C(L(#!X.#<T-3%C,&8L(#!X93!F-F$R-V$L(#!X,V%D830X
M,3DL(#!X-&-F,3<V-&8L(#!X,&0W-S%C,F(L(#!X-C=C9&(Q-38L(#!X,S4P
M9#@S.#0L"B`@("`@("`@,'@U.3,X9F$P9BP@,'@T,C,Y.65F,RP@,'@S-CDY
M-V(P-RP@,'@P93@T,#DS9"P@,'@T86$Y,V4V,2P@,'@X,S8P9#@W8BP@,'@Q
M9F$Y.&(P8RP@,'@Q,30Y,S@R8RP*("`@("`@("`P>&4Y-S8R-6$U+"`P>#`V
M,31D,6(W+"`P>#!E,C4R-#1B+"`P>#!C-S8X,S0W+"`P>#4X.64X9#@R+"`P
M>#!D,C`U.60Q+"`P>&$T-C9B8C%E+"`P>&8X9&$P83@R+`H@("`@("`@(#!X
M,#1F,3DQ,S`L(#!X8F$V931E8S`L(#!X.3DR-C4Q-C0L(#!X,65E-S(S,&0L
M(#!X-3!B,F%D.#`L(#!X96%E938X,#$L(#!X.&1B,F$R.#,L(#!X96$X8F8U
M.64I.PH*("`@("\J*@H@("`@("H@36%S:VEN9R!+97ES"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]+;2`](&%R<F%Y*"D[
M"@H@("`@+RHJ"B`@("`@*B!2;W1A=&4@2V5Y<PH@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1?2W(@/2!A<G)A>2@I.PH*("`@
M("\J*@H@("`@("H@5&AE(&YU;6)E<B!O9B!R;W5N9',@=&\@9&\*("`@("`J
M"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?<F]U;F1S
M(#T@,38["@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&ME>2!T;R!B92!U<V5D
M(&9O<B!E;B]D96-R>7!T:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&ME>2`@5&AE(&ME>2!T;R!U<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-E=$ME>2@D:V5Y*0H@("`@>PH@("`@("`@(&EF("@A:7-?;G5L;"@D:V5Y
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W)O=6YD<R`]("AS=')L96XH)&ME
M>2D@/"`Q,2D@/R`Q,B`Z(#$V.PH@("`@("`@("`@("`D:V5Y(#T@)'1H:7,M
M/E]F;W)M871+97DH)&ME>2D["B`@("`@("`@("`@("1K97E38VAE9'5L92`]
M("1T:&ES+3Y?:V5Y4V-H961U;&4H)&ME>2D["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N('1H92!S:7IE(&]F('1H92!B;&]C:W,@
M=&AA="!T:&ES(&-I<&AE<B!N965D<RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&EN=&5G97(@(%1H92!N=6UB97(@;V8@8VAA<F%C=&5R<R!P97(@8FQO8VLN
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$)L;V-K4VEZ92@I"B`@("!["B`@
M("`@("`@<F5T=7)N(#@["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%;F-R>7!T
M(&$@8FQO8VL@;V8@9&%T82X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1B;&]C:R`@5&AE(&1A=&$@=&\@96YC<GEP="X*("`@("`J($!P87)A;2!S
M=')I;F<@)&ME>2`@("!4:&4@:V5Y('1O('5S92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(&5N8W)Y<'1E9"!O=71P=70N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&5N8W)Y<'1";&]C:R@D8FQO8VLL("1K97D@/2!N=6QL
M*0H@("`@>PH@("`@("`@(&EF("@A:7-?;G5L;"@D:V5Y*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W)O=6YD<R`]("AS=')L96XH)&ME>2D@/"`Q,2D@/R`Q
M,B`Z(#$V.PH@("`@("`@("`@("`D:V5Y(#T@)'1H:7,M/E]F;W)M871+97DH
M)&ME>2D["B`@("`@("`@("`@("1K97E38VAE9'5L92`]("1T:&ES+3Y?:V5Y
M4V-H961U;&4H)&ME>2D["B`@("`@("`@?0H*("`@("`@("`D3"`]("1T:&ES
M+3Y?9F]R;6%T1&%T82AS=6)S='(H)&)L;V-K+"`P+"`T*2D["B`@("`@("`@
M)%(@/2`D=&AI<RT^7V9O<FUA=$1A=&$H<W5B<W1R*"1B;&]C:RP@-"P@-"DI
M.PH*("`@("`@("`D3"!>/2`D=&AI<RT^9C$H)%(L("1T:&ES+3Y?2VU;,5TL
M("`D=&AI<RT^7TMR6S%=*3L*("`@("`@("`D4B!>/2`D=&AI<RT^9C(H)$PL
M("1T:&ES+3Y?2VU;,ETL("`D=&AI<RT^7TMR6S)=*3L*("`@("`@("`D3"!>
M/2`D=&AI<RT^9C,H)%(L("1T:&ES+3Y?2VU;,UTL("`D=&AI<RT^7TMR6S-=
M*3L*("`@("`@("`D4B!>/2`D=&AI<RT^9C$H)$PL("1T:&ES+3Y?2VU;-%TL
M("`D=&AI<RT^7TMR6S1=*3L*("`@("`@("`D3"!>/2`D=&AI<RT^9C(H)%(L
M("1T:&ES+3Y?2VU;-5TL("`D=&AI<RT^7TMR6S5=*3L*("`@("`@("`D4B!>
M/2`D=&AI<RT^9C,H)$PL("1T:&ES+3Y?2VU;-ETL("`D=&AI<RT^7TMR6S9=
M*3L*("`@("`@("`D3"!>/2`D=&AI<RT^9C$H)%(L("1T:&ES+3Y?2VU;-UTL
M("`D=&AI<RT^7TMR6S==*3L*("`@("`@("`D4B!>/2`D=&AI<RT^9C(H)$PL
M("1T:&ES+3Y?2VU;.%TL("`D=&AI<RT^7TMR6SA=*3L*("`@("`@("`D3"!>
M/2`D=&AI<RT^9C,H)%(L("1T:&ES+3Y?2VU;.5TL("`D=&AI<RT^7TMR6SE=
M*3L*("`@("`@("`D4B!>/2`D=&AI<RT^9C$H)$PL("1T:&ES+3Y?2VU;,3!=
M+"`D=&AI<RT^7TMR6S$P72D["B`@("`@("`@)$P@7CT@)'1H:7,M/F8R*"12
M+"`D=&AI<RT^7TMM6S$Q72P@)'1H:7,M/E]+<ELQ,5TI.PH@("`@("`@("12
M(%X]("1T:&ES+3YF,R@D3"P@)'1H:7,M/E]+;5LQ,ETL("1T:&ES+3Y?2W);
M,3)=*3L*("`@("`@("!I9B`H)'1H:7,M/E]R;W5N9',@/B`Q,BD@>PH@("`@
M("`@("`@("`D3"!>/2`D=&AI<RT^9C$H)%(L("1T:&ES+3Y?2VU;,3-=+"`D
M=&AI<RT^7TMR6S$S72D["B`@("`@("`@("`@("12(%X]("1T:&ES+3YF,B@D
M3"P@)'1H:7,M/E]+;5LQ-%TL("1T:&ES+3Y?2W);,31=*3L*("`@("`@("`@
M("`@)$P@7CT@)'1H:7,M/F8S*"12+"`D=&AI<RT^7TMM6S$U72P@)'1H:7,M
M/E]+<ELQ-5TI.PH@("`@("`@("`@("`D4B!>/2`D=&AI<RT^9C$H)$PL("1T
M:&ES+3Y?2VU;,39=+"`D=&AI<RT^7TMR6S$V72D["B`@("`@("`@?0H*("`@
M("`@("`D96YC<GEP=&5D(#T@<&%C:R@B3B(L("12*2`N('!A8VLH(DXB+"`D
M3"D["@H@("`@("`@(')E='5R;B`D96YC<GEP=&5D.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1&5C<GEP="!A(&)L;V-K(&]F(&1A=&$N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D8FQO8VL@(%1H92!D871A('1O(&1E8W)Y<'0N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1K97D@("`@5&AE(&ME>2!T;R!U<V4N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!D96-R>7!T960@
M;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96-R>7!T0FQO8VLH)&)L
M;V-K+"`D:V5Y(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES7VYU;&PH
M)&ME>2DI('L*("`@("`@("`@("`@)'1H:7,M/E]R;W5N9',@/2`H<W1R;&5N
M*"1K97DI(#P@,3$I(#\@,3(@.B`Q-CL*("`@("`@("`@("`@)&ME>2`]("1T
M:&ES+3Y?9F]R;6%T2V5Y*"1K97DI.PH@("`@("`@("`@("`D:V5Y4V-H961U
M;&4@/2`D=&AI<RT^7VME>5-C:&5D=6QE*"1K97DI.PH@("`@("`@('T*"B`@
M("`@("`@)%(@/2`D=&AI<RT^7V9O<FUA=$1A=&$H<W5B<W1R*"1B;&]C:RP@
M,"P@-"DI.PH@("`@("`@("1,(#T@)'1H:7,M/E]F;W)M871$871A*'-U8G-T
M<B@D8FQO8VLL(#0L(#0I*3L*"B`@("`@("`@:68@*"1T:&ES+3Y?<F]U;F1S
M(#X@,3(I('L*("`@("`@("`@("`@)%(@7CT@)'1H:7,M/F8Q*"1,+"`D=&AI
M<RT^7TMM6S$V72P@)'1H:7,M/E]+<ELQ-ETI.PH@("`@("`@("`@("`D3"!>
M/2`D=&AI<RT^9C,H)%(L("1T:&ES+3Y?2VU;,35=+"`D=&AI<RT^7TMR6S$U
M72D["B`@("`@("`@("`@("12(%X]("1T:&ES+3YF,B@D3"P@)'1H:7,M/E]+
M;5LQ-%TL("1T:&ES+3Y?2W);,31=*3L*("`@("`@("`@("`@)$P@7CT@)'1H
M:7,M/F8Q*"12+"`D=&AI<RT^7TMM6S$S72P@)'1H:7,M/E]+<ELQ,UTI.PH@
M("`@("`@('T*"B`@("`@("`@)%(@7CT@)'1H:7,M/F8S*"1,+"`D=&AI<RT^
M7TMM6S$R72P@)'1H:7,M/E]+<ELQ,ETI.PH@("`@("`@("1,(%X]("1T:&ES
M+3YF,B@D4BP@)'1H:7,M/E]+;5LQ,5TL("1T:&ES+3Y?2W);,3%=*3L*("`@
M("`@("`D4B!>/2`D=&AI<RT^9C$H)$PL("1T:&ES+3Y?2VU;,3!=+"`D=&AI
M<RT^7TMR6S$P72D["B`@("`@("`@)$P@7CT@)'1H:7,M/F8S*"12+"`D=&AI
M<RT^7TMM6SE=+"`@)'1H:7,M/E]+<ELY72D["B`@("`@("`@)%(@7CT@)'1H
M:7,M/F8R*"1,+"`D=&AI<RT^7TMM6SA=+"`@)'1H:7,M/E]+<ELX72D["B`@
M("`@("`@)$P@7CT@)'1H:7,M/F8Q*"12+"`D=&AI<RT^7TMM6S==+"`@)'1H
M:7,M/E]+<ELW72D["B`@("`@("`@)%(@7CT@)'1H:7,M/F8S*"1,+"`D=&AI
M<RT^7TMM6S9=+"`@)'1H:7,M/E]+<ELV72D["B`@("`@("`@)$P@7CT@)'1H
M:7,M/F8R*"12+"`D=&AI<RT^7TMM6S5=+"`@)'1H:7,M/E]+<ELU72D["B`@
M("`@("`@)%(@7CT@)'1H:7,M/F8Q*"1,+"`D=&AI<RT^7TMM6S1=+"`@)'1H
M:7,M/E]+<ELT72D["B`@("`@("`@)$P@7CT@)'1H:7,M/F8S*"12+"`D=&AI
M<RT^7TMM6S-=+"`@)'1H:7,M/E]+<ELS72D["B`@("`@("`@)%(@7CT@)'1H
M:7,M/F8R*"1,+"`D=&AI<RT^7TMM6S)=+"`@)'1H:7,M/E]+<ELR72D["B`@
M("`@("`@)$P@7CT@)'1H:7,M/F8Q*"12+"`D=&AI<RT^7TMM6S%=+"`@)'1H
M:7,M/E]+<ELQ72D["@H@("`@("`@("1D96-R>7!T960@/2!P86-K*").(BP@
M)$PI("X@<&%C:R@B3B(L("12*3L*"B`@("`@("`@<F5T=7)N("1D96-R>7!T
M960["B`@("!]"@H@("`@+RHJ"B`@("`@*B!F,2@I"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&8Q*"1D+"`D2VTL("1+<BD*("`@('L*("`@("`@("`D22`]("1+
M;2`K("1D.PH*("`@("`@("`O*B!.87-T>2!&:7@@87,*("`@("`@("`@*B`D
M22`\/"`D2W(@?"`D22`^/B`H,S(@+2`D2W(I"B`@("`@("`@("H@1&]E<VXG
M="!A;'=A>7,@9VEV92!T:&4@8V]R<F5C="!A;G-W97(*("`@("`@("`@*B\*
M("`@("`@("`D8FEN(#T@<W1R7W!A9"AD96-B:6XH)$DI+"`S,BP@)S`G+"!3
M5%)?4$%$7TQ%1E0I.PH@("`@("`@("1)(#T@8FEN9&5C*'-U8G-T<B@D8FEN
M+"`D2W(I("X@<W5B<W1R*"1B:6XL(#`L("1+<BDI.PH*("`@("`@("`D9B`]
M("1T:&ES+3YS,5LH)$D@/CX@,C0I("8@,'A&1ET@7B`D=&AI<RT^<S);*"1)
M(#X^(#$V*2`F(#!X1D9=.PH@("`@("`@("1F(#T@)&8@+2`D=&AI<RT^<S-;
M*"1)(#X^(#@I("8@,'A&1ET["B`@("`@("`@)&8@/2`D9B`K("1T:&ES+3YS
M-%LD22`F(#!X1D9=.PH@("`@("`@(')E='5R;B`D9CL*("`@('T*"B`@("`O
M*BH*("`@("`J(&8R*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9C(H)&0L("1+
M;2P@)$MR*0H@("`@>PH@("`@("`@("1)(#T@)$MM(%X@)&0["@H@("`@("`@
M("\J($YA<W1Y($9I>"!A<PH@("`@("`@("`J("1)(#P\("1+<B!\("1)(#X^
M("@S,B`M("1+<BD*("`@("`@("`@*B!$;V5S;B=T(&%L=V%Y<R!G:79E('1H
M92!C;W)R96-T(&%N<W=E<@H@("`@("`@("`J+PH@("`@("`@("1B:6X@/2!S
M=')?<&%D*&1E8V)I;B@D22DL(#,R+"`G,"<L(%-44E]0041?3$5&5"D["B`@
M("`@("`@)$D@/2!B:6YD96,H<W5B<W1R*"1B:6XL("1+<BD@+B!S=6)S='(H
M)&)I;BP@,"P@)$MR*2D["@H@("`@("`@("1F(#T@)'1H:7,M/G,Q6R@D22`^
M/B`R-"D@)B`P>$9&72`M("1T:&ES+3YS,ELH)$D@/CX@,38I("8@,'A&1ET[
M"B`@("`@("`@)&8@/2`D9B`K("1T:&ES+3YS,ULH)$D@/CX@."D@)B`P>$9&
M73L*("`@("`@("`D9B`]("1F(%X@)'1H:7,M/G,T6R1)("8@,'A&1ET["B`@
M("`@("`@<F5T=7)N("1F.PH@("`@?0H*("`@("\J*@H@("`@("H@9C,H*0H@
M("`@("HO"B`@("!F=6YC=&EO;B!F,R@D9"P@)$MM+"`D2W(I"B`@("!["B`@
M("`@("`@)$D@/2`P>$9&1D9&1D9&("8@*"1+;2`M("1D*3L*"B`@("`@("`@
M+RH@3F%S='D@1FEX(&%S"B`@("`@("`@("H@)$D@/#P@)$MR('P@)$D@/CX@
M*#,R("T@)$MR*0H@("`@("`@("`J($1O97-N)W0@86QW87ES(&=I=F4@=&AE
M(&-O<G)E8W0@86YS=V5R"B`@("`@("`@("HO"B`@("`@("`@)&)I;B`]('-T
M<E]P860H9&5C8FEN*"1)*2P@,S(L("<P)RP@4U127U!!1%],1494*3L*("`@
M("`@("`D22`](&)I;F1E8RAS=6)S='(H)&)I;BP@)$MR*2`N('-U8G-T<B@D
M8FEN+"`P+"`D2W(I*3L*"B`@("`@("`@)&8@/2`H)'1H:7,M/G,Q6R@D22`^
M/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS,ELH)$D@/CX@,38I("8@,'A&1ETI
M.PH@("`@("`@("1F(#T@)&8@7B`D=&AI<RT^<S-;*"1)(#X^(#@I("8@,'A&
M1ET["B`@("`@("`@)&8@/2`P>$9&1D9&1D9&("8@*"1F("T@)'1H:7,M/G,T
M6R1)("8@,'A&1ETI.PH@("`@("`@(')E='5R;B`D9CL*("`@('T*"B`@("`O
M*BH*("`@("`J($-O;G9E<G0@82!S=')I;F<@:6YT;R!A(&%R<F%Y(&]F('1H
M92!O<F1I;F%T97,@;V8@:71S(&-H87)A8W1E<G,N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D9&%T82`@1&%T82!T;R!C;VYV97)T+@H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@(%1H92!C;VYV97)T960@9&%T82X*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V9O<FUA=$1A=&$H)&1A=&$I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?8V]M8FEN930H=6YP86-K*"=#*B<L("1D
M871A*2P@,'@Q*3L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E<G1S(&$@
M=&5X="!K97D@:6YT;R!A;B!A<G)A>2!P861D960@=VET:"!<,"=S('1O(&$@
M;&5N9W1H(&]F(#$R.`H@("`@("H@8FET<RX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1K97D@(%1H92!K97D@=&\@9F]R;6%T+@H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@(%1H92!P861D960@:V5Y+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?9F]R;6%T2V5Y*"1K97DI"B`@("!["B`@("`@("`@)')E
M<R`](&%R<F%Y7W9A;'5E<RAU;G!A8VLH)T,J)RP@)&ME>2DI.PH@("`@("`@
M(&9O<B`H)&D@/2!C;W5N="@D<F5S*3L@)&D@/"`Q-CL@)&DK*RD@>PH@("`@
M("`@("`@("`D<F5S6R1I72`](#`["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B`D<F5S.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E('1H92!C;VUP
M;&5T92!K97D@<VAE9'5L92X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)&ME>2`@5&AE(&ME>2!T;R!U<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]K
M97E38VAE9'5L92@D:V5Y*0H@("`@>PH@("`@("`@("1X,'@Q>#)X,R`]("1T
M:&ES+3Y?8V]M8FEN930H)&ME>2P@,'@P*3L*("`@("`@("`D>#1X-7@V>#<@
M/2`D=&AI<RT^7V-O;6)I;F4T*"1K97DL(#!X-"D["B`@("`@("`@)'@X>#EX
M07A"(#T@)'1H:7,M/E]C;VUB:6YE-"@D:V5Y+"`P>#@I.PH@("`@("`@("1X
M0WA$>$5X1B`]("1T:&ES+3Y?8V]M8FEN930H)&ME>2P@,'A#*3L*"B`@("`@
M("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1X,'@Q>#)X,RD[("1X,"`]("1B6S!=
M.R`D>#$@/2`D8ELQ73L@)'@R(#T@)&);,ET[("1X,R`]("1B6S-=.PH@("`@
M("`@("1B(#T@)'1H:7,M/E]S<&QI="@D>#1X-7@V>#<I.R`D>#0@/2`D8ELP
M73L@)'@U(#T@)&);,5T[("1X-B`]("1B6S)=.R`D>#<@/2`D8ELS73L*("`@
M("`@("`D8B`]("1T:&ES+3Y?<W!L:70H)'@X>#EX07A"*3L@)'@X(#T@)&);
M,%T[("1X.2`]("1B6S%=.R`D>$$@/2`D8ELR73L@)'A"(#T@)&);,UT["B`@
M("`@("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1X0WA$>$5X1BD[("1X0R`]("1B
M6S!=.R`D>$0@/2`D8ELQ73L@)'A%(#T@)&);,ET[("1X1B`]("1B6S-=.PH*
M("`@("`@("`D>C!Z,7HR>C,@/2`D>#!X,7@R>#,@7B`D=&AI<RT^<S5;)'A$
M72!>("1T:&ES+3YS-ELD>$9=(%X@)'1H:7,M/G,W6R1X0UT@7B`D=&AI<RT^
M<SA;)'A%72!>("1T:&ES+3YS-ULD>#A=.PH@("`@("`@("1B(#T@)'1H:7,M
M/E]S<&QI="@D>C!Z,7HR>C,I.R`D>C`@/2`D8ELP73L@)'HQ(#T@)&);,5T[
M("1Z,B`]("1B6S)=.R`D>C,@/2`D8ELS73L*("`@("`@("`D>C1Z-7HV>C<@
M/2`D>#AX.7A!>$(@7B`D=&AI<RT^<S5;)'HP72!>("1T:&ES+3YS-ELD>C)=
M(%X@)'1H:7,M/G,W6R1Z,5T@7B`D=&AI<RT^<SA;)'HS72!>("1T:&ES+3YS
M.%LD>$%=.PH@("`@("`@("1B(#T@)'1H:7,M/E]S<&QI="@D>C1Z-7HV>C<I
M.R`D>C0@/2`D8ELP73L@)'HU(#T@)&);,5T[("1Z-B`]("1B6S)=.R`D>C<@
M/2`D8ELS73L*("`@("`@("`D>CAZ.7I!>D(@/2`D>$-X1'A%>$8@7B`D=&AI
M<RT^<S5;)'HW72!>("1T:&ES+3YS-ELD>C9=(%X@)'1H:7,M/G,W6R1Z-5T@
M7B`D=&AI<RT^<SA;)'HT72!>("1T:&ES+3YS-5LD>#E=.PH@("`@("`@("1B
M(#T@)'1H:7,M/E]S<&QI="@D>CAZ.7I!>D(I.R`D>C@@/2`D8ELP73L@)'HY
M(#T@)&);,5T[("1Z02`]("1B6S)=.R`D>D(@/2`D8ELS73L*("`@("`@("`D
M>D-Z1'I%>D8@/2`D>#1X-7@V>#<@7B`D=&AI<RT^<S5;)'I!72!>("1T:&ES
M+3YS-ELD>CE=(%X@)'1H:7,M/G,W6R1Z0ET@7B`D=&AI<RT^<SA;)'HX72!>
M("1T:&ES+3YS-ELD>$)=.PH@("`@("`@("1B(#T@)'1H:7,M/E]S<&QI="@D
M>D-Z1'I%>D8I.R`D>D,@/2`D8ELP73L@)'I$(#T@)&);,5T[("1Z12`]("1B
M6S)=.R`D>D8@/2`D8ELS73L*"B`@("`@("`@)'1H:7,M/E]+;5LQ72`]("1T
M:&ES+3YS-5LD>CA=(%X@)'1H:7,M/G,V6R1Z.5T@7B`D=&AI<RT^<S=;)'HW
M72!>("1T:&ES+3YS.%LD>C9=(%X@)'1H:7,M/G,U6R1Z,ET["B`@("`@("`@
M)'1H:7,M/E]+;5LR72`]("1T:&ES+3YS-5LD>D%=(%X@)'1H:7,M/G,V6R1Z
M0ET@7B`D=&AI<RT^<S=;)'HU72!>("1T:&ES+3YS.%LD>C1=(%X@)'1H:7,M
M/G,V6R1Z-ET["B`@("`@("`@)'1H:7,M/E]+;5LS72`]("1T:&ES+3YS-5LD
M>D-=(%X@)'1H:7,M/G,V6R1Z1%T@7B`D=&AI<RT^<S=;)'HS72!>("1T:&ES
M+3YS.%LD>C)=(%X@)'1H:7,M/G,W6R1Z.5T["B`@("`@("`@)'1H:7,M/E]+
M;5LT72`]("1T:&ES+3YS-5LD>D5=(%X@)'1H:7,M/G,V6R1Z1ET@7B`D=&AI
M<RT^<S=;)'HQ72!>("1T:&ES+3YS.%LD>C!=(%X@)'1H:7,M/G,X6R1Z0UT[
M"@H@("`@("`@("1X,'@Q>#)X,R`]("1Z.'HY>D%Z0B!>("1T:&ES+3YS-5LD
M>C5=(%X@)'1H:7,M/G,V6R1Z-UT@7B`D=&AI<RT^<S=;)'HT72!>("1T:&ES
M+3YS.%LD>C9=(%X@)'1H:7,M/G,W6R1Z,%T["B`@("`@("`@)&(@/2`D=&AI
M<RT^7W-P;&ET*"1X,'@Q>#)X,RD[("1X,"`]("1B6S!=.R`D>#$@/2`D8ELQ
M73L@)'@R(#T@)&);,ET[("1X,R`]("1B6S-=.PH@("`@("`@("1X-'@U>#9X
M-R`]("1Z,'HQ>C)Z,R!>("1T:&ES+3YS-5LD>#!=(%X@)'1H:7,M/G,V6R1X
M,ET@7B`D=&AI<RT^<S=;)'@Q72!>("1T:&ES+3YS.%LD>#-=(%X@)'1H:7,M
M/G,X6R1Z,ET["B`@("`@("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1X-'@U>#9X
M-RD[("1X-"`]("1B6S!=.R`D>#4@/2`D8ELQ73L@)'@V(#T@)&);,ET[("1X
M-R`]("1B6S-=.PH@("`@("`@("1X.'@Y>$%X0B`]("1Z-'HU>C9Z-R!>("1T
M:&ES+3YS-5LD>#==(%X@)'1H:7,M/G,V6R1X-ET@7B`D=&AI<RT^<S=;)'@U
M72!>("1T:&ES+3YS.%LD>#1=(%X@)'1H:7,M/G,U6R1Z,5T["B`@("`@("`@
M)&(@/2`D=&AI<RT^7W-P;&ET*"1X.'@Y>$%X0BD[("1X."`]("1B6S!=.R`D
M>#D@/2`D8ELQ73L@)'A!(#T@)&);,ET[("1X0B`]("1B6S-=.PH@("`@("`@
M("1X0WA$>$5X1B`]("1Z0WI$>D5Z1B!>("1T:&ES+3YS-5LD>$%=(%X@)'1H
M:7,M/G,V6R1X.5T@7B`D=&AI<RT^<S=;)'A"72!>("1T:&ES+3YS.%LD>#A=
M(%X@)'1H:7,M/G,V6R1Z,UT["B`@("`@("`@)&(@/2`D=&AI<RT^7W-P;&ET
M*"1X0WA$>$5X1BD[("1X0R`]("1B6S!=.R`D>$0@/2`D8ELQ73L@)'A%(#T@
M)&);,ET[("1X1B`]("1B6S-=.PH*("`@("`@("`D=&AI<RT^7TMM6S5=("`]
M("1T:&ES+3YS-5LD>#-=(%X@)'1H:7,M/G,V6R1X,ET@7B`D=&AI<RT^<S=;
M)'A#72!>("1T:&ES+3YS.%LD>$1=(%X@)'1H:7,M/G,U6R1X.%T["B`@("`@
M("`@)'1H:7,M/E]+;5LV72`@/2`D=&AI<RT^<S5;)'@Q72!>("1T:&ES+3YS
M-ELD>#!=(%X@)'1H:7,M/G,W6R1X15T@7B`D=&AI<RT^<SA;)'A&72!>("1T
M:&ES+3YS-ELD>$1=.PH@("`@("`@("1T:&ES+3Y?2VU;-UT@(#T@)'1H:7,M
M/G,U6R1X-UT@7B`D=&AI<RT^<S9;)'@V72!>("1T:&ES+3YS-ULD>#A=(%X@
M)'1H:7,M/G,X6R1X.5T@7B`D=&AI<RT^<S=;)'@S73L*("`@("`@("`D=&AI
M<RT^7TMM6SA=("`]("1T:&ES+3YS-5LD>#5=(%X@)'1H:7,M/G,V6R1X-%T@
M7B`D=&AI<RT^<S=;)'A!72!>("1T:&ES+3YS.%LD>$)=(%X@)'1H:7,M/G,X
M6R1X-UT["@H@("`@("`@("1Z,'HQ>C)Z,R`]("1X,'@Q>#)X,R!>("1T:&ES
M+3YS-5LD>$1=(%X@)'1H:7,M/G,V6R1X1ET@7B`D=&AI<RT^<S=;)'A#72!>
M("1T:&ES+3YS.%LD>$5=(%X@)'1H:7,M/G,W6R1X.%T["B`@("`@("`@)&(@
M/2`D=&AI<RT^7W-P;&ET*"1Z,'HQ>C)Z,RD[("1Z,"`]("1B6S!=.R`D>C$@
M/2`D8ELQ73L@)'HR(#T@)&);,ET[("1Z,R`]("1B6S-=.PH@("`@("`@("1Z
M-'HU>C9Z-R`]("1X.'@Y>$%X0B!>("1T:&ES+3YS-5LD>C!=(%X@)'1H:7,M
M/G,V6R1Z,ET@7B`D=&AI<RT^<S=;)'HQ72!>("1T:&ES+3YS.%LD>C-=(%X@
M)'1H:7,M/G,X6R1X05T["B`@("`@("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1Z
M-'HU>C9Z-RD[("1Z-"`]("1B6S!=.R`D>C4@/2`D8ELQ73L@)'HV(#T@)&);
M,ET[("1Z-R`]("1B6S-=.PH@("`@("`@("1Z.'HY>D%Z0B`]("1X0WA$>$5X
M1B!>("1T:&ES+3YS-5LD>C==(%X@)'1H:7,M/G,V6R1Z-ET@7B`D=&AI<RT^
M<S=;)'HU72!>("1T:&ES+3YS.%LD>C1=(%X@)'1H:7,M/G,U6R1X.5T["B`@
M("`@("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1Z.'HY>D%Z0BD[("1Z."`]("1B
M6S!=.R`D>CD@/2`D8ELQ73L@)'I!(#T@)&);,ET[("1Z0B`]("1B6S-=.PH@
M("`@("`@("1Z0WI$>D5Z1B`]("1X-'@U>#9X-R!>("1T:&ES+3YS-5LD>D%=
M(%X@)'1H:7,M/G,V6R1Z.5T@7B`D=&AI<RT^<S=;)'I"72!>("1T:&ES+3YS
M.%LD>CA=(%X@)'1H:7,M/G,V6R1X0ET["B`@("`@("`@)&(@/2`D=&AI<RT^
M7W-P;&ET*"1Z0WI$>D5Z1BD[("1Z0R`]("1B6S!=.R`D>D0@/2`D8ELQ73L@
M)'I%(#T@)&);,ET[("1Z1B`]("1B6S-=.PH*("`@("`@("`D=&AI<RT^7TMM
M6SE=("`]("1T:&ES+3YS-5LD>C-=(%X@)'1H:7,M/G,V6R1Z,ET@7B`D=&AI
M<RT^<S=;)'I#72!>("1T:&ES+3YS.%LD>D1=(%X@)'1H:7,M/G,U6R1Z.5T[
M"B`@("`@("`@)'1H:7,M/E]+;5LQ,%T@/2`D=&AI<RT^<S5;)'HQ72!>("1T
M:&ES+3YS-ELD>C!=(%X@)'1H:7,M/G,W6R1Z15T@7B`D=&AI<RT^<SA;)'I&
M72!>("1T:&ES+3YS-ELD>D-=.PH@("`@("`@("1T:&ES+3Y?2VU;,3%=(#T@
M)'1H:7,M/G,U6R1Z-UT@7B`D=&AI<RT^<S9;)'HV72!>("1T:&ES+3YS-ULD
M>CA=(%X@)'1H:7,M/G,X6R1Z.5T@7B`D=&AI<RT^<S=;)'HR73L*("`@("`@
M("`D=&AI<RT^7TMM6S$R72`]("1T:&ES+3YS-5LD>C5=(%X@)'1H:7,M/G,V
M6R1Z-%T@7B`D=&AI<RT^<S=;)'I!72!>("1T:&ES+3YS.%LD>D)=(%X@)'1H
M:7,M/G,X6R1Z-ET["@H@("`@("`@("1X,'@Q>#)X,R`]("1Z.'HY>D%Z0B!>
M("1T:&ES+3YS-5LD>C5=(%X@)'1H:7,M/G,V6R1Z-UT@7B`D=&AI<RT^<S=;
M)'HT72!>("1T:&ES+3YS.%LD>C9=(%X@)'1H:7,M/G,W6R1Z,%T["B`@("`@
M("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1X,'@Q>#)X,RD[("1X,"`]("1B6S!=
M.R`D>#$@/2`D8ELQ73L@)'@R(#T@)&);,ET[("1X,R`]("1B6S-=.PH@("`@
M("`@("1X-'@U>#9X-R`]("1Z,'HQ>C)Z,R!>("1T:&ES+3YS-5LD>#!=(%X@
M)'1H:7,M/G,V6R1X,ET@7B`D=&AI<RT^<S=;)'@Q72!>("1T:&ES+3YS.%LD
M>#-=(%X@)'1H:7,M/G,X6R1Z,ET["B`@("`@("`@)&(@/2`D=&AI<RT^7W-P
M;&ET*"1X-'@U>#9X-RD[("1X-"`]("1B6S!=.R`D>#4@/2`D8ELQ73L@)'@V
M(#T@)&);,ET[("1X-R`]("1B6S-=.PH@("`@("`@("1X.'@Y>$%X0B`]("1Z
M-'HU>C9Z-R!>("1T:&ES+3YS-5LD>#==(%X@)'1H:7,M/G,V6R1X-ET@7B`D
M=&AI<RT^<S=;)'@U72!>("1T:&ES+3YS.%LD>#1=(%X@)'1H:7,M/G,U6R1Z
M,5T["B`@("`@("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1X.'@Y>$%X0BD[("1X
M."`]("1B6S!=.R`D>#D@/2`D8ELQ73L@)'A!(#T@)&);,ET[("1X0B`]("1B
M6S-=.PH@("`@("`@("1X0WA$>$5X1B`]("1Z0WI$>D5Z1B!>("1T:&ES+3YS
M-5LD>$%=(%X@)'1H:7,M/G,V6R1X.5T@7B`D=&AI<RT^<S=;)'A"72!>("1T
M:&ES+3YS.%LD>#A=(%X@)'1H:7,M/G,V6R1Z,UT["B`@("`@("`@)&(@/2`D
M=&AI<RT^7W-P;&ET*"1X0WA$>$5X1BD[("1X0R`]("1B6S!=.R`D>$0@/2`D
M8ELQ73L@)'A%(#T@)&);,ET[("1X1B`]("1B6S-=.PH*("`@("`@("`D=&AI
M<RT^7TMM6S$S72`]("1T:&ES+3YS-5LD>#A=(%X@)'1H:7,M/G,V6R1X.5T@
M7B`D=&AI<RT^<S=;)'@W72!>("1T:&ES+3YS.%LD>#9=(%X@)'1H:7,M/G,U
M6R1X,UT["B`@("`@("`@)'1H:7,M/E]+;5LQ-%T@/2`D=&AI<RT^<S5;)'A!
M72!>("1T:&ES+3YS-ELD>$)=(%X@)'1H:7,M/G,W6R1X-5T@7B`D=&AI<RT^
M<SA;)'@T72!>("1T:&ES+3YS-ELD>#==.PH@("`@("`@("1T:&ES+3Y?2VU;
M,35=(#T@)'1H:7,M/G,U6R1X0UT@7B`D=&AI<RT^<S9;)'A$72!>("1T:&ES
M+3YS-ULD>#-=(%X@)'1H:7,M/G,X6R1X,ET@7B`D=&AI<RT^<S=;)'@X73L*
M("`@("`@("`D=&AI<RT^7TMM6S$V72`]("1T:&ES+3YS-5LD>$5=(%X@)'1H
M:7,M/G,V6R1X1ET@7B`D=&AI<RT^<S=;)'@Q72!>("1T:&ES+3YS.%LD>#!=
M(%X@)'1H:7,M/G,X6R1X1%T["@H@("`@("`@("1Z,'HQ>C)Z,R`]("1X,'@Q
M>#)X,R!>("1T:&ES+3YS-5LD>$1=(%X@)'1H:7,M/G,V6R1X1ET@7B`D=&AI
M<RT^<S=;)'A#72!>("1T:&ES+3YS.%LD>$5=(%X@)'1H:7,M/G,W6R1X.%T[
M"B`@("`@("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1Z,'HQ>C)Z,RD[("1Z,"`]
M("1B6S!=.R`D>C$@/2`D8ELQ73L@)'HR(#T@)&);,ET[("1Z,R`]("1B6S-=
M.PH@("`@("`@("1Z-'HU>C9Z-R`]("1X.'@Y>$%X0B!>("1T:&ES+3YS-5LD
M>C!=(%X@)'1H:7,M/G,V6R1Z,ET@7B`D=&AI<RT^<S=;)'HQ72!>("1T:&ES
M+3YS.%LD>C-=(%X@)'1H:7,M/G,X6R1X05T["B`@("`@("`@)&(@/2`D=&AI
M<RT^7W-P;&ET*"1Z-'HU>C9Z-RD[("1Z-"`]("1B6S!=.R`D>C4@/2`D8ELQ
M73L@)'HV(#T@)&);,ET[("1Z-R`]("1B6S-=.PH@("`@("`@("1Z.'HY>D%Z
M0B`]("1X0WA$>$5X1B!>("1T:&ES+3YS-5LD>C==(%X@)'1H:7,M/G,V6R1Z
M-ET@7B`D=&AI<RT^<S=;)'HU72!>("1T:&ES+3YS.%LD>C1=(%X@)'1H:7,M
M/G,U6R1X.5T["B`@("`@("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1Z.'HY>D%Z
M0BD[("1Z."`]("1B6S!=.R`D>CD@/2`D8ELQ73L@)'I!(#T@)&);,ET[("1Z
M0B`]("1B6S-=.PH@("`@("`@("1Z0WI$>D5Z1B`]("1X-'@U>#9X-R!>("1T
M:&ES+3YS-5LD>D%=(%X@)'1H:7,M/G,V6R1Z.5T@7B`D=&AI<RT^<S=;)'I"
M72!>("1T:&ES+3YS.%LD>CA=(%X@)'1H:7,M/G,V6R1X0ET["B`@("`@("`@
M)&(@/2`D=&AI<RT^7W-P;&ET*"1Z0WI$>D5Z1BD[("1Z0R`]("1B6S!=.R`D
M>D0@/2`D8ELQ73L@)'I%(#T@)&);,ET[("1Z1B`]("1B6S-=.PH*("`@("`@
M("`D=&AI<RT^7TMR6S%=("`](#!X,48@)B`H)'1H:7,M/G,U6R1Z.%T@7B`D
M=&AI<RT^<S9;)'HY72!>("1T:&ES+3YS-ULD>C==(%X@)'1H:7,M/G,X6R1Z
M-ET@7B`D=&AI<RT^<S5;)'HR72D["B`@("`@("`@)'1H:7,M/E]+<ELR72`@
M/2`P>#%&("8@*"1T:&ES+3YS-5LD>D%=(%X@)'1H:7,M/G,V6R1Z0ET@7B`D
M=&AI<RT^<S=;)'HU72!>("1T:&ES+3YS.%LD>C1=(%X@)'1H:7,M/G,V6R1Z
M-ETI.PH@("`@("`@("1T:&ES+3Y?2W);,UT@(#T@,'@Q1B`F("@D=&AI<RT^
M<S5;)'I#72!>("1T:&ES+3YS-ELD>D1=(%X@)'1H:7,M/G,W6R1Z,UT@7B`D
M=&AI<RT^<SA;)'HR72!>("1T:&ES+3YS-ULD>CE=*3L*("`@("`@("`D=&AI
M<RT^7TMR6S1=("`](#!X,48@)B`H)'1H:7,M/G,U6R1Z15T@7B`D=&AI<RT^
M<S9;)'I&72!>("1T:&ES+3YS-ULD>C%=(%X@)'1H:7,M/G,X6R1Z,%T@7B`D
M=&AI<RT^<SA;)'I#72D["@H@("`@("`@("1X,'@Q>#)X,R`]("1Z.'HY>D%Z
M0B!>("1T:&ES+3YS-5LD>C5=(%X@)'1H:7,M/G,V6R1Z-UT@7B`D=&AI<RT^
M<S=;)'HT72!>("1T:&ES+3YS.%LD>C9=(%X@)'1H:7,M/G,W6R1Z,%T["B`@
M("`@("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1X,'@Q>#)X,RD[("1X,"`]("1B
M6S!=.R`D>#$@/2`D8ELQ73L@)'@R(#T@)&);,ET[("1X,R`]("1B6S-=.PH@
M("`@("`@("1X-'@U>#9X-R`]("1Z,'HQ>C)Z,R!>("1T:&ES+3YS-5LD>#!=
M(%X@)'1H:7,M/G,V6R1X,ET@7B`D=&AI<RT^<S=;)'@Q72!>("1T:&ES+3YS
M.%LD>#-=(%X@)'1H:7,M/G,X6R1Z,ET["B`@("`@("`@)&(@/2`D=&AI<RT^
M7W-P;&ET*"1X-'@U>#9X-RD[("1X-"`]("1B6S!=.R`D>#4@/2`D8ELQ73L@
M)'@V(#T@)&);,ET[("1X-R`]("1B6S-=.PH@("`@("`@("1X.'@Y>$%X0B`]
M("1Z-'HU>C9Z-R!>("1T:&ES+3YS-5LD>#==(%X@)'1H:7,M/G,V6R1X-ET@
M7B`D=&AI<RT^<S=;)'@U72!>("1T:&ES+3YS.%LD>#1=(%X@)'1H:7,M/G,U
M6R1Z,5T["B`@("`@("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1X.'@Y>$%X0BD[
M("1X."`]("1B6S!=.R`D>#D@/2`D8ELQ73L@)'A!(#T@)&);,ET[("1X0B`]
M("1B6S-=.PH@("`@("`@("1X0WA$>$5X1B`]("1Z0WI$>D5Z1B!>("1T:&ES
M+3YS-5LD>$%=(%X@)'1H:7,M/G,V6R1X.5T@7B`D=&AI<RT^<S=;)'A"72!>
M("1T:&ES+3YS.%LD>#A=(%X@)'1H:7,M/G,V6R1Z,UT["B`@("`@("`@)&(@
M/2`D=&AI<RT^7W-P;&ET*"1X0WA$>$5X1BD[("1X0R`]("1B6S!=.R`D>$0@
M/2`D8ELQ73L@)'A%(#T@)&);,ET[("1X1B`]("1B6S-=.PH*("`@("`@("`D
M=&AI<RT^7TMR6S5=("`](#!X,48@)B`H)'1H:7,M/G,U6R1X,UT@7B`D=&AI
M<RT^<S9;)'@R72!>("1T:&ES+3YS-ULD>$-=(%X@)'1H:7,M/G,X6R1X1%T@
M7B`D=&AI<RT^<S5;)'@X72D["B`@("`@("`@)'1H:7,M/E]+<ELV72`@/2`P
M>#%&("8@*"1T:&ES+3YS-5LD>#%=(%X@)'1H:7,M/G,V6R1X,%T@7B`D=&AI
M<RT^<S=;)'A%72!>("1T:&ES+3YS.%LD>$9=(%X@)'1H:7,M/G,V6R1X1%TI
M.PH@("`@("`@("1T:&ES+3Y?2W);-UT@(#T@,'@Q1B`F("@D=&AI<RT^<S5;
M)'@W72!>("1T:&ES+3YS-ELD>#9=(%X@)'1H:7,M/G,W6R1X.%T@7B`D=&AI
M<RT^<SA;)'@Y72!>("1T:&ES+3YS-ULD>#-=*3L*("`@("`@("`D=&AI<RT^
M7TMR6SA=("`](#!X,48@)B`H)'1H:7,M/G,U6R1X-5T@7B`D=&AI<RT^<S9;
M)'@T72!>("1T:&ES+3YS-ULD>$%=(%X@)'1H:7,M/G,X6R1X0ET@7B`D=&AI
M<RT^<SA;)'@W72D["@H@("`@("`@("1Z,'HQ>C)Z,R`]("1X,'@Q>#)X,R!>
M("1T:&ES+3YS-5LD>$1=(%X@)'1H:7,M/G,V6R1X1ET@7B`D=&AI<RT^<S=;
M)'A#72!>("1T:&ES+3YS.%LD>$5=(%X@)'1H:7,M/G,W6R1X.%T["B`@("`@
M("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1Z,'HQ>C)Z,RD[("1Z,"`]("1B6S!=
M.R`D>C$@/2`D8ELQ73L@)'HR(#T@)&);,ET[("1Z,R`]("1B6S-=.PH@("`@
M("`@("1Z-'HU>C9Z-R`]("1X.'@Y>$%X0B!>("1T:&ES+3YS-5LD>C!=(%X@
M)'1H:7,M/G,V6R1Z,ET@7B`D=&AI<RT^<S=;)'HQ72!>("1T:&ES+3YS.%LD
M>C-=(%X@)'1H:7,M/G,X6R1X05T["B`@("`@("`@)&(@/2`D=&AI<RT^7W-P
M;&ET*"1Z-'HU>C9Z-RD[("1Z-"`]("1B6S!=.R`D>C4@/2`D8ELQ73L@)'HV
M(#T@)&);,ET[("1Z-R`]("1B6S-=.PH@("`@("`@("1Z.'HY>D%Z0B`]("1X
M0WA$>$5X1B!>("1T:&ES+3YS-5LD>C==(%X@)'1H:7,M/G,V6R1Z-ET@7B`D
M=&AI<RT^<S=;)'HU72!>("1T:&ES+3YS.%LD>C1=(%X@)'1H:7,M/G,U6R1X
M.5T["B`@("`@("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1Z.'HY>D%Z0BD[("1Z
M."`]("1B6S!=.R`D>CD@/2`D8ELQ73L@)'I!(#T@)&);,ET[("1Z0B`]("1B
M6S-=.PH@("`@("`@("1Z0WI$>D5Z1B`]("1X-'@U>#9X-R!>("1T:&ES+3YS
M-5LD>D%=(%X@)'1H:7,M/G,V6R1Z.5T@7B`D=&AI<RT^<S=;)'I"72!>("1T
M:&ES+3YS.%LD>CA=(%X@)'1H:7,M/G,V6R1X0ET["B`@("`@("`@)&(@/2`D
M=&AI<RT^7W-P;&ET*"1Z0WI$>D5Z1BD[("1Z0R`]("1B6S!=.R`D>D0@/2`D
M8ELQ73L@)'I%(#T@)&);,ET[("1Z1B`]("1B6S-=.PH*("`@("`@("`D=&AI
M<RT^7TMR6SE=("`](#!X,48@)B`H)'1H:7,M/G,U6R1Z,UT@7B`D=&AI<RT^
M<S9;)'HR72!>("1T:&ES+3YS-ULD>D-=(%X@)'1H:7,M/G,X6R1Z1%T@7B`D
M=&AI<RT^<S5;)'HY72D["B`@("`@("`@)'1H:7,M/E]+<ELQ,%T@/2`P>#%&
M("8@*"1T:&ES+3YS-5LD>C%=(%X@)'1H:7,M/G,V6R1Z,%T@7B`D=&AI<RT^
M<S=;)'I%72!>("1T:&ES+3YS.%LD>D9=(%X@)'1H:7,M/G,V6R1Z0UTI.PH@
M("`@("`@("1T:&ES+3Y?2W);,3%=(#T@,'@Q1B`F("@D=&AI<RT^<S5;)'HW
M72!>("1T:&ES+3YS-ELD>C9=(%X@)'1H:7,M/G,W6R1Z.%T@7B`D=&AI<RT^
M<SA;)'HY72!>("1T:&ES+3YS-ULD>C)=*3L*("`@("`@("`D=&AI<RT^7TMR
M6S$R72`](#!X,48@)B`H)'1H:7,M/G,U6R1Z-5T@7B`D=&AI<RT^<S9;)'HT
M72!>("1T:&ES+3YS-ULD>D%=(%X@)'1H:7,M/G,X6R1Z0ET@7B`D=&AI<RT^
M<SA;)'HV72D["@H@("`@("`@("1X,'@Q>#)X,R`]("1Z.'HY>D%Z0B!>("1T
M:&ES+3YS-5LD>C5=(%X@)'1H:7,M/G,V6R1Z-UT@7B`D=&AI<RT^<S=;)'HT
M72!>("1T:&ES+3YS.%LD>C9=(%X@)'1H:7,M/G,W6R1Z,%T["B`@("`@("`@
M)&(@/2`D=&AI<RT^7W-P;&ET*"1X,'@Q>#)X,RD[("1X,"`]("1B6S!=.R`D
M>#$@/2`D8ELQ73L@)'@R(#T@)&);,ET[("1X,R`]("1B6S-=.PH@("`@("`@
M("1X-'@U>#9X-R`]("1Z,'HQ>C)Z,R!>("1T:&ES+3YS-5LD>#!=(%X@)'1H
M:7,M/G,V6R1X,ET@7B`D=&AI<RT^<S=;)'@Q72!>("1T:&ES+3YS.%LD>#-=
M(%X@)'1H:7,M/G,X6R1Z,ET["B`@("`@("`@)&(@/2`D=&AI<RT^7W-P;&ET
M*"1X-'@U>#9X-RD[("1X-"`]("1B6S!=.R`D>#4@/2`D8ELQ73L@)'@V(#T@
M)&);,ET[("1X-R`]("1B6S-=.PH@("`@("`@("1X.'@Y>$%X0B`]("1Z-'HU
M>C9Z-R!>("1T:&ES+3YS-5LD>#==(%X@)'1H:7,M/G,V6R1X-ET@7B`D=&AI
M<RT^<S=;)'@U72!>("1T:&ES+3YS.%LD>#1=(%X@)'1H:7,M/G,U6R1Z,5T[
M"B`@("`@("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1X.'@Y>$%X0BD[("1X."`]
M("1B6S!=.R`D>#D@/2`D8ELQ73L@)'A!(#T@)&);,ET[("1X0B`]("1B6S-=
M.PH@("`@("`@("1X0WA$>$5X1B`]("1Z0WI$>D5Z1B!>("1T:&ES+3YS-5LD
M>$%=(%X@)'1H:7,M/G,V6R1X.5T@7B`D=&AI<RT^<S=;)'A"72!>("1T:&ES
M+3YS.%LD>#A=(%X@)'1H:7,M/G,V6R1Z,UT["B`@("`@("`@)&(@/2`D=&AI
M<RT^7W-P;&ET*"1X0WA$>$5X1BD[("1X0R`]("1B6S!=.R`D>$0@/2`D8ELQ
M73L@)'A%(#T@)&);,ET[("1X1B`]("1B6S-=.PH*("`@("`@("`D=&AI<RT^
M7TMR6S$S72`](#!X,48@)B`H)'1H:7,M/G,U6R1X.%T@7B`D=&AI<RT^<S9;
M)'@Y72!>("1T:&ES+3YS-ULD>#==(%X@)'1H:7,M/G,X6R1X-ET@7B`D=&AI
M<RT^<S5;)'@S72D["B`@("`@("`@)'1H:7,M/E]+<ELQ-%T@/2`P>#%&("8@
M*"1T:&ES+3YS-5LD>$%=(%X@)'1H:7,M/G,V6R1X0ET@7B`D=&AI<RT^<S=;
M)'@U72!>("1T:&ES+3YS.%LD>#1=(%X@)'1H:7,M/G,V6R1X-UTI.PH@("`@
M("`@("1T:&ES+3Y?2W);,35=(#T@,'@Q1B`F("@D=&AI<RT^<S5;)'A#72!>
M("1T:&ES+3YS-ELD>$1=(%X@)'1H:7,M/G,W6R1X,UT@7B`D=&AI<RT^<SA;
M)'@R72!>("1T:&ES+3YS-ULD>#A=*3L*("`@("`@("`D=&AI<RT^7TMR6S$V
M72`](#!X,48@)B`H)'1H:7,M/G,U6R1X15T@7B`D=&AI<RT^<S9;)'A&72!>
M("1T:&ES+3YS-ULD>#%=(%X@)'1H:7,M/G,X6R1X,%T@7B`D=&AI<RT^<SA;
M)'A$72D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!5;G!A8VL@=&AE(#,R(&)I
M="!V86QU92!I;G1O(&%N(&%R<F%Y(&]F(&9O=7(@."!B:70@=F%L=65S+@H@
M("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1X("`S,B!B:70@=F%L=64N
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@1F]U<B`X(&)I="!V86QU
M97,@35,@=&\@3%,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S<&QI="@D>"D*
M("`@('L*("`@("`@("!R971U<FX@87)R87DH*"1X(#X^(#(T*2`F(#!X1D8L
M("@D>"`^/B`Q-BD@)B`P>$9&+"`H)'@@/CX@."D@)B`P>$9&+"`D>"`F(#!X
M1D8I.PH@("`@?0H*("`@("\J*@H@("`@("H@4&%C:R!F;W5R(#@@8FET('9A
M;'5E<R!I;G1O(&]N92`S,B!B:70@=F%L=64N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1K97D@("`@("!!<G)A>2!O9B`X(&)I="!V86QU97,N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D<W1A<G0@(%-T87)T('!O<VET:6]N(&EN
M(&%R<F%Y('1O(&=E="`T('9A;'5E<R!F<F]M+@H@("`@("H*("`@("`J($!R
M971U<FX@:6YT96=E<B`@,S(@8FET('9A;'5E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?8V]M8FEN930H)&ME>2P@)'-T87)T(#T@,"D*("`@('L*("`@("`@
M("`D<F5S("`](#`["B`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)'-T
M87)T+"`D:V5Y*2D@>PH@("`@("`@("`@("`D<F5S('P]("@D:V5Y6R1S=&%R
M=%TI(#P\(#(T.PH@("`@("`@('T*("`@("`@("!I9B`H87)R87E?:V5Y7V5X
M:7-T<R@D<W1A<G0@*R`Q+"`D:V5Y*2D@>PH@("`@("`@("`@("`D<F5S('P]
M("@D:V5Y6R1S=&%R="`K(#%=*2`\/"`Q-CL*("`@("`@("!]"B`@("`@("`@
M:68@*&%R<F%Y7VME>5]E>&ES=',H)'-T87)T("L@,BP@)&ME>2DI('L*("`@
M("`@("`@("`@)')E<R!\/2`H)&ME>5LD<W1A<G0@*R`R72D@/#P@.#L*("`@
M("`@("!]"B`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)'-T87)T("L@
M,RP@)&ME>2DI('L*("`@("`@("`@("`@)')E<R!\/2`H)&ME>5LD<W1A<G0@
M*R`S72D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5S.PH@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O0VEP:&5R+W)C,BYP:'``````````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3<P-S<@,3`U,34T,S,W,S<@,#(Q
M-S<W`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B!4:&4@0VEP:&5R7W)C,CHZ(&-L87-S(&EM<&QE;65N
M=',@=&AE($-I<&AE<B!I;G1E<F9A8V4@96YC<GEP=&EO;B!D871A"B`J('5S
M:6YG('1H92!20S(@86QG;W)I=&AM(&%S(&1E<V-R:6)E9"!I;B!21D,R,C8X
M+@H@*@H@*B!"87-E9"!O;B!T:&4@;F]T97,@8GD@4&5T97(@1W5T;6%N;B`\
M<&=U=#`Q0&-S+F%U8VML86YD+F%C+FYZ/@H@*B!H='1P.B\O=W=W+FUI<G)O
M<G,N=VER971A<'!E9"YN970O<V5C=7)I='DO8W)Y<'1O9W)A<&AY+PH@*B`@
M(&%L9V]R:71H;7,O<F,R+V-O;6UE;G1S+V=U=&UA;BTY-C`R,3$*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO0VEP:&5R+T-I<&AE<B]R8S(N<&AP+'8@,2XY
M+C$R+C<@,C`P-B\P,2\P,2`R,3HR.#HQ,"!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#(M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH
M86QL+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EK92!#
M;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@
M2&]R9&4@,BXR"B`J($!P86-K86=E($AO<F1E7T-I<&AE<@H@*B\*8VQA<W,@
M2&]R9&5?0VEP:&5R7W)C,B!E>'1E;F1S($AO<F1E7T-I<&AE<B!["@H@("`@
M+RHJ"B`@("`@*B!097)M=71A=&EO;G,@87)R87D*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!E<FT@/2!A<G)A>2@*("`@
M("`@("`P>$0Y+"`P>#<X+"`P>$8Y+"`P>$,T+"`P>#$Y+"`P>$1$+"`P>$(U
M+"`P>$5$+`H@("`@("`@(#!X,C@L(#!X13DL(#!X1D0L(#!X-SDL(#!X-$$L
M(#!X03`L(#!X1#@L(#!X.40L"B`@("`@("`@,'A#-BP@,'@W12P@,'@S-RP@
M,'@X,RP@,'@R0BP@,'@W-BP@,'@U,RP@,'@X12P*("`@("`@("`P>#8R+"`P
M>#1#+"`P>#8T+"`P>#@X+"`P>#0T+"`P>#A"+"`P>$9"+"`P>$$R+`H@("`@
M("`@(#!X,3<L(#!X.4$L(#!X-3DL(#!X1C4L(#!X.#<L(#!X0C,L(#!X-$8L
M(#!X,3,L"B`@("`@("`@,'@V,2P@,'@T-2P@,'@V1"P@,'@X1"P@,'@P.2P@
M,'@X,2P@,'@W1"P@,'@S,BP*("`@("`@("`P>$)$+"`P>#A&+"`P>#0P+"`P
M>$5"+"`P>#@V+"`P>$(W+"`P>#="+"`P>#!"+`H@("`@("`@(#!X1C`L(#!X
M.34L(#!X,C$L(#!X,C(L(#!X-4,L(#!X-D(L(#!X-$4L(#!X.#(L"B`@("`@
M("`@,'@U-"P@,'A$-BP@,'@V-2P@,'@Y,RP@,'A#12P@,'@V,"P@,'A",BP@
M,'@Q0RP*("`@("`@("`P>#<S+"`P>#4V+"`P>$,P+"`P>#$T+"`P>$$W+"`P
M>#A#+"`P>$8Q+"`P>$1#+`H@("`@("`@(#!X,3(L(#!X-S4L(#!X0T$L(#!X
M,48L(#!X,T(L(#!X0D4L(#!X130L(#!X1#$L"B`@("`@("`@,'@T,BP@,'@S
M1"P@,'A$-"P@,'@S,"P@,'A!,RP@,'@S0RP@,'A"-BP@,'@R-BP*("`@("`@
M("`P>#9&+"`P>$)&+"`P>#!%+"`P>$1!+"`P>#0V+"`P>#8Y+"`P>#`W+"`P
M>#4W+`H@("`@("`@(#!X,C<L(#!X1C(L(#!X,40L(#!X.4(L(#!X0D,L(#!X
M.30L(#!X-#,L(#!X,#,L"B`@("`@("`@,'A&."P@,'@Q,2P@,'A#-RP@,'A&
M-BP@,'@Y,"P@,'A%1BP@,'@S12P@,'A%-RP*("`@("`@("`P>#`V+"`P>$,S
M+"`P>$0U+"`P>#)&+"`P>$,X+"`P>#8V+"`P>#%%+"`P>$0W+`H@("`@("`@
M(#!X,#@L(#!X13@L(#!X14$L(#!X1$4L(#!X.#`L(#!X-3(L(#!X144L(#!X
M1C<L"B`@("`@("`@,'@X-"P@,'A!02P@,'@W,BP@,'A!0RP@,'@S-2P@,'@T
M1"P@,'@V02P@,'@R02P*("`@("`@("`P>#DV+"`P>#%!+"`P>$0R+"`P>#<Q
M+"`P>#5!+"`P>#$U+"`P>#0Y+"`P>#<T+`H@("`@("`@(#!X-$(L(#!X.48L
M(#!X1#`L(#!X-44L(#!X,#0L(#!X,3@L(#!X030L(#!X14,L"B`@("`@("`@
M,'A#,BP@,'A%,"P@,'@T,2P@,'@V12P@,'@P1BP@,'@U,2P@,'A#0BP@,'A#
M0RP*("`@("`@("`P>#(T+"`P>#DQ+"`P>$%&+"`P>#4P+"`P>$$Q+"`P>$8T
M+"`P>#<P+"`P>#,Y+`H@("`@("`@(#!X.3DL(#!X-T,L(#!X,T$L(#!X.#4L
M(#!X,C,L(#!X0C@L(#!X0C0L(#!X-T$L"B`@("`@("`@,'A&0RP@,'@P,BP@
M,'@S-BP@,'@U0BP@,'@R-2P@,'@U-2P@,'@Y-RP@,'@S,2P*("`@("`@("`P
M>#)$+"`P>#5$+"`P>$9!+"`P>#DX+"`P>$4S+"`P>#A!+"`P>#DR+"`P>$%%
M+`H@("`@("`@(#!X,#4L(#!X1$8L(#!X,CDL(#!X,3`L(#!X-C<L(#!X-D,L
M(#!X0D$L(#!X0SDL"B`@("`@("`@,'A$,RP@,'@P,"P@,'A%-BP@,'A#1BP@
M,'A%,2P@,'@Y12P@,'A!."P@,'@R0RP*("`@("`@("`P>#8S+"`P>#$V+"`P
M>#`Q+"`P>#-&+"`P>#4X+"`P>$4R+"`P>#@Y+"`P>$$Y+`H@("`@("`@(#!X
M,$0L(#!X,S@L(#!X,S0L(#!X,4(L(#!X04(L(#!X,S,L(#!X1D8L(#!X0C`L
M"B`@("`@("`@,'A"0BP@,'@T."P@,'@P0RP@,'@U1BP@,'A".2P@,'A",2P@
M,'A#1"P@,'@R12P*("`@("`@("`P>$,U+"`P>$8S+"`P>$1"+"`P>#0W+"`P
M>$4U+"`P>$$U+"`P>#E#+"`P>#<W+`H@("`@("`@(#!X,$$L(#!X038L(#!X
M,C`L(#!X-C@L(#!X1D4L(#!X-T8L(#!X0S$L(#!X040*("`@("D["@H@("`@
M+RHJ"B`@("`@*B!!<G)A>2!T;R!H;VQD('1H92!K97D@<V-H961U;&4*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7VME>5-C
M:&5D=6QE(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%-E="!T:&4@:V5Y
M('1O(&)E('5S960@9F]R(&5N+V1E8W)Y<'1I;VXN"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D:V5Y("!4:&4@:V5Y('1O('5S92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<V5T2V5Y*"1K97DI"B`@("!["B`@("`@("`@)&ME>2`]
M(&%R<F%Y7W9A;'5E<RAU;G!A8VLH)T,J)RP@)&ME>2DI.PH@("`@("`@("1B
M:71S(#T@,3`R-#L*"B`@("`@("`@+RH@17AP86YD(&EN<'5T(&ME>2!T;R`Q
M,C@@8GET97,@*B\*("`@("`@("`D;&5N(#T@8V]U;G0H)&ME>2D["B`@("`@
M("`@)&QA<W0@/2`D:V5Y6R1L96X@+2`Q73L*("`@("`@("!F;W(@*"1I(#T@
M)&QE;CL@)&D@/"`Q,C@[("1I*RLI('L*("`@("`@("`@("`@)&QA<W0@/2`D
M=&AI<RT^7W!E<FU;*"1K97E;)&D@+2`D;&5N72`K("1L87-T*2`F(#!X1D9=
M.PH@("`@("`@("`@("`D:V5Y6R1I72`]("1L87-T.PH@("`@("`@('T*"B`@
M("`@("`@+RH@4&AA<V4@,B`M(')E9'5C92!E9F9E8W1I=F4@:V5Y('-I>F4@
M=&\@(F)I=',B("HO"B`@("`@("`@:68@*"1L96X@(3T@."D@>PH@("`@("`@
M("`@("`D;&5N(#T@)&QE;B`J(#@["B`@("`@("`@?0H@("`@("`@("1K97E;
M,3(X("T@)&QE;ET@/2`D=&AI<RT^7W!E<FU;)&ME>5LQ,C@@+2`D;&5N72`F
M(#!X1D9=.PH@("`@("`@(&9O<B`H)&D@/2`Q,C<@+2`D;&5N.R`D:2`^/2`P
M.R`D:2TM*2!["B`@("`@("`@("`@("1K97E;)&E=(#T@)'1H:7,M/E]P97)M
M6R1K97E;)&D@*R`D;&5N72!>("1K97E;)&D@*R`Q75T["B`@("`@("`@?0H*
M("`@("`@("`O*B!0:&%S92`S("T@8V]N=F5R="!T;R`Q-B!B:70@=F%L=65S
M("HO"B`@("`@("`@9F]R("@D:2`](#8S.R`D:2`^/2`P.R`D:2TM*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?:V5Y4V-H961U;&5;)&E=(#T@*"1K97E;)&D@
M*B`R("L@,5T@/#P@."!\("1K97E;)&D@*B`R72D@)B`P>$9&1D8["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!S:7IE(&]F
M('1H92!B;&]C:W,@=&AA="!T:&ES(&-I<&AE<B!N965D<RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!N=6UB97(@;V8@8VAA<F%C=&5R
M<R!P97(@8FQO8VLN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$)L;V-K4VEZ
M92@I"B`@("!["B`@("`@("`@<F5T=7)N(#@["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!%;F-R>7!T(&$@8FQO8VL@;V8@9&%T82X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1B;&]C:R`@5&AE(&1A=&$@=&\@96YC<GEP="X*("`@
M("`J($!P87)A;2!S=')I;F<@)&ME>2`@("!4:&4@:V5Y('1O('5S92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&5N8W)Y<'1E9"!O=71P
M=70N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N8W)Y<'1";&]C:R@D8FQO8VLL
M("1K97D@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-?;G5L;"@D:V5Y
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T2V5Y*"1K97DI.PH@("`@("`@
M('T*"B`@("`@("`@)'!L86EN(#T@=6YP86-K*"=V*B<L("1B;&]C:RD["@H@
M("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(#$V.R`D:2LK*2!["B`@("`@("`@
M("`@("1P;&%I;ELQ72`K/2`H)'!L86EN6S)=("8@?B1P;&%I;ELT72D@*R`H
M)'!L86EN6S-=("8@)'!L86EN6S1=*2`K("1T:&ES+3Y?:V5Y4V-H961U;&5;
M-"`J("1I("L@,%T["B`@("`@("`@("`@("1B:6X@/2!S=')?<&%D*&1E8V)I
M;B@P>$9&1D8@)B`D<&QA:6Y;,5TI+"`S,BP@)S`G+"!35%)?4$%$7TQ%1E0I
M.PH@("`@("`@("`@("`D<&QA:6Y;,5T@/2!B:6YD96,H)&)I;B`N('-U8G-T
M<B@D8FEN+"`Q-BP@,2DI.PH*("`@("`@("`@("`@)'!L86EN6S)=("L]("@D
M<&QA:6Y;,UT@)B!^)'!L86EN6S%=*2`K("@D<&QA:6Y;-%T@)B`D<&QA:6Y;
M,5TI("L@)'1H:7,M/E]K97E38VAE9'5L95LT("H@)&D@*R`Q73L*("`@("`@
M("`@("`@)&)I;B`]('-T<E]P860H9&5C8FEN*#!X1D9&1B`F("1P;&%I;ELR
M72DL(#,R+"`G,"<L(%-44E]0041?3$5&5"D["B`@("`@("`@("`@("1P;&%I
M;ELR72`](&)I;F1E8R@D8FEN("X@<W5B<W1R*"1B:6XL(#$V+"`R*2D["@H@
M("`@("`@("`@("`D<&QA:6Y;,UT@*ST@*"1P;&%I;ELT72`F('XD<&QA:6Y;
M,ETI("L@*"1P;&%I;ELQ72`F("1P;&%I;ELR72D@*R`D=&AI<RT^7VME>5-C
M:&5D=6QE6S0@*B`D:2`K(#)=.PH@("`@("`@("`@("`D8FEN(#T@<W1R7W!A
M9"AD96-B:6XH,'A&1D9&("8@)'!L86EN6S-=*2P@,38L("<P)RP@4U127U!!
M1%],1494*3L*("`@("`@("`@("`@)'!L86EN6S-=(#T@8FEN9&5C*"1B:6X@
M+B!S=6)S='(H)&)I;BP@,"P@,RDI.PH*("`@("`@("`@("`@)'!L86EN6S1=
M("L]("@D<&QA:6Y;,5T@)B!^)'!L86EN6S-=*2`K("@D<&QA:6Y;,ET@)B`D
M<&QA:6Y;,UTI("L@)'1H:7,M/E]K97E38VAE9'5L95LT("H@)&D@*R`S73L*
M("`@("`@("`@("`@)&)I;B`]('-T<E]P860H9&5C8FEN*#!X1D9&1B`F("1P
M;&%I;ELT72DL(#$V+"`G,"<L(%-44E]0041?3$5&5"D["B`@("`@("`@("`@
M("1P;&%I;ELT72`](&)I;F1E8R@D8FEN("X@<W5B<W1R*"1B:6XL(#`L(#4I
M*3L*"B`@("`@("`@("`@(&EF("@D:2`]/2`T('Q\("1I(#T](#$P*2!["B`@
M("`@("`@("`@("`@("`D<&QA:6Y;,5T@*ST@)'1H:7,M/E]K97E38VAE9'5L
M95LD<&QA:6Y;-%T@)B`P>#-&73L*("`@("`@("`@("`@("`@("1P;&%I;ELR
M72`K/2`D=&AI<RT^7VME>5-C:&5D=6QE6R1P;&%I;ELQ72`F(#!X,T9=.PH@
M("`@("`@("`@("`@("`@)'!L86EN6S-=("L]("1T:&ES+3Y?:V5Y4V-H961U
M;&5;)'!L86EN6S)=("8@,'@S1ET["B`@("`@("`@("`@("`@("`D<&QA:6Y;
M-%T@*ST@)'1H:7,M/E]K97E38VAE9'5L95LD<&QA:6Y;,UT@)B`P>#-&73L*
M("`@("`@("`@("`@?0H*("`@("`@("!]"@H@("`@("`@("1E;F-R>7!T960@
M/2!P86-K*")V*B(L("1P;&%I;ELQ72P@)'!L86EN6S)=+"`D<&QA:6Y;,UTL
M("1P;&%I;ELT72D["B`@("`@("`@<F5T=7)N("1E;F-R>7!T960["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$96-R>7!T(&$@8FQO8VL@;V8@9&%T82X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1B;&]C:R`@5&AE(&1A=&$@=&\@
M9&5C<GEP="X*("`@("`J($!P87)A;2!S=')I;F<@)&ME>2`@("!4:&4@:V5Y
M('1O('5S92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&1E
M8W)Y<'1E9"!O=71P=70N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E8W)Y<'1"
M;&]C:R@D8FQO8VLL("1K97D@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A
M:7-?;G5L;"@D:V5Y*2D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T2V5Y*"1K
M97DI.PH@("`@("`@('T*"B`@("`@("`@)&-I<&AE<B`]('5N<&%C:R@G=BHG
M+"`D8FQO8VLI.PH*("`@("`@("!F;W(@*"1I(#T@,34[("1I(#X](#`[("1I
M+2TI('L*("`@("`@("`@("`@)&)I;B`]('-T<E]P860H9&5C8FEN*#!X1D9&
M1B`F("1C:7!H97);-%TI+"`Q-BP@)S`G+"!35%)?4$%$7TQ%1E0I.PH@("`@
M("`@("`@("`D8VEP:&5R6S1=(#T@8FEN9&5C*'-U8G-T<B@D8FEN+"`M,C$L
M(#(Q*2`N('-U8G-T<B@D8FEN+"`P+"`Q,2DI.PH@("`@("`@("`@("`D8VEP
M:&5R6S1=("T]("@D8VEP:&5R6S%=("8@?B1C:7!H97);,UTI("L@*"1C:7!H
M97);,ET@)B`D8VEP:&5R6S-=*2`K("1T:&ES+3Y?:V5Y4V-H961U;&5;-"`J
M("1I("L@,UT["@H@("`@("`@("`@("`D8FEN(#T@<W1R7W!A9"AD96-B:6XH
M,'A&1D9&("8@)&-I<&AE<ELS72DL(#$V+"`G,"<L(%-44E]0041?3$5&5"D[
M"B`@("`@("`@("`@("1C:7!H97);,UT@/2!B:6YD96,H<W5B<W1R*"1B:6XL
M("TQ.2P@,3DI("X@<W5B<W1R*"1B:6XL(#`L(#$S*2D["B`@("`@("`@("`@
M("1C:7!H97);,UT@+3T@*"1C:7!H97);-%T@)B!^)&-I<&AE<ELR72D@*R`H
M)&-I<&AE<ELQ72`F("1C:7!H97);,ETI("L@)'1H:7,M/E]K97E38VAE9'5L
M95LT("H@)&D@*R`R73L*"B`@("`@("`@("`@("1B:6X@/2!S=')?<&%D*&1E
M8V)I;B@P>$9&1D8@)B`D8VEP:&5R6S)=*2P@,38L("<P)RP@4U127U!!1%],
M1494*3L*("`@("`@("`@("`@)&-I<&AE<ELR72`](&)I;F1E8RAS=6)S='(H
M)&)I;BP@+3$X+"`Q."D@+B!S=6)S='(H)&)I;BP@,"P@,30I*3L*("`@("`@
M("`@("`@)&-I<&AE<ELR72`M/2`H)&-I<&AE<ELS72`F('XD8VEP:&5R6S%=
M*2`K("@D8VEP:&5R6S1=("8@)&-I<&AE<ELQ72D@*R`D=&AI<RT^7VME>5-C
M:&5D=6QE6S0@*B`D:2`K(#%=.PH*("`@("`@("`@("`@)&)I;B`]('-T<E]P
M860H9&5C8FEN*#!X1D9&1B`F("1C:7!H97);,5TI+"`Q-BP@)S`G+"!35%)?
M4$%$7TQ%1E0I.PH@("`@("`@("`@("`D8VEP:&5R6S%=(#T@8FEN9&5C*'-U
M8G-T<B@D8FEN+"`M,3<L(#$W*2`N('-U8G-T<B@D8FEN+"`P+"`Q-2DI.PH@
M("`@("`@("`@("`D8VEP:&5R6S%=("T]("@D8VEP:&5R6S)=("8@?B1C:7!H
M97);-%TI("L@*"1C:7!H97);,UT@)B`D8VEP:&5R6S1=*2`K("1T:&ES+3Y?
M:V5Y4V-H961U;&5;-"`J("1I("L@,%T["@H@("`@("`@("`@("!I9B`H)&D@
M/3T@-2!\?"`D:2`]/2`Q,2D@>PH@("`@("`@("`@("`@("`@)&-I<&AE<ELT
M72`M/2`D=&AI<RT^7VME>5-C:&5D=6QE6R1C:7!H97);,UT@)B`P>#-&73L*
M("`@("`@("`@("`@("`@("1C:7!H97);,UT@+3T@)'1H:7,M/E]K97E38VAE
M9'5L95LD8VEP:&5R6S)=("8@,'@S1ET["B`@("`@("`@("`@("`@("`D8VEP
M:&5R6S)=("T]("1T:&ES+3Y?:V5Y4V-H961U;&5;)&-I<&AE<ELQ72`F(#!X
M,T9=.PH@("`@("`@("`@("`@("`@)&-I<&AE<ELQ72`M/2`D=&AI<RT^7VME
M>5-C:&5D=6QE6R1C:7!H97);-%T@)B`P>#-&73L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N('!A8VLH(G8J(BP@)&-I<&AE<ELQ
M72P@)&-I<&AE<ELR72P@)&-I<&AE<ELS72P@)&-I<&AE<ELT72D["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-I<&AE<B]R
M8S0N<&AP````````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`T
M-#0P(#$P-3$U-#,S-S,W(#`R,3<V-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@5&AE($-I<&AE<E]R
M8S0Z.B!C;&%S<R!I;7!L96UE;G1S('1H92!#:7!H97(@:6YT97)F86-E(&5N
M8W)Y<'1I;VX@9&%T80H@*B!U<VEN9R!T:&4@4D,T(&5N8W)Y<'1I;VX@86QG
M;W)T:&EM+B!4:&ES(&-L87-S('5S97,@=&AE(%!%05(@0W)Y<'1?4D,T"B`J
M(&-L87-S('1O(&1O('1H92!E;F-R>7!T:6]N+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]#:7!H97(O0VEP:&5R+W)C-"YP:'`L=B`Q+C0N,3(N-R`R,#`V
M+S`Q+S`Q(#(Q.C(X.C$P(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P
M,BTR,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM
M:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!(;W)D92`R+C(*
M("H@0'!A8VMA9V4@2&]R9&5?0VEP:&5R"B`J+PIC;&%S<R!(;W)D95]#:7!H
M97)?<F,T(&5X=&5N9',@2&]R9&5?0VEP:&5R('L*"B`@("`O*BH*("`@("`J
M(%!O:6YT97(@=&\@82!014%2($-R>7!T7W)C-"!O8FIE8W0*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V-I<&AE<B`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("HO"B`@
M("!F=6YC=&EO;B!(;W)D95]#:7!H97)?<F,T*"1P87)A;7,@/2!N=6QL*0H@
M("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G0W)Y<'0O4F,T+G!H<"<["B`@
M("`@("`@)'1H:7,M/E]C:7!H97(@/2`F;F5W($-R>7!T7U)C-"@I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4V5T('1H92!K97D@=&\@8F4@=7-E9"!F;W(@
M96XO9&5C<GEP=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1K
M97D@(%1H92!K97D@=&\@=7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971+
M97DH)&ME>2D*("`@('L*("`@("`@("`D=&AI<RT^7V-I<&AE<BT^:V5Y*"1K
M97DI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!S:7IE(&]F
M('1H92!B;&]C:W,@=&AA="!T:&ES(&-I<&AE<B!N965D<RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!N=6UB97(@;V8@8VAA<F%C=&5R
M<R!P97(@8FQO8VLN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$)L;V-K4VEZ
M92@I"B`@("!["B`@("`@("`@<F5T=7)N(#@["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!%;F-R>7!T(&$@8FQO8VL@;V8@9&%T82X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1B;&]C:R`@5&AE(&1A=&$@=&\@96YC<GEP="X*("`@
M("`J($!P87)A;2!S=')I;F<@)&ME>2`@("!4:&4@:V5Y('1O('5S92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&5N8W)Y<'1E9"!O=71P
M=70N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N8W)Y<'1";&]C:R@D8FQO8VLL
M("1K97D@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-?;G5L;"@D:V5Y
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T2V5Y*"1K97DI.PH@("`@("`@
M('T*"B`@("`@("`@+R\@36%K92!A(&-O<'D@;V8@=&AE(&-I<&AE<B!A<R!I
M="!D97-T<F]Y<R!I='-E;&8@9'5R:6YG(&$@8W)Y<'0*("`@("`@("`D8VEP
M:&5R(#T@)'1H:7,M/E]C:7!H97(["B`@("`@("`@)&-I<&AE<BT^8W)Y<'0H
M)&)L;V-K*3L*"B`@("`@("`@<F5T=7)N("1B;&]C:SL*("`@('T*"B`@("`O
M*BH*("`@("`J($1E8W)Y<'0@82!B;&]C:R!O9B!D871A+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&)L;V-K("!4:&4@9&%T82!T;R!D96-R>7!T
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("`@(%1H92!K97D@=&\@=7-E
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9&5C<GEP=&5D
M(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5C<GEP=$)L;V-K*"1B
M;&]C:RP@)&ME>2`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"%I<U]N=6QL
M*"1K97DI*2!["B`@("`@("`@("`@("1T:&ES+3YS971+97DH)&ME>2D["B`@
M("`@("`@?0H*("`@("`@("`O+R!-86ME(&$@8V]P>2!O9B!T:&4@8VEP:&5R
M(&%S(&ET(&1E<W1R;WES(&ET<V5L9B!D=7)I;F<@80H@("`@("`@("\O(&-R
M>7!T+@H@("`@("`@("1C:7!H97(@/2`D=&AI<RT^7V-I<&AE<CL*("`@("`@
M("`D8VEP:&5R+3YD96-R>7!T*"1B;&]C:RD["@H@("`@("`@(')E='5R;B`D
M8FQO8VL["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+U)00P``````````````````````````````````````````````````
M`````````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S,W(#`Q-S<Q-P`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O4E!#+W)E<W0N<&AP````````````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#<T,3,@,3`U,34T,S,W,S<@
M,#(Q-#<Q`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B!4:&4@2&]R9&5?4E!#7W)E<W0@8VQA<W,@<')O
M=FED97,@82!215-4(&EM<&QE;65N=&%T:6]N(&]F('1H92!(;W)D92!24$,*
M("H@<WES=&5M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]24$,O4E!#+W)E
M<W0N<&AP+'8@,2XV+C(N,B`R,#`V+S`U+S`T(#$R.C(T.C$T(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@4F%F865L(%9A<F5L82!0970@/')A9F%E;"YV
M87)E;&$N<&5T0'5S8RYE<SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y
M;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M(%)A9F%E;"!687)E;&$@/')A9F%E;"YV87)E;&$N<&5T0'5S8RYE<SX*("H@
M0'-I;F-E("`@2&]R9&4@,RXQ"B`J($!P86-K86=E($AO<F1E7U)00PH@*B\*
M8VQA<W,@2&]R9&5?4E!#7W)E<W0@97AT96YD<R!(;W)D95]24$,@>PH*("`@
M("\J*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?8V]N
M=&5N=%1Y<&4@/2`G=&5X="]H=&UL)SL*"B`@("`O*BH*("`@("`J($-H96-K
M(&%U=&AE;G1I8V%T:6]N+B!$:69F97)E;G0@8F%C:V5N9',@;6%Y(&AA;F1L
M90H@("`@("H@875T:&5N=&EC871I;VX@:6X@9&EF9F5R96YT('=A>7,N(%1H
M92!B87-E(&-L87-S(&EM<&QE;65N=&%T:6]N"B`@("`@*B!C:&5C:W,@9F]R
M($A45%`@075T:&5N=&EC871I;VX@86=A:6YS="!T:&4@2&]R9&4@875T:"!S
M971U<"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%)E='5R;G,@
M=')U92!I9B!A=71H96YT:6-A=&EO;B!I<R!S=6-C97-S9G5L+@H@("`@("H@
M("`@("`@("`@("`@("`@("!3:&]U;&0@<V5N9"!A<'!R;W!R:6%T92`B;F]T
M(&%U=&AO<FEZ960B(&AE861E<G,*("`@("`J("`@("`@("`@("`@("`@("`@
M;W(@;W1H97(@<F5S<&]N<V4@8V]D97,O8F]D>2!I9B!A=71H(&9A:6QS+`H@
M("`@("H@("`@("`@("`@("`@("`@("!A;F0@=&%K92!C87)E(&]F(&5X:71I
M;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%U=&AO<FEZ92@I"B`@("!["B`@
M("`@("`@:68@*"$D=&AI<RT^7V%U=&AO<FEZ92D@>PH@("`@("`@("`@("!R
M971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@(&EF("A!=71H.CIG971!
M=71H*"DI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@<&%R96YT.CIA=71H;W)I>F4H*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($=E="X@86QL('1H92!'150@:6YP=70@9&%T82X@5&AE
M("=C86QL)R!P87)A;2!I<R!E>'1R86-T960@9G)O;2!T:&4*("`@("`J(&%R
M<F%Y(&%N9"!T<F5A=&5D('-E<&%R871E;'DN"B`@("`@*@H@("`@("H@0')E
M='5R;B!A<G)A>2`@*&UE=&AO9"!N86UE+"!A<G)A>2!O9B!P87)A;65T97)S
M*0H@("`@("H*("`@("`J(%1/1$\Z(&1E<V5R:6%L:7II;F<@;V8@8V]M<&QE
M>"!D871A('1Y<&5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971);G!U="@I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]C;VYT96YT5'EP92`](%5T:6PZ.F=E
M=$=E="@G<F5S=$-O;G1E;G14>7!E)RP@)W1E>'0O:'1M;"<I.PH*("`@(`DD
M9V5T1&%T82`](%5T:6PZ.F1I<W!E;$UA9VEC475O=&5S*"1?1T54*3L*("`@
M(`EU;G-E="@D9V5T1&%T85LG<F5S=$-A;&PG72D["B`@("`)=6YS970H)&=E
M=$1A=&%;)W)E<W1#;VYT96YT5'EP92==*3L*"B`@("`)<F5T=7)N(&%R<F%Y
M*"=M971H;V0G(#T^(%5T:6PZ.F=E=$=E="@G<F5S=$-A;&PG*2P*("`@(`D@
M("`@("`@("`@("`@)W!A<F%M<R<@/3X@)&=E=$1A=&$I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5N9',@86X@4E!#(')E<75E<W0@=&\@=&AE('-E<G9E
M<B!A;F0@<F5T=7)N<R!T:&4@<F5S=6QT+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@(%1H92!R87<@<F5Q=65S="!S=')I;F<N"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@5&AE(')E<W!O;G-E(&9R;VT@=&AE('-E<G9E
M<B!O<B!A;B!014%2(&5R<F]R(&]B:F5C="!O;@H@("`@("H@("`@("`@("`@
M("`@("`@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4F5S<&]N
M<V4H)')E<75E<W0I"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*
M"B`@("`@("`@)&UE=&AO9"`]('-T<E]R97!L86-E*"<N)RP@)R\G+"`D<F5Q
M=65S=%LG;65T:&]D)UTI.PH*("`@("`@("!I9B`H(21R96=I<W1R>2T^:&%S
M365T:&]D*"1M971H;V0I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*'-P<FEN=&8H7R@B365T:&]D(&YO="!D969I;F5D+B!#86QL
M960@;65T:&]D.B`E<R(I+"`D;65T:&]D*2D["B`@("`@("`@?0H*("`@("`@
M("`O*B!,;V]K(&%T('1H92!M971H;V0@<VEG;F%T=7)E('-O('1H870@<&%R
M86UE=&5R<R!A<F4@87-S:6=N960@8GD*("`@("`@("`@*B!N86UE+"!I;G-T
M96%D(&]F(')E;'EI;F<@;VX@=&AE(&]R9&5R(&]F($=%5"!P87)A;65T97)S
M('1O(&UA=&-H"B`@("`@("`@("H@=&AE(&]R9&5R(&1E9FEN960@:6X@=&AE
M($%022!M971H;V0N("HO"B`@("`@("`@)'-I9VYA='5R92`]("1R96=I<W1R
M>2T^9V5T4VEG;F%T=7)E*"1M971H;V0I.PH@("`@("`@("1P87)A;7,@/2!A
M<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*&%R<F%Y7VME>7,H)'-I9VYA='5R
M95LP72D@87,@)'!A<F%M*2!["B`@("`@("`@("`@("1P87)A;7-;)'!A<F%M
M72`](&ES<V5T*"1R97%U97-T6R=P87)A;7,G75LD<&%R86U=*2`_("1R97%U
M97-T6R=P87)A;7,G75LD<&%R86U=(#H@;G5L;#L*("`@("`@("!]"@H@("`@
M("`@("1R97-U;'0@/2`D<F5G:7-T<GDM/F-A;&PH)&UE=&AO9"P@)'!A<F%M
M<RD["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@
M("`@("\J(%1H92!R97-U;'0@:7,@<F5T=7)N960@9&5P96YD:6YG(&]N('1H
M92!R97%U97-T960@8V]N=&5N="!T>7!E+B`J+PH@("`@("`@(&EF("@D=&AI
M<RT^7V-O;G1E;G14>7!E(#T]("=T97AT+VAT;6PG*2!["B`@("`@("`@("`@
M(')E='5R;B`G/&AT;6P^/&)O9'D^)R`N('!R:6YT7W(H)')E<W5L="P@=')U
M92D@+B`G/"]B;V1Y/CPO:'1M;#XG.PH@("`@("`@('T@96QS96EF("@D=&AI
M<RT^7V-O;G1E;G14>7!E(#T]("=T97AT+W!L86EN)RD@>PH@("`@("`@("`@
M("!R971U<FX@<')I;G1?<B@D<F5S=6QT+"!T<G5E*3L*("`@("`@("!](&5L
M<V5I9B`H)'1H:7,M/E]C;VYT96YT5'EP92`]/2`G87!P;&EC871I;VXO>"UH
M='1P9"UP:'`G*2!["B`@("`@("`@("`@(')E='5R;B!S97)I86QI>F4H)')E
M<W5L="D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1V5T('1H
M92!#;VYT96YT+51Y<&4@;V8@=&AE(')E<W!O;G-E+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@34E-12!#;VYT96YT+51Y<&4@;V8@=&AE
M(%)00R!R97-P;VYS92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4F5S<&]N
M<V5#;VYT96YT5'EP92@I"B`@("!["B`@("`@("`@<W=I=&-H("@D=&AI<RT^
M7V-O;G1E;G14>7!E*2!["B`@("`@("`@8V%S92`G87!P;&EC871I;VXO>"UH
M='1P9"UP:'`G.@H@("`@("`@("`@("!R971U<FX@)W1E>'0O<&QA:6XG.PH@
M("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V-O
M;G1E;G14>7!E.PH@("`@("`@('T*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4E!#+WAM
M;')P8RYP:'``````````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,3,Q,38@,3`U,34T,S,W,S<@,#(R,#$V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@2&]R9&5?
M4E!#7WAM;')P8R!C;&%S<R!P<F]V:61E<R!A;B!834Q24$,@:6UP;&5M96YT
M871I;VX@;V8@=&AE"B`J($AO<F1E(%)00R!S>7-T96TN"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<"QV(#$N.2XQ,"XX(#(P
M,#8O,#<O,#$@,#0Z-30Z,38@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#(M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO
M<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO
M<F1E7U)00PH@*B\*8VQA<W,@2&]R9&5?4E!#7WAM;')P8R!E>'1E;F1S($AO
M<F1E7U)00R!["@H@("`@+RHJ"B`@("`@*B!297-O=7)C92!H86YD;&5R(&9O
M<B!T:&4@6$U,4E!#('-E<G9E<BX*("`@("`J"B`@("`@*B!`=F%R(')E<V]U
M<F-E"B`@("`@*B\*("`@('9A<B`D7W-E<G9E<CL*"B`@("`O*BH*("`@("`J
M(%A-3%)00R!S97)V97(@8V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?4E!#7WAM
M;')P8R@I"B`@("!["B`@("`@("`@<&%R96YT.CI(;W)D95]24$,H*3L*"B`@
M("`@("`@)'1H:7,M/E]S97)V97(@/2!X;6QR<&-?<V5R=F5R7V-R96%T92@I
M.PH*("`@("`@("!F;W)E86-H("@D1TQ/0D%,4ULG<F5G:7-T<GDG72T^;&ES
M=$UE=&AO9',H*2!A<R`D;65T:&]D*2!["B`@("`@("`@("`@('AM;')P8U]S
M97)V97)?<F5G:7-T97)?;65T:&]D*"1T:&ES+3Y?<V5R=F5R+"!S=')?<F5P
M;&%C92@G+R<L("<N)RP@)&UE=&AO9"DL(&%R<F%Y*"=(;W)D95]24$-?>&UL
M<G!C)RP@)U]D:7-P871C:&5R)RDI.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($-L96%N<R!U<"!T:&4@4E!#('-E<G9E<BX*("`@("`J+PH@
M("`@9G5N8W1I;VX@<VAU=&1O=VXH*0H@("`@>PH@("`@("`@('AM;')P8U]S
M97)V97)?9&5S=')O>2@D=&AI<RT^7W-E<G9E<BD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!396YD<R!A;B!24$,@<F5Q=65S="!T;R!T:&4@<V5R=F5R(&%N
M9"!R971U<FYS('1H92!R97-U;'0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`@5&AE(')A=R!R97%U97-T('-T<FEN9RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(%A-3"!E;F-O9&5D(')E<W!O;G-E(&9R;VT@
M=&AE('-E<G9E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4F5S<&]N<V4H
M)')E<75E<W0I"B`@("!["B`@("`@("`@)')E<W!O;G-E(#T@;G5L;#L*("`@
M("`@("!R971U<FX@>&UL<G!C7W-E<G9E<E]C86QL7VUE=&AO9"@D=&AI<RT^
M7W-E<G9E<BP@)')E<75E<W0L("1R97-P;VYS92D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!7:6QL(&)E(')E9VES=&5R960@87,@=&AE(&AA;F1L97(@9F]R
M(&%L;"!A=F%I;&%B;&4@;65T:&]D<PH@("`@("H@86YD('=I;&P@8V%L;"!T
M:&4@87!P<F]P<FEA=&4@9G5N8W1I;VX@=&AR;W5G:"!T:&4@<F5G:7-T<GDN
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;65T:&]D("!4:&4@;F%M92!O9B!T:&4@;65T:&]D
M(&-A;&QE9"!B>2!T:&4@4E!#(')E<75E<W0N"B`@("`@*B!`<&%R86T@87)R
M87D@)'!A<F%M<R`@(%1H92!P87-S960@<&%R86UE=&5R<RX*("`@("`J($!P
M87)A;2!M:7AE9"`D9&%T82`@("`@56YK;F]W;BX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4:&4@<F5S=6QT(&]F('1H92!C86QL960@<F5G:7-T
M<GD@;65T:&]D+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9&ES<&%T8VAE<B@D
M;65T:&]D+"`D<&%R86US+"`D9&%T82D*("`@('L*("`@("`@("!G;&]B86P@
M)')E9VES=')Y.PH*("`@("`@("`D;65T:&]D(#T@<W1R7W)E<&QA8V4H)RXG
M+"`G+R<L("1M971H;V0I.PH@("`@("`@(&EF("@A)')E9VES=')Y+3YH87--
M971H;V0H)&UE=&AO9"DI('L*("`@("`@("`@("`@<F5T=7)N('-P<FEN=&8H
M7R@B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(I+"`D;65T:&]D*3L*
M("`@("`@("!]"@H@("`@("`@("1R97-U;'0@/2`D<F5G:7-T<GDM/F-A;&PH
M)&UE=&AO9"P@)'!A<F%M<RD["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D<F5S=6QT(#T@87)R87DH
M)V9A=6QT0V]D92<@/3X@*&EN="DD<F5S=6QT+3YG971#;V1E*"DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G9F%U;'13=')I;F<G(#T^("1R97-U
M;'0M/F=E=$UE<W-A9V4H*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)')E<W5L=#L*("`@('T*"B`@("`O*BH*("`@("`J($)U:6QD<R!A;B!834Q2
M4$,@<F5Q=65S="!A;F0@<V5N9',@:70@=&\@=&AE(%A-3%)00R!S97)V97(N
M"B`@("`@*@H@("`@("H@5&AI<R!S=&%T:6-A;&QY(&-A;&QE9"!M971H;V0@
M:7,@86-T=6%L;'D@=&AE(%A-3%)00R!C;&EE;G0N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=7)L("`@("!4:&4@<&%T:"!T;R!T:&4@6$U,4E!#
M('-E<G9E<B!O;B!T:&4@8V%L;&5D(&AO<W0N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1M971H;V0@(%1H92!M971H;V0@=&\@8V%L;"X*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US("`@02!H87-H(&-O;G1A:6YI;F<@86YY(&YE8V5S
M<V%R>2!P87)A;65T97)S(&9O<@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("!T:&4@;65T:&]D(&-A;&PN"B`@("`@*B!`<&%R86T@)&]P=&EO;G,@
M($]P=&EO;F%L(&%S<V]C:6%T:79E(&%R<F%Y(&]F('!A<F%M971E<G,@=VAI
M8V@@8V%N(&)E.@H@("`@("H@("`@("`@("`@("`@("`@("!U<V5R("`@("`@
M("`@("`M($)A<VEC($%U=&@@=7-E<FYA;64*("`@("`J("`@("`@("`@("`@
M("`@("`@<&%S<R`@("`@("`@("`@+2!"87-I8R!!=71H('!A<W-W;W)D"B`@
M("`@*B`@("`@("`@("`@("`@("`@('!R;WAY7VAO<W0@("`@("T@4')O>'D@
M<V5R=F5R(&AO<W0*("`@("`J("`@("`@("`@("`@("`@("`@<')O>'E?<&]R
M="`@("`@+2!0<F]X>2!S97)V97(@<&]R=`H@("`@("H@("`@("`@("`@("`@
M("`@("!P<F]X>5]U<V5R("`@("`M(%!R;WAY(&%U=&@@=7-E<FYA;64*("`@
M("`J("`@("`@("`@("`@("`@("`@<')O>'E?<&%S<R`@("`@+2!0<F]X>2!A
M=71H('!A<W-W;W)D"B`@("`@*B`@("`@("`@("`@("`@("`@('1I;65O=70@
M("`@("`@("T@0V]N;F5C=&EO;B!T:6UE;W5T(&EN('-E8V]N9',N"B`@("`@
M*B`@("`@("`@("`@("`@("`@(&%L;&]W4F5D:7)E8W1S("T@5VAE=&AE<B!T
M;R!F;VQL;W<@<F5D:7)E8W1S(&]R(&YO=`H@("`@("H@("`@("`@("`@("`@
M("`@("!M87A2961I<F5C=',@("`M($UA>"!N=6UB97(@;V8@<F5D:7)E8W1S
M('1O(&9O;&QO=PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@("`@("`@
M("`@("!4:&4@<F5T=7)N960@<F5S=6QT(&9R;VT@=&AE(&UE=&AO9"!O<B!A
M(%!%05(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!E<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5Q=65S
M="@D=7)L+"`D;65T:&]D+"`D<&%R86US(#T@;G5L;"P@)&]P=&EO;G,@/2!A
M<G)A>2@I*0H@("`@>PH@("`@("`@("1O<'1I;VYS6R=M971H;V0G72`]("=0
M3U-4)SL*("`@("`@("`D;&%N9W5A9V4@/2!I<W-E="@D1TQ/0D%,4ULG;&%N
M9W5A9V4G72D@/R`D1TQ/0D%,4ULG;&%N9W5A9V4G72`Z"B`@("`@("`@("`@
M("`@("`@("`@*&ES<V5T*"1?4T525D526R=,04Y')UTI(#\@)%]315)615);
M)TQ!3D<G72`Z("<G*3L*"B`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG
M=&EM96]U="==*2D@>PH@("`@("`@("`@("`D;W!T:6]N<ULG=&EM96]U="==
M(#T@-3L*("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG
M86QL;W=2961I<F5C=',G72DI('L*("`@("`@("`@("`@)&]P=&EO;G-;)V%L
M;&]W4F5D:7)E8W1S)UT@/2!T<G5E.PH@("`@("`@("`@("`D;W!T:6]N<ULG
M;6%X4F5D:7)E8W1S)UT@/2`S.PH@("`@("`@('T*"B`@("`@("`@<F5Q=6ER
M95]O;F-E("=(5%10+U)E<75E<W0N<&AP)SL*"B`@("`@("`@)&AT='`@/2`F
M;F5W($A45%!?4F5Q=65S="@D=7)L+"`D;W!T:6]N<RD["B`@("`@("`@:68@
M*"%E;7!T>2@D;&%N9W5A9V4I*2!["B`@("`@("`@("`@("1H='1P+3YA9&1(
M96%D97(H)T%C8V5P="U,86YG=6%G92<L("1L86YG=6%G92D["B`@("`@("`@
M?0H@("`@("`@("1H='1P+3YA9&1(96%D97(H)U5S97(M06=E;G0G+"`G2&]R
M9&4@4E!#(&-L:65N="<I.PH@("`@("`@("1H='1P+3YA9&1(96%D97(H)T-O
M;G1E;G0M5'EP92<L("=T97AT+WAM;"<I.PH@("`@("`@("1H='1P+3YA9&12
M87=0;W-T1&%T82AX;6QR<&-?96YC;V1E7W)E<75E<W0H)&UE=&AO9"P@)'!A
M<F%M<RDI.PH*("`@("`@("`D<F5S=6QT(#T@)&AT='`M/G-E;F1297%U97-T
M*"D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!](&5L<V5I
M9B`H)&AT='`M/F=E=%)E<W!O;G-E0V]D92@I("$](#(P,"D@>PH@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")297%U97-T(&-O=6QD
M;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(I("X@)&AT
M='`M/F=E=%)E<W!O;G-E0V]D92@I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@
M("!](&5L<V5I9B`H<W1R<&]S*"1H='1P+3YG971297-P;VYS94)O9'DH*2P@
M)SP_>&UL)RD@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*%\H(DYO('9A;&ED(%A-3"!D871A(')E='5R;F5D(BDL
M("=H;W)D92YE<G)O<B<L(&YU;&PL(&YU;&PL("1H='1P+3YG971297-P;VYS
M94)O9'DH*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)')E<W!O
M;G-E(#T@0'AM;')P8U]D96-O9&4H<W5B<W1R*"1H='1P+3YG971297-P;VYS
M94)O9'DH*2P@<W1R<&]S*"1H='1P+3YG971297-P;VYS94)O9'DH*2P@)SP_
M>&UL)RDI*3L*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1R97-P;VYS92D@
M)B8@:7-S970H)')E<W!O;G-E6R=F875L=%-T<FEN9R==*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)')E<W!O;G-E6R=F
M875L=%-T<FEN9R==+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@?2!E
M;'-E:68@*&ES7V%R<F%Y*"1R97-P;VYS92D@)B8@:7-S970H)')E<W!O;G-E
M6S!=*2`F)@H@("`@("`@("`@("`@("`@("`@("`@:7-?87)R87DH)')E<W!O
M;G-E6S!=*2`F)B!I<W-E="@D<F5S<&]N<V5;,%U;)V9A=6QT4W1R:6YG)UTI
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D
M<F5S<&]N<V5;,%U;)V9A=6QT4W1R:6YG)UTL("=H;W)D92YE<G)O<B<I.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D<F5S<&]N<V4["B`@
M("`@("`@?0H@("`@?0H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]24$,O=V5B9&%V
M+G!H<```````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q-38T
M-2`Q,#4Q-30S,S<S-R`P,C$W-S(`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*"FEN8VQU9&5?;VYC92`G2%144"]7
M96)$058O4V5R=F5R+G!H<"<["@HO*BH*("H@5&AE($AO<F1E7U)00U]W96)D
M878@8VQA<W,@<')O=FED97,@82!796)$058@:6UP;&5M96YT871I;VX@;V8@
M=&AE"B`J($AO<F1E(%)00R!S>7-T96TN"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+U)00R]24$,O=V5B9&%V+G!H<"QV(#$N,2XQ,BXV(#(P,#8O,#$O,#$@
M,C$Z,C@Z,S,@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E
M+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E
M7U)00PH@*B\*8VQA<W,@2&]R9&5?4E!#7W=E8F1A=B!E>'1E;F1S($AO<F1E
M7U)00R!["@H@("`@+RHJ"B`@("`@*B!297-O=7)C92!H86YD;&5R(&9O<B!T
M:&4@5V5B1$%6('-E<G9E<BX*("`@("`J"B`@("`@*B!`=F%R($A45%!?5V5B
M1$%67U-E<G9E<E](;W)D90H@("`@("HO"B`@("!V87(@)%]S97)V97(["@H@
M("`@+RHJ"B`@("`@*B!796)$878@<V5R=F5R(&-O;G-T<G5C=&]R+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO
M;B!(;W)D95]24$-?=V5B9&%V*"D*("`@('L*("`@("`@("!P87)E;G0Z.DAO
M<F1E7U)00R@I.PH*("`@("`@("`D=&AI<RT^7W-E<G9E<B`]("9N97<@2%14
M4%]796)$059?4V5R=F5R7TAO<F1E*"D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!396YD<R!A;B!24$,@<F5Q=65S="!T;R!T:&4@<V5R=F5R(&%N9"!R971U
M<FYS('1H92!R97-U;'0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@
M5&AE(')A=R!R97%U97-T('-T<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE(%A-3"!E;F-O9&5D(')E<W!O;G-E(&9R;VT@=&AE('-E
M<G9E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4F5S<&]N<V4H)')E<75E
M<W0I"B`@("!["B`@("`@("`@)'1H:7,M/E]S97)V97(M/E-E<G9E4F5Q=65S
M="@I.PH@("`@("`@(&5X:70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!796)$
M058@:&%N9&QE<R!A=71H96YT:6-A=&EO;B!I;G1E<FYA;&QY+"!S;R!B>7!A
M<W,@=&AE"B`@("`@*B!S>7-T96TM;&5V96P@875T:"!C:&5C:R!B>2!J=7-T
M(')E='5R;FEN9R!T<G5E(&AE<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%U
M=&AO<FEZ92@I"B`@("!["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@I]
M"@HO*BH*("H@2&]R9&4@97AT96YS:6]N(&]F('1H92!B87-E($A45%!?5V5B
M1$%67U-E<G9E<B!C;&%S<RX*("H*("H@0'!A8VMA9V4@2&]R9&5?4E!#"B`J
M+PIC;&%S<R!(5%107U=E8D1!5E]397)V97)?2&]R9&4@97AT96YD<R!(5%10
M7U=E8D1!5E]397)V97(@>PH*("`@("\J*@H@("`@("H@4F5A;&T@<W1R:6YG
M('1O(&)E('5S960@:6X@875T:&5N=&EF:6-A=&EO;B!P;W!U<',*("`@("`J
M"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)&AT='!?875T
M:%]R96%L;2`]("=(;W)D92!796)$058G.PH*("`@("\J*@H@("`@("H@4W1R
M:6YG('1O(&)E('5S960@:6X@(E@M1&%V+5!O=V5R960M0GDB(&AE861E<@H@
M("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D9&%V
M7W!O=V5R961?8GD@/2`G2&]R9&4@5V5B1$%6(%-E<G9E<B<["@H@("`@+RHJ
M"B`@("`@*B!'150@:6UP;&5M96YT871I;VXN"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1O<'1I;VYS("!!<G)A>2!O9B!I;G!U="!A;F0@;W5T<'5T
M('!A<F%M971E<G,N"B`@("`@*B`\8G(^/'-T<F]N9SYI;G!U=#PO<W1R;VYG
M/CQU;#X*("`@("`J(#QL:3X@<&%T:"`M"B`@("`@*B`\+W5L/@H@("`@("H@
M/&)R/CQS=')O;F<^;W5T<'5T/"]S=')O;F<^/'5L/@H@("`@("H@/&QI/B!S
M:7IE("T*("`@("`J(#PO=6P^"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E
M9V5R("!(5%10+5-T871U<V-O9&4N"B`@("`@*B\*("`@(&9U;F-T:6]N($=%
M5"@F)&]P=&EO;G,I"B`@("!["B`@("`@("`@:68@*"1O<'1I;VYS6R=P871H
M)UT@/3T@)R\G*2!["B`@("`@("`@("`@("1O<'1I;VYS6R=M:6UE='EP92==
M(#T@)VAT='!D+W5N:7@M9&ER96-T;W)Y)SL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D;W!T:6]N<R`]("1T:&ES+3Y?;&ES="@D;W!T:6]N<ULG
M<&%T:"==+"`P*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4%54(&UE=&AO9"!H86YD;&5R"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("8D;W!T:6]N<R`@4&%R86UE=&5R('!A
M<W-I;F<@87)R87DN"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@
M<W5C8V5S<RX*("`@("`J+PH@("`@9G5N8W1I;VX@4%54*"8D;W!T:6]N<RD*
M("`@('L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%!23U!&24Y$(&UE=&AO9"!H86YD;&5R"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1O<'1I;VYS("!'96YE<F%L('!A<F%M971E<B!P87-S:6YG
M(&%R<F%Y+@H@("`@("H@0'!A<F%M(&%R<F%Y("8D9FEL97,@(%)E='5R;B!A
M<G)A>2!F;W(@9FEL92!P<F]P97)T:65S+@H@("`@("H@0')E='5R;B!B;V]L
M96%N("!4<G5E(&]N('-U8V-E<W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%!2
M3U!&24Y$*"1O<'1I;VYS+"`F)&9I;&5S*0H@("`@>PH@("`@("`@("1L:7-T
M(#T@)'1H:7,M/E]L:7-T*"1O<'1I;VYS6R=P871H)UTL("1O<'1I;VYS6R=D
M97!T:"==*3L*("`@("`@("!I9B`H)&QI<W0@/3T](&9A;'-E*2!["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@)&9I;&5S
M6R=F:6QE<R==(#T@)&QI<W0["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"@H@("`@9G5N8W1I;VX@7VQI<W0H)'!A=&@L("1D97!T:"D*("`@('L*("`@
M("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("`D;&ES="`](&%R<F%Y
M*`H@("`@("`@("`@("!A<G)A>2@G<&%T:"<@/3X@)'1H:7,M/G!A=&@L"B`@
M("`@("`@("`@("`@("`G<')O<',G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YM:W!R;W`H)V1I<W!L87EN86UE)RP@)'1H:7,M/G!A
M=&@I+`H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YM:W!R;W`H)V-R96%T
M:6]N9&%T92<L('1I;64H*2DL"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/FUK<')O<"@G9V5T;&%S=&UO9&EF:65D)RP@=&EM92@I*2P*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^;6MP<F]P*"=R97-O=7)C971Y<&4G+"`G8V]L
M;&5C=&EO;B<I+`H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YM:W!R;W`H
M)V=E=&-O;G1E;G1T>7!E)RP@)VAT='!D+W5N:7@M9&ER96-T;W)Y)RDL"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/FUK<')O<"@G9V5T8V]N=&5N=&QE
M;F=T:"<L(#`I*2DI.PH@("`@("`@(&EF("@D<&%T:"`]/2`G+R<I('L*("`@
M("`@("`@("`@)&%P<',@/2`D<F5G:7-T<GDM/FQI<W1!<'!S*&YU;&PL(&9A
M;'-E+"!015)-4U]214%$*3L*("`@("`@("`@("`@:68@*&ES7V$H)&%P<',L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!F;W)E86-H("@D87!P<R!A
M<R`D87!P*2!["B`@("`@("`@("`@("`@("!I9B`H)')E9VES=')Y+3YH87--
M971H;V0H)V)R;W=S92<L("1A<'`I*2!["B`@("`@("`@("`@("`@("`@("`@
M)'!R;W!S(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YM:W!R;W`H)V1I<W!L87EN86UE)RP@4W1R:6YG.CIC;VYV97)T0VAA<G-E
M="@D<F5G:7-T<GDM/F=E="@G;F%M92<L("1A<'`I+"!.3%,Z.F=E=$-H87)S
M970H*2P@)U541BTX)RDI+`H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^;6MP<F]P*"=C<F5A=&EO;F1A=&4G+"!T:6UE*"DI+`H@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^;6MP<F]P*"=G971L87-T;6]D:69I960G
M+"!T:6UE*"DI+`H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;6MP
M<F]P*"=R97-O=7)C971Y<&4G+"`G8V]L;&5C=&EO;B<I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^;6MP<F]P*"=G971C;VYT96YT='EP92<L
M("=H='1P9"]U;FEX+61I<F5C=&]R>2<I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^;6MP<F]P*"=G971C;VYT96YT;&5N9W1H)RP@,"DI.PH@
M("`@("`@("`@("`@("`@("`@("1I=&5M(#T@87)R87DH)W!A=&@G(#T^("1T
M:&ES+3YP871H("X@)R\G("X@)&%P<"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=P<F]P<R<@/3X@)'!R;W!S*3L*("`@("`@("`@("`@
M("`@("`@("`D;&ES=%M=(#T@)&ET96T["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H
M<W5B<W1R*"1P871H+"`P+"`Q*2`]/2`G+R<I('L*("`@("`@("`@("`@("`@
M("1P871H(#T@<W5B<W1R*"1P871H+"`Q*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D<&EE8V5S(#T@97AP;&]D92@G+R<L("1P871H*3L*("`@("`@
M("`@("`@)&ET96US(#T@)')E9VES=')Y+3YC86QL0GE086-K86=E*"1P:65C
M97-;,%TL("=B<F]W<V4G+"!A<G)A>2@G<&%T:"<@/3X@)'!A=&@L("=P<F]P
M97)T:65S)R`]/B!A<G)A>2@G;F%M92<L("=B<F]W<V5A8FQE)RP@)V-O;G1E
M;G1T>7!E)RP@)V-O;G1E;G1L96YG=&@G+"`G8W)E871E9"<L("=M;V1I9FEE
M9"<I*2D["B`@("`@("`@("`@(&EF("AI<U]A*"1I=&5M<RP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("@A:7-?87)R87DH<F5S970H)&ET96US
M*2DI('L*("`@("`@("`@("`@("`@("\J(%=E(')E='5R;B!A;B!O8FIE8W0G
M<R!C;VYT96YT+B`J+PH@("`@("`@("`@("`@("`@<F5T=7)N("1I=&5M<SL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!F;W)E86-H("@D:71E;7,@87,@
M)'-U8E]P871H(#T^("1I*2!["B`@("`@("`@("`@("`@("`D<')O<',@/2!A
M<G)A>2@*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;6MP<F]P*"=D:7-P
M;&%Y;F%M92<L(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&E;)VYA;64G72P@
M3DQ3.CIG971#:&%R<V5T*"DL("=55$8M."<I*2P*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^;6MP<F]P*"=C<F5A=&EO;F1A=&4G+"!E;7!T>2@D:5LG
M8W)E871E9"==*2`_(#`@.B`D:5LG8W)E871E9"==*2P*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^;6MP<F]P*"=G971L87-T;6]D:69I960G+"!E;7!T
M>2@D:5LG;6]D:69I960G72D@/R`P(#H@)&E;)VUO9&EF:65D)UTI+`H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YM:W!R;W`H)W)E<V]U<F-E='EP92<L
M("1I6R=B<F]W<V5A8FQE)UT@/R`G8V]L;&5C=&EO;B<@.B`G)RDL"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/FUK<')O<"@G9V5T8V]N=&5N='1Y<&4G
M+"`D:5LG8G)O=W-E86)L92==(#\@)VAT='!D+W5N:7@M9&ER96-T;W)Y)R`Z
M("AE;7!T>2@D:5LG8V]N=&5N='1Y<&4G72D@/R`G87!P;&EC871I;VXO;V-T
M970M<W1R96%M)R`Z("1I6R=C;VYT96YT='EP92==*2DL"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/FUK<')O<"@G9V5T8V]N=&5N=&QE;F=T:"<L(&5M
M<'1Y*"1I6R=C;VYT96YT;&5N9W1H)UTI(#\@,"`Z("1I6R=C;VYT96YT;&5N
M9W1H)UTI*3L*("`@("`@("`@("`@("`@("1I=&5M(#T@87)R87DH)W!A=&@G
M(#T^("<O)R`N("1S=6)?<&%T:"P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W!R;W!S)R`]/B`D<')O<',I.PH@("`@("`@("`@("`@("`@)&QI
M<W1;72`]("1I=&5M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!I9B`H)&1E<'1H*2!["B`@("`@("`@("`@(&EF("@D9&5P=&@@/3T@,2D@
M>PH@("`@("`@("`@("`@("`@)&1E<'1H(#T@,#L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!F;W)E86-H("@D;&ES="!A<R`D87!P(#T^("1I=&5M*2![
M"B`@("`@("`@("`@("`@("`O+U]L:7-T*"1P871H("X@)R\G("X@)&ET96TL
M("1D97!T:"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D;&ES=#L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K(&%U=&AE
M;G1I8V%T:6]N+B!792!A;'=A>7,@<F5T=7)N('1R=64@:&5R92!S:6YC92!W
M90H@("`@("H@:&%N9&QE('!E<FUI<W-I;VYS(&)A<V5D(&]N('1H92!R97-O
M=7)C92!T:&%T)W,@<F5Q=65S=&5D+"!B=70*("`@("`J('=E(&1O(')E8V]R
M9"!T:&4@875T:&5N=&EC871E9"!U<V5R(&9O<B!L871E<B!U<V4N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@("`@($%U=&AE;G1I8V%T
M:6]N('1Y<&4L(&4N9RX@(F)A<VEC(B!O<B`B9&EG97-T(@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=7-E<FYA;64@(%1R86YS;6ET=&5D('5S97)N86UE+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<&%S<W=O<F0@(%1R86YS;6ET=&5D('!A
M<W-W;W)D+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@075T:&5N
M=&EC871I;VX@<W1A='5S+B!!;'=A>7,@=')U92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@8VAE8VM?875T:"@D='EP92P@)'5S97)N86UE+"`D<&%S<W=O<F0I
M"B`@("!["B`@("`@("`@)&%U=&@@/2`F075T:#HZ<VEN9VQE=&]N*"1'3$]"
M04Q36R=C;VYF)UU;)V%U=&@G75LG9')I=F5R)UTI.PH@("`@("`@(')E='5R
M;B`D875T:"T^875T:&5N=&EC871E*"1U<V5R;F%M92P@87)R87DH)W!A<W-W
M;W)D)R`]/B`D<&%S<W=O<F0I*3L*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92]24$,O<WEN8VUL7W=B>&UL+G!H<```````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-C<P-R`Q,#4Q-30S,S<S-R`P
M,C,R,S<`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*"G)E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O
M<WEN8VUL+G!H<"<["G)E<75I<F5?;VYC92`G6$U,+U="6$U,+T1E8V]D97(N
M<&AP)SL*<F5Q=6ER95]O;F-E("=834PO5T)834PO16YC;V1E<BYP:'`G.PH*
M+RHJ"B`J(%1H92!(;W)D95]24$-?<WEN8VUL7W=B>&UL(&-L87-S('!R;W9I
M9&5S(&$@4WEN8TU,(&EM<&QE;65N=&%T:6]N(&]F('1H90H@*B!(;W)D92!2
M4$,@<WES=&5M('5S:6YG(%="6$U,(&5N8V]D:6YG+@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]24$,O4E!#+W-Y;F-M;%]W8GAM;"YP:'`L=B`Q+C$Q+C$P
M+C8@,C`P-B\P,2\P,2`R,3HR.#HS,R!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#,M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!!;G1H;VYY($UI;&QS(#QA;6EL
M;'-`<'ER86UI9#8N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!A=71H;W(@
M($%N=&AO;GD@36EL;',@/&%M:6QL<T!P>7)A;6ED-BYC;VT^"B`J($!S:6YC
M92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]24$,*("HO"F-L87-S
M($AO<F1E7U)00U]S>6YC;6Q?=V)X;6P@97AT96YD<R!(;W)D95]24$-?<WEN
M8VUL('L*"B`@("`O*BH*("`@("`J(%-E;F1S(&%N(%)00R!R97%U97-T('1O
M('1H92!S97)V97(@86YD(')E='5R;G,@=&AE(')E<W5L="X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1R97%U97-T("!4:&4@<F%W(')E<75E<W0@
M<W1R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@5T)8
M34P@96YC;V1E9"!R97-P;VYS92!F<F]M('1H92!S97)V97(@*&)I;F%R>2DN
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%)E<W!O;G-E*"1R97%U97-T*0H@
M("`@>PH@("`@("`@("\J($-A=&-H(&%N>2!E<G)O<G,O=V%R;FEN9W,O;F]T
M:6-E<R!T:&%T(&UA>2!G970@=&AR;W=N('=H:6QE"B`@("`@("`@("H@<')O
M8V5S<VEN9RX@1&]N)W0@=V%N="!T;R!L970@86YY=&AI;F<@9V\@=&\@=&AE
M(&-L:65N="!T:&%T)W,@;F]T"B`@("`@("`@("H@<&%R="!O9B!T:&4@=F%L
M:60@<F5S<&]N<V4N("HO"B`@("`@("`@;V)?<W1A<G0H*3L*"B`@("`@("`@
M+RH@5F5R>2!U<V5F=6P@9F]R(&1E8G5G9VEN9RX@3&]G<R!70EA-3"!P86-K
M971S('1O"B`@("`@("`@("H@)'1H:7,M/E]D96)U9T1I<BX@*B\*("`@("`@
M("!I9B`H(65M<'1Y*"1T:&ES+3Y?9&5B=6=$:7(I("8F(&ES7V1I<B@D=&AI
M<RT^7V1E8G5G1&ER*2D@>PH@("`@("`@("`@("`D<&%C:V5T3G5M(#T@0&EN
M='9A;"AF:6QE7V=E=%]C;VYT96YT<R@D=&AI<RT^7V1E8G5G1&ER("X@)R]S
M>6YC;6PN<&%C:V5T;G5M)RDI.PH@("`@("`@("`@("!I9B`H(6ES<V5T*"1P
M86-K971.=6TI*2!["B`@("`@("`@("`@("`@("`D<&%C:V5T3G5M(#T@,#L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&9P(#T@9F]P96XH)'1H:7,M
M/E]D96)U9T1I<B`N("<O<WEN8VUL7V-L:65N=%\G("X@)'!A8VME=$YU;2`N
M("<N=V)X;6PG+"`G=V(G*3L*("`@("`@("`@("`@9G=R:71E*"1F<"P@)')E
M<75E<W0I.PH@("`@("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@("!]"@H*
M("`@("`@("`D9&5C;V1E<B`]("9N97<@6$U,7U="6$U,7T1E8V]D97(H*3L*
M("`@("`@("`D=&AI<RT^7V]U='!U="`]("9N97<@6$U,7U="6$U,7T5N8V]D
M97(H*3L*"B`@("`@("`@)&1E8V]D97(M/G-E=$-O;G1E;G1(86YD;&5R*"1T
M:&ES*3L*"B`@("`@("`@)'(@/2`D9&5C;V1E<BT^9&5C;V1E*"1R97%U97-T
M*3L*("`@("`@("!I9B`H:7-?82@D<BP@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4WEN8TU,.B`G("X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'(M/F=E=$UE<W-A9V4H*2P@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@('T*"B`@
M("`@("`@)'1H:7,M/E]O=71P=70M/G-E=%9E<G-I;VXH)&1E8V]D97(M/F=E
M=%9E<G-I;VXH*2D["B`@("`@("`@)'1H:7,M/E]O=71P=70M/G-E=$-H87)S
M970H)&1E8V]D97(M/F=E=$-H87)S9713='(H*2D["B`@("`@("`@)')E<W!O
M;G-E(#T@)'1H:7,M/E]O=71P=70M/F=E=$]U='!U="@I.PH*("`@("`@("!I
M9B`H:7-?82@D<F5S<&]N<V4L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@2&]R9&4Z.FQO9TUE<W-A9V4H)')E<W!O;G-E+"!?7T9)3$5?7RP@7U],
M24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@("1R97-P;VYS92`]
M("1R97-P;VYS92T^9V5T365S<V%G92@I.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"%E;7!T>2@D=&AI<RT^7V1E8G5G1&ER*2`F)B!I<U]D:7(H)'1H:7,M
M/E]D96)U9T1I<BDI('L*("`@("`@("`@("`@)&9P(#T@9F]P96XH)'1H:7,M
M/E]D96)U9T1I<B`N("<O<WEN8VUL7W-E<G9E<E\G("X@)'!A8VME=$YU;2`N
M("<N=V)X;6PG+"`G=V(G*3L*("`@("`@("`@("`@9G=R:71E*"1F<"P@)')E
M<W!O;G-E*3L*("`@("`@("`@("`@9F-L;W-E*"1F<"D["@H@("`@("`@("`@
M("`D9G`@/2!`9F]P96XH)'1H:7,M/E]D96)U9T1I<B`N("<O<WEN8VUL+G!A
M8VME=&YU;2<L("=W)RD["B`@("`@("`@("`@(&EF("@D9G`I('L*("`@("`@
M("`@("`@("`@(&9W<FET92@D9G`L("LK)'!A8VME=$YU;2D["B`@("`@("`@
M("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@("`@("`@?0H*("`@("`@("!]
M"@H@("`@("`@("\J($-L96%R('1H92!O=71P=70@8G5F9F5R('1H870@=V4@
M<W1A<G1E9"!A8F]V92P@86YD(&QO9R!A;GET:&EN9PH@("`@("`@("`J('1H
M870@8V%M92!U<"!F;W(@;&%T97(@9&5B=6=G:6YG+B`J+PH@("`@("`@("1E
M<G)O<DQO9V=I;F<@/2!O8E]G971?8VQE86XH*3L*("`@("`@("!I9B`H(65M
M<'1Y*"1E<G)O<DQO9V=I;F<I*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-
M97-S86=E*"=3>6YC34PZ(&-A=6=H="!O=71P=70])R`N("1E<G)O<DQO9V=I
M;F<L"B`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?
M1$5"54<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R97-P;VYS93L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE($-O;G1E;G0M5'EP
M92!O9B!T:&4@<F5S<&]N<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!-24U%($-O;G1E;G0M5'EP92!O9B!T:&4@4E!#(')E<W!O;G-E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971297-P;VYS94-O;G1E;G14>7!E
M*"D*("`@('L*("`@("`@("!R971U<FX@)V%P<&QI8V%T:6]N+W9N9"YS>6YC
M;6PK=V)X;6PG.PH@("`@?0H*?0H`````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O4E!#+W-Y;F-M;"YP:'``````````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3<V-#8@,3`U,34T,S,W,S<@
M,#(R,#,R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"@IR97%U:7)E7V]N8V4@)U-Y;F--3"YP:'`G.PIR97%U:7)E
M7V]N8V4@)U-Y;F--3"]3=&%T92YP:'`G.PIR97%U:7)E7V]N8V4@)U-Y;F--
M3"]#;VUM86YD+U-T871U<RYP:'`G.PH*+RHJ"B`J(%1H92!(;W)D95]24$-?
M<WEN8VUL(&-L87-S('!R;W9I9&5S(&$@4WEN8TU,(&EM<&QE;65N=&%T:6]N
M(&]F('1H92!(;W)D90H@*B!24$,@<WES=&5M+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]24$,O4E!#+W-Y;F-M;"YP:'`L=B`Q+C$X+C$P+C<@,C`P-B\P
M-2\P,2`Q,CHP-3HQ,R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M
M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P
M>7)I9VAT(#(P,#,M,C`P-B!!;G1H;VYY($UI;&QS(#QA;6EL;'-`<'ER86UI
M9#8N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G
M96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!A=71H;W(@($%N=&AO;GD@
M36EL;',@/&%M:6QL<T!P>7)A;6ED-BYC;VT^"B`J($!S:6YC92`@($AO<F1E
M(#,N,`H@*B!`<&%C:V%G92!(;W)D95]24$,*("HO"F-L87-S($AO<F1E7U)0
M0U]S>6YC;6P@97AT96YD<R!(;W)D95]24$,@>PH*("`@("\J*@H@("`@("H@
M3W5T<'5T($-O;G1E;G1(86YD;&5R('5S960@=&\@;W5T<'5T(%A-3"!E=F5N
M=',N"B`@("`@*@H@("`@("H@0'9A<B!O8FIE8W0*("`@("`J+PH@("`@=F%R
M("1?;W5T<'5T.PH*("`@("\J*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@
M*B\*("`@('9A<B`D7WAM;%-T86-K(#T@,#L*"B`@("`O*BH*("`@("`J($1E
M8G5G(&1I<F5C=&]R>2P@:68@<V5T('=I;&P@<W1O<F4@8V]P:65S(&]F(&%L
M;"!P86-K971S+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*
M("`@('9A<B`D7V1E8G5G1&ER(#T@)R]T;7`O<WEN8R<["@H@("`@+RHJ"B`@
M("`@*B!$969A=6QT(&-H87)A8W1E<B!S970N("!/;FQY('-U<'!O<G1S(%54
M1BTX*$%30TE)/RDN"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J
M+PH@("`@=F%R("1?8VAA<G-E="`]("=55$8M."<["@H@("`@+RHJ"B`@("`@
M*B!3>6YC34P@:&%N9&QE<R!A=71H96YT:6-A=&EO;B!I;G1E<FYA;&QY+"!S
M;R!B>7!A<W,@=&AE(%)00R!F<F%M97=O<FL*("`@("`J(&%U=&@@8VAE8VL@
M8GD@:G5S="!R971U<FYI;F<@=')U92!H97)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!A=71H;W)I>F4H*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4V5N9',@86X@4E!#(')E<75E<W0@=&\@
M=&AE('-E<G9E<B!A;F0@<F5T=7)N<R!T:&4@<F5S=6QT+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)')E<75E<W0@(%1H92!R87<@<F5Q=65S="!S
M=')I;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!834P@
M96YC;V1E9"!R97-P;VYS92!F<F]M('1H92!S97)V97(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%)E<W!O;G-E*"1R97%U97-T*0H@("`@>PH@("`@("`@
M("\J($-A=&-H(&%N>2!E<G)O<G,O=V%R;FEN9W,O;F]T:6-E<R!T:&%T(&UA
M>2!G970@=&AR;W=N('=H:6QE"B`@("`@("`@("H@<')O8V5S<VEN9RX@1&]N
M)W0@=V%N="!T;R!L970@86YY=&AI;F<@9V\@=&\@=&AE(&-L:65N="!T:&%T
M)W,@;F]T"B`@("`@("`@("H@<&%R="!O9B!T:&4@=F%L:60@<F5S<&]N<V4N
M("HO"B`@("`@("`@;V)?<W1A<G0H*3L*"B`@("`@("`@+RH@5F5R>2!U<V5F
M=6P@9F]R(&1E8G5G9VEN9RX@3&]G<R!70EA-3"!P86-K971S('1O"B`@("`@
M("`@("H@)'1H:7,M/E]D96)U9T1I<BX@*B\*("`@("`@("!I9B`H(65M<'1Y
M*"1T:&ES+3Y?9&5B=6=$:7(I("8F(&ES7V1I<B@D=&AI<RT^7V1E8G5G1&ER
M*2D@>PH@("`@("`@("`@("`D<&%C:V5T3G5M(#T@0&EN='9A;"AF:6QE7V=E
M=%]C;VYT96YT<R@D=&AI<RT^7V1E8G5G1&ER("X@)R]S>6YC;6PN<&%C:V5T
M;G5M)RDI.PH@("`@("`@("`@("!I9B`H(6ES<V5T*"1P86-K971.=6TI*2![
M"B`@("`@("`@("`@("`@("`D<&%C:V5T3G5M(#T@,#L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@)&8@/2!`9F]P96XH)'1H:7,M/E]D96)U9T1I<B`N
M("<O<WEN8VUL7V-L:65N=%\G("X@)'!A8VME=$YU;2`N("<N>&UL)RP@)W=B
M)RD["B`@("`@("`@("`@(&EF("@D9BD@>PH@("`@("`@("`@("`@("`@9G=R
M:71E*"1F+"`D<F5Q=65S="D["B`@("`@("`@("`@("`@("!F8VQO<V4H)&8I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R97%U:7)E7V]N
M8V4@)UA-3"]70EA-3"]#;VYT96YT2&%N9&QE<BYP:'`G.PH@("`@("`@("1T
M:&ES+3Y?;W5T<'5T(#T@)FYE=R!834Q?5T)834Q?0V]N=&5N=$AA;F1L97(H
M*3L*"B`@("`@("`@)'1H:7,M/E]P87)S92@D<F5Q=65S="D["B`@("`@("`@
M)')E<W!O;G-E(#T@)'1H:7,M/E]O=71P=70M/F=E=$]U='!U="@I.PH*("`@
M("`@("`O*B!697)Y('5S969U;"!F;W(@9&5B=6=G:6YG+B`J+PH@("`@("`@
M(&EF("@A96UP='DH)'1H:7,M/E]D96)U9T1I<BD@)B8@:7-?9&ER*"1T:&ES
M+3Y?9&5B=6=$:7(I*2!["B`@("`@("`@("`@("1F(#T@0&9O<&5N*"1T:&ES
M+3Y?9&5B=6=$:7(@+B`G+W-Y;F-M;%]S97)V97)?)R`N("1P86-K971.=6T@
M+B`G+GAM;"<L("=W8B<I.PH@("`@("`@("`@("!I9B`H)&8I('L*("`@("`@
M("`@("`@("`@(&9W<FET92@D9BP@)')E<W!O;G-E*3L*("`@("`@("`@("`@
M("`@(&9C;&]S92@D9BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1F
M<"`]($!F;W!E;B@D=&AI<RT^7V1E8G5G1&ER("X@)R]S>6YC;6PN<&%C:V5T
M;G5M)RP@)W<G*3L*("`@("`@("`@("`@:68@*"1F<"D@>PH@("`@("`@("`@
M("`@("`@9G=R:71E*"1F<"P@*RLD<&%C:V5T3G5M*3L*("`@("`@("`@("`@
M("`@(&9C;&]S92@D9G`I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("`O*B!#;&5A<B!T:&4@;W5T<'5T(&)U9F9E<B!T:&%T('=E('-T87)T
M960@86)O=F4L(&%N9"!L;V<@86YY=&AI;F<*("`@("`@("`@*B!T:&%T(&-A
M;64@=7`@9F]R(&QA=&5R(&1E8G5G9VEN9RX@*B\*("`@("`@("`D97)R;W),
M;V=G:6YG(#T@;V)?9V5T7V-L96%N*"D["B`@("`@("`@:68@*"%E;7!T>2@D
M97)R;W),;V=G:6YG*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G
M92@G4WEN8TU,.B!C875G:'0@;W5T<'5T/2<@+@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!S=')?<F5P;&%C92@B7&XB+"`G("<L("1E<G)O<DQO
M9V=I;F<I+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S<&]N<V4["B`@("!]"@H@
M("`@9G5N8W1I;VX@7W!A<G-E*"1X;6PI"B`@("!["B`@("`@("`@+RH@=')Y
M('1O(&5X=')A8W0@8VAA<G-E="!F<F]M(%A-3"!T97AT("HO"B`@("`@("`@
M:68H<')E9U]M871C:"@G+UY<<RH\7#]X;6Q;7CY=*F5N8V]D:6YG7',J/5QS
M*B(H6UXB72HI(B]I)RP*("`@("`@("`@("`@("`@("1X;6PL("1M*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7V-H87)S970@/2`D;5LQ73L*("`@("`@("!]
M"B`@("`@("`@3DQ3.CIS971#:&%R<V5T*"1T:&ES+3Y?8VAA<G-E="D["B`@
M("`@("`@4W1R:6YG.CIS971$969A=6QT0VAA<G-E="@D=&AI<RT^7V-H87)S
M970I.PH*("`@("`@("`O*B!#<F5A=&4@=&AE(%A-3"!P87)S97(@86YD('-E
M="!M971H;V0@<F5F97)E;F-E<RX@*B\*("`@("`@("`D=&AI<RT^7W!A<G-E
M<B`]('AM;%]P87)S97)?8W)E871E7VYS*"1T:&ES+3Y?8VAA<G-E="D["B`@
M("`@("`@>&UL7W-E=%]O8FIE8W0H)'1H:7,M/E]P87)S97(L("1T:&ES*3L*
M("`@("`@("!X;6Q?<&%R<V5R7W-E=%]O<'1I;VXH)'1H:7,M/E]P87)S97(L
M(%A-3%]/4%1)3TY?0T%315]&3TQ$24Y'+"!F86QS92D["B`@("`@("`@>&UL
M7W-E=%]E;&5M96YT7VAA;F1L97(H)'1H:7,M/E]P87)S97(L("=?<W1A<G1%
M;&5M96YT)RP@)U]E;F1%;&5M96YT)RD["B`@("`@("`@>&UL7W-E=%]C:&%R
M86-T97)?9&%T85]H86YD;&5R*"1T:&ES+3Y?<&%R<V5R+"`G7V-H87)A8W1E
M<G,G*3L*("`@("`@("!X;6Q?<V5T7W!R;V-E<W-I;F=?:6YS=')U8W1I;VY?
M:&%N9&QE<B@D=&AI<RT^7W!A<G-E<BP@)R<I.PH@("`@("`@('AM;%]S971?
M97AT97)N86Q?96YT:71Y7W)E9E]H86YD;&5R*"1T:&ES+3Y?<&%R<V5R+"`G
M)RD["@H@("`@("`@(&EF("@A>&UL7W!A<G-E*"1T:&ES+3Y?<&%R<V5R+"`D
M>&UL*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M<W!R:6YT9B@G6$U,(&5R<F]R.B`E<R!A="!L:6YE("5D)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@>&UL7V5R<F]R
M7W-T<FEN9RAX;6Q?9V5T7V5R<F]R7V-O9&4H)'1H:7,M/E]P87)S97(I*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M>&UL7V=E=%]C=7)R96YT7VQI;F5?;G5M8F5R*"1T:&ES+3Y?<&%R<V5R*2DI
M.PH@("`@("`@('T*"B`@("`@("`@>&UL7W!A<G-E<E]F<F5E*"1T:&ES+3Y?
M<&%R<V5R*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<W1A<G1%;&5M96YT*"1P
M87)S97(L("1T86<L("1A='1R:6)U=&5S*0H@("`@>PH@("`@("`@(&QI<W0H
M)'5R:2P@)&YA;64I(#T@)'1H:7,M/E]S<&QI=%5222@D=&%G*3L*"B`@("`@
M("`@)'1H:7,M/G-T87)T16QE;65N="@D=7)I+"`D;F%M92P@)&%T=')I8G5T
M97,I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]C:&%R86-T97)S*"1P87)S97(L
M("1C:&%R<RD*("`@('L*("`@("`@("`D=&AI<RT^8VAA<F%C=&5R<R@D8VAA
M<G,I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]E;F1%;&5M96YT*"1P87)S97(L
M("1T86<I"B`@("!["B`@("`@("`@;&ES="@D=7)I+"`D;F%M92D@/2`D=&AI
M<RT^7W-P;&ET55))*"1T86<I.PH*("`@("`@("`D=&AI<RT^96YD16QE;65N
M="@D=7)I+"`D;F%M92D["B`@("!]"@H@("`@9G5N8W1I;VX@7W-P;&ET55))
M*"1T86<I"B`@("!["B`@("`@("`@)'!A<G1S(#T@97AP;&]D92@G.B<L("1T
M86<I.PH@("`@("`@("1N86UE(#T@87)R87E?<&]P*"1P87)T<RD["B`@("`@
M("`@)'5R:2`](&EM<&QO9&4H)SHG+"`D<&%R=',I.PH@("`@("`@(')E='5R
M;B!A<G)A>2@D=7)I+"`D;F%M92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!#;VYT96YT+51Y<&4@;V8@=&AE(')E<W!O;G-E+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@34E-12!#;VYT96YT+51Y
M<&4@;V8@=&AE(%)00R!R97-P;VYS92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T4F5S<&]N<V5#;VYT96YT5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N
M("=A<'!L:6-A=&EO;B]V;F0N<WEN8VUL*WAM;"<["B`@("!]"@H@("`@9G5N
M8W1I;VX@<W1A<G1%;&5M96YT*"1U<FDL("1E;&5M96YT+"`D871T<G,I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]X;6Q3=&%C:RLK.PH*("`@("`@("!S=VET
M8V@@*"1T:&ES+3Y?>&UL4W1A8VLI('L*("`@("`@("!C87-E(#$Z"B`@("`@
M("`@("`@("\O(#Q3>6YC34P^"B`@("`@("`@("`@("\O($1E9FEN960@:6X@
M4WEN8TU,(%)E<')E<V5N=&%T:6]N(%!R;W1O8V]L+"!V97)S:6]N(#$N,2`U
M+C(N,0H@("`@("`@("`@("`D=&AI<RT^7V]U='!U="T^<W1A<G1%;&5M96YT
M*"1U<FDL("1E;&5M96YT+"`D871T<G,I.PH@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@8V%S92`R.@H@("`@("`@("`@("`O+R!%:71H97(@/%-Y;F--
M3#X\4WEN8TAD<CX@;W(@/%-Y;F--3#X\4WEN8T)O9'D^"B`@("`@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/E]C;VYT96YT2&%N9&QE<BDI('L*("`@("`@
M("`@("`@("`@("\O($EF(&YO="!D969I;F5D('1H96X@8W)E871E(%-Y;F-(
M9'(N"B`@("`@("`@("`@("`@("`D=&AI<RT^7V-O;G1E;G1(86YD;&5R(#T@
M)FYE=R!3>6YC34Q?4WEN8VUL2&1R*"D["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7V-O;G1E;G1(86YD;&5R+3YS971/=71P=70H)'1H:7,M/E]O=71P=70I
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^7V-O;G1E;G1(
M86YD;&5R+3YS=&%R=$5L96UE;G0H)'5R:2P@)&5L96UE;G0L("1A='1R<RD[
M"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!D969A=6QT.@H@("`@("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]C;VYT96YT2&%N9&QE<BDI('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?8V]N=&5N=$AA;F1L97(M/G-T87)T16QE
M;65N="@D=7)I+"`D96QE;65N="P@)&%T=')S*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I
M;VX@96YD16QE;65N="@D=7)I+"`D96QE;65N="D*("`@('L*("`@("`@("!S
M=VET8V@@*"1T:&ES+3Y?>&UL4W1A8VLI('L*("`@("`@("!C87-E(#$Z"B`@
M("`@("`@("`@("\O(#PO4WEN8TU,/@H@("`@("`@("`@("`O+R!$969I;F5D
M(&EN(%-Y;F--3"!297!R97-E;G1A=&EO;B!0<F]T;V-O;"P@=F5R<VEO;B`Q
M+C$@-2XR+C$*("`@("`@("`@("`@)'1H:7,M/E]O=71P=70M/F5N9$5L96UE
M;G0H)'5R:2P@)&5L96UE;G0I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@8V%S92`R.@H@("`@("`@("`@("`O+R!%:71H97(@/"]3>6YC2&1R/CPO
M4WEN8TU,/B!O<B`\+U-Y;F-";V1Y/CPO4WEN8TU,/@H@("`@("`@("`@("!I
M9B`H)&5L96UE;G0@/3T@)U-Y;F-(9'(G*2!["B`@("`@("`@("`@("`@("`O
M+R!4:&5N('=E(&=E="!T:&4@<W1A=&4@9G)O;2!3>6YC34Q(9'(L(&%N9"!C
M<F5A=&4@82!N97<*("`@("`@("`@("`@("`@("\O(%-Y;F--3$)O9'DN"B`@
M("`@("`@("`@("`@("`D=&AI<RT^7V-O;G1E;G1(86YD;&5R+3YE;F1%;&5M
M96YT*"1U<FDL("1E;&5M96YT*3L*"B`@("`@("`@("`@("`@("!U;G-E="@D
M=&AI<RT^7V-O;G1E;G1(86YD;&5R*3L*"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7V-O;G1E;G1(86YD;&5R(#T@)FYE=R!3>6YC34Q?4WEN8VUL0F]D>2@I
M.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C;VYT96YT2&%N9&QE<BT^<V5T
M3W5T<'5T*"1T:&ES+3Y?;W5T<'5T*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("\O($YO(&QO;F=E<B!U<V5D+@H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]C;VYT96YT2&%N9&QE<BT^96YD16QE;65N="@D=7)I
M+"`D96QE;65N="D["B`@("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^7V-O
M;G1E;G1(86YD;&5R*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@+R\@/"\J/CPO4WEN
M8TAD<CX\+U-Y;F--3#X@;W(@/"\J/CPO4WEN8T)O9'D^/"]3>6YC34P^"B`@
M("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-O;G1E;G1(86YD;&5R*2D@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C;VYT96YT2&%N9&QE<BT^96YD
M16QE;65N="@D=7)I+"`D96QE;65N="D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]C:&%R<RDI('L*("`@("`@("`@("`@=6YS970H)'1H:7,M/E]C:&%R
M<RD["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7WAM;%-T86-K+2T["B`@
M("!]"@H@("`@9G5N8W1I;VX@8VAA<F%C=&5R<R@D<W1R*0H@("`@>PH@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7V-O;G1E;G1(86YD;&5R*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7V-O;G1E;G1(86YD;&5R+3YC:&%R86-T97)S*"1S
M='(I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!R86ES945R<F]R
M*"1S='(I"B`@("!["B`@("`@("`@<F5T=7)N($AO<F1E.CIL;V=-97-S86=E
M*"1S='(L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U)00R]S
M;V%P+G!H<```````````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#$U,34W(#$P-3$U-#,S-S,W(#`R,30V,@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@5&AE($AO<F1E
M7U)00U]S;V%P(&-L87-S('!R;W9I9&5S(&%N(%-/05`@:6UP;&5M96YT871I
M;VX@;V8@=&AE"B`J($AO<F1E(%)00R!S>7-T96TN"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+U)00R]24$,O<V]A<"YP:'`L=B`Q+C$S+C$P+C<@,C`P-B\P
M,2\P,2`R,3HR.#HS,R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M
M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("H*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R
M9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7U)0
M0PH@*B\*8VQA<W,@2&]R9&5?4E!#7W-O87`@97AT96YD<R!(;W)D95]24$,@
M>PH*("`@("\J*@H@("`@("H@4F5S;W5R8V4@:&%N9&QE<B!F;W(@=&AE(%)0
M0R!S97)V97(N"B`@("`@*@H@("`@("H@0'9A<B!O8FIE8W0*("`@("`J+PH@
M("`@=F%R("1?<V5R=F5R.PH*("`@("\J*@H@("`@("H@2&%S:"!H;VQD:6YG
M(&%L;"!M971H;V1S)R!S:6=N871U<F5S+@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1?7V1I<W!A=&-H7VUA<"`](&%R<F%Y
M*"D["@H@("`@+RHJ"B`@("`@*B!33T%0('-E<G9E<B!C;VYS=')U8W1O<@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC
M=&EO;B!(;W)D95]24$-?<V]A<"@D<&%R86US(#T@;G5L;"D*("`@('L*("`@
M("`@("!I9B`H)'!A<F%M<R`]/2`G=W-D;"<@?'P@)'!A<F%M<R`]/2`G9&ES
M8V\G*2!["B`@("`@("`@("`@("1T:&ES+3Y?875T:&]R:7IE(#T@9F%L<V4[
M"B`@("`@("`@?0H*("`@("`@("!P87)E;G0Z.DAO<F1E7U)00R@I.PH*("`@
M("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("!R97%U:7)E7V]N8V4@
M)U-/05`O4V5R=F5R+G!H<"<["B`@("`@("`@)'1H:7,M/E]S97)V97(@/2`F
M;F5W(%-/05!?4V5R=F5R*"D["B`@("`@("`@)'1H:7,M/E]S97)V97(M/E]A
M=71O7W1R86YS;&%T:6]N(#T@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J
M($9I;&QS(&$@:&%S:"!T:&%T(&ES('5S960@8GD@=&AE(%-/05`@<V5R=F5R
M('=I=&@@=&AE('-I9VYA='5R97,@;V8*("`@("`J(&%L;"!A=F%I;&%B;&4@
M;65T:&]D<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E='5P1&ES<&%T8VA-
M87`H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@("`@
M("1M971H;V1S(#T@)')E9VES=')Y+3YL:7-T365T:&]D<R@I.PH@("`@("`@
M(&9O<F5A8V@@*"1M971H;V1S(&%S("1M971H;V0I('L*("`@("`@("`@("`@
M)'-I9VYA='5R92`]("1R96=I<W1R>2T^9V5T4VEG;F%T=7)E*"1M971H;V0I
M.PH@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1S:6=N871U<F4I*2!["B`@
M("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D;65T:&]D(#T@<W1R7W)E<&QA8V4H)R\G+"`G+B<L("1M971H;V0I
M.PH@("`@("`@("`@("`D=&AI<RT^7U]D:7-P871C:%]M87!;)&UE=&AO9%T@
M/2!A<G)A>2@*("`@("`@("`@("`@("`@("=I;B<@/3X@)'-I9VYA='5R95LP
M72P*("`@("`@("`@("`@("`@("=O=70G(#T^(&%R<F%Y*"=O=71P=70G(#T^
M("1S:6=N871U<F5;,5TI"B`@("`@("`@("`@("D["B`@("`@("`@?0H*("`@
M("`@("`D=&AI<RT^7U]T>7!E9&5F(#T@)')E9VES=')Y+3YL:7-T5'EP97,H
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('-I9VYA='5R
M92!O9B!A(&UE=&AO9"X*("`@("`J($EN=&5R;F%L;'D@=7-E9"!B>2!T:&4@
M4T]!4"!S97)V97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;65T
M:&]D("!!(&UE=&AO9"!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@($%N(&%R<F%Y(&1E<V-R:6)I;F<@=&AE(&UE=&AO9"=S('-I9VYA='5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@7U]D:7-P871C:"@D;65T:&]D*0H@
M("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["B`@("`@("`@)&UE=&AO
M9"`]('-T<E]R97!L86-E*"<N)RP@)R\G+"`D;65T:&]D*3L*"B`@("`@("`@
M)'-I9VYA='5R92`]("1R96=I<W1R>2T^9V5T4VEG;F%T=7)E*"1M971H;V0I
M.PH@("`@("`@(&EF("@A:7-?87)R87DH)'-I9VYA='5R92DI('L*("`@("`@
M("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M87)R87DH)VEN)R`]/B`D<VEG;F%T=7)E6S!=+`H@("`@("`@("`@("`@("`@
M("`@("`G;W5T)R`]/B!A<G)A>2@G;W5T<'5T)R`]/B`D<VEG;F%T=7)E6S%=
M*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!7:6QL(&)E(')E9VES=&5R960@
M87,@=&AE(&AA;F1L97(@9F]R(&%L;"!M971H;V1S(&-A;&QE9"!I;B!T:&4*
M("`@("`J(%-/05`@<V5R=F5R(&%N9"!W:6QL(&-A;&P@=&AE(&%P<')O<')I
M871E(&9U;F-T:6]N('1H<F]U9V@@=&AE(')E9VES=')Y+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&UE=&AO9"`@("!4:&4@;F%M92!O9B!T:&4@;65T:&]D(&-A;&QE9"!B
M>2!T:&4@4E!#(')E<75E<W0N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M
M<R`@("`@5&AE('!A<W-E9"!P87)A;65T97)S+@H@("`@("H@0'!A<F%M(&UI
M>&5D("1D871A("`@("`@(%5N:VYO=VXN"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@("`@("`@("`@(%1H92!R97-U;'0@;V8@=&AE(&-A;&QE9"!R
M96=I<W1R>2!M971H;V0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]D:7-P871C
M:&5R*"1M971H;V0L("1P87)A;7,I"B`@("!["B`@("`@("`@9VQO8F%L("1R
M96=I<W1R>3L*("`@("`@("`D;65T:&]D(#T@<W1R7W)E<&QA8V4H)RXG+"`G
M+R<L("1M971H;V0I.PH*("`@("`@("!I9B`H(21R96=I<W1R>2T^:&%S365T
M:&]D*"1M971H;V0I*2!["B`@("`@("`@("`@(')E='5R;B!S<')I;G1F*%\H
M(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B*2P@)&UE=&AO9"D["B`@
M("`@("`@?0H*("`@("`@("`D=&AI<RT^7W-E<G9E<BT^8FEN9%=31$PH2&]R
M9&4Z.G5R;"@D<F5G:7-T<GDM/F=E="@G=V5B<F]O="<L("=H;W)D92<I("X@
M)R]R<&,N<&AP/W=S9&PG+"!T<G5E+"!F86QS92DI.PH@("`@("`@(')E='5R
M;B`D<F5G:7-T<GDM/F-A;&PH)&UE=&AO9"P@)'!A<F%M<RD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!486ME<R!A;B!24$,@<F5Q=65S="!A;F0@<F5T=7)N
M<R!T:&4@<F5S=6QT+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@(%1H
M92!R87<@<F5Q=65S="!S=')I;F<N"B`@("`@*B!`<&%R86T@<W1R:6YG("!3
M=')I;F<@<W!E8VEF>6EN9R!W:&%T(&MI;F0@;V8@9&%T82!T;R!R971U<FXN
M($1E9F%U;'1S"B`@("`@*B`@("`@("`@("`@("`@("!T;R!33T%0(')E<75E
M<W0N(%!O<W-I8FQE(&]T:&5R('9A;'5E<SH@(G=D<VPB(&%N9`H@("`@("H@
M("`@("`@("`@("`@("`@(F1I<V-O(BX*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE(%A-3"!E;F-O9&5D(')E<W!O;G-E(&9R;VT@=&AE('-E
M<G9E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4F5S<&]N<V4H)')E<75E
M<W0L("1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<V5R
M=F5R+3YA9&1/8FIE8W1-87`H)'1H:7,L("=U<FXZ:&]R9&4G*3L*"B`@("`@
M("`@:68@*"$D<&%R86US*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V5R=F5R
M+3YS971#86QL2&%N9&QE<BAA<G)A>2@D=&AI<RP@)U]D:7-P871C:&5R)RDI
M.PH@("`@("`@("`@("`O*B!792!C86XG="!U<V4@571I;#HZ8G5F9F5R3W5T
M<'5T*"D@:&5R92!F;W(@<V]M92!R96%S;VXN("HO"B`@("`@("`@("`@(&]B
M7W-T87)T*"D["B`@("`@("`@("`@("1T:&ES+3Y?<V5R=F5R+3YS97)V:6-E
M*"1R97%U97-T*3L*("`@("`@("`@("`@)&]U='!U="`](&]B7V=E=%]C;VYT
M96YT<R@I.PH@("`@("`@("`@("!O8E]E;F1?8VQE86XH*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U-/05`O1&ES8V\N
M<&AP)SL*("`@("`@("`@("`@)&1I<V-O(#T@;F5W(%-/05!?1$E30T]?4V5R
M=F5R*"1T:&ES+3Y?<V5R=F5R+"`G:&]R9&4G*3L*("`@("`@("`@("`@:68@
M*"1P87)A;7,@/3T@)W=S9&PG*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7W-E='5P1&ES<&%T8VA-87`H*3L*("`@("`@("`@("`@("`@("1O=71P=70@
M/2`D9&ES8V\M/F=E=%=31$PH*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1O=71P=70@/2`D9&ES8V\M/F=E=$1)4T-/*"D["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;W5T<'5T
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0G5I;&1S(&%N(%-/05`@<F5Q=65S
M="!A;F0@<V5N9',@:70@=&\@=&AE(%-/05`@<V5R=F5R+@H@("`@("H*("`@
M("`J(%1H:7,@<W1A=&EC86QL>2!C86QL960@;65T:&]D(&ES(&%C='5A;&QY
M('1H92!33T%0(&-L:65N="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1U<FP@("`@(%1H92!P871H('1O('1H92!33T%0('-E<G9E<B!O;B!T:&4@
M8V%L;&5D(&AO<W0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1M971H;V0@(%1H
M92!M971H;V0@=&\@8V%L;"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US
M("`@02!H87-H(&-O;G1A:6YI;F<@86YY(&YE8V5S<V%R>2!P87)A;65T97)S
M(&9O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!T:&4@;65T:&]D
M(&-A;&PN"B`@("`@*B!`<&%R86T@)&]P=&EO;G,@($]P=&EO;F%L(&%S<V]C
M:6%T:79E(&%R<F%Y(&]F('!A<F%M971E<G,@=VAI8V@@8V%N(&)E.@H@("`@
M("H@("`@("`@("`@("`@("`@("!U<V5R("`@("`@("`@("`@("`@("T@0F%S
M:6,@075T:"!U<V5R;F%M90H@("`@("H@("`@("`@("`@("`@("`@("!P87-S
M("`@("`@("`@("`@("`@("T@0F%S:6,@075T:"!P87-S=V]R9`H@("`@("H@
M("`@("`@("`@("`@("`@("!P<F]X>5]H;W-T("`@("`@("`@("T@4')O>'D@
M<V5R=F5R(&AO<W0*("`@("`J("`@("`@("`@("`@("`@("`@<')O>'E?<&]R
M="`@("`@("`@("`M(%!R;WAY('-E<G9E<B!P;W)T"B`@("`@*B`@("`@("`@
M("`@("`@("`@('!R;WAY7W5S97(@("`@("`@("`@+2!0<F]X>2!A=71H('5S
M97)N86UE"B`@("`@*B`@("`@("`@("`@("`@("`@('!R;WAY7W!A<W,@("`@
M("`@("`@+2!0<F]X>2!A=71H('!A<W-W;W)D"B`@("`@*B`@("`@("`@("`@
M("`@("`@('1I;65O=70@("`@("`@("`@("`@+2!#;VYN96-T:6]N('1I;65O
M=70@:6X@<V5C;VYD<RX*("`@("`J("`@("`@("`@("`@("`@("`@86QL;W=2
M961I<F5C=',@("`@("`M(%=H971H97(@=&\@9F]L;&]W(')E9&ER96-T<R!O
M<B!N;W0*("`@("`J("`@("`@("`@("`@("`@("`@;6%X4F5D:7)E8W1S("`@
M("`@("`M($UA>"!N=6UB97(@;V8@<F5D:7)E8W1S('1O(&9O;&QO=PH@("`@
M("H@("`@("`@("`@("`@("`@("!N86UE<W!A8V4*("`@("`J("`@("`@("`@
M("`@("`@("`@<V]A<&%C=&EO;@H@("`@("H@("`@("`@("`@("`@("`@("!F
M<F]M("`@("`@("`@("`@("`@("T@4TU44"P@9G)O;2!A9&1R97-S"B`@("`@
M*B`@("`@("`@("`@("`@("`@('1R86YS9F5R+65N8V]D:6YG("`@+2!33510
M+"!S971S('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9R!H96%D97(*
M("`@("`J("`@("`@("`@("`@("`@("`@<W5B:F5C="`@("`@("`@("`@("`M
M(%--5%`L('-U8FIE8W0@:&5A9&5R"B`@("`@*B`@("`@("`@("`@("`@("`@
M(&AE861E<G,@("`@("`@("`@("`@+2!33510+"!A<G)A>2UH87-H(&]F(&5X
M=')A('-M='`*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&AE861E<G,*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("`@("`@("`@("`@5&AE(')E='5R;F5D(')E<W5L="!F<F]M('1H92!M971H
M;V0@;W(@82!014%2"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M97)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E<75E<W0H)'5R;"P@)&UE=&AO9"P@)'!A<F%M<R`](&YU;&PL("1O<'1I
M;VYS(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1O<'1I
M;VYS6R=T:6UE;W5T)UTI*2!["B`@("`@("`@("`@("1O<'1I;VYS6R=T:6UE
M;W5T)UT@/2`U.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1O<'1I
M;VYS6R=A;&QO=U)E9&ER96-T<R==*2D@>PH@("`@("`@("`@("`D;W!T:6]N
M<ULG86QL;W=2961I<F5C=',G72`]('1R=64["B`@("`@("`@("`@("1O<'1I
M;VYS6R=M87A2961I<F5C=',G72`@(#T@,SL*("`@("`@("!]"@H@("`@("`@
M(')E<75I<F5?;VYC92`G4T]!4"]#;&EE;G0N<&AP)SL*("`@("`@("`D<V]A
M<"`]("9N97<@4T]!4%]#;&EE;G0H)'5R;"P@9F%L<V4L(&9A;'-E+"`D;W!T
M:6]N<RD["B`@("`@("`@<F5T=7)N("1S;V%P+3YC86QL*"1M971H;V0L("1P
M87)A;7,L("1O<'1I;VYS6R=N86UE<W!A8V4G72D["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U-13```````````````````````
M````````````````````````````````````````````````````````````
M`#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S
M-S,W(#`Q-S<S,@`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4U%,
M+T%T=')I8G5T97,N<&AP````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,S`S,C4@,3`U,34T,S,W,S<@,#(R-C4S`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!4:&ES(&-L
M87-S('!R;W9I9&5S(&%T=')I8G5T97,@;65T:&]D<R!F;W(@86YY(&5X:7-T
M:6YG(%-13"!C;&%S<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4U%,+U-1
M3"]!='1R:6)U=&5S+G!H<"QV(#$N,30N,3`N.2`R,#`V+S`Q+S`Q(#(Q.C(X
M.C,S(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K
M($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/@H@*B!`<VEN8V4@("!(;W)D92`R+C(*("H@0'!A8VMA9V4@2&]R9&5?4U%,
M"B`J+PIC;&%S<R!(;W)D95]344Q?071T<FEB=71E<R!["@H@("`@+RHJ"B`@
M("`@*B!4:&4@4$5!4CHZ1$(@;V)J96-T('1O(')U;B!Q=65R:65S('=I=&@N
M"B`@("`@*@H@("`@("H@0'9A<B!$0@H@("`@("HO"B`@("!V87(@)%]D8CL*
M"B`@("`O*BH*("`@("`J(%!A<F%M971E<G,@=&\@=7-E('=H96X@9V5N97)A
M=&EN9R!Q=65R:65S.@H@("`@("H@("!I9%]C;VQU;6X@("`@("`@+2!4:&4@
M<')I;6%R>2!I9"!C;VQU;6X@=&\@=7-E(&EN(&IO:6YS+@H@("`@("H@("!P
M<FEM87)Y7W1A8FQE("`@+2!4:&4@;6%I;B!T86)L92!N86UE+@H@("`@("H@
M("!A='1R:6)U=&5?=&%B;&4@+2!4:&4@=&%B;&4@=&AA="!T:&4@871T<FEB
M=71E<R!A<F4@<W1O<F5D(&EN+@H@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1?<&%R86US(#T@87)R87DH*3L*"B`@("`O*BH*
M("`@("`J(%1H92!N=6UB97(@;V8@8V]P:65S(&]F('1H92!A='1R:6)U=&5S
M('1A8FQE('1H870@=V4@;F5E9"!T;R!J;VEN(&]N(&EN"B`@("`@*B!T:&4@
M8W5R<F5N="!Q=65R>2X*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@
M("`J+PH@("`@=F%R("1?=&%B;&5?8V]U;G0@/2`Q.PH*("`@("\J*@H@("`@
M("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M($1"("1D8F@@
M("`@("`@($$@4$5!4CHZ1$(@;V)J96-T+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;7,@(%1H92!I9"!C;VQU;6XL('1A8FQE(&YA;65S+"!E=&,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7U-13%]!='1R:6)U=&5S*"1D8F@L
M("1P87)A;7,I"B`@("!["B`@("`@("`@)'1H:7,M/E]D8B`]("1D8F@["B`@
M("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!A;&P@871T<FEB=71E<R!F;W(@82!G:79E;B!I
M9"!O<B!M=6QT:7!L92!I9',N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@?"!A<G)A>2`D:60@(%1H92!I9"!T;R!F971C:"!O<B!A;B!A<G)A>2!O
M9B!I9',N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!H87-H(&]F
M(&%T=')I8G5T97,L(&]R(&$@;75L=&DM;&5V96P@:&%S:`H@("`@("H@("`@
M("`@("`@("`@("`@;V8@:61S(#T^('1H96ER(&%T=')I8G5T97,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$%T=')I8G5T97,H)&ED*0H@("`@>PH@("`@
M("`@(&EF("AI<U]A<G)A>2@D:60I*2!["B`@("`@("`@("`@("1Q=65R>2`]
M('-P<FEN=&8H)U-%3$5#5"`E,21S+"!A='1R:6)U=&5?;F%M92!A<R!N86UE
M+"!A='1R:6)U=&5?:V5Y(&%S(")K97DB+"!A='1R:6)U=&5?=F%L=64@87,@
M=F%L=64@1E)/32`E,B1S(%=(15)%("4Q)',@24X@*"4S)',I)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG:61?8V]L
M=6UN)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)V%T=')I8G5T95]T86)L92==+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EM<&QO9&4H)RP@)RP@)&ED*2D["@H@("`@("`@("`@("!(
M;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($AO<F1E7U-13%]!='1R
M:6)U=&5S.CIG971!='1R:6)U=&5S*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?
M+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("`D<F]W
M<R`]("1T:&ES+3Y?9&(M/F=E=$%L;"@D<75E<GDL($1"7T9%5$-(34]$15]!
M4U-/0RD["B`@("`@("`@("`@(&EF("AI<U]A*"1R;W=S+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')O=W,["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("1I9%]C;VQU;6X@/2`D=&AI<RT^7W!A<F%M
M<ULG:61?8V]L=6UN)UT["B`@("`@("`@("`@("1D871A(#T@87)R87DH*3L*
M("`@("`@("`@("`@9F]R96%C:"`H)')O=W,@87,@)')O=RD@>PH@("`@("`@
M("`@("`@("`@:68@*&5M<'1Y*"1D871A6R1R;W=;)&ED7V-O;'5M;EU=*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1D871A6R1R;W=;)&ED7V-O;'5M;EU=
M(#T@87)R87DH*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("1D871A6R1R;W=;)&ED7V-O;'5M;EU=6UT@/2!A<G)A>2@G;F%M92<@(#T^
M("1R;W=;)VYA;64G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G:V5Y)R`@(#T^("1R;W=;)VME>2==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=V
M86QU92<@/3X@)')O=ULG=F%L=64G72D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@<F5T=7)N("1D871A.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1Q=65R>2`]('-P<FEN=&8H)U-%3$5#5"`E,21S+"!A='1R:6)U=&5?
M;F%M92!A<R!N86UE+"!A='1R:6)U=&5?:V5Y(&%S(")K97DB+"!A='1R:6)U
M=&5?=F%L=64@87,@=F%L=64@1E)/32`E,B1S(%=(15)%("4Q)',@/2`E,R1S
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M
M<ULG:61?8V]L=6UN)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)V%T=')I8G5T95]T86)L92==+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("AI;G0I)&ED*3L*("`@("`@("`@("`@2&]R
M9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!(;W)D95]344Q?071T<FEB
M=71E<SHZ9V5T071T<FEB=71E<R@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@
M7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?9&(M/F=E=$%L;"@D<75E<GDL($1"7T9%5$-(34]$15]!4U-/
M0RD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&$@
M<V5T(&]F(&ED<R!B87-E9"!O;B!A('-E="!O9B!A='1R:6)U=&4@8W)I=&5R
M:6$N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<FET97)I82`@5&AE
M(&%R<F%Y(&]F(&-R:71E<FEA+B!%>&%M<&QE.@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@)&-R:71E<FEA6R=/4B==(#T@87)R87DH"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH
M)V9I96QD)R`]/B`G;F%M92<L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)V]P)R`@("`]/B`G/2<L"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W1E<W0G("`]/B`G9F]O)RDL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@87)R87DH)V9I96QD)R`]/B`G;F%M92<L"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V]P)R`@("`]/B`G/2<L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W1E<W0G("`]/B`G8F%R)RDI.PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(%1H:7,@=V]U;&0@<F5T
M=7)N(&%L;"!I9',@9F]R('=H:6-H('1H92!F:65L9`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@(&%T=')I8G5T95]N86UE(&ES(&5I=&AE<B`G
M9F]O)R!O<B`G8F%R)RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0GE!='1R
M:6)U=&5S*"1C<FET97)I82D*("`@('L*("`@("`@("!I9B`H(6-O=6YT*"1C
M<FET97)I82DI('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@("`@
M("`@?0H*("`@("`@("`O*B!"=6EL9"!T:&4@<75E<GDN("HO"B`@("`@("`@
M)'1H:7,M/E]T86)L95]C;W5N="`](#$["B`@("`@("`@)'%U97)Y(#T@)R<[
M"B`@("`@("`@9F]R96%C:"`H)&-R:71E<FEA(&%S("1K97D@/3X@)'9A;',I
M('L*("`@("`@("`@("`@:68@*"1K97D@/3T@)T]2)R!\?"`D:V5Y(#T]("=!
M3D0G*2!["B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1Q=65R>2DI('L*
M("`@("`@("`@("`@("`@("`@("`D<75E<GD@+CT@)R`G("X@)&ME>2`N("<@
M)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1Q=65R>2`N
M/2`G*"<@+B`D=&AI<RT^7V)U:6QD071T<FEB=71E475E<GDH)&ME>2P@)'9A
M;',I("X@)RDG.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O
M*B!"=6EL9"!T:&4@1E)/32]*3TE.(&-L875S97,N("HO"B`@("`@("`@)&IO
M:6YS(#T@87)R87DH*3L*("`@("`@("`D<&%I<G,@/2!A<G)A>2@I.PH@("`@
M("`@(&9O<B`H)&D@/2`Q.R`D:2`\/2`D=&AI<RT^7W1A8FQE7V-O=6YT.R`D
M:2LK*2!["B`@("`@("`@("`@("1J;VEN<UM=(#T@<W!R:6YT9B@G3$5&5"!*
M3TE.("4Q)',@824R)',@3TX@824R)',N)3,D<R`](&TN)3,D<R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG871T
M<FEB=71E7W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D:2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=I9%]C;VQU;6XG72D["@H@("`@("`@("`@("`D<&%I<G-;72`]
M("=!3D0@83$N871T<FEB=71E7VYA;64@/2!A)R`N("1I("X@)RYA='1R:6)U
M=&5?;F%M92<["B`@("`@("`@?0H@("`@("`@("1J;VEN<R`](&EM<&QO9&4H
M)R`G+"`D:F]I;G,I.PH@("`@("`@("1P86ER<R`](&EM<&QO9&4H)R`G+"`D
M<&%I<G,I.PH*("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=314Q%0U0@1$E3
M5$E.0U0@83$N)7,@1E)/32`E<R!M("5S(%=(15)%("5S("5S)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=I9%]C;VQU;6XG
M72P*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=P
M<FEM87)Y7W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`D:F]I
M;G,L"B`@("`@("`@("`@("`@("`@("`@("`@("`D<75E<GDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`D<&%I<G,I.PH*("`@("`@("!(;W)D93HZ;&]G
M365S<V%G92@G4U%,(%%U97)Y(&)Y($AO<F1E7U-13%]!='1R:6)U=&5S.CIG
M971">4%T=')I8G5T97,H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@(')E='5R;B`D=&AI<RT^
M7V1B+3YG971#;VPH)'%U97)Y*3L*("`@('T*"B`@("`O*BH*("`@("`J($=I
M=F5N(&$@;F5W(&%T=')I8G5T92!S970@86YD(&%N(&ED+"!I;G-E<G0@96%C
M:"!I;G1O('1H92!$0BX@268*("`@("`J(&%N>71H:6YG(&9A:6QS(&EN(&AE
M<F4L(')O;&QB86-K('1H92!T<F%N<V%C=&EO;BP@<F5T=7)N('1H92!R96QE
M=F%N=`H@("`@("H@97)R;W(@86YD(&)A:6P@;W5T+@H@("`@("H*("`@("`J
M($!P87)A;2!I;G1E9V5R("1I9"`@("`@("`@5&AE(&ED(&]F('1H92!R96-O
M<F0@9F]R('=H:6-H(&%T=')I8G5T97,@87)E"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&)E:6YG(&EN<V5R=&5D+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1A='1R:6)U=&5S("!!;B!H87-H(&-O;G1A:6YI;F<@=&AE(&%T
M=')I8G5T97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&EN<V5R=$%T=')I8G5T
M97,H)&ED+"`D871T<FEB=71E<RD*("`@('L*("`@("`@("!F;W)E86-H("@D
M871T<FEB=71E<R!A<R`D871T<BD@>PH@("`@("`@("`@("`D<75E<GD@/2`G
M24Y315)4($E.5$\@)R`N("1T:&ES+3Y?<&%R86US6R=A='1R:6)U=&5?=&%B
M;&4G72`N"B`@("`@("`@("`@("`@("`@("`@("<@*"<@+B`D=&AI<RT^7W!A
M<F%M<ULG:61?8V]L=6UN)UT@+B`G+"!A='1R:6)U=&5?;F%M92PG("X*("`@
M("`@("`@("`@("`@("`@("`@)R!A='1R:6)U=&5?:V5Y+"!A='1R:6)U=&5?
M=F%L=64I(%9!3%5%4R`H/RP@/RP@/RP@/RDG.PH@("`@("`@("`@("`D=F%L
M=65S(#T@87)R87DH*&EN="DD:60L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D871T<ELG;F%M92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&%T=');)VME>2==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&%T=');)W9A;'5E)UTI.PH*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A
M9V4H)U-13"!1=65R>2!B>2!(;W)D95]344Q?071T<FEB=71E<SHZ:6YS97)T
M071T<FEB=71E<R@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L
M(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI
M<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH@("`@("`@("`@("!I
M9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7V1B+3YR;VQL8F%C:R@I.PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]D8BT^875T;T-O;6UI="AT<G5E*3L*("`@("`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("`O*B!#;VUM:70@=&AE('1R86YS86-T:6]N+"!A;F0@='5R;B!A=71O
M8V]M;6ET(&)A8VL@;VXN("HO"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?
M9&(M/F-O;6UI="@I.PH@("`@("`@("1T:&ES+3Y?9&(M/F%U=&]#;VUM:70H
M=')U92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!':79E;B!A;B!I9"P@9&5L
M971E(&%L;"!A='1R:6)U=&5S(&9O<B!T:&%T(&ED(&9R;VT@=&AE"B`@("`@
M*B!A='1R:6)U=&5S('1A8FQE+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E
M9V5R("1I9"`@5&AE(&ED(&]F('1H92!R96-O<F0@9F]R('=H:6-H(&%T=')I
M8G5T97,@87)E(&)E:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(&1E
M;&5T960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T94%T=')I8G5T97,H
M)&ED*0H@("`@>PH@("`@("`@("\J($1E;&5T92!A='1R:6)U=&5S+B`J+PH@
M("`@("`@("1Q=65R>2`]('-P<FEN=&8H)T1%3$5412!&4D]-("5S(%=(15)%
M("5S(#T@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)V%T=')I8G5T95]T86)L92==+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)VED7V-O;'5M;B==+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@*&EN="DD:60I.PH*("`@("`@("!(;W)D93HZ;&]G
M365S<V%G92@G4U%,(%%U97)Y(&)Y($AO<F1E7U-13%]!='1R:6)U=&5S.CID
M96QE=&5!='1R:6)U=&5S*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)
M3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("1R97-U;'0@/2`D=&AI
M<RT^7V1B+3YQ=65R>2@D<75E<GDI.PH@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O*BH*("`@("`J($=I=F5N(&%N(&ED+"!U<&1A=&4@86QL(&%T=')I8G5T
M97,@9F]R('1H870@:60@:6X@=&AE(&%T=')I8G5T97,@=&%B;&4*("`@("`J
M('=I=&@@=&AE(&YE=R!A='1R:6)U=&5S+@H@("`@("H*("`@("`J($!P87)A
M;2!I;G1E9V5R("1I9"`@("`@("`@5&AE(&ED(&]F('1H92!R96-O<F0@9F]R
M('=H:6-H(&%T=')I8G5T97,@87)E"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&)E:6YG(&1E;&5T960N"B`@("`@*B!`<&%R86T@87)R87D@
M)&%T=')I8G5T97,@($%N(&AA<V@@8V]N=&%I;FEN9R!T:&4@871T<FEB=71E
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@=7!D871E071T<FEB=71E<R@D:60L
M("1A='1R:6)U=&5S*0H@("`@>PH@("`@("`@("\J($1E;&5T92!T:&4@;VQD
M(&%T=')I8G5T97,N("HO"B`@("`@("`@)')E<W5L="`]("1T:&ES+3YD96QE
M=&5!='1R:6)U=&5S*"1I9"D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@("`@("!]"@H@("`@("`@("\J($EN<V5R="!T:&4@;F5W(&%T=')I8G5T
M92!S970N("HO"B`@("`@("`@)')E<W5L="`]("1T:&ES+3YI;G-E<G1!='1R
M:6)U=&5S*"1I9"P@)&%T=')I8G5T97,I.PH@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@?0H*("`@("\J*@H@("`@("H@0G5I;&0@82!P:65C92!O9B!A
M;B!A='1R:6)U=&4@<75E<GDN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9VQU92`@("`@5&AE(&=L=64@=&\@:F]I;B!T:&4@8W)I=&5R:6$@*$]2
M+T%.1"DN"B`@("`@*B!`<&%R86T@87)R87D@)&-R:71E<FEA("!4:&4@87)R
M87D@;V8@8W)I=&5R:6$N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D:F]I;B`@
M("!3:&]U;&0@=V4@:F]I;B!O;B!A(&-L96%N(&%T=')I8G5T97,@=&%B;&4_
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($%N(%-13"!F<F%G;65N
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@7V)U:6QD071T<FEB=71E475E<GDH
M)&=L=64L("1C<FET97)I82P@)&IO:6X@/2!F86QS92D*("`@('L*("`@("`@
M("!R97%U:7)E7V]N8V4@)TAO<F1E+U-13"YP:'`G.PH*("`@("`@("`O*B!)
M;FET:6%L:7IE('1H92!C;&%U<V4@=&AA="!W92=R92!B=6EL9&EN9RX@*B\*
M("`@("`@("`D8VQA=7-E(#T@)R<["@H@("`@("`@("\J($=E="!T:&4@=&%B
M;&4@86QI87,@=&\@=7-E(&9O<B!T:&ES('-E="!O9B!C<FET97)I82X@*B\*
M("`@("`@("!I9B`H)&IO:6XI('L*("`@("`@("`@("`@)&%L:6%S(#T@)'1H
M:7,M/E]G971!;&EA<RAT<G5E*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D86QI87,@/2`D=&AI<RT^7V=E=$%L:6%S*"D["B`@("`@("`@?0H*
M("`@("`@("!F;W)E86-H("@D8W)I=&5R:6$@87,@)&ME>2`]/B`D=F%L<RD@
M>PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1V86QS6R=/4B==*2!\?"`A96UP
M='DH)'9A;'-;)T%.1"==*2D@>PH@("`@("`@("`@("`@("`@:68@*"%E;7!T
M>2@D8VQA=7-E*2D@>PH@("`@("`@("`@("`@("`@("`@("1C;&%U<V4@+CT@
M)R`G("X@)&=L=64@+B`G("<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`D8VQA=7-E("X]("<H)R`N("1T:&ES+3Y?8G5I;&1!='1R:6)U
M=&51=65R>2@D9VQU92P@)'9A;',I("X@)RDG.PH@("`@("`@("`@("!](&5L
M<V5I9B`H(65M<'1Y*"1V86QS6R=*3TE.)UTI*2!["B`@("`@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1C;&%U<V4I*2!["B`@("`@("`@("`@("`@("`@("`@
M)&-L875S92`N/2`G("<@+B`D9VQU92`N("<@)SL*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("1C;&%U<V4@+CT@)'1H:7,M/E]B=6EL9$%T
M=')I8G5T95%U97)Y*"1G;'5E+"`D=F%L<ULG2D])3B==+"!T<G5E*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M=F%L<ULG9FEE;&0G72DI('L*("`@("`@("`@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1C;&%U<V4I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1C;&%U
M<V4@+CT@)R`G("X@)&=L=64@+B`G("<["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@("1C;&%U<V4@+CT@2&]R9&5?4U%,.CIB
M=6EL9$-L875S92@D=&AI<RT^7V1B+"`D86QI87,@+B`G+F%T=')I8G5T95\G
M("X@)'9A;'-;)V9I96QD)UTL("1V86QS6R=O<"==+"`D=F%L<ULG=&5S="==
M*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)'9A;',@87,@)'1E<W0I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"%E;7!T>2@D8VQA=7-E*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&-L875S92`N/2`G("<@+B`D:V5Y("X@)R`G.PH@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M("`@("1C;&%U<V4@+CT@2&]R9&5?4U%,.CIB=6EL9$-L875S92@D=&AI<RT^
M7V1B+"`D86QI87,@+B`G+F%T=')I8G5T95\G("X@)'1E<W1;)V9I96QD)UTL
M("1T97-T6R=O<"==+"`D=&5S=%LG=&5S="==*3L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D8VQA=7-E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1V5T(&%N(&%L:6%S('1O(&%N(&%T=')I8G5T97,@=&%B;&4L(&EN
M8W)E;65N=&EN9R!I="!I9@H@("`@("H@;F5C97-S87)Y+@H@("`@("H*("`@
M("`J($!P87)A;2!B;V]L96%N("1I;F-R96UE;G0@($EN8W)E;65N="!T:&4@
M86QI87,@8V]U;G0_($1E9F%U;'1S('1O(&9A;'-E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?9V5T06QI87,H)&EN8W)E;65N="`](&9A;'-E*0H@("`@>PH@
M("`@("`@('-T871I8R`D<V5E;B`@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H
M)&EN8W)E;65N="`F)B`A96UP='DH)'-E96Y;)'1H:7,M/E]T86)L95]C;W5N
M=%TI*2!["B`@("`@("`@("`@("1T:&ES+3Y?=&%B;&5?8V]U;G0K*SL*("`@
M("`@("!]"@H@("`@("`@("1S965N6R1T:&ES+3Y?=&%B;&5?8V]U;G1=(#T@
M=')U93L*("`@("`@("!R971U<FX@)V$G("X@)'1H:7,M/E]T86)L95]C;W5N
M=#L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A
M(')E9F5R96YC92!T;R!A(&-O;F-R971E(%-13"!!='1R:6)U=&5S"B`@("`@
M*B!I;G-T86YC92!B87-E9"!O;B!P87)A;65T97)S('!A<W-E9"X@270@=VEL
M;"!O;FQY(&-R96%T92!A(&YE=PH@("`@("H@:6YS=&%N8V4@:68@;F\@071T
M<FEB=71E<R!I;G-T86YC92!W:71H('1H92!S86UE('!A<F%M971E<G,*("`@
M("`J(&-U<G)E;G1L>2!E>&ES=',N"B`@("`@*@H@("`@("H@5&AI<R!S:&]U
M;&0@8F4@=7-E9"!I9B!M=6QT:7!L92!344P@871T<FEB=71E('1A8FQE<R!A
M<F4*("`@("`J(')E<75I<F5D+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D
M(&UU<W0@8F4@:6YV;VME9"!A<SH@)'9A<B`]"B`@("`@*B`F2&]R9&5?4U%,
M7T%T=')I8G5T97,Z.G-I;F=L971O;B@I"B`@("`@*@H@("`@("H@0'!A<F%M
M($1"("1D8F@@("`@("`@($%N(&]B:F5C="!P;VEN=&EN9R!T;R!A(%-13"!D
M871A8F%S92!H86YD;&4N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P
M87)A;7,@(%!A<F%M971E<G,@9F]R('1H92!A='1R:6)U=&5S('1A8FQE+"!C
M;VYS:7-T:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@;V8@=&AE
M(&9O;&QO=VEN9R!K97ES.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("=P<FEM87)Y7W1A8FQE)R`@("T@=&AE(&UA:6X@4U%,('1A8FQE"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@)V%T=')I8G5T95]T86)L92<@+2!T
M:&4@<V5C;VYD('1A8FQE(&-O;G1A:6YI;F<*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H92!A='1R:6)U=&5S
M('1O('1H92!M86EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!T86)L92X*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`G:61?8V]L=6UN)R`@("`@("`M('1H92!N86UE(&]F('1H92!C
M;VQU;6X@=VET:`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@=&AE($E$(&]R(&ME>2!F:65L9"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@)G-I;F=L971O;B@D9&)H+"`D<&%R86US*0H@("`@>PH@
M("`@("`@('-T871I8R`D:6YS=&%N8V5S.PH*("`@("`@("!I9B`H(6ES<V5T
M*"1I;G-T86YC97,I*2!["B`@("`@("`@("`@("1I;G-T86YC97,@/2!A<G)A
M>2@I.PH@("`@("`@('T*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA;&EZ
M92@D<&%R86US*3L*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97-;)'-I
M9VYA='5R95TI*2!["B`@("`@("`@("`@("1I;G-T86YC97-;)'-I9VYA='5R
M95T@/2`F;F5W($AO<F1E7U-13%]!='1R:6)U=&5S*"1D8F@L("1P87)A;7,I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;)'-I9VYA
M='5R95T["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U-13"]+97EW;W)D
M<RYP:'``````````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$T-3,R
M(#$P-3$U-#,S-S,W(#`R,C,S-@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@5&AI<R!C;&%S<R!P<F]V
M:61E<R!A('!A<G-E<B!W:&EC:"!C86X@8V]N<W1R=6-T(&%N(%-13"!72$52
M10H@*B!C;&%U<V4@9G)O;2!A($=O;V=L92UL:6ME('-E87)C:"!E>'!R97-S
M:6]N+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S
M+G!H<"QV(#$N,BXQ,"XT(#(P,#8O,#$O,#$@,C$Z,C@Z,S,@:F%N($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@0W)O;F]S>7,L($Q,0R`\:'1T
M<#HO+W=W=RYC<F]N;W-Y<RYC;VTO/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J(%1H
M92!E>'!R97-S:6]N(')E8V]G;FEZ97,@8F]O;&5A;B`B04Y$(BP@(D]2(BP@
M86YD(").3U0B("AP<F]V:61I;F<*("H@;F\@;W!E<F%T;W(@8F5T=V5E;B!K
M97EW;W)D<R!I;7!L:65S(")!3D0B*2P@;&EK92!S;SH*("H*("H@("!C870@
M86YD(&1O9PH@*B`@(&-A="!O<B!D;V<*("H@("!C870@86YD(&YO="!D;V<*
M("H*("H@268@;F\@;W!E<F%T;W(@87!P96%R<R!B971W965N(&ME>7=O<F1S
M(&]R('%U;W1E9"!S=')I;F=S+"`B04Y$(B!I<PH@*B!A<W-U;65D+B`@02!C
M;VUM82!C86X@8F4@=7-E9"!I;G-T96%D(&]F(")/4B(Z"B`J"B`J("`@8V%T
M(&1O9PH@*B`@(&-A="P@9&]G"B`J("`@8V%T(&YO="!D;V<*("H*("H@5&AE
M('!A<G-E<B!R96-O9VYI>F5S('!A<F5N=&AE<V5S+"!S;R!C;VUP;&5X(&5X
M<')E<W-I;VYS(&-A;B!B90H@*B!C<F5A=&5D.@H@*@H@*B`@(&-A="!A;F0@
M;F]T("AD;V<@;W(@<'5P<'DI"B`J"B`J(%%U;W1E9"!S=')I;F=S(&%R92!A
M;'-O(')E8V]G;FEZ960L(&%N9"!A<F4@=&%K96X@87,@;&ET97)A;`H@*B!K
M97EW;W)D<SH*("H*("H@("`B8V%T(&%N9"!D;V<B"B`J"B`J(%!A<G-I;F<@
M:7,@9&5S:6=N960@=&\@8F4@87,@9G5Z>GD@87,@<&]S<VEB;&4L('-O(&ET
M('-H;W5L9&XG=`H@*B!E<G)O<B!U;FQE<W,@<&5O<&QE('-E87)C:"!F;W(@
M(D%.1"(L(")/4B(L(&]R(").3U0B('=I=&AO=70*("H@<75O=&EN9R!I="!O
M<B!U<V4@=6YB86QA;F-E9"!P87)E;G1H97-E<RX*("H*("H@0&%U=&AO<B`@
M2F%S;VX@32X@1F5L:6-E(#QJ9F5L:6-E0&-R;VYO<WES+F-O;3X*("H@0'-I
M;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7U-13`H@*B\*8VQA
M<W,@2&]R9&5?4U%,7TME>7=O<F1S('L*"B`@("`O*BH*("`@("`J(%!A<G-E
M(&$@:V5Y=V]R9"!E>'!R97-S:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&-O;'5M;B`@("`@("`@5&AI<R!I<R!T:&4@4U%,(&9I96QD(&YA
M;64@=&AE(')E<W5L=&EN9PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!E>'!R97-S:6]N('-H;W5L9"!T97-T(&%G86EN<W0N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1E>'!R("`@("`@("`@(%1H:7,@:7,@=&AE(&ME
M>7=O<F0@97AP<F5S<VEO;B!W92!W86YT('1O"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('!A<G-E+@H@("`@("H@0')E='5R;B!M:7AE
M9"!T:&4@<75E<GD@97AP<F5S<VEO;B!O<B!A(%!%05)?17)R;W(@;VX@9F%I
M;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<&%R<V4H)&-O;'5M;BP@)&5X
M<'(I"B`@("!["B`@("`@("`@+RH@1FER<W0@<&%S<R`M('-C86X@=&AE('-T
M<FEN9R!F;W(@=&]K96YS+B`@0F%R92!W;W)D<R!A<F4*("`@("`@("`@*B!T
M;VME;G,L(&]R('1H92!U<V5R(&-A;B!Q=6]T92!S=')I;F=S('1O(&AA=F4@
M96UB961D960*("`@("`@("`@*B!S<&%C97,L(&ME>7=O<F1S+"!O<B!P87)E
M;G1H97-E<RX@(%!A<F5N=&AE<V5S(&-A;B!B92!U<V5D"B`@("`@("`@("H@
M9F]R(&=R;W5P:6YG(&)O;VQE86X@;W!E<F%T;W)S+"!A;F0@=&AE(&)O;VQE
M86X@;W!E<F%T;W)S"B`@("`@("`@("H@04Y$+"!/4BP@86YD($Y/5"!A<F4@
M86QL(')E8V]G;FEZ960N"B`@("`@("`@("H*("`@("`@("`@*B!4:&4@=&]K
M96YS(&%R92!R971U<FYE9"!I;B!T:&4@)'1O:V5N<R!A<G)A>2`M+2!A;B!A
M<G)A>2!O9@H@("`@("`@("`J('-T<FEN9W,N("!%86-H('-T<FEN9R!I;B!T
M:&4@87)R87D@<W1A<G1S('=I=&@@96ET:&5R(&$@8"$G"B`@("`@("`@("H@
M;W(@82!@/2<N("!@/2<@:7,@82!B87)E('=O<F0@;W(@<75O=&5D('-T<FEN
M9R!W92!A<F4*("`@("`@("`@*B!S96%R8VAI;F<@9F]R+"!A;F0@8"$G(&EN
M9&EC871E<R!A(&)O;VQE86X@;W!E<F%T;W(@;W(*("`@("`@("`@*B!P87)E
M;G1H97-I<RX@($$@=&]K96X@=&AA="!S=&%R=',@=VET:"!A("<N)R`@:6YD
M:6-A=&5S(&$*("`@("`@("`@*B!0;W-T9W)E4U%,('=O<F0@8F]U;F1A<GD@
M<V5A<F-H+B`J+PH@("`@("`@("1T;VME;G,@/2!A<G)A>2@I.PH@("`@("`@
M('=H:6QE("@A96UP='DH)&5X<'(I*2!["B`@("`@("`@("`@("1E>'!R(#T@
M<')E9U]R97!L86-E*"(O7EQS*R\B+"`B(BP@)&5X<'(I.PH@("`@("`@("`@
M("!I9B`H96UP='DH)&5X<'(I*2!["B`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H<W5B<W1R*"1E>'!R+#`L
M,2D@/3T@)R@G*2!["B`@("`@("`@("`@("`@("`D97AP<B`]('-U8G-T<B@D
M97AP<BP@,2D["B`@("`@("`@("`@("`@("`D=&]K96X@/2`G(2@G.PH@("`@
M("`@("`@("!](&5L<V5I9B`H<W5B<W1R*"1E>'!R+"`P+"`Q*2`]/2`G*2<I
M('L*("`@("`@("`@("`@("`@("1E>'!R(#T@<W5B<W1R*"1E>'!R+"`Q*3L*
M("`@("`@("`@("`@("`@("1T;VME;B`]("<A*2<["B`@("`@("`@("`@('T@
M96QS96EF("AS=6)S='(H)&5X<'(L(#`L(#$I(#T]("<L)RD@>PH@("`@("`@
M("`@("`@("`@)&5X<'(@/2!S=6)S='(H)&5X<'(L(#$I.PH@("`@("`@("`@
M("`@("`@)'1O:V5N(#T@)R%/4B<["B`@("`@("`@("`@('T@96QS96EF("AP
M<F5G7VUA=&-H*"(O7BA!3D1\3U)\3D]4*2A;7F$M>ETN*BD_)"]I(BP@)&5X
M<'(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1M871C:&5S
M*2D@>PH@("`@("`@("`@("`@("`@)'1O:V5N(#T@)R$G("X@<W1R=&]U<'!E
M<B@D;6%T8VAE<ULQ72D["B`@("`@("`@("`@("`@("`D97AP<B`]('-U8G-T
M<B@D97AP<BP@<W1R;&5N*"1M871C:&5S6S%=*2D["B`@("`@("`@("`@('T@
M96QS96EF("AP<F5G7VUA=&-H*"(O7EPB*"A;7EPB77Q<7%LP+3==*WQ<7%M8
M>%U;,"TY82UF02U&72M\7%Q;7EAX,"TW72DJ*5PB+R(L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1E>'!R+"`D;6%T8VAE<RDI('L*("`@
M("`@("`@("`@("`@("1T;VME;B`]("<])R`N('-T<FEP8W-L87-H97,H)&UA
M=&-H97-;,5TI.PH@("`@("`@("`@("`@("`@)&5X<'(@/2!S=6)S='(H)&5X
M<'(L('-T<FQE;B@D;6%T8VAE<ULP72DI.PH@("`@("`@("`@("!](&5L<V5I
M9B`H<')E9U]M871C:"@B+UY;7EQ<<UQ<*%Q<*2Q=*R\B+"`D97AP<BP@)&UA
M=&-H97,I*2!["B`@("`@("`@("`@("`@("`D=&]K96X@/2`G/2<@+B`D;6%T
M8VAE<ULP73L*("`@("`@("`@("`@("`@("1E>'!R(#T@<W5B<W1R*"1E>'!R
M+'-T<FQE;B@D=&]K96XI+3$I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B4WEN=&%X
M(&5R<F]R(&EN('-E87)C:"!T97)M<R(I*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!I9B`H)'1O:V5N(#T]("<A04Y$)RD@>PH@("`@("`@("`@("`@
M("`@+RH@(4%.1"!I<R!I;7!L:65D(&)Y(&-O;F-A=&5N871I;VXN("HO"B`@
M("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D=&]K96YS6UT@/2`D=&]K96X["B`@("`@("`@?0H*("`@("`@("`O
M*B!#86QL('1H92!E>'!R97-S:6]N('!A<G-E<BX@*B\*("`@("`@("!R971U
M<FX@2&]R9&5?4U%,7TME>7=O<F1S.CI?<&%R<V5+97EW;W)D<S$H)&-O;'5M
M;BP@)'1O:V5N<RD["B`@("!]"@H@("`@9G5N8W1I;VX@7W!A<G-E2V5Y=V]R
M9',Q*"1C;VQU;6XL("8D=&]K96YS*0H@("`@>PH@("`@("`@(&EF("AC;W5N
M="@D=&]K96YS*2`]/2`P*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(D5M<'1Y('-E87)C:"!T97)M<R(I*3L*("`@("`@("!]
M"B`@("`@("`@)&QH<R`]($AO<F1E7U-13%]+97EW;W)D<SHZ7W!A<G-E2V5Y
M=V]R9',R*"1C;VQU;6XL("1T;VME;G,I.PH@("`@("`@(&EF("AI<U]A*"1L
M:',L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1L:',[
M"B`@("`@("`@?0H@("`@("`@(&EF("AC;W5N="@D=&]K96YS*2`]/2`P('Q\
M("1T;VME;G-;,%T@(3T@)R%/4B<I('L*("`@("`@("`@("`@<F5T=7)N("1L
M:',["B`@("`@("`@?0H@("`@("`@(&%R<F%Y7W-H:69T*"1T;VME;G,I.PH@
M("`@("`@("1R:',@/2!(;W)D95]344Q?2V5Y=V]R9',Z.E]P87)S94ME>7=O
M<F1S,2@D8V]L=6UN+"`D=&]K96YS*3L*("`@("`@("!I9B`H:7-?82@D<FAS
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<FAS.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@(B@@)&QH<R!/4B`D<FAS("DB.PH@
M("`@?0H*("`@(&9U;F-T:6]N(%]P87)S94ME>7=O<F1S,B@D8V]L=6UN+"`F
M)'1O:V5N<RD*("`@('L*("`@("`@("`D;&AS(#T@2&]R9&5?4U%,7TME>7=O
M<F1S.CI?<&%R<V5+97EW;W)D<S,H)&-O;'5M;BP@)'1O:V5N<RD["B`@("`@
M("`@:68@*&ES7V$H)&QH<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&QH<SL*("`@("`@("!]"B`@("`@("`@:68@*'-I>F5O9B@D
M=&]K96YS*2`]/2`P('Q\("1T;VME;G-;,%T@/3T@)R$I)R!\?"`D=&]K96YS
M6S!=(#T]("<A3U(G*2!["B`@("`@("`@("`@(')E='5R;B`D;&AS.PH@("`@
M("`@('T*("`@("`@("`D<FAS(#T@2&]R9&5?4U%,7TME>7=O<F1S.CI?<&%R
M<V5+97EW;W)D<S(H)&-O;'5M;BP@)'1O:V5N<RD["B`@("`@("`@:68@*&ES
M7V$H)')H<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)')H<SL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("(H("1L:',@04Y$("1R
M:',@*2(["B`@("!]"@H@("`@9G5N8W1I;VX@7W!A<G-E2V5Y=V]R9',S*"1C
M;VQU;6XL("8D=&]K96YS*0H@("`@>PH@("`@("`@(&EF("@D=&]K96YS6S!=
M(#T]("<A3D]4)RD@>PH@("`@("`@("`@("!A<G)A>5]S:&EF="@D=&]K96YS
M*3L*("`@("`@("`@("`@)&QH<R`]($AO<F1E7U-13%]+97EW;W)D<SHZ7W!A
M<G-E2V5Y=V]R9',T*"1C;VQU;6XL("1T;VME;G,I.PH@("`@("`@("`@("!I
M9B`H:7-?82@D;&AS+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@)&QH<SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U
M<FX@(B@@3D]4("1L:',@*2(["B`@("`@("`@?0H@("`@("`@(')E='5R;B!(
M;W)D95]344Q?2V5Y=V]R9',Z.E]P87)S94ME>7=O<F1S-"@D8V]L=6UN+"`D
M=&]K96YS*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<&%R<V5+97EW;W)D<S0H
M)&-O;'5M;BP@)B1T;VME;G,I"B`@("!["B`@("`@("`@:68@*"`D=&]K96YS
M6S!=(#T]("<A*"<@*2!["B`@("`@("`@("`@(&%R<F%Y7W-H:69T*"1T;VME
M;G,I.PH@("`@("`@("`@("`D;&AS(#T@2&]R9&5?4U%,7TME>7=O<F1S.CI?
M<&%R<V5+97EW;W)D<S$H)&-O;'5M;BP@)'1O:V5N<RD["B`@("`@("`@("`@
M(&EF("AI<U]A*"1L:',L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D;&AS.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("AS:7IE;V8H)'1O:V5N<RD@/3T@,"!\?"`D=&]K96YS6S!=("$]("<A*2<I
M('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(D5X<&5C=&5D("<I)R(I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!A
M<G)A>5]S:&EF="@D=&]K96YS*3L*("`@("`@("`@("`@<F5T=7)N("1L:',[
M"B`@("`@("`@?0H@("`@("`@(&EF("AS=6)S='(H)'1O:V5N<ULP72P@,"P@
M,2D@(3T@)STG("8F"B`@("`@("`@("`@('-U8G-T<B@D=&]K96YS6S!=+"`P
M+"`R*2`A/2`G/2XG*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*%\H(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H
M('1E<FTB*2D["B`@("`@("`@?0H@("`@("`@("1V86P@/2!S=')T;VQO=V5R
M*'-U8G-T<BAA<G)A>5]S:&EF="@D=&]K96YS*2P@,2DI.PH@("`@("`@("1V
M86P@/2!A9&1S;&%S:&5S*&5R96=?<F5P;&%C92@B*%M<7"5=*2(L(")<7%Q<
M,2(L("1V86PI*3L*("`@("`@("!R971U<FX@(B@@3$]715(H)&-O;'5M;BD@
M3$E+12`G)21V86PE)R`I(CL*("`@('T*"GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]"<F]W<V5R````````````````````````````````````````````````
M```````````````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<S-R`P,C`W,38`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+T)R;W=S97(O:6UO9&4N<&AP````````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#,Q,#<R(#$P-3$U-#,S-S,W(#`R
M,C8P-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@5&AE($)R;W=S97)?:6UO9&4Z.B!C;&%S<R!E>'1E
M;F1S('1H92!"<F]W<V5R($%022!B>2!P<F]V:61I;F<*("H@<W!E8VEF:6,@
M:6YF;W)M871I;VX@86)O=70@26UO9&4@:&%N9'-E=',N"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<B]I;6]D92YP:'`L=B`Q+C<N
M,3(N-2`R,#`V+S`Q+S`Q(#(Q.C(X.C`Y(&IA;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,C`P,"TR,#`V($UI:V$@5'5U<&]L80H@*B!#;W!Y<FEG:'0@,C`P
M,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G
M92!(;W)D95]"<F]W<V5R"B`J+PIC;&%S<R!"<F]W<V5R7VEM;V1E('L*"B`@
M("`O*BH*("`@("`J($1E=FEC92!D871A+B!&<F]M(&AT='`Z+R]W=W<N;G1T
M9&]C;VUO+F-O+FIP+VDO=&%G+W,U+FAT;6PC-5\Q"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]D871A(#T@87)R87DH"B`@
M("`@("`@)T0R,#EI)R`]/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED
M=&@G(#T^(#DV+"`G:6UA9V5H96EG:'0G(#T^(#DP+`H@("`@("`@("`@("`G
M=&5X='=I9'1H)R`]/B`X+"`G=&5X=&AE:6=H="<@/3X@-RP*("`@("`@("`@
M("`@)V-O;&]R)R`]/B`R-38L"B`@("`@("`@("`@("=I;6%G969O<FUA=',G
M(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@("`@)T8R,#EI)R`]
M/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G(#T^(#DV+"`G:6UA
M9V5H96EG:'0G(#T^(#DQ+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`X
M+"`G=&5X=&AE:6=H="<@/3X@-RP*("`@("`@("`@("`@)V-O;&]R)R`]/B`R
M-38L"B`@("`@("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G
M*0H@("`@("`@("DL"B`@("`@("`@)TXR,#EI)R`]/B!A<G)A>2@*("`@("`@
M("`@("`@)VEM86=E=VED=&@G(#T^(#$P."P@)VEM86=E:&5I9VAT)R`]/B`X
M,BP*("`@("`@("`@("`@)W1E>'1W:61T:"<@/3X@.2P@)W1E>'1H96EG:'0G
M(#T^(#8L"B`@("`@("`@("`@("=C;VQO<B<@/3X@)V=R97DG+`H@("`@("`@
M("`@("`G:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*("`@("`@("`I
M+`H@("`@("`@("=0,C`Y:2<@/3X@87)R87DH"B`@("`@("`@("`@("=I;6%G
M97=I9'1H)R`]/B`Y-BP@)VEM86=E:&5I9VAT)R`]/B`X-RP*("`@("`@("`@
M("`@)W1E>'1W:61T:"<@/3X@."P@)W1E>'1H96EG:'0G(#T^(#8L"B`@("`@
M("`@("`@("=C;VQO<B<@/3X@)V=R97DG+`H@("`@("`@("`@("`G:6UA9V5F
M;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*("`@("`@("`I+`H@("`@("`@("=0
M,C`Y:7,G(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:6UA9V5W:61T:"<@/3X@
M.38L("=I;6%G96AE:6=H="<@/3X@.#<L"B`@("`@("`@("`@("=T97AT=VED
M=&@G(#T^(#@L("=T97AT:&5I9VAT)R`]/B`V+`H@("`@("`@("`@("`G8V]L
M;W(G(#T^(#(U-BP*("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@87)R
M87DH)V=I9B<I"B`@("`@("`@*2P*("`@("`@("`G4C(P.6DG(#T^(&%R<F%Y
M*`H@("`@("`@("`@("`G:6UA9V5W:61T:"<@/3X@.38L("=I;6%G96AE:6=H
M="<@/3X@-S(L"B`@("`@("`@("`@("=T97AT=VED=&@G(#T^(#@L("=T97AT
M:&5I9VAT)R`]/B`V+`H@("`@("`@("`@("`G8V]L;W(G(#T^("=G<F5Y)RP*
M("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@
M("`@("`@*2P*("`@("`@("`G15(R,#EI)R`]/B!A<G)A>2@*("`@("`@("`@
M("`@)VEM86=E=VED=&@G(#T^(#$R,"P@)VEM86=E:&5I9VAT)R`]/B`W,BP*
M("`@("`@("`@("`@)W1E>'1W:61T:"<@/3X@,3`L("=T97AT:&5I9VAT)R`]
M/B`V+`H@("`@("`@("`@("`G8V]L;W(G(#T^("=G<F5Y)RP*("`@("`@("`@
M("`@)VEM86=E9F]R;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@*2P*
M("`@("`@("`G2T\R,#EI)R`]/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E
M=VED=&@G(#T^(#DV+"`G:6UA9V5H96EG:'0G(#T^(#DV+`H@("`@("`@("`@
M("`G=&5X='=I9'1H)R`]/B`X+"`G=&5X=&AE:6=H="<@/3X@."P*("`@("`@
M("`@("`@)V-O;&]R)R`]/B`R-38L"B`@("`@("`@("`@("=I;6%G969O<FUA
M=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@("`@)T0R,3!I
M)R`]/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G(#T^(#DV+"`G
M:6UA9V5H96EG:'0G(#T^(#DQ+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]
M/B`X+"`G=&5X=&AE:6=H="<@/3X@-RP*("`@("`@("`@("`@)V-O;&]R)R`]
M/B`R-38L"B`@("`@("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G
M:68G*0H@("`@("`@("DL"B`@("`@("`@)T8R,3!I)R`]/B!A<G)A>2@*("`@
M("`@("`@("`@)VEM86=E=VED=&@G(#T^(#DV+"`G:6UA9V5H96EG:'0G(#T^
M(#$Q,RP*("`@("`@("`@("`@)W1E>'1W:61T:"<@/3X@."P@)W1E>'1H96EG
M:'0G(#T^(#@L"B`@("`@("`@("`@("=C;VQO<B<@/3X@,C4V+`H@("`@("`@
M("`@("`G:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*("`@("`@("`I
M+`H@("`@("`@("=.,C$P:2<@/3X@87)R87DH"B`@("`@("`@("`@("=I;6%G
M97=I9'1H)R`]/B`Q,3@L("=I;6%G96AE:6=H="<@/3X@,3$S+`H@("`@("`@
M("`@("`G=&5X='=I9'1H)R`]/B`Q,"P@)W1E>'1H96EG:'0G(#T^(#@L"B`@
M("`@("`@("`@("=C;VQO<B<@/3X@,C4V+`H@("`@("`@("`@("`G:6UA9V5F
M;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*("`@("`@("`I+`H@("`@("`@("=0
M,C$P:2<@/3X@87)R87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]/B`Y
M-BP@)VEM86=E:&5I9VAT)R`]/B`Y,2P*("`@("`@("`@("`@)W1E>'1W:61T
M:"<@/3X@."P@)W1E>'1H96EG:'0G(#T^(#8L"B`@("`@("`@("`@("=C;VQO
M<B<@/3X@,C4V+`H@("`@("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A<G)A
M>2@G9VEF)RD*("`@("`@("`I+`H@("`@("`@("=+3S(Q,&DG(#T^(&%R<F%Y
M*`H@("`@("`@("`@("`G:6UA9V5W:61T:"<@/3X@.38L("=I;6%G96AE:6=H
M="<@/3X@.38L"B`@("`@("`@("`@("=T97AT=VED=&@G(#T^(#@L("=T97AT
M:&5I9VAT)R`]/B`X+`H@("`@("`@("`@("`G8V]L;W(G(#T^(#(U-BP*("`@
M("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@("`@
M("`@*2P*("`@("`@("`G4T\R,3!I)R`]/B!A<G)A>2@*("`@("`@("`@("`@
M)VEM86=E=VED=&@G(#T^(#$R,"P@)VEM86=E:&5I9VAT)R`]/B`Q,3,L"B`@
M("`@("`@("`@("=T97AT=VED=&@G(#T^(#@L("=T97AT:&5I9VAT)R`]/B`W
M+`H@("`@("`@("`@("`G8V]L;W(G(#T^(#(U-BP*("`@("`@("`@("`@)VEM
M86=E9F]R;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@("`@
M("`G1#4P,6DG(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:6UA9V5W:61T:"<@
M/3X@.38L("=I;6%G96AE:6=H="<@/3X@-S(L"B`@("`@("`@("`@("=T97AT
M=VED=&@G(#T^(#@L("=T97AT:&5I9VAT)R`]/B`V+`H@("`@("`@("`@("`G
M8V]L;W(G(#T^("=B;&%C:R<L"B`@("`@("`@("`@("=I;6%G969O<FUA=',G
M(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@("`@)T8U,#%I)R`]
M/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G(#T^(#$Q,BP@)VEM
M86=E:&5I9VAT)R`]/B`X-"P*("`@("`@("`@("`@)W1E>'1W:61T:"<@/3X@
M."P@)W1E>'1H96EG:'0G(#T^(#8L"B`@("`@("`@("`@("=C;VQO<B<@/3X@
M)V)L86-K)RP*("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@87)R87DH
M)V=I9B<I"B`@("`@("`@*2P*("`@("`@("`G3C4P,6DG(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`G:6UA9V5W:61T:"<@/3X@,3$X+"`G:6UA9V5H96EG:'0G
M(#T^(#$R."P*("`@("`@("`@("`@)W1E>'1W:61T:"<@/3X@,3`L("=T97AT
M:&5I9VAT)R`]/C$P+`H@("`@("`@("`@("`G8V]L;W(G(#T^("=B;&%C:R<L
M"B`@("`@("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@
M("`@("`@("DL"B`@("`@("`@)U`U,#%I)R`]/B!A<G)A>2@*("`@("`@("`@
M("`@)VEM86=E=VED=&@G(#T^(#DV+"`G:6UA9V5H96EG:'0G(#T^(#$R,"P*
M("`@("`@("`@("`@)W1E>'1W:61T:"<@/3X@."P@)W1E>'1H96EG:'0G(#T^
M(#@L"B`@("`@("`@("`@("=C;VQO<B<@/3X@)V)L86-K)RP*("`@("`@("`@
M("`@)VEM86=E9F]R;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@*2P*
M("`@("`@("`G1#4P,FDG(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:6UA9V5W
M:61T:"<@/3X@.38L("=I;6%G96AE:6=H="<@/3X@.3`L"B`@("`@("`@("`@
M("=T97AT=VED=&@G(#T^(#@L("=T97AT:&5I9VAT)R`]/B`W+`H@("`@("`@
M("`@("`G8V]L;W(G(#T^(#(U-BP*("`@("`@("`@("`@)VEM86=E9F]R;6%T
M<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@("`@("`G1C4P,FDG
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:6UA9V5W:61T:"<@/3X@.38L("=I
M;6%G96AE:6=H="<@/3X@.3$L"B`@("`@("`@("`@("=T97AT=VED=&@G(#T^
M(#@L("=T97AT:&5I9VAT)R`]/B`W+`H@("`@("`@("`@("`G8V]L;W(G(#T^
M(#(U-BP*("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@87)R87DH)V=I
M9B<I"B`@("`@("`@*2P*("`@("`@("`G1C4P,FET)R`]/B!A<G)A>2@*("`@
M("`@("`@("`@)VEM86=E=VED=&@G(#T^(#DV+"`G:6UA9V5H96EG:'0G(#T^
M(#DQ+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`X+"`G=&5X=&AE:6=H
M="<@/3X@-RP*("`@("`@("`@("`@)V-O;&]R)R`]/B`R-38L"B`@("`@("`@
M("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@("DL
M"B`@("`@("`@)TXU,#)I)R`]/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E
M=VED=&@G(#T^(#$Q."P@)VEM86=E:&5I9VAT)R`]/B`Q,C@L"B`@("`@("`@
M("`@("=T97AT=VED=&@G(#T^(#$P+"`G=&5X=&AE:6=H="<@/3X@,3`L"B`@
M("`@("`@("`@("=C;VQO<B<@/3X@)V=R97DG+`H@("`@("`@("`@("`G:6UA
M9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*("`@("`@("`I+`H@("`@("`@
M("=.-3`R:70G(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:6UA9V5W:61T:"<@
M/3X@,3$X+"`G:6UA9V5H96EG:'0G(#T^(#$R."P*("`@("`@("`@("`@)W1E
M>'1W:61T:"<@/3X@,3`L("=T97AT:&5I9VAT)R`]/B`Q,"P*("`@("`@("`@
M("`@)V-O;&]R)R`]/B`R-38L"B`@("`@("`@("`@("=I;6%G969O<FUA=',G
M(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@("`@)U`U,#)I)R`]
M/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G(#T^(#DV+"`G:6UA
M9V5H96EG:'1H)R`]/B`Q,3<L"B`@("`@("`@("`@("=T97AT=VED=&@G(#T^
M(#@L("=T97AT:&5I9VAT)R`]/B`X+`H@("`@("`@("`@("`G8V]L;W(G(#T^
M("=G<F5Y)RP*("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@87)R87DH
M)V=I9B<I"B`@("`@("`@*2P*("`@("`@("`G3DTU,#)I)R`]/B!A<G)A>2@*
M("`@("`@("`@("`@)VEM86=E=VED=&@G(#T^(#$Q,2P@)VEM86=E:&5I9VAT
M)R`]/B`W-RP*("`@("`@("`@("`@)W1E>'1W:61T:"<@/3X@."P@)W1E>'1H
M96EG:'0G(#T^(#8L"B`@("`@("`@("`@("=C;VQO<B<@/3X@)V)L86-K)RP*
M("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@
M("`@("`@*2P*("`@("`@("`G4T\U,#)I)R`]/B!A<G)A>2@*("`@("`@("`@
M("`@)VEM86=E=VED=&@G(#T^(#$R,"P@)VEM86=E:&5I9VAT)R`]/B`Q,C`L
M"B`@("`@("`@("`@("=T97AT=VED=&@G(#T^(#@L("=T97AT:&5I9VAT)R`]
M/B`X+`H@("`@("`@("`@("`G8V]L;W(G(#T^("=G<F5Y)RP*("`@("`@("`@
M("`@)VEM86=E9F]R;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@*2P*
M("`@("`@("`G4T\U,#)I=VTG(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:6UA
M9V5W:61T:"<@/3X@,3(P+"`G:6UA9V5H96EG:'0G(#T^(#$Q,RP*("`@("`@
M("`@("`@)W1E>'1W:61T:"<@/3X@."P@)W1E>'1H96EG:'0G(#T^(#<L"B`@
M("`@("`@("`@("=C;VQO<B<@/3X@,C4V+`H@("`@("`@("`@("`G:6UA9V5F
M;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*("`@("`@("`I+`H@("`@("`@("=&
M-3`S:2<@/3X@87)R87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]/B`Q
M,C`L("=I;6%G96AE:6=H="<@/3X@,3,P+`H@("`@("`@("`@("`G=&5X='=I
M9'1H)R`]/B`Q,"P@)W1E>'1H96EG:'0G(#T^(#$P+`H@("`@("`@("`@("`G
M8V]L;W(G(#T^(#(U-BP*("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@
M87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@("`@("`G1C4P,VE3)R`]/B!A
M<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G(#T^(#$R,"P@)VEM86=E
M:&5I9VAT)R`]/B`Q,S`L"B`@("`@("`@("`@("=T97AT=VED=&@G(#T^(#$R
M+"`G=&5X=&AE:6=H="<@/3X@,3(L"B`@("`@("`@("`@("=C;VQO<B<@/3X@
M-#`Y-BP*("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@87)R87DH)V=I
M9B<I"B`@("`@("`@*2P*("`@("`@("`G4#4P,VDG(#T^(&%R<F%Y*`H@("`@
M("`@("`@("`G:6UA9V5W:61T:"<@/3X@,3(P+"`G:6UA9V5H96EG:'0G(#T^
M(#$S,"P*("`@("`@("`@("`@)W1E>'1W:61T:"<@/3X@,3(L("=T97AT:&5I
M9VAT)R`]/B`Q,"P*("`@("`@("`@("`@)V-O;&]R)R`]/B`R-38L"B`@("`@
M("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@
M("DL"B`@("`@("`@)U`U,#-I4R<@/3X@87)R87DH"B`@("`@("`@("`@("=I
M;6%G97=I9'1H)R`]/B`Q,C`L("=I;6%G96AE:6=H="<@/3X@,3,P+`H@("`@
M("`@("`@("`G=&5X='=I9'1H)R`]/B`Q,BP@)W1E>'1H96EG:'0G(#T^(#$P
M+`H@("`@("`@("`@("`G8V]L;W(G(#T^(#(U-BP*("`@("`@("`@("`@)VEM
M86=E9F]R;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@("`@
M("`G4T\U,#-I)R`]/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G
M(#T^(#$R,"P@)VEM86=E:&5I9VAT)R`]/B`Q,3,L"B`@("`@("`@("`@("=T
M97AT=VED=&@G(#T^(#@N-2P@)W1E>'1H96EG:'0G(#T^(#<L"B`@("`@("`@
M("`@("=C;VQO<B<@/3X@-C4U,S8L"B`@("`@("`@("`@("=I;6%G969O<FUA
M=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@("`@)T0U,#-I
M)R`]/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G(#T^(#$S,BP@
M)VEM86=E:&5I9VAT)R`]/B`Q,C8L"B`@("`@("`@("`@("=T97AT=VED=&@G
M(#T^(#@L("=T97AT:&5I9VAT)R`]/B`W+`H@("`@("`@("`@("`G8V]L;W(G
M(#T^(#0P.38L"B`@("`@("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y
M*"=G:68G*0H@("`@("`@("DL"B`@("`@("`@)TXU,#-I)R`]/B!A<G)A>2@*
M("`@("`@("`@("`@)VEM86=E=VED=&@G(#T^(#$Q."P@)VEM86=E:&5I9VAT
M)R`]/B`Q,C@L"B`@("`@("`@("`@("=T97AT=VED=&@G(#T^(#$P+"`G=&5X
M=&AE:6=H="<@/3X@,3`L"B`@("`@("`@("`@("=C;VQO<B<@/3X@-#`Y-BP*
M("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@87)R87DH)V=I9B<L("=J
M<&<G*0H@("`@("`@("DL"B`@("`@("`@)TXU,#-I4R<@/3X@87)R87DH"B`@
M("`@("`@("`@("=I;6%G97=I9'1H)R`]/B`Q,3@L("=I;6%G96AE:6=H="<@
M/3X@,3(X+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`Q,"P@)W1E>'1H
M96EG:'0G(#T^(#$P+`H@("`@("`@("`@("`G8V]L;W(G(#T^(#0P.38L"B`@
M("`@("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G+"`G:G!G
M)RD*("`@("`@("`I+`H@("`@("`@("=.-CDQ:2<@/3X@87)R87DH"B`@("`@
M("`@("`@("=I;6%G97=I9'1H)R`]/B`Y-BP@)VEM86=E:&5I9VAT)R`]/B`W
M,BP*("`@("`@("`@("`@)W1E>'1W:61T:"<@/3X@."P@)W1E>'1H96EG:'0G
M(#T^(#8L"B`@("`@("`@("`@("=C;VQO<B<@/3X@)V=R97DG+`H@("`@("`@
M("`@("`G:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*("`@("`@("`I
M+`H@("`@("`@("=32#@R,6DG(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:6UA
M9V5W:61T:"<@/3X@.38L("=I;6%G96AE:6=H="<@/3X@-S@L"B`@("`@("`@
M("`@("=T97AT=VED=&@G(#T^(#@L("=T97AT:&5I9VAT)R`]/B`V+`H@("`@
M("`@("`@("`G8V]L;W(G(#T^(#(U-BP*("`@("`@("`@("`@)VEM86=E9F]R
M;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@("`@("`G3C@R
M,6DG(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:6UA9V5W:61T:"<@/3X@,3$X
M+"`G:6UA9V5H96EG:'0G(#T^(#$R."P*("`@("`@("`@("`@)W1E>'1W:61T
M:"<@/3X@,3`L("=T97AT:&5I9VAT)R`]/B`Q,"P*("`@("`@("`@("`@)V-O
M;&]R)R`]/B`G9W)E>2<L"B`@("`@("`@("`@("=I;6%G969O<FUA=',G(#T^
M(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@("`@)U`X,C%I)R`]/B!A
M<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G(#T^(#$Q."P@)VEM86=E
M:&5I9VAT)R`]/B`Q,C@L"B`@("`@("`@("`@("=T97AT=VED=&@G(#T^(#$P
M+"`G=&5X=&AE:6=H="<@/3X@,3`L"B`@("`@("`@("`@("=C;VQO<B<@/3X@
M)V=R97DG+`H@("`@("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G
M9VEF)RD*("`@("`@("`I+`H@("`@("`@("=S869E)R`]/B!A<G)A>2@*("`@
M("`@("`@("`@)VEM86=E=VED=&@G(#T^(#DT+"`G:6UA9V5H96EG:'0G(#T^
M(#<R+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`X+"`G=&5X=&AE:6=H
M="<@/3X@-BP*("`@("`@("`@("`@)V-O;&]R)R`]/B`G8FQA8VLG+`H@("`@
M("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*("`@("`@
M("`I"B`@("`I.PH*("`@('9A<B`D7VUA;G5F86-T=7)E<FQI<W0@/2!A<G)A
M>2@*("`@("`@("`G1"<@/3X@)TUI='-U8FES:&DG+`H@("`@("`@("=0)R`]
M/B`G4&%N87-O;FEC("A-871S=7-H:71A*2<L"B`@("`@("`@)TY-)R`]/B`G
M3F]K:6$G+`H@("`@("`@("=33R<@/3X@)U-O;GDG+`H@("`@("`@("=&)R`]
M/B`G1G5J:71S=2<L"B`@("`@("`@)TXG(#T^("=.96,G+`H@("`@("`@("=3
M2"<@/3X@)U-H87)P)RP*("`@("`@("`G15(G(#T^("=%<FEC<W-O;B<L"B`@
M("`@("`@)U(G(#T^("=*87!A;B!2861I;R<L"B`@("`@("`@)TM/)R`]/B`G
M2V]K=7-A:2`H2&ET86-H:2DG"B`@("`I.PH*("`@('9A<B`D7V5X=')A(#T@
M87)R87DH"B`@("`@("`@)W0G(#T^("=4<F%N<W!O<G0@;&%Y97(G+`H@("`@
M("`@("=E)R`]/B`G16YG;&ES:"!L86YG=6%G92<L"B`@("`@("`@)W,G(#T^
M("=396-O;F0@=F5R<VEO;B<*("`@("D["@H@("`@=F%R("1?=7-E<E]A9V5N
M=#L*("`@('9A<B`D7VUO9&5L.PH@("`@=F%R("1?;6%N=69A8W1U<F5R.PH@
M("`@=F%R("1?:'1T<'9E<G-I;VX["B`@("!V87(@)%]C86-H92`](#4["@H@
M("`@+RHJ"B`@("`@*B!$;V5S(&YO="!H86YD;&4@8F]G=7,@=7-E<E]A9V5N
M=',@;W(@;6]S="!O9B!T:&4@;W1H97(@97)R;W(*("`@("`J('-I='5A=&EO
M;B!P<F]P97)L>2!Y970N"B`@("`@*@H@("`@("H@17AA;7!L92!U<V%G93H*
M("`@("`J("`@)'5A(#T@)FYE=R!"<F]W<V5R7VEM;V1E*"1?4T525D5R6R=(
M5%107U5315)?04=%3E0G72D["B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D:6YP=70@(%1H92!U<V5R(&%G96YT('1O(&UA=&-H+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!"<F]W<V5R7VEM;V1E*"1I;G!U="D*("`@('L*("`@("`@
M("`D7V5R<F]R(#T@,#L*("`@("`@("`D=&5M<"`](&5X<&QO9&4H)R\G+"`D
M:6YP=70I.PH*("`@("`@("`D=&AI<RT^7W5S97)?86=E;G0@/2`D:6YP=70[
M"B`@("`@("`@)'1H:7,M/E]H='1P=F5R<VEO;B`]("1T96UP6S%=.PH@("`@
M("`@("1T:&ES+3Y?;6]D96P@/2`D=&5M<%LR73L*("`@("`@("!I9B`H)'1E
M;7!;,UTI('L*("`@("`@("`@("`@)'1H:7,M/E]C86-H92`]('-U8G-T<B@D
M=&5M<%LS72P@,2D["B`@("`@("`@?0H*("`@("`@("!P<F5G7VUA=&-H*"<O
M*%Y;82UZ02U:72LI*%LP+3E=*VDI*"XJ*5PO/R@N*BDO)RP@)'1H:7,M/E]M
M;V1E;"P@)&UA=&-H97,I.PH*("`@("`@("`O+R!`5$]$3SH@1FEX('-I='5A
M=&EO;B!O9B!U;FMN;W=N(&UA;G5F86-T=7)E<BX@26UP;&5M96YT"B`@("`@
M("`@+R\@97AT<F%I;F9O('!R;W!E<FQY+@H@("`@("`@("1T:&ES+3Y?;6%N
M=69A8W1U<F5R(#T@)'1H:7,M/E]M86YU9F%C='5R97)L:7-T6R1M871C:&5S
M6S%=73L*("`@("`@("`D=&AI<RT^7V5X=')A(#T@)&UA=&-H97-;,UT["@H@
M("`@("`@(&EF("@A*"1T:&ES+3Y?9&%T85LD=&AI<RT^7VUO9&5L72DI('L*
M("`@("`@("`@("`@)%]E<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H)U5N:VYO
M=VX@57-E<B!!9V5N="<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($5X86UP;&4@=7-A9V4Z"B`@("`@*B`@)&EM86=E9&EM("`@(#T@)'5A
M+3YG971);6%G941I;65N<VEO;G,H*3L*("`@("`J("`D:6UA9V5W:61T:"`@
M/2`D:6UA9V5D:6U;,%T["B`@("`@*B`@)&EM86=E:&5I9VAT(#T@)&EM86=E
M9&EM6S%=.PH@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!M87AI
M;75M(&EM86=E=VED=&@@86YD(&EM86=E:&5I9VAT('1H870*("`@("`J("`@
M("`@("`@("`@("`@(&9I="!O;B!T:&4@:&%N9'-E="!S8W)E96X@=VET:&]U
M="!S8W)O;&QI;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$EM86=E1&EM
M96YS:6]N<R@I"B`@("!["B`@("`@("`@)&1A=&$@/2`D=&AI<RT^7V1A=&%;
M)'1H:7,M/E]M;V1E;%T["B`@("`@("`@<F5T=7)N(&%R<F%Y*"1D871A6R=I
M;6%G97=I9'1H)UTL("1D871A6R=I;6%G96AE:6=H="==*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($5X86UP;&4@=7-A9V4Z"B`@("`@*B`@)'1E>'1D:6T@
M("`@/2`D=6$M/F=E=%1E>'1$:6UE;G-I;VYS*"D["B`@("`@*B`@)'1E>'1W
M:61T:"`@/2`D=&5X=&1I;5LP73L*("`@("`J("`D=&5X=&AE:6=H="`]("1T
M97AT9&EM6S%=.PH@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!-
M87AI;75M('1E>'1W:61T:"!A;F0@=&5X=&AE:6=H="!T:&%T"B`@("`@*B`@
M("`@("`@("`@("`@("!F:70@;VX@=&AE(&AA;F1S970@<V-R965N('=I=&AO
M=70@<V-R;VQL:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971497AT1&EM
M96YS:6]N<R@I"B`@("!["B`@("`@("`@<F5T=7)N(&%R<F%Y*"1T:&ES+3Y?
M9&%T85LD=&AI<RT^7VUO9&5L75LG=&5X='=I9'1H)UTL"B`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?9&%T85LD=&AI<RT^7VUO9&5L75LG=&5X=&AE
M:6=H="==*3L*("`@('T*"B`@("`O*BH*("`@("`J($!R971U<FX@:6YT96=E
M<B`@5&AE(&%M;W5N="!O9B!H86YD<V5T(&-A8VAE(&EN(&MI;&]B>71E<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0V%C:&4H*0H@("`@>PH@("`@("`@
M(')E='5R;B`H:6YT*21T:&ES+3Y?8V%C:&4["B`@("!]"@H@("`@9G5N8W1I
M;VX@9V5T36%N=69A8W1U<F5R*"D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]M86YU9F%C='5R97(["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T17AT
M<F$H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V5X=')A.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&=E=$EM86=E1F]R;6%T<R@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?9&%T85LD=&AI<RT^7VUO9&5L75LG:6UA9V5F
M;W)M871S)UT["B`@("!]"@H@("`@+RHJ"B`@("`@*B!`<F5T=7)N(&EN=&5G
M97(@(%=H:6-H(&-O;&]R(&UO9&5L('1H92!H86YD<V5T('-U<'!O<G1S+@H@
M("`@("H@("!686QU97,@:&%V92!T:&4@9F]L;&]W:6YG(&UE86YI;F<Z"B`@
M("`@*B`@("`@,"`M/B!B;&%C:R!A;F0@=VAI=&4*("`@("`J("`@("`Q("T^
M(#0@=&]N92!G<F5Y<V-A;&4*("`@("`J("`@("`R("T^(#(U-B!C;VQO<@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971#;VQO<B@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?9&%T85LD=&AI<RT^7VUO9&5L75LG8V]L;W(G73L*
M("`@('T*"B`@("!F=6YC=&EO;B!G971(5%105F5R<VEO;B@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?:'1T<'9E<G-I;VX["B`@("!]"@H@("`@
M9G5N8W1I;VX@:7-#;VQO<B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?9&%T85LD=&AI<RT^7VUO9&5L75LG8V]L;W(G72`]/2`R-38["B`@("!]
M"@H@("`@9G5N8W1I;VX@:7-'<F5Y4V-A;&4H*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7V1A=&%;)'1H:7,M/E]M;V1E;%U;)V-O;&]R)UT@/3T@
M)V=R97DG.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES0FQA8VM!;F17:&ET92@I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&%T85LD=&AI<RT^7VUO
M9&5L75LG8V]L;W(G72`]/2`G8FQA8VLG.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T5D:71O<@``````````````
M````````````````````````````````````````````````````````````
M`````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U
M-#,S-S,W(#`R,#4R,0`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M161I=&]R+VAT;6QA<F5A+G!H<```````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#8V,S`@,3`U,34T,S,W,S<@,#(S,3$S`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@
M161I=&]R7VAT;6QA<F5A.CH@8VQA<W,@<')O=FED97,@86X@5UE325=91R!E
M9&ET;W(@9F]R('5S90H@*B!I;B!T:&4@2&]R9&4@1G)A;65W;W)K+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]%9&ET;W(O161I=&]R+VAT;6QA<F5A+G!H
M<"QV(#$N,C0N-"XT(#(P,#8O,#$O,#$@,C$Z,C@Z,30@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@3G5N;R!,;W5R96ER;R`\;G5N;T!C
M;RYS87!O+G!T/@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($IA;B!38VAN96ED
M97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!.=6YO($QO=7)E:7)O(#QN=6YO0&-O+G-A<&\N<'0^"B`J($!A=71H;W(@
M($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO
M<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]%9&ET;W(*("HO"F-L87-S($AO
M<F1E7T5D:71O<E]H=&UL87)E82!E>'1E;F1S($AO<F1E7T5D:71O<B!["@H@
M("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX@26YC;'5D92!T:&4@;F5C97-S
M87)Y(&IA=F%S8W)I<'0@9FEL97,N"B`@("`@*B\*("`@(&9U;F-T:6]N($AO
M<F1E7T5D:71O<E]H=&UL87)E82@D<&%R86US(#T@87)R87DH*2D*("`@('L*
M("`@("`@("!G;&]B86P@)')E9VES=')Y+"`D;F]T:69I8V%T:6]N+"`D<')E
M9G,["@H@("`@("`@($AO<F1E.CIA9&138W)I<'1&:6QE*"=H=&UL87)E82YJ
M<R<L("=H;W)D92<I.PH@("`@("`@($AO<F1E.CIA9&138W)I<'1&:6QE*"<O
M<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VAT;6QA<F5A+FIS)RP@)VAO<F1E
M)RP@=')U92D["B`@("`@("`@)'-C<FEP="`]($AO<F1E.CIU<FPH571I;#HZ
M861D4&%R86UE=&5R*"1R96=I<W1R>2T^9V5T*"=W96)R;V]T)RP@)VAO<F1E
M)RD@+B`G+W-E<G9I8V5S+VIA=F%S8W)I<'0N<&AP)RP@)V%P<"<L("=H;W)D
M92<I+"!T<G5E*3L*("`@("`@("`D:G,@/2`G2%1-3$%R96$N;&]A9%-C<FEP
M="@B)R`N(%5T:6PZ.F%D9%!A<F%M971E<B@D<V-R:7!T+"`G9FEL92<L("`G
M:'1M;&%R96%?;&%N9RYJ<R<L(&9A;'-E*2`N("<B*3L@)SL*"B`@("`@("`@
M)'!L=6=I;G,@/2`G)SL*("`@("`@("!I9B`H)'!R969S+3YG971686QU92@G
M=&%B;&5O<&5R871I;VYS)RDI('L*("`@("`@("`@("`@)&IS("X]("=(5$U,
M07)E82YL;V%D4&QU9VEN*")486)L94]P97)A=&EO;G,B*3L@)R`N"B`@("`@
M("`@("`@("`@("`@("`G2%1-3$%R96$N;&]A9%-C<FEP="@B)R`N(%5T:6PZ
M.F%D9%!A<F%M971E<B@D<V-R:7!T+"`G9FEL92<L("`G:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<R<L(&9A;'-E*2`N("<B*3L@)SL*("`@("`@("`@("`@)'!L
M=6=I;G,@+CT@)V5D:71O<BYR96=I<W1E<E!L=6=I;BA486)L94]P97)A=&EO
M;G,I.R`G.PH@("`@("`@('T*("`@("`@("!I9B`H)'!R969S+3YG971686QU
M92@G8V]N=&5X=&UE;G4G*2D@>PH@("`@("`@("`@("`D:G,@+CT@)TA434Q!
M<F5A+FQO8610;'5G:6XH(D-O;G1E>'1-96YU(BD[("<@+@H@("`@("`@("`@
M("`@("`@("`@)TA434Q!<F5A+FQO86138W)I<'0H(B<@+B!5=&EL.CIA9&10
M87)A;65T97(H)'-C<FEP="P@)V9I;&4G+"`@)VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<R<L(&9A;'-E*2`N("<B*3L@)SL*("`@("`@("`@("`@)'!L=6=I
M;G,@+CT@)V5D:71O<BYR96=I<W1E<E!L=6=I;BA#;VYT97AT365N=2D[("<[
M"B`@("`@("`@?0H@("`@("`@(&EF("@D<')E9G,M/F=E=%9A;'5E*"=L:7-T
M='EP92<I*2!["B`@("`@("`@("`@("1J<R`N/2`G2%1-3$%R96$N;&]A9%!L
M=6=I;B@B3&ES=%1Y<&4B*3L@)R`N"B`@("`@("`@("`@("`@("`@("`G2%1-
M3$%R96$N;&]A9%-C<FEP="@B)R`N(%5T:6PZ.F%D9%!A<F%M971E<B@D<V-R
M:7!T+"`G9FEL92<L("`G:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<R<L(&9A
M;'-E*2`N("<B*3L@)SL*("`@("`@("`@("`@)'!L=6=I;G,@+CT@)V5D:71O
M<BYR96=I<W1E<E!L=6=I;BA,:7-T5'EP92D[("<["B`@("`@("`@?0H@("`@
M("`@(&EF("@D<')E9G,M/F=E=%9A;'5E*"=A;G-E;&EM86=E)RD@)B8@)')E
M9VES=')Y+3YH87--971H;V0H)VEM86=E<R]L:7-T1V%L;&5R:65S)RDI('L*
M("`@("`@("`@("`@)&IS("X]("=(5$U,07)E82YL;V%D4&QU9VEN*")!;G-E
M;$EM86=E(BD[("<@+@H@("`@("`@("`@("`@("`@("`@)TA434Q!<F5A+FQO
M86138W)I<'0H(B<@+B!5=&EL.CIA9&1087)A;65T97(H)'-C<FEP="P@)V9I
M;&4G+"`@)VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<R<L(&9A;'-E*2`N
M("<B*3L@)SL*("`@("`@("`@("`@)'!L=6=I;G,@+CT@)V5D:71O<BYR96=I
M<W1E<E!L=6=I;BA!;G-E;$EM86=E*3L@)SL*("`@("`@("!]"@H@("`@("`@
M("1J<R`N/2`G2%1-3$%R96$N;VYL;V%D(#T@9G5N8W1I;VXH*2![("<@+@H@
M("`@("`@("`@("`@("`G=F%R(&-O;F9I9R`](&YE=R!(5$U,07)E82Y#;VYF
M:6<H*2`[)R`N"B`@("`@("`@("`@("`@("=C;VYF:6<N9&5B=6<@/2!F86QS
M93L@)R`N"B`@("`@("`@("`@("`@("=C;VYF:6<N:&ED95-O;65"=71T;VYS
M*"(@<VAO=VAE;'`@(BD[("<["B`@("`@("`@:68@*&ES<V5T*"1P87)A;7-;
M)V-O;F9I9R==*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D<&%R86US6R=C
M;VYF:6<G72!A<R`D8V]N9FEG(#T^("1V86QU92D@>PH@("`@("`@("`@("`@
M("`@)&IS("X]("=C;VYF:6<N)R`N("1C;VYF:6<@+B`G(#T@(B<@+B!A9&1S
M;&%S:&5S*"1V86QU92D@+B`G(CLG.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG:60G72DI('L*("`@("`@
M("`@("`@)&IS("X]("=V87(@=&5X=&%R96%S(#T@6V1O8W5M96YT+F=E=$5L
M96UE;G1">4ED*"(G("X@)'!A<F%M<ULG:60G72`N("<B*5T[("<["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&IS("X]("=V87(@=&5X=&%R96%S
M(#T@9&]C=6UE;G0N9V5T16QE;65N='-">51A9TYA;64H(G1E>'1A<F5A(BD[
M("<["B`@("`@("`@?0H@("`@("`@("1J<R`N/2`G9F]R("AV87(@:2`]('1E
M>'1A<F5A<RYL96YG=&@@+2`Q.R!I(#X](#`[(&DM+2D@>R`G("X*("`@("`@
M("`@("`@("`@)W9A<B!E9&ET;W(@/2!N97<@2%1-3$%R96$H=&5X=&%R96%S
M6VE=+"!C;VYF:6<I.R`G("X*("`@("`@("`@("`@("`@)'!L=6=I;G,@+@H@
M("`@("`@("`@("`@("`G961I=&]R+F=E;F5R871E*"E]?3L@)R`N"B`@("`@
M("`@("`@("`@("=(5$U,07)E82YI;FET*"D[)SL*"B`@("`@("`@)&YO=&EF
M:6-A=&EO;BT^<'5S:"@D:G,L("=J879A<V-R:7!T)RD["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+T-A8VAE````````````````````````````````````````````````````
M`````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S,W(#`R,#(W-@`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O0V%C:&4O9FEL92YP:'``````````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,30Q-3<@,3`U,34T,S,W,S<@,#(R
M,#$U`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B!4:&4@2&]R9&5?0V%C:&5?9FEL93HZ(&-L87-S('!R
M;W9I9&5S(&$@9FEL97-Y<W1E;2!I;7!L96UE;G1A=&EO;B!O9B!T:&4*("H@
M2&]R9&4@8V%C:&EN9R!S>7-T96TN"B`J"B`J($]P=&EO;F%L('!A<F%M971E
M<G,Z/'!R93X*("H@("`G9&ER)R`@("`@5&AE(&1I<F5C=&]R>2!T;R!S=&]R
M92!T:&4@8V%C:&4@9FEL97,@:6XN"B`J("`@)W!R969I>"<@(%1H92!F:6QE
M;F%M92!P<F5F:7@@=&\@=7-E(&9O<B!T:&4@8V%C:&4@9FEL97,N/"]P<F4^
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T-A8VAE+T-A8VAE+V9I;&4N<&AP
M+'8@,2XR."XQ,"XY(#(P,#8O,#$O,#$@,C$Z,C@Z,3`@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@06YI;"!-861H879A<&5D9'D@/&%N
M:6Q`<F5C;VEL+F]R9SX*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(
M86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^
M"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?0V%C
M:&4*("HO"F-L87-S($AO<F1E7T-A8VAE7V9I;&4@97AT96YD<R!(;W)D95]#
M86-H92!["@H@("`@+RHJ"B`@("`@*B!4:&4@;&]C871I;VX@;V8@=&AE('1E
M;7`@9&ER96-T;W)Y+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B\*("`@('9A<B`D7V1I<CL*"B`@("`O*BH*("`@("`J(%1H92!F:6QE;F%M
M92!P<F5F:7@@9F]R(&-A8VAE(&9I;&5S+@H@("`@("H*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W!R969I>"`]("=C86-H95\G.PH*
M("`@("\J*@H@("`@("H@0V]N<W1R=6-T(&$@;F5W($AO<F1E7T-A8VAE7V9I
M;&4@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US
M("!087)A;65T97(@87)R87DN"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E
M7T-A8VAE7V9I;&4H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M:68@*"%E;7!T>2@D<&%R86US6R=D:7(G72D@)B8@0&ES7V1I<B@D<&%R86US
M6R=D:7(G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]D:7(@/2`D<&%R86US
M6R=D:7(G73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+U5T:6PN<&AP)SL*("`@("`@("`@("`@)'1H:7,M/E]D
M:7(@/2!5=&EL.CIG971496UP1&ER*"D["B`@("`@("`@?0H*("`@("`@("!I
M9B`H:7-S970H)'!A<F%M<ULG<')E9FEX)UTI*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?<')E9FEX(#T@)'!A<F%M<ULG<')E9FEX)UT["B`@("`@("`@?0H*
M("`@("`@("!P87)E;G0Z.DAO<F1E7T-A8VAE*"1P87)A;7,I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T<FEE=F4@8V%C:&5D(&1A
M=&$@9G)O;2!T:&4@9FEL97-Y<W1E;2!A;F0@<F5T=7)N(&ET('1O"B`@("`@
M*B!T:&4@8V%L;&5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1K
M97D@("`@("`@0V%C:&4@:V5Y('1O(&9E=&-H+@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)&QI9F5T:6UE("!,:69E=&EM92!O9B!T:&4@9&%T82!I;B!S96-O
M;F1S+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@($-A8VAE9"!D871A
M+"!O<B!F86QS92!I9B!N;VYE('=A<R!F;W5N9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T*"1K97DL("1L:69E=&EM92`](#$I"B`@("!["B`@("`@("`@
M:68@*"1T:&ES+3YE>&ES=',H)&ME>2P@)&QI9F5T:6UE*2D@>PH@("`@("`@
M("`@("`D9FEL96YA;64@/2`D=&AI<RT^7VME>51O1FEL92@D:V5Y*3L*("`@
M("`@("`@("`@)'-I>F4@/2!F:6QE<VEZ92@D9FEL96YA;64I.PH@("`@("`@
M("`@("!I9B`H(21S:7IE*2!["B`@("`@("`@("`@("`@("!R971U<FX@)R<[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&1A=&$@/2!F:6QE7V=E=%]C
M;VYT96YT<R@D9FEL96YA;64I.PH@("`@("`@("`@("!I9B`H)&1A=&$@(3T]
M(&9A;'-E*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&1A=&$["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J($YO=&AI;F<@8V%C:&5D
M+"!R971U<FX@9F%I;'5R92X@*B\*("`@("`@("!R971U<FX@9F%L<V4["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!S=&]R92!D871A('1O
M('1H92!F:6QE<WES=&5M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&ME>2`@($-A8VAE(&ME>2X*("`@("`J($!P87)A;2!M:7AE9"`@)&1A=&$@
M($1A=&$@=&\@<W1O<F4@:6X@=&AE(&-A8VAE+@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S970H)&ME>2P@)&1A=&$I"B`@
M("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]5=&EL+G!H<"<["B`@
M("`@("`@)&9I;&5N86UE(#T@)'1H:7,M/E]K97E4;T9I;&4H)&ME>2D["B`@
M("`@("`@)'1M<%]F:6QE(#T@571I;#HZ9V5T5&5M<$9I;&4H)TAO<F1E0V%C
M:&4G+"!T<G5E+"`D=&AI<RT^7V1I<BD["@H@("`@("`@(&EF("@D9F0@/2!F
M;W!E;B@D=&UP7V9I;&4L("=W)RDI('L*("`@("`@("`@("`@:68@*&9W<FET
M92@D9F0L("1D871A*2`\('-T<FQE;B@D9&%T82DI('L*("`@("`@("`@("`@
M("`@(&9C;&]S92@D9F0I.PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@9F-L;W-E
M*"1F9"D["B`@("`@("`@("`@("`@("!`<F5N86UE*"1T;7!?9FEL92P@)&9I
M;&5N86UE*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($%T=&5M<'1S('1O(&1I<F5C=&QY(&]U='!U="!C86-H960@
M9&%T82!F<F]M('1H92!F:6QE<WES=&5M+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@("1K97D@("`@("`@0V%C:&4@:V5Y('1O(&]U='!U="X*("`@
M("`J($!P87)A;2!I;G1E9V5R("1L:69E=&EM92`@3&EF971I;64@;V8@=&AE
M(&1A=&$@:6X@<V5C;VYD<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!#86-H960@9&%T82P@;W(@9F%L<V4@:68@;F]N92!W87,@9F]U;F0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&]U='!U="@D:V5Y+"`D;&EF971I;64@/2`Q
M*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^97AI<W1S*"1K97DL("1L:69E
M=&EM92DI('L*("`@("`@("`@("`@)&9I;&5N86UE(#T@)'1H:7,M/E]K97E4
M;T9I;&4H)&ME>2D["B`@("`@("`@("`@("1F9"`]($!F;W!E;B@D9FEL96YA
M;64L("=R)RD["B`@("`@("`@("`@(&EF("@D9F0I('L*("`@("`@("`@("`@
M("`@(&9P87-S=&AR=2@D9F0I.PH@("`@("`@("`@("`@("`@<F5T=7)N('1R
M=64["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J($YO=&AI
M;F<@8V%C:&5D+"!R971U<FX@9F%I;'5R92X@*B\*("`@("`@("!R971U<FX@
M9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@:68@82!G:79E
M;B!K97D@97AI<W1S(&EN('1H92!C86-H92P@=F%L:60@9F]R('1H92!G:79E
M;@H@("`@("H@;&EF971I;64N($EF(&ET(&5X:7-T<R!B=70@:7,@97AP:7)E
M9"P@9&5L971E('1H92!F:6QE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@("1K97D@("`@("`@0V%C:&4@:V5Y('1O(&-H96-K+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&QI9F5T:6UE("!,:69E=&EM92!O9B!T:&4@:V5Y(&EN
M('-E8V]N9',N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!%>&ES
M=&%N8V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X:7-T<R@D:V5Y+"`D;&EF
M971I;64@/2`Q*0H@("`@>PH@("`@("`@("1F:6QE;F%M92`]("1T:&ES+3Y?
M:V5Y5&]&:6QE*"1K97DI.PH*("`@("`@("`O*B!+97D@97AI<W1S(&EN('1H
M92!C86-H92`J+PH@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D9FEL96YA;64I
M*2!["B`@("`@("`@("`@("\J(#`@;65A;G,@;F\@97AP:7)E+B`J+PH@("`@
M("`@("`@("!I9B`H)&QI9F5T:6UE(#T](#`I('L*("`@("`@("`@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!)
M9B!T:&4@9FEL92!W87,@8F5E;B!C<F5A=&5D(&%F=&5R('1H92!S=7!P;&EE
M9"!V86QU92P*("`@("`@("`@("`@("H@=&AE(&1A=&$@:7,@=F%L:60@*&9R
M97-H*2X@*B\*("`@("`@("`@("`@:68@*'1I;64H*2`M("1L:69E=&EM92`\
M/2!F:6QE;71I;64H)&9I;&5N86UE*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N('1R=64["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("!`=6YL:6YK*"1F:6QE;F%M92D["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J
M($5X<&ER92!A;GD@97AI<W1I;F<@9&%T82!F;W(@=&AE(&=I=F5N(&ME>2X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1K97D@($-A8VAE(&ME>2!T
M;R!E>'!I<F4N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!3=6-C
M97-S(&]R(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X<&ER92@D
M:V5Y*0H@("`@>PH@("`@("`@("1F:6QE;F%M92`]("1T:&ES+3Y?:V5Y5&]&
M:6QE*"1K97DI.PH@("`@("`@(')E='5R;B!`=6YL:6YK*"1F:6QE;F%M92D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!-87`@82!C86-H92!K97D@=&\@82!U
M;FEQ=64@9FEL96YA;64N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("!#86-H92!K97DN
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($9U;&QY('%U86QI9FEE
M9"!F:6QE;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@7VME>51O1FEL92@D
M:V5Y*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V1I<B`N("<O)R`N
M("1T:&ES+3Y?<')E9FEX("X@;60U*"1K97DI.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1&\@86YY(&=A<F)A9V4@8V]L;&5C=&EO;B!N965D960@9F]R('1H
M92!D<FEV97(N"B`@("`@*@H@("`@("H@0'!R:79A=&4*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D<V5C<R`@5&AE(&UI;FEM=6T@86UO=6YT(&]F
M('1I;64@*&EN('-E8V]N9',I(')E<75I<F5D"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@8F5F;W)E(&$@8V%C:&4@:71E;2!I<R!R96UO=F5D+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?9&]'0R@D<V5C<RD*("`@('L*("`@("`@
M("`D9FEL96YA;64@/2`D=&AI<RT^7V1I<B`N("<O:&]R9&5?8V%C:&5?9V,G
M.PH@("`@("`@("1G8U]T:6UE(#T@=&EM92@I("T@)'-E8W,["B`@("`@("`@
M:68@*&9I;&5?97AI<W1S*"1F:6QE;F%M92DI('L*("`@("`@("`@("`@)&]L
M9%]T:6UE(#T@9FEL95]G971?8V]N=&5N=',H)&9I;&5N86UE*3L*("`@("`@
M("`@("`@:68@*"@D;VQD7W1I;64@(3T](&9A;'-E*2`F)@H@("`@("`@("`@
M("`@("`@*"1G8U]T:6UE(#X@)&]L9%]T:6UE*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D
M9"`](&1I<B@D=&AI<RT^7V1I<BD["B`@("`@("`@=VAI;&4@*"@D96YT<GD@
M/2`D9"T^<F5A9"@I*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@:68@*'-T
M<G!O<R@D96YT<GDL("1T:&ES+3Y?<')E9FEX*2`]/3T@,"D@>PH@("`@("`@
M("`@("`@("`@)&UT:6UE(#T@9FEL96UT:6UE*"1T:&ES+3Y?9&ER("X@)R\G
M("X@)&5N=')Y*3L*("`@("`@("`@("`@("`@(&EF("@D9V-?=&EM92`^("1M
M=&EM92D@>PH@("`@("`@("`@("`@("`@("`@($!U;FQI;FLH)'1H:7,M/E]D
M:7(@+B`G+R<@+B`D96YT<GDI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@("1D+3YC;&]S92@I.PH@"B`@("`@
M("`@)&9P(#T@9F]P96XH)&9I;&5N86UE+"`G=R<I.PH@("`@("`@(&9W<FET
M92@D9G`L('1I;64H*2D["B`@("`@("`@9F-L;W-E*"1F<"D["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-A8VAE+WIP<S0N<&AP
M````````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`T-#<R(#$P
M-3$U-#,S-S,W(#`R,3<W-0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@5&AE($AO<F1E7T-A8VAE7WIP
M<S0Z.B!C;&%S<R!P<F]V:61E<R!A(%IE;F0@4&5R9F]R;6%N8V4@4W5I=&4*
M("H@*'9E<G-I;VX@-"XP*RD@:6UP;&5M96YT871I;VX@;V8@=&AE($AO<F1E
M(&-A8VAI;F<@<WES=&5M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]#86-H
M92]#86-H92]Z<',T+G!H<"QV(#$N,2XQ,"XT(#(P,#8O,#$O,#$@,C$Z,C@Z
M,3`@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@
M2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@
M*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*
M("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T-A8VAE
M"B`J+PIC;&%S<R!(;W)D95]#86-H95]Z<',T(&5X=&5N9',@2&]R9&5?0V%C
M:&4@>PH*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T<FEE=F4@82!P
M:65C92!O9B!C86-H960@9&%T82!A;F0@<F5T=7)N(&ET('1O('1H92!C86QL
M97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&ME>2`@("`@("!#
M86-H92!K97D@=&\@9F5T8V@N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;&EF
M971I;64@($QI9F5T:6UE(&]F('1H92!K97D@:6X@<V5C;VYD<RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!#86-H960@9&%T82P@;W(@9F%L<V4@
M:68@;F]N92!W87,@9F]U;F0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E="@D
M:V5Y+"`D;&EF971I;64@/2`Q*0H@("`@>PH@("`@("`@(')E='5R;B!O=71P
M=71?8V%C:&5?9V5T*"1K97DL("1L:69E=&EM92D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!!='1E;7!T<R!T;R!S=&]R92!A;B!O8FIE8W0@=&\@=&AE(&-A
M8VAE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ME>2`@($-A8VAE
M(&ME>2`H:61E;G1I9FEE<BDN"B`@("`@*B!`<&%R86T@;6EX960@("1D871A
M("!$871A('1O('-T;W)E(&EN('1H92!C86-H92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@9F%I
M;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T*"1K97DL("1D871A*0H@
M("`@>PH@("`@("`@(&]U='!U=%]C86-H95]P=70H)&ME>2P@)&1A=&$I.PH@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@071T
M96UP=',@=&\@9&ER96-T;'D@;W5T<'5T(&-A8VAE9"!D871A+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@("1K97D@("`@("`@0V%C:&4@:V5Y('1O
M(&]U='!U="X*("`@("`J($!P87)A;2!I;G1E9V5R("1L:69E=&EM92`@3&EF
M971I;64@;V8@=&AE(&ME>2!I;B!S96-O;F1S+@H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@($-A8VAE9"!D871A+"!O<B!F86QS92!I9B!N;VYE('=A
M<R!F;W5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@;W5T<'5T*"1K97DL("1L
M:69E=&EM92`](#$I"B`@("!["B`@("`@("`@96-H;R`D=&AI<RT^9F5T8V@H
M)&ME>2P@)&QI9F5T:6UE*3L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K
M<R!I9B!A(&=I=F5N(&ME>2!E>&ES=',@:6X@=&AE(&-A8VAE+"!V86QI9"!F
M;W(@=&AE(&=I=F5N(&QI9F5T:6UE+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@("1K97D@("`@("`@0V%C:&4@:V5Y('1O(&-H96-K+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&QI9F5T:6UE("!,:69E=&EM92!O9B!T:&4@:V5Y
M(&EN('-E8V]N9',N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!%
M>&ES=&%N8V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X:7-T<R@D:V5Y+"`D
M;&EF971I;64@/2`Q*0H@("`@>PH@("`@("`@("1E>&ES=',@/2!O=71P=71?
M8V%C:&5?97AI<W1S*"1K97DL("1L:69E=&EM92D["B`@("`@("`@;W5T<'5T
M7V-A8VAE7W-T;W`H*3L*("`@("`@("!R971U<FX@)&5X:7-T<SL*("`@('T*
M"B`@("`O*BH*("`@("`J($5X<&ER92!A;GD@97AI<W1I;F<@9&%T82!F;W(@
M=&AE(&=I=F5N(&ME>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1K
M97D@($-A8VAE(&ME>2!T;R!E>'!I<F4N"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!3=6-C97-S(&]R(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&5X<&ER92@D:V5Y*0H@("`@>PH@("`@("`@(')E='5R;B!O=71P
M=71?8V%C:&5?<F5M;W9E7VME>2@D:V5Y*3L*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T)L
M;V-K````````````````````````````````````````````````````````
M`````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,#`P(#$P-3$U-#,S-S,W(#`R,#,R-0`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T````````````````````````
M````````````````````````````````````````````````,#`P-S4U(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W,S<@,#(Q-C`R
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]";&]C:R],87EO=70O
M5FEE=RYP:'``````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,#4S,B`Q
M,#4Q-30S,S<S-R`P,C,S,#4`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O0G)O
M=W-E<BYP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T)L;V-K+T-O;&QE8W1I
M;VXN<&AP)SL*"B\J*@H@*B!4:&4@2&]R9&5?0FQO8VM?3&%Y;W5T7U9I97<@
M8VQA<W,@<F5P<F5S96YT<R!T:&4@=7-E<B!D969I;F5D('!O<G1A;"!L87EO
M=70N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="]6:65W+G!H<"QV(#$N-"XR+C,@,C`P-B\P-B\R,R`P-#HS-3HR,2!C:'5C
M:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI:V4@0V]C:')A
M;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($-O<'ER:6=H="`R,#`S
M+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O
M;FAA;&PN8V\N;GH^"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H
M;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,@H@*B!`<&%C:V%G92!(
M;W)D95]";&]C:PH@*B\*8VQA<W,@2&]R9&5?0FQO8VM?3&%Y;W5T7U9I97<@
M>PH*("`@("\J*@H@("`@("H@5&AE(&-U<G)E;G0@8FQO8VL@;&%Y;W5T+@H@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?;&%Y
M;W5T(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($%L;"!A<'!L:6-A=&EO
M;G,@=7-E9"!I;B!T:&ES(&QA>6]U="X*("`@("`J"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D7V%P<&QI8V%T:6]N<R`](&%R<F%Y*"D[
M"@H@("`@+RHJ"B`@("`@*B!#4U,@;&EN:R!T86=S('!U;&QE9"!O=70@;V8@
M8FQO8VL@8V]N=&5N="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D7VQI;FM486=S(#T@87)R87DH*3L*"B`@("`O*BH*("`@
M("`J($-O;G-T<G5C=&]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]"
M;&]C:U],87EO=71?5FEE=R@D;&%Y;W5T(#T@)R<I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]L87EO=70@/2!`=6YS97)I86QI>F4H)&QA>6]U="D["B`@("`@
M("`@:68@*"$D=&AI<RT^7VQA>6]U="D@>PH@("`@("`@("`@("`D=&AI<RT^
M7VQA>6]U="`](&%R<F%Y*"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@4F5N9&5R('1H92!C=7)R96YT(&QA>6]U="!A<R!(5$U,+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG($A434P@;&%Y;W5T+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!T;TAT;6PH*0H@("`@>PH@("`@("`@("1B<F]W<V5R
M(#T@)D)R;W=S97(Z.G-I;F=L971O;B@I.PH@("`@("`@("1T<&Q$:7(@/2`D
M1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G
M*3L*("`@("`@("`D:6YT97)V86P@/2`D1TQ/0D%,4ULG<')E9G,G72T^9V5T
M5F%L=64H)W-U;6UA<GE?<F5F<F5S:%]T:6UE)RD["@H@("`@("`@("1H=&UL
M(#T@)SQT86)L92!C;&%S<STB;F]P861D:6YG(B!C96QL<W!A8VEN9STB-B(@
M=VED=&@](C$P,"4B/B<["@H@("`@("`@("1C;W9E<F5D(#T@87)R87DH*3L*
M("`@("`@("!F;W)E86-H("@D=&AI<RT^7VQA>6]U="!A<R`D<F]W7VYU;2`]
M/B`D<F]W*2!["B`@("`@("`@("`@("1W:61T:"`](&9L;V]R*#$P,"`O(&-O
M=6YT*"1R;W<I*3L*("`@("`@("`@("`@)&AT;6P@+CT@)SQT<CXG.PH@("`@
M("`@("`@("!F;W)E86-H("@D<F]W(&%S("1C;VQ?;G5M(#T^("1I=&5M*2![
M"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&-O=F5R961;)')O=U]N=6U=
M*2`F)B!I<W-E="@D8V]V97)E9%LD<F]W7VYU;5U;)&-O;%]N=6U=*2D@>PH@
M("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1I=&5M*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?87!P;&EC871I;VYS6R1I=&5M6R=A
M<'`G75T@/2`D:71E;5LG87!P)UT["B`@("`@("`@("`@("`@("`@("`@)&)L
M;V-K(#T@)DAO<F1E7T)L;V-K7T-O;&QE8W1I;VXZ.F=E=$)L;V-K*"1I=&5M
M6R=A<'`G72P@)&ET96U;)W!A<F%M<R==6R=T>7!E)UTL("1I=&5M6R=P87)A
M;7,G75LG<&%R86US)UTI.PH@("`@("`@("`@("`@("`@("`@("1R;W=S<&%N
M(#T@)&ET96U;)VAE:6=H="==.PH@("`@("`@("`@("`@("`@("`@("1C;VQS
M<&%N(#T@)&ET96U;)W=I9'1H)UT["B`@("`@("`@("`@("`@("`@("`@)'=I
M9'1H("H]("1C;VQS<&%N.PH@("`@("`@("`@("`@("`@("`@(&9O<B`H)&D@
M/2`P.R`D:2`\("1I=&5M6R=H96EG:'0G73L@)&DK*RD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1C;W9E<F5D6R1R;W=?;G5M("L@
M)&E=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O=F5R961;
M)')O=U]N=6T@*R`D:5T@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@(&9O<B`H)&H@/2`P.R`D
M:B`\("1I=&5M6R=W:61T:"==.R`D:BLK*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D8V]V97)E9%LD<F]W7VYU;2`K("1I75LD8V]L7VYU;2`K
M("1J72`]('1R=64["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@:68@*&ES7V$H
M)&)L;V-K+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1H96%D97(@/2!?*")%<G)O<B(I.PH@("`@("`@("`@("`@("`@("`@
M("`@("`D8V]N=&5N="`]("1B;&]C:RT^9V5T365S<V%G92@I.PH@("`@("`@
M("`@("`@("`@("`@("`@("!O8E]S=&%R="@I.PH@("`@("`@("`@("`@("`@
M("`@("`@("!I;F-L=61E("1T<&Q$:7(@+B`G+W!O<G1A;"]B;&]C:RYI;F,G
M.PH@("`@("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2!O8E]G971?8VQE
M86XH*3L*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H:7-?82@D8FQO
M8VLL("=(;W)D95]";&]C:R<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1H96%D97(@/2`D8FQO8VLM/F=E=%1I=&QE*"D["B`@("`@("`@("`@("`@
M("`@("`@("`@("1C;VYT96YT(#T@)&)L;V-K+3YG971#;VYT96YT*"D["B`@
M("`@("`@("`@("`@("`@("`@("`@(&]B7W-T87)T*"D["B`@("`@("`@("`@
M("`@("`@("`@("`@(&EN8VQU9&4@)'1P;$1I<B`N("<O<&]R=&%L+V)L;V-K
M+FEN8R<["B`@("`@("`@("`@("`@("`@("`@("`@("1H=&UL("X](&]B7V=E
M=%]C;&5A;B@I.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1H=&UL("X]("<\=&0@=VED=&@](B<@+B`D
M=VED=&@@+B`G)2(^)FYB<W`[/"]T9#XG.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@)&AT;6P@+CT@)SQT9"!W:61T:#TB)R`N("1W:61T:"`N("<E(CXF;F)S
M<#L\+W1D/B<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)&AT;6P@+CT@)SPO='(^)SL*("`@("`@("!]"B`@("`@("`@
M)&AT;6P@+CT@)SPO=&%B;&4^)SL*"B`@("`@("`@+R\@4W1R:7`@86YY($-3
M4R`\;&EN:SX@=&%G<R!O=70@;V8@=&AE(')E='5R;F5D(&-O;G1E;G0@<V\*
M("`@("`@("`O+R!T:&5Y(&-A;B!B92!H86YD;&5D('-E<&5R871E;'DN"B`@
M("`@("`@:68@*'!R96=?;6%T8VA?86QL*"<O/&QI;FL@+BH_<F5L/2)S='EL
M97-H965T(BXJ/UPO/B\G+"`D:'1M;"P@)&QI;FMS*2D@>PH@("`@("`@("`@
M("`D:'1M;"`]('-T<E]R97!L86-E*"1L:6YK<ULP72P@)R<L("1H=&UL*3L*
M("`@("`@("`@("`@)'1H:7,M/E]L:6YK5&%G<R`]("1L:6YK<ULP73L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D:'1M;#L*("`@('T*"B`@("`O*BH*
M("`@("`J($=E="!A;GD@;&EN:R!T86=S(&9O=6YD(&EN('1H92!V:65W+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971,:6YK5&%G<R@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?;&EN:U1A9W,["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FX@82!L:7-T(&]F(&%L;"!T:&4@87!P;&EC871I;VYS('5S
M960@8GD@8FQO8VMS(&EN('1H:7,@;&%Y;W5T+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@3&ES="!O9B!A<'!L:6-A=&EO;G,N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$%P<&QI8V%T:6]N<R@I"B`@("!["B`@("`@("`@<F5T
M=7)N(&%R<F%Y7VME>7,H)'1H:7,M/E]A<'!L:6-A=&EO;G,I.PH@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,3,S,C$W(#$P-3$U-#,S-S,W
M(#`R,S<U,P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D92]!<G)A>2YP:'`G.PH*
M+RHJ"B`J(%1H92!(;W)D95]";&]C:U],87EO=71?36%N86=E<B!C;&%S<R!A
M;&QO=W,@;6%N:7!U;&%T:6]N(&]F"B`J($AO<F1E7T)L;V-K(&QA>6]U=',N
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-
M86YA9V5R+G!H<"QV(#$N-"XR+C,@,C`P-B\P,R\P."`Q-SHU-#HP."!C:'5C
M:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI:V4@0V]C:')A
M;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($-O<'ER:6=H="`R,#`S
M+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O
M;FAA;&PN8V\N;GH^"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H
M;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,@H@*B!`<&%C:V%G92!(
M;W)D95]";&]C:PH@*B\*8VQA<W,@2&]R9&5?0FQO8VM?3&%Y;W5T7TUA;F%G
M97(@>PH*("`@("\J*@H@("`@("H@3W5R($AO<F1E7T)L;V-K7T-O;&QE8W1I
M;VX@:6YS=&%N8V4N"B`@("`@*@H@("`@("H@0'9A<B!(;W)D95]";&]C:U]#
M;VQL96-T:6]N"B`@("`@*B\*("`@('9A<B`D7V-O;&QE8W1I;VX["@H@("`@
M+RHJ"B`@("`@*B!4:&4@8W5R<F5N="!B;&]C:R!L87EO=70N"B`@("`@*@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]L87EO=70@/2!A
M<G)A>2@I.PH*("`@("\J*@H@("`@("H@02!C86-H92!F;W(@=&AE(&)L;V-K
M(&]B:F5C=',N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)%]B;&]C:W,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@5&AE
M(&UA>&EM=6T@;G5M8F5R(&]F(&-O;'5M;G,N"B`@("`@*@H@("`@("H@0'9A
M<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7V-O;'5M;G,@/2`P.PH*("`@
M("\J*@H@("`@("H@2&%S('1H92!L87EO=70@8F5E;B!U<&1A=&5D('-I;F-E
M(&ET('=A<R!I;G-T86YT:6%T960N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L
M96%N"B`@("`@*B\*("`@('9A<B`D7W5P9&%T960@/2!F86QS93L*"B`@("`O
M*BH*("`@("`J(%1H92!C=7)R96YT(&)L;V-K("AA<G)A>3H@6W)O=RP@8V]L
M72DN"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@
M)%]C=7)R96YT0FQO8VL@/2!A<G)A>2AN=6QL+"!N=6QL*3L*"B`@("`O*BH*
M("`@("`J(%1H92!N97<@<F]W(&]F('1H92!L87-T(&-H86YG960@8FQO8VLN
M"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D
M7V-H86YG961?<F]W(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%1H92!N97<@
M8V]L=6UN(&]F('1H92!L87-T(&-H86YG960@8FQO8VLN"B`@("`@*@H@("`@
M("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7V-H86YG961?8V]L
M(#T@;G5L;#L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*
M("`@("`J($!P87)A;2!(;W)D95]";&]C:U]#;VQL96-T:6]N("8D8V]L;&5C
M=&EO;@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&%T80H@("`@("HO"B`@("!F
M=6YC=&EO;B!(;W)D95]";&]C:U],87EO=71?36%N86=E<B@F)&-O;&QE8W1I
M;VXL("1D871A(#T@)R<I"B`@("!["B`@("`@("`@)'1H:7,M/E]C;VQL96-T
M:6]N(#T@)B1C;VQL96-T:6]N.PH@("`@("`@("1T:&ES+3YU;G-E<FEA;&EZ
M92@D9&%T82D["@H@("`@("`@("\O($9I;&P@=&AE(%]C;W9E<F5D(&-A8VAE
M<R!A;F0@96UP='D@<F]W<RX*("`@("`@("`D<F]W<R`](&-O=6YT*"1T:&ES
M+3Y?;&%Y;W5T*3L*("`@("`@("`D96UP='D@/2!A<G)A>2@I.PH@("`@("`@
M(&9O<B`H)')O=R`](#`[("1R;W<@/"`D<F]W<SL@)')O=RLK*2!["B`@("`@
M("`@("`@("1C;VQS(#T@8V]U;G0H)'1H:7,M/E]L87EO=71;)')O=UTI.PH@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1E;7!T>5LD<F]W72DI('L*("`@("`@
M("`@("`@("`@("1E;7!T>5LD<F]W72`]('1R=64["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@9F]R("@D8V]L(#T@,#L@)&-O;"`\("1C;VQS.R`D8V]L
M*RLI('L*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]L87EO
M=71;)')O=UU;)&-O;%TI*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]B;&]C:W-;)')O=UU;)&-O;%T@/2!014%2.CIR86ES945R<F]R*%\H(DYO
M(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(BDL("=H
M;W)D92YE<G)O<B<I.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES7V%R
M<F%Y*"1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1F:65L9"`]("1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=
M.PH*("`@("`@("`@("`@("`@("`@("`D96UP='E;)')O=UT@/2!F86QS93L*
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&9I96QD6R=W:61T:"==
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,3L@)&D@
M/"`D9FEE;&1;)W=I9'1H)UT[("1I*RLI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VP@*R`D:5T@/2`G
M8V]V97)E9"<["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1F
M:65L9%LG:&5I9VAT)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)&9I96QD6R=W:61T:"==*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&9I96QD6R=W:61T:"==(#T@,3L*("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!F;W(@*"1I
M(#T@,3L@)&D@/"`D9FEE;&1;)VAE:6=H="==.R`D:2LK*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W("L@)&E=
M6R1C;VQ=(#T@)V-O=F5R960G.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@9F]R("@D:B`](#$[("1J(#P@)&9I96QD6R=W:61T:"==.R`D:BLK*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]L87EO
M=71;)')O=R`K("1I75LD8V]L("L@)&I=(#T@)V-O=F5R960G.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&5M<'1Y6R1R;W<@*R`D:5T@/2!F86QS93L*("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@4W1R:7`@
M96UP='D@8FQO8VMS(&9R;VT@=&AE(&5N9"!O9B!T:&4@<F]W<RX*("`@("`@
M("`@("`@9F]R("@D8V]L(#T@)&-O;',@+2`Q.R`D8V]L(#X](#`[("1C;VPM
M+2D@>PH@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7VQA>6]U
M=%LD<F]W75LD8V]L72D@?'P*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7VQA>6]U=%LD<F]W75LD8V]L72`]/2`G96UP='DG*2!["B`@("`@("`@("`@
M("`@("`@("`@=6YS970H)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;%TI.PH@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)'1H:7,M/E]C;VQU;6YS(#T@;6%X*"1T:&ES+3Y?8V]L=6UN<RP@
M8V]U;G0H)'1H:7,M/E]L87EO=71;)')O=UTI*3L*("`@("`@("!]"@H@("`@
M("`@("\O($9I;&P@86QL(')O=W,@=7`@=&\@=&AE('-A;64@;&5N9W1H+@H@
M("`@("`@("1L87EO=70@/2!A<G)A>2@I.PH@("`@("`@(&9O<B`H)')O=R`]
M(#`[("1R;W<@/"`D<F]W<SL@)')O=RLK*2!["B`@("`@("`@("`@("1C;VQS
M(#T@8V]U;G0H)'1H:7,M/E]L87EO=71;)')O=UTI.PH@("`@("`@("`@("!I
M9B`H)&-O;',@/"`D=&AI<RT^7V-O;'5M;G,I('L*("`@("`@("`@("`@("`@
M(&9O<B`H)&-O;"`]("1C;VQS.R`D8V]L(#P@)'1H:7,M/E]C;VQU;6YS.R`D
M8V]L*RLI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD
M<F]W75LD8V]L72`]("=E;7!T>2<["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)&QA>6]U=%M=(#T@)'1H:7,M/E]L87EO
M=71;)')O=UT["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7VQA>6]U="`]
M("1L87EO=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!397)I86QI>F4@86YD
M(')E='5R;B!T:&4@8W5R<F5N="!B;&]C:R!L87EO=70N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('-E<FEA;&EZ92@I"B`@("!["B`@("`@("`@<F5T=7)N('-E
M<FEA;&EZ92@D=&AI<RT^7VQA>6]U="D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!297-E=',@=&AE(&-U<G)E;G0@;&%Y;W5T('1O('1H92!V86QU92!S=&]R
M960@:6X@=&AE('!R969E<F5N8V5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!U
M;G-E<FEA;&EZ92@D9&%T82D*("`@('L*("`@("`@("`D=&AI<RT^7VQA>6]U
M="`]($!U;G-E<FEA;&EZ92@D9&%T82D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&$@<VEN9VQE(&EN<W1A;F-E(&]F('1H92!(;W)D95]";&]C
M:U],87EO=71?36%N86=E<B!C;&%S<RX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1N86UE"B`@("`@*B!`<&%R86T@2&]R9&5?0FQO8VM?0V]L;&5C
M=&EO;B`F)&-O;&QE8W1I;VX*("`@("`J($!P87)A;2!S=')I;F<@)&1A=&$*
M("`@("`J"B`@("`@*B!`<W1A=&EC"B`@("`@*@H@("`@("H@0')E='5R;B!(
M;W)D95]";&]C:U],87EO=71?36%N86=E<B`@5&AE($AO<F1E7T)L;V-K7TQA
M>6]U=%]-86YA9V5R(&EN<W1A;F-E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F
M<VEN9VQE=&]N*"1N86UE+"`F)&-O;&QE8W1I;VXL("1D871A(#T@)R<I"B`@
M("!["B`@("`@("`@<W1A=&EC("1I;G-T86YC97,@/2!A<G)A>2@I.PH@("`@
M("`@(&EF("@A:7-S970H)&EN<W1A;F-E<ULD;F%M95TI*2!["B`@("`@("`@
M("`@("1I;G-T86YC97-;)&YA;65=(#T@;F5W($AO<F1E7T)L;V-K7TQA>6]U
M=%]-86YA9V5R*"1C;VQL96-T:6]N+"`D9&%T82D["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D:6YS=&%N8V5S6R1N86UE73L*("`@('T*"B`@("`O*BH*
M("`@("`J(%!R;V-E<W,@82!M;V1I9FEC871I;VX@=&\@=&AE(&-U<G)E;G0@
M;&%Y;W5T+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG("1A8W1I;VX*("`@
M("`J($!V87(@:6YT96=E<B`D<F]W"B`@("`@*B!`=F%R(&EN=&5G97(@)&-O
M;`H@("`@("HO"B`@("!F=6YC=&EO;B!H86YD;&4H)&%C=&EO;BP@)')O=RP@
M)&-O;"D*("`@('L*("`@("`@("!S=VET8V@@*"1A8W1I;VXI('L*("`@("`@
M("!C87-E("=M;W9E57`G.@H@("`@("`@(&-A<V4@)VUO=F5$;W=N)SH*("`@
M("`@("!C87-E("=M;W9E3&5F="<Z"B`@("`@("`@8V%S92`G;6]V95)I9VAT
M)SH*("`@("`@("!C87-E("=E>'!A;F15<"<Z"B`@("`@("`@8V%S92`G97AP
M86YD1&]W;B<Z"B`@("`@("`@8V%S92`G97AP86YD3&5F="<Z"B`@("`@("`@
M8V%S92`G97AP86YD4FEG:'0G.@H@("`@("`@(&-A<V4@)W-H<FEN:TQE9G0G
M.@H@("`@("`@(&-A<V4@)W-H<FEN:U)I9VAT)SH*("`@("`@("!C87-E("=S
M:')I;FM5<"<Z"B`@("`@("`@8V%S92`G<VAR:6YK1&]W;B<Z"B`@("`@("`@
M8V%S92`G<F5M;W9E0FQO8VLG.@H@("`@("`@("`@("`D<F5S=6QT(#T@8V%L
M;%]U<V5R7V9U;F,H87)R87DH)B1T:&ES+"`D86-T:6]N*2P@)')O=RP@)&-O
M;"D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@("1'3$]"04Q36R=N;W1I9FEC871I;VXG
M72T^<'5S:"@D<F5S=6QT*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?=7!D871E9"`]('1R=64["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@("\O(%-A=F4@=&AE(&-H
M86YG97,@;6%D92!T;R!A(&)L;V-K+@H@("`@("`@(&-A<V4@)W-A=F4G.@H@
M("`@("`@("\O(%-A=F4@=&AE(&-H86YG97,@;6%D92!T;R!A(&)L;V-K(&%N
M9"!C;VYT:6YU92!E9&ET:6YG+@H@("`@("`@(&-A<V4@)W-A=F4M<F5S=6UE
M)SH*("`@("`@("`@("`@+R\@1V5T(')E<75E<W1E9"!B;&]C:R!T>7!E+@H@
M("`@("`@("`@("!L:7-T*"1N97=A<'`L("1N97=T>7!E*2`](&5X<&QO9&4H
M)SHG+"!5=&EL.CIG971&;W)M1&%T82@G87!P)RDI.PH*("`@("`@("`@("`@
M+R\@27,@=&AI<R!A(&YE=R!B;&]C:S\*("`@("`@("`@("`@)&YE=R`](&9A
M;'-E.PH@("`@("`@("`@("!I9B`H)'1H:7,M/FES16UP='DH)')O=RP@)&-O
M;"D@?'P*("`@("`@("`@("`@("`@("$D=&AI<RT^<F]W17AI<W1S*"1R;W<I
M('Q\"B`@("`@("`@("`@("`@("`A)'1H:7,M/F-O;$5X:7-T<R@D8V]L*2D@
M>PH@("`@("`@("`@("`@("`@+R\@0VAE8VL@<&5R;6ES<VEO;G,N"B`@("`@
M("`@("`@("`@("!I9B`H2&]R9&4Z.FAA<U!E<FUI<W-I;VXH)VUA>%]B;&]C
M:W,G*2`A/3T@=')U92`F)@H@("`@("`@("`@("`@("`@("`@($AO<F1E.CIH
M87-097)M:7-S:6]N*"=M87A?8FQO8VMS)RD@/#T@)'1H:7,M/F-O=6YT*"DI
M('L*("`@("`@("`@("`@("`@("`@("`D;65S<V%G92`]($!H=&UL<W!E8VEA
M;&-H87)S*'-P<FEN=&8H7R@B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A
M=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB*2P@2&]R9&4Z.FAA<U!E<FUI<W-I
M;VXH)VUA>%]B;&]C:W,G*2DL($5.5%]#3TU0050L($Y,4SHZ9V5T0VAA<G-E
M="@I*3L*("`@("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=H
M;V]K<R==6R=P97)M<V1E;FEE9"==*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D;65S<V%G92`]($AO<F1E.CIC86QL2&]O:R@G7W!E<FUS7VAO;VM?
M9&5N:65D)RP@87)R87DH)VAO<F1E.FUA>%]B;&]C:W,G*2P@)VAO<F1E)RP@
M)&UE<W-A9V4I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`D1TQ/0D%,4ULG;F]T:69I8V%T:6]N)UTM/G!U<V@H)&UE<W-A
M9V4L("=H;W)D92YE<G)O<B<L(&%R<F%Y*"=C;VYT96YT+G)A=R<I*3L*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("`@("`D;F5W(#T@=')U93L*("`@("`@("`@("`@("`@("\O
M($UA:V4@<W5R92!T:&5R92!I<R!S;VUE=VAE<F4@=&\@<'5T(&ET+@H@("`@
M("`@("`@("`@("`@)'1H:7,M/F%D9$)L;V-K*"1R;W<L("1C;VPI.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`O+R!/<B!A;B!E>&ES=&EN9R!O;F4_
M"B`@("`@("`@("`@("1E>&ES=',@/2!F86QS93L*("`@("`@("`@("`@)&-H
M86YG960@/2!F86QS93L*("`@("`@("`@("`@:68@*"$D;F5W*2!["B`@("`@
M("`@("`@("`@("`O+R!'970@=&%R9V5T(&)L;V-K(&EN9F\N"B`@("`@("`@
M("`@("`@("`D:6YF;R`]("1T:&ES+3YG971";&]C:TEN9F\H)')O=RP@)&-O
M;"D["B`@("`@("`@("`@("`@("`D97AI<W1S(#T@)'1H:7,M/FES0FQO8VLH
M)')O=RP@)&-O;"D["B`@("`@("`@("`@("`@("`O+R!(87,@82!D:69F97)E
M;G0@8FQO8VL@8F5E;B!S96QE8W1E9#\*("`@("`@("`@("`@("`@(&EF("@D
M97AI<W1S("8F"B`@("`@("`@("`@("`@("`@("`@*"1I;F9O6R=A<'`G72`A
M/2`D;F5W87!P('Q\"B`@("`@("`@("`@("`@("`@("`@("1I;F9O6R=B;&]C
M:R==("$]("1N97=T>7!E*2D@>PH@("`@("`@("`@("`@("`@("`@("1C:&%N
M9V5D(#T@=')U93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@:68@*"1N97<@?'P@)&-H86YG960I('L*("`@("`@("`@
M("`@("`@("\O($-H86YG92!A<'`@;W(@='EP92X*("`@("`@("`@("`@("`@
M("1I;F9O(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("1I;F9O6R=A<'`G
M72`]("1N97=A<'`["B`@("`@("`@("`@("`@("`D:6YF;ULG8FQO8VLG72`]
M("1N97=T>7!E.PH@("`@("`@("`@("`@("`@)'!A<F%M<R`]("1T:&ES+3Y?
M8V]L;&5C=&EO;BT^9V5T4&%R86US*"1N97=A<'`L("1N97=T>7!E*3L*("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)&YE=W!A<F%M*2![
M"B`@("`@("`@("`@("`@("`@("`@)&EN9F];)W!A<F%M<R==6R1N97=P87)A
M;5T@/2`D=&AI<RT^7V-O;&QE8W1I;VXM/F=E=$1E9F%U;'1686QU92@D;F5W
M87!P+"`D;F5W='EP92P@)&YE=W!A<F%M*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("1T:&ES+3YS971";&]C:TEN9F\H)')O=RP@)&-O
M;"P@)&EN9F\I.PH@("`@("`@("`@("!](&5L<V5I9B`H)&5X:7-T<RD@>PH@
M("`@("`@("`@("`@("`@+R\@0VAA;F=E('9A;'5E<RX*("`@("`@("`@("`@
M("`@("1T:&ES+3YS971";&]C:TEN9F\H)')O=RP@)&-O;"P@87)R87DH)W!A
M<F%M<R<@/3X@571I;#HZ9V5T1F]R;41A=&$H)W!A<F%M<R<L(&%R<F%Y*"DI
M*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]U<&1A=&5D
M(#T@=')U93L*("`@("`@("`@("`@:68@*"1A8W1I;VX@/3T@)W-A=F4G*2![
M"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H*("`@("`@
M("`O+R!-86ME(&$@8FQO8VL@=&AE(&-U<G)E;G0@8FQO8VL@9F]R(&5D:71I
M;F<N"B`@("`@("`@8V%S92`G961I="<Z"B`@("`@("`@("`@("1T:&ES+3Y?
M8W5R<F5N=$)L;V-K(#T@87)R87DH)')O=RP@)&-O;"D["B`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($AA<R!T
M:&4@;&%Y;W5T(&)E96X@8VAA;F=E9"!S:6YC92!I="!W87,@:6YS=&%N=&EA
M=&5D/PH@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;@H@("`@("HO"B`@
M("!F=6YC=&EO;B!U<&1A=&5D*"D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]U<&1A=&5D.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T('1H92!C
M=7)R96YT(&)L;V-K(')O=R!A;F0@8V]L=6UN+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@6W)O=RP@8V]L70H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971#=7)R96YT0FQO8VLH*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M7V-U<G)E;G1";&]C:SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE($AO<F1E7T)L;V-K(&%T('1H92!S<&5C:69I960@<&]S:71I;VXN"B`@
M("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O=R`@02!L87EO=70@<F]W
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O;"`@02!L87EO=70@8V]L=6UN
M+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?0FQO8VL@(%1H92!B;&]C
M:R!F<F]M('1H870@<&]S:71I;VX@;W(@82!014%27T5R<F]R"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("!I9B!S;VUE=&AI;F<@=V5N="!W<F]N9RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=$)L;V-K*"1R;W<L("1C;VPI"B`@
M("!["B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V)L;V-K<ULD<F]W75LD
M8V]L72DI('L*("`@("`@("`@("`@)&9I96QD(#T@)'1H:7,M/E]L87EO=71;
M)')O=UU;)&-O;%T["B`@("`@("`@("`@("1T:&ES+3Y?8FQO8VMS6R1R;W==
M6R1C;VQ=(#T*("`@("`@("`@("`@("`@("9(;W)D95]";&]C:U]#;VQL96-T
M:6]N.CIG971";&]C:R@D9FEE;&1;)V%P<"==+"`D9FEE;&1;)W!A<F%M<R==
M6R=T>7!E)UTL("1F:65L9%LG<&%R86US)UU;)W!A<F%M<R==*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^7V)L;V-K<ULD<F]W75LD8V]L
M73L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-O;W)D:6YA
M=&5S(&]F('1H92!B;&]C:R!C;W9E<FEN9R!T:&4@<W!E8VEF:65D"B`@("`@
M*B!F:65L9"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W("!!
M(&QA>6]U="!R;W<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]L("!!(&QA
M>6]U="!C;VQU;6XN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE
M('1O<"UL969T(')O=RUC;VQU;6XM8V]O<F1I;F%T92!O9B!T:&4@8FQO8VL*
M("`@("`J("`@("`@("`@("`@("`@(&-O=F5R:6YG('1H92!S<&5C:69I960@
M9FEE;&0@;W(@;G5L;"!I9B!T:&4@9FEE;&0*("`@("`J("`@("`@("`@("`@
M("`@(&ES(&5M<'1Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971";&]C:T%T
M*"1R;W<L("1C;VPI"B`@("!["B`@("`@("`@+RH@5')I=FEA;"!C87-E<R!F
M:7)S="X@*B\*("`@("`@("!I9B`H)'1H:7,M/FES16UP='DH)')O=RP@)&-O
M;"DI('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?2!E;'-E
M:68@*"$D=&AI<RT^:7-#;W9E<F5D*"1R;W<L("1C;VPI*2!["B`@("`@("`@
M("`@(')E='5R;B!A<G)A>2@D<F]W+"`D8V]L*3L*("`@("`@("!]"@H@("`@
M("`@("\J(%1H:7,@:7,@82!C;W9E<F5D(&9I96QD+B`J+PH@("`@("`@(&9O
M<B`H)'1E<W0@/2`D<F]W("T@,3L@)'1E<W0@/CT@,#L@)'1E<W0M+2D@>PH@
M("`@("`@("`@("!I9B`H(21T:&ES+3YI<T-O=F5R960H)'1E<W0L("1C;VPI
M("8F"B`@("`@("`@("`@("`@("`A)'1H:7,M/FES16UP='DH)'1E<W0L("1C
M;VPI("8F"B`@("`@("`@("`@("`@("`D=&5S="`K("1T:&ES+3YG971(96EG
M:'0H)'1E<W0L("1C;VPI("T@,2`]/2`D<F]W*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@87)R87DH)'1E<W0L("1C;VPI.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@(&9O<B`H)'1E<W0@/2`D8V]L("T@,3L@)'1E<W0@
M/CT@,#L@)'1E<W0M+2D@>PH@("`@("`@("`@("!I9B`H(21T:&ES+3YI<T-O
M=F5R960H)')O=RP@)'1E<W0I("8F"B`@("`@("`@("`@("`@("`A)'1H:7,M
M/FES16UP='DH)'1E<W0L("1C;VPI("8F"B`@("`@("`@("`@("`@("`D=&5S
M="`K("1T:&ES+3YG9717:61T:"@D<F]W+"`D=&5S="D@+2`Q(#T]("1C;VPI
M('L*("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>2@D<F]W+"`D=&5S="D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&$@:&%S:"!W:71H('-O;64@=7-E9G5L(&EN9F]R;6%T:6]N
M(&%B;W5T('1H92!S<&5C:69I960*("`@("`J(&)L;V-K+@H@("`@("H*("`@
M("`J(%)E='5R;F5D(&AA<V@@=F%L=65S.@H@("`@("H@)V%P<"<Z(&%P<&QI
M8V%T:6]N(&YA;64*("`@("`J("=B;&]C:R<Z(&)L;V-K(&YA;64*("`@("`J
M("=P87)A;7,G.B!P87)A;65T97(@:&%S:`H@("`@("H*("`@("`J($!P87)A
M;2!I;G1E9V5R("1R;W<@($$@;&%Y;W5T(')O=RX*("`@("`J($!P87)A;2!I
M;G1E9V5R("1C;VP@($$@;&%Y;W5T(&-O;'5M;BX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!4:&4@:6YF;W)M871I;VX@:&%S:"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T0FQO8VM);F9O*"1R;W<L("1C;VPI"B`@("!["B`@
M("`@("`@:68@*"%I<W-E="@D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L72D@
M?'P*("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;%T@/3T@
M)V5M<'1Y)RD@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BA?*").;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO
M;B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!A<G)A>2@G87!P)R`]/B`D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L75LG
M87!P)UTL"B`@("`@("`@("`@("`@("`@("`@("=B;&]C:R<@/3X@)'1H:7,M
M/E]L87EO=71;)')O=UU;)&-O;%U;)W!A<F%M<R==6R=T>7!E)UTL"B`@("`@
M("`@("`@("`@("`@("`@("=P87)A;7,G(#T^("1T:&ES+3Y?;&%Y;W5T6R1R
M;W==6R1C;VQ=6R=P87)A;7,G75LG<&%R86US)UTI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4V5T<R!A(&)A=&-H(&]F(&EN9F]R;6%T:6]N(&%B;W5T('1H
M92!S<&5C:69I960@8FQO8VLN"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)')O=R`@02!L87EO=70@<F]W+@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)&-O;"`@02!L87EO=70@8V]L=6UN+@H@("`@("H@0'!A<F%M(&%R<F%Y("1I
M;F9O("`@02!H87-H('=I=&@@:6YF;W)M871I;VX@=F%L=65S+@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@4&]S<VEB;&4@96QE;65N=',@87)E.@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@)V%P<"<Z(&%P<&QI8V%T:6]N
M(&YA;64*("`@("`J("`@("`@("`@("`@("`@("`@("`@("=B;&]C:R<Z(&)L
M;V-K(&YA;64*("`@("`J("`@("`@("`@("`@("`@("`@("`@("=P87)A;7,G
M.B!P87)A;65T97(@:&%S:`H@("`@("HO"B`@("!F=6YC=&EO;B!S971";&]C
M:TEN9F\H)')O=RP@)&-O;"P@)&EN9F\@/2!A<G)A>2@I*0H@("`@>PH@("`@
M("`@(&EF("@A:7-S970H)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;%TI*2![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DYO(&)L
M;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(BDL("=H;W)D
M92YE<G)O<B<I.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1I;F9O
M6R=A<'`G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=UU;
M)&-O;%U;)V%P<"==(#T@)&EN9F];)V%P<"==.PH@("`@("`@('T*("`@("`@
M("!I9B`H:7-S970H)&EN9F];)V)L;V-K)UTI*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=6R=P87)A;7,G75LG='EP92==(#T@
M)&EN9F];)V)L;V-K)UT["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D
M:6YF;ULG<&%R86US)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T
M6R1R;W==6R1C;VQ=6R=P87)A;7,G75LG<&%R86US)UT@/2`D:6YF;ULG<&%R
M86US)UT["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V-H86YG961?<F]W
M(#T@)')O=SL*("`@("`@("`D=&AI<RT^7V-H86YG961?8V]L(#T@)&-O;#L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&YU;6)E<B!O9B!B
M;&]C:W,@:6X@=&AE(&-U<G)E;G0@;&%Y;W5T+@H@("`@("H*("`@("`J($!S
M:6YC92!(;W)D92`S+C$*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@
M(%1H92!N=6UB97(@;V8@8FQO8VMS+@H@("`@("HO"B`@("!F=6YC=&EO;B!C
M;W5N="@I"B`@("!["B`@("`@("`@)')O=W,@/2`D=&AI<RT^<F]W<R@I.PH@
M("`@("`@("1C;W5N="`](#`["@H@("`@("`@(&9O<B`H)')O=R`](#`[("1R
M;W<@/"`D<F]W<SL@)')O=RLK*2!["B`@("`@("`@("`@("1C;VQS(#T@)'1H
M:7,M/F-O;'5M;G,H)')O=RD["B`@("`@("`@("`@(&9O<B`H)&-O;"`](#`[
M("1C;VP@/"`D8V]L<SL@)&-O;"LK*2!["B`@("`@("`@("`@("`@("!I9B`H
M(21T:&ES+3YI<T5M<'1Y*"1R;W<L("1C;VPI("8F"B`@("`@("`@("`@("`@
M("`@("`@(21T:&ES+3YI<T-O=F5R960H)')O=RP@)&-O;"DI('L*("`@("`@
M("`@("`@("`@("`@("`D8V]U;G0K*SL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1C;W5N=#L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&YU;6)E<B!O9B!R
M;W=S(&EN('1H92!C=7)R96YT(&QA>6]U="X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&EN=&5G97(@(%1H92!N=6UB97(@;V8@<F]W<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@<F]W<R@I"B`@("!["B`@("`@("`@<F5T=7)N(&-O=6YT*"1T
M:&ES+3Y?;&%Y;W5T*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE(&YU;6)E<B!O9B!C;VQU;6YS(&EN('1H92!S<&5C:69I960@<F]W(&]F
M('1H90H@("`@("H@8W5R<F5N="!L87EO=70N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)')O=R`@5&AE(')O=R!T;R!R971U<FX@=&AE(&YU;6)E
M<B!O9B!C;VQU;6YS(&9R;VTN"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E
M9V5R("!4:&4@;G5M8F5R(&]F(&-O;'5M;G,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&-O;'5M;G,H)')O=RD*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?;&%Y;W5T6R1R;W==*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E1H92!S<&5C:69I960@<F]W("@E
M9"D@9&]E<R!N;W0@97AI<W0N(BDL("1R;W<I+"`G:&]R9&4N97)R;W(G*3L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N(&-O=6YT*"1T:&ES+3Y?;&%Y;W5T
M6R1R;W==*3L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!T;R!S964@
M:68@82!G:79E;B!L;V-A=&EO;B!I9B!B96EN9R!U<V5D(&)Y(&$@8FQO8VL*
M("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W("!!(&QA>6]U="!R
M;W<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]L("!!(&QA>6]U="!C;VQU
M;6XN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H
M92!L;V-A=&EO;B!I<R!E;7!T>0H@("`@("H@("`@("`@("`@("`@("`@("!&
M86QS92!I<R!T:&4@;&]C871I;VX@:7,@8F5I;F<@=7-E9"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@:7-%;7!T>2@D<F]W+"`D8V]L*0H@("`@>PH@("`@("`@
M(')E='5R;B`A:7-S970H)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;%TI('Q\
M("1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=(#T]("=E;7!T>2<["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&EF('1H92!F:65L9"!A="!T:&4@
M<W!E8VEF:65D('!O<VET:6]N(&ES(&-O=F5R960@8GD*("`@("`J(&%N;W1H
M97(@8FQO8VLN"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O=R`@
M02!L87EO=70@<F]W+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O;"`@02!L
M87EO=70@8V]L=6UN+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@
M5')U92!I9B!T:&4@<W!E8VEF:65D(&9I96QD(&ES(&-O=F5R960N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&ES0V]V97)E9"@D<F]W+"`D8V]L*0H@("`@>PH@
M("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L
M72D@/R`D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L72`]/2`G8V]V97)E9"<@
M.B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@:68@=&AE
M('-P96-I9FEE9"!L;V-A=&EO;B!I<R!T:&4@=&]P(&QE9G0@9FEE;&0@;V8*
M("`@("`J(&$@8FQO8VLN"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)')O=R`@02!L87EO=70@<F]W+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O
M;"`@02!L87EO=70@8V]L=6UN+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5')U92!I9B!T:&4@<W!E8VEF:65D('!O<VET:6]N(&ES(&$@8FQO
M8VLL(&9A;'-E(&EF"B`@("`@*B`@("`@("`@("`@("`@("`@('1H92!F:65L
M9"!D;V5S;B=T(&5X:7-T+"!I<R!E;7!T>2!O<B!C;W9E<F5D+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!I<T)L;V-K*"1R;W<L("1C;VPI"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3YR;W=%>&ES=',H)')O=RD@)B8@)'1H:7,M/F-O
M;$5X:7-T<R@D8V]L*2`F)@H@("`@("`@("`@("`A)'1H:7,M/FES16UP='DH
M)')O=RP@)&-O;"D@)B8@(21T:&ES+3YI<T-O=F5R960H)')O=RP@)&-O;"D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&EF('1H92!S<&5C:69I
M960@8FQO8VL@:&%S(&)E96X@8VAA;F=E9"!L87-T+@H@("`@("H*("`@("`J
M($!P87)A;2!I;G1E9V5R("1R;W<@($$@;&%Y;W5T(')O=RX*("`@("`J($!P
M87)A;2!I;G1E9V5R("1C;VP@($$@;&%Y;W5T(&-O;'5M;BX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AI<R!B;&]C:R!I<R!T
M:&4@;&%S="!O;F4@=&AA="!W87,@8VAA;F=E9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@:7-#:&%N9V5D*"1R;W<L("1C;VPI"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?8VAA;F=E9%]R;W<@/3T]("1R;W<@)B8@)'1H:7,M/E]C
M:&%N9V5D7V-O;"`]/3T@)&-O;#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@:68@=&AE('-P96-I9FEE9"!B;&]C:R!M87D@8F4@<F5M;W9E9"X*
M("`@("`J"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O=R`@02!L
M87EO=70@<F]W+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O;"`@02!L87EO
M=70@8V]L=6UN+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U
M92!I9B!T:&ES(&)L;V-K(&UA>2!B92!R96UO=F5D+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!I<U)E;6]V86)L92@D<F]W+"`D8V]L*0H@("`@>PH@("`@("`@
M(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@)&%P<"`]("1T:&ES+3Y?;&%Y;W5T
M6R1R;W==6R1C;VQ=6R=A<'`G73L*("`@("`@("`D='EP92`]("1T:&ES+3Y?
M;&%Y;W5T6R1R;W==6R1C;VQ=6R=P87)A;7,G75LG='EP92==.PH@("`@("`@
M("1B;&]C:R`]("1A<'`@+B`G.B<@+B`D='EP93L*"B`@("`@("`@+RH@0VAE
M8VL@:68@=&AE(&)L;V-K(&ES(&$@9FEX960@8FQO8VLN("HO"B`@("`@("`@
M:68@*"%I;E]A<G)A>2@D8FQO8VLL("1C;VYF6R=P;W)T86PG75LG9FEX961?
M8FQO8VMS)UTI*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M('T*"B`@("`@("`@+RH@0VAE8VL@:68@=V4@:&%V92!S=&EL;"!A;F]T:&5R
M(&)L;V-K(&]F('1H92!S86UE('1Y<&4N("HO"B`@("`@("`@)&9O=6YD(#T@
M9F%L<V4["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]L87EO=70@87,@)&-U
M<E]R;W<I('L*("`@("`@("`@("`@9F]R96%C:"`H)&-U<E]R;W<@87,@)&-U
M<E]C;VPI('L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D8W5R7V-O;%LG
M87!P)UTI("8F"B`@("`@("`@("`@("`@("`@("`@)&-U<E]C;VQ;)V%P<"==
M(#T]("1A<'`@)B8*("`@("`@("`@("`@("`@("`@("`D8W5R7V-O;%LG<&%R
M86US)UU;)W1Y<&4G72`]/2`D='EP92D@>PH@("`@("`@("`@("`@("`@("`@
M(&EF("@D9F]U;F0I('L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M('1R=64["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&9O=6YD(#T@=')U93L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@86X@55),('1R:6=G97)I;F<@86X@86-T:6]N('1O(&$@
M8FQO8VL*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A8W1I;VX@($%N
M(&%C=&EO;B!T;R!T<FEG9V5R+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O
M=R`@02!L87EO=70@<F]W+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O;"`@
M02!L87EO=70@8V]L=6UN+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!!;B!54DP@=VET:"!A;&P@;F5C97-S87)Y('!A<F%M971E<G,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$%C=&EO;E5R;"@D86-T:6]N+"`D<F]W+"`D
M8V]L*0H@("`@>PH@("`@("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H
M2&]R9&4Z.G-E;&95<FPH*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"=C;VPG(#T^("1C;VPL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G<F]W)R`]/B`D<F]W+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%C=&EO;B<@/3X@
M)&%C=&EO;BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=N;V-A8VAE)R`]/B!B87-E7V-O;G9E<G0H;6EC<F]T:6UE*"DL(#$P
M+"`S-BDI*3L*("`@("`@("!R971U<FX@)'5R;"`N("<C8FQO8VLG.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&-O;G1R;VP@*&QI;FME9"!A
M<G)O=RD@9F]R(&$@8V5R=&%I;B!A8W1I;VX@;VX@=&AE"B`@("`@*B!S<&5C
M:69I960@8FQO8VLN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP
M92`@02!C;VYT<F]L('1Y<&4@:6X@=&AE(&9O<FT*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@(")M;V1I9FEC871I;VXO9&ER96-T:6]N(BX@4&]S<VEB
M;&4@=F%L=65S(&9O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@;6]D
M:69I8V%T:6]N.B!E>'!A;F0L('-H<FEN:RP@;6]V92X@4&]S<VEB;&4@=F%L
M=65S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!F;W(@9&ER96-T:6]N
M.B!U<"P@9&]W;BP@;&5F="P@<FEG:'0N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D<F]W("!!(&QA>6]U="!R;W<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M8V]L("!!(&QA>6]U="!C;VQU;6XN"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@($$@;&EN:R!C;VYT86EN:6YG(&%N(&%R<F]W(')E<')E<V5N=&EN
M9R!T:&4@<F5Q=65S=&5D"B`@("`@*B`@("`@("`@("`@("`@("`@8V]N=')O
M;"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0V]N=')O;"@D='EP92P@)')O
M=RP@)&-O;"D*("`@('L*("`@("`@("`D='EP92`](&5X<&QO9&4H)R\G+"`D
M='EP92D["B`@("`@("`@)&%C=&EO;B`]("1T>7!E6S!=("X@=6-F:7)S="@D
M='EP95LQ72D["B`@("`@("`@)'5R;"`]("1T:&ES+3YG971!8W1I;VY5<FPH
M)&%C=&EO;BP@)')O=RP@)&-O;"D["@H@("`@("`@('-W:71C:"`H)'1Y<&5;
M,%TI('L*("`@("`@("!C87-E("=E>'!A;F0G.@H@("`@("`@("`@("`D=&ET
M;&4@/2!?*")%>'!A;F0B*3L*("`@("`@("`@("`@)&EM9R`]("=L87)G95\G
M("X@)'1Y<&5;,5T["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E
M("=S:')I;FLG.@H@("`@("`@("`@("`D=&ET;&4@/2!?*")3:')I;FLB*3L*
M("`@("`@("`@("`@)&EM9R`]("=L87)G95\G.PH*("`@("`@("`@("`@<W=I
M=&-H("@D='EP95LQ72D@>PH@("`@("`@("`@("!C87-E("=U<"<Z"B`@("`@
M("`@("`@("`@("`D:6UG("X]("=D;W=N)SL*("`@("`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("`@("`@8V%S92`G9&]W;B<Z"B`@("`@("`@("`@("`@
M("`D:6UG("X]("=U<"<["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@(&-A<V4@)VQE9G0G.@H@("`@("`@("`@("`@("`@)&EM9R`N/2`G
M<FEG:'0G.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C
M87-E("=R:6=H="<Z"B`@("`@("`@("`@("`@("`D:6UG("X]("=L969T)SL*
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("!C87-E("=M;W9E)SH*("`@("`@("`@("`@
M<W=I=&-H("@D='EP95LQ72D@>PH@("`@("`@("`@("!C87-E("=U<"<Z"B`@
M("`@("`@("`@("`@("`D=&ET;&4@/2!?*")-;W9E(%5P(BD["B`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V1O=VXG.@H@("`@
M("`@("`@("`@("`@)'1I=&QE(#T@7R@B36]V92!$;W=N(BD["B`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)VQE9G0G.@H@("`@
M("`@("`@("`@("`@)'1I=&QE(#T@7R@B36]V92!,969T(BD["B`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)W)I9VAT)SH*("`@
M("`@("`@("`@("`@("1T:71L92`](%\H(DUO=F4@4FEG:'0B*3L*("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M:6UG(#T@)'1Y<&5;,5T["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N($AO<F1E.CIL:6YK*"1U<FPL("1T:71L92D@+@H@
M("`@("`@("`@("!(;W)D93HZ:6UG*"=B;&]C:R\G("X@)&EM9R`N("<N<&YG
M)RP@)'1I=&QE+"`G)RP@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E=$EM86=E
M1&ER*"=H;W)D92<I*2`N("<\+V$^)SL*("`@('T*"B`@("`O*BH*("`@("`J
M($1O97,@82!R;W<@97AI<W0_"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)')O=R`@5&AE(')O=R!T;R!L;V]K(&9O<@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&4@<F]W(&5X:7-T<PH@("`@("HO
M"B`@("!F=6YC=&EO;B!R;W=%>&ES=',H)')O=RD*("`@('L*("`@("`@("!R
M971U<FX@)')O=R`\(&-O=6YT*"1T:&ES+3Y?;&%Y;W5T*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($1O97,@82!C;VQU;6X@97AI<W0_"B`@("`@*@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&-O;"`@5&AE(&-O;'5M;B!T;R!L;V]K(&9O
M<@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&4@
M8V]L=6UN(&5X:7-T<PH@("`@("HO"B`@("!F=6YC=&EO;B!C;VQ%>&ES=',H
M)&-O;"D*("`@('L*("`@("`@("!R971U<FX@)&-O;"`\("1T:&ES+3Y?8V]L
M=6UN<SL*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@=VED=&@@;V8@
M=&AE(&)L;V-K(&%T(&$@9VEV96X@;&]C871I;VXN"B`@("`@*B!4:&ES(')E
M='5R;G,@=&AE('=I9'1H(&EF('1H97)E(&ES(&$@8FQO8VL@870@=&AI<PH@
M("`@("H@;&]C871I;VXL(&]T:&5R=VES92!R971U<FYS(#$N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)')O=R`@02!L87EO=70@<F]W+@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&-O;"`@02!L87EO=70@8V]L=6UN+@H@("`@
M("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(&YU;6)E<B!O9B!C;VQU
M;6YS('1H:7,@8FQO8VL@<W!A;G,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M5VED=&@H)')O=RP@)&-O;"D*("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y
M*"1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=*2D@>PH@("`@("`@("`@("!R
M971U<FX@,3L*("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^
M7VQA>6]U=%LD<F]W75LD8V]L75LG=VED=&@G72DI('L*("`@("`@("`@("`@
M)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;%U;)W=I9'1H)UT@/2`Q.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/E]L87EO=71;)')O=UU;)&-O
M;%U;)W=I9'1H)UT["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE(&AE
M:6=H="!O9B!T:&4@8FQO8VL@870@82!G:79E;B!L;V-A=&EO;BX*("`@("`J
M(%1H:7,@<F5T=7)N<R!T:&4@:&5I9VAT(&EF('1H97)E(&ES(&$@8FQO8VL@
M870@=&AI<PH@("`@("H@;&]C871I;VXL(&]T:&5R=VES92!R971U<FYS(#$N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O=R`@02!L87EO=70@
M<F]W+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O;"`@02!L87EO=70@8V]L
M=6UN+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(&YU;6)E
M<B!O9B!R;W=S('1H:7,@8FQO8VL@<W!A;G,*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T2&5I9VAT*"1R;W<L("1C;VPI"B`@("!["B`@("`@("`@:68@*"%I
M<U]A<G)A>2@D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L72DI('L*("`@("`@
M("`@("`@<F5T=7)N(#$["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H
M)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;%U;)VAE:6=H="==*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L75LG:&5I9VAT)UT@
M/2`Q.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/E]L87EO=71;
M)')O=UU;)&-O;%U;)VAE:6=H="==.PH@("`@?0H*("`@("\J*@H@("`@("H@
M061D<R!A;B!E;7!T>2!B;&]C:R!A="!T:&4@<W!E8VEF:65D('!O<VET:6]N
M+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W<@($$@;&%Y;W5T
M(')O=RX*("`@("`J($!P87)A;2!I;G1E9V5R("1C;VP@($$@;&%Y;W5T(&-O
M;'5M;BX*("`@("`J+PH@("`@9G5N8W1I;VX@861D0FQO8VLH)')O=RP@)&-O
M;"D*("`@('L*("`@("`@("!I9B`H(21T:&ES+3YR;W=%>&ES=',H)')O=RDI
M('L*("`@("`@("`@("`@)'1H:7,M/F%D9%)O=R@D<F]W*3L*("`@("`@("!]
M"B`@("`@("`@:68@*"$D=&AI<RT^8V]L17AI<W1S*"1C;VPI*2!["B`@("`@
M("`@("`@("1T:&ES+3YA9&1#;VPH)&-O;"D["B`@("`@("`@?0H*("`@("`@
M("`D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L72`](&%R<F%Y*"=A<'`G(#T^
M(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G:&5I9VAT)R`]/B`Q+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W=I9'1H)R`]/B`Q+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!A<F%M<R<@/3X@87)R
M87DH)W1Y<&4G(#T^(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<&%R86US)R`]
M/B!A<G)A>2@I*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@;F5W
M(')O=R!T;R!T:&4@;&%Y;W5T+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E
M9V5R("1R;W<@(%1H92!N=6UB97(@;V8@=&AE(')O=R!T;R!A9&0*("`@("`J
M+PH@("`@9G5N8W1I;VX@861D4F]W*"1R;W<I"B`@("!["B`@("`@("`@:68@
M*"1T:&ES+3Y?8V]L=6UN<R`^(#`I('L*("`@("`@("`@("`@)'1H:7,M/E]L
M87EO=71;)')O=UT@/2!A<G)A>5]F:6QL*#`L("1T:&ES+3Y?8V]L=6UN<RP@
M)V5M<'1Y)RD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@061D
M<R!A(&YE=R!C;VQU;6X@=&\@=&AE(&QA>6]U="X*("`@("`J"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D8V]L("!4:&4@;G5M8F5R(&]F('1H92!C;VQU;6X@
M=&\@861D"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$-O;"@D8V]L*0H@("`@
M>PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?;&%Y;W5T(&%S("1I9"`]/B`D
M=F%L*2!["B`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1I9%U;)&-O;%T@
M/2`G96UP='DG.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7V-O;'5M;G,K
M*SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V97,@82!B;&]C:RX*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W("!!(&QA>6]U="!R;W<N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]L("!!(&QA>6]U="!C;VQU;6XN
M"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V94)L;V-K*"1R;W<L("1C;VPI
M"B`@("!["B`@("`@("`@)'=I9'1H(#T@)'1H:7,M/F=E=%=I9'1H*"1R;W<L
M("1C;VPI.PH@("`@("`@("1H96EG:'0@/2`D=&AI<RT^9V5T2&5I9VAT*"1R
M;W<L("1C;VPI.PH@("`@("`@(&9O<B`H)&D@/2`D:&5I9VAT("T@,3L@)&D@
M/CT@,#L@)&DM+2D@>PH@("`@("`@("`@("!F;W(@*"1J(#T@)'=I9'1H("T@
M,3L@)&H@/CT@,#L@)&HM+2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]L
M87EO=71;)')O=R`K("1I75LD8V]L("L@)&I=(#T@)V5M<'1Y)SL*("`@("`@
M("`@("`@("`@(&EF("@A)'1H:7,M/F-O;$5X:7-T<R@D8V]L("L@)&H@*R`Q
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YR96UO=F5#;VQ)9D5M
M<'1Y*"1C;VP@*R`D:BD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("`@("`@:68@*"$D=&AI<RT^<F]W17AI<W1S*"1R;W<@*R`D
M:2`K(#$I("8F("1T:&ES+3YR;W=%>&ES=',H)')O=R`K("1I*2D@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/G)E;6]V95)O=TEF16UP='DH)')O=R`K("1I
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]C
M:&%N9V5D7W)O=R`]("1R;W<["B`@("`@("`@)'1H:7,M/E]C:&%N9V5D7V-O
M;"`]("1C;VP["@H@("`@("`@(&EF("@A)'1H:7,M/G)O=T5X:7-T<R@D<F]W
M*2D@>PH@("`@("`@("`@("`D<F]W+2T["B`@("`@("`@("`@('=H:6QE("@D
M<F]W(#X](#`@)B8@)'1H:7,M/G)E;6]V95)O=TEF16UP='DH)')O=RDI('L*
M("`@("`@("`@("`@("`@("1R;W<M+3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("!I9B`H(21T:&ES+3YC;VQ%>&ES=',H)&-O;"DI('L*("`@
M("`@("`@("`@)&-O;"TM.PH@("`@("`@("`@("!W:&EL92`H)&-O;"`^/2`P
M("8F("1T:&ES+3YR96UO=F5#;VQ)9D5M<'1Y*"1C;VPI*2!["B`@("`@("`@
M("`@("`@("`D8V]L+2T["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!296UO=F5S(&$@<F]W(&EF(&ET)W,@96UP='DN
M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O=R`@5&AE(&YU;6)E
M<B!O9B!T:&4@<F]W('1O('1O(&-H96-K"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!4<G5E(&EF('1H92!R;W<@:7,@;F]W(')E;6]V960N"B`@
M("`@*B`@("`@("`@("`@("`@("`@($9A;'-E(&EF('1H92!R;W<@<W1I;&P@
M97AI<W1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F52;W=)9D5M<'1Y
M*"1R;W<I"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^<F]W17AI<W1S*"1R
M;W<I*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@
M("`@("`@)')O=W,@/2!C;W5N="@D=&AI<RT^7VQA>6]U=%LD<F]W72D["B`@
M("`@("`@9F]R("@D:2`](#`[("1I(#P@)')O=W,[("1I*RLI('L*("`@("`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1I72D@)B8@
M)'1H:7,M/E]L87EO=71;)')O=UU;)&E=("$]("=E;7!T>2<I('L*("`@("`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("!U;G-E="@D=&AI<RT^7VQA>6]U=%LD<F]W72D["@H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E
M<R!A(&-O;'5M;B!I9B!I="=S(&5M<'1Y+@H@("`@("H*("`@("`J($!P87)A
M;2!I;G1E9V5R("1C;VP@(%1H92!N=6UB97(@;V8@=&AE(&-O;'5M;B!T;R!T
M;R!C:&5C:PH@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I
M9B!T:&4@8V]L=6UN(&ES(&YO=R!R96UO=F5D+@H@("`@("H@("`@("`@("`@
M("`@("`@("!&86QS92!I9B!T:&4@8V]L=6UN('-T:6QL(&5X:7-T<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E0V]L269%;7!T>2@D8V]L*0H@("`@
M>PH@("`@("`@(&EF("@A)'1H:7,M/F-O;$5X:7-T<R@D8V]L*2D@>PH@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("1C;VQS
M(#T@8V]U;G0H)'1H:7,M/E]L87EO=70I.PH@("`@("`@(&9O<B`H)&D@/2`P
M.R`D:2`\("1C;VQS.R`D:2LK*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7VQA>6]U=%LD:5U;)&-O;%TI("8F("1T:&ES+3Y?;&%Y;W5T6R1I
M75LD8V]L72`A/2`G96UP='DG*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&9O<B`H
M)&D@/2`P.R`D:2`\("1C;VQS.R`D:2LK*2!["B`@("`@("`@("`@('5N<V5T
M*"1T:&ES+3Y?;&%Y;W5T6R1I75LD8V]L72D["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($UO=F5S(&$@
M8FQO8VL@;VYE(')O=R!U<"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D<F]W("!!(&QA>6]U="!R;W<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M8V]L("!!(&QA>6]U="!C;VQU;6XN"B`@("`@*B\*("`@(&9U;F-T:6]N(&UO
M=F55<"@D<F]W+"`D8V]L*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^<F]W
M17AI<W1S*"1R;W<@+2`Q*2D@>PH@("`@("`@("`@("`D=VED=&@@/2`D=&AI
M<RT^9V5T5VED=&@H)')O=RP@)&-O;"D["B`@("`@("`@("`@("\O(%-E92!I
M9B!T:&5R92=S(')O;VT@=&\@;6]V92!I;G1O"B`@("`@("`@("`@(&9O<B`H
M)&D@/2`P.R`D:2`\("1W:61T:#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@
M:68@*"$D=&AI<RT^:7-%;7!T>2@D<F]W("T@,2P@)&-O;"`K("1I*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1I;E]W87D@/2`D=&AI<RT^9V5T0FQO8VM!
M="@D<F]W("T@,2P@)&-O;"`K("1I*3L*("`@("`@("`@("`@("`@("`@("!I
M9B`H(6ES7VYU;&PH)&EN7W=A>2D@)B8*("`@("`@("`@("`@("`@("`@("`@
M("`@)&EN7W=A>5LQ72`]/2`D8V]L("8F"B`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YG9717:61T:"@D:6Y?=V%Y6S!=+"`D:6Y?=V%Y6S%=*2`]
M/2`D=VED=&@I('L*("`@("`@("`@("`@("`@("`@("`@("`@+R\@5V4@;F5E
M9"!T;R!S=V%P('1H92!B;&]C:W,N"B`@("`@("`@("`@("`@("`@("`@("`@
M("1R96,Q(#T@2&]R9&5?07)R87DZ.F=E=%)E8W1A;F=L92@D=&AI<RT^7VQA
M>6]U="P@)')O=RP@)&-O;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YG971(96EG
M:'0H)')O=RP@)&-O;"DL("1T:&ES+3YG9717:61T:"@D<F]W+"`D8V]L*2D[
M"B`@("`@("`@("`@("`@("`@("`@("`@("1R96,R(#T@2&]R9&5?07)R87DZ
M.F=E=%)E8W1A;F=L92@D=&AI<RT^7VQA>6]U="P@)&EN7W=A>5LP72P@)&EN
M7W=A>5LQ72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YG971(96EG:'0H)&EN7W=A
M>5LP72P@)&EN7W=A>5LQ72DL("1T:&ES+3YG9717:61T:"@D:6Y?=V%Y6S!=
M+"`D:6Y?=V%Y6S%=*2D["B`@("`@("`@("`@("`@("`@("`@("`@(&9O<B`H
M)&H@/2`P.R`D:B`\(&-O=6YT*"1R96,Q*3L@)&HK*RD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@9F]R("@D:R`](#`[("1K(#P@8V]U;G0H)')E
M8S%;)&I=*3L@)&LK*RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?;&%Y;W5T6R1I;E]W87E;,%T@*R`D:EU;)&EN7W=A>5LQ
M72`K("1K72`]("1R96,Q6R1J75LD:UT["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`@("`@9F]R("@D:B`](#`[("1J(#P@8V]U;G0H)')E8S(I
M.R`D:BLK*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W(@*"1K
M(#T@,#L@)&L@/"!C;W5N="@D<F5C,ELD:ETI.R`D:RLK*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)&EN7W=A
M>5LP72`K(&-O=6YT*"1R96,Q*2`K("1J75LD:6Y?=V%Y6S%=("L@)&M=(#T@
M)')E8S);)&I=6R1K73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7V-H86YG961?<F]W(#T@)&EN7W=A>5LP73L*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C:&%N9V5D7V-O;"`]("1I;E]W
M87E;,5T["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;CL*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@+R\@3F]W:&5R
M92!T;R!G;RX*("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BA?*")3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH
M<RD@;W5T(&]F('1H92!W87D@9FER<W0B*2P@)VAO<F1E+G=A<FYI;F<G*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M)&QA<W1R;W<@/2`D<F]W("L@)'1H:7,M/F=E=$AE:6=H="@D<F]W+"`D8V]L
M*2`M(#$["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1W:61T:#L@
M)&DK*RD@>PH@("`@("`@("`@("`@("`@)'!R978@/2`D=&AI<RT^7VQA>6]U
M=%LD<F]W75LD8V]L("L@)&E=.PH@("`@("`@("`@("`@("`@+R\@36]V92!T
M;W`@961G90H@("`@("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=R`M
M(#%=6R1C;VP@*R`D:5T@/2`D<')E=CL*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?;&%Y;W5T6R1R;W==6R1C;VP@*R`D:5T@/2`G8V]V97)E9"<["B`@("`@
M("`@("`@("`@("`O+R!-;W9E(&)O='1O;2!E9&=E"B`@("`@("`@("`@("`@
M("`D=&AI<RT^7VQA>6]U=%LD;&%S=')O=UU;)&-O;"`K("1I72`]("=E;7!T
M>2<["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@A)'1H:7,M/G)O
M=T5X:7-T<R@D;&%S=')O=R`K(#$I*2!["B`@("`@("`@("`@("`@("`O+R!7
M87,@;VX@=&AE(&)O='1O;2!R;W<*("`@("`@("`@("`@("`@("1T:&ES+3YR
M96UO=F52;W=)9D5M<'1Y*"1L87-T<F]W*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@)'1H:7,M/E]C:&%N9V5D7W)O=R`]("1R;W<@+2`Q
M.PH@("`@("`@("1T:&ES+3Y?8VAA;F=E9%]C;VP@/2`D8V]L.PH@("`@?0H*
M("`@("\J*@H@("`@("H@36]V97,@82!B;&]C:R!O;F4@<F]W(&1O=VXN"B`@
M("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O=R`@02!L87EO=70@<F]W
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O;"`@02!L87EO=70@8V]L=6UN
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!M;W9E1&]W;B@D<F]W+"`D8V]L*0H@
M("`@>PH@("`@("`@("1W:61T:"`]("1T:&ES+3YG9717:61T:"@D<F]W+"`D
M8V]L*3L*("`@("`@("`D;&%S=')O=R`]("1R;W<@*R`D=&AI<RT^9V5T2&5I
M9VAT*"1R;W<L("1C;VPI.PH@("`@("`@(&EF("@D=&AI<RT^<F]W17AI<W1S
M*"1L87-T<F]W*2D@>PH@("`@("`@("`@("`O+R!3964@:68@=&AE<F4G<R!R
M;V]M('1O(&UO=F4@:6YT;PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@
M/"`D=VED=&@[("1I*RLI('L*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M
M/FES16UP='DH)&QA<W1R;W<L("1C;VP@*R`D:2DI('L*("`@("`@("`@("`@
M("`@("`@("`D:6Y?=V%Y(#T@)'1H:7,M/F=E=$)L;V-K070H)&QA<W1R;W<L
M("1C;VP@*R`D:2D["B`@("`@("`@("`@("`@("`@("`@:68@*"%I<U]N=6QL
M*"1I;E]W87DI("8F"B`@("`@("`@("`@("`@("`@("`@("`@("1I;E]W87E;
M,5T@/3T@)&-O;"`F)@H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M9V5T5VED=&@H)&EN7W=A>5LP72P@)&EN7W=A>5LQ72D@/3T@)'=I9'1H*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("\O(%=E(&YE960@=&\@<W=A<"!T
M:&4@8FQO8VMS+@H@("`@("`@("`@("`@("`@("`@("`@("`D<F5C,2`]($AO
M<F1E7T%R<F%Y.CIG971296-T86YG;&4H)'1H:7,M/E]L87EO=70L("1R;W<L
M("1C;VPL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9V5T2&5I9VAT*"1R;W<L("1C
M;VPI+"`D=&AI<RT^9V5T5VED=&@H)')O=RP@)&-O;"DI.PH@("`@("`@("`@
M("`@("`@("`@("`@("`D<F5C,B`]($AO<F1E7T%R<F%Y.CIG971296-T86YG
M;&4H)'1H:7,M/E]L87EO=70L("1I;E]W87E;,%TL("1I;E]W87E;,5TL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^9V5T2&5I9VAT*"1I;E]W87E;,%TL("1I;E]W
M87E;,5TI+"`D=&AI<RT^9V5T5VED=&@H)&EN7W=A>5LP72P@)&EN7W=A>5LQ
M72DI.PH@("`@("`@("`@("`@("`@("`@("`@("!F;W(@*"1J(#T@,#L@)&H@
M/"!C;W5N="@D<F5C,BD[("1J*RLI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&9O<B`H)&L@/2`P.R`D:R`\(&-O=6YT*"1R96,R6R1J72D[("1K
M*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7VQA>6]U=%LD<F]W("L@)&I=6R1C;VP@*R`D:UT@/2`D<F5C,ELD:EU;)&M=
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@(&9O<B`H)&H@
M/2`P.R`D:B`\(&-O=6YT*"1R96,Q*3L@)&HK*RD@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@9F]R("@D:R`](#`[("1K(#P@8V]U;G0H)')E8S%;
M)&I=*3L@)&LK*RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?;&%Y;W5T6R1R;W<@*R!C;W5N="@D<F5C,BD@*R`D:EU;)&-O
M;"`K("1K72`]("1R96,Q6R1J75LD:UT["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]C:&%N9V5D7W)O=R`]("1I;E]W87E;
M,%T["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8VAA;F=E9%]C
M;VP@/2`D:6Y?=V%Y6S%=.PH@("`@("`@("`@("`@("`@("`@("`@("!R971U
M<FX["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M("\O($YO('=H97)E('1O(&=O"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R
M:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(BDL("=H;W)D92YW
M87)N:6YG)RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!-86ME(')O;VT@=&\@;6]V
M92!I;G1O"B`@("`@("`@("`@("1T:&ES+3YA9&12;W<H)&QA<W1R;W<I.PH@
M("`@("`@('T*"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)'=I9'1H.R`D
M:2LK*2!["B`@("`@("`@("`@("1P<F5V(#T@)'1H:7,M/E]L87EO=71;)')O
M=UU;)&-O;"`K("1I73L*("`@("`@("`@("`@+R\@36]V92!B;W1T;VT@961G
M90H@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD;&%S=')O=UU;)&-O;"`K
M("1I72`]("=C;W9E<F5D)SL*("`@("`@("`@("`@+R\@36]V92!T;W`@961G
M90H@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W("L@,5U;)&-O;"`K
M("1I72`]("1P<F5V.PH@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W
M75LD8V]L("L@)&E=(#T@)V5M<'1Y)SL*("`@("`@("!]"@H@("`@("`@("1T
M:&ES+3Y?8VAA;F=E9%]R;W<@/2`D<F]W("L@,3L*("`@("`@("`D=&AI<RT^
M7V-H86YG961?8V]L(#T@)&-O;#L*("`@('T*"B`@("`O*BH*("`@("`J($UO
M=F5S(&%L;"!B;&]C:W,@8F5L;W<@82!C97)T86EN(')O=R!O;F4@<F]W(&1O
M=VXN"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O=R`@02!L87EO
M=70@<F]W+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I
M9B!A;&P@<F]W<R!C;W5L9"!B92!M;W9E9"!D;W=N+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!M;W9E1&]W;D)E;&]W*"1R;W<I"B`@("!["B`@("`@("`@)&UO
M=F5D(#T@87)R87DH*3L*("`@("`@("!F;W(@*"1Y(#T@8V]U;G0H)'1H:7,M
M/E]L87EO=70I("T@,3L@)'D@/B`D<F]W.R`D>2TM*2!["B`@("`@("`@("`@
M(&9O<B`H)'@@/2`P.R`D>"`\("1T:&ES+3Y?8V]L=6UN<SL@)'@K*RD@>PH@
M("`@("`@("`@("`@("`@)&)L;V-K(#T@)'1H:7,M/F=E=$)L;V-K070H)'DL
M("1X*3L*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D8FQO8VLI*2!["B`@
M("`@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!I9B`H96UP='DH)&UO=F5D6R1B;&]C:ULQ72`N
M("<Z)R`N("1B;&]C:ULP75TI*2!["B`@("`@("`@("`@("`@("`@("`@)&UO
M=F5D6R1B;&]C:ULQ72`N("<Z)R`N("1B;&]C:ULP75T@/2!T<G5E.PH@("`@
M("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^;6]V941O=VXH)&)L
M;V-K6S!=+"`D8FQO8VM;,5TI.PH@("`@("`@("`@("`@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($UO=F5S
M(&$@8FQO8VL@;VYE(&-O;'5M;B!L969T+@H@("`@("H*("`@("`J($!P87)A
M;2!I;G1E9V5R("1R;W<@($$@;&%Y;W5T(')O=RX*("`@("`J($!P87)A;2!I
M;G1E9V5R("1C;VP@($$@;&%Y;W5T(&-O;'5M;BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@;6]V94QE9G0H)')O=RP@)&-O;"D*("`@('L*("`@("`@("!I9B`H
M)'1H:7,M/F-O;$5X:7-T<R@D8V]L("T@,2DI('L*("`@("`@("`@("`@)&AE
M:6=H="`]("1T:&ES+3YG971(96EG:'0H)')O=RP@)&-O;"D["B`@("`@("`@
M("`@("\O(%-E92!I9B!T:&5R92=S(')O;VT@=&\@;6]V92!I;G1O+@H@("`@
M("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D:&5I9VAT.R`D:2LK*2!["B`@
M("`@("`@("`@("`@("!I9B`H(21T:&ES+3YI<T5M<'1Y*"1R;W<@*R`D:2P@
M)&-O;"`M(#$I*2!["B`@("`@("`@("`@("`@("`@("`@)&EN7W=A>2`]("1T
M:&ES+3YG971";&]C:T%T*"1R;W<@*R`D:2P@)&-O;"`M(#$I.PH@("`@("`@
M("`@("`@("`@("`@(&EF("@A:7-?;G5L;"@D:6Y?=V%Y*2`F)@H@("`@("`@
M("`@("`@("`@("`@("`@("`D:6Y?=V%Y6S!=(#T]("1R;W<@)B8*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/F=E=$AE:6=H="@D:6Y?=V%Y6S!=
M+"`D:6Y?=V%Y6S%=*2`]/2`D:&5I9VAT*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("\O(%=E(&YE960@=&\@<W=A<"!T:&4@8FQO8VMS+@H@("`@("`@
M("`@("`@("`@("`@("`@("`D<F5C,2`]($AO<F1E7T%R<F%Y.CIG971296-T
M86YG;&4H)'1H:7,M/E]L87EO=70L("1R;W<L("1C;VPL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^9V5T2&5I9VAT*"1R;W<L("1C;VPI+"`D=&AI<RT^9V5T5VED
M=&@H)')O=RP@)&-O;"DI.PH@("`@("`@("`@("`@("`@("`@("`@("`D<F5C
M,B`]($AO<F1E7T%R<F%Y.CIG971296-T86YG;&4H)'1H:7,M/E]L87EO=70L
M("1I;E]W87E;,%TL("1I;E]W87E;,5TL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M9V5T2&5I9VAT*"1I;E]W87E;,%TL("1I;E]W87E;,5TI+"`D=&AI<RT^9V5T
M5VED=&@H)&EN7W=A>5LP72P@)&EN7W=A>5LQ72DI.PH@("`@("`@("`@("`@
M("`@("`@("`@("!F;W(@*"1J(#T@,#L@)&H@/"!C;W5N="@D<F5C,2D[("1J
M*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O<B`H)&L@/2`P
M.R`D:R`\(&-O=6YT*"1R96,Q6R1J72D[("1K*RLI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD:6Y?=V%Y6S!=
M("L@)&I=6R1I;E]W87E;,5T@*R`D:UT@/2`D<F5C,5LD:EU;)&M=.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@(&9O<B`H)&H@/2`P.R`D
M:B`\(&-O=6YT*"1R96,R*3L@)&HK*RD@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@9F]R("@D:R`](#`[("1K(#P@8V]U;G0H)')E8S);)&I=*3L@
M)&LK*RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?;&%Y;W5T6R1I;E]W87E;,%T@*R`D:EU;)&EN7W=A>5LQ72`K(&-O=6YT
M*"1R96,Q6R1J72D@*R`D:UT@/2`D<F5C,ELD:EU;)&M=.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8VAA;F=E9%]R;W<@
M/2`D:6Y?=V%Y6S!=.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V-H86YG961?8V]L(#T@)&EN7W=A>5LQ73L*("`@("`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`O+R!.;R!W:&5R92!T;R!G;PH@("`@("`@("`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E-H<FEN:R!O<B!M;W9E
M(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(I
M+"`G:&]R9&4N=V%R;FEN9R<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`D;&%S=&-O;"`]("1C;VP@*R`D=&AI<RT^
M9V5T5VED=&@H)')O=RP@)&-O;"D@+2`Q.PH@("`@("`@("`@("!F;W(@*"1I
M(#T@,#L@)&D@/"`D:&5I9VAT.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D
M<')E=B`]("1T:&ES+3Y?;&%Y;W5T6R1R;W<@*R`D:5U;)&-O;%T["B`@("`@
M("`@("`@("`@("`O+R!-;W9E(&QE9G0@:&%N9"!E9&=E"B`@("`@("`@("`@
M("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W("L@)&E=6R1C;VP@+2`Q72`]("1P
M<F5V.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=R`K("1I
M75LD8V]L72`]("=C;W9E<F5D)SL*("`@("`@("`@("`@("`@("\O($UO=F4@
M<FEG:'0@:&%N9"!E9&=E"B`@("`@("`@("`@("`@("`D=&AI<RT^7VQA>6]U
M=%LD<F]W("L@)&E=6R1L87-T8V]L72`]("=E;7!T>2<["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@(&EF("@A)'1H:7,M/F-O;$5X:7-T<R@D;&%S=&-O
M;"`K(#$I*2!["B`@("`@("`@("`@("`@("`O+R!787,@;VX@=&AE(')I9VAT
M+6UO<W0@8V]L=6UN"B`@("`@("`@("`@("`@("`D=&AI<RT^<F5M;W9E0V]L
M269%;7!T>2@D;&%S=&-O;"D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1T:&ES+3Y?8VAA;F=E9%]R;W<@/2`D<F]W.PH@("`@("`@("`@("`D=&AI
M<RT^7V-H86YG961?8V]L(#T@)&-O;"`M(#$["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@36]V97,@82!B;&]C:R!O;F4@8V]L=6UN(')I9VAT
M+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W<@($$@;&%Y;W5T
M(')O=RX*("`@("`J($!P87)A;2!I;G1E9V5R("1C;VP@($$@;&%Y;W5T(&-O
M;'5M;BX*("`@("`J+PH@("`@9G5N8W1I;VX@;6]V95)I9VAT*"1R;W<L("1C
M;VPI"B`@("!["B`@("`@("`@)&AE:6=H="`]("1T:&ES+3YG971(96EG:'0H
M)')O=RP@)&-O;"D["B`@("`@("`@)&QA<W1C;VP@/2`D8V]L("L@)'1H:7,M
M/F=E=%=I9'1H*"1R;W<L("1C;VPI.PH@("`@("`@(&EF("@D=&AI<RT^8V]L
M17AI<W1S*"1L87-T8V]L*2D@>PH@("`@("`@("`@("`O+R!3964@:68@=&AE
M<F4G<R!R;V]M('1O(&UO=F4@:6YT;RX*("`@("`@("`@("`@9F]R("@D:2`]
M(#`[("1I(#P@)&AE:6=H=#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@:68@
M*"$D=&AI<RT^:7-%;7!T>2@D<F]W("L@)&DL("1L87-T8V]L*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1I;E]W87D@/2`D=&AI<RT^9V5T0FQO8VM!="@D
M<F]W("L@)&DL("1L87-T8V]L*3L*("`@("`@("`@("`@("`@("`@("!I9B`H
M(6ES7VYU;&PH)&EN7W=A>2D@)B8*("`@("`@("`@("`@("`@("`@("`@("`@
M)&EN7W=A>5LP72`]/2`D<F]W("8F"B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YG971(96EG:'0H)&EN7W=A>5LP72P@)&EN7W=A>5LQ72D@/3T@
M)&AE:6=H="D@>PH@("`@("`@("`@("`@("`@("`@("`@("`O+R!792!N965D
M('1O('-W87`@=&AE(&)L;V-K<RX*("`@("`@("`@("`@("`@("`@("`@("`@
M)')E8S$@/2!(;W)D95]!<G)A>3HZ9V5T4F5C=&%N9VQE*"1T:&ES+3Y?;&%Y
M;W5T+"`D<F]W+"`D8V]L+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F=E=$AE:6=H
M="@D<F]W+"`D8V]L*2P@)'1H:7,M/F=E=%=I9'1H*"1R;W<L("1C;VPI*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@)')E8S(@/2!(;W)D95]!<G)A>3HZ
M9V5T4F5C=&%N9VQE*"1T:&ES+3Y?;&%Y;W5T+"`D:6Y?=V%Y6S!=+"`D:6Y?
M=V%Y6S%=+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F=E=$AE:6=H="@D:6Y?=V%Y
M6S!=+"`D:6Y?=V%Y6S%=*2P@)'1H:7,M/F=E=%=I9'1H*"1I;E]W87E;,%TL
M("1I;E]W87E;,5TI*3L*("`@("`@("`@("`@("`@("`@("`@("`@9F]R("@D
M:B`](#`[("1J(#P@8V]U;G0H)')E8S(I.R`D:BLK*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!F;W(@*"1K(#T@,#L@)&L@/"!C;W5N="@D<F5C
M,ELD:ETI.R`D:RLK*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]L87EO=71;)')O=R`K("1J75LD8V]L("L@)&M=(#T@)')E
M8S);)&I=6R1K73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@
M("!F;W(@*"1J(#T@,#L@)&H@/"!C;W5N="@D<F5C,2D[("1J*RLI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&9O<B`H)&L@/2`P.R`D:R`\(&-O
M=6YT*"1R96,Q6R1J72D[("1K*RLI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W("L@)&I=6R1C;VP@*R!C
M;W5N="@D<F5C,ELD:ETI("L@)&M=(#T@)')E8S%;)&I=6R1K73L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-H86YG961?
M<F]W(#T@)&EN7W=A>5LP73L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]C:&%N9V5D7V-O;"`]("1I;E]W87E;,5T["B`@("`@("`@("`@("`@
M("`@("`@("`@(')E='5R;CL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@+R\@3F\@=VAE<F4@=&\@9V\*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")3:')I;FL@;W(@
M;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER
M<W0B*2P@)VAO<F1E+G=A<FYI;F<G*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O($UA
M:V4@<F]O;2!T;R!M;W9E(&EN=&\N"B`@("`@("`@("`@("1T:&ES+3YA9&1#
M;VPH)&QA<W1C;VPI.PH@("`@("`@('T*"B`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P@)&AE:6=H=#L@)&DK*RD@>PH@("`@("`@("`@("`D<')E=B`]("1T
M:&ES+3Y?;&%Y;W5T6R1R;W<@*R`D:5U;)&-O;%T["B`@("`@("`@("`@("\O
M($UO=F4@<FEG:'0@:&%N9"!E9&=E"B`@("`@("`@("`@("1T:&ES+3Y?;&%Y
M;W5T6R1R;W<@*R`D:5U;)&QA<W1C;VQ=(#T@)V-O=F5R960G.PH@("`@("`@
M("`@("`O+R!-;W9E(&QE9G0@:&%N9"!E9&=E"B`@("`@("`@("`@("1T:&ES
M+3Y?;&%Y;W5T6R1R;W<@*R`D:5U;)&-O;"`K(#%=(#T@)'!R978["B`@("`@
M("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W<@*R`D:5U;)&-O;%T@/2`G96UP
M='DG.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]C:&%N9V5D7W)O=R`]
M("1R;W<["B`@("`@("`@)'1H:7,M/E]C:&%N9V5D7V-O;"`]("1C;VP@*R`Q
M.PH@("`@?0H*("`@("\J*@H@("`@("H@36]V97,@86QL(&)L;V-K<R!A9G1E
M<B!A(&-E<G1A:6X@8V]L=6UN(&]N92!C;VQU;6X@<FEG:'0N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&-O;"`@02!L87EO=70@8V]L=6UN+@H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!A;&P@8V]L
M=6UN<R!C;W5L9"!B92!M;W9E9"!R:6=H="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@;6]V95)I9VAT069T97(H)&-O;"D*("`@('L*("`@("`@("`D;6]V960@
M/2!A<G)A>2@I.PH@("`@("`@(&9O<B`H)'@@/2`D=&AI<RT^7V-O;'5M;G,@
M+2`Q.R`D>"`^("1C;VP[("1X+2TI('L*("`@("`@("`@("`@9F]R("@D>2`]
M(#`[("1Y(#P@8V]U;G0H)'1H:7,M/E]L87EO=70I.R`D>2LK*2!["B`@("`@
M("`@("`@("`@("`D8FQO8VL@/2`D=&AI<RT^9V5T0FQO8VM!="@D>2P@)'@I
M.PH@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1B;&]C:RDI('L*("`@("`@
M("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&EF("AE;7!T>2@D;6]V961;)&)L;V-K6S%=("X@)SHG
M("X@)&)L;V-K6S!=72DI('L*("`@("`@("`@("`@("`@("`@("`D;6]V961;
M)&)L;V-K6S%=("X@)SHG("X@)&)L;V-K6S!=72`]('1R=64["B`@("`@("`@
M("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YM;W9E4FEG:'0H)&)L;V-K
M6S!=+"`D8FQO8VM;,5TI.PH@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($UA:V5S(&$@
M8FQO8VL@;VYE(')O=R!T86QL97(@8GD@;6]V:6YG('1H92!T;W`@=7`N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O=R`@02!L87EO=70@<F]W
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O;"`@02!L87EO=70@8V]L=6UN
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>'!A;F15<"@D<F]W+"`D8V]L*0H@
M("`@>PH@("`@("`@(&EF("@D=&AI<RT^<F]W17AI<W1S*"1R;W<@+2`Q*2D@
M>PH@("`@("`@("`@("`D=VED=&@@/2`D=&AI<RT^9V5T5VED=&@H)')O=RP@
M)&-O;"D["B`@("`@("`@("`@("\O(%-E92!I9B!T:&5R92=S(')O;VT@=&\@
M97AP86YD(&EN=&\*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)'=I
M9'1H.R`D:2LK*2!["B`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3YI<T5M
M<'1Y*"1R;W<@+2`Q+"`D8V]L("L@)&DI*2!["B`@("`@("`@("`@("`@("`@
M("`@:68@*"$D=&AI<RT^;6]V941O=VY"96QO=R@D<F]W("T@,2DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M7R@B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O
M9B!T:&4@=V%Y(&9I<G-T(BDL("=H;W)D92YW87)N:6YG)RD["B`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)')O=RLK.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I
M(#P@)'=I9'1H.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VQA
M>6]U=%LD<F]W("T@,5U;)&-O;"`K("1I72`]("1T:&ES+3Y?;&%Y;W5T6R1R
M;W==6R1C;VP@*R`D:5T["B`@("`@("`@("`@("`@("`D=&AI<RT^7VQA>6]U
M=%LD<F]W75LD8V]L("L@)&E=(#T@)V-O=F5R960G.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W<@+2`Q75LD8V]L75LG
M:&5I9VAT)UT@/2`D=&AI<RT^9V5T2&5I9VAT*"1R;W<@+2`Q+"`D8V]L*2`K
M(#$["@H@("`@("`@("`@("`D=&AI<RT^7V-H86YG961?<F]W(#T@)')O=R`M
M(#$["B`@("`@("`@("`@("1T:&ES+3Y?8VAA;F=E9%]C;VP@/2`D8V]L.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($UA:V5S(&$@8FQO8VL@
M;VYE(')O=R!T86QL97(@8GD@;6]V:6YG('1H92!B;W1T;VT@9&]W;BX*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W("!!(&QA>6]U="!R;W<N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]L("!!(&QA>6]U="!C;VQU;6XN
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X<&%N9$1O=VXH)')O=RP@)&-O;"D*
M("`@('L*("`@("`@("`D=VED=&@@/2`D=&AI<RT^9V5T5VED=&@H)')O=RP@
M)&-O;"D["B`@("`@("`@)&QA<W1R;W<@/2`D<F]W("L@)'1H:7,M/F=E=$AE
M:6=H="@D<F]W+"`D8V]L*2`M(#$["B`@("`@("`@:68@*"$D=&AI<RT^<F]W
M17AI<W1S*"1L87-T<F]W("L@,2DI('L*("`@("`@("`@("`@+R\@061D(&$@
M;F5W(')O=RX*("`@("`@("`@("`@)'1H:7,M/F%D9%)O=R@D;&%S=')O=R`K
M(#$I.PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D=VED=&@[("1I
M*RLI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1L87-T<F]W
M("L@,5U;)&-O;"`K("1I72`]("=C;W9E<F5D)SL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L75LG:&5I9VAT
M)UT@/2`D=&AI<RT^9V5T2&5I9VAT*"1R;W<L("1C;VPI("L@,3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`O+R!3964@:68@=&AE<F4G<R!R;V]M
M('1O(&5X<&%N9"!I;G1O"B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M("1W:61T:#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@:68@*"$D=&AI<RT^
M:7-%;7!T>2@D;&%S=')O=R`K(#$L("1C;VP@*R`D:2DI('L*("`@("`@("`@
M("`@("`@("`@("!I9B`H(21T:&ES+3YM;W9E1&]W;D)E;&]W*"1L87-T<F]W
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BA?*")3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH
M<RD@;W5T(&]F('1H92!W87D@9FER<W0B*2P@)VAO<F1E+G=A<FYI;F<G*3L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1W:61T
M:#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)&QA
M<W1R;W<@*R`Q75LD8V]L("L@)&E=(#T@)V-O=F5R960G.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=6R=H
M96EG:'0G72`]("1T:&ES+3YG971(96EG:'0H)')O=RP@)&-O;"D@*R`Q.PH@
M("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]C:&%N9V5D7W)O=R`]("1R;W<[
M"B`@("`@("`@)'1H:7,M/E]C:&%N9V5D7V-O;"`]("1C;VP["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!-86ME<R!A(&)L;V-K(&]N92!C;VQU;6X@=VED97(@
M8GD@;6]V:6YG('1H92!L969T('-I9&4@;W5T+@H@("`@("H*("`@("`J($!P
M87)A;2!I;G1E9V5R("1R;W<@($$@;&%Y;W5T(')O=RX*("`@("`J($!P87)A
M;2!I;G1E9V5R("1C;VP@($$@;&%Y;W5T(&-O;'5M;BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@97AP86YD3&5F="@D<F]W+"`D8V]L*0H@("`@>PH@("`@("`@
M(&EF("@D=&AI<RT^8V]L17AI<W1S*"1C;VP@+2`Q*2D@>PH@("`@("`@("`@
M("`D:&5I9VAT(#T@)'1H:7,M/F=E=$AE:6=H="@D<F]W+"`D8V]L*3L*("`@
M("`@("`@("`@+R\@4V5E(&EF('1H97)E)W,@<F]O;2!T;R!E>'!A;F0@:6YT
M;PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D:&5I9VAT.R`D:2LK
M*2!["B`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3YI<T5M<'1Y*"1R;W<@
M*R`D:2P@)&-O;"`M(#$I*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"$D
M=&AI<RT^;6]V95)I9VAT069T97(H)&-O;"`M(#$I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E-H<FEN
M:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A
M>2!F:7)S="(I+"`G:&]R9&4N=V%R;FEN9R<I.PH@("`@("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1C;VPK*SL*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1H96EG
M:'0[("1I*RLI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R
M;W<@*R`D:5U;)&-O;"`M(#%=(#T@)'1H:7,M/E]L87EO=71;)')O=R`K("1I
M75LD8V]L73L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W<@
M*R`D:5U;)&-O;%T@/2`G8V]V97)E9"<["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;"`M(#%=6R=W:61T:"==
M(#T@)'1H:7,M/F=E=%=I9'1H*"1R;W<L("1C;VP@+2`Q*2`K(#$["@H@("`@
M("`@("`@("`D=&AI<RT^7V-H86YG961?<F]W(#T@)')O=SL*("`@("`@("`@
M("`@)'1H:7,M/E]C:&%N9V5D7V-O;"`]("1C;VP@+2`Q.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($UA:V5S(&$@8FQO8VL@;VYE(&-O;'5M
M;B!W:61E<B!B>2!M;W9I;F<@=&AE(')I9VAT('-I9&4@;W5T+@H@("`@("H*
M("`@("`J($!P87)A;2!I;G1E9V5R("1R;W<@($$@;&%Y;W5T(')O=RX*("`@
M("`J($!P87)A;2!I;G1E9V5R("1C;VP@($$@;&%Y;W5T(&-O;'5M;BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@97AP86YD4FEG:'0H)')O=RP@)&-O;"D*("`@
M('L*("`@("`@("`D:&5I9VAT(#T@)'1H:7,M/F=E=$AE:6=H="@D<F]W+"`D
M8V]L*3L*("`@("`@("`D;&%S=&-O;"`]("1C;VP@*R`D=&AI<RT^9V5T5VED
M=&@H)')O=RP@)&-O;"D@+2`Q.PH@("`@("`@(&EF("@D=&AI<RT^8V]L17AI
M<W1S*"1L87-T8V]L("L@,2DI('L*("`@("`@("`@("`@+R\@4V5E(&EF('1H
M97)E)W,@<F]O;2!T;R!E>'!A;F0@:6YT;PH@("`@("`@("`@("!F;W(@*"1I
M(#T@,#L@)&D@/"`D:&5I9VAT.R`D:2LK*2!["B`@("`@("`@("`@("`@("!I
M9B`H(21T:&ES+3YI<T5M<'1Y*"1R;W<@*R`D:2P@)&QA<W1C;VP@*R`Q*2D@
M>PH@("`@("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/FUO=F52:6=H=$%F
M=&5R*"1L87-T8V]L*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")3:')I;FL@;W(@;6]V92!N96EG:&)O
M=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0B*2P@)VAO<F1E
M+G=A<FYI;F<G*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&9O<B`H)&D@/2`P
M.R`D:2`\("1H96EG:'0[("1I*RLI('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?;&%Y;W5T6R1R;W<@*R`D:5U;)&QA<W1C;VP@*R`Q72`]("=C;W9E<F5D
M)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD
M<F]W75LD8V]L75LG=VED=&@G72`]("1T:&ES+3YG9717:61T:"@D<F]W+"`D
M8V]L*2`K(#$["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@061D
M(&YE=R!C;VQU;6X*("`@("`@("`@("`@)'1H:7,M/F%D9$-O;"@D;&%S=&-O
M;"`K(#$I.PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D:&5I9VAT
M.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W
M("L@)&E=6R1L87-T8V]L("L@,5T@/2`G8V]V97)E9"<["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;%U;)W=I
M9'1H)UT@/2`D=&AI<RT^9V5T5VED=&@H)')O=RP@)&-O;"D@*R`Q.PH@("`@
M("`@('T*"B`@("`@("`@)'1H:7,M/E]C:&%N9V5D7W)O=R`]("1R;W<["B`@
M("`@("`@)'1H:7,M/E]C:&%N9V5D7V-O;"`]("1C;VP["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!-86ME<R!A(&)L;V-K(&]N92!R;W<@;&]W97(@8GD@;6]V
M:6YG('1H92!T;W`@9&]W;BX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D<F]W("!!(&QA>6]U="!R;W<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M8V]L("!!(&QA>6]U="!C;VQU;6XN"B`@("`@*B\*("`@(&9U;F-T:6]N('-H
M<FEN:U5P*"1R;W<L("1C;VPI"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YG
M971(96EG:'0H)')O=RP@)&-O;"D@/B`Q*2!["B`@("`@("`@("`@("1W:61T
M:"`]("1T:&ES+3YG9717:61T:"@D<F]W+"`D8V]L*3L*("`@("`@("`@("`@
M9F]R("@D:2`](#`[("1I(#P@)'=I9'1H.R`D:2LK*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W("L@,5U;)&-O;"`K("1I72`]("1T
M:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VP@*R`D:5T["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L("L@)&E=(#T@)V5M<'1Y)SL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W
M("L@,5U;)&-O;%U;)VAE:6=H="==(#T@)'1H:7,M/F=E=$AE:6=H="@D<F]W
M("L@,2P@)&-O;"D@+2`Q.PH*("`@("`@("`@("`@)'1H:7,M/E]C:&%N9V5D
M7W)O=R`]("1R;W<@*R`Q.PH@("`@("`@("`@("`D=&AI<RT^7V-H86YG961?
M8V]L(#T@)&-O;#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!-
M86ME<R!A(&)L;V-K(&]N92!R;W<@;&]W97(@8GD@;6]V:6YG('1H92!B;W1T
M;VT@=7`N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O=R`@02!L
M87EO=70@<F]W+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O;"`@02!L87EO
M=70@8V]L=6UN+@H@("`@("HO"B`@("!F=6YC=&EO;B!S:')I;FM$;W=N*"1R
M;W<L("1C;VPI"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YG971(96EG:'0H
M)')O=RP@)&-O;"D@/B`Q*2!["B`@("`@("`@("`@("1L87-T<F]W(#T@)')O
M=R`K("1T:&ES+3YG971(96EG:'0H)')O=RP@)&-O;"D@+2`Q.PH@("`@("`@
M("`@("`D=VED=&@@/2`D=&AI<RT^9V5T5VED=&@H)')O=RP@)&-O;"D["B`@
M("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1W:61T:#L@)&DK*RD@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)&QA<W1R;W==6R1C;VP@
M*R`D:5T@/2`G96UP='DG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T
M:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=6R=H96EG:'0G72`]("1T:&ES+3YG
M971(96EG:'0H)')O=RP@)&-O;"D@+2`Q.PH@("`@("`@("`@("!I9B`H(21T
M:&ES+3YR;W=%>&ES=',H)&QA<W1R;W<@*R`Q*2D@>PH@("`@("`@("`@("`@
M("`@+R\@5V%S(&]N('1H92!B;W1T;VT@<F]W"B`@("`@("`@("`@("`@("`D
M=&AI<RT^<F5M;W9E4F]W269%;7!T>2@D;&%S=')O=RD["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("1T:&ES+3Y?8VAA;F=E9%]R;W<@/2`D<F]W.PH@
M("`@("`@("`@("`D=&AI<RT^7V-H86YG961?8V]L(#T@)&-O;#L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!-86ME<R!A(&)L;V-K(&]N92!C
M;VQU;6X@;F%R<F]W97(@8GD@;6]V:6YG('1H92!L969T('-I9&4@:6XN"B`@
M("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O=R`@02!L87EO=70@<F]W
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O;"`@02!L87EO=70@8V]L=6UN
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!S:')I;FM,969T*"1R;W<L("1C;VPI
M"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YG9717:61T:"@D<F]W+"`D8V]L
M*2`^(#$I('L*("`@("`@("`@("`@)&AE:6=H="`]("1T:&ES+3YG971(96EG
M:'0H)')O=RP@)&-O;"D["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M("1H96EG:'0[("1I*RLI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;&%Y
M;W5T6R1R;W<@*R`D:5U;)&-O;"`K(#%=(#T@)'1H:7,M/E]L87EO=71;)')O
M=R`K("1I75LD8V]L73L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T
M6R1R;W<@*R`D:5U;)&-O;%T@/2`G96UP='DG.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VP@*R`Q75LG=VED
M=&@G72`]("1T:&ES+3YG9717:61T:"@D<F]W+"`D8V]L("L@,2D@+2`Q.PH*
M("`@("`@("`@("`@)'1H:7,M/E]C:&%N9V5D7W)O=R`]("1R;W<["B`@("`@
M("`@("`@("1T:&ES+3Y?8VAA;F=E9%]C;VP@/2`D8V]L("L@,3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!-86ME<R!A(&)L;V-K(&]N92!C
M;VQU;6X@;F%R<F]W97(@8GD@;6]V:6YG('1H92!R:6=H="!S:61E(&EN+@H@
M("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W<@($$@;&%Y;W5T(')O
M=RX*("`@("`J($!P87)A;2!I;G1E9V5R("1C;VP@($$@;&%Y;W5T(&-O;'5M
M;BX*("`@("`J+PH@("`@9G5N8W1I;VX@<VAR:6YK4FEG:'0H)')O=RP@)&-O
M;"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/F=E=%=I9'1H*"1R;W<L("1C
M;VPI(#X@,2D@>PH@("`@("`@("`@("`D;&%S=&-O;"`]("1C;VP@*R`D=&AI
M<RT^9V5T5VED=&@H)')O=RP@)&-O;"D@+2`Q.PH@("`@("`@("`@("`D:&5I
M9VAT(#T@)'1H:7,M/F=E=$AE:6=H="@D<F]W+"`D8V]L*3L*("`@("`@("`@
M("`@9F]R("@D:2`](#`[("1I(#P@)&AE:6=H=#L@)&DK*RD@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=R`K("1I75LD;&%S=&-O;%T@
M/2`G96UP='DG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?
M;&%Y;W5T6R1R;W==6R1C;VQ=6R=W:61T:"==(#T@)'1H:7,M/F=E=%=I9'1H
M*"1R;W<L("1C;VPI("T@,3L*("`@("`@("`@("`@)'1H:7,M/G)E;6]V94-O
M;$EF16UP='DH)&QA<W1C;VPI.PH*("`@("`@("`@("`@)'1H:7,M/E]C:&%N
M9V5D7W)O=R`]("1R;W<["B`@("`@("`@("`@("1T:&ES+3Y?8VAA;F=E9%]C
M;VP@/2`D8V]L.PH@("`@("`@('T*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T)L;V-K+U5)+G!H<```````
M````````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`U-S8W(#$P-3$U
M-#,S-S,W(#`R,30U,0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@0VQA<W,@9F]R('-E='1I;F<@=7`@
M2&]R9&4@0FQO8VMS('5S:6YG('1H92!(;W)D95]&;W)M.CH@8VQA<W-E<RX*
M("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!-87)K;R!$:G5K:6,@/&UA<FMO
M0&]B;&\N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*
M("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO54DN<&AP+'8@,2XX+C$P+C4@,C`P-B\P,2\P,B`Q
M-SHT-CHS-2!J86X@17AP("0*("H*("H@0&%U=&AO<B`@36%R:V\@1&IU:VEC
M(#QM87)K;T!O8FQO+F-O;3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P
M86-K86=E($AO<F1E7T)L;V-K"B`J+PIC;&%S<R!(;W)D95]";&]C:U]522![
M"@H@("`@=F%R("1?8FQO8VMS(#T@87)R87DH*3L*("`@('9A<B`D7V9O<FT@
M/2!N=6QL.PH@("`@=F%R("1?=F%R<R`](&YU;&P["@H@("`@9G5N8W1I;VX@
M2&]R9&5?0FQO8VM?54DH*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G
M2&]R9&4O0FQO8VLN<&AP)SL*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E
M+T)L;V-K+T-O;&QE8W1I;VXN<&AP)SL*("`@("`@("`D=&AI<RT^7V)L;V-K
M<R`]("9(;W)D95]";&]C:U]#;VQL96-T:6]N.CIS:6YG;&5T;VXH*3L*("`@
M('T*"B`@("!F=6YC=&EO;B!S971&;W)M*"8D9F]R;2D*("`@('L*("`@("`@
M("`D=&AI<RT^7V9O<FT@/2`F)&9O<FT["B`@("!]"@H@("`@9G5N8W1I;VX@
M<V5T5F%R<R@F)'9A<G,I"B`@("!["B`@("`@("`@)'1H:7,M/E]V87)S(#T@
M)B1V87)S.PH@("`@?0H*("`@(&9U;F-T:6]N('-E='5P161I=$9O<FTH)&9I
M96QD(#T@)V)L;V-K)RD*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D=&AI
M<RT^7W9A<G,I*2!["B`@("`@("`@("`@("\J($YO(&5X:7-T:6YG('9A<G,@
M<V5T+"!G970@=&AE;2!N;W<N("HO"B`@("`@("`@("`@(')E<75I<F5?;VYC
M92`G2&]R9&4O5F%R:6%B;&5S+G!H<"<["B`@("`@("`@("`@("1T:&ES+3Y?
M=F%R<R`]("9687)I86)L97,Z.F=E=$1E9F%U;'1687)I86)L97,H*3L*("`@
M("`@("!]"@H@("`@("`@(&EF("@A:7-?82@D=&AI<RT^7V9O<FTL("=(;W)D
M95]&;W)M)RDI('L*("`@("`@("`@("`@+RH@3F\@97AI<W1I;F<@=F%L:60@
M9F]R;2!O8FIE8W0@<V5T('-O('-E="!U<"!A(&YE=R!O;F4N("HO"B`@("`@
M("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O1F]R;2YP:'`G.PH@("`@("`@
M("`@("`D=&AI<RT^7V9O<FT@/2`F2&]R9&5?1F]R;3HZ<VEN9VQE=&]N*"<G
M+"`D=&AI<RT^7W9A<G,L(%\H(D5D:70@0FQO8VLB*2D["B`@("`@("`@?0H*
M("`@("`@("`O*B!'970@=&AE(&-U<G)E;G0@=F%L=64@;V8@=&AE(&)L;V-K
M('-E;&5C=&EO;BX@*B\*("`@("`@("`D=F%L=64@/2`D=&AI<RT^7W9A<G,M
M/F=E="@D9FEE;&0I.PH*("`@("`@("`O*B!&:65L9"!T;R!S96QE8W0@87!P
M<RX@*B\*("`@("`@("`D87!P<R`]("1T:&ES+3Y?8FQO8VMS+3YG971";&]C
M:W-,:7-T*"D["B`@("`@("`@)'8@/2`F)'1H:7,M/E]F;W)M+3YA9&1687)I
M86)L92A?*")!<'!L:6-A=&EO;B(I+"`D9FEE;&0@+B`G6V%P<%TG+"`G96YU
M;2<L('1R=64L(&9A;'-E+"!N=6QL+"!A<G)A>2@D87!P<RDI.PH@("`@("`@
M("1V+3YS971/<'1I;VXH)W1R86-K8VAA;F=E)RP@=')U92D["@H@("`@("`@
M(&EF("AE;7!T>2@D=F%L=65;)V%P<"==*2D@>PH@("`@("`@("`@("!R971U
M<FX["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!A(&)L;V-K(&AA<R!B965N
M('-E;&5C=&5D+"!O=71P=70@86YY(&]P=&EO;G,@:6YP=70N("HO"B`@("`@
M("`@;&ES="@D87!P+"`D8FQO8VLI(#T@97AP;&]D92@G.B<L("1V86QU95LG
M87!P)UTI.PH*("`@("`@("`O*B!'970@=&AE(&]P=&EO;G,@9F]R('1H92!R
M97%U97-T960@8FQO8VLN("HO"B`@("`@("`@)&]P=&EO;G,@/2`D=&AI<RT^
M7V)L;V-K<RT^9V5T4&%R86US*"1A<'`L("1B;&]C:RD["@H@("`@("`@("\J
M($=O('1H<F]U9V@@=&AE(&]P=&EO;G,@9F]R('1H:7,@8FQO8VL@86YD('-E
M="!U<"!A;GD@<F5Q=6ER960*("`@("`@("`@*B!E>'1R82!I;G!U="X@*B\*
M("`@("`@("!F;W)E86-H("@D;W!T:6]N<R!A<R`D;W!T:6]N*2!["B`@("`@
M("`@("`@("1N86UE(#T@)'1H:7,M/E]B;&]C:W,M/F=E=%!A<F%M3F%M92@D
M87!P+"`D8FQO8VLL("1O<'1I;VXI.PH@("`@("`@("`@("`D='EP92`]("1T
M:&ES+3Y?8FQO8VMS+3YG971/<'1I;VY4>7!E*"1A<'`L("1B;&]C:RP@)&]P
M=&EO;BD["B`@("`@("`@("`@("1R97%U:7)E9"`]("1T:&ES+3Y?8FQO8VMS
M+3YG971/<'1I;VY297%U:7)E9"@D87!P+"`D8FQO8VLL("1O<'1I;VXI.PH@
M("`@("`@("`@("`D=F%L=65S(#T@)'1H:7,M/E]B;&]C:W,M/F=E=$]P=&EO
M;E9A;'5E<R@D87!P+"`D8FQO8VLL("1O<'1I;VXI.PH@("`@("`@("`@("`O
M*B!43T1/.B!T:&4@<V5T=&EN9R`G<W1R:6YG)R!S:&]U;&0@8F4@8VAA;F=E
M9"!I;B!A;&P@8FQO8VMS"B`@("`@("`@("`@("`J('1O("=T97AT)R!S;R!T
M:&%T(&ET(&-O;F9O<FUS('=I=&@@2&]R9&5?1F]R;2!S>6YT87@N("HO"B`@
M("`@("`@("`@(&EF("@D='EP92`]/2`G<W1R:6YG)RD@>PH@("`@("`@("`@
M("`@("`@)'1Y<&4@/2`G=&5X="<["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'!A<F%M<R`](&%R<F%Y*"D["B`@("`@("`@("`@(&EF("@D='EP92`]
M/2`G96YU;2<@?'P@)'1Y<&4@/3T@)VUL96YU;2<I('L*("`@("`@("`@("`@
M("`@("1P87)A;7,@/2!A<G)A>2@D=F%L=65S+"!T<G5E*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D=&AI<RT^7V9O<FTM/F%D9%9A<FEA8FQE*"1N
M86UE+"`D9FEE;&0@+B`G6V]P=&EO;G-=6R<@+B`D;W!T:6]N("X@)UTG+"`D
M='EP92P@)')E<75I<F5D+"!F86QS92P@;G5L;"P@)'!A<F%M<RD["B`@("`@
M("`@?0H@("`@?0H*?0H```````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'``````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,S8U-3$@,3`U,34T,S,W,S<@,#(S,C(R`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"@IR97%U:7)E7V]N8V4@)TAO<F1E+T)L;V-K+G!H<"<["@HO*BH*("H@5&AE
M($AO<F1E7T)L;V-K7T-O;&QE8W1I;VXZ.B!C;&%S<R!P<F]V:61E<R!A;B!!
M4$D@=&\@=&AE(&)L;V-K<PH@*B`H87!P;&5T<RD@9G)A;65W;W)K+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H
M<"QV(#$N,S8N-"XQ-R`R,#`V+S`S+S`X(#$W.C4S.C4R(&-H=6-K($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EK92!#;V-H<F%N92`\;6EK
M94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!*
M86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@0&%U=&AO<B`@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC
M;RYN>CX*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R
M9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T)L
M;V-K"B`J+PIC;&%S<R!(;W)D95]";&]C:U]#;VQL96-T:6]N('L*"B`@("`O
M*BH*("`@("`J(%=H870@:VEN9"!O9B!B;&]C:W,@87)E('=E(&-O;&QE8W1I
M;F<_($1E9F%U;'1S('1O(&%N>2X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("HO"B`@("!V87(@)%]T>7!E(#T@)W!O<G1A;"<["@H@("`@+RHJ
M"B`@("`@*B!!(&AA<V@@<W1O<FEN9R!T:&4@:6YF;W)M871I;VX@86)O=70@
M86QL(&%V86EL86)L92!B;&]C:W,@9G)O;0H@("`@("H@86QL(&%P<&QI8V%T
M:6]N<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D7V)L;V-K<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U
M8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E("!4:&4@
M:VEN9"!O9B!B;&]C:W,@=&\@;&ES="X*("`@("`J($!P87)A;2!A<G)A>2`D
M87!P<R`@(%1H92!A<'!L:6-A=&EO;G,@=VAO<V4@8FQO8VMS('1O(&QI<W0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7T)L;V-K7T-O;&QE8W1I;VXH
M)'1Y<&4@/2!N=6QL+"`D87!P<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M:68@*"%I<U]N=6QL*"1T>7!E*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W1Y
M<&4@/2`D='EP93L*("`@("`@("!]"@H@("`@("`@("1S:6=N871U<F4@/2!S
M97)I86QI>F4H)&%P<',I.PH@("`@("`@(&EF("AI<W-E="@D7U-%4U-)3TY;
M)VAO<F1E)UU;)V)L;V-K<R==6R1S:6=N871U<F5=*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7V)L;V-K<R`]("8D7U-%4U-)3TY;)VAO<F1E)UU;)V)L;V-K
M<R==6R1S:6=N871U<F5=.PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@
M?0H*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH@("`@("`@(')E<75I<F5?
M;VYC92`G2&]R9&4O0FQO8VLN<&AP)SL*"B`@("`@("`@9F]R96%C:"`H)')E
M9VES=')Y+3YL:7-T07!P<R@I(&%S("1A<'`I('L*("`@("`@("`@("`@:68@
M*&-O=6YT*"1A<'!S*2`F)B`A:6Y?87)R87DH)&%P<"P@)&%P<',I*2!["B`@
M("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!I9B`H:7-?82@D<F5S=6QT(#T@)')E9VES=')Y+3YP=7-H07!P*"1A
M<'`I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU
M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D8FQO8VMD:7(@/2`D<F5G
M:7-T<GDM/F=E="@G9FEL97)O;W0G+"`D87!P*2`N("<O;&EB+T)L;V-K)SL*
M("`@("`@("`@("`@)&1H(#T@0&]P96YD:7(H)&)L;V-K9&ER*3L*("`@("`@
M("`@("`@:68@*&ES7W)E<V]U<F-E*"1D:"DI('L*("`@("`@("`@("`@("`@
M('=H:6QE("@H)&9I;&4@/2!R96%D9&ER*"1D:"DI("$]/2!F86QS92D@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("AS=6)S='(H)&9I;&4L("TT*2`]/2`G
M+G!H<"<I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&)L;V-K7VYA;64@
M/2!N=6QL.PH@("`@("`@("`@("`@("`@("`@("`@("`D8FQO8VM?='EP92`]
M(&YU;&P["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<U]R96%D86)L
M92@D8FQO8VMD:7(@+B`G+R<@+B`D9FEL92DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&EN8VQU9&5?;VYC92`D8FQO8VMD:7(@+B`G+R<@+B`D
M9FEL93L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H(6ES7VYU;&PH)&)L;V-K7W1Y<&4I("8F("%I<U]N
M=6QL*"1T:&ES+3Y?='EP92D@)B8*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1B;&]C:U]T>7!E("$]("1T:&ES+3Y?='EP92D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D
M8FQO8VM?;F%M92DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?8FQO8VMS6R1A<'!=6W-U8G-T<B@D9FEL92P@,"P@+30I75LG;F%M
M92==(#T@)&)L;V-K7VYA;64["B`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!C;&]S961I<B@D9&@I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1R96=I<W1R>2T^<&]P07!P*"1A<'`I.PH@("`@("`@('T*"B`@
M("`@("`@=6MS;W)T*"1T:&ES+3Y?8FQO8VMS+`H@("`@("`@("`@("`@("!C
M<F5A=&5?9G5N8W1I;VXH)R1A+"`D8B<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G9VQO8F%L("1R96=I<W1R>3L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!R971U<FX@<W1R8V%S96-M<"@D<F5G:7-T<GDM
M/F=E="@B;F%M92(L("1A*2P@)')E9VES=')Y+3YG970H(FYA;64B+"`D8BDI
M.R<I"B`@("`@("`@("`@("`@("D["@H@("`@("`@("1?4T534TE/3ELG:&]R
M9&4G75LG8FQO8VMS)UU;)'-I9VYA='5R95T@/2`F)'1H:7,M/E]B;&]C:W,[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<VEN9VQE(&EN<W1A
M;F-E(&]F('1H92!(;W)D95]";&]C:W,@8VQA<W,N"B`@("`@*@H@("`@("H@
M0'-T871I8PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@(%1H
M92!K:6YD(&]F(&)L;V-K<R!T;R!L:7-T+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1A<'!S("`@5&AE(&%P<&QI8V%T:6]N<R!W:&]S92!B;&]C:W,@=&\@;&ES
M="X*("`@("`J"B`@("`@*B!`<F5T=7)N($AO<F1E7T)L;V-K7T-O;&QE8W1I
M;VX@(%1H92!(;W)D95]";&]C:U]#;VQL96-T:6]N(&EN<W1A;F-E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1T>7!E(#T@;G5L;"P@)&%P
M<',@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@('-T871I8R`D:6YS=&%N8V5S
M(#T@87)R87DH*3L*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA;&EZ92AA
M<G)A>2@D='EP92P@)&%P<',I*3L*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T
M86YC97-;)'-I9VYA='5R95TI*2!["B`@("`@("`@("`@("1I;G-T86YC97-;
M)'-I9VYA='5R95T@/2!N97<@2&]R9&5?0FQO8VM?0V]L;&5C=&EO;B@D='EP
M92P@)&%P<',I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC
M97-;)'-I9VYA='5R95T["B`@("!]"@H@("`@9G5N8W1I;VX@)F=E=$)L;V-K
M*"1A<'`L("1N86UE+"`D<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@("!G
M;&]B86P@)')E9VES=')Y.PH*("`@("`@("`D<&%T:"`]("1R96=I<W1R>2T^
M9V5T*"=F:6QE<F]O="<L("1A<'`I("X@)R]L:6(O0FQO8VLO)R`N("1N86UE
M("X@)RYP:'`G.PH@("`@("`@("1C;&%S<R`]("=(;W)D95]";&]C:U\G("X@
M)&%P<"`N("=?)R`N("1N86UE.PH@("`@("`@(&EF("AI<U]R96%D86)L92@D
M<&%T:"DI('L*("`@("`@("`@("`@:6YC;'5D95]O;F-E("1P871H.PH@("`@
M("`@('T*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@
M("`@("`@("`@("1E<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?
M*"(E<R!N;W0@9F]U;F0N(BDL("1C;&%S<RDI.PH@("`@("`@("`@("!R971U
M<FX@)&5R<F]R.PH@("`@("`@('T*"B`@("`@("`@)&)L;V-K(#T@)FYE=R`D
M8VQA<W,H)'!A<F%M<RD["B`@("`@("`@<F5T=7)N("1B;&]C:SL*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!P<F5T='D@<')I;G1E9"!L:7-T
M(&]F(&%L;"!A=F%I;&%B;&4@8FQO8VMS+@H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@($$@:&%S:"!W:71H(&)L;V-K($E$<R!A<R!K97ES(&%N9"!A
M<'!L:6-A=&EO;B!P;'5S(&)L;V-K"B`@("`@*B`@("`@("`@("`@("`@("!B
M;&]C:R!N86UE<R!A<R!V86QU97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$)L;V-K<TQI<W0H*0H@("`@>PH@("`@("`@('-T871I8R`D8FQO8VMS(#T@
M87)R87DH*3L*("`@("`@("!I9B`H(65M<'1Y*"1B;&]C:W,I*2!["B`@("`@
M("`@("`@(')E='5R;B`D8FQO8VMS.PH@("`@("`@('T*"B`@("`@("`@9VQO
M8F%L("1R96=I<W1R>3L*"B`@("`@("`@+RH@1V5T(&%V86EL86)L92!B;&]C
M:W,@9G)O;2!A;&P@87!P<RX@*B\*("`@("`@("!F;W)E86-H("@D=&AI<RT^
M7V)L;V-K<R!A<R`D87!P(#T^("1A<'!?8FQO8VMS*2!["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1A<'!?8FQO8VMS(&%S("1B;&]C:U]I9"`]/B`D8FQO8VLI
M('L*("`@("`@("`@("`@("`@("1B;&]C:W-;)&%P<"`N("<Z)R`N("1B;&]C
M:U]I9%T@/2`D<F5G:7-T<GDM/F=E="@G;F%M92<L("1A<'`I("X@)SH@)R`N
M("1B;&]C:ULG;F%M92==.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)&)L;V-K<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@82!L87EO=70@:&%S:"!W:71H(&%L;"!F:7AE9"!B;&]C:W,@87,@
M<&5R(&-O;F9I9W5R871I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A
M>2`@02!H87-H(')E<')E<V5N=&EN9R!A(&1E9F%U;'0@;&%Y;W5T('=I=&@@
M86QL(&9I>&5D"B`@("`@*B`@("`@("`@("`@("`@("!B;&]C:W,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$9I>&5D0FQO8VMS*"D*("`@('L*("`@("`@
M("!G;&]B86P@)&-O;F8["@H@("`@("`@("1L87EO=70@/2!A<G)A>2@I.PH@
M("`@("`@(&EF("AI<W-E="@D8V]N9ELG<&]R=&%L)UU;)V9I>&5D7V)L;V-K
M<R==*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D8V]N9ELG<&]R=&%L)UU;
M)V9I>&5D7V)L;V-K<R==(&%S("1B;&]C:RD@>PH@("`@("`@("`@("`@("`@
M;&ES="@D87!P+"`D='EP92D@/2!E>'!L;V1E*"<Z)RP@)&)L;V-K+"`R*3L*
M("`@("`@("`@("`@("`@("1L87EO=71;72`](&%R<F%Y*&%R<F%Y*"=A<'`G
M(#T^("1A<'`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G<&%R86US)R`]/B!A<G)A>2@G='EP92<@/3X@)'1Y<&4L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G<&%R86US)R`]/B!F86QS92DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G:&5I9VAT)R`]/B`Q+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W=I9'1H)R`]/B`Q
M*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M;&%Y;W5T.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A('-E;&5C
M="!W:61G970@=VET:"!A;&P@879A:6QA8FQE(&)L;V-K<RX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1C=7)?87!P("`@(%1H92!B;&]C:R!F<F]M
M('1H:7,@87!P;&EC871I;VX@9V5T<R!S96QE8W1E9"X*("`@("`J($!P87)A
M;2!S=')I;F<@)&-U<E]B;&]C:R`@5&AE(&)L;V-K('=I=&@@=&AI<R!N86UE
M(&=E=',@<V5L96-T960N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!S96QE8W0@=&%G('=I=&@@86QL(&%V86EL86)L92!B;&]C:W,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$)L;V-K<U=I9&=E="@D8W5R7V%P<"`]
M(&YU;&PL("1C=7)?8FQO8VL@/2!N=6QL+"`D;VYC:&%N9V4@/2!F86QS92D*
M("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("`D=VED
M9V5T(#T@)SQS96QE8W0@;F%M93TB87!P(B<["B`@("`@("`@:68@*"1O;F-H
M86YG92D@>PH@("`@("`@("`@("`D=VED9V5T("X]("<@;VYC:&%N9V4](F1O
M8W5M96YT+F)L;V-K9F]R;2YA8W1I;VXN=F%L=64]7"=S879E+7)E<W5M95PG
M.V1O8W5M96YT+F)L;V-K9F]R;2YS=6)M:70H*2(G.PH@("`@("`@('T*("`@
M("`@("`D=VED9V5T("X]("(^7&XB.PH@("`@("`@("1B;&]C:W-?;&ES="`]
M("1T:&ES+3YG971";&]C:W-,:7-T*"D["B`@("`@("`@9F]R96%C:"`H)&)L
M;V-K<U]L:7-T(&%S("1I9"`]/B`D;F%M92D@>PH@("`@("`@("`@("`D=VED
M9V5T("X]('-P<FEN=&8H(CQO<'1I;VX@=F%L=64]7"(E<UPB)7,^)7,\+V]P
M=&EO;CY<;B(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&ED+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("@D:60@
M/3T@)&-U<E]A<'`@+B`G.B<@+B`D8W5R7V)L;V-K*2`_("<@<V5L96-T960]
M(G-E;&5C=&5D(B<@.B`G)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D;F%M92D["B`@("`@("`@?0H@("`@("`@("1W:61G970@+CT@
M(CPO<V5L96-T/EQN(CL*"B`@("`@("`@<F5T=7)N("1W:61G970["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!O<'1I;VX@='EP92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T3W!T:6]N5'EP92@D87!P+"`D8FQO8VLL
M("1P87)A;5]I9"D*("`@('L*("`@("`@("`D=&AI<RT^9V5T4&%R86US*"1A
M<'`L("1B;&]C:RD["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8FQO8VMS6R1A
M<'!=6R1B;&]C:UU;)W!A<F%M<R==6R1P87)A;5]I9%U;)W1Y<&4G73L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=VAE=&AE<B!T:&4@;W!T:6]N
M(&ES(')E<75I<F5D(&]R(&YO="X@1&5F875L=',@=&\@=')U92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T3W!T:6]N4F5Q=6ER960H)&%P<"P@)&)L;V-K
M+"`D<&%R86U?:60I"B`@("!["B`@("`@("`@)'1H:7,M/F=E=%!A<F%M<R@D
M87!P+"`D8FQO8VLI.PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]B;&]C
M:W-;)&%P<%U;)&)L;V-K75LG<&%R86US)UU;)'!A<F%M7VED75LG<F5Q=6ER
M960G72DI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?8FQO8VMS6R1A<'!=
M6R1B;&]C:UU;)W!A<F%M<R==6R1P87)A;5]I9%U;)W)E<75I<F5D)UT["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@=F%L
M=65S(&9O<B!A;B!O<'1I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N("9G971/
M<'1I;VY686QU97,H)&%P<"P@)&)L;V-K+"`D<&%R86U?:60I"B`@("!["B`@
M("`@("`@)'1H:7,M/F=E=%!A<F%M<R@D87!P+"`D8FQO8VLI.PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7V)L;V-K<ULD87!P75LD8FQO8VM=6R=P87)A;7,G
M75LD<&%R86U?:61=6R=V86QU97,G73L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=&AE('=I9&=E="!N96-E<W-A<GD@=&\@8V]N9FEG=7)E('1H
M:7,@8FQO8VLN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$]P=&EO;G-7:61G
M970H)&%P<"P@)&)L;V-K+"`D<&%R86U?:60L("1V86P@/2!N=6QL*0H@("`@
M>PH@("`@("`@("1W:61G970@/2`G)SL*"B`@("`@("`@)'1H:7,M/F=E=%!A
M<F%M<R@D87!P+"`D8FQO8VLI.PH@("`@("`@("1P87)A;2`]("1T:&ES+3Y?
M8FQO8VMS6R1A<'!=6R1B;&]C:UU;)W!A<F%M<R==6R1P87)A;5]I9%T["B`@
M("`@("`@:68@*"%I<W-E="@D<&%R86U;)V1E9F%U;'0G72DI('L*("`@("`@
M("`@("`@)'!A<F%M6R=D969A=6QT)UT@/2`G)SL*("`@("`@("!]"@H@("`@
M("`@('-W:71C:"`H)'!A<F%M6R=T>7!E)UTI('L*("`@("`@("!C87-E("=B
M;V]L96%N)SH*("`@("`@("!C87-E("=C:&5C:V)O>"<Z"B`@("`@("`@("`@
M("1C:&5C:V5D(#T@(65M<'1Y*"1V86Q;)'!A<F%M7VED72D@/R`G(&-H96-K
M960](F-H96-K960B)R`Z("<G.PH@("`@("`@("`@("`D=VED9V5T(#T@<W!R
M:6YT9B@G/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE/2)P87)A;7-;)7-=
M(B5S("\^)RP@)'!A<F%M7VED+"`D8VAE8VME9"D["B`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("!C87-E("=E;G5M)SH*("`@("`@("`@("`@)'=I9&=E
M="`]('-P<FEN=&8H)SQS96QE8W0@;F%M93TB<&%R86US6R5S72(^)RP@)'!A
M<F%M7VED*3L*("`@("`@("`@("`@9F]R96%C:"`H)'!A<F%M6R=V86QU97,G
M72!A<R`D:V5Y(#T^("1N86UE*2!["B`@("`@("`@("`@("`@("!I9B`H4W1R
M:6YG.CIL96YG=&@H)&YA;64I(#X@,S`I('L*("`@("`@("`@("`@("`@("`@
M("`D;F%M92`]('-U8G-T<B@D;F%M92P@,"P@,C<I("X@)RXN+B<["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=VED9V5T("X]('-P<FEN
M=&8H(CQO<'1I;VX@=F%L=64]7"(E<UPB)7,^)7,\+V]P=&EO;CY<;B(L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:'1M;'-P96-I86QC
M:&%R<R@D:V5Y*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`H:7-S970H)'9A;%LD<&%R86U?:61=*2`F)B`D=F%L6R1P87)A;5]I9%T@
M/3T@)&ME>2D@/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:'1M;'-P96-I86QC:&%R
M<R@D;F%M92DI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=VED9V5T
M("X]("<\+W-E;&5C=#XG.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M8V%S92`G;75L=&EE;G5M)SH*("`@("`@("`@("`@)'=I9&=E="`]('-P<FEN
M=&8H)SQS96QE8W0@;75L=&EP;&4](FUU;'1I<&QE(B!N86UE/2)P87)A;7-;
M)7-=6UTB/B<L("1P87)A;5]I9"D["B`@("`@("`@("`@(&9O<F5A8V@@*"1P
M87)A;5LG=F%L=65S)UT@87,@)&ME>2`]/B`D;F%M92D@>PH@("`@("`@("`@
M("`@("`@:68@*%-T<FEN9SHZ;&5N9W1H*"1N86UE*2`^(#,P*2!["B`@("`@
M("`@("`@("`@("`@("`@)&YA;64@/2!S=6)S='(H)&YA;64L(#`L(#(W*2`N
M("<N+BXG.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'=I
M9&=E="`N/2!S<')I;G1F*"(\;W!T:6]N('9A;'5E/5PB)7-<(B5S/B5S/"]O
M<'1I;VX^7&XB+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@*&ES<V5T*"1V86Q;)'!A<F%M7VED72D@)B8@:6Y?
M87)R87DH)&ME>2P@)'9A;%LD<&%R86U?:61=*2D@/R`G('-E;&5C=&5D/2)S
M96QE8W1E9"(G(#H@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:'1M;'-P96-I86QC:&%R<R@D;F%M92DI.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`D=VED9V5T("X]("<\+W-E;&5C=#XG.PH@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G;6QE;G5M)SH*("`@("`@("`@
M("`@+R\@375L=&DM;&5V96P@96YU;2X*("`@("`@("`@("`@:68@*&ES7V%R
M<F%Y*"1V86PI("8F(&ES<V5T*"1V86Q;)U]?)R`N("1P87)A;5]I9%TI*2![
M"B`@("`@("`@("`@("`@("`D9FER<W1V86P@/2`D=F%L6R=?7R<@+B`D<&%R
M86U?:61=.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)'1M<"`](&%R<F%Y7VME>7,H)'!A<F%M6R=V86QU97,G72D["B`@("`@("`@
M("`@("`@("`D9FER<W1V86P@/2!C=7)R96YT*"1T;7`I.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1B;&]C:W9A;'5E<R`]("1P87)A;5LG=F%L=65S
M)UU;)&9I<G-T=F%L73L*("`@("`@("`@("`@87-O<G0H)&)L;V-K=F%L=65S
M*3L*"B`@("`@("`@("`@("1W:61G970@/2!S<')I;G1F*"<\<V5L96-T(&YA
M;64](G!A<F%M<UM?7R5S72(@;VYC:&%N9V4](F1O8W5M96YT+F)L;V-K9F]R
M;2YA8W1I;VXN=F%L=64]7"=S879E+7)E<W5M95PG.V1O8W5M96YT+F)L;V-K
M9F]R;2YS=6)M:70H*2(^)RP@)'!A<F%M7VED*2`N(")<;B(["B`@("`@("`@
M("`@(&9O<F5A8V@@*"1P87)A;5LG=F%L=65S)UT@87,@)&ME>2`]/B`D=F%L
M=65S*2!["B`@("`@("`@("`@("`@("`D;F%M92`](%-T<FEN9SHZ;&5N9W1H
M*"1K97DI(#X@,S`@/R!3=')I;F<Z.G-U8G-T<B@D:V5Y+"`P+"`R-RD@+B`G
M+BXN)R`Z("1K97D["B`@("`@("`@("`@("`@("`D=VED9V5T("X]('-P<FEN
M=&8H(CQO<'1I;VX@=F%L=64]7"(E<UPB)7,^)7,\+V]P=&EO;CY<;B(L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:'1M;'-P96-I86QC
M:&%R<R@D:V5Y*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D:V5Y(#T]("1F:7)S='9A;"`_("<@<V5L96-T960](G-E;&5C=&5D(B<@
M.B`G)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!H=&UL
M<W!E8VEA;&-H87)S*"1N86UE*2D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'=I9&=E="`N/2`B/"]S96QE8W0^/&)R("\^7&XB.PH*("`@("`@("`@
M("`@)'=I9&=E="`N/2!S<')I;G1F*"(\<V5L96-T(&YA;64]7")P87)A;7-;
M)7-=7"(^7&XB+"`D<&%R86U?:60I.PH@("`@("`@("`@("!F;W)E86-H("@D
M8FQO8VMV86QU97,@87,@)&ME>2`]/B`D;F%M92D@>PH@("`@("`@("`@("`@
M("`@)&YA;64@/2`H4W1R:6YG.CIL96YG=&@H)&YA;64I(#X@,S`I(#\@4W1R
M:6YG.CIS=6)S='(H)&YA;64L(#`L(#(W*2`N("<N+BXG(#H@)&YA;64["B`@
M("`@("`@("`@("`@("`D=VED9V5T("X]('-P<FEN=&8H(CQO<'1I;VX@=F%L
M=64]7"(E<UPB)7,^)7,\+V]P=&EO;CY<;B(L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%L6R1P87)A;5]I
M9%T@/3T@)&ME>2`_("<@<V5L96-T960](G-E;&5C=&5D(B<@.B`G)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!H=&UL<W!E8VEA;&-H
M87)S*"1N86UE*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'=I9&=E
M="`N/2`B/"]S96QE8W0^/&)R("\^7&XB.PH@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@8V%S92`G8V]L;W(G.@H@("`@("`@("`@("`D=F%L(#T@:7-S
M970H)&)L;V-K+3Y?<&%R86US6R1P87)A;5]I9%TI(#\@)&)L;V-K+3Y?<&%R
M86US6R1P87)A;5]I9%T@.B`G)SL*("`@("`@("`@("`@)'=I9&=E="`]('-P
M<FEN=&8H)SQI;G!U="!S='EL93TB8F%C:V=R;W5N9"UC;VQO<CHE<R(@='EP
M93TB=&5X="(@;F%M93TB<&%R86US6R5S72(@=F%L=64](B5S(B`O/B<L("1V
M86PL("1P87)A;5]I9"P@)'9A;"D["B`@("`@("`@("`@("1U<FP@(#T@)')E
M9VES=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*3L*("`@("`@("`@("`@
M)'5R;"`N/2!5=&EL.CIA9&1087)A;65T97(H)R]S97)V:6-E<R]I;6%G97,O
M8V]L;W)P:6-K97(N<&AP/W1A<F=E=#UP87)A;7-;)R`N("1P87)A;5]I9"`N
M("==)RP@)V9O<FTG+"`G8FQO8VMF;W)M)RD["B`@("`@("`@("`@("1W:61G
M970@+CT@<W!R:6YT9B@G/&$@:')E9CTB)7,B(&]N8VQI8VL](G=I;F1O=RYO
M<&5N*%PG)7-<)RP@7"=C;VQO<G!I8VME<EPG+"!<)W1O;VQB87(];F\L;&]C
M871I;VX];F\L<W1A='5S/6YO+'-C<F]L;&)A<G,];F\L<F5S:7IA8FQE/6YO
M+'=I9'1H/3$R,"QH96EG:'0],C4P+&QE9G0],3`P+'1O<#TQ,#!<)RD[(')E
M='5R;B!F86QS93LB(&]N;6]U<V5O=70](G=I;F1O=RYS=&%T=7,]7"=<)SLB
M(&]N;6]U<V5O=F5R/2)W:6YD;W<N<W1A='5S/5PG)7-<)SL@<F5T=7)N('1R
M=64[(B!C;&%S<STB=VED9V5T(B!T87)G970](F-O;&]R<&EC:V5R(CXG+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'5R;"P@)'5R;"P@7R@B
M0V]L;W(@4&EC:V5R(BDI.PH@("`@("`@("`@("`D=VED9V5T("X]($AO<F1E
M.CII;6<H)V-O;&]R<&EC:V5R+G!N9R<L(%\H(D-O;&]R(%!I8VME<B(I+"`G
M:&5I9VAT/2(Q-B(G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I
M*3L*("`@("`@("`@("`@)'=I9&=E="`N/2`G/"]A/B<["B`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("!C87-E("=I;G0G.@H@("`@("`@(&-A<V4@)W1E
M>'0G.@H@("`@("`@("`@("`D=VED9V5T(#T@<W!R:6YT9B@G/&EN<'5T('1Y
M<&4](G1E>'0B(&YA;64](G!A<F%M<ULE<UTB('9A;'5E/2(E<R(@+SXG+"`D
M<&%R86U?:60L("%I<W-E="@D=F%L6R1P87)A;5]I9%TI(#\@)'!A<F%M6R=D
M969A=6QT)UT@.B`D=F%L6R1P87)A;5]I9%TI.PH@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@8V%S92`G97)R;W(G.@H@("`@("`@("`@("`D=VED9V5T
M(#T@)SQS<&%N(&-L87-S/2)F;W)M+65R<F]R(CXG("X@)'!A<F%M6R=D969A
M=6QT)UT@+B`G/"]S<&%N/B<["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1W:61G970["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!N86UE(&]F('1H92!S<&5C:69I960@8FQO8VLN
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D87!P("`@($%N(&%P<&QI
M8V%T:6]N(&YA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1B;&]C:R`@02!B
M;&]C:R!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M;F%M92!O9B!T:&4@<W!E8VEF:65D(&)L;V-K+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971.86UE*"1A<'`L("1B;&]C:RD*("`@('L*("`@("`@("!I9B`H
M(6ES<V5T*"1T:&ES+3Y?8FQO8VMS6R1A<'!=6R1B;&]C:UTI*2!["B`@("`@
M("`@("`@(')E='5R;B!S<')I;G1F*%\H(D)L;V-K(%PB)7-<(B!O9B!A<'!L
M:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(I+"`D8FQO8VLL("1A<'`I.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/E]B;&]C:W-;)&%P<%U;
M)&)L;V-K75LG;F%M92==.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!T:&4@<&%R86UE=&5R(&QI<W0@;V8@=&AE('-P96-I9FEE9"!B;&]C:RX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@("`@06X@87!P;&EC
M871I;VX@;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@)&)L;V-K("!!(&)L
M;V-K(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R
M87D@=VET:"!A;&P@<&%R86UT97(@;F%M97,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=%!A<F%M<R@D87!P+"`D8FQO8VLI"B`@("!["B`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^7V)L;V-K<ULD87!P75LD8FQO8VM=6R=P87)A;7,G
M72DI('L*("`@("`@("`@("`@)&)L;V-K3V(@/2`F)'1H:7,M/F=E=$)L;V-K
M*"1A<'`L("1B;&]C:RD["B`@("`@("`@("`@(&EF("AI<U]A*"1B;&]C:T]B
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&)L
M;V-K3V(["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]B;&]C
M:W-;)&%P<%U;)&)L;V-K75LG<&%R86US)UT@/2`D8FQO8VM/8BT^9V5T4&%R
M86US*"D["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]B
M;&]C:W-;)&%P<%U;)&)L;V-K75LG<&%R86US)UTI("8F"B`@("`@("`@("`@
M(&ES7V%R<F%Y*"1T:&ES+3Y?8FQO8VMS6R1A<'!=6R1B;&]C:UU;)W!A<F%M
M<R==*2D@>PH@("`@("`@("`@("!R971U<FX@87)R87E?:V5Y<R@D=&AI<RT^
M7V)L;V-K<ULD87!P75LD8FQO8VM=6R=P87)A;7,G72D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@*&-L96%R('1E>'0I
M(&YA;64@;V8@=&AE('-P96-I9FEE9"!P87)A;65T97(N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D87!P("`@($%N(&%P<&QI8V%T:6]N(&YA;64N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1B;&]C:R`@02!B;&]C:R!N86UE+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<&%R86T@($$@<&%R86UE=&5R(&YA;64N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!N86UE(&]F('1H
M92!S<&5C:69I960@<&%R86UE=&5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971087)A;4YA;64H)&%P<"P@)&)L;V-K+"`D<&%R86TI"B`@("!["B`@("`@
M("`@)'1H:7,M/F=E=%!A<F%M<R@D87!P+"`D8FQO8VLI.PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7V)L;V-K<ULD87!P75LD8FQO8VM=6R=P87)A;7,G75LD
M<&%R86U=6R=N86UE)UT["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!D969A=6QT('9A;'5E(&]F('1H92!S<&5C:69I960@<&%R86UE=&5R
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%P<"`@("!!;B!A<'!L
M:6-A=&EO;B!N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8FQO8VL@($$@
M8FQO8VL@;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@)'!A<F%M("!!('!A
M<F%M971E<B!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@9&5F875L="!V86QU92!O9B!T:&4@<W!E8VEF:65D('!A<F%M971E<B!O
M<B!N=6QL+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971$969A=6QT5F%L=64H
M)&%P<"P@)&)L;V-K+"`D<&%R86TI"B`@("!["B`@("`@("`@)'1H:7,M/F=E
M=%!A<F%M<R@D87!P+"`D8FQO8VLI.PH@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^7V)L;V-K<ULD87!P75LD8FQO8VM=6R=P87)A;7,G75LD<&%R86U=6R=D
M969A=6QT)UTI*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V)L;V-K
M<ULD87!P75LD8FQO8VM=6R=P87)A;7,G75LD<&%R86U=6R=D969A=6QT)UT[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B!N=6QL.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!I9B!T:&4@<W!E8VEF:65D(&)L;V-K(&ES(&-U
M<W1O;6EZ96%B;&4@8GD@=&AE('5S97(N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D87!P("`@($%N(&%P<&QI8V%T:6]N(&YA;64N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1B;&]C:R`@02!B;&]C:R!N86UE+@H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I<R!T:&4@8FQO8VL@:7,@8W5S
M=&]M:7IE86)L92X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-%9&ET86)L92@D
M87!P+"`D8FQO8VLI"B`@("!["B`@("`@("`@)'1H:7,M/F=E=%!A<F%M<R@D
M87!P+"`D8FQO8VLI.PH@("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^7V)L
M;V-K<ULD87!P75LD8FQO8VM=6R=P87)A;7,G72D@)B8*("`@("`@("`@("`@
M8V]U;G0H)'1H:7,M/E]B;&]C:W-;)&%P<%U;)&)L;V-K75LG<&%R86US)UTI
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+T%U=&@`````````````````````````````````
M`````````````````````````````````````````````````#`P,#<U-2``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S0P(#`R,#$V
M-@`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O075T:"]P87-S=V0N
M<&AP````````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,38Q,3`@
M,3`U,34T,S,W,S<@,#(R,C8T`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B!4:&4@075T:%]P87-S=V0Z
M.B!C;&%S<R!P<F]V:61E<R!A('!A<W-W9"UF:6QE(&EM<&QE;65N=&%T:6]N
M(&]F"B`J('1H92!(;W)D92!A=71H96YT:6-A=&EO;B!S>7-T96TN"B`J"B`J
M($]P=&EO;F%L('!A<F%M971E<G,Z/'!R93X*("H@("`G9FEL96YA;64G("!4
M:&4@<&%S<W=D(&9I;&4@=&\@=7-E+@H@*B`@("`@("`@("`@("`@($1%1D%5
M3%0Z("]E=&,O<&%S<W=D"B`J("`@)VQO8VLG("`@("`@4VAO=6QD('=E(&QO
M8VL@=&AE('!A<W-W9"!F:6QE/R`H8F]O;&5A;BD*("H@("`@("`@("`@("`@
M("!$149!54Q4.B!F86QS93PO<')E/@H@*@H@*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<&%S<W=D+G!H<"QV(#$N,38N,3`N,3$@,C`P-B\P
M."\Q-"`P,CHT.#HT."!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY
M-RTR,#`V(%)A<VUU<R!,97)D;W)F(#QR87-M=7-`<&AP+FYE=#X*("H@0V]P
M>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E
M+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@(%)A<VUU<R!,97)D
M;W)F(#QR87-M=7-`<&AP+FYE=#X*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@
M*B!`<&%C:V%G92!(;W)D95]!=71H"B`J+PIC;&%S<R!!=71H7W!A<W-W9"!E
M>'1E;F1S($%U=&@@>PH*("`@("\J*@H@("`@("H@06X@87)R87D@;V8@8V%P
M86)I;&ET:65S+"!S;R!T:&%T('1H92!D<FEV97(@8V%N(')E<&]R="!W:&EC
M:`H@("`@("H@;W!E<F%T:6]N<R!I="!S=7!P;W)T<R!A;F0@=VAI8V@@:70@
M9&]E<VXG="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@
M('9A<B`D8V%P86)I;&ET:65S(#T@87)R87DH)V%D9"<@("`@("`@("`@(#T^
M(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=7!D871E
M)R`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=R97-E='!A<W-W;W)D)R`]/B!F86QS92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W)E;6]V92<@("`@("`@(#T^(&9A;'-E+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G;&ES="<@("`@("`@("`@/3X@
M=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1R86YS<&%R
M96YT)R`@(#T^(&9A;'-E*3L*"B`@("`O*BH*("`@("`J(%!A<W-W9"!F:6QE
M+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D
M7V9I;&5N86UE(#T@)R]E=&,O<&%S<W=D)SL*"B`@("`O*BH*("`@("`J($AA
M<V@@;&ES="!O9B!U<V5R<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B\*("`@('9A<B`D7W5S97)S.PH*("`@("\J*@H@("`@("H@1FEL96AA
M;F1L92!F;W(@;&]C:V9I;&4N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R
M"B`@("`@*B\*("`@('9A<B`D7V9P;&]C:SL*"B`@("`O*BH*("`@("`J($QO
M8VMI;F<@<W1A=&4N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@
M*B\*("`@('9A<B`D7VQO8VME9#L*"B`@("`O*BH*("`@("`J($QI<W0@;V8@
M=7-E<G,@=&AA="!S:&]U;&0@8F4@97AC;'5D960@9G)O;2!B96EN9R!L:7-T
M960O:&%N9&QE9`H@("`@("H@:6X@86YY('=A>2!B>2!T:&ES(&1R:79E<BX*
M("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V5X
M8VQU9&4@/2!A<G)A>2@G<F]O="<L("=D865M;VXG+"`G8FEN)RP@)W-Y<R<L
M("=S>6YC)RP@)V=A;65S)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`G
M;6%N)RP@)VQP)RP@)VUA:6PG+"`G;F5W<R<L("=U=6-P)RP@)W!R;WAY)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`G<&]S=&=R97,G+"`G=W=W+61A
M=&$G+"`G8F%C:W5P)RP@)V]P97)A=&]R)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`G;&ES="<L("=I<F,G+"`G9VYA=',G+"`G;F]B;V1Y)RP@)VED
M96YT9"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@)W-S:&0G+"`G9V1M
M)RP@)W!O<W1F:7@G+"`G;7ES<6PG+"`G8WER=7,G+"`G9G1P)RD["@H@("`@
M+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W(%!A<W-W9"!A=71H96YT:6-A
M=&EO;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A
M;7,@($$@:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@075T:%]P87-S=V0H)'!A<F%M<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R86US
M.PH@("`@("`@(&EF("@A96UP='DH)'!A<F%M<ULG9FEL96YA;64G72DI('L*
M("`@("`@("`@("`@)'1H:7,M/E]F:6QE;F%M92`]("1P87)A;7-;)V9I;&5N
M86UE)UT["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V9P;&]C:R`](&9O
M<&5N*$AO<F1E.CIG971496UP1&ER*"D@+B`G+W!A<W-W9"YL;V-K)RP@)W<G
M*3L*("`@("`@("!I9B`H(65M<'1Y*"1P87)A;7-;)VQO8VLG72DI('L*("`@
M("`@("`@("`@9FQO8VLH)'1H:7,M/E]F<&QO8VLL($Q/0TM?15@I.PH@("`@
M("`@("`@("`D=&AI<RT^7VQO8VME9"`]('1R=64["B`@("`@("`@?0H*("`@
M("`@("`D9G`@/2!F;W!E;B@D=&AI<RT^7V9I;&5N86UE+"`G<B<I.PH@("`@
M("`@(&EF("@A)&9P*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*")#;W5L9&XG="!O<&5N("<B("X@)'1H:7,M/E]F:6QE;F%M92`N
M("(G+B(I.PH@("`@("`@('T*("`@("`@("!W:&EL92`H(69E;V8H)&9P*2D@
M>PH@("`@("`@("`@("`D;&EN92`](&9G971S*"1F<"P@,3(X*3L*("`@("`@
M("`@("`@:68@*"%E;7!T>2@D;&EN92DI('L*("`@("`@("`@("`@("`@(&QI
M<W0H)'5S97(L("1P87-S+"`D=6ED+"`D9VED+"`D:6YF;RP@)&AO;64L("1S
M:&5L;"D@/2!E>'!L;V1E*"<Z)RP@)&QI;F4I.PH@("`@("`@("`@("`@("`@
M:68@*'-T<FQE;B@D=7-E<BD@)B8*("`@("`@("`@("`@("`@("`@("`A:6Y?
M87)R87DH)'5S97(L("1T:&ES+3Y?97AC;'5D92DI('L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W5S97)S6R1U<V5R75LG<&%S<W=O<F0G72`]("1P
M87-S.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=7-E<G-;)'5S97)=
M6R=U:60G72`]("1U:60["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]U
M<V5R<ULD=7-E<EU;)V=I9"==(#T@)&=I9#L*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W5S97)S6R1U<V5R75LG:6YF;R==(#T@)&EN9F\["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]U<V5R<ULD=7-E<EU;)VAO;64G72`]
M("1H;VUE.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=7-E<G-;)'5S
M97)=6R=S:&5L;"==(#T@)'-H96QL.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&9C;&]S92@D9G`I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1FEN9"!O=70@:68@82!S970@;V8@;&]G:6X@
M8W)E9&5N=&EA;',@87)E('9A;&ED+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@
M("`@(%1H92!U<V5R260@=&\@8VAE8VLN"B`@("`@*B!`<&%R86T@87)R87D@
M)&-R961E;G1I86QS("!!;B!A<G)A>2!O9B!L;V=I;B!C<F5D96YT:6%L<RX@
M1F]R($U#04PL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!T
M:&ES(&UU<W0@8V]N=&%I;B!A('!A<W-W;W)D(&5N=')Y+@H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&-R961E
M;G1I86QS(&%R92!V86QI9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V%U=&AE
M;G1I8V%T92@D=7-E<DED+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@
M:68@*&5M<'1Y*"1C<F5D96YT:6%L<ULG<&%S<W=O<F0G72DI('L*("`@("`@
M("`@("`@2&]R9&4Z.F9A=&%L*%\H(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!005-35T0@875T:&5N=&EC871I;VXN(BDL(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W5S97)S
M6R1U<V5R261=*2D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]U<V5R<ULD
M=7-E<DED75LG<&%S<W=O<F0G72`]/2!C<GEP="@D8W)E9&5N=&EA;'-;)W!A
M<W-W;W)D)UTL('-U8G-T<B@D=&AI<RT^7W5S97)S6R1U<V5R261=6R=P87-S
M=V]R9"==+"`P+"`R*2DI(')E='5R;B!T<G5E.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!,:7-T(&%L
M;"!U<V5R<R!I;B!T:&4@<WES=&5M+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1H92!A<G)A>2!O9B!U<V5R261S+"!O<B!A(%!%05)?17)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W15
M<V5R<R@I"B`@("!["B`@("`@("`@<F5T=7)N(&%R<F%Y7VME>7,H)'1H:7,M
M/E]U<V5R<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@=7-E<BX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R("`@("!.97<@=7-E
M<B!)1"X*("`@("`J($!P87)A;2!S=')I;F<@)'!A<W,@("`@(%!A<W-W;W)D
M(&9O<B!N97<@=7-E<BX*("`@("`J($!P87)A;2!S=')I;F<@)&-V<W5S97(@
M($-64R!U<V5R(&ED("AN965D960@9F]R('!S97)V97(@<&%S<W=D(&9I;&5S
M*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%)E='5R;G,@=')U
M92!O<B!014%27T5R<F]R(&EF('1H92!U<V5R(&%L<F5A9'D*("`@("`J("`@
M("`@("`@("`@("`@("`@97AI<W1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!A
M9&15<V5R*"1U<V5R+"`D<&%S<RP@)&-V<W5S97(@/2`G)RD*("`@('L*("`@
M("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?=7-E<G-;)'5S97)=*2`F)B`D=&AI
M<RT^7VQO8VME9"D@>PH@("`@("`@("`@("`D=&AI<RT^7W5S97)S6R1U<V5R
M72`](&-R>7!T*"1P87-S*3L*("`@("`@("`@("`@)'1H:7,M/E]C=G-;)'5S
M97)=(#T@)&-V<W5S97(["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*")#;W5L9&XG="!A9&0@=7-E<B`G)'5S97(G+"!B96-A=7-E('1H92!U
M<V5R(&%L<F5A9'D@97AI<W1S+B(I.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($UO9&EF:65S(&$@=7-E<BX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1U<V5R("`@("!5<V5R($E$+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<&%S<R`@("`@4&%S<W=O<F0@9F]R(&YE=R!U<V5R+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D8W9S=7-E<B`@0U93('5S97(@:60@*&YE961E9"!F
M;W(@<'-E<G9E<B!P87-S=V0@9FEL97,I+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@4F5T=7)N<R!T<G5E(&]R(%!%05)?17)R;W(@:68@=&AE
M('5S97(@9&]E<VXG=`H@("`@("H@("`@("`@("`@("`@("`@("!E>&ES=',N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&UO9%5S97(H)'5S97(L("1P87-S+"`D
M8W9S=7-E<B`]("<G*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M7W5S97)S6R1U<V5R72D@)B8@)'1H:7,M/E]L;V-K960I('L*("`@("`@("`@
M("`@)'1H:7,M/E]U<V5R<ULD=7-E<ET@/2!C<GEP="@D<&%S<RD["B`@("`@
M("`@("`@("1T:&ES+3Y?8W9S6R1U<V5R72`]("1C=G-U<V5R.PH@("`@("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B0V]U;&1N)W0@;6]D:69Y('5S
M97(@)R1U<V5R)RP@8F5C875S92!T:&4@=7-E<B!D;V5S;B=T(&5X:7-T+B(I
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1E;&5T97,@82!U
M<V5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97(@(%5S97(@
M240N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!2971U<FYS('1R
M=64@;W(@4$5!4E]%<G)O<B!I9B!T:&4@=7-E<B!D;V5S;B=T(&5X:7-T+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!D96Q5<V5R*"1U<V5R*0H@("`@>PH@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7W5S97)S6R1U<V5R72D@)B8@)'1H:7,M
M/E]L;V-K960I('L*("`@("`@("`@("`@=6YS970H)'1H:7,M/E]U<V5R<ULD
M=7-E<ETI.PH@("`@("`@("`@("!U;G-E="@D=&AI<RT^7V-V<ULD=7-E<ETI
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*")#;W5L9&XG="!D96QE=&4@=7-E<B`G)'5S97(G+"!B96-A
M=7-E('1H92!U<V5R(&1O97-N)W0@97AI<W0N(BD["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@5W)I=&5S(&-H86YG97,@=&\@<&%S<W=D(&9I
M;&4@86YD('5N;&]C:W,@:70N("!486ME<R!N;R!A<F=U;65N=',@86YD"B`@
M("`@*B!H87,@;F\@9&5F:6YE9"!R971U<FX@=F%L=64N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-L;W-E*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]L
M;V-K960I('L*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]U<V5R<R!A
M<R`D=7-E<B`]/B`D<&%S<RD@>PH@("`@("`@("`@("`@("`@:68@*"1T:&ES
M+3Y?=7-E<G-;)'5S97)=*2!["B`@("`@("`@("`@("`@("`@("`@9G!U=',H
M)'1H:7,M/E]F<&QO8VLL("(D=7-E<CHD<&%S<SHB("X@)'1H:7,M/E]U<V5R
M<ULD=7-E<ET@+B`B7&XB*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@9G!U=',H)'1H:7,M/E]F<&QO8VLL("(D=7-E
M<CHD<&%S<UQN(BD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("`@("`@<F5N86UE*"1T:&ES+3Y?;&]C:V9I;&4L("1T:&ES+3Y?
M9FEL96YA;64I.PH@("`@("`@("`@("!F;&]C:R@D=&AI<RT^7V9P;&]C:RP@
M3$]#2U]53BD["B`@("`@("`@("`@("1T:&ES+3Y?;&]C:V5D(#T@9F%L<V4[
M"B`@("`@("`@("`@(&9C;&]S92@D=&AI<RT^7V9P;&]C:RD["B`@("`@("`@
M?0H@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+VEP8F%S
M:6,N<&AP````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-C<R
M-B`Q,#4Q-30S,S<S-R`P,C(T,3$`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J(%1H92!!=71H7VEP8F%S
M:6,@8VQA<W,@<')O=FED97,@86-C97-S(&-O;G1R;VP@8F%S960@;VX@0TE$
M4B!M87-K<PH@*B`H8VQI96YT($E0(&%D9')E<W-E<RDN($ET(&ES(&YO="!M
M96%N="!F;W(@=7-E<BUB87-E9"!S>7-T96US+"!B=70*("H@9F]R('1I;65S
M('=H96X@>6]U('=A;G0@82!B;&]C:R!O9B!)4',@=&\@8F4@86)L92!T;R!A
M8V-E<W,@82!S:71E+`H@*B!A;F0@=&AA="!A8V-E<W,@:7,@<VEM<&QY(&]N
M+V]F9B`M(&YO('!R969E<F5N8V5S+"!E=&,N($EF('EO=2!N965D"B`J(&UO
M<F4@<V]P:&ES=&EC871E9"!)4"UB87-E9"!A=71H96YT:6-A=&EO;BP@>6]U
M('-H;W5L9"!L;V]K(&%T('1H90H@*B!!=71H7VEP;6%P(&-L87-S('=H:6-H
M(&QE=',@>6]U(&UA<"!)4"!B;&]C:W,@=&\@<W!E8VEF:6,*("H@=7-E<FYA
M;65S+@H@*@H@*B!087)A;65T97)S.@H@*B`@("=B;&]C:W,G("`@("!!;B!A
M<G)A>2!O9B!#2412(&UA<VMS('=H:6-H(&%R92!A;&QO=V5D(&%C8V5S<RX*
M("H*("H@)$AO<F1E.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP
M+'8@,2XR,"XQ,"XW(#(P,#8O,#$O,#$@,C$Z,C@Z,#<@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C
M:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R
M9&4@,2XS"B`J($!P86-K86=E($AO<F1E7T%U=&@*("HO"F-L87-S($%U=&A?
M:7!B87-I8R!E>'1E;F1S($%U=&@@>PH*("`@("\J*@H@("`@("H@06X@87)R
M87D@;V8@8V%P86)I;&ET:65S+"!S;R!T:&%T('1H92!D<FEV97(@8V%N(')E
M<&]R="!W:&EC:`H@("`@("H@;W!E<F%T:6]N<R!I="!S=7!P;W)T<R!A;F0@
M=VAI8V@@:70@9&]E<VXG="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B\*("`@('9A<B`D8V%P86)I;&ET:65S(#T@87)R87DH)V%D9"<@("`@
M("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G=7!D871E)R`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=R97-E='!A<W-W;W)D)R`]/B!F86QS92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W)E;6]V92<@("`@("`@(#T^(&9A
M;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;&ES="<@("`@
M("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=T<F%N<W!A<F5N="<@("`]/B!T<G5E*3L*"B`@("`O*BH*("`@("`J($-O
M;G-T<G5C=',@82!N97<@0F%S:6,@25`@875T:&5N=&EC871I;VX@;V)J96-T
M+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@
M8V]N=&%I;FEN9R!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!!
M=71H7VEP8F%S:6,H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M)'1H:7,M/E]S971087)A;7,H)'!A<F%M<RD["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3970@<&%R86UE=&5R<R!F;W(@=&AE($%U=&A?:7!B87-I8R!O8FIE
M8W0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@(%-H;W5L9"!C;VYT86EN("=B;&]C
M:W,G+"!A;B!A<G)A>2!O9B!#2412(&UA<VMS+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?<V5T4&%R86US*"1P87)A;7,I"B`@("!["B`@("`@("`@:68@*&5M
M<'1Y*"1P87)A;7-;)V)L;V-K<R==*2D@>PH@("`@("`@("`@("`D<&%R86US
M6R=B;&]C:W,G72`](&%R<F%Y*"D["B`@("`@("`@?2!E;'-E:68@*"%I<U]A
M<G)A>2@D<&%R86US6R=B;&]C:W,G72DI('L*("`@("`@("`@("`@)'!A<F%M
M<ULG8FQO8VMS)UT@/2!A<G)A>2@D<&%R86US6R=B;&]C:W,G72D["B`@("`@
M("`@?0H*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P87)A;7,["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!=71O;6%T:6,@875T:&5N=&EC871I;VXZ($9I
M;F0@;W5T(&EF('1H92!C;&EE;G0@;6%T8VAE<R!A;B!A;&QO=V5D($E0"B`@
M("`@*B!B;&]C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H
M971H97(@;W(@;F]T('1H92!C;&EE;G0@:7,@86QL;W=E9"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@=')A;G-P87)E;G0H*0H@("`@>PH@("`@("`@(&EF("@A
M:7-S970H)%]315)615);)U)%34]415]!1$12)UTI*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?<V5T075T:$5R<F]R*$%55$A?4D5!4T].7TU%4U-!1T4L(%\H
M(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB*2D["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1C;&EE;G0@/2`D7U-%
M4E9%4ELG4D5-3U1%7T%$1%(G73L*("`@("`@("!F;W)E86-H("@D=&AI<RT^
M7W!A<F%M<ULG8FQO8VMS)UT@87,@)&-I9'(I('L*("`@("`@("`@("`@:68@
M*"1T:&ES+3Y?861D<F5S<U=I=&AI;D-)1%(H)&-L:65N="P@)&-I9'(I*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T075T:"@D8VED<BP@87)R87DH
M)W1R86YS<&%R96YT)R`]/B`Q*2D["B`@("`@("`@("`@("`@("!R971U<FX@
M=')U93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)'1H:7,M
M/E]S971!=71H17)R;W(H05542%]214%33TY?34534T%'12P@7R@B25`@061D
M<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB*2D["B`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5T97)M
M:6YE(&EF(&%N($E0(&%D9')E<W,@:7,@=VET:&EN(&$@0TE$4B!B;&]C:RX*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1A9&1R97-S("!4:&4@25`@861D<F5S<R!T;R!C:&5C
M:RX*("`@("`J($!P87)A;2!S=')I;F<@)&-I9'(@("`@(%1H92!B;&]C:R`H
M92YG+B`Q.3(N,38X+C`N,"\Q-BD@=&\@=&5S="!A9V%I;G-T+@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&%D
M9')E<W,@;6%T8VAE<R!T:&4@;6%S:RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V%D9')E<W-7:71H:6Y#2412*"1A9&1R97-S+"`D8VED<BD*("`@('L*("`@
M("`@("`D861D<F5S<R`](&EP,FQO;F<H)&%D9')E<W,I.PH@("`@("`@(&QI
M<W0H)'%U860L("1B:71S*2`](&5X<&QO9&4H)R\G+"`D8VED<BD["B`@("`@
M("`@)&)I=',@/2!I;G1V86PH)&)I=',I.PH@("`@("`@("1Q=6%D(#T@:7`R
M;&]N9R@D<75A9"D["@H@("`@("`@(')E='5R;B`H*"1A9&1R97-S(#X^("@S
M,B`M("1B:71S*2D@/3T@*"1Q=6%D(#X^("@S,B`M("1B:71S*2DI.PH@("`@
M?0H*?0H`````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O075T:"]L9&%P
M+G!H<```````````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-#<Q
M,38@,3`U,34T,S,W,S<@,#(Q-S$U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B!4:&4@075T:%]L9&%P
M(&-L87-S('!R;W9I9&5S(&%N($Q$05`@:6UP;&5M96YT871I;VX@;V8@=&AE
M($AO<F1E"B`J(&%U=&AE;G1I8V%T:6]N('-Y<W1E;2X*("H*("H@4F5Q=6ER
M960@<&%R86UE=&5R<SH\<')E/@H@*B`@("=B87-E9&XG("`@("`@(%1H92!B
M87-E($1.(&9O<B!T:&4@3$1!4"!S97)V97(N"B`J("`@)VAO<W1S<&5C)R`@
M("`@5&AE(&AO<W1N86UE(&]F('1H92!,1$%0('-E<G9E<BX*("H@("`G=6ED
M)R`@("`@("`@("!4:&4@=7-E<FYA;64@<V5A<F-H(&ME>2X*("H@("`G9FEL
M=&5R)R`@("`@("!4:&4@3$1!4"!F;W)M871T960@<V5A<F-H(&9I;'1E<B!T
M;R!S96%R8V@@9F]R('5S97)S+B!4:&ES"B`J("`@("`@("`@("`@("`@("`@
M<V5T=&EN9R!O=F5R<FED97,@=&AE("=O8FIE8W1C;&%S<R<@;65T:&]D(&)E
M;&]W+@H@*B`@("=O8FIE8W1C;&%S<R<@(%1H92!O8FIE8W1C;&%S<R!F:6QT
M97(@=7-E9"!T;R!S96%R8V@@9F]R('5S97)S+B!#86X@8F4@80H@*B`@("`@
M("`@("`@("`@("`@('-I;F=L92!O8FIE8W1C;&%S<R!O<B!A;B!A<G)A>2X\
M+W!R93X*("H*("H@3W!T:6]N86P@<&%R86UE=&5R<SH\<')E/@H@*B`@("=B
M:6YD9&XG("`@("`@(%1H92!$3B!U<V5D('1O(&)I;F0@=&\@=&AE($Q$05`@
M<V5R=F5R"B`J("`@)W!A<W-W;W)D)R`@("`@5&AE('!A<W-W;W)D('5S960@
M=&\@8FEN9"!T;R!T:&4@3$1!4"!S97)V97(*("H@("`G=F5R<VEO;B<@("`@
M("!4:&4@=F5R<VEO;B!O9B!T:&4@3$1!4"!P<F]T;V-O;"!T;R!U<V4N"B`J
M("`@("`@("`@("`@("`@("`@1$5&055,5#H@3D].12`H<WES=&5M(&1E9F%U
M;'0@=VEL;"!B92!U<V5D*3PO<')E/@H@*@H@*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`L=B`Q+C0W+C$P+C$Y(#(P,#8O,#@O
M,30@,#(Z-#@Z-#@@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM
M,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H@
M0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E7T%U=&@*("HO
M"F-L87-S($%U=&A?;&1A<"!E>'1E;F1S($%U=&@@>PH*("`@("\J*@H@("`@
M("H@06X@87)R87D@;V8@8V%P86)I;&ET:65S+"!S;R!T:&%T('1H92!D<FEV
M97(@8V%N(')E<&]R="!W:&EC:`H@("`@("H@;W!E<F%T:6]N<R!I="!S=7!P
M;W)T<R!A;F0@=VAI8V@@:70@9&]E<VXG="X*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D8V%P86)I;&ET:65S(#T@87)R87DH
M)V%D9"<@("`@("`@("`@(#T^('1R=64L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=U<&1A=&4G("`@("`@("`]/B!T<G5E+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G<F5S971P87-S=V]R9"<@/3X@9F%L<V4L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R96UO=F4G("`@("`@
M("`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;&ES
M="<@("`@("`@("`@/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W1R86YS<&%R96YT)R`@(#T^(&9A;'-E*3L*"B`@("`O*BH*("`@
M("`J($Q$05`@8V]N;F5C=&EO;B!H86YD;&4*("`@("`J"B`@("`@*B!`=F%R
M(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D7V1S.PH*("`@("\J*@H@("`@
M("H@0V]N<W1R=6-T<R!A(&YE=R!,1$%0(&%U=&AE;G1I8V%T:6]N(&]B:F5C
M="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H
M(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!!=71H7VQD87`H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("![
M"B`@("`@("`@:68@*"%5=&EL.CIE>'1E;G-I;VY%>&ES=',H)VQD87`G*2D@
M>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH7R@B075T:%]L9&%P.B!297%U
M:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(BDL(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7W-E=%!A<F%M
M<R@D<&%R86US*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!C;VYF:6=U
M<F%T:6]N('!A<F%M971E<G,*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H
M(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?<V5T4&%R86US*"1P87)A;7,I"B`@("!["B`@("`@("`@
M+RH@16YS=7)E('=E)W9E(&)E96X@<')O=FED960@=VET:"!A;&P@;V8@=&AE
M(&YE8V5S<V%R>2!P87)A;65T97)S+B`J+PH@("`@("`@($AO<F1E.CIA<W-E
M<G1$<FEV97)#;VYF:6<H)'!A<F%M<RP@)V%U=&@G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)VAO<W1S<&5C)RP@)V)A<V5D
M;B<L("=U:60G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=A=71H96YT:6-A=&EO;B!,1$%0)RD["@H@("`@("`@("1T:&ES+3Y?<&%R
M86US(#T@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J($1O97,@86X@
M;&1A<"!C;VYN96-T(&%N9"!B:6YD<R!A<R!T:&4@9W5E<W0@=7-E<B!O<B!A
M<R!T:&4@;W!T:6]N86P@9&XN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]R($9A
M;'-E(&)A<V5D(&]N('-U8V-E<W,@;V8@8V]N;F5C="!A;F0@8FEN9"X*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V-O;FYE8W0H*0H@("`@>PH@("`@("`@("\J
M($-O;FYE8W0@=&\@=&AE($Q$05`@<V5R=F5R+B`J+PH@("`@("`@("1T:&ES
M+3Y?9',@/2!`;&1A<%]C;VYN96-T*"1T:&ES+3Y?<&%R86US6R=H;W-T<W!E
M8R==*3L*("`@("`@("!I9B`H(21T:&ES+3Y?9',I('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B1F%I;&5D('1O(&-O;FYE8W0@
M=&\@3$1!4"!S97)V97(N(BDI.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?<&%R86US6R=V97)S:6]N)UTI*2!["B`@("`@("`@("`@
M(&EF("@A;&1A<%]S971?;W!T:6]N*"1T:&ES+3Y?9',L($Q$05!?3U!47U!2
M3U1/0T],7U9%4E-)3TXL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=V97)S:6]N)UTI*2!["B`@("`@("`@("`@
M("`@("!(;W)D93HZ;&]G365S<V%G92AS<')I;G1F*"=3970@3$1!4"!P<F]T
M;V-O;"!V97)S:6]N('1O("5D(&9A:6QE9#H@6R5D72`E<R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=V97)S:6]N)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&QD87!?97)R;F\H)&-O;FXI+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!L9&%P7V5R<F]R*"1C;VYN
M*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?
M7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A<F%M<ULG8FEN
M9&1N)UTI*2!["B`@("`@("`@("`@("1B:6YD(#T@0&QD87!?8FEN9"@D=&AI
M<RT^7V1S+"`D=&AI<RT^7W!A<F%M<ULG8FEN9&1N)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G
M72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&)I;F0@/2!`;&1A
M<%]B:6YD*"1T:&ES+3Y?9',I.PH@("`@("`@('T*"B`@("`@("`@:68@*"$D
M8FEN9"D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?
M*")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB*2D["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J
M($9I;F0@=&AE('5S97(@9&X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@("`@("`@
M5&AE('5S97))9"!T;R!F:6YD+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@=7-E<G,@9G5L;"!$3@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M9FEN9$1.*"1U<V5R260I"B`@("!["B`@("`@("`@+RH@4V5A<F-H(&9O<B!T
M:&4@=7-E<B=S(&9U;&P@1$XN("HO"B`@("`@("`@)'-E87)C:"`]($!L9&%P
M7W-E87)C:"@D=&AI<RT^7V1S+"`D=&AI<RT^7W!A<F%M<ULG8F%S961N)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M
M<ULG=6ED)UT@+B`G/2<@+B`D=7-E<DED+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)'1H:7,M/E]P87)A;7-;)W5I9"==*2D["B`@
M("`@("`@:68@*"$D<V5A<F-H*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-
M97-S86=E*&QD87!?97)R;W(H)'1H:7,M/E]D<RDL(%]?1DE,15]?+"!?7TQ)
M3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H7R@B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V
M97(N(BDI.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]($!L9&%P7V=E
M=%]E;G1R:65S*"1T:&ES+3Y?9',L("1S96%R8V@I.PH@("`@("`@(&EF("AI
M<U]A<G)A>2@D<F5S=6QT*2`F)B`H8V]U;G0H)')E<W5L="D@/B`Q*2D@>PH@
M("`@("`@("`@("`D9&X@/2`D<F5S=6QT6S!=6R=D;B==.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(D5M<'1Y(')E<W5L="XB*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&1N.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS(&9O<B!S:&%D;W=,
M87-T0VAA;F=E(&%N9"!S:&%D;W=-:6XO36%X('-U<'!O<G0@86YD(')E='5R
M;G,@=&AE:7(*("`@("`J('9A;'5E<RX@(%=E('=I;&P@86QS;R!C:&5C:R!F
M;W(@<'=D3&%S=%-E="!I9B!!8W1I=F4@1&ER96-T;W)Y(&ES"B`@("`@*B!S
M=7!P;W)T(&ES(')E<75E<W1E9"X@($9O<B!T:&ES(&-H96-K('1O('-U8V-E
M960@=V4@;F5E9"!T;R!B92!B;W5N9`H@("`@("H@=&\@=&AE(&1I<F5C=&]R
M>0H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&1N("`@("!4:&4@9&X@;V8@=&AE('5S97(*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!A<G)A>2!W:71H(&ME>7,@8F5I
M;F<@(G-H861O=VQA<W1C:&%N9V4B+"`B<VAA9&]W;6EN(@H@("`@("H@("`@
M("`@("`@("`@("`@(G-H861O=VUA>"(L(")S:&%D;W=W87)N:6YG(B!A;F0@
M8V]N=&%I;FEN9R!T:&5I<@H@("`@("H@("`@("`@("`@("`@("`@<F5S<&5C
M=&EV92!V86QU97,@;W(@9F%L<V4@9F]R(&YO('-U<'!O<G0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]L;V]K=7!3:&%D;W<H)&1N*0H@("`@>PH@("`@("`@
M("\J($EN:70@=&AE(')E='5R;B!A<G)A>2X@*B\*("`@("`@("`D;&]O:W5P
M<VAA9&]W(#T@87)R87DH)W-H861O=VQA<W1C:&%N9V4G(#T^(&9A;'-E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<VAA9&]W;6EN)R`]/B!F
M86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-H861O=VUA
M>"<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S
M:&%D;W=W87)N:6YG)R`]/B!F86QS92D["@H*("`@("`@("`D<F5S=6QT(#T@
M0&QD87!?<F5A9"@D=&AI<RT^7V1S+"`D9&XL("=O8FIE8W1#;&%S<STJ)RD[
M"@H@("`@("`@(&EF("@D<F5S=6QT*2!["B`@("`@("`@("`@("1I;F9O<FUA
M=&EO;B`]($!L9&%P7V=E=%]E;G1R:65S*"1T:&ES+3Y?9',L("1R97-U;'0I
M.PH*("`@("`@("`@("`@:68@*"1T:&ES+3Y?<&%R86US6R=A9"==*2!["B`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)&EN9F]R;6%T:6]N6S!=6R=P=V1L
M87-T<V5T)UU;,%TI*2!["B`@("`@("`@("`@("`@("`@("`@+RH@06-T:79E
M($1I<F5C=&]R>2!H86YD;&5S('1I;65S=&%M<',@82!B:70*("`@("`@("`@
M("`@("`@("`@("`@*B!D:69F97)E;G1L>2X@($-O;G9E<G0@=&AE('1I;65S
M=&%M<"!T;R!A(%5.25@*("`@("`@("`@("`@("`@("`@("`@*B!T:6UE<W1A
M;7`N("HO"B`@("`@("`@("`@("`@("`@("`@)&QO;VMU<'-H861O=ULG<VAA
M9&]W;&%S=&-H86YG92==(#T@9FQO;W(H*"@D:6YF;W)M871I;VY;,%U;)W!W
M9&QA<W1S970G75LP72`O(#$P,#`P,#`P*2`M(#$Q-C0T-#`V-S@S*2`O(#@V
M-#`P*2`M(#$["@H@("`@("`@("`@("`@("`@("`@("\J(%!A<W-W;W)D(&5X
M<&ER>2!A='1R:6)U=&5S(&%R92!I;B!A('!O;&EC>2X@5V4*("`@("`@("`@
M("`@("`@("`@("`@*B!C86YN;W0@<F5A9"!T:&5M('-O('5S92!T:&4@2&]R
M9&4@8V]N9FEG+B`J+PH@("`@("`@("`@("`@("`@("`@("1L;V]K=7!S:&%D
M;W=;)W-H861O=W=A<FYI;F<G72`]("1T:&ES+3Y?<&%R86US6R=W87)N86=E
M)UT["B`@("`@("`@("`@("`@("`@("`@)&QO;VMU<'-H861O=ULG<VAA9&]W
M;6EN)UT@("`@(#T@)'1H:7,M/E]P87)A;7-;)VUI;F%G92==.PH@("`@("`@
M("`@("`@("`@("`@("1L;V]K=7!S:&%D;W=;)W-H861O=VUA>"==("`@("`]
M("1T:&ES+3Y?<&%R86US6R=M87AA9V4G73L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D:6YF;W)M871I;VY;,%U;)W-H861O=VUA>"==6S!=*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1L;V]K=7!S:&%D;W=;)W-H861O=VUA>"==(#T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN
M9F]R;6%T:6]N6S!=6R=S:&%D;W=M87@G75LP73L*("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&EN9F]R;6%T:6]N6S!=
M6R=S:&%D;W=M:6XG75LP72DI('L*("`@("`@("`@("`@("`@("`@("`D;&]O
M:W5P<VAA9&]W6R=S:&%D;W=M:6XG72`]"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O<FUA=&EO;ELP75LG<VAA
M9&]W;6EN)UU;,%T["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1I;F9O<FUA=&EO;ELP75LG<VAA9&]W;&%S=&-H86YG
M92==6S!=*2D@>PH@("`@("`@("`@("`@("`@("`@("1L;V]K=7!S:&%D;W=;
M)W-H861O=VQA<W1C:&%N9V4G72`]"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&EN9F]R;6%T:6]N6S!=6R=S:&%D;W=L87-T8VAA
M;F=E)UU;,%T["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1I;F9O<FUA=&EO;ELP75LG<VAA9&]W=V%R;FEN9R==6S!=
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1L;V]K=7!S:&%D;W=;)W-H861O
M=W=A<FYI;F<G72`]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&EN9F]R;6%T:6]N6S!=6R=S:&%D;W=W87)N:6YG)UU;,%T[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D;&]O:W5P<VAA9&]W.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1FEN9"!O=70@:68@=&AE(&=I=F5N('-E="!O9B!L;V=I;B!C<F5D
M96YT:6%L<R!A<F4@=F%L:60N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("`@("`@
M(%1H92!U<V5R260@=&\@8VAE8VLN"B`@("`@*B!`<&%R86T@87)R87D@("1C
M<F5D96YT:6%L<R`@06X@87)R87D@;V8@;&]G:6X@8W)E9&5N=&EA;',N"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,@
M;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?875T:&5N=&EC871E*"1U<V5R260L("1C<F5D96YT:6%L
M<RD*("`@('L*("`@("`@("`O*B!#;VYN96-T('1O('1H92!,1$%0('-E<G9E
M<BX@*B\*("`@("`@("`D<W5C8V5S<R`]("1T:&ES+3Y?8V]N;F5C="@I.PH@
M("`@("`@(&EF("AI<U]A*"1S=6-C97-S+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?<V5T075T:$5R<F]R*$%55$A?4D5!4T].7TU%
M4U-!1T4L("1S=6-C97-S+3YG971-97-S86=E*"DI.PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O*B!396%R8V@@9F]R
M('1H92!U<V5R)W,@9G5L;"!$3BX@*B\*("`@("`@("`D9&X@/2`D=&AI<RT^
M7V9I;F1$3B@D=7-E<DED*3L*("`@("`@("!I9B`H:7-?82@D9&XL("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H
M05542%]214%33TY?34534T%'12P@)&1N+3YG971-97-S86=E*"DI.PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O*B!!
M='1E;7!T('1O(&)I;F0@=&\@=&AE($Q$05`@<V5R=F5R(&%S('1H92!U<V5R
M+B`J+PH@("`@("`@("1B:6YD(#T@0&QD87!?8FEN9"@D=&AI<RT^7V1S+"`D
M9&XL("1C<F5D96YT:6%L<ULG<&%S<W=O<F0G72D["B`@("`@("`@:68@*"1B
M:6YD("$](&9A;'-E*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^7W!A<F%M
M<ULG<&%S<W=O<F1?97AP:7)A=&EO;B==(#T]("=Y97,G*2!["@H@("`@("`@
M("`@("`@("`@)'-H861O=R`]("1T:&ES+3Y?;&]O:W5P4VAA9&]W*"1D;BD[
M"@H@("`@("`@("`@("`@("`@:68@*"1S:&%D;W=;)W-H861O=VUA>"==("8F
M("1S:&%D;W=;)W-H861O=VQA<W1C:&%N9V4G72`F)@H@("`@("`@("`@("`@
M("`@("`@("1S:&%D;W=;)W-H861O=W=A<FYI;F<G72D@>PH*("`@("`@("`@
M("`@("`@("`@("`D=&]D87D@/2!F;&]O<BAT:6UE*"D@+R`X-C0P,"D["B`@
M("`@("`@("`@("`@("`@("`@)'=A<FYD87D@/2`D<VAA9&]W6R=S:&%D;W=L
M87-T8VAA;F=E)UT@*PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'-H861O=ULG<VAA9&]W;6%X)UT@+2`D<VAA9&]W6R=S:&%D;W=W87)N:6YG
M)UT["@H@("`@("`@("`@("`@("`@("`@("1T;V5X<&ER92`]("1S:&%D;W=;
M)W-H861O=VQA<W1C:&%N9V4G72`K"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'-H861O=ULG<VAA9&]W;6%X)UT@+2`D=&]D87D["@H*("`@
M("`@("`@("`@("`@("`@("!I9B`H)'1O9&%Y(#X]("1W87)N9&%Y*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1'3$]"04Q36R=N;W1I9FEC871I;VXG
M72T^<'5S:"AS<')I;G1F*%\H(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R
M9"!E>'!I<F5S+B(I+"`D=&]E>'!I<F4I+"=H;W)D92YW87)N:6YG)RD["B`@
M("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@("!I9B`H
M)'1O97AP:7)E(#T@,"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7V%U=&A#<F5D96YT:6%L<ULG8VAA;F=E4F5Q=65S=&5D)UT@/2!T<G5E
M.PH@("`@("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@
M:68@*"1T;V5X<&ER92`\(#`I('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]S971!=71H17)R;W(H05542%]214%33TY?15A025)%1"D["B`@
M("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@($!L9&%P7V-L;W-E*"1T:&ES+3Y?9',I.PH@("`@("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!`;&1A<%]C;&]S92@D=&AI<RT^7V1S*3L*("`@("`@("`@("`@)'1H:7,M
M/E]S971!=71H17)R;W(H05542%]214%33TY?1D%)3$5$*3L*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($%D9"!A('-E="!O9B!A=71H96YT:6-A=&EO;B!C<F5D96YT:6%L<RX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@("`@("!4:&4@
M=7-E<DED('1O(&%D9"X*("`@("`J($!P87)A;2!A<G)A>2`D8W)E9&5N=&EA
M;',@(%1H92!C<F5D96YT:6%L<R!T;R!B92!S970N"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@861D
M57-E<B@D=7-E<DED+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@:68@
M*"1T:&ES+3Y?<&%R86US6R=A9"==*2!["B`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H7R@B075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@
M;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(I+"!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@+RH@0V]N;F5C="!T
M;R!T:&4@3$1!4"!S97)V97(N("HO"B`@("`@("`@)'-U8V-E<W,@/2`D=&AI
M<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@9VQO8F%L("1C;VYF.PH@("`@("`@
M(&EF("@A96UP='DH)&-O;F9;)VAO;VMS)UU;)V%U=&AL9&%P)UTI*2!["B`@
M("`@("`@("`@($!I;F-L=61E($A/4D1%7T)!4T4@+B`G+V-O;F9I9R]H;V]K
M<RYP:'`G.PH@("`@("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=?:&]R
M9&5?:&]O:U]A=71H;&1A<"<I*2!["B`@("`@("`@("`@("`@("`D96YT<GD@
M/2!C86QL7W5S97)?9G5N8R@G7VAO<F1E7VAO;VM?875T:&QD87`G+"`D=7-E
M<DED+"`D8W)E9&5N=&EA;',I.PH@("`@("`@("`@("`@("`@)&1N(#T@)&5N
M=')Y6R=D;B==.PH@("`@("`@("`@("`@("`@+RH@<F5M;W9E('1H92!D;B!E
M;G1R>2!F<F]M('1H92!A<G)A>2X@*B\*("`@("`@("`@("`@("`@('5N<V5T
M*"1E;G1R>5LG9&XG72D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`O*B!4<GD@=&AI<R!S:6UP;&4@9&5F875L="!A;F0@
M:&]P92!I="!W;W)K<RX@*B\*("`@("`@("`@("`@)&1N(#T@)'1H:7,M/E]P
M87)A;7-;)W5I9"==("X@)STG("X@)'5S97))9"`N("<L)R`N("1T:&ES+3Y?
M<&%R86US6R=B87-E9&XG73L*("`@("`@("`@("`@)&5N=')Y6R=C;B==(#T@
M)'5S97))9#L*("`@("`@("`@("`@)&5N=')Y6R=S;B==(#T@)'5S97))9#L*
M("`@("`@("`@("`@)&5N=')Y6R1T:&ES+3Y?<&%R86US6R=U:60G75T@/2`D
M=7-E<DED.PH@("`@("`@("`@("`D96YT<GE;)V]B:F5C=&-L87-S)UT@/2!A
M<G)A>5]M97)G92AA<G)A>2@G=&]P)RDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=N97=U<V5R7V]B:F5C
M=&-L87-S)UTI.PH@("`@("`@("`@("`D96YT<GE;)W5S97)087-S=V]R9"==
M(#T@)'1H:7,M/F=E=$-R>7!T961087-S=V]R9"@D8W)E9&5N=&EA;'-;)W!A
M<W-W;W)D)UTL)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=E;F-R>7!T:6]N)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T<G5E)RD["@H@
M("`@("`@("`@("!I9B`H)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D7V5X<&ER
M871I;VXG72`]/2`G>65S)RD@>PH@("`@("`@("`@("`@("`@)&5N=')Y6R=S
M:&%D;W=-:6XG72`]("1T:&ES+3Y?<&%R86US6R=M:6YA9V4G73L*("`@("`@
M("`@("`@("`@("1E;G1R>5LG<VAA9&]W36%X)UT@/2`D=&AI<RT^7W!A<F%M
M<ULG;6%X86=E)UT["B`@("`@("`@("`@("`@("`D96YT<GE;)W-H861O=U=A
M<FYI;F<G72`]("1T:&ES+3Y?<&%R86US6R=W87)N86=E)UT["B`@("`@("`@
M("`@("`@("`D96YT<GE;)W-H861O=TQA<W1#:&%N9V4G72`](&9L;V]R*'1I
M;64H*2`O(#@V-#`P*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("`D<W5C8V5S<R`]($!L9&%P7V%D9"@D=&AI<RT^7V1S+"`D9&XL("1E;G1R
M>2D["@H@("`@("`@(&EF("@A)'-U8V-E<W,I('L*("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D%U=&A?;&1A<#H@56YA
M8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED.B`B*2P@)'5S97))9"D@+B!`;&1A<%]E<G)O<B@D=&AI<RT^7V1S*2D[
M"B`@("`@("`@?0H*("`@("`@("!`;&1A<%]C;&]S92@D=&AI<RT^7V1S*3L*
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M96UO=F4@82!S970@;V8@875T:&5N=&EC871I;VX@8W)E9&5N=&EA;',N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("`@("`@5&AE('5S
M97))9"!T;R!A9&0N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U
M92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E57-E<B@D=7-E<DED*0H@
M("`@>PH@("`@("`@(&EF("@D=&AI<RT^7W!A<F%M<ULG860G72D@>PH@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D%U=&A?;&1A<#H@
M4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I
M<F5C=&]R>2(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@
M("`@("`@+RH@0V]N;F5C="!T;R!T:&4@3$1!4"!S97)V97(N("HO"B`@("`@
M("`@)'-U8V-E<W,@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H
M:7-?82@D<W5C8V5S<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/3E]-15-304=%+"`D<W5C
M8V5S<RT^9V5T365S<V%G92@I*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*"B`@("`@("`@9VQO8F%L("1C;VYF.PH@("`@("`@(&EF
M("@A96UP='DH)&-O;F9;)VAO;VMS)UU;)V%U=&AL9&%P)UTI*2!["B`@("`@
M("`@("`@($!I;F-L=61E($A/4D1%7T)!4T4@+B`G+V-O;F9I9R]H;V]K<RYP
M:'`G.PH@("`@("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=?:&]R9&5?
M:&]O:U]A=71H;&1A<"<I*2!["B`@("`@("`@("`@("`@("`D96YT<GD@/2!C
M86QL7W5S97)?9G5N8R@G7VAO<F1E7VAO;VM?875T:&QD87`G+"`D=7-E<DED
M*3L*("`@("`@("`@("`@("`@("1D;B`]("1E;G1R>5LG9&XG73L*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J(%-E87)C
M:"!F;W(@=&AE('5S97(G<R!F=6QL($1.+B`J+PH@("`@("`@("`@("`D9&X@
M/2`D=&AI<RT^7V9I;F1$3B@D=7-E<DED*3L*("`@("`@("`@("`@:68@*&ES
M7V$H)&1N+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/3E]-15-304=%+"`D9&XM/F=E
M=$UE<W-A9V4H*2D["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1S=6-C97-S(#T@0&QD
M87!?9&5L971E*"1T:&ES+3Y?9',L)&1N*3L*("`@("`@("!I9B`H(21S=6-C
M97-S*2!["B`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R
M:6YT9BA?*")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(I
M+"`D=7-E<DED*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@
M("`@("`@($!L9&%P7V-L;W-E*"1T:&ES+3Y?9',I.PH*("`@("`@("!R971U
M<FX@)'1H:7,M/G)E;6]V955S97)$871A*"1U<V5R260I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@57!D871E(&$@<V5T(&]F(&%U=&AE;G1I8V%T:6]N(&-R
M961E;G1I86QS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&]L9$E$
M("`@("`@(%1H92!O;&0@=7-E<DED+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;F5W240@("`@("`@5&AE(&YE=R!U<V5R260N"B`@("`@*B!`<&%R86T@87)R
M87D@)&-R961E;G1I86QS("!4:&4@;F5W(&-R961E;G1I86QS"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!
M4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@=7!D871E57-E<B@D;VQD240L("1N97=)1"P@)&-R961E;G1I86QS*0H@
M("`@>PH@("`@("`@(&EF("@D=&AI<RT^7W!A<F%M<ULG860G72D@>PH@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D%U=&A?;&1A<#H@
M57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I
M<F5C=&]R>2XB*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@
M("`@("`@("\J($-O;FYE8W0@=&\@=&AE($Q$05`@<V5R=F5R+B`J+PH@("`@
M("`@("1S=6-C97-S(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@
M*&ES7V$H)'-U8V-E<W,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)'-U8V-E<W,M/F=E=$UE<W-A9V4H
M*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@(&=L
M;V)A;"`D8V]N9CL*("`@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=H;V]K<R==
M6R=A=71H;&1A<"==*2D@>PH@("`@("`@("`@("!`:6YC;'5D92!(3U)$15]"
M05-%("X@)R]C;VYF:6<O:&]O:W,N<&AP)SL*("`@("`@("`@("`@:68@*&9U
M;F-T:6]N7V5X:7-T<R@G7VAO<F1E7VAO;VM?875T:&QD87`G*2D@>PH@("`@
M("`@("`@("`@("`@)&5N=')Y(#T@8V%L;%]U<V5R7V9U;F,H)U]H;W)D95]H
M;V]K7V%U=&AL9&%P)RP@)&]L9$E$+"`D8W)E9&5N=&EA;',I.PH@("`@("`@
M("`@("`@("`@)&]L9&1N(#T@)&5N=')Y6R=D;B==.PH@("`@("`@("`@("`@
M("`@)&5N=')Y(#T@8V%L;%]U<V5R7V9U;F,H)U]H;W)D95]H;V]K7V%U=&AL
M9&%P)RP@)&YE=TE$+"`D8W)E9&5N=&EA;',I.PH@("`@("`@("`@("`@("`@
M)&YE=V1N(#T@)&5N=')Y6R=D;B==.PH@("`@("`@("`@("`@("`@=6YS970H
M)&5N=')Y6R=D;B==*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("\J(%-E87)C:"!F;W(@=&AE('5S97(G<R!F=6QL($1.
M+B`J+PH@("`@("`@("`@("`D9&X@/2`D=&AI<RT^7V9I;F1$3B@D;VQD240I
M.PH*("`@("`@("`@("`@:68@*&ES7V$H)&1N+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D<W5C
M8V5S<RT^9V5T365S<V%G92@I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&]L9&1N(#T@)&1N
M.PH@("`@("`@("`@("`@("`@)&YE=V1N(#T@<')E9U]R97!L86-E*"<O=6ED
M/2XJ/RPO)RPG=6ED/2<N)&YE=TE$+B<L)RPD9&XL,2D["B`@("`@("`@("`@
M("`@("`D<VAA9&]W(#T@)'1H:7,M/E]L;V]K=7!3:&%D;W<H)&1N*3L*"B`@
M("`@("`@("`@("`@("`O*B!I9B!S:&%D;W=M:6X@:&%S;B=T('EE="!E>'!I
M<F5D(&]N;'D@8VAA;F=E('=H96X@=V4@87)E"B`@("`@("`@("`@("`@("`@
M("!A9&UI;FES=')A=&]R("HO"B`@("`@("`@("`@("`@("!I9B`H)'-H861O
M=ULG<VAA9&]W;&%S=&-H86YG92==("8F("1S:&%D;W=;)W-H861O=VUI;B==
M*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1S:&%D;W=;)W-H861O=VQA
M<W1C:&%N9V4G72`K("1S:&%D;W=;)W-H861O=VUI;B==(#X@*'1I;64H*2`O
M(#@V-#`P*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BA?*")-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T
M('EE="!E>'!I<F5D(BDI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O*B!3970@=&AE(&QA<W1C
M:&%N9V4@9FEE;&0@*B\*("`@("`@("`@("`@("`@(&EF("@D<VAA9&]W6R=S
M:&%D;W=L87-T8VAA;F=E)UTI('L*("`@("`@("`@("`@("`@("`@("`D96YT
M<GE;)W-H861O=VQA<W1C:&%N9V4G72`]("!F;&]O<BAT:6UE*"D@+R`X-C0P
M,"D["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@+RH@16YC
M<GEP="!T:&4@;F5W('!A<W-W;W)D("HO"B`@("`@("`@("`@("`@("`D96YT
M<GE;)W5S97)P87-S=V]R9"==(#T@)'1H:7,M/F=E=$-R>7!T961087-S=V]R
M9"@D8W)E9&5N=&EA;'-;)W!A<W-W;W)D)UTL)R<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A<F%M<ULG96YC<GEP=&EO;B==+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W1R=64G*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@:68@*"1O;&1)1"`A/2`D;F5W240I('L*("`@("`@("`@
M("`@:68@*$Q$05!?3U!47U!23U1/0T],7U9%4E-)3TX@/3T@,RD@>PH@("`@
M("`@("`@("`@("`@;&1A<%]R96YA;64H)'1H:7,M/E]D<RP@)&]L9&1N+"`D
M;F5W9&XL("1T:&ES+3Y?<&%R86US6R=B87-E9&XG72P@=')U92D["@H@("`@
M("`@("`@("`@("`@)'-U8V-E<W,@/2!L9&%P7VUO9&EF>2@D=&AI<RT^7V1S
M+"`D;F5W9&XL("1E;G1R>2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`O*B!'970@=&AE(&-O;7!L971E(&]L9"!R96-O<F0@9FER
M<W0@*B\*("`@("`@("`@("`@("`@("1S=6-C97-S(#T@0&QD87!?<F5A9"@D
M=&AI<RT^7V1S+"`D;VQD9&XL("=O8FIE8W1#;&%S<STJ)RD["@H@("`@("`@
M("`@("`@("`@:68@*"1S=6-C97-S*2!["B`@("`@("`@("`@("`@("`@("`@
M)&EN9F]R;6%T:6]N(#T@0&QD87!?9V5T7V5N=')I97,H)'1H:7,M/E]D<RP@
M)'-U8V-E<W,I.PH*("`@("`@("`@("`@("`@("`@("`O*B!296UO=F4@=&AE
M(&-O=6YT(&5L96UE;G1S(&9R;VT@=&AE(&%R<F%Y("HO"B`@("`@("`@("`@
M("`@("`@("`@)&-O=6YT97(@/2`P.PH@("`@("`@("`@("`@("`@("`@("1N
M97=R96-O<F0@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@('=H:6QE
M("AI<W-E="@D:6YF;W)M871I;VY;,%U;)&-O=6YT97)=*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H)&EN9F]R;6%T:6]N6S!=6R1I;F9O<FUA
M=&EO;ELP75LD8V]U;G1E<EU=6R=C;W5N="==(#T](#$I('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1N97=R96-O<F1;)&EN9F]R;6%T:6]N6S!=
M6R1C;W5N=&5R75T@/2`D:6YF;W)M871I;VY;,%U;)&EN9F]R;6%T:6]N6S!=
M6R1C;W5N=&5R75U;,%T["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F5W<F5C;W)D6R1I
M;F9O<FUA=&EO;ELP75LD8V]U;G1E<EU=(#T@)&EN9F]R;6%T:6]N6S!=6R1I
M;F9O<FUA=&EO;ELP75LD8V]U;G1E<EU=.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@=6YS970H)&YE=W)E8V]R9%LD:6YF;W)M871I;VY;,%U;)&-O
M=6YT97)=75LG8V]U;G0G72D["B`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`@("`@)&-O=6YT97(K*SL*("`@("`@("`@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@("`@("\J($%D:G5S="!T
M:&4@8VAA;F=E9"!P87)A;65T97)S("HO"B`@("`@("`@("`@("`@("`@("`@
M=6YS970H)&YE=W)E8V]R9%LG9&XG72D["B`@("`@("`@("`@("`@("`@("`@
M)&YE=W)E8V]R9%LD=&AI<RT^7W!A<F%M<ULG=6ED)UU=(#T@)&YE=TE$.PH@
M("`@("`@("`@("`@("`@("`@("1N97=R96-O<F1;)W5S97)P87-S=V]R9"==
M(#T@)&5N=')Y6R=U<V5R<&%S<W=O<F0G73L*("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)&5N=')Y6R=S:&%D;W=L87-T8VAA;F=E)UTI*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1N97=R96-O<F1;)W-H861O=VQA<W1C
M:&%N9V4G72`]("1E;G1R>5LG<VAA9&]W;&%S=&-H86YG92==.PH@("`@("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@)'-U8V-E<W,@
M/2!L9&%P7V%D9"@D=&AI<RT^7V1S+"1N97=D;BPD;F5W<F5C;W)D*3L*("`@
M("`@("`@("`@("`@("`@("!I9B`H)'-U8V-E<W,I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'-U8V-E<W,@/2!`;&1A<%]D96QE=&4H)'1H:7,M/E]D
M<RPD;VQD9&XI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1S=6-C97-S(#T@0&QD87!?;6]D:69Y*"1T:&ES+3Y?9',L("1O;&1D
M;BP@)&5N=')Y*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A)'-U8V-E<W,I
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT
M9BA?*")!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<R(I+"`D
M;F5W240I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@
M("`@0&QD87!?8VQO<V4H)'1H:7,M/E]D<RD["@H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@3&ES="!5<V5R<PH@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@($QI<W0@;V8@57-E<G,*("`@("`J+PH@
M("`@9G5N8W1I;VX@;&ES=%5S97)S*"D*("`@('L*("`@("`@("`O*B!#;VYN
M96-T('1O('1H92!,1$%0('-E<G9E<BX@*B\*("`@("`@("`D<W5C8V5S<R`]
M("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1S=6-C97-S
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"1S=6-C97-S+3YG971-97-S86=E*"DL(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES
M+3Y?<&%R86US6R=F:6QT97(G72DI('L*("`@("`@("`@("`@)&9I;'1E<B`]
M("1T:&ES+3Y?<&%R86US6R=F:6QT97(G73L*("`@("`@("!](&5L<V5I9B`H
M(6ES7V%R<F%Y*"1T:&ES+3Y?<&%R86US6R=O8FIE8W1C;&%S<R==*2D@>PH@
M("`@("`@("`@("`D9FEL=&5R(#T@)V]B:F5C=&-L87-S/2<@+B`D=&AI<RT^
M7W!A<F%M<ULG;V)J96-T8VQA<W,G73L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D9FEL=&5R(#T@)R<["B`@("`@("`@("`@(&9O<F5A8V@@*"1T
M:&ES+3Y?<&%R86US6R=O8FIE8W1C;&%S<R==(&%S("1O8FIE8W1C;&%S<RD@
M>PH@("`@("`@("`@("`@("`@)&9I;'1E<B`]("<H)B<@+B`D9FEL=&5R.PH@
M("`@("`@("`@("`@("`@)&9I;'1E<B`N/2`G*&]B:F5C=&-L87-S/2<@+B`D
M;V)J96-T8VQA<W,@+B`G*2DG.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("`D<V5A<F-H(#T@0&QD87!?<V5A<F-H*"1T:&ES+3Y?9',L("1T
M:&ES+3Y?<&%R86US6R=B87-E9&XG72P@)&9I;'1E<BP@87)R87DH)'1H:7,M
M/E]P87)A;7-;)W5I9"==*2D["B`@("`@("`@)&5N=')I97,@/2!`;&1A<%]G
M971?96YT<FEE<R@D=&AI<RT^7V1S+"`D<V5A<F-H*3L*("`@("`@("`D=7-E
M<FQI<W0@/2!A<G)A>2@I.PH@("`@("`@("1U:60@/2!3=')I;F<Z.FQO=V5R
M*"1T:&ES+3Y?<&%R86US6R=U:60G72D["B`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P@)&5N=')I97-;)V-O=6YT)UT[("1I*RLI('L*("`@("`@("`@("`@
M)'5S97)L:7-T6R1I72`]("1E;G1R:65S6R1I75LD=6ED75LP73L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D=7-E<FQI<W0["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP````````````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#,P,#<Q(#$P-3$U-#,S-S,W(#`R,C$S,@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@5&AE($%U=&A?8WER=7,@8VQA<W,@<')O=FED97,@:&]R9&4@
M=VET:"!T:&4@86)I;&ET>2!O9B!A9&UI;FES=')A=&EN9PH@*B!A($-Y<G5S
M(&UA:6P@<V5R=F5R(&%U=&AE;G1I8V%T:6]N<R!A9V%I;G-T(&%N;W1H97(@
M8F%C:V5N9"!T:&%T($AO<F1E"B`J(&-A;B!U<&1A=&4@*&5G(%-13"!O<B!,
M1$%0*2X*("H*("H@4F5Q=6ER960@<&%R86UE=&5R<SH\<')E/@H@*B`@("=C
M>7)A9&UI;B<@("!4:&4@=7-E<FYA;64@;V8@=&AE(&-Y<G5S(&%D;6EN:7-T
M<F%T;W(*("H@("`G8WER<&%S<R<@("`@5&AE('!A<W-W;W)D(&9O<B!T:&4@
M8WER=7,@861M:6YI<W1R871O<@H@*B`@("=I;6%P7V1S;B<@("!4:&4@9G5L
M;"!)34%0($133B`H:2YE+@H@("`@("`@("`@("`@("`@("![;&]C86QH;W-T
M.CDY,R]I;6%P+W-S;"]N;W9A;&ED871E+6-E<G1]*0H@*B`@("=B86-K96YD
M)R`@("!4:&4@8V]M<&QE=&4@:&%S:"!F;W(@=&AE($%U=&A?*B!D<FEV97(@
M=&AA="!C>7)U<PH@*B`@("`@("`@("`@("`@("!A=71H96YT:6-A=&5S(&%G
M86EN<W0@*&5G(%-13"P@3$1!4"DN"B`J("`@)W-E<&%R871O<B<@($AI97)A
M<F-H>2!S97!A<F%T;W(@=&\@=7-E("AE+F<N+"!I<R!I="!U<V5R+VUA:6QB
M;W@@;W(*("H@("`@("`@("`@("`@("`@=7-E<BYM86EL8F]X*3PO<')E/@H@
M*@H@*B!/<'1I;VYA;"!V86QU97,Z/'!R93X*("H@("`G=6YI>&AI97(G("`@
M5&AE('9A;'5E(&]F(&EM87!D+F-O;F8G<R!U;FEX:&EE<F%R8VAY<V5P('-E
M='1I;F<N"B`J("`@("`@("`@("`@("`@(%-E="!T:&ES('1O("=T<G5E)R!I
M9B!T:&4@=F%L=64@:7,@=')U92!I;B!I;6%P9"YC;VYF"B`J("`@)V9O;&1E
M<G,G("`@($%N(&%R<F%Y(&]F(&9O;&1E<G,@=&\@8W)E871E('5N9&5R('5S
M97)N86UE+@H@*B`@("`@("`@("`@("`@("!$;V5S;B=T(&-R96%T92!S=6)F
M;VQD97)S(&)Y(&1E9F%U;'0N"B`J("`@)W%U;W1A)R`@("`@(%1H92!Q=6]T
M82`H:6X@:VEL;V)Y=&5S*2!T;R!G<F%N="!O;B!T:&4@;6%I;&)O>"X*("H@
M("`@("`@("`@("`@("`@1&]E<R!N;W0@97-T86)L:7-H('%U;W1A(&)Y(&1E
M9F%U;'0N/"]P<F4^"B`J"B`J($5X86UP;&4@57-A9V4Z/'!R93X*("H@("`D
M8V]N9ELG875T:"==6R=D<FEV97(G72`]("=C;VUP;W-I=&4G.PH@*B`@("1C
M;VYF6R=A=71H)UU;)W!A<F%M<R==6R=L;V=I;G-C<F5E;E]S=VET8V@G72`]
M("=?:&]R9&5?<V5L96-T7VQO9VEN<V-R965N)SL*("H@("`D8V]N9ELG875T
M:"==6R=P87)A;7,G75LG861M:6Y?9')I=F5R)UT@/2`G8WER=7,G.PH@*B`@
M("1C;VYF6R=A=71H)UU;)W!A<F%M<R==6R=D<FEV97)S)UU;)VEM<"==(#T@
M87)R87DH)V1R:79E<B<@/3X@)V%P<&QI8V%T:6]N)RP*("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P
M87)A;7,G(#T^(&%R<F%Y*"=A<'`G(#T^("=I;7`G*2D["B`J("`@)&-O;F9;
M)V%U=&@G75LG<&%R86US)UU;)V1R:79E<G,G75LG8WER=7,G72`](&%R<F%Y
M*"=D<FEV97(G(#T^("=C>7)U<R<L"B`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P87)A;7,G(#T^
M(&%R<F%Y*"=C>7)A9&UI;B<@/3X@)V-Y<G5S)RP*("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V-Y<G!A<W,G(#T^("=P87-S=V]R9"<L"B`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=S97!A<F%T;W(G(#T^("<N)RP*
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VEM87!?9'-N)R`]/B`G
M>VUA:6LN97AA;7!L92YC;VTO:6UA<'TG*2D["B`J("`@)&-O;F9;)V%U=&@G
M75LG<&%R86US)UU;)V1R:79E<G,G75LG8WER=7,G75LG<&%R86US)UU;)V)A
M8VME;F0G72`](&%R<F%Y*"=D<FEV97(G(#T^("=S<6PG+`H@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G<&%R86US)R`]/B!A<G)A>2@G<&AP
M='EP92<@/3X@)VUY<W%L)RP*("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)VAO<W1S<&5C)R`]/B`G9&%T86)A
M<V4N97AA;7!L92YC;VTG+`H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G<')O=&]C;VPG(#T^("=T8W`G+`H@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G=7-E<FYA;64G(#T^("=U<V5R;F%M92<L"B`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P87-S=V]R
M9"<@/3X@)W!A<W-W;W)D)RP*("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)V1A=&%B87-E)R`]/B`G;6%I;"<L
M"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=T86)L92<@/3X@)V%C8V]U;G1U<V5R)RP*("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V5N8W)Y
M<'1I;VXG(#T^("=M9#4M:&5X)RP*("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5S97)N86UE7V9I96QD)R`]
M/B`G=7-E<FYA;64G+`H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G<&%S<W=O<F1?9FEE;&0G(#T^("=P87-S
M=V]R9"<I*3L*("H*("H@("!I9B`H(69U;F-T:6]N7V5X:7-T<R@G7VAO<F1E
M7W-E;&5C=%]L;V=I;G-C<F5E;B<I*2!["B`J("`@("`@(&9U;F-T:6]N(%]H
M;W)D95]S96QE8W1?;&]G:6YS8W)E96XH*2!["B`J("`@("`@("`@("!R971U
M<FX@)VEM<"<["B`J("`@("`@('T*("H@("!]/"]P<F4^"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`L=B`Q+C$U+C$P+C$T
M(#(P,#8O,#@O,30@,#(Z-#@Z-#@@8VAU8VL@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#(M,C`P-B!);'EA(#QM86EL0&MR96PN;W)G/@H@*B!#;W!Y<FEG
M:'0@,C`P,RTR,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN
M8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!);'EA(#QM86EL
M0&MR96PN;W)G/@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R
M869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A
M8VMA9V4@2&]R9&5?075T:`H@*B\*8VQA<W,@075T:%]C>7)U<R!E>'1E;F1S
M($%U=&@@>PH*("`@("\J*@H@("`@("H@2&%N9&QE(&9O<B!T:&4@8W5R<F5N
M="!)34%0(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@("H@0'9A<B!R97-O=7)C
M90H@("`@("HO"B`@("!V87(@)%]I;6%P4W1R96%M.PH*("`@("\J*@H@("`@
M("H@1FQA9R!I;F1I8V%T:6YG(&EF('1H92!)34%0(&-O;FYE8W1I;VX@:7,@
M8V]N;F5C=&5D+@H@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO
M"B`@("!V87(@)%]C;VYN96-T960["@H@("`@+RHJ"B`@("`@*B!0;VEN=&5R
M('1O(&%N;W1H97(@075T:%\@8F%C:V5N9"!T:&%T($-Y<G5S(&%U=&AE;G1I
M8V%T97,@86=A:6YS="X*("`@("`J"B`@("`@*B!`=F%R($%U=&@*("`@("`J
M+PH@("`@('9A<B`D7V)A8VME;F0["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A
M>2!O9B!C87!A8FEL:71I97,L('-O('1H870@=&AE(&1R:79E<B!C86X@<F5P
M;W)T('=H:6-H"B`@("`@*B!O<&5R871I;VYS(&ET('-U<'!O<G1S(&%N9"!W
M:&EC:"!I="!D;V5S;B=T+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1C87!A8FEL:71I97,@/2!A<G)A>2@G861D)R`@("`@
M("`@("`@/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W5P9&%T92<@("`@("`@(#T^('1R=64L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=R97-E='!A<W-W;W)D)R`]/B!F86QS92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W)E;6]V92<@("`@("`@(#T^('1R=64L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=L:7-T)R`@("`@("`@
M("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V=R
M;W5P<R<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G=')A;G-P87)E;G0G("`@/3X@9F%L<V4I.PH*("`@("\J*@H@
M("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE
M=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@075T:%]C>7)U<R@D<&%R86US
M(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P
M87)A;7,["@H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;)W-E
M<&%R871O<B==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<V5P
M87)A=&]R)UT@/2`G+B<["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]P87)A;7-;)W5N:7AH:65R)UTI("8F("1T:&ES+3Y?<&%R86US
M6R=U;FEX:&EE<B==(#T]('1R=64I('L*("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)W-E<&%R871O<B==(#T@)R\G.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"%5=&EL.CIE>'1E;G-I;VY%>&ES=',H)VEM87`G*2D@>PH@("`@("`@
M("`@("!(;W)D93HZ9F%T86PH7R@B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA
M<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I
M.PH@("`@("`@('T*"B`@("`@("`@+R\@0W)E871E(&)A8VME;F0@:6YS=&%N
M8V4N"B`@("`@("`@)'1H:7,M/E]B86-K96YD(#T@)D%U=&@Z.G-I;F=L971O
M;B@D=&AI<RT^7W!A<F%M<ULG8F%C:V5N9"==6R=D<FEV97(G72P@)'1H:7,M
M/E]P87)A;7-;)V)A8VME;F0G75LG<&%R86US)UTI.PH@("`@("`@(&EF("AI
M<U]A*"1T:&ES+3Y?8F%C:V5N9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]B86-K96YD.PH@("`@("`@('T*"B`@("`@
M("`@+R\@0VAE8VL@=&AE(&-A<&%B:6QI=&EE<R!O9B!T:&4@8F%C:V5N9"X*
M("`@("`@("!I9B`H(21T:&ES+3Y?8F%C:V5N9"T^:&%S0V%P86)I;&ET>2@G
M861D)RD@?'P*("`@("`@("`@("`@(21T:&ES+3Y?8F%C:V5N9"T^:&%S0V%P
M86)I;&ET>2@G=7!D871E)RD@?'P*("`@("`@("`@("`@(21T:&ES+3Y?8F%C
M:V5N9"T^:&%S0V%P86)I;&ET>2@G<F5M;W9E)RDI('L*("`@("`@("`@("`@
M2&]R9&4Z.F9A=&%L*%\H(D%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@
M:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB*2P@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YC87!A8FEL:71I97-;
M)VQI<W0G72`]("1T:&ES+3Y?8F%C:V5N9"T^:&%S0V%P86)I;&ET>2@G;&ES
M="<I.PH@("`@("`@("1T:&ES+3YC87!A8FEL:71I97-;)V=R;W5P<R==(#T@
M)'1H:7,M/E]B86-K96YD+3YH87-#87!A8FEL:71Y*"=G<F]U<',G*3L*("`@
M("`@("`D=&AI<RT^8V%P86)I;&ET:65S6R=T<F%N<W!A<F5N="==(#T@)'1H
M:7,M/E]B86-K96YD+3YH87-#87!A8FEL:71Y*"=T<F%N<W!A<F5N="<I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@061D(&$@<V5T(&]F(&%U=&AE;G1I8V%T
M:6]N(&-R961E;G1I86QS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'5S97))9"`@("`@("!4:&4@=7-E<DED('1O(&%D9"X*("`@("`J($!P87)A
M;2!A<G)A>2`@)&-R961E;G1I86QS("!4:&4@8W)E9&5N=&EA;',@=&\@861D
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S
M<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&%D9%5S97(H)'5S97))9"P@)&-R961E;G1I86QS*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("`D<F5S
M(#T@)'1H:7,M/E]B86-K96YD+3YA9&15<V5R*"1U<V5R260L("1C<F5D96YT
M:6%L<RD["B`@("`@("`@:68@*&ES7V$H)')E<RP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("!]"@H@("`@("`@
M("1N86UE(#T@:6UA<%]U=&8W7V5N8V]D92@D=7-E<DED*3L*("`@("`@("!I
M9B`H0&EM87!?8W)E871E;6%I;&)O>"@D=&AI<RT^7VEM87!3=')E86TL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:6UA<%]U=&8W7V5N8V]D
M92@D=&AI<RT^7W!A<F%M<ULG:6UA<%]D<VXG72`N"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W5S97(G("X@)'1H:7,M/E]P87)A;7-;)W-E
M<&%R871O<B==("X@)&YA;64I*2D@>PH@("`@("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]P87)A;7-;)V9O;&1E<G,G72D@)B8@:7-?87)R87DH)'1H:7,M
M/E]P87)A;7-;)V9O;&1E<G,G72DI('L*("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3Y?<&%R86US6R=F;VQD97)S)UT@87,@)&9O;&1E<BD@>PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8W)E871E4W5B1F]L9&5R*"1N
M86UE+"`D9F]L9&5R*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S
M86=E*"=)34%0(&UA:6QB;W@@8W)E871I;VX@9F]R("<@+B`D;F%M92`N("<@
M9F%I;&5D("<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,
M15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*"))34%0(&UA:6QB;W@@
M8W)E871I;VX@9F%I;&5D.B`E<R(I+"!I;6%P7VQA<W1?97)R;W(H*2DI.PH@
M("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%R86US6R=Q
M=6]T82==*2`F)B`D=&AI<RT^7W!A<F%M<ULG<75O=&$G72`^/2`P*2!["B`@
M("`@("`@("`@(&EF("@A0&EM87!?<V5T7W%U;W1A*"1T:&ES+3Y?:6UA<%-T
M<F5A;2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5S97(G
M("X@)'1H:7,M/E]S97!A<F%T;W(@+B`D;F%M92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W%U;W1A)UTI*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I
M;G1F*%\H(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S
M(BDL(&EM87!?;&%S=%]E<G)O<B@I*2D["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1&5L971E(&$@<V5T(&]F(&%U=&AE;G1I8V%T:6]N(&-R961E;G1I86QS
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@5&AE('5S
M97))9"!T;R!D96QE=&4N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("`@("`@("!3=6-C97-S(&]R(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(')E;6]V955S97(H)'5S97))9"D*("`@('L*("`@("`@("`D=&AI<RT^
M7V-O;FYE8W0H*3L*"B`@("`@("`@)')E<R`]("1T:&ES+3Y?8F%C:V5N9"T^
M<F5M;W9E57-E<B@D=7-E<DED*3L*("`@("`@("!I9B`H:7-?82@D<F5S+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@
M("`@('T*"B`@("`@("`@+RH@4V5T($%#3"!F;W(@;6%I;&)O>"!D96QE=&EO
M;BX@*B\*("`@("`@("!L:7-T*"1A9&UI;BD@/2!E>'!L;V1E*"=`)RP@)'1H
M:7,M/E]P87)A;7-;)V-Y<F%D;6EN)UTI.PH@("`@("`@($!I;6%P7W-E=&%C
M;"@D=&AI<RT^7VEM87!3=')E86TL"B`@("`@("`@("`@("`@("`@("`@("=U
M<V5R)R`N("1T:&ES+3Y?<&%R86US6R=S97!A<F%T;W(G72`N("1U<V5R260L
M"B`@("`@("`@("`@("`@("`@("`@("1A9&UI;BP@)VQR<W=I<&-D82<I.PH*
M("`@("`@("`O*B!$96QE=&4@24U!4"!M86EL8F]X+B`J+PH@("`@("`@("1I
M;6%P<F5S=6QT(#T@0&EM87!?9&5L971E;6%I;&)O>"@D=&AI<RT^7VEM87!3
M=')E86TL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=I;6%P7V1S;B==("X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5S97(G("X@)'1H:7,M
M/E]P87)A;7-;)W-E<&%R871O<B==("X@)'5S97))9"D["@H@("`@("`@(&EF
M("@A)&EM87!R97-U;'0I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H<W!R:6YT9BA?*"))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I
M;&5D.B`E<R(I+"!I;6%P7VQA<W1?97)R;W(H*2DI.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1T:&ES+3YR96UO=F55<V5R1&%T82@D=7-E<DED*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(&]P96X@8V]N;F5C
M=&EO;G,@=&\@=&AE(%-13"!A;F0@24U!4"!S97)V97)S+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYN96-T*"D*("`@
M('L*("`@("`@("!I9B`H(21T:&ES+3Y?8V]N;F5C=&5D*2!["@H@("`@("`@
M("`@("`D=&AI<RT^7VEM87!3=')E86T@/2!`:6UA<%]O<&5N*"1T:&ES+3Y?
M<&%R86US6R=I;6%P7V1S;B==+"`D=&AI<RT^7W!A<F%M<ULG8WER861M:6XG
M72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULG8WER<&%S<R==+"!/4%](04Q&3U!%3BD["@H@
M("`@("`@("`@("!I9B`H(21T:&ES+3Y?:6UA<%-T<F5A;2D@>PH@("`@("`@
M("`@("`@("`@2&]R9&4Z.F9A=&%L*'-P<FEN=&8H7R@B0V%N)W0@8V]N;F5C
M="!T;R!)34%0('-E<G9E<CH@)7,B*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&EM87!?;&%S=%]E<G)O<B@I*2P@7U]&24Q%7U\L
M(%]?3$E.15]?*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M
M/E]C;VYN96-T960@/2!T<G5E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$:7-C;VYN96-T(&9R;VT@
M=&AE($E-05`@<V5R=F5R+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C
M97-S+"!F86QS92!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M9&ES8V]N;F5C="@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?8V]N;F5C
M=&5D*2!["B`@("`@("`@("`@($!I;6%P7V-L;W-E*"1T:&ES+3Y?:6UA<%-T
M<F5A;2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*
M"B`@("`O*BH*("`@("`J($-R96%T97,@82!M86EL8F]X97,@<W5P<&QI960@
M:6X@8V]N9FEG=7)A=&EO;@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97).86UE("`@1F]R
M('=H;VT@=&AE(&9O;&1E<B!W:6QL(&)E(&-R96%T960*("`@("`J($!P87)A
M;2!S=')I;F<@)&9O;&1E<DYA;64@3F%M92!O9B!F;VQD97(@=&\@8W)E871E
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C<F5A=&53=6)&;VQD97(H)'5S97).
M86UE+"`D9F]L9&5R3F%M92D*("`@('L*("`@("`@("`@0&EM87!?8W)E871E
M;6%I;&)O>"@D=&AI<RT^7VEM87!3=')E86TL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!I;6%P7W5T9C=?96YC;V1E*"1T:&ES+3Y?<&%R86US6R=I
M;6%P7V1S;B==("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U<V5R
M)R`N("1T:&ES+3Y?<&%R86US6R=S97!A<F%T;W(G72`N("1U<V5R3F%M92`N
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG<V5P87)A=&]R)UT@+B`D9F]L9&5R3F%M92DI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@3&ES="!A;&P@=7-E<G,@:6X@=&AE('-Y<W1E;2X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@87)R87D@;V8@=7-E
M<DED<RP@;W(@9F%L<V4@;VX@9F%I;'5R92]U;G-U<'!O<G1E9"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@;&ES=%5S97)S*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]B86-K96YD+3YL:7-T57-E<G,H*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%5P9&%T92!A('-E="!O9B!A=71H96YT:6-A=&EO;B!C<F5D
M96YT:6%L<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1O;&1)1"`@
M("`@("!4:&4@;VQD('5S97))9"X*("`@("`J($!P87)A;2!S=')I;F<@)&YE
M=TE$("`@("`@(%1H92!N97<@=7-E<DED+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1C<F5D96YT:6%L<R`@5&AE(&YE=R!C<F5D96YT:6%L<PH@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('5P9&%T955S97(H)&]L9$E$+"`D;F5W240L("1C<F5D96YT:6%L<RD*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/E]B86-K96YD+3YU<&1A=&55<V5R
M*"1O;&1)1"P@)&YE=TE$+"`D8W)E9&5N=&EA;',I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N('1H92!54DD@;V8@=&AE(&QO9VEN('-C<F5E;B!F
M;W(@=&AI<R!A=71H96YT:6-A=&EO;B!M971H;V0N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M87!P("!4:&4@87!P;&EC871I;VX@=&\@=7-E+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D=7)L("!4:&4@55),('1O(')E9&ER96-T('1O(&%F=&5R(&QO9VEN
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;&]G:6X@<V-R
M965N(%5222X*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$QO9VEN4V-R965N
M*"1A<'`@/2`G:&]R9&4G+"`D=7)L(#T@)R<I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?8F%C:V5N9"T^7V=E=$QO9VEN4V-R965N*"1A<'`L("1U
M<FPI.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS(&EF(&$@=7-E<DED
M(&5X:7-T<R!I;B!T:&4@<VES=&5M+@H@("`@("H*("`@("`J($!R971U<FX@
M8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE('5S97))9"!A;')E861Y(&5X
M:7-T<RX*("`@("`J+PH@("`@9G5N8W1I;VX@97AI<W1S*"1U<V5R260I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8F%C:V5N9"T^97AI<W1S*"1U
M<V5R260I.PH@("`@?0H*("`@("\J*@H@("`@("H@075T;VUA=&EC(&%U=&AE
M;G1I8V%T:6]N.B!&:6YD(&]U="!I9B!T:&4@8VQI96YT(&UA=&-H97,@86X@
M86QL;W=E9"!)4`H@("`@("H@8FQO8VLN"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@8VQI96YT(&ES(&%L;&]W
M960N"B`@("`@*B\*("`@(&9U;F-T:6]N('1R86YS<&%R96YT*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]B86-K96YD+3YT<F%N<W!A<F5N="@I
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92]!=71H+U-I9VYU<"YP:'``````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`R,C0P,"`Q,#4Q-30S,S<S-R`P,C(R,C<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"G)E<75I
M<F5?;VYC92`G2&]R9&4O1&%T851R964N<&AP)SL*<F5Q=6ER95]O;F-E("=(
M;W)D92]&;W)M+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O1F]R;2]296YD
M97)E<BYP:'`G.PH*+RHJ"B`J($%U=&A?4VEG;G5P.CH@5&AI<R!C;&%S<R!P
M<F]V:61E<R!A;B!I;G1E<F9A8V4@=&\@<VEG;B!U<"!O<B!H879E"B`J(&YE
M=R!U<V5R<R!S:6=N('1H96US96QV97,@=7`@:6YT;R!T:&4@:&]R9&4@:6YS
M=&%L;&%T:6]N+"!D97!E;F1I;F<*("H@;VX@:&]W('1H92!A9&UI;B!H87,@
M8V]N9FEG=7)E9"!(;W)D92X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO075T
M:"]!=71H+U-I9VYU<"YP:'`L=B`Q+C,X+C(N,3$@,C`P-B\P."\Q-"`P,CHT
M.#HT."!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UA
M<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@
M*B!`875T:&]R("!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*B!`
M<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?075T:`H@*B\*
M8VQA<W,@075T:%]3:6=N=7`@>PH*("`@("\J*@H@("`@("H@4&]I;G1E<B!T
M;R!A($1A=&%4<F5E(&EN<W1A;F-E('1O(&UA;F%G92]S=&]R92!S:6=N=7!S
M"B`@("`@*@H@("`@("H@0'9A<B!$871A5')E90H@("`@("HO"B`@("!V87(@
M)%]D871A=')E93L*"B`@("!F=6YC=&EO;B!!=71H7U-I9VYU<"@I"B`@("![
M"B`@("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("!I9B`H96UP='DH)&-O
M;F9;)V1A=&%T<F5E)UU;)V1R:79E<B==*2D@>PH@("`@("`@("`@("!(;W)D
M93HZ9F%T86PH7R@B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C
M:V5N9"!T;R!U<V4@4VEG;G5P<RXB*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M("`@("`@("!]"B`@("`@("`@)&1R:79E<B`]("1C;VYF6R=D871A=')E92==
M6R=D<FEV97(G73L*("`@("`@("`D=&AI<RT^7V1A=&%T<F5E(#T@)D1A=&%4
M<F5E.CIS:6YG;&5T;VXH)&1R:79E<BP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87E?;65R9V4H2&]R9&4Z
M.F=E=$1R:79E<D-O;F9I9R@G9&%T871R964G+"`D9')I=F5R*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@87)R87DH)V=R;W5P)R`]/B`G:&]R9&4N<VEG;G5P)RDI*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(')E
M9F5R96YC92!T;R!A(&-O;F-R971E($%U=&A?4VEG;G5P"B`@("`@*B!I;G-T
M86YC92X@270@=VEL;"!O;FQY(&-R96%T92!A(&YE=R!I;G-T86YC92!I9B!N
M;R!!=71H7U-I9VYU<`H@("`@("H@:6YS=&%N8V4@8W5R<F5N=&QY(&5X:7-T
M<RX*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@
M87,Z("1V87(@/2`F075T:%]3:6=N=7`Z.G-I;F=L971O;B@I"B`@("`@*@H@
M("`@("H@0')E='5R;B!!=71H7U-I9VYU<"`@5&AE(&-O;F-R971E($%U=&A?
M4VEG;G5P(')E9F5R96YC92P@;W(@9F%L<V4@;VX@97)R;W(N"B`@("`@*B\*
M("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH*0H@("`@>PH@("`@("`@('-T871I
M8R`D<VEG;G5P.PH*("`@("`@("!I9B`H(6ES<V5T*"1S:6=N=7`I*2!["B`@
M("`@("`@("`@("1S:6=N=7`@/2!N97<@075T:%]3:6=N=7`H*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D<VEG;G5P.PH@("`@?0H*("`@("\J*@H@
M("`@("H@061D<R!A(&YE=R!U<V5R('1O('1H92!S>7-T96T@86YD(&AA;F1L
M97,@86YY(&5X=')A(&9I96QD<R!T:&%T(&UA>2!H879E"B`@("`@*B!B965N
M(&-O;7!I;&5D+"!R96QY:6YG(&]N('1H92!H;V]K<RYP:'`@9FEL92X*("`@
M("`J"B`@("`@*B!`<&%R86US(&UI>&5D("1I;F9O("!2969E<F5N8V4@=&\@
M87)R87D@;V8@<&%R86UE=&5R97,@=&\@8F4@<&%S<V5D"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("!T;R!H;V]K"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@4$5!4E]%<G)O<B!I9B!A;GD@97)R;W)S+"!O=&AE<G=I<V4@
M=')U92X*("`@("`J+PH@("`@9G5N8W1I;VX@861D4VEG;G5P*"8D:6YF;RD*
M("`@('L*("`@("`@("!G;&]B86P@)&%U=&@L("1C;VYF.PH*("`@("`@("`O
M+R!097)F;W)M(&%N>2!P<F5P<F]C97-S:6YG(&EF(')E<75E<W1E9"X*("`@
M("`@("!I9B`H)&-O;F9;)W-I9VYU<"==6R=P<F5P<F]C97-S)UTI('L*("`@
M("`@("`@("`@)&EN9F\@/2!(;W)D93HZ8V%L;$AO;VLH)U]H;W)D95]H;V]K
M7W-I9VYU<%]P<F5P<F]C97-S)RP@87)R87DH)&EN9F\I*3L*("`@("`@("`@
M("`@:68@*&ES7V$H)&EN9F\L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D:6YF;SL*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@+R\@071T96UP="!T;R!A9&0@=&AE('5S97(@=&\@=&AE('-Y
M<W1E;2X*("`@("`@("`D<W5C8V5S<R`]("1A=71H+3YA9&15<V5R*"1I;F9O
M6R=U<V5R7VYA;64G72P@87)R87DH)W!A<W-W;W)D)R`]/B`D:6YF;ULG<&%S
M<W=O<F0G72DI.PH@("`@("`@(&EF("AI<U]A*"1S=6-C97-S+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<W5C8V5S<SL*("`@("`@
M("!]"@H@("`@("`@("\O($%T=&5M<'0@=&\@861D+W5P9&%T92!A;GD@97AT
M<F$@9&%T82!H86YD960@:6XN"B`@("`@("`@:68@*"%E;7!T>2@D:6YF;ULG
M97AT<F$G72DI('L*("`@("`@("`@("`@)&%D9&5D(#T@9F%L<V4["B`@("`@
M("`@("`@("1A9&1E9"`]($AO<F1E.CIC86QL2&]O:R@G7VAO<F1E7VAO;VM?
M<VEG;G5P7V%D9&5X=')A)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*"1I;F9O6R=U<V5R7VYA;64G72P@)&EN9F];)V5X
M=')A)UTI*3L*("`@("`@("`@("`@:68@*"$D861D960@?'P@:7-?82@D861D
M960L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@($AO<F1E.CIL
M;V=-97-S86=E*"1A9&1E9"P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/
M1U]%34521RD["B`@("`@("`@("`@("`@("!(;W)D93HZ9F%T86PH7R@B56YA
M8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN
M9R!U<"XB*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!1=65U97,@=&AE('5S97(G<R!S=6)M:71T960@<F5G:7-T<F%T
M:6]N(&EN9F\@9F]R(&QA=&5R(&%D;6EN(&%P<')O=F%L+@H@("`@("H*("`@
M("`J($!P87)A;7,@;6EX960@)&EN9F\@(%)E9F5R96YC92!T;R!A<G)A>2!O
M9B!P87)A;65T97)E<R!T;R!B92!P87-S960*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@('1O(&AO;VL*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!014%27T5R<F]R(&EF(&%N>2!E<G)O<G,L(&]T:&5R=VES92!T<G5E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B`F<75E=653:6=N=7`H)B1I;F9O*0H@("`@
M>PH@("`@("`@(&=L;V)A;"`D875T:"PD8V]N9CL*"B`@("`@("`@+R\@4&5R
M9F]R;2!A;GD@<')E<')O8V5S<VEN9R!I9B!R97%U97-T960N"B`@("`@("`@
M:68@*"1C;VYF6R=S:6=N=7`G75LG<')E<')O8V5S<R==*2!["B`@("`@("`@
M("`@("1I;F9O(#T@2&]R9&4Z.F-A;&Q(;V]K*"=?:&]R9&5?:&]O:U]S:6=N
M=7!?<')E<')O8V5S<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"1I;F9O*2D["B`@("`@("`@("`@(&EF("AI<U]A*"1I
M;F9O+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)&EN9F\["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O($-H
M96-K('1O('-E92!I9B!T:&4@=7-E<FYA;64@86QR96%D>2!E>&ES=',N"B`@
M("`@("`@:68@*"1A=71H+3YE>&ES=',H)&EN9F];)W5S97)?;F%M92==*2!\
M?`H@("`@("`@("`@("`D=&AI<RT^7V1A=&%T<F5E+3YE>&ES=',H)&EN9F];
M)W5S97)?;F%M92==*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BAS<')I;G1F*%\H(E5S97)N86UE(%PB)7-<(B!A;')E861Y(&5X
M:7-T<RXB*2P@)&EN9F];)W5S97)?;F%M92==*2D["B`@("`@("`@?0H*("`@
M("`@("`O+R!)9B!I="=S(&$@=6YI<75E('5S97)N86UE+"!G;R!A:&5A9"!A
M;F0@<75E=64@=&AE(')E<75E<W0N"B`@("`@("`@)'-I9VYU<"`]("1T:&ES
M+3YN97=3:6=N=7`H)&EN9F];)W5S97)?;F%M92==*3L*("`@("`@("!I9B`H
M(65M<'1Y*"1I;F9O6R=E>'1R82==*2D@>PH@("`@("`@("`@("`D<VEG;G5P
M+3YD871A(#T@87)R87E?;65R9V4H)&EN9F];)V5X=')A)UTL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<&%S<W=O
M<F0G(#T^("1I;F9O6R=P87-S=V]R9"==+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1A=&5296-E:79E9"<@/3X@
M=&EM92@I*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'-I9VYU
M<"T^9&%T82`](&%R<F%Y*"=P87-S=V]R9"<@/3X@)&EN9F];)W!A<W-W;W)D
M)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&%T95)E
M8V5I=F5D)R`]/B!T:6UE*"DI.PH@("`@("`@('T*"B`@("`@("`@:68@*"1C
M;VYF6R=S:6=N=7`G75LG<75E=64G72D@>PH@("`@("`@("`@("`D<F5S=6QT
M(#T@2&]R9&4Z.F-A;&Q(;V]K*"=?:&]R9&5?:&]O:U]S:6=N=7!?<75E=65D
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@D:6YF;ULG=7-E<E]N86UE)UTL("1I;F9O*2D["B`@("`@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)'1H:7,M/E]D871A=')E92T^861D*"1S:6=N=7`I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T(&$@=7-E<B=S('%U975E9"!S
M:6=N=7`@:6YF;W)M871I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=7-E<FYA;64@(%1H92!U<V5R;F%M92!T;R!R971R:65V92!T:&4@<75E
M=65D(&EN9F\@9F]R+@H@("`@("H*("`@("`J($!R971U<FX@1&%T851R965/
M8FIE8W1?4VEG;G5P("!4:&4@1&%T851R965/8FIE8W0@9F]R('1H92!R97%U
M97-T960*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S
M:6=N=7`N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%%U975E9%-I9VYU<"@D
M=7-E<FYA;64I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&%T871R
M964M/F=E=$]B:F5C="@D=7-E<FYA;64L("=$871A5')E94]B:F5C=%]3:6=N
M=7`G*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@<75E=65D(&EN
M9F]R;6%T:6]N(&9O<B!A;&P@<&5N9&EN9R!S:6=N=7!S+@H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y(&]F($1A=&%4<F5E3V)J96-T
M7U-I9VYU<"!O8FIE8W1S+"!O;F4@9F]R"B`@("`@*B`@("`@("`@("`@("`@
M("!E86-H('-I9VYU<"!I;B!T:&4@<75E=64N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=%%U975E9%-I9VYU<',H*0H@("`@>PH@("`@("`@("1S:6=N=7!S
M(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V1A=&%T<F5E
M+3YG970H1$%40512145?1D]234%47T9,050L($1!5$%44D5%7U)/3U0L('1R
M=64I(&%S("1U<V5R;F%M92D@>PH@("`@("`@("`@("!I9B`H)'5S97)N86UE
M("$]($1!5$%44D5%7U)/3U0I('L*("`@("`@("`@("`@("`@("1S:6=N=7!S
M6UT@/2`D=&AI<RT^7V1A=&%T<F5E+3YG971/8FIE8W0H)'5S97)N86UE*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@)'-I9VYU
M<',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F4@82!Q=65U960@<VEG
M;G5P+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97)N86UE("!4
M:&4@=7-E<B!T;R!R96UO=F4@9G)O;2!T:&4@<VEG;G5P('%U975E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!R96UO=F51=65U9613:6=N=7`H)'5S97)N86UE
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9&%T871R964M/G)E;6]V92@D=7-E
M<FYA;64I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&$@;F5W('-I
M9VYU<"!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M
M92`@5&AE('-I9VYU<',G<R!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@
M1&%T851R965/8FIE8W1?4VEG;G5P("!!(&YE=R!S:6=N=7`@;V)J96-T+@H@
M("`@("HO"B`@("!F=6YC=&EO;B`F;F5W4VEG;G5P*"1N86UE*0H@("`@>PH@
M("`@("`@(&EF("AE;7!T>2@D;F%M92DI('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H)U-I9VYU<"!N86UE<R!M=7-T(&)E(&YO;BUE
M;7!T>2<I.PH@("`@("`@('T*("`@("`@("`D<VEG;G5P(#T@)FYE=R!$871A
M5')E94]B:F5C=%]3:6=N=7`H)&YA;64I.PH@("`@("`@(')E='5R;B`D<VEG
M;G5P.PH@("`@?0H*?0H*+RHJ"B`J($5X=&5N<VEO;B!O9B!T:&4@1&%T851R
M965/8FIE8W0@8VQA<W,@9F]R('-T;W)I;F<@4VEG;G5P"B`J(&EN9F]R;6%T
M:6]N(&EN('1H92!$871A5')E92!D<FEV97(N($EF('EO=2!W86YT('1O('-T
M;W)E"B`J('-P96-I86QI>F5D(%-I9VYU<"!I;F9O<FUA=&EO;BP@>6]U('-H
M;W5L9"!E>'1E;F0@=&AI<R!C;&%S<PH@*B!I;G-T96%D(&]F(&5X=&5N9&EN
M9R!$871A5')E94]B:F5C="!D:7)E8W1L>2X*("H*("H@0&%U=&AO<B`@36%R
M:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H@0'-I;F-E("`@2&]R9&4@
M,RXP"B`J($!P86-K86=E($AO<F1E7T%U=&@*("HO"F-L87-S($1A=&%4<F5E
M3V)J96-T7U-I9VYU<"!E>'1E;F1S($1A=&%4<F5E3V)J96-T('L*"B`@("`O
M*BH*("`@("`J(%=E('=A;G0@=&\@<V5E('%U975E9"!S:6=N=7!S(&EN(&1E
M<V-E;F1I;F<@;W)D97(@;V8@<F5C96EP="X*("`@("`J($EN<V5R="!N97<@
M<VEG;G5P<R!A="!P;W-I=&EO;B`P(&%N9"!P=7-H('1H92!R97-T(&1O=VXN
M"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D
M;W)D97(@/2`P.PH*("`@("\J*@H@("`@("H@5&AE($1A=&%4<F5E3V)J96-T
M7U-I9VYU<"!C;VYS=')U8W1O<BX@2G5S="!M86ME<R!S=7)E('1O(&-A;&P*
M("`@("`J('1H92!P87)E;G0@8V]N<W1R=6-T;W(@<V\@=&AA="!T:&4@<VEG
M;G5P)W,@:7,@:7,@<V5T"B`@("`@*B!P<F]P97)L>2X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE(&ED(&]F('1H92!S:6=N=7`N"B`@
M("`@*B\*("`@(&9U;F-T:6]N($1A=&%4<F5E3V)J96-T7U-I9VYU<"@D:60I
M"B`@("!["B`@("`@("`@<&%R96YT.CI$871A5')E94]B:F5C="@D:60I.PH@
M("`@("`@(&EF("AI<U]N=6QL*"1T:&ES+3YD871A*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^9&%T82`](&%R<F%Y*"D["B`@("`@("`@?0H@("`@?0H*?0H*
M+RHJ"B`J($AO<F1E(%-I9VYU<"!&;W)M+"!E>'1E;F1I;F<@;V8@2&]R9&5?
M1F]R;3HZ"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36%R:V\@1&IU:VEC
M(#QM87)K;T!O8FQO+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN("!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]G<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@
M36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H@0'-I;F-E("`@2&]R
M9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T%U=&@*("HO"F-L87-S($AO<F1E
M4VEG;G5P1F]R;2!E>'1E;F1S($AO<F1E7T9O<FT@>PH*("`@('9A<B`D7W5S
M949O<FU4;VME;B`]('1R=64["@H@("`@9G5N8W1I;VX@2&]R9&53:6=N=7!&
M;W)M*"8D=F%R<RD*("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*
M("`@("`@("!P87)E;G0Z.DAO<F1E7T9O<FTH)'9A<G,L('-P<FEN=&8H7R@B
M)7,@4VEG;B!5<"(I+"`D<F5G:7-T<GDM/F=E="@G;F%M92<I*2D["@H@("`@
M("`@("1T:&ES+3YS971"=71T;VYS*%\H(E-I9VX@=7`B*2P@=')U92D["@H@
M("`@("`@("1T:&ES+3YA9&1(:61D96XH)R<L("=U<FPG+"`G=&5X="<L(&9A
M;'-E*3L*("`@("`@("`D=&AI<RT^861D5F%R:6%B;&4H7R@B0VAO;W-E(&$@
M=7-E<FYA;64B*2P@)W5S97)?;F%M92<L("=T97AT)RP@=')U92D["B`@("`@
M("`@)'1H:7,M/F%D9%9A<FEA8FQE*%\H(D-H;V]S92!A('!A<W-W;W)D(BDL
M("=P87-S=V]R9"<L("=P87-S=V]R9&-O;F9I<FTG+"!T<G5E+"!F86QS92P@
M7R@B='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(I*3L*"B`@
M("`@("`@+RH@57-E(&AO;VMS(&=E="!A;GD@97AT<F$@9FEE;&1S(')E<75I
M<F5D(&EN('-I9VYI;F<@=7`N("HO"B`@("`@("`@)&5X=')A(#T@2&]R9&4Z
M.F-A;&Q(;V]K*"=?:&]R9&5?:&]O:U]S:6=N=7!?9V5T97AT<F$G*3L*("`@
M("`@("!I9B`H(6ES7V$H)&5X=')A+"`G4$5!4E]%<G)O<B<I("8F("%E;7!T
M>2@D97AT<F$I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1E>'1R82!A<R`D
M9FEE;&1?;F%M92`]/B`D9FEE;&0I('L*("`@("`@("`@("`@("`@("1R96%D
M;VYL>2`](&ES<V5T*"1F:65L9%LG<F5A9&]N;'DG72D@/R`D9FEE;&1;)W)E
M861O;FQY)UT@.B!N=6QL.PH@("`@("`@("`@("`@("`@)&1E<V,@/2!I<W-E
M="@D9FEE;&1;)V1E<V,G72D@/R`D9FEE;&1;)V1E<V,G72`Z(&YU;&P["B`@
M("`@("`@("`@("`@("`D<F5Q=6ER960@/2!I<W-E="@D9FEE;&1;)W)E<75I
M<F5D)UTI(#\@)&9I96QD6R=R97%U:7)E9"==(#H@9F%L<V4["B`@("`@("`@
M("`@("`@("`D9FEE;&1?<&%R86US(#T@:7-S970H)&9I96QD6R=P87)A;7,G
M72D@/R`D9FEE;&1;)W!A<F%M<R==(#H@87)R87DH*3L*"B`@("`@("`@("`@
M("`@("`D=&AI<RT^861D5F%R:6%B;&4H)&9I96QD6R=L86)E;"==+"`G97AT
M<F%;)R`N("1F:65L9%]N86UE("X@)UTG+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1F:65L9%LG='EP92==+"`D<F5Q=6ER960L("1R
M96%D;VYL>2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M9&5S8RP@)&9I96QD7W!A<F%M<RD["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O075T:"]I<&UA<"YP:'``
M````````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(T-30@,3`U
M,34T,S,W,S<@,#(R,#<W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)
M3$5?7RD@+B`G+VEP8F%S:6,N<&AP)SL*"B\J*@H@*B!4:&4@075T:%]I<&UA
M<"!C;&%S<R!P<F]V:61E<R!A8V-E<W,@8V]N=')O;"!B87-E9"!O;B!#2412
M(&UA<VMS+@H@*@H@*B!087)A;65T97)S.@H@*B`@($Y/3D4*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO075T:"]!=71H+VEP;6%P+G!H<"QV(#$N,30N,3`N
M-B`R,#`V+S`Q+S`Q(#(Q.C(X.C`W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`
M<&%C:V%G92!(;W)D95]!=71H"B`J+PIC;&%S<R!!=71H7VEP;6%P(&5X=&5N
M9',@075T:%]I<&)A<VEC('L*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&]F
M(&-A<&%B:6QI=&EE<RP@<V\@=&AA="!T:&4@9')I=F5R(&-A;B!R97!O<G0@
M=VAI8V@*("`@("`J(&]P97)A=&EO;G,@:70@<W5P<&]R=',@86YD('=H:6-H
M(&ET(&1O97-N)W0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)&-A<&%B:6QI=&EE<R`](&%R<F%Y*"=A9&0G("`@("`@("`@
M("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5P
M9&%T92<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G<F5S971P87-S=V]R9"<@/3X@9F%L<V4L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=R96UO=F4G("`@("`@("`]/B!F86QS92P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VQI<W0G("`@("`@("`@
M(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=')A
M;G-P87)E;G0G("`@/3X@=')U92D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U
M8W1S(&$@;F5W($E0+6UA<'!I;F<@875T:&5N=&EC871I;VX@;V)J96-T+@H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N
M=&%I;FEN9R!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!!=71H
M7VEP;6%P*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?<V5T4&%R86US*"1P87)A;7,I.PH@("`@?0H*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92]!=71H+W-A<VPN<&AP````````````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P-C`Q,2`Q,#4Q-30S,S<T,"`P,C$W,38`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J(%1H92!!=71H7W-A<VPZ.B!C;&%S<R!P<F]V:61E<R!A(%-!4TPM8F%S
M960@:6UP;&5M96YT871I;VX@;V8@=&AE($AO<F1E"B`J(&%U=&AE;G1I8V%T
M:6]N('-Y<W1E;2X*("H*("H@4T%33"!I<R!T:&4@4VEM<&QE($%U=&AE;G1I
M8V%T:6]N(&%N9"!396-U<FET>2!,87EE<B`H87,@9&5F:6YE9"!B>2!21D,*
M("H@,C(R,BDN($ET('!R;W9I9&5S(&$@<WES=&5M(&9O<B!A9&1I;F<@<&QU
M9V%B;&4@875T:&5N=&EC871I;F<@<W5P<&]R="!T;PH@*B!C;VYN96-T:6]N
M+6)A<V5D('!R;W1O8V]L<RX*("H*("H@5&AI<R!D<FEV97(@<F5L:65S(&]N
M('1H92!014-,('-A<VP@<&%C:V%G93H*("H*("H@("`@("!H='1P.B\O<&5C
M;"YP:'`N;F5T+W!A8VMA9V4O<V%S;`H@*@H@*B!/<'1I;VYA;"!P87)A;65T
M97)S.CQP<F4^"B`J("`@)V%P<"<@("`@("!4:&4@;F%M92!O9B!T:&4@875T
M:&5N=&EC871I;F<@87!P;&EC871I;VXN"B`J("`@("`@("`@("`@("!$149!
M54Q4.B!H;W)D90H@*B`@("=S97)V:6-E)R`@5&AE(&YA;64@;V8@=&AE(%-!
M4TP@<V5R=FEC92!T;R!U<V4@=VAE;B!A=71H96YT:6-A=&EN9RX*("H@("`@
M("`@("`@("`@($1%1D%53%0Z('!H<#PO<')E/@H@*@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`L=B`Q+C0N,3`N.2`R,#`V
M+S`Q+S`Q(#(Q.C(X.C`W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P
M-"TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B!`875T:&]R("!*86X@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@
M*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?075T:`H@
M*B\*8VQA<W,@075T:%]S87-L(&5X=&5N9',@075T:"!["@H@("`@+RHJ"B`@
M("`@*B!!;B!A<G)A>2!O9B!C87!A8FEL:71I97,L('-O('1H870@=&AE(&1R
M:79E<B!C86X@<F5P;W)T('=H:6-H"B`@("`@*B!O<&5R871I;VYS(&ET('-U
M<'!O<G1S(&%N9"!W:&EC:"!I="!D;V5S;B=T+@H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1C87!A8FEL:71I97,@/2!A<G)A
M>2@G861D)R`@("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=U<&1A=&4G("`@("`@("`]/B!F86QS92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W)E<V5T<&%S<W=O<F0G(#T^(&9A
M;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5M;W9E)R`@
M("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=L:7-T)R`@("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W1R86YS<&%R96YT)R`@(#T^(&9A;'-E*3L*"B`@("`O
M*BH*("`@("`J($-O;G-T<G5C=',@82!N97<@4T%33"!A=71H96YT:6-A=&EO
M;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@
M($$@:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@075T:%]S87-L*"1P87)A;7,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL*"B`@
M("`@("`@:68@*"%E>'1E;G-I;VY?;&]A9&5D*"=S87-L)RDI('L*("`@("`@
M("`@("`@9&PH)W-A<VPN<V\G*3L*("`@("`@("!]"@H@("`@("`@("1A<'`@
M/2`H(65M<'1Y*"1P87)A;7-;)V%P<"==*2D@/R`D<&%R86US6R=A<'`G72`Z
M("=H;W)D92<["B`@("`@("`@<V%S;%]S97)V97)?:6YI="@D87!P*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($9I;F0@;W5T(&EF(&$@<V5T(&]F(&QO9VEN
M(&-R961E;G1I86QS(&%R92!V86QI9"X*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@
M("`@("!4:&4@=7-E<DED('1O(&-H96-K+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1C<F5D96YT:6%L<R`@06X@87)R87D@;V8@;&]G:6X@8W)E9&5N=&EA;',N
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO
M="!T:&4@8W)E9&5N=&EA;',@87)E('9A;&ED+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?875T:&5N=&EC871E*"1U<V5R260L("1C<F5D96YT:6%L<RD*("`@
M('L*("`@("`@("!I9B`H96UP='DH)&-R961E;G1I86QS6R=P87-S=V]R9"==
M*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH7R@B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(I+"!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E>'1E;G-I
M;VY?;&]A9&5D*"=S87-L)RDI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L
M*%\H(E-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB*2P@
M7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("1S97)V
M:6-E(#T@*"%E;7!T>2@D<&%R86US6R=S97)V:6-E)UTI*2`_("1P87)A;7-;
M)W-E<G9I8V4G72`Z("=P:'`G.PH@("`@("`@("1C;VYN(#T@<V%S;%]S97)V
M97)?;F5W*"1S97)V:6-E*3L*("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1C
M;VYN*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH7R@B1F%I;&5D('1O
M(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+B(I+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%S87-L7V-H96-K<&%S
M<R@D8V]N;BP@)'5S97))9"P@)&-R961E;G1I86QS6R=P87-S=V]R9"==*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/
M3E]-15-304=%+"!S87-L7V5R<F1E=&%I;"@D8V]N;BDI.PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U
M93L*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O075T:"]C;VUP;W-I=&4N<&AP````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,C$U-#,@,3`U,34T,S,W-#`@,#(R-S8U`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B!4:&4@075T:%]C;VUP;W-I=&4@8VQA<W,@<')O=FED97,@82!W<F%P
M<&5R(&%R;W5N9`H@*B!A<'!L:6-A=&EO;BUP<F]V:61E9"!(;W)D92!A=71H
M96YT:6-A=&EO;B!W:&EC:"!F:71S(&EN<VED92!T:&4*("H@2&]R9&4@075T
M:#HZ($%022X*("H*("H@4F5Q=6ER960@<&%R86UE=&5R<SH\<')E/@H@*B`@
M($YO;F4N/"]P<F4^"B`J"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T%U=&@O
M075T:"]C;VUP;W-I=&4N<&AP+'8@,2XR-BXQ,"XQ,"`R,#`V+S`X+S$T(#`R
M.C0X.C0X(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E
M+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E
M7T%U=&@*("HO"F-L87-S($%U=&A?8V]M<&]S:71E(&5X=&5N9',@075T:"![
M"@H@("`@+RHJ"B`@("`@*B!(87-H(&-O;G1A:6YI;F<@86YY(&EN<W1A;G1I
M871E9"!D<FEV97)S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1?9')I=F5R<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@
M*B!#;VYS=')U8W1S(&$@;F5W($-O;7!O<VET92!A=71H96YT:6-A=&EO;B!O
M8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@
M:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@075T:%]C;VUP;W-I=&4H)'!A<F%M<R`](&%R<F%Y
M*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]S971087)A;7,H)'!A<F%M<RD[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@8V]N;F5C=&EO;B!P87)A;65T
M97)S+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!C
M;VYN96-T:6]N('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S
M971087)A;7,H)'!A<F%M<RD*("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y
M*"1P87)A;7,I*2!["B`@("`@("`@("`@($AO<F1E.CIF871A;"@G3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($-O;7!O<VET
M92!A=71H96YT:6-A=&EO;BXG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@
M("`@('T*"B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!N86UE9"!P87)A;65T97(@
M9F]R('1H92!C=7)R96YT(&%U=&@@9')I=F5R+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'!A<F%M("!4:&4@<&%R86UE=&5R('1O(&9E=&-H+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<&%R86UE=&5R)W,@
M=F%L=64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A<F%M*"1P87)A;2D*
M("`@('L*("`@("`@("!I9B`H*"1L;V=I;E]D<FEV97(@/2!!=71H.CI?9V5T
M1')I=F5R0GE087)A;2@G;&]G:6YS8W)E96Y?<W=I=&-H)RP@)'1H:7,M/E]P
M87)A;7,I*2`F)@H@("`@("`@("`@("`D=&AI<RT^7VQO861$<FEV97(H)&QO
M9VEN7V1R:79E<BDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9')I
M=F5R<ULD;&]G:6Y?9')I=F5R72T^9V5T4&%R86TH)'!A<F%M*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1FEN9"!O=70@:68@82!S970@;V8@;&]G:6X@8W)E9&5N=&EA;',@87)E
M('9A;&ED+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@("`@(%1H92!U<V5R260@
M=&\@8VAE8VLN"B`@("`@*B!`<&%R86T@87)R87D@)&-R961E;G1I86QS("!4
M:&4@8W)E9&5N=&EA;',@=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@
M8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&-R961E;G1I86QS(&%R92!V
M86QI9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V%U=&AE;G1I8V%T92@D=7-E
M<DED+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@:68@*"@D875T:%]D
M<FEV97(@/2!!=71H.CI?9V5T1')I=F5R0GE087)A;2@G;&]G:6YS8W)E96Y?
M<W=I=&-H)RP@)'1H:7,M/E]P87)A;7,I*2`F)@H@("`@("`@("`@("`D=&AI
M<RT^7VQO861$<FEV97(H)&%U=&A?9')I=F5R*2D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]D<FEV97)S6R1A=71H7V1R:79E<ETM/F%U=&AE;G1I
M8V%T92@D=7-E<DED+"`D8W)E9&5N=&EA;',I.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"@D875T:%]D<FEV97(@/2!!=71H.CI?9V5T1')I=F5R0GE087)A
M;2@G=7-E<FYA;65?<W=I=&-H)RP@)'1H:7,M/E]P87)A;7,L(&%R<F%Y*"1U
M<V5R260I*2D@)B8*("`@("`@("`@("`@)'1H:7,M/E]L;V%D1')I=F5R*"1A
M=71H7V1R:79E<BDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9')I
M=F5R<ULD875T:%]D<FEV97)=+3YH87-#87!A8FEL:71Y*"=T<F%N<W!A<F5N
M="<I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H
M05542%]214%33TY?1D%)3$5$*3L*("`@("`@("!R971U<FX@9F%L<V4["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!1=65R>2!T:&4@8W5R<F5N="!!=71H(&]B
M:F5C="!T;R!F:6YD(&]U="!I9B!I="!S=7!P;W)T<R!T:&4@9VEV96X*("`@
M("`J(&-A<&%B:6QI='DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M8V%P86)I;&ET>2`@5&AE(&-A<&%B:6QI='D@=&\@=&5S="!F;W(N"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@
M8V%P86)I;&ET>2!I<R!S=7!P;W)T960N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&AA<T-A<&%B:6QI='DH)&-A<&%B:6QI='DI"B`@("!["B`@("`@("`@<W=I
M=&-H("@D8V%P86)I;&ET>2D@>PH@("`@("`@(&-A<V4@)V%D9"<Z"B`@("`@
M("`@8V%S92`G=7!D871E)SH*("`@("`@("!C87-E("=R96UO=F4G.@H@("`@
M("`@(&-A<V4@)VQI<W0G.@H@("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES
M+3Y?<&%R86US6R=A9&UI;E]D<FEV97(G72D@)B8*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?;&]A9$1R:79E<B@D=&AI<RT^7W!A<F%M<ULG861M:6Y?9')I
M=F5R)UTI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]D<FEV
M97)S6R1T:&ES+3Y?<&%R86US6R=A9&UI;E]D<FEV97(G75TM/FAA<T-A<&%B
M:6QI='DH)&-A<&%B:6QI='DI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=T<F%N<W!A<F5N="<Z"B`@
M("`@("`@("`@(&EF("@H)&QO9VEN7V1R:79E<B`]($%U=&@Z.E]G971$<FEV
M97)">5!A<F%M*"=L;V=I;G-C<F5E;E]S=VET8V@G+"`D=&AI<RT^7W!A<F%M
M<RDI("8F"B`@("`@("`@("`@("`@("`D=&AI<RT^7VQO861$<FEV97(H)&QO
M9VEN7V1R:79E<BDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7V1R:79E<G-;)&QO9VEN7V1R:79E<ETM/FAA<T-A<&%B:6QI='DH)W1R86YS
M<&%R96YT)RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($%U=&]M871I8R!A=71H96YT:6-A=&EO;CH@1FEN9"!O=70@
M:68@=&AE(&-L:65N="!M871C:&5S(&%N(&%L;&]W960@25`*("`@("`J(&)L
M;V-K+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O
M<B!N;W0@=&AE(&-L:65N="!I<R!A;&QO=V5D+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!T<F%N<W!A<F5N="@I"B`@("!["B`@("`@("`@:68@*"@D;&]G:6Y?
M9')I=F5R(#T@075T:#HZ7V=E=$1R:79E<D)Y4&%R86TH)VQO9VEN<V-R965N
M7W-W:71C:"<L("1T:&ES+3Y?<&%R86US*2D@)B8*("`@("`@("`@("`@)'1H
M:7,M/E]L;V%D1')I=F5R*"1L;V=I;E]D<FEV97(I*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7V1R:79E<G-;)&QO9VEN7V1R:79E<ETM/G1R86YS
M<&%R96YT*"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@9F%L<V4["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(%5222!O9B!T:&4@;&]G
M:6X@<V-R965N(&9O<B!T:&ES(&%U=&AE;G1I8V%T:6]N(&]B:F5C="X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1A<'`@(%1H92!A<'!L:6-A=&EO;B!T;R!U<V4N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1U<FP@(%1H92!54DP@=&\@<F5D:7)E8W0@=&\@
M869T97(@;&]G:6XN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!L;V=I;B!S8W)E96X@55))+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T
M3&]G:6Y38W)E96XH)&%P<"`]("=H;W)D92<L("1U<FP@/2`G)RD*("`@('L*
M("`@("`@("!I9B`H*"1L;V=I;E]D<FEV97(@/2!!=71H.CI?9V5T1')I=F5R
M0GE087)A;2@G;&]G:6YS8W)E96Y?<W=I=&-H)RP@)'1H:7,M/E]P87)A;7,I
M*2`F)@H@("`@("`@("`@("`D=&AI<RT^7VQO861$<FEV97(H)&QO9VEN7V1R
M:79E<BDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9')I=F5R<ULD
M;&]G:6Y?9')I=F5R72T^7V=E=$QO9VEN4V-R965N*"1A<'`L("1U<FPI.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!P87)E;G0Z.E]G
M971,;V=I;E-C<F5E;B@D87!P+"`D=7)L*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!!9&0@82!S970@;V8@875T:&5N=&EC871I;VX@8W)E
M9&5N=&EA;',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED
M("`@("`@(%1H92!U<V5R260@=&\@861D+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("`D8W)E9&5N=&EA;',@(%1H92!C<F5D96YT:6%L<R!T;R!U<V4N"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@("`@("`@5')U92!O;B!S=6-C97-S
M(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@861D57-E<B@D=7-E<DED+"`D8W)E9&5N=&EA;',I"B`@
M("!["B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG861M:6Y?
M9')I=F5R)UTI("8F"B`@("`@("`@("`@("1T:&ES+3Y?;&]A9$1R:79E<B@D
M=&AI<RT^7W!A<F%M<ULG861M:6Y?9')I=F5R)UTI*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7V1R:79E<G-;)'1H:7,M/E]P87)A;7-;)V%D;6EN
M7V1R:79E<B==72T^861D57-E<B@D=7-E<DED+"`D8W)E9&5N=&EA;',I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*"=5;G-U<'!O<G1E9"<I.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%5P9&%T92!A('-E="!O9B!A=71H96YT:6-A=&EO;B!C<F5D
M96YT:6%L<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1O;&1)1"`@
M("`@("!4:&4@;VQD('5S97))9"X*("`@("`J($!P87)A;2!S=')I;F<@)&YE
M=TE$("`@("`@(%1H92!N97<@=7-E<DED+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1C<F5D96YT:6%L<R`@5&AE(&YE=R!C<F5D96YT:6%L<PH@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('5P9&%T955S97(H)&]L9$E$+"`D;F5W240L("1C<F5D96YT:6%L<RD*("`@
M('L*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=A9&UI;E]D
M<FEV97(G72D@)B8*("`@("`@("`@("`@)'1H:7,M/E]L;V%D1')I=F5R*"1T
M:&ES+3Y?<&%R86US6R=A9&UI;E]D<FEV97(G72DI('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?9')I=F5R<ULD=&AI<RT^7W!A<F%M<ULG861M:6Y?
M9')I=F5R)UU=+3YU<&1A=&55<V5R*"1O;&1)1"P@)&YE=TE$+"`D8W)E9&5N
M=&EA;',I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"=5;G-U<'!O<G1E9"<I.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($1E;&5T92!A('-E="!O9B!A=71H96YT:6-A
M=&EO;B!C<F5D96YT:6%L<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1U<V5R260@(%1H92!U<V5R260@=&\@9&5L971E+@H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R
M;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E
M;6]V955S97(H)'5S97))9"D*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1T
M:&ES+3Y?<&%R86US6R=A9&UI;E]D<FEV97(G72D@)B8*("`@("`@("`@("`@
M)'1H:7,M/E]L;V%D1')I=F5R*"1T:&ES+3Y?<&%R86US6R=A9&UI;E]D<FEV
M97(G72DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9')I=F5R<ULD
M=&AI<RT^7W!A<F%M<ULG861M:6Y?9')I=F5R)UU=+3YR96UO=F55<V5R*"1U
M<V5R260I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"=5;G-U<'!O<G1E9"<I.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($QI<W0@86QL('5S97)S(&EN('1H92!S>7-T
M96TN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&%R<F%Y(&]F
M('5S97))9',L(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=%5S97)S*"D*("`@('L*("`@("`@
M("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=A9&UI;E]D<FEV97(G72D@
M)B8*("`@("`@("`@("`@)'1H:7,M/E]L;V%D1')I=F5R*"1T:&ES+3Y?<&%R
M86US6R=A9&UI;E]D<FEV97(G72DI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?9')I=F5R<ULD=&AI<RT^7W!A<F%M<ULG861M:6Y?9')I=F5R)UU=
M+3YL:7-T57-E<G,H*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G56YS=7!P;W)T960G*3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@:68@82!U<V5R260@
M97AI<W1S(&EN('1H92!S>7-T96TN"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D=7-E<DED("!5<V5R($E$('1O(&-H96-K"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@=7-E<DED(&%L
M<F5A9'D@97AI<W1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>&ES=',H)'5S
M97))9"D*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US
M6R=A9&UI;E]D<FEV97(G72D@)B8*("`@("`@("`@("`@)'1H:7,M/E]L;V%D
M1')I=F5R*"1T:&ES+3Y?<&%R86US6R=A9&UI;E]D<FEV97(G72DI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9')I=F5R<ULD=&AI<RT^7W!A<F%M
M<ULG861M:6Y?9')I=F5R)UU=+3YE>&ES=',H)'5S97))9"D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)U5N<W5P<&]R=&5D)RD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@3&]A9',@;VYE(&]F('1H92!D<FEV97)S(&EN(&]U<B!C;VYF:6=U<F%T
M:6]N(&%R<F%Y+"!I9B!I="!I<VXG="!A;')E861Y"B`@("`@*B!L;V%D960N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D9')I=F5R("!4:&4@;F%M92!O9B!T:&4@9')I=F5R
M('1O(&QO860N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N(%1R=64@
M:68@9')I=F5R('-U8V-E<W-F=6QL>2!I;FET:6%L:7IE<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@7VQO861$<FEV97(H)&1R:79E<BD*("`@('L*("`@("`@
M("!I9B`H96UP='DH)'1H:7,M/E]D<FEV97)S6R1D<FEV97)=*2D@>PH@("`@
M("`@("`@("`O+R!4:&ES(&ES(&$@8FET('-P96-I86QI>F5D(&9O<B!(;W)D
M93HZ9V5T1')I=F5R0V]N9FEG*"DL"B`@("`@("`@("`@("\O('-O(&QO8V%L
M:7IE(&ET(&AE<F4Z"B`@("`@("`@("`@(&=L;V)A;"`D8V]N9CL*("`@("`@
M("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG9')I=F5R<R==6R1D
M<FEV97)=6R=P87)A;7,G72DI('L*("`@("`@("`@("`@("`@("1P87)A;7,@
M/2`D=&AI<RT^7W!A<F%M<ULG9')I=F5R<R==6R1D<FEV97)=6R=P87)A;7,G
M73L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D8V]N9ELD=&AI<RT^7W!A
M<F%M<ULG9')I=F5R<R==6R1D<FEV97)=6R=D<FEV97(G75TI*2!["B`@("`@
M("`@("`@("`@("`@("`@)'!A<F%M<R`](&%R<F%Y7VUE<F=E*"1C;VYF6R1T
M:&ES+3Y?<&%R86US6R=D<FEV97)S)UU;)&1R:79E<EU;)V1R:79E<B==72P@
M)'!A<F%M<RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS
M96EF("@A96UP='DH)&-O;F9;)&1R:79E<ETI*2!["B`@("`@("`@("`@("`@
M("`D<&%R86US(#T@)&-O;F9;)&1R:79E<ET["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D<&%R86US(#T@;G5L;#L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@)'1H:7,M/E]D<FEV97)S6R1D<FEV97)=(#T@
M)D%U=&@Z.G-I;F=L971O;B@D=&AI<RT^7W!A<F%M<ULG9')I=F5R<R==6R1D
M<FEV97)=6R=D<FEV97(G72P@)'!A<F%M<RD["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@:7-S970H)'1H:7,M/E]D<FEV97)S6R1D<FEV97)=*3L*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B](;W)D92]!=71H+V%U=&\N<&AP````````````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-3,S-R`Q,#4Q-30S,S<T,"`P,C$W
M,S8`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J(%1H92!!=71H7V%U=&\@8VQA<W,@=')A;G-P87)E;G1L
M>2!L;V=S('5S97)S(&EN('1O($AO<F1E('5S:6YG($].10H@*B!U<V5R;F%M
M92P@96ET:&5R(&1E9FEN960@:6X@=&AE(&-O;F9I9R!O<B!D969A=6QT:6YG
M('1O"B`J("=H;W)D95]U<V5R)RX@5&AI<R!I<R!O;FQY(&9O<B!U<V4@:6X@
M=&5S=&EN9R!O<B!B96AI;F0@82!F:7)E=V%L;#L*("H@:70@<VAO=6QD($Y/
M5"!B92!U<V5D(&]N(&$@<'5B;&EC+"!P<F]D=6-T:6]N(&UA8VAI;F4N"B`J
M"B`J($]P=&EO;F%L('!A<F%M971E<G,Z/'!R93X*("H@("`G=7-E<FYA;64G
M("`@("!4:&4@=7-E<FYA;64@=&\@875T:&5N=&EC871E(&5V97)Y;VYE(&%S
M+@H@*B`@("`@("`@("`@("`@("`@($1%1D%53%0Z("=H;W)D95]U<V5R)PH@
M*B`@("=P87-S=V]R9"<@("`@(%1H92!P87-S=V]R9"!T;R!R96-O<F0@:6X@
M=&AE('5S97(G<R!C<F5D96YT:6%L<RX*("H@("`@("`@("`@("`@("`@("!$
M149!54Q4.B!N;VYE"B`J("`@)W)E<75E<W1U<V5R)R`@268@=')U92P@86QL
M;W<@=7-E<FYA;64@=&\@8F4@<&%S<V5D(&)Y($=%5"P@4$]35"!O<@H@*B`@
M("`@("`@("`@("`@("`@(&-O;VMI92X\+W!R93X*("H*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO075T:"]!=71H+V%U=&\N<&AP+'8@,2XQ,BXT+C@@,C`P
M-B\P,2\P,2`R,3HR.#HP-R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y
M.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU
M8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`R+C(*("H@0'!A8VMA
M9V4@2&]R9&5?075T:`H@*B\*8VQA<W,@075T:%]A=71O(&5X=&5N9',@075T
M:"!["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!C87!A8FEL:71I97,L
M('-O('1H870@=&AE(&1R:79E<B!C86X@<F5P;W)T('=H:6-H"B`@("`@*B!O
M<&5R871I;VYS(&ET('-U<'!O<G1S(&%N9"!W:&EC:"!I="!D;V5S;B=T+@H@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1C87!A
M8FEL:71I97,@/2!A<G)A>2@G861D)R`@("`@("`@("`@/3X@9F%L<V4L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U<&1A=&4G("`@("`@("`]
M/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E<V5T
M<&%S<W=O<F0G(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G<F5M;W9E)R`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=L:7-T)R`@("`@("`@("`]/B!F86QS92P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1R86YS<&%R96YT)R`@(#T^
M('1R=64I.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!!=71O
M;6%T:6,@875T:&5N=&EC871I;VX@;V)J96-T+@H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!P87)A;65T
M97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!!=71H7V%U=&\H)'!A<F%M<R`]
M(&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]S971087)A;7,H)'!A
M<F%M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@<&%R86UE=&5R<R!F
M;W(@=&AE($%U=&A?875T;R!O8FIE8W0N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@
M(%!A<F%M971E<G,N($YO;F4@8W5R<F5N=&QY(')E<75I<F5D.PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("=U<V5R;F%M92<L("=P87-S=V]R9"<L
M(&%N9"`G<F5Q=65S='5S97(G(&%R92!O<'1I;VYA;"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@7W-E=%!A<F%M<R@D<&%R86US*0H@("`@>PH@("`@("`@(&EF
M("@A:7-S970H)'!A<F%M<ULG=7-E<FYA;64G72DI('L*("`@("`@("`@("`@
M)'!A<F%M<ULG=7-E<FYA;64G72`]("=H;W)D95]U<V5R)SL*("`@("`@("!]
M"B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@?0H*("`@
M("\J*@H@("`@("H@075T;VUA=&EC(&%U=&AE;G1I8V%T:6]N.B!3970@=&AE
M('5S97(@86QL;W=E9"!)4"!B;&]C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@(%=H971H97(@;W(@;F]T('1H92!C;&EE;G0@:7,@86QL;W=E
M9"X*("`@("`J+PH@("`@9G5N8W1I;VX@=')A;G-P87)E;G0H*0H@("`@>PH@
M("`@("`@("1U<V5R;F%M92`]("@A96UP='DH)'1H:7,M/E]P87)A;7-;)W)E
M<75E<W1U<V5R)UTI("8F(&ES<V5T*"1?4D5154535%LG=7-E<FYA;64G72DI
M(#\*("`@("`@("`@("`@)%]215%515-46R=U<V5R;F%M92==(#H*("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)W5S97)N86UE)UT["B`@("`@("`@)'1H
M:7,M/G-E=$%U=&@H)'5S97)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*"=T<F%N<W!A<F5N="<@/3X@,2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G<&%S<W=O<F0G(#T^(&ES<V5T*"1T:&ES+3Y?<&%R86US
M6R=P87-S=V]R9"==*2`_("1T:&ES+3Y?<&%R86US6R=P87-S=V]R9"==(#H@
M;G5L;"DI.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+T%U=&@O:'1T<"YP:'``````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#$R,3`W(#$P-3$U-#,S-S0P(#`R,3<S-@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@5&AE
M($%U=&A?:'1T<"!C;&%S<R!T<F%N<W!A<F5N=&QY(&QO9W,@=7-E<G,@:6X@
M=&\@2&]R9&4@=7-I;F<*("H@86QR96%D>2!P<F5S96YT($A45%`@875T:&5N
M=&EC871I;VX@:&5A9&5R<RX*("H*("H@5&AE("=E;F-R>7!T:6]N)R!P87)A
M;65T97(@<W!E8VEF:65S('=H870@:VEN9"!O9B!P87-S=V]R9',@87)E(&EN
M"B`J('1H92`N:'1P87-S=V0@9FEL92X@5&AE('-U<'!O<G1E9"!O<'1I;VYS
M(&%R92`G8W)Y<'0M9&5S)R`H<W1A;F1A<F0*("H@8W)Y<'1E9"!H='!A<W-W
M9"!E;G1R:65S*2!A;F0@)V%P<FUD-2<N(%1H:7,@:6YF;W)M871I;VX@:7,@
M=7-E9"!I9@H@*B!Y;W4@=V%N="!T;R!D:7)E8W1L>2!A=71H96YT:6-A=&4@
M=7-E<G,@=VET:"!T:&ES(&1R:79E<BP@:6YS=&5A9`H@*B!O9B!R96QY:6YG
M(&]N('1R86YS<&%R96YT(&%U=&@N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+T%U=&@O075T:"]H='1P+G!H<"QV(#$N,C$N,3`N.2`R,#`V+S`Q+S`Q(#(Q
M.C(X.C`W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H
M=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO
M<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]!
M=71H"B`J+PIC;&%S<R!!=71H7VAT='`@97AT96YD<R!!=71H('L*"B`@("`O
M*BH*("`@("`J($%N(&%R<F%Y(&]F(&-A<&%B:6QI=&EE<RP@<V\@=&AA="!T
M:&4@9')I=F5R(&-A;B!R97!O<G0@=VAI8V@*("`@("`J(&]P97)A=&EO;G,@
M:70@<W5P<&]R=',@86YD('=H:6-H(&ET(&1O97-N)W0N"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&-A<&%B:6QI=&EE<R`]
M(&%R<F%Y*"=A9&0G("`@("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W5P9&%T92<@("`@("`@(#T^(&9A;'-E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5S971P87-S=V]R9"<@
M/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R96UO
M=F4G("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VQI<W0G("`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G=')A;G-P87)E;G0G("`@/3X@=')U92D["@H@
M("`@+RHJ"B`@("`@*B!!<G)A>2!O9B!U<V5R;F%M97,@86YD(&AA<VAE9"!P
M87-S=V]R9',N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)%]U<V5R<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#;VYS
M=')U8W1S(&$@;F5W($A45%`@875T:&5N=&EC871I;VX@;V)J96-T+@H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I
M;FEN9R!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!!=71H7VAT
M='`H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]P
M87)A;7,@/2`D<&%R86US.PH*("`@("`@("`O+R!$969A=6QT('1O($1%4R!P
M87-S=V]R9',N"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%R86US6R=E
M;F-R>7!T:6]N)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=E
M;F-R>7!T:6]N)UT@/2`G8W)Y<'0M9&5S)SL*("`@("`@("!]"@H@("`@("`@
M(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;)VAT<&%S<W=D7V9I;&4G72DI
M('L*("`@("`@("`@("`@)'5S97)S(#T@0&9I;&4H)'1H:7,M/E]P87)A;7-;
M)VAT<&%S<W=D7V9I;&4G72D["B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D
M=7-E<G,I*2!["B`@("`@("`@("`@("`@("`O+R!%;F%B;&4@=&AE(&QI<W0@
M=7-E<G,@8V%P86)I;&ET>2X*("`@("`@("`@("`@("`@("1T:&ES+3YC87!A
M8FEL:71I97-;)VQI<W0G72`]('1R=64["@H@("`@("`@("`@("`@("`@+R\@
M4'5T('5S97)S(&EN=&\@86QP:&%B971I8V%L(&]R9&5R+@H@("`@("`@("`@
M("`@("`@<V]R="@D=7-E<G,I.PH*("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1U<V5R<R!A<R`D;&EN92D@>PH@("`@("`@("`@("`@("`@("`@(&QI<W0H
M)'5S97(L("1P87-S*2`](&5X<&QO9&4H)SHG+"`D;&EN92P@,BD["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]U<V5R<UMT<FEM*"1U<V5R*5T@/2!T
M<FEM*"1P87-S*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($9I;F0@;W5T(&EF(&$@
M<V5T(&]F(&QO9VEN(&-R961E;G1I86QS(&%R92!V86QI9"X@3VYL>2!S=7!P
M;W)T<PH@("`@("H@:'1P87-S=V0@9FEL97,@=VET:"!$15,@<&%S<W=O<F1S
M(')I9VAT(&YO=RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@("`@("`@5&AE('5S
M97))9"!T;R!C:&5C:RX*("`@("`J($!P87)A;2!A<G)A>2`@)&-R961E;G1I
M86QS("!!;B!A<G)A>2!O9B!L;V=I;B!C<F5D96YT:6%L<RX@1F]R($E-05`L
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AI<R!M=7-T
M(&-O;G1A:6X@82!P87-S=V]R9"!E;G1R>2X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T('1H92!C<F5D96YT:6%L<R!A
M<F4@=F%L:60N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A=71H96YT:6-A=&4H
M)'5S97))9"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@("`@(&EF("AE;7!T
M>2@D8W)E9&5N=&EA;'-;)W!A<W-W;W)D)UTI*2!["B`@("`@("`@("`@($AO
M<F1E.CIF871A;"A?*").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A
M=71H96YT:6-A=&EO;BXB*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@
M("!]"@H@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W5S97)S6R1U<V5R261=
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%
M05-/3E]"041,3T=)3BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@("1H87-H(#T@)'1H:7,M/F=E=$-R>7!T961087-S
M=V]R9"@D8W)E9&5N=&EA;'-;)W!A<W-W;W)D)UTL("1T:&ES+3Y?=7-E<G-;
M)'5S97))9%TL("1T:&ES+3Y?<&%R86US6R=E;F-R>7!T:6]N)UTL("%E;7!T
M>2@D=&AI<RT^7W!A<F%M<ULG<VAO=U]E;F-R>7!T:6]N)UTI*3L*("`@("`@
M("!I9B`H)&AA<V@@/3T@)'1H:7,M/E]U<V5R<ULD=7-E<DED72D@>PH@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/3E]"041,3T=)
M3BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(%5222!O9B!T:&4@;&]G:6X@
M<V-R965N(&9O<B!T:&ES(&%U=&AE;G1I8V%T:6]N(&]B:F5C="X*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1A<'`@(%1H92!A<'!L:6-A=&EO;B!T;R!U<V4N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1U<FP@(%1H92!54DP@=&\@<F5D:7)E8W0@=&\@869T
M97(@;&]G:6XN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!L
M;V=I;B!S8W)E96X@55))+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T3&]G
M:6Y38W)E96XH)&%P<"`]("=H;W)D92<L("1U<FP@/2`G)RD*("`@('L*("`@
M("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=L;V=I;E-C<F5E;B==
M*2D@>PH@("`@("`@("`@("!I9B`H)'5R;"D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(%5T:6PZ.F%D9%!A<F%M971E<B@D=&AI<RT^7W!A<F%M<ULG;&]G
M:6Y38W)E96XG72P@)W5R;"<L("1U<FPI.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%R86US6R=L;V=I
M;E-C<F5E;B==.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<F5T=7)N('!A<F5N=#HZ7V=E=$QO9VEN4V-R965N*"1A<'`L
M("1U<FPI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($QI<W0@
M86QL('5S97)S(&EN('1H92!S>7-T96TN"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@5&AE(&%R<F%Y(&]F('5S97))9',L(&]R(&$@4$5!4E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@;&ES
M=%5S97)S*"D*("`@('L*("`@("`@("!R971U<FX@87)R87E?:V5Y<R@D=&AI
M<RT^7W5S97)S*3L*("`@('T*"B`@("`O*BH*("`@("`J($%U=&]M871I8R!A
M=71H96YT:6-A=&EO;CH@1FEN9"!O=70@:68@=&AE(&-L:65N="!H87,@2%14
M4`H@("`@("H@875T:&5N=&EC871I;VX@:6YF;R!P<F5S96YT+@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&-L
M:65N="!I<R!A;&QO=V5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!T<F%N<W!A
M<F5N="@I"B`@("!["B`@("`@("`@:68@*"%E;7!T>2@D7U-%4E9%4ELG4$A0
M7T%55$A?55-%4B==*2`F)@H@("`@("`@("`@("`A96UP='DH)%]315)615);
M)U!(4%]!551(7U!7)UTI*2!["B`@("`@("`@("`@("1T:&ES+3YS971!=71H
M*%5T:6PZ.F1I<W!E;$UA9VEC475O=&5S*"1?4T525D526R=02%!?05542%]5
M4T52)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<&%S
M<W=O<F0G(#T^(%5T:6PZ.F1I<W!E;$UA9VEC475O=&5S*"1?4T525D526R=0
M2%!?05542%]05R==*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W1R86YS<&%R96YT)R`]/B`Q*2D["B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H
M05542%]214%33TY?34534T%'12P@7R@B2%144"!!=71H96YT:6-A=&EO;B!N
M;W0@9F]U;F0N(BDI.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O<VUB+G!H<```````````
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`W,3(V(#$P-3$U-#,S
M-S0P(#`R,34T-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@5&AE($%U=&A?<VUB(&-L87-S('!R;W9I
M9&5S(&%N(%--0B!I;7!L96UE;G1A=&EO;B!O9B!T:&4@2&]R9&4*("H@875T
M:&5N=&EC871I;VX@<WES=&5M+@H@*@H@*B!4:&ES(&UO9'5L92!R97%U:7)E
M<R!T:&4@<VUB875T:"!E>'1E;G-I;VX@9F]R(%!(4#H*("H@("!H='1P.B\O
M=W=W+G1E:W)A="YC;VTO<VUB875T:"\*("H*("H@070@=&AE('1I;64@;V8@
M=&AI<R!W<FET:6YG+"!T:&4@97AT96YS:6]N+"!A;F0@=&AU<R!T:&ES(&UO
M9'5L92P@;VYL>0H@*B!S=7!P;W)T960@875T:&5N=&EC871I;VX@86=A:6YS
M="!A(&1O;6%I;BP@86YD('!D8R!A;F0@8F1C(&UU<W0@8F4@;F]N+6YU;&P*
M("H@86YD(&YO="!E<75A;"!T;R!E86-H(&]T:&5R+B!);B!O=&AE<B!W;W)D
M<RP@=&\@=7-E('1H:7,@;6]D=6QE('EO=2!M=7-T"B`J(&AA=F4@82!D;VUA
M:6X@=VET:"!A="!L96%S="!O;F4@4$1#(&%N9"!O;F4@0D1#+@H@*@H@*B!2
M97%U:7)E9"!P87)A;65T97)S.CQP<F4^"B`J("`@)VAO<W1S<&5C)R`@25`L
M($1.4R!.86UE+"!O<B!.971":6]S($YA;64@;V8@=&AE(%--0B!S97)V97(@
M=&\*("H@("`@("`@("`@("`@("!A=71H96YT:6-A=&4@=VET:"X*("H@("`G
M9&]M86EN)R`@("!4:&4@9&]M86EN(&YA;64@=&\@875T:&5N=&EC871E('=I
M=&@N/"]P<F4^"B`J"B`J($]P=&EO;F%L('!A<F%M971E<G,Z/'!R93X*("H@
M("`G9W)O=7`G("`@("!'<F]U<"!N86UE('1H870@=&AE('5S97(@;75S="!B
M92!A(&UE;6)E<B!O9BX@5VEL;"!B90H@*B`@("`@("`@("`@("`@(&EG;F]R
M960@:68@=&AE('9A;'5E('!A<W-E9"!I<R!A('IE<F\@;&5N9W1H('-T<FEN
M9RX\+W!R93X*("H*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO075T:"]!=71H
M+W-M8BYP:'`L=B`Q+C(P+C$P+C@@,C`P-B\P,2\P,2`R,3HR.#HP-R!J86X@
M17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!*;VX@4&%R:7-E(#QJ
M;VY`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UA<F-U<R!)
M+B!2>6%N(#QM87)C=7-`<FEB;V9L879I;BYN970^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B!`875T:&]R("!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!`
M875T:&]R("!-87)C=7,@22X@4GEA;B`\;6%R8W5S0')I8F]F;&%V:6XN;F5T
M/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?075T
M:`H@*B\*8VQA<W,@075T:%]S;6(@97AT96YD<R!!=71H('L*"B`@("`O*BH*
M("`@("`J($%N(&%R<F%Y(&]F(&-A<&%B:6QI=&EE<RP@<V\@=&AA="!T:&4@
M9')I=F5R(&-A;B!R97!O<G0@=VAI8V@*("`@("`J(&]P97)A=&EO;G,@:70@
M<W5P<&]R=',@86YD('=H:6-H(&ET(&1O97-N)W0N"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&-A<&%B:6QI=&EE<R`](&%R
M<F%Y*"=A9&0G("`@("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W5P9&%T92<@("`@("`@(#T^(&9A;'-E+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5S971P87-S=V]R9"<@/3X@
M9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R96UO=F4G
M("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)VQI<W0G("`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G=')A;G-P87)E;G0G("`@/3X@9F%L<V4I.PH*("`@
M("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!334(@875T:&5N=&EC871I
M;VX@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US
M("!!(&AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N('!A<F%M971E<G,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N($%U=&A?<VUB*"1P87)A;7,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@(&EF("@A571I;#HZ97AT96YS:6]N17AI<W1S*"=S
M;6)A=71H)RDI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*%\H(D%U=&A?
M<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@
M+RH@16YS=7)E('=E)W9E(&)E96X@<')O=FED960@=VET:"!A;&P@;V8@=&AE
M(&YE8V5S<V%R>2!P87)A;65T97)S+B`J+PH@("`@("`@($AO<F1E.CIA<W-E
M<G1$<FEV97)#;VYF:6<H)'!A<F%M<RP@)V%U=&@G+`H@("`@("`@("`@("!A
M<G)A>2@G:&]S='-P96,G+"`G9&]M86EN)RDL"B`@("`@("`@("`@("=A=71H
M96YT:6-A=&EO;B!386UB82<I.PH*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]
M("1P87)A;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&:6YD(&]U="!I9B!T
M:&4@9VEV96X@<V5T(&]F(&QO9VEN(&-R961E;G1I86QS(&%R92!V86QI9"X*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1U<V5R260@("`@("!4:&4@=7-E<DED('1O(&-H96-K
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L<R`@06X@87)R87D@
M;V8@;&]G:6X@8W)E9&5N=&EA;',N"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?875T:&5N=&EC
M871E*"1U<V5R260L("1C<F5D96YT:6%L<RD*("`@('L*("`@("`@("!I9B`H
M96UP='DH)&-R961E;G1I86QS6R=P87-S=V]R9"==*2D@>PH@("`@("`@("`@
M("!(;W)D93HZ9F%T86PH7R@B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--
M0B!A=71H96YT:6-A=&EO;BXB*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@
M("`@("!]"@H@("`@("`@("\J($%U=&AE;G1I8V%T92X@*B\*("`@("`@("`D
M<G9A;"`]('9A;&ED871E*"1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V1O;6%I
M;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@96UP='DH)'1H:7,M/E]P
M87)A;7-;)V=R;W5P)UTI(#\@)R<@.B`D=&AI<RT^7W!A<F%M<ULG9W)O=7`G
M72P*("`@("`@("`@("`@("`@("`@("`@("`@("1U<V5R260L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`D8W)E9&5N=&EA;'-;)W!A<W-W;W)D)UTI.PH*
M("`@("`@("!I9B`H)')V86P@/3T](#`I('L*("`@("`@("`@("`@<F5T=7)N
M('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*"1R=F%L
M(#T]/2`Q*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O
M<BA!551(7U)%05-/3E]-15-304=%+"!?*")&86EL960@=&\@8V]N;F5C="!T
M;R!334(@<V5R=F5R+B(I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<V5T075T:$5R<F]R*$%55$A?4D5!4T].7TU%
M4U-!1T4L(&5R<C)S='(H*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U
M=&@O;&]G:6XN<&AP````````````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`U-C(W(#$P-3$U-#,S-S0P(#`R,C$P,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@5&AE($%U
M=&A?;&]G:6XZ.B!C;&%S<R!P<F]V:61E<R!A('-Y<W1E;2!L;V=I;B!I;7!L
M96UE;G1A=&EO;B!O9@H@*B!T:&4@2&]R9&4@875T:&5N=&EC871I;VX@<WES
M=&5M+@H@*B!4:&ES($%U=&@@9')I=F5R(&ES('5S969U;"!I9B!Y;W4@:&%V
M92!A('-H861O=R!P87-S=V]R9"!S>7-T96T*("H@=VAE<F4@=&AE($%U=&A?
M<&%S<W=D(&1R:79E<B!D;V5S;B=T('=O<FLN"B`J"B`J($]P=&EO;F%L('!A
M<F%M971E<G,Z/'!R93X*("H@("`G;&]C871I;VXG("!,;V-A=&EO;B!O9B!T
M:&4@<W4@8FEN87)Y+@H@*B`@("`@("`@("`@("`@($1%1D%53%0Z("]B:6XO
M<W4\+W!R93X*("H*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO075T:"]!=71H
M+VQO9VEN+G!H<"QV(#$N,RXQ,"XY(#(P,#8O,#$O,#$@,C$Z,C@Z,#<@:F%N
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@2F%N(%-C:&YE:61E
M<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO
M<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]!=71H"B`J+PIC;&%S<R!!=71H
M7VQO9VEN(&5X=&5N9',@075T:"!["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A
M>2!O9B!C87!A8FEL:71I97,L('-O('1H870@=&AE(&1R:79E<B!C86X@<F5P
M;W)T('=H:6-H"B`@("`@*B!O<&5R871I;VYS(&ET('-U<'!O<G1S(&%N9"!W
M:&EC:"!I="!D;V5S;B=T+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1C87!A8FEL:71I97,@/2!A<G)A>2@G861D)R`@("`@
M("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=U<&1A=&4G("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W)E<V5T<&%S<W=O<F0G(#T^(&9A;'-E+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G<F5M;W9E)R`@("`@("`@/3X@9F%L
M<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=L:7-T)R`@("`@
M("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W1R86YS<&%R96YT)R`@(#T^(&9A;'-E*3L*"B`@("`O*BH*("`@("`J('-U
M(&)I;F%R>2X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)%]L;V-A=&EO;B`]("<O8FEN+W-U)SL*"B`@("`O*BH*("`@("`J
M($QI<W0@;V8@=7-E<G,@=&AA="!S:&]U;&0@8F4@97AC;'5D960@9G)O;2!B
M96EN9R!L:7-T960O:&%N9&QE9`H@("`@("H@:6X@86YY('=A>2!B>2!T:&ES
M(&1R:79E<BX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@
M('9A<B`D7V5X8VQU9&4@/2!A<G)A>2@G<F]O="<L("=D865M;VXG+"`G8FEN
M)RP@)W-Y<R<L("=S>6YC)RP@)V=A;65S)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`G;6%N)RP@)VQP)RP@)VUA:6PG+"`G;F5W<R<L("=U=6-P)RP@
M)W!R;WAY)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`G<&]S=&=R97,G
M+"`G=W=W+61A=&$G+"`G8F%C:W5P)RP@)V]P97)A=&]R)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`G;&ES="<L("=I<F,G+"`G9VYA=',G+"`G;F]B
M;V1Y)RP@)VED96YT9"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@)W-S
M:&0G+"`G9V1M)RP@)W!O<W1F:7@G+"`G;7ES<6PG+"`G8WER=7,G+"`G9G1P
M)RD["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W($QO9VEN(&%U
M=&AE;G1I8V%T:6]N(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A
M;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!!=71H7VQO9VEN*"1P87)A
M;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<&%R86US(#T@
M)'!A<F%M<SL*("`@("`@("!I9B`H(65M<'1Y*"1P87)A;7-;)VQO8V%T:6]N
M)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?;&]C871I;VX@/2`D<&%R86US
M6R=L;V-A=&EO;B==.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($9I;F0@;W5T(&EF(&$@<V5T(&]F(&QO9VEN(&-R961E;G1I86QS(&%R92!V
M86QI9"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@("`@("!4:&4@=7-E<DED('1O
M(&-H96-K+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L<R`@06X@
M87)R87D@;V8@;&]G:6X@8W)E9&5N=&EA;',N"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@8W)E9&5N=&EA;',@
M87)E('9A;&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!?875T:&5N=&EC871E
M*"1U<V5R260L("1C<F5D96YT:6%L<RD*("`@('L*("`@("`@("!I9B`H96UP
M='DH)&-R961E;G1I86QS6R=P87-S=V]R9"==*2D@>PH@("`@("`@("`@("!(
M;W)D93HZ9F%T86PH7R@B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN
M(&%U=&AE;G1I8V%T:6]N+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@
M("`@('T*"B`@("`@("`@)'!R;V,@/2!P;W!E;B@D=&AI<RT^7VQO8V%T:6]N
M("X@)R`M8R`O8FEN+W1R=64@)R`N("1U<V5R260L("=W)RD["B`@("`@("`@
M:68@*"%I<U]R97-O=7)C92@D<')O8RDI('L*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@('T*("`@("`@("!F=W)I=&4H)'!R;V,L("1C<F5D
M96YT:6%L<ULG<&%S<W=O<F0G72D["@H@("`@("`@(')E='5R;B!P8VQO<V4H
M)'!R;V,I(#T]/2`P.PH@("`@?0H*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O075T:"]C=7-T;VUS<6PN<&AP
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,C,W-C`@,3`U,34T
M,S,W-#`@,#(S,#(P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"@IR97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?
M7RD@+B`G+W-Q;"YP:'`G.PH*+RHJ"B`J(%1H92!!=71H7V-U<W1O;7-Q;"!C
M;&%S<R!P<F]V:61E<R!A('-Q;"!I;7!L96UE;G1A=&EO;B!O9B!T:&4@2&]R
M9&4*("H@875T:&5N=&EC871I;VX@<WES=&5M('=I=&@@=&AE('!O<W-I8FEL
M:71Y('1O('-E="!C=7-T;VTM;6%D92!Q=65R:65S+@H@*@H@*B!297%U:7)E
M9"!P87)A;65T97)S.CQP<F4^"B`J("`@)W!H<'1Y<&4G("!4:&4@9&%T86)A
M<V4@='EP92`H:64N("=P9W-Q;"<L("=M>7-Q;"<L(&5T8RXI+CPO<')E/@H@
M*@H@*B!297%U:7)E9"!P87)A;65T97)S.B`H0W5S=&]M('%U97)Y*3QP<F4^
M"B`J(%-O;64@<W!E8VEA;"!T;VME;G,@8V%N(&)E('5S960@:6X@=&AE('-Q
M;"!Q=65R>2X@5&AE>2!A<F4@<F5P;&%C960*("H@870@=&AE('%U97)Y('-T
M86=E.@H@*@H@*B`@("T@)UQ,)R!W:6QL(&)E(')E<&QA8V5D(&)Y('1H92!U
M<V5R)W,@;&]G:6X*("H@("`M("=<4"<@=VEL;"!B92!R97!L86-E9"!B>2!T
M:&4@=7-E<B=S('!A<W-W;W)D+@H@*B`@("T@)UQ/)R!W:6QL(&)E(')E<&QA
M8V5D(&)Y('1H92!O;&0@=7-E<B=S(&QO9VEN("AR97%U:7)E9"!F;W(@=7!D
M871E*0H@*@H@*B`@($5G.B`B4T5,14-4("H@1E)/32!U<V5R<R!72$5212!U
M:60@/2!<3`H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!!3D0@<&%S
M<W=D(#T@7%`*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@04Y$(&)I
M;&QI;F<@/2`G<&%I9"<*("H*("H@("`G<75E<GE?875T:"<@("`@075T:&5N
M=&EC871E('1H92!U<V5R+B`@("`@("`G7$PG("8@)UQ.)PH@*B`@("=Q=65R
M>5]A9&0G("`@("!!9&0@=7-E<BX@("`@("`@("`@("`@("`@("`@("=<3"<@
M)B`G7$XG"B`J("`@)W%U97)Y7W5P9&%T92<@(%5P9&%T92!U<V5R+B`@("`@
M("`@("`@("`@("`@)UQ/)RP@)UQ,)R`F("=<3B<*("H@("`G<75E<GE?<F5S
M971P87-S=V]R9"<@(%)E<V5T('!A<W-W;W)D+B`@("`@("`G7$PG+"`F("=<
M4"<*("H@("`G<75E<GE?<F5M;W9E)R`@4F5M;W9E('5S97(N("`@("`@("`@
M("`@("`@("`G7$PG"B`J("`@)W%U97)Y7VQI<W0G("`@($QI<W0@=7-E<BX@
M("`@("`@("`@("`@("`@("`@)UQ,)SPO<')E/@H@*@H@*B!/<'1I;VYA;"!P
M87)A;65T97)S.CQP<F4^"B`J("`@)V5N8W)Y<'1I;VXG("`@("`@(%1H92!E
M;F-R>7!T:6]N('1O('5S92!T;R!S=&]R92!T:&4@<&%S<W=O<F0@:6X@=&AE
M"B`J("`@("`@("`@("`@("`@("`@("`@('1A8FQE("AE+F<N('!L86EN+"!C
M<GEP="P@;60U+6AE>"P@;60U+6)A<V4V-"P@<VUD-2P*("H@("`@("`@("`@
M("`@("`@("`@("`@<VAA+"!S<VAA*2X*("H@("`@("`@("`@("`@("`@("`@
M("`@1$5&055,5#H@)VUD-2UH97@G"B`J("`@)W-H;W=?96YC<GEP=&EO;B<@
M(%=H971H97(@;W(@;F]T('1O('!R97!E;F0@=&AE(&5N8W)Y<'1I;VX@:6X@
M=&AE"B`J("`@("`@("`@("`@("`@("`@("`@('!A<W-W;W)D(&9I96QD+@H@
M*B`@("`@("`@("`@("`@("`@("`@("!$149!54Q4.B`G9F%L<V4G/"]P<F4^
M"B`J"B`J(%)E<75I<F5D(&)Y('-O;64@9&%T86)A<V4@:6UP;&5M96YT871I
M;VYS.CQP<F4^"B`J("`@)VAO<W1S<&5C)R`@5&AE(&AO<W1N86UE(&]F('1H
M92!D871A8F%S92!S97)V97(N"B`J("`@)W!R;W1O8V]L)R`@5&AE(&-O;6UU
M;FEC871I;VX@<')O=&]C;VP@*"=T8W`G+"`G=6YI>"<L(&5T8RXI+@H@*B`@
M("=D871A8F%S92<@(%1H92!N86UE(&]F('1H92!D871A8F%S92X*("H@("`G
M=7-E<FYA;64G("!4:&4@=7-E<FYA;64@=VET:"!W:&EC:"!T;R!C;VYN96-T
M('1O('1H92!D871A8F%S92X*("H@("`G<&%S<W=O<F0G("!4:&4@<&%S<W=O
M<F0@87-S;V-I871E9"!W:71H("=U<V5R;F%M92<N"B`J("`@)V]P=&EO;G,G
M("`@061D:71I;VYA;"!O<'1I;VYS('1O('!A<W,@=&\@=&AE(&1A=&%B87-E
M+@H@*B`@("=P;W)T)R`@("`@(%1H92!P;W)T(&]N('=H:6-H('1O(&-O;FYE
M8W0@=&\@=&AE(&1A=&%B87-E+@H@*B`@("=T='DG("`@("`@(%1H92!45%D@
M;VX@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N/"]P<F4^"B`J
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T%U=&@O075T:"]C=7-T;VUS<6PN
M<&AP+'8@,2XQ-BXQ,"XX(#(P,#4O,3$O,S`@,#`Z,#,Z,SD@:F%N($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`R,#`R(%)O;FYI92!'87)C:6$@/')O;FYI94!M
M:S(N;F5T/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@4F]N;FEE($=A
M<F-I82`\<F]N;FEE0&UK,BYN970^"B`J($!A=71H;W(@($-H=6-K($AA9V5N
M8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("!*;V5L(%9A;F1A
M;"`\:G9A;F1A;$!I;F9O=&5C:RYQ8RYC83X*("H@0'-I;F-E("`@2&]R9&4@
M,2XS"B`J($!P86-K86=E($AO<F1E7T%U=&@*("HO"F-L87-S($%U=&A?8W5S
M=&]M<W%L(&5X=&5N9',@075T:%]S<6P@>PH*("`@("\J*@H@("`@("H@06X@
M87)R87D@;V8@8V%P86)I;&ET:65S+"!S;R!T:&%T('1H92!D<FEV97(@8V%N
M(')E<&]R="!W:&EC:`H@("`@("H@;W!E<F%T:6]N<R!I="!S=7!P;W)T<R!A
M;F0@=VAI8V@@:70@9&]E<VXG="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*B\*("`@('9A<B`D8V%P86)I;&ET:65S(#T@87)R87DH)V%D9"<@
M("`@("`@("`@(#T^('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=U<&1A=&4G("`@("`@("`]/B!T<G5E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G<F5S971P87-S=V]R9"<@/3X@=')U92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W)E;6]V92<@("`@("`@(#T^('1R
M=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=L:7-T)R`@("`@
M("`@("`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M=')A;G-P87)E;G0G("`@/3X@9F%L<V4I.PH*("`@("\J*@H@("`@("H@0V]N
M<W1R=6-T<R!A(&YE=R!344P@875T:&5N=&EC871I;VX@;V)J96-T+@H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I
M;FEN9R!C;VYN96-T:6]N('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N($%U=&A?8W5S=&]M<W%L*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL*"B`@("`@("`@2&]R
M9&4Z.F%S<V5R=$1R:79E<D-O;F9I9R@D<&%R86US+"`G875T:"<L"B`@("`@
M("`@("`@(&%R<F%Y*"=Q=65R>5]A=71H)RDL"B`@("`@("`@("`@("=A=71H
M96YT:6-A=&EO;B!C=7-T;VT@4U%,)RD["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!&:6YD(&]U="!I9B!A('-E="!O9B!L;V=I;B!C<F5D96YT:6%L<R!A<F4@
M=F%L:60N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("`@("`@5&AE('5S97))9"!T
M;R!C:&5C:RX*("`@("`J($!P87)A;2!A<G)A>2`D8W)E9&5N=&EA;',@(%1H
M92!C<F5D96YT:6%L<R!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@8W)E9&5N=&EA;',@87)E('9A
M;&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!?875T:&5N=&EC871E*"1U<V5R
M260L("1C<F5D96YT:6%L<RD*("`@('L*("`@("`@("`O*B!?8V]N;F5C="@I
M('=I;&P@9&EE('=I=&@@2&]R9&4Z.F9A=&%L*"D@=7!O;B!F86EL=7)E+B`J
M+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("`O*B!"=6EL
M9"!A(&-U<W1O;2!Q=65R>2P@8F%S960@;VX@=&AE(&-O;F9I9R!F:6QE+B`J
M+PH@("`@("`@("1Q=65R>2`]("1T:&ES+3Y?<&%R86US6R=Q=65R>5]A=71H
M)UT["B`@("`@("`@)'%U97)Y(#T@<W1R7W)E<&QA8V4H)UQ,)RP@)'1H:7,M
M/E]D8BT^<75O=&4H)'5S97))9"DL("1Q=65R>2D["B`@("`@("`@)'%U97)Y
M(#T@<W1R7W)E<&QA8V4H)UQ0)RP@)'1H:7,M/E]D8BT^<75O=&4H)'1H:7,M
M/F=E=$-R>7!T961087-S=V]R9"@D8W)E9&5N=&EA;'-;)W!A<W-W;W)D)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=E
M;F-R>7!T:6]N)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULG<VAO=U]E;F-R>7!T:6]N)UTI*2P@)'%U97)Y
M*3L*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R
M>2D["B`@("`@("`@:68@*"%I<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@)')O=R`]("1R97-U;'0M/F9E=&-H4F]W*$1"7T=%
M5$U/1$5?05-33T,I.PH@("`@("`@("`@("`O*B!)9B!W92!H879E(&%T(&QE
M87-T(&]N92!R971U<FYE9"!R;W<L('1H96X@=&AE('5S97(@:7,*("`@("`@
M("`@("`@("H@=F%L:60N("HO"B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D
M<F]W*2D@>PH@("`@("`@("`@("`@("`@)')E<W5L="T^9G)E92@I.PH@("`@
M("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D<F5S=6QT+3YF<F5E*"D["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/3E]"041,3T=)
M3BD["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@
M('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7W-E=$%U
M=&A%<G)O<BA!551(7U)%05-/3E]&04E,140I.PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@061D
M(&$@<V5T(&]F(&%U=&AE;G1I8V%T:6]N(&-R961E;G1I86QS+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@("`@(%1H92!U<V5R260@
M=&\@861D+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L<R`@5&AE
M(&-R961E;G1I86QS('1O(&%D9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O
M;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&15<V5R*"1U<V5R
M260L("1C<F5D96YT:6%L<RD*("`@('L*("`@("`@("`D=&AI<RT^7V-O;FYE
M8W0H*3L*"B`@("`@("`@+RH@0G5I;&0@82!C=7-T;VT@<75E<GDL(&)A<V5D
M(&]N('1H92!C;VYF:6<@9FEL92X@*B\*("`@("`@("`D<75E<GD@/2`D=&AI
M<RT^7W!A<F%M<ULG<75E<GE?861D)UT["B`@("`@("`@)'%U97)Y(#T@<W1R
M7W)E<&QA8V4H)UQ,)RP@)'1H:7,M/E]D8BT^<75O=&4H)'5S97))9"DL("1Q
M=65R>2D["B`@("`@("`@)'%U97)Y(#T@<W1R7W)E<&QA8V4H)UQ0)RP@)'1H
M:7,M/E]D8BT^<75O=&4H)'1H:7,M/F=E=$-R>7!T961087-S=V]R9"@D8W)E
M9&5N=&EA;'-;)W!A<W-W;W)D)UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=E;F-R>7!T:6]N)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<VAO=U]E
M;F-R>7!T:6]N)UTI*2P@)'%U97)Y*3L*"B`@("`@("`@)')E<W5L="`]("1T
M:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2D["B`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@57!D871E(&$@<V5T(&]F(&%U=&AE;G1I8V%T:6]N
M(&-R961E;G1I86QS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&]L
M9$E$("`@("`@(%1H92!O;&0@=7-E<DED+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;F5W240@("`@("`@5&AE(&YE=R!U<V5R260N"B`@("`@*B!`<&%R86T@
M87)R87D@)&-R961E;G1I86QS("!4:&4@;F5W(&-R961E;G1I86QS"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@
M4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@=7!D871E57-E<B@D;VQD240L("1N97=)1"P@)&-R961E;G1I86QS
M*0H@("`@>PH@("`@("`@("\J(%]C;VYN96-T*"D@=VEL;"!D:64@=VET:"!(
M;W)D93HZ9F%T86PH*2!U<&]N(&9A:6QU<F4N("HO"B`@("`@("`@)'1H:7,M
M/E]C;VYN96-T*"D["@H@("`@("`@("\J($)U:6QD(&$@8W5S=&]M('%U97)Y
M+"!B87-E9"!O;B!T:&4@8V]N9FEG(&9I;&4N("HO"B`@("`@("`@)'%U97)Y
M(#T@)'1H:7,M/E]P87)A;7-;)W%U97)Y7W5P9&%T92==.PH@("`@("`@("1Q
M=65R>2`]('-T<E]R97!L86-E*"=<3R<L("1T:&ES+3Y?9&(M/G%U;W1E*"1O
M;&1)1"DL("1Q=65R>2D["B`@("`@("`@)'%U97)Y(#T@<W1R7W)E<&QA8V4H
M)UQ,)RP@)'1H:7,M/E]D8BT^<75O=&4H)&YE=TE$*2P@)'%U97)Y*3L*("`@
M("`@("`D<75E<GD@/2!S=')?<F5P;&%C92@G7%`G+"`D=&AI<RT^7V1B+3YQ
M=6]T92@D=&AI<RT^9V5T0W)Y<'1E9%!A<W-W;W)D*"1C<F5D96YT:6%L<ULG
M<&%S<W=O<F0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]P87)A;7-;)V5N8W)Y<'1I;VXG72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=S:&]W7V5N8W)Y<'1I;VXG
M72DI+"`D<75E<GDI.PH*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^
M<75E<GDH)'%U97)Y*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!297-E=',@82!U<V5R)W,@<&%S<W=O<F0N(%5S960@9F]R(&5X86UP
M;&4@=VAE;B!T:&4@=7-E<B!D;V5S(&YO=`H@("`@("H@<F5M96UB97(@=&AE
M(&5X:7-T:6YG('!A<W-W;W)D+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'5S97)?:60@(%1H92!U<V5R(&ED(&9O<B!W:&EC:"!T;R!R97-E="!T
M:&4@<&%S<W=O<F0N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE
M(&YE=R!P87-S=V]R9"!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE
M8W0@;VX*("`@("`J("`@("`@("`@("`@("`@(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(')E<V5T4&%S<W=O<F0H)'5S97)?:60I"B`@("!["B`@
M("`@("`@+RH@7V-O;FYE8W0H*2!W:6QL(&1I92!W:71H($AO<F1E.CIF871A
M;"@I('5P;VX@9F%I;'5R92X@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H
M*3L*"B`@("`@("`@+RH@1V5T(&$@;F5W(')A;F1O;2!P87-S=V]R9"X@*B\*
M("`@("`@("`D<&%S<W=O<F0@/2!!=71H.CIG96Y286YD;VU087-S=V]R9"@I
M.PH*("`@("`@("`O*B!"=6EL9"!T:&4@4U%,('%U97)Y+B`J+PH@("`@("`@
M("1Q=65R>2`]("1T:&ES+3Y?<&%R86US6R=Q=65R>5]R97-E='!A<W-W;W)D
M)UT["B`@("`@("`@)'%U97)Y(#T@<W1R7W)E<&QA8V4H)UQ,)RP@)'1H:7,M
M/E]D8BT^<75O=&4H)'5S97)?:60I+"`D<75E<GDI.PH@("`@("`@("1Q=65R
M>2`]('-T<E]R97!L86-E*"=<4"<L("1T:&ES+3Y?9&(M/G%U;W1E*"1T:&ES
M+3YG971#<GEP=&5D4&%S<W=O<F0H)'!A<W-W;W)D+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG96YC<GEP=&EO;B==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)W-H;W=?96YC<GEP=&EO;B==*2DL("1Q=65R>2D["@H@("`@("`@("1R
M97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDI.PH@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'!A
M<W-W;W)D.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E(&$@<V5T(&]F
M(&%U=&AE;G1I8V%T:6]N(&-R961E;G1I86QS+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'5S97))9"`@5&AE('5S97))9"!T;R!D96QE=&4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("`@("`@("!3=6-C97-S(&]R
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V955S97(H)'5S
M97))9"D*("`@('L*("`@("`@("`O*B!?8V]N;F5C="@I('=I;&P@9&EE('=I
M=&@@2&]R9&4Z.F9A=&%L*"D@=7!O;B!F86EL=7)E+B`J+PH@("`@("`@("1T
M:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("`O*B!"=6EL9"!A(&-U<W1O;2!Q
M=65R>2P@8F%S960@;VX@=&AE(&-O;F9I9R!F:6QE+B`J+PH@("`@("`@("1Q
M=65R>2`]("1T:&ES+3Y?<&%R86US6R=Q=65R>5]R96UO=F4G73L*("`@("`@
M("`D<75E<GD@/2!S=')?<F5P;&%C92@G7$PG+"`D=&AI<RT^7V1B+3YQ=6]T
M92@D=7-E<DED*2P@)'%U97)Y*3L*"B`@("`@("`@)')E<W5L="`]("1T:&ES
M+3Y?9&(M/G%U97)Y*"1Q=65R>2D["B`@("`@("`@:68@*&ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^<F5M;W9E57-E
M<D1A=&$H)'5S97))9"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!,:7-T(&%L
M;"!U<V5R<R!I;B!T:&4@<WES=&5M+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1H92!A<G)A>2!O9B!U<V5R261S+"!O<B!F86QS92!O;B!F86EL
M=7)E+W5N<W5P<&]R=&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T57-E
M<G,H*0H@("`@>PH@("`@("`@("\J(%]C;VYN96-T*"D@=VEL;"!D:64@=VET
M:"!(;W)D93HZ9F%T86PH*2!U<&]N(&9A:6QU<F4N("HO"B`@("`@("`@)'1H
M:7,M/E]C;VYN96-T*"D["@H@("`@("`@("\J($)U:6QD(&$@8W5S=&]M('%U
M97)Y+"!B87-E9"!O;B!T:&4@8V]N9FEG(&9I;&4N("HO"B`@("`@("`@)'%U
M97)Y(#T@)'1H:7,M/E]P87)A;7-;)W%U97)Y7VQI<W0G73L*"B`@("`@("`@
M)')E<W5L="`]("1T:&ES+3Y?9&(M/F=E=$%L;"@D<75E<GDL(&YU;&PL($1"
M7T9%5$-(34]$15]/4D1%4D5$*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@("`@('T*"B`@("`@("`@+RH@3&]O<"!T:')O=6=H(&%N9"!B=6EL
M9"!R971U<FX@87)R87DN("HO"B`@("`@("`@)'5S97)S(#T@87)R87DH*3L*
M("`@("`@("!F;W)E86-H("@D<F5S=6QT(&%S("1A<BD@>PH@("`@("`@("`@
M("`D=7-E<G-;72`]("1A<ELP73L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D=7-E<G,["B`@("!]"@I]"@````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O075T:"]K;VQA8BYP:'``````````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#<Q,#,@,3`U,34T,S,W
M-#`@,#(R,#0W`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+T%U=&@O:6UA<"YP
M:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TAI<W1O<GDN<&AP)SL*"B\J*@H@
M*B!+;VQA8B!I;7!L96UE;G1A=&EO;B!O9B!T:&4@2&]R9&4@875T:&5N=&EC
M871I;VX@<WES=&5M+B!$97)I=F5S(&9R;VT@=&AE"B`J($%U=&A?:6UA<"!)
M34%0(&%U=&AE;G1I8V%T:6]N(&]B:F5C="P@86YD('-I;7!L>2!P<F]V:61E
M<R!P87)A;65T97)S('1O(&ET"B`J(&)A<V5D(&]N('1H92!G;&]B86P@2V]L
M86(@8V]N9FEG=7)A=&EO;BX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO075T
M:"]!=71H+VMO;&%B+G!H<"QV(#$N,2XQ,"XX(#(P,#8O,#,O,#,@,C,Z,#`Z
M,C@@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!3='5A
M<G0@0FEN9V4@/',N8FEN9V5`8V]D969U<VEO;BYC;RYZ83X*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@(%-T=6%R="!":6YG92`\<RYB:6YG94!C;V1E
M9G5S:6]N+F-O+GIA/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA
M9V4@2&]R9&5?075T:`H@*B\*8VQA<W,@075T:%]K;VQA8B!E>'1E;F1S($%U
M=&A?:6UA<"!["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W($MO
M;&%B(&%U=&AE;G1I8V%T:6]N(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R
M86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO
M;B!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!!=71H7VMO;&%B
M*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1P87)A;7-;)VAO
M<W1S<&5C)UT@/2`D1TQ/0D%,4ULG8V]N9B==6R=K;VQA8B==6R=I;6%P)UU;
M)W-E<G9E<B==.PH@("`@("`@("1P87)A;7-;)W!O<G0G72`]("1'3$]"04Q3
M6R=C;VYF)UU;)VMO;&%B)UU;)VEM87`G75LG<&]R="==.PH@("`@("`@("1P
M87)A;7-;)W!R;W1O8V]L)UT@/2`G:6UA<"]N;W1L<R]N;W9A;&ED871E+6-E
M<G0G.PH*("`@("`@("!P87)E;G0Z.D%U=&A?:6UA<"@D<&%R86US*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($9I;F0@;W5T(&EF(&$@<V5T(&]F(&QO9VEN
M(&-R961E;G1I86QS(&%R92!V86QI9"X*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@
M("`@("!4:&4@=7-E<DED('1O(&-H96-K+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1C<F5D96YT:6%L<R`@06X@87)R87D@;V8@;&]G:6X@8W)E9&5N=&EA;',N
M($9O<B!+;VQA8BP*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('1H:7,@;75S="!C;VYT86EN(&$@<&%S<W=O<F0@96YT<GDN"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@8W)E
M9&5N=&EA;',@87)E('9A;&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!?875T
M:&5N=&EC871E*"1U<V5R260L("1C<F5D96YT:6%L<RD*("`@('L*("`@("`@
M("!G;&]B86P@)&-O;F8["@H@("`@("`@("1L;V=I;E]O:R`]('!A<F5N=#HZ
M7V%U=&AE;G1I8V%T92@D=7-E<DED+"`D8W)E9&5N=&EA;',I.PH*("`@("`@
M("!I9B`H)&-O;F9;)V%U=&@G75LG<&%R86US)UU;)VQO9VEN7V)L;V-K)UT@
M(3T@,2D@>PH@("`@("`@("`@("`O+R!2971U<FX@:68@9F5A='5R92!I<R!D
M:7-A8FQE9"X*("`@("`@("`@("`@<F5T=7)N("1L;V=I;E]O:SL*("`@("`@
M("!]"@H@("`@("`@("1H:7-T;W)Y(#T@)DAO<F1E7TAI<W1O<GDZ.G-I;F=L
M971O;B@I.PH*("`@("`@("`D:&ES=&]R>5]I9&5N=&EF:65R(#T@(B1U<V5R
M261`;&]G:6YS+FMO;&%B(CL*("`@("`@("`D:&ES=&]R>5]L;V<@/2`D:&ES
M=&]R>2T^9V5T2&ES=&]R>2@D:&ES=&]R>5]I9&5N=&EF:65R*3L*("`@("`@
M("`D:&ES=&]R>5]L:7-T(#T@87)R87DH*3L*"B`@("`@("`@+R\@17AT<F%C
M="!H:7-T;W)Y(&QI<W0@9G)O;2!L;V<N"B`@("`@("`@:68@*"1H:7-T;W)Y
M7VQO9R`F)B`A:7-?82@D:&ES=&]R>5]L;V<L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@)&1A=&$@/2`D:&ES=&]R>5]L;V<M/F=E=$1A=&$H*3L*
M("`@("`@("`@("`@:68@*"%E;7!T>2@D9&%T82DI('L*("`@("`@("`@("`@
M("`@("1E;G1R>2`](&%R<F%Y7W-H:69T*"1D871A*3L*("`@("`@("`@("`@
M("`@("1H:7-T;W)Y7VQI<W0@/2`D96YT<GE;)VAI<W1O<GE?;&ES="==.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!#86QC=6QA=&4@
M=&AE('1I;64@<F%N9V4N"B`@("`@("`@)'-T87)T7W1I;64@/2`H=&EM92@I
M("T@)&-O;F9;)V%U=&@G75LG<&%R86US)UU;)VQO9VEN7V)L;V-K7W1I;64G
M72`J(#8P*3L*"B`@("`@("`@)&YE=U]H:7-T;W)Y7VQI<W0@/2!A<G)A>2@I
M.PH@("`@("`@("1C;W5N="`](#`["@H@("`@("`@("\O($-O<'D@86YD(&-O
M=6YT(&%L;"!R96QE=F%N="!T:6UE<W1A;7!S+@H@("`@("`@(&9O<F5A8V@@
M*"1H:7-T;W)Y7VQI<W0@87,@)&5N=')Y*2!["B`@("`@("`@("`@("1T:6UE
M<W1A;7`@/2`D96YT<GE;("=T:6UE<W1A;7`G(%T["@H@("`@("`@("`@("!I
M9B`H)'1I;65S=&%M<"`^("1S=&%R=%]T:6UE*2!["B`@("`@("`@("`@("`@
M("`D;F5W7VAI<W1O<GE?;&ES=%M=(#T@)&5N=')Y.PH@("`@("`@("`@("`@
M("`@)&-O=6YT*RL["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("1M87A?8V]U;G0@/2`D8V]N9ELG875T:"==6R=P87)A;7,G75LG;&]G:6Y?
M8FQO8VM?8V]U;G0G73L*"B`@("`@("`@:68@*"1C;W5N="`^("1M87A?8V]U
M;G0@?'P@(21L;V=I;E]O:RD@>PH@("`@("`@("`@("`O+R!!9&0@96YT<GD@
M9F]R(&-U<G)E;G0@9F%I;&5D(&QO9VEN+@H@("`@("`@("`@("`D96YT<GD@
M/2!A<G)A>2@I.PH@("`@("`@("`@("`D96YT<GE;("=T:6UE<W1A;7`G(%T@
M/2!T:6UE*"D["B`@("`@("`@("`@("1N97=?:&ES=&]R>5]L:7-T6UT@/2`D
M96YT<GD["@H@("`@("`@("`@("`O+R!7<FET92!B86-K(&AI<W1O<GDN"B`@
M("`@("`@("`@("1H:7-T;W)Y+3YL;V<H)&AI<W1O<GE?:61E;G1I9FEE<BP@
M87)R87DH)V%C=&EO;B<@/3X@)V%D9"<L("=W:&\G(#T^("1U<V5R260L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VAI<W1O<GE?;&ES="<@/3X@)&YE=U]H:7-T;W)Y7VQI<W0I+"!T
M<G5E*3L*"B`@("`@("`@("`@(&EF("@D8V]U;G0@/B`D;6%X7V-O=6YT*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%
M05-/3E]-15-304=%+"!?*")4;V\@;6%N>2!I;G9A;&ED(&QO9VEN<R!D=7)I
M;F<@=&AE(&QA<W0@;6EN=71E<RXB*2D["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%
M05-/3E]"041,3T=)3BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;&]G:6Y?
M;VL["B`@("!]"@I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O075T
M:"]S<6PN<&AP````````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P-#`U-#0@,3`U,34T,S,W-#`@,#(Q-38T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@075T
M:%]S<6P@8VQA<W,@<')O=FED97,@82!344P@:6UP;&5M96YT871I;VX@;V8@
M=&AE($AO<F1E"B`J(&%U=&AE;G1I8V%T:6]N('-Y<W1E;2X*("H*("H@4F5Q
M=6ER960@<&%R86UE=&5R<SH\<')E/@H@*B`@("=P:'!T>7!E)R`@("`@(%1H
M92!D871A8F%S92!T>7!E("AI92X@)W!G<W%L)RP@)VUY<W%L)RP@971C+BDN
M/"]P<F4^"B`J"B`J($]P=&EO;F%L('!A<F%M971E<G,Z/'!R93X*("H@("`G
M96YC<GEP=&EO;B<@("`@("`@("`@("`@5&AE(&5N8W)Y<'1I;VX@=&\@=7-E
M('1O('-T;W)E('1H92!P87-S=V]R9"!I;@H@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!T:&4@=&%B;&4@*&4N9RX@<&QA:6XL(&-R>7!T+"!M9#4M
M:&5X+`H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!M9#4M8F%S938T
M+"!S;60U+"!S:&$L('-S:&$L(&%P<FUD-2DN"B`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@($1%1D%53%0Z("=M9#4M:&5X)PH@*B`@("=S:&]W7V5N
M8W)Y<'1I;VXG("`@("`@("!7:&5T:&5R(&]R(&YO="!T;R!P<F5P96YD('1H
M92!E;F-R>7!T:6]N(&EN('1H90H@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!P87-S=V]R9"!F:65L9"X*("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@1$5&055,5#H@)V9A;'-E)PH@*B`@("=P87-S=V]R9%]F:65L9"<@
M("`@("`@("!4:&4@;F%M92!O9B!T:&4@<&%S<W=O<F0@9FEE;&0@:6X@=&AE
M(&%U=&@@=&%B;&4N"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@($1%
M1D%53%0Z("=U<V5R7W!A<W,G"B`J("`@)W1A8FQE)R`@("`@("`@("`@("`@
M("`@(%1H92!N86UE(&]F('1H92!344P@=&%B;&4@=&\@=7-E(&EN("=D871A
M8F%S92<N"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@($1%1D%53%0Z
M("=H;W)D95]U<V5R<R<*("H@("`G=7-E<FYA;65?9FEE;&0G("`@("`@("`@
M5&AE(&YA;64@;V8@=&AE('5S97)N86UE(&9I96QD(&EN('1H92!A=71H('1A
M8FQE+@H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!$149!54Q4.B`G
M=7-E<E]U:60G"B`J("`@)W-O9G1?97AP:7)A=&EO;E]F:65L9"<@(%1H92!N
M86UE(&]F('1H92!F:65L9"!C;VYT86EN:6YG(&$@9&%T92!A9G1E<@H@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!W:&EC:"!T:&4@<WES=&5M('=I
M;&P@<F5Q=65S="!T:&4@=7-E<B!C:&%N9V4@:&ES"B`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&]R(&AE<B!P87-S=V]R9"X*("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@1$5&055,5#H@;F]N90H@*B`@("=H87)D7V5X
M<&ER871I;VY?9FEE;&0G("!4:&4@;F%M92!O9B!T:&4@9FEE;&0@8V]N=&%I
M;FEN9R!A(&1A=&4@869T97(*("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@=VAI8V@@=&AE(&%C8V]U;G0@:7,@;F\@;&]N9V5R('9A;&ED(&%N9"!T
M:&4@=7-E<@H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!W:6QL(&YO
M="!B92!A8FQE('1O(&QO9R!I;B!A="!A;&PN"B`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@($1%1D%53%0Z(&YO;F4\+W!R93X*("H*("H@4F5Q=6ER
M960@8GD@<V]M92!D871A8F%S92!I;7!L96UE;G1A=&EO;G,Z/'!R93X*("H@
M("`G:&]S='-P96,G("`@("!4:&4@:&]S=&YA;64@;V8@=&AE(&1A=&%B87-E
M('-E<G9E<BX*("H@("`G<')O=&]C;VPG("`@("!4:&4@8V]M;75N:6-A=&EO
M;B!P<F]T;V-O;"`H)W1C<"<L("=U;FEX)RP@971C+BDN"B`J("`@)V1A=&%B
M87-E)R`@("`@5&AE(&YA;64@;V8@=&AE(&1A=&%B87-E+@H@*B`@("=U<V5R
M;F%M92<@("`@(%1H92!U<V5R;F%M92!W:71H('=H:6-H('1O(&-O;FYE8W0@
M=&\@=&AE(&1A=&%B87-E+@H@*B`@("=P87-S=V]R9"<@("`@(%1H92!P87-S
M=V]R9"!A<W-O8VEA=&5D('=I=&@@)W5S97)N86UE)RX*("H@("`G;W!T:6]N
M<R<@("`@("!!9&1I=&EO;F%L(&]P=&EO;G,@=&\@<&%S<R!T;R!T:&4@9&%T
M86)A<V4N"B`J("`@)W!O<G0G("`@("`@("`@5&AE('!O<G0@;VX@=VAI8V@@
M=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N"B`J("`@)W1T>2<@("`@("`@
M("`@5&AE(%1462!O;B!W:&EC:"!T;R!C;VYN96-T('1O('1H92!D871A8F%S
M92X\+W!R93X*("H*("H@5&AE('1A8FQE('-T<G5C='5R92!F;W(@=&AE($%U
M=&@@<WES=&5M(&ES(&EN"B`J('-C<FEP=',O<W%L+VAO<F1E7W5S97)S+G-Q
M;"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`L
M=B`Q+C8Y+C$P+C$Y(#(P,#8O,#@O,30@,#(Z-#@Z-#@@8VAU8VL@17AP("0*
M("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H
M=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(
M;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?075T:`H@*B\*8VQA<W,@075T
M:%]S<6P@97AT96YD<R!!=71H('L*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y
M(&]F(&-A<&%B:6QI=&EE<RP@<V\@=&AA="!T:&4@9')I=F5R(&-A;B!R97!O
M<G0@=VAI8V@*("`@("`J(&]P97)A=&EO;G,@:70@<W5P<&]R=',@86YD('=H
M:6-H(&ET(&1O97-N)W0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)&-A<&%B:6QI=&EE<R`](&%R<F%Y*"=A9&0G("`@("`@
M("`@("`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M=7!D871E)R`@("`@("`@/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W)E<V5T<&%S<W=O<F0G(#T^('1R=64L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=R96UO=F4G("`@("`@("`]/B!T<G5E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;&ES="<@("`@("`@("`@
M/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1R86YS
M<&%R96YT)R`@(#T^(&9A;'-E*3L*"B`@("`O*BH*("`@("`J($AA;F1L92!F
M;W(@=&AE(&-U<G)E;G0@9&%T86)A<V4@8V]N;F5C=&EO;BX*("`@("`J"B`@
M("`@*B!`=F%R($1""B`@("`@*B\*("`@('9A<B`D7V1B.PH*("`@("\J*@H@
M("`@("H@0F]O;&5A;B!I;F1I8V%T:6YG('=H971H97(@;W(@;F]T('=E)W)E
M(&-O;FYE8W1E9"!T;R!T:&4@4U%,('-E<G9E<BX*("`@("`J"B`@("`@*B!`
M=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?8V]N;F5C=&5D(#T@9F%L
M<V4["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W(%-13"!A=71H
M96YT:6-A=&EO;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE
M=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@075T:%]S<6PH)'!A<F%M<R`]
M(&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R
M86US.PH@("`@?0H*("`@("\J*@H@("`@("H@1FEN9"!O=70@:68@82!S970@
M;V8@;&]G:6X@8W)E9&5N=&EA;',@87)E('9A;&ED+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'5S97))9"`@("`@(%1H92!U<V5R260@=&\@8VAE8VLN"B`@("`@*B!`<&%R
M86T@87)R87D@)&-R961E;G1I86QS("!4:&4@8W)E9&5N=&EA;',@=&\@=7-E
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N
M;W0@=&AE(&-R961E;G1I86QS(&%R92!V86QI9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@7V%U=&AE;G1I8V%T92@D=7-E<DED+"`D8W)E9&5N=&EA;',I"B`@
M("!["B`@("`@("`@+RH@7V-O;FYE8W0H*2!W:6QL(&1I92!W:71H($AO<F1E
M.CIF871A;"@I('5P;VX@9F%I;'5R92X@*B\*("`@("`@("`D=&AI<RT^7V-O
M;FYE8W0H*3L*"B`@("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*
M("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=314Q%0U0@*B!&4D]-("5S(%=(
M15)%("5S(#T@/R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG=&%B;&4G72P*("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%R86US6R=U<V5R;F%M95]F:65L9"==*3L*("`@("`@("`D=F%L
M=65S(#T@87)R87DH)'5S97))9"D["@H@("`@("`@($AO<F1E.CIL;V=-97-S
M86=E*"=344P@475E<GD@8GD@075T:%]S<6PZ.E]A=71H96YT:6-A=&4H*3H@
M)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)5
M1RD["@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<75E
M<GDL("1V86QU97,I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H
M05542%]214%33TY?1D%)3$5$*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*"B`@("`@("`@)')O=R`]("1R97-U;'0M/F9E=&-H4F]W
M*$1"7T=%5$U/1$5?05-33T,I.PH@("`@("`@(&EF("AI<U]A<G)A>2@D<F]W
M*2D@>PH@("`@("`@("`@("`D<F5S=6QT+3YF<F5E*"D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H05542%]2
M14%33TY?0D%$3$]'24XI.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H*("`@("`@("!I9B`H(21T:&ES+3Y?8V]M<&%R95!A<W-W;W)D
M<R@D<F]W6R1T:&ES+3Y?<&%R86US6R=P87-S=V]R9%]F:65L9"==72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8W)E9&5N=&EA
M;'-;)W!A<W-W;W)D)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V5T075T
M:$5R<F]R*$%55$A?4D5!4T].7T)!1$Q/1TE.*3L*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@)&YO=R`]('1I;64H*3L*
M("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=H87)D7V5X<&ER
M871I;VY?9FEE;&0G72D@)B8*("`@("`@("`@("`@(65M<'1Y*"1R;W=;)'1H
M:7,M/E]P87)A;7-;)VAA<F1?97AP:7)A=&EO;E]F:65L9"==72D@)B8*("`@
M("`@("`@("`@*"1N;W<@/B`D<F]W6R1T:&ES+3Y?<&%R86US6R=H87)D7V5X
M<&ER871I;VY?9FEE;&0G75TI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V5T
M075T:$5R<F]R*$%55$A?4D5!4T].7T584$E2140I.PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1T
M:&ES+3Y?<&%R86US6R=S;V9T7V5X<&ER871I;VY?9FEE;&0G72D@)B8*("`@
M("`@("`@("`@(65M<'1Y*"1R;W=;)'1H:7,M/E]P87)A;7-;)W-O9G1?97AP
M:7)A=&EO;E]F:65L9"==72D@)B8*("`@("`@("`@("`@*"1N;W<@/B`D<F]W
M6R1T:&ES+3Y?<&%R86US6R=S;V9T7V5X<&ER871I;VY?9FEE;&0G75TI*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?875T:$-R961E;G1I86QS6R=C:&%N9V52
M97%U97-T960G72`]('1R=64["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($%D9"!A('-E="!O9B!A=71H
M96YT:6-A=&EO;B!C<F5D96YT:6%L<RX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1U<V5R260@("`@("!4:&4@=7-E<DED('1O(&%D9"X*("`@("`J
M($!P87)A;2!A<G)A>2`D8W)E9&5N=&EA;',@(%1H92!C<F5D96YT:6%L<R!T
M;R!A9&0N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S
M=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@861D57-E<B@D=7-E<DED+"`D8W)E9&5N=&EA
M;',I"B`@("!["B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@
M("\J($)U:6QD('1H92!344P@<75E<GDN("HO"B`@("`@("`@)'%U97)Y(#T@
M<W!R:6YT9B@G24Y315)4($E.5$\@)7,@*"5S+"`E<RD@5D%,5453("@_+"`_
M*2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG
M=&%B;&4G72P*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=U<V5R;F%M95]F:65L9"==+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D7V9I96QD)UTI.PH@("`@("`@
M("1V86QU97,@/2!A<G)A>2@D=7-E<DED+`H@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^9V5T0W)Y<'1E9%!A<W-W;W)D*"1C<F5D96YT:6%L<ULG
M<&%S<W=O<F0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG96YC
M<GEP=&EO;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=S:&]W7V5N8W)Y<'1I
M;VXG72DI.PH*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y
M(&)Y($%U=&A?<W%L.CIA9&15<V5R*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?
M+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`D<F5S=6QT
M(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*("`@("`@
M("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!5<&1A=&4@82!S970@;V8@
M875T:&5N=&EC871I;VX@8W)E9&5N=&EA;',N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;VQD240@("`@("`@(%1H92!O;&0@=7-E<DED+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;F5W240@("`@("`@(%1H92!N97<@=7-E<DED
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("`D8W)E9&5N=&EA;',@(%1H92!N97<@
M8W)E9&5N=&EA;',*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E
M(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!U<&1A=&55<V5R*"1O;&1)1"P@)&YE
M=TE$+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@+RH@7V-O;FYE8W0H
M*2!W:6QL(&1I92!W:71H($AO<F1E.CIF871A;"@I('5P;VX@9F%I;'5R92X@
M*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@+RH@0G5I
M;&0@=&AE(%-13"!Q=65R>2X@*B\*("`@("`@("`D='5P;&4@/2!A<G)A>2@I
M.PH@("`@("`@("1T=7!L95LD=&AI<RT^7W!A<F%M<ULG=7-E<FYA;65?9FEE
M;&0G75T@/2`D;F5W240["B`@("`@("`@)'1U<&QE6R1T:&ES+3Y?<&%R86US
M6R=P87-S=V]R9%]F:65L9"==72`]"B`@("`@("`@("`@("1T:&ES+3YG971#
M<GEP=&5D4&%S<W=O<F0H)&-R961E;G1I86QS6R=P87-S=V]R9"==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=E;F-R>7!T:6]N)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W-H;W=?96YC<GEP=&EO;B==*3L*
M"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%R86US6R=S;V9T7V5X<&ER
M871I;VY?=VEN9&]W)UTI*2!["B`@("`@("`@("`@(&EF("@A96UP='DH)'1H
M:7,M/E]P87)A;7-;)W-O9G1?97AP:7)A=&EO;E]F:65L9"==*2D@>PH@("`@
M("`@("`@("`@("`@)'1U<&QE6R1T:&ES+3Y?<&%R86US6R=S;V9T7V5X<&ER
M871I;VY?9FEE;&0G75T@/2!N=6QL.PH@("`@("`@("`@("!]"B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&1A=&4@/2!T:6UE*"D["B`@("`@("`@
M("`@("1D871E82`](&QO8V%L=&EM92@D9&%T92P@=')U92D["B`@("`@("`@
M("`@("1D871E(#T@;6MT:6UE*"1D871E85LG=&U?:&]U<B==+"`D9&%T96%;
M)W1M7VUI;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&%T96%;
M)W1M7W-E8R==+"`D9&%T96%;)W1M7VUO;B==("L@,2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&1A=&5A6R=T;5]M9&%Y)UT@*R`D=&AI<RT^7W!A
M<F%M<ULG<V]F=%]E>'!I<F%T:6]N7W=I;F1O=R==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9&%T96%;)W1M7WEE87(G72D["@H@("`@("`@("`@
M("`D='5P;&5;)'1H:7,M/E]P87)A;7-;)W-O9G1?97AP:7)A=&EO;E]F:65L
M9"==72`]("1D871E.PH*("`@("`@("`@("`@9VQO8F%L("1N;W1I9FEC871I
M;VX["B`@("`@("`@("`@(&EF("@A96UP='DH)&YO=&EF:6-A=&EO;BDI('L*
M("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W1R9G1I;64H
M7R@B3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+B(I+"`D9&%T92DL
M("=H;W)D92YM97-S86=E)RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M(&EF("AE;7!T>2@D=&AI<RT^7W!A<F%M<ULG:&%R9%]E>'!I<F%T:6]N7W=I
M;F1O=R==*2D@>PH@("`@("`@("`@("`@("`@)'1U<&QE6R1T:&ES+3Y?<&%R
M86US6R=H87)D7V5X<&ER871I;VY?9FEE;&0G75T@/2!N=6QL.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&1A=&5A(#T@;&]C86QT
M:6UE*"1D871E+"!T<G5E*3L*("`@("`@("`@("`@("`@("1D871E(#T@;6MT
M:6UE*"1D871E85LG=&U?:&]U<B==+"`D9&%T96%;)W1M7VUI;B==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&5A6R=T;5]S96,G72P@
M)&1A=&5A6R=T;5]M;VXG72`K(#$L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9&%T96%;)W1M7VUD87DG72`K("1T:&ES+3Y?<&%R86US6R=S
M;V9T7V5X<&ER871I;VY?=VEN9&]W)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D9&%T96%;)W1M7WEE87(G72D["@H@("`@("`@("`@("`@
M("`@)'1U<&QE6R1T:&ES+3Y?<&%R86US6R=H87)D7V5X<&ER871I;VY?9FEE
M;&0G75T@/2`D9&%T93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5Q=6ER95]O;F-E("=(;W)D92]344PN<&AP)SL*("`@("`@("`D<75E
M<GD@/2!S<')I;G1F*"=54$1!5$4@)7,@4T54("5S(%=(15)%("5S(#T@/R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B
M;&4G72P*("`@("`@("`@("`@("`@("`@("`@("`@($AO<F1E7U-13#HZ=7!D
M871E5F%L=65S*"1T:&ES+3Y?9&(L("1T=7!L92DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;65?9FEE;&0G72D[
M"B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"1O;&1)1"D["@H@("`@("`@($AO
M<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@075T:%]S<6PZ=7!D871E
M57-E<B@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T1%0E5'*3L*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U
M97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@("`@("`@:68@*&ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S
M<V%G92@D<F5S=6QT+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T52
M4BD["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!297-E
M="!A('5S97(G<R!P87-S=V]R9"X@57-E9"!F;W(@97AA;7!L92!W:&5N('1H
M92!U<V5R(&1O97,@;F]T"B`@("`@*B!R96UE;6)E<B!T:&4@97AI<W1I;F<@
M<&%S<W=O<F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<E]I
M9"`@5&AE('5S97(@:60@9F]R('=H:6-H('1O(')E<V5T('1H92!P87-S=V]R
M9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@;F5W('!A<W-W
M;W)D(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;@H@("`@
M("H@("`@("`@("`@("`@("`@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F5S971087-S=V]R9"@D=7-E<E]I9"D*("`@('L*("`@("`@("`O*B!?
M8V]N;F5C="@I('=I;&P@9&EE('=I=&@@2&]R9&4Z.F9A=&%L*"D@=7!O;B!F
M86EL=7)E+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@
M("`O*B!'970@82!N97<@<F%N9&]M('!A<W-W;W)D+B`J+PH@("`@("`@("1P
M87-S=V]R9"`]($%U=&@Z.F=E;E)A;F1O;5!A<W-W;W)D*"D["@H@("`@("`@
M("\J($)U:6QD('1H92!344P@<75E<GDN("HO"B`@("`@("`@)'%U97)Y(#T@
M<W!R:6YT9B@G55!$051%("5S(%-%5"`E<R`](#\@5TA%4D4@)7,@/2`_)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L
M92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)W!A<W-W;W)D7V9I96QD)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!A<F%M<ULG=7-E<FYA;65?9FEE;&0G72D["B`@("`@("`@)'9A
M;'5E<R`](&%R<F%Y*"1T:&ES+3YG971#<GEP=&5D4&%S<W=O<F0H)'!A<W-W
M;W)D+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=E;F-R>7!T:6]N
M)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W-H;W=?96YC<GEP=&EO;B==*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@)'5S97)?:60I.PH*("`@("`@("!(
M;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($%U=&A?<W%L.CIR97-E
M=%!A<W-W;W)D*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D
M8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1P87-S=V]R9#L*
M("`@('T*"B`@("`O*BH*("`@("`J($1E;&5T92!A('-E="!O9B!A=71H96YT
M:6-A=&EO;B!C<F5D96YT:6%L<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1U<V5R260@(%1H92!U<V5R260@=&\@9&5L971E+@H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@("`@("`@4W5C8V5S<R!O<B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F55<V5R*"1U<V5R260I"B`@
M("!["B`@("`@("`@+RH@7V-O;FYE8W0H*2!W:6QL(&1I92!W:71H($AO<F1E
M.CIF871A;"@I('5P;VX@9F%I;'5R92X@*B\*("`@("`@("`D=&AI<RT^7V-O
M;FYE8W0H*3L*"B`@("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*
M("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=$14Q%5$4@1E)/32`E<R!72$52
M12`E<R`](#\G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG=7-E<FYA;65?9FEE;&0G72D["B`@("`@("`@)'9A;'5E
M<R`](&%R<F%Y*"1U<V5R260I.PH*("`@("`@("!(;W)D93HZ;&]G365S<V%G
M92@G4U%,(%%U97)Y(&)Y($%U=&A?<W%L.CIR96UO=F55<V5R*"DZ("<@+B`D
M<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*
M("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D
M=F%L=65S*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YR96UO=F55<V5R1&%T82@D=7-E<DED
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($QI<W0@86QL('5S97)S(&EN('1H
M92!S>7-T96TN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&%R
M<F%Y(&]F('5S97))9',L(&]R(&9A;'-E(&]N(&9A:6QU<F4O=6YS=7!P;W)T
M960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W15<V5R<R@I"B`@("!["B`@
M("`@("`@+RH@7V-O;FYE8W0H*2!W:6QL(&1I92!W:71H($AO<F1E.CIF871A
M;"@I('5P;VX@9F%I;'5R92X@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H
M*3L*"B`@("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*("`@("`@
M("`D<75E<GD@/2!S<')I;G1F*"=314Q%0U0@)7,@1E)/32`E<R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;65?
M9FEE;&0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=T86)L92==*3L*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-1
M3"!1=65R>2!B>2!!=71H7W-Q;#HZ;&ES=%5S97)S*"DZ("<@+B`D<75E<GDL
M(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@
M("!R971U<FX@)'1H:7,M/E]D8BT^9V5T0V]L*"1Q=65R>2D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#:&5C:W,@:68@82!U<V5R260@97AI<W1S(&EN('1H
M92!S:7-T96TN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T
M:&5R(&]R(&YO="!T:&4@=7-E<DED(&%L<F5A9'D@97AI<W1S+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!E>&ES=',H)'5S97))9"D*("`@('L*("`@("`@("`O
M*B!?8V]N;F5C="@I('=I;&P@9&EE('=I=&@@2&]R9&4Z.F9A=&%L*"D@=7!O
M;B!F86EL=7)E+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@
M("`@("`O*B!"=6EL9"!T:&4@4U%,('%U97)Y+B`J+PH@("`@("`@("1Q=65R
M>2`]('-P<FEN=&8H)U-%3$5#5"`E<R!&4D]-("5S(%=(15)%("5S(#T@/R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E
M<FYA;65?9FEE;&0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=T86)L92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)W5S97)N86UE7V9I96QD)UTI.PH@("`@("`@("1V
M86QU97,@/2!A<G)A>2@D=7-E<DED*3L*"B`@("`@("`@2&]R9&4Z.FQO9TUE
M<W-A9V4H)U-13"!1=65R>2!B>2!!=71H7W-Q;#HZ97AI<W1S*"DZ("<@+B`D
M<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*
M("`@("`@("!R971U<FX@)'1H:7,M/E]D8BT^9V5T3VYE*"1Q=65R>2P@)'9A
M;'5E<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VUP87)E(&%N(&5N8W)Y
M<'1E9"!P87-S=V]R9"!T;R!A('!L86EN=&5X="!S=')I;F<@=&\@<V5E(&EF
M"B`@("`@*B!T:&5Y(&UA=&-H+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&5N8W)Y<'1E9"`@
M5&AE(&-R>7!T960@<&%S<W=O<F0@=&\@8V]M<&%R92!A9V%I;G-T+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<&QA:6YT97AT("!4:&4@<&QA:6YT97AT('!A
M<W-W;W)D('1O('9E<FEF>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@(%1R=64@:68@;6%T8VAE9"P@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?8V]M<&%R95!A<W-W;W)D<R@D96YC<GEP=&5D+"`D
M<&QA:6YT97AT*0H@("`@>PH@("`@("`@(')E='5R;B`D96YC<GEP=&5D(#T]
M("1T:&ES+3YG971#<GEP=&5D4&%S<W=O<F0H)'!L86EN=&5X="P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1E;F-R>7!T960L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG96YC
M<GEP=&EO;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W-H;W=?96YC
M<GEP=&EO;B==*3L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O
M(&]P96X@82!C;VYN96-T:6]N('1O('1H92!344P@<V5R=F5R+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYN96-T*"D*
M("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]C;VYN96-T960I('L*("`@("`@
M("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("!(;W)D93HZ
M87-S97)T1')I=F5R0V]N9FEG*"1T:&ES+3Y?<&%R86US+"`G875T:"<L(&%R
M<F%Y*"=P:'!T>7!E)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G875T:&5N=&EC871I;VX@4U%,)RD["@H@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]P87)A;7-;)V1A=&%B87-E)UTI*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=D871A8F%S92==(#T@)R<["B`@("`@("`@?0H@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;)W5S97)N86UE)UTI
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=U<V5R;F%M92==(#T@
M)R<["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A
M;7-;)W!A<W-W;W)D)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=P87-S=V]R9"==(#T@)R<["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UTI*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==(#T@)R<["B`@("`@("`@?0H@
M("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W!A<F%M<ULG96YC<GEP=&EO;B==
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG96YC<GEP=&EO;B==
M(#T@)VUD-2UH97@G.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?<&%R86US6R=S:&]W7V5N8W)Y<'1I;VXG72DI('L*("`@("`@("`@
M("`@)'1H:7,M/E]P87)A;7-;)W-H;W=?96YC<GEP=&EO;B==(#T@9F%L<V4[
M"B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W!A<F%M<ULG
M=&%B;&4G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE
M)UT@/2`G:&]R9&5?=7-E<G,G.PH@("`@("`@('T*("`@("`@("!I9B`H96UP
M='DH)'1H:7,M/E]P87)A;7-;)W5S97)N86UE7V9I96QD)UTI*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=U<V5R;F%M95]F:65L9"==(#T@)W5S
M97)?=6ED)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG=7-E<FYA;65?9FEE;&0G72`](%-T<FEN9SHZ;&]W97(H)'1H
M:7,M/E]P87)A;7-;)W5S97)N86UE7V9I96QD)UTI.PH@("`@("`@('T*("`@
M("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D7V9I96QD
M)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=P87-S=V]R9%]F
M:65L9"==(#T@)W5S97)?<&%S<R<["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D7V9I96QD)UT@/2!3=')I
M;F<Z.FQO=V5R*"1T:&ES+3Y?<&%R86US6R=P87-S=V]R9%]F:65L9"==*3L*
M("`@("`@("!]"@H@("`@("`@("\J($-O;FYE8W0@=&\@=&AE(%-13"!S97)V
M97(@=7-I;F<@=&AE('-U<'!L:65D('!A<F%M971E<G,N("HO"B`@("`@("`@
M:6YC;'5D95]O;F-E("=$0BYP:'`G.PH@("`@("`@("1T:&ES+3Y?9&(@/2`F
M1$(Z.F-O;FYE8W0H)'1H:7,M/E]P87)A;7,L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@G<&5R<VES=&5N="<@/3X@(65M<'1Y
M*"1T:&ES+3Y?<&%R86US6R=P97)S:7-T96YT)UTI*2D["B`@("`@("`@:68@
M*&ES7V$H)'1H:7,M/E]D8BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!(;W)D93HZ9F%T86PH7R@B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E
M<G9E<BXB*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@
M("`@("\O(%-E="!$0B!P;W)T86)I;&ET>2!O<'1I;VYS+@H@("`@("`@('-W
M:71C:"`H)'1H:7,M/E]D8BT^<&AP='EP92D@>PH@("`@("`@(&-A<V4@)VUS
M<W%L)SH*("`@("`@("`@("`@)'1H:7,M/E]D8BT^<V5T3W!T:6]N*"=P;W)T
M86)I;&ET>2<L($1"7U!/4E1!0DE,25197TQ/5T520T%312!\($1"7U!/4E1!
M0DE,25197T524D]24R!\($1"7U!/4E1!0DE,25197U)44DE-*3L*("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@)'1H
M:7,M/E]D8BT^<V5T3W!T:6]N*"=P;W)T86)I;&ET>2<L($1"7U!/4E1!0DE,
M25197TQ/5T520T%312!\($1"7U!/4E1!0DE,25197T524D]24RD["B`@("`@
M("`@?0H*("`@("`@("`D=&AI<RT^7V-O;FYE8W1E9"`]('1R=64["B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+VMR8C4N
M<&AP````````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-3<R
M-R`Q,#4Q-30S,S<T,"`P,C$V,S0`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J(%1H92!!=71H7VMR8C4@
M8VQA<W,@<')O=FED97,@86X@:V5R8F5R;W,@:6UP;&5M96YT871I;VX@;V8@
M=&AE($AO<F1E"B`J(&%U=&AE;G1I8V%T:6]N('-Y<W1E;2X*("H*("H@5&AI
M<R!D<FEV97(@<F5Q=6ER97,@=&AE("=K<F(U)R!02%`@97AT96YS:6]N('1O
M(&)E(&QO861E9"X*("H@5&AE(&UO9'5L92!C86X@8F4@9&]W;FQO861E9"!H
M97)E.@H@*B`@(&AT='`Z+R]W=W<N:&]R9&4N;W)G+V1O=VYL;V%D+W!H<"]P
M:'!K<F(U+G1A<BYG>@H@*@H@*B!297%U:7)E9"!P87)A;65T97)S.CQP<F4^
M"B`J("`@3F]N92X\+W!R93X*("H*("H@26YS=&5A9"P@2V5R8F5R;W,@;75S
M="!B92!C;W)R96-T;'D@8V]N9FEG=7)E9"!O;B!Y;W5R('-Y<W1E;2`H92YG
M+@H@*B`@("]E=&,O:W)B-2YC;VYF*2!F;W(@=&AI<R!C;&%S<R!T;R!W;W)K
M(&-O<G)E8W1L>2X*("H*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO075T:"]!
M=71H+VMR8C4N<&AP+'8@,2XR,2XQ,"XX(#(P,#8O,#$O,#$@,C$Z,C@Z,#<@
M:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EC:&%E;"!3
M;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z
M0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!(;W)D92`R+C(*
M("H@0'!A8VMA9V4@2&]R9&5?075T:`H@*B\*8VQA<W,@075T:%]K<F(U(&5X
M=&5N9',@075T:"!["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!C87!A
M8FEL:71I97,L('-O('1H870@=&AE(&1R:79E<B!C86X@<F5P;W)T('=H:6-H
M"B`@("`@*B!O<&5R871I;VYS(&ET('-U<'!O<G1S(&%N9"!W:&EC:"!I="!D
M;V5S;B=T+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1C87!A8FEL:71I97,@/2!A<G)A>2@G861D)R`@("`@("`@("`@/3X@
M9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U<&1A=&4G
M("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W)E<V5T<&%S<W=O<F0G(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G<F5M;W9E)R`@("`@("`@/3X@9F%L<V4L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=L:7-T)R`@("`@("`@("`]/B!F
M86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1R86YS<&%R
M96YT)R`@(#T^(&9A;'-E*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@
M82!N97<@2V5R8F5R;W,@875T:&5N=&EC871I;VX@;V)J96-T+@H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN
M9R!C;VYN96-T:6]N('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M($%U=&A?:W)B-2@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!I
M9B`H(55T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G:W)B-2<I*2!["B`@("`@("`@
M("`@($AO<F1E.CIF871A;"A?*")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@
M97AT96YS:6]N(&YO="!F;W5N9"XB*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL*
M("`@('T*"B`@("`O*BH*("`@("`J($9I;F0@;W5T(&EF(&$@<V5T(&]F(&QO
M9VEN(&-R961E;G1I86QS(&%R92!V86QI9"X*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R
M260@("`@("!4:&4@=7-E<DED('1O(&-H96-K+@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1C<F5D96YT:6%L<R`@06X@87)R87D@;V8@;&]G:6X@8W)E9&5N=&EA
M;',N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!&;W(@:V5R
M8F5R;W,L('1H:7,@;75S="!C;VYT86EN(&$@<&%S<W=O<F0*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&5N=')Y+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&-R961E;G1I
M86QS(&%R92!V86QI9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V%U=&AE;G1I
M8V%T92@D=7-E<DED+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@:68@
M*&5M<'1Y*"1C<F5D96YT:6%L<ULG<&%S<W=O<F0G72DI('L*("`@("`@("`@
M("`@2&]R9&4Z.F9A=&%L*%\H(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+
M97)B97)O<R!A=71H96YT:6-A=&EO;BXB*2P@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("!]"@H@("`@("`@("1R97-U;'0@/2!K<F(U7VQO9VEN*"1U
M<V5R260L("1C<F5D96YT:6%L<ULG<&%S<W=O<F0G72D["@H@("`@("`@(&EF
M("@D<F5S=6QT(#T]/2!+4D(U7T]+*2!["B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@D<F5S=6QT
M(#T]/2!+4D(U7T)!1%]005-35T]21"D@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]S971!=71H17)R;W(H05542%]214%33TY?34534T%'12P@7R@B0F%D
M(&ME<F)E<F]S('!A<W-W;W)D+B(I*3L*("`@("`@("`@("`@?2!E;'-E:68@
M*"1R97-U;'0@/3T]($M20C5?0D%$7U5315(I('L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<V5T075T:$5R<F]R*$%55$A?4D5!4T].7TU%4U-!1T4L(%\H
M(D)A9"!K97)B97)O<R!U<V5R;F%M92XB*2D["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(
M7U)%05-/3E]-15-304=%+"!?*")+97)B97)O<R!S97)V97(@<F5J96-T960@
M875T:&5N=&EC871I;VXN(BDI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"@I]"@``````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O;6-A;"YP:'``````````````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`U-C`S(#$P-3$U-#,S-S0P(#`R
M,38W-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@5&AE($%U=&A?;6-A;"!C;&%S<R!P<F]V:61E<R!A
M;B!-0T%,(&EM<&QE;65N=&%T:6]N(&]F('1H92!(;W)D90H@*B!A=71H96YT
M:6-A=&EO;B!S>7-T96TN"B`J"B`J($U#04P@2&]M92!086=E.B!H='1P.B\O
M;6-A;"YC:&5K+F-O;2\*("H*("H@4F5Q=6ER960@<&%R86UE=&5R<SH\<')E
M/@H@*B`@("=C86QE;F1A<B<@(%1H92!-0T%,(&-A;&5N9&%R(&YA;64N/"]P
M<F4^"B`J"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L
M+G!H<"QV(#$N,C<N,3`N.2`R,#`V+S`Q+S`Q(#(Q.C(X.C`W(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\
M8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@
M($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]!=71H"B`J+PIC;&%S<R!!
M=71H7VUC86P@97AT96YD<R!!=71H('L*"B`@("`O*BH*("`@("`J($%N(&%R
M<F%Y(&]F(&-A<&%B:6QI=&EE<RP@<V\@=&AA="!T:&4@9')I=F5R(&-A;B!R
M97!O<G0@=VAI8V@*("`@("`J(&]P97)A=&EO;G,@:70@<W5P<&]R=',@86YD
M('=H:6-H(&ET(&1O97-N)W0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)&-A<&%B:6QI=&EE<R`](&%R<F%Y*"=A9&0G("`@
M("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W5P9&%T92<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G<F5S971P87-S=V]R9"<@/3X@9F%L<V4L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=R96UO=F4G("`@("`@("`]/B!F
M86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VQI<W0G("`@
M("`@("`@(#T^('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=T<F%N<W!A<F5N="<@("`]/B!F86QS92D["@H@("`@+RHJ"B`@("`@*B!#
M;VYS=')U8W1S(&$@;F5W($U#04P@875T:&5N=&EC871I;VX@;V)J96-T+@H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N
M=&%I;FEN9R!C;VYN96-T:6]N('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U
M;F-T:6]N($%U=&A?;6-A;"@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@
M("`@("!I9B`H(55T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G;6-A;"<I*2!["B`@
M("`@("`@("`@($AO<F1E.CIF871A;"A?*")!=71H7VUC86PZ(%)E<75I<F5D
M($U#04P@97AT96YS:6]N(&YO="!F;W5N9"XB*2P@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*("`@("`@("!]"@H@("`@("`@(&EF("AE;7!T>2@D<&%R86US6R=C
M86QE;F1A<B==*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH7R@B3F\@
M8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO
M;BXB*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@
M("1T:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@
M("`J($9I;F0@;W5T(&EF(&$@<V5T(&]F(&QO9VEN(&-R961E;G1I86QS(&%R
M92!V86QI9"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@("`@("!4:&4@=7-E<DED
M('1O(&-H96-K+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L<R`@
M06X@87)R87D@;V8@;&]G:6X@8W)E9&5N=&EA;',N($9O<B!-0T%,+`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AI<R!M=7-T(&-O;G1A
M:6X@82!P87-S=V]R9"!E;G1R>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%=H971H97(@;W(@;F]T('1H92!C<F5D96YT:6%L<R!A<F4@=F%L
M:60N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A=71H96YT:6-A=&4H)'5S97))
M9"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@("`@("1M8V%L(#T@0&UC86Q?
M;W!E;B@D=&AI<RT^7W!A<F%M<ULG8V%L96YD87(G72P@)'5S97))9"P@)&-R
M961E;G1I86QS6R=P87-S=V]R9"==*3L*"B`@("`@("`@:68@*"1M8V%L*2![
M"B`@("`@("`@("`@($!M8V%L7V-L;W-E*"1M8V%L*3L*("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@0&UC
M86Q?8VQO<V4H)&UC86PI.PH@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%
M<G)O<BA!551(7U)%05-/3E]"041,3T=)3BD["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!,:7-T
M(&%L;"!U<V5R<R!I;B!T:&4@<WES=&5M+@H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@(%1H92!A<G)A>2!O9B!U<V5R261S+"!O<B!A(%!%05)?17)R
M;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI
M<W15<V5R<R@I"B`@("!["B`@("`@("`@)&QI;F5S(#T@0&9I;&4H)R]E=&,O
M;7!A<W-W9"<I.PH@("`@("`@(&EF("@A)&QI;F5S('Q\("%I<U]A<G)A>2@D
M;&EN97,I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"=5;F%B;&4@=&\@;&ES="!U<V5R<RXG*3L*("`@("`@("!]"@H@("`@("`@
M("1U<V5R<R`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)&QI;F5S(&%S
M("1L:6YE*2!["B`@("`@("`@("`@("1U<V5R<UM=(#T@<W5B<W1R*"1L:6YE
M+"`P+"!S=')P;W,H)&QI;F4L("<Z)RDI.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1U<V5R<SL*("`@('T*"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O075T:"]F='`N<&AP````````````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#0R,3<@,3`U,34T,S,W-#`@,#(Q-34S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B!4
M:&4@075T:%]F='`@8VQA<W,@<')O=FED97,@86X@1E10(&EM<&QE;65N=&%T
M:6]N(&]F('1H92!(;W)D90H@*B!A=71H96YT:6-A=&EO;B!S>7-T96TN"B`J
M"B`J($]P=&EO;F%L('!A<F%M971E<G,Z/'!R93X*("H@("`G:&]S='-P96,G
M("!4:&4@:&]S=&YA;64@;W(@25`@861D<F5S<R!O9B!T:&4@1E10('-E<G9E
M<BX*("H@("`@("`@("`@("`@("!$149!54Q4.B`G;&]C86QH;W-T)PH@*B`@
M("=P;W)T)R`@("`@(%1H92!S97)V97(@<&]R="!T;R!C;VYN96-T('1O+@H@
M*B`@("`@("`@("`@("`@($1%1D%53%0Z(#(Q/"]P<F4^"B`J"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+T%U=&@O075T:"]F='`N<&AP+'8@,2XR,RXQ,BXX
M(#(P,#8O,#$O,#$@,C$Z,C@Z,#<@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@36%X($MA;&EK82`\;6%X0&AO<F1E
M+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N
M8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("!-87@@2V%L:6MA
M(#QM87A`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A
M8VMA9V4@2&]R9&5?075T:`H@*B\*8VQA<W,@075T:%]F='`@97AT96YD<R!!
M=71H('L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!N97<@1E10(&%U
M=&AE;G1I8V%T:6]N(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A
M;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!!=71H7V9T<"@D<&%R86US
M(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H(55T:6PZ.F5X=&5N<VEO
M;D5X:7-T<R@G9G1P)RDI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*%\H
M(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@
M0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"XB*2P@
M7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("1D969A
M=6QT7W!A<F%M<R`](&%R<F%Y*`H@("`@("`@("`@("`G:&]S='-P96,G(#T^
M("=L;V-A;&AO<W0G+`H@("`@("`@("`@("`G<&]R="<@/3X@,C$*("`@("`@
M("`I.PH@("`@("`@("1T:&ES+3Y?<&%R86US(#T@87)R87E?;65R9V4H)&1E
M9F%U;'1?<&%R86US+"`D<&%R86US*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($9I;F0@;W5T(&EF(&$@<V5T(&]F(&QO9VEN(&-R961E;G1I86QS(&%R92!V
M86QI9"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@("`@("!4:&4@=7-E<DED('1O
M(&-H96-K+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L<R`@06X@
M87)R87D@;V8@;&]G:6X@8W)E9&5N=&EA;',N($9O<B!&5%`L"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!T:&ES(&UU<W0@8V]N=&%I;B!A
M('!A<W-W;W)D(&5N=')Y+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&-R961E;G1I86QS(&%R92!V86QI9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V%U=&AE;G1I8V%T92@D=7-E<DED+"`D
M8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@)&9T<"`]($!F='!?8V]N;F5C
M="@D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G72P@)'1H:7,M/E]P87)A;7-;
M)W!O<G0G72D["@H@("`@("`@(&EF("@D9G1P("8F($!F='!?;&]G:6XH)&9T
M<"P@)'5S97))9"P@)&-R961E;G1I86QS6R=P87-S=V]R9"==*2D@>PH@("`@
M("`@("`@("!`9G1P7W%U:70H)&9T<"D["B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@($!F='!?<75I="@D
M9G1P*3L*("`@("`@("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H05542%]2
M14%33TY?0D%$3$]'24XI.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H@("`@?0H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O075T:"]I;6%P+G!H<```````````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,3,Q,3`@,3`U,34T,S,W-#`@,#(Q-S`P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B!4:&4@075T:%]I;6%P.CH@8VQA<W,@<')O=FED97,@86X@
M24U!4"!I;7!L96UE;G1A=&EO;B!O9B!T:&4@2&]R9&4*("H@875T:&5N=&EC
M871I;VX@<WES=&5M+@H@*@H@*B!/<'1I;VYA;"!P87)A;65T97)S.CQP<F4^
M"B`J("`G:&]S='-P96,G("`@("`@("!4:&4@:&]S=&YA;64@;W(@25`@861D
M<F5S<R!O9B!T:&4@<V5R=F5R+@H@*B`@("`@("`@("`@("`@("`@("`@1$5&
M055,5#H@)VQO8V%L:&]S="<*("H@("=P;W)T)R`@("`@("`@("`@(%1H92!S
M97)V97(@<&]R="!T;R!W:&EC:"!W92!W:6QL(&-O;FYE8W0N"B`J("`@("`@
M("`@("`@("`@("`@("!)34%0(&ES(&=E;F5R86QL>2`Q-#,L('=H:6QE($E-
M05`M4U-,(&ES(&=E;F5R86QL>2`Y.3,N"B`J("`@("`@("`@("`@("`@("`@
M("!$149!54Q4.B`Q-#,*("H@("=P<F]T;V-O;"<@("`@("`@(%1H92!C;VYN
M96-T:6]N('!R;W1O8V]L("AE+F<N("=I;6%P)RP@)W!O<#,G+"`G;FYT<"<I
M+@H@*B`@("`@("`@("`@("`@("`@("`@4')O=&]C;VP@:7,@;VYE(&]F("=I
M;6%P+VYO=&QS)R`H;W(@;VYL>2`G:6UA<"<@:68@>6]U"B`J("`@("`@("`@
M("`@("`@("`@("!H879E(&$@8RUC;&EE;G0@=F5R<VEO;B`R,#`P8R!O<B!O
M;&1E<BDL("=I;6%P+W-S;"<L"B`J("`@("`@("`@("`@("`@("`@("!O<B`G
M:6UA<"]S<VPO;F]V86QI9&%T92UC97)T)R`H9F]R(&$@<V5L9BUS:6=N960*
M("H@("`@("`@("`@("`@("`@("`@(&-E<G1I9FEC871E*2X*("H@("`@("`@
M("`@("`@("`@("`@($1%1D%53%0Z("=I;6%P)PH@*B`@)V%D;6EN7W5S97(G
M("`@("`@5&AE(&YA;64@;V8@82!U<V5R('=I=&@@861M:6X@<')I=FEL96=E
M<RX*("H@("`@("`@("`@("`@("`@("`@($1%1D%53%0Z(&YU;&P*("H@("=A
M9&UI;E]P87-S=V]R9"<@(%1H92!P87-S=V]R9"!O9B!T:&4@861M:6YS=')A
M=&]R+@H@*B`@("`@("`@("`@("`@("`@("`@1$5&055,5#H@;G5L;`H@*B`@
M)W5S97)H:65R87)C:'DG("`@5&AE(&AI97)A<F-H>2!W:&5R92!U<V5R(&UA
M:6QB;WAE<R!A<F4@<W1O<F5D+@H@*B`@("`@("`@("`@("`@("`@("`@1$5&
M055,5#H@)W5S97(N)PH@*B`@)V1S;B<@("`@("`@("`@("`@5&AE(&9U;&P@
M24U!4"!C;VYN96-T:6]N('-T<FEN9RX*("H@("`@("`@("`@("`@("`@("`@
M($EF(&YO="!P<F5S96YT+"!T:&ES(&ES(&)U:6QT(&9R;VT@)VAO<W1S<&5C
M)RP@)W!O<G0G"B`J("`@("`@("`@("`@("`@("`@("!A;F0@)W!R;W1O8V]L
M)R!P87)A;65T97)S+CPO<')E/@H@*@H@*@H@*B!)9B!S971T:6YG('5P(&%S
M($AO<F1E(&%U=&@@:&%N9&QE<B!I;B!C;VYF+G!H<"P@=&AI<R!I<R!A('-A
M;7!L92!E;G1R>3H\<')E/@H@*B`@("1C;VYF6R=A=71H)UU;)W!A<F%M<R==
M6R=H;W-T<W!E8R==(#T@)VEM87`N97AA;7!L92YC;VTG.PH@*B`@("1C;VYF
M6R=A=71H)UU;)W!A<F%M<R==6R=P;W)T)UT@/2`Q-#,["B`J("`@)&-O;F9;
M)V%U=&@G75LG<&%R86US)UU;)W!R;W1O8V]L)UT@/2`G:6UA<"]N;W1L<R]N
M;W9A;&ED871E+6-E<G0G.SPO<')E/@H@*@H@*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`L=B`Q+C(X+C$P+CD@,C`P-B\P-2\S
M,2`Q.3HS.3HT."!S;'5S87)Z($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY
M+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O
M<'ER:6=H="`Q.3DY+3(P,#8@1V%U9&5N>B!3=&5I;FQI;B`\9V%U9&5N>BYS
M=&5I;FQI;D!I9"YU;FEB92YC:#X*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!*
M86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J($!A=71H;W(@($=A=61E;GH@4W1E:6YL:6X@/&=A=61E;GHN<W1E:6YL
M:6Y`:60N=6YI8F4N8V@^"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA
M;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G
M92!(;W)D95]!=71H"B`J+PIC;&%S<R!!=71H7VEM87`@97AT96YD<R!!=71H
M('L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!N97<@24U!4"!A=71H
M96YT:6-A=&EO;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE
M=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@075T:%]I;6%P*"1P87)A;7,@
M/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("@A571I;#HZ97AT96YS:6]N
M17AI<W1S*"=I;6%P)RDI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*%\H
M(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@
M)&1E9F%U;'1?<&%R86US(#T@87)R87DH"B`@("`@("`@("`@("=H;W-T<W!E
M8R<@/3X@)VQO8V%L:&]S="<L"B`@("`@("`@("`@("=P;W)T)R`]/B`G,30S
M)RP*("`@("`@("`@("`@)W!R;W1O8V]L)R`]/B`G:6UA<"<L"B`@("`@("`@
M("`@("=U<V5R:&EE<F%R8VAY)R`]/B`G=7-E<BXG"B`@("`@("`@*3L*("`@
M("`@("`D=&AI<RT^7W!A<F%M<R`](&%R<F%Y7VUE<F=E*"1D969A=6QT7W!A
M<F%M<RP@)'!A<F%M<RD["@H@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P
M87)A;7-;)V%D;6EN7W5S97(G72DI('L*("`@("`@("`@("`@)'1H:7,M/F-A
M<&%B:6QI=&EE<ULG861D)UT@/2!T<G5E.PH@("`@("`@("`@("`D=&AI<RT^
M8V%P86)I;&ET:65S6R=R96UO=F4G72`]('1R=64["B`@("`@("`@("`@("1T
M:&ES+3YC87!A8FEL:71I97-;)VQI<W0G72`]('1R=64["B`@("`@("`@?0H*
M("`@("`@("`O*B!#<F5A=&4@1%-.('-T<FEN9RX@*B\*("`@("`@("!I9B`H
M(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=D<VXG72DI('L*("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)V1S;B==(#T@<W!R:6YT9B@G>R5S.B5D+R5S?2<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UTL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!O
M<G0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG<')O=&]C;VPG72D["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@1FEN9"!O=70@:68@82!S970@;V8@;&]G
M:6X@8W)E9&5N=&EA;',@87)E('9A;&ED+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97))
M9"`@("`@(%1H92!U<V5R260@=&\@8VAE8VLN"B`@("`@*B!`<&%R86T@87)R
M87D@)&-R961E;G1I86QS("!!;B!A<G)A>2!O9B!L;V=I;B!C<F5D96YT:6%L
M<RX@1F]R($E-05`L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!T:&ES(&UU<W0@8V]N=&%I;B!A('!A<W-W;W)D(&5N=')Y+@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&-R
M961E;G1I86QS(&%R92!V86QI9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V%U
M=&AE;G1I8V%T92@D=7-E<DED+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@
M("`@:68@*&5M<'1Y*"1C<F5D96YT:6%L<ULG<&%S<W=O<F0G72DI('L*("`@
M("`@("`@("`@2&]R9&4Z.F9A=&%L*%\H(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+B(I+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@('T*"B`@("`@("`@)&EM87`@/2!`:6UA<%]O<&5N*"1T
M:&ES+3Y?<&%R86US6R=D<VXG72P@)'5S97))9"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&-R961E;G1I86QS6R=P87-S=V]R9"==+"!/4%](04Q&
M3U!%3BD["@H@("`@("`@(&EF("@D:6UA<"D@>PH@("`@("`@("`@("!`:6UA
M<%]C;&]S92@D:6UA<"D["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?<V5T075T:$5R<F]R
M*$%55$A?4D5!4T].7T)!1$Q/1TE.*3L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%D9"!A('-E
M="!O9B!A=71H96YT:6-A=&EO;B!C<F5D96YT:6%L<RX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1U<V5R260@("`@("`@5&AE('5S97))9"!T;R!A
M9&0N"B`@("`@*B!`<&%R86T@87)R87D@("1C<F5D96YT:6%L<R`@5&AE(&-R
M961E;G1I86QS('1O('5S92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&15<V5R*"1U<V5R260L
M("1C<F5D96YT:6%L<RD*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO
M<F1E+TE-05`O061M:6XN<&AP)SL*("`@("`@("`D:6UA<"`]("9N97<@24U!
M4%]!9&UI;B@D=&AI<RT^7W!A<F%M<RD["B`@("`@("`@<F5T=7)N("1I;6%P
M+3YA9&1-86EL8F]X*%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'5S97))9"P@
M3DQ3.CIG971#:&%R<V5T*"DL("=U=&8W+6EM87`G*2D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!$96QE=&4@82!S970@;V8@875T:&5N=&EC871I;VX@8W)E
M9&5N=&EA;',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED
M("!4:&4@=7-E<DED('1O(&1E;&5T92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F55<V5R
M*"1U<V5R260I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92])
M34%0+T%D;6EN+G!H<"<["B`@("`@("`@)&EM87`@/2`F;F5W($E-05!?061M
M:6XH)'1H:7,M/E]P87)A;7,I.PH@("`@("`@("1R97-U;'0@/2`D:6UA<"T^
M<F5M;W9E36%I;&)O>"A3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1U<V5R260L
M($Y,4SHZ9V5T0VAA<G-E="@I+"`G=71F-RUI;6%P)RDI.PH@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI
M<RT^<F5M;W9E57-E<D1A=&$H)'5S97))9"D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!,:7-T(&%L;"!U<V5R<R!I;B!T:&4@<WES=&5M+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1H92!A<G)A>2!O9B!U<V5R261S+"!O<B!A
M(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&QI<W15<V5R<R@I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E
M("=(;W)D92])34%0+T%D;6EN+G!H<"<["B`@("`@("`@)&EM87`@/2`F;F5W
M($E-05!?061M:6XH)'1H:7,M/E]P87)A;7,I.PH@("`@("`@(')E='5R;B`D
M:6UA<"T^;&ES=$UA:6QB;WAE<R@I.PH@("`@?0H*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'``````````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`T,3(V-2`Q,#4Q-30S,S<T,"`P,C(S,#,`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M"G)E<75I<F5?;VYC92`G2&]R9&4O075T:"]S<6PN<&AP)SL*<F5Q=6ER95]O
M;F-E("=(;W)D92])34%0+T%D;6EN+G!H<"<["@HO*BH*("H@5&AE($%U=&A?
M8WER<W%L(&-L87-S('!R;W9I9&5S(&$@4U%,(&EM<&QE;65N=&%T:6]N(&]F
M('1H92!(;W)D90H@*B!A=71H96YT:6-A=&EO;B!S>7-T96T@9F]R('1H92!#
M>7)U<R!)34%0('-E<G9E<BX@36]S="!O9B!T:&4@9G5N8W1I;VYA;&ET>0H@
M*B!I<R!T:&4@<V%M92!A<R!F;W(@=&AE(%-13"!C;&%S<SL@;VYL>2!W:&%T
M(&ES(&1I9F9E<F5N="!O=F5R<FED97,@=&AE"B`J('!A<F5N="!C;&%S<R!I
M;7!L96UE;G1A=&EO;G,N"B`J"B`J(%)E<75I<F5D('!A<F%M971E<G,Z/'!R
M93X*("H@("`G8WER861M:6XG("!4:&4@=7-E<FYA;64@;V8@=&AE(&-Y<G5S
M(&%D;6EN:7-T<F%T;W(N"B`J("`@)V-Y<G!A<W,G("`@5&AE('!A<W-W;W)D
M(&9O<B!T:&4@8WER=7,@861M:6YI<W1R871O<BX*("H@("`G:6UA<%]D<VXG
M("!4:&4@9G5L;"!)34%0($133@H@*B`@("`@("`@("`@("`@("AI+F4N('ML
M;V-A;&AO<W0Z.3DS+VEM87`O<W-L+VYO=F%L:61A=&4M8V5R='TI+@H@*B`@
M("=P:'!T>7!E)R`@(%1H92!D871A8F%S92!T>7!E("AI92X@)W!G<W%L)RP@
M)VUY<W%L)RP@971C+BDN/"]P<F4^"B`J"B`J($]P=&EO;F%L('!A<F%M971E
M<G,Z/'!R93X*("H@("`G9&]M86EN7V9I96QD)R`@("!)9B!S970@=&\@86YY
M=&AI;F<@;W1H97(@=&AA;B`G;F]N92<@=&AI<R!I<R!U<V5D(&%S"B`J("`@
M("`@("`@("`@("`@("`@("`@9FEE;&0@;F%M92!W:&5R92!D;VUA:6X@:7,@
M<W1O<F5D+@H@*B`@("`@("`@("`@("`@("`@("`@($1%1D%53%0Z("=D;VUA
M:6Y?;F%M92<*("H@("`G96YC<GEP=&EO;B<@("`@("!4:&4@96YC<GEP=&EO
M;B!T;R!U<V4@=&\@<W1O<F4@=&AE('!A<W-W;W)D(&EN('1H90H@*B`@("`@
M("`@("`@("`@("`@("`@('1A8FQE("AE+F<N('!L86EN+"!C<GEP="P@;60U
M+6AE>"P@;60U+6)A<V4V-"P@<VUD-2P*("H@("`@("`@("`@("`@("`@("`@
M("!S:&$L('-S:&$I+@H@*B`@("`@("`@("`@("`@("`@("`@($1%1D%53%0Z
M("=M9#4M:&5X)PH@*B`@("=F;VQD97)S)R`@("`@("`@($%N(&%R<F%Y(&]F
M(&9O;&1E<G,@=&\@8W)E871E('5N9&5R('5S97)N86UE+@H@*B`@("`@("`@
M("`@("`@("`@("`@($1%1D%53%0Z($Y/3D4*("H@("`G<&%S<W=O<F1?9FEE
M;&0G("!4:&4@;F%M92!O9B!T:&4@<&%S<W=O<F0@9FEE;&0@:6X@=&AE(&%U
M=&@@=&%B;&4N"B`J("`@("`@("`@("`@("`@("`@("`@1$5&055,5#H@)W!A
M<W-W;W)D)PH@*B`@("=Q=6]T82<@("`@("`@("`@(%1H92!Q=6]T82`H:6X@
M:VEL;V)Y=&5S*2!T;R!G<F%N="!O;B!T:&4@;6%I;&)O>"X*("H@("`@("`@
M("`@("`@("`@("`@("!$149!54Q4.B!.3TY%"B`J("`@)W1A8FQE)R`@("`@
M("`@("`@5&AE(&YA;64@;V8@=&AE(&%U=&@@=&%B;&4@:6X@)V1A=&%B87-E
M)RX*("H@("`@("`@("`@("`@("`@("`@("!$149!54Q4.B`G86-C;W5N='5S
M97(G"B`J("`@)W5N:7AH:65R)R`@("`@("`@5&AE('9A;'5E(&]F(&EM87!D
M+F-O;F8G<R!U;FEX:&EE<F%R8VAY<V5P('-E='1I;F<N"B`J("`@("`@("`@
M("`@("`@("`@("`@4V5T('1H:7,@=&\@=')U92!I9B!T:&4@=F%L=64@:7,@
M=')U92!I;B!I;6%P9"YC;VYF+@H@*B`@("=U<V5R;F%M95]F:65L9"<@(%1H
M92!N86UE(&]F('1H92!U<V5R;F%M92!F:65L9"!I;B!T:&4@875T:"!T86)L
M92X*("H@("`@("`@("`@("`@("`@("`@("!$149!54Q4.B`G=7-E<FYA;64G
M/"]P<F4^"B`J"B`J(%)E<75I<F5D(&)Y('-O;64@9&%T86)A<V4@:6UP;&5M
M96YT871I;VYS.CQP<F4^"B`J("`@)V1A=&%B87-E)R`@5&AE(&YA;64@;V8@
M=&AE(&1A=&%B87-E+@H@*B`@("=H;W-T<W!E8R<@(%1H92!H;W-T;F%M92!O
M9B!T:&4@9&%T86)A<V4@<V5R=F5R+@H@*B`@("=P<F]T;V-O;"<@(%1H92!C
M;VUM=6YI8V%T:6]N('!R;W1O8V]L("@G=&-P)RP@)W5N:7@G+"!E=&,N*2X*
M("H@("`G=7-E<FYA;64G("!4:&4@=7-E<FYA;64@=VET:"!W:&EC:"!T;R!C
M;VYN96-T('1O('1H92!D871A8F%S92X*("H@("`G<&%S<W=O<F0G("!4:&4@
M<&%S<W=O<F0@87-S;V-I871E9"!W:71H("=U<V5R;F%M92<N"B`J("`@)V]P
M=&EO;G,G("`@061D:71I;VYA;"!O<'1I;VYS('1O('!A<W,@=&\@=&AE(&1A
M=&%B87-E+@H@*B`@("=P;W)T)R`@("`@(%1H92!P;W)T(&]N('=H:6-H('1O
M(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+@H@*B`@("=T='DG("`@("`@(%1H
M92!45%D@;VX@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N/"]P
M<F4^"B`J"B`J"B`J(%1H92!T86)L92!S=')U8W1U<F4@9F]R('1H92!A=71H
M('-Y<W1E;2!I<R!A<R!F;VQL;W=S.@H@*@H@*B`\<')E/@H@*B!#4D5!5$4@
M5$%"3$4@86-C;W5N='5S97(@*`H@*B`@("`@=7-E<FYA;64@("`@5D%20TA!
M4B@R-34I($))3D%262!.3U0@3E5,3"!$149!54Q4("<G+`H@*B`@("`@<&%S
M<W=O<F0@("`@5D%20TA!4B@S,BD@0DE.05)9($Y/5"!.54Q,($1%1D%53%0@
M)R<L"B`J("`@("!P<F5F:7@@("`@("!605)#2$%2*#4P*2!.3U0@3E5,3"!$
M149!54Q4("<G+`H@*B`@("`@9&]M86EN7VYA;64@5D%20TA!4B@R-34I($Y/
M5"!.54Q,($1%1D%53%0@)R<L"B`J("`@("!53DE1544@2T59('5S97)N86UE
M("AU<V5R;F%M92D*("H@*3L*("H*("H@0U)%051%(%1!0DQ%(&%D;6EN=7-E
M<B`H"B`J("`@("!U<V5R;F%M92`@("!605)#2$%2*#4P*2!"24Y!4ED@3D]4
M($Y53$P@1$5&055,5"`G)RP*("H@("`@('!A<W-W;W)D("`@(%9!4D-(05(H
M-3`I($))3D%262!.3U0@3E5,3"!$149!54Q4("<G+`H@*B`@("`@='EP92`@
M("`@("`@24Y4*#$Q*2!.3U0@3E5,3"!$149!54Q4("<P)RP*("H@("`@(%-)
M1"`@("`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"!$149!54Q4("<G+`H@
M*B`@("`@:&]M92`@("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,($1%1D%5
M3%0@)R<L"B`J("`@("!04DE-05)9($M%62`H=7-E<FYA;64I"B`J("D["B`J
M"B`J($-214%412!404),12!A;&EA<R`H"B`J("`@("!A;&EA<R`@("`@("!6
M05)#2$%2*#(U-2D@3D]4($Y53$P@1$5&055,5"`G)RP*("H@("`@(&1E<W0@
M("`@("`@($Q/3D=415A4+`H@*B`@("`@=7-E<FYA;64@("`@5D%20TA!4B@U
M,"D@3D]4($Y53$P@1$5&055,5"`G)RP*("H@("`@('-T871U<R`@("`@($E.
M5"@Q,2D@3D]4($Y53$P@1$5&055,5"`G,2<L"B`J("`@("!04DE-05)9($M%
M62`H86QI87,I"B`J("D["B`J"B`J($-214%412!404),12!D;VUA:6X@*`H@
M*B`@("`@9&]M86EN7VYA;64@5D%20TA!4B@R-34I($Y/5"!.54Q,($1%1D%5
M3%0@)R<L"B`J("`@("!P<F5F:7@@("`@("!605)#2$%2*#4P*2!.3U0@3E5,
M3"!$149!54Q4("<G+`H@*B`@("`@;6%X86-C;W5N=',@24Y4*#$Q*2!.3U0@
M3E5,3"!$149!54Q4("<R,"<L"B`J("`@("!Q=6]T82`@("`@("!)3E0H,3`I
M($Y/5"!.54Q,($1%1D%53%0@)S(P,#`P)RP*("H@("`@('1R86YS<&]R="`@
M(%9!4D-(05(H,C4U*2!.3U0@3E5,3"!$149!54Q4("=C>7)U<R<L"B`J("`@
M("!F<F5E;F%M97,@("!%3E5-*"=915,G+"=.3R<I($Y/5"!.54Q,($1%1D%5
M3%0@)TY/)RP*("H@("`@(&9R965A9&1R97-S($5.54TH)UE%4R<L)TY/)RD@
M3D]4($Y53$P@1$5&055,5"`G3D\G+`H@*B`@("`@4%))34%262!+15D@*&1O
M;6%I;E]N86UE*2P*("H@("`@(%5.25%512!+15D@<')E9FEX("AP<F5F:7@I
M"B`J("D["B`J"B`J($-214%412!404),12!D;VUA:6YA9&UI;B`H"B`J("`@
M("!D;VUA:6Y?;F%M92!605)#2$%2*#(U-2D@3D]4($Y53$P@1$5&055,5"`G
M)RP*("H@("`@(&%D;6EN=7-E<B`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"!$
M149!54Q4("<G"B`J("D["B`J"B`J($-214%412!404),12!S96%R8V@@*`H@
M*B`@("`@<V5A<F-H7VED("`@5D%20TA!4B@R-34I($Y/5"!.54Q,($1%1D%5
M3%0@)R<L"B`J("`@("!S96%R8VA?<W%L("!415A4($Y/5"!.54Q,+`H@*B`@
M("`@<&5R<&%G92`@("`@24Y4*#$Q*2!.3U0@3E5,3"!$149!54Q4("<P)RP*
M("H@("`@('1I;65S=&%M<"`@(%1)34535$%-4"@Q-"D@3D]4($Y53$PL"B`J
M("`@("!04DE-05)9($M%62`H<V5A<F-H7VED*2P*("H@("`@($M%62!S96%R
M8VA?:60@*'-E87)C:%]I9"D*("H@*3L*("H*("H@0U)%051%(%1!0DQ%('9I
M<G1U86P@*`H@*B`@("`@86QI87,@("`@("`@5D%20TA!4B@R-34I($Y/5"!.
M54Q,($1%1D%53%0@)R<L"B`J("`@("!D97-T("`@("`@("!,3TY'5$585"P*
M("H@("`@('5S97)N86UE("`@(%9!4D-(05(H-3`I($Y/5"!.54Q,($1%1D%5
M3%0@)R<L"B`J("`@("!S=&%T=7,@("`@("!)3E0H,3$I($Y/5"!.54Q,($1%
M1D%53%0@)S$G+`H@*B`@("`@2T59(&%L:6%S("AA;&EA<RD*("H@*3L*("H*
M("H@0U)%051%(%1!0DQ%(&QO9R`H"B`J("`@("!I9"`@("`@("`@("!)3E0H
M,3$I($Y/5"!.54Q,($%55$]?24Y#4D5-14Y4+`H@*B`@("`@;7-G("`@("`@
M("`@5$585"!.3U0@3E5,3"P*("H@("`@('5S97(@("`@("`@(%9!4D-(05(H
M,C4U*2!.3U0@3E5,3"!$149!54Q4("<G+`H@*B`@("`@:&]S="`@("`@("`@
M5D%20TA!4B@R-34I($Y/5"!.54Q,($1%1D%53%0@)R<L"B`J("`@("!T:6UE
M("`@("`@("!$051%5$E-12!.3U0@3E5,3"!$149!54Q4("<R,#`P+3`P+3`P
M(#`P.C`P.C`P)RP*("H@("`@('!I9"`@("`@("`@(%9!4D-(05(H,C4U*2!.
M3U0@3E5,3"!$149!54Q4("<G+`H@*B`@("`@4%))34%262!+15D@*&ED*0H@
M*B`I.PH@*B`\+W!R93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO075T:"]!
M=71H+V-Y<G-Q;"YP:'`L=B`Q+C,S+C$P+C$T(#(P,#8O,#@O,30@,#(Z-#@Z
M-#@@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!);'EA
M(#QM86EL0&MR96PN;W)G/@H@*B!#;W!Y<FEG:'0@,C`P-2TR,#`V($IA;B!3
M8VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,
M*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`
M875T:&]R("!);'EA(#QM86EL0&MR96PN;W)G/@H@*B!`875T:&]R("!*86X@
M4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S
M+C`*("H@0'!A8VMA9V4@2&]R9&5?075T:`H@*B\*8VQA<W,@075T:%]C>7)S
M<6P@97AT96YD<R!!=71H7W-Q;"!["@H@("`@+RHJ"B`@("`@*B!(86YD;&4@
M9F]R('1H92!C=7)R96YT($E-05`@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@
M*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D7VEM87!3=')E86T[
M"@H@("`@+RHJ"B`@("`@*B!(86YD;&4@9F]R(&%N($E-05!?061M:6X@;V)J
M96-T+@H@("`@("H*("`@("`J($!V87(@24U!4%]!9&UI;@H@("`@("HO"B`@
M("!V87(@)%]A9&UI;CL*"B`@("`O*BH*("`@("`J($AI97)A<F-H>2!S97!A
M<F%T;W(@=&\@=7-E("AE+F<N+"!I<R!I="!U<V5R+VUA:6QB;W@@;W(@=7-E
M<BYM86EL8F]X*0H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*
M("`@('9A<B`D7W-E<&%R871O<B`]("<N)SL*"B`@("`O*BH*("`@("`J($-O
M;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US
M("!!(&AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N('!A<F%M971E<G,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N($%U=&A?8WER<W%L*"1P87)A;7,@/2!A<G)A
M>2@I*0H@("`@>PH@("`@("`@(&EF("@A571I;#HZ97AT96YS:6]N17AI<W1S
M*"=I;6%P)RDI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*%\H(D%U=&A?
M8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(BDL
M(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@("`@('!A<F5N
M=#HZ075T:%]S<6PH)'!A<F%M<RD["@H@("`@("`@("1A9&UI;E]P87)A;7,@
M/2!A<G)A>2@G861M:6Y?=7-E<B<@/3X@)'!A<F%M<ULG8WER861M:6XG72P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%D;6EN7W!A<W-W;W)D
M)R`]/B`D<&%R86US6R=C>7)P87-S)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=D<VXG(#T^("1P87)A;7-;)VEM87!?9'-N)UTI.PH@("`@
M("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;)W5N:7AH:65R)UTI*2![
M"B`@("`@("`@("`@("1A9&UI;E]P87)A;7-;)W5S97)H:65R87)C:'DG72`]
M("=U<V5R+R<["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?861M:6X@/2`F
M;F5W($E-05!?061M:6XH)&%D;6EN7W!A<F%M<RD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!!9&0@82!S970@;V8@875T:&5N=&EC871I;VX@8W)E9&5N=&EA
M;',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("`@("`@
M(%1H92!U<V5R260@=&\@861D+@H@("`@("H@0'!A<F%M(&%R<F%Y("`D8W)E
M9&5N=&EA;',@(%1H92!C<F5D96YT:6%L<R!T;R!A9&0N"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%
M<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M861D57-E<B@D=7-E<DED+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@(&EF("@A96UP='DH)'1H:7,M
M/E]P87)A;7-;)V1O;6%I;E]F:65L9"==*2`F)@H@("`@("`@("`@("`H)'1H
M:7,M/E]P87)A;7-;)V1O;6%I;E]F:65L9"==("$]("=N;VYE)RDI('L*("`@
M("`@("`@("`@;&ES="@D;F%M92P@)&1O;6%I;BD@/2!E>'!L;V1E*"=`)RP@
M)'5S97))9"D["B`@("`@("`@("`@("\J($)U:6QD('1H92!344P@<75E<GDN
M("HO"B`@("`@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)TE.4T525"!)3E1/
M("5S("@E<RP@)7,L("5S*2!604Q515,@*#\L(#\L(#\I)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG
M=7-E<FYA;65?9FEE;&0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULG9&]M86EN7V9I96QD)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D7V9I
M96QD)UTI.PH@("`@("`@("`@("`D=F%L=65S(#T@87)R87DH)&YA;64L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9&]M86EN+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/F=E=$-R>7!T961087-S=V]R9"@D
M8W)E9&5N=&EA;'-;)W!A<W-W;W)D)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULG96YC<GEP=&EO;B==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG<VAO=U]E;F-R>7!T:6]N)UTI*3L*"B`@("`@("`@("`@
M($AO<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@075T:%]C>7)S<6PZ
M.F%D9%5S97(H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!0
M14%27TQ/1U]$14)51RD["@H@("`@("`@("`@("`D9&)R97-U;'0@/2`D=&AI
M<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH@("`@("`@("`@("`D
M<75E<GD@/2`G24Y315)4($E.5$\@=FER='5A;"`H86QI87,L(&1E<W0L('5S
M97)N86UE+"!S=&%T=7,I(%9!3%5%4R`H/RP@/RP@/RP@,2DG.PH@("`@("`@
M("`@("`D=F%L=65S(#T@87)R87DH)'5S97))9"P@)&YA;64L("1N86UE*3L*
M"B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@
M075T:%]C>7)S<6PZ.F%D9%5S97(H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L
M(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("`@("`D9&)R
M97-U;'0R(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*
M("`@("`@("`@("`@:68@*&ES7V$H)&1B<F5S=6QT,BP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1D8G)E<W5L=#(["B`@("`@
M("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9&)R97-U
M;'0@/2!P87)E;G0Z.F%D9%5S97(H)'5S97))9"P@)&-R961E;G1I86QS*3L*
M("`@("`@("`@("`@)&YA;64@/2`D=7-E<DED.PH@("`@("`@('T*("`@("`@
M("!I9B`H:7-?82@D9&)R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1D8G)E<W5L=#L*("`@("`@("!]"@H@("`@("`@(&EF
M("@A:7-?82@D<F5S=6QT(#T@)'1H:7,M/E]A9&UI;BT^861D36%I;&)O>"@D
M;F%M92DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@0&%R<F%Y7W=A
M;&LH)'1H:7,M/E]P87)A;7-;)V9O;&1E<G,G72P*("`@("`@("`@("`@("`@
M("`@("`@("`@87)R87DH)'1H:7,L("=?8W)E871E4W5B1F]L9&5R<R<I+"`D
M;F%M92D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@2&]R9&4Z.FQO
M9TUE<W-A9V4H)TE-05`@;6%I;&)O>"!C<F5A=&EO;B!F;W(@)R`N("1N86UE
M("X@)R!F86EL960Z("<@+B`D<F5S=6QT+3YG971-97-S86=E*"DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H<W!R:6YT9BA?*"))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D
M.B`E<R(I+"`D<F5S=6QT+3YG971-97-S86=E*"DI*3L*("`@("`@("!]"@H@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A<F%M<ULG<75O=&$G72D@)B8@
M)'1H:7,M/E]P87)A;7-;)W%U;W1A)UT@/CT@,"D@>PH@("`@("`@("`@("!I
M9B`H(4!I;6%P7W-E=%]Q=6]T82@D=&AI<RT^7VEM87!3=')E86TL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U<V5R)R`N("1T:&ES+3Y?
M<V5P87)A=&]R("X@)&YA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=Q=6]T82==*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*"))34%0
M(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<R(I+"!I;6%P7VQA
M<W1?97)R;W(H*2DI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($1E;&5T92!A
M('-E="!O9B!A=71H96YT:6-A=&EO;B!C<F5D96YT:6%L<RX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@(%1H92!U<V5R260@=&\@9&5L
M971E+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@("`@("`@4W5C
M8V5S<R!O<B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F55
M<V5R*"1U<V5R260I"B`@("!["B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D[
M"@H@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;)V1O;6%I;E]F
M:65L9"==*2`F)@H@("`@("`@("`@("`H)'1H:7,M/E]P87)A;7-;)V1O;6%I
M;E]F:65L9"==("$]("=N;VYE)RDI('L*("`@("`@("`@("`@;&ES="@D;F%M
M92P@)&1O;6%I;BD@/2!E>'!L;V1E*"=`)RP@)'5S97))9"D["B`@("`@("`@
M("`@("\J($)U:6QD('1H92!344P@<75E<GDN("HO"B`@("`@("`@("`@("1Q
M=65R>2`]('-P<FEN=&8H)T1%3$5412!&4D]-("5S(%=(15)%("5S(#T@/R!A
M;F0@)7,@/2`_)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG=&%B;&4G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;65?9FEE;&0G72P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG9&]M86EN
M7V9I96QD)UTI.PH@("`@("`@("`@("`D=F%L=65S(#T@87)R87DH)&YA;64L
M("1D;VUA:6XI.PH*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-1
M3"!1=65R>2!B>2!!=71H7V-Y<G-Q;#HZ<F5M;W9E57-E<B@I.B`G("X@)'%U
M97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@
M("`@("`@("`@("1D8G)E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R
M>2P@)'9A;'5E<RD["B`@("`@("`@("`@("1Q=65R>2`]("=$14Q%5$4@1E)/
M32!V:7)T=6%L(%=(15)%(&1E<W0@/2`_)SL*("`@("`@("`@("`@)'9A;'5E
M<R`](&%R<F%Y*"1N86UE*3L*"B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S
M86=E*"=344P@475E<GD@8GD@075T:%]C>7)S<6PZ.G)E;6]V955S97(H*3H@
M)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)5
M1RD["@H@("`@("`@("`@("`D9&)R97-U;'0R(#T@)'1H:7,M/E]D8BT^<75E
M<GDH)'%U97)Y+"`D=F%L=65S*3L*("`@("`@("`@("`@:68@*&ES7V$H)&1B
M<F5S=6QT,BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1D8G)E<W5L=#(["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D9&)R97-U;'0@/2!P87)E;G0Z.G)E;6]V955S97(H
M)'5S97))9"D["B`@("`@("`@("`@("1N86UE(#T@)'5S97))9#L*("`@("`@
M("!]"@H@("`@("`@(&EF("AI<U]A*"1D8G)E<W5L="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&1B<F5S=6QT.PH@("`@("`@('T*
M"B`@("`@("`@+RH@1&5L971E($E-05`@;6%I;&)O>"X@*B\*("`@("`@("`D
M:6UA<')E<W5L="`]("1T:&ES+3Y?861M:6XM/G)E;6]V94UA:6QB;W@H)&YA
M;64I.PH*("`@("`@("!I9B`H:7-?82@D:6UA<')E<W5L="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS
M<')I;G1F*%\H(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(BDL
M("1I;6%P<F5S=6QT+3YG971-97-S86=E*"DI*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D=&AI<RT^<F5M;W9E57-E<D1A=&$H)'5S97))9"D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!O<&5N(&-O;FYE8W1I
M;VYS('1O('1H92!344P@86YD($E-05`@<V5R=F5R<RX*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N;F5C="@I"B`@("![
M"B`@("`@("`@:68@*"$D=&AI<RT^7V-O;FYE8W1E9"D@>PH@("`@("`@("`@
M("!P87)E;G0Z.E]C;VYN96-T*"D["@H@("`@("`@("`@("`O+R!297-E="!T
M:&4@)%]C;VYN96-T960@9FQA9SL@=V4@:&%V96XG="!Y970@<W5C8V5S<V9U
M;&QY(&]P96YE9`H@("`@("`@("`@("`O+R!E=F5R>71H:6YG+@H@("`@("`@
M("`@("`D=&AI<RT^7V-O;FYE8W1E9"`](&9A;'-E.PH*("`@("`@("`@("`@
M)'1H:7,M/E]I;6%P4W1R96%M(#T@0&EM87!?;W!E;B@D=&AI<RT^7W!A<F%M
M<ULG:6UA<%]D<VXG72P@)'1H:7,M/E]P87)A;7-;)V-Y<F%D;6EN)UTL("1T
M:&ES+3Y?<&%R86US6R=C>7)P87-S)UTL($]07TA!3$9/4$5.*3L*("`@("`@
M("`@("`@:68@*"$D=&AI<RT^7VEM87!3=')E86TI('L*("`@("`@("`@("`@
M("`@($AO<F1E.CIF871A;"AS<')I;G1F*%\H(D-A;B=T(&-O;FYE8W0@=&\@
M24U!4"!S97)V97(Z("5S(BDL(&EM87!?;&%S=%]E<G)O<B@I*2P@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@
M*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG=6YI>&AI97(G72DI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<V5P87)A=&]R(#T@)R\G.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1T:&ES+3Y?8V]N;F5C=&5D(#T@=')U93L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1&ES8V]N;F5C="!F<F]M('1H92!344P@86YD($E-05`@<V5R=F5R
M<R!A;F0@8VQE86X@=7`@=&AE(&-O;FYE8W1I;VYS+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O;B!F86EL=7)E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?9&ES8V]N;F5C="@I"B`@("!["B`@("`@("`@:68@
M*"1T:&ES+3Y?8V]N;F5C=&5D*2!["B`@("`@("`@("`@('!A<F5N=#HZ7V1I
M<V-O;FYE8W0H*3L*("`@("`@("`@("`@0&EM87!?8VQO<V4H)'1H:7,M/E]I
M;6%P4W1R96%M*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0W)E871E<R!A;&P@;6%I;&)O>&5S('-U
M<'!L:65D(&EN(&-O;F9I9W5R871I;VX*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1V86QU90H@
M("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("`@("`@56YU<V5D(&)Y('1H:7,@
M9')I=F5R"B`@("`@*B!`<&%R86T@<W1R:6YG('5S97).86UE"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]C<F5A=&53=6)&;VQD97)S*"1V86QU92P@)&ME>2P@
M)'5S97).86UE*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P
M87)A;7-;)V1O;6%I;E]F:65L9"==*2`F)@H@("`@("`@("`@("`H)'1H:7,M
M/E]P87)A;7-;)V1O;6%I;E]F:65L9"==("$]("=N;VYE)RDI('L*("`@("`@
M("`@("`@;&ES="@D=7-E<DYA;64I(#T@97AP;&]D92@G0"<L("1U<V5R3F%M
M92D["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?861M:6XM/F%D9$UA:6QB
M;W@H)'5S97).86UE("X@)'1H:7,M/E]S97!A<F%T;W(@+B`D=F%L=64I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@3&ES="!A;&P@=7-E<G,@:6X@=&AE('-Y
M<W1E;2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@87)R87D@
M;V8@=7-E<DED<RP@;W(@9F%L<V4@;VX@9F%I;'5R92]U;G-U<'!O<G1E9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=%5S97)S*"D*("`@('L*("`@("`@
M("`O*B!?8V]N;F5C="@I('=I;&P@9&EE('=I=&@@2&]R9&4Z.F9A=&%L*"D@
M=7!O;B!F86EL=7)E+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*
M("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=D;VUA:6Y?9FEE
M;&0G72D@)B8*("`@("`@("`@("`@*"1T:&ES+3Y?<&%R86US6R=D;VUA:6Y?
M9FEE;&0G72`A/2`G;F]N92<I*2!["B`@("`@("`@("`@("\J($)U:6QD('1H
M92!344P@<75E<GD@=VET:"!D;VUA:6XN("HO"B`@("`@("`@("`@("1Q=65R
M>2`]('-P<FEN=&8H)U-%3$5#5"`E<RP@)7,@1E)/32`E<R!/4D1%4B!"62`E
M<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)W5S97)N86UE7V9I96QD)UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)V1O;6%I;E]F:65L9"==+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=U<V5R;F%M95]F:65L9"==*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`O*B!"=6EL9"!T:&4@4U%,('%U97)Y('=I=&AO=70@9&]M86EN+B`J
M+PH@("`@("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=314Q%0U0@)7,@1E)/
M32`E<R!/4D1%4B!"62`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P87)A;7-;)W5S97)N86UE7V9I96QD)UTL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)W5S97)N86UE7V9I96QD)UTI.PH@("`@("`@('T*"B`@("`@("`@2&]R9&4Z
M.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!!=71H7V-Y<G-Q;#HZ;&ES=%5S
M97)S*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],
M3T=?1$5"54<I.PH*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^9V5T
M06QL*"1Q=65R>2P@;G5L;"P@1$)?1D540TA-3T1%7T]21$52140I.PH@("`@
M("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`O*B!,
M;V]P('1H<F]U9V@@86YD(&)U:6QD(')E='5R;B!A<G)A>2X@*B\*("`@("`@
M("`D=7-E<G,@/2!A<G)A>2@I.PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M
M/E]P87)A;7-;)V1O;6%I;E]F:65L9"==*2`F)@H@("`@("`@("`@("`H)'1H
M:7,M/E]P87)A;7-;)V1O;6%I;E]F:65L9"==("$]("=N;VYE)RDI('L*("`@
M("`@("`@("`@9F]R96%C:"`H)')E<W5L="!A<R`D87(I('L*("`@("`@("`@
M("`@("`@("1U<V5R<UM=(#T@)&%R6S!=("X@)T`G("X@)&%R6S%=.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@9F]R96%C
M:"`H)')E<W5L="!A<R`D87(I('L*("`@("`@("`@("`@("`@("1U<V5R<UM=
M(#T@)&%R6S!=.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)'5S97)S.PH@("`@?0H*("`@("\J*@H@("`@("H@57!D871E(&$@
M<V5T(&]F(&%U=&AE;G1I8V%T:6]N(&-R961E;G1I86QS+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&]L9$E$("`@("`@(%1H92!O;&0@=7-E<DED
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5W240@("`@("`@5&AE(&YE=R!U
M<V5R260N"B`@("`@*B!`<&%R86T@87)R87D@)&-R961E;G1I86QS("!4:&4@
M;F5W(&-R961E;G1I86QS"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@
M5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I
M;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@=7!D871E57-E<B@D;VQD240L
M("1N97=)1"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@("`@("\J(%]C;VYN
M96-T*"D@=VEL;"!D:64@=VET:"!(;W)D93HZ9F%T86PH*2!U<&]N(&9A:6QU
M<F4N("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@(&EF
M("@A96UP='DH)'1H:7,M/E]P87)A;7-;)V1O;6%I;E]F:65L9"==*2`F)@H@
M("`@("`@("`@("`H)'1H:7,M/E]P87)A;7-;)V1O;6%I;E]F:65L9"==("$]
M("=N;VYE)RDI('L*("`@("`@("`@("`@;&ES="@D;F%M92P@)&1O;6%I;BD@
M/2!E>'!L;V1E*"=`)RP@)&]L9$E$*3L*("`@("`@("`@("`@+RH@0G5I;&0@
M=&AE(%-13"!Q=65R>2!W:71H(&1O;6%I;BX@*B\*("`@("`@("`@("`@)'%U
M97)Y(#T@<W!R:6YT9B@G55!$051%("5S(%-%5"`E<R`](#\@5TA%4D4@)7,@
M/2`_(&%N9"`E<R`](#\G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=T86)L92==+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=P87-S=V]R9%]F:65L9"==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=U
M<V5R;F%M95]F:65L9"==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=D;VUA:6Y?9FEE;&0G72D["B`@("`@("`@("`@
M("1V86QU97,@/2!A<G)A>2@D=&AI<RT^9V5T0W)Y<'1E9%!A<W-W;W)D*"1C
M<F5D96YT:6%L<ULG<&%S<W=O<F0G72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=E;F-R>7!T:6]N)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=S:&]W7V5N8W)Y<'1I;VXG72DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D;F%M92P@)&1O;6%I;BD["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*("`@
M("`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G55!$051%("5S(%-%5"`E<R`]
M(#\@5TA%4D4@)7,@/2`_)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F1?9FEE;&0G72P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG
M=7-E<FYA;65?9FEE;&0G72D["B`@("`@("`@("`@("1V86QU97,@/2!A<G)A
M>2@D=&AI<RT^9V5T0W)Y<'1E9%!A<W-W;W)D*"1C<F5D96YT:6%L<ULG<&%S
M<W=O<F0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=E;F-R>7!T:6]N)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=S:&]W
M7V5N8W)Y<'1I;VXG72DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M;VQD240I.PH@("`@("`@('T*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H
M)U-13"!1=65R>2!B>2!!=71H7V-Y<G-Q;#HZ=7!D871E57-E<B@I.B`G("X@
M)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A
M;'5E<RD["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O075T:"]Y86AO;RYP:'``````````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#4P-C`@,3`U,34T,S,W-#`@
M,#(R,#<V`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B!4:&4@075T:%]Y86AO;SHZ(&-L87-S(&-H96-K
M<R!L;V=I;B!C<F5D96YT:6%L<R!A9V%I;G-T(%EA:&]O(2!M86EL"B`J(&%C
M8V]U;G1S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]!=71H+T%U=&@O>6%H
M;V\N<&AP+'8@,2XQ,RXQ,BXW(#(P,#8O,#$O,#$@,C$Z,C@Z,#<@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!Y86AO;SHO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC
M92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]!=71H"B`J+PIC;&%S
M<R!!=71H7WEA:&]O(&5X=&5N9',@075T:"!["@H@("`@+RHJ"B`@("`@*B!`
M=F%R($A45%!?4F5Q=65S=`H@("`@("HO"B`@("!V87(@)%]H='1P.PH*("`@
M("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!986AO;R!A=71H96YT:6-A
M=&EO;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A
M;7,@($$@:&%S:"!C;VYT86EN:6YG('!A<F%M971E<G,N"B`@("`@*B\*("`@
M(&9U;F-T:6]N($%U=&A?>6%H;V\H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("![
M"B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1FEN9"!O=70@:68@82!S970@;V8@;&]G:6X@8W)E9&5N
M=&EA;',@87)E('9A;&ED+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@("`@("!4
M:&4@=7-E<DED('1O(&-H96-K+@H@("`@("H@0'!A<F%M(&%R<F%Y("`D8W)E
M9&5N=&EA;',@(%1H92!C<F5D96YT:6%L<R!T;R!U<V4N"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@8W)E9&5N
M=&EA;',@87)E('9A;&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!?875T:&5N
M=&EC871E*"1U<V5R260L("1C<F5D96YT:6%L<RD*("`@('L*("`@("`@("!R
M97%U:7)E7V]N8V4@)TA45%`O4F5Q=65S="YP:'`G.PH*("`@("`@("`O+R!-
M86ME('-U<F4@=&AA="!W92!H879E(&$@8F%R92!U<V5R;F%M92`M('-T<FEP
M(&]F9B!A;GET:&EN9PH@("`@("`@("\O(&%F=&5R("AA;F0@:6YC;'5D:6YG
M*2!T:&4@9FER<W0@0"P@:68@=&AE<F4@:7,@;VYE+@H@("`@("`@("1P;W,@
M/2!S=')P;W,H)'5S97))9"P@)T`G*3L*("`@("`@("!I9B`H)'!O<R`A/3T@
M9F%L<V4I('L*("`@("`@("`@("`@)'5S97))9"`]('-U8G-T<B@D=7-E<DED
M+"`P+"`D<&]S*3L*("`@("`@("!]"@H@("`@("`@("1O<'1I;VYS6R=M971H
M;V0G72`]($A45%!?4D5154535%]-151(3T1?4$]35#L*("`@("`@("`D;W!T
M:6]N<ULG=&EM96]U="==(#T@-3L*("`@("`@("`D;W!T:6]N<ULG86QL;W=2
M961I<F5C=',G72`]('1R=64["@H@("`@("`@("1T:&ES+3Y?:'1T<"`]("9N
M97<@2%144%]297%U97-T*"=H='1P.B\O;&]G:6XN>6%H;V\N8V]M+V-O;F9I
M9R]L;V=I;B<L("1O<'1I;VYS*3L*("`@("`@("`D=&AI<RT^7VAT='`M/F%D
M9%!O<W1$871A*"=L;V=I;B<L("1U<V5R260I.PH@("`@("`@("1T:&ES+3Y?
M:'1T<"T^861D4&]S=$1A=&$H)W!A<W-W9"<L("1C<F5D96YT:6%L<ULG<&%S
M<W=O<F0G72D["@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VAT='`M/G-E
M;F1297%U97-T*"D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`D<F5S=6QT(#T@)')E<W5L="T^9V5T
M365S<V%G92@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R97-U
M;'0@/2`D=&AI<RT^7VAT='`M/F=E=%)E<W!O;G-E0F]D>2@I.PH@("`@("`@
M("`@("`D8V]O:VEE<R`]("1T:&ES+3Y?:'1T<"T^9V5T4F5S<&]N<V5#;V]K
M:65S*"D["B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D8V]O:VEE<RDI('L*
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1C;V]K:65S(&%S("1C;V]K:64I
M('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VAT='`M/F%D9$-O;VMI
M92@D8V]O:VEE6R=N86UE)UTL("1C;V]K:65;)W9A;'5E)UTI.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O
M+R!4:&ES(&ES(%]S=6-H7R!A(&AA8VLL(&)U="!I="!W;W)K<RX*("`@("`@
M("!I9B`H(7!R96=?;6%T8V@H)WQI;G9A;&ED('!A<W-W;W)D?&DG+"`D<F5S
M=6QT*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D<F5S=6QT+"!?
M7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@
M("`@)'1H:7,M/E]S971!=71H17)R;W(H05542%]214%33TY?0D%$3$]'24XI
M.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92]!=71H+W!A;2YP:'``````````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P-3,R,R`Q,#4Q-30S,S<T,"`P,C$U,S8`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M(%1H92!!=71H7W!A;3HZ(&-L87-S('!R;W9I9&5S(&$@4$%-+6)A<V5D(&EM
M<&QE;65N=&%T:6]N(&]F('1H92!(;W)D90H@*B!A=71H96YT:6-A=&EO;B!S
M>7-T96TN"B`J"B`J(%!!32`H4&QU9V=A8FQE($%U=&AE;G1I8V%T:6]N($UO
M9'5L97,I(&ES(&$@9FQE>&EB;&4@;65C:&%N:7-M(&9O<@H@*B!A=71H96YT
M:6-A=&EN9R!U<V5R<RX@($ET(&AA<R!B96-O;64@=&AE('-T86YD87)D(&%U
M=&AE;G1I8V%T:6]N('-Y<W1E;2!F;W(*("H@3&EN=7@L(%-O;&%R:7,@86YD
M($9R965"4T0N"B`J"B`J(%1H:7,@:6UP;&5M96YT871I;VX@<F5Q=6ER97,@
M0VAA9"!#=6YN:6YG:&%M)W,@<&%M7V%U=&@@97AT96YS:6]N.@H@*@H@*B`@
M("`@(&AT='`Z+R]W=W<N;6%T:"YO:&EO+7-T871E+F5D=2]^8V-U;FYI;F<O
M<&%M7V%U=&@O"B`J"B`J($]P=&EO;F%L('!A<F%M971E<G,Z/'!R93X*("H@
M("`G<V5R=FEC92<@(%1H92!N86UE(&]F('1H92!004T@<V5R=FEC92!T;R!U
M<V4@=VAE;B!A=71H96YT:6-A=&EN9RX*("H@("`@("`@("`@("`@($1%1D%5
M3%0Z('!H<#PO<')E/@H@*@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<&%M+G!H<"QV(#$N,RXQ,"XQ,2`R,#`V+S`Q+S`Q(#(Q.C(X.C`W
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($IO;B!087)I
M<V4@/&IO;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!*86X@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D
M92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?075T:`H@*B\*8VQA<W,@075T:%]P
M86T@97AT96YD<R!!=71H('L*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&]F
M(&-A<&%B:6QI=&EE<RP@<V\@=&AA="!T:&4@9')I=F5R(&-A;B!R97!O<G0@
M=VAI8V@*("`@("`J(&]P97)A=&EO;G,@:70@<W5P<&]R=',@86YD('=H:6-H
M(&ET(&1O97-N)W0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)&-A<&%B:6QI=&EE<R`](&%R<F%Y*"=A9&0G("`@("`@("`@
M("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5P
M9&%T92<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G<F5S971P87-S=V]R9"<@/3X@9F%L<V4L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=R96UO=F4G("`@("`@("`]/B!F86QS92P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VQI<W0G("`@("`@("`@
M(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=')A
M;G-P87)E;G0G("`@/3X@9F%L<V4I.PH*("`@("\J*@H@("`@("H@0V]N<W1R
M=6-T<R!A(&YE=R!004T@875T:&5N=&EC871I;VX@;V)J96-T+@H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN
M9R!C;VYN96-T:6]N('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M($%U=&A?<&%M*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL*("`@("`@("!I9B`H(65M<'1Y*"1P
M87)A;7-;)W-E<G9I8V4G72DI('L*("`@("`@("`@("`@:6YI7W-E="@G<&%M
M7V%U=&@N<V5R=FEC96YA;64G+"`D<&%R86US6R=S97)V:6-E)UTI.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"%E>'1E;G-I;VY?;&]A9&5D*"=P86U?875T
M:"<I*2!["B`@("`@("`@("`@(&1L*"=P86U?875T:"YS;R<I.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($9I;F0@;W5T(&EF(&$@<V5T(&]F
M(&QO9VEN(&-R961E;G1I86QS(&%R92!V86QI9"X*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U
M<V5R260@("`@("!4:&4@=7-E<DED('1O(&-H96-K+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1C<F5D96YT:6%L<R`@06X@87)R87D@;V8@;&]G:6X@8W)E9&5N
M=&EA;',N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R
M(&]R(&YO="!T:&4@8W)E9&5N=&EA;',@87)E('9A;&ED+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?875T:&5N=&EC871E*"1U<V5R260L("1C<F5D96YT:6%L
M<RD*("`@('L*("`@("`@("!I9B`H96UP='DH)&-R961E;G1I86QS6R=P87-S
M=V]R9"==*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH7R@B3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(I+"!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E
M>'1E;G-I;VY?;&]A9&5D*"=P86U?875T:"<I*2!["B`@("`@("`@("`@($AO
M<F1E.CIF871A;"A?*")004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL
M86)L92XB*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@
M("`@(&EF("@A<&%M7V%U=&@H)'5S97))9"P@)&-R961E;G1I86QS6R=P87-S
M=V]R9"==+"`F)&5R<F]R*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W-E=$%U
M=&A%<G)O<BA!551(7U)%05-/3E]-15-304=%+"`D97)R;W(I.PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O:6US<"YP
M:'``````````````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`U-#4V
M(#$P-3$U-#,S-S0P(#`R,3<T,``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@5&AE($%U=&A?:6US<"!C
M;&%S<R!P<F]V:61E<R!B87-I8R!A=71H96YT:6-A=&EO;B!A9V%I;G-T(&%N
M($E-4U`@<V5R=F5R+@H@*B!4:&ES('=I;&P@8F4@;6]S="!B96YI9FEC:6%L
M(&EF(&%L<F5A9'D@=7-I;F<@86X@24U34"!B87-E9"!P<F5F97)E;F-E"B`J
M('-Y<W1E;2!O<B!)35-0(&)A<V5D(&%D9')E<W-B;V]K('-Y<W1E;0H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6US<"YP:'`L=B`Q+C(N
M,3`N,3`@,C`P-B\P,2\P,2`R,3HR.#HP-R!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#0M,C`P-B!-:6-H865L(%)U8FEN<VMY(#QM<G5B:6YS:T!H
M;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6-H865L
M(%)U8FEN<VMY(#QM<G5B:6YS:T!H;W)D92YO<F<^"B`J($!P86-K86=E($AO
M<F1E7T%U=&@*("HO"F-L87-S($%U=&A?:6US<"!E>'1E;F1S($%U=&A["@H@
M("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!C87!A8FEL:71I97,L('-O('1H
M870@=&AE(&1R:79E<B!C86X@<F5P;W)T('=H:6-H"B`@("`@*B!O<&5R871I
M;VYS(&ET('-U<'!O<G1S(&%N9"!W:&EC:"!I="!D;V5S;B=T+@H@("`@("H*
M("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1C87!A8FEL:71I
M97,@/2!A<G)A>2@G861D)R`@("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=U<&1A=&4G("`@("`@("`]/B!F86QS
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E<V5T<&%S<W=O
M<F0G(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M<F5M;W9E)R`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=L:7-T)R`@("`@("`@("`]/B!F86QS92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W1R86YS<&%R96YT)R`@(#T^(&9A;'-E
M*3L*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(@9G5N8W1I;VXN($-R96%T
M97,@;F5W($%U=&A?:6US<"!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P87)A;7,@02!H87-H(&-O;G1A:6YI;F<@<&%R86UE=&5R<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@075T:%]I;7-P*"1P87)A;7,@/2!A<G)A
M>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<V5T4&%R86US*"1P87)A;7,I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4')I=F%T92!A=71H96YT:6-A=&EO
M;B!F=6YC=&EO;BX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R240@57-E<FYA;64@9F]R
M($E-4U`@<V5R=F5R+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L
M<R!(87-H(&-O;G1A:6YI;F<@)W!A<W-W;W)D)R!E;&5M96YT+@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;B!4<G5E(&]N('-U8V-E<W,@+R!&86QS
M92!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?875T:&5N=&EC
M871E*"1U<V5R240L("1C<F5D96YT:6%L<RD*("`@('L*("`@("`@("!R97%U
M:7)E7V]N8V4@)TYE="])35-0+T%U=&@N<&AP)SL*"B`@("`@("`@)'1H:7,M
M/E]P87)A;7-;)W5S97)N86UE)UT@/2`D=7-E<DE$.PH@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=P87-S=V]R9"==(#T@)&-R961E;G1I86QS6R=P87-S=V]R
M9"==.PH@("`@("`@("1I;7-P(#T@)DYE=%])35-07T%U=&@Z.G-I;F=L971O
M;B@D=&AI<RT^7W!A<F%M<ULG875T:%]M971H;V0G72D["@H@("`@("`@(&EF
M("AI<U]A*"1I;7-P+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D:6US<#L*("`@("`@("!]"@H@("`@("`@("1R97-U;'0@/2`D:6US
M<"T^875T:&5N=&EC871E*"1T:&ES+3Y?<&%R86US+"!F86QS92D["B`@("`@
M("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/3E]"041,3T=)
M3BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#:&5C:W,@=&AE('!A<F%M<R!A<G)A>2!A;F0@<V5T
M<R!D969A=6QT('9A;'5E<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US($AA<V@@8V]N=&%I;FEN
M9R!)35-0('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S9710
M87)A;7,H)'!A<F%M<RD*("`@('L*("`@("`@("`D=&AI<RT^7W!A<F%M<ULG
M<V5R=F5R)UT@/2`D<&%R86US6R=S97)V97(G73L*("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG<&]R="==(#T@)'!A<F%M<ULG<&]R="==.PH@("`@("`@("1T
M:&ES+3Y?<&%R86US6R=A=71H7VUE=&AO9"==(#T@)'!A<F%M<ULG875T:%]M
M971H;V0G73L*"B`@("`@("`@:68@*&ES<V5T*"1P87)A;7-;)V%U=&A?;65C
M:&%N:7-M)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=A=71H
M7VUE8VAA;FES;2==(#T@)'!A<F%M<ULG875T:%]M96-H86YI<VTG73L*("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W-O8VME="==(#T@)'!A<F%M<ULG
M<V]C:V5T)UT["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=C;VUM86YD
M)UT@/2`D<&%R86US6R=C;VUM86YD)UT["B`@("`@("`@?0H@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O075T:"]R861I=7,N<&AP````````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,30W,30@,3`U,34T,S,W-#`@,#(R
M,C4T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B!4:&4@075T:%]R861I=7,@8VQA<W,@<')O=FED97,@
M82!2041)55,@:6UP;&5M96YT871I;VX@;V8@=&AE($AO<F1E"B`J(&%U=&AE
M;G1I8V%T:6]N('-Y<W1E;2X*("H*("H@5&AI<R!C;&%S<R!R97%U:7)E<R!T
M:&4@)W)A9&EU<R<@4$5#3"!E>'1E;G-I;VXN"B`J(%)!1$E54R!014-,(&5X
M=&5N<VEO;CH@:'1T<#HO+W!E8VPN<&AP+FYE="]P86-K86=E+W)A9&EU<PH@
M*@H@*B!/;B`J;FEX+7D@;6%C:&EN97,L('1H:7,@97AT96YS:6]N(&-A;B!B
M92!I;G-T86QL960@87,@9F]L;&]W<SH\<')E/@H@*B`@(")P96%R(&EN<W1A
M;&P@<F%D:75S(CPO<')E/@H@*@H@*B!4:&5N+"!E9&ET('EO=7(@<&AP+FEN
M:2!F:6QE(&%N9"!M86ME('-U<F4@=&AE(&9O;&QO=VEN9R!L:6YE(&ES('!R
M97-E;G0Z/'!R93X*("H@("!&;W(@5VEN9&]W<R!M86-H:6YE<SH@(&5X=&5N
M<VEO;CUP:'!?<F%D:75S+F1L;`H@*B`@($9O<B!A;&P@;W1H97)S.B`@("`@
M("`@97AT96YS:6]N/7)A9&EU<RYS;SPO<')E/@H@*@H@*B!297%U:7)E9"!P
M87)A;65T97)S.CQP<F4^"B`J("`@)VAO<W0G("`@(%1H92!2041)55,@:&]S
M="!T;R!U<V4@*$E0(&%D9')E<W,@;W(@9G5L;'D@<75A;&EF:65D"B`J("`@
M("`@("`@("`@(&AO<W1N86UE*2X*("H@("`G;65T:&]D)R`@5&AE(%)!1$E5
M4R!M971H;V0@=&\@=7-E(&9O<B!V86QI9&%T:6YG('1H92!R97%U97-T+@H@
M*B`@("`@("`@("`@("!%:71H97(Z("=005`G+"`G0TA!4%]-1#4G+"`G35-#
M2$%0=C$G+"!O<B`G35-#2$%0=C(G+@H@*B`@("`@("`@("`@("`J*B!#55)2
M14Y43%DL(&]N;'D@)U!!4"<@:7,@<W5P<&]R=&5D+B`J*@H@*B`@("=S96-R
M970G("!4:&4@4D%$2553('-H87)E9"!S96-R970@<W1R:6YG(&9O<B!T:&4@
M:&]S="X@5&AE"B`J("`@("`@("`@("`@(%)!1$E54R!P<F]T;V-O;"!I9VYO
M<F5S(&%L;"!B=70@=&AE(&QE861I;F<@,3(X(&)Y=&5S"B`J("`@("`@("`@
M("`@(&]F('1H92!S:&%R960@<V5C<F5T+CPO<')E/@H@*@H@*B!/<'1I;VYA
M;"!P87)A;65T97)S.CQP<F4^"B`J("`@)VYA<R<@("`@("!4:&4@4D%$2553
M($Y!4R!I9&5N=&EF:65R('1O('5S92X*("H@("`@("`@("`@("`@($1%1D%5
M3%0Z(%1H92!V86QU92!O9B`D7U-%4E9%4ELG2%144%](3U-4)UT@;W(L(&EF
M(&YO=`H@*B`@("`@("`@("`@("`@("`@("`@("`@9&5F:6YE9"P@=&AE;B`G
M;&]C86QH;W-T)RX*("H@("`G<&]R="<@("`@(%1H92!P;W)T('1O('5S92!O
M;B!T:&4@4D%$2553('-E<G9E<BX*("H@("`@("`@("`@("`@($1%1D%53%0Z
M(%=H871E=F5R('1H92!L;V-A;"!S>7-T96T@:61E;G1I9FEE<R!A<R!T:&4*
M("H@("`@("`@("`@("`@("`@("`@("`@("=R861I=7,G(%5$4"!P;W)T"B`J
M("`@)W)E=')I97,G("!4:&4@;6%X:6UU;2!N=6UB97(@;V8@<F5P96%T960@
M<F5Q=65S=',@=&\@;6%K92!B969O<F4*("H@("`@("`@("`@("`@(&=I=FEN
M9R!U<"X*("H@("`@("`@("`@("`@($1%1D%53%0Z(#,*("H@("`G<W5F9FEX
M)R`@(%1H92!D;VUA:6X@;F%M92!T;R!A9&0@=&\@=6YQ=6%L:69I960@=7-E
M<B!N86UE<RX*("H@("`@("`@("`@("`@($1%1D%53%0Z($Y/3D4*("H@("`G
M=&EM96]U="<@(%1H92!T:6UE;W5T(&9O<B!R96-E:79I;F<@<F5P;&EE<R!F
M<F]M('1H92!S97)V97(@*&EN"B`J("`@("`@("`@("`@("!S96-O;F1S*2X*
M("H@("`@("`@("`@("`@($1%1D%53%0Z(#,@<V5C;VYD<SPO<')E/@H@*@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<"QV
M(#$N,C0N."XX(#(P,#8O,#$O,#$@,C$Z,C@Z,#<@:F%N($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`R+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z
M0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A
M9&\N961U/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R
M9&5?075T:`H@*B\*8VQA<W,@075T:%]R861I=7,@97AT96YD<R!!=71H('L*
M"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&]F(&-A<&%B:6QI=&EE<RP@<V\@
M=&AA="!T:&4@9')I=F5R(&-A;B!R97!O<G0@=VAI8V@*("`@("`J(&]P97)A
M=&EO;G,@:70@<W5P<&]R=',@86YD('=H:6-H(&ET(&1O97-N)W0N"B`@("`@
M*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&-A<&%B:6QI
M=&EE<R`](&%R<F%Y*"=A9&0G("`@("`@("`@("`]/B!F86QS92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W5P9&%T92<@("`@("`@(#T^(&9A
M;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5S971P87-S
M=V]R9"<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=R96UO=F4G("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)VQI<W0G("`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G=')A;G-P87)E;G0G("`@/3X@9F%L
M<V4I.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!2041)55,@
M875T:&5N=&EC871I;VX@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N('!A
M<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N($%U=&A?<F%D:75S*"1P
M87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("@A571I;#HZ97AT
M96YS:6]N17AI<W1S*"=R861I=7,G*2D@>PH@("`@("`@("`@("!(;W)D93HZ
M9F%T86PH)T%U=&A?<F%D:75S(')E<75I<F5S('1H92!R861I=7,@4$5#3"!E
M>'1E;G-I;VX@=&\@8F4@;&]A9&5D+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7W-E=%!A<F%M<R@D<&%R86US
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!P87)A;65T97)S+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US("!4:&4@<&%R86UE=&5R(&AA<V@N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]S971087)A;7,H)'!A<F%M<RD*("`@('L*("`@("`@
M("`O*B!!(%)!1$E54R!H;W-T(&ES(')E<75I<F5D+B`J+PH@("`@("`@(&EF
M("AE;7!T>2@D<&%R86US6R=H;W-T)UTI*2!["B`@("`@("`@("`@($AO<F1E
M.CIF871A;"@G075T:%]R861I=7,@<F5Q=6ER97,@82!2041)55,@:&]S="!T
M;R!C;VYN96-T('1O+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@
M?0H*("`@("`@("`O*B!!(%)!1$E54R!S96-R970@<W1R:6YG(&ES(')E<75I
M<F5D+B`J+PH@("`@("`@(&EF("AE;7!T>2@D<&%R86US6R=S96-R970G72DI
M('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*"=!=71H7W)A9&EU<R!R97%U
M:7)E<R!A(%)!1$E54R!S96-R970@<W1R:6YG+B<L(%]?1DE,15]?+"!?7TQ)
M3D5?7RD["B`@("`@("`@?0H*("`@("`@("`O*B!!(%)!1$E54R!A=71H96YT
M:6-A=&EO;B!M971H;V0@:7,@<F5Q=6ER960N("HO"B`@("`@("`@:68@*&5M
M<'1Y*"1P87)A;7-;)VUE=&AO9"==*2D@>PH@("`@("`@("`@("!(;W)D93HZ
M9F%T86PH)T%U=&A?<F%D:75S(')E<75I<F5S(&$@4D%$2553(&%U=&AE;G1I
M8V%T:6]N(&UE=&AO9"XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@
M('T*"B`@("`@("`@+RH@4D%$2553($Y!4R!)9&5N=&EF:65R+B`J+PH@("`@
M("`@(&EF("AE;7!T>2@D<&%R86US6R=N87,G72DI('L*("`@("`@("`@("`@
M)'!A<F%M<ULG;F%S)UT@/2!I<W-E="@D7U-%4E9%4ELG2%144%](3U-4)UTI
M(#\@)%]315)615);)TA45%!?2$]35"<*72`Z("=L;V-A;&AO<W0G.PH@("`@
M("`@('T*"B`@("`@("`@+RH@4W5F9FEX('1O(&%D9"!T;R!U;G%U86QI9FEE
M9"!U<V5R(&YA;65S+B`J+PH@("`@("`@(&EF("AE;7!T>2@D<&%R86US6R=S
M=69F:7@G72DI('L*("`@("`@("`@("`@)'!A<F%M<ULG<W5F9FEX)UT@/2`G
M)SL*("`@("`@("!]"@H@("`@("`@("\J(%1H92!2041)55,@<&]R="!T;R!U
M<V4N("HO"B`@("`@("`@:68@*&5M<'1Y*"1P87)A;7-;)W!O<G0G72DI('L*
M("`@("`@("`@("`@)'!A<F%M<ULG<&]R="==(#T@,#L*("`@("`@("!]"@H@
M("`@("`@("\J($UA>&EM=6T@;G5M8F5R(&]F(')E=')I97,N("HO"B`@("`@
M("`@:68@*&5M<'1Y*"1P87)A;7-;)W)E=')I97,G72DI('L*("`@("`@("`@
M("`@)'!A<F%M<ULG<F5T<FEE<R==(#T@,SL*("`@("`@("!]"@H@("`@("`@
M("\J(%)!1$E54R!T:6UE;W5T+B`J+PH@("`@("`@(&EF("AE;7!T>2@D<&%R
M86US6R=T:6UE;W5T)UTI*2!["B`@("`@("`@("`@("1P87)A;7-;)W1I;65O
M=70G72`](#,["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]
M("1P87)A;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&:6YD(&]U="!I9B!A
M('-E="!O9B!L;V=I;B!C<F5D96YT:6%L<R!A<F4@=F%L:60N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D=7-E<FYA;64@("`@5&AE('5S97))9"!T;R!C:&5C:RX*("`@("`J
M($!P87)A;2!A<G)A>2`D8W)E9&5N=&EA;',@($%N(&%R<F%Y(&]F(&QO9VEN
M(&-R961E;G1I86QS+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@1F]R(')A9&EU<RP@=&AI<R!M=7-T(&-O;G1A:6X@82!P87-S=V]R9`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@96YT<GDN"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@
M8W)E9&5N=&EA;',@87)E('9A;&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M875T:&5N=&EC871E*"1U<V5R;F%M92P@)&-R961E;G1I86QS*0H@("`@>PH@
M("`@("`@("\J(%!A<W-W;W)D(&ES(')E<75I<F5D+B`J+PH@("`@("`@(&EF
M("@A:7-S970H)&-R961E;G1I86QS6R=P87-S=V]R9"==*2D@>PH@("`@("`@
M("`@("!(;W)D93HZ9F%T86PH7R@B4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!
M1$E54R!A=71H96YT:6-A=&EO;BXB*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M("`@("`@("!]"@H@("`@("`@("1R97,@/2!R861I=7-?875T:%]O<&5N*"D[
M"B`@("`@("`@<F%D:75S7V%D9%]S97)V97(H)')E<RP@)'1H:7,M/E]P87)A
M;7-;)VAO<W0G72P@)'1H:7,M/E]P87)A;7-;)W!O<G0G72P@)'1H:7,M/E]P
M87)A;7-;)W-E8W)E="==+"`D=&AI<RT^7W!A<F%M<ULG=&EM96]U="==+"`D
M=&AI<RT^7W!A<F%M<ULG<F5T<FEE<R==*3L*("`@("`@("!R861I=7-?8W)E
M871E7W)E<75E<W0H)')E<RP@4D%$25537T%#0T534U]215%515-4*3L*("`@
M("`@("!R861I=7-?<'5T7V%T='(H)')E<RP@4D%$25537TY!4U])1$5.5$E&
M2452+"`D=&AI<RT^7W!A<F%M<ULG;F%S)UTI.PH@("`@("`@(')A9&EU<U]P
M=71?871T<B@D<F5S+"!2041)55-?3D%37U!/4E1?5%E012P@4D%$25537U9)
M4E1504PI.PH@("`@("`@(')A9&EU<U]P=71?871T<B@D<F5S+"!2041)55-?
M4T525DE#15]465!%+"!2041)55-?1E)!345$*3L*("`@("`@("!R861I=7-?
M<'5T7V%T='(H)')E<RP@4D%$25537T9204U%1%]04D]43T-/3"P@4D%$2553
M7U!04"D["B`@("`@("`@<F%D:75S7W!U=%]A='1R*"1R97,L(%)!1$E54U]#
M04Q,24Y'7U-4051)3TY?240L(&ES<V5T*"1?4T525D526R=214U/5$5?2$]3
M5"==*2`_("1?4T525D526R=214U/5$5?2$]35"==(#H@)S$R-RXP+C`N,2<I
M.PH*("`@("`@("`O*B!);G-E<G0@=7-E<FYA;64O<&%S<W=O<F0@:6YT;R!R
M97%U97-T+B`J+PH@("`@("`@(')A9&EU<U]P=71?871T<B@D<F5S+"!2041)
M55-?55-%4E].04U%+"`D=7-E<FYA;64I.PH@("`@("`@(')A9&EU<U]P=71?
M871T<B@D<F5S+"!2041)55-?55-%4E]005-35T]21"P@)&-R961E;G1I86QS
M6R=P87-S=V]R9"==*3L*"B`@("`@("`@+RH@4V5N9"!R97%U97-T+B`J+PH@
M("`@("`@("1S=6-C97-S(#T@<F%D:75S7W-E;F1?<F5Q=65S="@D<F5S*3L*
M"B`@("`@("`@<W=I=&-H("@D<W5C8V5S<RD@>PH@("`@("`@(&-A<V4@4D%$
M25537T%#0T534U]!0T-%4%0Z"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH*
M("`@("`@("!C87-E(%)!1$E54U]!0T-%4U-?4D5*14-4.@H@("`@("`@("`@
M("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/3E]-15-304=%+"!?
M*")!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(I
M*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH*("`@("`@("!D969A=6QT
M.@H@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/
M3E]-15-304=%+"!R861I=7-?<W1R97)R;W(H)')E<RDI.PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O87!P;&EC871I
M;VXN<&AP````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$T-#4P(#$P
M-3$U-#,S-S0P(#`R,S(V-0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@5&AE($%U=&A?87!P;&EC871I
M;VX@8VQA<W,@<')O=FED97,@82!W<F%P<&5R(&%R;W5N9`H@*B!A<'!L:6-A
M=&EO;BUP<F]V:61E9"!(;W)D92!A=71H96YT:6-A=&EO;B!W:&EC:"!F:71S
M(&EN<VED92!T:&4*("H@2&]R9&4@075T:#HZ($%022X*("H*("H@4F5Q=6ER
M960@<&%R86UE=&5R<SH\<')E/@H@*B`@("=A<'`G("!4:&4@87!P;&EC871I
M;VX@=VAI8V@@:7,@<')O=FED:6YG(&%U=&AE;G1I8V%T:6]N+CPO<')E/@H@
M*@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]!=71H+T%U=&@O87!P;&EC871I
M;VXN<&AP+'8@,2XR-RXQ,"XQ,B`R,#`V+S`X+S$T(#`R.C0X.C0X(&-H=6-K
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I
M;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T%U=&@*("HO"F-L
M87-S($%U=&A?87!P;&EC871I;VX@97AT96YD<R!!=71H('L*"B`@("`O*BH*
M("`@("`J($%N(&%R<F%Y(&]F(&-A<&%B:6QI=&EE<RP@<V\@=&AA="!T:&4@
M9')I=F5R(&-A;B!R97!O<G0@=VAI8V@*("`@("`J(&]P97)A=&EO;G,@:70@
M<W5P<&]R=',@86YD('=H:6-H(&ET(&1O97-N)W0N"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&-A<&%B:6QI=&EE<R`](&%R
M<F%Y*"=A9&0G("`@("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W5P9&%T92<@("`@("`@(#T^(&9A;'-E+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5S971P87-S=V]R9"<@/3X@
M9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R96UO=F4G
M("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)VQI<W0G("`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G=')A;G-P87)E;G0G("`@/3X@9F%L<V4I.PH*("`@
M("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!!<'!L:6-A=&EO;B!A=71H
M96YT:6-A=&EO;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE
M=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@075T:%]A<'!L:6-A=&EO;B@D
M<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^7W-E=%!A
M<F%M<R@D<&%R86US*3L*("`@('T*"B`@("`O*BH*("`@("`J(%%U97)I97,@
M=&AE(&-U<G)E;G0@075T:"!O8FIE8W0@=&\@9FEN9"!O=70@:68@:70@<W5P
M<&]R=',@=&AE(&=I=F5N"B`@("`@*B!C87!A8FEL:71Y+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&-A<&%B:6QI='D@(%1H92!C87!A8FEL:71Y
M('1O('1E<W0@9F]R+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@
M5VAE=&AE<B!O<B!N;W0@=&AE(&-A<&%B:6QI='D@:7,@<W5P<&]R=&5D+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!H87-#87!A8FEL:71Y*"1C87!A8FEL:71Y
M*0H@("`@>PH@("`@("`@('-T871I8R`D;&]A9&5D(#T@87)R87DH*3L*"B`@
M("`@("`@)&UE=&AO9',@/2!A<G)A>2@G;&ES="<@/3X@)W5S97),:7-T)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("=A9&0G(#T^("=A9&15<V5R)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("=U<&1A=&4G(#T^("=U<&1A=&55
M<V5R)RP*("`@("`@("`@("`@("`@("`@("`@("`@("=R96UO=F4G(#T^("=R
M96UO=F55<V5R)RD["@H@("`@("`@(&EF("AE;7!T>2@D;&]A9&5D6R1C87!A
M8FEL:71Y72D@)B8@:7-S970H)&UE=&AO9'-;)&-A<&%B:6QI='E=*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^8V%P86)I;&ET:65S6R1C87!A8FEL:71Y72`]
M("1'3$]"04Q36R=R96=I<W1R>2==+3YH87--971H;V0H)&UE=&AO9'-;)&-A
M<&%B:6QI='E=+"`D=&AI<RT^7W!A<F%M<ULG87!P)UTI.PH@("`@("`@("`@
M("`D;&]A9&5D6R1C87!A8FEL:71Y72`]('1R=64["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@(65M<'1Y*"1T:&ES+3YC87!A8FEL:71I97-;)&-A<&%B
M:6QI='E=*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!C;VYN96-T:6]N
M('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT
M86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@7W-E=%!A<F%M<R@D<&%R86US*0H@("`@>PH@("`@("`@($AO<F1E
M.CIA<W-E<G1$<FEV97)#;VYF:6<H)'!A<F%M<RP@)V%U=&@G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V%P<"<I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%U=&AE;G1I8V%T:6]N
M(&%P<&QI8V%T:6]N)RD["@H@("`@("`@(&EF("AE;7!T>2@D1TQ/0D%,4ULG
M<F5G:7-T<GDG72T^87!P;&EC871I;VYS6R1P87)A;7-;)V%P<"==72DI('L*
M("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*"1P87)A;7-;)V%P<"==("X@)R!I
M<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN)RP@7U]&
M24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?
M<&%R86US(#T@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J($9I;F0@
M;W5T(&EF(&$@<V5T(&]F(&QO9VEN(&-R961E;G1I86QS(&%R92!V86QI9"X*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1U<V5R260@("`@("!4:&4@=7-E<DED('1O(&-H96-K
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L<R`@5&AE(&-R961E
M;G1I86QS('1O('5S92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%=H971H97(@;W(@;F]T('1H92!C<F5D96YT:6%L<R!A<F4@=F%L:60N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]A=71H96YT:6-A=&4H)'5S97))9"P@)&-R
M961E;G1I86QS*0H@("`@>PH@("`@("`@(&EF("@A)$=,3T)!3%-;)W)E9VES
M=')Y)UTM/FAA<TUE=&AO9"@G875T:&5N=&EC871E)RP@)'1H:7,M/E]P87)A
M;7-;)V%P<"==*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH)'1H:7,M
M/E]P87)A;7-;)V%P<"==("X@)R!D;V5S(&YO="!P<F]V:61E(&%N(&%U=&AE
M;G1I8V%T92@I(&UE=&AO9"XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F-A
M;&Q">5!A8VMA9V4H)'1H:7,M/E]P87)A;7-;)V%P<"==+"`G875T:&5N=&EC
M871E)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)W5S97))9"<@/3X@)'5S97))9"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)V-R961E;G1I86QS)R`]/B`D8W)E9&5N=&EA;',L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=P87)A;7,G(#T^("1T:&ES+3Y?<&%R86US*2D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FX@=&AE(%5222!O9B!T:&4@;&]G:6X@<V-R965N
M(&9O<B!T:&ES(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"X*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1A<'`@(%1H92!A<'!L:6-A=&EO;B!T;R!U<V4N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1U<FP@(%1H92!54DP@=&\@<F5D:7)E8W0@=&\@869T97(@;&]G
M:6XN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!L;V=I;B!S
M8W)E96X@55))+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T3&]G:6Y38W)E
M96XH)&%P<"`]("=H;W)D92<L("1U<FP@/2`G)RD*("`@('L*("`@("`@("!R
M971U<FX@<&%R96YT.CI?9V5T3&]G:6Y38W)E96XH)'1H:7,M/E]P87)A;7-;
M)V%P<"==+"`D=7)L*3L*("`@('T*"B`@("`O*BH*("`@("`J($QI<W0@86QL
M('5S97)S(&EN('1H92!S>7-T96TN"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@5&AE(&%R<F%Y(&]F('5S97))9',L(&]R(&$@4$5!4E]%<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=%5S
M97)S*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/FAA<T-A<&%B:6QI='DH
M)VQI<W0G*2D@>PH@("`@("`@("`@("!R971U<FX@)$=,3T)!3%-;)W)E9VES
M=')Y)UTM/F-A;&Q">5!A8VMA9V4H)'1H:7,M/E]P87)A;7-;)V%P<"==+"`G
M=7-E<DQI<W0G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@G=6YS=7!P;W)T960G*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@82!S970@;V8@875T:&5N=&EC
M871I;VX@8W)E9&5N=&EA;',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=7-E<DED("`@("`@5&AE('5S97))9"!T;R!A9&0N"B`@("`@*B!`<&%R
M86T@87)R87D@)&-R961E;G1I86QS("!4:&4@8W)E9&5N=&EA;',@=&\@=7-E
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S
M<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&%D9%5S97(H)'5S97))9"P@)&-R961E;G1I86QS*0H@
M("`@>PH@("`@("`@(&EF("@D=&AI<RT^:&%S0V%P86)I;&ET>2@G861D)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1'3$]"04Q36R=R96=I<W1R>2==+3YC
M86QL0GE086-K86=E*"1T:&ES+3Y?<&%R86US6R=A<'`G72P@)V%D9%5S97(G
M+"!A<G)A>2@D=7-E<DED+"`D8W)E9&5N=&EA;',I*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G=6YS
M=7!P;W)T960G*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!5
M<&1A=&4@82!S970@;V8@875T:&5N=&EC871I;VX@8W)E9&5N=&EA;',N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;VQD240@("`@("`@5&AE(&]L
M9"!U<V5R260N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=)1"`@("`@("!4
M:&4@;F5W('5S97))9"X*("`@("`J($!P87)A;2!A<G)A>2`D8W)E9&5N=&EA
M;',@(%1H92!N97<@8W)E9&5N=&EA;',*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!U<&1A=&55<V5R
M*"1O;&1)1"P@)&YE=TE$+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@
M:68@*"1T:&ES+3YH87-#87!A8FEL:71Y*"=U<&1A=&4G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F-A;&Q">5!A8VMA
M9V4H)'1H:7,M/E]P87)A;7-;)V%P<"==+"`G=7!D871E57-E<B<L(&%R<F%Y
M*"1O;&1)1"P@)&YE=TE$+"`D8W)E9&5N=&EA;',I*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G=6YS
M=7!P;W)T960G*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$
M96QE=&4@82!S970@;V8@875T:&5N=&EC871I;VX@8W)E9&5N=&EA;',N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("!4:&4@=7-E<DED
M('1O(&1E;&5T92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E
M(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F55<V5R*"1U<V5R260I"B`@
M("!["B`@("`@("`@:68@*"1T:&ES+3YH87-#87!A8FEL:71Y*"=R96UO=F4G
M*2D@>PH@("`@("`@("`@("`D<F5S=6QT(#T@)$=,3T)!3%-;)W)E9VES=')Y
M)UTM/F-A;&Q">5!A8VMA9V4H)'1H:7,M/E]P87)A;7-;)V%P<"==+"`G<F5M
M;W9E57-E<B<L(&%R<F%Y*"1U<V5R260I*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G=6YS=7!P;W)T
M960G*3L*("`@("`@("!]"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^<F5M;W9E57-E<D1A=&$H
M)'5S97))9"D["B`@("!]"@I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]I
M0V%L96YD87(`````````````````````````````````````````````````
M```````````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#`P,"`Q,#4Q-30S,S<T,"`P,C$Q-#<`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+VE#86QE;F1A<B]V;F]T92YP:'``````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-#8R(#$P-3$U-#,S-S0P(#`R,S`W
M-@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D92]I0V%L96YD87(N<&AP)SL*"B\J
M*@H@*B!#;&%S<R!R97!R97-E;G1I;F<@=DYO=&5S+@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]I0V%L96YD87(O:4-A;&5N9&%R+W9N;W1E+G!H<"QV(#$N
M,RXQ,"XU(#(P,#8O,#,O,#,@,#DZ,#<Z,S$@:F%N($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`R,#`S+3(P,#8@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N
M:&%L;"YC;RYN>CX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($MA<G-T
M96X@1F]U<FUO;G0@/&9O=7)M;VYT0&=M>"YD93X*("H@0'!A8VMA9V4@2&]R
M9&5?:4-A;&5N9&%R"B`J+PIC;&%S<R!(;W)D95]I0V%L96YD87)?=FYO=&4@
M97AT96YD<R!(;W)D95]I0V%L96YD87(@>PH*("`@(&9U;F-T:6]N($AO<F1E
M7VE#86QE;F1A<E]V;F]T92@D=F5R<VEO;B`]("<Q+C$G*0H@("`@>PH@("`@
M("`@(')E='5R;B!P87)E;G0Z.DAO<F1E7VE#86QE;F1A<B@D=F5R<VEO;BD[
M"B`@("!]"@H@("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@
M<F5T=7)N("=V3F]T92<["B`@("!]"@H@("`@9G5N8W1I;VX@<&%R<V5V0V%L
M96YD87(H)&1A=&$I"B`@("!["B`@("`@("`@<F5T=7)N('!A<F5N=#HZ<&%R
M<V5V0V%L96YD87(H)&1A=&$L("=63D]412<I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@56YL:6ME('9E=F5N="!A;F0@=G1O9&\L(&$@=FYO=&4@:7,@;F]R
M;6%L;'D@;F]T(&5N8VQO<V5D(&EN(&%N"B`@("`@*B!I0V%L96YD87(@8V]N
M=&%I;F5R+B`H0D5'24XN+D5.1"D*("`@("`J+PH@("`@9G5N8W1I;VX@97AP
M;W)T=D-A;&5N9&%R*"D*("`@('L*("`@("`@("`D<F5Q=6ER961!='1R:6)U
M=&5S6R="3T19)UT@/2`G)SL*("`@("`@("`D<F5Q=6ER961!='1R:6)U=&5S
M6R=615)324].)UT@/2`G,2XQ)SL*"B`@("`@("`@9F]R96%C:"`H)')E<75I
M<F5D071T<FEB=71E<R!A<R`D;F%M92`]/B`D9&5F875L=%]V86QU92D@>PH@
M("`@("`@("`@("!I9B`H:7-?82@D=&AI<RT^9V5T871T<FEB=71E*"1N86UE
M*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E
M=$%T=')I8G5T92@D;F%M92P@)&1E9F%U;'1?=F%L=64I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]E>'!O<G1V
M1&%T82@G5DY/5$4G*3L*("`@('T*"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O:4-A;&5N
M9&%R+W9J;W5R;F%L+G!H<```````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#$T,3$@,3`U,34T,S,W-#`@,#(S-3<T`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B!#;&%S<R!R97!R
M97-E;G1I;F<@=DIO=7)N86QS+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]I
M0V%L96YD87(O:4-A;&5N9&%R+W9J;W5R;F%L+G!H<"QV(#$N."XQ,"XT(#(P
M,#8O,#$O,#$@,C$Z,C@Z-#<@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`S+3(P,#8@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN
M>CX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@
M/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!S:6YC92`@($AO<F1E(#,N
M,`H@*B!`<&%C:V%G92!(;W)D95]I0V%L96YD87(*("HO"F-L87-S($AO<F1E
M7VE#86QE;F1A<E]V:F]U<FYA;"!E>'1E;F1S($AO<F1E7VE#86QE;F1A<B![
M"@H@("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N
M("=V2F]U<FYA;"<["B`@("!]"@H@("`@9G5N8W1I;VX@<&%R<V5V0V%L96YD
M87(H)&1A=&$I"B`@("!["B`@("`@("`@<&%R96YT.CIP87)S979#86QE;F1A
M<B@D9&%T82P@)U9*3U523D%,)RD["B`@("!]"@H@("`@9G5N8W1I;VX@97AP
M;W)T=D-A;&5N9&%R*"D*("`@('L*("`@("`@("!R971U<FX@<&%R96YT.CI?
M97AP;W)T=D1A=&$H)U9*3U523D%,)RD["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M:4-A;&5N9&%R+W9T;V1O+G!H<```````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#0U,C$@,3`U,34T,S,W-#`@,#(S,#<T`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B!#;&%S
M<R!R97!R97-E;G1I;F<@=E1O9&]S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R
M:R]I0V%L96YD87(O:4-A;&5N9&%R+W9T;V1O+G!H<"QV(#$N,3,N,3`N-"`R
M,#`V+S`Q+S`Q(#(Q.C(X.C0W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,C`P,RTR,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N
M;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE
M(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!(;W)D92`S
M+C`*("H@0'!A8VMA9V4@2&]R9&5?:4-A;&5N9&%R"B`J+PIC;&%S<R!(;W)D
M95]I0V%L96YD87)?=G1O9&\@97AT96YD<R!(;W)D95]I0V%L96YD87(@>PH*
M("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G
M=E1O9&\G.PH@("`@?0H*("`@(&9U;F-T:6]N('!A<G-E=D-A;&5N9&%R*"1D
M871A*0H@("`@>PH@("`@("`@('!A<F5N=#HZ<&%R<V5V0V%L96YD87(H)&1A
M=&$L("=65$]$3R<I.PH@("`@?0H*("`@(&9U;F-T:6]N(&5X<&]R='9#86QE
M;F1A<B@I"B`@("!["B`@("`@("`@<F5T=7)N('!A<F5N=#HZ7V5X<&]R='9$
M871A*"=65$]$3R<I.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R="!T
M:&ES('1O9&\@=&\@86X@87)R87D@;V8@871T<FEB=71E<RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A>2!C;VYT86EN:6YG('1H92!D971A
M:6QS(&]F('1H92!T;V1O(&EN(&$@:&%S:`H@("`@("H@("`@("`@("`@("`@
M("`@87,@=7-E9"!B>2!(;W)D92!A<'!L:6-A=&EO;G,N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('1O07)R87DH*0H@("`@>PH@("`@("`@("1T;V1O(#T@87)R
M87DH*3L*"B`@("`@("`@)&YA;64@/2`D=&AI<RT^9V5T071T<FEB=71E*"=3
M54U-05)9)RD["B`@("`@("`@:68@*"%I<U]A<G)A>2@D;F%M92D@)B8@(6ES
M7V$H)&YA;64L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@)'1O9&];
M)VYA;64G72`]("1N86UE.PH@("`@("`@('T*("`@("`@("`D9&5S8R`]("1T
M:&ES+3YG971!='1R:6)U=&4H)T1%4T-225!424].)RD["B`@("`@("`@:68@
M*"%I<U]A<G)A>2@D9&5S8RD@)B8@(6ES7V$H)&1E<V,L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@)'1O9&];)V1E<V,G72`]("1D97-C.PH@("`@
M("`@('T*"B`@("`@("`@)'!R:6]R:71Y(#T@)'1H:7,M/F=E=$%T=')I8G5T
M92@G4%))3U))5%DG*3L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1P<FEO<FET
M>2D@)B8@(6ES7V$H)'!R:6]R:71Y+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("1T;V1O6R=P<FEO<FET>2==(#T@)'!R:6]R:71Y.PH@("`@("`@
M('T*"B`@("`@("`@)&1U92`]("1T:&ES+3YG971!='1R:6)U=&4H)T144U1!
M35`G*3L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1D=64I("8F("%I<U]A*"1D
M=64L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@)'1O9&];)V1U92==
M(#T@)&1U93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&]D;SL*("`@
M('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@871T<FEB=71E<R!F;W(@=&AI
M<R!T;V1O(&ET96T@9G)O;2!A;B!A<G)A>2X*("`@("`J"B`@("`@*B!`<&%R
M86T@87)R87D@)'1O9&\@($%R<F%Y(&-O;G1A:6YI;F<@=&AE(&1E=&%I;',@
M;V8@=&AE('1O9&\@:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@=&AE
M('-A;64@9F]R;6%T('1H870@=&]!<G)A>2@I(&5X<&]R=',N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&9R;VU!<G)A>2@D=&]D;RD*("`@('L*("`@("`@("!I
M9B`H:7-S970H)'1O9&];)VYA;64G72DI('L*("`@("`@("`@("`@)'1H:7,M
M/G-E=$%T=')I8G5T92@G4U5-34%262<L("1T;V1O6R=N86UE)UTI.PH@("`@
M("`@('T*("`@("`@("!I9B`H:7-S970H)'1O9&];)V1E<V,G72DI('L*("`@
M("`@("`@("`@)'1H:7,M/G-E=$%T=')I8G5T92@G1$530U))4%1)3TXG+"`D
M=&]D;ULG9&5S8R==*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D
M=&]D;ULG<')I;W)I='DG72DI('L*("`@("`@("`@("`@)'1H:7,M/G-E=$%T
M=')I8G5T92@G4%))3U))5%DG+"`D=&]D;ULG<')I;W)I='DG72D["B`@("`@
M("`@?0H*("`@("`@("!I9B`H:7-S970H)'1O9&];)V1U92==*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^<V5T071T<FEB=71E*"=$5%-404U0)RP@)'1O9&];
M)V1U92==*3L*("`@("`@("!]"B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O:4-A;&5N9&%R+W9E=F5N="YP:'``````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,C`R-30@,3`U,34T,S,W-#`@,#(S,C4Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B!#;&%S<R!R97!R97-E;G1I;F<@=D5V96YT<RX*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO:4-A;&5N9&%R+VE#86QE;F1A<B]V979E;G0N<&AP
M+'8@,2XS,2XQ,"XX(#(P,#8O,#$O,#$@,C$Z,C@Z-#<@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EK92!#;V-H<F%N92`\;6EK94!G
M<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!S
M:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]I0V%L96YD87(*
M("HO"F-L87-S($AO<F1E7VE#86QE;F1A<E]V979E;G0@97AT96YD<R!(;W)D
M95]I0V%L96YD87(@>PH*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@
M("`@("`@(')E='5R;B`G=D5V96YT)SL*("`@('T*"B`@("!F=6YC=&EO;B!P
M87)S979#86QE;F1A<B@D9&%T82D*("`@('L*("`@("`@("!P87)E;G0Z.G!A
M<G-E=D-A;&5N9&%R*"1D871A+"`G5D5614Y4)RD["B`@("!]"@H@("`@9G5N
M8W1I;VX@97AP;W)T=D-A;&5N9&%R*"D*("`@('L*("`@("`@("`O+R!$969A
M=6QT('9A;'5E<RX*("`@("`@("`D<F5Q=6ER961!='1R:6)U=&5S(#T@87)R
M87DH*3L*("`@("`@("`D<F5Q=6ER961!='1R:6)U=&5S6R=$5%-404U0)UT@
M/2!T:6UE*"D["B`@("`@("`@)')E<75I<F5D071T<FEB=71E<ULG3U)'04Y)
M6D52)UT@/2`G56YK;F]W;B!/<F=A;FEZ97(G.PH@("`@("`@("1R97%U:7)E
M9$%T=')I8G5T97-;)U5)1"==(#T@)'1H:7,M/E]E>'!O<G1$871E5&EM92AT
M:6UE*"DI("X@)T`G("X@*&ES<V5T*"1?4T525D526R=315)615)?3D%-12==
M*2`_("1?4T525D526R=315)615)?3D%-12==(#H@)VQO8V%L:&]S="<I.PH*
M("`@("`@("`D;65T:&]D(#T@(65M<'1Y*"1T:&ES+3Y?8V]N=&%I;F5R*2`_
M"B`@("`@("`@("`@("1T:&ES+3Y?8V]N=&%I;F5R+3YG971!='1R:6)U=&4H
M)TU%5$A/1"<I(#H@)U!50DQ)4T@G.PH*("`@("`@("!S=VET8V@@*"1M971H
M;V0I('L*("`@("`@("!C87-E("=054),25-()SH*("`@("`@("`@("`@)')E
M<75I<F5D071T<FEB=71E<ULG1%135$%25"==(#T@=&EM92@I.PH@("`@("`@
M("`@("`D<F5Q=6ER961!='1R:6)U=&5S6R=354U-05)9)UT@/2`G)SL*("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)U)%455%4U0G.@H@("`@
M("`@("`@("`D<F5Q=6ER961!='1R:6)U=&5S6R=!5%1%3D1%12==(#T@)R<[
M"B`@("`@("`@("`@("1R97%U:7)E9$%T=')I8G5T97-;)T144U1!4E0G72`]
M('1I;64H*3L*("`@("`@("`@("`@)')E<75I<F5D071T<FEB=71E<ULG4U5-
M34%262==(#T@)R<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E
M("=215!,62<Z"B`@("`@("`@("`@("1R97%U:7)E9$%T=')I8G5T97-;)T%4
M5$5.1$5%)UT@/2`G)SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@)T%$1"<Z"B`@("`@("`@("`@("1R97%U:7)E9$%T=')I8G5T97-;)T14
M4U1!4E0G72`]('1I;64H*3L*("`@("`@("`@("`@)')E<75I<F5D071T<FEB
M=71E<ULG4T51545.0T4G72`](#$["B`@("`@("`@("`@("1R97%U:7)E9$%T
M=')I8G5T97-;)U-534U!4EDG72`]("<G.PH@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@8V%S92`G0T%.0T5,)SH*("`@("`@("`@("`@)')E<75I<F5D
M071T<FEB=71E<ULG051414Y$144G72`]("<G.PH@("`@("`@("`@("`D<F5Q
M=6ER961!='1R:6)U=&5S6R=315%514Y#12==(#T@,3L*("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@(&-A<V4@)U)%1E)%4T@G.@H@("`@("`@("`@("`D
M<F5Q=6ER961!='1R:6)U=&5S6R=!5%1%3D1%12==(#T@)R<["B`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)')E<75I
M<F5D071T<FEB=71E<R!A<R`D;F%M92`]/B`D9&5F875L=%]V86QU92D@>PH@
M("`@("`@("`@("!I9B`H:7-?82@D=&AI<RT^9V5T071T<FEB=71E*"1N86UE
M*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E
M=$%T=')I8G5T92@D;F%M92P@)&1E9F%U;'1?=F%L=64I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@<&%R96YT.CI?97AP;W)T
M=D1A=&$H)U9%5D5.5"<I.PH@("`@?0H*("`@("\J*@H@("`@("H@57!D871E
M('1H92!S=&%T=7,@;V8@86X@871T96YD964@;V8@86X@979E;G0N"B`@("`@
M*@H@("`@("H@0'!A<F%M("1E;6%I;"`@("!4:&4@96UA:6P@861D<F5S<R!O
M9B!T:&4@871T96YD964N"B`@("`@*B!`<&%R86T@)'-T871U<R`@(%1H92!P
M87)T:6-I<&%N="!S=&%T=7,@=&\@<V5T+@H@("`@("H@0'!A<F%M("1F=6QL
M;F%M92!4:&4@9G5L;"!N86UE(&]F('1H92!P87)T:6-I<&%N="!T;R!S970N
M"B`@("`@*B\*("`@(&9U;F-T:6]N('5P9&%T94%T=&5N9&5E*"1E;6%I;"P@
M)'-T871U<RP@)&9U;&QN86UE(#T@)R<I"B`@("!["B`@("`@("`@9F]R96%C
M:"`H)'1H:7,M/E]A='1R:6)U=&5S(&%S("1K97D@/3X@)&%T=')I8G5T92D@
M>PH@("`@("`@("`@("!I9B`H)&%T=')I8G5T95LG;F%M92==(#T]("=!5%1%
M3D1%12<@)B8@)&%T=')I8G5T95LG=F%L=64G72`]/2`G34%)3%1/.B<@+B`D
M96UA:6PI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?871T<FEB=71E<ULD
M:V5Y75LG<&%R86US)UU;)U!!4E135$%4)UT@/2`D<W1A='5S.PH@("`@("`@
M("`@("`@("`@:68@*"%E;7!T>2@D9G5L;&YA;64I*2!["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]A='1R:6)U=&5S6R1K97E=6R=P87)A;7,G75LG
M0TXG72`]("1F=6QL;F%M93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('5N<V5T*"1T:&ES+3Y?871T<FEB=71E<ULD:V5Y75LG<&%R86US
M)UU;)U)35E`G72D["B`@("`@("`@("`@("`@("!R971U<FX["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"=005)4
M4U1!5"<@/3X@)'-T871U<RD["B`@("`@("`@:68@*"%E;7!T>2@D9G5L;&YA
M;64I*2!["B`@("`@("`@("`@("1P87)A;7-;)T-.)UT@/2`D9G5L;&YA;64[
M"B`@("`@("`@?0H@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H)T%45$5.
M1$5%)RP@)TU!24Q43SHG("X@)&5M86EL+"`D<&%R86US*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;B!T:&4@;W)G86YI>F5R(&1I<W!L87D@;F%M
M92!O<B!E;6%I;"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M(&]R9V%N:7IE<B!N86UE('1O(&1I<W!L87D@9F]R('1H:7,@979E;G0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&]R9V%N:7IE<DYA;64H*0H@("`@>PH@("`@
M("`@("1O<F=A;FEZ97(@/2`D=&AI<RT^9V5T071T<FEB=71E*"=/4D=!3DE:
M15(G+"!T<G5E*3L*("`@("`@("!I9B`H:7-?82@D;W)G86YI>F5R+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@
M('T*"B`@("`@("`@:68@*&ES<V5T*"1O<F=A;FEZ97);,%U;)T-.)UTI*2![
M"B`@("`@("`@("`@(')E='5R;B`D;W)G86YI>F5R6S!=6R=#3B==.PH@("`@
M("`@('T*"B`@("`@("`@)&]R9V%N:7IE<B`]('!A<G-E7W5R;"@D=&AI<RT^
M9V5T071T<FEB=71E*"=/4D=!3DE:15(G*2D["@H@("`@("`@(')E='5R;B`D
M;W)G86YI>F5R6R=P871H)UT["B`@("!]"@H@("`@+RHJ"B`@("`@*B!5<&1A
M=&4@=&AI<R!E=F5N="!W:71H(&1E=&%I;',@9G)O;2!A;F]T:&5R(&5V96YT
M+@H@("`@("H*("`@("`J($!P87)A;2!(;W)D95]I0V%L96YD87)?=D5V96YT
M("1V979E;G0@(%1H92!V179E;G0@=VET:"!L871E<W0@9&5T86EL<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@=7!D871E1G)O;79%=F5N="@D=F5V96YT*0H@
M("`@>PH@("`@("`@("1N97=!='1R:6)U=&5S(#T@)'9E=F5N="T^9V5T06QL
M071T<FEB=71E<R@I.PH@("`@("`@(&9O<F5A8V@@*"1N97=!='1R:6)U=&5S
M(&%S("1N97=!='1R:6)U=&4I('L*("`@("`@("`@("`@)&-U<G)E;G1686QU
M92`]("1T:&ES+3YG971!='1R:6)U=&4H)&YE=T%T=')I8G5T95LG;F%M92==
M*3L*("`@("`@("`@("`@:68@*&ES7V$H)&-U<G)E;G1686QU92P@)U!%05)?
M97)R;W(G*2D@>PH@("`@("`@("`@("`@("`@+R\@06QR96%D>2!E>&ES=',@
M<V\@:G5S="!A9&0@:70N"B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T071T
M<FEB=71E*"1N97=!='1R:6)U=&5;)VYA;64G72P@)&YE=T%T=')I8G5T95LG
M=F%L=64G72P@)&YE=T%T=')I8G5T95LG<&%R86US)UTI.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+R\@06QR96%D>2!E>&ES=',@
M<V\@;&]C871E(&%N9"!M;V1I9GDN"B`@("`@("`@("`@("`@("`D9F]U;F0@
M/2!F86QS93L*"B`@("`@("`@("`@("`@("`O+R!4<GD@;6%T8VAI;F<@=&AE
M(&%T=')I8G1E(&YA;64@86YD('9A;'5E(&EN8V%S90H@("`@("`@("`@("`@
M("`@+R\@;VYL>2!T:&4@<&%R86US(&-H86YG960@*&5G(&%T=&5N9&5E('5P
M9&%T:6YG"B`@("`@("`@("`@("`@("`O+R!S=&%T=7,I+@H@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)'1H:7,M/E]A='1R:6)U=&5S(&%S("1I9"`]/B`D
M871T<BD@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D871T<ELG;F%M92==
M(#T]("1N97=!='1R:6)U=&5;)VYA;64G72`F)@H@("`@("`@("`@("`@("`@
M("`@("`@("`D871T<ELG=F%L=64G72`]/2`D;F5W071T<FEB=71E6R=V86QU
M92==*2!["B`@("`@("`@("`@("`@("`@("`@("`@("\O(&UE<F=E('1H92!P
M87)A;7,*("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&YE=T%T
M=')I8G5T95LG<&%R86US)UT@87,@)'!A<F%M7VED(#T^("1P87)A;5]N86UE
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%T=')I
M8G5T97-;)&ED75LG<&%R86US)UU;)'!A<F%M7VED72`]("1P87)A;5]N86UE
M.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@("1F;W5N9"`]('1R=64["B`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@(&EF("@A)&9O=6YD*2!["B`@("`@("`@("`@
M("`@("`@("`@+R\@16QS92!M871C:"!T:&4@9FER<W0@871T<FEB=71E('=I
M=&@@=&AE('-A;64*("`@("`@("`@("`@("`@("`@("`O+R!N86UE("AE9R!C
M:&%N9VEN9R!S=&%R="!T:6UE*2X*("`@("`@("`@("`@("`@("`@("!F;W)E
M86-H("@D=&AI<RT^7V%T=')I8G5T97,@87,@)&ED(#T^("1A='1R*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@D871T<ELG;F%M92==(#T]("1N
M97=!='1R:6)U=&5;)VYA;64G72D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]A='1R:6)U=&5S6R1I9%U;)W9A;'5E)UT@/2`D;F5W
M071T<FEB=71E6R=V86QU92==.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+R\@365R9V4@=&AE('!A<F%M<RX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1N97=!='1R:6)U=&5;)W!A<F%M<R==(&%S("1P
M87)A;5]I9"`]/B`D<&%R86U?;F%M92D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?871T<FEB=71E<ULD:61=6R=P87)A;7,G
M75LD<&%R86U?:61=(#T@)'!A<F%M7VYA;64["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%5P9&%T92!J=7-T('1H92!A='1E
M;F1E<W,@;V8@979E;G0@=VET:"!D971A:6QS(&9R;VT@86YO=&AE<@H@("`@
M("H@979E;G0N"B`@("`@*@H@("`@("H@0'!A<F%M($AO<F1E7VE#86QE;F1A
M<E]V179E;G0@)'9E=F5N="`@5&AE('9%=F5N="!W:71H(&QA=&5S="!D971A
M:6QS"B`@("`@*B\*("`@(&9U;F-T:6]N('5P9&%T94%T=&5N9&5E<T9R;VUV
M179E;G0H)'9E=F5N="D*("`@('L*("`@("`@("`D;F5W071T<FEB=71E<R`]
M("1V979E;G0M/F=E=$%L;$%T=')I8G5T97,H*3L*("`@("`@("!F;W)E86-H
M("@D;F5W071T<FEB=71E<R!A<R`D;F5W071T<FEB=71E*2!["B`@("`@("`@
M("`@(&EF("@D;F5W071T<FEB=71E6R=N86UE)UT@(3T@)T%45$5.1$5%)RD@
M>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)&-U<G)E;G1686QU92`]("1T:&ES+3YG971!='1R:6)U=&4H
M)&YE=T%T=')I8G5T95LG;F%M92==*3L*("`@("`@("`@("`@:68@*&ES7V$H
M)&-U<G)E;G1686QU92P@)U!%05)?97)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@+R\@06QR96%D>2!E>&ES=',@<V\@:G5S="!A9&0@:70N"B`@("`@("`@
M("`@("`@("`D=&AI<RT^<V5T071T<FEB=71E*"1N97=!='1R:6)U=&5;)VYA
M;64G72P@)&YE=T%T=')I8G5T95LG=F%L=64G72P@)&YE=T%T=')I8G5T95LG
M<&%R86US)UTI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@+R\@06QR96%D>2!E>&ES=',@<V\@;&]C871E(&%N9"!M;V1I9GDN"B`@
M("`@("`@("`@("`@("`D9F]U;F0@/2!F86QS93L*("`@("`@("`@("`@("`@
M("\O(%1R>2!M871C:&EN9R!T:&4@871T<FEB=&4@;F%M92!A;F0@=F%L=64@
M:6YC87-E"B`@("`@("`@("`@("`@("`O+R!O;FQY('1H92!P87)A;7,@8VAA
M;F=E9"`H96<@871T96YD964@=7!D871I;F<*("`@("`@("`@("`@("`@("\O
M('-T871U<RDN"B`@("`@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7V%T
M=')I8G5T97,@87,@)&ED(#T^("1A='1R*2!["B`@("`@("`@("`@("`@("`@
M("`@:68@*"1A='1R6R=N86UE)UT@/3T@)&YE=T%T=')I8G5T95LG;F%M92==
M("8F"B`@("`@("`@("`@("`@("`@("`@("`@("1A='1R6R=V86QU92==(#T]
M("1N97=!='1R:6)U=&5;)W9A;'5E)UTI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@+R\@365R9V4@=&AE('!A<F%M<RX*("`@("`@("`@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)&YE=T%T=')I8G5T95LG<&%R86US)UT@87,@)'!A
M<F%M7VED(#T^("1P87)A;5]N86UE*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7V%T=')I8G5T97-;)&ED75LG<&%R86US)UU;)'!A
M<F%M7VED72`]("1P87)A;5]N86UE.PH@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@("`@("1F;W5N9"`]('1R=64["B`@
M("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I9B`H
M(21F;W5N9"D@>PH@("`@("`@("`@("`@("`@("`@("\O($5L<V4@;6%T8V@@
M=&AE(&9I<G-T(&%T=')I8G5T92!W:71H('1H92!S86UE"B`@("`@("`@("`@
M("`@("`@("`@+R\@;F%M92`H96<@8VAA;F=I;F<@<W1A<G0@=&EM92DN"B`@
M("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]A='1R:6)U=&5S
M(&%S("1I9"`]/B`D871T<BD@>PH@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H)&%T=');)VYA;64G72`]/2`D;F5W071T<FEB=71E6R=N86UE)UTI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?871T<FEB=71E
M<ULD:61=6R=V86QU92==(#T@)&YE=T%T=')I8G5T95LG=F%L=64G73L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("\O($UE<F=E('1H92!P87)A;7,N
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D;F5W071T
M<FEB=71E6R=P87)A;7,G72!A<R`D<&%R86U?:60@/3X@)'!A<F%M7VYA;64I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%T
M=')I8G5T97-;)&ED75LG<&%R86US)UU;)'!A<F%M7VED72`]("1P87)A;5]N
M86UE.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O:4-A;&5N9&%R+W9T:6UE>F]N92YP:'``````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#(W,3<@,3`U,34T,S,W-#`@,#(S-S8V`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B!#
M;&%S<R!R97!R97-E;G1I;F<@=E1I;65Z;VYE<RX*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO:4-A;&5N9&%R+VE#86QE;F1A<B]V=&EM97IO;F4N<&AP+'8@
M,2XX+C$P+C0@,C`P-B\P,2\P,2`R,3HR.#HT-R!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T
M;VYH86QL+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EK
M92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E
M("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7VE#86QE;F1A<@H@*B\*
M8VQA<W,@2&]R9&5?:4-A;&5N9&%R7W9T:6UE>F]N92!E>'1E;F1S($AO<F1E
M7VE#86QE;F1A<B!["@H@("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@
M("`@("`@<F5T=7)N("=V5&EM95IO;F4G.PH@("`@?0H*("`@(&9U;F-T:6]N
M('!A<G-E=D-A;&5N9&%R*"1D871A*0H@("`@>PH@("`@("`@('!A<F5N=#HZ
M<&%R<V5V0V%L96YD87(H)&1A=&$L("=65$E-15I/3D4G*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!E>'!O<G1V0V%L96YD87(H*0H@("`@>PH@("`@("`@(')E
M='5R;B!P87)E;G0Z.E]E>'!O<G1V1&%T82@G5E1)345:3TY%)RD["B`@("!]
M"@I]"@HO*BH*("H@0'!A8VMA9V4@2&]R9&5?:4-A;&5N9&%R"B`J+PIC;&%S
M<R!(;W)D95]I0V%L96YD87)?<W1A;F1A<F0@97AT96YD<R!(;W)D95]I0V%L
M96YD87(@>PH*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@("`@("`@
M(')E='5R;B`G<W1A;F1A<F0G.PH@("`@?0H*("`@(&9U;F-T:6]N('!A<G-E
M=D-A;&5N9&%R*"1D871A*0H@("`@>PH@("`@("`@('!A<F5N=#HZ<&%R<V5V
M0V%L96YD87(H)&1A=&$L("=35$%.1$%21"<I.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&5X<&]R='9#86QE;F1A<B@I"B`@("!["B`@("`@("`@<F5T=7)N('!A
M<F5N=#HZ7V5X<&]R='9$871A*"=35$%.1$%21"<I.PH@("`@?0H*?0H*+RHJ
M"B`J($!P86-K86=E($AO<F1E7VE#86QE;F1A<@H@*B\*8VQA<W,@2&]R9&5?
M:4-A;&5N9&%R7V1A>6QI9VAT(&5X=&5N9',@2&]R9&5?:4-A;&5N9&%R('L*
M"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@("!R971U<FX@
M)V1A>6QI9VAT)SL*("`@('T*"B`@("!F=6YC=&EO;B!P87)S979#86QE;F1A
M<B@D9&%T82D*("`@('L*("`@("`@("!P87)E;G0Z.G!A<G-E=D-A;&5N9&%R
M*"1D871A+"`G1$%93$E'2%0G*3L*("`@('T*"B`@("!F=6YC=&EO;B!E>'!O
M<G1V0V%L96YD87(H*0H@("`@>PH@("`@("`@(')E='5R;B!P87)E;G0Z.E]E
M>'!O<G1V1&%T82@G1$%93$E'2%0G*3L*("`@('T*"GT*````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]I0V%L96YD87(O=F9R965B=7-Y
M+G!H<```````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R,S8T,2`Q,#4Q-30S
M,S<T,"`P,C,W-3<`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J($-L87-S(')E<')E<V5N=&EN9R!V1G)E
M96)U<WD@8V]M<&]N96YT<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO:4-A
M;&5N9&%R+VE#86QE;F1A<B]V9G)E96)U<WDN<&AP+'8@,2XQ-BXQ,"XY(#(P
M,#8O,#(O,#8@,3<Z-3,Z,SD@;7)U8FEN<VL@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#,M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL
M+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EK92!#;V-H
M<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@2&]R
M9&4@,RXP"B`J($!P86-K86=E($AO<F1E7VE#86QE;F1A<@H@*B\*8VQA<W,@
M2&]R9&5?:4-A;&5N9&%R7W9F<F5E8G5S>2!E>'1E;F1S($AO<F1E7VE#86QE
M;F1A<B!["@H@("`@=F%R("1?8G5S>5!E<FEO9',@/2!A<G)A>2@I.PH*("`@
M(&9U;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G=D9R
M965B=7-Y)SL*("`@('T*"B`@("`O*BH*("`@("`J(%!A<G-E<R!A('-T<FEN
M9R!C;VYT86EN:6YG('9&<F5E8G5S>2!D871A+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&1A=&$@("`@(%1H92!D871A('1O('!A<G-E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!P87)S979#86QE;F1A<B@D9&%T82D*("`@('L*
M("`@("`@("!P87)E;G0Z.G!A<G-E=D-A;&5N9&%R*"1D871A+"`G5D92145"
M55-9)RD["@H@("`@("`@("\O($1O('-O;65T:&EN9R!W:71H(&%L;"!T:&4@
M8G5S>2!P97)I;V1S+@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?871T<FEB
M=71E<R!A<R`D:V5Y(#T^("1A='1R:6)U=&4I('L*("`@("`@("`@("`@:68@
M*"1A='1R:6)U=&5;)VYA;64G72`]/2`G1E)%14)54UDG*2!["B`@("`@("`@
M("`@("`@("!F;W)E86-H("@D871T<FEB=71E6R=V86QU97,G72!A<R`D=F%L
M=64I('L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'9A;'5E6R=D
M=7)A=&EO;B==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YA
M9&1"=7-Y4&5R:6]D*"="55-9)RP@)'9A;'5E6R=S=&%R="==+"!N=6QL+"`D
M=F%L=65;)V1U<F%T:6]N)UTI.PH@("`@("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F%D9$)U<WE097)I
M;V0H)T)54UDG+"`D=F%L=65;)W-T87)T)UTL("1V86QU95LG96YD)UTI.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('5N<V5T*"1T:&ES+3Y?871T<FEB=71E<ULD:V5Y72D["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@97AP
M;W)T=D-A;&5N9&%R*"D*("`@('L*("`@("`@("!F;W)E86-H("@D=&AI<RT^
M7V)U<WE097)I;V1S(&%S("1S=&%R="`]/B`D96YD*2!["B`@("`@("`@("`@
M("1P97)I;V1S(#T@87)R87DH87)R87DH)W-T87)T)R`]/B`D<W1A<G0L("=E
M;F0G(#T^("1E;F0I*3L*("`@("`@("`@("`@)'1H:7,M/G-E=$%T=')I8G5T
M92@G1E)%14)54UDG+"`D<&5R:6]D<RD["B`@("`@("`@?0H*("`@("`@("`D
M<F5S(#T@<&%R96YT.CI?97AP;W)T=D1A=&$H)U9&4D5%0E5362<I.PH*("`@
M("`@("!F;W)E86-H("@D=&AI<RT^7V%T=')I8G5T97,@87,@)&ME>2`]/B`D
M871T<FEB=71E*2!["B`@("`@("`@("`@(&EF("@D871T<FEB=71E6R=N86UE
M)UT@/3T@)T92145"55-9)RD@>PH@("`@("`@("`@("`@("`@=6YS970H)'1H
M:7,M/E]A='1R:6)U=&5S6R1K97E=*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1R97,["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&$@9&ES<&QA>2!N86UE(&9O<B!T:&ES(&]B:F5C="X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@02!C;&5A<B!T97AT(&YA;64@
M9F]R(&1I<W!L87EI;F<@=&AI<R!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$YA;64H*0H@("`@>PH@("`@("`@("1N86UE(#T@)R<["B`@("`@
M("`@)&UE=&AO9"`]("%E;7!T>2@D=&AI<RT^7V-O;G1A:6YE<BD@/PH@("`@
M("`@("`@("`D=&AI<RT^7V-O;G1A:6YE<BT^9V5T071T<FEB=71E*"=-151(
M3T0G*2`Z("=054),25-()SL*"B`@("`@("`@:68@*&ES7V$H)&UE=&AO9"P@
M)U!%05)?17)R;W(G*2!\?"`D;65T:&]D(#T]("=054),25-()RD@>PH@("`@
M("`@("`@("`D871T<B`]("=/4D=!3DE:15(G.PH@("`@("`@('T@96QS96EF
M("@D;65T:&]D(#T]("=215!,62<I('L*("`@("`@("`@("`@)&%T='(@/2`G
M051414Y$144G.PH@("`@("`@('T*"B`@("`@("`@)&YA;64@/2`D=&AI<RT^
M9V5T071T<FEB=71E*"1A='1R+"!T<G5E*3L*("`@("`@("!I9B`H:7-S970H
M)&YA;65;,%U;)T-.)UTI*2!["B`@("`@("`@("`@(')E='5R;B`D;F%M95LP
M75LG0TXG73L*("`@("`@("!]"@H@("`@("`@("1N86UE(#T@)'1H:7,M/F=E
M=$%T=')I8G5T92@D871T<BD["B`@("`@("`@:68@*&ES7V$H)&YA;64L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1N86UE(#T@<&%R<V5?=7)L*"1N86UE
M*3L*("`@("`@("`@("`@<F5T=7)N("1N86UE6R=P871H)UT["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@96UA:6P@861D
M<F5S<R!F;W(@=&AI<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!E;6%I;"!A9&1R97-S(&]F('1H:7,@;V)J96-T)W,@;W=N
M97(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$5M86EL*"D*("`@('L*("`@
M("`@("`D;F%M92`]("<G.PH@("`@("`@("1M971H;V0@/2`A96UP='DH)'1H
M:7,M/E]C;VYT86EN97(I"B`@("`@("`@("`@("`@("`@(#\@)'1H:7,M/E]C
M;VYT86EN97(M/F=E=$%T=')I8G5T92@G34542$]$)RD@.B`G4%5"3$E32"<[
M"@H@("`@("`@(&EF("AI<U]A*"1M971H;V0L("=014%27T5R<F]R)RD@?'P@
M)&UE=&AO9"`]/2`G4%5"3$E32"<I('L*("`@("`@("`@("`@)&%T='(@/2`G
M3U)'04Y)6D52)SL*("`@("`@("!](&5L<V5I9B`H)&UE=&AO9"`]/2`G4D50
M3%DG*2!["B`@("`@("`@("`@("1A='1R(#T@)T%45$5.1$5%)SL*("`@("`@
M("!]"@H@("`@("`@("1N86UE(#T@)'1H:7,M/F=E=$%T=')I8G5T92@D871T
M<BD["B`@("`@("`@:68@*&ES7V$H)&YA;64L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1N86UE(#T@<&%R<V5?=7)L*"1N86UE*3L*("`@("`@("`@("`@
M<F5T=7)N("1N86UE6R=P871H)UT["B`@("`@("`@?0H@("`@?0H*("`@(&9U
M;F-T:6]N(&=E=$)U<WE097)I;V1S*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/E]B=7-Y4&5R:6]D<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@86QL('1H92!F<F5E('!E<FEO9',@;V8@=&EM92!I;B!A(&=I=F5N
M('!E<FEO9"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<W1A<G13
M=&%M<"`@5&AE('-T87)T('1I;65S=&%M<"X*("`@("`J($!P87)A;2!I;G1E
M9V5R("1E;F13=&%M<"`@("!4:&4@96YD('1I;65S=&%M<"X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y("!!(&AA<V@@=VET:"!F<F5E('1I;64@<&5R
M:6]D<RP@=&AE('-T87)T('1I;65S(&%S('1H90H@("`@("H@("`@("`@("`@
M("`@("`@:V5Y<R!A;F0@=&AE(&5N9"!T:6UE<R!A<R!T:&4@=F%L=65S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971&<F5E4&5R:6]D<R@D<W1A<G13=&%M
M<"P@)&5N9%-T86UP*0H@("`@>PH@("`@("`@("1T:&ES+3YS:6UP;&EF>2@I
M.PH@("`@("`@("1P97)I;V1S(#T@87)R87DH*3L*"B`@("`@("`@+R\@0VAE
M8VL@=&AA="!W92!H879E(&1A=&$@9F]R('-O;64@<&%R="!O9B!T:&ES('!E
M<FEO9"X*("`@("`@("!I9B`H)'1H:7,M/F=E=$5N9"@I(#P@)'-T87)T4W1A
M;7`@?'P@)'1H:7,M/F=E=%-T87)T*"D@/B`D96YD4W1A;7`I('L*("`@("`@
M("`@("`@<F5T=7)N("1P97)I;V1S.PH@("`@("`@('T*"B`@("`@("`@+R\@
M3&]C871E('1H92!F:7)S="!T:6UE(&EN('1H92!R97%U97-T960@<&5R:6]D
M('=E(&AA=F4@9&%T82!F;W(N"B`@("`@("`@)&YE>'1S=&%R="`](&UA>"@D
M<W1A<G13=&%M<"P@)'1H:7,M/F=E=%-T87)T*"DI.PH*("`@("`@("`O+R!#
M:&5C:R!E86-H(&)U<WD@<&5R:6]D(&%N9"!A9&0@9G)E92!P97)I;V1S(&EN
M(&)E='=E96XN"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]B=7-Y4&5R:6]D
M<R!A<R`D<W1A<G0@/3X@)&5N9"D@>PH@("`@("`@("`@("!I9B`H)'-T87)T
M(#P]("1E;F13=&%M<"`F)B`D96YD(#X]("1N97AT<W1A<G0I('L*("`@("`@
M("`@("`@("`@(&EF("@D;F5X='-T87)T(#P]("1S=&%R="D@>PH@("`@("`@
M("`@("`@("`@("`@("1P97)I;V1S6R1N97AT<W1A<G1=(#T@;6EN*"1S=&%R
M="P@)&5N9%-T86UP*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("1N97AT<W1A<G0@/2!M:6XH)&5N9"P@)&5N9%-T86UP*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@268@=V4@9&ED;B=T(')E
M860@=&AE(&5N9"!O9B!T:&4@<F5Q=65S=&5D('!E<FEO9"!B=70@<W1I;&P@
M:&%V90H@("`@("`@("\O(&1A=&$@=&AE;B!M87)K(&%S(&9R964@=&\@=&AE
M(&5N9"!O9B!T:&4@<&5R:6]D(&]R(&%V86EL86)L92!D871A+@H@("`@("`@
M(&EF("@D;F5X='-T87)T(#P@)&5N9%-T86UP("8F("1N97AT<W1A<G0@/"`D
M=&AI<RT^9V5T16YD*"DI('L*("`@("`@("`@("`@)'!E<FEO9'-;)&YE>'1S
M=&%R=%T@/2!M:6XH)'1H:7,M/F=E=$5N9"@I+"`D96YD4W1A;7`I.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1P97)I;V1S.PH@("`@?0H*("`@("\J
M*@H@("`@("H@061D<R!A(&)U<WD@<&5R:6]D('1O('1H92!I;F9O+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@("`@("`@5&AE('1Y<&4@
M;V8@=&AE('!E<FEO9"X@16ET:&5R("=&4D5%)R!O<@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G0E5362<[(&]N;'D@)T)54UDG('-U<'!O
M<G1E9"!A="!T:&4@;6]M96YT+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'-T
M87)T("`@("!4:&4@<W1A<G0@=&EM97-T86UP(&]F('1H92!P97)I;V0N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D96YD("`@("`@(%1H92!E;F0@=&EM97-T
M86UP(&]F('1H92!P97)I;V0N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9'5R
M871I;VX@(%1H92!D=7)A=&EO;B!O9B!T:&4@<&5R:6]D+B!)9B!S<&5C:69I
M960L('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`D96YD
M('!A<F%M971E<B!W:6QL(&)E(&EG;F]R960N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%D9$)U<WE097)I;V0H)'1Y<&4L("1S=&%R="P@)&5N9"`](&YU;&PL
M("1D=7)A=&EO;B`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"1T>7!E(#T]
M("=&4D5%)RD@>PH@("`@("`@("`@("`O+R!-86ME('-U<F4@=&AI<R!P97)I
M;V0@:7,@;F]T(&UA<FME9"!A<R!B=7-Y+@H@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O+R!#86QC=6QA=&4@=&AE(&5N
M9"!T:6UE(&EF(&1U<F%T:6]N('=A<R!S<&5C:69I960N"B`@("`@("`@)'1E
M;7!%;F0@/2!I<U]N=6QL*"1D=7)A=&EO;BD@/R`D96YD(#H@)'-T87)T("L@
M)&1U<F%T:6]N.PH*("`@("`@("`O+R!-86ME('-U<F4@=&AE('!E<FEO9"!L
M96YG=&@@:7,@86QW87ES('!O<VET:79E+@H@("`@("`@("1E;F0@/2!M87@H
M)'-T87)T+"`D=&5M<$5N9"D["B`@("`@("`@)'-T87)T(#T@;6EN*"1S=&%R
M="P@)'1E;7!%;F0I.PH*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]B=7-Y
M4&5R:6]D<ULD<W1A<G1=*2D@>PH@("`@("`@("`@("`O+R!!;')E861Y(&$@
M<&5R:6]D('-T87)T:6YG(&%T('1H:7,@=&EM92X@17AT96YD('1O('1H92!L
M96YG=&@@;V8*("`@("`@("`@("`@+R\@=&AE(&QO;F=E<W0@;V8@=&AE('1W
M;RX*("`@("`@("`@("`@)'1H:7,M/E]B=7-Y4&5R:6]D<ULD<W1A<G1=(#T@
M;6%X*"1E;F0L("1T:&ES+3Y?8G5S>5!E<FEO9'-;)'-T87)T72D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@061D(&$@;F5W(&)U<WD@<&5R
M:6]D+@H@("`@("`@("`@("`D=&AI<RT^7V)U<WE097)I;V1S6R1S=&%R=%T@
M/2`D96YD.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!T:6UE<W1A;7`@;V8@=&AE
M('-T87)T(&]F('1H92!T:6UE('!E<FEO9"!T:&ES(&9R964@8G5S>0H@("`@
M("H@:6YF;W)M871I;VX@8V]V97)S+@H@("`@("H*("`@("`J($!R971U<FX@
M:6YT96=E<B`@02!T:6UE<W1A;7`N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%-T87)T*"D*("`@('L*("`@("`@("!I9B`H(6ES7V$H)'1H:7,M/F=E=$%T
M=')I8G5T92@G1%135$%25"<I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^9V5T071T<FEB=71E*"=$5%-405)4)RD["B`@
M("`@("`@?2!E;'-E:68@*&-O=6YT*"1T:&ES+3Y?8G5S>5!E<FEO9',I*2![
M"B`@("`@("`@("`@(')E='5R;B!M:6XH87)R87E?:V5Y<R@D=&AI<RT^7V)U
M<WE097)I;V1S*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE('1I;65S=&%M<"!O9B!T:&4@96YD(&]F('1H92!T:6UE('!E
M<FEO9"!T:&ES(&9R964@8G5S>0H@("`@("H@:6YF;W)M871I;VX@8V]V97)S
M+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@02!T:6UE<W1A;7`N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$5N9"@I"B`@("!["B`@("`@("`@
M:68@*"%I<U]A*"1T:&ES+3YG971!='1R:6)U=&4H)T1414Y$)RDL("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YG971!='1R
M:6)U=&4H)T1414Y$)RD["B`@("`@("`@?2!E;'-E:68@*&-O=6YT*"1T:&ES
M+3Y?8G5S>5!E<FEO9',I*2!["B`@("`@("`@("`@(')E='5R;B!M87@H87)R
M87E?=F%L=65S*"1T:&ES+3Y?8G5S>5!E<FEO9',I*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@365R9V5S('1H92!B=7-Y('!E<FEO9',@;V8@
M86YO=&AE<B!(;W)D95]I0V%L96YD87)?=F9R965B=7-Y(&]B:F5C="!I;G1O
M"B`@("`@*B!T:&ES(&]N92X*("`@("`J"B`@("`@*B!`<&%R86T@2&]R9&5?
M:4-A;&5N9&%R7W9F<F5E8G5S>2`D9G)E96)U<WD@($$@9G)E96)U<WD@;V)J
M96-T+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'-I;7!L:69Y("`@("`@("`@
M("`@("`@("`@("!)9B!T<G5E+"!S:6UP;&EF>2@I('=I;&P*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V%L
M;&5D(&%F=&5R('1H92!M97)G92X*("`@("`J+PH@("`@9G5N8W1I;VX@;65R
M9V4H)&9R965B=7-Y+"`D<VEM<&QI9GD@/2!T<G5E*0H@("`@>PH@("`@("`@
M(&EF("@A:7-?82@D9G)E96)U<WDL("=(;W)D95]I0V%L96YD87)?=F9R965B
M=7-Y)RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M"B`@("`@("`@9F]R96%C:"`H)&9R965B=7-Y+3YG971"=7-Y4&5R:6]D<R@I
M(&%S("1S=&%R="`]/B`D96YD*2!["B`@("`@("`@("`@("1T:&ES+3YA9&1"
M=7-Y4&5R:6]D*"="55-9)RP@)'-T87)T+"`D96YD*3L*("`@("`@("!]"@H@
M("`@("`@("1T:&ES871T<B`]("1T:&ES+3YG971!='1R:6)U=&4H)T144U1!
M4E0G*3L*("`@("`@("`D=&AA=&%T='(@/2`D9G)E96)U<WDM/F=E=$%T=')I
M8G5T92@G1%135$%25"<I.PH@("`@("`@(&EF("AI<U]A*"1T:&ES871T<BP@
M)U!%05)?17)R;W(G*2`F)B`A:7-?82@D=&AA=&%T='(L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@)'1H:7,M/G-E=$%T=')I8G5T92@G1%135$%2
M5"<L("1T:&%T871T<BD["B`@("`@("`@?2!E;'-E:68@*"%I<U]A*"1T:&%T
M871T<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!I9B`H)'1H871A
M='1R(#X@)'1H:7-A='1R*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T
M071T<FEB=71E*"=$5%-405)4)RP@)'1H871A='1R*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@)'1H:7-A='1R(#T@)'1H:7,M/F=E=$%T
M=')I8G5T92@G1%1%3D0G*3L*("`@("`@("`D=&AA=&%T='(@/2`D9G)E96)U
M<WDM/F=E=$%T=')I8G5T92@G1%1%3D0G*3L*("`@("`@("!I9B`H:7-?82@D
M=&AI<V%T='(L("=014%27T5R<F]R)RD@)B8@(6ES7V$H)'1H871A='1R+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1T:&ES+3YS971!='1R:6)U
M=&4H)T1414Y$)RP@)'1H871A='1R*3L*("`@("`@("!](&5L<V5I9B`H(6ES
M7V$H)'1H871A='1R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(&EF
M("@D=&AA=&%T='(@/"`D=&AI<V%T='(I('L*("`@("`@("`@("`@("`@("1T
M:&ES+3YS971!='1R:6)U=&4H)T1414Y$)RP@)'1H871A='1R*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1S:6UP;&EF>2D@>PH@
M("`@("`@("`@("`D=&AI<RT^<VEM<&QI9GDH*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E
M<R!A;&P@;W9E<FQA<',@86YD('-I;7!L:69I97,@=&AE(&)U<WD@<&5R:6]D
M<R!A<G)A>2!A<R!M=6-H(&%S"B`@("`@*B!P;W-S:6)L92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<VEM<&QI9GDH*0H@("`@>PH@("`@("`@("1C:&5C:V5D
M(#T@87)R87DH*3L*("`@("`@("`D8VAE8VME9$5M<'1Y(#T@=')U93L*"B`@
M("`@("`@9F]R96%C:"`H)'1H:7,M/E]B=7-Y4&5R:6]D<R!A<R`D<W1A<G0@
M/3X@)&5N9"D@>PH@("`@("`@("`@("!I9B`H)&-H96-K961%;7!T>2D@>PH@
M("`@("`@("`@("`@("`@)&-H96-K961;)'-T87)T72`]("1E;F0["B`@("`@
M("`@("`@("`@("`D8VAE8VME9$5M<'1Y(#T@9F%L<V4["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D861D960@/2!F86QS93L*("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1C:&5C:V5D(&%S("1T97-T4W1A<G0@
M/3X@)'1E<W1%;F0I('L*("`@("`@("`@("`@("`@("`@("!I9B`H)'-T87)T
M(#T]("1T97-T4W1A<G0I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&-H
M96-K961;)'1E<W13=&%R=%T@/2!M87@H)'1E<W1%;F0L("1E;F0I.PH@("`@
M("`@("`@("`@("`@("`@("`@("`D861D960@/2!T<G5E.PH@("`@("`@("`@
M("`@("`@("`@('T@96QS96EF("@D96YD(#P]("1T97-T16YD("8F("1E;F0@
M/CT@)'1E<W13=&%R="D@>PH@("`@("`@("`@("`@("`@("`@("`@("!U;G-E
M="@D8VAE8VME9%LD=&5S=%-T87)T72D["B`@("`@("`@("`@("`@("`@("`@
M("`@("1C:&5C:V5D6VUI;B@D=&5S=%-T87)T+"`D<W1A<G0I72`](&UA>"@D
M=&5S=$5N9"P@)&5N9"D["B`@("`@("`@("`@("`@("`@("`@("`@("1A9&1E
M9"`]('1R=64["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@(&EF("@D861D960I('L*("`@("`@("`@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@:68@*"$D861D960I('L*("`@("`@("`@("`@
M("`@("`@("`D8VAE8VME9%LD<W1A<G1=(#T@)&5N9#L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:W-O<G0H
M)&-H96-K960L(%-/4E1?3E5-15))0RD["B`@("`@("`@)'1H:7,M/E]B=7-Y
M4&5R:6]D<R`]("1C:&5C:V5D.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92]I0V%L96YD87(O=F%L87)M+G!H<```
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3,W-2`Q,#4Q-30S,S<T
M,"`P,C,R,C<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J($-L87-S(')E<')E<V5N=&EN9R!V06QA<FUS
M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]I0V%L96YD87(O:4-A;&5N9&%R
M+W9A;&%R;2YP:'`L=B`Q+C@N,3`N-"`R,#`V+S`Q+S`Q(#(Q.C(X.C0W(&IA
M;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI:V4@0V]C:')A
M;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@
M*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O
M+FYZ/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?
M:4-A;&5N9&%R"B`J+PIC;&%S<R!(;W)D95]I0V%L96YD87)?=F%L87)M(&5X
M=&5N9',@2&]R9&5?:4-A;&5N9&%R('L*"B`@("!F=6YC=&EO;B!G9714>7!E
M*"D*("`@('L*("`@("`@("!R971U<FX@)W9!;&%R;2<["B`@("!]"@H@("`@
M9G5N8W1I;VX@<&%R<V5V0V%L96YD87(H)&1A=&$I"B`@("!["B`@("`@("`@
M<&%R96YT.CIP87)S979#86QE;F1A<B@D9&%T82P@)U9!3$%232<I.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&5X<&]R='9#86QE;F1A<B@I"B`@("!["B`@("`@
M("`@<F5T=7)N('!A<F5N=#HZ7V5X<&]R='9$871A*"=604Q!4DTG*3L*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]I0V%L96YD87(O=F-A<F0N
M<&AP````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-S(T,B`Q,#4Q
M-30S,S<T,"`P,C,P-#,`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O:4-A;&5N
M9&%R+G!H<"<["@HO+R!4:&4@9F]L;&]W:6YG('=E<F4@<VAA;65L97-S;'D@
M>6]I;FME9"!F<F]M($-O;G1A8W1?5F-A<F1?0G5I;&0*+R\@4&%R="!N=6UB
M97)S(&9O<B!.(&-O;7!O;F5N=',N"F1E9FEN92@G5D-!4D1?3E]&04U)3%DG
M+"`@("`@,"D["F1E9FEN92@G5D-!4D1?3E]'259%3B<L("`@("`@,2D["F1E
M9FEN92@G5D-!4D1?3E]!1$1,)RP@("`@("`@,BD["F1E9FEN92@G5D-!4D1?
M3E]04D5&25@G+"`@("`@,RD["F1E9FEN92@G5D-!4D1?3E]3549&25@G+"`@
M("`@-"D["@HO+R!087)T(&YU;6)E<G,@9F]R($%$4B!C;VUP;VYE;G1S+@ID
M969I;F4H)U9#05)$7T%$4E]03T(G+"`@("`@(#`I.PID969I;F4H)U9#05)$
M7T%$4E]%6%1%3D0G+"`@(#$I.PID969I;F4H)U9#05)$7T%$4E]35%)%150G
M+"`@(#(I.PID969I;F4H)U9#05)$7T%$4E],3T-!3$E462<L(#,I.PID969I
M;F4H)U9#05)$7T%$4E]214=)3TXG+"`@(#0I.PID969I;F4H)U9#05)$7T%$
M4E]03U-40T]$12<L(#4I.PID969I;F4H)U9#05)$7T%$4E]#3U5.5%)9)RP@
M(#8I.PH*+R\@4&%R="!N=6UB97)S(&9O<B!'14\@8V]M<&]N96YT<RX*9&5F
M:6YE*"=60T%21%]'14]?3$%4)RP@("`@("`P*3L*9&5F:6YE*"=60T%21%]'
M14]?3$].)RP@("`@("`Q*3L*"B\J*@H@*B!#;&%S<R!R97!R97-E;G1I;F<@
M=D-A<F0@96YT<FEE<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO:4-A;&5N
M9&%R+VE#86QE;F1A<B]V8V%R9"YP:'`L=B`Q+C,N,3`N."`R,#`V+S`U+S`Y
M(#(S.C`X.C(R(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P
M,#8@2V%R<W1E;B!&;W5R;6]N="`H:V%R<W1E;D!H;W)D92YO<F<I"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!+87)S=&5N($9O=7)M;VYT(#QK87)S
M=&5N0&AO<F1E+F]R9SX*("H@0'!A8VMA9V4@2&]R9&5?:4-A;&5N9&%R"B`J
M+PIC;&%S<R!(;W)D95]I0V%L96YD87)?=F-A<F0@97AT96YD<R!(;W)D95]I
M0V%L96YD87(@>PH*("`@(&9U;F-T:6]N($AO<F1E7VE#86QE;F1A<E]V8V%R
M9"@D=F5R<VEO;B`]("<R+C$G*0H@("`@>PH@("`@("`@(')E='5R;B!P87)E
M;G0Z.DAO<F1E7VE#86QE;F1A<B@D=F5R<VEO;BD["B`@("!]"@H@("`@9G5N
M8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=V8V%R9"<[
M"B`@("!]"@H@("`@9G5N8W1I;VX@<&%R<V5V0V%L96YD87(H)&1A=&$I"B`@
M("!["B`@("`@("`@<F5T=7)N('!A<F5N=#HZ<&%R<V5V0V%L96YD87(H)&1A
M=&$L("=V8V%R9"<I.PH@("`@?0H*("`@("\J*@H@("`@("H@56YL:6ME('9E
M=F5N="!A;F0@=G1O9&\L(&$@=F-A<F0@:7,@;F]R;6%L;'D@;F]T(&5N8VQO
M<V5D(&EN(&%N"B`@("`@*B!I0V%L96YD87(@8V]N=&%I;F5R+B`H0D5'24XN
M+D5.1"D*("`@("`J+PH@("`@9G5N8W1I;VX@97AP;W)T=D-A;&5N9&%R*"D*
M("`@('L*("`@("`@("`D<F5Q=6ER961!='1R:6)U=&5S6R="3T19)UT@/2`G
M)SL*("`@("`@("`D<F5Q=6ER961!='1R:6)U=&5S6R=615)324].)UT@/2`G
M,BXQ)SL*"B`@("`@("`@9F]R96%C:"`H)')E<75I<F5D071T<FEB=71E<R!A
M<R`D;F%M92`]/B`D9&5F875L=%]V86QU92D@>PH@("`@("`@("`@("!I9B`H
M:7-?82@D=&AI<RT^9V5T071T<FEB=71E*"1N86UE*2P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$%T=')I8G5T92@D;F%M
M92P@)&1E9F%U;'1?=F%L=64I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)'1H:7,M/E]E>'!O<G1V1&%T82@G5D-!4D0G*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-O;G1E;G1S(&]F
M('1H92`B3B(@=&%G(&%S(&$@<')I;G1A8FQE($YA;64Z"B`@("`@*B!I+F4N
M(&-O;G9E<G1S.@H@("`@("H*("`@("`J("`@3CI$=6-K.T1A9V]B97)T.U0[
M4')O9F5S<V]R.U-E;BX*("`@("`J('1O"B`@("`@*B`@(")0<F]F97-S;W(@
M1&%G;V)E<G0@5"!$=6-K(%-E;B(*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@1G5L;"!N86UE(&]F('9C87)D(").(B!T86<*("`@("`J("`@("`@
M("`@("`@("`@("!O<B!N=6QL(&EF(&YO($X@=&%G+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!P<FEN=&%B;&5.86UE*"D*("`@('L*("`@("`@("`D;F%M95]P
M87)T<R`]("1T:&ES+3YG971!='1R:6)U=&5686QU97,H)TXG*3L*("`@("`@
M("!I9B`H:7-?82@D;F%M95]P87)T<RP@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"@H@("`@("`@(&EF("@A
M96UP='DH)&YA;65?<&%R='-;5D-!4D1?3E]04D5&25A=*2D@>PH@("`@("`@
M("`@("`D;F%M95]A<G);72`]("1N86UE7W!A<G1S6U9#05)$7TY?4%)%1DE8
M73L*("`@("`@("!]"B`@("`@("`@:68@*"%E;7!T>2@D;F%M95]P87)T<UM6
M0T%21%].7T=)5D5.72DI('L*("`@("`@("`@("`@)&YA;65?87)R6UT@/2`D
M;F%M95]P87)T<UM60T%21%].7T=)5D5.73L*("`@("`@("!]"B`@("`@("`@
M:68@*"%E;7!T>2@D;F%M95]P87)T<UM60T%21%].7T%$1$Q=*2D@>PH@("`@
M("`@("`@("`D;F%M95]A<G);72`]("1N86UE7W!A<G1S6U9#05)$7TY?041$
M3%T["B`@("`@("`@?0H@("`@("`@(&EF("@A96UP='DH)&YA;65?<&%R='-;
M5D-!4D1?3E]&04U)3%E=*2D@>PH@("`@("`@("`@("`D;F%M95]A<G);72`]
M("1N86UE7W!A<G1S6U9#05)$7TY?1D%-24Q973L*("`@("`@("!]"B`@("`@
M("`@:68@*"%E;7!T>2@D;F%M95]P87)T<UM60T%21%].7U-51D9)6%TI*2![
M"B`@("`@("`@("`@("1N86UE7V%R<EM=(#T@)&YA;65?<&%R='-;5D-!4D1?
M3E]3549&25A=.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&EM<&QO9&4H
M)R`G+"`D;F%M95]A<G(I.PH@("`@?0H*("`@("\J*@H@("`@("H@4W1A=&EC
M(&9U;F-T:6]N('1O(&UA:V4@82!G:79E;B!E;6%I;"!A9&1R97-S(')F8S@R
M,B!C;VUP;&EA;G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D861D
M<F5S<R`@06X@96UA:6P@861D<F5S<RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE(%)&0S@R,BUF;W)M871T960@96UA:6P@861D<F5S<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0F%R945M86EL*"1A9&1R97-S*0H@
M("`@>PH@("`@("`@("\O($5M<'1Y('9A;'5E<R!A<F4@<W1I;&P@96UP='DN
M"B`@("`@("`@:68@*"$D861D<F5S<RD@>PH@("`@("`@("`@("!R971U<FX@
M)&%D9')E<W,["B`@("`@("`@?0H*("`@("`@("!R97%U:7)E7V]N8V4@)TUA
M:6PO4D9#.#(R+G!H<"<["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-
M24U%+G!H<"<["@H@("`@("`@('-T871I8R`D<F9C.#(R.PH@("`@("`@(&EF
M("AI<U]N=6QL*"1R9F,X,C(I*2!["B`@("`@("`@("`@("1R9F,X,C(@/2!N
M97<@36%I;%]21D,X,C(H*3L*("`@("`@("!]"@H@("`@("`@("1R9F,X,C(M
M/G9A;&ED871E36%I;&)O>"@D861D<F5S<RD["B`@("`@("`@<F5T=7)N($U)
M344Z.G)F8S@R,E=R:71E061D<F5S<R@D861D<F5S<RT^;6%I;&)O>"P@)&%D
M9')E<W,M/FAO<W0I.PH@("`@?0H*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]520``````````````````````````````````````````````````````
M```````````````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<T,"`P,3<V,#(`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R````````````````
M`````````````````````````````````````````````````````#`P,#<U
M-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S0P(#`R
M,C`R,0`@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'``````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`R,#$U
M-C4@,3`U,34T,S,W-#`@,#(S-38V`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B!4:&4@2&]R9&5?54E?
M5F%R4F5N9&5R97)?:'1M;#HZ(&-L87-S(')E;F1E<G,@=F%R:6%B;&5S('1O
M($A434PN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP+'8@,2XY."XR+C(X(#(P,#8O,#@O,38@,3(Z,3<Z,C(@
M:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@2F%S;VX@32X@
M1F5L:6-E(#QJ9F5L:6-E0&-R;VYO<WES+F-O;3X*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($Q)0T5.4T4@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+@H@*@H@*B!`<VEN8V4@("!(;W)D95]522`P+C`N,0H@*B!`<&%C
M:V%G92!(;W)D95]520H@*B\*8VQA<W,@2&]R9&5?54E?5F%R4F5N9&5R97)?
M:'1M;"!E>'1E;F1S($AO<F1E7U5)7U9A<E)E;F1E<F5R('L*"B`@("!V87(@
M)%]O;DQO861*4R`](&%R<F%Y*"D["@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A
M<DEN<'5T1&5F875L="@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@
M("`@("`@<F5T=7)N("<\<W1R;VYG/E=A<FYI;F<Z/"]S=')O;F<^(%5N:VYO
M=VX@=F%R:6%B;&4@='EP92`G("X*("`@("`@("`@("`@0&AT;6QS<&5C:6%L
M8VAA<G,H)'9A<BT^9V5T5'EP94YA;64H*2P@14Y47U%53U1%4RP@)'1H:7,M
M/E]C:&%R<V5T*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP
M=71?;G5M8F5R*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@
M("`D=F%L=64@/2`D=F%R+3YG971686QU92@D=F%R<RD["B`@("`@("`@:68@
M*&ES<V5T*"1V87(M/G1Y<&4M/E]F<F%C=&EO;BDI('L*("`@("`@("`@("`@
M)'9A;'5E(#T@<W!R:6YT9B@G)3`Q+B<@+B`D=F%R+3YT>7!E+3Y?9G)A8W1I
M;VX@+B`G9B<L("1V86QU92D["B`@("`@("`@?0H@("`@("`@("1L:6YF;R`]
M($Y,4SHZ9V5T3&]C86QE26YF;R@I.PH@("`@("`@("\J($]N;'D@:68@=&AE
M<F4@:7,@82!M;VY?9&5C:6UA;%]P;VEN="!D;R!T:&4*("`@("`@("`@*B!S
M=6)S=&ET=71I;VXN("HO"B`@("`@("`@:68@*"%E;7!T>2@D;&EN9F];)VUO
M;E]D96-I;6%L7W!O:6YT)UTI*2!["B`@("`@("`@("`@("1V86QU92`]('-T
M<E]R97!L86-E*"<N)RP@)&QI;F9O6R=M;VY?9&5C:6UA;%]P;VEN="==+"`D
M=F%L=64I.PH@("`@("`@('T*("`@("`@("`D=F%R;F%M92`]($!H=&UL<W!E
M8VEA;&-H87)S*"1V87(M/F=E=%9A<DYA;64H*2P@14Y47U%53U1%4RP@)'1H
M:7,M/E]C:&%R<V5T*3L*("`@("`@("!R971U<FX@<W!R:6YT9B@G/&EN<'5T
M('1Y<&4](G1E>'0B('-I>F4](C4B(&YA;64](B5S(B!I9#TB)7,B('9A;'5E
M/2(E<R(E<R`O/B<L"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L
M"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@
M("`@("`@("`@("`@)'9A;'5E+`H@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?9V5T06-T:6]N4V-R:7!T<R@D9F]R;2P@)'9A<BD*("`@("`@("`@
M("`@("`@*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?
M:6YT*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("`D=F%R
M;F%M92`]($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A<DYA;64H*2P@
M14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("!R971U<FX@
M<W!R:6YT9B@G/&EN<'5T('1Y<&4](G1E>'0B('-I>F4](C4B(&YA;64](B5S
M(B!I9#TB)7,B('9A;'5E/2(E<R(E<R`O/B<L"B`@("`@("`@("`@("`@("`@
M("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA
M;64L"B`@("`@("`@("`@("`@("`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H
M)'9A<BT^9V5T5F%L=64H)'9A<G,I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H
M87)S970I+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T06-T
M:6]N4V-R:7!T<R@D9F]R;2P@)'9A<BD*("`@("`@("`@("`@("`@*3L*("`@
M('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?;V-T86PH)B1F;W)M
M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@("1V87)N86UE(#T@0&AT
M;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%R3F%M92@I+"!%3E1?455/5$53
M+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@(')E='5R;B!S<')I;G1F*"<\
M:6YP=70@='EP93TB=&5X="(@<VEZ93TB-2(@;F%M93TB)7,B(&ED/2(E<R(@
M=F%L=64](B5S(B5S("\^)RP*("`@("`@("`@("`@("`@("`@("`@("`D=F%R
M;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@
M("`@("`@("`@("`@("`@("!S<')I;G1F*"<P)6\G+"!O8W1D96,H)'9A<BT^
M9V5T5F%L=64H)'9A<G,I*2DL"B`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]G971!8W1I;VY38W)I<'1S*"1F;W)M+"`D=F%R*0H@("`@("`@("`@
M("`@("`I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=%]I
M;G1L:7-T*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("`D
M=F%R;F%M92`]($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A<DYA;64H
M*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("!R971U
M<FX@<W!R:6YT9B@G/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](B5S(B!I9#TB
M)7,B('9A;'5E/2(E<R(E<R`O/B<L"B`@("`@("`@("`@("`@("`@("`@("`@
M)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@
M("`@("`@("`@("`@("`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^
M9V5T5F%L=64H)'9A<G,I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I
M+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T06-T:6]N4V-R
M:7!T<R@D9F]R;2P@)'9A<BD*("`@("`@("`@("`@("`@*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?=&5X="@F)&9O<FTL("8D=F%R
M+"`F)'9A<G,I"B`@("!["B`@("`@("`@)&UA>&QE;F=T:"`]("1V87(M/G1Y
M<&4M/F=E=$UA>$QE;F=T:"@I.PH@("`@("`@("1V87)N86UE(#T@0&AT;6QS
M<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%R3F%M92@I+"!%3E1?455/5$53+"`D
M=&AI<RT^7V-H87)S970I.PH@("`@("`@(')E='5R;B!S<')I;G1F*"<\:6YP
M=70@='EP93TB=&5X="(@;F%M93TB)7,B(&ED/2(E<R(@<VEZ93TB)7,B('9A
M;'5E/2(E<R(@)7,E<R5S("\^)RP*("`@("`@("`@("`@("`@("`@("`@("`D
M=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@
M("`@("`@("`@("`@("`@("`@("`D=F%R+3YT>7!E+3YG9713:7IE*"DL"B`@
M("`@("`@("`@("`@("`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^
M9V5T5F%L=64H)'9A<G,I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I
M+`H@("`@("`@("`@("`@("`@("`@("`@("1V87(M/FES1&ES86)L960H*2`_
M("<@9&ES86)L960](F1I<V%B;&5D(B`G(#H@)R<L"B`@("`@("`@("`@("`@
M("`@("`@("`@96UP='DH)&UA>&QE;F=T:"D@/R`G)R`Z("<@;6%X;&5N9W1H
M/2(G("X@)&UA>&QE;F=T:"`N("<B)RP*("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP=',H)&9O<FTL("1V87(I"B`@("`@
M("`@("`@("`@("D["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN
M<'5T7W=E871H97)D;W1C;VTH)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W)E;F1E<E9A<DEN<'5T7W1E>'0H
M)&9O<FTL("1V87(L("1V87)S*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N
M9&5R5F%R26YP=71?<W1R:6YG;&ES="@F)&9O<FTL("8D=F%R+"`F)'9A<G,I
M"B`@("!["B`@("`@("`@)'9A<FYA;64@/2!`:'1M;'-P96-I86QC:&%R<R@D
M=F%R+3YG971687).86UE*"DL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E
M="D["B`@("`@("`@<F5T=7)N('-P<FEN=&8H)SQI;G!U="!T>7!E/2)T97AT
M(B!S:7IE/2(V,"(@;F%M93TB)7,B(&ED/2(E<R(@=F%L=64](B5S(B5S("\^
M)RP*("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@
M("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@
M("!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971686QU92@D=F%R<RDL($5.
M5%]154]415,L("1T:&ES+3Y?8VAA<G-E="DL"B`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]G971!8W1I;VY38W)I<'1S*"1F;W)M+"`D=F%R*0H@
M("`@("`@("`@("`@("`I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)6
M87));G!U=%]C96QL<&AO;F4H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@
M>PH@("`@("`@("1V87)N86UE(#T@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^
M9V5T5F%R3F%M92@I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@
M("`@("`@(')E='5R;B!S<')I;G1F*"<\:6YP=70@='EP93TB=&5X="(@;F%M
M93TB)7,B(&ED/2(E<R(@<VEZ93TB,34B('9A;'5E/2(E<R(@)7,E<R`O/B<L
M"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@
M("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@
M0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%L=64H)'9A<G,I+"!%3E1?
M455/5$53+"`D=&AI<RT^7V-H87)S970I+`H@("`@("`@("`@("`@("`@("`@
M("`@("1V87(M/FES1&ES86)L960H*2`_("<@9&ES86)L960](F1I<V%B;&5D
M(B`G(#H@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G971!
M8W1I;VY38W)I<'1S*"1F;W)M+"`D=F%R*0H@("`@("`@("`@("`@("`I.PH@
M("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=%]I<&%D9')E<W,H
M)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@("1V87)N86UE
M(#T@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%R3F%M92@I+"!%3E1?
M455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@(')E='5R;B!S<')I
M;G1F*"<\:6YP=70@='EP93TB=&5X="(@;F%M93TB)7,B(&ED/2(E<R(@<VEZ
M93TB,38B('9A;'5E/2(E<R(@)7,E<R`O/B<L"B`@("`@("`@("`@("`@("`@
M("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA
M;64L"B`@("`@("`@("`@("`@("`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H
M)'9A<BT^9V5T5F%L=64H)'9A<G,I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H
M87)S970I+`H@("`@("`@("`@("`@("`@("`@("`@("1V87(M/FES1&ES86)L
M960H*2`_("<@9&ES86)L960](F1I<V%B;&5D(B`G(#H@)R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]G971!8W1I;VY38W)I<'1S*"1F;W)M
M+"`D=F%R*0H@("`@("`@("`@("`@("`I.PH@("`@?0H*("`@(&9U;F-T:6]N
M(%]R96YD97)687));G!U=%]F:6QE*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*
M("`@('L*("`@("`@("`D=F%R;F%M92`]($!H=&UL<W!E8VEA;&-H87)S*"1V
M87(M/F=E=%9A<DYA;64H*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T
M*3L*("`@("`@("!R971U<FX@<W!R:6YT9B@G/&EN<'5T('1Y<&4](F9I;&4B
M('-I>F4](C,P(B!N86UE/2(E<R(@:60](B5S(B5S("\^)RP*("`@("`@("`@
M("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@
M("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E
M=$%C=&EO;E-C<FEP=',H)&9O<FTL("1V87(I*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($!T;V1O(%-H;W<@:6UA9V4@9&EM96YS:6]N<R!I;B!T:&4@=VED
M=&@O:&5I9VAT(&)O>&5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<F5N9&5R
M5F%R26YP=71?:6UA9V4H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@
M("`@("`@("1V87)N86UE(#T@:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG9716
M87).86UE*"DI.PH@("`@("`@("1I;6%G92`]("1V87(M/F=E=%9A;'5E*"1V
M87)S*3L*"B`@("`@("`@+RH@0VAE8VL@:68@97AI<W1I;F<@:6UA9V4@9&%T
M82!I<R!B96EN9R!L;V%D960N("HO"B`@("`@("`@)'9A<BT^='EP92T^7VQO
M861);6%G941A=&$H)&EM86=E*3L*"B`@("`@("`@2&]R9&4Z.F%D9%-C<FEP
M=$9I;&4H)VEM86=E+FIS)RP@)VAO<F1E)RP@=')U92D["B`@("`@("`@)&=R
M87!H:6-S7V1I<B`]("1'3$]"04Q36R=R96=I<W1R>2==+3YG971);6%G941I
M<B@G:&]R9&4G*3L*("`@("`@("`D:6UG7V1I<B`]("1G<F%P:&EC<U]D:7(@
M+B`G+VEM86=E)SL*"B`@("`@("`@)&AT;6P@/2`G)SL*"B`@("`@("`@+RH@
M0VAE8VL@:68@=&AE<F4@:7,@97AI<W1I;F<@:6UG(&EN9F]R;6%T:6]N('-T
M;W)E9"X@*B\*("`@("`@("!I9B`H:7-S970H)&EM86=E6R=I;6<G72DI('L*
M("`@("`@("`@("`@+RH@2&ED9&5N('1A9R!T;R!S=&]R92!T:&4@<')E=FEE
M=R!I;6%G92!F:6QE;F%M92X@*B\*("`@("`@("`@("`@)&AT;6P@/2!S<')I
M;G1F*"<\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2(E<R(@:60](B5S(B!V
M86QU93TB)7,B("\^)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V
M87)N86UE("X@)UMI;6==)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1V87)N86UE("X@)UMI;6==)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@($!H=&UL<W!E8VEA;&-H87)S*"1I;6%G95LG:6UG)UTL($5.5%]154]4
M15,L("1T:&ES+3Y?8VAA<G-E="DI.PH@("`@("`@("`@("`O*B!5;G-E<FEA
M;&EZ92!T:&4@:6UG(&EN9F]R;6%T:6]N('1O(&=E="!T:&4@9G5L;"!A<G)A
M>2X@*B\*("`@("`@("`@("`@)&EM86=E6R=I;6<G72`]($!U;G-E<FEA;&EZ
M92@D:6UA9V5;)VEM9R==*3L*("`@("`@("!]"@H@("`@("`@("\J($]U='!U
M="!T:&4@:6YP=70@=&%G+B`J+PH@("`@("`@(&EF("AE;7!T>2@D:6UA9V5;
M)VEM9R==*2D@>PH@("`@("`@("`@("`D:G,@/2`B=F%R('`@/2!D;V-U;65N
M="YG971%;&5M96YT0GE)9"@G(B`N("1V87)N86UE("X@(EMP<F5V:65W72<I
M.R!O(#T@)UQ<7%PG.R!A(#T@)R\G.R!T;7`@/2`G)R`K(&1O8W5M96YT+F=E
M=$5L96UE;G1">4ED*"<B("X@)'9A<FYA;64@+B`B6VYE=UTG*2YV86QU93L@
M:68@*'1M<"D@>R!W:&EL92`H=&UP+FEN9&5X3V8H;RD@/B`M,2D@>R!P;W,@
M/2!T;7`N:6YD97A/9BAO*3L@=&UP(#T@)R<@*R`H=&UP+G-U8G-T<FEN9R@P
M+"!P;W,I("L@82`K('1M<"YS=6)S=')I;F<H*'!O<R`K(&\N;&5N9W1H*2P@
M=&UP+FQE;F=T:"DI.WT[('`N<W)C(#T@)V9I;&4Z+R\O)R`K('1M<#L@<"YA
M;'0@/2`G(B`N(&%D9'-L87-H97,H7R@B268@>6]U('-E92!T:&ES(&UE<W-A
M9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D
M(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(BDI("X@(B<[
M('T[(CL*("`@("`@("`@("`@)&)R;W=S97(@/2`F0G)O=W-E<CHZ<VEN9VQE
M=&]N*"D["B`@("`@("`@("`@(&EF("@D8G)O=W-E<BT^:7-"<F]W<V5R*"=M
M<VEE)RDI('L*("`@("`@("`@("`@("`@("1H=&UL("X]('-P<FEN=&8H)SQI
M;G!U="!T>7!E/2)F:6QE(B!S:7IE/2(S,"(@;F%M93TB)7,B(&ED/2(E<R(@
M;VYC:&%N9V4](B5S(B`O/B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1V87)N86UE("X@)UMN97==)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'9A<FYA;64@+B`G6VYE=UTG+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D:G,I.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@<W!R:6YT9B@G/&EN<'5T
M('1Y<&4](F9I;&4B('-I>F4](C,P(B!N86UE/2(E<R(@:60](B5S(B!O;F-L
M:6-K/2)W:6YD;W<N<V5T5&EM96]U="A<)V1O8W5M96YT+F=E=$5L96UE;G1"
M>4ED*%Q<7"<E<UQ<7"<I+F)L=7(H*3M<)RP@-2D[(B!O;F)L=7(](B5S(B`O
M/B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE
M("X@)UMN97==)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'9A<FYA;64@+B`G6VYE=UTG+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=F%R;F%M92`N("=;;F5W72<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1J<RD["B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D:'1M;"`N/2!S<')I;G1F*"<\:6YP=70@
M='EP93TB9FEL92(@<VEZ93TB,S`B(&YA;64](B5S(B!I9#TB)7,B("\^)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92`N("=;;F5W
M72<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64@+B`G
M6VYE=UTG*3L*("`@("`@("!]"@H@("`@("`@("\J($]U='!U="!T:&4@8G5T
M=&]N('1O('5P;&]A9"]R97-E="!T:&4@:6UA9V4N("HO"B`@("`@("`@:68@
M*"1V87(M/G1Y<&4M/E]S:&]W7W5P;&]A9"D@>PH@("`@("`@("`@("`D:'1M
M;"`N/2`G)FYB<W`[)SL*("`@("`@("`@("`@)&AT;6P@+CT@<W!R:6YT9B@G
M/&EN<'5T(&-L87-S/2)B=71T;VXB(&YA;64](B5S(B!I9#TB)7,B('1Y<&4]
M(G-U8FUI="(@=F%L=64](B5S(B`O/B`G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=?9&]?)R`N("1V87)N86UE+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=?9&]?)R`N("1V87)N86UE+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(%\H(E5P;&]A9"(I*3L*("`@("`@("!]"@H@("`@
M("`@(&EF("AE;7!T>2@D:6UA9V5;)VEM9R==*2D@>PH@("`@("`@("`@("`O
M*B!.;R!I;6%G92!I;F9O<FUA=&EO;B!S=&]R960@>65T+"!S:&]W(&$@8FQA
M;FL@<')E=FEE=RX@*B\*("`@("`@("`@("`@)&AT;6P@+CT@2&]R9&4Z.FEM
M9R@G=')E92]B;&%N:RYP;F<G+"!?*")0<F5V:65W(BDL("=W:61T:#TB-3`B
M(&AE:6=H=#TB-#`B(&ED/2(G("X@)'9A<FYA;64@+B`G6W!R979I97==(B<L
M("1G<F%P:&EC<U]D:7(I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("\J($EM86=E(&EN9F]R;6%T:6]N('-T;W)E9"P@<VAO=R!P<F5V:65W+"!A
M9&0@8G5T=&]N<R!F;W(@:6UA9V4*("`@("`@("`@("`@("H@;6%N:7!U;&%T
M:6]N+B`J+PH@("`@("`@("`@("`D:'1M;"`N/2`G/&)R("\^)SL*("`@("`@
M("`@("`@)&EM9R`]($AO<F1E.CIU<FPH)$=,3T)!3%-;)W)E9VES=')Y)UTM
M/F=E="@G=V5B<F]O="<L("=H;W)D92<I("X@)R]S97)V:6-E<R]I;6%G97,O
M=FEE=RYP:'`G*3L*("`@("`@("`@("`@:68@*&ES<V5T*"1I;6%G95LG:6UG
M)UU;)W9F<U]I9"==*2D@>PH@("`@("`@("`@("`@("`@+RH@0V%L;&EN9R!A
M;B!I;6%G92!F<F]M(%9&4RX@*B\*("`@("`@("`@("`@("`@("1I;6<@/2!5
M=&EL.CIA9&1087)A;65T97(H)&EM9RP@87)R87DH)V8G(#T^("1I;6%G95LG
M:6UG)UU;)W9F<U]I9"==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G<R<@/3X@)W9F<R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=P)R`]/B`D:6UA9V5;)VEM9R==6R=V9G-?<&%T:"==*2D["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O*B!#86QL:6YG(&%N
M(&EM86=E(&9R;VT@82!T;7`@9&ER96-T;W)Y("AU<&QO861S*2X@*B\*("`@
M("`@("`@("`@("`@("1I;6<@/2!5=&EL.CIA9&1087)A;65T97(H)&EM9RP@
M)V8G+"`D:6UA9V5;)VEM9R==6R=F:6QE)UTI.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`O*B!297-E="X@*B\*("`@("`@("`@("`@)&AT;6P@+CT@
M2&]R9&4Z.FQI;FLH)R,G+"!?*")297-E="(I+"`G)RP@)R<L("=S:&]W26UA
M9V4H7"<G("X@)&EM9R`N("=<)RP@7"=?<%\G("X@)'9A<FYA;64@+B`G7"<L
M('1R=64I.R<I("X@2&]R9&4Z.FEM9R@G<F5F<F5S:"YP;F<G+"!?*")297-E
M="(I+"`G86QI9VX](FUI9&1L92(G+"`D:6UG7V1I<BD@+B`G/"]A/B<["@H@
M("`@("`@("`@("`O*B!2;W1A=&4@,C<P+B`J+PH@("`@("`@("`@("`D:'1M
M;"`N/2!(;W)D93HZ;&EN:R@G(R<L(%\H(E)O=&%T92!,969T(BDL("<G+"`G
M)RP@)W-H;W=);6%G92A<)R<@+B!5=&EL.CIA9&1087)A;65T97(H)&EM9RP@
M87)R87DH)V$G(#T^("=R;W1A=&4G+"`G=B<@/3X@)S(W,"<I*2`N("=<)RP@
M7"=?<%\G("X@)'9A<FYA;64@+B`G7"<L('1R=64I.R<I("X@2&]R9&4Z.FEM
M9R@G<F]T871E+3(W,"YP;F<G+"!?*")2;W1A=&4@3&5F="(I+"`G86QI9VX]
M(FUI9&1L92(G+"`D:6UG7V1I<BD@+B`G/"]A/B<["@H@("`@("`@("`@("`O
M*B!2;W1A=&4@,3@P+B`J+PH@("`@("`@("`@("`D:'1M;"`N/2!(;W)D93HZ
M;&EN:R@G(R<L(%\H(E)O=&%T92`Q.#`B*2P@)R<L("<G+"`G<VAO=TEM86=E
M*%PG)R`N(%5T:6PZ.F%D9%!A<F%M971E<B@D:6UG+"!A<G)A>2@G82<@/3X@
M)W)O=&%T92<L("=V)R`]/B`G,3@P)RDI("X@)UPG+"!<)U]P7R<@+B`D=F%R
M;F%M92`N("=<)RP@=')U92D[)RD@+B!(;W)D93HZ:6UG*"=R;W1A=&4M,3@P
M+G!N9R<L(%\H(E)O=&%T92`Q.#`B*2P@)V%L:6=N/2)M:61D;&4B)RP@)&EM
M9U]D:7(I("X@)SPO83XG.PH*("`@("`@("`@("`@+RH@4F]T871E(#DP+B`J
M+PH@("`@("`@("`@("`D:'1M;"`N/2!(;W)D93HZ;&EN:R@G(R<L(%\H(E)O
M=&%T92!2:6=H="(I+"`G)RP@)R<L("=S:&]W26UA9V4H7"<G("X@571I;#HZ
M861D4&%R86UE=&5R*"1I;6<L(&%R<F%Y*"=A)R`]/B`G<F]T871E)RP@)W8G
M(#T^("<Y,"<I*2`N("=<)RP@7"=?<%\G("X@)'9A<FYA;64@+B`G7"<L('1R
M=64I.R<I("X@2&]R9&4Z.FEM9R@G<F]T871E+3DP+G!N9R<L(%\H(E)O=&%T
M92!2:6=H="(I+"`G86QI9VX](FUI9&1L92(G+"`D:6UG7V1I<BD@+B`G/"]A
M/B<["@H@("`@("`@("`@("`O*B!&;&EP(&EM86=E+B`J+PH@("`@("`@("`@
M("`D:'1M;"`N/2!(;W)D93HZ;&EN:R@G(R<L(%\H(D9L:7`B*2P@)R<L("<G
M+"`G<VAO=TEM86=E*%PG)R`N(%5T:6PZ.F%D9%!A<F%M971E<B@D:6UG+"`G
M82<L("=F;&EP)RD@+B`G7"<L(%PG7W!?)R`N("1V87)N86UE("X@)UPG+"!T
M<G5E*3LG*2`N($AO<F1E.CII;6<H)V9L:7`N<&YG)RP@7R@B1FQI<"(I+"`G
M86QI9VX](FUI9&1L92(G+"`D:6UG7V1I<BD@+B`G/"]A/B<["@H@("`@("`@
M("`@("`O*B!-:7)R;W(@:6UA9V4N("HO"B`@("`@("`@("`@("1H=&UL("X]
M($AO<F1E.CIL:6YK*"<C)RP@7R@B36ER<F]R(BDL("<G+"`G)RP@)W-H;W=)
M;6%G92A<)R<@+B!5=&EL.CIA9&1087)A;65T97(H)&EM9RP@)V$G+"`G;6ER
M<F]R)RD@+B`G7"<L(%PG7W!?)R`N("1V87)N86UE("X@)UPG+"!T<G5E*3LG
M*2`N($AO<F1E.CII;6<H)VUI<G)O<BYP;F<G+"!?*")-:7)R;W(B*2P@)V%L
M:6=N/2)M:61D;&4B)RP@)&EM9U]D:7(I("X@)SPO83XG.PH*("`@("`@("`@
M("`@+RH@07!P;'D@9W)A>7-C86QE+B`J+PH@("`@("`@("`@("`D:'1M;"`N
M/2!(;W)D93HZ;&EN:R@G(R<L(%\H(D=R87ES8V%L92(I+"`G)RP@)R<L("=S
M:&]W26UA9V4H7"<G("X@571I;#HZ861D4&%R86UE=&5R*"1I;6<L("=A)RP@
M)V=R87ES8V%L92<I("X@)UPG+"!<)U]P7R<@+B`D=F%R;F%M92`N("=<)RP@
M=')U92D[)RD@+B!(;W)D93HZ:6UG*"=G<F%Y<V-A;&4N<&YG)RP@7R@B1W)A
M>7-C86QE(BDL("=A;&EG;CTB;6ED9&QE(B<L("1I;6=?9&ER*2`N("<\+V$^
M)SL*"B`@("`@("`@("`@("\J(%)E<VEZ92!W:61T:"X@*B\*("`@("`@("`@
M("`@)&AT;6P@+CT@<W!R:6YT9B@G)7,\:6YP=70@='EP93TB=&5X="(@<VEZ
M93TB-"(@;VYC:&%N9V4](G-R8SUG971297-I>F53<F,H7"<E<UPG+"!<)R5S
M7"<I.W-H;W=);6%G92AS<F,L(%PG7W!?)7-<)RP@=')U92D[(B`E<R`O/B<L
M"B`@("`@("`@("`@("`@("`@("!?*")W.B(I+`H@("`@("`@("`@("`@("`@
M("`@571I;#HZ861D4&%R86UE=&5R*"1I;6<L("=A)RP@)W)E<VEZ92<I+`H@
M("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@
M("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5N240H
M)U]W7R<@+B`D=F%R;F%M92DI.PH*("`@("`@("`@("`@+RH@4F5S:7IE(&AE
M:6=H="X@*B\*("`@("`@("`@("`@)&AT;6P@+CT@<W!R:6YT9B@G)7,\:6YP
M=70@='EP93TB=&5X="(@<VEZ93TB-"(@;VYC:&%N9V4](G-R8SUG971297-I
M>F53<F,H7"<E<UPG+"!<)R5S7"<I.W-H;W=);6%G92AS<F,L(%PG7W!?)7-<
M)RP@=')U92D[(B`E<R`O/B<L"B`@("`@("`@("`@("`@("`@("!?*")H.B(I
M+`H@("`@("`@("`@("`@("`@("`@571I;#HZ861D4&%R86UE=&5R*"1I;6<L
M("=A)RP@)W)E<VEZ92<I+`H@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L
M"B`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9V5N240H)U]H7R<@+B`D=F%R;F%M92DI.PH*("`@("`@
M("`@("`@+RH@07!P;'D@9FEX960@<F%T:6\@<F5S:7IE+B`J+PH@("`@("`@
M("`@("`D:'1M;"`N/2!(;W)D93HZ;&EN:R@G(R<L(%\H(D9I>"!R871I;R(I
M+"`G)RP@)R<L("=S<F,]9V5T4F5S:7IE4W)C*%PG)R`N(%5T:6PZ.F%D9%!A
M<F%M971E<B@D:6UG+"`G82<L("=R97-I>F4G*2`N("=<)RP@7"<G("X@)'9A
M<FYA;64@+B`G7"<L(%PG,5PG*3MS:&]W26UA9V4H<W)C+"!<)U]P7R<@+B`D
M=F%R;F%M92`N("=<)RP@=')U92D[)RD@+B!(;W)D93HZ:6UG*"=R871I;RYP
M;F<G+"!?*")&:7@@<F%T:6\B*2P@)V%L:6=N/2)M:61D;&4B)RP@)&EM9U]D
M:7(I("X@)SPO83XG.PH*("`@("`@("`@("`@+RH@2V5E<"!A;'-O(&]R:6=I
M;F%L(&EF(&ET(&AA<R!B965N(')E<75E<W1E9"X@*B\*("`@("`@("`@("`@
M:68@*"1V87(M/G1Y<&4M/E]S:&]W7VME97!O<FEG*2!["B`@("`@("`@("`@
M("`@("`D:'1M;"`N/2!S<')I;G1F*"<\:6YP=70@='EP93TB8VAE8VMB;W@B
M(&-L87-S/2)C:&5C:V)O>"(@;F%M93TB)7,B(&ED/2(E<R(E<R`O/B5S)R`N
M(")<;B(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V87)N
M86UE("X@)UMK965P7V]R:6==)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'9A<FYA;64@+B`G6VME97!?;W)I9UTG+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`A96UP='DH)&EM86=E6R=K965P7V]R
M:6<G72D@/R`G(&-H96-K960](F-H96-K960B)R`Z("<G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!?*")+965P(&]R:6=I;F%L/R(I*3L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@5&AE('!R979I97<@:6UA
M9V4@96QE;65N="X@*B\*("`@("`@("`@("`@)&AT;6P@+CT@)SQB<B`O/CQI
M;6<@<W)C/2(G("X@)&EM9R`N("<B("<@+B`D=&AI<RT^7V=E;DE$*"=?<%\G
M("X@)'9A<FYA;64I("X@(CY<;B(["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)&AT;6P["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T
M7VQO;F=T97AT*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@
M("!G;&]B86P@)&)R;W=S97(["@H@("`@("`@("1V87)N86UE(#T@0&AT;6QS
M<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%R3F%M92@I+"!%3E1?455/5$53+"`D
M=&AI<RT^7V-H87)S970I.PH@("`@("`@("1H=&UL(#T@<W!R:6YT9B@G/'1E
M>'1A<F5A(&ED/2(E<R(@;F%M93TB)7,B(&-O;',](B5S(B!R;W=S/2(E<R(E
M<R5S/B5S/"]T97AT87)E83XG+`H@("`@("`@("`@("`@("`@("`@("`@("`D
M=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@
M("`@("`@("`@("`@("`@("`@("`@("AI;G0I)'9A<BT^='EP92T^9V5T0V]L
M<R@I+`H@("`@("`@("`@("`@("`@("`@("`@("`H:6YT*21V87(M/G1Y<&4M
M/F=E=%)O=W,H*2P*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G
M971!8W1I;VY38W)I<'1S*"1F;W)M+"`D=F%R*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@)'9A<BT^:7-$:7-A8FQE9"@I(#\@)R!D:7-A8FQE9#TB9&ES
M86)L960B)R`Z("<G+`H@("`@("`@("`@("`@("`@("`@("`@("!`:'1M;'-P
M96-I86QC:&%R<R@D=F%R+3YG971686QU92@D=F%R<RDL($5.5%]154]415,L
M("1T:&ES+3Y?8VAA<G-E="DI.PH*("`@("`@("!I9B`H)'9A<BT^='EP92T^
M:&%S2&5L<&5R*"=R=&4G*2`F)B`D8G)O=W-E<BT^:&%S1F5A='5R92@G<G1E
M)RDI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]%9&ET;W(N
M<&AP)SL*("`@("`@("`@("`@)&5D:71O<B`]("9(;W)D95]%9&ET;W(Z.G-I
M;F=L971O;B@G:'1M;&%R96$G+"!A<G)A>2@G:60G(#T^("1V87)N86UE*2D[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H)'9A<BT^='EP92T^:&%S2&5L<&5R
M*"D@)B8@)&)R;W=S97(M/FAA<T9E871U<F4H)VIA=F%S8W)I<'0G*2D@>PH@
M("`@("`@("`@("`D:'1M;"`N/2`G/&)R("\^/'1A8FQE(&-E;&QS<&%C:6YG
M/2(P(CX\='(^/'1D/B<["B`@("`@("`@("`@($AO<F1E.CIA9&138W)I<'1&
M:6QE*"=O<&5N7VAT;6Q?:&5L<&5R+FIS)RP@)VAO<F1E)RD["B`@("`@("`@
M("`@("1I;6=)9"`]("1T:&ES+3Y?9V5N240H)'9A<BT^9V5T5F%R3F%M92@I
M+"!F86QS92D@+B`G96AE;'!E<B<["B`@("`@("`@("`@(&EF("@D=F%R+3YT
M>7!E+3YH87-(96QP97(H)V5M;W1I8V]N<R<I*2!["B`@("`@("`@("`@("`@
M("`D:'1M;"`N/2!(;W)D93HZ;&EN:R@G(R<L(%\H(D5M;W1I8V]N<R(I+"`G
M)RP@)R<L("=O<&5N2'1M;$AE;'!E<BA<)V5M;W1I8V]N<UPG+"!<)R<@+B`D
M=F%R+3YG971687).86UE*"D@+B`G7"<I.R!R971U<FX@9F%L<V4[)RD@+B!(
M;W)D93HZ:6UG*"=S;6EL92YP;F<G+"!?*")%;6]T:6-O;G,B*2P@)VED/2(G
M("X@)&EM9TED("X@)R(@86QI9VX](FUI9&1L92(G+"`D1TQ/0D%,4ULG<F5G
M:7-T<GDG72T^9V5T26UA9V5$:7(H)VAO<F1E)RD@+B`G+V5M;W1I8V]N<R<I
M("X@)SPO83XG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1H=&UL("X]
M("<\+W1D/CPO='(^/'1R/CQT9#X\9&EV("<@+B`D=&AI<RT^7V=E;DE$*"=H
M=&UL:&5L<&5R7R<@+B`D=F%R+3YG971687).86UE*"DI("X@)R!C;&%S<STB
M8V]N=')O;"(^/"]D:78^/"]T9#X\+W1R/CPO=&%B;&4^)R`N(")<;B(["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&AT;6P["B`@("!]"@H@("`@9G5N
M8W1I;VX@7W)E;F1E<E9A<DEN<'5T7V-O=6YT961T97AT*"8D9F]R;2P@)B1V
M87(L("8D=F%R<RD*("`@('L*("`@("`@("`D=F%R;F%M92`]($!H=&UL<W!E
M8VEA;&-H87)S*"1V87(M/F=E=%9A<DYA;64H*2P@14Y47U%53U1%4RP@)'1H
M:7,M/E]C:&%R<V5T*3L*("`@("`@("!R971U<FX@<W!R:6YT9B@G/'1E>'1A
M<F5A(&YA;64](B5S(B!I9#TB)7,B(&-O;',](B5S(B!R;W=S/2(E<R(E<R5S
M/B5S/"]T97AT87)E83XG+`H@("`@("`@("`@("`@("`@("`@("`@("1V87)N
M86UE+`H@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@
M("`@("`@("`@("`@("`@("AI;G0I)'9A<BT^='EP92T^9V5T0V]L<R@I+`H@
M("`@("`@("`@("`@("`@("`@("`@("AI;G0I)'9A<BT^='EP92T^9V5T4F]W
M<R@I+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T06-T:6]N
M4V-R:7!T<R@D9F]R;2P@)'9A<BDL"B`@("`@("`@("`@("`@("`@("`@("`@
M)'9A<BT^:7-$:7-A8FQE9"@I(#\@)R!D:7-A8FQE9#TB9&ES86)L960B)R`Z
M("<G+`H@("`@("`@("`@("`@("`@("`@("`@($!H=&UL<W!E8VEA;&-H87)S
M*"1V87(M/F=E=%9A;'5E*"1V87)S*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C
M:&%R<V5T*2D["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T
M7V%D9')E<W,H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@
M("1V87)N86UE(#T@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%R3F%M
M92@I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@(')E
M='5R;B!S<')I;G1F*"<\=&5X=&%R96$@;F%M93TB)7,B(&ED/2(E<R(@8V]L
M<STB)7,B(')O=W,](B5S(B5S)7,^)7,\+W1E>'1A<F5A/B<L"B`@("`@("`@
M("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@
M("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@*&EN="DD=F%R
M+3YT>7!E+3YG971#;VQS*"DL"B`@("`@("`@("`@("`@("`@("`@("`@*&EN
M="DD=F%R+3YT>7!E+3YG9712;W=S*"DL"B`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]G971!8W1I;VY38W)I<'1S*"1F;W)M+"`D=F%R*2P*("`@
M("`@("`@("`@("`@("`@("`@("`D=F%R+3YI<T1I<V%B;&5D*"D@/R`G(&1I
M<V%B;&5D/2)D:7-A8FQE9"(G(#H@)R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%L=64H)'9A<G,I+"!%
M3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!?<F5N9&5R5F%R26YP=71?9&%T92@F)&9O<FTL("8D=F%R+"`F)'9A
M<G,I"B`@("!["B`@("`@("`@)'9A<FYA;64@/2!`:'1M;'-P96-I86QC:&%R
M<R@D=F%R+3YG971687).86UE*"DL($5.5%]154]415,L("1T:&ES+3Y?8VAA
M<G-E="D["B`@("`@("`@<F5T=7)N('-P<FEN=&8H)SQI;G!U="!T>7!E/2)T
M97AT(B!N86UE/2(E<R(@:60](B5S(B!V86QU93TB)7,B)7,@+SXG+`H@("`@
M("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@
M("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@($!H=&UL
M<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A;'5E*"1V87)S*2P@14Y47U%53U1%
M4RP@)'1H:7,M/E]C:&%R<V5T*2P*("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7V=E=$%C=&EO;E-C<FEP=',H)&9O<FTL("1V87(I*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?=&EM92@F)&9O<FTL("8D
M=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'9A<FYA;64@/2!`:'1M;'-P
M96-I86QC:&%R<R@D=F%R+3YG971687).86UE*"DL($5.5%]154]415,L("1T
M:&ES+3Y?8VAA<G-E="D["B`@("`@("`@<F5T=7)N('-P<FEN=&8H)SQI;G!U
M="!T>7!E/2)T97AT(B!S:7IE/2(U(B!N86UE/2(E<R(@:60](B5S(B!V86QU
M93TB)7,B)7,@+SXG+`H@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE
M+`H@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@
M("`@("`@("`@("`@($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A;'5E
M*"1V87)S*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2P*("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP=',H)&9O
M<FTL("1V87(I*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP
M=71?:&]U<FUI;G5T97-E8V]N9"@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@
M("!["B`@("`@("`@)'9A<FYA;64@/2!`:'1M;'-P96-I86QC:&%R<R@D=F%R
M+3YG971687).86UE*"DL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D[
M"B`@("`@("`@)'1I;64@/2`D=F%R+3YT>7!E+3YG9714:6UE4&%R=',H)'9A
M<BT^9V5T5F%L=64H)'9A<G,I*3L*"B`@("`@("`@+RH@3W5T<'5T(&AO=7)S
M+B`J+PH@("`@("`@("1H;W5R<R`](&%R<F%Y*"<G(#T^(%\H(FAH(BDI.PH@
M("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\/2`R,SL@)&DK*RD@>PH@("`@("`@
M("`@("`D:&]U<G-;)&E=(#T@)&D["B`@("`@("`@?0H@("`@("`@("1H=&UL
M(#T@<W!R:6YT9B@G/'-E;&5C="!N86UE/2(E<UMH;W5R72(@:60](B5S6VAO
M=7)=(B5S/B5S/"]S96QE8W0^)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP
M=',H)&9O<FTL("1V87(I+`H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W-E;&5C=$]P=&EO;G,H)&AO=7)S+"`H)'1I;65;)VAO=7(G72`]/3T@
M)R<I(#\@)R<@.B`D=&EM95LG:&]U<B==*2D["@H@("`@("`@("\J($]U='!U
M="!M:6YU=&5S+B`J+PH@("`@("`@("1M:6YU=&5S(#T@87)R87DH)R<@/3X@
M7R@B;6TB*2D["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P](#4Y.R`D:2LK
M*2!["B`@("`@("`@("`@("1M(#T@<W!R:6YT9B@G)3`R9"<L("1I*3L*("`@
M("`@("`@("`@)&UI;G5T97-;)&U=(#T@)&T["B`@("`@("`@?0H@("`@("`@
M("1H=&UL("X]('-P<FEN=&8H)SQS96QE8W0@;F%M93TB)7-;;6EN=71E72(@
M:60](B5S6VUI;G5T95TB)7,^)7,\+W-E;&5C=#XG+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M9V5T06-T:6]N4V-R:7!T<R@D9F]R;2P@)'9A<BDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W-E;&5C=$]P=&EO;G,H)&UI;G5T97,L("@D
M=&EM95LG;6EN=71E)UT@/3T]("<G*2`_("<G(#H@<W!R:6YT9B@G)3`R9"<L
M("1T:6UE6R=M:6YU=&4G72DI*3L*"B`@("`@("`@+RH@4F5T=7)N(&EF('-E
M8V]N9',@87)E(&YO="!R97%U:7)E9"X@*B\*("`@("`@("!I9B`H(21V87(M
M/G1Y<&4M/E]S:&]W7W-E8V]N9',I('L*("`@("`@("`@("`@<F5T=7)N("1H
M=&UL.PH@("`@("`@('T*"B`@("`@("`@+RH@3W5T<'5T('-E8V]N9',N("HO
M"B`@("`@("`@)'-E8V]N9',@/2!A<G)A>2@G)R`]/B!?*")S<R(I*3L*("`@
M("`@("!F;W(@*"1I(#T@,#L@)&D@/#T@-3D[("1I*RLI('L*("`@("`@("`@
M("`@)'-E8V]N9'-;)&E=(#T@<W!R:6YT9B@G)3`R9"<L("1I*3L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1H=&UL("X@<W!R:6YT9B@G/'-E;&5C="!N
M86UE/2(E<UMS96-O;F1=(B!I9#TB)7-;<V5C;VYD72(E<SXE<SPO<V5L96-T
M/B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G971!8W1I;VY3
M8W)I<'1S*"1F;W)M+"`D=F%R*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<V5L96-T3W!T:6]N<R@D<V5C;VYD<RP@*"1T:6UE
M6R=S96-O;F0G72`]/3T@)R<I(#\@)R<@.B!S<')I;G1F*"<E,#)D)RP@)'1I
M;65;)W-E8V]N9"==*2DI.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)6
M87));G!U=%]M;VYT:'EE87(H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@
M>PH@("`@("`@("1D871E<R`](&%R<F%Y*"D["B`@("`@("`@)&1A=&5S6R=M
M;VYT:"==(#T@87)R87DH)R<@/3X@7R@B34TB*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`Q(#T^(%\H(DIA;G5A<GDB*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`R(#T^(%\H(D9E8G)U87)Y(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@,R`]/B!?*")-87)C:"(I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#0@/3X@7R@B07!R
M:6PB*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`U(#T^(%\H
M(DUA>2(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#8@/3X@
M7R@B2G5N92(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#<@
M/3X@7R@B2G5L>2(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#@@/3X@7R@B075G=7-T(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@.2`]/B!?*")397!T96UB97(B*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`Q,"`]/B!?*")/8W1O8F5R(BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@,3$@/3X@7R@B3F]V96UB97(B*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Q,B`]/B!?*")$96-E;6)E
M<B(I*3L*("`@("`@("`D9&%T97-;)WEE87(G72`](&%R<F%Y*"<G(#T^(%\H
M(EE965DB*2D["B`@("`@("`@:68@*"1V87(M/G1Y<&4M/E]S=&%R=%]Y96%R
M(#X@)'9A<BT^='EP92T^7V5N9%]Y96%R*2!["B`@("`@("`@("`@(&9O<B`H
M)&D@/2`D=F%R+3YT>7!E+3Y?<W1A<G1?>65A<CL@)&D@/CT@)'9A<BT^='EP
M92T^7V5N9%]Y96%R.R`D:2TM*2!["B`@("`@("`@("`@("`@("`D9&%T97-;
M)WEE87(G75LD:5T@/2`D:3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(&9O<B`H)&D@/2`D=F%R+3YT>7!E+3Y?<W1A<G1?
M>65A<CL@)&D@/#T@)'9A<BT^='EP92T^7V5N9%]Y96%R.R`D:2LK*2!["B`@
M("`@("`@("`@("`@("`D9&%T97-;)WEE87(G75LD:5T@/2`D:3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@<W!R:6YT9B@G/'-E
M;&5C="!N86UE/2(E<R(@:60](B5S(B5S/B5S/"]S96QE8W0^)RP*("`@("`@
M("`@("`@("`@("`@("`@("`D=F%R+3YT>7!E+3YG971-;VYT:%9A<B@D=F%R
M*2P*("`@("`@("`@("`@("`@("`@("`@("`D=F%R+3YT>7!E+3YG971-;VYT
M:%9A<B@D=F%R*2P*("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E
M=$%C=&EO;E-C<FEP=',H)&9O<FTL("1V87(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<V5L96-T3W!T:6]N<R@D9&%T97-;)VUO;G1H)UTL
M("1V87)S+3YG970H)'9A<BT^='EP92T^9V5T36]N=&A687(H)'9A<BDI*2D@
M+@H@("`@("`@("`@("!S<')I;G1F*"<\<V5L96-T(&YA;64](B5S(B!I9#TB
M)7,B)7,^)7,\+W-E;&5C=#XG+`H@("`@("`@("`@("`@("`@("`@("1V87(M
M/G1Y<&4M/F=E=%EE87)687(H)'9A<BDL"B`@("`@("`@("`@("`@("`@("`@
M)'9A<BT^='EP92T^9V5T665A<E9A<B@D=F%R*2P*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP=',H)&9O<FTL("1V87(I+`H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5L96-T3W!T:6]N<R@D9&%T
M97-;)WEE87(G72P@)'9A<G,M/F=E="@D=F%R+3YT>7!E+3YG971996%R5F%R
M*"1V87(I*2DI.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687));G!U
M=%]M;VYT:&1A>7EE87(H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@
M("`@("`@("1D871E<R`](&%R<F%Y*"D["B`@("`@("`@)&1A=&5S6R=M;VYT
M:"==(#T@87)R87DH)R<@("`]/B!?*")-32(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("<Q)R`@/3X@7R@B2F%N=6%R>2(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("<R)R`@/3X@7R@B1F5B<G5A<GDB
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G,R<@(#T^(%\H
M(DUA<F-H(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)S0G
M("`]/B!?*")!<')I;"(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("<U)R`@/3X@7R@B36%Y(BDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)S8G("`]/B!?*")*=6YE(BDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)S<G("`]/B!?*")*=6QY(BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)S@G("`]/B!?*")!=6=U<W0B*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G.2<@(#T^(%\H(E-E<'1E
M;6)E<B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<Q,"<@
M/3X@7R@B3V-T;V)E<B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("<Q,2<@/3X@7R@B3F]V96UB97(B*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G,3(G(#T^(%\H(D1E8V5M8F5R(BDI.PH@("`@("`@
M("1D871E<ULG9&%Y)UT@/2!A<G)A>2@G)R`]/B!?*")$1"(I*3L*("`@("`@
M("!F;W(@*"1I(#T@,3L@)&D@/#T@,S$[("1I*RLI('L*("`@("`@("`@("`@
M)&1A=&5S6R=D87DG75LD:5T@/2`D:3L*("`@("`@("!]"B`@("`@("`@)&1A
M=&5S6R=Y96%R)UT@/2!A<G)A>2@G)R`]/B!?*")965E9(BDI.PH@("`@("`@
M(&EF("@D=F%R+3YT>7!E+3Y?<W1A<G1?>65A<B`^("1V87(M/G1Y<&4M/E]E
M;F1?>65A<BD@>PH@("`@("`@("`@("!F;W(@*"1I(#T@)'9A<BT^='EP92T^
M7W-T87)T7WEE87([("1I(#X]("1V87(M/G1Y<&4M/E]E;F1?>65A<CL@)&DM
M+2D@>PH@("`@("`@("`@("`@("`@)&1A=&5S6R=Y96%R)UU;)&E=(#T@)&D[
M"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!F
M;W(@*"1I(#T@)'9A<BT^='EP92T^7W-T87)T7WEE87([("1I(#P]("1V87(M
M/G1Y<&4M/E]E;F1?>65A<CL@)&DK*RD@>PH@("`@("`@("`@("`@("`@)&1A
M=&5S6R=Y96%R)UU;)&E=(#T@)&D["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@)&1A=&4@/2`D=F%R+3YT>7!E+3YG971$871E4&%R=',H)'9A
M<BT^9V5T5F%L=64H)'9A<G,I*3L*"B`@("`@("`@+R\@5$]$3SH@=7-E($Y,
M4R!T;R!G970@=&AE(&]R9&5R(')I9VAT(&9O<B!T:&4@4F5S="!/9B!4:&4*
M("`@("`@("`O+R!7;W)L9"X*("`@("`@("`D:'1M;"`]("<G.PH@("`@("`@
M("1D871E7W!A<G1S(#T@87)R87DH)VUO;G1H)RP@)V1A>2<L("=Y96%R)RD[
M"B`@("`@("`@9F]R96%C:"`H)&1A=&5?<&%R=',@87,@)'!A<G0I('L*("`@
M("`@("`@("`@)'9A<FYA;64@/2!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG
M971687).86UE*"D@+B`G6R<@+B`D<&%R="`N("==)RP@14Y47U%53U1%4RP@
M)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("`@("`@)&AT;6P@+CT@<W!R:6YT
M9B@G/'-E;&5C="!N86UE/2(E<R(@:60](B5S(B5S/B5S/"]S96QE8W0^)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP=',H)&9O
M<FTL("1V87(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<V5L96-T3W!T:6]N<R@D9&%T97-;)'!A<G1=+"`D9&%T95LD<&%R=%TI
M*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D=F%R+3YT>7!E+3Y?<&EC:V5R
M("8F("1'3$]"04Q36R=B<F]W<V5R)UTM/FAA<T9E871U<F4H)VIA=F%S8W)I
M<'0G*2D@>PH@("`@("`@("`@("!(;W)D93HZ861D4V-R:7!T1FEL92@G;W!E
M;E]C86QE;F1A<BYJ<R<L("=H;W)D92<I.PH@("`@("`@("`@("`D:6UG260@
M/2`D=&AI<RT^7V=E;DE$*"1V87(M/F=E=%9A<DYA;64H*2P@9F%L<V4I("X@
M)V=O=&\G.PH@("`@("`@("`@("`D:'1M;"`N/2`G/&1I=B!I9#TB9V]T;R(@
M8VQA<W,](FAE861E<F)O>"(@<W1Y;&4](G!O<VET:6]N.F%B<V]L=71E.W9I
M<VEB:6QI='DZ:&ED9&5N.W!A9&1I;F<Z,"(^/"]D:78^)R`N"B`@("`@("`@
M("`@("`@("!(;W)D93HZ;&EN:R@G(R<L(%\H(E-E;&5C="!A(&1A=&4B*2P@
M)R<L("<G+"`G;W!E;D-A;&5N9&%R*%PG)R`N("1I;6=)9"`N("=<)RP@7"<G
M("X@)'9A<BT^9V5T5F%R3F%M92@I("X@)UPG*3L@<F5T=7)N(&9A;'-E.R<I
M("X@2&]R9&4Z.FEM9R@G8V%L96YD87(N<&YG)RP@7R@B0V%L96YD87(B*2P@
M)VED/2(G("X@)&EM9TED("X@)R(@86QI9VX](FUI9&1L92(G+"`D1TQ/0D%,
M4ULG<F5G:7-T<GDG72T^9V5T26UA9V5$:7(H)VAO<F1E)RDI("X@(CPO83Y<
M;B(["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&AT;6P["B`@("!]"@H@
M("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7V-O;&]R<&EC:V5R*"8D9F]R
M;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("!G;&]B86P@)')E9VES
M=')Y+"`D8G)O=W-E<CL*"B`@("`@("`@)'9A<FYA;64@/2!`:'1M;'-P96-I
M86QC:&%R<R@D=F%R+3YG971687).86UE*"DL($5.5%]154]415,L("1T:&ES
M+3Y?8VAA<G-E="D["B`@("`@("`@)&AT;6P@/2`G/'1A8FQE(&-E;&QS<&%C
M:6YG/2(P(CX\='(^/'1D/B<@+@H@("`@("`@("`@("`G/&EN<'5T('1Y<&4]
M(G1E>'0B('-I>F4](C$P(B!M87AL96YG=&@](C<B(&YA;64](B<@+@H@("`@
M("`@("`@("`D=F%R;F%M92`N("<B(&ED/2(G("X@)'9A<FYA;64@+@H@("`@
M("`@("`@("`G(B!V86QU93TB)R`N($!H=&UL<W!E8VEA;&-H87)S*"1V87(M
M/F=E=%9A;'5E*"1V87)S*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T
M*2`N("<B("\^/"]T9#XG.PH@("`@("`@(&EF("@D8G)O=W-E<BT^:&%S1F5A
M='5R92@G:F%V87-C<FEP="<I*2!["B`@("`@("`@("`@($AO<F1E.CIA9&13
M8W)I<'1&:6QE*"=O<&5N7V-O;&]R<&EC:V5R+FIS)RP@)VAO<F1E)RP@=')U
M92D["B`@("`@("`@("`@("1H=&UL("X]("<\=&0@=VED=&@](C(P(B!I9#TB
M8V]L;W)D96UO7R<@+B`D=F%R;F%M92`N("<B('-T>6QE/2)B86-K9W)O=6YD
M.B<@+B!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971686QU92@D=F%R<RDL
M($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D@+B`G(CX@/"]T9#XG("X*
M("`@("`@("`@("`@("`@("<\=&0^)R`N($AO<F1E.CIL:6YK*"<C)RP@7R@B
M0V]L;W(@4&EC:V5R(BDL("=W:61G970G+"`G)RP@)V]P96Y#;VQO<E!I8VME
M<BA<)R<@+B`D=F%R;F%M92`N("=<)RD[(')E='5R;B!F86QS93LG*2`N($AO
M<F1E.CII;6<H)V-O;&]R<&EC:V5R+G!N9R<L(%\H(D-O;&]R(%!I8VME<B(I
M+"`G:&5I9VAT/2(Q-B(G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D
M92<I*2`N("<\+V$^/"]T9#XG("X*("`@("`@("`@("`@("`@("<\=&0^/&1I
M=B!I9#TB8V]L;W)P:6-K97)?)R`N("1V87)N86UE("X@)R(@8VQA<W,](F-O
M;G1R;VPB/CPO9&EV/CPO=&0^)SL*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1H=&UL("X@)SPO='(^/"]T86)L93XG.PH@("`@?0H*("`@(&9U;F-T:6]N
M(%]R96YD97)687));G!U=%]S;W)T97(H)B1F;W)M+"`F)'9A<BP@)B1V87)S
M*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@("`@("1V
M87)N86UE(#T@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%R3F%M92@I
M+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@("1I;G-T
M86YC92`]("1V87(M/G1Y<&4M/E]I;G-T86YC93L*"B`@("`@("`@2&]R9&4Z
M.F%D9%-C<FEP=$9I;&4H)W-O<G1E<BYJ<R<L("=H;W)D92<L('1R=64I.PH*
M("`@("`@("!R971U<FX@)SQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](B<@
M+B`D=F%R;F%M92`N"B`@("`@("`@("`@("=;87)R87E=(B!V86QU93TB(B`G
M("X@)'1H:7,M/E]G96Y)1"@D=F%R;F%M92`N("=;87)R87E=)RD@+B`G+SXG
M("X*("`@("`@("`@("`@)SQS96QE8W0@8VQA<W,](FQE9G1&;&]A="(@;75L
M=&EP;&4](FUU;'1I<&QE(B!S:7IE/2(G("X*("`@("`@("`@("`@*&EN="DD
M=F%R+3YT>7!E+3YG9713:7IE*"D@+B`G(B!N86UE/2(G("X@)'9A<FYA;64@
M+@H@("`@("`@("`@("`G6VQI<W1=(B!O;F-H86YG93TB)R`N("1I;G-T86YC
M92`N("<N9&5S96QE8W1(96%D97(H*3LB("<@+@H@("`@("`@("`@("`D=&AI
M<RT^7V=E;DE$*"1V87)N86UE("X@)UML:7-T72<I("X@)SXG("X*("`@("`@
M("`@("`@)'9A<BT^='EP92T^9V5T3W!T:6]N<R@D=F%R+3YG971686QU92@D
M=F%R<RDI("X@)SPO<V5L96-T/CQD:78@8VQA<W,](FQE9G1&;&]A="(^)R`N
M"B`@("`@("`@("`@($AO<F1E.CIL:6YK*"<C)RP@7R@B36]V92!U<"(I+"`G
M)RP@)R<L("1I;G-T86YC92`N("<N;6]V94-O;'5M;E5P*"D[(')E='5R;B!F
M86QS93LG*2`N($AO<F1E.CII;6<H)VYA=B]U<"YP;F<G+"!?*")-;W9E('5P
M(BDL("<G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`N("<\
M+V$^/&)R("\^)R`N"B`@("`@("`@("`@($AO<F1E.CIL:6YK*"<C)RP@7R@B
M36]V92!U<"(I+"`G)RP@)R<L("1I;G-T86YC92`N("<N;6]V94-O;'5M;D1O
M=VXH*3L@<F5T=7)N(&9A;'-E.R<I("X@2&]R9&4Z.FEM9R@G;F%V+V1O=VXN
M<&YG)RP@7R@B36]V92!D;W=N(BDL("<G+"`D<F5G:7-T<GDM/F=E=$EM86=E
M1&ER*"=H;W)D92<I*2`N("<\+V$^/"]D:78^)R`N"B`@("`@("`@("`@("<\
M<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^)R`N(")<;B(@+@H@("`@
M("`@("`@("!S<')I;G1F*"<E,21S(#T@;F5W($AO<F1E7T9O<FU?4V]R=&5R
M*%PG)3$D<UPG+"!<)R4R)'-<)RP@7"<E,R1S7"<I.R<@+B`B7&XB+`H@("`@
M("`@("`@("`@("`@("`@("1I;G-T86YC92P@)'9A<FYA;64L("1V87(M/G1Y
M<&4M/F=E=$AE861E<B@I*2`N"B`@("`@("`@("`@('-P<FEN=&8H(B5S+G-E
M=$AI9&1E;B@I.UQN/"]S8W)I<'0^7&XB+"`D:6YS=&%N8V4I.PH@("`@?0H*
M("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=%]A<W-I9VXH)B1F;W)M+"`F
M)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD[
M"@H@("`@("`@($AO<F1E.CIA9&138W)I<'1&:6QE*"=F;W)M7V%S<VEG;BYJ
M<R<L("=H;W)D92<L('1R=64I.PH*("`@("`@("`D;F%M92`]($!H=&UL<W!E
M8VEA;&-H87)S*"1V87(M/F=E=%9A<DYA;64H*2P@14Y47U%53U1%4RP@)'1H
M:7,M/E]C:&%R<V5T*3L*("`@("`@("`D9FYA;64@/2`D9F]R;2T^9V5T3F%M
M92@I("X@)RXG("X@)'9A<BT^9V5T5F%R3F%M92@I.PH@("`@("`@("1S:7IE
M(#T@)'9A<BT^='EP92T^9V5T4VEZ92@I.PH@("`@("`@("1W:61T:"`]("1V
M87(M/G1Y<&4M/F=E=%=I9'1H*"D["B`@("`@("`@)&QH9'(@/2`H8F]O;"DD
M=F%R+3YT>7!E+3YG971(96%D97(H,"D["B`@("`@("`@)')H9'(@/2`H8F]O
M;"DD=F%R+3YT>7!E+3YG971(96%D97(H,2D["B`@("`@("`@)'1H:7,M/E]A
M9&1/;DQO861*879A<V-R:7!T*"=(;W)D95]&;W)M7T%S<VEG;BYS971&:65L
M9"A<)R<@+B`D9FYA;64@+B`G7"<I.R<I.PH*("`@("`@("!R971U<FX@)SQT
M86)L93X\='(^/'1D/B<@+@H@("`@("`@("`@("`G/&EN<'5T('1Y<&4](FAI
M9&1E;B(@;F%M93TB)R`N("1N86UE("X@)U]?=F%L=65S(B`O/B<@+@H@("`@
M("`@("`@("!S<')I;G1F*"<\<V5L96-T(&YA;64](B5S7U]L969T(B!M=6QT
M:7!L93TB;75L=&EP;&4B('-I>F4](B5D(B!S='EL93TB=VED=&@Z)7,B)7,^
M)RP*("`@("`@("`@("`@("`@("`@("`D;F%M92P@)'-I>F4L("1W:61T:"P*
M("`@("`@("`@("`@("`@("`@("`D;&AD<B`_("<@;VYC:&%N9V4](DAO<F1E
M7T9O<FU?07-S:6=N+F1E<V5L96-T2&5A9&5R<RA<)R<@+B`D9FYA;64@+B`G
M7"<L(#`I.R(G(#H@)R<I("X*("`@("`@("`@("`@)'9A<BT^='EP92T^9V5T
M3W!T:6]N<R@P+"`D9FYA;64I("X*("`@("`@("`@("`@)SPO<V5L96-T/CPO
M=&0^/'1D/B<@+@H@("`@("`@("`@("`G/&$@:')E9CTB(B!O;F-L:6-K/2)(
M;W)D95]&;W)M7T%S<VEG;BYM;W9E*%PG)R`N("1F;F%M92`N"B`@("`@("`@
M("`@("=<)RP@,"D[(')E='5R;B!F86QS93LB/B<@+@H@("`@("`@("`@("!(
M;W)D93HZ:6UG*"=R:&%N9"YP;F<G+"!?*")!9&0@8V]L=6UN(BDL(&YU;&PL
M("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RDI("X*("`@("`@("`@
M("`@)SPO83X\8G(@+SX\82!H<F5F/2(B(&]N8VQI8VL](DAO<F1E7T9O<FU?
M07-S:6=N+FUO=F4H7"<G("X*("`@("`@("`@("`@)&9N86UE("X@)UPG+"`Q
M*3L@<F5T=7)N(&9A;'-E.R(^)R`N"B`@("`@("`@("`@($AO<F1E.CII;6<H
M)VQH86YD+G!N9R<L(%\H(E)E;6]V92!C;VQU;6XB*2P@;G5L;"P@)')E9VES
M=')Y+3YG971);6%G941I<B@G:&]R9&4G*2D@+@H@("`@("`@("`@("`G/"]A
M/CPO=&0^/'1D/B<@+@H@("`@("`@("`@("!S<')I;G1F*"<\<V5L96-T(&YA
M;64](B5S7U]R:6=H="(@;75L=&EP;&4](FUU;'1I<&QE(B!S:7IE/2(E9"(@
M<W1Y;&4](G=I9'1H.B5S(B5S/B<L"B`@("`@("`@("`@("`@("`@("`@)&YA
M;64L("1S:7IE+"`D=VED=&@L"B`@("`@("`@("`@("`@("`@("`@)')H9'(@
M/R`G(&]N8VAA;F=E/2)(;W)D95]&;W)M7T%S<VEG;BYD97-E;&5C=$AE861E
M<G,H7"<G("X@)&9N86UE("X@)UPG+"`Q*3LB)R`Z("<G*2`N"B`@("`@("`@
M("`@("1V87(M/G1Y<&4M/F=E=$]P=&EO;G,H,2P@)&9N86UE*2`N"B`@("`@
M("`@("`@("<\+W-E;&5C=#X\+W1D/CPO='(^/"]T86)L93XG.PH@("`@?0H*
M("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=%]I;G9A;&ED*"8D9F]R;2P@
M)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]R
M96YD97)687)$:7-P;&%Y7VEN=F%L:60H)&9O<FTL("1V87(L("1V87)S*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?96YU;2@F)&9O
M<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'9A;'5E<R`]("1V
M87(M/F=E=%9A;'5E<R@I.PH@("`@("`@("1P<F]M<'0@/2`D=F%R+3YT>7!E
M+3YG9710<F]M<'0H*3L*("`@("`@("`D:'1M;&-H87)S(#T@)'9A<BT^9V5T
M3W!T:6]N*"=H=&UL8VAA<G,G*3L*("`@("`@("!I9B`H(65M<'1Y*"1P<F]M
M<'0I*2!["B`@("`@("`@("`@("1P<F]M<'0@/2`G/&]P=&EO;B!V86QU93TB
M(CXG("X@*"1H=&UL8VAA<G,@/R`D<')O;7!T(#H@0&AT;6QS<&5C:6%L8VAA
M<G,H)'!R;VUP="P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2D@+B`G
M/"]O<'1I;VX^)SL*("`@("`@("!]"B`@("`@("`@)'9A<FYA;64@/2!`:'1M
M;'-P96-I86QC:&%R<R@D=F%R+3YG971687).86UE*"DL($5.5%]154]415,L
M("1T:&ES+3Y?8VAA<G-E="D["B`@("`@("`@<F5T=7)N('-P<FEN=&8H)SQS
M96QE8W0@;F%M93TB)7,B(&ED/2(E<R(@)7,^)7,E<SPO<V5L96-T/B<L"B`@
M("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@
M("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]G971!8W1I;VY38W)I<'1S*"1F;W)M+"`D=F%R*2P*("`@("`@("`@
M("`@("`@("`@("`@("`D<')O;7!T+`H@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<V5L96-T3W!T:6]N<R@D=F%L=65S+"`D=F%R+3YG971686QU
M92@D=F%R<RDL("1H=&UL8VAA<G,I*3L*("`@('T*"B`@("!F=6YC=&EO;B!?
M<F5N9&5R5F%R26YP=71?;6QE;G5M*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*
M("`@('L*("`@("`@("`D=F%R;F%M92`]("1V87(M/F=E=%9A<DYA;64H*3L*
M("`@("`@("`D:'9A<FYA;64@/2!`:'1M;'-P96-I86QC:&%R<R@D=F%R;F%M
M92P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("`D=F%L
M=65S(#T@)'9A<BT^9V5T5F%L=65S*"D["B`@("`@("`@)'!R;VUP=',@/2`D
M=F%R+3YT>7!E+3YG9710<F]M<'1S*"D["B`@("`@("`@)'-E;&5C=&5D(#T@
M)'9A<BT^9V5T5F%L=64H)'9A<G,I.PH@("`@("`@("\J($EF('!A<W-I;F<@
M82!N;VXM87)R87D@=F%L=64@;F5E9"!T;R!G970@=&AE(&ME>7,N("HO"B`@
M("`@("`@:68@*"%I<U]A<G)A>2@D<V5L96-T960I*2!["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1V86QU97,@87,@)&ME>5\Q(#T^("1V86QU97-?,BD@>PH@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1V86QU97-?,ELD<V5L96-T961=
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1S96QE8W1E9"`](&%R<F%Y*"<Q
M)R`]/B`D:V5Y7S$L("<R)R`]/B`D<V5L96-T960I.PH@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`O*B!(:61D96X@=&%G('1O('-T;W)E('1H
M92!C=7)R96YT(&9I<G-T(&QE=F5L+B`J+PH@("`@("`@("1H=&UL(#T@<W!R
M:6YT9B@G/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB)7-;;VQD72(@=F%L
M=64](B5S(B`E<R`O/B<L"B`@("`@("`@("`@("`@("`@("`@("`@("1H=F%R
M;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@0&AT;6QS<&5C:6%L8VAA
M<G,H)'-E;&5C=&5D6R<Q)UTL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E
M="DL"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5N240H)'9A
M<FYA;64@+B`G6V]L9%TG*2D["@H@("`@("`@("\J($9I<G-T(&QE=F5L+B`J
M+PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O07)R87DN<&AP)SL*("`@
M("`@("`D=F%L=65S7S$@/2!(;W)D95]!<G)A>3HZ=F%L=65S5&]+97ES*&%R
M<F%Y7VME>7,H)'9A;'5E<RDI.PH@("`@("`@("1H=&UL("X]('-P<FEN=&8H
M)SQS96QE8W0@)7,@;F%M93TB)7-;,5TB(&]N8VAA;F=E/2(E<R(E<SXG+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G96Y)1"@D=F%R;F%M
M92`N("=;,5TG*2P*("`@("`@("`@("`@("`@("`@("`@("`@("1H=F%R;F%M
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("=I9B`H=&AI<RYV86QU92D@
M>R!D;V-U;65N="XG("X@)&9O<FTM/F=E=$YA;64H*2`N("<N9F]R;6YA;64N
M=F%L=64]7"=<)SLG("X@)V1O8W5M96YT+B<@+B`D9F]R;2T^9V5T3F%M92@I
M("X@)RYS=6)M:70H*2!])RP*("`@("`@("`@("`@("`@("`@("`@("`@("@D
M=F%R+3YH87-!8W1I;VXH*2`_("<@)R`N("1T:&ES+3Y?9V5N06-T:6]N4V-R
M:7!T*"1F;W)M+"`D=F%R+3Y?86-T:6]N+"`D=F%R;F%M92D@.B`G)RDI.PH@
M("`@("`@(&EF("@A96UP='DH)'!R;VUP=',I*2!["B`@("`@("`@("`@("1H
M=&UL("X]("<\;W!T:6]N('9A;'5E/2(B/B<@+B!`:'1M;'-P96-I86QC:&%R
M<R@D<')O;7!T<ULP72P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2`N
M("<\+V]P=&EO;CXG.PH@("`@("`@('T*("`@("`@("`D:'1M;"`N/2`D=&AI
M<RT^7W-E;&5C=$]P=&EO;G,H)'9A;'5E<U\Q+"`D<V5L96-T961;)S$G72D[
M"B`@("`@("`@)&AT;6P@+CT@)SPO<V5L96-T/B<["@H@("`@("`@("\J(%-E
M8V]N9"!L979E;"X@*B\*("`@("`@("`D:'1M;"`N/2!S<')I;G1F*"<\<V5L
M96-T("5S(&YA;64](B5S6S)=(B5S/B<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7V=E;DE$*"1V87)N86UE("X@)ULR72<I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@)&AV87)N86UE+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@*"1V87(M/FAA<T%C=&EO;B@I(#\@)R`G("X@)'1H:7,M/E]G
M96Y!8W1I;VY38W)I<'0H)&9O<FTL("1V87(M/E]A8W1I;VXL("1V87)N86UE
M*2`Z("<G*2D["B`@("`@("`@:68@*"%E;7!T>2@D<')O;7!T<RDI('L*("`@
M("`@("`@("`@)&AT;6P@+CT@)SQO<'1I;VX@=F%L=64](B(^)R`N($!H=&UL
M<W!E8VEA;&-H87)S*"1P<F]M<'1S6S%=+"!%3E1?455/5$53+"`D=&AI<RT^
M7V-H87)S970I("X@)SPO;W!T:6]N/B<["B`@("`@("`@?0H@("`@("`@("1V
M86QU97-?,B`](&%R<F%Y*"D["B`@("`@("`@:68@*"%E;7!T>2@D<V5L96-T
M961;)S$G72DI('L*("`@("`@("`@("`@)'9A;'5E<U\R(#T@)B1V86QU97-;
M)'-E;&5C=&5D6R<Q)UU=.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&AT
M;6P@+B`D=&AI<RT^7W-E;&5C=$]P=&EO;G,H)'9A;'5E<U\R+"`D<V5L96-T
M961;)S(G72D@+B`G/"]S96QE8W0^)SL*("`@('T*"B`@("!F=6YC=&EO;B!?
M<F5N9&5R5F%R26YP=71?;75L=&EE;G5M*"8D9F]R;2P@)B1V87(L("8D=F%R
M<RD*("`@('L*("`@("`@("`D=F%L=65S(#T@)'9A<BT^9V5T5F%L=65S*"D[
M"B`@("`@("`@)'-E;&5C=&5D(#T@)'9A<G,M/F=E=$5X:7-T<R@D=F%R+3YG
M971687).86UE*"DL("1W87-S970I.PH@("`@("`@(&EF("@A)'=A<W-E="D@
M>PH@("`@("`@("`@("`D<V5L96-T960@/2`D=F%R+3YG971$969A=6QT*"D[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B!S<')I;G1F*"<\<V5L96-T(&UU
M;'1I<&QE/2)M=6QT:7!L92(@<VEZ93TB)7,B(&YA;64](B5S6UTB("5S/B5S
M/"]S96QE8W0^)RP*("`@("`@("`@("`@("`@("`@("`@("`H:6YT*21V87(M
M/G1Y<&4M/G-I>F4L"B`@("`@("`@("`@("`@("`@("`@("`@0&AT;6QS<&5C
M:6%L8VAA<G,H)'9A<BT^9V5T5F%R3F%M92@I+"!%3E1?455/5$53+"`D=&AI
M<RT^7V-H87)S970I+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M9V5T06-T:6]N4V-R:7!T<R@D9F]R;2P@)'9A<BDL"B`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]M=6QT:5-E;&5C=$]P=&EO;G,H)'9A;'5E<RP@
M)'-E;&5C=&5D*2D@+@H@("`@("`@("`@("`B/&)R("\^7&XB("X@7R@B5&\@
M<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@
M*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RXB*2`N
M(")<;B(["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7W)A
M9&EO*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]R861I;T)U='1O;G,H)'9A<BT^9V5T5F%R3F%M92@I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%R+3YG9716
M86QU97,H*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'9A<BT^9V5T5F%L=64H)'9A<G,I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP=',H)&9O<FTL
M("1V87(I*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?
M<V5T*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("`D:'1M
M;"`]("1T:&ES+3Y?8VAE8VM";WAE<R@D=F%R+3YG971687).86UE*"DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A<BT^9V5T5F%L
M=65S*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A
M<BT^9V5T5F%L=64H)'9A<G,I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?9V5T06-T:6]N4V-R:7!T<R@D9F]R;2P@)'9A
M<BDI.PH*("`@("`@("!I9B`H)'9A<BT^='EP92T^7V-H96-K06QL*2!["B`@
M("`@("`@("`@("1F;W)M7VYA;64@/2`D9F]R;2T^9V5T3F%M92@I.PH@("`@
M("`@("`@("`D=F%R7VYA;64@/2`D=F%R+3YG971687).86UE*"D@+B`G6UTG
M.PH@("`@("`@("`@("`D9G5N8W1I;VY?;F%M92`]("=S96QE8W0G("`N("1F
M;W)M7VYA;64@+B`D=F%R+3YG971687).86UE*"D["B`@("`@("`@("`@("1E
M;F%B;&4@/2!?*")396QE8W0@86QL(BD["B`@("`@("`@("`@("1D:7-A8FQE
M(#T@7R@B4V5L96-T(&YO;F4B*3L*("`@("`@("`@("`@)&EN=F5R="`](%\H
M(DEN=F5R="!S96QE8W1I;VXB*3L*("`@("`@("`@("`@)&AT;6P@+CT@/#P\
M14]4"CQS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*9G5N8W1I;VX@
M)&9U;F-T:6]N7VYA;64H*0I["B`@("!F;W(@*'9A<B!I(#T@,#L@:2`\(&1O
M8W5M96YT+B1F;W)M7VYA;64N96QE;65N=',N;&5N9W1H.R!I*RLI('L*("`@
M("`@("!F(#T@9&]C=6UE;G0N)&9O<FU?;F%M92YE;&5M96YT<UMI73L*("`@
M("`@("!I9B`H9BYN86UE("$]("<D=F%R7VYA;64G*2!["B`@("`@("`@("`@
M(&-O;G1I;G5E.PH@("`@("`@('T*("`@("`@("!I9B`H87)G=6UE;G1S+FQE
M;F=T:"D@>PH@("`@("`@("`@("!F+F-H96-K960@/2!A<F=U;65N='-;,%T[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@9BYC:&5C:V5D(#T@(68N
M8VAE8VME9#L*("`@("`@("!]"B`@("!]"GT*/"]S8W)I<'0^"CQA(&AR968]
M(B,B(&]N8VQI8VL](B1F=6YC=&EO;E]N86UE*'1R=64I.R!R971U<FX@9F%L
M<V4[(CXD96YA8FQE/"]A/BP*/&$@:')E9CTB(R(@;VYC;&EC:STB)&9U;F-T
M:6]N7VYA;64H9F%L<V4I.R!R971U<FX@9F%L<V4[(CXD9&ES86)L93PO83XL
M"CQA(&AR968](B,B(&]N8VQI8VL](B1F=6YC=&EO;E]N86UE*"D[(')E='5R
M;B!F86QS93LB/B1I;G9E<G0\+V$^"D5/5#L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D:'1M;#L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R
M26YP=71?;&EN:R@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?<F5N9&5R5F%R1&ES<&QA>5]L:6YK*"1F;W)M
M+"`D=F%R+"`D=F%R<RD["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A
M<DEN<'5T7VAT;6PH)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^7W)E;F1E<E9A<D1I<W!L87E?:'1M;"@D9F]R
M;2P@)'9A<BP@)'9A<G,I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)6
M87));G!U=%]E;6%I;"@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@
M("`@("`@<F5T=7)N('-P<FEN=&8H)SQI;G!U="!T>7!E/2)T97AT(B!N86UE
M/2(E<R(@:60](B5S(B!V86QU93TB)7,B)7,@+SXG+`H@("`@("`@("`@("`@
M("`@("`@("`@("1V87(M/F=E=%9A<DYA;64H*2P*("`@("`@("`@("`@("`@
M("`@("`@("`D=F%R+3YG971687).86UE*"DL"B`@("`@("`@("`@("`@("`@
M("`@("`@)'9A<BT^9V5T5F%L=64H)'9A<G,I+`H@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?9V5T06-T:6]N4V-R:7!T<R@D9F]R;2P@)'9A<BDI
M.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=%]M871R:7@H
M)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@("1V87)N86UE
M("`@/2`D=F%R+3YG971687).86UE*"D["B`@("`@("`@)'9A<E]A<G)A>2`]
M("1V87(M/F=E=%9A;'5E*"1V87)S*3L*("`@("`@("`D8V]L<R`@("`@(#T@
M)'9A<BT^='EP92T^9V5T0V]L<R@I.PH@("`@("`@("1R;W=S("`@("`@/2`D
M=F%R+3YT>7!E+3YG9712;W=S*"D["B`@("`@("`@)&UA=')I>"`@("`]("1V
M87(M/G1Y<&4M/F=E=$UA=')I>"@I.PH@("`@("`@("1N97=?:6YP=70@/2`D
M=F%R+3YT>7!E+3YG971.97=);G!U="@I.PH*("`@("`@("`D:'1M;"`]("<\
M=&%B;&4@8V5L;'-P86-I;F<](C`B/CQT<CXG.PH*("`@("`@("`D:'1M;"`N
M/2`G/'1D(&%L:6=N/2)R:6=H="(@=VED=&@](C(P)2(^/"]T9#XG.PH@("`@
M("`@(&9O<F5A8V@@*"1C;VQS(&%S("1C;VQ?=&ET;&4I('L*("`@("`@("`@
M("`@)&AT;6P@+CT@<W!R:6YT9B@G/'1D(&%L:6=N/2)C96YT97(B('=I9'1H
M/2(Q)24B/B5S/"]T9#XG+"`D8V]L7W1I=&QE*3L*("`@("`@("!]"B`@("`@
M("`@)&AT;6P@+CT@)SQT9"!A;&EG;CTB<FEG:'0B('=I9'1H/2(V,"4B/CPO
M=&0^/"]T<CXG.PH*("`@("`@("`O*B!/9F9E<B!A(&YE=R!R;W<@;V8@9&%T
M82!T;R!B92!A9&1E9"!T;R!T:&4@;6%T<FEX/R`J+PH@("`@("`@(&EF("@D
M;F5W7VEN<'5T*2!["B`@("`@("`@("`@("1H=&UL("X]("<\='(^/'1D/B<[
M"B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D;F5W7VEN<'5T*2D@>PH@("`@
M("`@("`@("`@("`@)&AT;6P@+CT@<W!R:6YT9B@G/'-E;&5C="`E<R!N86UE
M/2(E<UMN75MR72(^/&]P=&EO;B!V86QU93TB(CXE<SPO;W!T:6]N/B5S/"]S
M96QE8W0^/&)R("\^)RP*("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V=E;DE$*"1V87)N86UE("X@)UMN75MR72<I+`H@("`@("`@("`@("`@("`@
M("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@(%\H(BTM
M('-E;&5C="`M+2(I+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<V5L96-T3W!T:6]N<R@D;F5W7VEN<'5T+"`D=F%R7V%R<F%Y6R=N)UU;)W(G
M72DI.PH@("`@("`@("`@("!](&5L<V5I9B`H)&YE=U]I;G!U="`]/2!T<G5E
M*2!["B`@("`@("`@("`@("`@("`D:'1M;"`N/2!S<')I;G1F*"<\:6YP=70@
M)7,@='EP93TB=&5X="(@;F%M93TB)7-;;EU;<ETB('9A;'5E/2(E<R(@+SXG
M+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5N240H)'9A<FYA
M;64@+B`G6VY=6W)=)RDL"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA
M;64L"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<E]A<G)A>5LG;B==6R=R
M)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1H=&UL("X]("<@/"]T
M9#XG.PH@("`@("`@("`@("!F;W)E86-H("@D8V]L<R!A<R`D8V]L7VED(#T^
M("1C;VQ?=&ET;&4I('L*("`@("`@("`@("`@("`@("1H=&UL("X]('-P<FEN
M=&8H)SQT9"!A;&EG;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B
M(&-L87-S/2)C:&5C:V)O>"(@;F%M93TB)7-;;EU;=EU;)7-=(B`O/CPO=&0^
M)RP@)'9A<FYA;64L("1C;VQ?:60I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1H=&UL("X]("<\=&0^(#PO=&0^/"]T<CXG.PH@("`@("`@('T*"B`@
M("`@("`@+RH@3&]O<"!T:')O=6=H('1H92!R;W=S(&%N9"!C<F5A=&4@8VAE
M8VMB;WAE<R!F;W(@96%C:"!C;VQU;6XN("HO"B`@("`@("`@9F]R96%C:"`H
M)')O=W,@87,@)')O=U]I9"`]/B`D<F]W7W1I=&QE*2!["B`@("`@("`@("`@
M("1H=&UL("X]('-P<FEN=&8H)SQT<CX\=&0^)7,\+W1D/B<L("1R;W=?=&ET
M;&4I.PH@("`@("`@("`@("!F;W)E86-H("@D8V]L<R!A<R`D8V]L7VED(#T^
M("1C;VQ?=&ET;&4I('L*("`@("`@("`@("`@("`@("1H=&UL("X]('-P<FEN
M=&8H)SQT9"!A;&EG;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B
M(&-L87-S/2)C:&5C:V)O>"(@;F%M93TB)7-;<EU;)7-=6R5S72(E<R`O/CPO
M=&0^)RP@)'9A<FYA;64L("1R;W=?:60L("1C;VQ?:60L("@A96UP='DH)&UA
M=')I>%LD<F]W7VED75LD8V]L7VED72D@/R`G(&-H96-K960](F-H96-K960B
M)R`Z("<G*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&AT;6P@+CT@
M)SQT9#X@/"]T9#X\+W1R/B<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&AT;6P@+B`G/"]T86)L93XG.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD
M97)687));G!U=%]P87-S=V]R9"@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@
M("!["B`@("`@("`@)'9A<FYA;64@/2!`:'1M;'-P96-I86QC:&%R<R@D=F%R
M+3YG971687).86UE*"DL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D[
M"B`@("`@("`@<F5T=7)N('-P<FEN=&8H)SQI;G!U="!T>7!E/2)P87-S=V]R
M9"(@;F%M93TB)7,B(&ED/2(E<R(@=F%L=64](B5S(B5S("\^)RP*("`@("`@
M("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@
M("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("!`:'1M;'-P
M96-I86QC:&%R<R@D=F%R+3YG971686QU92@D=F%R<RDL($5.5%]154]415,L
M("1T:&ES+3Y?8VAA<G-E="DL"B`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]G971!8W1I;VY38W)I<'1S*"1F;W)M+"`D=F%R*2D["B`@("!]"@H@
M("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7V5M86EL8V]N9FER;2@F)&9O
M<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)&5M86EL(#T@)'9A
M<BT^9V5T5F%L=64H)'9A<G,I.PH@("`@("`@("1V87)N86UE(#T@0&AT;6QS
M<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%R3F%M92@I+"!%3E1?455/5$53+"`D
M=&AI<RT^7V-H87)S970I.PH@("`@("`@(')E='5R;B!S<')I;G1F*"<\:6YP
M=70@='EP93TB=&5X="(@;F%M93TB)7-;;W)I9VEN86Q=(B!I9#TB)7-;;W)I
M9VEN86Q=(B!V86QU93TB)7,B)7,@+SXG+`H@("`@("`@("`@("`@("`@("`@
M("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE
M+`H@("`@("`@("`@("`@("`@("`@("`@($!H=&UL<W!E8VEA;&-H87)S*"1E
M;6%I;%LG;W)I9VEN86PG72P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T
M*2P*("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$%C=&EO;E-C
M<FEP=',H)&9O<FTL("1V87(I*2`N"B`@("`@("`@("`@("<@)R`N('-P<FEN
M=&8H)SQI;G!U="!T>7!E/2)T97AT(B!N86UE/2(E<UMC;VYF:7)M72(@:60]
M(B5S6V-O;F9I<FU=(B!V86QU93TB)7,B)7,@+SXG+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@($!H=&UL
M<W!E8VEA;&-H87)S*"1E;6%I;%LG8V]N9FER;2==+"!%3E1?455/5$53+"`D
M=&AI<RT^7V-H87)S970I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?9V5T06-T:6]N4V-R:7!T<R@D9F]R;2P@)'9A<BDI.PH@("`@?0H*
M("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=%]P87-S=V]R9&-O;F9I<FTH
M)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@("1P87-S=V]R
M9"`]("1V87(M/F=E=%9A;'5E*"1V87)S*3L*("`@("`@("`D=F%R;F%M92`]
M($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A<DYA;64H*2P@14Y47U%5
M3U1%4RP@)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("!R971U<FX@<W!R:6YT
M9B@G/&EN<'5T('1Y<&4](G!A<W-W;W)D(B!N86UE/2(E<UMO<FEG:6YA;%TB
M(&ED/2(E<UMO<FEG:6YA;%TB('9A;'5E/2(E<R(E<R`O/B<L"B`@("`@("`@
M("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@
M("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@0&AT;6QS<&5C
M:6%L8VAA<G,H)'!A<W-W;W)D6R=O<FEG:6YA;"==+"!%3E1?455/5$53+"`D
M=&AI<RT^7V-H87)S970I+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?9V5T06-T:6]N4V-R:7!T<R@D9F]R;2P@)'9A<BDI("X*("`@("`@("`@
M("`@)R`G("X@<W!R:6YT9B@G/&EN<'5T('1Y<&4](G!A<W-W;W)D(B!N86UE
M/2(E<UMC;VYF:7)M72(@:60](B5S6V-O;F9I<FU=(B!V86QU93TB)7,B)7,@
M+SXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@($!H=&UL<W!E8VEA;&-H87)S*"1P87-S=V]R9%LG8V]N
M9FER;2==+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T06-T:6]N4V-R:7!T<R@D
M9F]R;2P@)'9A<BDI.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687))
M;G!U=%]B;V]L96%N*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@
M("`@("`D=F%R;F%M92`]($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A
M<DYA;64H*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@
M("`D:'1M;"`]("<\:6YP=70@='EP93TB8VAE8VMB;W@B(&-L87-S/2)C:&5C
M:V)O>"(@;F%M93TB)R`N("`D=F%R;F%M92`N("<B)R`N"B`@("`@("`@("`@
M("<@:60](B<@+B`D=F%R;F%M92`N("<B)R`N("@D=F%R+3YG971686QU92@D
M=F%R<RD@/R`G(&-H96-K960](F-H96-K960B)R`Z("<G*3L*("`@("`@("!I
M9B`H)'9A<BT^:&%S06-T:6]N*"DI('L*("`@("`@("`@("`@)&AT;6P@+CT@
M)'1H:7,M/E]G96Y!8W1I;VY38W)I<'0H)&9O<FTL("1V87(M/E]A8W1I;VXL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1V87(M/F=E=%9A<DYA;64H*2D["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B`D:'1M;"`N("<@+SXG.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)6
M87));G!U=%]C<F5D:71C87)D*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@
M('L*("`@("`@("`D=F%R;F%M92`]($!H=&UL<W!E8VEA;&-H87)S*"1V87(M
M/F=E=%9A<DYA;64H*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*3L*
M("`@("`@("`D:'1M;"`]("<\:6YP=70@='EP93TB=&5X="(@;F%M93TB)R`N
M("1V87)N86UE("X@)R(@:60](B<@+B`D=F%R;F%M92`N("<B('9A;'5E/2(G
M("X*("`@("`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%L
M=64H)'9A<G,I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I("X@)R(G
M.PH@("`@("`@(&EF("@D=F%R+3YH87-!8W1I;VXH*2D@>PH@("`@("`@("`@
M("`D:'1M;"`N/2`D=&AI<RT^7V=E;D%C=&EO;E-C<FEP="@D9F]R;2P@)'9A
M<BT^7V%C=&EO;BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'9A<BT^9V5T5F%R3F%M92@I*3L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N("1H=&UL("X@)R`O/B<["B`@("!]"@H@("`@9G5N8W1I
M;VX@7W)E;F1E<E9A<DEN<'5T7V]B<F]W<V5R*"8D9F]R;2P@)B1V87(L("8D
M=F%R<RD*("`@('L*("`@("`@("`D=F%R;F%M92`]("1V87(M/F=E=%9A<DYA
M;64H*3L*("`@("`@("`D=F%R=F%L=64@/2`D=F%R<RT^9V5T*"1V87)N86UE
M*3L*("`@("`@("`D9FEE;&1)9"`]("1T:&ES+3Y?9V5N240H;60U*'5N:7%I
M9"AR86YD*"DL('1R=64I*2P@9F%L<V4I("X@)VED)SL*("`@("`@("`D:'1M
M;"`]("<*("`@("`@("`@("`@/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I
M<'0B/@H@("`@("`@("`@("!V87(@;V)R;W=S97)7:6YD;W=.86UE.PH@("`@
M("`@("`@("!F=6YC=&EO;B!O8G)O=W-E<D-A;&QB86-K*&YA;64L(&]I9"D*
M("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@:68@*&YA;64@/3T@;V)R
M;W=S97)7:6YD;W=.86UE*2!["B`@("`@("`@("`@("`@("`@("`@9&]C=6UE
M;G0N9V5T16QE;65N=$)Y260H7"<G("X@)&9I96QD260@+B`G7"<I+G9A;'5E
M(#T@;VED.PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N("));G9A;&ED('=I;F1O=R!N86UE('-U<'!L:65D(CL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`\+W-C<FEP=#X*
M("`@("`@("`@("`@)SL*("`@("`@("`D:'1M;"`N/2!S<')I;G1F*"<\:6YP
M=70@='EP93TB:&ED9&5N(B!N86UE/2(E<R(@:60](B5S(B5S('9A;'5E/2(E
M<R(^)RP*("`@("`@("`@("`@("`@("`@("`@("`@($!H=&UL<W!E8VEA;&-H
M87)S*"1V87)N86UE+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@)&9I96QD260L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP=',H)&9O<FTL
M("1V87(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@0&AT;6QS<&5C:6%L
M8VAA<G,H)'9A<G9A;'5E+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I
M*3L*("`@("`@("!I9B`H(65M<'1Y*"1V87)V86QU92DI('L*("`@("`@("`@
M("`@)&AT;6P@+CT@)'9A<G9A;'5E.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"1'3$]"04Q36R=B<F]W<V5R)UTM/FAA<T9E871U<F4H)VIA=F%S8W)I<'0G
M*2D@>PH@("`@("`@("`@("!(;W)D93HZ861D4V-R:7!T1FEL92@G<&]P=7`N
M:G,G+"`G:&]R9&4G+"!T<G5E*3L*("`@("`@("`@("`@)&EM9TED(#T@)'1H
M:7,M/E]G96Y)1"@D=F%R;F%M92P@9F%L<V4I("X@)V=O=&\G.PH@("`@("`@
M("`@("`D:'1M;"`N/2`G/&1I=B!I9#TB9V]T;R(@8VQA<W,](FAE861E<F)O
M>"(@<W1Y;&4](G!O<VET:6]N.F%B<V]L=71E.W9I<VEB:6QI='DZ:&ED9&5N
M.W!A9&1I;F<Z,"(^/"]D:78^)R`N"B`@("`@("`@("`@("`@("!(;W)D93HZ
M;&EN:R@G(R<L(%\H(E-E;&5C="!A;B!O8FIE8W0B*2P@)R<L("<G+"`G;V)R
M;W=S97)7:6YD;W<@/2!P;W!U<"A<)R<@+B`D1TQ/0D%,4ULG<F5G:7-T<GDG
M72T^9V5T*"=W96)R;V]T)RP@)VAO<F1E)RD@+B`G+W-E<G9I8V5S+V]B<F]W
M<V5R+R<@+B`G7"<I.R!O8G)O=W-E<E=I;F1O=TYA;64@/2!O8G)O=W-E<E=I
M;F1O=RYN86UE.R!R971U<FX@9F%L<V4[)RD@+B!(;W)D93HZ:6UG*"=T<F5E
M+VQE868N<&YG)RP@7R@B3V)J96-T(BDL("=I9#TB)R`N("1I;6=)9"`N("<B
M(&%L:6=N/2)M:61D;&4B)RP@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E=$EM
M86=E1&ER*"=H;W)D92<I*2`N("(\+V$^7&XB.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1H=&UL.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)6
M87));G!U=%]D8FQO;VMU<"@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F5N9&5R5F%R26YP=71?96YU;2@D
M9F]R;2P@)'9A<BP@)'9A<G,I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD
M97)687));G!U=%]F:6=L970H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@
M>PH@("`@("`@("1V87)N86UE(#T@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^
M9V5T5F%R3F%M92@I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@
M("`@("`@(')E='5R;B!S<')I;G1F*"<\:6YP=70@='EP93TB=&5X="(@;F%M
M93TB)7,B(&ED/2(E<R(@<VEZ93TB)7,B('9A;'5E/2(E<R(@+SXG+`H@("`@
M("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@
M("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@('-T<FQE
M;B@D=F%R+3YT>7!E+3YG971497AT*"DI+`H@("`@("`@("`@("`@("`@("`@
M("`@($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A;'5E*"1V87)S*2P@
M14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2D@+@H@("`@("`@("`@("`G
M/&)R("\^)R`N(%\H(D5N=&5R('1H92!L971T97)S(&)E;&]W.B(I("X@)SQB
M<B`O/B<@+@H@("`@("`@("`@("`D=&AI<RT^7W)E;F1E<E9A<D1I<W!L87E?
M9FEG;&5T*"1F;W)M+"`D=F%R+"`D=F%R<RD["B`@("!]"@H@("`@9G5N8W1I
M;VX@7W)E;F1E<E9A<D1I<W!L87E$969A=6QT*"8D9F]R;2P@)B1V87(L("8D
M=F%R<RD*("`@('L*("`@("`@("!R971U<FX@;FPR8G(H0&AT;6QS<&5C:6%L
M8VAA<G,H)'9A<BT^9V5T5F%L=64H)'9A<G,I+"!%3E1?455/5$53+"`D=&AI
M<RT^7V-H87)S970I*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R
M1&ES<&QA>5]H=&UL*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@
M("`@("`O+R!3:6YC92!T:&ES(&ES(&%N($A434P@='EP92!W92!E>'!L:6-I
M=&QY(&1O;B=T(&5S8V%P90H@("`@("`@("\O(&ET+B!5<V5R(&)E=V%R92X*
M("`@("`@("!R971U<FX@)'9A<BT^9V5T5F%L=64H)'9A<G,I.PH@("`@?0H*
M("`@(&9U;F-T:6]N(%]R96YD97)687)$:7-P;&%Y7V5M86EL*"8D9F]R;2P@
M)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("`D9&ES<&QA>5]E;6%I;"`]
M("1E;6%I;"`]("1V87(M/F=E=%9A;'5E*"1V87)S*3L*"B`@("`@("`@:68@
M*"1V87(M/G1Y<&4M/E]S=')I<%]D;VUA:6X@)B8@<W1R<&]S*"1E;6%I;"P@
M)T`G*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@)&1I<W!L87E?96UA:6P@
M/2!S=')?<F5P;&%C92AA<G)A>2@G0"<L("<N)RDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)R`H870I("<L("<@
M*&1O="D@)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&5M86EL*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D=F%R+3YT
M>7!E+3Y?;&EN:U]C;VUP;W-E*2!["B`@("`@("`@("`@("1E;6%I;%]V86P@
M/2!T<FEM*"1E;6%I;"D["@H@("`@("`@("`@("`O+R!&;W)M870@=&AE(&%D
M9')E<W,@86-C;W)D:6YG('1O(%)&0S@R,BX*("`@("`@("`@("`@)&UA:6QB
M;WA?:&]S="`](&5X<&QO9&4H)T`G+"`D96UA:6Q?=F%L*3L*("`@("`@("`@
M("`@:68@*"%I<W-E="@D;6%I;&)O>%]H;W-T6S%=*2D@>PH@("`@("`@("`@
M("`@("`@)&UA:6QB;WA?:&]S=%LQ72`]("<G.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`D;F%M92`](&YU;&P["B`@("`@("`@("`@(&EF("@D=F%R
M+3YT>7!E+3Y?;&EN:U]N86UE*2!["B`@("`@("`@("`@("`@("`D;F%M92`]
M("1V87(M/G1Y<&4M/E]L:6YK7VYA;64["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O34E-12YP:'`G.PH@("`@("`@
M("`@("`D861D<F5S<R`]($U)344Z.G)F8S@R,E=R:71E061D<F5S<R@D;6%I
M;&)O>%]H;W-T6S!=+"`D;6%I;&)O>%]H;W-T6S%=+"`D;F%M92D["@H@("`@
M("`@("`@("`O+R!'970@<FED(&]F('1H92!T<F%I;&EN9R!`("AW:&5N(&YO
M(&AO<W0@:7,@:6YC;'5D960@:6X*("`@("`@("`@("`@+R\@=&AE(&5M86EL
M(&%D9')E<W,I+@H@("`@("`@("`@("`D861D<F5S<R`]('-T<E]R97!L86-E
M*"=`/B<L("<^)RP@)&%D9')E<W,I.PH@("`@("`@("`@("`D;6%I;%]L:6YK
M(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F-A;&PH)VUA:6PO8V]M<&]S92<L
M(&%R<F%Y*&%R<F%Y*"=T;R<@/3X@861D<VQA<VAE<R@D861D<F5S<RDI*2D[
M"B`@("`@("`@("`@(&EF("AI<U]A*"1M86EL7VQI;FLL("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@("1M86EL7VQI;FL@/2`G;6%I;'1O.B<@
M+B!U<FQE;F-O9&4H)&%D9')E<W,I.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("!R971U<FX@2&]R9&4Z.FQI;FLH)&UA:6Q?;&EN:RP@)&5M86EL7W9A
M;"D@+B!`:'1M;'-P96-I86QC:&%R<R@D9&ES<&QA>5]E;6%I;"P@14Y47U%5
M3U1%4RP@)'1H:7,M/E]C:&%R<V5T*2`N("<\+V$^)SL*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!R971U<FX@;FPR8G(H0&AT;6QS<&5C:6%L8VAA
M<G,H)&1I<W!L87E?96UA:6PL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E
M="DI.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R
M1&ES<&QA>5]P87-S=V]R9"@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("![
M"B`@("`@("`@<F5T=7)N("<J*BHJ*BHJ*B<["B`@("!]"@H@("`@9G5N8W1I
M;VX@7W)E;F1E<E9A<D1I<W!L87E?<&%S<W=O<F1C;VYF:7)M*"8D9F]R;2P@
M)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("!R971U<FX@)RHJ*BHJ*BHJ
M)SL*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R1&ES<&QA>5]O8W1A
M;"@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@<F5T=7)N
M('-P<FEN=&8H)S`E;R<L(&]C=&1E8R@D=F%R+3YG971686QU92@D=F%R<RDI
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R1&ES<&QA>5]B;V]L
M96%N*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("!R971U
M<FX@)'9A<BT^9V5T5F%L=64H)'9A<G,I(#\@7R@B665S(BD@.B!?*").;R(I
M.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687)$:7-P;&%Y7V5N=6TH
M)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@("1V86QU97,@
M/2`D=F%R+3YG971686QU97,H*3L*("`@("`@("`D=F%L=64@/2`D=F%R+3YG
M971686QU92@D=F%R<RD["B`@("`@("`@:68@*&-O=6YT*"1V86QU97,I(#T]
M(#`I('L*("`@("`@("`@("`@<F5T=7)N(%\H(DYO('9A;'5E<R(I.PH@("`@
M("`@('T@96QS96EF("AI<W-E="@D=F%L=65S6R1V86QU95TI("8F("1V86QU
M92`A/2`G)RD@>PH@("`@("`@("`@("!R971U<FX@0&AT;6QS<&5C:6%L8VAA
M<G,H)'9A;'5E<ULD=F%L=65=+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S
M970I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R
M1&ES<&QA>5]R861I;R@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@
M("`@("`@)'9A;'5E<R`]("1V87(M/F=E=%9A;'5E<R@I.PH@("`@("`@(&EF
M("AC;W5N="@D=F%L=65S*2`]/2`P*2!["B`@("`@("`@("`@(')E='5R;B!?
M*").;R!V86QU97,B*3L*("`@("`@("!](&5L<V5I9B`H:7-S970H)'9A;'5E
M<ULD=F%R+3YG971686QU92@D=F%R<RE=*2D@>PH@("`@("`@("`@("!R971U
M<FX@0&AT;6QS<&5C:6%L8VAA<G,H)'9A;'5E<ULD=F%R+3YG971686QU92@D
M=F%R<RE=+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@
M('T*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R1&ES<&QA>5]M=6QT
M:65N=6TH)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@("1V
M86QU97,@/2`D=F%R+3YG971686QU97,H*3L*("`@("`@("`D;VX@/2`D=F%R
M+3YG971686QU92@D=F%R<RD["B`@("`@("`@:68@*"%C;W5N="@D=F%L=65S
M*2!\?"`A8V]U;G0H)&]N*2D@>PH@("`@("`@("`@("!R971U<FX@7R@B3F\@
M=F%L=65S(BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&1I<W!L
M87D@/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W)E86-H("@D=F%L=65S(&%S
M("1V86QU92`]/B`D;F%M92D@>PH@("`@("`@("`@("`@("`@:68@*&EN7V%R
M<F%Y*"1V86QU92P@)&]N*2D@>PH@("`@("`@("`@("`@("`@("`@("1D:7-P
M;&%Y6UT@/2`D;F%M93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!R971U<FX@0&AT;6QS<&5C:6%L8VAA<G,H:6UP;&]D
M92@G+"`G+"`D9&ES<&QA>2DL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E
M="D["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687)$
M:7-P;&%Y7W-E="@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@
M("`@)'9A;'5E<R`]("1V87(M/F=E=%9A;'5E<R@I.PH@("`@("`@("1O;B`]
M("1V87(M/F=E=%9A;'5E*"1V87)S*3L*("`@("`@("!I9B`H(6-O=6YT*"1V
M86QU97,I('Q\("%C;W5N="@D;VXI*2!["B`@("`@("`@("`@(')E='5R;B!?
M*").;R!V86QU97,B*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M9&ES<&QA>2`](&%R<F%Y*"D["B`@("`@("`@("`@(&9O<F5A8V@@*"1V86QU
M97,@87,@)'9A;'5E(#T^("1N86UE*2!["B`@("`@("`@("`@("`@("!I9B`H
M:6Y?87)R87DH)'9A;'5E+"`D;VXI*2!["B`@("`@("`@("`@("`@("`@("`@
M)&1I<W!L87E;72`]("1N86UE.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@("`@(')E='5R;B!`:'1M;'-P96-I86QC:&%R<RAI
M;7!L;V1E*"<L("<L("1D:7-P;&%Y*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C
M:&%R<V5T*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E
M<E9A<D1I<W!L87E?:6UA9V4H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@
M>PH@("`@("`@("1I;6=?<&%R86US(#T@)'9A<BT^9V5T5F%L=64H)'9A<G,I
M.PH@("`@("`@("1I;6=?=7)L(#T@2&]R9&4Z.G5R;"@D1TQ/0D%,4ULG<F5G
M:7-T<GDG72T^9V5T*"=W96)R;V]T)RP@)VAO<F1E)RD@+B`G+W-E<G9I8V5S
M+VEM86=E<R]V:65W+G!H<"<I.PH@("`@("`@("1I;6=?=7)L(#T@571I;#HZ
M861D4&%R86UE=&5R*"1I;6=?=7)L+"`D:6UG7W!A<F%M<RD["@H@("`@("`@
M(')E='5R;B!(;W)D93HZ:6UG*"1I;6=?=7)L+"!I<W-E="@D:6UG7W!A<F%M
M<ULG9B==*2`_("1I;6=?<&%R86US6R=F)UT@.B`G)RP@)R<L("<G*3L*("`@
M('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R1&ES<&QA>5]C96QL<&AO;F4H
M)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@(&=L;V)A;"`D
M<F5G:7-T<GD["@H@("`@("`@("1N=6UB97(@/2`D=F%R+3YG971686QU92@D
M=F%R<RD["B`@("`@("`@)&AT;6P@/2!`:'1M;'-P96-I86QC:&%R<R@D;G5M
M8F5R+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I.PH*("`@("`@("!I
M9B`H)&YU;6)E<B`F)B`D<F5G:7-T<GDM/FAA<TUE=&AO9"@G<VUS+V-O;7!O
M<V4G*2D@>PH@("`@("`@("`@("`D=7)L(#T@)')E9VES=')Y+3YL:6YK*"=S
M;7,O8V]M<&]S92<L(&%R<F%Y*"=T;R<@/3X@)&YU;6)E<BDI.PH@("`@("`@
M("`@("`D:'1M;"`N/2`G("<@+B!(;W)D93HZ;&EN:R@D=7)L+"!?*")396YD
M(%--4R(I*2`N($AO<F1E.CII;6<H)VUO8FEL92YP;F<G+"!?*")396YD(%--
M4R(I+"`G)RP@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G*2D@+B`G
M/"]A/B<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&AT;6P["B`@("!]
M"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<D1I<W!L87E?861D<F5S<R@F)&9O
M<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I
M<W1R>3L*"B`@("`@("`@)&%D9')E<W,@/2`D=F%R+3YG971686QU92@D=F%R
M<RD["B`@("`@("`@)&%U<U]S=&%T95]R96=E>"`]("<H/SI!0U1\3E-7?$Y4
M?%%,1'Q307Q405-\5DE#?%=!*2<["@H@("`@("`@(&EF("AP<F5G7VUA=&-H
M*"<O*"@_.D%;0DQ=?$);04)$2$Q.4E-473]\0UM!0D9(34]25%9777Q$6T%$
M14=(3$Y465U\15M#2$Y873]\1EM+65U\1UM,55E=/WQ(6T%$1U!24U5877Q)
M6T=-4%9=?$I%?$M;051765U\3%M!1$5,3E-573]\35M%2TQ=/WQ.6T5'3E!2
M5UT_?$];3%A=?%!;045(3$]277Q26T=(35U\4UM!14=+3$U.3U!24U1765T_
M?%1;041&3E%24U==?%5"?%=;04-$1DY24U9=/WQ93WQ:12E<9"@_.EQD?%M!
M+5I=*3\@7&1;02U:77LR?2DO)RP@)&%D9')E<W,L("1P;W-T8V]D92DI('L*
M("`@("`@("`@("`@+RH@54L@<&]S=&-O9&4@9&5T96-T960N("HO"B`@("`@
M("`@("`@("\J($UU;'1I;6%P+F-O+G5K(&=E;F5R871E9"!M87`@*B\*("`@
M("`@("`@("`@)&UA<'5R;"`]("=H='1P.B\O=W=W+FUU;'1I;6%P+F-O;2]M
M87`O8G)O=W-E+F-G:3]P8STG("X@=7)L96YC;V1E*"1P;W-T8V]D95LQ72D[
M"B`@("`@("`@("`@("1D97-C(#T@7R@B375L=&EM87`@54L@;6%P(BD["B`@
M("`@("`@("`@("1I8V]N(#T@)VUA<"YP;F<G.PH@("`@("`@('T@96QS96EF
M("AP<F5G7VUA=&-H*"<O7&(G("X@)&%U<U]S=&%T95]R96=E>"`N("=<8B\G
M+"`D861D<F5S<RDI('L*("`@("`@("`@("`@+RH@075S=')A;&EA;B!S=&%T
M92!D971E8W1E9"X@*B\*("`@("`@("`@("`@+RH@5VAE<F5I<RYC;VTN874@
M9V5N97)A=&5D(&UA<"`J+PH@("`@("`@("`@("`D;6%P=7)L(#T@)VAT='`Z
M+R]W=W<N=VAE<F5I<RYC;VTN874O=VAE<F5I<R]M87!P:6YG+V=E;V-O9&5!
M9&1R97-S+F1O/R<["B`@("`@("`@("`@("1D97-C(#T@7R@B5VAE<F5I<R!!
M=7-T<F%L:6$@;6%P(BD["B`@("`@("`@("`@("1I8V]N(#T@)VUA<"YP;F<G
M.PH@("`@("`@("`@("`O*B!3<&QI="!O=70@=&AE(&%D9')E<W,L(&QI;F4M
M8GDM;&EN92X@*B\*("`@("`@("`@("`@)&%D9')E<W-,:6YE<R`](&5X<&QO
M9&4H(EQN(BP@)&%D9')E<W,I.PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@
M)&D@/"!C;W5N="@D861D<F5S<TQI;F5S*3L@)&DK*RD@>PH@("`@("`@("`@
M("`@("`@+RH@4V5E(&EF(&ET)W,@=&AE('-T<F5E="!N=6UB97(@)B!N86UE
M+B`J+PH@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R\H7&0K7',J
M7"]<<RHI/RA<9"M\7&0K6V$M>D$M6ETI7',K*%MA+7I!+5H@72HI+R<L("1A
M9&1R97-S3&EN97-;)&E=+"`D;&EN95!A<G1S*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1M87!U<FP@+CT@)R9S=')E971.=6UB97(])R`N('5R;&5N8V]D
M92@D;&EN95!A<G1S6S)=*2`N("<F<W1R965T3F%M93TG("X@=7)L96YC;V1E
M*"1L:6YE4&%R='-;,UTI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@+RH@3&]O:R!F;W(@(E-U8G5R8BP@4W1A=&4B+B`J+PH@("`@("`@
M("`@("`@("`@:68@*'!R96=?;6%T8V@H)R\H6V$M>D$M6B!=*BDL/UQS*R<@
M+B`D875S7W-T871E7W)E9V5X("X@)R\G+"`D861D<F5S<TQI;F5S6R1I72P@
M)&QI;F5087)T<RDI('L*("`@("`@("`@("`@("`@("`@("`D;6%P=7)L("X]
M("<F<W5B=7)B/2<@+B!U<FQE;F-O9&4H)&QI;F5087)T<ULQ72D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`O*B!,;V]K(&9O<B`B4W1A
M=&4@/#0@9&EG:70@<&]S=&-O9&4^(BX@*B\*("`@("`@("`@("`@("`@(&EF
M("AP<F5G7VUA=&-H*"<O*"<@+B`D875S7W-T871E7W)E9V5X("X@)RE<<RLH
M7&1[-'TI+R<L("1A9&1R97-S3&EN97-;)&E=+"`D;&EN95!A<G1S*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1M87!U<FP@+CT@)R9S=&%T93TG("X@=7)L
M96YC;V1E*"1L:6YE4&%R='-;,5TI.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H)R\H+BHI
M7&XH+BHI7',J+%QS*BA<=RLI7"X_7',K*%QD*WQ;82UZ02U:75QD6V$M>D$M
M6EU<<S]<9%MA+7I!+5I=7&0I+R<L("1A9&1R97-S+"`D861D<F5S<U!A<G1S
M*2D@>PH@("`@("`@("`@("`O*B!!;65R:6-A;B]#86YA9&EA;B!A9&1R97-S
M('-T>6QE+B`J+PH@("`@("`@("`@("`O*B!-87!Q=65S="!G96YE<F%T960@
M;6%P("HO"B`@("`@("`@("`@("1M87!U<FP@/2`G:'1T<#HO+W=W=RYM87!Q
M=65S="YC;VTO;6%P<R]M87`N861P/W-I>F4]8FEG)GIO;VT]-R<["B`@("`@
M("`@("`@("1D97-C(#T@7R@B36%P475E<W0@;6%P(BD["B`@("`@("`@("`@
M("1I8V]N(#T@)VUA<"YP;F<G.PH@("`@("`@("`@("`D8V]U;G1R>2`](&YU
M;&P["B`@("`@("`@("`@(&EF("@A96UP='DH)&%D9')E<W-087)T<ULT72D@
M)B8@<')E9U]M871C:"@G?%MA+7I!+5I=7&1;82UZ02U:75QS/UQD6V$M>D$M
M6EU<9'PG+"`D861D<F5S<U!A<G1S6S1=*2D@>PH@("`@("`@("`@("`@("`@
M)&-O=6YT<GD@/2`G0T$G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("@A96UP='DH)&%D9')E<W-087)T<ULQ72DI('L*("`@("`@("`@("`@("`@
M("1M87!U<FP@+CT@)R9A9&1R97-S/2<@+B!U<FQE;F-O9&4H)&%D9')E<W-0
M87)T<ULQ72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%E;7!T
M>2@D861D<F5S<U!A<G1S6S)=*2D@>PH@("`@("`@("`@("`@("`@)&UA<'5R
M;"`N/2`G)F-I='D])R`N('5R;&5N8V]D92@D861D<F5S<U!A<G1S6S)=*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(65M<'1Y*"1A9&1R97-S
M4&%R='-;,UTI*2!["B`@("`@("`@("`@("`@("`D;6%P=7)L("X]("<F<W1A
M=&4])R`N('5R;&5N8V]D92@D861D<F5S<U!A<G1S6S-=*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!I9B`H(65M<'1Y*"1A9&1R97-S4&%R='-;-%TI
M*2!["B`@("`@("`@("`@("`@("!I9B`H)&-O=6YT<GD@/3T@)T-!)RD@>PH@
M("`@("`@("`@("`@("`@("`@("1M87!U<FP@+CT@)R9C;W5N=')Y/4-!)SL*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1M87!U<FP@+CT@
M)R9Z:7!C;V1E/2<@+B!U<FQE;F-O9&4H)&%D9')E<W-087)T<ULT72D["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("\J(%EA:&]O(2!G96YE<F%T960@
M;6%P+B`J+PH@("`@("`@("`@("`D;6%P=7)L,B`]("=H='1P.B\O=7,N<F0N
M>6%H;V\N8V]M+VUA<',O:&]M92]S=6)M:71?82\J+6AT='`Z+R]M87!S+GEA
M:&]O+F-O;2]M87!S/W-R8VAT>7!E/6$F9V5T;6%P/4=E="M-87`F)SL*("`@
M("`@("`@("`@)&1E<V,R(#T@7R@B66%H;V\A(&UA<"(I.PH@("`@("`@("`@
M("`D:6-O;C(@/2`G;6%P+G!N9R<["B`@("`@("`@("`@(&EF("@A96UP='DH
M)&%D9')E<W-087)T<ULQ72DI('L*("`@("`@("`@("`@("`@("1M87!U<FPR
M("X]("<F861D<CTG("X@=7)L96YC;V1E*"1A9&1R97-S4&%R='-;,5TI.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("\J($=I=F4@<')E8V5D96YC92!T
M;R!Z:7!C;V1E(&]V97(@8VET>2]S=&%T92`J+PH@("`@("`@("`@("!I9B`H
M96UP='DH)&%D9')E<W-087)T<ULT72D@)B8@(65M<'1Y*"1A9&1R97-S4&%R
M='-;,ETI("8F("%E;7!T>2@D861D<F5S<U!A<G1S6S-=*2D@>PH@("`@("`@
M("`@("`@("`@)&UA<'5R;#(@+CT@)R9C<WH])R`N('5R;&5N8V]D92@D861D
M<F5S<U!A<G1S6S)=("X@)R`G("X@)&%D9')E<W-087)T<ULS72D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@:68@*"%E;7!T>2@D861D<F5S<U!A<G1S
M6S1=*2D@>PH@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)WPH6V$M
M>D$M6EU<9%MA+7I!+5I=*5QS/RA<9%MA+7I!+5I=7&0I?"<L("1A9&1R97-S
M4&%R='-;-%TL("1P8U!A<G1S*2D@>PH@("`@("`@("`@("`@("`@("`@("1M
M87!U<FPR("X]("<F8V]U;G1R>3UC82<["B`@("`@("`@("`@("`@("`@("`@
M+RH@;6%K92!S=7)E('1H92!P;W-T86PM8V]D92!H87,@82!S<&%C92`J+PH@
M("`@("`@("`@("`@("`@("`@("1A9&1R97-S4&%R='-;-%T@/2`D<&-087)T
M<ULQ72`N("<@)R`N("1P8U!A<G1S6S)=.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@)&UA<'5R;#(@+CT@)R9C<WH])R`N('5R;&5N8V]D
M92@D861D<F5S<U!A<G1S6S1=*3L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@+RH@1V]O9VQE(&=E;F5R871E9"!M87`N("HO"B`@("`@("`@("`@("1M
M87!U<FPS(#T@)VAT='`Z+R]M87!S+F=O;V=L92YC;VTO;6%P<S]Q/2<@+B!U
M<FQE;F-O9&4H)&%D9')E<W-087)T<ULP72D@+B`G)FAL/65N)SL*("`@("`@
M("`@("`@)&1E<V,S(#T@7R@B1V]O9VQE($UA<',B*3L*("`@("`@("`@("`@
M)&EC;VXS(#T@)VUA<"YP;F<G.PH*("`@("`@("!](&5L<V5I9B`H<')E9U]M
M871C:"@G+R@N*C\I7'(_7&XH6T$M6EU[,2PS?2DM*%QD>S5]*5QS*R@N*BDO
M:2<L("1A9&1R97-S+"`D861D<F5S<U!A<G1S*2D@>PH@("`@("`@("`@("`O
M*B!%=7)O<&5A;B!A9&1R97-S('-T>6QE+B`J+PH@("`@("`@("`@("!I;F-L
M=61E("=(;W)D92].3%,O8V%R<VEG;G,N<&AP)SL*("`@("`@("`@("`@)&-O
M=6YT<GD@/2!A<G)A>5]S96%R8V@H4W1R:6YG.CIU<'!E<B@D861D<F5S<U!A
M<G1S6S)=*2P@)&-A<G-I9VYS*3L*"B`@("`@("`@("`@("\J($UA<#(T(&=E
M;F5R871E9"!M87`N("HO"B`@("`@("`@("`@(&EF("AI;E]A<G)A>2@D8V]U
M;G1R>2P@87)R87DH)V%L)RP@)V%D)RP@)V%M)RP@)V%Z)RP@)V)E)RP@)V)A
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M8F<G+"`G9&4G+"`G9&LG+"`G964G+"`G9F\G+"`G9FDG+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=F<B<L("=G92<L("=G
M<B<L("=G8B<L("=I92<L("=I<R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)VET)RP@)VAR)RP@)VQV)RP@)VQI)RP@)VQT
M)RP@)VQU)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G;70G+"`G;6LG+"`G;60G+"`G;6,G+"`G;FPG+"`G;F\G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P;"<L("=P
M="<L("=R;R<L("=R=2<L("=S92<L("=C:"<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)V-S)RP@)W-K)RP@)W-I)RP@)V5S
M)RP@)V-Z)RP@)W1R)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G=6$G+"`G:'4G+"`G8GDG+"`G8WDG+"`G870G*2DI('L*
M("`@("`@("`@("`@("`@(&EF("AI;E]A<G)A>2@D8V]U;G1R>2P@87)R87DH
M)V%T)RP@)V)E)RP@)V-H)RP@)V1E)RP@)V1K)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V5S)RP@)V9I)RP@)V9R
M)RP@)VET)RP@)VYL)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)VYO)RP@)W-E)RDI*2!["B`@("`@("`@("`@("`@
M("`@("`@)&UI<G)O<B`]("1C;W5N=')Y.PH@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`D;6ER<F]R(#T@)W5K)SL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1M87!U<FP@/2`G:'1T
M<#HO+W=W=RXG("X@)&UI<G)O<B`N("<N;6%P,C0N8V]M+W-O=7)C92]A9&1R
M97-S+W8R+C`N,"]C;G1?;F%V7VUA<&QE="YP:'`_8VED/79A;&ED871E861D
M<B9C;W5N=')Y/2<@+B`D8V]U;G1R>3L*("`@("`@("`@("`@("`@("1D97-C
M(#T@7R@B36%P,C0@;6%P(BD["B`@("`@("`@("`@("`@("`D:6-O;B`]("=M
M87!?974N<&YG)SL*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&%D9')E
M<W-087)T<ULQ72DI('L*("`@("`@("`@("`@("`@("`@("`D;6%P=7)L("X]
M("<F<W1R965T/2<@+B!U<FQE;F-O9&4H)&%D9')E<W-087)T<ULQ72D["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1A
M9&1R97-S4&%R='-;,UTI*2!["B`@("`@("`@("`@("`@("`@("`@)&UA<'5R
M;"`N/2`G)GII<#TG("X@=7)L96YC;V1E*"1A9&1R97-S4&%R='-;,UTI.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D
M861D<F5S<U!A<G1S6S1=*2D@>PH@("`@("`@("`@("`@("`@("`@("1M87!U
M<FP@+CT@)R9C:71Y/2<@+B!U<FQE;F-O9&4H)&%D9')E<W-087)T<ULT72D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("\J($UA<'%U97-T(&=E;F5R871E9"!M87`N("HO"B`@("`@("`@("`@("1M
M87!U<FPR(#T@)VAT='`Z+R]W=W<N;6%P<75E<W0N8V]M+VUA<',O;6%P+F%D
M<#]C;W5N=')Y/2<@+B!3=')I;F<Z.G5P<&5R*"1C;W5N=')Y*3L*("`@("`@
M("`@("`@)&1E<V,R(#T@7R@B36%P475E<W0@;6%P(BD["B`@("`@("`@("`@
M("1I8V]N,B`]("=M87!?974N<&YG)SL*("`@("`@("`@("`@:68@*"%E;7!T
M>2@D861D<F5S<U!A<G1S6S%=*2D@>PH@("`@("`@("`@("`@("`@)&UA<'5R
M;#(@+CT@)R9A9&1R97-S/2<@+B!U<FQE;F-O9&4H)&%D9')E<W-087)T<ULQ
M72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%E;7!T>2@D861D
M<F5S<U!A<G1S6S-=*2D@>PH@("`@("`@("`@("`@("`@)&UA<'5R;#(@+CT@
M)R9Z:7!C;V1E/2<@+B!U<FQE;F-O9&4H)&%D9')E<W-087)T<ULS72D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%E;7!T>2@D861D<F5S<U!A
M<G1S6S1=*2D@>PH@("`@("`@("`@("`@("`@)&UA<'5R;#(@+CT@)R9C:71Y
M/2<@+B!U<FQE;F-O9&4H)&%D9')E<W-087)T<ULT72D["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@("1H=&UL(#T@;FPR8G(H0&AT;6QS<&5C
M:6%L8VAA<G,H)&%D9')E<W,L($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E
M="DI.PH@("`@("`@(&EF("@A96UP='DH)&UA<'5R;"DI('L*("`@("`@("`@
M("`@)&AT;6P@+CT@)R9N8G-P.R9N8G-P.R<@+B!(;W)D93HZ;&EN:RA(;W)D
M93HZ97AT97)N86Q5<FPH)&UA<'5R;"DL("1D97-C+"!N=6QL+"`G7V)L86YK
M)RD@+B!(;W)D93HZ:6UG*"1I8V]N+"`D9&5S8RP@)V%L:6=N/2)M:61D;&4B
M)RP@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G*2D@+B`G/"]A/B<[
M"B`@("`@("`@?0H@("`@("`@(&EF("@A96UP='DH)&UA<'5R;#(I*2!["B`@
M("`@("`@("`@("1H=&UL("X]("<F;F)S<#LG("X@2&]R9&4Z.FQI;FLH2&]R
M9&4Z.F5X=&5R;F%L57)L*"1M87!U<FPR*2P@)&1E<V,R+"!N=6QL+"`G7V)L
M86YK)RD@+B!(;W)D93HZ:6UG*"1I8V]N,BP@)&1E<V,R+"`G86QI9VX](FUI
M9&1L92(G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`N("<\
M+V$^)SL*("`@("`@("!]"B`@("`@("`@:68@*"%E;7!T>2@D;6%P=7)L,RDI
M('L*("`@("`@("`@("`@)&AT;6P@+CT@)R9N8G-P.R<@+B!(;W)D93HZ;&EN
M:RA(;W)D93HZ97AT97)N86Q5<FPH)&UA<'5R;#,I+"`D9&5S8S,L(&YU;&PL
M("=?8FQA;FLG*2`N($AO<F1E.CII;6<H)&EC;VXS+"`D9&5S8S,L("=A;&EG
M;CTB;6ED9&QE(B<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RDI
M("X@)SPO83XG.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1H=&UL.PH@
M("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687)$:7-P;&%Y7V1A=&4H)B1F
M;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@(')E='5R;B!H=&UL
M<W!E8VEA;&-H87)S*"1V87(M/G1Y<&4M/F=E=$9O<FUA='1E9%1I;64H)'9A
M<BT^9V5T5F%L=64H)'9A<G,I*2D["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E
M;F1E<E9A<D1I<W!L87E?:&]U<FUI;G5T97-E8V]N9"@F)&9O<FTL("8D=F%R
M+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'1I;64@/2`D=F%R+3YT>7!E+3YG
M9714:6UE4&%R=',H)'9A<BT^9V5T5F%L=64H)'9A<G,I*3L*("`@("`@("!I
M9B`H(21V87(M/G1Y<&4M/E]S:&]W7W-E8V]N9',I('L*("`@("`@("`@("`@
M<F5T=7)N("AI;G0I)'1I;65;)VAO=7(G72`N("<Z)R`N('-P<FEN=&8H)R4P
M,F0G+"`H:6YT*21T:6UE6R=M:6YU=&4G72D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<F5T=7)N("AI;G0I)'1I;65;)VAO=7(G72`N("<Z)R`N
M('-P<FEN=&8H)R4P,F0G+"`H:6YT*21T:6UE6R=M:6YU=&4G72D@+B`G.B<@
M+B!S<')I;G1F*"<E,#)D)RP@*&EN="DD=&EM95LG<V5C;VYD)UTI.PH@("`@
M("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R1&ES<&QA>5]M
M;VYT:'EE87(H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@
M(')E='5R;B`H:6YT*21V87)S+3YG970H)'9A<BT^9V5T5F%R3F%M92@I("X@
M)UMM;VYT:%TG*2`N("<L("<@+B`H:6YT*21V87)S+3YG970H)'9A<BT^9V5T
M5F%R3F%M92@I("X@)UMY96%R72<I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R
M96YD97)687)$:7-P;&%Y7VUO;G1H9&%Y>65A<B@F)&9O<FTL("8D=F%R+"`F
M)'9A<G,I"B`@("!["B`@("`@("`@)&1A=&4@/2`D=F%R+3YG971686QU92@D
M=F%R<RD["B`@("`@("`@:68@*"AI<U]A<G)A>2@D9&%T92D@)B8@(65M<'1Y
M*"1D871E6R=Y96%R)UTI("8F"B`@("`@("`@("`@("`A96UP='DH)&1A=&5;
M)VUO;G1H)UTI("8F("%E;7!T>2@D9&%T95LG9&%Y)UTI*0H@("`@("`@("`@
M("!\?"`H(6ES7V%R<F%Y*"1D871E*2`F)B`A96UP='DH)&1A=&4I*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'9A<BT^='EP92T^9F]R;6%T1&%T92@D9&%T
M92D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`G)SL*("`@('T*"B`@("!F
M=6YC=&EO;B!?<F5N9&5R5F%R1&ES<&QA>5]I;G9A;&ED*"8D9F]R;2P@)B1V
M87(L("8D=F%R<RD*("`@('L*("`@("`@("!R971U<FX@)SQS<&%N(&-L87-S
M/2)F;W)M+65R<F]R(CXG("X@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^='EP
M92T^;65S<V%G92P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2`N("<\
M+W-P86X^)SL*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R1&ES<&QA
M>5]L:6YK*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("`D
M=F%L=65S(#T@)'9A<BT^='EP92T^=F%L=65S.PH@("`@("`@(&EF("@A:7-S
M970H)'9A;'5E<ULP72DI('L*("`@("`@("`@("`@)'9A;'5E<R`](&%R<F%Y
M*"1V86QU97,I.PH@("`@("`@('T*"B`@("`@("`@)&-O=6YT(#T@8V]U;G0H
M)'9A;'5E<RD["B`@("`@("`@)&AT;6P@/2`G)SL*("`@("`@("!F;W(@*"1I
M(#T@,#L@)&D@/"`D8V]U;G0[("1I*RLI('L*("`@("`@("`@("`@:68@*&5M
M<'1Y*"1V86QU97-;)&E=6R=U<FPG72D@?'P@96UP='DH)'9A;'5E<ULD:5U;
M)W1E>'0G72DI('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("@A:7-S970H)'9A;'5E<ULD:5U;)W1A
M<F=E="==*2D@>PH@("`@("`@("`@("`@("`@)'9A;'5E<ULD:5U;)W1A<F=E
M="==(#T@)R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%I<W-E
M="@D=F%L=65S6R1I75LG;VYC;&EC:R==*2D@>PH@("`@("`@("`@("`@("`@
M)'9A;'5E<ULD:5U;)V]N8VQI8VLG72`]("<G.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&EF("@A:7-S970H)'9A;'5E<ULD:5U;)W1I=&QE)UTI*2![
M"B`@("`@("`@("`@("`@("`D=F%L=65S6R1I75LG=&ET;&4G72`]("<G.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A:7-S970H)'9A;'5E<ULD
M:5U;)V%C8V5S<VME>2==*2D@>PH@("`@("`@("`@("`@("`@)'9A;'5E<ULD
M:5U;)V%C8V5S<VME>2==(#T@)R<["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*"1I(#X@,"D@>PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@)R!\
M("<["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&AT;6P@+CT@2&]R9&4Z
M.FQI;FLH)'9A;'5E<ULD:5U;)W5R;"==+"`D=F%L=65S6R1I75LG=&5X="==
M+"`G=VED9V5T)RP@)'9A;'5E<ULD:5U;)W1A<F=E="==+"`D=F%L=65S6R1I
M75LG;VYC;&EC:R==+"`D=F%L=65S6R1I75LG=&ET;&4G72P@)'9A;'5E<ULD
M:5U;)V%C8V5S<VME>2==*2`N($!H=&UL<W!E8VEA;&-H87)S*"1V86QU97-;
M)&E=6R=T97AT)UTL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D@+B`G
M/"]A/B<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&AT;6P["B`@("!]
M"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<D1I<W!L87E?9&)L;V]K=7`H)B1F
M;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^7W)E;F1E<E9A<D1I<W!L87E?96YU;2@D9F]R;2P@)'9A<BP@)'9A<G,I
M.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687)$:7-P;&%Y7V9I9VQE
M="@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@<W1A=&EC
M("1F:6=L970["@H@("`@("`@(&EF("@A:7-S970H)&9I9VQE="DI('L*("`@
M("`@("`@("`@<F5Q=6ER95]O;F-E("=497AT+T9I9VQE="YP:'`G.PH@("`@
M("`@("`@("`D9FEG;&5T(#T@)FYE=R!497AT7T9I9VQE="@I.PH@("`@("`@
M('T*"B`@("`@("`@)')E<W5L="`]("1F:6=L970M/FQO861&;VYT*"1V87(M
M/G1Y<&4M/F=E=$9O;G0H*2D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L="T^
M9V5T365S<V%G92@I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("<\<')E
M/B<@+B`D9FEG;&5T+3YL:6YE16-H;R@D=F%R+3YT>7!E+3YG971497AT*"DI
M("X@)SPO<')E/B<["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN
M<'5T7W-E;&5C=$9I;&5S*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*
M("`@("`@("`O*B!.965D960@9F]R(&=O;&QE;2!J<R!C86QL<R`J+PH@("`@
M("`@("1V87)N86UE(#T@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%R
M3F%M92@I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@
M("1H=&UL(#T@<W!R:6YT9B@G/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB
M)7,B(&ED/2(E<R(@=F%L=64](B5S(B`O/B<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("=S96QE8W1L:7-T7W-E;&5C=&ED)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@)W-E;&5C=&QI<W1?<V5L96-T:60G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`D=F%R+3YT>7!E+3Y?<V5L96-T:60I("X*("`@("`@("`@
M("`@<W!R:6YT9B@G/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB)7,B(&ED
M/2(E<R(@+SXG+"`G86-T:6]N240G+"`G86-T:6]N240G*2`N"@H@("`@("`@
M("`@("`O*B!&;W)M(&9I96QD+B`J+PH@("`@("`@("`@("!S<')I;G1F*"<\
M:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2(E<R(@:60](B5S(B!V86QU93TB
M)7,B("\^)RP*("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@
M("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`D
M=F%R+3YT>7!E+3Y?<V5L96-T:60I.PH*("`@("`@("`O*B!/<&5N('=I;F1O
M=R!L:6YK+B`J+PH@("`@("`@("1P87)A;2`](&%R<F%Y*"1V87(M/G1Y<&4M
M/E]L:6YK7W1E>'0L"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<BT^='EP
M92T^7VQI;FM?<W1Y;&4L"B`@("`@("`@("`@("`@("`@("`@("`@)&9O<FTM
M/F=E=$YA;64H*2P*("`@("`@("`@("`@("`@("`@("`@("`D=F%R+3YT>7!E
M+3Y?:6-O;BP*("`@("`@("`@("`@("`@("`@("`@("`D=F%R+3YT>7!E+3Y?
M<V5L96-T:60I.PH@("`@("`@("1H=&UL("X]("1'3$]"04Q36R=R96=I<W1R
M>2==+3YC86QL*"=F:6QE<R]S96QE8W1L:7-T3&EN:R<L("1P87)A;2D@+B`B
M/&)R("\^7&XB.PH*("`@("`@("!I9B`H)'9A<BT^='EP92T^7W-E;&5C=&ED
M*2!["B`@("`@("`@("`@("1P87)A;2`](&%R<F%Y*"1V87(M/G1Y<&4M/E]S
M96QE8W1I9"D["B`@("`@("`@("`@("1F:6QE<R`]("1'3$]"04Q36R=R96=I
M<W1R>2==+3YC86QL*"=F:6QE<R]S96QE8W1L:7-T4F5S=6QT<R<L("1P87)A
M;2D["B`@("`@("`@("`@(&EF("@D9FEL97,I('L*("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1F:6QE<R!A<R`D:60@/3X@)&9I;&4I('L*("`@("`@("`@
M("`@("`@("`@("`D9&ER(#T@:V5Y*"1F:6QE*3L*("`@("`@("`@("`@("`@
M("`@("`D9FEL96YA;64@/2!C=7)R96YT*"1F:6QE*3L*("`@("`@("`@("`@
M("`@("`@("`D:'1M;"`N/2`H)&ED("L@,2D@+B`G+B`G.PH@("`@("`@("`@
M("`@("`@("`@(&EF("@A96UP='DH)&1I<BD@)B8@*"1D:7(@(3T@)RXG*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D9FEL96YA;64@/2`D9&ER("X@
M)R\G("X@)&9I;&5N86UE.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`D:'1M;"`N/2!`:'1M;'-P96-I86QC:&%R<R@D9FEL
M96YA;64L($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D@+B`B/&)R("\^
M7&XB.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&AT;6P["B`@("!]"@H@("`@9G5N8W1I;VX@
M7W-E;&5C=$]P=&EO;G,H)B1V86QU97,L("1S96QE8W1E9%9A;'5E(#T@9F%L
M<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:'1M;&-H87)S(#T@
M9F%L<V4I"B`@("!["B`@("`@("`@)')E<W5L="`]("<G.PH@("`@("`@("1S
M96P@/2!F86QS93L*("`@("`@("!F;W)E86-H("@D=F%L=65S(&%S("1V86QU
M92`]/B`D9&ES<&QA>2D@>PH@("`@("`@("`@("!I9B`H(6ES7VYU;&PH)'-E
M;&5C=&5D5F%L=64I("8F("$D<V5L("8F"B`@("`@("`@("`@("`@("`D=F%L
M=64@/3T@)'-E;&5C=&5D5F%L=64@)B8*("`@("`@("`@("`@("`@('-T<FQE
M;B@D=F%L=64I(#T]('-T<FQE;B@D<V5L96-T961686QU92DI('L*("`@("`@
M("`@("`@("`@("1S96QE8W1E9"`]("<@<V5L96-T960](G-E;&5C=&5D(B<[
M"B`@("`@("`@("`@("`@("`D<V5L(#T@=')U93L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1S96QE8W1E9"`]("<G.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1R97-U;'0@+CT@)R`\;W!T:6]N('9A;'5E
M/2(G.PH@("`@("`@("`@("`D<F5S=6QT("X]("1H=&UL8VAA<G,*("`@("`@
M("`@("`@("`@(#\@)'9A;'5E"B`@("`@("`@("`@("`@("`Z($!H=&UL<W!E
M8VEA;&-H87)S*"1V86QU92P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T
M*3L*("`@("`@("`@("`@)')E<W5L="`N/2`G(B<@+B`D<V5L96-T960@+B`G
M/B<["B`@("`@("`@("`@("1R97-U;'0@+CT@)&AT;6QC:&%R<PH@("`@("`@
M("`@("`@("`@/R`D9&ES<&QA>0H@("`@("`@("`@("`@("`@.B!`:'1M;'-P
M96-I86QC:&%R<R@D9&ES<&QA>2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R
M<V5T*3L*("`@("`@("`@("`@)')E<W5L="`N/2`B/"]O<'1I;VX^7&XB.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@
M9G5N8W1I;VX@7VUU;'1I4V5L96-T3W!T:6]N<R@F)'9A;'5E<RP@)'-E;&5C
M=&5D5F%L=65S*0H@("`@>PH@("`@("`@("1R97-U;'0@/2`G)SL*("`@("`@
M("`D<V5L(#T@9F%L<V4["B`@("`@("`@9F]R96%C:"`H)'9A;'5E<R!A<R`D
M=F%L=64@/3X@)&1I<W!L87DI('L*("`@("`@("`@("`@:68@*$!I;E]A<G)A
M>2@D=F%L=64L("1S96QE8W1E9%9A;'5E<RDI('L*("`@("`@("`@("`@("`@
M("1S96QE8W1E9"`]("<@<V5L96-T960](G-E;&5C=&5D(B<["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<V5L96-T960@/2`G)SL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D<F5S=6QT("X]("(@/&]P=&EO
M;B!V86QU93U<(B(@+B!`:'1M;'-P96-I86QC:&%R<R@D=F%L=64L($5.5%]1
M54]415,L("1T:&ES+3Y?8VAA<G-E="D@+B`B7"(D<V5L96-T960^(B`N($!H
M=&UL<W!E8VEA;&-H87)S*"1D:7-P;&%Y+"!%3E1?455/5$53+"`D=&AI<RT^
M7V-H87)S970I("X@(CPO;W!T:6]N/EQN(CL*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@(&9U;F-T:6]N(%]C:&5C:T)O
M>&5S*"1N86UE+"`D=F%L=65S+"`D8VAE8VME9%9A;'5E<RP@)&%C=&EO;G,@
M/2`G)RD*("`@('L*("`@("`@("`D<F5S=6QT(#T@)R<["B`@("`@("`@:68@
M*"%I<U]A<G)A>2@D8VAE8VME9%9A;'5E<RDI('L*("`@("`@("`@("`@)&-H
M96-K961686QU97,@/2!A<G)A>2@I.PH@("`@("`@('T*("`@("`@("`D:2`]
M(#`["B`@("`@("`@9F]R96%C:"`H)'9A;'5E<R!A<R`D=F%L=64@/3X@)&1I
M<W!L87DI('L*("`@("`@("`@("`@)&-H96-K960@/2`H:6Y?87)R87DH)'9A
M;'5E+"`D8VAE8VME9%9A;'5E<RDI(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@
M.B`G)SL*("`@("`@("`@("`@)')E<W5L="`N/2!S<')I;G1F*"<\:6YP=70@
M:60](B5S)7,B('1Y<&4](F-H96-K8F]X(B!C;&%S<STB8VAE8VMB;W@B(&YA
M;64](B5S6UTB('9A;'5E/2(E<R(E<R5S("\^/&QA8F5L(&9O<CTB)7,E<R(^
M)FYB<W`[)7,\+VQA8F5L/CQB<B`O/B<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!`:'1M;'-P96-I86QC:&%R<R@D;F%M92P@14Y47U%53U1%
M4RP@)'1H:7,M/E]C:&%R<V5T*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@0&AT
M;6QS<&5C:6%L8VAA<G,H)&YA;64L($5.5%]154]415,L("1T:&ES+3Y?8VAA
M<G-E="DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!`:'1M;'-P
M96-I86QC:&%R<R@D=F%L=64L($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E
M="DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8VAE8VME9"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1A8W1I;VYS+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H
M)&YA;64L($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D:2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@($!H=&UL<W!E8VEA;&-H87)S*"1D:7-P;&%Y+"!%3E1?
M455/5$53+"`D=&AI<RT^7V-H87)S970I*3L*("`@("`@("`@("`@)&DK*SL*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@
M(&9U;F-T:6]N(%]R861I;T)U='1O;G,H)&YA;64L("1V86QU97,L("1C:&5C
M:V5D5F%L=64@/2!N=6QL+"`D86-T:6]N<R`]("<G*0H@("`@>PH@("`@("`@
M("1R97-U;'0@/2`G)SL*("`@("`@("`D:2`](#`["B`@("`@("`@9F]R96%C
M:"`H)'9A;'5E<R!A<R`D=F%L=64@/3X@)&1I<W!L87DI('L*("`@("`@("`@
M("`@)&-H96-K960@/2`H(6ES7VYU;&PH)&-H96-K961686QU92D@)B8@)'9A
M;'5E(#T]("1C:&5C:V5D5F%L=64I(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@
M.B`G)SL*("`@("`@("`@("`@)')E<W5L="`N/2!S<')I;G1F*"<\:6YP=70@
M:60](B5S)7,B('1Y<&4](G)A9&EO(B!C;&%S<STB8VAE8VMB;W@B(&YA;64]
M(B5S(B!V86QU93TB)7,B)7,E<R`O/CQL86)E;"!F;W(](B5S)7,B/B9N8G-P
M.R5S/"]L86)E;#X\8G(@+SXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H)&YA;64L($5.5%]154]415,L("1T
M:&ES+3Y?8VAA<G-E="DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D:2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($!H=&UL<W!E
M8VEA;&-H87)S*"1N86UE+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@0&AT;6QS<&5C:6%L
M8VAA<G,H)'9A;'5E+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-H96-K960L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D86-T:6]N<RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@($!H=&UL<W!E8VEA;&-H87)S*"1N86UE
M+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!`:'1M;'-P96-I86QC:&%R<R@D9&ES<&QA>2P@14Y47U%53U1%
M4RP@)'1H:7,M/E]C:&%R<V5T*2D["B`@("`@("`@("`@("1I*RL["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("!F=6YC
M=&EO;B!?9V5N240H)&YA;64L("1F=6QL=&%G(#T@=')U92D*("`@('L*("`@
M("`@("`D;F%M92`]($!H=&UL<W!E8VEA;&-H87)S*"1N86UE+"!%3E1?455/
M5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@(')E='5R;B`D9G5L;'1A
M9R`_("=I9#TB)R`N("1N86UE("X@)R(G(#H@)&YA;64["B`@("!]"@H@("`@
M9G5N8W1I;VX@7V=E;D%C=&EO;E-C<FEP="@F)&9O<FTL("1A8W1I;VXL("1V
M87)N86UE*0H@("`@>PH@("`@("`@("1H=&UL(#T@)R<["B`@("`@("`@)'1R
M:6=G97)S(#T@)&%C=&EO;BT^9V5T5')I9V=E<B@I.PH@("`@("`@(&EF("@A
M:7-?87)R87DH)'1R:6=G97)S*2D@>PH@("`@("`@("`@("`D=')I9V=E<G,@
M/2!A<G)A>2@D=')I9V=E<G,I.PH@("`@("`@('T*("`@("`@("`D:G,@/2`D
M86-T:6]N+3YG971!8W1I;VY38W)I<'0H)&9O<FTL("1T:&ES+"`D=F%R;F%M
M92D["B`@("`@("`@9F]R96%C:"`H)'1R:6=G97)S(&%S("1T<FEG9V5R*2![
M"B`@("`@("`@("`@(&EF("@D=')I9V=E<B`]/2`G;VYL;V%D)RD@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]A9&1/;DQO861*879A<V-R:7!T*"1J<RD[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D:'1M;"`N
M/2`G("<@+B`D=')I9V=E<B`N("<](B<@+B`D:G,@+B`G(B<["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1H=&UL.PH@("`@?0H*
M("`@(&9U;F-T:6]N(%]G971!8W1I;VY38W)I<'1S*"8D9F]R;2P@)B1V87(I
M"B`@("!["B`@("`@("`@)&%C=&EO;G,@/2`G)SL*("`@("`@("!I9B`H)'9A
M<BT^:&%S06-T:6]N*"DI('L*("`@("`@("`@("`@)'9A<FYA;64@/2`D=F%R
M+3YG971687).86UE*"D["B`@("`@("`@("`@("1A8W1I;VX@/28@)'9A<BT^
M7V%C=&EO;CL*("`@("`@("`@("`@)'1R:6=G97)S(#T@)&%C=&EO;BT^9V5T
M5')I9V=E<B@I.PH@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1T<FEG9V5R
M<RDI('L*("`@("`@("`@("`@("`@("1T<FEG9V5R<R`](&%R<F%Y*"1T<FEG
M9V5R<RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&IS(#T@)&%C=&EO
M;BT^9V5T06-T:6]N4V-R:7!T*"1F;W)M+"`D=&AI<RP@)'9A<FYA;64I.PH@
M("`@("`@("`@("!F;W)E86-H("@D=')I9V=E<G,@87,@)'1R:6=G97(I('L*
M("`@("`@("`@("`@("`@(&EF("@D=')I9V=E<B`]/2`G;VYL;V%D)RD@>PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?861D3VY,;V%D2F%V87-C<FEP
M="@D:G,I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D86-T:6]N<R`N/2`G("<@+B`D=')I9V=E<B`N("<](B<@+B`D
M:G,@+B`G(B<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("1A8W1I;VYS.PH@("`@?0H*("`@(&9U
M;F-T:6]N(%]A9&1/;DQO861*879A<V-R:7!T*"1S8W)I<'0I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]O;DQO861*4UM=(#T@)'-C<FEP=#L*("`@('T*"B`@
M("!F=6YC=&EO;B!R96YD97)%;F0H*0H@("`@>PH@("`@("`@(&EF("AC;W5N
M="@D=&AI<RT^7V]N3&]A9$I3*2D@>PH@("`@("`@("`@("!R971U<FX@(CQS
M8W)I<'0@='EP93U<(G1E>'0O:F%V87-C<FEP=%PB/B(@+@H@("`@("`@("`@
M("`@("`@(CPA+2U<;B(@+B`@:6UP;&]D92@B7&XB+"`D=&AI<RT^7V]N3&]A
M9$I3*2`N(")<;B\O("TM/EQN(B`N"B`@("`@("`@("`@("`@("`B/"]S8W)I
M<'0^(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)R<[
M"B`@("`@("`@?0H@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+W1A8FQE<V5T7VAT;6PN<&AP
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`V,#0T(#$P-3$U-#,S-S0P(#`R-30T-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`H*<F5Q=6ER95]O;F-E("=(;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<"<["@HO*BH*("H@)$AO<F1E.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O=&%B;&5S971?:'1M;"YP:'`L=B`Q+C,N,BXQ(#(P,#4O,3`O,3@@,3$Z
M,#$Z,S8@:F%N($5X<"`D"B`J"B`J($!P86-K86=E($AO<F1E7U5)"B`J($!S
M:6YC92`@($AO<F1E(#,N,0H@*B\*8VQA<W,@2&]R9&5?54E?5F%R4F5N9&5R
M97)?=&%B;&5S971?:'1M;"!E>'1E;F1S($AO<F1E7U5)7U9A<E)E;F1E<F5R
M7VAT;6P@>PH*("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=%]T86)L97-E
M="@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)&AE861E
M<B`]("1V87(M/G1Y<&4M/F=E=$AE861E<B@I.PH@("`@("`@("1N86UE("`@
M/2`D=F%R+3YG971687).86UE*"D["B`@("`@("`@)'9A;'5E<R`]("1V87(M
M/F=E=%9A;'5E<R@I.PH@("`@("`@("1C:&5C:V5D5F%L=65S(#T@)'9A<BT^
M9V5T5F%L=64H)'9A<G,I.PH@("`@("`@("1A8W1I;VYS(#T@)'1H:7,M/E]G
M971!8W1I;VY38W)I<'1S*"1F;W)M+"`D=F%R*3L*"B`@("`@("`@)&AT;6P@
M/2`G/'1A8FQE('=I9'1H/2(Q,#`E(B!C;&%S<STB:71E;2(@8V5L;'-P86-I
M;F<](C$B/CQT<B!C;&%S<STB<V5L96-T960B/B<@+@H@("`@("`@("`@("`G
M/'1H(&-L87-S/2)W:61G970B(&%L:6=N/2)R:6=H="(@=VED=&@](C$E(CXF
M;F)S<#L\+W1H/B<["B`@("`@("`@9F]R96%C:"`H)&AE861E<B!A<R`D8V]L
M7W1I=&QE*2!["B`@("`@("`@("`@("1H=&UL("X]('-P<FEN=&8H)SQT:"!A
M;&EG;CTB;&5F="(@8VQA<W,](G=I9&=E="(^)7,\+W1H/B<L("1C;VQ?=&ET
M;&4I.PH@("`@("`@('T*("`@("`@("`D:'1M;"`N/2`G/"]T<CXG.PH*("`@
M("`@("!I9B`H(6ES7V%R<F%Y*"1C:&5C:V5D5F%L=65S*2D@>PH@("`@("`@
M("`@("`D8VAE8VME9%9A;'5E<R`](&%R<F%Y*"D["B`@("`@("`@?0H@("`@
M("`@("1I(#T@,#L*("`@("`@("!F;W)E86-H("@D=F%L=65S(&%S("1V86QU
M92`]/B`D9&ES<&QA>7,I('L*("`@("`@("`@("`@)&-L87-S(#T@)VET96TG
M("X@*"1I("L@,2D@)2`R.PH@("`@("`@("`@("`D8VAE8VME9"`]("AI;E]A
M<G)A>2@D=F%L=64L("1C:&5C:V5D5F%L=65S*2D@/R`G(&-H96-K960](F-H
M96-K960B)R`Z("<G.PH@("`@("`@("`@("`D:'1M;"`N/2!S<')I;G1F*"<\
M='(@8VQA<W,](B5S(CXG+"`D8VQA<W,I("X*("`@("`@("`@("`@("`@('-P
M<FEN=&8H)SQT9"!A;&EG;CTB8V5N=&5R(CX\:6YP=70@:60](B5S)7,B('1Y
M<&4](F-H96-K8F]X(B!N86UE/2(E<UM=(B!V86QU93TB)7,B)7,E<R`O/CPO
M=&0^)RP*("`@("`@("`@("`@("`@("`@("`@("`@)&YA;64L"B`@("`@("`@
M("`@("`@("`@("`@("`@("1I+`H@("`@("`@("`@("`@("`@("`@("`@("`D
M;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E+`H@("`@("`@
M("`@("`@("`@("`@("`@("`D8VAE8VME9"P*("`@("`@("`@("`@("`@("`@
M("`@("`@)&%C=&EO;G,I.PH@("`@("`@("`@("!F;W)E86-H("@D9&ES<&QA
M>7,@87,@)&-O;"D@>PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@<W!R:6YT
M9B@G/'1D(&%L:6=N/2)L969T(CXF;F)S<#LE<SPO=&0^)RP@)&-O;"D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)&AT;6P@+CT@)SPO='(^)SL*("`@
M("`@("`@("`@)&DK*SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:'1M
M;"`N("<\+W1A8FQE/B<["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A
M<D1I<W!L87E?=&%B;&5S970H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@
M>PH@("`@("`@("1H96%D97(@/2`D=F%R+3YT>7!E+3YG971(96%D97(H*3L*
M("`@("`@("`D;F%M92`@(#T@)'9A<BT^9V5T5F%R3F%M92@I.PH@("`@("`@
M("1V86QU97,@/2`D=F%R+3YG971686QU97,H*3L*("`@("`@("`D8VAE8VME
M9%9A;'5E<R`]("1V87(M/F=E=%9A;'5E*"1V87)S*3L*("`@("`@("`D86-T
M:6]N<R`]("1T:&ES+3Y?9V5T06-T:6]N4V-R:7!T<R@D9F]R;2P@)'9A<BD[
M"@H@("`@("`@("1H=&UL(#T@)SQT86)L92!W:61T:#TB,3`P)2(@8V5L;'-P
M86-I;F<](C$B/CQT<B!C;&%S<STB<V5L96-T960B/B<@+@H@("`@("`@("`@
M("`G/'1H(&-L87-S/2)W:61G970B(&%L:6=N/2)R:6=H="(@=VED=&@](C$E
M(CXF;F)S<#L\+W1H/B<["B`@("`@("`@9F]R96%C:"`H)&AE861E<B!A<R`D
M8V]L7W1I=&QE*2!["B`@("`@("`@("`@("1H=&UL("X]('-P<FEN=&8H)SQT
M:"!A;&EG;CTB;&5F="(@8VQA<W,](G=I9&=E="(^)7,\+W1H/B<L("1C;VQ?
M=&ET;&4I.PH@("`@("`@('T*("`@("`@("`D:'1M;"`N/2`G/"]T<CXG.PH*
M("`@("`@("!I9B`H(6ES7V%R<F%Y*"1C:&5C:V5D5F%L=65S*2D@>PH@("`@
M("`@("`@("`D8VAE8VME9%9A;'5E<R`](&%R<F%Y*"D["B`@("`@("`@?0H@
M("`@("`@("1I(#T@,#L*("`@("`@("!F;W)E86-H("@D=F%L=65S(&%S("1V
M86QU92`]/B`D9&ES<&QA>7,I('L*("`@("`@("`@("`@)&-L87-S("`@/2`G
M:71E;2<@+B`H)&D@*R`Q*2`E(#(["B`@("`@("`@("`@("1C:&5C:V5D(#T@
M*&EN7V%R<F%Y*"1V86QU92P@)&-H96-K961686QU97,I*2`_("=;(#QS=')O
M;F<^/&9O;G0@8V]L;W(]9W)E96X^5CPO9F]N=#X\+W-T<F]N9SX@72<@.B`G
M6R`\<W1R;VYG/CQF;VYT(&-O;&]R/7)E9#Y8/"]F;VYT/CPO<W1R;VYG/B!=
M)SL*("`@("`@("`@("`@)&AT;6P@+CT@<W!R:6YT9B@G/'1R(&-L87-S/2(E
M<R(^)RP@)&-L87-S*2`N"B`@("`@("`@("`@("`@("!S<')I;G1F*"<\=&0@
M86QI9VX](F-E;G1E<B(^)7,\+W1D/B<L("1C:&5C:V5D*3L*("`@("`@("`@
M("`@9F]R96%C:"`H)&1I<W!L87ES(&%S("1C;VPI('L*("`@("`@("`@("`@
M("`@("1H=&UL("X]('-P<FEN=&8H)SQT9"!A;&EG;CTB;&5F="(^)FYB<W`[
M)7,\+W1D/B<L("1C;VPI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1H
M=&UL("X]("<\+W1R/B<["B`@("`@("`@("`@("1I*RL["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&AT;6P@+B`G/"]T86)L93XG.PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B](;W)D92]522]7:61G970N<&AP````````````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P-#,U,B`Q,#4Q-30S,S<T,"`P,C$V,C$`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J(%1H92!(;W)D95]525]7:61G970Z.B!C;&%S<R!P<F]V:61E
M<R!B87-E(&9U;F-T:6]N86QI='D@9F]R(&]T:&5R($AO<F1E"B`J(%5)(&5L
M96UE;G1S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]522]522]7:61G970N
M<&AP+'8@,2XW+C$P+C@@,C`P-B\P-B\R,"`P.3HP.#HT-2!J86X@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!*87-O;B!-+B!&96QI8V4@/&IF
M96QI8V5`8W)O;F]S>7,N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0'-I;F-E
M("`@2&]R9&5?54D@,"XP+C$*("H@0'!A8VMA9V4@2&]R9&5?54D*("HO"F-L
M87-S($AO<F1E7U5)7U=I9&=E="!["@H@("`@+RHJ"B`@("`@*B!!;GD@=F%R
M:6%B;&5S('1H870@<VAO=6QD(&)E('!R97-E<G9E9"!I;B!A;&P@;V8@=&AE
M('=I9&=E="=S"B`@("`@*B!L:6YK<RX*("`@("`J"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D7W!R97-E<G9E(#T@87)R87DH*3L*"B`@
M("`O*BH*("`@("`J(%1H92!N86UE(&]F('1H:7,@=VED9V5T+B`@5&AI<R!I
M<R!U<V5D(&%S('1H92!B87-E;F%M92!F;W(@=F%R:6%B;&5S"B`@("`@*B!W
M92!A8V-E<W,@86YD(&UA;FEP=6QA=&4N"B`@("`@*@H@("`@("H@0'9A<B!S
M=')I;F<*("`@("`J+PH@("`@=F%R("1?;F%M93L*"B`@("`O*BH*("`@("`J
M($$@<F5F97)E;F-E('1O(&$@5F%R:6%B;&5S.CH@;V)J96-T('1H:7,@=VED
M9V5T('=I;&P@=7-E(&%N9`H@("`@("H@;6%N:7!U;&%T92X*("`@("`J"B`@
M("`@*B!`=F%R(%9A<FEA8FQE<PH@("`@("HO"B`@("!V87(@)%]V87)S.PH*
M("`@("\J*@H@("`@("H@06X@87)R87D@;V8@;F%M92`]/B!V86QU92!P86ER
M<R!W:&EC:"!C;VYF:6=U<F4@:&]W('1H:7,@=VED9V5T"B`@("`@*B!B96AA
M=F5S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R
M("1?8V]N9FEG.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T(&$@;F5W(%5)
M(%=I9&=E="!I;G1E<F9A8V4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;F%M92`@("`@(%1H92!N86UE(&]F('1H92!V87)I86)L92!W:&EC:"!W
M:6QL('1R86-K('1H:7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("!522!W:61G970G<R!S=&%T92X*("`@("`J($!P87)A;2!687)I86)L97,@
M)B1V87)S("!!(%9A<FEA8FQE<SHZ(&]B:F5C="X*("`@("`J($!P87)A;2!A
M<G)A>2`D8V]N9FEG("`@("!4:&4@=VED9V5T)W,@8V]N9FEG=7)A=&EO;BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?54E?5VED9V5T*"1N86UE+"`F
M)'9A<G,L("1C;VYF:6<@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?;F%M92`]("1N86UE.PH@("`@("`@("1T:&ES+3Y?=F%R<R`]("8D=F%R
M<SL*("`@("`@("`D=&AI<RT^7V-O;F9I9R`]("1C;VYF:6<["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!);G-T<G5C="!(;W)D95]525]7:61G970Z.B!T;R!P
M<F5S97)V92!A('9A<FEA8FQE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'9A<B`@(%1H92!N86UE(&]F('1H92!V87)I86)L92!T;R!P<F5S97)V
M92X*("`@("`J($!P87)A;2!M:7AE9"`D=F%L=64@(%1H92!V86QU92!O9B!T
M:&4@=F%R:6%B;&4@=&\@<')E<V5R=F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('!R97-E<G9E*"1V87(L("1V86QU92D*("`@('L*("`@("`@("`D=&AI<RT^
M7W!R97-E<G9E6R1V87)=(#T@)'9A;'5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A9&10
M<F5S97)V960H)&QI;FLI"B`@("!["B`@("`@("`@9F]R96%C:"`H)'1H:7,M
M/E]P<F5S97)V92!A<R`D=F%R3F%M92`]/B`D=F%R5F%L=64I('L*("`@("`@
M("`@("`@)&QI;FL@/2!5=&EL.CIA9&1087)A;65T97(H)&QI;FLL("1V87).
M86UE+"`D=F%R5F%L=64I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&QI
M;FL["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296YD97(@=&AE('=I9&=E="X*
M("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<&%R86T@
M;6EX960@)&1A=&$@(%1H92!W:61G970G<R!S=&%T92!D871A+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!R96YD97(H*2![?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]522]486)S+G!H<```````````
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-C8R,"`Q,#4Q-30S
M,S<T,"`P,C$R-C<`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"G)E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?
M*2`N("<O5VED9V5T+G!H<"<["@HO*BH*("H@5&AE($AO<F1E7U5)7U1A8G,Z
M.B!C;&%S<R!M86YA9V5S(&%N9"!R96YD97)S(&$@=&%B+6QI:V4@:6YT97)F
M86-E+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]522]522]486)S+G!H<"QV
M(#$N,C<N-BXQ,"`R,#`V+S`V+S(P(#`Y.C`X.C0U(&IA;B!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,C`P,2TR,#`S(%)O8F5R="!%+B!#;WEL92`\<F]B97)T
M96-O>6QE0&AO=&UA:6PN8V]M/@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($IA
M<V]N($TN($9E;&EC92`\:F9E;&EC94!C<F]N;W-Y<RYC;VT^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*@H@*B!`<VEN8V4@("!(;W)D95]522`P+C`N,0H@*B!`<&%C:V%G
M92!(;W)D95]520H@*B\*8VQA<W,@2&]R9&5?54E?5&%B<R!E>'1E;F1S($AO
M<F1E7U5)7U=I9&=E="!["@H@("`@+RHJ"B`@("`@*B!4:&4@87)R87D@;V8@
M=&%B<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D7W1A8G,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@061D(&$@=&%B
M('1O('1H92!I;G1E<F9A8V4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=&ET;&4@("`@5&AE('1E>'0@=VAI8V@@87!P96%R<R!O;B!T:&4@=&%B
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;&EN:R`@("`@5&AE('1A<F=E="!P
M86=E+@H@("`@("H@0'!A<F%M(&UI>&5D("`D<&%R86US("`@16ET:&5R(&$@
M<W1R:6YG('9A;'5E('1O('-E="!T:&4@=&%B('9A<FEA8FQE('1O+`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@;W(@82!H87-H(&]F('!A<F%M
M971E<G,N($EF(&%N(&%R<F%Y+"!T:&4@=&%B('9A<FEA8FQE"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!C86X@8F4@<V5T(&)Y('1H92`G=&%B
M;F%M92<@:V5Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1486(H)'1I=&QE
M+"`D;&EN:RP@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@
M*"%I<U]A<G)A>2@D<&%R86US*2D@>PH@("`@("`@("`@("`D<&%R86US(#T@
M87)R87DH)W1A8FYA;64G(#T^("1P87)A;7,I.PH@("`@("`@('T*("`@("`@
M("`D=&AI<RT^7W1A8G-;72`](&%R<F%Y7VUE<F=E*&%R<F%Y*"=T:71L92<@
M/3X@)'1I=&QE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)VQI;FLG(#T^("1L:6YK+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W1A8FYA;64G(#T^(&YU;&PI+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<RD[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V92!T:&4@=&ET;&4@;V8@
M=&AE('1A8B!W:71H('1H92!S<&5C:69I960@;F%M92X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1T86)N86UE("!4:&4@;F%M92!O9B!T:&4@=&%B
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=&%B)W,@=&ET
M;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1I=&QE1G)O;4%C=&EO;B@D
M=&%B;F%M92D*("`@('L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7W1A8G,@
M87,@)'1A8BD@>PH@("`@("`@("`@("!I9B`H)'1A8ELG=&%B;F%M92==(#T]
M("1T86)N86UE*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1A8ELG=&ET
M;&4G73L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296YD97)S('1H92!T86)S
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%C=&EV95]T86(@($EF
M('-P96-I9FEE9"P@=&AE(&YA;64@;V8@=&AE(&%C=&EV92!T86(N($EF"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!N;W0L('1H92!A8W1I
M=F4@=&%B(&ES(&1E=&5R;6EN960*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%U=&]M871I8V%L;'DN"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E;F1E<B@D86-T:79E7W1A8B`](&YU;&PI"B`@("!["B`@("`@("`@)&AT
M;6P@/2`B/&1I=B!C;&%S<SU<(G1A8G-E=%PB/CQU;#Y<;B(["@H@("`@("`@
M("1F:7)S="`]('1R=64["B`@("`@("`@)&%C=&EV92`]("1?4T525D526R=0
M2%!?4T5,1B==("X@)'1H:7,M/E]V87)S+3YG970H)'1H:7,M/E]N86UE*3L*
M"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]T86)S(&%S("1T86(I('L*("`@
M("`@("`@("`@)&QI;FL@/2`D=&AI<RT^7V%D9%!R97-E<G9E9"@D=&%B6R=L
M:6YK)UTI.PH@("`@("`@("`@("!I9B`H(6ES7VYU;&PH)'1H:7,M/E]N86UE
M*2`F)B`A:7-?;G5L;"@D=&%B6R=T86)N86UE)UTI*2!["B`@("`@("`@("`@
M("`@("`D;&EN:R`](%5T:6PZ.F%D9%!A<F%M971E<B@D;&EN:RP@)'1H:7,M
M/E]N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1A8ELG=&%B;F%M92==*3L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)&-L87-S(#T@)R<["B`@("`@("`@("`@(&EF("@H(6ES7VYU;&PH
M)&%C=&EV95]T86(I("8F("1A8W1I=F5?=&%B(#T]("1T86);)W1A8FYA;64G
M72D@?'P*("`@("`@("`@("`@("`@("@D86-T:79E(#T]("1T86);)VQI;FLG
M72`N("1T86);)W1A8FYA;64G72DI('L*("`@("`@("`@("`@("`@("1C;&%S
M<R`]("<@8VQA<W,](F%C=&EV951A8B(G.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1T86);)W1A<F=E="==*2D@>PH@("`@("`@
M("`@("`@("`@)'1A8ELG=&%R9V5T)UT@/2`G)SL*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@:68@*"%I<W-E="@D=&%B6R=O;F-L:6-K)UTI*2!["B`@
M("`@("`@("`@("`@("`D=&%B6R=O;F-L:6-K)UT@/2`G)SL*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@)&%C8V5S<VME>2`]($AO<F1E.CIG971!8V-E
M<W-+97DH)'1A8ELG=&ET;&4G72D["@H@("`@("`@("`@("`D:'1M;"`N/2`G
M/&QI)R`N("1C;&%S<R`N("<^)R`N"B`@("`@("`@("`@("`@("!(;W)D93HZ
M;&EN:R@D;&EN:RP@)R<L("<G+"`D=&%B6R=T87)G970G72P@)'1A8ELG;VYC
M;&EC:R==+"!N=6QL+"`D86-C97-S:V5Y*2`N"B`@("`@("`@("`@("`@("!(
M;W)D93HZ:&EG:&QI9VAT06-C97-S2V5Y*'-T<E]R97!L86-E*"<@)RP@)R9N
M8G-P.R<L("1T86);)W1I=&QE)UTI+"`D86-C97-S:V5Y*2`N"B`@("`@("`@
M("`@("`@("`B/"]A/B`\+VQI/EQN(CL*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D:'1M;"`N("(\+W5L/CPO9&EV/CQB<B!C;&%S<SU<(F-L96%R7"(@
M+SY<;B(["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O54DO3&%N9W5A9V4N<&AP````
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,R-#`@,3`U,34T
M,S,W-#`@,#(R,3$T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B!4:&4@2&]R9&5?54E?3&%N9W5A9V4Z
M.B!C;&%S<R!P<F]V:61E<R!A('=I9&=E="!F;W(@8VAA;F=I;F<@=&AE"B`J
M(&-U<G)E;G1L>2!S96QE8W1E9"!L86YG=6%G92X*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO54DO54DO3&%N9W5A9V4N<&AP+'8@,2XU+C$P+C<@,C`P-B\P
M-B\R,"`P.3HP.#HT-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M
M,C`P-B!*87-O;B!-+B!&96QI8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0'-I;F-E("`@2&]R9&5?54D@,"XP+C$*("H@
M0'!A8VMA9V4@2&]R9&5?54D*("HO"F-L87-S($AO<F1E7U5)7TQA;F=U86=E
M('L*"B`@("`O*BH*("`@("`J(%)E;F1E<B!T:&4@;&%N9W5A9V4@<V5L96-T
M:6]N+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!P
M87)A;2!B;V]L96%N("1F;W)M("!2971U<FX@=&AE('-E;&5C=&EO;B!B;W@@
M87,@86X@8V]M<&QE=&4@<W1A;F1A;&]N90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@(&9O<FTN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!(5$U,('-E;&5C=&EO;B!B;W@N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E;F1E<B@I"B`@("!["B`@("`@("`@)&AT;6P@/2`G)SL*("`@("`@("!I
M9B`H(21'3$]"04Q36R=P<F5F<R==+3YI<TQO8VME9"@G;&%N9W5A9V4G*2D@
M>PH@("`@("`@("`@("!(;W)D93HZ861D4V-R:7!T1FEL92@G;&%N9W5A9V4N
M:G,G+"`G:&]R9&4G*3L*("`@("`@("`@("`@)%]315-324].6R=H;W)D95]L
M86YG=6%G92==(#T@3DQ3.CIS96QE8W0H*3L*("`@("`@("`@("`@)&AT;6P@
M/2!S<')I;G1F*"<\9F]R;2!N86UE/2)L86YG=6%G92(@86-T:6]N/2(E<R(^
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@($AO<F1E.CIU<FPH)$=,
M3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B<F]O="<L("=H;W)D92<I("X@
M)R]S97)V:6-E<R]L86YG=6%G92YP:'`G+"!F86QS92P@+3$I*3L*("`@("`@
M("`@("`@)&AT;6P@+CT@)SQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](G5R
M;"(@=F%L=64](B<@+B!`:'1M;'-P96-I86QC:&%R<RA(;W)D93HZ<V5L9E5R
M;"AF86QS92P@9F%L<V4L('1R=64I*2`N("<B("\^)SL*("`@("`@("`@("`@
M)&AT;6P@+CT@)SQS96QE8W0@;F%M93TB;F5W7VQA;F<B(&]N8VAA;F=E/2)D
M;V-U;65N="YL86YG=6%G92YS=6)M:70H*2(^)SL*("`@("`@("`@("`@9F]R
M96%C:"`H)$=,3T)!3%-;)VYL<R==6R=L86YG=6%G97,G72!A<R`D:V5Y(#T^
M("1V86PI('L*("`@("`@("`@("`@("`@("1S96P@/2`H)&ME>2`]/2`D7U-%
M4U-)3TY;)VAO<F1E7VQA;F=U86=E)UTI(#\@)R!S96QE8W1E9#TB<V5L96-T
M960B)R`Z("<G.PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@(CQO<'1I;VX@
M=F%L=64]7"(D:V5Y7"(D<V5L/B1V86P\+V]P=&EO;CXB.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1H=&UL("X]("<\+W-E;&5C=#X\+V9O<FT^)SL*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("1H=&UL.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+G!H<```````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$P,C(Q(#$P-3$U-#,S-S0P
M(#`R,C8P-0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@5&AE($AO<F1E7U5)7U9A<E)E;F1E<F5R.CH@
M8VQA<W,@<')O=FED97,@8F%S92!F=6YC=&EO;F%L:71Y(&9O<@H@*B!O=&AE
M<B!(;W)D92!522!E;&5M96YT<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(N<&AP+'8@,2XQ,BXQ,"XQ,"`R,#`V+S`V+S(P
M(#`Y.C`X.C0U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V
M($IA<V]N($TN($9E;&EC92`\:F9E;&EC94!C<F]N;W-Y<RYC;VT^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`<VEN8V4@("!(;W)D95]522`P+C`N,0H@*B!`<&%C
M:V%G92!(;W)D95]520H@*B\*8VQA<W,@2&]R9&5?54E?5F%R4F5N9&5R97(@
M>PH*("`@("\J*@H@("`@("H@4&%R86UE=&5R<R!W:&EC:"!C:&%N9V4@=&AI
M<R!R96YD97)E<B=S(&)E:&%V:6]R+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?<&%R86US.PH*("`@("\J*@H@("`@("H@
M0VAA<G-E="!T;R!U<V4@9F]R(&]U='!U="X*("`@("`J"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]C:&%R<V5T.PH*("`@("\J*@H@
M("`@("H@0V]N<W1R=6-T<R!A(&YE=R!R96YD97)E<BX*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@)'!A<F%M<R`@5&AE(&YA;64@;V8@=&AE('9A<FEA
M8FQE('=H:6-H('=I;&P@=')A8VL@=&AI<R!520H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@('=I9&=E="=S('-T871E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!(;W)D95]525]687)296YD97)E<B@D<&%R86US(#T@87)R87DH*2D*
M("`@('L*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P87)A;7,["B`@("`@
M("`@)'1H:7,M/E]C:&%R<V5T(#T@3DQ3.CIG971#:&%R<V5T*"D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W($AO<F1E7U5)7U9A
M<E)E;F1E<F5R.CH@:6YS=&%N8V4N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI
M>&5D("1D<FEV97(@(%1H:7,@:7,@=&AE(')E;F1E<F5R('-U8F-L87-S('=E
M('=I;&P@:6YS=&%N=&EA=&4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@268@86X@87)R87D@:7,@<&%S<V5D+"!T:&4@9FER<W0@96QE;65N="!I
M<R!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!L:6)R87)Y('!A
M=&@@86YD('1H92!S96-O;F0@96QE;65N="!I<R!T:&4@9')I=F5R"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@;F%M92X*("`@("`J($!P87)A;2!A
M<G)A>2`D<&%R86US("!087)A;65T97)S('-P96-I9FEC('1O('1H92!S=6)C
M;&%S<RX*("`@("`J"B`@("`@*B!`<F5T=7)N($AO<F1E7U5)7U9A<E)E;F1E
M<F5R("!!($AO<F1E7U5)7U9A<E)E;F1E<F5R.CH@<W5B8VQA<W,*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EN<W1A;F-E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D9')I=F5R+"`D<&%R86US(#T@
M87)R87DH*2D*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH)&1R:79E<BDI
M('L*("`@("`@("`@("`@)&%P<"`]("1D<FEV97);,%T["B`@("`@("`@("`@
M("1D<FEV97(@/2`D9')I=F5R6S%=.PH@("`@("`@('T*"B`@("`@("`@)&1R
M:79E<B`](&)A<V5N86UE*"1D<FEV97(I.PH*("`@("`@("!I9B`H(65M<'1Y
M*"1A<'`I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`D1TQ/0D%,4ULG
M<F5G:7-T<GDG72T^9V5T*"=F:6QE<F]O="<L("1A<'`I("X@)R]L:6(O54DO
M5F%R4F5N9&5R97(O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?2!E
M;'-E:68@*$!F:6QE7V5X:7-T<RAD:7)N86UE*%]?1DE,15]?*2`N("<O5F%R
M4F5N9&5R97(O)R`N("1D<FEV97(@+B`G+G!H<"<I*2!["B`@("`@("`@("`@
M(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O5F%R4F5N9&5R
M97(O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@0&EN8VQU9&5?;VYC92`G2&]R9&4O54DO5F%R4F5N9&5R97(O
M)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?0H*("`@("`@("`D8VQA
M<W,@/2`G2&]R9&5?54E?5F%R4F5N9&5R97)?)R`N("1D<FEV97(["B`@("`@
M("`@:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1V
M<B`]("9N97<@)&-L87-S*"1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1V<B`](%!%05(Z.G)A:7-E17)R;W(H)T-L87-S(&1E9FEN
M:71I;VX@;V8@)R`N("1C;&%S<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1V<CL*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@82!(;W)D95]525]687)296YD97)E<CHZ(&EN<W1A;F-E+"!C
M;VYS=')U8W1I;F<@;VYE('=I=&@@=&AE"B`@("`@*B!S<&5C:69I960@<&%R
M86UE=&5R<R!I9B!N96-E<W-A<GDN"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9')I=F5R("!4:&ES(&ES('1H92!R96YD97)E<B!S=6)C;&%S<R!W
M92!W:6QL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&EN<W1A;G1I
M871E+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("!087)A;65T97)S
M('-P96-I9FEC('1O('1H92!S=6)C;&%S<RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N($AO<F1E7U5)7U9A<E)E;F1E<F5R("!!($AO<F1E7U5)7U9A<E)E;F1E
M<F5R.CH@<W5B8VQA<W,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EN<W1A;F-E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE
M=&]N*"1D<FEV97(L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@
M('-T871I8R`D8V%C:&4["@H@("`@("`@(&EF("AI<U]N=6QL*"1D<FEV97(I
M*2!["B`@("`@("`@("`@("1C;&%S<R`]("=(;W)D95]525]687)296YD97)E
M<B<["B`@("`@("`@?0H@("`@("`@("1K97D@/2!S97)I86QI>F4H87)R87D@
M*"1D<FEV97(L("1P87)A;7,I*3L*("`@("`@("!I9B`H(6ES<V5T*"1C86-H
M95LD:V5Y72DI('L*("`@("`@("`@("`@)&-A8VAE6R1K97E=(#T@)DAO<F1E
M7U5)7U9A<E)E;F1E<F5R.CIF86-T;W)Y*"1D<FEV97(L("1P87)A;7,I.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)&-A8VAE6R1K97E=.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5N9&5R<R!A('9A<FEA8FQE+@H@("`@("H*("`@
M("`J($!P87)A;2!(;W)D95]&;W)M("8D9F]R;2`@("`@("`@("`@4F5F97)E
M;F-E('1O(&$@2&]R9&5?1F]R;2!I;G-T86YC92P*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@;W(@;G5L;"!I9B!N;VYE(&ES
M(&%V86EL86)L92X*("`@("`J($!P87)A;2!(;W)D95]&;W)M7U9A<FEA8FQE
M("8D=F%R("`@4F5F97)E;F-E('1O(&$@2&]R9&5?1F]R;5]687)I86)L92X*
M("`@("`J($!P87)A;2!687)I86)L97,@)B1V87)S("`@("`@("`@("`@02!6
M87)I86)L97,@:6YS=&%N8V4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D:7-)
M;G!U="`@("`@("`@("`@(%=H971H97(@=&AI<R!I<R!A;B!I;G!U="!F:65L
M9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R*"8D9F]R;2P@)B1V87(L
M("8D=F%R<RP@)&ES26YP=70@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H
M)&ES26YP=70I('L*("`@("`@("`@("`@)'-T871E(#T@)TEN<'5T)SL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<W1A=&4@/2`G1&ES<&QA>2<[
M"B`@("`@("`@?0H@("`@("`@("1M971H;V0@/2`B7W)E;F1E<E9A<B1[<W1A
M=&5]7R(@+B`D=F%R+3YT>7!E+3YG9714>7!E3F%M92@I.PH@("`@("`@(&EF
M("@A0&UE=&AO9%]E>&ES=',H)'1H:7,L("1M971H;V0I*2!["B`@("`@("`@
M("`@("1M971H;V0@/2`B7W)E;F1E<E9A<B1[<W1A=&5]1&5F875L="(["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^)&UE=&AO9"@D9F]R;2P@
M)'9A<BP@)'9A<G,I.PH@("`@?0H*("`@("\J*@H@("`@("H@1FEN:7-H97,@
M<F5N9&5R:6YG(&%F=&5R(&%L;"!F:65L9',@87)E(&]U='!U="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<F5N9&5R16YD*"D*("`@('L*("`@("`@("!R971U
M<FX@)R<["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O54DO4&%G97(N<&AP````````````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#<U-C8@,3`U,34T,S,W-#`@,#(Q-#0V`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"@IR97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+U=I9&=E="YP
M:'`G.PH*+RHJ"B`J(%1H92!(;W)D95]525]086=E<CHZ('!R;W9I9&5S(&QI
M;FMS('1O(&EN9&EV:61U86P@<&%G97,N"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+U5)+U5)+U!A9V5R+G!H<"QV(#$N-RXQ,"XX(#(P,#8O,#8O,C`@,#DZ
M,#@Z,C8@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@2F]E
M;"!686YD86P@/&IV86YD86Q`:6YF;W1E8VLN<6,N8V$^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B!`875T:&]R("!"96X@0VAA=F5T(#QB96Y`8VAA=F5T+FYE=#X*
M("H@0&%U=&AO<B`@2F]E;"!686YD86P@/&IV86YD86Q`:6YF;W1E8VLN<6,N
M8V$^"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*B!`<VEN8V4@("!(;W)D95]522`P+C`N,0H@*B!`<&%C:V%G92!(
M;W)D95]520H@*B\*8VQA<W,@2&]R9&5?54E?4&%G97(@97AT96YD<R!(;W)D
M95]525]7:61G970@>PH*("`@(&9U;F-T:6]N($AO<F1E7U5)7U!A9V5R*"1N
M86UE+"`F)'9A<G,L("1C;VYF:6<I"B`@("!["B`@("`@("`@:68@*"%I<W-E
M="@D8V]N9FEG6R=P86=E7VQI;6ET)UTI*2!["B`@("`@("`@("`@("1C;VYF
M:6=;)W!A9V5?;&EM:70G72`](#$P.PH@("`@("`@('T*("`@("`@("!I9B`H
M(6ES<V5T*"1C;VYF:6=;)W!E<G!A9V4G72DI('L*("`@("`@("`@("`@)&-O
M;F9I9ULG<&5R<&%G92==(#T@,3`P.PH@("`@("`@('T*("`@("`@("!P87)E
M;G0Z.DAO<F1E7U5)7U=I9&=E="@D;F%M92P@)'9A<G,L("1C;VYF:6<I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5N9&5R('1H92!P86=E<BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@2%1-3"!C;V1E(&-O;G1A:6YI;F<@
M82!C96YT97)E9"!T86)L92!W:71H('1H92!P86=E<@H@("`@("H@("`@("!L
M:6YK<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R*"D*("`@('L*("`@
M("`@("!G;&]B86P@)'!R969S+"`D<F5G:7-T<GDL("1C;VYF.PH*("`@("`@
M("`D;G5M(#T@)'1H:7,M/E]C;VYF:6=;)VYU;2==.PH@("`@("`@("1U<FP@
M/2`D=&AI<RT^7V-O;F9I9ULG=7)L)UT["B`@("`@("`@)'!A9V5?;&EM:70@
M/2`D=&AI<RT^7V-O;F9I9ULG<&%G95]L:6UI="==.PH@("`@("`@("1P97)P
M86=E(#T@)'1H:7,M/E]C;VYF:6=;)W!E<G!A9V4G73L*"B`@("`@("`@)&-U
M<G)E;G1?<&%G92`]("1T:&ES+3Y?=F%R<RT^9V5T*"1T:&ES+3Y?;F%M92D[
M"@H@("`@("`@("\O($9I9W5R92!O=70@:&]W(&UA;GD@<&%G97,@=&AE<F4@
M=VEL;"!B92X*("`@("`@("`D<&%G97,@/2`H)&YU;2`O("1P97)P86=E*3L*
M("`@("`@("!I9B`H:7-?:6YT96=E<B@D<&%G97,I*2!["B`@("`@("`@("`@
M("1P86=E<RTM.PH@("`@("`@('T*("`@("`@("`D<&%G97,@/2`H:6YT*21P
M86=E<SL*"B`@("`@("`@+R\@4F5T=7)N(&YO=&AI;F<@:68@=&AE<F4@:7,@
M;VYL>2!O;F4@<&%G92X*("`@("`@("!I9B`H)'!A9V5S(#T](#`@?'P@)&YU
M;2`]/2`P*2!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("!]"@H@
M("`@("`@("1H=&UL(#T@)SQD:78@8VQA<W,](G!A9V5R(CXG.PH*("`@("`@
M("`O+R!#<F5A=&4@=&AE("<\/"!0<F5V)R!L:6YK(&EF('=E(&%R92!N;W0@
M;VX@=&AE(&9I<G-T('!A9V4N"B`@("`@("`@)&QI;FL@/2!5=&EL.CIA9&10
M87)A;65T97(H)'5R;"P@)'1H:7,M/E]N86UE+"`D8W5R<F5N=%]P86=E("T@
M,2D["B`@("`@("`@)&QI;FL@/2`D=&AI<RT^7V%D9%!R97-E<G9E9"@D;&EN
M:RD["B`@("`@("`@:68@*"1C=7)R96YT7W!A9V4@/B`P*2!["B`@("`@("`@
M("`@("1H=&UL("X]($AO<F1E.CIL:6YK*$AO<F1E.CIA<'!L:6-A=&EO;E5R
M;"@D;&EN:RDL("<G+"`G<')E=B<I("X@:'1M;'-P96-I86QC:&%R<RA?*"(\
M4')E=FEO=7,B*2D@+B`G/"]A/B<["B`@("`@("`@?0H*("`@("`@("`O+R!&
M:6=U<F4@;W5T('1H92!T;W`@)B!B;W1T;VT@9&ES<&QA>2!L:6UI=',N"B`@
M("`@("`@)&)O='1O;2`](&UA>"@P+"`D8W5R<F5N=%]P86=E("T@*"1P86=E
M7VQI;6ET("\@,BD@*R`Q*3L*("`@("`@("`D=&]P(#T@)&)O='1O;2`K("1P
M86=E7VQI;6ET("T@,3L*("`@("`@("!I9B`H)'1O<"`M(#$@/B`D<&%G97,I
M('L*("`@("`@("`@("`@)&)O='1O;2`M/2`H)'1O<"`M(#$I("T@)'!A9V5S
M.PH@("`@("`@("`@("`D=&]P(#T@)'!A9V5S("L@,3L*("`@("`@("!]"@H@
M("`@("`@("\O($-R96%T92!B;W1T;VT@)UMX+7E=)R!L:6YK(&EF(&YE8V5S
M<V%R>2X*("`@("`@("`D;&EN:R`]("1T:&ES+3Y?861D4')E<V5R=F5D*%5T
M:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`D=&AI<RT^7VYA;64L("1B;W1T;VT@
M+2`Q*2D["B`@("`@("`@:68@*"1B;W1T;VT@/B`P*2!["B`@("`@("`@("`@
M("1H=&UL("X]("<@)R`N($AO<F1E.CIL:6YK*$AO<F1E.CIA<'!L:6-A=&EO
M;E5R;"@D;&EN:RDL("<G+"`G<')E=E)A;F=E)RD@+B`G6R<@+B`H)&)O='1O
M;2`]/2`Q(#\@)&)O='1O;2`Z("<Q+2<@+B`D8F]T=&]M*2`N("==/"]A/B<[
M"B`@("`@("`@?0H*("`@("`@("`O+R!#<F5A=&4@;&EN:W,@=&\@:6YD:79I
M9'5A;"!P86=E<R!B971W965N(&QI;6ET<RX*("`@("`@("!F;W(@*"1I(#T@
M)&)O='1O;3L@)&D@/#T@)'1O<"`F)B`D:2`\/2`D<&%G97,[("LK)&DI('L*
M("`@("`@("`@("`@:68@*"1I(#T]("1C=7)R96YT7W!A9V4I('L*("`@("`@
M("`@("`@("`@("1H=&UL("X]("<@/'-T<F]N9SXH)R`N("@D:2`K(#$I("X@
M)RD\+W-T<F]N9SXG.PH@("`@("`@("`@("!](&5L<V5I9B`H)&D@/CT@,"`F
M)B`D:2`\/2`D<&%G97,I('L*("`@("`@("`@("`@("`@("1L:6YK(#T@)'1H
M:7,M/E]A9&10<F5S97)V960H571I;#HZ861D4&%R86UE=&5R*"1U<FPL("1T
M:&ES+3Y?;F%M92P@)&DI*3L*("`@("`@("`@("`@("`@("1H=&UL("X]("<@
M)R`N($AO<F1E.CIL:6YK*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@D;&EN:RDI
M("X@*"1I("L@,2D@+B`G/"]A/B<["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("\O($-R96%T92!T;W`@)UMX+7E=)R!L:6YK(&EF(&YE8V5S
M<V%R>2X*("`@("`@("!I9B`H)'1O<"`\("1P86=E<RD@>PH@("`@("`@("`@
M("`D;&EN:R`]("1T:&ES+3Y?861D4')E<V5R=F5D*%5T:6PZ.F%D9%!A<F%M
M971E<B@D=7)L+"`D=&AI<RT^7VYA;64L("1T;W`@*R`Q*2D["B`@("`@("`@
M("`@("1H=&UL("X]("<@)R`N($AO<F1E.CIL:6YK*$AO<F1E.CIA<'!L:6-A
M=&EO;E5R;"@D;&EN:RDL("<G+"`G;F5X=%)A;F=E)RD@+B`G6R<@+@H@("`@
M("`@("`@("`@("`@*"1T;W`@*R`R(#T]("1P86=E<R`K(#$@/R`D<&%G97,@
M*R`Q(#H@*"1T;W`@*R`R*2`N("<M)R`N("@D<&%G97,@*R`Q*2D@+B`G73PO
M83XG.PH@("`@("`@('T*"B`@("`@("`@+R\@0W)E871E('1H92`G3F5X=#X^
M)R!L:6YK(&EF('=E(&%R92!N;W0@;VX@=&AE(&QA<W0@<&%G92X*("`@("`@
M("!I9B`H)&-U<G)E;G1?<&%G92`\("1P86=E<RD@>PH@("`@("`@("`@("`D
M;&EN:R`]("1T:&ES+3Y?861D4')E<V5R=F5D*%5T:6PZ.F%D9%!A<F%M971E
M<B@D=7)L+"`D=&AI<RT^7VYA;64L("1C=7)R96YT7W!A9V4@*R`Q*2D["B`@
M("`@("`@("`@("1H=&UL("X]("<@)R`N($AO<F1E.CIL:6YK*$AO<F1E.CIA
M<'!L:6-A=&EO;E5R;"@D;&EN:RDL("<G+"`G;F5X="<I("X@:'1M;'-P96-I
M86QC:&%R<RA?*").97AT/B(I*2`N("<\+V$^)SL*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D:'1M;"`N("<\+V1I=CXG.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4V-H961U;&5R````````
M````````````````````````````````````````````````````````````
M````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U
M,34T,S,W-#`@,#(Q,C`S`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]38VAE9'5L97(O8W)O;BYP:'``````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`R-C0R,"`Q,#4Q-30S,S<T,"`P,C(W-#``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*"G)E<75I<F5?
M;VYC92`G2&]R9&4O4V-H961U;&5R+G!H<"<["G)E<75I<F5?;VYC92`G2&]R
M9&4O4W1R:6YG+G!H<"<["@HO*BH*("H@2&]R9&5?4V-H961U;&5R7V-R;VXZ
M.B!3;W)T(&]F(&$@8W)O;B!R97!L86-E;65N="!I;B!A(%!(4"!C;&D*("H@
M<V-R:7!T+@H@*@H@*B!$871E(%-Y;G1A>"!%>&%M<&QE<RX*("H*("H@4F5M
M96UB97(Z"B`J("`@+2!7:&ET97-P86-E("AS<&%C92P@=&%B+"!N97=L:6YE
M*2!D96QI;6ET960@9FEE;&1S"B`J("`@+2!3:6YG;&4@=F%L=65S+"!S971S
M+"!R86YG97,L('=I;&1C87)D<PH@*@H@*B!314-/3D0@("!-24Y55$4@("`@
M("`@("`@("`@($A/55(@("`@("`@($1!62`@("`@34].5$@*("H@*B`@("`@
M("`@*B`@("`@("`@("`@("`@("`@("`J("`@("`@("`@("`J("`@("`@("H@
M("`@("`@*&5V97)Y('-E8V]N9"D*("H@,"PS,"`@("`@*B`@("`@("`@("`@
M("`@("`@("`J("`@("`@("`@("`J("`@("`@("H@("`@("`@*&5V97)Y(#,P
M('-E8V]N9',I"B`J(#`@("`@("`@(#`L,3`L,C`L,S`L-#`L-3`@("`@*B`@
M("`@("`@("`@*B`@("`@("`J("`@("`@("AE=F5R>2`Q,"!M:6YU=&5S*0H@
M*B`P("`@("`@("`P("`@("`@("`@("`@("`@("`@("H@("`@("`@("`@("H@
M("`@("`@*B`@("`@("`H8F5G:6YN:6YG(&]F(&5V97)Y(&AO=7(I"B`J(#`@
M("`@("`@(#`@("`@("`@("`@("`@("`@("`@,"PV+#$R+#$X("`@*B`@("`@
M("`J("`@("`@("AA="!M:61N:6=H="P@-F%M+"!N;V]N+"`V<&TI"B`J(#`@
M("`@("`@(#`@("`@("`@("`@("`@("`@("`@,"`@("`@("`@("`@,2TW)D9R
M:2`J("`@("`@("AM:61N:6=H="P@9FER<W0@1G)I(&]F('1H92!M;VYT:"D*
M("H@,"`@("`@("`@,"`@("`@("`@("`@("`@("`@("`P("`@("`@("`@("`Q
M+3<A1G)I("H@("`@("`@*&UI9&YI9VAT+"!F:7)S="!-;VXM5&AU+%-A="U3
M=6X@;V8@=&AE(&UO;G1H*0H@*@H@*@H@*B!%>&%M<&QE('5S86=E.@H@*@H@
M*B!`<V5T7W1I;65?;&EM:70H,"D["B`J(')E<75I<F5?;VYC92`G2&]R9&4O
M4V-H961U;&5R+G!H<"<["B`J("1C<F]N(#T@)DAO<F1E7U-C:&5D=6QE<CHZ
M<VEN9VQE=&]N*"=C<F]N)RD["B`J"B`J("\O(%)U;B!T:&ES(&-O;6UA;F0@
M979E<GD@-2!M:6YU=&5S+@H@*B`D8W)O;BT^861D5&%S:R@G<&5R;"!S;VUE
M<V-R:7!T+G!L)RP@)S`@,"PU+#$P+#$U+#(P+#(U+#,P+#,U+#0P+#0U+#4P
M+#4U("H@*B`J)RD["B`J"B`J("\O(%)U;B!T:&ES(&-O;6UA;F0@;6ED;FEG
M:'0@;V8@=&AE(&9I<G-T($9R:61A>2!O9B!O9&0@;G5M8F5R960@;6]N=&AS
M+@H@*B`D8W)O;BT^861D5&%S:R@G<&AP("UQ('-O;65S8W)I<'0N<&AP)RP@
M)S`@,"`P(#$M-R9&<FD@,2PS+#4L-RPY+#$Q)RD["B`J"B`J("\O($%L<V\@
M<G5N('1H:7,@8V]M;6%N9"!M:61N:6=H="!O9B!T:&4@<V5C;VYD(%1H=7)S
M9&%Y(&%N9"!3871U<F1A>2!O9B!T:&4@979E;B!N=6UB97)E9"!M;VYT:',N
M"B`J("1C<F]N+3YA9&1487-K*"=P:'`@+7$@<V]M97-C<FEP="YP:'`G+"`G
M,"`P(#`@."TQ-294:'4L."TQ-293870@,BPT+#8L."PQ,"PQ,B<I.PH@*@H@
M*B`D8W)O;BT^<G5N*"D["B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U-C:&5D
M=6QE<B]38VAE9'5L97(O8W)O;BYP:'`L=B`Q+C$S+C$P+C,@,C`P-2\Q,"\Q
M."`Q,3HP,3HR-B!J86X@17AP("0*("H*("H@0&%U=&AO<B`@4GEA;B!&;'EN
M;B`\<GEA;D!R>6%N9FQY;FXN8V]M/@H@*B!`875T:&]R("!#:'5C:R!(86=E
M;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'!A8VMA9V4@2&]R9&5?4V-H
M961U;&5R"B`J+PIC;&%S<R!(;W)D95]38VAE9'5L97)?8W)O;B!E>'1E;F1S
M($AO<F1E7U-C:&5D=6QE<B!["@H@("`@=F%R("1?=&%S:W,@/2!A<G)A>2@I
M.PH*("`@("\J*@H@("`@("H@179E<GD@=&EM92!A('1A<VL@:7,@861D960@
M:70@=VEL;"!G970@82!F<F5S:"!U:60@979E;B!I9@H@("`@("H@:6UM961I
M871E;'D@<F5M;W9E9"X*("`@("`J+PH@("`@=F%R("1?8V]U;G1E<B`](#$[
M"@H@("`@9G5N8W1I;VX@861D5&%S:R@D8VUD+"`D<G5L97,I"B`@("!["B`@
M("`@("`@)&1S(#T@)FYE=R!(;W)D95]38VAE9'5L97)?8W)O;D1A=&4H)')U
M;&5S*3L*"B`@("`@("`@)'1H:7,M/E]C;W5N=&5R*RL["@H@("`@("`@("1T
M:&ES+3Y?=&%S:W-;72`]"B`@("`@("`@("`@(&%R<F%Y*`H@("`@("`@("`@
M("`@("`@)W5I9"<@/3X@)'1H:7,M/E]C;W5N=&5R+`H@("`@("`@("`@("`@
M("`@)W)U;&5S)R`]/B`D9',L"B`@("`@("`@("`@("`@("`G8VUD)R`]/B`D
M8VUD"B`@("`@("`@("`@("D["@H@("`@("`@(')E='5R;B`D=&AI<RT^7V-O
M=6YT97(["B`@("!]"@H@("`@9G5N8W1I;VX@<F5M;W9E5&%S:R@D=6ED*0H@
M("`@>PH@("`@("`@("1C;W5N="`](&-O=6YT*"1T:&ES+3Y?=&%S:W,I.PH@
M("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1C;W5N=#L@)&DK*RD@>PH@("`@
M("`@("`@("!I9B`H)'1H:7,M/E]T87-K<ULG=6ED)UT@/3T@)'5I9"D@>PH@
M("`@("`@("`@("`@("`@)&9O=6YD(#T@)&D["B`@("`@("`@("`@("`@("!A
M<G)A>5]S<&QI8V4H)'1H:7,M/E]T87-K<RP@)&DI.PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@,#L*("`@('T*"B`@("!F=6YC=&EO;B!R=6XH*0H@("`@>PH@
M("`@("`@(&EF("@A8V]U;G0H)'1H:7,M/E]T87-K<RDI('L*("`@("`@("`@
M("`@97AI="@B8W)O;F0Z($YO=&AI;F<@=&\@<V-H961U;&4[(&5X:71I;F<N
M7&XB*3L*("`@("`@("!]"@H@("`@("`@('=H:6QE("AT<G5E*2!["B`@("`@
M("`@("`@("1T(#T@=&EM92@I.PH*("`@("`@("`@("`@+R\@0VAE8VL@96%C
M:"!T87-K+@H@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7W1A<VMS(&%S
M("1T87-K*2!["B`@("`@("`@("`@("`@("!I9B`H)'1A<VM;)W)U;&5S)UTM
M/FYO=TUA=&-H97,H*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YR
M=6YC;60H)'1A<VLI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`O+R!786ET('5N=&EL('1H92!N97AT('-E8V]N9"X*
M("`@("`@("`@("`@=VAI;&4@*'1I;64H*2`]/2`D="D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/G-L965P*#$P,#`P,"D["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@<G5N8VUD*"8D=&%S:RD*("`@
M('L*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G2&]R9&5?4V-H961U;&5R
M7T-R;VXZ.G)U;F-M9"@I.B`G("X@)'1A<VM;)V-M9"==("X@)R!R=6X@8GD@
M)R`N("1T87-K6R=U:60G72P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/
M1U])3D9/*3L*("`@("`@("!R971U<FX@<VAE;&Q?97AE8R@D=&%S:ULG8VUD
M)UTI.PH@("`@?0H*?0H*+RHJ"B`J($!P86-K86=E($AO<F1E7U-C:&5D=6QE
M<@H@*B\*8VQA<W,@2&]R9&5?4V-H961U;&5R7V-R;VY$871E('L*"B`@("!V
M87(@)&QE9V%L1&%Y<R`](&%R<F%Y*"=-3TXG+"`G5%5%)RP@)U=%1"<L("=4
M2%4G+"`G1E)))RP@)U-!5"<L("=354XG*3L*"B`@("!V87(@)'-E8SL*("`@
M('9A<B`D;6EN.PH@("`@=F%R("1H;W5R.PH@("`@=F%R("1D87D["B`@("!V
M87(@)&UO;G1H.PH*("`@(&9U;F-T:6]N($AO<F1E7U-C:&5D=6QE<E]C<F]N
M1&%T92@D<F%W*0H@("`@>PH@("`@("`@("1T:&ES+3YP87)S92A3=')I;F<Z
M.G5P<&5R*"1R87<I*3L*("`@('T*"B`@("!F=6YC=&EO;B!N;W=-871C:&5S
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G-C:&5D=6QE9$%T*'1I
M;64H*2D["B`@("!]"@H@("`@9G5N8W1I;VX@<V-H961U;&5D070H)'1S(#T@
M;G5L;"D*("`@('L*("`@("`@("!I9B`H)'1S(#T]/2!N=6QL*2!["B`@("`@
M("`@("`@("1T<R`]('1I;64H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("@D=&AI<RT^;6]N=&A-871C:&5S*"1T<RD@)B8*("`@("`@("`@("`@("`@
M("1T:&ES+3YM;VYT:$UA=&-H97,H)'1S*2`F)@H@("`@("`@("`@("`@("`@
M)'1H:7,M/F1A>4UA=&-H97,H)'1S*2`F)@H@("`@("`@("`@("`@("`@)'1H
M:7,M/FAO=7)-871C:&5S*"1T<RD@)B8*("`@("`@("`@("`@("`@("1T:&ES
M+3YM:6Y-871C:&5S*"1T<RD@)B8*("`@("`@("`@("`@("`@("1T:&ES+3YS
M96--871C:&5S*"1T<RDI.PH@("`@?0H*("`@(&9U;F-T:6]N(&UO;G1H36%T
M8VAE<R@D=',I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YM;VYT:"`]/2`G
M*B<I('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@
M("`@("`D8W5R<F5N=&UO;G1H(#T@)RTG("X@9&%T92@G;B<L("1T<RD@+B`G
M+2<["@H@("`@("`@(')E='5R;B`H8F]O;"ES=')P;W,H)'1H:7,M/FUO;G1H
M+"`D8W5R<F5N=&UO;G1H*3L*("`@('T*"B`@("!F=6YC=&EO;B!D87E-871C
M:&5S*"1T<RD*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3YD87E;
M)W9A;'5E)UTI("8F("1T:&ES+3YD87E;)W9A;'5E)UT@/3T@)RHG*2!["B`@
M("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@)&-U
M<G)E;G1D87EN=6T@/2`G+2<@+B!D871E*"=J)RP@)'1S*2`N("<M)SL*("`@
M("`@("`D8W5R<F5N=&1A>71X="`](%-T<FEN9SHZ=7!P97(H9&%T92@G1"<I
M*3L*"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/F1A>2!A<R`D9&%Y*2!["B`@
M("`@("`@("`@(&EF("A`<W1R<&]S*"1D87E;)VYO="==+"`D8W5R<F5N=&1A
M>71X="D@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D=C$@/2`H0'-T
M<G!O<R@D9&%Y6R=V86QU92==+"`D8W5R<F5N=&1A>6YU;2D@(3T](&9A;'-E
M*3L*("`@("`@("`@("`@("`@("1V,B`]("A`<W1R<&]S*"1D87E;)V%N9"==
M+"`D8W5R<F5N=&1A>71X="D@(3T](&9A;'-E*3L*"B`@("`@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1D87E;)V%N9"==*2`F)B`H)'8Q("8F("1V,BDI('L*
M("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@
M("`@('T@96QS96EF("AE;7!T>2@D9&%Y6R=A;F0G72D@)B8@)'8Q*2!["B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F
M86QS93L*("`@('T*"B`@("!F=6YC=&EO;B!H;W5R36%T8VAE<R@D=',I"B`@
M("!["B`@("`@("`@:68@*"1T:&ES+3YH;W5R(#T]("<J)RD@>PH@("`@("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("1C=7)R96YT
M:&]U<B`]("<M)R`N(&1A=&4H)T<G+"`D=',I("X@)RTG.PH*("`@("`@("!R
M971U<FX@*'-T<G!O<R@D=&AI<RT^:&]U<BP@)&-U<G)E;G1H;W5R*2`A/3T@
M9F%L<V4I.PH@("`@?0H*("`@(&9U;F-T:6]N(&UI;DUA=&-H97,H)'1S*0H@
M("`@>PH@("`@("`@(&EF("@D=&AI<RT^;6EN(#T]("<J)RD@>PH@("`@("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("1C=7)R96YT
M;6EN(#T@)RTG("X@:6YT=F%L*&1A=&4H)VDG+"`D=',I*2`N("<M)SL*"B`@
M("`@("`@<F5T=7)N("AS=')P;W,H)'1H:7,M/FUI;BP@)&-U<G)E;G1M:6XI
M("$]/2!F86QS92D["B`@("!]"@H@("`@9G5N8W1I;VX@<V5C36%T8VAE<R@D
M=',I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YS96,@/3T@)RHG*2!["B`@
M("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@)&-U
M<G)E;G1S96,@/2`G+2<@+B!I;G1V86PH9&%T92@G<R<L("1T<RDI("X@)RTG
M.PH*("`@("`@("!R971U<FX@*'-T<G!O<R@D=&AI<RT^<V5C+"`D8W5R<F5N
M='-E8RD@(3T](&9A;'-E*3L*("`@('T*"B`@("!F=6YC=&EO;B!P87)S92@D
M<W1R*0H@("`@>PH@("`@("`@("1S(#T@87)R87DH*3L*"B`@("`@("`@;&ES
M="@D<ULG<V5C)UTL("1S6R=M:6XG72P@)'-;)VAO=7(G72P@)'-;)V1A>2==
M+"`D<ULG;6]N=&@G72D@/2!P<F5G7W-P;&ET*"=\6UQN7'0@72M\)RP@)'-T
M<BD["@H@("`@("`@(&9O<F5A8V@@*"1S(&%S("1K(#T^("1V*2!["B`@("`@
M("`@("`@(&EF("AS=')P;W,H)'8L("<J)RD@(3T](&9A;'-E*2!["B`@("`@
M("`@("`@("`@("`D<ULD:UT@/2!A<G)A>2@G*B<I.PH@("`@("`@("`@("!]
M(&5L<V5I9B`H(21T:&ES+3YG96YE<F%L;'E$96-E;G13>6YT87@H)'8I*2![
M"B`@("`@("`@("`@("`@("!D:64H(DEL;&5G86P@<WEN=&%X(&EN("<D=B=<
M;B(I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'-;
M)&M=(#T@97AP;&]D92@G+"<L("1S6R1K72D["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(&EF("@D<ULG<V5C)UU;,%T@/3T@)RHG*2!["B`@
M("`@("`@("`@("1T:&ES+3YS96,@/2`G*B<["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F*"1S6R=S96,G
M72D[("1I*RLI('L*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^:7-286YG
M92@D<ULG<V5C)UU;)&E=*2D@>PH@("`@("`@("`@("`@("`@("`@("1S6R=S
M96,G75LD:5T@/2`D=&AI<RT^97AP86YD4F%N9V4H)'1H:7,M/G)A;F=E5F%L
M<R@D<ULG<V5C)UU;)&E=*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)'1H:7,M/G-E8R`]("<M)R`N(&IO:6XH)RTG
M+"`D<ULG<V5C)UTI("X@)RTG.PH@("`@("`@('T*"B`@("`@("`@:68@*"1S
M6R=M:6XG75LP72`]/2`G*B<I('L*("`@("`@("`@("`@)'1H:7,M/FUI;B`]
M("<J)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!F;W(@*"1I(#T@
M,#L@)&D@/"!S:7IE;V8H)'-;)VUI;B==*3L@)&DK*RD@>PH@("`@("`@("`@
M("`@("`@:68@*"1T:&ES+3YI<U)A;F=E*"1S6R=M:6XG75LD:5TI*2!["B`@
M("`@("`@("`@("`@("`@("`@)'-;)VUI;B==6R1I72`]("1T:&ES+3YE>'!A
M;F1286YG92@D=&AI<RT^<F%N9V5686QS*"1S6R=M:6XG75LD:5TI*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI
M<RT^;6EN(#T@)RTG("X@:F]I;B@G+2<L("1S6R=M:6XG72D@+B`G+2<["B`@
M("`@("`@?0H*("`@("`@("!I9B`H)'-;)VAO=7(G75LP72`]/2`G*B<I('L*
M("`@("`@("`@("`@)'1H:7,M/FAO=7(@/2`G*B<["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F*"1S6R=H
M;W5R)UTI.R`D:2LK*2!["B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/FES
M4F%N9V4H)'-;)VAO=7(G75LD:5TI*2!["B`@("`@("`@("`@("`@("`@("`@
M)'-;)VAO=7(G75LD:5T@/2`D=&AI<RT^97AP86YD4F%N9V4H)'1H:7,M/G)A
M;F=E5F%L<R@D<ULG:&]U<B==6R1I72DI.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3YH;W5R(#T@)RTG("X@
M:F]I;B@G+2<L("1S6R=H;W5R)UTI("X@)RTG.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"1S6R=D87DG75LP72`]/2`G*B<I('L*("`@("`@("`@("`@)'1H
M:7,M/F1A>2`]("<J)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!F
M;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'-;)V1A>2==*3L@)&DK*RD@>PH@
M("`@("`@("`@("`@("`@)'1M<"`](&%R<F%Y*"D["B`@("`@("`@("`@("`@
M("!I9B`H*"1C:&%R(#T@)'1H:7,M/FES0V]N9"@D<ULG9&%Y)UU;)&E=*2D@
M(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1C:&%R(#T]
M("<F)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("!L:7-T*"1T;7!;)W9A
M;'5E)UTL("1T;7!;)V%N9"==*2`](&5X<&QO9&4H)&-H87(L("1S6R=D87DG
M75LD:5TI.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/FES
M4F%N9V4H)'1M<%LG86YD)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&UP6R=A;F0G72`]("1T:&ES+3YE>'!A;F1286YG92@D=&AI<RT^
M<F%N9V5686QS*"1T;7!;)V%N9"==*2D["B`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("`@("!L:7-T*"1T;7!;)W9A;'5E)UTL("1T;7!;)VYO="==
M*2`](&5X<&QO9&4H)&-H87(L("1S6R=D87DG75LD:5TI.PH@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H)'1H:7,M/FES4F%N9V4H)'1M<%LG;F]T)UTI
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&UP6R=N;W0G72`]
M("1T:&ES+3YE>'!A;F1286YG92@D=&AI<RT^<F%N9V5686QS*"1T;7!;)VYO
M="==*2D["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1T;7`@/2!A<G)A>2@G=F%L=64G(#T^("1S6R=D87DG75LD
M:5TI.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1S6R=D
M87DG75LD:5T@/2`D=&UP.PH*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^
M:7-286YG92@D<ULG9&%Y)UU;)&E=6R=V86QU92==*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1S6R=D87DG75LD:5U;)W9A;'5E)UT@/2`D=&AI<RT^97AP
M86YD4F%N9V4H)'1H:7,M/G)A;F=E5F%L<R@D<ULG9&%Y)UU;)&E=6R=V86QU
M92==*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("1T:&ES+3YD87D@/2`D<ULG9&%Y)UT["B`@("`@("`@?0H*("`@
M("`@("!I9B`H)'-;)VUO;G1H)UU;,%T@/3T@)RHG*2!["B`@("`@("`@("`@
M("1T:&ES+3YM;VYT:"`]("<J)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'-;)VUO;G1H)UTI.R`D
M:2LK*2!["B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/FES4F%N9V4H)'-;
M)VUO;G1H)UU;)&E=*2D@>PH@("`@("`@("`@("`@("`@("`@("1S6R=M;VYT
M:"==6R1I72`]("1T:&ES+3YE>'!A;F1286YG92@D=&AI<RT^<F%N9V5686QS
M*"1S6R=M;VYT:"==6R1I72DI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1T:&ES+3YM;VYT:"`]("<M)R`N(&IO:6XH
M)RTG+"`D<ULG;6]N=&@G72D@+B`G+2<["B`@("`@("`@?0H@("`@?0H*("`@
M(&9U;F-T:6]N(&ES0V]N9"@D<RD*("`@('L*("`@("`@("!I9B`H<W1R<&]S
M*"1S+"`G)B<I("$]/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@)R8G
M.PH@("`@("`@('T@96QS96EF("AS=')P;W,H)',L("<A)RD@(3T](&9A;'-E
M*2!["B`@("`@("`@("`@(')E='5R;B`G(2<["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@
M("!F=6YC=&EO;B!I<U)A;F=E*"1S*0H@("`@>PH@("`@("`@(')E='5R;B!P
M<F5G7VUA=&-H*"<O7EQW*UPM7'<K+R<L("1S*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!I<T-O;F1286YG92@D<RD*("`@('L*("`@("`@("!R971U<FX@*&ES
M0V]N9"@D<RD@)B8@:7-286YG92@D<RDI.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&ES0V]N9%9A;"@D<RD*("`@('L*("`@("`@("!R971U<FX@*&ES0V]N9"@D
M<RD@)B8@(6ES4F%N9V4H)',I*3L*("`@('T*"B`@("!F=6YC=&EO;B!R86YG
M959A;',H)',I"B`@("!["B`@("`@("`@<F5T=7)N(&5X<&QO9&4H)RTG+"`D
M<RD["B`@("!]"@H@("`@9G5N8W1I;VX@97AP86YD4F%N9V4H)&PL("1H(#T@
M)R<I"B`@("!["B`@("`@("`@+R\@17AP86YD(')A;F=E(&9R;VT@,2TU("T^
M("<M,2TR+3,M-"TU+2<N"B`@("`@("`@:68@*&ES7V%R<F%Y*"1L*2D@>PH@
M("`@("`@("`@("`D:"`]("1L6S%=.PH@("`@("`@("`@("`D;"`]("1L6S!=
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES+3YI<T1I9VET*"1L*2D@
M>PH@("`@("`@("`@("!I9B`H(21T:&ES+3YI<T1I9VET*"1H*2D@>PH@("`@
M("`@("`@("`@("`@9&EE*"));G9A;&ED('9A;'5E("<D:"<@:6X@<F%N9V4@
M)R1L+21H)R(I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!#=7)R
M96YT;'D@=&AE<F4@:7,@;F\@<&]S<VEB;&4@<F5A<V]N('1O(&YE960@=&\@
M9&\@80H@("`@("`@("`@("`O+R!R86YG92!B97EO;F0@,"TU.2!F;W(@86YY
M=&AI;F<N"B`@("`@("`@("`@(&EF("@D;"`\(#`I('L*("`@("`@("`@("`@
M("`@("1L(#T@,#L*("`@("`@("`@("`@?2!E;'-E:68@*"1L(#X@-3DI('L*
M("`@("`@("`@("`@("`@("1L(#T@-3D["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@(&EF("@D:"`\(#`I('L*("`@("`@("`@("`@("`@("1H(#T@,#L*
M("`@("`@("`@("`@?2!E;'-E:68@*"1H(#X@-3DI('L*("`@("`@("`@("`@
M("`@("1H(#T@-3D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D
M;"`^("1H*2!["B`@("`@("`@("`@("`@("`D=&UP(#T@)&P["B`@("`@("`@
M("`@("`@("`D;"`]("1H.PH@("`@("`@("`@("`@("`@)&@@/2`D=&UP.PH@
M("`@("`@("`@("`@("`@=6YS970H)'1M<"D["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("\O($9O<B!S;VUE(')E87-O;B!R86YG92@I(&1O97-N)W0@
M=V]R:R!W+V\@=&AE(&5X<&QI8VET"B`@("`@("`@("`@("\O(&EN='9A;"@I
M(&-A;&QS+@H@("`@("`@("`@("!R971U<FX@)RTG("X@:F]I;B@G+2<L(')A
M;F=E*&EN='9A;"@D;"DL(&EN='9A;"@D:"DI*2`N("<M)SL*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`O+R!);G9A;&ED+@H@("`@("`@("`@("!D
M:64H(DEN=F%L:60@=F%L=64@)R1L)R!I;B!R86YG92`G)&PM)&@G(BD["B`@
M("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&1A>59A;'5E*"1S*0H@("`@
M>PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1T:&ES+3YL96=A
M;$1A>7,I.R`D:2LK*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^;&5G86Q$
M87ES6R1I72`]/2`D<RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@+3$["B`@
M("!]"@H@("`@9G5N8W1I;VX@:7-$:6=I="@D<RD*("`@('L*("`@("`@("!R
M971U<FX@<')E9U]M871C:"@G+UY<9"LD+R<L("1S*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!I<T%L<&AA*"1S*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^:7-,96=A;$1A>2@D<RD["B`@("!]"@H@("`@9G5N8W1I;VX@:7-,96=A
M;$1A>2@D<RD*("`@('L*("`@("`@("!R971U<FX@:6Y?87)R87DH)',L("1T
M:&ES+3YL96=A;$1A>7,I.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E;F5R86QL
M>41E8V5N=%-Y;G1A>"@D<RD*("`@('L*("`@("`@("!R971U<FX@*"1S(#T]
M("<J)R!\?`H@("`@("`@("`@("`@("`@<')E9U]M871C:"@G+UY<9"LH+5QD
M*RD_*%LA)EU;02U:7"I=*R@M6T$M6EPJ72LI/RD_*"Q<9"LH+5QD*RD_*%LA
M)EU;02U:7"I=*R@M6T$M6EPJ72LI/RD_*2HD+R<L("1S*2D["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92](96QP+G!H<```````````````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`S-C4Q-R`Q,#4Q-30S,S<T,"`P,C`W-C$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"B\J*@H@
M*B!287<@:&5L<"!I;B!T:&4@<W1R:6YG+@H@*B\*9&5F:6YE*"=(14Q07U-/
M55)#15]205<G+"`P*3L*"B\J*@H@*B!(96QP('1E>'0@:7,@:6X@82!F:6QE
M+@H@*B\*9&5F:6YE*"=(14Q07U-/55)#15]&24Q%)RP@,2D["@HO*BH*("H@
M5&AE($AE;'`Z.B!C;&%S<R!P<F]V:61E<R!A;B!I;G1E<F9A8V4@=&\@=&AE
M(&]N;&EN92!H96QP('-U8G-Y<W1E;2X*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`L=B`Q+C8X+C@N,3@@,C`P-B\P,R\P
M,B`P-3HR-SHS-2!S;'5S87)Z($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY
M+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J
M($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]&<F%M97=O
M<FL*("HO"F-L87-S($AE;'`@>PH*("`@("\J*@H@("`@("H@2&%N9&QE(&9O
M<B!T:&4@6$U,('!A<G-E<B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'9A<B!R
M97-O=7)C90H@("`@("HO"B`@("!V87(@)%]P87)S97(@/2`P.PH*("`@("\J
M*@H@("`@("H@4W1R:6YG(&)U9F9E<B!T;R!H;VQD('1H92!834P@:&5L<"!S
M;W5R8V4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1?8G5F9F5R(#T@)R<["@H@("`@+RHJ"B`@("`@*B!3=')I;F<@8V]N
M=&%I;FEN9R!T:&4@240@;V8@=&AE(')E<75E<W1E9"!H96QP(&5N=')Y+@H@
M("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W)E
M<45N=')Y(#T@)R<["@H@("`@+RHJ"B`@("`@*B!3=')I;F<@8V]N=&%I;FEN
M9R!T:&4@240@;V8@=&AE(&-U<G)E;G0@:&5L<"!E;G1R>2X*("`@("`J"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]C=7)%;G1R>2`]
M("<G.PH*("`@("\J*@H@("`@("H@4W1R:6YG(&-O;G1A:6YI;F<@=&AE(&9O
M<FUA='1E9"!O=71P=70N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@
M("`J+PH@("`@=F%R("1?;W5T<'5T(#T@)R<["@H@("`@+RHJ"B`@("`@*B!"
M;V]L96%N(&EN9&EC871I;F<@=VAE=&AE<B!W92=R92!I;G-I9&4@82`\:&5L
M<#X@8FQO8VLN"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*
M("`@('9A<B`D7VEN2&5L<"`](&9A;'-E.PH*("`@("\J*@H@("`@("H@0F]O
M;&5A;B!I;F1I8V%T:6YG('=H971H97(@=V4G<F4@:6YS:61E('1H92!R97%U
M97-T960@8FQO8VLN"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@
M*B\*("`@('9A<B`D7VEN0FQO8VL@/2!F86QS93L*"B`@("`O*BH*("`@("`J
M($)O;VQE86X@:6YD:6-A=&EN9R!W:&5T:&5R('=E)W)E(&EN<VED92!A(#QT
M:71L93X@8FQO8VLN"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@
M*B\*("`@('9A<B`D7VEN5&ET;&4@/2!F86QS93L*"B`@("`O*BH*("`@("`J
M($AA<V@@8V]N=&%I;FEN9R!A;B!I;F1E>"!O9B!A;&P@;V8@=&AE(&AE;'`@
M96YT<FEE<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@
M('9A<B`D7V5N=')I97,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@4W1R
M:6YG(&-O;G1A:6YI;F<@=&AE(&-H87)S970@;V8@=&AE(%A-3"!D871A('-O
M=7)C92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)%]C:&%R<V5T(#T@)VES;RTX.#4Y+3$G.PH*("`@("\J*@H@("`@("H@
M2&%S:"!O9B!U<V5R+61E9FEN960@9G5N8W1I;VX@:&%N9&QE<G,@9F]R('1H
M92!834P@96QE;65N=',N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)%]H86YD;&5R<R`](&%R<F%Y*`H@("`@("`@("=H96QP
M)R`@("`@/3X@("=?:&5L<$AA;F1L97(G+`H@("`@("`@("=E;G1R>2<@("`@
M/3X@("=?96YT<GE(86YD;&5R)RP*("`@("`@("`G=&ET;&4G("`@(#T^("`G
M7W1I=&QE2&%N9&QE<B<L"B`@("`@("`@)VAE861I;F<G("`]/B`@)U]H96%D
M:6YG2&%N9&QE<B<L"B`@("`@("`@)W!A<F$G("`@("`]/B`@)U]P87)A2&%N
M9&QE<B<L"B`@("`@("`@)W)E9B<@("`@("`]/B`@)U]R969(86YD;&5R)RP*
M("`@("`@("`G97)E9B<@("`@(#T^("`G7V5R969(86YD;&5R)RP*("`@("`@
M("`G:')E9B<@("`@(#T^("`G7VAR969(86YD;&5R)RP*("`@("`@("`G8B<@
M("`@("`@(#T^("`G7V)(86YD;&5R)RP*("`@("`@("`G:2<@("`@("`@(#T^
M("`G7VE(86YD;&5R)RP*("`@("`@("`G<')E)R`@("`@(#T^("`G7W!R94AA
M;F1L97(G+`H@("`@("`@("=T:7`G("`@("`@/3X@("=?=&EP2&%N9&QE<B<L
M"B`@("`@("`@)W=A<FXG("`@("`]/B`@)U]W87)N2&%N9&QE<B<*("`@("D[
M"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("H*("`@("`J($!P
M87)A;2!I;G1E9V5R("1S;W5R8V4@(%1H92!S;W5R8V4@;V8@=&AE(%A-3"!H
M96QP(&1A=&$L(&)A<V5D(&]N('1H90H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@2$5,4%]33U520T5?*B!C;VYS=&%N=',N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1A<F<@("`@("!3;W5R8V4M9&5P96YD96YT(&%R9W5M96YT
M(&9O<B!T:&ES($AE;'`*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M(&EN<W1A;F-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!(96QP*"1S;W5R8V4L
M("1A<F<@/2!N=6QL*0H@("`@>PH@("`@("`@(&=L;V)A;"`D;&%N9W5A9V4L
M("1N;',["@H@("`@("`@(&EF("@A571I;#HZ97AT96YS:6]N17AI<W1S*"=X
M;6PG*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH4$5!4CHZ<F%I<V5%
M<G)O<B@G5&AE(%A-3"!F=6YC=&EO;G,@87)E(&YO="!A=F%I;&%B;&4N(%)E
M8G5I;&0@4$A0('=I=&@@+2UW:71H+7AM;"XG*2P@7U]&24Q%7U\L(%]?3$E.
M15]?+"!F86QS92D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V-H87)S
M970@/2!I<W-E="@D;FQS6R=C:&%R<V5T<R==6R1L86YG=6%G95TI(#\@)&YL
M<ULG8VAA<G-E=',G75LD;&%N9W5A9V5=(#H@)TE33RTX.#4Y+3$G.PH*("`@
M("`@("`O*B!0;W!U;&%T92`D=&AI<RT^7V)U9F9E<B!B87-E9"!O;B`D<V]U
M<F-E+B`J+PH@("`@("`@('-W:71C:"`H)'-O=7)C92D@>PH@("`@("`@(&-A
M<V4@2$5,4%]33U520T5?4D%7.@H@("`@("`@("`@("`D=&AI<RT^7V)U9F9E
M<B`]("1A<F<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E($A%
M3%!?4T]54D-%7T9)3$4Z"B`@("`@("`@("`@(&EF("A`9FEL95]E>&ES=',H
M)&%R9ULP72D@)B8@0&9I;&5S:7IE*"1A<F=;,%TI*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7V)U9F9E<B`](&9I;&5?9V5T7V-O;G1E;G1S*"1A<F=;
M,%TI.PH@("`@("`@("`@("!](&5L<V5I9B`H0&9I;&5?97AI<W1S*"1A<F=;
M,5TI("8F($!F:6QE<VEZ92@D87)G6S%=*2D@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]B=69F97(@/2!F:6QE7V=E=%]C;VYT96YT<R@D87)G6S%=*3L*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M8G5F9F5R(#T@)R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("1T:&ES+3Y?8G5F9F5R
M(#T@)R<["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($=E;F5R871E<R!T:&4@2%1-3"!L:6YK('1H870@=VEL
M;"!P;W`@=7`@82!H96QP('=I;F1O=R!F;W(@=&AE"B`@("`@*B!R97%U97-T
M960@=&]P:6,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;6]D=6QE
M("!4:&4@;F%M92!O9B!T:&4@8W5R<F5N="!(;W)D92!M;V1U;&4N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1T;W!I8R`@(%1H92!H96QP('1O<&EC('1O(&)E
M(&1I<W!L87EE9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M($A434P@=&\@8W)E871E('1H92!H96QP(&QI;FLN"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&QI;FLH)&UO9'5L92P@)'1O<&EC*0H@("`@>PH@("`@("`@(&=L
M;V)A;"`D8V]N9BP@)')E9VES=')Y+"`D8G)O=W-E<CL*"B`@("`@("`@:68@
M*"%(;W)D93HZ<VAO=U-E<G9I8V4H)VAE;'`G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)R9N8G-P.R<["B`@("`@("`@?0H*("`@("`@("!I9B`H)&)R;W=S
M97(M/FAA<T9E871U<F4H)VIA=F%S8W)I<'0G*2D@>PH@("`@("`@("`@("!(
M;W)D93HZ861D4V-R:7!T1FEL92@G<&]P=7`N:G,G+"`G:&]R9&4G*3L*("`@
M("`@("!]"@H@("`@("`@("1U<FP@/2!(;W)D93HZ=7)L*"1R96=I<W1R>2T^
M9V5T*"=W96)R;V]T)RP@)VAO<F1E)RD@+B`G+W-E<G9I8V5S+VAE;'`O)RP@
M=')U92D["B`@("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L
M+"!A<G)A>2@G;6]D=6QE)R`]/B`D;6]D=6QE+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1O<&EC)R`]/B`D=&]P
M:6,I*3L*("`@("`@("`D:'1M;"`]($AO<F1E.CIL:6YK*"1U<FPL(%\H(DAE
M;'`B*2P@)R<L("=H;W)D96AE;'!W:6XG+"`G<&]P=7`H=&AI<RYH<F5F*3L@
M<F5T=7)N(&9A;'-E.R<I.PH*("`@("`@("!R971U<FX@)&AT;6P@+B!(;W)D
M93HZ:6UG*"=H96QP+G!N9R<L(%\H(DAE;'`B*2P@)W=I9'1H/2(Q-B(@:&5I
M9VAT/2(Q-B(G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`N
M("<\+V$^)SL*("`@('T*"B`@("`O*BH*("`@("`J($-L96%N<R!U<"!T:&4@
M2&5L<"!C;&%S<R!R97-O=7)C97,N"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!2971U<FYS('1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@9F%I
M;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@8VQE86YU<"@I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]B=69F97(@/2`G)SL*("`@("`@("!R971U<FX@>&UL
M7W!A<G-E<E]F<F5E*"1T:&ES+3Y?<&%R<V5R*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($QO;VMS('5P('1H92!R97%U97-T960@96YT<GD@:6X@=&AE(%A-
M3"!H96QP(&)U9F9E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1E
M;G1R>2`@4W1R:6YG(&-O;G1A:6YI;F<@=&AE(&5N=')Y($E$+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!L;V]K=7`H)&5N=')Y*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?;W5T<'5T(#T@)R<["B`@("`@("`@)'1H:7,M/E]R97%%;G1R>2`]
M(%-T<FEN9SHZ=7!P97(H)&5N=')Y*3L*("`@("`@("!I9B`H(21T:&ES+3Y?
M<&%R<V5R*2!["B`@("`@("`@("`@("1T:&ES+3Y?:6YI="@I.PH@("`@("`@
M('T*("`@("`@("!X;6Q?<&%R<V4H)'1H:7,M/E]P87)S97(L("1T:&ES+3Y?
M8G5F9F5R+"!T<G5E*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M82!H87-H(&]F(&%L;"!O9B!T:&4@=&]P:6-S(&EN('1H:7,@:&5L<"!B=69F
M97(N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@2&%S:"!O9B!A;&P@
M;V8@=&AE('1O<&EC<R!I;B!T:&ES(&)U9F9E<BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@=&]P:6-S*"D*("`@('L*("`@("`@("!I9B`H(21T:&ES+3Y?<&%R
M<V5R*2!["B`@("`@("`@("`@("1T:&ES+3Y?:6YI="@I.PH@("`@("`@('T*
M("`@("`@("!X;6Q?<&%R<V4H)'1H:7,M/E]P87)S97(L("1T:&ES+3Y?8G5F
M9F5R+"!T<G5E*3L*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?96YT<FEE<SL*
M("`@('T*"B`@("`O*BH*("`@("`J($1I<W!L87D@=&AE(&-O;G1E;G1S(&]F
M('1H92!F;W)M871T960@;W5T<'5T(&)U9F9E<BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@9&ES<&QA>2@I"B`@("!["B`@("`@("`@96-H;R`D=&AI<RT^7V]U
M='!U=#L*("`@('T*"B`@("`O*BH*("`@("`J($EN:71I86QZ97,@=&AE(%A-
M3"!P87)S97(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!2971U<FYS('1R=64@;VX@<W5C
M8V5S<RP@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M7VEN:70H*0H@("`@>PH@("`@("`@("\J($-R96%T92!A(&YE=R!P87)S97(@
M86YD('-E="!I=',@9&5F875L="!P<F]P97)T:65S+B`J+PH@("`@("`@("1T
M:&ES+3Y?<&%R<V5R(#T@>&UL7W!A<G-E<E]C<F5A=&4H*3L*("`@("`@("!X
M;6Q?<V5T7V]B:F5C="@D=&AI<RT^7W!A<G-E<BP@)'1H:7,I.PH@("`@("`@
M('AM;%]P87)S97)?<V5T7V]P=&EO;B@D=&AI<RT^7W!A<G-E<BP@6$U,7T]0
M5$E/3E]#05-%7T9/3$1)3D<L(&9A;'-E*3L*("`@("`@("!X;6Q?<V5T7V5L
M96UE;G1?:&%N9&QE<B@D=&AI<RT^7W!A<G-E<BP@)U]S=&%R=$5L96UE;G0G
M+"`G7V5N9$5L96UE;G0G*3L*("`@("`@("!X;6Q?<V5T7V-H87)A8W1E<E]D
M871A7VAA;F1L97(H)'1H:7,M/E]P87)S97(L("=?9&5F875L=$AA;F1L97(G
M*3L*"B`@("`@("`@<F5T=7)N("@D=&AI<RT^7W!A<G-E<B`A/2`P*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%5S97(M9&5F:6YE9"!F=6YC=&EO;B!C86QL
M8F%C:R!F;W(@<W1A<G0@96QE;65N=',N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="`D<&%R<V5R
M("!(86YD;&4@=&\@=&AE('!A<G-E<B!I;G-T86YC92X*("`@("`J($!P87)A
M;2!S=')I;F<@)&YA;64@("`@5&AE(&YA;64@;V8@=&AI<R!834P@96QE;65N
M="X*("`@("`J($!P87)A;2!A<G)A>2`D871T<G,@("`@3&ES="!O9B!T:&ES
M(&5L96UE;G0G<R!A='1R:6)U=&5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M<W1A<G1%;&5M96YT*"1P87)S97(L("1N86UE+"`D871T<G,I"B`@("!["B`@
M("`@("`@+RH@0V%L;"!T:&4@87-S:6=N960@:&%N9&QE<B!F;W(@=&AI<R!E
M;&5M96YT+"!I9B!O;F4@:7,*("`@("`@("`@*B!A=F%I;&%B;&4N("HO"B`@
M("`@("`@:68@*&EN7V%R<F%Y*"1N86UE+"!A<G)A>5]K97ES*"1T:&ES+3Y?
M:&%N9&QE<G,I*2D@>PH@("`@("`@("`@("!C86QL7W5S97)?9G5N8RAA<G)A
M>2@F)'1H:7,L("1T:&ES+3Y?:&%N9&QE<G-;)&YA;65=*2P@=')U92P@)&%T
M=')S*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!5<V5R+61E
M9FEN960@9G5N8W1I;VX@8V%L;&)A8VL@9F]R(&5N9"!E;&5M96YT<RX*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@;V)J96-T("1P87)S97(@($AA;F1L92!T;R!T:&4@<&%R<V5R(&EN<W1A
M;F-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("!4:&4@;F%M92!O
M9B!T:&ES(%A-3"!E;&5M96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!?96YD
M16QE;65N="@D<&%R<V5R+"`D;F%M92D*("`@('L*("`@("`@("`O*B!#86QL
M('1H92!A<W-I9VYE9"!H86YD;&5R(&9O<B!T:&ES(&5L96UE;G0L(&EF(&]N
M92!I<R!A=F%I;&%B;&4N("HO"B`@("`@("`@:68@*&EN7V%R<F%Y*"1N86UE
M+"!A<G)A>5]K97ES*"1T:&ES+3Y?:&%N9&QE<G,I*2D@>PH@("`@("`@("`@
M("!C86QL7W5S97)?9G5N8RAA<G)A>2@F)'1H:7,L("1T:&ES+3Y?:&%N9&QE
M<G-;)&YA;65=*2P@9F%L<V4I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%5S97(M9&5F:6YE9"!F=6YC=&EO;B!C86QL8F%C:R!F;W(@8VAA
M<F%C=&5R(&1A=&$N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="`D<&%R<V5R("!(86YD;&4@=&\@
M=&AE('!A<G-E<B!I;G-T86YC92X*("`@("`J($!P87)A;2!S=')I;F<@)&1A
M=&$@("`@4W1R:6YG(&]F(&-H87)A8W1E<B!D871A+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?9&5F875L=$AA;F1L97(H)'!A<G-E<BP@)&1A=&$I"B`@("![
M"B`@("`@("`@)&1A=&$@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1D871A
M+"!V97)S:6]N7V-O;7!A<F4H>F5N9%]V97)S:6]N*"DL("<R)RP@)SPG*2`_
M("1T:&ES+3Y?8VAA<G-E="`Z("=55$8M."<I.PH@("`@("`@(&EF("@D=&AI
M<RT^7VEN5&ET;&4I('L*("`@("`@("`@("`@)'1H:7,M/E]E;G1R:65S6R1T
M:&ES+3Y?8W5R16YT<GE=("X]("1D871A.PH@("`@("`@('T*("`@("`@("!I
M9B`H)'1H:7,M/E]I;DAE;'`@)B8@)'1H:7,M/E]I;D)L;V-K*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?;W5T<'5T("X](&AT;6QS<&5C:6%L8VAA<G,H)&1A
M=&$I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%A-3"!E;&5M
M96YT(&AA;F1L97(@9F]R('1H92`\:&5L<#X@=&%G+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N
M("1S=&%R=%1A9R`@0F]O;&5A;B!I;F1I8V%T:6YG('=H971H97(@=&AI<R!I
M;G-T86YC92!I<R!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M('-T87)T('1A9RX*("`@("`J($!P87)A;2!A<G)A>2`D871T<G,@("`@("`@
M061D:71I;VYA;"!E;&5M96YT(&%T=')I8G5T97,@*$YO="!U<V5D*2X*("`@
M("`J+PH@("`@9G5N8W1I;VX@7VAE;'!(86YD;&5R*"1S=&%R=%1A9RP@)&%T
M=')S(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^7VEN2&5L<"`]
M("1S=&%R=%1A9R`_("!T<G5E(#H@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!834P@96QE;65N="!H86YD;&5R(&9O<B!T:&4@/&5N=')Y/B!T86<N
M"B`@("`@*B!!='1R:6)U=&5S.B!I9`H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1S=&%R=%1A
M9R`@0F]O;&5A;B!I;F1I8V%T:6YG('=H971H97(@=&AI<R!I;G-T86YC92!I
M<R!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@('-T87)T('1A
M9RX*("`@("`J($!P87)A;2!A<G)A>2`D871T<G,@("`@("`@061D:71I;VYA
M;"!E;&5M96YT(&%T=')I8G5T97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]E
M;G1R>4AA;F1L97(H)'-T87)T5&%G+"`D871T<G,@/2!A<G)A>2@I*0H@("`@
M>PH@("`@("`@(&EF("@A)'-T87)T5&%G*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?:6Y";&]C:R`](&9A;'-E.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1I9"`](%-T<FEN9SHZ=7!P97(H)&%T=')S6R=I9"==*3L*("`@("`@
M("`@("`@)'1H:7,M/E]C=7)%;G1R>2`]("1I9#L*("`@("`@("`@("`@)'1H
M:7,M/E]E;G1R:65S6R1I9%T@/2`G)SL*("`@("`@("`@("`@)'1H:7,M/E]I
M;D)L;V-K(#T@*"1I9"`]/2`D=&AI<RT^7W)E<45N=')Y*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!834P@96QE;65N="!H86YD;&5R(&9O
M<B!T:&4@/'1I=&QE/B!T86<N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'-T87)T5&%G("!"
M;V]L96%N(&EN9&EC871I;F<@=VAE=&AE<B!T:&ES(&EN<W1A;F-E(&ES(&$*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1A<G0@=&%G+@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1A='1R<R`@("`@("!!9&1I=&EO;F%L(&5L
M96UE;G0@871T<FEB=71E<R`H3F]T('5S960I+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?=&ET;&5(86YD;&5R*"1S=&%R=%1A9RP@)&%T=')S(#T@87)R87DH
M*2D*("`@('L*("`@("`@("`D=&AI<RT^7VEN5&ET;&4@/2`D<W1A<G1486<[
M"B`@("`@("`@:68@*"1T:&ES+3Y?:6Y(96QP("8F("1T:&ES+3Y?:6Y";&]C
M:RD@>PH@("`@("`@("`@("`D=&AI<RT^7V]U='!U="`N/2`D<W1A<G1486<@
M/R`G/&@Q/B<@.B`G/"]H,3XG.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%A-3"!E;&5M96YT(&AA;F1L97(@9F]R('1H92`\:&5A9&EN9SX@
M=&%G+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!P87)A;2!B;V]L96%N("1S=&%R=%1A9R`@0F]O;&5A;B!I;F1I8V%T
M:6YG('=H971H97(@=&AI<R!I;G-T86YC92!I<R!A"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@('-T87)T('1A9RX*("`@("`J($!P87)A;2`@
M87)R87D@)&%T=')S("`@("`@061D:71I;VYA;"!E;&5M96YT(&%T=')I8G5T
M97,@*$YO="!U<V5D*2X*("`@("`J+PH@("`@9G5N8W1I;VX@7VAE861I;F=(
M86YD;&5R*"1S=&%R=%1A9RP@)&%T=')S(#T@87)R87DH*2D*("`@('L*("`@
M("`@("!I9B`H)'1H:7,M/E]I;DAE;'`@)B8@)'1H:7,M/E]I;D)L;V-K*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T("X]("1S=&%R=%1A9R`_("<\
M:#(^)R`Z("<\+V@R/B<["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@6$U,(&5L96UE;G0@:&%N9&QE<B!F;W(@=&AE(#QP87)A/B!T86<N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)'-T87)T5&%G("!";V]L96%N(&EN9&EC871I;F<@=VAE
M=&AE<B!T:&ES(&EN<W1A;F-E(&ES(&$*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<W1A<G0@=&%G+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A
M='1R<R`@("`@("!!9&1I=&EO;F%L(&5L96UE;G0@871T<FEB=71E<R`H3F]T
M('5S960I+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<&%R84AA;F1L97(H)'-T
M87)T5&%G+"`D871T<G,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("@D
M=&AI<RT^7VEN2&5L<"`F)B`D=&AI<RT^7VEN0FQO8VLI('L*("`@("`@("`@
M("`@)'1H:7,M/E]O=71P=70@+CT@)'-T87)T5&%G(#\@)SQP/B<@.B`G/"]P
M/B<["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@6$U,(&5L96UE
M;G0@:&%N9&QE<B!F;W(@=&AE(#QR968^('1A9RX*("`@("`J(%)E<75I<F5D
M(&%T=')I8G5T97,Z($5.5%)9+"!-3T153$4*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<W1A
M<G1486<@($)O;VQE86X@:6YD:6-A=&EN9R!W:&5T:&5R('1H:7,@:6YS=&%N
M8V4@:7,@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!S=&%R
M="!T86<N"B`@("`@*B!`<&%R86T@87)R87D@)&%T=')S("`@("`@($%D9&ET
M:6]N86P@96QE;65N="!A='1R:6)U=&5S+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?<F5F2&%N9&QE<B@D<W1A<G1486<L("1A='1R<R`](&%R<F%Y*"DI"B`@
M("!["B`@("`@("`@:68@*"1T:&ES+3Y?:6Y(96QP("8F("1T:&ES+3Y?:6Y"
M;&]C:RD@>PH@("`@("`@("`@("!I9B`H)'-T87)T5&%G("8F(&ES<V5T*"1A
M='1R<ULG;6]D=6QE)UTI("8F(&ES<V5T*"1A='1R<ULG96YT<GDG72DI('L*
M("`@("`@("`@("`@("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H2&]R
M9&4Z.G-E;&95<FPH*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)W-H;W<G(#T^("=E;G1R>2<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M;V1U
M;&4G(#T^("1A='1R<ULG;6]D=6QE)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T;W!I8R<@(#T^("1A='1R
M<ULG96YT<GDG72DI.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O=71P=70@
M+CT@2&]R9&4Z.FQI;FLH)'5R;"D["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7V]U='!U="`N/2`G/"]A/B<["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!834P@
M96QE;65N="!H86YD;&5R(&9O<B!T:&4@/&5R968^('1A9RX*("`@("`J(%)E
M<75I<F5D(&5L96UE;G1S.B!54DP*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<W1A<G1486<@
M($)O;VQE86X@:6YD:6-A=&EN9R!W:&5T:&5R('1H:7,@:6YS=&%N8V4@:7,@
M80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!S=&%R="!T86<N
M"B`@("`@*B!`<&%R86T@87)R87D@)&%T=')S("`@("`@($%D9&ET:6]N86P@
M96QE;65N="!A='1R:6)U=&5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?97)E
M9DAA;F1L97(H)'-T87)T5&%G+"`D871T<G,@/2!A<G)A>2@I*0H@("`@>PH@
M("`@("`@(&EF("@D=&AI<RT^7VEN2&5L<"`F)B`D=&AI<RT^7VEN0FQO8VLI
M('L*("`@("`@("`@("`@:68@*"1S=&%R=%1A9RD@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]O=71P=70@+CT@2&]R9&4Z.FQI;FLH)&%T=')S6R=U<FPG
M72P@;G5L;"P@)R<L("=?8FQA;FLG*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T("X]("<\+V$^)SL*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%A-
M3"!E;&5M96YT(&AA;F1L97(@9F]R('1H92`\:')E9CX@=&%G+@H@("`@("H@
M4F5Q=6ER960@96QE;65N=',Z('5R;"P@87!P+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1S
M=&%R=%1A9R`@0F]O;&5A;B!I;F1I8V%T:6YG('=H971H97(@=&AI<R!I;G-T
M86YC92!I<R!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@('-T
M87)T('1A9RX*("`@("`J($!P87)A;2!A<G)A>2`D871T<G,@("`@("`@061D
M:71I;VYA;"!E;&5M96YT(&%T=')I8G5T97,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]H<F5F2&%N9&QE<B@D<W1A<G1486<L("1A='1R<R`](&%R<F%Y*"DI
M"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?:6Y(96QP("8F("1T:&ES+3Y?
M:6Y";&]C:RD@>PH@("`@("`@("`@("!I9B`H)'-T87)T5&%G*2!["B`@("`@
M("`@("`@("`@("!G;&]B86P@)')E9VES=')Y.PH@("`@("`@("`@("`@("`@
M)'5R;"`]($AO<F1E.CIU<FPH)')E9VES=')Y+3YG970H)W=E8G)O;W0G+"`D
M871T<G-;)V%P<"==*2`N("<O)R`N("1A='1R<ULG=7)L)UTI.PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@2&]R9&4Z.FQI;FLH)'5R;"P@
M;G5L;"P@)R<L("=?8FQA;FLG*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T("X]("<\+V$^)SL*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%A-3"!E
M;&5M96YT(&AA;F1L97(@9F]R('1H92`F;'0[8B9G=#L@=&%G+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!B
M;V]L96%N("1S=&%R=%1A9R`@0F]O;&5A;B!I;F1I8V%T:6YG('=H971H97(@
M=&AI<R!I;G-T86YC92!I<R!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@('-T87)T('1A9RX*("`@("`J($!P87)A;2!A<G)A>2`D871T<G,@
M("`@("`@061D:71I;VYA;"!E;&5M96YT(&%T=')I8G5T97,@*$YO="!U<V5D
M*2X*("`@("`J+PH@("`@9G5N8W1I;VX@7V)(86YD;&5R*"1S=&%R=%1A9RP@
M)&%T=')S(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]I
M;DAE;'`@)B8@)'1H:7,M/E]I;D)L;V-K*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?;W5T<'5T("X]("1S=&%R=%1A9R`_("<\<W1R;VYG/B<@.B`G/"]S=')O
M;F<^)SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!834P@96QE
M;65N="!H86YD;&5R(&9O<B!T:&4@)FQT.VDF9W0[('1A9RX*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D<W1A<G1486<@($)O;VQE86X@:6YD:6-A=&EN9R!W:&5T:&5R('1H
M:7,@:6YS=&%N8V4@:7,@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("!S=&%R="!T86<N"B`@("`@*B!`<&%R86T@87)R87D@)&%T=')S("`@
M("`@($%D9&ET:6]N86P@96QE;65N="!A='1R:6)U=&5S+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?:4AA;F1L97(H)'-T87)T5&%G+"`D871T<G,@/2!A<G)A
M>2@I*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7VEN2&5L<"`F)B`D=&AI
M<RT^7VEN0FQO8VLI('L*("`@("`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@
M)'-T87)T5&%G(#\@)SQE;3XG(#H@)SPO96T^)SL*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!834P@96QE;65N="!H86YD;&5R(&9O<B!T:&4@
M)FQT.W!R929G=#L@=&%G+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1S=&%R=%1A9R`@0F]O
M;&5A;B!I;F1I8V%T:6YG('=H971H97(@=&AI<R!I;G-T86YC92!I<R!A"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@('-T87)T('1A9RX*("`@
M("`J($!P87)A;2!A<G)A>2`D871T<G,@("`@("`@061D:71I;VYA;"!E;&5M
M96YT(&%T=')I8G5T97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P<F5(86YD
M;&5R*"1S=&%R=%1A9RP@)&%T=')S(#T@87)R87DH*2D*("`@('L*("`@("`@
M("!I9B`H)'1H:7,M/E]I;DAE;'`@)B8@)'1H:7,M/E]I;D)L;V-K*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?;W5T<'5T("X]("1S=&%R=%1A9R`_("<\<')E
M/B<@.B`G/"]P<F4^)SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!834P@96QE;65N="!H86YD;&5R(&9O<B!T:&4@/'1I<#X@=&%G+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A
M;2!B;V]L96%N("1S=&%R=%1A9R`@0F]O;&5A;B!I;F1I8V%T:6YG('=H971H
M97(@=&AI<R!I;G-T86YC92!I<R!A"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@('-T87)T('1A9RX*("`@("`J($!P87)A;2!A<G)A>2`D871T
M<G,@("`@("`@061D:71I;VYA;"!E;&5M96YT(&%T=')I8G5T97,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]T:7!(86YD;&5R*"1S=&%R=%1A9RP@)&%T=')S
M(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]I;DAE;'`@
M)B8@)'1H:7,M/E]I;D)L;V-K*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T
M<'5T("X]("1S=&%R=%1A9R`_("<\96T@8VQA<W,](FAE;'!4:7`B/B<@.B`G
M/"]E;3XG.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%A-3"!E
M;&5M96YT(&AA;F1L97(@9F]R('1H92`\=V%R;CX@=&%G+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!B;V]L
M96%N("1S=&%R=%1A9R`@0F]O;&5A;B!I;F1I8V%T:6YG('=H971H97(@=&AI
M<R!I;G-T86YC92!I<R!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@('-T87)T('1A9RX*("`@("`J($!P87)A;2!A<G)A>2`D871T<G,@("`@
M("`@061D:71I;VYA;"!E;&5M96YT(&%T=')I8G5T97,N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]W87)N2&%N9&QE<B@D<W1A<G1486<L("1A='1R<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?:6Y(96QP("8F("1T
M:&ES+3Y?:6Y";&]C:RD@>PH@("`@("`@("`@("`D=&AI<RT^7V]U='!U="`N
M/2`D<W1A<G1486<@/R`G/&5M(&-L87-S/2)H96QP5V%R;B(^)R`Z("<\+V5M
M/B<["B`@("`@("`@?0H@("`@?0H*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O571I;"YP:'``````````````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P-C<R-C$@,3`U,34T,S,W-#`@,#(Q,#`V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"@HO
M*BH*("H@17)R;W(@8V]D92!F;W(@82!M:7-S:6YG(&1R:79E<B!C;VYF:6=U
M<F%T:6]N+@H@*B\*9&5F:6YE*"=(3U)$15]%4E)/4E]$4DE615)?0T].1DE'
M7TU)4U-)3D<G+"`Q*3L*"B\J*@H@*B!%<G)O<B!C;V1E(&9O<B!A;B!I;F-O
M;7!L971E(&1R:79E<B!C;VYF:6=U<F%T:6]N+@H@*B\*9&5F:6YE*"=(3U)$
M15]%4E)/4E]$4DE615)?0T].1DE')RP@,BD["@HO*BH*("H@5&AE(%5T:6PZ
M.B!C;&%S<R!P<F]V:61E<R!G96YE<F%L;'D@=7-E9G5L(&UE=&AO9',@;V8@
M9&EF9F5R96YT(&MI;F1S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]5=&EL
M+U5T:6PN<&AP+'8@,2XS.#0N-BXQ-R`R,#`V+S`U+S`U(#$V.C`R.C$R(&IA
M;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N
M8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V
M($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@
M*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*
M("H@0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H@0'-I
M;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7U5T:6P*("HO"F-L
M87-S(%5T:6P@>PH*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!O8FIE8W0G
M<R!C;&]N92X*("`@("`J"B`@("`@*B!`<&%R86T@;V)J96-T("8D;V)J("!4
M:&4@;V)J96-T('1O(&-L;VYE+@H@("`@("H*("`@("`J($!R971U<FX@;V)J
M96-T("!4:&4@8VQO;F5D(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@
M)F-L;VYE3V)J96-T*"8D;V)J*0H@("`@>PH@("`@("`@("\J($-L;VYI;F<@
M9&]E<R`J;F]T*B!C=7)R96YT;'D@=V]R:R!I9B!U<VEN9R!02%`@-2X*("`@
M("`@("`@*B!4:&ES(&ES(&$@:VYO=VX@4$A0(&ES<W5E.B!H='1P.B\O8G5G
M<RYP:'`N;F5T+V)U9RYP:'`_:60],C<R-C@*("`@("`@("`@*B!4:&5R969O
M<F4L('=O<FL@87)O=6YD('1H:7,@:7-S=64@8GD@=7-I;F<@=&AE(%!(4"`T
M"B`@("`@("`@("H@<V5R:6%L:7IE+W5N<V5R:6%L:7IE(&-L;VYE(&AA8VLN
M("HO"B`@("`@("`@+RH*("`@("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*'IE
M;F1?=F5R<VEO;B@I+"`G,B<L("<^)RDI('L*("`@("`@("`@("`@<F5T=7)N
M(&-L;VYE*"1O8FHI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1N
M97=/8FH@/2`D;V)J.PH@("`@("`@("`@("!R971U<FX@)&YE=T]B:CL*("`@
M("`@("!]"B`@("`@("`@*B\*("`@("`@("`D<F5T(#T@=6YS97)I86QI>F4H
M<V5R:6%L:7IE*"1O8FHI*3L*("`@("`@("!R971U<FX@)')E=#L*("`@('T*
M"B`@("`O*BH*("`@("`J($)U9F9E<G,@=&AE(&]U='!U="!F<F]M(&$@9G5N
M8W1I;VX@8V%L;"P@;&EK92!R96%D9FEL92@I(&]R"B`@("`@*B!H:6=H;&EG
M:'1?<W1R:6YG*"DL('1H870@<')I;G1S('1H92!O=71P=70@9&ER96-T;'DL
M('-O('1H870@:6YS=&5A9"!I=`H@("`@("H@8V%N(&)E(')E='5R;F5D(&%S
M(&$@<W1R:6YG(&%N9"!U<V5D+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&9U;F-T:6]N("!4:&4@9G5N8W1I;VX@=&\@<G5N+@H@("`@("H@0'!A
M<F%M(&UI>&5D("1A<F<Q("`@("`@($9I<G-T(&%R9W5M96YT('1O("1F=6YC
M=&EO;B@I+@H@("`@("H@0'!A<F%M(&UI>&5D("1A<F<R("`@("`@(%-E8V]N
M9"!A<F=U;65N="!T;R`D9G5N8W1I;VXH*2X*("`@("`J($!P87)A;2!M:7AE
M9"`D87)G+BXN("`@("`N+BX*("`@("`J($!P87)A;2!M:7AE9"`D87)G3B`@
M("`@("!.=&@@87)G=6UE;G0@=&\@)&9U;F-T:6]N*"DN"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!O=71P=70@;V8@=&AE(&9U;F-T:6]N
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!B=69F97)/=71P=70H*0H@("`@>PH@
M("`@("`@(&EF("AF=6YC7VYU;5]A<F=S*"D@/3T@,"D@>PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@("1I;F-L=61E(#T@
M9F%L<V4["B`@("`@("`@)&%R9W,@/2!F=6YC7V=E=%]A<F=S*"D["B`@("`@
M("`@)&9U;F-T:6]N(#T@87)R87E?<VAI9G0H)&%R9W,I.PH@("`@("`@(&EF
M("AI<U]A<G)A>2@D9G5N8W1I;VXI*2!["B`@("`@("`@("`@(&EF("@A:7-?
M8V%L;&%B;&4H)&9U;F-T:6]N*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E:68@*"@D9G5N
M8W1I;VX@/3T@)VEN8VQU9&4G*2!\?`H@("`@("`@("`@("`@("`@("`H)&9U
M;F-T:6]N(#T]("=I;F-L=61E7V]N8V4G*2!\?`H@("`@("`@("`@("`@("`@
M("`H)&9U;F-T:6]N(#T]("=R97%U:7)E)RD@?'P*("`@("`@("`@("`@("`@
M("`@*"1F=6YC=&EO;B`]/2`G<F5Q=6ER95]O;F-E)RDI('L*("`@("`@("`@
M("`@)&EN8VQU9&4@/2!T<G5E.PH@("`@("`@('T@96QS96EF("@A9G5N8W1I
M;VY?97AI<W1S*"1F=6YC=&EO;BDI('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@;V)?<W1A<G0H*3L*("`@("`@("!I
M9B`H)&EN8VQU9&4I('L*("`@("`@("`@("`@)&9I;&4@/2!I;7!L;V1E*"<L
M)RP@)&%R9W,I.PH@("`@("`@("`@("!S=VET8V@@*"1F=6YC=&EO;BD@>PH@
M("`@("`@("`@("!C87-E("=I;F-L=61E)SH*("`@("`@("`@("`@("`@(&EN
M8VQU9&4@)&9I;&4["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&-A<V4@)VEN8VQU9&5?;VYC92<Z"B`@("`@("`@("`@("`@("!I;F-L
M=61E7V]N8V4@)&9I;&4["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@(&-A<V4@)W)E<75I<F4G.@H@("`@("`@("`@("`@("`@<F5Q=6ER
M92`D9FEL93L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M8V%S92`G<F5Q=6ER95]O;F-E)SH*("`@("`@("`@("`@("`@(')E<75I<F5?
M;VYC92`D9FEL93L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@8V%L;%]U<V5R7V9U
M;F-?87)R87DH)&9U;F-T:6]N+"`D87)G<RD["B`@("`@("`@?0H@("`@("`@
M("1O=71P=70@/2!O8E]G971?8V]N=&5N=',H*3L*("`@("`@("!O8E]E;F1?
M8VQE86XH*3L*"B`@("`@("`@<F5T=7)N("1O=71P=70["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#:&5C:W,@=&\@<V5E(&EF(&$@=F%L=64@:&%S(&)E96X@
M<V5T(&)Y('1H92!S8W)I<'0@86YD(&YO="!B>2!'150L"B`@("`@*B!03U-4
M+"!O<B!C;V]K:64@:6YP=70N(%1H92!V86QU92!B96EN9R!C:&5C:V5D($U5
M4U0@8F4@:6X@=&AE(&=L;V)A;`H@("`@("H@<V-O<&4N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=F%R;F%M92`@5&AE('9A<FEA8FQE(&YA;64@
M=&\@8VAE8VLN"B`@("`@*B!`<&%R86T@;6EX960@)&1E9F%U;'0@("!$969A
M=6QT('9A;'5E(&EF('1H92!V87)I86)L92!I<VXG="!P<F5S96YT"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("!O<B!W87,@<W!E8VEF:65D(&)Y
M('1H92!U<V5R+B!$969A=6QT<R!T;R!N=6QL+@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@0'-I;F-E($AO<F1E(#,N,0H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@("1D969A=6QT(&EF('1H92!V87(@:7,@:6X@=7-E
M<B!I;G!U="!O<B!N;W0@<')E<V5N="P*("`@("`J("`@("`@("`@("`@("`@
M('1H92!V87)I86)L92!V86QU92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&YO;DEN<'5T5F%R*"1V87)N86UE+"`D9&5F875L="`](&YU;&PI
M"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1?1T546R1V87)N86UE72D@?'P*
M("`@("`@("`@("`@:7-S970H)%]03U-46R1V87)N86UE72D@?'P*("`@("`@
M("`@("`@:7-S970H)%]#3T]+245;)'9A<FYA;65=*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&1E9F%U;'0["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N(&ES<V5T*"1'3$]"04Q36R1V87)N86UE72D@/R`D1TQ/0D%,
M4ULD=F%R;F%M95T@.B`D9&5F875L=#L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!9&1S(&$@;F%M93UV86QU92!P86ER('1O('1H92!E;F0@
M;V8@86X@55),+"!T86MI;F<@8V%R92!O9B!W:&5T:&5R"B`@("`@*B!T:&5R
M92!A<F4@97AI<W1I;F<@<&%R86UE=&5R<R!A;F0@=VAE=&AE<B!T;R!U<V4@
M/RP@)B!O<B`F86UP.R!A<R!T:&4*("`@("`J(&=L=64N("!!;&P@9&%T82!W
M:6QL(&)E('5R;&5N8V]D960N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=7)L("`@("`@(%1H92!54DP@=&\@;6]D:69Y"B`@("`@*B!`<&%R86T@
M;6EX960@)'!A<F%M971E<B`@16ET:&5R('1H92!N86UE/79A;'5E('!A:7(@
M=&\@861D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@*$1%4%)%
M0T%4140I("UO<BT*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!T
M:&4@;F%M92!V86QU92`M;W(M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@86X@87)R87D@;V8@;F%M92]V86QU92!P86ER<RX*("`@("`J($!P
M87)A;2!S=')I;F<@)'9A;'5E("`@("!)9B!S<&5C:69I960L('1H92!V86QU
M92!P87)T("@D<&%R86UE=&5R(&ES"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@=&AE;B!A<W-U;65D('1O(&IU<W0@8F4@=&AE('!A<F%M971E
M<B!N86UE*2X*("`@("`J($!P87)A;2!B;V]L96%N("1E;F-O9&4@("!)9B!T
M<G5E+"!A;F0@=V4@9&]N)W0@:&%V92!A<F=U;65N="!S97!A<F%T;W)S"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@>65T+"!T:&4@87)G=6UE
M;G0@<V5P87)A=&]R(&=E=',@96YC;V1E9"X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(&UO9&EF:65D(%523"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@861D4&%R86UE=&5R*"1U<FPL("1P87)A;65T97(L("1V86QU92`]
M(&YU;&PL("1E;F-O9&4@/2!T<G5E*0H@("`@>PH@("`@("`@('-T871I8R`D
M=')A;G-L871I;VY?=&%B;&4["@H@("`@("`@(&EF("@A:7-S970H)'1R86YS
M;&%T:6]N7W1A8FQE*2D@>PH@("`@("`@("`@("`D=')A;G-L871I;VY?=&%B
M;&4@/2!A<G)A>5]F;&EP*&=E=%]H=&UL7W1R86YS;&%T:6]N7W1A8FQE*$A4
M34Q?14Y4251)15,I*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1P
M87)A;65T97(I*2!["B`@("`@("`@("`@(')E='5R;B`D=7)L.PH@("`@("`@
M('T*"B`@("`@("`@+RH@36%K92!S=7)E('1O(&AA=F4@86X@87)R87DN("HO
M"B`@("`@("`@:68@*"%I<U]A<G)A>2@D<&%R86UE=&5R*2D@>PH@("`@("`@
M("`@("`D861D(#T@87)R87DH)'!A<F%M971E<B`]/B`D=F%L=64I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1A9&0@/2`D<&%R86UE=&5R.PH@
M("`@("`@('T*"B`@("`@("`@)&%R9R`]("1E;F-O9&4@/R`G)F%M<#LG(#H@
M)R8G.PH@("`@("`@(&EF("@H)'!O<R`]('-T<G!O<R@D=7)L+"`G/R<I*2`]
M/3T@9F%L<V4I('L*("`@("`@("`@("`@)&=L=64@/2`G/R<["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@+RH@0VAE8VL@:68@=&AE(&%R9W5M96YT
M('-E<&%R871O<B!H87,@8F5E;B!A;')E861Y"B`@("`@("`@("`@("`J(&AT
M;6QE;G1I=&EE<RUI>F5D(&EN('1H92!54DPN("HO"B`@("`@("`@("`@("1Q
M=65R>2`]('-U8G-T<B@D=7)L+"`D<&]S("L@,2D["B`@("`@("`@("`@(&EF
M("AP<F5G7VUA=&-H*"<O/2XJ/R9A;7`[+BH_/2\G+"`D<75E<GDI*2!["B`@
M("`@("`@("`@("`@("`D87)G(#T@)R9A;7`[)SL*("`@("`@("`@("`@("`@
M("1Q=65R>2`]('-T<G1R*"1Q=65R>2P@)'1R86YS;&%T:6]N7W1A8FQE*3L*
M("`@("`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H)R\]+BH_)BXJ/STO
M)RP@)'%U97)Y*2D@>PH@("`@("`@("`@("`@("`@)&%R9R`]("<F)SL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D<&%I<G,@/2!E>'!L;V1E*"1A<F<L
M("1Q=65R>2D["B`@("`@("`@("`@("1P87)A;7,@/2!A<G)A>2@I.PH@("`@
M("`@("`@("!F;W)E86-H("@D<&%I<G,@87,@)'!A:7(I('L*("`@("`@("`@
M("`@("`@("1P86ER(#T@97AP;&]D92@G/2<L("1P86ER+"`R*3L*("`@("`@
M("`@("`@("`@("1P87)A;7-;)'!A:7);,%U=(#T@8V]U;G0H)'!A:7(I(#T]
M(#(@/R`D<&%I<ELQ72`Z("<G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1G;'5E(#T@)&%R9SL*("`@("`@("!]"@H@("`@("`@("1U<FQ?<&%R86US
M(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D861D(&%S("1P87)A;65T
M97(@/3X@)'9A;'5E*2!["B`@("`@("`@("`@(&EF("@A:7-S970H)'!A<F%M
M<ULD<&%R86UE=&5R72DI('L*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A
M>2@D=F%L=64I*2!["B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'9A
M;'5E(&%S("1V86PI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'5R;%]P
M87)A;7-;72`]('5R;&5N8V]D92@D<&%R86UE=&5R*2`N("=;73TG("X@=7)L
M96YC;V1E*"1V86PI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'5R;%]P87)A
M;7-;72`]('5R;&5N8V]D92@D<&%R86UE=&5R*2`N("<])R`N('5R;&5N8V]D
M92@D=F%L=64I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!I9B`H8V]U;G0H)'5R;%]P87)A;7,I*2!["B`@
M("`@("`@("`@(')E='5R;B`D=7)L("X@)&=L=64@+B!I;7!L;V1E*"1A<F<L
M("1U<FQ?<&%R86US*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@)'5R;#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M96UO=F5S(&YA;64]=F%L=64@<&%I<G,@9G)O;2!A(%523"X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1U<FP@("`@5&AE(%523"!T;R!M;V1I9GDN
M"B`@("`@*B!`<&%R86T@;6EX960@)')E;6]V92`@16ET:&5R(&$@<VEN9VQE
M('!A<F%M971E<B!T;R!R96UO=F4@;W(@86X@87)R87D*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!O9B!P87)A;65T97)S('1O(')E;6]V92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&UO9&EF:65D(%523"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E4&%R86UE=&5R*"1U<FPL("1R
M96UO=F4I"B`@("!["B`@("`@("`@<W1A=&EC("1T<F%N<VQA=&EO;E]T86)L
M93L*"B`@("`@("`@:68@*"%I<W-E="@D=')A;G-L871I;VY?=&%B;&4I*2![
M"B`@("`@("`@("`@("1T<F%N<VQA=&EO;E]T86)L92`](&%R<F%Y7V9L:7`H
M9V5T7VAT;6Q?=')A;G-L871I;VY?=&%B;&4H2%1-3%]%3E1)5$E%4RDI.PH@
M("`@("`@('T*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1R96UO=F4I*2!["B`@
M("`@("`@("`@("1R96UO=F4@/2!A<G)A>2@D<F5M;W9E*3L*("`@("`@("!]
M"@H@("`@("`@("\J(%)E='5R;B!I;6UE9&EA=&5L>2!I9B!T:&5R92!A<F4@
M;F\@<&%R86UE=&5R<R!T;R!R96UO=F4N("HO"B`@("`@("`@:68@*"@D<&]S
M(#T@<W1R<&]S*"1U<FPL("<_)RDI(#T]/2!F86QS92D@>PH@("`@("`@("`@
M("!R971U<FX@)'5R;#L*("`@("`@("!]"@H@("`@("`@("1E;G1I=&EE<R`]
M(&9A;'-E.PH@("`@("`@(&QI<W0H)'5R;"P@)'%U97)Y*2`](&5X<&QO9&4H
M)S\G+"`D=7)L+"`R*3L*"B`@("`@("`@+RH@0VAE8VL@:68@=&AE(&%R9W5M
M96YT('-E<&%R871O<B!H87,@8F5E;B!A;')E861Y"B`@("`@("`@("H@:'1M
M;&5N=&ET:65S+6EZ960@:6X@=&AE(%523"X@*B\*("`@("`@("!I9B`H<')E
M9U]M871C:"@G+STN*C\F86UP.RXJ/STO)RP@)'%U97)Y*2D@>PH@("`@("`@
M("`@("`D96YT:71I97,@/2!T<G5E.PH@("`@("`@("`@("`D<75E<GD@/2!S
M=')T<B@D<75E<GDL("1T<F%N<VQA=&EO;E]T86)L92D["B`@("`@("`@?0H*
M("`@("`@("`O*B!'970@=&AE(&QI<W0@;V8@<&%R86UE=&5R<RX@*B\*("`@
M("`@("`D<&%I<G,@/2!E>'!L;V1E*"<F)RP@)'%U97)Y*3L*("`@("`@("`D
M<&%R86US(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D<&%I<G,@87,@
M)'!A:7(I('L*("`@("`@("`@("`@)'!A:7(@/2!E>'!L;V1E*"<])RP@)'!A
M:7(L(#(I.PH@("`@("`@("`@("`D<&%R86US6R1P86ER6S!=72`](&-O=6YT
M*"1P86ER*2`]/2`R(#\@)'!A:7);,5T@.B`G)SL*("`@("`@("!]"@H@("`@
M("`@("\J(%)E;6]V92!T:&4@<&%R86UE=&5R<RX@*B\*("`@("`@("!F;W)E
M86-H("@D<F5M;W9E(&%S("1P87)A;2D@>PH@("`@("`@("`@("!U;G-E="@D
M<&%R86US6R1P87)A;5TI.PH@("`@("`@('T*"B`@("`@("`@:68@*"%C;W5N
M="@D<&%R86US*2D@>PH@("`@("`@("`@("!R971U<FX@)'5R;#L*("`@("`@
M("!]"@H@("`@("`@("\J($9L871T96X@87)R87ES+@H@("`@("`@("`J($9)
M6$U%.B!S:&]U;&0@:&%N9&QE(&UO<F4@=&AA;B!O;F4@87)R87D@;&5V96P@
M<V]M96AO=RX@*B\*("`@("`@("`D861D(#T@87)R87DH*3L*("`@("`@("!F
M;W)E86-H("@D<&%R86US(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@
M("!I9B`H:7-?87)R87DH)'9A;"DI('L*("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1V86P@87,@)'8I('L*("`@("`@("`@("`@("`@("`@("`D861D6UT@
M/2`D:V5Y("X@)UM=/2<@+B`D=CL*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1A9&1;72`]("1K97D@
M+B`G/2<@+B`D=F%L.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`D<75E<GD@/2!I;7!L;V1E*"<F)RP@)&%D9"D["B`@("`@("`@:68@*"1E
M;G1I=&EE<RD@>PH@("`@("`@("`@("`D<75E<GD@/2!H=&UL96YT:71I97,H
M)'%U97)Y*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=7)L("X@)S\G
M("X@)'%U97)Y.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A('5R
M;"!W:71H('1H92`G;F]C86-H92<@<&%R86UE=&5R(&%D9&5D+"!I9B!T:&4@
M8G)O=W-E<B!I<PH@("`@("H@8G5G9WD@86YD(&-A8VAE<R!O;&0@55),<RX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<FP@(%1H92!54DP@=&\@
M;6]D:69Y+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F5Q
M=65S=&5D(%5222X*("`@("`J+PH@("`@9G5N8W1I;VX@;F]C86-H955R;"@D
M=7)L*0H@("`@>PH@("`@("`@('-T871I8R`D<F%N9%]N=6T["@H@("`@("`@
M(')E<75I<F5?;VYC92`G2&]R9&4O0G)O=W-E<BYP:'`G.PH@("`@("`@("1B
M<F]W<V5R(#T@)D)R;W=S97(Z.G-I;F=L971O;B@I.PH*("`@("`@("`O*B!7
M92!M87D@;F5E9"!T;R!S970@82!D=6UM>2!P87)A;65T97(@)VYO8V%C:&4G
M('-I;F-E('-O;64*("`@("`@("`@*B!B<F]W<V5R<R!D;R!N;W0@86QW87ES
M(&AO;F]R('1H92`G;F\M8V%C:&4G(&AE861E<BX@*B\*("`@("`@("!I9B`H
M)&)R;W=S97(M/FAA<U%U:7)K*"=C86-H95]S86UE7W5R;"<I*2!["B`@("`@
M("`@("`@(&EF("@A:7-S970H)')A;F1?;G5M*2D@>PH@("`@("`@("`@("`@
M("`@)')A;F1?;G5M(#T@8F%S95]C;VYV97)T*&UI8W)O=&EM92@I+"`Q,"P@
M,S8I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B!5=&EL.CIA
M9&1087)A;65T97(H)'5R;"P@)VYO8V%C:&4G+"`D<F%N9%]N=6TI.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D=7)L.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!H:61D96X@9F]R
M;2!I;G!U="!C;VYT86EN:6YG('1H92!S97-S:6]N(&YA;64@86YD(&ED+@H@
M("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1A<'!E;F1?<V5S<VEO;B`@
M,"`](&]N;'D@:68@;F5E9&5D+"`Q(#T@86QW87ES+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@:&ED9&5N(&9O<FT@:6YP=70L(&EF(&YE
M961E9"]R97%U97-T960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&9O<FU);G!U
M="@D87!P96YD7W-E<W-I;VX@/2`P*0H@("`@>PH@("`@("`@(&EF("@D87!P
M96YD7W-E<W-I;VX@/3T@,2!\?`H@("`@("`@("`@("`A:7-S970H)%]#3T]+
M245;<V5S<VEO;E]N86UE*"E=*2D@>PH@("`@("`@("`@("!R971U<FX@)SQI
M;G!U="!T>7!E/2)H:61D96XB(&YA;64](B<@+B!H=&UL<W!E8VEA;&-H87)S
M*'-E<W-I;VY?;F%M92@I*2`N("<B('9A;'5E/2(G("X@:'1M;'-P96-I86QC
M:&%R<RAS97-S:6]N7VED*"DI("X@(EPB("\^7&XB.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!0<FEN=',@82!H:61D96X@9F]R;2!I;G!U="!C;VYT
M86EN:6YG('1H92!S97-S:6]N(&YA;64@86YD(&ED+@H@("`@("H*("`@("`J
M($!P87)A;2!B;V]L96%N("1A<'!E;F1?<V5S<VEO;B`@,"`](&]N;'D@:68@
M;F5E9&5D+"`Q(#T@86QW87ES+@H@("`@("HO"B`@("!F=6YC=&EO;B!P9F]R
M;4EN<'5T*"1A<'!E;F1?<V5S<VEO;B`](#`I"B`@("!["B`@("`@("`@96-H
M;R!5=&EL.CIF;W)M26YP=70H)&%P<&5N9%]S97-S:6]N*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($EF(&UA9VEC7W%U;W1E<U]G<&,@:7,@:6X@=7-E+"!R
M=6X@<W1R:7!S;&%S:&5S*"D@;VX@)'9A<BX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("8D=F%R("!4:&4@<W1R:6YG('1O('5N+7%U;W1E+"!I9B!N
M96-E<W-A<GDN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@("1V87(L
M(&UI;G5S(&%N>2!M86=I8R!Q=6]T97,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&1I<W!E;$UA9VEC475O=&5S*"8D=F%R*0H@("`@>PH@("`@("`@('-T871I
M8R`D;6%G:6-?<75O=&5S.PH*("`@("`@("!I9B`H(6ES<V5T*"1M86=I8U]Q
M=6]T97,I*2!["B`@("`@("`@("`@("1M86=I8U]Q=6]T97,@/2!G971?;6%G
M:6-?<75O=&5S7V=P8R@I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1M86=I
M8U]Q=6]T97,I('L*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D=F%R*2D@
M>PH@("`@("`@("`@("`@("`@)'9A<B`]('-T<FEP<VQA<VAE<R@D=F%R*3L*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&%R<F%Y7W=A
M;&LH)'9A<BP@87)R87DH)U5T:6PG+"`G9&ES<&5L36%G:6-1=6]T97,G*2D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=F%R
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T<R!A(&9O<FT@=F%R:6%B;&4@
M9G)O;2!'150@;W(@4$]35"!D871A+"!S=')I<'!E9"!O9B!M86=I8R!Q=6]T
M97,@:68*("`@("`J(&YE8V5S<V%R>2X@268@=&AE('9A<FEA8FQE(&ES('-O
M;65H;W<@<V5T(&EN(&)O=&@@=&AE($=%5"!D871A(&%N9"!T:&4*("`@("`J
M(%!/4U0@9&%T82P@=&AE('9A;'5E(&9R;VT@=&AE(%!/4U0@9&%T82!W:6QL
M(&)E(')E='5R;F5D(&%N9"!T:&4@1T54"B`@("`@*B!V86QU92!W:6QL(&)E
M(&EG;F]R960N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=F%R("`@
M("`@5&AE(&YA;64@;V8@=&AE(&9O<FT@=F%R:6%B;&4@=&\@;&]O:R!F;W(N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1D969A=6QT("!4:&4@=F%L=64@=&\@
M<F5T=7)N(&EF('1H92!V87)I86)L92!I<R!N;W0*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@('1H97)E+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@8VQE86YE9"!F;W)M('9A<FEA8FQE+"!O<B`D9&5F875L
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1F]R;41A=&$H)'9A<BP@)&1E
M9F%U;'0@/2!N=6QL*0H@("`@>PH@("`@("`@(')E='5R;B`H*"1V86P@/2!5
M=&EL.CIG9710;W-T*"1V87(I*2`A/3T@;G5L;"D*("`@("`@("`@("`@/R`D
M=F%L(#H@571I;#HZ9V5T1V5T*"1V87(L("1D969A=6QT*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($=E=',@82!F;W)M('9A<FEA8FQE(&9R;VT@1T54(&1A
M=&$L('-T<FEP<&5D(&]F(&UA9VEC('%U;W1E<R!I9@H@("`@("H@;F5C97-S
M87)Y+B!4:&ES(&9U;F-T:6]N('=I;&P@3D]4(')E='5R;B!A(%!/4U0@=F%R
M:6%B;&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=F%R("`@("`@
M5&AE(&YA;64@;V8@=&AE(&9O<FT@=F%R:6%B;&4@=&\@;&]O:R!F;W(N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1D969A=6QT("!4:&4@=F%L=64@=&\@<F5T
M=7)N(&EF('1H92!V87)I86)L92!I<R!N;W0*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@('1H97)E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@8VQE86YE9"!F;W)M('9A<FEA8FQE+"!O<B`D9&5F875L="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1V5T*"1V87(L("1D969A=6QT(#T@
M;G5L;"D*("`@('L*("`@("`@("!R971U<FX@*&ES<V5T*"1?1T546R1V87)=
M*2D*("`@("`@("`@("`@/R!5=&EL.CID:7-P96Q-86=I8U%U;W1E<R@D7T=%
M5%LD=F%R72D*("`@("`@("`@("`@.B`D9&5F875L=#L*("`@('T*"B`@("`O
M*BH*("`@("`J($=E=',@82!F;W)M('9A<FEA8FQE(&9R;VT@4$]35"!D871A
M+"!S=')I<'!E9"!O9B!M86=I8R!Q=6]T97,@:68*("`@("`J(&YE8V5S<V%R
M>2X@5&AI<R!F=6YC=&EO;B!W:6QL($Y/5"!R971U<FX@82!'150@=F%R:6%B
M;&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=F%R("`@("`@5&AE
M(&YA;64@;V8@=&AE(&9O<FT@=F%R:6%B;&4@=&\@;&]O:R!F;W(N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1D969A=6QT("!4:&4@=F%L=64@=&\@<F5T=7)N
M(&EF('1H92!V87)I86)L92!I<R!N;W0*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@('1H97)E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@8VQE86YE9"!F;W)M('9A<FEA8FQE+"!O<B`D9&5F875L="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T4&]S="@D=F%R+"`D9&5F875L="`](&YU
M;&PI"B`@("!["B`@("`@("`@<F5T=7)N("AI<W-E="@D7U!/4U1;)'9A<ETI
M*0H@("`@("`@("`@("`_(%5T:6PZ.F1I<W!E;$UA9VEC475O=&5S*"1?4$]3
M5%LD=F%R72D*("`@("`@("`@("`@.B`D9&5F875L=#L*("`@('T*"B`@("`O
M*BH*("`@("`J($1E=&5R;6EN97,@=&AE(&QO8V%T:6]N(&]F('1H92!S>7-T
M96T@=&5M<&]R87)Y(&1I<F5C=&]R>2X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@02!D:7)E8W1O<GD@;F%M92!W:&EC:"!C86X@8F4@=7-E9"!F
M;W(@=&5M<"!F:6QE<RX*("`@("`J("`@("`@("`@("`@("`@("!2971U<FYS
M(&9A;'-E(&EF(&]N92!C;W5L9"!N;W0@8F4@9F]U;F0N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%1E;7!$:7(H*0H@("`@>PH@("`@("`@("\J($9I<G-T
M+"!T<GD@4$A0)W,@=7!L;V%D7W1M<%]D:7(@9&ER96-T:79E+B`J+PH@("`@
M("`@("1T;7`@/2!I;FE?9V5T*"=U<&QO861?=&UP7V1I<B<I.PH*("`@("`@
M("`O*B!/=&AE<G=I<V4L('1R>2!T;R!D971E<FUI;F4@=&AE(%1-4$1)4B!E
M;G9I<F]N;65N=`H@("`@("`@("`J('9A<FEA8FQE+B`J+PH@("`@("`@(&EF
M("AE;7!T>2@D=&UP*2D@>PH@("`@("`@("`@("`D=&UP(#T@9V5T96YV*"=4
M35!$25(G*3L*("`@("`@("!]"@H@("`@("`@("\J($EF('=E('-T:6QL(&-A
M;FYO="!D971E<FUI;F4@82!V86QU92P@=&AE;B!C>6-L92!T:')O=6=H(&$*
M("`@("`@("`@*B!L:7-T(&]F('!R97-E="!P;W-S:6)I;&ET:65S+B`J+PH@
M("`@("`@("1T;7!?;&]C871I;VYS(#T@87)R87DH)R]T;7`G+"`G+W9A<B]T
M;7`G+"`G8SI<5U5496UP)RP@)V,Z7'1E;7`G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V,Z7'=I;F1O=W-<=&5M<"<L("=C.EQW:6YN=%QT
M96UP)RD["B`@("`@("`@=VAI;&4@*&5M<'1Y*"1T;7`I("8F(&-O=6YT*"1T
M;7!?;&]C871I;VYS*2D@>PH@("`@("`@("`@("`D=&UP7V-H96-K(#T@87)R
M87E?<VAI9G0H)'1M<%]L;V-A=&EO;G,I.PH@("`@("`@("`@("!I9B`H0&ES
M7V1I<B@D=&UP7V-H96-K*2D@>PH@("`@("`@("`@("`@("`@)'1M<"`]("1T
M;7!?8VAE8VL["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J
M($EF(&ET(&ES('-T:6QL(&5M<'1Y+"!W92!H879E(&9A:6QE9"P@<V\@<F5T
M=7)N(&9A;'-E.PH@("`@("`@("`J(&]T:&5R=VES92!R971U<FX@=&AE(&1I
M<F5C=&]R>2!D971E<FUI;F5D+B`J+PH@("`@("`@(')E='5R;B!E;7!T>2@D
M=&UP*2`_(&9A;'-E(#H@)'1M<#L*("`@('T*"B`@("`O*BH*("`@("`J($-R
M96%T97,@82!T96UP;W)A<GD@9FEL96YA;64@9F]R('1H92!L:69E=&EM92!O
M9B!T:&4@<V-R:7!T+"!A;F0*("`@("`J("AO<'1I;VYA;&QY*2!R96=I<W1E
M<B!I="!T;R!B92!D96QE=&5D(&%T(')E<75E<W0@<VAU=&1O=VXN"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')E9FEX("`@4')E9FEX('1O(&UA
M:V4@=&AE('1E;7!O<F%R>2!N86UE(&UO<F4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@(')E8V]G;FEZ86)L92X*("`@("`J($!P87)A;2!B;V]L
M96%N("1D96QE=&4@($1E;&5T92!T:&4@9FEL92!A="!T:&4@96YD(&]F('1H
M92!R97%U97-T/PH@("`@("H@0'!A<F%M('-T<FEN9R`D9&ER("`@("`@1&ER
M96-T;W)Y('1O(&-R96%T92!T:&4@=&5M<&]R87)Y(&9I;&4@:6XN"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D<V5C=7)E("!)9B!D96QE=&EN9R!F:6QE+"!S
M:&]U;&0@=V4@<V5C=7)E;'D@9&5L971E('1H90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@9FEL93\*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@(%)E='5R;G,@=&AE(&9U;&P@<&%T:"UN86UE('1O('1H92!T96UP
M;W)A<GD@9FEL92X*("`@("`J("`@("`@("`@("`@("`@("`@4F5T=7)N<R!F
M86QS92!I9B!A('1E;7`@9FEL92!C;W5L9"!N;W0@8F4@8W)E871E9"X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T5&5M<$9I;&4H)'!R969I>"`]("<G+"`D
M9&5L971E(#T@=')U92P@)&1I<B`]("<G+"`D<V5C=7)E(#T@9F%L<V4I"B`@
M("!["B`@("`@("`@:68@*&5M<'1Y*"1D:7(I('Q\("%I<U]D:7(H)&1I<BDI
M('L*("`@("`@("`@("`@)'1M<%]D:7(@/2!5=&EL.CIG971496UP1&ER*"D[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1M<%]D:7(@/2`D9&ER
M.PH@("`@("`@('T*"B`@("`@("`@:68@*&5M<'1Y*"1T;7!?9&ER*2D@>PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D
M=&UP7V9I;&4@/2!T96UP;F%M*"1T;7!?9&ER+"`D<')E9FEX*3L*"B`@("`@
M("`@+RH@268@=&AE(&9I;&4@=V%S(&-R96%T960L('1H96X@<F5G:7-T97(@
M:70@9F]R(&1E;&5T:6]N(&%N9"!R971U<FX@*B\*("`@("`@("!I9B`H96UP
M='DH)'1M<%]F:6QE*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*"1D96QE=&4I('L*("`@
M("`@("`@("`@("`@(%5T:6PZ.F1E;&5T94%T4VAU=&1O=VXH)'1M<%]F:6QE
M+"!T<G5E+"`D<V5C=7)E*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R
M971U<FX@)'1M<%]F:6QE.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($-R96%T97,@82!T96UP;W)A<GD@9&ER96-T;W)Y(&EN('1H92!S>7-T
M96TG<R!T96UP;W)A<GD@9&ER96-T;W)Y+@H@("`@("H*("`@("`J($!P87)A
M;2!B;V]L96%N("1D96QE=&4@("!$96QE=&4@=&AE('1E;7!O<F%R>2!D:7)E
M8W1O<GD@870@=&AE(&5N9"!O9@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@('1H92!R97%U97-T/PH@("`@("H@0'!A<F%M('-T<FEN9R`D=&5M
M<%]D:7(@(%5S92!T:&ES('1E;7!O<F%R>2!D:7)E8W1O<GD@87,@=&AE(&1I
M<F5C=&]R>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('=H97)E
M('1H92!T96UP;W)A<GD@9&ER96-T;W)Y('=I;&P@8F4@8W)E871E9"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('!A=&AN86UE('1O('1H
M92!N97<@=&5M<&]R87)Y(&1I<F5C=&]R>2X*("`@("`J("`@("`@("`@("`@
M("`@("!2971U<FYS(&9A;'-E(&EF(&1I<F5C=&]R>2!N;W0@8W)E871E9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@8W)E871E5&5M<$1I<B@D9&5L971E(#T@
M=')U92P@)'1E;7!?9&ER(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?
M;G5L;"@D=&5M<%]D:7(I*2!["B`@("`@("`@("`@("1T96UP7V1I<B`](%5T
M:6PZ.F=E=%1E;7!$:7(H*3L*("`@("`@("!]"@H@("`@("`@(&EF("AE;7!T
M>2@D=&5M<%]D:7(I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@("\J($=E="!T:&4@9FER<W0@."!C:&%R86-T97)S
M(&]F(&$@<F%N9&]M('-T<FEN9R!T;R!U<V4@87,@82!T96UP;W)A<GD*("`@
M("`@("`@("!D:7)E8W1O<GD@;F%M92X@*B\*("`@("`@("!D;R!["B`@("`@
M("`@("`@("1T96UP7V1I<B`N/2`G+R<@+B!S=6)S='(H8F%S95]C;VYV97)T
M*&UT7W)A;F0H*2`N(&UI8W)O=&EM92@I+"`Q,"P@,S8I+"`P+"`X*3L*("`@
M("`@("!]('=H:6QE("AF:6QE7V5X:7-T<R@D=&5M<%]D:7(I*3L*"B`@("`@
M("`@)&]L9%]U;6%S:R`]('5M87-K*#`P,#`I.PH@("`@("`@(&EF("@A;6MD
M:7(H)'1E;7!?9&ER+"`P-S`P*2D@>PH@("`@("`@("`@("`D=&5M<%]D:7(@
M/2!F86QS93L*("`@("`@("!](&5L<V5I9B`H)&1E;&5T92D@>PH@("`@("`@
M("`@("!5=&EL.CID96QE=&5!=%-H=71D;W=N*"1T96UP7V1I<BD["B`@("`@
M("`@?0H@("`@("`@('5M87-K*"1O;&1?=6UA<VLI.PH*("`@("`@("!R971U
M<FX@)'1E;7!?9&ER.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&4@8V%N;VYI8V%L('!A=&@@;V8@=&AE('-T<FEN9RX@($QI:V4@4$A0)W,@
M8G5I;'0M:6X*("`@("`J(')E86QP871H*"D@97AC97!T('1H92!D:7)E8W1O
M<GD@;F5E9"!N;W0@97AI<W0@;VX@=&AE(&QO8V%L('-E<G9E<BX*("`@("`J
M"B`@("`@*B!!;&=O<FET:&EM(&QO;W-E;'D@8F%S960@;VX@8V]D92!F<F]M
M('1H92!097)L($9I;&4Z.E-P96,Z.E5N:7@@;6]D=6QE"B`@("`@*B`H=F5R
M<VEO;B`Q+C4I+@H@("`@("H*("`@("`J($!S:6YC92!(;W)D92`S+C`N-0H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@($$@9FEL92!P871H
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8V%N;VYI8V%L
M:7IE9"!F:6QE('!A=&@N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E86Q0871H
M*"1P871H*0H@("`@>PH@("`@("`@("\J(%-T86YD87)D:7IE(&]N(%5.25@@
M9&ER96-T;W)Y('-E<&%R871O<G,N("HO"B`@("`@("`@:68@*'-U8G-T<BA0
M2%!?3U,L(#`L(#,I(#T]("=724XG*2!["B`@("`@("`@("`@("1P871H(#T@
M<W1R7W)E<&QA8V4H)UQ<)RP@)R\G+"`D<&%T:"D["B`@("`@("`@?0H*("`@
M("`@("`O*B!X>"\O+R]X>"`M/B!X>"]X>`H@("`@("`@("`J('AX+RXO+B]X
M>"`M/B!X>"]X>"`J+PH@("`@("`@("1P871H(#T@<')E9U]R97!L86-E*&%R
M<F%Y*")\+RM\(BP@(D`H+UPN*2LH+WQ<6B@_(5QN*2E`(BDL(&%R<F%Y*"<O
M)RP@)R\G*2P@)'!A=&@I.PH*("`@("`@("`O*B`N+WAX("T^('AX("HO"B`@
M("`@("`@:68@*"1P871H("$]("<N+R<I('L*("`@("`@("`@("`@)'!A=&@@
M/2!P<F5G7W)E<&QA8V4H(GQ>*%PN+RDK?"(L("<G+"`D<&%T:"D["B`@("`@
M("`@?0H*("`@("`@("`O*B`O+BXO+BXO>'@@+3X@>'@@*B\*("`@("`@("`D
M<&%T:"`]('!R96=?<F5P;&%C92@B?%XO*%PN7"XO/RDK?"(L("<O)RP@)'!A
M=&@I.PH*("`@("`@("`O*B!X>"\@+3X@>'@@*B\*("`@("`@("!I9B`H)'!A
M=&@@(3T@)R\G*2!["B`@("`@("`@("`@("1P871H(#T@<')E9U]R97!L86-E
M*")\+UQ:*#\A7&XI?"(L("<G+"`D<&%T:"D["B`@("`@("`@?0H*("`@("`@
M("`O*B`O>'@O+BX@+3X@+R`J+PH@("`@("`@('=H:6QE("AS=')P;W,H)'!A
M=&@L("<O+BXG*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@)'!A=&@@/2!P
M<F5G7W)E<&QA8V4H(GPO6UXO72LO7"Y<+GPB+"`G)RP@)'!A=&@I.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N(&5M<'1Y*"1P871H*2`_("<O)R`Z("1P
M871H.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E<R!G:79E;B!E;&5M
M96YT<R!A="!R97%U97-T('-H=71D;W=N+@H@("`@("H*("`@("`J($EF(&-A
M;&QE9"!W:71H(&$@9FEL96YA;64@=VEL;"!D96QE=&4@=&AA="!F:6QE(&%T
M(')E<75E<W0@<VAU=&1O=VX[(&EF"B`@("`@*B!C86QL960@=VET:"!A(&1I
M<F5C=&]R>2!W:6QL(')E;6]V92!T:&%T(&1I<F5C=&]R>2!A;F0@86QL(&9I
M;&5S(&EN('1H870*("`@("`J(&1I<F5C=&]R>2!A="!R97%U97-T('-H=71D
M;W=N+@H@("`@("H*("`@("`J($EF(&-A;&QE9"!W:71H(&YO(&%R9W5M96YT
M<RP@<F5T=7)N(&%L;"!E;&5M96YT<R!T;R!B92!D96QE=&5D("AT:&ES"B`@
M("`@*B!S:&]U;&0@;VYL>2!B92!D;VYE(&)Y(%5T:6PZ.E]D96QE=&5!=%-H
M=71D;W=N*2X*("`@("`J"B`@("`@*B!4:&4@9FER<W0@=&EM92!I="!I<R!C
M86QL960L(&ET(&EN:71I86QI>F5S('1H92!A<G)A>2!A;F0@<F5G:7-T97)S
M"B`@("`@*B!5=&EL.CI?9&5L971E0713:'5T9&]W;B@I(&%S(&$@<VAU=&1O
M=VX@9G5N8W1I;VX@+2!N;R!N965D('1O(&1O('-O"B`@("`@*B!M86YU86QL
M>2X*("`@("`J"B`@("`@*B!4:&4@<V5C;VYD('!A<F%M971E<B!A;&QO=W,@
M=&AE('5N<F5G:7-T97)I;F<@;V8@<')E=FEO=7-L>2!R96=I<W1E<F5D"B`@
M("`@*B!E;&5M96YT<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F
M:6QE;F%M92`@(%1H92!F:6QE;F%M92!T;R!B92!D96QE=&5D(&%T('1H92!E
M;F0@;V8@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@(')E
M<75E<W0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<F5G:7-T97(@($EF('1R
M=64L('1H96X@<F5G:7-T97(@=&AE(&5L96UE;G0@9F]R"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&1E;&5T:6]N+"!O=&AE<G=I<V4L('5N
M<F5G:7-T97(@:70N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<V5C=7)E("`@
M($EF(&1E;&5T:6YG(&9I;&4L('-H;W5L9"!W92!S96-U<F5L>2!D96QE=&4*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&9I;&4_"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T94%T4VAU=&1O=VXH)&9I;&5N86UE
M(#T@9F%L<V4L("1R96=I<W1E<B`]('1R=64L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1S96-U<F4@/2!F86QS92D*("`@('L*("`@("`@("!S
M=&%T:6,@)&1I<G,L("1F:6QE<RP@)'-E8W5R961E;#L*"B`@("`@("`@+RH@
M26YI=&EA;&EZ871I;VX@;V8@=F%R:6%B;&5S(&%N9"!S:'5T9&]W;B!F=6YC
M=&EO;G,N("HO"B`@("`@("`@:68@*&ES7VYU;&PH)&1I<G,I*2!["B`@("`@
M("`@("`@("1D:7)S(#T@87)R87DH*3L*("`@("`@("`@("`@)&9I;&5S(#T@
M87)R87DH*3L*("`@("`@("`@("`@)'-E8W5R961E;"`](&%R<F%Y*"D["B`@
M("`@("`@("`@(')E9VES=&5R7W-H=71D;W=N7V9U;F-T:6]N*&%R<F%Y*"=5
M=&EL)RP@)U]D96QE=&5!=%-H=71D;W=N)RDI.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"1F:6QE;F%M92D@>PH@("`@("`@("`@("!I9B`H)')E9VES=&5R
M*2!["B`@("`@("`@("`@("`@("!I9B`H0&ES7V1I<B@D9FEL96YA;64I*2![
M"B`@("`@("`@("`@("`@("`@("`@)&1I<G-;)&9I;&5N86UE72`]('1R=64[
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("1F:6QE<ULD9FEL96YA;65=(#T@=')U93L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&EF("@D<V5C=7)E*2!["B`@("`@("`@("`@("`@
M("`@("`@)'-E8W5R961E;%LD9FEL96YA;65=(#T@=')U93L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M('5N<V5T*"1D:7)S6R1F:6QE;F%M95TI.PH@("`@("`@("`@("`@("`@=6YS
M970H)&9I;&5S6R1F:6QE;F%M95TI.PH@("`@("`@("`@("`@("`@=6YS970H
M)'-E8W5R961E;%LD9FEL96YA;65=*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@D9&ER<RP@)&9I
M;&5S+"`D<V5C=7)E9&5L*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!$96QE=&5S(')E9VES=&5R960@9FEL97,@870@<F5Q=65S="!S:'5T
M9&]W;BX*("`@("`J"B`@("`@*B!4:&ES(&9U;F-T:6]N('-H;W5L9"!N979E
M<B!B92!C86QL960@;6%N=6%L;'D[(&ET(&ES(')E9VES=&5R960@87,@80H@
M("`@("H@<VAU=&1O=VX@9G5N8W1I;VX@8GD@571I;#HZ9&5L971E0713:'5T
M9&]W;B@I(&%N9"!C86QL960@875T;VUA=&EC86QL>0H@("`@("H@870@=&AE
M(&5N9"!O9B!T:&4@<F5Q=65S="X@270@=VEL;"!R971R:65V92!T:&4@;&ES
M="!O9B!F;VQD97)S(&%N9`H@("`@("H@9FEL97,@=&\@9&5L971E(&9R;VT@
M571I;#HZ9&5L971E0713:'5T9&]W;B@I)W,@<W1A=&EC(&%R<F%Y+"!A;F0@
M=&AE;@H@("`@("H@:71E<F%T92!T:')O=6=H+"!D96QE=&EN9R!F;VQD97)S
M(')E8W5R<VEV96QY+@H@("`@("H*("`@("`J($-O;G1A:6YS(&-O9&4@9G)O
M;2!G<&=?9G5N8W1I;VYS+G!H<"X*("`@("`J($-O<'ER:6=H="`H8RD@,C`P
M,BTR,#`S($)R879E<F]C:R!696YT=7)E<PH@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?9&5L971E0713:'5T
M9&]W;B@I"B`@("!["B`@("`@("`@)')E9VES=&5R960@/2!5=&EL.CID96QE
M=&5!=%-H=71D;W=N*"D["B`@("`@("`@)&1I<G,@/2`D<F5G:7-T97)E9%LP
M73L*("`@("`@("`D9FEL97,@/2`D<F5G:7-T97)E9%LQ73L*("`@("`@("`D
M<V5C=7)E(#T@)')E9VES=&5R961;,ET["@H@("`@("`@(&9O<F5A8V@@*"1F
M:6QE<R!A<R`D9FEL92`]/B`D=F%L*2!["B`@("`@("`@("`@("\J($1E;&5T
M92!F:6QE<R`J+PH@("`@("`@("`@("!I9B`H)'9A;"`F)B!`9FEL95]E>&ES
M=',H)&9I;&4I*2!["B`@("`@("`@("`@("`@("`O*B!3:&]U;&0@=V4@<V5C
M=7)E;'D@9&5L971E('1H92!F:6QE(&)Y(&]V97)W<FET:6YG('1H90H@("`@
M("`@("`@("`@("`@("`@9&%T82!W:71H(&$@<F%N9&]M('-T<FEN9S\@*B\*
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<V5C=7)E6R1F:6QE72DI('L*
M("`@("`@("`@("`@("`@("`@("`D<F%N9&]M7W-T<B`]("<G.PH@("`@("`@
M("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&9I;&5S:7IE*"1F:6QE
M*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<F%N9&]M7W-T
M<B`N/2!C:'(H;71?<F%N9"@P+"`R-34I*3L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@)&9P(#T@9F]P96XH)&9I;&4L("=R
M*R<I.PH@("`@("`@("`@("`@("`@("`@(&9W<FET92@D9G`L("1R86YD;VU?
M<W1R*3L*("`@("`@("`@("`@("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@($!U;FQI;FLH)&9I;&4I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D9&ER
M<R!A<R`D9&ER(#T^("1V86PI('L*("`@("`@("`@("`@+RH@1&5L971E(&1I
M<F5C=&]R:65S("HO"B`@("`@("`@("`@(&EF("@D=F%L("8F($!F:6QE7V5X
M:7-T<R@D9&ER*2D@>PH@("`@("`@("`@("`@("`@+RH@36%K92!S=7)E(&1I
M<F5C=&]R>2!I<R!E;7!T>2X@*B\*("`@("`@("`@("`@("`@("1D:7)?8VQA
M<W,@/2!D:7(H)&1I<BD["B`@("`@("`@("`@("`@("!W:&EL92`H9F%L<V4@
M(3T]("@D96YT<GD@/2`D9&ER7V-L87-S+3YR96%D*"DI*2!["B`@("`@("`@
M("`@("`@("`@("`@:68@*"1E;G1R>2`A/2`G+B<@)B8@)&5N=')Y("$]("<N
M+B<I('L*("`@("`@("`@("`@("`@("`@("`@("`@0'5N;&EN:R@D9&ER("X@
M)R\G("X@)&5N=')Y*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`D9&ER7V-L87-S+3YC;&]S92@I
M.PH@("`@("`@("`@("`@("`@0')M9&ER*"1D:7(I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@3W5T<'5T<R!J879A
M<V-R:7!T(&-O9&4@=&\@8VQO<V4@=&AE(&-U<G)E;G0@=VEN9&]W+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&-O9&4@($%N>2!A9&1T:6]N86P@
M:F%V87-C<FEP="!C;V1E('1O(')U;B!B969O<F4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@(&-L;W-I;F<@=&AE('=I;F1O=RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@8VQO<V57:6YD;W=*4R@D8V]D92`]("<G*0H@("`@>PH@("`@
M("`@(&5C:&\@)SQS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CXG("X@
M)&-O9&4@+@H@("`@("`@("`@("`G=VEN9&]W+F-L;W-E*"D[/"]S8W)I<'0^
M)SL*("`@('T*"B`@("`O*BH*("`@("`J($-A8VAE<R!T:&4@<F5S=6QT(&]F
M(&5X=&5N<VEO;E]L;V%D960H*2!C86QL<RX*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1E>'0@
M(%1H92!E>'1E;G-I;VX@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@($ES('1H92!E>'1E;G-I;VX@;&]A9&5D/PH@("`@("HO"B`@("!F
M=6YC=&EO;B!E>'1E;G-I;VY%>&ES=',H)&5X="D*("`@('L*("`@("`@("!S
M=&%T:6,@)&-A8VAE(#T@87)R87DH*3L*"B`@("`@("`@:68@*"%I<W-E="@D
M8V%C:&5;)&5X=%TI*2!["B`@("`@("`@("`@("1C86-H95LD97AT72`](&5X
M=&5N<VEO;E]L;V%D960H)&5X="D["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)&-A8VAE6R1E>'1=.PH@("`@?0H*("`@("\J*@H@("`@("H@5')I97,@
M=&\@;&]A9"!A(%!(4"!E>'1E;G-I;VXL(&)E:&%V:6YG(&-O<G)E8W1L>2!F
M;W(@86QL(&]P97)A=&EN9PH@("`@("H@<WES=&5M<RX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1E>'0@(%1H92!E>'1E;G-I;VX@=&\@;&]A9"X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE(&5X
M=&5N<VEO;B!I<R!N;W<@;&]A9&5D+"!F86QS92!I9B!N;W0N"B`@("`@*B`@
M("`@("`@("`@("`@("`@(%1R=64@8V%N(&UE86X@=&AA="!T:&4@97AT96YS
M:6]N('=A<R!A;')E861Y(&QO861E9"P*("`@("`J("`@("`@("`@("`@("`@
M("`@3U(@=V%S(&QO861E9"!D>6YA;6EC86QL>2X*("`@("`J+PH@("`@9G5N
M8W1I;VX@;&]A9$5X=&5N<VEO;B@D97AT*0H@("`@>PH@("`@("`@("\J($EF
M("1E>'0@:7,@86QR96%D>2!L;V%D960L(&]U<B!W;W)K(&ES(&1O;F4N("HO
M"B`@("`@("`@:68@*%5T:6PZ.F5X=&5N<VEO;D5X:7-T<R@D97AT*2D@>PH@
M("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("\J
M(%-E92!I9B!W92!C86X@8V%L;"!D;"@I(&%T(&%L;"P@8GD@=&AE(&-U<G)E
M;G0@:6YI('-E='1I;F=S+B`J+PH@("`@("`@(&EF("@H:6YI7V=E="@G96YA
M8FQE7V1L)RD@(3T@,2D@?'P@*&EN:5]G970H)W-A9F5?;6]D92<I(#T](#$I
M*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@
M("`@(&EF("AS=6)S='(H4$A07T]3+"`P+"`S*2`]/2`G5TE.)RD@>PH@("`@
M("`@("`@("`D<W5F9FEX(#T@)V1L;"<["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<W=I=&-H("A02%!?3U,I('L*("`@("`@("`@("`@8V%S92`G
M2%`M55@G.@H@("`@("`@("`@("`@("`@)'-U9F9I>"`]("=S;"<["B`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)T%)6"<Z"B`@
M("`@("`@("`@("`@("`D<W5F9FEX(#T@)V$G.PH@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("!C87-E("=/4U@G.@H@("`@("`@("`@("`@
M("`@)'-U9F9I>"`]("=B=6YD;&4G.PH@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@)'-U9F9I
M>"`]("=S;R<["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!`9&PH)&5X="`N("<N)R`N("1S=69F:7@I('Q\($!D;"@G<&AP7R<@
M+B`D97AT("X@)RXG("X@)'-U9F9I>"D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#:&5C:W,@:68@86QL(&YE8V5S<V%R>2!P87)A;65T97)S(&9O<B!A(&1R
M:79E<B=S(&-O;F9I9W5R871I;VX@87)E('-E=`H@("`@("H@86YD(')E='5R
M;G,@82!014%27T5R<F]R(&EF('-O;65T:&EN9R!I<R!M:7-S:6YG+@H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@5&AE(&-O;F9I9W5R
M871I;VX@87)R87D@=VET:"!A;&P@<&%R86UE=&5R<RX*("`@("`J($!P87)A
M;2!A<G)A>2`D9FEE;&1S("`@06X@87)R87D@=VET:"!M86YD871O<GD@<&%R
M86UE=&5R(&YA;65S(&9O<B!T:&ES"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@(&1R:79E<BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@
M5&AE(&-L96%R('1E>'0@;F%M92!O9B!T:&4@9')I=F5R+B!)9B!N;W0*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@<W!E8VEF:65D+"!T:&4@87!P
M;&EC871I;VX@;F%M92!W:6QL(&)E('5S960N"B`@("`@*B!`<&%R86T@87)R
M87D@)&EN9F\@("`@($$@:&%S:"!C;VYT86EN:6YG(&1E=&%I;&5D(&EN9F]R
M;6%T:6]N(&%B;W5T('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("!D<FEV97(N(%=I;&P@8F4@<&%S<V5D(&%S('1H92!U<V5R26YF;R!T;R!T
M:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E]%<G)O<BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@87-S97)T1')I=F5R0V]N9FEG*"1P87)A
M;7,L("1F:65L9',L("1N86UE+"`D:6YF;R`](&%R<F%Y*"DI"B`@("!["B`@
M("`@("`@)&EN9F\@/2!A<G)A>5]M97)G92@D:6YF;RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"=P87)A;7,G(#T^("1P87)A;7,L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9FEE;&1S)R`]/B`D
M9FEE;&1S+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYA
M;64G(#T^("1N86UE*2D["@H@("`@("`@(&EF("@A:7-?87)R87DH)'!A<F%M
M<RD@?'P@(6-O=6YT*"1P87)A;7,I*2!["B`@("`@("`@("`@(')E<75I<F5?
M;VYC92`G4$5!4BYP:'`G.PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ=&AR
M;W=%<G)O<BAS<')I;G1F*%\H(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B`E<RXB*2P@)&YA;64I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!(3U)$15]%4E)/4E]$4DE615)?0T].
M1DE'7TU)4U-)3D<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1I;F9O*3L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1F:65L
M9',@87,@)&9I96QD*2!["B`@("`@("`@("`@(&EF("@A:7-S970H)'!A<F%M
M<ULD9FEE;&1=*2D@>PH@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=0
M14%2+G!H<"<["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ=&AR;W=%
M<G)O<BAS<')I;G1F*%\H(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D
M(&EN(&-O;F9I9W5R871I;VXN(BDL("1F:65L9"P@)&YA;64I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@2$]21$5?15)23U)?
M1%))5D527T-/3D9)1RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1I;F9O*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!F;W)M870@<W1R:6YG('1O
M(&)E('5S960@8GD@<W1R9G1I;64H*2X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1F;W)M870@($$@9F]R;6%T('-T<FEN9R!A<R!U<V5D(&)Y(&1A
M=&4H*2X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@02!F;W)M870@
M<W1R:6YG(&%S('-I;6EL87(@87,@<&]S<VEB;&4@=&\@)&9O<FUA="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9&%T93)S=')F=&EM92@D9F]R;6%T*0H@("`@
M>PH@("`@("`@("1D871E4WEM8F]L<R`](&%R<F%Y*"=A)RP@)T$G+"`G9"<L
M("=$)RP@)T8G+"`G9R<L("=')RP@)V@G+"`G2"<L("=I)RP@)VHG+"`G;"<L
M("=M)RP@)TTG+"`G;B<L("=R)RP@)W,G+"`G5"<L("=W)RP@)U<G+"`G>2<L
M("=9)RP@)WHG+"`G;2]D+UDG+"`G32<L(")<;B(L("=G.FD@82<L("='.FDG
M+"`B7'0B+"`G2#II.G,G+"`G)2<I.PH@("`@("`@("1S=')F=&EM95-Y;6)O
M;',@/2!A<G)A>2@G)7`G+"`G)7`G+"`G)60G+"`G)6$G+"`G)4(G+"`G)4DG
M+"`G)4@G+"`G)4DG+"`G)4@G+"`G)4TG+"`G)64G+"`G)4$G+"`G)6TG+"`G
M)6(G+"`G)6TG+"`G)6$L("5E("5B("59("54("5:)RP@)R53)RP@)R5:)RP@
M)R5W)RP@)R56)RP@)R5Y)RP@)R59)RP@)R5J)RP@)R5$)RP@)R5H)RP@)R5N
M)RP@)R5R)RP@)R52)RP@)R5T)RP@)R54)RP@)R4E)RD["@H@("`@("`@("1R
M97-U;'0@/2`G)SL*("`@("`@("!F;W(@*"1P;W,@/2`P.R`D<&]S(#P@<W1R
M;&5N*"1F;W)M870I.RD@>PH@("`@("`@("`@("!F;W(@*"1S>6UB;VP@/2`P
M.R`D<WEM8F]L(#P@8V]U;G0H)&1A=&53>6UB;VQS*3L@)'-Y;6)O;"LK*2![
M"B`@("`@("`@("`@("`@("!I9B`H<W1R<&]S*"1F;W)M870L("1D871E4WEM
M8F]L<ULD<WEM8F]L72P@)'!O<RD@/3T]("1P;W,I('L*("`@("`@("`@("`@
M("`@("`@("`D<F5S=6QT("X]("1S=')F=&EM95-Y;6)O;'-;)'-Y;6)O;%T[
M"B`@("`@("`@("`@("`@("`@("`@)'!O<R`K/2!S=')L96XH)&1A=&53>6UB
M;VQS6R1S>6UB;VQ=*3L*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU92`R
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1R97-U;'0@+CT@<W5B<W1R*"1F;W)M870L("1P;W,L(#$I.PH@("`@("`@
M("`@("`D<&]S*RL["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!F;W)M870@<W1R
M:6YG('1O(&)E('5S960@8GD@9&%T92@I+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&9O<FUA="`@02!F;W)M870@<W1R:6YG(&%S('5S960@8GD@
M<W1R9G1I;64H*2X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@02!F
M;W)M870@<W1R:6YG(&%S('-I;6EL87(@87,@<&]S<VEB;&4@=&\@)&9O<FUA
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@<W1R9G1I;64R9&%T92@D9F]R;6%T
M*0H@("`@>PH@("`@("`@("1D871E4WEM8F]L<R`](&%R<F%Y*"=A)RP@)T$G
M+"`G9"<L("=$)RP@)T8G+"`G9R<L("=')RP@)V@G+"`G2"<L("=I)RP@)VHG
M+"`G;"<L("=M)RP@)TTG+"`G;B<L("=R)RP@)W,G+"`G5"<L("=W)RP@)U<G
M+"`G>2<L("=9)RP@)WHG+"`G;2]D+UDG+"`G32<L(")<;B(L("=G.FD@82<L
M("='.FDG+"`B7'0B+"`G2#II.G,G+"`G)2<I.PH@("`@("`@("1S=')F=&EM
M95-Y;6)O;',@/2!A<G)A>2@G)7`G+"`G)7`G+"`G)60G+"`G)6$G+"`G)4(G
M+"`G)4DG+"`G)4@G+"`G)4DG+"`G)4@G+"`G)4TG+"`G)64G+"`G)4$G+"`G
M)6TG+"`G)6(G+"`G)6TG+"`G)6$L("5E("5B("59("54("5:)RP@)R53)RP@
M)R5:)RP@)R5W)RP@)R56)RP@)R5Y)RP@)R59)RP@)R5J)RP@)R5$)RP@)R5H
M)RP@)R5N)RP@)R5R)RP@)R52)RP@)R5T)RP@)R54)RP@)R4E)RD["@H@("`@
M("`@(')E='5R;B!S=')?<F5P;&%C92@D<W1R9G1I;653>6UB;VQS+"`D9&%T
M95-Y;6)O;',L("1F;W)M870I.PH@("`@?0H*?0H*:68@*"%F=6YC=&EO;E]E
M>&ES=',H)U\G*2D@>PH@("`@9G5N8W1I;VX@7R@D<W1R:6YG*0H@("`@>PH@
M("`@("`@(')E='5R;B`D<W1R:6YG.PH@("`@?0H*("`@(&9U;F-T:6]N(&)I
M;F1T97AT9&]M86EN*"D*("`@('L*("`@('T*"B`@("!F=6YC=&EO;B!T97AT
M9&]M86EN*"D*("`@('L*("`@('T*"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4V-H961U;&5R+G!H
M<```````````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,34U,C<@
M,3`U,34T,S,W-#`@,#(R,#`U`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+G!H
M<"<["G)E<75I<F5?;VYC92`G5D93+G!H<"<["@HO*BH*("H@2&]R9&5?4V-H
M961U;&5R"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U-C:&5D=6QE<B]38VAE
M9'5L97(N<&AP+'8@,2XR,RXQ,"XX(#(P,#4O,3(O,#$@,34Z,C<Z,C,@8VAU
M8VL@17AP("0*("H*("H@0'!A8VMA9V4@2&]R9&5?4V-H961U;&5R"B`J+PIC
M;&%S<R!(;W)D95]38VAE9'5L97(@>PH*("`@("\J*@H@("`@("H@3F%M92!O
M9B!T:&4@<VQE97`@9G5N8W1I;VXN"B`@("`@*@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1?<VQE97`["@H@("`@+RHJ"B`@("`@*B!!
M9&IU<W1M96YT(&9A8W1O<B!T;R!S;&5E<"!I;B!M:6-R;W-E8V]N9',N"B`@
M("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7W-L
M965P7V%D:CL*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*
M("`@("`J($9I9W5R97,@;W5T(&AO=R!W92!C86X@8F5S="!S;&5E<"!W:71H
M(&UI8W)O<V5C;VYD('!R96-I<VEO;@H@("`@("H@8F%S960@;VX@=VAA="!P
M;&%T9F]R;2!W92=R92!R=6YN:6YG(&]N+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!(;W)D95]38VAE9'5L97(H*0H@("`@>PH@("`@("`@(&EF("AS=6)S='(H
M4$A07T]3+"`P+"`S*2`]/2`G5TE.)RD@>PH@("`@("`@("`@("`D=&AI<RT^
M7W-L965P(#T@)W-L965P)SL*("`@("`@("`@("`@)'1H:7,M/E]S;&5E<%]A
M9&H@/2`Q,#`P,#`P.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T
M:&ES+3Y?<VQE97`@/2`G=7-L965P)SL*("`@("`@("`@("`@)'1H:7,M/E]S
M;&5E<%]A9&H@/2`Q.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($UA:6X@;&]O<"]A8W1I;VX@9G5N8W1I;VXN"B`@("`@*@H@("`@("H@0&%B
M<W1R86-T"B`@("`@*B\*("`@(&9U;F-T:6]N(')U;B@I"B`@("!["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!0<F5S97)V92!T:&4@:6YT97)N86P@<W1A=&4@
M;V8@=&AE('-C:&5D=6QE<B!O8FIE8W0@=&AA="!W92!A<F4*("`@("`J('!A
M<W-E9"P@86YD('-A=F4@:70@=&\@=&AE($AO<F1E(%9&4R!B86-K96YD+B!(
M;W)D95]38VAE9'5L97(*("`@("`J(&]B:F5C=',@<VAO=6QD(&1E9FEN92!?
M7W-L965P*"D@86YD(%]?=V%K975P*"D@<V5R:6%L:7IA=&EO;@H@("`@("H@
M8V%L;&)A8VMS(&9O<B!A;GET:&EN9R!T:&%T(&YE961S('1O(&)E(&1O;F4@
M870@;V)J96-T"B`@("`@*B!S97)I86QI>F%T:6]N(&]R(&1E<V5R:6%L:7IA
M=&EO;B`M(&AA;F1L:6YG(&1A=&%B87-E"B`@("`@*B!C;VYN96-T:6]N<RP@
M971C+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1I9"`@06X@:60@
M=&\@=6YI<75E;'D@:61E;G1I9GD@=&AI<R!S8VAE9'5L97(@9G)O;0H@("`@
M("H@("`@("`@("`@("`@("`@("`@("!O=&AE<G,@;V8@=&AE('-A;64@8VQA
M<W,N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E<FEA;&EZ92@D:60@/2`G)RD*
M("`@('L*("`@("`@("`D=F9S(#T@)E9&4SHZ<VEN9VQE=&]N*"1'3$]"04Q3
M6R=C;VYF)UU;)W9F<R==6R=T>7!E)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!(;W)D93HZ9V5T1')I=F5R0V]N9FEG*"=V9G,G+"`D1TQ/
M0D%,4ULG8V]N9B==6R=V9G,G75LG='EP92==*2D["B`@("`@("`@:68@*&ES
M7V$H)'9F<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(;W)D93HZ
M;&]G365S<V%G92@D=F9S+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'
M7T524BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@
M("`@("`@("1R97-U;'0@/2`D=F9S+3YW<FET941A=&$H)RYH;W)D92]S8VAE
M9'5L97(G+"!3=')I;F<Z.FQO=V5R*&=E=%]C;&%S<R@D=&AI<RDI("X@)&ED
M+"!S97)I86QI>F4H)'1H:7,I+"!T<G5E*3L*("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@($AO<F1E.CIL
M;V=-97-S86=E*"1R97-U;'0L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],
M3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M97-T;W)E(&$@2&]R9&5?4V-H961U;&5R(&]B:F5C="!F<F]M('1H92!C86-H
M92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D8VQA<W,@("`@(%1H
M92!N86UE(&]F('1H92!(;W)D95]38VAE9'5L97(@;V)J96-T('1O(')E<W1O
M<F4N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D:60@("`@("`@($%N(&ED('1O
M('5N:7%U96QY(&ED96YT:69Y('1H:7,*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<V-H961U;&5R(&9R;VT@;W1H97)S(&]F('1H92!S86UE
M(&-L87-S+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%U=&]S879E("!!=71O
M;6%T:6-A;&QY('-T;W)E("AS97)I86QI>F4I('1H92!R971U<FYE9`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("!O8FIE8W0@870@<V-R:7!T
M('-H=71D;W=N+@H@("`@("H*("`@("`J($!S964@2&]R9&5?4V-H961U;&5R
M.CIS97)I86QI>F4H*0H@("`@("HO"B`@("!F=6YC=&EO;B`F=6YS97)I86QI
M>F4H)&-L87-S+"`D:60@/2`G)RP@)&%U=&]S879E(#T@=')U92D*("`@('L*
M("`@("`@("`O+R!.965D(&$@;&]W97)C87-E('9E<G-I;VX@;V8@=&AE(&-L
M87-S;F%M92P@86YD(&$@9&5F875L=`H@("`@("`@("\O(&EN<W1A;F-E(&]F
M('1H92!S8VAE9'5L97(@;V)J96-T(&EN(&-A<V4@=V4@8V%N)W0@<F5T<FEE
M=F4*("`@("`@("`O+R!O;F4N"B`@("`@("`@)&-L87-S(#T@<W1R=&]L;W=E
M<B@D8VQA<W,I.PH@("`@("`@("1S8VAE9'5L97(@/2`F;F5W("1C;&%S<SL*
M"B`@("`@("`@)'9F<R`]("961E,Z.G-I;F=L971O;B@D1TQ/0D%,4ULG8V]N
M9B==6R=V9G,G75LG='EP92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@2&]R9&4Z.F=E=$1R:79E<D-O;F9I9R@G=F9S)RP@)$=,3T)!3%-;
M)V-O;F8G75LG=F9S)UU;)W1Y<&4G72DI.PH@("`@("`@(&EF("AI<U]A*"1V
M9G,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE
M<W-A9V4H)'9F<RP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1D871A(#T@)'9F<RT^
M<F5A9"@G+FAO<F1E+W-C:&5D=6QE<B<L("1C;&%S<R`N("1I9"D["B`@("`@
M("`@("`@(&EF("AI<U]A*"1D871A+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D9&%T82P@7U]&24Q%7U\L
M(%]?3$E.15]?+"!014%27TQ/1U])3D9/*3L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1S8VAE9'5L97(@/2!`=6YS97)I86QI>F4H
M)&1A=&$I.PH@("`@("`@("`@("`@("`@:68@*"$D<V-H961U;&5R*2!["B`@
M("`@("`@("`@("`@("`@("`@)'-C:&5D=6QE<B`]("9N97<@)&-L87-S.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!I9B`H)&%U=&]S879E*2!["B`@("`@("`@("`@(')E9VES=&5R7W-H
M=71D;W=N7V9U;F-T:6]N*&%R<F%Y*"8D<V-H961U;&5R+"`G<V5R:6%L:7IE
M)RDI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1S8VAE9'5L97(["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!0;&%T9F]R;2UI;F1E<&5N9&%N="!S;&5E
M<"`D;7-E8R!M:6-R;W-E8V]N9',N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)&US96,@($UI8W)O<V5C;VYD<R!T;R!S;&5E<"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<VQE97`H)&US96,I"B`@("!["B`@("`@("`@8V%L;%]U
M<V5R7V9U;F,H)'1H:7,M/E]S;&5E<"P@)&US96,@+R`D=&AI<RT^7W-L965P
M7V%D:BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U
M<FX@82!C;VYC<F5T92!(;W)D95]38VAE9'5L97(@:6YS=&%N8V4@8F%S960@
M;VX@)&1R:79E<BX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&1R:79E
M<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@2&]R9&5?4V-H961U;&5R('-U8F-L
M87-S('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N+B!)
M9B`D9')I=F5R(&ES(&%N(&%R<F%Y+"!T:&5N('=E('=I;&P@;&]O:PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@(&EN("1D<FEV97);,%TO;&EB+TAO
M<F1E7U-C:&5D=6QE<B\@9F]R('1H90H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@('-U8F-L87-S(&EM<&QE;65N=&%T:6]N(&YA;65D("1D<FEV97);
M,5TN<&AP+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C
M;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@;W(*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("!C;VYN96-T:6]N('!A<F%M971E
M<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@("`J($!R971U
M<FX@2&]R9&5?4V-H961U;&5R("!4:&4@;F5W;'D@8W)E871E9"!C;VYC<F5T
M92!(;W)D95]38VAE9'5L97(*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("!I;G-T86YC92P@;W(@9F%L<V4@;VX@86X@97)R;W(N"B`@("`@*B\*
M("`@(&9U;F-T:6]N("9F86-T;W)Y*"1D<FEV97(L("1P87)A;7,@/2!N=6QL
M*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D9')I=F5R*2D@>PH@("`@
M("`@("`@("`D87!P(#T@)&1R:79E<ELP73L*("`@("`@("`@("`@)&1R:79E
M<B`]("1D<FEV97);,5T["B`@("`@("`@?0H*("`@("`@("`D9')I=F5R(#T@
M8F%S96YA;64H)&1R:79E<BD["@H@("`@("`@(&EF("AE;7!T>2@D9')I=F5R
M*2!\?"`H<W1R8VUP*"1D<FEV97(L("=N;VYE)RD@/3T@,"DI('L*("`@("`@
M("`@("`@)'-C:&5D=6QE<B`]("9N97<@2&]R9&5?4V-H961U;&5R*"D["B`@
M("`@("`@("`@(')E='5R;B`D<V-H961U;&5R.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"%E;7!T>2@D87!P*2D@>PH@("`@("`@("`@("!I;F-L=61E7V]N
M8V4@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G9FEL97)O;W0G+"`D87!P
M*2`N("<O;&EB+U-C:&5D=6QE<B\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@
M("`@("!](&5L<V5I9B`H0&9I;&5?97AI<W1S*&1I<FYA;64H7U]&24Q%7U\I
M("X@)R]38VAE9'5L97(O)R`N("1D<FEV97(@+B`G+G!H<"<I*2!["B`@("`@
M("`@("`@(&EN8VQU9&5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O4V-H
M961U;&5R+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("\O(%5S92!I;F-L=61E7V]N8V4@:&5R92!T;R!A=F]I
M9"!A(&9A=&%L(&5R<F]R(&EF('1H90H@("`@("`@("`@("`O+R!C;&%S<R!I
M<VXG="!F;W5N9"X*("`@("`@("`@("`@0&EN8VQU9&5?;VYC92`G2&]R9&4O
M4V-H961U;&5R+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T*("`@
M("`@("`D8VQA<W,@/2`G2&]R9&5?4V-H961U;&5R7R<@+B`D9')I=F5R.PH@
M("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@
M("`D<V-H961U;&5R(#T@)FYE=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)'-C:&5D=6QE<B`](%!%05(Z.G)A:7-E
M17)R;W(H)T-L87-S(&1E9FEN:71I;VX@;V8@)R`N("1C;&%S<R`N("<@;F]T
M(&9O=6YD+B<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1S8VAE9'5L
M97(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@
M82!R969E<F5N8V4@=&\@82!C;VYC<F5T92!(;W)D95]38VAE9'5L97(*("`@
M("`J(&EN<W1A;F-E(&)A<V5D(&]N("1D<FEV97(N($ET('=I;&P@;VYL>2!C
M<F5A=&4@82!N97<@:6YS=&%N8V4*("`@("`J(&EF(&YO($AO<F1E7U-C:&5D
M=6QE<B!I;G-T86YC92!W:71H('1H92!S86UE('!A<F%M971E<G,*("`@("`J
M(&-U<G)E;G1L>2!E>&ES=',N"B`@("`@*@H@("`@("H@5&AI<R!S:&]U;&0@
M8F4@=7-E9"!I9B!M=6QT:7!L92!S8VAE9'5L97)S("AA;F0L('1H=7,L(&UU
M;'1I<&QE"B`@("`@*B!(;W)D95]38VAE9'5L97(@:6YS=&%N8V5S*2!A<F4@
M<F5Q=6ER960N"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@;75S="!B92!I
M;G9O:V5D(&%S.B`D=F%R(#T@)DAO<F1E7U-C:&5D=6QE<CHZ<VEN9VQE=&]N
M*"D*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D<FEV97(@(%1H92!T
M>7!E(&]F(&-O;F-R971E($AO<F1E7U-C:&5D=6QE<B!S=6)C;&%S<R!T;PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FXN"B`@("`@*B!`
M<&%R86T@87)R87D@)'!A<F%M<R`@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A
M9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@;W(*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@8V]N;F5C=&EO;B!P87)A;65T97)S(&$@<W5B8VQA<W,@
M;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N($AO<F1E7U-C:&5D
M=6QE<B`@5&AE(&-O;F-R971E($AO<F1E7U-C:&5D=6QE<B!R969E<F5N8V4L
M(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@9F%L<V4@;VX@
M86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)&1R
M:79E<BP@)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@<W1A=&EC("1I
M;G-T86YC97,@/2!A<G)A>2@I.PH*("`@("`@("`D<VEG;F%T=7)E(#T@<V5R
M:6%L:7IE*&%R<F%Y*"1D<FEV97(L("1P87)A;7,I*3L*("`@("`@("!I9B`H
M(6ES<V5T*"1I;G-T86YC97-;)'-I9VYA='5R95TI*2!["B`@("`@("`@("`@
M("1I;G-T86YC97-;)'-I9VYA='5R95T@/2`F2&]R9&5?4V-H961U;&5R.CIF
M86-T;W)Y*"1D<FEV97(L("1P87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1I;G-T86YC97-;)'-I9VYA='5R95T["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O161I=&]R+G!H<```````````````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#<W,34@,3`U,34T,S,W-#`@,#(Q
M,S$U`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B!%9&ET;W(@0VQA<W,*("H*("H@5&AE($5D:71O<CHZ
M('!A8VMA9V4@<')O=FED97,@86X@<G1E(&5D:71O<B!F;W(@=&AE($AO<F1E
M"B`J($%P<&QI8V%T:6]N($9R86UE=V]R:RX*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO161I=&]R+T5D:71O<BYP:'`L=B`Q+C@N,3`N."`R,#`V+S`Q+S`Q
M(#(Q.C(X.C$T(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V
M($YU;F\@3&]U<F5I<F\@/&YU;F]`8V\N<V%P;RYP=#X*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($YU;F\@3&]U<F5I<F\@/&YU;F]`8V\N<V%P;RYP
M=#X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T5D
M:71O<@H@*B\*8VQA<W,@2&]R9&5?161I=&]R('L*"B`@("`O*BH*("`@("`J
M($-O;G-T<G5C=&]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]%9&ET
M;W(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC<F5T92!(;W)D95]%9&ET
M;W(@:6YS=&%N8V4@8F%S960@;VX@)&1R:79E<BX*("`@("`J"B`@("`@*B!`
M<&%R86T@;6EX960@)&1R:79E<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@2&]R
M9&5?161I=&]R('-U8F-L87-S('1O"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N+B!)9B`D9')I=F5R(&ES(&%N(&%R<F%Y+"!T:&5N('=E
M('=I;&P@;&]O:PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&EN("1D
M<FEV97);,%TO;&EB+T1R:79E<B\@9F]R('1H92!S=6)C;&%S<PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@(&EM<&QE;65N=&%T:6]N(&YA;65D("1D
M<FEV97);,5TN<&AP+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@
M:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@
M;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!C;VYN96-T:6]N('!A
M<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@("`J
M($!R971U<FX@2&]R9&5?161I=&]R("!4:&4@;F5W;'D@8W)E871E9"!C;VYC
M<F5T92!(;W)D95]%9&ET;W(@:6YS=&%N8V4L"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@;W(@9F%L<V4@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U
M;F-T:6]N("9F86-T;W)Y*"1D<FEV97(L("1P87)A;7,@/2!N=6QL*0H@("`@
M>PH@("`@("`@(&EF("AI<U]A<G)A>2@D9')I=F5R*2D@>PH@("`@("`@("`@
M("`D87!P(#T@)&1R:79E<ELP73L*("`@("`@("`@("`@)&1R:79E<B`]("1D
M<FEV97);,5T["B`@("`@("`@?0H*("`@("`@("`D9')I=F5R(#T@8F%S96YA
M;64H)&1R:79E<BD["B`@("`@("`@:68@*&5M<'1Y*"1D<FEV97(I('Q\("1D
M<FEV97(@/3T@)VYO;F4G*2!["B`@("`@("`@("`@("1E9&ET;W(@/2`F;F5W
M($AO<F1E7T5D:71O<B@D<&%R86US*3L*("`@("`@("`@("`@<F5T=7)N("1E
M9&ET;W(["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?;G5L;"@D<&%R86US
M*2`F)B!C;&%S<U]E>&ES=',H)TAO<F1E)RDI('L*("`@("`@("`@("`@)'!A
M<F%M<R`]($AO<F1E.CIG971$<FEV97)#;VYF:6<H)V5D:71O<B<L("1D<FEV
M97(I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D87!P*2D@>PH@
M("`@("`@("`@("!G;&]B86P@)')E9VES=')Y.PH@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@)')E9VES=')Y+3YG970H)V9I;&5R;V]T)RP@)&%P<"D@+B`G
M+VQI8B]%9&ET;W(O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?2!E
M;'-E:68@*$!F:6QE7V5X:7-T<RAD:7)N86UE*%]?1DE,15]?*2`N("<O161I
M=&]R+R<@+B`D9')I=F5R("X@)RYP:'`G*2D@>PH@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+T5D:71O<B\G("X@)&1R
M:79E<B`N("<N<&AP)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!`
M:6YC;'5D95]O;F-E("=(;W)D92]%9&ET;W(O)R`N("1D<FEV97(@+B`G+G!H
M<"<["B`@("`@("`@?0H*("`@("`@("`D8VQA<W,@/2`G2&]R9&5?161I=&]R
M7R<@+B`D9')I=F5R.PH@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S
M*2D@>PH@("`@("`@("`@("`D961I=&]R(#T@)FYE=R`D8VQA<W,H)'!A<F%M
M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&5D:71O<B`](%!%
M05(Z.G)A:7-E17)R;W(H)T-L87-S(&1E9FEN:71I;VX@;V8@)R`N("1C;&%S
M<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1E9&ET;W(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R
M971U<FX@82!R969E<F5N8V4@=&\@82!C;VYC<F5T92!(;W)D95]%9&ET;W(*
M("`@("`J(&EN<W1A;F-E(&)A<V5D(&]N("1D<FEV97(N($ET('=I;&P@;VYL
M>2!C<F5A=&4@82!N97<@:6YS=&%N8V4*("`@("`J(&EF(&YO($AO<F1E7T5D
M:71O<B!I;G-T86YC92!W:71H('1H92!S86UE('!A<F%M971E<G,@8W5R<F5N
M=&QY"B`@("`@*B!E>&ES=',N"B`@("`@*@H@("`@("H@5&AI<R!S:&]U;&0@
M8F4@=7-E9"!I9B!M=6QT:7!L92!C86-H92!B86-K96YD<R`H86YD+"!T:'5S
M+`H@("`@("H@;75L=&EP;&4@2&]R9&5?161I=&]R(&EN<W1A;F-E<RD@87)E
M(')E<75I<F5D+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@
M:6YV;VME9"!A<SH*("`@("`J("1V87(@/2`F2&]R9&5?161I=&]R.CIS:6YG
M;&5T;VXH*0H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D9')I=F5R("!4
M:&4@='EP92!O9B!C;VYC<F5T92!(;W)D95]%9&ET;W(@<W5B8VQA<W,@=&\*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!R971U<FXN($EF("1D<FEV
M97(@:7,@86X@87)R87DL('1H96X@=V4@=VEL;"!L;V]K"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@:6X@)&1R:79E<ELP72]L:6(O161I=&]R+R!F
M;W(@=&AE('-U8F-L87-S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M:6UP;&5M96YT871I;VX@;F%M960@)&1R:79E<ELQ72YP:'`N"B`@("`@*B!`
M<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@86YY(&%D
M9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!O<@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A('-U8F-L87-S(&UI
M9VAT(&YE960N"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E(#(N,@H@("`@
M("H*("`@("`J($!R971U<FX@2&]R9&5?161I=&]R("!4:&4@8V]N8W)E=&4@
M2&]R9&5?161I=&]R(')E9F5R96YC92P@;W(@9F%L<V4@;VX*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@)G-I;F=L971O;B@D9')I=F5R+"`D<&%R86US(#T@;G5L;"D*("`@('L*
M("`@("`@("!S=&%T:6,@)&EN<W1A;F-E<SL*"B`@("`@("`@:68@*"%I<W-E
M="@D:6YS=&%N8V5S*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S(#T@87)R
M87DH*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]N=6QL*"1P87)A;7,I
M("8F(&-L87-S7V5X:7-T<R@G2&]R9&4G*2D@>PH@("`@("`@("`@("`D<&%R
M86US(#T@2&]R9&4Z.F=E=$1R:79E<D-O;F9I9R@G8V%C:&4G+"`D9')I=F5R
M*3L*("`@("`@("!]"@H@("`@("`@("1S:6=N871U<F4@/2!S97)I86QI>F4H
M87)R87DH)&1R:79E<BP@)'!A<F%M<RDI.PH@("`@("`@(&EF("@A87)R87E?
M:V5Y7V5X:7-T<R@D<VEG;F%T=7)E+"`D:6YS=&%N8V5S*2D@>PH@("`@("`@
M("`@("`D:6YS=&%N8V5S6R1S:6=N871U<F5=(#T@)DAO<F1E7T5D:71O<CHZ
M9F%C=&]R>2@D9')I=F5R+"`D<&%R86US*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D:6YS=&%N8V5S6R1S:6=N871U<F5=.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O365N=2YP:'``
M````````````````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,C0V
M-C$@,3`U,34T,S,W-#`@,#(P-S<R`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"@ID969I;F4H)TA/4D1%7TU%3E5?
M4$]37TQ!4U0G+"`Y.3DI.PH*9&5F:6YE*"=(3U)$15]-14Y57TU!4TM?3D].
M12<L("`@("`P*3L*9&5F:6YE*"=(3U)$15]-14Y57TU!4TM?2$5,4"<L("`@
M("`Q*3L*9&5F:6YE*"=(3U)$15]-14Y57TU!4TM?3$]'24XG+"`@("`R*3L*
M9&5F:6YE*"=(3U)$15]-14Y57TU!4TM?4%)%1E,G+"`@("`T*3L*9&5F:6YE
M*"=(3U)$15]-14Y57TU!4TM?4%)/0DQ%32<L("`X*3L*9&5F:6YE*"=(3U)$
M15]-14Y57TU!4TM?04Q,)RP@("`@(#$U*3L*"B\J*@H@*B!4:&4@365N=3HZ
M(&-L87-S('!R;W9I9&5S('-T86YD87)D:7IE9"!M971H;V1S(&9O<B!C<F5A
M=&EN9R!M96YU<R!I;@H@*B!(;W)D92!A<'!L:6-A=&EO;G,N"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP+'8@,2XS-2XR
M+C$Q(#(P,#8O,#<O,C`@,#0Z,S$Z,C<@<VQU<V%R>B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($IO;B!087)I<V4@/&IO
M;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C
M:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@2F]N
M(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS
M"B`J($!P86-K86=E($AO<F1E7T9R86UE=V]R:PH@*B\*8VQA<W,@365N=2![
M"@H@("`@+RHJ"B`@("`@*B!-96YU(&%R<F%Y+@H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1?;65N=2`](&%R<F%Y*"D["@H@
M("`@+RHJ"B`@("`@*B!-87-K(&1E9FEN:6YG('=H870@9V5N97)A;"!(;W)D
M92!L:6YK<R!A<F4@<VAO=VX@:6X@=&AI<R!-96YU+@H@("`@("H*("`@("`J
M($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]M87-K.PH*("`@("\J
M*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J+PH@("`@9G5N8W1I;VX@365N
M=2@D;6%S:R`]($A/4D1%7TU%3E5?34%32U]!3$PI"B`@("!["B`@("`@("`@
M+RH@365N=6ET96T@;6%S:RX@*B\*("`@("`@("`D=&AI<RT^7VUA<VL@/2`D
M;6%S:SL*"B`@("`@("`@+RH@3&]C871I;VX@;V8@=&AE(&UE;G5F:6QE+B`J
M+PH@("`@("`@("1T:&ES+3Y?;65N=69I;&4@/2`D1TQ/0D%,4ULG<F5G:7-T
M<GDG72T^9V5T*"=F:6QE<F]O="<I("X@)R]C;VYF:6<O;65N=2YP:'`G.PH@
M("`@?0H*("`@("\J*@H@("`@("H@061D(&%N(&ET96T@=&\@=&AE(&UE;G4@
M87)R87DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7)L("`@("`@
M("!3=')I;F<@8V]N=&%I;FEN9R!T:&4@=F%L=64@9F]R('1H92!H>7!E<FQI
M;FLN"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("`@("`@(%-T<FEN9R!C
M;VYT86EN:6YG('1H92!L86)E;"!F;W(@=&AI<R!M96YU"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&ET96TN"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1I8V]N("`@("`@(%-T<FEN9R!C;VYT86EN:6YG('1H92!F:6QE;F%M
M92!O9B!T:&4@:6UA9V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:6-O;B!T;R!D:7-P;&%Y(&9O<B!T:&ES(&UE;G4@:71E;2X*("`@("`J
M($!P87)A;2!S=')I;F<@)&EC;VY?<&%T:"`@268@=&AE(&EC;VX@;&EV97,@
M:6X@82!N;VXM9&5F875L="!D:7)E8W1O<GDL"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@('=H97)E(&ES(&ET/PH@("`@("H@0'!A<F%M('-T
M<FEN9R`D=&%R9V5T("`@("!)9B!T:&4@;&EN:R!N965D<R!T;R!O<&5N(&EN
M(&%N;W1H97(@9G)A;64@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@=VEN9&]W+"!W:&%T(&ES(&ET<R!N86UE/PH@("`@("H@0'!A<F%M
M('-T<FEN9R`D;VYC;&EC:R`@("!/;F-L:6-K(&IA=F%S8W)I<'0L(&EF(&1E
M<VER960N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;&%S<R`@("`@($-34R!C
M;&%S<R!F;W(@=&AE(&UE;G4@:71E;2X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&EN=&5G97(@(%1H92!I9"`H3D]4(&=U87)A;G1E960@=&\@8F4@86X@87)R
M87D@:6YD97@I(&]F('1H90H@("`@("H@("`@("`@("`@("`@("`@("!I=&5M
M(&IU<W0@861D960@=&\@=&AE(&UE;G4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%D9"@D=7)L+"`D=&5X="P@)&EC;VX@/2`G)RP@)&EC;VY?<&%T:"`](&YU
M;&PL"B`@("`@("`@("`@("`@("`@)'1A<F=E="`]("<G+"`D;VYC;&EC:R`]
M(&YU;&PL("1C;&%S<R`](&YU;&PI"B`@("!["B`@("`@("`@)'!O<R`](&-O
M=6YT*"1T:&ES+3Y?;65N=2D["B`@("`@("`@:68@*"$D<&]S('Q\("@D<&]S
M("T@,2`A/2!M87@H87)R87E?:V5Y<R@D=&AI<RT^7VUE;G4I*2DI('L*("`@
M("`@("`@("`@)'!O<R`](&-O=6YT*"1T:&ES+3Y?;65N=2D["B`@("`@("`@
M?0H*("`@("`@("`D=&AI<RT^7VUE;G5;)'!O<UT@/0H@("`@("`@("`@("!A
M<G)A>2@*("`@("`@("`@("`@("`@("=U<FPG(#T^("1U<FPL"B`@("`@("`@
M("`@("`@("`G=&5X="<@/3X@)'1E>'0L"B`@("`@("`@("`@("`@("`G:6-O
M;B<@/3X@)&EC;VXL"B`@("`@("`@("`@("`@("`G:6-O;E]P871H)R`]/B`D
M:6-O;E]P871H+`H@("`@("`@("`@("`@("`@)W1A<F=E="<@/3X@)'1A<F=E
M="P*("`@("`@("`@("`@("`@("=O;F-L:6-K)R`]/B`D;VYC;&EC:RP*("`@
M("`@("`@("`@("`@("=C;&%S<R<@/3X@)&-L87-S"B`@("`@("`@("`@("D[
M"@H@("`@("`@(')E='5R;B`D<&]S.PH@("`@?0H*("`@("\J*@H@("`@("H@
M061D(&%N(&ET96T@=&\@=&AE(&UE;G4@87)R87DN"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=7)L("`@("`@("!3=')I;F<@8V]N=&%I;FEN9R!T
M:&4@=F%L=64@9F]R('1H92!H>7!E<FQI;FLN"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1T97AT("`@("`@(%-T<FEN9R!C;VYT86EN:6YG('1H92!L86)E;"!F
M;W(@=&AI<R!M96YU"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&ET96TN"B`@("`@*B!`<&%R86T@<W1R:6YG("1I8V]N("`@("`@(%-T<FEN
M9R!C;VYT86EN:6YG('1H92!F:6QE;F%M92!O9B!T:&4@:6UA9V4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:6-O;B!T;R!D:7-P;&%Y(&9O
M<B!T:&ES(&UE;G4@:71E;2X*("`@("`J($!P87)A;2!S=')I;F<@)&EC;VY?
M<&%T:"`@268@=&AE(&EC;VX@;&EV97,@:6X@82!N;VXM9&5F875L="!D:7)E
M8W1O<GDL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@('=H97)E
M(&ES(&ET/PH@("`@("H@0'!A<F%M('-T<FEN9R`D=&%R9V5T("`@("!)9B!T
M:&4@;&EN:R!N965D<R!T;R!O<&5N(&EN(&%N;W1H97(@9G)A;64@;W(*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@=VEN9&]W+"!W:&%T(&ES
M(&ET<R!N86UE/PH@("`@("H@0'!A<F%M('-T<FEN9R`D;VYC;&EC:R`@("!/
M;F-L:6-K(&IA=F%S8W)I<'0L(&EF(&1E<VER960N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1C;&%S<R`@("`@($-34R!C;&%S<R!F;W(@=&AE(&UE;G4@:71E
M;2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!I9"`H3D]4
M(&=U87)A;G1E960@=&\@8F4@86X@87)R87D@:6YD97@I(&]F('1H92!I=&5M
M"B`@("`@*B`@("`@("`@("`@("`@("`@(&IU<W0@861D960@=&\@=&AE(&UE
M;G4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$%R<F%Y*"1I=&5M*0H@("`@
M>PH@("`@("`@("1P;W,@/2!C;W5N="@D=&AI<RT^7VUE;G4I.PH@("`@("`@
M(&EF("@A)'!O<R!\?"`H)'!O<R`M(#$@(3T@;6%X*&%R<F%Y7VME>7,H)'1H
M:7,M/E]M96YU*2DI*2!["B`@("`@("`@("`@("1P;W,@/2!C;W5N="@D=&AI
M<RT^7VUE;G4I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]M96YU6R1P
M;W-=(#T@)&ET96T["@H@("`@("`@(')E='5R;B`D<&]S.PH@("`@?0H*("`@
M(&9U;F-T:6]N('-E=%!O<VET:6]N*"1I9"P@)'!O<RD*("`@('L*("`@("`@
M("!I9B`H(6ES<V5T*"1T:&ES+3Y?;65N=5LD:61=*2!\?"!I<W-E="@D=&AI
M<RT^7VUE;G5;)'!O<UTI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!]"@H@("`@("`@("1I=&5M(#T@)'1H:7,M/E]M96YU6R1I9%T[
M"B`@("`@("`@=6YS970H)'1H:7,M/E]M96YU6R1I9%TI.PH@("`@("`@("1T
M:&ES+3Y?;65N=5LD<&]S72`]("1I=&5M.PH*("`@("`@("!R971U<FX@=')U
M93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@=6YO<F1E<F5D
M(&QI<W0@<F5P<F5S96YT:6YG('1H92!L:7-T(&]F(&UE;G4@:71E;7,N(%-T
M>6QI;F<*("`@("`J(&ES(&1O;F4@=&AR;W5G:"!#4U,N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@($%N('5N;W)D97)E9"!L:7-T(&]F(&UE;G4@
M96QE;65N=',@=&AA="!C86X@8F4@96YT:7)E;'D*("`@("`J("`@("`@("`@
M("`@("`@("!S='EL960@=VET:"!#4U,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E;F1E<B@I"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF+"`D<F5G:7-T
M<GDL("1P<F5F<SL*"B`@("`@("`@)&=R87!H:6-S(#T@)')E9VES=')Y+3YG
M971);6%G941I<B@G:&]R9&4G*3L*("`@("`@("`D87!P(#T@)')E9VES=')Y
M+3YG971!<'`H*3L*"B`@("`@("`@:68@*"1T:&ES+3Y?;6%S:R`A/3T@2$]2
M1$5?345.55]-05-+7TY/3D4I('L*("`@("`@("`@("`@+RH@061D(&%N>2!C
M=7-T;VT@;65N=2!I=&5M<RX@*B\*("`@("`@("`@("`@)'1H:7,M/F%D9%-I
M=&5,:6YK<R@I.PH*("`@("`@("`@("`@+RH@061D(&%N>2!A<'`@;65N=2!I
M=&5M<RX@*B\*("`@("`@("`@("`@)'1H:7,M/F%D9$%P<$QI;FMS*"D["B`@
M("`@("`@?0H*("`@("`@("`O*B!!9&0@<V5T=&EN9W,@;&EN:RX@*B\*("`@
M("`@("!I9B`H)'1H:7,M/E]M87-K("8@2$]21$5?345.55]-05-+7U!21493
M("8F("1U<FP@/2!(;W)D93HZ9V5T4V5R=FEC94QI;FLH)V]P=&EO;G,G+"`D
M87!P*2D@>PH@("`@("`@("`@("`D=&AI<RT^861D*"1U<FPL(%\H(E]/<'1I
M;VYS(BDL("=P<F5F<RYP;F<G+"`D9W)A<&AI8W,I.PH@("`@("`@('T*"B`@
M("`@("`@+RH@061D('!R;V)L96T@;&EN:RX@*B\*("`@("`@("!I9B`H)'1H
M:7,M/E]M87-K("8@2$]21$5?345.55]-05-+7U!23T),14T@)B8@)'!R;V)L
M96U?;&EN:R`]($AO<F1E.CIG971397)V:6-E3&EN:R@G<')O8FQE;2<L("1A
M<'`I*2!["B`@("`@("`@("`@("1T:&ES+3YA9&0H)'!R;V)L96U?;&EN:RP@
M7R@B4')O8FQE;2(I+"`G<')O8FQE;2YP;F<G+"`D9W)A<&AI8W,I.PH@("`@
M("`@('T*"B`@("`@("`@+RH@061D(&AE;'`@;&EN:RX@*B\*("`@("`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+TAE;'`N<&AP)SL*("`@("`@("!I9B`H)'1H
M:7,M/E]M87-K("8@2$]21$5?345.55]-05-+7TA%3%`@)B8@)&AE;'!?;&EN
M:R`]($AO<F1E.CIG971397)V:6-E3&EN:R@G:&5L<"<L("1A<'`I*2!["B`@
M("`@("`@("`@("1T:&ES+3YA9&0H)&AE;'!?;&EN:RP@7R@B2&5L<"(I+"`G
M:&5L<%]I;F1E>"YP;F<G+"`D9W)A<&AI8W,L("=H96QP)RP@)W!O<'5P*'1H
M:7,N:')E9BD[(')E='5R;B!F86QS93LG*3L*("`@("`@("!]"@H@("`@("`@
M("\J($QO9VEN+TQO9V]U="X@*B\*("`@("`@("!I9B`H)'1H:7,M/E]M87-K
M("8@2$]21$5?345.55]-05-+7TQ/1TE.*2!["B`@("`@("`@("`@("\J($EF
M('1H92!S:61E8F%R(&ES;B=T(&%L=V%Y<R!S:&]W;BP@8G5T(&ES('-O;65T
M:6UE<PH@("`@("`@("`@("`@*B!S:&]W;BP@=&AE;B!L;V=O=70@;&EN:W,@
M<VAO=6QD(&)E('1O('1H92!P87)E;G0*("`@("`@("`@("`@("H@9G)A;64N
M("HO"B`@("`@("`@("`@("1A=71H7W1A<F=E="`](&YU;&P["B`@("`@("`@
M("`@(&EF("@D8V]N9ELG;65N=2==6R=A;'=A>7,G72!\?"`D<')E9G,M/F=E
M=%9A;'5E*"=S:&]W7W-I9&5B87(G*2D@>PH@("`@("`@("`@("`@("`@)&%U
M=&A?=&%R9V5T(#T@)U]P87)E;G0G.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("!I9B`H075T:#HZ9V5T075T:"@I*2!["B`@("`@("`@("`@("`@("!I
M9B`H)&QO9V]U=%]L:6YK(#T@2&]R9&4Z.F=E=%-E<G9I8V5,:6YK*"=L;V=O
M=70G+"`D87!P+"`A)'!R969S+3YG971686QU92@G<VAO=U]S:61E8F%R)RDI
M*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F%D9"@D;&]G;W5T7VQI
M;FLL(%\H(E],;V<@;W5T(BDL("=L;V=O=70N<&YG)RP@)&=R87!H:6-S+"`D
M875T:%]T87)G970L(&YU;&PL("=?7VYO<V5L96-T:6]N)RD["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("!I9B`H)&QO9VEN7VQI;FL@/2!(;W)D93HZ9V5T4V5R=FEC94QI;FLH)VQO
M9VEN)RP@)&%P<"DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^861D
M*"1L;V=I;E]L:6YK+"!?*")?3&]G(&EN(BDL("=L;V=I;BYP;F<G+"`D9W)A
M<&AI8W,L("1A=71H7W1A<F=E="P@;G5L;"P@)U]?;F]S96QE8W1I;VXG*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@+RH@3F\@;F5E9"!T;R!R971U<FX@86X@96UP='D@;&ES="!I9B!T
M:&5R92!A<F4@;F\@;65N=0H@("`@("`@("`J(&ET96US+B`J+PH@("`@("`@
M(&EF("@A8V]U;G0H)'1H:7,M/E]M96YU*2D@>PH@("`@("`@("`@("!R971U
M<FX@)R<["B`@("`@("`@?0H*("`@("`@("`O*B!3;W)T('1O(&UA=&-H(&5X
M<&QI8VET;'D@<V5T('!O<VET:6]N<RX@*B\*("`@("`@("!K<V]R="@D=&AI
M<RT^7VUE;G4I.PH@("`@("`@(&EF("@A96UP='DH)$=,3T)!3%-;)VYL<R==
M6R=R=&PG75LD1TQ/0D%,4ULG;&%N9W5A9V4G75TI*2`@>PH@("`@("`@("`@
M("`D=&AI<RT^7VUE;G4@/2!A<G)A>5]R979E<G-E*"1T:&ES+3Y?;65N=2D@
M.PH@("`@("`@('T*"B`@("`@("`@)&UE;G5?=FEE=R`]("1P<F5F<RT^9V5T
M5F%L=64H)VUE;G5?=FEE=R<I.PH@("`@("`@("1O=71P=70@/2`G/'5L/B<[
M"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]M96YU(&%S("1M*2!["B`@("`@
M("`@("`@("\J($ET96T@8VQA<W,@86YD('-E;&5C=&5D(&EN9&EC871I;VXN
M("HO"B`@("`@("`@("`@(&EF("@A:7-S970H)&U;)V-L87-S)UTI*2!["B`@
M("`@("`@("`@("`@("`O*B!4<GD@=&\@;6%T8V@@=&AE(&ET96TG<R!P871H
M(&%G86EN<W0@=&AE(&-U<G)E;G0*("`@("`@("`@("`@("`@("`J('-C<FEP
M="!F:6QE;F%M92!A<R!W96QL(&%S(&]T:&5R('!O<W-I8FQE(%523',@=&\*
M("`@("`@("`@("`@("`@("`J('1H:7,@<V-R:7!T+B`J+PH@("`@("`@("`@
M("`@("`@:68@*$UE;G4Z.FES4V5L96-T960H)&U;)W5R;"==*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1M6R=C;&%S<R==(#T@)V-U<G)E;G0G.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V5I9B`H)&U;)V-L87-S
M)UT@/3T]("=?7VYO<V5L96-T:6]N)RD@>PH@("`@("`@("`@("`@("`@=6YS
M970H)&U;)V-L87-S)UTI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O
M*B!)8V]N+B`J+PH@("`@("`@("`@("`D:6-O;B`]("<G.PH@("`@("`@("`@
M("!I9B`H)&UE;G5?=FEE=R`]/2`G:6-O;B<@?'P@)&UE;G5?=FEE=R`]/2`G
M8F]T:"<I('L*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&U;)VEC;VY?
M<&%T:"==*2D@>PH@("`@("`@("`@("`@("`@("`@("1M6R=I8V]N7W!A=&@G
M72`](&YU;&P["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M:6-O;B`]($AO<F1E.CII;6<H)&U;)VEC;VXG72P@2&]R9&4Z.G-T<FEP06-C
M97-S2V5Y*"1M6R=T97AT)UTI+"`G)RP@)&U;)VEC;VY?<&%T:"==*3L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@+RH@3&EN:RX@*B\*("`@("`@("`@
M("`@)&%C8V5S<VME>2`]($AO<F1E.CIG971!8V-E<W-+97DH)&U;)W1E>'0G
M72D["B`@("`@("`@("`@("1L:6YK(#T@2&]R9&4Z.FQI;FLH)&U;)W5R;"==
M+"`D;65N=5]V:65W(#T]("=I8V]N)R`_("1M6R=T97AT)UT@.B`G)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I<W-E="@D;5LG8VQA<W,G
M72D@/R`D;5LG8VQA<W,G72`Z("<G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&ES<V5T*"1M6R=T87)G970G72D@/R`D;5LG=&%R9V5T)UT@
M.B`G)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I<W-E="@D
M;5LG;VYC;&EC:R==*2`_("1M6R=O;F-L:6-K)UT@.B`G)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G)RP@)&%C8V5S<VME>2D["@H@("`@
M("`@("`@("`D;W5T<'5T("X]('-P<FEN=&8H(EQN/&QI/B5S)7,\8G(@+SXE
M<SPO83X\+VQI/B(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M;&EN:RP@)&EC;VXL("@D;65N=5]V:65W("$]("=I8V]N)RD@/R!(;W)D93HZ
M:&EG:&QI9VAT06-C97-S2V5Y*"1M6R=T97AT)UTL("1A8V-E<W-K97DI(#H@
M)R<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O=71P=70@+B`G/"]U
M;#XG.PH@("`@?0H*("`@("\J*@H@("`@("H@06YY(&QI;FMS('1O(&]T:&5R
M($AO<F1E(&%P<&QI8V%T:6]N<R!D969I;F5D(&EN(&%N(&%P<&QI8V%T:6]N
M)W,@8V]N9FEG"B`@("`@*B!F:6QE(&)Y('1H92`D8V]N9ELG;65N=2==6R=A
M<'!S)UT@87)R87D@87)E(&%D9&5D('1O('1H92!M96YU(&%R<F%Y+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!A9&1!<'!,:6YK<R@I"B`@("!["B`@("`@("`@
M9VQO8F%L("1C;VYF+"`D<F5G:7-T<GD["@H@("`@("`@(&EF("AI<W-E="@D
M8V]N9ELG;65N=2==6R=A<'!S)UTI("8F(&ES7V%R<F%Y*"1C;VYF6R=M96YU
M)UU;)V%P<',G72DI('L*("`@("`@("`@("`@9F]R96%C:"`H)&-O;F9;)VUE
M;G4G75LG87!P<R==(&%S("1A<'`I('L*("`@("`@("`@("`@("`@(&EF("@D
M<F5G:7-T<GDM/F=E="@G<W1A='5S)RP@)&%P<"D@(3T@)VEN86-T:79E)R`F
M)B`D<F5G:7-T<GDM/FAA<U!E<FUI<W-I;VXH)&%P<"P@4$5235-?4TA/5RDI
M('L*("`@("`@("`@("`@("`@("`@("`D=7)L(#T@)')E9VES=')Y+3YG971)
M;FET:6%L4&%G92@D87!P*3L*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES
M7V$H)'5R;"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^861D*$AO<F1E.CIU<FPH)'5R;"DL("1R96=I<W1R>2T^
M9V5T*"=N86UE)RP@)&%P<"DL("1R96=I<W1R>2T^9V5T*"=I8V]N)RP@)&%P
M<"DL("<G*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!!9&0@86YY(&]T:&5R(&QI;FMS(&9O=6YD(&EN("1T:&ES+3Y?;65N
M=69I;&4@=&\@8F4@:6YC;'5D960@:6X@=&AE"B`@("`@*B!M96YU+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!A9&13:71E3&EN:W,H*0H@("`@>PH@("`@("`@
M(&EF("A`:7-?<F5A9&%B;&4H)'1H:7,M/E]M96YU9FEL92DI('L*("`@("`@
M("`@("`@:6YC;'5D92`D=&AI<RT^7VUE;G5F:6QE.PH@("`@("`@("`@("!I
M9B`H:7-S970H)%]M96YU*2`F)B!I<U]A<G)A>2@D7VUE;G4I*2!["B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D7VUE;G4@87,@)&UE;G5I=&5M*2!["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/F%D9$%R<F%Y*"1M96YU:71E;2D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@=&\@<V5E(&EF('1H92!C=7)R
M96YT('5R;"!M871C:&5S('1H92!G:79E;B!U<FPN"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N("!7:&5T:&5R('1H92!G:79E;B!54DP@:7,@=&AE
M(&-U<G)E;G0@;&]C871I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES4V5L
M96-T960H)'5R;"D*("`@('L*("`@("`@("`D<V5R=F5R7W5R;"`]('!A<G-E
M7W5R;"@D7U-%4E9%4ELG4$A07U-%3$8G72D["B`@("`@("`@)&-H96-K7W5R
M;"`]('!A<G-E7W5R;"@D=7)L*3L*"B`@("`@("`@+RH@5')Y('1O(&UA=&-H
M('1H92!I=&5M)W,@<&%T:"!A9V%I;G-T('1H92!C=7)R96YT('-C<FEP=`H@
M("`@("`@("`@(&9I;&5N86UE(&%S('=E;&P@87,@;W1H97(@<&]S<VEB;&4@
M55),<R!T;R!T:&ES('-C<FEP="X@*B\*("`@("`@("!I9B`H:7-S970H)&-H
M96-K7W5R;%LG<&%T:"==*2`F)@H@("`@("`@("`@("`H*"1C:&5C:U]U<FQ;
M)W!A=&@G72`]/2`D<V5R=F5R7W5R;%LG<&%T:"==*2!\?`H@("`@("`@("`@
M("`@*"1C:&5C:U]U<FQ;)W!A=&@G72`N("=I;F1E>"YP:'`G(#T]("1S97)V
M97)?=7)L6R=P871H)UTI('Q\"B`@("`@("`@("`@("`H)&-H96-K7W5R;%LG
M<&%T:"==("X@)R]I;F1E>"YP:'`G(#T]("1S97)V97)?=7)L6R=P871H)UTI
M*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!F86QS93L*("`@('T*"GT*````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92]4<F5E+G!H<```````````````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`S-C8W,R`Q,#4Q-30S,S<T,"`P,C`W-S,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"B\J*@H@
M*B!$:7-P;&%Y(&5X=')A(&-O;'5M;G,@=&\@=&AE(&QE9G0@;V8@=&AE(&UA
M:6X@=')E92X*("HO"F1E9FEN92@G2$]21$5?5%)%15]%6%1205],1494)RP@
M,"D["@HO*BH*("H@1&ES<&QA>2!E>'1R82!C;VQU;6YS('1O('1H92!R:6=H
M="!O9B!T:&4@;6%I;B!T<F5E+@H@*B\*9&5F:6YE*"=(3U)$15]44D5%7T58
M5%)!7U))1TA4)RP@,2D["@HO*BH*("H@5&AE('!R96-E9&EN9R!T97AT+"!B
M969O<F4@=&AE($AO<F1E7U1R964@:6YS=&%N8V4@;F%M92P@=7-E9"!F;W(*
M("H@8V]L;&%P<V4O97AP86YD('-U8FUI<W-I;VYS+@H@*B\*9&5F:6YE*"=(
M3U)$15]44D5%7U1/1T=,12<L("=H=%]T;V=G;&5?)RD["@HO*BH*("H@5&AE
M($AO<F1E7U1R964Z.B!C;&%S<R!P<F]V:61E<R!A('1R964@=FEE=R!O9B!H
M:65R87)C:&EC86P@:6YF;W)M871I;VXN($ET"B`J(&%L;&]W<R!F;W(@97AP
M86YD:6YG+V-O;&QA<'-I;F<@;V8@8G)A;F-H97,@86YD(&UA:6YT86EN<R!T
M:&5I<B!S=&%T92X@270*("H@8V%N('=O<FL@=&]G971H97(@=VET:"!T:&4@
M2&]R9&5?5')E92!J879A<V-R:7!T(&-L87-S('1O(&%C:&EE=F4@=&AI<R!I
M;@H@*B!$2%1-3"!O;B!S=7!P;W)T960@8G)O=W-E<G,N"B`J"B`J($-O<'ER
M:6=H="`R,#`S+3(P,#8@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1R964O5')E
M92YP:'`L=B`Q+C0V+C8N,3$@,C`P-B\P,2\P,2`R,3HR.#HT,"!J86X@17AP
M("0*("H*("H@0&%U=&AO<B`@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O
M;3X*("H@0'!A8VMA9V4@2&]R9&5?5')E90H@*B!`<VEN8V4@("!(;W)D92`S
M+C`*("HO"F-L87-S($AO<F1E7U1R964@>PH*("`@("\J*@H@("`@("H@5&AE
M(&YA;64@;V8@=&AI<R!I;G-T86YC92X*("`@("`J"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)%]I;G-T86YC92`](&YU;&P["@H@("`@
M+RHJ"B`@("`@*B!(87-H('=I=&@@:&5A9&5R(&EN9F]R;6%T:6]N+@H@("`@
M("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?:&5A9&5R
M(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&-O;G1A:6YI
M;F<@86QL('1H92!T<F5E(&YO9&5S+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?;F]D97,@/2!A<G)A>2@I.PH*("`@("\J
M*@H@("`@("H@5&AE('1O<"UL979E;"!N;V1E<R!I;B!T:&4@=')E92X*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W)O;W1?
M;F]D97,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@2V5E<"!C;W5N="!O
M9B!H;W<@;6%N>2!E>'1R82!C;VQU;6YS('1H97)E(&%R92!O;B!T:&4@;&5F
M="!S:61E"B`@("`@*B!O9B!T:&4@;F]D92X*("`@("`J"B`@("`@*B!`=F%R
M(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?97AT<F%?8V]L<U]L969T(#T@
M,#L*"B`@("`O*BH*("`@("`J($ME97`@8V]U;G0@;V8@:&]W(&UA;GD@97AT
M<F$@8V]L=6UN<R!T:&5R92!A<F4@;VX@=&AE(')I9VAT('-I9&4*("`@("`J
M(&]F('1H92!N;V1E+@H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@
M("HO"B`@("!V87(@)%]E>'1R85]C;VQS7W)I9VAT(#T@,#L*"B`@("`O*BH*
M("`@("`J($]P=&EO;B!V86QU97,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)%]O<'1I;VYS(#T@87)R87DH)VQI;F5S)R`]
M/B!T<G5E*3L*"B`@("`O*BH*("`@("`J(%-T;W)E<R!T:&4@<V]R=&EN9R!C
M<FET97)I82!T96UP;W)A<FEL>2X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("HO"B`@("!V87(@)%]S;W)T0W)I=&5R:6$["@H@("`@+RHJ"B`@
M("`@*B!5<V4@<V5S<VEO;B!T;R!S=&]R92!C86-H960@5')E92!D871A/PH@
M("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]U
M<V5S97-S:6]N(#T@=')U93L*"B`@("`O*BH*("`@("`J(%-H;W5L9"!T:&4@
M=')E92!B92!R96YD97)E9"!S=&%T:6-A;&QY/PH@("`@("H*("`@("`J($!V
M87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]S=&%T:6,@/2!F86QS93L*
M"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(')E9F5R96YC
M92!T;R!A(&-O;F-R971E($AO<F1E7U1R964*("`@("`J(&EN<W1A;F-E(&)A
M<V5D(&]N("1N86UE(&%N9"`D<F5N9&5R97(N($ET('=I;&P@;VYL>2!C<F5A
M=&4@80H@("`@("H@;F5W(&EN<W1A;F-E(&EF(&YO($AO<F1E7U1R964@:6YS
M=&%N8V4@=VET:"!T:&4@<V%M92!P87)A;65T97)S"B`@("`@*B!C=7)R96YT
M;'D@97AI<W1S+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@
M:6YV;VME9"!A<SH*("`@("`J("`@)'9A<B`]("9(;W)D95]4<F5E.CIS:6YG
M;&5T;VXH)&YA;65;+"`D<F5N9&5R97)=*3L*("`@("`J"B`@("`@*B!`<W1A
M=&EC"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("`D;F%M92`@("`@($!S
M964@2&]R9&5?5')E93HZ9F%C=&]R>2X*("`@("`J($!P87)A;2!S=')I;F<@
M)')E;F1E<F5R("!`<V5E($AO<F1E7U1R964Z.F9A8W1O<GDN"B`@("`@*B!`
M<&%R86T@87)R87D@("1P87)A;7,@("`@0'-E92!(;W)D95]4<F5E.CIF86-T
M;W)Y+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?5')E92`@5&AE(&-O
M;F-R971E($AO<F1E7U1R964@<F5F97)E;F-E+"!O<B!014%27T5R<F]R(&]N
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(&5R<F]R+@H@("`@("HO"B`@
M("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1N86UE+"`D<F5N9&5R97(L("1P87)A
M;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@('-T871I8R`D:6YS=&%N8V5S
M(#T@87)R87DH*3L*"B`@("`@("`@)&ED(#T@)&YA;64@+B`G.B<@+B`D<F5N
M9&5R97(@+B`G.B<@+B!S97)I86QI>F4H)'!A<F%M<RD["B`@("`@("`@:68@
M*"%I<W-E="@D:6YS=&%N8V5S6R1I9%TI*2!["B`@("`@("`@("`@("1I;G-T
M86YC97-;)&ED72`]("9(;W)D95]4<F5E.CIF86-T;W)Y*"1N86UE+"`D<F5N
M9&5R97(L("1P87)A;7,I.PH@("`@("`@("`@("!I9B`H(21I;G-T86YC97-;
M)&ED72T^:7-3=7!P;W)T960H*2D@>PH@("`@("`@("`@("`@("`@)')E;F1E
M<F5R(#T@2&]R9&5?5')E93HZ9F%L;&)A8VLH)')E;F1E<F5R*3L*("`@("`@
M("`@("`@("`@(&EF("AI<U]A*"1R96YD97)E<BP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5N9&5R97(["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!R971U<FX@2&]R9&5?5')E
M93HZ<VEN9VQE=&]N*"1N86UE+"`D<F5N9&5R97(L("1P87)A;7,I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EN<W1A;F-E
M<ULD:61=.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T
M=7)N(&$@8V]N8W)E=&4@2&]R9&5?5')E92!I;G-T86YC92X*("`@("`J"B`@
M("`@*B!`<W1A=&EC"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M
M92`@("`@(%1H92!N86UE(&]F('1H:7,@=')E92!I;G-T86YC92X*("`@("`J
M($!P87)A;2!M:7AE9"`@)')E;F1E<F5R("!4:&4@='EP92!O9B!C;VYC<F5T
M92!(;W)D95]4<F5E('-U8F-L87-S('1O"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N+B!4:&ES(&ES(&)A<V5D(&]N('1H92!R96YD
M97)I;F<@9')I=F5R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M*"1R96YD97)E<BDN(%1H92!C;V1E(&ES(&1Y;F%M:6-A;&QY(&EN8VQU9&5D
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("`D<&%R86US("`@($%N>2!A9&1I=&EO
M;F%L('!A<F%M971E<G,@=&AE(&-O;G-T<G5C=&]R"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@;F5E9',N"B`@("`@*@H@("`@("H@0')E='5R
M;B!(;W)D95]4<F5E("!4:&4@;F5W;'D@8W)E871E9"!C;VYC<F5T92!(;W)D
M95]4<F5E(&EN<W1A;F-E+"!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F
M9F%C=&]R>2@D;F%M92P@)')E;F1E<F5R+"`D<&%R86US(#T@87)R87DH*2D*
M("`@('L*("`@("`@("`O*B!297%U:7)E('1H92!R96YD97)E<B!L:6(N("HO
M"B`@("`@("`@:6YC;'5D95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]4
M<F5E+R<@+B`D<F5N9&5R97(@+B`G+G!H<"<["@H@("`@("`@("1C;&%S<R`]
M("=(;W)D95]4<F5E7R<@+B`D<F5N9&5R97(["B`@("`@("`@:68@*&-L87-S
M7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1T<F5E(#T@)FYE=R`D
M8VQA<W,H)&YA;64L("1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1T<F5E(#T@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(EPB
M)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB*2P@)')E;F1E<F5R*2D[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1R964["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!4<GD@=&\@9F%L;"!B86-K('1O(&$@<VEM<&QE<B!R96YD
M97)E<BX*("`@("`J"B`@("`@*B!`<&%R86X@<W1R:6YG("1R96YD97)E<B`@
M5&AE(')E;F1E<F5R('1H870@=V4@8V%N)W0@:&%N9&QE+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG('P@4$5!4E]%<G)O<B`@5&AE(&YE>'0@8F5S
M="!R96YD97)E<BP@;W(@86X@97)R;W(*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:68@=V4G=F4@<G5N(&]U="!O9B!R96YD97)E<G,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&9A;&QB86-K*"1R96YD97)E<BD*("`@
M('L*("`@("`@("!S=VET8V@@*"1R96YD97)E<BD@>PH@("`@("`@(&-A<V4@
M)VIA=F%S8W)I<'0G.@H@("`@("`@("`@("!R971U<FX@)VAT;6PG.PH*("`@
M("`@("!C87-E("=H=&UL)SH*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H)V]U="!O9B!R96YD97)E<G,G*3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1N86UE("`@(%1H92!N86UE(&]F('1H:7,@=')E92!I
M;G-T86YC92X*("`@("`J($!P87)A;2!A<G)A>2`@)'!A<F%M<R`@061D:71I
M;VYA;"!P87)A;65T97)S+@H@("`@("H@/'!R93X*("`@("`J("=N;W-E<W-I
M;VXG("`M+2`@*&)O;VQE86XI($EF('1R=64L(&1O(&YO="!S=&]R92!T<F5E
M(&1A=&$@:6X@<V5S<VEO;BX*("`@("`J(#PO<')E/@H@("`@("HO"B`@("!F
M=6YC=&EO;B!(;W)D95]4<F5E*"1N86UE+"`D<&%R86US(#T@87)R87DH*2D*
M("`@('L*("`@("`@("`D=&AI<RT^7VEN<W1A;F-E(#T@)&YA;64["B`@("`@
M("`@)'1H:7,M/E]U<V5S97-S:6]N(#T@96UP='DH)'!A<F%M<ULG;F]S97-S
M:6]N)UTI.PH*("`@("`@("`O*B!3970@=7`@=&AE('-E<W-I;VX@9F]R(&QA
M=&5R('1O('-A=F4@=')E92!S=&%T97,N("HO"B`@("`@("`@:68@*"1T:&ES
M+3Y?=7-E<V5S<VEO;B`F)@H@("`@("`@("`@("`A:7-S970H)%]315-324].
M6R=H;W)D95]T<F5E)UU;)'1H:7,M/E]I;G-T86YC95TI*2!["B`@("`@("`@
M("`@("1?4T534TE/3ELG:&]R9&5?=')E92==6R1T:&ES+3Y?:6YS=&%N8V5=
M(#T@87)R87DH*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M96YD97)S('1H92!T<F5E+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N
M("1S=&%T:6,@($EF('1R=64@=&AE('1R964@;F]D97,@8V%N)W0@8F4@97AP
M86YD960@86YD"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!C;VQL
M87!S960@86YD('1H92!T<F5E(&=E=',@<F5N9&5R960@97AP86YD960N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<E1R964H)'-T871I8R`](&9A;'-E
M*0H@("`@>PH@("`@("`@(&5C:&\@)'1H:7,M/F=E=%1R964H)'-T871I8RD[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S(&%N(&]P=&EO;BX*("`@("`J
M($%V86EL86)L92!O<'1I;VYS.@H@("`@("H@/'!R93X*("`@("`J("`@86QT
M97)N871E("`@("TM("!!;'1E<FYA=&4@<VAA9&EN9R!I;B!T:&4@=&%B;&4_
M("AB;V]L96%N*0H@("`@("H@("!H:61E2&5A9&5R<R`@+2T@($1O;B=T(')E
M;F1E<B!A;GD@2%1-3"!F;W(@=&AE(&AE861E<B!R;W<L(&IU<W0@=7-E('1H
M92!W:61T:',N"B`@("`@*B`@(&-L87-S("`@("`@("`M+2`@5&AE(&-L87-S
M('1O('5S92!F;W(@=&AE('1A8FQE+B`H<W1R:6YG*0H@("`@("H@("!L:6YE
M<R`@("`@("`@+2T@(%-H;W<@=')E92!L:6YE<S\@*&)O;VQE86XI"B`@("`@
M*B`@(&UU;'1I;&EN92`@("`M+2`@1&\@=&AE(&YO9&4@;&%B96QS(&-O;G1A
M:6X@;&EN96)R96%K<S\@*&)O;VQE86XI"B`@("`@*B`\+W!R93X*("`@("`J
M"B`@("`@*B!`<&%R86T@;6EX960@)&]P=&EO;B`@5&AE(&]P=&EO;B!N86UE
M("UO<BT@86X@87)R87D@;V8@;W!T:6]N(&YA;64O=F%L=64*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!P86ER<RX*("`@("`J($!P87)A;2!M:7AE
M9"`D=F%L("`@("!4:&4@;W!T:6]N)W,@=F%L=64N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-E=$]P=&EO;B@D;W!T:6]N<RP@)'9A;'5E(#T@;G5L;"D*("`@
M('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1O<'1I;VYS*2D@>PH@("`@("`@
M("`@("`D;W!T:6]N<R`](&%R<F%Y*"1O<'1I;VYS(#T^("1V86QU92D["B`@
M("`@("`@?0H*("`@("`@("!F;W)E86-H("@D;W!T:6]N<R!A<R`D;W!T:6]N
M(#T^("1V86QU92D@>PH@("`@("`@("`@("`D=&AI<RT^7V]P=&EO;G-;)&]P
M=&EO;ET@/2`D=F%L=64["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@1V5T<R!A;B!O<'1I;VXG<R!V86QU92X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1O<'1I;VX@("!4:&4@;F%M92!O9B!T:&4@;W!T:6]N('1O
M(&9E=&-H+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&AT;6P@("`@5')U92!O
M<B!F86QS92!W:&5T:&5R('1O(&9O<FUA="!T:&4@<F5T=7)N('9A;'5E"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!I;B!H=&UL+B!$969A=6QT
M<R!T;R!F86QS92X*("`@("`J($!P87)A;2!S=')I;F<@)&1E9F%U;'0@($$@
M9&5F875L="!V86QU92!T;R!U<V4@:6X@8V%S92!N;VYE(&ES('-E="!F;W(*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('1H92!R97%U97-T960@
M;W!T:6]N+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!O<'1I
M;VXG<R!V86QU92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3W!T:6]N*"1O
M<'1I;VXL("1H=&UL(#T@9F%L<V4L("1D969A=6QT(#T@;G5L;"D*("`@('L*
M("`@("`@("`D=F%L=64@/2!N=6QL.PH*("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?;W!T:6]N<ULD;W!T:6]N72D@)B8@(6ES7VYU;&PH)&1E9F%U;'0I
M*2!["B`@("`@("`@("`@("\J(%)E<75E<W1E9"!O<'1I;VX@:&%S(&YO="!B
M965N(&)U="!T:&5R92!I<R!A"B`@("`@("`@("`@("`J(&1E9F%U;'0N("HO
M"B`@("`@("`@("`@("1V86QU92`]("1D969A=6QT.PH@("`@("`@('T@96QS
M96EF("AI<W-E="@D=&AI<RT^7V]P=&EO;G-;)&]P=&EO;ETI*2!["B`@("`@
M("`@("`@("\J(%)E<75E<W1E9"!O<'1I;VX@:&%S(&)E96X@<V5T+"!G970@
M:71S('9A;'5E+B`J+PH@("`@("`@("`@("`D=F%L=64@/2`D=&AI<RT^7V]P
M=&EO;G-;)&]P=&EO;ET["B`@("`@("`@?0H*("`@("`@("!I9B`H)&AT;6P@
M)B8@(6ES7VYU;&PH)'9A;'5E*2D@>PH@("`@("`@("`@("`O*B!&;W)M870@
M=F%L=64@9F]R(&AT;6P@;W5T<'5T+B`J+PH@("`@("`@("`@("`D=F%L=64@
M/2!S<')I;G1F*"<@)7,](B5S(B<L("1O<'1I;VXL("1V86QU92D["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)'9A;'5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@061D<R!A(&YO9&4@=&\@=&AE(&YO9&4@=')E92!A<G)A>2X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D:60@("`@("`@("`@(%1H92!U
M;FEQ=64@;F]D92!I9"X*("`@("`J($!P87)A;2!S=')I;F<@("1P87)E;G0@
M("`@("`@5&AE('!A<F5N="=S('5N:7%U92!N;V1E(&ED+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`@)&QA8F5L("`@("`@("!4:&4@=&5X="!L86)E;"!F;W(@
M=&AE(&YO9&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D:6YD96YT("`@("`@
M($1E<')E8V%T960L('1H:7,@:7,@8V%L8W5L871E9"!A=71O;6%T:6-A;&QY
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)A<V5D(&]N
M('1H92!P87)E;G0@;F]D92X*("`@("`J($!P87)A;2!B;V]L96%N("1E>'!A
M;F1E9"`@("`@27,@=&AI<R!L979E;"!E>'!A;F1E9"!O<B!N;W0N"B`@("`@
M*B!`<&%R86T@87)R87D@("`D<&%R86US("`@("`@($%N>2!O=&AE<B!P87)A
M;65T97)S('1O('-E="`H0'-E90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A9&1.;V1E4&%R86US*"D@9F]R(&9U;&P@9&5T86EL<RDN
M"B`@("`@*B!`<&%R86T@87)R87D@("`D97AT<F%?<FEG:'0@($%N>2!O=&AE
M<B!C;VQU;6YS('1O(&1I<W!L87D@=&\@=&AE(')I9VAT(&]F"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H92!T<F5E+@H@("`@("H@
M0'!A<F%M(&%R<F%Y("`@)&5X=')A7VQE9G0@("!!;GD@;W1H97(@8V]L=6UN
M<R!T;R!D:7-P;&%Y('1O('1H92!L969T(&]F"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('1H92!T<F5E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!A9&1.;V1E*"1I9"P@)'!A<F5N="P@)&QA8F5L+"`D:6YD96YT+"`D
M97AP86YD960@/2!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`D<&%R86US
M(#T@87)R87DH*2P@)&5X=')A7W)I9VAT(#T@87)R87DH*2P*("`@("`@("`@
M("`@("`@("`@("`@)&5X=')A7VQE9G0@/2!A<G)A>2@I*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?;F]D97-;)&ED75LG;&%B96PG72`]("1L86)E;#L*"B`@
M("`@("`@:68@*"1T:&ES+3Y?=7-E<V5S<VEO;BD@>PH@("`@("`@("`@("`D
M<V5S<VEO;E]S=&%T92`]("1?4T534TE/3ELG:&]R9&5?=')E92==6R1T:&ES
M+3Y?:6YS=&%N8V5=.PH@("`@("`@("`@("`D=&]G9VQE7VED(#T@571I;#HZ
M9V5T1F]R;41A=&$H2$]21$5?5%)%15]43T='3$4@+B`D=&AI<RT^7VEN<W1A
M;F-E*3L*("`@("`@("`@("`@:68@*"1I9"`]/2`D=&]G9VQE7VED*2!["B`@
M("`@("`@("`@("`@("`O*B!792!H879E(&$@=7)L('1O9V=L92!R97%U97-T
M(&9O<B!T:&ES(&YO9&4N("HO"B`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)'-E<W-I;VY?<W1A=&5;)V5X<&%N9&5D)UU;)&ED72DI('L*("`@("`@("`@
M("`@("`@("`@("`O*B!5<V4@<V5S<VEO;B!S=&%T92!I9B!I="!I<R!S970N
M("HO"B`@("`@("`@("`@("`@("`@("`@)&5X<&%N9&5D(#T@*"$D<V5S<VEO
M;E]S=&%T95LG97AP86YD960G75LD:61=*3L*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@+RH@3W1H97)W:7-E('5S92!W
M:&%T('=A<R!P87-S960@=&AR;W5G:"!T:&4*("`@("`@("`@("`@("`@("`@
M("`@*B!F=6YC=&EO;BX@*B\*("`@("`@("`@("`@("`@("`@("`D97AP86YD
M960@/2`H(21E>'!A;F1E9"D["B`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@+RH@4V%V92!T:&ES('-T871E('1O('-E<W-I;VXN("HO"B`@
M("`@("`@("`@("`@("`D7U-%4U-)3TY;)VAO<F1E7W1R964G75LD=&AI<RT^
M7VEN<W1A;F-E75LG97AP86YD960G75LD:61=(#T@)&5X<&%N9&5D.PH@("`@
M("`@("`@("!](&5L<V5I9B`H:7-S970H)'-E<W-I;VY?<W1A=&5;)V5X<&%N
M9&5D)UU;)&ED72DI('L*("`@("`@("`@("`@("`@("\J($EF('=E(&AA=F4@
M82!S879E9"!S97-S:6]N('-T871E('5S92!I="X@*B\*("`@("`@("`@("`@
M("`@("1E>'!A;F1E9"`]("1S97-S:6]N7W-T871E6R=E>'!A;F1E9"==6R1I
M9%T["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?
M;F]D97-;)&ED75LG97AP86YD960G72`]("1E>'!A;F1E9#L*"B`@("`@("`@
M+RH@268@86YY('!A<F%M<R!I;F-L=61E9"!H97)E(&%D9"!T:&5M(&YO=RX@
M*B\*("`@("`@("!I9B`H(65M<'1Y*"1P87)A;7,I*2!["B`@("`@("`@("`@
M("1T:&ES+3YA9&1.;V1E4&%R86US*"1I9"P@)'!A<F%M<RD["B`@("`@("`@
M?0H*("`@("`@("`O*B!)9B!A;GD@97AT<F$@8V]L=6UN<R!I;F-L=61E9"!H
M97)E(&%D9"!T:&5M(&YO=RX@*B\*("`@("`@("!I9B`H(65M<'1Y*"1E>'1R
M85]R:6=H="DI('L*("`@("`@("`@("`@)'1H:7,M/F%D9$YO9&5%>'1R82@D
M:60L($A/4D1%7U12145?15A44D%?4DE'2%0L("1E>'1R85]R:6=H="D["B`@
M("`@("`@?0H@("`@("`@(&EF("@A96UP='DH)&5X=')A7VQE9G0I*2!["B`@
M("`@("`@("`@("1T:&ES+3YA9&1.;V1E17AT<F$H)&ED+"!(3U)$15]44D5%
M7T585%)!7TQ%1E0L("1E>'1R85]L969T*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("AI<U]N=6QL*"1P87)E;G0I*2!["B`@("`@("`@("`@(&EF("@A:6Y?
M87)R87DH)&ED+"`D=&AI<RT^7W)O;W1?;F]D97,I*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7W)O;W1?;F]D97-;72`]("1I9#L*("`@("`@("`@("`@
M?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("AE;7!T>2@D=&AI
M<RT^7VYO9&5S6R1P87)E;G1=6R=C:&EL9')E;B==*2D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]N;V1E<ULD<&%R96YT75LG8VAI;&1R96XG72`](&%R
M<F%Y*"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%I;E]A<G)A
M>2@D:60L("1T:&ES+3Y?;F]D97-;)'!A<F5N=%U;)V-H:6QD<F5N)UTI*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7VYO9&5S6R1P87)E;G1=6R=C:&EL
M9')E;B==6UT@/2`D:60["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!9&1S(&%D9&ET:6]N86P@<&%R86UE=&5R<R!T
M;R!A(&YO9&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@("`@
M(%1H92!U;FEQ=64@;F]D92!I9"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R
M86US("!!;GD@;W1H97(@<&%R86UE=&5R<R!T;R!S970N"B`@("`@*B`\<')E
M/@H@("`@("H@8VQA<W,@("`@("TM("!#4U,@8VQA<W,@=&\@=7-E('=I=&@@
M=&AI<R!N;V1E"B`@("`@*B!I8V]N("`@("`@+2T@($EC;VX@=&\@9&ES<&QA
M>2!N97AT(&YO9&4*("`@("`J(&EC;VYA;'0@("`M+2`@06QT('1E>'0@=&\@
M=7-E(&9O<B!T:&4@:6-O;@H@("`@("H@:6-O;F1I<B`@("TM("!)8V]N(&1I
M<F5C=&]R>0H@("`@("H@:6-O;F]P96X@("TM("!)8V]N('1O(&EN9&EC871E
M('1H:7,@;F]D92!A<R!E>'!A;F1E9`H@("`@("H@;VYC;&EC:R`@("TM("!/
M;F-L:6-K(&5V96YT(&%T=&%C:&5D('1O('1H:7,@;F]D90H@("`@("H@=7)L
M("`@("`@("TM("!54DP@=&\@;&EN:R!T:&4@;F]D92!T;PH@("`@("H@=7)L
M8VQA<W,@("TM("!#4U,@8VQA<W,@9F]R('1H92!N;V1E)W,@55),"B`@("`@
M*B!T87)G970@("`@+2T@(%1A<F=E="!F;W(@=&AE("=U<FPG(&QI;FL*("`@
M("`J(#PO<')E/@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1.;V1E4&%R86US
M*"1I9"P@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"%I
M<U]A<G)A>2@D<&%R86US*2D@>PH@("`@("`@("`@("`D<&%R86US(#T@87)R
M87DH)'!A<F%M<RD["B`@("`@("`@?0H*("`@("`@("`D86QL;W=E9"`](&%R
M<F%Y*`H@("`@("`@("`@("`G8VQA<W,G+"`G:6-O;B<L("=I8V]N86QT)RP@
M)VEC;VYD:7(G+"`G:6-O;F]P96XG+`H@("`@("`@("`@("`G;VYC;&EC:R<L
M("=U<FPG+"`G=7)L8VQA<W,G+"`G=&%R9V5T)RP*("`@("`@("`I.PH*("`@
M("`@("!F;W)E86-H("@D<&%R86US(&%S("1P87)A;5]I9"`]/B`D<&%R86U?
M=F%L*2!["B`@("`@("`@("`@("\J(%-E="!O;FQY(&%L;&]W960@86YD(&YO
M;BUN=6QL('!A<F%M<RX@*B\*("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"1P
M87)A;5]I9"P@)&%L;&]W960I("8F("%I<U]N=6QL*"1P87)A;5]V86PI*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7VYO9&5S6R1I9%U;)'!A<F%M7VED
M72`]("1P87)A;5]V86P["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!9&1S(&5X=')A(&-O;'5M;G,@=&\@8F4@9&ES
M<&QA>65D('1O('1H92!S:61E(&]F('1H92!N;V1E+@H@("`@("H*("`@("`J
M($!P87)A;2!M:7AE9"`@("1I9"`@("`@5&AE('5N:7%U92!N;V1E(&ED+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)'-I9&4@("!7:&EC:"!S:61E('1O('!L
M86-E('1H92!E>'1R82!C;VQU;6YS(&]N+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("`@)&5X=')A("!%>'1R82!C;VQU;6YS('1O(&1I<W!L87DN"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&%D9$YO9&5%>'1R82@D:60L("1S:61E+"`D97AT<F$I
M"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D97AT<F$I*2!["B`@("`@
M("`@("`@("1E>'1R82`](&%R<F%Y*"1E>'1R82D["B`@("`@("`@?0H*("`@
M("`@("`D8V]L7V-O=6YT(#T@8V]U;G0H)&5X=')A*3L*"B`@("`@("`@<W=I
M=&-H("@D<VED92D@>PH@("`@("`@(&-A<V4@2$]21$5?5%)%15]%6%1205],
M1494.@H@("`@("`@("`@("`D=&AI<RT^7VYO9&5S6R1I9%U;)V5X=')A)UU;
M2$]21$5?5%)%15]%6%1205],149472`]("1E>'1R83L*("`@("`@("`@("`@
M:68@*"1C;VQ?8V]U;G0@/B`D=&AI<RT^7V5X=')A7V-O;'-?;&5F="D@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]E>'1R85]C;VQS7VQE9G0@/2`D8V]L
M7V-O=6YT.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("!C87-E($A/4D1%7U12145?15A44D%?4DE'2%0Z"B`@("`@("`@("`@
M("1T:&ES+3Y?;F]D97-;)&ED75LG97AT<F$G75M(3U)$15]44D5%7T585%)!
M7U))1TA472`]("1E>'1R83L*("`@("`@("`@("`@:68@*"1C;VQ?8V]U;G0@
M/B`D=&AI<RT^7V5X=')A7V-O;'-?<FEG:'0I('L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?97AT<F%?8V]L<U]R:6=H="`]("1C;VQ?8V]U;G0["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@4V]R=',@=&AE('1R964@8GD@=&AE('-P96-I9FEE
M9"!N;V1E('!R;W!E<G1Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&-R:71E<FEA("!4:&4@;F]D92!P<F]P97)T>2!T;R!S;W)T(&)Y+@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&ED("`@("`@(%5S960@:6YT97)N86QL>2!F
M;W(@<F5C=7)S:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!S;W)T*"1C<FET
M97)I82P@)&ED(#T@+3$I"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D=&AI
M<RT^7VYO9&5S6R1I9%U;)V-H:6QD<F5N)UTI*2!["B`@("`@("`@("`@(')E
M='5R;CL*("`@("`@("!]"@H@("`@("`@(&EF("@D8W)I=&5R:6$@/3T@)VME
M>2<I('L*("`@("`@("`@("`@:W-O<G0H)'1H:7,M/E]N;V1E<ULD:61=6R=C
M:&EL9')E;B==*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI
M<RT^7W-O<G1#<FET97)I82`]("1C<FET97)I83L*("`@("`@("`@("`@=7-O
M<G0H)'1H:7,M/E]N;V1E<ULD:61=6R=C:&EL9')E;B==+"!A<G)A>2@D=&AI
M<RP@)U]S;W)T)RDI.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)'1H
M:7,M/E]N;V1E<ULD:61=6R=C:&EL9')E;B==(&%S("1C:&EL9"D@>PH@("`@
M("`@("`@("`D=&AI<RT^<V]R="@D8W)I=&5R:6$L("1C:&EL9"D["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@2&5L<&5R(&UE=&AO9"!F;W(@
M<V]R="@I('1O(&-O;7!A<F4@='=O('1R964@96QE;65N=',N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S
M;W)T*"1A+"`D8BD*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?
M;F]D97-;)&%=6R1T:&ES+3Y?<V]R=$-R:71E<FEA72DI('L*("`@("`@("`@
M("`@<F5T=7)N(#$["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)'1H
M:7,M/E]N;V1E<ULD8EU;)'1H:7,M/E]S;W)T0W)I=&5R:6%=*2D@>PH@("`@
M("`@("`@("!R971U<FX@+3$["B`@("`@("`@?0H@("`@("`@(')E='5R;B!S
M=')C;VQL*"1T:&ES+3Y?;F]D97-;)&%=6R1T:&ES+3Y?<V]R=$-R:71E<FEA
M72P*("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VYO9&5S6R1B75LD
M=&AI<RT^7W-O<G1#<FET97)I85TI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!W:&5T:&5R('1H92!S<&5C:69I960@;F]D92!I<R!C=7)R96YT
M;'D@97AP86YD960N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1I9"`@
M5&AE('5N:7%U92!N;V1E(&ED+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5')U92!I9B!T:&4@<W!E8VEF:65D(&YO9&4@:7,@97AP86YD960N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES17AP86YD960H)&ED*0H@("`@>PH@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VYO9&5S6R1I9%TI*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7VYO9&5S6R1I9%U;)V5X<&%N9&5D)UT[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O
M*BH*("`@("`J($%D9',@8V]L=6UN(&AE861E<G,@=&\@=&AE('1R964@=&%B
M;&4N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1H96%D97(@($%N(&%R
M<F%Y(&-O;G1A:6YI;F<@:&%S:&5S('=I=&@@:&5A9&5R"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@:6YF;W)M871I;VXN(%1H92!F;VQL;W=I;F<@
M:V5Y<R!A<F4@86QL;W=E9#H*("`@("`J(#QP<F4^"B`@("`@*B!H=&UL("`M
M+2!4:&4@2%1-3"!C;VYT96YT(&]F('1H92!H96%D97(@8V5L;`H@("`@("H@
M=VED=&@@+2T@5&AE('=I9'1H(&]F('1H92!H96%D97(@8V5L;`H@("`@("H@
M86QI9VX@+2T@5&AE(&%L:6=N;65N="!I;G-I9&4@=&AE(&AE861E<B!C96QL
M"B`@("`@*B!C;&%S<R`M+2!4:&4@0U-3(&-L87-S(&]F('1H92!H96%D97(@
M8V5L;`H@("`@("H@/"]P<F4^"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$AE
M861E<B@D:&5A9&5R*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:&5A9&5R(#T@
M)&AE861E<CL*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@:6YD96YT
M(&QE=F5L(&9O<B!E86-H(&YO9&4@:6X@=&AE('1R964N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]B=6EL9$EN9&5N=',H)&YO9&5S+"`D:6YD96YT(#T@,"D*
M("`@('L*("`@("`@("!F;W)E86-H("@D;F]D97,@87,@)&ED*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?;F]D97-;)&ED75LG:6YD96YT)UT@/2`D:6YD96YT
M.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?;F]D97-;)&ED75LG
M8VAI;&1R96XG72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?8G5I;&1)
M;F1E;G1S*"1T:&ES+3Y?;F]D97-;)&ED75LG8VAI;&1R96XG72P@)&EN9&5N
M="`K(#$I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O4V5R:6%L:7IE+G!H<```````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,C(Q,3<@,3`U,34T,S,W-#`@,#(R,#`W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"@ID
M969I;F4H)U-%4DE!3$E:15]53DM.3U=.)RP@+3$I.PID969I;F4H)U-%4DE!
M3$E:15].3TY%)RP@,"D["F1E9FEN92@G4T5224%,25I%7U=$1%@G+"`Q*3L*
M9&5F:6YE*"=315))04Q)6D5?0EI)4"<L(#(I.PID969I;F4H)U-%4DE!3$E:
M15])34%0."<L(#,I.PID969I;F4H)U-%4DE!3$E:15])34%0551&-R<L(#0I
M.PID969I;F4H)U-%4DE!3$E:15])34%0551&."<L(#4I.PID969I;F4H)U-%
M4DE!3$E:15]"05-)0R<L(#8I.PID969I;F4H)U-%4DE!3$E:15]'6E]$149,
M051%)RP@-RD["F1E9FEN92@G4T5224%,25I%7T=:7T-/35!215-3)RP@."D[
M"F1E9FEN92@G4T5224%,25I%7T=:7T5.0T]$)RP@.2D["F1E9FEN92@G4T52
M24%,25I%7T)!4T4V-"<L(#$P*3L*9&5F:6YE*"=315))04Q)6D5?4U%,6$U,
M)RP@,3$I.PID969I;F4H)U-%4DE!3$E:15]205<G+"`Q,BD["F1E9FEN92@G
M4T5224%,25I%7U523"<L(#$S*3L*9&5F:6YE*"=315))04Q)6D5?551&-R<L
M(#$T*3L*"B\J*B!5<V4@4T5224%,25I%7U541C<@86YD(%-%4DE!3$E:15]"
M05-)0R!S=&%C:V5D+B`@*B\*9&5F:6YE*"=315))04Q)6D5?551&-U]"05-)
M0R<L(#$U*3L*"@HO*BH*("H@5&AE(%-E<FEA;&EZ93HZ(&-L87-S('!R;W9I
M9&5S('9A<FEO=7,@;65T:&]D<R!O9B!E;F-A<'-U;&%T:6YG(&1A=&$N"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+U-E<FEA;&EZ92]397)I86QI>F4N<&AP
M+'8@,2XR-2XQ,"XY(#(P,#8O,#$O,#$@,C$Z,C@Z,S0@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`Q+3(P,#8@4W1E<&AA;F4@2'5T:&5R(#QS:'5T
M:&5R0&)I9V9O;W0N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M(%-T97!H86YE($AU=&AE<B`\<VAU=&AE<D!B:6=F;V]T+F-O;3X*("H@0'-I
M;F-E("`@2&]R9&4@,BXP"B`J($!P86-K86=E($AO<F1E7U-E<FEA;&EZ90H@
M*B\*8VQA<W,@2&]R9&5?4V5R:6%L:7IE('L*"B`@("`O*BH*("`@("`J(%-E
M<FEA;&EZ92!A('9A;'5E+@H@("`@("H*("`@("`J(%-E92!T:&4@;&ES="!O
M9B!C;VYS=&%N=',@870@=&AE('1O<"!O9B!T:&4@9FEL92!F;W(@=&AE('-E
M<FEA;&EZ:6YG"B`@("`@*B!T96-H;FEQ=65S('1H870@8V%N(&)E('5S960N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1D871A("`@(%1H92!D871A
M('1O(&)E('-E<FEA;&EZ960N"B`@("`@*B!`<&%R86T@;6EX960@)&UO9&4@
M("`@5&AE(&UO9&4@;V8@<V5R:6%L:7IA=&EO;BX@0V%N(&)E(&5I=&AE<B!A
M('-I;F=L90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&UO9&4@;W(@
M87)R87D@;V8@;6]D97,N("!)9B!A<G)A>2P@=VEL;"!B90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@('-E<FEA;&EZ960@:6X@=&AE(&]R9&5R('!R
M;W9I9&5D+@H@("`@("H@0'!A<F%M(&UI>&5D("1P87)A;7,@($%N>2!A9&1I
M=&EO;F%L('!A<F%M971E<G,@=&AE('-E<FEA;&EZ871I;VX@;65T:&]D"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@<F5Q=6ER97,N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!S97)I86QI>F5D(&1A=&$N"B`@
M("`@*B`@("`@("`@("`@("`@("`@4F5T=7)N<R!014%27T5R<F]R(&]N(&5R
M<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!S97)I86QI>F4H)&1A=&$L("1M
M;V1E(#T@87)R87DH4T5224%,25I%7T)!4TE#*2P@)'!A<F%M<R`](&YU;&PI
M"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D;6]D92DI('L*("`@("`@
M("`@("`@)&UO9&4@/2!A<G)A>2@D;6]D92D["B`@("`@("`@?0H*("`@("`@
M("`O*B!2971U<FX@;F]W(&EF(&YO(&1A=&$N("HO"B`@("`@("`@:68@*&5M
M<'1Y*"1D871A*2`F)B`A:7-?87)R87DH)&1A=&$I*2!["B`@("`@("`@("`@
M(')E='5R;B`D9&%T83L*("`@("`@("!]"@H@("`@("`@("\J(%!A<G-E('1H
M<F]U9V@@=&AE(&QI<W0@;V8@<V5R:6%L:7II;F<@;6]D97,N("HO"B`@("`@
M("`@9F]R96%C:"`H)&UO9&4@87,@)'9A;"D@>PH@("`@("`@("`@("`O*B!#
M:&5C:R!T;R!M86ME('-U<F4@=&AE(&UO9&4@:7,@<W5P<&]R=&5D+B`J+PH@
M("`@("`@("`@("!I9B`H(4AO<F1E7U-E<FEA;&EZ93HZ:&%S0V%P86)I;&ET
M>2@D=F%L*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)U5N<W5P<&]R=&5D('-E<FEA;&EZ871I;VX@='EP92<I.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@($AO<F1E7U-E<FEA;&EZ93HZ7W-E<FEA
M;&EZ92@D9&%T82P@)'9A;"P@)'!A<F%M<RD["B`@("`@("`@("`@(&EF("AI
M<U]A*"1D871A+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1D871A.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5R:6%L:7IE(&1A=&$N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M(&UI>&5D("8D9&%T82`@("`@("`@("`@(%1H92!D871A('1O(&)E
M('-E<FEA;&EZ960N"B`@("`@*B!`<&%R86T@;6EX960@)&UO9&4@("`@("`@
M("`@("`@5&AE(&UO9&4@;V8@<V5R:6%L:7IA=&EO;BX@0V%N(&)E"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@96ET:&5R(&$@<VEN
M9VQE(&UO9&4@;W(@87)R87D@;V8@;6]D97,N"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@268@87)R87DL('=I;&P@8F4@<V5R:6%L
M:7IE9"!I;B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!O<F1E<B!P<F]V:61E9"X*("`@("`J($!P87)A;2!M:7AE9"`D<&%R
M86US("!!;GD@861D:71I;VYA;"!P87)A;65T97)S('1H92!S97)I86QI>F%T
M:6]N(&UE=&AO9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(')E<75I
M<F5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<V5R:6%L:7IE*"8D9&%T82P@
M)&UO9&4L("1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@("`@('-W:71C:"`H
M)&UO9&4I('L*("`@("`@("!C87-E(%-%4DE!3$E:15].3TY%.@H@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!315))04Q)6D5?0EI)4#H*("`@
M("`@("`@("`@)&1A=&$@/2!B>F-O;7!R97-S*"1D871A+"`Y+"`S,"D["B`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%-%4DE!3$E:15]71$18
M.@H@("`@("`@("`@("`D9&%T82`]('=D9'A?<V5R:6%L:7IE7W9A;'5E*"1D
M871A*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@4T5224%,
M25I%7TE-05`X.@H@("`@("`@("`@("`D9&%T82`](&EM87!?.&)I="@D9&%T
M82D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%-%4DE!3$E:
M15])34%0551&-SH*("`@("`@("`@("`@)&1A=&$@/2!I;6%P7W5T9C=?96YC
M;V1E*"1D871A*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@
M4T5224%,25I%7TE-05!55$8X.@H@("`@("`@("`@("`D9&%T82`](&EM87!?
M=71F."@D9&%T82D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E
M(%-%4DE!3$E:15]'6E]$149,051%.@H@("`@("`@("`@("`D9&%T82`](&=Z
M9&5F;&%T92@D9&%T82P@.2D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!C87-E(%-%4DE!3$E:15]"05-)0SH*("`@("`@("`@("`@)&1A=&$@/2!S
M97)I86QI>F4H)&1A=&$I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M8V%S92!315))04Q)6D5?1UI?0T]-4%)%4U,Z"B`@("`@("`@("`@("1D871A
M(#T@9WIC;VUP<F5S<R@D9&%T82P@.2D["B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!C87-E(%-%4DE!3$E:15]"05-%-C0Z"B`@("`@("`@("`@("1D
M871A(#T@8F%S938T7V5N8V]D92@D9&%T82D["B`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("!C87-E(%-%4DE!3$E:15]'6E]%3D-/1#H*("`@("`@("`@
M("`@)&1A=&$@/2!G>F5N8V]D92@D9&%T82P@.2D["B`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("!C87-E(%-%4DE!3$E:15]205<Z"B`@("`@("`@("`@
M("1D871A(#T@<F%W=7)L96YC;V1E*"1D871A*3L*("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@(&-A<V4@4T5224%,25I%7U523#H*("`@("`@("`@("`@
M)&1A=&$@/2!U<FQE;F-O9&4H)&1A=&$I.PH@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@8V%S92!315))04Q)6D5?4U%,6$U,.@H@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)T1"+G!H<"<["B`@("`@("`@("`@("1S<6PR>&UL(#T@
M)FYE=R!X;6Q?<W%L,GAM;"@I.PH@("`@("`@("`@("`D9&%T82`]("1S<6PR
M>&UL+3YG971834PH)&1A=&$I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@8V%S92!315))04Q)6D5?551&-SH*("`@("`@("`@("`@<F5Q=6ER95]O
M;F-E("=(;W)D92]3=')I;F<N<&AP)SL*("`@("`@("`@("`@)&1A=&$@/2!3
M=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1D871A+"`D<&%R86US+"`G=71F+3<G
M*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@4T5224%,25I%
M7U541C=?0D%324,Z"B`@("`@("`@("`@($AO<F1E7U-E<FEA;&EZ93HZ7W-E
M<FEA;&EZ92@D9&%T82P@4T5224%,25I%7U541C<L("1P87)A;7,I.PH@("`@
M("`@("`@("!(;W)D95]397)I86QI>F4Z.E]S97)I86QI>F4H)&1A=&$L(%-%
M4DE!3$E:15]"05-)0RP@)'!A<F%M<RD["B`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%5N<V5R:6%L:7IE(&$@
M=F%L=64N"B`@("`@*@H@("`@("H@4V5E('1H92!L:7-T(&]F(&-O;G-T86YT
M<R!A="!T:&4@=&]P(&]F('1H92!F:6QE(&9O<B!T:&4@<V5R:6%L:7II;F<*
M("`@("`J('1E8VAN:7%U97,@=&AA="!C86X@8F4@=7-E9"X*("`@("`J"B`@
M("`@*B!`<&%R86T@;6EX960@)&1A=&$@("`@("`@("`@("`@5&AE(&1A=&$@
M=&\@8F4@=6YS97)I86QI>F5D+@H@("`@("H@0'!A<F%M(&UI>&5D("1M;V1E
M("`@(%1H92!M;V1E(&]F('5N<V5R:6%L:7IA=&EO;BX@($-A;B!B92!E:71H
M97(@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('-I;F=L92!M;V1E
M(&]R(&%R<F%Y(&]F(&UO9&5S+B`@268@87)R87DL('=I;&P@8F4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("!U;G-E<FEA;&EZ960@:6X@=&AE(&]R
M9&5R('!R;W9I9&5D+@H@("`@("H@0'!A<F%M(&UI>&5D("1P87)A;7,@($%N
M>2!A9&1I=&EO;F%L('!A<F%M971E<G,@=&AE('5N<V5R:6%L:7IA=&EO;@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@(&UE=&AO9"!R97%U:7)E<RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('5N<V5R:6%L:7IE
M9"!D871A+@H@("`@("H@("`@("`@("`@("`@("`@(%)E='5R;G,@4$5!4E]%
M<G)O<B!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@=6YS97)I86QI
M>F4H)&1A=&$L("1M;V1E(#T@4T5224%,25I%7T)!4TE#+"`D<&%R86US(#T@
M;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1M;V1E*2D@>PH@
M("`@("`@("`@("`D;6]D92`](&%R<F%Y*"1M;V1E*3L*("`@("`@("!]"@H@
M("`@("`@("\J(%)E='5R;B!N;W<@:68@;F\@9&%T82X@*B\*("`@("`@("!I
M9B`H96UP='DH)&1A=&$I*2!["B`@("`@("`@("`@(')E='5R;B`D9&%T83L*
M("`@("`@("!]"@H@("`@("`@("\J(%!A<G-E('1H<F]U9V@@=&AE(&QI<W0@
M;V8@=6YS97)I86QI>FEN9R!M;V1E<RX@*B\*("`@("`@("!F;W)E86-H("@D
M;6]D92!A<R`D=F%L*2!["B`@("`@("`@("`@("\J($-H96-K('1O(&UA:V4@
M<W5R92!T:&4@;6]D92!I<R!S=7!P;W)T960N("HO"B`@("`@("`@("`@(&EF
M("@A2&]R9&5?4V5R:6%L:7IE.CIH87-#87!A8FEL:71Y*"1V86PI*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G56YS=7!P
M;W)T960@=6YS97)I86QI>F%T:6]N('1Y<&4G*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!(;W)D95]397)I86QI>F4Z.E]U;G-E<FEA;&EZ92@D9&%T
M82P@)'9A;"P@)'!A<F%M<RD["B`@("`@("`@("`@(&EF("AI<U]A*"1D871A
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1D871A.PH@
M("`@?0H*("`@("\J*@H@("`@("H@56YS97)I86QI>F4@9&%T82X*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@
M;6EX960@)B1D871A("`@5&AE(&1A=&$@=&\@8F4@=6YS97)I86QI>F5D+@H@
M("`@("H@0'!A<F%M(&UI>&5D("1M;V1E("`@(%1H92!M;V1E(&]F('5N<V5R
M:6%L:7IA=&EO;BX@0V%N(&)E(&5I=&AE<B!A"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@<VEN9VQE(&UO9&4@;W(@87)R87D@;V8@;6]D97,N("!)
M9B!A<G)A>2P@=VEL;"!B90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M('5N<V5R:6%L:7IE9"!I;B!T:&4@;W)D97(@<')O=FED960N"B`@("`@*B!`
M<&%R86T@;6EX960@)'!A<F%M<R`@06YY(&%D9&ET:6]N86P@<&%R86UE=&5R
M<R!T:&4@=6YS97)I86QI>F%T:6]N"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@;65T:&]D(')E<75I<F5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M=6YS97)I86QI>F4H)B1D871A+"`D;6]D92P@)'!A<F%M<R`](&YU;&PI"B`@
M("!["B`@("`@("`@<W=I=&-H("@D;6]D92D@>PH@("`@("`@(&-A<V4@4T52
M24%,25I%7TY/3D4Z"B`@("`@("`@8V%S92!315))04Q)6D5?4U%,6$U,.@H@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!315))04Q)6D5?4D%7
M.@H@("`@("`@("`@("`D9&%T82`](')A=W5R;&1E8V]D92@D9&%T82D["B`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%-%4DE!3$E:15]54DPZ
M"B`@("`@("`@("`@("1D871A(#T@=7)L9&5C;V1E*"1D871A*3L*("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@4T5224%,25I%7U=$1%@Z"B`@
M("`@("`@("`@("1D871A(#T@=V1D>%]D97-E<FEA;&EZ92@D9&%T82D["B`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%-%4DE!3$E:15]"6DE0
M.@H@("`@("`@("`@("`D9&%T82`](&)Z9&5C;VUP<F5S<R@D9&%T82P@9F%L
M<V4I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!315))04Q)
M6D5?24U!4%541C<Z"B`@("`@("`@("`@("1D871A(#T@:6UA<%]U=&8W7V1E
M8V]D92@D9&%T82D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E
M(%-%4DE!3$E:15]"05-)0SH*("`@("`@("`@("`@)&1A=&$@/2!`=6YS97)I
M86QI>F4H)&1A=&$I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S
M92!315))04Q)6D5?1UI?1$5&3$%413H*("`@("`@("`@("`@)&1A=&$@/2!G
M>FEN9FQA=&4H)&1A=&$I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M8V%S92!315))04Q)6D5?0D%3138T.@H@("`@("`@("`@("`D9&%T82`](&)A
M<V4V-%]D96-O9&4H)&1A=&$I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@8V%S92!315))04Q)6D5?1UI?0T]-4%)%4U,Z"B`@("`@("`@("`@("1D
M871A(#T@9WIU;F-O;7!R97-S*"1D871A*3L*("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@(&-A<V4@4T5224%,25I%7U541C<Z"B`@("`@("`@("`@(')E
M<75I<F5?;VYC92`G2&]R9&4O4W1R:6YG+G!H<"<["B`@("`@("`@("`@("1D
M871A(#T@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D9&%T82P@)W5T9BTW)RP@
M)'!A<F%M<RD["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%-%
M4DE!3$E:15]55$8W7T)!4TE#.@H@("`@("`@("`@("!(;W)D95]397)I86QI
M>F4Z.E]U;G-E<FEA;&EZ92@D9&%T82P@4T5224%,25I%7T)!4TE#+"`D<&%R
M86US*3L*("`@("`@("`@("`@2&]R9&5?4V5R:6%L:7IE.CI?=6YS97)I86QI
M>F4H)&1A=&$L(%-%4DE!3$E:15]55$8W+"`D<&%R86US*3L*("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0VAE
M8VL@=VAE=&AE<B!O<B!N;W0@82!S97)I86QI>F%T:6]N(&UE=&AO9"!I<R!S
M=7!P;W)T960N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&UO9&4@
M(%1H92!S97)I86QI>F%T:6]N(&UE=&AO9"X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%1R=64@:68@<W5P<&]R=&5D+"!F86QS92!I9B!N;W0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA<T-A<&%B:6QI='DH)&UO9&4I"B`@
M("!["B`@("`@("`@<W=I=&-H("@D;6]D92D@>PH@("`@("`@(&-A<V4@4T52
M24%,25I%7T):25`Z"B`@("`@("`@("`@(')E='5R;B!5=&EL.CIE>'1E;G-I
M;VY%>&ES=',H)V)Z,B<I.PH*("`@("`@("!C87-E(%-%4DE!3$E:15]71$18
M.@H@("`@("`@("`@("!R971U<FX@571I;#HZ97AT96YS:6]N17AI<W1S*"=W
M9&1X)RD["@H@("`@("`@(&-A<V4@4T5224%,25I%7TE-05!55$8W.@H@("`@
M("`@(&-A<V4@4T5224%,25I%7TE-05!55$8X.@H@("`@("`@(&-A<V4@4T52
M24%,25I%7TE-05`X.@H@("`@("`@("`@("!R971U<FX@571I;#HZ97AT96YS
M:6]N17AI<W1S*"=I;6%P)RD["@H@("`@("`@(&-A<V4@4T5224%,25I%7T=:
M7T1%1DQ!5$4Z"B`@("`@("`@8V%S92!315))04Q)6D5?1UI?0T]-4%)%4U,Z
M"B`@("`@("`@8V%S92!315))04Q)6D5?1UI?14Y#3T0Z"B`@("`@("`@("`@
M(')E='5R;B!5=&EL.CIE>'1E;G-I;VY%>&ES=',H)WIL:6(G*3L*"B`@("`@
M("`@8V%S92!315))04Q)6D5?4U%,6$U,.@H@("`@("`@("`@("!R971U<FX@
M0&EN8VQU9&5?;VYC92`G6$U,+W-Q;#)X;6PN<&AP)SL*"B`@("`@("`@8V%S
M92!315))04Q)6D5?3D].13H*("`@("`@("!C87-E(%-%4DE!3$E:15]"05-)
M0SH*("`@("`@("!C87-E(%-%4DE!3$E:15]"05-%-C0Z"B`@("`@("`@8V%S
M92!315))04Q)6D5?4D%7.@H@("`@("`@(&-A<V4@4T5224%,25I%7U523#H*
M("`@("`@("!C87-E(%-%4DE!3$E:15]55$8W.@H@("`@("`@(&-A<V4@4T52
M24%,25I%7U541C=?0D%324,Z"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH*
M("`@("`@("!D969A=6QT.@H@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H@("`@?0H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T1A=&$N<&AP````
M````````````````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#,T-38Q
M(#$P-3$U-#,S-S0P(#`R,#<S-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=014%2+G!H
M<"<["@HO+R!);7!O<G0@8V]N<W1A;G1S"B\J*B!);7!O<G0@86QR96%D>2!M
M87!P960@8W-V(&1A=&$N("`@("`@("`J+R!D969I;F4H)TE-4$]25%]-05!0
M140G+"`Q*3L*+RHJ($UA<"!D871E(&%N9"!T:6UE(&5N=')I97,@;V8@8W-V
M(&1A=&$N("HO(&1E9FEN92@G24U03U)47T1!5$5424U%)RP@,BD["B\J*B!)
M;7!O<G0@9V5N97)I8R!#4U8@9&%T82X@("`@("`@("`@("`@("`J+R!D969I
M;F4H)TE-4$]25%]#4U8G+"`S*3L*+RHJ($EM<&]R="!-4R!/=71L;V]K(&1A
M=&$N("`@("`@("`@("`@("`@("HO(&1E9FEN92@G24U03U)47T]55$Q/3TLG
M+"`T*3L*+RHJ($EM<&]R="!V0V%L96YD87(O:4-A;&5N9&%R(&1A=&$N("`@
M("`@("HO(&1E9FEN92@G24U03U)47TE#04Q%3D1!4B<L(#4I.PHO*BH@26UP
M;W)T('9#87)D<RX@("`@("`@("`@("`@("`@("`@("`@("`@*B\@9&5F:6YE
M*"=)35!/4E1?5D-!4D0G+"`V*3L*+RHJ($EM<&]R="!G96YE<FEC('1S=B!D
M871A+B`@("`@("`@("`@("`@("HO(&1E9FEN92@G24U03U)47U135B<L(#<I
M.PHO*BH@26UP;W)T($UU;&)E<G)Y(&%D9')E<W,@8F]O:R!D871A("`@("`@
M*B\@9&5F:6YE*"=)35!/4E1?355,0D524EDG+"`X*3L*+RHJ($EM<&]R="!0
M:6YE(&%D9')E<W,@8F]O:R!D871A+B`@("`@("`@("HO(&1E9FEN92@G24U0
M3U)47U!)3D4G+"`Y*3L*+RHJ($EM<&]R="!F:6QE+B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("HO(&1E9FEN92@G24U03U)47T9)3$4G+"`Q,2D["B\J
M*B!);7!O<G0@9&%T82X@("`@("`@("`@("`@("`@("`@("`@("`@("`J+R!D
M969I;F4H)TE-4$]25%]$051!)RP@,3(I.PH*+R\@17AP;W)T(&-O;G-T86YT
M<PHO*BH@17AP;W)T(&=E;F5R:6,@0U-6(&1A=&$N("HO(&1E9FEN92@G15A0
M3U)47T-35B<L(#$P,"D["B\J*B!%>'!O<G0@:4-A;&5N9&%R(&1A=&$N("`@
M*B\@9&5F:6YE*"=%6%!/4E1?24-!3$5.1$%2)RP@,3`Q*3L*+RHJ($5X<&]R
M="!V0V%R9',N("`@("`@("`@("`J+R!D969I;F4H)T584$]25%]60T%21"<L
M(#$P,BD["B\J*B!%>'!O<G0@5%-6(&1A=&$N("`@("`@("`@*B\@9&5F:6YE
M*"=%6%!/4E1?5%-6)RP@,3`S*3L*+RHJ($5X<&]R="!/=71L;V]K($-35B!D
M871A+B`J+R!D969I;F4H)T584$]25%]/551,3T]+0U-6)RP@,3`T*3L*"B\J
M*@H@*B!!8G-T<F%C="!C;&%S<R!T;R!H86YD;&4@9&EF9F5R96YT(&MI;F1S
M(&]F($1A=&$@9F]R;6%T<R!A;F0@=&\*("H@:&5L<"!D871A(&5X8VAA;F=E
M(&)E='=E96X@2&]R9&4@87!P;&EC871I;VYS(&%N9"!E>'1E<FYA;"!S;W5R
M8V5S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP+'8@
M,2XX,"XQ,"XQ,B`R,#`V+S`X+S`X(#$W.C$U.C(R(&IA;B!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D
M92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*86X@4V-H;F5I
M9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U
M8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J
M($!P86-K86=E($AO<F1E7T1A=&$*("HO"F-L87-S($AO<F1E7T1A=&$@97AT
M96YD<R!014%2('L*"B`@("!V87(@)%]E>'1E;G-I;VX["B`@("!V87(@)%]C
M;VYT96YT5'EP92`]("=T97AT+W!L86EN)SL*"B`@("`O*BH*("`@("`J($$@
M;&ES="!O9B!W87)N:6YG<R!R86ES960@9'5R:6YG('1H92!L87-T(&]P97)A
M=&EO;BX*("`@("`J"B`@("`@*B!`<VEN8V4@2&]R9&4@,RXQ"B`@("`@*B\*
M("`@('9A<B`D7W=A<FYI;F=S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J
M(%-T=6(@=&\@:6UP;W)T('!A<W-E9"!D871A+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!I;7!O<G1$871A*"D*("`@('L*("`@('T*"B`@("`O*BH*("`@("`J
M(%-T=6(@=&\@<F5T=7)N(&5X<&]R=&5D(&1A=&$N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&5X<&]R=$1A=&$H*0H@("`@>PH@("`@?0H*("`@("\J*@H@("`@
M("H@4W1U8B!T;R!I;7!O<G0@82!F:6QE+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!I;7!O<G1&:6QE*"1F:6QE;F%M92P@)&AE861E<B`](&9A;'-E*0H@("`@
M>PH@("`@("`@("1D871A(#T@9FEL95]G971?8V]N=&5N=',H)&9I;&5N86UE
M*3L*("`@("`@("!R971U<FX@)'1H:7,M/FEM<&]R=$1A=&$H)&1A=&$L("1H
M96%D97(I.PH@("`@?0H*("`@("\J*@H@("`@("H@4W1U8B!T;R!E>'!O<G0@
M9&%T82!T;R!A(&9I;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X<&]R=$9I
M;&4H*0H@("`@>PH@("`@?0H*("`@("\J*@H@("`@("H@5')I97,@=&\@9&5T
M97)M:6YE('1H92!E>'!E8W1E9"!N97=L:6YE(&-H87)A8W1E<B!B87-E9"!O
M;B!T:&4*("`@("`J('!L871F;W)M(&EN9F]R;6%T:6]N('!A<W-E9"!B>2!T
M:&4@8G)O=W-E<B=S(&%G96YT(&AE861E<BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(&=U97-S960@97AP96-T960@;F5W;&EN92!C:&%R
M86-T97)S+"!E:71H97(@7&XL(%QR"B`@("`@*B`@("`@("`@("`@("`@("`@
M;W(@7')<;BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3F5W;&EN92@I"B`@
M("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]"<F]W<V5R+G!H<"<[
M"B`@("`@("`@)&)R;W=S97(@/2`F0G)O=W-E<CHZ<VEN9VQE=&]N*"D["@H@
M("`@("`@('-W:71C:"`H)&)R;W=S97(M/F=E=%!L871F;W)M*"DI('L*("`@
M("`@("!C87-E("=W:6XG.@H@("`@("`@("`@("!R971U<FX@(EQR7&XB.PH*
M("`@("`@("!C87-E("=M86,G.@H@("`@("`@("`@("!R971U<FX@(EQR(CL*
M"B`@("`@("`@8V%S92`G=6YI>"<Z"B`@("`@("`@9&5F875L=#H*("`@("`@
M("`@("`@<F5T=7)N(")<;B(["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T
M:6]N(&=E=$9I;&5N86UE*"1B87-E;F%M92D*("`@('L*("`@("`@("!R971U
M<FX@)&)A<V5N86UE("X@)RXG("X@)'1H:7,M/E]E>'1E;G-I;VX["B`@("!]
M"@H@("`@9G5N8W1I;VX@9V5T0V]N=&5N=%1Y<&4H*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7V-O;G1E;G14>7!E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!A(&QI<W0@;V8@=V%R;FEN9W,@=&AA="!H879E(&)E
M96X@<F%I<V5D(&1U<FEN9R!T:&4@;&%S=`H@("`@("H@;W!E<F%T:6]N+@H@
M("`@("H*("`@("`J($!S:6YC92!(;W)D92`S+C$*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!!("AP;W-S:6)L>2!E;7!T>2D@;&ES="!O9B!W87)N
M:6YG<RX*("`@("`J+PH@("`@9G5N8W1I;VX@=V%R;FEN9W,H*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7W=A<FYI;F=S.PH@("`@?0H*("`@("\J
M*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E=&4@2&]R9&5?
M1&%T82!I;G-T86YC92!B87-E9"!O;B`D9F]R;6%T+@H@("`@("H*("`@("`J
M($!P87)A;2!M:7AE9"`D9F]R;6%T("!4:&4@='EP92!O9B!C;VYC<F5T92!(
M;W)D95]$871A('-U8F-L87-S('1O"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N+B!)9B`D9F]R;6%T(&ES(&%N(&%R<F%Y+"!T:&5N('=E
M('=I;&P@;&]O:PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&EN("1F
M;W)M871;,%TO;&EB+T1A=&$O(&9O<B!T:&4@<W5B8VQA<W,*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!I;7!L96UE;G1A=&EO;B!N86UE9"`D9F]R
M;6%T6S%=+G!H<"X*("`@("`J"B`@("`@*B!`<F5T=7)N($AO<F1E7T1A=&$@
M(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R971E($AO<F1E7T1A=&$@:6YS=&%N
M8V4L(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(&9A;'-E(&]N(&%N
M(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D9F]R;6%T
M*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D9F]R;6%T*2D@>PH@("`@
M("`@("`@("`D87!P(#T@)&9O<FUA=%LP73L*("`@("`@("`@("`@)&9O<FUA
M="`]("1F;W)M871;,5T["B`@("`@("`@?0H*("`@("`@("`D9F]R;6%T(#T@
M8F%S96YA;64H)&9O<FUA="D["@H@("`@("`@(&EF("AE;7!T>2@D9F]R;6%T
M*2!\?"`H<W1R8VUP*"1F;W)M870L("=N;VYE)RD@/3T@,"DI('L*("`@("`@
M("`@("`@)&1A=&$@/28@;F5W($AO<F1E7T1A=&$H*3L*("`@("`@("`@("`@
M<F5T=7)N("1D871A.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D
M87!P*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)$=,3T)!3%-;)W)E
M9VES=')Y)UTM/F=E="@G9FEL97)O;W0G+"`D87!P*2`N("<O;&EB+T1A=&$O
M)R`N("1F;W)M870@+B`G+G!H<"<["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]$871A+R<@+B`D9F]R;6%T("X@
M)RYP:'`G.PH@("`@("`@('T*("`@("`@("`D8VQA<W,@/2`G2&]R9&5?1&%T
M85\G("X@)&9O<FUA=#L*("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S
M<RDI('L*("`@("`@("`@("`@)&1A=&$@/28@;F5W("1C;&%S<R@I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1D871A(#T@4$5!4CHZ<F%I<V5%
M<G)O<B@G0VQA<W,@9&5F:6YI=&EO;B!O9B`G("X@)&-L87-S("X@)R!N;W0@
M9F]U;F0N)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&1A=&$["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!R969E
M<F5N8V4@=&\@82!C;VYC<F5T92!(;W)D95]$871A(&EN<W1A;F-E"B`@("`@
M*B!B87-E9"!O;B`D9F]R;6%T+B!)="!W:6QL(&]N;'D@8W)E871E(&$@;F5W
M(&EN<W1A;F-E(&EF(&YO($AO<F1E7T1A=&$*("`@("`J(&EN<W1A;F-E('=I
M=&@@=&AE('-A;64@<&%R86UE=&5R<R!C=7)R96YT;'D@97AI<W1S+@H@("`@
M("H*("`@("`J(%1H:7,@<VAO=6QD(&)E('5S960@:68@;75L=&EP;&4@9&%T
M82!S;W5R8V5S("AA;F0L('1H=7,L(&UU;'1I<&QE"B`@("`@*B!(;W)D95]$
M871A(&EN<W1A;F-E<RD@87)E(')E<75I<F5D+@H@("`@("H*("`@("`J(%1H
M:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH@)'9A<B`]("9(;W)D95]$
M871A.CIS:6YG;&5T;VXH*0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&9O<FUA="`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@2&]R9&5?1&%T82!S=6)C
M;&%S<R!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FXN
M"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D95]$871A("!4:&4@8V]N8W)E
M=&4@2&]R9&5?1&%T82!R969E<F5N8V4L(&]R(&9A;'-E(&]N(&%N"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@(&5R<F]R+@H@("`@("HO"B`@("!F=6YC
M=&EO;B`F<VEN9VQE=&]N*"1F;W)M870I"B`@("!["B`@("`@("`@<W1A=&EC
M("1I;G-T86YC97,["B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S*2D@
M>PH@("`@("`@("`@("`D:6YS=&%N8V5S(#T@87)R87DH*3L*("`@("`@("!]
M"@H@("`@("`@("1S:6=N871U<F4@/2!S97)I86QI>F4H)&9O<FUA="D["B`@
M("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S6R1S:6=N871U<F5=*2D@>PH@
M("`@("`@("`@("`D:6YS=&%N8V5S6R1S:6=N871U<F5=(#T@)DAO<F1E7T1A
M=&$Z.F9A8W1O<GDH)&9O<FUA="D["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)&EN<W1A;F-E<ULD<VEG;F%T=7)E73L*("`@('T*"B`@("`O*BH*("`@
M("`J($UA<',@82!D871E+W1I;64@<W1R:6YG('1O(&%N(&%S<V]C:6%T:79E
M(&%R<F%Y+@H@("`@("H*("`@("`J(%1H92!M971H;V0@<VEG;F%T=7)E(&AA
M<R!C:&%N9V5D(&EN($AO<F1E(#,N,2XS+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1A=&4@
M("!4:&4@9&%T92X*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@("!/;F4@
M;V8@)V1A=&4G+"`G=&EM92<@;W(@)V1A=&5T:6UE)RX*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US("!4=V\M9&EM96YS:6]N86P@87)R87D@=VET:"!A
M9&1I=&EO;F%L(&EN9F]R;6%T:6]N"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@86)O=70@=&AE(&9O<FUA='1I;F<N(%!O<W-I8FQE(&ME>7,@87)E
M.CQP<F4^"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@9&5L:6UI=&5R
M("TM(%1H92!C:&%R86-T97(@=&AA="!S97!E<F%T97,@=&AE"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&1I9F9E<F5N="!D
M871E+W1I;64@<&%R=',N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M9F]R;6%T("TM($EF("=A;7!M)R!A;F0@)&1A=&4@8V]N=&%I;G,@82!T:6UE
M('=E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%S
M<W5M92!T:&%T(&ET(&ES(&EN($%-+U!-(&9O<FUA="X*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!O<F1E<B`M+2!)9B`D='EP92!I<R`G9&%T971I
M;64G('1H92!O<F1E<B!O9B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!D87D@86YD('1I;64@<&%R=',Z("TQ("AT:6UE<W1A
M;7`I+"`P"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M*&1A>2]T:6UE*2P@,2`H=&EM92]D87DI+@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)&ME>2`@(%1H92!K97D@=&\@=7-E(&9O<B`D<&%R86US+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9&%T92!O<B!T:6UE(&EN($E3
M3R!F;W)M870N"B`@("`@*B\*("`@(&9U;F-T:6]N(&UA<$1A=&4H)&1A=&4L
M("1T>7!E+"`D<&%R86US+"`D:V5Y*0H@("`@>PH@("`@("`@('-W:71C:"`H
M)'1Y<&4I('L*("`@("`@("!C87-E("=D871E)SH*("`@("`@("!C87-E("=M
M;VYT:&1A>2<Z"B`@("`@("`@8V%S92`G;6]N=&AD87EY96%R)SH*("`@("`@
M("`@("`@)&1A=&5S(#T@97AP;&]D92@D<&%R86US6R=D96QI;6ET97(G75LD
M:V5Y72P@)&1A=&4I.PH@("`@("`@("`@("!I9B`H8V]U;G0H)&1A=&5S*2`A
M/2`S*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&1A=&4["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)&EN9&5X(#T@87)R87E?9FQI<"AE>'!L;V1E
M*"<O)RP@)'!A<F%M<ULG9F]R;6%T)UU;)&ME>5TI*3L*("`@("`@("`@("`@
M<F5T=7)N("1D871E<ULD:6YD97A;)WEE87(G75T@+B`G+2<@+B`D9&%T97-;
M)&EN9&5X6R=M;VYT:"==72`N("<M)R`N("1D871E<ULD:6YD97A;)VUD87DG
M75T["@H@("`@("`@(&-A<V4@)W1I;64G.@H@("`@("`@("`@("`D9&%T97,@
M/2!E>'!L;V1E*"1P87)A;7-;)V1E;&EM:71E<B==6R1K97E=+"`D9&%T92D[
M"B`@("`@("`@("`@(&EF("AC;W5N="@D9&%T97,I(#P@,B!\?"!C;W5N="@D
M9&%T97,I(#X@,RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1D871E.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D<&%R86US6R=F;W)M870G
M75LD:V5Y72`]/2`G86UP;2<I('L*("`@("`@("`@("`@("`@(&EF("AS=')P
M;W,H<W1R=&]L;W=E<B@D9&%T97-;8V]U;G0H)&1A=&5S*2TQ72DL("=P;2<I
M("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D9&%T97-;
M,%T@(3T]("<Q,B<I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&5S
M6S!=("L](#$R.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T@96QS96EF("@D9&%T97-;,%T@/3T@)S$R)RD@>PH@("`@("`@("`@
M("`@("`@("`@("1D871E<ULP72`]("<P)SL*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("1D871E<UMC;W5N="@D9&%T97,I("T@,5T@/2!S
M<')I;G1F*"<E,#)D)RP@)&1A=&5S6V-O=6YT*"1D871E<RDM,5TI.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D9&%T97-;,%T@+B`G.B<@
M+B`D9&%T97-;,5T@+B`H8V]U;G0H)&1A=&5S*2`]/2`S(#\@*"<Z)R`N("1D
M871E<ULR72D@.B`G.C`P)RD["@H@("`@("`@(&-A<V4@)V1A=&5T:6UE)SH*
M("`@("`@("`@("`@<W=I=&-H("@D<&%R86US6R=O<F1E<B==6R1K97E=*2![
M"B`@("`@("`@("`@(&-A<V4@+3$Z"B`@("`@("`@("`@("`@("!R971U<FX@
M*'-T<FEN9RDH:6YT*21D871E(#T]("1D871E"B`@("`@("`@("`@("`@("`@
M("`@/R!D871E*"=9+6TM9"!(.FDZ<R<L("1D871E*0H@("`@("`@("`@("`@
M("`@("`@(#H@)&1A=&4["B`@("`@("`@("`@(&-A<V4@,#H*("`@("`@("`@
M("`@("`@(&QI<W0H)&1A>2P@)'1I;64I(#T@97AP;&]D92@G("<L("1D871E
M+"`R*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E
M(#$Z"B`@("`@("`@("`@("`@(&QI<W0H)'1I;64L("1D87DI(#T@97AP;&]D
M92@G("<L("1D871E+"`R*3L*("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)&1A=&4@/2`D=&AI<RT^;6%P1&%T92@D
M9&%Y+"`G9&%T92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH)V1E;&EM:71E<B<@/3X@)'!A<F%M<ULG9&%Y7V1E;&EM:71E
M<B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=F;W)M870G(#T^("1P87)A;7-;)V1A>5]F;W)M870G72DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&ME>2D["B`@("`@("`@("`@
M("1T:6UE(#T@)'1H:7,M/FUA<$1A=&4H)'1I;64L("=T:6UE)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G9&5L:6UI=&5R
M)R`]/B`D<&%R86US6R=T:6UE7V1E;&EM:71E<B==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=F;W)M870G(#T^("1P87)A
M;7-;)W1I;65?9F]R;6%T)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1K97DI.PH@("`@("`@("`@("!R971U<FX@)&1A=&4@+B`G
M("<@+B`D=&EM93L*"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M5&%K97,@86QL(&YE8V5S<V%R>2!A8W1I;VYS(&9O<B!T:&4@9VEV96X@:6UP
M;W)T('-T97`L('!A<F%M971E<G,@86YD"B`@("`@*B!F;W)M('9A;'5E<R!A
M;F0@<F5T=7)N<R!T:&4@;F5X="!N96-E<W-A<GD@<W1E<"X*("`@("`J"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D86-T:6]N("!4:&4@8W5R<F5N="!S=&5P
M+B!/;F4@;V8@=&AE($E-4$]25%\J(&-O;G-T86YT<RX*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86T@("`@($%N(&%S<V]C:6%T:79E(&%R<F%Y(&-O;G1A
M:6YI;F<@;F5E9&5D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!P
M87)A;65T97)S(&9O<B!T:&4@8W5R<F5N="!S=&5P+@H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@($5I=&AE<B!T:&4@;F5X="!S=&5P(&%S(&%N(&EN
M=&5G97(@8V]N<W1A;G0@;W(@:6UP;W)T960*("`@("`J("`@("`@("`@("`@
M("`@(&1A=&$@<V5T(&%F=&5R('1H92!F:6YA;"!S=&5P+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!N97AT4W1E<"@D86-T:6]N+"`D<&%R86T@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@("\J($9I<G-T('-T97`N("HO"B`@("`@("`@:68@
M*&ES7VYU;&PH)&%C=&EO;BDI('L*("`@("`@("`@("`@)%]315-324].6R=I
M;7!O<G1?9&%T82==(#T@87)R87DH*3L*("`@("`@("`@("`@<F5T=7)N($E-
M4$]25%]&24Q%.PH@("`@("`@('T*"B`@("`@("`@<W=I=&-H("@D86-T:6]N
M*2!["B`@("`@("`@8V%S92!)35!/4E1?1DE,13H*("`@("`@("`@("`@+RH@
M4V%N:71I>F4@=7!L;V%D960@9FEL92X@*B\*("`@("`@("`@("`@)&EM<&]R
M=%]F;W)M870@/2!5=&EL.CIG971&;W)M1&%T82@G:6UP;W)T7V9O<FUA="<I
M.PH@("`@("`@("`@("`D8VAE8VM?=7!L;V%D(#T@0G)O=W-E<CHZ=V%S1FEL
M955P;&]A9&5D*"=I;7!O<G1?9FEL92<L("1P87)A;5LG9FEL95]T>7!E<R==
M6R1I;7!O<G1?9F]R;6%T72D["B`@("`@("`@("`@(&EF("AI<U]A*"1C:&5C
M:U]U<&QO860L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D8VAE8VM?=7!L;V%D.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("@D7T9)3$536R=I;7!O<G1?9FEL92==6R=S:7IE)UT@/#T@,"D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B5&AE
M(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N(BDI.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG9F]R;6%T)UT@
M/2`D:6UP;W)T7V9O<FUA=#L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&-A<V4@24U03U)47TU!4%!%1#H*("`@("`@("`@("`@)&1A=&%+97ES(#T@
M571I;#HZ9V5T1F]R;41A=&$H)V1A=&%+97ES)RP@)R<I.PH@("`@("`@("`@
M("`D87!P2V5Y<R`](%5T:6PZ.F=E=$9O<FU$871A*"=A<'!+97ES)RP@)R<I
M.PH@("`@("`@("`@("!I9B`H96UP='DH)&1A=&%+97ES*2!\?"!E;7!T>2@D
M87!P2V5Y<RDI('L*("`@("`@("`@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD[
M"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I
M;G1F*%\H(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP
M;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@)7,N
M(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1R96=I<W1R>2T^9V5T*"=N86UE)RDI*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D9&%T84ME>7,@/2!E>'!L;V1E*")<="(L("1D871A
M2V5Y<RD["B`@("`@("`@("`@("1A<'!+97ES(#T@97AP;&]D92@B7'0B+"`D
M87!P2V5Y<RD["B`@("`@("`@("`@("1M87`@/2!A<G)A>2@I.PH@("`@("`@
M("`@("`D9&%T97,@/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W)E86-H("@D
M87!P2V5Y<R!A<R`D:V5Y(#T^("1A<'`I('L*("`@("`@("`@("`@("`@("1M
M87!;)&1A=&%+97ES6R1K97E=72`]("1A<'`["B`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)'!A<F%M6R=T:6UE7V9I96QD<R==*2`F)@H@("`@("`@("`@
M("`@("`@("`@(&ES<V5T*"1P87)A;5LG=&EM95]F:65L9',G75LD87!P72DI
M('L*("`@("`@("`@("`@("`@("`@("`D9&%T97-;)&1A=&%+97ES6R1K97E=
M75LG='EP92==(#T@)'!A<F%M6R=T:6UE7V9I96QD<R==6R1A<'!=.PH@("`@
M("`@("`@("`@("`@("`@("1D871E<ULD9&%T84ME>7-;)&ME>5U=6R=V86QU
M97,G72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@)&D@/2`P.PH@
M("`@("`@("`@("`@("`@("`@("\J($)U:6QD(&%N(&5X86UP;&4@87)R87D@
M;V8@=7`@=&\@,3`@9&%T92]T:6UE(&9I96QD<RX@*B\*("`@("`@("`@("`@
M("`@("`@("!W:&EL92`H)&D@/"!C;W5N="@D7U-%4U-)3TY;)VEM<&]R=%]D
M871A)UU;)V1A=&$G72D@)B8@8V]U;G0H)&1A=&5S6R1D871A2V5Y<ULD:V5Y
M75U;)W9A;'5E<R==*2`\(#$P*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@A96UP='DH)%]315-324].6R=I;7!O<G1?9&%T82==6R=D871A)UU;
M)&E=6R1D871A2V5Y<ULD:V5Y75TI*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9&%T97-;)&1A=&%+97ES6R1K97E=75LG=F%L=65S)UU;72`]
M("1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG9&%T82==6R1I75LD9&%T84ME
M>7-;)&ME>5U=.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@("`@("1I*RL["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1?
M4T534TE/3ELG:6UP;W)T7V1A=&$G75LG;6%P)UT@/2`D;6%P.PH@("`@("`@
M("`@("!I9B`H8V]U;G0H)&1A=&5S*2`^(#`I('L*("`@("`@("`@("`@("`@
M("1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG9&%T97,G72`]("1D871E<SL*
M("`@("`@("`@("`@("`@(')E='5R;B!)35!/4E1?1$%4151)344["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YN97AT4W1E<"A)
M35!/4E1?1$%402P@)'!A<F%M*3L*"B`@("`@("`@8V%S92!)35!/4E1?1$%4
M151)344Z"B`@("`@("`@8V%S92!)35!/4E1?1$%403H*("`@("`@("`@("`@
M:68@*"1A8W1I;VX@/3T@24U03U)47T1!5$5424U%*2!["B`@("`@("`@("`@
M("`@("`D<&%R86US(#T@87)R87DH)V1E;&EM:71E<B<@/3X@571I;#HZ9V5T
M1F]R;41A=&$H)V1E;&EM:71E<B<I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=F;W)M870G(#T^(%5T:6PZ.F=E=$9O<FU$871A*"=F;W)M
M870G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;W)D97(G
M(#T^(%5T:6PZ.F=E=$9O<FU$871A*"=O<F1E<B<I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=D87E?9&5L:6UI=&5R)R`]/B!5=&EL.CIG
M971&;W)M1&%T82@G9&%Y7V1E;&EM:71E<B<I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=D87E?9F]R;6%T)R`]/B!5=&EL.CIG971&;W)M
M1&%T82@G9&%Y7V9O<FUA="<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=T:6UE7V1E;&EM:71E<B<@/3X@571I;#HZ9V5T1F]R;41A=&$H
M)W1I;65?9&5L:6UI=&5R)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W1I;65?9F]R;6%T)R`]/B!5=&EL.CIG971&;W)M1&%T82@G=&EM
M95]F;W)M870G*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%I
M<W-E="@D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)V1A=&$G72DI('L*("`@
M("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E1H92!U
M<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P
M+B(I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`O*B!"=6EL9"!T:&4@
M<F5S=6QT(&1A=&$@<V5T(&%S(&%N(&%S<V]C:6%T:79E(&%R<F%Y+B`J+PH@
M("`@("`@("`@("`D9&%T82`](&%R<F%Y*"D["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG9&%T82==(&%S("1R;W<I
M('L*("`@("`@("`@("`@("`@("1D871A7W)O=R`](&%R<F%Y*"D["B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D<F]W(&%S("1K97D@/3X@)'9A;"D@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D7U-%4U-)3TY;)VEM<&]R
M=%]D871A)UU;)VUA<"==6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D;6%P<&5D7VME>2`]("1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG
M;6%P)UU;)&ME>5T["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D86-T
M:6]N(#T]($E-4$]25%]$051%5$E-12`F)@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(65M<'1Y*"1V86PI("8F"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I<W-E="@D<&%R86U;)W1I;65?9FEE;&1S)UTI("8F"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I<W-E="@D<&%R86U;)W1I;65?9FEE
M;&1S)UU;)&UA<'!E9%]K97E=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'9A;"`]("1T:&ES+3YM87!$871E*"1V86PL("1P87)A;5LG=&EM
M95]F:65L9',G75LD;6%P<&5D7VME>5TL("1P87)A;7,L("1K97DI.PH@("`@
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@
M("1D871A7W)O=ULD7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)VUA<"==6R1K
M97E=72`]("1V86P["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@)&1A=&%;72`]("1D871A7W)O=SL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)&1A=&$["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0VQE86YS('1H92!S97-S:6]N
M(&1A=&$@=7`@86YD(')E;6]V97,@86YY('5P;&]A9&5D(&%N9"!M;W9E9`H@
M("`@("H@9FEL97,N($EF(&$@9G5N8W1I;VX@8V%L;&5D(")?8VQE86YU<"@I
M(B!E>&ES=',L('1H:7,@9V5T<PH@("`@("H@8V%L;&5D('1O;RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!)9B!?8VQE86YU<"@I('=A<R!C86QL
M960L('1H92!R971U<FX@=F%L=64@;V8@=&AI<R!C86QL+@H@("`@("H@("`@
M("`@("`@("`@("`@5&AI<R!S:&]U;&0@8F4@=&AE('9A;'5E(&]F('1H92!F
M:7)S="!I;7!O<G0@<W1E<"X*("`@("`J+PH@("`@9G5N8W1I;VX@8VQE86YU
M<"@I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1?4T534TE/3ELG:6UP;W)T
M7V1A=&$G75LG9FEL95]N86UE)UTI*2!["B`@("`@("`@("`@($!U;FQI;FLH
M)%]315-324].6R=I;7!O<G1?9&%T82==6R=F:6QE7VYA;64G72D["B`@("`@
M("`@?0H@("`@("`@("1?4T534TE/3ELG:6UP;W)T7V1A=&$G72`](&%R<F%Y
M*"D["B`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G7V-L96%N=7`G*2D@
M>PH@("`@("`@("`@("!R971U<FX@7V-L96%N=7`H*3L*("`@("`@("!]"B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+T1A=&4N<&AP````````````````````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#,S-3,S(#$P-3$U-#,S-S0P(#`R,#<T,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`H*9&5F:6YE
M*"=(3U)$15]$051%7U-53D1!62<L("`@(#`I.PID969I;F4H)TA/4D1%7T1!
M5$5?34].1$%9)RP@("`@,2D["F1E9FEN92@G2$]21$5?1$%415]454531$%9
M)RP@("`R*3L*9&5F:6YE*"=(3U)$15]$051%7U=%1$Y%4T1!62<L(#,I.PID
M969I;F4H)TA/4D1%7T1!5$5?5$A54E-$05DG+"`@-"D["F1E9FEN92@G2$]2
M1$5?1$%415]&4DE$05DG+"`@("`U*3L*9&5F:6YE*"=(3U)$15]$051%7U-!
M5%521$%9)RP@(#8I.PH*9&5F:6YE*"=(3U)$15]$051%7TU!4TM?4U5.1$%9
M)RP@("`@,2D["F1E9FEN92@G2$]21$5?1$%415]-05-+7TU/3D1!62<L("`@
M(#(I.PID969I;F4H)TA/4D1%7T1!5$5?34%32U]454531$%9)RP@("`T*3L*
M9&5F:6YE*"=(3U)$15]$051%7TU!4TM?5T5$3D531$%9)RP@."D["F1E9FEN
M92@G2$]21$5?1$%415]-05-+7U1(55)31$%9)RP@,38I.PID969I;F4H)TA/
M4D1%7T1!5$5?34%32U]&4DE$05DG+"`@(#,R*3L*9&5F:6YE*"=(3U)$15]$
M051%7TU!4TM?4T%455)$05DG+"`V-"D["F1E9FEN92@G2$]21$5?1$%415]-
M05-+7U=%14M$05E3)RP@-C(I.PID969I;F4H)TA/4D1%7T1!5$5?34%32U]7
M145+14Y$)RP@(#8U*3L*9&5F:6YE*"=(3U)$15]$051%7TU!4TM?04Q,1$%9
M4R<L(#$R-RD["@ID969I;F4H)TA/4D1%7T1!5$5?34%32U]314-/3D0G+"`@
M("`Q*3L*9&5F:6YE*"=(3U)$15]$051%7TU!4TM?34E.551%)RP@("`@,BD[
M"F1E9FEN92@G2$]21$5?1$%415]-05-+7TA/55(G+"`@("`@(#0I.PID969I
M;F4H)TA/4D1%7T1!5$5?34%32U]$05DG+"`@("`@("`X*3L*9&5F:6YE*"=(
M3U)$15]$051%7TU!4TM?34].5$@G+"`@("`Q-BD["F1E9FEN92@G2$]21$5?
M1$%415]-05-+7UE%05(G+"`@("`@,S(I.PID969I;F4H)TA/4D1%7T1!5$5?
M34%32U]!3$Q005)44R<L(#8S*3L*"B\J*@H@*B!(;W)D92!$871E('=R87!P
M97(O;&]G:6,@8VQA<W,L(&EN8VQU9&EN9R!S;VUE(&-A;&-U;&%T:6]N"B`J
M(&9U;F-T:6]N<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO1&%T92]$871E
M+G!H<"QV(#$N."XQ,"XW(#(P,#8O,#4O,#0@,#,Z-#(Z,S(@<V5L<VMY($5X
M<"`D"B`J"B`J($!P86-K86=E($AO<F1E7T1A=&4*("HO"F-L87-S($AO<F1E
M7T1A=&4@>PH*("`@("\J*@H@("`@("H@665A<@H@("`@("H*("`@("`J($!V
M87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)'EE87(["@H@("`@+RHJ"B`@
M("`@*B!-;VYT:`H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO
M"B`@("!V87(@)&UO;G1H.PH*("`@("\J*@H@("`@("H@1&%Y"B`@("`@*@H@
M("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D;61A>3L*"B`@
M("`O*BH*("`@("`J($AO=7(*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*
M("`@("`J+PH@("`@=F%R("1H;W5R(#T@,#L*"B`@("`O*BH*("`@("`J($UI
M;G5T90H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V
M87(@)&UI;B`](#`["@H@("`@+RHJ"B`@("`@*B!396-O;F0*("`@("`J"B`@
M("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1S96,@/2`P.PH*
M("`@("\J*@H@("`@("H@0G5I;&0@82!N97<@9&%T92!O8FIE8W0N($EF("1D
M871E(&-O;G1A:6YS(&1A=&4@<&%R=',L('5S92!T:&5M"B`@("`@*B!T;R!I
M;FET:6%L:7IE('1H92!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N($AO
M<F1E7T1A=&4H)&1A=&4@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]A
M<G)A>2@D9&%T92D@?'P@:7-?;V)J96-T*"1D871E*2D@>PH@("`@("`@("`@
M("!F;W)E86-H("@D9&%T92!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@
M("`@("`@(&EF("AI;E]A<G)A>2@D:V5Y+"!A<G)A>2@G>65A<B<L("=M;VYT
M:"<L("=M9&%Y)RP@)VAO=7(G+"`G;6EN)RP@)W-E8R<I*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3XD:V5Y(#T@*&EN="DD=F%L.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E:68@*"%I
M<U]N=6QL*"1D871E*2D@>PH@("`@("`@("`@("`O+R!-871C:"!965E9+4U-
M+41$($A(.DU-.E-3(&%N9"!965E934U$1$A(34U34RX*("`@("`@("`@("`@
M:68@*'!R96=?;6%T8V@H)R\H7&1[-'TI+3\H7&1[,GTI+3\H7&1[,GTI(#\H
M7&1[,GTI.C\H7&1[,GTI.C\H7&1[,GTI+R<L("1D871E+"`D<&%R=',I*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^>65A<B`]("AI;G0I)'!A<G1S6S%=
M.PH@("`@("`@("`@("`@("`@)'1H:7,M/FUO;G1H(#T@*&EN="DD<&%R='-;
M,ET["B`@("`@("`@("`@("`@("`D=&AI<RT^;61A>2`]("AI;G0I)'!A<G1S
M6S-=.PH@("`@("`@("`@("`@("`@)'1H:7,M/FAO=7(@/2`H:6YT*21P87)T
M<ULT73L*("`@("`@("`@("`@("`@("1T:&ES+3YM:6X@/2`H:6YT*21P87)T
M<ULU73L*("`@("`@("`@("`@("`@("1T:&ES+3YS96,@/2`H:6YT*21P87)T
M<ULV73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("\O
M(%1R>2!A<R!A('1I;65S=&%M<"X*("`@("`@("`@("`@("`@("1P87)T<R`]
M($!G971D871E*"1D871E*3L*("`@("`@("`@("`@("`@(&EF("@D<&%R=',I
M('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^>65A<B`]("1P87)T<ULG
M>65A<B==.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YM;VYT:"`]("1P
M87)T<ULG;6]N)UT["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FUD87D@
M/2`D<&%R='-;)VUD87DG73L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M:&]U<B`]("1P87)T<ULG:&]U<G,G73L*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^;6EN(#T@)'!A<G1S6R=M:6YU=&5S)UT["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G-E8R`]("1P87)T<ULG<V5C;VYD<R==.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N('1H92!U;FEX('1I;65S=&%M<"!R97!R97-E
M;G1A=&EO;B!O9B!T:&ES(&1A=&4N"B`@("`@*@H@("`@("H@0')E='5R;B!I
M;G1E9V5R("!!('5N:7@@=&EM97-T86UP+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!T:6UE<W1A;7`H*0H@("`@>PH@("`@("`@(')E='5R;B!`;6MT:6UE*"1T
M:&ES+3YH;W5R+"`D=&AI<RT^;6EN+"`D=&AI<RT^<V5C+"`D=&AI<RT^;6]N
M=&@L("1T:&ES+3YM9&%Y+"`D=&AI<RT^>65A<BD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FX@=&AE('5N:7@@=&EM97-T86UP(')E<')E<V5N=&%T
M:6]N(&]F('1H:7,@9&%T92P@,3(Z,#!A;2X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&EN=&5G97(@($$@=6YI>"!T:6UE<W1A;7`N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&1A=&5S=&%M<"@I"B`@("!["B`@("`@("`@<F5T=7)N($!M:W1I
M;64H,"P@,"P@,"P@)'1H:7,M/FUO;G1H+"`D=&AI<RT^;61A>2P@)'1H:7,M
M/GEE87(I.PH@("`@?0H*("`@("\J*@H@("`@("H@0'-T871I8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!I<TQE87!996%R*"1Y96%R*0H@("`@>PH@("`@("`@
M(&EF("AS=')L96XH)'EE87(I("$](#0@?'P@<')E9U]M871C:"@G+UQ$+R<L
M("1Y96%R*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@*"@D>65A<B`E(#0@/3T@,"`F)B`D>65A<B`E
M(#$P,"`A/2`P*2!\?"`D>65A<B`E(#0P,"`]/2`P*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE(&1A>2!O9B!T:&4@>65A<B`H,2TS-C8I
M('1H870@8V]R<F5S<&]N9',@=&\@=&AE"B`@("`@*B!F:7)S="!D87D@;V8@
M=&AE(&=I=F5N('=E96LN"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)'=E96L@(%1H92!W965K(&]F('1H92!Y96%R('1O(&9I;F0@=&AE(&9I<G-T
M(&1A>2!O9BX*("`@("`J($!P87)A;2!I;G1E9V5R("1Y96%R("!4:&4@>65A
M<B!T;R!C86QC=6QA=&4@9F]R+@H@("`@("H*("`@("`J($!R971U<FX@:6YT
M96=E<B`@5&AE(&1A>2!O9B!T:&4@>65A<B!O9B!T:&4@9FER<W0@9&%Y(&]F
M('1H92!G:79E;B!W965K+@H@("`@("HO"B`@("!F=6YC=&EO;B!F:7)S=$1A
M>4]F5V5E:R@D=V5E:RP@)'EE87(I"B`@("!["B`@("`@("`@)&IA;C$@/2`F
M;F5W($AO<F1E7T1A=&4H87)R87DH)WEE87(G(#T^("1Y96%R+"`G;6]N=&@G
M(#T^(#$L("=M9&%Y)R`]/B`Q*2D["B`@("`@("`@)'-T87)T(#T@)&IA;C$M
M/F1A>4]F5V5E:R@I.PH@("`@("`@(&EF("@D<W1A<G0@/B!(3U)$15]$051%
M7U1(55)31$%9*2!["B`@("`@("`@("`@("1S=&%R="`M/2`W.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@*"@D=V5E:R`J(#<I("T@*#<@*R`D<W1A<G0I
M*2`K(#$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&1A>7-);DUO;G1H*"1M;VYT:"P@)'EE87(I"B`@("![
M"B`@("`@("`@:68@*"1M;VYT:"`]/2`R*2!["B`@("`@("`@("`@(&EF("A(
M;W)D95]$871E.CII<TQE87!996%R*"1Y96%R*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N(#(Y.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(#(X.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E
M:68@*"1M;VYT:"`]/2`T('Q\("1M;VYT:"`]/2`V('Q\("1M;VYT:"`]/2`Y
M('Q\("1M;VYT:"`]/2`Q,2D@>PH@("`@("`@("`@("!R971U<FX@,S`["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(#,Q.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@9&%Y(&]F('1H
M92!W965K("@P(#T@4W5N9&%Y+"`V(#T@4V%T=7)D87DI(&]F('1H:7,*("`@
M("`J(&]B:F5C="=S(&1A=&4N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E
M9V5R("!4:&4@9&%Y(&]F('1H92!W965K+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!D87E/9E=E96LH*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^;6]N=&@@
M/B`R*2!["B`@("`@("`@("`@("1M;VYT:"`]("1T:&ES+3YM;VYT:"`M(#([
M"B`@("`@("`@("`@("1Y96%R(#T@)'1H:7,M/GEE87(["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)&UO;G1H(#T@)'1H:7,M/FUO;G1H("L@,3`[
M"B`@("`@("`@("`@("1Y96%R(#T@)'1H:7,M/GEE87(@+2`Q.PH@("`@("`@
M('T*"B`@("`@("`@)&1A>2`]("AF;&]O<B@H,3,@*B`D;6]N=&@@+2`Q*2`O
M(#4I("L*("`@("`@("`@("`@("`@("1T:&ES+3YM9&%Y("L@*"1Y96%R("4@
M,3`P*2`K"B`@("`@("`@("`@("`@("!F;&]O<B@H)'EE87(@)2`Q,#`I("\@
M-"D@*PH@("`@("`@("`@("`@("`@9FQO;W(H*"1Y96%R("\@,3`P*2`O(#0I
M("T@,B`J"B`@("`@("`@("`@("`@("!F;&]O<B@D>65A<B`O(#$P,"D@*R`W
M-RD["@H@("`@("`@(')E='5R;B`H:6YT*2@D9&%Y("T@-R`J(&9L;V]R*"1D
M87D@+R`W*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!D
M87D@;G5M8F5R(&]F('1H92!Y96%R("@P('1O(#,V-2\S-C8I+@H@("`@("H*
M("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(&1A>2!O9B!T:&4@>65A<BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@9&%Y3V9996%R*"D*("`@('L*("`@("`@
M("`D;6]N=&A4;W1A;',@/2!A<G)A>2@P+"`S,2P@-3DL(#DP+"`Q,C`L(#$U
M,2P@,3@Q+"`R,3(L(#(T,RP@,C<S+"`S,#0L(#,S-"D["B`@("`@("`@)&1A
M>4]F665A<B`]("1T:&ES+3YM9&%Y("L@)&UO;G1H5&]T86QS6R1T:&ES+3YM
M;VYT:"`M(#%=.PH@("`@("`@(&EF("A(;W)D95]$871E.CII<TQE87!996%R
M*"1T:&ES+3YY96%R*2`F)B`D=&AI<RT^;6]N=&@@/B`R*2!["B`@("`@("`@
M("`@("1D87E/9EEE87(K*SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M9&%Y3V9996%R.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!W965K
M(&]F('1H92!Y96%R+"!F:7)S="!-;VYD87D@:7,@9FER<W0@9&%Y(&]F(&9I
M<G-T"B`@("`@*B!W965K+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E
M<B`@5&AE('=E96L@;G5M8F5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!W965K
M3V9996%R*"D*("`@('L*("`@("`@("!R971U<FX@9&%T92@G5R<L("1T:&ES
M+3YT:6UE<W1A;7`H*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@
M=&AE(&YU;6)E<B!O9B!W965K<R!I;B!T:&4@9VEV96X@>65A<B`H-3(@;W(@
M-3,I+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1Y96%R("!4:&4@
M>65A<B!T;R!C;W5N="!T:&4@;G5M8F5R(&]F('=E96MS(&EN+@H@("`@("H*
M("`@("`J($!R971U<FX@:6YT96=E<B`D;G5M5V5E:W,@("`@("!4:&4@;G5M
M8F5R(&]F('=E96MS(&EN("1Y96%R+@H@("`@("HO"B`@("!F=6YC=&EO;B!W
M965K<TEN665A<B@D>65A<BD*("`@('L*("`@("`@("`O+R!&:6YD('1H92!L
M87-T(%1H=7)S9&%Y(&]F('1H92!Y96%R+@H@("`@("`@("1D87D@/2`S,3L*
M("`@("`@("!W:&EL92`H9&%T92@G=R<L(&UK=&EM92@P+"`P+"`P+"`Q,BP@
M)&1A>2P@)'EE87(I*2`A/2!(3U)$15]$051%7U1(55)31$%9*2!["B`@("`@
M("`@("`@("1D87DM+3L*("`@("`@("!]"@H@("`@("`@("1D871E(#T@)FYE
M=R!(;W)D95]$871E*&%R<F%Y*"=Y96%R)R`]/B`D>65A<BP@)VUO;G1H)R`]
M/B`Q,BP@)VUD87DG(#T^("1D87DI*3L*("`@("`@("!R971U<FX@)&1A=&4M
M/G=E96M/9EEE87(H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@
M9&%T92!O9B!T:&ES(&]B:F5C="!T;R!T:&4@)&YT:"!W965K9&%Y(&]F("1W
M965K9&%Y+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1W965K9&%Y
M("!4:&4@9&%Y(&]F('1H92!W965K("@P(#T@4W5N9&%Y+"!E=&,I+@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&YT:"`@("`@(%1H92`D;G1H("1W965K9&%Y
M('1O('-E="!T;R`H9&5F875L=',@=&\@,2DN"B`@("`@*B\*("`@(&9U;F-T
M:6]N('-E=$YT:%=E96MD87DH)'=E96MD87DL("1N=&@@/2`Q*0H@("`@>PH@
M("`@("`@(&EF("@D=V5E:V1A>2`\($A/4D1%7T1!5$5?4U5.1$%9('Q\("1W
M965K9&%Y(#X@2$]21$5?1$%415]305154D1!62D@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^;61A>2`]
M(#$["B`@("`@("`@)&9I<G-T(#T@)'1H:7,M/F1A>4]F5V5E:R@I.PH@("`@
M("`@(&EF("@D=V5E:V1A>2`\("1F:7)S="D@>PH@("`@("`@("`@("`D=&AI
M<RT^;61A>2`](#@@*R`D=V5E:V1A>2`M("1F:7)S=#L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D=&AI<RT^;61A>2`]("1W965K9&%Y("T@)&9I
M<G-T("L@,3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/FUD87D@*ST@-R`J
M("1N=&@@+2`W.PH*("`@("`@("`D=&AI<RT^8V]R<F5C="@I.PH*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!D=6UP*"1P<F5F
M:7@@/2`G)RD*("`@('L*("`@("`@("!E8VAO("@D<')E9FEX(#\@)'!R969I
M>"`N("<Z("<@.B`G)RD@+B`D=&AI<RT^>65A<B`N("<M)R`N("1T:&ES+3YM
M;VYT:"`N("<M)R`N("1T:&ES+3YM9&%Y("X@(CQB<B`O/EQN(CL*("`@('T*
M"B`@("`O*BH*("`@("`J($ES('1H92!D871E(&-U<G)E;G1L>2!R97!R97-E
M;G1E9"!B>2!T:&ES(&]B:F5C="!A('9A;&ED(&1A=&4_"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!686QI9&ET>2P@8V]U;G1I;F<@;&5A<"!Y
M96%R<RP@971C+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<U9A;&ED*"D*("`@
M('L*("`@("`@("!I9B`H)'1H:7,M/GEE87(@/"`P('Q\("1T:&ES+3YY96%R
M(#X@.3DY.2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B!C:&5C:V1A=&4H)'1H:7,M/FUO;G1H+"`D=&AI
M<RT^;61A>2P@)'1H:7,M/GEE87(I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0V]R<F5C="!A;GD@;W9E<BT@;W(@=6YD97)F;&]W<R!I;B!A;GD@;V8@=&AE
M(&1A=&4G<R!M96UB97)S+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R
M("1M87-K("!792!M87D@;F]T('=A;G0@=&\@8V]R<F5C="!S;VUE(&]V97)F
M;&]W<RX*("`@("`J+PH@("`@9G5N8W1I;VX@8V]R<F5C="@D;6%S:R`]($A/
M4D1%7T1!5$5?34%32U]!3$Q005)44RD*("`@('L*("`@("`@("!I9B`H)&UA
M<VL@)B!(3U)$15]$051%7TU!4TM?4T5#3TY$*2!["B`@("`@("`@("`@('=H
M:6QE("@D=&AI<RT^<V5C(#P@,"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/FUI;BTM.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E8R`K/2`V,#L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!W:&EL92`H)'1H:7,M/G-E8R`^(#4Y
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^;6EN*RL["B`@("`@("`@("`@
M("`@("`D=&AI<RT^<V5C("T](#8P.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!I9B`H)&UA<VL@)B!(3U)$15]$051%7TU!4TM?34E.551%
M*2!["B`@("`@("`@("`@('=H:6QE("@D=&AI<RT^;6EN(#P@,"D@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/FAO=7(M+3L*("`@("`@("`@("`@("`@("1T
M:&ES+3YM:6X@*ST@-C`["B`@("`@("`@("`@('T*("`@("`@("`@("`@=VAI
M;&4@*"1T:&ES+3YM:6X@/B`U.2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/FAO=7(K*SL*("`@("`@("`@("`@("`@("1T:&ES+3YM:6X@+3T@-C`["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@D;6%S:R`F($A/
M4D1%7T1!5$5?34%32U](3U52*2!["B`@("`@("`@("`@('=H:6QE("@D=&AI
M<RT^:&]U<B`\(#`I('L*("`@("`@("`@("`@("`@("1T:&ES+3YM9&%Y+2T[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^:&]U<B`K/2`R-#L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!W:&EL92`H)'1H:7,M/FAO=7(@/B`R,RD@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/FUD87DK*SL*("`@("`@("`@("`@("`@
M("1T:&ES+3YH;W5R("T](#(T.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!I9B`H)&UA<VL@)B!(3U)$15]$051%7TU!4TM?34].5$@I('L*
M("`@("`@("`@("`@=VAI;&4@*"1T:&ES+3YM;VYT:"`^(#$R*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^>65A<BLK.PH@("`@("`@("`@("`@("`@)'1H
M:7,M/FUO;G1H("T](#$R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@('=H
M:6QE("@D=&AI<RT^;6]N=&@@/"`Q*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^>65A<BTM.PH@("`@("`@("`@("`@("`@)'1H:7,M/FUO;G1H("L](#$R
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H)&UA<VL@
M)B!(3U)$15]$051%7TU!4TM?1$%9*2!["B`@("`@("`@("`@('=H:6QE("@D
M=&AI<RT^;61A>2`^($AO<F1E7T1A=&4Z.F1A>7-);DUO;G1H*"1T:&ES+3YM
M;VYT:"P@)'1H:7,M/GEE87(I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M;61A>2`M/2!(;W)D95]$871E.CID87ES26Y-;VYT:"@D=&AI<RT^;6]N=&@L
M("1T:&ES+3YY96%R*3L*("`@("`@("`@("`@("`@("1T:&ES+3YM;VYT:"LK
M.PH@("`@("`@("`@("`@("`@)'1H:7,M/F-O<G)E8W0H2$]21$5?1$%415]-
M05-+7TU/3E1(*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!W:&EL92`H
M)'1H:7,M/FUD87D@/"`Q*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^;6]N
M=&@M+3L*("`@("`@("`@("`@("`@("1T:&ES+3YC;W)R96-T*$A/4D1%7T1!
M5$5?34%32U]-3TY42"D["B`@("`@("`@("`@("`@("`D=&AI<RT^;61A>2`K
M/2!(;W)D95]$871E.CID87ES26Y-;VYT:"@D=&AI<RT^;6]N=&@L("1T:&ES
M+3YY96%R*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($-O;7!A<F4@=&AI<R!D871E('1O(&%N;W1H97(@9&%T92!O
M8FIE8W0@=&\@<V5E('=H:6-H(&]N92!I<PH@("`@("H@9W)E871E<B`H;&%T
M97(I+B!!<W-U;65S('1H870@=&AE(&1A=&5S(&%R92!I;B!T:&4@<V%M90H@
M("`@("H@=&EM97IO;F4N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1D
M871E("!4:&4@9&%T92!T;R!C;VUP87)E('1O+@H@("`@("H*("`@("`J($!R
M971U<FX@:6YT96=E<B`@/3T@(#`@:68@=&AE(&1A=&5S(&%R92!E<75A;`H@
M("`@("H@("`@("`@("`@("`@("`@("`^/2`@,2!I9B!T:&ES(&1A=&4@:7,@
M9W)E871E<B`H;&%T97(I"B`@("`@*B`@("`@("`@("`@("`@("`@(#P]("TQ
M(&EF('1H92!O=&AE<B!D871E(&ES(&=R96%T97(@*&QA=&5R*0H@("`@("HO
M"B`@("!F=6YC=&EO;B!C;VUP87)E1&%T92@D9&%T92D*("`@('L*("`@("`@
M("!I9B`H(6ES7V$H)&1A=&4L("=(;W)D95]$871E)RDI('L*("`@("`@("`@
M("`@)&1A=&4@/2`F;F5W($AO<F1E7T1A=&4H)&1A=&4I.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"1T:&ES+3YY96%R("$]("1D871E+3YY96%R*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^>65A<B`M("1D871E+3YY96%R.PH@
M("`@("`@('T@96QS96EF("@D=&AI<RT^;6]N=&@@(3T@)&1A=&4M/FUO;G1H
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;6]N=&@@+2`D9&%T92T^
M;6]N=&@["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YM9&%Y("T@)&1A=&4M/FUD87D["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@0V]M<&%R92!T:&ES('1O(&%N;W1H97(@9&%T92!O8FIE
M8W0@8GD@=&EM92P@=&\@<V5E('=H:6-H(&]N90H@("`@("H@:7,@9W)E871E
M<B`H;&%T97(I+B!!<W-U;65S('1H870@=&AE(&1A=&5S(&%R92!I;B!T:&4@
M<V%M90H@("`@("H@=&EM97IO;F4N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI
M>&5D("1D871E("!4:&4@9&%T92!T;R!C;VUP87)E('1O+@H@("`@("H*("`@
M("`J($!R971U<FX@:6YT96=E<B`@/3T@(#`@:68@=&AE(&1A=&5S(&%R92!E
M<75A;`H@("`@("H@("`@("`@("`@("`@("`@("`^/2`@,2!I9B!T:&ES(&1A
M=&4@:7,@9W)E871E<B`H;&%T97(I"B`@("`@*B`@("`@("`@("`@("`@("`@
M(#P]("TQ(&EF('1H92!O=&AE<B!D871E(&ES(&=R96%T97(@*&QA=&5R*0H@
M("`@("HO"B`@("!F=6YC=&EO;B!C;VUP87)E5&EM92@D9&%T92D*("`@('L*
M("`@("`@("!I9B`H(6ES7V$H)&1A=&4L("=(;W)D95]$871E)RDI('L*("`@
M("`@("`@("`@)&1A=&4@/2`F;F5W($AO<F1E7T1A=&4H)&1A=&4I.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"1T:&ES+3YH;W5R("$]("1D871E+3YH;W5R
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^:&]U<B`M("1D871E+3YH
M;W5R.PH@("`@("`@('T@96QS96EF("@D=&AI<RT^;6EN("$]("1D871E+3YM
M:6XI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM:6X@+2`D9&%T92T^
M;6EN.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<V5C("T@)&1A=&4M/G-E8SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#;VUP87)E('1H:7,@=&\@86YO=&AE<B!D871E(&]B:F5C="P@
M:6YC;'5D:6YG('1I;65S+"!T;R!S964*("`@("`J('=H:6-H(&]N92!I<R!G
M<F5A=&5R("AL871E<BDN($%S<W5M97,@=&AA="!T:&4@9&%T97,@87)E(&EN
M('1H90H@("`@("H@<V%M92!T:6UE>F]N92X*("`@("`J"B`@("`@*B!`<&%R
M86T@;6EX960@)&1A=&4@(%1H92!D871E('1O(&-O;7!A<F4@=&\N"B`@("`@
M*@H@("`@("H@0')E='5R;B!I;G1E9V5R("`]/2`@,"!I9B!T:&4@9&%T97,@
M87)E(&5Q=6%L"B`@("`@*B`@("`@("`@("`@("`@("`@(#X]("`Q(&EF('1H
M:7,@9&%T92!I<R!G<F5A=&5R("AL871E<BD*("`@("`J("`@("`@("`@("`@
M("`@("`@/#T@+3$@:68@=&AE(&]T:&5R(&1A=&4@:7,@9W)E871E<B`H;&%T
M97(I"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;7!A<F5$871E5&EM92@D9&%T
M92D*("`@('L*("`@("`@("!I9B`H(6ES7V$H)&1A=&4L("=(;W)D95]$871E
M)RDI('L*("`@("`@("`@("`@)&1A=&4@/2`F;F5W($AO<F1E7T1A=&4H)&1A
M=&4I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1D:69F(#T@)'1H:7,M/F-O
M;7!A<F5$871E*"1D871E*2D@>PH@("`@("`@("`@("!R971U<FX@)&1I9F8[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YC
M;VUP87)E5&EM92@D9&%T92D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@1V5T('1H92!T:6UE(&]F9G-E="!F;W(@;&]C86P@=&EM92!Z;VYE
M+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1C;VQO;B`@4&QA8V4@
M82!C;VQO;B!B971W965N(&AO=7)S(&%N9"!M:6YU=&5S/PH@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:6UE>F]N92!O9F9S970@87,@82!S=')I
M;F<@:6X@=&AE(&9O<FUA="`K2$@Z34TN"B`@("`@*B\*("`@(&9U;F-T:6]N
M('1Z3V9F<V5T*"1C;VQO;B`]('1R=64I"B`@("!["B`@("`@("`@)'-E8W,@
M/2!D871E*"=:)RP@)'1H:7,M/G1I;65S=&%M<"@I*3L*"B`@("`@("`@:68@
M*"1S96-S(#P@,"D@>PH@("`@("`@("`@("`D<VEG;B`]("<M)SL*("`@("`@
M("`@("`@)'-E8W,@/2`M)'-E8W,["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'-I9VX@/2`G*R<["B`@("`@("`@?0H@("`@("`@("1C;VQO;B`]
M("1C;VQO;B`_("<Z)R`Z("<G.PH@("`@("`@("1M:6YS(#T@:6YT=F%L*"@D
M<V5C<R`K(#,P*2`O(#8P*3L*("`@("`@("!R971U<FX@<W!R:6YT9B@G)7,E
M,#)D)7,E,#)D)RP*("`@("`@("`@("`@("`@("`@("`@("`D<VEG;BP@)&UI
M;G,@+R`V,"P@)&-O;&]N+"`D;6EN<R`E(#8P*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($9O<FUA="!T:6UE(&EN($E33RTX-C`Q(&9O<FUA="X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@1&%T92!A;F0@=&EM92!I;B!)4T\M
M.#8P,2!F;W)M870N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES;S@V,#%$871E
M5&EM92@I"B`@("!["B`@("`@("`@)'1Z;V9F(#T@)'1H:7,M/G1Z3V9F<V5T
M*"D["B`@("`@("`@)&1A=&4@/2`D=&AI<RT^>65A<B`N("<M)R`N("1T:&ES
M+3YM;VYT:"`N("<M)R`N("1T:&ES+3YM9&%Y.PH@("`@("`@("1T:6UE(#T@
M)'1H:7,M/FAO=7(@+B`G.B<@+B`D=&AI<RT^;6EN("X@)SHG("X@)'1H:7,M
M/G-E8SL*"B`@("`@("`@<F5T=7)N("1D871E("X@)U0G("X@)'1I;64@+B`D
M='IO9F8["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&;W)M870@=&EM92!I;B!2
M1D,@,C@R,B!F;W)M870N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M($1A=&4@86YD('1I;64@:6X@4D9#(#(X,C(@9F]R;6%T+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!R9F,R.#(R1&%T951I;64H*0H@("`@>PH@("`@("`@(')E
M='5R;B!D871E*"=$+"!J($T@62!(.FDZ<R`G+"`D=&AI<RT^=&EM97-T86UP
M*"DI("X@)'1H:7,M/G1Z3V9F<V5T*&9A;'-E*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($9O<FUA="!T:6UE(&EN(%)&0R`S,S,Y(&9O<FUA="X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@1&%T92!A;F0@=&EM92!I;B!21D,@
M,S,S.2!F;W)M870N"B`@("`@*B\*("`@(&9U;F-T:6]N(')F8S,S,SE$871E
M5&EM92@I"B`@("!["B`@("`@("`@<F5T=7)N(&1A=&4H)UDM;2UD7%1(.FDG
M+"`D=&AI<RT^=&EM97-T86UP*"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1F]R;6%T('1I;64@=&\@<W1A;F1A<F0@)V-T:6UE)R!F;W)M870N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@($1A=&4@86YD('1I;64N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-4:6UE*"1T:6UE(#T@9F%L<V4I"B`@("!["B`@
M("`@("`@<F5T=7)N(&1A=&4H)T0@32!J($@Z:3IS(%DG+"`D=&AI<RT^=&EM
M97-T86UP*"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@1F]R;6%T(&1A=&4@
M86YD('1I;64@=7-I;F<@<W1R9G1I;64H*2!F;W)M870N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@('-T<F9T:6UE*"D@9F]R;6%T=&5D(&1A=&4@
M86YD('1I;64N"B`@("`@*B\*("`@(&9U;F-T:6]N('-T<F9T:6UE*"1F;W)M
M870I"B`@("!["B`@("`@("`@<F5T=7)N('-T<F9T:6UE*"1F;W)M870L("1T
M:&ES+3YT:6UE<W1A;7`H*2D["B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]396-R970N<&AP````````````````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`Q,S(R,"`Q,#4Q-30S,S<T,"`P,C$S,#``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H
M92!396-R970Z.B!C;&%S<R!P<F]V:61E<R!A;B!!4$D@9F]R(&5N8W)Y<'1I
M;F<@86YD(&1E8W)Y<'1I;F<*("H@<VUA;&P@<&EE8V5S(&]F(&1A=&$@=VET
M:"!T:&4@=7-E(&]F(&$@<VAA<F5D(&ME>2X*("H*("H@5&AE(%-E8W)E=#HZ
M(&9U;F-T:6]N<R!U<V4@=&AE($AO<F1E($-I<&AE<CHZ(&-L87-S(&EF(&UC
M<GEP="!I<R!N;W0*("H@879A:6QA8FQE+@H@*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]396-R970O4V5C<F5T+G!H<"QV(#$N-#4N,3`N-R`R,#`V+S`S+S`R
M(#`U.C(U.C$P('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM
M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@
M2&]R9&5?4V5C<F5T"B`J+PIC;&%S<R!396-R970@>PH*("`@("\J*@H@("`@
M("H@5&%K92!A('-M86QL('!I96-E(&]F(&1A=&$@86YD(&5N8W)Y<'0@:70@
M=VET:"!A(&ME>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1K97D@
M("`@("!4:&4@:V5Y('1O('5S92!F;W(@96YC<GEP=&EO;BX*("`@("`J($!P
M87)A;2!S=')I;F<@)&UE<W-A9V4@(%1H92!P;&%I;G1E>'0@;65S<V%G92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-I<&AE<G1E>'0@
M;65S<V%G92X*("`@("`J+PH@("`@9G5N8W1I;VX@=W)I=&4H)&ME>2P@)&UE
M<W-A9V4I"B`@("!["B`@("`@("`@:68@*%5T:6PZ.F5X=&5N<VEO;D5X:7-T
M<R@G;6-R>7!T)RDI('L*("`@("`@("`@("`@)'1D(#T@0&UC<GEP=%]M;V1U
M;&5?;W!E;BA-0U)94%1?1T]35"P@)R<L($U#4EE05%]-3T1%7T5#0BP@)R<I
M.PH@("`@("`@("`@("!I9B`H)'1D*2!["B`@("`@("`@("`@("`@("`D:78@
M/2!`;6-R>7!T7V-R96%T95]I=BAM8W)Y<'1?96YC7V=E=%]I=E]S:7IE*"1T
M9"DL($U#4EE05%]204Y$*3L*("`@("`@("`@("`@("`@($!M8W)Y<'1?9V5N
M97)I8U]I;FET*"1T9"P@)&ME>2P@)&EV*3L*("`@("`@("`@("`@("`@("1E
M;F-R>7!T961?9&%T82`]($!M8W)Y<'1?9V5N97)I8R@D=&0L("1M97-S86=E
M*3L*("`@("`@("`@("`@("`@($!M8W)Y<'1?9V5N97)I8U]D96EN:70H)'1D
M*3L*"B`@("`@("`@("`@("`@("!R971U<FX@)&5N8W)Y<'1E9%]D871A.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!S=&%T:6,@)&-I<&AE
M<D-A8VAE(#T@87)R87DH*3L*("`@("`@("`D8V%C:&5)9'@@/2!M9#4H)&ME
M>2D["@H@("`@("`@(&EF("@A:7-S970H)&-I<&AE<D-A8VAE6R1C86-H94ED
M>%TI*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O0VEP:&5R
M+G!H<"<["@H@("`@("`@("`@("`D8VEP:&5R0V%C:&5;)&-A8VAE261X72`]
M("9(;W)D95]#:7!H97(Z.F9A8W1O<GDH)V)L;W=F:7-H)RD["B`@("`@("`@
M("`@("1C:7!H97)#86-H95LD8V%C:&5)9'A=+3YS971";&]C:TUO9&4H)V]F
M8C8T)RD["B`@("`@("`@("`@("1C:7!H97)#86-H95LD8V%C:&5)9'A=+3YS
M971+97DH)&ME>2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-I<&AE
M<D-A8VAE6R1C86-H94ED>%TM/F5N8W)Y<'0H)&UE<W-A9V4I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1&5C<GEP="!A(&UE<W-A9V4@96YC<GEP=&5D('=I
M=&@@4V5C<F5T.CIW<FET92@I+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&ME>2`@("`@(%1H92!K97D@=&\@=7-E(&9O<B!D96-R>7!T:6]N+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;65S<V%G92`@5&AE(&-I<&AE<G1E>'0@
M;65S<V%G92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('!L
M86EN=&5X="!M97-S86=E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96%D*"1K
M97DL("1C:7!H97)T97AT*0H@("`@>PH@("`@("`@(&EF("A5=&EL.CIE>'1E
M;G-I;VY%>&ES=',H)VUC<GEP="<I*2!["B`@("`@("`@("`@("1T9"`]($!M
M8W)Y<'1?;6]D=6QE7V]P96XH34-265!47T=/4U0L("<G+"!-0U)94%1?34]$
M15]%0T(L("<G*3L*("`@("`@("`@("`@:68@*"1T9"D@>PH@("`@("`@("`@
M("`@("`@)&EV(#T@0&UC<GEP=%]C<F5A=&5?:78H;6-R>7!T7V5N8U]G971?
M:79?<VEZ92@D=&0I+"!-0U)94%1?4D%.1"D["B`@("`@("`@("`@("`@("!`
M;6-R>7!T7V=E;F5R:6-?:6YI="@D=&0L("1K97DL("1I=BD["B`@("`@("`@
M("`@("`@("`D9&5C<GEP=&5D7V1A=&$@/2!`;61E8W)Y<'1?9V5N97)I8R@D
M=&0L("1C:7!H97)T97AT*3L*("`@("`@("`@("`@("`@($!M8W)Y<'1?9V5N
M97)I8U]D96EN:70H)'1D*3L*"B`@("`@("`@("`@("`@("`O+R!3=')I<"!P
M861D:6YG(&-H87)A8W1E<G,N"B`@("`@("`@("`@("`@("!R971U<FX@<G1R
M:6TH)&1E8W)Y<'1E9%]D871A+"`B7#`B*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<W1A=&EC("1C:7!H97)#86-H93L*("`@("`@("`D
M8V%C:&5)9'@@/2!M9#4H)&ME>2D["@H@("`@("`@(&EF("@A:7-?87)R87DH
M)&-I<&AE<D-A8VAE*2!\?"`A:7-S970H)&-I<&AE<D-A8VAE6R1C86-H94ED
M>%TI*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O0VEP:&5R
M+G!H<"<["@H@("`@("`@("`@("`D8VEP:&5R0V%C:&5;)&-A8VAE261X72`]
M("9(;W)D95]#:7!H97(Z.F9A8W1O<GDH)V)L;W=F:7-H)RD["B`@("`@("`@
M("`@("1C:7!H97)#86-H95LD8V%C:&5)9'A=+3YS971";&]C:TUO9&4H)V]F
M8C8T)RD["B`@("`@("`@("`@("1C:7!H97)#86-H95LD8V%C:&5)9'A=+3YS
M971+97DH)&ME>2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-I<&AE
M<D-A8VAE6R1C86-H94ED>%TM/F1E8W)Y<'0H)&-I<&AE<G1E>'0I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1V5N97)A=&4@82!S96-R970@:V5Y("AF;W(@
M96YC<GEP=&EO;BDL(&5I=&AE<B!U<VEN9R!A(')A;F1O;0H@("`@("H@;60U
M('-T<FEN9R!A;F0@<W1O<FEN9R!I="!I;B!A(&-O;VMI92!I9B!T:&4@=7-E
M<B!H87,@8V]O:VEE<PH@("`@("H@96YA8FQE9"P@;W(@;75N9VEN9R!S;VUE
M(&MN;W=N('9A;'5E<R!I9B!T:&5Y(&1O;B=T+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&ME>6YA;64@(%1H92!N86UE(&]F('1H92!K97D@=&\@
M<V5T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<V5C<F5T
M(&ME>2!T:&%T(&AA<R!B965N(&=E;F5R871E9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5T2V5Y*"1K97EN86UE(#T@)V=E;F5R:6,G*0H@("`@>PH@("`@
M("`@(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@)'1I;65O=70@/2`D8V]N9ELG
M<V5S<VEO;B==6R=T:6UE;W5T)UT@/R!T:6UE*"D@*R`D8V]N9ELG<V5S<VEO
M;B==6R=T:6UE;W5T)UT@.B`P.PH*("`@("`@("!I9B`H:7-S970H)%]#3T]+
M245;)&-O;F9;)W-E<W-I;VXG75LG;F%M92==72DI('L*("`@("`@("`@("`@
M:68@*&ES<V5T*"1?0T]/2TE%6R1K97EN86UE("X@)U]K97DG72DI('L*("`@
M("`@("`@("`@("`@("1K97D@/2`D7T-/3TM)15LD:V5Y;F%M92`N("=?:V5Y
M)UT["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D:V5Y
M(#T@;60U*&UT7W)A;F0H*2D["B`@("`@("`@("`@("`@("`D7T-/3TM)15LD
M:V5Y;F%M92`N("=?:V5Y)UT@/2`D:V5Y.PH@("`@("`@("`@("`@("`@0'-E
M=&-O;VMI92@D:V5Y;F%M92`N("=?:V5Y)RP@)&ME>2P@)'1I;65O=70L("1C
M;VYF6R=C;V]K:64G75LG<&%T:"==+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D8V]N9ELG8V]O:VEE)UU;)V1O;6%I;B==+"`D8V]N9ELG=7-E7W-S
M;"==(#T](#$@/R`Q(#H@,"D["B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D:V5Y(#T@<V5S<VEO;E]I9"@I.PH@("`@("`@
M("`@("!`<V5T8V]O:VEE*"1K97EN86UE("X@)U]K97DG+"`D:V5Y+"`D=&EM
M96]U="P@)&-O;F9;)V-O;VMI92==6R=P871H)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@)&-O;F9;)V-O;VMI92==6R=D;VUA:6XG72P@)&-O;F9;)W5S
M95]S<VPG72`]/2`Q(#\@,2`Z(#`I.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1K97D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@82!S96-R
M970@:V5Y+"!E:71H97(@9G)O;2!A(&-O;VMI92P@;W(@:68@=&AE(&-O;VMI
M90H@("`@("H@:7-N)W0@=&AE<F4L(&%S<W5M92!W92!A<F4@=7-I;F<@82!M
M=6YG960@=F5R<VEO;B!O9B!A(&MN;W=N"B`@("`@*B!B87-E('9A;'5E+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ME>6YA;64@(%1H92!N86UE
M(&]F('1H92!K97D@=&\@9V5T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@<V5C<F5T(&ME>2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M2V5Y*"1K97EN86UE(#T@)V=E;F5R:6,G*0H@("`@>PH@("`@("`@('-T871I
M8R`D:V5Y8V%C:&4@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H(6ES<V5T*"1K
M97EC86-H95LD:V5Y;F%M95TI*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D
M7T-/3TM)15LD:V5Y;F%M92`N("=?:V5Y)UTI*2!["B`@("`@("`@("`@("`@
M("`D:V5Y8V%C:&5;)&ME>6YA;65=(#T@)%]#3T]+245;)&ME>6YA;64@+B`G
M7VME>2==.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M9VQO8F%L("1C;VYF.PH@("`@("`@("`@("`@("`@)&ME>6-A8VAE6R1K97EN
M86UE72`]('-E<W-I;VY?:60H*3L*("`@("`@("`@("`@("`@($!S971C;V]K
M:64H)&ME>6YA;64@+B`G7VME>2<L("1K97EC86-H95LD:V5Y;F%M95TL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1C;VYF6R=S97-S:6]N)UU;)W1I
M;65O=70G72`_('1I;64H*2`K("1C;VYF6R=S97-S:6]N)UU;)W1I;65O=70G
M72`Z(#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;VYF6R=C;V]K
M:64G75LG<&%T:"==+"`D8V]N9ELG8V]O:VEE)UU;)V1O;6%I;B==+"`D8V]N
M9ELG=7-E7W-S;"==(#T](#$@/R`Q(#H@,"D["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D:V5Y8V%C:&5;)&ME>6YA;65=.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0VQE87)S(&$@<V5C<F5T(&ME>2!E;G1R
M>2!F<F]M('1H92!C=7)R96YT(&-O;VMI92X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1K97EN86UE("!4:&4@;F%M92!O9B!T:&4@:V5Y('1O(&-L
M96%R+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!K
M97D@97AI<W1E9"P@9F%L<V4@:68@;F]T+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!C;&5A<DME>2@D:V5Y;F%M92`]("=G96YE<FEC)RD*("`@('L*("`@("`@
M("!I9B`H:7-S970H)%]#3T]+245;)$=,3T)!3%-;)V-O;F8G75LG<V5S<VEO
M;B==6R=N86UE)UU=*2`F)@H@("`@("`@("`@("!I<W-E="@D7T-/3TM)15LD
M:V5Y;F%M92`N("=?:V5Y)UTI*2!["B`@("`@("`@("`@('5N<V5T*"1?0T]/
M2TE%6R1K97EN86UE("X@)U]K97DG72D["B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@('T*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-,
M22YP:'``````````````````````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#(S-#(T(#$P-3$U-#,S-S0P(#`R,#0W,0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@2&]R9&5?
M0TQ).CH@05!)(&9O<B!B87-I8R!C;VUM86YD+6QI;F4@9G5N8W1I;VYA;&ET
M>2]C:&5C:W,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T-,22]#3$DN<&AP
M+'8@,2XT,BXV+C$S(#(P,#8O,#4O,S$@,3(Z,S$Z,#`@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@2F%N(%-C:&YE
M:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T
M:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@
M("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?0TQ)"B`J+PIC;&%S<R!(
M;W)D95]#3$D@>PH*("`@("\J*@H@("`@("H@07)E('=E(')U;FYI;F<@;VX@
M82!C;VYS;VQE/PH@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO
M"B`@("!V87(@)%]C;VYS;VQE.PH*("`@("\J*@H@("`@("H@5&AE(&YE=VQI
M;F4@<W1R:6YG('1O('5S92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("HO"B`@("!V87(@)%]N97=L:6YE.PH*("`@("\J*@H@("`@("H@5&AE
M(&EN9&5N="!S=')I;F<@=&\@=7-E+@H@("`@("H*("`@("`J($!V87(@<W1R
M:6YG"B`@("`@*B\*("`@('9A<B`D7VEN9&5N=#L*"B`@("`O*BH*("`@("`J
M(%1H92!S=')I;F<@=&\@;6%R:R!T:&4@8F5G:6YN:6YG(&]F(&)O;&0@=&5X
M="X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@
M)%]B;VQD7W-T87)T(#T@)R<["@H@("`@+RHJ"B`@("`@*B!4:&4@<W1R:6YG
M('1O(&UA<FL@=&AE(&5N9"!O9B!B;VQD('1E>'0N"B`@("`@*@H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?8F]L9%]E;F0@/2`G)SL*
M"B`@("`O*BH*("`@("`J(%1H92!S=')I;F=S('1O(&UA<FL@=&AE(&)E9VEN
M;FEN9R!O9B!C;VQO=7)E9"!T97AT+@H@("`@("HO"B`@("!V87(@)%]R961?
M<W1A<G0@("`@/2`G)SL*("`@('9A<B`D7V=R965N7W-T87)T("`]("<G.PH@
M("`@=F%R("1?>65L;&]W7W-T87)T(#T@)R<["B`@("!V87(@)%]B;'5E7W-T
M87)T("`@/2`G)SL*"B`@("`O*BH*("`@("`J(%1H92!S=')I;F=S('1O(&UA
M<FL@=&AE(&5N9"!O9B!C;VQO=7)E9"!T97AT+@H@("`@("HO"B`@("!V87(@
M)%]R961?96YD("`@("`@/2`G)SL*("`@('9A<B`D7V=R965N7V5N9"`@("`]
M("<G.PH@("`@=F%R("1?>65L;&]W7V5N9"`@(#T@)R<["B`@("!V87(@)%]B
M;'5E7V5N9"`@("`@/2`G)SL*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!S
M:6YG;&4@:6YS=&%N8V4@;V8@=&AE($AO<F1E7T-,22!C;&%S<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@I"B`@("!["B`@("`@("`@<W1A
M=&EC("1I;G-T86YC93L*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC92DI
M('L*("`@("`@("`@("`@)&EN<W1A;F-E(#T@;F5W($AO<F1E7T-,22@I.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)&EN<W1A;F-E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1&5T96-T('1H92!C=7)R96YT(&5N=FER;VYM96YT("AW
M96(@<V5R=F5R(&]R(&-O;G-O;&4I(&%N9"!S971S"B`@("`@*B!I;G1E<FYA
M;"!V86QU97,@86-C;W)D:6YG;'DN"B`@("`@*B\*("`@(&9U;F-T:6]N($AO
M<F1E7T-,22@I"B`@("!["B`@("`@("`@)'1H:7,M/E]C;VYS;VQE(#T@)'1H
M:7,M/G)U;FYI;F=&<F]M0TQ)*"D["@H@("`@("`@(&EF("@D=&AI<RT^7V-O
M;G-O;&4I('L*("`@("`@("`@("`@)'1H:7,M/E]N97=L:6YE(#T@(EQN(CL*
M("`@("`@("`@("`@)'1H:7,M/E]I;F1E;G0@(#T@)R`@("`G.PH*("`@("`@
M("`@("`@)'1E<FT@/2!G971E;G8H)U1%4DTG*3L*("`@("`@("`@("`@:68@
M*"1T97)M*2!["B`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+UXH
M>'1E<FU\=G0R,C!\;&EN=7@I+R<L("1T97)M*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?8F]L9%]S=&%R="`@(#T@(EQX,6);,6TB.PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5D7W-T87)T("`@(#T@(EQX,6);
M,#$[,S%M(CL*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=R965N7W-T
M87)T("`](")<>#%B6S`Q.S,R;2(["B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]Y96QL;W=?<W1A<G0@/2`B7'@Q8ELP,3LS,VTB.PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?8FQU95]S=&%R="`@(#T@(EQX,6);,#$[,S1M
M(CL*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V)O;&1?96YD(#T@)'1H
M:7,M/E]R961?96YD(#T@)'1H:7,M/E]G<F5E;E]E;F0@/2`D=&AI<RT^7WEE
M;&QO=U]E;F0@/2`D=&AI<RT^7V)L=65?96YD(#T@(EQX,6);,&TB.PH@("`@
M("`@("`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H)R]>=G0Q,#`O)RP@
M)'1E<FTI*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]B;VQD7W-T
M87)T(#T@(EQX,6);,6TB.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M8F]L9%]E;F0@("`](")<>#%B6S!M(CL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES
M+3Y?;F5W;&EN92`]("<\8G(@+SXG.PH@("`@("`@("`@("`D=&AI<RT^7VEN
M9&5N="`@/2!S=')?<F5P96%T*"<F;F)S<#LG+"`T*3L*"B`@("`@("`@("`@
M("1T:&ES+3Y?8F]L9%]S=&%R="`@(#T@)SQS=')O;F<^)SL*("`@("`@("`@
M("`@)'1H:7,M/E]B;VQD7V5N9"`@("`@/2`G/"]S=')O;F<^)SL*("`@("`@
M("`@("`@)'1H:7,M/E]R961?<W1A<G0@("`@/2`G/'-P86X@<W1Y;&4](F-O
M;&]R.G)E9"(^)SL*("`@("`@("`@("`@)'1H:7,M/E]G<F5E;E]S=&%R="`@
M/2`G/'-P86X@<W1Y;&4](F-O;&]R.F=R965N(CXG.PH@("`@("`@("`@("`D
M=&AI<RT^7WEE;&QO=U]S=&%R="`]("<\<W!A;B!S='EL93TB8V]L;W(Z>65L
M;&]W(CXG.PH@("`@("`@("`@("`D=&AI<RT^7V)L=65?<W1A<G0@("`]("<\
M<W!A;B!S='EL93TB8V]L;W(Z8FQU92(^)SL*("`@("`@("`@("`@)'1H:7,M
M/E]R961?96YD(#T@)'1H:7,M/E]G<F5E;E]E;F0@/2`D=&AI<RT^7WEE;&QO
M=U]E;F0@/2`D=&AI<RT^7V)L=65?96YD(#T@)SPO<W!A;CXG.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%!R:6YT<R`D=&5X="!O;B!A('-I
M;F=L92!L:6YE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1T97AT
M("!4:&4@=&5X="!T;R!P<FEN="X*("`@("`J($!P87)A;2!B;V]L96%N("1P
M<F4@("!)9B!T<G5E('1H92!L:6YE8G)E86L@:7,@<')I;G1E9"!B969O<F4*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!T:&4@=&5X="!I;G-T96%D
M(&]F(&%F=&5R(&ET+@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET96QN*"1T
M97AT(#T@)R<L("1P<F4@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H)'!R
M92D@>PH@("`@("`@("`@("!E8VAO("1T:&ES+3Y?;F5W;&EN92`N("1T97AT
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&5C:&\@)'1E>'0@+B`D
M=&AI<RT^7VYE=VQI;F4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@:6YD96YT960@<W1R:6YG+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!T97AT('1O(&EN9&5N="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@:6YD96YT*"1T97AT*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7VEN9&5N="`N("1T97AT.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!A(&)O;&0@=F5R<VEO;B!O9B`D=&5X="X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("!4:&4@=&5X="!T;R!B
M;VQD+@H@("`@("HO"B`@("!F=6YC=&EO;B!B;VQD*"1T97AT*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7V)O;&1?<W1A<G0@+B`D=&5X="`N("1T
M:&ES+3Y?8F]L9%]E;F0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M(&$@<F5D('9E<G-I;VX@;V8@)'1E>'0N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=&5X="`@5&AE('1E>'0@=&\@<')I;G0@:6X@<F5D+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!R960H)'1E>'0I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?<F5D7W-T87)T("X@)'1E>'0@+B`D=&AI<RT^7W)E9%]E
M;F0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@9W)E96X@=F5R
M<VEO;B!O9B`D=&5X="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T
M97AT("!4:&4@=&5X="!T;R!P<FEN="!I;B!G<F5E;BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@9W)E96XH)'1E>'0I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?9W)E96Y?<W1A<G0@+B`D=&5X="`N("1T:&ES+3Y?9W)E96Y?96YD
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&)L=64@=F5R<VEO
M;B!O9B`D=&5X="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT
M("!4:&4@=&5X="!T;R!P<FEN="!I;B!B;'5E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!B;'5E*"1T97AT*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M7V)L=65?<W1A<G0@+B`D=&5X="`N("1T:&ES+3Y?8FQU95]E;F0["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@>65L;&]W('9E<G-I;VX@;V8@
M)'1E>'0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@5&AE
M('1E>'0@=&\@<')I;G0@:6X@>65L;&]W+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!Y96QL;W<H)'1E>'0I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M>65L;&]W7W-T87)T("X@)'1E>'0@+B`D=&AI<RT^7WEE;&QO=U]E;F0["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!$:7-P;&%Y<R!A(&UE<W-A9V4N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D979E;G0@(%1H92!M97-S86=E('-T
M<FEN9RX*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@("!4:&4@='EP92!O
M9B!M97-S86=E.B`G8VQI+F5R<F]R)RP@)V-L:2YW87)N:6YG)RP*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`G8VQI+G-U8V-E<W,G+"!O<B`G8VQI
M+FUE<W-A9V4G+@H@("`@("HO"B`@("!F=6YC=&EO;B!M97-S86=E*"1M97-S
M86=E+"`D='EP92`]("=C;&DN;65S<V%G92<I"B`@("!["B`@("`@("`@)&UE
M<W-A9V4@/2!W;W)D=W)A<"@D;65S<V%G92P@-C@L(")<;B`@("`@("`@("`@
M(BP@=')U92D["@H@("`@("`@('-W:71C:"`H)'1Y<&4I('L*("`@("`@("!C
M87-E("=C;&DN97)R;W(G.@H@("`@("`@("`@("`D='EP95]M97-S86=E(#T@
M)'1H:7,M/G)E9"@G6R!%4E)/4B$@72`G*3L*("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@(&-A<V4@)V-L:2YW87)N:6YG)SH*("`@("`@("`@("`@)'1Y
M<&5?;65S<V%G92`]("1T:&ES+3YY96QL;W<H)UL@(%=!4DX@(%T@)RD["B`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=C;&DN<W5C8V5S<R<Z
M"B`@("`@("`@("`@("1T>7!E7VUE<W-A9V4@/2`D=&AI<RT^9W)E96XH)UL@
M("!/2R`@(%T@)RD["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E
M("=C;&DN;65S<V%G92<Z"B`@("`@("`@("`@("1T>7!E7VUE<W-A9V4@/2`D
M=&AI<RT^8FQU92@G6R`@24Y&3R`@72`G*3L*("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^=W)I=&5L;B@D='EP95]M97-S
M86=E("X@)&UE<W-A9V4I.PH@("`@?0H*("`@("\J*@H@("`@("H@1&ES<&QA
M>7,@82!F871A;"!E<G)O<B!M97-S86=E+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&5R<F]R("!4:&4@97)R;W(@=&5X="!T;R!D:7-P;&%Y+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!F871A;"@D97)R;W(I"B`@("!["B`@("`@
M("`@)'1H:7,M/G=R:71E;&XH)'1H:7,M/G)E9"@G/3T]/3T]/3T]/3T]/3T]
M/3T]/3TG*2D["B`@("`@("`@)'1H:7,M/G=R:71E;&XH*3L*("`@("`@("`D
M=&AI<RT^=W)I=&5L;B@D=&AI<RT^<F5D*%\H(D9A=&%L($5R<F]R.B(I*2D[
M"B`@("`@("`@)'1H:7,M/G=R:71E;&XH)'1H:7,M/G)E9"@D97)R;W(I*3L*
M("`@("`@("`D=&AI<RT^=W)I=&5L;B@I.PH@("`@("`@("1T:&ES+3YW<FET
M96QN*"1T:&ES+3YR960H)ST]/3T]/3T]/3T]/3T]/3T]/3T])RDI.PH@("`@
M("`@(&5X:70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!0<F]M<'1S(&9O<B!A
M('5S97(@<F5S<&]N<V4N"B`@("`@*@H@("`@("H@0'1O9&\@2&]R9&4@-#H@
M<W=I=&-H("1C:&]I8V5S(&%N9"`D9&5F875L=`H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'!R;VUP="`@5&AE(&UE<W-A9V4@=&\@9&ES<&QA>2!W
M:&5N('!R;VUP=&EN9R!T:&4@=7-E<BX*("`@("`J($!P87)A;2!A<G)A>2`D
M8VAO:6-E<R`@5&AE(&-H;VEC97,@879A:6QA8FQE('1O('1H92!U<V5R(&]R
M(&YU;&P@9F]R(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@=&5X
M="!I;G!U="X*("`@("`J($!P87)A;2!S=')I;F<@)&1E9F%U;'0@5&AE(&1E
M9F%U;'0@=F%L=64@:68@;F\@=F%L=64@<W!E8VEF:65D+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1H92!U<V5R)W,@<F5S<&]N<V4@=&\@=&AE
M('!R;VUP="X*("`@("`J+PH@("`@9G5N8W1I;VX@<')O;7!T*"1P<F]M<'0L
M("1C:&]I8V5S(#T@;G5L;"P@)&1E9F%U;'0@/2!N=6QL*0H@("`@>PH@("`@
M("`@(&EF("@D9&5F875L="`A/3T@;G5L;"D@>PH@("`@("`@("`@("`D<')O
M;7!T("X]("<@6R<@+B`D9&5F875L="`N("==)SL*("`@("`@("!]"@H@("`@
M("`@("\O($UA:6X@979E;G0@;&]O<"!T;R!C87!T=7)E('1O<"!L979E;"!C
M;VUM86YD+@H@("`@("`@('=H:6QE("AT<G5E*2!["B`@("`@("`@("`@("\O
M(%!R:6YT(&]U="!T:&4@<')O;7!T(&UE<W-A9V4N"B`@("`@("`@("`@("1T
M:&ES+3YW<FET96QN*"1P<F]M<'0@+B`G("<L("%I<U]A<G)A>2@D8VAO:6-E
M<RDI.PH@("`@("`@("`@("!I9B`H:7-?87)R87DH)&-H;VEC97,I("8F("%E
M;7!T>2@D8VAO:6-E<RDI('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1C
M:&]I8V5S(&%S("1K97D@/3X@)&-H;VEC92D@>PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YW<FET96QN*"1T:&ES+3YI;F1E;G0H)R@G("X@)'1H:7,M
M/F)O;&0H)&ME>2D@+B`G*2`G("X@)&-H;VEC92DI.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)'1H:7,M/G=R:71E;&XH7R@B5'EP92!Y
M;W5R(&-H;VEC93H@(BDL('1R=64I.PH@("`@("`@("`@("`@("`@0&]B7V9L
M=7-H*"D["@H@("`@("`@("`@("`@("`@+R\@1V5T('1H92!U<V5R(&-H;VEC
M92X*("`@("`@("`@("`@("`@("1R97-P;VYS92`]('1R:6TH9F=E=',H4U1$
M24XI*3L*("`@("`@("`@("`@("`@(&EF("@D<F5S<&]N<V4@/3T]("<G("8F
M("1D969A=6QT("$]/2!N=6QL*2!["B`@("`@("`@("`@("`@("`@("`@)')E
M<W!O;G-E(#T@)&1E9F%U;'0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&-H;VEC97-;)')E<W!O;G-E72DI('L*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)')E<W!O;G-E.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=W)I
M=&5L;BAS<')I;G1F*%\H(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N
M(BDL("1R97-P;VYS92DI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)')E<W!O;G-E(#T@=')I;2AF
M9V5T<RA35$1)3BDI.PH@("`@("`@("`@("`@("`@:68@*"1R97-P;VYS92`]
M/3T@)R<@)B8@)&1E9F%U;'0@(3T](&YU;&PI('L*("`@("`@("`@("`@("`@
M("`@("`D<F5S<&]N<V4@/2`D9&5F875L=#L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(')E='5R;B`D<F5S<&]N<V4["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5A9',@979E<GET:&EN9R!T:&%T(&ES('-E;G0@=&AR
M;W5G:"!S=&%N9&%R9"!I;G!U="!A;F0@<F5T=7)N<R!I=`H@("`@("H@87,@
M82!S:6YG;&4@<W1R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@8V]N=&5N=',@;V8@=&AE('-T86YD87)D(&EN<'5T+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!R96%D4W1D:6XH*0H@("`@>PH@("`@("`@("1I;B`]
M("<G.PH@("`@("`@('=H:6QE("@A9F5O9BA35$1)3BDI('L*("`@("`@("`@
M("`@)&EN("X](&9G971S*%-41$E.+"`Q,#(T*3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1I;CL*("`@('T*"B`@("`O*BH*("`@("`J($-,22!S8W)I
M<'1S('-H;W5L9&XG="!T:6UE;W5T+"!S;R!T<GD@=&\@<V5T('1H92!T:6UE
M(&QI;6ET('1O"B`@("`@*B!N;VYE+B!!;'-O(&EN:71I86QI>F4@82!F97<@
M=F%R:6%B;&5S(&EN("1?4T525D52('1H870@87)E;B=T('!R97-E;G0*("`@
M("`J(&9R;VT@=&AE($-,22X*("`@("`J"B`@("`@*B!`<W1A=&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&EN:70H*0H@("`@>PH@("`@("`@("\J(%)U;B!C
M;VYS=')U8W1O<B!N;W<@8F5C875S92!I="!R97%U:7)E<R`D7U-%4E9%4ELG
M4T525D527TY!344G72!T;PH@("`@("`@("`J(&)E(&5M<'1Y(&EF(&-A;&QE
M9"!W:71H(&$@0T=)(%-!4$DN("HO"B`@("`@("`@)&-L:2`]("9(;W)D95]#
M3$DZ.G-I;F=L971O;B@I.PH*("`@("`@("!`<V5T7W1I;65?;&EM:70H,"D[
M"B`@("`@("`@;V)?:6UP;&EC:71?9FQU<V@H=')U92D["B`@("`@("`@:6YI
M7W-E="@G:'1M;%]E<G)O<G,G+"!F86QS92D["B`@("`@("`@)%]315)615);
M)TA45%!?2$]35"==(#T@)S$R-RXP+C`N,2<["B`@("`@("`@)%]315)615);
M)U-%4E9%4E].04U%)UT@/2`G,3(W+C`N,"XQ)SL*("`@("`@("`D7U-%4E9%
M4ELG4T525D527U!/4E0G72`]("<G.PH@("`@("`@("1?4T525D526R=214U/
M5$5?041$4B==(#T@)R<["B`@("`@("`@)%]315)615);)U!(4%]314Q&)UT@
M/2!I<W-E="@D87)G=BD@/R`D87)G=ELP72`Z("<G.PH@("`@("`@(&EF("@A
M9&5F:6YE9"@G4U1$24XG*2D@>PH@("`@("`@("`@("!D969I;F4H)U-41$E.
M)RP@9F]P96XH)W!H<#HO+W-T9&EN)RP@)W(G*2D["B`@("`@("`@?0H@("`@
M("`@(&EF("@A9&5F:6YE9"@G4U1$3U54)RDI('L*("`@("`@("`@("`@9&5F
M:6YE*"=35$1/550G+"!F;W!E;B@G<&AP.B\O<W1D;W5T)RP@)W(G*2D["B`@
M("`@("`@?0H@("`@("`@(&EF("@A9&5F:6YE9"@G4U1$15)2)RDI('L*("`@
M("`@("`@("`@9&5F:6YE*"=35$1%4E(G+"!F;W!E;B@G<&AP.B\O<W1D97)R
M)RP@)W(G*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@36%K
M92!S=7)E('=E)W)E(&)E:6YG(&-A;&QE9"!F<F]M('1H92!C;VUM86YD(&QI
M;F4L(&%N9"!N;W0@=FEA"B`@("`@*B!T:&4@=V5B+@H@("`@("H*("`@("`J
M($!S=&%T:6,*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@
M:68@=V4@87)E+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(')U;FYI;F=&<F]M0TQ)*"D*("`@('L*("`@("`@("`D<V%P:2`]('!H
M<%]S87!I7VYA;64H*3L*("`@("`@("!I9B`H)'-A<&D@/3T@)V-L:2<I('L*
M("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<F5T=7)N("1S87!I(#T]("=C9VDG("8F(&5M<'1Y*"1?4T52
M5D526R=315)615)?3D%-12==*3L*("`@("`@("!]"B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-A8VAE
M+G!H<```````````````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#$T,#$Q(#$P-3$U-#,S-S0P(#`R,3`U-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@5&AE($AO<F1E
M7T-A8VAE.CH@8VQA<W,@<')O=FED97,@82!C;VUM;VX@86)S=')A8W1E9"!I
M;G1E<F9A8V4@:6YT;PH@*B!T:&4@=F%R:6]U<R!C86-H:6YG(&)A8VME;F1S
M+B`@270@86QS;R!P<F]V:61E<R!F=6YC=&EO;G,@9F]R"B`J(&-H96-K:6YG
M(&EN+"!R971R:65V:6YG+"!A;F0@9FQU<VAI;F<@82!C86-H92X*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO0V%C:&4O0V%C:&4N<&AP+'8@,2XS,2XQ,"XQ
M,2`R,#`V+S`Q+S`Q(#(Q.C(X.C$P(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,3DY.2TR,#`V($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO
M<F<^"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!!
M;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`875T:&]R
M("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E
M("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E7T-A8VAE"B`J+PIC;&%S
M<R!(;W)D95]#86-H92!["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W0@82!N
M97<@2&]R9&5?0V%C:&4@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`D<&%R86US("!087)A;65T97(@87)R87DN"B`@("`@*B\*("`@(&9U
M;F-T:6]N($AO<F1E7T-A8VAE*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@
M("`@("`@("\J($]N;'D@9&\@9V%R8F%G92!C;VQL96-T:6]N(&EF(&%S:V5D
M(&9O<BP@86YD('1H96X@;VYL>2`Q)2!O9B!T:&4*("`@("`@("`@*B!T:6UE
M('=E(&-R96%T92!A;B!O8FIE8W0N("HO"B`@("`@("`@:68@*"%E;7!T>2@D
M<&%R86US6R=G8R==*2`F)@H@("`@("`@("`@("`H<F%N9"@P+"`Y.2D@/3T@
M,"DI('L*("`@("`@("`@("`@)'1H:7,M/E]D;T=#*"1P87)A;7-;)V=C)UTI
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O
M(')E=')I979E(&$@8V%C:&5D(&]B:F5C="!A;F0@<F5T=7)N(&ET('1O('1H
M90H@("`@("H@8V%L;&5R+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@("1K97D@("`@("`@3V)J96-T($E$
M('1O('%U97)Y+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&QI9F5T:6UE("!,
M:69E=&EM92!O9B!T:&4@;V)J96-T(&EN('-E8V]N9',N"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@0V%C:&5D(&1A=&$L(&]R(&9A;'-E(&EF(&YO
M;F4@=V%S(&9O=6YD+@H@("`@("HO"B`@("!F=6YC=&EO;B!G970H)&ME>2P@
M)&QI9F5T:6UE(#T@,2D*("`@('L*("`@("`@("!R971U<FX@9F%L<V4["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!S=&]R92!A;B!O8FIE
M8W0@:6X@=&AE(&-A8VAE+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&ME>2`@($]B:F5C="!)1"!U<V5D
M(&%S('1H92!C86-H:6YG(&ME>2X*("`@("`J($!P87)A;2!M:7AE9"`@)&1A
M=&$@($1A=&$@=&\@<W1O<F4@:6X@=&AE(&-A8VAE+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O;B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S970H)&ME>2P@)&1A=&$I
M"B`@("!["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!!='1E;7!T<R!T;R!D:7)E8W1L>2!O=71P=70@82!C86-H960@;V)J
M96-T+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@("1K97D@("`@("`@3V)J96-T($E$('1O('%U97)Y+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&QI9F5T:6UE("!,:69E=&EM92!O9B!T
M:&4@;V)J96-T(&EN('-E8V]N9',N"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@0V%C:&5D(&1A=&$L(&]R(&9A;'-E(&EF(&YO;F4@=V%S(&9O=6YD
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!O=71P=70H)&ME>2P@)&QI9F5T:6UE
M(#T@,2D*("`@('L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#:&5C:W,@:68@82!G:79E;B!K97D@97AI<W1S(&EN('1H
M92!C86-H92P@=F%L:60@9F]R('1H92!G:79E;@H@("`@("H@;&EF971I;64N
M"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`@)&ME>2`@("`@("!#86-H92!K97D@=&\@8VAE8VLN"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D;&EF971I;64@($QI9F5T:6UE(&]F('1H92!K
M97D@:6X@<V5C;VYD<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M($5X:7-T86YC92X*("`@("`J+PH@("`@9G5N8W1I;VX@97AI<W1S*"1K97DL
M("1L:69E=&EM92`](#$I"B`@("!["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@17AP:7)E(&%N>2!E>&ES=&EN9R!D871A
M(&9O<B!T:&4@9VEV96X@:V5Y+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ME>2`@0V%C:&4@:V5Y('1O
M(&5X<&ER92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%-U8V-E
M<W,@;W(@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@97AP:7)E*"1K
M97DI"B`@("!["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!$;R!A;GD@9V%R8F%G92!C;VQL96-T:6]N(&YE961E9"!F;W(@
M=&AE(&1R:79E<BX*("`@("`J"B`@("`@*B!`<')I=F%T90H@("`@("H*("`@
M("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1S
M96-S("!4:&4@;6EN:6UU;2!A;6]U;G0@;V8@=&EM92`H:6X@<V5C;VYD<RD@
M<F5Q=6ER960*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!B969O<F4@
M82!C86-H92!I=&5M(&ES(')E;6]V960N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]D;T=#*"1S96-S*0H@("`@>PH@("`@?0H*("`@("\J*@H@("`@("H@071T
M96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E=&4@2&]R9&5?0V%C:&4@:6YS=&%N
M8V4@8F%S960@;VX@)&1R:79E<BX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX
M960@)&1R:79E<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@2&]R9&5?0V%C:&4@
M<W5B8VQA<W,@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!R971U
M<FXN($EF("1D<FEV97(@:7,@86X@87)R87DL('1H96X@=V4@=VEL;"!L;V]K
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@:6X@)&1R:79E<ELP72]L
M:6(O0V%C:&4O(&9O<B!T:&4@<W5B8VQA<W,*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!I;7!L96UE;G1A=&EO;B!N86UE9"`D9')I=F5R6S%=+G!H
M<"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I
M;FEN9R!A;GD@861D:71I;VYA;`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@(&-O;F9I9W5R871I;VX@;W(@8V]N;F5C=&EO;B!P87)A;65T97)S(&$@
M<W5B8VQA<W,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!M:6=H="!N
M965D+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?0V%C:&4@(%1H92!N
M97=L>2!C<F5A=&5D(&-O;F-R971E($AO<F1E7T-A8VAE(&EN<W1A;F-E+"!O
M<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@9F%L<V4@;VX@97)R;W(N
M"B`@("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1D<FEV97(L("1P87)A
M;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D9')I
M=F5R*2D@>PH@("`@("`@("`@("`D87!P(#T@)&1R:79E<ELP73L*("`@("`@
M("`@("`@)&1R:79E<B`]("1D<FEV97);,5T["B`@("`@("`@?0H*("`@("`@
M("`D9')I=F5R(#T@8F%S96YA;64H)&1R:79E<BD["B`@("`@("`@:68@*&5M
M<'1Y*"1D<FEV97(I('Q\("1D<FEV97(@/3T@)VYO;F4G*2!["B`@("`@("`@
M("`@("1C86-H92`]("9N97<@2&]R9&5?0V%C:&4H)'!A<F%M<RD["B`@("`@
M("`@("`@(')E='5R;B`D8V%C:&4["B`@("`@("`@?0H*("`@("`@("!I9B`H
M(65M<'1Y*"1A<'`I*2!["B`@("`@("`@("`@(&EN8VQU9&5?;VYC92`D87!P
M("X@)R]L:6(O0V%C:&4O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@
M?2!E;'-E:68@*$!F:6QE7V5X:7-T<RAD:7)N86UE*%]?1DE,15]?*2`N("<O
M0V%C:&4O)R`N("1D<FEV97(@+B`G+G!H<"<I*2!["B`@("`@("`@("`@(&EN
M8VQU9&5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O0V%C:&4O)R`N("1D
M<FEV97(@+B`G+G!H<"<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M0&EN8VQU9&5?;VYC92`G2&]R9&4O0V%C:&4O)R`N("1D<FEV97(@+B`G+G!H
M<"<["B`@("`@("`@?0H*("`@("`@("`D8VQA<W,@/2`G2&]R9&5?0V%C:&5?
M)R`N("1D<FEV97(["B`@("`@("`@:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I
M*2!["B`@("`@("`@("`@("1C86-H92`]("9N97<@)&-L87-S*"1P87)A;7,I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1C86-H92`](%!%05(Z
M.G)A:7-E17)R;W(H)T-L87-S(&1E9FEN:71I;VX@;V8@)R`N("1C;&%S<R`N
M("<@;F]T(&9O=6YD+B<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1C
M86-H93L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R
M;B!A(')E9F5R96YC92!T;R!A(&-O;F-R971E($AO<F1E7T-A8VAE"B`@("`@
M*B!I;G-T86YC92!B87-E9"!O;B`D9')I=F5R+B!)="!W:6QL(&]N;'D@8W)E
M871E(&$@;F5W(&EN<W1A;F-E"B`@("`@*B!I9B!N;R!(;W)D95]#86-H92!I
M;G-T86YC92!W:71H('1H92!S86UE('!A<F%M971E<G,@8W5R<F5N=&QY"B`@
M("`@*B!E>&ES=',N"B`@("`@*@H@("`@("H@5&AI<R!S:&]U;&0@8F4@=7-E
M9"!I9B!M=6QT:7!L92!C86-H92!B86-K96YD<R`H86YD+"!T:'5S+`H@("`@
M("H@;75L=&EP;&4@2&]R9&5?0V%C:&4@:6YS=&%N8V5S*2!A<F4@<F5Q=6ER
M960N"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D
M(&%S.@H@("`@("H@)'9A<B`]("9(;W)D95]#86-H93HZ<VEN9VQE=&]N*"D*
M("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&1R:79E<B`@5&AE('1Y<&4@
M;V8@8V]N8W)E=&4@2&]R9&5?0V%C:&4@<W5B8VQA<W,@=&\*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!R971U<FXN($EF("1D<FEV97(@:7,@86X@
M87)R87DL('1H96X@=V4@=VEL;"!L;V]K"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@:6X@)&1R:79E<ELP72]L:6(O0V%C:&4O(&9O<B!T:&4@<W5B
M8VQA<W,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!I;7!L96UE;G1A
M=&EO;B!N86UE9"`D9')I=F5R6S%=+G!H<"X*("`@("`J($!P87)A;2!A<G)A
M>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!C
M;VYF:6=U<F%T:6]N(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M8V]N;F5C=&EO;B!P87)A;65T97)S(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*
M("`@("`J"B`@("`@*B!`<F5T=7)N($AO<F1E7T-A8VAE("!4:&4@8V]N8W)E
M=&4@2&]R9&5?0V%C:&4@<F5F97)E;F-E+"!O<B!F86QS92!O;@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N("9S:6YG;&5T;VXH)&1R:79E<BP@)'!A<F%M<R`](&%R<F%Y*"DI"B`@
M("!["B`@("`@("`@<W1A=&EC("1I;G-T86YC97,@/2!A<G)A>2@I.PH*("`@
M("`@("`D<VEG;F%T=7)E(#T@<V5R:6%L:7IE*&%R<F%Y*"1D<FEV97(L("1P
M87)A;7,I*3L*("`@("`@("!I9B`H96UP='DH)&EN<W1A;F-E<ULD<VEG;F%T
M=7)E72DI('L*("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E72`]
M("9(;W)D95]#86-H93HZ9F%C=&]R>2@D9')I=F5R+"`D<&%R86US*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D:6YS=&%N8V5S6R1S:6=N871U<F5=
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92]0<F5F<RYP:'``````````````````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`V,#<P-B`Q,#4Q-30S,S<T,"`P,C$Q-#4`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*"B\J
M*@H@*B!0<F5F97)E;F-E(&ES(&%D;6EN:7-T<F%T:79E;'D@;&]C:V5D+@H@
M*B\*9&5F:6YE*"=?4%)%1E],3T-+140G+"`Q*3L*"B\J*@H@*B!0<F5F97)E
M;F-E(&ES('-H87)E9"!A;6]N9W-T(&%P<&QI8V%T:6]N<RX*("HO"F1E9FEN
M92@G7U!2149?4TA!4D5$)RP@,BD["@HO*BH*("H@4')E9F5R96YC92!V86QU
M92!H87,@8F5E;B!C:&%N9V5D+@H@*B\*9&5F:6YE*"=?4%)%1E]$25)462<L
M(#0I.PH*+RHJ"B`J(%!R969E<F5N8V4@=F%L=64@:7,@=&AE(&%P<&QI8V%T
M:6]N(&1E9F%U;'0N"B`J+PID969I;F4H)U]04D5&7T1%1D%53%0G+"`X*3L*
M"B\J*@H@*B!4:&4@4')E9G,Z.B!C;&%S<R!P<F]V:61E<R!A(&-O;6UO;B!A
M8G-T<F%C=&5D(&EN=&5R9F%C92!I;G1O('1H90H@*B!V87)I;W5S('!R969E
M<F5N8V5S('-T;W)A9V4@;65D:75M<RX@($ET(&%L<V\@:6YC;'5D97,@86QL
M(&]F('1H90H@*B!F=6YC=&EO;G,@9F]R(')E=')I979I;F<L('-T;W)I;F<L
M(&%N9"!C:&5C:VEN9R!P<F5F97)E;F-E('9A;'5E<RX*("H*("H@5$]$3SH@
M9&]C=6UE;G0@=&AE(&9O<FUA="!O9B!T:&4@)%]P<F5F<R!H87-H(&AE<F4*
M("H*("H@)%]P<F5F<ULJ<')E9B!N86UE*ET@/2!A<G)A>2@*("H@("`@("=V
M86QU92<@(#T^("I$969A=6QT('9A;'5E*BP*("H@("`@("=L;V-K960G(#T^
M("IB;V]L96%N*BP*("H@("`@("=S:&%R960G(#T^("IB;V]L96%N*BP*("H@
M("`@("=T>7!E)R`@(#T^("=C:&5C:V)O>"<*("H@("`@("`@("`@("`@("`@
M("=T97AT)PH@*B`@("`@("`@("`@("`@("`@)W!A<W-W;W)D)PH@*B`@("`@
M("`@("`@("`@("`@)W1E>'1A<F5A)PH@*B`@("`@("`@("`@("`@("`@)W-E
M;&5C="<*("H@("`@("`@("`@("`@("`@("=N=6UB97(G"B`J("`@("`@("`@
M("`@("`@("`G:6UP;&EC:70G"B`J("`@("`@("`@("`@("`@("`G<W!E8VEA
M;"<*("H@("`@("`@("`@("`@("`@("=L:6YK)R`M(%1H97)E(&UU<W0@8F4@
M82!F:65L9"!N86UE9"!E:71H97(@)W5R;"<*("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("AI;G1E<FYA;"!A<'!L:6-A=&EO;B!L:6YK*2!O<B`G>'5R
M;"<*("H@("`@("`@("`@("`@("`@("`@("`@("`@("AE>'1E<FYA;"!A<'!L
M:6-A=&EO;B!L:6YK*2!I9B!T:&ES('1Y<&4@:7,@=7-E9"X*("H@("`@("`@
M("`@("`@("`@("=E;G5M)PH@*B`@("`@)V5N=6TG("`@/3X@5$]$3RP*("H@
M("`@("=D97-C)R`@(#T^(%\H*D1E<V-R:7!T:6]N('-T<FEN9RHI+`H@*B`@
M("`@)VAE;'`G("`@/3X@*DYA;64@;V8@=&AE(&5N=')Y(&EN('1H92!834P@
M:&5L<"!F:6QE*@H@*B`I.PH@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<RYP:'`L=B`Q+C$S-RXQ,"XR-R`R,#`V+S`W+S`S(#$W.C,X.C$Q
M(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@2F]N(%!A
M<FES92`\:F]N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO
M<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]0<F5F<PH@*B\*8VQA<W,@4')E
M9G,@>PH*("`@("\J*@H@("`@("H@2&%S:"!H;VQD:6YG(&%L;"!O9B!T:&4@
M=7-E<B=S('!R969E<F5N8V5S+B!%86-H('!R969E<F5N8V4@:7,*("`@("`J
M(&ET<V5L9B!A(&AA<V@L('-O('1H:7,@=VEL;"!U;'1I;6%T96QY(&)E(&UU
M;'1I+61I;65N<VEO;F%L+@H@("`@("H*("`@("`J(%LJ<')E9B!N86UE*ET@
M/3X@07)R87DH"B`@("`@*B`@("`@6V1=("`]/B`@*F1E9F%U;'0@=F%L=64J
M"B`@("`@*B`@("`@6VU=("`]/B`@*G!R968@;6%S:RH*("`@("`J("`@("!;
M=ET@(#T^("`J<')E9B!V86QU92H*("`@("`J("D*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D7W!R969S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J
M(%-T<FEN9R!C;VYT86EN:6YG('1H92!N86UE(&]F('1H:7,@<V-O<&4N(%1H
M:7,@:7,@=7-E9"!T;PH@("`@("H@;6%I;G1A:6X@=&AE(&%P<&QI8V%T:6]N
M('-C;W!E(&)E='=E96X@<V5T<R!O9B!P<F5F97)E;F-E<RX@0GD*("`@("`J
M(&1E9F%U;'0L(&%L;"!P<F5F97)E;F-E<R!B96QO;F<@=&\@=&AE(")G;&]B
M86PB("A(;W)D92D@<V-O<&4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J+PH@("`@=F%R("1?<V-O<&4@/2`G:&]R9&4G.PH*("`@("\J*@H@
M("`@("H@4W1R:6YG(&-O;G1A:6YI;F<@=&AE(&-U<G)E;G0@=7-E<FYA;64N
M(%1H:7,@:6YD:6-A=&5S('1H92!O=VYE<B!O9B!T:&4*("`@("`J('!R969E
M<F5N8V5S+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@
M('9A<B`D7W5S97(@/2`G)SL*"B`@("`O*BH*("`@("`J($)O;VQE86X@:6YD
M:6-A=&EN9R!W:&5T:&5R('!R969E<F5N8V4@8V%C:&EN9R!S:&]U;&0@8F4@
M=7-E9"X*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@
M=F%R("1?8V%C:&EN9R`](&9A;'-E.PH*("`@("\J*@H@("`@("H@2&%S:"!H
M;VQD:6YG('!R969E<F5N8V5S('=I=&@@:&]O:R!F=6YC=&EO;G,@9&5F:6YE
M9"X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D
M7VAO;VMS(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($AA=F4@=V4@<G5N
M(&AO;VL@9G5N8W1I;VYS('EE=#\*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE
M86X*("`@("`J+PH@("`@=F%R("1?:&]O:W-#86QL960@/2!N=6QL.PH*("`@
M("\J*@H@("`@("H@1&5F875L="!C;VYS=')U8W1O<B`H;75S="!B92!C86QL
M960@9G)O;2!E86-H(&5X=&5N9&EN9R!C;&%S<R!I;B!T:&5I<@H@("`@("H@
M8V]N<W1R=6-T;W)S('9I82!P87)E;G0Z.E!R969S*"DI+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!0<F5F<R@I"B`@("!["B`@("`@("`@)'1H:7,M/E]S:'5T
M9&]W;B@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8VAA
M<G-E="!U<V5D(&)Y('1H92!C;VYC<F5T92!P<F5F97)E;F-E(&)A8VME;F0N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!P<F5F97)E;F-E
M(&)A8VME;F0G<R!C:&%R<V5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971#
M:&%R<V5T*"D*("`@('L*("`@("`@("!R971U<FX@3DQ3.CIG971#:&%R<V5T
M*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!5<&1A=&5S('1H92!S97-S:6]N
M+6)A<V5D('!R969E<F5N8V5S(&-A8VAE("AI9B!A=F%I;&%B;&4I+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'!R968@(%1H92!P<F5F97)E;F-E
M('1O('5P9&%T92X@($EF(&5M<'1Y+"!W:6QL('5P9&%T90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@=&AE(&5N=&ER92!C86-H92!W:71H('1H92!C
M=7)R96YT('-E="!O9B!P<F5F<RX*("`@("`J+PH@("`@9G5N8W1I;VX@8V%C
M:&55<&1A=&4H)'!R968@/2!N=6QL*0H@("`@>PH@("`@("`@("\J(%)E='5R
M;B!I;6UE9&EA=&5L>2!I9B!C86-H:6YG(&ES(&1I<V%B;&5D+B`J+PH@("`@
M("`@(&EF("@A)'1H:7,M/E]C86-H:6YG*2!["B`@("`@("`@("`@(')E='5R
M;CL*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D7U-%4U-)3TY;)W!R
M969S7V-A8VAE)UTI*2!["B`@("`@("`@("`@(&EF("AI<U]N=6QL*"1P<F5F
M*2D@>PH@("`@("`@("`@("`@("`@)'!R969S(#T@)'1H:7,M/E]P<F5F<SL*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1P<F5F<R`]
M(&%R<F%Y*"1P<F5F(#T^("1T:&ES+3Y?<')E9G-;)'!R969=*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@+RH@4&QA8V4@96%C:"!P<F5F97)E;F-E
M(&EN('1H92!C86-H92!A8V-O<F1I;F<@=&\@:71S"B`@("`@("`@("`@("`J
M('-C;W!E+B`J+PH@("`@("`@("`@("!F;W)E86-H("@D<')E9G,@87,@)&YA
M;64@/3X@)'!R968I('L*("`@("`@("`@("`@("`@("1?4T534TE/3ELG<')E
M9G-?8V%C:&4G75LD=&AI<RT^9V5T4V-O<&4H)&YA;64I75LD;F%M95T@/2`D
M<')E9CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%1R:65S('1O(&9I;F0@=&AE(')E<75E<W1E9"!P<F5F97)E;F-E
M<R!I;B!T:&4@8V%C:&4N($EF('1H97D@97AI<W0L"B`@("`@*B!U<&1A=&4@
M=&AE("1P<F5F<R!H87-H('=I=&@@=&AE(&-A8VAE9"!V86QU97,N"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A
M;'-E(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-A8VAE3&]O
M:W5P*"D*("`@('L*("`@("`@("`O*B!2971U<FX@:6UM961I871E;'D@:68@
M8V%C:&EN9R!I<R!D:7-A8FQE9"X@*B\*("`@("`@("!I9B`H(21T:&ES+3Y?
M8V%C:&EN9RD@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("!I9B`H:7-S970H)%]315-324].6R=P<F5F<U]C86-H92==
M6R=H;W)D92==*2`F)@H@("`@("`@("`@("!I<W-E="@D7U-%4U-)3TY;)W!R
M969S7V-A8VAE)UU;)'1H:7,M/E]S8V]P95TI*2!["@H@("`@("`@("`@("`O
M*B!297-T;W)E(&=L;V)A;"!P<F5F97)E;F-E<RX@*B\*("`@("`@("`@("`@
M)'1H:7,M/E]P<F5F<R`](&%R<F%Y7VUE<F=E*"1T:&ES+3Y?<')E9G,L("1?
M4T534TE/3ELG<')E9G-?8V%C:&4G75LG:&]R9&4G72P@)%]315-324].6R=P
M<F5F<U]C86-H92==6R1T:&ES+3Y?<V-O<&5=*3L*"B`@("`@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@061D<R!A(&YE=R!P<F5F97)E;F-E(&5N
M=')Y('1O('1H92`D<')E9G,@:&%S:"X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1P<F5F("`@5&AE(&YA;64@;V8@=&AE('!R969E<F5N8V4@=&\@
M861D+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=F%L("`@(%1H92!I;FET:6%L
M('9A;'5E(&]F('1H92!P<F5F97)E;F-E+@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)&UA<VL@(%1H92!I;FET:6%L(&)I=&UA<VL@;V8@=&AE('!R969E<F5N
M8V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9"@D<')E9BP@)'9A;"`]("<G
M+"`D;6%S:R`](#`I"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES
M+3Y?<')E9G,I*2!["B`@("`@("`@("`@("1T:&ES+3Y?<')E9G-;)'!R969=
M(#T@87)R87DH)W8G(#T^("1V86PL("=M)R`]/B`D;6%S:RP@)V0G(#T^("1V
M86PI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V97,@
M82!P<F5F97)E;F-E(&5N=')Y(&9R;VT@=&AE("1P<F5F<R!H87-H+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'!R968@(%1H92!N86UE(&]F('1H
M92!P<F5F97)E;F-E('1O(')E;6]V92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<F5M;W9E*"1P<F5F*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D=&AI
M<RT^7W!R969S*2D@>PH@("`@("`@("`@("`D<V-O<&4@/2`D=&AI<RT^9V5T
M4V-O<&4H)'!R968I.PH@("`@("`@("`@("!U;G-E="@D=&AI<RT^7W!R969S
M6R1P<F5F72D["B`@("`@("`@("`@('5N<V5T*"1?4T534TE/3ELG<')E9G-?
M8V%C:&4G75LD<V-O<&5=6R1P<F5F72D["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@4V5T<R!T:&4@9VEV96X@<')E9F5R96YC97,@*"1P<F5F
M*2!T;R!T:&4@<W!E8VEF:65D('9A;'5E"B`@("`@*B`H)'9A;"DL(&EF('1H
M92!P<F5F97)E;F-E(&ES(&UO9&EF:6%B;&4N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<')E9B`@("`@(%1H92!N86UE(&]F('1H92!P<F5F97)E
M;F-E('1O(&UO9&EF>2X*("`@("`J($!P87)A;2!S=')I;F<@)'9A;"`@("`@
M("!4:&4@;F5W('9A;'5E(&9O<B!T:&ES('!R969E<F5N8V4N"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D8V]N=F5R="`@268@=')U92!T:&4@<')E9F5R96YC
M92!V86QU92!G971S(&-O;G9E<G1E9`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@(&9R;VT@=&AE(&-U<G)E;G0@8VAA<G-E="!T;R!T:&4@8F%C
M:V5N9"=S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@8VAA<G-E
M="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE
M('9A;'5E('=A<R!S=6-C97-S9G5L;'D@<V5T+"!F86QS92!O;B!A"B`@("`@
M*B`@("`@("`@("`@("`@("`@(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('-E=%9A;'5E*"1P<F5F+"`D=F%L+"`D8V]N=F5R="`]('1R=64I"B`@
M("!["B`@("`@("`@+RH@17AI="!E87)L>2!I9B!T:&ES('!R969E<F5N8V4@
M:7,@;&]C:V5D(&]R(&1O97-N)W0@97AI<W0N("HO"B`@("`@("`@:68@*"%I
M<W-E="@D=&AI<RT^7W!R969S6R1P<F5F72D@?'P@)'1H:7,M/FES3&]C:V5D
M*"1P<F5F*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]S971686QU92@D<')E9BP@)'9A
M;"P@=')U92P@)&-O;G9E<G0I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]?<V5T
M*"1N86UE+"`D=F%L=64I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YS
M971686QU92@D;F%M92P@)'9A;'5E*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%-E=',@=&AE(&=I=F5N('!R969E<F5N8V5S("@D<')E9BD@=&\@=&AE('-P
M96-I9FEE9"!V86QU90H@("`@("H@*"1V86PI+"!W:&5T:&5R(&]R(&YO="!T
M:&4@<')E9F5R96YC92!I<R!U<V5R+6UO9&EF:6%B;&4L('5N<V5T"B`@("`@
M*B!T:&4@9&5F875L="!B:70L(&%N9"!S970@=&AE(&1I<G1Y(&)I="X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@("1P<F5F("`@("!4:&4@;F%M92!O9B!T:&4@<')E9F5R
M96YC92!T;R!M;V1I9GDN"B`@("`@*B!`<&%R86T@<W1R:6YG("`D=F%L("`@
M("`@5&AE(&YE=R!V86QU92!F;W(@=&AI<R!P<F5F97)E;F-E+@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)&1I<G1Y("`@(%1R=64@:68@=V4@<VAO=6QD(&UA
M<FL@=&AE(&YE=R!V86QU92!A<PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@(&1I<G1Y("AC:&%N9V5D*2X*("`@("`J($!P87)A;2!B;V]L96%N
M("1C;VYV97)T("!)9B!T<G5E('1H92!P<F5F97)E;F-E('9A;'5E(&=E=',@
M8V]N=F5R=&5D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@9G)O
M;2!T:&4@8W5R<F5N="!C:&%R<V5T('1O('1H92!B86-K96YD)W,*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("!C:&%R<V5T+@H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&4@=F%L=64@=V%S('-U
M8V-E<W-F=6QL>2!S970L(&9A;'-E(&]N(&$*("`@("`J("`@("`@("`@("`@
M("`@("`@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E=%9A;'5E
M*"1P<F5F+"`D=F%L+"`D9&ER='D@/2!T<G5E+"`D8V]N=F5R="`]('1R=64I
M"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("!I9B`H)&-O
M;G9E<G0I('L*("`@("`@("`@("`@)'9A;"`]("1T:&ES+3YC;VYV97)T5&]$
M<FEV97(H)'9A;"P@3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@("`@('T*"B`@
M("`@("`@+RH@268@=&AE('!R969E<F5N8V4G<R!V86QU92!I<R!A;')E861Y
M(&5Q=6%L('1O("1V86PL(&1O;B=T"B`@("`@("`@("H@8F]T:&5R(&-H86YG
M:6YG(&ET+B!#:&%N9VEN9R!I="!W;W5L9"!S970@=&AE(")D:7)T>2(@8FET
M+`H@("`@("`@("`J(&-A=7-I;F<@86X@=6YN96-E<W-A<GD@=7!D871E(&QA
M=&5R(&]N(&EN('1H92!S=&]R86=E"B`@("`@("`@("H@<F]U=&EN92X@*B\*
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P<F5F<ULD<')E9ETI("8F"B`@
M("`@("`@("`@("@H)'1H:7,M/E]P<F5F<ULD<')E9EU;)W8G72`]/2`D=F%L
M*2`F)@H@("`@("`@("`@("`@(21T:&ES+3YI<T1E9F%U;'0H)'!R968I*2D@
M>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@
M("\J($-H96-K('1O('-E92!I9B!T:&4@=F%L=64@97AC965D<R!T:&4@86QL
M;W=A8FQE('-T;W)A9V4*("`@("`@("`@*B!L:6UI="X@*B\*("`@("`@("!I
M9B`H:7-S970H)&-O;F9;)W!R969S)UU;)VUA>'-I>F4G72DI('L*("`@("`@
M("`@("`@:68@*'-T<FQE;B@D=F%L*2`^("1C;VYF6R=P<F5F<R==6R=M87AS
M:7IE)UTI('L*("`@("`@("`@("`@("`@(&=L;V)A;"`D;F]T:69I8V%T:6]N
M.PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1N;W1I9FEC871I;VXI*2![
M"B`@("`@("`@("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I
M;G1F*%\H(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V
M960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO
M=V%B;&4@<VEZ92(I+"`D<')E9BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@07-S:6=N('1H
M92!N97<@=F%L=64L('5N<V5T('1H92`B9&5F875L="(@8FET+"!A;F0@<V5T
M('1H90H@("`@("`@("`@(")D:7)T>2(@8FET+B`J+PH@("`@("`@(&EF("AE
M;7!T>2@D=&AI<RT^7W!R969S6R1P<F5F75LG;2==*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7W!R969S6R1P<F5F75LG;2==(#T@,#L*("`@("`@("!]"B`@
M("`@("`@)'1H:7,M/E]P<F5F<ULD<')E9EU;)W8G72`]("1V86P["B`@("`@
M("`@)'1H:7,M/G-E=$1E9F%U;'0H)'!R968L(&9A;'-E*3L*("`@("`@("!I
M9B`H)&1I<G1Y*2!["B`@("`@("`@("`@("1T:&ES+3YS971$:7)T>2@D<')E
M9BP@=')U92D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^8V%C:&55<&1A
M=&4H)'!R968I.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE('9A;'5E(&]F('1H92!R97%U97-T960@
M<')E9F5R96YC92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P<F5F
M("`@("`@5&AE(&YA;64@;V8@=&AE('!R969E<F5N8V4@=&\@<F5T<FEE=F4N
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D8V]N=F5R="`@268@=')U92!T:&4@
M<')E9F5R96YC92!V86QU92!G971S(&-O;G9E<G1E9`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@(&9R;VT@=&AE(&)A8VME;F0G<R!C:&%R<V5T
M('1O('1H92!C=7)R96YT"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@8VAA<G-E="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M('9A;'5E(&]F('1H92!P<F5F97)E;F-E+"!N=6QL(&EF(&ET(&1O97-N)W0@
M97AI<W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%9A;'5E*"1P<F5F+"`D
M8V]N=F5R="`]('1R=64I"B`@("!["B`@("`@("`@<W1A=&EC("1C:&%R<V5T
M.PH@("`@("`@(&EF("@A:7-S970H)&-H87)S970I*2!["B`@("`@("`@("`@
M("1C:&%R<V5T(#T@3DQ3.CIG971#:&%R<V5T*"D["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@*&ES<V5T*"1T:&ES+3Y?<')E9G-;)'!R969=6R=V)UTI
M*2`_"B`@("`@("`@("`@("@D8V]N=F5R="`_"B`@("`@("`@("`@("`D=&AI
M<RT^8V]N=F5R=$9R;VU$<FEV97(H)'1H:7,M/E]P<F5F<ULD<')E9EU;)W8G
M72P@)&-H87)S970I(#H*("`@("`@("`@("`@("1T:&ES+3Y?<')E9G-;)'!R
M969=6R=V)UTI(#H*("`@("`@("`@("`@;G5L;#L*("`@('T*"B`@("!F=6YC
M=&EO;B!?7V=E="@D;F%M92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/F=E=%9A;'5E*"1N86UE*3L*("`@('T*"B`@("`O*BH*("`@("`J($UO9&EF
M:65S('1H92`B;&]C:V5D(B!B:70@9F]R('1H92!G:79E;B!P<F5F97)E;F-E
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!R968@("!4:&4@;F%M
M92!O9B!T:&4@<')E9F5R96YC92!T;R!M;V1I9GDN"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`D8F]O;"`@5&AE(&YE=R!B;V]L96%N('9A;'5E(&9O<B!T:&4@
M(FQO8VME9"(@8FET+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971,;V-K960H
M)'!R968L("1B;V]L*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<V5T36%S:R@D
M<')E9BP@)&)O;VPL(%]04D5&7TQ/0TM%1"D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!S=&%T92!O9B!T:&4@(FQO8VME9"(@8FET(&9O
M<B!T:&4@9VEV96X@<')E9F5R96YC92X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1P<F5F("!4:&4@;F%M92!O9B!T:&4@<')E9F5R96YC92!T;R!C
M:&5C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1H92!B;V]L
M96%N('-T871E(&]F("1P<F5F)W,@(FQO8VME9"(@8FET+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!I<TQO8VME9"@D<')E9BD*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]G971-87-K*"1P<F5F+"!?4%)%1E],3T-+140I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@36]D:69I97,@=&AE(")S:&%R960B(&)I="!F
M;W(@=&AE(&=I=F5N('!R969E<F5N8V4N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<')E9B`@(%1H92!N86UE(&]F('1H92!P<F5F97)E;F-E('1O
M(&UO9&EF>2X*("`@("`J($!P87)A;2!B;V]L96%N("1B;V]L("!4:&4@;F5W
M(&)O;VQE86X@=F%L=64@9F]R('1H92`B<VAA<F5D(B!B:70N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-E=%-H87)E9"@D<')E9BP@)&)O;VPI"B`@("!["B`@
M("`@("`@)'1H:7,M/E]S971-87-K*"1P<F5F+"`D8F]O;"P@7U!2149?4TA!
M4D5$*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('-T871E
M(&]F('1H92`B<VAA<F5D(B!B:70@9F]R('1H92!G:79E;B!P<F5F97)E;F-E
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!R968@(%1H92!N86UE
M(&]F('1H92!P<F5F97)E;F-E('1O(&-H96-K+@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;&5A;B`@5&AE(&)O;VQE86X@<W1A=&4@;V8@)'!R968G<R`B
M<VAA<F5D(B!B:70N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES4VAA<F5D*"1P
M<F5F*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V=E=$UA<VLH)'!R
M968L(%]04D5&7U-(05)%1"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!-;V1I
M9FEE<R!T:&4@(F1I<G1Y(B!B:70@9F]R('1H92!G:79E;B!P<F5F97)E;F-E
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!R968@("`@("!4:&4@
M;F%M92!O9B!T:&4@<')E9F5R96YC92!T;R!M;V1I9GDN"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D8F]O;"`@("`@5&AE(&YE=R!B;V]L96%N('9A;'5E(&9O
M<B!T:&4@(F1I<G1Y(B!B:70N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$1I
M<G1Y*"1P<F5F+"`D8F]O;"D*("`@('L*("`@("`@("`D=&AI<RT^7W-E=$UA
M<VLH)'!R968L("1B;V]L+"!?4%)%1E]$25)462D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92!S=&%T92!O9B!T:&4@(F1I<G1Y(B!B:70@
M9F]R('1H92!G:79E;B!P<F5F97)E;F-E+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'!R968@(%1H92!N86UE(&]F('1H92!P<F5F97)E;F-E('1O
M(&-H96-K+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5&AE(&)O
M;VQE86X@<W1A=&4@;V8@)'!R968G<R`B9&ER='DB(&)I="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@:7-$:7)T>2@D<')E9BD*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]G971-87-K*"1P<F5F+"!?4%)%1E]$25)462D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!-;V1I9FEE<R!T:&4@(F1E9F%U;'0B(&)I="!F
M;W(@=&AE(&=I=F5N('!R969E<F5N8V4N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<')E9B`@(%1H92!N86UE(&]F('1H92!P<F5F97)E;F-E('1O
M(&UO9&EF>2X*("`@("`J($!P87)A;2!B;V]L96%N("1B;V]L("!4:&4@;F5W
M(&)O;VQE86X@=F%L=64@9F]R('1H92`B9&5F875L="(@8FET+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!S971$969A=6QT*"1P<F5F+"`D8F]O;"D*("`@('L*
M("`@("`@("`D=&AI<RT^7W-E=$UA<VLH)'!R968L("1B;V]L+"!?4%)%1E]$
M149!54Q4*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&1E
M9F%U;'0@=F%L=64@;V8@=&AE(&=I=F5N('!R969E<F5N8V4N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<')E9B`@5&AE(&YA;64@;V8@=&AE('!R
M969E<F5N8V4@=&\@9V5T('1H92!D969A=6QT(&9O<BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@("`@("!4:&4@<')E9F5R96YC92=S(&1E9F%U
M;'0@=F%L=64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1E9F%U;'0H)'!R
M968I"B`@("!["B`@("`@("`@<F5T=7)N("%E;7!T>2@D=&AI<RT^7W!R969S
M6R1P<F5F75LG9"==*2`_"B`@("`@("`@("`@("1T:&ES+3Y?<')E9G-;)'!R
M969=6R=D)UT@.@H@("`@("`@("`@("`G)SL*("`@('T*"B`@("`O*BH*("`@
M("`J($1E=&5R;6EN97,@:68@=&AE(&-U<G)E;G0@<')E9F5R96YC92!V86QU
M92!I<R!T:&4@9&5F875L=`H@("`@("H@=F%L=64@9G)O;2!P<F5F<RYP:'`@
M;W(@82!U<V5R(&1E9FEN960@=F%L=64*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1P<F5F("!4:&4@;F%M92!O9B!T:&4@<')E9F5R96YC92!T;R!C
M:&5C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@
M=&AE('!R969E<F5N8V4@:7,@=&AE(&%P<&QI8V%T:6]N(&1E9F%U;'0*("`@
M("`J("`@("`@("`@("`@("`@("`@=F%L=64N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&ES1&5F875L="@D<')E9BD*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]G971-87-K*"1P<F5F+"!?4%)%1E]$149!54Q4*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E=',@=&AE('9A;'5E(&9O<B!A(&=I=F5N(&UA<VLN
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<')E9B`@(%1H92!N86UE(&]F('1H92!P<F5F97)E
M;F-E('1O(&UO9&EF>2X*("`@("`J($!P87)A;2!B;V]L96%N("1B;V]L("!4
M:&4@;F5W(&)O;VQE86X@=F%L=64@9F]R('1H92`B9&5F875L="(@8FET+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&UA<VL@(%1H92!M87-K('1O(&%D9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7W-E=$UA<VLH)'!R968L("1B;V]L+"`D
M;6%S:RD*("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P<F5F<ULD
M<')E9ETI*2!["B`@("`@("`@("`@(&EF("@D8F]O;"`A/2`D=&AI<RT^7V=E
M=$UA<VLH)'!R968L("1M87-K*2D@>PH@("`@("`@("`@("`@("`@:68@*"1B
M;V]L*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P<F5F<ULD<')E
M9EU;)VTG72!\/2`D;6%S:SL*("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P<F5F<ULD<')E9EU;)VTG72`F
M/2!^)&UA<VL["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!B;V]L96%N
M('-T871E(&9O<B!A(&=I=F5N(&UA<VLN"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')E9B`@
M(%1H92!N86UE(&]F('1H92!P<F5F97)E;F-E('1O(&UO9&EF>2X*("`@("`J
M($!P87)A;2!I;G1E9V5R("1M87-K("!4:&4@;6%S:R!T;R!G970N"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4:&4@8F]O;&5A;B!S=&%T92!F
M;W(@=&AE(&=I=F5N(&UA<VLN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971-
M87-K*"1P<F5F+"`D;6%S:RD*("`@('L*("`@("`@("!R971U<FX@:7-S970H
M)'1H:7,M/E]P<F5F<ULD<')E9EU;)VTG72D@/R`H)'1H:7,M/E]P<F5F<ULD
M<')E9EU;)VTG72`F("1M87-K*2`Z(&9A;'-E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1&5T97)M:6YE<R!W:&5T:&5R('1H92!C=7)R96YT('!R969E<F5N
M8V4@:7,@96UP='DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')E
M9B`@5&AE(&YA;64@;V8@=&AE('!R969E<F5N8V4@=&\@8VAE8VLN"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!P<F5F97)E
M;F-E(&ES(&5M<'1Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<T5M<'1Y*"1P
M<F5F*0H@("`@>PH@("`@("`@(')E='5R;B!E;7!T>2@D=&AI<RT^7W!R969S
M6R1P<F5F75LG=B==*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE('-C;W!E(&]F('1H92!G:79E;B!P<F5F97)E;F-E+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'!R968@(%1H92!N86UE(&]F('1H92!P<F5F
M97)E;F-E('1O(&5X86UI;F4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!S8V]P92!O9B!T:&4@)'!R968N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=%-C;W!E*"1P<F5F*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^
M:7-3:&%R960H)'!R968I*2!["B`@("`@("`@("`@(')E='5R;B`G:&]R9&4G
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7W-C;W!E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;B!A(&QI<W0@;V8@(F1I<G1Y(B!P<F5F97)E;F-E<RX*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!4:&4@;&ES="!O9B`B9&ER='DB('!R969E<F5N8V5S(&EN("1T:&ES+3Y?
M<')E9G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]D:7)T>5!R969S*"D*("`@
M('L*("`@("`@("`D9&ER='E?<')E9G,@/2!A<G)A>2@I.PH*("`@("`@("!F
M;W)E86-H("AA<G)A>5]K97ES*"1T:&ES+3Y?<')E9G,I(&%S("1P<F5F*2![
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^:7-$:7)T>2@D<')E9BDI('L*("`@
M("`@("`@("`@("`@("1D:7)T>5]P<F5F<UM=(#T@)'!R968["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D9&ER='E?<')E9G,[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V97,@=&AE(&1E9F%U;'0@
M<')E9F5R96YC97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E=')I979E*"D*
M("`@('L*("`@("`@("`O*B!,;V%D(&1E9F%U;'1S('1O(&UA:V4@<W5R92!W
M92!H879E(&%L;"!P<F5F97)E;F-E<RX@*B\*("`@("`@("`D=&AI<RT^7W-E
M=$1E9F%U;'1S*"=H;W)D92<I.PH@("`@("`@("1T:&ES+3Y?<V5T1&5F875L
M=',H)'1H:7,M/E]S8V]P92D["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@5&AI<R!F=6YC=&EO;B!W:6QL(&)E(')U;B!A
M="!T:&4@96YD(&]F(&5V97)Y(')E<75E<W0@87,@82!S:'5T9&]W;@H@("`@
M("H@9G5N8W1I;VX@*')E9VES=&5R960@8GD@=&AE(%!R969S.CH@8V]N<W1R
M=6-T;W(I+B`@06QL('!R969S('=I=&@@=&AE"B`@("`@*B!D:7)T>2!B:70@
M<V5T('=I;&P@8F4@<V%V960@=&\@=&AE('-T;W)A9V4@8F%C:V5N9"!A="!T
M:&ES('1I;64[('1H=7,L"B`@("`@*B!T:&5R92!I<R!N;R!N965D('1O(&UA
M;G5A;&QY(&-A;&P@)'!R969S+3YS=&]R92@I(&5V97)Y('1I;64@80H@("`@
M("H@<')E9F5R96YC92!I<R!C:&%N9V5D+@H@("`@("H*("`@("`J($!A8G-T
M<F%C=`H@("`@("HO"B`@("!F=6YC=&EO;B!S=&]R92@I"B`@("!["B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES(&9U
M;F-T:6]N('!R;W9I9&5S(&-O;6UO;B!C;&5A;G5P(&9U;F-T:6]N<R!F;W(@
M86QL(&]F('1H92!D<FEV97(*("`@("`J(&EM<&QE;65N=&%T:6]N<RX*("`@
M("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D86QL("!#;&5A;B!U<"!A;&P@
M2&]R9&4@<')E9F5R96YC97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L96%N
M=7`H)&%L;"`](&9A;'-E*0H@("`@>PH@("`@("`@("\J(%)E;6]V92!T:&ES
M('-C;W!E(&9R;VT@=&AE('!R969E<F5N8V5S(&-A8VAE+"!I9B!I=`H@("`@
M("`@("`@(&5X:7-T<RX@*B\*("`@("`@("!I9B`H:7-S970H)%]315-324].
M6R=P<F5F<U]C86-H92==6R1T:&ES+3Y?<V-O<&5=*2D@>PH@("`@("`@("`@
M("!U;G-E="@D7U-%4U-)3TY;)W!R969S7V-A8VAE)UU;)'1H:7,M/E]S8V]P
M95TI.PH@("`@("`@('T*"B`@("`@("`@+RH@4&5R9F]R;2!A($AO<F1E+7=I
M9&4@8VQE86YU<#\@*B\*("`@("`@("!I9B`H)&%L;"D@>PH@("`@("`@("`@
M("`O*B!$97-T<F]Y('1H92!C;VYT96YT<R!O9B!T:&4@<')E9F5R96YC97,@
M:&%S:"X@*B\*("`@("`@("`@("`@)'1H:7,M/E]P<F5F<R`](&%R<F%Y*"D[
M"@H@("`@("`@("`@("`O*B!$97-T<F]Y('1H92!C;VYT96YT<R!O9B!T:&4@
M<')E9F5R96YC97,@8V%C:&4N("HO"B`@("`@("`@("`@(&EF("AI<W-E="@D
M7U-%4U-)3TY;)W!R969S7V-A8VAE)UTI*2!["B`@("`@("`@("`@("`@("!U
M;G-E="@D7U-%4U-)3TY;)W!R969S7V-A8VAE)UTI.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0VQE87)S(&%L;"!P
M<F5F97)E;F-E<R!F<F]M('1H92!B86-K96YD+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!C;&5A<B@I"B`@("!["B`@("`@("`@)'1H:7,M/F-L96%N=7`H=')U
M92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T<R!A('9A;'5E(&9R
M;VT@=&AE(&1R:79E<B=S(&-H87)S970@=&\@=&AE('-P96-I9FEE9"!C:&%R
M<V5T+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D=F%L=64@("`@($$@
M=F%L=64@=&\@8V]N=F5R="X*("`@("`J($!P87)A;2!S=')I;F<@)&-H87)S
M970@(%1H92!C:&%R<V5T('1O(&-O;G9E<G0@=&\N"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@5&AE(&-O;G9E<G1E9"!V86QU92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@8V]N=F5R=$9R;VU$<FEV97(H)'9A;'5E+"`D8VAA<G-E
M="D*("`@('L*("`@("`@("!R971U<FX@)'9A;'5E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0V]N=F5R=',@82!V86QU92!F<F]M('1H92!S<&5C:69I960@
M8VAA<G-E="!T;R!T:&4@9')I=F5R)W,@8VAA<G-E="X*("`@("`J"B`@("`@
M*B!`<&%R86T@;6EX960@)'9A;'5E("!!('9A;'5E('1O(&-O;G9E<G0N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1C:&%R<V5T("!4:&4@8VAA<G-E="!T;R!C
M;VYV97)T(&9R;VTN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE
M(&-O;G9E<G1E9"!V86QU92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]N=F5R
M=%1O1')I=F5R*"1V86QU92P@)&-H87)S970I"B`@("!["B`@("`@("`@<F5T
M=7)N("1V86QU93L*("`@('T*"B`@("`O*BH*("`@("`J(%!O<'5L871E<R!T
M:&4@)'!R969S(&AA<V@@=VET:"!N97<@96YT<FEE<R!A;F0@97AT97)N86QL
M>2!D969I;F5D"B`@("`@*B!D969A=6QT('9A;'5E<RX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1A<'`@(%1H92!A<'!L:6-A=&EO;B!T;R!L;V%D
M(&1E9F%U;'1S(&9O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E=$1E9F%U
M;'1S*"1A<'`I"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*("`@
M("`@("`D9FEL96YA;64@/2`D<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G+"`D
M87!P*2`N("<O8V]N9FEG+W!R969S+G!H<"<["@H@("`@("`@("\J($5N<W5R
M92!T:&%T('1H92!D969A=6QT<R!F<F]M('1H:7,@9FEL92!A<F4@;VYL>2!R
M96%D(&]N8V4N"B`@("`@("`@("`@06QS;RP@;6%K92!S=7)E('=E(&-A;B!R
M96%D('1H:7,@9FEL92X@*B\*("`@("`@("!I9B`H(4!I<U]R96%D86)L92@D
M9FEL96YA;64I*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@
M("`@("`@("\J(%)E860@=&AE(&-O;F9I9W5R871I;VX@9FEL92X@5&AE("1?
M<')E9G,@87)R87DL('=H:6-H('=I;&P@8F4*("`@("`@("`@("!I;B!L;V-A
M;"!S8V]P92P@:7,@87-S=6UE9"!T;R!H;VQD('1H92!D969A=6QT('9A;'5E
M<RX@*B\*("`@("`@("!I;F-L=61E("1F:6QE;F%M93L*("`@("`@("!F;W)E
M86-H("@D7W!R969S(&%S("1P<F5F(#T^("1P=F%L<RD@>PH@("`@("`@("`@
M("!I9B`H:7-S970H)'!V86QS6R=V86QU92==*2`F)@H@("`@("`@("`@("`@
M("`@:7-S970H)'!V86QS6R=L;V-K960G72D@)B8*("`@("`@("`@("`@("`@
M(&ES<V5T*"1P=F%L<ULG<VAA<F5D)UTI("8F"B`@("`@("`@("`@("`@("`H
M)'!V86QS6R=T>7!E)UT@(3T@)VQI;FLG*2`F)@H@("`@("`@("`@("`@("`@
M*"1P=F%L<ULG='EP92==("$]("=S<&5C:6%L)RDI('L*("`@("`@("`@("`@
M("`@("1P<F5F(#T@<W1R7W)E<&QA8V4H)RXG+"`G7R<L("1P<F5F*3L*("`@
M("`@("`@("`@("`@("1M87-K(#T@,#L*("`@("`@("`@("`@("`@(&EF("@D
M<'9A;'-;)VQO8VME9"==*2!["B`@("`@("`@("`@("`@("`@("`@)&UA<VL@
M?#T@7U!2149?3$]#2T5$.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@:68@*"1P=F%L<ULG<VAA<F5D)UT@?'P@)&%P<"`]/2`G:&]R9&4G
M*2!["B`@("`@("`@("`@("`@("`@("`@)&UA<VL@?#T@7U!2149?4TA!4D5$
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&UA<VL@)CT@
M?E]04D5&7T1)4E19.PH@("`@("`@("`@("`@("`@)&UA<VL@?#T@7U!2149?
M1$5&055,5#L*"B`@("`@("`@("`@("`@("`D=&AI<RT^861D*"1P<F5F+"`D
M<'9A;'-;)W9A;'5E)UTL("1M87-K*3L*("`@("`@("`@("`@("`@(&EF("@A
M96UP='DH)'!V86QS6R=H;V]K)UTI*2!["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]S971(;V]K*"1P<F5F*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@57!D871E('1H92!P
M<F5F97)E;F-E<R!C86-H92!W:71H('1H92!D969A=6QT<RX@*B\*("`@("`@
M("`D=&AI<RT^8V%C:&55<&1A=&4H*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%!E<F9O<FUS('-H=71D;W=N(&%C=&EV:71I97,N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S:'5T9&]W
M;B@I"B`@("!["B`@("`@("`@<F5G:7-T97)?<VAU=&1O=VY?9G5N8W1I;VXH
M87)R87DH)B1T:&ES+"`G<W1O<F4G*2D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!9&0@)'!R968@=&\@=&AE(&QI<W0@;V8@<')E9F5R96YC97,@=VET:"!H
M;V]K(&9U;F-T:6]N<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P
M<F5F("!4:&4@<')E9F5R96YC92!W:71H(&$@:&]O:RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@7W-E=$AO;VLH)'!R968I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]H;V]K<UM=(#T@)'!R968["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9G1E
M<B!P<F5F97)E;F-E<R!H879E(&)E96X@;&]A9&5D+"!S970@86YY(&QO8VME
M9"!O<B!E;7!T>0H@("`@("H@<')E9F5R96YC97,@=&AA="!H879E(&AO;VMS
M('1O('1H92!R97-U;'0@;V8@=&AE(&AO;VLN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]C86QL2&]O:W,H*0H@("`@>PH@("`@("`@(&EF("@A:7-?;G5L;"@D
M=&AI<RT^7VAO;VMS0V%L;&5D*2D@>PH@("`@("`@("`@("!R971U<FX["B`@
M("`@("`@?0H*("`@("`@("`D=&AI<RT^7VAO;VMS0V%L;&5D(#T@=')U93L*
M"B`@("`@("`@:68@*"%C;W5N="@D=&AI<RT^7VAO;VMS*2D@>PH@("`@("`@
M("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("!G;&]B86P@)')E9VES
M=')Y.PH@("`@("`@(&EN8VQU9&5?;VYC92`D<F5G:7-T<GDM/F=E="@G9FEL
M97)O;W0G+"`G:&]R9&4G*2`N("<O8V]N9FEG+VAO;VMS+G!H<"<["B`@("`@
M("`@9F]R96%C:"`H)'1H:7,M/E]H;V]K<R!A<R`D<')E9BD@>PH@("`@("`@
M("`@("!I9B`H)'1H:7,M/FES3&]C:V5D*"1P<F5F*2!\?`H@("`@("`@("`@
M("`@("`@(21T:&ES+3YG971686QU92@D<')E9BD@?'P*("`@("`@("`@("`@
M("`@("1T:&ES+3YI<T1E9F%U;'0H)'!R968I*2!["B`@("`@("`@("`@("`@
M("`D9G5N8R`]("=?<')E9G-?:&]O:U\G("X@)'!R968["B`@("`@("`@("`@
M("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"1F=6YC*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<V5T5F%L=64H)'!R968L("1F=6YC*"1T:&ES
M+3Y?=7-E<BDI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T
M=7)N(&$@8V]N8W)E=&4@4')E9G,@:6YS=&%N8V4@8F%S960@;VX@)&1R:79E
M<BX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&1R:79E<B`@("`@5&AE
M('1Y<&4@;V8@8V]N8W)E=&4@4')E9G,@<W5B8VQA<W,@=&\@<F5T=7)N+@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@($EF("1D<FEV97(@:7,@
M86X@87)R87DL('1H96X@=V4@=VEL;"!L;V]K(&EN"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&1R:79E<ELP72]L:6(O4')E9G,O(&9O<B!T
M:&4@<W5B8VQA<W,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!I
M;7!L96UE;G1A=&EO;B!N86UE9"`D9')I=F5R6S%=+G!H<"X*("`@("`J($!P
M87)A;2!S=')I;F<@)'-C;W!E("`@("!4:&4@<V-O<&4@9F]R('1H:7,@<V5T
M(&]F('!R969E<F5N8V5S+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<B`@
M("`@(%1H92!N86UE(&]F('1H92!U<V5R('=H;R!O=VYS('1H:7,@<V5T(&]F
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@<')E9F5R96YC97,N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1P87-S=V]R9"`@5&AE('!A<W-W;W)D
M(&%S<V]C:6%T960@=VET:"`D=7-E<BX*("`@("`J($!P87)A;2!A<G)A>2`D
M<&%R86US("`@("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!C
M;VYF:6=U<F%T:6]N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M;W(@8V]N;F5C=&EO;B!P87)A;65T97)S(&$@<W5B8VQA<W,@;6EG:'0@;F5E
M9"X*("`@("`J($!P87)A;2!B;V]L96%N("1C86-H:6YG("!3:&]U;&0@8V%C
M:&EN9R!B92!U<V5D/PH@("`@("H*("`@("`J($!R971U<FX@4')E9G,@(%1H
M92!N97=L>2!C<F5A=&5D(&-O;F-R971E(%!R969S(&EN<W1A;F-E+"!O<B!F
M86QS92!O;@H@("`@("H@("`@("`@("`@("`@("`@97)R;W(N"B`@("`@*B\*
M("`@(&9U;F-T:6]N("9F86-T;W)Y*"1D<FEV97(L("1S8V]P92`]("=H;W)D
M92<L("1U<V5R(#T@)R<L("1P87-S=V]R9"`]("<G+`H@("`@("`@("`@("`@
M("`@("`@("`@)'!A<F%M<R`](&YU;&PL("1C86-H:6YG(#T@=')U92D*("`@
M('L*("`@("`@("!I9B`H:7-?87)R87DH)&1R:79E<BDI('L*("`@("`@("`@
M("`@)&%P<"`]("1D<FEV97);,%T["B`@("`@("`@("`@("1D<FEV97(@/2`D
M9')I=F5R6S%=.PH@("`@("`@('T*"B`@("`@("`@+RH@071T96UP="!T;R!R
M96=I<W1E<B`H8V%C:&4I('1H92`D<')E9G,@:&%S:"!I;B!S97-S:6]N('-T
M;W)A9V4N("HO"B`@("`@("`@:68@*"1C86-H:6YG*2!["B`@("`@("`@("`@
M(&EF("@A:7-S970H)%]315-324].6R=P<F5F<U]C86-H92==*2D@>PH@("`@
M("`@("`@("`@("`@)%]315-324].6R=P<F5F<U]C86-H92==(#T@87)R87DH
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&1R:79E<B`]
M(&)A<V5N86UE*"1D<FEV97(I.PH@("`@("`@(&EF("AE;7!T>2@D9')I=F5R
M*2!\?"`D9')I=F5R(#T]("=N;VYE)RD@>PH@("`@("`@("`@("`D9')I=F5R
M(#T@)W-E<W-I;VXG.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7VYU;&PH
M)'!A<F%M<RDI('L*("`@("`@("`@("`@)'!A<F%M<R`]($AO<F1E.CIG971$
M<FEV97)#;VYF:6<H)W!R969S)RP@)&1R:79E<BD["B`@("`@("`@?0H*("`@
M("`@("`O*B!)9B`D<&%R86US6R=U<V5R7VAO;VLG72!I<R!D969I;F5D+"!U
M<V4@:70@=&\@<F5T<FEE=F4@=&AE('9A;'5E('1O"B`@("`@("`@("H@=7-E
M(&9O<B!T:&4@=7-E<FYA;64@*"1T:&ES+3Y?=7-E<BDN($]T:&5R=VES92P@
M:G5S="!U<V4@=&AE('9A;'5E"B`@("`@("`@("H@<&%S<V5D(&EN('1H92`D
M=7-E<B!P87)A;65T97(N("HO"B`@("`@("`@:68@*"%E;7!T>2@D<&%R86US
M6R=U<V5R7VAO;VLG72D@)B8*("`@("`@("`@("`@9G5N8W1I;VY?97AI<W1S
M*"1P87)A;7-;)W5S97)?:&]O:R==*2D@>PH@("`@("`@("`@("`D=7-E<B`]
M(&-A;&Q?=7-E<E]F=6YC*"1P87)A;7-;)W5S97)?:&]O:R==+"`D=7-E<BD[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1A<'`I*2!["B`@("`@
M("`@("`@(')E<75I<F5?;VYC92`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T
M*"=F:6QE<F]O="<L("1A<'`I("X@)R]L:6(O4')E9G,O)R`N("1D<FEV97(@
M+B`G+G!H<"<["B`@("`@("`@?2!E;'-E:68@*&9I;&5?97AI<W1S*&1I<FYA
M;64H7U]&24Q%7U\I("X@)R]0<F5F<R\G("X@)&1R:79E<B`N("<N<&AP)RDI
M('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I
M("X@)R]0<F5F<R\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!I;F-L=61E7V]N8V4@)TAO<F1E+U!R969S+R<@
M+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T*"B`@("`@("`@)&-L87-S
M(#T@)U!R969S7R<@+B`D9')I=F5R.PH@("`@("`@(&EF("AC;&%S<U]E>&ES
M=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D<')E9G,@/2`F;F5W("1C;&%S
M<R@D=7-E<BP@)'!A<W-W;W)D+"`D<V-O<&4L("1P87)A;7,L("1C86-H:6YG
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<')E9G,@/2!014%2
M.CIR86ES945R<F]R*"=#;&%S<R!D969I;FET:6]N(&]F("<@+B`D8VQA<W,@
M+B`G(&YO="!F;W5N9"XG*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M<')E9G,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U
M<FX@82!R969E<F5N8V4@=&\@82!C;VYC<F5T92!0<F5F<R!I;G-T86YC92!B
M87-E9"!O;@H@("`@("H@)&1R:79E<BX@270@=VEL;"!O;FQY(&-R96%T92!A
M(&YE=R!I;G-T86YC92!I9B!N;R!0<F5F<R!I;G-T86YC90H@("`@("H@=VET
M:"!T:&4@<V%M92!P87)A;65T97)S(&-U<G)E;G1L>2!E>&ES=',N"B`@("`@
M*@H@("`@("H@5&AI<R!S:&]U;&0@8F4@=7-E9"!I9B!M=6QT:7!L92!P<F5F
M97)E;F-E('-O=7)C97,@*&%N9"P@=&AU<RP*("`@("`J(&UU;'1I<&QE(%!R
M969S(&EN<W1A;F-E<RD@87)E(')E<75I<F5D+@H@("`@("H*("`@("`J(%1H
M:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH@)'9A<B`]("90<F5F<SHZ
M<VEN9VQE=&]N*"D*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&1R:79E
M<B`@("`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@4')E9G,@<W5B8VQA<W,@=&\@
M<F5T=7)N+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@($EF("1D
M<FEV97(@:7,@86X@87)R87DL('1H96X@=V4@=VEL;"!L;V]K(&EN"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@)&1R:79E<ELP72]L:6(O4')E
M9G,O(&9O<B!T:&4@<W5B8VQA<W,*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("!I;7!L96UE;G1A=&EO;B!N86UE9"`D9')I=F5R6S%=+G!H<"X*
M("`@("`J($!P87)A;2!S=')I;F<@)'-C;W!E("`@("!4:&4@<V-O<&4@9F]R
M('1H:7,@<V5T(&]F('!R969E<F5N8V5S+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=7-E<B`@("`@(%1H92!N86UE(&]F('1H92!U<V5R('=H;R!O=VYS('1H
M:7,@<V5T(&]F"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@<')E
M9F5R96YC97,N"B`@("`@*B!`<&%R86T@<W1R:6YG("1P87-S=V]R9"`@5&AE
M('!A<W-W;W)D(&%S<V]C:6%T960@=VET:"`D=7-E<BX*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US("`@("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@861D
M:71I;VYA;"!C;VYF:6=U<F%T:6]N"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@;W(@8V]N;F5C=&EO;B!P87)A;65T97)S(&$@<W5B8VQA<W,@
M;6EG:'0@;F5E9"X*("`@("`J($!P87)A;2!B;V]L96%N("1C86-H:6YG("!3
M:&]U;&0@8V%C:&EN9R!B92!U<V5D/PH@("`@("H*("`@("`J($!R971U<FX@
M4')E9G,@(%1H92!C;VYC<F5T92!0<F5F<R!R969E<F5N8V4L(&]R(&9A;'-E
M(&]N(&%N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N
M*"1D<FEV97(L("1S8V]P92`]("=H;W)D92<L("1U<V5R(#T@)R<L("1P87-S
M=V]R9"`]("<G+`H@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86US(#T@
M;G5L;"P@)&-A8VAI;F<@/2!T<G5E*0H@("`@>PH@("`@("`@('-T871I8R`D
M:6YS=&%N8V5S(#T@87)R87DH*3L*"B`@("`@("`@:68@*&ES7VYU;&PH)'!A
M<F%M<RDI('L*("`@("`@("`@("`@)'!A<F%M<R`]($AO<F1E.CIG971$<FEV
M97)#;VYF:6<H)W!R969S)RP@)&1R:79E<BD["B`@("`@("`@?0H*("`@("`@
M("`D<VEG;F%T=7)E(#T@<V5R:6%L:7IE*&%R<F%Y*"1D<FEV97(L("1U<V5R
M+"`D<&%R86US*2D["B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S6R1S
M:6=N871U<F5=*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S6R1S:6=N871U
M<F5=(#T@)E!R969S.CIF86-T;W)Y*"1D<FEV97(L("1S8V]P92P@)'5S97(L
M("1P87-S=V]R9"P@)'!A<F%M<RP@)&-A8VAI;F<I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1I;G-T86YC97-;)'-I9VYA='5R95T["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O075T:"YP:'``````````````````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`Q,C0Q,C`@,3`U,34T,S,W-#`@,#(P-S4V`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B!4
M:&4@<&%R86UE=&5R(&YA;64@9F]R('1H92!L;V=O=70@<F5A<V]N+@H@*B\*
M9&5F:6YE*"=!551(7U)%05-/3E]005)!32<L("=L;V=O=71?<F5A<V]N)RD[
M"@HO*BH*("H@5&AE('!A<F%M971E<B!N86UE(&9O<B!T:&4@;&]G;W5T(&UE
M<W-A9V4@=7-E9"!W:71H('1Y<&4*("H@05542%]214%33TY?34534T%'12X*
M("HO"F1E9FEN92@G05542%]214%33TY?35-'7U!!4D%-)RP@)VQO9V]U=%]M
M<V<G*3L*"B\J*@H@*B!4:&4@)V)A9&QO9VEN)R!R96%S;VXN"B`J"B`J(%1H
M92!F;VQL;W=I;F<@)W)E87-O;G,G(&9O<B!T:&4@;&]G;W5T('-C<F5E;B!A
M<F4@<F5C;V=N:7IE9#H*("H@/'!R93X*("H@("`G8F%D;&]G:6XG("`@+2T@
M($)A9"!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0*("H@("`G8G)O=W-E<B<@
M("`@+2T@($$@8G)O=W-E<B!C:&%N9V4@=V%S(&1E=&5C=&5D"B`J("`@)V9A
M:6QE9"<@("`@("TM("!,;V=I;B!F86EL960*("H@("`G;&]G;W5T)R`@("`@
M+2T@($QO9V]U="!D=64@=&\@=7-E<B!R97%U97-T"B`J("`@)VUE<W-A9V4G
M("`@("TM("!,;V=O=70@=VET:"!C=7-T;VT@;65S<V%G92!I;B!!551(7U)%
M05-/3E]-4T=?4$%204T*("H@("`G<V5S<VEO;B<@("`@+2T@($QO9V]U="!D
M=64@=&\@<V5S<VEO;B!E>'!I<F%T:6]N"B`J("`@)W-E<W-I;VYI<"<@("TM
M("!,;V=O=70@9'5E('1O(&-H86YG92!O9B!)4"!A9&1R97-S(&1U<FEN9R!S
M97-S:6]N"B`J(#PO<')E/@H@*B\*9&5F:6YE*"=!551(7U)%05-/3E]"041,
M3T=)3B<L("=B861L;V=I;B<I.PH*+RHJ"B`J(%1H92`G8G)O=W-E<B<@<F5A
M<V]N+@H@*B\*9&5F:6YE*"=!551(7U)%05-/3E]"4D]74T52)RP@)V)R;W=S
M97(G*3L*"B\J*@H@*B!4:&4@)V9A:6QE9"<@<F5A<V]N+@H@*B\*9&5F:6YE
M*"=!551(7U)%05-/3E]&04E,140G+"`G9F%I;&5D)RD["@HO*BH*("H@5&AE
M("=E>'!I<F5D)R!R96%S;VXN"B`J+PID969I;F4H)T%55$A?4D5!4T].7T58
M4$E2140G+"`G97AP:7)E9"<I.PH*+RHJ"B`J(%1H92`G;&]G;W5T)R!R96%S
M;VXN"B`J+PID969I;F4H)T%55$A?4D5!4T].7TQ/1T]55"<L("=L;V=O=70G
M*3L*"B\J*@H@*B!4:&4@)VUE<W-A9V4G(')E87-O;BX*("HO"F1E9FEN92@G
M05542%]214%33TY?34534T%'12<L("=M97-S86=E)RD["@HO*BH*("H@5&AE
M("=S97-S:6]N)R!R96%S;VXN"B`J+PID969I;F4H)T%55$A?4D5!4T].7U-%
M4U-)3TXG+"`G<V5S<VEO;B<I.PH*+RHJ"B`J(%1H92`G<V5S<VEO;FEP)R!R
M96%S;VXN"B`J+PID969I;F4H)T%55$A?4D5!4T].7U-%4U-)3TY)4"<L("=S
M97-S:6]N:7`G*3L*"B\J*@H@*B!4:&4@075T:#HZ(&-L87-S('!R;W9I9&5S
M(&$@8V]M;6]N(&%B<W1R86-T960@:6YT97)F86-E(&EN=&\@=&AE('9A<FEO
M=7,*("H@8F%C:V5N9',@9F]R('1H92!(;W)D92!A=71H96YT:6-A=&EO;B!S
M>7-T96TN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T%U=&@O075T:"YP:'`L
M=B`Q+C$T,BXQ,"XR,R`R,#`V+S`X+S$T(#`R.C0X.C0X(&-H=6-K($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#
M:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@
M2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E7T%U=&@*("HO"F-L87-S($%U
M=&@@>PH*("`@("\J*@H@("`@("H@06X@87)R87D@;V8@8V%P86)I;&ET:65S
M+"!S;R!T:&%T('1H92!D<FEV97(@8V%N(')E<&]R="!W:&EC:`H@("`@("H@
M;W!E<F%T:6]N<R!I="!S=7!P;W)T<R!A;F0@=VAI8V@@:70@9&]E<VXG="X*
M("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D8V%P
M86)I;&ET:65S(#T@87)R87DH)V%D9"<@("`@("`@("`@(#T^(&9A;'-E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=7!D871E)R`@("`@("`@
M/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R97-E
M='!A<W-W;W)D)R`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W)E;6]V92<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G;&ES="<@("`@("`@("`@/3X@9F%L<V4L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=G<F]U<',G("`@("`@("`]
M/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1R86YS
M<&%R96YT)R`@(#T^(&9A;'-E*3L*"B`@("`O*BH*("`@("`J($AA<V@@8V]N
M=&%I;FEN9R!P87)A;65T97)S+@H@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1?<&%R86US(#T@87)R87DH*3L*"B`@("`O*BH*
M("`@("`J(%1H92!C<F5D96YT:6%L<R!C=7)R96YT;'D@8F5I;F<@875T:&5N
M=&EC871E9"X*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@
M("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?875T:$-R
M961E;G1I86QS(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE(&YA;64@;V8@=&AE(&-O;F-R971E($%U=&@@:6UP;&5M96YT871I;VXN
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!!=71H(&EM<&QE
M;65N=&%T:6]N(&YA;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1R:79E
M<B@I"B`@("!["B`@("`@("`@<F5T=7)N('-T<E]R97!L86-E*"=A=71H7R<L
M("<G+"!S=')T;VQO=V5R*&=E=%]C;&%S<R@D=&AI<RDI*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($9I;F1S(&]U="!I9B!A('-E="!O9B!L;V=I;B!C<F5D
M96YT:6%L<R!A<F4@=F%L:60L(&%N9"!I9B!R97%U97-T960L"B`@("`@*B!M
M87)K('1H92!U<V5R(&%S(&QO9V=E9"!I;B!I;B!T:&4@8W5R<F5N="!S97-S
M:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@("`@
M(%1H92!U<V5R260@=&\@8VAE8VLN"B`@("`@*B!`<&%R86T@87)R87D@)&-R
M961E;G1I86QS("!4:&4@8W)E9&5N=&EA;',@=&\@8VAE8VLN"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D;&]G:6X@("`@("!7:&5T:&5R('1O(&QO9R!T:&4@
M=7-E<B!I;BX@268@9F%L<V4L('=E)VQL"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!O;FQY('1E<W0@=&AE(&-R961E;G1I86QS(&%N9"!W
M;VXG="!M;V1I9GD*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('1H92!C=7)R96YT('-E<W-I;VXN($1E9F%U;'1S('1O('1R=64N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1R96%L;2`@("`@("!4:&4@875T:&5N=&EC871I
M;VX@<F5A;&T@=&\@8VAE8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M96%N("!7:&5T:&5R(&]R(&YO="!T:&4@8W)E9&5N=&EA;',@87)E('9A;&ED
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!A=71H96YT:6-A=&4H)'5S97))9"P@
M)&-R961E;G1I86QS+"`D;&]G:6X@/2!T<G5E+"`D<F5A;&T@/2!N=6QL*0H@
M("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@)&%U=&@@/2!F
M86QS93L*("`@("`@("`D=7-E<DED(#T@=')I;2@D=7-E<DED*3L*"B`@("`@
M("`@:68@*"%E;7!T>2@D8V]N9ELG:&]O:W,G75LG<')E875T:&5N=&EC871E
M)UTI*2!["B`@("`@("`@("`@(&EN8VQU9&5?;VYC92!(3U)$15]"05-%("X@
M)R]C;VYF:6<O:&]O:W,N<&AP)SL*("`@("`@("`@("`@:68@*&9U;F-T:6]N
M7V5X:7-T<R@G7VAO<F1E7VAO;VM?<')E875T:&5N=&EC871E)RDI('L*("`@
M("`@("`@("`@("`@(&EF("@A8V%L;%]U<V5R7V9U;F,H)U]H;W)D95]H;V]K
M7W!R96%U=&AE;G1I8V%T92<L("1U<V5R260L("1C<F5D96YT:6%L<RP@)')E
M86QM*2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7V=E=$%U
M=&A%<G)O<B@I("$]($%55$A?4D5!4T].7TU%4U-!1T4I('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H05542%]214%3
M3TY?1D%)3$5$*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!3=&]R92!T:&4@8W)E
M9&5N=&EA;',@8F5I;F<@8VAE8VME9"!S;R!T:&%T('-U8F-L87-S97,@8V%N
M(&UO9&EF>0H@("`@("`@("`J('1H96T@:68@;F5C97-S87)Y("AL:6ME('1R
M86YS<&%R96YT(&%U=&@@9&]E<RDN("HO"B`@("`@("`@)'1H:7,M/E]A=71H
M0W)E9&5N=&EA;',@/2!A<G)A>2@*("`@("`@("`@("`@)W5S97))9"<@/3X@
M)'5S97))9"P*("`@("`@("`@("`@)V-R961E;G1I86QS)R`]/B`D8W)E9&5N
M=&EA;',L"B`@("`@("`@("`@("=R96%L;2<@/3X@)')E86QM+`H@("`@("`@
M("`@("`G8VAA;F=E4F5Q=65S=&5D)R`]/B!F86QS90H@("`@("`@("D["@H@
M("`@("`@(&EF("@D875T:&5N=&EC871E9"`]("1T:&ES+3Y?875T:&5N=&EC
M871E*"1U<V5R260L("1C<F5D96YT:6%L<RDI('L*("`@("`@("`@("`@:68@
M*&ES7V$H)&%U=&AE;G1I8V%T960L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1C;VYF6R=H;V]K<R==6R=P;W-T875T:&5N=&EC
M871E)UTI*2!["B`@("`@("`@("`@("`@("!I;F-L=61E7V]N8V4@2$]21$5?
M0D%312`N("<O8V]N9FEG+VAO;VMS+G!H<"<["B`@("`@("`@("`@("`@("!I
M9B`H9G5N8W1I;VY?97AI<W1S*"=?:&]R9&5?:&]O:U]P;W-T875T:&5N=&EC
M871E)RDI('L*("`@("`@("`@("`@("`@("`@("!I9B`H(6-A;&Q?=7-E<E]F
M=6YC*"=?:&]R9&5?:&]O:U]P;W-T875T:&5N=&EC871E)RP@)'5S97))9"P@
M)&-R961E;G1I86QS+"`D<F5A;&TI*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@D=&AI<RT^7V=E=$%U=&A%<G)O<B@I("$]($%55$A?4D5!4T].
M7TU%4U-!1T4I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<V5T075T:$5R<F]R*$%55$A?4D5!4T].7T9!24Q%1"D["B`@("`@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1L;V=I;BD@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$%U=&@H)'1H:7,M/E]A=71H
M0W)E9&5N=&EA;'-;)W5S97))9"==+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]A=71H0W)E9&5N=&EA;'-;)V-R961E;G1I86QS
M)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%U
M=&A#<F5D96YT:6%L<ULG<F5A;&TG72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?875T:$-R961E;G1I86QS6R=C:&%N9V5297%U
M97-T960G72D["B`@("`@("`@("`@("`@("`D875T:"`]('1R=64["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3Y?
M8VAE8VM397-S:6]N25`H*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<V5T075T:$5R<F]R*$%55$A?4D5!4T].7U-%4U-)3TY)4"D["B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@
M?2!E;'-E:68@*"$D=&AI<RT^7V-H96-K0G)O=W-E<E-T<FEN9R@I*2!["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H05542%]2
M14%33TY?0E)/5U-%4BD["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&%U=&@@
M/2!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)&%U=&@["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&;W)M871S(&$@<&%S
M<W=O<F0@=7-I;F<@=&AE(&-U<G)E;G0@96YC<GEP=&EO;BX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P;&%I;G1E>'0@("`@("!4:&4@<&QA:6YT
M97AT('!A<W-W;W)D('1O(&5N8W)Y<'0N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1S86QT("`@("`@("`@("!4:&4@<V%L="!T;R!U<V4@=&\@96YC<GEP="!T
M:&4@<&%S<W=O<F0N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!)9B!N;W0@<')E<V5N="P@82!N97<@<V%L="!W:6QL(&)E"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!G96YE<F%T960N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1E;F-R>7!T:6]N("`@("!4:&4@:VEN9"!O
M9B!P87-W;W)D(&5N8W)Y<'1I;VX@=&\@=7-E+@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@1&5F875L=',@=&\@;60U+6AE>"X*("`@
M("`J($!P87)A;2!B;V]L96%N("1S:&]W7V5N8W)Y<'0@(%-O;64@<&%S<W=O
M<F0@<WES=&5M<R!P<F5P96YD('1H92!K:6YD(&]F"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!E;F-R>7!T:6]N('1O('1H92!C<GEP
M=&5D('!A<W-W;W)D("A[4TA!?2P*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&5T8RDN($1E9F%U;'1S('1O(&9A;'-E+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@96YC<GEP=&5D('!A<W-W;W)D
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971#<GEP=&5D4&%S<W=O<F0H)'!L
M86EN=&5X="P@)'-A;'0@/2`G)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D96YC<GEP=&EO;B`]("=M9#4M:&5X)RP@)'-H;W=?96YC<GEP
M="`](&9A;'-E*0H@("`@>PH@("`@("`@("\J($=E="!T:&4@<V%L="!T;R!U
M<V4N("HO"B`@("`@("`@)'-A;'0@/2!!=71H.CIG971386QT*"1E;F-R>7!T
M:6]N+"`D<V%L="P@)'!L86EN=&5X="D["@H@("`@("`@("\J($5N8W)Y<'0@
M=&AE('!A<W-W;W)D+B`J+PH@("`@("`@('-W:71C:"`H)&5N8W)Y<'1I;VXI
M('L*("`@("`@("!C87-E("=P;&%I;B<Z"B`@("`@("`@("`@(')E='5R;B`D
M<&QA:6YT97AT.PH*("`@("`@("!C87-E("=M<V%D)SH*("`@("`@("`@("`@
M<F5T=7)N(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)R(G("X@)'!L86EN=&5X
M="`N("<B)RP@)TE33RTX.#4Y+3$G+"`G551&+3$V3$4G*3L*"B`@("`@("`@
M8V%S92`G<VAA)SH*("`@("`@("`@("`@)&5N8W)Y<'1E9"`](&)A<V4V-%]E
M;F-O9&4H;6AA<V@H34A!4TA?4TA!,2P@)'!L86EN=&5X="DI.PH@("`@("`@
M("`@("!R971U<FX@*"1S:&]W7V5N8W)Y<'0I(#\@)WM32$%])R`N("1E;F-R
M>7!T960@.B`D96YC<GEP=&5D.PH*("`@("`@("!C87-E("=C<GEP="<Z"B`@
M("`@("`@8V%S92`G8W)Y<'0M9&5S)SH*("`@("`@("!C87-E("=C<GEP="UM
M9#4G.@H@("`@("`@(&-A<V4@)V-R>7!T+6)L;W=F:7-H)SH*("`@("`@("`@
M("`@<F5T=7)N("@D<VAO=U]E;F-R>7!T(#\@)WMC<GEP='TG(#H@)R<I("X@
M8W)Y<'0H)'!L86EN=&5X="P@)'-A;'0I.PH*("`@("`@("!C87-E("=M9#4M
M8F%S938T)SH*("`@("`@("`@("`@)&5N8W)Y<'1E9"`](&)A<V4V-%]E;F-O
M9&4H;6AA<V@H34A!4TA?340U+"`D<&QA:6YT97AT*2D["B`@("`@("`@("`@
M(')E='5R;B`H)'-H;W=?96YC<GEP="D@/R`G>TU$-7TG("X@)&5N8W)Y<'1E
M9"`Z("1E;F-R>7!T960["@H@("`@("`@(&-A<V4@)W-S:&$G.@H@("`@("`@
M("`@("`D96YC<GEP=&5D(#T@8F%S938T7V5N8V]D92AM:&%S:"A-2$%32%]3
M2$$Q+"`D<&QA:6YT97AT("X@)'-A;'0I("X@)'-A;'0I.PH@("`@("`@("`@
M("!R971U<FX@*"1S:&]W7V5N8W)Y<'0I(#\@)WM34TA!?2<@+B`D96YC<GEP
M=&5D(#H@)&5N8W)Y<'1E9#L*"B`@("`@("`@8V%S92`G<VUD-2<Z"B`@("`@
M("`@("`@("1E;F-R>7!T960@/2!B87-E-C1?96YC;V1E*&UH87-H*$U(05-(
M7TU$-2P@)'!L86EN=&5X="`N("1S86QT*2`N("1S86QT*3L*("`@("`@("`@
M("`@<F5T=7)N("@D<VAO=U]E;F-R>7!T*2`_("=[4TU$-7TG("X@)&5N8W)Y
M<'1E9"`Z("1E;F-R>7!T960["@H@("`@("`@(&-A<V4@)V%P<FUD-2<Z"B`@
M("`@("`@("`@("1L96YG=&@@/2!S=')L96XH)'!L86EN=&5X="D["B`@("`@
M("`@("`@("1C;VYT97AT(#T@)'!L86EN=&5X="`N("<D87!R,20G("X@)'-A
M;'0["B`@("`@("`@("`@("1B:6YA<GD@/2!!=71H.CI?8FEN*&UD-2@D<&QA
M:6YT97AT("X@)'-A;'0@+B`D<&QA:6YT97AT*2D["@H@("`@("`@("`@("!F
M;W(@*"1I(#T@)&QE;F=T:#L@)&D@/B`P.R`D:2`M/2`Q-BD@>PH@("`@("`@
M("`@("`@("`@)&-O;G1E>'0@+CT@<W5B<W1R*"1B:6YA<GDL(#`L("@D:2`^
M(#$V(#\@,38@.B`D:2DI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&9O
M<B`H)&D@/2`D;&5N9W1H.R`D:2`^(#`[("1I(#X^/2`Q*2!["B`@("`@("`@
M("`@("`@("`D8V]N=&5X="`N/2`H)&D@)B`Q*2`_(&-H<B@P*2`Z("1P;&%I
M;G1E>'1[,'T["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1B:6YA<GD@
M/2!!=71H.CI?8FEN*&UD-2@D8V]N=&5X="DI.PH*("`@("`@("`@("`@9F]R
M("@D:2`](#`[("1I(#P@,3`P,#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@
M)&YE=R`]("@D:2`F(#$I(#\@)'!L86EN=&5X="`Z('-U8G-T<B@D8FEN87)Y
M+"`P+#$V*3L*("`@("`@("`@("`@("`@(&EF("@D:2`E(#,I('L*("`@("`@
M("`@("`@("`@("`@("`D;F5W("X]("1S86QT.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@:68@*"1I("4@-RD@>PH@("`@("`@("`@("`@
M("`@("`@("1N97<@+CT@)'!L86EN=&5X=#L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("1N97<@+CT@*"1I("8@,2D@/R!S=6)S='(H)&)I
M;F%R>2P@,"P@,38I(#H@)'!L86EN=&5X=#L*("`@("`@("`@("`@("`@("1B
M:6YA<GD@/2!!=71H.CI?8FEN*&UD-2@D;F5W*2D["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("1P(#T@87)R87DH*3L*("`@("`@("`@("`@9F]R("@D
M:2`](#`[("1I(#P@-3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@)&L@/2`D
M:2`K(#8["B`@("`@("`@("`@("`@("`D:B`]("1I("L@,3(["B`@("`@("`@
M("`@("`@("!I9B`H)&H@/3T@,38I('L*("`@("`@("`@("`@("`@("`@("`D
M:B`](#4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<%M=
M(#T@075T:#HZ7W1O05!2340U*"AO<F0H)&)I;F%R>5LD:5TI(#P\(#$V*2!\
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("AO<F0H
M)&)I;F%R>5LD:UTI(#P\(#@I('P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@*&]R9"@D8FEN87)Y6R1J72DI+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`U*3L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@<F5T=7)N("<D87!R,20G("X@)'-A;'0@+B`G)"<@
M+B!I;7!L;V1E*"<G+"`D<"D@+B!!=71H.CI?=&]!4%)-1#4H;W)D*"1B:6YA
M<GE;,3%=*2P@,RD["@H@("`@("`@(&-A<V4@)VUD-2UH97@G.@H@("`@("`@
M(&1E9F%U;'0Z"B`@("`@("`@("`@(')E='5R;B`H)'-H;W=?96YC<GEP="D@
M/R`G>TU$-7TG("X@;60U*"1P;&%I;G1E>'0I(#H@;60U*"1P;&%I;G1E>'0I
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!S
M86QT(&9O<B!T:&4@87!P<F]P<FEA=&4@:VEN9"!O9B!P87-S=V]R9"!E;F-R
M>7!T:6]N+@H@("`@("H@3W!T:6]N86QL>2!T86ME<R!A('-E960@86YD(&$@
M<&QA:6YT97AT('!A<W-W;W)D+"!T;R!E>'1R86-T('1H92!S965D"B`@("`@
M*B!O9B!A;B!E>&ES=&EN9R!P87-S=V]R9"P@;W(@9F]R(&5N8W)Y<'1I;VX@
M='EP97,@=&AA="!U<V4@=&AE('!L86EN=&5X=`H@("`@("H@:6X@=&AE(&=E
M;F5R871I;VX@;V8@=&AE('-A;'0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D96YC<GEP=&EO;B`@5&AE(&MI;F0@;V8@<&%S=V]R9"!E;F-R>7!T
M:6]N('1O('5S92X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M($1E9F%U;'1S('1O(&UD-2UH97@N"B`@("`@*B!`<&%R86T@<W1R:6YG("1S
M965D("`@("`@("!4:&4@<V5E9"!T;R!G970@=&AE('-A;'0@9G)O;2`H<')O
M8F%B;'D@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<')E
M=FEO=7-L>2!G96YE<F%T960@<&%S<W=O<F0I+B!$969A=6QT<R!T;PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@9V5N97)A=&EN9R!A(&YE
M=R!S965D+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&QA:6YT97AT("`@5&AE
M('!L86EN=&5X="!P87-S=V]R9"!T:&%T('=E)W)E(&=E;F5R871I;F<*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&$@<V%L="!F;W(N($1E
M9F%U;'1S('1O(&YO;F4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!G96YE<F%T960@;W(@97AT<F%C=&5D('-A;'0N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%-A;'0H)&5N8W)Y<'1I;VX@/2`G;60U+6AE>"<L("1S
M965D(#T@)R<L("1P;&%I;G1E>'0@/2`G)RD*("`@('L*("`@("`@("`O+R!%
M;F-R>7!T('1H92!P87-S=V]R9"X*("`@("`@("!S=VET8V@@*"1E;F-R>7!T
M:6]N*2!["B`@("`@("`@8V%S92`G8W)Y<'0G.@H@("`@("`@(&-A<V4@)V-R
M>7!T+61E<R<Z"B`@("`@("`@("`@(&EF("@D<V5E9"D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N('-U8G-T<BAP<F5G7W)E<&QA8V4H)WQ>>V-R>7!T?7QI
M)RP@)R<L("1S965D*2P@,"P@,BD["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("!R971U<FX@<W5B<W1R*&UD-2AM=%]R86YD*"DI+"`P
M+"`R*3L*("`@("`@("`@("`@?0H*("`@("`@("!C87-E("=C<GEP="UM9#4G
M.@H@("`@("`@("`@("!I9B`H)'-E960I('L*("`@("`@("`@("`@("`@(')E
M='5R;B!S=6)S='(H<')E9U]R97!L86-E*"=\7GMC<GEP='U\:2<L("<G+"`D
M<V5E9"DL(#`L(#$R*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@(')E='5R;B`G)#$D)R`N('-U8G-T<BAM9#4H;71?<F%N9"@I*2P@
M,"P@."D@+B`G)"<["B`@("`@("`@("`@('T*"B`@("`@("`@8V%S92`G8W)Y
M<'0M8FQO=V9I<V@G.@H@("`@("`@("`@("!I9B`H)'-E960I('L*("`@("`@
M("`@("`@("`@(')E='5R;B!S=6)S='(H<')E9U]R97!L86-E*"=\7GMC<GEP
M='U\:2<L("<G+"`D<V5E9"DL(#`L(#$V*3L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@(')E='5R;B`G)#(D)R`N('-U8G-T<BAM9#4H
M;71?<F%N9"@I*2P@,"P@,3(I("X@)R0G.PH@("`@("`@("`@("!]"@H@("`@
M("`@(&-A<V4@)W-S:&$G.@H@("`@("`@("`@("!I9B`H)'-E960I('L*("`@
M("`@("`@("`@("`@(')E='5R;B!S=6)S='(H<')E9U]R97!L86-E*"=\7GM3
M4TA!?7PG+"`G)RP@)'-E960I+"`M,C`I.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(&UH87-H7VME>6=E;E]S,FLH34A!
M4TA?4TA!,2P@)'!L86EN=&5X="P@<W5B<W1R*'!A8VLH)V@J)RP@;60U*&UT
M7W)A;F0H*2DI+"`P+"`X*2P@-"D["B`@("`@("`@("`@('T*"B`@("`@("`@
M8V%S92`G<VUD-2<Z"B`@("`@("`@("`@(&EF("@D<V5E9"D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N('-U8G-T<BAP<F5G7W)E<&QA8V4H)WQ>>U--1#5]
M?"<L("<G+"`D<V5E9"DL("TQ-BD["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("!R971U<FX@;6AA<VA?:V5Y9V5N7W,R:RA-2$%32%]-
M1#4L("1P;&%I;G1E>'0L('-U8G-T<BAP86-K*"=H*B<L(&UD-2AM=%]R86YD
M*"DI*2P@,"P@."DL(#0I.PH@("`@("`@("`@("!]"@H@("`@("`@(&-A<V4@
M)V%P<FUD-2<Z"B`@("`@("`@("`@("\J(#8T(&-H87)A8W1E<G,@=&AA="!A
M<F4@=F%L:60@9F]R($%04DU$-2!P87-S=V]R9',N("HO"B`@("`@("`@("`@
M("1!4%)-1#4@/2`G+B\P,3(S-#4V-S@Y04)#1$5&1TA)2DM,34Y/4%%24U15
M5E=865IA8F-D969G:&EJ:VQM;F]P<7)S='5V=WAY>B<["@H@("`@("`@("`@
M("!I9B`H)'-E960I('L*("`@("`@("`@("`@("`@(')E='5R;B!S=6)S='(H
M<')E9U]R97!L86-E*"<O7EPD87!R,5PD*"Y[.'TI+BHO)RP@)UQ<,2<L("1S
M965D*2P@,"P@."D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D<V%L="`]("<G.PH@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P@.#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("1S86QT("X]
M("1!4%)-1#5[<F%N9"@P+"`V,RE].PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@<F5T=7)N("1S86QT.PH@("`@("`@("`@("!]"@H@("`@
M("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T97,@82!R86YD;VTL(&AO
M<&5F=6QL>2!P<F]N;W5N8V5A8FQE+"!P87-S=V]R9"X@5&AI<R!C86X@8F4@
M=7-E9`H@("`@("H@=VAE;B!R97-E='1I;F<@875T;VUA=&EC86QL>2!A('5S
M97(G<R!P87-S=V]R9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R!!
M(')A;F1O;2!P87-S=V]R9`H@("`@("HO"B`@("!F=6YC=&EO;B!G96Y286YD
M;VU087-S=V]R9"@I"B`@("!["B`@("`@("`@)'9O=V5L<R`@("`]("=A96EO
M=7DG.PH@("`@("`@("1C;VYS=&%N=',@/2`G8F-D9F=H:FML;6YP<7)S='9W
M>'HG.PH@("`@("`@("1N=6UB97)S("`@/2`G,#$R,S0U-C<X.2<["@H@("`@
M("`@("\J($%L=&5R;F%T92!C;VYS=&%N="!A;F0@=F]W96P@<F%N9&]M(&-H
M87)S('=I=&@@='=O(')A;F1O;2!N=6UB97)S"B`@("`@("`@("H@870@=&AE
M(&5N9"X@5&AI<R!S:&]U;&0@<')O9'5C92!A(&9A:7)L>2!P<F]N;W5N8V5A
M8FQE('!A<W-W;W)D+B`J+PH@("`@("`@("1C:&%R<ULP72`]('-U8G-T<B@D
M8V]N<W1A;G1S+"!M=%]R86YD*#`L('-T<FQE;B@D8V]N<W1A;G1S*2`M(#$I
M+"`Q*3L*("`@("`@("`D8VAA<G-;,5T@/2!S=6)S='(H)'9O=V5L<RP@;71?
M<F%N9"@P+"!S=')L96XH)'9O=V5L<RD@+2`Q*2P@,2D["B`@("`@("`@)&-H
M87)S6S)=(#T@<W5B<W1R*"1C;VYS=&%N=',L(&UT7W)A;F0H,"P@<W1R;&5N
M*"1C;VYS=&%N=',I("T@,2DL(#$I.PH@("`@("`@("1C:&%R<ULS72`]('-U
M8G-T<B@D=F]W96QS+"!M=%]R86YD*#`L('-T<FQE;B@D=F]W96QS*2`M(#$I
M+"`Q*3L*("`@("`@("`D8VAA<G-;-%T@/2!S=6)S='(H)&-O;G-T86YT<RP@
M;71?<F%N9"@P+"!S=')L96XH)&-O;G-T86YT<RD@+2`Q*2P@,2D["B`@("`@
M("`@)&-H87)S6S5=(#T@<W5B<W1R*"1N=6UB97)S+"!M=%]R86YD*#`L('-T
M<FQE;B@D;G5M8F5R<RD@+2`Q*2P@,2D["B`@("`@("`@)&-H87)S6S9=(#T@
M<W5B<W1R*"1N=6UB97)S+"!M=%]R86YD*#`L('-T<FQE;B@D;G5M8F5R<RD@
M+2`Q*2P@,2D["@H@("`@("`@(')E='5R;B!I;7!L;V1E*"<G+"`D8VAA<G,I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@061D<R!A('-E="!O9B!A=71H96YT
M:6-A=&EO;B!C<F5D96YT:6%L<RX*("`@("`J"B`@("`@*B!`86)S=')A8W0*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@("`@("!4:&4@
M=7-E<DED('1O(&%D9"X*("`@("`J($!P87)A;2!A<G)A>2`D8W)E9&5N=&EA
M;',@(%1H92!C<F5D96YT:6%L<R!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@861D57-E
M<B@D=7-E<DED+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H)W5N<W5P<&]R=&5D)RD["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!5<&1A=&5S(&$@<V5T(&]F(&%U=&AE;G1I8V%T:6]N(&-R
M961E;G1I86QS+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&]L9$E$("`@("`@("!4:&4@;VQD('5S97))
M9"X*("`@("`J($!P87)A;2!S=')I;F<@)&YE=TE$("`@("`@("!4:&4@;F5W
M('5S97))9"X*("`@("`J($!P87)A;2!A<G)A>2`D8W)E9&5N=&EA;',@("!4
M:&4@;F5W(&-R961E;G1I86QS"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@=7!D871E57-E<B@D;VQD
M240L("1N97=)1"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"=U;G-U<'!O<G1E9"<I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1&5L971E<R!A('-E="!O9B!A=71H96YT:6-A=&EO;B!C
M<F5D96YT:6%L<RX*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@(%1H92!U<V5R260@=&\@9&5L
M971E+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C
M8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(')E;6]V955S97(H)'5S97))9"D*("`@('L*("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G=6YS=7!P;W)T960G*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($-A;&QS(&%L;"!A<'!L:6-A=&EO;G,G
M(')E;6]V955S97(@05!)(&UE=&AO9',N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=7-E<DED("!4:&4@=7-E<DED('1O(&1E;&5T92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!0
M14%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!R96UO=F55<V5R1&%T82@D=7-E<DED*0H@("`@>PH@("`@("`@(&=L
M;V)A;"`D<F5G:7-T<GD["@H@("`@("`@(&9O<F5A8V@@*"1R96=I<W1R>2T^
M;&ES=$%P<',H87)R87DH)VYO=&]O;&)A<B<L("=H:61D96XG+"`G86-T:79E
M)RP@)V%D;6EN)RDI(&%S("1A<'`I('L*("`@("`@("`@("`@:68@*"1R96=I
M<W1R>2T^:&%S365T:&]D*"=R96UO=F55<V5R1&%T82<L("1A<'`I*2!["B`@
M("`@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT(#T@)')E9VES=')Y+3YC
M86QL0GE086-K86=E*"1A<'`L("=R96UO=F55<V5R1&%T82<L(&%R<F%Y*"1U
M<V5R260I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!,:7-T<R!A;&P@=7-E<G,@:6X@=&AE('-Y<W1E;2X*
M("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!4:&4@87)R87D@;V8@=7-E<DED<RP@;W(@82!014%27T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T
M57-E<G,H*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"=U;G-U<'!O<G1E9"<I.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS
M(&EF("1U<V5R260@97AI<W1S(&EN('1H92!S>7-T96TN"B`@("`@*@H@("`@
M("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E
M<DED(%5S97(@240@9F]R('=H:6-H('1O(&-H96-K"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="`D=7-E<DED(&%L<F5A
M9'D@97AI<W1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>&ES=',H)'5S97))
M9"D*("`@('L*("`@("`@("!R971U<FX@:6Y?87)R87DH)'5S97))9"P@)'1H
M:7,M/FQI<W15<V5R<R@I*3L*("`@('T*"B`@("`O*BH*("`@("`J($%U=&]M
M871I8R!A=71H96YT:6-A=&EO;CH@1FEN9',@;W5T(&EF('1H92!C;&EE;G0@
M;6%T8VAE<R!A;B!A;&QO=V5D($E0"B`@("`@*B!B;&]C:RX*("`@("`J"B`@
M("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%=H971H97(@;W(@;F]T('1H92!C;&EE;G0@:7,@86QL;W=E9"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@=')A;G-P87)E;G0H*0H@("`@>PH@("`@("`@(')E
M='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!I9B!T
M:&5R92!I<R!A('-E<W-I;VX@=VET:"!V86QI9"!A=71H(&EN9F]R;6%T:6]N
M+B!F;W(@=&AE"B`@("`@*B!S<&5C:69I960@=7-E<BX@268@=&AE<F4@:7-N
M)W0L(&)U="!T:&4@8V]N9FEG=7)E9"!!=71H(&1R:79E<B!S=7!P;W)T<PH@
M("`@("H@=')A;G-P87)E;G0@875T:&5N=&EC871I;VXL('1H96X@=V4@=')Y
M('1H870N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<F5A;&T@(%1H
M92!A=71H96YT:6-A=&EO;B!R96%L;2!T;R!C:&5C:RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T('1H92!U<V5R(&ES
M(&%U=&AE;G1I8V%T960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES075T:&5N
M=&EC871E9"@D<F5A;&T@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<W-E
M="@D7U-%4U-)3TY;)U]?875T:"==*2D@>PH@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1?4T534TE/3ELG7U]A=71H)UU;)V%U=&AE;G1I8V%T960G72D@)B8*
M("`@("`@("`@("`@("`@("%E;7!T>2@D7U-%4U-)3TY;)U]?875T:"==6R=U
M<V5R260G72D@)B8*("`@("`@("`@("`@("`@("@D7U-%4U-)3TY;)U]?875T
M:"==6R=R96%L;2==(#T]("1R96%L;2DI('L*("`@("`@("`@("`@("`@(&EF
M("@A075T:#HZ7V-H96-K4V5S<VEO;DE0*"DI('L*("`@("`@("`@("`@("`@
M("`@("!!=71H.CI?<V5T075T:$5R<F]R*$%55$A?4D5!4T].7U-%4U-)3TY)
M4"D["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M("`@("`@("`@?2!E;'-E:68@*"%!=71H.CI?8VAE8VM"<F]W<V5R4W1R:6YG
M*"DI('L*("`@("`@("`@("`@("`@("`@("!!=71H.CI?<V5T075T:$5R<F]R
M*$%55$A?4D5!4T].7T)23U=315(I.PH@("`@("`@("`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O(%1R>2!T<F%N<W!A
M<F5N="!A=71H96YT:6-A=&EO;B!N;W<N"B`@("`@("`@)&%U=&@@/2`F075T
M:#HZ<VEN9VQE=&]N*"1'3$]"04Q36R=C;VYF)UU;)V%U=&@G75LG9')I=F5R
M)UTI.PH@("`@("`@(&EF("@D875T:"T^:&%S0V%P86)I;&ET>2@G=')A;G-P
M87)E;G0G*2`F)@H@("`@("`@("`@("`D875T:"T^=')A;G-P87)E;G0H*2D@
M>PH@("`@("`@("`@("!R971U<FX@075T:#HZ:7-!=71H96YT:6-A=&5D*"1R
M96%L;2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C=7)R96YT;'D@;&]G9V5D
M(&EN('5S97(L(&EF('1H97)E(&ES(&]N92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!4:&4@=7-E<DED(&]F('1H92!C=7)R96YT('5S97(L(&]R
M(&9A;'-E(&EF(&YO('5S97(@:7,*("`@("`J("`@("`@("`@("`@("`@(&QO
M9V=E9"!I;BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T075T:"@I"B`@("![
M"B`@("`@("`@:68@*&ES<V5T*"1?4T534TE/3ELG7U]A=71H)UTI*2!["B`@
M("`@("`@("`@(&EF("@A96UP='DH)%]315-324].6R=?7V%U=&@G75LG875T
M:&5N=&EC871E9"==*2`F)@H@("`@("`@("`@("`@("`@(65M<'1Y*"1?4T53
M4TE/3ELG7U]A=71H)UU;)W5S97))9"==*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1?4T534TE/3ELG7U]A=71H)UU;)W5S97))9"==.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=VAE=&AE<B!T:&4@875T:&5N=&EC
M871I;VX@8F%C:V5N9"!R97%U97-T960@82!P87-S=V]R9"!C:&%N9V4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N(%=H971H97(@=&AE(&)A8VME
M;F0@<F5Q=65S=&5D(&$@<&%S<W=O<F0@8VAA;F=E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!I<U!A<W-W;W)D0VAA;F=E4F5Q=65S=&5D*"D*("`@('L*("`@
M("`@("!I9B`H:7-S970H)%]315-324].6R=?7V%U=&@G72D@)B8*("`@("`@
M("`@("`@(65M<'1Y*"1?4T534TE/3ELG7U]A=71H)UU;)V%U=&AE;G1I8V%T
M960G72D@)B8*("`@("`@("`@("`@(65M<'1Y*"1?4T534TE/3ELG7U]A=71H
M)UU;)V-H86YG95)E<75E<W1E9"==*2D@>PH@("`@("`@("`@("!R971U<FX@
M=')U93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-U<F5N=&QY(&QO9V=E9"UI
M;B!U<V5R('=I=&AO=70@86YY(&1O;6%I;B!I;F9O<FUA=&EO;@H@("`@("H@
M*&4N9RXL(&)O8D!E>&%M<&QE+F-O;2!W;W5L9"!B92!R971U<FYE9"!A<R`G
M8F]B)RDN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE('5S97(@
M240@;V8@=&AE(&-U<G)E;G0@=7-E<BP@;W(@9F%L<V4@:68@;F\@=7-E<@H@
M("`@("H@("`@("`@("`@("`@("`@:7,@;&]G9V5D(&EN+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971"87)E075T:"@I"B`@("!["B`@("`@("`@)'5S97(@
M/2!!=71H.CIG971!=71H*"D["B`@("`@("`@:68@*"1U<V5R*2!["B`@("`@
M("`@("`@("1P;W,@/2!S=')P;W,H)'5S97(L("=`)RD["B`@("`@("`@("`@
M(&EF("@D<&]S("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@)'5S97(@
M/2!S=6)S='(H)'5S97(L(#`L("1P;W,I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)'5S97(["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!D;VUA:6X@;V8@8W5R<F5N=&QY(&QO9V=E9"UI
M;B!U<V5R("AE+F<N+"!B;V)`97AA;7!L92YC;VT*("`@("`J('=O=6QD(&)E
M(')E='5R;F5D(&%S("=E>&%M<&QE+F-O;2<I+@H@("`@("H*("`@("`J($!S
M:6YC92!(;W)D92`S+C`N-@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1H92!D;VUA:6X@<W5F9FEX(&]F('1H92!C=7)R96YT('5S97(L(&]R(&9A
M;'-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971!=71H1&]M86EN*"D*("`@
M('L*("`@("`@("!I9B`H)'5S97(@/2!!=71H.CIG971!=71H*"DI('L*("`@
M("`@("`@("`@)'!O<R`]('-T<G!O<R@D=7-E<BP@)T`G*3L*("`@("`@("`@
M("`@:68@*"1P;W,@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@<W5B<W1R*"1U<V5R+"`D<&]S("L@,2D["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE(')E<75E<W1E9"!C<F5D96YT:6%L(&9O<B!T
M:&4@8W5R<F5N=&QY(&QO9V=E9"!I;B!U<V5R+"!I9@H@("`@("H@<')E<V5N
M="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C<F5D96YT:6%L("!4
M:&4@8W)E9&5N=&EA;"!T;R!R971R:65V92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!4:&4@<F5Q=65S=&5D(&-R961E;G1I86PL(&]R(&9A;'-E
M(&EF(&YO('5S97(@:7,*("`@("`J("`@("`@("`@("`@("`@(&QO9V=E9"!I
M;BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0W)E9&5N=&EA;"@D8W)E9&5N
M=&EA;"D*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1?4T534TE/3ELG7U]A
M=71H)UTI("8F"B`@("`@("`@("`@("%E;7!T>2@D7U-%4U-)3TY;)U]?875T
M:"==6R=A=71H96YT:6-A=&5D)UTI*2!["B`@("`@("`@("`@(')E<75I<F5?
M;VYC92`G2&]R9&4O4V5C<F5T+G!H<"<["B`@("`@("`@("`@("1C<F5D96YT
M:6%L<R`]($!U;G-E<FEA;&EZ92A396-R970Z.G)E860H4V5C<F5T.CIG971+
M97DH)V%U=&@G*2P@)%]315-324].6R=?7V%U=&@G75LG8W)E9&5N=&EA;',G
M72DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]A<G)A>2@D8W)E9&5N=&EA
M;',I("8F"B`@("`@("`@("`@(&ES<V5T*"1C<F5D96YT:6%L<ULD8W)E9&5N
M=&EA;%TI*2!["B`@("`@("`@("`@(')E='5R;B`D8W)E9&5N=&EA;'-;)&-R
M961E;G1I86Q=.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S
M('1H92!R97%U97-T960@8W)E9&5N=&EA;"!F;W(@=&AE(&-U<G)E;G1L>2!L
M;V=G960@:6X@=7-E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C
M<F5D96YT:6%L("!4:&4@8W)E9&5N=&EA;"!T;R!S970N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1V86QU92`@("`@("!4:&4@=F%L=64@=&\@<V5T('1H92!C
M<F5D96YT:6%L('1O+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971#<F5D96YT
M:6%L*"1C<F5D96YT:6%L+"`D=F%L=64I"B`@("!["B`@("`@("`@:68@*"%E
M;7!T>2@D7U-%4U-)3TY;)U]?875T:"==*2`F)@H@("`@("`@("`@("`A96UP
M='DH)%]315-324].6R=?7V%U=&@G75LG875T:&5N=&EC871E9"==*2D@>PH@
M("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U-E8W)E="YP:'`G.PH@
M("`@("`@("`@("`D8W)E9&5N=&EA;',@/2!`=6YS97)I86QI>F4H4V5C<F5T
M.CIR96%D*%-E8W)E=#HZ9V5T2V5Y*"=A=71H)RDL("1?4T534TE/3ELG7U]A
M=71H)UU;)V-R961E;G1I86QS)UTI*3L*("`@("`@("`@("`@:68@*&ES7V%R
M<F%Y*"1C<F5D96YT:6%L<RDI('L*("`@("`@("`@("`@("`@("1C<F5D96YT
M:6%L<ULD8W)E9&5N=&EA;%T@/2`D=F%L=64["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D8W)E9&5N=&EA;',@/2!A<G)A>2@D8W)E
M9&5N=&EA;"`]/B`D=F%L=64I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1?4T534TE/3ELG7U]A=71H)UU;)V-R961E;G1I86QS)UT@/2!396-R970Z
M.G=R:71E*%-E8W)E=#HZ9V5T2V5Y*"=A=71H)RDL('-E<FEA;&EZ92@D8W)E
M9&5N=&EA;',I*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M971S(&$@=F%R:6%B;&4@:6X@=&AE('-E<W-I;VX@<V%Y:6YG('1H870@875T
M:&]R:7IA=&EO;B!H87,@<W5C8V5E9&5D+`H@("`@("H@;F]T92!W:&EC:"!U
M<V5R260@=V%S(&%U=&AO<FEZ960L(&%N9"!N;W1E('=H96X@=&AE(&QO9VEN
M('1O;VL@<&QA8V4N"B`@("`@*@H@("`@("H@268@82!U<V5R(&YA;64@:&]O
M:R!W87,@9&5F:6YE9"!I;B!T:&4@8V]N9FEG=7)A=&EO;BP@:70@9V5T<R!A
M<'!L:65D"B`@("`@*B!T;R!T:&4@=7-E<DED(&%T('1H:7,@<&]I;G0N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("`@("`@("`@("`@
M5&AE('5S97))9"!W:&\@:&%S(&)E96X@875T:&]R:7IE9"X*("`@("`J($!P
M87)A;2!A<G)A>2`D8W)E9&5N=&EA;',@("`@("`@(%1H92!C<F5D96YT:6%L
M<R!O9B!T:&4@=7-E<BX*("`@("`J($!P87)A;2!S=')I;F<@)')E86QM("`@
M("`@("`@("`@(%1H92!A=71H96YT:6-A=&EO;B!R96%L;2!T;R!U<V4N"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B`D8VAA;F=E4F5Q=65S=&5D("!7:&5T:&5R
M('1O(')E<75E<W0@=&AA="!T:&4@=7-E<B!C:&%N9V4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H96ER('!A<W-W;W)D+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!S971!=71H*"1U<V5R260L("1C<F5D96YT
M:6%L<RP@)')E86QM(#T@;G5L;"P@)&-H86YG95)E<75E<W1E9"`](&9A;'-E
M*0H@("`@>PH@("`@("`@("1U<V5R260@/2!T<FEM*"1U<V5R260I.PH@("`@
M("`@("1U<V5R260@/2!!=71H.CIA9&1(;V]K*"1U<V5R260I.PH*("`@("`@
M("`O*B!)9B!W92=R92!A;')E861Y('-E="!W:71H('1H:7,@=7-E<DED+"!D
M;VXG="!C;VYT:6YU92X@*B\*("`@("`@("!I9B`H:7-S970H)%]315-324].
M6R=?7V%U=&@G75LG=7-E<DED)UTI("8F"B`@("`@("`@("`@("1?4T534TE/
M3ELG7U]A=71H)UU;)W5S97))9"==(#T]("1U<V5R260I('L*("`@("`@("`@
M("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@+RH@0VQE87(@86YY(&5X
M:7-T:6YG(&EN9F\N("HO"B`@("`@("`@)'1H:7,M/F-L96%R075T:"@D<F5A
M;&TI.PH*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U-E8W)E="YP:'`G
M.PH@("`@("`@("1C<F5D96YT:6%L<R`](%-E8W)E=#HZ=W)I=&4H4V5C<F5T
M.CIG971+97DH)V%U=&@G*2P@<V5R:6%L:7IE*"1C<F5D96YT:6%L<RDI.PH*
M("`@("`@("!I9B`H(65M<'1Y*"1R96%L;2DI('L*("`@("`@("`@("`@)'5S
M97))9"`N/2`G0"<@+B`D<F5A;&T["B`@("`@("`@?0H*("`@("`@("`D7U-%
M4U-)3TY;)U]?875T:"==(#T@87)R87DH"B`@("`@("`@("`@("=A=71H96YT
M:6-A=&5D)R`]/B!T<G5E+`H@("`@("`@("`@("`G=7-E<DED)R`]/B`D=7-E
M<DED+`H@("`@("`@("`@("`G8W)E9&5N=&EA;',G(#T^("1C<F5D96YT:6%L
M<RP*("`@("`@("`@("`@)W)E86QM)R`]/B`D<F5A;&TL"B`@("`@("`@("`@
M("=T:6UE<W1A;7`G(#T^('1I;64H*2P*("`@("`@("`@("`@)W)E;6]T95]A
M9&1R)R`]/B!I<W-E="@D7U-%4E9%4ELG4D5-3U1%7T%$1%(G72D@/R`D7U-%
M4E9%4ELG4D5-3U1%7T%$1%(G72`Z(&YU;&PL"B`@("`@("`@("`@("=B<F]W
M<V5R)R`]/B`D1TQ/0D%,4ULG8G)O=W-E<B==+3YG971!9V5N=%-T<FEN9R@I
M+`H@("`@("`@("`@("`G8VAA;F=E4F5Q=65S=&5D)R`]/B`D8VAA;F=E4F5Q
M=65S=&5D"B`@("`@("`@*3L*"B`@("`@("`@+RH@4F5L;V%D('!R969E<F5N
M8V5S(&9O<B!T:&4@;F5W('5S97(N("HO"B`@("`@("`@)$=,3T)!3%-;)W)E
M9VES=')Y)UTM/FQO8610<F5F<R@I.PH@("`@("`@($Y,4SHZ<V5T3&%N9R@D
M1TQ/0D%,4ULG<')E9G,G72T^9V5T5F%L=64H)VQA;F=U86=E)RDI.PH*("`@
M("`@("`O*B!&971C:"!T:&4@=7-E<B=S(&QA<W0@;&]G:6X@=&EM92X@*B\*
M("`@("`@("`D;VQD7VQO9VEN(#T@0'5N<V5R:6%L:7IE*"1'3$]"04Q36R=P
M<F5F<R==+3YG971686QU92@G;&%S=%]L;V=I;B<I*3L*"B`@("`@("`@+RH@
M1&ES<&QA>2!I="P@:68@=V4@:&%V92!A(&YO=&EF:6-A=&EO;B!O8FIE8W0@
M86YD('1H90H@("`@("`@("`J('-H;W=?;&%S=%]L;V=I;B!P<F5F97)E;F-E
M(&ES(&%C=&EV92X@*B\*("`@("`@("!I9B`H:7-S970H)$=,3T)!3%-;)VYO
M=&EF:6-A=&EO;B==*2`F)B`D1TQ/0D%,4ULG<')E9G,G72T^9V5T5F%L=64H
M)W-H;W=?;&%S=%]L;V=I;B<I*2!["B`@("`@("`@("`@(&EF("AE;7!T>2@D
M;VQD7VQO9VEN6R=T:6UE)UTI*2!["B`@("`@("`@("`@("`@("`D1TQ/0D%,
M4ULG;F]T:69I8V%T:6]N)UTM/G!U<V@H7R@B3&%S="!L;V=I;CH@3F5V97(B
M*2P@)VAO<F1E+FUE<W-A9V4G*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@(&EF("AE;7!T>2@D;VQD7VQO9VEN6R=H;W-T)UTI*2![
M"B`@("`@("`@("`@("`@("`@("`@)$=,3T)!3%-;)VYO=&EF:6-A=&EO;B==
M+3YP=7-H*'-P<FEN=&8H7R@B3&%S="!L;V=I;CH@)7,B*2P@<W1R9G1I;64H
M)R5C)RP@)&]L9%]L;V=I;ELG=&EM92==*2DL("=H;W)D92YM97-S86=E)RD[
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("1'3$]"04Q36R=N;W1I9FEC871I;VXG72T^<'5S:"AS<')I;G1F*%\H(DQA
M<W0@;&]G:6XZ("5S(&9R;VT@)7,B*2P@<W1R9G1I;64H)R5C)RP@)&]L9%]L
M;V=I;ELG=&EM92==*2P@)&]L9%]L;V=I;ELG:&]S="==*2P@)VAO<F1E+FUE
M<W-A9V4G*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@+R\@4V5T('1H92!U<V5R)W,@;&%S=%]L;V=I;B!I
M;F9O<FUA=&EO;BX*("`@("`@("`D:&]S="`](&5M<'1Y*"1?4T525D526R=(
M5%107UA?1D]25T%21$5$7T9/4B==*0H@("`@("`@("`@("`_("1?4T525D52
M6R=214U/5$5?041$4B=="B`@("`@("`@("`@(#H@)%]315)615);)TA45%!?
M6%]&3U)705)$141?1D]2)UT["B`@("`@("`@)&QA<W1?;&]G:6X@/2!A<G)A
M>2@G=&EM92<@/3X@=&EM92@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)VAO<W0G(#T^($!G971H;W-T8GEA9&1R*"1H;W-T*2D["B`@("`@("`@
M)$=,3T)!3%-;)W!R969S)UTM/G-E=%9A;'5E*"=L87-T7VQO9VEN)RP@<V5R
M:6%L:7IE*"1L87-T7VQO9VEN*2D["@H@("`@("`@(&EF("@D8VAA;F=E4F5Q
M=65S=&5D*2!["B`@("`@("`@("`@("1'3$]"04Q36R=N;W1I9FEC871I;VXG
M72T^<'5S:"A?*")9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+B(I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAO<F1E
M+FUE<W-A9V4G*3L*("`@("`@("`@("`@:68@*"1T:&ES+3YH87-#87!A8FEL
M:71Y*"=U<&1A=&4G*2D@>PH@("`@("`@("`@("`@("`@+RH@02!B:70@;V8@
M82!K;'5D9V4N("!54DP@:7,@<V5T(&9R;VT@=&AE(&QO9VEN('-C<F5E;BP@
M8G5T"B`@("`@("`@("`@("`@("`@*B!W92!A<F5N)W0@8V]M<&QE=&5L>2!C
M97)T86EN('=E(&=O="!H97)E(&9R;VT@=&AE(&QO9VEN"B`@("`@("`@("`@
M("`@("`@*B!S8W)E96XN("!3;R!A;GD@<V-R965N('=H:6-H(&-A;&QS('-E
M=$%U=&@H*2!W:&EC:"!H87,@80H@("`@("`@("`@("`@("`@("H@=7)L('=I
M;&P@96YD('5P(&=O:6YG('1H97)E+B`@4VAO=6QD(&)E($]++B`J+PH@("`@
M("`@("`@("`@("`@)'5R;%]P87)A;2`](%5T:6PZ.F=E=$9O<FU$871A*"=U
M<FPG*3L*"B`@("`@("`@("`@("`@("!I9B`H)'5R;%]P87)A;2D@>PH@("`@
M("`@("`@("`@("`@("`@("1U<FP@/2!(;W)D93HZ=7)L*%5T:6PZ.G)E;6]V
M95!A<F%M971E<B@D=7)L7W!A<F%M+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S97-S:6]N
M7VYA;64H*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@=')U92D["B`@("`@("`@("`@("`@("`@("`@)')E='5R;E]T;R`]("1'
M3$]"04Q36R=R96=I<W1R>2==+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<O:6YD97@N<&AP
M)SL*("`@("`@("`@("`@("`@("`@("`D<F5T=7)N7W1O(#T@571I;#HZ861D
M4&%R86UE=&5R*"1R971U<FY?=&\L("=U<FPG+"`D=7)L*3L*("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)')E='5R;E]T
M;R`]($AO<F1E.CIU<FPH)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B
M<F]O="<L("=H;W)D92<I"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("X@)R]I;F1E>"YP:'`G*3L*("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("`@("`D=7)L(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`G*3L*("`@("`@("`@("`@("`@("1U
M<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W)E='5R;E]T;R<@
M/3X@)')E='5R;E]T;RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&YU;&PL(&9A;'-E*3L*"B`@("`@("`@("`@("`@("!H
M96%D97(H)TQO8V%T:6]N.B`G("X@)'5R;"D["B`@("`@("`@("`@("`@("!E
M>&ET.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@0VQE87)S(&%N>2!A=71H96YT:6-A=&EO;B!T;VME;G,@:6X@=&AE
M(&-U<G)E;G0@<V5S<VEO;BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1R96%L;2`@5&AE(&%U=&AE;G1I8V%T:6]N(')E86QM('1O(&-L96%R+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!C;&5A<D%U=&@H)')E86QM(#T@;G5L;"D*
M("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1R96%L;2D@)B8@:7-S970H)%]3
M15-324].6R=?7V%U=&@G75LD<F5A;&U=*2D@>PH@("`@("`@("`@("`D7U-%
M4U-)3TY;)U]?875T:"==6R1R96%L;5T@/2!A<G)A>2@I.PH@("`@("`@("`@
M("`D7U-%4U-)3TY;)U]?875T:"==6R1R96%L;5U;)V%U=&AE;G1I8V%T960G
M72`](&9A;'-E.PH@("`@("`@('T@96QS96EF("AI<W-E="@D7U-%4U-)3TY;
M)U]?875T:"==*2D@>PH@("`@("`@("`@("`D7U-%4U-)3TY;)U]?875T:"==
M(#T@87)R87DH*3L*("`@("`@("`@("`@)%]315-324].6R=?7V%U=&@G75LG
M875T:&5N=&EC871E9"==(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O
M*B!296UO=F4@=&AE('5S97(G<R!C86-H960@<')E9F5R96YC97,@:68@=&AE
M>2!A<F4@<')E<V5N="X@*B\*("`@("`@("!I9B`H:7-S970H)$=,3T)!3%-;
M)W)E9VES=')Y)UTI*2!["B`@("`@("`@("`@("1'3$]"04Q36R=R96=I<W1R
M>2==+3YU;FQO8610<F5F<R@I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($ES('1H92!C=7)R96YT('5S97(@86X@861M:6YI<W1R871O<C\*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P97)M:7-S:6]N("!!;&QO
M=R!U<V5R<R!W:71H('1H:7,@<&5R;6ES<VEO;B!A9&UI;B!A8V-E<W,*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EN('1H92!C=7)R96YT
M(&-O;G1E>'0N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<&5R;6QE=F5L("!4
M:&4@;&5V96P@;V8@<&5R;6ES<VEO;G,@=&\@8VAE8VL@9F]R"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`H4$5235-?141)5"P@4$5235-?
M1$5,151%+"!E=&,I+B!$969A=6QT<PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@=&\@4$5235-?141)5"X*("`@("`J($!P87)A;2!S=')I
M;F<@)'5S97(@("`@("`@(%1H92!U<V5R('1O(&-H96-K+B!$969A=6QT<R!T
M;R!!=71H.CIG971!=71H*"DN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M96%N("!7:&5T:&5R(&]R(&YO="!T:&ES(&ES(&%N(&%D;6EN('5S97(N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&ES061M:6XH)'!E<FUI<W-I;VX@/2!N=6QL
M+"`D<&5R;6QE=F5L(#T@;G5L;"P@)'5S97(@/2!N=6QL*0H@("`@>PH@("`@
M("`@(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@:68@*"1U<V5R(#T]/2!N=6QL
M*2!["B`@("`@("`@("`@("1U<V5R(#T@075T:#HZ9V5T075T:"@I.PH@("`@
M("`@('T*"B`@("`@("`@:68@*$!I<U]A<G)A>2@D8V]N9ELG875T:"==6R=A
M9&UI;G,G72DI('L*("`@("`@("`@("`@:68@*"1U<V5R("8F(&EN7V%R<F%Y
M*"1U<V5R+"`D8V]N9ELG875T:"==6R=A9&UI;G,G72DI('L*("`@("`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!I9B`H(6ES7VYU;&PH)'!E<FUI<W-I;VXI*2!["B`@("`@("`@
M("`@(&EF("AI<U]N=6QL*"1P97)M;&5V96PI*2!["B`@("`@("`@("`@("`@
M("`D<&5R;6QE=F5L(#T@4$5235-?141)5#L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!R971U<FX@)$=,3T)!3%-;)W!E<FUS)UTM/FAA<U!E<FUI<W-I
M;VXH)'!E<FUI<W-I;VXL("1U<V5R+"`D<&5R;6QE=F5L*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J
M($%P<&QI97,@82!H;V]K(&1E9FEN960@8GD@=&AE(&9U;F-T:6]N(%]U<V5R
M;F%M95]H;V]K7V9R;VUB86-K96YD*"D@=&\*("`@("`J('1H92!G:79E;B!U
M<V5R(&YA;64@:68@=&AI<R!F=6YC=&EO;B!E>&ES=',@86YD('5S97(@:&]O
M:W,@87)E(&5N86)L960N"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@<VAO
M=6QD(&)E(&-A;&QE9"!I9B!A(&)A8VME;F0G<R!U<V5R(&YA;64@;F5E9',@
M=&\@8F4*("`@("`J(&-O;G9E<G1E9"!T;R!A("AU;FEQ=64I($AO<F1E('5S
M97(@;F%M92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@
M(%1H92!O<FEG:6YA;"!U<V5R(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!U<V5R(&YA;64@=VET:"!T:&4@:&]O:R!A<'!L:65D
M('1O(&ET+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1(;V]K*"1U<V5R260I
M"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("!I9B`H(65M
M<'1Y*"1C;VYF6R=H;V]K<R==6R=U<V5R;F%M92==*2D@>PH@("`@("`@("`@
M("!R97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O8V]N9FEG+VAO;VMS+G!H
M<"<["B`@("`@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)U]U<V5R;F%M
M95]H;V]K7V9R;VUB86-K96YD)RDI('L*("`@("`@("`@("`@("`@("1U<V5R
M260@/2!C86QL7W5S97)?9G5N8R@G7W5S97)N86UE7VAO;VM?9G)O;6)A8VME
M;F0G+"`D=7-E<DED*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1U<V5R260["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!<'!L
M:65S(&$@:&]O:R!D969I;F5D(&)Y('1H92!F=6YC=&EO;B!?=7-E<FYA;65?
M:&]O:U]T;V)A8VME;F0H*2!T;PH@("`@("H@=&AE(&=I=F5N('5S97(@;F%M
M92!I9B!T:&ES(&9U;F-T:6]N(&5X:7-T<R!A;F0@=7-E<B!H;V]K<R!A<F4@
M96YA8FQE9"X*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!S:&]U;&0@8F4@
M8V%L;&5D(&EF(&$@2&]R9&4@=7-E<B!N86UE(&YE961S('1O(&)E(&-O;G9E
M<G1E9`H@("`@("H@=&\@82!B86-K96YD)W,@=7-E<B!N86UE(&]R(&1I<W!L
M87EE9"!T;R!T:&4@=7-E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1U<V5R260@(%1H92!(;W)D92!U<V5R(&YA;64N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!U<V5R(&YA;64@=VET:"!T:&4@:&]O:R!A
M<'!L:65D('1O(&ET+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F5(;V]K
M*"1U<V5R260I"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@
M("!I9B`H(65M<'1Y*"1C;VYF6R=H;V]K<R==6R=U<V5R;F%M92==*2D@>PH@
M("`@("`@("`@("!R97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O8V]N9FEG
M+VAO;VMS+G!H<"<["B`@("`@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H
M)U]U<V5R;F%M95]H;V]K7W1O8F%C:V5N9"<I*2!["B`@("`@("`@("`@("`@
M("`D=7-E<DED(#T@8V%L;%]U<V5R7V9U;F,H)U]U<V5R;F%M95]H;V]K7W1O
M8F%C:V5N9"<L("1U<V5R260I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)'5S97))9#L*("`@('T*"B`@("`O*BH*("`@("`J
M(%%U97)I97,@=&AE(&-U<G)E;G0@075T:"!O8FIE8W0@=&\@9FEN9"!O=70@
M:68@:70@<W5P<&]R=',@=&AE(&=I=F5N"B`@("`@*B!C87!A8FEL:71Y+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-A<&%B:6QI='D@(%1H92!C
M87!A8FEL:71Y('1O('1E<W0@9F]R+@H@("`@("H*("`@("`J($!R971U<FX@
M8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&-A<&%B:6QI='D@:7,@<W5P
M<&]R=&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!H87-#87!A8FEL:71Y*"1C
M87!A8FEL:71Y*0H@("`@>PH@("`@("`@(')E='5R;B`A96UP='DH)'1H:7,M
M/F-A<&%B:6QI=&EE<ULD8V%P86)I;&ET>5TI.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@55))(&]F('1H92!L;V=I;B!S8W)E96X@9F]R
M('1H92!C=7)R96YT(&%U=&AE;G1I8V%T:6]N"B`@("`@*B!M971H;V0N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D87!P("!4:&4@87!P;&EC871I
M;VX@=&\@=7-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7)L("!4:&4@55),
M('1O(')E9&ER96-T('1O(&%F=&5R(&QO9VEN+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@;&]G:6X@<V-R965N(%5222X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T3&]G:6Y38W)E96XH)&%P<"`]("=H;W)D92<L("1U
M<FP@/2`G)RD*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["B`@("`@("`@
M)&%U=&@@/2`F075T:#HZ<VEN9VQE=&]N*"1C;VYF6R=A=71H)UU;)V1R:79E
M<B==*3L*("`@("`@("!R971U<FX@)&%U=&@M/E]G971,;V=I;E-C<F5E;B@D
M87!P+"`D=7)L*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE
M(&YA;65D('!A<F%M971E<B!F;W(@=&AE(&-U<G)E;G0@875T:"!D<FEV97(N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%R86T@(%1H92!P87)A
M;65T97(@=&\@9F5T8V@N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!P87)A;65T97(G<R!V86QU92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T4&%R86TH)'!A<F%M*0H@("`@>PH@("`@("`@(')E='5R;B!I<W-E="@D
M=&AI<RT^7W!A<F%M<ULD<&%R86U=*2`_("1T:&ES+3Y?<&%R86US6R1P87)A
M;5T@.B!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M;F%M92!O9B!T:&4@875T:&5N=&EC871I;VX@<')O=FED97(N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D9')I=F5R("!5<V5D(&)Y(')E8W5R<VEV
M92!C86QL<R!W:&5N('5N=&%N9VQI;F<@8V]M<&]S:71E"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@(&%U=&@N"B`@("`@*B!`<&%R86T@87)R87D@
M("1P87)A;7,@(%5S960@8GD@<F5C=7)S:79E(&-A;&QS('=H96X@=6YT86YG
M;&EN9R!C;VUP;W-I=&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M875T:"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&YA;64@
M;V8@=&AE(&1R:79E<B!C=7)R96YT;'D@<')O=FED:6YG"B`@("`@*B`@("`@
M("`@("`@("`@("`@875T:&5N=&EC871I;VXN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=%!R;W9I9&5R*"1D<FEV97(@/2!N=6QL+"`D<&%R86US(#T@;G5L
M;"D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@(&EF("AI
M<U]N=6QL*"1D<FEV97(I*2!["B`@("`@("`@("`@("1D<FEV97(@/2`D8V]N
M9ELG875T:"==6R=D<FEV97(G73L*("`@("`@("!]"B`@("`@("`@:68@*&ES
M7VYU;&PH)'!A<F%M<RDI('L*("`@("`@("`@("`@)'!A<F%M<R`]($AO<F1E
M.CIG971$<FEV97)#;VYF:6<H)V%U=&@G+`H@("`@("`@("`@("`@("`@:7-?
M87)R87DH)&1R:79E<BD@/R`D9')I=F5R6S%=(#H@)&1R:79E<BD["B`@("`@
M("`@?0H*("`@("`@("!I9B`H)&1R:79E<B`]/2`G87!P;&EC871I;VXG*2![
M"B`@("`@("`@("`@(')E='5R;B!I<W-E="@D<&%R86US6R=A<'`G72D@/R`D
M<&%R86US6R=A<'`G72`Z("=A<'!L:6-A=&EO;B<["B`@("`@("`@?2!E;'-E
M:68@*"1D<FEV97(@/3T@)V-O;7!O<VET92<I('L*("`@("`@("`@("`@:68@
M*"@D;&]G:6Y?9')I=F5R(#T@075T:#HZ7V=E=$1R:79E<D)Y4&%R86TH)VQO
M9VEN<V-R965N7W-W:71C:"<L("1P87)A;7,I*2`F)@H@("`@("`@("`@("`@
M("`@(65M<'1Y*"1P87)A;7-;)V1R:79E<G,G75LD;&]G:6Y?9')I=F5R72DI
M('L*("`@("`@("`@("`@("`@(')E='5R;B!!=71H.CIG9710<F]V:61E<B@D
M<&%R86US6R=D<FEV97)S)UU;)&QO9VEN7V1R:79E<EU;)V1R:79E<B==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&ES<V5T
M*"1P87)A;7-;)V1R:79E<G,G75LD;&]G:6Y?9')I=F5R75LG<&%R86US)UTI
M(#\@)'!A<F%M<ULG9')I=F5R<R==6R1L;V=I;E]D<FEV97)=6R=P87)A;7,G
M72`Z(&YU;&PI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`G
M8V]M<&]S:71E)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U
M<FX@)&1R:79E<CL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!L;V=O=70@<F5A<V]N+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG($]N92!O9B!T:&4@;&]G;W5T(')E87-O;G,@*'-E92!T:&4@
M05542%],3T=/551?*@H@("`@("H@("`@("`@("`@("`@("`@8V]N<W1A;G1S
M(&9O<B!T:&4@=F%L:60@<F5A<V]N<RDN("!2971U<FYS(&YU;&P@:68@=&AE
M<F4*("`@("`J("`@("`@("`@("`@("`@(&ES(&YO(&QO9V]U="!R96%S;VX@
M<')E<V5N="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3&]G;W5T4F5A<V]N
M*"D*("`@('L*("`@("`@("!I9B`H:7-S970H)$=,3T)!3%-;)U]?875T:&5R
M<F]R)UU;)W1Y<&4G72DI('L*("`@("`@("`@("`@<F5T=7)N("1'3$]"04Q3
M6R=?7V%U=&AE<G)O<B==6R=T>7!E)UT["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<F5T=7)N(%5T:6PZ.F=E=$9O<FU$871A*$%55$A?4D5!4T].
M7U!!4D%-*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS('1H92!S=&%T=7,@<W1R:6YG('1O('5S92!F;W(@;&]G;W5T(&UE<W-A
M9V5S+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;&]G;W5T
M(')E87-O;B!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$QO9V]U
M=%)E87-O;E-T<FEN9R@I"B`@("!["B`@("`@("`@<W=I=&-H("A!=71H.CIG
M971,;V=O=71296%S;VXH*2D@>PH@("`@("`@(&-A<V4@05542%]214%33TY?
M4T534TE/3CH*("`@("`@("`@("`@)'1E>'0@/2!S<')I;G1F*%\H(EEO=7(@
M)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(I
M+"`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=N86UE)RDI.PH@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!!551(7U)%05-/3E]315-324].
M25`Z"B`@("`@("`@("`@("1T97AT(#T@<W!R:6YT9BA?*")9;W5R($EN=&5R
M;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O
M9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@
M>6]U(&UU<W0@;&]G:6X@86=A:6XN(BDL("1'3$]"04Q36R=R96=I<W1R>2==
M+3YG970H)VYA;64G*2D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C
M87-E($%55$A?4D5!4T].7T)23U=315(Z"B`@("`@("`@("`@("1T97AT(#T@
M<W!R:6YT9BA?*")9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG
M960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O
M('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN
M(BDL("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)VYA;64G*2D["B`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("!C87-E($%55$A?4D5!4T].7TQ/1T]5
M5#H*("`@("`@("`@("`@)'1E>'0@/2!?*")9;W4@:&%V92!B965N(&QO9V=E
M9"!O=70N(BD["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E($%5
M5$A?4D5!4T].7T9!24Q%1#H*("`@("`@("`@("`@)'1E>'0@/2!?*"),;V=I
M;B!F86EL960N(BD["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E
M($%55$A?4D5!4T].7T)!1$Q/1TE..@H@("`@("`@("`@("`D=&5X="`](%\H
M(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O
M<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(BD["B`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("!C87-E($%55$A?4D5!4T].7T584$E2140Z"B`@("`@
M("`@("`@("1T97AT(#T@7R@B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB*3L*
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@05542%]214%33TY?
M34534T%'13H*("`@("`@("`@("`@:68@*&ES<V5T*"1'3$]"04Q36R=?7V%U
M=&AE<G)O<B==6R=M<V<G72DI('L*("`@("`@("`@("`@("`@("1T97AT(#T@
M)$=,3T)!3%-;)U]?875T:&5R<F]R)UU;)VUS9R==.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)'1E>'0@/2!5=&EL.CIG971&;W)M
M1&%T82A!551(7U)%05-/3E]-4T=?4$%204TI.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@
M("`D=&5X="`]("<G.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D=&5X=#L*("`@('T*"B`@("`O*BH*("`@("`J($=E
M;F5R871E<R!T:&4@8V]R<F5C="!P87)A;65T97)S('1O('!A<W,@=&\@=&AE
M(&=I=F5N(&QO9V]U="!54DPN"B`@("`@*@H@("`@("H@268@;F\@<F5A<V]N
M+VUS9R!I<R!P87-S960@:6XL('5S92!T:&4@8W5R<F5N="!G;&]B86P@875T
M:&5N=&EC871I;VX*("`@("`J(&5R<F]R(&UE<W-A9V4N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=7)L("`@("!4:&4@55),('1O(')E9&ER96-T
M('1O+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<F5A<V]N("!4:&4@<F5A<V]N
M(&9O<B!L;V=O=70N"B`@("`@*B!`<&%R86T@<W1R:6YG("1M<V<@("`@($EF
M(')E87-O;B!I<R!!551(7U)%05-/3E]-15-304=%+"!T:&4@;65S<V%G92!T
M;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!D:7-P;&%Y('1O('1H
M92!U<V5R+@H@("`@("H@0')E='5R;B!S=')I;F<@5&AE(&9O<FUA='1E9"!5
M4DP*("`@("`J+PH@("`@9G5N8W1I;VX@861D3&]G;W5T4&%R86UE=&5R<R@D
M=7)L+"`D<F5A<V]N(#T@;G5L;"P@)&US9R`](&YU;&PI"B`@("!["B`@("`@
M("`@:68@*&ES7VYU;&PH)')E87-O;BDI('L*("`@("`@("`@("`@)')E87-O
M;B`]($%U=&@Z.F=E=$QO9V]U=%)E87-O;B@I.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"1R96%S;VXI('L*("`@("`@("`@("`@)'5R;"`](%5T:6PZ.F%D
M9%!A<F%M971E<B@D=7)L+"!!551(7U)%05-/3E]005)!32P@)')E87-O;BP@
M9F%L<V4I.PH@("`@("`@("`@("!I9B`H)')E87-O;B`]/2!!551(7U)%05-/
M3E]-15-304=%*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?;G5L;"@D;7-G
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1M<V<@/2!!=71H.CIG971,;V=O
M=71296%S;VY3=')I;F<H*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@05542%]2
M14%33TY?35-'7U!!4D%-+"`D;7-G+"!F86QS92D["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=7)L.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!T:&4@55))(&]F('1H92!L;V=I;B!S8W)E96X@
M9F]R('1H:7,@875T:&5N=&EC871I;VX@;V)J96-T+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&%P<"`@5&AE(&%P<&QI8V%T:6]N('1O('5S92X*("`@("`J($!P87)A;2!S
M=')I;F<@)'5R;"`@5&AE(%523"!T;R!R961I<F5C="!T;R!A9G1E<B!L;V=I
M;BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&QO9VEN('-C
M<F5E;B!54DDN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971,;V=I;E-C<F5E
M;B@D87!P(#T@)VAO<F1E)RP@)'5R;"`]("<G*0H@("`@>PH@("`@("`@("1L
M;V=I;B`]($AO<F1E.CIU<FPH)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G
M=V5B<F]O="<L("1A<'`I("X@)R]L;V=I;BYP:'`G+"!T<G5E*3L*("`@("`@
M("!I9B`H(65M<'1Y*"1U<FPI*2!["B`@("`@("`@("`@("1L;V=I;B`](%5T
M:6PZ.F%D9%!A<F%M971E<B@D;&]G:6XL("=U<FPG+"`D=7)L*3L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1L;V=I;CL*("`@('T*"B`@("`O*BH*("`@
M("`J($%U=&AE;G1I8V%T:6]N('-T=6(N"B`@("`@*@H@("`@("H@0&%B<W1R
M86-T"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@($9A;'-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?875T
M:&5N=&EC871E*"D*("`@('L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!E<G)O<B!M97-S86=E(&9O<B!A
M;B!I;G9A;&ED(&%U=&AE;G1I8V%T:6]N+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@
M(%1H92!T>7!E(&]F(&5R<F]R("A!551(7U)%05-/3B!C;VYS=&%N="DN"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1M<V<@("!4:&4@97)R;W(@;65S<V%G92]R
M96%S;VX@9F]R(&EN=F%L:60*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M(&%U=&AE;G1I8V%T:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<V5T075T
M:$5R<F]R*"1T>7!E+"`D;7-G(#T@;G5L;"D*("`@('L*("`@("`@("`D1TQ/
M0D%,4ULG7U]A=71H97)R;W(G72`](&%R<F%Y*"D["B`@("`@("`@)$=,3T)!
M3%-;)U]?875T:&5R<F]R)UU;)W1Y<&4G72`]("1T>7!E.PH@("`@("`@("1'
M3$]"04Q36R=?7V%U=&AE<G)O<B==6R=M<V<G72`]("1M<V<["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!E<G)O<B!T>7!E(&9O<B!A;B!I
M;G9A;&ED(&%U=&AE;G1I8V%T:6]N(&]R(&9A;'-E(&]N(&5R<F]R+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@17)R;W(@='EP92!O<B!F86QS92!O;B!E<G)O<@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?9V5T075T:$5R<F]R*"D*("`@('L*("`@("`@("!I
M9B`H:7-S970H)$=,3T)!3%-;)U]?875T:&5R<F]R)UU;)W1Y<&4G72DI('L*
M("`@("`@("`@("`@<F5T=7)N("1'3$]"04Q36R=?7V%U=&AE<G)O<B==6R=T
M>7!E)UT["B`@("`@("`@?0H*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!A<'!R;W!R:6%T92!A=71H
M96YT:6-A=&EO;B!D<FEV97(L(&EF(&%N>2P@<V5L96-T:6YG(&)Y('1H90H@
M("`@("H@<W!E8VEF:65D('!A<F%M971E<BX*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE
M("`@("`@("`@(%1H92!P87)A;65T97(@;F%M92X*("`@("`J($!P87)A;2!A
M<G)A>2`D<&%R86US("`@("`@("`@5&AE('!A<F%M971E<B!L:7-T+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D9')I=F5R<&%R86US("!!(&QI<W0@;V8@<&%R
M86UE=&5R<R!T;R!P87-S('1O('1H92!D<FEV97(N"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"!2971U<FX@=F%L=64@;W(@8V%L;&5D('5S97(@9G5N
M8R!O<B!N=6QL(&EF('5N879A:6QA8FQE"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]G971$<FEV97)">5!A<F%M*"1N86UE+"`D<&%R86US+"`D9')I=F5R<&%R
M86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H:7-S970H)'!A<F%M
M<ULD;F%M95TI("8F"B`@("`@("`@("`@(&9U;F-T:6]N7V5X:7-T<R@D<&%R
M86US6R1N86UE72DI('L*("`@("`@("`@("`@<F5T=7)N(&-A;&Q?=7-E<E]F
M=6YC7V%R<F%Y*"1P87)A;7-;)&YA;65=+"`D9')I=F5R<&%R86US*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!N=6QL.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4&5R9F]R;7,@8VAE8VL@;VX@<V5S<VEO;B!T;R!S964@:68@25`@
M061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4*("`@("`J(&QA<W0@86-C
M97-S+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!)4"!!9&1R97-S(&ES('1H
M92!S86UE("AO<B!T:&4@8VAE8VL@:7,*("`@("`J("`@("`@("`@("`@("`@
M("`@9&ES86)L960I+"!F86QS92!I9B!T:&4@861D<F5S<R!H87,@8VAA;F=E
M9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V-H96-K4V5S<VEO;DE0*"D*("`@
M('L*("`@("`@("!R971U<FX@*&5M<'1Y*"1'3$]"04Q36R=C;VYF)UU;)V%U
M=&@G75LG8VAE8VMI<"==*2!\?`H@("`@("`@("`@("`@("`@*&ES<V5T*"1?
M4T534TE/3ELG7U]A=71H)UU;)W)E;6]T95]A9&1R)UTI("8F("1?4T534TE/
M3ELG7U]A=71H)UU;)W)E;6]T95]A9&1R)UT@/3T@)%]315)615);)U)%34]4
M15]!1$12)UTI*3L*("`@('T*"B`@("`O*BH*("`@("`J(%!E<F9O<FUS(&-H
M96-K(&]N('-E<W-I;VX@=&\@<V5E(&EF(&)R;W=S97(@<W1R:6YG(&AA<R!C
M:&%N9V5D('-I;F-E"B`@("`@*B!T:&4@;&%S="!A8V-E<W,N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!4<G5E(&EF(&)R;W=S97(@<W1R:6YG(&ES('1H92!S86UE+"!F
M86QS92!I9B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@<W1R:6YG(&AA
M<R!C:&%N9V5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8VAE8VM"<F]W<V5R
M4W1R:6YG*"D*("`@('L*("`@("`@("!R971U<FX@*&5M<'1Y*"1'3$]"04Q3
M6R=C;VYF)UU;)V%U=&@G75LG8VAE8VMB<F]W<V5R)UTI('Q\"B`@("`@("`@
M("`@("`@("`D7U-%4U-)3TY;)U]?875T:"==6R=B<F]W<V5R)UT@/3T@)$=,
M3T)!3%-;)V)R;W=S97(G72T^9V5T06=E;G13=')I;F<H*2D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#;VYV97)T<R!T;R!A;&QO=V5D(#8T(&-H87)A8W1E
M<G,@9F]R($%04DU$-2!P87-S=V]R9',N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'9A;'5E
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]U;G0*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@)'9A;'5E(&-O;G9E<G1E9"!T;R!T:&4@-C0@340U
M(&-H87)A8W1E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]T;T%04DU$-2@D
M=F%L=64L("1C;W5N="D*("`@('L*("`@("`@("`O*B`V-"!C:&%R86-T97)S
M('1H870@87)E('9A;&ED(&9O<B!!4%)-1#4@<&%S<W=O<F1S+B`J+PH@("`@
M("`@("1!4%)-1#4@/2`G+B\P,3(S-#4V-S@Y04)#1$5&1TA)2DM,34Y/4%%2
M4U155E=865IA8F-D969G:&EJ:VQM;F]P<7)S='5V=WAY>B<["@H@("`@("`@
M("1A<')M9#4@/2`G)SL*("`@("`@("`D8V]U;G0@/2!A8G,H)&-O=6YT*3L*
M("`@("`@("!W:&EL92`H+2TD8V]U;G0I('L*("`@("`@("`@("`@)&%P<FUD
M-2`N/2`D05!2340U6R1V86QU92`F(#!X,V9=.PH@("`@("`@("`@("`D=F%L
M=64@/CX](#8["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D87!R;60U.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R=',@:&5X861E8VEM86P@<W1R
M:6YG('1O(&)I;F%R>2!D871A+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&AE>"`@2&5X(&1A
M=&$N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($)I;F%R>2!D871A
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8FEN*"1H97@I"B`@("!["B`@("`@
M("`@)&)I;B`]("<G.PH@("`@("`@("1L96YG=&@@/2!S=')L96XH)&AE>"D[
M"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&QE;F=T:#L@)&D@*ST@,BD@
M>PH@("`@("`@("`@("`D=&UP(#T@<W-C86YF*'-U8G-T<B@D:&5X+"`D:2P@
M,BDL("<E>"<I.PH@("`@("`@("`@("`D8FEN("X](&-H<BAA<G)A>5]S:&EF
M="@D=&UP*2D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D8FEN.PH@("`@
M?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E
M=&4@075T:"!I;G-T86YC92!B87-E9"!O;B`D9')I=F5R+@H@("`@("H*("`@
M("`J($!P87)A;2!M:7AE9"`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T
M92!!=71H('-U8F-L87-S('1O(')E='5R;BX@5&AI<PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@(&ES(&)A<V5D(&]N('1H92!S=&]R86=E(&1R:79E
M<B`H)&1R:79E<BDN(%1H92!C;V1E"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@:7,@9'EN86UI8V%L;'D@:6YC;'5D960N($EF("1D<FEV97(@:7,@
M86X@87)R87DL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@=&AE;B!W
M92!W:6QL(&QO;VL@:6X@)&1R:79E<ELP72]L:6(O075T:"\@9F]R('1H90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@('-U8F-L87-S(&EM<&QE;65N
M=&%T:6]N(&YA;65D("1D<FEV97);,5TN<&AP+@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L
M(&-O;F9I9W5R871I;VX@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!C;VYN96-T:6]N('!A<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D
M+@H@("`@("H*("`@("`J($!R971U<FX@075T:"`@5&AE(&YE=VQY(&-R96%T
M960@8V]N8W)E=&4@075T:"!I;G-T86YC92P@;W(@9F%L<V4@;VX@86X*("`@
M("`J("`@("`@("`@("`@("`@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9F86-T;W)Y*"1D<FEV97(L("1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@
M("`@(&EF("AI<U]A<G)A>2@D9')I=F5R*2D@>PH@("`@("`@("`@("`D87!P
M(#T@)&1R:79E<ELP73L*("`@("`@("`@("`@)&1R:79E<B`]("1D<FEV97);
M,5T["B`@("`@("`@?0H*("`@("`@("`D9')I=F5R(#T@8F%S96YA;64H)&1R
M:79E<BD["@H@("`@("`@(&EF("AE;7!T>2@D9')I=F5R*2!\?"`H)&1R:79E
M<B`]/2`G;F]N92<I*2!["B`@("`@("`@("`@("1A=71H(#T@)FYE=R!!=71H
M*"D["B`@("`@("`@("`@(')E='5R;B`D875T:#L*("`@("`@("!]"@H@("`@
M("`@(&EF("AI<U]N=6QL*"1P87)A;7,I*2!["B`@("`@("`@("`@("1P87)A
M;7,@/2!(;W)D93HZ9V5T1')I=F5R0V]N9FEG*"=A=71H)RP@)&1R:79E<BD[
M"B`@("`@("`@?0H*("`@("`@("!I;FE?<V5T*"=T<F%C:U]E<G)O<G,G+"`Q
M*3L*("`@("`@("`D:6YC;'5D95]E<G)O<B`]("<G.PH@("`@("`@(&EF("@A
M96UP='DH)&%P<"DI('L*("`@("`@("`@("`@0&EN8VQU9&5?;VYC92`D1TQ/
M0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=F:6QE<F]O="<L("1A<'`I("X@)R]L
M:6(O075T:"\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!`:6YC;'5D95]O;F-E("=(;W)D92]!=71H+R<@+B`D
M9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T*("`@("`@("!I9B`H:7-S970H
M)'!H<%]E<G)O<FUS9RDI('L*("`@("`@("`@("`@)&EN8VQU9&5?97)R;W(@
M/2`D<&AP7V5R<F]R;7-G.PH@("`@("`@('T*("`@("`@("!I;FE?<F5S=&]R
M92@G=')A8VM?97)R;W)S)RD["@H@("`@("`@("1C;&%S<R`]("=!=71H7R<@
M+B`D9')I=F5R.PH@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@
M>PH@("`@("`@("`@("`D875T:"`]("9N97<@)&-L87-S*"1P87)A;7,I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1A=71H(#T@4$5!4CHZ<F%I
M<V5%<G)O<B@G075T:"!$<FEV97(@*"<@+B`D8VQA<W,@+B`G*2!N;W0@9F]U
M;F0G("X@*"1I;F-L=61E7V5R<F]R(#\@)SH@)R`N("1I;F-L=61E7V5R<F]R
M(#H@)R<I("X@)RXG*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D875T
M:#L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A
M(')E9F5R96YC92!T;R!A(&-O;F-R971E($%U=&@@:6YS=&%N8V4@8F%S960@
M;VX*("`@("`J("1D<FEV97(N($ET('=I;&P@;VYL>2!C<F5A=&4@82!N97<@
M:6YS=&%N8V4@:68@;F\@075T:"!I;G-T86YC92!W:71H"B`@("`@*B!T:&4@
M<V%M92!P87)A;65T97)S(&-U<G)E;G1L>2!E>&ES=',N"B`@("`@*@H@("`@
M("H@5&AI<R!S:&]U;&0@8F4@=7-E9"!I9B!M=6QT:7!L92!A=71H96YT:6-A
M=&EO;B!S;W5R8V5S("AA;F0L('1H=7,L"B`@("`@*B!M=6QT:7!L92!!=71H
M(&EN<W1A;F-E<RD@87)E(')E<75I<F5D+@H@("`@("H*("`@("`J(%1H:7,@
M;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH@)'9A<B`]("9!=71H.CIS:6YG
M;&5T;VXH*0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1R:79E<B`@
M5&AE('1Y<&4@;V8@8V]N8W)E=&4@075T:"!S=6)C;&%S<R!T;R!R971U<FXN
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(%1H:7,@:7,@8F%S960@
M;VX@=&AE('-T;W)A9V4@9')I=F5R("@D9')I=F5R*2X*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@5&AE(&-O9&4@:7,@9'EN86UI8V%L;'D@:6YC
M;'5D960N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@($$@:&%S:"!C
M;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@;W(*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P87)A;65T
M97)S(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T
M=7)N($%U=&@@(%1H92!C;VYC<F5T92!!=71H(')E9F5R96YC92P@;W(@9F%L
M<V4@;VX@86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T
M;VXH)&1R:79E<BP@)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@<W1A
M=&EC("1I;G-T86YC97,@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H:7-?;G5L
M;"@D<&%R86US*2D@>PH@("`@("`@("`@("`D<&%R86US(#T@2&]R9&4Z.F=E
M=$1R:79E<D-O;F9I9R@G875T:"<L"B`@("`@("`@("`@("`@("!I<U]A<G)A
M>2@D9')I=F5R*2`_("1D<FEV97);,5T@.B`D9')I=F5R*3L*("`@("`@("!]
M"@H@("`@("`@("1S:6=N871U<F4@/2!S97)I86QI>F4H87)R87DH)&1R:79E
M<BP@)'!A<F%M<RDI.PH@("`@("`@(&EF("AE;7!T>2@D:6YS=&%N8V5S6R1S
M:6=N871U<F5=*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S6R1S:6=N871U
M<F5=(#T@)D%U=&@Z.F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M<RD["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&EN<W1A;F-E<ULD<VEG;F%T=7)E73L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TAI<W1O<GDN<&AP````````````
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#(V-#(U(#$P-3$U-#,S
M-S0P(#`R,34R-P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@5&AE($AI<W1O<GDZ.B!C;&%S<R!P<F]V
M:61E<R!A(&UE=&AO9"!O9B!T<F%C:VEN9R!C:&%N9V5S(&EN($AO<F1E"B`J
M(&]B:F5C=',L('-T;W)E9"!I;B!A(%-13"!T86)L92X*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO2&ES=&]R>2](:7-T;W)Y+G!H<"QV(#$N,C@N,BXQ-"`R
M,#`V+S`U+S`S(#(Q.C0V.C$S(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,C`P,RTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#(N,0H@*B!`<&%C
M:V%G92!(;W)D95](:7-T;W)Y"B`J+PIC;&%S<R!(;W)D95](:7-T;W)Y('L*
M"B`@("`O*BH*("`@("`J(%!O:6YT97(@=&\@82!$0B!I;G-T86YC92!T;R!M
M86YA9V4@=&AE(&AI<W1O<GDN"B`@("`@*@H@("`@("H@0'9A<B!$0@H@("`@
M("HO"B`@("!V87(@)%]D8CL*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O
M(')E='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R971E($AI<W1O<GD@:6YS
M=&%N8V4N"B`@("`@*B!)="!W:6QL(&]N;'D@8W)E871E(&$@;F5W(&EN<W1A
M;F-E(&EF(&YO($AI<W1O<GD@:6YS=&%N8V4*("`@("`J(&-U<G)E;G1L>2!E
M>&ES=',N"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O
M:V5D(&%S.B`D=F%R(#T@)DAI<W1O<GDZ.G-I;F=L971O;B@I"B`@("`@*@H@
M("`@("H@0')E='5R;B!(;W)D95](:7-T;W)Y("!4:&4@8V]N8W)E=&4@2&ES
M=&]R>2!R969E<F5N8V4L(&]R(&9A;'-E(&]N(&%N"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F
M<VEN9VQE=&]N*"D*("`@('L*("`@("`@("!S=&%T:6,@)&AI<W1O<GD["@H@
M("`@("`@(&EF("@A:7-S970H)&AI<W1O<GDI*2!["B`@("`@("`@("`@("1H
M:7-T;W)Y(#T@)FYE=R!(;W)D95](:7-T;W)Y*"D["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)&AI<W1O<GD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M;VYS=')U8W1O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?2&ES=&]R
M>2@I"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("!I9B`H
M96UP='DH)&-O;F9;)W-Q;"==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V1B
M(#T@4$5!4CHZ<F%I<V5%<G)O<BA?*")4:&4@2&ES=&]R>2!S>7-T96T@:7,@
M9&ES86)L960N(BDI.PH@("`@("`@('T*"B`@("`@("`@<F5Q=6ER95]O;F-E
M("=$0BYP:'`G.PH@("`@("`@("1T:&ES+3Y?9&(@/2`F1$(Z.F-O;FYE8W0H
M)&-O;F9;)W-Q;"==*3L*"B`@("`@("`@+RH@4V5T($1"('!O<G1A8FEL:71Y
M(&]P=&EO;G,N("HO"B`@("`@("`@:68@*&ES7V$H)'1H:7,M/E]D8BP@)T1"
M7V-O;6UO;B<I*2!["B`@("`@("`@("`@('-W:71C:"`H)'1H:7,M/E]D8BT^
M<&AP='EP92D@>PH@("`@("`@("`@("!C87-E("=M<W-Q;"<Z"B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V1B+3YS971/<'1I;VXH)W!O<G1A8FEL:71Y)RP@
M1$)?4$]25$%"24Q)5%E?3$]715)#05-%('P@1$)?4$]25$%"24Q)5%E?15)2
M3U)3('P@1$)?4$]25$%"24Q)5%E?4E1224TI.PH@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V1B+3YS971/<'1I;VXH)W!O<G1A8FEL:71Y)RP@1$)?4$]25$%"
M24Q)5%E?3$]715)#05-%('P@1$)?4$]25$%"24Q)5%E?15)23U)3*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($QO
M9W,@86X@979E;G0@=&\@86X@:71E;2=S(&AI<W1O<GD@;&]G+B!4:&4@:71E
M;2!M=7-T(&)E('5N:7%U96QY"B`@("`@*B!I9&5N=&EF:65D(&)Y("1G=6ED
M+B!!;GD@;W1H97(@9&5T86EL<R!A8F]U="!T:&4@979E;G0@87)E('!A<W-E
M9"!I;@H@("`@("H@)&%T=')I8G5T97,N(%-T86YD87)D('-U9V=E<W1E9"!A
M='1R:6)U=&5S(&%R93H*("`@("`J"B`@("`@*B`@("=W:&\G(#T^(%1H92!I
M9"!O9B!T:&4@=7-E<B!T:&%T('!E<F9O<FUE9"!T:&4@86-T:6]N("AW:6QL
M(&)E(&%D9&5D"B`@("`@*B`@("`@("`@("`@(&%U=&]M871I8V%L;'D@:68@
M;F]T('!R97-E;G0I+@H@("`@("H*("`@("`J("`@)W1S)R`]/B!4:6UE<W1A
M;7`@;V8@=&AE(&%C=&EO;B`H=&AI<R!W:6QL(&)E(&%D9&5D(&%U=&]M871I
M8V%L;'D@:68*("`@("`J("`@("`@("`@("!I="!I<R!N;W0@<')E<V5N="DN
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9W5I9"`@("`@("`@("`@
M(%1H92!U;FEQ=64@:61E;G1I9FEE<B!O9B!T:&4@96YT<GD@=&\*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A9&0@=&\N"B`@("`@
M*B!`<&%R86T@87)R87D@)&%T=')I8G5T97,@("`@("`@5&AE(&AA<V@@;V8@
M;F%M92`]/B!V86QU92!E;G1R:65S('1H870*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!D97-C<FEB92!T:&ES(&5V96YT+@H@("`@
M("H@0'!A<F%M(&)O;VQE86X@)')E<&QA8V5!8W1I;VX@($EF("1A='1R:6)U
M=&5S6R=A8W1I;VXG72!I<R!A;')E861Y"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@<')E<V5N="!I;B!T:&4@:71E;2=S(&AI<W1O
M<GD@;&]G+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('5P9&%T92!T:&%T(&5N=')Y(&EN<W1E860@;V8@8W)E871I;F<@80H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YE=R!O;F4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N?%!%05)?17)R;W(@(%1R=64@
M;VX@<W5C8V5S<RP@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!L;V<H)&=U:60L("1A='1R:6)U=&5S(#T@87)R87DH*2P@
M)')E<&QA8V5!8W1I;VX@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H:7-?
M82@D=&AI<RT^7V1B+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7V1B.PH@("`@("`@('T*"B`@("`@("`@)&AI<W1O<GD@
M/2`F)'1H:7,M/F=E=$AI<W1O<GDH)&=U:60I.PH@("`@("`@(&EF("@A)&AI
M<W1O<GD@?'P@:7-?82@D:&ES=&]R>2P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)&AI<W1O<GD["B`@("`@("`@?0H*("`@("`@("!I
M9B`H96UP='DH)&%T=')I8G5T97-;)W=H;R==*2D@>PH@("`@("`@("`@("`D
M871T<FEB=71E<ULG=VAO)UT@/2!!=71H.CIG971!=71H*"D["B`@("`@("`@
M?0H@("`@("`@(&EF("AE;7!T>2@D871T<FEB=71E<ULG=',G72DI('L*("`@
M("`@("`@("`@)&%T=')I8G5T97-;)W1S)UT@/2!T:6UE*"D["B`@("`@("`@
M?0H*("`@("`@("`O*B!)9B!W92!W86YT('1O(')E<&QA8V4@86X@96YT<GD@
M=VET:"!T:&4@<V%M92!A8W1I;VXL('1R>2!A;F0@9FEN9`H@("`@("`@("`J
M(&]N92X@5')A8VL@=VAE=&AE<B!O<B!N;W0@=V4@<W5C8V5E9"!I;B`D9&]N
M92P@<V\@=V4@:VYO=R!W:&5T:&5R"B`@("`@("`@("H@;W(@;F]T('1O(&%D
M9"!T:&4@96YT<GD@;&%T97(N("HO"B`@("`@("`@)&1O;F4@/2!F86QS93L*
M("`@("`@("!I9B`H)')E<&QA8V5!8W1I;VX@)B8@(65M<'1Y*"1A='1R:6)U
M=&5S6R=A8W1I;VXG72DI('L*("`@("`@("`@("`@)&-O=6YT(#T@8V]U;G0H
M)&AI<W1O<GDM/F1A=&$I.PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@
M/"`D8V]U;G0[("1I*RLI('L*("`@("`@("`@("`@("`@(&EF("@A96UP='DH
M)&AI<W1O<GDM/F1A=&%;)&E=6R=A8W1I;VXG72D@)B8*("`@("`@("`@("`@
M("`@("`@("`D:&ES=&]R>2T^9&%T85LD:5U;)V%C=&EO;B==(#T]("1A='1R
M:6)U=&5S6R=A8W1I;VXG72D@>PH*("`@("`@("`@("`@("`@("`@("`D=F%L
M=65S(#T@87)R87DH)&%T=')I8G5T97-;)W1S)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1A='1R:6)U=&5S6R=W:&\G72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:7-S970H)&%T=')I
M8G5T97-;)V1E<V,G72D@/R`D871T<FEB=71E<ULG9&5S8R==(#H@;G5L;"D[
M"B`@("`@("`@("`@("`@("`@("`@=6YS970H)&%T=')I8G5T97-;)W1S)UTI
M.PH@("`@("`@("`@("`@("`@("`@('5N<V5T*"1A='1R:6)U=&5S6R=W:&\G
M72D["B`@("`@("`@("`@("`@("`@("`@=6YS970H)&%T=')I8G5T97-;)V1E
M<V,G72D["B`@("`@("`@("`@("`@("`@("`@=6YS970H)&%T=')I8G5T97-;
M)V%C=&EO;B==*3L*("`@("`@("`@("`@("`@("`@("!I9B`H)&%T=')I8G5T
M97,I('L*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E<UM=(#T@<V5R
M:6%L:7IE*"1A='1R:6)U=&5S*3L*("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=65S6UT@/2!N=6QL
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D
M=F%L=65S6UT@/2`D:&ES=&]R>2T^9&%T85LD:5U;)VED)UT["@H@("`@("`@
M("`@("`@("`@("`@("1R(#T@)'1H:7,M/E]D8BT^<75E<GDH)U501$%412!H
M;W)D95]H:7-T;W)I97,@4T54(&AI<W1O<GE?=',@/2`_+"<@+@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<@:&ES=&]R>5]W:&\@
M/2`_+"<@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("<@:&ES=&]R>5]D97-C(#T@/RPG("X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G(&AI<W1O<GE?97AT<F$@/2`_(%=(15)%(&AI
M<W1O<GE?:60@/2`_)RP@)'9A;'5E<RD["B`@("`@("`@("`@("`@("`@("`@
M:68@*&ES7V$H)'(L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("1R.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("`D9&]N92`]('1R=64["B`@("`@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@("\J($EF('=E)W)E(&YO="!R97!L86-I;F<@
M8GD@86-T:6]N+"!O<B!I9B!W92!D:61N)W0@9FEN9"!A;B!E;G1R>2!T;PH@
M("`@("`@("`J(')E<&QA8V4L(&EN<V5R="!A(&YE=R!R;W<N("HO"B`@("`@
M("`@:68@*"$D9&]N92D@>PH@("`@("`@("`@("`D=F%L=65S(#T@87)R87DH
M)'1H:7,M/E]D8BT^;F5X=$ED*"=H;W)D95]H:7-T;W)I97,G*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1G=6ED+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&%T=')I8G5T97-;)W1S)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D871T<FEB=71E<ULG=VAO)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I<W-E="@D871T<FEB=71E<ULG9&5S8R==*2`_
M("1A='1R:6)U=&5S6R=D97-C)UT@.B!N=6QL+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:7-S970H)&%T=')I8G5T97-;)V%C=&EO;B==*2`_("1A
M='1R:6)U=&5S6R=A8W1I;VXG72`Z(&YU;&PI.PH@("`@("`@("`@("!U;G-E
M="@D871T<FEB=71E<ULG=',G72D["B`@("`@("`@("`@('5N<V5T*"1A='1R
M:6)U=&5S6R=W:&\G72D["B`@("`@("`@("`@('5N<V5T*"1A='1R:6)U=&5S
M6R=D97-C)UTI.PH@("`@("`@("`@("!U;G-E="@D871T<FEB=71E<ULG86-T
M:6]N)UTI.PH@("`@("`@("`@("!I9B`H)&%T=')I8G5T97,I('L*("`@("`@
M("`@("`@("`@("1V86QU97-;72`]('-E<FEA;&EZ92@D871T<FEB=71E<RD[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=F%L=65S
M6UT@/2!N=6QL.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<B`]("1T
M:&ES+3Y?9&(M/G%U97)Y*"=)3E-%4E0@24Y43R!H;W)D95]H:7-T;W)I97,@
M*&AI<W1O<GE?:60L(&]B:F5C=%]U:60L(&AI<W1O<GE?=',L(&AI<W1O<GE?
M=VAO+"!H:7-T;W)Y7V1E<V,L(&AI<W1O<GE?86-T:6]N+"!H:7-T;W)Y7V5X
M=')A*2<@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G(%9!3%5%
M4R`H/RP@/RP@/RP@/RP@/RP@/RP@/RDG+"`D=F%L=65S*3L*("`@("`@("`@
M("`@:68@*&ES7V$H)'(L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D<CL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M(&$@2&ES=&]R>4]B:F5C="!C;W)R97-P;VYD:6YG('1O('1H92!N86UE9"!H
M:7-T;W)Y"B`@("`@*B!E;G1R>2P@=VET:"!T:&4@9&%T82!R971R:65V960@
M87!P<F]P<FEA=&5L>2X@)&%U=&]C<F5A=&4@:&%S"B`@("`@*B!N;R!A9F9E
M8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9W5I9"`@("`@("`@
M(%1H92!N86UE(&]F('1H92!H:7-T;W)Y(&5N=')Y('1O(')E=')I979E+@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)&%U=&]C<F5A=&4@($1E<')E8V%T960N
M"B`@("`@*B\*("`@(&9U;F-T:6]N("9G971(:7-T;W)Y*"1G=6ED+"`D875T
M;V-R96%T92`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7V$H)'1H:7,M
M/E]D8BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D9F%L<V4@/2!F
M86QS93L*("`@("`@("`@("`@<F5T=7)N("1F86QS93L*("`@("`@("!]"@H@
M("`@("`@("1R;W=S(#T@)'1H:7,M/E]D8BT^9V5T06QL*"=314Q%0U0@*B!&
M4D]-(&AO<F1E7VAI<W1O<FEE<R!72$5212!O8FIE8W1?=6ED(#T@/R<L(&%R
M<F%Y*"1G=6ED*2P@1$)?1D540TA-3T1%7T%34T]#*3L*("`@("`@("`D:&ES
M=&]R>2`]("9N97<@2&ES=&]R>4]B:F5C="@D9W5I9"P@)')O=W,I.PH@("`@
M("`@(')E='5R;B`D:&ES=&]R>3L*("`@('T*"B`@("`O*BH*("`@("`J($9I
M;F1S(&AI<W1O<GD@;V)J96-T<R!B>2!T:6UE<W1A;7`L(&%N9"!O<'1I;VYA
M;&QY(&9I;'1E<B!O;B!O=&AE<@H@("`@("H@9FEE;&1S(&%S('=E;&PN"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VUP("`@("!4:&4@8V]M<&%R
M:7-O;B!O<&5R871O<B`H/"P@/BP@/#TL(#X]+"!O<B`]*2!T;PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("!C:&5C:R!T:&4@=&EM97-T86UP<R!W
M:71H+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'1S("`@("!4:&4@=&EM97-T
M86UP('1O(&-O;7!A<F4@86=A:6YS="X*("`@("`J($!P87)A;2!A<G)A>2`D
M9FEL=&5R<R`@06X@87)R87D@;V8@861D:71I;VYA;"`H04Y$960I(&-R:71E
M<FEA+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!%86-H(&%R<F%Y
M('9A;'5E('-H;W5L9"!B92!A;B!A<G)A>2!W:71H(#,*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@96YT<FEE<SH*("`@("`J(#QP<F4^"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`G;W`G("`@("T@=&AE(&]P97)A
M=&]R('1O(&-O;7!A<F4@=&AI<R!F:65L9`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('=I=&@N"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`G9FEE;&0G("T@=&AE(&AI<W1O<GD@9FEE;&0@8F5I
M;F<@8V]M<&%R960*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`H:2YE+B`G86-T:6]N)RDN"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`G=F%L=64G("T@=&AE('9A;'5E('1O(&-H96-K(&9O<B`H
M:2YE+B`G861D)RDN"B`@("`@*B`\+W!R93X*("`@("`J($!P87)A;2!S=')I
M;F<@)'!A<F5N="`@5&AE('!A<F5N="!H:7-T;W)Y('1O('-T87)T('-E87)C
M:&EN9R!A="X@268@;F]N+65M<'1Y+`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("!W:6QL(&)E('-E87)C:&5D(&9O<B!W:71H(&$@3$E+12`G)'!A
M<F5N=#HE)R!C;&%U<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@
M06X@87)R87D@;V8@:&ES=&]R>2!O8FIE8W0@:61S+"!O<B!A;B!E;7!T>2!A
M<G)A>2!I9@H@("`@("H@("`@("`@("`@("`@("`@;F]N92!M871C:&5D('1H
M92!C<FET97)I82X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0GE4:6UE<W1A
M;7`H)&-M<"P@)'1S+"`D9FEL=&5R<R`](&%R<F%Y*"DL("1P87)E;G0@/2!N
M=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?9&(L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T*"B`@("`@("`@+RH@0G5I;&0@=&AE('1I;65S=&%M<"!T97-T+B`J+PH@
M("`@("`@("1W:&5R92`](&%R<F%Y*")H:7-T;W)Y7W1S("1C;7`@)'1S(BD[
M"@H@("`@("`@("\J($%D9"!A9&1I=&EO;F%L(&9I;'1E<G,L(&EF('1H97)E
M(&%R92!A;GDN("HO"B`@("`@("`@:68@*"1F:6QT97)S*2!["B`@("`@("`@
M("`@(&9O<F5A8V@@*"1F:6QT97)S(&%S("1F:6QT97(I('L*("`@("`@("`@
M("`@("`@("1W:&5R95M=(#T@)VAI<W1O<GE?)R`N("1F:6QT97);)V9I96QD
M)UT@+B`G("<@+B`D9FEL=&5R6R=O<"==("X@)R`G("X@)'1H:7,M/E]D8BT^
M<75O=&4H)&9I;'1E<ELG=F%L=64G72D["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(&EF("@D<&%R96YT*2!["B`@("`@("`@("`@("1W:&5R
M95M=(#T@)V]B:F5C=%]U:60@3$E+12`G("X@)'1H:7,M/E]D8BT^<75O=&4H
M)'!A<F5N="`N("<Z)2<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?9&(M/F=E=$%S<V]C*"=314Q%0U0@1$E35$E.0U0@;V)J96-T7W5I
M9"P@:&ES=&]R>5]I9"!&4D]-(&AO<F1E7VAI<W1O<FEE<R!72$5212`G("X@
M:6UP;&]D92@G($%.1"`G+"`D=VAE<F4I*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($=E=',@=&AE('1I;65S=&%M<"!O9B!T:&4@;6]S="!R96-E;G0@8VAA
M;F=E('1O("1G=6ED+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&=U
M:60@("`@5&AE(&YA;64@;V8@=&AE(&AI<W1O<GD@96YT<GD@=&\@<F5T<FEE
M=F4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1A8W1I;VX@($%N(&%C=&EO;CH@
M)V%D9"<L("=M;V1I9GDG+"`G9&5L971E)RP@971C+@H@("`@("H*("`@("`J
M($!R971U<FX@:6YT96=E<B`@5&AE('1I;65S=&%M<"P@;W(@,"!I9B!N;R!M
M871C:&EN9R!E;G1R>2!I<R!F;W5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T06-T:6]N5&EM97-T86UP*"1G=6ED+"`D86-T:6]N*0H@("`@>PH@("`@
M("`@("\J(%1H:7,@:6UP;&5M96YT871I;VX@<W1I;&P@=V]R:W,L(&)U="!W
M92!S:&]U;&0@8F4@86)L92!T;PH@("`@("`@("`J(&=E="!M=6-H(&9A<W1E
M<B!N;W<@=VET:"!A(%-%3$5#5"!-05@H:&ES=&]R>5]T<RD*("`@("`@("`@
M*B`N+BX@<75E<GDN("HO"B`@("`@("`@)&AI<W1O<GD@/2`F)'1H:7,M/F=E
M=$AI<W1O<GDH)&=U:60I.PH@("`@("`@(&EF("@A)&AI<W1O<GD@?'P@:7-?
M82@D:&ES=&]R>2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@,#L*("`@("`@("!]"@H@("`@("`@("1L87-T(#T@,#L*("`@("`@("!I
M9B`H:7-?87)R87DH)&AI<W1O<GDM/F1A=&$I*2!["B`@("`@("`@("`@(&9O
M<F5A8V@@*"1H:7-T;W)Y+3YD871A(&%S("1E;G1R>2D@>PH@("`@("`@("`@
M("`@("`@:68@*"1E;G1R>5LG86-T:6]N)UT@/3T@)&%C=&EO;B`F)B`D96YT
M<GE;)W1S)UT@/B`D;&%S="D@>PH@("`@("`@("`@("`@("`@("`@("1L87-T
M(#T@)&5N=')Y6R=T<R==.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&QA<W0["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!296UO=F4@;VYE(&]R(&UO<F4@:&ES=&]R>2!E;G1R
M:65S(&)Y(&YA;64N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1N86UE
M<R`@5&AE(&AI<W1O<GD@96YT<FEE<R!T;R!R96UO=F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(')E;6]V94)Y3F%M97,H)&YA;65S*0H@("`@>PH@("`@("`@
M(&EF("AI<U]A*"1T:&ES+3Y?9&(L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@)&ED<R`]
M(&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)&YA;65S(&%S("1N86UE*2![
M"B`@("`@("`@("`@("1I9'-;72`]("1T:&ES+3Y?9&(M/G%U;W1E*"1N86UE
M*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^7V1B+3YQ=65R
M>2@G1$5,151%($923TT@:&]R9&5?:&ES=&]R:65S(%=(15)%(&]B:F5C=%]U
M:60@24X@*"<@+B!I;7!L;V1E*"<L)RP@)&ED<RD@+B`G*2<I.PH@("`@?0H*
M?0H*+RHJ"B`J($-L87-S(&9O<B!P<F5S96YT:6YG($AI<W1O<GD@:6YF;W)M
M871I;VXN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`R+C$*("H@0'!A8VMA9V4@
M2&]R9&5?2&ES=&]R>0H@*B\*8VQA<W,@2&ES=&]R>4]B:F5C="!["@H@("`@
M=F%R("1U:60["B`@("!V87(@)&1A=&$@/2!A<G)A>2@I.PH*("`@(&9U;F-T
M:6]N($AI<W1O<GE/8FIE8W0H)'5I9"P@)&1A=&$@/2!A<G)A>2@I*0H@("`@
M>PH@("`@("`@("1T:&ES+3YU:60@/2`D=6ED.PH*("`@("`@("!I9B`H(21D
M871A('Q\(&ES7V$H)&1A=&$L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)&1A=&$@
M87,@)')O=RD@>PH@("`@("`@("`@("`D:&ES=&]R>2`](&%R<F%Y*"=A8W1I
M;VXG(#T^("1R;W=;)VAI<W1O<GE?86-T:6]N)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V1E<V,G(#T^("1R;W=;)VAI<W1O<GE?9&5S8R==
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=W:&\G(#T^("1R;W=;
M)VAI<W1O<GE?=VAO)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)VED)R`]/B`D<F]W6R=H:7-T;W)Y7VED)UTL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W1S)R`]/B`D<F]W6R=H:7-T;W)Y7W1S)UTI.PH@("`@
M("`@("`@("!I9B`H)')O=ULG:&ES=&]R>5]E>'1R82==*2!["B`@("`@("`@
M("`@("`@("`D97AT<F$@/2!`=6YS97)I86QI>F4H)')O=ULG:&ES=&]R>5]E
M>'1R82==*3L*("`@("`@("`@("`@("`@(&EF("@D97AT<F$I('L*("`@("`@
M("`@("`@("`@("`@("`D:&ES=&]R>2`](&%R<F%Y7VUE<F=E*"1H:7-T;W)Y
M+"`D97AT<F$I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1T:&ES+3YD871A6UT@/2`D:&ES=&]R>3L*("`@("`@("!]
M"B`@("!]"@H@("`@9G5N8W1I;VX@9V5T1&%T82@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3YD871A.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<```
M````````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#8S,#(V(#$P-3$U
M-#,S-S0P(#`R,C,P-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`H*+RHJ"B`J($1O('1A<VL@>65A<FQY("A&:7)S
M="!L;V=I;B!A9G1E<B]O;B!*86YU87)Y(#$I+@H@*B\*9&5F:6YE*"=-04E.
M5$5.04Y#15]914%23%DG+"`Q*3L*"B\J*@H@*B!$;R!T87-K(&UO;G1H;'D@
M*$9I<G-T(&QO9VEN(&%F=&5R+V]N(&9I<G-T(&]F(&UO;G1H*2X*("HO"F1E
M9FEN92@G34%)3E1%3D%.0T5?34].5$A,62<L(#(I.PH*+RHJ"B`J($1O('1A
M<VL@=V5E:VQY("A&:7)S="!L;V=I;B!A9G1E<B]O;B!A(%-U;F1A>2DN"B`J
M+PID969I;F4H)TU!24Y414Y!3D-%7U=%14M,62<L(#,I.PH*+RHJ"B`J($1O
M('1A<VL@9&%I;'D@*$9I<G-T(&QO9VEN(&]F('1H92!D87DI+@H@*B\*9&5F
M:6YE*"=-04E.5$5.04Y#15]$04E,62<L(#0I.PH*+RHJ"B`J($1O('1A<VL@
M979E<GD@;&]G:6XN"B`J+PID969I;F4H)TU!24Y414Y!3D-%7T5615)9)RP@
M-2D["@HO*BH*("H@1&\@=&%S:R!O;B!F:7)S="!L;V=I;B!O;FQY+@H@*B\*
M9&5F:6YE*"=-04E.5$5.04Y#15]&25)35%],3T=)3B<L(#8I.PH*+RHJ"B`J
M($-O;F9I<FUA=&EO;BUS='EL92!O=71P=70@9F]R(&UA:6YT96YA;F-E('!A
M9V4N"B`J+PID969I;F4H)TU!24Y414Y!3D-%7T]55%!55%]#3TY&25)-)RP@
M-RD["@HO*BH*("H@06=R965M96YT+7-T>6QE(&]U='!U="!F;W(@;6%I;G1E
M;F%N8V4@<&%G92X*("HO"F1E9FEN92@G34%)3E1%3D%.0T5?3U544%547T%'
M4D5%)RP@."D["@HO*BH*("H@3F]T:6-E+7-T>6QE(&]U='!U="!F;W(@;6%I
M;G1E;F%N8V4@<&%G92X*("HO"F1E9FEN92@G34%)3E1%3D%.0T5?3U544%54
M7TY/5$E#12<L(#DI.PH*+RHJ"B`J(%1H92!N86UE(&]F('1H92!54DP@<&%R
M86UE=&5R('1H870@:6YD:6-A=&5S('1H870@=&AE(&UA:6YT96YA;F-E('1A
M<VMS(&%R90H@*B!C;VUP;&5T960N"B`J+PID969I;F4H)TU!24Y414Y!3D-%
M7T1/3D5?4$%204TG+"`G;6%I;G1E;F%N8V5?9&]N92<I.PH*+RH@26YT97)V
M86QS(&AA<V@@+2!U<V5D('1O(&)U:6QD('-E;&5C="!T86)L97,@:6X@<')E
M9F5R96YC97,@;65N=2X@*B\*)&EN=&5R=F%L<R`](&%R<F%Y*"D["B1I;G1E
M<G9A;'-;34%)3E1%3D%.0T5?645!4DQ972`@/2!?*")996%R;'DB*3L*)&EN
M=&5R=F%L<UM-04E.5$5.04Y#15]-3TY42$Q972`](%\H(DUO;G1H;'DB*3L*
M)&EN=&5R=F%L<UM-04E.5$5.04Y#15]7145+3%E=("`](%\H(E=E96ML>2(I
M.PHD:6YT97)V86QS6TU!24Y414Y!3D-%7T1!24Q972`@(#T@7R@B1&%I;'DB
M*3L*)&EN=&5R=F%L<UM-04E.5$5.04Y#15]%5D5265T@("`](%\H(D5V97)Y
M($QO9VEN(BD["B1'3$]"04Q36R=I;G1E<G9A;',G72`]("8D:6YT97)V86QS
M.PH*+RHJ"B`J(%1H92!-86EN=&5N86YC93HZ(&-L87-S('!R;W9I9&5S(&$@
M<V5T(&]F(&UE=&AO9',@9F]R(&1E86QI;F<@=VET:`H@*B!M86EN=&5N86YC
M92!O<&5R871I;VYS(')U;B!U<&]N(&QO9VEN('1O($AO<F1E(&%P<&QI8V%T
M:6]N<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I
M;G1E;F%N8V4N<&AP+'8@,2XU,BXQ,"XQ,R`R,#`V+S`Q+S`Q(#(Q.C(X.C(V
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,2TR,#`V($UI8VAA96P@
M4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6-H865L(%-L=7-A<GH@/'-L=7-A
M<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J($!S:6YC92`@($AO<F1E(#$N
M,RXU"B`J($!P86-K86=E($AO<F1E7TUA:6YT96YA;F-E"B`J+PIC;&%S<R!-
M86EN=&5N86YC92!["@H@("`@+RHJ"B`@("`@*B!(87-H(&AO;&1I;F<@;6%I
M;G1E;F%N8V4@<')E9F5R96YC92!N86UE<RX*("`@("`J(%-Y;G1A>#H@(%!2
M149.04U%(#T^(&EN=&5R=F%L"B`@("`@*B!686QI9"!I;G1E<G9A;',@87)E
M.B!-04E.5$5.04Y#15]914%23%DL($U!24Y414Y!3D-%7TU/3E1(3%DL"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("!-04E.5$5.04Y#15]7145+3%DL
M($U!24Y414Y!3D-%7T1!24Q9+`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@34%)3E1%3D%.0T5?159%4EDL("!-04E.5$5.04Y#15]&25)35%],3T=)
M3@H@("`@("H@3W!E<F%T:6]N<R!W:6QL(&)E(')U;B!I;B!T:&4@;W)D97(@
M=&AE>2!A<'!E87(@:6X@=&AE(&%R<F%Y("T*("`@("`J("`@34%+12!355)%
M($953D-424].4R!!4D4@24X@5$A%($-/4E)%0U0@3U)$15(A"B`@("`@*B!/
M<&5R871I;VYS(&-A;B!A<'!E87(@;6]R92!T:&%N(&]N8V4@+2!T:&5Y('=I
M;&P@;VYL>2!B92!R=6X@;VYC92!P97(*("`@("`J("`@;&]G:6X@=&AO=6=H
M("AT:&4@;W!E<F%T:6]N('=I;&P@<G5N('1H92!F:7)S="!T:6UE(&ET(&ES
M('-E96X@:6X*("`@("`J("`@=&AE(&%R<F%Y*2X*("`@("`J"B`@("`@*B!4
M:&ES(&%R<F%Y('-H;W5L9"!B92!F:6QL960@:6X@9F]R(&5A8V@@2&]R9&4@
M;6]D=6QE('1H870@97AT96YD<PH@("`@("H@("!T:&4@36%I;G1E;F%N8V4@
M8VQA<W,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)&UA:6YT7W1A<VMS(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%5.
M25@@=&EM97-T86UP(&]F('1H92!L87-T(&UA:6YT96YA;F-E(')U;B!F;W(@
M=7-E<BX*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@
M=F%R("1?;&%S=%)U;B`](#`["@H@("`@+RHJ"B`@("`@*B!4:&4@36%I;G1E
M;F%N8V5?5&%S:VQI<W0@;V)J96-T(&9O<B!T:&ES(&QO9VEN+@H@("`@("H*
M("`@("`J($!V87(@36%I;G1E;F%N8V5?5&%S:VQI<W0*("`@("`J+PH@("`@
M=F%R("1?=&%S:VQI<W0["@H@("`@+RHJ"B`@("`@*B!!<G)A>2!T;R!S=&]R
M92!-86EN=&5N86YC95]487-K(&]B:F5C=',N"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]T87-K0V%C:&4@/2!A<G)A>2@I
M.PH*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E
M=&4@36%I;G1E;F%N8V5?*B!O8FIE8W0@8F%S960@;VX@=&AE(&UO9'5L90H@
M("`@("H@;F%M92!P87-S960@:6YT;R!I="X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1M;V1U;&4@(%1H92!N86UE(&]F('1H92!(;W)D92!M;V1U
M;&4N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@($$@:&%S:"!C;VYT
M86EN:6YG(&%D9&ET:6]N86P@9&%T82!N965D960@8GD@=&AE"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@(&-O;G-T<G5C=&]R+@H@("`@("H*("`@
M("`J($!R971U<FX@36%I;G1E;F%N8V4@(%1H92!-86EN=&5N86YC92!O8FIE
M8W0L(&]R(&9A;'-E(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F
M9F%C=&]R>2@D;6]D=6QE+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@
M("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("`O*B!3<&%W;B!T:&4@
M<F5L979A;G0@9')I=F5R+"!A;F0@<F5T=7)N(&ET("AO<B!F86QS92!O;B!F
M86EL=7)E*2X@*B\*("`@("`@("!I;F-L=61E7V]N8V4@)')E9VES=')Y+3YG
M970H)V9I;&5R;V]T)RP@)&UO9'5L92D@+B`G+VQI8B]-86EN=&5N86YC92\G
M("X@)&UO9'5L92`N("<N<&AP)SL*("`@("`@("`D8VQA<W,@/2`G36%I;G1E
M;F%N8V5?)R`N("1M;V1U;&4["B`@("`@("`@:68@*&-L87-S7V5X:7-T<R@D
M8VQA<W,I*2!["B`@("`@("`@("`@("1M86EN=&5N86YC92`]("9N97<@)&-L
M87-S*"1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1M
M86EN=&5N86YC92`](&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1M86EN=&5N86YC93L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G-T<G5C
M=&]R+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA
M<V@@8V]N=&%I;FEN9R!T:&4@9F]L;&]W:6YG(&5N=')I97,Z"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@)VQA<W1?;6%I;G1E;F%N8V4G(#T^(%1H
M92!L87-T('1I;64@;6%I;G1E;F%N8V4@=V%S(')U;B`H=6YI>"!T:6UE<W1A
M;7`I+@H@("`@("HO"B`@("!F=6YC=&EO;B!-86EN=&5N86YC92@D<&%R86US
M(#T@87)R87DH*2D*("`@('L*("`@("`@("`O*B!3970@=&AE(&-L87-S('9A
M<FEA8FQE("1?;&%S=%)U;BX@*B\*("`@("`@("!I9B`H:7-S970H)'!A<F%M
M<ULG;&%S=%]M86EN=&5N86YC92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7VQA<W12=6X@/2`D<&%R86US6R=L87-T7VUA:6YT96YA;F-E)UT["B`@("`@
M("`@?0H*("`@("`@("`D=&AI<RT^7W)E=')I979E5&%S:VQI<W0H*3L*("`@
M("`@("`D=&AI<RT^7W-H=71D;W=N*"D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!$;R!M86EN=&5N86YC92!O<&5R871I;VYS(&YE961E9"!F;W(@=&AI<R!L
M;V=I;BX@(%1H:7,@9G5N8W1I;VX*("`@("`J('=I;&P@9V5N97)A=&4@=&AE
M(&QI<W0@;V8@=&%S:W,@=&\@<&5R9F]R;2!D=7)I;F<@=&AI<R!L;V=I;@H@
M("`@("H@86YD('=I;&P@<F5D:7)E8W0@=&\@=&AE(&UA:6YT96YA;F-E('!A
M9V4@:68@;F5C97-S87)Y+B`@5&AI<PH@("`@("H@:7,@=&AE(&9U;F-T:6]N
M('1H870@<VAO=6QD(&)E(&-A;&QE9"!F<F]M('1H92!A<'!L:6-A=&EO;B!U
M<&]N"B`@("`@*B!L;V=I;BX*("`@("`J+PH@("`@9G5N8W1I;VX@<G5N36%I
M;G1E;F%N8V4H*0H@("`@>PH@("`@("`@("\J($-H96-K('1O('-E92!I9B!W
M92!A<F4@9FEN:7-H960@=VET:"!M86EN=&5N86YC90H@("`@("`@("`J(&]P
M97)A=&EO;G,N("HO"B`@("`@("`@:68@*"%5=&EL.CIG971&;W)M1&%T82A-
M04E.5$5.04Y#15]$3TY%7U!!4D%-*2D@>PH@("`@("`@("`@("`O*B!$971E
M<FUI;F4@:68@=V4@<VAO=6QD(')E9&ER96-T('1O('1H92!M86EN=&5N86YC
M92!P86=E+B`J+PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]N965D36%I;G1E
M;F%N8V5086=E*"D@(3T](&YU;&PI('L*("`@("`@("`@("`@("`@(&AE861E
M<B@G3&]C871I;VXZ("<@+B`D=&AI<RT^7V=E=$UA:6YT96YA;F-E55),*"DL
M('1R=64I.PH@("`@("`@("`@("`@("`@97AI=#L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@+RH@1FEN86QL>2P@<G5N(&%N>2!T87-K<R!T
M:&%T(&YE960@=&\@8F4@97AE8W5T960N("HO"B`@("`@("`@)'1H:7,M/E]D
M;TUA:6YT96YA;F-E5&%S:W,H*3L*("`@('T*"B`@("`O*BH*("`@("`J($1O
M('1H92!N96-E<W-A<GD@;6%I;G1E;F%N8V4@=&%S:W,@9F]R('1H:7,@;&]A
M9&EN9R!O9B!T:&4@;6%I;G1E;F%N8V4*("`@("`J('!A9V4N("!4:&ES(&ES
M('1H92!F=6YC=&EO;B!T:&%T(&ES(&-A;&QE9"!F<F]M('1H92!M86EN=&5N
M86YC92!P86=E"B`@("`@*B!E=F5R>2!T:6UE(&ET(&ES(&QO861E9"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!D:7-P;&%Y(')E<75I
M<F5D(&9O<B!T:&4@;6%I;G1E;F%N8V4@<&%G92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<G5N36%I;G1E;F%N8V5086=E*"D*("`@('L*("`@("`@("`O*B!3
M:&]U;&0@=V4@<G5N(&%N>2!T87-K<S\@*B\*("`@("`@("`D=&AI<RT^7V1O
M36%I;G1E;F%N8V5487-K<R@I.PH*("`@("`@("`O*B!'970@=&AE(&QI<W0@
M;V8@=&%S:W,@=V4@;F5E9"!T;R!D:7-P;&%Y('1O('1H92!U<V5R+B`J+PH@
M("`@("`@("1T87-K7VYO(#T@)'1H:7,M/E]N965D36%I;G1E;F%N8V5086=E
M*"D["B`@("`@("`@)'1A<VMS(#T@)'1H:7,M/E]T87-K;&ES="T^9V5T3&ES
M="@I.PH*("`@("`@("`O*B!296UO=F4@)VYE=V9L86<G(&9R;VT@9FER<W0@
M=&%S:RX@*B\*("`@("`@("!I9B`H(21T:&ES+3Y?=&%S:VQI<W0M/G!R;V-E
M<W-E9"AT<G5E*2D@>PH@("`@("`@("`@("!I9B`H8V]U;G0H)'1A<VMS*2D@
M>PH@("`@("`@("`@("`@("`@<F5S970H)'1A<VMS*3L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?=&%S:VQI<W0M/G-E=$YE=U!A9V4H:V5Y*"1T87-K<RDL
M(&9A;'-E*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@
M*"%I<U]N=6QL*"1T87-K7VYO*2D@>PH@("`@("`@("`@("`D=&%S:W,@/2!A
M<G)A>5]S;&EC92@D=&%S:W,L(#`L("1T87-K7VYO("L@,2D["B`@("`@("`@
M?0H*("`@("`@("!I9B`H8V]U;G0H)'1A<VMS*2D@>PH@("`@("`@("`@("!R
M97-E="@D=&%S:W,I.PH@("`@("`@("`@("`D86-T:6]N(#T@)'1A<VMS6VME
M>2@D=&%S:W,I75LG9&ES<&QA>2==.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1A8W1I;VX@/2!N=6QL.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N(&%R<F%Y*"1A8W1I;VXL(&%R<F%Y7VME>7,H)'1A<VMS*2D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!I;F9O<FUA=&EO;F%L('1E
M>'0@;65S<V%G92!O;B!W:&%T('1H92!O<&5R871I;VX@:7,*("`@("`J(&%B
M;W5T('1O(&1O+B!!;'-O(&EN9&EC871E<R!W:&5T:&5R('1H92!B;W@@<VAO
M=6QD(&)E(&-H96-K960*("`@("`J(&)Y(&1E9F%U;'0@;W(@;F]T+B!/<&5R
M871I;VYS('1H870@:&%V92!B965N(&QO8VME9"!B>2!T:&4*("`@("`J(&%D
M;6EN('=I;&P@<F5T=7)N(&YU;&PN"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<')E9B`@3F%M92!O9B!T:&4@;W!E<F%T:6]N('1O(&=E="!I;F9O
M<FUA=&EO;B!F;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@,7-T
M(&5L96UE;G0@+2!$97-C<FEP=&EO;B!O9B!W:&%T('1H92!O<&5R871I;VX@
M:7,@86)O=70*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M=&\@9&\@9'5R:6YG('1H:7,@;&]G:6XN"B`@("`@*B`@("`@("`@("`@("`@
M("`R;F0@96QE;65N="`M(%=H971H97(@=&AE('!R969E<F5N8V4@:7,@<V5T
M('1O(&]N(&]R(&YO="X*("`@("`J+PH@("`@9G5N8W1I;VX@:6YF;TUA:6YT
M96YA;F-E*"1P<F5F*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<')E9G,["@H@
M("`@("`@("\J($EF('1H92!P<F5F97)E;F-E(&AA<R!B965N(&QO8VME9"!B
M>2!T:&4@861M:6XL(&1O(&YO="!S:&]W"B`@("`@("`@("`@=&AE('5S97(N
M("HO"B`@("`@("`@:68@*"1P<F5F<RT^:7-,;V-K960H)'!R968I*2!["B`@
M("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("1M;V0@/2`F
M)'1H:7,M/E]L;V%D36]D=6QE*"1P<F5F*3L*("`@("`@("!R971U<FX@87)R
M87DH)&UO9"T^9&5S8W)I8F5-86EN=&5N86YC92@I+"`D<')E9G,M/F=E=%9A
M;'5E*"1P<F5F*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>'!O<G0@=F%R
M:6%B;&4@;F%M97,@=&\@=7-E(&9O<B!C<F5A=&EN9R!S96QE8W0@=&%B;&5S
M(&EN('1H90H@("`@("H@<')E9F5R96YC97,@;65N=2X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!O9B!V87)I86)L92!N86UE<R!T
M;R!B92!I;7!O<G1E9"!I;G1O('1H90H@("`@("H@("`@("`@("`@("`@("`@
M<')E9G,N<&AP(&YA;65S<&%C92X*("`@("`J+PH@("`@9G5N8W1I;VX@97AP
M;W)T26YT97)V86Q0<F5F<R@I"B`@("!["B`@("`@("`@9VQO8F%L("1P<F5F
M<SL*"B`@("`@("`@)')E='5R;E]A<G)A>2`](&%R<F%Y*"D["@H@("`@("`@
M(&9O<F5A8V@@*&%R<F%Y7VME>7,H)'1H:7,M/FUA:6YT7W1A<VMS*2!A<R`D
M=F%L*2!["B`@("`@("`@("`@(&EF("@A)'!R969S+3YI<TQO8VME9"@D=F%L
M("X@)U]I;G1E<G9A;"<I*2!["B`@("`@("`@("`@("`@("`D<F5T=7)N7V%R
M<F%Y6UT@/2`D=F%L("X@)U]I;G1E<G9A;%]O<'1I;VYS)SL*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R971U<FY?87)R87D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!/=71P=70@:&ED9&5N(&9O<B!E;&5M
M96YT<R!F;W(@=&AE(%!/4U0@9F]R;2!T;R!E;G-U<F4@=&AE(&-A;&QI;F<*
M("`@("`J('-C<FEP="!H87,@=&AE('-A;64@4$]35"!E;&5M96YT<R!A<R!W
M:&5N('1H92!M86EN=&5N86YC92!O<&5R871I;VYS"B`@("`@*B!F:7)S="!R
M=6XN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!F;W)M(&1A
M=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!O<W1$871A*"D*("`@('L*
M("`@("`@("`D=&5X="`]("<G.PH*("`@("`@("!I9B`H*"1D871A(#T@)'1H
M:7,M/E]T87-K;&ES="T^9V5T4&]S=$1A=&$H*2DI('L*("`@("`@("`@("`@
M9F]R96%C:"`H)&1A=&$@87,@)&YA;64@/3X@)'9A;"D@>PH@("`@("`@("`@
M("`@("`@)'1E>'0@+CT@)SQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](B<@
M+B!H=&UL<W!E8VEA;&-H87)S*"1N86UE*2`N("<B('9A;'5E/2(G("X@:'1M
M;'-P96-I86QC:&%R<R@D=F%L*2`N("<B("\^)R`N(")<;B(["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&5X=#L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@55),(&YE961E9"!F;W(@=&AE
M(&UA:6YT96YA;F-E(&9O<FTN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!54DP@=&\@<F5D:7)E8W0@=&\N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$UA:6YT96YA;F-E1F]R;5523"@I"B`@("!["B`@("`@("!I9B`H
M)'1H:7,M/E]N965D36%I;G1E;F%N8V5086=E*"D@(3T](&YU;&PI('L*("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]G971-86EN=&5N86YC95523"@I.PH@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("!R971U<FX@)'1H:7,M/E]G971)
M;FET:6%L4&%G95523"@I.PH@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@0W)E871E<R!T:&4@;&ES="!O9B!M86EN=&5N86YC92!O<&5R871I;VYS
M('1H870@87)E(&%V86EL86)L90H@("`@("H@9F]R('1H:7,@<V5S<VEO;B`H
M<W1O<F5D(&EN(&$@36%I;G1E;F%N8V5?5&%S:VQI<W0@;V)J96-T*2X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%)E='5R;G,@=')U92!I9B!L:7-T('=A<R!C<F5A=&5D
M+@H@("`@("H@("`@("`@("`@("`@("`@("!&86QS92!I9B!N;W0@*&4N9RX@
M;&ES="!A;')E861Y(&5X:7-T<RDN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C
M<F5A=&5487-K3&ES="@I"B`@("!["B`@("`@("`@9VQO8F%L("1P<F5F<SL*
M"B`@("`@("`@+RH@0W)E871E(&$@;F5W($UA:6YT96YA;F-E7U1A<VML:7-T
M(&]B:F5C="X@*B\*("`@("`@("`D=&AI<RT^7W1A<VML:7-T(#T@)FYE=R!-
M86EN=&5N86YC95]487-K;&ES="@I.PH*("`@("`@("`O*B!#<F5A=&4@=&EM
M92!O8FIE8W1S(&9O<B!T;V1A>2=S(&1A=&4@86YD(&QA<W0@;&]G:6X@9&%T
M92X@*B\*("`@("`@("`D;&%S=%]D871E(#T@9V5T9&%T92@D=&AI<RT^7VQA
M<W12=6XI.PH@("`@("`@("1C=7)?9&%T92`@/2!G971D871E*"D["@H@("`@
M("`@("\J($=O('1H<F]U9V@@96%C:"!I=&5M(&EN("1M86EN=%]T87-K<R!A
M;F0@9&5T97)M:6YE(&EF('=E(&YE960@=&\*("`@("`@("`@("!R=6X@:70@
M9'5R:6YG('1H:7,@;6%I;G1E;F%N8V4@<G5N+B`J+PH@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3YM86EN=%]T87-K<R!A<R`D:V5Y(#T^("1V86PI('L*("`@
M("`@("`@("`@+RH@4VMI<"!I=&5M(&EF(&ET(&%L<F5A9'D@87!P96%R<R!I
M;B!T:&4@=&%S:W,@;&ES="X@*B\*("`@("`@("`@("`@:68@*"1T:&ES+3Y?
M=&%S:VQI<W0M/FEN3&ES="@D:V5Y*2D@>PH@("`@("`@("`@("`@("`@8V]N
M=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($1E=&5R;6EN
M92!T:&4@8V]R<F5C="!I;G1E<G9A;"!F;W(@=&AE(&ET96TN("HO"B`@("`@
M("`@("`@(&EF("@H)&EN=&5R=F%L(#T@)'!R969S+3YG971686QU92@D:V5Y
M("X@)U]I;G1E<G9A;"<I*2D@>PH@("`@("`@("`@("`@("`@)'9A;"`]("1I
M;G1E<G9A;#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&%D9%1A<VL@
M/2!F86QS93L*"B`@("`@("`@("`@("\J($9)4E-4($Q/1TE.($]015)!5$E/
M3E,@*B\*("`@("`@("`@("`@+RH@268@)%]L87-T4G5N(&ES(&5M<'1Y("@]
M(#`I+"!T:&ES(&ES('1H92!F:7)S="!T:6UE('1H92!U<V5R"B`@("`@("`@
M("`@("`@(&AA<R!L;V=G960@:6XN($1O;B=T(')U;B!A;GD@;W1H97(@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<R!O;@H@("`@("`@("`@("`@("!T:&4@9FER
M<W0@;&]G:6XN("HO"B`@("`@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7VQA
M<W12=6XI*2!["B`@("`@("`@("`@("`@("!I9B`H)'9A;"`]/2!-04E.5$5.
M04Y#15]&25)35%],3T=)3BD@>PH@("`@("`@("`@("`@("`@("`@("1A9&14
M87-K(#T@=')U93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@+RH@645!4DQ97T]015)!5$E/3E,@*B\*("`@("`@("`@
M("`@96QS96EF("@H)'9A;"`]/2!-04E.5$5.04Y#15]914%23%DI("8F"B`@
M("`@("`@("`@("`@("`@("`@*"1C=7)?9&%T95LG>65A<B==(#X@)&QA<W1?
M9&%T95LG>65A<B==*2D@>PH@("`@("`@("`@("`@("`@)&%D9%1A<VL@/2!T
M<G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!-3TY42$Q9($]0
M15)!5$E/3E,@*B\*("`@("`@("`@("`@96QS96EF("@H)'9A;"`]/2!-04E.
M5$5.04Y#15]-3TY42$Q9*2`F)@H@("`@("`@("`@("`@("`@("`@("@H)&-U
M<E]D871E6R=Y96%R)UT@/B`D;&%S=%]D871E6R=Y96%R)UTI('Q\("@D8W5R
M7V1A=&5;)VUO;B==(#X@)&QA<W1?9&%T95LG;6]N)UTI*2D@>PH@("`@("`@
M("`@("`@("`@)&%D9%1A<VL@/2!T<G5E.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`O*B!7145+3%D@3U!%4D%424].4R`J+PH@("`@("`@("`@("!E
M;'-E:68@*"@D=F%L(#T]($U!24Y414Y!3D-%7U=%14M,62D@)B8*("`@("`@
M("`@("`@("`@("`@("`H*"1C=7)?9&%T95LG=V1A>2==(#P@)&QA<W1?9&%T
M95LG=V1A>2==*2!\?"`H*'1I;64H*2`M(#8P-#@P,"D@/B`D=&AI<RT^7VQA
M<W12=6XI*2D@>PH@("`@("`@("`@("`@("`@)&%D9%1A<VL@/2!T<G5E.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!$04E,62!/4$52051)3TY3
M("HO"B`@("`@("`@("`@(&5L<V5I9B`H*"1V86P@/3T@34%)3E1%3D%.0T5?
M1$%)3%DI("8F"B`@("`@("`@("`@("`@("`@("`@*"@D8W5R7V1A=&5;)WEE
M87(G72`^("1L87-T7V1A=&5;)WEE87(G72D@?'P@*"1C=7)?9&%T95LG>61A
M>2==(#X@)&QA<W1?9&%T95LG>61A>2==*2DI('L*("`@("`@("`@("`@("`@
M("1A9&1487-K(#T@=')U93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M+RH@159%4ED@3$]'24X@3U!%4D%424].4R`J+PH@("`@("`@("`@("!E;'-E
M:68@*"1V86P@/3T@34%)3E1%3D%.0T5?159%4EDI('L*("`@("`@("`@("`@
M("`@("1A9&1487-K(#T@=')U93L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`O*B!3:VEP('1H92!T87-K(&EF(&%N>2!O9B!T:&4@9F]L;&]W:6YG.@H@
M("`@("`@("`@("`@("`K(%1H:7,@=&%S:R!D;V5S(&YO="!N965D('1O(&)E
M(')U;B!I;B!T:&ES(&QO9VEN"B`@("`@("`@("`@("`@("L@5&AI<R!T87-K
M(&ES(&YO="!S970@:6X@=&AE('!R969E<F5N8V5S("HO"B`@("`@("`@("`@
M(&EF("@A)&%D9%1A<VL@?'P@(21P<F5F<RT^9V5T5F%L=64H)&ME>2DI(&-O
M;G1I;G5E.PH*("`@("`@("`@("`@+RH@3&]A9"!T:&4@=&%S:R!M;V1U;&4@
M;F]W+B`J+PH@("`@("`@("`@("`D;6]D(#T@)B1T:&ES+3Y?;&]A9$UO9'5L
M92@D:V5Y*3L*"B`@("`@("`@("`@("\J($1E=&5R;6EN92!I9B!T:&ES('1A
M<VL@:&%S(&%L<F5A9'D@8F5E;B!C;VYF:7)M960O<V5T('9I82!S;VUE"B`@
M("`@("`@("`@("`@('-O<G0@;V8@861M:6X@<V5T=&EN9RX@06QS;RP@:68@
M=&AE('5S97(O861M:6X@:&%S('-E="!T:&4*("`@("`@("`@("`@("`@)V-O
M;F9I<FU?;6%I;G1E;F%N8V4G(&9L86<L('-K:7`@8V]N9FER;6%T:6]N+B`J
M+PH@("`@("`@("`@("`D8V]N9FER;65D(#T@9F%L<V4["B`@("`@("`@("`@
M(&EF("@D<')E9G,M/FES3&]C:V5D*"1K97DI('Q\"B`@("`@("`@("`@("`@
M("`A)'!R969S+3YG971686QU92@G8V]N9FER;5]M86EN=&5N86YC92<I*2![
M"B`@("`@("`@("`@("`@("`D8V]N9FER;65D(#T@=')U93L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@+RH@061D('1H92!T87-K('1O('1H92!T87-K
M;&ES="X@*B\*("`@("`@("`@("`@)'1H:7,M/E]T87-K;&ES="T^861D5&%S
M:R@D:V5Y+"`D8V]N9FER;65D+"`D;6]D+3YG971$:7-P;&%Y5'EP92@I*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!,;V%D(&UO9'5L92`H
M:68@;F]T(&%L<F5A9'D@;&]A9&5D*2X*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1M;V1N86UE
M("!.86UE(&]F('1H92!M;V1U;&4@=&\@;&]A9"X*("`@("`J"B`@("`@*B!`
M<F5T=7)N($UA:6YT96YA;F-E7U1A<VL@($$@<F5F97)E;F-E('1O('1H92!R
M97%U97-T960@;6]D=6QE+@H@("`@("HO"B`@("!F=6YC=&EO;B`F7VQO861-
M;V1U;&4H)&UO9&YA;64I"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R
M>3L*"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W1A<VM#86-H95LD;6]D
M;F%M95TI*2!["B`@("`@("`@("`@(&EN8VQU9&5?;VYC92`D<F5G:7-T<GDM
M/F=E="@G9FEL97)O;W0G+"`D=&AI<RT^7W1A<VML:7-T+3YG971-;V1U;&4H
M*2D@+B`G+VQI8B]-86EN=&5N86YC92]487-K+R<@+B`D;6]D;F%M92`N("<N
M<&AP)SL*("`@("`@("`@("`@)&-L87-S(#T@)TUA:6YT96YA;F-E7U1A<VM?
M)R`N("1M;V1N86UE.PH@("`@("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1C
M;&%S<RDI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?=&%S:T-A8VAE6R1M
M;V1N86UE72`]("9N97<@)&-L87-S.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*%!%05(Z.G)A:7-E17)R;W(H
M<W!R:6YT9BA?*")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO
M9'5L92`E<R(I+"`D8VQA<W,I*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M=&%S:T-A8VAE6R1M;V1N86UE73L*("`@('T*"B`@("`O*BH*("`@("`J($=E
M="!T:&4@55),(&9O<B!T:&4@:6YI=&EA;"!P86=E+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@55),(&9O<B!T:&4@:6YI=&EA;"!P86=E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?9V5T26YI=&EA;%!A9V554DPH*0H@("`@>PH@("`@("`@(')E
M='5R;B!5=&EL.CIA9&1087)A;65T97(H)'1H:7,M/E]T87-K;&ES="T^9V5T
M5&%R9V5T*"DL(&%R<F%Y*$U!24Y414Y!3D-%7T1/3D5?4$%204T@/3X@,2P@
M)V1O;6%I;G1E;F%N8V4G(#T^(#$I+"!N=6QL+"!F86QS92D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!'970@=&AE(%523"!F;W(@=&AE(&UA:6YT96YA;F-E
M('!A9V4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!54DP@9F]R('1H92!M86EN=&5N
M86YC92!P86=E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T36%I;G1E;F%N
M8V554DPH*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@
M("`@("\J(%=E(&YE960@=&\@<&%S<R!T:&4@8V%C:&4@240@86YD("=M;V1U
M;&4G('!A<F%M971E<G,N("HO"B`@("`@("`@)'5R;"`]($AO<F1E.CIU<FPH
M)')E9VES=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O<V5R=FEC
M97,O;6%I;G1E;F%N8V4N<&AP)RP@=')U92D["B`@("`@("`@)'5R;"`](%5T
M:6PZ.F%D9%!A<F%M971E<B@D=7)L+"!A<G)A>2@G;6]D=6QE)R`]/B`D=&AI
M<RT^7W1A<VML:7-T+3YG971-;V1U;&4H*2P@)V1O;6%I;G1E;F%N8V4G(#T^
M(#$I+"!N=6QL+"!F86QS92D["@H@("`@("`@(')E='5R;B`D=7)L.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5G:7-T97(@=&AE('-H=71D;W=N(&9U;F-T
M:6]N(&9O<B!S=&]R:6YG('1H92!M86EN=&5N86YC90H@("`@("H@=&%S:VQI
M<W0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]S:'5T9&]W;B@I"B`@("!["B`@("`@("`@<F5G:7-T97)?
M<VAU=&1O=VY?9G5N8W1I;VXH87)R87DH)B1T:&ES+"`G7V-A8VAE5&%S:VQI
M<W0G*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#86-H92!T:&4@;6%I;G1E
M;F%N8V4@=&%S:VQI<W0@8F5T=V5E;B!P86=E(')E<75E<W1S+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?
M8V%C:&5487-K;&ES="@I"B`@("!["B`@("`@("`@)%]315-324].6R=H;W)D
M95]M86EN=&5N86YC95]T87-K;&ES="==(#T@<V5R:6%L:7IE*"1T:&ES+3Y?
M=&%S:VQI<W0I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S(&$@
M8V%C:&5D(&UA:6YT96YA;F-E('1A<VML:7-T(&]R(&UA:V5S('-U<F4@;VYE
M(&ES"B`@("`@*B!C<F5A=&5D+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?<F5T<FEE=F5487-K;&ES="@I
M"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1?4T534TE/3ELG:&]R9&5?;6%I
M;G1E;F%N8V5?=&%S:VQI<W0G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]T
M87-K;&ES="`]('5N<V5R:6%L:7IE*"1?4T534TE/3ELG:&]R9&5?;6%I;G1E
M;F%N8V5?=&%S:VQI<W0G72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'1H:7,M/E]C<F5A=&5487-K;&ES="@I.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($5X96-U=&4@86QL(&-O;F9I<FUE9"!T87-K<RX*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N
M8W1I;VX@7V1O36%I;G1E;F%N8V5487-K<R@I"B`@("!["B`@("`@("`@)'1A
M<VMS(#T@)'1H:7,M/E]T87-K;&ES="T^9V5T3&ES="@I.PH*("`@("`@("!F
M;W)E86-H("@D=&%S:W,@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@
M(&EF("@D=F%L6R=N97=P86=E)UTI('L*("`@("`@("`@("`@("`@(&EF("@D
M=&AI<RT^7W1A<VML:7-T+3YP<F]C97-S960H*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?=&%S:VQI<W0M/G-E=$YE=U!A9V4H)&ME>2P@9F%L
M<V4I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@('T@96QS96EF("@D=F%L6R=C;VYF:7)M960G72!\?`H@
M("`@("`@("`@("`@("`@("`@("`@571I;#HZ9V5T1F]R;41A=&$H)&ME>2`N
M("=?8V]N9FER;2<I*2!["B`@("`@("`@("`@("`@("`O*B!097)F;W)M(&UA
M:6YT96YA;F-E(&EF(&-O;F9I<FUE9"X@*B\*("`@("`@("`@("`@("`@("1M
M;V0@/2`F)'1H:7,M/E]L;V%D36]D=6QE*"1K97DI.PH@("`@("`@("`@("`@
M("`@)&UO9"T^9&]-86EN=&5N86YC92@I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1T:&ES+3Y?=&%S:VQI<W0M/G)E;6]V951A<VLH)&ME>2D["B`@
M("`@("`@?0H*("`@("`@("`O*B!)9B!W92=V92!S=6-C97-S9G5L;'D@8V]M
M<&QE=&5D(&5V97)Y('1A<VL@:6X@=&AE(&QI<W0@*&]R"B`@("`@("`@("H@
M<VMI<'!E9"!I="DL(')E8V]R9"!N;W<@87,@=&AE(&QA<W0@=&EM92!M86EN
M=&5N86YC92!W87,*("`@("`@("`@*B!R=6XN("HO"B`@("`@("`@:68@*"%C
M;W5N="@D=&AI<RT^7W1A<VML:7-T+3YG971,:7-T*"DI*2!["B`@("`@("`@
M("`@("1'3$]"04Q36R=P<F5F<R==+3YS971686QU92@G;&%S=%]M86EN=&5N
M86YC92<L('1I;64H*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@1&\@86YY(&]F('1H92!T87-K<R!R97%U:7)E('1H92!M86EN=&5N86YC
M92!P86=E/PH@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(&ME>2!O9B!T:&4@=&%S:R!T
M:&%T(')E<75I<F5S('1H92!M86EN=&5N86YC90H@("`@("H@("`@("`@("`@
M("`@("`@("!P86=E+B!2971U<FYS(&YU;&P@:68@=&AE(&UA:6YT96YA;F-E
M('!A9V4@:7,@;F\*("`@("`J("`@("`@("`@("`@("`@("`@;&]N9V5R(&YE
M961E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7VYE961-86EN=&5N86YC95!A
M9V4H*0H@("`@>PH@("`@("`@("1I(#T@,#L*("`@("`@("!F;W)E86-H("@D
M=&AI<RT^7W1A<VML:7-T+3YG971,:7-T*"D@87,@)&ME>2`]/B`D=F%L*2![
M"B`@("`@("`@("`@(&EF("@D=F%L6R=N97=P86=E)UTI('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D:3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I
M9B`H(65M<'1Y*"1V86Q;)W!R;V-E<W,G72D@)B8*("`@("`@("`@("`@("`@
M("%5=&EL.CIG971&;W)M1&%T82@G9&]M86EN=&5N86YC92<I*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7W1A<VML:7-T+3YS971.97=086=E*"1K97DL
M('1R=64I.PH@("`@("`@("`@("`@("`@<F5T=7)N("1I.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1I*RL["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@;G5L;#L*("`@('T*"GT*"B\J*@H@*B!4:&4@36%I;G1E;F%N8V5?5&%S
M:VQI<W0Z.B!C;&%S<R!I<R!U<V5D('1O('-T;W)E('1H92!L:7-T(&]F(&UA
M:6YT96YA;F-E"B`J('1A<VMS('1H870@;F5E9"!T;R!B92!R=6X@9'5R:6YG
M('1H:7,@;&]G:6XN"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EC:&%E
M;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU
M<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@
M,RXP"B`J($!P86-K86=E($AO<F1E7TUA:6YT96YA;F-E"B`J+PIC;&%S<R!-
M86EN=&5N86YC95]487-K;&ES="!["@H@("`@+RHJ"B`@("`@*B!4:&4@2&]R
M9&4@;6]D=6QE(')U;FYI;F<@=&AE(&UA:6YT96YA;F-E('1A<VMS+@H@("`@
M("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VUO9'5L
M93L*"B`@("`O*BH*("`@("`J(%1H92!54DP@;V8@=&AE('=E8B!P86=E('1O
M(&QO860@869T97(@;6%I;G1E;F%N8V4@:7,@8V]M<&QE=&4N"B`@("`@*@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?=&%R9V5T.PH*
M("`@("\J*@H@("`@("H@4$]35"!D871A(&9O<B!T:&4@8V%L;&EN9R!S8W)I
M<'0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@
M)%]P;W-T9&%T83L*"B`@("`O*BH*("`@("`J(%1H92!L:7-T(&]F('1A<VMS
M('1O(')U;B!D=7)I;F<@=&AI<R!L;V=I;BX*("`@("`J"B`@("`@*B!+15DZ
M("`@(%1A<VL@;F%M90H@("`@("H@5D%,544Z("!!<G)A>2`]/B`H"B`@("`@
M*B`@("`@("`@("`@)V-O;F9I<FUE9"<@(#T^("!B;V]L96%N+`H@("`@("H@
M("`@("`@("`@("=D:7-P;&%Y)R`@("`]/B`@:6YT96=E<BP*("`@("`J("`@
M("`@("`@("`G;F5W<&%G92<@("`@/3X@(&)O;VQE86XL"B`@("`@*B`@("`@
M("`@("`@)W!R;V-E<W,G("`@(#T^("!B;V]L96%N"B`@("`@*B`@("`@("`@
M("D*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D
M7W1A<VMS(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($EN=&5R;F%L(&9L
M86<@9F]R(&%D9%1A<VLH*2X*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*
M("`@("`J+PH@("`@=F%R("1?861D1FQA9R`](&9A;'-E.PH*("`@("\J*@H@
M("`@("H@2&%S('1H92!T87-K;&ES="!B965N('!R;V-E<W-E9"!Y970_"B`@
M("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7W!R
M;V-E<W-E9"`](&9A;'-E.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N
M"B`@("`@*B\*("`@(&9U;F-T:6]N($UA:6YT96YA;F-E7U1A<VML:7-T*"D*
M("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("`D=&AI
M<RT^7VUO9'5L92`]("1R96=I<W1R>2T^9V5T07!P*"D["B`@("`@("`@)'1H
M:7,M/E]T87)G970@/2!(;W)D93HZ<V5L9E5R;"AT<G5E*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($%D9',@82!T87-K('1O('1H92!T87-K;&ES="X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1K97D@("`@("`@("!4:&4@;F%M
M92!O9B!T:&4@=&%S:R!T;R!P97)F;W)M+@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)&-O;F9I<FUE9"`@2&%S('1H92!T87-K(&)E96X@8V]N9FER;65D/PH@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&1I<W!L87D@("`@5&AE(&1I<W!L87D@
M='EP92!O9B!T:&4@=&%S:RX*("`@("`J+PH@("`@9G5N8W1I;VX@861D5&%S
M:R@D:V5Y+"`D8V]N9FER;65D+"`D9&ES<&QA>2D*("`@('L*("`@("`@("`D
M=&AI<RT^7W1A<VMS6R1K97E=(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^
M7W1A<VMS6R1K97E=6R=C;VYF:7)M960G72`]("1C;VYF:7)M960["B`@("`@
M("`@)'1H:7,M/E]T87-K<ULD:V5Y75LG9&ES<&QA>2==(#T@)&1I<W!L87D[
M"@H@("`@("`@(&EF("@H)&1I<W!L87D@/3T@34%)3E1%3D%.0T5?3U544%54
M7T%'4D5%*2!\?`H@("`@("`@("`@("`H)&1I<W!L87D@/3T@34%)3E1%3D%.
M0T5?3U544%547TY/5$E#12DI('L*("`@("`@("`@("`@)'1H:7,M/E]T87-K
M<ULD:V5Y75LG;F5W<&%G92==(#T@=')U93L*("`@("`@("`@("`@)'1H:7,M
M/E]A9&1&;&%G(#T@9F%L<V4["B`@("`@("`@?2!E;'-E:68@*"@D8V]N9FER
M;65D(#T](&9A;'-E*2`F)B`H(21T:&ES+3Y?861D1FQA9RDI('L*("`@("`@
M("`@("`@)'1H:7,M/E]T87-K<ULD:V5Y75LG;F5W<&%G92==(#T@=')U93L*
M("`@("`@("`@("`@)'1H:7,M/E]A9&1&;&%G(#T@=')U93L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7W1A<VMS6R1K97E=6R=N97=P
M86=E)UT@/2!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!3971S('1H92!N97=P86=E(&9L86<@9F]R(&$@=&%S:RX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1T87-K("!4:&4@;F%M92!O9B!T:&4@=&%S
M:R!T;R!A;'1E<BX*("`@("`J($!P87)A;2!S=')I;F<@)&9L86<@($AO=R!T
M;R!S970@=&AE(&9L86<N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$YE=U!A
M9V4H)'1A<VLL("1F;&%G*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^:6Y,
M:7-T*"1T87-K*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W1A<VMS6R1T87-K
M75LG;F5W<&%G92==(#T@)&9L86<["B`@("`@("`@("`@("1T:&ES+3Y?=&%S
M:W-;)'1A<VM=6R=P<F]C97-S)UT@/2`A)&9L86<["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@4F5M;W9E<R!T:&4@=&%S:R!F<F]M('1H92!T
M87-K;&ES="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T87-K("!4
M:&4@;F%M92!O9B!T:&4@=&%S:R!T;R!A;'1E<BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F5M;W9E5&%S:R@D=&%S:RD*("`@('L*("`@("`@("!I9B`H)'1H
M:7,M/FEN3&ES="@D=&%S:RDI('L*("`@("`@("`@("`@=6YS970H)'1H:7,M
M/E]T87-K<ULD=&%S:UTI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($ES('1H:7,@=&%S:R!A;')E861Y(&EN('1H92!T87-K;&ES=#\*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T87-K("!4:&4@;F%M92!O9B!T
M:&4@=&%S:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H
M97(@=&AE('1A<VL@:7,@86QR96%D>2!I;B!T:&4@=&%S:VQI<W0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&EN3&ES="@D=&%S:RD*("`@('L*("`@("`@("!R
M971U<FX@:7-S970H)'1H:7,M/E]T87-K<ULD=&%S:UTI.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N('1H92!L:7-T(&]F('1A<VMS+@H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@(%1H92!L:7-T(&]F('1A<VMS('1H870@
M<W1I;&P@;F5E9"!T;R!B92!D;VYE+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971,:7-T*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]T87-K<SL*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@2&]R9&4@;6]D=6QE
M('1H92!T87-K<R!A<F4@<G5N;FEN9R!U;F1E<BX*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE($AO<F1E(&UO9'5L92!N86UE+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971-;V1U;&4H*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7VUO9'5L93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;B!T:&4@4$]35"!D871A+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M(%1H92!03U-4(&1A=&$@9G)O;2!T:&4@:6YI=&EA;"!54DPN"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=%!O<W1$871A*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]P;W-T9&%T83L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;B!T:&4@55),(&]F('1H92!W96(@<&%G92!T;R!L;V%D(&%F=&5R(&UA
M:6YT96YA;F-E(&ES(&-O;7!L971E+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@=&%R9V5T(%523"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T5&%R9V5T*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]T87)G
M970["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S+V1I<W!L87ES('1H92!F
M;&%G('1O('-H;W<@=&AA="!T87-K;&ES="!H87,@8F5E;B!P<F]C97-S960@
M870*("`@("`J(&QE87-T(&]N8V4N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O
M;VQE86X@)'-E="`@4V5T('1H92!F;&%G/PH@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@2&%S('1H92!T87-K;&ES="!B965N('!R;V-E<W-E9"!B
M969O<F4_"B`@("`@*B\*("`@(&9U;F-T:6]N('!R;V-E<W-E9"@D<V5T(#T@
M9F%L<V4I"B`@("!["B`@("`@("`@)')E='9A;'5E(#T@)'1H:7,M/E]P<F]C
M97-S960["B`@("`@("`@:68@*"1S970I('L*("`@("`@("`@("`@)'1H:7,M
M/E]P<F]C97-S960@/2!T<G5E.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M)')E='9A;'5E.PH@("`@?0H*?0H*+RHJ"B`J($%B<W1R86-T(&-L87-S('1O
M(&%L;&]W(&9O<B!M;V1U;&%R:7IA=&EO;B!O9B!S<&5C:69I8R!M86EN=&5N
M86-E('1A<VMS+@H@*@H@*B!&;W(@=&AI<R!E>'!L86YA=&EO;BP@=&AE('-P
M96-I9FEC($AO<F1E(&%P<&QI8V%T:6]N('EO=2!W86YT('1O(&-R96%T90H@
M*B!M86EN=&5N86YC92!A8W1I;VYS(&9O<B!W:6QL(&)E(&QA8F5L960@2$]2
M1$5!4%`N"B`J"B`J(%1O(&%D9"!A(&YE=R!M86EN=&5N86YC92!T87-K+"!Y
M;W4@;F5E9"!T;R!D;R!T:&4@9F]L;&]W:6YG.@H@*B!;,5T@061D('!R969E
M<F5N8V4@=&\@(DA/4D1%05!0+V-O;F9I9R]P<F5F<RYP:'`B(&9I;&4N"B`J
M("`@("`H5&AE(&YA;64@;V8@=&AI<R!P<F5F97)E;F-E('=I;&P@8F4@<F5F
M97)R960@=&\@87,@4%)%1DY!344I"B`J("`@("!4:&ES('!R969E<F5N8V4@
M<VAO=6QD(&)E(&]F('1Y<&4@)V-H96-K8F]X)R`H:2YE+B`Q(#T@;VX[(#`@
M/2!O9F8I+@H@*B`@("`@6T]P=&EO;F%L.ET@($%D9"!A('!R969E<F5N8V4@
M:6X@<')E9G,N<&AP(&]F('1H92!N86UE"B`J("`@("`@("`@("`@("`@("`@
M)U!2149.04U%7VEN=&5R=F%L)R!T;R!A;&QO=R!T:&4@=7-E<B!T;R!S970@
M=&AE(&EN=&5R=F%L+@H@*B`@("`@("`@("`@("`@("`@("=D969A=6QT)R!V
M86QU92!S:&]U;&0@8F4@<V5T('1O('1H92!V86QU97,@;V8@=&AE(&EN=&5R
M=F%L"B`J("`@("`@("`@("`@("`@("`@8V]N<W1A;G1S(&%B;W9E+@H@*B`@
M("`@("`@("`@("`@("`@($EF('1H:7,@<')E9F5R96YC92!D;V5S;B=T(&5X
M:7-T+"!T:&4@9&5F875L="!I;G1E<G9A;`H@*B`@("`@("`@("`@("`@("`@
M('5S960@=VEL;"!B92!T:&4@;VYE('1H870@87!P96%R<R!I;B`D;6%I;G1?
M=&%S:W,N"B`J(%LR72!#<F5A=&4@82!D:7)E8W1O<GD@;F%M960@(DA/4D1%
M05!0+VQI8B]-86EN=&5N86YC92(N"B`J(%LS72!#<F5A=&4@82!C;&%S<R!E
M;G1I=&QE9"!-86EN=&5N86YC95](3U)$14%04"!T:&%T(&5X=&5N9',@=&AE
M"B`J("`@("!-86EN=&5N86YC92!C;&%S<RX*("H@("`@(%1H:7,@8VQA<W,@
M<VAO=6QD(&-O;G1A:6X@;VYL>2!T:&4@87!P;&EC871I;VX@<W!E8VEF:6,@
M9&5F:6YI=&EO;G,@;V8*("H@("`@("1M86EN=%]T87-K<R`H<V5E(&%B;W9E
M(&9O<B!D97-C<FEP=&EO;BDN"B`J("`@("!3879E('1H:7,@9FEL92!A<R`B
M2$]21$5!4%`O;&EB+TUA:6YT96YA;F-E+TA/4D1%05!0+G!H<"(N"B`J(%LT
M72!#<F5A=&4@82!D:7)E8W1O<GD@=&ET;&5D(")(3U)$14%04"]L:6(O36%I
M;G1E;F%N8V4O5&%S:R(N"B`J(%LU72!#<F5A=&4@;6]D=6QE<R!I;B!(3U)$
M14%04"]L:6(O36%I;G1E;F%N8V4O5&%S:R!N86UE9"`G4%)%1DY!344N<&AP
M)PH@*B`@("`@=&AA="!E>'1E;F0@=&AE($UA:6YT96YA;F-E7U1A<VL@8VQA
M<W,N"B`J("`@("!4:&4@8VQA<W,@<VAO=6QD(&)E(&YA;65D($UA:6YT96YA
M;F-E7U1A<VM?4%)%1DY!344N"B`J("`@("!4:&4@8VQA<W,@<VAO=6QD(&1E
M8VQA<F4@=&AE(&9O;&QO=VEN9R!T=V\@;65T:&]D<SH*("H@("`@("`@)V1O
M36%I;G1E;F%N8V4G("T@5&AI<R!I<R!T:&4@9G5N8W1I;VX@=&AA="!I<R!R
M=6X@=&\@9&\@=&AE"B`J("`@("`@("`@("`@("`@("`@("`@("`@('-P96-I
M9FEE9"!M86EN=&5N86YC92!O<&5R871I;VXN"B`J("`@("`@("=D97-C<FEB
M94UA:6YT96YA;F-E)R`M(%1H:7,@9G5N8W1I;VX@<V5T<R!T:&4@<')E9F5R
M96YC92!T97AT"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%N
M9"!T97AT('1O(&)E('5S960@;VX@=&AE(&-O;F9I<FUA=&EO;@H@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!P86=E+B`@4VAO=6QD(')E='5R
M;B!A(&1E<V-R:7!T:6]N(&]F('=H870*("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@>6]U<B`G9&]-86EN=&5N86YC92<@9G5N8W1I;VX@:7,@
M86)O=70@=&\@9&\N"B`J("`@("!.96ET:&5R(&9U;F-T:6]N(')E<75I<F5S
M(&%N>2!P87)A;65T97)S('!A<W-E9"!I;BX*("H*("H@5&AE<F4@87)E(#,@
M9&EF9F5R96YT('1Y<&5S(&]F(&UA:6YT96YA;F-E("AS970@=FEA("1?9&ES
M<&QA>5]T>7!E*3H*("H@6S%=($U!24Y414Y!3D-%7T]55%!55%]#3TY&25)-
M"B`J("`@("!%86-H(&]U='!U="!F<F]M(&1E<V-R:6)E36%I;G1E;F%N8V4H
M*2!W:6QL(&AA=F4@82!C:&5C:V)O>"!A<W-O8VEA=&5D"B`J("`@("!W:71H
M(&ET+B!&;W(@96%C:"!C:&5C:V)O>"!S96QE8W1E9"P@9&]-86EN=&5N86YC
M92@I(&9O<B!T:&%T('1A<VL@=VEL;`H@*B`@("`@8F4@<G5N+B!-;W)E('1H
M86X@,2!C;VYF:7)M871I;VX@;65S<V%G92!C86X@8F4@9&ES<&QA>65D(&]N
M('1H90H@*B`@("`@;6%I;G1E;F%N8V4@<&%G92!A="!O;F-E+@H@*@H@*B!;
M,ET@34%)3E1%3D%.0T5?3U544%547T%'4D5%"B`J("`@("!4:&4@;W5T<'5T
M(&9R;VT@9&5S8W)I8F5-86EN=&5N86YC92@I('-H;W5L9"!B92!T97AT(&%S
M:VEN9R!T:&4@=7-E<B!T;PH@*B`@("`@86=R964O9&ES86=R964@=&\@<W!E
M8VEF:65D('1E<FUS+B!)9B`G>65S)R!I<R!S96QE8W1E9"P@=&AE(%!/4U0*
M("H@("`@('9A<FEA8FQE("=A9W)E92<@=VEL;"!B92!S970N($EF("=N;R<@
M:7,@<V5L96-T960L('1H92!03U-4('9A<FEA8FQE"B`J("`@("`G;F]T7V%G
M<F5E)R!W:6QL(&)E('-E="X@26X@96ET:&5R(&-A<V4L(&1O36%I;G1E;F%N
M8V4H*2!W:6QL($%,5T%94R!B90H@*B`@("`@<G5N+@H@*B`@("`@*B!4:&ES
M('-T>6QE('=I;&P@8F4@9&ES<&QA>65D(&]N(&ET<R!O=VXL('-E<&%R871E
M(&UA:6YT96YA;F-E('!A9V4N("H*("H*("H@6S-=($U!24Y414Y!3D-%7T]5
M5%!55%].3U1)0T4*("H@("`@(%1H92!O=71P=70@9G)O;2!D97-C<FEB94UA
M:6YT96YA;F-E*"D@<VAO=6QD(&)E(&%N>2!N;VXM:6YT97)A8W1I=F4@=&5X
M=`H@*B`@("`@9&5S:7)E9"X@5&AE<F4@=VEL;"!B92!A('-I;F=L92`G0VQI
M8VL@=&\@0V]N=&EN=64G(&)U='1O;B!B96QO=R!T:&ES"B`J("`@("!T97AT
M+B!D;TUA:6YT96YA;F-E*"D@=VEL;"!!3%=!65,@8F4@<G5N+@H@*B`@("`@
M*B!4:&ES('-T>6QE('=I;&P@8F4@9&ES<&QA>65D(&]N(&ET<R!O=VXL('-E
M<&%R871E(&UA:6YT96YA;F-E('!A9V4N("H*("H*("H@0V]P>7)I9VAT(#(P
M,#$M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO
M<F%D;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E
M;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`
M<VEN8V4@("!(;W)D92`Q+C,N-0H@*B!`<&%C:V%G92!(;W)D95]-86EN=&5N
M86YC90H@*B\*8VQA<W,@36%I;G1E;F%N8V5?5&%S:R!["@H@("`@+RHJ"B`@
M("`@*B!4:&4@<W1Y;&4@;V8@=&AE(&UA:6YT96YA;F-E('!A9V4@;W5T<'5T
M+@H@("`@("H@4&]S<VEB;&4@=F%L=65S.B!-04E.5$5.04Y#15]/5510551?
M0T].1DE232P*("`@("`J("`@("`@("`@("`@("`@("`@34%)3E1%3D%.0T5?
M3U544%547T%'4D5%+`H@("`@("H@("`@("`@("`@("`@("`@("!-04E.5$5.
M04Y#15]/5510551?3D]424-%"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R
M"B`@("`@*B\*("`@('9A<B`D7V1I<W!L87E?='EP92`]($U!24Y414Y!3D-%
M7T]55%!55%]#3TY&25)-.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*
M("`@("`J+PH@("`@9G5N8W1I;VX@36%I;G1E;F%N8V5?5&%S:R@I"B`@("![
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$;R!M86EN=&5N86YC92!O<&5R871I
M;VX@*&EF(&ET(&AA<R!B965N(&-O;F9I<FUE9"DN"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N("!7:&5T:&5R('1H92!M86EN=&5N86YC92!O<&5R
M871I;VX@=V%S('-U8V-E<W-F=6P@;W(*("`@("`J("`@("`@("`@("`@("`@
M("`@;F]T+@H@("`@("HO"B`@("!F=6YC=&EO;B!D;TUA:6YT96YA;F-E*"D*
M("`@('L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FX@9&5S8W)I<'1I;VX@:6YF;W)M871I;VX@9F]R('1H92!M
M86EN=&5N86YC92!P86=E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!$97-C<FEP=&EO;B!T:&%T('=I;&P@8F4@9&ES<&QA>65D(&]N('1H92!M
M86EN=&5N86YC90H@("`@("H@("`@("`@("`@("`@("`@(&-O;F9I<FUA=&EO
M;B!P86=E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D97-C<FEB94UA:6YT96YA
M;F-E*"D*("`@('L*("`@("`@("!R971U<FX@)R<["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92!D97-I<F5D(&]U='!U="!T>7!E(&9O<B!T
M:&4@;6%I;G1E;F%N8V4@<&%G92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN
M=&5G97(@($1E<VER960@;W5T<'5T('1Y<&4@9F]R('1H92!M86EN=&5N86YC
M92!C;VYF:7)M871I;VX*("`@("`J("`@("`@("`@("`@("`@("`@<&%G92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&ES<&QA>51Y<&4H*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7V1I<W!L87E?='EP93L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]397-S:6]N2&%N9&QE<BYP
M:'``````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q-S<Q,B`Q,#4Q
M-30S,S<T,"`P,C,P,#8`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J(%-E<W-I;VY(86YD;&5R.CH@9&5F
M:6YE<R!A;B!!4$D@9F]R(&EM<&QE;65N=&EN9R!C=7-T;VT@<V5S<VEO;@H@
M*B!H86YD;&5R<R!F;W(@4$A0+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]3
M97-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`L=B`Q+C$S+C$P+C$Q
M(#(P,#8O,#<O,30@,#@Z-30Z-3D@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`R+3(P,#8@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC
M;RYN>CX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A
M;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!S:6YC92`@($AO<F1E
M(#,N,`H@*B!`<&%C:V%G92!(;W)D95]397-S:6]N2&%N9&QE<@H@*B\*8VQA
M<W,@4V5S<VEO;DAA;F1L97(@>PH*("`@("\J*@H@("`@("H@2&%S:"!C;VYT
M86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A<F%M<R`](&%R<F%Y*"D[
M"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W(%-E<W-I;VY(86YD
M;&5R(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M
M<R`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!397-S:6]N2&%N9&QE<B@D<&%R86US(#T@
M87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P87)A
M;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@
M82!C;VYC<F5T92!397-S:6]N2&%N9&QE<B!I;G-T86YC92!B87-E9"!O;@H@
M("`@("H@)&1R:79E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D
M<FEV97(@(%1H92!T>7!E(&]F(&-O;F-R971E(%-E<W-I;VY(86YD;&5R('-U
M8F-L87-S('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;BX*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@02!H87-H(&-O;G1A
M:6YI;F<@86YY(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!O<@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("!C;VYN96-T:6]N('!A<F%M971E<G,@
M82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R971E(%-E<W-I;VY(86YD
M;&5R(&EN<W1A;F-E+"!O<@H@("`@("H@("`@("`@("`@("`@("`@9F%L<V4@
M;VX@86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1D
M<FEV97(L("1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]A
M<G)A>2@D9')I=F5R*2D@>PH@("`@("`@("`@("`D87!P(#T@)&1R:79E<ELP
M73L*("`@("`@("`@("`@)&1R:79E<B`]("1D<FEV97);,5T["B`@("`@("`@
M?0H*("`@("`@("`D9')I=F5R(#T@8F%S96YA;64H)&1R:79E<BD["B`@("`@
M("`@:68@*"1D<FEV97(@/3T@)VUE;6-A8VAE9"<I('L*("`@("`@("`@("`@
M+R\@5')A<"!F;W(@;VQD(&1R:79E<B!N86UE+@H@("`@("`@("`@("`D9')I
M=F5R(#T@)VUE;6-A8VAE)SL*("`@("`@("!]"@H@("`@("`@("1C;&%S<R`]
M("=397-S:6]N2&%N9&QE<E\G("X@)&1R:79E<CL*("`@("`@("!I9B`H(6-L
M87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@(&EF("@A96UP='DH
M)&%P<"DI('L*("`@("`@("`@("`@("`@(&EN8VQU9&5?;VYC92`D1TQ/0D%,
M4ULG<F5G:7-T<GDG72T^9V5T*"=F:6QE<F]O="<L("1A<'`I("X@)R]L:6(O
M4V5S<VEO;DAA;F1L97(O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("!I;F-L=61E7V]N8V4@)TAO
M<F1E+U-E<W-I;VY(86YD;&5R+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H8VQA<W-?97AI<W1S
M*"1C;&%S<RDI('L*("`@("`@("`@("`@:68@*&ES7VYU;&PH)'!A<F%M<RDI
M('L*("`@("`@("`@("`@("`@(&EN8VQU9&5?;VYC92`G2&]R9&4N<&AP)SL*
M("`@("`@("`@("`@("`@("1P87)A;7,@/2!(;W)D93HZ9V5T1')I=F5R0V]N
M9FEG*"=S97-S:6]N:&%N9&QE<B<L("1D<FEV97(I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1H86YD;&5R(#T@;F5W("1C;&%S<R@D<&%R86US*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D:&%N9&QE<B`](%!%05(Z
M.G)A:7-E17)R;W(H)T-L87-S(&1E9FEN:71I;VX@;V8@)R`N("1C;&%S<R`N
M("<@;F]T(&9O=6YD+B<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1H
M86YD;&5R.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T
M=7)N(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@4V5S<VEO;DAA;F1L97(*
M("`@("`J(&EN<W1A;F-E(&)A<V5D(&]N("1D<FEV97(N($ET('=I;&P@;VYL
M>2!C<F5A=&4@82!N97<@:6YS=&%N8V4*("`@("`J(&EF(&YO(%-E<W-I;VY(
M86YD;&5R(&EN<W1A;F-E('=I=&@@=&AE('-A;64@<&%R86UE=&5R<PH@("`@
M("H@8W5R<F5N=&QY(&5X:7-T<RX*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO
M9"!M=7-T(&)E(&EN=F]K960@87,Z("1V87(@/2`F4V5S<VEO;DAA;F1L97(Z
M.G-I;F=L971O;B@I"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9')I
M=F5R("!3964@4V5S<VEO;DAA;F1L97(Z.F9A8W1O<GDH*2X*("`@("`J($!P
M87)A;2!A<G)A>2`D<&%R86US("`@4V5E(%-E<W-I;VY(86YD;&5R.CIF86-T
M;W)Y*"DN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&-R96%T
M960@8V]N8W)E=&4@4V5S<VEO;DAA;F1L97(@:6YS=&%N8V4L(&]R(&9A;'-E
M"B`@("`@*B`@("`@("`@("`@("`@("!O;B!E<G)O<BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@)G-I;F=L971O;B@D9')I=F5R+"`D<&%R86US(#T@;G5L;"D*
M("`@('L*("`@("`@("!S=&%T:6,@)&EN<W1A;F-E<R`](&%R<F%Y*"D["@H@
M("`@("`@("1S:6=N871U<F4@/2!S97)I86QI>F4H87)R87DH)&1R:79E<BP@
M)'!A<F%M<RDI.PH@("`@("`@(&EF("AE;7!T>2@D:6YS=&%N8V5S6R1S:6=N
M871U<F5=*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S6R1S:6=N871U<F5=
M(#T@)E-E<W-I;VY(86YD;&5R.CIF86-T;W)Y*"1D<FEV97(L("1P87)A;7,I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;)'-I9VYA
M='5R95T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!/<&5N('1H92!397-S:6]N
M2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'-A=F5?<&%T:"`@("`@5&AE('!A
M=&@@=&\@=&AE('-E<W-I;VX@;V)J96-T+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<V5S<VEO;E]N86UE("!4:&4@;F%M92!O9B!T:&4@<V5S<VEO;BX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@
M9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!O<&5N*"1S
M879E7W!A=&@L("1S97-S:6]N7VYA;64I"B`@("!["B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;&]S92!T:&4@4V5S<VEO
M;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@
M9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;&]S92@I
M"B`@("!["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!296%D('1H92!D871A(&9O<B!A('!A<G1I8W5L87(@<V5S<VEO;B!I
M9&5N=&EF:65R(&9R;VT@=&AE"B`@("`@*B!397-S:6]N2&%N9&QE<B!B86-K
M96YD+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&ED("!4:&4@<V5S<VEO;B!I9&5N=&EF:65R+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<V5S<VEO;B!D871A+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!R96%D*"1I9"D*("`@('L*("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;W0@<W5P<&]R=&5D+B(I*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%=R:71E('-E<W-I;VX@9&%T82!T;R!T
M:&4@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`86)S
M=')A8W0*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@("`@("`@
M("`@(%1H92!S97-S:6]N(&ED96YT:69I97(N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1S97-S:6]N7V1A=&$@(%1H92!S97-S:6]N(&1A=&$N"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E
M(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@=W)I=&4H)&ED+"`D
M<V5S<VEO;E]D871A*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*%\H(DYO="!S=7!P;W)T960N(BDI.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1&5S=')O>2!T:&4@9&%T82!F;W(@82!P87)T:6-U;&%R('-E<W-I
M;VX@:61E;G1I9FEE<B!I;B!T:&4*("`@("`J(%-E<W-I;VY(86YD;&5R(&)A
M8VME;F0N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D:60@(%1H92!S97-S:6]N(&ED96YT:69I97(N"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L
M(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5S=')O
M>2@D:60I"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M7R@B3F]T('-U<'!O<G1E9"XB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'
M87)B86=E(&-O;&QE8W0@<W1A;&4@<V5S<VEO;G,@9G)O;2!T:&4@4V5S<VEO
M;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;6%X;&EF971I;64@(%1H92!M
M87AI;75M(&%G92!O9B!A('-E<W-I;VXN"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]T:&5R=VES92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V,H)&UA>&QI9F5T:6UE(#T@,S`P*0H@
M("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DYO="!S
M=7!P;W)T960N(BDI.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE
M<R!I9B!A('-E<W-I;VX@8F5L;VYG<R!T;R!A;B!A=71H96YT:6-A=&5D('5S
M97(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<V5S<VEO;E]D871A("!4:&4@<V5S<VEO;B!D
M871A(&ET<V5L9BX*("`@("`J($!P87)A;2!B;V]L96%N("1R971U<FY?=7-E
M<B`@268@=')U92P@<F5T=7)N('1H92!U<V5R('-E<W-I;VX@9&%T82X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86Y\<W1R:6YG("!4<G5E(&]R('1H
M92!U<V5R)W,@<V5S<VEO;B!D871A(&EF('1H92!S97-S:6]N"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!B96QO;F=S('1O(&%N(&%U=&AE;G1I
M8V%T960@=7-E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@7VES075T:&5N=&EC
M871E9"@D<V5S<VEO;E]D871A+"`D<F5T=7)N7V1A=&$@/2!F86QS92D*("`@
M('L*("`@("`@("!I9B`H96UP='DH)'-E<W-I;VY?9&%T82DI('L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@=VAI;&4@
M*"1S97-S:6]N7V1A=&$I('L*("`@("`@("`@("`@)'9A<G,@/2!E>'!L;V1E
M*"=\)RP@)'-E<W-I;VY?9&%T82P@,BD["B`@("`@("`@("`@("1D871A(#T@
M=6YS97)I86QI>F4H)'9A<G-;,5TI.PH@("`@("`@("`@("!I9B`H)'9A<G-;
M,%T@/3T@)U]?875T:"<I('L*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D
M9&%T82DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1D
M871A6R=A=71H96YT:6-A=&5D)UTI*2!["B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1R971U<FY?9&%T82`_("1D871A(#H@=')U93L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D<V5S<VEO;E]D871A(#T@<W5B<W1R*"1S
M97-S:6]N7V1A=&$L('-T<FQE;B@D=F%R<ULP72D@*R!S=')L96XH<V5R:6%L
M:7IE*"1D871A*2D@*R`Q*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!'970@82!L:7-T(&]F('1H92!V86QI9"!S97-S:6]N(&ED96YT:69I
M97)S+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@($$@;&ES="!O9B!V86QI9"!S97-S:6]N(&ED96YT:69I
M97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971397-S:6]N241S*"D*("`@
M('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;W0@<W5P
M<&]R=&5D+B(I*3L*("`@('T*"B`@("`O*BH*("`@("`J($1E=&5R;6EN92!T
M:&4@;G5M8F5R(&]F(&-U<G)E;G1L>2!L;V=G960@:6X@=7-E<G,N"B`@("`@
M*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!!(&-O=6YT(&]F(&QO9V=E9"!I
M;B!U<V5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@8V]U;G1!=71H96YT:6-A
M=&5D57-E<G,H*0H@("`@>PH@("`@("`@("1C;W5N="`](#`["@H@("`@("`@
M("1S97-S:6]N<R`]("1T:&ES+3YG971397-S:6]N241S*"D["B`@("`@("`@
M:68@*&ES7V$H)'-E<W-I;VYS+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D<V5S<VEO;G,["B`@("`@("`@?0H*("`@("`@("!F;W)E
M86-H("@D<V5S<VEO;G,@87,@)&ED*2!["B`@("`@("`@("`@("1D871A(#T@
M)'1H:7,M/G)E860H)&ED*3L*("`@("`@("`@("`@:68@*"%I<U]A*"1D871A
M+"`G4$5!4E]%<G)O<B<I("8F"B`@("`@("`@("`@("`@("`D=&AI<RT^7VES
M075T:&5N=&EC871E9"@D9&%T82DI('L*("`@("`@("`@("`@("`@("1C;W5N
M="LK.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&-O=6YT.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&QI<W0@
M;V8@8W5R<F5N=&QY(&QO9V=E9"!I;B!U<V5R<RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!!(&QI<W0@;V8@;&]G9V5D(&EN('5S97)S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!L:7-T075T:&5N=&EC871E9%5S97)S*"1D871E
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'5S97)S(#T@87)R87DH*3L*"B`@
M("`@("`@)'-E<W-I;VYS(#T@)'1H:7,M/F=E=%-E<W-I;VY)1',H*3L*("`@
M("`@("!I9B`H:7-?82@D<V5S<VEO;G,L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1S97-S:6]N<SL*("`@("`@("!]"@H@("`@("`@
M(&9O<F5A8V@@*"1S97-S:6]N<R!A<R`D:60I('L*("`@("`@("`@("`@)&1A
M=&$@/2`D=&AI<RT^<F5A9"@D:60I.PH@("`@("`@("`@("!I9B`H:7-?82@D
M9&%T82P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@8V]N=&EN
M=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1D871A(#T@)'1H:7,M
M/E]I<T%U=&AE;G1I8V%T960H)&1A=&$L('1R=64I.PH@("`@("`@("`@("!I
M9B`H)&1A=&$@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D=7-E<B`]
M("1D871A6R=U<V5R260G73L*("`@("`@("`@("`@("`@(&EF("@D9&%T92D@
M>PH@("`@("`@("`@("`@("`@("`@("1U<V5R(#T@9&%T92@G<B<L("1D871A
M6R=T:6UE<W1A;7`G72D@+B`G("`G("X@)'5S97(["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`D=7-E<G-;72`]("1U<V5R.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'5S97)S.PH@("`@
M?0H*?0H`````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O1F]R;2YP:'``````````````````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`S,C0V-3(@,3`U,34T,S,W-#`@,#(P-S<T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B!(
M;W)D95]&;W)M($UA<W1E<B!#;&%S<RX*("H*("H@5&AE($AO<F1E7T9O<FTZ
M.B!P86-K86=E('!R;W9I9&5S(&9O<FT@<F5N9&5R:6YG+"!V86QI9&%T:6]N
M+"!A;F0*("H@;W1H97(@9G5N8W1I;VYA;&ET>2!F;W(@=&AE($AO<F1E($%P
M<&QI8V%T:6]N($9R86UE=V]R:RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<"QV(#$N,S`V+C(N-#@@,C`P-B\P-"\R-B`Q-3HU,CHR
M.2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#$M,C`P-B!2;V)E<G0@
M12X@0V]Y;&4@/')O8F5R=&5C;WEL94!H;W1M86EL+F-O;3X*("H@0V]P>7)I
M9VAT(#(P,#$M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@(%)O8F5R="!%+B!#;WEL
M92`\<F]B97)T96-O>6QE0&AO=&UA:6PN8V]M/@H@*B!`<VEN8V4@("!(;W)D
M92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?1F]R;0H@*B\*8VQA<W,@2&]R9&5?
M1F]R;2!["@H@("`@=F%R("1?;F%M92`]("<G.PH@("`@=F%R("1?=&ET;&4@
M/2`G)SL*("`@('9A<B`D7V5X=')A(#T@)R<["B`@("!V87(@)%]V87)S.PH@
M("`@=F%R("1?<W5B;6ET(#T@87)R87DH*3L*("`@('9A<B`D7W)E<V5T(#T@
M9F%L<V4["B`@("!V87(@)%]E<G)O<G,@/2!A<G)A>2@I.PH@("`@=F%R("1?
M<W5B;6ET=&5D(#T@;G5L;#L*("`@('9A<B`D7W-E8W1I;VYS(#T@87)R87DH
M*3L*("`@('9A<B`D7V]P96Y?<V5C=&EO;B`](&YU;&P["B`@("!V87(@)%]C
M=7)R96YT4V5C=&EO;B`](&%R<F%Y*"D["B`@("!V87(@)%]V87)I86)L97,@
M/2!A<G)A>2@I.PH@("`@=F%R("1?:&ED9&5N5F%R:6%B;&5S(#T@87)R87DH
M*3L*("`@('9A<B`D7W5S949O<FU4;VME;B`]('1R=64["B`@("!V87(@)%]A
M=71O9FEL;&5D(#T@9F%L<V4["B`@("!V87(@)%]E;F-T>7!E(#T@;G5L;#L*
M("`@('9A<B`D7VAE;'`@/2!F86QS93L*"B`@("!F=6YC=&EO;B!(;W)D95]&
M;W)M*"8D=F%R<RP@)'1I=&QE(#T@)R<L("1N86UE(#T@;G5L;"D*("`@('L*
M("`@("`@("!I9B`H:7-?;G5L;"@D;F%M92DI('L*("`@("`@("`@("`@)&YA
M;64@/2!3=')I;F<Z.FQO=V5R*&=E=%]C;&%S<R@D=&AI<RDI.PH@("`@("`@
M('T*"B`@("`@("`@)'1H:7,M/E]V87)S(#T@)B1V87)S.PH@("`@("`@("1T
M:&ES+3Y?=&ET;&4@/2`D=&ET;&4["B`@("`@("`@)'1H:7,M/E]N86UE(#T@
M)&YA;64["B`@("!]"@H@("`@9G5N8W1I;VX@)G-I;F=L971O;B@D9F]R;2P@
M)B1V87)S+"`D=&ET;&4@/2`G)RP@)&YA;64@/2!N=6QL*0H@("`@>PH@("`@
M("`@('-T871I8R`D:6YS=&%N8V5S.PH*("`@("`@("`D<VEG;F%T=7)E(#T@
M<V5R:6%L:7IE*&%R<F%Y*"1F;W)M+"`D=F%R<RP@)'1I=&QE+"`D;F%M92DI
M.PH@("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E<ULD<VEG;F%T=7)E72DI
M('L*("`@("`@("`@("`@:68@*&-L87-S7V5X:7-T<R@D9F]R;2DI('L*("`@
M("`@("`@("`@("`@("1I;G-T86YC97-;)'-I9VYA='5R95T@/2`F;F5W("1F
M;W)M*"1V87)S+"`D=&ET;&4L("1N86UE*3L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1I;G-T86YC97-;)'-I9VYA='5R95T@/2`F
M;F5W($AO<F1E7T9O<FTH)'9A<G,L("1T:71L92P@)&YA;64I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EN<W1A;F-E<ULD
M<VEG;F%T=7)E73L*("`@('T*"B`@("!F=6YC=&EO;B!S971687)S*"8D=F%R
M<RD*("`@('L*("`@("`@("`D=&AI<RT^7W9A<G,@/2`F)'9A<G,["B`@("!]
M"@H@("`@9G5N8W1I;VX@9V5T5&ET;&4H*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7W1I=&QE.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=%1I=&QE
M*"1T:71L92D*("`@('L*("`@("`@("`D=&AI<RT^7W1I=&QE(#T@)'1I=&QE
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$5X=')A*"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]E>'1R83L*("`@('T*"B`@("!F=6YC=&EO;B!S
M971%>'1R82@D97AT<F$I"B`@("!["B`@("`@("`@)'1H:7,M/E]E>'1R82`]
M("1E>'1R83L*("`@('T*"B`@("!F=6YC=&EO;B!G971.86UE*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]N86UE.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4V5T<R!O<B!G971S('=H971H97(@=&AE(&9O<FT@<VAO=6QD(&)E
M('9E<FEF:65D(&)Y('1O:V5N<RX*("`@("`J(%1O:V5N<R!A<F4@=7-E9"!T
M;R!V97)I9GD@=&AA="!A(&9O<FT@:7,@;VYL>2!S=6)M:71T960@;VYC92X*
M("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D=&]K96X@($EF('-P96-I
M9FEE9"P@<V5T<R!W:&5T:&5R('1O('5S92!F;W)M('1O:V5N<RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@9F]R;2!T;VME;G,@
M87)E(&)E:6YG('5S960N"B`@("`@*B\*("`@(&9U;F-T:6]N('5S951O:V5N
M*"1T;VME;B`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"%I<U]N=6QL*"1T
M;VME;BDI('L*("`@("`@("`@("`@)'1H:7,M/E]U<V5&;W)M5&]K96X@/2`D
M=&]K96X["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^7W5S949O
M<FU4;VME;CL*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@<F5N9&5R
M97(@9F]R('1H:7,@9F]R;2P@96ET:&5R(&$@8W5S=&]M(')E;F1E<F5R(&]R
M('1H90H@("`@("H@<W1A;F1A<F0@;VYE+@H@("`@("H*("`@("`J(%1O('5S
M92!A(&-U<W1O;2!F;W)M(')E;F1E<F5R+"!Y;W5R(&9O<FT@8VQA<W,@;F5E
M9',@=&\*("`@("`J(&]V97)R:61E('1H:7,@9G5N8W1I;VXZ"B`@("`@*B`\
M8V]D93X*("`@("`J(&9U;F-T:6]N("9G971296YD97)E<B@I"B`@("`@*B![
M"B`@("`@*B`@("`@)'(@/2`F;F5W($-U<W1O;49O<FU296YD97)E<B@I.PH@
M("`@("H@("`@(')E='5R;B`D<CL*("`@("`J('T*("`@("`J(#PO8V]D93X*
M("`@("`J"B`@("`@*B`N+BX@=VAE<F4@0W5S=&]M1F]R;5)E;F1E<F5R(&ES
M('1H92!C;&%S<VYA;64@;V8@=&AE(&-U<W1O;0H@("`@("H@<F5N9&5R97(@
M8VQA<W,L('=H:6-H('-H;W5L9"!E>'1E;F0@2&]R9&5?1F]R;5]296YD97)E
M<BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H
M(&]F(')E;F1E<F5R+7-P96-I9FEC('!A<F%M971E<G,N"B`@("`@*@H@("`@
M("H@0')E='5R;B!O8FIE8W0@2&]R9&5?1F]R;5]296YD97)E<B`@5&AE(&9O
M<FT@<F5N9&5R97(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9G971296YD97)E
M<B@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!R97%U:7)E7V]N
M8V4@)TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP)SL*("`@("`@("`D<F5N9&5R
M97(@/2`F;F5W($AO<F1E7T9O<FU?4F5N9&5R97(H)'!A<F%M<RD["B`@("`@
M("`@<F5T=7)N("1R96YD97)E<CL*("`@('T*"B`@("!F=6YC=&EO;B`F9V5T
M5'EP92@D='EP92P@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M)'1Y<&5?8VQA<W,@/2`G2&]R9&5?1F]R;5]4>7!E7R<@+B`D='EP93L*("`@
M("`@("!I9B`H(6-L87-S7V5X:7-T<R@D='EP95]C;&%S<RDI('L*("`@("`@
M("`@("`@<F5Q=6ER95]O;F-E("=014%2+G!H<"<["B`@("`@("`@("`@($AO
M<F1E.CIF871A;"A014%2.CIR86ES945R<F]R*'-P<FEN=&8H)TYO;F5X:7-T
M86YT(&-L87-S("(E<R(@9F]R(&9I96QD('1Y<&4@(B5S(B<L("1T>7!E7V-L
M87-S+"`D='EP92DI+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*
M("`@("`@("`D='EP95]O8B`]("9N97<@)'1Y<&5?8VQA<W,H*3L*("`@("`@
M("!C86QL7W5S97)?9G5N8U]A<G)A>2AA<G)A>2@F)'1Y<&5?;V(L("=I;FET
M)RDL("1P87)A;7,I.PH@("`@("`@(')E='5R;B`D='EP95]O8CL*("`@('T*
M"B`@("!F=6YC=&EO;B!S971396-T:6]N*"1S96-T:6]N(#T@)R<L("1D97-C
M(#T@)R<L("1I;6%G92`]("<G+"`D97AP86YD960@/2!T<G5E*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?8W5R<F5N=%-E8W1I;VX@/2`D<V5C=&EO;CL*("`@
M("`@("!I9B`H(6-O=6YT*"1T:&ES+3Y?<V5C=&EO;G,I("8F("$D=&AI<RT^
M9V5T3W!E;E-E8W1I;VXH*2D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T3W!E
M;E-E8W1I;VXH)'-E8W1I;VXI.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^
M7W-E8W1I;VYS6R1S96-T:6]N75LG9&5S8R==(#T@)&1E<V,["B`@("`@("`@
M)'1H:7,M/E]S96-T:6]N<ULD<V5C=&EO;EU;)V5X<&%N9&5D)UT@/2`D97AP
M86YD960["B`@("`@("`@)'1H:7,M/E]S96-T:6]N<ULD<V5C=&EO;EU;)VEM
M86=E)UT@/2`D:6UA9V4["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T4V5C=&EO
M;D1E<V,H)'-E8W1I;VXI"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M<V5C=&EO;G-;)'-E8W1I;VY=6R=D97-C)UT["B`@("!]"@H@("`@9G5N8W1I
M;VX@9V5T4V5C=&EO;DEM86=E*"1S96-T:6]N*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7W-E8W1I;VYS6R1S96-T:6]N75LG:6UA9V4G73L*("`@
M('T*"B`@("!F=6YC=&EO;B!S971/<&5N4V5C=&EO;B@D<V5C=&EO;BD*("`@
M('L*("`@("`@("`D=&AI<RT^7W9A<G,M/G-E="@G7U]F;W)M3W!E;E-E8W1I
M;VXG+"`D<V5C=&EO;BD["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T3W!E;E-E
M8W1I;VXH*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W9A<G,M/F=E
M="@G7U]F;W)M3W!E;E-E8W1I;VXG*3L*("`@('T*"B`@("!F=6YC=&EO;B!G
M971396-T:6]N17AP86YD9613=&%T92@D<V5C=&EO;BP@)&)O;VQE86X@/2!F
M86QS92D*("`@('L*("`@("`@("!I9B`H)&)O;VQE86XI('L*("`@("`@("`@
M("`@+RH@3VYL>2!T:&4@8F]O;&5A;B!V86QU92!I<R!R97%U:7)E9"X@*B\*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<V5C=&EO;G-;)'-E8W1I;VY=
M6R=E>'!A;F1E9"==.PH@("`@("`@('T*"B`@("`@("`@+RH@3F5E9"!T;R!R
M971U<FX@=&AE('9A;'5E<R!F;W(@=7-E(&EN('-T>6QE<RX@*B\*("`@("`@
M("!I9B`H)'1H:7,M/E]S96-T:6]N<ULD<V5C=&EO;EU;)V5X<&%N9&5D)UTI
M('L*("`@("`@("`@("`@<F5T=7)N("=B;&]C:R<["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@<F5T=7)N("=N;VYE)SL*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!43T1/"B`@("`@*B\*("`@(&9U;F-T:6]N("9A
M9&1687)I86)L92@D:'5M86Y.86UE+"`D=F%R3F%M92P@)'1Y<&4L("1R97%U
M:7)E9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5A9&]N;'D@/2!F
M86QS92P@)&1E<V-R:7!T:6]N(#T@;G5L;"P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/FEN<V5R=%9A<FEA8FQE0F5F;W)E*&YU;&PL("1H=6UA;DYA
M;64L("1V87).86UE+"`D='EP92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1R97%U:7)E9"P@)')E861O;FQY+"`D9&5S
M8W)I<'1I;VXL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<&%R86US*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1/1$\*
M("`@("`J+PH@("`@9G5N8W1I;VX@)FEN<V5R=%9A<FEA8FQE0F5F;W)E*"1B
M969O<F4L("1H=6UA;DYA;64L("1V87).86UE+"`D='EP92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5Q=6ER960L("1R96%D;VYL
M>2`](&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1D97-C<FEP=&EO;B`](&YU;&PL("1P87)A;7,@/2!A<G)A>2@I*0H@("`@
M>PH@("`@("`@("1T>7!E(#T@)B1T:&ES+3YG9714>7!E*"1T>7!E+"`D<&%R
M86US*3L*("`@("`@("`D=F%R(#T@)FYE=R!(;W)D95]&;W)M7U9A<FEA8FQE
M*"1H=6UA;DYA;64L("1V87).86UE+"`D='EP92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1R97%U:7)E9"P@)')E861O;FQY
M+"`D9&5S8W)I<'1I;VXI.PH*("`@("`@("`O*B!3970@=&AE(&9O<FT@;V)J
M96-T(')E9F5R96YC92!I;B!T:&4@=F%R+B`J+PH@("`@("`@("1V87(M/G-E
M=$9O<FU/8B@D=&AI<RD["@H@("`@("`@(&EF("@D=F%R+3YG9714>7!E3F%M
M92@I(#T]("=E;G5M)R`F)@H@("`@("`@("`@("!C;W5N="@D=F%R+3YG9716
M86QU97,H*2D@/3T@,2D@>PH@("`@("`@("`@("`D=F%L<R`](&%R<F%Y7VME
M>7,H)'9A<BT^9V5T5F%L=65S*"DI.PH@("`@("`@("`@("`D=&AI<RT^7W9A
M<G,M/F%D9"@D=F%R+3YV87).86UE+"`D=F%L<ULP72D["B`@("`@("`@("`@
M("1V87(M/E]A=71O9FEL;&5D(#T@=')U93L*("`@("`@("!](&5L<V5I9B`H
M)'9A<BT^9V5T5'EP94YA;64H*2`]/2`G9FEL92<@?'P*("`@("`@("`@("`@
M("`@("`@)'9A<BT^9V5T5'EP94YA;64H*2`]/2`G:6UA9V4G*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?96YC='EP92`]("=M=6QT:7!A<G0O9F]R;2UD871A
M)SL*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?8W5R<F5N
M=%-E8W1I;VXI*2!["B`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=%-E8W1I
M;VX@/2`G7U]B87-E)SL*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]N=6QL
M*"1B969O<F4I*2!["B`@("`@("`@("`@("1T:&ES+3Y?=F%R:6%B;&5S6R1T
M:&ES+3Y?8W5R<F5N=%-E8W1I;VY=6UT@/2`F)'9A<CL*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D;G5M(#T@,#L*("`@("`@("`@("`@=VAI;&4@
M*&ES<V5T*"1T:&ES+3Y?=F%R:6%B;&5S6R1T:&ES+3Y?8W5R<F5N=%-E8W1I
M;VY=6R1N=6U=*2`F)@H@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]V87)I
M86)L97-;)'1H:7,M/E]C=7)R96YT4V5C=&EO;EU;)&YU;5TM/F=E=%9A<DYA
M;64H*2`A/2`D8F5F;W)E*2!["B`@("`@("`@("`@("`@("`D;G5M*RL["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W9A
M<FEA8FQE<ULD=&AI<RT^7V-U<G)E;G1396-T:6]N75LD;G5M72DI('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?=F%R:6%B;&5S6R1T:&ES+3Y?8W5R<F5N
M=%-E8W1I;VY=6UT@/2`F)'9A<CL*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?=F%R:6%B;&5S6R1T:&ES+3Y?8W5R<F5N
M=%-E8W1I;VY=(#T@87)R87E?;65R9V4H"B`@("`@("`@("`@("`@("`@("`@
M87)R87E?<VQI8V4H)'1H:7,M/E]V87)I86)L97-;)'1H:7,M/E]C=7)R96YT
M4V5C=&EO;ETL(#`L("1N=6TI+`H@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"8D=F%R*2P*("`@("`@("`@("`@("`@("`@("!A<G)A>5]S;&EC92@D=&AI
M<RT^7W9A<FEA8FQE<ULD=&AI<RT^7V-U<G)E;G1396-T:6]N72P@)&YU;2DI
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'9A
M<CL*("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V97,@82!V87)I86)L92!F
M<F]M('1H92!F;W)M+@H@("`@("H*("`@("`J($%S(&]N;'D@=F%R:6%B;&5S
M(&-A;B!B92!P87-S960@8GD@<F5F97)E;F-E+"!Y;W4@;F5E9"!T;R!C86QL
M('1H:7,*("`@("`J(&UE=&AO9"!T:&ES('=A>2!I9B!W86YT('1O('!A<W,@
M82!V87)I86)L92!N86UE.@H@("`@("H@/&-O9&4^"B`@("`@*B`D9F]R;2T^
M<F5M;W9E5F%R:6%B;&4H)'9A<B`]("=V87)N86UE)RD["B`@("`@*B`\+V-O
M9&4^"B`@("`@*@H@("`@("H@0'!A<F%M($AO<F1E7T9O<FU?5F%R:6%B;&5\
M<W1R:6YG("1V87(@($5I=&AE<B!T:&4@=F%R:6%B;&4G<R!N86UE(&]R"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M=&AE('9A<FEA8FQE('1O(')E;6]V92!F<F]M('1H90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O<FTN"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!V87)I86)L
M92!W87,@9F]U;F0@*&%N9"!D96QE=&5D*2X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F5M;W9E5F%R:6%B;&4H)B1V87(I"B`@("!["B`@("`@("`@9F]R96%C
M:"`H87)R87E?:V5Y<R@D=&AI<RT^7W9A<FEA8FQE<RD@87,@)'-E8W1I;VXI
M('L*("`@("`@("`@("`@9F]R96%C:"`H87)R87E?:V5Y<R@D=&AI<RT^7W9A
M<FEA8FQE<ULD<V5C=&EO;ETI(&%S("1I*2!["B`@("`@("`@("`@("`@("!I
M9B`H*&ES7V$H)'9A<BP@)TAO<F1E7T9O<FU?5F%R:6%B;&4G*2`F)B`D=&AI
M<RT^7W9A<FEA8FQE<ULD<V5C=&EO;EU;)&E=(#T]/2`D=F%R*2!\?`H@("`@
M("`@("`@("`@("`@("`@("@D=&AI<RT^7W9A<FEA8FQE<ULD<V5C=&EO;EU;
M)&E=+3YG971687).86UE*"D@/3T@)'9A<BDI('L*("`@("`@("`@("`@("`@
M("`@("`O+R!3;&EC92!O=70@=&AE('9A<FEA8FQE('1O(&)E(')E;6]V960N
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]V87)I86)L97-;)'1H:7,M
M/E]C=7)R96YT4V5C=&EO;ET@/2!A<G)A>5]M97)G92@*("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87E?<VQI8V4H)'1H:7,M/E]V87)I86)L97-;)'1H
M:7,M/E]C=7)R96YT4V5C=&EO;ETL(#`L("1I*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@87)R87E?<VQI8V4H)'1H:7,M/E]V87)I86)L97-;)'1H:7,M
M/E]C=7)R96YT4V5C=&EO;ETL("1I("L@,2DI.PH*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@5$]$3PH@("`@("HO"B`@("!F=6YC=&EO;B`F861D
M2&ED9&5N*"1H=6UA;DYA;64L("1V87).86UE+"`D='EP92P@)')E<75I<F5D
M+`H@("`@("`@("`@("`@("`@("`@("`@("`D<F5A9&]N;'D@/2!F86QS92P@
M)&1E<V-R:7!T:6]N(#T@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@
M)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1Y<&4@/2`F)'1H
M:7,M/F=E=%1Y<&4H)'1Y<&4L("1P87)A;7,I.PH@("`@("`@("1V87(@/2`F
M;F5W($AO<F1E7T9O<FU?5F%R:6%B;&4H)&AU;6%N3F%M92P@)'9A<DYA;64L
M("1T>7!E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)')E<75I<F5D+"`D<F5A9&]N;'DL("1D97-C<FEP=&EO;BD["B`@("`@
M("`@)'9A<BT^:&ED92@I.PH@("`@("`@("1T:&ES+3Y?:&ED9&5N5F%R:6%B
M;&5S6UT@/2`F)'9A<CL*("`@("`@("!R971U<FX@)'9A<CL*("`@('T*"B`@
M("!F=6YC=&EO;B`F9V5T5F%R:6%B;&5S*"1F;&%T(#T@=')U92P@)'=I=&A(
M:61D96X@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H)&9L870I('L*("`@
M("`@("`@("`@)'9A<G,@/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W)E86-H
M("@D=&AI<RT^7W9A<FEA8FQE<R!A<R`D<V5C=&EO;BD@>PH@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)'-E8W1I;VX@87,@)'9A<BD@>PH@("`@("`@("`@
M("`@("`@("`@("1V87)S6UT@/2`D=F%R.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D=VET:$AI9&1E;BD@>PH@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]H:61D96Y687)I86)L
M97,@87,@)'9A<BD@>PH@("`@("`@("`@("`@("`@("`@("1V87)S6UT@/2`D
M=F%R.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M("`@(')E='5R;B`D=F%R<SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]V87)I86)L97,["B`@("`@("`@?0H@("`@?0H*
M("`@(&9U;F-T:6]N('-E=$)U='1O;G,H)'-U8FUI="P@)')E<V5T(#T@9F%L
M<V4I"B`@("!["B`@("`@("`@:68@*"1S=6)M:70@/3T]('1R=64@?'P@:7-?
M;G5L;"@D<W5B;6ET*2!\?"!E;7!T>2@D<W5B;6ET*2D@>PH@("`@("`@("`@
M("`O*B!$969A=6QT('1O("=3=6)M:70G+B`J+PH@("`@("`@("`@("`D<W5B
M;6ET(#T@87)R87DH7R@B4W5B;6ET(BDI.PH@("`@("`@('T@96QS96EF("@A
M:7-?87)R87DH)'-U8FUI="DI('L*("`@("`@("`@("`@+RH@1&5F875L="!T
M;R!A<G)A>2!I9B!N;W0@<&%S<V5D+B`J+PH@("`@("`@("`@("`D<W5B;6ET
M(#T@87)R87DH)'-U8FUI="D["B`@("`@("`@?0H@("`@("`@("\J($]N;'D@
M:68@)')E<V5T(&ES('-T<FEC=&QY('1R=64@:6YS97)T(&1E9F%U;'0@)U)E
M<V5T)RX@*B\*("`@("`@("!I9B`H)')E<V5T(#T]/2!T<G5E*2!["B`@("`@
M("`@("`@("1R97-E="`](%\H(E)E<V5T(BD["B`@("`@("`@?0H*("`@("`@
M("`D=&AI<RT^7W-U8FUI="`]("1S=6)M:70["B`@("`@("`@)'1H:7,M/E]R
M97-E="`]("1R97-E=#L*("`@('T*"B`@("!F=6YC=&EO;B!A<'!E;F1"=71T
M;VYS*"1S=6)M:70I"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D<W5B
M;6ET*2D@>PH@("`@("`@("`@("`D<W5B;6ET(#T@87)R87DH)'-U8FUI="D[
M"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7W-U8FUI="`](&%R<F%Y7VUE
M<F=E*"1T:&ES+3Y?<W5B;6ET+"`D<W5B;6ET*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!P<F5S97)V959A<D)Y4&]S="@F)'9A<G,L("1V87)N86UE+"`D86QT
M7W9A<FYA;64@/2`G)RD*("`@('L*("`@("`@("`D=F%L=64@/2`D=F%R<RT^
M9V5T17AI<W1S*"1V87)N86UE+"`D=V%S<V5T*3L*"B`@("`@("`@+RH@268@
M86X@86QT97)N871E(&YA;64@:7,@9VEV96X@=6YD97(@=VAI8V@@=&\@<')E
M<V5R=F4@=7-E('1H870N("HO"B`@("`@("`@:68@*"1A;'1?=F%R;F%M92D@
M>PH@("`@("`@("`@("`D=F%R;F%M92`]("1A;'1?=F%R;F%M93L*("`@("`@
M("!]"@H@("`@("`@(&EF("@D=V%S<V5T*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?<')E<V5R=F5687)">5!O<W0H)'9A<FYA;64L("1V86QU92D["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]P<F5S97)V959A<D)Y4&]S="@D=F%R;F%M
M92P@)'9A;'5E*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D=F%L=64I
M*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1V86QU92!A<R`D:60@/3X@)'9A
M;"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P<F5S97)V959A<D)Y4&]S
M="@D=F%R;F%M92`N("=;)R`N("1I9"`N("==)RP@)'9A;"D["B`@("`@("`@
M("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=F%R;F%M92`]
M(&AT;6QS<&5C:6%L8VAA<G,H)'9A<FYA;64I.PH@("`@("`@("`@("`D=F%L
M=64@/2!H=&UL<W!E8VEA;&-H87)S*"1V86QU92D["B`@("`@("`@("`@('!R
M:6YT9B@G/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB)7,B('9A;'5E/2(E
M<R(@+SXG("X@(EQN(BP*("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@
M("`@("`@("`@("`@("`@("`@)'9A;'5E*3L*("`@("`@("!]"B`@("!]"@H@
M("`@9G5N8W1I;VX@;W!E;B@F)')E;F1E<F5R+"`F)'9A<G,L("1A8W1I;VXL
M("1M971H;V0@/2`G9V5T)RP@)&5N8W1Y<&4@/2!N=6QL*0H@("`@>PH@("`@
M("`@(&EF("AI<U]N=6QL*"1E;F-T>7!E*2`F)B`A:7-?;G5L;"@D=&AI<RT^
M7V5N8W1Y<&4I*2!["B`@("`@("`@("`@("1E;F-T>7!E(#T@)'1H:7,M/E]E
M;F-T>7!E.PH@("`@("`@('T*("`@("`@("`D<F5N9&5R97(M/F]P96XH)&%C
M=&EO;BP@)&UE=&AO9"P@)'1H:7,M/E]N86UE+"`D96YC='EP92D["B`@("`@
M("`@)')E;F1E<F5R+3YL:7-T1F]R;59A<G,H)'1H:7,I.PH*("`@("`@("!I
M9B`H(65M<'1Y*"1T:&ES+3Y?;F%M92DI('L*("`@("`@("`@("`@)'1H:7,M
M/E]P<F5S97)V959A<D)Y4&]S="@G9F]R;6YA;64G+"`D=&AI<RT^7VYA;64I
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES+3Y?=7-E1F]R;51O:V5N
M*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O5&]K96XN<&AP
M)SL*("`@("`@("`@("`@)'1H:7,M/E]P<F5S97)V959A<D)Y4&]S="@G7U]F
M;W)M5&]K96Y?)R`N("1T:&ES+3Y?;F%M92P@2&]R9&5?5&]K96XZ.F=E;F5R
M871E260H)'1H:7,M/E]N86UE*2D["B`@("`@("`@?0H*("`@("`@("`O*B!,
M;V]P('1H<F]U9V@@=F%R<R!A;F0@8VAE8VL@9F]R(&%N>2!S<&5C:6%L(&-A
M<V5S('1O('!R97-E<G9E+B`J+PH@("`@("`@("1V87)I86)L97,@/2`D=&AI
M<RT^9V5T5F%R:6%B;&5S*"D["B`@("`@("`@9F]R96%C:"`H)'9A<FEA8FQE
M<R!A<R`D=F%R*2!["B`@("`@("`@("`@("\J(%!R97-E<G9E('9A;'5E(&EF
M(&-H86YG92!H87,@=&\@8F4@=')A8VME9"X@*B\*("`@("`@("`@("`@:68@
M*"1V87(M/F=E=$]P=&EO;B@G=')A8VMC:&%N9V4G*2D@>PH@("`@("`@("`@
M("`@("`@)'9A<FYA;64@/2`D=F%R+3YG971687).86UE*"D["B`@("`@("`@
M("`@("`@("`D=&AI<RT^<')E<V5R=F5687)">5!O<W0H)'9A<G,L("1V87)N
M86UE+"`G7U]O;&1?)R`N("1V87)N86UE*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]H:61D96Y687)I86)L
M97,@87,@)'9A<BD@>PH@("`@("`@("`@("`D=&AI<RT^<')E<V5R=F5687)"
M>5!O<W0H)'9A<G,L("1V87(M/F=E=%9A<DYA;64H*2D["B`@("`@("`@?0H@
M("`@?0H*("`@(&9U;F-T:6]N(&-L;W-E*"8D<F5N9&5R97(I"B`@("!["B`@
M("`@("`@)')E;F1E<F5R+3YC;&]S92@I.PH@("`@?0H*("`@(&9U;F-T:6]N
M(')E;F1E<D%C=&EV92@F)')E;F1E<F5R+"`F)'9A<G,L("1A8W1I;VXL("1M
M971H;V0@/2`G9V5T)RP@)&5N8W1Y<&4@/2!N=6QL+"`D9F]C=7,@/2!T<G5E
M*0H@("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1E;F-T>7!E*2`F)B`A:7-?
M;G5L;"@D=&AI<RT^7V5N8W1Y<&4I*2!["B`@("`@("`@("`@("1E;F-T>7!E
M(#T@)'1H:7,M/E]E;F-T>7!E.PH@("`@("`@('T*("`@("`@("`D<F5N9&5R
M97(M/F]P96XH)&%C=&EO;BP@)&UE=&AO9"P@)'1H:7,M/F=E=$YA;64H*2P@
M)&5N8W1Y<&4I.PH@("`@("`@("1R96YD97)E<BT^;&ES=$9O<FU687)S*"1T
M:&ES*3L*"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7VYA;64I*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?<')E<V5R=F5687)">5!O<W0H)V9O<FUN86UE
M)RP@)'1H:7,M/E]N86UE*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI
M<RT^7W5S949O<FU4;VME;BD@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M)TAO<F1E+U1O:V5N+G!H<"<["B`@("`@("`@("`@("1T:&ES+3Y?<')E<V5R
M=F5687)">5!O<W0H)U]?9F]R;51O:V5N7R<@+B`D=&AI<RT^7VYA;64L($AO
M<F1E7U1O:V5N.CIG96YE<F%T94ED*"1T:&ES+3Y?;F%M92DI.PH@("`@("`@
M('T*"B`@("`@("`@:68@*&-O=6YT*"1T:&ES+3Y?<V5C=&EO;G,I*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?<')E<V5R=F5687)">5!O<W0H)U]?9F]R;4]P
M96Y396-T:6]N)RP@)'1H:7,M/F=E=$]P96Y396-T:6]N*"DI.PH@("`@("`@
M('T*"B`@("`@("`@+RH@3&]O<"!T:')O=6=H('9A<G,@86YD(&-H96-K(&9O
M<B!A;GD@<W!E8VEA;"!C87-E<R!T;PH@("`@("`@("`J('!R97-E<G9E+B`J
M+PH@("`@("`@("1V87)I86)L97,@/2`D=&AI<RT^9V5T5F%R:6%B;&5S*"D[
M"B`@("`@("`@9F]R96%C:"`H)'9A<FEA8FQE<R!A<R`D=F%R*2!["B`@("`@
M("`@("`@("\J(%!R97-E<G9E('9A;'5E(&EF(&-H86YG92!H87,@=&\@8F4@
M=')A8VME9"X@*B\*("`@("`@("`@("`@:68@*"1V87(M/F=E=$]P=&EO;B@G
M=')A8VMC:&%N9V4G*2D@>PH@("`@("`@("`@("`@("`@)'9A<FYA;64@/2`D
M=F%R+3YG971687).86UE*"D["B`@("`@("`@("`@("`@("`D=&AI<RT^<')E
M<V5R=F5687)">5!O<W0H)'9A<G,L("1V87)N86UE+"`G7U]O;&1?)R`N("1V
M87)N86UE*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@9F]R
M96%C:"`H)'1H:7,M/E]H:61D96Y687)I86)L97,@87,@)'9A<BD@>PH@("`@
M("`@("`@("`D=&AI<RT^<')E<V5R=F5687)">5!O<W0H)'9A<G,L("1V87(M
M/F=E=%9A<DYA;64H*2D["B`@("`@("`@?0H*("`@("`@("`D<F5N9&5R97(M
M/F)E9VEN06-T:79E*"1T:&ES+3YG9714:71L92@I+"`D=&AI<RT^9V5T17AT
M<F$H*2D["B`@("`@("`@)')E;F1E<F5R+3YR96YD97)&;W)M06-T:79E*"1T
M:&ES+"`D=F%R<RD["B`@("`@("`@)')E;F1E<F5R+3YS=6)M:70H)'1H:7,M
M/E]S=6)M:70L("1T:&ES+3Y?<F5S970I.PH@("`@("`@("1R96YD97)E<BT^
M96YD*"D["B`@("`@("`@)')E;F1E<F5R+3YC;&]S92@D9F]C=7,I.PH@("`@
M?0H*("`@(&9U;F-T:6]N(')E;F1E<DEN86-T:79E*"8D<F5N9&5R97(L("1V
M87)S*0H@("`@>PH@("`@("`@("1R96YD97)E<BT^8F5G:6Y);F%C=&EV92@D
M=&AI<RT^9V5T5&ET;&4H*2P@)'1H:7,M/F=E=$5X=')A*"DI.PH@("`@("`@
M("1R96YD97)E<BT^<F5N9&5R1F]R;4EN86-T:79E*"1T:&ES+"`D=F%R<RD[
M"B`@("`@("`@)')E;F1E<F5R+3YE;F0H*3L*("`@('T*"B`@("!F=6YC=&EO
M;B!P<F5S97)V92@D=F%R<RD*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]U
M<V5&;W)M5&]K96XI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D
M92]4;VME;BYP:'`G.PH@("`@("`@("`@("`D=&AI<RT^7W!R97-E<G9E5F%R
M0GE0;W-T*"=?7V9O<FU4;VME;E\G("X@)'1H:7,M/E]N86UE+"!(;W)D95]4
M;VME;CHZ9V5N97)A=&5)9"@D=&AI<RT^7VYA;64I*3L*("`@("`@("!]"@H@
M("`@("`@("1V87)I86)L97,@/2`D=&AI<RT^9V5T5F%R:6%B;&5S*"D["B`@
M("`@("`@9F]R96%C:"`H)'9A<FEA8FQE<R!A<R`D=F%R*2!["B`@("`@("`@
M("`@("1V87)N86UE(#T@)'9A<BT^9V5T5F%R3F%M92@I.PH*("`@("`@("`@
M("`@+RH@4V%V92!V86QU92!O9B!I;F1I=FED=6%L(&-O;7!O;F5N=',N("HO
M"B`@("`@("`@("`@('-W:71C:"`H)'9A<BT^9V5T5'EP94YA;64H*2D@>PH@
M("`@("`@("`@("!C87-E("=P87-S=V]R9&-O;F9I<FTG.@H@("`@("`@("`@
M("!C87-E("=E;6%I;&-O;F9I<FTG.@H@("`@("`@("`@("`@("`@)'1H:7,M
M/G!R97-E<G9E5F%R0GE0;W-T*"1V87)S+"`D=F%R;F%M92`N("=;;W)I9VEN
M86Q=)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^<')E<V5R=F5687)">5!O
M<W0H)'9A<G,L("1V87)N86UE("X@)UMC;VYF:7)M72<I.PH@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=M;VYT:'EE87(G.@H@
M("`@("`@("`@("`@("`@)'1H:7,M/G!R97-E<G9E5F%R0GE0;W-T*"1V87)S
M+"`D=F%R;F%M92`N("=;;6]N=&A=)RD["B`@("`@("`@("`@("`@("`D=&AI
M<RT^<')E<V5R=F5687)">5!O<W0H)'9A<G,L("1V87)N86UE("X@)UMY96%R
M72<I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E
M("=M;VYT:&1A>7EE87(G.@H@("`@("`@("`@("`@("`@)'1H:7,M/G!R97-E
M<G9E5F%R0GE0;W-T*"1V87)S+"`D=F%R;F%M92`N("=;;6]N=&A=)RD["B`@
M("`@("`@("`@("`@("`D=&AI<RT^<')E<V5R=F5687)">5!O<W0H)'9A<G,L
M("1V87)N86UE("X@)UMD87E=)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^
M<')E<V5R=F5687)">5!O<W0H)'9A<G,L("1V87)N86UE("X@)UMY96%R72<I
M.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("1T:&ES+3YP<F5S97)V959A<D)Y4&]S="@D=F%R<RP@)'9A<FYA
M;64I.PH@("`@("`@('T*("`@("`@("!F;W)E86-H("@D=&AI<RT^7VAI9&1E
M;E9A<FEA8FQE<R!A<R`D=F%R*2!["B`@("`@("`@("`@("1T:&ES+3YP<F5S
M97)V959A<D)Y4&]S="@D=F%R<RP@)'9A<BT^9V5T5F%R3F%M92@I*3L*("`@
M("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@=6YS971687)S*"8D=F%R<RD*
M("`@('L*("`@("`@("!F;W)E86-H("@D=&AI<RT^9V5T5F%R:6%B;&5S*"D@
M87,@)'9A<BD@>PH@("`@("`@("`@("`D=F%R<RT^<F5M;W9E*"1V87(M/F=E
M=%9A<DYA;64H*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M1&]E<R!T:&4@86-T:6]N(&]F('9A;&ED871I;F<@=&AE(&9O<FTL(&-H96-K
M:6YG(&EF(&ET(')E86QL>2!H87,@8F5E;@H@("`@("H@<W5B;6ET=&5D(&)Y
M(&-A;&QI;F<@:7-3=6)M:71T960H*2!A;F0@:68@=')U92!D;V5S(&%N>2!O
M;E-U8FUI="@I"B`@("`@*B!C86QL<R!F;W(@=F%R('1Y<&5S(&EN('1H92!F
M;W)M+B!4:&4@7W-U8FUI='1E9"!V87(@:7,@=&AE;B!R96-H96-K960N"B`@
M("`@*@H@("`@("H@0'!A<F%M($AO<F1E7U9A<FEA8FQE<R`D=F%R<PH@("`@
M("H@0'!A<F%M(&)O;VQE86X@("`@("`@("`D8V%N075T;V9I;&P@($-A;B!T
M:&4@9F]R;2!B92!V86QI9"!W:71H;W5T"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8F5I;F<@<W5B;6ET=&5D/PH@("`@
M("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&4@9F]R;2!I
M<R!V86QI9"X*("`@("`J+PH@("`@9G5N8W1I;VX@=F%L:61A=&4H)B1V87)S
M+"`D8V%N075T;T9I;&P@/2!F86QS92D*("`@('L*("`@("`@("`O*B!'970@
M<W5B;6ET=&5D('-T871U<RX@*B\*("`@("`@("!I9B`H)'1H:7,M/FES4W5B
M;6ET=&5D*"D@?'P@)&-A;D%U=&]&:6QL*2!["B`@("`@("`@("`@("\J($9O
M<FT@=V%S('-U8FUI='1E9"!O<B!C86X@875T;V9I;&P[(&-H96-K(&9O<B!A
M;GD@=F%R:6%B;&4*("`@("`@("`@("`@("H@='EP97,G(&]N4W5B;6ET*"DN
M("HO"B`@("`@("`@("`@("1T:&ES+3YO;E-U8FUI="@D=F%R<RD["@H@("`@
M("`@("`@("`O*B!296-H96-K('-U8FUI='1E9"!S=&%T=7,N("HO"B`@("`@
M("`@("`@(&EF("@A)'1H:7,M/FES4W5B;6ET=&5D*"D@)B8@(21C86Y!=71O
M1FEL;"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@1F]R;2!H
M87,@;F]T(&)E96X@<W5B;6ET=&5D.R!R971U<FX@9F%L<V4N("HO"B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1M97-S
M86=E(#T@)R<["B`@("`@("`@)'1H:7,M/E]A=71O9FEL;&5D(#T@=')U93L*
M"B`@("`@("`@:68@*"1T:&ES+3Y?=7-E1F]R;51O:V5N*2!["B`@("`@("`@
M("`@(&=L;V)A;"`D8V]N9CL*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(
M;W)D92]4;VME;BYP:'`G.PH@("`@("`@("`@("!I9B`H:7-S970H)&-O;F9;
M)W1O:V5N)UTI*2!["B`@("`@("`@("`@("`@("`O*B!)9B!T:&5R92!I<R!A
M(&-O;F9I9W5R960@=&]K96X@<WES=&5M+"!S970@:70@=7`N("HO"B`@("`@
M("`@("`@("`@("`D=&]K96Y3;W5R8V4@/2`F2&]R9&5?5&]K96XZ.G-I;F=L
M971O;B@D8V]N9ELG=&]K96XG75LG9')I=F5R)UTL($AO<F1E.CIG971$<FEV
M97)#;VYF:6<H)W1O:V5N)RP@)&-O;F9;)W1O:V5N)UU;)V1R:79E<B==*2D[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O*B!$969A
M=6QT('1O('1H92!F:6QE('-Y<W1E;2!I9B!N;R!C;VYF:6<N("HO"B`@("`@
M("`@("`@("`@("`D=&]K96Y3;W5R8V4@/2`F2&]R9&5?5&]K96XZ.G-I;F=L
M971O;B@G9FEL92<I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A
M)'1O:V5N4V]U<F-E+3YV97)I9GDH)'9A<G,M/F=E="@G7U]F;W)M5&]K96Y?
M)R`N("1T:&ES+3Y?;F%M92DI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7V5R<F]R<ULG7U]F;W)M5&]K96XG72`](%\H(E1H:7,@9F]R;2!H87,@86QR
M96%D>2!B965N('!R;V-E<W-E9"XB*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/F=E=%9A<FEA8FQE<R@I(&%S
M("1V87(I('L*("`@("`@("`@("`@)'1H:7,M/E]A=71O9FEL;&5D(#T@)'9A
M<BT^7V%U=&]F:6QL960@)B8@)'1H:7,M/E]A=71O9FEL;&5D.PH@("`@("`@
M("`@("!I9B`H(21V87(M/G9A;&ED871E*"1V87)S+"`D;65S<V%G92DI('L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?97)R;W)S6R1V87(M/F=E=%9A<DYA
M;64H*5T@/2`D;65S<V%G93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@:68@*"1T:&ES+3Y?875T;V9I;&QE9"D@>PH@("`@("`@("`@("!U
M;G-E="@D=&AI<RT^7V5R<F]R<ULG7U]F;W)M5&]K96XG72D["B`@("`@("`@
M?0H*("`@("`@("!F;W)E86-H("@D=&AI<RT^7VAI9&1E;E9A<FEA8FQE<R!A
M<R`D=F%R*2!["B`@("`@("`@("`@(&EF("@A)'9A<BT^=F%L:61A=&4H)'9A
M<G,L("1M97-S86=E*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]E<G)O
M<G-;)'9A<BT^9V5T5F%R3F%M92@I72`]("1M97-S86=E.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/FES5F%L:60H
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!C;&5A<E9A;&ED871I;VXH*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?97)R;W)S(#T@87)R87DH*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!G971%<G)O<B@D=F%R*0H@("`@>PH@("`@("`@(&EF("AI
M<U]A*"1V87(L("=(;W)D95]&;W)M7U9A<FEA8FQE)RDI('L*("`@("`@("`@
M("`@)&YA;64@/2`D=F%R+3YG971687).86UE*"D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)&YA;64@/2`D=F%R.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@:7-S970H)'1H:7,M/E]E<G)O<G-;)&YA;65=*2`_("1T:&ES
M+3Y?97)R;W)S6R1N86UE72`Z(&YU;&P["B`@("!]"@H@("`@9G5N8W1I;VX@
M<V5T17)R;W(H)'9A<BP@)&UE<W-A9V4I"B`@("!["B`@("`@("`@:68@*&ES
M7V$H)'9A<BP@)TAO<F1E7T9O<FU?5F%R:6%B;&4G*2D@>PH@("`@("`@("`@
M("`D;F%M92`]("1V87(M/F=E=%9A<DYA;64H*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D;F%M92`]("1V87(["B`@("`@("`@?0H@("`@("`@
M("1T:&ES+3Y?97)R;W)S6R1N86UE72`]("1M97-S86=E.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&-L96%R17)R;W(H)'9A<BD*("`@('L*("`@("`@("!I9B`H
M:7-?82@D=F%R+"`G2&]R9&5?1F]R;5]687)I86)L92<I*2!["B`@("`@("`@
M("`@("1N86UE(#T@)'9A<BT^9V5T5F%R3F%M92@I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1N86UE(#T@)'9A<CL*("`@("`@("!]"B`@("`@
M("`@=6YS970H)'1H:7,M/E]E<G)O<G-;)&YA;65=*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!I<U9A;&ED*"D*("`@('L*("`@("`@("!R971U<FX@*"1T:&ES
M+3Y?875T;V9I;&QE9"!\?"!C;W5N="@D=&AI<RT^7V5R<F]R<RD@/3T@,"D[
M"B`@("!]"@H@("`@9G5N8W1I;VX@97AE8W5T92@F)'9A<G,I"B`@("!["B`@
M("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U=A<FYI;F<Z($AO<F1E7T9O<FTZ
M.F5X96-U=&4H*2!C86QL960L('-H;W5L9"!B92!O=F5R<FED9&5N)RP@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!&971C:"!T:&4@9FEE;&0@=F%L=65S(&]F('1H92!S=6)M
M:71T960@9F]R;2X*("`@("`J"B`@("`@*B!`<&%R86T@5F%R:6%B;&5S("1V
M87)S("!4:&4@5F%R:6%B;&5S(&]B:F5C="X*("`@("`J($!P87)A;2!A<G)A
M>2`D:6YF;R`@("`@($%R<F%Y('1O(&)E(&9I;&QE9"!W:71H('1H92!S=6)M
M:71T960@9FEE;&0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('9A
M;'5E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T26YF;R@F)'9A<G,L("8D
M:6YF;RD*("`@('L*("`@("`@("`D=&AI<RT^7V=E=$EN9F]&<F]M5F%R:6%B
M;&5S*"1T:&ES+3YG971687)I86)L97,H*2P@)'9A<G,L("1I;F9O*3L*("`@
M("`@("`D=&AI<RT^7V=E=$EN9F]&<F]M5F%R:6%B;&5S*"1T:&ES+3Y?:&ED
M9&5N5F%R:6%B;&5S+"`D=F%R<RP@)&EN9F\I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1F5T8V@@=&AE(&9I96QD('9A;'5E<R!F<F]M(&$@9VEV96X@87)R
M87D@;V8@=F%R:6%B;&5S+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`@)'9A<FEA8FQE<R`@06X@
M87)R87D@;V8@2&]R9&5?1F]R;5]687)I86)L92!O8FIE8W1S('1O"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&9E=&-H(&9R;VTN"B`@("`@
M*B!`<&%R86T@;V)J96-T("1V87)S("`@("`@(%1H92!687)I86)L97,@;V)J
M96-T+@H@("`@("H@0'!A<F%M(&%R<F%Y("`D:6YF;R`@("`@("!4:&4@87)R
M87D@=&\@8F4@9FEL;&5D('=I=&@@=&AE('-U8FUI='1E9`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("!F:65L9"!V86QU97,N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]G971);F9O1G)O;59A<FEA8FQE<R@D=F%R:6%B;&5S
M+"`F)'9A<G,L("8D:6YF;RD*("`@('L*("`@("`@("!F;W)E86-H("@D=F%R
M:6%B;&5S(&%S("1V87(I('L*("`@("`@("`@("`@:68@*"1V87(M/FES07)R
M87E686PH*2D@>PH@("`@("`@("`@("`@("`@)'9A<BT^9V5T26YF;R@D=F%R
M<RP@)'9A;'5E<RD["B`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)'9A
M;'5E<RDI('L*("`@("`@("`@("`@("`@("`@("`D=F%R3F%M92`]('-T<E]R
M97!L86-E*"=;72<L("<G+"`D=F%R+3YG971687).86UE*"DI.PH@("`@("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1V86QU97,@87,@)&D@/3X@)'9A;"D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D:6YF;ULD:5U;)'9A<DYA;65=
M(#T@)'9A;#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@)TAO<F1E+T%R<F%Y+G!H<"<["B`@("`@("`@("`@("`@("!I
M9B`H2&]R9&5?07)R87DZ.F=E=$%R<F%Y4&%R=',H)'9A<BT^9V5T5F%R3F%M
M92@I+"`D8F%S92P@)&ME>7,I*2!["B`@("`@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D:6YF;ULD8F%S95TI*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1I;F9O6R1B87-E72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R(#T@)B1I;F9O6R1B
M87-E73L*("`@("`@("`@("`@("`@("`@("!W:&EL92`H8V]U;G0H)&ME>7,I
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1K97D@/2!A<G)A>5]S:&EF
M="@D:V5Y<RD["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H
M)'!O:6YT97);)&ME>5TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<&]I;G1E<ELD:V5Y72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97(@/2`F
M)'!O:6YT97);)&ME>5T["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@("1V87(M/F=E=$EN9F\H)'9A<G,L("1P;VEN=&5R*3L*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M)'9A<BT^9V5T26YF;R@D=F%R<RP@)&EN9F];)'9A<BT^9V5T5F%R3F%M92@I
M72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("!]"@H@("`@9G5N8W1I;VX@:&%S2&5L<"@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?:&5L<#L*("`@('T*"B`@("`O*BH*("`@("`J($1E
M=&5R;6EN97,@:68@=&AI<R!F;W)M(&AA<R!B965N('-U8FUI='1E9"!O<B!N
M;W0N($EF('1H92!C;&%S<PH@("`@("H@=F%R(%]S=6)M:71T960@:7,@;G5L
M;"!T:&5N(&ET('=I;&P@8VAE8VL@9F]R('1H92!P<F5S96YC92!O9@H@("`@
M("H@=&AE(&9O<FUN86UE(&EN('1H92!F;W)M('9A<FEA8FQE<RX*("`@("`J
M"B`@("`@*B!/=&AE<B!E=F5N=',@8V%N(&5X<&QI8VET;'D@<V5T('1H92!?
M<W5B;6ET=&5D('9A<FEA8FQE('1O"B`@("`@*B!F86QS92!T;R!I;F1I8V%T
M92!A(&9O<FT@<W5B;6ET(&)U="!N;W0@9F]R(&%C='5A;"!P;W-T:6YG(&]F
M"B`@("`@*B!D871A("AE9RX@;VY#:&%N9V4@979E;G1S('1O('5P9&%T92!T
M:&4@9&ES<&QA>2!O9B!F:65L9',I+@H@("`@("H*("`@("`J($!R971U<FX@
M8F]O;&5A;B`@5')U92!O<B!F86QS92!I;F1I8V%T:6YG(&EF('1H92!F;W)M
M(&AA<R!B965N"B`@("`@*B`@("`@("`@("`@("`@("`@('-U8FUI='1E9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@:7-3=6)M:71T960H*0H@("`@>PH@("`@
M("`@(&EF("AI<U]N=6QL*"1T:&ES+3Y?<W5B;6ET=&5D*2D@>PH@("`@("`@
M("`@("!I9B`H)'1H:7,M/E]V87)S+3YG970H)V9O<FUN86UE)RD@/3T@)'1H
M:7,M/F=E=$YA;64H*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]S=6)M
M:71T960@/2!T<G5E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]S=6)M:71T960@/2!F86QS93L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<W5B;6ET=&5D
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS(&EF('1H97)E(&ES(&%N
M>71H:6YG('1O(&1O(&]N('1H92!S=6)M:7-S:6]N(&]F('1H92!F;W)M(&)Y
M"B`@("`@*B!L;V]P:6YG('1H<F]U9V@@96%C:"!V87)I86)L92=S(&]N4W5B
M;6ET*"D@9G5N8W1I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M($AO<F1E7U9A
M<FEA8FQE<R`D=F%R<PH@("`@("HO"B`@("!F=6YC=&EO;B!O;E-U8FUI="@F
M)'9A<G,I"B`@("!["B`@("`@("`@+RH@3&]O<"!T:')O=6=H(&%L;"!V87)S
M(&%N9"!C:&5C:R!I9B!T:&5R92=S(&%N>71H:6YG('1O(&1O(&]N"B`@("`@
M("`@("H@<W5B;6ET+B`J+PH@("`@("`@("1V87)I86)L97,@/2`D=&AI<RT^
M9V5T5F%R:6%B;&5S*"D["B`@("`@("`@9F]R96%C:"`H)'9A<FEA8FQE<R!A
M<R`D=F%R*2!["B`@("`@("`@("`@("1V87(M/G1Y<&4M/F]N4W5B;6ET*"1V
M87(L("1V87)S*3L*("`@("`@("`@("`@+RH@268@8VAA;F=E<R!T;R!V87(@
M8F5I;F<@=')A8VME9"!D;VXG="!R96=I<W1E<B!T:&4@9F]R;2!A<PH@("`@
M("`@("`@("`@*B!S=6)M:71T960@:68@;VQD('9A;'5E(&%N9"!N97<@=F%L
M=64@9&EF9F5R+B`J+PH@("`@("`@("`@("!I9B`H)'9A<BT^9V5T3W!T:6]N
M*"=T<F%C:V-H86YG92<I*2!["B`@("`@("`@("`@("`@("`D=F%R;F%M92`]
M("1V87(M/F=E=%9A<DYA;64H*3L*("`@("`@("`@("`@("`@(&EF("@A:7-?
M;G5L;"@D=F%R<RT^9V5T*"=F;W)M;F%M92<I*2`F)@H@("`@("`@("`@("`@
M("`@("`@("1V87)S+3YG970H)'9A<FYA;64I("$]("1V87)S+3YG970H)U]?
M;VQD7R<@+B`D=F%R;F%M92DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W-U8FUI='1E9"`](&9A;'-E.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@17AP
M;&EC:71L>2!S971S('1H92!S=&%T92!O9B!T:&4@9F]R;2!S=6)M:70N"B`@
M("`@*@H@("`@("H@06X@979E;G0@8V%N(&]V97)R:61E('1H92!A=71O;6%T
M:6,@9&5T97)M:6YA=&EO;B!O9B!T:&4@<W5B;6ET('-T871E"B`@("`@*B!I
M;B!T:&4@:7-3=6)M:71T960H*2!F=6YC=&EO;BX*("`@("`J"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D<W1A=&4@(%=H971H97(@=&\@<V5T('1H92!S=&%T
M92!O9B!T:&4@9F]R;2!A<R!B96EN9PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("!S=6)M:71T960N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%-U
M8FUI='1E9"@D<W1A=&4@/2!T<G5E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M<W5B;6ET=&5D(#T@)'-T871E.PH@("`@?0H*?0H*+RHJ"B`J($AO<F1E7T9O
M<FU?5'EP92!#;&%S<PH@*@H@*B!`875T:&]R("!2;V)E<G0@12X@0V]Y;&4@
M/')O8F5R=&5C;WEL94!H;W1M86EL+F-O;3X*("H@0'!A8VMA9V4@2&]R9&5?
M1F]R;0H@*B\*8VQA<W,@2&]R9&5?1F]R;5]4>7!E('L*"B`@("!F=6YC=&EO
M;B!(;W)D95]&;W)M7U1Y<&4H*0H@("`@>PH@("`@?0H*("`@(&9U;F-T:6]N
M(&EN:70H*0H@("`@>PH@("`@?0H*("`@(&9U;F-T:6]N(&]N4W5B;6ET*"D*
M("`@('L*("`@('T*"B`@("!F=6YC=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A
M<G,L("1V86QU92P@)B1M97-S86=E*0H@("`@>PH@("`@("`@("1M97-S86=E
M(#T@)SQS=')O;F<^17)R;W(Z/"]S=')O;F<^($AO<F1E7T9O<FU?5'EP93HZ
M:7-686QI9"@I(&-A;&QE9"`M('-H;W5L9"!B92!O=F5R<FED9&5N/&)R("\^
M)SL*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@9G5N8W1I;VX@
M9V5T5'EP94YA;64H*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R
M9&4O4W1R:6YG+G!H<"<["B`@("`@("`@<F5T=7)N('-T<E]R97!L86-E*"=H
M;W)D95]F;W)M7W1Y<&5?)RP@)R<L(%-T<FEN9SHZ;&]W97(H9V5T7V-L87-S
M*"1T:&ES*2DI.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%9A;'5E<R@I"B`@
M("!["B`@("`@("`@<F5T=7)N(&YU;&P["B`@("!]"@H@("`@9G5N8W1I;VX@
M9V5T26YF;R@F)'9A<G,L("8D=F%R+"`F)&EN9F\I"B`@("!["B`@("`@("`@
M)&EN9F\@/2`D=F%R+3YG971686QU92@D=F%R<RD["B`@("!]"@I]"@IC;&%S
M<R!(;W)D95]&;W)M7U1Y<&5?<W!A8V5R(&5X=&5N9',@2&]R9&5?1F]R;5]4
M>7!E('L*"B`@("!F=6YC=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V
M86QU92P@)B1M97-S86=E*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@
M='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@
M("`@("1A8F]U="`](&%R<F%Y*"D["B`@("`@("`@)&%B;W5T6R=N86UE)UT@
M/2!?*")3<&%C97(B*3L*("`@("`@("!R971U<FX@)&%B;W5T.PH@("`@?0H*
M?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7W=E871H97)D;W1C;VT@97AT96YD
M<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@('9A<B`D7W)E9V5X.PH@("`@=F%R
M("1?<VEZ93L*("`@('9A<B`D7VUA>&QE;F=T:#L*"B`@("`O*BH*("`@("`J
M(%1H92!I;FET:6%L:7-A=&EO;B!F=6YC=&EO;B!F;W(@=&AE('1E>'0@=F%R
M:6%B;&4@='EP92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1R96=E>"`@("`@("!!;GD@=F%L
M:60@4$A0(%!#4D4@<&%T=&5R;B!S>6YT87@@=&AA=`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@;F5E9',@=&\@8F4@;6%T8VAE9"!F;W(@
M=&AE(&9I96QD('1O(&)E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!C;VYS:61E<F5D('9A;&ED+B!)9B!L969T(&5M<'1Y('9A;&ED:71Y
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!W:6QL(&)E(&-H
M96-K960@;VYL>2!F;W(@<F5Q=6ER960@9FEE;&1S"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!W:&5T:&5R('1H97D@87)E(&5M<'1Y(&]R
M(&YO="X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@($EF('5S
M:6YG('1H:7,@<F5G97@@=&5S="!I="!I<R!A9'9I<V%B;&4*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('1O(&5N=&5R(&$@9&5S8W)I<'1I
M;VX@9F]R('1H:7,@9FEE;&0@=&\*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('=A<FX@=&AE('5S97(@=VAA="!I<R!E>'!E8W1E9"P@87,@
M=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!G96YE<F%T
M960@97)R;W(@;65S<V%G92!I<R!Q=6ET92!G96YE<FEC"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A;F0@=VEL;"!N;W0@9VEV92!A;GD@
M:6YD:6-A=&EO;B!W:&5R90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@=&AE(')E9V5X(&9A:6QE9"X*("`@("`J($!P87)A;2!I;G1E9V5R
M("1S:7IE("`@("`@(%1H92!S:7IE(&]F('1H92!I;G!U="!F:65L9"X*("`@
M("`J($!P87)A;2!I;G1E9V5R("1M87AL96YG=&@@(%1H92!M87@@;G5M8F5R
M(&]F(&-H87)A8W1E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&EN:70H)')E
M9V5X(#T@)R<L("1S:7IE(#T@-#`L("1M87AL96YG=&@@/2!N=6QL*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?<F5G97@@("`@(#T@)')E9V5X.PH@("`@("`@
M("1T:&ES+3Y?<VEZ92`@("`@(#T@)'-I>F4["B`@("`@("`@)'1H:7,M/E]M
M87AL96YG=&@@/2`D;6%X;&5N9W1H.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES
M5F%L:60H)B1V87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("![
M"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7VUA>&QE;F=T:"D@)B8@4W1R
M:6YG.CIL96YG=&@H)'9A;'5E*2`^("1T:&ES+3Y?;6%X;&5N9W1H*2!["B`@
M("`@("`@("`@("1M97-S86=E(#T@<W!R:6YT9BA?*")686QU92!I<R!O=F5R
M('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB*2P@)'1H:7,M/E]M87AL96YG
M=&@I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("!R97%U:7)E7V]N8V4@)U-E<G9I8V5S+U=E871H97(N<&AP)SL*("`@
M("`@("`D=V5A=&AE<D1O=$-O;2`]("9397)V:6-E<U]796%T:&5R.CIS97)V
M:6-E*"=796%T:&5R1&]T0V]M)RD["B`@("`@("`@)'=E871H97)$;W1#;VTM
M/G-E=$%C8V]U;G1$871A*"<\4&%R=&YE<DE$/B<L("<\3&EC96YS94ME>3XG
M*3L*("`@("`@("`D<V5A<F-H(#T@)'=E871H97)$;W1#;VTM/G-E87)C:$QO
M8V%T:6]N*"1V86QU92D["@H@("`@("`@(&EF("AI<U]A<G)A>2@D<V5A<F-H
M*2D@>PH@("`@("`@("`@("`D;65S<V%G92`](%\H(E9A;&ED(&QO8V%T:6]N
M<R!F;W5N9"!I;F-L=61E.B`B*2`N(&EM<&QO9&4H)RP@)RP@)'-E87)C:"D[
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!](&5L<V5I9B`H
M:7-?82@D<V5A<F-H+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1M
M97-S86=E(#T@)'-E87)C:"T^9V5T365S<V%G92@I.PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N('1R=64["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&=E=%-I
M>F4H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W-I>F4["B`@("!]
M"@H@("`@9G5N8W1I;VX@9V5T36%X3&5N9W1H*"D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]M87AL96YG=&@["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FX@:6YF;R!A8F]U="!F:65L9"!T>7!E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R87DH
M*3L*("`@("`@("`D86)O=71;)VYA;64G72`](%\H(E=E871H97(N8V]M(BD[
M"B`@("`@("`@)&%B;W5T6R=P87)A;7,G72`](&%R<F%Y*`H@("`@("`@("`@
M("`G<F5G97@G("`@("`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(E)E9V5X(BDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@
M)W1E>'0G*2P*("`@("`@("`@("`@)W-I>F4G("`@("`@/3X@87)R87DH)VQA
M8F5L)R`]/B!?*")3:7IE(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=T>7!E)R`@/3X@)VEN="<I+`H@("`@("`@("`@("`G;6%X;&5N
M9W1H)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(DUA>&EM=6T@;&5N9W1H(BDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@
M)VEN="<I+`H@("`@("`@("D["B`@("`@("`@<F5T=7)N("1A8F]U=#L*("`@
M('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP95]H96%D97(@97AT96YD<R!(
M;W)D95]&;W)M7U1Y<&4@>PH*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L
M("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A
M8F]U="!F:65L9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I
M"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R87DH*3L*("`@("`@("`D86)O
M=71;)VYA;64G72`](%\H(DAE861E<B(I.PH@("`@("`@(')E='5R;B`D86)O
M=70["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?9&5S8W)I<'1I
M;VX@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@(&9U;F-T:6]N(&ES
M5F%L:60H)B1V87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("![
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FX@:6YF;R!A8F]U="!F:65L9"!T>7!E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R87DH*3L*
M("`@("`@("`D86)O=71;)VYA;64G72`](%\H(D1E<V-R:7!T:6]N(BD["B`@
M("`@("`@<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"B\J*@H@*B!3:6UP;'D@
M<F5N9&5R<R!I=',@<F%W('9A;'5E(&EN(&)O=&@@86-T:79E(&%N9"!I;F%C
M=&EV92!R96YD97)I;F<N"B`J+PIC;&%S<R!(;W)D95]&;W)M7U1Y<&5?:'1M
M;"!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@9G5N8W1I;VX@:7-6
M86QI9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O=70@/2!A<G)A>2@I.PH@
M("`@("`@("1A8F]U=%LG;F%M92==(#T@7R@B2%1-3"(I.PH@("`@("`@(')E
M='5R;B`D86)O=70["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?
M;G5M8F5R(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@("!V87(@)%]F
M<F%C=&EO;CL*"B`@("!F=6YC=&EO;B!I;FET*"1F<F%C=&EO;B`](&YU;&PI
M"B`@("!["B`@("`@("`@)'1H:7,M/E]F<F%C=&EO;B`]("1F<F%C=&EO;CL*
M("`@('T*"B`@("!F=6YC=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V
M86QU92P@)B1M97-S86=E*0H@("`@>PH@("`@("`@(&EF("@D=F%R+3YI<U)E
M<75I<F5D*"D@)B8@96UP='DH)'9A;'5E*2`F)B`H*'-T<FEN9RDH9&]U8FQE
M*21V86QU92`A/3T@)'9A;'5E*2D@>PH@("`@("`@("`@("`D;65S<V%G92`]
M(%\H(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(BD["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!](&5L<V5I9B`H96UP='DH)'9A;'5E*2D@
M>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@
M("\J($EF(&UA=&-H960L('1H96X@=&AI<R!I<R!A(&-O<G)E8W0@;G5M97)I
M8R!V86QU92X@*B\*("`@("`@("!I9B`H<')E9U]M871C:"@D=&AI<RT^7V=E
M=%9A;&ED871I;VY0871T97)N*"DL("1V86QU92DI('L*("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`D;65S<V%G92`](%\H
M(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB*3L*("`@("`@
M("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@9G5N8W1I;VX@7V=E=%9A;&ED
M871I;VY0871T97)N*"D*("`@('L*("`@("`@("!S=&%T:6,@)'!A='1E<FX@
M/2`G)SL*("`@("`@("!I9B`H(65M<'1Y*"1P871T97)N*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'!A='1E<FX["B`@("`@("`@?0H*("`@("`@("`O*B!'
M970@8W5R<F5N="!L;V-A;&4@:6YF;W)M871I;VXN("HO"B`@("`@("`@)&QI
M;F9O(#T@3DQ3.CIG971,;V-A;&5);F9O*"D["@H@("`@("`@("\J($)U:6QD
M('1H92!P871T97)N+B`J+PH@("`@("`@("1P871T97)N(#T@)R@M*3\G.PH*
M("`@("`@("`O*B!/;FQY(&-H96-K('1H;W5S86YD<R!S97!A<F%T;W)S(&EF
M(&QO8V%L92!H87,@86YY+B`J+PH@("`@("`@(&EF("@A96UP='DH)&QI;F9O
M6R=M;VY?=&AO=7-A;F1S7W-E<"==*2D@>PH@("`@("`@("`@("`O*B!296=E
M>"!T;R!C:&5C:R!F;W(@8V]R<F5C="!T:&]U<V%N9',@<V5P87)A=&]R<R`H
M:68@86YY*2X@*B\*("`@("`@("`@("`@)'!A='1E<FX@+CT@)R@H7&0K*7PH
M*%QD>S`L,WT_*2A;)R`N("1L:6YF;ULG;6]N7W1H;W5S86YD<U]S97`G72`N
M("==7&1[,WTI*C\I*2<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M+RH@3F\@;&]C86QE('1H;W5S86YD<R!S97!A<F%T;W(L(&-H96-K(&9O<B!O
M;FQY(&1I9VET<RX@*B\*("`@("`@("`@("`@)'!A='1E<FX@+CT@)RA<9"LI
M)SL*("`@("`@("!]"B`@("`@("`@+RH@268@;F\@9&5C:6UA;"!P;VEN="!S
M<&5C:69I960@9&5F875L="!T;R!D;W0N("HO"B`@("`@("`@:68@*&5M<'1Y
M*"1L:6YF;ULG;6]N7V1E8VEM86Q?<&]I;G0G72DI('L*("`@("`@("`@("`@
M)&QI;F9O6R=M;VY?9&5C:6UA;%]P;VEN="==(#T@)RXG.PH@("`@("`@('T*
M("`@("`@("`O*B!296=E>"!T;R!C:&5C:R!F;W(@8V]R<F5C="!D96-I;6%L
M<R`H:68@86YY*2X@*B\*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]F<F%C
M=&EO;BDI('L*("`@("`@("`@("`@)&9R86-T:6]N(#T@)RHG.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1F<F%C=&EO;B`]("=[,"PG("X@)'1H
M:7,M/E]F<F%C=&EO;B`N("=])SL*("`@("`@("!]"B`@("`@("`@)'!A='1E
M<FX@+CT@)RA;)R`N("1L:6YF;ULG;6]N7V1E8VEM86Q?<&]I;G0G72`N("==
M*%QD)R`N("1F<F%C=&EO;B`N("<I*3\G.PH*("`@("`@("`O*B!0=70@=&]G
M971H97(@=&AE('=H;VQE(')E9V5X('!A='1E<FXN("HO"B`@("`@("`@)'!A
M='1E<FX@/2`G+UXG("X@)'!A='1E<FX@+B`G)"\G.PH*("`@("`@("!R971U
M<FX@)'!A='1E<FX["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T26YF;R@F)'9A
M<G,L("8D=F%R+"`F)&EN9F\I"B`@("!["B`@("`@("`@)'9A;'5E(#T@)'9A
M<G,M/F=E="@D=F%R+3YG971687).86UE*"DI.PH@("`@("`@("1L:6YF;R`]
M($Y,4SHZ9V5T3&]C86QE26YF;R@I.PH@("`@("`@("1V86QU92`]('-T<E]R
M97!L86-E*"1L:6YF;ULG;6]N7W1H;W5S86YD<U]S97`G72P@)R<L("1V86QU
M92D["B`@("`@("`@)&EN9F\@/2!S=')?<F5P;&%C92@D;&EN9F];)VUO;E]D
M96-I;6%L7W!O:6YT)UTL("<N)RP@)'9A;'5E*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O=70@/2!A
M<G)A>2@I.PH@("`@("`@("1A8F]U=%LG;F%M92==(#T@7R@B3G5M8F5R(BD[
M"B`@("`@("`@<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E
M7T9O<FU?5'EP95]I;G0@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@
M(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE
M<W-A9V4I"B`@("!["B`@("`@("`@:68@*"1V87(M/FES4F5Q=6ER960H*2`F
M)B!E;7!T>2@D=F%L=64I("8F("@H<W1R:6YG*2AI;G0I)'9A;'5E("$]/2`D
M=F%L=64I*2!["B`@("`@("`@("`@("1M97-S86=E(#T@7R@B5&AI<R!F:65L
M9"!I<R!R97%U:7)E9"XB*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@:68@*&5M<'1Y*"1V86QU92D@?'P@<')E9U]M
M871C:"@G+UY;,"TY72LD+R<L("1V86QU92DI('L*("`@("`@("`@("`@<F5T
M=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`D;65S<V%G92`](%\H(E1H
M:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB*3L*("`@("`@
M("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@
M:6YF;R!A8F]U="!F:65L9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A
M8F]U="@I"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R87DH*3L*("`@("`@
M("`D86)O=71;)VYA;64G72`](%\H(DEN=&5G97(B*3L*("`@("`@("!R971U
M<FX@)&%B;W5T.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7V]C
M=&%L(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@("!F=6YC=&EO;B!I
M<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E*0H@("`@
M>PH@("`@("`@(&EF("@D=F%R+3YI<U)E<75I<F5D*"D@)B8@96UP='DH)'9A
M;'5E*2`F)B`H*'-T<FEN9RDH:6YT*21V86QU92`A/3T@)'9A;'5E*2D@>PH@
M("`@("`@("`@("`D;65S<V%G92`](%\H(E1H:7,@9FEE;&0@:7,@<F5Q=6ER
M960N(BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@
M("`@("`@(&EF("AE;7!T>2@D=F%L=64I('Q\('!R96=?;6%T8V@H)R]>6S`M
M-UTK)"\G+"`D=F%L=64I*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@("`@('T*"B`@("`@("`@)&UE<W-A9V4@/2!?*")4:&ES(&9I96QD(&UA
M>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(I.PH@("`@("`@(')E='5R
M;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!I;F9O(&%B
M;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%B;W5T*"D*
M("`@('L*("`@("`@("`D86)O=70@/2!A<G)A>2@I.PH@("`@("`@("1A8F]U
M=%LG;F%M92==(#T@7R@B3V-T86PB*3L*("`@("`@("!R971U<FX@)&%B;W5T
M.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7VEN=$QI<W0@97AT
M96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@(&9U;F-T:6]N(&ES5F%L:60H
M)B1V87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@
M("`@:68@*&5M<'1Y*"1V86QU92D@)B8@)'9A<BT^:7-297%U:7)E9"@I*2![
M"B`@("`@("`@("`@("1M97-S86=E(#T@7R@B5&AI<R!F:65L9"!I<R!R97%U
M:7)E9"XB*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M"B`@("`@("`@:68@*&5M<'1Y*"1V86QU92D@?'P@<')E9U]M871C:"@G+UY;
M,"TY("Q=*R0O)RP@)'9A;'5E*2D@>PH@("`@("`@("`@("!R971U<FX@=')U
M93L*("`@("`@("!]"@H@("`@("`@("1M97-S86=E(#T@7R@B5&AI<R!F:65L
M9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@
M:6YT96=E<G,B*3L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L9"!T>7!E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@)&%B;W5T
M(#T@87)R87DH*3L*("`@("`@("`D86)O=71;)VYA;64G72`](%\H(DEN=&5G
M97(@;&ES="(I.PH@("`@("`@(')E='5R;B`D86)O=70["B`@("!]"@I]"@IC
M;&%S<R!(;W)D95]&;W)M7U1Y<&5?=&5X="!E>'1E;F1S($AO<F1E7T9O<FU?
M5'EP92!["@H@("`@=F%R("1?<F5G97@["B`@("!V87(@)%]S:7IE.PH@("`@
M=F%R("1?;6%X;&5N9W1H.PH*("`@("\J*@H@("`@("H@5&AE(&EN:71I86QI
M<V%T:6]N(&9U;F-T:6]N(&9O<B!T:&4@=&5X="!V87)I86)L92!T>7!E+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)')E9V5X("`@("`@($%N>2!V86QI9"!02%`@4$-212!P
M871T97)N('-Y;G1A>"!T:&%T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!N965D<R!T;R!B92!M871C:&5D(&9O<B!T:&4@9FEE;&0@=&\@
M8F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G-I9&5R
M960@=F%L:60N($EF(&QE9G0@96UP='D@=F%L:61I='D*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('=I;&P@8F4@8VAE8VME9"!O;FQY(&9O
M<B!R97%U:7)E9"!F:65L9',*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('=H971H97(@=&AE>2!A<F4@96UP='D@;W(@;F]T+@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@268@=7-I;F<@=&AI<R!R96=E
M>"!T97-T(&ET(&ES(&%D=FES86)L90H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@=&\@96YT97(@82!D97-C<FEP=&EO;B!F;W(@=&AI<R!F
M:65L9"!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@=V%R
M;B!T:&4@=7-E<B!W:&%T(&ES(&5X<&5C=&5D+"!A<R!T:&4*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&=E;F5R871E9"!E<G)O<B!M97-S
M86=E(&ES('%U:71E(&=E;F5R:6,*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%N9"!W:6QL(&YO="!G:79E(&%N>2!I;F1I8V%T:6]N('=H
M97)E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@<F5G
M97@@9F%I;&5D+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'-I>F4@("`@("`@
M5&AE('-I>F4@;V8@=&AE(&EN<'5T(&9I96QD+@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)&UA>&QE;F=T:"`@5&AE(&UA>"!N=6UB97(@;V8@8VAA<F%C=&5R
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@:6YI="@D<F5G97@@/2`G)RP@)'-I
M>F4@/2`T,"P@)&UA>&QE;F=T:"`](&YU;&PI"B`@("!["B`@("`@("`@)'1H
M:7,M/E]R96=E>"`@("`@/2`D<F5G97@["B`@("`@("`@)'1H:7,M/E]S:7IE
M("`@("`@/2`D<VEZ93L*("`@("`@("`D=&AI<RT^7VUA>&QE;F=T:"`]("1M
M87AL96YG=&@["B`@("!]"@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@
M)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@("`D=F%L
M:60@/2!T<G5E.PH*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?;6%X;&5N
M9W1H*2`F)B!3=')I;F<Z.FQE;F=T:"@D=F%L=64I(#X@)'1H:7,M/E]M87AL
M96YG=&@I('L*("`@("`@("`@("`@)'9A;&ED(#T@9F%L<V4["B`@("`@("`@
M("`@("1M97-S86=E(#T@<W!R:6YT9BA?*")686QU92!I<R!O=F5R('1H92!M
M87AI;75M(&QE;F=T:"!O9B`E<RXB*2P@)'1H:7,M/E]M87AL96YG=&@I.PH@
M("`@("`@('T@96QS96EF("@D=F%R+3YI<U)E<75I<F5D*"D@)B8@96UP='DH
M)'1H:7,M/E]R96=E>"DI('L*("`@("`@("`@("`@)'9A;&ED(#T@<W1R;&5N
M*'1R:6TH)'9A;'5E*2D@/B`P.PH*("`@("`@("`@("`@:68@*"$D=F%L:60I
M('L*("`@("`@("`@("`@("`@("1M97-S86=E(#T@7R@B5&AI<R!F:65L9"!I
M<R!R97%U:7)E9"XB*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS96EF
M("@A96UP='DH)'1H:7,M/E]R96=E>"DI('L*("`@("`@("`@("`@)'9A;&ED
M(#T@<')E9U]M871C:"@D=&AI<RT^7W)E9V5X+"`D=F%L=64I.PH*("`@("`@
M("`@("`@:68@*"$D=F%L:60I('L*("`@("`@("`@("`@("`@("1M97-S86=E
M(#T@7R@B66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92XB*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1V86QI9#L*
M("`@('T*"B`@("!F=6YC=&EO;B!G9713:7IE*"D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]S:7IE.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$UA
M>$QE;F=T:"@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;6%X;&5N
M9W1H.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&EN9F\@86)O=70@
M9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@86)O=70H*0H@("`@
M>PH@("`@("`@("1A8F]U="`](&%R<F%Y*"D["B`@("`@("`@)&%B;W5T6R=N
M86UE)UT@/2!?*")497AT(BD["B`@("`@("`@)&%B;W5T6R=P87)A;7,G72`]
M(&%R<F%Y*`H@("`@("`@("`@("`G<F5G97@G("`@("`]/B!A<G)A>2@G;&%B
M96PG(#T^(%\H(E)E9V5X(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=T>7!E)R`@/3X@)W1E>'0G*2P*("`@("`@("`@("`@)W-I>F4G
M("`@("`@/3X@87)R87DH)VQA8F5L)R`]/B!?*")3:7IE(BDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@)VEN="<I+`H@
M("`@("`@("`@("`G;6%X;&5N9W1H)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H
M(DUA>&EM=6T@;&5N9W1H(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=T>7!E)R`@/3X@)VEN="<I+`H@("`@("`@("D["B`@("`@("`@
M<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP
M95]S=')I;F=L:7-T(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E7W1E>'0@>PH*
M("`@("\J*@H@("`@("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A
M8F]U="`](&%R<F%Y*"D["B`@("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*")3
M=')I;F<@;&ES="(I.PH@("`@("`@("1A8F]U=%LG<&%R86US)UT@/2!A<G)A
M>2@*("`@("`@("`@("`@)W)E9V5X)R`@("`@/3X@87)R87DH)VQA8F5L)R`]
M/B!?*")296=E>"(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G='EP92<@(#T^("=T97AT)RDL"B`@("`@("`@("`@("=S:7IE)R`@("`@
M(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B4VEZ92(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=I;G0G*2P*("`@("`@
M("`@("`@)VUA>&QE;F=T:"<@/3X@87)R87DH)VQA8F5L)R`]/B!?*")-87AI
M;75M(&QE;F=T:"(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G='EP92<@(#T^("=I;G0G*2P*("`@("`@("`I.PH@("`@("`@(')E='5R
M;B`D86)O=70["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?8V5L
M;'!H;VYE(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@("!F=6YC=&EO
M;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E*0H@
M("`@>PH@("`@("`@("1V86QI9"`]('1R=64["@H@("`@("`@(&EF("@D=F%R
M+3YI<U)E<75I<F5D*"DI('L*("`@("`@("`@("`@)'9A;&ED(#T@<W1R;&5N
M*'1R:6TH)'9A;'5E*2D@/B`P.PH@("`@("`@("`@("!I9B`H(21V86QI9"D@
M>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")4:&ES(&9I96QD(&ES
M(')E<75I<F5D+B(I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'9A;&ED(#T@<')E9U]M871C:"@G+UY<*S];7&0H*5PM
M7"\@72HD+R<L("1V86QU92D["B`@("`@("`@("`@(&EF("@A)'9A;&ED*2![
M"B`@("`@("`@("`@("`@("`D;65S<V%G92`](%\H(EEO=2!H879E('1O(&5N
M=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET
M:"!A;B!O<'1I;VYA;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI
M;F<@<')E9FEX+B(I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)'9A;&ED.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y*"D["B`@("`@
M("`@)&%B;W5T6R=N86UE)UT@/2!?*")#96QL<&AO;F4B*3L*("`@("`@("!R
M971U<FX@)&%B;W5T.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E
M7VEP861D<F5S<R!E>'1E;F1S($AO<F1E7T9O<FU?5'EP95]T97AT('L*"B`@
M("!F=6YC=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M
M97-S86=E*0H@("`@>PH@("`@("`@("1V86QI9"`]('1R=64["@H@("`@("`@
M(&EF("AS=')L96XH=')I;2@D=F%L=64I*2`^(#`I('L*("`@("`@("`@("`@
M)&EP(#T@97AP;&]D92@G+B<L("1V86QU92D["B`@("`@("`@("`@("1V86QI
M9"`]("AC;W5N="@D:7`I(#T](#0I.PH@("`@("`@("`@("!I9B`H)'9A;&ED
M*2!["B`@("`@("`@("`@("`@("!F;W)E86-H("@D:7`@87,@)'!A<G0I('L*
M("`@("`@("`@("`@("`@("`@("!I9B`H(6ES7VYU;65R:6,H)'!A<G0I('Q\
M"B`@("`@("`@("`@("`@("`@("`@("`@("1P87)T(#X@,C4U('Q\"B`@("`@
M("`@("`@("`@("`@("`@("`@("1P87)T(#P@,"D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D=F%L:60@/2!F86QS93L*("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H(21V86QI
M9"D@>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")0;&5A<V4@96YT
M97(@82!V86QI9"!)4"!A9&1R97-S+B(I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E:68@*"1V87(M/FES4F5Q=6ER960H*2D@>PH@("`@("`@("`@
M("`D=F%L:60@/2!F86QS93L*("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")4
M:&ES(&9I96QD(&ES(')E<75I<F5D+B(I.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1V86QI9#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!I
M;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%B
M;W5T*"D*("`@('L*("`@("`@("!R971U<FX@87)R87DH)VYA;64G(#T^(%\H
M(DE0($%D9')E<W,B*2D["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y
M<&5?;&]N9U1E>'0@97AT96YD<R!(;W)D95]&;W)M7U1Y<&5?=&5X="!["@H@
M("`@=F%R("1?<F]W<SL*("`@('9A<B`D7V-O;',["B`@("!V87(@)%]H96QP
M97(@/2!A<G)A>2@I.PH*("`@(&9U;F-T:6]N(&EN:70H)')O=W,@/2`X+"`D
M8V]L<R`](#@P+"`D:&5L<&5R(#T@)R<I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]R;W=S(#T@)')O=W,["B`@("`@("`@)'1H:7,M/E]C;VQS(#T@)&-O;',[
M"B`@("`@("`@)'1H:7,M/E]H96QP97(@/2`D:&5L<&5R.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&=E=%)O=W,H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^7W)O=W,["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T0V]L<R@I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8V]L<SL*("`@('T*"B`@("!F=6YC
M=&EO;B!H87-(96QP97(H)&]P=&EO;B`]("<G*0H@("`@>PH@("`@("`@(&EF
M("AE;7!T>2@D;W!T:6]N*2D@>PH@("`@("`@("`@("`O*B!.;R!O<'1I;VX@
M<W!E8VEF:65D+"!C:&5C:R!I9B!A;GD@:&5L<&5R<R!H879E(&)E96X*("`@
M("`@("`@("`@("H@86-T:79A=&5D+B`J+PH@("`@("`@("`@("!R971U<FX@
M(65M<'1Y*"1T:&ES+3Y?:&5L<&5R*3L*("`@("`@("!](&5L<V5I9B`H96UP
M='DH)'1H:7,M/E]H96QP97(I*2!["B`@("`@("`@("`@("\J($YO(&AE;'!E
M<G,@86-T:79A=&5D(&%T(&%L;"P@<F5T=7)N(&9A;'-E+B`J+PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@+RH@0VAE8VL@:68@9VEV96X@:&5L<&5R(&AA<R!B965N(&%C=&EV871E
M9"X@*B\*("`@("`@("`@("`@<F5T=7)N(&EN7V%R<F%Y*"1O<'1I;VXL("1T
M:&ES+3Y?:&5L<&5R*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FX@:6YF;R!A8F]U="!F:65L9"!T>7!E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R87DH
M*3L*("`@("`@("`D86)O=71;)VYA;64G72`](%\H(DQO;F<@=&5X="(I.PH@
M("`@("`@("1A8F]U=%LG<&%R86US)UT@/2!A<G)A>2@*("`@("`@("`@("`@
M)W)O=W,G("`@/3X@87)R87DH)VQA8F5L)R`]/B!?*").=6UB97(@;V8@<F]W
M<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^
M("=I;G0G*2P*("`@("`@("`@("`@)V-O;',G("`@/3X@87)R87DH)VQA8F5L
M)R`]/B!?*").=6UB97(@;V8@8V]L=6UN<R(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G='EP92<@(#T^("=I;G0G*2P*("`@("`@("`@("`@
M)VAE;'!E<B<@/3X@87)R87DH)VQA8F5L)R`]/B!?*")(96QP97(B*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G8F]O;&5A
M;B<I"B`@("`@("`@*3L*("`@("`@("!R971U<FX@)&%B;W5T.PH@("`@?0H*
M?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7V-O=6YT961497AT(&5X=&5N9',@
M2&]R9&5?1F]R;5]4>7!E7VQO;F=497AT('L*"B`@("!V87(@)%]C:&%R<SL*
M"B`@("!F=6YC=&EO;B!I;FET*"1R;W=S(#T@;G5L;"P@)&-O;',@/2!N=6QL
M+"`D8VAA<G,@/2`Q,#`P*0H@("`@>PH@("`@("`@('!A<F5N=#HZ:6YI="@D
M<F]W<RP@)&-O;',I.PH@("`@("`@("1T:&ES+3Y?8VAA<G,@/2`D8VAA<G,[
M"B`@("!]"@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V87)S+"`D
M=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@("`D=F%L:60@/2!T<G5E
M.PH*("`@("`@("!I9B`H)'9A<BT^:7-297%U:7)E9"@I*2!["B`@("`@("`@
M("`@("1L96YG=&@@/2!3=')I;F<Z.FQE;F=T:"AT<FEM*"1V86QU92DI.PH*
M("`@("`@("`@("`@:68@*"1L96YG=&@@/#T@,"D@>PH@("`@("`@("`@("`@
M("`@)'9A;&ED(#T@9F%L<V4["B`@("`@("`@("`@("`@("`D;65S<V%G92`]
M(%\H(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(BD["B`@("`@("`@("`@('T@
M96QS96EF("@D;&5N9W1H(#X@)'1H:7,M/E]C:&%R<RD@>PH@("`@("`@("`@
M("`@("`@)'9A;&ED(#T@9F%L<V4["B`@("`@("`@("`@("`@("`D;65S<V%G
M92`]('-P<FEN=&8H7R@B5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@
M:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S
M.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(BDL(%-T<FEN9SHZ;&5N
M9W1H*'1R:6TH)'9A;'5E*2DL("1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'9A;&ED.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&=E=$-H87)S*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/E]C:&%R<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!I
M;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%B
M;W5T*"D*("`@('L*("`@("`@("`D86)O=70@/2!A<G)A>2@I.PH@("`@("`@
M("1A8F]U=%LG;F%M92==(#T@7R@B0V]U;G1E9"!T97AT(BD["B`@("`@("`@
M)&%B;W5T6R=P87)A;7,G72`](&%R<F%Y*`H@("`@("`@("`@("`G<F]W<R<@
M(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B3G5M8F5R(&]F(')O=W,B*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=I;G0G*2P*
M("`@("`@("`@("`@)V-O;',G("`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(DYU
M;6)E<B!O9B!C;VQU;6YS(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W1Y<&4G("`]/B`G:6YT)RDL"B`@("`@("`@("`@("=C:&%R<R<@/3X@
M87)R87DH)VQA8F5L)R`]/B!?*").=6UB97(@;V8@8VAA<F%C=&5R<R(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@)VEN="<I
M"B`@("`@("`@*3L*("`@("`@("!R971U<FX@)&%B;W5T.PH@("`@?0H*?0H*
M8VQA<W,@2&]R9&5?1F]R;5]4>7!E7V%D9')E<W,@97AT96YD<R!(;W)D95]&
M;W)M7U1Y<&5?;&]N9U1E>'0@>PH*("`@("\J*@H@("`@("H@4F5T=7)N(&EN
M9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@86)O
M=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y*"D["B`@("`@("`@
M)&%B;W5T6R=N86UE)UT@/2!?*")!9&1R97-S(BD["B`@("`@("`@)&%B;W5T
M6R=P87)A;7,G72`](&%R<F%Y*`H@("`@("`@("`@("`G<F]W<R<@/3X@87)R
M87DH)VQA8F5L)R`]/B!?*").=6UB97(@;V8@<F]W<R(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G:6YT)RDL"B`@("`@("`@
M("`@("=C;VQS)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(DYU;6)E<B!O9B!C
M;VQU;6YS(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@
M(#T^("=I;G0G*2D["B`@("`@("`@<F5T=7)N("1A8F]U=#L*("`@('T*"GT*
M"F-L87-S($AO<F1E7T9O<FU?5'EP95]F:6QE(&5X=&5N9',@2&]R9&5?1F]R
M;5]4>7!E('L*"B`@("!F=6YC=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L
M("1V86QU92P@)B1M97-S86=E*0H@("`@>PH@("`@("`@(&EF("@D=F%R+3YI
M<U)E<75I<F5D*"DI('L*("`@("`@("`@("`@)'5P;&]A9&5D(#T@0G)O=W-E
M<CHZ=V%S1FEL955P;&]A9&5D*"1V87(M/F=E=%9A<DYA;64H*2D["B`@("`@
M("`@("`@(&EF("AI<U]A*"1U<&QO861E9"P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("`@("`@)&UE<W-A9V4@/2`D=7!L;V%D960M/F=E=$UE<W-A
M9V4H*3L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@9G5N8W1I;VX@9V5T26YF;R@F)'9A<G,L("8D=F%R+"`F)&EN9F\I"B`@
M("!["B`@("`@("`@)&YA;64@/2`D=F%R+3YG971687).86UE*"D["B`@("`@
M("`@)'5P;&]A9&5D(#T@0G)O=W-E<CHZ=V%S1FEL955P;&]A9&5D*"1N86UE
M*3L*("`@("`@("!I9B`H)'5P;&]A9&5D(#T]/2!T<G5E*2!["B`@("`@("`@
M("`@("1I;F9O6R=N86UE)UT@/2`D7T9)3$536R1N86UE75LG;F%M92==.PH@
M("`@("`@("`@("`D:6YF;ULG='EP92==(#T@)%]&24Q%4ULD;F%M95U;)W1Y
M<&4G73L*("`@("`@("`@("`@)&EN9F];)W1M<%]N86UE)UT@/2`D7T9)3$53
M6R1N86UE75LG=&UP7VYA;64G73L*("`@("`@("`@("`@)&EN9F];)V9I;&4G
M72`]("1?1DE,15-;)&YA;65=6R=T;7!?;F%M92==.PH@("`@("`@("`@("`D
M:6YF;ULG97)R;W(G72`]("1?1DE,15-;)&YA;65=6R=E<G)O<B==.PH@("`@
M("`@("`@("`D:6YF;ULG<VEZ92==(#T@)%]&24Q%4ULD;F%M95U;)W-I>F4G
M73L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF
M;R!A8F]U="!F:65L9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U
M="@I"B`@("!["B`@("`@("`@<F5T=7)N(&%R<F%Y*"=N86UE)R`]/B!?*")&
M:6QE('5P;&]A9"(I*3L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP
M95]I;6%G92!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@+RHJ"B`@
M("`@*B!(87,@82!F:6QE(&)E96X@=7!L;V%D960@;VX@=&AI<R!F;W)M('-U
M8FUI=#\*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@
M=F%R("1?=7!L;V%D960@/2!N=6QL.PH*("`@("\J*@H@("`@("H@4VAO=R!T
M:&4@=7!L;V%D(&)U='1O;C\*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*
M("`@("`J+PH@("`@=F%R("1?<VAO=U]U<&QO860@/2!T<G5E.PH*("`@("\J
M*@H@("`@("H@4VAO=R!T:&4@;W!T:6]N('1O('5P;&]A9"!A;'-O(&]R:6=I
M;F%L(&YO;BUM;V1I9FEE9"!I;6%G93\*("`@("`J"B`@("`@*B!`=F%R(&)O
M;VQE86X*("`@("`J+PH@("`@=F%R("1?<VAO=U]K965P;W)I9ST@9F%L<V4[
M"@H@("`@+RHJ"B`@("`@*B!(87-H(&-O;G1A:6YI;F<@=&AE('!R979I;W5S
M;'D@=7!L;V%D960@:6UA9V4@:6YF;RX*("`@("`J"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D7VEM9R`](&%R<F%Y*"D["@H@("`@9G5N
M8W1I;VX@:6YI="@D<VAO=U]U<&QO860@/2!T<G5E+"`D<VAO=U]K965P;W)I
M9R`](&9A;'-E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<VAO=U]U<&QO860@
M("`]("1S:&]W7W5P;&]A9#L*("`@("`@("`D=&AI<RT^7W-H;W=?:V5E<&]R
M:6<@/2`D<VAO=U]K965P;W)I9SL*("`@('T*"B`@("!F=6YC=&EO;B!O;E-U
M8FUI="@F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@("\J($=E="!T:&4@
M=7!L;V%D+B`J+PH@("`@("`@("1T:&ES+3Y?9V5T57!L;V%D*"1V87)S+"`D
M=F%R*3L*"B`@("`@("`@+RH@268@=&AI<R!W87,@9&]N92!T:')O=6=H('1H
M92!U<&QO860@8G5T=&]N(&]V97)R:61E('1H92!S=6)M:71T960*("`@("`@
M("`@*B!V86QU92!O9B!T:&4@9F]R;2X@*B\*("`@("`@("!I9B`H)'9A<G,M
M/F=E="@G7V1O7R<@+B`D=F%R+3YG971687).86UE*"DI*2!["B`@("`@("`@
M("`@("1V87(M/F9O<FTM/G-E=%-U8FUI='1E9"AF86QS92D["B`@("`@("`@
M?0H@("`@?0H*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L("8D=F%R<RP@
M)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@)&9I96QD(#T@)'9A
M<G,M/F=E="@D=F%R+3YG971687).86UE*"DI.PH*("`@("`@("`O*B!'970@
M=&AE('5P;&]A9"X@*B\*("`@("`@("`D=&AI<RT^7V=E=%5P;&]A9"@D=F%R
M<RP@)'9A<BD["@H@("`@("`@("\J(%1H92!U<&QO860@9V5N97)A=&5D(&$@
M4$5!4B!%<G)O<BX@*B\*("`@("`@("!I9B`H:7-?82@D=&AI<RT^7W5P;&]A
M9&5D+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("\J($YO="!R97%U
M:7)E9"!A;F0@;F\@:6UA9V4@=7!L;V%D(&%T=&5M<'1E9"X@*B\*("`@("`@
M("`@("`@:68@*"$D=F%R+3YI<U)E<75I<F5D*"D@)B8@96UP='DH)&9I96QD
M6R=I;6<G72D@)B8*("`@("`@("`@("`@("`@("1T:&ES+3Y?=7!L;V%D960M
M/F=E=$-O9&4H*2`]/2`T*2!["B`@("`@("`@("`@("`@("!R971U<FX@=')U
M93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"@D=&AI<RT^7W5P
M;&]A9&5D+3YG971#;V1E*"D@/3T@55!,3T%$7T524E].3U]&24Q%*2`F)@H@
M("`@("`@("`@("`@("`@96UP='DH)&9I96QD6R=I;6<G72DI('L*("`@("`@
M("`@("`@("`@("\J($YO=&AI;F<@=7!L;V%D960@86YD(&YO(&]L9&5R('5P
M;&]A9"X@*B\*("`@("`@("`@("`@("`@("1M97-S86=E(#T@7R@B5&AI<R!F
M:65L9"!I<R!R97%U:7)E9"XB*3L*("`@("`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("`@("`@?2!E;'-E:68@*"%E;7!T>2@D9FEE;&1;)VEM
M9R==*2D@>PH@("`@("`@("`@("`@("`@+RH@3F]T:&EN9R!U<&QO861E9"!B
M=70@;VQD97(@=7!L;V%D('!R97-E;G0N("HO"B`@("`@("`@("`@("`@("!R
M971U<FX@=')U93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("\J(%-O;64@;W1H97(@97)R;W(@;65S<V%G92X@*B\*("`@("`@("`@
M("`@("`@("1M97-S86=E(#T@)'1H:7,M/E]U<&QO861E9"T^9V5T365S<V%G
M92@I.PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("!F=6YC=&EO;B!G971);F9O*"8D=F%R<RP@)B1V87(L("8D:6YF;RD*("`@
M('L*("`@("`@("`O*B!'970@=&AE('5P;&]A9"X@*B\*("`@("`@("`D=&AI
M<RT^7V=E=%5P;&]A9"@D=F%R<RP@)'9A<BD["@H@("`@("`@("\J($=E="!I
M;6%G92!P87)A;7,@<W1O<F5D(&EN('1H92!H:61D96X@9FEE;&0N("HO"B`@
M("`@("`@)'9A;'5E(#T@)'9A<BT^9V5T5F%L=64H)'9A<G,I.PH@("`@("`@
M("1I;F9O(#T@)'1H:7,M/E]I;6<["B`@("`@("`@:68@*&5M<'1Y*"1I;F9O
M6R=F:6QE)UTI*2!["B`@("`@("`@("`@('5N<V5T*"1I;F9O6R=F:6QE)UTI
M.PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@("`@("`@(&EF("@D
M=&AI<RT^7W-H;W=?:V5E<&]R:6<I('L*("`@("`@("`@("`@)&EN9F];)VME
M97!?;W)I9R==(#T@(65M<'1Y*"1V86QU95LG:V5E<%]O<FEG)UTI.PH@("`@
M("`@('T*"B`@("`@("`@+RH@4V5T('1H92!U<&QO861E9"!V86QU92`H96ET
M:&5R('1R=64@;W(@4$5!4E]%<G)O<BDN("HO"B`@("`@("`@)&EN9F];)W5P
M;&]A9&5D)UT@/2`F)'1H:7,M/E]U<&QO861E9#L*"B`@("`@("`@+RH@268@
M82!M;V1I9FEE9"!F:6QE(&5X:7-T<R!M;W9E(&ET(&]V97(@=&AE(&]R:6=I
M;F%L+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7W-H;W=?:V5E<&]R:6<@)B8@
M)&EN9F];)VME97!?;W)I9R==*2!["B`@("`@("`@("`@("\J(%)E<75E<W1E
M9"!T:&4@<V%V:6YG(&]F(&]R:6=I;F%L(&9I;&4@86QS;RX@*B\*("`@("`@
M("`@("`@)&EN9F];)V]R:6=?9FEL92==(#T@2&]R9&4Z.F=E=%1E;7!$:7(H
M*2`N("<O)R`N("1I;F9O6R=F:6QE)UT["B`@("`@("`@("`@("1I;F9O6R=F
M:6QE)UT@/2!(;W)D93HZ9V5T5&5M<$1I<B@I("X@)R]M;V1?)R`N("1I;F9O
M6R=F:6QE)UT["B`@("`@("`@("`@("\J($-H96-K(&EF(&$@;6]D:69I960@
M9FEL92!A8W1U86QL>2!E>&ES=',N("HO"B`@("`@("`@("`@(&EF("@A9FEL
M95]E>&ES=',H)&EN9F];)V9I;&4G72DI('L*("`@("`@("`@("`@("`@("1I
M;F9O6R=F:6QE)UT@/2`D:6YF;ULG;W)I9U]F:6QE)UT["B`@("`@("`@("`@
M("`@("!U;G-E="@D:6YF;ULG;W)I9U]F:6QE)UTI.PH@("`@("`@("`@("!]
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@4V%V:6YG(&]F(&]R
M:6=I;F%L(&YO="!R97%U:7)E9"X@*B\*("`@("`@("`@("`@)&UO9%]F:6QE
M(#T@2&]R9&4Z.F=E=%1E;7!$:7(H*2`N("<O;6]D7R<@+B`D:6YF;ULG9FEL
M92==.PH@("`@("`@("`@("`D:6YF;ULG9FEL92==(#T@2&]R9&4Z.F=E=%1E
M;7!$:7(H*2`N("<O)R`N("1I;F9O6R=F:6QE)UT["@H@("`@("`@("`@("!I
M9B`H9FEL95]E>&ES=',H)&UO9%]F:6QE*2D@>PH@("`@("`@("`@("`@("`@
M+RH@56YL:6YK(&9I<G-T("AH87,@=&\@8F4@9&]N92!O;B!7:6YD;W=S(&UA
M8VAI;F5S/RD@*B\*("`@("`@("`@("`@("`@('5N;&EN:R@D:6YF;ULG9FEL
M92==*3L*("`@("`@("`@("`@("`@(')E;F%M92@D;6]D7V9I;&4L("1I;F9O
M6R=F:6QE)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@1V5T<R!T:&4@=7!L;V%D(&%N9"!S971S('5P('1H92!U
M<&QO860@9&%T82!A<G)A>2X@16ET:&5R"B`@("`@*B!F971C:&5S(&%N('5P
M;&]A9"!D;VYE('=I=&@@=&AI<R!S=6)M:70@;W(@<F5T<FEE<R!S=&]R960*
M("`@("`J('5P;&]A9"!I;F9O+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T
M57!L;V%D*"8D=F%R<RP@)B1V87(I"B`@("!["B`@("`@("`@+RH@1&]N)W0@
M8F]T:&5R('=I=&@@=&AI<R!F=6YC=&EO;B!I9B!A;')E861Y(&-A;&QE9"!A
M;F0@<V5T"B`@("`@("`@("H@=7`@=F%R<RX@*B\*("`@("`@("!I9B`H(65M
M<'1Y*"1T:&ES+3Y?:6UG*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*
M("`@("`@("!]"@H@("`@("`@("\J($-H96-K(&EF(&9I;&4@:&%S(&)E96X@
M=7!L;V%D960N("HO"B`@("`@("`@)'9A<FYA;64@/2`D=F%R+3YG971687).
M86UE*"D["B`@("`@("`@)'1H:7,M/E]U<&QO861E9"`]($)R;W=S97(Z.G=A
M<T9I;&55<&QO861E9"@D=F%R;F%M92`N("=;;F5W72<I.PH*("`@("`@("!I
M9B`H)'1H:7,M/E]U<&QO861E9"`]/3T@=')U92D@>PH@("`@("`@("`@("`O
M*B!!(&9I;&4@:&%S(&)E96X@=7!L;V%D960@;VX@=&AI<R!S=6)M:70N(%-A
M=F4@=&\@=&5M<"!D:7(@9F]R"B`@("`@("`@("`@("`J('!R979I97<@=V]R
M:RX@*B\*("`@("`@("`@("`@)'1H:7,M/E]I;6=;)W1Y<&4G72`]("1T:&ES
M+3YG9715<&QO861E9$9I;&54>7!E*"1V87)N86UE("X@)UMN97==)RD["@H@
M("`@("`@("`@("`O*B!'970@=&AE(&]T:&5R('!A<G1S(&]F('1H92!U<&QO
M860N("HO"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O07)R87DN
M<&AP)SL*("`@("`@("`@("`@2&]R9&5?07)R87DZ.F=E=$%R<F%Y4&%R=',H
M)'9A<FYA;64@+B`G6VYE=UTG+"`D8F%S92P@)&ME>7,I.PH*("`@("`@("`@
M("`@+RH@1V5T('1H92!T96UP;W)A<GD@9FEL92!N86UE+B`J+PH@("`@("`@
M("`@("`D:V5Y<U]P871H(#T@87)R87E?;65R9V4H87)R87DH)&)A<V4L("=T
M;7!?;F%M92<I+"`D:V5Y<RD["B`@("`@("`@("`@("1T:&ES+3Y?:6UG6R=F
M:6QE)UT@/2!(;W)D95]!<G)A>3HZ9V5T16QE;65N="@D7T9)3$53+"`D:V5Y
M<U]P871H*3L*"B`@("`@("`@("`@("\J($=E="!T:&4@86-T=6%L(&9I;&4@
M;F%M92X@*B\*("`@("`@("`@("`@)&ME>7-?<&%T:#T@87)R87E?;65R9V4H
M87)R87DH)&)A<V4L("=N86UE)RDL("1K97ES*3L*("`@("`@("`@("`@)'1H
M:7,M/E]I;6=;)VYA;64G72`]($AO<F1E7T%R<F%Y.CIG971%;&5M96YT*"1?
M1DE,15,L("1K97ES7W!A=&@I.PH*("`@("`@("`@("`@+RH@1V5T('1H92!F
M:6QE('-I>F4N("HO"B`@("`@("`@("`@("1K97ES7W!A=&@](&%R<F%Y7VUE
M<F=E*&%R<F%Y*"1B87-E+"`G<VEZ92<I+"`D:V5Y<RD["B`@("`@("`@("`@
M("1T:&ES+3Y?:6UG6R=S:7IE)UT@/2!(;W)D95]!<G)A>3HZ9V5T16QE;65N
M="@D7T9)3$53+"`D:V5Y<U]P871H*3L*"B`@("`@("`@("`@("\J($=E="!A
M;GD@97AI<W1I;F<@=F%L=65S(&9O<B!T:&4@:6UA9V4@=7!L;V%D(&9I96QD
M+B`J+PH@("`@("`@("`@("`D=7!L;V%D(#T@)'9A<G,M/F=E="@D=F%R+3YG
M971687).86UE*"DI.PH@("`@("`@("`@("`D=7!L;V%D6R=I;6<G72`]($!U
M;G-E<FEA;&EZ92@D=7!L;V%D6R=I;6<G72D["@H@("`@("`@("`@("`O*B!'
M970@=&AE('1E;7`@9FEL92!I9B!A;')E861Y(&]N92!U<&QO861E9"P@;W1H
M97)W:7-E(&-R96%T92!A"B`@("`@("`@("`@("`J(&YE=R!T96UP;W)A<GD@
M9FEL92X@*B\*("`@("`@("`@("`@:68@*"%E;7!T>2@D=7!L;V%D6R=I;6<G
M75LG9FEL92==*2D@>PH@("`@("`@("`@("`@("`@)'1M<%]F:6QE(#T@2&]R
M9&4Z.F=E=%1E;7!$:7(H*2`N("<O)R`N("1U<&QO861;)VEM9R==6R=F:6QE
M)UT["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&UP
M7V9I;&4@/2!(;W)D93HZ9V5T5&5M<$9I;&4H)TAO<F1E)RP@9F%L<V4I.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!-;W9E('1H92!B<F]W<V5R
M(&-R96%T960@=&5M<"!F:6QE('1O('1H92!N97<@=&5M<"!F:6QE+B`J+PH@
M("`@("`@("`@("!M;W9E7W5P;&]A9&5D7V9I;&4H)'1H:7,M/E]I;6=;)V9I
M;&4G72P@)'1M<%]F:6QE*3L*("`@("`@("`@("`@)'1H:7,M/E]I;6=;)V9I
M;&4G72`](&)A<V5N86UE*"1T;7!?9FEL92D["@H@("`@("`@("`@("`O*B!3
M=&]R92!T:&4@=7!L;V%D960@:6UA9V4@9FEL92!D871A('1O('1H92!H:61D
M96X@9FEE;&0N("HO"B`@("`@("`@("`@("1U<&QO861;)VEM9R==(#T@<V5R
M:6%L:7IE*"1T:&ES+3Y?:6UG*3L*("`@("`@("`@("`@)'9A<G,M/G-E="@D
M=F%R+3YG971687).86UE*"DL("1U<&QO860I.PH@("`@("`@('T@96QS96EF
M("@D=&AI<RT^7W5P;&]A9&5D*2!["B`@("`@("`@("`@("\J($9I;&4@:&%S
M(&YO="!B965N('5P;&]A9&5D+B`J+PH@("`@("`@("`@("`D=7!L;V%D(#T@
M)'9A<G,M/F=E="@D=F%R+3YG971687).86UE*"DI.PH@("`@("`@("`@("!I
M9B`H)'1H:7,M/E]U<&QO861E9"T^9V5T0V]D92@I(#T](#0@)B8@(65M<'1Y
M*"1U<&QO861;)VEM9R==*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]I
M;6<@/2!`=6YS97)I86QI>F4H)'5P;&]A9%LG:6UG)UTI.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&=E=%5P;&]A9&5D
M1FEL951Y<&4H)&9I96QD*0H@("`@>PH@("`@("`@("\J($=E="!A;GD@:6YD
M97@@;VX@=&AE(&9I96QD(&YA;64N("HO"B`@("`@("`@<F5Q=6ER95]O;F-E
M("=(;W)D92]!<G)A>2YP:'`G.PH@("`@("`@("1I;F1E>"`]($AO<F1E7T%R
M<F%Y.CIG971!<G)A>5!A<G1S*"1F:65L9"P@)&)A<V4L("1K97ES*3L*"B`@
M("`@("`@:68@*"1I;F1E>"D@>PH@("`@("`@("`@("`O*B!);F1E>"!P<F5S
M96YT+"!F971C:"!T:&4@;6EM92!T>7!E('9A<B!T;R!C:&5C:RX@*B\*("`@
M("`@("`@("`@)&ME>7-?<&%T:"`](&%R<F%Y7VUE<F=E*&%R<F%Y*"1B87-E
M+"`G='EP92<I+"`D:V5Y<RD["B`@("`@("`@("`@("1T>7!E(#T@2&]R9&5?
M07)R87DZ.F=E=$5L96UE;G0H)%]&24Q%4RP@)&ME>7-?<&%T:"D["B`@("`@
M("`@("`@("1K97ES7W!A=&@](&%R<F%Y7VUE<F=E*&%R<F%Y*"1B87-E+"`G
M=&UP7VYA;64G*2P@)&ME>7,I.PH@("`@("`@("`@("`D=&UP7VYA;64@/2!(
M;W)D95]!<G)A>3HZ9V5T16QE;65N="@D7T9)3$53+"`D:V5Y<U]P871H*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!.;R!I;F1E>"P@<VEM
M<&QE('-E="!U<"!O9B!V87)S('1O(&-H96-K+B`J+PH@("`@("`@("`@("`D
M='EP92`]("1?1DE,15-;)&9I96QD75LG='EP92==.PH@("`@("`@("`@("`D
M=&UP7VYA;64@/2`D7T9)3$536R1F:65L9%U;)W1M<%]N86UE)UT["B`@("`@
M("`@?0H*("`@("`@("!I9B`H96UP='DH)'1Y<&4I('Q\("@D='EP92`]/2`G
M87!P;&EC871I;VXO;V-T970M<W1R96%M)RDI('L*("`@("`@("`@("`@+RH@
M5'EP92!W87-N)W0@<V5T(&]N('5P;&]A9"P@=')Y(&%N86QI<VEN9R!T:&4@
M=7!L;V%D+B`J+PH@("`@("`@("`@("!G;&]B86P@)&-O;F8["B`@("`@("`@
M("`@(')E<75I<F5?;VYC92`G2&]R9&4O34E-12]-86=I8RYP:'`G.PH@("`@
M("`@("`@("!I9B`H(2@D='EP92`]($U)345?36%G:6,Z.F%N86QY>F5&:6QE
M*"1T;7!?;F%M92P@:7-S970H)&-O;F9;)VUI;64G75LG;6%G:6-?9&(G72D@
M/R`D8V]N9ELG;6EM92==6R=M86=I8U]D8B==(#H@;G5L;"DI*2!["B`@("`@
M("`@("`@("`@("!I9B`H)&EN9&5X*2!["B`@("`@("`@("`@("`@("`@("`@
M+RH@1V5T('1H92!N86UE('9A;'5E+B`J+PH@("`@("`@("`@("`@("`@("`@
M("1K97ES7W!A=&@@/2!A<G)A>5]M97)G92AA<G)A>2@D8F%S92P@)VYA;64G
M*2P@)&ME>7,I.PH@("`@("`@("`@("`@("`@("`@("1N86UE(#T@2&]R9&5?
M07)R87DZ.F=E=$5L96UE;G0H)%]&24Q%4RP@)&ME>7-?<&%T:"D["@H@("`@
M("`@("`@("`@("`@("`@("\J(%=O<FL@;W5T('1H92!T>7!E(&9R;VT@=&AE
M(&9I;&4@;F%M92X@*B\*("`@("`@("`@("`@("`@("`@("`D='EP92`]($U)
M345?36%G:6,Z.F9I;&5N86UE5&]-24U%*"1N86UE*3L*"B`@("`@("`@("`@
M("`@("`@("`@+RH@4V5T('1H92!T>7!E+B`J+PH@("`@("`@("`@("`@("`@
M("`@("1K97ES7W!A=&@@/2!A<G)A>5]M97)G92AA<G)A>2@D8F%S92P@)W1Y
M<&4G*2P@)&ME>7,I.PH@("`@("`@("`@("`@("`@("`@($AO<F1E7T%R<F%Y
M.CIG971%;&5M96YT*"1?1DE,15,L("1K97ES7W!A=&@L("1T>7!E*3L*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@+RH@
M5V]R:R!O=70@=&AE('1Y<&4@9G)O;2!T:&4@9FEL92!N86UE+B`J+PH@("`@
M("`@("`@("`@("`@("`@("1T>7!E(#T@34E-15]-86=I8SHZ9FEL96YA;654
M;TU)344H)%]&24Q%4ULD9FEE;&1=6R=N86UE)UTI.PH*("`@("`@("`@("`@
M("`@("`@("`O*B!3970@=&AE('1Y<&4N("HO"B`@("`@("`@("`@("`@("`@
M("`@)%]&24Q%4ULD9FEE;&1=6R=T>7!E)UT@/2!-24U%7TUA9VEC.CIF:6QE
M;F%M951O34E-12@D7T9)3$536R1F:65L9%U;)VYA;64G72D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D='EP93L*("`@('T*"B`@("`O*BH*("`@("`J($QO861S(&%N>2!E
M>&ES=&EN9R!I;6%G92!D871A(&EN=&\@=&AE(&EM86=E(&9I96QD+B!297%U
M:7)E<R!T:&%T('1H90H@("`@("H@87)R87D@)&EM86=E('!A<W-E9"!T;R!I
M="!C;VYT86EN<R!T:&4@<W1R=6-T=7)E.@H@("`@("H@("`D:6UA9V5;)VQO
M860G75LG9FEL92==("T@=&AE(&9I;&5N86UE(&]F('1H92!I;6%G93L*("`@
M("`J("`@)&EM86=E6R=L;V%D)UU;)V1A=&$G72`M('1H92!R87<@:6UA9V4@
M9&%T82X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@)&EM86=E("!4:&4@:6UA9V4@87)R87DN"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]L;V%D26UA9V5$871A*"8D:6UA9V4I"B`@
M("!["B`@("`@("`@+RH@3F\@97AI<W1I;F<@:6UA9V4@9&%T82!T;R!L;V%D
M+B`J+PH@("`@("`@(&EF("@A:7-S970H)&EM86=E6R=L;V%D)UTI*2!["B`@
M("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("\J(%-A=F4@
M=&AE(&1A=&$@=&\@=&AE('1E;7`@9&ER+B`J+PH@("`@("`@("1T;7!?9FEL
M92`]($AO<F1E.CIG971496UP1&ER*"D@+B`G+R<@+B`D:6UA9V5;)VQO860G
M75LG9FEL92==.PH@("`@("`@(&EF("@D9F0@/2!F;W!E;B@D=&UP7V9I;&4L
M("=W)RDI('L*("`@("`@("`@("`@9G=R:71E*"1F9"P@)&EM86=E6R=L;V%D
M)UU;)V1A=&$G72D["B`@("`@("`@("`@(&9C;&]S92@D9F0I.PH@("`@("`@
M('T*"B`@("`@("`@)&EM86=E6R=I;6<G72`]('-E<FEA;&EZ92AA<G)A>2@G
M9FEL92<@/3X@)&EM86=E6R=L;V%D)UU;)V9I;&4G72DI.PH@("`@("`@('5N
M<V5T*"1I;6%G95LG;&]A9"==*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O=70@/2!A<G)A>2@I.PH@
M("`@("`@("1A8F]U=%LG;F%M92==(#T@7R@B26UA9V4@=7!L;V%D(BD["B`@
M("`@("`@)&%B;W5T6R=P87)A;7,G72`](&%R<F%Y*`H@("`@("`@("`@("`G
M<VAO=U]U<&QO860G("`@/3X@87)R87DH)VQA8F5L)R`]/B!?*")3:&]W('5P
M;&]A9"(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W1Y<&4G("`]/B`G8F]O;&5A;B<I+`H@("`@("`@("`@("`G<VAO=U]K965P
M;W)I9R<@/3X@87)R87DH)VQA8F5L)R`]/B!?*")3:&]W(&]P=&EO;B!T;R!K
M965P(&]R:6=I;F%L(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G='EP92<@(#T^("=B;V]L96%N)RDI.PH@("`@("`@(')E='5R
M;B`D86)O=70["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?8F]O
M;&5A;B!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@9G5N8W1I;VX@
M:7-686QI9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@
M('L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!G
M971);F9O*"8D=F%R<RP@)B1V87(L("8D:6YF;RD*("`@('L*("`@("`@("`D
M:6YF;R`](%-T<FEN9SHZ;&]W97(H)'9A<G,M/F=E="@D=F%R+3YG971687).
M86UE*"DI*2`]/2`G;VXG.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y*"D["B`@("`@
M("`@)&%B;W5T6R=N86UE)UT@/2!?*")4<G5E(&]R(&9A;'-E(BD["B`@("`@
M("`@<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?
M5'EP95]L:6YK(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@("!F=6YC
M=&EO;B!I;FET*"1V86QU97,I"B`@("!["B`@("`@("`@)'1H:7,M/G9A;'5E
M<R`]("1V86QU97,["B`@("!]"@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A
M<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!I;F9O
M(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%B;W5T
M*"D*("`@('L*("`@("`@("!R971U<FX@87)R87DH"B`@("`@("`@("`@("=N
M86UE)R`]/B!?*"),:6YK(BDL"B`@("`@("`@("`@("=P87)A;7,G(#T^(&%R
M<F%Y*`H@("`@("`@("`@("`@("`@)W5R;"<@/3X@87)R87DH"B`@("`@("`@
M("`@("`@("`@("`@)VQA8F5L)R`]/B!?*"),:6YK(%523"(I+`H@("`@("`@
M("`@("`@("`@("`@("=T>7!E)R`]/B`G=&5X="<I+`H@("`@("`@("`@("`@
M("`@)W1E>'0G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=L86)E
M;"<@/3X@7R@B3&EN:R!T97AT(BDL"B`@("`@("`@("`@("`@("`@("`@)W1Y
M<&4G(#T^("=T97AT)RDL"B`@("`@("`@("`@("`@("`G=&%R9V5T)R`]/B!A
M<G)A>2@*("`@("`@("`@("`@("`@("`@("`G;&%B96PG(#T^(%\H(DQI;FL@
M=&%R9V5T(BDL"B`@("`@("`@("`@("`@("`@("`@)W1Y<&4G(#T^("=T97AT
M)RDL"B`@("`@("`@("`@("`@("`G;VYC;&EC:R<@/3X@87)R87DH"B`@("`@
M("`@("`@("`@("`@("`@)VQA8F5L)R`]/B!?*")/;F-L:6-K(&5V96YT(BDL
M"B`@("`@("`@("`@("`@("`@("`@)W1Y<&4G(#T^("=T97AT)RDL"B`@("`@
M("`@("`@("`@("`G=&ET;&4G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@
M("`@("=L86)E;"<@/3X@7R@B3&EN:R!T:71L92!A='1R:6)U=&4B*2P*("`@
M("`@("`@("`@("`@("`@("`G='EP92<@/3X@)W1E>'0G*2P*("`@("`@("`@
M("`@("`@("=A8V-E<W-K97DG(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@
M("`@("=L86)E;"<@/3X@7R@B3&EN:R!A8V-E<W,@:V5Y(BDL"B`@("`@("`@
M("`@("`@("`@("`@)W1Y<&4G(#T^("=T97AT)RDI*3L*("`@('T*"GT*"F-L
M87-S($AO<F1E7T9O<FU?5'EP95]E;6%I;"!E>'1E;F1S($AO<F1E7T9O<FU?
M5'EP92!["@H@("`@=F%R("1?86QL;W=?;75L=&D@/2!F86QS93L*("`@('9A
M<B`D7W-T<FEP7V1O;6%I;B`](&9A;'-E.PH@("`@=F%R("1?;&EN:U]C;VUP
M;W-E(#T@9F%L<V4["B`@("!V87(@)%]L:6YK7VYA;64@/2!N=6QL.PH*("`@
M(&9U;F-T:6]N(&EN:70H)&%L;&]W7VUU;'1I(#T@9F%L<V4L("1S=')I<%]D
M;VUA:6X@/2!F86QS92P*("`@("`@("`@("`@("`@("`@)&QI;FM?8V]M<&]S
M92`](&9A;'-E+"`D;&EN:U]N86UE(#T@;G5L;"D*("`@('L*("`@("`@("`D
M=&AI<RT^7V%L;&]W7VUU;'1I(#T@)&%L;&]W7VUU;'1I.PH@("`@("`@("1T
M:&ES+3Y?<W1R:7!?9&]M86EN(#T@)'-T<FEP7V1O;6%I;CL*("`@("`@("`D
M=&AI<RT^7VQI;FM?8V]M<&]S92`]("1L:6YK7V-O;7!O<V4["B`@("`@("`@
M)'1H:7,M/E]L:6YK7VYA;64@/2`D;&EN:U]N86UE.PH@("`@?0H*("`@(&9U
M;F-T:6]N(&ES5F%L:60H)B1V87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A
M9V4I"B`@("!["B`@("`@("`@:68@*"1V87(M/FES4F5Q=6ER960H*2`F)B!E
M;7!T>2@D=F%L=64I*2!["B`@("`@("`@("`@("1M97-S86=E(#T@7R@B5&AI
M<R!F:65L9"!I<R!R97%U:7)E9"XB*3L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T@96QS96EF("@A96UP='DH)'9A;'5E*2D@>PH@("`@
M("`@("`@("!R97%U:7)E7V]N8V4@)TUA:6PO4D9#.#(R+G!H<"<["B`@("`@
M("`@("`@("1P87)S97(@/2`F;F5W($UA:6Q?4D9#.#(R*"D["B`@("`@("`@
M("`@("1P87)S961?96UA:6P@/2`D<&%R<V5R+3YP87)S94%D9')E<W-,:7-T
M*"1V86QU92P@9F%L<V4L('1R=64I.PH*("`@("`@("`@("`@:68@*&ES7V$H
M)'!A<G-E9%]E;6%I;"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@)&UE<W-A9V4@/2`D<&%R<V5D7V5M86EL+3YG971-97-S86=E*"D["B`@
M("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@:68@*"@A)'1H:7,M/E]A;&QO=U]M=6QT:2D@)B8@8V]U;G0H
M)'!A<G-E9%]E;6%I;"D@/B`Q*2!["B`@("`@("`@("`@("`@("`D;65S<V%G
M92`](%\H(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"XB*3L*("`@
M("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!I9B`H96UP='DH)'!A<G-E9%]E;6%I;%LP72T^;6%I;&)O>"DI
M('L*("`@("`@("`@("`@("`@("1M97-S86=E(#T@7R@B66]U(&1I9"!N;W0@
M96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+B(I.PH@("`@("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O=70@/2!A<G)A>2@I.PH@("`@
M("`@("1A8F]U=%LG;F%M92==(#T@7R@B16UA:6PB*3L*("`@("`@("`D86)O
M=71;)W!A<F%M<R==(#T@87)R87DH"B`@("`@("`@("`@("=A;&QO=U]M=6QT
M:2<@/3X@87)R87DH)VQA8F5L)R`]/B!?*")!;&QO=R!M=6QT:7!L92!A9&1R
M97-S97,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M='EP92<@(#T^("=B;V]L96%N)RDL"B`@("`@("`@("`@("=S=')I<%]D;VUA
M:6XG(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B4W1R:7`@9&]M86EN(&9R;VT@
M=&AE(&%D9')E<W,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W1Y<&4G(#T^("=B;V]L96%N)RDL"B`@("`@("`@("`@("=L:6YK
M7V-O;7!O<V4G(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B3&EN:R!T:&4@96UA
M:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN
M9R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP
M92<@/3X@)V)O;VQE86XG*2P*("`@("`@("`@("`@)VQI;FM?;F%M92<@/3X@
M87)R87DH)VQA8F5L)R`]/B!?*")4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK
M:6YG('1O('1H92!C;VUP;W-E('!A9V4B*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W1Y<&4G(#T^("=T97AT)RDI.PH@("`@("`@
M(')E='5R;B`D86)O=70["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y
M<&5?;6%T<FEX(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@("!V87(@
M)%]C;VQS.PH@("`@=F%R("1?<F]W<SL*("`@('9A<B`D7VUA=')I>#L*("`@
M('9A<B`D7VYE=U]I;G!U=#L*"B`@("`O*BH*("`@("`J($EN:71I86QI>F5S
M('1H92!V87)I86)L92X*("`@("`J"B`@("`@*B!`97AA;7!L90H@("`@("H@
M:6YI="AA<G)A>2@G0V]L=6UN($$G+"`G0V]L=6UN($(G*2P*("`@("`J("`@
M("`@87)R87DH,2`]/B`G4F]W($]N92<L(#(@/3X@)U)O=R`R)RP@,R`]/B`G
M4F]W(#,G*2P*("`@("`J("`@("`@87)R87DH87)R87DH=')U92P@=')U92P@
M9F%L<V4I+`H@("`@("H@("`@("`@("`@("!A<G)A>2AT<G5E+"!F86QS92P@
M=')U92DL"B`@("`@*B`@("`@("`@("`@(&%R<F%Y*&9A<VQE+"!T<G5E+"!F
M86QS92DI+`H@("`@("H@("`@("!A<G)A>2@G4F]W(#0G+"`G4F]W(#4G*2D[
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1C;VQS("`@("`@("`@("`@
M("`@02!L:7-T(&]F(&-O;'5M;B!H96%D97)S+@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1R;W=S("`@("`@("`@("`@("`@02!H87-H('=I=&@@<F]W($E$<R!A
M<R!T:&4@:V5Y<R!A;F0@<F]W"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!L86)E;',@87,@=&AE('9A;'5E<RX*("`@("`J($!P
M87)A;2!A<G)A>2`D;6%T<FEX("`@("`@("`@("`@($$@='=O(&1I;65N<VEO
M;F%L(&AA<V@@=VET:"!T:&4@9FEE;&0*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('9A;'5E<RX*("`@("`J($!P87)A;2!B;V]L
M96%N?&%R<F%Y("1N97=?:6YP=70@($EF('1R=64L(&$@9G)E92!T97AT(&9I
M96QD('1O(&%D9"!A(&YE=PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<F]W(&ES(&1I<W!L87EE9"!O;B!T:&4@=&]P+"!A('-E
M;&5C=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M8F]X(&EF('1H:7,@<&%R86UE=&5R(&ES(&$@=F%L=64N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&EN:70H)&-O;',L("1R;W=S(#T@87)R87DH*2P@)&UA=')I
M>"`](&%R<F%Y*"DL("1N97=?:6YP=70@/2!F86QS92D*("`@('L*("`@("`@
M("`D=&AI<RT^7V-O;',@("`@("`@/2`D8V]L<SL*("`@("`@("`D=&AI<RT^
M7W)O=W,@("`@("`@/2`D<F]W<SL*("`@("`@("`D=&AI<RT^7VUA=')I>"`@
M("`@/2`D;6%T<FEX.PH@("`@("`@("1T:&ES+3Y?;F5W7VEN<'5T("`]("1N
M97=?:6YP=70["B`@("!]"@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@
M)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!G971#;VQS*"D@("`@('L@
M<F5T=7)N("1T:&ES+3Y?8V]L<SL@?0H@("`@9G5N8W1I;VX@9V5T4F]W<R@I
M("`@("![(')E='5R;B`D=&AI<RT^7W)O=W,[('T*("`@(&9U;F-T:6]N(&=E
M=$UA=')I>"@I("`@>R!R971U<FX@)'1H:7,M/E]M871R:7@[('T*("`@(&9U
M;F-T:6]N(&=E=$YE=TEN<'5T*"D@>R!R971U<FX@)'1H:7,M/E]N97=?:6YP
M=70[('T*"B`@("!F=6YC=&EO;B!G971);F9O*"8D=F%R<RP@)B1V87(L("8D
M:6YF;RD*("`@('L*("`@("`@("`D=F%L=65S(#T@)'9A<G,M/F=E="@D=F%R
M+3YG971687).86UE*"DI.PH@("`@("`@(&EF("@A96UP='DH)'9A;'5E<ULG
M;B==6R=R)UTI("8F(&ES<V5T*"1V86QU97-;)VXG75LG=B==*2D@>PH@("`@
M("`@("`@("`D;F5W7W)O=R`]("1V86QU97-;)VXG75LG<B==.PH@("`@("`@
M("`@("`D=F%L=65S6R=R)UU;)&YE=U]R;W==(#T@)'9A;'5E<ULG;B==6R=V
M)UT["B`@("`@("`@("`@('5N<V5T*"1V86QU97-;)VXG72D["B`@("`@("`@
M?0H*("`@("`@("`D:6YF;R`]("AI<W-E="@D=F%L=65S6R=R)UTI(#\@)'9A
M;'5E<ULG<B==(#H@87)R87DH*2D["B`@("!]"@H@("`@9G5N8W1I;VX@86)O
M=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y*"D["B`@("`@("`@
M)&%B;W5T6R=N86UE)UT@/2!?*")&:65L9"!M871R:7@B*3L*("`@("`@("`D
M86)O=71;)W!A<F%M<R==(#T@87)R87DH"B`@("`@("`@("`@("=C;VQS)R`]
M/B!A<G)A>2@G;&%B96PG(#T^(%\H(D-O;'5M;B!T:71L97,B*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@)W-T<FEN9VQI<W0G
M*2D["B`@("`@("`@<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO
M<F1E7T9O<FU?5'EP95]E;6%I;$-O;F9I<FT@97AT96YD<R!(;W)D95]&;W)M
M7U1Y<&4@>PH*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L("8D=F%R<RP@
M)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@:68@*"1V87(M/FES
M4F5Q=6ER960H*2`F)B!E;7!T>2@D=F%L=65;)V]R:6=I;F%L)UTI*2!["B`@
M("`@("`@("`@("1M97-S86=E(#T@7R@B5&AI<R!F:65L9"!I<R!R97%U:7)E
M9"XB*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"1V86QU95LG;W)I9VEN86PG72`A/2`D=F%L=65;)V-O;F9I
M<FTG72D@>PH@("`@("`@("`@("`D;65S<V%G92`](%\H(D5M86EL(&%D9')E
M<W-E<R!M=7-T(&UA=&-H+B(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=-
M86EL+U)&0S@R,BYP:'`G.PH@("`@("`@("`@("`D<&%R<V5R(#T@)FYE=R!-
M86EL7U)&0S@R,B@I.PH@("`@("`@("`@("`D<&%R<V5D7V5M86EL(#T@)'!A
M<G-E<BT^<&%R<V5!9&1R97-S3&ES="@D=F%L=65;)V]R:6=I;F%L)UTL(&9A
M;'-E+"!T<G5E*3L*"B`@("`@("`@("`@(&EF("AC;W5N="@D<&%R<V5D7V5M
M86EL*2`^(#$I('L*("`@("`@("`@("`@("`@("1M97-S86=E(#T@7R@B3VYL
M>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+B(I.PH@("`@("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("AE;7!T>2@D<&%R<V5D7V5M86EL6S!=+3YM86EL8F]X*2D@>PH@("`@("`@
M("`@("`@("`@)&UE<W-A9V4@/2!?*")9;W4@9&ED(&YO="!E;G1E<B!A('9A
M;&ED(&5M86EL(&%D9')E<W,N(BD["B`@("`@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&EN9F\@86)O
M=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@86)O=70H*0H@
M("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y*"D["B`@("`@("`@)&%B;W5T
M6R=N86UE)UT@/2!?*")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(I.PH@("`@
M("`@(')E='5R;B`D86)O=70["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M
M7U1Y<&5?<&%S<W=O<F0@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@
M(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE
M<W-A9V4I"B`@("!["B`@("`@("`@)'9A;&ED(#T@=')U93L*"B`@("`@("`@
M:68@*"1V87(M/FES4F5Q=6ER960H*2D@>PH@("`@("`@("`@("`D=F%L:60@
M/2!S=')L96XH=')I;2@D=F%L=64I*2`^(#`["@H@("`@("`@("`@("!I9B`H
M(21V86QI9"D@>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")4:&ES
M(&9I96QD(&ES(')E<75I<F5D+B(I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)'9A;&ED.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y
M*"D["B`@("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*")087-S=V]R9"(I.PH@
M("`@("`@(')E='5R;B`D86)O=70["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&
M;W)M7U1Y<&5?<&%S<W=O<F1#;VYF:7)M(&5X=&5N9',@2&]R9&5?1F]R;5]4
M>7!E('L*"B`@("!F=6YC=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V
M86QU92P@)B1M97-S86=E*0H@("`@>PH@("`@("`@(&EF("@D=F%R+3YI<U)E
M<75I<F5D*"D@)B8@96UP='DH)'9A;'5E6R=O<FEG:6YA;"==*2D@>PH@("`@
M("`@("`@("`D;65S<V%G92`](%\H(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N
M(BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@
M("`@(&EF("@D=F%L=65;)V]R:6=I;F%L)UT@(3T@)'9A;'5E6R=C;VYF:7)M
M)UTI('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")087-S=V]R9',@;75S
M="!M871C:"XB*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@9G5N8W1I;VX@
M9V5T26YF;R@F)'9A<G,L("8D=F%R+"`F)&EN9F\I"B`@("!["B`@("`@("`@
M)'9A;'5E(#T@)'9A<G,M/F=E="@D=F%R+3YG971687).86UE*"DI.PH@("`@
M("`@("1I;F9O(#T@)'9A;'5E6R=O<FEG:6YA;"==.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`]
M(&%R<F%Y*"D["B`@("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*")087-S=V]R
M9"!W:71H(&-O;F9I<FUA=&EO;B(I.PH@("`@("`@(')E='5R;B`D86)O=70[
M"B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?96YU;2!E>'1E;F1S
M($AO<F1E7T9O<FU?5'EP92!["@H@("`@=F%R("1?=F%L=65S.PH@("`@=F%R
M("1?<')O;7!T.PH*("`@(&9U;F-T:6]N(&EN:70H)'9A;'5E<RP@)'!R;VUP
M="`](&YU;&PI"B`@("!["B`@("`@("`@)'1H:7,M/E]V86QU97,@/2`D=F%L
M=65S.PH*("`@("`@("!I9B`H)'!R;VUP="`]/3T@=')U92D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W!R;VUP="`](%\H(BTM('-E;&5C="`M+2(I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?<')O;7!T(#T@)'!R
M;VUP=#L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@:7-686QI9"@F
M)'9A<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@
M("!I9B`H)'9A<BT^:7-297%U:7)E9"@I("8F("1V86QU92`]/2`G)R`F)B`A
M:7-S970H)'1H:7,M/E]V86QU97-;)'9A;'5E72DI('L*("`@("`@("`@("`@
M)&UE<W-A9V4@/2!?*")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(I.PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H
M8V]U;G0H)'1H:7,M/E]V86QU97,I(#T](#`@?'P@:7-S970H)'1H:7,M/E]V
M86QU97-;)'9A;'5E72D@?'P*("`@("`@("`@("`@*"1T:&ES+3Y?<')O;7!T
M("8F(&5M<'1Y*"1V86QU92DI*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@("`@('T*"B`@("`@("`@)&UE<W-A9V4@/2!?*"));G9A;&ED(&1A
M=&$@<W5B;6ET=&5D+B(I.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*
M"B`@("!F=6YC=&EO;B!G971686QU97,H*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7W9A;'5E<SL*("`@('T*"B`@("!F=6YC=&EO;B!G9710<F]M
M<'0H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W!R;VUP=#L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y
M<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%B;W5T*"D*("`@('L*("`@("`@
M("`D86)O=70@/2!A<G)A>2@I.PH@("`@("`@("1A8F]U=%LG;F%M92==(#T@
M7R@B1')O<"!D;W=N(&QI<W0B*3L*("`@("`@("`D86)O=71;)W!A<F%M<R==
M(#T@87)R87DH"B`@("`@("`@("`@("=V86QU97,G(#T^(&%R<F%Y*"=L86)E
M;"<@/3X@7R@B5F%L=65S('1O('-E;&5C="!F<F]M(BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@)W-T<FEN9VQI<W0G*2P*
M("`@("`@("`@("`@)W!R;VUP="<@/3X@87)R87DH)VQA8F5L)R`]/B!?*")0
M<F]M<'0@=&5X="(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M='EP92<@(#T^("=T97AT)RDI.PH@("`@("`@(')E='5R;B`D86)O=70["B`@
M("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?;6QE;G5M(&5X=&5N9',@
M2&]R9&5?1F]R;5]4>7!E('L*"B`@("!V87(@)%]V86QU97,["B`@("!V87(@
M)%]P<F]M<'1S.PH*("`@(&9U;F-T:6]N(&EN:70H)B1V86QU97,L("1P<F]M
M<'1S(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^7W9A;'5E<R`]("8D
M=F%L=65S.PH*("`@("`@("!I9B`H)'!R;VUP=',@/3T]('1R=64I('L*("`@
M("`@("`@("`@)'1H:7,M/E]P<F]M<'1S(#T@87)R87DH7R@B+2T@<V5L96-T
M("TM(BDL(%\H(BTM('-E;&5C="`M+2(I*3L*("`@("`@("!](&5L<V5I9B`H
M(6ES7V%R<F%Y*"1P<F]M<'1S*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!R
M;VUP=',@/2!A<G)A>2@D<')O;7!T<RP@)'!R;VUP=',I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?<')O;7!T<R`]("1P<F]M<'1S
M.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!O;E-U8FUI="@F)'9A
M<BP@)B1V87)S*0H@("`@>PH@("`@("`@("1V87)N86UE(#T@)'9A<BT^9V5T
M5F%R3F%M92@I.PH@("`@("`@("1V86QU92`]("1V87)S+3YG970H)'9A<FYA
M;64I.PH*("`@("`@("!I9B`H)'9A;'5E6R<Q)UT@(3T@)'9A;'5E6R=O;&0G
M72D@>PH@("`@("`@("`@("`D=F%R+3YF;W)M+3YS9713=6)M:71T960H9F%L
M<V4I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!I<U9A;&ED*"8D
M=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E*0H@("`@>PH@("`@("`@
M(&EF("@D=F%R+3YI<U)E<75I<F5D*"D@)B8@*&5M<'1Y*"1V86QU95LG,2==
M*2!\?"!E;7!T>2@D=F%L=65;)S(G72DI*2!["B`@("`@("`@("`@("1M97-S
M86=E(#T@7R@B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB*3L*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@*"%C;W5N
M="@D=&AI<RT^7W9A;'5E<RD@?'P@:7-S970H)'1H:7,M/E]V86QU97-;)'9A
M;'5E6R<Q)UU=*2!\?`H@("`@("`@("`@("`H(65M<'1Y*"1T:&ES+3Y?<')O
M;7!T<RD@)B8@96UP='DH)'9A;'5E6R<Q)UTI*2D@>PH@("`@("`@("`@("!R
M971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("1M97-S86=E(#T@7R@B
M26YV86QI9"!D871A('-U8FUI='1E9"XB*3L*("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T5F%L=65S*"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/E]V86QU97,["B`@("!]"@H@("`@9G5N8W1I
M;VX@9V5T4')O;7!T<R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M<')O;7!T<SL*("`@('T*"B`@("!F=6YC=&EO;B!G971);F9O*"8D=F%R<RP@
M)B1V87(L("8D:6YF;RD*("`@('L*("`@("`@("`D:6YF;R`]("1V87)S+3YG
M970H)'9A<BT^9V5T5F%R3F%M92@I*3L*("`@("`@("!R971U<FX@)&EN9F];
M)S(G73L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!I;F9O(&%B;W5T
M(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%B;W5T*"D*("`@
M('L*("`@("`@("`D86)O=70@/2!A<G)A>2@I.PH@("`@("`@("1A8F]U=%LG
M;F%M92==(#T@7R@B375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S(BD["B`@
M("`@("`@)&%B;W5T6R=P87)A;7,G72`](&%R<F%Y*`H@("`@("`@("`@("`G
M=F%L=65S)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(E9A;'5E<R!T;R!S96QE
M8W0@9G)O;2(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP
M92<@(#T^("=S=')I;F=L:7-T)RDL"B`@("`@("`@("`@("=P<F]M<'0G(#T^
M(&%R<F%Y*"=L86)E;"<@/3X@7R@B4')O;7!T('1E>'0B*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G=&5X="<I*3L*("`@
M("`@("!R971U<FX@)&%B;W5T.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R
M;5]4>7!E7VUU;'1I96YU;2!E>'1E;F1S($AO<F1E7T9O<FU?5'EP95]E;G5M
M('L*"B`@("!V87(@)'-I>F4@/2`U.PH*("`@(&9U;F-T:6]N(&EN:70H)'9A
M;'5E<RP@)'-I>F4@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-?;G5L
M;"@D<VEZ92DI('L*("`@("`@("`@("`@)'1H:7,M/G-I>F4@/2`H:6YT*21S
M:7IE.PH@("`@("`@('T*"B`@("`@("`@<&%R96YT.CII;FET*"1V86QU97,I
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L("8D=F%R<RP@
M)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y
M*"1V86QU92DI('L*("`@("`@("`@("`@9F]R96%C:"`H)'9A;'5E(&%S("1V
M86PI('L*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/FES5F%L:60H)'9A
M<BP@)'9A<G,L("1V86PL("1M97-S86=E*2D@>PH@("`@("`@("`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@
M("`@(&EF("AE;7!T>2@D=F%L=64I("8F("@H<W1R:6YG*2AI;G0I)'9A;'5E
M("$]/2`D=F%L=64I*2!["B`@("`@("`@("`@(&EF("@D=F%R+3YI<U)E<75I
M<F5D*"DI('L*("`@("`@("`@("`@("`@("1M97-S86=E(#T@7R@B5&AI<R!F
M:65L9"!I<R!R97%U:7)E9"XB*3L*("`@("`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I
M9B`H8V]U;G0H)'1H:7,M/E]V86QU97,I(#T](#`@?'P@:7-S970H)'1H:7,M
M/E]V86QU97-;)'9A;'5E72DI('L*("`@("`@("`@("`@<F5T=7)N('1R=64[
M"B`@("`@("`@?0H*("`@("`@("`D;65S<V%G92`](%\H(DEN=F%L:60@9&%T
M82!S=6)M:71T960N(BD["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A
M8F]U="`](&%R<F%Y*"D["B`@("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*")-
M=6QT:7!L92!S96QE8W1I;VXB*3L*("`@("`@("`D86)O=71;)W!A<F%M<R==
M(#T@87)R87DH"B`@("`@("`@("`@("=V86QU97,G(#T^(&%R<F%Y*"=L86)E
M;"<@/3X@7R@B5F%L=65S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=T>7!E)R`@/3X@)W-T<FEN9VQI<W0G*2P*("`@("`@("`@("`@)W-I
M>F4G("`@/3X@87)R87DH)VQA8F5L)R`]/B!?*")3:7IE(BDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@)VEN="<I*3L*("`@
M("`@("!R971U<FX@)&%B;W5T.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R
M;5]4>7!E7W)A9&EO(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E7V5N=6T@>PH*
M("`@("\J($5N=&ER96QY(&EM<&QE;65N=&5D(&)Y($AO<F1E7T9O<FU?5'EP
M95]E;G5M.R!J=7-T(&$@9&EF9F5R96YT"B`@("`@*B!V:65W+B`J+PH*("`@
M("\J*@H@("`@("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U
M="`](&%R<F%Y*"D["B`@("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*")2861I
M;R!S96QE8W1I;VXB*3L*("`@("`@("`D86)O=71;)W!A<F%M<R==(#T@87)R
M87DH"B`@("`@("`@("`@("=V86QU97,G(#T^(&%R<F%Y*"=L86)E;"<@/3X@
M7R@B5F%L=65S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T
M>7!E)R`@/3X@)W-T<FEN9VQI<W0G*2D["B`@("`@("`@<F5T=7)N("1A8F]U
M=#L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP95]S970@97AT96YD
M<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@('9A<B`D7W9A;'5E<SL*("`@('9A
M<B`D7V-H96-K06QL(#T@9F%L<V4["@H@("`@9G5N8W1I;VX@:6YI="@F)'9A
M;'5E<RP@)&-H96-K06QL(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]V86QU97,@/2`D=F%L=65S.PH@("`@("`@("1T:&ES+3Y?8VAE8VM!;&P@
M/2`D8VAE8VM!;&P["B`@("!]"@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A
M<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@("!I
M9B`H8V]U;G0H)'1H:7,M/E]V86QU97,I(#T](#`@?'P@8V]U;G0H)'9A;'5E
M*2`]/2`P*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*
M("`@("`@("!F;W)E86-H("@D=F%L=64@87,@)&ET96TI('L*("`@("`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^7W9A;'5E<ULD:71E;5TI*2!["B`@("`@
M("`@("`@("`@("`D97)R;W(@/2!T<G5E.PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E
M="@D97)R;W(I*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M('T*"B`@("`@("`@)&UE<W-A9V4@/2!?*"));G9A;&ED(&1A=&$@<W5B;6ET
M=&5D+B(I.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("!F=6YC
M=&EO;B!G971686QU97,H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M7W9A;'5E<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!I;F9O(&%B
M;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%B;W5T*"D*
M("`@('L*("`@("`@("`D86)O=70@/2!A<G)A>2@I.PH@("`@("`@("1A8F]U
M=%LG;F%M92==(#T@7R@B4V5T(BD["B`@("`@("`@)&%B;W5T6R=P87)A;7,G
M72`](&%R<F%Y*`H@("`@("`@("`@("`G=F%L=65S)R`]/B!A<G)A>2@G;&%B
M96PG(#T^(%\H(E9A;'5E<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G='EP92<@(#T^("=S=')I;F=L:7-T)RDI.PH@("`@("`@(')E='5R
M;B`D86)O=70["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?9&%T
M92!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@=F%R("1?9F]R;6%T
M.PH*("`@(&9U;F-T:6]N(&EN:70H)&9O<FUA="`]("<E82`E9"`E0B<I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]F;W)M870@/2`D9F]R;6%T.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L("8D=F%R<RP@)'9A;'5E+"`F
M)&UE<W-A9V4I"B`@("!["B`@("`@("`@)'9A;&ED(#T@=')U93L*"B`@("`@
M("`@:68@*"1V87(M/FES4F5Q=6ER960H*2D@>PH@("`@("`@("`@("`D=F%L
M:60@/2!S=')L96XH=')I;2@D=F%L=64I*2`^(#`["@H@("`@("`@("`@("!I
M9B`H(21V86QI9"D@>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2!S<')I
M;G1F*%\H(B5S(&ES(')E<75I<F5D(BDL("1V87(M/F=E=$AU;6%N3F%M92@I
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1V
M86QI9#L*("`@('T*"B`@("`O*BH*("`@("`J($!S=&%T:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T06=O*"1T:6UE<W1A;7`I"B`@("!["B`@("`@("`@
M<F5Q=6ER95]O;F-E("=$871E+T-A;&,N<&AP)SL*("`@("`@("`D9&EF9F1A
M>7,@/2!$871E7T-A;&,Z.F1A=&5$:69F*&1A=&4H)VHG+"`D=&EM97-T86UP
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&1A
M=&4H)VXG+"`D=&EM97-T86UP*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&1A=&4H)UDG+"`D=&EM97-T86UP*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&1A=&4H)VHG*2P@
M9&%T92@G;B<I+"!D871E*"=9)RDI.PH*("`@("`@("`O*B!!;B!E<G)O<B!O
M8V-U<F5D+B`J+PH@("`@("`@(&EF("@D9&EF9F1A>7,@/3T@+3$I('L*("`@
M("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@)&%G;R`]("1D
M:69F9&%Y<R`J($1A=&5?0V%L8SHZ8V]M<&%R941A=&5S*&1A=&4H)VHG+"`D
M=&EM97-T86UP*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@9&%T92@G;B<L("1T:6UE<W1A;7`I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!D871E*"=9)RP@)'1I;65S=&%M<"DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&1A=&4H)VHG*2P@9&%T
M92@G;B<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!D871E*"=9)RDI.PH@("`@("`@(&EF("@D86=O(#P@
M+3$I('L*("`@("`@("`@("`@<F5T=7)N('-P<FEN=&8H7R@B("@E<R!D87ES
M(&%G;RDB*2P@)&1I9F9D87ES*3L*("`@("`@("!](&5L<V5I9B`H)&%G;R`]
M/2`M,2D@>PH@("`@("`@("`@("!R971U<FX@7R@B("AY97-T97)D87DI(BD[
M"B`@("`@("`@?2!E;'-E:68@*"1A9V\@/3T@,"D@>PH@("`@("`@("`@("!R
M971U<FX@7R@B("AT;V1A>2DB*3L*("`@("`@("!](&5L<V5I9B`H)&%G;R`]
M/2`Q*2!["B`@("`@("`@("`@(')E='5R;B!?*"(@*'1O;6]R<F]W*2(I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!S<')I;G1F*%\H
M(B`H:6X@)7,@9&%Y<RDB*2P@)&1I9F9D87ES*3L*("`@("`@("!]"B`@("!]
M"@H@("`@9G5N8W1I;VX@9V5T1F]R;6%T=&5D5&EM92@D=&EM97-T86UP+"`D
M9F]R;6%T(#T@;G5L;"P@)'-H;W=A9V\@/2!T<G5E*0H@("`@>PH@("`@("`@
M(&EF("AE;7!T>2@D9F]R;6%T*2D@>PH@("`@("`@("`@("`D9F]R;6%T(#T@
M)'1H:7,M/E]F;W)M870["B`@("`@("`@?0H@("`@("`@(&EF("@A96UP='DH
M)'1I;65S=&%M<"DI('L*("`@("`@("`@("`@<F5T=7)N('-T<F9T:6UE*"1F
M;W)M870L("1T:6UE<W1A;7`I("X@*"1S:&]W86=O(#\@2&]R9&5?1F]R;5]4
M>7!E7V1A=&4Z.F=E=$%G;R@D=&EM97-T86UP*2`Z("<G*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@
M(')E='5R;B!A<G)A>2@G;F%M92<@/3X@7R@B1&%T92(I*3L*("`@('T*"GT*
M"F-L87-S($AO<F1E7T9O<FU?5'EP95]T:6UE(&5X=&5N9',@2&]R9&5?1F]R
M;5]4>7!E('L*"B`@("!F=6YC=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L
M("1V86QU92P@)B1M97-S86=E*0H@("`@>PH@("`@("`@(&EF("@D=F%R+3YI
M<U)E<75I<F5D*"D@)B8@96UP='DH)'9A;'5E*2`F)B`H*'-T<FEN9RDH9&]U
M8FQE*21V86QU92`A/3T@)'9A;'5E*2D@>PH@("`@("`@("`@("`D;65S<V%G
M92`](%\H(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(BD["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(&EF("AE;7!T>2@D
M=F%L=64I('Q\('!R96=?;6%T8V@H)R]>6S`M,ET_6S`M.5TZ6S`M-5U;,"TY
M720O)RP@)'9A;'5E*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@
M("`@("!]"@H@("`@("`@("1M97-S86=E(#T@7R@B5&AI<R!F:65L9"!M87D@
M;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BXB*3L*("`@("`@
M("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@
M:6YF;R!A8F]U="!F:65L9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A
M8F]U="@I"B`@("!["B`@("`@("`@<F5T=7)N(&%R<F%Y*"=N86UE)R`]/B!?
M*")4:6UE(BDI.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7VAO
M=7)-:6YU=&5396-O;F0@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@
M('9A<B`D7W-H;W=?<V5C;VYD<SL*"B`@("!F=6YC=&EO;B!I;FET*"1S:&]W
M7W-E8V]N9',@/2!F86QS92D*("`@('L*("`@("`@("`D=&AI<RT^7W-H;W=?
M<V5C;VYD<R`]("1S:&]W7W-E8V]N9',["B`@("!]"@H@("`@9G5N8W1I;VX@
M:7-686QI9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@
M('L*("`@("`@("`D=&EM92`]("1V87)S+3YG970H)'9A<BT^9V5T5F%R3F%M
M92@I*3L*("`@("`@("!I9B`H(21T:&ES+3Y?<VAO=U]S96-O;F1S("8F("%I
M<W-E="@D=&EM95LG<V5C;VYD)UTI*2!["B`@("`@("`@("`@("1T:6UE6R=S
M96-O;F0G72`](#`["B`@("`@("`@?0H*("`@("`@("!I9B`H(21T:&ES+3YE
M;7!T>51I;65!<G)A>2@D=&EM92D@)B8@(21T:&ES+3YC:&5C:W1I;64H)'1I
M;65;)VAO=7(G72P@)'1I;65;)VUI;G5T92==+"`D=&EM95LG<V5C;VYD)UTI
M*2!["B`@("`@("`@("`@("1M97-S86=E(#T@7R@B4&QE87-E(&5N=&5R(&$@
M=F%L:60@=&EM92XB*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T@96QS96EF("@D=&AI<RT^96UP='E4:6UE07)R87DH)'1I;64I("8F
M("1V87(M/FES4F5Q=6ER960H*2D@>PH@("`@("`@("`@("`D;65S<V%G92`]
M(%\H(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(BD["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&-H96-K=&EM92@D:&]U<BP@)&UI;G5T92P@
M)'-E8V]N9"D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1H;W5R*2!\?"`D
M:&]U<B`]/2`G)R!\?"`H)&AO=7(@/"`P('Q\("1H;W5R(#X@,C,I*2!["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@:68@
M*"%I<W-E="@D;6EN=71E*2!\?"`D;6EN=71E(#T]("<G('Q\("@D;6EN=71E
M(#P@,"!\?"`D;6EN=71E(#X@-C`I*2!["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D<V5C;VYD*2!\
M?"`D<V5C;VYD(#T]/2`G)R!\?"`H)'-E8V]N9"`\(#`@?'P@)'-E8V]N9"`^
M(#8P*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;B!T:&4@=&EM92!S=7!P;&EE9"!A<R!A($AO<F1E7T1A=&4@;V)J96-T
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1I;65?:6X@($1A=&4@
M:6X@;VYE(&]F('1H92!T:')E92!F;W)M871S('-U<'!O<G1E9"!B>0H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@2&]R9&5?1F]R;2!A;F0@2&]R
M9&5?1&%T92`H25-/(&9O<FUA=`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@65E962U-32U$1"!(2#I-33I34RP@=&EM97-T86UP(%E965E-341$
M2$A-35-3(&%N9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@54Y)
M6"!E<&]C:"DN"B`@("`@*@H@("`@("H@0')E='5R;B!$871E("!4:&4@=&EM
M92!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1I;65/8B@D=&EM
M95]I;BD*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T1A=&4N
M<&AP)SL*"B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:6UE7VEN*2D@>PH@("`@
M("`@("`@("!I9B`H(21T:&ES+3YE;7!T>51I;65!<G)A>2@D=&EM95]I;BDI
M('L*("`@("`@("`@("`@("`@("1T:6UE7VEN(#T@<W!R:6YT9B@G,3DW,"TP
M,2TP,2`E,#)D.B4P,F0Z)3`R9"<L("1T:6UE7VEN6R=H;W5R)UTL("1T:6UE
M7VEN6R=M:6YU=&4G72P@)'1I;65?:6Y;)W-E8V]N9"==*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&YE=R!(;W)D95]$871E
M*"1T:6UE7VEN*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@
M=&EM92!S=7!P;&EE9"!S<&QI="!U<"!I;G1O(&%N(&%R<F%Y+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'1I;65?:6X@(%1I;64@:6X@;VYE(&]F
M('1H92!T:')E92!F;W)M871S('-U<'!O<G1E9"!B>0H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@2&]R9&5?1F]R;2!A;F0@2&]R9&5?1&%T92`H
M25-/(&9O<FUA=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@65E9
M62U-32U$1"!(2#I-33I34RP@=&EM97-T86UP(%E965E-341$2$A-35-3(&%N
M9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@54Y)6"!E<&]C:"DN
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@07)R87D@=VET:"!T:')E
M92!E;&5M96YT<R`M(&AO=7(L(&UI;G5T92!A;F0@<V5C;VYD<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T5&EM95!A<G1S*"1T:6UE7VEN*0H@("`@>PH@
M("`@("`@(&EF("AI<U]A<G)A>2@D=&EM95]I;BDI('L*("`@("`@("`@("`@
M+RH@5&AI<R!I<R!P<F]B86)L>2!A(&9A:6QE9"!I<U9A;&ED(&EN<'5T('-O
M(&IU<W0@<F5T=7)N('1H90H@("`@("`@("`@("`@*B!P87)T<R!A<R!T:&5Y
M(&%R92X@*B\*("`@("`@("`@("`@<F5T=7)N("1T:6UE7VEN.PH@("`@("`@
M('T@96QS96EF("AE;7!T>2@D=&EM95]I;BDI('L*("`@("`@("`@("`@+RH@
M5&AI<R!I<R!J=7-T(&%N(&5M<'1Y(&9I96QD('-O(')E='5R;B!E;7!T>2!P
M87)T<RX@*B\*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"=H;W5R)R`]/B`G
M)RP@)VUI;G5T92<@/3X@)R<L("=S96-O;F0G(#T^("<G*3L*("`@("`@("!]
M"B`@("`@("`@)'1I;64@/2`D=&AI<RT^9V5T5&EM94]B*"1T:6UE7VEN*3L*
M("`@("`@("!R971U<FX@87)R87DH)VAO=7(G(#T^("1T:6UE+3YH;W5R+`H@
M("`@("`@("`@("`@("`@("`@("`G;6EN=71E)R`]/B`D=&EM92T^;6EN+`H@
M("`@("`@("`@("`@("`@("`@("`G<V5C;VYD)R`]/B`D=&EM92T^<V5C*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!E;7!T>51I;65!<G)A>2@D=&EM92D*("`@
M('L*("`@("`@("!R971U<FX@*&ES7V%R<F%Y*"1T:6UE*2`F)B!E;7!T>2@D
M=&EM95LG:&]U<B==*2`F)B!E;7!T>2@D=&EM95LG;6EN=71E)UTI("8F(&5M
M<'1Y*"1T:6UE6R=S96-O;F0G72DI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@G;F%M
M92<@/3X@7R@B5&EM92!S96QE8W1I;VXB*2D["B`@("!]"@I]"@IC;&%S<R!(
M;W)D95]&;W)M7U1Y<&5?;6]N=&A996%R(&5X=&5N9',@2&]R9&5?1F]R;5]4
M>7!E('L*"B`@("!V87(@)%]S=&%R=%]Y96%R.PH@("`@=F%R("1?96YD7WEE
M87(["@H@("`@9G5N8W1I;VX@:6YI="@D<W1A<G1?>65A<B`](&YU;&PL("1E
M;F1?>65A<B`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1S=&%R
M=%]Y96%R*2D@>PH@("`@("`@("`@("`D<W1A<G1?>65A<B`](#$Y,C`["B`@
M("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D96YD7WEE87(I*2!["B`@("`@
M("`@("`@("1E;F1?>65A<B`](&1A=&4H)UDG*3L*("`@("`@("!]"@H@("`@
M("`@("1T:&ES+3Y?<W1A<G1?>65A<B`]("1S=&%R=%]Y96%R.PH@("`@("`@
M("1T:&ES+3Y?96YD7WEE87(@/2`D96YD7WEE87(["B`@("!]"@H@("`@9G5N
M8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G
M92D*("`@('L*("`@("`@("!I9B`H(21V87(M/FES4F5Q=6ER960H*2D@>PH@
M("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@(&EF
M("@A)'9A<G,M/F=E="@D=&AI<RT^9V5T36]N=&A687(H)'9A<BDI('Q\"B`@
M("`@("`@("`@("$D=F%R<RT^9V5T*"1T:&ES+3YG971996%R5F%R*"1V87(I
M*2D@>PH@("`@("`@("`@("`D;65S<V%G92`](%\H(E!L96%S92!E;G1E<B!A
M(&UO;G1H(&%N9"!A('EE87(N(BD["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&=E=$UO;G1H5F%R*"1V87(I"B`@("!["B`@("`@("`@<F5T
M=7)N("1V87(M/F=E=%9A<DYA;64H*2`N("=;;6]N=&A=)SL*("`@('T*"B`@
M("!F=6YC=&EO;B!G971996%R5F%R*"1V87(I"B`@("!["B`@("`@("`@<F5T
M=7)N("1V87(M/F=E=%9A<DYA;64H*2`N("=;>65A<ETG.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@(')E='5R
M;B!A<G)A>2@G;F%M92<@/3X@7R@B36]N=&@@86YD('EE87(B*2P*("`@("`@
M("`@("`@("`@("`@("`@)W!A<F%M<R<@/3X@87)R87DH"B`@("`@("`@("`@
M("`@("`@("`@("`@("`G<W1A<G1?>65A<B<@/3X@87)R87DH)VQA8F5L)R`]
M/B!?*")3=&%R="!Y96%R(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G<W1R:6YG;&ES="<I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@)V5N9%]Y96%R)R`@(#T^(&%R
M<F%Y*"=L86)E;"<@/3X@7R@B16YD('EE87(B*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=S
M=')I;F=L:7-T)RDI*3L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP
M95]M;VYT:$1A>5EE87(@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@
M('9A<B`D7W-T87)T7WEE87(["B`@("!V87(@)%]E;F1?>65A<CL*("`@('9A
M<B`D7W!I8VME<CL*("`@('9A<B`D7V9O<FUA=%]I;B`](&YU;&P["B`@("!V
M87(@)%]F;W)M871?;W5T(#T@)R5X)SL*"B`@("`O*BH*("`@("`J(%)E='5R
M;B!T:&4@9&%T92!S=7!P;&EE9"!A<R!A($AO<F1E7T1A=&4@;V)J96-T+@H@
M("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1S=&%R=%]Y96%R("!4:&4@
M9FER<W0@879A:6QA8FQE('EE87(@9F]R(&EN<'5T+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)&5N9%]Y96%R("`@(%1H92!L87-T(&%V86EL86)L92!Y96%R
M(&9O<B!I;G!U="X*("`@("`J($!P87)A;2!B;V]L96%N("1P:6-K97(@("`@
M("!$;R!W92!S:&]W('1H92!$2%1-3"!C86QE;F1A<C\*("`@("`J($!P87)A
M;2!I;G1E9V5R("1F;W)M871?:6X@("!4:&4@9F]R;6%T('1O('5S92!W:&5N
M('-E;F1I;F<@=&AE(&1A=&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!F;W(@<W1O<F%G92X@1&5F875L=',@=&\@56YI>"!E<&]C:"X*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!3:6UI;&%R('1O
M('1H92!S=')F=&EM92@I(&9U;F-T:6]N+@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)&9O<FUA=%]O=70@(%1H92!F;W)M870@=&\@=7-E('=H96X@9&ES<&QA
M>6EN9R!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!D
M871E+B!3:6UI;&%R('1O('1H92!S=')F=&EM92@I(&9U;F-T:6]N+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!I;FET*"1S=&%R=%]Y96%R(#T@)R<L("1E;F1?
M>65A<B`]("<G+"`D<&EC:V5R(#T@=')U92P*("`@("`@("`@("`@("`@("`@
M)&9O<FUA=%]I;B`](&YU;&PL("1F;W)M871?;W5T(#T@)R5X)RD*("`@('L*
M("`@("`@("!I9B`H96UP='DH)'-T87)T7WEE87(I*2!["B`@("`@("`@("`@
M("1S=&%R=%]Y96%R(#T@9&%T92@G62<I.PH@("`@("`@('T*("`@("`@("!I
M9B`H96UP='DH)&5N9%]Y96%R*2D@>PH@("`@("`@("`@("`D96YD7WEE87(@
M/2!D871E*"=9)RD@*R`Q,#L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?
M<W1A<G1?>65A<B`]("1S=&%R=%]Y96%R.PH@("`@("`@("1T:&ES+3Y?96YD
M7WEE87(@/2`D96YD7WEE87(["B`@("`@("`@)'1H:7,M/E]P:6-K97(@/2`D
M<&EC:V5R.PH@("`@("`@("1T:&ES+3Y?9F]R;6%T7VEN(#T@)&9O<FUA=%]I
M;CL*("`@("`@("`D=&AI<RT^7V9O<FUA=%]O=70@/2`D9F]R;6%T7V]U=#L*
M("`@('T*"B`@("!F=6YC=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V
M86QU92P@)B1M97-S86=E*0H@("`@>PH@("`@("`@("1D871E(#T@)'9A<G,M
M/F=E="@D=F%R+3YG971687).86UE*"DI.PH@("`@("`@("1E;7!T>2`]("1T
M:&ES+3YE;7!T>41A=&5!<G)A>2@D9&%T92D["@H@("`@("`@(&EF("@D96UP
M='D@/3T@,2`F)B`D=F%R+3YI<U)E<75I<F5D*"DI('L*("`@("`@("`@("`@
M)&UE<W-A9V4@/2!?*")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(I.PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?2!E;'-E:68@*"1E;7!T
M>2`]/2`P("8F("%C:&5C:V1A=&4H)&1A=&5;)VUO;G1H)UTL("1D871E6R=D
M87DG72P@)&1A=&5;)WEE87(G72DI('L*("`@("`@("`@("`@)&UE<W-A9V4@
M/2!?*")0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M
M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+B(I.PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?2!E;'-E:68@*"1E;7!T>2`]/2`M,2D@>PH@
M("`@("`@("`@("`D;65S<V%G92`](%\H(E-E;&5C="!A;&P@9&%T92!C;VUP
M;VYE;G1S+B(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!E
M;7!T>41A=&5!<G)A>2@D9&%T92D*("`@('L*("`@("`@("!I9B`H(6ES7V%R
M<F%Y*"1D871E*2D@>PH@("`@("`@("`@("!R971U<FX@96UP='DH)&1A=&4I
M.PH@("`@("`@('T*"B`@("`@("`@)&5M<'1Y(#T@,#L*("`@("`@("`O*B!#
M:&5C:R!E86-H(&1A=&4@87)R87D@8V]M<&]N96YT+B`J+PH@("`@("`@(&9O
M<F5A8V@@*"1D871E(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("!I
M9B`H96UP='DH)'9A;"DI('L*("`@("`@("`@("`@("`@("1E;7!T>2LK.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!#:&5C:R!S=&%T
M92!O9B!E;7!T>2X@*B\*("`@("`@("!I9B`H)&5M<'1Y(#T](#`I('L*("`@
M("`@("`@("`@+RH@268@;F\@96UP='D@<&%R=',@<F5T=7)N(#`N("HO"B`@
M("`@("`@("`@(')E='5R;B`P.PH@("`@("`@('T@96QS96EF("@D96UP='D@
M/3T@,RD@>PH@("`@("`@("`@("`O*B!)9B!A;&P@96UP='D@<&%R=',@<F5T
M=7)N(#$N("HO"B`@("`@("`@("`@(')E='5R;B`Q.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("\J($EF('-O;64@96UP='D@<&%R=',@<F5T=7)N
M("TQ+B`J+PH@("`@("`@("`@("!R971U<FX@+3$["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!D871E('-U<'!L:65D('-P
M;&ET('5P(&EN=&\@86X@87)R87DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9&%T95]I;B`@1&%T92!I;B!O;F4@;V8@=&AE('1H<F5E(&9O<FUA
M=',@<W5P<&]R=&5D(&)Y"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("!(;W)D95]&;W)M(&%N9"!(;W)D95]$871E("A)4T\@9F]R;6%T"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("!965E9+4U-+41$($A(.DU-.E-3
M+"!T:6UE<W1A;7`@65E964U-1$1(2$U-4U,*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@(&%N9"!53DE8(&5P;V-H*2!P;'5S('1H92!F;W5R=&@@
M65E962U-32U$1"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A
M>2!W:71H('1H<F5E(&5L96UE;G1S("T@>65A<BP@;6]N=&@@86YD(&1A>2X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&%T95!A<G1S*"1D871E7VEN*0H@
M("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D9&%T95]I;BDI('L*("`@("`@
M("`@("`@+RH@5&AI<R!I<R!P<F]B86)L>2!A(&9A:6QE9"!I<U9A;&ED(&EN
M<'5T('-O(&IU<W0@<F5T=7)N"B`@("`@("`@("`@("`J('1H92!P87)T<R!A
M<R!T:&5Y(&%R92X@*B\*("`@("`@("`@("`@<F5T=7)N("1D871E7VEN.PH@
M("`@("`@('T@96QS96EF("AE;7!T>2@D9&%T95]I;BDI('L*("`@("`@("`@
M("`@+RH@5&AI<R!I<R!J=7-T(&%N(&5M<'1Y(&9I96QD('-O(')E='5R;B!E
M;7!T>2!P87)T<RX@*B\*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"=Y96%R
M)R`]/B`G)RP@)VUO;G1H)R`]/B`G)RP@)V1A>2<@/3X@)R<I.PH@("`@("`@
M('T*"B`@("`@("`@)&1A=&4@/2`D=&AI<RT^9V5T1&%T94]B*"1D871E7VEN
M*3L*("`@("`@("!R971U<FX@87)R87DH)WEE87(G(#T^("1D871E+3YY96%R
M+`H@("`@("`@("`@("`@("`@("`@("`G;6]N=&@G(#T^("1D871E+3YM;VYT
M:"P*("`@("`@("`@("`@("`@("`@("`@)V1A>2<@/3X@)&1A=&4M/FUD87DI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!D871E('-U<'!L
M:65D(&%S(&$@2&]R9&5?1&%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D9&%T95]I;B`@1&%T92!I;B!O;F4@;V8@=&AE('1H<F5E
M(&9O<FUA=',@<W5P<&]R=&5D(&)Y"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("!(;W)D95]&;W)M(&%N9"!(;W)D95]$871E("A)4T\@9F]R;6%T
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!965E9+4U-+41$($A(
M.DU-.E-3+"!T:6UE<W1A;7`@65E964U-1$1(2$U-4U,*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@(&%N9"!53DE8(&5P;V-H*2!P;'5S('1H92!F
M;W5R=&@@65E962U-32U$1"X*("`@("`J"B`@("`@*B!`<F5T=7)N($1A=&4@
M(%1H92!D871E(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&%T
M94]B*"1D871E7VEN*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R
M9&4O1&%T92YP:'`G.PH*("`@("`@("!I9B`H:7-?87)R87DH)&1A=&5?:6XI
M*2!["B`@("`@("`@("`@("\J($EF('!A<W-E9"!A;B!A<G)A>2!C:&%N9V4@
M:70@=&\@=&AE($E33R!F;W)M870N("HO"B`@("`@("`@("`@(&EF("@D=&AI
M<RT^96UP='E$871E07)R87DH)&1A=&5?:6XI(#T](#`I('L*("`@("`@("`@
M("`@("`@("1D871E7VEN(#T@<W!R:6YT9B@G)3`T9"TE,#)D+24P,F0@,#`Z
M,#`Z,#`G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D
M871E7VEN6R=Y96%R)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&1A=&5?:6Y;)VUO;G1H)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&1A=&5?:6Y;)V1A>2==*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H*"<O7EQD>S1]+5QD>S)]
M+5QD>S)])"\G+"`D9&%T95]I;BDI('L*("`@("`@("`@("`@+RH@1FEX('1H
M92!D871E(&EF(&ET(&ES('1H92!S:&]R=&5N960@25-/+B`J+PH@("`@("`@
M("`@("`D9&%T95]I;B`]("1D871E7VEN("X@)R`P,#HP,#HP,"<["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@;F5W($AO<F1E7T1A=&4H)&1A=&5?:6XI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!D871E('-U<'!L
M:65D(&%S(&$@2&]R9&5?1&%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D9&%T92`@16ET:&5R(&%N(&%L<F5A9'D@<V5T('5P($AO
M<F1E7T1A=&4@;V)J96-T(&]R(&$*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@('-T<FEN9R!D871E(&EN(&]N92!O9B!T:&4@=&AR964@9F]R;6%T<R!S
M=7!P;W)T960*("`@("`J("`@("`@("`@("`@("`@("`@("`@(&)Y($AO<F1E
M7T9O<FT@86YD($AO<F1E7T1A=&4@*$E33R!F;W)M870*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@(%E965DM34TM1$0@2$@Z34TZ4U,L('1I;65S=&%M
M<"!965E934U$1$A(34U34R!A;F0*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@(%5.25@@97!O8V@I('!L=7,@=&AE(&9O=7)T:"!965E9+4U-+41$+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9&%T92!F;W)M871T
M960@86-C;W)D:6YG('1O('1H92`D9F]R;6%T7V]U=`H@("`@("H@("`@("`@
M("`@("`@("`@('!A<F%M971E<B!W:&5N('-E='1I;F<@=7`@=&AE(&UO;G1H
M9&%Y>65A<B!F:65L9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9F]R;6%T1&%T
M92@D9&%T92D*("`@('L*("`@("`@("!I9B`H(6ES7V$H)&1A=&4L("=$871E
M)RDI('L*("`@("`@("`@("`@)&1A=&4@/2`D=&AI<RT^9V5T1&%T94]B*"1D
M871E*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D9&%T92T^<W1R9G1I
M;64H)'1H:7,M/E]F;W)M871?;W5T*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($EN<V5R="!T:&4@9&%T92!I;G!U="!T:')O=6=H('1H92!F;W)M(&EN=&\@
M)&EN9F\@87)R87DL(&EN('1H92!F;W)M870*("`@("`J('-P96-I9FEE9"!B
M>2!T:&4@)&9O<FUA=%]I;B!P87)A;65T97(@=VAE;B!S971T:6YG('5P(&UO
M;G1H9&%Y>65A<@H@("`@("H@9FEE;&0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$EN9F\H)B1V87)S+"`F)'9A<BP@)B1I;F9O*0H@("`@>PH@("`@("`@
M("1I;F9O(#T@)'1H:7,M/E]V86QI9&%T94%N9$9O<FUA="@D=F%R+3YG9716
M86QU92@D=F%R<RDL("1V87(I.PH@("`@?0H*("`@("\J*@H@("`@("H@5F%L
M:61A=&4O9F]R;6%T(&$@9&%T92!S=6)M:7-S:6]N+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?=F%L:61A=&5!;F1&;W)M870H)'9A;'5E+"`F)'9A<BD*("`@
M('L*("`@("`@("`O*B!)9B!A;GD@8V]M<&]N96YT(&ES(&5M<'1Y(&-O;G-I
M9&5R(&ET(&$@8F%D(&1A=&4@86YD(')E='5R;B!T:&4*("`@("`@("`@*B!D
M969A=6QT+B`J+PH@("`@("`@(&EF("@D=&AI<RT^96UP='E$871E07)R87DH
M)'9A;'5E*2`]/2`Q*2!["B`@("`@("`@("`@(')E='5R;B`D=F%R+3YG971$
M969A=6QT*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&1A=&4@
M/2`D=&AI<RT^9V5T1&%T94]B*"1V86QU92D["B`@("`@("`@("`@(&EF("@D
M=&AI<RT^7V9O<FUA=%]I;B`]/3T@;G5L;"D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1D871E+3YT:6UE<W1A;7`H*3L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D9&%T92T^<W1R9G1I;64H)'1H
M:7,M/E]F;W)M871?:6XI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@
M(')E='5R;B!A<G)A>2@G;F%M92<@/3X@7R@B1&%T92!S96QE8W1I;VXB*2P*
M("`@("`@("`@("`@("`@("`@("`@)W!A<F%M<R<@/3X@87)R87DH"B`@("`@
M("`@("`@("`@("`@("`@("`@("`G<W1A<G1?>65A<B<@/3X@87)R87DH)VQA
M8F5L)R`]/B!?*")3=&%R="!Y96%R(BDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G:6YT)RDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`G96YD7WEE87(G("`@/3X@87)R
M87DH)VQA8F5L)R`]/B!?*")%;F0@>65A<B(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@)VEN
M="<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@)W!I8VME<B<@("`@(#T^
M(&%R<F%Y*"=L86)E;"<@/3X@7R@B4VAO=R!P:6-K97(B*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@
M(#T^("=B;V]L96%N)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`G9F]R
M;6%T7VEN)R`@/3X@87)R87DH)VQA8F5L)R`]/B!?*")3=&]R86=E(&9O<FUA
M="(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=T>7!E)R`@/3X@)W1E>'0G*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("=F;W)M871?;W5T)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(D1I
M<W!L87D@9F]R;6%T(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G=&5X="<I*2D["B`@("!]
M"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?8V]L;W)0:6-K97(@97AT96YD
M<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V
M87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@
M:68@*"1V87(M/FES4F5Q=6ER960H*2`F)B!E;7!T>2@D=F%L=64I*2!["B`@
M("`@("`@("`@("1M97-S86=E(#T@7R@B5&AI<R!F:65L9"!I<R!R97%U:7)E
M9"XB*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@:68@*&5M<'1Y*"1V86QU92D@?'P@<')E9U]M871C:"@G+UXC*%LP
M+3EA+7I=*7LV?20O:2<L("1V86QU92DI('L*("`@("`@("`@("`@<F5T=7)N
M('1R=64["B`@("`@("`@?0H*("`@("`@("`D;65S<V%G92`](%\H(E1H:7,@
M9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE
M>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RXB*3L*("`@("`@("!R
M971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF
M;R!A8F]U="!F:65L9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U
M="@I"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R87DH*3L*("`@("`@("`D
M86)O=71;)VYA;64G72`](%\H(D-O;&]U<B!S96QE8W1I;VXB*3L*("`@("`@
M("!R971U<FX@)&%B;W5T.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R;5]4
M>7!E7W-O<G1E<B!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@=F%R
M("1?:6YS=&%N8V4["B`@("!V87(@)%]V86QU97,["B`@("!V87(@)%]S:7IE
M.PH@("`@=F%R("1?:&5A9&5R.PH*("`@(&9U;F-T:6]N(&EN:70H)'9A;'5E
M<RP@)'-I>F4@/2`X+"`D:&5A9&5R(#T@)R<I"B`@("!["B`@("`@("`@<W1A
M=&EC("1H;W)D95]S;W)T97)?:6YS=&%N8V4@/2`P.PH*("`@("`@("`O*B!'
M970@=&AE(&YE>'0@<')O9W)E<W-I=F4@:6YS=&%N8V4@8V]U;G0@9F]R('1H
M92!H;W)D90H@("`@("`@("`J('-O<G1E<B!S;R!T:&%T(&UU;'1I<&QE('-O
M<G1E<G,@8V%N(&)E('5S960@;VX@;VYE('!A9V4N("HO"B`@("`@("`@)&AO
M<F1E7W-O<G1E<E]I;G-T86YC92LK.PH@("`@("`@("1T:&ES+3Y?:6YS=&%N
M8V4@/2`G:&]R9&5?<V]R=&5R7R<@+B`D:&]R9&5?<V]R=&5R7VEN<W1A;F-E
M.PH@("`@("`@("1T:&ES+3Y?=F%L=65S(#T@)'9A;'5E<SL*("`@("`@("`D
M=&AI<RT^7W-I>F4@("`]("1S:7IE.PH@("`@("`@("1T:&ES+3Y?:&5A9&5R
M(#T@)&AE861E<CL*("`@('T*"B`@("!F=6YC=&EO;B!I<U9A;&ED*"8D=F%R
M+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E*0H@("`@>PH@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%9A;'5E<R@I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=F%L=65S.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&=E=%-I>F4H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^7W-I>F4["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T2&5A9&5R*"D*("`@
M('L*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?:&5A9&5R*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]H96%D97(["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`G)SL*("`@('T*"B`@("!F=6YC=&EO;B!G971/<'1I;VYS
M*"1K97ES(#T@;G5L;"D*("`@('L*("`@("`@("`D:'1M;"`]("<G.PH@("`@
M("`@(&EF("@D=&AI<RT^7VAE861E<BD@>PH@("`@("`@("`@("`D:'1M;"`N
M/2`G/&]P=&EO;B!V86QU93TB(CXG("X@:'1M;'-P96-I86QC:&%R<R@D=&AI
M<RT^7VAE861E<BD@+B`G/"]O<'1I;VX^)SL*("`@("`@("!]"@H@("`@("`@
M(&EF("AE;7!T>2@D:V5Y<RDI('L*("`@("`@("`@("`@)&ME>7,@/2!A<G)A
M>5]K97ES*"1T:&ES+3Y?=F%L=65S*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D:V5Y<R`](&5X<&QO9&4H(EQT(BP@)&ME>7-;)V%R<F%Y)UTI
M.PH@("`@("`@('T*("`@("`@("!F;W)E86-H("@D:V5Y<R!A<R`D<VQ?:V5Y
M*2!["B`@("`@("`@("`@("1H=&UL("X]("<\;W!T:6]N('9A;'5E/2(G("X@
M)'-L7VME>2`N("<B/B<@+B!H=&UL<W!E8VEA;&-H87)S*"1T:&ES+3Y?=F%L
M=65S6R1S;%]K97E=*2`N("<\+V]P=&EO;CXG.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1H=&UL.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$EN9F\H
M)B1V87)S+"`F)'9A<BP@)B1I;F9O*0H@("`@>PH@("`@("`@("1V86QU92`]
M("1V87)S+3YG970H)'9A<BT^9V5T5F%R3F%M92@I*3L*("`@("`@("`D:6YF
M;R`](&5X<&QO9&4H(EQT(BP@)'9A;'5E6R=A<G)A>2==*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O
M=70@/2!A<G)A>2@I.PH@("`@("`@("1A8F]U=%LG;F%M92==(#T@7R@B4V]R
M="!O<F1E<B!S96QE8W1I;VXB*3L*("`@("`@("`D86)O=71;)W!A<F%M<R==
M(#T@87)R87DH"B`@("`@("`@("`@("=V86QU97,G(#T^(&%R<F%Y*"=L86)E
M;"<@/3X@7R@B5F%L=65S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=T>7!E)R`@/3X@)W-T<FEN9VQI<W0G*2P*("`@("`@("`@("`@)W-I
M>F4G("`@/3X@87)R87DH)VQA8F5L)R`]/B!?*")3:7IE(BDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@)VEN="<I+`H@("`@
M("`@("`@("`G:&5A9&5R)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(DAE861E
M<B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^
M("=T97AT)RDI.PH@("`@("`@(')E='5R;B`D86)O=70["B`@("!]"@I]"@IC
M;&%S<R!(;W)D95]&;W)M7U1Y<&5?<V5L96-T1FEL97,@97AT96YD<R!(;W)D
M95]&;W)M7U1Y<&4@>PH*("`@("\J*@H@("`@("H@5&AE('1E>'0@=&\@=7-E
M(&EN('1H92!L:6YK+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B\*("`@('9A<B`D7VQI;FM?=&5X=#L*"B`@("`O*BH*("`@("`J(%1H92!S
M='EL92!T;R!U<V4@9F]R('1H92!L:6YK+@H@("`@("H*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VQI;FM?<W1Y;&4["@H@("`@+RHJ
M"B`@("`@*B`@0W)E871E('1H92!L:6YK('=I=&@@86X@:6-O;B!I;G-T96%D
M(&]F('1E>'0_"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*
M("`@('9A<B`D7VEC;VX["@H@("`@+RHJ"B`@("`@*B!#;VYT86EN<R!G;VQL
M96T@<V5L96-T9FEL92!S96QE8W1I;VY)1`H@("`@("H*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W-E;&5C=&ED.PH*("`@(&9U;F-T
M:6]N(&EN:70H)&QI;FM?=&5X="`](&YU;&PL("1L:6YK7W-T>6QE(#T@)R<L
M("1I8V]N(#T@9F%L<V4L"B`@("`@("`@("`@("`@("`@("1S96QE8W1I9"`]
M("<G*0H@("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1L:6YK7W1E>'0I*2![
M"B`@("`@("`@("`@("1L:6YK7W1E>'0@/2!?*")396QE8W0@1FEL97,B*3L*
M("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]L:6YK7W1E>'0@/2`D;&EN:U]T
M97AT.PH@("`@("`@("1T:&ES+3Y?;&EN:U]S='EL92`]("1L:6YK7W-T>6QE
M.PH@("`@("`@("1T:&ES+3Y?:6-O;B`]("1I8V]N.PH@("`@("`@("1T:&ES
M+3Y?<V5L96-T:60@/2`D<V5L96-T:60["B`@("!]"@H@("`@9G5N8W1I;VX@
M:7-686QI9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@
M('L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!G
M971);F9O*"8D=F%R<RP@)B1V87(L("8D:6YF;RD*("`@('L*("`@("`@("`D
M=F%L=64@/2`D=F%R+3YG971686QU92@D=F%R<RD["B`@("`@("`@)&EN9F\@
M/2`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^8V%L;"@G9FEL97,O<V5L96-T;&ES
M=%)E<W5L=',G+"!A<G)A>2@D=F%L=64I("D["B`@("!]"@H@("`@9G5N8W1I
M;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y*"D["B`@
M("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*")&:6QE('-E;&5C=&EO;B(I.PH@
M("`@("`@(')E='5R;B`D86)O=70["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&
M;W)M7U1Y<&5?87-S:6=N(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@
M("!V87(@)%]L969T5F%L=65S.PH@("`@=F%R("1?<FEG:'1686QU97,["B`@
M("!V87(@)%]L969T2&5A9&5R.PH@("`@=F%R("1?<FEG:'1(96%D97(["B`@
M("!V87(@)%]S:7IE.PH@("`@=F%R("1?=VED=&@["@H@("`@9G5N8W1I;VX@
M:6YI="@D;&5F=%9A;'5E<RP@)')I9VAT5F%L=65S+"`D;&5F=$AE861E<B`]
M("<G+`H@("`@("`@("`@("`@("`@("`D<FEG:'1(96%D97(@/2`G)RP@)'-I
M>F4@/2`X+"`D=VED=&@@/2`G,C`P<'@G*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?;&5F=%9A;'5E<R`]("1L969T5F%L=65S.PH@("`@("`@("1T:&ES+3Y?
M<FEG:'1686QU97,@/2`D<FEG:'1686QU97,["B`@("`@("`@)'1H:7,M/E]L
M969T2&5A9&5R(#T@)&QE9G1(96%D97(["B`@("`@("`@)'1H:7,M/E]R:6=H
M=$AE861E<B`]("1R:6=H=$AE861E<CL*("`@("`@("`D=&AI<RT^7W-I>F4@
M/2`D<VEZ93L*("`@("`@("`D=&AI<RT^7W=I9'1H(#T@)'=I9'1H.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L("8D=F%R<RP@)'9A;'5E
M+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"@H@("`@9G5N8W1I;VX@9V5T5F%L=65S*"1S:61E*0H@("`@>PH@("`@("`@
M(')E='5R;B`D<VED92`_("1T:&ES+3Y?<FEG:'1686QU97,@.B`D=&AI<RT^
M7VQE9G1686QU97,["B`@("!]"@H@("`@9G5N8W1I;VX@<V5T5F%L=65S*"1S
M:61E+"`D=F%L=65S*0H@("`@>PH@("`@("`@(&EF("@D<VED92D@>PH@("`@
M("`@("`@("`D=&AI<RT^7W)I9VAT5F%L=65S(#T@)'9A;'5E<SL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7VQE9G1686QU97,@/2`D
M=F%L=65S.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!G971(96%D
M97(H)'-I9&4I"B`@("!["B`@("`@("`@<F5T=7)N("1S:61E(#\@)'1H:7,M
M/E]R:6=H=$AE861E<B`Z("1T:&ES+3Y?;&5F=$AE861E<CL*("`@('T*"B`@
M("!F=6YC=&EO;B!G9713:7IE*"D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]S:7IE.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%=I9'1H*"D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/E]W:61T:#L*("`@('T*"B`@("!F
M=6YC=&EO;B!G971/<'1I;VYS*"1S:61E+"`D9F]R;6YA;64I"B`@("!["B`@
M("`@("`@)&AT;6P@/2`G)SL*("`@("`@("`D:&5A9&5R(#T@9F%L<V4["B`@
M("`@("`@:68@*"1S:61E*2!["B`@("`@("`@("`@("1V86QU97,@/2`D=&AI
M<RT^7W)I9VAT5F%L=65S.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES
M+3Y?<FEG:'1(96%D97(I*2!["B`@("`@("`@("`@("`@("`D=F%L=65S(#T@
M87)R87DH)R<@/3X@)'1H:7,M/E]R:6=H=$AE861E<BD@*R`D=F%L=65S.PH@
M("`@("`@("`@("`@("`@)&AE861E<G,@/2!T<G5E.PH@("`@("`@("`@("!]
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'9A;'5E<R`]("1T:&ES
M+3Y?;&5F=%9A;'5E<SL*("`@("`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^
M7VQE9G1(96%D97(I*2!["B`@("`@("`@("`@("`@("`D=F%L=65S(#T@87)R
M87DH)R<@/3X@)'1H:7,M/E]L969T2&5A9&5R*2`K("1V86QU97,["B`@("`@
M("`@("`@("`@("`D:&5A9&5R<R`]('1R=64["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("`@("`@9F]R96%C:"`H)'9A;'5E<R!A<R`D:V5Y(#T^("1V
M86PI('L*("`@("`@("`@("`@)&AT;6P@+CT@)SQO<'1I;VX@=F%L=64](B<@
M+B`D:V5Y("X@)R(G.PH@("`@("`@("`@("!I9B`H)&AE861E<G,I('L*("`@
M("`@("`@("`@("`@("1H96%D97)S(#T@9F%L<V4["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D:'1M;"`N/2`G(&]N9&)L8VQI8VL]
M(DAO<F1E7T9O<FU?07-S:6=N+FUO=F4H7"<G("X@)&9O<FUN86UE("X*("`@
M("`@("`@("`@("=<)RP@)R`N("AI;G0I)'-I9&4@+B`G*3LB)SL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D:'1M;"`N/2`G/B<@+B`D=F%L("X@)SPO
M;W!T:6]N/B<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&AT;6P["B`@
M("!]"@H@("`@9G5N8W1I;VX@9V5T26YF;R@F)'9A<G,L("8D=F%R+"`F)&EN
M9F\I"B`@("!["B`@("`@("`@)'9A;'5E(#T@)'9A<G,M/F=E="@D=F%R+3YG
M971687).86UE*"D@+B`G7U]V86QU97,G*3L*("`@("`@("!I9B`H<W1R<&]S
M*"1V86QU92P@(EQT7'0B*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@)&QE
M9G0@/2`D=F%L=64["B`@("`@("`@("`@("1R:6=H="`]("<G.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(&QI<W0H)&QE9G0L("1R:6=H="D@/2!E
M>'!L;V1E*")<=%QT(BP@)'9A;'5E*3L*("`@("`@("!]"B`@("`@("`@:68@
M*&5M<'1Y*"1L969T*2D@>PH@("`@("`@("`@("`D:6YF;ULG;&5F="==(#T@
M87)R87DH*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D:6YF;ULG
M;&5F="==(#T@97AP;&]D92@B7'0B+"`D;&5F="D["B`@("`@("`@?0H@("`@
M("`@(&EF("AE;7!T>2@D<FEG:'0I*2!["B`@("`@("`@("`@("1I;F9O6R=R
M:6=H="==(#T@87)R87DH*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D:6YF;ULG<FEG:'0G72`](&5X<&QO9&4H(EQT(BP@)')I9VAT*3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U
M="!F:65L9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@
M("!["B`@("`@("`@)&%B;W5T(#T@87)R87DH*3L*("`@("`@("`D86)O=71;
M)VYA;64G72`](%\H(D%S<VEG;FUE;G0@8V]L=6UN<R(I.PH@("`@("`@("1A
M8F]U=%LG<&%R86US)UT@/2!A<G)A>2@*("`@("`@("`@("`@)VQE9G1686QU
M97,G(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B3&5F="!V86QU97,B*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@)W-T
M<FEN9VQI<W0G*2P*("`@("`@("`@("`@)W)I9VAT5F%L=65S)R`]/B!A<G)A
M>2@G;&%B96PG(#T^(%\H(E)I9VAT('9A;'5E<R(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@)W-T<FEN9VQI<W0G
M*2P*("`@("`@("`@("`@)VQE9G1(96%D97(G(#T^(&%R<F%Y*"=L86)E;"<@
M/3X@7R@B3&5F="!H96%D97(B*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W1Y<&4G("`]/B`G=&5X="<I+`H@("`@("`@("`@("`G<FEG:'1(
M96%D97(G(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B4FEG:'0@:&5A9&5R(BDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]
M/B`G=&5X="<I+`H@("`@("`@("`@("`G<VEZ92<@("`]/B!A<G)A>2@G;&%B
M96PG(#T^(%\H(E-I>F4B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W1Y<&4G("`]/B`G:6YT)RDL"B`@("`@("`@("`@("=W:61T:"<@("`]
M/B!A<G)A>2@G;&%B96PG(#T^(%\H(E=I9'1H(&EN($-34R!U;FET<R(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G=&5X
M="<I*3L*("`@("`@("!R971U<FX@)&%B;W5T.PH@("`@?0H*?0H*8VQA<W,@
M2&]R9&5?1F]R;5]4>7!E7V-R961I=&-A<F0@97AT96YD<R!(;W)D95]&;W)M
M7U1Y<&4@>PH*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L("8D=F%R<RP@
M)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1V
M86QU92D@)B8@)'9A<BT^:7-297%U:7)E9"@I*2!["B`@("`@("`@("`@("1M
M97-S86=E(#T@7R@B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB*3L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E
M;7!T>2@D=F%L=64I*2!["B`@("`@("`@("`@("\J(&=E=$-A<F14>7!E*"D@
M=VEL;"!A;'-O('9E<FEF>2!T:&4@8VAE8VMS=6TN("HO"B`@("`@("`@("`@
M("1T>7!E(#T@)'1H:7,M/F=E=$-A<F14>7!E*"1V86QU92D["B`@("`@("`@
M("`@(&EF("@D='EP92`]/3T@9F%L<V4@?'P@)'1Y<&4@/3T@)W5N:VYO=VXG
M*2!["B`@("`@("`@("`@("`@("`D;65S<V%G92`](%\H(E1H:7,@9&]E<R!N
M;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(I.PH@("`@("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!G
M971#:&5C:W-U;2@D8V-N=6TI"B`@("!["B`@("`@("`@)&QE;B`]('-T<FQE
M;B@D8V-N=6TI.PH@("`@("`@(&EF("@A:7-?;&]N9R@D;&5N("\@,BDI('L*
M("`@("`@("`@("`@)'=E:6=H="`](#(["B`@("`@("`@("`@("1D:6=I="`]
M("1C8VYU;5LP73L*("`@("`@("!](&5L<V5I9B`H:7-?;&]N9R@D;&5N("\@
M,BDI('L*("`@("`@("`@("`@)'=E:6=H="`](#$["B`@("`@("`@("`@("1D
M:6=I="`]("1C8VYU;5LP72`J(#(["B`@("`@("`@?0H@("`@("`@(&EF("@D
M9&EG:70@/B`Y*2!["B`@("`@("`@("`@("1D:6=I="`]("1D:6=I="`M(#D[
M"B`@("`@("`@?0H@("`@("`@("1I(#T@,3L*("`@("`@("`D8VAE8VMS=6T@
M/2`D9&EG:70["B`@("`@("`@=VAI;&4@*"1I(#P@)&QE;BD@>PH@("`@("`@
M("`@("!I9B`H)&-C;G5M6R1I72`A/2`G("<I('L*("`@("`@("`@("`@("`@
M("1D:6=I="`]("1C8VYU;5LD:5T@*B`D=V5I9VAT.PH@("`@("`@("`@("`@
M("`@)'=E:6=H="`]("@D=V5I9VAT(#T](#$I(#\@,B`Z(#$["B`@("`@("`@
M("`@("`@("!I9B`H)&1I9VET(#X@.2D@>PH@("`@("`@("`@("`@("`@("`@
M("1D:6=I="`]("1D:6=I="`M(#D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D8VAE8VMS=6T@*ST@)&1I9VET.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1I*RL["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&-H96-K<W5M.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$-A<F14>7!E*"1C
M8VYU;2D*("`@('L*("`@("`@("`D<W5M(#T@)'1H:7,M/F=E=$-H96-K<W5M
M*"1C8VYU;2D["B`@("`@("`@)&P@/2!S=')L96XH)&-C;G5M*3L*"B`@("`@
M("`@+R\@4V-R965N(&-H96-K<W5M+@H@("`@("`@(&EF("@H)'-U;2`E(#$P
M*2`A/2`P*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"@H@("`@("`@("\O($-H96-K(&9O<B!6:7-A+@H@("`@("`@(&EF("@H*"1L
M(#T](#$V*2!\?"`H)&P@/3T@,3,I*2`F)@H@("`@("`@("`@("`H)&-C;G5M
M6S!=(#T](#0I*2!["B`@("`@("`@("`@(')E='5R;B`G=FES82<["B`@("`@
M("`@?0H*("`@("`@("`O+R!#:&5C:R!F;W(@36%S=&5R0V%R9"X*("`@("`@
M("!I9B`H*"1L(#T](#$V*2`F)@H@("`@("`@("`@("`H)&-C;G5M6S!=(#T]
M(#4I("8F"B`@("`@("`@("`@("@D8V-N=6U;,5T@/CT@,2D@)B8*("`@("`@
M("`@("`@*"1C8VYU;5LQ72`\/2`U*2D@>PH@("`@("`@("`@("!R971U<FX@
M)VUA<W1E<F-A<F0G.PH@("`@("`@('T*"B`@("`@("`@+R\@0VAE8VL@9F]R
M($%M97@N"B`@("`@("`@:68@*"@D;"`]/2`Q-2D@)B8*("`@("`@("`@("`@
M*"1C8VYU;5LP72`]/2`S*2`F)@H@("`@("`@("`@("`H*"1C8VYU;5LQ72`]
M/2`T*2!\?"`H)&-C;G5M6S%=(#T](#<I*2D@>PH@("`@("`@("`@("!R971U
M<FX@)V%M97@G.PH@("`@("`@('T*"B`@("`@("`@+R\@0VAE8VL@9F]R($1I
M<V-O=F5R("A.;W9U<RDN"B`@("`@("`@:68@*'-T<FQE;B@D8V-N=6TI(#T]
M(#$V("8F"B`@("`@("`@("`@('-U8G-T<B@D8V-N=6TL(#`L(#0I(#T]("<V
M,#$Q)RD@>PH@("`@("`@("`@("!R971U<FX@)V1I<V-O=F5R)SL*("`@("`@
M("!]"@H@("`@("`@("\O($EF('=E(&=O="!T:&ES(&9A<BP@=&AE;B!N;R!C
M87)D(&UA=&-H960N"B`@("`@("`@<F5T=7)N("=U;FMN;W=N)SL*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&%B;W5T*"D*("`@('L*("`@("`@("`D
M86)O=70@/2!A<G)A>2@I.PH@("`@("`@("1A8F]U=%LG;F%M92==(#T@7R@B
M0W)E9&ET(&-A<F0@;G5M8F5R(BD["B`@("`@("`@<F5T=7)N("1A8F]U=#L*
M("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP95]O8G)O=W-E<B!E>'1E
M;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@9G5N8W1I;VX@:7-686QI9"@F
M)'9A<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!I
M;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%B
M;W5T*"D*("`@('L*("`@("`@("`D86)O=70@/2!A<G)A>2@I.PH@("`@("`@
M("1A8F]U=%LG;F%M92==(#T@7R@B4F5L871I;VYS:&EP($)R;W=S97(B*3L*
M("`@("`@("!R971U<FX@)&%B;W5T.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?
M1F]R;5]4>7!E7V1B;&]O:W5P(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E7V5N
M=6T@>PH*("`@(&9U;F-T:6]N(&EN:70H)&1S;BP@)'-Q;"P@)'!R;VUP="`]
M(&YU;&PI"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=$0BYP:'`G.PH@
M("`@("`@("1V86QU97,@/2!A<G)A>2@I.PH@("`@("`@("1D8B`]("9$0CHZ
M8V]N;F5C="@D9'-N*3L*("`@("`@("!I9B`H(6ES7V$H)&1B+"`G4$5!4E]%
M<G)O<B<I*2!["@H@("`@("`@("`@("`O+R!3970@1$(@<&]R=&%B:6QI='D@
M;W!T:6]N<RX*("`@("`@("`@("`@<W=I=&-H("@D9&(M/G!H<'1Y<&4I('L*
M("`@("`@("`@("`@8V%S92`G;7-S<6PG.@H@("`@("`@("`@("`@("`@)&1B
M+3YS971/<'1I;VXH)W!O<G1A8FEL:71Y)RP@1$)?4$]25$%"24Q)5%E?3$]7
M15)#05-%('P@1$)?4$]25$%"24Q)5%E?15)23U)3('P@1$)?4$]25$%"24Q)
M5%E?4E1224TI.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`D9&(M/G-E=$]P=&EO;B@G<&]R
M=&%B:6QI='DG+"!$0E]03U)404))3$E465],3U=%4D-!4T4@?"!$0E]03U)4
M04))3$E465]%4E)/4E,I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M8V]L(#T@)B1D8BT^9V5T0V]L*"1S<6PI.PH@("`@("`@("`@("!I9B`H(6ES
M7V$H)&-O;"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5Q
M=6ER95]O;F-E("=(;W)D92]!<G)A>2YP:'`G.PH@("`@("`@("`@("`@("`@
M)'9A;'5E<R`]($AO<F1E7T%R<F%Y.CIC;VUB:6YE*"1C;VPL("1C;VPI.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@('!A<F5N=#HZ:6YI="@D
M=F%L=65S+"`D<')O;7!T*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%B;W5T*"D*("`@('L*("`@("`@("!R971U<FX@87)R87DH"B`@("`@("`@
M("`@("=N86UE)R`]/B!?*")$871A8F%S92!,;V]K=7`B*2P*("`@("`@("`@
M("`@)W!A<F%M<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`G9'-N)R`]
M/B!A<G)A>2@G;&%B96PG(#T^(%\H(D133B`H<V5E(&AT='`Z+R]P96%R+G!H
M<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N
M+G!H<"DB*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E
M)R`@/3X@)W1E>'0G*2P*("`@("`@("`@("`@("`@("=S<6PG(#T^(&%R<F%Y
M*"=L86)E;"<@/3X@7R@B4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P
M<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]
M/B`G=&5X="<I+`H@("`@("`@("`@("`@("`@)W!R;VUP="<@/3X@87)R87DH
M)VQA8F5L)R`]/B!?*")0<F]M<'0@=&5X="(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G=&5X="<I*0H@("`@("`@
M("`@("`I.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7V9I9VQE
M="!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@=F%R("1?=&5X=#L*
M("`@('9A<B`D7V9O;G0["@H@("`@9G5N8W1I;VX@:6YI="@D=&5X="P@)&9O
M;G0I"B`@("!["B`@("`@("`@)'1H:7,M/E]T97AT(#T@)'1E>'0["B`@("`@
M("`@)'1H:7,M/E]F;VYT(#T@)&9O;G0["B`@("!]"@H@("`@9G5N8W1I;VX@
M:7-686QI9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@
M('L*("`@("`@("!I9B`H96UP='DH)'9A;'5E*2`F)B`D=F%R+3YI<U)E<75I
M<F5D*"DI('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")4:&ES(&9I96QD
M(&ES(')E<75I<F5D+B(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H*("`@("`@("!I9B`H4W1R:6YG.CIL;W=E<B@D=F%L=64I("$]
M(%-T<FEN9SHZ;&]W97(H)'1H:7,M/E]T97AT*2D@>PH@("`@("`@("`@("`D
M;65S<V%G92`](%\H(E1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T
M8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB*3L*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@9G5N8W1I;VX@9V5T1F]N="@I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?9F]N=#L*("`@('T*"B`@("!F=6YC=&EO;B!G971497AT
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]T97AT.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@(')E
M='5R;B!A<G)A>2@*("`@("`@("`@("`@)VYA;64G(#T^(%\H(D9I9VQE="!#
M05!40TA!(BDL"B`@("`@("`@("`@("=P87)A;7,G(#T^(&%R<F%Y*`H@("`@
M("`@("`@("`@("`@)W1E>'0G(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B5&5X
M="(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@
M/3X@)W1E>'0G*2P*("`@("`@("`@("`@("`@("=F;VYT)R`]/B!A<G)A>2@G
M;&%B96PG(#T^(%\H(D9I9VQE="!F;VYT(BDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G=&5X="<I*0H@("`@("`@("`@
M("`I.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7VEN=F%L:60@
M97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@('9A<B`D;65S<V%G93L*
M"B`@("!F=6YC=&EO;B!I;FET*"1M97-S86=E*0H@("`@>PH@("`@("`@("1T
M:&ES+3YM97-S86=E(#T@)&UE<W-A9V4["B`@("!]"@H@("`@9G5N8W1I;VX@
M:7-686QI9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@
M('L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@I]"@HO*BH*("H@5&AI
M<R!C;&%S<R!R97!R97-E;G1S(&$@<VEN9VQE(&9O<FT@=F%R:6%B;&4@=&AA
M="!M87D@8F4@<F5N9&5R960@87,@;VYE(&]R"B`J(&UO<F4@9F]R;2!F:65L
M9',N"B`J"B`J($!A=71H;W(@(%)O8F5R="!%+B!#;WEL92`\<F]B97)T96-O
M>6QE0&AO=&UA:6PN8V]M/@H@*B!`<&%C:V%G92!(;W)D95]&;W)M"B`J+PIC
M;&%S<R!(;W)D95]&;W)M7U9A<FEA8FQE('L*"B`@("`O*BH*("`@("`J(%1H
M92!F;W)M(&EN<W1A;F-E('1H:7,@=F%R:6%B;&4@:7,@87-S:6=N960@=&\N
M"B`@("`@*@H@("`@("H@0'9A<B!(;W)D95]&;W)M"B`@("`@*B\*("`@('9A
M<B`D9F]R;3L*"B`@("`O*BH*("`@("`J($$@<VAO<G0@9&5S8W)I<'1I;VX@
M;V8@=&AI<R!V87)I86)L92=S('!U<G!O<V4N"B`@("`@*@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1H=6UA;DYA;64["@H@("`@+RHJ
M"B`@("`@*B!4:&4@:6YT97)N86QL>2!U<V5D(&YA;64N"B`@("`@*@H@("`@
M("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1V87).86UE.PH*("`@
M("\J*@H@("`@("H@02![0&QI;FL@2&]R9&5?1F]R;5]4>7!E?2!I;G-T86YC
M92X*("`@("`J"B`@("`@*B!`=F%R($AO<F1E7T9O<FU?5'EP90H@("`@("HO
M"B`@("!V87(@)'1Y<&4["@H@("`@+RHJ"B`@("`@*B!7:&5T:&5R('1H:7,@
M:7,@82!R97%U:7)E9"!V87)I86)L92X*("`@("`J"B`@("`@*B!`=F%R(&)O
M;VQE86X*("`@("`J+PH@("`@=F%R("1R97%U:7)E9#L*"B`@("`O*BH*("`@
M("`J(%=H971H97(@=&AI<R!I<R!A(')E861O;FQY('9A<FEA8FQE+@H@("`@
M("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)')E861O
M;FQY.PH*("`@("\J*@H@("`@("H@02!L;VYG(&1E<V-R:7!T:6]N(&]F('1H
M92!V87)I86)L92=S('!U<G!O<V4L('-P96-I86P@:6YS=')U8W1I;VYS+"!E
M=&,N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1D97-C<FEP=&EO;CL*"B`@("`O*BH*("`@("`J(%1H92!V87)I86)L92!H
M96QP('1E>'0N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@
M("`@=F%R("1H96QP.PH*("`@("\J*@H@("`@("H@5VAE=&AE<B!T:&ES(&ES
M(&%N(&%R<F%Y('9A<FEA8FQE+@H@("`@("H*("`@("`J($!V87(@8F]O;&5A
M;@H@("`@("HO"B`@("!V87(@)%]A<G)A>59A;#L*"B`@("`O*BH*("`@("`J
M(%1H92!D969A=6QT('9A;'5E+@H@("`@("H*("`@("`J($!V87(@;6EX960*
M("`@("`J+PH@("`@=F%R("1?9&5F5F%L=64@/2!N=6QL.PH*("`@("\J*@H@
M("`@("H@02![0&QI;FL@2&]R9&5?1F]R;5]!8W1I;VY](&EN<W1A;F-E+@H@
M("`@("H*("`@("`J($!V87(@2&]R9&5?1F]R;5]!8W1I;VX*("`@("`J+PH@
M("`@=F%R("1?86-T:6]N.PH*("`@("\J*@H@("`@("H@5VAE=&AE<B!T:&ES
M('9A<FEA8FQE(&ES(&1I<V%B;&5D+@H@("`@("H*("`@("`J($!V87(@8F]O
M;&5A;@H@("`@("HO"B`@("!V87(@)%]D:7-A8FQE9"`](&9A;'-E.PH*("`@
M("\J*@H@("`@("H@5$]$3PH@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@
M("`@("HO"B`@("!V87(@)%]A=71O9FEL;&5D(#T@9F%L<V4["@H@("`@+RHJ
M"B`@("`@*B!7:&5T:&5R('1H:7,@:7,@82!H:61D96X@=F%R:6%B;&4N"B`@
M("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7VAI
M9&1E;B`](&9A;'-E.PH*("`@("\J*@H@("`@("H@5$]$3PH@("`@("H*("`@
M("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?;W!T:6]N<R`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!687)I86)L92!C;VYS=')U8W1O<BX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1H=6UA;DYA;64@("`@("!!
M('-H;W)T(&1E<V-R:7!T:6]N(&]F('1H92!V87)I86)L92=S"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!P=7)P;W-E+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=F%R3F%M92`@("`@("`@5&AE(&EN=&5R;F%L;'D@
M=7-E9"!N86UE+@H@("`@("H@0'!A<F%M($AO<F1E7T9O<FU?5'EP92`D='EP
M92`@02![0&QI;FL@2&]R9&5?1F]R;5]4>7!E?2!I;G-T86YC92X*("`@("`J
M($!P87)A;2!B;V]L96%N("1R97%U:7)E9"`@("`@(%=H971H97(@=&AI<R!I
M<R!A(')E<75I<F5D('9A<FEA8FQE+@H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)')E861O;FQY("`@("`@5VAE=&AE<B!T:&ES(&ES(&$@<F5A9&]N;'D@=F%R
M:6%B;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1D97-C<FEP=&EO;B`@("!!
M(&QO;F<@9&5S8W)I<'1I;VX@;V8@=&AE('9A<FEA8FQE)W,*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('!U<G!O<V4L('-P96-I86P@
M:6YS=')U8W1I;VYS+"!E=&,N"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E
M7T9O<FU?5F%R:6%B;&4H)&AU;6%N3F%M92P@)'9A<DYA;64L("8D='EP92P@
M)')E<75I<F5D+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<F5A9&]N;'D@/2!F86QS92P@)&1E<V-R:7!T:6]N(#T@;G5L;"D*("`@('L*
M("`@("`@("`D=&AI<RT^:'5M86Y.86UE("`@/2`D:'5M86Y.86UE.PH@("`@
M("`@("1T:&ES+3YV87).86UE("`@("`]("1V87).86UE.PH@("`@("`@("1T
M:&ES+3YT>7!E("`@("`@("`]("8D='EP93L*("`@("`@("`D=&AI<RT^<F5Q
M=6ER960@("`@/2`D<F5Q=6ER960["B`@("`@("`@)'1H:7,M/G)E861O;FQY
M("`@(#T@)')E861O;FQY.PH@("`@("`@("1T:&ES+3YD97-C<FEP=&EO;B`]
M("1D97-C<FEP=&EO;CL*("`@("`@("`D=&AI<RT^7V%R<F%Y5F%L("`@/2`H
M<W1R<&]S*"1V87).86UE+"`G6UTG*2`A/3T@9F%L<V4I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@07-S:6=N('1H:7,@=F%R:6%B;&4@=&\@=&AE('-P96-I
M9FEE9"!F;W)M+@H@("`@("H*("`@("`J($!P87)A;2!(;W)D95]&;W)M("1F
M;W)M("!4:&4@9F]R;2!I;G-T86YC92!T;R!A<W-I9VX@=&AI<R!V87)I86)L
M92!T;RX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T1F]R;4]B*"8D9F]R;2D*
M("`@('L*("`@("`@("`D=&AI<RT^9F]R;2`]("8D9F]R;3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E=',@82!D969A=6QT('9A;'5E(&9O<B!T:&ES('9A
M<FEA8FQE+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D=F%L=64@($$@
M=F%R:6%B;&4@=F%L=64N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$1E9F%U
M;'0H)'9A;'5E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9&5F5F%L=64@/2`D
M=F%L=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H:7,@=F%R
M:6%B;&4G<R!D969A=6QT('9A;'5E+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1H:7,@=F%R:6%B;&4G<R!D969A=6QT('9A;'5E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971$969A=6QT*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]D969686QU93L*("`@('T*"B`@("`O*BH*("`@("`J($%S
M<VEG;G,@86X@86-T:6]N('1O('1H:7,@=F%R:6%B;&4N"B`@("`@*@H@("`@
M("H@17AA;7!L93H*("`@("`J(#QC;V1E/@H@("`@("H@)'8@/2`F)&9O<FTM
M/F%D9%9A<FEA8FQE*"=->2!687)I86)L92<L("=V87(Q)RP@)W1E>'0G+"!F
M86QS92D["B`@("`@*B`D86-T:6]N(#T@)DAO<F1E7T9O<FU?06-T:6]N.CIF
M86-T;W)Y*"=S=6)M:70G*3L*("`@("`J("1V+3YS971!8W1I;VXH)&%C=&EO
M;BD["B`@("`@*B`\+V-O9&4^"B`@("`@*@H@("`@("H@0'!A<F%M($AO<F1E
M7T9O<FU?06-T:6]N("1A8W1I;VX@($$@>T!L:6YK($AO<F1E7T9O<FU?06-T
M:6]N?2!I;G-T86YC92X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T06-T:6]N
M*"1A8W1I;VXI"B`@("!["B`@("`@("`@)'1H:7,M/E]A8W1I;VX@/2`D86-T
M:6]N.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!W:&5T:&5R('1H
M:7,@=F%R:6%B;&4@:&%S(&%N(&%T=&%C:&5D(&%C=&EO;BX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AI<R!V87)I86)L92!H
M87,@86X@871T86-H960@86-T:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!H
M87-!8W1I;VXH*0H@("`@>PH@("`@("`@(')E='5R;B`A:7-?;G5L;"@D=&AI
M<RT^7V%C=&EO;BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!-86ME<R!T:&ES
M(&$@:&ED9&5N('9A<FEA8FQE+@H@("`@("HO"B`@("!F=6YC=&EO;B!H:61E
M*"D*("`@('L*("`@("`@("`D=&AI<RT^7VAI9&1E;B`]('1R=64["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('=H971H97(@=&AI<R!I<R!A(&AI
M9&1E;B!V87)I86)L92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%1R=64@:68@=&AI<R!A(&AI9&1E;B!V87)I86)L92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@:7-(:61D96XH*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^7VAI9&1E;CL*("`@('T*"B`@("`O*BH*("`@("`J($1I<V%B;&5S('1H
M:7,@=F%R:6%B;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1I<V%B;&4H*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?9&ES86)L960@/2!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!W:&5T:&5R('1H:7,@=F%R:6%B;&4@
M:7,@9&ES86)L960N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&EF('1H:7,@=F%R:6%B;&4@:7,@9&ES86)L960N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&ES1&ES86)L960H*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^7V1I<V%B;&5D.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M('1H92!S:&]R="!D97-C<FEP=&EO;B!O9B!T:&ES('9A<FEA8FQE+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!!('-H;W)T(&1E<V-R:7!T:6]N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$AU;6%N3F%M92@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3YH=6UA;DYA;64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92!I;G1E<FYA;&QY('5S960@=F%R:6%B;&4@
M;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AI<R!V87)I
M86)L92=S(&EN=&5R;F%L(&YA;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%9A<DYA;64H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^=F%R3F%M
M93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AI<R!V87)I86)L
M92=S('1Y<&4N"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D95]&;W)M7U1Y
M<&4@(%1H:7,@=F%R:6%B;&4G<R![0&QI;FL@2&]R9&5?1F]R;5]4>7!E?0H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&EN<W1A;F-E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B`F9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3YT>7!E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!T:&4@;F%M92!O9B!T:&ES('9A<FEA8FQE)W,@='EP92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AI<R!V87)I86)L92=S("![0&QI;FL@
M2&]R9&5?1F]R;5]4>7!E?2!N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M9714>7!E3F%M92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YT>7!E
M+3YG9714>7!E3F%M92@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!W:&5T:&5R('1H:7,@:7,@82!R97%U:7)E9"!V87)I86)L92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AI<R!I<R!A(')E
M<75I<F5D('9A<FEA8FQE+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<U)E<75I
M<F5D*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G)E<75I<F5D.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!W:&5T:&5R('1H:7,@:7,@
M82!R96%D;VYL>2!V87)I86)L92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%1R=64@:68@=&AI<R!A(')E861O;FQY('9A<FEA8FQE+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!I<U)E861O;FQY*"D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/G)E861O;FQY.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!T:&4@<&]S<VEB;&4@=F%L=65S(&]F('1H:7,@=F%R:6%B;&4N
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE('!O<W-I8FQE('9A
M;'5E<R!O9B!T:&ES('9A<FEA8FQE(&]R(&YU;&PN"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%9A;'5E<R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3YT>7!E+3YG971686QU97,H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=VAE=&AE<B!T:&ES('9A<FEA8FQE(&AA<R!A(&QO;F<@9&5S8W)I
M<'1I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF
M('1H:7,@=F%R:6%B;&4@:&%S(&$@;&]N9R!D97-C<FEP=&EO;BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@:&%S1&5S8W)I<'1I;VXH*0H@("`@>PH@("`@("`@
M(')E='5R;B`A96UP='DH)'1H:7,M/F1E<V-R:7!T:6]N*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@=&AI<R!V87)I86)L92=S(&QO;F<@9&5S
M8W)I<'1I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H:7,@
M=F%R:6%B;&4G<R!L;VYG(&1E<V-R:7!T:6]N+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971$97-C<FEP=&EO;B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3YD97-C<FEP=&EO;CL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=VAE=&AE<B!T:&ES(&ES(&%N(&%R<F%Y('9A<FEA8FQE+@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&ES(&%N(&%R<F%Y
M('9A<FEA8FQE+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<T%R<F%Y5F%L*"D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]A<G)A>59A;#L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=VAE=&AE<B!T:&ES('9A<FEA8FQE
M(&ES('1O('5P;&]A9"!A(&9I;&4N"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!4<G5E(&EF('9A<FEA8FQE(&ES('1O('5P;&]A9"!A(&9I;&4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES57!L;V%D*"D*("`@('L*("`@("`@
M("!R971U<FX@*"1T:&ES+3YT>7!E+3YG9714>7!E3F%M92@I(#T]("=F:6QE
M)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!<W-I9VYS(&$@:&5L<"!T97AT
M('1O('1H:7,@=F%R:6%B;&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D:&5L<"`@5&AE('9A<FEA8FQE(&AE;'`@=&5X="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<V5T2&5L<"@D:&5L<"D*("`@('L*("`@("`@("`D=&AI<RT^
M9F]R;2T^7VAE;'`@/2!T<G5E.PH@("`@("`@("1T:&ES+3YH96QP(#T@)&AE
M;'`["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('=H971H97(@=&AI
M<R!V87)I86)L92!H87,@<V]M92!H96QP('1E>'0@87-S:6=N960N"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H:7,@=F%R:6%B
M;&4@:&%S(&$@:&5L<"!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!H87-(
M96QP*"D*("`@('L*("`@("`@("!R971U<FX@(65M<'1Y*"1T:&ES+3YH96QP
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&AE;'`@=&5X
M="!O9B!T:&ES('9A<FEA8FQE+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&ES('9A<FEA8FQE)W,@:&5L<"!T97AT+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971(96QP*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/FAE;'`["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S(&$@=F%R:6%B;&4@
M;W!T:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&]P=&EO;B`@
M5&AE(&]P=&EO;B!N86UE+@H@("`@("H@0'!A<F%M(&UI>&5D("1V86P@("`@
M("!4:&4@;W!T:6]N)W,@=F%L=64N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E
M=$]P=&EO;B@D;W!T:6]N+"`D=F%L*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M;W!T:6]N<ULD;W!T:6]N72`]("1V86P["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&$@=F%R:6%B;&4@;W!T:6]N)W,@=F%L=64N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;W!T:6]N("!4:&4@;W!T:6]N(&YA;64N
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@("`@("`@("!4:&4@;W!T
M:6]N)W,@=F%L=64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$]P=&EO;B@D
M;W!T:6]N*0H@("`@>PH@("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^7V]P
M=&EO;G-;)&]P=&EO;ETI(#\@)'1H:7,M/E]O<'1I;VYS6R1O<'1I;VY=(#H@
M;G5L;#L*("`@('T*"B`@("`O*BH*("`@("`J(%!R;V-E<W-E<R!T:&4@<W5B
M;6ET=&5D('9A;'5E(&]F('1H:7,@=F%R:6%B;&4@86-C;W)D:6YG('1O('1H
M92!R=6QE<R!O9@H@("`@("H@=&AE('9A<FEA8FQE('1Y<&4N"B`@("`@*@H@
M("`@("H@0'!A<F%M(%9A<FEA8FQE<R`D=F%R<R`@5&AE('M`;&EN:R!687)I
M86)L97-](&EN<W1A;F-E(&]F('1H92!S=6)M:71T960*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@(&9O<FTN"B`@("`@*B!`<&%R86T@;6EX960@
M)&EN9F\@("`@("!!('9A<FEA8FQE('!A<W-E9"!B>2!R969E<F5N8V4@=&AA
M="!W:6QL(&)E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!A<W-I
M9VYE9"!T:&4@<')O8V5S<V5D('9A;'5E(&]F('1H92!S=6)M:71T960*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@('9A<FEA8FQE('9A;'5E+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@($1E<&5N9&EN9R!O;B!T:&4@
M=F%R:6%B;&4@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T26YF;R@F
M)'9A<G,L("8D:6YF;RD*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G1Y
M<&4M/F=E=$EN9F\H)'9A<G,L("1T:&ES+"`D:6YF;RD["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('=H971H97(@=&AI<R!V87)I86)L92!I9B!I
M="!H860@=&AE(")T<F%C:V-H86YG92(@;W!T:6]N('-E=`H@("`@("H@:&%S
M(&%C='5A;&QY(&)E96X@8VAA;F=E9"X*("`@("`J"B`@("`@*B!`<&%R86T@
M5F%R:6%B;&5S("1V87)S("!4:&4@>T!L:6YK(%9A<FEA8FQE<WT@:6YS=&%N
M8V4@;V8@=&AE('-U8FUI='1E9`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@9F]R;2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@($YU
M;&P@:68@=&AI<R!V87)I86)L92!D;V5S;B=T(&AA=F4@=&AE(")T<F%C:V-H
M86YG92(*("`@("`J("`@("`@("`@("`@("`@("`@;W!T:6]N('-E="!O<B!T
M:&4@9F]R;2!W87-N)W0@<W5B;6ET=&5D('EE="X@02!B;V]L96%N"B`@("`@
M*B`@("`@("`@("`@("`@("`@(&EN9&EC871I;F<@=VAE=&AE<B!T:&4@=F%R
M:6%B;&4@=V%S(&-H86YG960@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!W87-#:&%N9V5D*"8D=F%R<RD*("`@('L*("`@("`@("!I9B`H(21T
M:&ES+3YG971/<'1I;VXH)W1R86-K8VAA;F=E)RDI('L*("`@("`@("`@("`@
M<F5T=7)N(&YU;&P["B`@("`@("`@?0H@("`@("`@("1O;&0@/2`D=F%R<RT^
M9V5T*"=?7V]L9%\G("X@)'1H:7,M/F=E=%9A<DYA;64H*2D["B`@("`@("`@
M:68@*&ES7VYU;&PH)&]L9"DI('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D;VQD("$]("1V87)S+3YG970H
M)'1H:7,M/F=E=%9A<DYA;64H*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!6
M86QI9&%T97,@=&AI<R!V87)I86)L92X*("`@("`J"B`@("`@*B!`<&%R86T@
M5F%R:6%B;&5S("1V87)S("!4:&4@>T!L:6YK(%9A<FEA8FQE<WT@:6YS=&%N
M8V4@;V8@=&AE('-U8FUI='1E9`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@9F]R;2X*("`@("`J($!P87)A;2!S=')I;F<@)&UE<W-A9V4@($$@
M=F%R:6%B;&4@<&%S<V5D(&)Y(')E9F5R96YC92!T:&%T('=I;&P@8F4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@(&%S<VEG;F5D(&$@9&5S8W)I
M<'1I=F4@97)R;W(@;65S<V%G92!I9@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@=F%L:61A=&EO;B!F86EL960N"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!V87)I86)L92!V86QI9&%T960N
M"B`@("`@*B\*("`@(&9U;F-T:6]N('9A;&ED871E*"8D=F%R<RP@)B1M97-S
M86=E*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V%R<F%Y5F%L*2!["B`@
M("`@("`@("`@("1V86QS(#T@)'1H:7,M/F=E=%9A;'5E*"1V87)S*3L*("`@
M("`@("`@("`@:68@*"%I<U]A<G)A>2@D=F%L<RDI('L*("`@("`@("`@("`@
M("`@(&EF("@D=&AI<RT^<F5Q=6ER960I('L*("`@("`@("`@("`@("`@("`@
M("`D;65S<V%G92`](%\H(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(BD["B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!F
M;W)E86-H("@D=F%L<R!A<R`D:2`]/B`D=F%L=64I('L*("`@("`@("`@("`@
M("`@(&EF("@D=F%L=64@/3T](&YU;&P@)B8@)'1H:7,M/G)E<75I<F5D*2![
M"B`@("`@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")4:&ES(&9I96QD
M(&ES(')E<75I<F5D+B(I.PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@:68@*"$D=&AI<RT^='EP92T^:7-686QI9"@D=&AI<RP@)'9A<G,L
M("1V86QU92P@)&UE<W-A9V4I*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=F%L=64@/2`D=&AI<RT^9V5T5F%L=64H)'9A<G,I.PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G1Y<&4M/FES5F%L:60H)'1H:7,L("1V
M87)S+"`D=F%L=64L("1M97-S86=E*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M<W5B;6ET=&5D(&]R(&1E9F%U;'0@=F%L=64@;V8@=&AI<R!V87)I86)L92X*
M("`@("`J($EF(&%N(&%C=&EO;B!I<R!A='1A8VAE9"!T;R!T:&ES('9A<FEA
M8FQE+"!T:&4@=F%L=64@=VEL;"!G970@<&%S<V5D('1O"B`@("`@*B!T:&4@
M86-T:6]N(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@5F%R:6%B;&5S
M("1V87)S("!4:&4@>T!L:6YK(%9A<FEA8FQE<WT@:6YS=&%N8V4@;V8@=&AE
M('-U8FUI='1E9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@9F]R
M;2X*("`@("`J($!P87)A;2!I;G1E9V5R("1I;F1E>"`@($EF('1H92!V87)I
M86)L92!I<R!A;B!A<G)A>2!V87)I86)L92P@=&AI<PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@<W!E8VEF:65S('1H92!A<G)A>2!E;&5M96YT
M('1O(')E='5R;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@
M=F%R:6%B;&4@;W(@96QE;65N="!V86QU92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T5F%L=64H)B1V87)S+"`D:6YD97@@/2!N=6QL*0H@("`@>PH@("`@
M("`@(&EF("@D=&AI<RT^7V%R<F%Y5F%L*2!["B`@("`@("`@("`@("1N86UE
M(#T@<W1R7W)E<&QA8V4H)UM=)RP@)R<L("1T:&ES+3YV87).86UE*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;F%M92`]("1T:&ES+3YV87).
M86UE.PH@("`@("`@('T*("`@("`@("`D=F%L=64@/2`D=F%R<RT^9V5T17AI
M<W1S*"1N86UE+"`D=V%S<V5T*3L*"B`@("`@("`@:68@*"$D=V%S<V5T*2![
M"B`@("`@("`@("`@("1V86QU92`]("1T:&ES+3YG971$969A=6QT*"D["B`@
M("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/E]A<G)A>59A;"`F)B`A:7-?
M;G5L;"@D:6YD97@I*2!["B`@("`@("`@("`@(&EF("@A)'=A<W-E="`F)B`A
M:7-?87)R87DH)'9A;'5E*2D@>PH@("`@("`@("`@("`@("`@)')E='5R;B`]
M("1V86QU93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1R971U<FX@/2!I<W-E="@D=F%L=65;)&EN9&5X72D@/R`D=F%L=65;)&EN
M9&5X72`Z(&YU;&P["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D<F5T=7)N(#T@)'9A;'5E.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"1T:&ES+3YH87-!8W1I;VXH*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^7V%C=&EO;BT^<V5T5F%L=65S*"1V87)S+"`D<F5T=7)N+"`D=&AI<RT^
M7V%R<F%Y5F%L*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5T=7)N
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]+;VQA
M8BYP:'``````````````````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#$V-30P-2`Q,#4Q-30S,S<T,"`P,C$Q,C``(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*"B\J*B!792!R97%U:7)E
M('1H92!B87-E($AO<F1E(&QI8G)A<GDN("HO"G)E<75I<F5?;VYC92`G2&]R
M9&4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]3:&%R92YP:'`G.PH*+RHJ
M(%=E(&YE960@=&AE(%-T<FEN9R`F($Y,4R!L:6)R87)I97,@9F]R(&-H87)A
M8W1E<B!S970@8V]N=F5R<VEO;G,L(&5T8RX@*B\*<F5Q=6ER95]O;F-E("=(
M;W)D92]3=')I;F<N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92].3%,N<&AP
M)SL*"B\J*B!792!N965D('1H92!(;W)D92!-24U%(&QI8G)A<GD@=&\@9&5A
M;"!W:71H($U)344@;65S<V%G97,L(&]B=FEO=7-L>2`Z+2DN("HO"G)E<75I
M<F5?;VYC92`G2&]R9&4O34E-12YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E
M+TU)344O4&%R="YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TU)344O365S
M<V%G92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TU)344O2&5A9&5R<RYP
M:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TU)344O4W1R=6-T=7)E+G!H<"<[
M"@HO*BH*("H@5&AE($AO<F1E7TMO;&%B(&QI8G)A<GD@<F5Q=6ER97,@=F5R
M<VEO;B`^/2`Q+C`N,R!O9B!.971?24U!4"`H:2YE+B!A('9E<G-I;VX*("H@
M=&AA="!I;F-L=61E<R!S=7!P;W)T(&9O<B!T:&4@04Y.3U1!5$5-3U)%($E-
M05`@97AT96YS:6]N*2X@5&AE(&QA=&5S=`H@*B!V97)S:6]N(&]F($YE=%])
M34%0(&-A;B!B92!O8G1A:6YE9"!F<F]M(&AT='`Z+R]P96%R+G!H<"YN970O
M9V5T+TYE=%])34%0"B`J+PIR97%U:7)E7V]N8V4@)TYE="])34%0+G!H<"<[
M"@HO*BH*("H@5&AE(&-H87)A8W1E<B!S97%U96YC92!U<V5D(&)Y(&$@*$MO
M;&%B*2!#>7)U<R!)34%0('-E<G9E<B!T;R!S97!A<F%T92!L:6YE<PH@*B!W
M:71H:6X@82!M97-S86=E+@H@*B\*9&5F:6YE*"=+3TQ!0E].15=,24Y%)RP@
M(EQR7&XB*3L*"B\J*@H@*B!4:&4@8VAA<F%C=&5R('5S960@=&\@9&5L:6UI
M="!S=6)F;VQD97)S('=I=&AI;B!A("A+;VQA8BD@0WER=7,@9F]L9&5R"B`J
M(&AI97)A<F-H>2X*("HO"F1E9FEN92@G2T],04)?1D],1$527T1%3$E-)RP@
M)R\G*3L*"B\J*@H@*B!4:&4@<F]O="!O9B!T:&4@2V]L86(@86YN;W1A=&EO
M;B!H:65R87)C:'DL('5S960@;VX@=&AE('9A<FEO=7,@24U!4"!F;VQD97(*
M("H@=&AA="!A<F4@=7-E9"!B>2!+;VQA8B!C;&EE;G1S+@H@*B\*9&5F:6YE
M*"=+3TQ!0E]!3DY/5%]23T]4)RP@)R]V96YD;W(O:V]L86(O)RD["@HO*BH*
M("H@5&AE(&%N;F]T871I;VXL(&%S(&1E9FEN960@8GD@=&AE($MO;&%B(&9O
M<FUA="!S<&5C+"!T:&%T(&ES('5S960@=&\@<W1O<F4*("H@:6YF;W)M871I
M;VX@86)O=70@=VAA="!G<F]U<'=A<F4@9F]R;6%T('1H92!F;VQD97(@8V]N
M=&%I;G,N"B`J+PID969I;F4H)TM/3$%"7T%.3D]47T9/3$1%4E]465!%)RP@
M2T],04)?04Y.3U1?4D]/5"`N("=F;VQD97(M='EP92<I.PH*+RHJ"B`J($$@
M2&]R9&4M<W!E8VEF:6,@86YN;W1A=&EO;B!T:&%T('-T;W)E<R!T:&4@54E$
M(&]F('1H92!(;W)D92!S:&%R92!T:&%T"B`J(&-O<G)E<W!O;F1S('1O('1H
M92!)34%0(&9O;&1E<BX@5&AI<R!I<R!U<V5D(&EN('1H92!S>6YC:')O;FES
M871I;VX@<')O8V5S<PH@*B!O9B!T:&4@24U!4"!F;VQD97(@;&ES="!A;F0@
M=&AE($AO<F1E('-H87)E(&QI<W0N"B`J+PID969I;F4H)TM/3$%"7T%.3D]4
M7U-(05)%7U5)1"<L($M/3$%"7T%.3D]47U)/3U0@+B`G:"US:&%R92UU:60G
M*3L*"B\J*@H@*B!4:&4@6"T@:&5A9&5R('5S960@=&\@<W1O<F4@82!C;W!Y
M(&]F('1H92!+;VQA8B!O8FIE8W0@='EP92!S=')I;F<@9F]R('1H90H@*B!O
M8FIE8W0@='EP92!T:&%T(&ES(&-O;G1A:6YE9"!W:71H:6X@=&AE(&5M86EL
M(&UE<W-A9V4N"B`J+PID969I;F4H)TM/3$%"7TA%041%4E]465!%)RP@)U@M
M2V]L86(M5'EP92<I.PH*+RHJ"B`J($%N(&EN9&5X(&EN=&\@=&AE("1?4T53
M4TE/3B!A<G)A>2!W:&EC:"!I<R!U<V5D('1O(&-A8VAE('=H870@87!P;&EC
M871I;VX*("H@=V%S(&QA<W0@<WEN8VAR;VYI<V5D.R!T:&ES('!R979E;G1S
M('5S(&9R;VT@8V]N=&EN=6]U<VQY(')E+7-Y;F-H<F]N:7-I;F<*("H@;VX@
M979E<GD@<&%G92!L;V%D('=I=&AI;B!A('-I;F=L92!A<'!L:6-A=&EO;BX*
M("HO"F1E9FEN92@G2T],04)?3$%35%]364Y#2$5$7T%04"<L("=K;VQA8E]L
M87-T7W-Y;F-H961?87!P)RD["@HO*BH*("H@06X@:6YD97@@:6YT;R!T:&4@
M)%]315-324].(&%R<F%Y('=H:6-H(&ES('5S960@=&\@8V%C:&4@82!M87!P
M:6YG(&]F('-H87)E"B`J(%5)1',@=&\@24U!4"!F;VQD97)S.R!T:&ES(&ES
M('5S960@8GD@=&AE('9A<FEO=7,@87!P;&EC871I;VX@9')I=F5R<R!W:&5N
M"B`J(&]P96YI;F<@82!S<&5C:69I8R!S:&%R92P@:6X@;W)D97(@=&\@:VYO
M=R!W:&%T('1H92!C;W)R97-P;VYD:6YG($E-05`*("H@9F]L9&5R('1H870@
M;75S="!B92!O<&5N960@:7,N"B`J+PID969I;F4H)TM/3$%"7U-(05)%7TU!
M4"<L("=K;VQA8E]S:&%R95]M87`G*3L*"B\J*@H@*B!4:&4@<')E9FEX(&9O
M<B!A;&P@2V]L86(@9W)O=7!W87)E(&]B:F5C="!M:6UE('1Y<&4@<W1R:6YG
M<RX@16%C:"!O8FIE8W0*("H@='EP92!H87,@=&AI<R!S=')I;F<@:6X@8V]M
M;6]N+"!W:71H(&$@<W5F9FEX(&]F(&4N9RX@)VYO=&4G+"`G979E;G0G+"!E
M=&,N"B`J('1O(&EN9&EC871E('=H870@=&AE('-P96-I9FEC($MO;&%B(&=R
M;W5P=V%R92!F;W)M870@:7,N"B`J+PID969I;F4H)TM/3$%"7TU)345?5%E0
M15]04D5&25@G+"`G87!P;&EC871I;VXO>"UV;F0N:V]L86(N)RD["@HO*BH*
M("H@5&AE('-T<FEN9R!U<V5D('1O(&ED96YT:69Y('1H92!(;W)D92]+;VQA
M8B!I;G1E9W)A=&EO;B!E;F=I;F4@:6X@=F%R:6]U<PH@*B!P;&%C97,@*&4N
M9RX@:6X@2V]L86(@;V)J96-T<R!G96YE<F%T960@8GD@=&AE(&QI8G)A<GDI
M+@H@*B\*9&5F:6YE*"=+3TQ!0E]04D]$54-47TE$)RP@)VAO<F1E+VMO;&%B
M+S$N,"<I.PH*+RHJ"B`J(%1H92!(;W)D95]+;VQA8B!L:6)R87)Y(&ES(&)O
M=&@@86X@;V)J96-T('5S960@8GD@87!P;&EC871I;VX@9')I=F5R<R!T;PH@
M*B!C;VUM=6YI8V%T92!W:71H(&$@2V]L86(@<V5R=F5R+"!A<R!W96QL(&%S
M(&$@=71I;&ET>2!L:6)R87)Y('!R;W9I9&EN9PH@*B!S979E<F%L(&9U;F-T
M:6]N<R!T;R!H96QP(&EN('1H92!)34%0(&9O;&1E<B`\+3X@2&]R9&4@4VAA
M<F4@<WEN8VAR;VYI<V%T:6]N"B`J('!R;V-E<W,N"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<"QV(#$N,C8N,3`N,38@,C`P-B\P
M-R\Q-R`P.3HS,#HU,"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M
M,C`P-B!(;W)D92!0<F]J96-T("AH='1P.B\O:&]R9&4N;W)G+RD*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@(%-T=6%R="!":6YG92`\;VUI8W)O;D!M
M:6=H='DN8V\N>F$^"B`J($!P86-K86=E($AO<F1E7TMO;&%B"B`J+PIC;&%S
M<R!+;VQA8B!["@HO+R!#;&%S<R!I;G1E<F9A8V4*"B`@("`O*BH*("`@("`J
M(%1H92!C=7)R96YT(&%P<&QI8V%T:6]N('1H870@=&AI<R!+;VQA8B!O8FIE
M8W0@:6YS=&%N8V4@:7,@8V%T97)I;F<@=&\N"B`@("`@*@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?87!P.PH*("`@("\J*@H@("`@
M("H@3W5R($YE=%])34%0(&]B:F5C="P@=7-E9"!T;R!C;VUM=6YI8V%T92!W
M:71H('1H92!#>7)U<R!S97)V97(N"B`@("`@*@H@("`@("H@0'9A<B!.971?
M24U!4`H@("`@("HO"B`@("!V87(@)%]I;6%P(#T@;G5L;#L*"B`@("`O*BH*
M("`@("`J($$@8V%C:&5D('9E<G-I;VX@;V8@2V]L86(Z.F=E=$%P<$-O;G-T
M<R@D=&AI<RT^7V%P<"D@=&AA="!I<R!U<V5D(&EN"B`@("`@*B!S979E<F%L
M(&]F('1H92!+;VQA8CHZ(&9U;F-T:6]N<RX*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V%P<%]C;VYS=',["@H@("`@+RHJ
M"B`@("`@*B!!('-H;W)T8W5T('1O("1T:&ES+3Y?87!P7V-O;G-T<ULG;6EM
M95]T>7!E7W-U9F9I>"=="B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@
M("`J+PH@("`@=F%R("1?;V)J96-T7W1Y<&4["@H@("`@+RHJ"B`@("`@*B!4
M:&4@9G5L;"!M:6UE('1Y<&4@<W1R:6YG(&]F('1H92!C=7)R96YT($MO;&%B
M(&]B:F5C="!F;W)M870@=V4G<F4*("`@("`J(&1E86QI;F<@=VET:"X*("`@
M("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]M:6UE
M7W1Y<&4["@H@("`@+RHJ"B`@("`@*B!4:&4@*&5N8V]D960I(&YA;64@;V8@
M=&AE($E-05`@9F]L9&5R('1H870@8V]R<F5S<&]N9',@=&\@=&AE(&-U<G)E
M;G0*("`@("`J('-H87)E+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D7V9O;&1E<CL*"B`@("`O*BH*("`@("`J(%1H92!-
M24U%7TUE<W-A9V4@;V)J96-T('1H870@8V]N=&%I;G,@=&AE(&-U<G)E;G1L
M>2!L;V%D960@;65S<V%G92X@5&AI<PH@("`@("H@:7,@=7-E9"!W:&5N('5P
M9&%T:6YG(&%N(&]B:F5C="P@:6X@;W)D97(@=&\@<')E<V5R=F4@979E<GET
M:&EN9R!E;'-E"B`@("`@*B!W:71H:6X@=&AE(&UE<W-A9V4@=&AA="!W92!D
M;VXG="!K;F]W(&AO=R!T;R!H86YD;&4N"B`@("`@*@H@("`@("H@0'9A<B!-
M24U%7TUE<W-A9V4*("`@("`J+PH@("`@=F%R("1?;65S<V%G93L*"B`@("`O
M*BH*("`@("`J($%N(&%R<F%Y(&-O;G1A:6YI;F<@)%]M97-S86=E)W,@:&5A
M9&5R<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D7VAE861E<G,["@H@("`@+RHJ"B`@("`@*B!4:&4@34E-12!I9&5N=&EF
M:65R(&]F('1H92!+;VQA8B!G<F]U<'=A<F4@;V)J96-T('=I=&AI;B`D=&AI
M<RT^7VUE<W-A9V4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J
M+PH@("`@=F%R("1?;6EM95]I9#L*"B`@("`O*BH*("`@("`J(%1H92`H2V]L
M86(I(%5)1"!O9B`D=&AI<RT^7VUE<W-A9V4N"B`@("`@*@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?=6ED.PH*("`@("\J*@H@("`@
M("H@5&AE($1O;41O8W5M96YT(&]B:F5C="!T:&%T(&-O;G1A:6YS('1H92!8
M34P@1$]-('1R964@;V8@=&AE(&-U<G)E;G1L>0H@("`@("H@;&]A9&5D(&=R
M;W5P=V%R92!O8FIE8W0N(%=E(&-A8VAE('1H:7,@:&5R92!T;R!E;G-U<F4@
M<')E<V5R=F%T:6]N(&]F"B`@("`@*B!U;FMN;W=N(&9I96QD<R!W:&5N(')E
M+7-A=FEN9R!T:&4@;V)J96-T+@H@("`@("H*("`@("`J($!V87(@1&]M1&]C
M=6UE;G0*("`@("`J+PH@("`@=F%R("1?>&UL.PH*("`@("\J*@H@("`@("H@
M5&AE($E-05`@;65S<V%G92!N=6UB97(@;V8@)'1H:7,M/E]M97-S86=E+@H@
M("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]M
M<V=?;F\["@H@("`@9G5N8W1I;VX@9V5T54E$*"D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]U:60["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T36EM
M951Y<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VUI;65?='EP
M93L*("`@('T*"B`@("!F=6YC=&EO;B!+;VQA8B@I"B`@("!["B`@("`@("`@
M9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@)'1H:7,M/E]A<'`@/2`D<F5G
M:7-T<GDM/F=E=$%P<"@I.PH@("`@?0H*("`@(&9U;F-T:6]N(&]P96XH)'-H
M87)E7W5I9"D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@
M(&EF("@A571I;#HZ97AT96YS:6]N17AI<W1S*"=D;VUX;6PG*2D@>PH@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")(;W)D92]+;VQA
M8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM
M;"<@4$A0(&5X=&5N<VEO;B(I*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES
M+3Y?87!P7V-O;G-T<R`]($MO;&%B.CIG971!<'!#;VYS=',H)'1H:7,M/E]A
M<'`I.PH@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?87!P7V-O;G-T<RP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]A<'!?
M8V]N<W1S.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]O8FIE8W1?='EP
M92`]("1T:&ES+3Y?87!P7V-O;G-T<ULG;6EM95]T>7!E7W-U9F9I>"==.PH@
M("`@("`@("1T:&ES+3Y?;6EM95]T>7!E(#T@2T],04)?34E-15]465!%7U!2
M149)6"`N("1T:&ES+3Y?;V)J96-T7W1Y<&4["@H@("`@("`@("1C=7)R96YT
M7W5S97(@/2!!=71H.CIG971!=71H*"D["B`@("`@("`@)&YD>"`]('-T<G!O
M<R@D8W5R<F5N=%]U<V5R+"`G0"<I.PH@("`@("`@("1U<V5R(#T@)&YD>"`]
M/3T@9F%L<V4@/R`D8W5R<F5N=%]U<V5R(#H@<W5B<W1R*"1C=7)R96YT7W5S
M97(L(#`L("1N9'@I.PH@("`@("`@("1D;VUA:6X@/2!S=')S='(H)&-U<G)E
M;G1?=7-E<BP@)T`G*3L*"B`@("`@("`@)'-H87)E7VUA<"`]($MO;&%B.CIG
M9713:&%R94UA<"@I.PH@("`@("`@(&EF("AE;7!T>2@D<VAA<F5?;6%P6R1S
M:&%R95]U:61=*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H@("`@("`@("1F;VQD97(@/2`D<VAA<F5?;6%P6R1S:&%R95]U:61=
M.PH*("`@("`@("`O+R!4<F%N<VQA=&4@<F5M;W1E+7-Y;G1A>"!F;VQD97)S
M('1H870@=V4@;W=N('1O(&QO8V%L+7-Y;G1A>"!S;R!T:&%T"B`@("`@("`@
M+R\@=V4@8V%N(&]P96X@=&AE;2!P<F]P97)L>0H@("`@("`@('!R96=?;6%T
M8V@H(CMU<V5R+RA;7B]=*RDO*%M>0%TK*2A`+BHI/SLB+"`D9F]L9&5R+"`D
M;6%T8VAE<RD["@H@("`@("`@("1U<V5R7V1O;6%I;B`](&ES<V5T*"1M871C
M:&5S6S-=*2`_("1M871C:&5S6S-=(#H@)&1O;6%I;CL*("`@("`@("!I9B`H
M)&UA=&-H97-;,5T@/3T@)'5S97(@)B8@)'5S97)?9&]M86EN(#T]("1D;VUA
M:6XI('L*("`@("`@("`@("`@)&9O;&1E<B`]("))3D)/6"\D;6%T8VAE<ULR
M72(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&9O;&1E<B`](")U
M<V5R+R1M871C:&5S6S%=+R1M871C:&5S6S)=(CL*("`@("`@("`@("`@:68@
M*"1U<V5R7V1O;6%I;B`A/2`D9&]M86EN*2!["B`@("`@("`@("`@("`@("`D
M9F]L9&5R("X]("1U<V5R7V1O;6%I;CL*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@)'1H:7,M/E]F;VQD97(@/2`D9F]L9&5R.PH*("`@("`@
M("`D=&AI<RT^7VEM87`@/2!N97<@3F5T7TE-05`H)&-O;F9;)VMO;&%B)UU;
M)VEM87`G75LG<V5R=F5R)UTL("1C;VYF6R=K;VQA8B==6R=I;6%P)UU;)W!O
M<G0G72D["@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM87`M/FQO9VEN
M*"1C=7)R96YT7W5S97(L($%U=&@Z.F=E=$-R961E;G1I86PH)W!A<W-W;W)D
M)RDL(&9A;'-E+"!F86QS92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@("`@("!]"@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM87`M/G-E
M;&5C=$UA:6QB;W@H)'1H:7,M/E]F;VQD97(I.PH@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("!F=6YC=&EO;B!C;&]S92@I"B`@("!["B`@("`@("`@:68@*"%E
M;7!T>2@D=&AI<RT^7VEM87`I*2!["B`@("`@("`@("`@("1T:&ES+3Y?:6UA
M<"T^9&ES8V]N;F5C="@I.PH@("`@("`@("`@("`D=&AI<RT^7VEM87`@/2!N
M=6QL.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!F:6YD3V)J96-T
M*"1U:60I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?:6UA<"DI
M('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@
M("`@)')E<W5L="`]("1T:&ES+3Y?:6UA<"T^<V5A<F-H*")354)*14-4(%PB
M)'5I9%PB(BD["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]
M"@H@("`@("`@(&EF("AE;7!T>2@D<F5S=6QT*2D@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(DAO<F1E+TMO;&%B
M.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(I+"`D=6ED
M*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E<W5L=%LP73L*("`@
M('T*"B`@("!F=6YC=&EO;B!L:7-T3V)J96-T<R@I"B`@("!["B`@("`@("`@
M:68@*&5M<'1Y*"1T:&ES+3Y?:6UA<"DI('L*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6UA
M<"T^<V5A<F-H*"=(14%$15(@(B<@+B!+3TQ!0E](14%$15)?5%E012`N("<B
M("(G("X@)'1H:7,M/E]M:6UE7W1Y<&4@+B`G(B<I.PH@("`@?0H*("`@(&9U
M;F-T:6]N(&9I;F1/8FIE8W1S*"1C<FET97)I82D*("`@('L*("`@("`@("!I
M9B`H96UP='DH)'1H:7,M/E]I;6%P*2D@>PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]I;6%P
M+3YS96%R8V@H)&-R:71E<FEA*3L*("`@('T*"B`@("!F=6YC=&EO;B!L:7-T
M3V)J96-T<TEN1F]L9&5R*"1F;VQD97(I"B`@("!["B`@("`@("`@9VQO8F%L
M("1C;VYF.PH*("`@("`@("`O+R!#;VYN96-T('1O('1H92!)34%0('-E<G9E
M<@H@("`@("`@("1I;6%P(#T@;F5W($YE=%])34%0*"1C;VYF6R=K;VQA8B==
M6R=I;6%P)UU;)W-E<G9E<B==+"`D8V]N9ELG:V]L86(G75LG:6UA<"==6R=P
M;W)T)UTI.PH*("`@("`@("`O+R!,;V=I;B!U<VEN9R!T:&4@8W5R<F5N="!(
M;W)D92!C<F5D96YT:6%L<PH@("`@("`@("1R97-U;'0@/2`D:6UA<"T^;&]G
M:6XH075T:#HZ9V5T075T:"@I+"!!=71H.CIG971#<F5D96YT:6%L*"=P87-S
M=V]R9"<I+"!F86QS92P@9F%L<V4I.PH@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE
M<W-A9V4H)U5N86)L92!T;R!A=71H96YT:6-A=&4@=VET:"!T:&4@2V]L86(@
M24U!4"!S97)V97(G+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T52
M4BD["B`@("`@("`@("`@("1I;6%P+3YD:7-C;VYN96-T*"D["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("\O(%-E;&5C
M="!M86EL8F]X('1O('-E87)C:"!I;@H@("`@("`@("1R97-U;'0@/2`D:6UA
M<"T^<V5L96-T36%I;&)O>"@D9F]L9&5R*3L*("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1I;6%P+3YD
M:7-C;VYN96-T*"D["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM87`M/G-E87)C:"@G
M2$5!1$52("(G("X@2T],04)?2$5!1$527U194$4@+B`G(B`B)R`N("1T:&ES
M+3Y?;6EM95]T>7!E("X@)R(G*3L*("`@("`@("`D:6UA<"T^9&ES8V]N;F5C
M="@I.PH*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O+R!4
M3T1/.B!W<FET92!A(&9U;F-T:6]N('1H870@:7,@86)L92!T;R!L;V]K('1H
M<F]U9V@@86QL(&9O;&1E<G,*("`@("\O(&]F('1H92!T>7!E('=E)W)E(&EN
M=&5R97-T960@:6XL(&QO;VMI;F<@9F]R(&%N(&]B:F5C="!W:71H(&$*("`@
M("\O('-P96-I9FEC(%5)1"X@5&AI<R!I<R!N965D960@9F]R('1H92!G971"
M>4=5240H*2!F=6YC=&EO;G,@:6X*("`@("\O('1H92!V87)I;W5S(&%P<&QI
M8V%T:6]N(&1R:79E<G,N"@H@("`@9G5N8W1I;VX@;6]V94]B:F5C="@D=6ED
M+"`D;F5W7W-H87)E*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^
M7VEM87`I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"@H@("`@("`@("1M<V=?;F\@/2`D=&AI<RT^9FEN9$]B:F5C="@D=6ED*3L*
M("`@("`@("!I9B`H:7-?82@D;7-G7VYO+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D;7-G7VYO.PH@("`@("`@('T*"B`@("`@("`@
M)'-H87)E7VUA<"`]($MO;&%B.CIG9713:&%R94UA<"@I.PH@("`@("`@(&EF
M("AE;7!T>2@D<VAA<F5?;6%P6R1N97=?<VAA<F5=*2D@>PH@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(DAO<F1E+TMO
M;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(I+"`D;F5W7W-H87)E*2D["B`@
M("`@("`@?0H*("`@("`@("`D;F5W7V9O;&1E<B`]("1S:&%R95]M87!;)&YE
M=U]S:&%R95T["@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM87`M/F-O
M<'E-97-S86=E<R@D;F5W7V9O;&1E<BP@)&US9U]N;RD["B`@("`@("`@:68@
M*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@("1R97-U;'0@/2`D
M=&AI<RT^7VEM87`M/F1E;&5T94UE<W-A9V5S*"1M<V=?;F\I.PH@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)'1H:7,M/E]I;6%P+3YE>'!U;F=E*"D["B`@("!]"@H@("`@9G5N8W1I;VX@
M<F5M;W9E3V)J96-T<R@D;V)J96-T<RP@)&ES7VUS9VYO(#T@9F%L<V4I"B`@
M("!["B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?:6UA<"DI('L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I
M<U]A<G)A>2@D;V)J96-T<RDI('L*("`@("`@("`@("`@)&]B:F5C=',@/2!A
M<G)A>2@D;V)J96-T<RD["B`@("`@("`@?0H*("`@("`@("!I9B`H)&ES7VUS
M9VYO(#T]/2!F86QS92D@>PH@("`@("`@("`@("`D;F5W7V]B:F5C=',@/2!A
M<G)A>2@I.PH*("`@("`@("`@("`@9F]R96%C:"`H)&]B:F5C=',@87,@)&]B
M:F5C="D@>PH@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YF:6YD
M3V)J96-T*"1O8FIE8W0I.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@("1N97=?;V)J96-T<UM=(#T@)')E<W5L=#L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@)&]B:F5C=',@/2`D;F5W7V]B:F5C=',["B`@("`@("`@
M?0H*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;6%P+3YD96QE=&5-97-S
M86=E<R@D;V)J96-T<RD["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M("`@("!]"@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM87`M/F5X<'5N
M9V4H*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@9G5N8W1I;VX@<F5M;W9E
M06QL3V)J96-T<R@I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?
M:6UA<"DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6UA<"T^9&5L971E365S<V%G
M97,H)'1H:7,M/FQI<W1/8FIE8W1S*"DI.PH@("`@("`@(&EF("AI<U]A*"1R
M97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*
M"B`@("!F=6YC=&EO;B`F;&]A9$]B:F5C="@D=6ED+"`D:7-?;7-G;F\@/2!F
M86QS92D*("`@('L*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]I;6%P*2D@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@
M("!I9B`H)&ES7VUS9VYO(#T]/2!F86QS92D@>PH@("`@("`@("`@("`D=6ED
M(#T@)'1H:7,M/F9I;F1/8FIE8W0H)'5I9"D["B`@("`@("`@("`@(&EF("AI
M<U]A*"1U:60L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D=6ED.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D
M=&AI<RT^7VAE861E<G,@/2`D=&AI<RT^7VEM87`M/F=E=%!A<G-E9$AE861E
M<G,H)'5I9"D["B`@("`@("`@:68@*&ES7V$H)'1H:7,M/E]H96%D97)S+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@
M("`@("`@('T*"B`@("`@("`@)&UE<W-A9V5?=&5X="`]("1T:&ES+3Y?:6UA
M<"T^9V5T365S<V%G97,H)'5I9"D["B`@("`@("`@:68@*&ES7V$H)&UE<W-A
M9V5?=&5X="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)&UE<W-A9V5?=&5X=#L*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]A<G)A
M>2@D;65S<V%G95]T97AT*2D@>PH@("`@("`@("`@("`D;65S<V%G95]T97AT
M(#T@87)R87E?<VAI9G0H)&UE<W-A9V5?=&5X="D["B`@("`@("`@?0H*("`@
M("`@("`D=&AI<RT^7VUS9U]N;R`]("1U:60["B`@("`@("`@)'1H:7,M/E]M
M97-S86=E(#T@)DU)345?4W1R=6-T=7)E.CIP87)S951E>'1-24U%365S<V%G
M92@D;65S<V%G95]T97AT*3L*"B`@("`@("`@)'!A<G1S(#T@)'1H:7,M/E]M
M97-S86=E+3YC;VYT96YT5'EP94UA<"@I.PH@("`@("`@(&EF("@H)'1H:7,M
M/E]M:6UE7VED(#T@87)R87E?<V5A<F-H*"1T:&ES+3Y?;6EM95]T>7!E+"`D
M<&%R=',I*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@)'!A<G0@/2`D=&AI
M<RT^7VUE<W-A9V4M/F=E=%!A<G0H)'1H:7,M/E]M:6UE7VED*3L*("`@("`@
M("`@("`@)'1E>'0@/2`D<&%R="T^=')A;G-F97)$96-O9&4H*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BAS<')I;G1F*%\H(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E
M<R!F;W5N9"!I;B!M97-S86=E("5S(BDL("1T:&ES+3Y?;6EM95]T>7!E+"`D
M=6ED*2D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7WAM;"`]($!D;VUX
M;6Q?;W!E;E]M96TH)'1E>'0L($1/35A-3%],3T%$7U!!4E-)3D<@?`H@("`@
M("`@("`@("!$3TU834Q?3$]!1%]#3TU03$5415]!5%124R!\($1/35A-3%],
M3T%$7U-50E-425155$5?14Y4251)15,@?`H@("`@("`@("`@("!$3TU834Q?
M3$]!1%]$3TY47TM%15!?0DQ!3DM3+"`D97)R;W(I.PH@("`@("`@(&EF("@A
M96UP='DH)&5R<F]R*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BAS<')I;G1F*%\H(DAO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-
M3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,B*2P@)'1H:7,M/E]O
M8FIE8W1?='EP92P@)'5I9"DI.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M
M/E]U:60@/2`D=&AI<RT^9V5T5F%L*"=U:60G*3L*("`@("`@("!R971U<FX@
M)'1H:7,M/E]X;6PM/F1O8W5M96YT7V5L96UE;G0H*3L*("`@('T*"B`@("!F
M=6YC=&EO;B`F;F5W3V)J96-T*"1U:60I"B`@("!["B`@("`@("`@:68@*&5M
M<'1Y*"1T:&ES+3Y?:6UA<"DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]M<V=?;F\@/2`M,3L*"B`@
M("`@("`@)'1H:7,M/E]M97-S86=E(#T@;F5W($U)345?365S<V%G92@I.PH*
M("`@("`@("`D:V]L86)?=&5X="`]('-P<FEN=&8H7R@B5&AI<R!I<R!A($MO
M;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U
M('=I;&P@;F5E9"!A;B!E;6%I;"!C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T
M:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H
M(&5M86EL(&-L:65N=',@<&QE87-E('9I<VET("5S(BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=H='1P.B\O=W=W+FMO;&%B+F]R9R]K;VQA
M8C(M8VQI96YT<RYH=&UL)RD["@H@("`@("`@("1P87)T(#T@;F5W($U)345?
M4&%R="@G=&5X="]P;&%I;B<L(%-T<FEN9SHZ=W)A<"@D:V]L86)?=&5X="P@
M-S8L($M/3$%"7TY%5TQ)3D4L($Y,4SHZ9V5T0VAA<G-E="@I*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@3DQ3.CIG971#:&%R<V5T*"DI.PH@
M("`@("`@("1P87)T+3YS9714<F%N<V9E<D5N8V]D:6YG*"=Q=6]T960M<')I
M;G1A8FQE)RD["B`@("`@("`@)'1H:7,M/E]M97-S86=E+3YA9&1087)T*"1P
M87)T*3L*"B`@("`@("`@)'!A<G0@/2!N97<@34E-15]087)T*"1T:&ES+3Y?
M;6EM95]T>7!E+"`G)RP@3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@("`@("1P
M87)T+3YS9714<F%N<V9E<D5N8V]D:6YG*"=Q=6]T960M<')I;G1A8FQE)RD[
M"B`@("`@("`@)'1H:7,M/E]M97-S86=E+3YA9&1087)T*"1P87)T*3L*"B`@
M("`@("`@)'!A<G1S(#T@)'1H:7,M/E]M97-S86=E+3YC;VYT96YT5'EP94UA
M<"@I.PH@("`@("`@(&EF("@H)'1H:7,M/E]M:6UE7VED(#T@87)R87E?<V5A
M<F-H*"1T:&ES+3Y?;6EM95]T>7!E+"`D<&%R=',I*2`]/3T@9F%L<V4I('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?
M*")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R
M('1H92!P87)T(&]F('1Y<&4@)7,B*2P@)'1H:7,M/E]M:6UE7W1Y<&4I*3L*
M("`@("`@("!]"@H@("`@("`@("1H96%D97)S(#T@;F5W($U)345?2&5A9&5R
M<R@I.PH@("`@("`@("1H96%D97)S+3YA9&1(96%D97(H)T9R;VTG+"!!=71H
M.CIG971!=71H*"DI.PH@("`@("`@("1H96%D97)S+3YA9&1(96%D97(H)U1O
M)RP@075T:#HZ9V5T075T:"@I*3L*("`@("`@("`D:&5A9&5R<RT^861D2&5A
M9&5R*"=3=6)J96-T)RP@)'5I9"D["B`@("`@("`@)&AE861E<G,M/F%D9$AE
M861E<B@G57-E<BU!9V5N="<L($M/3$%"7U!23T150U1?240I.PH@("`@("`@
M("1H96%D97)S+3YA9&1(96%D97(H)U)E<&QY+51O)RP@)R<I.PH@("`@("`@
M("1H96%D97)S+3YA9&1(96%D97(H)T1A=&4G+"!D871E*"=R)RDI.PH@("`@
M("`@("1H96%D97)S+3YA9&1(96%D97(H2T],04)?2$5!1$527U194$4L("1T
M:&ES+3Y?;6EM95]T>7!E*3L*("`@("`@("`D:&5A9&5R<RT^861D34E-14AE
M861E<G,H)'1H:7,M/E]M97-S86=E*3L*"B`@("`@("`@)'1H:7,M/E]H96%D
M97)S(#T@)&AE861E<G,M/G1O07)R87DH*3L*"B`@("`@("`@)'1H:7,M/E]X
M;6P@/2!D;VUX;6Q?;W!E;E]M96TH"B`@("`@("`@("`@("<\/WAM;"!V97)S
M:6]N/2(Q+C`B(&5N8V]D:6YG/2)55$8M."(_/B<@+@H@("`@("`@("`@("`G
M/"<@+B`D=&AI<RT^7V]B:F5C=%]T>7!E("X@)R!V97)S:6]N/2(Q+C`B/B<@
M+@H@("`@("`@("`@("`G/'5I9#XG("X@)'5I9"`N("<\+W5I9#XG("X*("`@
M("`@("`@("`@)SQB;V1Y/CPO8F]D>3XG("X*("`@("`@("`@("`@)SQC871E
M9V]R:65S/CPO8V%T96=O<FEE<SXG("X*("`@("`@("`@("`@)SQC<F5A=&EO
M;BUD871E/B<@+B!+;VQA8CHZ96YC;V1E1&%T951I;64H*2`N("<\+V-R96%T
M:6]N+61A=&4^)R`N"B`@("`@("`@("`@("<\<V5N<VET:79I='D^<'5B;&EC
M/"]S96YS:71I=FET>3XG("X*("`@("`@("`@("`@)SPO)R`N("1T:&ES+3Y?
M;V)J96-T7W1Y<&4@+B`G/B<L"B`@("`@("`@("`@($1/35A-3%],3T%$7U!!
M4E-)3D<@?"!$3TU834Q?3$]!1%]#3TU03$5415]!5%124R!\"B`@("`@("`@
M("`@($1/35A-3%],3T%$7U-50E-425155$5?14Y4251)15,@?"!$3TU834Q?
M3$]!1%]$3TY47TM%15!?0DQ!3DM3+`H@("`@("`@("`@("`D97)R;W(*("`@
M("`@("`I.PH@("`@("`@(&EF("@A96UP='DH)&5R<F]R*2D@>PH@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J
M96-T("5S(BDL("1U:60I*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?
M=6ED(#T@)'5I9#L*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?>&UL+3YD;V-U
M;65N=%]E;&5M96YT*"D["B`@("!]"@H@("`@9G5N8W1I;VX@<V%V94]B:F5C
M="@I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?:6UA<"DI('L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@
M)'1H:7,M/G-E=%9A;"@G;&%S="UM;V1I9FEC871I;VXM9&%T92<L($MO;&%B
M.CIE;F-O9&5$871E5&EM92@I*3L*("`@("`@("`D=&AI<RT^<V5T5F%L*"=P
M<F]D=6-T+6ED)RP@2T],04)?4%)/1%5#5%])1"D["@H@("`@("`@("1P87)T
M(#T@;F5W($U)345?4&%R="@D=&AI<RT^7VUI;65?='EP92P@)'1H:7,M/E]X
M;6PM/F1U;7!?;65M*'1R=64I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!.3%,Z.F=E=$-H87)S970H*2D["B`@("`@("`@)'!A<G0M/G-E=%1R
M86YS9F5R16YC;V1I;F<H)W%U;W1E9"UP<FEN=&%B;&4G*3L*("`@("`@("`D
M=&AI<RT^7VUE<W-A9V4M/F%L=&5R4&%R="@D=&AI<RT^7VUI;65?:60L("1P
M87)T*3L*"B`@("`@("`@:68@*"1T:&ES+3Y?;7-G7VYO("$]("TQ*2!["B`@
M("`@("`@("`@("1T:&ES+3YR96UO=F5/8FIE8W1S*"1T:&ES+3Y?;7-G7VYO
M+"!T<G5E*3L*("`@("`@("!]"@H@("`@("`@("1H96%D97)S(#T@;F5W($U)
M345?2&5A9&5R<R@I.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?:&5A9&5R
M<R!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@)&AE861E<G,M/F%D
M9$AE861E<B@D:V5Y+"`D=F%L*3L*("`@("`@("!]"@H@("`@("`@("1M97-S
M86=E(#T@2V]L86(Z.FMO;&%B3F5W;&EN97,H)&AE861E<G,M/G1O4W1R:6YG
M*"D@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]M97-S86=E+3YT;U-T<FEN9RAF86QS92DI.PH*("`@("`@("`D
M<F5S=6QT(#T@)'1H:7,M/E]I;6%P+3YA<'!E;F1-97-S86=E*"1M97-S86=E
M*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@
M("`@)'1H:7,M/E]M<V=?;F\@/2`D=&AI<RT^9FEN9$]B:F5C="@D=&AI<RT^
M7W5I9"D["B`@("`@("`@:68@*&ES7V$H)'1H:7,M/E]M<V=?;F\L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?;7-G7VYO
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M9G5N8W1I;VX@)F=E=$-U<G)E;G1/8FIE8W0H*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7WAM;"T^9&]C=6UE;G1?96QE;65N="@I.PH@("`@?0H*
M("`@(&9U;F-T:6]N("9G971%;&5M*"1N86UE+"`F)'!A<F5N="D*("`@('L*
M("`@("`@("`D96QE;65N=',@/2`F)'1H:7,M/F=E=$%L;$5L96US*"1N86UE
M+"`D<&%R96YT*3L*"B`@("`@("`@:68@*&5M<'1Y*"1E;&5M96YT<RDI('L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1E;&5M96YT<ULP73L*("`@('T*"B`@("!F=6YC=&EO;B`F9V5T
M06QL16QE;7,H)&YA;64L("8D<&%R96YT*0H@("`@>PH@("`@("`@(')E='5R
M;B`D<&%R96YT+3YG971?96QE;65N='-?8GE?=&%G;F%M92@D;F%M92D["B`@
M("!]"@H@("`@9G5N8W1I;VX@)F=E=%)O;W1%;&5M*"1N86UE*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^9V5T16QE;2@D;F%M92P@)'1H:7,M/F=E
M=$-U<G)E;G1/8FIE8W0H*2D["B`@("!]"@H@("`@9G5N8W1I;VX@)F=E=$%L
M;%)O;W1%;&5M<R@D;F%M92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/F=E=$%L;$5L96US*"1N86UE+"`D=&AI<RT^9V5T0W5R<F5N=$]B:F5C="@I
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!D96Q%;&5M*"1N86UE+"`F)'!A<F5N
M="D*("`@('L*("`@("`@("`D96QE;65N="`]("8D=&AI<RT^9V5T16QE;2@D
M;F%M92P@)'!A<F5N="D["B`@("`@("`@:68@*"1E;&5M96YT(#T]/2!F86QS
M92D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)'!A<F5N="T^<F5M;W9E7V-H:6QD*"1E;&5M96YT*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!D96Q!;&Q%;&5M<R@D;F%M92P@)B1P87)E;G0I"B`@
M("!["B`@("`@("`@)&5L96UE;G1S(#T@)B1T:&ES+3YG971!;&Q%;&5M<R@D
M;F%M92P@)'!A<F5N="D["B`@("`@("`@9F]R("@D:2`](#`L("1J(#T@8V]U
M;G0H)&5L96UE;G1S*3L@)&D@/"`D:CL@)&DK*RD@>PH@("`@("`@("`@("`D
M<&%R96YT+3YR96UO=F5?8VAI;&0H)&5L96UE;G1S6R1I72D["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N(&1E
M;$%L;%)O;W1%;&5M<R@D;F%M92D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/F1E;$%L;$5L96US*"1N86UE+"`D=&AI<RT^9V5T0W5R<F5N=$]B:F5C
M="@I*3L*("`@('T*"B`@("!F=6YC=&EO;B!D96Q2;V]T16QE;2@F)&5L96UE
M;G0I"B`@("!["B`@("`@("`@:68@*"1E;&5M96YT(#T]/2!F86QS92D@>PH@
M("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`D<F]O="`]
M("8D=&AI<RT^9V5T0W5R<F5N=$]B:F5C="@I.PH@("`@("`@(')E='5R;B`D
M<F]O="T^<F5M;W9E7V-H:6QD*"1E;&5M96YT*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!G971%;&5M5F%L*"8D<&%R96YT+"`D;F%M92P@)&1E9F%U;'0@/2`P
M*0H@("`@>PH@("`@("`@(&EF("@D<&%R96YT(#T]/2!F86QS92D@>PH@("`@
M("`@("`@("!R971U<FX@)&1E9F%U;'0["B`@("`@("`@?0H*("`@("`@("`D
M96QE;65N="`]("8D=&AI<RT^9V5T16QE;2@D;F%M92P@)'!A<F5N="D["B`@
M("`@("`@:68@*"1E;&5M96YT(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R
M971U<FX@)&1E9F%U;'0["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&5L
M96UE;G0M/F=E=%]C;VYT96YT*"D["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T
M16QE;5-T<B@F)'!A<F5N="P@)&YA;64L("1D969A=6QT(#T@)R<I"B`@("![
M"B`@("`@("`@:68@*"1P87)E;G0@/3T](&9A;'-E*2!["B`@("`@("`@("`@
M(')E='5R;B`D9&5F875L=#L*("`@("`@("!]"@H@("`@("`@("1E;&5M96YT
M(#T@)B1T:&ES+3YG971%;&5M*"1N86UE+"`D<&%R96YT*3L*("`@("`@("!I
M9B`H)&5L96UE;G0@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;B`D
M9&5F875L=#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!3=')I;F<Z.F-O
M;G9E<G1#:&%R<V5T*"1E;&5M96YT+3YG971?8V]N=&5N="@I+"`G=71F+3@G
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!G971686PH)&YA;64L("1D969A=6QT
M(#T@,"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F=E=$5L96U686PH
M)'1H:7,M/F=E=$-U<G)E;G1/8FIE8W0H*2P@)&YA;64L("1D969A=6QT*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!G9713='(H)&YA;64L("1D969A=6QT(#T@
M)R<I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YG971%;&5M4W1R*"1T
M:&ES+3YG971#=7)R96YT3V)J96-T*"DL("1N86UE+"`D9&5F875L="D["B`@
M("!]"@H@("`@9G5N8W1I;VX@)FEN:71%;&5M*"1N86UE+"`F)'!A<F5N="D*
M("`@('L*("`@("`@("!I9B`H)'!A<F5N="`]/3T@9F%L<V4I('L*("`@("`@
M("`@("`@)'!A<F5N="`]("1T:&ES+3YG971#=7)R96YT3V)J96-T*"D["B`@
M("`@("`@?0H*("`@("`@("`D96QE;65N="`]("1T:&ES+3YG971%;&5M*"1N
M86UE+"`D<&%R96YT*3L*"B`@("`@("`@:68@*"1E;&5M96YT(#T]/2!F86QS
M92D@>PH@("`@("`@("`@("`D96QE;65N="`]("1P87)E;G0M/F%P<&5N9%]C
M:&EL9"@D=&AI<RT^7WAM;"T^8W)E871E7V5L96UE;G0H)&YA;64I*3L*("`@
M("`@("!]"@H@("`@("`@("1C:&EL9')E;B`]("1E;&5M96YT+3YC:&EL9%]N
M;V1E<R@I.PH@("`@("`@(&9O<F5A8V@@*"1C:&EL9')E;B!A<R`D8VAI;&0I
M('L*("`@("`@("`@("`@:68@*"1C:&EL9"T^;F]D95]T>7!E*"D@/3T@6$U,
M7U1%6%1?3D]$12D@>PH@("`@("`@("`@("`@("`@)&5L96UE;G0M/G)E;6]V
M95]C:&EL9"@D8VAI;&0I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)&5L96UE;G0["B`@("!]"@H@("`@9G5N8W1I;VX@)FEN
M:712;V]T16QE;2@D;F%M92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/FEN:71%;&5M*"1N86UE+"`D=&AI<RT^9V5T0W5R<F5N=$]B:F5C="@I*3L*
M("`@('T*"B`@("!F=6YC=&EO;B`F87!P96YD16QE;2@D;F%M92P@)B1P87)E
M;G0I"B`@("!["B`@("`@("`@<F5T=7)N("1P87)E;G0M/F%P<&5N9%]C:&EL
M9"@D=&AI<RT^7WAM;"T^8W)E871E7V5L96UE;G0H)&YA;64I*3L*("`@('T*
M"B`@("!F=6YC=&EO;B`F87!P96YD4F]O=$5L96TH)&YA;64I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3YA<'!E;F1%;&5M*"1N86UE+"`D=&AI<RT^
M9V5T0W5R<F5N=$]B:F5C="@I*3L*("`@('T*"B`@("!F=6YC=&EO;B`F<V5T
M16QE;59A;"@F)'!A<F5N="P@)&YA;64L("1V86QU92`]("<G*0H@("`@>PH@
M("`@("`@("1E;&5M96YT(#T@)B1T:&ES+3YI;FET16QE;2@D;F%M92P@)'!A
M<F5N="D["B`@("`@("`@)&5L96UE;G0M/G-E=%]C;VYT96YT*"1V86QU92D[
M"@H@("`@("`@(')E='5R;B`D96QE;65N=#L*("`@('T*"B`@("!F=6YC=&EO
M;B`F<V5T16QE;5-T<B@F)'!A<F5N="P@)&YA;64L("1V86QU92`]("<G*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<V5T16QE;59A;"@D<&%R96YT
M+"`D;F%M92P@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D=F%L=64L($Y,4SHZ
M9V5T0VAA<G-E="@I+"`G=71F+3@G*2D["B`@("!]"@H@("`@9G5N8W1I;VX@
M)G-E=%9A;"@D;F%M92P@)'9A;'5E(#T@)R<I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3YS971%;&5M5F%L*"1T:&ES+3YG971#=7)R96YT3V)J96-T
M*"DL("1N86UE+"`D=F%L=64I.PH@("`@?0H*("`@(&9U;F-T:6]N("9S9713
M='(H)&YA;64L("1V86QU92`]("<G*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^<V5T16QE;5-T<B@D=&AI<RT^9V5T0W5R<F5N=$]B:F5C="@I+"`D
M;F%M92P@)'9A;'5E*3L*("`@('T*"B\O(%5T:6QI='D@;&EB<F%R>2!I;G1E
M<F9A8V4*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!S=')I;F<@8V]N=&%I
M;FEN9R!T:&4@8W5R<F5N="!55$,@9&%T92!I;B!T:&4@9F]R;6%T"B`@("`@
M*B!P<F5S8W)I8F5D(&)Y('1H92!+;VQA8B!&;W)M870@4W!E8VEF:6-A=&EO
M;BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-U<G)E;G0@
M551#(&1A=&4@:6X@=&AE(&9O<FUA="`G65E962U-32U$1"<N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&5N8V]D941A=&4H)&1A=&4@/2!F86QS92D*("`@('L*
M("`@("`@("!I9B`H)&1A=&4@/3T](#`I('L*("`@("`@("`@("`@<F5T=7)N
M(#`["B`@("`@("`@?0H@("`@("`@(')E='5R;B!S=')F=&EM92@G)5DM)6TM
M)60G+"`D9&%T92`]/3T@9F%L<V4@/R!T:6UE*"D@.B`D9&%T92D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@54Y)6"!T:6UE<W1A;7`@8V]R
M<F5S<&]N9&EN9R!T:&4@9VEV96X@9&%T92!S=')I;F<@=VAI8V@@:7,@:6X*
M("`@("`J('1H92!F;W)M870@<')E<V-R:6)E9"!B>2!T:&4@2V]L86(@1F]R
M;6%T(%-P96-I9FEC871I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9&%T92`@5&AE('-T<FEN9R!R97!R97-E;G1A=&EO;B!O9B!T:&4@9&%T
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!U;FEX('1I
M;65S=&%M<"!C;W)R97-P;VYD:6YG('1O("1D871E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!D96-O9&5$871E*"1D871E*0H@("`@>PH@("`@("`@(&EF("AE
M;7!T>2@D9&%T92DI('L*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@
M?0H*("`@("`@("!L:7-T*"1Y96%R+"`D;6]N=&@L("1D87DI(#T@97AP;&]D
M92@G+2<L("1D871E*3L*("`@("`@("!R971U<FX@;6MT:6UE*#`L(#`L(#`L
M("1M;VYT:"P@)&1A>2P@)'EE87(I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!A('-T<FEN9R!C;VYT86EN:6YG('1H92!C=7)R96YT(%540R!D
M871E(&%N9"!T:6UE(&EN('1H92!F;W)M870*("`@("`J('!R97-C<FEB960@
M8GD@=&AE($MO;&%B($9O<FUA="!3<&5C:69I8V%T:6]N+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("`@(%1H92!C=7)R96YT(%540R!D871E(&%N
M9"!T:6UE(&EN('1H92!F;W)M870*("`@("`J("`@("`@("`@("`@("`@("`@
M("=965E9+4U-+41$5&AH.FUM.G-S6B<L('=H97)E('1H92!4(&%N9"!:(&%R
M92!L:71E<F%L"B`@("`@*B`@("`@("`@("`@("`@("`@("!C:&%R86-T97)S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!E;F-O9&5$871E5&EM92@D9&%T971I
M;64@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H)&1A=&5T:6UE(#T]/2`P
M*2!["B`@("`@("`@("`@(')E='5R;B`P.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@9VUS=')F=&EM92@G)5DM)6TM)614)4@Z)4TZ)5-:)RP@)&1A=&5T
M:6UE(#T]/2!F86QS92`_('1I;64H*2`Z("1D871E=&EM92D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS(&$@54Y)6"!T:6UE<W1A;7`@8V]R<F5S
M<&]N9&EN9R!T:&4@9VEV96X@9&%T92UT:6UE('-T<FEN9R!W:&EC:`H@("`@
M("H@:7,@:6X@=&AE(&9O<FUA="!P<F5S8W)I8F5D(&)Y('1H92!+;VQA8B!&
M;W)M870@4W!E8VEF:6-A=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1D871E=&EM92`@5&AE('-T<FEN9R!R97!R97-E;G1A=&EO;B!O9B!T
M:&4@9&%T92`F('1I;64N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R
M("!4:&4@=6YI>"!T:6UE<W1A;7`@8V]R<F5S<&]N9&EN9R!T;R`D9&%T971I
M;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E8V]D941A=&54:6UE*"1D871E
M=&EM92D*("`@('L*("`@("`@("!I9B`H96UP='DH)&1A=&5T:6UE*2D@>PH@
M("`@("`@("`@("!R971U<FX@,#L*("`@("`@("!]"@H@("`@("`@(&QI<W0H
M)'EE87(L("1M;VYT:"P@)&1A>2P@)&AO=7(L("1M:6YU=&4L("1S96-O;F0I
M"B`@("`@("`@("`@(#T@<W-C86YF*"1D871E=&EM92P@)R5D+25D+25D5"5D
M.B5D.B5D6B<I.PH@("`@("`@(')E='5R;B!G;6UK=&EM92@D:&]U<BP@)&UI
M;G5T92P@)'-E8V]N9"P@)&UO;G1H+"`D9&%Y+"`D>65A<BD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS(&$@54Y)6"!T:6UE<W1A;7`@8V]R<F5S
M<&]N9&EN9R!T:&4@9VEV96X@9&%T92!O<B!D871E+71I;64*("`@("`J('-T
M<FEN9R!W:&EC:"!I<R!I;B!E:71H97(@9F]R;6%T('!R97-C<FEB960@8GD@
M=&AE($MO;&%B($9O<FUA=`H@("`@("H@4W!E8VEF:6-A=&EO;BX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871E("!4:&4@<W1R:6YG(')E<')E
M<V5N=&%T:6]N(&]F('1H92!D871E("@F('1I;64I+@H@("`@("H*("`@("`J
M($!R971U<FX@:6YT96=E<B`@5&AE('5N:7@@=&EM97-T86UP(&-O<G)E<W!O
M;F1I;F<@=&\@)&1A=&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E8V]D941A
M=&5/<D1A=&54:6UE*"1D871E*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D
M9&%T92DI('L*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@*'-T<FQE;B@D9&%T92D@/3T@,3`@/R!+;VQA8CHZ9&5C
M;V1E1&%T92@D9&%T92D@.B!+;VQA8CHZ9&5C;V1E1&%T951I;64H)&1A=&4I
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!D96-O9&5&=6QL1&%Y1&%T92@D9&%T
M92D*("`@('L*("`@("`@("!I9B`H96UP='DH)&1A=&4I*2!["B`@("`@("`@
M("`@(')E='5R;B`P.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("AS=')L
M96XH)&1A=&4I(#T](#$P(#\@2V]L86(Z.F1E8V]D941A=&4H)&1A=&4I*S(T
M*C8P*C8P(#H@2V]L86(Z.F1E8V]D941A=&54:6UE*"1D871E*2D["B`@("!]
M"@H@("`@9G5N8W1I;VX@<&5R8V5N=&%G951O0F]O;&5A;B@D<&5R8V5N=&%G
M92D*("`@('L*("`@("`@("!R971U<FX@)'!E<F-E;G1A9V4@/3T@,3`P(#\@
M)S$G(#H@)S`G.PH@("`@?0H*("`@(&9U;F-T:6]N(&)O;VQE86Y4;U!E<F-E
M;G1A9V4H)&)O;VQE86XI"B`@("!["B`@("`@("`@<F5T=7)N("1B;V]L96%N
M(#\@)S$P,"<@.B`G,"<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T
M<R!A('-T<FEN9R!I;B!T:&4@8W5R<F5N="!C:&%R86-T97(@<V5T('1O(&%N
M($E-05`@551&+3<@<W1R:6YG+`H@("`@("H@<W5I=&%B;&4@9F]R('5S92!A
M<R!T:&4@;F%M92!O9B!A;B!)34%0(&9O;&1E<BX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1N86UE("!4:&4@=&5X="!I;B!T:&4@8W5R<F5N="!C
M:&%R86-T97(@<V5T('1O(&-O;G9E<G0N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@("`@)&YA;64@96YC;V1E9"!I;B!T:&4@24U!4"!V87)I871I
M;VX@;V8@551&+3<N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N8V]D94EM87!&
M;VQD97).86UE*"1N86UE*0H@("`@>PH@("`@("`@(')E='5R;B!3=')I;F<Z
M.F-O;G9E<G1#:&%R<V5T*"1N86UE+"!.3%,Z.F=E=$-H87)S970H*2P@)U54
M1C<M24U!4"<I.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R=',@82!S
M=')I;F<@:6X@=&AE($E-05`@=F%R:6%T:6]N(&]F(%541BTW(&EN=&\@82!S
M=')I;F<@:6X@=&AE"B`@("`@*B!C=7)R96YT(&-H87)A8W1E<B!S970N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE('1E>'0@:6X@
M24U!4"!55$8M-R!T;R!C;VYV97)T+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("`@("1N86UE(&5N8V]D960@:6X@=&AE(&-U<G)E;G0@8VAA<F%C
M=&5R('-E="X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5C;V1E26UA<$9O;&1E
M<DYA;64H)&YA;64I"B`@("!["B`@("`@("`@<F5T=7)N(%-T<FEN9SHZ8V]N
M=F5R=$-H87)S970H)&YA;64L("=55$8W+4E-05`G*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($-O;G9E<G1S(&%L;"!N97=L:6YE<R`H:6X@1$]3+"!-04,@
M)B!53DE8(&9O<FUA="D@:6X@=&AE('-P96-I9FEE9"!T97AT"B`@("`@*B!T
M;R!U;FEX+7-T>6QE("A,1BD@9F]R;6%T+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'1E>'0@(%1H92!T97AT('1O(&-O;G9E<G0N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@("1T97AT('=I=&@@86QL(&YE=VQI;F5S
M(')E<&QA8V5D(&)Y($Q&+@H@("`@("HO"B`@("!F=6YC=&EO;B!U;FEX3F5W
M;&EN97,H)'1E>'0I"B`@("!["B`@("`@("`@<F5T=7)N('!R96=?<F5P;&%C
M92@B+UQR7&Y\7&Y\7'(O<R(L(")<;B(L("1T97AT*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($-O;G9E<G1S(&%L;"!N97=L:6YE<R`H:6X@1$]3+"!-04,@
M)B!53DE8(&9O<FUA="D@:6X@=&AE('-P96-I9FEE9"!T97AT"B`@("`@*B!T
M;R!+;VQA8B`H0WER=7,I(&9O<FUA="X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1T97AT("!4:&4@=&5X="!T;R!C;VYV97)T+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("`D=&5X="!W:71H(&%L;"!N97=L:6YE<R!R
M97!L86-E9"!B>2!+3TQ!0E].15=,24Y%+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!K;VQA8DYE=VQI;F5S*"1T97AT*0H@("`@>PH@("`@("`@(')E='5R;B!P
M<F5G7W)E<&QA8V4H(B]<<EQN?%QN?%QR+W,B+"!+3TQ!0E].15=,24Y%+"`D
M=&5X="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!U;F9O
M;&1E9"!R97!R97-E;G1A=&EO;B!O9B!T:&4@9VEV96X@=&5X="X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("!4:&4@=&5X="!T;R!U;F9O
M;&0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!U;F9O;&1E
M9"!R97!R97-E;G1A=&EO;B!O9B`D=&5X="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@=6YF;VQD5&5X="@D=&5X="D*("`@('L*("`@("`@("!R971U<FX@<')E
M9U]R97!L86-E*"(O7')<;EL@7'1=*R\B+"`B(BP@)'1E>'0I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!A<G)A>2!O9B!A<'!L:6-A=&EO
M;BUS<&5C:69I8R!C;VYS=&%N=',L('1H870@87)E('5S960@:6X*("`@("`J
M(&$@9V5N97)I8R!M86YN97(@=&AR;W5G:&]U="!T:&4@;&EB<F%R>2X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@(%1H92!A<'!L:6-A=&EO
M;B!W:&]S92!C;VYS=&%N=',@=&\@<75E<GDN"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@06X@87)R87D@;V8@87!P;&EC871I;VXM<W!E8VEF:6,@
M8V]N<W1A;G1S(&EF("1A<'`@:7,@80H@("`@("H@("`@("`@("`@("`@("`@
M<W5P<&]R=&5D(&%P<&QI8V%T:6]N+"!O<B!A(%!%05)?17)R;W(@;V)J96-T
M(&EF("1A<'`@:7,*("`@("`J("`@("`@("`@("`@("`@(&YO="!S=7!P;W)T
M960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%P<$-O;G-T<R@D87!P*0H@
M("`@>PH@("`@("`@('-W:71C:"`H)&%P<"D@>PH@("`@("`@(&-A<V4@)VUN
M96UO)SH*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*`H@("`@("`@("`@("`@
M("`@)VUI;65?='EP95]S=69F:7@G("`@("`@/3X@)VYO=&4G+`H@("`@("`@
M("`@("`@("`@)V1E9F%U;'1?9F]L9&5R7VYA;64G("`@/3X@7R@B3F]T97,B
M*2P*("`@("`@("`@("`@("`@("=S:&%R95]N86UE)R`@("`@("`@("`@(#T^
M(%\H(FYO=&5P860B*2P*("`@("`@("`@("`@("`@("=D969A=6QT7W-H87)E
M7VYA;64G("`@(#T^(%\H(B5S)W,@3F]T97!A9"(I+`H@("`@("`@("`@("`I
M.PH*("`@("`@("!C87-E("=K<F]N;VQI=&@G.@H@("`@("`@("`@("!R971U
M<FX@87)R87DH"B`@("`@("`@("`@("`@("`G;6EM95]T>7!E7W-U9F9I>"<@
M("`@("`]/B`G979E;G0G+`H@("`@("`@("`@("`@("`@)V1E9F%U;'1?9F]L
M9&5R7VYA;64G("`@/3X@7R@B0V%L96YD87(B*2P*("`@("`@("`@("`@("`@
M("=S:&%R95]N86UE)R`@("`@("`@("`@(#T^(%\H(F-A;&5N9&%R(BDL"B`@
M("`@("`@("`@("`@("`G9&5F875L=%]S:&%R95]N86UE)R`@("`]/B!?*"(E
M<R=S($-A;&5N9&%R(BDL"B`@("`@("`@("`@("D["@H@("`@("`@(&-A<V4@
M)W1U<F)A)SH*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*`H@("`@("`@("`@
M("`@("`@)VUI;65?='EP95]S=69F:7@G("`@("`@/3X@)V-O;G1A8W0G+`H@
M("`@("`@("`@("`@("`@)V1E9F%U;'1?9F]L9&5R7VYA;64G("`@/3X@7R@B
M0V]N=&%C=',B*2P*("`@("`@("`@("`@("`@("=S:&%R95]N86UE)R`@("`@
M("`@("`@(#T^(%\H(F%D9')E<W,@8F]O:R(I+`H@("`@("`@("`@("`@("`@
M)V1E9F%U;'1?<VAA<F5?;F%M92<@("`@/3X@7R@B)7,G<R!!9&1R97-S($)O
M;VLB*2P*("`@("`@("`@("`@*3L*"B`@("`@("`@8V%S92`G;F%G)SH*("`@
M("`@("`@("`@<F5T=7)N(&%R<F%Y*`H@("`@("`@("`@("`@("`@)VUI;65?
M='EP95]S=69F:7@G("`@("`@/3X@)W1A<VLG+`H@("`@("`@("`@("`@("`@
M)V1E9F%U;'1?9F]L9&5R7VYA;64G("`@/3X@7R@B5&%S:W,B*2P*("`@("`@
M("`@("`@("`@("=S:&%R95]N86UE)R`@("`@("`@("`@(#T^(%\H(G1A<VL@
M;&ES="(I+`H@("`@("`@("`@("`@("`@)V1E9F%U;'1?<VAA<F5?;F%M92<@
M("`@/3X@7R@B)7,G<R!487-K;&ES="(I+`H@("`@("`@("`@("`I.PH*("`@
M("`@("!D969A=6QT.@H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BAS<')I;G1F*%\H(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E
M;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B*2P@)&%P<"DI.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86X@24U!4"!!
M0TP@<W1R:6YG(&-O<G)E<W!O;F1I;F<@=&\@=&AE(&=I=F5N($AO<F1E('!E
M<FUI<W-I;VYS"B`@("`@*B!V86QU92X*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D<&5R;7,@(%1H92!(;W)D92!P97)M:7-S:6]N<R!V86QU92X*
M("`@("`J($!P87)A;2!B;V]L96%N("1O=VYE<B`@5VEL;"!T:&4@04-,('-T
M<FEN9R!B92!U<V5D(&9O<B!T:&4@9F]L9&5R(&]W;F5R/PH@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("!4:&ES(&EN8VQU9&5S('1H92`G82<@<FEG
M:'1S(&EN('1H92!!0TP@<W1R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@24U!4"!!0TP@<W1R:6YG(&-O<G)E<W!O;F1I;F<@=&\@
M)'!E<FUS(&%N9"`D;W=N97(N"B`@("`@*B\*("`@(&9U;F-T:6]N('!E<FUS
M5&]!0TPH)'!E<FUS+"`D;W=N97(@/2!T<G5E*0H@("`@>PH@("`@("`@("1R
M97-U;'0@/2`D;W=N97(@/R`G82<@.B`G)SL*("`@("`@("!I9B`H)'!E<FUS
M("8@4$5235-?4TA/5RD@>PH@("`@("`@("`@("`D<F5S=6QT("X]("=L)SL*
M("`@("`@("!]"B`@("`@("`@:68@*"1P97)M<R`F(%!%4DU37U)%040I('L*
M("`@("`@("`@("`@)')E<W5L="`N/2`G<B<["B`@("`@("`@?0H@("`@("`@
M(&EF("@D<&5R;7,@)B!015)-4U]%1$E4*2!["B`@("`@("`@("`@("1R97-U
M;'0@+CT@)VES=V,G.PH@("`@("`@('T*("`@("`@("!I9B`H)'!E<FUS("8@
M4$5235-?1$5,151%*2!["B`@("`@("`@("`@("1R97-U;'0@+CT@)V0G.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS(&$@2&]R9&4@<&5R;6ES<VEO;G,@=F%L=64@
M8V]R<F5S<&]N9&EN9R!T;R!T:&4@9VEV96X@24U!4"!!0TP*("`@("`J('-T
M<FEN9RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A8VQ?<W1R:6YG
M("!4:&4@24U!4"!!0TP@<W1R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@
M:6YT96=E<B`@5&AE($AO<F1E('!E<FUI<W-I;VYS('9A;'5E(&-O<G)E<W!O
M;F1I;F<@=&\*("`@("`J("`@("`@("`@("`@("`@("`@)&%C;%]S=')I;F<N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&%C;%1O4&5R;7,H)&%C;%]S=')I;F<I
M"B`@("!["B`@("`@("`@)')E<W5L="`](#`["@H@("`@("`@(&9O<B`H)&D@
M/2`P+"`D:B`]('-T<FQE;B@D86-L7W-T<FEN9RD[("1I(#P@)&H[("1I*RLI
M('L*("`@("`@("`@("`@<W=I=&-H("@D86-L7W-T<FEN9ULD:5TI('L*("`@
M("`@("`@("`@8V%S92`G;"<Z"B`@("`@("`@("`@("`@("`D<F5S=6QT('P]
M(%!%4DU37U-(3U<["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&-A<V4@)W(G.@H@("`@("`@("`@("`@("`@)')E<W5L="!\/2!015)-
M4U]214%$.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C
M87-E("=I)SH*("`@("`@("`@("`@("`@("1R97-U;'0@?#T@4$5235-?141)
M5#L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G
M9"<Z"B`@("`@("`@("`@("`@("`D<F5S=6QT('P](%!%4DU37T1%3$5413L*
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O*BH*("`@
M("`J($-R96%T97,@86X@87-S;V-I871I=F4@87)R87D@;W5T(&]F(&%N($E-
M05`@04-,(&QI<W0@87,@<F5T=7)N960@8GD@=&AE"B`@("`@*B!.971?24U!
M4"!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1A8VP@(%1H
M92!)34%0($%#3"!A<G)A>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!!;B!A<W-O8VEA=&EV92!A<G)A>2P@=VAE<F4@=&AE(&ME>7,@87)E(&EN
M9&EV:61U86P@=7-E<G,*("`@("`J("`@("`@("`@("`@("`@(&%N9"!T:&4@
M=F%L=65S('1H92!!0TP@<W1R:6YG(&9O<B!T:&4@<W!E8VEF:6,@=7-E<BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@86-L5&]!<G)A>2@D86-L*0H@("`@>PH@
M("`@("`@(&EF("AI<U]A*"1A8VPL("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1A8VP["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT
M(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D86-L(&%S("1U<V5R*2![
M"B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O9W)O=7`Z*"XK*2\G+"`D
M=7-E<ELG55-%4B==+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@("`@("\J
M($QO;VL@=7`@86YD(&5X<&%N9"!G<F]U<',N("HO"B`@("`@("`@("`@("`@
M("!R97%U:7)E7V]N8V4@)TAO<F1E+T=R;W5P+G!H<"<["B`@("`@("`@("`@
M("`@("`D9W)O=7`@/2`F1W)O=7`Z.G-I;F=L971O;B@I.PH@("`@("`@("`@
M("`@("`@)&=I9"`]("1G<F]U<"T^9V5T1W)O=7!)9"@D;6%T8VAE<ULQ72D[
M"B`@("`@("`@("`@("`@("`D=7-E<G,@/2`D9W)O=7`M/FQI<W15<V5R<R@D
M9VED*3L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1U<V5R<R!A<R`D=2D@
M>PH@("`@("`@("`@("`@("`@("`@("1R97-U;'1;)'5=(#T@)'5S97);)U))
M1TA44R==.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)')E<W5L=%LD=7-E<ELG55-%4B==72`]("1U
M<V5R6R=224=(5%,G73L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T4VAA
M<F5-87`H*0H@("`@>PH@("`@("`@(')E='5R;B!E;7!T>2@D7U-%4U-)3TY;
M2T],04)?4TA!4D5?34%072D*("`@("`@("`@(#\@87)R87DH*0H@("`@("`@
M("`@.B!U;G-E<FEA;&EZ92@D7U-%4U-)3TY;2T],04)?4TA!4D5?34%072D[
M"B`@("!]"@H@("`@9G5N8W1I;VX@<V5T4VAA<F5-87`H)'-H87)E7VUA<"D*
M("`@('L*("`@("`@("`D7U-%4U-)3TY;2T],04)?4TA!4D5?34%072`]('-E
M<FEA;&EZ92@D<VAA<F5?;6%P*3L*("`@('T*"B`@("!F=6YC=&EO;B!U<&1A
M=&5-87!P9613:&%R92@F)'-H87)E7VUA<"P@)'-H87)E7W5I9"P@)&EM87!?
M9F]L9&5R*0H@("`@>PH@("`@("`@("1S:&%R95]M87!;)'-H87)E7W5I9%T@
M/2`D:6UA<%]F;VQD97(["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T4VAA<F5-
M87!P:6YG*"8D<VAA<F5?;6%P+"`D<VAA<F5?=6ED+"`D9&YE7W)E<W5L="`]
M("<G*0H@("`@>PH@("`@("`@(')E='5R;B!E;7!T>2@D<VAA<F5?;6%P6R1S
M:&%R95]U:61=*2`_("1D;F5?<F5S=6QT(#H@)'-H87)E7VUA<%LD<VAA<F5?
M=6ED73L*("`@('T*"B`@("!F=6YC=&EO;B!R96UO=F5-87!P9613:&%R92@F
M)'-H87)E7VUA<"P@)'-H87)E7W5I9"D*("`@('L*("`@("`@("!I9B`H:7-S
M970H)'-H87)E7VUA<%LD<VAA<F5?=6ED72DI('L*("`@("`@("`@("`@=6YS
M970H)'-H87)E7VUA<%LD<VAA<F5?=6ED72D["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@4WEN8VAR;VYI<V5S('1H92!097)M<R!O9B!A($AO
M<F1E('-H87)E('1O('1H92!!0TP@;V8@86X@24U!4"!F;VQD97(L"B`@("`@
M*B!C<F5A=&EN9R!T:&4@9F]L9&5R(&EF(&YE8V5S<V%R>2X@270@86QS;R!S
M971S('1H92!N96-E<W-A<GD@86YN;W1A=&EO;G,*("`@("`J(&EN9&EC871I
M;F<@=VAA="!G<F]U<'=A<F4@9F]R;6%T('1Y<&4@:7,@8V]N=&%I;F5D('=I
M=&AI;B!T:&4@9F]L9&5R+`H@("`@("H@86YD('=H870@2&]R9&4@<VAA<F4@
M:70@8V]R<F5S<&]N9',@=&\N"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C
M="`D:6UA<"`@($$@<F5F97)E;F-E('1O(&$@3F5T7TE-05`@;V)J96-T('1H
M870@:7,@86QR96%D>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&-O
M;FYE8W1E9"!A;F0@875T:&5N=&EC871E9"!T;R!T:&4@8V]R<F5C="!S97)V
M97(N"B`@("`@*B!`<&%R86T@;V)J96-T("1S:&%R92`@02!R969E<F5N8V4@
M=&\@=&AE($AO<F1E('-H87)E(&]B:F5C="!T:&%T('=E(&%R90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@(&EN=&5R97-T960@:6XN"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1A<'!?8V]N<W1S("!!(')E9F5R96YC92!T;R!T:&4@
M<F5S=6QT(&]F(&$@9V5T07!P0V]N<W1S*"D*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&-A;&P@9F]R('1H92!C=7)R96YT($AO<F1E(&%P
M<&QI8V%T:6]N+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@($AO<F1E
M+TMO;&%B(&EN=&5G<F%T:6]N+7-U<'!O<G1E9"!A<'`N"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S+"!A(%!%05)?17)R
M;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-Y
M;F-H<F]N:7-E4VAA<F4H)B1I;6%P+"`F)'-H87)E+"`F)&%P<%]C;VYS=',I
M"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("!I9B`H96UP
M='DH)'-H87)E*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BA?*"));G9A;&ED('-H87)E(&]B:F5C="(I*3L*("`@("`@("!]"@H@
M("`@("`@("1S:&%R95]U:60@/2`D<VAA<F4M/F=E=$YA;64H*3L*("`@("`@
M("`D;W=N97(@/2`D<VAA<F4M/F=E="@G;W=N97(G*3L*("`@("`@("`D9&5F
M875L="`]("1S:&%R95]U:60@/3T@)&]W;F5R.PH*("`@("`@("`D;F1X(#T@
M<W1R<&]S*"1O=VYE<BP@)T`G*3L*("`@("`@("`D=7-E<B`]("1N9'@@/3T]
M(&9A;'-E(#\@)&]W;F5R(#H@<W5B<W1R*"1O=VYE<BP@,"P@)&YD>"D["B`@
M("`@("`@)&1O;6%I;B`]('-T<G-T<B@D;W=N97(L("=`)RD["@H@("`@("`@
M("1F;VQD97)?='EP92`]("1A<'!?8V]N<W1S6R=M:6UE7W1Y<&5?<W5F9FEX
M)UT@+B`H)&1E9F%U;'0@/R`G+F1E9F%U;'0G(#H@)R<I.PH@("`@("`@("1F
M;VQD97)?;F%M92`](")U<V5R+R1U<V5R+R(@+B`H)&1E9F%U;'0@/R`D87!P
M7V-O;G-T<ULG9&5F875L=%]F;VQD97)?;F%M92==(#H@)'-H87)E+3YG970H
M)VYA;64G*2D@+B`D9&]M86EN.PH@("`@("`@("\O2V]L86(Z.F5N8V]D94EM
M87!&;VQD97).86UE*"1D969A=6QT(#\@)&%P<%]C;VYS='-;)V1E9F%U;'1?
M9F]L9&5R7VYA;64G72`Z("1S:&%R92T^9V5T*"=N86UE)RDI.PH@("`@("`@
M(&EF("AI<U]A*"1F;VQD97)?;F%M92P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)&9O;&1E<E]N86UE.PH@("`@("`@('T*"B`@("`@
M("`@)'-H87)E7VUA<"`]($MO;&%B.CIG9713:&%R94UA<"@I.PH*("`@("`@
M("`D;VQD7V9O;&1E<B`]($MO;&%B.CIG9713:&%R94UA<'!I;F<H)'-H87)E
M7VUA<"P@)'-H87)E7W5I9"D["@H@("`@("`@("1R97-U;'0@/2`D:6UA<"T^
M;6%I;&)O>$5X:7-T*"1F;VQD97)?;F%M92D["B`@("`@("`@:68@*&ES7V$H
M)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@(&EF("@D9F]L9&5R7VYA;64@
M(3T@)&]L9%]F;VQD97(I('L*("`@("`@("`@("`@:68@*"1R97-U;'0@)B8@
M)&]L9%]F;VQD97(I('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O(')E;F%M92`E<R!T;R`E
M<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S(BDL("1F;VQD
M97)?;F%M92P@)&]L9%]F;VQD97(I*3L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@:68@*"1O;&1?9F]L9&5R*2!["B`@("`@("`@("`@("`@("`D<F5S
M=6QT(#T@)&EM87`M/G)E;F%M94UA:6QB;W@H)&]L9%]F;VQD97(L("1F;VQD
M97)?;F%M92D["B`@("`@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS96EF
M("@D<F5S=6QT(#T]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@)')E<W5L
M="`]("1I;6%P+3YC<F5A=&5-86EL8F]X*"1F;VQD97)?;F%M92D["B`@("`@
M("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O
M($=R86YT('1H92!#>7)U<R!!9&UI;FES=')A=&]R(&-R96%T92`F(&1E;&5T
M92!A8V-E<W,@*&YE961E9`H@("`@("`@("\O(&9O<B!T:&4@861M:6YU<V5R
M('1O(&1E;&5T92!T:&4@;6%I;&)O>"!W:&5N(')E;6]V:6YG('-H87)E<RD*
M("`@("`@("`D<F5S=6QT(#T@)&EM87`M/G-E=$%#3"@D9F]L9&5R7VYA;64L
M("1C;VYF6R=K;VQA8B==6R=I;6%P)UU;)V%D;6EN=7-E<B==+"`G8V0G*3L*
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@
M)&%C;"`]($MO;&%B.CIA8VQ4;T%R<F%Y*"1I;6%P+3YG971!0TPH)&9O;&1E
M<E]N86UE*2D["B`@("`@("`@:68@*&ES7V$H)&%C;"P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&%C;#L*("`@("`@("!]"@H@("`@
M("`@("1P97)M(#T@)B1S:&%R92T^9V5T4&5R;6ES<VEO;B@I.PH@("`@("`@
M("1P97)M7VQI<W0@/2`D<&5R;2T^9V5T57-E<E!E<FUI<W-I;VYS*"D["@H@
M("`@("`@(&9O<F5A8V@@*"1P97)M7VQI<W0@87,@)'5S97(@/3X@)'5S97)?
M<&5R;7,I('L*("`@("`@("`@("`@)')E<W5L="`]("1I;6%P+3YS971!0TPH
M)&9O;&1E<E]N86UE+"`D=7-E<BP@2V]L86(Z.G!E<FUS5&]!8VPH)'5S97)?
M<&5R;7,L("1U<V5R(#T]("1O=VYE<BDI.PH@("`@("`@("`@("!I9B`H:7-?
M82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@=6YS
M970H)&%C;%LD=7-E<ETI.PH@("`@("`@('T*"B`@("`@("`@+R\@36%K92!S
M=7)E('=E(&1O;B=T(&1E;&5T92!T:&4@8W5R<F5N="!U<V5R(&]R('1H92!#
M>7)U<PH@("`@("`@("\O($%D;6EN:7-T<F%T;W(@9G)O;2!T:&4@9F]L9&5R
M)W,@04-,+"!O<B!E;'-E('=E)VQL(&)E(&QO8VME9"!O=70*("`@("`@("!U
M;G-E="@D86-L6R1O=VYE<ETI.PH@("`@("`@('5N<V5T*"1A8VQ;)&-O;F9;
M)VMO;&%B)UU;)VEM87`G75LG861M:6YU<V5R)UU=*3L*"B`@("`@("`@9F]R
M96%C:"`H)&%C;"!A<R`D=7-E<B`]/B`D=7-E<E]A8VPI('L*("`@("`@("`@
M("`@)')E<W5L="`]("1I;6%P+3YD96QE=&5!0TPH)&9O;&1E<E]N86UE+"`D
M=7-E<BD["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@)&EM87`M
M/G-E=$%N;F]T871I;VXH2T],04)?04Y.3U1?1D],1$527U194$4L(&%R<F%Y
M*"=V86QU92YS:&%R960G(#T^("1F;VQD97)?='EP92DL("1F;VQD97)?;F%M
M92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@
M("`@("1R97-U;'0@/2`D:6UA<"T^<V5T06YN;W1A=&EO;BA+3TQ!0E]!3DY/
M5%]32$%215]5240L(&%R<F%Y*"=V86QU92YS:&%R960G(#T^("1S:&%R95]U
M:60I+"`D9F]L9&5R7VYA;64I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("`@("`@?0H*("`@("`@("!+;VQA8CHZ=7!D871E36%P<&5D4VAA<F4H
M)'-H87)E7VUA<"P@)'-H87)E7W5I9"P@)&9O;&1E<E]N86UE*3L*("`@("`@
M("!+;VQA8CHZ<V5T4VAA<F5-87`H)'-H87)E7VUA<"D["@H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N('5P9&%T95-H87)E*"8D
M<VAA<F4I"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R>2P@)&YO=&EF
M:6-A=&EO;CL*"B`@("`@("`@)&%P<"`]("1R96=I<W1R>2T^9V5T07!P*"D[
M"B`@("`@("`@:68@*&%R<F%Y7W-E87)C:"@D87!P+"!A<G)A>2@G;6YE;6\G
M+"`G;F%G)RP@)W1U<F)A)RP@)VMR;VYO;&ET:"<I*2`]/3T@9F%L<V4I('L*
M("`@("`@("`@("`@:68@*&5M<'1Y*"1?4T534TE/3EM+3TQ!0E],05-47U-9
M3D-(141?05!072DI('L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D87!P(#T@)%]315-324].6TM/
M3$%"7TQ!4U1?4UE.0TA%1%]!4%!=.PH@("`@("`@('T*"B`@("`@("`@)&%P
M<%]C;VYS=',@/2!+;VQA8CHZ9V5T07!P0V]N<W1S*"1A<'`I.PH@("`@("`@
M(&EF("AI<U]A*"1A<'!?8V]N<W1S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1R97-U
M;'0@/2!+;VQA8CHZ7W5P9&%T95-H87)E*"1S:&%R92P@)&%P<%]C;VYS=',I
M.PH@("`@("`@("1I9"`]("1S:&%R92T^9V5T*"=N86UE)RD["B`@("`@("`@
M:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<(B5S7"(Z("5S(BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D87!P7V-O;G-T
M<ULG<VAA<F5?;F%M92==+"`D:60L("1R97-U;'0M/F=E=$UE<W-A9V4H*2DL
M("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@9G5N8W1I;VX@7W5P9&%T95-H87)E*"8D<VAA<F4L
M("8D87!P7V-O;G-T<RD*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@
M("`@("`@("1I;6%P(#T@;F5W($YE=%])34%0*"1C;VYF6R=K;VQA8B==6R=I
M;6%P)UU;)W-E<G9E<B==+"`D8V]N9ELG:V]L86(G75LG:6UA<"==6R=P;W)T
M)UTI.PH*("`@("`@("`D<F5S=6QT(#T@)&EM87`M/FQO9VEN*"1C;VYF6R=K
M;VQA8B==6R=I;6%P)UU;)V%D;6EN=7-E<B==+"`D8V]N9ELG:V]L86(G75LG
M:6UA<"==6R=A9&UI;G!W)UTL(&9A;'-E+"!F86QS92D["B`@("`@("`@:68@
M*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@("1R97-U;'0@/2!+
M;VQA8CHZ<WEN8VAR;VYI<V53:&%R92@D:6UA<"P@)'-H87)E+"`D87!P7V-O
M;G-T<RD["@H@("`@("`@("1I;6%P+3YD:7-C;VYN96-T*"D["@H@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@(&9U;F-T:6]N(')E;6]V95-H
M87)E*"8D<VAA<F4I"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R>2P@
M)&YO=&EF:6-A=&EO;CL*"B`@("`@("`@)&%P<"`]("1R96=I<W1R>2T^9V5T
M07!P*"D["@H@("`@("`@("\O(%=E(&]N;'D@<F5M;W9E('-H87)E<R!I9B!+
M;VQA8B!I;G1E9W)A=&EO;B!I<R!E;F%B;&5D+"!A;F0@:68@=V4G=F4*("`@
M("`@("`O+R!P<F5V:6]U<VQY('-Y;F-H<F]N:7-E9"!T:&4@<VAA<F5S(&QI
M<W0@*&DN92X@=V4@:VYO=R!W:&%T($E-05`*("`@("`@("`O+R!F;VQD97(@
M8V]R<F5S<&]N9',@=&\@=&AE(&=I=F5N('-H87)E*2X*("`@("`@("!I9B`H
M96UP='DH)$=,3T)!3%-;)V-O;F8G75LG:V]L86(G75LG96YA8FQE9"==*2!\
M?`H@("`@("`@("`@("`H(65M<'1Y*"1?4T534TE/3EM+3TQ!0E],05-47U-9
M3D-(141?05!072D@)B8*("`@("`@("`@("`@("1?4T534TE/3EM+3TQ!0E],
M05-47U-93D-(141?05!072`A/2`D87!P*2D@>PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D87!P7V-O;G-T<R`]($MO
M;&%B.CIG971!<'!#;VYS=',H)&%P<"D["B`@("`@("`@:68@*&ES7V$H)&%P
M<%]C;VYS=',L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]($MO;&%B.CI?
M<F5M;W9E4VAA<F4H)'-H87)E*3L*("`@("`@("`D:60@/2`D<VAA<F4M/F=E
M="@G;F%M92<I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I
M;G1F*%\H(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<
M(CH@)7,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1A<'!?8V]N<W1S6R=S:&%R95]N86UE)UTL("1I9"P@)')E<W5L="T^
M9V5T365S<V%G92@I*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@?2!E;'-E
M:68@*"1R97-U;'0@/3T]('1R=64I('L*("`@("`@("`@("`@)&YO=&EF:6-A
M=&EO;BT^<'5S:"AS<')I;G1F*%\H(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L
M;'D@<F5M;W9E9"`E<R!<(B5S7"(B*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1A<'!?8V]N<W1S6R=S:&%R95]N86UE)UTL
M("1I9"DL("=H;W)D92YS=6-C97-S)RD["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5M;W9E4VAA<F4H
M)B1S:&%R92D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@
M(&EF("AE;7!T>2@D<VAA<F4I*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*%\H(DEN=F%L:60@<VAA<F4@;V)J96-T(BDI.PH@("`@
M("`@('T*"B`@("`@("`@)'-H87)E7W5I9"`]("1S:&%R92T^9V5T3F%M92@I
M.PH*("`@("`@("`D<VAA<F5?;6%P(#T@2V]L86(Z.F=E=%-H87)E36%P*"D[
M"@H@("`@("`@("1F;VQD97(@/2!+;VQA8CHZ9V5T4VAA<F5-87!P:6YG*"1S
M:&%R95]M87`L("1S:&%R95]U:60I.PH@("`@("`@(&EF("AE;7!T>2@D9F]L
M9&5R*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@
M("`@("`@("1I;6%P(#T@;F5W($YE=%])34%0*"1C;VYF6R=K;VQA8B==6R=I
M;6%P)UU;)W-E<G9E<B==+"`D8V]N9ELG:V]L86(G75LG:6UA<"==6R=P;W)T
M)UTI.PH*("`@("`@("`D<F5S=6QT(#T@)&EM87`M/FQO9VEN*"1C;VYF6R=K
M;VQA8B==6R=I;6%P)UU;)V%D;6EN=7-E<B==+"`D8V]N9ELG:V]L86(G75LG
M:6UA<"==6R=A9&UI;G!W)UTL(&9A;'-E+"!F86QS92D["B`@("`@("`@:68@
M*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@("1R97-U;'0@/2`D
M:6UA<"T^9&5L971E36%I;&)O>"@D9F]L9&5R*3L*("`@("`@("!I9B`H:7-?
M82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@)&EM87`M/F1I<V-O;FYE
M8W0H*3L*"B`@("`@("`@2V]L86(Z.G)E;6]V94UA<'!E9%-H87)E*"1S:&%R
M95]M87`L("1S:&%R95]U:60I.PH*("`@("`@("!+;VQA8CHZ<V5T4VAA<F5-
M87`H)'-H87)E7VUA<"D["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@(&9U;F-T:6]N('-Y;F-H<F]N:7-E4VAA<F5S*"8D<VAA<F5S+"`D87!P
M*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D1TQ/0D%,4ULG8V]N9B==6R=K
M;VQA8B==6R=E;F%B;&5D)UTI('Q\"B`@("`@("`@("`@(&%R<F%Y7W-E87)C
M:"@D87!P+"!A<G)A>2@G;6YE;6\G+"`G;F%G)RP@)W1U<F)A)RP@)VMR;VYO
M;&ET:"<I*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@
M("`@('T*"B`@("`@("`@+R\@5'5R8F$@9&]E<VXG="!U<V4@<VAA<F5S+"!S
M;R!W92!J=7-T(&-R96%T92!A(&1U;6UY('-H87)E(&QI<W0@)@H@("`@("`@
M("\O(&1E9F%U;'0@<VAA<F4@:&5R92!T;R!M86ME('-U<F4@=&AE(&9O;&QO
M=VEN9R!C;V1E('=O<FMS+@H@("`@("`@(&EF("AE;7!T>2@D<VAA<F5S*2`F
M)B`D87!P(#T]("=T=7)B82<I('L*("`@("`@("`@("`@)'-H87)E<R`]("9(
M;W)D95]3:&%R93HZ<VEN9VQE=&]N*"1A<'`I.PH*("`@("`@("`@("`@)&%P
M<%]C;VYS=',@/2!+;VQA8CHZ9V5T07!P0V]N<W1S*"1A<'`I.PH*("`@("`@
M("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92])9&5N=&ET>2YP:'`G.PH@("`@
M("`@("`@("`D:61E;G1I='D@/2`F261E;G1I='DZ.G-I;F=L971O;B@I.PH@
M("`@("`@("`@("`D;F%M92`]("1I9&5N=&ET>2T^9V5T5F%L=64H)V9U;&QN
M86UE)RD["B`@("`@("`@("`@(&EF("AT<FEM*"1N86UE*2`]/2`G)RD@>PH@
M("`@("`@("`@("`@("`@)&YA;64@/2!!=71H.CIR96UO=F5(;V]K*$%U=&@Z
M.F=E=$%U=&@H*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'-H87)E
M(#T@)B1S:&%R97,M/FYE=U-H87)E*$%U=&@Z.F=E=$%U=&@H*2D["B`@("`@
M("`@("`@("1S:&%R92T^<V5T*"=N86UE)RP@<W!R:6YT9B@D87!P7V-O;G-T
M<ULG9&5F875L=%]S:&%R95]N86UE)UTL("1N86UE*2D["B`@("`@("`@("`@
M("1S:&%R97,M/F%D9%-H87)E*"1S:&%R92D["B`@("`@("`@?0H*("`@("`@
M("`O+R!#:&5C:R!I9B!W92=V92!A;')E861Y('-Y;F-H<F]N:7-E9"!T:&4@
M24U!4"!F;VQD97(@;&ES=#L@:68@=V4@:&%V90H@("`@("`@("\O('1H96X@
M97AI="!E87)L>2X@1F]L9&5R('-Y;F-H<F]N:7-A=&EO;B!I<R!D;VYE(&]N
M(&%P<&QI8V%T:6]N"B`@("`@("`@+R\@<W1A<G1U<"`M('1H:7,@:6YC;'5D
M97,@<W=I=&-H:6YG(&)E='=E96X@87!P;&EC871I;VYS(&%S('=E;&P@87,*
M("`@("`@("`O+R!U<&]N(&EN:71I86P@;&]G:6XN"B`@("`@("`@:68@*"%E
M;7!T>2@D7U-%4U-)3TY;2T],04)?3$%35%]364Y#2$5$7T%04%TI("8F"B`@
M("`@("`@("`@("1?4T534TE/3EM+3TQ!0E],05-47U-93D-(141?05!072`]
M/2`D87!P*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@
M("`@(&=L;V)A;"`D;F]T:69I8V%T:6]N.PH*("`@("`@("`D<F5S=6QT(#T@
M2V]L86(Z.E]S>6YC:%-H87)E<R@D<VAA<F5S*3L*("`@("`@("!I9B`H:7-?
M82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1N;W1I
M9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")(;W)D92]+;VQA8CH@56YA8FQE
M('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B*2P@)')E<W5L="T^9V5T365S
M<V%G92@I*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@4WEN8VAR;VYI<V5S('1H92!)34%0(&9O;&1E<B!L:7-T
M(&%N9"!T:&4@2&]R9&4@<VAA<F4@;&ES="X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!4<G5E(&]N(&$@<W5C8V5S<V9U;"!S>6YC:')O;FES871I
M;VXL(&9A;'-E('=H96X@80H@("`@("H@("`@("`@("`@("`@("`@<WEN8VAR
M;VYI<V%T:6]N(&ES(&YO="!R97%U:7)E9"`H:2YE+B!M=6QT:7!L92!P86=E
M(&QO861S"B`@("`@*B`@("`@("`@("`@("`@("!I;B!A('-I;F=L92!A<'!L
M:6-A=&EO;BDL(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX*("`@("`J("`@
M("`@("`@("`@("`@(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S
M>6YC:%-H87)E<R@F)'-H87)E<RD*("`@('L*("`@("`@("!G;&]B86P@)')E
M9VES=')Y+"`D8V]N9CL*"B`@("`@("`@)&%P<"`]("1R96=I<W1R>2T^9V5T
M07!P*"D["@H@("`@("`@("\O($]T:&5R=VES92!W92!N965D('1O(&UA<"!T
M:&4@8W5R<F5N="!)34%0(&9O;&1E<B!L:7-T('1O('1H90H@("`@("`@("\O
M(&%P<&QI8V%T:6]N<R!S:&%R92!L:7-T+@H*("`@("`@("`O+R!-86ME('-U
M<F4@=&AI<R!I<R!B96EN9R!C86QL960@9G)O;2!A(&MN;W=N(&%P<&QI8V%T
M:6]N"B`@("`@("`@)&%P<%]C;VYS=',@/2!+;VQA8CHZ9V5T07!P0V]N<W1S
M*"1A<'`I.PH@("`@("`@(&EF("AI<U]A*"1A<'!?8V]N<W1S+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D87!P7V-O;G-T<SL*("`@
M("`@("!]"@H@("`@("`@("\O($-O;FYE8W0@=&\@=&AE($E-05`@<V5R=F5R
M"B`@("`@("`@)&EM87`@/2!N97<@3F5T7TE-05`H)&-O;F9;)VMO;&%B)UU;
M)VEM87`G75LG<V5R=F5R)UTL("1C;VYF6R=K;VQA8B==6R=I;6%P)UU;)W!O
M<G0G72D["@H@("`@("`@("\O($QO9VEN('5S:6YG('1H92!C=7)R96YT($AO
M<F1E(&-R961E;G1I86QS"B`@("`@("`@)&-U<G)E;G1?=7-E<B`]($%U=&@Z
M.F=E=$%U=&@H*3L*("`@("`@("`D;F1X(#T@<W1R<&]S*"1C=7)R96YT7W5S
M97(L("=`)RD["B`@("`@("`@)'5S97(@/2`D;F1X(#T]/2!F86QS92`_("1C
M=7)R96YT7W5S97(@.B!S=6)S='(H)&-U<G)E;G1?=7-E<BP@,"P@)&YD>"D[
M"B`@("`@("`@)&1O;6%I;B`]('-T<G-T<B@D8W5R<F5N=%]U<V5R+"`G0"<I
M.PH@("`@("`@("1R97-U;'0@/2`D:6UA<"T^;&]G:6XH)&-U<G)E;G1?=7-E
M<BP@075T:#HZ9V5T0W)E9&5N=&EA;"@G<&%S<W=O<F0G*2P@9F%L<V4L(&9A
M;'-E*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@
M("`@("`@+R\@3V)T86EN(&$@;&ES="!O9B!A;&P@9F]L9&5R<R!T:&4@8W5R
M<F5N="!U<V5R(&AA<R!A8V-E<W,@=&\*("`@("`@("`D9F]L9&5R7VQI<W0@
M/2`D:6UA<"T^9V5T36%I;&)O>&5S*"D["B`@("`@("`@:68@*&ES7V$H)&9O
M;&1E<E]L:7-T+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D9F]L9&5R7VQI<W0["B`@("`@("`@?0H*("`@("`@("`O+R!792=R92!O
M;FQY(&EN=&5R97-T960@:6X@=&AE(&9O;&1E<G,@;V8@=&AE('-P96-I9FEC
M(')E<V]U<F-E('1Y<&4*("`@("`@("`O+R!F;W(@=&AE(&-U<G)E;G0@87!P
M;&EC871I;VXL('-O(&9I;'1E<B!O=70@=&AE(')E<W0*("`@("`@("`D;&]C
M86Q?9F]L9&5R<R`](&%R<F%Y*"D["B`@("`@("`@)')E;6]T95]F;VQD97)S
M(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D9F]L9&5R7VQI<W0@87,@
M)&9O;&1E<BD@>PH@("`@("`@("`@("`D86YN;W1A=&EO;B`]("1I;6%P+3YG
M971!;FYO=&%T:6]N*$M/3$%"7T%.3D]47T9/3$1%4E]465!%+"`G=F%L=64N
M<VAA<F5D)RP@)&9O;&1E<BD["B`@("`@("`@("`@(&EF("AI<U]A*"1A;FYO
M=&%T:6]N+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)&%N;F]T871I;VX["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O
M($EF('1H97)E(&ES(&YO(&%N;F]T871I;VX@=&AE;B!W92!T<F5A="!I="!A
M<R!A('-T86YD87)D(&UA:6P*("`@("`@("`@("`@+R\@9F]L9&5R("AI+F4N
M('=E(&EG;F]R92!I="DN"B`@("`@("`@("`@(&EF("AE;7!T>2@D86YN;W1A
M=&EO;BDI('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`O+R!)9B!T:&4@9F]L9&5R(&ES(&]F('1H92!C
M;W)R96-T('1Y<&4@=&AE;B!W92!A9&0@:70@=&\@;W5R(&QI<W0*("`@("`@
M("`@("`@+R\@;V8@9F]L9&5R<R!T:&%T('-H;W5L9"!C;W)R97-P;VYD('1O
M(&$@<VAA<F4N($AE<F4@=V4@9V5T(&%N>0H@("`@("`@("`@("`O+R!O=&AE
M<B!A9&1I=&EO;F%L(&EN9F]R;6%T:6]N('=E(&UA>2!N965D+"!S=6-H(&%S
M('=H971H97(@=&AE"B`@("`@("`@("`@("\O(&9O;&1E<B!W87,@<')E=FEO
M=7-L>2!M87!P960@=&\@82!S:&%R92P@:71S($%#3"P@:71S(&]W;F5R("AI
M9@H@("`@("`@("`@("`O+R!I="!I<R!A('-H87)E9"!F;VQD97(I(&%N9"!I
M=',@9&ES<&QA>2!N86UE+@H@("`@("`@("`@("`D='EP92`](&5X<&QO9&4H
M)RXG+"`D86YN;W1A=&EO;BD["B`@("`@("`@("`@(&EF("@D='EP95LP72`]
M/2`D87!P7V-O;G-T<ULG;6EM95]T>7!E7W-U9F9I>"==*2!["B`@("`@("`@
M("`@("`@("`D86-L(#T@2V]L86(Z.F%C;%1O07)R87DH)&EM87`M/F=E=$%#
M3"@D9F]L9&5R*2D["B`@("`@("`@("`@("`@("!I9B`H:7-?82@D86-L+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1A
M8VP["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@+R\@4VMI
M<"!T:&4@0WER=7,@061M:6YI<W1R871O<@H@("`@("`@("`@("`@("`@=6YS
M970H)&%C;%LD8V]N9ELG:V]L86(G75LG:6UA<"==6R=A9&UI;G5S97(G75TI
M.PH*("`@("`@("`@("`@("`@("1S:&%R95]U:60@/2`D:6UA<"T^9V5T06YN
M;W1A=&EO;BA+3TQ!0E]!3DY/5%]32$%215]5240L("=V86QU92YS:&%R960G
M+"`D9F]L9&5R*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1S:&%R95]U
M:60L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)'-H87)E7W5I9#L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("`@("!P<F5G7VUA=&-H*"([*$E.0D]8?'5S97(O*%M>+UTK*2DO*%M>0%TK
M*2A`+BHI/SLB+"`D9F]L9&5R+"`D;6%T8VAE<RD["@H@("`@("`@("`@("`@
M("`@)&1E9F%U;'0@/2`H(65M<'1Y*"1T>7!E6S%=*2`F)B`D='EP95LQ72`]
M/2`G9&5F875L="<I.PH*("`@("`@("`@("`@("`@(&EF("@D;6%T8VAE<ULQ
M72`]/2`G24Y"3U@G*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1D969A
M=6QT*2!["B`@("`@("`@("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G
M2&]R9&4O261E;G1I='DN<&AP)SL*("`@("`@("`@("`@("`@("`@("`@("`@
M)&ED96YT:71Y(#T@)DED96YT:71Y.CIS:6YG;&5T;VXH*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&YA;64@/2`D:61E;G1I='DM/F=E=%9A;'5E*"=F
M=6QL;F%M92<I.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H=')I;2@D
M;F%M92D@/3T@)R<I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N
M86UE(#T@075T:#HZ<F5M;W9E2&]O:R@D8W5R<F5N=%]U<V5R*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`D
M;F%M92`]('-P<FEN=&8H)&%P<%]C;VYS='-;)V1E9F%U;'1?<VAA<F5?;F%M
M92==+"`D;F%M92D["B`@("`@("`@("`@("`@("`@("`@("`@("1F;VQD97(@
M/2`D87!P7V-O;G-T<ULG9&5F875L=%]F;VQD97)?;F%M92==.PH@("`@("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1N86UE(#T@)&9O;&1E<B`]($MO;&%B.CID96-O9&5);6%P1F]L9&5R3F%M
M92@D;6%T8VAE<ULS72D["B`@("`@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@("`@("`@("`D9F]L9&5R(#T@(G5S97(O)'5S97(O)&9O;&1E<B1D
M;VUA:6XB.PH*("`@("`@("`@("`@("`@("`@("`D;&]C86Q?9F]L9&5R<ULD
M9F]L9&5R72`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`G<VAA
M<F5?=6ED)R`@("`@/3X@)'-H87)E7W5I9"P*("`@("`@("`@("`@("`@("`@
M("`@("`@)V%C;"<@("`@("`@("`@(#T^("1A8VPL"B`@("`@("`@("`@("`@
M("`@("`@("`@("=N86UE)R`@("`@("`@("`]/B`D;F%M92P*("`@("`@("`@
M("`@("`@("`@("`@("`@)V1E9F%U;'0G("`@("`@(#T^("1D969A=6QT+`H@
M("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("1U<V5R7V1O;6%I;B`](&ES<V5T*"1M
M871C:&5S6S1=*2`_("1M871C:&5S6S1=(#H@)&1O;6%I;CL*("`@("`@("`@
M("`@("`@("`@("`D9F]L9&5R(#T@:7-S970H)&UA=&-H97-;-%TI(#\@)&9O
M;&1E<B`Z("1F;VQD97(@+B`D=7-E<E]D;VUA:6X["B`@("`@("`@("`@("`@
M("`@("`@)&]W;F5R(#T@)&UA=&-H97-;,ET@+B`D=7-E<E]D;VUA:6X["B`@
M("`@("`@("`@("`@("`@("`@:68@*"1D969A=6QT*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O261E;G1I='DN<&AP
M)SL*("`@("`@("`@("`@("`@("`@("`@("`@)&ED96YT:71Y(#T@)DED96YT
M:71Y.CIS:6YG;&5T;VXH)VYO;F4G+"`D;W=N97(I.PH@("`@("`@("`@("`@
M("`@("`@("`@("`D;F%M92`]("1I9&5N=&ET>2T^9V5T5F%L=64H)V9U;&QN
M86UE)RD["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AT<FEM*"1N86UE
M*2`]/2`G)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YA;64@
M/2!!=71H.CIR96UO=F5(;V]K*"1O=VYE<BD["B`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)&YA;64@/2!S<')I
M;G1F*"1A<'!?8V]N<W1S6R=D969A=6QT7W-H87)E7VYA;64G72P@)&YA;64I
M.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1N86UE(#T@2V]L86(Z.F1E8V]D94EM87!&;VQD97).86UE
M*"1M871C:&5S6S-=*3L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@("`@("1R96UO=&5?9F]L9&5R<ULD9F]L9&5R72`](&%R<F%Y
M*`H@("`@("`@("`@("`@("`@("`@("`@("`G<VAA<F5?=6ED)R`@("`@/3X@
M)'-H87)E7W5I9"P*("`@("`@("`@("`@("`@("`@("`@("`@)V%C;"<@("`@
M("`@("`@(#T^("1A8VPL"B`@("`@("`@("`@("`@("`@("`@("`@("=N86UE
M)R`@("`@("`@("`]/B`D;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@
M)V1E9F%U;'0G("`@("`@(#T^("1D969A=6QT+`H@("`@("`@("`@("`@("`@
M("`@("`@("`G;W=N97(G("`@("`@("`@/3X@)&]W;F5R+`H@("`@("`@("`@
M("`@("`@("`@("D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@("\O(%=E(&YO=R!M87`@=&AE(')E;6%I;FEN
M9R!F;VQD97(@;&ES="!T;R!T:&4@8W5R<F5N="!A<'!L:6-A=&EO;G,*("`@
M("`@("`O+R!S:&%R92!L:7-T+"!T;R!S>6YC:"!(;W)D92!W:71H(&]T:&5R
M($MO;&%B(&-L:65N=',@=&AA="!M87D@:&%V90H@("`@("`@("\O('!R979I
M;W5S;'D@;6]D:69I960@=&AE(&=R;W5P=V%R92!F;VQD97)S"@H@("`@("`@
M("1I;6%P+3YD:7-C;VYN96-T*"D["B`@("`@("`@)&EM87`@/2!N97<@3F5T
M7TE-05`H)&-O;F9;)VMO;&%B)UU;)VEM87`G75LG<V5R=F5R)UTL("1C;VYF
M6R=K;VQA8B==6R=I;6%P)UU;)W!O<G0G72D["@H@("`@("`@("1R97-U;'0@
M/2`D:6UA<"T^;&]G:6XH)&-O;F9;)VMO;&%B)UU;)VEM87`G75LG861M:6YU
M<V5R)UTL("1C;VYF6R=K;VQA8B==6R=I;6%P)UU;)V%D;6EN<'<G72P@9F%L
M<V4L(&9A;'-E*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@
M('T*"B`@("`@("`@+R\@5$]$3SH@<V5E(&EF('1H97)E(&ES(&$@;6]R92!A
M8V-U<F%T92!W87D@;V8@;&ES=&EN9R!A;&P@<VAA<F5S('1H870*("`@("`@
M("`O+R!A<F4@86-C97-S:6)L92P@<F5G87)D;&5S<R!O9B!W:&%T('!E<FUI
M<W-I;VYS('1H92!U<V5R(&AA<R`H:2YE+B!I9@H@("`@("`@("\O('1H92!U
M<V5R(&AA<R!A="!L96%S="!O;F4@<&5R;6ES<VEO;B!L979E;"!T;R!T:&4@
M<VAA<F4L('1H92!S:&%R90H@("`@("`@("\O('-H;W5L9"!B92!I;B!O;F4@
M;V8@=&AE<V4@;&ES=',I+@H@("`@("`@("1L;V-A;%]S:&%R97,@/2`D<VAA
M<F5S+3YL:7-T4VAA<F5S*"1C=7)R96YT7W5S97(L(%!%4DU37U-(3U<L("1C
M=7)R96YT7W5S97(I.PH@("`@("`@("1A;&Q?<VAA<F5S(#T@)'-H87)E<RT^
M;&ES=%-H87)E<R@D8W5R<F5N=%]U<V5R+"!015)-4U]32$]7*3L*("`@("`@
M("`D<F5M;W1E7W-H87)E<R`](&%R<F%Y7V1I9F9?87-S;V,H)&%L;%]S:&%R
M97,L("1L;V-A;%]S:&%R97,I.PH@("`@("`@($MO;&%B.CIS9713:&%R94UA
M<"AA<G)A>2@I*3L*("`@("`@("`D<VAA<F5?;6%P(#T@87)R87DH*3L*"B`@
M("`@("`@+R\@3F]W('-Y;F-H<F]N:7-E('1H92!F;VQD97(@;&ES="!W:71H
M('1H92!S:&%R92!L:7-T"B`@("`@("`@9F]R96%C:"`H)&QO8V%L7V9O;&1E
M<G,@87,@)&9O;&1E<B`]/B`D871T<G,I('L*("`@("`@("`@("`@:68@*&5M
M<'1Y*"1A='1R<ULG<VAA<F5?=6ED)UTI*2!["B`@("`@("`@("`@("`@("`O
M+R!.;R!S:&%R92!C;W)R97-P;VYD<R!T;R!T:&ES(&9O;&1E<BP@<V\@8W)E
M871E(&]N90H@("`@("`@("`@("`@("`@)'5I9"`](&5M<'1Y*"1A='1R<ULG
M9&5F875L="==*2`_(&UD-2AM:6-R;W1I;64H*2D@.B`D8W5R<F5N=%]U<V5R
M.PH@("`@("`@("`@("`@("`@)'-H87)E(#T@)B1S:&%R97,M/FYE=U-H87)E
M*"1U:60I.PH@("`@("`@("`@("`@("`@)'-H87)E+3YS970H)VYA;64G+"`D
M871T<G-;)VYA;64G72D["B`@("`@("`@("`@("`@("`D<VAA<F5S+3YA9&13
M:&%R92@D<VAA<F4I.PH*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D:6UA
M<"T^<V5T06YN;W1A=&EO;BA+3TQ!0E]!3DY/5%]32$%215]5240L(&%R<F%Y
M*"=V86QU92YS:&%R960G(#T^("1U:60I+"`D9F]L9&5R*3L*("`@("`@("`@
M("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("`@("!+;VQA8CHZ=7!D871E36%P<&5D4VAA
M<F4H)'-H87)E7VUA<"P@)'5I9"P@)&9O;&1E<BD["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`O+R!/=&AE<G=I<V4@=&AE<F4@:7,@
M82!S:&%R92!C;W)R97-P;VYD:6YG('1O('1H:7,@9F]L9&5R"B`@("`@("`@
M("`@("`@("!I9B`H(21S:&%R97,M/F5X:7-T<R@D871T<G-;)W-H87)E7W5I
M9"==*2D@>PH@("`@("`@("`@("`@("`@("`@("\O($EF(&ET)W,@;F]T('!R
M97-E;G0@9F]R('=H871E=F5R(')E87-O;BP@8W)E871E(&ET"B`@("`@("`@
M("`@("`@("`@("`@)'-H87)E(#T@)B1S:&%R97,M/FYE=U-H87)E*"1A='1R
M<ULG<VAA<F5?=6ED)UTI.PH@("`@("`@("`@("`@("`@("`@("1S:&%R92T^
M<V5T*"=N86UE)RP@)&%T=')S6R=N86UE)UTI.PH@("`@("`@("`@("`@("`@
M("`@("1S:&%R97,M/F%D9%-H87)E*"1S:&%R92D["B`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("\O($]T:&5R=VES92!C
M:&5C:R!T:&%T(&ET(&ES(&YA;65D(&-O<G)E8W1L>0H@("`@("`@("`@("`@
M("`@("`@("1S:&%R92`]("8D;&]C86Q?<VAA<F5S6R1A='1R<ULG<VAA<F5?
M=6ED)UU=.PH@("`@("`@("`@("`@("`@("`@(&EF("@D<VAA<F4M/F=E="@G
M;F%M92<I("$]("1A='1R<ULG;F%M92==*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1S:&%R92T^<V5T*"=N86UE)RP@)&%T=')S6R=N86UE)UTI.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("`@("!+;VQA8CHZ=7!D871E36%P<&5D4VAA<F4H)'-H87)E7VUA
M<"P@)&%T=')S6R=S:&%R95]U:60G72P@)&9O;&1E<BD["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("1C=7)R96YT7W5S97)S(#T@)'-H87)E+3YL:7-T
M57-E<G,H*3L*"B`@("`@("`@("`@("1P97)M(#T@)B1S:&%R92T^9V5T4&5R
M;6ES<VEO;B@I.PH@("`@("`@("`@("`D;75S=%]S879E(#T@9F%L<V4["@H@
M("`@("`@("`@("!F;W)E86-H("@D871T<G-;)V%C;"==(&%S("1U<V5R(#T^
M("1A8VPI('L*("`@("`@("`@("`@("`@("1P97)M<R`]($MO;&%B.CIA8VQ4
M;U!E<FUS*"1A8VPI.PH@("`@("`@("`@("`@("`@:68@*"1P97)M<R`A/2`D
M1TQ/0D%,4ULG<&5R;7,G72T^9V5T4&5R;6ES<VEO;G,H)'!E<FTL("1U<V5R
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1P97)M+3YA9&15<V5R4&5R;6ES
M<VEO;B@D=7-E<BP@)'!E<FUS+"!F86QS92D["B`@("`@("`@("`@("`@("`@
M("`@)&UU<W1?<V%V92`]('1R=64["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D;F1X(#T@87)R87E?<V5A<F-H*"1U<V5R+"`D8W5R<F5N
M=%]U<V5R<RD["B`@("`@("`@("`@("`@("!I9B`H)&YD>"`A/3T@9F%L<V4I
M('L*("`@("`@("`@("`@("`@("`@("!U;G-E="@D8W5R<F5N=%]U<V5R<ULD
M;F1X72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@(&9O<F5A8V@@*"1C=7)R96YT7W5S97)S(&%S("1U<V5R*2!["B`@
M("`@("`@("`@("`@("!I9B`H)$=,3T)!3%-;)W!E<FUS)UTM/F=E=%!E<FUI
M<W-I;VYS*"1P97)M+"`D=7-E<BD@(3T](&9A;'-E*2!["B`@("`@("`@("`@
M("`@("`@("`@)'!E<FTM/G)E;6]V955S97)097)M:7-S:6]N*"1U<V5R+"!0
M15)-4U]!3$PL(&9A;'-E*3L*("`@("`@("`@("`@("`@("`@("`D;75S=%]S
M879E(#T@=')U93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@:68@*"1M=7-T7W-A=F4I('L*("`@("`@("`@("`@("`@
M("1S:&%R92T^<V5T4&5R;6ES<VEO;B@D<&5R;2P@9F%L<V4I.PH@("`@("`@
M("`@("`@("`@)'-H87)E+3YS879E*"D["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@(&EF("@A96UP='DH)&%T=')S6R=S:&%R95]U:60G72DI('L*("`@
M("`@("`@("`@("`@('5N<V5T*"1L;V-A;%]S:&%R97-;)&%T=')S6R=S:&%R
M95]U:60G75TI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@('5N
M<V5T*"1L;V-A;%]S:&%R97-;)&-U<G)E;G1?=7-E<ETI.PH*("`@("`@("`O
M+R!5<&1A=&4@<VAA<F5S('1H870@87)E(&YO="!O=VYE9"!B>2!T:&4@8W5R
M<F5N="!U<V5R("AO;FQY(&EF('1H97)E"B`@("`@("`@+R\@87)E('-H87)E
M9"!F;VQD97)S(&%C8V5S<VEB;&4@=&\@=&AE(&-U<G)E;G0@=7-E<BD*("`@
M("`@("!I9B`H(65M<'1Y*"1R96UO=&5?9F]L9&5R<RDI('L*("`@("`@("`@
M("`@9F]R96%C:"`H)')E;6]T95]F;VQD97)S(&%S("1F;VQD97(@/3X@)&%T
M=')S*2!["B`@("`@("`@("`@("`@("!I9B`H96UP='DH)&%T=')S6R=S:&%R
M95]U:60G72DI('L*("`@("`@("`@("`@("`@("`@("`D=6ED(#T@96UP='DH
M)&%T=')S6R=D969A=6QT)UTI(#\@;60U*&UI8W)O=&EM92@I*2`Z("1A='1R
M<ULG;W=N97(G73L*("`@("`@("`@("`@("`@("`@("`D<VAA<F4@/2`F)'-H
M87)E<RT^;F5W4VAA<F4H)'5I9"D["B`@("`@("`@("`@("`@("`@("`@)'-H
M87)E+3YS970H)V]W;F5R)RP@)&%T=')S6R=O=VYE<B==*3L*("`@("`@("`@
M("`@("`@("`@("`D<VAA<F4M/G-E="@G;F%M92<L("1A='1R<ULG;F%M92==
M*3L*("`@("`@("`@("`@("`@("`@("`D<VAA<F5S+3YA9&13:&%R92@D<VAA
M<F4I.PH*("`@("`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)&EM87`M/G-E
M=$%N;F]T871I;VXH2T],04)?04Y.3U1?4TA!4D5?54E$+"!A<G)A>2@G=F%L
M=64N<VAA<F5D)R`]/B`D=6ED*2P@)&9O;&1E<BD["B`@("`@("`@("`@("`@
M("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@("`@($MO;&%B.CIU<&1A
M=&5-87!P9613:&%R92@D<VAA<F5?;6%P+"`D=6ED+"`D9F]L9&5R*3L*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@:68@
M*"$D<VAA<F5S+3YE>&ES=',H)&%T=')S6R=S:&%R95]U:60G72DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)'-H87)E(#T@)B1S:&%R97,M/FYE=U-H
M87)E*"1A='1R<ULG<VAA<F5?=6ED)UTI.PH@("`@("`@("`@("`@("`@("`@
M("`@("`D<VAA<F4M/G-E="@G;W=N97(G+"`D871T<G-;)V]W;F5R)UTI.PH@
M("`@("`@("`@("`@("`@("`@("`@("`D<VAA<F4M/G-E="@G;F%M92<L("1A
M='1R<ULG;F%M92==*3L*("`@("`@("`@("`@("`@("`@("`@("`@)'-H87)E
M<RT^861D4VAA<F4H)'-H87)E*3L*("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`O+R!4:&4@<VAA<F4@97AI
M<W1S(&=L;V)A;&QY+"!B=70@;6%Y(&YO="!Y970@8F4@;&ES=&5D"B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D<F5M;W1E7W-H87)E<ULD
M871T<G-;)W-H87)E7W5I9"==72DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1S:&%R92`]("8D<VAA<F5S+3YG9713:&%R92@D871T<G-;)W-H
M87)E7W5I9"==*3L*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S:&%R92`]("8D<F5M;W1E
M7W-H87)E<ULD871T<G-;)W-H87)E7W5I9"==73L*("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'-H87)E
M+3YG970H)VYA;64G*2`A/2`D871T<G-;)VYA;64G72D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'-H87)E+3YS970H)VYA;64G+"`D871T<G-;
M)VYA;64G72D["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@("`@($MO;&%B.CIU<&1A
M=&5-87!P9613:&%R92@D<VAA<F5?;6%P+"`D871T<G-;)W-H87)E7W5I9"==
M+"`D9F]L9&5R*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@
M("`D8W5R<F5N=%]U<V5R<R`]("1S:&%R92T^;&ES=%5S97)S*"D["@H@("`@
M("`@("`@("`@("`@)'!E<FT@/2`F)'-H87)E+3YG971097)M:7-S:6]N*"D[
M"B`@("`@("`@("`@("`@("`D;75S=%]S879E(#T@9F%L<V4["@H@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)&%T=')S6R=A8VPG72!A<R`D=7-E<B`]/B`D
M86-L*2!["B`@("`@("`@("`@("`@("`@("`@)'!E<FUS(#T@2V]L86(Z.F%C
M;%1O4&5R;7,H)&%C;"D["B`@("`@("`@("`@("`@("`@("`@:68@*"1P97)M
M<R`A/2`D1TQ/0D%,4ULG<&5R;7,G72T^9V5T4&5R;6ES<VEO;G,H)'!E<FTL
M("1U<V5R*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<&5R;2T^861D
M57-E<E!E<FUI<W-I;VXH)'5S97(L("1P97)M<RP@9F%L<V4I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D;75S=%]S879E(#T@=')U93L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&YD>"`](&%R<F%Y
M7W-E87)C:"@D=7-E<BP@)&-U<G)E;G1?=7-E<G,I.PH@("`@("`@("`@("`@
M("`@("`@(&EF("@D;F1X("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("!U;G-E="@D8W5R<F5N=%]U<V5R<ULD;F1X72D["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1C=7)R96YT7W5S97)S(&%S("1U<V5R*2!["B`@("`@
M("`@("`@("`@("`@("`@:68@*"1'3$]"04Q36R=P97)M<R==+3YG971097)M
M:7-S:6]N<R@D<&5R;2P@)'5S97(I("$]/2!F86QS92D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D<&5R;2T^<F5M;W9E57-E<E!E<FUI<W-I;VXH)'5S
M97(L(%!%4DU37T%,3"P@9F%L<V4I.PH@("`@("`@("`@("`@("`@("`@("`@
M("`D;75S=%]S879E(#T@=')U93L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*"1M=7-T7W-A
M=F4I('L*("`@("`@("`@("`@("`@("`@("`D<VAA<F4M/G-E=%!E<FUI<W-I
M;VXH)'!E<FTL(&9A;'-E*3L*("`@("`@("`@("`@("`@("`@("`D<VAA<F4M
M/G-A=F4H*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I
M9B`H(65M<'1Y*"1A='1R<ULG<VAA<F5?=6ED)UTI*2!["B`@("`@("`@("`@
M("`@("`@("`@=6YS970H)')E;6]T95]S:&%R97-;)&%T=')S6R=S:&%R95]U
M:60G75TI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("`O+R!&:6YA;&QY+"!R96UO=F4@86YY(&5X=')A('-H
M87)E<R!W92!M87D@:&%V92`H=&AE<V4@=V5R92!O;F-E(&9O;&1E<G,*("`@
M("`@("`O+R!T:&%T('=E<F4@<W5B<V5Q=65N=&QY(&1E;&5T960@8GD@86YO
M=&AE<B!+;VQA8B!C;&EE;G0I+B!4:&ES(&ES(&]N;'D*("`@("`@("`O+R!D
M;VYE(&9O<B!S:&%R97,@=&AA="!T:&4@8W5R<F5N="!U<V5R(&]W;G,L(&DN
M92X@<VAA<F5S('1H870@=V5R90H@("`@("`@("\O('-U8F9O;&1E<G,@;V8@
M=&AE(&-U<G)E;G0@=7-E<G,G($E.0D]8+@H@("`@("`@(&9O<F5A8V@@*"1L
M;V-A;%]S:&%R97,@87,@)'-H87)E*2!["B`@("`@("`@("`@("1R97-U;'0@
M/2`D<VAA<F5S+3YR96UO=F53:&%R92@D<VAA<F4I.PH@("`@("`@("`@("!I
M9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@+R\@1F]R(')E;6]T92!S:&%R97,L('=E('-I;7!L>2!R96UO
M=F4@=&AE(&-U<G)E;G0@=7-E<B!F<F]M('1H92!S:&%R97,*("`@("`@("`O
M+R!P97)M:7-S:6]N<R!L:7-T+@H@("`@("`@(&9O<F5A8V@@*"1R96UO=&5?
M<VAA<F5S(&%S("1U:60@/3X@)'-H87)E*2!["B`@("`@("`@("`@("1P97)M
M(#T@)B1S:&%R92T^9V5T4&5R;6ES<VEO;B@I.PH@("`@("`@("`@("`D<&5R
M;2T^<F5M;W9E57-E<E!E<FUI<W-I;VXH)&-U<G)E;G1?=7-E<BP@4$5235-?
M04Q,+"!F86QS92D["B`@("`@("`@("`@("1S:&%R92T^<V5T4&5R;6ES<VEO
M;B@D<&5R;2P@9F%L<V4I.PH@("`@("`@("`@("`D<VAA<F4M/G-A=F4H*3L*
M("`@("`@("!]"@H@("`@("`@("\O($%N9"!W92=R92!D;VYE(2!$:7-C;VYN
M96-T(&9R;VT@24U!4"P@<V5T('1H92!L87-T('-Y;F-H)V5D(&%P<`H@("`@
M("`@("\O(&9L86<@=&\@=&AE(&-U<G)E;G0@87!P;&EC871I;VXL(&%N9"!U
M<&1A=&4@=&AE('-H87)E(&UA<"X*("`@("`@("`D:6UA<"T^9&ES8V]N;F5C
M="@I.PH*("`@("`@("`D7U-%4U-)3TY;2T],04)?3$%35%]364Y#2$5$7T%0
M4%T@/2`D87!P.PH@("`@("`@($MO;&%B.CIS9713:&%R94UA<"@D<VAA<F5?
M;6%P*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!G<F]U<'=A<F4@='EP92!O9B!T:&4@9VEV96X@
M24U!4"!F;VQD97(N"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="`D;6%I
M;&)O>"`@5&AE(&UA:6QB;W@@;V8@:6YT97)E<W0N"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@02!S=')I;F<@:6YD:6-A=&EN9R!T:&4@9W)O=7!W
M87)E('1Y<&4@;V8@)&UA:6QB;W@@;W(*("`@("`J("`@("`@("`@("`@("`@
M(&)O;VQE86X@(F9A;'-E(B!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T36%I;&)O>%1Y<&4H)&UA:6QB;W@I"B`@("!["B`@("`@("`@9VQO
M8F%L("1C;VYF.PH*("`@("`@("`D='EP92`](&9A;'-E.PH*("`@("`@("`O
M+R!#;VYN96-T('1O('1H92!)34%0('-E<G9E<@H@("`@("`@("1I;6%P(#T@
M;F5W($YE=%])34%0*"1C;VYF6R=K;VQA8B==6R=I;6%P)UU;)W-E<G9E<B==
M+"`D8V]N9ELG:V]L86(G75LG:6UA<"==6R=P;W)T)UTI.PH*("`@("`@("`O
M+R!,;V=I;B!U<VEN9R!T:&4@8W5R<F5N="!(;W)D92!C<F5D96YT:6%L<PH@
M("`@("`@("1R97-U;'0@/2`D:6UA<"T^;&]G:6XH075T:#HZ9V5T075T:"@I
M+"!!=71H.CIG971#<F5D96YT:6%L*"=P87-S=V]R9"<I+"!F86QS92P@9F%L
M<V4I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U5N86)L92!T;R!A
M=71H96YT:6-A=&4@=VET:"!T:&4@2V]L86(@24U!4"!S97)V97(G+"!?7T9)
M3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@("1I
M;6%P+3YD:7-C;VYN96-T*"D["B`@("`@("`@("`@(')E='5R;B`D='EP93L*
M("`@("`@("!]"@H@("`@("`@("\O($]B=&%I;B!T:&4@9W)O=7!W87)E(&%N
M;F]T871I;VX@;V8@)&UA:6QB;W@*("`@("`@("`D86YN;W1A=&EO;B`]("1I
M;6%P+3YG971!;FYO=&%T:6]N*$M/3$%"7T%.3D]47T9/3$1%4E]465!%+"`G
M=F%L=64N<VAA<F5D)RP@)&UA:6QB;W@I.PH@("`@("`@(&EF("@A:7-?82@D
M86YN;W1A=&EO;BP@)U!%05)?17)R;W(G*2`F)B`A96UP='DH)&%N;F]T871I
M;VXI*2!["B`@("`@("`@("`@("1T>7!E(#T@97AP;&]D92@G+B<L("1A;FYO
M=&%T:6]N*3L*("`@("`@("`@("`@:68@*"@A96UP='DH)'1Y<&5;,5TI("8F
M("1T>7!E6S%=(#T]("=D969A=6QT)RD@?'P@*&5M<'1Y*"1T>7!E6S%=*2DI
M('L*("`@("`@("`@("`@("`@("1T>7!E(#T@)'1Y<&5;,%T["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("1I;6%P+3YD:7-C;VYN96-T*"D[
M"@H@("`@("`@(')E='5R;B`D='EP93L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;B!A(&QI<W0@;V8@86QL($E-05`@9F]L9&5R<R`H:6YC;'5D:6YG
M('1H96ER(&=R;W5P=V%R92!T>7!E*2!T:&%T"B`@("`@*B!T:&4@8W5R<F5N
M="!U<V5R(&AA<R!A8V-C97-S('1O+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@($%N(&%R<F%Y(&]F(&%R<F%Y*"1F;VQD97)N86UE+"`D9F]L9&5R
M='EP92D@:71E;7,@*&5M<'1Y"B`@("`@*B`@("`@("`@("`@("`@("!O;B!E
M<G)O<BDN"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W1&;VQD97)S*"D*("`@
M('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@("1F;VQD97)S(#T@
M87)R87DH*3L*"B`@("`@("`@+R\@0V]N;F5C="!T;R!T:&4@24U!4"!S97)V
M97(*("`@("`@("`D:6UA<"`](&YE=R!.971?24U!4"@D8V]N9ELG:V]L86(G
M75LG:6UA<"==6R=S97)V97(G72P@)&-O;F9;)VMO;&%B)UU;)VEM87`G75LG
M<&]R="==*3L*"B`@("`@("`@+R\@3&]G:6X@=7-I;F<@=&AE(&-U<G)E;G0@
M2&]R9&4@8W)E9&5N=&EA;',*("`@("`@("`D<F5S=6QT(#T@)&EM87`M/FQO
M9VEN*$%U=&@Z.F=E=$%U=&@H*2P@075T:#HZ9V5T0W)E9&5N=&EA;"@G<&%S
M<W=O<F0G*2P@9F%L<V4L(&9A;'-E*3L*("`@("`@("!I9B`H:7-?82@D<F5S
M=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-
M97-S86=E*"=5;F%B;&4@=&\@875T:&5N=&EC871E('=I=&@@=&AE($MO;&%B
M($E-05`@<V5R=F5R)RP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%
M4E(I.PH@("`@("`@("`@("`D:6UA<"T^9&ES8V]N;F5C="@I.PH@("`@("`@
M("`@("!R971U<FX@)&9O;&1E<G,["B`@("`@("`@?0H*("`@("`@("`O+R!/
M8G1A:6X@82!L:7-T(&]F(&%L;"!F;VQD97)S('1H92!C=7)R96YT('5S97(@
M:&%S(&%C8V5S<R!T;PH@("`@("`@("1F;VQD97)?;&ES="`]("1I;6%P+3YG
M971-86EL8F]X97,H*3L*("`@("`@("!I9B`H:7-?82@D9F]L9&5R7VQI<W0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A
M9V4H)U5N86)L92!T;R!O8G1A:6X@24U!4"!F;VQD97(@;&ES="<L(%]?1DE,
M15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@)&EM
M87`M/F1I<V-O;FYE8W0H*3L*("`@("`@("`@("`@<F5T=7)N("1F;VQD97)S
M.PH@("`@("`@('T*"B`@("`@("`@+R\@271E<F%T92!O=F5R(&%L;"!T:&4@
M9F]L9&5R<R!O8G1A:6YI;F<@=&AE:7(@9W)O=7!W87)E('1Y<&5S"B`@("`@
M("`@9F]R96%C:"`H)&9O;&1E<E]L:7-T(&%S("1F;VQD97(I('L*("`@("`@
M("`@("`@)&9O;&1E<G1Y<&4@/2`G;6%I;"<["@H@("`@("`@("`@("`D86YN
M;W1A=&EO;B`]("1I;6%P+3YG971!;FYO=&%T:6]N*$M/3$%"7T%.3D]47T9/
M3$1%4E]465!%+"`G=F%L=64N<VAA<F5D)RP@)&9O;&1E<BD["B`@("`@("`@
M("`@(&EF("@A:7-?82@D86YN;W1A=&EO;BP@)U!%05)?17)R;W(G*2`F)B`A
M96UP='DH)&%N;F]T871I;VXI*2!["B`@("`@("`@("`@("`@("`D='EP92`]
M(&5X<&QO9&4H)RXG+"`D86YN;W1A=&EO;BD["B`@("`@("`@("`@("`@("!I
M9B`H*"%E;7!T>2@D='EP95LQ72D@)B8@)'1Y<&5;,5T@/3T@)V1E9F%U;'0G
M*2!\?"`H96UP='DH)'1Y<&5;,5TI*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1F;VQD97)T>7!E(#T@)'1Y<&5;,%T["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1F;VQD97)S6UT@/2!A<G)A>2@D
M9F]L9&5R+"`D9F]L9&5R='EP92D["B`@("`@("`@?0H*("`@("`@("`D:6UA
M<"T^9&ES8V]N;F5C="@I.PH*("`@("`@("!R971U<FX@)&9O;&1E<G,["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!4<FEG9V5R<R!T:&4@9G)E96)U<WD@=7!D
M871E(&9O<B!T:&4@9VEV96X@<VAA<F4@=6ED+@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;&5A;B!4<G5E(&EF('5P9&%T92!W87,@<W5C8V5S<V9U;&PL
M(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@=')I9V=E
M<D9R965"=7-Y57!D871E*"1S:&%R95]U:60I"B`@("!["B`@("`@("`@)'-H
M87)E7VUA<"`]($MO;&%B.CIG9713:&%R94UA<"@I.PH@("`@("`@(&EF("AE
M;7!T>2@D<VAA<F5?;6%P6R1S:&%R95]U:61=*2D@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D9F]L9&5R7W!A=&@@
M/2`D<VAA<F5?;6%P6R1S:&%R95]U:61=.PH*("`@("`@("`O+R!)34%0('!A
M=&@@:7,@96ET:&5R("])3D)/6"\\<&%T:#Y`9&]M86EN(&]R("]U<V5R+W-O
M;65O;F4O/'!A=&@^0&1O;6%I;@H@("`@("`@("\O('-T<FEP(&1O;6%I;@H@
M("`@("`@("1E;F0@/2!S=')R<&]S*"1F;VQD97)?<&%T:"P@)T`G*3L*("`@
M("`@("`D9F]L9&5R(#T@<W5B<W1R*"1F;VQD97)?<&%T:"P@,"P@)&5N9"D[
M"@H@("`@("`@(&EF("@A)&9O;&1E<ELP72`]/2`G+R<I('L*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("`D<V5C;VYD7W-L
M87-H(#T@<W1R<&]S*"1F;VQD97(L("<O)RP@,2D["B`@("`@("`@:68@*"1S
M96-O;F1?<VQA<V@@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"@H@("`@("`@(&EF("AS=')N8VUP*"1F;VQD97(L
M("<O24Y"3U@O)RP@-RD@/3T@,"D@>PH@("`@("`@("`@("`D9F]L9&5R(#T@
M075T:#HZ9V5T075T:"@I+G-U8G-T<B@D9F]L9&5R+"`D<V5C;VYD7W-L87-H
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9F]L9&5R(#T@<W5B
M<W1R*"1F;VQD97(L("1S96-O;F1?<VQA<V@@*R`Q*3L*("`@("`@("!]"B`@
M("`@("`@)'5R;"`]("=H='1P<SHO+R<@+B`D1TQ/0D%,4ULG8V]N9B==6R=K
M;VQA8B==6R=I;6%P)UU;)W-E<G9E<B==("X@)R]F<F5E8G5S>2]T<FEG9V5R
M+R<@+B`D9F]L9&5R("X@)RYP9F(G.PH*("`@("`@("`O+R!N;W<@<W1A<G0@
M=&AE(')E<75E<W0*("`@("`@("!R97%U:7)E7V]N8V4@)TA45%`O4F5Q=65S
M="YP:'`G.PH@("`@("`@("1H='1P(#T@;F5W($A45%!?4F5Q=65S="@D=7)L
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G;65T
M:&]D)R`]/B`G1T54)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W1I;65O=70G(#T^(#4L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=A;&QO=U)E9&ER96-T<R<@/3X@=')U92DI
M.PH@("`@("`@("1H='1P+3YS971"87-I8T%U=&@H075T:#HZ9V5T075T:"@I
M+"!!=71H.CIG971#<F5D96YT:6%L*"=P87-S=V]R9"<I*3L*"B`@("`@("`@
M0"1H='1P+3YS96YD4F5Q=65S="@I.PH@("`@("`@(&EF("@D:'1T<"T^9V5T
M4F5S<&]N<V5#;V1E*"D@(3T@,C`P*2!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O('1R:6=G97(@
M9G)E92]B=7-Y('5P9&%T92!F;W(@)7,B*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&5M86EL*2D["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O1&%T851R
M964N<&AP````````````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`Q
M-#,U-#`@,3`U,34T,S,W-#`@,#(Q-34U`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"@HO*BH*("H@3&ES="!E=F5R
M>2!O8FIE8W0@:6X@86X@87)R87DL('-I;6EL87(@=&\@4$5!4B]H=&UL+VUE
M;G4N<&AP+@H@*B\*9&5F:6YE*"=$051!5%)%15]&3U)-051?5%)%12<L(#$I
M.PH*+RHJ"B`J($=E="!A(&9U;&P@;&ES="`M(&%N(&%R<F%Y(&]F(&ME>7,N
M"B`J+PID969I;F4H)T1!5$%44D5%7T9/4DU!5%]&3$%4)RP@,BD["@HO*BH*
M("H@5&AE(')O;W0@96QE;65N="`H=&]P+6QE=F5L('!A<F5N="D@;V8@96%C
M:"!$871A5')E92!G<F]U<"X*("HO"F1E9FEN92@G1$%40512145?4D]/5"<L
M("TQ*3L*"B\J*@H@*B!"=6EL9"!A(&YO<FUA;"!S96QE8W0@<75E<GDN"B`J
M+PID969I;F4H)T1!5$%44D5%7T)524Q$7U-%3$5#5"<L(#`I.PH*+RHJ"B`J
M($)U:6QD(&$@8V]U;G0@;VYL>2!Q=65R>2X*("HO"F1E9FEN92@G1$%40512
M145?0E5)3$1?0T]53E0G+"`Q*3L*"B\J*@H@*B!4:&4@1&%T851R964Z.B!C
M;&%S<R!P<F]V:61E<R!A(&-O;6UO;B!A8G-T<F%C=&5D(&EN=&5R9F%C92!I
M;G1O('1H90H@*B!V87)I;W5S(&)A8VME;F1S(&9O<B!T:&4@2&]R9&4@1&%T
M851R964@<WES=&5M+@H@*@H@*B!!('!I96-E(&]F(&1A=&$@:7,@:G5S="!A
M('1I=&QE('1H870@:7,@<V%V960@:6X@=&AE('!A9V4@9F]R('1H92!N=6QL
M"B`J(&1R:79E<B!O<B!C86X@8F4@<V%V960@:6X@82!D871A8F%S92!T;R!B
M92!A8V-E<W-E9"!F<F]M(&5V97)Y=VAE<F4N($5V97)Y"B`J('-T;W)E9"!O
M8FIE8W0@;75S="!H879E(&$@9&EF9F5R96YT(&YA;64@*&EN<VED92!E86-H
M(&=R;W5P:60I+@H@*@H@*B!297%U:7)E9"!V86QU97,@9F]R("1P87)A;7,Z
M/'!R93X*("H@("`G9W)O=7`G("TM($1E9FEN92!E86-H(&=R;W5P(&]F(&]B
M:F5C=',@=V4@=V%N="!T;R!B=6EL9"X\+W!R93X*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO1&%T851R964O1&%T851R964N<&AP+'8@,2XQ-3$N,BXQ."`R
M,#`V+S`W+S$S(#`X.C4X.C0T(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,3DY.2TR,#`S(%-T97!H86YE($AU=&AE<B`\<VAU=&AE<D!B:6=F;V]T+F-O
M;3X*("H@0V]P>7)I9VAT(#(P,#$M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@
M9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@(%-T
M97!H86YE($AU=&AE<B`\<VAU=&AE<D!B:6=F;V]T+F-O;3X*("H@0&%U=&AO
M<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC
M92`@($AO<F1E(#(N,0H@*B!`<&%C:V%G92!(;W)D95]$871A5')E90H@*B\*
M8VQA<W,@1&%T851R964@>PH*("`@("\J*@H@("`@("H@07)R87D@;V8@86QL
M(&1A=&$Z(&EN9&5X960@8GD@:60N(%1H92!F;W)M870@:7,Z(&%R<F%Y*&ED
M(#T^"B`@("`@*B`G;F%M92<@/3X@;F%M92P@)W!A<F5N="<@/3X@<&%R96YT
M*2X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D
M7V1A=&$@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@02!H87-H('1H870@
M8V%N(&)E('5S960@=&\@;6%P(&$@9G5L;"!O8FIE8W0@;F%M90H@("`@("H@
M*'!A<F5N=#IC:&EL9#IO8FIE8W0I('1O('1H870@;V)J96-T)W,@=6YI<75E
M($E$+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R
M("1?;F%M94UA<"`](&%R<F%Y*"D["@H@("`@("\J*@H@("`@("H@06-T=6%L
M(&%T=')I8G5T92!S;W)T:6YG(&AA<V@N"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)%]S;W)T2&%S:"`](&YU;&P["@H@("`@
M+RHJ"B`@("`@*B!(87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T
M97)S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R
M("1?<&%R86US(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C
M=&]R+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA
M<V@@8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P87)A
M;65T97)S(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!792!A;'=A>7,@;F5E9"`G9W)O=7`G+"!A('-T<FEN
M9R!T:&%T(&1E9FEN97,@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@<')E9FEX(&9O<B!E86-H('-E="!O9B!H:65R87)C:&EC86P@9&%T82X*
M("`@("`J+PH@("`@9G5N8W1I;VX@1&%T851R964H)'!A<F%M<R`](&YU;&PI
M"B`@("!["B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A('!A<F%M971E<B!O9B!T:&ES
M($1A=&%4<F5E(&EN<W1A;F-E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'!A<F%M("!4:&4@<&%R86UE=&5R('1O(')E='5R;BX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@<&%R86UE=&5R)W,@=F%L=64@;W(@
M;G5L;"!I9B!I="!D;V5S;B=T(&5X:7-T+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971087)A;2@D<&%R86TI"B`@("!["B`@("`@("`@<F5T=7)N(&ES<V5T
M*"1T:&ES+3Y?<&%R86US6R1P87)A;5TI(#\@)'1H:7,M/E]P87)A;7-;)'!A
M<F%M72`Z(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S(&%N
M(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1O8FIE8W0@
M(%1H92!O8FIE8W0@=&\@<F5M;W9E+@H@("`@("H@0'!A<F%M("1F;W)C92`@
M("`@("`@("!&;W)C92!R96UO=F%L(&]F(&5V97)Y(&-H:6QD(&]B:F5C=#\*
M("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E*"1O8FIE8W0L("1F;W)C92`]
M(&9A;'-E*0H@("`@>PH@("`@("`@(&EF("AI<U]A*"1O8FIE8W0L("=$871A
M5')E94]B:F5C="<I*2!["B`@("`@("`@("`@("1O8FIE8W0@/2`D;V)J96-T
M+3YG971.86UE*"D["B`@("`@("`@?0H*("`@("`@("!I9B`H(21T:&ES+3YE
M>&ES=',H)&]B:F5C="DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H)&]B:F5C="`N("<@9&]E<R!N;W0@97AI<W0G*3L*("`@("`@
M("!]"@H@("`@("`@("1C:&EL9')E;B`]("1T:&ES+3YG971.=6UB97)/9D-H
M:6QD<F5N*"1O8FIE8W0I.PH@("`@("`@(&EF("@D8VAI;&1R96XI('L*("`@
M("`@("`@("`@+RH@5$]$3SH@<F5M;W9E(&-H:6QD<F5N(&EF("1F;W)C92`]
M/2!T<G5E("HO"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*'-P<FEN=&8H7R@B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N
M(BDL(&-O=6YT*"1C:&EL9')E;BDI*3L*("`@("`@("!]"@H@("`@("`@("1I
M9"`]("1T:&ES+3YG971)9"@D;V)J96-T*3L*("`@("`@("`D<&ED(#T@)'1H
M:7,M/F=E=%!A<F5N="@D;V)J96-T*3L*("`@("`@("`D;W)D97(@/2`D=&AI
M<RT^7V1A=&%;)&ED75LG;W)D97(G73L*("`@("`@("!U;G-E="@D=&AI<RT^
M7V1A=&%;)&ED72D["B`@("`@("`@=6YS970H)'1H:7,M/E]N86UE36%P6R1I
M9%TI.PH*("`@("`@("`O+R!3:&EF="!D;W=N('1H92!O<F1E<B!P;W-I=&EO
M;G,N"B`@("`@("`@)'1H:7,M/E]R96]R9&5R*"1P:60L("1O<F1E<BD["@H@
M("`@("`@(')E='5R;B`D:60["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO
M=F5S(&%L;"!$871A5')E92!O8FIE8W1S(&]W;F5D(&)Y(&$@8V5R=&%I;B!U
M<V5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97(@($$@=7-E
M<B!N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F55<V5R1&%T82@D
M=7-E<BD*("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G
M;F]T('-U<'!O<G1E9"<I.PH@("`@?0H*("`@("\J*@H@("`@("H@36]V92!A
M;B!O8FIE8W0@=&\@82!N97<@<&%R96YT+@H@("`@("H*("`@("`J($!P87)A
M;2!M:7AE9"`D;V)J96-T("`@("`@5&AE(&]B:F5C="!T;R!M;W9E+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;F5W<&%R96YT("!4:&4@;F5W('!A<F5N="!O
M8FIE8W0N($1E9F%U;'1S('1O('1H92!R;V]T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!M;W9E*"1O8FIE8W0L("1N97=P87)E;G0@/2!N=6QL*0H@("`@>PH@
M("`@("`@("1C:60@/2`D=&AI<RT^9V5T260H)&]B:F5C="D["B`@("`@("`@
M:68@*&ES7V$H)&-I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*"=/8FIE8W0@=&\@;6]V
M92!D;V5S(&YO="!E>&ES=#H@)7,G+"`D8VED+3YG971-97-S86=E*"DI*3L*
M("`@("`@("!]"@H@("`@("`@(&EF("@A:7-?;G5L;"@D;F5W<&%R96YT*2D@
M>PH@("`@("`@("`@("`D<&ED(#T@)'1H:7,M/F=E=$ED*"1N97=P87)E;G0I
M.PH@("`@("`@("`@("!I9B`H:7-?82@D<&ED+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I
M;G1F*"=.97<@<&%R96YT(&1O97,@;F]T(&5X:7-T.B`E<R<L("1P:60M/F=E
M=$UE<W-A9V4H*2DI.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'!I9"`]($1!5$%44D5%7U)/3U0["B`@("`@("`@?0H*
M("`@("`@("`D=&AI<RT^7V1A=&%;)&-I9%U;)W!A<F5N="==(#T@)'!I9#L*
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M:&%N9V4@86X@;V)J96-T)W,@;F%M92X*("`@("`J"B`@("`@*B!`<&%R86T@
M;6EX960@("1O;&1?;V)J96-T("`@("`@(%1H92!O;&0@;V)J96-T+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;F5W7V]B:F5C=%]N86UE("!4:&4@;F5W(&]B
M:F5C="!N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YA;64H)&]L9%]O
M8FIE8W0L("1N97=?;V)J96-T7VYA;64I"B`@("!["B`@("`@("`@+RH@0VAE
M8VL@=VAE=&AE<B!T:&4@;V)J96-T(&5X:7-T<R!A="!A;&P@*B\*("`@("`@
M("!I9B`H(21T:&ES+3YE>&ES=',H)&]L9%]O8FIE8W0I*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"1O;&1?;V)J96-T("X@)R!D
M;V5S(&YO="!E>&ES="<I.PH@("`@("`@('T*"B`@("`@("`@+RH@0VAE8VL@
M9F]R(&1U<&QI8V%T97,@+2!G970@<&%R96YT(&%N9"!C<F5A=&4@;F5W(&]B
M:F5C=`H@("`@("`@("`J(&YA;64@*B\*("`@("`@("`D<&%R96YT(#T@)'1H
M:7,M/F=E=$YA;64H)'1H:7,M/F=E=%!A<F5N="@D;VQD7V]B:F5C="DI.PH@
M("`@("`@(&EF("@D=&AI<RT^97AI<W1S*"1P87)E;G0@+B`G.B<@+B`D;F5W
M7V]B:F5C=%]N86UE*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@G1'5P;&EC871E(&YA;64@)R`N("1N97=?;V)J96-T7VYA;64I
M.PH@("`@("`@('T*"B`@("`@("`@+RH@4F5P;&%C92!T:&4@;VQD(&YA;64@
M=VET:"!T:&4@;F5W(&]N92!I;B!T:&4@8V%C:&4@*B\*("`@("`@("`D;VQD
M7V]B:F5C=%]I9"`]("1T:&ES+3YG971)9"@D;VQD7V]B:F5C="D["B`@("`@
M("`@)'1H:7,M/E]D871A6R1O;&1?;V)J96-T7VED75LG;F%M92==(#T@)&YE
M=U]O8FIE8W1?;F%M93L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#:&%N9V5S('1H92!O<F1E<B!O9B!T:&4@8VAI;&1R
M96X@;V8@86X@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'!A<F5N="`@5&AE(&9U;&P@:60@<&%T:"!O9B!T:&4@<&%R96YT(&]B:F5C
M="X*("`@("`J($!P87)A;2!M:7AE9"`D;W)D97(@("`@268@86X@87)R87D@
M:70@<W!E8VEF:65S('1H92!N97<@<&]S:71I;VYS(&9O<@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("!A;&P@8VAI;&0@;V)J96-T<RX*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@268@86X@:6YT96=E<B!A;F0@)&-I
M9"!I<R!S<&5C:69I960L('1H92!P;W-I=&EO;@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("!W:&5R92!T:&4@8VAI;&0@<W!E8VEF:65D(&)Y("1C
M:60@:7,@:6YS97)T960N($EF"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("1C:60@:7,@;F]T('-P96-I9FEE9"P@=&AE('!O<VET:6]N(&=E=',@
M9&5L971E9"P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@8V%U<VEN
M9R!T:&4@9F]L;&]W:6YG('!O<VET:6]N<R!T;R!S:&EF="!U<"X*("`@("`J
M($!P87)A;2!I;G1E9V5R("1C:60@("`@4V5E("1O<F1E<BX*("`@("`J+PH@
M("`@9G5N8W1I;VX@<F5O<F1E<B@D<&%R96YT<RP@)&]R9&5R(#T@;G5L;"P@
M)&-I9"`](&YU;&PI"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)VYO="!S=7!P;W)T960G*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($-H86YG92!O<F1E<B!O9B!C:&EL9')E;B!O9B!A;B!O8FIE8W0N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&ED("`@("!4:&4@<&%R96YT(&]B
M:F5C="!I9"!S=')I;F<@<&%T:"X*("`@("`J($!P87)A;2!M:7AE9"`D;W)D
M97(@("`@4W!E8VEF:6,@;F5W(&]R9&5R('!O<VET:6]N(&]R(&%N(&%R<F%Y
M(&-O;G1A:6YI;F<*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@=&AE
M(&YE=R!P;W-I=&EO;G,@9F]R('1H92!G:79E;B!P87)E;G0N"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D8VED("`@($EF('!R;W9I9&5D(&EN9&EC871E<R!I
M;G-E<G1I;VX@;V8@82!N97<@8VAI;&0@=&\*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@=&AE('!A<F5N="!T;R!A=F]I9"!I;F-R96UE;G1I;F<@
M:70@=VAE;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!S:&EF=&EN
M9R!U<"!A;&P@;W1H97(@8VAI;&1R96XG<R!O<F1E<BX@268@;F]T"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@('!R;W9I9&5D(&EN9&EC871E<R!D
M96QE=&EO;BP@<V\@<VAI9G0@86QL(&]T:&5R"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@('!O<VET:6]N<R!D;W=N(&]N92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@7W)E;W)D97(H)'!I9"P@)&]R9&5R(#T@;G5L;"P@)&-I9"`]
M(&YU;&PI"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D;W)D97(I("8F
M("%I<U]N=6QL*"1O<F1E<BDI('L*("`@("`@("`@("`@+R\@4VEN9VQE('5P
M9&%T92`H861D+V1E;"DN"B`@("`@("`@("`@(&EF("AI<U]N=6QL*"1C:60I
M*2!["B`@("`@("`@("`@("`@("`O+R!.;R!I9"!G:79E;B!S;R!S:'5F9FQE
M(&1O=VXN"B`@("`@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7V1A=&$@
M87,@)&-?:V5Y(#T^("1C7W9A;"D@>PH@("`@("`@("`@("`@("`@("`@(&EF
M("@D=&AI<RT^7V1A=&%;)&-?:V5Y75LG<&%R96YT)UT@/3T@)'!I9`H@("`@
M("`@("`@("`@("`@("`@("`@("`F)B`D=&AI<RT^7V1A=&%;)&-?:V5Y75LG
M;W)D97(G72`^("1O<F1E<BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7V1A=&%;)&-?:V5Y75LG;W)D97(G72TM.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("\O(%=E(&AA=F4@86X@:60@<V\@<VAU9F9L
M92!U<"X*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?9&%T82!A
M<R`D8U]K97D@/3X@)&-?=F%L*2!["B`@("`@("`@("`@("`@("`@("`@:68@
M*"1C7VME>2`A/2`D8VED("`F)B`D=&AI<RT^7V1A=&%;)&-?:V5Y75LG<&%R
M96YT)UT@/3T@)'!I9`H@("`@("`@("`@("`@("`@("`@("`@("`F)B`D=&AI
M<RT^7V1A=&%;)&-?:V5Y75LG;W)D97(G72`^/2`D;W)D97(I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D871A6R1C7VME>5U;)V]R9&5R
M)UTK*SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V5I9B`H:7-?87)R87DH)&]R
M9&5R*2`F)B!C;W5N="@D;W)D97(I*2!["B`@("`@("`@("`@("\O($UU;'1I
M('5P9&%T92X*("`@("`@("`@("`@9F]R96%C:"`H)&]R9&5R(&%S("1O<F1E
M<E]P;W-I=&EO;B`]/B`D8VED*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7V1A=&%;)&-I9%U;)V]R9&5R)UT@/2`D;W)D97)?<&]S:71I;VX["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>'!L
M:6-I=&QY('-E="!T:&4@;W)D97(@9F]R(&$@9&%T871R964@;V)J96-T+@H@
M("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!P87)A;2!I
M;G1E9V5R("1I9"`@("`@5&AE(&1A=&%T<F5E(&]B:F5C="!I9"!T;R!C:&%N
M9V4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;W)D97(@(%1H92!N97<@;W)D
M97(N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$]R9&5R*"1I9"P@)&]R9&5R
M*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=N;W0@
M<W5P<&]R=&5D)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$>6YA;6EC86QL
M>2!D971E<FUI;F5S('1H92!O8FIE8W0@8VQA<W,N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1A='1R:6)U=&5S("!4:&4@<V5T(&]F(&%T=')I8G5T
M97,@=&AA="!C;VYT86EN('1H92!C;&%S<PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("!I;F9O<FUA=&EO;BX@1&5F875L=',@=&\@1&%T851R
M965/8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]D969I;F5/8FIE8W1#
M;&%S<R@D871T<FEB=71E<RD*("`@('L*("`@("`@("!G;&]B86P@)')E9VES
M=')Y.PH*("`@("`@("`D8VQA<W,@/2`G1&%T851R965/8FIE8W0G.PH@("`@
M("`@(&EF("@A:7-?87)R87DH)&%T=')I8G5T97,I*2!["B`@("`@("`@("`@
M(')E='5R;B`D8VQA<W,["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D
M871T<FEB=71E<R!A<R`D871T<BD@>PH@("`@("`@("`@("!I9B`H)&%T=');
M)VYA;64G72`]/2`G1&%T851R964G*2!["B`@("`@("`@("`@("`@("!I9B`H
M)&%T=');)VME>2==(#T]("=O8FIE8W1#;&%S<R<I('L*("`@("`@("`@("`@
M("`@("`@("`D8VQA<W,@/2`D871T<ELG=F%L=64G73L*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T@96QS96EF("@D871T
M<ELG:V5Y)UT@/3T@)V]B:F5C=%1Y<&4G*2!["B`@("`@("`@("`@("`@("`@
M("`@)')E<W5L="`](&5X<&QO9&4H)R\G+"`D871T<ELG=F%L=64G72D["B`@
M("`@("`@("`@("`@("`@("`@)&-L87-S(#T@)')E9VES=')Y+3YC86QL0GE0
M86-K86=E*"1R97-U;'1;,%TL("=D969I;F5#;&%S<R<L(&%R<F%Y*"=T>7!E
M)R`]/B`D<F5S=6QT6S%=*2D["B`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D8VQA<W,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS(&$@1&%T851R965/8FIE8W0@*&]R('-U8F-L87-S*2!O8FIE8W0@
M;V8@=&AE(&1A=&$@:6X@=&AE"B`@("`@*B!O8FIE8W0@9&5F:6YE9"!B>2`D
M;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&]B:F5C="`@
M5&AE(&]B:F5C="!T;R!F971C:#H@)W!A<F5N=#IS=6(M<&%R96YT.FYA;64G
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VQA<W,@("!3=6)C;&%S<R!O9B!$
M871A5')E94]B:F5C="!T;R!U<V4N($1E9F%U;'1S('1O"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@($1A=&%4<F5E3V)J96-T+B!.=6QL(&9O<F-E
M<R!T:&4@9')I=F5R('1O(&QO;VL*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@:6YT;R!T:&4@871T<FEB=71E<R!T86)L92!T;R!D971E<FUI;F4@
M=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@('-U8F-L87-S('1O
M('5S92X@268@;F]N92!I<R!F;W5N9"!I="!U<V5S"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@($1A=&%4<F5E3V)J96-T+@H@("`@("HO"B`@("!F
M=6YC=&EO;B`F9V5T3V)J96-T*"1O8FIE8W0L("1C;&%S<R`]("=$871A5')E
M94]B:F5C="<I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1O8FIE8W0I*2![
M"B`@("`@("`@("`@("1E<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H)TYO(&]B
M:F5C="!R97%U97-T960N)RD["B`@("`@("`@("`@(')E='5R;B`D97)R;W([
M"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7VQO860H)&]B:F5C="D["B`@
M("`@("`@:68@*"$D=&AI<RT^97AI<W1S*"1O8FIE8W0I*2!["B`@("`@("`@
M("`@("1E<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H)&]B:F5C="`N("<@;F]T
M(&9O=6YD+B<I.PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@
M('T*"B`@("`@("`@)'5S95]A='1R:6)U=&5S(#T@:7-?;G5L;"@D8VQA<W,I
M('Q\(&ES7V-A;&QA8FQE*&%R<F%Y*"1C;&%S<RP@)U]F<F]M071T<FEB=71E
M<R<I*3L*("`@("`@("!I9B`H)'5S95]A='1R:6)U=&5S*2!["B`@("`@("`@
M("`@("1A='1R:6)U=&5S(#T@)'1H:7,M/F=E=$%T=')I8G5T97,H)'1H:7,M
M/F=E=$ED*"1O8FIE8W0I*3L*("`@("`@("`@("`@:68@*&ES7V$H)&%T=')I
M8G5T97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D871T<FEB=71E<SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@
M*&ES7VYU;&PH)&-L87-S*2D@>PH@("`@("`@("`@("`@("`@)&-L87-S(#T@
M)'1H:7,M/E]D969I;F5/8FIE8W1#;&%S<R@D871T<FEB=71E<RD["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S
M*"1C;&%S<RDI('L*("`@("`@("`@("`@)&5R<F]R(#T@4$5!4CHZ<F%I<V5%
M<G)O<B@D8VQA<W,@+B`G(&YO="!F;W5N9"XG*3L*("`@("`@("`@("`@<F5T
M=7)N("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@("1D871A3V(@/2`F;F5W
M("1C;&%S<R@D;V)J96-T*3L*("`@("`@("`D9&%T84]B+3YS971$871A5')E
M92@D=&AI<RD["B`@("`@("`@+RH@268@=&AE(&-L87-S(&AA<R!A(%]F<F]M
M071T<FEB=71E<R!M971H;V0L(&QO860@9&%T82!F<F]M"B`@("`@("`@("H@
M=&AE(&%T=')I8G5T97,@8F%C:V5N9"X@*B\*("`@("`@("!I9B`H)'5S95]A
M='1R:6)U=&5S*2!["B`@("`@("`@("`@("1D871A3V(M/E]F<F]M071T<FEB
M=71E<R@D871T<FEB=71E<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@+RH@3W1H97)W:7-E(&QO860@:70@9G)O;2!T:&4@;VQD(&1A=&$@<W1O
M<F%G92!F:65L9"X@*B\*("`@("`@("`@("`@)&1A=&%/8BT^<V5T1&%T82@D
M=&AI<RT^9V5T1&%T82@D=&AI<RT^9V5T260H)&]B:F5C="DI*3L*("`@("`@
M("!]"@H@("`@("`@("1D871A3V(M/G-E=$]R9&5R*"1T:&ES+3YG971/<F1E
M<B@D;V)J96-T*2D["B`@("`@("`@<F5T=7)N("1D871A3V(["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS(&$@1&%T851R965/8FIE8W0@*&]R('-U
M8F-L87-S*2!O8FIE8W0@;V8@=&AE(&1A=&$@:6X@=&AE"B`@("`@*B!O8FIE
M8W0@=VET:"!T:&4@240@)&ED+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E
M9V5R("1I9"`@("!!;B!O8FIE8W0@:60N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1C;&%S<R`@4W5B8VQA<W,@;V8@1&%T851R965/8FIE8W0@=&\@=7-E+B!$
M969A=6QT<R!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@($1A=&%4
M<F5E3V)J96-T+B!.=6QL(&9O<F-E<R!T:&4@9')I=F5R('1O(&QO;VL*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("!I;G1O('1H92!A='1R:6)U=&5S
M('1A8FQE('1O(&1E=&5R;6EN92!T:&4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!S=6)C;&%S<R!T;R!U<V4N($EF(&YO;F4@:7,@9F]U;F0@:70@
M=7-E<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@($1A=&%4<F5E3V)J
M96-T+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T3V)J96-T0GE)9"@D:60L
M("1C;&%S<R`]("=$871A5')E94]B:F5C="<I"B`@("!["B`@("`@("`@:68@
M*&5M<'1Y*"1I9"DI('L*("`@("`@("`@("`@)&]B:F5C="`](%!%05(Z.G)A
M:7-E17)R;W(H)TYO(&ED(')E<75E<W1E9"XG*3L*("`@("`@("`@("`@<F5T
M=7)N("1O8FIE8W0["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@)'1H
M:7,M/E]L;V%D0GE)9"@D:60I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("`@("`@?0H*("`@("`@("`D=7-E7V%T=')I8G5T97,@/2!I<U]N=6QL
M*"1C;&%S<RD@?'P@:7-?8V%L;&%B;&4H87)R87DH)&-L87-S+"`G7V9R;VU!
M='1R:6)U=&5S)RDI.PH@("`@("`@(&EF("@D=7-E7V%T=')I8G5T97,I('L*
M("`@("`@("`@("`@)&%T=')I8G5T97,@/2`D=&AI<RT^9V5T071T<FEB=71E
M<R@D:60I.PH@("`@("`@("`@("!I9B`H:7-?82@D871T<FEB=71E<RP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1A='1R:6)U
M=&5S.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H:7-?;G5L;"@D
M8VQA<W,I*2!["B`@("`@("`@("`@("`@("`D8VQA<W,@/2`D=&AI<RT^7V1E
M9FEN94]B:F5C=$-L87-S*"1A='1R:6)U=&5S*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)&-L87-S*2D@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D8VQA<W,@
M+B`G(&YO="!F;W5N9"XG*3L*("`@("`@("!]"@H@("`@("`@("1N86UE(#T@
M)'1H:7,M/F=E=$YA;64H)&ED*3L*("`@("`@("`D9&%T84]B(#T@)FYE=R`D
M8VQA<W,H)&YA;64I.PH@("`@("`@("1D871A3V(M/G-E=$1A=&%4<F5E*"1T
M:&ES*3L*("`@("`@("`O*B!)9B!T:&4@8VQA<W,@:&%S(&$@7V9R;VU!='1R
M:6)U=&5S(&UE=&AO9"P@;&]A9"!D871A(&9R;VT*("`@("`@("`@*B!T:&4@
M871T<FEB=71E<R!B86-K96YD+B`J+PH@("`@("`@(&EF("@D=7-E7V%T=')I
M8G5T97,I('L*("`@("`@("`@("`@)&1A=&%/8BT^7V9R;VU!='1R:6)U=&5S
M*"1A='1R:6)U=&5S*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O
M*B!/=&AE<G=I<V4@;&]A9"!I="!F<F]M('1H92!O;&0@9&%T82!S=&]R86=E
M(&9I96QD+B`J+PH@("`@("`@("`@("`D9&%T84]B+3YS971$871A*"1T:&ES
M+3YG971$871A*"1I9"DI.PH@("`@("`@('T*"B`@("`@("`@)&1A=&%/8BT^
M<V5T3W)D97(H)'1H:7,M/F=E=$]R9&5R*"1N86UE*2D["B`@("`@("`@<F5T
M=7)N("1D871A3V(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N
M(&%R<F%Y(&]F($1A=&%4<F5E3V)J96-T("AO<B!S=6)C;&%S<RD@;V)J96-T
M<PH@("`@("H@8V]R<F5S<&]N9&EN9R!T;R!T:&4@;V)J96-T<R!I;B`D:61S
M+"!W:71H('1H92!O8FIE8W0*("`@("`J(&YA;65S(&%S('1H92!K97ES(&]F
M('1H92!A<G)A>2X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&ED<R`@
M("`@06X@87)R87D@;V8@;V)J96-T(&ED<RX*("`@("`J($!P87)A;2!S=')I
M;F<@)&-L87-S("!3=6)C;&%S<R!O9B!$871A5')E94]B:F5C="!T;R!U<V4N
M($1E9F%U;'1S('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@1&%T
M851R965/8FIE8W0N($YU;&P@9F]R8V5S('1H92!D<FEV97(@=&\@;&]O:PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@(&EN=&\@=&AE(&%T=')I8G5T
M97,@=&%B;&4@=&\@9&5T97)M:6YE('1H90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@('-U8F-L87-S('1O('5S92X@268@;F]N92!I<R!F;W5N9"!I
M="!U<V5S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@1&%T851R965/
M8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N("9G971/8FIE8W1S*"1I9',L
M("1C;&%S<R`]("=$871A5')E94]B:F5C="<I"B`@("!["B`@("`@("`@)')E
M<W5L="`]("1T:&ES+3Y?;&]A9$)Y260H)&ED<RD["B`@("`@("`@:68@*&ES
M7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@("1D969I;F5#;&%S<R`]
M(&ES7VYU;&PH)&-L87-S*3L*("`@("`@("`D871T<FEB=71E<R`](&ES7VYU
M;&PH)&-L87-S*2!\?"!I<U]C86QL86)L92AA<G)A>2@D8VQA<W,L("=?9G)O
M;4%T=')I8G5T97,G*2D["@H@("`@("`@(&EF("@D871T<FEB=71E<RD@>PH@
M("`@("`@("`@("`D9&%T82`]("1T:&ES+3YG971!='1R:6)U=&5S*"1I9',I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1D871A(#T@)'1H:7,M
M/F=E=$1A=&$H)&ED<RD["B`@("`@("`@?0H*("`@("`@("`D;V)J96-T<R`]
M(&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)&ED<R!A<R`D:60I('L*("`@
M("`@("`@("`@)&YA;64@/2`D=&AI<RT^9V5T3F%M92@D:60I.PH@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1N86UE*2`F)B`A96UP='DH)&1A=&%;)&ED72DI
M('L*("`@("`@("`@("`@("`@(&EF("@D9&5F:6YE0VQA<W,I('L*("`@("`@
M("`@("`@("`@("`@("`D8VQA<W,@/2`D=&AI<RT^7V1E9FEN94]B:F5C=$-L
M87-S*"1D871A6R1I9%TI.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D8VQA<W,@+B`G
M(&YO="!F;W5N9"XG*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("`@("`D;V)J96-T<ULD;F%M95T@/2`F;F5W("1C;&%S<R@D;F%M92D["B`@
M("`@("`@("`@("`@("`D;V)J96-T<ULD;F%M95TM/G-E=$1A=&%4<F5E*"1T
M:&ES*3L*("`@("`@("`@("`@("`@(&EF("@D871T<FEB=71E<RD@>PH@("`@
M("`@("`@("`@("`@("`@("1O8FIE8W1S6R1N86UE72T^7V9R;VU!='1R:6)U
M=&5S*"1D871A6R1I9%TI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`D;V)J96-T<ULD;F%M95TM/G-E=$1A=&$H)&1A
M=&%;)&ED72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M;V)J96-T<ULD;F%M95TM/G-E=$]R9&5R*"1T:&ES+3YG971/<F1E<B@D;F%M
M92DI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&]B:F5C=',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>'!O<G0@82!L:7-T
M(&]F(&]B:F5C=',N"B`@("`@*@H@("`@("H@0'!A<F%M(&-O;G-T86YT("1F
M;W)M870@("`@("!&;W)M870@;V8@=&AE(&5X<&]R=`H@("`@("H@0'!A<F%M
M('-T<FEN9R`@("1S=&%R=&QE868@("!4:&4@;F%M92!O9B!T:&4@;&5A9B!F
M<F]M('=H:6-H('=E('-T87)T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('1H92!E>'!O<G0@=')E92X*("`@("`J($!P87)A;2!B;V]L
M96%N("`D<F5L;V%D("`@("`@4F4M;&]A9"!T:&4@<F5Q=65S=&5D(&-H=6YK
M/R!$969A=6QT<R!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!F86QS92`H;VYL>2!W:&%T(&ES(&-U<G)E;G1L>2!L;V%D960I+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`@("1R;V]T;F%M92`@("!4:&4@;&%B96P@
M=&\@=7-E(&9O<B!T:&4@<F]O="!E;&5M96YT+@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!$969A=6QT<R!T;R!$051!5%)%15]23T]4
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@("1M87AD97!T:"`@("!4:&4@;6%X
M:6UU;2!N=6UB97(@;V8@;&5V96QS('1O(')E='5R;BX*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@1&5F875L=',@=&\@1$%40512145?
M4D]/5"P@=VAI8V@@:7,@;F\*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@;&EM:70N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`@)&QO8614
M<F5E("`@($QO860@82!T<F5E('-T87)T:6YG(&%T("1R;V]T+"!O<B!J=7-T
M('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R97%U
M97-T960@;&5V96P@86YD(&1I<F5C="!P87)E;G1S/PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!$969A=6QT<R!T;R!S:6YG;&4@;&5V
M96PN"B`@("`@*B!`<&%R86T@<W1R:6YG("`@)'-O<G1B>5]N86UE($%T=')I
M8G5T92!N86UE('1O('5S92!F;W(@<V]R=&EN9RX*("`@("`J($!P87)A;2!S
M=')I;F<@("`D<V]R=&)Y7VME>2`@071T<FEB=71E(&ME>2!T;R!U<V4@9F]R
M('-O<G1I;F<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`@)&1I<F5C=&EO;B`@
M(%-O<G0@9&ER96-T:6]N.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@,"`M(&%S8V5N9&EN9PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@,2`M(&1E<V-E;F1I;F<*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4:&4@=')E92!R97!R97-E;G1A=&EO;B!O9B!T:&4@
M;V)J96-T<RP@;W(@82!014%27T5R<F]R"B`@("`@*B`@("`@("`@("`@("`@
M("!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G970H)&9O<FUA
M="P@)'-T87)T;&5A9B`]($1!5$%44D5%7U)/3U0L("1R96QO860@/2!F86QS
M92P*("`@("`@("`@("`@("`@("`D<F]O=&YA;64@/2!$051!5%)%15]23T]4
M+"`D;6%X9&5P=&@@/2`M,2P@)&QO8614<F5E(#T@9F%L<V4L"B`@("`@("`@
M("`@("`@("`@)'-O<G1B>5]N86UE(#T@;G5L;"P@)'-O<G1B>5]K97D@/2!N
M=6QL+"`D9&ER96-T:6]N(#T@,"D*("`@('L*("`@("`@("`O*B!3970@<V]R
M=&EN9R!H87-H("HO"B`@("`@("`@:68@*"%I<U]N=6QL*"1S;W)T8GE?;F%M
M92D@?'P@(6ES7VYU;&PH)'-O<G1B>5]N86UE*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7W-O<G1(87-H(#T@1&%T851R964Z.G-O<G1(87-H*"1S=&%R=&QE
M868L("1S;W)T8GE?;F%M92P@)'-O<G1B>5]K97DL("1D:7)E8W1I;VXI.PH@
M("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]L;V%D*"1S=&%R=&QE868L("1L
M;V%D5')E92P@)')E;&]A9"P@)'-O<G1B>5]N86UE+"`D<V]R=&)Y7VME>2P@
M)&1I<F5C=&EO;BD["B`@("`@("`@)&]U="`](&%R<F%Y*"D["@H@("`@("`@
M('-W:71C:"`H)&9O<FUA="D@>PH@("`@("`@(&-A<V4@1$%40512145?1D]2
M34%47U12144Z"B`@("`@("`@("`@("1S=&%R=&ED(#T@)'1H:7,M/F=E=$ED
M*"1S=&%R=&QE868L("1M87AD97!T:"D["B`@("`@("`@("`@(&EF("AI<U]A
M*"1S=&%R=&ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)'-T87)T:60["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H
M:7,M/E]E>'1R86-T06QL3&5V96Q4<F5E*"1O=70L("1S=&%R=&ED+"`D;6%X
M9&5P=&@I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!$051!
M5%)%15]&3U)-051?1DQ!5#H*("`@("`@("`@("`@)'-T87)T:60@/2`D=&AI
M<RT^9V5T260H)'-T87)T;&5A9BD["B`@("`@("`@("`@(&EF("AI<U]A*"1S
M=&%R=&ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)'-T87)T:60["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M
M/E]E>'1R86-T06QL3&5V96Q,:7-T*"1O=70L("1S=&%R=&ED+"`D;6%X9&5P
M=&@I.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1O=71;1$%40512145?4D]/
M5%TI*2!["B`@("`@("`@("`@("`@("`D;W5T6T1!5$%44D5%7U)/3U1=(#T@
M)')O;W1N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!D969A=6QT.@H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@G3F]T('-U<'!O<G1E9"<I.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"%I<U]N=6QL*"1T:&ES+3Y?<V]R=$AA<V@I*2!["B`@("`@("`@("`@
M("\J(%)E<V5T('-O<G1I;F<@:&%S:"X@*B\*("`@("`@("`@("`@)'1H:7,M
M/E]S;W)T2&%S:"`](&YU;&P["B`@("`@("`@("`@("\J(%)E=F5R<V4@<VEN
M8V4@=&AE(&%T=')I8G5T92!S;W)T:6YG(&-O;6)I;F5D('=I=&@@=')E92!U
M<"UW87)D"B`@("`@("`@("`@("`J('-O<G1I;F<@<')O9'5C97,@82!R979E
M<G-E9"!O8FIE8W0@;W)D97(N("HO"B`@("`@("`@("`@("1O=70@/2!A<G)A
M>5]R979E<G-E*"1O=70L('1R=64I.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1O=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;W5N=',@;V)J96-T
M<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S=&%R=&QE868@(%1H
M92!N86UE(&]F('1H92!L96%F(&9R;VT@=VAI8V@@=V4@<W1A<G0*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]U;G1I;F<N"B`@("`@*@H@
M("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@;G5M8F5R(&]F('1H92!O8FIE
M8W1S(&)E;&]W("1S=&%R=&QE868N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O
M=6YT*"1S=&%R=&QE868@/2!$051!5%)%15]23T]4*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7V-O=6YT*"1S=&%R=&QE868I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0W)E871E(&%T=')I8G5T92!S;W)T(&AA<V@*("`@("`J
M"B`@("`@*B!`<VEN8V4@2&]R9&4@,RXQ"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`@)')O;W0@("`@("`@("!4:&4@;F%M92!O9B!T:&4@;&5A9B!F
M<F]M('=H:6-H('=E('-T87)T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('1H92!E>'!O<G0@=')E92X*("`@("`J($!P87)A;2!S=')I
M;F<@("1S;W)T8GE?;F%M92`@071T<FEB=71E(&YA;64@=&\@=7-E(&9O<B!S
M;W)T:6YG+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'-O<G1B>5]K97D@("!!
M='1R:6)U=&4@:V5Y('1O('5S92!F;W(@<V]R=&EN9RX*("`@("`J($!P87)A
M;2!I;G1E9V5R("1D:7)E8W1I;VX@("`@4V]R="!D:7)E8W1I;VXZ"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#`@+2!A<V-E;F1I;F<*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@,2`M(&1E<V-E
M;F1I;F<*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R!4:&4@<V]R="!H
M87-H"B`@("`@*B\*("`@(&9U;F-T:6]N('-O<G1(87-H*"1R;V]T+"`D<V]R
M=&)Y7VYA;64@/2!N=6QL+"`D<V]R=&)Y7VME>2`](&YU;&PL"B`@("`@("`@
M("`@("`@("`@("`@("`D9&ER96-T:6]N(#T@,"D*("`@('L*("`@("`@("!R
M971U<FX@<W!R:6YT9B@G)7,M)7,M)7,M)7,G+"`D<F]O="P@)'-O<G1B>5]N
M86UE+"`D<V]R=&)Y7VME>2P@)&1I<F5C=&EO;BD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!%>'!O<G0@82!L:7-T(&]F(&]B:F5C=',@:G5S="!L:6ME(&=E
M="@I(&%B;W9E+"!B=70@=7-E<R!A;@H@("`@("H@;V)J96-T(&ED('1O(&9E
M=&-H('1H92!L:7-T(&]F(&]B:F5C=',N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&-O;G-T86YT("1F;W)M870@("`@1F]R;6%T(&]F('1H92!E>'!O<G0N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("`D<W1A<G1L96%F("!4:&4@:60@;V8@=&AE
M(&QE868@9G)O;2!W:&EC:"!W92!S=&%R="!T:&4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&5X<&]R="!T<F5E+@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)')E;&]A9"`@("`@4F5L;V%D('1H92!R97%U97-T960@8VAU
M;FL_($1E9F%U;'1S('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!F86QS92`H;VYL>2!W:&%T(&ES(&-U<G)E;G1L>2!L;V%D960I+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`@)')O;W1N86UE("`@5&AE(&QA8F5L('1O
M('5S92!F;W(@=&AE(')O;W0@96QE;65N="X*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@($1E9F%U;'1S('1O($1!5$%44D5%7U)/3U0N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D;6%X9&5P=&@@("!4:&4@;6%X:6UU;2!N
M=6UB97(@;V8@;&5V96QS('1O(')E='5R;@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@1&5F875L=',@=&\@+3$L('=H:6-H(&ES(&YO(&QI
M;6ET+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!T<F5E(')E
M<')E<V5N=&%T:6]N(&]F('1H92!O8FIE8W1S+"!O<B!A(%!%05)?17)R;W(*
M("`@("`J("`@("`@("`@("`@("`@(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$)Y260H)&9O<FUA="P@)'-T87)T;&5A9B`]($1!5$%4
M4D5%7U)/3U0L("1R96QO860@/2!F86QS92P*("`@("`@("`@("`@("`@("`@
M("`@)')O;W1N86UE(#T@1$%40512145?4D]/5"P@)&UA>&1E<'1H(#T@+3$I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]L;V%D0GE)9"@D<W1A<G1L96%F*3L*
M("`@("`@("`D;W5T(#T@87)R87DH*3L*"B`@("`@("`@<W=I=&-H("@D9F]R
M;6%T*2!["B`@("`@("`@8V%S92!$051!5%)%15]&3U)-051?5%)%13H*("`@
M("`@("`@("`@)'1H:7,M/E]E>'1R86-T06QL3&5V96Q4<F5E*"1O=70L("1S
M=&%R=&QE868L("1M87AD97!T:"D["B`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("!C87-E($1!5$%44D5%7T9/4DU!5%]&3$%4.@H@("`@("`@("`@("`D
M=&AI<RT^7V5X=')A8W1!;&Q,979E;$QI<W0H)&]U="P@)'-T87)T;&5A9BP@
M)&UA>&1E<'1H*3L*("`@("`@("`@("`@:68@*"%E;7!T>2@D;W5T6T1!5$%4
M4D5%7U)/3U1=*2D@>PH@("`@("`@("`@("`@("`@)&]U=%M$051!5%)%15]2
M3T]472`]("1R;V]T;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)TYO="!S=7!P;W)T960G*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D;W5T.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!A(&QI<W0@;V8@86QL(&=R;W5P<R`H<F]O="!N;V1E<RD@;V8@=&AE
M(&1A=&$@=')E92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@
M=&AE(&=R;W5P($E$<PH@("`@("HO"B`@("!F=6YC=&EO;B!G971'<F]U<',H
M*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=N;W0@
M<W5P<&]R=&5D)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V92!D
M871A(&9O<B!A;B!O8FIE8W0@9G)O;2!T:&4@9&%T871R965?9&%T82!F:65L
M9"X*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D8VED("!4:&4@;V)J96-T(&ED('1O(&9E=&-H+"!O<B!A
M;B!A<G)A>2!O9B!O8FIE8W0@:61S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971$871A*"1C:60I"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)VYO="!S=7!P;W)T960G*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($EM<&]R="!A(&QI<W0@;V8@;V)J96-T<RX@57-E9"!B>2!D<FEV97)S('1O
M('!O<'5L871E('1H92!I;G1E<FYA;`H@("`@("H@)%]D871A(&%R<F%Y+@H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`@("1D871A("`@("!4:&4@9&%T
M82!T;R!I;7!O<G0N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D8VAA<G-E="`@
M5&AE(&-H87)S970@=&\@8V]N=F5R="!T:&4@;V)J96-T(&YA;64@9G)O;2X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<V5T*"1D871A+"`D8VAA<G-E="`](&YU
M;&PI"B`@("!["B`@("`@("`@)&-I9',@/2!A<G)A>2@I.PH@("`@("`@(&9O
M<F5A8V@@*"1D871A(&%S("1I9"`]/B`D8V%T*2!["B`@("`@("`@("`@(&EF
M("@A:7-?;G5L;"@D8VAA<G-E="DI('L*("`@("`@("`@("`@("`@("1C871;
M,5T@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1C871;,5TL("1C:&%R<V5T
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D8VED<ULD8V%T6S!=72`]
M("1C871;,5T["B`@("`@("`@("`@("1C<&%R96YT<ULD8V%T6S!=72`]("1C
M871;,ET["B`@("`@("`@("`@("1C;W)D97)S6R1C871;,%U=(#T@)&-A=%LS
M73L*("`@("`@("`@("`@)'-O<F1E<G-;)&-A=%LP75T@/2`D:60["B`@("`@
M("`@?0H*("`@("`@("!F;W)E86-H("@D8VED<R!A<R`D:60@/3X@)&YA;64I
M('L*("`@("`@("`@("`@)'1H:7,M/E]D871A6R1I9%U;)VYA;64G72`]("1N
M86UE.PH@("`@("`@("`@("`D=&AI<RT^7V1A=&%;)&ED75LG;W)D97(G72`]
M("1C;W)D97)S6R1I9%T["B`@("`@("`@("`@(&EF("@A:7-?;G5L;"@D=&AI
M<RT^7W-O<G1(87-H*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]D871A
M6R1I9%U;)W-O<G1E<B==6R1T:&ES+3Y?<V]R=$AA<VA=(#T@)'-O<F1E<G-;
M)&ED73L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(65M<'1Y*"1C
M<&%R96YT<ULD:61=*2D@>PH@("`@("`@("`@("`@("`@)'!A<F5N=',@/2!E
M>'!L;V1E*"<Z)RP@<W5B<W1R*"1C<&%R96YT<ULD:61=+"`Q*2D["B`@("`@
M("`@("`@("`@("`D<&%R(#T@)'!A<F5N='-;8V]U;G0H)'!A<F5N=',I("T@
M,5T["B`@("`@("`@("`@("`@("`D=&AI<RT^7V1A=&%;)&ED75LG<&%R96YT
M)UT@/2`D<&%R.PH*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'1H:7,M
M/E]N86UE36%P6R1P87)=*2D@>PH@("`@("`@("`@("`@("`@("`@("\O($EF
M('=E)W9E(&%L<F5A9'D@;&]A9&5D('1H92!D:7)E8W0@<&%R96YT(&]F"B`@
M("`@("`@("`@("`@("`@("`@+R\@=&AI<R!O8FIE8W0L('5S92!T:&%T('1O
M(&9I;F0@=&AE(&9U;&P@;F%M92X*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7VYA;65-87!;)&ED72`]("1T:&ES+3Y?;F%M94UA<%LD<&%R72`N("<Z
M)R`N("1N86UE.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`O+R!/=&AE<G=I<V4L(')U;B!T:')O=6=H('!A<F5N=',@
M;VYE(&)Y(&]N92!T;PH@("`@("`@("`@("`@("`@("`@("\O(&)U:6QD(&ET
M('5P+@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;F%M94UA<%LD:61=
M(#T@)R<["B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!A<F5N=',@
M87,@)'!A<DE$*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A96UP
M='DH)&-I9'-;)'!A<DE$72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?;F%M94UA<%LD:61=("X]("<Z)R`N("1C:61S6R1P87))
M1%T["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]N86UE36%P6R1I
M9%T@/2!S=6)S='(H)'1H:7,M/E]N86UE36%P6R1I9%TL(#$I("X@)SHG("X@
M)&YA;64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7V1A=&%;)&ED75LG<&%R96YT)UT@
M/2!$051!5%)%15]23T]4.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]N86UE
M36%P6R1I9%T@/2`D;F%M93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>'1R
M86-T(&]N92!L979E;"!O9B!D871A(&9O<B!A('!A<F5N="!L96%F+"!S;W)T
M960@9FER<W0@8GD*("`@("`J('1H96ER(&]R9&5R(&%N9"!T:&5N(&)Y(&YA
M;64N(%1H:7,@9G5N8W1I;VX@:7,@82!W87D@=&\@9V5T(&$*("`@("`J(&-O
M;&QE8W1I;VX@;V8@)&QE868G<R!C:&EL9')E;BX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1L96%F("!.86UE(&]F('1H92!P87)E;G0@9G)O;2!W
M:&EC:"!T;R!S=&%R="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]E>'1R86-T3VYE3&5V96PH)&QE868@/2!$
M051!5%)%15]23T]4*0H@("`@>PH@("`@("`@("1O=70@/2!A<G)A>2@I.PH@
M("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?9&%T82!A<R`D:60@/3X@)'9A;',I
M('L*("`@("`@("`@("`@:68@*"1V86QS6R=P87)E;G0G72`]/2`D;&5A9BD@
M>PH@("`@("`@("`@("`@("`@)&]U=%LD:61=(#T@)'9A;',["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]N=6QL*"1T:&ES+3Y?
M<V]R=$AA<V@I*2!["B`@("`@("`@("`@('5A<V]R="@D;W5T+"!A<G)A>2@D
M=&AI<RP@)U]C;7`G*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M=6%S;W)T*"1O=70L(&%R<F%Y*"1T:&ES+"`G7V-M<%-O<G1E9"<I*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D;W5T.PH@("`@?0H*("`@("\J*@H@
M("`@("H@17AT<F%C="!A;&P@;&5V96QS(&]F(&1A=&$L('-T87)T:6YG(&9R
M;VT@82!G:79E;B!P87)E;G0*("`@("`J(&QE868@:6X@=&AE(&1A=&%T<F5E
M+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D;W5T("`@("`@("`@5&AI
M<R!I<R!A;B!I=&5R871I;F<@9G5N8W1I;VXL('-O("1O=70@:7,*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@<&%S<V5D(&)Y(')E9F5R96YC
M92!T;R!C;VYT86EN('1H92!R97-U;'0N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("`D<&%R96YT("`@(%1H92!N86UE(&]F('1H92!P87)E;G0@9G)O;2!W:&EC
M:"!T;R!B96=I;BX*("`@("`J($!P87)A;2!I;G1E9V5R("1M87AD97!T:"`@
M36%X(&]F(&QE=F5L<R!O9B!D97!T:"!T;R!C:&5C:RX*("`@("`J"B`@("`@
M*B!`;F]T92!)9B!N;W1H:6YG(&ES(')E='5R;F5D('1H870@;65A;G,@=&AE
M<F4@:7,@;F\@8VAI;&0L(&)U=`H@("`@("H@9&]N)W0@9F]R9V5T('1O(&%D
M9"!T:&4@<&%R96YT(&EF(&%N>2!S=6)S97%U96YT(&]P97)A=&EO;G,@87)E
M"B`@("`@*B!R97%U:7)E9"$*("`@("`J+PH@("`@9G5N8W1I;VX@7V5X=')A
M8W1!;&Q,979E;%1R964H)B1O=70L("1P87)E;G0@/2!$051!5%)%15]23T]4
M+"`D;6%X9&5P=&@@/2`M,2D*("`@('L*("`@("`@("!I9B`H)&UA>&1E<'1H
M(#T](#`I('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M"B`@("`@("`@)&]U=%LD<&%R96YT72`]('1R=64["@H@("`@("`@("1K(#T@
M)'1H:7,M/E]E>'1R86-T3VYE3&5V96PH)'!A<F5N="D["B`@("`@("`@9F]R
M96%C:"`H)&L@87,@)&]B:F5C="`]/B`D=BD@>PH@("`@("`@("`@("!I9B`H
M(6ES7V%R<F%Y*"1O=71;)'!A<F5N=%TI*2!["B`@("`@("`@("`@("`@("`D
M;W5T6R1P87)E;G1=(#T@87)R87DH*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D;W5T6R1P87)E;G1=6R1O8FIE8W1=(#T@=')U93L*("`@("`@("`@
M("`@)'1H:7,M/E]E>'1R86-T06QL3&5V96Q4<F5E*"1O=71;)'!A<F5N=%TL
M("1O8FIE8W0L("1M87AD97!T:"`M(#$I.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($5X=')A8W0@86QL(&QE=F5L<R!O9B!D871A+"!S=&%R
M=&EN9R!F<F]M(&%N>2!P87)E;G0@:6X*("`@("`J('1H92!T<F5E+@H@("`@
M("H*("`@("`J(%)E='5R;F5D(&%R<F%Y(&9O<FUA=#H@87)R87DH<&%R96YT
M(#T^(&%R<F%Y*&-H:6QD(#T^('1R=64I*0H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D;W5T("`@("`@("`@5&AI<R!I<R!A;B!I=&5R871I;F<@9G5N
M8W1I;VXL('-O("1O=70@:7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<&%S<V5D(&)Y(')E9F5R96YC92!T;R!C;VYT86EN('1H92!R97-U
M;'0N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<&%R96YT("`@(%1H92!N86UE
M(&]F('1H92!P87)E;G0@9G)O;2!W:&EC:"!T;R!B96=I;BX*("`@("`J($!P
M87)A;2!I;G1E9V5R("1M87AD97!T:"`@36%X(&YU;6)E<B!O9B!L979E;',@
M;V8@9&5P=&@@=&\@8VAE8VLN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]E>'1R
M86-T06QL3&5V96Q,:7-T*"8D;W5T+"`D<&%R96YT(#T@1$%40512145?4D]/
M5"P@)&UA>&1E<'1H(#T@+3$I"B`@("!["B`@("`@("`@:68@*"1M87AD97!T
M:"`]/2`P*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"@H@("`@("`@("\O(%1H:7,@:7,@<F5D=6YD86YT(&UO<W0@;V8@=&AE('1I
M;64L('-O(&UA:V4@<W5R92!W92!N965D('1O"B`@("`@("`@+R\@9&\@:70N
M"B`@("`@("`@:68@*&5M<'1Y*"1O=71;)'!A<F5N=%TI*2!["B`@("`@("`@
M("`@("1O=71;)'!A<F5N=%T@/2`D=&AI<RT^9V5T3F%M92@D<&%R96YT*3L*
M("`@("`@("!]"@H@("`@("`@("1K(#T@87)R87E?:V5Y<R@D=&AI<RT^7V5X
M=')A8W1/;F5,979E;"@D<&%R96YT*2D["B`@("`@("`@9F]R96%C:"`H)&L@
M87,@)&]B:F5C="D@>PH@("`@("`@("`@("`D;W5T6R1O8FIE8W1=(#T@)'1H
M:7,M/F=E=$YA;64H)&]B:F5C="D["B`@("`@("`@("`@("1T:&ES+3Y?97AT
M<F%C=$%L;$QE=F5L3&ES="@D;W5T+"`D;V)J96-T+"`D;6%X9&5P=&@@+2`Q
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@
M8VAI;&0G<R!D:7)E8W0@<&%R96YT($E$+@H@("`@("H*("`@("`J($!P87)A
M;2!M:7AE9"`D8VAI;&0@($5I=&AE<B!T:&4@;V)J96-T+"!A;B!A<G)A>2!C
M;VYT86EN:6YG('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@<&%T
M:"!E;&5M96YT<RP@;W(@=&AE(&]B:F5C="!N86UE(&9O<B!W:&EC:`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@=&\@;&]O:R!U<"!T:&4@<&%R96YT
M)W,@240N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@=6YI
M<75E($E$(&]F('1H92!P87)E;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%!A<F5N="@D8VAI;&0I"B`@("!["B`@("`@("`@:68@*&ES7V$H)&-H:6QD
M+"`G1&%T851R965/8FIE8W0G*2D@>PH@("`@("`@("`@("`D8VAI;&0@/2`D
M8VAI;&0M/F=E=$YA;64H*3L*("`@("`@("!]"B`@("`@("`@)&ED(#T@)'1H
M:7,M/F=E=$ED*"1C:&EL9"D["B`@("`@("`@:68@*&ES7V$H)&ED+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D:60["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]D871A6R1I9%U;)W!A<F5N="==
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T(&$@)&-H:6QD)W,@9&ER96-T
M('!A<F5N="!)1"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8VAI
M;&1)9"`@1V5T('1H92!P87)E;G0@;V8@=&AI<R!O8FIE8W0N"B`@("`@*@H@
M("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@=6YI<75E($E$(&]F('1H92!P
M87)E;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A<F5N=$)Y260H)&-H
M:6QD260I"B`@("!["B`@("`@("`@)'1H:7,M/E]L;V%D0GE)9"@D8VAI;&1)
M9"D["B`@("`@("`@<F5T=7)N(&ES<V5T*"1T:&ES+3Y?9&%T85LD8VAI;&1)
M9%TI(#\*("`@("`@("`@("`@)'1H:7,M/E]D871A6R1C:&EL9$ED75LG<&%R
M96YT)UT@.@H@("`@("`@("`@("!014%2.CIR86ES945R<F]R*"1C:&EL9$ED
M("X@)R!N;W0@9F]U;F0G*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A
M(&QI<W0@;V8@<&%R96YT<R!A;&P@=&AE('=A>2!U<"!T;R!T:&4@<F]O="!O
M8FIE8W0@9F]R"B`@("`@*B`D8VAI;&0N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&UI>&5D("`@)&-H:6QD("`@5&AE(&YA;64@;V8@=&AE(&-H:6QD"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D9V5T:61S("!)9B!T<G5E+"!R971U<FX@<&%R
M96YT($E$<SL@;W1H97)W:7-E+"!R971U<FX*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@(&YA;65S+@H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@(%MC:&EL9%T@6W!A<F5N=%T@:6X@82!T<F5E(&9O<FUA="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T4&%R96YT<R@D8VAI;&0L("1G971I9',@/2!F
M86QS92D*("`@('L*("`@("`@("`D<&ED(#T@)'1H:7,M/F=E=%!A<F5N="@D
M8VAI;&0I.PH@("`@("`@(&EF("AI<U]A*"1P:60L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U!A<F5N
M=',@;F]T(&9O=6YD.B`G("X@)'!I9"T^9V5T365S<V%G92@I*3L*("`@("`@
M("!]"B`@("`@("`@)'!N86UE(#T@)'1H:7,M/F=E=$YA;64H)'!I9"D["B`@
M("`@("`@:68@*"1G971I9',I('L*("`@("`@("`@("`@)'!A<F5N=',@/2!A
M<G)A>2@D<&ED(#T^('1R=64I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1P87)E;G1S(#T@87)R87DH)'!N86UE(#T^('1R=64I.PH@("`@("`@
M('T*"B`@("`@("`@:68@*"1P:60@(3T@1$%40512145?4D]/5"D@>PH@("`@
M("`@("`@("!I9B`H)&=E=&ED<RD@>PH@("`@("`@("`@("`@("`@)'!A<F5N
M='-;)'!I9%T@/2`D=&AI<RT^9V5T4&%R96YT<R@D<&YA;64L("1G971I9',I
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'!A<F5N
M='-;)'!N86UE72`]("1T:&ES+3YG971087)E;G1S*"1P;F%M92P@)&=E=&ED
M<RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M<&%R96YT<SL*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A(&QI<W0@;V8@
M<&%R96YT<R!A;&P@=&AE('=A>2!U<"!T;R!T:&4@<F]O="!O8FIE8W0@9F]R
M"B`@("`@*B`D8VAI;&0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)&-H:6QD260@(%1H92!I9"!O9B!T:&4@8VAI;&0N"B`@("`@*B!`<&%R86T@
M87)R87D@)'!A<F5N=',@("`@5&AE(&%R<F%Y+"!A<R!W92!B=6EL9"!I="!U
M<"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!(&9L870@;&ES="!O
M9B!A;&P@;V8@=&AE('!A<F5N=',@;V8@)&-H:6QD+`H@("`@("H@("`@("`@
M("`@("`@("`@:&%S:&5D(&EN("1I9"`]/B`D;F%M92!F;W)M870N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=%!A<F5N=$QI<W0H)&-H:6QD260L("1P87)E
M;G1S(#T@87)R87DH*2D*("`@('L*("`@("`@("`D<&ED(#T@)'1H:7,M/F=E
M=%!A<F5N=$)Y260H)&-H:6QD260I.PH@("`@("`@(&EF("AI<U]A*"1P:60L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H)U!A<F5N=',@;F]T(&9O=6YD.B`G("X@)'!I9"T^9V5T365S
M<V%G92@I*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D<&ED("$]($1!5$%4
M4D5%7U)/3U0I('L*("`@("`@("`@("`@)'!A<F5N='-;)'!I9%T@/2`D=&AI
M<RT^9V5T3F%M92@D<&ED*3L*("`@("`@("`@("`@)'!A<F5N=',@/2`D=&AI
M<RT^9V5T4&%R96YT3&ES="@D<&ED+"`D<&%R96YT<RD["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)'!A<F5N=',["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!'970@82!P87)E;G0@240@<W1R:6YG("AI9#IC:60@9F]R;6%T*2!F;W(@
M=&AE('-P96-I9FEE9"!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI
M>&5D("1O8FIE8W0@(%1H92!O8FIE8W0@=&\@<F5T=7)N(&$@<&%R96YT('-T
M<FEN9R!F;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F=\4$5!4E]%
M<G)O<B`@5&AE($E$(")P871H(B!T;R!T:&4@<&%R96YT(&]B:F5C="!O<@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E]%<G)O<B!O
M;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971087)E;G1)9%-T
M<FEN9R@D;V)J96-T*0H@("`@>PH@("`@("`@("1P=')E92`]("1T:&ES+3YG
M971087)E;G1S*"1O8FIE8W0L('1R=64I.PH@("`@("`@(&EF("AI<U]A*"1P
M=')E92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'!T
M<F5E.PH@("`@("`@('T*"B`@("`@("`@)'!I9',@/2`G)SL*("`@("`@("!W
M:&EL92`H*&QI<W0H)&ED+"`D<&%R96YT*2`](&5A8V@H)'!T<F5E*2D@)B8@
M:7-?87)R87DH)'!A<F5N="DI('L*("`@("`@("`@("`@)'!I9',@/2`G.B<@
M+B`D:60@+B`D<&ED<SL*("`@("`@("`@("`@)'!T<F5E(#T@)'!A<F5N=#L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<&ED<SL*("`@('T*"B`@("`O
M*BH*("`@("`J($=E="!T:&4@;G5M8F5R(&]F(&-H:6QD<F5N(&%N(&]B:F5C
M="!H87,L(&]N;'D@8V]U;G1I;F<@:6UM961I871E"B`@("`@*B!C:&EL9')E
M;BP@;F]T(&=R86YD8VAI;&1R96XL(&5T8RX*("`@("`J"B`@("`@*B!`<&%R
M86T@;6EX960@)'!A<F5N="`@16ET:&5R('1H92!O8FIE8W0@;W(@=&AE(&YA
M;64@9F]R('=H:6-H('1O(&-O=6YT"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@=&AE(&-H:6QD<F5N+"!D969A=6QT<R!T;R!T:&4@<F]O=`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("A$051!5%)%15]23T]4*2X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T3G5M8F5R3V9#:&EL9')E;B@D<&%R96YT(#T@1$%40512145?4D]/
M5"D*("`@('L*("`@("`@("!I9B`H:7-?82@D<&%R96YT+"`G1&%T851R965/
M8FIE8W0G*2D@>PH@("`@("`@("`@("`D<&%R96YT(#T@)'!A<F5N="T^9V5T
M3F%M92@I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7VQO860H)'!A<F5N
M="D["B`@("`@("`@)&]U="`]("1T:&ES+3Y?97AT<F%C=$]N94QE=F5L*"1T
M:&ES+3YG971)9"@D<&%R96YT*2D["B`@("`@("`@<F5T=7)N(&ES7V%R<F%Y
M*"1O=70I(#\@8V]U;G0H)&]U="D@.B`P.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0VAE8VL@:68@86X@;V)J96-T(&5X:7-T<R!O<B!N;W0N(%1H92!R;V]T
M(&5L96UE;G0@1$%40512145?4D]/5"!A;'=A>7,@97AI<W1S+@H@("`@("H*
M("`@("`J($!P87)A;2!M:7AE9"`D;V)J96-T("!4:&4@;F%M92!O9B!T:&4@
M;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I
M9B!T:&4@;V)J96-T(&5X:7-T<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!E>&ES=',H)&]B:F5C="D*("`@('L*("`@("`@("!I
M9B`H96UP='DH)&]B:F5C="DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?82@D;V)J96-T+"`G1&%T851R
M965/8FIE8W0G*2D@>PH@("`@("`@("`@("`D;V)J96-T(#T@)&]B:F5C="T^
M9V5T3F%M92@I.PH@("`@("`@('T@96QS96EF("AI<U]A<G)A>2@D;V)J96-T
M*2D@>PH@("`@("`@("`@("`D;V)J96-T(#T@:6UP;&]D92@G.B<L("1O8FIE
M8W0I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1O8FIE8W0@/3T@1$%40512
M145?4D]/5"D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]
M"@H@("`@("`@("1I9$UA<"`](&%R<F%Y7V9L:7`H)'1H:7,M/E]N86UE36%P
M*3L*("`@("`@("!I9B`H:7-S970H)&ED36%P6R1O8FIE8W1=*2D@>PH@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("1T:&ES
M+3Y?;&]A9"@D;V)J96-T*3L*("`@("`@("`D:61-87`@/2!A<G)A>5]F;&EP
M*"1T:&ES+3Y?;F%M94UA<"D["B`@("`@("`@<F5T=7)N(&ES<V5T*"1I9$UA
M<%LD;V)J96-T72D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE(&YA
M;64@;V8@86X@;V)J96-T(&9R;VT@:71S(&ED+@H@("`@("H*("`@("`J($!P
M87)A;2!I;G1E9V5R("1I9"`@5&AE(&ED(&9O<B!W:&EC:"!T;R!L;V]K('5P
M('1H92!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$YA;64H)&ED*0H@("`@>PH@("`@("`@("\J
M($EF(&YO(&ED(&]R(&EF(&ED(&ES(&$@4$5!4B!E<G)O<BP@<F5T=7)N(&YU
M;&PN("HO"B`@("`@("`@:68@*&5M<'1Y*"1I9"D@?'P@:7-?82@D:60L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@
M("`@?0H*("`@("`@("`O*B!)9B!C:&5C:VEN9R!N86UE(&]F(')O;W0L(')E
M='5R;B!$051!5%)%15]23T]4+B`J+PH@("`@("`@(&EF("@D:60@/3T@1$%4
M0512145?4D]/5"D@>PH@("`@("`@("`@("!R971U<FX@1$%40512145?4D]/
M5#L*("`@("`@("!]"@H@("`@("`@("\J($EF(&9O=6YD(&EN('1H92!N86UE
M(&UA<"P@<F5T=7)N('1H92!N86UE+B`J+PH@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7VYA;65-87!;)&ED72DI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?;F%M94UA<%LD:61=.PH@("`@("`@('T*"B`@("`@("`@+RH@3F]T
M(&9O=6YD(&EN(&YA;64@;6%P+"!T<GD@;&]A9&EN9R!T:&ES(&ED(&EN=&\@
M=&AE(&YA;64*("`@("`@("`@*B!M87`N("HO"B`@("`@("`@)'1H:7,M/E]L
M;V%D0GE)9"@D:60I.PH*("`@("`@("`O*B!)9B!I9"!L;V%D960@<F5T=7)N
M('1H92!N86UE+"!O=&AE<G=I<V4@<F5T=7)N(&YU;&PN("HO"B`@("`@("`@
M<F5T=7)N(&ES<V5T*"1T:&ES+3Y?;F%M94UA<%LD:61=*2`_"B`@("`@("`@
M("`@("1T:&ES+3Y?;F%M94UA<%LD:61=(#H*("`@("`@("`@("`@;G5L;#L*
M("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@:60@;V8@86X@;V)J96-T
M(&9R;VT@:71S(&YA;64N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1N
M86UE("!%:71H97(@=&AE(&]B:F5C="P@86X@87)R87D@8V]N=&%I;FEN9R!T
M:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@<&%T:"!E;&5M96YT<RP@
M;W(@=&AE(&]B:F5C="!N86UE(&9O<B!W:&EC:`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("!T;R!L;V]K('5P('1H92!I9"X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9PH@("`@("HO"B`@("!F=6YC=&EO;B!G971)9"@D;F%M
M92D*("`@('L*("`@("`@("`O*B!#:&5C:R!I9B`D;F%M92!I<R!N;W0@82!S
M=')I;F<N("HO"B`@("`@("`@:68@*&ES7V$H)&YA;64L("=$871A5')E94]B
M:F5C="<I*2!["B`@("`@("`@("`@("\J($1A=&%4<F5E3V)J96-T+"!G970@
M=&AE('-T<FEN9R!N86UE+B`J+PH@("`@("`@("`@("`D;F%M92`]("1N86UE
M+3YG971.86UE*"D["B`@("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y*"1N86UE
M*2D@>PH@("`@("`@("`@("`O*B!0871H(&%R<F%Y+"!I;7!L;V1E('1O(&=E
M="!T:&4@<W1R:6YG(&YA;64N("HO"B`@("`@("`@("`@("1N86UE(#T@:6UP
M;&]D92@G.B<L("1N86UE*3L*("`@("`@("!]"@H@("`@("`@("\J($EF(&-H
M96-K:6YG(&ED(&]F(')O;W0L(')E='5R;B!$051!5%)%15]23T]4+B`J+PH@
M("`@("`@(&EF("@D;F%M92`]/2!$051!5%)%15]23T]4*2!["B`@("`@("`@
M("`@(')E='5R;B!$051!5%)%15]23T]4.PH@("`@("`@('T*"B`@("`@("`@
M+RH@0VAE8VL@:68@=&AE(&YA;64@86-T=6%L;'D@97AI<W1S+"!I9B!N;W0@
M<F5T=7)N(&$@4$5!4@H@("`@("`@("`J(&5R<F]R+B`J+PH@("`@("`@(&EF
M("@A)'1H:7,M/F5X:7-T<R@D;F%M92DI('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H)&YA;64@+B`G(&1O97,@;F]T(&5X:7-T)RD[
M"B`@("`@("`@?0H*("`@("`@("`O*B!&;&EP('1H92!N86UE(&UA<"!T;R!L
M;V]K('5P('1H92!I9"!U<VEN9R!T:&4@;F%M92!A<R!K97DN("HO"B`@("`@
M("`@)&ED36%P(#T@87)R87E?9FQI<"@D=&AI<RT^7VYA;65-87`I.PH@("`@
M("`@(')E='5R;B`D:61-87!;)&YA;65=.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1V5T('1H92!O<F1E<B!P;W-I=&EO;B!O9B!A;B!O8FIE8W0N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&UI>&5D("1C:&EL9"`@16ET:&5R('1H92!O8FIE
M8W0@;W(@=&AE(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@
M5&AE(&]B:F5C="=S(&]R9&5R('!O<VET:6]N(&]R(&$@4$5!4B!E<G)O<B!O
M;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971/<F1E<B@D8VAI
M;&0I"B`@("!["B`@("`@("`@:68@*&ES7V$H)&-H:6QD+"`G1&%T851R965/
M8FIE8W0G*2D@>PH@("`@("`@("`@("`D8VAI;&0@/2`D8VAI;&0M/F=E=$YA
M;64H*3L*("`@("`@("!]"B`@("`@("`@)&ED(#T@)'1H:7,M/F=E=$ED*"1C
M:&EL9"D["B`@("`@("`@:68@*&ES7V$H)&ED+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D:60["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@:7-S970H)'1H:7,M/E]D871A6R1I9%U;)V]R9&5R)UTI(#\*("`@
M("`@("`@("`@)'1H:7,M/E]D871A6R1I9%U;)V]R9&5R)UT@.@H@("`@("`@
M("`@("!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5P;&%C92!A;&P@
M;V-C=7)E;F-E<R!O9B`G.B<@:6X@86X@;V)J96-T(&YA;64@=VET:"`G+B<N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&YA;64@
M;V8@=&AE(&]B:F5C="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE(&5N8V]D960@;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@96YC;V1E
M3F%M92@D;F%M92D*("`@('L*("`@("`@("!R971U<FX@<W1R7W)E<&QA8V4H
M)SHG+"`G+B<L("1N86UE*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T
M:&4@<VAO<G0@;F%M92!O9B!A;B!O8FIE8W0L(')E='5R;G,@;VYL>2!T:&4@
M;&%S="!P;W)T:6]N(&]F('1H90H@("`@("H@9G5L;"!N86UE+B!&;W(@9&ES
M<&QA>2!P=7)P;W-E<R!O;FQY+@H@("`@("H*("`@("`J($!S=&%T:6,*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@;F%M92!O9B!T
M:&4@;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M;V)J96-T)W,@<VAO<G0@;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M4VAO<G1.86UE*"1N86UE*0H@("`@>PH@("`@("`@("\J($EF('1H97)E(&%R
M92!S979E<F%L(&-O;7!O;F5N=',@=&\@=&AE(&YA;64L(&5X<&QO9&4@86YD
M(&=E="!T:&4*("`@("`@("`@*B!L87-T(&]N92P@;W1H97)W:7-E(&IU<W0@
M<F5T=7)N('1H92!N86UE+B`J+PH@("`@("`@(&EF("AS=')P;W,H)&YA;64L
M("<Z)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("1N86UE(#T@97AP;&]D
M92@G.B<L("1N86UE*3L*("`@("`@("`@("`@)&YA;64@/2!A<G)A>5]P;W`H
M)&YA;64I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&YA;64["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@=')E92!S;W)T960@8GD@=&AE
M('-P96-I9FEE9"!A='1R:6)U=&4@;F%M92!A;F0O;W(@:V5Y+@H@("`@("H*
M("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!S:6YC92!(;W)D92`S
M+C$*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1R;V]T("`@("`@("`@
M5VAI8V@@<&]R=&EO;B!O9B!T:&4@=')E92!T;R!S;W)T+@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@($1E9F%U;'1S('1O(&%L;"!O9B!I
M="X*("`@("`J($!P87)A;2!B;V]L96%N("1L;V%D5')E92`@("!3;W)T('1H
M92!T<F5E('-T87)T:6YG(&%T("1R;V]T+"!O<B!J=7-T('1H90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E<75E<W1E9"!L979E;"!A
M;F0@9&ER96-T('!A<F5N=',_"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@1&5F875L=',@=&\@<VEN9VQE(&QE=F5L+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<V]R=&)Y7VYA;64@($%T=')I8G5T92!N86UE('1O('5S
M92!F;W(@<V]R=&EN9RX*("`@("`J($!P87)A;2!S=')I;F<@)'-O<G1B>5]K
M97D@("!!='1R:6)U=&4@:V5Y('1O('5S92!F;W(@<V]R=&EN9RX*("`@("`J
M($!P87)A;2!I;G1E9V5R("1D:7)E8W1I;VX@("!3;W)T(&1I<F5C=&EO;CH*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`P("T@87-C96YD
M:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@,2`M(&1E
M<V-E;F1I;F<*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4V]R=&5D5')E92@D
M<F]O="P@)&QO8614<F5E(#T@9F%L<V4L("1S;W)T8GE?;F%M92`](&YU;&PL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1S;W)T8GE?:V5Y(#T@;G5L
M;"P@)&1I<F5C=&EO;B`](#`I"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H)VYO="!S=7!P;W)T960G*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($%D9',@86X@;V)J96-T+@H@("`@("H*("`@("`J($!A8G-T<F%C
M=`H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D;V)J96-T("`@("`@("!4
M:&4@;V)J96-T('1O(&%D9"`H<W1R:6YG(&]R"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@1&%T851R965/8FIE8W0I+@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)&ED7V%S7VYA;64@(%1R=64@;W(@9F%L<V4@=&\@:6YD
M:6-A=&4@:68@;V)J96-T($E$(&ES('1O"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8F4@=7-E9"!A<R!O8FIE8W0@;F%M92X@57-E9"!I
M;B!S:71U871I;VYS"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@=VAE<F4@=&AE<F4@:7,@;F\@879A:6QA8FQE('5N:7%U92!I;G!U="!F
M;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!O8FIE8W0@
M;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@861D*"1O8FIE8W0L("1I9%]A
M<U]N86UE(#T@9F%L<V4I"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H)VYO="!S=7!P;W)T960G*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($%D9"!A;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`@("1N86UE("!4:&4@<VAO<G0@;V)J96-T(&YA;64N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`@)&ED("`@(%1H92!N97<@;V)J96-T)W,@=6YI<75E($E$
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@("1P:60@("!4:&4@=6YI<75E($E$
M(&]F('1H92!O8FIE8W0G<R!P87)E;G0N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`@)&]R9&5R(%1H92!O<F1E<FEN9R!D871A(&9O<B!T:&4@;V)J96-T+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]A9&0H)&YA;64L("1I9"P@)'!I9"P@)&]R9&5R(#T@)R<I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]D871A6R1I9%T@/2!A<G)A>2@G;F%M92<@
M/3X@)&YA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M<&%R96YT)R`]/B`D<&ED+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)V]R9&5R)R`]/B`D;W)D97(I.PH@("`@("`@("1T:&ES+3Y?;F%M
M94UA<%LD:61=(#T@)&YA;64["@H@("`@("`@("\J(%-H:69T(&%L;VYG('1H
M92!O<F1E<B!P;W-I=&EO;G,N("HO"B`@("`@("`@)'1H:7,M/E]R96]R9&5R
M*"1P:60L("1O<F1E<BP@)&ED*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V92!D871A(&9O<B!A;B!O8FIE
M8W0@9G)O;2!T:&4@:&]R9&5?9&%T871R965?871T<FEB=71E<PH@("`@("H@
M=&%B;&4N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@?"!A<G)A>2`D8VED("!4:&4@;V)J96-T(&ED('1O
M(&9E=&-H+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!O
M<B!A;B!A<G)A>2!O9B!O8FIE8W0@:61S+@H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@($$@:&%S:"!O9B!A='1R:6)U=&5S+"!O<B!A(&UU;'1I+6QE
M=F5L(&AA<V@*("`@("`J("`@("`@("`@("`@("`@(&]F(&]B:F5C="!I9',@
M/3X@=&AE:7(@871T<FEB=71E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M071T<FEB=71E<R@D8VED*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"=N;W0@<W5P<&]R=&5D)RD["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!N=6UB97(@;V8@;V)J96-T<R!M871C:&EN9R!A
M('-E="!O9B!A='1R:6)U=&4@8W)I=&5R:6$N"B`@("`@*@H@("`@("H@0&%B
M<W1R86-T"B`@("`@*@H@("`@("H@0'-E92!B=6EL9$%T=')I8G5T95%U97)Y
M*"D*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@("`D8W)I=&5R:6$@("!4
M:&4@87)R87D@;V8@8W)I=&5R:6$N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D
M<&%R96YT("`@("!4:&4@<&%R96YT(&YO9&4@=&\@<W1A<G0@<V5A<F-H:6YG
M(&9R;VTN"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D86QL3&5V96QS("!2971U
M<FX@86QL(&QE=F5L<RP@;W(@:G5S="!T:&4@9&ER96-T"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!C:&EL9')E;B!O9B`D<&%R96YT/R!$
M969A=6QT<R!T;R!A;&P@;&5V96QS+@H@("`@("H@0'!A<F%M('-T<FEN9R`@
M)')E<W1R:6-T("`@3VYL>2!R971U<FX@871T<FEB=71E<R!W:71H('1H92!S
M86UE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A='1R:6)U
M=&5?;F%M92!O<B!A='1R:6)U=&5?:60N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&-O=6YT0GE!='1R:6)U=&5S*"1C<FET97)I82P@)'!A<F5N="`]($1!5$%4
M4D5%7U)/3U0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D86QL
M3&5V96QS(#T@=')U92P@)')E<W1R:6-T(#T@)VYA;64G*0H@("`@>PH@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=N;W0@<W5P<&]R=&5D)RD[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<V5T(&]F(&]B:F5C
M="!I9',@8F%S960@;VX@82!S970@;V8@871T<FEB=71E(&-R:71E<FEA+@H@
M("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!S964@8G5I
M;&1!='1R:6)U=&51=65R>2@I"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("`@)&-R:71E<FEA("`@("!4:&4@87)R87D@;V8@8W)I=&5R:6$N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("`D<&%R96YT("`@("`@(%1H92!P87)E;G0@;F]D
M92!T;R!S=&%R="!S96%R8VAI;F<@9G)O;2X*("`@("`J($!P87)A;2!B;V]L
M96%N("1A;&Q,979E;',@("`@4F5T=7)N(&%L;"!L979E;',L(&]R(&IU<W0@
M=&AE(&1I<F5C=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!C:&EL9')E;B!O9B`D<&%R96YT/R!$969A=6QT<R!T;R!A;&P@;&5V96QS
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)')E<W1R:6-T("`@("!/;FQY(')E
M='5R;B!A='1R:6)U=&5S('=I=&@@=&AE('-A;64*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@871T<FEB=71E7VYA;64@;W(@871T<FEB
M=71E7VED+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&9R;VT@("`@("`@("!4
M:&4@;V)J96-T('1O('-T87)T('1O(&9E=&-H:6YG"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D8V]U;G0@("`@("`@(%1H92!N=6UB97(@;V8@;V)J96-T<R!T
M;R!F971C:`H@("`@("H@0'!A<F%M('-T<FEN9R`@)'-O<G1B>5]N86UE("!!
M='1R:6)U=&4@;F%M92!T;R!U<V4@9F]R('-O<G1I;F<N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("`D<V]R=&)Y7VME>2`@($%T=')I8G5T92!K97D@=&\@=7-E
M(&9O<B!S;W)T:6YG+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&1I<F5C=&EO
M;B`@("!3;W)T(&1I<F5C=&EO;CH*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`P("T@87-C96YD:6YG"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@,2`M(&1E<V-E;F1I;F<*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T0GE!='1R:6)U=&5S*"1C<FET97)I82P@)'!A<F5N
M="`]($1!5$%44D5%7U)/3U0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&%L;$QE=F5L<R`]('1R=64L("1R97-T<FEC="`]("=N86UE)RP@)&9R
M;VT@/2`P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;W5N="`]
M(#`L("1S;W)T8GE?;F%M92`](&YU;&PL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'-O<G1B>5]K97D@/2!N=6QL+"`D9&ER96-T:6]N(#T@,"D*
M("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G;F]T('-U
M<'!O<G1E9"<I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V]R=',@241S(&)Y
M(&%T=')I8G5T92!V86QU97,N($E$<R!W:71H;W5T(&%T=')I8G5T97,@=VEL
M;"!B92!A9&1E9"!T;PH@("`@("H@=&AE(&5N9"!O9B!T:&4@<V]R=&5D(&QI
M<W0N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1U;F]R9&5R961?:61S("!!<G)A>2!O9B!I9',@=&\@<V]R
M="X*("`@("`J($!P87)A;2!A<G)A>2`D<V]R=&)Y7VYA;64@("`@071T<FEB
M=71E(&YA;64@=&\@=7-E(&9O<B!S;W)T:6YG+@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1S;W)T8GE?:V5Y("`@("!!='1R:6)U=&4@:V5Y('1O('5S92!F;W(@
M<V]R=&EN9RX*("`@("`J($!P87)A;2!A<G)A>2`D9&ER96-T:6]N("`@("`@
M4V]R="!D:7)E8W1I;VXZ"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@,"`M(&%S8V5N9&EN9PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#$@+2!D97-C96YD:6YG"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@4V]R=&5D(&ED<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@<V]R=$)Y071T<FEB=71E<R@D=6YO<F1E<F5D7VED<RP@)'-O<G1B>5]N
M86UE(#T@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-O
M<G1B>5]K97D@/2!N=6QL+"`D9&ER96-T:6]N(#T@,"D*("`@('L*("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G;F]T('-U<'!O<G1E9"<I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@57!D871E('1H92!D871A(&EN(&%N(&]B
M:F5C="X@1&]E<R!N;W0@8VAA;F=E('1H92!O8FIE8W0G<PH@("`@("H@<&%R
M96YT(&]R(&YA;64L(&IU<W0@<V5R:6%L:7IE9"!D871A(&]R(&%T=')I8G5T
M97,N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@0'!A
M<F%M($1A=&%4<F5E("1O8FIE8W0@($$@1&%T851R964@;V)J96-T+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!U<&1A=&5$871A*"1O8FIE8W0I"B`@("!["B`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)VYO="!S=7!P;W)T960G
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-O<G0@='=O(&]B:F5C=',@8GD@
M=&AE:7(@;W)D97(@9FEE;&0L(&%N9"!I9B!T:&%T(&ES('1H92!S86UE+`H@
M("`@("H@86QP:&%B971I8V%L;'D@*&-A<V4@:6YS96YS:71I=F4I(&)Y(&YA
M;64N"B`@("`@*@H@("`@("H@66]U(&YE=F5R(&-A;&P@=&AI<R!F=6YC=&EO
M;CL@:70G<R!U<V5D(&EN('5A<V]R="@I(&-A;&QS+B!$;PH@("`@("H@3D]4
M('5S92!U<V]R="@I.R!Y;W4G;&P@;&]S92!K97D@/3X@=F%L=64@87-S;V-I
M871I;VYS+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D82`@5&AE(&9I
M<G-T(&]B:F5C=`H@("`@("H@0'!A<F%M(&%R<F%Y("1B("!4:&4@<V5C;VYD
M(&]B:F5C=`H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@,2!I9B`D
M82!S:&]U;&0@8F4@9FER<W0L"B`@("`@*B`@("`@("`@("`@("`@("`@+3$@
M:68@)&(@<VAO=6QD(&)E(&9I<G-T+`H@("`@("H@("`@("`@("`@("`@("`@
M("`P(&EF('1H97D@87)E(&5N=&ER96QY(&5Q=6%L+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?8VUP*"1A+"`D8BD*("`@('L*("`@("`@("!I9B`H)&%;)V]R
M9&5R)UT@/B`D8ELG;W)D97(G72D@>PH@("`@("`@("`@("!R971U<FX@,3L*
M("`@("`@("!](&5L<V5I9B`H)&%;)V]R9&5R)UT@/"`D8ELG;W)D97(G72D@
M>PH@("`@("`@("`@("!R971U<FX@+3$["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<F5T=7)N('-T<F-A<V5C;7`H)&%;)VYA;64G72P@)&);)VYA
M;64G72D["B`@("`@("`@?0H@("`@?0H*("`@("`O*BH*("`@("`J(%-O<G1S
M('1W;R!O8FIE8W1S(&)Y('1H96ER('-O<G1E<B!H87-H(&9I96QD+@H@("`@
M("H*("`@("`J(%EO=2!N979E<B!C86QL('1H:7,@9G5N8W1I;VX[(&ET)W,@
M=7-E9"!I;B!U87-O<G0H*2!C86QL<RX@1&\@3D]4('5S90H@("`@("H@=7-O
M<G0H*3L@>6]U)VQL(&QO<V4@:V5Y(#T^('9A;'5E(&%S<V]C:6%T:6]N<RX*
M("`@("`J"B`@("`@*B!`<VEN8V4@2&]R9&4@,RXQ"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1A("!4:&4@9FER<W0@;V)J96-T"B`@("`@*B!`<&%R
M86T@87)R87D@)&(@(%1H92!S96-O;F0@;V)J96-T"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G1E9V5R("`Q(&EF("1A('-H;W5L9"!B92!F:7)S="P*("`@
M("`J("`@("`@("`@("`@("`@("`M,2!I9B`D8B!S:&]U;&0@8F4@9FER<W0L
M"B`@("`@*B`@("`@("`@("`@("`@("`@(#`@:68@=&AE>2!A<F4@96YT:7)E
M;'D@97%U86PN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;7!3;W)T960H)&$L
M("1B*0H@("`@>PH@("`@("`@(&EF("@D85LG<V]R=&5R)UU;)'1H:7,M/E]S
M;W)T2&%S:%T@/"`D8ELG<V]R=&5R)UU;)'1H:7,M/E]S;W)T2&%S:%TI('L*
M("`@("`@("`@("`@<F5T=7)N(#$["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@<F5T=7)N(#`["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E=&4@1&%T851R964@:6YS
M=&%N8V4@8F%S960@;VX@)&1R:79E<BX*("`@("`J"B`@("`@*B!`<&%R86T@
M;6EX960@)&1R:79E<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@1&%T851R964@
M<W5B8VQA<W,@=&\@<F5T=7)N+@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@(%1H:7,@:7,@8F%S960@;VX@=&AE('-T;W)A9V4@9')I=F5R("@D9')I
M=F5R*2X@5&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@8V]D92!I
M<R!D>6YA;6EC86QL>2!I;F-L=61E9"X@268@)&1R:79E<B!I<R!A;B!A<G)A
M>2P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!T:&5N('=E('=I;&P@
M;&]O:R!I;B`D9')I=F5R6S!=+VQI8B]$871A5')E92\@9F]R"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@=&AE('-U8F-L87-S(&EM<&QE;65N=&%T
M:6]N(&YA;65D("1D<FEV97);,5TN<&AP+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O
M;F9I9W5R871I;VX@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!C
M;VYN96-T:6]N('!A<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@($AE<F4L('=E(&YE960@)V=R
M;W5P)R`](&$@<W1R:6YG('1H870@9&5F:6YE<PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@('1O<"UL979E;"!G<F]U<',@;V8@;V)J96-T<RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N($1A=&%4<F5E("!4:&4@;F5W;'D@8W)E871E
M9"!C;VYC<F5T92!$871A5')E92!I;G-T86YC92P@;W(@9F%L<V4*("`@("`J
M("`@("`@("`@("`@("`@("`@(&]N(&%N(&5R<F]R+@H@("`@("HO"B`@("!F
M=6YC=&EO;B`F9F%C=&]R>2@D9')I=F5R+"`D<&%R86US(#T@;G5L;"D*("`@
M('L*("`@("`@("`D9')I=F5R(#T@8F%S96YA;64H)&1R:79E<BD["@H@("`@
M("`@(&EF("AI<U]N=6QL*"1P87)A;7,I*2!["B`@("`@("`@("`@("1P87)A
M;7,@/2!(;W)D93HZ9V5T1')I=F5R0V]N9FEG*"=D871A=')E92<L("1D<FEV
M97(I.PH@("`@("`@('T*"B`@("`@("`@:68@*&5M<'1Y*"1D<FEV97(I*2![
M"B`@("`@("`@("`@("1D<FEV97(@/2`G;G5L;"<["B`@("`@("`@?0H*("`@
M("`@("!I;F-L=61E7V]N8V4@)TAO<F1E+T1A=&%4<F5E+R<@+B`D9')I=F5R
M("X@)RYP:'`G.PH@("`@("`@("1C;&%S<R`]("=$871A5')E95\G("X@)&1R
M:79E<CL*("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@
M("`@("`@("`@)&1T(#T@)FYE=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&1T(#T@4$5!4CHZ<F%I<V5%<G)O<B@G
M0VQA<W,@9&5F:6YI=&EO;B!O9B`G("X@)&-L87-S("X@)R!N;W0@9F]U;F0N
M)RD["B`@("`@("`@?0H@"B`@("`@("`@<F5T=7)N("1D=#L*("`@('T*"B`@
M("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(')E9F5R96YC92!T
M;R!A(&-O;F-R971E($1A=&%4<F5E(&EN<W1A;F-E(&)A<V5D(&]N"B`@("`@
M*B`D9')I=F5R+@H@("`@("H*("`@("`J($ET('=I;&P@;VYL>2!C<F5A=&4@
M82!N97<@:6YS=&%N8V4@:68@;F\@1&%T851R964@:6YS=&%N8V4@=VET:"!T
M:&4@<V%M90H@("`@("H@<&%R86UE=&5R<R!C=7)R96YT;'D@97AI<W1S+@H@
M("`@("H*("`@("`J(%1H:7,@<VAO=6QD(&)E('5S960@:68@;75L=&EP;&4@
M1&%T851R964@<V]U<F-E<R`H86YD+"!T:'5S+"!M=6QT:7!L90H@("`@("H@
M1&%T851R964@:6YS=&%N8V5S*2!A<F4@<F5Q=6ER960N"B`@("`@*@H@("`@
M("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.B`D=F%R(#T@)D1A
M=&%4<F5E.CIS:6YG;&5T;VXH*3L*("`@("`J"B`@("`@*B!`<&%R86T@;6EX
M960@)&1R:79E<B`@5'EP92!O9B!C;VYC<F5T92!$871A5')E92!S=6)C;&%S
M<R!T;R!R971U<FXL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@8F%S
M960@;VX@<W1O<F%G92!D<FEV97(@*"1D<FEV97(I+B!4:&4@8V]D92!I<PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@(&1Y;F%M:6-A;&QY(&EN8VQU
M9&5D+B!)9B`D9')I=F5R(&ES(&%N(&%R<F%Y+"!T:&5N"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@;&]O:R!I;B`D9')I=F5R6S!=+VQI8B]$871A
M5')E92\@9F]R('-U8F-L87-S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@:6UP;&5M96YT871I;VX@;F%M960@)&1R:79E<ELQ72YP:'`N"B`@("`@
M*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@86YY
M(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!O<@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A('-U8F-L87-S
M(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!$871A5')E92`@
M5&AE(&-O;F-R971E($1A=&%4<F5E(')E9F5R96YC92P@;W(@9F%L<V4@;VX@
M86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)&1R
M:79E<BP@)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@<W1A=&EC("1I
M;G-T86YC97,["B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S*2D@>PH@
M("`@("`@("`@("`D:6YS=&%N8V5S(#T@87)R87DH*3L*("`@("`@("!]"@H@
M("`@("`@(&EF("AI<U]N=6QL*"1P87)A;7,I*2!["B`@("`@("`@("`@("1P
M87)A;7,@/2!(;W)D93HZ9V5T1')I=F5R0V]N9FEG*"=D871A=')E92<L("1D
M<FEV97(I.PH@("`@("`@('T*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA
M;&EZ92AA<G)A>2@D9')I=F5R+"`D<&%R86US*2D["B`@("`@("`@:68@*"%I
M<W-E="@D:6YS=&%N8V5S6R1S:6=N871U<F5=*2D@>PH@("`@("`@("`@("`D
M:6YS=&%N8V5S6R1S:6=N871U<F5=(#T@)D1A=&%4<F5E.CIF86-T;W)Y*"1D
M<FEV97(L("1P87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I
M;G-T86YC97-;)'-I9VYA='5R95T["B`@("!]"@I]"@HO*BH*("H@0VQA<W,@
M=&AA="!C86X@8F4@97AT96YD960@=&\@<V%V92!A<F)I=')A<GD@:6YF;W)M
M871I;VX@87,@<&%R="!O9B!A('-T;W)E9`H@*B!O8FIE8W0N"B`J"B`J($!A
M=71H;W(@(%-T97!H86YE($AU=&AE<B`\<VAU=&AE<D!B:6=F;V]T+F-O;3X*
M("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J($!S:6YC92`@($AO<F1E(#(N,0H@*B!`<&%C:V%G92!(;W)D95]$871A
M5')E90H@*B\*8VQA<W,@1&%T851R965/8FIE8W0@>PH*("`@("\J*@H@("`@
M("H@5&AI<R!O8FIE8W0G<R!$871A5')E92!I;G-T86YC92X*("`@("`J"B`@
M("`@*B!`=F%R($1A=&%4<F5E"B`@("`@*B\*("`@('9A<B`D9&%T871R964[
M"@H@("`@+RHJ"B`@("`@*B!+97DM=F%L=64@:&%S:"!T:&%T('=I;&P@8F4@
M<V5R:6%L:7IE9"X*("`@("`J"B`@("`@*B!`<V5E(&=E=$1A=&$H*0H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&1A=&$@/2!A<G)A>2@I
M.PH*("`@("\J*@H@("`@("H@5&AE('5N:7%U92!N86UE(&]F('1H:7,@;V)J
M96-T+@H@("`@("H@5&AE<V4@;F%M97,@:&%V92!T:&4@<V%M92!R97%U:7)E
M;65N=',@87,@;W1H97(@;V)J96-T(&YA;65S("T@=&AE>2!M=7-T"B`@("`@
M*B!B92!U;FEQ=64L(&5T8RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("HO"B`@("!V87(@)&YA;64["@H@("`@+RHJ"B`@("`@*B!)9B!T:&ES
M(&]B:F5C="!H87,@;W)D97)I;F<@9&%T82P@<W1O<F4@:70@:&5R92X*("`@
M("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1O<F1E
M<B`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!$871A5')E94]B:F5C="!C;VYS
M=')U8W1O<BX*("`@("`J($IU<W0@<V5T<R!T:&4@)&YA;64@<&%R86UE=&5R
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!O8FIE
M8W0@;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@1&%T851R965/8FIE8W0H
M)&YA;64I"B`@("!["B`@("`@("`@)'1H:7,M/G-E=$YA;64H)&YA;64I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@>T!L:6YK($1A=&%4<F5E
M?2!I;G-T86YC92!U<V5D('1O(')E=')I979E('1H:7,@;V)J96-T+@H@("`@
M("H*("`@("`J($!P87)A;2!$871A5')E92`D9&%T871R964@($$@>T!L:6YK
M($1A=&%4<F5E?2!I;G-T86YC92X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T
M1&%T851R964H)B1D871A=')E92D*("`@('L*("`@("`@("`D=&AI<RT^9&%T
M871R964@/2`F)&1A=&%T<F5E.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T
M<R!T:&4@;F%M92!O9B!T:&ES(&]B:F5C="X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R!4:&4@;V)J96-T(&YA;64N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$YA;64H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^;F%M
M93L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE(&YA;64@;V8@=&AI
M<R!O8FIE8W0N"B`@("`@*@H@("`@("H@3D]413H@57-E('=I=&@@8V%U=&EO
M;BX@5&AI<R!M87D@=&AR;W<@;W5T(&]F('-Y;F,@=&AE(&-A8VAE9"!D871A
M=')E90H@("`@("H@=&%B;&5S(&EF(&YO="!U<V5D('!R;W!E<FQY+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!N86UE('1O('-E
M="!T:&ES(&]B:F5C="=S(&YA;64@=&\N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-E=$YA;64H)&YA;64I"B`@("!["B`@("`@("`@)'1H:7,M/FYA;64@/2`D
M;F%M93L*("`@('T*"B`@("`O*BH*("`@("`J($=E=',@=&AE('-H;W)T(&YA
M;64@;V8@=&AI<R!O8FIE8W0N"B`@("`@*B!&;W(@9&ES<&QA>2!P=7)P;W-E
M<R!O;FQY+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;V)J
M96-T)W,@<VAO<G0@;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4VAO
M<G1.86UE*"D*("`@('L*("`@("`@("!R971U<FX@1&%T851R964Z.F=E=%-H
M;W)T3F%M92@D=&AI<RT^;F%M92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'
M971S('1H92!)1"!O9B!T:&ES(&]B:F5C="X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(&]B:F5C="=S($E$+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971)9"@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YD871A
M=')E92T^9V5T260H)'1H:7,I.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T
M<R!T:&4@9&%T82!A<G)A>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!4:&4@:6YT97)N86P@9&%T82!A<G)A>2X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T1&%T82@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YD871A
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@9&%T82!A<G)A>2X*
M("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@(%1H92!D871A(&%R<F%Y('1O
M('-T;W)E(&EN=&5R;F%L;'DN"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$1A
M=&$H)&1A=&$I"B`@("!["B`@("`@("`@)'1H:7,M/F1A=&$@/2`D9&%T83L*
M("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE(&]R9&5R(&]F('1H:7,@
M;V)J96-T(&EN(&ET<R!O8FIE8W0@8V]L;&5C=&EO;BX*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D;W)D97(*("`@("`J+PH@("`@9G5N8W1I;VX@
M<V5T3W)D97(H)&]R9&5R*0H@("`@>PH@("`@("`@("1T:&ES+3YO<F1E<B`]
M("1O<F1E<CL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AI<R!O
M8FIE8W0G<R!P87)E;G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M8VQA<W,@("!3=6)C;&%S<R!O9B!$871A5')E94]B:F5C="!T;R!U<V4N($1E
M9F%U;'1S('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@($1A=&%4
M<F5E3V)J96-T+B!.=6QL(&9O<F-E<R!T:&4@9')I=F5R('1O(&QO;VL*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@:6YT;R!T:&4@871T<FEB=71E
M<R!T86)L92!T;R!D971E<FUI;F4@=&AE"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@('-U8F-L87-S('1O('5S92X@268@;F]N92!I<R!F;W5N9"!I
M="!U<V5S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@($1A=&%4<F5E
M3V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@1&%T851R965/8FIE8W0@
M(%1H:7,@;V)J96-T)W,@<&%R96YT"B`@("`@*B\*("`@(&9U;F-T:6]N("9G
M971087)E;G0H)&-L87-S(#T@)T1A=&%4<F5E3V)J96-T)RD*("`@('L*("`@
M("`@("`D:60@/2`D=&AI<RT^9&%T871R964M/F=E=%!A<F5N="@D=&AI<RD[
M"B`@("`@("`@:68@*&ES7V$H)&ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D:60["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D
M=&AI<RT^9&%T871R964M/F=E=$]B:F5C=$)Y260H)&ED+"`D8VQA<W,I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&-H:6QD(&]F('1H:7,@
M;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@
M("`@("!4:&4@8VAI;&0G<R!N86UE+@H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)&%U=&]C<F5A=&4@($EF('1R=64@86YD(&YO(&-H:6QD('=I=&@@=&AE(&=I
M=F5N(&YA;64*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!E
M>&ES=',L(&]N92!G971S(&-R96%T960N"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9G971#:&EL9"@D;F%M92P@)&%U=&]C<F5A=&4@/2!T<G5E*0H@("`@>PH@
M("`@("`@("1N86UE(#T@)'1H:7,M/F=E=%-H;W)T3F%M92@I("X@)SHG("X@
M)&YA;64["@H@("`@("`@("\J($EF('1H92!C:&EL9"!S:&]U;&1N)W0@9V5T
M(&-R96%T960L('=E(&1O;B=T(&-H96-K(&9O<B!I=',*("`@("`@("`@*B!E
M>&ES=&%N8V4@=&\@<F5T=7)N('1H92`B;F]T(&9O=6YD(B!E<G)O<B!O9@H@
M("`@("`@("`J(&=E=$]B:F5C="@I+B`J+PH@("`@("`@(&EF("@A)&%U=&]C
M<F5A=&4@?'P@)'1H:7,M/F1A=&%T<F5E+3YE>&ES=',H)&YA;64I*2!["B`@
M("`@("`@("`@("1C:&EL9"`]("8D=&AI<RT^9&%T871R964M/F=E=$]B:F5C
M="@D;F%M92D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&-H:6QD
M(#T@)FYE=R!$871A5')E94]B:F5C="@D;F%M92D["B`@("`@("`@("`@("1C
M:&EL9"T^<V5T1&%T851R964H)'1H:7,M/F1A=&%T<F5E*3L*("`@("`@("`@
M("`@)'1H:7,M/F1A=&%T<F5E+3YA9&0H)&-H:6QD*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D8VAI;&0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M879E<R!A;GD@8VAA;F=E<R!T;R!T:&ES(&]B:F5C="!T;R!T:&4@8F%C:V5N
M9"!P97)M86YE;G1L>2X@3F5W(&]B:F5C=',*("`@("`J(&%R92!A9&1E9"!I
M;G-T96%D+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;GQ014%27T5R
M<F]R("!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('-A=F4H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^9&%T871R964M
M/F5X:7-T<R@D=&AI<RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YD
M871A=')E92T^=7!D871E1&%T82@D=&AI<RD["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YD871A=')E92T^861D*"1T:&ES
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&4@=&AI
M<R!O8FIE8W0@9G)O;2!T:&4@8F%C:V5N9"!P97)M86YE;G1L>2X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86Y\4$5!4E]%<G)O<B`@4$5!4E]%<G)O
M<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96QE=&4H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^9&%T871R964M/G)E;6]V92@D
M=&AI<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'971S(&]N92!O9B!T:&4@
M871T<FEB=71E<R!O9B!T:&4@;V)J96-T+"!O<B!N=6QL(&EF(&ET(&ES;B=T
M(&1E9FEN960N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D871T<FEB
M=71E("!4:&4@871T<FEB=71E('1O(&=E="X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!4:&4@=F%L=64@;V8@=&AE(&%T=')I8G5T92P@;W(@;G5L
M;"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T*"1A='1R:6)U=&4I"B`@("![
M"B`@("`@("`@<F5T=7)N(&ES<V5T*"1T:&ES+3YD871A6R1A='1R:6)U=&5=
M*0H@("`@("`@("`@("`_("1T:&ES+3YD871A6R1A='1R:6)U=&5="B`@("`@
M("`@("`@(#H@;G5L;#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@;VYE
M(&]F('1H92!A='1R:6)U=&5S(&]F('1H92!O8FIE8W0N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D871T<FEB=71E("!4:&4@871T<FEB=71E('1O
M('-E="X*("`@("`J($!P87)A;2!M:7AE9"`D=F%L=64@("`@("`@5&AE('9A
M;'5E(&9O<B`D871T<FEB=71E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S970H
M)&%T=')I8G5T92P@)'9A;'5E*0H@("`@>PH@("`@("`@("1T:&ES+3YD871A
M6R1A='1R:6)U=&5=(#T@)'9A;'5E.PH@("`@?0H*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+U!E<FUS+G!H<```````````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#,Q,C(U(#$P-3$U-#,S-S0P(#`R,3$T-@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`H*+RHJ($5X:7-T
M96YC92!O9B!O8FIE8W0@:7,@:VYO=VX@+2!O8FIE8W0@:7,@<VAO=VX@=&\@
M=7-E<BX@*B\*9&5F:6YE*"=015)-4U]32$]7)RP@,BD["@HO*BH@0V]N=&5N
M=',@;V8@=&AE(&]B:F5C="!C86X@8F4@<F5A9"X@*B\*9&5F:6YE*"=015)-
M4U]214%$)RP@-"D["@HO*BH@0V]N=&5N=',@;V8@=&AE(&]B:F5C="!C86X@
M8F4@961I=&5D+B`J+PID969I;F4H)U!%4DU37T5$250G+"`X*3L*"B\J*B!4
M:&4@;V)J96-T(&-A;B!B92!D96QE=&5D+B`J+PID969I;F4H)U!%4DU37T1%
M3$5412<L(#$V*3L*"B\J*@H@*B!!(&)I=&UA<VL@;V8@86QL('!O<W-I8FQE
M('!E<FUI<W-I;VX@=F%L=65S+B!5<V5F=6P@9F]R"B`J(')E;6]V95AX>%!E
M<FUI<W-I;VXH*2P@=6YS971097)M*"DL(&5T8RX*("HO"F1E9FEN92@G4$52
M35-?04Q,)RP@4$5235-?4TA/5R!\(%!%4DU37U)%040@?"!015)-4U]%1$E4
M('P@4$5235-?1$5,151%*3L*"B\J*@H@*B!4:&4@4&5R;7,Z.B!C;&%S<R!P
M<F]V:61E<R!T:&4@2&]R9&4@<&5R;6ES<VEO;G,@<WES=&5M+@H@*@H@*B`D
M2&]R9&4Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`L=B`Q+C@P+C$P+CD@
M,C`P-B\P-2\P-2`P-#HP.#HU.2!S96QS:WD@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#$M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`
M:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@
M2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!A=71H;W(@($IA;B!3
M8VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#(N
M,0H@*B!`<&%C:V%G92!(;W)D95]097)M<PH@*B\*8VQA<W,@4&5R;7,@>PH*
M("`@("\J*@H@("`@("H@0V%C:&5S(&EN9F]R;6%T:6]N(&%B;W5T(&%P<&QI
M8V%T:6]N('!E<FUI<W-I;VYS+@H@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1?87!P;&EC871I;VY097)M:7-S:6]N<SL*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&%V86EL86)L92!P97)M:7-S:6]N
M<R!F;W(@82!G:79E;B!L979E;"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1N86UE("!4:&4@<&5R;6ES<VEO;B=S(&YA;64N"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@;V8@879A:6QA8FQE('!E<FUI
M<W-I;VYS(&%N9"!T:&5I<B!T:71L97,@;W(*("`@("`J("`@("`@("`@("`@
M("`@(&9A;'-E(&EF(&YO="!S=6(@<&5R;6ES<VEO;G,@97AI<W0@9F]R('1H
M:7,@;&5V96PN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%V86EL86)L92@D
M;F%M92D*("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@
M("!I9B`H96UP='DH)&YA;64I*2!["B`@("`@("`@("`@("\J($YO(&YA;64@
M<&%S<V5D+"!S;R!T;W`@;&5V96P@<&5R;6ES<VEO;G,@87)E(')E<75E<W1E
M9"X@5&AE<V4*("`@("`@("`@("`@("H@8V%N(&]N;'D@8F4@87!P;&EC871I
M;VYS+B`J+PH@("`@("`@("`@("`D87!P<R`]("1R96=I<W1R>2T^;&ES=$%P
M<',H87)R87DH)VYO=&]O;&)A<B<L("=A8W1I=F4G+"`G:&ED9&5N)RDL('1R
M=64I.PH@("`@("`@("`@("!F;W)E86-H("AA<G)A>5]K97ES*"1A<'!S*2!A
M<R`D87!P*2!["B`@("`@("`@("`@("`@("`D87!P<ULD87!P72`]("1R96=I
M<W1R>2T^9V5T*"=N86UE)RP@)&%P<"D@+B`G("@G("X@)&%P<"`N("<I)SL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!A<V]R="@D87!P<RD["B`@("`@
M("`@("`@(')E='5R;B`D87!P<SL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`O*B!.86UE(&AA<R!B965N('!A<W-E9"P@97AP;&]D92!T:&4@;F%M
M92!T;R!G970@86QL('1H92!L979E;',@:6X*("`@("`@("`@("`@("H@<&5R
M;6ES<VEO;B!B96EN9R!R97%U:7-T960L('=I=&@@=&AE(&%P<"!A<R!T:&4@
M9FER<W0@;&5V96PN("HO"B`@("`@("`@("`@("1L979E;',@/2!A<G)A>2@I
M.PH@("`@("`@("`@("`D;&5V96QS(#T@97AP;&]D92@G.B<L("1N86UE*3L*
M"B`@("`@("`@("`@("\J($9I<G-T(&QE=F5L(&ES(&%L=V%Y<R!A<'`N("HO
M"B`@("`@("`@("`@("1A<'`@/2`D;&5V96QS6S!=.PH*("`@("`@("`@("`@
M+RH@4F5T=7)N(&5M<'1Y(&EF(&YO(&%P<"!D969I;F5D($%022!M971H;V0@
M9F]R('!R;W9I9&EN9PH@("`@("`@("`@("`@*B!P97)M:7-S:6]N(&EN9F]R
M;6%T:6]N+B`J+PH@("`@("`@("`@("!I9B`H(21R96=I<W1R>2T^:&%S365T
M:&]D*"=P97)M<R<L("1A<'`I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($-A;&P@=&AE
M(&%P<"=S('!E<FUI<W-I;VX@9G5N8W1I;VX@=&\@<F5T=7)N('1H92!P97)M
M:7-S:6]N<PH@("`@("`@("`@("`@*B!S<&5C:69I8R!T;R!T:&ES(&%P<"X@
M*B\*("`@("`@("`@("`@)'!E<FUS(#T@)'1H:7,M/F=E=$%P<&QI8V%T:6]N
M4&5R;6ES<VEO;G,H)&%P<"D["B`@("`@("`@("`@(&EF("AI<U]A*"1P97)M
M<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1P
M97)M<SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@<F5Q=6ER95]O;F-E
M("=(;W)D92]!<G)A>2YP:'`G.PH@("`@("`@("`@("`O*B!'970@=&AE('!A
M<G0@;V8@=&AE(&%P<"=S('!E<FUI<W-I;VYS(&)A<V5D(&]N('1H92!P97)M
M:7-S:6]N"B`@("`@("`@("`@("`J(&YA;64@<F5Q=65S=&5D+B`J+PH@("`@
M("`@("`@("`D8VAI;&1R96X@/2!(;W)D95]!<G)A>3HZ9V5T16QE;65N="@D
M<&5R;7-;)W1R964G72P@)&QE=F5L<RD["B`@("`@("`@("`@(&EF("@D8VAI
M;&1R96X@/3T](&9A;'-E('Q\"B`@("`@("`@("`@("`@("`A:7-?87)R87DH
M)&-H:6QD<F5N*2!\?`H@("`@("`@("`@("`@("`@(6-O=6YT*"1C:&EL9')E
M;BDI('L*("`@("`@("`@("`@("`@("\J($YO(&%R<F%Y(&]F(&-H:6QD<F5N
M(&%V86EL86)L92!F;W(@=&AI<R!P97)M:7-S:6]N(&YA;64N("HO"B`@("`@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("1P97)M<U]L:7-T(#T@87)R87DH*3L*("`@("`@("`@("`@9F]R
M96%C:"`H)&-H:6QD<F5N(&%S("1P97)M7VME>2`]/B`D<&5R;5]V86PI('L*
M("`@("`@("`@("`@("`@("1P97)M<U]L:7-T6R1P97)M7VME>5T@/2`D<&5R
M;7-;)W1I=&QE)UU;)&YA;64@+B`G.B<@+B`D<&5R;5]K97E=.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(')E='5R;B`D<&5R;7-?;&ES=#L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!S:&]R="!N
M86UE(&]F(&%N(&]B:F5C="P@=&AE(&QA<W0@<&]R=&EO;B!O9B!T:&4@9G5L
M;"!N86UE+@H@("`@("H*("`@("`J($!S=&%T:6,*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1N86UE("!4:&4@;F%M92!O9B!T:&4@;V)J96-T+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;V)J96-T)W,@<VAO
M<G0@;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4VAO<G1.86UE*"1N
M86UE*0H@("`@>PH@("`@("`@("\J($EF('1H97)E(&%R92!S979E<F%L(&-O
M;7!O;F5N=',@=&\@=&AE(&YA;64L(&5X<&QO9&4@86YD"B`@("`@("`@("H@
M9V5T('1H92!L87-T(&]N92P@;W1H97)W:7-E(&IU<W0@<F5T=7)N('1H92!N
M86UE+B`J+PH@("`@("`@(&EF("AS=')P;W,H)&YA;64L("<Z)RD@(3T](&9A
M;'-E*2!["B`@("`@("`@("`@("1T;7`@/2!E>'!L;V1E*"<Z)RP@)&YA;64I
M.PH@("`@("`@("`@("!R971U<FX@87)R87E?<&]P*"1T;7`I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D;F%M93L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!':79E;B!A('!E<FUI<W-I;VX@;F%M
M92P@<F5T=7)N<R!T:&4@=&ET;&4@9F]R('1H870@<&5R;6ES<VEO;B!B>0H@
M("`@("H@;&]O:VEN9R!I="!U<"!I;B!T:&4@87!P;&EC871I;VYS)W,@<&5R
M;6ES<VEO;B!A<&DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M
M92`@5&AE('!E<FUI<W-I;VYS)W,@;F%M92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE('1I=&QE(&9O<B!T:&4@<&5R;6ES<VEO;BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T5&ET;&4H)&YA;64I"B`@("!["B`@("`@
M("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@)&QE=F5L<R`](&5X<&QO
M9&4H)SHG+"`D;F%M92D["B`@("`@("`@:68@*&-O=6YT*"1L979E;',I(#T]
M(#$I('L*("`@("`@("`@("`@<F5T=7)N("1R96=I<W1R>2T^9V5T*"=N86UE
M)RP@)&YA;64I("X@)R`H)R`N("1N86UE("X@)RDG.PH@("`@("`@('T*("`@
M("`@("`D<&5R;2`](&%R<F%Y7W!O<"@D;&5V96QS*3L*"B`@("`@("`@+RH@
M1FER<W0@;&5V96P@:7,@86QW87ES(&%P<"X@*B\*("`@("`@("`D87!P(#T@
M)&QE=F5L<ULP73L*"B`@("`@("`@+RH@4F5T=7)N(&5M<'1Y(&EF(&YO(&%P
M<"!D969I;F5D($%022!M971H;V0@9F]R('!R;W9I9&EN9R!P97)M:7-S:6]N
M"B`@("`@("`@("H@:6YF;W)M871I;VXN("HO"B`@("`@("`@:68@*"$D<F5G
M:7-T<GDM/FAA<TUE=&AO9"@G<&5R;7,G+"`D87!P*2D@>PH@("`@("`@("`@
M("!R971U<FX@4&5R;7,Z.F=E=%-H;W)T3F%M92@D;F%M92D["B`@("`@("`@
M?0H*("`@("`@("`D87!P7W!E<FUS(#T@)'1H:7,M/F=E=$%P<&QI8V%T:6]N
M4&5R;6ES<VEO;G,H)&%P<"D["@H@("`@("`@(')E='5R;B!I<W-E="@D87!P
M7W!E<FUS6R=T:71L92==6R1N86UE72D*("`@("`@("`@("`@/R`D87!P7W!E
M<FUS6R=T:71L92==6R1N86UE72`N("<@*"<@+B!$871A5')E93HZ9V5T4VAO
M<G1.86UE*"1N86UE*2`N("<I)PH@("`@("`@("`@("`Z($1A=&%4<F5E.CIG
M9713:&]R=$YA;64H)&YA;64I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!I;F9O<FUA=&EO;B!A8F]U="!P97)M:7-S:6]N<R!I;7!L96UE;G1E
M9"!B>2!A;B!A<'!L:6-A=&EO;BX*("`@("`J"B`@("`@*B!`<VEN8V4@2&]R
M9&4@,RXQ"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D87!P("!!;B!A
M<'!L:6-A=&EO;B!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M($AA<V@@=VET:"!P97)M:7-S:6]N<R!I;F9O<FUA=&EO;BX*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T07!P;&EC871I;VY097)M:7-S:6]N<R@D87!P*0H@
M("`@>PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]A<'!L:6-A=&EO;E!E
M<FUI<W-I;VYS6R1A<'!=*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V%P<&QI
M8V%T:6]N4&5R;6ES<VEO;G-;)&%P<%T@/2`D1TQ/0D%,4ULG<F5G:7-T<GDG
M72T^8V%L;$)Y4&%C:V%G92@D87!P+"`G<&5R;7,G*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D=&AI<RT^7V%P<&QI8V%T:6]N4&5R;6ES<VEO;G-;
M)&%P<%T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@;F5W('!E
M<FUI<W-I;VYS(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N86UE("!4:&4@<&5R;6ES<VEO;B=S(&YA;64N"B`@("`@*@H@("`@("H@
M0')E='5R;B!097)M:7-S:6]N<R`@02!N97<@<&5R;6ES<VEO;G,@;V)J96-T
M+@H@("`@("HO"B`@("!F=6YC=&EO;B`F;F5W4&5R;6ES<VEO;B@D;F%M92D*
M("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")4:&4@
M861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@
M4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES
M<VEO;G,N(BDI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(%!E
M<FUI<W-I;VX@;V)J96-T(&-O<G)E<W!O;F1I;F<@=&\@=&AE(&YA;65D('!E
M<FUI<W-I;VXL"B`@("`@*B!W:71H('1H92!U<V5R<R!A;F0@;W1H97(@9&%T
M82!R971R:65V960@87!P<F]P<FEA=&5L>2X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1N86UE("!4:&4@;F%M92!O9B!T:&4@<&5R;6ES<VEO;B!T
M;R!R971R:65V92X*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=%!E<FUI<W-I
M;VXH)&YA;64I"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@
M<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@
M=7-E(%!E<FUI<W-I;VYS+B(I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@82!097)M:7-S:6]N(&]B:F5C="!C;W)R97-P;VYD:6YG('1O('1H
M92!G:79E;B!U;FEQ=64@240L('=I=&@*("`@("`J('1H92!U<V5R<R!A;F0@
M;W1H97(@9&%T82!R971R:65V960@87!P<F]P<FEA=&5L>2X*("`@("`J"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D8VED("!4:&4@=6YI<75E($E$(&]F('1H
M92!P97)M:7-S:6]N('1O(')E=')I979E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B`F9V5T4&5R;6ES<VEO;D)Y260H)&-I9"D*("`@('L*("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")4:&4@861M:6YI<W1R871O<B!N965D
M<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N
M9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(BDI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@061D<R!A('!E<FUI<W-I;VX@=&\@=&AE('!E<FUI
M<W-I;VYS('-Y<W1E;2X@5&AE('!E<FUI<W-I;VX@;75S="!F:7)S=`H@("`@
M("H@8F4@8W)E871E9"!W:71H(%!E<FTZ.FYE=U!E<FUI<W-I;VXH*2P@86YD
M(&AA=F4@86YY(&EN:71I86P@=7-E<G,*("`@("`J(&%D9&5D('1O(&ET+"!B
M969O<F4@=&AI<R!F=6YC=&EO;B!I<R!C86QL960N"B`@("`@*@H@("`@("H@
M0'!A<F%M(%!E<FUI<W-I;VX@)'!E<FT@(%1H92!N97<@<&5R;2!O8FIE8W0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9%!E<FUI<W-I;VXH)B1P97)M*0H@
M("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E1H92!A
M9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!0
M97)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S
M:6]N<RXB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S(&$@<&5R
M;6ES<VEO;B!F<F]M('1H92!P97)M:7-S:6]N<R!S>7-T96T@<&5R;6%N96YT
M;'DN"B`@("`@*@H@("`@("H@0'!A<F%M(%!E<FUI<W-I;VX@)'!E<FT@(%1H
M92!P97)M:7-S:6]N('1O(')E;6]V92X*("`@("`J($!P87)A;2!B;V]L96%N
M("1F;W)C92`@("!&;W)C92!T;R!R96UO=F4@979E<GD@8VAI;&0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(')E;6]V95!E<FUI<W-I;VXH)B1P97)M+"`D9F]R
M8V4@/2!F86QS92D*("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BA?*")4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@
M82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T
M;R!U<V4@4&5R;6ES<VEO;G,N(BDI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1FEN9',@;W5T('=H870@<FEG:'1S('1H92!G:79E;B!U<V5R(&AA<R!T;R!T
M:&ES(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)'!E<FUI
M<W-I;VX@(%1H92!F=6QL('!E<FUI<W-I;VX@;F%M92!O9B!T:&4@;V)J96-T
M('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&-H96-K('1H
M92!P97)M:7-S:6]N<R!O9BP@;W(@=&AE(%!E<FUI<W-I;VX*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@;V)J96-T+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=7-E<B`@("`@("!4:&4@=7-E<B!T;R!C:&5C:R!F;W(N($1E
M9F%U;'1S('1O('1H92!C=7)R96YT"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@('5S97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C<F5A=&]R
M("`@(%1H92!U<V5R('=H;R!C<F5A=&5D('1H92!E=F5N="X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!!(&)I=&UA<VL@;V8@<&5R;6ES<VEO;G,@
M=&AE('5S97(@:&%S+"!F86QS92!I9B!T:&5R90H@("`@("H@("`@("`@("`@
M("`@("`@87)E(&YO;F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!E<FUI
M<W-I;VYS*"1P97)M:7-S:6]N+"`D=7-E<B`](&YU;&PL("1C<F5A=&]R(#T@
M;G5L;"D*("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?
M*")4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M
M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@
M4&5R;6ES<VEO;G,N(BDI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!T:&4@=6YI<75E(&ED96YT:69I97(@;V8@=&AI<R!P97)M:7-S:6]N+@H@
M("`@("H*("`@("`J($!P87)A;2!097)M:7-S:6]N("1P97)M:7-S:6]N("!4
M:&4@<&5R;6ES<VEO;B!O8FIE8W0@=&\@9V5T('1H92!)1"!O9BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!U;FEQ=64@:60N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=%!E<FUI<W-I;VY)9"@D<&5R;6ES<VEO;BD*
M("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")4:&4@
M861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@
M4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES
M<VEO;G,N(BDI.PH@("`@?0H*("`@("\J*@H@("`@("H@1FEN9',@;W5T(&EF
M('1H92!U<V5R(&AA<R!T:&4@<W!E8VEF:65D(')I9VAT<R!T;R!T:&4@9VEV
M96X@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1P97)M
M:7-S:6]N("!4:&4@<&5R;6ES<VEO;B!T;R!C:&5C:RX*("`@("`J($!P87)A
M;2!S=')I;F<@("1U<V5R("`@("`@("!4:&4@=7-E<B!T;R!C:&5C:R!F;W(N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<&5R;2`@("`@("`@5&AE('!E<FUI
M<W-I;VX@;&5V96P@;F5E9&5D(&9O<B!A8V-E<W,N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("`D8W)E871O<B`@("`@5&AE(&-R96%T;W(@;V8@=&AE(&5V96YT
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!U
M<V5R(&AA<R!T:&4@<W!E8VEF:65D('!E<FUI<W-I;VYS+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!H87-097)M:7-S:6]N*"1P97)M:7-S:6]N+"`D=7-E<BP@
M)'!E<FTL("1C<F5A=&]R(#T@;G5L;"D*("`@('L*("`@("`@("!R971U<FX@
M9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@:68@82!P97)M
M:7-S:6]N(&5X:7-T<R!I;B!T:&4@<WES=&5M+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'!E<FUI<W-I;VX@(%1H92!P97)M:7-S:6]N('1O(&-H
M96-K+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T
M:&4@<&5R;6ES<VEO;B!E>&ES=',N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X
M:7-T<R@D<&5R;6ES<VEO;BD*("`@('L*("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@;&ES="!O9B!P87)E
M;G0@<&5R;6ES<VEO;G,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M8VAI;&0@(%1H92!N86UE(&]F('1H92!C:&EL9"!T;R!R971R:65V92!P87)E
M;G1S(&9O<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!(&AA<V@@
M=VET:"!A;&P@<&%R96YT<R!I;B!A('1R964@9F]R;6%T+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971087)E;G1S*"1C:&EL9"D*("`@('L*("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")4:&4@861M:6YI<W1R871O<B!N
M965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C
M:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(BDI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;&P@<&5R;6ES<VEO;G,@;V8@
M=&AE('-Y<W1E;2!I;B!A('1R964@9F]R;6%T+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@($$@:&%S:"!W:71H(&%L;"!P97)M:7-S:6]N<R!I;B!A
M('1R964@9F]R;6%T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714<F5E*"D*
M("`@('L*("`@("`@("!R971U<FX@87)R87DH*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@86X@:&%S:"!O9B!T:&4@879A:6QA8FQE('!E<FUI
M<W-I;VYS+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!A=F%I
M;&%B;&4@<&5R;6ES<VEO;G,@87,@82!H87-H+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971097)M<T%R<F%Y*"D*("`@('L*("`@("`@("!R971U<FX@87)R
M87DH4$5235-?4TA/5R`]/B!?*")3:&]W(BDL"B`@("`@("`@("`@("`@("`@
M("`@(%!%4DU37U)%040@/3X@7R@B4F5A9"(I+`H@("`@("`@("`@("`@("`@
M("`@("!015)-4U]%1$E4(#T^(%\H(D5D:70B*2P*("`@("`@("`@("`@("`@
M("`@("`@4$5235-?1$5,151%(#T^(%\H(D1E;&5T92(I*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($=I=F5N(&%N(&EN=&5G97(@=F%L=64@;V8@<&5R;6ES
M<VEO;G,@<F5T=7)N<R!A;B!A<G)A>0H@("`@("H@<F5P<F5S96YT871I;VX@
M;V8@=&AE(&EN=&5G97(N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)&EN="`@5&AE(&EN=&5G97(@<F5P<F5S96YT871I;VX@;V8@<&5R;6ES<VEO
M;G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&EN=&5G97)4;T%R<F%Y*"1I;G0I
M"B`@("!["B`@("`@("`@<W1A=&EC("1A<G)A>2`](&%R<F%Y*"D["B`@("`@
M("`@:68@*&ES<V5T*"1A<G)A>5LD:6YT72DI('L*("`@("`@("`@("`@<F5T
M=7)N("1A<G)A>5LD:6YT73L*("`@("`@("!]"@H@("`@("`@("1A<G)A>5LD
M:6YT72`](&%R<F%Y*"D["@H@("`@("`@("\J($=E="!T:&4@879A:6QA8FQE
M('!E<FUS(&%R<F%Y+B`J+PH@("`@("`@("1P97)M<R`](%!E<FUS.CIG9710
M97)M<T%R<F%Y*"D["@H@("`@("`@("\J($QO;W`@=&AR;W5G:"!E86-H('!E
M<FT@86YD(&-H96-K(&EF(&ET<R!V86QU92!I<R!I;F-L=61E9"!I;B!T:&4*
M("`@("`@("`@*B!I;G1E9V5R(')E<')E<V5N=&%T:6]N+B`J+PH@("`@("`@
M(&9O<F5A8V@@*"1P97)M<R!A<R`D=F%L(#T^("1L86)E;"D@>PH@("`@("`@
M("`@("!I9B`H)&EN="`F("1V86PI('L*("`@("`@("`@("`@("`@("1A<G)A
M>5LD:6YT75LD=F%L72`]('1R=64["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D87)R87E;)&EN=%T["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC<F5T92!097)M<R!I
M;G-T86YC92!B87-E9"!O;B`D9')I=F5R+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&1R:79E<B`@5&AE('1Y<&4@;V8@=&AE(&-O;F-R971E(%!E
M<FUS('-U8F-L87-S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@('1O
M(')E='5R;BX@(%1H92!C;&%S<R!N86UE(&ES(&)A<V5D(&]N('1H90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("!P97)M<R!D<FEV97(@*"1D<FEV
M97(I+B`@5&AE(&-O9&4@:7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@9'EN86UI8V%L;'D@:6YC;'5D960N"B`@("`@*@H@("`@("H@0')E='5R
M;B!097)M<WQB;V]L96%N("!4:&4@;F5W;'D@8W)E871E9"!C;VYC<F5T92!0
M97)M<R!I;G-T86YC92P@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@9F%L<V4@;VX@86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9F
M86-T;W)Y*"1D<FEV97(@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]N
M=6QL*"1D<FEV97(I*2!["B`@("`@("`@("`@("1P97)M<R`]("9N97<@4&5R
M;7,H*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I;F-L=61E7V]N
M8V4@)TAO<F1E+U!E<FUS+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@
M("`@("`D8VQA<W,@/2`G4&5R;7-?)R`N("1D<FEV97(["B`@("`@("`@("`@
M(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`@("`@
M)'!E<FUS(#T@)FYE=R`D8VQA<W,H*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1P97)M<R`](&9A;'-E.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'!E<FUS.PH@("`@?0H*("`@
M("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@<F5F97)E;F-E('1O
M(&$@8V]N8W)E=&4@4&5R;7,@:6YS=&%N8V4N"B`@("`@*B!)="!W:6QL(&]N
M;'D@8W)E871E(&$@;F5W(&EN<W1A;F-E(&EF(&YO(%!E<FUS(&EN<W1A;F-E
M"B`@("`@*B!C=7)R96YT;'D@97AI<W1S+@H@("`@("H*("`@("`J(%1H:7,@
M;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH@)'9A<B`]("9097)M<SHZ<VEN
M9VQE=&]N*"D*("`@("`J"B`@("`@*B!`<F5T=7)N(%!E<FUS?&)O;VQE86X@
M(%1H92!C;VYC<F5T92!097)M(')E9F5R96YC92P@;W(@9F%L<V4@;VX@97)R
M;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH*0H@("`@>PH@
M("`@("`@('-T871I8R`D<&5R;3L*"B`@("`@("`@:68@*"%I<W-E="@D<&5R
M;2DI('L*("`@("`@("`@("`@)'!E<FT@/2`F4&5R;7,Z.F9A8W1O<GDH(65M
M<'1Y*"1'3$]"04Q36R=C;VYF)UU;)V1A=&%T<F5E)UU;)V1R:79E<B==*2`_
M("=D871A=')E92<@.B!N=6QL*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D<&5R;3L*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+TAO<F1E+TUO8FEL92YP:'``````````````````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,3`W,#<S(#$P-3$U-#,S-S0P(#`R,3(W-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@0'!A8VMA9V4@2&]R9&5?36]B:6QE"B`J+PIC;&%S<R!(;W)D95]-
M;V)I;&5?8V%R9"!E>'1E;F1S($AO<F1E7TUO8FEL95]E;&5M96YT('L*"B`@
M("!V87(@)%]N86UE.PH@("`@=F%R("1?=&ET;&4["B`@("!V87(@)%]F;W)M
M.PH@("`@=F%R("1?96QE;65N=',@/2!A<G)A>2@I.PH@("`@=F%R("1?<V]F
M=&ME>7,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@5&AE(&YA;64@
M;V8@=&AI<R!C87)D+B!#86X@8F4@=7-E9"!I;B!A;F-H;W(*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!L:6YK<RX*("`@("`J($!P87)A;2!S=')I
M;F<@)'1I=&QE("!)9B!A('-T<FEN9R!I<R!P<F]V:61E9"!H97)E+"!I="!W
M:6QL(&)E(&1I<W!L87EE9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M(&EN('1H92!(5$U,('1I=&QE(&)A<BP@<F5S<&5C=&EV96QY('-O;65W:&5R
M92!O;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('1H92!705`@9&ES
M<&QA>2X@57-I;F<@82!T:71L92!Y;W4@=VEL;"!N;W)M86QL>0H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@(&AA=F4@=&\@<W!E;F0@;VYE(&]F('EO
M=7(@9F5W(&QI;F5S(&]N('EO=7(@5T%0"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@9&ES<&QA>2X@0V]N<VED97(@=&AA="!S;VUE(%=!4"!P:&]N
M97,O4T1+)W,@86YD"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@:&%N
M9&AE;&0@9&5V:6-E<R!D;VXG="!D:7-P;&%Y('1H92!T:71L92!A="!A;&PN
M"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7TUO8FEL95]C87)D*"1N86UE
M(#T@;G5L;"P@)'1I=&QE(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^
M7VYA;64@/2`D;F%M93L*("`@("`@("`D=&AI<RT^7W1I=&QE(#T@)'1I=&QE
M.PH@("`@?0H*("`@(&9U;F-T:6]N("9A9&0H)B1E;&5M96YT*0H@("`@>PH@
M("`@("`@('-T871I8R`D;&EN:W-E=$%D9&5D.PH*("`@("`@("!I9B`H(6ES
M7V$H)&5L96UE;G0L("=(;W)D95]-;V)I;&5?96QE;65N="<I*2!["B`@("`@
M("`@("`@("1E<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H)TEN=F%L:60@96QE
M;65N="XG*3L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]
M(&5L<V5I9B`H:7-?82@D96QE;65N="P@)TAO<F1E7TUO8FEL95]T97AT)RD@
M?'P*("`@("`@("`@("`@("`@("`@:7-?82@D96QE;65N="P@)TAO<F1E7TUO
M8FEL95]T86)L92<I('Q\"B`@("`@("`@("`@("`@("`@(&ES7V$H)&5L96UE
M;G0L("=(;W)D95]-;V)I;&5?:6UA9V4G*2!\?`H@("`@("`@("`@("`@("`@
M("!I<U]A*"1E;&5M96YT+"`G2&]R9&5?36]B:6QE7VQI;FLG*2!\?`H@("`@
M("`@("`@("`@("`@("!I<U]A*"1E;&5M96YT+"`G2&]R9&5?36]B:6QE7W!H
M;VYE)RD@?'P*("`@("`@("`@("`@("`@("`@:7-?82@D96QE;65N="P@)TAO
M<F1E7TUO8FEL95]R=6QE)RDI('L*("`@("`@("`@("`@)&)L;V-K(#T@)FYE
M=R!(;W)D95]-;V)I;&5?8FQO8VLH)&5L96UE;G0I.PH@("`@("`@("`@("`D
M=&AI<RT^7V5L96UE;G1S6UT@/2`F)&)L;V-K.PH@("`@("`@('T@96QS96EF
M("AI<U]A*"1E;&5M96YT+"`G2&]R9&5?36]B:6QE7V)L;V-K)RDI('L*("`@
M("`@("`@("`@)'1H:7,M/E]E;&5M96YT<UM=(#T@)B1E;&5M96YT.PH@("`@
M("`@('T@96QS96EF("AI<U]A*"1E;&5M96YT+"`G2&]R9&5?36]B:6QE7V9O
M<FTG*2D@>PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?9F]R;2DI
M('L*("`@("`@("`@("`@("`@("1E<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H
M)T-A<F1S(&UA>2!O;FQY(&-O;G1A:6X@;VYE($9O<FT@96QE;65N="XG*3L*
M("`@("`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)'1H:7,M/E]E;&5M96YT<UM=(#T@)B1E;&5M96YT.PH@
M("`@("`@("`@("`D=&AI<RT^7V9O<FT@/2`F)&5L96UE;G0["B`@("`@("`@
M?2!E;'-E:68@*&ES7V$H)&5L96UE;G0L("=(;W)D95]-;V)I;&5?;&EN:W-E
M="<I*2!["B`@("`@("`@("`@(&EF("@A96UP='DH)&QI;FMS971!9&1E9"DI
M('L*("`@("`@("`@("`@("`@("1E<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H
M)T-A<F1S(&UA>2!O;FQY(&-O;G1A:6X@;VYE($QI;FMS970@96QE;65N="XG
M*3L*("`@("`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)&)L;V-K(#T@)FYE=R!(;W)D95]-;V)I;&5?8FQO
M8VLH)&5L96UE;G0I.PH@("`@("`@("`@("`D=&AI<RT^7V5L96UE;G1S6UT@
M/2`F)&)L;V-K.PH@("`@("`@("`@("`D;&EN:W-E=$%D9&5D(#T@=')U93L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D97)R;W(@/2!014%2.CIR
M86ES945R<F]R*"=4:&ES(&5L96UE;G0@;75S="!B92!I;G-I9&4@86X@87!P
M<F]P<FEA=&4@8V]N=&%I;F5R(&5L96UE;G0N)RD["B`@("`@("`@("`@(')E
M='5R;B`D97)R;W(["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&5L96UE
M;G0["B`@("!]"@H@("`@9G5N8W1I;VX@<V]F=&ME>2@D=7)L+"`D;&%B96PI
M"B`@("!["B`@("`@("`@)'1H:7,M/E]S;V9T:V5Y<UM=(#T@87)R87DH)W5R
M;"<@/3X@)'5R;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G;&%B96PG(#T^("1L86)E;"D["B`@("!]"@I]"@HO*BH*("H@2&]R9&5?
M36]B:6QE.CH*("H*("H@2&]R9&4@05!)(&9O<B!G96YE<F%T:6YG($UO8FEL
M92!C;VYT96YT+B!);F-L=61E<R!N=6UE<F]U<R!U=&EL:71Y"B`J(&9U;F-T
M:6]N<RP@9V5N97)A;&EZ960@96QE;65N="!C;&%S<V5S+"!A;F0@<F5N9&5R
M97)S(&9O<B!M87)K=7`*("H@;&%N9W5A9V5S(&EN8VQU9&EN9R!734PL($A$
M34PL(&%N9"!#2%1-3"X*("H*("H@5&AI<R!C;&%S<R!I<R!T:&4@=&]P(&QE
M=F5L(&-L87-S(&]F(&%L;"!(;W)D95]-;V)I;&4@8VQA<W-E<RX@66]U<@H@
M*B!P86=E('-H;W5L9"!C;VYS:7-T(&]F(&5X86-T;'D@;VYE($AO<F1E7TUO
M8FEL92!O8FIE8W0N($%P<')O<')I871E"B`J(&UA<FMU<"`M($EM;V1E+"!7
M34PL($A$34PL(&5T8RX@+2!I<R!G96YE<F%T960@8GD@=&AE(&%P<')O<')I
M871E"B`J(')E;F1E<F5R(&]B:F5C=`H@*@H@*B!$;R!N;W0@;W9E<G-T=69F
M($AO<F1E7TUO8FEL92!O8FIE8W1S+B!296UE;6)E<B!T:&%T(&$@;&]T(&]F
M(%=!4`H@*B!C;&EE;G1S(&-A;FYO="!H86YD;&4@;6]R92!T:&%N(&%B;W5T
M(#$T,#`@8GET97,@;V8@8V]M<&EL960@9&%T82X*("H*("H@17AA;7!L97,Z
M"B`J"B`J("1M>5!A9V4@/2!N97<@2&]R9&5?36]B:6QE*"D["B`J("1M>5!A
M9V4@/2!N97<@2&]R9&5?36]B:6QE*"=->2!705`@<&%G92<I.PH@*B`D;7E0
M86=E(#T@;F5W($AO<F1E7TUO8FEL92@G)RP@)V-E;G1E<B<I.PH@*@H@*B`O
M+R!-;W)E('-T=69F"B`J"B`J("1M>5!A9V4M/F%D9"@D;7E497AT*3L*("H*
M("H@+R\@36]R92!I=&5M<PH@*@H@*B`D;7E086=E+3YR96YD97(H*3L*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO36]B:6QE+TUO8FEL92YP:'`L=B`Q+C,R
M+C$P+CD@,C`P-B\P-B\R-B`P-CHR-SHR,R!S96QS:WD@17AP("0*("H*("H@
M0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO
M<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S
M+C`*("H@0'!A8VMA9V4@2&]R9&5?36]B:6QE"B`J+PIC;&%S<R!(;W)D95]-
M;V)I;&4@97AT96YD<R!(;W)D95]-;V)I;&5?8V%R9"!["@H@("`@=F%R("1?
M=&ET;&4["B`@("!V87(@)%]E;&5M96YT<R`](&%R<F%Y*"D["B`@("!V87(@
M)%]C87)D<R`](&%R<F%Y*"D["B`@("!V87(@)%]D96)U9R`](&9A;'-E.PH*
M("`@("\O($1E8VED92!W:&5T:&5R('1H92!S:6UU;&%T;W(@9&5V:6-E(&ES
M('1O(&)E('5S960N($]N;'D@869F96-T<PH@("`@+R\@2%1-3"!B<F]W<V5R
M(&]U='!U="X*("`@('9A<B`D7W-I;75L871O<B`](&9A;'-E.PH*("`@("\J
M*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1T:71L92`@268@82!S=')I;F<@:7,@<')O=FED960@:&5R92P@:70@
M=VEL;"!B92!D:7-P;&%Y960*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!I;B!T:&4@2%1-3"!T:71L92!B87(L(')E<W!E8W1I=F5L>2!S;VUE=VAE
M<F4@;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!T:&4@5T%0(&1I
M<W!L87DN(%5S:6YG(&$@=&ET;&4@>6]U('=I;&P@;F]R;6%L;'D*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("!H879E('1O('-P96YD(&]N92!O9B!Y
M;W5R(&9E=R!L:6YE<R!O;B!Y;W5R(%=!4`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@(&1I<W!L87DN($-O;G-I9&5R('1H870@<V]M92!705`@<&AO
M;F5S+U-$2R=S(&%N9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&AA
M;F1H96QD(&1E=FEC97,@9&]N)W0@9&ES<&QA>2!T:&4@=&ET;&4@870@86QL
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D86=E;G0@($EF('-P96-I9FEE9"P@
M=7-E(&EN<W1E860@;V8@2%144%]54T527T%'14Y4+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!(;W)D95]-;V)I;&4H)'1I=&QE(#T@;G5L;"P@)&%G96YT(#T@
M;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES7VYU;&PH)'1I=&QE*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7W1I=&QE(#T@)'1I=&QE.PH@("`@("`@('T*
M"B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]"<F]W<V5R+G!H<"<["B`@
M("`@("`@)&)R;W=S97(@/2`F0G)O=W-E<CHZ<VEN9VQE=&]N*"1A9V5N="D[
M"@H@("`@("`@(&EF("@D8G)O=W-E<BT^:&%S1F5A='5R92@G:'1M;"<I*2![
M"B`@("`@("`@("`@("1M;"`]("=H=&UL)SL*("`@("`@("!](&5L<V5I9B`H
M)&)R;W=S97(M/FAA<T9E871U<F4H)W=M;"<I*2!["B`@("`@("`@("`@("1M
M;"`]("=W;6PG.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1M;"`]
M("=H=&UL)SL*("`@("`@("!]"@H@("`@("`@(')E<75I<F5?;VYC92!D:7)N
M86UE*%]?1DE,15]?*2`N("<O36]B:6QE+U)E;F1E<F5R+G!H<"<["B`@("`@
M("`@)'1H:7,M/E]R96YD97)E<B`]("9(;W)D95]-;V)I;&5?4F5N9&5R97(Z
M.G-I;F=L971O;B@D;6PL("1B<F]W<V5R*3L*("`@('T*"B`@("!F=6YC=&EO
M;B`F861D*"8D96QE;65N="D*("`@('L*("`@("`@("!I9B`H:7-?82@D96QE
M;65N="P@)TAO<F1E7TUO8FEL95]C87)D)RDI('L*("`@("`@("`@("`@:68@
M*&-O=6YT*"1T:&ES+3Y?96QE;65N=',I*2!["B`@("`@("`@("`@("`@("`D
M97)R;W(@/2!014%2.CIR86ES945R<F]R*"=9;W4@8V%N;F]T(&UI>"!(;W)D
M95]-;V)I;&5?8V%R9',@86YD(&]T:&5R(&5L96UE;G1S(&%T('1H92!D96-K
M(&QE=F5L+B<I.PH@("`@("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M/E]U<VEN9T-A<F1S(#T@
M=')U93L*("`@("`@("`@("`@)'1H:7,M/E]C87)D<UM=(#T@)B1E;&5M96YT
M.PH*("`@("`@("`@("`@<F5T=7)N("1E;&5M96YT.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(&EF("AC;W5N="@D=&AI<RT^7V-A<F1S*2D@>PH@
M("`@("`@("`@("`@("`@)&5R<F]R(#T@4$5!4CHZ<F%I<V5%<G)O<B@G66]U
M(&-A;FYO="!M:7@@2&]R9&5?36]B:6QE7V-A<F1S(&%N9"!O=&AE<B!E;&5M
M96YT<R!A="!T:&4@9&5C:R!L979E;"XG*3L*("`@("`@("`@("`@("`@(')E
M='5R;B`D97)R;W(["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(')E='5R
M;B!P87)E;G0Z.F%D9"@D96QE;65N="D["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@06-T:79A=&5S('1H92!B=6EL="UI;B!D979I8V4@<VEM
M=6QA=&]R(&]N(&)I9W-C<F5E;B!B<F]W<V5R<RX*("`@("`J(%1H92!D979I
M8V4@<VEM=6QA=&]R(&ES(&]N;'D@9G5L;'DM9G5N8W1I;VYA;"!I;B!);G1E
M<FYE=`H@("`@("H@17AP;&]R97(L(&)E8V%U<V4@=&AE(&QA>6]U="!R97%U
M:7)E<R!A('-C<F]L;&%B;&4@=&%B;&4*("`@("`J(&5L96UE;G0N($]T:&5R
M(&)R;W=S97)S('=I;&P@9F%I;"!T;R!S:&]W(&-O;G1E;G0@;VX@<&%G97,*
M("`@("`J(&QO;F=E<B!T:&%N(&$@<VEN9VQE('-C<F5E;BX*("`@("`J+PH@
M("`@9G5N8W1I;VX@=7-E4VEM=6QA=&]R*"D*("`@('L*("`@("`@("`D=&AI
M<RT^7W-I;75L871O<B`]('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M<F5A=&5S('1H92!P86=E(&EN('1H92!A<'!R;W!R:6%T92!M87)K=7`@;&%N
M9W5A9V4N($1E<&5N9&EN9PH@("`@("H@;VX@=&AE(')E;F1E<F5R('1Y<&4L
M($A434P@*'!U<F4@2%1-3"P@:&%N9&AE;&1F<FEE;F1L>2!!=F%N=$=O"B`@
M("`@*B!(5$U,+"!I+6UO9&4@8TA434PL($U-3"DL(%=-3"!O<B!(1$U,(&-O
M9&4@:7,@8W)E871E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9&ES<&QA>2@I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]R96YD97)E<BT^<F5N9&5R*"1T:&ES
M*3L*("`@('T*"GT*"B\J*@H@*B!`<&%C:V%G92!(;W)D95]-;V)I;&4*("HO
M"F-L87-S($AO<F1E7TUO8FEL95]E;&5M96YT('L*"B`@("!F=6YC=&EO;B!(
M;W)D95]-;V)I;&5?96QE;65N="@I"B`@("!["B`@("!]"@H@("`@9G5N8W1I
M;VX@9V5T*"1A='1R:6)U=&4I"B`@("!["B`@("`@("`@)&%T='(@/2`G7R<@
M+B`D871T<FEB=71E.PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^)&%T='(I
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^)&%T='(["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H@
M("`@?0H*("`@(&9U;F-T:6]N('-E="@D871T<FEB=71E+"`D=F%L=64I"B`@
M("!["B`@("`@("`@)&%T='(@/2`G7R<@+B`D871T<FEB=71E.PH@("`@("`@
M("1T:&ES+3XD871T<B`]("1V86QU93L*("`@('T*"GT*"B\J*@H@*B!`<&%C
M:V%G92!(;W)D95]-;V)I;&4*("HO"F-L87-S($AO<F1E7TUO8FEL95]F;W)M
M16QE;65N="!E>'1E;F1S($AO<F1E7TUO8FEL95]E;&5M96YT('L*"B`@("!V
M87(@)%]N86UE.PH@("`@=F%R("1?=F%L=64["B`@("!V87(@)%]L86)E;#L*
M("`@('9A<B`D7W-I>F4["B`@("!V87(@)%]M87AL96YG=&@["B`@("!V87(@
M)%]T>7!E.PH@("`@=F%R("1?9F]R;6%T.PH@("`@=F%R("1?;6]D93L*"B`@
M("`O*BH*("`@("`J(%-E="!I;G!U="!M;V1E+VES='EL92!F;W(@:F%P86YE
M<V4@34U,+VDM;6]D92!D979I8V5S+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&UO9&4@($EN<'5T(&UO9&4L(&]N92!O9CH*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("=A;'!H82<@*&1E9F%U;'0I"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`G:V%T86MA;F$G"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`G:&ER86=A;F$G"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`G;G5M97)I8R<*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T36]D92@D
M;6]D92D*("`@('L*("`@("`@("`D=&AI<RT^7VUO9&4@/2`D;6]D93L*"B`@
M("`@("`@+R\@36%P('1H92!M;V1E(&EN=&\@86X@87!P<F]P<FEA=&4@9F]R
M;6%T('-T<FEN9RP@=7-E9"!F;W(*("`@("`@("`O+R!734P@86YD($A$34PN
M($EF(&$@9F]R;6%T('-T<FEN9R!W87,@<')O=FED960@96%R;&EE<BP@:70*
M("`@("`@("`O+R!W:6QL(&)E(&]V97)W<FET=&5N+@H@("`@("`@('-W:71C
M:"`H)&UO9&4I('L*("`@("`@("!C87-E("=H:7)A9V%N82<Z"B`@("`@("`@
M8V%S92`G:V%T86MA;F$G.@H@("`@("`@("`@("`D=&AI<RT^7V9O<FUA="`]
M("<J32<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=A;'!H
M82<Z"B`@("`@("`@("`@("1T:&ES+3Y?9F]R;6%T(#T@)RIM)SL*("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)VYU;65R:6,G.@H@("`@("`@
M("`@("`D=&AI<RT^7V9O<FUA="`]("<J3B<["B`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@('T*("`@('T*"GT*"B\J*@H@*B!4:&ES(&-L87-S(&1E9FEN
M97,@82!F;W)M('=I=&@@=F%R:6]U<R!P;W-S:6)L92!I;G!U="!E;&5M96YT
M<RX@5&AE"B`J(&EN<'5T(&5L96UE;G1S(&AA=F4@=&\@8F4@9&5F:6YE9"!A
M<R!S97!A<F%T92!O8FIE8W1S(&%N9"!A<F4*("H@;&EN:V5D('1O('1H92!F
M;W)M('=I=&@@82!S<&5C:6%L(")A9&0B(&9U;F-T:6]N+B!/;F4@2&]R9&5?
M36]B:6QE"B`J(&]B:F5C="!C86X@8V]N=&%I;B!O;FQY(&]N92!(;W)D95]-
M;V)I;&5?9F]R;2!O8FIE8W0N"B`J"B`J($5X86UP;&5S.@H@*@H@*B`D;7E0
M86=E(#T@;F5W($AO<F1E7TUO8FEL92@N+BXI.PH@*@H@*B`D;7E&;W)M(#T@
M;F5W($AO<F1E7TUO8FEL95]F;W)M*"(O;7EN97AT<&%G92YW;6PB*3L*("H@
M)&UY5&5X="`](&YE=R!(;W)D95]-;V)I;&5?=&5X="@N+BXI.PH@*B`D;7E&
M;W)M+3YA9&0H)&UY5&5X="D["B`J("1M>4EN<'5T(#T@;F5W($AO<F1E7TUO
M8FEL95]I;G!U="@N+BXI.PH@*B`D;7E&;W)M+3YA9&0H)&UY26YP=70I.PH@
M*B`D;7E3=6)M:70@/2!N97<@2&]R9&5?36]B:6QE7W-U8FUI="@N+BXI.PH@
M*B`D;7E&;W)M+3YA9&0H)&UY4W5B;6ET*3L*("H*("H@)&UY4&%G92T^861D
M*"1M>49O<FTI.PH@*@H@*B`D;7E086=E+3YR96YD97(H*3L*("H*("H@0'-E
M92!(;W)D95]-;V)I;&5?=&5X=`H@*B!`<V5E($AO<F1E7TUO8FEL95]I;6%G
M90H@*B!`<V5E($AO<F1E7TUO8FEL95]T86)L90H@*B!`<V5E($AO<F1E7TUO
M8FEL95]I;G!U=`H@*B!`<V5E($AO<F1E7TUO8FEL95]T97AT87)E80H@*B!`
M<V5E($AO<F1E7TUO8FEL95]S96QE8W0*("H@0'-E92!(;W)D95]-;V)I;&5?
M<F%D:6\*("H@0'-E92!(;W)D95]-;V)I;&5?8VAE8VMB;W@*("H@0'-E92!(
M;W)D95]-;V)I;&5?<W5B;6ET"B`J($!S964@2&]R9&5?36]B:6QE7W)U;&4*
M("H*("H@0'!A8VMA9V4@2&]R9&5?36]B:6QE"B`J+PIC;&%S<R!(;W)D95]-
M;V)I;&5?9F]R;2!E>'1E;F1S($AO<F1E7TUO8FEL95]E;&5M96YT('L*"B`@
M("!V87(@)%]U<FP["B`@("!V87(@)%]M971H;V0["B`@("!V87(@)%]E;&5M
M96YT<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5R;"`@("`@("!!9&1R97-S
M('=H97)E('1H92!U<V5R(&EN<'5T(&ES('-E;G0@=&\N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1M971H;V0@("`@)W!O<W0G("AD969A=6QT*2!O<B`G9V5T
M)RX*("`@("`J($!P87)A;2!B;V]L96%N("1S97-S:6]N("!0<F5S97)V92!T
M:&4@<V5S:6]N(&ED(&EN('1H92!F;W)M/R!$969A=6QT<R!T;R!T<G5E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]-;V)I;&5?9F]R;2@D=7)L+"`D
M;65T:&]D(#T@)W!O<W0G+"`D<V5S<VEO;B`]('1R=64I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]U<FP@/2`D=7)L.PH@("`@("`@("1T:&ES+3Y?;65T:&]D
M(#T@)&UE=&AO9#L*"B`@("`@("`@:68@*"1S97-S:6]N("8F("%A<G)A>5]K
M97E?97AI<W1S*'-E<W-I;VY?;F%M92@I+"`D7T-/3TM)12DI('L*("`@("`@
M("`@("`@)'1H:7,M/F%D9"AN97<@2&]R9&5?36]B:6QE7VAI9&1E;BAS97-S
M:6]N7VYA;64H*2P@<V5S<VEO;E]I9"@I*2D["B`@("`@("`@?0H@("`@?0H*
M("`@(&9U;F-T:6]N("9A9&0H)B1F;W)M16QE;65N="D*("`@('L*("`@("`@
M("!I9B`H:7-?82@D9F]R;45L96UE;G0L("=(;W)D95]-;V)I;&5?<W5B;6ET
M)RDI('L*("`@("`@("`@("`@)&9O<FU%;&5M96YT+3Y?9F]R;2`]("8D=&AI
M<SL*("`@("`@("`@("`@)&)L;V-K(#T@)FYE=R!(;W)D95]-;V)I;&5?8FQO
M8VLH)&9O<FU%;&5M96YT*3L*("`@("`@("`@("`@)'1H:7,M/E]E;&5M96YT
M<UM=(#T@)B1B;&]C:SL*("`@("`@("!](&5L<V5I9B`H:7-?82@D9F]R;45L
M96UE;G0L("=(;W)D95]-;V)I;&5?:&ED9&5N)RD@?'P*("`@("`@("`@("`@
M("`@("`@:7-?82@D9F]R;45L96UE;G0L("=(;W)D95]-;V)I;&5?8FQO8VLG
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V5L96UE;G1S6UT@/2`F)&9O<FU%
M;&5M96YT.PH@("`@("`@('T@96QS96EF("AI<U]A*"1F;W)M16QE;65N="P@
M)TAO<F1E7TUO8FEL95]F;W)M16QE;65N="<I('Q\"B`@("`@("`@("`@("`@
M("`@(&ES7V$H)&9O<FU%;&5M96YT+"`G2&]R9&5?36]B:6QE7W1E>'0G*2!\
M?`H@("`@("`@("`@("`@("`@("!I<U]A*"1F;W)M16QE;65N="P@)TAO<F1E
M7TUO8FEL95]T86)L92<I('Q\"B`@("`@("`@("`@("`@("`@(&ES7V$H)&9O
M<FU%;&5M96YT+"`G2&]R9&5?36]B:6QE7W)U;&4G*2!\?`H@("`@("`@("`@
M("`@("`@("!I<U]A*"1F;W)M16QE;65N="P@)TAO<F1E7TUO8FEL95]I;6%G
M92<I*2!["B`@("`@("`@("`@("1B;&]C:R`]("9N97<@2&]R9&5?36]B:6QE
M7V)L;V-K*"1F;W)M16QE;65N="D["B`@("`@("`@("`@("1T:&ES+3Y?96QE
M;65N='-;72`]("8D8FQO8VL["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&5R<F]R(#T@4$5!4CHZ<F%I<V5%<G)O<B@G4W!E8VEF:65D(&5L96UE
M;G0@8V%N;F]T(&)E(&EN<VED92!A(&9O<FTN)RD["B`@("`@("`@("`@(')E
M='5R;B`D97)R;W(["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&9O<FU%
M;&5M96YT.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$1E9F%U;'1S*"D*("`@
M('L*("`@("`@("`D9&5F875L=',@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3Y?96QE;65N=',@87,@)'9A;"D@>PH@("`@("`@("`@("!S
M=VET8V@@*'-T<G1O;&]W97(H9V5T7V-L87-S*"1V86PI*2D@>PH@("`@("`@
M("`@("!C87-E("=H;W)D95]M;V)I;&5?:&ED9&5N)SH*("`@("`@("`@("`@
M("`@("1D969A=6QT<UM=(#T@87)R87DH)VYA;64G(#T^("1V86PM/F=E="@G
M;F%M92<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M=F%L=64G(#T^("1V86PM/F=E="@G=F%L=64G*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)VAI9&1E;B<@/3X@=')U92D["B`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)VAO<F1E7VUO
M8FEL95]B;&]C:R<Z"B`@("`@("`@("`@("`@("!F;W)E86-H("@D=F%L+3Y?
M96QE;65N=',@87,@)&)V86PI('L*("`@("`@("`@("`@("`@("`@("!S=VET
M8V@@*'-T<G1O;&]W97(H9V5T7V-L87-S*"1B=F%L*2DI('L*("`@("`@("`@
M("`@("`@("`@("!C87-E("=H;W)D95]M;V)I;&5?8VAE8VMB;W@G.@H@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H)&)V86PM/FES0VAE8VME9"@I*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5F875L='-;72`](&%R
M<F%Y*"=N86UE)R`]/B`D8G9A;"T^9V5T*"=N86UE)RDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=V86QU92<@
M/3X@)&)V86PM/F=E="@G=F%L=64G*2D["B`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("`@("`@("`@(&-A<V4@)VAO<F1E7VUO8FEL95]I;G!U="<Z"B`@("`@
M("`@("`@("`@("`@("`@8V%S92`G:&]R9&5?;6]B:6QE7W1E>'1A<F5A)SH*
M("`@("`@("`@("`@("`@("`@("!C87-E("=H;W)D95]M;V)I;&5?<V5L96-T
M)SH*("`@("`@("`@("`@("`@("`@("!C87-E("=H;W)D95]M;V)I;&5?<F%D
M:6\G.@H@("`@("`@("`@("`@("`@("`@("`@("`D9&5F875L='-;72`](&%R
M<F%Y*"=N86UE)R`]/B`D8G9A;"T^9V5T*"=N86UE)RDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W9A;'5E)R`]/B`D
M8G9A;"T^9V5T*"=V86QU92<I*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("`@("`@("`@(&-A<V4@)VAO<F1E7VUO8FEL
M95]H:61D96XG.@H@("`@("`@("`@("`@("`@("`@("`@("`D9&5F875L='-;
M72`](&%R<F%Y*"=N86UE)R`]/B`D8G9A;"T^9V5T*"=N86UE)RDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W9A;'5E
M)R`]/B`D8G9A;"T^9V5T*"=V86QU92<I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=H:61D96XG(#T^('1R=64I.PH@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@
M("`@("`@8V%S92`G:&]R9&5?;6]B:6QE7W1A8FQE)SH*("`@("`@("`@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)&)V86PM/E]R;W=S(&%S("1R;W<I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1R;W<M/E]C
M;VQU;6YS(&%S("1C;VPI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!S=VET8V@@*'-T<G1O;&]W97(H9V5T7V-L87-S*"1C;VPI*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)VAO<F1E7VUO
M8FEL95]C:&5C:V)O>"<Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@D8V]L+3YI<T-H96-K960H*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E9F%U;'1S6UT@/2!A<G)A
M>2@G;F%M92<@/3X@)&)V86PM/F=E="@G;F%M92<I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G=F%L=64G(#T^("1B=F%L+3YG970H)W9A;'5E)RDI.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!C87-E("=H;W)D95]M;V)I;&5?:6YP=70G.@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)VAO<F1E7VUO8FEL
M95]T97AT87)E82<Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M8V%S92`G:&]R9&5?;6]B:6QE7W-E;&5C="<Z"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8V%S92`G:&]R9&5?;6]B:6QE7W)A9&EO)SH*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E9F%U;'1S6UT@
M/2!A<G)A>2@G;F%M92<@/3X@)&)V86PM/F=E="@G;F%M92<I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=V86QU92<@/3X@)&)V86PM/F=E="@G=F%L=64G*2D["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!C87-E("=H;W)D95]M;V)I;&5?:&ED
M9&5N)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E
M9F%U;'1S6UT@/2!A<G)A>2@G;F%M92<@/3X@)&)V86PM/F=E="@G;F%M92<I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=V86QU92<@/3X@)&)V86PM/F=E="@G=F%L=64G*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G:&ED9&5N)R`]/B!T<G5E*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&1E9F%U;'1S.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&=E=$=E=%9A<G,H*0H@("`@>PH@("`@("`@("\O($1E
M=&5R;6EN92!A;&P@96QE;65N=',@=&AA="!H879E('1O(&)E('-U8FUI='1E
M9"X*("`@("`@("`D9V5T=F%R<R`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C
M:"`H)'1H:7,M/E]E;&5M96YT<R!A<R`D=F%L*2!["B`@("`@("`@("`@('-W
M:71C:"`H<W1R=&]L;W=E<BAG971?8VQA<W,H)'9A;"DI*2!["B`@("`@("`@
M("`@(&-A<V4@)VAO<F1E7VUO8FEL95]B;&]C:R<Z"B`@("`@("`@("`@("`@
M("!F;W)E86-H("@D=F%L+3Y?96QE;65N=',@87,@)&)V86PI('L*("`@("`@
M("`@("`@("`@("`@("!S=VET8V@@*'-T<G1O;&]W97(H9V5T7V-L87-S*"1B
M=F%L*2DI('L*("`@("`@("`@("`@("`@("`@("!C87-E("=H;W)D95]M;V)I
M;&5?:6YP=70G.@H@("`@("`@("`@("`@("`@("`@(&-A<V4@)VAO<F1E7VUO
M8FEL95]H:61D96XG.@H@("`@("`@("`@("`@("`@("`@(&-A<V4@)VAO<F1E
M7VUO8FEL95]T97AT87)E82<Z"B`@("`@("`@("`@("`@("`@("`@8V%S92`G
M:&]R9&5?;6]B:6QE7W-E;&5C="<Z"B`@("`@("`@("`@("`@("`@("`@8V%S
M92`G:&]R9&5?;6]B:6QE7V-H96-K8F]X)SH*("`@("`@("`@("`@("`@("`@
M("!C87-E("=H;W)D95]M;V)I;&5?<F%D:6\G.@H@("`@("`@("`@("`@("`@
M("`@("`@("`D9V5T=F%R<UM=(#T@)&)V86PM/F=E="@G;F%M92<I.PH@("`@
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("`@
M("`@8V%S92`G:&]R9&5?;6]B:6QE7W1A8FQE)SH*("`@("`@("`@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)&)V86PM/E]R;W=S(&%S("1R;W<I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1R;W<M/E]C;VQU
M;6YS(&%S("1C;VPI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!S=VET8V@@*'-T<G1O;&]W97(H9V5T7V-L87-S*"1C;VPI*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)VAO<F1E7VUO8FEL
M95]I;G!U="<Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V%S
M92`G:&]R9&5?;6]B:6QE7VAI9&1E;B<Z"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8V%S92`G:&]R9&5?;6]B:6QE7W1E>'1A<F5A)SH*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C87-E("=H;W)D95]M;V)I
M;&5?<V5L96-T)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C
M87-E("=H;W)D95]M;V)I;&5?8VAE8VMB;W@G.@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&-A<V4@)VAO<F1E7VUO8FEL95]R861I;R<Z"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1G971V87)S6UT@
M/2`D8V]L+3YG970H)VYA;64G*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&=E='9A<G,["B`@("!]"@I]"@HO*BH*("H@
M5&AI<R!C;&%S<R!H;VQD<R!T97AT+6QE=F5L(&5L96UE;G1S(&9O<B!U<V4@
M:6X@2&]R9&5?36]B:6QE(&]R"B`J($AO<F1E7TUO8FEL95]F;W)M(&]B:F5C
M=',N"B`J"B`J($5X86UP;&5S.@H@*@H@*B`D8FQO8VL@/2!N97<@2&]R9&5?
M36]B:6QE7V)L;V-K*")(96QL;R!705`A(BD["B`J("1T97AT(#T@;F5W($AO
M<F1E7TUO8FEL95]T97AT*")796QC;VUE('1O($AO<F1E7TUO8FEL92(L("=B
M)RD["B`J("1B;&]C:RT^861D*"1T97AT*3L*("H*("H@0'-E92!(;W)D95]-
M;V)I;&4*("H@0'-E92!(;W)D95]-;V)I;&5?9F]R;0H@*@H@*B!`<&%C:V%G
M92!(;W)D95]-;V)I;&4*("HO"F-L87-S($AO<F1E7TUO8FEL95]B;&]C:R!E
M>'1E;F1S($AO<F1E7TUO8FEL95]E;&5M96YT('L*"B`@("!V87(@)%]E;&5M
M96YT<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*
M("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&5L96UE;G1S("!!;GD@96QE
M;65N=',@*&$@<VEN9VQE(&]N92!O<B!A;B!A<G)A>2D@=&\@9FEL;"!T:&ES
M(&)L;V-K('=I=&@N"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7TUO8FEL
M95]B;&]C:R@F)&5L96UE;G1S*0H@("`@>PH@("`@("`@(&EF("@A:7-?;G5L
M;"@D96QE;65N=',I*2!["B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)&5L
M96UE;G1S*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/F%D9"@D96QE;65N
M=',I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@9F]R
M96%C:"`H)&5L96UE;G1S(&%S("1E;&5M96YT*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/F%D9"@D96QE;65N="D["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@
M)F%D9"@F)&5L96UE;G0I"B`@("!["B`@("`@("`@:68@*"%I<U]A*"1E;&5M
M96YT+"`G2&]R9&5?36]B:6QE7V5L96UE;G0G*2D@>PH@("`@("`@("`@("`D
M97)R;W(@/2!014%2.CIR86ES945R<F]R*"=);G9A;&ED(&5L96UE;G0N)RD[
M"B`@("`@("`@?2!E;'-E:68@*&ES7V$H)&5L96UE;G0L("=(;W)D95]-;V)I
M;&5?=&5X="<I('Q\"B`@("`@("`@("`@("`@("`@(&ES7V$H)&5L96UE;G0L
M("=(;W)D95]-;V)I;&5?=&%B;&4G*2!\?`H@("`@("`@("`@("`@("`@("!I
M<U]A*"1E;&5M96YT+"`G2&]R9&5?36]B:6QE7VEM86=E)RD@?'P*("`@("`@
M("`@("`@("`@("`@:7-?82@D96QE;65N="P@)TAO<F1E7TUO8FEL95]F;W)M
M16QE;65N="<I('Q\"B`@("`@("`@("`@("`@("`@(&ES7V$H)&5L96UE;G0L
M("=(;W)D95]-;V)I;&5?;&EN:R<I('Q\"B`@("`@("`@("`@("`@("`@(&ES
M7V$H)&5L96UE;G0L("=(;W)D95]-;V)I;&5?;&EN:W-E="<I('Q\"B`@("`@
M("`@("`@("`@("`@(&ES7V$H)&5L96UE;G0L("=(;W)D95]-;V)I;&5?<&AO
M;F4G*2!\?`H@("`@("`@("`@("`@("`@("!I<U]A*"1E;&5M96YT+"`G2&]R
M9&5?36]B:6QE7W)U;&4G*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V5L96UE
M;G1S6UT@/2`F)&5L96UE;G0["B`@("`@("`@("`@(')E='5R;B`D96QE;65N
M=#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D97)R;W(@/2!014%2
M.CIR86ES945R<F]R*"=4:&4@96QE;65N="!I<R!N;W0@86QL;W=E9"!I;G-I
M9&4@82!B;&]C:RXG*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1E<G)O
M<CL*("`@('T*"GT*"B\J*@H@*B!4:&ES(&-L87-S(&EN<V5R=',@<&QA:6X@
M=&5X="!I;G1O(&$@2&]R9&5?36]B:6QE7V)L;V-K(&]R(&$*("H@2&]R9&5?
M36]B:6QE7W)O=R!O8FIE8W0N"B`J"B`J($5X86UP;&5S.@H@*@H@*B`D;7E4
M97AT,2`](&YE=R!(;W)D95]-;V)I;&5?=&5X="@B2&5L;&\@5T%0(2(I.PH@
M*B`D;7E497AT,B`](&YE=R!(;W)D95]-;V)I;&5?=&5X="@B5V5L8V]M92!T
M;R!(;W)D95]-;V)I;&4B+"`G8B<I.PH@*B`D;7E497AT,R`](&YE=R!(;W)D
M95]-;V)I;&5?=&5X="@B1V]O9"!-;W)N:6YG(BP@87)R87DH)V(G+"`G8FEG
M)RDI.PH@*@H@*B!`<V5E($AO<F1E7TUO8FEL95]B;&]C:PH@*B!`<V5E($AO
M<F1E7TUO8FEL95]R;W<*("H*("H@0'!A8VMA9V4@2&]R9&5?36]B:6QE"B`J
M+PIC;&%S<R!(;W)D95]-;V)I;&5?=&5X="!E>'1E;F1S($AO<F1E7TUO8FEL
M95]E;&5M96YT('L*"B`@("!V87(@)%]T97AT(#T@)R<["B`@("!V87(@)%]A
M='1R:6)U=&5S(#T@87)R87DH*3L*("`@('9A<B`D7VQI;F5B<F5A:W,@/2!F
M86QS93L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1T97AT("`@("`@(%1H92!T97AT(&-O;G1E;G0@;V8@=&AE
M(&5L96UE;G0N"B`@("`@*B!`<&%R86T@87)R87D@)&%T=')I8G5T97,@(%1E
M>'0@871T<FEB=71E<RX@06YY(&]F.@H@("`@("H@("`G8B<*("`@("`J("`@
M)W4G"B`@("`@*B`@("=I)PH@("`@("H@("`G8FEG)PH@("`@("H@("`G<VUA
M;&PG"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7TUO8FEL95]T97AT*"1T
M97AT+"`D871T<FEB=71E<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H
M:7,M/E]T97AT(#T@)'1E>'0["B`@("`@("`@:68@*"%I<U]A<G)A>2@D871T
M<FEB=71E<RDI('L*("`@("`@("`@("`@)&%T=')I8G5T97,@/2!A<G)A>2@D
M871T<FEB=71E<RD["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?871T<FEB
M=71E<R`]("1A='1R:6)U=&5S.PH@("`@?0H*?0H*+RHJ"B`J(%1H:7,@8VQA
M<W,@86QL;W=S('1O(&EN<V5R="!B:71M87`@:6UA9V5S(&EN=&\@82!(;W)D
M95]-;V)I;&5?8FQO8VLL"B`J($AO<F1E7TUO8FEL95]F;W)M(&]R($AO<F1E
M7TUO8FEL95]R;W<@;V)J96-T+@H@*@H@*B!%>&%M<&QE<SH*("H*("H@)&EM
M86=E(#T@;F5W($AO<F1E7TUO8FEL95]I;6%G92@G+W!A=&@O=&\O:6UA9V4N
M=V)M<"<L"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)VAE:6=H="<@/3X@,3`P+"`G=VED=&@G(#T^(#$P,"DI.PH@*@H@*B!`
M<V5E($AO<F1E7TUO8FEL95]B;&]C:PH@*B!`<V5E($AO<F1E7TUO8FEL95]F
M;W)M"B`J($!S964@2&]R9&5?36]B:6QE7W)O=PH@*@H@*B!`<&%C:V%G92!(
M;W)D95]-;V)I;&4*("HO"F-L87-S($AO<F1E7TUO8FEL95]I;6%G92!E>'1E
M;F1S($AO<F1E7TUO8FEL95]E;&5M96YT('L*"B`@("!V87(@)%]S<F,@/2`G
M)SL*("`@('9A<B`D7V%T=')I8G5T97,@/2!A<G)A>2@I.PH*("`@("\J*@H@
M("`@("H@0V]N<W1R=6-T;W(*("`@("`J($!P87)A;2!S=')I;F<@)'-R8R`@
M("`@("`@5&AE('-O=7)C92!L;V-A=&EO;B!O9B!T:&4@:6UA9V4N"B`@("`@
M*B!`<&%R86T@87)R87D@)&%T=')I8G5T97,@($EM86=E(&%T=')I8G5T97,N
M($%N>2!O9CH*("`@("`J("`@)V%L:6=N)PH@("`@("H@("`G86QT)PH@("`@
M("H@("`G:&5I9VAT)PH@("`@("H@("`G:'-P86-E)PH@("`@("H@("`G=G-P
M86-E)PH@("`@("H@("`G=VED=&@G"B`@("`@*B`@("=C;&%S<R<*("`@("`J
M("`@)VED)PH@("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]-;V)I;&5?:6UA
M9V4H)'-R8RP@)&%T=')I8G5T97,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?<W)C(#T@)'-R8SL*("`@("`@("`D=&AI<RT^7V%T=')I8G5T
M97,@/2`D871T<FEB=71E<SL*("`@('T*"GT*"B\J*@H@*B!4:&ES(&-L87-S
M(&%L;&]W<R!T;R!I;G-E<G0@=&%B;&5S(&EN=&\@82!(;W)D95]-;V)I;&4@
M;W(*("H@2&]R9&5?36]B:6QE7V9O<FT@;V)J96-T+@H@*@H@*B!%>&%M<&QE
M<SH*("H*("H@)&UY5&%B;&4@/2!N97<@2&]R9&5?36]B:6QE7W1A8FQE*"D[
M"B`J"B`J("1R;W<Q(#T@;F5W($AO<F1E7TUO8FEL95]R;W<H*3L*("H@)')O
M=S$M/F%D9"@D:6UA9V4Q*3L*("H@)')O=S$M/F%D9"@D=&5X=#$I.PH@*B`D
M;7E486)L92T^861D*"1R;W<Q*3L*("H*("H@)')O=S(@/2!N97<@2&]R9&5?
M36]B:6QE7W)O=R@I.PH@*B`D<F]W,BT^861D*"1I;6%G93(I.PH@*B`D<F]W
M,BT^861D*"1T97AT,BD["B`J("1M>51A8FQE+3YA9&0H)')O=S(I.PH@*@H@
M*B`D;7E$96-K+3YA9&0H)&UY5&%B;&4I.PH@*@H@*B!`<V5E($AO<F1E7TUO
M8FEL90H@*B!`<V5E($AO<F1E7TUO8FEL95]F;W)M"B`J($!S964@2&]R9&5?
M36]B:6QE7W)O=PH@*@H@*B!`<&%C:V%G92!(;W)D95]-;V)I;&4*("HO"F-L
M87-S($AO<F1E7TUO8FEL95]T86)L92!E>'1E;F1S($AO<F1E7TUO8FEL95]E
M;&5M96YT('L*"B`@("!V87(@)%]R;W=S(#T@87)R87DH*3L*("`@('9A<B`D
M7V)O<F1E<B`](&YU;&P["B`@("!V87(@)%]P861D:6YG(#T@;G5L;#L*("`@
M('9A<B`D7W-P86-I;F<@/2!N=6QL.PH*("`@("\J*@H@("`@("H@061D<R!A
M($AO<F1E7TUO8FEL95]R;W<@;V)J96-T('1O($AO<F1E7TUO8FEL95]T86)L
M92X*("`@("`J"B`@("`@*B!`<&%R86T@2&]R9&5?36]B:6QE7W)O=R`D<F]W
M("!4:&4@<F]W(&]B:F5C="!T;R!A9&0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9A9&0H)B1R;W<I"B`@("!["B`@("`@("`@:68@*"%I<U]A*"1R;W<L("=(
M;W)D95]-;V)I;&5?<F]W)RDI('L*("`@("`@("`@("`@)&5R<F]R(#T@4$5!
M4CHZ<F%I<V5%<G)O<B@G4F]W<R!M=7-T(&)E($AO<F1E7TUO8FEL95]R;W<@
M;V)J96-T<RXG*3L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@
M("!]"@H@("`@("`@("1T:&ES+3Y?<F]W<UM=(#T@)B1R;W<["B`@("`@("`@
M<F5T=7)N("1R;W<["B`@("!]"@I]"@HO*BH*("H@5&AI<R!C;&%S<R!D969I
M;F5S('1H92!R;W=S('1H870@82!(;W)D95]-;V)I;&5?=&%B;&4@;V)J96-T
M"B`J(&-O;G-I<W1S(&]F+@H@*@H@*B!%>&%M<&QE<SH*("H*("H@)&EM86=E
M,2`](&YE=R!(;W)D95]-;V)I;&5?:6UA9V4H(FUY7VEM86=E+G=B;7`B+"`B
M;7E?:6UA9V4N<&YG(BP@(CHM*2(I.PH@*B`D=&5X=#$@/2!N97<@2&]R9&5?
M36]B:6QE7W1E>'0H(FUY('1E>'0B*3L*("H@)')O=S$@/2!N97<@2&]R9&5?
M36]B:6QE7W)O=R@I.PH@*B`D<F]W,2T^861D*"1I;6%G93$I.PH@*B`D<F]W
M,2T^861D*"D["B`J("1R;W<Q+3YA9&0H)'1E>'0Q*3L*("H*("H@0'-E92!(
M;W)D95]-;V)I;&5?=&%B;&4*("H@0'-E92!(;W)D95]-;V)I;&5?=&5X=`H@
M*B!`<V5E($AO<F1E7TUO8FEL95]I;6%G90H@*B!`<V5E($AO<F1E7TUO8FEL
M95]L:6YK"B`J"B`J($!P86-K86=E($AO<F1E7TUO8FEL90H@*B\*8VQA<W,@
M2&]R9&5?36]B:6QE7W)O=R!E>'1E;F1S($AO<F1E7TUO8FEL95]E;&5M96YT
M('L*"B`@("!V87(@)%]C;VQU;6YS(#T@87)R87DH*3L*"B`@("`O*BH*("`@
M("`J($%D9',@82!C;VQU;6X@96QE;65N="!T;R!A($AO<F1E7TUO8FEL95]R
M;W<@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!(;W)D95]-;V)I;&5?
M96QE;65N="`D8V5L;$5L96UE;G0@($-A;B!B92!A($AO<F1E7TUO8FEL95]T
M97AT"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!O8FIE8W0L(&$@2&]R9&5?36]B:6QE7VEM86=E"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!O8FIE
M8W0L(&$@2&]R9&5?36]B:6QE7VQI;FL*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&]B:F5C="!O<B!N=6QL+B!4
M:&4@;&%T=&5R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!R97-U;'1S(&EN(&%N(&5M<'1Y(&-E;&PN"B`@("`@
M*B\*("`@(&9U;F-T:6]N("9A9&0H)&-E;&Q%;&5M96YT(#T@;G5L;"D*("`@
M('L*("`@("`@("!I9B`H:7-?;V)J96-T*"1C96QL16QE;65N="DI('L*("`@
M("`@("`@("`@:68@*"%I<U]A*"1C96QL16QE;65N="P@)TAO<F1E7TUO8FEL
M95]T97AT)RD@)B8*("`@("`@("`@("`@("`@("%I<U]A*"1C96QL16QE;65N
M="P@)TAO<F1E7TUO8FEL95]L:6YK)RD@)B8*("`@("`@("`@("`@("`@("%I
M<U]A*"1C96QL16QE;65N="P@)TAO<F1E7TUO8FEL95]I;6%G92<I*2!["B`@
M("`@("`@("`@("`@("`D97)R;W(@/2!014%2.CIR86ES945R<F]R*"=486)L
M92!C96QL<R!C86X@;VYL>2!C;VYT86EN('1E>'0L(&QI;FMS+"!O<B!I;6%G
M97,N)RD["B`@("`@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?8V]L=6UN<UM=(#T@)B1C96QL
M16QE;65N=#L*("`@("`@("`@("`@<F5T=7)N("1C96QL16QE;65N=#L*("`@
M("`@("!](&5L<V5I9B`H(6ES7VYU;&PH)&-E;&Q%;&5M96YT*2D@>PH@("`@
M("`@("`@("`D="`]("9N97<@2&]R9&5?36]B:6QE7W1E>'0H)&-E;&Q%;&5M
M96YT*3L*("`@("`@("`@("`@)'1H:7,M/E]C;VQU;6YS6UT@/2`F)'0["B`@
M("`@("`@("`@(')E='5R;B`D=#L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D=&AI<RT^7V-O;'5M;G-;72`]("8D8V5L;$5L96UE;G0["B`@("`@
M("`@("`@(')E='5R;B`D8V5L;$5L96UE;G0["B`@("`@("`@?0H@("`@?0H*
M("`@(&9U;F-T:6]N(&=E=$-O;'5M;D-O=6YT*"D*("`@('L*("`@("`@("!R
M971U<FX@8V]U;G0H)'1H:7,M/E]C;VQU;6YS*3L*("`@('T*"GT*"B\J*@H@
M*B!4:&ES(&-L87-S('!R;W9I9&5S(&$@=&5X="!I;G!U="!F:65L9"!I;B!A
M($AO<F1E7TUO8FEL95]F;W)M(&]B:F5C="X*("H*("H@17AA;7!L97,Z"B`J
M"B`J("1M>4EN<'5T,2`](&YE=R!(;W)D95]-;V)I;&5?:6YP=70H)V-I9"<L
M("<G+"`G0W5S=&]M97(@240G*3L*("H*("H@)&UY26YP=70R(#T@;F5W($AO
M<F1E7TUO8FEL95]I;G!U="@G8VED)RP@)R<L("=#=7-T;VUE<B!)1"<L("<J
M3B<I.PH@*B`D;7E);G!U=#(M/G-E=%]S:7IE*#8I.PH@*B`D;7E);G!U=#(M
M/G-E=%]M87AL96YG=&@H-BD["B`J"B`J("1M>4EN<'5T,R`](&YE=R!(;W)D
M95]-;V)I;&5?:6YP=70H)W!W)RP@)R<L("=087-S=V]R9"<L("<J3B<I.PH@
M*B`D;7E);G!U=#,M/G-E=%]S:7IE*#@I.PH@*B`D;7E);G!U=#,M/G-E=%]M
M87AL96YG=&@H."D["B`J("1M>4EN<'5T,RT^<V5T7W1Y<&4H)W!A<W-W;W)D
M)RD["B`J"B`J($!S964@2&]R9&5?36]B:6QE7V9O<FT*("H*("H@0'!A8VMA
M9V4@2&]R9&5?36]B:6QE"B`J+PIC;&%S<R!(;W)D95]-;V)I;&5?:6YP=70@
M97AT96YD<R!(;W)D95]-;V)I;&5?9F]R;45L96UE;G0@>PH*("`@("\J*@H@
M("`@("H@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N86UE("`@(%9A<FEA8FQE(&EN('=H:6-H('1H92!I;G!U="!I<R!S96YT
M('1O('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!D97-T:6YA
M=&EO;B!54DPN"B`@("`@*B!`<&%R86T@<W1R:6YG("1V86QU92`@($EN:71I
M86P@=F%L=64@=&AA="!W:6QL(&)E('!R97-E;G1E9"!I;B!T:&4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@:6YP=70@9FEE;&0N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1L86)E;"`@($1E<V-R:6)E<R!Y;W5R(&EN<'5T(&9I
M96QD(&]N('1H92!S=7)F97(G<PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("!S8W)E96XO9&ES<&QA>2X*("`@("`J($!P87)A;2!S=')I;F<@)&9O
M<FUA="`@26YP=70@9F]R;6%T(&-O9&4@86-C;W)D:6YG('1O('1H92!705`@
M<W1A;F1A<F0N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@($%L;&]W
M<R!T:&4@5T%0('5S97(@8VQI96YT(&4N9RX@=&\@:6YP=70@;VYL>0H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("!D:6=I=',@86YD(&YO(&-H87)A
M8W1E<G,N($]N(&%N($A434P@9V5N97)A=&5D"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@('!A9V4@=&AI<R!F;W)M870@:&%S(&YO('-I9VYI9FEC
M86YC92X*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?36]B:6QE7VEN<'5T
M*"1N86UE+"`D=F%L=64L("1L86)E;"`]("<G+"`D9F]R;6%T(#T@)RI-)RD*
M("`@('L*("`@("`@("`D=&AI<RT^7VYA;64@/2`D;F%M93L*("`@("`@("`D
M=&AI<RT^7W9A;'5E(#T@)'9A;'5E.PH@("`@("`@("1T:&ES+3Y?;&%B96P@
M/2`D;&%B96P["B`@("`@("`@)'1H:7,M/E]F;W)M870@/2`D9F]R;6%T.PH@
M("`@("`@("1T:&ES+3Y?='EP92`]("=T97AT)SL*("`@("`@("`D=&AI<RT^
M7VUO9&4@/2`G86QP:&$G.PH@("`@?0H*?0H*+RHJ"B`J(%1H:7,@8VQA<W,@
M<')O=FED97,@86X@:6YP=70@=&5X=&%R96$@:6X@82!(;W)D95]-;V)I;&5?
M9F]R;2!O8FIE8W0N"B`J"B`J($5X86UP;&5S.@H@*@H@*B`D;7E!<F5A,2`]
M(&YE=R!(;W)D95]-;V)I;&5?=&5X=&%R96$H)V9B)RP@)R<L("=&965D8F%C
M:R<I.PH@*B`D;7E!<F5A,B`](&YE=R!(;W)D95]-;V)I;&5?=&5X=&%R96$H
M)VUS9R<L("=%;G1E<B!M97-S86=E(&AE<F4@+BXN)RP@)TUE<W-A9V4G+"`T
M,"P@-2D["B`J"B`J($!S964@2&]R9&5?36]B:6QE7V9O<FT*("H*("H@0'!A
M8VMA9V4@2&]R9&5?36]B:6QE"B`J+PIC;&%S<R!(;W)D95]-;V)I;&5?=&5X
M=&%R96$@97AT96YD<R!(;W)D95]-;V)I;&5?9F]R;45L96UE;G0@>PH*("`@
M('9A<B`D7W)O=W,["B`@("!V87(@)%]C;VQS.PH*("`@("\J*@H@("`@("H@
M0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M
M92`@(%9A<FEA8FQE(&EN('=H:6-H('1H92!I;G!U="!I<R!S96YT('1O('1H
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&1E<W1I;F%T:6]N(%52
M3"X*("`@("`J($!P87)A;2!S=')I;F<@)'9A;'5E("!);FET:6%L('9A;'5E
M('1H870@=VEL;"!B92!P<F5S96YT960@:6X@=&AE"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@=&5X=&%R96$N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1L86)E;"`@1&5S8W)I8F5S('EO=7(@=&5X=&%R96$@;VX@=&AE('-U<F9E
M<B=S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<V-R965N+V1I<W!L
M87DN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W<R`@4F]W<RX*("`@("`J
M($!P87)A;2!I;G1E9V5R("1C;VQS("!#;VQU;6YS+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!(;W)D95]-;V)I;&5?=&5X=&%R96$H)&YA;64L("1V86QU92P@
M)&QA8F5L+"`D<F]W<R`](#,L("1C;VQS(#T@,38I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]N86UE(#T@)&YA;64["B`@("`@("`@)'1H:7,M/E]V86QU92`]
M("1V86QU93L*("`@("`@("`D=&AI<RT^7VQA8F5L(#T@)&QA8F5L.PH@("`@
M("`@("1T:&ES+3Y?<F]W<R`]("1R;W=S.PH@("`@("`@("1T:&ES+3Y?8V]L
M<R`]("1C;VQS.PH@("`@("`@("1T:&ES+3Y?;6]D92`]("=A;'!H82<["B`@
M("!]"@I]"@HO*BH*("H@5&AI<R!C;&%S<R!P<F]V:61E<R!A('-E;&5C="!E
M;&5M96YT(&EN(&$@2&]R9&5?36]B:6QE7V9O<FT@;V)J96-T+@H@*B!)="!A
M;&QO=W,@=&\@8W)E871E(&]P=&EM:7IE9"!734P@9F]R(%=!4"!D979I8V5S
M('=H:6-H(&%R92!C87!A8FQE"B`J('1O(&EN=&5R<')E=&4@=&AE($]P96YW
M879E($=522!E>'1E;G-I;VYS(&9O<B!734P@,2XS+B!!;&P@;W1H97(*("H@
M5TU,(&1E=FEC97,@<F5C96EV92!734P@,2XQ(&-O;7!A=&EB;&4@;6%R:W5P
M(&-O9&4L('=H:6-H(&ES('%U:71E"B`J('-I;6EL87(@=&\@=&AE(&UA<FMU
M<"!C;V1E(&-R96%T960@8GD@=&AE($AO<F1E7TUO8FEL95]R861I;R!C;&%S
M<RX*("H*("H@17AA;7!L97,Z"B`J"B`J("1M>5-E;&5C="`](&YE=R!(;W)D
M95]-;V)I;&5?<V5L96-T*"=C;VQO<B<I.PH@*B`D;7E396QE8W0M/F%D9"@G
M0FQU92<L("=B)RD["B`J("1M>5-E;&5C="T^861D*"=2960G+"`G<B<L('1R
M=64I.PH@*B`D;7E396QE8W0M/F%D9"@G665L;&]W)RP@)WDG*3L*("H*("H@
M0'-E92!(;W)D95]-;V)I;&5?9F]R;0H@*@H@*B!`<&%C:V%G92!(;W)D95]-
M;V)I;&4*("HO"F-L87-S($AO<F1E7TUO8FEL95]S96QE8W0@97AT96YD<R!(
M;W)D95]-;V)I;&5?9F]R;45L96UE;G0@>PH*("`@('9A<B`D7W1Y<&4["B`@
M("!V87(@)%]O<'1I;VYS(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($-O
M;G-T<G5C=&]R"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@
M5F%R:6%B;&4@:6X@=VAI8V@@=&AE(&EN9F]R;6%T:6]N(&%B;W5T('1H90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@<V5L96-T960@;W!T:6]N(&ES
M('-E;G0@=&\@=&AE(&1E<W1I;F%T:6]N(%523"X*("`@("`J($!P87)A;2!S
M=')I;F<@)'1Y<&4@(%1Y<&4@;V8@<V5L96-T(&%R96$Z"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`G<&]P=7`G.B!P;W!U<"!T:&4@=VAO;&4@<V5L
M96-T:6]N(&QI<W0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("=S<&EN
M)SH@(')O=&%T92!O<'1I;VYS(&]N(&$@5T%0(&1E=FEC92!S8W)E96X@*$]7
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Q+C,@1U5)
M(&]N;'DI+@H@("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]-;V)I;&5?<V5L
M96-T*"1N86UE+"`D='EP92`]("=P;W!U<"<I"B`@("!["B`@("`@("`@)'1H
M:7,M/E]N86UE(#T@)&YA;64["B`@("`@("`@)'1H:7,M/E]T>7!E(#T@)'1Y
M<&4["B`@("`@("`@)'1H:7,M/E]V86QU92`](&YU;&P["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!9&1S(&]N92!O<'1I;VX@=&\@82!(;W)D95]-;V)I;&5?
M<V5L96-T(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1L
M86)E;"`@("`@("`@($1E<V-R:6)E<R!T:&4@;W!T:6]N(&]N('1H92!S=7)F
M97(G<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S8W)E
M96XO9&ES<&QA>2X*("`@("`J($!P87)A;2!S=')I;F<@)'9A;'5E("`@("`@
M("`@5F%L=64@<V5N="!I;B!T:&4@(FYA;64B('9A<FEA8FQE+"!I9B!T:&ES
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&ES('1H92!O
M<'1I;VX@<V5L96-T960N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D:7-?<V5L
M96-T960@($%L;&]W960@=F%L=65S(&%R92!T<G5E(&]R(&9A;'-E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!A9&0H)&QA8F5L+"`D=F%L=64L("1I<U]S96QE
M8W1E9"`](&9A;'-E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;W!T:6]N<UM=
M(#T@87)R87DH)VQA8F5L)R`]/B`D;&%B96PL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G=F%L=64G(#T^("1V86QU92D["@H@("`@("`@
M(&EF("AI<U]N=6QL*"1T:&ES+3Y?=F%L=64I('Q\("1I<U]S96QE8W1E9"D@
M>PH@("`@("`@("`@("`D=&AI<RT^7W9A;'5E(#T@)'9A;'5E.PH@("`@("`@
M('T*("`@('T*"GT*"B\J*@H@*B!4:&ES(&-L87-S('!R;W9I9&5S(&$@<F%D
M:6\@8G5T=&]N(&5L96UE;G0@:6X@82!(;W)D95]-;V)I;&5?9F]R;2!O8FIE
M8W0N"B`J"B`J($5X86UP;&5S.@H@*@H@*B`D;7E2861I;R`](&YE=R!(;W)D
M95]-;V)I;&5?<F%D:6\H)V-O=6YT<GDG*3L*("H@)&UY4F%D:6\M/F%D9"@G
M1FEN;&%N9"<L("=&)RD["B`J("1M>5)A9&EO+3YA9&0H)T=E<FUA;GDG+"`G
M1R<L('1R=64I.PH@*B`D;7E2861I;RT^861D*"=3=V5D96XG+"`G4R<I.PH@
M*@H@*B!`<V5E($AO<F1E7TUO8FEL95]F;W)M"B`J"B`J($!P86-K86=E($AO
M<F1E7TUO8FEL90H@*B\*8VQA<W,@2&]R9&5?36]B:6QE7W)A9&EO(&5X=&5N
M9',@2&]R9&5?36]B:6QE7V9O<FU%;&5M96YT('L*"B`@("!V87(@)%]B=71T
M;VYS(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5F%R:6%B;&4@:6X@
M=VAI8V@@=&AE(&EN9F]R;6%T:6]N(&%B;W5T('1H92!P<F5S<V5D(&)U='1O
M;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@:7,@<V5N="!T;R!T:&4@
M9&5S=&EN871I;VX@55),+@H@("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]-
M;V)I;&5?<F%D:6\H)&YA;64I"B`@("!["B`@("`@("`@)'1H:7,M/E]N86UE
M(#T@)&YA;64["B`@("`@("`@)'1H:7,M/E]V86QU92`](&YU;&P["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!9&1S(&]N92!R861I;R!B=71T;VX@=&\@82!(
M;W)D95]-;V)I;&5?<F%D:6\@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&QA8F5L("`@("`@("!$97-C<FEB97,@=&AE(')A9&EO8G5T
M=&]N(&]N('1H92!S=7)F97(G<PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('-C<F5E;B]D:7-P;&%Y+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=F%L=64@("`@("`@(%9A;'5E('-E;G0@:6X@=&AE(")N86UE(B!V87)I
M86)L92P@:68@=&AI<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&)U='1O;B!I<R!S96QE8W1E9"X*("`@("`J($!P87)A;2!B;V]L96%N
M("1I<U]C:&5C:V5D("!!;&QO=V5D('9A;'5E<R!A<F4@=')U92!O<B!F86QS
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@861D*"1L86)E;"P@)'9A;'5E+"`D
M:7-?8VAE8VME9"`](&9A;'-E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8G5T
M=&]N<UM=(#T@87)R87DH)VQA8F5L)R`]/B`D;&%B96PL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G=F%L=64G(#T^("1V86QU92D["@H@
M("`@("`@(&EF("@A)'1H:7,M/E]V86QU92!\?"`H)&ES7V-H96-K960I*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?=F%L=64@/2`D=F%L=64["B`@("`@("`@
M?0H@("`@?0H*?0H*+RHJ"B`J(%1H:7,@8VQA<W,@<')O=FED97,@82!S:6YG
M;&4@8VAE8VMB;W@@96QE;65N="!I;B!A($AO<F1E7TUO8FEL95]F;W)M(&]B
M:F5C="X*("H*("H@17AA;7!L97,Z"B`J"B`J("1M>4-H96-K8F]X(#T@;F5W
M($AO<F1E7TUO8FEL95]C:&5C:V)O>"@G86=M="<L("=Y97,G+"`G22!A9W)E
M92<I.PH@*B`D;7E#:&5C:V)O>"`](&YE=R!(;W)D95]-;V)I;&5?8VAE8VMB
M;W@H)V%G;70G+"`G>65S)RP@)TD@86=R964G+"!F86QS92D["B`J("1M>4-H
M96-K8F]X(#T@;F5W($AO<F1E7TUO8FEL95]C:&5C:V)O>"@G86=M="<L("=Y
M97,G+"`G22!A9W)E92<L('1R=64I.PH@*@H@*B!`;F]T92!4:&4@9FER<W0@
M86YD('-E8V]N9"!E>&%M<&QE<R!A<F4@:61E;G1I8V%L+@H@*@H@*B!`<V5E
M($AO<F1E7TUO8FEL95]F;W)M"B`J"B`J($!P86-K86=E($AO<F1E7TUO8FEL
M90H@*B\*8VQA<W,@2&]R9&5?36]B:6QE7V-H96-K8F]X(&5X=&5N9',@2&]R
M9&5?36]B:6QE7V9O<FU%;&5M96YT('L*"B`@("!V87(@)%]C:&5C:V5D.PH*
M("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1N86UE("`@("`@5F%R:6%B;&4@:6X@=VAI8V@@(G9A;'5E
M(B!I<R!S96YT('1O('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@(&1E<W1I;F%T:6]N(%523"P@:68@=&AE(&)O>"!I<R!C:&5C:V5D+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=F%L=64@("`@(%-E92!N86UE+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;&%B96P@("`@($1E<V-R:6)E<R!T:&4@8VAE
M8VMB;W@@;VX@=&AE('-U<F9E<B=S"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@<V-R965N+V1I<W!L87DN"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D8VAE8VME9"`@06QL;W=E9"!V86QU97,@87)E('1R=64@;W(@9F%L<V4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7TUO8FEL95]C:&5C:V)O>"@D
M;F%M92P@)'9A;'5E+"`D;&%B96PL("1C:&5C:V5D(#T@9F%L<V4I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]N86UE("`]("1N86UE.PH@("`@("`@("1T:&ES
M+3Y?=F%L=64@/2`D=F%L=64["B`@("`@("`@)'1H:7,M/E]L86)E;"`]("1L
M86)E;#L*("`@("`@("`D=&AI<RT^7V-H96-K960@/2`D8VAE8VME9#L*("`@
M('T*"B`@("!F=6YC=&EO;B!I<T-H96-K960H*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7V-H96-K960["B`@("!]"@I]"@HO*BH*("H@5&AI<R!C
M;&%S<R!P<F]V:61E<R!H:61D96X@96QE;65N=',@:6X@2&]R9&5?36]B:6QE
M7V9O<FT@;V)J96-T<RX*("H*("H@17AA;7!L97,Z"B`J"B`J("1H:61D96X@
M/2!N97<@2&]R9&5?36]B:6QE7VAI9&1E;B@G:6YT97)N86Q?<F5F97)E;F-E
M)RP@)S`X,34T-S$Q)RD["B`J"B`J($!S964@2&]R9&5?36]B:6QE7V9O<FT*
M("H*("H@0'!A8VMA9V4@2&]R9&5?36]B:6QE"B`J+PIC;&%S<R!(;W)D95]-
M;V)I;&5?:&ED9&5N(&5X=&5N9',@2&]R9&5?36]B:6QE7V9O<FU%;&5M96YT
M('L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;F%M92`@(%9A<FEA8FQE(&EN('=H:6-H("1V86QU
M92!I<R!S96YT('1O('1H92!D97-T:6YA=&EO;B!54DPN"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1V86QU92`@4V5E(&YA;64N"B`@("`@*B\*("`@(&9U;F-T
M:6]N($AO<F1E7TUO8FEL95]H:61D96XH)&YA;64L("1V86QU92D*("`@('L*
M("`@("`@("`D=&AI<RT^7VYA;64@/2`D;F%M93L*("`@("`@("`D=&AI<RT^
M7W9A;'5E(#T@)'9A;'5E.PH@("`@?0H*?0H*+RHJ"B`J(%1H:7,@8VQA<W,@
M<')O=FED97,@82!S=6)M:70@8G5T=&]N(&9O<B!A($AO<F1E7TUO8FEL95]F
M;W)M(&]B:F5C="X@3VYE"B`J($AO<F1E7TUO8FEL95]F;W)M(&]B:F5C="!C
M86X@8V]N=&%I;B!O;FQY(&]N92!(;W)D95]-;V)I;&5?<W5B;6ET(&]B:F5C
M="X*("H*("H@17AA;7!L97,Z"B`J("1M>5-U8FUI="`]("9N97<@2&]R9&5?
M36]B:6QE7W-U8FUI="@G4W5B;6ET)RD["B`J("1M>5-U8FUI="`]("9N97<@
M2&]R9&5?36]B:6QE7W-U8FUI="@G4W5B;6ET)RP@)W5S97)?<')E<W-E9"<I
M.PH@*@H@*B!`<V5E($AO<F1E7TUO8FEL95]F;W)M"B`J"B`J($!P86-K86=E
M($AO<F1E7TUO8FEL90H@*B\*8VQA<W,@2&]R9&5?36]B:6QE7W-U8FUI="!E
M>'1E;F1S($AO<F1E7TUO8FEL95]F;W)M16QE;65N="!["@H@("`@=F%R("1?
M9F]R;3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;&%B96P@(%=H870G<R!W<FET=&5N(&]N('1H
M92!B=71T;VXN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@5F%R:6%B
M;&4@:6X@=VAI8V@@(FQA8F5L(B!I<R!S96YT('1O('1H90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@(&1E<W1I;F%T:6]N(%523"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@2&]R9&5?36]B:6QE7W-U8FUI="@D;&%B96PL("1N86UE
M(#T@)R<I"B`@("!["B`@("`@("`@)'1H:7,M/E]L86)E;"`]("1L86)E;#L*
M("`@("`@("`D=&AI<RT^7VYA;64@/2`D;F%M93L*("`@('T*"GT*"B\J*@H@
M*B!4:&ES(&-L87-S('!R;W9I9&5S(&$@;&EN:R!I;B!A($AO<F1E7TUO8FEL
M92P@2&]R9&5?36]B:6QE7VQI;FMS970@;W(*("H@2&]R9&5?36]B:6QE7W1A
M8FQE(&]B:F5C="X*("H*("H@17AA;7!L97,Z"B`J"B`J("1M>5!A9V4@/2!N
M97<@2&]R9&5?36]B:6QE*"XN+BD["B`J"B`J("1M>4QI;FL@/2!N97<@2&]R
M9&5?36]B:6QE7VQI;FLH)T-O;G1I;G5E)RP@)R]M>6YE>'1P86=E+G=M;"<I
M.PH@*B`D;7E086=E+3YA9&0H)&UY3&EN:RD["B`J"B`J($!S964@2&]R9&5?
M36]B:6QE"B`J($!S964@2&]R9&5?36]B:6QE7VQI;FMS970*("H@0'-E92!(
M;W)D95]-;V)I;&5?=&%B;&4*("H*("H@0'!A8VMA9V4@2&]R9&5?36]B:6QE
M"B`J+PIC;&%S<R!(;W)D95]-;V)I;&5?;&EN:R!E>'1E;F1S($AO<F1E7TUO
M8FEL95]E;&5M96YT('L*"B`@("!V87(@)%]L86)E;#L*("`@('9A<B`D7W5R
M;#L*("`@('9A<B`D7W1I=&QE.PH@("`@=F%R("1?86-C97-S:V5Y.PH*("`@
M("\J*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1L86)E;"`@1&5S8W)I8F5S('1H92!L:6YK(&]N('1H92!S=7)F
M97(G<R!S8W)E96XO9&ES<&QA>2X*("`@("`J($!P87)A;2!S=')I;F<@)'5R
M;"`@("!.97AT(&1E<W1I;F%T:6]N(&%D9')E<W,N($U54U0@8F4@=F%L:60@
M6$U,("@F86UP.R!I;G-T96%D(&]F("8L(&5T8RXI+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=&ET;&4@($EF(&$@<W1R:6YG(&ES('!R;W9I9&5D(&AE<F4L
M(&ET('=I;&P@8F4@9&ES<&QA>65D"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@:6X@=&AE($A434P@8G)O=W-E<B!S=&%T=7,@8F%R(&1U<FEN9PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@(")-;W5S94]V97(B+"!R97-P
M96-T:79E;'D@<V]M97=H97)E(&]N('1H92!705`*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!D:7-P;&%Y+B!);B!O<F1E<B!T;R!W;W)K('=E;&P@
M=VET:"!A(&)R;V%D(')A;F=E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@;V8@=7-E<B!A9V5N=',L(&ME97`@>6]U<B!T:71L92!U;F1E<B`V"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@8VAA<F%C=&5R<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@2&]R9&5?36]B:6QE7VQI;FLH)&QA8F5L+"`D=7)L
M+"`D=&ET;&4@/2`G)RD*("`@('L*("`@("`@("`D=&AI<RT^7VQA8F5L(#T@
M)&QA8F5L.PH@("`@("`@("1T:&ES+3Y?=7)L(#T@)'5R;#L*("`@("`@("`D
M=&AI<RT^7W1I=&QE(#T@)'1I=&QE.PH*("`@("`@("`O+R!.;R!A8V-E<W-K
M97D@87-S:6=N960@8GD@9&5F875L=#L@8V%N(&)E(&%S<VEG;F5D(&QA=&5R
M"B`@("`@("`@+R\@9G)O;2!A($AO<F1E7TUO8FEL95]L:6YK<V5T(&]B:F5C
M="!I9B!R97%U:7)E9"X*("`@("`@("`D=&AI<RT^7V%C8V5S<VME>2`](&YU
M;&P["B`@("!]"@I]"@HO*BH*("H@5&AI<R!C;&%S<R!P<F]V:61E<R!A('!H
M;VYE(&YU;6)E<B!I;B!A($AO<F1E7TUO8FEL92!O8FIE8W0N($EF('-U<'!O
M<G1E9"!B>0H@*B!T:&5I<B!M;V)I;&4@9&5V:6-E+"!U<V5R<R!C86X@97-T
M86)L:7-H(&$@=F]I8V4@8V]N;F5C=&EO;B!T;R!T:&4*("H@<W!E8VEF:65D
M(&YU;6)E<BX*("H*("H@17AA;7!L97,Z"B`J"B`J("1M>5!H;VYE(#T@)FYE
M=R!(;W)D95]-;V)I;&5?<&AO;F4H)S$R,RTT-38W."<L("=#04Q,)RD["B`J
M("1M>5!A9V4M/F%D9"@D;7E0:&]N92D["B`J"B`J($!S964@2&]R9&5?36]B
M:6QE"B`J"B`J($!P86-K86=E($AO<F1E7TUO8FEL90H@*B\*8VQA<W,@2&]R
M9&5?36]B:6QE7W!H;VYE(&5X=&5N9',@2&]R9&5?36]B:6QE7V5L96UE;G0@
M>PH*("`@('9A<B`D7VQA8F5L.PH@("`@=F%R("1?;G5M8F5R.PH@("`@=F%R
M("1?=&ET;&4["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'!H;VYE7VYU;6)E<B`@4&AO;F4@;G5M
M8F5R('1O(&1I86PN"B`@("`@*B!`<&%R86T@<W1R:6YG("1T:71L92`@("`@
M("`@($EF(&$@<W1R:6YG(&ES('!R;W9I9&5D(&AE<F4L('1H92!C86QL"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)U='1O;B!O;B!A
M(%=!4"](1$U,(&1E=FEC92!W:6QL(&)E"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&5N86)L960N($EN(&]R9&5R('1O('=O<FL@=V5L
M;"!W:71H"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&$@
M8G)O860@<F%N9V4@;V8@=7-E<B!A9V5N=',L(&ME97`@>6]U<@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T:71L92!U;F1E<B`V(&-H
M87)A8W1E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7TUO8FEL95]P
M:&]N92@D<&AO;F5?;G5M8F5R+"`D=&ET;&4@/2`G)RD*("`@('L*("`@("`@
M("`D=&AI<RT^7VQA8F5L(#T@)'!H;VYE7VYU;6)E<CL*("`@("`@("`D=&AI
M<RT^7VYU;6)E<B`]('!R96=?<F5P;&%C92@G?%Q$?"<L("<G+"`D<&AO;F5?
M;G5M8F5R*3L*("`@("`@("`D=&AI<RT^7W1I=&QE(#T@)'1I=&QE.PH@("`@
M?0H*?0H*+RHJ"B`J(%1H:7,@8VQA<W,@9&5F:6YE<R!A('-E="!O9B!L:6YK
M<RX@5&AE(&QI;FMS(&AA=F4@=&\@8F4@9&5F:6YE9"!A<PH@*B!S97!A<F%T
M92!(;W)D95]-;V)I;&5?;&EN:R!O8FIE8W1S(&%N9"!A<F4@871T86-H960@
M=&\@=&AE(&QI;FMS970*("H@=VET:"!A('-P96-I86P@(F%D9"(@9G5N8W1I
M;VXN("!&;W(@5T%0(&1E=FEC97,@8G)O=W-E<BUD97!E;F1E;G0*("H@5TU,
M(&-O9&4@=VEL;"!B92!C<F5A=&5D+B!/;B!A;&P@55`M8G)O=W-E<BUB87-E
M9"!705`@9&5V:6-E<PH@*B!L:6YK<V5T<R!A;&QO=R!E87-I97(@;F%V:6=A
M=&EO;B!T:')O=6=H(%=-3"!D96-K<R!B>2!U<VEN9R!T:&4*("H@(F]N<&EC
M:R(@5TU,(&]P=&EO;B!A;F0@=&AE<F5F;W)E(&%R92!I;7!R;W9I;F<@=&AE
M(")U<V%B:6QI='DB(&]F"B`J(&%N(&%P<&QI8V%T:6]N+B!);G-T96%D(&]F
M('!A:6YF=6QL>2!N879I9V%T:6YG('1H<F]U9V@@=&AE(&QI;FMS"B`J(")S
M<&]R=',M/F9O;W1B86QL+3YR97-U;'1S+3YT;V1A>2(@=&AE(&UO8FEL92!U
M<V5R(&4N9RX@8V%N('!R97-S"B`J("(R-#,Q(B!O;B!T:&4@:V5Y<&%D('1O
M(&5N=&5R(&AI<R!F879O<FET92!D96-K+B!&;W(@86QL(&]T:&5R(%=!4`H@
M*B!D979I8V5S(&YO<FUA;"`\83X@=&%G<R!A<F4@8W)E871E9"X@3VYE($AO
M<F1E7TUO8FEL92!O8FIE8W0@8V%N"B`J(&-O;G1A:6X@;VYL>2!O;F4@;&EN
M:W-E="!O8FIE8W0N"B`J"B`J($5X86UP;&5S.@H@*@H@*B`D;7E086=E(#T@
M;F5W($AO<F1E7TUO8FEL92@N+BXI.PH@*@H@*B`D;7E,:6YK<V5T(#T@;F5W
M($AO<F1E7TUO8FEL95]L:6YK<V5T*"D["B`J("1M>4QI;FLQ(#T@;F5W($AO
M<F1E7TUO8FEL95]L:6YK*")0:&]N96)O;VLB+"`B+W=A<"]P:&]N96)O;VLN
M=VUL(BD["B`J("1M>4QI;FMS970M/F%D9"@D;7E,:6YK,2D["B`J("1M>4QI
M;FLR(#T@;F5W($AO<F1E7TUO8FEL95]L:6YK*")$871E0F]O:R(L("(O=V%P
M+V1A=&5B;V]K+G=M;"(I.PH@*B`D;7E,:6YK<V5T+3YA9&0H)&UY3&EN:S(I
M.PH@*@H@*B`D;7E086=E+3YA9&0H)&UY3&EN:W-E="D["B`J"B`J("1M>5!A
M9V4M/G)E;F1E<B@I.PH@*@H@*B!`<V5E($AO<F1E7TUO8FEL95]L:6YK"B`J
M($!S964@2&]R9&5?36]B:6QE"B`J"B`J($!P86-K86=E($AO<F1E7TUO8FEL
M90H@*B\*8VQA<W,@2&]R9&5?36]B:6QE7VQI;FMS970@97AT96YD<R!(;W)D
M95]-;V)I;&5?96QE;65N="!["@H@("`@=F%R("1?96QE;65N=',["@H@("`@
M+RHJ"B`@("`@*B!!9&1S(&$@2&]R9&5?36]B:6QE7VQI;FL@;V)J96-T('1O
M($AO<F1E7TUO8FEL95]L:6YK<V5T+@H@("`@("H*("`@("`J($!P87)A;2!(
M;W)D95]-;V)I;&5?;&EN:R`D;&EN:R`@5&AE(&QI;FL@;V)J96-T('1O(&%D
M9"X*("`@("`J"B`@("`@*B!`<V5E($AO<F1E7TUO8FEL95]L:6YK"B`@("`@
M*B\*("`@(&9U;F-T:6]N("9A9&0H)B1L:6YK*0H@("`@>PH@("`@("`@(&EF
M("@A:7-?82@D;&EN:RP@)TAO<F1E7TUO8FEL95]L:6YK)RDI('L*("`@("`@
M("`@("`@)&5R<F]R(#T@4$5!4CHZ<F%I<V5%<G)O<B@G3&EN:W,@;75S="!B
M92!(;W)D95]-;V)I;&5?;&EN:R!O8FIE8W1S+B<I.PH@("`@("`@("`@("!R
M971U<FX@)&5R<F]R.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]E;&5M
M96YT<UM=(#T@)B1L:6YK.PH@("`@("`@("1L:6YK+3YS970H)V%C8V5S<VME
M>2<L(&-O=6YT*"1T:&ES+3Y?96QE;65N=',I*3L*"B`@("`@("`@<F5T=7)N
M("1L:6YK.PH@("`@?0H*?0H*+RHJ"B`J(%1H:7,@8VQA<W,@=VEL;"!C875S
M92!A(&AO<FEZ;VYT86P@<G5L92!T;R!B92!D<F%W;B!A8W)O<W,@=&AE('-C
M<F5E;BX@(%EO=0H@*B!C86X@=7-E(&ET('1O('-E<&%R871E('1E>'0@<&%R
M86=R87!H<R!I;B!(;W)D95]-;V)I;&4@;W(@2&]R9&5?36]B:6QE7V9O<FT*
M("H@;V)J96-T<RX*("H*("H@17AA;7!L97,Z"B`J"B`J("1M>41E9F%U;'12
M=6QE(#T@;F5W($AO<F1E7TUO8FEL95]R=6QE*"D["B`J("1M>5-P96-I86Q2
M=6QE(#T@;F5W($AO<F1E7TUO8FEL95]R=6QE*"<V,"4G+"`T*3L*("H*("H@
M)&UY4&%G92T^861D*"1M>41E9F%U;'12=6QE*3L*("H*("H@)&UY4&%G92T^
M861D*"1M>5-P96-I86Q2=6QE*3L*("H*("H@0'-E92!(;W)D95]-;V)I;&4*
M("H@0'-E92!(;W)D95]-;V)I;&5?9F]R;0H@*@H@*B!`<&%C:V%G92!(;W)D
M95]-;V)I;&4*("HO"F-L87-S($AO<F1E7TUO8FEL95]R=6QE(&5X=&5N9',@
M2&]R9&5?36]B:6QE7V5L96UE;G0@>PH*("`@('9A<B`D7W=I9'1H.PH@("`@
M=F%R("1?<VEZ93L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R"B`@("`@
M*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'=I9'1H("!097)C96YT86=E(&]F
M('-C<F5E;B!W:61T:"!O<B!A8G-O;'5T92!V86QU92!I;@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("!N=6UB97(@;V8@<&EX96QS("AE+F<N("(U
M,"4B+"`Q,#`I+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'-I>F4@("!(96EG
M:'0@;V8@=&AE(&QI;F4@=&\@8F4@9')A=VX@:6X@<&EX96QS+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!(;W)D95]-;V)I;&5?<G5L92@D=VED=&@@/2`G)RP@
M)'-I>F4@/2`G)RD*("`@('L*("`@("`@("`D=&AI<RT^7W=I9'1H(#T@)'=I
M9'1H.PH@("`@("`@("1T:&ES+3Y?<VEZ92`]("1S:7IE.PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4E!#+G!H<```
M````````````````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,C`Q
M,#,@,3`U,34T,S,W-#`@,#(P-#<U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B!4:&4@2&]R9&5?4E!#
M.CH@8VQA<W,@<')O=FED97,@82!S970@;V8@<V5R=F5R(&%N9"!C;&EE;G0@
M;65T:&]D<R!F;W(*("H@4E!#(&-O;6UU;FEC871I;VXN"B`J"B`J(%1/1$\Z
M"B`J("T@26YT<F]S<&5C=&EO;B!D;V-U;65N=&%T:6]N(&%N9"!M971H;V0@
M<VEG;F%T=7)E<RX*("H*("H@15A!35!,13H*("H@/&-O9&4^"B`J("1R97-P
M;VYS92`]($AO<F1E7U)00SHZ<F5Q=65S="@G>&UL<G!C)RP*("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=H='1P.B\O;&]C86QH;W-T.C@P
M+VAO<F1E+W)P8RYP:'`G"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G8V]N=&%C=',N<V5A<F-H)RP*("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*&%R<F%Y*"=J86XG*2P@87)R87DH)VQO8V%L
M<W%L)RDL"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@G;F%M92<L("=E;6%I;"<I*2P*("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"=U<V5R)R`]/B!!=71H.CIG971!=71H
M*"DL"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M<&%S<R<@/3X@075T:#HZ9V5T0W)E9&5N=&EA;"@G<&%S<W=O<F0G*2DI.PH@
M*B`\+V-O9&4^"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U)00R]24$,N<&AP
M+'8@,2XW+C$P+C@@,C`P-B\P,2\P,2`R,3HR.#HS,R!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R
M9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F%N(%-C:&YE
M:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J
M($!P86-K86=E($AO<F1E7U)00PH@*B\*8VQA<W,@2&]R9&5?4E!#('L*"B`@
M("`O*BH*("`@("`J(%=H971H97(@=V4@;F5E9"!A;B!A=71H;W)I>F5D('5S
M97(@;W(@;F]T+@H@("`@("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@
M("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?875T:&]R:7IE
M(#T@=')U93L*"B`@("`O*BH*("`@("`J(%)00R!S97)V97(@8V]N<W1R=6-T
M;W(*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!R971U
M<FX@;V)J96-T("`@06X@4E!#('-E<G9E<B!I;G-T86YC92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@2&]R9&5?4E!#*"D*("`@('L*("`@("`@("!R96=I<W1E
M<E]S:'5T9&]W;E]F=6YC=&EO;BAA<G)A>2@D=&AI<RP@)W-H=71D;W=N)RDI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0VQE86YS('5P('1H92!24$,@<V5R
M=F5R+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("HO"B`@("!F=6YC
M=&EO;B!S:'5T9&]W;B@I"B`@("!["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M:&5C:R!A=71H96YT:6-A=&EO;BX@1&EF9F5R96YT(&)A8VME;F1S(&UA>2!H
M86YD;&4*("`@("`J(&%U=&AE;G1I8V%T:6]N(&EN(&1I9F9E<F5N="!W87ES
M+B!4:&4@8F%S92!C;&%S<R!I;7!L96UE;G1A=&EO;@H@("`@("H@8VAE8VMS
M(&9O<B!(5%10($%U=&AE;G1I8V%T:6]N(&%G86EN<W0@=&AE($AO<F1E(&%U
M=&@@<V5T=7`N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!2971U
M<FYS('1R=64@:68@875T:&5N=&EC871I;VX@:7,@<W5C8V5S<V9U;"X*("`@
M("`J("`@("`@("`@("`@("`@("`@4VAO=6QD('-E;F0@87!P<F]P<FEA=&4@
M(FYO="!A=71H;W)I>F5D(B!H96%D97)S"B`@("`@*B`@("`@("`@("`@("`@
M("`@(&]R(&]T:&5R(')E<W!O;G-E(&-O9&5S+V)O9'D@:68@875T:"!F86EL
M<RP*("`@("`J("`@("`@("`@("`@("`@("`@86YD('1A:V4@8V%R92!O9B!E
M>&ET:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!A=71H;W)I>F4H*0H@("`@
M>PH@("`@("`@(&EF("@A)'1H:7,M/E]A=71H;W)I>F4I('L*("`@("`@("`@
M("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`D875T:"`]("9!
M=71H.CIS:6YG;&5T;VXH)$=,3T)!3%-;)V-O;F8G75LG875T:"==6R=D<FEV
M97(G72D["@H@("`@("`@(&EF("AI<W-E="@D7U-%4E9%4ELG4$A07T%55$A?
M55-%4B==*2D@>PH@("`@("`@("`@("`D=7-E<B`]("1?4T525D526R=02%!?
M05542%]54T52)UT["B`@("`@("`@("`@("1P87-S(#T@)%]315)615);)U!(
M4%]!551(7U!7)UT["B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES<V5T*"1U
M<V5R*0H@("`@("`@("`@("!\?"`A)&%U=&@M/F%U=&AE;G1I8V%T92@D=7-E
M<BP@87)R87DH)W!A<W-W;W)D)R`]/B`D<&%S<RDI*2!["B`@("`@("`@("`@
M(&AE861E<B@G5U=7+4%U=&AE;G1I8V%T93H@0F%S:6,@<F5A;&T](DAO<F1E
M(%)00R(G*3L*("`@("`@("`@("`@:&5A9&5R*"=(5%10+S$N,"`T,#$@56YA
M=71H;W)I>F5D)RD["B`@("`@("`@("`@(&5C:&\@)S0P,2!5;F%U=&AO<FEZ
M960G.PH@("`@("`@("`@("!E>&ET.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE(')E<75E
M<W0@8F]D>2!I;G!U="X@1&EF9F5R96YT(%)00R!B86-K96YD<R!C86X@;W9E
M<G)I9&4*("`@("`J('1H:7,@=&\@<F5T=7)N(&%N(&]P96X@<W1R96%M('1O
M('!H<#HO+W-T9&EN+"!F;W(@:6YS=&%N8V4@+0H@("`@("H@=VAA=&5V97(@
M:7,@96%S:65S="!T;R!H86YD;&4@:6X@=&AE(&=E=%)E<W!O;G-E*"D@;65T
M:&]D+@H@("`@("H*("`@("`J(%1H92!B87-E(&-L87-S(&EM<&QE;65N=&%T
M:6]N(&QO;VMS(&9O<B`D2%144%]205=?4$]35%]$051!(&%N9`H@("`@("H@
M<F5T=7)N<R!T:&%T(&EF(&ET)W,@879A:6QA8FQE.R!O=&AE<G=I<V4L(&ET
M(')E='5R;G,@=&AE"B`@("`@*B!C;VYT96YT<R!O9B!P:'`Z+R]S=&1I;BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@:6YP=70@+2!A('-T
M<FEN9R`H9&5F875L="DL(&$@9FEL96AA;F1L92P@971C+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971);G!U="@I"B`@("!["B`@("`@("`@:68@*&ES<V5T
M*"1'3$]"04Q36R=(5%107U)!5U]03U-47T1!5$$G72DI('L*("`@("`@("`@
M("`@<F5T=7)N("1'3$]"04Q36R=(5%107U)!5U]03U-47T1!5$$G73L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@:6UP;&]D92@B7')<
M;B(L(&9I;&4H)W!H<#HO+VEN<'5T)RDI.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E;F1S(&%N(%)00R!R97%U97-T('1O('1H92!S97)V
M97(@86YD(')E='5R;G,@=&AE(')E<W5L="X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("!4:&4@<F%W(')E<75E<W0@<W1R:6YG+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@6$U,(&5N8V]D960@<F5S<&]N<V4@
M9G)O;2!T:&4@<V5R=F5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971297-P
M;VYS92@D<F5Q=65S="D*("`@('L*("`@("`@("!R971U<FX@7R@B;F]T(&EM
M<&QE;65N=&5D(BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE($-O
M;G1E;G0M5'EP92!O9B!T:&4@<F5S<&]N<V4N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!-24U%($-O;G1E;G0M5'EP92!O9B!T:&4@4E!#
M(')E<W!O;G-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971297-P;VYS94-O
M;G1E;G14>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)W1E>'0O>&UL)SL*
M("`@('T*"B`@("`O*BH*("`@("`J($)U:6QD<R!A;B!24$,@<F5Q=65S="!A
M;F0@<V5N9',@:70@=&\@=&AE(%)00R!S97)V97(N"B`@("`@*@H@("`@("H@
M5&AI<R!S=&%T:6-A;&QY(&-A;&QE9"!M971H;V0@:7,@86-T=6%L;'D@=&AE
M(%)00R!C;&EE;G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9')I
M=F5R("`@(%1H92!P<F]T;V-O;"!D<FEV97(@=&\@=7-E+B!#=7)R96YT;'D@
M)W-O87`G"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@86YD("=X
M;6QR<&,G(&%R92!A=F%I;&%B;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1U
M<FP@("`@("`@5&AE('!A=&@@=&\@=&AE(%)00R!S97)V97(@;VX@=&AE(&-A
M;&QE9"!H;W-T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;65T:&]D("`@(%1H
M92!M971H;V0@=&\@8V%L;"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US
M("`@("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@;F5C97-S87)Y('!A<F%M971E
M<G,@9F]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&UE
M=&AO9"!C86QL+@H@("`@("H@0'!A<F%M("1O<'1I;VYS("`@("`@("`@($%S
M<V]C:6%T:79E(&%R<F%Y(&]F('!A<F%M971E<G,@9&5P96YD:6YG(&]N"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE('-E;&5C=&5D('!R
M;W1O8V]L(&1R:79E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("`@
M("`@("`@("`@5&AE(')E='5R;F5D(')E<W5L="!F<F]M('1H92!M971H;V0@
M;W(@82!014%2"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@97)R
M;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E
M<75E<W0H)&1R:79E<BP@)'5R;"P@)&UE=&AO9"P@)'!A<F%M<R`](&YU;&PL
M("1O<'1I;VYS(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H:7-?87)R
M87DH)&1R:79E<BDI('L*("`@("`@("`@("`@;&ES="@D87!P+"`D9')I=F5R
M*2`]("1D<FEV97(["B`@("`@("`@?0H*("`@("`@("`D9')I=F5R(#T@8F%S
M96YA;64H)&1R:79E<BD["@H@("`@("`@(&EF("@A96UP='DH)&%P<"DI('L*
M("`@("`@("`@("`@<F5Q=6ER95]O;F-E("1A<'`@+B`G+VQI8B]24$,O)R`N
M("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?2!E;'-E:68@*$!F:6QE7V5X
M:7-T<RAD:7)N86UE*%]?1DE,15]?*2`N("<O4E!#+R<@+B`D9')I=F5R("X@
M)RYP:'`G*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?
M7T9)3$5?7RD@+B`G+U)00R\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!`:6YC;'5D95]O;F-E("=(;W)D92]2
M4$,O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?0H@("`@("`@("1C
M;&%S<R`]("=(;W)D95]24$-?)R`N("1D<FEV97(["B`@("`@("`@:68@*&-L
M87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@(')E='5R;B!C86QL
M7W5S97)?9G5N8RAA<G)A>2@D8VQA<W,L("=R97%U97-T)RDL("1U<FPL("1M
M971H;V0L("1P87)A;7,L("1O<'1I;VYS*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T-L87-S(&1E9FEN:71I;VX@
M;V8@)R`N("1C;&%S<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(&-O;F-R
M971E(%)00R!S97)V97(@:6YS=&%N8V4@8F%S960@;VX*("`@("`J("1D<FEV
M97(N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1D<FEV97(@(%1H92!T
M>7!E(&]F(&-O;F-R971E(%)00R!S=6)C;&%S<R!T;R!R971U<FXN($EF"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@)&1R:79E<B!I<R!A;B!A<G)A
M>2P@=&AE;B!W92!W:6QL(&QO;VL@:6X*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`D9')I=F5R6S!=+VQI8B]24$,O(&9O<B!T:&4@<W5B8VQA<W,*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!I;7!L96UE;G1A=&EO;B!N
M86UE9"`D9')I=F5R6S%=+G!H<"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R
M86US("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U
M<F%T:6]N(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@8V]N;F5C
M=&EO;B!P87)A;65T97)S(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N($AO<F1E7U)00R`@5&AE(&YE=VQY(&-R96%T960@
M8V]N8W)E=&4@2&]R9&5?4E!#('-E<G9E<B!I;G-T86YC92P*("`@("`J("`@
M("`@("`@("`@("`@("`@("!O<B!A(%!%05)?17)R;W(@;VX@86X@97)R;W(N
M"B`@("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1D<FEV97(L("1P87)A
M;7,@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D9')I=F5R
M*2D@>PH@("`@("`@("`@("!L:7-T*"1A<'`L("1D<FEV97(I(#T@)&1R:79E
M<CL*("`@("`@("!]"@H@("`@("`@("1D<FEV97(@/2!B87-E;F%M92@D9')I
M=F5R*3L*"B`@("`@("`@:68@*"%E;7!T>2@D87!P*2D@>PH@("`@("`@("`@
M("!R97%U:7)E7V]N8V4@)&%P<"`N("<O;&EB+U)00R\G("X@)&1R:79E<B`N
M("<N<&AP)SL*("`@("`@("!](&5L<V5I9B`H0&9I;&5?97AI<W1S*&1I<FYA
M;64H7U]&24Q%7U\I("X@)R]24$,O)R`N("1D<FEV97(@+B`G+G!H<"<I*2![
M"B`@("`@("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N
M("<O4E!#+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@($!I;F-L=61E7V]N8V4@)TAO<F1E+U)00R\G("X@)&1R
M:79E<B`N("<N<&AP)SL*("`@("`@("!]"B`@("`@("`@)&-L87-S(#T@)TAO
M<F1E7U)00U\G("X@)&1R:79E<CL*("`@("`@("!I9B`H8VQA<W-?97AI<W1S
M*"1C;&%S<RDI('L*("`@("`@("`@("`@)')P8R`]("9N97<@)&-L87-S*"1P
M87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E<75I<F5?
M;VYC92`G4$5!4BYP:'`G.PH@("`@("`@("`@("`D<G!C(#T@4$5!4CHZ<F%I
M<V5%<G)O<B@G0VQA<W,@9&5F:6YI=&EO;B!O9B`G("X@)&-L87-S("X@)R!N
M;W0@9F]U;F0N)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')P8SL*
M("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(')E
M9F5R96YC92!T;R!A(&-O;F-R971E(%)00R!S97)V97(*("`@("`J(&EN<W1A
M;F-E(&)A<V5D(&]N("1D<FEV97(N($ET('=I;&P@;VYL>2!C<F5A=&4@82!N
M97<@:6YS=&%N8V4*("`@("`J(&EF(&YO(%)00R!S97)V97(@:6YS=&%N8V4@
M=VET:"!T:&4@<V%M92!P87)A;65T97)S(&-U<G)E;G1L>0H@("`@("H@97AI
M<W1S+@H@("`@("H*("`@("`J(%1H:7,@<VAO=6QD(&)E('5S960@:68@;75L
M=&EP;&4@4E!#('-E<G9E<G,@*&%N9"!T:'5S+"!M=6QT:7!L92!24$,*("`@
M("`J('-E<G9E<B!I;G-T86YC97,I(&%R92!R97%U:7)E9"X*("`@("`J"B`@
M("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z("1V87(@/2`F
M2&]R9&5?4E!#.CIS:6YG;&5T;VXH*0H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&1R:79E<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@4E!#('-U8F-L
M87-S('1O(')E='5R;BX*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@
M02!H87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO
M;B!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!C;VYN96-T:6]N
M('!A<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@
M("`J($!R971U<FX@2&]R9&5?4E!#("!4:&4@8V]N8W)E=&4@2&]R9&5?4E!#
M('-E<G9E<B!R969E<F5N8V4L(&]R(&$*("`@("`J("`@("`@("`@("`@("`@
M("`@("!014%27T5R<F]R(&]N(&%N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC
M=&EO;B`F<VEN9VQE=&]N*"1D<FEV97(L("1P87)A;7,@/2!N=6QL*0H@("`@
M>PH@("`@("`@('-T871I8R`D:6YS=&%N8V5S.PH*("`@("`@("!I9B`H(6ES
M<V5T*"1I;G-T86YC97,I*2!["B`@("`@("`@("`@("1I;G-T86YC97,@/2!A
M<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA
M;&EZ92AA<G)A>2@D9')I=F5R+"`D<&%R86US*2D["B`@("`@("`@:68@*"%A
M<G)A>5]K97E?97AI<W1S*"1S:6=N871U<F4L("1I;G-T86YC97,I*2!["B`@
M("`@("`@("`@("1I;G-T86YC97-;)'-I9VYA='5R95T@/2`F2&]R9&5?4E!#
M.CIF86-T;W)Y*"1D<FEV97(L("1P87)A;7,I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1I;G-T86YC97-;)'-I9VYA='5R95T["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O5D,N<&AP````````````````
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,S0U,#<@,3`U,34T
M,S,W-#`@,#(P,S<V`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B!3;W)T:6YG(&]P=&EO;G,*("HO"F1E
M9FEN92@G5D-?4T]25%].3TY%)RP@,"D[("`@("`@("`O+R!D;VXG="!S;W)T
M"F1E9FEN92@G5D-?4T]25%]!1T4G+"`Q*3L@("`@("`@("`O+R!S;W)T(&)Y
M(&%G90ID969I;F4H)U9#7U-/4E1?3D%-12<L(#(I.R`@("`@("`@+R\@<V]R
M="!B>2!F:6QE;F%M90ID969I;F4H)U9#7U-/4E1?4D56)RP@,RD[("`@("`@
M("`@+R\@<V]R="!B>2!R979I<VEO;B!N=6UB97(*9&5F:6YE*"=60U]33U)4
M7T%55$A/4B<L(#0I.R`@("`@("\O('-O<G0@8GD@875T:&]R(&YA;64*"F1E
M9FEN92@G5D-?4T]25%]!4T-%3D1)3D<G+"`P*3L@("`O+R!A<V-E;F1I;F<@
M;W)D97(*9&5F:6YE*"=60U]33U)47T1%4T-%3D1)3D<G+"`Q*3L@("\O(&1E
M<V-E;F1I;F<@;W)D97(*"F1E9FEN92@G5D-?5TE.1$]74R<L('-U8G-T<BA0
M2%!?3U,L(#`L(#,I(#T]("=724XG*3L*"B\J*@H@*B!697)S:6]N($-O;G1R
M;VP@9V5N97)A;&EZ960@;&EB<F%R>2X*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO5D,O5D,N<&AP+'8@,2XQ,BXX+C$R(#(P,#8O,#4O,S$@,3<Z,#8Z,S<@
M<V5L<VMY($5X<"`D"B`J"B`J($!P86-K86=E(%9#"B`J+PIC;&%S<R!60R![
M"@H@("`@+RHJ"B`@("`@*B!4:&4@<V]U<F-E(')O;W0@;V8@=&AE(')E<&]S
M:71O<GDN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W-O=7)C97)O;W0["@H@
M("`@+RHJ"B`@("`@*B!(87-H('=I=&@@=&AE(&QO8V%T:6]N<R!O9B!A;&P@
M;F5C97-S87)Y(&)I;F%R:65S+@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)%]P871H<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!(
M87-H(&-A8VAI;F<@=&AE('!A<G-E9"!U<V5R<R!F:6QE+@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]U<V5R<SL*"B`@("`O*BH*("`@
M("`J(%)E='5R;B!T:&4@<V]U<F-E(')O;W0@9F]R('1H:7,@<F5P;W-I=&]R
M>2P@=VET:"!N;R!T<F%I;&EN9R`O"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%-O=7)C92!R;V]T(&9O<B!T:&ES(')E<&]S:71O<GDN"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-O=7)C97)O;W0H*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7W-O=7)C97)O;W0["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!L;V-A=&EO;B!O9B!T:&4@<W!E8VEF:65D(&)I;F%R
M>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1B:6YA<GD@($%N(&5X
M=&5R;F%L('!R;V=R86T@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86Y\<W1R:6YG("!4:&4@;&]C871I;VX@;V8@=&AE(&5X=&5R;F%L('!R
M;V=R86T@;W(@9F%L<V4@:68*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@(&ET('=A<VXG="!S<&5C:69I960N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=%!A=&@H)&)I;F%R>2D*("`@('L*("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]P871H<ULD8FEN87)Y72DI('L*("`@("`@("`@("`@:68@*%9#7U=)
M3D1/5U,I('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A=&AS
M6R1B:6YA<GE=.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N(&ES7V5X96-U=&%B;&4H)'1H:7,M/E]P871H<ULD8FEN87)Y
M72D@/R`D=&AI<RT^7W!A=&AS6R1B:6YA<GE=(#H@9F%L<V4["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*
M"B`@("`O*BH*("`@("`J(%!A<G-E('1H92!U<V5R<R!F:6QE+"!I9B!P<F5S
M96YT(&EN('1H92!S;W5R8V4@<F]O="P@86YD(')E='5R;@H@("`@("H@82!H
M87-H(&-O;G1A:6YI;F<@=&AE(')E<75I<VET92!I;F9O<FUA=&EO;BP@:V5Y
M960@;VX@=&AE"B`@("`@*B!U<V5R;F%M92P@86YD('=I=&@@=&AE("=D97-C
M)RPG;F%M92<L(&%N9"`G;6%I;"<@=F%L=65S(&EN<VED92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86Y\87)R87D@($9A;'-E(&EF('1H92!F:6QE
M(&ES(&YO="!P<F5S96YT+"!O=&AE<G=I<V4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]U<V5R<R!P;W!U;&%T960@=VET:"!T:&4@
M9&%T80H@("`@("HO"B`@("!F=6YC=&EO;B!G9715<V5R<R@D=7-E<G-F:6QE
M*0H@("`@>PH@("`@("`@("\J($-H96-K('1H870@=V4@:&%V96XG="!A;')E
M861Y('!A<G-E9"!U<V5R<RX@*B\*("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/E]U<V5R<RD@)B8@:7-?87)R87DH)'1H:7,M/E]U<V5R<RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?=7-E<G,["B`@("`@("`@?0H*("`@("`@
M("!I9B`H(4!I<U]F:6QE*"1U<V5R<V9I;&4I('Q\("$H)&9L(#T@0&9O<&5N
M*"1U<V5R<V9I;&4L(%9#7U=)3D1/5U,@/R`G<F(G(#H@)W(G*2DI('L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@)'1H
M:7,M/E]U<V5R<R`](&%R<F%Y*"D["@H@("`@("`@("\J($1I<V-A<F0@=&AE
M(&9I<G-T(&QI;F4L('-I;F-E(&ET)VQL(&)E('1H92!H96%D97(@:6YF;RX@
M*B\*("`@("`@("!F9V5T<R@D9FPL(#0P.38I.PH*("`@("`@("`O*B!087)S
M92!T:&4@<F5S="!O9B!T:&4@;&EN97,@:6YT;R!A(&AA<V@L(&ME>65D(&]N
M"B`@("`@("`@("H@=7-E<FYA;64N("HO"B`@("`@("`@=VAI;&4@*"1L:6YE
M(#T@9F=E=',H)&9L+"`T,#DV*2D@>PH@("`@("`@("`@("!I9B`H<')E9U]M
M871C:"@G+UY<<RHD+R<L("1L:6YE*2D@>PH@("`@("`@("`@("`@("`@8V]N
M=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%P<F5G7VUA
M=&-H*"<O7BA<=RLI7',K*"XK*5QS*RA;7'=<+EPM7%]=*T!;7'=<+EPM7%]=
M*RE<<RLH+BHI)"\G+"`D;&EN92P@)')E9W,I*2!["B`@("`@("`@("`@("`@
M("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M
M/E]U<V5R<ULD<F5G<ULQ75U;)VYA;64G72`]('1R:6TH)')E9W-;,ETI.PH@
M("`@("`@("`@("`D=&AI<RT^7W5S97)S6R1R96=S6S%=75LG;6%I;"==(#T@
M=')I;2@D<F5G<ULS72D["B`@("`@("`@("`@("1T:&ES+3Y?=7-E<G-;)')E
M9W-;,5U=6R=D97-C)UT@/2!T<FEM*"1R96=S6S1=*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D=&AI<RT^7W5S97)S.PH@("`@?0H*("`@("\J*@H@
M("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E=&4@5D,@:6YS=&%N
M8V4@8F%S960@;VX@)&1R:79E<BX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX
M960@)&1R:79E<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@5D,@<W5B8VQA<W,@
M=&\@<F5T=7)N+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(%1H92!C
M;V1E(&ES(&1Y;F%M:6-A;&QY(&EN8VQU9&5D+@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L
M(&-O;F9I9W5R871I;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!O
M<B`@<&%R86UE=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE960N"B`@("`@*@H@
M("`@("H@0')E='5R;B!60R`@5&AE(&YE=VQY(&-R96%T960@8V]N8W)E=&4@
M5D,@:6YS=&%N8V4L(&]R(%!%05)?17)R;W(@;VX*("`@("`J("`@("`@("`@
M("`@(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1D
M<FEV97(L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EN8VQU
M9&5?;VYC92`G5D,O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@)&-L
M87-S(#T@)U9#7R<@+B`D9')I=F5R.PH@("`@("`@(&EF("AC;&%S<U]E>&ES
M=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D=F,@/2!N97<@)&-L87-S*"1P
M87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1V8R`](%!%
M05(Z.G)A:7-E17)R;W(H)&-L87-S("X@)R!N;W0@9F]U;F0N)RD["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)'9C.PH@("`@?0H*("`@("\J*@H@("`@
M("H@071T96UP=',@=&\@<F5T=7)N(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E
M=&4@5D,@:6YS=&%N8V4@8F%S960*("`@("`J(&]N("1D<FEV97(N($ET('=I
M;&P@;VYL>2!C<F5A=&4@82!N97<@:6YS=&%N8V4@:68@;F\@5D,*("`@("`J
M(&EN<W1A;F-E('=I=&@@=&AE('-A;64@<&%R86UE=&5R<R!C=7)R96YT;'D@
M97AI<W1S+@H@("`@("H*("`@("`J(%1H:7,@<VAO=6QD(&)E('5S960@:68@
M;75L=&EP;&4@='EP97,@;V8@9FEL92!B86-K96YD<R`H86YD+`H@("`@("H@
M=&AU<RP@;75L=&EP;&4@5D,@:6YS=&%N8V5S*2!A<F4@<F5Q=6ER960N"B`@
M("`@*@H@("`@("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.B`D
M=F%R(#T@)E9#.CIS:6YG;&5T;VXH*0H@("`@("H*("`@("`J($!P87)A;2!M
M:7AE9"`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!60R!S=6)C;&%S
M<R!T;R!R971U<FXN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@5&AE
M(&-O9&4@:7,@9'EN86UI8V%L;'D@:6YC;'5D960N"B`@("`@*B!`<&%R86T@
M87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N
M86P@8V]N9FEG=7)A=&EO;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M(&]R('!A<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*
M("`@("`J($!R971U<FX@5D,@(%1H92!C;VYC<F5T92!60R!R969E<F5N8V4L
M(&]R(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@)G-I;F=L971O;B@D9')I=F5R+"`D<&%R86US(#T@87)R87DH*2D*("`@
M('L*("`@("`@("!S=&%T:6,@)&EN<W1A;F-E<SL*("`@("`@("!I9B`H(6ES
M<V5T*"1I;G-T86YC97,I*2!["B`@("`@("`@("`@("1I;G-T86YC97,@/2!A
M<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA
M;&EZ92AA<G)A>2@D9')I=F5R+"`D<&%R86US*2D["B`@("`@("`@:68@*"%I
M<W-E="@D:6YS=&%N8V5S6R1S:6=N871U<F5=*2D@>PH@("`@("`@("`@("`D
M:6YS=&%N8V5S6R1S:6=N871U<F5=(#T@5D,Z.F9A8W1O<GDH)&1R:79E<BP@
M)'!A<F%M<RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EN<W1A;F-E
M<ULD<VEG;F%T=7)E73L*("`@('T*"GT*"B\J*@H@*B!`<&%C:V%G92!60PH@
M*B\*8VQA<W,@5D-?1&EF9B!["@H@("`@+RHJ"B`@("`@*B!/8G1A:6X@82!T
M<F5E(&-O;G1A:6YI;F<@:6YF;W)M871I;VX@86)O=70@=&AE(&-H86YG97,@
M8F5T=V5E;@H@("`@("H@='=O(')E=FES:6]N<RX*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)')A=R`@06X@87)R87D@;V8@;&EN97,@;V8@=&AE(')A
M=R!U;FEF:65D(&1I9F8L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@;F]R
M;6%L;'D@;V)T86EN960@=&AR;W5G:"!60U]$:69F.CIG970H*2X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y"B`@("`@*@H@("`@("H@0'1O9&\@9&]C
M=6UE;G0@=&AI<R!T:&]R;W5G:&QY+"!A<R!T:&4@9F]R;6%T(&ES(&$@8FET
M(&-O;7!L97@N"B`@("`@*B\*("`@(&9U;F-T:6]N(&AU;6%N4F5A9&%B;&4H
M)')A=RD*("`@('L*("`@("`@("`D<F5T(#T@87)R87DH*3L*"B`@("`@("`@
M+RH@2&]L9"!T:&4@;&5F="!A;F0@<FEG:'0@8V]L=6UN<R!O9B!L:6YE<R!F
M;W(@8VAA;F=E"B`@("`@("`@("H@8FQO8VMS+B`J+PH@("`@("`@("1C;VQS
M(#T@87)R87DH87)R87DH*2P@87)R87DH*2D["B`@("`@("`@)'-T871E(#T@
M)V5M<'1Y)SL*"B`@("`@("`@+RH@271E<F%T92!T:')O=6=H(&5V97)Y(&QI
M;F4@;V8@=&AE(&1I9F8N("HO"B`@("`@("`@9F]R96%C:"`H)')A=R!A<R`D
M;&EN92D@>PH@("`@("`@("`@("`O*B!,;V]K(&9O<B!A(&AE861E<B!W:&EC
M:"!I;F1I8V%T97,@=&AE('-T87)T(&]F(&$@9&EF9@H@("`@("`@("`@("`@
M*B!C:'5N:RX@*B\*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>0$`@
M7"TH6S`M.5TK*2XJ7"LH6S`M.5TK*2XJ0$`H+BHI+R<L("1L:6YE+"`D<F5G
M<RDI('L*("`@("`@("`@("`@("`@("\J(%!U<V@@86YY('!R979I;W5S(&AE
M861E<B!I;F9O<FUA=&EO;B!T;R!T:&4@<F5T=7)N"B`@("`@("`@("`@("`@
M("`@*B!S=&%C:RX@*B\*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&%T
M82DI('L*("`@("`@("`@("`@("`@("`@("`D<F5T6UT@/2`D9&%T83L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1D871A(#T@87)R87DH
M)W1Y<&4G(#T^("=H96%D97(G+"`G;VQD;&EN92<@/3X@)')E9W-;,5TL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=N97=L:6YE)R`]/B`D<F5G
M<ULR72P@)V-O;G1E;G1S)SX@87)R87DH*2D["B`@("`@("`@("`@("`@("`D
M9&%T85LG9G5N8W1I;VXG72`](&ES<V5T*"1R96=S6S-=*2`_("1R96=S6S-=
M(#H@)R<["B`@("`@("`@("`@("`@("`D<W1A=&4@/2`G9'5M<"<["B`@("`@
M("`@("`@('T@96QS96EF("@D<W1A=&4@(3T@)V5M<'1Y)RD@>PH@("`@("`@
M("`@("`@("`@+RH@5V4@87)E(&EN(&$@8VAU;FLL('-O('-P;&ET(&]U="!T
M:&4@86-T:6]N("@K+RTI"B`@("`@("`@("`@("`@("`@*B!A;F0@=&AE(&QI
M;F4N("HO"B`@("`@("`@("`@("`@("!P<F5G7VUA=&-H*"<O7BA;7"M<+2!=
M*2@N*BDO)RP@)&QI;F4L("1R96=S*3L*("`@("`@("`@("`@("`@(&EF("AC
M;W5N="@D<F5G<RD@/B`R*2!["B`@("`@("`@("`@("`@("`@("`@)&%C=&EO
M;B`]("1R96=S6S%=.PH@("`@("`@("`@("`@("`@("`@("1C;VYT96YT(#T@
M)')E9W-;,ET["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1A8W1I;VX@/2`G("<["B`@("`@("`@("`@("`@("`@("`@
M)&-O;G1E;G0@/2`G)SL*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("`@("!I9B`H)&%C=&EO;B`]/2`G*R<I('L*("`@("`@("`@("`@("`@("`@
M("`O*B!4:&ES(&ES(&IU<W0@86X@861D:71I;VX@;&EN92X@*B\*("`@("`@
M("`@("`@("`@("`@("!I9B`H)'-T871E(#T]("=D=6UP)R!\?"`D<W1A=&4@
M/3T@)V%D9"<I('L*("`@("`@("`@("`@("`@("`@("`@("`@+RH@4W1A<G0@
M861D:6YG('1O('1H92!A9&1I=&EO;B!S=&%C:RX@*B\*("`@("`@("`@("`@
M("`@("`@("`@("`@)&-O;'-;,%U;72`]("1C;VYT96YT.PH@("`@("`@("`@
M("`@("`@("`@("`@("`D<W1A=&4@/2`G861D)SL*("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`O*B!4:&ES
M(&ES(&EN<VED92!A(&-H86YG92!B;&]C:RP@<V\@<W1A<G0*("`@("`@("`@
M("`@("`@("`@("`@("`@("H@86-C=6UU;&%T:6YG(&QI;F5S+B`J+PH@("`@
M("`@("`@("`@("`@("`@("`@("`D<W1A=&4@/2`G8VAA;F=E)SL*("`@("`@
M("`@("`@("`@("`@("`@("`@)&-O;'-;,5U;72`]("1C;VYT96YT.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS96EF("@D
M86-T:6]N(#T]("<M)RD@>PH@("`@("`@("`@("`@("`@("`@("\J(%1H:7,@
M:7,@82!R96UO=F%L(&QI;F4N("HO"B`@("`@("`@("`@("`@("`@("`@)'-T
M871E(#T@)W)E;6]V92<["B`@("`@("`@("`@("`@("`@("`@)&-O;'-;,%U;
M72`]("1C;VYT96YT.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`O*B!!;B!E;7!T>2!B;&]C:R!W:71H(&YO(&%C=&EO
M;BX@*B\*("`@("`@("`@("`@("`@("`@("!S=VET8V@@*"1S=&%T92D@>PH@
M("`@("`@("`@("`@("`@("`@(&-A<V4@)V%D9"<Z"B`@("`@("`@("`@("`@
M("`@("`@("`@("1D871A6R=C;VYT96YT<R==6UT@/2!A<G)A>2@G='EP92<@
M/3X@)V%D9"<L("=L:6YE<R<@/3X@)&-O;'-;,%TI.PH@("`@("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("`@("`@8V%S92`G
M<F5M;W9E)SH*("`@("`@("`@("`@("`@("`@("`@("`@+RH@5V4@:&%V92!S
M;VUE(')E;6]V86P@;&EN97,@<&5N9&EN9R!I;B!O=7(*("`@("`@("`@("`@
M("`@("`@("`@("`@("H@<W1A8VLL('-O(&9L=7-H('1H96TN("HO"B`@("`@
M("`@("`@("`@("`@("`@("`@("1D871A6R=C;VYT96YT<R==6UT@/2!A<G)A
M>2@G='EP92<@/3X@)W)E;6]V92<L("=L:6YE<R<@/3X@)&-O;'-;,%TI.PH@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@
M("`@("`@8V%S92`G8VAA;F=E)SH*("`@("`@("`@("`@("`@("`@("`@("`@
M+RH@5V4@:&%V92!B;W1H(')E;6]V92!A;F0@861D:71I;VX@;&EN97,L('-O
M"B`@("`@("`@("`@("`@("`@("`@("`@("`J('1H:7,@:7,@82!C:&%N9V4@
M8FQO8VLN("HO"B`@("`@("`@("`@("`@("`@("`@("`@("1D871A6R=C;VYT
M96YT<R==6UT@/2!A<G)A>2@G='EP92<@/3X@)V-H86YG92<L("=O;&0G(#T^
M("1C;VQS6S!=+"`G;F5W)R`]/B`D8V]L<ULQ72D["B`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`D8V]L<R`](&%R<F%Y*&%R<F%Y*"DL(&%R<F%Y*"DI
M.PH@("`@("`@("`@("`@("`@("`@("1D871A6R=C;VYT96YT<R==6UT@/2!A
M<G)A>2@G='EP92<@/3X@)V5M<'1Y)RP@)VQI;F4G(#T^("1C;VYT96YT*3L*
M("`@("`@("`@("`@("`@("`@("`D<W1A=&4@/2`G9'5M<"<["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J
M($IU<W0@9FQU<V@@86YY(')E;6%I;FEN9R!E;G1R:65S(&EN('1H92!C;VQU
M;6YS('-T86-K+B`J+PH@("`@("`@('-W:71C:"`H)'-T871E*2!["B`@("`@
M("`@8V%S92`G861D)SH*("`@("`@("`@("`@)&1A=&%;)V-O;G1E;G1S)UU;
M72`](&%R<F%Y*"=T>7!E)R`]/B`G861D)RP@)VQI;F5S)R`]/B`D8V]L<ULP
M72D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=R96UO=F4G
M.@H@("`@("`@("`@("`O*B!792!H879E('-O;64@<F5M;W9A;"!L:6YE<R!P
M96YD:6YG(&EN(&]U<B!S=&%C:RP@<V\*("`@("`@("`@("`@("H@9FQU<V@@
M=&AE;2X@*B\*("`@("`@("`@("`@)&1A=&%;)V-O;G1E;G1S)UU;72`](&%R
M<F%Y*"=T>7!E)R`]/B`G<F5M;W9E)RP@)VQI;F5S)R`]/B`D8V]L<ULP72D[
M"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=C:&%N9V4G.@H@
M("`@("`@("`@("`O*B!792!H879E(&)O=&@@<F5M;W9E(&%N9"!A9&1I=&EO
M;B!L:6YE<RP@<V\@=&AI<R!I<R!A"B`@("`@("`@("`@("`J(&-H86YG92!B
M;&]C:RX@*B\*("`@("`@("`@("`@)&1A=&%;)V-O;G1E;G1S)UU;72`](&%R
M<F%Y*"=T>7!E)R`]/B`G8VAA;F=E)RP@)V]L9"<@/3X@)&-O;'-;,%TL("=N
M97<G(#T^("1C;VQS6S%=*3L*("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M?0H*("`@("`@("!I9B`H:7-S970H)&1A=&$I*2!["B`@("`@("`@("`@("1R
M971;72`]("1D871A.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R970[
M"B`@("!]"@I]"@HO*BH*("H@0'!A8VMA9V4@5D,*("HO"F-L87-S(%9#7T9I
M;&4@>PH*("`@('9A<B`D<F5P.PH@("`@=F%R("1D:7(["B`@("!V87(@)&YA
M;64["B`@("!V87(@)&QO9W,["B`@("!V87(@)')E=G,["B`@("!V87(@)&AE
M860["B`@("!V87(@)'%U:6-K;&]G.PH@("`@=F%R("1S>6UR978["B`@("!V
M87(@)')E=G-Y;3L*("`@('9A<B`D8G)A;F-H97,["@H@("`@9G5N8W1I;VX@
M<V5T4F5P;W-I=&]R>2@D<F5P*0H@("`@>PH@("`@("`@("1T:&ES+3YR97`@
M/2`D<F5P.PH@("`@?0H*?0H*+RHJ"B`J(%9#('!A=&-H<V5T(&-L87-S+@H@
M*@H@*B!`<&%C:V%G92!60PH@*B\*8VQA<W,@5D-?4&%T8VAS970@>PH*("`@
M('9A<B`D7W)E<#L*("`@('9A<B`D7W!A=&-H<V5T<R`](&%R<F%Y*"D["@H@
M("`@9G5N8W1I;VX@<V5T4F5P;W-I=&]R>2@D<F5P*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?<F5P(#T@)')E<#L*("`@('T*"GT*"B\J*@H@*B!60R!R979I
M<VEO;G,@8VQA<W,N"B`J"B`J($-O<'ER:6=H="!!;FEL($UA9&AA=F%P961D
M>2P@/&%N:6Q`<F5C;VEL+F]R9SX*("H*("H@0&%U=&AO<B`@06YI;"!-861H
M879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H@0'!A8VMA9V4@5D,*("HO
M"F-L87-S(%9#7U)E=FES:6]N('L*"B`@("`O*BH*("`@("`J(%9A;&ED871I
M;VX@9G5N8W1I;VX@=&\@96YS=7)E('1H870@82!R979I<VEO;B!N=6UB97(@
M:7,@;V8@=&AE"B`@("`@*B!R:6=H="!F;W)M+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'9A;"`@5F%L=64@=&\@8VAE8VLN"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF(&ET(&ES(&$@<F5V:7-I;VX@
M;G5M8F5R"B`@("`@*B\*("`@(&9U;F-T:6]N('9A;&ED*"1V86PI"B`@("![
M"B`@("`@("`@<F5T=7)N("1V86P@)B8@<')E9U]M871C:"@G+UY;7&1<+ETK
M)"\G+"`D=F%L*3L*("`@('T*"B`@("`O*BH*("`@("`J($=I=F5N(&$@<F5V
M:7-I;VX@;G5M8F5R+"!R96UO=F4@82!G:79E;B!N=6UB97(@;V8@<&]R=&EO
M;G,@9G)O;0H@("`@("H@:70N($9O<B!E>&%M<&QE+"!I9B!W92!R96UO=F4@
M,B!P;W)T:6]N<R!O9B`Q+C(N,RXT+"!W92!A<F4*("`@("`J(&QE9G0@=VET
M:"`Q+C(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=F%L("`@("`@
M26YP=70@<F5V:7-I;VX*("`@("`J($!P87)A;2!I;G1E9V5R("1A;6]U;G0@
M($YU;6)E<B!O9B!P;W)T:6]N<R!T;R!S=')I<`H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!3=')I<'!E9"!R979I<VEO;B!N=6UB97(*("`@("`J
M+PH@("`@9G5N8W1I;VX@<W1R:7`H)'9A;"P@)&%M;W5N="D*("`@('L*("`@
M("`@("!I9B`H(59#7U)E=FES:6]N.CIV86QI9"@D=F%L*2D@>PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@("1P;W,@/2`P
M.PH@("`@("`@('=H:6QE("@D86UO=6YT+2T@/B`P("8F("@D<&]S(#T@<W1R
M<G!O<R@D=F%L+"`G+B<I*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@)'9A
M;"`]('-U8G-T<B@D=F%L+"`P+"`D<&]S*3L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("1P;W,@(3T](&9A;'-E(#\@)'9A;"`Z(&9A;'-E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@5&AE('-I>F4@;V8@82!R979I<VEO;B!N=6UB97(@
M:7,@=&AE(&YU;6)E<B!O9B!P;W)T:6]N<R!I="!H87,N"B`@("`@*B!&;W(@
M97AA;7!L92P@,2PR+C,N-"!I<R!O9B!S:7IE(#0N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=F%L("!2979I<VEO;B!N=6UB97(@=&\@9&5T97)M
M:6YE('-I>F4@;V8*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%-I
M>F4@;V8@<F5V:7-I;VX@;G5M8F5R"B`@("`@*B\*("`@(&9U;F-T:6]N('-I
M>F5O9B@D=F%L*0H@("`@>PH@("`@("`@(&EF("@A5D-?4F5V:7-I;VXZ.G9A
M;&ED*"1V86PI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`H<W5B<W1R7V-O=6YT*"1V86PL("<N)RD@
M*R`Q*3L*("`@('T*"B`@("`O*BH*("`@("`J($=I=F5N(&$@=F%L:60@<F5V
M:7-I;VX@;G5M8F5R+"!T:&ES('=I;&P@<F5T=7)N('1H92!R979I<VEO;@H@
M("`@("H@;G5M8F5R(&9R;VT@=VAI8V@@:70@8G)A;F-H960N($EF(&ET(&-A
M;FYO="!B92!D971E<FUI;F5D+"!T:&5N"B`@("`@*B!F86QS92!I<R!R971U
M<FYE9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1V86P@(%)E=FES
M:6]N(&YU;6)E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9WQB;V]L
M96%N("!"<F%N8V@@<&]I;G0@<F5V:7-I;VXL(&]R(&9A;'-E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!B<F%N8VA0;VEN="@D=F%L*0H@("`@>PH@("`@("`@
M("\J($-H96-K(&EF('=E(&AA=F4@82!V86QI9"!R979I<VEO;B!N=6UB97(@
M*B\*("`@("`@("!I9B`H(59#7U)E=FES:6]N.CIV86QI9"@D=F%L*2D@>PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O
M*B!)9B!I=',@;VX@=&AE('1R=6YK+"!O<B!I<R!A;B!O9&0@<VEZ92P@<F5T
M(&9A;'-E("HO"B`@("`@("`@:68@*%9#7U)E=FES:6]N.CIS:7IE;V8H)'9A
M;"D@/"`S('Q\("A60U]2979I<VEO;CHZ<VEZ96]F*"1V86PI("4@,BDI('L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@
M+RH@4W1R:7`@;V9F('1W;R!R979I<VEO;B!P;W)T:6]N<RP@86YD(')E='5R
M;B!I="`J+PH@("`@("`@(')E='5R;B!60U]2979I<VEO;CHZ<W1R:7`H)'9A
M;"P@,BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!':79E;B!T=V\@4U9.(')E
M=FES:6]N(&YU;6)E<G,L('1H:7,@9FEG=7)E<R!O=70@=VAI8V@@;VYE(&ES
M"B`@("`@*B!G<F5A=&5R('1H86X@=&AE(&]T:&5R(&)Y('-T97!P:6YG(&%L
M;VYG('1H92!D96-I;6%L('!O:6YT<PH@("`@("H@=6YT:6P@82!D:69F97)E
M;F-E(&ES(&9O=6YD+"!A="!W:&EC:"!P;VEN="!A('-I9VX@8V]M<&%R:7-O
M;@H@("`@("H@;V8@=&AE('1W;R!I<R!R971U<FYE9"X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1R978Q("!097)I;V0@9&5L:6UI=&5D(')E=FES
M:6]N(&YU;6)E<@H@("`@("H@0'!A<F%M('-T<FEN9R`D<F5V,B`@4V5C;VYD
M('!E<FEO9"!D96QI;6ET960@<F5V:7-I;VX@;G5M8F5R"B`@("`@*@H@("`@
M("H@0')E='5R;B!I;G1E9V5R("`Q(&EF('1H92!F:7)S="!I<R!G<F5A=&5R
M+"`M,2!I9B!T:&4@<V5C;VYD(&EF(&=R96%T97(L"B`@("`@*B`@("`@("`@
M("`@("`@("`@(&%N9"`P(&EF('1H97D@87)E(&5Q=6%L"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-M<"@D<F5V,2P@)')E=C(I"B`@("!["B`@("`@("`@<F5T
M=7)N('9E<G-I;VY?8V]M<&%R92@D<F5V,2P@)')E=C(I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N('1H92!L;V=I8V%L(')E=FES:6]N(&)E9F]R
M92!T:&ES(&]N92X@3F]R;6%L;'DL('1H:7,*("`@("`J('=I;&P@8F4@=&AE
M(')E=FES:6]N(&UI;G5S(&]N92P@8G5T(&EN('1H92!C87-E(&]F(&$@;F5W
M"B`@("`@*B!B<F%N8V@L('=E('-T<FEP(&]F9B!T:&4@;&%S="!T=V\@9&5C
M:6UA;"!P;&%C97,@=&\@<F5T=7)N('1H90H@("`@("H@;W)I9VEN86P@8G)A
M;F-H('!O:6YT+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)')E=B`@
M4F5V:7-I;VX@;G5M8F5R('1O(&1E8W)E;65N="X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9WQB;V]L96%N("!2979I<VEO;B!N=6UB97(L(&]R(&9A
M;'-E(&EF(&YO;F4@8V]U;&0@8F4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@(&1E=&5R;6EN960N"B`@("`@*B\*("`@(&9U;F-T:6]N('!R978H
M)')E=BD*("`@('L*("`@("`@("`D;&%S=%]D;W0@/2!S=')R<&]S*"1R978L
M("<N)RD["B`@("`@("`@)'9A;"`]('-U8G-T<B@D<F5V+"`K*R1L87-T7V1O
M="D["@H@("`@("`@(&EF("@M+21V86P@/B`P*2!["B`@("`@("`@("`@(')E
M='5R;B!S=6)S='(H)')E=BP@,"P@)&QA<W1?9&]T*2`N("1V86P["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&QA<W1?9&]T+2T["B`@("`@("`@
M("`@('=H:6QE("@M+21L87-T7V1O="D@>PH@("`@("`@("`@("`@("`@:68@
M*"1R979;)&QA<W1?9&]T72`]/2`G+B<I('L*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@('-U8G-T<B@D<F5V+"`P+"`D;&%S=%]D;W0I.PH@("`@("`@
M("`@("`@("`@?2!E;'-E:68@*"1R979;)&QA<W1?9&]T72`]/2!N=6QL*2![
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@1VEV96X@82!R979I<VEO;B!N=6UB97(@;V8@=&AE(&9O<FT@
M>"YY+C`N>BP@=&AI<R!R96UA<',@:70*("`@("`J(&EN=&\@=&AE(&%P<')O
M<')I871E(&)R86YC:"!N=6UB97(L('=H:6-H(&ES('@N>2YZ"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<F5V("!%=F5N+61I9VET(')E=FES:6]N
M(&YU;6)E<B!O9B!A(&)R86YC:`H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!/9&0M9&EG:70@0G)A;F-H(&YU;6)E<@H@("`@("HO"B`@("!F=6YC
M=&EO;B!T;T)R86YC:"@D<F5V*0H@("`@>PH@("`@("`@("\J($-H96-K(&EF
M('=E(&AA=F4@82!V86QI9"!R979I<VEO;B!N=6UB97(@*B\*("`@("`@("!I
M9B`H(59#7U)E=FES:6]N.CIV86QI9"@D<F5V*2D@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H*"1E;F0@/2!S
M=')R<&]S*"1R978L("<N)RDI(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D<F5V6R1E;F1=(#T@
M,#L*("`@("`@("!I9B`H*"1E;F0R(#T@<W1R<G!O<R@D<F5V+"`G+B<I*2`]
M/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T=7)N('-U8G-T<B@D<F5V+"`K
M*R1E;F0I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('-U8G-T<E]R97!L
M86-E*"1R978L("<N)RP@)&5N9#(L("@D96YD+21E;F0R*S$I*3L*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O5&5X
M="YP:'``````````````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#(W-#<@,3`U,34T,S,W-#`@,#(Q,#$S`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@5&5X
M=#HZ(&-L87-S('!R;W9I9&5S(&-O;6UO;B!M971H;V1S(&9O<B!M86YI<'5L
M871I;F<@=&5X="X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O5&5X="YP:'`L=B`Q+C(N,3`N-2`R,#`V+S`Q+S`Q(#(Q.C(X.C(P(&IA
M;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($IO;B!087)I<V4@
M/&IO;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*
M;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q
M+C,*("H@0'!A8VMA9V4@2&]R9&5?5&5X=`H@*B\*8VQA<W,@5&5X="!["@H@
M("`@+RHJ"B`@("`@*B!#;VYV97)T(&$@;&EN92!O9B!T97AT('1O(&1I<W!L
M87D@<')O<&5R;'D@:6X@2%1-3"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1T97AT("!4:&4@<W1R:6YG(&]F('1E>'0@=&\@8V]N=F5R="X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($A434PM8V]M<&QI86YT
M(&-O;G9E<G1E9"!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!H=&UL4W!A
M8V5S*"1T97AT(#T@)R<I"B`@("!["B`@("`@("`@<W1A=&EC("1C:&%R<V5T
M.PH@("`@("`@(&EF("@A:7-S970H)&-H87)S970I*2!["B`@("`@("`@("`@
M("1C:&%R<V5T(#T@3DQ3.CIG971#:&%R<V5T*"D["B`@("`@("`@?0H*("`@
M("`@("`D=&5X="`]($!H=&UL<W!E8VEA;&-H87)S*"1T97AT+"!%3E1?0T]-
M4$%4+"`D8VAA<G-E="D["B`@("`@("`@)'1E>'0@/2!S=')?<F5P;&%C92@B
M7'0B+"`G)FYB<W`[("9N8G-P.R`F;F)S<#L@)FYB<W`[("<L("1T97AT*3L*
M("`@("`@("`D=&5X="`]('-T<E]R97!L86-E*"<@("<L("<F;F)S<#L@)RP@
M)'1E>'0I.PH@("`@("`@("1T97AT(#T@<W1R7W)E<&QA8V4H)R`@)RP@)R`F
M;F)S<#LG+"`D=&5X="D["@H@("`@("`@(')E='5R;B`D=&5X=#L*("`@('T*
M"B`@("`O*BH*("`@("`J(%-A;64@87,@:'1M;%-P86-E<R@I(&)U="!C;VYV
M97)T<R!A;&P@<W!A8V5S('1O("9N8G-P.PH@("`@("H*("`@("`J($!S964@
M:'1M;%-P86-E<R@I"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X
M="`@5&AE('-T<FEN9R!O9B!T97AT('1O(&-O;G9E<G0N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!(5$U,+6-O;7!L:6%N="!C;VYV97)T
M960@=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@:'1M;$%L;%-P86-E<R@D
M=&5X="`]("<G*0H@("`@>PH@("`@("`@("1T97AT(#T@5&5X=#HZ:'1M;%-P
M86-E<R@D=&5X="D["B`@("`@("`@)'1E>'0@/2!S=')?<F5P;&%C92@G("<L
M("<F;F)S<#LG+"`D=&5X="D["@H@("`@("`@(')E='5R;B`D=&5X=#L*("`@
M('T*"GT*`````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92]3:&%R92YP:'``````````````````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`W-3$P,R`Q,#4Q-30S,S<T,"`P
M,C$Q,C4`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O1&%T851R964N<&AP)SL*
M"B\J*@H@*B!(;W)D95]3:&%R93HZ('!R;W9I9&5S(&%N(&EN=&5R9F%C92!T
M;R!A;&P@<VAA<F5S(&$@=7-E<B!M:6=H="!H879E+B`@271S"B`J(&UE=&AO
M9',@=&%K92!C87)E(&]F(&%N>2!S:71E+7-P96-I9FEC(')E<W1R:6-T:6]N
M<R!C;VYF:6=U<F5D(&EN(&EN('1H90H@*B!A<'!L:6-A=&EO;B=S('!R969S
M+G!H<"!A;F0@8V]N9BYP:'`@9FEL97,N"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+U-H87)E+U-H87)E+G!H<"QV(#$N,3$Q+C(N,C`@,C`P-B\P-2\P-"`Q
M,SHR-3HR.2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!*
M;V5L(%9A;F1A;"`\:G9A;F1A;$!I;F9O=&5C:RYQ8RYC83X*("H@0V]P>7)I
M9VAT(#(P,#(M,C`P-B!);F9O=&5C:R!);G1E<FYE="`\=V5B;6%S=&5R0&EN
M9F]T96-K+G%C+F-A/@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@
M0&%U=&AO<B`@2F]E;"!686YD86P@/&IV86YD86Q`:6YF;W1E8VLN<6,N8V$^
M"B`J($!A=71H;W(@($UI:V4@0V]C:')A;64@/&UI:V5`9W)A9G1O;FAA;&PN
M8V\N;GH^"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R
M9&5?4VAA<F4*("HO"F-L87-S($AO<F1E7U-H87)E('L*"B`@("`O*BH*("`@
M("`J(%!O:6YT97(@=&\@82!$871A5')E92!I;G-T86YC92!T;R!M86YA9V4O
M<W1O<F4@<VAA<F5S"B`@("`@*@H@("`@("H@0'9A<B!$871A5')E90H@("`@
M("HO"B`@("!V87(@)%]D871A=')E93L*"B`@("`O*BH*("`@("`J(%1H92!A
M<'!L:6-A=&EO;B!W92=R92!M86YA9VEN9R!S:&%R97,@9F]R+@H@("`@("H*
M("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V%P<#L*"B`@
M("`O*BH*("`@("`J(%1H92!S=6)C;&%S<R!O9B!$871A5')E94]B:F5C="!T
M;R!I;G-T86YT:6%T92!S:&%R97,@87,N"B`@("`@*@H@("`@("H@0'9A<B!S
M=')I;F<*("`@("`J+PH@("`@=F%R("1?<VAA<F5/8FIE8W0@/2`G1&%T851R
M965/8FIE8W1?4VAA<F4G.PH*("`@("\J*@H@("`@("H@02!C86-H92!O9B!A
M;&P@<VAA<F5S('1H870@:&%V92!B965N(')E=')I979E9"P@<V\@=V4@9&]N
M)W0@:&ET('1H90H@("`@("H@8F%C:V5N9"!A9V%I;B!A;F0@86=A:6X@9F]R
M('1H96TN"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)%]C86-H92`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#86-H92!U
M<V5D(&9O<B!L:7-T4VAA<F5S*"DN"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)%]L:7-T8V%C:&4@/2!A<G)A>2@I.PH*("`@
M("\J*@H@("`@("H@02!L:7-T(&]F(&]B:F5C=',@=&AA="!W92=R92!C=7)R
M96YT;'D@<V]R=&EN9RP@9F]R(')E9F5R96YC92!D=7)I;F<@=&AE"B`@("`@
M*B!S;W)T:6YG(&%L9V]R:71H;2X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*B\*("`@('9A<B`D7W-O<G1,:7-T.PH*("`@("\J*@H@("`@("H@
M071T96UP=',@=&\@<F5T=7)N(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@
M2&]R9&5?4VAA<F4@:6YS=&%N8V4N($ET"B`@("`@*B!W:6QL(&]N;'D@8W)E
M871E(&$@;F5W(&EN<W1A;F-E(&EF(&YO($AO<F1E7U-H87)E(&EN<W1A;F-E
M(&-U<G)E;G1L>0H@("`@("H@97AI<W1S+@H@("`@("H*("`@("`J(%1H:7,@
M;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH*("`@("`J("`@/&-O9&4^)'9A
M<B`]("9(;W)D95]3:&%R93HZ<VEN9VQE=&]N*"1A<'`I.SPO8V]D93X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@(%1H92!A<'!L:6-A=&EO
M;G,@=&AA="!T:&4@<VAA<F5S(')E;&%T97,@=&\N"B`@("`@*@H@("`@("H@
M0')E='5R;B!(;W)D95]3:&%R92`@5&AE(&-O;F-R971E(%-H87)E(')E9F5R
M96YC92P@;W(@9F%L<V4@;VX@86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N("9S:6YG;&5T;VXH)&%P<"D*("`@('L*("`@("`@("!S=&%T:6,@)'-H
M87)E<SL*"B`@("`@("`@:68@*"%I<W-E="@D<VAA<F5S6R1A<'!=*2D@>PH@
M("`@("`@("`@("`D<VAA<F5S6R1A<'!=(#T@;F5W($AO<F1E7U-H87)E*"1A
M<'`I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1S:&%R97-;)&%P<%T[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1A<'`@(%1H92!A<'!L:6-A=&EO;B!T:&%T
M('1H92!S:&%R97,@8F5L;VYG('1O+@H@("`@("HO"B`@("!F=6YC=&EO;B!(
M;W)D95]3:&%R92@D87!P*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9BP@
M)')E9VES=')Y.PH*("`@("`@("!I9B`H96UP='DH)&-O;F9;)V1A=&%T<F5E
M)UU;)V1R:79E<B==*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH)UEO
M=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-H
M87)E<RXG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@
M("`@)&1R:79E<B`]("1C;VYF6R=D871A=')E92==6R=D<FEV97(G73L*("`@
M("`@("`D=&AI<RT^7V%P<"`]("1A<'`["B`@("`@("`@)'1H:7,M/E]D871A
M=')E92`]("9$871A5')E93HZ<VEN9VQE=&]N*`H@("`@("`@("`@("`D9')I
M=F5R+`H@("`@("`@("`@("!A<G)A>5]M97)G92A(;W)D93HZ9V5T1')I=F5R
M0V]N9FEG*"=D871A=')E92<L("1D<FEV97(I+"!A<G)A>2@G9W)O=7`G(#T^
M("=H;W)D92YS:&%R97,N)R`N("1A<'`I*0H@("`@("`@("D["@H@("`@("`@
M($AO<F1E.CIC86QL2&]O:R@G7VAO<F1E7VAO;VM?<VAA<F5?:6YI="<L(&%R
M<F%Y*"1T:&ES+"`D87!P*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS('1H92!$871A5')E92!I;G-T86YC92!U<V5D('1O(&UA;F%G92!T:&ES
M('-H87)E+@H@("`@("H*("`@("`J($!R971U<FX@1&%T851R964@(%1H:7,@
M<VAA<F4G<R!$871A5')E92!I;G-T86YC92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@)F=E=$1A=&%4<F5E*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/E]D871A=')E93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!$
M871A5')E94]B:F5C=%]3:&%R92!O8FIE8W0@8V]R<F5S<&]N9&EN9R!T;R!T
M:&4@9VEV96X@<VAA<F4*("`@("`J(&YA;64L('=I=&@@=&AE(&1E=&%I;',@
M<F5T<FEE=F5D(&%P<')O<')I871E;'DN"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;F%M92`@5&AE(&YA;64@;V8@=&AE('-H87)E('1O(')E=')I
M979E+@H@("`@("H*("`@("`J($!R971U<FX@1&%T851R965/8FIE8W1?4VAA
M<F4@(%1H92!R97%U97-T960@<VAA<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9G9713:&%R92@D;F%M92D*("`@('L*("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]C86-H95LD;F%M95TI*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7V-A8VAE6R1N86UE73L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?
M8V%C:&5;)&YA;65=(#T@)B1T:&ES+3Y?9&%T871R964M/F=E=$]B:F5C="@D
M;F%M92P@)'1H:7,M/E]S:&%R94]B:F5C="D["B`@("`@("`@:68@*"%I<U]A
M*"1T:&ES+3Y?8V%C:&5;)&YA;65=+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?8V%C:&5;)&YA;65=+3YS9713:&%R94]B*"1T:&ES
M*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^7V-A8VAE6R1N
M86UE73L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!$871A5')E
M94]B:F5C=%]3:&%R92!O8FIE8W0@8V]R<F5S<&]N9&EN9R!T;R!T:&4@9VEV
M96X@=6YI<75E"B`@("`@*B!)1"P@=VET:"!T:&4@9&5T86EL<R!R971R:65V
M960@87!P<F]P<FEA=&5L>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1C:60@(%1H92!I9"!O9B!T:&4@<VAA<F4@=&\@<F5T<FEE=F4N"B`@("`@
M*@H@("`@("H@0')E='5R;B!$871A5')E94]B:F5C=%]3:&%R92`@5&AE(')E
M<75E<W1E9"!S:&%R92X*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=%-H87)E
M0GE)9"@D8VED*0H@("`@>PH@("`@("`@("1S:&%R92`]("1T:&ES+3Y?9&%T
M871R964M/F=E=$]B:F5C=$)Y260H)&-I9"P@)'1H:7,M/E]S:&%R94]B:F5C
M="D["B`@("`@("`@:68@*"%I<U]A*"1S:&%R92P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("`D<VAA<F4M/G-E=%-H87)E3V(H)'1H:7,I.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@)'-H87)E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!A;B!A<G)A>2!O9B!$871A5')E94]B:F5C=%]3:&%R
M92!O8FIE8W1S(&-O<G)E<W!O;F1I;F<@=&\@=&AE"B`@("`@*B!G:79E;B!S
M970@;V8@=6YI<75E($E$<RP@=VET:"!T:&4@9&5T86EL<R!R971R:65V960@
M87!P<F]P<FEA=&5L>2X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&-I
M9',@(%1H92!A<G)A>2!O9B!I9',@=&\@<F5T<FEE=F4N"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@5&AE(')E<75E<W1E9"!S:&%R97,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N("9G9713:&%R97,H)&-I9',I"B`@("!["B`@("`@
M("`@)'-H87)E<R`]("1T:&ES+3Y?9&%T871R964M/F=E=$]B:F5C=',H)&-I
M9',L("1T:&ES+3Y?<VAA<F5/8FIE8W0I.PH@("`@("`@(&EF("AI<U]A*"1S
M:&%R97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1S
M:&%R97,["B`@("`@("`@?0H*("`@("`@("`D:V5Y<R`](&%R<F%Y7VME>7,H
M)'-H87)E<RD["B`@("`@("`@9F]R96%C:"`H)&ME>7,@87,@)&ME>2D@>PH@
M("`@("`@("`@("!I9B`H:7-?82@D<VAA<F5S6R1K97E=+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'-H87)E<ULD:V5Y73L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M/E]C86-H95LD:V5Y
M72`]("8D<VAA<F5S6R1K97E=.PH@("`@("`@("`@("`D<VAA<F5S6R1K97E=
M+3YS9713:&%R94]B*"1T:&ES*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D<VAA<F5S.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&YE
M=R!S:&%R92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;F%M92`@5&AE('-H87)E)W,@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M($1A=&%4<F5E3V)J96-T7U-H87)E("!!(&YE=R!S:&%R92!O8FIE8W0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N("9N97=3:&%R92@D;F%M92D*("`@('L*("`@
M("`@("!I9B`H96UP='DH)&YA;64I*2!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"=3:&%R92!N86UE<R!M=7-T(&)E(&YO;BUE;7!T
M>2<I.PH@("`@("`@('T*("`@("`@("`D<VAA<F4@/2`F;F5W("1T:&ES+3Y?
M<VAA<F5/8FIE8W0H)&YA;64I.PH@("`@("`@("1S:&%R92T^<V5T1&%T851R
M964H)'1H:7,M/E]D871A=')E92D["B`@("`@("`@)'-H87)E+3YS9713:&%R
M94]B*"1T:&ES*3L*("`@("`@("`D<VAA<F4M/G-E="@G;W=N97(G+"!!=71H
M.CIG971!=71H*"DI.PH*("`@("`@("!R971U<FX@)'-H87)E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@061D<R!A('-H87)E('1O('1H92!S:&%R97,@<WES
M=&5M+B!4:&4@<VAA<F4@;75S="!F:7)S="!B92!C<F5A=&5D('=I=&@*("`@
M("`J($AO<F1E7U-H87)E.CIN97=3:&%R92@I+"!A;F0@:&%V92!A;GD@:6YI
M=&EA;"!D971A:6QS(&%D9&5D('1O(&ET+`H@("`@("H@8F5F;W)E('1H:7,@
M9G5N8W1I;VX@:7,@8V%L;&5D+@H@("`@("H*("`@("`J($!P87)A;2!$871A
M5')E94]B:F5C=%]3:&%R92`D<VAA<F4@(%1H92!N97<@<VAA<F4@;V)J96-T
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;GQ014%27T5R<F]R("!0
M14%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D
M9%-H87)E*"1S:&%R92D*("`@('L*("`@("`@("!I9B`H(6ES7V$H)'-H87)E
M+"`G1&%T851R965/8FIE8W1?4VAA<F4G*2D@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4VAA<F5S(&UU<W0@8F4@1&%T851R965/
M8FIE8W1?4VAA<F4@;V)J96-T<R!O<B!E>'1E;F0@=&AA="!C;&%S<RXG*3L*
M("`@("`@("!]"@H@("`@("`@("1P97)M(#T@)B1'3$]"04Q36R=P97)M<R==
M+3YN97=097)M:7-S:6]N*"1S:&%R92T^9V5T3F%M92@I*3L*("`@("`@("!I
M9B`H:7-?82@D<&5R;2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)'!E<FT["B`@("`@("`@?0H*("`@("`@("`O*B!':79E('1H92!O
M=VYE<B!F=6QL(&%C8V5S<R`J+PH@("`@("`@("1P97)M+3YA9&15<V5R4&5R
M;6ES<VEO;B@D<VAA<F4M/F=E="@G;W=N97(G*2P@4$5235-?4TA/5RP@9F%L
M<V4I.PH@("`@("`@("1P97)M+3YA9&15<V5R4&5R;6ES<VEO;B@D<VAA<F4M
M/F=E="@G;W=N97(G*2P@4$5235-?4D5!1"P@9F%L<V4I.PH@("`@("`@("1P
M97)M+3YA9&15<V5R4&5R;6ES<VEO;B@D<VAA<F4M/F=E="@G;W=N97(G*2P@
M4$5235-?141)5"P@9F%L<V4I.PH@("`@("`@("1P97)M+3YA9&15<V5R4&5R
M;6ES<VEO;B@D<VAA<F4M/F=E="@G;W=N97(G*2P@4$5235-?1$5,151%+"!F
M86QS92D["@H@("`@("`@("1S:&%R92T^<V5T4&5R;6ES<VEO;B@D<&5R;2P@
M9F%L<V4I.PH*("`@("`@("`D<F5S=6QT(#T@2&]R9&4Z.F-A;&Q(;V]K*"=?
M:&]R9&5?:&]O:U]S:&%R95]A9&0G+"!A<G)A>2@D<VAA<F4I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAO<F1E)RP@9F%L<V4I.PH@
M("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)'1H:7,M/E]D871A=')E92T^861D*"1S:&%R92D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!296UO=F5S(&$@<VAA<F4@9G)O;2!T:&4@<VAA<F5S
M('-Y<W1E;2!P97)M86YE;G1L>2X*("`@("`J"B`@("`@*B!`<&%R86T@1&%T
M851R965/8FIE8W1?4VAA<F4@)'-H87)E("!4:&4@<VAA<F4@=&\@<F5M;W9E
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;GQ014%27T5R<F]R("!0
M14%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E
M;6]V95-H87)E*"1S:&%R92D*("`@('L*("`@("`@("!I9B`H(6ES7V$H)'-H
M87)E+"`G1&%T851R965/8FIE8W1?4VAA<F4G*2D@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4VAA<F5S(&UU<W0@8F4@1&%T851R
M965/8FIE8W1?4VAA<F4@;V)J96-T<R!O<B!E>'1E;F0@=&AA="!C;&%S<RXG
M*3L*("`@("`@("!]"@H@("`@("`@("1R97-U;'0@/2!(;W)D93HZ8V%L;$AO
M;VLH)U]H;W)D95]H;V]K7W-H87)E7W)E;6]V92<L(&%R<F%Y*"1S:&%R92DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:&]R9&4G+"!F
M86QS92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D=&AI<RT^7V1A=&%T<F5E+3YR96UO=F4H)'-H87)E
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!T;R!S964@:68@82!S
M:&%R92!H87,@86YY(&-H:6QD('-H87)E<RX*("`@("`J"B`@("`@*B!`<&%R
M86T@1&%T851R965/8FIE8W1?4VAA<F4@)'-H87)E("!4:&4@<VAA<F4@=&\@
M8VAE8VL@9F]R(&-H:6QD<F5N+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5')U92!I9B!T:&4@<W!E8VEF:65D('-H87)E(&AA<R!C:&EL9"!S
M:&%R97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA<T-H:6QD<F5N*"1S:&%R
M92D*("`@('L*("`@("`@("!I9B`H(6ES7V$H)'-H87)E+"`G1&%T851R965/
M8FIE8W1?4VAA<F4G*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@G4VAA<F5S(&UU<W0@8F4@1&%T851R965/8FIE8W1?4VAA<F4@
M;V)J96-T<R!O<B!E>'1E;F0@=&AA="!C;&%S<RXG*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`H8F]O;"DD=&AI<RT^7V1A=&%T<F5E+3YG971.=6UB
M97)/9D-H:6QD<F5N*"1S:&%R92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS(&$@<VAA<F4G<R!D:7)E8W0@<&%R96YT(&]B:F5C="X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1S:&%R92`@1V5T('1H92!P87)E;G0@
M;V8@=&AI<R!S:&%R92X*("`@("`J"B`@("`@*B!`<F5T=7)N($1A=&%4<F5E
M3V)J96-T7U-H87)E("!4:&4@<&%R96YT('-H87)E+"!I9B!I="!E>&ES=',N
M"B`@("`@*B\*("`@(&9U;F-T:6]N("9G971087)E;G0H)&-H:6QD*0H@("`@
M>PH@("`@("`@("1I9"`]("1T:&ES+3Y?9&%T871R964M/F=E=%!A<F5N="@D
M8VAI;&0I.PH@("`@("`@(&EF("AI<U]A*"1I9"P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&ED.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"$D:60@?'P@*"1I9"`]/2!$051!5%)%15]23T]4*2D@>PH@("`@("`@
M("`@("`D97)R;W(@/2!014%2.CIR86ES945R<F]R*"=087)E;G0@9&]E<R!N
M;W0@97AI<W0N)RD["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/F=E=%-H87)E0GE)9"@D:60I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@240@;V8@82!S
M:&%R92X*("`@("`J"B`@("`@*B!`<&%R86T@1&%T851R965/8FIE8W1?4VAA
M<F4@(%1H92!S:&%R92!T;R!R971U<FX@=&AE($E$(&]F+@H@("`@("H*("`@
M("`J($!R971U<FX@:6YT96=E<B`@5&AE('-H87)E)W,@240@;W(@4$5!4E]%
M<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9713:&%R
M94ED*"1S:&%R92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]D871A
M=')E92T^9V5T260H)'-H87)E+3YG971.86UE*"DI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@571I;&ET>2!F=6YC=&EO;B!T;R!B92!U<V5D('=I=&@@=6%S
M;W)T*"D@9F]R('-O<G1I;F<@87)R87ES(&]F"B`@("`@*B!(;W)D95]3:&%R
M92!O8FIE8W1S+@H@("`@("H@17AA;7!L93H\8V]D93X*("`@("`J('5A<V]R
M="@D;&ES="P@87)R87DH)TAO<F1E7U-H87)E)RP@)U]S;W)T4VAA<F5S)RDI
M.PH@("`@("H@/"]C;V1E/@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("HO"B`@("!F=6YC=&EO;B!?<V]R=%-H87)E<R@D82P@)&(I"B`@
M("!["B`@("`@("`@)&%087)T<R`](&5X<&QO9&4H)SHG+"`D82T^9V5T3F%M
M92@I*3L*("`@("`@("`D8E!A<G1S(#T@97AP;&]D92@G.B<L("1B+3YG971.
M86UE*"DI.PH*("`@("`@("`D;6EN(#T@;6EN*&-O=6YT*"1A4&%R=',I+"!C
M;W5N="@D8E!A<G1S*2D["B`@("`@("`@)&ED02`]("<G.PH@("`@("`@("1I
M9$(@/2`G)SL*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D;6EN.R`D:2LK
M*2!["B`@("`@("`@("`@(&EF("@D:61!*2!["B`@("`@("`@("`@("`@("`D
M:61!("X]("<Z)SL*("`@("`@("`@("`@("`@("1I9$(@+CT@)SHG.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1I9$$@+CT@)&%087)T<ULD:5T["B`@
M("`@("`@("`@("1I9$(@+CT@)&)087)T<ULD:5T["@H@("`@("`@("`@("!I
M9B`H)&ED02`A/2`D:61"*2!["B`@("`@("`@("`@("`@("`D8W5R02`](&ES
M<V5T*"1T:&ES+3Y?<V]R=$QI<W1;)&ED05TI(#\@)'1H:7,M/E]S;W)T3&ES
M=%LD:61!72T^9V5T*"=N86UE)RD@.B`G)SL*("`@("`@("`@("`@("`@("1C
M=7)"(#T@:7-S970H)'1H:7,M/E]S;W)T3&ES=%LD:61"72D@/R`D=&AI<RT^
M7W-O<G1,:7-T6R1I9$)=+3YG970H)VYA;64G*2`Z("<G.PH@("`@("`@("`@
M("`@("`@<F5T=7)N('-T<FYA=&-A<V5C;7`H)&-U<D$L("1C=7)"*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&-O=6YT*"1A
M4&%R=',I(#X@8V]U;G0H)&)087)T<RD["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#:&5C:W,@:68@82!S:&%R92!E>&ES=',@:6X@=&AE('-Y<W1E;2X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S:&%R92`@5&AE('-H87)E('1O
M(&-H96-K+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I
M9B!T:&4@<VAA<F4@97AI<W1S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&5X:7-T<R@D<VAA<F4I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?9&%T871R964M/F5X:7-T<R@D<VAA<F4I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8V]U;G0@;V8@86QL('-H87)E
M<R!T:&%T("1U<V5R:60@:&%S(&%C8V5S<R!T;RX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`D=7-E<FED("`@("`@5&AE('5S97)I9"!O9B!T:&4@
M=7-E<B!T;R!C:&5C:R!A8V-E<W,@9F]R+@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)'!E<FT@("`@("`@(%1H92!L979E;"!O9B!P97)M:7-S:6]N<R!R97%U
M:7)E9"X*("`@("`J($!P87)A;2!M:7AE9"`@("1A='1R:6)U=&5S("!297-T
M<FEC="!T:&4@<VAA<F5S(&-O=6YT960@=&\@=&AO<V4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!M871C:&EN9R`D871T<FEB=71E<RX@
M06X@87)R87D@;V8*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A='1R:6)U=&4O=F%L=65S('!A:7)S(&]R(&$@<VAA<F4@;W=N97(*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!U<V5R;F%M92X*("`@
M("`J($!P87)A;2!S=')I;F<@("1P87)E;G0@("`@("!4:&4@<&%R96YT('-H
M87)E('1O('-T87)T('-E87)C:&EN9R!A="X*("`@("`J($!P87)A;2!B;V]L
M96%N("1A;&Q,979E;',@("!2971U<FX@86QL(&QE=F5L<RP@;W(@:G5S="!T
M:&4@9&ER96-T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M8VAI;&1R96X@;V8@)'!A<F5N=#\@1&5F875L=',@=&\@86QL(&QE=F5L<RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@($YU;6)E<B!O9B!S:&%R
M97,@=&AE('5S97(@:&%S(&%C8V5S<R!T;RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@8V]U;G13:&%R97,H)'5S97)I9"P@)'!E<FT@/2!015)-4U]32$]7+"`D
M871T<FEB=71E<R`](&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`D
M<&%R96YT(#T@1$%40512145?4D]/5"P@)&%L;$QE=F5L<R`]('1R=64I"B`@
M("!["B`@("`@("`@)&ME>2`]('-E<FEA;&EZ92AA<G)A>2@D=&AI<RT^7V%P
M<"P@)'5S97)I9"P@)'!E<FTL("1A='1R:6)U=&5S+"`D<&%R96YT+"`D86QL
M3&5V96QS+"`G8V]U;G0G*2D["B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?
M;&ES=&-A8VAE6R1K97E=*2D@>PH@("`@("`@("`@("`D8W)I=&5R:6$@/2`D
M=&AI<RT^9V5T4VAA<F5#<FET97)I82@D=7-E<FED+"`D<&5R;2P@)&%T=')I
M8G5T97,I.PH@("`@("`@("`@("`D=&AI<RT^7VQI<W1C86-H95LD:V5Y72`]
M("1T:&ES+3Y?9&%T871R964M/F-O=6YT0GE!='1R:6)U=&5S*"1C<FET97)I
M82P@)'!A<F5N="P@)&%L;$QE=F5L<RP@)VED)RD["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)'1H:7,M/E]L:7-T8V%C:&5;)&ME>5T["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&%R<F%Y(&]F(&%L;"!S:&%R97,@
M=&AA="`D=7-E<FED(&AA<R!A8V-E<W,@=&\N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`@)'5S97)I9"`@("`@("!4:&4@=7-E<FED(&]F('1H92!U
M<V5R('1O(&-H96-K(&%C8V5S<R!F;W(N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D<&5R;2`@("`@("`@(%1H92!L979E;"!O9B!P97)M:7-S:6]N<R!R97%U
M:7)E9"X*("`@("`J($!P87)A;2!M:7AE9"`@("1A='1R:6)U=&5S("`@4F5S
M=')I8W0@=&AE('-H87)E<R!C;W5N=&5D('1O('1H;W-E"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&UA=&-H:6YG("1A='1R:6)U=&5S
M+B!!;B!A<G)A>2!O9@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A='1R:6)U=&4O=F%L=65S('!A:7)S(&]R(&$@<VAA<F4@;W=N97(*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=7-E<FYA;64N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<&%R96YT("`@("`@(%1H92!P87)E
M;G0@<VAA<F4@=&\@<W1A<G0@<V5A<F-H:6YG(&%T+@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)&%L;$QE=F5L<R`@("!2971U<FX@86QL(&QE=F5L<RP@;W(@
M:G5S="!T:&4@9&ER96-T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&-H:6QD<F5N(&]F("1P87)E;G0_($1E9F%U;'1S('1O(&%L;`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!L979E;',N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D9G)O;2`@("`@("`@(%1H92!S:&%R92!T
M;R!S=&%R="!L:7-T:6YG(&%T+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O
M=6YT("`@("`@("!4:&4@;G5M8F5R(&]F('-H87)E<R!T;R!R971U<FXN"B`@
M("`@*B!`<&%R86T@<W1R:6YG("`D<V]R=&)Y7VYA;64@($%T=')I8G5T92!N
M86UE('1O('5S92!F;W(@<V]R=&EN9RX*("`@("`J($!P87)A;2!S=')I;F<@
M("1S;W)T8GE?:V5Y("`@071T<FEB=71E(&ME>2!T;R!U<V4@9F]R('-O<G1I
M;F<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9&ER96-T:6]N("`@(%-O<G0@
M9&ER96-T:6]N.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#`@+2!A<V-E;F1I;F<*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`Q("T@9&5S8V5N9&EN9PH@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@(%1H92!S:&%R97,@=&AE('5S97(@:&%S(&%C8V5S<R!T;RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@)FQI<W13:&%R97,H)'5S97)I9"P@)'!E
M<FT@/2!015)-4U]32$]7+"`D871T<FEB=71E<R`](&YU;&PL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`D<&%R96YT(#T@1$%40512145?4D]/5"P@)&%L
M;$QE=F5L<R`]('1R=64L("1F<F]M(#T@,"P*("`@("`@("`@("`@("`@("`@
M("`@("`@("1C;W5N="`](#`L("1S;W)T8GE?;F%M92`](&YU;&PL("1S;W)T
M8GE?:V5Y(#T@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("1D:7)E
M8W1I;VX@/2`P*0H@("`@>PH@("`@("`@("1K97D@/2!S97)I86QI>F4H87)R
M87DH)'1H:7,M/E]A<'`L("1U<V5R:60L("1P97)M+"`D871T<FEB=71E<RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P87)E;G0L("1A;&Q,
M979E;',L("1F<F]M+"`D8V]U;G0L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<V]R=&)Y7VYA;64L("1S;W)T8GE?:V5Y+"`D9&ER96-T:6]N
M*2D["B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?;&ES=&-A8VAE6R1K97E=
M*2D@>PH@("`@("`@("`@("`D8W)I=&5R:6$@/2`D=&AI<RT^9V5T4VAA<F5#
M<FET97)I82@D=7-E<FED+"`D<&5R;2P@)&%T=')I8G5T97,I.PH@("`@("`@
M("`@("`D<VAA<F5L:7-T(#T@)'1H:7,M/E]D871A=')E92T^9V5T0GE!='1R
M:6)U=&5S*`H@("`@("`@("`@("`@("`@)&-R:71E<FEA+"`D<&%R96YT+"`D
M86QL3&5V96QS+"`G:60G+"`D9G)O;2P@)&-O=6YT+`H@("`@("`@("`@("`@
M("`@)'-O<G1B>5]N86UE+"`D<V]R=&)Y7VME>2P@)&1I<F5C=&EO;BD["B`@
M("`@("`@("`@(&EF("AI<U]A*"1S:&%R96QI<W0L("=014%27T5R<F]R)RD@
M?'P@(6-O=6YT*"1S:&%R96QI<W0I*2!["B`@("`@("`@("`@("`@("`O*B!)
M9B!W92!G;W0@8F%C:R!A;B!E<G)O<B!O<B!A;B!E;7!T>2!A<G)A>2P@<&%S
M<R!I="!B86-K('1O"B`@("`@("`@("`@("`@("`@*B!T:&4@8V%L;&5R+B`J
M+PH@("`@("`@("`@("`@("`@<F5T=7)N("1S:&%R96QI<W0["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("\J($UA:V4@<W5R92!G9713:&%R97,H*2!D
M:61N)W0@<F5T=7)N(&%N(&5R<F]R+B`J+PH@("`@("`@("`@("`D<VAA<F5S
M(#T@)B1T:&ES+3YG9713:&%R97,H87)R87E?:V5Y<R@D<VAA<F5L:7-T*2D[
M"B`@("`@("`@("`@(&EF("AI<U]A*"1S:&%R97,L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D<VAA<F5S.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`D=&AI<RT^7VQI<W1C86-H95LD:V5Y72`]("8D
M<VAA<F5S.PH@("`@("`@("`@("`D=&AI<RT^7W-O<G1,:7-T(#T@)'1H:7,M
M/E]L:7-T8V%C:&5;)&ME>5T["B`@("`@("`@("`@('5A<V]R="@D=&AI<RT^
M7VQI<W1C86-H95LD:V5Y72P@87)R87DH)'1H:7,L("=?<V]R=%-H87)E<R<I
M*3L*("`@("`@("`@("`@)'1H:7,M/E]S;W)T3&ES="`](&YU;&P["B`@("`@
M("`@?0H*("`@("`@("`D<F5S=6QT(#T@2&]R9&4Z.F-A;&Q(;V]K*"=?:&]R
M9&5?:&]O:U]S:&%R95]L:7-T)RP@87)R87DH)'5S97)I9"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1P97)M+"`D871T<FEB=71E<RP@
M)'1H:7,M/E]L:7-T8V%C:&5;)&ME>5TI+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)VAO<F1E)RP@9F%L<V4I.PH@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M
M/E]L:7-T8V%C:&5;)&ME>5T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!,:7-T
M<R`J86QL*B!S:&%R97,@9F]R('1H92!C=7)R96YT(&%P<"]S:&%R92P@<F5G
M87)D;&5S<R!O9@H@("`@("H@<&5R;6ES<VEO;G,N(%1H:7,@:7,@9F]R(&%D
M;6EN(&9U;F-T:6]N86QI='D@86YD('-C<FEP=&EN9R!T;V]L<RP@86YD"B`@
M("`@*B!S:&]U;&1N)W0@8F4@8V%L;&5D(&9R;VT@=7-E<BUL979E;"!C;V1E
M(0H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1P87)E;G0@(%-T87)T
M('1H92!L:7-T:6YG(&%T(&$@8V5R=&%I;B!P;VEN="!I;B!T:&4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@('1R964N($1E9F%U;'1S('1O($1!
M5$%44D5%7U)/3U0L('1H92!R;V]T+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@($%L;"!S:&%R97,@9F]R('1H92!C=7)R96YT(&%P<"]S:&%R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=$%L;%-H87)E<R@D<&%R96YT(#T@
M1$%40512145?4D]/5"D*("`@('L*("`@("`@("`D<VAA<F5L:7-T(#T@)'1H
M:7,M/E]D871A=')E92T^9V5T*$1!5$%44D5%7T9/4DU!5%]&3$%4+"`D<&%R
M96YT+"!T<G5E*3L*("`@("`@("!I9B`H:7-?82@D<VAA<F5L:7-T+"`G4$5!
M4E]%<G)O<B<I('Q\("%C;W5N="@D<VAA<F5L:7-T*2D@>PH@("`@("`@("`@
M("`O+R!)9B!W92!G;W0@8F%C:R!A;B!E<G)O<B!O<B!A;B!E;7!T>2!A<G)A
M>2P@:G5S="!R971U<FX@:70N"B`@("`@("`@("`@(')E='5R;B`D<VAA<F5L
M:7-T.PH@("`@("`@('T*("`@("`@("!U;G-E="@D<VAA<F5L:7-T6R1P87)E
M;G1=*3L*"B`@("`@("`@)'-H87)E<R`]("8D=&AI<RT^9V5T4VAA<F5S*&%R
M<F%Y7VME>7,H)'-H87)E;&ES="DI.PH@("`@("`@(&EF("AI<U]A*"1S:&%R
M97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1S:&%R
M97,["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7W-O<G1,:7-T(#T@)'-H
M87)E<SL*("`@("`@("!U87-O<G0H)'-H87)E<RP@87)R87DH)'1H:7,L("=?
M<V]R=%-H87)E<R<I*3L*("`@("`@("`D=&AI<RT^7W-O<G1,:7-T(#T@;G5L
M;#L*"B`@("`@("`@<F5T=7)N("1S:&%R97,["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS(&%N(&%R<F%Y(&]F(&-R:71E<FEA(&9O<B!Q=65R>6EN
M9R!S:&%R97,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'5S97)I
M9"`@("`@(%1H92!U<V5R:60@;V8@=&AE('5S97(@=&\@8VAE8VL@86-C97-S
M(&9O<BX*("`@("`J($!P87)A;2!I;G1E9V5R("1P97)M("`@("`@("!4:&4@
M;&5V96P@;V8@<&5R;6ES<VEO;G,@<F5Q=6ER960N"B`@("`@*B!`<&%R86T@
M;6EX960@("`D871T<FEB=71E<R`@4F5S=')I8W0@=&AE('-H87)E<R!R971U
M<FYE9"!T;R!T:&]S92!W:&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!H879E('1H97-E(&%T=')I8G5T92!V86QU97,N"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&-R:71E<FEA('1R964@9F]R(&9E
M=&-H:6YG('1H:7,@=7-E<B=S('-H87)E<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T4VAA<F5#<FET97)I82@D=7-E<FED+"`D<&5R;2`](%!%4DU37U-(
M3U<L("1A='1R:6)U=&5S(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(65M
M<'1Y*"1U<V5R:60I*2!["B`@("`@("`@("`@("1C<FET97)I82`](&%R<F%Y
M*`H@("`@("`@("`@("`@("`@)T]2)R`]/B!A<G)A>2@*("`@("`@("`@("`@
M("`@("`@("`O+R`H;W=N97(@/3T@)'5S97)I9"D*("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@)T%.1"<@/3X@
M87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G9FEE
M;&0G(#T^("=N86UE)RP@)V]P)R`]/B`G/2<L("=T97-T)R`]/B`G;W=N97(G
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=F:65L9"<@
M/3X@)W9A;'5E)RP@)V]P)R`]/B`G/2<L("=T97-T)R`]/B`D=7-E<FED*2DI
M+`H*("`@("`@("`@("`@("`@("`@("`O+R`H;F%M92`]/2!P97)M7W5S97)S
M(&%N9"!K97D@/3T@)'5S97)I9"!A;F0@=F%L("8@)'!E<FTI"B`@("`@("`@
M("`@("`@("`@("`@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=!
M3D0G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)V9I96QD)R`]/B`G;F%M92<L("=O<"<@/3X@)STG+"`G=&5S="<@/3X@
M)W!E<FU?=7-E<G,G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*"=F:65L9"<@/3X@)VME>2<L("=O<"<@/3X@)STG+"`G=&5S="<@/3X@
M)'5S97)I9"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G
M9FEE;&0G(#T^("=V86QU92<L("=O<"<@/3X@)R8G+"`G=&5S="<@/3X@)'!E
M<FTI*2DL"@H@("`@("`@("`@("`@("`@("`@("\O("AN86UE(#T]('!E<FU?
M8W)E871O<B!A;F0@=F%L("8@)'!E<FTI"B`@("`@("`@("`@("`@("`@("`@
M87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=!3D0G(#T^(&%R<F%Y
M*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V9I96QD)R`]
M/B`G;F%M92<L("=O<"<@/3X@)STG+"`G=&5S="<@/3X@)W!E<FU?8W)E871O
M<B<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V9I96QD
M)R`]/B`G=F%L=64G+"`G;W`G(#T^("<F)RP@)W1E<W0G(#T^("1P97)M*2DI
M+`H*("`@("`@("`@("`@("`@("`@("`O+R`H;F%M92`]/2!P97)M7V1E9F%U
M;'0@86YD('9A;"`F("1P97)M*0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*`H@("`@("`@("`@("`@("`@("`@("`@("`G04Y$)R`]/B!A<G)A>2@*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=F:65L9"<@/3X@)VYA
M;64G+"`G;W`G(#T^("<])RP@)W1E<W0G(#T^("=P97)M7V1E9F%U;'0G*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=F:65L9"<@/3X@
M)W9A;'5E)RP@)V]P)R`]/B`G)B<L("=T97-T)R`]/B`D<&5R;2DI*2DI.PH*
M("`@("`@("`@("`@+R\@268@=&AE('5S97(@:&%S(&%N>2!G<F]U<"!M96UB
M97)S:&EP<RP@8VAE8VL@9F]R('1H;W-E(&%L<V\N"B`@("`@("`@("`@(')E
M<75I<F5?;VYC92`G2&]R9&4O1W)O=7`N<&AP)SL*("`@("`@("`@("`@)&=R
M;W5P(#T@)D=R;W5P.CIS:6YG;&5T;VXH*3L*("`@("`@("`@("`@)&=R;W5P
M<R`]("1G<F]U<"T^9V5T1W)O=7!-96UB97)S:&EP<R@D=7-E<FED+"!T<G5E
M*3L*("`@("`@("`@("`@:68@*"%I<U]A*"1G<F]U<',L("=014%27T5R<F]R
M)RD@)B8@8V]U;G0H)&=R;W5P<RDI('L*("`@("`@("`@("`@("`@("\O("AN
M86UE(#T]('!E<FU?9W)O=7!S(&%N9"!K97D@:6X@*"1G<F]U<',I(&%N9"!V
M86P@)B`D<&5R;2D*("`@("`@("`@("`@("`@("1C<FET97)I85LG3U(G75M=
M(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)T%.1"<@/3X@87)R87DH
M"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=F:65L9"<@/3X@)VYA
M;64G+"`G;W`G(#T^("<])RP@)W1E<W0G(#T^("=P97)M7V=R;W5P<R<I+`H@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G9FEE;&0G(#T^("=K97DG
M+"`G;W`G(#T^("=)3B<L("=T97-T)R`]/B!A<G)A>5]K97ES*"1G<F]U<',I
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V9I96QD)R`]/B`G
M=F%L=64G+"`G;W`G(#T^("<F)RP@)W1E<W0G(#T^("1P97)M*2DI.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&-R:71E
M<FEA(#T@87)R87DH"B`@("`@("`@("`@("`@("`G04Y$)R`]/B!A<G)A>2@*
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)V9I96QD)R`]/B`G;F%M92<L
M("=O<"<@/3X@)STG+"`G=&5S="<@/3X@)W!E<FU?9W5E<W0G*2P*("`@("`@
M("`@("`@("`@("`@("`@87)R87DH)V9I96QD)R`]/B`G=F%L=64G+"`G;W`G
M(#T^("<F)RP@)W1E<W0G(#T^("1P97)M*2DI.PH@("`@("`@('T*"B`@("`@
M("`@:68@*&ES7V%R<F%Y*"1A='1R:6)U=&5S*2D@>PH@("`@("`@("`@("`O
M+R!"=6EL9"!A='1R:6)U=&4O:V5Y(&9I;'1E<BX*("`@("`@("`@("`@9F]R
M96%C:"`H)&%T=')I8G5T97,@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@
M("`@("`@("`@("1C<FET97)I82`](&%R<F%Y*`H@("`@("`@("`@("`@("`@
M("`@("=!3D0G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`D
M8W)I=&5R:6$L"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)TI/24XG(#T^(&%R<F%Y*`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=!3D0G(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G9FEE
M;&0G(#T^("=N86UE)RP@)V]P)R`]/B`G/2<L("=T97-T)R`]/B`D:V5Y*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V9I
M96QD)R`]/B`G=F%L=64G+"`G;W`G(#T^("<])RP@)W1E<W0G(#T^("1V86QU
M92DI*2DI*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS96EF("@A96UP
M='DH)&%T=')I8G5T97,I*2!["B`@("`@("`@("`@("\O(%)E<W1R:6-T('1O
M('-H87)E<R!O=VYE9"!B>2!T:&4@=7-E<B!S<&5C:69I960@:6X@=&AE"B`@
M("`@("`@("`@("\O("1A='1R:6)U=&5S('-T<FEN9RX*("`@("`@("`@("`@
M)&-R:71E<FEA(#T@87)R87DH"B`@("`@("`@("`@("`@("`G04Y$)R`]/B!A
M<G)A>2@*("`@("`@("`@("`@("`@("`@("`D8W)I=&5R:6$L"B`@("`@("`@
M("`@("`@("`@("`@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=*
M3TE.)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*"=F:65L9"<@/3X@)VYA;64G+"`G;W`G(#T^("<])RP@)W1E<W0G(#T^
M("=O=VYE<B<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH
M)V9I96QD)R`]/B`G=F%L=64G+"`G;W`G(#T^("<])RP@)W1E<W0G(#T^("1A
M='1R:6)U=&5S*2DI*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-R
M:71E<FEA.PH@("`@?0H*("`@("\J*@H@("`@("H@5$]$3PH@("`@("H*("`@
M("`J($!S964@4&5R;7,Z.F=E=%!E<FUI<W-I;VYS"B`@("`@*@H@("`@("H@
M0'!A<F%M(%1/1$\*("`@("`J($!P87)A;2!43T1/"B`@("`@*@H@("`@("H@
M0')E='5R;B!43T1/"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!E<FUI<W-I
M;VYS*"1S:&%R92P@)'5S97(@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A
M:7-?82@D<VAA<F4L("=$871A5')E94]B:F5C=%]3:&%R92<I*2!["B`@("`@
M("`@("`@("1S:&%R92`]("8D=&AI<RT^9V5T4VAA<F4H)'-H87)E*3L*("`@
M("`@("!]"@H@("`@("`@("1P97)M(#T@)B1S:&%R92T^9V5T4&5R;6ES<VEO
M;B@I.PH@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG<&5R;7,G72T^9V5T4&5R
M;6ES<VEO;G,H)'!E<FTL("1U<V5R*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=&AE($ED96YT:71Y(&9O<B!A('!A<G1I8W5L87(@<VAA<F4@
M;W=N97(N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1S:&%R92`@5&AE
M('-H87)E('1O(&9E=&-H('1H92!)9&5N=&ET>2!F;W(@+2!E:71H97(@=&AE
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!S=')I;F<@;F%M92P@;W(@
M=&AE($1A=&%4<F5E3V)J96-T7U-H87)E(&]B:F5C="X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE('!R969E<F5N8V4G<R!V86QU92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@)F=E=$ED96YT:71Y0GE3:&%R92@D<VAA<F4I
M"B`@("!["B`@("`@("`@:68@*"%I<U]A*"1S:&%R92P@)T1A=&%4<F5E3V)J
M96-T7U-H87)E)RDI('L*("`@("`@("`@("`@)'-H87)E(#T@)'1H:7,M/F=E
M=%-H87)E*"1S:&%R92D["B`@("`@("`@("`@(&EF("AI<U]A*"1S:&%R92P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&YU;&P[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E<75I<F5?;VYC
M92`G2&]R9&4O261E;G1I='DN<&AP)SL*("`@("`@("`D;W=N97(@/2`D<VAA
M<F4M/F=E="@G;W=N97(G*3L*("`@("`@("!R971U<FX@)')E="`]("9)9&5N
M=&ET>3HZ<VEN9VQE=&]N*"=N;VYE)RP@)&]W;F5R*3L*("`@('T*"GT*"B\J
M*@H@*B!%>'1E;G-I;VX@;V8@=&AE($1A=&%4<F5E3V)J96-T(&-L87-S(&9O
M<B!S=&]R:6YG(%-H87)E(&EN9F]R;6%T:6]N(&EN('1H90H@*B!$871A5')E
M92!D<FEV97(N($EF('EO=2!W86YT('1O('-T;W)E('-P96-I86QI>F5D(%-H
M87)E(&EN9F]R;6%T:6]N+"!Y;W4*("H@<VAO=6QD(&5X=&5N9"!T:&ES(&-L
M87-S(&EN<W1E860@;V8@97AT96YD:6YG($1A=&%4<F5E3V)J96-T(&1I<F5C
M=&QY+@H@*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T
M;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA
M9V4@2&]R9&5?4VAA<F4*("HO"F-L87-S($1A=&%4<F5E3V)J96-T7U-H87)E
M(&5X=&5N9',@1&%T851R965/8FIE8W0@>PH*("`@("\J*@H@("`@("H@5&AE
M($AO<F1E7U-H87)E(&]B:F5C="!W:&EC:"!T:&ES('-H87)E(&-A;64@9G)O
M;2`M(&YE961E9"!F;W(*("`@("`J('5P9&%T:6YG(&1A=&$@:6X@=&AE(&)A
M8VME;F0@=&\@;6%K92!C:&%N9V5S('-T:6-K+"!E=&,N"B`@("`@*@H@("`@
M("H@0'9A<B!(;W)D95]3:&%R90H@("`@("HO"B`@("!V87(@)%]S:&%R94]B
M.PH*("`@("\J*@H@("`@("H@5&AE($1A=&%4<F5E3V)J96-T7U-H87)E(&-O
M;G-T<G5C=&]R+B!*=7-T(&UA:V5S('-U<F4@=&\@8V%L;"!T:&4@<&%R96YT
M"B`@("`@*B!C;VYS=')U8W1O<B!S;R!T:&%T('1H92!S:&%R92=S(&YA;64@
M:7,@<V5T('!R;W!E<FQY+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&ED("!4:&4@:60@;V8@=&AE('-H87)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!$871A5')E94]B:F5C=%]3:&%R92@D:60I"B`@("!["B`@("`@("`@<&%R
M96YT.CI$871A5')E94]B:F5C="@D:60I.PH@("`@("`@(&EF("AI<U]N=6QL
M*"1T:&ES+3YD871A*2D@>PH@("`@("`@("`@("`D=&AI<RT^9&%T82`](&%R
M<F%Y*"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@07-S;V-I
M871E<R!A(%-H87)E(&]B:F5C="!W:71H('1H:7,@<VAA<F4N"B`@("`@*@H@
M("`@("H@0'!A<F%M($AO<F1E7U-H87)E("1S:&%R94]B("!4:&4@4VAA<F4@
M;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!S9713:&%R94]B*"8D<VAA
M<F5/8BD*("`@('L*("`@("`@("`D=&AI<RT^7W-H87)E3V(@/2`F)'-H87)E
M3V(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H:7,@<VAA<F4G
M<R!P87)E;G0@;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@1&%T851R
M965/8FIE8W1?4VAA<F4@(%1H92!P87)E;G0@<VAA<F4L(&EF(&ET(&5X:7-T
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=%!A<F5N="@I"B`@("!["B`@
M("`@("`@)'!A<F5N="`]("1T:&ES+3Y?<VAA<F5/8BT^9V5T4&%R96YT*"1T
M:&ES*3L*("`@("`@("!R971U<FX@)'!A<F5N=#L*("`@('T*"B`@("`O*BH*
M("`@("`J($=I=F5S(&$@=7-E<B!A(&-E<G1A:6X@<')I=FEL96=E(&9O<B!T
M:&ES('-H87)E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97)I
M9"`@("`@("!4:&4@=7-E<FED(&]F('1H92!U<V5R+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)'!E<FUI<W-I;VX@($$@4$5235-?*B!C;VYS=&%N="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@861D57-E<E!E<FUI<W-I;VXH)'5S97)I9"P@
M)'!E<FUI<W-I;VXI"B`@("!["B`@("`@("`@)'!E<FT@/2`F)'1H:7,M/F=E
M=%!E<FUI<W-I;VXH*3L*("`@("`@("`D<&5R;2T^861D57-E<E!E<FUI<W-I
M;VXH)'5S97)I9"P@)'!E<FUI<W-I;VXL(&9A;'-E*3L*("`@("`@("`D=&AI
M<RT^<V5T4&5R;6ES<VEO;B@D<&5R;2D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!296UO=F5S(&$@8V5R=&%I;B!P<FEV:6QE9V4@9F]R(&$@=7-E<B!F<F]M
M('1H:7,@<VAA<F4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E
M<FED("`@("`@(%1H92!U<V5R:60@;V8@=&AE('5S97(N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D<&5R;6ES<VEO;B`@02!015)-4U\J(&-O;G-T86YT+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F55<V5R4&5R;6ES<VEO;B@D=7-E
M<FED+"`D<&5R;6ES<VEO;BD*("`@('L*("`@("`@("`D<&5R;2`]("8D=&AI
M<RT^9V5T4&5R;6ES<VEO;B@I.PH@("`@("`@("1P97)M+3YR96UO=F55<V5R
M4&5R;6ES<VEO;B@D=7-E<FED+"`D<&5R;6ES<VEO;BP@9F%L<V4I.PH@("`@
M("`@("1T:&ES+3YS971097)M:7-S:6]N*"1P97)M*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($=I=F5S(&$@9W)O=7`@8V5R=&%I;B!P<FEV:6QE9V5S(&9O
M<B!T:&ES('-H87)E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&=R
M;W5P("`@("`@("!4:&4@9W)O=7`@=&\@861D('!E<FUI<W-I;VYS(&9O<BX*
M("`@("`J($!P87)A;2!I;G1E9V5R("1P97)M:7-S:6]N("!!(%!%4DU37RH@
M8V]N<W1A;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$=R;W5P4&5R;6ES
M<VEO;B@D9W)O=7`L("1P97)M:7-S:6]N*0H@("`@>PH@("`@("`@("1P97)M
M(#T@)B1T:&ES+3YG971097)M:7-S:6]N*"D["B`@("`@("`@)'!E<FTM/F%D
M9$=R;W5P4&5R;6ES<VEO;B@D9W)O=7`L("1P97)M:7-S:6]N+"!F86QS92D[
M"B`@("`@("`@)'1H:7,M/G-E=%!E<FUI<W-I;VXH)'!E<FTI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5M;W9E<R!A(&-E<G1A:6X@<')I=FEL96=E(&9R
M;VT@82!G<F]U<"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1G<F]U
M<"`@("`@("`@(%1H92!G<F]U<"!T;R!R96UO=F4@<&5R;6ES<VEO;G,@9G)O
M;2X*("`@("`J($!P87)A;2!C;VYS=&%N="`D<&5R;6ES<VEO;B`@02!015)-
M4U\J(&-O;G-T86YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F5'<F]U
M<%!E<FUI<W-I;VXH)&=R;W5P+"`D<&5R;6ES<VEO;BD*("`@('L*("`@("`@
M("`D<&5R;2`]("8D=&AI<RT^9V5T4&5R;6ES<VEO;B@I.PH@("`@("`@("1P
M97)M+3YR96UO=F5'<F]U<%!E<FUI<W-I;VXH)&=R;W5P+"`D<&5R;6ES<VEO
M;BP@9F%L<V4I.PH@("`@("`@("1T:&ES+3YS971097)M:7-S:6]N*"1P97)M
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!T;R!S964@:68@82!U
M<V5R(&AA<R!A(&=I=F5N('!E<FUI<W-I;VXN"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=7-E<FED("`@("`@(%1H92!U<V5R:60@;V8@=&AE('5S
M97(N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<&5R;6ES<VEO;B`@02!015)-
M4U\J(&-O;G-T86YT('1O('1E<W0@9F]R+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D8W)E871O<B`@("`@(%1H92!C<F5A=&]R(&]F('1H92!E=F5N="X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T("1U
M<V5R:60@:&%S("1P97)M:7-S:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!H
M87-097)M:7-S:6]N*"1U<V5R:60L("1P97)M:7-S:6]N+"`D8W)E871O<B`]
M(&YU;&PI"B`@("!["B`@("`@("`@:68@*"1U<V5R:60@/3T@)'1H:7,M/F=E
M="@G;W=N97(G*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG<&5R;7,G72T^:&%S4&5R
M;6ES<VEO;B@D=&AI<RT^9V5T4&5R;6ES<VEO;B@I+"`D=7-E<FED+"`D<&5R
M;6ES<VEO;BP@)&-R96%T;W(I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5M
M;W9E<R!A('5S97(@9G)O;2!T:&ES('-H87)E+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'5S97)I9"`@5&AE('5S97)I9"!O9B!T:&4@=7-E<B!T
M;R!R96UO=F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V955S97(H)'5S
M97)I9"D*("`@('L*("`@("`@("`O*B!296UO=F4@86QL("1U<V5R:60G<R!P
M97)M:7-S:6]N<RX@*B\*("`@("`@("`D<&5R;2`]("8D=&AI<RT^9V5T4&5R
M;6ES<VEO;B@I.PH@("`@("`@("1P97)M+3YR96UO=F55<V5R4&5R;6ES<VEO
M;B@D=7-E<FED+"!015)-4U]32$]7+"!F86QS92D["B`@("`@("`@)'!E<FTM
M/G)E;6]V955S97)097)M:7-S:6]N*"1U<V5R:60L(%!%4DU37U)%040L(&9A
M;'-E*3L*("`@("`@("`D<&5R;2T^<F5M;W9E57-E<E!E<FUI<W-I;VXH)'5S
M97)I9"P@4$5235-?141)5"P@9F%L<V4I.PH@("`@("`@("1P97)M+3YR96UO
M=F55<V5R4&5R;6ES<VEO;B@D=7-E<FED+"!015)-4U]$14Q%5$4L(&9A;'-E
M*3L*("`@("`@("!R971U<FX@)'1H:7,M/G-E=%!E<FUI<W-I;VXH)'!E<FTI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E<R!A(&=R;W5P(&9R;VT@
M=&AI<R!S:&%R92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9W)O
M=7!)9"`@5&AE(&=R;W5P('1O(')E;6]V92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F5M;W9E1W)O=7`H)&=R;W5P260I"B`@("!["B`@("`@("`@+RH@4F5M
M;W9E(&%L;"`D9W)O=7!)9"=S('!E<FUI<W-I;VYS+B`J+PH@("`@("`@("1P
M97)M(#T@)B1T:&ES+3YG971097)M:7-S:6]N*"D["B`@("`@("`@)'!E<FTM
M/G)E;6]V94=R;W5P4&5R;6ES<VEO;B@D9W)O=7!)9"P@4$5235-?4TA/5RP@
M9F%L<V4I.PH@("`@("`@("1P97)M+3YR96UO=F5'<F]U<%!E<FUI<W-I;VXH
M)&=R;W5P260L(%!%4DU37U)%040L(&9A;'-E*3L*("`@("`@("`D<&5R;2T^
M<F5M;W9E1W)O=7!097)M:7-S:6]N*"1G<F]U<$ED+"!015)-4U]%1$E4+"!F
M86QS92D["B`@("`@("`@)'!E<FTM/G)E;6]V94=R;W5P4&5R;6ES<VEO;B@D
M9W)O=7!)9"P@4$5235-?1$5,151%+"!F86QS92D["B`@("`@("`@<F5T=7)N
M("1T:&ES+3YS971097)M:7-S:6]N*"1P97)M*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@86X@87)R87D@8V]N=&%I;FEN9R!A;&P@=&AE('5S
M97)I9',@;V8@=&AE('5S97)S('=I=&@@86-C97-S('1O"B`@("`@*B!T:&ES
M('-H87)E+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1P97)M7VQE
M=F5L("!,:7-T(&]N;'D@=7-E<G,@=VET:"!T:&ES('!E<FUI<W-I;VX@;&5V
M96PN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1&5F875L
M=',@=&\@86QL('5S97)S+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M(%1H92!U<V5R<R!W:71H(&%C8V5S<R!T;R!T:&ES('-H87)E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!L:7-T57-E<G,H)'!E<FU?;&5V96P@/2!N=6QL*0H@
M("`@>PH@("`@("`@("1P97)M(#T@)B1T:&ES+3YG971097)M:7-S:6]N*"D[
M"B`@("`@("`@<F5T=7)N(&%R<F%Y7VME>7,H)'!E<FTM/F=E=%5S97)097)M
M:7-S:6]N<R@D<&5R;5]L979E;"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!A;B!A<G)A>2!C;VYT86EN:6YG(&%L;"!T:&4@9W)O=7!I9',@
M;V8@=&AE(&=R;W5P<R!W:71H(&%C8V5S<PH@("`@("H@=&\@=&AI<R!S:&%R
M92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<&5R;5]L979E;"`@
M3&ES="!O;FQY('5S97)S('=I=&@@=&AI<R!P97)M:7-S:6]N(&QE=F5L+@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@($1E9F%U;'1S('1O
M(&%L;"!U<V5R<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@
M241S(&]F('1H92!G<F]U<',@=VET:"!A8V-E<W,@=&\@=&AI<R!S:&%R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=$=R;W5P<R@D<&5R;5]L979E;"`]
M(&YU;&PI"B`@("!["B`@("`@("`@)'!E<FT@/2`F)'1H:7,M/F=E=%!E<FUI
M<W-I;VXH*3L*("`@("`@("!R971U<FX@87)R87E?:V5Y<R@D<&5R;2T^9V5T
M1W)O=7!097)M:7-S:6]N<R@D<&5R;5]L979E;"DI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@5$]$3PH@("`@("H*("`@("`J($!P87)A;2!43T1/"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D=7!D871E("!43T1/"B`@("`@*@H@("`@("H@
M0')E='5R;B!43T1/"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%!E<FUI<W-I
M;VXH)B1P97)M+"`D=7!D871E(#T@=')U92D*("`@('L*("`@("`@("`D=&AI
M<RT^9&%T85LG<&5R;2==(#T@)'!E<FTM/F=E=$1A=&$H*3L*("`@("`@("!I
M9B`H)'5P9&%T92D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G-A=F4H
M*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!43T1/"B`@("`@*@H@("`@("H@0')E='5R;B!43T1/"B`@
M("`@*B\*("`@(&9U;F-T:6]N("9G971097)M:7-S:6]N*"D*("`@('L*("`@
M("`@("`D<&5R;2`]("9N97<@1&%T851R965/8FIE8W1?4&5R;6ES<VEO;B@D
M=&AI<RT^9V5T3F%M92@I*3L*("`@("`@("`D<&5R;2T^9&%T82`](&ES<V5T
M*"1T:&ES+3YD871A6R=P97)M)UTI(#\@)'1H:7,M/F1A=&%;)W!E<FTG72`Z
M(&%R<F%Y*"D["@H@("`@("`@(')E='5R;B`D<&5R;3L*("`@('T*"B`@("`O
M*BH*("`@("`J($9O<F-E<R!A;&P@8VAI;&1R96X@;V8@=&AI<R!S:&%R92!T
M;R!I;FAE<FET('1H92!P97)M:7-S:6]N<R!S970@;VX@=&AI<PH@("`@("H@
M<VAA<F4N"B`@("`@*@H@("`@("H@0')E='5R;B!43T1/"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&EN:&5R:71097)M:7-S:6]N<R@I"B`@("!["B`@("`@("`@
M)'!E<FT@/2`F)'1H:7,M/F=E=%!E<FUI<W-I;VXH*3L*("`@("`@("`D8VAI
M;&1R96X@/2`D=&AI<RT^7W-H87)E3V(M/FQI<W1!;&Q3:&%R97,H)'1H:7,M
M/F=E=$YA;64H*2D["B`@("`@("`@:68@*&ES7V$H)&-H:6QD<F5N+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D8VAI;&1R96X["B`@
M("`@("`@?0H*("`@("`@("!F;W)E86-H("@D8VAI;&1R96X@87,@)&-H:6QD
M*2!["B`@("`@("`@("`@("1C:&EL9"T^<V5T4&5R;6ES<VEO;B@D<&5R;2D[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-A=F5S(&%N>2!C:&%N9V5S('1O('1H:7,@;V)J96-T('1O
M('1H92!B86-K96YD('!E<FUA;F5N=&QY+B!.97<@;V)J96-T<PH@("`@("H@
M87)E(&%D9&5D(&EN<W1E860N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M96%N('P@4$5!4E]%<G)O<B`@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S879E*"D*("`@('L*("`@("`@("`D<F5S=6QT
M(#T@2&]R9&4Z.F-A;&Q(;V]K*"=?:&]R9&5?:&]O:U]S:&%R95]M;V1I9GDG
M+"!A<G)A>2@D=&AI<RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G:&]R9&4G+"!F86QS92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!P87)E;G0Z.G-A=F4H*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($UA<',@=&AI<R!O8FIE8W0G<R!A='1R
M:6)U=&5S(&9R;VT@=&AE(&1A=&$@87)R87D@:6YT;R!A(&9O<FUA="!T:&%T
M('=E"B`@("`@*B!C86X@<W1O<F4@:6X@=&AE(&%T=')I8G5T97,@<W1O<F%G
M92!B86-K96YD+@H@("`@("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@
M("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'!E<FUS;VYL>2`@3VYL>2!P
M<F]C97-S('!E<FUI<W-I;VYS/R!,971S('-U8F-L87-S97,*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&]V97)R:61E('!A<G0@;V8@=&AI
M<R!M971H;V0@=VAI;&4@:&%N9&QI;F<*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('1H96ER(&%D9&ET:6]N86P@871T<FEB=71E<R!S97!E
M<F%T96QY+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!A='1R
M:6)U=&5S(&%R<F%Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=&]!='1R:6)U
M=&5S*"1P97)M<V]N;'D@/2!F86QS92D*("`@('L*("`@("`@("`O+R!$969A
M=6QT('1O(&YO(&%T=')I8G5T97,N"B`@("`@("`@)&%T=')I8G5T97,@/2!A
M<G)A>2@I.PH*("`@("`@("!F;W)E86-H("@D=&AI<RT^9&%T82!A<R`D:V5Y
M(#T^("1V86QU92D@>PH@("`@("`@("`@("!I9B`H)&ME>2`]/2`G<&5R;2<I
M('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1V86QU92!A<R`D='EP92`]
M/B`D<&5R;7,I('L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH
M)'!E<FUS*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D
M<&5R;7,@87,@)&UE;6)E<B`]/B`D<&5R;2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&%T=')I8G5T97-;72`](&%R<F%Y*"=N86UE)R`]/B`G
M<&5R;5\G("X@)'1Y<&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)VME>2<@/3X@)&UE;6)E<BP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M=F%L=64G(#T^("1P97)M*3L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1A='1R:6)U=&5S6UT@/2!A<G)A>2@G;F%M92<@/3X@)W!E<FU?
M)R`N("1T>7!E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)VME>2<@/3X@)R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G=F%L=64G(#T^("1P97)M<RD[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!](&5L<V5I9B`H(21P97)M<V]N;'DI('L*("`@("`@("`@("`@
M("`@("1A='1R:6)U=&5S6UT@/2!A<G)A>2@G;F%M92<@/3X@)&ME>2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:V5Y)R`]/B`G
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=F%L
M=64G(#T^("1V86QU92D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D871T<FEB=71E<SL*("`@('T*"B`@("`O*BH*("`@("`J
M(%1A:V5S(&EN(&$@;&ES="!O9B!A='1R:6)U=&5S(&9R;VT@=&AE(&)A8VME
M;F0@86YD(&UA<',@:70@=&\@;W5R"B`@("`@*B!I;G1E<FYA;"!D871A(&%R
M<F%Y+@H@("`@("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1A='1R:6)U=&5S("`@5&AE(&QI<W0@;V8@
M871T<FEB=71E<R!F<F]M('1H92!B86-K96YD"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`H871T<FEB=71E(&YA;64L(&ME>2P@86YD('9A
M;'5E*2X*("`@("`J($!P87)A;2!B;V]L96%N("1P97)M<V]N;'D@($]N;'D@
M<')O8V5S<R!P97)M:7-S:6]N<S\@3&5T<R!S=6)C;&%S<V5S"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!O=F5R<FED92!P87)T(&]F('1H
M:7,@;65T:&]D('=H:6QE(&AA;F1L:6YG"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!T:&5I<B!A9&1I=&EO;F%L(&%T=')I8G5T97,@<V5P
M97)A=&5L>2X*("`@("`J+PH@("`@9G5N8W1I;VX@7V9R;VU!='1R:6)U=&5S
M*"1A='1R:6)U=&5S+"`D<&5R;7-O;FQY(#T@9F%L<V4I"B`@("!["B`@("`@
M("`@+R\@26YI=&EA;&EZ92!D871A(&%R<F%Y+@H@("`@("`@("1T:&ES+3YD
M871A6R=P97)M)UT@/2!A<G)A>2@I.PH*("`@("`@("!F;W)E86-H("@D871T
M<FEB=71E<R!A<R`D871T<BD@>PH@("`@("`@("`@("!I9B`H<W5B<W1R*"1A
M='1R6R=N86UE)UTL(#`L(#0I(#T]("=P97)M)RD@>PH@("`@("`@("`@("`@
M("`@:68@*"%E;7!T>2@D871T<ELG:V5Y)UTI*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/F1A=&%;)W!E<FTG75MS=6)S='(H)&%T=');)VYA;64G
M72P@-2E=6R1A='1R6R=K97DG75T@/2`D871T<ELG=F%L=64G73L*("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/F1A=&%;)W!E<FTG75MS=6)S='(H)&%T=');)VYA;64G72P@-2E=(#T@)&%T
M=');)W9A;'5E)UT["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@
M96QS96EF("@A)'!E<FUS;VYL>2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/F1A=&%;)&%T=');)VYA;64G75T@/2`D871T<ELG=F%L=64G73L*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@('T*"GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92]-24U%+G!H<```````````````````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`V-S$V-B`Q,#4Q-30S,S<T,"`P,C`V,C0`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M"B\J(%=E(&YE960@=&\@*'5N9F]R='5N871E;'DI(&AA<F0@8V]D92!T:&5S
M92!C;VYS=&%N=',@8F5C875S92!T:&5Y(')E<VED92!I;@H@*B!T:&4@:6UA
M<"!M;V1U;&4L('=H:6-H(&ES(&YO="!R97%U:7)E9"!F;W(@2&]R9&4N"B`J
M(%1H97-E(&-O;G-T86YT<R!A<F4@9F]U;F0@:6X@=&AE(%57+6EM87`@8RUC
M;&EE;G0@9&ES=')I8G5T:6]N.@H@*B`@(&9T<#HO+V9T<"YC86,N=V%S:&EN
M9W1O;BYE9'4O:6UA<"\*("H@5&AE(&-O;G-T86YT<R!A<'!E87(@:6X@=&AE
M(&9I;&4@:6YC;'5D92]M86EL+F@@*B\*<F5Q=6ER95]O;F-E("=(;W)D92]5
M=&EL+G!H<"<["FEF("@A571I;#HZ97AT96YS:6]N17AI<W1S*"=I;6%P)RDI
M('L*("`@("\J(%!R:6UA<GD@8F]D>2!T>7!E<R`J+PH@("`@9&5F:6YE*"=4
M65!%5$585"<L(#`I.PH@("`@9&5F:6YE*"=465!%355,5$E005)4)RP@,2D[
M"B`@("!D969I;F4H)U194$5-15-304=%)RP@,BD["B`@("!D969I;F4H)U19
M4$5!4%!,24-!5$E/3B<L(#,I.PH@("`@9&5F:6YE*"=465!%055$24\G+"`T
M*3L*("`@(&1E9FEN92@G5%E014E-04=%)RP@-2D["B`@("!D969I;F4H)U19
M4$56241%3R<L(#8I.PH@("`@9&5F:6YE*"=465!%3U1(15(G+"`X*3L*"B`@
M("`O*B!";V1Y(&5N8V]D:6YG<R`J+PH@("`@9&5F:6YE*"=%3D,W0DE4)RP@
M,"D["B`@("!D969I;F4H)T5.0SA"250G+"`Q*3L*("`@(&1E9FEN92@G14Y#
M0DE.05)9)RP@,BD["B`@("!D969I;F4H)T5.0T)!4T4V-"<L(#,I.PH@("`@
M9&5F:6YE*"=%3D-154]414104DE.5$%"3$4G+"`T*3L*("`@(&1E9FEN92@G
M14Y#3U1(15(G+"`U*3L*?0H*+RHJ"B`J($]L9&5R('9E<G-I;VYS(&]F(%!(
M4"=S(&EM87`@97AT96YS:6]N(&1O;B=T(&1E9FEN92!465!%34]$14PN"B`J
M+PII9B`H(61E9FEN960H)U194$5-3T1%3"<I*2!["B`@("!D969I;F4H)U19
M4$5-3T1%3"<L(#<I.PI]"@HO*BH*("H@4F5T=7)N(&$@8V]D92!F;W(@='EP
M92@I+V5N8V]D:6YG*"DN"B`J+PID969I;F4H)TU)345?0T]$12<L(#$I.PH*
M+RHJ"B`J(%)E='5R;B!A('-T<FEN9R!F;W(@='EP92@I+V5N8V]D:6YG*"DN
M"B`J+PID969I;F4H)TU)345?4U1224Y')RP@,BD["@H*+RHJ"B`J(%1H92!-
M24U%.CH@8VQA<W,@<')O=FED97,@;65T:&]D<R!F;W(@9&5A;&EN9R!W:71H
M($U)344@<W1A;F1A<F1S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%
M+TU)344N<&AP+'8@,2XQ,SDN-"XR,"`R,#`V+S`S+S(T(#`T.C(Y.C4R(&-H
M=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G
M96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,
M*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`
M875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@
M0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E7TU)344*("HO
M"F-L87-S($U)344@>PH*("`@("\J*@H@("`@("H@02!L:7-T:6YG(&]F('1H
M92!A;&QO=V5D($U)344@='EP97,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)&UI;65?='EP97,@/2!A<G)A>2@*("`@("`@
M("!465!%5$585"`]/B`G=&5X="<L"B`@("`@("`@5%E014U53%1)4$%25"`]
M/B`G;75L=&EP87)T)RP*("`@("`@("!465!%34534T%'12`]/B`G;65S<V%G
M92<L"B`@("`@("`@5%E014%04$Q)0T%424].(#T^("=A<'!L:6-A=&EO;B<L
M"B`@("`@("`@5%E014%51$E/(#T^("=A=61I;R<L"B`@("`@("`@5%E014E-
M04=%(#T^("=I;6%G92<L"B`@("`@("`@5%E0159)1$5/(#T^("=V:61E;R<L
M"B`@("`@("`@5%E014U/1$5,(#T^("=M;V1E;"<L"B`@("`@("`@5%E014]4
M2$52(#T^("=O=&AE<B<*("`@("D["@H@("`@+RHJ"B`@("`@*B!!(&QI<W1I
M;F<@;V8@=&AE(&%L;&]W960@34E-12!E;F-O9&EN9W,N"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&UI;65?96YC;V1I;F=S
M(#T@87)R87DH"B`@("`@("`@14Y#-T))5"`]/B`G-V)I="<L"B`@("`@("`@
M14Y#.$))5"`]/B`G.&)I="<L"B`@("`@("`@14Y#0DE.05)9(#T^("=B:6YA
M<GDG+`H@("`@("`@($5.0T)!4T4V-"`]/B`G8F%S938T)RP*("`@("`@("!%
M3D-154]414104DE.5$%"3$4@/3X@)W%U;W1E9"UP<FEN=&%B;&4G+`H@("`@
M("`@($5.0T]42$52(#T^("=U;FMN;W=N)PH@("`@*3L*"B`@("`O*BH*("`@
M("`J($9I;'1E<B!F;W(@4D9#.#(R+@H@("`@("H*("`@("`J($!V87(@<W1R
M:6YG"B`@("`@*B\*("`@('9A<B`D<F9C.#(R7V9I;'1E<B`]("(H*3P^0"P[
M.EQ<7");75PQ7#)<,UPT7#5<-EPW7#$P7#$Q7#$R7#$S7#$T7#$U7#$V7#$W
M7#(P7#(Q7#(R7#(S7#(T7#(U7#(V7#(W7#,P7#,Q7#,R7#,S7#,T7#,U7#,V
M7#,W7#$W-R(["@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S(&EF(&$@<W1R
M:6YG(&-O;G1A:6YS(#@M8FET(&-H87)A8W1E<G,N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<W1R:6YG("!4:&4@<W1R:6YG('1O(&-H96-K+@H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!I="!D;V5S
M+"!F86QS92!I9B!I="!D;V5S;B=T+@H@("`@("HO"B`@("!F=6YC=&EO;B!I
M<SAB:70H)'-T<FEN9RD*("`@('L*("`@("`@("!R971U<FX@*&ES7W-T<FEN
M9R@D<W1R:6YG*2`F)B!P<F5G7VUA=&-H*"<O6UQX.#`M7'AF9ETO)RP@)'-T
M<FEN9RDI.PH@("`@?0H*("`@("\J*@H@("`@("H@16YC;V1E<R!A('-T<FEN
M9R!C;VYT86EN:6YG(&YO;BU!4T-)22!C:&%R86-T97)S(&%C8V]R9&EN9R!T
M;R!21D,@,C`T-RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT
M("`@("!4:&4@=&5X="!T;R!E;F-O9&4N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1C:&%R<V5T("!4:&4@8VAA<F%C=&5R('-E="!O9B!T:&4@=&5X="X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('1E>'0L(&5N8V]D960@
M;VYL>2!I9B!I="!C;VYT86EN<R!N;VXM05-#24D*("`@("`J("`@("`@("`@
M("`@("`@("!C:&%R86-T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!E;F-O
M9&4H)'1E>'0L("1C:&%R<V5T(#T@;G5L;"D*("`@('L*("`@("`@("`O*B!2
M971U<FX@:68@;F]T:&EN9R!N965D<R!T;R!B92!E;F-O9&5D+B`J+PH@("`@
M("`@(&EF("@A34E-13HZ:7,X8FET*"1T97AT*2D@>PH@("`@("`@("`@("!R
M971U<FX@)'1E>'0["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?;G5L;"@D
M8VAA<G-E="DI('L*("`@("`@("`@("`@)&-H87)S970@/2!.3%,Z.F=E=$-H
M87)S970H*3L*("`@("`@("!]"@H@("`@("`@("1C:&%R<V5T(#T@4W1R:6YG
M.CIL;W=E<B@D8VAA<G-E="D["B`@("`@("`@)&QI;F4@/2`G)SL*"B`@("`@
M("`@+RH@1V5T('1H92!L:7-T(&]F(&5L96UE;G1S(&EN('1H92!S=')I;F<N
M("HO"B`@("`@("`@)'-I>F4@/2!P<F5G7VUA=&-H7V%L;"@G+RA;7EQS72LI
M*%M<<UTJ*2\G+"`D=&5X="P@)&UA=&-H97,L(%!214=?4T547T]21$52*3L*
M"B`@("`@("`@9F]R96%C:"`H)&UA=&-H97,@87,@)&ME>2`]/B`D=F%L*2![
M"B`@("`@("`@("`@(&EF("A-24U%.CII<SAB:70H)'9A;%LQ72DI('L*("`@
M("`@("`@("`@("`@(&EF("@H*"1K97D@*R`Q*2`\("1S:7IE*2`F)@H@("`@
M("`@("`@("`@("`@("`@($U)344Z.FES.&)I="@D;6%T8VAE<ULD:V5Y("L@
M,5U;,5TI*2!["B`@("`@("`@("`@("`@("`@("`@)&QI;F4@+CT@34E-13HZ
M7V5N8V]D92@D=F%L6S%=("X@)'9A;%LR72P@)&-H87)S970I("X@)R`G.PH@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D
M;&EN92`N/2!-24U%.CI?96YC;V1E*"1V86Q;,5TL("1C:&%R<V5T*2`N("1V
M86Q;,ET["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D;&EN92`N/2`D=F%L6S%=("X@)'9A;%LR73L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(')T<FEM
M*"1L:6YE*3L*("`@('T*"B`@("`O*BH*("`@("`J($EN=&5R;F%L(')E8W5R
M<VEV92!F=6YC=&EO;B!T;R!21D,@,C`T-R!E;F-O9&4@82!S=')I;F<N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=&5X="`@("`@5&AE('1E>'0@=&\@96YC;V1E+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D8VAA<G-E="`@5&AE(&-H87)A8W1E<B!S970@
M;V8@=&AE('1E>'0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!T97AT+"!E;F-O9&5D(&]N;'D@:68@:70@8V]N=&%I;G,@;F]N+4%30TE)
M"B`@("`@*B`@("`@("`@("`@("`@("`@8VAA<F%C=&5R<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V5N8V]D92@D=&5X="P@)&-H87)S970I"B`@("!["B`@
M("`@("`@)&-H87)?;&5N(#T@<W1R;&5N*"1C:&%R<V5T*3L*("`@("`@("`D
M='AT7VQE;B`]('-T<FQE;B@D=&5X="D@*B`R.PH*("`@("`@("`O*B!21D,@
M,C`T-R!;,ET@<W1A=&5S('1H870@;F\@96YC;V1E9"!W;W)D(&-A;B!B92!M
M;W)E('1H86X@-S4*("`@("`@("`@("!C:&%R86-T97)S(&QO;F<N($EF(&QO
M;F=E<BP@>6]U(&UU<W0@<W!L:70@=&AE('=O<F0N("HO"B`@("`@("`@:68@
M*"@D='AT7VQE;B`K("1C:&%R7VQE;B`K(#<I(#X@-S4I('L*("`@("`@("`@
M("`@)'!O<R`](&EN='9A;"@H-C@@+2`D8VAA<E]L96XI("\@,BD["B`@("`@
M("`@("`@(')E='5R;B!-24U%.CI?96YC;V1E*'-U8G-T<B@D=&5X="P@,"P@
M)'!O<RDL("1C:&%R<V5T*2`N("<@)R`N($U)344Z.E]E;F-O9&4H<W5B<W1R
M*"1T97AT+"`D<&]S*2P@)&-H87)S970I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E='5R;B`G/3\G("X@)&-H87)S970@+B`G/V(_)R`N('1R
M:6TH8F%S938T7V5N8V]D92@D=&5X="DI("X@)S\])SL*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!%;F-O9&5S(&$@;&EN92!V:6$@<75O=&5D
M+7!R:6YT86)L92!E;F-O9&EN9RX*("`@("`J(%=R87!S(&QI;F5S(&%T(#<V
M(&-H87)A8W1E<G,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X
M="`@5&AE('1E>'0@=&\@96YC;V1E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M96]L("`@5&AE($5/3"!S97%U96YC92!T;R!U<V4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!Q=6]T960M<')I;G1A8FQE(&5N8V]D960@
M<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!Q=6]T9610<FEN=&%B;&5%
M;F-O9&4H)'1E>'0L("1E;VPI"B`@("!["B`@("`@("`@)&]U='!U="`]("<G
M.PH*("`@("`@("!F;W)E86-H("AP<F5G7W-P;&ET*"(O7'(_7&XO(BP@)'1E
M>'0I(&%S("1L:6YE*2!["B`@("`@("`@("`@("\J(%=E(&YE960@=&\@9V\@
M8VAA<F%C=&5R(&)Y(&-H87)A8W1E<B!T:')O=6=H('1H92!L:6YE+B`J+PH@
M("`@("`@("`@("`D;&5N9W1H(#T@<W1R;&5N*"1L:6YE*3L*("`@("`@("`@
M("`@)&-U<G)E;G1?;&EN92`]("<G.PH@("`@("`@("`@("`D8W5R<F5N=%]L
M96YG=&@@/2`P.PH*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&QE
M;F=T:#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@)&-H87(@/2!S=6)S='(H
M)&QI;F4L("1I+"`Q*3L*("`@("`@("`@("`@("`@("1A<V-I:2`](&]R9"@D
M8VAA<BD["@H@("`@("`@("`@("`@("`@+RH@4W!A8V5S(&]R('1A8G,@870@
M=&AE(&5N9"!O9B!T:&4@;&EN92!A<F4@3D]4(&%L;&]W960N"B`@("`@("`@
M("`@("`@("`@*B!!;'-O+"!#:&%R86-T97)S(&EN($%30TE)(&)E;&]W(#,R
M(&]R(&%B;W9E(#$R-B!!3D0@-C$*("`@("`@("`@("`@("`@("`J(&UU<W0@
M8F4@96YC;V1E9"X@*B\*("`@("`@("`@("`@("`@(&EF("@H*"@D87-C:6D@
M/3T](#DI('Q\("@D87-C:6D@/3T](#,R*2D@)B8@*"1I(#T]("@D;&5N9W1H
M("T@,2DI*2!\?`H@("`@("`@("`@("`@("`@("`@("@H)&%S8VEI(#P@,S(I
M('Q\("@D87-C:6D@/B`Q,C8I('Q\("@D87-C:6D@/3T](#8Q*2DI('L*("`@
M("`@("`@("`@("`@("`@("`D8VAA<B`]("<])R`N(%-T<FEN9SHZ=7!P97(H
M<W!R:6YT9B@G)3`R<R<L(&1E8VAE>"@D87-C:6DI*2D["B`@("`@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`@("`@+RH@3&EN97,@;75S="!B92`W-B!C
M:&%R86-T97)S(&]R(&QE<W,N("HO"B`@("`@("`@("`@("`@("`D8VAA<E]L
M96YG=&@@/2!S=')L96XH)&-H87(I.PH@("`@("`@("`@("`@("`@)&-U<G)E
M;G1?;&5N9W1H("L]("1C:&%R7VQE;F=T:#L*("`@("`@("`@("`@("`@(&EF
M("@D8W5R<F5N=%]L96YG=&@@/B`W-BD@>PH@("`@("`@("`@("`@("`@("`@
M("1O=71P=70@+CT@)&-U<G)E;G1?;&EN92`N("<])R`N("1E;VP["B`@("`@
M("`@("`@("`@("`@("`@)&-U<G)E;G1?;&EN92`]("<G.PH@("`@("`@("`@
M("`@("`@("`@("1C=7)R96YT7VQE;F=T:"`]("1C:&%R7VQE;F=T:#L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1C=7)R96YT7VQI;F4@
M+CT@)&-H87(["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&]U='!U="`N
M/2`D8W5R<F5N=%]L:6YE("X@)&5O;#L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D;W5T<'5T.PH@("`@?0H*("`@("\J*@H@("`@("H@16YC;V1E<R!A
M('-T<FEN9R!C;VYT86EN:6YG(&5M86EL(&%D9')E<W-E<R!A8V-O<F1I;F<@
M=&\@4D9#(#(P-#<N"B`@("`@*@H@("`@("H@5&AI<R!D:69F97)S(&9R;VT@
M34E-13HZ96YC;V1E*"D@8F5C875S92!I="!K965P<R!E;6%I;"!A9&1R97-S
M97,@;&5G86PL"B`@("`@*B!O;FQY(&5N8V]D:6YG('1H92!P97)S;VYA;"!I
M;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A9&1R
M97-S97,@(%1H92!E;6%I;"!A9&1R97-S97,@=&\@96YC;V1E+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D8VAA<G-E="`@("!4:&4@8VAA<F%C=&5R('-E="!O
M9B!T:&4@=&5X="X*("`@("`J($!P87)A;2!S=')I;F<@)&1E9G-E<G9E<B`@
M5&AE(&1E9F%U;'0@9&]M86EN('1O(&%P<&5N9"!T;R!M86EL8F]X97,N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!T97AT+"!E;F-O9&5D
M(&]N;'D@:68@:70@8V]N=&%I;G,@;F]N+6%S8VEI"B`@("`@*B`@("`@("`@
M("`@("`@("`@8VAA<F%C=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@96YC
M;V1E061D<F5S<R@D861D<F5S<V5S+"`D8VAA<G-E="`](&YU;&PL("1D969S
M97)V97(@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D861D
M<F5S<V5S*2D@>PH@("`@("`@("`@("`D861D<E]A<G(@/2`D861D<F5S<V5S
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J('!A<G-E061D<F5S
M<TQI<W0H*2!D;V5S(&YO="!P<F]C97-S('1H92!N=6QL(&5N=')Y"B`@("`@
M("`@("`@("`J("=U;F1I<V-L;W-E9"UR96-I<&EE;G1S.CLG(&-O<G)E8W1L
M>2X@*B\*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R]U;F1I<V-L;W-E
M9"UR96-I<&EE;G1S.EQS*CLO:2<L('1R:6TH)&%D9')E<W-E<RDI*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)&%D9')E<W-E<SL*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=-86EL+U)&0S@R,BYP:'`G
M.PH@("`@("`@("`@("`D<&%R<V5R(#T@)FYE=R!-86EL7U)&0S@R,B@I.PH@
M("`@("`@("`@("`D861D<E]A<G(@/2`D<&%R<V5R+3YP87)S94%D9')E<W-,
M:7-T*"1A9&1R97-S97,L("1D969S97)V97(L('1R=64L(&9A;'-E*3L*("`@
M("`@("`@("`@:68@*&ES7V$H)&%D9')?87)R+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)&%D9')?87)R.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("`D=&5X="`]("<G.PH@("`@("`@(&EF
M("AI<U]A<G)A>2@D861D<E]A<G(I*2!["B`@("`@("`@("`@(&9O<F5A8V@@
M*"1A9&1R7V%R<B!A<R`D861D<BD@>PH@("`@("`@("`@("`@("`@+R\@0VAE
M8VL@9F]R(&=R;W5P<RX*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&%D
M9'(M/F=R;W5P;F%M92DI('L*("`@("`@("`@("`@("`@("`@("`D=&5X="`N
M/2!-24U%.CIE;F-O9&4H)&%D9'(M/F=R;W5P;F%M92P@)&-H87)S970I("X@
M)SH@)R`N($U)344Z.F5N8V]D94%D9')E<W,H)&%D9'(M/F%D9')E<W-E<RD@
M+B`G.R<["B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1A9&1R+3YP
M97)S;VYA;"DI('L*("`@("`@("`@("`@("`@("`@("`D<&5R<V]N86P@/2`G
M)SL*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@:68@*"AS=6)S='(H)&%D9'(M/G!E<G-O;F%L+"`P+"`Q*2`]/2`G(B<I
M("8F"B`@("`@("`@("`@("`@("`@("`@("`@("AS=6)S='(H)&%D9'(M/G!E
M<G-O;F%L+"`M,2D@/3T@)R(G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D861D<BT^<&5R<V]N86P@/2!S=6)S='(H)&%D9'(M/G!E<G-O;F%L+"`Q
M+"`M,2D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@("1P97)S;VYA;"`]($U)344Z.F5N8V]D92@D861D<BT^<&5R<V]N86PL
M("1C:&%R<V5T*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&EF("AS=')L96XH)'1E>'0I("$](#`I('L*("`@("`@("`@("`@("`@("`@
M("`D=&5X="`N/2`G+"`G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@)'1E>'0@+CT@34E-13HZ=')I;45M86EL061D<F5S<RA-24U%.CIR
M9F,X,C)7<FET94%D9')E<W,H)&%D9'(M/FUA:6QB;W@L("1A9&1R+3YH;W-T
M+"`D<&5R<V]N86PI*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1T97AT.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5C;V1E
M<R!A;B!21D,@,C`T-RUE;F-O9&5D('-T<FEN9RX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1S=')I;F<@("`@("!4:&4@=&5X="!T;R!D96-O9&4N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1T;U]C:&%R<V5T("!4:&4@8VAA<G-E
M="!T:&%T('1H92!T97AT('-H;W5L9"!B92!D96-O9&5D"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!T;RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(&1E8V]D960@=&5X="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9&5C;V1E*"1S=')I;F<L("1T;U]C:&%R<V5T(#T@;G5L;"D*("`@
M('L*("`@("`@("!I9B`H*"1P;W,@/2!S=')P;W,H)'-T<FEN9RP@)ST_)RDI
M(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@)'-T<FEN9SL*("`@
M("`@("!]"@H@("`@("`@("\J(%1A:V4@;W5T(&%N>2!S<&%C97,@8F5T=V5E
M;B!M=6QT:7!L92!E;F-O9&5D('=O<F1S+B`J+PH@("`@("`@("1S=')I;F<@
M/2!P<F5G7W)E<&QA8V4H)WQ</SU<<SU</WPG+"`G/ST]/R<L("1S=')I;F<I
M.PH*("`@("`@("`O*B!3879E(&%N>2!P<F5C961I;F<@=&5X="X@*B\*("`@
M("`@("`D<')E8V5D:6YG(#T@<W5B<W1R*"1S=')I;F<L(#`L("1P;W,I.PH*
M("`@("`@("`D<V5A<F-H(#T@<W5B<W1R*"1S=')I;F<L("1P;W,@*R`R*3L*
M("`@("`@("`D9#$@/2!S=')P;W,H)'-E87)C:"P@)S\G*3L*("`@("`@("!I
M9B`H)&0Q(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@)'-T<FEN
M9SL*("`@("`@("!]"@H@("`@("`@("1C:&%R<V5T(#T@<W5B<W1R*"1S=')I
M;F<L("1P;W,@*R`R+"`D9#$I.PH@("`@("`@("1S96%R8V@@/2!S=6)S='(H
M)'-E87)C:"P@)&0Q("L@,2D["@H@("`@("`@("1D,B`]('-T<G!O<R@D<V5A
M<F-H+"`G/R<I.PH@("`@("`@(&EF("@D9#(@/3T](&9A;'-E*2!["B`@("`@
M("`@("`@(')E='5R;B`D<W1R:6YG.PH@("`@("`@('T*"B`@("`@("`@)&5N
M8V]D:6YG(#T@<W5B<W1R*"1S96%R8V@L(#`L("1D,BD["B`@("`@("`@)'-E
M87)C:"`]('-U8G-T<B@D<V5A<F-H+"`D9#(@*R`Q*3L*"B`@("`@("`@)&5N
M9"`]('-T<G!O<R@D<V5A<F-H+"`G/STG*3L*("`@("`@("!I9B`H)&5N9"`]
M/3T@9F%L<V4I('L*("`@("`@("`@("`@)&5N9"`]('-T<FQE;B@D<V5A<F-H
M*3L*("`@("`@("!]"@H@("`@("`@("1E;F-O9&5D7W1E>'0@/2!S=6)S='(H
M)'-E87)C:"P@,"P@)&5N9"D["B`@("`@("`@)')E<W0@/2!S=6)S='(H)'-T
M<FEN9RP@*'-T<FQE;B@D<')E8V5D:6YG("X@)&-H87)S970@+B`D96YC;V1I
M;F<@+B`D96YC;V1E9%]T97AT*2`K(#8I*3L*"B`@("`@("`@:68@*"%I<W-E
M="@D=&]?8VAA<G-E="DI('L*("`@("`@("`@("`@)'1O7V-H87)S970@/2!.
M3%,Z.F=E=$-H87)S970H*3L*("`@("`@("!]"@H@("`@("`@('-W:71C:"`H
M)&5N8V]D:6YG*2!["B`@("`@("`@8V%S92`G42<Z"B`@("`@("`@8V%S92`G
M<2<Z"B`@("`@("`@("`@("1E;F-O9&5D7W1E>'0@/2!S=')?<F5P;&%C92@G
M7R<L("<@)RP@)&5N8V]D961?=&5X="D["B`@("`@("`@("`@("1D96-O9&5D
M(#T@<')E9U]R97!L86-E*"<O/2A;,"TY82UF77LR?2DO:64G+"`G8VAR*#!X
M7#$I)RP@)&5N8V]D961?=&5X="D["B`@("`@("`@("`@("1D96-O9&5D(#T@
M4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D9&5C;V1E9"P@)&-H87)S970L("1T
M;U]C:&%R<V5T*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@
M)T(G.@H@("`@("`@(&-A<V4@)V(G.@H@("`@("`@("`@("`D9&5C;V1E9"`]
M(&)A<V4V-%]D96-O9&4H)&5N8V]D961?=&5X="D["B`@("`@("`@("`@("1D
M96-O9&5D(#T@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D9&5C;V1E9"P@)&-H
M87)S970L("1T;U]C:&%R<V5T*3L*("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("1D96-O9&5D(#T@)ST_)R`N("1C
M:&%R<V5T("X@)S\G("X@)&5N8V]D:6YG("X@)S\G("X@)&5N8V]D961?=&5X
M="`N("<_/2<["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1P<F5C961I;F<@+B`D9&5C;V1E9"`N($U)344Z.F1E8V]D
M92@D<F5S="P@)'1O7V-H87)S970I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1&5C;V1E<R!A;B!21D,@,C(S,2UE;F-O9&5D('-T<FEN9RX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1S=')I;F<@("!4:&4@96YT:7)E('-T<FEN
M9R!T;R!D96-O9&4L(&EN8VQU9&EN9R!T:&4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@('!A<F%M971E<B!N86UE+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D8VAA<G-E="`@5&AE(&-H87)S970@=&AA="!T:&4@=&5X="!S:&]U
M;&0@8F4@9&5C;V1E9"!T;RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!4:&4@9&5C;V1E9"!T97AT+"!O<B!T:&4@;W)I9VEN86P@<W1R:6YG(&EF
M(&ET('=A<R!N;W0*("`@("`J("`@("`@("`@("`@("`@(&5N8V]D960N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&1E8V]D95)&0S(R,S$H)'-T<FEN9RP@)'1O
M7V-H87)S970@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@H)'!O<R`]('-T
M<G!O<R@D<W1R:6YG+"`G*B<I*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I<W-E="@D
M=&]?8VAA<G-E="DI('L*("`@("`@("`@("`@)'1O7V-H87)S970@/2!.3%,Z
M.F=E=$-H87)S970H*3L*("`@("`@("!]"@H@("`@("`@("1A='1R:6)U=&4@
M/2!S=6)S='(H)'-T<FEN9RP@,"P@)'!O<RD["B`@("`@("`@)&-H87)S970@
M/2`D;&%N9R`](&YU;&P["B`@("`@("`@)&]U='!U="`]("<G.PH*("`@("`@
M("`O*B!'970@=&AE(&-H87)A8W1E<B!S970@86YD(&QA;F=U86=E('5S960@
M:6X@=&AE(&5N8V]D:6YG+"!I9@H@("`@("`@("`J(&%N>2X@*B\*("`@("`@
M("!I9B`H<')E9U]M871C:"@B+UY;7CU=*UPJ7#TH6UXG72HI)RA;7B==*BDG
M+R(L("1S=')I;F<L("1M871C:&5S*2D@>PH@("`@("`@("`@("`D8VAA<G-E
M="`]("1M871C:&5S6S%=.PH@("`@("`@("`@("`D;&%N9R`]("1M871C:&5S
M6S)=.PH@("`@("`@("`@("`D<W1R:6YG(#T@<W1R7W)E<&QA8V4H)&-H87)S
M970@+B`B)R(@+B`D;&%N9R`N("(G(BP@)R<L("1S=')I;F<I.PH@("`@("`@
M('T*"B`@("`@("`@)&QI;F5S(#T@<')E9U]S<&QI="@G+R<@+B!P<F5G7W%U
M;W1E*"1A='1R:6)U=&4I("X@)R@_.EPJ7&0I*B\G+"`D<W1R:6YG*3L*("`@
M("`@("!F;W)E86-H("@D;&EN97,@87,@)&QI;F4I('L*("`@("`@("`@("`@
M)'!O<R`]('-T<G!O<R@D;&EN92P@)RH])RD["B`@("`@("`@("`@(&EF("@D
M<&]S(#T]/2`P*2!["B`@("`@("`@("`@("`@("`D;&EN92`]('-U8G-T<B@D
M;&EN92P@,BD["B`@("`@("`@("`@("`@("`D;&EN92`]('-T<E]R97!L86-E
M*"=?)RP@)R4R,"<L("1L:6YE*3L*("`@("`@("`@("`@("`@("1L:6YE(#T@
M<W1R7W)E<&QA8V4H)STG+"`G)2<L("1L:6YE*3L*("`@("`@("`@("`@("`@
M("1O=71P=70@+CT@=7)L9&5C;V1E*"1L:6YE*3L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1L:6YE(#T@<W5B<W1R*"1L:6YE+"`Q
M*3L*("`@("`@("`@("`@("`@("1O=71P=70@+CT@)&QI;F4["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("\J(%)&0R`R,C,Q('5S97,@<75O
M=&5D('!R:6YT86)L92!E;F-O9&EN9RX@*B\*("`@("`@("!I9B`H(6ES7VYU
M;&PH)&-H87)S970I*2!["B`@("`@("`@("`@("1O=71P=70@/2!3=')I;F<Z
M.F-O;G9E<G1#:&%R<V5T*"1O=71P=70L("1C:&%R<V5T+"`D=&]?8VAA<G-E
M="D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@87)R87DH"B`@("`@("`@
M("`@("=A='1R:6)U=&4G(#T^("1A='1R:6)U=&4L"B`@("`@("`@("`@("=V
M86QU92<@/3X@)&]U='!U=`H@("`@("`@("D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!)9B!A;B!E;6%I;"!A9&1R97-S(&AA<R!N;R!P97)S;VYA;"!I;F9O
M<FUA=&EO;BP@9V5T(')I9"!O9B!A;GD@86YG;&4*("`@("`J(&)R86-K971S
M("@\/BD@87)O=6YD(&ET+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&%D9')E<W,@(%1H92!A9&1R97-S('1O('1R:6TN"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!T<FEM;65D(&%D9')E<W,N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('1R:6U%;6%I;$%D9')E<W,H)&%D9')E<W,I"B`@("![
M"B`@("`@("`@)&%D9')E<W,@/2!T<FEM*"1A9&1R97-S*3L*"B`@("`@("`@
M:68@*"AS=6)S='(H)&%D9')E<W,L(#`L(#$I(#T]("<\)RD@)B8@*'-U8G-T
M<B@D861D<F5S<RP@+3$I(#T]("<^)RDI('L*("`@("`@("`@("`@)&%D9')E
M<W,@/2!S=6)S='(H)&%D9')E<W,L(#$L("TQ*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D861D<F5S<SL*("`@('T*"B`@("`O*BH*("`@("`J($)U
M:6QD<R!A;B!21D,@.#(R(&-O;7!L:6%N="!E;6%I;"!A9&1R97-S+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&UA:6QB;W@@("!-86EL8F]X(&YA
M;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1H;W-T("`@("`@1&]M86EN(&YA
M;64@;V8@;6%I;&)O>"=S(&AO<W0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1P
M97)S;VYA;"`@4&5R<V]N86P@;F%M92!P:')A<V4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!C;W)R96-T;'D@97-C87!E9"!A;F0@<75O
M=&5D"B`@("`@*B`@("`@("`@("`@("`@("`@(B1P97)S;VYA;"`\)&UA:6QB
M;WA`)&AO<W0^(B!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(')F8S@R
M,E=R:71E061D<F5S<R@D;6%I;&)O>"P@)&AO<W0@/2!N=6QL+"`D<&5R<V]N
M86P@/2`G)RD*("`@('L*("`@("`@("`D861D<F5S<R`]("<G.PH*("`@("`@
M("!I9B`H(65M<'1Y*"1P97)S;VYA;"DI('L*("`@("`@("`@("`@)'9A<G,@
M/2!G971?8VQA<W-?=F%R<R@G34E-12<I.PH@("`@("`@("`@("`D861D<F5S
M<R`N/2!-24U%.CI?<F9C.#(R16YC;V1E*"1P97)S;VYA;"P@)'9A<G-;)W)F
M8S@R,E]F:6QT97(G72`N("<N)RD["B`@("`@("`@("`@("1A9&1R97-S("X]
M("<@/"<["B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES7VYU;&PH)&AO<W0I
M*2!["B`@("`@("`@("`@("1A9&1R97-S("X]($U)344Z.E]R9F,X,C)%;F-O
M9&4H)&UA:6QB;W@I.PH@("`@("`@("`@("!I9B`H<W5B<W1R*"1H;W-T+"`P
M+"`Q*2`A/2`G0"<I('L*("`@("`@("`@("`@("`@("1A9&1R97-S("X]("=`
M)R`N("1H;W-T.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I
M9B`H(65M<'1Y*"1P97)S;VYA;"DI('L*("`@("`@("`@("`@)&%D9')E<W,@
M+CT@)SXG.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1A9&1R97-S.PH@
M("`@?0H*("`@("\J*@H@("`@("H@17AP;&]D97,@82!21D,@.#(R('-T<FEN
M9RP@:6=N;W)I;F<@82!D96QI;6ET97(@:68@<')E8V5D960@8GD@82`B7"(*
M("`@("`J(&-H87)A8W1E<BP@;W(@:68@9&5L:6UI=&5R(&ES(&EN<VED92!S
M:6YG;&4@;W(@9&]U8FQE('%U;W1E<RX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1S='(@("`@("`@(%1H92!21D,@.#(R('-T<FEN9RX*("`@("`J
M($!P87)A;2!S=')I;F<@)&1E;&EM:71E<B`@5&AE(&1E;&EM=&5R+@H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!E>'!L;V1E9"!S=')I;F<@
M:6X@86X@87)R87DN"B`@("`@*B\*("`@(&9U;F-T:6]N(')F8S@R,D5X<&QO
M9&4H)'-T<BP@)&1E;&EM:71E<BD*("`@('L*("`@("`@("`D87)R(#T@87)R
M87DH*3L*("`@("`@("`D;6%T8V@@/2`P.PH@("`@("`@("1Q=6]T97,@/2!A
M<G)A>2@G(B<L("(G(BD["B`@("`@("`@)&EN7W%U;W1E(#T@;G5L;#L*("`@
M("`@("`D:6Y?9W)O=7`@/2!F86QS93L*("`@("`@("`D<')E=B`](&YU;&P[
M"@H@("`@("`@(&EF("AE;7!T>2@D<W1R*2D@>PH@("`@("`@("`@("!R971U
M<FX@87)R87DH)'-T<BD["B`@("`@("`@?0H*("`@("`@("!I9B`H:6Y?87)R
M87DH)'-T<GLP?2P@)'%U;W1E<RDI('L*("`@("`@("`@("`@)&EN7W%U;W1E
M(#T@)'-T<GLP?3L*("`@("`@("!](&5L<V5I9B`H)'-T<GLP?2`]/2`G.B<I
M('L*("`@("`@("`@("`@)&EN7V=R;W5P(#T@=')U93L*("`@("`@("!](&5L
M<V5I9B`H)'-T<GLP?2`]/2`D9&5L:6UI=&5R*2!["B`@("`@("`@("`@("1A
M<G);72`]("<G.PH@("`@("`@("`@("`D;6%T8V@@/2`Q.PH@("`@("`@('T*
M"B`@("`@("`@9F]R("@D:2`](#$[("1I(#P@<W1R;&5N*"1S='(I.R`D:2LK
M*2!["B`@("`@("`@("`@("1C:&%R(#T@)'-T<GLD:7T["B`@("`@("`@("`@
M(&EF("AI;E]A<G)A>2@D8VAA<BP@)'%U;W1E<RDI('L*("`@("`@("`@("`@
M("`@(&EF("@D<')E=B`A/3T@)UQ<)RD@>PH@("`@("`@("`@("`@("`@("`@
M(&EF("@D:6Y?<75O=&4@/3T]("1C:&%R*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1I;E]Q=6]T92`](&YU;&P["B`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E:68@*&ES7VYU;&PH)&EN7W%U;W1E*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D:6Y?<75O=&4@/2`D8VAA<CL*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS96EF
M("@D:6Y?9W)O=7`I('L*("`@("`@("`@("`@("`@(&EF("@D8VAA<B`]/2`G
M.R<I('L*("`@("`@("`@("`@("`@("`@("`D87)R6UT@/2!S=6)S='(H)'-T
M<BP@)&UA=&-H+"`D:2`M("1M871C:"`K(#$I.PH@("`@("`@("`@("`@("`@
M("`@("1M871C:"`]("1I("L@,3L*("`@("`@("`@("`@("`@("`@("`D:6Y?
M9W)O=7`@/2!F86QS93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?2!E;'-E:68@*"1C:&%R(#T]("<Z)RD@>PH@("`@("`@("`@("`@("`@)&EN
M7V=R;W5P(#T@=')U93L*("`@("`@("`@("`@?2!E;'-E:68@*"1C:&%R(#T]
M("1D96QI;6ET97(@)B8*("`@("`@("`@("`@("`@("`@("`@("1P<F5V("$]
M/2`G7%PG("8F"B`@("`@("`@("`@("`@("`@("`@("!I<U]N=6QL*"1I;E]Q
M=6]T92DI('L*("`@("`@("`@("`@("`@("1A<G);72`]('-U8G-T<B@D<W1R
M+"`D;6%T8V@L("1I("T@)&UA=&-H*3L*("`@("`@("`@("`@("`@("1M871C
M:"`]("1I("L@,3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<')E=B`]
M("1C:&%R.PH@("`@("`@('T*"B`@("`@("`@:68@*"1M871C:"`A/2`D:2D@
M>PH@("`@("`@("`@("`O*B!4:&4@<W1R:6YG(&5N9&5D('=I=&AO=70@82`D
M9&5L:6UI=&5R+B`J+PH@("`@("`@("`@("`D87)R6UT@/2!S=6)S='(H)'-T
M<BP@)&UA=&-H+"`D:2`M("1M871C:"D["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)&%R<CL*("`@('T*"B`@("`O*BH*("`@("`J(%1A:V5S(&%N(&%D
M9')E<W,@;V)J96-T+"!A<R!R971U<FYE9"!B>2!I;6%P7VAE861E<B@I(&9O
M<B!E>&%M<&QE+"!A;F0*("`@("`J(&9O<FUA=',@:70@87,@82!S=')I;F<N
M"B`@("`@*@H@("`@("H@3V)J96-T(&9O<FUA="!F;W(@=&AE(&%D9')E<W,@
M(DIO:&X@1&]E(#QJ;VAN7V1O94!E>&%M<&QE+F-O;3XB(&ES.@H@("`@("H@
M/'!R93X*("`@("`J("`@)&]B:F5C="T^<&5R<V]N86P@/2!097)S;VYA;"!N
M86UE("@B2F]H;B!$;V4B*0H@("`@("H@("`D;V)J96-T+3YM86EL8F]X("`]
M(%1H92!U<V5R)W,@;6%I;&)O>"`H(FIO:&Y?9&]E(BD*("`@("`J("`@)&]B
M:F5C="T^:&]S="`@("`@/2!4:&4@:&]S="!T:&4@;6%I;&)O>"!I<R!O;B`H
M(F5X86UP;&4N8V]M(BD*("`@("`J(#PO<')E/@H@("`@("H*("`@("`J($!P
M87)A;2!S=&1#;&%S<R`D;V(@("!4:&4@861D<F5S<R!O8FIE8W0@=&\@8F4@
M='5R;F5D(&EN=&\@82!S=')I;F<N"B`@("`@*B!`<&%R86T@;6EX960@)&9I
M;'1E<B`@02!U<V5R0&5X86UP;&4N8V]M('-T>6QE(&)A<F4@861D<F5S<R!T
M;R!I9VYO<F4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@16ET:&5R
M('-I;F=L92!S=')I;F<@;W(@86X@87)R87D@;V8@<W1R:6YG<RX@($EF"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@=&AE(&%D9')E<W,@;6%T8VAE
M<R`D9FEL=&5R+"!A;B!E;7!T>2!S=')I;F<@=VEL;`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@(&)E(')E='5R;F5D+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@9F]R;6%T=&5D(&%D9')E<W,@*$5X86UP;&4Z
M($IO:&X@1&]E"B`@("`@*B`@("`@("`@("`@("`@("`@/&IO:&Y?9&]E0&5X
M86UP;&4N8V]M/BDN"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9')/8FIE8W0R
M4W1R:6YG*"1O8BP@)&9I;'1E<B`]("<G*0H@("`@>PH@("`@("`@("\J($EF
M('1H92!P97)S;VYA;"!N86UE(&ES('-E="P@9&5C;V1E(&ET+B`J+PH@("`@
M("`@("1O8BT^<&5R<V]N86P@/2!I<W-E="@D;V(M/G!E<G-O;F%L*2`_($U)
M344Z.F1E8V]D92@D;V(M/G!E<G-O;F%L*2`Z("<G.PH*("`@("`@("`O*B!)
M9B!B;W1H('1H92!M86EL8F]X(&%N9"!T:&4@:&]S="!A<F4@96UP='DL(')E
M='5R;B!A;B!E;7!T>0H@("`@("`@("`@('-T<FEN9RX@($EF('=E(&IU<W0@
M;&5T('1H:7,@8V%S92!F86QL('1H<F]U9V@L('1H92!C86QL('1O"B`@("`@
M("`@("`@34E-13HZ<F9C.#(R5W)I=&5!9&1R97-S*"D@=VEL;"!E;F0@=7`@
M<F5T=7)N(&IU<W0@82`G0"<L('=H:6-H"B`@("`@("`@("`@:7,@=6YD97-I
M<F%B;&4N("HO"B`@("`@("`@:68@*&5M<'1Y*"1O8BT^;6%I;&)O>"D@)B8@
M96UP='DH)&]B+3YH;W-T*2D@>PH@("`@("`@("`@("!R971U<FX@)R<["B`@
M("`@("`@?0H*("`@("`@("`O*B!-86ME('-U<F4@=&AE<V4@='=O('9A<FEA
M8FQE<R!H879E('-O;64@<V]R="!O9B!V86QU92X@*B\*("`@("`@("!I9B`H
M(6ES<V5T*"1O8BT^;6%I;&)O>"DI('L*("`@("`@("`@("`@)&]B+3YM86EL
M8F]X(#T@)R<["B`@("`@("`@?2!E;'-E:68@*"1O8BT^;6%I;&)O>"`]/2`G
M=6YD:7-C;&]S960M<F5C:7!I96YT<R<I('L*("`@("`@("`@("`@<F5T=7)N
M("<G.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1O8BT^:&]S="DI
M('L*("`@("`@("`@("`@)&]B+3YH;W-T(#T@)R<["B`@("`@("`@?0H*("`@
M("`@("`O*B!&:6QT97(@;W5T('5N=V%N=&5D(&%D9')E<W-E<R!B87-E9"!O
M;B!T:&4@)&9I;'1E<B!S=')I;F<N("HO"B`@("`@("`@:68@*"1F:6QT97(I
M('L*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D9FEL=&5R*2D@>PH@("`@
M("`@("`@("`@("`@)&9I;'1E<B`](&%R<F%Y*"1F:6QT97(I.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&9O<F5A8V@@*"1F:6QT97(@87,@)&8I('L*
M("`@("`@("`@("`@("`@(&EF("AS=')C87-E8VUP*"1F+"`D;V(M/FUA:6QB
M;W@@+B`G0"<@+B`D;V(M/FAO<W0I(#T](#`I('L*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)R<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@("\J(%)E='5R;B!T:&4@=')I;6UE9"P@
M9F]R;6%T=&5D(&5M86EL(&%D9')E<W,N("HO"B`@("`@("`@<F5T=7)N($U)
M344Z.G1R:6U%;6%I;$%D9')E<W,H34E-13HZ<F9C.#(R5W)I=&5!9&1R97-S
M*"1O8BT^;6%I;&)O>"P@)&]B+3YH;W-T+"`D;V(M/G!E<G-O;F%L*2D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!486ME<R!A;B!A<G)A>2!O9B!A9&1R97-S
M(&]B:F5C=',L(&%S(')E='5R;F5D(&)Y(&EM87!?:&5A9&5R:6YF;R@I+`H@
M("`@("H@9F]R(&5X86UP;&4L(&%N9"!P87-S97,@96%C:"!O9B!T:&5M('1H
M<F]U9V@@34E-13HZ861D<D]B:F5C=#)3=')I;F<H*2X*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@)&%D9')E<W-E<R`@5&AE(&%R<F%Y(&]F(&%D9')E
M<W,@;V)J96-T<RX*("`@("`J($!P87)A;2!M:7AE9"`D9FEL=&5R("`@("!!
M('5S97)`97AA;7!L92YC;VT@<W1Y;&4@8F%R92!A9&1R97-S('1O"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@:6=N;W)E+B`@268@86YY(&%D
M9')E<W,@;6%T8VAE<R`D9FEL=&5R+"!I=`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@('=I;&P@;F]T(&)E(&EN8VQU9&5D(&EN('1H92!F:6YA
M;"!S=')I;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($%L;"!O
M9B!T:&4@861D<F5S<V5S(&EN(&$@8V]M;6$M9&5L:6UI=&5D('-T<FEN9RX*
M("`@("`J("`@("`@("`@("`@("`@("!2971U<FYS('1H92!E;7!T>2!S=')I
M;F<@;VX@97)R;W(O;F\@861D<F5S<V5S(&9O=6YD+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!A9&1R07)R87DR4W1R:6YG*"1A9&1R97-S97,L("1F:6QT97(@
M/2`G)RD*("`@('L*("`@("`@("`D861D<DQI<W0@/2!A<G)A>2@I.PH*("`@
M("`@("!I9B`H(6ES7V%R<F%Y*"1A9&1R97-S97,I*2!["B`@("`@("`@("`@
M(')E='5R;B`G)SL*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1A9&1R
M97-S97,@87,@)&%D9'(I('L*("`@("`@("`@("`@)'9A;"`]($U)344Z.F%D
M9')/8FIE8W0R4W1R:6YG*"1A9&1R+"`D9FEL=&5R*3L*("`@("`@("`@("`@
M:68@*"%E;7!T>2@D=F%L*2D@>PH@("`@("`@("`@("`@("`@)&)A<F5!9&1R
M(#T@4W1R:6YG.CIL;W=E<BA-24U%.CIB87)E061D<F5S<R@D=F%L*2D["B`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1A9&1R3&ES=%LD8F%R94%D9')=
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1A9&1R3&ES=%LD8F%R94%D9')=
M(#T@)'9A;#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@:68@*&5M<'1Y*"1A9&1R3&ES="DI('L*("`@("`@
M("`@("`@<F5T=7)N("<G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(')E='5R;B!I;7!L;V1E*"<L("<L("1A9&1R3&ES="D["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8F%R92!A9&1R97-S
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%D9')E<W,@("`@5&AE
M(&%D9')E<W,@<W1R:6YG+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&5F<V5R
M=F5R("!4:&4@9&5F875L="!D;VUA:6X@=&\@87!P96YD('1O(&UA:6QB;WAE
M<RX*("`@("`J($!P87)A;2!B;V]L96%N("1M=6QT:7!L92`@4VAO=6QD('=E
M(')E='5R;B!M=6QT:7!L92!R97-U;'1S/PH@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@($EF("1M=6QT:7!L92!I<R!F86QS92P@<F5T=7)N<R!T:&4@
M;6%I;&)O>$!H;W-T(&4M;6%I;`H@("`@("H@("`@("`@("`@("`@("`@861D
M<F5S<RX@($EF("1M=6QT:7!L92!I<R!T<G5E+"!R971U<FYS(&%N(&%R<F%Y
M(&]F"B`@("`@*B`@("`@("`@("`@("`@("!T:&5S92!A9&1R97-S97,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&)A<F5!9&1R97-S*"1A9&1R97-S+"`D9&5F
M<V5R=F5R(#T@;G5L;"P@)&UU;'1I<&QE(#T@9F%L<V4I"B`@("!["B`@("`@
M("`@)&%D9')E<W-,:7-T(#T@87)R87DH*3L*"B`@("`@("`@+RH@57-E(&)U
M:6QT+6EN($E-05`@9G5N8W1I;VX@;VYL>2!I9B!A=F%I;&%B;&4@86YD(&EF
M(&YO="!P87)S:6YG"B`@("`@("`@("H@9&ES=')I8G5T:6]N(&QI<W1S(&)E
M8V%U<V4@:70@9&]E<VXG="!P87)S92!D:7-T<FEB=71I;VX@;&ES=',*("`@
M("`@("`@*B!P<F]P97)L>2X@*B\*("`@("`@("!I9B`H571I;#HZ97AT96YS
M:6]N17AI<W1S*"=I;6%P)RD@)B8@<W1R<&]S*"1A9&1R97-S+"`G.B<I(#T]
M/2!F86QS92D@>PH@("`@("`@("`@("`D9G)O;2`](&EM87!?<F9C.#(R7W!A
M<G-E7V%D<FQI<W0H)&%D9')E<W,L("1D969S97)V97(I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G36%I;"]21D,X,C(N
M<&AP)SL*("`@("`@("`@("`@)'!A<G-E<B`](&YE=R!-86EL7U)&0S@R,B@I
M.PH@("`@("`@("`@("`D9G)O;2`]("1P87)S97(M/G!A<G-E061D<F5S<TQI
M<W0H)&%D9')E<W,L("1D969S97)V97(L(&9A;'-E+"!F86QS92D["B`@("`@
M("`@("`@(&EF("AI<U]A*"1F<F]M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@)&UU;'1I<&QE(#\@87)R87DH*2`Z("<G.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D9G)O
M;2!A<R`D96YT<GDI('L*("`@("`@("`@("`@:68@*&ES<V5T*"1E;G1R>2T^
M;6%I;&)O>"D@)B8*("`@("`@("`@("`@("`@("1E;G1R>2T^;6%I;&)O>"`A
M/2`G=6YD:7-C;&]S960M<F5C:7!I96YT<R<@)B8*("`@("`@("`@("`@("`@
M("1E;G1R>2T^;6%I;&)O>"`A/2`G54Y%6%!%0U1%1%]$051!7T%&5$527T%$
M1%)%4U,G*2!["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&5N=')Y+3YH
M;W-T*2D@>PH@("`@("`@("`@("`@("`@("`@("1A9&1R97-S3&ES=%M=(#T@
M)&5N=')Y+3YM86EL8F]X("X@)T`G("X@)&5N=')Y+3YH;W-T.PH@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D861D<F5S
M<TQI<W1;72`]("1E;G1R>2T^;6%I;&)O>#L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1M=6QT
M:7!L92`_("1A9&1R97-S3&ES="`Z(&%R<F%Y7W!O<"@D861D<F5S<TQI<W0I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@475O=&5S(&%N9"!E<V-A<&5S('1H
M92!G:79E;B!S=')I;F<@:68@;F5C97-S87)Y+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T
M<B`@("`@5&AE('-T<FEN9R!T;R!B92!Q=6]T960@86YD(&5S8V%P960N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1F:6QT97(@($$@;&ES="!O9B!C:&%R86-T
M97)S('1H870@;6%K92!I="!N96-E<W-A<GD@=&\*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@<75O=&4@=&AE('-T<FEN9R!I9B!T:&5Y(&]C8W5R
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8V]R<F5C=&QY
M('%U;W1E9"!A;F0@97-C87!E9"!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]R9F,X,C)%;F-O9&4H)'-T<BP@)&9I;'1E<B`]("<G*0H@("`@>PH@
M("`@("`@(&EF("AE;7!T>2@D9FEL=&5R*2D@>PH@("`@("`@("`@("`D=F%R
M<R`](&=E=%]C;&%S<U]V87)S*"=-24U%)RD["B`@("`@("`@("`@("1F:6QT
M97(@/2`D=F%R<ULG<F9C.#(R7V9I;'1E<B==("X@)R`G.PH@("`@("`@('T*
M"B`@("`@("`@+R\@4W1R:7`@9&]U8FQE('%U;W1E<R!I9B!T:&5Y(&%R92!A
M<F]U;F0@=&AE('-T<FEN9R!A;')E861Y+@H@("`@("`@(&EF("AS=6)S='(H
M)'-T<BP@,"P@,2D@/3T@)R(G("8F('-U8G-T<B@D<W1R+"`M,2D@/3T@)R(G
M*2!["B`@("`@("`@("`@("1S='(@/2!S=6)S='(H)'-T<BP@,2P@+3$I.PH@
M("`@("`@('T*"B`@("`@("`@:68@*'-T<F-S<&XH)'-T<BP@)&9I;'1E<BD@
M(3T@<W1R;&5N*"1S='(I*2!["B`@("`@("`@("`@("1S='(@/2!S=')?<F5P
M;&%C92@G7"(G+"`G(B<L("1S='(I.PH@("`@("`@("`@("!R971U<FX@)R(G
M("X@<W1R7W)E<&QA8V4H)R(G+"`G7%PB)RP@<W1R7W)E<&QA8V4H)UQ<)RP@
M)UQ<7%PG+"`D<W1R*2D@+B`G(B<["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@<F5T=7)N("1S='(["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@34E-12!T>7!E(&9O<B!T:&4@9VEV96X@:6YP
M=70N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1I;G!U="`@("`@16ET
M:&5R('1H92!-24U%(&-O9&4@;W(@='EP92!S=')I;F<N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D9F]R;6%T("!)9B!-24U%7T-/1$4L(')E='5R;B!C;V1E
M+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@268@34E-15]35%))
M3D<L(')E='5R;G,@;&]W97)C87-E('-T<FEN9RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!3964@86)O=F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('1Y<&4H)&EN<'5T+"`D9F]R;6%T(#T@;G5L;"D*("`@('L*("`@("`@("!R
M971U<FX@34E-13HZ7V=E=$-O9&4H)&EN<'5T+"`D9F]R;6%T+"`G;6EM95]T
M>7!E<R<I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@34E-
M12!E;F-O9&EN9R!F;W(@=&AE(&=I=F5N(&EN<'5T+@H@("`@("H*("`@("`J
M($!P87)A;2!M:7AE9"`D:6YP=70@("`@($5I=&AE<B!T:&4@34E-12!C;V1E
M(&]R(&5N8V]D:6YG('-T<FEN9RX*("`@("`J($!P87)A;2!I;G1E9V5R("1F
M;W)M870@($EF($U)345?0T]$12P@<F5T=7)N(&-O9&4N"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("!)9B!-24U%7U-44DE.1RP@<F5T=7)N<R!L
M;W=E<F-A<V4@<W1R:6YG+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@268@;F]T('-E="P@<F5T=7)N<R!T:&4@;W!P;W-I=&4@=F%L=64N"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@4V5E(&%B;W9E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!E;F-O9&EN9R@D:6YP=70L("1F;W)M870@/2!N=6QL
M*0H@("`@>PH@("`@("`@(')E='5R;B!-24U%.CI?9V5T0V]D92@D:6YP=70L
M("1F;W)M870L("=M:6UE7V5N8V]D:6YG<R<I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T<FEE=F5S($U)344@96YC;V1I;F<O='EP92!D871A(&9R;VT@
M=&AE(&EN=&5R;F%L(&%R<F%Y<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&EN<'5T("`@($5I
M=&AE<B!T:&4@34E-12!C;V1E(&]R(&5N8V]D:6YG('-T<FEN9RX*("`@("`J
M($!P87)A;2!S=')I;F<@)&9O<FUA="`@268@34E-15]#3T1%+"!R971U<FYS
M(&-O9&4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@($EF($U)345?
M4U1224Y'+"!R971U<FYS(&QO=V5R8V%S92!S=')I;F<N"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@($EF(&YU;&PL(')E='5R;G,@=&AE(&]P<'!O
M<VET92!V86QU92X*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@("`@5&AE
M(&YA;64@;V8@=&AE(&EN=&5R;F%L(&%R<F%Y+@H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@(%-E92!A8F]V92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V=E=$-O9&4H)&EN<'5T+"`D9F]R;6%T+"`D='EP92D*("`@('L*("`@("`@
M("`D;G5M97)I8R`](&ES7VYU;65R:6,H)&EN<'5T*3L*("`@("`@("!I9B`H
M(21N=6UE<FEC*2!["B`@("`@("`@("`@("1I;G!U="`](%-T<FEN9SHZ;&]W
M97(H)&EN<'5T*3L*("`@("`@("!]"@H@("`@("`@('-W:71C:"`H)&9O<FUA
M="D@>PH@("`@("`@(&-A<V4@34E-15]#3T1%.@H@("`@("`@("`@("!I9B`H
M)&YU;65R:6,I(')E='5R;B`D:6YP=70["B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!C87-E($U)345?4U1224Y'.@H@("`@("`@("`@("!I9B`H(21N
M=6UE<FEC*2!R971U<FX@)&EN<'5T.PH@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("!]"@H@("`@("`@("1V87)S(#T@9V5T7V-L87-S7W9A<G,H)TU)344G
M*3L*"B`@("`@("`@:68@*"1N=6UE<FEC*2!["B`@("`@("`@("`@(&EF("AI
M<W-E="@D=F%R<ULD='EP95U;)&EN<'5T72DI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D=F%R<ULD='EP95U;)&EN<'5T73L*("`@("`@("`@("`@?0H@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@H)'-E87)C:"`](&%R
M<F%Y7W-E87)C:"@D:6YP=70L("1V87)S6R1T>7!E72DI*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)'-E87)C:#L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!'96YE<F%T97,@82!-97-S86=E+4E$('-T<FEN9R!C;VYF;W)M:6YG('1O
M(%)&0R`R.#(R(%LS+C8N-%T@86YD('1H90H@("`@("H@<W1A;F1A<F1S(&]U
M=&QI;F5D(&EN("=D<F%F="UI971F+75S969O<BUM97-S86=E+6ED+3`Q+G1X
M="<N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@02!M97-S86=E($E$
M('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5N97)A=&5-97-S86=E
M240H*0H@("`@>PH@("`@("`@(')E='5R;B`G/"<@+B!D871E*"=9;61(:7,G
M*2`N("<N)R`N"B`@("`@("`@("`@('-U8G-T<BAB87-E7V-O;G9E<G0H;6EC
M<F]T:6UE*"D@+B!M=%]R86YD*"DL(#$P+"`S-BDL("TQ-BD@+@H@("`@("`@
M("`@("`G0"<@+B`D7U-%4E9%4ELG4T525D527TY!344G72`N("<^)SL*("`@
M('T*"B`@("`O*BH*("`@("`J($%D9',@<')O<&5R(&QI;F5B<F5A:W,@=&\@
M82!H96%D97(@<W1R:6YG+@H@("`@("H@4D9#(#(X,C(@6S(N,BXS72!S87ES
M('1H870@:&5A9&5R<R!32$]53$0@8F4@=W)A<'!E9"!A="`W."!C:&%R86-T
M97)S+@H@("`@("H@2&]W979E<BP@<VEN8V4@=V4@;6%Y(&)E(&1E86QI;F<@
M=VET:"!Q=6]T960@=&5X="!T:&%T(&-O;G1A:6YS('-P86-E<RP*("`@("`J
M('-T<FEC="!W<F%P<&EN9R!A="`W."!C:&%R86-T97)S(&UA>2!A9&0@=6YW
M86YT960@;F5W;&EN97,@86YD('1A8G,@=&\*("`@("`J('1H92!Q=6]T960@
M<&%R86UE=&5R+B`@5&AE(&-O<G)E8W0@=V%Y('1O(&=E="!A<F]U;F0@=&AI
M<R!I<R!T;R!E;F-O9&4*("`@("`J('!A<F%E=&5R<R!A8V-O<F1I;F<@=&\@
M4D9#(#(R,S$N("!(;W=E=F5R+"!S:6YC92!M;W-T(&UA:6QE<G,@9&\@;F]T
M"B`@("`@*B!S965M('1O('-U<'!O<G0@=&AI<RP@=V4@=VEL;"!I;G-T96%D
M('-I;7!L>2!U<V4@;&]N9R!L:6YE<RX@(%)&0R`R.#(R"B`@("`@*B!S87ES
M(&AE861E<G,@4TA/54Q$(&]N;'D@8F4@-S@@8VAA<F%C=&5R<R!A(&QI;F4L
M(&)U="!A;'-O('-A>7,@=&AA=`H@("`@("H@82!H96%D97(@;&EN92!-55-4
M(&YO="!B92!M;W)E('1H86X@.3DX(&-H87)A8W1E<G,N("!4:&5R969O<F4L
M('1H90H@("`@("H@8V]M<')O;6ES92!I<R!T;R!P=70@96%C:"!P87)A;65T
M97(@;VX@82!S97!A<F%T92!L:6YE(&%N9"!C:&]P(&ET"B`@("`@*B!O;FQY
M(&EF(&ET(&ES(&QO;F=E<B!T:&%N(#DY."!C:&%R86-T97)S+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&AE861E<B`@5&AE(&AE861E<B!N86UE
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@("!4:&4@=&5X="!O9B!T
M:&4@:&5A9&5R(&9I96QD+@H@("`@("H@0'!A<F%M('-T<FEN9R`D96]L("`@
M("!4:&4@14],('-T<FEN9R!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!H96%D97(@=&5X="P@=VET:"!L:6YE8G)E86MS(&EN
M<V5R=&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!W<F%P2&5A9&5R<R@D:&5A
M9&5R+"`D=&5X="P@)&5O;"`](")<<EQN(BD*("`@('L*("`@("`@("`D:&5A
M9&5R(#T@<G1R:6TH)&AE861E<BD["@H@("`@("`@("\J(%)E;6]V92!A;GD@
M97AI<W1I;F<@;&EN96)R96%K<RX@*B\*("`@("`@("`D=&5X="`]('!R96=?
M<F5P;&%C92@B+UQR/UQN7',_+R(L("<@)RP@)'1E>'0I.PH@("`@("`@("1T
M97AT(#T@)&AE861E<B`N("<Z("<@+B!R=')I;2@D=&5X="D["@H@("`@("`@
M("1E;VQL96YG=&@@/2!S=')L96XH)&5O;"D["B`@("`@("`@)&AE861E<E]L
M;W=E<B`]('-T<G1O;&]W97(H)&AE861E<BD["@H@("`@("`@(&EF("@H)&AE
M861E<E]L;W=E<B`A/2`G8V]N=&5N="UT>7!E)RD@)B8*("`@("`@("`@("`@
M*"1H96%D97)?;&]W97(@(3T@)V-O;G1E;G0M9&ES<&]S:71I;VXG*2D@>PH@
M("`@("`@("`@("`O*B!7<F%P('1H92!L:6YE+B`J+PH@("`@("`@("`@("`D
M;&EN92`]('=O<F1W<F%P*"1T97AT+"`W-2P@)&5O;"`N(")<="(I.PH*("`@
M("`@("`@("`@+RH@36%K92!S=7)E('1H97)E(&%R92!N;R!E;7!T>2!L:6YE
M<RX@*B\*("`@("`@("`@("`@)&QI;F4@/2!P<F5G7W)E<&QA8V4H)R\G("X@
M)&5O;"`N(")<=%QS*B(@+B`D96]L("X@(EQT+R(L("<O)R`N("1E;VP@+B`B
M7'0O(BP@)&QI;F4I.PH*("`@("`@("`@("`@<F5T=7)N('-U8G-T<B@D;&EN
M92P@<W1R;&5N*"1H96%D97(I("L@,BD["B`@("`@("`@?0H*("`@("`@("`O
M*B!3<&QI="!T:&4@;&EN92!B>2!T:&4@4D9#('!A<F%M971E<B!S97!A<F%T
M;W(@)SLG+B`J+PH@("`@("`@("1P87)A;7,@/2!P<F5G7W-P;&ET*"(O7',J
M.UQS*B\B+"`D=&5X="D["@H@("`@("`@("1L:6YE(#T@)R<["B`@("`@("`@
M)&QE;F=T:"`](#$P,#`@+2`D96]L;&5N9W1H.PH@("`@("`@("1P87)A;6-O
M=6YT(#T@8V]U;G0H)'!A<F%M<RD["@H@("`@("`@(&9O<F5A8V@@*"1P87)A
M;7,@87,@)&-O=6YT(#T^("1V86PI('L*("`@("`@("`@("`@+RH@268@;&]N
M9V5R('1H86X@4D9#(&%L;&]W<RP@=&AE;B!S:6UP;'D@8VAO<"!O9F8@=&AE
M(&5X8V5S<RX@*B\*("`@("`@("`@("`@)&UO<F5P87)A;7,@/2`H*"1C;W5N
M="`K(#$I("$]("1P87)A;6-O=6YT*3L*("`@("`@("`@("`@)&UA>&QE;F=T
M:"`]("1L96YG=&@@+2`H(65M<'1Y*"1L:6YE*2`_(#$@.B`P*2`M("@H)&UO
M<F5P87)A;7,I(#\@,2`Z(#`I.PH@("`@("`@("`@("!I9B`H<W1R;&5N*"1V
M86PI(#X@)&UA>&QE;F=T:"D@>PH@("`@("`@("`@("`@("`@)'9A;"`]('-U
M8G-T<B@D=F%L+"`P+"`D;6%X;&5N9W1H*3L*"B`@("`@("`@("`@("`@("`O
M*B!)9B!W92!H879E(&%N(&]P96YI;F<@<75O=&4L(&%D9"!A(&-L;W-I;F<@
M<75O=&4@869T97(*("`@("`@("`@("`@("`@("`J(&-H;W!P:6YG('1H92!R
M97-T(&]F('1H92!T97AT+B`J+PH@("`@("`@("`@("`@("`@:68@*'-T<G!O
M<R@D=F%L+"`G(B<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@
M("1V86P@/2!S=6)S='(H)'9A;"P@,"P@+3$I.PH@("`@("`@("`@("`@("`@
M("`@("1V86P@+CT@)R(G.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@:68@*"%E;7!T>2@D;&EN92DI('L*("`@("`@
M("`@("`@("`@("1L:6YE("X](")<="(["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)&QI;F4@+CT@)'9A;"`N("@H)&UO<F5P87)A;7,I(#\@)SLG(#H@
M)R<I("X@)&5O;#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!S=6)S='(H
M)&QI;F4L('-T<FQE;B@D:&5A9&5R*2`K(#(L("@D96]L;&5N9W1H("H@+3$I
M*3L*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]!<G)A>2YP:'``
M````````````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q-S$R
M,R`Q,#4Q-30S,S<T,"`P,C$Q,S<`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J(%1H92!(;W)D95]!<G)A
M>3HZ(&-L87-S('!R;W9I9&5S('9A<FEO=7,@;65T:&]D<R!F;W(@87)R87D@
M;6%N:7!U;&%T:6]N+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]5=&EL+T%R
M<F%Y+G!H<"QV(#$N,C8N,BXX(#(P,#8O,#$O,#$@,C$Z,C@Z-#$@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EC:&%E;"!3;'5S87)Z
M(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!#;W!Y<FEG:'0@
M,C`P,RTR,#`V($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J($-O
M<'ER:6=H="`R,#`S+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R
M>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0&%U=&AO<B`@
M36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H@0&%U=&AO<B`@2F%N
M(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@
M,RXP"B`J($!P86-K86=E($AO<F1E7U5T:6P*("HO"F-L87-S($AO<F1E7T%R
M<F%Y('L*"B`@("`O*BH*("`@("`J(%!R97!A<F4@82!L:7-T(&]F(&%D9')E
M<W-E<R!F;W(@<W1O<F%G92X*("`@("`J($YA;65L>2P@=')I;7,@86YD(&QO
M=V5R8V%S97,@86QL(&%D9')E<W-E<R!A;F0@=&AE;B!S;W)T+@H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D861D<B`@5&AE(&QI<W0@;V8@861D<F5S
M<V5S+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!L:7-T(&]F
M(&%D9')E<W-E<RP@<')E<&%R960@9F]R('-T;W)A9V4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('!R97!A<F5!9&1R97-S3&ES="@D861D<BD*("`@('L*("`@
M("`@("`O*B!296UO=F4@86YY(&5X=')A('-P86-E(&EN('1H92!A9&1R97-S
M(&%N9"!M86ME(&ET(&QO=V5R8V%S92X@*B\*("`@("`@("`D861D<B`](&%R
M<F%Y7VUA<"@G=')I;2<L("1A9&1R*3L*("`@("`@("`D861D<B`](&%R<F%Y
M7VUA<"AA<G)A>2@G4W1R:6YG)RP@)VQO=V5R)RDL("1A9&1R*3L*"B`@("`@
M("`@+RH@4F5M;W9E(&1U<&QI8V%T92!E;G1R:65S+B`J+PH@("`@("`@("1A
M9&1R(#T@87)R87E?=6YI<75E*"1A9&1R*3L*"B`@("`@("`@+RH@4V]R="!T
M:&4@;&ES="X@*B\*("`@("`@("!U<V]R="@D861D<BP@87)R87DH)TAO<F1E
M7T%R<F%Y)RP@)W-O<G1!9&1R97-S3&ES="<I*3L*"B`@("`@("`@<F5T=7)N
M("1A9&1R.PH@("`@?0H*("`@("\J*@H@("`@("H@1G5N8W1I;VX@=7-E9"!B
M>2!U<V]R="@I('1O('-O<G0@86X@861D<F5S<R!L:7-T+@H@("`@("H@92YG
M+B!U<V]R="@D9F]O+"!A<G)A>2@G2&]R9&5?07)R87DG+"`G<V]R=$%D9')E
M<W-,:7-T)RDI.PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&$@($%D
M9')E<W,@(S$N"B`@("`@*B!`<&%R86T@<W1R:6YG("1B("!!9&1R97-S(",R
M+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@+3$L(#`L(&]R(#$N
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-O<G1!9&1R97-S3&ES="@D82P@)&(I
M"B`@("!["B`@("`@("`@)&$@/2!E>'!L;V1E*"=`)RP@)&$I.PH@("`@("`@
M("1B(#T@97AP;&]D92@G0"<L("1B*3L*"B`@("`@("`@+RH@3VYE(&]F('1H
M92!A9&1R97-S97,@9&]E<VXG="!H879E(&$@:&]S="!N86UE+B`J+PH@("`@
M("`@(&EF("AE;7!T>2@D85LP72DI('L*("`@("`@("`@("`@87)R87E?<VAI
M9G0H)&$I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&);,%TI*2![
M"B`@("`@("`@("`@(&%R<F%Y7W-H:69T*"1B*3L*("`@("`@("!]"B`@("`@
M("`@:68@*&-O=6YT*"1A*2`A/2!C;W5N="@D8BDI('L*("`@("`@("`@("`@
M<F5T=7)N("AC;W5N="@D82D@/B!C;W5N="@D8BDI.PH@("`@("`@('T*"B`@
M("`@("`@+RH@5&AE(&%D9')E<W-E<R!H879E(&1I9F9E<F5N="!H;W-T;F%M
M92!O<B!N;W0@:&]S=&YA;64@86YD"B`@("`@("`@("`@9&EF9F5R96YT(&UA
M:6QB;W@@;F%M97,N("HO"B`@("`@("`@:68@*"1A6RAC;W5N="@D82D@+2`Q
M*5T@(3T@)&);*&-O=6YT*"1B*2`M(#$I72D@>PH@("`@("`@("`@("!R971U
M<FX@<W1R8VUP*"1A6RAC;W5N="@D82D@+2`Q*5TL("1B6RAC;W5N="@D8BD@
M+2`Q*5TI.PH@("`@("`@('T*"B`@("`@("`@+RH@0V]M<&%R92!M86EL8F]X
M(&YA;65S+B`J+PH@("`@("`@(')E='5R;B!S=')C;7`H)&%;,%TL("1B6S!=
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-O<G1S(&%N(&%R<F%Y(&]N(&$@
M<W!E8VEF:65D(&ME>2X@268@=&AE(&ME>2!D;V5S(&YO="!E>&ES="P*("`@
M("`J(&1E9F%U;'1S('1O('1H92!F:7)S="!K97D@;V8@=&AE(&%R<F%Y+@H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`F)&%R<F%Y("`@("`@(%1H92!A
M<G)A>2!T;R!B92!S;W)T960L('!A<W-E9"!B>2!R969E<F5N8V4N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1K97D@("`@("`@("!4:&4@:V5Y(&)Y('=H:6-H
M('1O('-O<G0N($EF(&YO="!S<&5C:69I960*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('1H96X@=&AE(&9I<G-T(&ME>2!I<R!U<V5D+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&1I<F5C=&EO;B`@4V]R="!D:7)E8W1I
M;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`P(#T@87-C
M96YD:6YG("AD969A=6QT*0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#$@/2!D97-C96YD:6YG"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M87-S;V-I871E("!+965P(&ME>2!V86QU92!A<W-O8VEA=&EO;C\*("`@("`J
M+PH@("`@9G5N8W1I;VX@87)R87E3;W)T*"8D87)R87DL("1K97D@/2!N=6QL
M+"`D9&ER96-T:6]N(#T@,"P@)&%S<V]C:6%T92`]('1R=64I"B`@("!["B`@
M("`@("`@+RH@4F5T=7)N(&EF('1H92!A<G)A>2!I<R!E;7!T>2X@*B\*("`@
M("`@("!I9B`H96UP='DH)&%R<F%Y*2D@>PH@("`@("`@("`@("!R971U<FX[
M"B`@("`@("`@?0H*("`@("`@("`O*B!)9B!N;R!K97D@=&\@<V]R="!B>2!I
M<R!S<&5C:69I960L('5S92!T:&4@9FER<W0@:V5Y+B`J+PH@("`@("`@(&EF
M("AI<U]N=6QL*"1K97DI*2!["B`@("`@("`@("`@("1K97ES(#T@87)R87E?
M:V5Y<RAE86-H*"1A<G)A>2DI.PH@("`@("`@("`@("`D:V5Y(#T@)&ME>7-;
M,%T["B`@("`@("`@?0H*("`@("`@("`O*B!#<F5A=&4@=&AE(&9U;F-T:6]N
M('1H870@=VEL;"!B92!U<V5D('1O('-O<G0@=&AE(&ME>7,N("HO"B`@("`@
M("`@:68@*"1D:7)E8W1I;VXI('L*("`@("`@("`@("`@)&9U;F-T:6]N(#T@
M<W!R:6YT9B@G<F5T=7)N('-T<F-O;&PH4W1R:6YG.CIL;W=E<B@D8EM<)R4Q
M)'-<)UTL('1R=64I+"!3=')I;F<Z.FQO=V5R*"1A6UPG)3$D<UPG72P@=')U
M92DI.R<L("1K97DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1F
M=6YC=&EO;B`]('-P<FEN=&8H)W)E='5R;B!S=')C;VQL*%-T<FEN9SHZ;&]W
M97(H)&%;7"<E,21S7"==+"!T<G5E*2P@4W1R:6YG.CIL;W=E<B@D8EM<)R4Q
M)'-<)UTL('1R=64I*3LG+"`D:V5Y*3L*("`@("`@("!]"@H@("`@("`@("\J
M($-A;&P@=&AE(&%P<')O<')I871E('-O<G0@9G5N8W1I;VXN("HO"B`@("`@
M("`@:68@*"1A<W-O8VEA=&4I('L*("`@("`@("`@("`@=6%S;W)T*"1A<G)A
M>2P@8W)E871E7V9U;F-T:6]N*"<D82P@)&(G+"`D9G5N8W1I;VXI*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!U<V]R="@D87)R87DL(&-R96%T
M95]F=6YC=&EO;B@G)&$L("1B)RP@)&9U;F-T:6]N*2D["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@1VEV96X@86X@2%1-3"!T>7!E(&%R<F%Y
M(&9I96QD(")E>&%M<&QE6VME>3%=6VME>3)=6VME>3-=(B!B<F5A:W,@=7`*
M("`@("`J('1H92!K97ES('-O('1H870@=&AE>2!C;W5L9"!B92!U<V5D('1O
M(')E9F5R96YC92!A(')E9W5L87(@4$A0(&%R<F%Y+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&9I96QD("!4:&4@9FEE;&0@;F%M92!T;R!B92!E
M>&%M:6YE9"X*("`@("`J($!P87)A;2!S=')I;F<@)B1B87-E("!3970@=&\@
M=&AE(&)A<V4@96QE;65N="X*("`@("`J($!P87)A;2!A<G)A>2`F)&ME>7,@
M("!3970@=&\@=&AE(&QI<W0@;V8@:V5Y<RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C97-S+"!F86QS92!O;B!E<G)O<BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T07)R87E087)T<R@D9FEE;&0L("8D
M8F%S92P@)B1K97ES*0H@("`@>PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"=\
M*%M>7%M=*BDH*%Q;6UY<6UQ=72I<72DK*7PG+"`D9FEE;&0L("1M871C:&5S
M*2D@>PH@("`@("`@("`@("`D8F%S92`]("1M871C:&5S6S%=.PH@("`@("`@
M("`@("`D:V5Y<R`](&5X<&QO9&4H)UU;)RP@)&UA=&-H97-;,ETI.PH@("`@
M("`@("`@("`D:V5Y<ULP72`]('-U8G-T<B@D:V5Y<ULP72P@,2D["B`@("`@
M("`@("`@("1K97ES6V-O=6YT*"1K97ES*2`M(#%=(#T@<W5B<W1R*"1K97ES
M6V-O=6YT*"1K97ES*2`M(#%=+"`P+"!S=')L96XH)&ME>7-;8V]U;G0H)&ME
M>7,I("T@,5TI("T@,2D["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!5<VEN9R!A;B!A<G)A>2!O9B!K
M97ES(&ET87)A=&4@=&AR;W5G:"!T:&4@87)R87D@9F]L;&]W:6YG('1H90H@
M("`@("H@:V5Y<R!T;R!F:6YD('1H92!F:6YA;"!K97D@=F%L=64N($EF(&$@
M=F%L=64@:7,@<&%S<V5D('1H96X@<V5T"B`@("`@*B!T:&%T('9A;'5E+@H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`F)&%R<F%Y("!4:&4@87)R87D@
M=&\@8F4@=7-E9"X*("`@("`J($!P87)A;2!A<G)A>2`F)&ME>7,@("!4:&4@
M:V5Y('!A=&@@=&\@9F]L;&]W(&%S(&%N(&%R<F%Y+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1V86QU92`@($EF('-E="!T:&4@=&%R9V5T(&5L96UE;G0@=VEL
M;"!H879E('1H:7,@=F%L=64@<V5T"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@=&\@:70N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE
M(&9I;F%L('9A;'5E(&]F('1H92!K97D@<&%T:"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T16QE;65N="@F)&%R<F%Y+"`F)&ME>7,L("1V86QU92`](&YU
M;&PI"B`@("!["B`@("`@("`@:68@*&-O=6YT*"1K97ES*2D@>PH@("`@("`@
M("`@("`D:V5Y(#T@87)R87E?<VAI9G0H)&ME>7,I.PH@("`@("`@("`@("!I
M9B`H:7-S970H)&%R<F%Y6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N($AO<F1E7T%R<F%Y.CIG971%;&5M96YT*"1A<G)A>5LD:V5Y72P@)&ME
M>7,L("1V86QU92D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!I9B`H(6ES7VYU;&PH)'9A;'5E*2D@>PH@("`@
M("`@("`@("`@("`@)&%R<F%Y(#T@)'9A;'5E.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(')E='5R;B`D87)R87D["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!A(')E8W1A;F=L92!O9B!A('1W;RUD:6UE
M;G-I;VYA;"!A<G)A>2X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)B1A
M<G)A>2`@("!4:&4@87)R87D@=&\@97AT<F%C="!T:&4@<F5C=&%N9VQE(&9R
M;VTN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W("`@("!4:&4@<W1A<G0@
M<F]W(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M8V]L("`@("!4:&4@<W1A<G0@8V]L=6UN(&]F('1H92!R96-T86YG;&4N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D:&5I9VAT("!4:&4@:&5I9VAT(&]F('1H
M92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D=VED=&@@("!4
M:&4@=VED=&@@;V8@=&AE(')E8W1A;F=L92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("!4:&4@97AT<F%C=&5D(')E8W1A;F=L92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@)F=E=%)E8W1A;F=L92@F)&%R<F%Y+"`D<F]W+"`D8V]L
M+"`D:&5I9VAT+"`D=VED=&@I"B`@("!["B`@("`@("`@)')E8R`](&%R<F%Y
M*"D["B`@("`@("`@9F]R("@D>2`]("1R;W<[("1Y(#P@)')O=R`K("1H96EG
M:'0[("1Y*RLI('L*("`@("`@("`@("`@)')E8UM=(#T@87)R87E?<VQI8V4H
M)&%R<F%Y6R1Y72P@)&-O;"P@)'=I9'1H*3L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("1R96,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!':79E;B!A;B!A
M<G)A>2P@<F5T=7)N<R!A;B!A<W-O8VEA=&EV92!A<G)A>2!W:71H(&5A8V@@
M96QE;65N="!K97D*("`@("`J(&1E<FEV960@9G)O;2!I=',@=F%L=64N"B`@
M("`@*B!&;W(@97AA;7!L93H*("`@("`J("`@87)R87DH,"`]/B`G9F]O)RP@
M,2`]/B`G8F%R)RD*("`@("`J('=O=6QD(&)E8V]M93H*("`@("`J("`@87)R
M87DH)V9O;R<@/3X@)V9O;R<L("=B87(G(#T^("=B87(G*0H@("`@("H*("`@
M("`J($!P87)A;2!A<G)A>2`D87)R87D@($%N(&%R<F%Y(&]F('9A;'5E<RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!W:71H(&ME
M>7,@=&AE('-A;64@87,@=F%L=65S+@H@("`@("HO"B`@("!F=6YC=&EO;B!V
M86QU97-4;TME>7,H)&%R<F%Y*0H@("`@>PH@("`@("`@("1M87!P960@/2!A
M<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1A<G)A>2!A<R`D=F%L=64I('L*
M("`@("`@("`@("`@)&UA<'!E9%LD=F%L=65=(#T@)'9A;'5E.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)&UA<'!E9#L*("`@('T*"B`@("`O*BH*("`@
M("`J($-R96%T97,@86X@87)R87D@8GD@=7-I;F<@;VYE(&%R<F%Y(&9O<B!K
M97ES(&%N9"!A;F]T:&5R(&9O<@H@("`@("H@:71S('9A;'5E<RX@3VYL>2!E
M>&ES=',@:6X@4$A0-2P@<V\@=V4@8V%L;"!A<G)A>5]C;VUB:6YE(&EF(&ET
M"B`@("`@*B!E>&ES=',@86YD(&]T:&5R=VES92!E;75L871E(&ET+@H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D:V5Y<R`@("!+97D@87)R87DN"B`@
M("`@*B!`<&%R86T@87)R87D@)'9A;'5E<R`@5F%L=64@87)R87DN"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@1F%L<V4@:68@=&AE<F4@87)E(&YO
M(&5L96UE;G1S+"!O<B!T:&4@8V]M8FEN960@87)R87DN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-O;6)I;F4H)&ME>7,L("1V86QU97,I"B`@("!["B`@("`@
M("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G87)R87E?8V]M8FEN92<I*2!["B`@
M("`@("`@("`@(')E='5R;B!A<G)A>5]C;VUB:6YE*"1K97ES+"`D=F%L=65S
M*3L*("`@("`@("!]"@H@("`@("`@("1S:7IE(#T@8V]U;G0H)&ME>7,I.PH@
M("`@("`@(&EF("@H)'-I>F4@(3T@8V]U;G0H)'9A;'5E<RDI('Q\("@D<VEZ
M92`]/2`P*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("!F;W(@*"1X(#T@,#L@)'@@/"`D<VEZ93L@)'@K*RD@>PH@
M("`@("`@("`@("`D87)R87E;)&ME>7-;)'A=72`]("1V86QU97-;)'A=.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)&%R<F%Y.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O5&]K96XN<&AP````````````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,3,U,#$@,3`U,34T,S,W-#`@,#(Q,3,U`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"@IR
M97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*"B\J*@H@*B!4:&4@2&]R9&5?5&]K
M96XZ.B!C;&%S<R!P<F]V:61E<R!A(&-O;6UO;B!A8G-T<F%C=&5D(&EN=&5R
M9F%C92!I;G1O('1H90H@*B!V87)I;W5S('1O:V5N(&=E;F5R871I;VX@;65D
M:75M<RX@270@86QS;R!I;F-L=61E<R!A;&P@;V8@=&AE"B`J(&9U;F-T:6]N
M<R!F;W(@<F5T<FEE=FEN9RP@<W1O<FEN9RP@86YD(&-H96-K:6YG('1O:V5N
M<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&]K96XO5&]K96XN<&AP+'8@
M,2XS,RXV+C@@,C`P-B\P-"\Q.2`R,3HQ-#HP-2!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#$Y.3DM,C`P-B!-87@@2V%L:6MA(#QM87A`:&]R9&4N;W)G
M/@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU
M8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36%X
M($MA;&EK82`\;6%X0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@0VAU8VL@2&%G
M96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N
M,PH@*B!`<&%C:V%G92!(;W)D95]4;VME;@H@*B\*8VQA<W,@2&]R9&5?5&]K
M96X@>PH*("`@("\J*@H@("`@("H@2&%S:"!O9B!P87)A;65T97)S(&YE8V5S
M<V%R>2!T;R!U<V4@=&AE(&-H;W-E;B!B86-K96YD+@H@("`@("H*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<&%R86US(#T@87)R87DH
M*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!P87)A
M;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]4;VME;B@D<&%R
M86US(#T@87)R87DH*2D*("`@('L*("`@('T*"B`@("!F=6YC=&EO;B!E;F-O
M9&5296UO=&5!9&1R97-S*"D*("`@('L*("`@("`@("!I9B`H:7-S970H)%]3
M15)615);)U)%34]415]!1$12)UTI*2!["B`@("`@("`@("`@(')E='5R;B!B
M87-E-C1?96YC;V1E*"1?4T525D526R=214U/5$5?041$4B==*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@1V5N97)A=&5S(&$@8V]N;F5C=&EO;B!I
M9"!A;F0@<F5T=7)N<R!I="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1S965D("!!('5N:7%U92!)1"!T;R!B92!I;F-L=61E9"!I;B!T:&4@=&]K
M96XL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!I9B!I="!N965D<R!T
M;R!B92!M;W)E('5N:7%U92!T:&%N('1I;64@*&EN('-E8V]N9',I"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("!A;F0@=&AE(')E;6]T92!)4"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@(%1H92!G96YE<F%T960@:60@
M<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!G96YE<F%T94ED*"1S965D
M(#T@)R<I"B`@("!["B`@("`@("`@<F5T=7)N(&UD-2AT:6UE*"D@+B`G75LG
M("X@)'-E960@+B`G75LG("X@2&]R9&5?5&]K96XZ.F5N8V]D95)E;6]T94%D
M9')E<W,H*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@:68@=&AE
M(&=I=F5N('1O:V5N(&AA<R!B965N('!R979I;W5S;'D@=7-E9"X@1FER<W0*
M("`@("`J('!U<F=E<R!A;&P@97AP:7)E9"!T;VME;G,N(%1H96X@<F5T<FEE
M=F5S(&-U<G)E;G0@=&]K96YS(&9O<@H@("`@("H@=&AE(&=I=F5N(&EP(&%D
M9')E<W,N($EF('1H92!S<&5C:69I960@=&]K96X@=V%S(&YO="!F;W5N9"P*
M("`@("`J(&%D9',@:70N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=&]K96X@(%1H92!V86QU92!O9B!T:&4@=&]K96X@=&\@8VAE8VLN"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("`@("`@(%1R=64@:68@=&AE('1O
M:V5N(&AA<R!N;W0@8F5E;B!U<V5D+`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M=F5R:69Y*"1T;VME;BD*("`@('L*("`@("`@("`D=&AI<RT^<'5R9V4H*3L*
M("`@("`@("`D97AI<W1S(#T@)'1H:7,M/F5X:7-T<R@D=&]K96XI.PH@("`@
M("`@(&EF("AI<U]A*"1E>&ES=',L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1E>&ES=',["B`@("`@("`@?2!E;'-E:68@*"1E>&ES
M=',I('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^861D*"1T;VME;BD["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@5&AI<R!I<R!A;B!A8G-T
M<F%C="!M971H;V0@=&AA="!S:&]U;&0@8F4@;W9E<G)I9&1E;B!B>2!A"B`@
M("`@*B!S=6)C;&%S<R!I;7!L96UE;G1A=&EO;BX@5&AE(&)A<V4@:6UP;&5M
M96YT871I;VX@86QL;W=S(&%L;`H@("`@("H@=&]K96X@=F%L=65S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!E>&ES=',H*0H@("`@>PH@("`@("`@(')E='5R
M;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@:7,@86X@86)S
M=')A8W0@;65T:&]D('1H870@<VAO=6QD(&)E(&]V97)R:61D96X@8GD@80H@
M("`@("H@<W5B8VQA<W,@:6UP;&5M96YT871I;VXN(%1H92!B87-E(&EM<&QE
M;65N=&%T:6]N(&%L;&]W<R!A;&P*("`@("`J('1O:V5N('9A;'5E<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@861D*"D*("`@('L*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@:7,@86X@86)S=')A
M8W0@;65T:&]D('1H870@<VAO=6QD(&)E(&]V97)R:61D96X@8GD@80H@("`@
M("H@<W5B8VQA<W,@:6UP;&5M96YT871I;VXN(%1H92!B87-E(&EM<&QE;65N
M=&%T:6]N(&%L;&]W<R!A;&P*("`@("`J('1O:V5N('9A;'5E<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@<'5R9V4H*0H@("`@>PH@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N
M(&$@8V]N8W)E=&4@2&]R9&5?5&]K96X@:6YS=&%N8V4@8F%S960@;VX@)&1R
M:79E<BX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&1R:79E<B`@5&AE
M('1Y<&4@;V8@8V]N8W)E=&4@2&]R9&5?5&]K96X@<W5B8VQA<W,@=&\*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("!R971U<FXN($EF("1D<FEV97(@
M:7,@86X@87)R87DL('1H96X@=V4@=VEL;"!L;V]K"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@:6X@)&1R:79E<ELP72]L:6(O5&]K96XO(&9O<B!T
M:&4@<W5B8VQA<W,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!I;7!L
M96UE;G1A=&EO;B!N86UE9"`D9')I=F5R6S%=+G!H<"X*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@861D:71I
M;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@8V]N;F5C=&EO;B!P87)A;65T97)S(&$@<W5B8VQA<W,@;6EG:'0@
M;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N($AO<F1E7U1O:V5N("!4:&4@
M;F5W;'D@8W)E871E9"!C;VYC<F5T92!(;W)D95]4;VME;B!I;G-T86YC92P@
M;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@(&9A;'-E(&%N(&5R<F]R
M+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D9')I=F5R+"`D<&%R
M86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH)&1R
M:79E<BDI('L*("`@("`@("`@("`@;&ES="@D87!P+"`D9')I=F5R*2`]("1D
M<FEV97(["B`@("`@("`@?0H*("`@("`@("`D9')I=F5R(#T@8F%S96YA;64H
M)&1R:79E<BD["@H@("`@("`@(&EF("@A96UP='DH)&%P<"DI('L*("`@("`@
M("`@("`@<F5Q=6ER95]O;F-E("1A<'`@+B`G+VQI8B]4;VME;B\G("X@)&1R
M:79E<B`N("<N<&AP)SL*("`@("`@("!](&5L<V5I9B`H0&9I;&5?97AI<W1S
M*&1I<FYA;64H7U]&24Q%7U\I("X@)R]4;VME;B\G("X@)&1R:79E<B`N("<N
M<&AP)RDI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&
M24Q%7U\I("X@)R]4;VME;B\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!`:6YC;'5D95]O;F-E("=(;W)D92]4
M;VME;B\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!]"@H@("`@("`@
M("1C;&%S<R`]("=(;W)D95]4;VME;E\G("X@)&1R:79E<CL*("`@("`@("!I
M9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@)'1O:V5N
M(#T@)FYE=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'1O:V5N(#T@)FYE=R!(;W)D95]4;VME;B@D<&%R86US*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&]K96X["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!R969E<F5N8V4@=&\@
M82!C;VYC<F5T92!(;W)D95]4;VME;B!I;G-T86YC92!B87-E9`H@("`@("H@
M;VX@)&1R:79E<BX*("`@("`J"B`@("`@*B!)="!W:6QL(&]N;'D@8W)E871E
M(&$@;F5W(&EN<W1A;F-E(&EF(&YO($AO<F1E7U1O:V5N(&EN<W1A;F-E('=I
M=&@@=&AE"B`@("`@*B!S86UE('!A<F%M971E<G,@8W5R<F5N=&QY(&5X:7-T
M<RX*("`@("`J"B`@("`@*B!4:&ES('-H;W5L9"!B92!U<V5D(&EF(&UU;'1I
M<&QE('1Y<&5S(&]F('1O:V5N(&=E;F5R871O<G,@*&%N9"P@=&AU<RP*("`@
M("`J(&UU;'1I<&QE($AO<F1E7U1O:V5N(&EN<W1A;F-E<RD@87)E(')E<75I
M<F5D+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME
M9"!A<SH*("`@("`J(#QC;V1E/B1V87(@/2`F2&]R9&5?5&]K96XZ.G-I;F=L
M971O;B@I.SPO8V]D93X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&1R
M:79E<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@2&]R9&5?5&]K96X@<W5B8VQA
M<W,@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!R971U<FXN($EF
M("1D<FEV97(@:7,@86X@87)R87DL('1H96X@=V4@=VEL;"!L;V]K"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@:6X@)&1R:79E<ELP72]L:6(O5&]K
M96XO(&9O<B!T:&4@<W5B8VQA<W,*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!I;7!L96UE;G1A=&EO;B!N86UE9"`D9')I=F5R6S%=+G!H<"X*("`@
M("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!A
M;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P87)A;65T97)S(&$@<W5B8VQA
M<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N($AO<F1E7U1O
M:V5N("!4:&4@8V]N8W)E=&4@2&]R9&5?5&]K96X@<F5F97)E;F-E+"!O<B!F
M86QS92!O;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@97)R;W(N"B`@
M("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)&1R:79E<BP@)'!A<F%M
M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T86YC97,[
M"B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S*2D@>PH@("`@("`@("`@
M("`D:6YS=&%N8V5S(#T@87)R87DH*3L*("`@("`@("!]"@H@("`@("`@("1S
M:6=N871U<F4@/2!S97)I86QI>F4H87)R87DH)&1R:79E<BP@)'!A<F%M<RDI
M.PH@("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E<ULD<VEG;F%T=7)E72DI
M('L*("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E72`]("9(;W)D
M95]4;VME;CHZ9F%C=&]R>2@D9')I=F5R+"`D<&%R86US*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D:6YS=&%N8V5S6R1S:6=N871U<F5=.PH@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92]);6%G92YP:'``````````````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`S-3,W-"`Q,#4Q-30S,S<T,"`P,C$Q,3,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"G)E<75I
M<F5?;VYC92`G2&]R9&4O571I;"YP:'`G.PH*+RHJ"B`J(%1H:7,@8VQA<W,@
M9&5F:6YE<R!T:&4@2&]R9&5?26UA9V4Z.B!!4$DL(&%N9"!A;'-O('!R;W9I
M9&5S('-O;64*("H@=71I;&ET>2!F=6YC=&EO;G,L('-U8V@@87,@9V5N97)A
M=&EN9R!H:6=H;&EG:'1S(&]F(&$@8V]L;W(N"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+TEM86=E+TEM86=E+G!H<"QV(#$N,SDN,3`N,3,@,C`P-B\P,2\P
M,2`R,3HR.#HR,B!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P
M-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R
M9&5?26UA9V4*("HO"F-L87-S($AO<F1E7TEM86=E('L*"B`@("`O*BH*("`@
M("`J($-U<G)E;G0@8V]L;W(N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J+PH@("`@=F%R("1?<F=B(#T@)V9F,#`P,"<["@H@("`@+RHJ"B`@
M("`@*B!"86-K9W)O=6YD(&-O;&]R+@H@("`@("H*("`@("`J($!V87(@<W1R
M:6YG"B`@("`@*B\*("`@('9A<B`D7V)A8VMG<F]U;F0@/2`G=VAI=&4G.PH*
M("`@("\J*@H@("`@("H@3V)S97)V97)S+@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1?;V)S97)V97)S(#T@87)R87DH*3L*
M"B`@("`O*BH*("`@("`J($-A<&%B:6QI=&5S(&]F('1H:7,@9')I=F5R+@H@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?8V%P
M86)I;&ET:65S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1H92!C=7)R
M96YT(&EM86=E(&1A=&$N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@
M("`J+PH@("`@=F%R("1?9&%T82`]("<G.PH*("`@("\J*@H@("`@("H@5&AE
M(&-U<G)E;G0@:6UA9V4@:60N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J+PH@("`@=F%R("1?:60@/2`G)SL*"B`@("`O*BH*("`@("`J(%1H
M92!C=7)R96YT('=I9'1H(&]F('1H92!I;6%G92!D871A+@H@("`@("H*("`@
M("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]W:61T:"`](#`[
M"@H@("`@+RHJ"B`@("`@*B!4:&4@8W5R<F5N="!H96EG:'0@;V8@=&AE(&EM
M86=E(&1A=&$N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*
M("`@('9A<B`D7VAE:6=H="`](#`["@H@("`@+RHJ"B`@("`@*B!!(&1I<F5C
M=&]R>2!F;W(@=&5M<&]R87)Y(&9I;&5S+@H@("`@("H*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W1M<&1I<CL*"B`@("`O*BH*("`@
M("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)')G8B`@5&AE(&)A<V4@8V]L;W(@9F]R(&=E;F5R871E9"!P:7AE;',O:6UA
M9V5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]);6%G92@D<&%R86US
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=&UP9&ER(#T@)'!A<F%M<ULG=&5M
M<"==.PH@("`@("`@(&EF("AI<W-E="@D<&%R86US6R=W:61T:"==*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7W=I9'1H(#T@)'!A<F%M<ULG=VED=&@G73L*
M("`@("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1P87)A;7-;)VAE:6=H="==
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VAE:6=H="`]("1P87)A;7-;)VAE
M:6=H="==.PH@("`@("`@('T*("`@("`@("!I9B`H(65M<'1Y*"1P87)A;7-;
M)W)G8B==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W)G8B`]("1P87)A;7-;
M)W)G8B==.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7V)A8VMG<F]U;F0@
M/2!I<W-E="@D<&%R86US6R=B86-K9W)O=6YD)UTI(#\@)'!A<F%M<ULG8F%C
M:V=R;W5N9"==(#H@)W=H:71E)SL*("`@('T*"B`@("!F=6YC=&EO;B!G971#
M87!A8FEL:71I97,H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V-A
M<&%B:6QI=&EE<SL*("`@('T*"B`@("!F=6YC=&EO;B!H87-#87!A8FEL:71Y
M*"1C87!A8FEL:71Y*0H@("`@>PH@("`@("`@(')E='5R;B!I;E]A<G)A>2@D
M8V%P86)I;&ET>2P@)'1H:7,M/E]C87!A8FEL:71I97,I.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&=E=$QI;FLH)'5R;"P@)'1I=&QE(#T@)R<I"B`@("!["B`@
M("`@("`@<F5T=7)N($AO<F1E.CII;6<H)'5R;"P@)'1I=&QE+"`G)RP@)R<I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5N97)A=&4@:6UA9V4@:&5A9&5R
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@:&5A9&5R<R@I"B`@("!["B`@("`@
M("`@:&5A9&5R*"=#;VYT96YT+71Y<&4Z("<@+B`D=&AI<RT^9V5T0V]N=&5N
M=%1Y<&4H*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#86QC=6QA=&4@82!L
M:6=H=&5R("AO<B!D87)K97(I('9E<G-I;VX@;V8@82!C;VQO<BX*("`@("`J
M"B`@("`@*B!`<W1A=&EC"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M8V]L;W(@("!!;B!(5$U,(&-O;&]R+"!E+F<N.B`C9F9F9F-C+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D9F%C=&]R("!43T1/"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@($$@;6]D:69I960@2%1-3"!C;VQO<BX*("`@("`J+PH@
M("`@9G5N8W1I;VX@;6]D:69Y0V]L;W(H)&-O;&]R+"`D9F%C=&]R(#T@,'@Q
M,2D*("`@('L*("`@("`@("`D<B`](&AE>&1E8RAS=6)S='(H)&-O;&]R+"`Q
M+"`R*2D@*R`D9F%C=&]R.PH@("`@("`@("1G(#T@:&5X9&5C*'-U8G-T<B@D
M8V]L;W(L(#,L(#(I*2`K("1F86-T;W(["B`@("`@("`@)&(@/2!H97AD96,H
M<W5B<W1R*"1C;VQO<BP@-2P@,BDI("L@)&9A8W1O<CL*"B`@("`@("`@)'(@
M/2!M:6XH;6%X*"1R+"`P*2P@,C4U*3L*("`@("`@("`D9R`](&UI;BAM87@H
M)&<L(#`I+"`R-34I.PH@("`@("`@("1B(#T@;6EN*&UA>"@D8BP@,"DL(#(U
M-2D["@H@("`@("`@(')E='5R;B`G(R<@+B!S=')?<&%D*&1E8VAE>"@D<BDL
M(#(L("<P)RP@4U127U!!1%],1494*2`N('-T<E]P860H9&5C:&5X*"1G*2P@
M,BP@)S`G+"!35%)?4$%$7TQ%1E0I("X@<W1R7W!A9"AD96-H97@H)&(I+"`R
M+"`G,"<L(%-44E]0041?3$5&5"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M86QC=6QA=&4@82!M;W)E(&EN=&5N<V4@=F5R<VEO;B!O9B!A(&-O;&]R+@H@
M("`@("H*("`@("`J($!S=&%T:6,*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1C;VQO<B`@($%N($A434P@8V]L;W(L(&4N9RXZ("-F9F9F8V,N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1F86-T;W(@(%1/1$\*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@02!M;W)E(&EN=&5N<V4@2%1-3"!C;VQO<BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@;6]R94EN=&5N<V5#;VQO<B@D8V]L;W(L
M("1F86-T;W(@/2`P>#$Q*0H@("`@>PH@("`@("`@("1R(#T@:&5X9&5C*'-U
M8G-T<B@D8V]L;W(L(#$L(#(I*3L*("`@("`@("`D9R`](&AE>&1E8RAS=6)S
M='(H)&-O;&]R+"`S+"`R*2D["B`@("`@("`@)&(@/2!H97AD96,H<W5B<W1R
M*"1C;VQO<BP@-2P@,BDI.PH*("`@("`@("!I9B`H)'(@/CT@)&<@)B8@)'(@
M/CT@)&(I('L*("`@("`@("`@("`@)&<@/2`D9R`O("1R.PH@("`@("`@("`@
M("`D8B`]("1B("\@)'(["@H@("`@("`@("`@("`D<B`K/2`D9F%C=&]R.PH@
M("`@("`@("`@("`D9R`](&9L;V]R*"1G("H@)'(I.PH@("`@("`@("`@("`D
M8B`](&9L;V]R*"1B("H@)'(I.PH@("`@("`@('T@96QS96EF("@D9R`^/2`D
M<B`F)B`D9R`^/2`D8BD@>PH@("`@("`@("`@("`D<B`]("1R("\@)&<["B`@
M("`@("`@("`@("1B(#T@)&(@+R`D9SL*"B`@("`@("`@("`@("1G("L]("1F
M86-T;W(["B`@("`@("`@("`@("1R(#T@9FQO;W(H)'(@*B`D9RD["B`@("`@
M("`@("`@("1B(#T@9FQO;W(H)&(@*B`D9RD["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'(@/2`D<B`O("1B.PH@("`@("`@("`@("`D9R`]("1G
M("\@)&(["@H@("`@("`@("`@("`D8B`K/2`D9F%C=&]R.PH@("`@("`@("`@
M("`D<B`](&9L;V]R*"1R("H@)&(I.PH@("`@("`@("`@("`D9R`](&9L;V]R
M*"1G("H@)&(I.PH@("`@("`@('T*"B`@("`@("`@)'(@/2!M:6XH;6%X*"1R
M+"`P*2P@,C4U*3L*("`@("`@("`D9R`](&UI;BAM87@H)&<L(#`I+"`R-34I
M.PH@("`@("`@("1B(#T@;6EN*&UA>"@D8BP@,"DL(#(U-2D["@H@("`@("`@
M(')E='5R;B`G(R<@+B!S=')?<&%D*&1E8VAE>"@D<BDL(#(L("<P)RP@4U12
M7U!!1%],1494*2`N('-T<E]P860H9&5C:&5X*"1G*2P@,BP@)S`G+"!35%)?
M4$%$7TQ%1E0I("X@<W1R7W!A9"AD96-H97@H)&(I+"`R+"`G,"<L(%-44E]0
M041?3$5&5"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!B
M<FEG:'1N97-S(&]F(&$@8V]L;W(N"B`@("`@*@H@("`@("H@0'-T871I8PH@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-O;&]R("!!;B!(5$U,(&-O
M;&]R+"!E+F<N.B`C9F9F9F-C+@H@("`@("H*("`@("`J($!R971U<FX@:6YT
M96=E<B`@5&AE(&)R:6=H=&YE<W,@;VX@82!S8V%L92!O9B`P('1O(#(U-2X*
M("`@("`J+PH@("`@9G5N8W1I;VX@8G)I9VAT;F5S<R@D8V]L;W(I"B`@("![
M"B`@("`@("`@)'(@/2!H97AD96,H<W5B<W1R*"1C;VQO<BP@,2P@,BDI.PH@
M("`@("`@("1G(#T@:&5X9&5C*'-U8G-T<B@D8V]L;W(L(#,L(#(I*3L*("`@
M("`@("`D8B`](&AE>&1E8RAS=6)S='(H)&-O;&]R+"`U+"`R*2D["@H@("`@
M("`@(')E='5R;B!R;W5N9"@H*"1R("H@,CDY*2`K("@D9R`J(#4X-RD@*R`H
M)&(@*B`Q,30I*2`O(#$P,#`I.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%)'
M0B@D8V]L;W)N86UE*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92!D:7)N
M86UE*%]?1DE,15]?*2`N("<O26UA9V4O<F=B+G!H<"<["B`@("`@("`@<F5T
M=7)N(&ES<V5T*"1'3$]"04Q36R=H;W)D95]I;6%G95]R9V)?8V]L;W)S)UU;
M)&-O;&]R;F%M95TI(#\*("`@("`@("`@("`@)$=,3T)!3%-;)VAO<F1E7VEM
M86=E7W)G8E]C;VQO<G,G75LD8V]L;W)N86UE72`Z"B`@("`@("`@("`@(&%R
M<F%Y*#`L(#`L(#`I.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$AE>$-O;&]R
M*"1C;VQO<FYA;64I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA
M;64H7U]&24Q%7U\I("X@)R]);6%G92]R9V(N<&AP)SL*("`@("`@("!I9B`H
M:7-S970H)$=,3T)!3%-;)VAO<F1E7VEM86=E7W)G8E]C;VQO<G,G75LD8V]L
M;W)N86UE72DI('L*("`@("`@("`@("`@;&ES="@D<BP@)&<L("1B*2`]("1'
M3$]"04Q36R=H;W)D95]I;6%G95]R9V)?8V]L;W)S)UU;)&-O;&]R;F%M95T[
M"B`@("`@("`@("`@(')E='5R;B`G(R<@+B!S=')?<&%D*&1E8VAE>"AM:6XH
M)'(L(#(U-2DI+"`R+"`G,"<L(%-44E]0041?3$5&5"D@+B!S=')?<&%D*&1E
M8VAE>"AM:6XH)&<L(#(U-2DI+"`R+"`G,"<L(%-44E]0041?3$5&5"D@+B!S
M=')?<&%D*&1E8VAE>"AM:6XH)&(L(#(U-2DI+"`R+"`G,"<L(%-44E]0041?
M3$5&5"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("=B
M;&%C:R<["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A
M('-H87!E9"!P;VEN="!A="!T:&4@<W!E8VEF:65D("AX+'DI('!O:6YT+B!5
M<V5F=6P@9F]R"B`@("`@*B!S8V%T=&5R(&1I86=R86US+"!D96)U9R!P;VEN
M=',L(&5T8RX@1')A=W,@<W%U87)E<RP@8VER8VQE<RP*("`@("`J(&1I86UO
M;F1S+"!A;F0@=')I86YG;&5S+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E
M9V5R("1X("`@("!4:&4@>"!C;V]R9&EN871E(&]F('1H92!P;VEN="!T;R!B
M<G5S:"X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y("`@("!4:&4@>2!C;V]R
M9&EN871E(&]F('1H92!P;VEN="!T;R!B<G5S:"X*("`@("`J($!P87)A;2!S
M=')I;F<@)&-O;&]R("!4:&4@8V]L;W(@=&\@8G)U<V@@=&AE('!O:6YT('=I
M=&@N"B`@("`@*B!`<&%R86T@<W1R:6YG("1S:&%P92`@5VAA="!B<G5S:"!T
M;R!U<V4_($1E9F%U;'1S('1O(&$@<W%U87)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!B<G5S:"@D>"P@)'DL("1C;VQO<B`]("=B;&%C:R<L("1S:&%P92`]
M("=S<75A<F4G*0H@("`@>PH@("`@("`@('-W:71C:"`H)'-H87!E*2!["B`@
M("`@("`@8V%S92`G=')I86YG;&4G.@H@("`@("`@("`@("`D=F5R='-;,%T@
M/2!A<G)A>2@G>"<@/3X@)'@@*R`S+"`G>2<@/3X@)'D@*R`S*3L*("`@("`@
M("`@("`@)'9E<G1S6S%=(#T@87)R87DH)W@G(#T^("1X+"`G>2<@/3X@)'D@
M+2`S*3L*("`@("`@("`@("`@)'9E<G1S6S)=(#T@87)R87DH)W@G(#T^("1X
M("T@,RP@)WDG(#T^("1Y("L@,RD["B`@("`@("`@("`@("1T:&ES+3YP;VQY
M9V]N*"1V97)T<RP@)&-O;&]R+"`D8V]L;W(I.PH@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@8V%S92`G8VER8VQE)SH*("`@("`@("`@("`@)'1H:7,M
M/F-I<F-L92@D>"P@)'DL(#,L("1C;VQO<BP@)&-O;&]R*3L*("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@(&-A<V4@)V1I86UO;F0G.@H@("`@("`@("`@
M("`D=F5R='-;,%T@/2!A<G)A>2@G>"<@/3X@)'@@+2`S+"`G>2<@/3X@)'DI
M.PH@("`@("`@("`@("`D=F5R='-;,5T@/2!A<G)A>2@G>"<@/3X@)'@L("=Y
M)R`]/B`D>2`K(#,I.PH@("`@("`@("`@("`D=F5R='-;,ET@/2!A<G)A>2@G
M>"<@/3X@)'@@*R`S+"`G>2<@/3X@)'DI.PH@("`@("`@("`@("`D=F5R='-;
M,UT@/2!A<G)A>2@G>"<@/3X@)'@L("=Y)R`]/B`D>2`M(#,I.PH@("`@("`@
M("`@("`D=&AI<RT^<&]L>6=O;B@D=F5R=',L("1C;VQO<BP@)&-O;&]R*3L*
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)W-Q=6%R92<Z"B`@
M("`@("`@9&5F875L=#H*("`@("`@("`@("`@)'1H:7,M/G)E8W1A;F=L92@D
M>"`M(#(L("1Y("T@,BP@-"P@-"P@)&-O;&]R+"`D8V]L;W(I.PH@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!
M9&0@86X@;V)S97)V97(@=&\@=&AI<R!I;6%G92X@5&AE(&]B<V5R=F5R('=I
M;&P@8F4@;F]T:69I960*("`@("`J('=H96X@=&AE(&EM86=E)W,@8VAA;F=E
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@861D3V)S97)V97(H)&UE=&AO9"P@
M)B1O8FIE8W0I"B`@("!["B`@("`@("`@)'1H:7,M/E]O8G-E<G9E<G-;72`]
M(&%R<F%Y*"1M971H;V0L("8D;V)J96-T*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($QE="!O8G-E<G9E<G,@:VYO=R!T:&%T('-O;65T:&EN9R!H87!P96YE
M9"!W;W)T:"!A8W1I;F<@;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(&YO=&EF
M>4]B<V5R=F5R<R@I"B`@("!["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@
M8V]U;G0H)'1H:7,M/E]O8G-E<G9E<G,I.R`K*R1I*2!["B`@("`@("`@("`@
M("1O8FH@/2`F)'1H:7,M/E]O8G-E<G9E<G-;)&E=6S%=.PH@("`@("`@("`@
M("`D;65T:&]D(#T@)'1H:7,M/E]O8G-E<G9E<G-;)&E=6S!=.PH@("`@("`@
M("`@("`D;V)J+3XD;65T:&]D*"1T:&ES*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!297-E="!T:&4@:6UA9V4@9&%T82X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<F5S970H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9&%T
M82`]("<G.PH@("`@("`@("1T:&ES+3Y?:60@/2`G)SL*("`@("`@("`D=&AI
M<RT^7W=I9'1H(#T@;G5L;#L*("`@("`@("`D=&AI<RT^7VAE:6=H="`](&YU
M;&P["B`@("`@("`@)'1H:7,M/E]B86-K9W)O=6YD(#T@)W=H:71E)SL*("`@
M('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@:&5I9VAT(&%N9"!W:61T:"!O
M9B!T:&4@8W5R<F5N="!I;6%G92!D871A+@H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@($%N(&AA<V@@=VET:"`G=VED=&@G(&-O;G1A:6YI;F<@=&AE
M('=I9'1H+`H@("`@("H@("`@("`@("`@("`@("`@)VAE:6=H="<@8V]N=&%I
M;FEN9R!T:&4@:&5I9VAT(&]F('1H92!I;6%G92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T1&EM96YS:6]N<R@I"B`@("!["B`@("`@("`@)'1M<"`]("1T
M:&ES+3YT;T9I;&4H*3L*("`@("`@("`D9&5T86EL<R`]($!G971I;6%G97-I
M>F4H)'1M<"D["B`@("`@("`@=6YL:6YK*"1T;7`I.PH*("`@("`@("!R971U
M<FX@87)R87DH)W=I9'1H)R`]/B`D9&5T86EL<ULP72P*("`@("`@("`@("`@
M("`@("`@("`@)VAE:6=H="<@/3X@)&1E=&%I;'-;,5TI.PH@("`@?0H*("`@
M("\J*@H@("`@("H@3&]A9"!T:&4@:6UA9V4@9&%T82!F<F]M(&$@<W1R:6YG
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED("`@("`@("`@($%N
M(&%R8FET<F%R>2!I9"!F;W(@=&AE(&EM86=E+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D:6UA9V5?9&%T82`@5&AE(&1A=&$@=&\@=7-E(&9O<B!T:&4@:6UA
M9V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QO8613=')I;F<H)&ED+"`D:6UA
M9V5?9&%T82D*("`@('L*("`@("`@("!I9B`H)&ED("$]("1T:&ES+3Y?:60I
M('L*("`@("`@("`@("`@)'1H:7,M/G)E<V5T*"D["B`@("`@("`@("`@("1T
M:&ES+3Y?9&%T82`]("1I;6%G95]D871A.PH@("`@("`@("`@("`D=&AI<RT^
M7VED(#T@)&ED.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($QO
M860@=&AE(&EM86=E(&1A=&$@9G)O;2!A(&9I;&4N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D9FEL96YA;64@(%1H92!F=6QL('!A=&@@86YD(&9I
M;&5N86UE('1O('1H92!F:6QE('1O(&QO860*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("!T:&4@:6UA9V4@9&%T82!F<F]M+B!4:&4@9FEL96YA
M;64@=VEL;"!A;'-O(&)E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@=7-E9"!F;W(@=&AE(&EM86=E(&ED+@H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@(%!%05(@17)R;W(@:68@9FEL92!D;V5S(&YO="!E>&ES="!O
M<B!C;W5L9"!N;W0@8F4@;&]A9&5D"B`@("`@*B`@("`@("`@("`@("`@("!O
M=&AE<G=I<V4@3E5,3"!I9B!S=6-C97-S9G5L(&]R(&%L<F5A9'D@;&]A9&5D
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!L;V%D1FEL92@D9FEL96YA;64I"B`@
M("!["B`@("`@("`@:68@*"1F:6QE;F%M92`A/2`D=&AI<RT^7VED*2!["B`@
M("`@("`@("`@("1T:&ES+3YR97-E="@I.PH@("`@("`@("`@("!I9B`H(69I
M;&5?97AI<W1S*"1F:6QE;F%M92DI('L*("`@("`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"=4:&4@:6UA9V4@9FEL92`G("X@)&EM86=E
M("X@)R!D;V5S(&YO="!E>&ES="XG*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!I9B`H)'1H:7,M/E]D871A(#T@9FEL95]G971?8V]N=&5N=',H)&9I
M;&5N86UE*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]I9"`]("1F:6QE
M;F%M93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*"=#;W5L9"!N;W0@;&]A9"!T:&4@:6UA
M9V4@9FEL92`G("X@)&EM86=E*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@('T*"B`@("!F=6YC=&EO;B!T;T9I;&4H)&1A=&$@/2!F86QS92D*("`@
M('L*("`@("`@("`D=&UP(#T@571I;#HZ9V5T5&5M<$9I;&4H)VEM9R<L(&9A
M;'-E+"`D=&AI<RT^7W1M<&1I<BD["B`@("`@("`@)&9P(#T@0&9O<&5N*"1T
M;7`L("=W8B<I.PH@("`@("`@(&9W<FET92@D9G`L("1D871A(#\@)&1A=&$@
M.B`D=&AI<RT^<F%W*"DI.PH@("`@("`@(&9C;&]S92@D9G`I.PH@("`@("`@
M(')E='5R;B`D=&UP.PH@("`@?0H*("`@("\J*@H@("`@("H@1&ES<&QA>2!T
M:&4@8W5R<F5N="!I;6%G92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&ES<&QA
M>2@I"B`@("!["B`@("`@("`@)'1H:7,M/FAE861E<G,H*3L*("`@("`@("!E
M8VAO("1T:&ES+3YR87<H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE(')A=R!D871A(&9O<B!T:&ES(&EM86=E+@H@("`@("H*("`@("`J
M($!P87)A;2!B;V]L96%N("1C;VYV97)T("!)9B!T<G5E+"!T:&4@:6UA9V4@
M9&%T82!W:6QL(&)E(')E='5R;F5D(&EN('1H90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@('1A<F=E="!F;W)M870L(&EN9&5P96YD96YT;'D@
M9G)O;2!A;GD@:6UA9V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("!O<&5R871I;VYS+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@<F%W(&EM86=E(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')A=R@D
M8V]N=F5R="`](&9A;'-E*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M7V1A=&$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@86X@>"QY('!A:7(@
M;VX@8VER8VQE+"!A<W-U;6EN9R!C96YT97(@:7,@,"PP+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!D;W5B
M;&4@)&1E9W)E97,@("`@5&AE(&1E9W)E97,@;V8@87)C('1O(&=E="!T:&4@
M<&]I;G0@9F]R+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&1I86UE=&5R("!4
M:&4@9&EA;65T97(@;V8@=&AE(&-I<F-L92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("`H>"!C;V]R9&EN871E+"!Y(&-O;W)D:6YA=&4I(&]F('1H
M92!P;VEN="X*("`@("`J+PH@("`@9G5N8W1I;VX@7V-I<F-L95!O:6YT*"1D
M96=R965S+"`D9&EA;65T97(I"B`@("!["B`@("`@("`@+R\@079O:60@<')O
M8FQE;7,@=VET:"!D;W5B;&5S+@H@("`@("`@("1D96=R965S("L](#`N,#`P
M,3L*"B`@("`@("`@<F5T=7)N(&%R<F%Y*&-O<RAD96<R<F%D*"1D96=R965S
M*2D@*B`H)&1I86UE=&5R("\@,BDL"B`@("`@("`@("`@("`@("`@("`@('-I
M;BAD96<R<F%D*"1D96=R965S*2D@*B`H)&1I86UE=&5R("\@,BDI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1V5T('!O:6YT(&-O;W)D:6YA=&5S(&%T('1H
M92!L:6UI=',@;V8@86X@87)C+B!/;FQY('9A;&ED(&9O<@H@("`@("H@86YG
M;&5S("@D96YD("T@)'-T87)T*2`\/2`T-2!D96=R965S+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!I;G1E
M9V5R("1R("`@("`@5&AE(')A9&EU<R!O9B!T:&4@87)C+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)'-T87)T("!4:&4@<W1A<G1I;F<@86YG;&4N"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D96YD("`@(%1H92!E;F1I;F<@86YG;&4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE('-T87)T('!O:6YT+"!E
M;F0@<&]I;G0L(&%N9"!A;F-H;W(@<&]I;G0N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]A<F-0;VEN=',H)'(L("1S=&%R="P@)&5N9"D*("`@('L*("`@("`@
M("`O+R!3=&%R="!P;VEN="X*("`@("`@("`D<'1S6R=X,2==(#T@)'(@*B!C
M;W,H9&5G,G)A9"@D<W1A<G0I*3L*("`@("`@("`D<'1S6R=Y,2==(#T@)'(@
M*B!S:6XH9&5G,G)A9"@D<W1A<G0I*3L*"B`@("`@("`@+R\@16YD('!O:6YT
M+@H@("`@("`@("1P='-;)W@R)UT@/2`D<B`J(&-O<RAD96<R<F%D*"1E;F0I
M*3L*("`@("`@("`D<'1S6R=Y,B==(#T@)'(@*B!S:6XH9&5G,G)A9"@D96YD
M*2D["@H@("`@("`@("\O($%N8VAO<B!P;VEN="X*("`@("`@("`D83,@/2`H
M)'-T87)T("L@)&5N9"D@+R`R.PH@("`@("`@("1R,R`]("1R("\@8V]S*&1E
M9S)R860H*"1E;F0@+2`D<W1A<G0I("\@,BDI.PH@("`@("`@("1P='-;)W@S
M)UT@/2`D<C,@*B!C;W,H9&5G,G)A9"@D83,I*3L*("`@("`@("`D<'1S6R=Y
M,R==(#T@)'(S("H@<VEN*&1E9S)R860H)&$S*2D["@H@("`@("`@(')E='5R
M;B`D<'1S.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T
M=7)N(&$@8V]N8W)E=&4@2&]R9&5?26UA9V4@:6YS=&%N8V4@8F%S960@;VX@
M)&1R:79E<BX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&1R:79E<B`@
M5&AE('1Y<&4@;V8@8V]N8W)E=&4@2&]R9&5?26UA9V4@<W5B8VQA<W,@=&\*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!R971U<FXN(%1H:7,@:7,@
M8F%S960@;VX@=&AE('-T;W)A9V4@9')I=F5R"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@*"1D<FEV97(I+B!4:&4@8V]D92!I<R!D>6YA;6EC86QL
M>2!I;F-L=61E9"X@268*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`D
M9')I=F5R(&ES(&%N(&%R<F%Y+"!T:&5N('=E('=I;&P@;&]O:R!I;@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("1D<FEV97);,%TO;&EB+TEM86=E
M+R!F;W(@=&AE('-U8F-L87-S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@:6UP;&5M96YT871I;VX@;F%M960@)&1R:79E<ELQ72YP:'`N"B`@("`@
M*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@86YY
M(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!O<@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A('-U8F-L87-S
M(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D95]);6%G
M97QB;V]L96%N("!4:&4@;F5W;'D@8W)E871E9"!C;VYC<F5T92!(;W)D95])
M;6%G90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I;G-T
M86YC92P@;W(@9F%L<V4@;VX@86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N("9F86-T;W)Y*"1D<FEV97(L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@
M>PH@("`@("`@(&EF("AI<U]A<G)A>2@D9')I=F5R*2D@>PH@("`@("`@("`@
M("!L:7-T*"1A<'`L("1D<FEV97(I(#T@)&1R:79E<CL*("`@("`@("!]"@H@
M("`@("`@(&EF("@A96UP='DH)&%P<"DI('L*("`@("`@("`@("`@<F5Q=6ER
M95]O;F-E("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)V9I;&5R;V]T)RP@
M)&%P<"D@+B`G+VQI8B]);6%G92\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@
M("`@("!](&5L<V5I9B`H0&9I;&5?97AI<W1S*&1I<FYA;64H7U]&24Q%7U\I
M("X@)R]);6%G92\G("X@)&1R:79E<B`N("<N<&AP)RDI('L*("`@("`@("`@
M("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]);6%G92\G
M("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!`:6YC;'5D95]O;F-E("=(;W)D92]);6%G92\G("X@)&1R:79E<B`N
M("<N<&AP)SL*("`@("`@("!]"B`@("`@("`@)&-L87-S(#T@)TAO<F1E7TEM
M86=E7R<@+B`D9')I=F5R.PH@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L
M87-S*2D@>PH@("`@("`@("`@("`D:6UA9V4@/2`F;F5W("1C;&%S<R@D<&%R
M86US*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D:6UA9V4@/2!0
M14%2.CIR86ES945R<F]R*"=#;&%S<R!D969I;FET:6]N(&]F("<@+B`D8VQA
M<W,@+B`G(&YO="!F;W5N9"XG*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D:6UA9V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R
M971U<FX@82!R969E<F5N8V4@=&\@82!C;VYC<F5T92!(;W)D95]);6%G92!I
M;G-T86YC92!B87-E9`H@("`@("H@;VX@)&1R:79E<BX@270@=VEL;"!O;FQY
M(&-R96%T92!A(&YE=R!I;G-T86YC92!I9B!N;R!(;W)D95]);6%G90H@("`@
M("H@:6YS=&%N8V4@=VET:"!T:&4@<V%M92!P87)A;65T97)S(&-U<G)E;G1L
M>2!E>&ES=',N"B`@("`@*@H@("`@("H@5&AI<R!S:&]U;&0@8F4@=7-E9"!I
M9B!M=6QT:7!L92!T>7!E<R!O9B!I;6%G92!R96YD97)E<G,@*&%N9"P@=&AU
M<RP*("`@("`J(&UU;'1I<&QE($AO<F1E7TEM86=E(&EN<W1A;F-E<RD@87)E
M(')E<75I<F5D+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@
M:6YV;VME9"!A<SH@)'9A<B`]("9(;W)D95]);6%G93HZ<VEN9VQE=&]N*"D*
M("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&1R:79E<B`@5&AE('1Y<&4@
M;V8@8V]N8W)E=&4@2&]R9&5?26UA9V4@<W5B8VQA<W,@=&\*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!R971U<FXN(%1H:7,@:7,@8F%S960@;VX@
M=&AE('-T;W)A9V4@9')I=F5R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@*"1D<FEV97(I+B!4:&4@8V]D92!I<R!D>6YA;6EC86QL>2!I;F-L=61E
M9"X@268*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`D9')I=F5R(&ES
M(&%N(&%R<F%Y+"!T:&5N('=E('=I;&P@;&]O:R!I;@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("1D<FEV97);,%TO;&EB+TEM86=E+R!F;W(@=&AE
M('-U8F-L87-S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@:6UP;&5M
M96YT871I;VX@;F%M960@)&1R:79E<ELQ72YP:'`N"B`@("`@*B!`<&%R86T@
M87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N
M86P@8V]N9FEG=7)A=&EO;B!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE
M960N"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D95]);6%G97QB;V]L96%N
M("!4:&4@8V]N8W)E=&4@2&]R9&5?26UA9V4@<F5F97)E;F-E+"!O<@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F86QS92!O;B!A;B!E
M<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@D9')I=F5R
M+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!S=&%T:6,@)&EN
M<W1A;F-E<SL*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97,I*2!["B`@
M("`@("`@("`@("1I;G-T86YC97,@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@
M("`@("`@)'-I9VYA='5R92`]('-E<FEA;&EZ92AA<G)A>2@D9')I=F5R+"`D
M<&%R86US*2D["B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S6R1S:6=N
M871U<F5=*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S6R1S:6=N871U<F5=
M(#T@)DAO<F1E7TEM86=E.CIF86-T;W)Y*"1D<FEV97(L("1P87)A;7,I.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;)'-I9VYA='5R
M95T["B`@("!]"@I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+VE#86QE;F1A
M<BYP:'``````````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,3,P
M-3`T(#$P-3$U-#,S-S0P(#`R,3<T,@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@0'!A8VMA9V4@2&]R
M9&5?:4-A;&5N9&%R"B`J+PH*+RHJ"B`J(%-T<FEN9R!P86-K86=E"B`J+PII
M;F-L=61E7V]N8V4@)TAO<F1E+U-T<FEN9RYP:'`G.PH*+RHJ"B`J($-L87-S
M(')E<')E<V5N=&EN9R!I0V%L96YD87(@9FEL97,N"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+VE#86QE;F1A<B]I0V%L96YD87(N<&AP+'8@,2XU-RXT+C,T
M(#(P,#8O,#@O,#4@,3,Z-#,Z-#<@:V%R<W1E;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,C`P,RTR,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA
M;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6ME($-O
M8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!(
M;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?:4-A;&5N9&%R"B`J+PIC;&%S
M<R!(;W)D95]I0V%L96YD87(@>PH*("`@("\J*@H@("`@("H@5&AE('!A<F5N
M="`H8V]N=&%I;FEN9RD@:4-A;&5N9&%R(&]B:F5C="X*("`@("`J"B`@("`@
M*B!`=F%R($AO<F1E7VE#86QE;F1A<@H@("`@("HO"B`@("!V87(@)%]C;VYT
M86EN97(@/2!F86QS93L*"B`@("`O*BH*("`@("`J(%1H92!N86UE+W9A;'5E
M('!A:7)S(&]F(&%T=')I8G5T97,@9F]R('1H:7,@;V)J96-T("A5240L"B`@
M("`@*B!$5%-405)4+"!E=&,N*2X@5VAI8V@@87)E('!R97-E;G0@9&5P96YD
M<R!O;B!T:&4@;V)J96-T(&%N9"!O;@H@("`@("H@=VAA="!K:6YD(&]F(&-O
M;7!O;F5N="!I="!I<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D7V%T=')I8G5T97,@/2!A<G)A>2@I.PH*("`@("\J*@H@
M("`@("H@06YY(&-H:6QD<F5N("AC;VYT86EN960I(&E#86QE;F1A<B!C;VUP
M;VYE;G1S(&]F('1H:7,@;V)J96-T+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?8V]M<&]N96YT<R`](&%R<F%Y*"D["@H@
M("`@+RHJ"B`@("`@*B!!8V-O<F1I;F<@=&\@4D9#(#(T,C4L('=E('-H;W5L
M9"!A;'=A>7,@=7-E($-23$8M=&5R;6EN871E9"!L:6YE<RX*("`@("`J"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]N97=L:6YE(#T@
M(EQR7&XB.PH*("`@("\J*@H@("`@("H@:4-A;&5N9&%R(&9O<FUA="!V97)S
M:6]N("AD:69F97)E;G0@8F5H879I;W(@9F]R(#$N,"!A;F0@,BXP"B`@("`@
M*B!E<W!E8VEA;&QY('=I=&@@<F5C=7)R:6YG(&5V96YT<RDN"B`@("`@*@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?=F5R<VEO;CL*
M"B`@("!F=6YC=&EO;B!(;W)D95]I0V%L96YD87(H)'9E<G-I;VX@/2`G,BXP
M)RD*("`@('L*("`@("`@("`D=&AI<RT^7W9E<G-I;VX@/2`D=F5R<VEO;CL*
M("`@("`@("`D=&AI<RT^<V5T071T<FEB=71E*"=615)324].)RP@)'9E<G-I
M;VXI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&$@<F5F97)E;F-E
M('1O(&$@;F5W(&-O;7!O;F5N="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("`@("`@("`@("1T>7!E("`@("`@(%1H92!T>7!E(&]F(&-O;7!O;F5N
M="!T;R!R971U<FX*("`@("`J($!P87)A;2!(;W)D95]I0V%L96YD87(@)&-O
M;G1A:6YE<B`@02!C;VYT86EN97(@=&AA="!T:&ES(&-O;7!O;F5N=`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!W:6QL(&)E
M(&%S<V]C:6%T960@=VET:"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&]B:F5C
M="`@4F5F97)E;F-E('1O(&$@2&]R9&5?:4-A;&5N9&%R7RH@;V)J96-T(&%S
M('-P96-I9FEE9"X*("`@("`J"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9N97=#;VUP;VYE;G0H)'1Y<&4L("8D8V]N=&%I;F5R*0H@
M("`@>PH@("`@("`@("1T>7!E(#T@4W1R:6YG.CIL;W=E<B@D='EP92D["B`@
M("`@("`@)&-L87-S(#T@)TAO<F1E7VE#86QE;F1A<E\G("X@)'1Y<&4["B`@
M("`@("`@:68@*"%C;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@
M("!I;F-L=61E7V]N8V4@)TAO<F1E+VE#86QE;F1A<B\G("X@)'1Y<&4@+B`G
M+G!H<"<["B`@("`@("`@?0H@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L
M87-S*2D@>PH@("`@("`@("`@("`D8V]M<&]N96YT(#T@;F5W("1C;&%S<R@I
M.PH@("`@("`@("`@("!I9B`H)&-O;G1A:6YE<B`A/3T@9F%L<V4I('L*("`@
M("`@("`@("`@("`@("1C;VUP;VYE;G0M/E]C;VYT86EN97(@/2`F)&-O;G1A
M:6YE<CL*("`@("`@("`@("`@("`@("\O(%5S92!V97)S:6]N(&]F(&-O;G1A
M:6YE<BP@;F]T(&1E9F%U;'0@<V5T(&)Y(&-O;7!O;F5N=`H@("`@("`@("`@
M("`@("`@+R\@8V]N<W1R=6-T;W(N"B`@("`@("`@("`@("`@("`D8V]M<&]N
M96YT+3Y?=F5R<VEO;B`]("1C;VYT86EN97(M/E]V97)S:6]N.PH@("`@("`@
M("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@4VAO=6QD
M(')E='5R;B!A;B!D=6UM>2!X+75N:VYO=VX@='EP92!C;&%S<R!H97)E+@H@
M("`@("`@("`@("`D8V]M<&]N96YT(#T@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)&-O;7!O;F5N=#L*("`@('T*"B`@("`O*BH*("`@("`J
M(%-E=',@=&AE('9A;'5E(&]F(&%N(&%T=')I8G5T92X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1N86UE("`@("!4:&4@;F%M92!O9B!T:&4@871T
M<FEB=71E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=F%L=64@("`@5&AE('9A
M;'5E(&]F('1H92!A='1R:6)U=&4N"B`@("`@*B!`<&%R86T@87)R87D@)'!A
M<F%M<R`@("!!<G)A>2!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;B!P87)A;65T
M97)S(&9O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@=&AI<R!A
M='1R:6)U=&4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D87!P96YD("!4<G5E
M('1O(&%P<&5N9"!T:&4@871T<FEB=71E+"!&86QS92!T;R!R97!L86-E"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@9FER<W0@;6%T8VAI
M;F<@871T<FEB=71E(&9O=6YD+@H@("`@("H@0'!A<F%M(&%R<F%Y("1V86QU
M97,@("`@07)R87D@<F5P<F5S96YT871I;VX@;V8@)'9A;'5E+B`@1F]R"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!C;VUM82]S96UI8V]L;VX@
M<V5P97)A=&5D(&QI<W1S(&]F('9A;'5E<RX@($EF"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("!N;W0@<V5T('5S92`D=F%L=64@87,@<VEN9VQE
M(&%R<F%Y(&5L96UE;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$%T=')I
M8G5T92@D;F%M92P@)'9A;'5E+"`D<&%R86US(#T@87)R87DH*2P@)&%P<&5N
M9"`]('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E<R`]
M(&9A;'-E*0H@("`@>PH@("`@("`@("\O($UA:V4@<W5R92!W92!U<&1A=&4@
M=&AE(&EN=&5R;F%L(&9O<FUA="!V97)S:6]N(&EF"B`@("`@("`@+R\@<V5T
M071T<FEB=71E*"=615)324].)RP@+BXN*2!I<R!C86QL960N"B`@("`@("`@
M:68@*"1N86UE(#T]("=615)324].)RD@>PH@("`@("`@("`@("`D=&AI<RT^
M7W9E<G-I;VX@/2`D=F%L=64["B`@("`@("`@("`@(&EF("@D=&AI<RT^7V-O
M;G1A:6YE<B`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M8V]N=&%I;F5R+3Y?=F5R<VEO;B`]("1V86QU93L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@:68@*"$D=F%L=65S*2!["B`@("`@("`@("`@
M("1V86QU97,@/2!A<G)A>2@D=F%L=64I.PH@("`@("`@('T*("`@("`@("`D
M9F]U;F0@/2!F86QS93L*("`@("`@("!I9B`H(21A<'!E;F0I('L*("`@("`@
M("`@("`@)&ME>7,@/2!A<G)A>5]K97ES*"1T:&ES+3Y?871T<FEB=71E<RD[
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1K97ES(&%S("1K97DI('L*("`@("`@
M("`@("`@("`@(&EF("@D=&AI<RT^7V%T=')I8G5T97-;)&ME>5U;)VYA;64G
M72`]/2!3=')I;F<Z.G5P<&5R*"1N86UE*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?871T<FEB=71E<ULD:V5Y75LG<&%R86US)UT@/2`D<&%R
M86US.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?871T<FEB=71E<ULD
M:V5Y75LG=F%L=64G72`]("1V86QU93L*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7V%T=')I8G5T97-;)&ME>5U;)W9A;'5E<R==(#T@)'9A;'5E<SL*
M("`@("`@("`@("`@("`@("`@("`D9F]U;F0@/2!T<G5E.PH@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H)&%P<&5N9"!\?"`A)&9O=6YD
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?871T<FEB=71E<UM=(#T@87)R87DH
M"B`@("`@("`@("`@("`@("`G;F%M92<@("`@("`]/B!3=')I;F<Z.G5P<&5R
M*"1N86UE*2P*("`@("`@("`@("`@("`@("=P87)A;7,G("`@(#T^("1P87)A
M;7,L"B`@("`@("`@("`@("`@("`G=F%L=64G("`@("`]/B`D=F%L=64L"B`@
M("`@("`@("`@("`@("`G=F%L=65S)R`@("`]/B`D=F%L=65S"B`@("`@("`@
M("`@("D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!P
M87)A;65T97(H<RD@9F]R(&%N("AA;')E861Y(&5X:7-T:6YG*2!A='1R:6)U
M=&4N("!4:&4*("`@("`J('!A<F%M971E<B!S970@:7,@;65R9V5D(&EN=&\@
M=&AE(&5X:7-T:6YG('-E="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N86UE("`@5&AE(&YA;64@;V8@=&AE(&%T=')I8G5T92X*("`@("`J($!P
M87)A;2!A<G)A>2`D<&%R86US("!!<G)A>2!C;VYT86EN:6YG(&%N>2!A9&1I
M=&EO;F%L('!A<F%M971E<G,@9F]R"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@=&AI<R!A='1R:6)U=&4N"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@:68@;F\@871T<FEB=71E("1N86UE
M(&5X:7-T<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T4&%R86UE=&5R*"1N
M86UE+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D:V5Y<R`]
M(&%R<F%Y7VME>7,H)'1H:7,M/E]A='1R:6)U=&5S*3L*("`@("`@("!F;W)E
M86-H("@D:V5Y<R!A<R`D:V5Y*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^
M7V%T=')I8G5T97-;)&ME>5U;)VYA;64G72`]/2`D;F%M92D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]A='1R:6)U=&5S6R1K97E=6R=P87)A;7,G72`]
M"B`@("`@("`@("`@("`@("`@("`@87)R87E?;65R9V4H)'1H:7,M/E]A='1R
M:6)U=&5S6R1K97E=6R=P87)A;7,G72P@)'!A<F%M<RD["B`@("`@("`@("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T
M('1H92!V86QU92!O9B!A;B!A='1R:6)U=&4N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;F%M92`@("`@5&AE(&YA;64@;V8@=&AE(&%T=')I8G5T
M92X*("`@("`J($!P87)A;2!B;V]L96%N("1P87)A;7,@(%)E='5R;B!T:&4@
M<&%R86UE=&5R<R!F;W(@=&AI<R!A='1R:6)U=&4@:6YS=&5A9`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@;V8@:71S('9A;'5E+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@*&]B:F5C="D@(%!%05)?17)R;W(@:68@
M=&AE(&%T=')I8G5T92!D;V5S(&YO="!E>&ES="X*("`@("`J("`@("`@("`@
M("`@("`@*'-T<FEN9RD@(%1H92!V86QU92!O9B!T:&4@871T<FEB=71E+@H@
M("`@("H@("`@("`@("`@("`@("`H87)R87DI("`@5&AE('!A<F%M971E<G,@
M9F]R('1H92!A='1R:6)U=&4@;W(*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@(&UU;'1I<&QE('9A;'5E<R!F;W(@86X@871T<FEB=71E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971!='1R:6)U=&4H)&YA;64L("1P87)A;7,@
M/2!F86QS92D*("`@('L*("`@("`@("`D<F5S=6QT(#T@87)R87DH*3L*("`@
M("`@("!F;W)E86-H("@D=&AI<RT^7V%T=')I8G5T97,@87,@)&%T=')I8G5T
M92D@>PH@("`@("`@("`@("!I9B`H)&%T=')I8G5T95LG;F%M92==(#T]("1N
M86UE*2!["B`@("`@("`@("`@("`@("!I9B`H)'!A<F%M<RD@>PH@("`@("`@
M("`@("`@("`@("`@("1R97-U;'1;72`]("1A='1R:6)U=&5;)W!A<F%M<R==
M.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`D<F5S=6QT6UT@/2`D871T<FEB=71E6R=V86QU92==.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@A
M8V]U;G0H)')E<W5L="DI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=0
M14%2+G!H<"<["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"=!='1R:6)U=&4@(B<@+B`D;F%M92`N("<B($YO="!&;W5N9"<I.PH@("`@
M("`@('T@:68@*&-O=6YT*"1R97-U;'0I(#T](#$@)B8@(21P87)A;7,I('L*
M("`@("`@("`@("`@<F5T=7)N("1R97-U;'1;,%T["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@=F%L=65S(&]F(&%N(&%T=')I
M8G5T92!A<R!A;B!A<G)A>2X@($UU;'1I<&QE('9A;'5E<PH@("`@("H@87)E
M('!O<W-I8FQE(&1U92!T;SH*("`@("`J"B`@("`@*B`@82D@;75L=&EP;&-E
M(&]C8W5R96YC97,@;V8@)VYA;64G"B`@("`@*B`@8BD@*'5N<V5C87!D*2!C
M;VUM82!S97!E<F%T960@;&ES=',N"B`@("`@*@H@("`@("H@4V\@9F]R(&$@
M=F-A<F0@;&EK92`B2T59.F$L8EQN2T59.F,B(&=E=$%T=')I8G5T97-686QU
M97,H)TM%62<I"B`@("`@*B!W:6QL(')E='5R;B!A<G)A>2@G82<L)V(G+"=C
M)RDN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&YA;64@("`@5&AE
M(&YA;64@;V8@=&AE(&%T=')I8G5T92X*("`@("`J($!R971U<FX@;6EX960@
M*&]B:F5C="D@(%!%05)?17)R;W(@:68@=&AE(&%T=')I8G5T92!D;V5S(&YO
M="!E>&ES="X*("`@("`J("`@("`@("`@("`@("`@*&%R<F%Y*2`@($UU;'1I
M<&QE('9A;'5E<R!F;W(@86X@871T<FEB=71E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971!='1R:6)U=&5686QU97,H)&YA;64I"B`@("!["B`@("`@("`@
M)')E<W5L="`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]A
M='1R:6)U=&5S(&%S("1A='1R:6)U=&4I('L*("`@("`@("`@("`@:68@*"1A
M='1R:6)U=&5;)VYA;64G72`]/2`D;F%M92D@>PH@("`@("`@("`@("`@("`@
M)')E<W5L="`](&%R<F%Y7VUE<F=E*"1A='1R:6)U=&5;)W9A;'5E<R==+"`D
M<F5S=6QT*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H
M(6-O=6YT*"1R97-U;'0I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"=!='1R:6)U=&4@(B<@+B`D;F%M92`N("<B($YO="!&;W5N
M9"<I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('9A;'5E(&]F(&%N(&%T=')I
M8G5T92P@;W(@82!S<&5C:69I960@9&5F875L="!V86QU90H@("`@("H@:68@
M=&AE(&%T=')I8G5T92!D;V5S(&YO="!E>&ES="X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1N86UE("`@(%1H92!N86UE(&]F('1H92!A='1R:6)U
M=&4N"B`@("`@*B!`<&%R86T@;6EX960@)&1E9F%U;'0@(%=H870@=&\@<F5T
M=7)N(&EF('1H92!A='1R:6)U=&4@<W!E8VEF:65D(&)Y"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("1N86UE(&1O97,@;F]T(&5X:7-T+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@*'-T<FEN9RD@5&AE('9A;'5E(&]F
M("1N86UE+@H@("`@("H@("`@("`@("`@("`@("`H;6EX960I("`D9&5F875L
M="!I9B`D;F%M92!D;V5S(&YO="!E>&ES="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T071T<FEB=71E1&5F875L="@D;F%M92P@)&1E9F%U;'0@/2`G)RD*
M("`@('L*("`@("`@("`D=F%L=64@/2`D=&AI<RT^9V5T071T<FEB=71E*"1N
M86UE*3L*("`@("`@("!R971U<FX@:7-?82@D=F%L=64L("=014%27T5R<F]R
M)RD@/R`D9&5F875L="`Z("1V86QU93L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E;6]V92!A;&P@;V-C=7)E;F-E<R!O9B!A;B!A='1R:6)U=&4N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&YA;64@;V8@=&AE
M(&%T=')I8G5T92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E071T<FEB
M=71E*"1N86UE*0H@("`@>PH@("`@("`@("1K97ES(#T@87)R87E?:V5Y<R@D
M=&AI<RT^7V%T=')I8G5T97,I.PH@("`@("`@(&9O<F5A8V@@*"1K97ES(&%S
M("1K97DI('L*("`@("`@("`@("`@:68@*"1T:&ES+3Y?871T<FEB=71E<ULD
M:V5Y75LG;F%M92==(#T]("1N86UE*2!["B`@("`@("`@("`@("`@("!U;G-E
M="@D=&AI<RT^7V%T=')I8G5T97-;)&ME>5TI.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1V5T(&%T=')I8G5T97,@
M9F]R(&%L;"!T86=S(&]R(&9O<B!A(&=I=F5N('1A9RX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1T86<@(%)E='5R;B!A='1R:6)U=&5S(&9O<B!T
M:&ES('1A9RP@;W(@86QL(&%T=')I8G5T97,@:68*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@;F]T(&=I=F5N+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@($%N(&%R<F%Y(&-O;G1A:6YI;F<@86QL('1H92!A='1R:6)U=&5S
M(&%N9"!T:&5I<B!T>7!E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T06QL
M071T<FEB=71E<R@D=&%G(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"1T
M86<@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V%T
M=')I8G5T97,["B`@("`@("`@?0H@("`@("`@("1R97-U;'0@/2!A<G)A>2@I
M.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?871T<FEB=71E<R!A<R`D871T
M<FEB=71E*2!["B`@("`@("`@("`@(&EF("@D871T<FEB=71E6R=N86UE)UT@
M/3T@)'1A9RD@>PH@("`@("`@("`@("`@("`@)')E<W5L=%M=(#T@)&%T=')I
M8G5T93L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@
M)')E<W5L=#L*("`@('T*"B`@("`O*BH*("`@("`J($%D9"!A('9#86QE;F1A
M<B!C;VUP;VYE;G0@*&5G('9%=F5N="P@=E1I;65Z;VYE+"!E=&,N*2X*("`@
M("`J"B`@("`@*B!`<&%R86T@2&]R9&5?:4-A;&5N9&%R("1C;VUP;VYE;G0@
M($-O;7!O;F5N="`H<W5B8VQA<W,I('1O(&%D9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@861D0V]M<&]N96YT*"1C;VUP;VYE;G0I"B`@("!["B`@("`@("`@
M:68@*&ES7V$H)&-O;7!O;F5N="P@)TAO<F1E7VE#86QE;F1A<B<I*2!["B`@
M("`@("`@("`@("1C;VUP;VYE;G0M/E]C;VYT86EN97(@/2`F)'1H:7,["B`@
M("`@("`@("`@("1T:&ES+3Y?8V]M<&]N96YT<UM=(#T@)B1C;VUP;VYE;G0[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F4@86QL
M('1H92!C;VUP;VYE;G1S+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M($%R<F%Y(&]F($AO<F1E7VE#86QE;F1A<B!O8FIE8W1S+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971#;VUP;VYE;G1S*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]C;VUP;VYE;G1S.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E
M=%1Y<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G=F-A;&5N9&%R)SL*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@8VQA<W-E<R`H96YT<GD@
M='EP97,I('=E(&AA=F4N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@
M2&%S:"!W:71H(&-L87-S(&YA;65S($AO<F1E7VE#86QE;F1A<E]X>'@@87,@
M:V5Y<PH@("`@("H@("`@("`@("`@("`@("`@86YD(&YU;6)E<B!O9B!C;VUP
M;VYE;G1S(&]F('1H:7,@8VQA<W,@87,@=F%L=64N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=$-O;7!O;F5N=$-L87-S97,H*0H@("`@>PH@("`@("`@("1R
M(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V-O;7!O;F5N
M=',@87,@)&,I('L*("`@("`@("`@("`@)&-N(#T@<W1R=&]L;W=E<BAG971?
M8VQA<W,H)&,I*3L*("`@("`@("`@("`@:68@*&5M<'1Y*"1R6R1C;ETI*2![
M"B`@("`@("`@("`@("`@("`D<ELD8VY=(#T@,3L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1R6R1C;ETK*SL*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R.PH@("`@?0H*("`@("\J
M*@H@("`@("H@3G5M8F5R(&]F(&-O;7!O;F5N=',@:6X@=&AI<R!C;VYT86EN
M97(N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!.=6UB97(@;V8@
M8V]M<&]N96YT<R!I;B!T:&ES(&-O;G1A:6YE<BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T0V]M<&]N96YT0V]U;G0H*0H@("`@>PH@("`@("`@(')E='5R
M;B!C;W5N="@D=&AI<RT^7V-O;7!O;F5N=',I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T<FEE=F4@82!S<&5C:69I8R!C;VUP;VYE;G0N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&ED>"`@5&AE(&EN9&5X(&]F('1H92!O
M8FIE8W0@=&\@<F5T<FEE=F4N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@("`H8F]O;&5A;BD@1F%L<V4@:68@=&AE(&EN9&5X(&1O97,@;F]T(&5X
M:7-T+@H@("`@("H@("`@("`@("`@("`@("`@("`H2&]R9&5?:4-A;&5N9&%R
M7RHI(%1H92!R97%U97-T960@8V]M<&]N96YT+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971#;VUP;VYE;G0H)&ED>"D*("`@('L*("`@("`@("!I9B`H:7-S
M970H)'1H:7,M/E]C;VUP;VYE;G1S6R1I9'A=*2D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]C;VUP;VYE;G1S6R1I9'A=.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!,;V-A=&5S('1H92!F:7)S="!C:&EL9"!C;VUP
M;VYE;G0@;V8@=&AE('-P96-I9FEE9"!C;&%S<RP@86YD"B`@("`@*B!R971U
M<FYS(&$@<F5F97)E;F-E('1O('1H:7,@8V]M<&]N96YT+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'1Y<&4@(%1H92!T>7!E(&]F(&-O;7!O;F5N
M="!T;R!F:6YD+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@*&)O;VQE
M86XI($9A;'-E(&EF(&YO('-U8F-O;7!O;F5N="!O9B!T:&4@<W!E8VEF:65D
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!C;&%S<R!E>&ES=',N
M"B`@("`@*B`@("`@("`@("`@("`@("A(;W)D95]I0V%L96YD87)?*BD@02!R
M969E<F5N8V4@=&\@=&AE(')E<75E<W1E9"!C;VUP;VYE;G0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N("9F:6YD0V]M<&]N96YT*"1C:&EL9&-L87-S*0H@("`@
M>PH@("`@("`@("1C:&EL9&-L87-S(#T@)TAO<F1E7VE#86QE;F1A<E\G("X@
M4W1R:6YG.CIL;W=E<B@D8VAI;&1C;&%S<RD["B`@("`@("`@)&ME>7,@/2!A
M<G)A>5]K97ES*"1T:&ES+3Y?8V]M<&]N96YT<RD["B`@("`@("`@9F]R96%C
M:"`H)&ME>7,@87,@)&ME>2D@>PH@("`@("`@("`@("!I9B`H:7-?82@D=&AI
M<RT^7V-O;7!O;F5N='-;)&ME>5TL("1C:&EL9&-L87-S*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?8V]M<&]N96YT<ULD:V5Y73L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0VQE87)S('1H92!I0V%L96YD87(@;V)J
M96-T("AR97-E=',@=&AE(&-O;7!O;F5N=',@86YD(&%T=')I8G5T97,*("`@
M("`J(&%R<F%Y<RDN"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L96%R*"D*("`@
M('L*("`@("`@("`D=&AI<RT^7V-O;7!O;F5N=',@/2!A<G)A>2@I.PH@("`@
M("`@("1T:&ES+3Y?871T<FEB=71E<R`](&%R<F%Y*"D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#:&5C:W,@:68@96YT<GD@:7,@=F-A;&5N9&%R(#$N,"P@
M=F-A<F0@,BXQ(&]R('9N;W1E(#$N,2X*("`@("`J"B`@("`@*B!4:&5S92`G
M;VQD)R!F;W)M871S(&%R92!D969I;F5D(&)Y('=W=RYI;6,N;W)G+B!4:&4@
M)VYE=R<@*&YO;BUO;&0I"B`@("`@*B!F;W)M871S(&EC86QE;F1A<B`R+C`@
M86YD('9C87)D(#,N,"!A<F4@9&5F:6YE9"!I;B!R9F,R-#(V(&%N9"!R9F,R
M-#0U"B`@("`@*B!R97-P96-T:79E;'DN"B`@("`@*@H@("`@("H@0'-I;F-E
M($AO<F1E(#,N,2XR"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES3VQD1F]R;6%T
M*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]C;VYT86EN97(@(3T](&9A
M;'-E*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V-O;G1A:6YE<BT^
M:7-/;&1&;W)M870H*3L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YG
M9714>7!E*"D@/3T@)W9C87)D)RD@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]V97)S:6]N(#P@,R`_('1R=64@.B!F86QS93L*("`@("`@("!]"B`@
M("`@("`@:68@*"1T:&ES+3YG9714>7!E*"D@/3T@)W9.;W1E)RD@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]V97)S:6]N(#P@,B`_('1R=64@.B!F
M86QS93L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3Y?=F5R<VEO;B`^
M/2`R*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>'!O
M<G0@87,@=D-A;&5N9&%R(&9O<FUA="X*("`@("`J+PH@("`@9G5N8W1I;VX@
M97AP;W)T=D-A;&5N9&%R*"D*("`@('L*("`@("`@("`O+R!$969A=6QT('9A
M;'5E<RX*("`@("`@("`D<F5Q=6ER961!='1R:6)U=&5S6R=04D]$240G72`]
M("<M+R]4:&4@2&]R9&4@4')O:F5C="\O2&]R9&5?:4-A;&5N9&%R($QI8G)A
M<GDG("X@*&1E9FEN960H)TA/4D1%7U9%4E-)3TXG*2`_("<L($AO<F1E("<@
M+B!C;VYS=&%N="@G2$]21$5?5D524TE/3B<I(#H@)R<I("X@)R\O14XG.PH@
M("`@("`@("1R97%U:7)E9$%T=')I8G5T97-;)TU%5$A/1"==(#T@)U!50DQ)
M4T@G.PH*("`@("`@("!F;W)E86-H("@D<F5Q=6ER961!='1R:6)U=&5S(&%S
M("1N86UE(#T^("1D969A=6QT7W9A;'5E*2!["B`@("`@("`@("`@(&EF("AI
M<U]A*"1T:&ES+3YG971A='1R:6)U=&4H)&YA;64I+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T071T<FEB=71E*"1N86UE
M+"`D9&5F875L=%]V86QU92D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D=&AI<RT^7V5X<&]R='9$871A*"=60T%,14Y$05(G
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($5X<&]R="!T:&ES(&5N=')Y(&%S
M(&$@:&%S:"!A<G)A>2!W:71H('1A9R!N86UE<R!A<R!K97ES+@H@("`@("H*
M("`@("`J($!P87)A;2!B;V]L96%N("1P87)A;7-);DME>7,*("`@("`J("`@
M("`@("`@("`@("`@($EF(&9A;'-E+"!T:&4@;W!E<F%T:6]N(&-A;B!B92!Q
M=6ET92!L;W-S>2!A<R!T:&4*("`@("`J("`@("`@("`@("`@("`@('!A<F%M
M971E<G,@87)E(&EG;F]R960@=VAE;B!B=6EL9&EN9R!T:&4@87)R87D@:V5Y
M<RX*("`@("`J("`@("`@("`@("`@("`@(%-O(&EF('EO=2!E>'!O<G0@82!V
M8V%R9"!W:71H"B`@("`@*B`@("`@("`@("`@("`@("!,04)%3#M465!%/5=/
M4DLZ9F]O"B`@("`@*B`@("`@("`@("`@("`@("!,04)%3#M465!%/4A/344Z
M8F%R"B`@("`@*B`@("`@("`@("`@("`@("!T:&4@<F5S=6QT:6YG(&AA<V@@
M8V]N=&%I;G,@;VYL>2!O;F4@;&%B96P@9FEE;&0A"B`@("`@*B`@("`@("`@
M("`@("`@("!)9B!S970@=&\@=')U92P@87)R87D@:V5Y<R!L;V]K(&QI:V4@
M)TQ!0D5,.U194$4]5T]22R<*("`@("`J($!R971U<FX@87)R87D@($$@:&%S
M:"!A<G)A>2!W:71H('1A9R!N86UE<R!A<R!K97ES+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!T;TAA<V@H)'!A<F%M<TEN2V5Y<R`](&9A;'-E*0H@("`@>PH@
M("`@("`@("1H87-H(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D=&AI
M<RT^7V%T=')I8G5T97,@87,@)&$I("!["B`@("`@("`@("`@("1K(#T@)&%;
M)VYA;64G73L*("`@("`@("`@("`@:68@*"1P87)A;7-);DME>7,@)B8@:7-?
M87)R87DH)&%;)W!A<F%M<R==*2D@>PH@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)&%;)W!A<F%M<R==(&%S("1P(#T^("1V*2!["B`@("`@("`@("`@("`@
M("`@("`@)&L@+CT@(CLD<#TD=B(["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)&AA<VA;)&M=(#T@)&%;)W9A;'5E)UT[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&AA<V@["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!087)S97,@82!S=')I;F<@8V]N=&%I;FEN9R!V0V%L96YD
M87(@9&%T82X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("`@
M("!4:&4@9&%T82!T;R!P87)S92X*("`@("`J($!P87)A;2!S=')I;F<@)&)A
M<V4@("`@(%1H92!T>7!E(&]F('1H92!B87-E(&]B:F5C="X*("`@("`J($!P
M87)A;2!S=')I;F<@)&-H87)S970@(%1H92!E;F-O9&EN9R!C:&%R<V5T(&9O
M<B`D=&5X="X@1&5F875L=',@=&\*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@('5T9BTX+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&-L96%R("`@
M268@=')U92!C;&5A<G,@=&AE(&E#86P@;V)J96-T(&)E9F]R92!P87)S:6YG
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C
M97-S9G5L(&EM<&]R="P@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!P87)S979#86QE;F1A<B@D=&5X="P@)&)A<V4@/2`G5D-!3$5.
M1$%2)RP@)&-H87)S970@/2`G=71F+3@G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&-L96%R(#T@=')U92D*("`@('L*("`@("`@("!I9B`H)&-L
M96%R*2!["B`@("`@("`@("`@("1T:&ES+3YC;&5A<B@I.PH@("`@("`@('T*
M("`@("`@("!I9B`H<')E9U]M871C:"@G+RA"14=)3CHG("X@)&)A<V4@+B`G
M7'(_7&X_*2A;7%=<=UTJ*2A%3D0Z)R`N("1B87-E("X@)UQR/UQN/RDO:2<L
M("1T97AT+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@)'9#86P@/2`D;6%T
M8VAE<ULR73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!497AT
M(&ES;B=T(&5N8VQO<V5D(&EN($)%1TE..E9#04Q%3D1!4@H@("`@("`@("`@
M("`O+R`N+B!%3D0Z5D-!3$5.1$%2+B!792=L;"!T<GD@=&\@<&%R<V4@:70@
M86YY=V%Y+@H@("`@("`@("`@("`D=D-A;"`]("1T97AT.PH@("`@("`@('T*
M"B`@("`@("`@+R\@06QL('-U8F-O;7!O;F5N=',N"B`@("`@("`@)&UA=&-H
M97,@/2!N=6QL.PH@("`@("`@(&EF("AP<F5G7VUA=&-H7V%L;"@G+T)%1TE.
M.BA;7%=<=UTJ*2A<<EQN?%QR?%QN*2A;7%=<=UTJ*45.1#I<,2A<<EQN?%QR
M?%QN*2]5:2<L("1V0V%L+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@9F]R
M96%C:"`H)&UA=&-H97-;,%T@87,@)&ME>2`]/B`D9&%T82D@>PH@("`@("`@
M("`@("`@("`@)'1Y<&4@/2!T<FEM*"1M871C:&5S6S%=6R1K97E=*3L*("`@
M("`@("`@("`@("`@("1C;VUP;VYE;G0@/2`F2&]R9&5?:4-A;&5N9&%R.CIN
M97=#;VUP;VYE;G0H)'1Y<&4L("1T:&ES*3L*("`@("`@("`@("`@("`@(&EF
M("@D8V]M<&]N96YT(#T]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*")5;F%B;&4@=&\@8W)E871E(&]B
M:F5C="!F;W(@='EP92`D='EP92(I.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@)&-O;7!O;F5N="T^<&%R<V5V0V%L96YD87(H)&1A=&$I
M.PH*("`@("`@("`@("`@("`@("1T:&ES+3YA9&1#;VUP;VYE;G0H)&-O;7!O
M;F5N="D["@H@("`@("`@("`@("`@("`@+R\@4F5M;W9E(&9R;VT@=&AE('9#
M86QE;F1A<B!D871A+@H@("`@("`@("`@("`@("`@)'9#86P@/2!S=')?<F5P
M;&%C92@D9&%T82P@)R<L("1V0V%L*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@+R\@56YF;VQD(&%N>2!F;VQD960@;&EN97,N"B`@("`@
M("`@)'9#86P@/2!P<F5G7W)E<&QA8V4H)R];7')<;ETK6R!<=%TO)RP@)R<L
M("1V0V%L*3L*"B`@("`@("`@+R\@56YF;VQD(")Q=6]T960@<')I;G1A8FQE
M(B!F;VQD960@;&EN97,@;&EK93H*("`@("`@("`O+R`@0D]$63M%3D-/1$E.
M1SU154]4140M4%))3E1!0DQ%.CT*("`@("`@("`O+R`@86YO=&AE<CTR,&QI
M;F4]"B`@("`@("`@+R\@(&QA<W0],C!L:6YE"B`@("`@("`@=VAI;&4@*'!R
M96=?;6%T8VA?86QL*"<O7BA;7CI=*SM<<RI%3D-/1$E.1SU154]4140M4%))
M3E1!0DQ%*"XJ/5QR/UQN*2LH+BI;7CU=*3]<<C]<;BDO;54G+"`D=D-A;"P@
M)&UA=&-H97,I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1M871C:&5S6S%=
M(&%S("1S*2!["B`@("`@("`@("`@("`@("`D<B`]('!R96=?<F5P;&%C92@G
M+SU<<C]<;B\G+"`G)RP@)',I.PH@("`@("`@("`@("`@("`@)'9#86P@/2!S
M=')?<F5P;&%C92@D<RP@)'(L("1V0V%L*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@+R\@4&%R<V4@=&AE(')E;6%I;FEN9R!A='1R:6)U
M=&5S+@H@("`@("`@(&EF("AP<F5G7VUA=&-H7V%L;"@G+R@N*BDZ*%M>7')<
M;ETJ*5M<<EQN72LO)RP@)'9#86PL("1M871C:&5S*2D@>PH@("`@("`@("`@
M("!F;W)E86-H("@D;6%T8VAE<ULP72!A<R`D871T<FEB=71E*2!["B`@("`@
M("`@("`@("`@("!P<F5G7VUA=&-H*"<O*%M>.UXZ72HI*"@[6UXZ72HI/RDZ
M*%M>7')<;ETJ*5M<<EQN72HO)RP@)&%T=')I8G5T92P@)'!A<G1S*3L*("`@
M("`@("`@("`@("`@("1T86<@/2!3=')I;F<Z.G5P<&5R*"1P87)T<ULQ72D[
M"B`@("`@("`@("`@("`@("`D=F%L=64@/2`D<&%R='-;-%T["B`@("`@("`@
M("`@("`@("`D<&%R86US(#T@87)R87DH*3L*"B`@("`@("`@("`@("`@("`O
M+R!087)S92!P87)A;65T97)S+@H@("`@("`@("`@("`@("`@:68@*"%E;7!T
M>2@D<&%R='-;,ETI*2!["B`@("`@("`@("`@("`@("`@("`@<')E9U]M871C
M:%]A;&PH)R\[*"A;7CL]72HI*#TH6UX[72HI*3\I+R<L("1P87)T<ULR72P@
M)'!A<F%M7W!A<G1S*3L*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D
M<&%R86U?<&%R='-;,ET@87,@)&ME>2`]/B`D<&%R86U.86UE*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1P87)A;59A;'5E(#T@)'!A<F%M7W!A<G1S
M6S1=6R1K97E=.PH@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86US6U-T
M<FEN9SHZ=7!P97(H)'!A<F%M3F%M92E=(#T@)'!A<F%M5F%L=64["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@("`@("\O($-H87)S970@86YD(&5N8V]D:6YG(&AA;F1L:6YG+@H@("`@
M("`@("`@("`@("`@:68@*"AI<W-E="@D<&%R86US6R=%3D-/1$E.1R==*0H@
M("`@("`@("`@("`@("`@("`@("`F)B!3=')I;F<Z.G5P<&5R*"1P87)A;7-;
M)T5.0T]$24Y')UTI(#T]("=154]4140M4%))3E1!0DQ%)RD*("`@("`@("`@
M("`@("`@("`@("!\?"!I<W-E="@D<&%R86US6R=154]4140M4%))3E1!0DQ%
M)UTI*2!["@H@("`@("`@("`@("`@("`@("`@("1V86QU92`]('%U;W1E9%]P
M<FEN=&%B;&5?9&5C;V1E*"1V86QU92D["B`@("`@("`@("`@("`@("`@("`@
M+R\@475O=&5D('!R:6YT86)L92!I<R!N;W)M86QL>2!E;F-O9&5D(&%S('5T
M9BTX+@H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<&%R86US6R=#
M2$%24T54)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU92`]
M(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'9A;'5E+"`D<&%R86US6R=#2$%2
M4T54)UTI.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1V86QU92`](%-T<FEN9SHZ8V]N=F5R=$-H87)S
M970H)'9A;'5E+"`G=71F+3@G*3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!](&5L<V5I9B`H:7-S970H)'!A<F%M<ULG0TA!4E-%
M5"==*2D@>PH@("`@("`@("`@("`@("`@("`@("1V86QU92`](%-T<FEN9SHZ
M8V]N=F5R=$-H87)S970H)'9A;'5E+"`D<&%R86US6R=#2$%24T54)UTI.PH@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`O
M+R!!<R!P97(@4D9#(#(R-SDL(&%S<W5M92!55$8X(&EF('=E(&1O;B=T(&AA
M=F4@86X*("`@("`@("`@("`@("`@("`@("`O+R!E>'!L:6-I="!C:&%R<V5T
M('!A<F%M971E<BX*("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2!3=')I
M;F<Z.F-O;G9E<G1#:&%R<V5T*"1V86QU92P@)&-H87)S970I.PH@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@('-W:71C:"`H)'1A9RD@>PH@
M("`@("`@("`@("`@("`@+R\@1&%T92!F:65L9',N"B`@("`@("`@("`@("`@
M("!C87-E("=#3TU03$54140G.@H@("`@("`@("`@("`@("`@8V%S92`G0U)%
M051%1"<Z"B`@("`@("`@("`@("`@("!C87-E("=,05-4+4U/1$E&245$)SH*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T071T<FEB=71E*"1T86<L
M("1T:&ES+3Y?<&%R<V5$871E5&EM92@D=F%L=64I+"`D<&%R86US*3L*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E
M("="1$%9)SH*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T071T<FEB
M=71E*"1T86<L("1T:&ES+3Y?<&%R<V5$871E*"1V86QU92DL("1P87)A;7,I
M.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@
M(&-A<V4@)T1414Y$)SH*("`@("`@("`@("`@("`@(&-A<V4@)T144U1!4E0G
M.@H@("`@("`@("`@("`@("`@8V%S92`G1%135$%-4"<Z"B`@("`@("`@("`@
M("`@("!C87-E("=$544G.@H@("`@("`@("`@("`@("`@8V%S92`G04%,05)-
M)SH*("`@("`@("`@("`@("`@(&-A<V4@)U)%0U524D5.0T4M240G.@H@("`@
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<&%R86US6R=604Q512==*2`F
M)B`D<&%R86US6R=604Q512==(#T]("=$051%)RD@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^<V5T071T<FEB=71E*"1T86<L("1T:&ES+3Y?
M<&%R<V5$871E*"1V86QU92DL("1P87)A;7,I.PH@("`@("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS
M971!='1R:6)U=&4H)'1A9RP@)'1H:7,M/E]P87)S941A=&54:6UE*"1V86QU
M92DL("1P87)A;7,I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=44DE'
M1T52)SH*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG
M5D%,544G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1P87)A
M;7-;)U9!3%5%)UT@/3T@)T1!5$4M5$E-12<I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H)'1A9RP@)'1H:7,M
M/E]P87)S941A=&54:6UE*"1V86QU92DL("1P87)A;7,I.PH@("`@("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G-E=$%T=')I8G5T92@D=&%G+"`D=&AI<RT^7W!A<G-E
M1'5R871I;VXH)'9A;'5E*2P@)'!A<F%M<RD["B`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T071T<FEB=71E*"1T86<L("1T
M:&ES+3Y?<&%R<V5$=7)A=&EO;B@D=F%L=64I+"`D<&%R86US*3L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@("`@("`@("`@+R\@0V]M;6$@<V5P97)A=&5D(&1A=&5S+@H@("`@
M("`@("`@("`@("`@8V%S92`G15A$051%)SH*("`@("`@("`@("`@("`@(&-A
M<V4@)U)$051%)SH*("`@("`@("`@("`@("`@("`@("`D9&%T97,@/2!A<G)A
M>2@I.PH@("`@("`@("`@("`@("`@("`@('!R96=?;6%T8VA?86QL*"<O+"A;
M7BQ=*BDO)RP@)RPG("X@)'9A;'5E+"`D=F%L=65S*3L*"B`@("`@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)'9A;'5E<ULQ72!A<R`D=F%L=64I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&1A=&5S6UT@/2`D=&AI<RT^7W!A<G-E
M1&%T92@D=F%L=64I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^<V5T071T<FEB=71E*"1T86<L(&ES<V5T*"1D
M871E<ULP72D@/R`D9&%T97-;,%T@.B!N=6QL+"`D<&%R86US+"!T<G5E+"`D
M9&%T97,I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@("`@("\O($1U<F%T:6]N(&9I96QD<RX*("`@("`@("`@("`@("`@(&-A
M<V4@)T154D%424].)SH*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T
M071T<FEB=71E*"1T86<L("1T:&ES+3Y?<&%R<V5$=7)A=&EO;B@D=F%L=64I
M+"`D<&%R86US*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@("`@("`O+R!097)I;V0@;V8@=&EM92!F:65L9',N"B`@("`@("`@
M("`@("`@("!C87-E("=&4D5%0E5362<Z"B`@("`@("`@("`@("`@("`@("`@
M)'!E<FEO9',@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@('!R96=?
M;6%T8VA?86QL*"<O+"A;7BQ=*BDO)RP@)RPG("X@)'9A;'5E+"`D=F%L=65S
M*3L*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D=F%L=65S6S%=(&%S
M("1V86QU92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<&5R:6]D<UM=
M(#T@)'1H:7,M/E]P87)S95!E<FEO9"@D=F%L=64I.PH@("`@("`@("`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$%T=')I
M8G5T92@D=&%G+"!I<W-E="@D<&5R:6]D<ULP72D@/R`D<&5R:6]D<ULP72`Z
M(&YU;&PL("1P87)A;7,L('1R=64L("1P97)I;V1S*3L*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("`O+R!55$,@;V9F<V5T
M(&9I96QD<RX*("`@("`@("`@("`@("`@(&-A<V4@)U1:3T9&4T541E)/32<Z
M"B`@("`@("`@("`@("`@("!C87-E("=46D]&1E-%5%1/)SH*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^<V5T071T<FEB=71E*"1T86<L("1T:&ES+3Y?
M<&%R<V55=&-/9F9S970H)'9A;'5E*2P@)'!A<F%M<RD["B`@("`@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@+R\@26YT96=E<B!F
M:65L9',N"B`@("`@("`@("`@("`@("!C87-E("=015)#14Y4+4-/35!,151%
M)SH*("`@("`@("`@("`@("`@(&-A<V4@)U!224]22519)SH*("`@("`@("`@
M("`@("`@(&-A<V4@)U)%4$5!5"<Z"B`@("`@("`@("`@("`@("!C87-E("=3
M15%514Y#12<Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$%T=')I
M8G5T92@D=&%G+"!I;G1V86PH)'9A;'5E*2P@)'!A<F%M<RD["B`@("`@("`@
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@+R\@1V5O(&9I
M96QD<RX*("`@("`@("`@("`@("`@(&-A<V4@)T=%3R<Z"B`@("`@("`@("`@
M("`@("`@("`@)&9L;V%T<R`](&5X<&QO9&4H)SLG+"`D=F%L=64I.PH@("`@
M("`@("`@("`@("`@("`@("1V86QU95LG;&%T:71U9&4G72`](&9L;V%T=F%L
M*"1F;&]A='-;,%TI.PH@("`@("`@("`@("`@("`@("`@("1V86QU95LG;&]N
M9VET=61E)UT@/2!F;&]A='9A;"@D9FQO871S6S%=*3L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^<V5T071T<FEB=71E*"1T86<L("1V86QU92P@)'!A
M<F%M<RD["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("`@("`@+R\@4F5C=7)S:6]N(&9I96QD<RX*("`@("`@("`@("`@("`@(&-A
M<V4@)T584E5,12<Z"B`@("`@("`@("`@("`@("!C87-E("=24E5,12<Z"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$%T=')I8G5T92@D=&%G+"!T
M<FEM*"1V86QU92DL("1P87)A;7,I.PH@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("`@("`@("`@("\O($%$4BP@86YD($X@87)E(&QI<W1S
M('-E<&5R871E9"!B>2!U;F5S8V%P960*("`@("`@("`@("`@("`@("\O('-E
M;6EC;VQO;G,@=VET:"!A('-P96-I9FEC(&YU;6)E<B!O9B!S;&]T<RX*("`@
M("`@("`@("`@("`@(&-A<V4@)T%$4B<Z"B`@("`@("`@("`@("`@("!C87-E
M("=.)SH*("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2!T<FEM*"1V86QU
M92D["B`@("`@("`@("`@("`@("`@("`@+R\@07,@;V8@<F9C(#(T,C8@,BXT
M+C(@<V5M:6-O;&]N+"!C;VUM82P@86YD"B`@("`@("`@("`@("`@("`@("`@
M+R\@8V]L;VX@;75S="!B92!E<V-A<&5D("AC;VUM82!I<R!U;F5S8V%P960@
M869T97(*("`@("`@("`@("`@("`@("`@("`O+R!S<&QI='1I;F<@8F5L;W<I
M+@H@("`@("`@("`@("`@("`@("`@("1V86QU92`]('-T<E]R97!L86-E*&%R
M<F%Y*"=<7&XG+"`G7%P[)RP@)UQ<.B<I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1T:&ES+3Y?;F5W;&EN92P@
M)SLG+"`G.B<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1V86QU92D["@H@("`@("`@("`@("`@("`@("`@("\O(%-P;&ET
M(&)Y('5N97-C87!E9"!S96UI8V]L;VYS.@H@("`@("`@("`@("`@("`@("`@
M("1V86QU97,@/2!P<F5G7W-P;&ET*"<O*#\\(5Q<7%PI.R\G+"`D=F%L=64I
M.PH@("`@("`@("`@("`@("`@("`@("1V86QU92`]('-T<E]R97!L86-E*"=<
M7#LG+"`G.R<L("1V86QU92D["B`@("`@("`@("`@("`@("`@("`@)'9A;'5E
M<R`]('-T<E]R97!L86-E*"=<7#LG+"`G.R<L("1V86QU97,I.PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H)'1A9RP@=')I;2@D
M=F%L=64I+"`D<&%R86US+"!T<G5E+"`D=F%L=65S*3L*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("`O+R!/4D<@:7,@82!L
M:7-T('-E<&5R871E9"!B>2!U;F5S8V%P960@<V5M:6-O;&]N<R!B=70*("`@
M("`@("`@("`@("`@("\O('=I=&@@;F\@96UP='D@=F%L=65S+@H@("`@("`@
M("`@("`@("`@8V%S92`G3U)')SH*("`@("`@("`@("`@("`@("`@("`D=F%L
M=64@/2!T<FEM*"1V86QU92D["B`@("`@("`@("`@("`@("`@("`@+R\@07,@
M;V8@<F9C(#(T,C8@,BXT+C(@<V5M:6-O;&]N+"!C;VUM82P@86YD"B`@("`@
M("`@("`@("`@("`@("`@+R\@8V]L;VX@;75S="!B92!E<V-A<&5D("AC;VUM
M82!I<R!U;F5S8V%P960@869T97(*("`@("`@("`@("`@("`@("`@("`O+R!S
M<&QI='1I;F<@8F5L;W<I+@H@("`@("`@("`@("`@("`@("`@("1V86QU92`]
M('-T<E]R97!L86-E*&%R<F%Y*"=<7&XG+"`G7%P[)RP@)UQ<.B<I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1T
M:&ES+3Y?;F5W;&EN92P@)SLG+"`G.B<I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1V86QU92D["@H@("`@("`@("`@("`@
M("`@("`@("\O(%-P;&ET(&)Y('5N97-C87!E9"!S96UI8V]L;VYS.@H@("`@
M("`@("`@("`@("`@("`@("1V86QU97,@/2!P<F5G7W-P;&ET*"<O*#\\(5Q<
M7%PI.R\G+"`D=F%L=64L("TQ+"!04D5'7U-03$E47TY/7T5-4%19*3L*("`@
M("`@("`@("`@("`@("`@("`D=F%L=64@/2!S=')?<F5P;&%C92@G7%P[)RP@
M)SLG+"`D=F%L=64I.PH@("`@("`@("`@("`@("`@("`@("1V86QU97,@/2!S
M=')?<F5P;&%C92@G7%P[)RP@)SLG+"`D=F%L=65S*3L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^<V5T071T<FEB=71E*"1T86<L('1R:6TH)'9A;'5E
M*2P@)'!A<F%M<RP@=')U92P@)'9A;'5E<RD["B`@("`@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("`@("`@+R\@4W1R:6YG(&9I96QD<RX*
M("`@("`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@
M:68@*"1T:&ES+3YI<T]L9$9O<FUA="@I*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("\O('9C86QE;F1A<B`Q+C`@86YD('9C87)D(#(N,2!O;FQY(&5S
M8V%P92!S96UI8V]L;VYS"B`@("`@("`@("`@("`@("`@("`@("`@("\O(&%N
M9"!U<V4@=6YE<V-A<&5D('-E;6EC;VQO;G,@=&\@8W)E871E(&QI<W1S+@H@
M("`@("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2!T<FEM*"1V86QU92D[
M"B`@("`@("`@("`@("`@("`@("`@("`@("\O(%-P;&ET(&)Y('5N97-C87!E
M9"!S96UI8V]L;VYS.@H@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=65S
M(#T@<')E9U]S<&QI="@G+R@_/"%<7%Q<*3LO)RP@)'9A;'5E*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@<W1R7W)E<&QA8V4H)UQ<.R<L
M("<[)RP@)'9A;'5E*3L*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E
M<R`]('-T<E]R97!L86-E*"=<7#LG+"`G.R<L("1V86QU97,I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T071T<FEB=71E*"1T86<L('1R
M:6TH)'9A;'5E*2P@)'!A<F%M<RP@=')U92P@)'9A;'5E<RD["B`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)'9A;'5E(#T@=')I;2@D=F%L=64I.PH@("`@("`@("`@("`@("`@("`@("`@
M("`O+R!!<R!O9B!R9F,@,C0R-B`R+C0N,B!S96UI8V]L;VXL(&-O;6UA+"!A
M;F0*("`@("`@("`@("`@("`@("`@("`@("`@+R\@8V]L;VX@;75S="!B92!E
M<V-A<&5D("AC;VUM82!I<R!U;F5S8V%P960@869T97(*("`@("`@("`@("`@
M("`@("`@("`@("`@+R\@<W!L:71T:6YG(&)E;&]W*2X*("`@("`@("`@("`@
M("`@("`@("`@("`@)'9A;'5E(#T@<W1R7W)E<&QA8V4H87)R87DH)UQ<;B<L
M("=<7#LG+"`G7%PZ)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"1T:&ES+3Y?;F5W;&EN92P@)SLG+"`G
M.B<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=F%L=64I.PH*("`@("`@("`@("`@("`@("`@("`@("`@+R\@4W!L
M:70@8GD@=6YE<V-A<&5D(&-O;6UA<SH*("`@("`@("`@("`@("`@("`@("`@
M("`@)'9A;'5E<R`]('!R96=?<W!L:70H)R\H/SPA7%Q<7"DL+R<L("1V86QU
M92D["B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU92`]('-T<E]R97!L
M86-E*"=<7"PG+"`G+"<L("1V86QU92D["B`@("`@("`@("`@("`@("`@("`@
M("`@("1V86QU97,@/2!S=')?<F5P;&%C92@G7%PL)RP@)RPG+"`D=F%L=65S
M*3L*"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971!='1R:6)U
M=&4H)'1A9RP@=')I;2@D=F%L=64I+"`D<&%R86US+"!T<G5E+"`D=F%L=65S
M*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@17AP;W)T('1H:7,@8V]M<&]N96YT(&EN('9#86P@9F]R;6%T+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&)A<V4@(%1H92!T>7!E(&]F('1H
M92!B87-E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M=D-A;"!F;W)M870@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@7V5X<&]R
M='9$871A*"1B87-E(#T@)U9#04Q%3D1!4B<I"B`@("!["B`@("`@("`@)')E
M<W5L="`]("="14=)3CHG("X@4W1R:6YG.CIU<'!E<B@D8F%S92D@+B`D=&AI
M<RT^7VYE=VQI;F4["@H@("`@("`@("\O(%9%4E-)3TX@:7,@;F]T(&%L;&]W
M960@9F]R(&5N=')I97,@96YC;&]S960@:6X@5D-!3$5.1$%2+TE#04Q%3D1!
M4BP*("`@("`@("`O+R!A<R!I="!I<R!P87)T(&]F('1H92!E;F-L;W-I;F<@
M5D-!3$5.1$%2+TE#04Q%3D1!4BX@4V5E(')F8S(T-#4*("`@("`@("!I9B`H
M)&)A<V4@(3T]("=6159%3E0G("8F("1B87-E("$]/2`G5E1/1$\G("8F("1B
M87-E("$]/2`G5D%,05)-)R`F)@H@("`@("`@("`@("`D8F%S92`A/3T@)U9*
M3U523D%,)R`F)B`D8F%S92`A/3T@)U9&4D5%0E5362<I('L*("`@("`@("`@
M("`@+R\@16YS=7)E('1H870@=F5R<VEO;B!I<R!T:&4@9FER<W0@871T<FEB
M=71E+@H@("`@("`@("`@("`D<F5S=6QT("X]("=615)324]..B<@+B`D=&AI
M<RT^7W9E<G-I;VX@+B`D=&AI<RT^7VYE=VQI;F4["B`@("`@("`@?0H@("`@
M("`@(&9O<F5A8V@@*"1T:&ES+3Y?871T<FEB=71E<R!A<R`D871T<FEB=71E
M*2!["B`@("`@("`@("`@("1N86UE(#T@)&%T=')I8G5T95LG;F%M92==.PH@
M("`@("`@("`@("!I9B`H)&YA;64@/3T@)U9%4E-)3TXG*2!["B`@("`@("`@
M("`@("`@("`O+R!!;')E861Y(&1O;F4N"B`@("`@("`@("`@("`@("!C;VYT
M:6YU93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'!A<F%M<U]S='(@
M/2`G)SL*("`@("`@("`@("`@)'!A<F%M<R`]("1A='1R:6)U=&5;)W!A<F%M
M<R==.PH@("`@("`@("`@("!I9B`H)'!A<F%M<RD@>PH@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D<&%R86U?;F%M92`]/B`D<&%R86U?
M=F%L=64I('L*("`@("`@("`@("`@("`@("`@("`O+R!3:VEP($-(05)3150@
M9F]R(&E#86QE;F1A<B`R+C`@9&%T82P@;F]T"B`@("`@("`@("`@("`@("`@
M("`@+R\@86QL;W=E9"X*("`@("`@("`@("`@("`@("`@("!I9B`H)'!A<F%M
M7VYA;64@/3T@)T-(05)3150G("8F("$D=&AI<RT^:7-/;&1&;W)M870H*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)'!A<F%M<U]S='(@
M+CT@(CLD<&%R86U?;F%M93TD<&%R86U?=F%L=64B.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=F%L=64@/2`D871T
M<FEB=71E6R=V86QU92==.PH@("`@("`@("`@("!S=VET8V@@*"1N86UE*2![
M"B`@("`@("`@("`@("\O($1A=&4@9FEE;&1S+@H@("`@("`@("`@("!C87-E
M("=#3TU03$54140G.@H@("`@("`@("`@("!C87-E("=#4D5!5$5$)SH*("`@
M("`@("`@("`@8V%S92`G1$-214%4140G.@H@("`@("`@("`@("!C87-E("=,
M05-4+4U/1$E&245$)SH*("`@("`@("`@("`@("`@("1V86QU92`]("1T:&ES
M+3Y?97AP;W)T1&%T951I;64H)'9A;'5E*3L*("`@("`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("`@("`@8V%S92`G1%1%3D0G.@H@("`@("`@("`@("!C
M87-E("=$5%-405)4)SH*("`@("`@("`@("`@8V%S92`G1%135$%-4"<Z"B`@
M("`@("`@("`@(&-A<V4@)T1512<Z"B`@("`@("`@("`@(&-A<V4@)T%!3$%2
M32<Z"B`@("`@("`@("`@(&-A<V4@)U)%0U524D5.0T4M240G.@H@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1P87)A;7-;)U9!3%5%)UTI*2!["B`@("`@
M("`@("`@("`@("`@("`@:68@*"1P87)A;7-;)U9!3%5%)UT@/3T@)T1!5$4G
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU92`]("1T:&ES+3Y?
M97AP;W)T1&%T92@D=F%L=64I.PH@("`@("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU92`]("1T:&ES+3Y?
M97AP;W)T1&%T951I;64H)'9A;'5E*3L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("1V86QU92`]("1T:&ES+3Y?97AP;W)T1&%T951I;64H)'9A;'5E*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@+R\@0V]M;6$@<V5P97)A=&5D(&1A=&5S+@H@("`@("`@("`@("!C
M87-E("=%6$1!5$4G.@H@("`@("`@("`@("!C87-E("=21$%412<Z"B`@("`@
M("`@("`@("`@("`D9&%T97,@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)'9A;'5E(&%S("1D871E*2!["B`@("`@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1P87)A;7-;)U9!3%5%)UTI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("@D<&%R86US6R=604Q512==(#T]("=$051%)RD@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&5S6UT@/2`D=&AI
M<RT^7V5X<&]R=$1A=&4H)&1A=&4I.PH@("`@("`@("`@("`@("`@("`@("`@
M("!](&5L<V5I9B`H)'!A<F%M<ULG5D%,544G72`]/2`G4$5224]$)RD@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&5S6UT@/2`D=&AI<RT^
M7V5X<&]R=%!E<FEO9"@D9&%T92D["B`@("`@("`@("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&%T97-;
M72`]("1T:&ES+3Y?97AP;W)T1&%T951I;64H)&1A=&4I.PH@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&5S6UT@/2`D=&AI<RT^7V5X
M<&]R=$1A=&54:6UE*"1D871E*3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=F%L=64@/2!I;7!L
M;V1E*"<L)RP@)&1A=&5S*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@8V%S92`G5%))1T=%4B<Z"B`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)'!A<F%M<ULG5D%,544G72DI('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H)'!A<F%M<ULG5D%,544G72`]/2`G1$%412U424U%)RD@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2`D=&AI<RT^7V5X<&]R=$1A
M=&54:6UE*"1V86QU92D["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@
M*"1P87)A;7-;)U9!3%5%)UT@/3T@)T154D%424].)RD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D=F%L=64@/2`D=&AI<RT^7V5X<&]R=$1U<F%T:6]N
M*"1V86QU92D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2`D=&AI
M<RT^7V5X<&]R=$1U<F%T:6]N*"1V86QU92D["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("\O($1U<F%T
M:6]N(&9I96QD<RX*("`@("`@("`@("`@8V%S92`G1%52051)3TXG.@H@("`@
M("`@("`@("`@("`@)'9A;'5E(#T@)'1H:7,M/E]E>'!O<G1$=7)A=&EO;B@D
M=F%L=64I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`O
M+R!097)I;V0@;V8@=&EM92!F:65L9',N"B`@("`@("`@("`@(&-A<V4@)T92
M145"55-9)SH*("`@("`@("`@("`@("`@("1V86QU95]S='(@/2`G)SL*("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1V86QU92!A<R`D<&5R:6]D*2!["B`@
M("`@("`@("`@("`@("`@("`@)'9A;'5E7W-T<B`N/2!E;7!T>2@D=F%L=65?
M<W1R*2`_("<G(#H@)RPG.PH@("`@("`@("`@("`@("`@("`@("1V86QU95]S
M='(@+CT@)'1H:7,M/E]E>'!O<G1097)I;V0H)'!E<FEO9"D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`D=F%L=64@/2`D=F%L=65?<W1R
M.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`O+R!55$,@
M;V9F<V5T(&9I96QD<RX*("`@("`@("`@("`@8V%S92`G5%I/1D93151&4D]-
M)SH*("`@("`@("`@("`@8V%S92`G5%I/1D9315143R<Z"B`@("`@("`@("`@
M("`@("`D=F%L=64@/2`D=&AI<RT^7V5X<&]R=%5T8T]F9G-E="@D=F%L=64I
M.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`O+R!);G1E
M9V5R(&9I96QD<RX*("`@("`@("`@("`@8V%S92`G4$520T5.5"U#3TU03$54
M12<Z"B`@("`@("`@("`@(&-A<V4@)U!224]22519)SH*("`@("`@("`@("`@
M8V%S92`G4D5014%4)SH*("`@("`@("`@("`@8V%S92`G4T51545.0T4G.@H@
M("`@("`@("`@("`@("`@)'9A;'5E(#T@(B1V86QU92(["B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@("\O($=E;R!F:65L9',N"B`@("`@
M("`@("`@(&-A<V4@)T=%3R<Z"B`@("`@("`@("`@("`@("`D=F%L=64@/2`D
M=F%L=65;)VQA=&ET=61E)UT@+B`G+"<@+B`D=F%L=65;)VQO;F=I='5D92==
M.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`O+R!296-U
M<G)E;F-E(&9I96QD<RX*("`@("`@("`@("`@8V%S92`G15A254Q%)SH*("`@
M("`@("`@("`@8V%S92`G4E)53$4G.@H@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("`O+R!!='1E;F1A;F-E"B`@("`@("`@("`@(&-A<V4@
M)T%45$5.1$5%)SH*("`@("`@("`@("`@("`@("\O($MR;VYO;&ET:"!C<F5A
M=&5S(&%T=&5N9&5E(&9I96QD(&EN('9C86QE;F1A<C(N,"!F;W)M870N"B`@
M("`@("`@("`@("`@("`O+R!#;VYV97)T('1O('9C86QE;F1A<C$N,"!I9B!N
M96-E<W-A<GDN"B`@("`@("`@("`@("`@("`O+R!%>&%M<&QE(&]F(#$N,"!S
M='EL93H*("`@("`@("`@("`@("`@("\O($%45$5.1$5%.U)/3$4]3U=.15([
M4U1!5%53/4-/3D9)4DU%1#I*;VAN(%-M:71H(#QJ<VUI=&A`:&]S=#$N8V]M
M/@H@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YI<T]L9$9O<FUA="@I*2![
M"B`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@<')E9U]R97!L86-E*"<O
M34%)3%1/.B\G+"`G)RP@)'9A;'5E*3L*("`@("`@("`@("`@("`@("`@("`D
M=F%L=64@/2`@)'9A;'5E("X@)R`\)R`N("1V86QU92`N("<^)SL*("`@("`@
M("`@("`@("`@("`@("`D<&%R86US7W-T<B`]('-T<E]R97!L86-E*"=005)4
M4U1!5#TG+"`G4U1!5%53/2<L("1P87)A;7-?<W1R*3L*("`@("`@("`@("`@
M("`@("`@("`D<&%R86US7W-T<B`]('-T<E]R97!L86-E*"=35$%455,]3D5%
M1%,M04-424].)RP@)U-405154SU.145$4R!!0U1)3TXG+"`D<&%R86US7W-T
M<BD["B`@("`@("`@("`@("`@("`@("`@)'!A<F%M<U]S='(@/2!S=')?<F5P
M;&%C92@G4D],13U215$M4$%25$E#25!!3E0G+"`G15A014-4/5)%455)4D4G
M+"`D<&%R86US7W-T<BD["B`@("`@("`@("`@("`@("`@("`@)'!A<F%M<U]S
M='(@/2!S=')?<F5P;&%C92@G4D],13U/4%0M4$%25$E#25!!3E0G+"`G15A0
M14-4/5)%455%4U0G+"`D<&%R86US7W-T<BD["B`@("`@("`@("`@("`@("`@
M("`@)'!A<F%M<U]S='(@/2!S=')?<F5P;&%C92@G4D],13U.3TXM4$%25$E#
M25!!3E0G+"`G15A014-4/49922<L("1P87)A;7-?<W1R*3L*("`@("`@("`@
M("`@("`@("`@("`D<&%R86US7W-T<B`]('-T<E]R97!L86-E*"=24U90/512
M544G+"`G4E-64#U915,G+"`D<&%R86US7W-T<BD["B`@("`@("`@("`@("`@
M("`@("`@)'!A<F%M<U]S='(@/2!S=')?<F5P;&%C92@G4E-64#U&04Q312<L
M("=24U90/4Y/)RP@)'!A<F%M<U]S='(I.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@
M("`@("`@("`@("`@("!I9B`H)'1H:7,M/FES3VQD1F]R;6%T*"DI('L*("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)&%T=')I8G5T95LG=F%L
M=65S)UTI"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`F)B!C;W5N="@D
M871T<FEB=71E6R=V86QU97,G72D^,2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D=F%L=65S(#T@)&%T=')I8G5T95LG=F%L=65S)UT["B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@D;F%M92`]/2`G3B<@?'P@)&YA;64@/3T@
M)T%$4B<I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1G;'5E(#T@
M)SLG.PH@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&=L=64@/2`G+"<["B`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E
M<R`@/2!S=')?<F5P;&%C92AA<G)A>2@G.R<I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G7%P[)RDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V
M86QU97,I.PH@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2!I;7!L
M;V1E*"1G;'5E+"`D=F%L=65S*3L*("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`O*B!V8V%R9"`R+C$@86YD
M('9C86QE;F1A<B`Q+C`@97-C87!E(&]N;'D*("`@("`@("`@("`@("`@("`@
M("`@("`@("H@<V5M:6-O;&]N<R`J+PH@("`@("`@("`@("`@("`@("`@("`@
M("`D=F%L=64@/2!S=')?<F5P;&%C92AA<G)A>2@G.R<I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G7%P[
M)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1V86QU92D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@(&EF("@D;F%M92`]/2`G4U1!5%53)RD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!V8V%L96YD87(@,2XP(&AA<R!35$%455,Z3D5%
M1%,@04-424].('=H:6QE(#(N,"!H87,*("`@("`@("`@("`@("`@("`@("`@
M("`@+R\@4U1!5%53.DY%1413+4%#5$E/3BX*("`@("`@("`@("`@("`@("`@
M("`@("`@)'9A;'5E(#T@<W1R7W)E<&QA8V4H)TY%1413+4%#5$E/3B<L("=.
M145$4R!!0U1)3TXG+"`D=F%L=64I.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`O+R!497AT(&-O;G1A:6YI;F<@;F5W;&EN
M97,@;W(@05-#24D@/CT@,3(W(&UU<W0@8F4@0D%3138T"B`@("`@("`@("`@
M("`@("`@("`@+R\@;W(@455/5$5$+5!224Y404),12!E;F-O9&5D+B!#=7)R
M96YT;'D@=V4@=7-E"B`@("`@("`@("`@("`@("`@("`@+R\@455/5$5$+5!2
M24Y404),12!A<R!D969A=6QT+@H@("`@("`@("`@("`@("`@("`@("\O($9)
M6$U%.B!D96%L('=I=&@@8F%S938T(&5N8V]D:6YG<R$*("`@("`@("`@("`@
M("`@("`@("!I9B`H<')E9U]M871C:"@B+UM>7'@R,"U<>#=&72\B+"`D=F%L
M=64I"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`F)B!E;7!T>2@D<&%R
M86US6R=%3D-/1$E.1R==*2D@('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)'!A<F%M<ULG14Y#3T1)3D<G72`]("=154]4140M4%))3E1!0DQ%)SL*("`@
M("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<U]S='(@+CT@)SM%3D-/1$E.
M1SU154]4140M4%))3E1!0DQ%)SL*("`@("`@("`@("`@("`@("`@("`@("`@
M+R\@061D($-(05)3150@87,@=V5L;"X@070@;&5A<W0@=&AE('-Y;G1H97-I
M<R!C;&EE;G0*("`@("`@("`@("`@("`@("`@("`@("`@+R\@9V5T<R!C;VYF
M=7-E9"!O=&AE<G=I<V4*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&5M
M<'1Y*"1P87)A;7-;)T-(05)3150G72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1P87)A;7-;)T-!4E-%5"==(#T@3DQ3.CIG971#:&%R<V5T
M*"D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86US7W-T<B`N
M/2`G.T-(05)3150])R`N("1P87)A;7-;)T-!4E-%5"==.PH@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-?
M87)R87DH)&%T=')I8G5T95LG=F%L=65S)UTI"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`F)B!C;W5N="@D871T<FEB=71E6R=V86QU97,G72D^,2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=65S(#T@)&%T=')I8G5T
M95LG=F%L=65S)UT["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D;F%M
M92`]/2`G3B<@?'P@)&YA;64@/3T@)T%$4B<I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1G;'5E(#T@)SLG.PH@("`@("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&=L
M=64@/2`G+"<["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`@("`@)'9A;'5E<R`]('-T<E]R97!L86-E*&%R<F%Y*"<[
M)RP@)SHG+"`G+"<L("=-04E,5$]<7#HG*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)UQ<.R<L("=<7#HG
M+"`G7%PL)RP@)TU!24Q43SHG*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'9A;'5E<RD["B`@("`@("`@("`@("`@
M("`@("`@("`@("1V86QU92`](&EM<&QO9&4H)&=L=64L("1V86QU97,I.PH@
M("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@("`@("\O($%S(&]F(')F8R`R-#(V(#(N-"XR('-E;6EC;VQO;BP@8V]M
M;6$L(&%N9"!C;VQO;@H@("`@("`@("`@("`@("`@("`@("`@("`O+R!M=7-T
M(&)E(&5S8V%P960N($5X8VQU9&4@34%)3%1/.B!T:&]U9V@N(%1H:7,@:7,@
M80H@("`@("`@("`@("`@("`@("`@("`@("`O+R!H86-K(0H@("`@("`@("`@
M("`@("`@("`@("`@("`D=F%L=64@/2!S=')?<F5P;&%C92AA<G)A>2@G.R<L
M("<Z)RP@)RPG+"`G34%)3%1/7%PZ)RDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=<7#LG+"`G7%PZ)RP@
M)UQ<+"<L("=-04E,5$\Z)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1V86QU92D["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@A96UP='DH)'!A<F%M
M<ULG14Y#3T1)3D<G72D@)B8*("`@("`@("`@("`@("`@("1P87)A;7-;)T5.
M0T]$24Y')UT@/3T@)U%53U1%1"U04DE.5$%"3$4G("8F('-T<FQE;BAT<FEM
M*"1V86QU92DI(#X@,"D@>PH@("`@("`@("`@("`@("`@+RH@<75O=&5D4')I
M;G1A8FQE16YC;V1E(&1O97,@;F]T(&5S8V%P92!#4DQ&<RP@8G5T('-T<F%N
M9V4*("`@("`@("`@("`@("`@("`J(&5N;W5G:"!S:6YG;&4@3$9S+B!S;R!C
M;VYV97)T(&5V97)Y=&AI;F<@=&\@3$8@;VYL>2!A;F0*("`@("`@("`@("`@
M("`@("`J(')E<&QA8V4@869T97)W87)D<RX@*B\*("`@("`@("`@("`@("`@
M("1V86QU92`]('-T<E]R97!L86-E*")<<B(L("<G+"`D=F%L=64I.PH@("`@
M("`@("`@("`@("`@)')E<W5L="`N/2`B)&YA;64D<&%R86US7W-T<CH](B`N
M("1T:&ES+3Y?;F5W;&EN90H@("`@("`@("`@("`@("`@("`@("X@<W1R7W)E
M<&QA8V4H)STP02<L("<],$0],$$G+"`D=&AI<RT^7W%U;W1E9%!R:6YT86)L
M945N8V]D92@D=F%L=64I*0H@("`@("`@("`@("`@("`@("`@("X@)'1H:7,M
M/E]N97=L:6YE.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)&%T=')?<W1R:6YG(#T@(B1N86UE)'!A<F%M<U]S='(Z)'9A;'5E(CL*
M("`@("`@("`@("`@("`@("1R97-U;'0@+CT@)'1H:7,M/E]F;VQD3&EN92@D
M871T<E]S=')I;F<I("X@)'1H:7,M/E]N97=L:6YE.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V-O;7!O;F5N
M=',@87,@)&-O;7!O;F5N="D@>PH@("`@("`@("`@("`D<F5S=6QT("X]("1C
M;VUP;VYE;G0M/F5X<&]R='9#86QE;F1A<B@I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1R97-U;'0@+B`G14Y$.B<@+B`D8F%S92`N("1T:&ES+3Y?
M;F5W;&EN93L*("`@('T*"B`@("`O*BH*("`@("`J(%!A<G-E(&$@551#($]F
M9G-E="!F:65L9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7W!A<G-E571C3V9F
M<V5T*"1T97AT*0H@("`@>PH@("`@("`@("1O9F9S970@/2!A<G)A>2@I.PH@
M("`@("`@(&EF("AP<F5G7VUA=&-H*"<O*%PK?"TI*%LP+3E=>S)]*2A;,"TY
M77LR?2DH6S`M.5U[,GTI/R\G+"`D=&5X="P@)'1I;65087)T<RDI('L*("`@
M("`@("`@("`@)&]F9G-E=%LG86AE860G72`@/2`H8F]O;"DH)'1I;65087)T
M<ULQ72`]/2`G*R<I.PH@("`@("`@("`@("`D;V9F<V5T6R=H;W5R)UT@("`]
M(&EN='9A;"@D=&EM95!A<G1S6S)=*3L*("`@("`@("`@("`@)&]F9G-E=%LG
M;6EN=71E)UT@/2!I;G1V86PH)'1I;65087)T<ULS72D["B`@("`@("`@("`@
M(&EF("AI<W-E="@D=&EM95!A<G1S6S1=*2D@>PH@("`@("`@("`@("`@("`@
M)&]F9G-E=%LG<V5C;VYD)UT@/2!I;G1V86PH)'1I;65087)T<ULT72D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1O9F9S970["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($5X<&]R="!A(%540R!/9F9S970@
M9FEE;&0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]E>'!O<G15=&-/9F9S970H
M)'9A;'5E*0H@("`@>PH@("`@("`@("1O9F9S970@/2`D=F%L=65;)V%H96%D
M)UT@/R`G*R<@.B`G+2<["B`@("`@("`@)&]F9G-E="`N/2!S<')I;G1F*"<E
M,#)D)3`R9"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1V86QU95LG
M:&]U<B==+"`D=F%L=65;)VUI;G5T92==*3L*("`@("`@("!I9B`H:7-S970H
M)'9A;'5E6R=S96-O;F0G72DI('L*("`@("`@("`@("`@)&]F9G-E="`N/2!S
M<')I;G1F*"<E,#)D)RP@)'9A;'5E6R=S96-O;F0G72D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&]F9G-E=#L*("`@('T*"B`@("`O*BH*("`@("`J
M(%!A<G-E(&$@5&EM92!097)I;V0@9FEE;&0N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]P87)S95!E<FEO9"@D=&5X="D*("`@('L*("`@("`@("`D<&5R:6]D
M4&%R=',@/2!E>'!L;V1E*"<O)RP@)'1E>'0I.PH*("`@("`@("`D<W1A<G0@
M/2`D=&AI<RT^7W!A<G-E1&%T951I;64H)'!E<FEO9%!A<G1S6S!=*3L*"B`@
M("`@("`@:68@*"1D=7)A=&EO;B`]("1T:&ES+3Y?<&%R<V5$=7)A=&EO;B@D
M<&5R:6]D4&%R='-;,5TI*2!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@G
M<W1A<G0G(#T^("1S=&%R="P@)V1U<F%T:6]N)R`]/B`D9'5R871I;VXI.PH@
M("`@("`@('T@96QS96EF("@D96YD(#T@)'1H:7,M/E]P87)S941A=&54:6UE
M*"1P97)I;V1087)T<ULQ72DI('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y
M*"=S=&%R="<@/3X@)'-T87)T+"`G96YD)R`]/B`D96YD*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>'!O<G0@82!4:6UE(%!E<FEO9"!F
M:65L9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V5X<&]R=%!E<FEO9"@D=F%L
M=64I"B`@("!["B`@("`@("`@)'!E<FEO9"`]("1T:&ES+3Y?97AP;W)T1&%T
M951I;64H)'9A;'5E6R=S=&%R="==*3L*("`@("`@("`D<&5R:6]D("X]("<O
M)SL*("`@("`@("!I9B`H:7-S970H)'9A;'5E6R=D=7)A=&EO;B==*2D@>PH@
M("`@("`@("`@("`D<&5R:6]D("X]("1T:&ES+3Y?97AP;W)T1'5R871I;VXH
M)'9A;'5E6R=D=7)A=&EO;B==*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D<&5R:6]D("X]("1T:&ES+3Y?97AP;W)T1&%T951I;64H)'9A;'5E
M6R=E;F0G72D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<&5R:6]D.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4&%R<V5S(&$@1&%T951I;64@9FEE;&0@
M:6YT;R!A('5N:7@@=&EM97-T86UP+@H@("`@("H*("`@("`J($!T;V1O(%1H
M:7,@9G5N8W1I;VX@<VAO=6QD(&)E(&UO=F5D('1O($AO<F1E7T1A=&4@86YD
M(&UA9&4@<'5B;&EC+@H@("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC
M=&EO;B!?<&%R<V5$871E5&EM92@D=&5X="D*("`@('L*("`@("`@("`D9&%T
M95!A<G1S(#T@97AP;&]D92@G5"<L("1T97AT*3L*("`@("`@("!I9B`H8V]U
M;G0H)&1A=&5087)T<RD@(3T@,B`F)B`A96UP='DH)'1E>'0I*2!["B`@("`@
M("`@("`@("\O($YO="!A(&1A=&5T:6UE(&9I96QD(&)U="!M87D@8F4@:G5S
M="!A(&1A=&4@9FEE;&0N"B`@("`@("`@("`@(&EF("@A)&1A=&4@/2!(;W)D
M95]I0V%L96YD87(Z.E]P87)S941A=&4H)'1E>'0I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)&1A=&4["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M<F5T=7)N($!G;6UK=&EM92@P+"`P+"`P+"`D9&%T95LG;6]N=&@G72P@)&1A
M=&5;)VUD87DG72P@)&1A=&5;)WEE87(G72D["B`@("`@("`@?0H*("`@("`@
M("!I9B`H(21D871E(#T@2&]R9&5?:4-A;&5N9&%R.CI?<&%R<V5$871E*"1D
M871E4&%R='-;,%TI*2!["B`@("`@("`@("`@(')E='5R;B`D9&%T93L*("`@
M("`@("!]"B`@("`@("`@:68@*"$D=&EM92`]($AO<F1E7VE#86QE;F1A<CHZ
M7W!A<G-E5&EM92@D9&%T95!A<G1S6S%=*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'1I;64["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1I;65;)WIO;F4G
M72`]/2`G551#)RD@>PH@("`@("`@("`@("!R971U<FX@0&=M;6MT:6UE*"1T
M:6UE6R=H;W5R)UTL("1T:6UE6R=M:6YU=&4G72P@)'1I;65;)W-E8V]N9"==
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D871E6R=M;VYT:"==
M+"`D9&%T95LG;61A>2==+"`D9&%T95LG>65A<B==*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!R971U<FX@0&UK=&EM92@D=&EM95LG:&]U<B==
M+"`D=&EM95LG;6EN=71E)UTL("1T:6UE6R=S96-O;F0G72P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&1A=&5;)VUO;G1H)UTL("1D871E6R=M9&%Y
M)UTL("1D871E6R=Y96%R)UTI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($5X<&]R="!A($1A=&54:6UE(&9I96QD+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?97AP;W)T1&%T951I;64H)'9A;'5E*0H@("`@>PH@("`@("`@
M("1T96UP(#T@87)R87DH*3L*("`@("`@("!I9B`H(6ES7V]B:F5C="@D=F%L
M=64I("8F("%I<U]A<G)A>2@D=F%L=64I*2!["B`@("`@("`@("`@("1T>B`]
M(&1A=&4H)T\G+"`D=F%L=64I.PH@("`@("`@("`@("`D5%I/9F9S970@/2`H
M,S8P,"`J('-U8G-T<B@D='HL(#`L(#,I*2`K("@V,"`J('-U8G-T<BAD871E
M*"=/)RP@)'9A;'5E*2P@,RP@,BDI.PH@("`@("`@("`@("`D=F%L=64@+3T@
M)%1:3V9F<V5T.PH*("`@("`@("`@("`@)'1E;7!;)WIO;F4G72`@(#T@)U54
M0R<["B`@("`@("`@("`@("1T96UP6R=Y96%R)UT@("`](&1A=&4H)UDG+"`D
M=F%L=64I.PH@("`@("`@("`@("`D=&5M<%LG;6]N=&@G72`@/2!D871E*"=N
M)RP@)'9A;'5E*3L*("`@("`@("`@("`@)'1E;7!;)VUD87DG72`@(#T@9&%T
M92@G:B<L("1V86QU92D["B`@("`@("`@("`@("1T96UP6R=H;W5R)UT@("`]
M(&1A=&4H)T<G+"`D=F%L=64I.PH@("`@("`@("`@("`D=&5M<%LG;6EN=71E
M)UT@/2!D871E*"=I)RP@)'9A;'5E*3L*("`@("`@("`@("`@)'1E;7!;)W-E
M8V]N9"==(#T@9&%T92@G<R<L("1V86QU92D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&1A=&5/8B`](&YE=R!(;W)D95]$871E*"1V86QU92D[
M"B`@("`@("`@("`@(')E='5R;B!(;W)D95]I0V%L96YD87(Z.E]E>'!O<G1$
M871E5&EM92@D9&%T94]B+3YT:6UE<W1A;7`H*2D["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@2&]R9&5?:4-A;&5N9&%R.CI?97AP;W)T1&%T92@D=&5M
M<"D@+B`G5"<@+B!(;W)D95]I0V%L96YD87(Z.E]E>'!O<G14:6UE*"1T96UP
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%!A<G-E<R!A(%1I;64@9FEE;&0N
M"B`@("`@*@H@("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!?
M<&%R<V54:6UE*"1T97AT*0H@("`@>PH@("`@("`@(&EF("AP<F5G7VUA=&-H
M*"<O*%LP+3E=>S)]*2A;,"TY77LR?2DH6S`M.5U[,GTI*%HI/R\G+"`D=&5X
M="P@)'1I;65087)T<RDI('L*("`@("`@("`@("`@)'1I;65;)VAO=7(G72`]
M(&EN='9A;"@D=&EM95!A<G1S6S%=*3L*("`@("`@("`@("`@)'1I;65;)VUI
M;G5T92==(#T@:6YT=F%L*"1T:6UE4&%R='-;,ETI.PH@("`@("`@("`@("`D
M=&EM95LG<V5C;VYD)UT@/2!I;G1V86PH)'1I;65087)T<ULS72D["B`@("`@
M("`@("`@(&EF("AI<W-E="@D=&EM95!A<G1S6S1=*2D@>PH@("`@("`@("`@
M("`@("`@)'1I;65;)WIO;F4G72`]("=55$,G.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)'1I;65;)WIO;F4G72`]("=,;V-A;"<[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1T:6UE.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>'!O<G1S(&$@5&EM92!F:65L
M9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V5X<&]R=%1I;64H)'9A;'5E*0H@
M("`@>PH@("`@("`@("1T:6UE(#T@<W!R:6YT9B@G)3`R9"4P,F0E,#)D)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E6R=H;W5R)UTL("1V86QU
M95LG;6EN=71E)UTL("1V86QU95LG<V5C;VYD)UTI.PH@("`@("`@(&EF("@D
M=F%L=65;)WIO;F4G72`]/2`G551#)RD@>PH@("`@("`@("`@("`D=&EM92`N
M/2`G6B<["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&EM93L*("`@('T*
M"B`@("`O*BH*("`@("`J(%!A<G-E<R!A($1A=&4@9FEE;&0N"B`@("`@*@H@
M("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!?<&%R<V5$871E
M*"1T97AT*0H@("`@>PH@("`@("`@("1P87)T<R`](&5X<&QO9&4H)U0G+"`D
M=&5X="D["B`@("`@("`@:68@*&-O=6YT*"1P87)T<RD@/3T@,BD@>PH@("`@
M("`@("`@("`D=&5X="`]("1P87)T<ULP73L*("`@("`@("!]"@H@("`@("`@
M(&EF("@A<')E9U]M871C:"@G+UXH7&1[-'TI+3\H7&1[,GTI+3\H7&1[,GTI
M)"\G+"`D=&5X="P@)&UA=&-H*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@87)R87DH)WEE87(G(#T^
M("1M871C:%LQ72P*("`@("`@("`@("`@("`@("`@("`@)VUO;G1H)R`]/B`D
M;6%T8VA;,ETL"B`@("`@("`@("`@("`@("`@("`@("=M9&%Y)R`]/B`D;6%T
M8VA;,UTI.PH@("`@?0H*("`@("\J*@H@("`@("H@17AP;W)T(&$@1&%T92!F
M:65L9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V5X<&]R=$1A=&4H)'9A;'5E
M*0H@("`@>PH@("`@("`@(&EF("AI<U]O8FIE8W0H)'9A;'5E*2D@>PH@("`@
M("`@("`@("`D=F%L=64@/2!A<G)A>2@G>65A<B<@/3X@)'9A;'5E+3YY96%R
M+"`G;6]N=&@G(#T^("1V86QU92T^;6]N=&@L("=M9&%Y)R`]/B`D=F%L=64M
M/FUD87DI.PH@("`@("`@('T*("`@("`@("!R971U<FX@<W!R:6YT9B@G)3`T
M9"4P,F0E,#)D)RP@)'9A;'5E6R=Y96%R)UTL("1V86QU95LG;6]N=&@G72P@
M)'9A;'5E6R=M9&%Y)UTI.PH@("`@?0H*("`@("\J*@H@("`@("H@4&%R<V4@
M82!$=7)A=&EO;B!686QU92!F:65L9"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M7W!A<G-E1'5R871I;VXH)'1E>'0I"B`@("!["B`@("`@("`@:68@*'!R96=?
M;6%T8V@H)R\H6RM=/WQ;+5TI4"@H6S`M.5TK5RE\*%LP+3E=*T0I?"DH5"@H
M6S`M.5TK2"E\*%LP+3E=*TTI?"A;,"TY72M3*2DK*3\O)RP@=')I;2@D=&5X
M="DL("1D=7)V86QU92DI('L*("`@("`@("`@("`@+R\@5V5E:W,N"B`@("`@
M("`@("`@("1D=7)A=&EO;B`](#<@*B`X-C0P,"`J(&EN='9A;"@D9'5R=F%L
M=65;,UTI.PH*("`@("`@("`@("`@:68@*&-O=6YT*"1D=7)V86QU92D@/B`T
M*2!["B`@("`@("`@("`@("`@("`O+R!$87ES+@H@("`@("`@("`@("`@("`@
M)&1U<F%T:6]N("L](#@V-#`P("H@:6YT=F%L*"1D=7)V86QU95LT72D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*&-O=6YT*"1D=7)V86QU92D@
M/B`U*2!["B`@("`@("`@("`@("`@("`O+R!(;W5R<RX*("`@("`@("`@("`@
M("`@("1D=7)A=&EO;B`K/2`S-C`P("H@:6YT=F%L*"1D=7)V86QU95LW72D[
M"@H@("`@("`@("`@("`@("`@+R\@36EN<RX*("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D9'5R=F%L=65;.%TI*2!["B`@("`@("`@("`@("`@("`@("`@
M)&1U<F%T:6]N("L](#8P("H@:6YT=F%L*"1D=7)V86QU95LX72D["B`@("`@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@+R\@4V5C<RX*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D9'5R=F%L=65;.5TI*2!["B`@("`@("`@
M("`@("`@("`@("`@)&1U<F%T:6]N("L](&EN='9A;"@D9'5R=F%L=65;.5TI
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`O+R!3:6=N+@H@("`@("`@("`@("!I9B`H)&1U<G9A;'5E6S%=(#T]("(M
M(BD@>PH@("`@("`@("`@("`@("`@)&1U<F%T:6]N("H]("TQ.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("!R971U<FX@)&1U<F%T:6]N.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>'!O<G0@82!D=7)A=&EO;B!V86QU
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V5X<&]R=$1U<F%T:6]N*"1V86QU
M92D*("`@('L*("`@("`@("`D9'5R871I;VX@/2`G)SL*("`@("`@("!I9B`H
M)'9A;'5E(#P@,"D@>PH@("`@("`@("`@("`D=F%L=64@*CT@+3$["B`@("`@
M("`@("`@("1D=7)A=&EO;B`N/2`G+2<["B`@("`@("`@?0H@("`@("`@("1D
M=7)A=&EO;B`N/2`G4"<["@H@("`@("`@("1W965K<R`](&9L;V]R*"1V86QU
M92`O("@W("H@.#8T,#`I*3L*("`@("`@("`D=F%L=64@/2`D=F%L=64@)2`H
M-R`J(#@V-#`P*3L*("`@("`@("!I9B`H)'=E96MS*2!["B`@("`@("`@("`@
M("1D=7)A=&EO;B`N/2`D=V5E:W,@+B`G5R<["B`@("`@("`@?0H*("`@("`@
M("`D9&%Y<R`](&9L;V]R*"1V86QU92`O("@X-C0P,"DI.PH@("`@("`@("1V
M86QU92`]("1V86QU92`E("@X-C0P,"D["B`@("`@("`@:68@*"1D87ES*2![
M"B`@("`@("`@("`@("1D=7)A=&EO;B`N/2`D9&%Y<R`N("=$)SL*("`@("`@
M("!]"@H@("`@("`@(&EF("@D=F%L=64I('L*("`@("`@("`@("`@)&1U<F%T
M:6]N("X]("=4)SL*"B`@("`@("`@("`@("1H;W5R<R`](&9L;V]R*"1V86QU
M92`O(#,V,#`I.PH@("`@("`@("`@("`D=F%L=64@/2`D=F%L=64@)2`S-C`P
M.PH@("`@("`@("`@("!I9B`H)&AO=7)S*2!["B`@("`@("`@("`@("`@("`D
M9'5R871I;VX@+CT@)&AO=7)S("X@)T@G.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`D;6EN<R`](&9L;V]R*"1V86QU92`O(#8P*3L*("`@("`@("`@
M("`@)'9A;'5E(#T@)'9A;'5E("4@-C`["B`@("`@("`@("`@(&EF("@D;6EN
M<RD@>PH@("`@("`@("`@("`@("`@)&1U<F%T:6]N("X]("1M:6YS("X@)TTG
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)'9A;'5E*2!["B`@
M("`@("`@("`@("`@("`D9'5R871I;VX@+CT@)'9A;'5E("X@)U,G.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&1U<F%T:6]N
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!F;VQD960@=F5R
M<VEO;B!O9B!A(&QI;F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]F;VQD3&EN
M92@D;&EN92D*("`@('L*("`@("`@("`D;&EN92`]('!R96=?<F5P;&%C92@B
M+UQR7&Y\7&Y\7'(O(BP@)UQN)RP@)&QI;F4I.PH@("`@("`@(&EF("AS=')L
M96XH)&QI;F4I(#X@-S4I('L*("`@("`@("`@("`@)&9O;&1E9&QI;F4@/2`G
M)SL*("`@("`@("`@("`@=VAI;&4@*"%E;7!T>2@D;&EN92DI('L*("`@("`@
M("`@("`@("`@("1M87A,:6YE(#T@<W5B<W1R*"1L:6YE+"`P+"`W-2D["B`@
M("`@("`@("`@("`@("`D8W5T4&]I;G0@/2!M87@H-C`L(&UA>"AS=')R<&]S
M*"1M87A,:6YE+"`G.R<I+"!S=')R<&]S*"1M87A,:6YE+"`G.B<I*2`K(#$I
M.PH*("`@("`@("`@("`@("`@("1F;VQD961L:6YE("X]("AE;7!T>2@D9F]L
M9&5D;&EN92DI(#\*("`@("`@("`@("`@("`@("`@("!S=6)S='(H)&QI;F4L
M(#`L("1C=710;VEN="D@.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M;F5W;&EN92`N("<@)R`N('-U8G-T<B@D;&EN92P@,"P@)&-U=%!O:6YT*3L*
M"B`@("`@("`@("`@("`@("`D;&EN92`]("AS=')L96XH)&QI;F4I(#P]("1C
M=710;VEN="D@/R`G)R`Z('-U8G-T<B@D;&EN92P@)&-U=%!O:6YT*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)&9O;&1E9&QI;F4["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D;&EN93L*("`@('T*"B`@("`O*BH*
M("`@("`J($-O;G9E<G0@86X@.&)I="!S=')I;F<@=&\@82!Q=6]T960M<')I
M;G1A8FQE('-T<FEN9R!A8V-O<F1I;F<*("`@("`J('1O(%)&0S(P-#4L('-E
M8W1I;VX@-BXW+@H@("`@("H*("`@("`J(%5S97,@:6UA<%\X8FET(&EF(&%V
M86EL86)L92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I;G!U="`@
M5&AE('-T<FEN9R!T;R!B92!E;F-O9&5D+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@<75O=&5D+7!R:6YT86)L92!E;F-O9&5D('-T<FEN
M9RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W%U;W1E9%!R:6YT86)L945N8V]D
M92@D:6YP=70@/2`G)RD*("`@('L*("`@("`@("`O+R!)9B!I;6%P7SAB:70H
M*2!I<R!A=F%I;&%B;&4L('5S92!I="X*("`@("`@("!I9B`H9G5N8W1I;VY?
M97AI<W1S*"=I;6%P7SAB:70G*2D@>PH@("`@("`@("`@("!R971U<FX@:6UA
M<%\X8FET*"1I;G!U="D["B`@("`@("`@?0H*("`@("`@("`O+R!2871H97(@
M9'5M8B!R97!L86-M96YT.B!J=7-T(&5N8V]D92!E=F5R>71H:6YG+@H@("`@
M("`@("1H97@@/2!A<G)A>2@G,"<L("<Q)RP@)S(G+"`G,R<L("<T)RP@)S4G
M+"`G-B<L("<W)RP@)S@G+"`G.2<L"B`@("`@("`@("`@("`@("`@("`@("=!
M)RP@)T(G+"`G0R<L("=$)RP@)T4G+"`G1B<I.PH*("`@("`@("`D;W5T<'5T
M(#T@)R<["B`@("`@("`@)&QE;B`]('-T<FQE;B@D:6YP=70I.PH@("`@("`@
M(&9O<B`H)&D@/2`P.R`D:2`\("1L96X[("LK)&DI('L*("`@("`@("`@("`@
M)&,@/2!S=6)S='(H)&EN<'5T+"`D:2P@,2D["B`@("`@("`@("`@("1D96,@
M/2!O<F0H)&,I.PH@("`@("`@("`@("`D;W5T<'5T("X]("<])R`N("1H97A;
M9FQO;W(H)&1E8R`O(#$V*5T@+B`D:&5X6V9L;V]R*"1D96,@)2`Q-BE=.PH@
M("`@("`@("`@("!I9B`H*"1I("L@,2D@)2`R-2`]/2`P*2!["B`@("`@("`@
M("`@("`@("`D;W5T<'5T("X]("(]7')<;B(["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("1O=71P=70["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E;7!L871E
M+G!H<```````````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#4R
M-38W(#$P-3$U-#,S-S0P(#`R,38T-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@2&]R9&4@5&5M<&QA
M=&4@<WES=&5M+B!!9&%P=&5D(&9R;VT@8E1E;7!L871E(&)Y($)R:6%N($QO
M>FEE<@H@*B`\8G)I86Y`;6%S<V%S<VDN;F5T/BX*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP+'8@,2XS."XQ,"XQ,"`R
M,#`V+S`V+S$S(#`S.C4T.C`S(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P
M86-K86=E($AO<F1E7U1E;7!L871E"B`J+PIC;&%S<R!(;W)D95]496UP;&%T
M92!["@H@("`@+RHJ"B`@("`@*B!/<'1I;VX@=F%L=65S+@H@("`@("H*("`@
M("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?;W!T:6]N<R`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!$:7)E8W1O<GD@=&AA="!T96UP;&%T
M97,@<VAO=6QD(&)E(')E860@9G)O;2X*("`@("`J"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)%]B87-E<&%T:"`]("<G.PH*("`@("\J
M*@H@("`@("H@4F5S970@=&5M<&QA=&4@=F%R:6%B;&5S(&%F=&5R('!A<G-I
M;F<_"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A
M<B`D7W)E<V5T5F%R<R`]('1R=64["@H@("`@+RHJ"B`@("`@*B!486<@*'-C
M86QA<BD@=F%L=65S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1?<V-A;&%R<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@
M*B!,;V]P('1A9R!V86QU97,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]A<G)A>7,@/2!A<G)A>2@I.PH*("`@("\J*@H@
M("`@("H@0VQO;W`@=&%G('9A;'5E<RX*("`@("`J"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D7V-A<G)A>7,@/2!A<G)A>2@I.PH*("`@
M("\J*@H@("`@("H@268@=&%G('9A;'5E<RX*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7VEF<R`](&%R<F%Y*"D["@H@("`@
M+RHJ"B`@("`@*B!.86UE(&]F(&-A8VAE9"!T96UP;&%T92!F:6QE+@H@("`@
M("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W1E;7!L
M871E1FEL92`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!#86-H960@<V]U<F-E
M(&]F('1E;7!L871E(&9I;&4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J+PH@("`@=F%R("1?=&5M<&QA=&4@/2!N=6QL.PH*("`@("\J*@H@
M("`@("H@0V]N<W1R=6-T;W(N($-A;B!S970@=&AE('1E;7!L871E(&)A<V4@
M<&%T:"!A;F0@=VAE=&AE<B!O<B!N;W0*("`@("`J('1O(&1R;W`@=&5M<&QA
M=&4@=F%R:6%B;&5S(&%F=&5R(&$@<&%R<VEN9R!A('1E;7!L871E+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@("1B87-E<&%T:"`@(%1H92!D:7)E
M8W1O<GD@=VAE<F4@=&5M<&QA=&5S(&%R92!R96%D(&9R;VTN"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D<F5S971687)S("!$<F]P('1E;7!L871E('9A<G,@
M869T97(@<&%R<VEN9R!A('1E;7!L871E/PH@("`@("HO"B`@("!F=6YC=&EO
M;B!(;W)D95]496UP;&%T92@D8F%S97!A=&@@/2!N=6QL+"`D<F5S971687)S
M(#T@=')U92D*("`@('L*("`@("`@("!I9B`H(6ES7VYU;&PH)&)A<V5P871H
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V)A<V5P871H(#T@)&)A<V5P871H
M.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7W)E<V5T5F%R<R`]("AB;V]L
M*21R97-E=%9A<G,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S(&%N(&]P
M=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1O<'1I;VX@(%1H
M92!O<'1I;VX@;F%M92X*("`@("`J($!P87)A;2!M:7AE9"`@)'9A;"`@("`@
M5&AE(&]P=&EO;B=S('9A;'5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971/
M<'1I;VXH)&]P=&EO;BP@)'9A;"D*("`@('L*("`@("`@("`D=&AI<RT^7V]P
M=&EO;G-;)&]P=&EO;ET@/2`D=F%L.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4V5T('1H92!T96UP;&%T92!C;VYT96YT<R!T;R!A('-T<FEN9RX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1T96UP;&%T92`@5&AE('1E;7!L871E
M('1E>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%1E;7!L871E*"1T96UP
M;&%T92D*("`@('L*("`@("`@("`D=&AI<RT^7W1E;7!L871E(#T@)'1E;7!L
M871E.PH@("`@("`@("1T:&ES+3Y?=&5M<&QA=&5&:6QE(#T@)W-T<FEN9R<[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&]P=&EO;B=S('9A
M;'5E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&]P=&EO;B`@5&AE
M(&]P=&EO;B!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H
M92!O<'1I;VXG<R!V86QU92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3W!T
M:6]N*"1O<'1I;VXI"B`@("!["B`@("`@("`@<F5T=7)N(&ES<V5T*"1T:&ES
M+3Y?;W!T:6]N<ULD;W!T:6]N72D@/R`D=&AI<RT^7V]P=&EO;G-;)&]P=&EO
M;ET@.B!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!A('1A9RP@
M;&]O<"P@;W(@:68@=F%R:6%B;&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9WQA<G)A>2`D=&%G("`@16ET:&5R('1H92!T86<@;F%M92!O<B!A(&AA
M<V@@=VET:"!T86<@;F%M97,*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%S(&ME>7,@86YD('1A9R!V86QU97,@87,@=F%L=65S+@H@("`@
M("H@0'!A<F%M(&UI>&5D("`@("`@("`D=F%R("`@5&AE('9A;'5E('1O(')E
M<&QA8V4@=&AE('1A9R!W:71H+@H@("`@("H@0'!A<F%M(&)O;VQE86X@("`@
M("`D:7-)9B`@27,@=&AI<R!F;W(@86X@/&EF.CX@=&%G/R`H1&5F875L=#H@
M;F\I+@H@("`@("HO"B`@("!F=6YC=&EO;B!S970H)'1A9RP@)'9A<BP@)&ES
M268@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH)'1A9RDI
M('L*("`@("`@("`@("`@9F]R96%C:"`H)'1A9R!A<R`D=%1A9R`]/B`D=%9A
M<BD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E="@D=%1A9RP@)'1687(L
M("1I<TEF*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS96EF("AI<U]A
M<G)A>2@D=F%R*2!\?"!I<U]O8FIE8W0H)'9A<BDI('L*("`@("`@("`@("`@
M)'1H:7,M/E]A<G)A>7-;)'1A9UT@/2`D=F%R.PH@("`@("`@("`@("!I9B`H
M)&ES268I('L*("`@("`@("`@("`@("`@("\O($IU<W0@<W1O<F4@=&AE('-A
M;64@=F%R:6%B;&4@=&AA="!W92!S=&]R960@:6X*("`@("`@("`@("`@("`@
M("\O("1T:&ES+3Y?87)R87ES("T@:68@=V4@9&]N)W0@;6]D:69Y(&ET+"!0
M2%`G<PH@("`@("`@("`@("`@("`@+R\@<F5F97)E;F-E(&-O=6YT:6YG(&5N
M<W5R97,@=V4G<F4@;F]T('5S:6YG(&%N>0H@("`@("`@("`@("`@("`@+R\@
M861D:71I;VYA;"!M96UO<GD@:&5R92X*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?:69S6R1T86==(#T@)'9A<CL*("`@("`@("`@("`@?0H@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?<V-A;&%R<ULD=&%G72`]("1V
M87(["B`@("`@("`@("`@(&EF("@D:7-)9BD@>PH@("`@("`@("`@("`@("`@
M+R\@2G5S="!S=&]R92!T:&4@<V%M92!V87)I86)L92!T:&%T('=E('-T;W)E
M9"!I;@H@("`@("`@("`@("`@("`@+R\@)'1H:7,M/E]S8V%L87)S("T@:68@
M=V4@9&]N)W0@;6]D:69Y(&ET+"!02%`G<PH@("`@("`@("`@("`@("`@+R\@
M<F5F97)E;F-E(&-O=6YT:6YG(&5N<W5R97,@=V4G<F4@;F]T('5S:6YG(&%N
M>0H@("`@("`@("`@("`@("`@+R\@861D:71I;VYA;"!M96UO<GD@:&5R92X*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?:69S6R1T86==(#T@)'9A<CL*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE('9A;'5E(&]F(&$@=&%G(&]R(&QO;W`N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=&%G("!4:&4@=&%G(&YA;64N"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@5&AE('1A9R!V86QU92!O<B!N=6QL(&EF
M('1H92!T86<@:&%S;B=T(&)E96X@<V5T('EE="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T*"1T86<I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?87)R87ES6R1T86==*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]A<G)A>7-;)'1A9UT["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7W-C86QA<G-;)'1A9UTI*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7W-C86QA<G-;)'1A9UT["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!V86QU97,@9F]R
M(&$@8VQO;W`N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&%G("`@
M5&AE(&YA;64@;V8@=&AE(&-L;V]P+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A
M<G)A>2`@5&AE('9A;'5E<R!F;W(@=&AE(&-L;V]P+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1C87-E<R`@5&AE(&-A<V5S("AT97-T('9A;'5E<RD@9F]R('1H
M92!C;&]O<',N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$-L;V]P*"1T86<L
M("1A<G)A>2P@)&-A<V5S*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8V%R<F%Y
M<ULD=&%G72`](&%R<F%Y*`H@("`@("`@("`@("`G87)R87DG(#T^("1A<G)A
M>2P*("`@("`@("`@("`@)V-A<V5S)R`]/B`D8V%S97,*("`@("`@("`I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5S971S('1H92!T96UP;&%T92!V87)I
M86)L97,N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'-C86QA<G,@
M(%)E<V5T('-C86QA<B`H8F%S:6,@=&%G*2!V87)I86)L97,_"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D87)R87ES("`@4F5S970@;&]O<"!V87)I86)L97,_
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D8V%R<F%Y<R`@4F5S970@8VQO;W`@
M=F%R:6%B;&5S/PH@("`@("H@0'!A<F%M(&)O;VQE86X@)&EF<R`@("`@(%)E
M<V5T(&EF('9A<FEA8FQE<S\*("`@("`J+PH@("`@9G5N8W1I;VX@<F5S9716
M87)S*"1S8V%L87)S+"`D87)R87ES+"`D8V%R<F%Y<RP@)&EF<RD*("`@('L*
M("`@("`@("!I9B`H)'-C86QA<G,@/3T]('1R=64I('L*("`@("`@("`@("`@
M)'1H:7,M/E]S8V%L87)S(#T@87)R87DH*3L*("`@("`@("!]"B`@("`@("`@
M:68@*"1A<G)A>7,@/3T]('1R=64I('L*("`@("`@("`@("`@)'1H:7,M/E]A
M<G)A>7,@/2!A<G)A>2@I.PH@("`@("`@('T*("`@("`@("!I9B`H)&-A<G)A
M>7,@/3T]('1R=64I('L*("`@("`@("`@("`@)'1H:7,M/E]C87)R87ES(#T@
M87)R87DH*3L*("`@("`@("!]"B`@("`@("`@:68@*"1I9G,@/3T]('1R=64I
M('L*("`@("`@("`@("`@)'1H:7,M/E]I9G,@/2!A<G)A>2@I.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E(&QI<W0@;V8@8FQO
M8VMS('!R97-E;G0@:6X@=&AE('1E;7!L871E('-O=7)C92X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1F:6QE;F%M92`@5&AE(&9I;&4@=&\@9F5T
M8V@@=&AE('1E;7!L871E(&9R;VTN"B`@("`@*B!`<F5T=7)N(&UI>&5D("!!
M;B!A<G)A>2!O9B!A<'!L:6-A=&EO;G,L(&]R(%!%05)?17)R;W(@;VX@9F%I
M;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=$)L;V-K<R@I"B`@("![
M"B`@("`@("`@)&)L;V-K<R`](&%R<F%Y*"D["B`@("`@("`@:68@*'!R96=?
M;6%T8VA?86QL*"<\8FQO8VLZ*%MA+7I!+5HP+3E?72LZ6V$M>D$M6C`M.5]=
M*RD^)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T96UP
M;&%T92P@)&UA=&-H97,L(%!214=?4T547T]21$52*2D@>PH@("`@("`@("`@
M("!F;W)E86-H("@D;6%T8VAE<R!A<R`D;6%T8V@I('L*("`@("`@("`@("`@
M("`@("1B;&]C:W-;72`]("1M871C:%LQ73L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1B;&]C:W,["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!&971C:&5S(&$@=&5M<&QA=&4@9G)O;2!T:&4@<W!E8VEF:65D
M(&9I;&4@86YD(')E='5R;B!T:&4@<&%R<V5D"B`@("`@*B!C;VYT96YT<RX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QE;F%M92`@5&AE(&9I
M;&4@=&\@9F5T8V@@=&AE('1E;7!L871E(&9R;VTN"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!P87)S960@=&5M<&QA=&4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&9E=&-H*"1F:6QE;F%M92D*("`@('L*("`@("`@("`D
M8V]N=&5N=',@/2`D=&AI<RT^7V=E=%1E;7!L871E*"1F:6QE;F%M92D["B`@
M("`@("`@:68@*&ES7V$H)&-O;G1E;G1S+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D8V]N=&5N=',["B`@("`@("`@?0H*("`@("`@
M("`O+R!087)S92!A;F0@<F5T=7)N('1H92!C;VYT96YT<RX*("`@("`@("!R
M971U<FX@)'1H:7,M/G!A<G-E*"1C;VYT96YT<RD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!087)S97,@86QL('9A<FEA8FQE<R]T86=S(&EN('1H92!T96UP
M;&%T92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VYT96YT<R`@
M5&AE('5N<&%R<V5D('1E;7!L871E+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@<&%R<V5D('1E;7!L871E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!P87)S92@D8V]N=&5N=',@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF
M("@A)&-O;G1E;G1S*2!["B`@("`@("`@("`@("1C;VYT96YT<R`]("1T:&ES
M+3Y?=&5M<&QA=&4["B`@("`@("`@?0H*("`@("`@("`O+R!0<F]C97-S(&EF
M<RX*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?:69S*2D@>PH@("`@("`@
M("`@("!F;W)E86-H("@D=&AI<RT^7VEF<R!A<R`D=&%G(#T^("1V86QU92D@
M>PH@("`@("`@("`@("`@("`@)&-O;G1E;G1S(#T@)'1H:7,M/E]P87)S94EF
M*"1T86<L("1C;VYT96YT<RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("\O(%!R;V-E<W,@=&%G<RX*("`@("`@("`D<V5A<F-H(#T@87)R
M87DH*3L*("`@("`@("`D<F5P;&%C92`](&%R<F%Y*"D["B`@("`@("`@9F]R
M96%C:"`H)'1H:7,M/E]S8V%L87)S(&%S("1K97D@/3X@)'9A;'5E*2!["B`@
M("`@("`@("`@("1S96%R8VA;72`]("1T:&ES+3Y?9V5T5&%G*"1K97DI.PH@
M("`@("`@("`@("`D<F5P;&%C95M=(#T@)'9A;'5E.PH@("`@("`@('T*("`@
M("`@("!I9B`H8V]U;G0H)'-E87)C:"DI('L*("`@("`@("`@("`@)&-O;G1E
M;G1S(#T@<W1R7W)E<&QA8V4H)'-E87)C:"P@)')E<&QA8V4L("1C;VYT96YT
M<RD["B`@("`@("`@?0H*("`@("`@("`O+R!0<F]C97-S(&QO;W!S(&%N9"!A
M<G)A>7,N"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]A<G)A>7,@87,@)&ME
M>2`]/B`D87)R87DI('L*("`@("`@("`@("`@)&-O;G1E;G1S(#T@)'1H:7,M
M/E]P87)S94QO;W`H)&ME>2P@)&%R<F%Y+"`D8V]N=&5N=',I.PH@("`@("`@
M('T*"B`@("`@("`@+R\@4')O8V5S<R!C;&]O<',N"B`@("`@("`@9F]R96%C
M:"`H)'1H:7,M/E]C87)R87ES(&%S("1K97D@/3X@)&%R<F%Y*2!["B`@("`@
M("`@("`@("1C;VYT96YT<R`]("1T:&ES+3Y?<&%R<V5#;&]O<"@D:V5Y+"`D
M87)R87DL("1C;VYT96YT<RD["B`@("`@("`@?0H*("`@("`@("`O+R!087)S
M92!G971T97AT('1A9W,L(&EF('1H92!O<'1I;VX@:7,@96YA8FQE9"X*("`@
M("`@("!I9B`H)'1H:7,M/F=E=$]P=&EO;B@G9V5T=&5X="<I*2!["B`@("`@
M("`@("`@("1C;VYT96YT<R`]("1T:&ES+3Y?<&%R<V5'971T97AT*"1C;VYT
M96YT<RD["B`@("`@("`@?0H*("`@("`@("`O+R!087)S92!E;6)E9&1E9"!B
M;&]C:W,*("`@("`@("!I9B`H)'1H:7,M/F=E=$]P=&EO;B@G8FQO8VMS)RDI
M('L*("`@("`@("`@("`@)&-O;G1E;G1S(#T@)'1H:7,M/E]P87)S94)L;V-K
M<R@D8V]N=&5N=',I.PH@("`@("`@('T*"B`@("`@("`@+R\@4F5S970@=&5M
M<&QA=&4@9&%T82!U;FQE<W,@=V4G<F4@<W5P<&]S960@=&\@:V5E<"!I=`H@
M("`@("`@("\O(&%R;W5N9"X*("`@("`@("!I9B`H)'1H:7,M/E]R97-E=%9A
M<G,I('L*("`@("`@("`@("`@)'1H:7,M/G)E<V5T5F%R<RAF86QS92P@=')U
M92P@=')U92P@9F%L<V4I.PH@("`@("`@('T*"B`@("`@("`@+R\@4F5T=7)N
M('!A<G-E9"!T96UP;&%T92X*("`@("`@("!R971U<FX@)&-O;G1E;G1S.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!F=6QL('-T87)T(&%N9"!E
M;F0@=&%G<R!F;W(@82!N86UE9"!T86<N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&%G"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1D:7)E8W1I=F4@(%1H92!K:6YD(&]F('1A
M9R`M('1A9RP@:68L(&QO;W`L(&-L;V]P+@H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@("=B)R`]/B!3=&%R="!T86<N"B`@("`@*B`@("`@("`@("`@
M("`@("`G92<@/3X@16YD('1A9RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E
M=%1A9W,H)'1A9RP@)&1I<F5C=&EV92D*("`@('L*("`@("`@("!R971U<FX@
M87)R87DH)V(G(#T^("<\)R`N("1D:7)E8W1I=F4@+B`G.B<@+B`D=&%G("X@
M)SXG+`H@("`@("`@("`@("`@("`@("`@("`G92<@/3X@)SPO)R`N("1D:7)E
M8W1I=F4@+B`G.B<@+B`D=&%G("X@)SXG*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($9O<FUA=',@82!S8V%L87(@=&%G("AD969A=6QT(&9O<FUA="!I<R`\
M=&%G.FYA;64^*2X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T86<@(%1H92!N86UE(&]F('1H
M92!T86<N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!F=6QL
M('1A9R!W:71H('1H92!C=7)R96YT('-T87)T+V5N9"!D96QI;6ET97)S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?9V5T5&%G*"1T86<I"B`@("!["B`@("`@
M("`@<F5T=7)N("<\=&%G.B<@+B`D=&%G("X@)R`O/B<["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!%>'1R86-T<R!A('!O<G1I;VX@;V8@82!T96UP;&%T92X*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)'0@("`@("`@("`@(%1H92!T86<@=&\@97AT<F%C="X@
M2&%S:"!F;W)M870@:7,Z"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1;)V(G72`M(%1H92!S=&%R="!T86<*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=%LG92==("T@5&AE(&5N9"!T86<*("`@
M("`J($!P87)A;2!S=')I;F<@)B1C;VYT96YT<R`@5&AE('1E;7!L871E('1O
M(&5X=')A8W0@9G)O;2X*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=%-T871E
M;65N="@D="P@)B1C;VYT96YT<RD*("`@('L*("`@("`@("`O+R!,;V-A=&4@
M=&AE('-T871E;65N="X*("`@("`@("`D<&]S(#T@<W1R<&]S*"1C;VYT96YT
M<RP@)'1;)V(G72D["B`@("`@("`@:68@*"1P;W,@/3T](&9A;'-E*2!["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1T
M86=?;&5N9W1H(#T@<W1R;&5N*"1T6R=B)UTI.PH@("`@("`@("1F<&]S(#T@
M)'!O<R`K("1T86=?;&5N9W1H.PH@("`@("`@("1L<&]S(#T@<W1R<&]S*"1C
M;VYT96YT<RP@)'1;)V4G72D["B`@("`@("`@)&QE;F=T:"`]("1L<&]S("T@
M)&9P;W,["@H@("`@("`@("\O($5X=')A8W0@)B!R971U<FX@=&AE('-T871E
M;65N="X*("`@("`@("!R971U<FX@<W5B<W1R*"1C;VYT96YT<RP@)&9P;W,L
M("1L96YG=&@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4&%R<V5S(&=E='1E
M>'0@=&%G<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VYT96YT
M<R`@5&AE('5N<&%R<V5D(&-O;G1E;G0@;V8@=&AE(&9I;&4N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!P87)S960@8V]N=&5N=',@;V8@
M=&AE(&=E='1E>'0@8FQO8VMS+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<&%R
M<V5'971T97AT*"1C;VYT96YT<RD*("`@('L*("`@("`@("`O+R!'970@=&AE
M('1A9W,@)B!L;V]P+@H@("`@("`@("1T(#T@87)R87DH)V(G(#T^("<\9V5T
M=&5X=#XG+`H@("`@("`@("`@("`@("`@("`@)V4G(#T^("<\+V=E='1E>'0^
M)RD["B`@("`@("`@=VAI;&4@*"1T97AT(#T@)'1H:7,M/E]G9713=&%T96UE
M;G0H)'0L("1C;VYT96YT<RDI('L*("`@("`@("`@("`@)&-O;G1E;G1S(#T@
M<W1R7W)E<&QA8V4H)'1;)V(G72`N("1T97AT("X@)'1;)V4G72P@7R@D=&5X
M="DL("1C;VYT96YT<RD["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D8V]N
M=&5N=',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!087)S97,@8FQO8VL@=&%G
M<RX*("`@("`J"B`@("`@*B!(97)E('=E('!A<G-E(&)L;V-K('1A9W,@:6X@
M=&AE(&9O<FTZ"B`@("`@*@H@("`@("H@(#QB;&]C:SIA<'`Z;F%M93X*("`@
M("`J("`@/'!A<F%M.F9O;SYF;V\@<&%R86UE=&5R)W,@=F%L=64\+W!A<F%M
M.F9O;SX*("`@("`J("`@/'!A<F%M.F)A<CYB87(@<&%R86UE=&5R)W,@=F%L
M=64\+W!A<F%M.F)A<CX*("`@("`J("`@/'-E<FEA;#IB87H^<SHR,3HB8F%Z
M('!A<F%M971E<B=S('9A;'5E(CL\+W-E<FEA;#IB87H^"B`@("`@*B`@/"]B
M;&]C:SIA<'`Z;F%M93X*("`@("`J"B`@("`@*B`N+BX@86YD(')E<&QA8V4@
M=&AE;2!W:71H(')E;F1E<F5D(&%P<&QI8V%T:6]N(&)L;V-K<RX*("`@("`J
M"B`@("`@*B!";&]C:R!P87)A;65T97)S(&%R92!P<F]V:61E9"!W:71H('1H
M92!N97-T960@(G!A<F%M.F9O;R(@86YD"B`@("`@*B`B<V5R:6%L.F9O;R(@
M=&%G<RX@(%1H92!S97)I86PM<W1Y;&4@=&%G<R!T86ME(&$@<V5R:6%L:7IE
M9"!02%`*("`@("`J('9A;'5E+"!S;R!Y;W4@8V%N('5S92!I="!T;R!P<F]V
M:61E(&%R<F%Y+"!B;V]L96%N+"!A;F0@8V]M<&QE>`H@("`@("H@='EP92!P
M87)A;65T97)S+B`@5&AE('!A<F%M+7-T>6QE('1A9W,@<')O=FED92!S=')I
M;F<@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VYT96YT<R`@5&AE('5N
M<&%R<V5D(&-O;G1E;G1S(&]F('1H92!F:6QE+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@<&%R<V5D(&-O;G1E;G1S(&]F('1H92!F:6QE
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<&%R<V5";&]C:W,H)&-O;G1E;G1S
M*0H@("`@>PH@("`@("`@(')E='5R;B!P<F5G7W)E<&QA8V4H)R$\8FQO8VLZ
M*%MA+7I!+5I?,"TY72LI.BA;82UZ02U:7S`M.5TK*3XH+BH_*2<@+@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)SPO8FQO8VLZ*%MA+7I!+5I?,"TY
M72LI.BA;82UZ02U:7S`M.5TK*3XA<V4G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(EPD=&AI<RT^7W!A<G-E0FQO8VLH)UQ<,2<L("=<7#(G+"`G
M7%PS)RDB+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O;G1E;G1S
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($AA;F1L92!T:&4@8V]N=&5N=',@
M;V8@;VYE(&)L;V-K('1A9RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7W!A<G-E0FQO8VLH)&%P<"P@)&YA
M;64L("1C;VYT96YT<RD*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO
M<F1E+T)L;V-K+G!H<"<["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]"
M;&]C:R]#;VQL96-T:6]N+G!H<"<["@H@("`@("`@("\O(%5N9&\@<')E9U]R
M97!L86-E*"D@96YC;V1I;F<@<W1R86YG96YE<W,N"B`@("`@("`@)&-O;G1E
M;G1S(#T@<W1R7W)E<&QA8V4H)UQ<(B<L("<B)RP@)&-O;G1E;G1S*3L*"B`@
M("`@("`@+R\@1FEN9"!B;&]C:R=S('!A<F%M971E<G,N"B`@("`@("`@)'!A
M<F%M<R`](&%R<F%Y*"D["B`@("`@("`@:68@*'!R96=?;6%T8VA?86QL*"<A
M/'!A<F%M.BA;82UZ02U:7S`M.5TK*3XH+BH_*2<@+@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G/"]P87)A;3HH6V$M>D$M6E\P+3E=*RD^(7,G+"`D
M8V]N=&5N=',L("1M871C:&5S+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("!04D5'7U-%5%]/4D1%4BDI('L*("`@("`@("`@("`@9F]R96%C:"`H)&UA
M=&-H97,@87,@)&UA=&-H*2!["B`@("`@("`@("`@("`@("`D<&%R86US6R1M
M871C:%LQ75T@/2!H=&UL7V5N=&ET>5]D96-O9&4H)&UA=&-H6S)=*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H<')E9U]M871C:%]A
M;&PH)R$\<V5R:6%L.BA;82UZ02U:7S`M.5TK*3XH+BH_*2<@+@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G/"]S97)I86PZ*%MA+7I!+5I?,"TY72LI
M/B%S)RP@)&-O;G1E;G1S+"`D;6%T8VAE<RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@4%)%1U]3151?3U)$15(I*2!["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1M871C:&5S(&%S("1M871C:"D@>PH@("`@("`@("`@("`@("`@)'!A
M<F%M<ULD;6%T8VA;,5U=(#T@=6YS97)I86QI>F4H:'1M;%]E;G1I='E?9&5C
M;V1E*"1M871C:%LR72DI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("`O+R!#;VYS=')U8W0@=&AE(&)L;V-K+@H@("`@("`@("1B;&]C:R`]
M("9(;W)D95]";&]C:U]#;VQL96-T:6]N.CIG971";&]C:R@D87!P+"`D;F%M
M92P@)'!A<F%M<RD["B`@("`@("`@:68@*&ES7V$H)&)L;V-K+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("1R97-U;'0@/2`G/'-T<F]N9SXG("X@
M<W!R:6YT9BA?*")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,B*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8FQO8VLM/F=E=$UE
M<W-A9V4H*2D@+B`G/"]S=')O;F<^)SL*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D<F5S=6QT(#T@)&)L;V-K+3YG971#;VYT96YT*"D["B`@("`@
M("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@("1R97-U;'0@/2`G/'-T<F]N9SXG("X@<W!R:6YT9BA?
M*")%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(BDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R97-U;'0M/F=E=$UE<W-A
M9V4H*2D@+B`G/"]S=')O;F<^)SL*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!087)S97,@82!G:79E;B!I9B!S=&%T96UE;G0N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=&%G("`@("`@(%1H92!N86UE(&]F('1H92!I9B!B;&]C:R!T;R!P87)S92X*
M("`@("`J($!P87)A;2!S=')I;F<@)&-O;G1E;G1S("!4:&4@=6YP87)S960@
M8V]N=&5N=',@;V8@=&AE(&EF(&)L;V-K+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@<&%R<V5D(&-O;G1E;G1S(&]F('1H92!I9B!B;&]C
M:RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W!A<G-E268H)'1A9RP@)&-O;G1E
M;G1S+"`D:V5Y(#T@;G5L;"D*("`@('L*("`@("`@("`O+R!'970@=&AE('1A
M9W,@)B!I9B!S=&%T96UE;G0N"B`@("`@("`@)'0@/2`D=&AI<RT^7V=E=%1A
M9W,H)'1A9RP@)VEF)RD["B`@("`@("`@)&5T(#T@)'1H:7,M/E]G971486=S
M*"1T86<L("=E;'-E)RD["@H@("`@("`@("\O(&5X<&QO9&4@=&AE('1A9RP@
M<V\@=V4@:&%V92!T:&4@8V]R<F5C="!K97ES(&9O<B!T:&4@87)R87D*("`@
M("`@("!I9B`H:7-S970H)&ME>2DI('L*("`@("`@("`@("`@;&ES="@D=&<L
M("1K*2`](&5X<&QO9&4H)RXG+"`D=&%G*3L*("`@("`@("!]"B`@("`@("`@
M=VAI;&4@*"@D:68@/2`D=&AI<RT^7V=E=%-T871E;65N="@D="P@)&-O;G1E
M;G1S*2D@(3T](&9A;'-E*2!["B`@("`@("`@("`@("\O($-H96-K(&9O<B!E
M;'-E('-T871E;65N="X*("`@("`@("`@("`@:68@*"1E;'-E(#T@)'1H:7,M
M/E]G9713=&%T96UE;G0H)&5T+"`D:68I*2!["B`@("`@("`@("`@("`@("`O
M+R!0<F]C97-S('1H92!I9B!S=&%T96UE;G0N"B`@("`@("`@("`@("`@("!I
M9B`H*&ES<V5T*"1K97DI("8F("1T:&ES+3Y?:69S6R1T9UU;)&ME>5U;)&M=
M*2!\?`H@("`@("`@("`@("`@("`@("`@("AI<W-E="@D=&AI<RT^7VEF<ULD
M=&%G72D@)B8@)'1H:7,M/E]I9G-;)'1A9UTI*2!["B`@("`@("`@("`@("`@
M("`@("`@)')E<&QA8V4@/2!S=')?<F5P;&%C92@D971;)V(G72`N("1E;'-E
M("X@)&5T6R=E)UTL("<G+"`D:68I.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`D<F5P;&%C92`]("1E;'-E.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@+R\@4')O8V5S<R!T:&4@:68@<W1A=&5M96YT+@H@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1K97DI*2!["B`@("`@("`@("`@("`@("`@("`@
M)')E<&QA8V4@/2`D=&AI<RT^7VEF<ULD=&==6R1K97E=6R1K72`_("1I9B`Z
M(&YU;&P["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("1R97!L86-E(#T@)'1H:7,M/E]I9G-;)'1A9UT@/R`D:68@.B!N
M=6QL.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`O+R!087)S92!T:&4@=&5M<&QA=&4N"B`@("`@("`@("`@("1C;VYT
M96YT<R`]('-T<E]R97!L86-E*"1T6R=B)UT@+B`D:68@+B`D=%LG92==+"`D
M<F5P;&%C92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&-O;G1E;G1S*3L*("`@("`@("!]"@H@("`@("`@("\O(%)E='5R;B!P87)S
M960@=&5M<&QA=&4N"B`@("`@("`@<F5T=7)N("1C;VYT96YT<SL*("`@('T*
M"B`@("`O*BH*("`@("`J(%!A<G-E<R!T:&4@9VEV96X@87)R87D@9F]R(&%N
M>2!L;V]P<R!O<B!O=&AE<B!U<V5S(&]F('1H92!A<G)A>2X*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1T86<@("`@("`@5&AE(&YA;64@;V8@=&AE(&QO;W`@=&\@<&%R<V4N
M"B`@("`@*B!`<&%R86T@87)R87D@("1A<G)A>2`@("`@5&AE('9A;'5E<R!F
M;W(@=&AE(&QO;W`N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VYT96YT<R`@
M5&AE('5N<&%R<V5D(&-O;G1E;G1S(&]F('1H92!L;V]P+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@<&%R<V5D(&-O;G1E;G1S(&]F('1H
M92!L;V]P+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<&%R<V5,;V]P*"1T86<L
M("1A<G)A>2P@)&-O;G1E;G1S*0H@("`@>PH@("`@("`@("\O($=E="!T:&4@
M=&%G<R`F(&QO;W`N"B`@("`@("`@)'0@/2`D=&AI<RT^7V=E=%1A9W,H)'1A
M9RP@)VQO;W`G*3L*("`@("`@("`D;&]O<"`]("1T:&ES+3Y?9V5T4W1A=&5M
M96YT*"1T+"`D8V]N=&5N=',I.PH*("`@("`@("`O+R!3964@:68@=V4@:&%V
M92!A(&1I=FED97(N"B`@("`@("`@)&P@/2`D=&AI<RT^7V=E=%1A9W,H)'1A
M9RP@)V1I=FED97(G*3L*("`@("`@("`D9&EV:61E<B`]("1T:&ES+3Y?9V5T
M4W1A=&5M96YT*"1L+"`D;&]O<"D["B`@("`@("`@)&-O;G1E;G1S(#T@<W1R
M7W)E<&QA8V4H)&Q;)V(G72`N("1D:79I9&5R("X@)&Q;)V4G72P@)R<L("1C
M;VYT96YT<RD["@H@("`@("`@("\O(%!R;V-E<W,@=&AE(&%R<F%Y+@H@("`@
M("`@(&1O('L*("`@("`@("`@("`@)'!A<G-E9"`]("<G.PH@("`@("`@("`@
M("`D9FER<W0@/2!T<G5E.PH@("`@("`@("`@("!F;W)E86-H("@D87)R87D@
M87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@("`@(&EF("AI<U]A
M<G)A>2@D=F%L=64I('Q\(&ES7V]B:F5C="@D=F%L=64I*2!["B`@("`@("`@
M("`@("`@("`@("`@)&D@/2`D;&]O<#L*("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-?;G5M97)I8R@D:V5Y*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("!F;W)E86-H("@D=F%L=64@87,@)&ME>3(@/3X@)'9A;'5E,BD@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D=F%L=64R
M*2`F)B`A:7-?;V)J96-T*"1V86QU93(I*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@4F5P;&%C92!A<W-O8VEA=&EV92!A<G)A>2!T
M86=S+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1A85]T86<@
M/2`D=&%G("X@)RXG("X@)&ME>3(["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&D@/2!S=')?<F5P;&%C92@D=&AI<RT^7V=E=%1A9R@D86%?
M=&%G*2P@)'9A;'5E,BP@)&DI.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1P;W,@/2!S=')P;W,H)'1A9RP@)RXG*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H*"1P;W,@(3T](&9A;'-E*2`F)@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`A96UP='DH)'1H
M:7,M/E]I9G-;<W5B<W1R*"1T86<L(#`L("1P;W,I72DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I9G-;)&%A7W1A
M9UT@/2`D=F%L=64R.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D:2`]("1T:&ES+3Y?<&%R<V5)9B@D86%?=&%G+"`D:2D["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?
M:69S6R1A85]T86==*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O($-H96-K('1O('-E92!I
M9B!I="=S(&$@;F5S=&5D(&QO;W`N"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&D@/2`D=&AI<RT^7W!A<G-E3&]O<"@D=&%G("X@)RXG("X@
M)&ME>3(L("1V86QU93(L("1I*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D:2`]('-T<E]R97!L86-E
M*"1T:&ES+3Y?9V5T5&%G*"1T86<I+"`D:V5Y+"`D:2D["B`@("`@("`@("`@
M("`@("!](&5L<V5I9B`H:7-?<W1R:6YG*"1K97DI("8F("%I<U]A<G)A>2@D
M=F%L=64I("8F("%I<U]O8FIE8W0H)'9A;'5E*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1C;VYT96YT<R`]('-T<E]R97!L86-E*"1T:&ES+3Y?9V5T5&%G
M*"1T86<@+B`G+B<@+B`D:V5Y*2P@)'9A;'5E+"`D8V]N=&5N=',I.PH@("`@
M("`@("`@("`@("`@?2!E;'-E:68@*"%I<U]A<G)A>2@D=F%L=64I("8F("%I
M<U]O8FIE8W0H)'9A;'5E*2D@>PH@("`@("`@("`@("`@("`@("`@("1I(#T@
M<W1R7W)E<&QA8V4H)'1H:7,M/E]G971486<H)'1A9R`N("<G*2P@)'9A;'5E
M+"`D;&]O<"D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1I(#T@;G5L;#L*("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("`@("`O+R!087)S92!C;VYD:71I;VYS(&EN('1H92!A<G)A>2X*
M("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]I9G-;)'1A9UU;
M)&ME>5TI("8F(&ES7V%R<F%Y*"1T:&ES+3Y?:69S6R1T86==6R1K97E=*2`F
M)B`D=&AI<RT^7VEF<ULD=&%G75LD:V5Y72D@>PH@("`@("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1T:&ES+3Y?:69S6R1T86==6R1K97E=(&%S("1C5&%G
M(#T^("1C5F%L=64I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&D@/2`D
M=&AI<RT^7W!A<G-E268H)'1A9R`N("<N)R`N("1C5&%G+"`D:2P@)&ME>2D[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@("`@("\O($%D9"!T:&4@<&%R<V5D(&ET97)A=&EO;BX*("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D:2DI('L*("`@("`@("`@("`@("`@
M("`@("`O+R!)9B!I="=S(&YO="!T:&4@9FER<W0@=&EM92!T:')O=6=H+"!P
M<F5F:7@@=&AE"B`@("`@("`@("`@("`@("`@("`@+R\@;&]O<"!D:79I9&5R
M+"!I9B!T:&5R92!I<R!O;F4N"B`@("`@("`@("`@("`@("`@("`@:68@*"$D
M9FER<W0I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&D@/2`D9&EV:61E
M<B`N("1I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`D<&%R<V5D("X](')T<FEM*"1I*3L*("`@("`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("`@("`O+R!.;R!L;VYG97(@=&AE(&9I<G-T('1I;64@
M=&AR;W5G:"X*("`@("`@("`@("`@("`@("1F:7)S="`](&9A;'-E.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`O+R!297!L86-E('1H92!P87)S960@
M<&EE8V5S(&]F('1H92!T96UP;&%T92X*("`@("`@("`@("`@)&-O;G1E;G1S
M(#T@<W1R7W)E<&QA8V4H)'1;)V(G72`N("1L;V]P("X@)'1;)V4G72P@)'!A
M<G-E9"P@)&-O;G1E;G1S*3L*("`@("`@("!]('=H:6QE("@D;&]O<"`]("1T
M:&ES+3Y?9V5T4W1A=&5M96YT*"1T+"`D8V]N=&5N=',I*3L*"B`@("`@("`@
M<F5T=7)N("1C;VYT96YT<SL*("`@('T*"B`@("`O*BH*("`@("`J(%!A<G-E
M<R!T:&4@9VEV96X@8V%S92!L;V]P("AC;&]O<"DN"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=&%G("`@("`@(%1H92!N86UE(&]F('1H92!C;&]O<"!T;R!P87)S92X*("`@
M("`J($!P87)A;2!A<G)A>2`@)&%R<F%Y("`@("!4:&4@=F%L=65S(&9O<B!T
M:&4@8VQO;W`N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VYT96YT<R`@5&AE
M('5N<&%R<V5D(&-O;G1E;G1S(&]F('1H92!C;&]O<"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE('!A<G-E9"!C;VYT96YT<R!O9B!T:&4@
M8VQO;W`N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P87)S94-L;V]P*"1T86<L
M("1A<G)A>2P@)&-O;G1E;G1S*0H@("`@>PH@("`@("`@("\O($=E="!T:&4@
M=&%G<R`F(&-L;V]P+@H@("`@("`@("1T(#T@)'1H:7,M/E]G971486=S*"1T
M86<L("=C;&]O<"<I.PH*("`@("`@("!W:&EL92`H)&QO;W`@/2`D=&AI<RT^
M7V=E=%-T871E;65N="@D="P@)&-O;G1E;G1S*2D@>PH@("`@("`@("`@("`O
M+R!3970@=7`@=&AE(&-A<V5S+@H@("`@("`@("`@("`D87)R87E;)V-A<V5S
M)UU;72`]("=D969A=6QT)SL*("`@("`@("`@("`@)&-A<V5?8V]N=&5N="`]
M(&%R<F%Y*"D["@H@("`@("`@("`@("`O+R!'970@=&AE(&-A<V4@<W1R:6YG
M<RX*("`@("`@("`@("`@9F]R96%C:"`H)&%R<F%Y6R=C87-E<R==(&%S("1C
M87-E*2!["B`@("`@("`@("`@("`@("`D8W1A9W-;)&-A<V5=(#T@)'1H:7,M
M/E]G971486=S*"1C87-E+"`G8V%S92<I.PH@("`@("`@("`@("`@("`@)&-A
M<V5?8V]N=&5N=%LD8V%S95T@/2`D=&AI<RT^7V=E=%-T871E;65N="@D8W1A
M9W-;)&-A<V5=+"`D;&]O<"D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("\O(%!R;V-E<W,@=&AE(&-L;V]P+@H@("`@("`@("`@("`D<&%R<V5D(#T@
M)R<["B`@("`@("`@("`@(&9O<F5A8V@@*"1A<G)A>5LG87)R87DG72!A<R`D
M:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("`@("`@:68@*&ES7VYU;65R
M:6,H)&ME>2D@)B8@*&ES7V%R<F%Y*"1V86QU92D@?'P@:7-?;V)J96-T*"1V
M86QU92DI*2!["B`@("`@("`@("`@("`@("`@("`@+R\@4V5T('5P('1H92!C
M87-E<RX*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'9A;'5E6R=C
M87-E)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1C=7)R96YT7V-A
M<V4@/2`D=F%L=65;)V-A<V4G73L*("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=%]C87-E(#T@
M)V1E9F%U;'0G.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("!U;G-E="@D=F%L=65;)V-A<V4G72D["B`@("`@("`@("`@("`@
M("`@("`@)&D@/2`D8V%S95]C;VYT96YT6R1C=7)R96YT7V-A<V5=.PH*("`@
M("`@("`@("`@("`@("`@("`O+R!,;V]P('1H<F]U9V@@96%C:"!V86QU92X*
M("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D=F%L=64@87,@)&ME>3(@
M/3X@)'9A;'5E,BD@>PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-?
M87)R87DH)'9A;'5E,BD@?'P@:7-?;V)J96-T*"1V86QU93(I*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D:2`]("1T:&ES+3Y?<&%R<V5,;V]P
M*"1T86<@+B`G+B<@+B`D:V5Y,BP@)'9A;'5E,BP@)&DI.PH@("`@("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&D@/2!S=')?<F5P;&%C92@D=&AI<RT^7V=E=%1A9R@D=&%G("X@
M)RXG("X@)&ME>3(I+"`D=F%L=64R+"`D:2D["B`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`@("`@+R\@061D('1H92!P87)S960@:71E<F%T
M:6]N+@H@("`@("`@("`@("`@("`@)'!A<G-E9"`N/2!R=')I;2@D:2D["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("\O(%!A<G-E('1H92!C;&]O<"X*
M("`@("`@("`@("`@)&-O;G1E;G1S(#T@<W1R7W)E<&QA8V4H)'1;)V(G72`N
M("1L;V]P("X@)'1;)V4G72P@)'!A<G-E9"P@)&-O;G1E;G1S*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D8V]N=&5N=',["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!&971C:"!T:&4@8V]N=&5N=',@;V8@82!T96UP;&%T92!I;G1O
M("1T:&ES+3Y?=&5M<&QA=&4[(&-A8VAE"B`@("`@*B!T:&4@9FEL96YA;64@
M:6X@)'1H:7,M/E]T96UP;&%T949I;&4N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL96YA
M;64@($QO8V%T:6]N(&]F('1E;7!L871E(&9I;&4@;VX@9&ES:RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&QO861E9"!T96UP;&%T92!C
M;VYT96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T5&5M<&QA=&4H)&9I
M;&5N86UE(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES7VYU;&PH)&9I
M;&5N86UE*2`F)B`H)&9I;&5N86UE("$]("1T:&ES+3Y?=&5M<&QA=&5&:6QE
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W1E;7!L871E(#T@;G5L;#L*("`@
M("`@("!]"@H@("`@("`@(&EF("@A:7-?;G5L;"@D=&AI<RT^7W1E;7!L871E
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]T96UP;&%T93L*("`@
M("`@("!]"@H@("`@("`@("\O($=E="!T:&4@8V]N=&5N=',@;V8@=&AE(&9I
M;&4N"B`@("`@("`@)&9I;&4@/2`D=&AI<RT^7V)A<V5P871H("X@)&9I;&5N
M86UE.PH@("`@("`@("1C;VYT96YT<R`]($!F:6QE7V=E=%]C;VYT96YT<R@D
M9FEL92D["B`@("`@("`@:68@*"1C;VYT96YT<R`]/3T@9F%L<V4I('L*("`@
M("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+G!H<"<["B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B5&5M<&QA=&4@
M7"(E<UPB(&YO="!F;W5N9"XB*2P@)&9I;&4I*3L*("`@("`@("!]"@H@("`@
M("`@("1T:&ES+3Y?=&5M<&QA=&4@/2`D8V]N=&5N=',["B`@("`@("`@)'1H
M:7,M/E]T96UP;&%T949I;&4@/2`D9FEL96YA;64["@H@("`@("`@(')E='5R
M;B`D=&AI<RT^7W1E;7!L871E.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92]'<F%P:"YP:'``````````````````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`S-#,Q,"`Q,#4Q-30S,S<T,"`P
M,C$Q,3<`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J(%1H92!(;W)D92!G<F%P:&EN9R!S=6ET92X*("H*
M("H@4')O=FED97,@82!S970@;V8@9W)A<&@@8F%C:V5N9',@86YD(&UE=&AO
M9',@9F]R(&-R96%T:6YG(&=R87!H<R!A<PH@*B!(5$U,('1A8FQE<RP@4U9'
M(&EM86=E<RP@971C+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]'<F%P:"]'
M<F%P:"YP:'`L=B`Q+C(W+C$P+C<@,C`P-B\P,2\P,2`R,3HR.#HQ."!J86X@
M17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U
M8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN
M8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?1W)A<&@*("HO"F-L
M87-S($AO<F1E7T=R87!H('L*"B`@("`O*BH*("`@("`J(%1H92!(;W)D95])
M;6%G92!I;G-T86YC92!T:&%T('=E(&%R92!D<F%W:6YG('1H92!G<F%P:"!T
M;RX*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@("H@0'9A
M<B!(;W)D95]);6%G90H@("`@("HO"B`@("!V87(@)&EM9SL*"B`@("!V87(@
M)%]G<F%P:',@/2!A<G)A>2@I.PH*("`@('9A<B`D7VAE:6=H=#L*("`@('9A
M<B`D7W=I9'1H.PH*("`@('9A<B`D7W1I=&QE(#T@)R<["@H@("`@=F%R("1?
M8F%C:V=R;W5N9"`]("=L:6=H=&=R87DG.PH@("`@=F%R("1?=&ET;&5&;VYT
M(#T@)W-A;G,M<V5R:68G.PH@("`@=F%R("1?;&%B96Q&;VYT(#T@)W-A;G,M
M<V5R:68G.PH@("`@=F%R("1?87AI<T9O;G0@/2`G;6]N;W-P86-E)SL*"B`@
M("!V87(@)%]P861D:6YG3&5F="`](#8P.PH@("`@=F%R("1?<&%D9&EN9T)O
M='1O;2`](#0P.PH@("`@=F%R("1?<&%D9&EN9U1O<"`](#,P.PH@("`@=F%R
M("1?<&%D9&EN9U)I9VAT(#T@,C`["@H@("`@=F%R("1?;V9F<V5T1W)I9%@@
M/2`P.PH*("`@('9A<B`D7VEM9U1Y<&4@/2`G9V0G.PH*("`@('9A<B`D7V1A
M=&$@/2!A<G)A>2@G>"<@/3X@87)R87DH*2P*("`@("`@("`@("`@("`@("`@
M("`@("`G>2<@/3X@87)R87DH*2D["@H@("`@=F%R("1?=&UP9&ER.PH*("`@
M('9A<B`D7W!L;W1S(#T@87)R87DH*3L*("`@('9A<B`D7V-H87)T<R`](&%R
M<F%Y*"D["@H@("`@9G5N8W1I;VX@2&]R9&5?1W)A<&@H)'!A<F%M<RD*("`@
M('L*("`@("`@("!I9B`H(65M<'1Y*"1P87)A;7-;)W1E;7`G72DI('L*("`@
M("`@("`@("`@)'1H:7,M/E]T;7!D:7(@/2`D<&%R86US6R=T96UP)UT["B`@
M("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1P87)A;7-;)W=I9'1H)UTI
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?=VED=&@@/2`D<&%R86US6R=W:61T
M:"==.PH@("`@("`@("`@("`D=&AI<RT^7VAE:6=H="`]("1P87)A;7-;)VAE
M:6=H="==.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D<&%R86US
M6R=I;6=4>7!E)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?:6UG5'EP92`]
M("1P87)A;7-;)VEM9U1Y<&4G73L*("`@("`@("!]"B`@("!]"@H@("`@9G5N
M8W1I;VX@)F%D9%!L;W0H)'!L;W14>7!E+"`D<&QO=%!A<F%M<RD*("`@('L*
M("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/E]C:&%R=',I*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=-:7AI;F<@;V8@0VAA<G1S
M(&%N9"!0;&]T<R!I<R!N;W0@86QL;W=E9"XG*3L*("`@("`@("!]"@H@("`@
M("`@("1P;&]T5'EP92`](&)A<V5N86UE*"1P;&]T5'EP92D["B`@("`@("`@
M0&EN8VQU9&5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O1W)A<&@O4&QO
M="\G("X@)'!L;W14>7!E("X@)RYP:'`G.PH*("`@("`@("`D8VQA<W,@/2`G
M2&]R9&5?1W)A<&A?4&QO=%\G("X@)'!L;W14>7!E.PH@("`@("`@(&EF("AC
M;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D<&QO="`]("9N
M97<@)&-L87-S*"1T:&ES+"`D<&QO=%!A<F%M<RD["B`@("`@("`@("`@("1T
M:&ES+3Y?<&QO='-;72`]("8D<&QO=#L*("`@("`@("`@("`@<F5T=7)N("1P
M;&]T.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*"=0;&]T('1Y<&4@;F]T(&9O=6YD)RD["B`@("`@("`@
M?0H@("`@?0H*("`@(&9U;F-T:6]N("9A9&1#:&%R="@D8VAA<G14>7!E+"`D
M8VAA<G1087)A;7,I"B`@("!["B`@("`@("`@:68@*&-O=6YT*"1T:&ES+3Y?
M<&QO=',I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"=-:7AI;F<@;V8@0VAA<G1S(&%N9"!0;&]T<R!I<R!N;W0@86QL;W=E9"XG
M*3L*("`@("`@("!]"@H@("`@("`@("1C:&%R=%1Y<&4@/2!B87-E;F%M92@D
M8VAA<G14>7!E*3L*("`@("`@("!`:6YC;'5D95]O;F-E(&1I<FYA;64H7U]&
M24Q%7U\I("X@)R]'<F%P:"]#:&%R="\G("X@)&-H87)T5'EP92`N("<N<&AP
M)SL*"B`@("`@("`@)&-L87-S(#T@)TAO<F1E7T=R87!H7T-H87)T7R<@+B`D
M8VAA<G14>7!E.PH@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@
M>PH@("`@("`@("`@("`D8VAA<G0@/2`F;F5W("1C;&%S<R@D=&AI<RP@)&-H
M87)T4&%R86US*3L*("`@("`@("`@("`@)'1H:7,M/E]C:&%R='-;72`]("8D
M8VAA<G0["B`@("`@("`@("`@(')E='5R;B`D8VAA<G0["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T-H
M87)T('1Y<&4@;F]T(&9O=6YD)RD["B`@("`@("`@?0H@("`@?0H*("`@(&9U
M;F-T:6]N(&%D9%A$871A*"1D871A*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M9&%T85LG>"==(#T@)&1A=&$["B`@("!]"@H@("`@9G5N8W1I;VX@861D641A
M=&$H)&1A=&$L("1N86UE(#T@)R<I"B`@("!["B`@("`@("`@:68@*&5M<'1Y
M*"1N86UE*2D@>PH@("`@("`@("`@("`D;F%M92`](&UD-2AS97)I86QI>F4H
M)&1A=&$I*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]D871A6R=Y)UU;
M)&YA;65=(#T@)&1A=&$["B`@("`@("`@<F5T=7)N("1N86UE.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&=E="@D<&%R86TI"B`@("!["B`@("`@("`@)&ME>2`]
M("=?)R`N("1P87)A;3L*("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/B1K
M97DI(#\@)'1H:7,M/B1K97D@.B!N=6QL.PH@("`@?0H*("`@(&9U;F-T:6]N
M('-E="@D<&%R86TL("1V86QU92D*("`@('L*("`@("`@("`D:V5Y(#T@)U\G
M("X@)'!A<F%M.PH@("`@("`@("1T:&ES+3XD:V5Y(#T@)'9A;'5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@0V%C:&4@=&AE(&EM86=E(&%N9"!R971U<FX@
M82!L:6YK('1O('9I97<@:70@;W5T(&]F('1H92!C86-H92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9&ES<&QA>2@I"B`@("!["B`@("`@("`@9VQO8F%L("1C
M;VYF+"`D<F5G:7-T<GD["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]#
M86-H92YP:'`G.PH@("`@("`@("1C86-H92`]("9(;W)D95]#86-H93HZ<VEN
M9VQE=&]N*"1C;VYF6R=C86-H92==6R=D<FEV97(G72P@2&]R9&4Z.F=E=$1R
M:79E<D-O;F9I9R@G8V%C:&4G+"`D8V]N9ELG8V%C:&4G75LG9')I=F5R)UTI
M*3L*"B`@("`@("`@)'1H:7,M/FEN:71I86QI>F4H*3L*"B`@("`@("`@)&-I
M9"`](&UD-2AS97)I86QI>F4H)'1H:7,I*3L*("`@("`@("`D8V%C:&4M/G-E
M="@D8VED+"!S97)I86QI>F4H87)R87DH)V1A=&$G(#T^("1T:&ES+3YD<F%W
M*&9A;'-E*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)V-T>7!E)R`]/B`D=&AI<RT^:6UG+3YG971#;VYT96YT5'EP92@I
M*2DI.PH*("`@("`@("`D=7)L(#T@2&]R9&4Z.G5R;"@D<F5G:7-T<GDM/F=E
M="@G=V5B<F]O="<L("=H;W)D92<I("X@)R]S97)V:6-E<R]C86-H979I97<N
M<&AP)RD["B`@("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L
M+"`G8VED)RP@)&-I9"D["@H@("`@("`@(')E='5R;B`D=&AI<RT^:6UG+3YG
M971,:6YK*"1U<FPL("1T:&ES+3Y?=&ET;&4I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4')O8V5S<R!A;&P@;V8@=&AE(&1A=&$@<V5T<R!A;F0@<V5T(&=R
M87!H('!R;W!E<G1I97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&EN:71I86QI
M>F4H)&UI;ED@/2!F86QS92P@)'-T97!,86)E;'-9(#T@9F%L<V4I"B`@("![
M"B`@("`@("`@+R\@3&]A9"!A($AO<F1E7TEM86=E(&-A;G9A<R!T;R!D<F%W
M(&]N+@H@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O26UA9V4N<&AP)SL*
M("`@("`@("`D=&AI<RT^:6UG(#T@)DAO<F1E7TEM86=E.CIF86-T;W)Y*"1T
M:&ES+3Y?:6UG5'EP92P@87)R87DH)VAE:6=H="<@/3X@)'1H:7,M/E]H96EG
M:'0L("=W:61T:"<@/3X@)'1H:7,M/E]W:61T:"P@)W1E;7`G(#T^("1T:&ES
M+3Y?=&UP9&ER*2D["@H@("`@("`@("\O(%1O=&%L(&EM86=E(&%N9"!G<F%P
M:"!A<F5A(&1I;65N<VEO;G,N"B`@("`@("`@)'=I9'1H(#T@)'1H:7,M/E]W
M:61T:"`M(#$["B`@("`@("`@)&AE:6=H="`]("1T:&ES+3Y?:&5I9VAT("T@
M,3L*"B`@("`@("`@)'1H:7,M/E]G<F%P:%1O<"`]("1T:&ES+3Y?<&%D9&EN
M9U1O<#L*("`@("`@("`D=&AI<RT^7V=R87!H0F]T=&]M(#T@)'1H:7,M/E]H
M96EG:'0@+2`Q("T@*"1T:&ES+3Y?<&%D9&EN9U1O<"`K("1T:&ES+3Y?<&%D
M9&EN9T)O='1O;2D["B`@("`@("`@)'1H:7,M/E]G<F%P:$QE9G0@/2`D=&AI
M<RT^7W!A9&1I;F=,969T.PH@("`@("`@("1T:&ES+3Y?9W)A<&A2:6=H="`]
M("1T:&ES+3Y?=VED=&@@+2`D=&AI<RT^7W!A9&1I;F=2:6=H="`M(#$["B`@
M("`@("`@)'1H:7,M/E]G<F%P:$AE:6=H="`]("1T:&ES+3Y?9W)A<&A";W1T
M;VT@+2`D=&AI<RT^7V=R87!H5&]P.PH@("`@("`@("1T:&ES+3Y?9W)A<&A7
M:61T:"`]("1T:&ES+3Y?9W)A<&A2:6=H="`M("1T:&ES+3Y?9W)A<&A,969T
M.PH*("`@("`@("`D=&AI<RT^7V=R:618(#T@;6EN*&-O=6YT*"1T:&ES+3Y?
M9&%T85LG>"==*2P@<F]U;F0H)'1H:7,M/E]G<F%P:%=I9'1H("\@-#`I*3L*
M("`@("`@("!I9B`H(21T:&ES+3Y?9W)I9%@I('L*("`@("`@("`@("`@<F5Q
M=6ER95]O;F-E("=014%2+G!H<"<["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*"=.;R!D871A+B<I.PH@("`@("`@('T*"B`@("`@("`@
M+R\@1FEN9"!T:&4@<F%N9V4@;V8@86QL('D@=F%L=65S+@H@("`@("`@("1Y
M9&%T82`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/E]G<FED62`](#`["B`@
M("`@("`@9F]R96%C:"`H)'1H:7,M/E]D871A6R=Y)UT@87,@)&1A=&$I('L*
M("`@("`@("`@("`@)'1H:7,M/E]G<FED62`](&UA>"@D=&AI<RT^7V=R:619
M+"!C;W5N="@D9&%T82DI.PH@("`@("`@("`@("`D>61A=&$@/2!A<G)A>5]M
M97)G92@D>61A=&$L("1D871A*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES
M+3Y?;6%X6"`](&-O=6YT*"1T:&ES+3Y?9&%T85LG>"==*3L*("`@("`@("!L
M:7-T*"1T:&ES+3Y?;6EN62P@)'1H:7,M/E]M87A9*2`]("1T:&ES+3Y?9FEN
M9%)A;F=E*"1Y9&%T82D["B`@("`@("`@:68@*"1M:6Y9("$]/2!F86QS92D@
M>PH@("`@("`@("`@("`D=&AI<RT^7VUI;ED@/2`D;6EN63L*("`@("`@("!]
M"@H@("`@("`@("1T:&ES+3Y?9&EF9ED@/2`D=&AI<RT^7VUA>%D@+2`D=&AI
M<RT^7VUI;ED["@H@("`@("`@("\O($-A;&-U;&%T92!T:&4@;G5M8F5R(&]F
M(%D@9W)I9&QI;F5S("AA;F0@=&AU<RP@;&%B96QS*2!T;PH@("`@("`@("\O
M('-H;W<N(%1R>2!T;R!M86ME('-U<F4@=V4@9&]N)W0@96YD('5P('=I=&@@
M=&]O(&1E;G-E(&$*("`@("`@("`O+R!G<FED+"!B=70@86QS;R!M86ME('-U
M<F4@=&AA="!W92!H879E(&$@9F5W(&=R:60@;&EN97,@=&\*("`@("`@("`O
M+R!B<F5A:R!U<"!S;6%L;"!D871A<V5T<RX*("`@("`@("!I9B`H)'-T97!,
M86)E;'-9(#T]/2!F86QS92D@>PH@("`@("`@("`@("`D=&AI<RT^7V=R:619
M(#T@;6%X*&UI;B@D=&AI<RT^7V=R:619+"!F;&]O<B@D=&AI<RT^7V=R87!H
M2&5I9VAT("\@,S`I*2P@9FQO;W(H)'1H:7,M/E]G<F%P:$AE:6=H="`O(#8P
M*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]G<FED
M62`](&9L;V]R*"@D=&AI<RT^7VUA>%D@+2`D=&AI<RT^7VUI;EDI("\@)'-T
M97!,86)E;'-9*3L*("`@("`@("!]"@H@("`@("`@(&EF("@H)'1H:7,M/E]M
M87A9("T@)'1H:7,M/E]M:6Y9*2`]/2`P*2!["B`@("`@("`@("`@(')E<75I
M<F5?;VYC92`G4$5!4BYP:'`G.PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@G3F\@<F%N9V4@=&\@9W)A<&@N($-H96-K(&1A=&$N)RD[
M"B`@("`@("`@?0H*("`@("`@("`O+R!&;W)M870@=&5X="!F;W(@;&%B96QI
M;F<@=&AE(%D@87AI<RX*("`@("`@("!I9B`H)'-T97!,86)E;'-9(#T]/2!F
M86QS92D@>PH@("`@("`@("`@("`D9&5L=&%,86)E;'-9(#T@*"1T:&ES+3Y?
M;6%X62`M("1T:&ES+3Y?;6EN62D@+R`H)'1H:7,M/E]G<FED62D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&1E;'1A3&%B96QS62`]("1S=&5P
M3&%B96QS63L*("`@("`@("!]"@H@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M/2`D=&AI<RT^7V=R:619.R`D:2LK*2!["B`@("`@("`@("`@("1T97AT(#T@
M)'1H:7,M/E]M:6Y9("L@*"1D96QT84QA8F5L<UD@*B`D:2D["B`@("`@("`@
M("`@("1T:&ES+3Y?;&%B96QS65LD:5T@/2!N=6UB97)?9F]R;6%T*"1T97AT
M+"`R*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?;&%B
M96QS62DI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+G!H<"<[
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=.;R!9(&%X
M:7,@9&%T82XG*3L*("`@("`@("!]"@H@("`@("`@("\O($-A;&-U;&%T92!T
M:&4@<W!A8VEN9R!F;W(@=&EC:W,@86YD(&=R:60@;&EN97,N"B`@("`@("`@
M)&1E;F]M:6YA=&]R(#T@)'1H:7,M/E]M87A8("T@,2`K("@R("H@)'1H:7,M
M/E]O9F9S971'<FED6"D["B`@("`@("`@:68@*"1D96YO;6EN871O<B`]/2`P
M*2!["B`@("`@("`@("`@("1D96YO;6EN871O<B`](#$["B`@("`@("`@?0H@
M("`@("`@("1T:&ES+3Y?9F%C=&]R6"`]("1T:&ES+3Y?9W)A<&A7:61T:"`O
M("1D96YO;6EN871O<CL*("`@("`@("`D=&AI<RT^7V9A8W1O<ED@/2`D=&AI
M<RT^7V=R87!H2&5I9VAT("\@)'1H:7,M/E]D:69F63L*"B`@("`@("`@)&1E
M;F]M:6YA=&]R(#T@)'1H:7,M/E]G<FED6"`M(#$@*R`R("H@)'1H:7,M/E]O
M9F9S971'<FED6#L*("`@("`@("!I9B`H)&1E;F]M:6YA=&]R(#T](#`I('L*
M("`@("`@("`@("`@)&1E;F]M:6YA=&]R(#T@,3L*("`@("`@("!]"B`@("`@
M("`@)'1H:7,M/E]D96QT851I8VMS6"`]("@D=&AI<RT^7V=R87!H5VED=&@@
M+R`D9&5N;VUI;F%T;W(I("\@)'1H:7,M/E]F86-T;W)8.PH@("`@("`@(&EF
M("@D<W1E<$QA8F5L<UD@/3T](&9A;'-E*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?9&5L=&%4:6-K<UD@/2`H)'1H:7,M/E]G<F%P:$AE:6=H="`O("1T:&ES
M+3Y?9W)I9%DI("\@)'1H:7,M/E]F86-T;W)9.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1T:&ES+3Y?9&5L=&%4:6-K<UD@/2`D<W1E<$QA8F5L
M<UD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("!F=6YC=&EO;B!D<F%W*"1D:7-P;&%Y(#T@=')U92P@)&UI;ED@/2!F86QS
M92P@)&1E;'1A3&%B96QS62`](&9A;'-E*0H@("`@>PH@("`@("`@("1R97-U
M;'0@/2`D=&AI<RT^:6YI=&EA;&EZ92@D;6EN62P@)&1E;'1A3&%B96QS62D[
M"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@
M("1P;&]T<R`](&-O=6YT*"1T:&ES+3Y?<&QO=',I.PH@("`@("`@("1C:&%R
M=',@/2!C;W5N="@D=&AI<RT^7V-H87)T<RD["@H@("`@("`@(&EF("@D<&QO
M=',I('L*("`@("`@("`@("`@)'1H:7,M/F1R87="86-K9W)O=6YD*"D["B`@
M("`@("`@("`@("1T:&ES+3YD<F%W5&ET;&4H*3L*("`@("`@("`@("`@)'1H
M:7,M/F1R87='<FED6"@I.PH@("`@("`@("`@("`D=&AI<RT^9')A=T=R:619
M*"D["B`@("`@("`@("`@("1T:&ES+3YD<F%W4&QO=$)O>"@I.PH@("`@("`@
M("`@("`D=&AI<RT^9')A=TQA8F5L<U@H*3L*("`@("`@("`@("`@)'1H:7,M
M/F1R87=,86)E;'-9*"D["@H@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@
M/"`D<&QO=',[("1I*RLI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&QO
M='-;)&E=+3YD<F%W*"1T:&ES+3Y?;6EN62D["B`@("`@("`@("`@('T*("`@
M("`@("!](&5L<V5I9B`H)&-H87)T<RD@>PH@("`@("`@("`@("`D=&AI<RT^
M9')A=U1I=&QE*"D["@H@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D
M8VAA<G1S.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-H87)T
M<ULD:5TM/F1R87<H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1D:7-P;&%Y(#\@)'1H:7,M/FEM9RT^9&ES<&QA>2@I(#H@
M)'1H:7,M/FEM9RT^<F%W*"D["B`@("!]"@H@("`@9G5N8W1I;VX@9')A=T)A
M8VMG<F]U;F0H*0H@("`@>PH@("`@("`@("1T:&ES+3YI;6<M/G)E8W1A;F=L
M92@P+"`P+"`D=&AI<RT^7W=I9'1H("T@,2P@)'1H:7,M/E]H96EG:'0@+2`Q
M+"`G8FQA8VLG+"`D=&AI<RT^7V)A8VMG<F]U;F0I.PH@("`@("`@("1T:&ES
M+3YI;6<M/G)E8W1A;F=L92@D=&AI<RT^7V=R87!H3&5F="P@)'1H:7,M/E]G
M<F%P:%1O<"P@)'1H:7,M/E]G<F%P:%=I9'1H+"`D=&AI<RT^7V=R87!H2&5I
M9VAT+"`G8FQA8VLG+"`G=VAI=&4G*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($1R87<@82!B;W@@87)O=6YD('1H92!P;&]T(&%R96$N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&1R87=0;&]T0F]X*"D*("`@('L*("`@("`@("`D=&AI<RT^
M:6UG+3YR96-T86YG;&4H)'1H:7,M/E]G<F%P:$QE9G0L("1T:&ES+3Y?9W)A
M<&A4;W`L("1T:&ES+3Y?9W)A<&A7:61T:"P@)'1H:7,M/E]G<F%P:$AE:6=H
M="P@)V)L86-K)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W<R!G<FED
M(&QI;F5S(&9R;VT@=&]P('1O(&)O='1O;2!O;B!T:&4@:6UA9V4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&1R87='<FED6"@I"B`@("!["B`@("`@("`@9F]R
M("@D:2`](#`[("1I(#P@)'1H:7,M/E]G<FED6#L@)&DK*RD@>PH@("`@("`@
M("`@("`D>"`]("1T:&ES+3YT<F%N<VQA=&58*"1T:&ES+3Y?9&5L=&%4:6-K
M<U@@*B`D:2D["B`@("`@("`@("`@("1T:&ES+3YI;6<M/F1A<VAE9$QI;F4H
M)'@L("1T:&ES+3Y?9W)A<&A4;W`L("1X+"`D=&AI<RT^7V=R87!H0F]T=&]M
M+"`G9W)A>2<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1R
M87=S(&=R:60@;&EN97,@9G)O;2!L969T('1O(')I9VAT(&]N('1H92!I;6%G
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9')A=T=R:619*"D*("`@('L*("`@
M("`@("!F;W(@*"1I(#T@,#L@)&D@/#T@)'1H:7,M/E]G<FED63L@)&DK*RD@
M>PH@("`@("`@("`@("`D>2`]("1T:&ES+3YT<F%N<VQA=&59*"1T:&ES+3Y?
M;6EN62`K("1T:&ES+3Y?9&5L=&%4:6-K<UD@*B`D:2D["B`@("`@("`@("`@
M("1T:&ES+3YI;6<M/F1A<VAE9$QI;F4H)'1H:7,M/E]G<F%P:$QE9G0L("1Y
M+"`D=&AI<RT^7V=R87!H4FEG:'0L("1Y+"`G9W)A>2<I.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($1R87<@=&AE('1I=&QE+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!D<F%W5&ET;&4H*0H@("`@>PH@("`@("`@(&EF("@A
M96UP='DH)'1H:7,M/E]T:71L92DI('L*("`@("`@("`@("`@)'1H:7,M/FEM
M9RT^=&5X="@D=&AI<RT^7W1I=&QE+"`D=&AI<RT^7V=R87!H3&5F="`K("@D
M=&AI<RT^7V=R87!H5VED=&@@+R`R*2`M("@H<W1R;&5N*"1T:&ES+3Y?=&ET
M;&4I("\@,BD@*B`W*2P@)'1H:7,M/E]G<F%P:%1O<"`M(#(P+"`D=&AI<RT^
M7W1I=&QE1F]N="D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M1')A=W,@=&AE(&%X:7,@=&%G('1E>'0@;W5T<VED92!T:&4@<&QO='1I;F<@
M87)E82!O;B!T:&4@>`H@("`@("H@87AI<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@9')A=TQA8F5L<U@H*0H@("`@>PH@("`@("`@("\O($1R87<@6"!A>&ES
M(&QA8F5L+@H@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]X;&%B96PI*2![
M"B`@("`@("`@("`@("1X(#T@)'1H:7,M/E]G<F%P:$QE9G0@*R`H)'1H:7,M
M/E]G<F%P:%=I9'1H("\@,BD@+2`H<W1R;&5N*"1T:&ES+3Y?>&QA8F5L*2`J
M(#,I.PH@("`@("`@("`@("`D>2`]("1T:&ES+3Y?9W)A<&A";W1T;VT@*R`U
M,#L*("`@("`@("`@("`@)'1H:7,M/FEM9RT^=&5X="@D=&AI<RT^7WAL86)E
M;"P@)'@L("1Y+"`D=&AI<RT^7VQA8F5L1F]N="D["B`@("`@("`@?0H*("`@
M("`@("`D;&%S=%@@/2`P.PH@("`@("`@("1M:6Y$:69F(#T@,C`["B`@("`@
M("`@9F]R96%C:"`H)'1H:7,M/E]D871A6R=X)UT@87,@)&D@/3X@)'1E>'0I
M('L*("`@("`@("`@("`@)'@@/2`D=&AI<RT^=')A;G-L871E6"@D:2D["B`@
M("`@("`@("`@(&EF("@D>"`M("1L87-T6"`^/2`D;6EN1&EF9BD@>PH@("`@
M("`@("`@("`@("`@)&QA<W18(#T@)'@["B`@("`@("`@("`@("`@("`D=&AI
M<RT^:6UG+3YT97AT*"1T97AT+"`D>"`M(#4L("1T:&ES+3Y?9W)A<&A";W1T
M;VT@*R`H<W1R;&5N*"1T97AT*2`J(#<I+"`D=&AI<RT^7V%X:7-&;VYT+"`G
M8FQA8VLG+"`M.3`I.PH@("`@("`@("`@("`@("`@)'1H:7,M/FEM9RT^;&EN
M92@D>"P@)'1H:7,M/E]G<F%P:$)O='1O;2`K(#(L("1X+"`D=&AI<RT^7V=R
M87!H0F]T=&]M("T@,BD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$<F%W<R!T:&4@87AI<R!T86<@=&5X="!O=71S
M:61E('1H92!P;&]T=&EN9R!A<F5A(&]N('1H92!Y"B`@("`@*B!A>&ES+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!D<F%W3&%B96QS62@I"B`@("!["B`@("`@
M("`@+R\@1')A=R!9(&%X:7,@;&%B96PN"B`@("`@("`@:68@*"%E;7!T>2@D
M=&AI<RT^7WEL86)E;"DI('L*("`@("`@("`@("`@)'D@/2`D=&AI<RT^7V=R
M87!H5&]P("L@*"1T:&ES+3Y?9W)A<&A(96EG:'0@+R`R*2`K("@H<W1R;&5N
M*"1T:&ES+3Y?>6QA8F5L*2`O(#(I("H@-2D["B`@("`@("`@("`@("1T:&ES
M+3YI;6<M/G1E>'0H)'1H:7,M/E]Y;&%B96PL(#4L("1Y+"`D=&AI<RT^7VQA
M8F5L1F]N="P@)V)L86-K)RP@+3DP*3L*("`@("`@("!]"@H@("`@("`@(&9O
M<F5A8V@@*"1T:&ES+3Y?;&%B96QS62!A<R`D:2`]/B`D;&%B96PI('L*("`@
M("`@("`@("`@)'D@/2`D=&AI<RT^=')A;G-L871E62@D=&AI<RT^7VUI;ED@
M*R`D:2`J("1T:&ES+3Y?9&5L=&%4:6-K<UDI.PH@("`@("`@("`@("`D=&AI
M<RT^:6UG+3YT97AT*"1L86)E;"P@)'1H:7,M/E]G<F%P:$QE9G0@+2`H<W1R
M;&5N*"1L86)E;"D@*B`W*2P@)'D@+2`U+"`D=&AI<RT^7V%X:7-&;VYT*3L*
M("`@("`@("`@("`@)'1H:7,M/FEM9RT^;&EN92@D=&AI<RT^7V=R87!H3&5F
M="`M(#(L("1Y+"`D=&AI<RT^7V=R87!H3&5F="`K(#(L("1Y*3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!486ME(&$@<&%I<B!O9B`H>"QY
M*2!G<F%P:"!C;V]R9&EN871E<R!A;F0@<F5T=7)N('1H90H@("`@("H@<V-R
M965N+7!I>&5L(&-O;W)D:6YA=&5S(&9O<B!T:&5M+@H@("`@("H*("`@("`J
M($!P87)A;2!F;&]A="`F)'@@("`@(%1H92!X('!O<VET:6]N(&EN('=O<FQD
M(&-O;W)D:6YA=&5S+@H@("`@("H@0'!A<F%M(&9L;V%T("8D>2`@("`@5&AE
M('D@<&]S:71I;VX@:6X@=V]R;&0@8V]O<F1I;F%T97,N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('1R86YS;&%T92@F)'@L("8D>2D*("`@('L*("`@("`@("`D
M>"`]("1T:&ES+3YT<F%N<VQA=&58*"1X*3L*("`@("`@("`D>2`]("1T:&ES
M+3YT<F%N<VQA=&59*"1Y*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1R86YS
M;&%T92!T:&4@>"!C;V]R9&EN871E(&]F(&$@<&]I;G0@;VX@=&AE('!L;W0@
M=&\@<V-R965N"B`@("`@*B!C;V]R9&EN871E<RX*("`@("`J"B`@("`@*B!`
M<&%R86T@9FQO870@)'@@(%1H92!X('=O<FQD("AP;&]T*2!C;V]R9&EN871E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!T<F%N<VQA=&58*"1X*0H@("`@>PH@
M("`@("`@(')E='5R;B`H*"1X("L@)'1H:7,M/E]O9F9S971'<FED6"D@*B`D
M=&AI<RT^7V9A8W1O<E@I("L@)'1H:7,M/E]G<F%P:$QE9G0["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!4<F%N<VQA=&4@=&AE('D@8V]O<F1I;F%T92!O9B!A
M('!O:6YT(&]N('1H92!P;&]T('1O('-C<F5E;@H@("`@("H@8V]O<F1I;F%T
M97,N"B`@("`@*@H@("`@("H@0'!A<F%M(&9L;V%T("1Y("!4:&4@>2!W;W)L
M9"`H<&QO="D@8V]O<F1I;F%T92X*("`@("`J+PH@("`@9G5N8W1I;VX@=')A
M;G-L871E62@D>2D*("`@('L*("`@("`@("!I9B`H)'DI('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?9W)A<&A";W1T;VT@+2`H*"1Y("T@)'1H:7,M
M/E]M:6Y9*2`J("1T:&ES+3Y?9F%C=&]R62D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9W)A<&A";W1T;VT["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1FEN9"!T:&4@;6EN:6UU;2!A
M;F0@;6%X:6UU;2!V86QU97,@9F]R(&$@<V5T(&]F(&1A=&$N"B`@("`@*@H@
M("`@("H@5&AE("1R97-O;'5T:6]N('9A<FEA8FQE(&ES('5S960@9F]R(')O
M=6YD:6YG(&UA>&EM=6T@86YD"B`@("`@*B!M:6YI;75M('9A;'5E<RX@268@
M;6%X:6UU;2!V86QU92!I<R`X-C0U('1H96XZ"B`@("`@*@H@("`@("H@268@
M)')E<V]L=71I;VX@:7,@,"P@=&AE;B!M87AI;75M('9A;'5E(&)E8V]M97,@
M.3`P,"X*("`@("`J($EF("1R97-O;'5T:6]N(&ES(#$L('1H96X@;6%X:6UU
M;2!V86QU92!B96-O;65S(#@W,#`N"B`@("`@*B!)9B`D<F5S;VQU=&EO;B!I
M<R`R+"!T:&5N(&UA>&EM=6T@=F%L=64@8F5C;VUE<R`X-C4P+@H@("`@("H@
M268@)')E<V]L=71I;VX@:7,@,RP@=&AE;B!M87AI;75M('9A;'5E(&)E8V]M
M97,@.#8T-2X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@("1D871A("`@
M("`@("`@5&AE($1A=&%S970@=&\@9FEN9"!T:&4@<F%N9V4@9F]R+@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&UI;B`@("`@("`@($UI;FEM=6T@=F%L=64@
M=&\@<W1A<G0@870N(%1H92!L;W=E<W0@;G5M8F5R"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:6X@=&AE(&1A=&%S970@:7,@=7-E9"!I
M9B!I="=S(&QO=V5R+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&UA>"`@("`@
M("`@($UA>&EM=6T@=F%L=64@=&\@<W1A<G0@870N(%1H92!H:6=H97-T"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;G5M8F5R(&EN('1H
M92!D871A<V5T(&ES('5S960@:68@:70G<PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&AI9VAE<BX*("`@("`J($!P87)A;2!I;G1E9V5R
M("1R97-O;'5T:6]N("!4:&4@<F5S;VQU=&EO;B!T;R!U<V4@9F]R('1H92!R
M86YG92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@;6EN:6UU
M;2!A;F0@;6%X:6UU;2!V86QU97,@9F]R('1H92!R86YG92X*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?9FEN9%)A;F=E
M*"1D871A+"`D;6EN(#T@,"P@)&UA>"`](#`L("1R97-O;'5T:6]N(#T@,"D*
M("`@('L*("`@("`@("!I9B`H(6-O=6YT*"1D871A*2D@>PH@("`@("`@("`@
M("!R971U<FX@87)R87DH)VUI;B<@/3X@,"P@)VUA>"<@/3X@,"D["B`@("`@
M("`@?0H*("`@("`@("`D9&%T85M=(#T@)&UA>#L*("`@("`@("`D9&%T85M=
M(#T@)&UI;CL*("`@("`@("`D;6%X(#T@;6%X*"1D871A*3L*("`@("`@("`D
M;6EN(#T@;6EN*"1D871A*3L*"B`@("`@("`@:68@*"1M87@@/3T@,"D@>PH@
M("`@("`@("`@("`D9F%C=&]R(#T@,3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!I9B`H)&UA>"`\(#`I('L*("`@("`@("`@("`@("`@("1F86-T
M;W(@/2`M<&]W*#$P+"`H9FQO;W(H;&]G,3`H86)S*"1M87@I*2D@*R`D<F5S
M;VQU=&EO;BDI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)&9A8W1O<B`]('!O=R@Q,"P@*&9L;V]R*&QO9S$P*&%B<R@D;6%X*2DI
M("T@)')E<V]L=71I;VXI*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@)&UA>"`]("1F86-T;W(@*B!`8V5I;"@D;6%X("\@)&9A8W1O<BD[
M"B`@("`@("`@)&UI;B`]("1F86-T;W(@*B!`9FQO;W(H)&UI;B`O("1F86-T
M;W(I.PH*("`@("`@("!R971U<FX@87)R87DH)&UI;BP@)&UA>"D["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]344PN<&AP````
M````````````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`S-#,W
M-R`Q,#4Q-30S,S<T,"`P,C`U,S(`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J(%1H:7,@:7,@82!U=&EL
M:71Y(&-L87-S+"!E=F5R>2!M971H;V0@:7,@<W1A=&EC+@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]344PO4U%,+G!H<"QV(#$N,S`N,BXQ-R`R,#`V+S`T
M+S$Y(#`S.C0Y.C0Y(&)E;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR
M,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y
M<FEG:'0@,C`P-2TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF('EO=2!D:60*("H@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@
M/&IA;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#(N,@H@*B!`<&%C
M:V%G92!(;W)D95]344P*("HO"F-L87-S($AO<F1E7U-13"!["@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS(&$@8F]O;&5A;B!E>'!R97-S:6]N('5S:6YG('1H
M92!S<&5C:69I960@;W!E<F%T;W(N(%5S97,*("`@("`J(&1A=&%B87-E+7-P
M96-I9FEC(&-A<W1I;F<L(&EF(&YE8V5S<V%R>2X*("`@("`J"B`@("`@*B!`
M<&%R86T@1$(@)&1B:"`@("`@("`@5&AE(%!%05(Z.D1"(&1A=&%B87-E(&]B
M:F5C="X*("`@("`J($!P87)A;2!S=')I;F<@)&QH<R`@("!4:&4@8V]L=6UN
M(&]R(&5X<')E<W-I;VX@=&\@=&5S="X*("`@("`J($!P87)A;2!S=')I;F<@
M)&]P("`@("!4:&4@;W!E<F%T;W(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1R
M:',@("`@5&AE(&-O;7!A<FES;VX@=F%L=64N"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D8FEN9"`@268@=')U92P@=&AE(&UE=&AO9"!R971U<FYS('1H92!Q
M=65R>2!A;F0@82!L:7-T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M;V8@=F%L=65S('-U:71A8FQE(&9O<B!B:6YD:6YG(&%S(&%N(&%R<F%Y+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@4U%,('1E<W0@9G)A
M9VUE;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&)U:6QD0VQA=7-E*"8D9&)H
M+"`D;&AS+"`D;W`L("1R:',L("1B:6YD(#T@9F%L<V4I"B`@("!["B`@("`@
M("`@<W=I=&-H("@D;W`I('L*("`@("`@("!C87-E("=\)SH*("`@("`@("!C
M87-E("<F)SH*("`@("`@("`@("`@<W=I=&-H("@D9&)H+3YP:'!T>7!E*2![
M"B`@("`@("`@("`@(&-A<V4@)W!G<W%L)SH*("`@("`@("`@("`@("`@("\O
M($]N;'D@4&=344P@-RXS*R!U;F1E<G-T86YD<R!344PY.2`G4TE-24Q!4B!4
M3R<[('5S90H@("`@("`@("`@("`@("`@+R\@?B!F;W(@9W)E871E<B!B86-K
M=V%R9',@8V]M<&%T:6)I;&ET>2X*("`@("`@("`@("`@("`@("1Q=65R>2`]
M("=#05-%(%=(14X@0T%35"@E<R!!4R!605)#2$%2*2!^(%PG7BT_6S`M.5TK
M)%PG(%1(14X@*$-!4U0H)7,@05,@24Y414=%4BD@)7,@)7,I(#P^(#`@14Q3
M12!&04Q312!%3D0G.PH@("`@("`@("`@("`@("`@:68@*"1B:6YD*2!["B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*'-P<FEN=&8H2&]R9&5?
M4U%,.CIE<V-A<&50<F5P87)E*"1Q=65R>2DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@2&]R9&5?4U%,.CIE<V-A<&50<F5P
M87)E*"1L:',I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@($AO<F1E7U-13#HZ97-C87!E4')E<&%R92@D;&AS*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!(;W)D95]344PZ
M.F5S8V%P95!R97!A<F4H)&]P*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G/R<I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@H:6YT*21R:',I*3L*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N('-P<FEN=&8H
M)'%U97)Y+"`D;&AS+"`D;&AS+"`D;W`L("AI;G0I)')H<RD["B`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!C87-E("=O8VDX)SH*("`@("`@("`@
M("`@("`@("\O($]R86-L92!U<V5S("8@9F]R('9A<FEA8FQE<RX@5V4@;F5E
M9"!T;R!U<V4@=&AE(&)I=&%N9`H@("`@("`@("`@("`@("`@+R\@9G5N8W1I
M;VX@=&AA="!I<R!A=F%I;&%B;&4L(&)U="!M87D@8F4@=6YS=7!P;W)T960N
M"B`@("`@("`@("`@("`@("`D<75E<GD@/2`G8FET86YD*"5S+"`E<RD@/2`E
M<R<["B`@("`@("`@("`@("`@("!I9B`H)&)I;F0I('L*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@87)R87DH<W!R:6YT9BA(;W)D95]344PZ.F5S8V%P
M95!R97!A<F4H)'%U97)Y*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!(;W)D95]344PZ.F5S8V%P95!R97!A<F4H)&QH<RDL
M("<_)RP@)S\G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH*&EN="DD<FAS+"`H:6YT*21R:',I*3L*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N('-P<FEN=&8H
M)'%U97)Y+"`D;&AS+"`H:6YT*21R:',L("AI;G0I)')H<RD["B`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!C87-E("=M<W-Q;"<Z"B`@("`@("`@
M("`@("`@("`O+R!-4U-13"!M=7-T(&AA=F4@82!V86QI9"!B;V]L96%N(&5X
M<')E<W-I;VX*("`@("`@("`@("`@("`@("1Q=65R>2`]("<H0T%312!72$5.
M($E33E5-15))0R@E<RD@/2`Q(%1(14X@*"5S("8@)7,I($5,4T4@)7,@14Y$
M*2`]("5S)SL*("`@("`@("`@("`@("`@(&EF("@D8FEN9"D@>PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!A<G)A>2AS<')I;G1F*$AO<F1E7U-13#HZ
M97-C87!E4')E<&%R92@D<75E<GDI+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@($AO<F1E7U-13#HZ97-C87!E4')E<&%R92@D
M;&AS*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!(;W)D95]344PZ.F5S8V%P95!R97!A<F4H)&QH<RDL("<_)RP@)S\G+"`G
M/R<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@H
M:6YT*21R:',L("AI;G0I)')H<R`M(#$L("AI;G0I)')H<RDI.PH@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M<W!R:6YT9B@D<75E<GDL("1L:',L("1L:',L("AI;G0I)')H<RP@*&EN="DD
M<FAS("T@,2P@*&EN="DD<FAS*3L*("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@(&-A<V4@)V]D8F,G.@H@("`@("`@("`@("`@("`@+R\@3T1"0R!M
M=7-T(&AA=F4@82!V86QI9"!B;V]L96%N(&5X<')E<W-I;VX*("`@("`@("`@
M("`@("`@("1Q=65R>2`]("<H)7,@)B`E<RD@/2`E<R<["B`@("`@("`@("`@
M("`@("!I9B`H)&)I;F0I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M87)R87DH<W!R:6YT9BA(;W)D95]344PZ.F5S8V%P95!R97!A<F4H)'%U97)Y
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!(
M;W)D95]344PZ.F5S8V%P95!R97!A<F4H)&QH<RDL("<_)RP@)S\G*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH*&EN="DD<FAS
M+"`H:6YT*21R:',I*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N('-P<FEN=&8H)'%U97)Y+"`D;&AS+"`H
M:6YT*21R:',L("AI;G0I)')H<RD["B`@("`@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@:68@*"1B:6YD*2![
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"1L:',@+B`G("<@
M+B!(;W)D95]344PZ.F5S8V%P95!R97!A<F4H)&]P*2`N("<@/R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"AI;G0I)')H<RDI
M.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)&QH<R`N("<@)R`N("1O<"`N("<@)R`N("AI;G0I)')H<SL*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("!C87-E
M("=^)SH*("`@("`@("`@("`@:68@*"1D8F@M/G!H<'1Y<&4@/3T@)VUY<W%L
M)RD@>PH@("`@("`@("`@("`@("`@)&]P(#T@)U)%1T584"<["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@:68@*"1B:6YD*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@87)R87DH)&QH<R`N("<@)R`N("1O<"`N("<@/R<L(&%R<F%Y
M*"1R:',I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D;&AS("X@)R`G("X@)&]P("X@)R`G("X@)')H<SL*("`@("`@
M("`@("`@?0H*("`@("`@("!C87-E("=)3B<Z"B`@("`@("`@("`@(&EF("@D
M8FEN9"D@>PH@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1R:',I*2![
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"1L:',@+B`G($E.
M("@_)R`N('-T<E]R97!E870H)RP@/R<L(&-O=6YT*"1R:',I("T@,2D@+B`G
M*2<L("1R:',I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`O+R!792!N965D('1O(&)I;F0@96%C:"!M96UB97(@;V8@
M=&AE($E.(&-L875S90H@("`@("`@("`@("`@("`@("`@("\O('-E<&%R871E
M;'D@=&\@96YS=7)E('!R;W!E<B!Q=6]T:6YG+@H@("`@("`@("`@("`@("`@
M("`@(&EF("AS=6)S='(H)')H<RP@,"P@,2D@/3T@)R@G*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1R:',@/2!S=6)S='(H)')H<RP@,2D["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&EF("AS=6)S
M='(H)')H<RP@+3$I(#T]("<I)RD@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D<FAS(#T@<W5B<W1R*"1R:',L(#`L("TQ*3L*("`@("`@("`@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`@("`@("`@("1I9',@/2!P<F5G7W-P;&ET
M*"<O7',J+%QS*B\G+"`D<FAS*3L*"B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N(&%R<F%Y*"1L:',@+B`G($E.("@_)R`N('-T<E]R97!E870H)RP@/R<L
M(&-O=6YT*"1I9',I("T@,2D@+B`G*2<L("1I9',I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@:68@
M*&ES7V%R<F%Y*"1R:',I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M("1L:',@+B`G($E.("<@+B!I;7!L;V1E*"<L("<L("1R:',I.PH@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)&QH<R`N("<@24X@)R`N("1R:',["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*"B`@("`@("`@8V%S92`G3$E+12<Z"B`@("`@("`@("`@(&EF
M("@D9&)H+3YP:'!T>7!E(#T]("=P9W-Q;"<I('L*("`@("`@("`@("`@("`@
M("1Q=65R>2`]("<E<R!)3$E+12`E<R<["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D<75E<GD@/2`G3$]715(H)7,I($Q)2T4@3$]7
M15(H)7,I)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&)I;F0I
M('L*("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>2AS<')I;G1F*"1Q=65R
M>2P@2&]R9&5?4U%,.CIE<V-A<&50<F5P87)E*"1L:',I+"`G/R<I+"!A<G)A
M>2@G)2<@+B`D<FAS("X@)R4G*2D["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("!R971U<FX@<W!R:6YT9B@D<75E<GDL("1L:',L("1D
M8F@M/G%U;W1E*"<E)R`N("1R:',@+B`G)2<I*3L*("`@("`@("`@("`@?0H*
M("`@("`@("!D969A=6QT.@H@("`@("`@("`@("!I9B`H)&)I;F0I('L*("`@
M("`@("`@("`@("`@(')E='5R;B!A<G)A>2@D;&AS("X@)R`G("X@2&]R9&5?
M4U%,.CIE<V-A<&50<F5P87)E*"1O<"D@+B`G(#\G+"!A<G)A>2@D<FAS*2D[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@
M)&QH<R`N("<@)R`N("1O<"`N("<@)R`N("1D8F@M/G%U;W1E*"1R:',I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M17-C87!E<R!A;&P@8VAA<F%C=&5R<R!I;B!A('-T<FEN9R!T:&%T(&%R92!P
M;&%C96AO;&1E<G,@9F]R('1H90H@("`@("H@<')E<&%R92]E>&5C=71E(&UE
M=&AO9',@;V8@=&AE($1"('!A8VMA9V4N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<75E<GD@($$@<W1R:6YG('1O(&5S8V%P92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O<G)E8W1L>2!E<V-A<&5D('-T
M<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@97-C87!E4')E<&%R92@D<75E
M<GDI"B`@("!["B`@("`@("`@<F5T=7)N('!R96=?<F5P;&%C92@G+UL_(29=
M+R<L("=<7%Q<)#`G+"`D<75E<GDI.PH@("`@?0H*("`@(&9U;F-T:6]N(')E
M861";&]B*"8D9&)H+"`D=&%B;&4L("1F:65L9"P@)&-R:71E<FEA*0H@("`@
M>PH@("`@("`@(&EF("@A8V]U;G0H)&-R:71E<FEA*2D@>PH@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G66]U(&UU<W0@<W!E8VEF>2!T
M:&4@9F5T8V@@8W)I=&5R:6$G*3L*("`@("`@("!]"@H@("`@("`@("1W:&5R
M92`]("<G.PH*("`@("`@("!S=VET8V@@*"1D8F@M/F1B<WEN=&%X*2!["B`@
M("`@("`@8V%S92`G;V-I."<Z"B`@("`@("`@("`@(&9O<F5A8V@@*"1C<FET
M97)I82!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("`@("`@:68@
M*"%E;7!T>2@D=VAE<F4I*2!["B`@("`@("`@("`@("`@("`@("`@)'=H97)E
M("X]("<@04Y$("<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!I9B`H96UP='DH)'9A;'5E*2D@>PH@("`@("`@("`@("`@("`@("`@("1W
M:&5R92`N/2`D:V5Y("X@)R!)4R!.54Q,)SL*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@)'=H97)E("X]("1K97D@+B`G
M(#T@)R`N("1D8F@M/G%U;W1E*"1V86QU92D["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1S=&%T96UE;G0@/2!/0TE0
M87)S92@D9&)H+3YC;VYN96-T:6]N+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<W!R:6YT9B@G4T5,14-4("5S($923TT@)7,@5TA%4D4@
M)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9FEE;&0L("1T86)L92P@)'=H97)E*2D["B`@("`@("`@("`@($]#245X
M96-U=&4H)'-T871E;65N="D["B`@("`@("`@("`@(&EF("A/0TE&971C:$EN
M=&\H)'-T871E;65N="P@)&QO8BDI('L*("`@("`@("`@("`@("`@("1R97-U
M;'0@/2`D;&]B6S!=+3YL;V%D*"D["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D<F5S=6QT(#T@4$5!4CHZ<F%I<V5%<G)O<B@G56YA
M8FQE('1O(&QO860@4U%,($1A=&$G*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!/0TE&<F5E4W1A=&5M96YT*"1S=&%T96UE;G0I.PH@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@9F]R96%C
M:"`H)&-R:71E<FEA(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1W:&5R92DI('L*("`@("`@("`@("`@("`@("`@
M("`D=VAE<F4@+CT@)R!!3D0@)SL*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("1W:&5R92`N/2`D:V5Y("X@)R`]("<@+B`D9&)H+3YQ=6]T
M92@D=F%L=64I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1R97-U;'0@
M/2`D9&)H+3YG971/;F4H<W!R:6YT9B@G4T5,14-4("5S($923TT@)7,@5TA%
M4D4@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&9I96QD+"`D=&%B;&4L("1W:&5R92DI.PH*("`@("`@("`@("`@
M<W=I=&-H("@D9&)H+3YD8G-Y;G1A>"D@>PH@("`@("`@("`@("!C87-E("=P
M9W-Q;"<Z"B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@<&%C:R@G2"<@+B!S
M=')L96XH)')E<W5L="DL("1R97-U;'0I.PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@?0H*("`@(&9U;F-T:6]N(&EN<V5R=$)L;V(H)B1D8F@L
M("1T86)L92P@)&9I96QD+"`D9&%T82P@)&%T=')I8G5T97,I"B`@("!["B`@
M("`@("`@)&9I96QD<R`](&%R<F%Y*"D["B`@("`@("`@)'9A;'5E<R`](&%R
M<F%Y*"D["@H@("`@("`@('-W:71C:"`H)&1B:"T^9&)S>6YT87@I('L*("`@
M("`@("!C87-E("=O8VDX)SH*("`@("`@("`@("`@9F]R96%C:"`H)&%T=')I
M8G5T97,@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@("`@("1F
M:65L9'-;72`]("1K97D["B`@("`@("`@("`@("`@("`D=F%L=65S6UT@/2`D
M9&)H+3YQ=6]T92@D=F%L=64I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`D<W1A=&5M96YT(#T@3T-)4&%R<V4H)&1B:"T^8V]N;F5C=&EO;BP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-P<FEN=&8H)TE.4T52
M5"!)3E1/("5S("@E<RP@)7,I)R`N"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("<@5D%,5453("@E<RP@14U05%E?0DQ/0B@I
M*2!215154DY)3D<@)7,@24Y43R`Z8FQO8B<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T86)L92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:6UP;&]D92@G+"`G+"`D
M9FEE;&1S*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&9I96QD+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!I;7!L;V1E*"<L("<L("1V86QU97,I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9FEE;&0I*3L*"B`@
M("`@("`@("`@("1L;V(@/2!/0TE.97=$97-C<FEP=&]R*"1D8F@M/F-O;FYE
M8W1I;VXI.PH@("`@("`@("`@("!/0TE":6YD0GE.86UE*"1S=&%T96UE;G0L
M("<Z8FQO8B<L("1L;V(L("TQ+"!344Q47T),3T(I.PH@("`@("`@("`@("!/
M0TE%>&5C=71E*"1S=&%T96UE;G0L($]#25]$149!54Q4*3L*("`@("`@("`@
M("`@)&QO8BT^<V%V92@D9&%T82D["B`@("`@("`@("`@("1R97-U;'0@/2!/
M0TE#;VUM:70H)&1B:"T^8V]N;F5C=&EO;BD["B`@("`@("`@("`@("1L;V(M
M/F9R964H*3L*("`@("`@("`@("`@3T-)1G)E95-T871E;65N="@D<W1A=&5M
M96YT*3L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0@/R!T<G5E(#H@4$5!
M4CHZ<F%I<V5%<G)O<B@G56YK;F]W;B!%<G)O<B<I.PH*("`@("`@("!D969A
M=6QT.@H@("`@("`@("`@("!F;W)E86-H("@D871T<FEB=71E<R!A<R`D:V5Y
M(#T^("1V86QU92D@>PH@("`@("`@("`@("`@("`@)&9I96QD<UM=(#T@)&ME
M>3L*("`@("`@("`@("`@("`@("1V86QU97-;72`]("1V86QU93L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G24Y315)4
M($E.5$\@)7,@*"5S+"`E<RD@5D%,5453("@E<RDG+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T86)L92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I;7!L;V1E*"<L("<L("1F:65L9',I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1F:65L9"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G/R<@+B!S=')?<F5P96%T*"<L(#\G+"!C;W5N="@D=F%L=65S
M*2DI.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@('-W
M:71C:"`H)&1B:"T^9&)S>6YT87@I('L*("`@("`@("!C87-E("=M<W-Q;"<Z
M"B`@("`@("`@8V%S92`G<&=S<6PG.@H@("`@("`@("`@("`D=F%L=65S6UT@
M/2!B:6XR:&5X*"1D871A*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&1E9F%U;'0Z"B`@("`@("`@("`@("1V86QU97-;72`]("1D871A.PH@("`@
M("`@('T*"B`@("`@("`@+RH@3&]G('1H92!Q=65R>2!A="!A($1%0E5'(&QO
M9R!L979E;"X@*B\*("`@("`@("!(;W)D93HZ;&]G365S<V%G92AS<')I;G1F
M*"=344P@475E<GD@8GD@2&]R9&5?4U%,.CII;G-E<G1";&]B*"DZ('%U97)Y
M(#T@(B5S(B<L("1Q=65R>2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@
M("\J($5X96-U=&4@=&AE('%U97)Y+B`J+PH@("`@("`@(')E='5R;B`D=&AI
M<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH@("`@?0H*("`@(&9U
M;F-T:6]N('5P9&%T94)L;V(H)B1D8F@L("1T86)L92P@)&9I96QD+"`D9&%T
M82P@)'=H97)E+"`D86QS;W5P9&%T92D*("`@('L*("`@("`@("`D9FEE;&1S
M(#T@87)R87DH*3L*("`@("`@("`D=F%L=65S(#T@87)R87DH*3L*"B`@("`@
M("`@<W=I=&-H("@D9&)H+3YD8G-Y;G1A>"D@>PH@("`@("`@(&-A<V4@)V]C
M:3@G.@H@("`@("`@("`@("`D=VAE<F5S=')I;F<@/2`G)SL*("`@("`@("`@
M("`@9F]R96%C:"`H)'=H97)E(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1W:&5R97-T<FEN9RDI('L*("`@("`@
M("`@("`@("`@("`@("`D=VAE<F5S=')I;F<@+CT@)R!!3D0@)SL*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1W:&5R97-T<FEN9R`N/2`D
M:V5Y("X@)R`]("<@+B`D9&)H+3YQ=6]T92@D=F%L=64I.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`D<W1A=&5M96YT(#T@3T-)4&%R<V4H)&1B:"T^
M8V]N;F5C=&EO;BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('-P<FEN=&8H)U-%3$5#5"`E<R!&4D]-("5S(%=(15)%("5S($9/4B!54$1!
M5$4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9FEE;&0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T86)L92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'=H97)E<W1R:6YG*2D["@H@("`@("`@("`@("!/0TE%
M>&5C=71E*"1S=&%T96UE;G0L($]#25]$149!54Q4*3L*("`@("`@("`@("`@
M3T-)1F5T8VA);G1O*"1S=&%T96UE;G0L("1L;V(I.PH@("`@("`@("`@("`D
M;&]B6S!=+3YS879E*"1D871A*3L*("`@("`@("`@("`@)')E<W5L="`]($]#
M24-O;6UI="@D9&)H+3YC;VYN96-T:6]N*3L*("`@("`@("`@("`@)&QO8ELP
M72T^9G)E92@I.PH@("`@("`@("`@("!/0TE&<F5E4W1A=&5M96YT*"1S=&%T
M96UE;G0I.PH@("`@("`@("`@("!R971U<FX@)')E<W5L="`_('1R=64@.B!0
M14%2.CIR86ES945R<F]R*"=5;FMN;W=N($5R<F]R)RD["@H@("`@("`@(&1E
M9F%U;'0Z"B`@("`@("`@("`@("1U<&1A=&5S=')I;F<@/2`G)SL*("`@("`@
M("`@("`@)'9A;'5E<R`](&%R<F%Y*"D["B`@("`@("`@("`@(&9O<F5A8V@@
M*"1A;'-O=7!D871E(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@
M("`@("`D=7!D871E<W1R:6YG("X]("1K97D@+B`G(#T@/RP@)SL*("`@("`@
M("`@("`@("`@("1V86QU97-;72`]("1V86QU93L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D=7!D871E<W1R:6YG("X]("1F:65L9"`N("<@/2`_)SL*
M("`@("`@("`@("`@<W=I=&-H("@D9&)H+3YD8G-Y;G1A>"D@>PH@("`@("`@
M("`@("!C87-E("=M<W-Q;"<Z"B`@("`@("`@("`@(&-A<V4@)W!G<W%L)SH*
M("`@("`@("`@("`@("`@("1V86QU97-;72`](&)I;C)H97@H)&1A=&$I.PH@
M("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!D969A=6QT.@H@
M("`@("`@("`@("`@("`@)'9A;'5E<UM=(#T@)&1A=&$["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("1W:&5R97-T<FEN9R`]("<G.PH@("`@("`@("`@
M("!F;W)E86-H("@D=VAE<F4@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@
M("`@("`@("`@(&EF("@A96UP='DH)'=H97)E<W1R:6YG*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1W:&5R97-T<FEN9R`N/2`G($%.1"`G.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'=H97)E<W1R:6YG("X]("1K
M97D@+B`G(#T@/R<["B`@("`@("`@("`@("`@("`D=F%L=65S6UT@/2`D=F%L
M=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1Q=65R>2`]('-P<FEN
M=&8H)U501$%412`E<R!3150@)7,@5TA%4D4@)7,G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T86)L92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=7!D871E<W1R:6YG+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1W:&5R97-T<FEN9RD["B`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@('T*"B`@("`@("`@+RH@3&]G('1H92!Q=65R>2!A="!A($1%0E5'(&QO
M9R!L979E;"X@*B\*("`@("`@("!(;W)D93HZ;&]G365S<V%G92AS<')I;G1F
M*"=344P@475E<GD@8GD@2&]R9&5?4U%,.CIU<&1A=&5";&]B*"DZ('%U97)Y
M(#T@(B5S(B<L("1Q=65R>2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@
M("\J($5X96-U=&4@=&AE('%U97)Y+B`J+PH@("`@("`@(')E='5R;B`D9&)H
M+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0G5I;&0@86X@4U%,(%-%5"!C;&%U<V4N"B`@("`@*@H@("`@("H@5&AI
M<R!F=6YC=&EO;B!T86ME<R!A;B!A<G)A>2!I;B!T:&4@9F]R;2!C;VQU;6X@
M/3X@=F%L=64@86YD(')E='5R;G,*("`@("`J(&%N(%-13"!3150@8VQA=7-E
M("AW:71H;W5T('1H92!3150@:V5Y=V]R9"D@=VET:"!T:&4@=F%L=65S('!R
M;W!E<FQY"B`@("`@*B!Q=6]T960N("!&;W(@97AA;7!L92P@=&AE(&9O;&QO
M=VEN9SH*("`@("`J"B`@("`@*B`@("`@(&%R<F%Y*"=F;V\G(#T^(#$L"B`@
M("`@*B`@("`@("`@("`@("=B87(G(#T^("=H96QL;R<I"B`@("`@*@H@("`@
M("H@=V]U;&0@<F5S=6QT(&EN('1H92!F<F%G;65N=#H*("`@("`J"B`@("`@
M*B`@("`@(&9O;R`](#$L(&)A<B`]("=H96QL;R<*("`@("`J"B`@("`@*B!`
M<&%R86T@1$(@)&1B:"`@("`@("`@5&AE(%!%05(Z.D1"(&1A=&%B87-E(&]B
M:F5C="X*("`@("`J($!P87)A;2!A<G)A>2`D=F%L=65S("!4:&4@87)R87D@
M;V8@8V]L=6UN(#T^('9A;'5E('!A:7)S+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@4U%,(%-%5"!F<F%G;65N="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@=7!D871E5F%L=65S*"8D9&)H+"`D=F%L=65S*0H@("`@>PH@
M("`@("`@("1R970@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1V86QU
M97,@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@)')E=%M=(#T@
M)&ME>2`N("<@/2`G("X@*"1V86QU92`]/3T@;G5L;"`_("=.54Q,)R`Z("1D
M8F@M/G%U;W1E*"1V86QU92DI.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M:6UP;&]D92@G+"`G+"`D<F5T*3L*("`@('T*"B`@("`O*BH*("`@("`J($)U
M:6QD(&%N(%-13"!)3E-%4E0O5D%,5453(&-L875S92X*("`@("`J"B`@("`@
M*B!4:&ES(&9U;F-T:6]N('1A:V5S(&%N(&%R<F%Y(&EN('1H92!F;W)M(&-O
M;'5M;B`]/B!V86QU92!A;F0@<F5T=7)N<PH@("`@("H@86X@4U%,(&9R86=M
M96YT('-P96-I9GEI;F<@=&AE(&-O;'5M;B!N86UE<R!A;F0@:6YS97)T('9A
M;'5E<RP@=VET:`H@("`@("H@=&AE('9A;'5E<R!P<F]P97)L>2!Q=6]T960N
M("!&;W(@97AA;7!L92P@=&AE(&9O;&QO=VEN9SH*("`@("`J"B`@("`@*B`@
M("`@(&%R<F%Y*"=F;V\G(#T^(#$L"B`@("`@*B`@("`@("`@("`@("=B87(G
M(#T^("=H96QL;R<I"B`@("`@*@H@("`@("H@=V]U;&0@<F5S=6QT(&EN('1H
M92!F<F%G;65N=#H*("`@("`J"B`@("`@*B`@("`@("@@9F]O+"!B87(@*2!6
M04Q515,@*"`Q+"`G:&5L;&\G("D*("`@("`J"B`@("`@*B!`<&%R86T@1$(@
M)&1B:"`@("`@("`@5&AE(%!%05(Z.D1"(&1A=&%B87-E(&]B:F5C="X*("`@
M("`J($!P87)A;2!A<G)A>2`D=F%L=65S("!4:&4@87)R87D@;V8@8V]L=6UN
M(#T^('9A;'5E('!A:7)S+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@4U%,(&9R86=M96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!I;G-E
M<G1686QU97,H)B1D8F@L("1V86QU97,I"B`@("!["B`@("`@("`@)&-O;'5M
M;G,@/2!A<G)A>2@I.PH@("`@("`@("1V86QS(#T@87)R87DH*3L*("`@("`@
M("!F;W)E86-H("@D=F%L=65S(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@
M("`@("`@("1C;VQU;6YS6UT@/2`D:V5Y.PH@("`@("`@("`@("`D=F%L<UM=
M(#T@)'9A;'5E(#T]/2!N=6QL(#\@)TY53$PG(#H@)&1B:"T^<75O=&4H)'9A
M;'5E*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("<H("<@+B!I;7!L;V1E
M*"<L("<L("1C;VQU;6YS*2`N("<@*2!604Q515,@*"`G("X@:6UP;&]D92@G
M+"`G+"`D=F%L<RD@+B`G("DG.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92]3=')I;F<N<&AP````````````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`T-#<Q-B`Q,#4Q-30S,S<T,"`P,C$S,S<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"B1'3$]"
M04Q36R=?2$]21$5?4U1224Y'7T-(05)3150G72`]("=I<V\M.#@U.2TQ)SL*
M"B\J*@H@*B!4:&4@4W1R:6YG.CH@8VQA<W,@<')O=FED97,@<W1A=&EC(&UE
M=&AO9',@9F]R(&-H87)S970@86YD(&QO8V%L92!S869E"B`J('-T<FEN9R!M
M86YI<'5L871I;VXN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U5T:6PO4W1R
M:6YG+G!H<"QV(#$N-#,N-BXQ,R`R,#`V+S`S+S$S(#`Y.C0V.C`W(&IA;B!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($IA;B!38VAN96ED97(@
M/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*
M86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D
M92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?571I;`H@*B\*8VQA<W,@4W1R:6YG
M('L*"B`@("`O*BH*("`@("`J($-A8VAE<R!T:&4@<F5S=6QT(&]F(&5X=&5N
M<VEO;E]L;V%D960H*2!C86QL<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1E>'0@(%1H92!E>'1E;G-I;VX@;F%M92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@($ES('1H92!E>'1E;G-I;VX@;&]A9&5D/PH@("`@
M("H*("`@("`J($!S964@571I;#HZ97AT96YS:6]N17AI<W1S*"D*("`@("`J
M+PH@("`@9G5N8W1I;VX@97AT96YS:6]N17AI<W1S*"1E>'0I"B`@("!["B`@
M("`@("`@<W1A=&EC("1C86-H92`](&%R<F%Y*"D["@H@("`@("`@(&EF("@A
M:7-S970H)&-A8VAE6R1E>'1=*2D@>PH@("`@("`@("`@("`D8V%C:&5;)&5X
M=%T@/2!E>'1E;G-I;VY?;&]A9&5D*"1E>'0I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1C86-H95LD97AT73L*("`@('T*"B`@("`O*BH*("`@("`J
M(%-E=',@82!D969A=6QT(&-H87)S970@=&AA="!T:&4@4W1R:6YG.CH@;65T
M:&]D<R!W:6QL('5S92!I9B!N;VYE(&ES"B`@("`@*B!E>'!L:6-I=&5L>2!S
M<&5C:69I960N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VAA<G-E
M="`@5&AE(&-H87)S970@=&\@=7-E(&%S('1H92!D969A=6QT(&]N92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V5T1&5F875L=$-H87)S970H)&-H87)S970I
M"B`@("!["B`@("`@("`@)$=,3T)!3%-;)U](3U)$15]35%))3D=?0TA!4E-%
M5"==(#T@)&-H87)S970["B`@("`@("`@:68@*%-T<FEN9SHZ97AT96YS:6]N
M17AI<W1S*"=M8G-T<FEN9R<I("8F"B`@("`@("`@("`@(&9U;F-T:6]N7V5X
M:7-T<R@G;6)?<F5G97A?96YC;V1I;F<G*2D@>PH@("`@("`@("`@("!`;6)?
M<F5G97A?96YC;V1I;F<H)&-H87)S970I.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($-O;G9E<G1S(&$@<W1R:6YG(&9R;VT@;VYE(&-H87)S
M970@=&\@86YO=&AE<BX*("`@("`J"B`@("`@*B!7;W)K<R!O;FQY(&EF(&5I
M=&AE<B!T:&4@:6-O;G8@;W(@=&AE(&UB<W1R:6YG(&5X=&5N<VEO;@H@("`@
M("H@87)E('!R97-E;G0@86YD(&)E<W0@:68@8F]T:"!A<F4@879A:6QA8FQE
M+@H@("`@("H@5&AE(&]R:6=I;F%L('-T<FEN9R!I<R!R971U<FYE9"!I9B!C
M;VYV97)S:6]N(&9A:6QE9"!O<B!N;VYE"B`@("`@*B!O9B!T:&4@97AT96YS
M:6]N<R!W97)E(&%V86EL86)L92X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX
M960@)&EN<'5T("!4:&4@9&%T82!T;R!B92!C;VYV97)T960N($EF("1I;G!U
M="!I<R!A;B!A;B!A<G)A>2P*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M('1H92!A<G)A>2=S('9A;'5E<R!G970@8V]N=F5R=&5D(')E8W5R<VEV96QY
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9G)O;2`@5&AE('-T<FEN9R=S(&-U
M<G)E;G0@8VAA<G-E="X*("`@("`J($!P87)A;2!S=')I;F<@)'1O("`@(%1H
M92!C:&%R<V5T('1O(&-O;G9E<G0@=&AE('-T<FEN9R!T;RX@268@;F]T"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("!S<&5C:69I960L('1H92!G;&]B
M86P@=F%R:6%B;&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("1?2$]2
M1$5?4U1224Y'7T-(05)3150@=VEL;"!B92!U<V5D+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@8V]N=F5R=&5D('-T<FEN9RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@8V]N=F5R=$-H87)S970H)&EN<'5T+"`D9G)O;2P@
M)'1O(#T@;G5L;"D*("`@('L*("`@("`@("`O*B!'970@=&AE('5S97(G<R!D
M969A=6QT(&-H87)A8W1E<B!S970@:68@;F]N92!P87-S960@:6XN("HO"B`@
M("`@("`@:68@*&ES7VYU;&PH)'1O*2D@>PH@("`@("`@("`@("`D=&\@/2`D
M1TQ/0D%,4ULG7TA/4D1%7U-44DE.1U]#2$%24T54)UT["B`@("`@("`@?0H*
M("`@("`@("`O*B!)9B!T:&4@9G)O;2!A;F0@=&\@8VAA<F%C=&5R('-E=',@
M87)E(&ED96YT:6-A;"P@<F5T=7)N(&YO=RX@*B\*("`@("`@("`D9G)O;2`]
M(%-T<FEN9SHZ;&]W97(H)&9R;VTI.PH@("`@("`@("1T;R`](%-T<FEN9SHZ
M;&]W97(H)'1O*3L*("`@("`@("!I9B`H)&9R;VT@/3T@)'1O*2!["B`@("`@
M("`@("`@(')E='5R;B`D:6YP=70["B`@("`@("`@?0H*("`@("`@("!I9B`H
M:7-?87)R87DH)&EN<'5T*2D@>PH@("`@("`@("`@("`D=&UP(#T@87)R87DH
M*3L*("`@("`@("`@("`@9F]R96%C:"`H)&EN<'5T(&%S("1K97D@/3X@)'9A
M;"D@>PH@("`@("`@("`@("`@("`@)'1M<%M3=')I;F<Z.E]C;VYV97)T0VAA
M<G-E="@D:V5Y+"`D9G)O;2P@)'1O*5T@/2!3=')I;F<Z.F-O;G9E<G1#:&%R
M<V5T*"1V86PL("1F<F]M+"`D=&\I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(')E='5R;B`D=&UP.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?;V)J
M96-T*"1I;G!U="DI('L*("`@("`@("`@("`@)'9A<G,@/2!G971?;V)J96-T
M7W9A<G,H)&EN<'5T*3L*("`@("`@("`@("`@9F]R96%C:"`H)'9A<G,@87,@
M)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@("`@("`D:6YP=70M/B1K97D@
M/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1V86PL("1F<F]M+"`D=&\I.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D:6YP=70["B`@("`@
M("`@?0H*("`@("`@("!I9B`H(6ES7W-T<FEN9R@D:6YP=70I*2!["B`@("`@
M("`@("`@(')E='5R;B`D:6YP=70["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@4W1R:6YG.CI?8V]N=F5R=$-H87)S970H)&EN<'5T+"`D9G)O;2P@)'1O
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($EN=&5R;F%L(&9U;F-T:6]N('5S
M960@=&\@9&\@8VAA<G-E="!C;VYV97)S:6]N+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D:6YP
M=70@(%-E92!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"DN"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1F<F]M("!3964@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@I
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&\@("`@4V5E(%-T<FEN9SHZ8V]N
M=F5R=$-H87)S970H*2X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE(&-O;G9E<G1E9"!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C
M;VYV97)T0VAA<G-E="@D:6YP=70L("1F<F]M+"`D=&\I"B`@("!["B`@("`@
M("`@)&]U='!U="`]("<G.PH*("`@("`@("`O*B!5<V4@=71F.%];96Y\9&5=
M8V]D92@I(&EF('!O<W-I8FQE+B`J+PH@("`@("`@("1F<F]M7V-H96-K(#T@
M*"@D9G)O;2`]/2`G:7-O+3@X-3DM,2<I('Q\("@D9G)O;2`]/2`G=7,M87-C
M:6DG*2D["B`@("`@("`@:68@*"1F<F]M7V-H96-K("8F("@D=&\@/3T@)W5T
M9BTX)RDI('L*("`@("`@("`@("`@<F5T=7)N('5T9CA?96YC;V1E*"1I;G!U
M="D["B`@("`@("`@?0H*("`@("`@("`D=&]?8VAE8VL@/2`H*"1T;R`]/2`G
M:7-O+3@X-3DM,2<I('Q\("@D=&\@/3T@)W5S+6%S8VEI)RDI.PH@("`@("`@
M(&EF("@H)&9R;VT@/3T@)W5T9BTX)RD@)B8@)'1O7V-H96-K*2!["B`@("`@
M("`@("`@(')E='5R;B!U=&8X7V1E8V]D92@D:6YP=70I.PH@("`@("`@('T*
M"B`@("`@("`@+RH@1FER<W0@=')Y(&EC;VYV('=I=&@@=')A;G-L:71E<F%T
M:6]N+B`J+PH@("`@("`@(&EF("@H)&9R;VT@(3T@)W5T9C<M:6UA<"<I("8F
M"B`@("`@("`@("`@("@D=&\@(3T@)W5T9C<M:6UA<"<I("8F"B`@("`@("`@
M("`@(%-T<FEN9SHZ97AT96YS:6]N17AI<W1S*"=I8V]N=B<I*2!["B`@("`@
M("`@("`@("\J(%=E(&YE960@=&\@=&%C:R!A;B!E>'1R82!C:&%R86-T97(@
M=&5M<&]R87)I;'D@8F5C875S90H@("`@("`@("`@("`@*B!O9B!A(&)U9R!I
M;B!I8V]N=B@I(&EF('1H92!L87-T(&-H87)A8W1E<B!I<R!N;W0@82`W"B`@
M("`@("`@("`@("`J(&)I="!!4T-)22!C:&%R86-T97(N("HO"B`@("`@("`@
M("`@(&EN:5]S970H)W1R86-K7V5R<F]R<R<L(#$I.PH@("`@("`@("`@("`D
M;W5T<'5T(#T@0&EC;VYV*"1F<F]M+"`D=&\@+B`G+R]44D%.4TQ)5"<L("1I
M;G!U="`N("=X)RD["B`@("`@("`@("`@("1O=71P=70@/2`H:7-S970H)'!H
M<%]E<G)O<FUS9RDI(#\@9F%L<V4@.B`@4W1R:6YG.CIS=6)S='(H)&]U='!U
M="P@,"P@+3$L("1T;RD["B`@("`@("`@("`@(&EN:5]R97-T;W)E*"=T<F%C
M:U]E<G)O<G,G*3L*("`@("`@("!]"@H@("`@("`@("\J($YE>'0@=')Y(&UB
M<W1R:6YG+B`J+PH@("`@("`@(&EF("@A)&]U='!U="`F)B!3=')I;F<Z.F5X
M=&5N<VEO;D5X:7-T<R@G;6)S=')I;F<G*2D@>PH@("`@("`@("`@("`D;W5T
M<'5T(#T@0&UB7V-O;G9E<G1?96YC;V1I;F<H)&EN<'5T+"`D=&\L("1F<F]M
M*3L*("`@("`@("!]"@H@("`@("`@("\J($%T(&QA<W0@=')Y(&EM87!?=71F
M-U];96Y\9&5=8V]D92!I9B!A<'!R;W!R:6%T92X@*B\*("`@("`@("!I9B`H
M(21O=71P=70@)B8@4W1R:6YG.CIE>'1E;G-I;VY%>&ES=',H)VEM87`G*2D@
M>PH@("`@("`@("`@("!I9B`H)&9R;VU?8VAE8VL@)B8@*"1T;R`]/2`G=71F
M-RUI;6%P)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B!`:6UA<%]U=&8W
M7V5N8V]D92@D:6YP=70I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("@H)&9R;VT@/3T@)W5T9C<M:6UA<"<I("8F("1T;U]C:&5C:RD@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N($!I;6%P7W5T9C=?9&5C;V1E*"1I;G!U="D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`H(21O
M=71P=70I(#\@)&EN<'5T(#H@)&]U='!U=#L*("`@('T*"B`@("`O*BH*("`@
M("`J($UA:V5S(&$@<W1R:6YG(&QO=V5R8V%S92X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`D<W1R:6YG("`@5&AE('-T<FEN9R!T;R!B92!C;VYV
M97)T960N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;&]C86QE("`@268@=')U
M92!T:&4@<W1R:6YG('=I;&P@8F4@8V]N=F5R=&5D(&)A<V5D(&]N(&$*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("!G:79E;B!C:&%R<V5T+"!L
M;V-A;&4@:6YD97!E;F1E;G0@96QS92X*("`@("`J($!P87)A;2!S=')I;F<@
M("1C:&%R<V5T("!)9B`D;&]C86QE(&ES('1R=64L('1H92!C:&%R<V5T('1O
M('5S92!W:&5N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N
M=F5R=&EN9RX@268@;F]T('!R;W9I9&5D('1H92!C=7)R96YT(&-H87)S970N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!S=')I;F<@=VET
M:"!L;W=E<F-A<V4@8VAA<F%C=&5R<PH@("`@("HO"B`@("!F=6YC=&EO;B!L
M;W=E<B@D<W1R:6YG+"`D;&]C86QE(#T@9F%L<V4L("1C:&%R<V5T(#T@;G5L
M;"D*("`@('L*("`@("`@("!S=&%T:6,@)&QO=V5R<SL*"B`@("`@("`@:68@
M*"1L;V-A;&4I('L*("`@("`@("`@("`@+RH@5&AE(&5X:7-T96YC92!O9B!M
M8E]S=')T;VQO=V5R*"D@9&5P96YD<R!O;B!T:&4@<&QA=&9O<FTN("HO"B`@
M("`@("`@("`@(&EF("A3=')I;F<Z.F5X=&5N<VEO;D5X:7-T<R@G;6)S=')I
M;F<G*2`F)@H@("`@("`@("`@("`@("`@9G5N8W1I;VY?97AI<W1S*"=M8E]S
M=')T;VQO=V5R)RDI('L*("`@("`@("`@("`@("`@(&EF("AI<U]N=6QL*"1C
M:&%R<V5T*2D@>PH@("`@("`@("`@("`@("`@("`@("1C:&%R<V5T(#T@)$=,
M3T)!3%-;)U](3U)$15]35%))3D=?0TA!4E-%5"==.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)')E="`]($!M8E]S=')T;VQO=V5R*"1S
M=')I;F<L("1C:&%R<V5T*3L*("`@("`@("`@("`@("`@(&EF("@A96UP='DH
M)')E="DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E=#L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U
M<FX@<W1R=&]L;W=E<B@D<W1R:6YG*3L*("`@("`@("!]"@H@("`@("`@(&EF
M("@A:7-S970H)&QO=V5R<RDI('L*("`@("`@("`@("`@)&QO=V5R<R`](&%R
M<F%Y*"D["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)&QO=V5R<ULD
M<W1R:6YG72DI('L*("`@("`@("`@("`@)&QA;F=U86=E(#T@<V5T;&]C86QE
M*$Q#7T-465!%+"`P*3L*("`@("`@("`@("`@<V5T;&]C86QE*$Q#7T-465!%
M+"`G96Y?55,G*3L*("`@("`@("`@("`@)&QO=V5R<ULD<W1R:6YG72`]('-T
M<G1O;&]W97(H)'-T<FEN9RD["B`@("`@("`@("`@('-E=&QO8V%L92A,0U]#
M5%E012P@)&QA;F=U86=E*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M;&]W97)S6R1S=')I;F==.PH@("`@?0H*("`@("\J*@H@("`@("H@36%K97,@
M82!S=')I;F<@=7!P97)C87-E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@("1S=')I;F<@("!4:&4@<W1R:6YG('1O(&)E(&-O;G9E<G1E9"X*("`@
M("`J($!P87)A;2!B;V]L96%N("1L;V-A;&4@("!)9B!T<G5E('1H92!S=')I
M;F<@=VEL;"!B92!C;VYV97)T960@8F%S960@;VX@80H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@(&=I=F5N(&-H87)S970L(&QO8V%L92!I;F1E
M<&5N9&5N="!E;'-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&-H87)S970@
M($EF("1L;V-A;&4@:7,@=')U92P@=&AE(&-H87)S970@=&\@=7-E('=H96X*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYV97)T:6YG+B!)
M9B!N;W0@<')O=FED960@=&AE(&-U<G)E;G0@8VAA<G-E="X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('-T<FEN9R!W:71H('5P<&5R8V%S
M92!C:&%R86-T97)S"B`@("`@*B\*("`@(&9U;F-T:6]N('5P<&5R*"1S=')I
M;F<L("1L;V-A;&4@/2!F86QS92P@)&-H87)S970@/2!N=6QL*0H@("`@>PH@
M("`@("`@('-T871I8R`D=7!P97)S.PH*("`@("`@("!I9B`H)&QO8V%L92D@
M>PH@("`@("`@("`@("`O*B!4:&4@97AI<W1E;F-E(&]F(&UB7W-T<G1O=7!P
M97(H*2!D97!E;F1S(&]N('1H90H@("`@("`@("`@("`@*B!P;&%T9F]R;2X@
M*B\*("`@("`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G;6)?<W1R=&]U
M<'!E<B<I*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?;G5L;"@D8VAA<G-E
M="DI('L*("`@("`@("`@("`@("`@("`@("`D8VAA<G-E="`]("1'3$]"04Q3
M6R=?2$]21$5?4U1224Y'7T-(05)3150G73L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("1R970@/2!`;6)?<W1R=&]U<'!E<B@D<W1R:6YG
M+"`D8VAA<G-E="D["B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1R970I
M*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R970["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N('-T
M<G1O=7!P97(H)'-T<FEN9RD["B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES
M<V5T*"1U<'!E<G,I*2!["B`@("`@("`@("`@("1U<'!E<G,@/2!A<G)A>2@I
M.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1U<'!E<G-;)'-T<FEN
M9UTI*2!["B`@("`@("`@("`@("1L86YG=6%G92`]('-E=&QO8V%L92A,0U]#
M5%E012P@,"D["B`@("`@("`@("`@('-E=&QO8V%L92A,0U]#5%E012P@)V5N
M7U53)RD["B`@("`@("`@("`@("1U<'!E<G-;)'-T<FEN9UT@/2!S=')T;W5P
M<&5R*"1S=')I;F<I.PH@("`@("`@("`@("!S971L;V-A;&4H3$-?0U194$4L
M("1L86YG=6%G92D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'5P<&5R
M<ULD<W1R:6YG73L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!S
M=')I;F<@=VET:"!T:&4@9FER<W0@;&5T=&5R(&-A<&ET86QI>F5D(&EF(&ET
M(&ES"B`@("`@*B!A;'!H86)E=&EC+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@("1S=')I;F<@("!4:&4@<W1R:6YG('1O(&)E(&-A<&ET86QI>F5D
M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&QO8V%L92`@($EF('1R=64@=&AE
M('-T<FEN9R!W:6QL(&)E(&-O;G9E<G1E9"!B87-E9"!O;B!A"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@9VEV96X@8VAA<G-E="P@;&]C86QE
M(&EN9&5P96YD96YT(&5L<V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D8VAA
M<G-E="`@5&AE(&-H87)S970@=&\@=7-E+"!D969A=6QT<R!T;R!C=7)R96YT
M(&-H87)S970N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C
M87!I=&%L:7IE9"!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N('5C9FER
M<W0H)'-T<FEN9RP@)&QO8V%L92`](&9A;'-E+"`D8VAA<G-E="`](&YU;&PI
M"B`@("!["B`@("`@("`@:68@*"1L;V-A;&4I('L*("`@("`@("`@("`@)&9I
M<G-T(#T@4W1R:6YG.CIS=6)S='(H)'-T<FEN9RP@,"P@,2P@)&-H87)S970I
M.PH@("`@("`@("`@("!I9B`H4W1R:6YG.CII<T%L<&AA*"1F:7)S="P@)&-H
M87)S970I*2!["B`@("`@("`@("`@("`@("`D<W1R:6YG(#T@4W1R:6YG.CIU
M<'!E<B@D9FER<W0L('1R=64L("1C:&%R<V5T*2`N(%-T<FEN9SHZ<W5B<W1R
M*"1S=')I;F<L(#$L(&YU;&PL("1C:&%R<V5T*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1S=')I;F<@/2!3=')I;F<Z
M.G5P<&5R*'-U8G-T<B@D<W1R:6YG+"`P+"`Q*2P@9F%L<V4I("X@<W5B<W1R
M*"1S=')I;F<L(#$I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'-T<FEN
M9SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@<&%R="!O9B!A('-T
M<FEN9RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S=')I;F<@("!4
M:&4@<W1R:6YG('1O(&)E(&-O;G9E<G1E9"X*("`@("`J($!P87)A;2!I;G1E
M9V5R("1S=&%R="`@(%1H92!P87)T)W,@<W1A<G0@<&]S:71I;VXL('IE<F\@
M8F%S960N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;&5N9W1H("!4:&4@<&%R
M="=S(&QE;F=T:"X*("`@("`J($!P87)A;2!S=')I;F<@)&-H87)S970@(%1H
M92!C:&%R<V5T('1O('5S92!W:&5N(&-A;&-U;&%T:6YG('1H92!P87)T)W,*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('!O<VET:6]N(&%N9"!L
M96YG=&@L(&1E9F%U;'1S('1O(&-U<G)E;G0*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@(&-H87)S970N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!S=')I;F<G<R!P87)T+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!S=6)S='(H)'-T<FEN9RP@)'-T87)T+"`D;&5N9W1H(#T@;G5L;"P@)&-H
M87)S970@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("A3=')I;F<Z.F5X=&5N
M<VEO;D5X:7-T<R@G;6)S=')I;F<G*2D@>PH@("`@("`@("`@("!I9B`H:7-?
M;G5L;"@D8VAA<G-E="DI('L*("`@("`@("`@("`@("`@("1C:&%R<V5T(#T@
M)$=,3T)!3%-;)U](3U)$15]35%))3D=?0TA!4E-%5"==.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&EF("AI<U]N=6QL*"1L96YG=&@I*2!["B`@("`@
M("`@("`@("`@("`D;&5N9W1H(#T@4W1R:6YG.CIL96YG=&@H)'-T<FEN9RP@
M)&-H87)S970I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1R970@/2!`
M;6)?<W5B<W1R*"1S=')I;F<L("1S=&%R="P@)&QE;F=T:"P@)&-H87)S970I
M.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1R970I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)')E=#L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M("`@("!I9B`H:7-?;G5L;"@D;&5N9W1H*2D@>PH@("`@("`@("`@("`D;&5N
M9W1H(#T@4W1R:6YG.CIL96YG=&@H)'-T<FEN9RD["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B!S=6)S='(H)'-T<FEN9RP@)'-T87)T+"`D;&5N9W1H*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-H87)A8W1E<B`H
M;F]T(&)Y=&4I(&QE;F=T:"!O9B!A('-T<FEN9RX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1S=')I;F<@(%1H92!S=')I;F<@=&\@<F5T=7)N('1H
M92!L96YG=&@@;V8N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C:&%R<V5T(%1H
M92!C:&%R<V5T('1O('5S92!W:&5N(&-A;&-U;&%T:6YG('1H92!S=')I;F<G
M<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!L96YG=&@N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!S=')I;F<G<R!P87)T+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!L96YG=&@H)'-T<FEN9RP@)&-H87)S970@
M/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1C:&%R<V5T*2D@
M>PH@("`@("`@("`@("`D8VAA<G-E="`]("1'3$]"04Q36R=?2$]21$5?4U12
M24Y'7T-(05)3150G73L*("`@("`@("!]"B`@("`@("`@)&-H87)S970@/2!3
M=')I;F<Z.FQO=V5R*"1C:&%R<V5T*3L*("`@("`@("!I9B`H)&-H87)S970@
M/3T@)W5T9BTX)R!\?"`D8VAA<G-E="`]/2`G=71F."<I('L*("`@("`@("`@
M("`@<F5T=7)N('-T<FQE;BAU=&8X7V1E8V]D92@D<W1R:6YG*2D["B`@("`@
M("`@?0H@("`@("`@(&EF("A3=')I;F<Z.F5X=&5N<VEO;D5X:7-T<R@G;6)S
M=')I;F<G*2D@>PH@("`@("`@("`@("`D<F5T(#T@0&UB7W-T<FQE;B@D<W1R
M:6YG+"`D8VAA<G-E="D["B`@("`@("`@("`@(&EF("@A96UP='DH)')E="DI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5T.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B!S=')L96XH)'-T<FEN9RD["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!N=6UE<FEC('!O<VET
M:6]N(&]F('1H92!F:7)S="!O8V-U<G)E;F-E(&]F("1N965D;&4*("`@("`J
M(&EN('1H92`D:&%Y<W1A8VL@<W1R:6YG+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&AA>7-T86-K("!4:&4@<W1R:6YG('1O('-E87)C:"!T:')O
M=6=H+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5E9&QE("`@(%1H92!S=')I
M;F<@=&\@<V5A<F-H(&9O<BX*("`@("`J($!P87)A;2!I;G1E9V5R("1O9F9S
M970@("!!;&QO=W,@=&\@<W!E8VEF>2!W:&EC:"!C:&%R86-T97(@:6X@:&%Y
M<W1A8VL*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!T;R!S=&%R
M="!S96%R8VAI;F<N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C:&%R<V5T("`@
M5&AE(&-H87)S970@=&\@=7-E('=H96X@<V5A<F-H:6YG(&9O<B!T:&4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`D;F5E9&QE('-T<FEN9RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!P;W-I=&EO;B!O
M9B!F:7)S="!O8V-U<G)E;F-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!P;W,H
M)&AA>7-T86-K+"`D;F5E9&QE+"`D;V9F<V5T(#T@,"P@)&-H87)S970@/2!N
M=6QL*0H@("`@>PH@("`@("`@(&EF("A3=')I;F<Z.F5X=&5N<VEO;D5X:7-T
M<R@G;6)S=')I;F<G*2D@>PH@("`@("`@("`@("!I9B`H:7-?;G5L;"@D8VAA
M<G-E="DI('L*("`@("`@("`@("`@("`@("1C:&%R<V5T(#T@)$=,3T)!3%-;
M)U](3U)$15]35%))3D=?0TA!4E-%5"==.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&EN:5]S970H)W1R86-K7V5R<F]R<R<L(#$I.PH@("`@("`@("`@
M("`D<F5T(#T@0&UB7W-T<G!O<R@D:&%Y<W1A8VLL("1N965D;&4L("1O9F9S
M970L("1C:&%R<V5T*3L*("`@("`@("`@("`@:6YI7W)E<W1O<F4H)W1R86-K
M7V5R<F]R<R<I.PH@("`@("`@("`@("!I9B`H(6ES<V5T*"1P:'!?97)R;W)M
M<V<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E=#L*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@<W1R<&]S*"1H87ES=&%C
M:RP@)&YE961L92P@)&]F9G-E="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS(&$@<W1R:6YG('!A9&1E9"!T;R!A(&-E<G1A:6X@;&5N9W1H('=I
M=&@@86YO=&AE<B!S=')I;F<N"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@
M8F5H879E<R!E>&%C=&QY(&QI:V4@<W1R7W!A9"!B=70@:7,@;75L=&EB>71E
M('-A9F4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:6YP=70@("`@
M5&AE('-T<FEN9R!T;R!B92!P861D960N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D;&5N9W1H("!4:&4@;&5N9W1H(&]F('1H92!R97-U;'1I;F<@<W1R:6YG
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%D("`@("`@5&AE('-T<FEN9R!T
M;R!P860@=&AE(&EN<'5T('-T<FEN9R!W:71H+B!-=7-T"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("!B92!I;B!T:&4@<V%M92!C:&%R<V5T(&QI
M:V4@=&AE(&EN<'5T('-T<FEN9RX*("`@("`J($!P87)A;2!C;VYS="`D='EP
M92`@("`@(%1H92!P861D:6YG('1Y<&4N($]N92!O9B!35%)?4$%$7TQ%1E0L
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!35%)?4$%$7U))1TA4
M+"!O<B!35%)?4$%$7T)/5$@N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C:&%R
M<V5T("!4:&4@8VAA<G-E="!O9B!T:&4@:6YP=70@86YD('1H92!P861D:6YG
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!S=')I;F=S+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<&%D9&5D('-T<FEN9RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@<&%D*"1I;G!U="P@)&QE;F=T:"P@)'!A
M9"`]("<@)RP@)'1Y<&4@/2!35%)?4$%$7U))1TA4+`H@("`@("`@("`@("`@
M("`@("1C:&%R<V5T(#T@;G5L;"D*("`@('L*("`@("`@("`D;6)?;&5N9W1H
M(#T@4W1R:6YG.CIL96YG=&@H)&EN<'5T+"`D8VAA<G-E="D["B`@("`@("`@
M)'-B7VQE;F=T:"`]('-T<FQE;B@D:6YP=70I.PH@("`@("`@("1P861?;&5N
M9W1H(#T@4W1R:6YG.CIL96YG=&@H)'!A9"P@)&-H87)S970I.PH*("`@("`@
M("`O*B!2971U<FX@:68@=V4@86QR96%D>2!H879E('1H92!L96YG=&@N("HO
M"B`@("`@("`@:68@*"1M8E]L96YG=&@@/CT@)&QE;F=T:"D@>PH@("`@("`@
M("`@("!R971U<FX@)&EN<'5T.PH@("`@("`@('T*"B`@("`@("`@+RH@4VAO
M<G1C=70@9F]R('-I;F=L92!B>71E('-T<FEN9W,N("HO"B`@("`@("`@:68@
M*"1M8E]L96YG=&@@/3T@)'-B7VQE;F=T:"`F)B`D<&%D7VQE;F=T:"`]/2!S
M=')L96XH)'!A9"DI('L*("`@("`@("`@("`@<F5T=7)N('-T<E]P860H)&EN
M<'5T+"`D;&5N9W1H+"`D<&%D+"`D='EP92D["B`@("`@("`@?0H*("`@("`@
M("!S=VET8V@@*"1T>7!E*2!["B`@("`@("`@8V%S92!35%)?4$%$7TQ%1E0Z
M"B`@("`@("`@("`@("1L969T(#T@)&QE;F=T:"`M("1M8E]L96YG=&@["B`@
M("`@("`@("`@("1O=71P=70@/2!3=')I;F<Z.G-U8G-T<BAS=')?<F5P96%T
M*"1P860L(&-E:6PH)&QE9G0@+R`D<&%D7VQE;F=T:"DI+"`P+"`D;&5F="P@
M)&-H87)S970I("X@)&EN<'5T.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("!C87-E(%-44E]0041?0D]42#H*("`@("`@("`@("`@)&QE9G0@/2!F;&]O
M<B@H)&QE;F=T:"`M("1M8E]L96YG=&@I("\@,BD["B`@("`@("`@("`@("1R
M:6=H="`](&-E:6PH*"1L96YG=&@@+2`D;6)?;&5N9W1H*2`O(#(I.PH@("`@
M("`@("`@("`D;W5T<'5T(#T@4W1R:6YG.CIS=6)S='(H<W1R7W)E<&5A="@D
M<&%D+"!C96EL*"1L969T("\@)'!A9%]L96YG=&@I*2P@,"P@)&QE9G0L("1C
M:&%R<V5T*2`N"B`@("`@("`@("`@("`@("`D:6YP=70@+@H@("`@("`@("`@
M("`@("`@4W1R:6YG.CIS=6)S='(H<W1R7W)E<&5A="@D<&%D+"!C96EL*"1R
M:6=H="`O("1P861?;&5N9W1H*2DL(#`L("1R:6=H="P@)&-H87)S970I.PH@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("!C87-E(%-44E]0041?4DE'2%0Z
M"B`@("`@("`@("`@("1R:6=H="`]("1L96YG=&@@+2`D;6)?;&5N9W1H.PH@
M("`@("`@("`@("`D;W5T<'5T(#T@)&EN<'5T("X@4W1R:6YG.CIS=6)S='(H
M<W1R7W)E<&5A="@D<&%D+"!C96EL*"1R:6=H="`O("1P861?;&5N9W1H*2DL
M(#`L("1R:6=H="P@)&-H87)S970I.PH@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D;W5T<'5T.PH@("`@?0H*("`@("\J
M*@H@("`@("H@5W)A<',@=&AE('1E>'0@;V8@82!M97-S86=E+@H@("`@("H*
M("`@("`J($!T;V1O($UA:V4@;75L=&EB>71E+7-A=F4N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=&5X="`@("`@("`@4W1R:6YG(&-O;G1A:6YI
M;F<@=&AE('1E>'0@=&\@=W)A<"X*("`@("`J($!P87)A;2!I;G1E9V5R("1L
M96YG=&@@("`@(%=R87`@)'1E>'0@870@=&AI<R!N=6UB97(@;V8@8VAA<F%C
M=&5R<RX*("`@("`J($!P87)A;2!S=')I;F<@)&)R96%K7V-H87(@($-H87)A
M8W1E<BAS*2!T;R!U<V4@=VAE;B!B<F5A:VEN9R!L:6YE<RX*("`@("`J($!P
M87)A;2!S=')I;F<@)&-H87)S970@("`@($-H87)A8W1E<B!S970@=&\@=7-E
M('=H96X@8G)E86MI;F<@;&EN97,N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M<75O=&4@("`@("!)9VYO<F4@;&EN97,@=&AA="!A<F4@=W)A<'!E9"!W:71H
M('1H92`G/B<*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-H
M87)A8W1E<B`H4D9#(#(V-#8I/R!)9B!T<G5E+"!W92!D;VXG=`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5M;W9E(&%N>2!P861D:6YG
M('=H:71E<W!A8V4@870@=&AE(&5N9"!O9@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@=&AE('-T<FEN9RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@4W1R:6YG(&-O;G1A:6YI;F<@=&AE('=R87!P960@=&5X
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@=W)A<"@D=&5X="P@)&QE;F=T:"`]
M(#@P+"`D8G)E86M?8VAA<B`](")<;B(L("1C:&%R<V5T(#T@;G5L;"P*("`@
M("`@("`@("`@("`@("`@)'%U;W1E(#T@9F%L<V4I"B`@("!["B`@("`@("`@
M)'!A<F%G<F%P:',@/2!A<G)A>2@I.PH*("`@("`@("!F;W)E86-H("AP<F5G
M7W-P;&ET*"<O7'(_7&XO)RP@)'1E>'0I(&%S("1I;G!U="D@>PH@("`@("`@
M("`@("!I9B`H)'%U;W1E("8F("AS=')P;W,H)&EN<'5T+"`G/B<I(#T]/2`P
M*2D@>PH@("`@("`@("`@("`@("`@)&QI;F4@/2`D:6YP=70["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O*B!792!N965D('1O(&AA
M;F1L92!T:&4@57-E;F5T+7-T>6QE('-I9VYA='5R92!L:6YE"B`@("`@("`@
M("`@("`@("`@*B!S97!A<F%T96QY.R!S:6YC92!T:&4@<W!A8V4@869T97(@
M=&AE('1W;R!D87-H97,@:7,*("`@("`@("`@("`@("`@("`J(%)%455)4D5$
M+"!W92!D;VXG="!W86YT('1O('1R:6T@=&AE(&QI;F4N("HO"B`@("`@("`@
M("`@("`@("!I9B`H)&EN<'5T("$]("<M+2`G*2!["B`@("`@("`@("`@("`@
M("`@("`@)&EN<'5T(#T@<G1R:6TH)&EN<'5T*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("1L:6YE(#T@=V]R9'=R87`H)&EN<'5T+"`D
M;&5N9W1H+"`D8G)E86M?8VAA<BD["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1P87)A9W)A<&AS6UT@/2`D;&EN93L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!I;7!L;V1E*"1B<F5A:U]C:&%R+"`D<&%R86=R87!H<RD["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1R=64@:68@=&AE(&5V97)Y
M(&-H87)A8W1E<B!I;B!T:&4@<&%R86UE=&5R(&ES(&%N"B`@("`@*B!A;'!H
M86)E=&EC(&-H87)A8W1E<BX@5&AI<R!M971H;V0@9&]E<VXG="!W;W)K('=I
M=&@@86YY(&-H87)S970*("`@("`J(&]T:&5R('1H86X@=&AE(&-U<G)E;G0@
M8VAA<G-E="!Y970N"B`@("`@*@H@("`@("H@0'!A<F%M("1S=')I;F<@("!4
M:&4@<W1R:6YG('1O('1E<W0N"B`@("`@*B!`<&%R86T@)&-H87)S970@(%1H
M92!C:&%R<V5T('1O('5S92!W:&5N('1E<W1I;F<@=&AE('-T<FEN9RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE('!A<F%M
M971E<B!W87,@86QP:&%B971I8R!O;FQY+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!I<T%L<&AA*"1S=')I;F<L("1C:&%R<V5T(#T@;G5L;"D*("`@('L*("`@
M("`@("!I9B`H4W1R:6YG.CIE>'1E;G-I;VY%>&ES=',H)VUB<W1R:6YG)RDI
M('L*("`@("`@("`@("`@)&]L9%]C:&%R<V5T(#T@;6)?<F5G97A?96YC;V1I
M;F<H*3L*("`@("`@("`@("`@:68@*"1C:&%R<V5T("$]("1O;&1?8VAA<G-E
M="D@>PH@("`@("`@("`@("`@("`@0&UB7W)E9V5X7V5N8V]D:6YG*"1C:&%R
M<V5T*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D86QP:&$@/2`A;6)?
M97)E9U]M871C:"@G6UY;.F%L<&AA.EU=)RP@)'-T<FEN9RD["B`@("`@("`@
M("`@(&EF("@D8VAA<G-E="`A/2`D;VQD7V-H87)S970I('L*("`@("`@("`@
M("`@("`@($!M8E]R96=E>%]E;F-O9&EN9R@D;VQD7V-H87)S970I.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D86QP:&$["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@8W1Y<&5?86QP:&$H)'-T<FEN9RD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1R=64@:68@979E<GD@8VAA<F%C
M=&5R(&EN('1H92!P87)A;65T97(@:7,@82!L;W=E<F-A<V4*("`@("`J(&QE
M='1E<B!I;B!T:&4@8W5R<F5N="!L;V-A;&4N"B`@("`@*@H@("`@("H@0'!A
M<F%M("1S=')I;F<@("!4:&4@<W1R:6YG('1O('1E<W0N"B`@("`@*B!`<&%R
M86T@)&-H87)S970@(%1H92!C:&%R<V5T('1O('5S92!W:&5N('1E<W1I;F<@
M=&AE('-T<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R
M=64@:68@=&AE('!A<F%M971E<B!W87,@;&]W97)C87-E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!I<TQO=V5R*"1S=')I;F<L("1C:&%R<V5T(#T@;G5L;"D*
M("`@('L*("`@("`@("!R971U<FX@*"A3=')I;F<Z.FQO=V5R*"1S=')I;F<L
M('1R=64L("1C:&%R<V5T*2`]/3T@)'-T<FEN9RD@)B8*("`@("`@("`@("`@
M("`@(%-T<FEN9SHZ:7-!;'!H82@D<W1R:6YG+"`D8VAA<G-E="DI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T<G5E(&EF(&5V97)Y(&-H87)A
M8W1E<B!I;B!T:&4@<&%R86UE=&5R(&ES(&%N"B`@("`@*B!U<'!E<F-A<V4@
M;&5T=&5R(&EN('1H92!C=7)R96YT(&QO8V%L92X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1S=')I;F<@("!4:&4@<W1R:6YG('1O('1E<W0N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1C:&%R<V5T("!4:&4@8VAA<G-E="!T;R!U
M<V4@=VAE;B!T97-T:6YG('1H92!S=')I;F<N"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!P87)A;65T97(@=V%S('5P<&5R
M8V%S92X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-5<'!E<B@D<W1R:6YG+"`D
M8VAA<G-E="`](&YU;&PI"B`@("!["B`@("`@("`@<F5T=7)N("@H4W1R:6YG
M.CIU<'!E<B@D<W1R:6YG+"!T<G5E+"`D8VAA<G-E="D@/3T]("1S=')I;F<I
M("8F"B`@("`@("`@("`@("`@("!3=')I;F<Z.FES06QP:&$H)'-T<FEN9RP@
M)&-H87)S970I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%!E<F9O<FUS(&$@
M;75L=&EB>71E('-A9F4@<F5G97@@;6%T8V@@<V5A<F-H(&]N('1H92!T97AT
M('!R;W9I9&5D+@H@("`@("H*("`@("`J($!S:6YC92!(;W)D92`S+C$*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("`@("!4:&4@=&5X="!T
M;R!S96%R8V@N"B`@("`@*B!`<&%R86T@87)R87D@)')E9V5X("`@("!4:&4@
M<F5G=6QA<B!E>'!R97-S:6]N<R!T;R!U<V4L('=I=&AO=70@<&5R;`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@<F5G97@@9&5L:6UI=&5R<R`H
M92YG+B`G+R<@;W(@)WPG*2X*("`@("`J($!P87)A;2!S=')I;F<@)&-H87)S
M970@(%1H92!C:&%R86-T97(@<V5T(&]F('1H92!T97AT+@H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@(%1H92!M871C:&5S(&%R<F%Y(&9R;VT@=&AE
M(&9I<G-T(')E9V5X('1H870@;6%T8VAE<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F5G97A-871C:"@D=&5X="P@)')E9V5X+"`D8VAA<G-E="`](&YU;&PI
M"B`@("!["B`@("`@("`@:68@*"%E;7!T>2@D8VAA<G-E="DI('L*("`@("`@
M("`@("`@)')E9V5X(#T@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D<F5G97@L
M("1C:&%R<V5T+"`G=71F+3@G*3L*("`@("`@("`@("`@)'1E>'0@/2!3=')I
M;F<Z.F-O;G9E<G1#:&%R<V5T*"1T97AT+"`D8VAA<G-E="P@)W5T9BTX)RD[
M"B`@("`@("`@?0H*("`@("`@("`D;6%T8VAE<R`](&%R<F%Y*"D["B`@("`@
M("`@9F]R96%C:"`H)')E9V5X(&%S("1V86PI('L*("`@("`@("`@("`@:68@
M*'!R96=?;6%T8V@H)R\G("X@)'9A;"`N("<O=2<L("1T97AT+"`D;6%T8VAE
M<RDI('L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1C:&%R<V5T*2D@>PH@("`@
M("`@("`@("`D;6%T8VAE<R`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&UA
M=&-H97,L("=U=&8M."<L("1C:&%R<V5T*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D;6%T8VAE<SL*("`@('T*"GT*````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O3F]T:69I8V%T:6]N+G!H<```````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3<P,S(@,3`U,34T,S,W-#`@
M,#(R-3`V`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B!4:&4@3F]T:69I8V%T:6]N.CH@8VQA<W,@<')O
M=FED97,@82!S=6)J96-T+6]B<V5R=F5R('!A='1E<FX@9F]R"B`J(')A:7-I
M;F<@86YD('-H;W=I;F<@;65S<V%G97,@;V8@9&EF9F5R96YT('1Y<&5S(&%N
M9"!T;R!D:69F97)E;G0*("H@;&ES=&5N97)S+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+G!H<"QV(#$N-#8N
M,BXQ,2`R,#`V+S`Q+S$X(#$U.C$Y.C`Q(&IA;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,C`P,2TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ
M86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`R+C$*("H@0'!A8VMA
M9V4@2&]R9&5?3F]T:69I8V%T:6]N"B`J+PIC;&%S<R!.;W1I9FEC871I;VX@
M>PH*("`@("\J*@H@("`@("H@2&%S:"!C;VYT86EN:6YG(&%L;"!A='1A8VAE
M9"!L:7-T96YE<B!O8FIE8W1S+@H@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1?;&ES=&5N97)S(#T@87)R87DH*3L*"B`@("`O
M*BH*("`@("`J(%1H92!N86UE(&]F('1H92!S97-S:6]N('9A<FEA8FQE('=H
M97)E('=E('-T;W)E('1H92!M97-S86=E<RX*("`@("`J"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]S=&%C:R`]("=H;W)D94UE<W-A
M9V53=&%C:W,G.PH*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(')E9F5R96YC
M92!T;R!T:&4@9VQO8F%L($YO=&EF:6-A=&EO;B!O8FIE8W0L(&]N;'D*("`@
M("`J(&-R96%T:6YG(&ET(&EF(&ET(&1O97-N)W0@86QR96%D>2!E>&ES="X*
M("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z
M"B`@("`@*B`@("1N;W1I9FEC871I;VX@/2`F3F]T:69I8V%T:6]N.CIS:6YG
M;&5T;VXH*0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T86-K("!4
M:&4@;F%M92!O9B!T:&4@;65S<V%G92!S=&%C:R!T;R!U<V4N"B`@("`@*@H@
M("`@("H@0')E='5R;B!.;W1I9FEC871I;VX@(%1H92!(;W)D92!.;W1I9FEC
M871I;VX@:6YS=&%N8V4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T
M;VXH)'-T86-K(#T@)VAO<F1E365S<V%G95-T86-K<R<I"B`@("!["B`@("`@
M("`@<W1A=&EC("1N;W1I9FEC871I;VX@/2!A<G)A>2@I.PH*("`@("`@("!I
M9B`H(6ES<V5T*"1N;W1I9FEC871I;VY;)'-T86-K72DI('L*("`@("`@("`@
M("`@)&YO=&EF:6-A=&EO;ELD<W1A8VM=(#T@;F5W($YO=&EF:6-A=&EO;B@D
M<W1A8VLI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1N;W1I9FEC871I
M;VY;)'-T86-K73L*("`@('T*"B`@("`O*BH*("`@("`J($EN:71I86QI>F4@
M=&AE(&YO=&EF:6-A=&EO;B!S>7-T96TL('-E="!U<"!A;GD@;F5E9&5D('-E
M<W-I;VX*("`@("`J('9A<FEA8FQE<RP@971C+B!3:&]U;&0@;F5V97(@8F4@
M8V%L;&5D(&5X8V5P="!B>0H@("`@("H@)DYO=&EF:6-A=&EO;CHZ<VEN9VQE
M=&]N*"D["B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<W1A8VL@(%1H
M92!N86UE(&]F('1H92!M97-S86=E('-T86-K('1O('5S92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@3F]T:69I8V%T:6]N*"1S=&%C:R`]("=H;W)D94UE<W-A
M9V53=&%C:W,G*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<W1A8VL@/2`D<W1A
M8VL["@H@("`@("`@("\J($UA:V4@<W5R92!T:&4@;65S<V%G92!S=&%C:R!I
M<R!R96=I<W1E<F5D(&EN('1H92!S97-S:6]N+`H@("`@("`@("`J(&%N9"!O
M8G1A:6X@82!G;&]B86PM<V-O<&4@<F5F97)E;F-E('1O(&ET+B`J+PH@("`@
M("`@(&EF("@A:7-S970H)%]315-324].6R1T:&ES+3Y?<W1A8VM=*2D@>PH@
M("`@("`@("`@("`D7U-%4U-)3TY;)'1H:7,M/E]S=&%C:UT@/2!A<G)A>2@I
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E9VES=&5R<R!A
M(&QI<W1E;F5R('=I=&@@=&AE(&YO=&EF:6-A=&EO;B!O8FIE8W0@86YD(&EN
M8VQU9&5S"B`@("`@*B!T:&4@;F5C97-S87)Y(&QI8G)A<GD@9FEL92!D>6YA
M;6EC86QL>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D<FEV97(@
M(%1H92!N86UE(&]F('1H92!L:7-T96YE<B!T;R!A='1A8V@N(%1H97-E(&YA
M;65S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&UU<W0@8F4@=6YI
M<75E.R!F=7)T:&5R(&QI<W1E;F5R<R!W:71H('1H92!S86UE"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@(&YA;64@=VEL;"!B92!I9VYO<F5D+@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("!!(&AA<V@@8V]N=&%I;FEN
M9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A(&QI
M<W1E;F5R(&1R:79E<B!M:6=H=`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("!N965D+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VQA<W,@("!4:&4@
M8VQA<W,@;F%M92!F<F]M('=H:6-H('1H92!D<FEV97(@=V%S"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@(&EN<W1A;G1I871E9"!I9B!N;W0@=&AE
M(&1E9F%U;'0@;VYE+B!)9B!G:79E;@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("!Y;W4@:&%V92!T;R!I;F-L=61E('1H92!L:6)R87)Y(&9I;&4@
M8V]N=&%I;FEN9PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!T:&ES
M(&-L87-S('EO=7)S96QF+B!4:&ES(&ES('5S969U;"!I9B!Y;W4@=V%N=`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("!T:&4@;&ES=&5N97(@9')I
M=F5R('1O(&)E(&]V97)R:61E;B!B>2!A;@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("!A<'!L:6-A=&EO;B=S(&EM<&QE;65N=&%T:6]N+@H@("`@
M("HO"B`@("!F=6YC=&EO;B`F871T86-H*"1L:7-T96YE<BP@)'!A<F%M<R`]
M(&%R<F%Y*"DL("1C;&%S<R`](&YU;&PI"B`@("!["B`@("`@("`@)&QI<W1E
M;F5R(#T@8F%S96YA;64H)&QI<W1E;F5R*3L*("`@("`@("!I9B`H(65M<'1Y
M*"1T:&ES+3Y?;&ES=&5N97)S6R1L:7-T96YE<ETI*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7VQI<W1E;F5R<ULD;&ES=&5N97)=.PH@("`@("`@
M('T*"B`@("`@("`@:68@*&ES7VYU;&PH)&-L87-S*2D@>PH@("`@("`@("`@
M("!`<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R].;W1I9FEC
M871I;VXO3&ES=&5N97(O)R`N("1L:7-T96YE<B`N("<N<&AP)SL*("`@("`@
M("`@("`@)&-L87-S(#T@)TYO=&EF:6-A=&EO;E],:7-T96YE<E\G("X@)&QI
M<W1E;F5R.PH@("`@("`@('T*("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1C
M;&%S<RDI('L*("`@("`@("`@("`@)'1H:7,M/E]L:7-T96YE<G-;)&QI<W1E
M;F5R72`]("9N97<@)&-L87-S*"1P87)A;7,I.PH@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1?4T534TE/3ELD=&AI<RT^7W-T86-K75LD;&ES=&5N97)=*2D@
M>PH@("`@("`@("`@("`@("`@)%]315-324].6R1T:&ES+3Y?<W1A8VM=6R1L
M:7-T96YE<ET@/2!A<G)A>2@I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7VQI<W1E;F5R<ULD;&ES=&5N97)=.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*'-P<FEN=&8H)TYO=&EF:6-A=&EO;B!L:7-T96YE<B`E<R!N;W0@9F]U;F0N
M)RP@)&QI<W1E;F5R*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@4F5M;W9E(&$@;&ES=&5N97(@9G)O;2!T:&4@;F]T:69I8V%T:6]N(&QI
M<W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;&ES=&YE<B`@5&AE
M(&YA;64@;V8@=&AE(&QI<W1E;F5R('1O(&1E=&%C:"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9&5T86-H*"1L:7-T96YE<BD*("`@('L*("`@("`@("`D;&ES
M=&5N97(@/2!B87-E;F%M92@D;&ES=&5N97(I.PH@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]L:7-T96YE<G-;)&QI<W1E;F5R72DI('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9B@G3F]T:69I8V%T
M:6]N(&QI<W1E;F5R("5S(&YO="!F;W5N9"XG+"`D;&ES=&5N97(I*3L*("`@
M("`@("!]"@H@("`@("`@("1L:7-T(#T@)'1H:7,M/E]L:7-T96YE<G-;)&QI
M<W1E;F5R73L*("`@("`@("!U;G-E="@D=&AI<RT^7VQI<W1E;F5R<ULD;&ES
M=&5N97)=*3L*("`@("`@("!U;G-E="@D7U-%4U-)3TY;)'1H:7,M/E]S=&%C
M:UU;)&QI<W0M/F=E=$YA;64H*5TI.PH@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@061D(&%N(&5V96YT('1O('1H92!(;W)D
M92!M97-S86=E('-T86-K+@H@("`@("H*("`@("`J(%1H92!E=F5N="!T>7!E
M('!A<F%M971E<B!S:&]U;&0@8F5G:6X@=VET:"`G:&]R9&4N)R!U;FQE<W,@
M=&AE"B`@("`@*B!A<'!L:6-A=&EO;B!D969I;F5S(&ET<R!O=VX@3F]T:69I
M8V%T:6]N7TQI<W1E;F5R('-U8F-L87-S('1H870*("`@("`J(&AA;F1L97,@
M861D:71I;VYA;"!C;V1E<RX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@
M)&5V96YT("`@3F]T:69I8V%T:6]N7T5V96YT(&]B:F5C="!O<B!M97-S86=E
M('-T<FEN9RX*("`@("`J($!P87)A;2!I;G1E9V5R("1T>7!E("!4:&4@='EP
M92!O9B!M97-S86=E.B`G:&]R9&4N97)R;W(G+`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("=H;W)D92YW87)N:6YG)RP@)VAO<F1E+G-U8V-E<W,G
M+"!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("=H;W)D92YM97-S
M86=E)RX*("`@("`J($!P87)A;2!A<G)A>2`D9FQA9W,@("!!<G)A>2!O9B!O
M<'1I;VYA;"!F;&%G<R!T:&%T('=I;&P@8F4@<&%S<V5D('1O('1H90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@(')E9VES=&5R960@;&ES=&5N97)S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!P=7-H*"1E=F5N="P@)'1Y<&4@/2!N
M=6QL+"`D9FQA9W,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("@A:7-?
M82@D979E;G0L("=.;W1I9FEC871I;VY?179E;G0G*2`F)@H@("`@("`@("`@
M("`A:7-?82@D979E;G0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M+RH@5')A;G-P87)E;G1L>2!C<F5A=&4@82!.;W1I9FEC871I;VY?179E;G0@
M;V)J96-T(&%N9`H@("`@("`@("`@("`@*B!S970@=&AE(&UE<W-A9V4@871T
M<FEB=71E+B`J+PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?
M7T9)3$5?7RD@+B`G+TYO=&EF:6-A=&EO;B]%=F5N="YP:'`G.PH@("`@("`@
M("`@("`D979E;G0@/2`F;F5W($YO=&EF:6-A=&EO;E]%=F5N="@D979E;G0I
M.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?82@D979E;G0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@:68@*"%I<W-E="@D='EP92DI('L*("`@
M("`@("`@("`@("`@("1T>7!E(#T@)VAO<F1E+F5R<F]R)SL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D979E;G0L(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@('T*
M("`@("`@("!I9B`H(6ES<V5T*"1T>7!E*2D@>PH@("`@("`@("`@("`D='EP
M92`]("=H;W)D92YM97-S86=E)SL*("`@("`@("!]"@H@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3Y?;&ES=&5N97)S(&%S("1L:7-T96YE<BD@>PH@("`@("`@
M("`@("!I9B`H)&QI<W1E;F5R+3YH86YD;&5S*"1T>7!E*2D@>PH@("`@("`@
M("`@("`@("`@)%]315-324].6R1T:&ES+3Y?<W1A8VM=6R1L:7-T96YE<BT^
M9V5T3F%M92@I75M=(#T*("`@("`@("`@("`@("`@("`@("!A<G)A>2@G='EP
M92<@/3X@)'1Y<&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@)V-L87-S
M)R`]/B!G971?8VQA<W,H)&5V96YT*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`G979E;G0G(#T^('-E<FEA;&EZ92@D979E;G0I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("=F;&%G<R<@/3X@<V5R:6%L:7IE*"1F;&%G<RDI
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@4&%S<V5S('1H92!M97-S86=E('-T86-K('1O(&%L;"!L:7-T96YE<G,@
M86YD(&%S:W,@=&AE;2!T;PH@("`@("H@:&%N9&QE('1H96ER(&UE<W-A9V5S
M+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D;W!T:6]N<R`@06X@87)R
M87D@8V]N=&%I;FEN9R!D:7-P;&%Y(&]P=&EO;G,@9F]R('1H90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("!L:7-T96YE<G,N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&YO=&EF>2@D;W!T:6]N<R`](&%R<F%Y*"DI"B`@("!["B`@
M("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG;&ES=&5N97)S)UTI*2!["B`@
M("`@("`@("`@("1O<'1I;VYS6R=L:7-T96YE<G,G72`](&%R<F%Y7VME>7,H
M)'1H:7,M/E]L:7-T96YE<G,I.PH@("`@("`@('T@96QS96EF("@A:7-?87)R
M87DH)&]P=&EO;G-;)VQI<W1E;F5R<R==*2D@>PH@("`@("`@("`@("`D;W!T
M:6]N<ULG;&ES=&5N97)S)UT@/2!A<G)A>2@D;W!T:6]N<ULG;&ES=&5N97)S
M)UTI.PH@("`@("`@('T*("`@("`@("!F;W)E86-H("@D;W!T:6]N<ULG;&ES
M=&5N97)S)UT@87,@)&QI<W1E;F5R*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M;&ES=&5N97)S6R1L:7-T96YE<ETM/FYO=&EF>2@D7U-%4U-)3TY;)'1H:7,M
M/E]S=&%C:UU;)'1H:7,M/E]L:7-T96YE<G-;)&QI<W1E;F5R72T^9V5T3F%M
M92@I72P@)&]P=&EO;G,I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;B!T:&4@;G5M8F5R(&]F(&YO=&EF:6-A=&EO;B!M97-S86=E
M<R!I;B!T:&4@<W1A8VLN"B`@("`@*@H@("`@("H@0&%U=&AO<B!$879I9"!5
M;&5V:71C:"`\9&%V:61U0&5V97)Y9&YS+FYE=#X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1M>5]L:7-T96YE<B`@5&AE(&YA;64@;V8@=&AE(&QI
M<W1E;F5R+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(&YU
M;6)E<B!O9B!M97-S86=E<R!I;B!T:&4@<W1A8VLN"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&-O=6YT*"1M>5]L:7-T96YE<B`](&YU;&PI"B`@("!["B`@("`@
M("`@:68@*&ES7VYU;&PH)&UY7VQI<W1E;F5R*2D@>PH@("`@("`@("`@("`D
M8V]U;G0@/2`P.PH@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7VQI<W1E
M;F5R<R!A<R`D;&ES=&5N97(I('L*("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D7U-%4U-)3TY;)'1H:7,M/E]S=&%C:UU;)&QI<W1E;F5R+3YG971.86UE
M*"E=*2D@>PH@("`@("`@("`@("`@("`@("`@("1C;W5N="`K/2!C;W5N="@D
M7U-%4U-)3TY;)'1H:7,M/E]S=&%C:UU;)&QI<W1E;F5R+3YG971.86UE*"E=
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!R971U<FX@)&-O=6YT.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(')E='5R;B!`8V]U;G0H)%]315-324].6R1T:&ES+3Y?<W1A8VM=6R1T:&ES
M+3Y?;&ES=&5N97)S6R1M>5]L:7-T96YE<ETM/F=E=$YA;64H*5TI.PH@("`@
M("`@('T*("`@('T*"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U9A<FEA
M8FQE<RYP:'``````````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#$U-38T(#$P-3$U-#,S-S0P(#`R,C`P,``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=(
M;W)D92]5=&EL+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O07)R87DN<&AP
M)SL*"B\J*@H@*B!687)I86)L97,Z.B!C;&%S<RX*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO571I;"]687)I86)L97,N<&AP+'8@,2XX+C$P+C8@,C`P-B\P
M,R\R."`Q,CHS,3HQ,B!J86X@17AP("0*("H*("H@0&%U=&AO<B`@4F]B97)T
M($4N($-O>6QE(#QR;V)E<G1E8V]Y;&5`:&]T;6%I;"YC;VT^"B`J($!A=71H
M;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<&%C
M:V%G92!(;W)D95]5=&EL"B`J+PIC;&%S<R!687)I86)L97,@>PH*("`@('9A
M<B`D7W9A<G,["B`@("!V87(@)%]E>'!E8W1E9%9A<FEA8FQE<R`](&%R<F%Y
M*"D["@H@("`@9G5N8W1I;VX@5F%R:6%B;&5S*"1V87)S(#T@87)R87DH*2D*
M("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D=F%R<RDI('L*("`@("`@("`@
M("`@)'9A<G,@/2!5=&EL.CID:7-P96Q-86=I8U%U;W1E<R@D7U)%455%4U0I
M.PH@("`@("`@('T*("`@("`@("!I9B`H:7-S970H)'9A<G-;)U]F;W)M=F%R
M<R==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V5X<&5C=&5D5F%R:6%B;&5S
M(#T@0'5N<V5R:6%L:7IE*"1V87)S6R=?9F]R;79A<G,G72D["B`@("`@("`@
M("`@('5N<V5T*"1V87)S6R=?9F]R;79A<G,G72D["B`@("`@("`@?0H@("`@
M("`@("1T:&ES+3Y?=F%R<R`]("1V87)S.PH@("`@?0H*("`@(&9U;F-T:6]N
M("9G971$969A=6QT5F%R:6%B;&5S*"D*("`@('L*("`@("`@("`D=F%R<R`]
M("9N97<@5F%R:6%B;&5S*%5T:6PZ.F1I<W!E;$UA9VEC475O=&5S*"1?4D51
M54535"DI.PH@("`@("`@(')E='5R;B`D=F%R<SL*("`@('T*"B`@("!F=6YC
M=&EO;B!E>&ES=',H)'9A<FYA;64I"B`@("!["B`@("`@("`@:68@*&-O=6YT
M*"1T:&ES+3Y?97AP96-T961687)I86)L97,I("8F"B`@("`@("`@("`@("1T
M:&ES+3Y?97AI<W1S*"1T:&ES+3Y?97AP96-T961687)I86)L97,L("1V87)N
M86UE+"!F86QS92DI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^7V5X:7-T<R@D=&AI<RT^7W9A
M<G,L("1V87)N86UE+"!F86QS92D["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T
M*"1V87)N86UE*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9V5T17AI<W1S*"1T
M:&ES+3Y?=F%R<RP@)'9A<FYA;64L("1V86QU92D["B`@("`@("`@<F5T=7)N
M("1V86QU93L*("`@('T*"B`@("!F=6YC=&EO;B!G971%>&ES=',H)'9A<FYA
M;64L("8D97AI<W1S*0H@("`@>PH@("`@("`@("1E>&ES=',@/2`D=&AI<RT^
M7V=E=$5X:7-T<R@D=&AI<RT^7W9A<G,L("1V87)N86UE+"`D=F%L=64I.PH@
M("`@("`@(')E='5R;B`D=F%L=64["B`@("!]"@H@("`@9G5N8W1I;VX@<V5T
M*"1V87)N86UE+"`D=F%L=64I"B`@("!["B`@("`@("`@)&ME>7,@/2!A<G)A
M>2@I.PH@("`@("`@(&EF("@A2&]R9&5?07)R87DZ.F=E=$%R<F%Y4&%R=',H
M)'9A<FYA;64L("1B87-E+"`D:V5Y<RDI('L*("`@("`@("`@("`@)'1H:7,M
M/E]V87)S6R1V87)N86UE72`]("1V86QU93L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!A<G)A>5]U;G-H:69T*"1K97ES+"`D8F%S92D["B`@("`@
M("`@("`@("1P;&%C92`]("8D=&AI<RT^7W9A<G,["@H@("`@("`@("`@("!W
M:&EL92`H8V]U;G0H)&ME>7,I*2!["B`@("`@("`@("`@("`@("`D:V5Y(#T@
M87)R87E?<VAI9G0H)&ME>7,I.PH@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D<&QA8V5;)&ME>5TI*2!["B`@("`@("`@("`@("`@("`@("`@)'!L86-E
M6R1K97E=(#T@87)R87DH*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("1P;&%C92`]("8D<&QA8V5;)&ME>5T["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("1P;&%C92`]("1V86QU93L*("`@("`@("!]"B`@("!]
M"@H@("`@9G5N8W1I;VX@;65R9V4H)'9A<G,I"B`@("!["B`@("`@("`@9F]R
M96%C:"`H)'9A<G,@87,@)'9A<FYA;64@/3X@)'9A;'5E*2!["B`@("`@("`@
M("`@("1T:&ES+3YS970H)'9A<FYA;64L("1V86QU92D["B`@("`@("`@?0H@
M("`@?0H*("`@(&9U;F-T:6]N(&%D9"@D=F%R;F%M92P@)'9A;'5E*0H@("`@
M>PH@("`@("`@(&EF("@D=&AI<RT^97AI<W1S*"1V87)N86UE*2D@>PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@("1T:&ES
M+3Y?=F%R<ULD=F%R;F%M95T@/2`D=F%L=64["B`@("!]"@H@("`@9G5N8W1I
M;VX@<F5M;W9E*"1V87)N86UE*0H@("`@>PH@("`@("`@($AO<F1E7T%R<F%Y
M.CIG971!<G)A>5!A<G1S*"1V87)N86UE+"`D8F%S92P@)&ME>7,I.PH@("`@
M("`@(&EF("@A:7-?;G5L;"@D8F%S92DI('L*("`@("`@("`@("`@)'!T<B`]
M("8D=&AI<RT^7W9A<G-;)&)A<V5=.PH@("`@("`@("`@("`D96YD(#T@8V]U
M;G0H)&ME>7,I("T@,3L*("`@("`@("`@("`@9F]R96%C:"`H)&ME>7,@87,@
M)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1P
M=');)'9A;%TI*2!["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H)&5N9"`]/2`D:V5Y
M*2!["B`@("`@("`@("`@("`@("`@("`@87)R87E?<W!L:6-E*"1P='(L(&%R
M<F%Y7W-E87)C:"@D=F%L+"!A<G)A>5]K97ES*"1P='(I*2P@,2D["B`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1P='(@
M/2`F)'!T<ELD=F%L73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?
M=F%R<ULD=F%R;F%M95TI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($9I;F0@;W5T('=H971H97(@;W(@;F]T("1V87)N86UE('=A<R!S970@
M:6X@)&%R<F%Y+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`@("1A<G)A>2`@("`@("`@("`@("`@
M("`@("!4:&4@87)R87D@=&\@<V5A<F-H(&EN("AU<W5A;&QY"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@96ET:&5R
M("1T:&ES+3Y?=F%R<R!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?97AP96-T961687)I86)L97,I
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'9A<FYA;64@("`@("`@("`@("`@
M("`@(%1H92!N86UE(&]F('1H92!V87)I86)L92!T;R!L;V]K"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R+@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)&-H96-K17AP96-T961687)I86)L97,@
M($EF('=E(&1O;B=T(&9I;F0@)'9A<FYA;64L"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<VAO=6QD('=E(&-H96-K
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]E>'!E8W1E9%9A<FEA8FQE<R!T;R!S964*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B!S:&]U
M;&0@:&%V92!E>&ES=&5D("AL:6ME(&$*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!C:&5C:V)O>"!O<B!S96QE8W0@
M;75L=&EP;&4I+@H@("`@("H*("`@("`J($!R971U<FX@(%=H971H97(@;W(@
M;F]T('1H92!V87)I86)L92!W87,@<V5T("AO<BP@:68@=V4G=F4@8VAE8VME
M9`H@("`@("H@("`@("`@("`@)'1H:7,M/E]E>'!E8W1E9%9A<FEA8FQE<RP@
M<VAO=6QD(&AA=F4@8F5E;B!S970I+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M97AI<W1S*"1A<G)A>2P@)'9A<FYA;64L("1C:&5C:T5X<&5C=&5D5F%R:6%B
M;&5S(#T@=')U92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]G971%
M>&ES=',H)&%R<F%Y+"`D=F%R;F%M92P@)'9A;'5E+"`D8VAE8VM%>'!E8W1E
M9%9A<FEA8FQE<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&971C:"!T:&4@
M<F5Q=65S=&5D('9A<FEA8FQE("@D=F%R;F%M92D@:6YT;R`D=F%L=64L(&%N
M9"!R971U<FX*("`@("`J('=H971H97(@;W(@;F]T('1H92!V87)I86)L92!W
M87,@<V5T(&EN("1A<G)A>2X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@("`D87)R87D@("`@("`@
M("`@("`@("`@("`@5&AE(&%R<F%Y('1O('-E87)C:"!I;B`H=7-U86QL>0H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&5I=&AE<B`D=&AI<RT^7W9A<G,@;W(*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V5X<&5C=&5D5F%R
M:6%B;&5S*2X*("`@("`J($!P87)A;2!S=')I;F<@("1V87)N86UE("`@("`@
M("`@("`@("`@("!4:&4@;F%M92!O9B!T:&4@=F%R:6%B;&4@=&\@;&]O:PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&9O<BX*("`@("`J($!P87)A;2!M:7AE9"`@)B1V86QU92`@("`@("`@("`@
M("`@("`@("`D=F%R;F%M92=S('9A;'5E(&=E=',@87-S:6=N960*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T;RX*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!T:&ES('9A<FEA8FQE+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&-H96-K
M17AP96-T961687)I86)L97,@($EF('=E(&1O;B=T(&9I;F0@)'9A<FYA;64L
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<VAO=6QD('=E(&-H96-K"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]E>'!E8W1E9%9A<FEA8FQE
M<R!T;R!S964*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!I9B!I="!S:&]U;&0@:&%V92!E>&ES=&5D("AL:6ME"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M82!C:&5C:V)O>"!O<B!S96QE8W0@;75L=&EP;&4I+@H@("`@("H*("`@("`J
M($!R971U<FX@(%=H971H97(@;W(@;F]T('1H92!V87)I86)L92!W87,@<V5T
M("AO<BP@:68@=V4G=F4@8VAE8VME9`H@("`@("H@("`@("`@("`@)'1H:7,M
M/E]E>'!E8W1E9%9A<FEA8FQE<RP@<VAO=6QD(&AA=F4@8F5E;B!S970I+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?9V5T17AI<W1S*"1A<G)A>2P@)'9A<FYA
M;64L("8D=F%L=64L("1C:&5C:T5X<&5C=&5D5F%R:6%B;&5S(#T@=')U92D*
M("`@('L*("`@("`@("!I9B`H2&]R9&5?07)R87DZ.F=E=$%R<F%Y4&%R=',H
M)'9A<FYA;64L("1B87-E+"`D:V5Y<RDI('L*("`@("`@("`@("`@:68@*"%I
M<W-E="@D87)R87E;)&)A<V5=*2D@>PH@("`@("`@("`@("`@("`@)'9A;'5E
M(#T@;G5L;#L*("`@("`@("`@("`@("`@("\O($EF('=E)W)E('-U<'!O<V5D
M('1O(&-H96-K("1T:&ES+3Y?97AP96-T961687)I86)L97,L(&1O('-O+`H@
M("`@("`@("`@("`@("`@+R\@8G5T(&UA:V4@<W5R92!N;W0@=&\@8VAE8VL@
M:70@86=A:6XN"B`@("`@("`@("`@("`@("!R971U<FX@)&-H96-K17AP96-T
M961687)I86)L97,@/R`D=&AI<RT^7V5X:7-T<R@D=&AI<RT^7V5X<&5C=&5D
M5F%R:6%B;&5S+"`D=F%R;F%M92P@9F%L<V4I(#H@9F%L<V4["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<V5A<F-H<W!A8V4@/2`F
M)&%R<F%Y6R1B87-E73L*("`@("`@("`@("`@("`@('=H:6QE("AC;W5N="@D
M:V5Y<RDI('L*("`@("`@("`@("`@("`@("`@("`D:V5Y(#T@87)R87E?<VAI
M9G0H)&ME>7,I.PH@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'-E
M87)C:'-P86-E6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M=F%L=64@/2!N=6QL.PH@("`@("`@("`@("`@("`@("`@("`@("`O+R!)9B!W
M92=R92!S=7!P;W-E9"!T;R!C:&5C:PH@("`@("`@("`@("`@("`@("`@("`@
M("`O+R`D=&AI<RT^7V5X<&5C=&5D5F%R:6%B;&5S+"!D;R!S;RP@8G5T(&UA
M:V4*("`@("`@("`@("`@("`@("`@("`@("`@+R\@<W5R92!N;W0@=&\@8VAE
M8VL@:70@86=A:6XN"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M8VAE8VM%>'!E8W1E9%9A<FEA8FQE<R`_("1T:&ES+3Y?97AI<W1S*"1T:&ES
M+3Y?97AP96-T961687)I86)L97,L("1V87)N86UE+"!F86QS92D@.B!F86QS
M93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M)'-E87)C:'-P86-E(#T@)B1S96%R8VAS<&%C95LD:V5Y73L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1V86QU92`]("1S96%R8VAS<&%C
M93L*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!]
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'9A;'5E(#T@:7-S970H
M)&%R<F%Y6R1V87)N86UE72D@/R`D87)R87E;)'9A<FYA;65=(#H@;G5L;#L*
M("`@("`@("`@("`@:68@*"%I<U]N=6QL*"1V86QU92DI('L*("`@("`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!](&5L<V5I9B`H)&-H
M96-K17AP96-T961687)I86)L97,I('L*("`@("`@("`@("`@("`@("\O($EF
M('=E)W)E('-U<'!O<V5D('1O(&-H96-K"B`@("`@("`@("`@("`@("`O+R`D
M=&AI<RT^7V5X<&5C=&5D5F%R:6%B;&5S+"!D;R!S;RP@8G5T(&UA:V4@<W5R
M92!N;W0*("`@("`@("`@("`@("`@("\O('1O(&-H96-K(&ET(&%G86EN+@H@
M("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?97AI<W1S*"1T:&ES+3Y?
M97AP96-T961687)I86)L97,L("1V87)N86UE+"!F86QS92D["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-O;F9I9RYP:'``````````````
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,30W,3$R(#$P-3$U-#,S
M-S0P(#`R,3(W,``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D92]&;W)M+G!H<"<[
M"@HO*BH*("H@5&AE($-O;F9I9SHZ('!A8VMA9V4@<')O=FED97,@82!F<F%M
M97=O<FL@9F]R(&UA;F%G:6YG('1H90H@*B!C;VYF:6=U<F%T:6]N(&]F($AO
M<F1E(&%P<&QI8V%T:6]N<RP@=W)I=&EN9R!C;VYF+G!H<"!F:6QE<R!F<F]M
M"B`J(&-O;F8N>&UL('-O=7)C92!F:6QE<RP@9V5N97)A=&EN9R!U<V5R(&EN
M=&5R9F%C97,L(&5T8RX*("H*("H@5&AE($AO<F1E7T-O;F9I9U].;V1E($1/
M32!C;&%S<V5S(&%N9"!S=6)C;&%S<V5S"B`J("A(;W)D95]#;VYF:6=?1&]C
M=6UE;G0L($AO<F1E7T-O;F9I9U]%;&5M96YT*2!A<F4@<VEM<&QY(&UA<W-A
M9V5D"B`J(&9R;VT@8V]D92!W<FET=&5N(&)Y('1O(&5M=6QA=&4@4$A0-"=S
M($1/35A-3"!E>'1E;G-I;VX@=VET:"!02%`U)W,*("H@1$]-('-U<'!O<G0N
M($]N;'D@8VAA;F=E<R!A<F4@;F%M:6YG(&%N9"!S>6YT86-T:6,@<W5G87(O
M2&]R9&4*("H@8V]D:6YG('-T86YD87)D<SL@86QL(&-R961I="!G;V5S('1O
M($%L97AA;F1R92!A;F0@=&AE(&-O9&4@:7,@=7-E9`H@*B!W:71H(&AI<R!P
M97)M:7-S:6]N+B!(:7,@;W)I9VEN86P@8V]D92!C86X@8F4@9F]U;F0@870Z
M"B`J"B`J("`@:'1T<#HO+V%L97AA;F1R92YA;&%P971I=&4N;F5T+V1O8RUA
M;&5X+V1O;7AM;"UP:'`T+7!H<#4O"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+T-O;F9I9RYP:'`L=B`Q+C@P+C(N,C8@,C`P-B\P-B\P
M,2`R,SHT-#HS,B!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P
M-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R
M9&5?1G)A;65W;W)K"B`J+PIC;&%S<R!(;W)D95]#;VYF:6<@>PH*("`@("\J
M*@H@("`@("H@5&AE(&YA;64@;V8@=&AE(&-O;F9I9W5R960@87!P;&EC871I
M;VXN"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?87!P.PH*("`@("\J*@H@("`@("H@5&AE(%A-3"!T<F5E(&]F('1H92!C
M;VYF:6=U<F%T:6]N(&9I;&4@=')A=F5R<V5D('1O(&%N"B`@("`@*B!A<W-O
M8VEA=&EV92!A<G)A>2X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D7WAM;$-O;F9I9U1R964@/2!N=6QL.PH*("`@("\J*@H@
M("`@("H@5&AE(&-O;G1E;G0@;V8@=&AE(&=E;F5R871E9"!C;VYF:6=U<F%T
M:6]N(&9I;&4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@
M("`@=F%R("1?<&AP0V]N9FEG.PH*("`@("\J*@H@("`@("H@5&AE(&-O;G1E
M;G0@;V8@=&AE(&]L9"!C;VYF:6=U<F%T:6]N(&9I;&4N"B`@("`@*@H@("`@
M("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?;VQD0V]N9FEG.PH*
M("`@("\J*@H@("`@("H@5&AE(&UA;G5A;"!C;VYF:6=U<F%T:6]N(&EN(&9R
M;VYT(&]F('1H92!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX*("`@("`J"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]P<F5#;VYF:6<[
M"@H@("`@+RHJ"B`@("`@*B!4:&4@;6%N=6%L(&-O;F9I9W5R871I;VX@869T
M97(@=&AE(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@H@("`@("H*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W!O<W1#;VYF:6<["@H@
M("`@+RHJ"B`@("`@*B!4:&4@8W5R<F5N="`D8V]N9B!A<G)A>2!O9B!T:&4@
M8V]N9FEG=7)E9"!A<'!L:6-A=&EO;BX*("`@("`J"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D7V-U<G)E;G1#;VYF:6<@/2!A<G)A>2@I
M.PH*("`@("\J*@H@("`@("H@5&AE($-64R!V97)S:6]N('1A9R!O9B!T:&4@
M8V]N9BYX;6P@9FEL92!W:&EC:"!W:6QL(&)E(&-O<&EE9"!I;G1O('1H90H@
M("`@("H@8V]N9BYP:'`@9FEL92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("HO"B`@("!V87(@)%]V97)S:6]N5&%G(#T@)R<["@H@("`@+RHJ
M"B`@("`@*B!4:&4@;&EN92!M87)K:6YG('1H92!B96=I;B!O9B!T:&4@9V5N
M97)A=&5D(&-O;F9I9W5R871I;VXN"B`@("`@*@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1?8V]N9FEG0F5G:6X@/2`B+RH@0T].1DE'
M(%-405)4+B!$3R!.3U0@0TA!3D=%($%.651(24Y'($E.($]2($%&5$52(%1(
M25,@3$E.12X@*B]<;B(["@H@("`@+RHJ"B`@("`@*B!4:&4@;&EN92!M87)K
M:6YG('1H92!E;F0@;V8@=&AE(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@H@
M("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V-O
M;F9I9T5N9"`]("(O*B!#3TY&24<@14Y$+B!$3R!.3U0@0TA!3D=%($%.651(
M24Y'($E.($]2($)%1D]212!42$E3($Q)3D4N("HO7&XB.PH*("`@("\J*@H@
M("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D87!P("!4:&4@;F%M92!O9B!T:&4@87!P;&EC871I;VX@=&\@8F4@8V]N
M9FEG=7)E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?0V]N9FEG*"1A
M<'`I"B`@("!["B`@("`@("`@)'1H:7,M/E]A<'`@/2`D87!P.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5A9',@=&AE(&%P<&QI8V%T:6]N)W,@8V]N9BYX
M;6P@9FEL92!A;F0@8G5I;&1S(&%N(&%S<V]C:6%T:79E(&%R<F%Y"B`@("`@
M*B!F<F]M(&ET<R!834P@=')E92X*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)&-U<W1O;5]C;VYF("`@06YY('-E='1I;F=S('1H870@<VAA;&P@8F4@
M:6YC;'5D960@:6X@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@06X@87-S;V-I871I=F4@87)R87D@<F5P<F5S96YT
M:6YG('1H92!C;VYF:6=U<F%T:6]N('1R964N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(')E861834Q#;VYF:6<H)&-U<W1O;5]C;VYF(#T@;G5L;"D*("`@('L*
M("`@("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^7WAM;$-O;F9I9U1R964I('Q\
M("1C=7-T;VU?8V]N9BD@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO
M<F1E+U1E>'0N<&AP)SL*"B`@("`@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD[
M"B`@("`@("`@("`@("1P871H(#T@)')E9VES=')Y+3YG970H)V9I;&5R;V]T
M)RP@)'1H:7,M/E]A<'`I("X@)R]C;VYF:6<G.PH*("`@("`@("`@("`@:68@
M*"1C=7-T;VU?8V]N9BD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C=7)R
M96YT0V]N9FEG(#T@)&-U<W1O;5]C;VYF.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@+RH@1F5T8V@@=&AE(&-U<G)E;G0@8V]N9BYP
M:'`@8V]N=&5N=',N("HO"B`@("`@("`@("`@("`@("!`979A;"@D=&AI<RT^
M9V5T4$A00V]N9FEG*"DI.PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1C
M;VYF*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=$-O
M;F9I9R`]("1C;VYF.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`O*B!,;V%D('1H92!$3TT@;V)J96-T+B`J+PH@("`@
M("`@("`@("`D9&]C(#T@2&]R9&5?0V]N9FEG7T1O8W5M96YT.CIF86-T;W)Y
M*"1P871H("X@)R]C;VYF+GAM;"<I.PH*("`@("`@("`@("`@+RH@0VAE8VL@
M:68@=&AE<F4@:7,@82!#5E,@=F5R<VEO;B!T86<@86YD('-T;W)E(&ET+B`J
M+PH@("`@("`@("`@("`D;F]D92`]("1D;V,M/F9I<G-T7V-H:6QD*"D["B`@
M("`@("`@("`@('=H:6QE("@A96UP='DH)&YO9&4I*2!["B`@("`@("`@("`@
M("`@("!I9B`H)&YO9&4M/G1Y<&4@/3T@6$U,7T-/34U%3E1?3D]$12D@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7"0N*C]C;VYF
M7"YX;6PL=B`N*C\@+BI<)"\G+"`D;F]D92T^;F]D95]V86QU92@I+"`D;6%T
M8V@I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=F5R<VEO
M;E1A9R`]("1M871C:%LP72`N(")<;B(["B`@("`@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("1N;V1E(#T@)&YO9&4M/FYE>'1?<VEB
M;&EN9R@I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!087)S92!T
M:&4@8V]N9FEG(&9I;&4N("HO"B`@("`@("`@("`@("1T:&ES+3Y?>&UL0V]N
M9FEG5')E92`](&%R<F%Y*"D["B`@("`@("`@("`@("1R;V]T(#T@)&1O8RT^
M<F]O="@I.PH@("`@("`@("`@("!I9B`H)')O;W0M/FAA<U]C:&EL9%]N;V1E
M<R@I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<G-E3&5V96PH)'1H
M:7,M/E]X;6Q#;VYF:6=4<F5E+"`D<F]O="T^8VAI;&1?;F]D97,H*2P@)R<I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H
M:7,M/E]X;6Q#;VYF:6=4<F5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@9FEL92!C;VYT96YT(&]F('1H92!C=7)R96YT(&-O;F9I9W5R
M871I;VX@9FEL92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M('5N<&%R<V5D(&-O;F9I9W5R871I;VX@9FEL92!C;VYT96YT+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G97102%!#;VYF:6<H*0H@("`@>PH@("`@("`@(&EF
M("AI<U]N=6QL*"1T:&ES+3Y?;VQD0V]N9FEG*2D@>PH@("`@("`@("`@("!G
M;&]B86P@)')E9VES=')Y.PH@("`@("`@("`@("`D<&%T:"`]("1R96=I<W1R
M>2T^9V5T*"=F:6QE<F]O="<L("1T:&ES+3Y?87!P*2`N("<O8V]N9FEG)SL*
M("`@("`@("`@("`@:68@*&9I;&5?97AI<W1S*"1P871H("X@)R]C;VYF+G!H
M<"<I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V]L9$-O;F9I9R`](&9I
M;&5?9V5T7V-O;G1E;G1S*"1P871H("X@)R]C;VYF+G!H<"<I.PH@("`@("`@
M("`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7V]L9$-O;F9I9RDI('L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7V]L9$-O;F9I9R`]('!R96=?<F5P
M;&%C92@G+SQ</W!H<%QN/R\G+"`G)RP@)'1H:7,M/E]O;&1#;VYF:6<I.PH@
M("`@("`@("`@("`@("`@("`@("1P;W,@/2!S=')P;W,H)'1H:7,M/E]O;&1#
M;VYF:6<L("1T:&ES+3Y?8V]N9FEG0F5G:6XI.PH@("`@("`@("`@("`@("`@
M("`@(&EF("@D<&]S("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!R94-O;F9I9R`]('-U8G-T<B@D=&AI<RT^7V]L9$-O
M;F9I9RP@,"P@)'!O<RD["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?;VQD0V]N9FEG(#T@<W5B<W1R*"1T:&ES+3Y?;VQD0V]N9FEG+"`D<&]S
M*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M)'!O<R`]('-T<G!O<R@D=&AI<RT^7V]L9$-O;F9I9RP@)'1H:7,M/E]C;VYF
M:6=%;F0I.PH@("`@("`@("`@("`@("`@("`@(&EF("@D<&]S("$]/2!F86QS
M92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!O<W1#;VYF
M:6<@/2!S=6)S='(H)'1H:7,M/E]O;&1#;VYF:6<L("1P;W,@*R!S=')L96XH
M)'1H:7,M/E]C;VYF:6=%;F0I*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]O;&1#;VYF:6<@/2!S=6)S='(H)'1H:7,M/E]O;&1#;VYF:6<L
M(#`L("1P;W,I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?;VQD0V]N9FEG(#T@)R<["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;VQD0V]N9FEG.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1V5N97)A=&5S('1H92!C;VYT96YT(&]F('1H92!A<'!L
M:6-A=&EO;B=S(&-O;F9I9W5R871I;VX@9FEL92X*("`@("`J"B`@("`@*B!`
M<&%R86T@5F%R:6%B;&5S("1F;W)M=F%R<R`@5&AE('!R;V-E<W-E9"!C;VYF
M:6=U<F%T:6]N(&9O<FT@9&%T82X*("`@("`J($!P87)A;2!A<G)A>2`D8W5S
M=&]M7V-O;F8@("!!;GD@<V5T=&EN9W,@=&AA="!S:&%L;"!B92!I;F-L=61E
M9"!I;B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE(&-O;G1E;G0@;V8@=&AE(&=E;F5R871E9"!C;VYF:6=U
M<F%T:6]N(&9I;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E;F5R871E4$A0
M0V]N9FEG*"1F;W)M=F%R<RP@)&-U<W1O;5]C;VYF(#T@;G5L;"D*("`@('L*
M("`@("`@("`D=&AI<RT^<F5A9%A-3$-O;F9I9R@D8W5S=&]M7V-O;F8I.PH@
M("`@("`@("1T:&ES+3YG97102%!#;VYF:6<H*3L*"B`@("`@("`@)'1H:7,M
M/E]P:'!#;VYF:6<@/2`B/#]P:'!<;B(["B`@("`@("`@)'1H:7,M/E]P:'!#
M;VYF:6<@+CT@)'1H:7,M/E]P<F5#;VYF:6<["B`@("`@("`@)'1H:7,M/E]P
M:'!#;VYF:6<@+CT@)'1H:7,M/E]C;VYF:6="96=I;CL*("`@("`@("!I9B`H
M(65M<'1Y*"1T:&ES+3Y?=F5R<VEO;E1A9RDI('L*("`@("`@("`@("`@)'1H
M:7,M/E]P:'!#;VYF:6<@+CT@)R\O("<@+B`D=&AI<RT^7W9E<G-I;VY486<[
M"B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?9V5N97)A=&502%!#;VYF:6<H
M)'1H:7,M/E]X;6Q#;VYF:6=4<F5E+"`G)RP@)&9O<FUV87)S*3L*("`@("`@
M("`D=&AI<RT^7W!H<$-O;F9I9R`N/2`D=&AI<RT^7V-O;F9I9T5N9#L*("`@
M("`@("`D=&AI<RT^7W!H<$-O;F9I9R`N/2`D=&AI<RT^7W!O<W1#;VYF:6<[
M"@H@("`@("`@(')E='5R;B`D=&AI<RT^7W!H<$-O;F9I9SL*("`@('T*"B`@
M("`O*BH*("`@("`J($=E;F5R871E<R!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE
M(&ET96US(&9O<B!A('!A<G0@;V8@=&AE(&-O;F9I9W5R871I;VX*("`@("`J
M('1R964N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1S96-T:6]N("!!;B!A<W-O8VEA=&EV92!A
M<G)A>2!C;VYT86EN:6YG('1H92!P87)T(&]F('1H90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("!T<F%V97)S960@6$U,(&-O;F9I9W5R871I;VX@
M=')E92!T:&%T('-H;W5L9"!B90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("!P<F]C97-S960N"B`@("`@*B!`<&%R86T@<W1R:6YG("1P<F5F:7@@
M($$@8V]N9FEG=7)A=&EO;B!P<F5F:7@@9&5T97)M:6YI;F<@=&AE(&-U<G)E
M;G0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@<&]S:71I;VX@:6YS
M:61E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4N(%1H:7,*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@<')E9FEX('=I;&P@8F4@=')A;G-L871E9"!T
M;R!K97ES(&]F('1H92`D8V]N9@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2!I;B!T:&4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@9FEL
M92X*("`@("`J($!P87)A;2!687)I86)L97,@)&9O<FUV87)S("!4:&4@<')O
M8V5S<V5D(&-O;F9I9W5R871I;VX@9F]R;2!D871A+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?9V5N97)A=&502%!#;VYF:6<H)'-E8W1I;VXL("1P<F5F:7@L
M("1F;W)M=F%R<RD*("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1S96-T
M:6]N*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@
M("!F;W)E86-H("@D<V5C=&EO;B!A<R`D;F%M92`]/B`D8V]N9FEG:71E;2D@
M>PH@("`@("`@("`@("`D<')E9FEX961N86UE(#T@96UP='DH)'!R969I>"D@
M/R`D;F%M92`Z("1P<F5F:7@@+B`G?"<@+B`D;F%M93L*("`@("`@("`@("`@
M)&-O;F9I9VYA;64@/2!S=')?<F5P;&%C92@G?"<L("=?7R<L("1P<F5F:7AE
M9&YA;64I.PH@("`@("`@("`@("`D<75O=&4@/2`A:7-S970H)&-O;F9I9VET
M96U;)W%U;W1E)UTI('Q\("1C;VYF:6=I=&5M6R=Q=6]T92==("$]/2!F86QS
M93L*("`@("`@("`@("`@:68@*"1C;VYF:6=I=&5M(#T]("=P;&%C96AO;&1E
M<B<I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&AP0V]N9FEG("X]("<D
M8V]N9EM<)R<@+B!S=')?<F5P;&%C92@G?"<L("=<)UU;7"<G+"`D<')E9FEX
M*2`N("(G72`](&%R<F%Y*"D[7&XB.PH@("`@("`@("`@("!](&5L<V5I9B`H
M:7-S970H)&-O;F9I9VET96U;)W-W:71C:"==*2D@>PH@("`@("`@("`@("`@
M("`@)'9A;"`]("1F;W)M=F%R<RT^9V5T17AI<W1S*"1C;VYF:6=N86UE+"`D
M=V%S<V5T*3L*("`@("`@("`@("`@("`@(&EF("@A)'=A<W-E="D@>PH@("`@
M("`@("`@("`@("`@("`@("1V86P@/2!I<W-E="@D8V]N9FEG:71E;5LG9&5F
M875L="==*2`_("1C;VYF:6=I=&5M6R=D969A=6QT)UT@.B!N=6QL.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1C;VYF
M:6=I=&5M6R=S=VET8V@G75LD=F%L72DI('L*("`@("`@("`@("`@("`@("`@
M("`D=F%L=64@/2`D=F%L.PH@("`@("`@("`@("`@("`@("`@(&EF("@D<75O
M=&4@)B8@)'9A;'5E("$]("=T<G5E)R`F)B`D=F%L=64@(3T@)V9A;'-E)RD@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2`B)R(@+B`D=F%L
M=64@+B`B)R(["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?9V5N97)A=&502%!#;VYF:6<H)&-O;F9I9VET96U;
M)W-W:71C:"==6R1V86Q=6R=F:65L9',G72P@)'!R969I>"P@)&9O<FUV87)S
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E:68@*&ES
M<V5T*"1C;VYF:6=I=&5M6R=?='EP92==*2D@>PH@("`@("`@("`@("`@("`@
M)'9A;"`]("1F;W)M=F%R<RT^9V5T17AI<W1S*"1C;VYF:6=N86UE+"`D=V%S
M<V5T*3L*("`@("`@("`@("`@("`@(&EF("@A)'=A<W-E="D@>PH@("`@("`@
M("`@("`@("`@("`@("1V86P@/2!I<W-E="@D8V]N9FEG:71E;5LG9&5F875L
M="==*2`_("1C;VYF:6=I=&5M6R=D969A=6QT)UT@.B!N=6QL.PH@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1T>7!E(#T@)&-O;F9I9VET
M96U;)U]T>7!E)UT["B`@("`@("`@("`@("`@("!S=VET8V@@*"1T>7!E*2![
M"B`@("`@("`@("`@("`@("!C87-E("=M=6QT:65N=6TG.@H@("`@("`@("`@
M("`@("`@("`@(&EF("AI<U]A<G)A>2@D=F%L*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D96YC=F%L<R`](&%R<F%Y*"D["B`@("`@("`@("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1V86P@87,@)'8I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1E;F-V86QS6UT@/2`D=&AI<RT^7W%U;W1E*"1V
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@("`@("`D87)R87EV86P@/2`B)R(@+B!I;7!L;V1E*"=<)RP@7"<G+"`D
M96YC=F%L<RD@+B`B)R(["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D
M87)R87EV86P@/3T@(B<G(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&%R<F%Y=F%L(#T@)R<["B`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D87)R87EV86P@/2`G)SL*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@)V%R<F%Y*"<@+B`D87)R
M87EV86P@+B`G*2<["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("`@("`@8V%S92`G8F]O;&5A;B<Z"B`@("`@("`@("`@("`@("`@
M("`@:68@*&ES7V)O;VPH)'9A;"DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)'9A;'5E(#T@)'9A;"`_("=T<G5E)R`Z("=F86QS92<["B`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)'9A;'5E(#T@*"1V86P@/3T@)V]N)RD@/R`G=')U92<@.B`G9F%L<V4G.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@("`@("!C87-E("=S=')I;F=L:7-T)SH*("`@("`@
M("`@("`@("`@("`@("`D=F%L=65S(#T@97AP;&]D92@G+"<L("1V86PI.PH@
M("`@("`@("`@("`@("`@("`@(&EF("@A:7-?87)R87DH)'9A;'5E<RDI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@(F%R<F%Y*"<B("X@
M)'1H:7,M/E]Q=6]T92AT<FEM*"1V86QU97,I*2`N("(G*2(["B`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&5N8W9A;',@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@("`@("!F
M;W)E86-H("@D=F%L=65S(&%S("1V*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D96YC=F%L<UM=(#T@)'1H:7,M/E]Q=6]T92AT<FEM*"1V*2D[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`@("`@)&%R<F%Y=F%L(#T@(B<B("X@:6UP;&]D92@G7"<L(%PG)RP@)&5N
M8W9A;',I("X@(B<B.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&%R
M<F%Y=F%L(#T]("(G)R(I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1A<G)A>79A;"`]("<G.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@("`@("1V86QU92`]("=A<G)A>2@G("X@)&%R
M<F%Y=F%L("X@)RDG.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=I;G0G
M.@H@("`@("`@("`@("`@("`@("`@(&EF("@D=F%L("$]/2`G)RD@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2`H:6YT*21V86P["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@("`@(&-A<V4@)V]C=&%L)SH*("`@("`@("`@("`@("`@
M("`@("`D=F%L=64@/2!S<')I;G1F*"<P)6\G+"!O8W1D96,H)'9A;"DI.PH@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A
M<V4@)VAE861E<B<Z"B`@("`@("`@("`@("`@("!C87-E("=D97-C<FEP=&EO
M;B<Z"B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@
M("`@9&5F875L=#H*("`@("`@("`@("`@("`@("`@("!I9B`H)'9A;"`A/2`G
M)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2`D=F%L.PH@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'%U;W1E("8F("1V86QU92`A
M/2`G=')U92<@)B8@)'9A;'5E("$]("=F86QS92<I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1V86QU92`]("(G(B`N("1T:&ES+3Y?<75O=&4H
M)'9A;'5E*2`N("(G(CL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?9V5N97)A=&502%!#;VYF:6<H)&-O;F9I9VET
M96TL("1P<F5F:7AE9&YA;64L("1F;W)M=F%R<RD["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@(&EF("AI<W-E="@D=F%L=64I*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!H<$-O;F9I9R`N/2`G)&-O;F9;7"<G("X@<W1R7W)E
M<&QA8V4H)U]?)RP@)UPG75M<)R<L("1C;VYF:6=N86UE*2`N("=<)UT@/2`G
M("X@)'9A;'5E("X@(CM<;B(["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M=6YS970H)'9A;'5E*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!087)S97,@;VYE(&QE=F5L(&]F('1H92!C;VYF:6=U<F%T:6]N(%A-3"!T
M<F5E(&EN=&\@=&AE(&%S<V]C:6%T:79E"B`@("`@*B!A<G)A>2!C;VYT86EN
M:6YG('1H92!T<F%V97)S960@8V]N9FEG=7)A=&EO;B!T<F5E+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`F)&-O;F8@("`@(%1H92!A;')E861Y(&5X:7-T:6YG(&%R<F%Y('=H
M97)E('1H92!P<F]C97-S960*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@(%A-3"!T<F5E('!O<G1I;VX@<VAO=6QD(&)E(&%P<&5N9&5D('1O+@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1C:&EL9')E;B`@06X@87)R87D@8V]N=&%I
M;FEN9R!T:&4@6$U,(&YO9&5S(&]F('1H92!L979E;`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@=&AA="!S:&]U;&0@8F4@<&%R<V5D+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D8W1X("`@("`@02!S=')I;F<@<F5P<F5S96YT
M:6YG('1H92!C=7)R96YT('!O<VET:6]N"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`H8V]N=&5X="!P<F5F:7@I(&EN<VED92!T:&4@8V]N9FEG
M=7)A=&EO;B!834P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&9I
M;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P87)S94QE=F5L*"8D8V]N9BP@
M)&-H:6QD<F5N+"`D8W1X*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G
M2&]R9&4O5&5X="]&:6QT97(N<&AP)SL*"B`@("`@("`@9F]R96%C:"`H)&-H
M:6QD<F5N(&%S("1N;V1E*2!["B`@("`@("`@("`@(&EF("@D;F]D92T^='EP
M92`A/2!834Q?14Q%345.5%].3T1%*2!["B`@("`@("`@("`@("`@("!C;VYT
M:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D;F%M92`]("1N;V1E
M+3YG971?871T<FEB=71E*"=N86UE)RD["B`@("`@("`@("`@("1D97-C(#T@
M5&5X=%]&:6QT97(Z.F9I;'1E<B@D;F]D92T^9V5T7V%T=')I8G5T92@G9&5S
M8R<I+"`G;&EN:W5R;',G+"!A<G)A>2@G8V%L;&)A8VLG(#T^("=(;W)D93HZ
M97AT97)N86Q5<FPG*2D["B`@("`@("`@("`@("1R97%U:7)E9"`]("$H)&YO
M9&4M/F=E=%]A='1R:6)U=&4H)W)E<75I<F5D)RD@/3T@)V9A;'-E)RD["B`@
M("`@("`@("`@("1Q=6]T92`]("$H)&YO9&4M/F=E=%]A='1R:6)U=&4H)W%U
M;W1E)RD@/3T@)V9A;'-E)RD["B`@("`@("`@("`@(&EF("@A96UP='DH)&-T
M>"DI('L*("`@("`@("`@("`@("`@("1C=7)C='@@/2`D8W1X("X@)WPG("X@
M)&YA;64["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M8W5R8W1X(#T@)&YA;64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@('-W
M:71C:"`H)&YO9&4M/G1A9VYA;64I('L*("`@("`@("`@("`@8V%S92`G8V]N
M9FEG9&5S8W)I<'1I;VXG.@H@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1N
M86UE*2D@>PH@("`@("`@("`@("`@("`@("`@("1N86UE(#T@;60U*&UI8W)O
M=&EM92@I*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1C
M;VYF6R1N86UE72`](&%R<F%Y*"=?='EP92<@/3X@)V1E<V-R:7!T:6]N)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D97-C)R`]
M/B!497AT7T9I;'1E<CHZ9FEL=&5R*"1T:&ES+3Y?9&5F875L="@D8W5R8W1X
M+"`D=&AI<RT^7V=E=$YO9&5/;FQY5&5X="@D;F]D92DI+"`G;&EN:W5R;',G
M+"!A<G)A>2@G8V%L;&)A8VLG(#T^("=(;W)D93HZ97AT97)N86Q5<FPG*2DI
M.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=C
M;VYF:6=H96%D97(G.@H@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1N86UE
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1N86UE(#T@;60U*&UI8W)O=&EM
M92@I*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1C;VYF
M6R1N86UE72`](&%R<F%Y*"=?='EP92<@/3X@)VAE861E<B<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)'1H:7,M
M/E]D969A=6QT*"1C=7)C='@L("1T:&ES+3Y?9V5T3F]D94]N;'E497AT*"1N
M;V1E*2DI.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C
M87-E("=C;VYF:6=S=VET8V@G.@H@("`@("`@("`@("`@("`@)'9A;'5E<R`]
M("1T:&ES+3Y?9V5T4W=I=&-H5F%L=65S*"1N;V1E+"`D8W1X*3L*("`@("`@
M("`@("`@("`@(&EF("@D<75O=&4I('L*("`@("`@("`@("`@("`@("`@("`D
M9&5F875L="`]("1T:&ES+3Y?9&5F875L="@D8W5R8W1X+"`D=&AI<RT^7V=E
M=$YO9&5/;FQY5&5X="@D;F]D92DI.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`D9&5F875L="`]("1T:&ES+3Y?9&5F
M875L=%)A=R@D8W5R8W1X+"`D=&AI<RT^7V=E=$YO9&5/;FQY5&5X="@D;F]D
M92DI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"1D
M969A=6QT(#T]/2`G)RD@>PH@("`@("`@("`@("`@("`@("`@("1D969A=6QT
M(#T@:V5Y*"1V86QU97,I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@:68@*&ES7V)O;VPH)&1E9F%U;'0I*2!["B`@("`@("`@("`@("`@
M("`@("`@)&1E9F%U;'0@/2`D9&5F875L="`_("=T<G5E)R`Z("=F86QS92<[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D8V]N9ELD;F%M
M95T@/2!A<G)A>2@G9&5S8R<@/3X@)&1E<V,L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G<W=I=&-H)R`]/B`D=F%L=65S+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^
M("1D969A=6QT*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@8V%S92`G8V]N9FEG96YU;2<Z"B`@("`@("`@("`@("`@("`D=F%L=65S
M(#T@)'1H:7,M/E]G971%;G5M5F%L=65S*"1N;V1E*3L*("`@("`@("`@("`@
M("`@(&EF("@D<75O=&4I('L*("`@("`@("`@("`@("`@("`@("`D9&5F875L
M="`]("1T:&ES+3Y?9&5F875L="@D8W5R8W1X+"`D=&AI<RT^7V=E=$YO9&5/
M;FQY5&5X="@D;F]D92DI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`D9&5F875L="`]("1T:&ES+3Y?9&5F875L=%)A
M=R@D8W5R8W1X+"`D=&AI<RT^7V=E=$YO9&5/;FQY5&5X="@D;F]D92DI.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"1D969A=6QT
M(#T]/2`G)RD@>PH@("`@("`@("`@("`@("`@("`@("1D969A=6QT(#T@:V5Y
M*"1V86QU97,I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M:68@*&ES7V)O;VPH)&1E9F%U;'0I*2!["B`@("`@("`@("`@("`@("`@("`@
M)&1E9F%U;'0@/2`D9&5F875L="`_("=T<G5E)R`Z("=F86QS92<["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D8V]N9ELD;F%M95T@/2!A
M<G)A>2@G7W1Y<&4G(#T^("=E;G5M)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=R97%U:7)E9"<@/3X@)')E<75I<F5D+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W%U;W1E)R`]/B`D
M<75O=&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M=F%L=65S)R`]/B`D=F%L=65S+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V1E<V,G(#T^("1D97-C+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^("1D969A=6QT*3L*
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G8V]N
M9FEG;&ES="<Z"B`@("`@("`@("`@("`@("`D9&5F875L="`]("1T:&ES+3Y?
M9&5F875L="@D8W5R8W1X+"!N=6QL*3L*("`@("`@("`@("`@("`@(&EF("@D
M9&5F875L="`]/3T@;G5L;"D@>PH@("`@("`@("`@("`@("`@("`@("1D969A
M=6QT(#T@)'1H:7,M/E]G971.;V1E3VYL>51E>'0H)&YO9&4I.PH@("`@("`@
M("`@("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y*"1D969A=6QT*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1D969A=6QT(#T@:6UP;&]D92@G+"`G+"`D9&5F
M875L="D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D8V]N
M9ELD;F%M95T@/2!A<G)A>2@G7W1Y<&4G(#T^("=S=')I;F=L:7-T)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R97%U:7)E9"<@
M/3X@)')E<75I<F5D+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)V1E<V,G(#T^("1D97-C+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^("1D969A=6QT*3L*("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G8V]N9FEG;75L
M=&EE;G5M)SH*("`@("`@("`@("`@("`@("1V86QU97,@/2`D=&AI<RT^7V=E
M=$5N=6U686QU97,H)&YO9&4I.PH@("`@("`@("`@("`@("`@<F5Q=6ER95]O
M;F-E("=(;W)D92]!<G)A>2YP:'`G.PH@("`@("`@("`@("`@("`@)&-O;F9;
M)&YA;65=(#T@87)R87DH)U]T>7!E)R`]/B`G;75L=&EE;G5M)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R97%U:7)E9"<@/3X@
M)')E<75I<F5D+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W9A;'5E<R<@/3X@)'9A;'5E<RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=D97-C)R`]/B`D9&5S8RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=D969A=6QT)R`]/B!(;W)D95]!
M<G)A>3HZ=F%L=65S5&]+97ES*"1T:&ES+3Y?9&5F875L="@D8W5R8W1X+"!E
M>'!L;V1E*"<L)RP@)'1H:7,M/E]G971.;V1E3VYL>51E>'0H)&YO9&4I*2DI
M*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G
M8V]N9FEG<&%S<W=O<F0G.@H@("`@("`@("`@("`@("`@)&-O;F9;)&YA;65=
M(#T@87)R87DH)U]T>7!E)R`]/B`G<&%S<W=O<F0G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W)E<75I<F5D)R`]/B`D<F5Q=6ER
M960L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5S
M8R<@/3X@)&1E<V,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G9&5F875L="<@/3X@)'1H:7,M/E]D969A=6QT*"1C=7)C='@L("1T
M:&ES+3Y?9V5T3F]D94]N;'E497AT*"1N;V1E*2DI.PH@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=C;VYF:6=S=')I;F<G.@H@
M("`@("`@("`@("`@("`@)&-O;F9;)&YA;65=(#T@87)R87DH)U]T>7!E)R`]
M/B`G=&5X="<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G<F5Q=6ER960G(#T^("1R97%U:7)E9"P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=D97-C)R`]/B`D9&5S8RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D969A=6QT)R`]/B`D=&AI
M<RT^7V1E9F%U;'0H)&-U<F-T>"P@)'1H:7,M/E]G971.;V1E3VYL>51E>'0H
M)&YO9&4I*2D["B`@("`@("`@("`@("`@("!I9B`H)&-O;F9;)&YA;65=6R=D
M969A=6QT)UT@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`@("`@)&-O
M;F9;)&YA;65=6R=D969A=6QT)UT@/2`G9F%L<V4G.PH@("`@("`@("`@("`@
M("`@?2!E;'-E:68@*"1C;VYF6R1N86UE75LG9&5F875L="==(#T]/2!T<G5E
M*2!["B`@("`@("`@("`@("`@("`@("`@)&-O;F9;)&YA;65=6R=D969A=6QT
M)UT@/2`G=')U92<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V-O;F9I9V)O;VQE86XG.@H@
M("`@("`@("`@("`@("`@)&1E9F%U;'0@/2`D=&AI<RT^7V=E=$YO9&5/;FQY
M5&5X="@D;F]D92D["B`@("`@("`@("`@("`@("!I9B`H96UP='DH)&1E9F%U
M;'0I('Q\("1D969A=6QT(#T]/2`G9F%L<V4G*2!["B`@("`@("`@("`@("`@
M("`@("`@)&1E9F%U;'0@/2!F86QS93L*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@)&1E9F%U;'0@/2!T<G5E.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&-O;F9;)&YA;65=(#T@
M87)R87DH)U]T>7!E)R`]/B`G8F]O;&5A;B<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G<F5Q=6ER960G(#T^("1R97%U:7)E9"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D97-C)R`]
M/B`D9&5S8RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-U<F-T>"P@)&1E9F%U
M;'0I*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S
M92`G8V]N9FEG:6YT96=E<B<Z"B`@("`@("`@("`@("`@("`D=F%L=65S(#T@
M)'1H:7,M/E]G971%;G5M5F%L=65S*"1N;V1E*3L*("`@("`@("`@("`@("`@
M("1C;VYF6R1N86UE72`](&%R<F%Y*"=?='EP92<@/3X@)VEN="<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5Q=6ER960G(#T^
M("1R97%U:7)E9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=V86QU97,G(#T^("1V86QU97,L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)&1E<V,L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@)'1H:7,M
M/E]D969A=6QT*"1C=7)C='@L("1T:&ES+3Y?9V5T3F]D94]N;'E497AT*"1N
M;V1E*2DI.PH@("`@("`@("`@("`@("`@:68@*"1N;V1E+3YG971?871T<FEB
M=71E*"=O8W1A;"<I(#T]("=T<G5E)R`F)@H@("`@("`@("`@("`@("`@("`@
M("1C;VYF6R1N86UE75LG9&5F875L="==("$]("<G*2!["B`@("`@("`@("`@
M("`@("`@("`@)&-O;F9;)&YA;65=6R=?='EP92==(#T@)V]C=&%L)SL*("`@
M("`@("`@("`@("`@("`@("`D8V]N9ELD;F%M95U;)V1E9F%U;'0G72`]('-P
M<FEN=&8H)S`E;R<L("1T:&ES+3Y?9&5F875L="@D8W5R8W1X+"!O8W1D96,H
M)'1H:7,M/E]G971.;V1E3VYL>51E>'0H)&YO9&4I*2DI.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C
M87-E("=C;VYF:6=P:'`G.@H@("`@("`@("`@("`@("`@)&-O;F9;)&YA;65=
M(#T@87)R87DH)U]T>7!E)R`]/B`G<&AP)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=R97%U:7)E9"<@/3X@)')E<75I<F5D+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W%U;W1E)R`]
M/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=D97-C)R`]/B`D9&5S8RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'1287<H)&-U
M<F-T>"P@)'1H:7,M/E]G971.;V1E3VYL>51E>'0H)&YO9&4I*2D["B`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V-O;F9I9W-Q
M;"<Z"B`@("`@("`@("`@("`@("`D8V]N9ELD;F]D92T^9V5T7V%T=')I8G5T
M92@G<W=I=&-H;F%M92<I72`]("1T:&ES+3Y?8V]N9FEG4U%,*"1C='@L("1N
M;V1E*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S
M92`G8V]N9FEG=F9S)SH*("`@("`@("`@("`@("`@("1C;VYF6R1N;V1E+3YG
M971?871T<FEB=71E*"=S=VET8VAN86UE)RE=(#T@)'1H:7,M/E]C;VYF:6=6
M1E,H)&-T>"P@)&YO9&4I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("!C87-E("=C;VYF:6=S96-T:6]N)SH*("`@("`@("`@("`@("`@
M("1C;VYF6R1N86UE72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`D8W5R
M(#T@)B1C;VYF6R1N86UE73L*("`@("`@("`@("`@("`@(&EF("@D;F]D92T^
M:&%S7V-H:6QD7VYO9&5S*"DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<G-E3&5V96PH)&-U<BP@)&YO9&4M/F-H:6QD7VYO9&5S*"DL("1C
M=7)C='@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("!C87-E("=C;VYF:6=T86(G.@H@("`@("`@("`@
M("`@("`@)&ME>2`](&UD-2AM:6-R;W1I;64H*2D["B`@("`@("`@("`@("`@
M("`D8V]N9ELD:V5Y72`](&%R<F%Y*"=T86(G(#T^("1N86UE+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)&1E<V,I
M.PH@("`@("`@("`@("`@("`@:68@*"1N;V1E+3YH87-?8VAI;&1?;F]D97,H
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R<V5,979E;"@D
M8V]N9BP@)&YO9&4M/F-H:6QD7VYO9&5S*"DL("1C='@I.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C
M87-E("=C;VYF:6=P;&%C96AO;&1E<B<Z"B`@("`@("`@("`@("`@("`D8V]N
M9EMM9#4H;6EC<F]T:6UE*"DI72`]("=P;&%C96AO;&1E<B<["B`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@
M("`@("`@("`D8V]N9ELD;F%M95T@/2!A<G)A>2@I.PH@("`@("`@("`@("`@
M("`@)&-U<B`]("8D8V]N9ELD;F%M95T["B`@("`@("`@("`@("`@("!I9B`H
M)&YO9&4M/FAA<U]C:&EL9%]N;V1E<R@I*2!["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P87)S94QE=F5L*"1C=7(L("1N;V1E+3YC:&EL9%]N;V1E
M<R@I+"`D8W5R8W1X*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8V]N9FEG=7)A=&EO;B!T<F5E(&9O
M<B!A;B!344P@8F%C:V5N9"!C;VYF:6=U<F%T:6]N('1O"B`@("`@*B!R97!L
M86-E(&$@/&-O;F9I9W-Q;#X@=&%G+@H@("`@("H@4W5B;F]D97,@=VEL;"!B
M92!P87)S960@86YD(&%D9&5D('1O(&)O=&@@=&AE($AO<F1E(&1E9F%U;'1S
M(&%N9"!T:&4*("`@("`J($-U<W1O;2!C;VYF:6=U<F%T:6]N('!A<G1S+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&-T>"`@("`@("`@(%1H92!C;VYT97AT(&]F('1H92`\
M8V]N9FEG<W%L/B!T86<N"B`@("`@*B!`<&%R86T@1&]M3F]D92`D;F]D92`@
M("`@("!4:&4@1&]M3F]D92!R97!R97-E;G1A=&EO;B!O9B!T:&4@/&-O;F9I
M9W-Q;#X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@('1A9RX*
M("`@("`J($!P87)A;2!S=')I;F<@)'-W:71C:&YA;64@($EF($1O;4YO9&4@
M:7,@;F]T('-E="P@=&AE('9A;'5E(&]F('1H90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@=&%G)W,@<W=I=&-H;F%M92!A='1R:6)U=&4N
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87-S;V-I871I=F4@
M87)R87D@=VET:"!T:&4@4U%,(&-O;F9I9W5R871I;VX@=')E92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V-O;F9I9U-13"@D8W1X+"`D;F]D92`](&YU;&PL
M("1S=VET8VAN86UE(#T@)V1R:79E<F-O;F9I9R<I"B`@("!["B`@("`@("`@
M)'!E<G-I<W1E;G0@/2!A<G)A>2@*("`@("`@("`@("`@)U]T>7!E)R`]/B`G
M8F]O;&5A;B<L"B`@("`@("`@("`@("=R97%U:7)E9"<@/3X@9F%L<V4L"B`@
M("`@("`@("`@("=D97-C)R`]/B`G4F5Q=65S="!P97)S:7-T96YT(&-O;FYE
M8W1I;VYS/R<L"B`@("`@("`@("`@("=D969A=6QT)R`]/B`D=&AI<RT^7V1E
M9F%U;'0H)&-T>"`N("=\<&5R<VES=&5N="<L(&9A;'-E*2D["B`@("`@("`@
M)&AO<W1S<&5C(#T@87)R87DH"B`@("`@("`@("`@("=?='EP92<@/3X@)W1E
M>'0G+`H@("`@("`@("`@("`G<F5Q=6ER960G(#T^('1R=64L"B`@("`@("`@
M("`@("=D97-C)R`]/B`G1&%T86)A<V4@<V5R=F5R+VAO<W0G+`H@("`@("`@
M("`@("`G9&5F875L="<@/3X@)'1H:7,M/E]D969A=6QT*"1C='@@+B`G?&AO
M<W1S<&5C)RP@)R<I*3L*("`@("`@("`D=7-E<FYA;64@/2!A<G)A>2@*("`@
M("`@("`@("`@)U]T>7!E)R`]/B`G=&5X="<L"B`@("`@("`@("`@("=R97%U
M:7)E9"<@/3X@=')U92P*("`@("`@("`@("`@)V1E<V,G(#T^("=5<V5R;F%M
M92!T;R!C;VYN96-T('1O('1H92!D871A8F%S92!A<R<L"B`@("`@("`@("`@
M("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-T>"`N("=\=7-E<FYA
M;64G+"`G)RDI.PH@("`@("`@("1P87-S=V]R9"`](&%R<F%Y*`H@("`@("`@
M("`@("`G7W1Y<&4G(#T^("=T97AT)RP*("`@("`@("`@("`@)W)E<75I<F5D
M)R`]/B!F86QS92P*("`@("`@("`@("`@)V1E<V,G(#T^("=087-S=V]R9"!T
M;R!C;VYN96-T('=I=&@G+`H@("`@("`@("`@("`G9&5F875L="<@/3X@)'1H
M:7,M/E]D969A=6QT*"1C='@@+B`G?'!A<W-W;W)D)RP@)R<I*3L*("`@("`@
M("`D9&%T86)A<V4@/2!A<G)A>2@*("`@("`@("`@("`@)U]T>7!E)R`]/B`G
M=&5X="<L"B`@("`@("`@("`@("=R97%U:7)E9"<@/3X@=')U92P*("`@("`@
M("`@("`@)V1E<V,G(#T^("=$871A8F%S92!N86UE('1O('5S92<L"B`@("`@
M("`@("`@("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-T>"`N("=\
M9&%T86)A<V4G+"`G)RDI.PH@("`@("`@("1S;V-K970@/2!A<G)A>2@*("`@
M("`@("`@("`@)U]T>7!E)R`]/B`G=&5X="<L"B`@("`@("`@("`@("=R97%U
M:7)E9"<@/3X@9F%L<V4L"B`@("`@("`@("`@("=D97-C)R`]/B`G3&]C871I
M;VX@;V8@54Y)6"!S;V-K970G+`H@("`@("`@("`@("`G9&5F875L="<@/3X@
M)'1H:7,M/E]D969A=6QT*"1C='@@+B`G?'-O8VME="<L("<G*2D["B`@("`@
M("`@)'!O<G0@/2!A<G)A>2@*("`@("`@("`@("`@)U]T>7!E)R`]/B`G:6YT
M)RP*("`@("`@("`@("`@)W)E<75I<F5D)R`]/B!F86QS92P*("`@("`@("`@
M("`@)V1E<V,G(#T^("=0;W)T('1H92!$0B!I<R!R=6YN:6YG(&]N+"!I9B!N
M;VXM<W1A;F1A<F0G+`H@("`@("`@("`@("`G9&5F875L="<@/3X@)'1H:7,M
M/E]D969A=6QT*"1C='@@+B`G?'!O<G0G+"!N=6QL*2D["B`@("`@("`@)'!R
M;W1O8V]L(#T@87)R87DH"B`@("`@("`@("`@("=D97-C)R`]/B`G2&]W('-H
M;W5L9"!W92!C;VYN96-T('1O('1H92!D871A8F%S93\G+`H@("`@("`@("`@
M("`G9&5F875L="<@/3X@)'1H:7,M/E]D969A=6QT*"1C='@@+B`G?'!R;W1O
M8V]L)RP@)W5N:7@G*2P*("`@("`@("`@("`@)W-W:71C:"<@/3X@87)R87DH
M"B`@("`@("`@("`@("`@("`G=6YI>"<@/3X@87)R87DH"B`@("`@("`@("`@
M("`@("`@("`@)V1E<V,G(#T^("=53DE8(%-O8VME=',G+`H@("`@("`@("`@
M("`@("`@("`@("=F:65L9',G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@
M("`@("`@("`G<V]C:V5T)R`]/B`D<V]C:V5T*2DL"B`@("`@("`@("`@("`@
M("`G=&-P)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G9&5S8R<@
M/3X@)U1#4"])4"<L"B`@("`@("`@("`@("`@("`@("`@)V9I96QD<R<@/3X@
M87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=P;W)T)R`]/B`D<&]R
M="DI*2D["B`@("`@("`@)&UY<W%L7W!R;W1O8V]L(#T@)'!R;W1O8V]L.PH@
M("`@("`@("1M>7-Q;%]P<F]T;V-O;%LG<W=I=&-H)UU;)W1C<"==6R=F:65L
M9',G75LG<&]R="==6R=D969A=6QT)UT@/2`D=&AI<RT^7V1E9F%U;'0H)&-T
M>"`N("=\<&]R="<L(#,S,#8I.PH@("`@("`@("1C:&%R<V5T(#T@87)R87DH
M"B`@("`@("`@("`@("=?='EP92<@/3X@)W1E>'0G+`H@("`@("`@("`@("`G
M<F5Q=6ER960G(#T^('1R=64L"B`@("`@("`@("`@("=D97-C)R`]/B`G26YT
M97)N86QL>2!U<V5D(&-H87)S970G+`H@("`@("`@("`@("`G9&5F875L="<@
M/3X@)'1H:7,M/E]D969A=6QT*"1C='@@+B`G?&-H87)S970G+"`G:7-O+3@X
M-3DM,2<I*3L*"B`@("`@("`@)&]C:3A?9FEE;&1S(#T@87)R87DH"B`@("`@
M("`@("`@("=P97)S:7-T96YT)R`]/B`D<&5R<VES=&5N="P*("`@("`@("`@
M("`@)W5S97)N86UE)R`]/B`D=7-E<FYA;64L"B`@("`@("`@("`@("=P87-S
M=V]R9"<@/3X@)'!A<W-W;W)D*3L*("`@("`@("!I9B`H9G5N8W1I;VY?97AI
M<W1S*"=O8VE?8V]N;F5C="<I*2!["B`@("`@("`@("`@("1O8VDX7V9I96QD
M<ULG9&%T86)A<V4G72`](&%R<F%Y*`H@("`@("`@("`@("`@("`@)U]T>7!E
M)R`]/B`G=&5X="<L"B`@("`@("`@("`@("`@("`G<F5Q=6ER960G(#T^('1R
M=64L"B`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)T1A=&%B87-E(&YA;64@
M;W(@16%S>2!#;VYN96-T('!A<F%M971E<B<L"B`@("`@("`@("`@("`@("`G
M9&5F875L="<@/3X@)'1H:7,M/E]D969A=6QT*"1C='@@+B`G?&1A=&%B87-E
M)RP@)VAO<F1E)RDI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1O
M8VDX7V9I96QD<ULG:&]S='-P96,G72`](&%R<F%Y*`H@("`@("`@("`@("`@
M("`@)U]T>7!E)R`]/B`G=&5X="<L"B`@("`@("`@("`@("`@("`G<F5Q=6ER
M960G(#T^('1R=64L"B`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)T1A=&%B
M87-E(&YA;64@;W(@16%S>2!#;VYN96-T('!A<F%M971E<B<L"B`@("`@("`@
M("`@("`@("`G9&5F875L="<@/3X@)'1H:7,M/E]D969A=6QT*"1C='@@+B`G
M?&AO<W1S<&5C)RP@)VAO<F1E)RDI.PH@("`@("`@('T*("`@("`@("`D;V-I
M.%]F:65L9'-;)V-H87)S970G72`]("1C:&%R<V5T.PH*("`@("`@("`D8W5S
M=&]M7V9I96QD<R`](&%R<F%Y*`H@("`@("`@("`@("`G<F5Q=6ER960G(#T^
M('1R=64L"B`@("`@("`@("`@("=D97-C)R`]/B`G5VAA="!D871A8F%S92!B
M86-K96YD('-H;W5L9"!W92!U<V4_)RP*("`@("`@("`@("`@)V1E9F%U;'0G
M(#T^("1T:&ES+3Y?9&5F875L="@D8W1X("X@)WQP:'!T>7!E)RP@)V9A;'-E
M)RDL"B`@("`@("`@("`@("=S=VET8V@G(#T^(&%R<F%Y*`H@("`@("`@("`@
M("`@("`@)V9A;'-E)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G
M9&5S8R<@/3X@)UM.;VYE72<L"B`@("`@("`@("`@("`@("`@("`@)V9I96QD
M<R<@/3X@87)R87DH*2DL"B`@("`@("`@("`@("`@("`G9&)A<V4G(#T^(&%R
M<F%Y*`H@("`@("`@("`@("`@("`@("`@("=D97-C)R`]/B`G9$)A<V4G+`H@
M("`@("`@("`@("`@("`@("`@("=F:65L9',G(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`@("`@("`@("`@("`G9&%T86)A<V4G(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)U]T>7!E)R`]/B`G=&5X="<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G<F5Q=6ER960G(#T^('1R=64L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)T%B<V]L=71E
M('!A=&@@=&\@=&AE(&1A=&%B87-E(&9I;&4G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V1E9F%U;'0G(#T^("1T:&ES+3Y?9&5F875L="@D8W1X
M("X@)WQD871A8F%S92<L("<G*2DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("=M;V1E)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=?='EP92<@/3X@)V5N=6TG+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V1E<V,G(#T^("=4:&4@;6]D92!T;R!O<&5N('1H92!F:6QE('=I=&@G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W9A;'5E<R<@/3X@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@,"`]/B`G4F5A
M9"!/;FQY)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`R(#T^
M("=296%D(%=R:71E)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M9&5F875L="<@/3X@)'1H:7,M/E]D969A=6QT*"1C='@@+B`G?&UO9&4G+"`R
M*2DL"@H@("`@("`@("`@("`@("`@("`@("`@("`G8VAA<G-E="<@/3X@)&-H
M87)S970I*2P*("`@("`@("`@("`@("`@("=I8F%S92<@/3X@87)R87DH"B`@
M("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("=&:7)E8FER9"]);G1E<D)A
M<V4G+`H@("`@("`@("`@("`@("`@("`@("=F:65L9',G(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("`@("`G9&)S>6YT87@G(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)U]T>7!E)R`]/B`G96YU;2<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)U1H92!D
M871A8F%S92!S>6YT87@@=F%R:6%N="!T;R!U<V4G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W)E<75I<F5D)R`]/B!F86QS92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=V86QU97,G(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=I8F%S92<@/3X@)TEN=&5R0F%S
M92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V9I<F5B:7)D
M)R`]/B`G1FER96)I<F0G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-T>"`N("=\9&)S>6YT
M87@G+"`G9FER96)I<F0G*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("=P
M97)S:7-T96YT)R`]/B`D<&5R<VES=&5N="P*("`@("`@("`@("`@("`@("`@
M("`@("`@)VAO<W1S<&5C)R`]/B`D:&]S='-P96,L"B`@("`@("`@("`@("`@
M("`@("`@("`@("=U<V5R;F%M92<@/3X@)'5S97)N86UE+`H@("`@("`@("`@
M("`@("`@("`@("`@("`G<&%S<W=O<F0G(#T^("1P87-S=V]R9"P*("`@("`@
M("`@("`@("`@("`@("`@("`@)V1A=&%B87-E)R`]/B`D9&%T86)A<V4L"B`@
M("`@("`@("`@("`@("`@("`@("`@("=B=69F97)S)R`]/B!A<G)A>2@*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=?='EP92<@/3X@)VEN="<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)U1H92!N=6UB
M97(@;V8@9&%T86)A<V4@8G5F9F5R<R!T;R!A;&QO8V%T92<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G<F5Q=6ER960G(#T^(&9A;'-E+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^("1T:&ES+3Y?
M9&5F875L="@D8W1X("X@)WQB=69F97)S)RP@;G5L;"DI+`H@("`@("`@("`@
M("`@("`@("`@("`@("`G9&EA;&5C="<@/3X@87)R87DH"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G7W1Y<&4G(#T^("=I;G0G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("=4:&4@9&5F875L="!344P@
M9&EA;&5C="!F;W(@86YY('-T871E;65N="!E>&5C=71E9"!W:71H:6X@82!C
M;VYN96-T:6]N+B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5Q
M=6ER960G(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V1E9F%U;'0G(#T^("1T:&ES+3Y?9&5F875L="@D8W1X("X@)WQD:6%L96-T
M)RP@;G5L;"DI+`H@("`@("`@("`@("`@("`@("`@("`@("`G<F]L92<@/3X@
M87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G7W1Y<&4G(#T^
M("=T97AT)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D97-C)R`]
M/B`G4F]L92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5Q=6ER
M960G(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1E
M9F%U;'0G(#T^("1T:&ES+3Y?9&5F875L="@D8W1X("X@)WQR;VQE)RP@;G5L
M;"DI+`H@("`@("`@("`@("`@("`@("`@("`@("`G8VAA<G-E="<@/3X@)&-H
M87)S970I*2P*("`@("`@("`@("`@("`@("=F8G-Q;"<@/3X@87)R87DH"B`@
M("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("=&<F]N=&)A<V4G+`H@("`@
M("`@("`@("`@("`@("`@("=F:65L9',G(#T^(&%R<F%Y*`H@("`@("`@("`@
M("`@("`@("`@("`@("`G<&5R<VES=&5N="<@/3X@)'!E<G-I<W1E;G0L"B`@
M("`@("`@("`@("`@("`@("`@("`@("=H;W-T<W!E8R<@/3X@)&AO<W1S<&5C
M+`H@("`@("`@("`@("`@("`@("`@("`@("`G=7-E<FYA;64G(#T^("1U<V5R
M;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@)W!A<W-W;W)D)R`]/B`D
M<&%S<W=O<F0L"B`@("`@("`@("`@("`@("`@("`@("`@("=D871A8F%S92<@
M/3X@)&1A=&%B87-E+`H@("`@("`@("`@("`@("`@("`@("`@("`G8VAA<G-E
M="<@/3X@)&-H87)S970I*2P*("`@("`@("`@("`@("`@("=I9G@G(#T^(&%R
M<F%Y*`H@("`@("`@("`@("`@("`@("`@("=D97-C)R`]/B`G26YF;W)M:7@G
M+`H@("`@("`@("`@("`@("`@("`@("=F:65L9',G(#T^(&%R<F%Y*`H@("`@
M("`@("`@("`@("`@("`@("`@("`G<&5R<VES=&5N="<@/3X@)'!E<G-I<W1E
M;G0L"B`@("`@("`@("`@("`@("`@("`@("`@("=U<V5R;F%M92<@/3X@)'5S
M97)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`G<&%S<W=O<F0G(#T^
M("1P87-S=V]R9"P*("`@("`@("`@("`@("`@("`@("`@("`@)V1A=&%B87-E
M)R`]/B`D9&%T86)A<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("=C:&%R
M<V5T)R`]/B`D8VAA<G-E="DI+`H@("`@("`@("`@("`@("`@)VUS<6PG(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=D97-C)R`]/B`G;5-13"<L
M"B`@("`@("`@("`@("`@("`@("`@)V9I96QD<R<@/3X@87)R87DH"B`@("`@
M("`@("`@("`@("`@("`@("`@("=P97)S:7-T96YT)R`]/B`D<&5R<VES=&5N
M="P*("`@("`@("`@("`@("`@("`@("`@("`@)VAO<W1S<&5C)R`]/B`D:&]S
M='-P96,L"B`@("`@("`@("`@("`@("`@("`@("`@("=U<V5R;F%M92<@/3X@
M)'5S97)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`G<&%S<W=O<F0G
M(#T^("1P87-S=V]R9"P*("`@("`@("`@("`@("`@("`@("`@("`@)W!O<G0G
M(#T^("1P;W)T+`H@("`@("`@("`@("`@("`@("`@("`@("`G9&%T86)A<V4G
M(#T^("1D871A8F%S92P*("`@("`@("`@("`@("`@("`@("`@("`@)V-H87)S
M970G(#T^("1C:&%R<V5T*2DL"B`@("`@("`@("`@("`@("`G;7-S<6PG(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=D97-C)R`]/B`G35,@4U%,
M(%-E<G9E<B<L"B`@("`@("`@("`@("`@("`@("`@)V9I96QD<R<@/3X@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=P97)S:7-T96YT)R`]/B`D
M<&5R<VES=&5N="P*("`@("`@("`@("`@("`@("`@("`@("`@)VAO<W1S<&5C
M)R`]/B`D:&]S='-P96,L"B`@("`@("`@("`@("`@("`@("`@("`@("=U<V5R
M;F%M92<@/3X@)'5S97)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`G
M<&%S<W=O<F0G(#T^("1P87-S=V]R9"P*("`@("`@("`@("`@("`@("`@("`@
M("`@)W!O<G0G(#T^("1P;W)T+`H@("`@("`@("`@("`@("`@("`@("`@("`G
M9&%T86)A<V4G(#T^("1D871A8F%S92P*("`@("`@("`@("`@("`@("`@("`@
M("`@)V-H87)S970G(#T^("1C:&%R<V5T*2DL"B`@("`@("`@("`@("`@("`G
M;7ES<6PG(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=D97-C)R`]
M/B`G37E344PG+`H@("`@("`@("`@("`@("`@("`@("=F:65L9',G(#T^(&%R
M<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`G<&5R<VES=&5N="<@/3X@
M)'!E<G-I<W1E;G0L"B`@("`@("`@("`@("`@("`@("`@("`@("=H;W-T<W!E
M8R<@/3X@)&AO<W1S<&5C+`H@("`@("`@("`@("`@("`@("`@("`@("`G=7-E
M<FYA;64G(#T^("1U<V5R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@
M)W!A<W-W;W)D)R`]/B`D<&%S<W=O<F0L"B`@("`@("`@("`@("`@("`@("`@
M("`@("=P<F]T;V-O;"<@/3X@)&UY<W%L7W!R;W1O8V]L+`H@("`@("`@("`@
M("`@("`@("`@("`@("`G9&%T86)A<V4G(#T^("1D871A8F%S92P*("`@("`@
M("`@("`@("`@("`@("`@("`@)V-H87)S970G(#T^("1C:&%R<V5T*2DL"B`@
M("`@("`@("`@("`@("`G;7ES<6QI)R`]/B!A<G)A>2@*("`@("`@("`@("`@
M("`@("`@("`G9&5S8R<@/3X@)TUY4U%,("AM>7-Q;&DI)RP*("`@("`@("`@
M("`@("`@("`@("`G9FEE;&1S)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@
M("`@("`@("`@)W!E<G-I<W1E;G0G(#T^("1P97)S:7-T96YT+`H@("`@("`@
M("`@("`@("`@("`@("`@("`G:&]S='-P96,G(#T^("1H;W-T<W!E8RP*("`@
M("`@("`@("`@("`@("`@("`@("`@)W5S97)N86UE)R`]/B`D=7-E<FYA;64L
M"B`@("`@("`@("`@("`@("`@("`@("`@("=P87-S=V]R9"<@/3X@)'!A<W-W
M;W)D+`H@("`@("`@("`@("`@("`@("`@("`@("`G<&]R="<@/3X@)'!O<G0L
M"B`@("`@("`@("`@("`@("`@("`@("`@("=S;V-K970G(#T^("1S;V-K970L
M"B`@("`@("`@("`@("`@("`@("`@("`@("=D871A8F%S92<@/3X@)&1A=&%B
M87-E+`H@("`@("`@("`@("`@("`@("`@("`@("`G8VAA<G-E="<@/3X@)&-H
M87)S970I*2P*("`@("`@("`@("`@("`@("=O8VDX)R`]/B!A<G)A>2@*("`@
M("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)T]R86-L92<L"B`@("`@("`@
M("`@("`@("`@("`@)V9I96QD<R<@/3X@)&]C:3A?9FEE;&1S*2P*("`@("`@
M("`@("`@("`@("=O9&)C)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@
M("`G9&5S8R<@/3X@)T]$0D,G+`H@("`@("`@("`@("`@("`@("`@("=F:65L
M9',G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`G<&5R<VES
M=&5N="<@/3X@)'!E<G-I<W1E;G0L"B`@("`@("`@("`@("`@("`@("`@("`@
M("=U<V5R;F%M92<@/3X@)'5S97)N86UE+`H@("`@("`@("`@("`@("`@("`@
M("`@("`G<&%S<W=O<F0G(#T^("1P87-S=V]R9"P*("`@("`@("`@("`@("`@
M("`@("`@("`@)VAO<W1S<&5C)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=?='EP92<@/3X@)W1E>'0G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V1E<V,G(#T^("=$4TXG+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^("1T:&ES+3Y?9&5F875L="@D
M8W1X("X@)WQH;W-T<W!E8R<L("<G*2DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("=D8G-Y;G1A>"<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G7W1Y<&4G(#T^("=E;G5M)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=D97-C)R`]/B`G5&AE(&1A=&%B87-E('-Y;G1A>"!V87)I
M86YT('1O('5S92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5Q
M=6ER960G(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W9A;'5E<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W-Q;#DR)R`]/B`G4U%,.3(G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=A8V-E<W,G(#T^("=!8V-E<W,G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=D8C(G(#T^("=$0C(G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=S;VQI9"<@/3X@)U-O;&ED)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;F%V:7-I;VXG(#T^
M("=.879I<VEO;B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)VUS<W%L)R`]/B`G35,@4U%,(%-E<G9E<B<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W-Y8F%S92<@/3X@)U-Y8F%S92<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)VUY<W%L)R`]/B`G37E344PG+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M>7-Q;&DG(#T^("=-
M>5-13"`H;7ES<6QI*2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D969A=6QT)R`]
M/B`D=&AI<RT^7V1E9F%U;'0H)&-T>"`N("=\9&)S>6YT87@G+"`G<W%L.3(G
M*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("=C=7)S;W(G(#T^(&%R<F%Y
M*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U]T>7!E)R`]/B`G96YU
M;2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)T-U
M<G-O<B!T>7!E)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=Q=6]T
M92<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5Q
M=6ER960G(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W9A;'5E<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VYU;&PG(#T^("=.;VYE)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G4U%,7T-54E]$149!54Q4)R`]/B`G1&5F875L="<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U-13%]#55)?55-%7T12
M259%4B<@/3X@)U5S92!$<FEV97(G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=344Q?0U527U5315]/1$)#)R`]/B`G57-E($]$0D,G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=344Q?0U527U5315])
M1E].145$140G(#T^("=5<V4@268@3F5E9&5D)RDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G9&5F875L="<@/3X@)'1H:7,M/E]D969A=6QT*"1C
M='@@+B`G?&-U<G-O<B<L(&YU;&PI*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@)V-H87)S970G(#T^("1C:&%R<V5T*2DL"B`@("`@("`@("`@("`@("`G
M<&=S<6PG(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=D97-C)R`]
M/B`G4&]S=&=R95-13"<L"B`@("`@("`@("`@("`@("`@("`@)V9I96QD<R<@
M/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=P97)S:7-T96YT
M)R`]/B`D<&5R<VES=&5N="P*("`@("`@("`@("`@("`@("`@("`@("`@)VAO
M<W1S<&5C)R`]/B`D:&]S='-P96,L"B`@("`@("`@("`@("`@("`@("`@("`@
M("=U<V5R;F%M92<@/3X@)'5S97)N86UE+`H@("`@("`@("`@("`@("`@("`@
M("`@("`G<&%S<W=O<F0G(#T^("1P87-S=V]R9"P*("`@("`@("`@("`@("`@
M("`@("`@("`@)W!R;W1O8V]L)R`]/B`D<')O=&]C;VPL"B`@("`@("`@("`@
M("`@("`@("`@("`@("=D871A8F%S92<@/3X@)&1A=&%B87-E+`H@("`@("`@
M("`@("`@("`@("`@("`@("`G8VAA<G-E="<@/3X@)&-H87)S970I*2P*("`@
M("`@("`@("`@("`@("=S<6QI=&4G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("=D97-C)R`]/B`G4U%,:71E)RP*("`@("`@("`@("`@("`@("`@
M("`G9FEE;&1S)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@
M)V1A=&%B87-E)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=?='EP92<@/3X@)W1E>'0G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W)E<75I<F5D)R`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)V1E<V,G(#T^("=!8G-O;'5T92!P871H('1O('1H92!D871A
M8F%S92!F:6QE)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D969A
M=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-T>"`N("=\9&%T86)A<V4G+"`G
M)RDI+`H@("`@("`@("`@("`@("`@("`@("`@("`G;6]D92<@/3X@87)R87DH
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G7W1Y<&4G(#T^("=T97AT
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D97-C)R`]/B`G5&AE
M(&UO9&4@=&\@;W!E;B!T:&4@9FEL92!W:71H)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-T
M>"`N("=\;6]D92<L("<P-C0T)RDI+`H@("`@("`@("`@("`@("`@("`@("`@
M("`G8VAA<G-E="<@/3X@)&-H87)S970I*2P*("`@("`@("`@("`@("`@("=S
M>6)A<V4G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=D97-C)R`]
M/B`G4WEB87-E)RP*("`@("`@("`@("`@("`@("`@("`G9FEE;&1S)R`]/B!A
M<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@)W!E<G-I<W1E;G0G(#T^
M("1P97)S:7-T96YT+`H@("`@("`@("`@("`@("`@("`@("`@("`G:&]S='-P
M96,G(#T^("1H;W-T<W!E8RP*("`@("`@("`@("`@("`@("`@("`@("`@)W5S
M97)N86UE)R`]/B`D=7-E<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@
M("=P87-S=V]R9"<@/3X@)'!A<W-W;W)D+`H@("`@("`@("`@("`@("`@("`@
M("`@("`G9&%T86)A<V4G(#T^("1D871A8F%S92P*("`@("`@("`@("`@("`@
M("`@("`@("`@)V%P<&YA;64G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)U]T>7!E)R`]/B`G=&5X="<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G9&5S8R<@/3X@)T%P<&QI8V%T:6]N($YA;64G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E<75I<F5D)R`]/B!F86QS
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D969A=6QT)R`]/B`D
M=&AI<RT^7V1E9F%U;'0H)&-T>"`N("=\87!P;F%M92<L("<G*2DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("=C:&%R<V5T)R`]/B`D8VAA<G-E="DI*2D[
M"@H@("`@("`@(&EF("AI<W-E="@D;F]D92D@)B8@)&YO9&4M/F=E=%]A='1R
M:6)U=&4H)V)A<V5C;VYF:6<G*2`]/2`G=')U92<I('L*("`@("`@("`@("`@
M<F5T=7)N("1C=7-T;VU?9FEE;&1S.PH@("`@("`@('T*"B`@("`@("`@)&-O
M;F9I9R`](&%R<F%Y*`H@("`@("`@("`@("`G9&5S8R<@/3X@)T1R:79E<B!C
M;VYF:6=U<F%T:6]N)RP*("`@("`@("`@("`@)V1E9F%U;'0G(#T^("1T:&ES
M+3Y?9&5F875L="@D8W1X("X@)WPG("X@*&ES<V5T*"1N;V1E*2`_("1N;V1E
M+3YG971?871T<FEB=71E*"=S=VET8VAN86UE)RD@.B`D<W=I=&-H;F%M92DL
M("=H;W)D92<I+`H@("`@("`@("`@("`G<W=I=&-H)R`]/B!A<G)A>2@*("`@
M("`@("`@("`@("`@("=H;W)D92<@/3X@87)R87DH"B`@("`@("`@("`@("`@
M("`@("`@)V1E<V,G(#T^("=(;W)D92!D969A=6QT<R<L"B`@("`@("`@("`@
M("`@("`@("`@)V9I96QD<R<@/3X@87)R87DH*2DL"B`@("`@("`@("`@("`@
M("`G8W5S=&]M)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G9&5S
M8R<@/3X@)T-U<W1O;2!P87)A;65T97)S)RP*("`@("`@("`@("`@("`@("`@
M("`G9FEE;&1S)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@
M;60U*&UI8W)O=&EM92@I*2`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=?='EP92<@/3X@)V1E<V-R:7!T:6]N)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=D97-C)R`]/B`G06YY('!A<F%M971E<G,@
M=&AA="!T:&4@<W1O<F%G92!D<FEV97(@;F5E9',N)RDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("=P:'!T>7!E)R`]/B`D8W5S=&]M7V9I96QD<RDI*2D[
M"@H@("`@("`@(&EF("AI<W-E="@D;F]D92D@)B8@)&YO9&4M/FAA<U]C:&EL
M9%]N;V1E<R@I*2!["B`@("`@("`@("`@("1C=7(@/2!A<G)A>2@I.PH@("`@
M("`@("`@("`D=&AI<RT^7W!A<G-E3&5V96PH)&-U<BP@)&YO9&4M/F-H:6QD
M7VYO9&5S*"DL("1C='@I.PH@("`@("`@("`@("`D8V]N9FEG6R=S=VET8V@G
M75LG:&]R9&4G75LG9FEE;&1S)UT@/2!A<G)A>5]M97)G92@D8V]N9FEG6R=S
M=VET8V@G75LG:&]R9&4G75LG9FEE;&1S)UTL("1C=7(I.PH@("`@("`@("`@
M("`D8V]N9FEG6R=S=VET8V@G75LG8W5S=&]M)UU;)V9I96QD<R==(#T@87)R
M87E?;65R9V4H)&-O;F9I9ULG<W=I=&-H)UU;)V-U<W1O;2==6R=F:65L9',G
M72P@)&-U<BD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-O;F9I9SL*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-O;F9I9W5R871I
M;VX@=')E92!F;W(@82!61E,@8F%C:V5N9"!C;VYF:6=U<F%T:6]N('1O"B`@
M("`@*B!R97!L86-E(&$@/&-O;F9I9W9F<SX@=&%G+@H@("`@("H@4W5B;F]D
M97,@=VEL;"!B92!P87)S960@86YD(&%D9&5D('1O(&)O=&@@=&AE($AO<F1E
M(&1E9F%U;'1S(&%N9"!T:&4*("`@("`J($-U<W1O;2!C;VYF:6=U<F%T:6]N
M('!A<G1S+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&-T>"`@("!4:&4@8V]N=&5X="!O9B!T
M:&4@/&-O;F9I9W9F<SX@=&%G+@H@("`@("H@0'!A<F%M($1O;4YO9&4@)&YO
M9&4@(%1H92!$;VU.;V1E(')E<')E<V5N=&%T:6]N(&]F('1H92`\8V]N9FEG
M=F9S/@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('1A9RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<W-O8VEA=&EV92!A<G)A>2!W
M:71H('1H92!61E,@8V]N9FEG=7)A=&EO;B!T<F5E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?8V]N9FEG5D93*"1C='@L("1N;V1E*0H@("`@>PH@("`@("`@
M("1S<6P@/2`D=&AI<RT^7V-O;F9I9U-13"@D8W1X("X@)WQP87)A;7,G*3L*
M("`@("`@("`D8V]N9FEG(#T*("`@("`@("`@("`@87)R87DH"B`@("`@("`@
M("`@("`@("`G9&5S8R<@/3X@)U=H870@5D93(&1R:79E<B!S:&]U;&0@=V4@
M=7-E/R<L"B`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@)'1H:7,M/E]D
M969A=6QT*"1C='@@+B`G?"<@+B`D;F]D92T^9V5T7V%T=')I8G5T92@G<W=I
M=&-H;F%M92<I+"`G:&]R9&4G*2P*("`@("`@("`@("`@("`@("=S=VET8V@G
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=N;VYE)R`]/B!A<G)A
M>2@*("`@("`@("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("=.;VYE)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@)V9I96QD<R<@/3X@87)R87DH*2DL
M"B`@("`@("`@("`@("`@("`@("`@)VAO<F1E)R`]/B!A<G)A>2@*("`@("`@
M("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("=(;W)D92!D969A=6QT<R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("=F:65L9',G(#T^(&%R<F%Y*"DI
M+`H@("`@("`@("`@("`@("`@("`@("=F:6QE)R`]/B!A<G)A>2@*("`@("`@
M("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("=&:6QE<R!O;B!T:&4@;&]C
M86P@<WES=&5M)RP*("`@("`@("`@("`@("`@("`@("`@("`@)V9I96QD<R<@
M/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<&%R86US
M)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M=F9S<F]O="<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=?='EP92<@/3X@)W1E>'0G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)U=H97)E(&]N('1H92!R
M96%L(&9I;&5S>7-T96T@<VAO=6QD($AO<F1E('5S92!A<R!R;V]T(&]F('1H
M92!V:7)T=6%L(&9I;&5S>7-T96T_)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^("1T:&ES+3Y?9&5F875L="@D
M8W1X("X@)WQP87)A;7-\=F9S<F]O="<L("<O=&UP)RDI*2DI+`H@("`@("`@
M("`@("`@("`@("`@("=S<6PG(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@
M("`@("`@("`G9&5S8R<@/3X@)U-13"!D871A8F%S92<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("=F:65L9',G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W!A<F%M<R<@/3X@87)R87DH"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V1R:79E<F-O;F9I9R<@/3X@)'-Q;"DI
M*2DI.PH*("`@("`@("`D8V%S97,@/2`D=&AI<RT^7V=E=%-W:71C:%9A;'5E
M<R@D;F]D92P@)&-T>"`N("=\<&%R86US)RD["B`@("`@("`@9F]R96%C:"`H
M)&-A<V5S(&%S("1C87-E(#T^("1F:65L9',I('L*("`@("`@("`@("`@:68@
M*&ES<V5T*"1C;VYF:6=;)W-W:71C:"==6R1C87-E72DI('L*("`@("`@("`@
M("`@("`@("1C;VYF:6=;)W-W:71C:"==6R1C87-E75LG9FEE;&1S)UU;)W!A
M<F%M<R==(#T@87)R87E?;65R9V4H)&-O;F9I9ULG<W=I=&-H)UU;)&-A<V5=
M6R=F:65L9',G75LG<&%R86US)UTL("1F:65L9'-;)V9I96QD<R==*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1C;VYF:6<[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@8V5R=&%I;B!V86QU
M92!F<F]M('1H92!C=7)R96YT(&-O;F9I9W5R871I;VX@87)R87D@;W(*("`@
M("`J(&$@9&5F875L="!V86QU92P@:68@;F]T(&9O=6YD+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&-T>"`@("`@02!S=')I;F<@<F5P<F5S96YT:6YG('1H92!K97D@;V8@
M=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&-O;F9I9W5R871I
M;VX@87)R87D@=&\@<F5T=7)N+@H@("`@("H@0'!A<F%M(&UI>&5D("1D969A
M=6QT("!4:&4@9&5F875L="!V86QU92!T;R!R971U<FX@:68@=&AE(&ME>2!W
M87-N)W0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@9F]U;F0N"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@16ET:&5R('1H92!V86QU92!O
M9B!T:&4@8V]N9FEG=7)A=&EO;B!A<G)A>2=S(')E<75E<W1E9`H@("`@("H@
M("`@("`@("`@("`@("`@:V5Y(&]R('1H92!D969A=6QT('9A;'5E(&EF('1H
M92!K97D@=V%S;B=T(&9O=6YD+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9&5F
M875L="@D8W1X+"`D9&5F875L="D*("`@('L*("`@("`@("`D8W1X(#T@97AP
M;&]D92@G?"<L("1C='@I.PH@("`@("`@("1P='(@/2`D=&AI<RT^7V-U<G)E
M;G1#;VYF:6<["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)&-T
M>"D[("1I*RLI('L*("`@("`@("`@("`@:68@*"%I<W-E="@D<'1R6R1C='A;
M)&E=72DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D9&5F875L=#L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1P='(@/2`D<'1R
M6R1C='A;)&E=73L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I
M9B`H:7-?<W1R:6YG*"1P='(I*2!["B`@("`@("`@("`@(')E='5R;B!3=')I
M;F<Z.F-O;G9E<G1#:&%R<V5T*"1P='(L("=I<V\M.#@U.2TQ)RD["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1P='(["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&-E<G1A:6X@=F%L
M=64@9G)O;2!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N(&9I;&4@;W(*("`@
M("`J(&$@9&5F875L="!V86QU92P@:68@;F]T(&9O=6YD+@H@("`@("H@270@
M9&]E<R!.3U0@<F5T=7)N('1H92!A8W1U86P@=F%L=64L(&)U="!T:&4@4$A0
M(&5X<')E<W-I;VX@87,@=7-E9`H@("`@("H@:6X@=&AE(&-O;F9I9W5R871I
M;VX@9FEL92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1C='@@("`@($$@<W1R:6YG(')E<')E
M<V5N=&EN9R!T:&4@:V5Y(&]F('1H90H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("!C;VYF:6=U<F%T:6]N(&%R<F%Y('1O(')E='5R;BX*("`@("`J
M($!P87)A;2!M:7AE9"`D9&5F875L="`@5&AE(&1E9F%U;'0@=F%L=64@=&\@
M<F5T=7)N(&EF('1H92!K97D@=V%S;B=T"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@(&9O=6YD+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M($5I=&AE<B!T:&4@=F%L=64@;V8@=&AE(&-O;F9I9W5R871I;VX@9FEL92=S
M(')E<75E<W1E9`H@("`@("H@("`@("`@("`@("`@("`@:V5Y(&]R('1H92!D
M969A=6QT('9A;'5E(&EF('1H92!K97D@=V%S;B=T(&9O=6YD+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?9&5F875L=%)A=R@D8W1X+"`D9&5F875L="D*("`@
M('L*("`@("`@("`D8W1X(#T@97AP;&]D92@G?"<L("1C='@I.PH@("`@("`@
M("1P871T97)N(#T@)R]>7"1C;VYF7%M<)R<@+B!I;7!L;V1E*"(G7%U<6R<B
M+"`D8W1X*2`N("=<)UQ=(#T@*"XJ*3LD+VTG.PH@("`@("`@(&EF("AP<F5G
M7VUA=&-H*"1P871T97)N+"`D=&AI<RT^9V5T4$A00V]N9FEG*"DL("1M871C
M:&5S*2D@>PH@("`@("`@("`@("!R971U<FX@)&UA=&-H97-;,5T["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D9&5F875L=#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE(&-O;G1E;G0@;V8@86QL('1E>'0@;F]D92!C
M:&EL9')E;B!O9B!T:&4@<W!E8VEF:65D(&YO9&4N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M($1O;4YO9&4@
M)&YO9&4@($$@1&]M3F]D92!O8FIE8W0@=VAO<V4@=&5X="!N;V1E(&-H:6QD
M<F5N('1O(')E='5R;BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE(&-O;F-A=&5N871E9"!V86QU97,@;V8@86QL('1E>'0@;F]D97,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]G971.;V1E3VYL>51E>'0H)&YO9&4I"B`@
M("!["B`@("`@("`@)'1E>'0@/2`G)SL*("`@("`@("!I9B`H(21N;V1E+3YH
M87-?8VAI;&1?;F]D97,H*2D@>PH@("`@("`@("`@("!R971U<FX@)&YO9&4M
M/F=E=%]C;VYT96YT*"D["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1N
M;V1E+3YC:&EL9%]N;V1E<R@I(&%S("1T;F]D92D@>PH@("`@("`@("`@("!I
M9B`H)'1N;V1E+3YT>7!E(#T](%A-3%]415A47TY/1$4I('L*("`@("`@("`@
M("`@("`@("1T97AT("X]("1T;F]D92T^8V]N=&5N=#L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R:6TH)'1E>'0I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!A<W-O8VEA=&EV92!A<G)A
M>2!C;VYT86EN:6YG(&%L;"!P;W-S:6)L92!V86QU97,@;V8@=&AE"B`@("`@
M*B!S<&5C:69I960@/&-O;F9I9V5N=6T^('1A9RX*("`@("`J(%1H92!K97ES
M(&-O;G1A:6X@=&AE(&%C='5A;"!E;G5M('9A;'5E<R!W:&EL92!T:&4@=F%L
M=65S(&-O;G1A:6X@=&AE:7(*("`@("`J(&-O<G)E<W!O;F1I;F<@9&5S8W)I
M<'1I;VYS+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!$;VU.;V1E("1N;V1E("!4:&4@1&]M3F]D92!R97!R
M97-E;G1A=&EO;B!O9B!T:&4@/&-O;F9I9V5N=6T^('1A9PH@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@('=H;W-E('9A;'5E<R!S:&]U;&0@8F4@<F5T
M=7)N960N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87-S;V-I
M871I=F4@87)R87D@=VET:"!A;&P@<&]S<VEB;&4@96YU;2!V86QU97,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]G971%;G5M5F%L=65S*"1N;V1E*0H@("`@
M>PH@("`@("`@("1V86QU97,@/2!A<G)A>2@I.PH@("`@("`@(&EF("@A)&YO
M9&4M/FAA<U]C:&EL9%]N;V1E<R@I*2!["B`@("`@("`@("`@(')E='5R;B!A
M<G)A>2@I.PH@("`@("`@('T*("`@("`@("!F;W)E86-H("@D;F]D92T^8VAI
M;&1?;F]D97,H*2!A<R`D=FYO9&4I('L*("`@("`@("`@("`@:68@*"1V;F]D
M92T^='EP92`]/2!834Q?14Q%345.5%].3T1%("8F"B`@("`@("`@("`@("`@
M("`D=FYO9&4M/G1A9VYA;64@/3T@)W9A;'5E<R<I('L*("`@("`@("`@("`@
M("`@(&EF("@A)'9N;V1E+3YH87-?8VAI;&1?;F]D97,H*2D@>PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'9N;V1E+3YC:&EL9%]N;V1E
M<R@I(&%S("1V86QU92D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D=F%L
M=64M/G1Y<&4@/3T@6$U,7T5,14U%3E1?3D]$12D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H)'9A;'5E+3YT86=N86UE(#T]("=C;VYF:6=S<&5C
M:6%L)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?:&%N9&QE4W!E8VEA;',H)'9A;'5E*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E:68@*"1V86QU92T^=&%G;F%M92`]/2`G=F%L=64G
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&5X="`]("1V86QU
M92T^9V5T7V-O;G1E;G0H*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1D97-C(#T@)'9A;'5E+3YG971?871T<FEB=71E*"=D97-C)RD["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1D97-C*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V86QU97-;)'1E>'1=
M(#T@)&1E<V,["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V86QU97-;)'1E
M>'1=(#T@)'1E>'0["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N("1V86QU97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS(&$@;75L=&ED:6UE;G-I;VYA;"!A<W-O8VEA=&EV92!A<G)A>2!R
M97!R97-E;G1I;F<@=&AE('-P96-I9FEE9`H@("`@("H@/&-O;F9I9W-W:71C
M:#X@=&%G+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!$;VU.;V1E("8D;F]D92`@5&AE($1O;4YO9&4@<F5P
M<F5S96YT871I;VX@;V8@=&AE(#QC;VYF:6=S=VET8V@^"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@('1A9R!T;R!P<F]C97-S+@H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@($%N(&%S<V]C:6%T:79E(&%R<F%Y(')E<')E
M<V5N=&EN9R!T:&4@;F]D92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=%-W
M:71C:%9A;'5E<R@F)&YO9&4L("1C=7)C='@I"B`@("!["B`@("`@("`@:68@
M*"$D;F]D92T^:&%S7V-H:6QD7VYO9&5S*"DI('L*("`@("`@("`@("`@<F5T
M=7)N(&%R<F%Y*"D["B`@("`@("`@?0H@("`@("`@("1V86QU97,@/2!A<G)A
M>2@I.PH@("`@("`@(&9O<F5A8V@@*"1N;V1E+3YC:&EL9%]N;V1E<R@I(&%S
M("1C87-E*2!["B`@("`@("`@("`@(&EF("@D8V%S92T^='EP92`]/2!834Q?
M14Q%345.5%].3T1%*2!["B`@("`@("`@("`@("`@("`D;F%M92`]("1C87-E
M+3YG971?871T<FEB=71E*"=N86UE)RD["B`@("`@("`@("`@("`@("`D=F%L
M=65S6R1N86UE72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`D=F%L=65S
M6R1N86UE75LG9&5S8R==(#T@)&-A<V4M/F=E=%]A='1R:6)U=&4H)V1E<V,G
M*3L*("`@("`@("`@("`@("`@("1V86QU97-;)&YA;65=6R=F:65L9',G72`]
M(&%R<F%Y*"D["B`@("`@("`@("`@("`@("!I9B`H)&-A<V4M/FAA<U]C:&EL
M9%]N;V1E<R@I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)S
M94QE=F5L*"1V86QU97-;)&YA;65=6R=F:65L9',G72P@)&-A<V4M/F-H:6QD
M7VYO9&5S*"DL("1C=7)C='@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=F%L=65S.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!A<W-O8VEA=&EV92!A<G)A
M>2!C;VYT86EN:6YG('1H92!P;W-S:6)L92!V86QU97,@;V8@80H@("`@("H@
M/&-O;F9I9W-P96-I86P^('1A9R!A<R!U<V5D(&EN<VED92!O9B!E;G5M(&-O
M;F9I9W5R871I;VYS+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H*("`@("`J($!P87)A;2!$;VU.;V1E("1N;V1E("!4:&4@1&]M3F]D
M92!R97!R97-E;G1A=&EO;B!O9B!T:&4@/&-O;F9I9W-P96-I86P^"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@=&%G+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@($%N(&%S<V]C:6%T:79E(&%R<F%Y('=I=&@@=&AE('!O
M<W-I8FQE('9A;'5E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7VAA;F1L95-P
M96-I86QS*"1N;V1E*0H@("`@>PH@("`@("`@('-W:71C:"`H)&YO9&4M/F=E
M=%]A='1R:6)U=&4H)VYA;64G*2D@>PH@("`@("`@(&-A<V4@)VQI<W0M:&]R
M9&4M87!P<R<Z"B`@("`@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["B`@("`@
M("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O07)R87DN<&AP)SL*("`@("`@
M("`@("`@)&%P<',@/2!(;W)D95]!<G)A>3HZ=F%L=65S5&]+97ES*"1R96=I
M<W1R>2T^;&ES=$%P<',H87)R87DH)VAI9&1E;B<L("=N;W1O;VQB87(G+"`G
M86-T:79E)RDI*3L*("`@("`@("`@("`@87-O<G0H)&%P<',I.PH@("`@("`@
M("`@("!R971U<FX@)&%P<',["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!C87-E("=L:7-T+6AO<F1E+6QA;F=U86=E<R<Z"B`@("`@("`@("`@(')E
M='5R;B!A<G)A>5]M87`H8W)E871E7V9U;F-T:6]N*"<D=F%L)RP@)W)E='5R
M;B!P<F5G7W)E<&QA8V4H87)R87DH(B\F(W@H6S`M.6$M9EU[-'TI.R]I92(L
M("(O*"9;7CM=*SLI+V4B*2P@87)R87DH(E-T<FEN9SHZ8V]N=F5R=$-H87)S
M970H<&%C:RA<(D@J7"(L(%PB)#%<(BDL(%PB=6-S+3)<(BP@7"(G("X@3DQ3
M.CIG971#:&%R<V5T*"D@+B`G7"(I(BP@(E-T<FEN9SHZ8V]N=F5R=$-H87)S
M970H:'1M;%]E;G1I='E?9&5C;V1E*%PB)#%<(BP@14Y47T-/35!!5"P@7")I
M<V\M.#@U.2TQ7"(I+"!<(FES;RTX.#4Y+3%<(BP@7"(G("X@3DQ3.CIG971#
M:&%R<V5T*"D@+B`G7"(I(BDL("1V86PI.R<I+"`D1TQ/0D%,4ULG;FQS)UU;
M)VQA;F=U86=E<R==*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@)VQI<W0M8FQO8VMS)SH*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(
M;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<"<["B`@("`@("`@("`@("1C;VQL
M96-T:6]N(#T@)DAO<F1E7T)L;V-K7T-O;&QE8W1I;VXZ.G-I;F=L971O;B@G
M<&]R=&%L)RD["B`@("`@("`@("`@(')E='5R;B`D8V]L;&5C=&EO;BT^9V5T
M0FQO8VMS3&ES="@I.PH*("`@("`@("!C87-E("=L:7-T+6-L:65N="UF:65L
M9',G.@H@("`@("`@("`@("!G;&]B86P@)')E9VES=')Y.PH@("`@("`@("`@
M("`D9B`](&%R<F%Y*"D["B`@("`@("`@("`@(&EF("@D<F5G:7-T<GDM/FAA
M<TUE=&AO9"@G8VQI96YT<R]G971#;&EE;G13;W5R8V4G*2D@>PH@("`@("`@
M("`@("`@("`@)&%D9')E<W-B;V]K(#T@)')E9VES=')Y+3YC86QL*"=C;&EE
M;G1S+V=E=$-L:65N=%-O=7)C92<I.PH@("`@("`@("`@("`@("`@)&9I96QD
M<R`]("1R96=I<W1R>2T^8V%L;"@G8VQI96YT<R]F:65L9',G+"!A<G)A>2@D
M861D<F5S<V)O;VLI*3L*("`@("`@("`@("`@("`@(&EF("@A:7-?82@D9FEE
M;&1S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@9F]R
M96%C:"`H)&9I96QD<R!A<R`D9FEE;&0I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&9;)&9I96QD6R=N86UE)UU=(#T@)&9I96QD6R=L86)E;"==.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!R971U<FX@)&8["B`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!S<&5C:69I960@<W1R:6YG
M('=I=&@@97-C87!E9"!S:6YG;&4@<75O=&5S"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<W1R
M:6YG("!!('-T<FEN9R!T;R!E<V-A<&4N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!S<&5C:69I960@<W1R:6YG('=I=&@@<VEN9VQE('%U
M;W1E<R!B96EN9R!E<V-A<&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<75O
M=&4H)'-T<FEN9RD*("`@('L*("`@("`@("!R971U<FX@<W1R7W)E<&QA8V4H
M(B<B+"`B7"<B+"`D<W1R:6YG*3L*("`@('T*"GT*"B\J*@H@*B!!($AO<F1E
M7T9O<FTZ.B!F;W)M('1H870@:6UP;&5M96YT<R!A('5S97(@:6YT97)F86-E
M(&9O<B!T:&4@8V]N9FEG"B`J('-Y<W1E;2X*("H*("H@0&%U=&AO<B`@0VAU
M8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO
M<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]&<F%M97=O<FL*("HO"F-L87-S
M($-O;F9I9T9O<FT@97AT96YD<R!(;W)D95]&;W)M('L*"B`@("`O*BH*("`@
M("`J($1O;B=T('5S92!F;W)M('1O:V5N<R!F;W(@=&AE(&-O;F9I9W5R871I
M;VX@9F]R;2`M('=H:6QE"B`@("`@*B!G96YE<F%T:6YG(&-O;F9I9W5R871I
M;VX@:6YF;RP@=&AI;F=S(&QI:V4@=&AE(%1O:V5N('-Y<W1E;0H@("`@("H@
M;6EG:'0@;F]T('=O<FL@8V]R<F5C=&QY+B!4:&ES('-A=F5S('-O;64@:&5A
M9&%C:&5S+@H@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@
M("!V87(@)%]U<V5&;W)M5&]K96X@/2!F86QS93L*"B`@("`O*BH*("`@("`J
M($-O;G1A:6YS('1H92!(;W)D95]#;VYF:6<@;V)J96-T('1H870@=&AI<R!F
M;W)M(')E<')E<V5N=',N"B`@("`@*@H@("`@("H@0'9A<B!(;W)D95]#;VYF
M:6<*("`@("`J+PH@("`@=F%R("1?>&UL0V]N9FEG.PH*("`@("\J*@H@("`@
M("H@0V]N=&%I;G,@=&AE(%9A<FEA8FQE<R!O8FIE8W0@;V8@=&AI<R!F;W)M
M+@H@("`@("H*("`@("`J($!V87(@5F%R:6%B;&5S"B`@("`@*B\*("`@('9A
M<B`D7W9A<G,["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J
M"B`@("`@*B!`<&%R86T@5F%R:6%B;&5S("8D=F%R<R`@5&AE(%9A<FEA8FQE
M<R!O8FIE8W0@;V8@=&AI<R!F;W)M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M87!P("`@("`@("`@("`@(%1H92!N86UE(&]F('1H92!A<'!L:6-A=&EO;B!T
M:&%T('1H:7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!C;VYF:6=U<F%T:6]N(&9O<FT@:7,@9F]R+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!#;VYF:6=&;W)M*"8D=F%R<RP@)&%P<"D*("`@('L*("`@("`@("!P
M87)E;G0Z.DAO<F1E7T9O<FTH)'9A<G,I.PH*("`@("`@("`D=&AI<RT^7WAM
M;$-O;F9I9R`]("9N97<@2&]R9&5?0V]N9FEG*"1A<'`I.PH@("`@("`@("1T
M:&ES+3Y?=F%R<R`]("8D=F%R<SL*("`@("`@("`D8V]N9FEG(#T@)'1H:7,M
M/E]X;6Q#;VYF:6<M/G)E861834Q#;VYF:6<H*3L*("`@("`@("`D=&AI<RT^
M861D2&ED9&5N*"<G+"`G87!P)RP@)W1E>'0G+"!T<G5E*3L*("`@("`@("`D
M=&AI<RT^7V)U:6QD5F%R:6%B;&5S*"1C;VYF:6<I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0G5I;&1S('1H92!F;W)M(&)A<V5D(&]N('1H92!S<&5C:69I
M960@;&5V96P@;V8@=&AE(&-O;F9I9W5R871I;VX@=')E92X*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)&-O;F9I9R`@(%1H92!P;W)T:6]N(&]F('1H92!C;VYF:6=U<F%T:6]N
M('1R964@9F]R('1H870*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M=&AE(&9O<FT@9FEE;&1S('-H;W5L9"!B92!C<F5A=&5D+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<')E9FEX("!!('-T<FEN9R!R97!R97-E;G1I;F<@=&AE
M(&-U<G)E;G0@<&]S:71I;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@:6YS:61E('1H92!C;VYF:6=U<F%T:6]N('1R964N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]B=6EL9%9A<FEA8FQE<R@D8V]N9FEG+"`D<')E9FEX(#T@
M)R<I"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D8V]N9FEG*2D@>PH@
M("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@
M*"1C;VYF:6<@87,@)&YA;64@/3X@)&-O;F9I9VET96TI('L*("`@("`@("`@
M("`@)'!R969I>&5D;F%M92`](&5M<'1Y*"1P<F5F:7@I(#\@)&YA;64@.B`D
M<')E9FEX("X@)WPG("X@)&YA;64["B`@("`@("`@("`@("1V87)N86UE(#T@
M<W1R7W)E<&QA8V4H)WPG+"`G7U\G+"`D<')E9FEX961N86UE*3L*("`@("`@
M("`@("`@)&1E<V-R:7!T:6]N(#T@;G5L;#L*("`@("`@("`@("`@:68@*"1C
M;VYF:6=I=&5M(#T]("=P;&%C96AO;&1E<B<I('L*("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PH@("`@("`@("`@("!](&5L<V5I9B`H:7-S970H)&-O;F9I
M9VET96U;)W1A8B==*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=%-E
M8W1I;VXH)&-O;F9I9VET96U;)W1A8B==+"`D8V]N9FEG:71E;5LG9&5S8R==
M*3L*("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1C;VYF:6=I=&5M6R=S
M=VET8V@G72DI('L*("`@("`@("`@("`@("`@("1S96QE8W1E9"`]("1T:&ES
M+3Y?=F%R<RT^9V5T17AI<W1S*"1V87)N86UE+"`D=V%S<V5T*3L*("`@("`@
M("`@("`@("`@("1V87)?<&%R86US(#T@87)R87DH*3L*("`@("`@("`@("`@
M("`@("1S96QE8W1?;W!T:6]N(#T@=')U93L*("`@("`@("`@("`@("`@(&EF
M("AI<U]B;V]L*"1C;VYF:6=I=&5M6R=D969A=6QT)UTI*2!["B`@("`@("`@
M("`@("`@("`@("`@)&-O;F9I9VET96U;)V1E9F%U;'0G72`]("1C;VYF:6=I
M=&5M6R=D969A=6QT)UT@/R`G=')U92<@.B`G9F%L<V4G.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&-O;F9I9VET96U;
M)W-W:71C:"==(&%S("1O<'1I;VX@/3X@)&-A<V4I('L*("`@("`@("`@("`@
M("`@("`@("`D=F%R7W!A<F%M<ULD;W!T:6]N72`]("1C87-E6R=D97-C)UT[
M"B`@("`@("`@("`@("`@("`@("`@:68@*"1O<'1I;VX@/3T@)&-O;F9I9VET
M96U;)V1E9F%U;'0G72D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<V5L
M96-T7V]P=&EO;B`](&9A;'-E.PH@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H(21W87-S970I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S
M96QE8W1E9"`]("1O<'1I;VX["B`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D=B`]("8D=&AI<RT^861D5F%R:6%B;&4H)&-O;F9I9VET
M96U;)V1E<V,G72P@)'9A<FYA;64L("=E;G5M)RP@=')U92P@9F%L<V4L(&YU
M;&PL(&%R<F%Y*"1V87)?<&%R86US+"`D<V5L96-T7V]P=&EO;BDI.PH@("`@
M("`@("`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)V1E9F%U;'0G+"`D
M8V]N9FEG:71E;2DI('L*("`@("`@("`@("`@("`@("`@("`D=BT^<V5T1&5F
M875L="@D8V]N9FEG:71E;5LG9&5F875L="==*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("1V7V%C=&EO;B`]("9(;W)D95]&;W)M7T%C
M=&EO;CHZ9F%C=&]R>2@G<F5L;V%D)RD["B`@("`@("`@("`@("`@("`D=BT^
M<V5T06-T:6]N*"1V7V%C=&EO;BD["B`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)'-E;&5C=&5D*2`F)B!I<W-E="@D8V]N9FEG:71E;5LG<W=I=&-H)UU;
M)'-E;&5C=&5D72DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V)U
M:6QD5F%R:6%B;&5S*"1C;VYF:6=I=&5M6R=S=VET8V@G75LD<V5L96-T961=
M6R=F:65L9',G72P@)'!R969I>"D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T@96QS96EF("AI<W-E="@D8V]N9FEG:71E;5LG7W1Y<&4G72DI
M('L*("`@("`@("`@("`@("`@("1R97%U:7)E9"`]("AI<W-E="@D8V]N9FEG
M:71E;5LG<F5Q=6ER960G72DI(#\@)&-O;F9I9VET96U;)W)E<75I<F5D)UT@
M.B!T<G5E.PH@("`@("`@("`@("`@("`@)'1Y<&4@/2`D8V]N9FEG:71E;5LG
M7W1Y<&4G73L*("`@("`@("`@("`@("`@("\O($9)6$U%.B!M=6QT:65N=6T@
M9FEE;&1S(&-A;B!W96QL(&)E(')E<75I<F5D+"!M96%N:6YG('1H870*("`@
M("`@("`@("`@("`@("\O('EO=2!N965D('1O('-E;&5C="!A="!L96%S="!O
M;F4@96YT<GDN($-H86YG:6YG('1H:7,@8F5F;W)E"B`@("`@("`@("`@("`@
M("`O+R!(;W)D92`T+C`@=V]U;&0@8G)E86L@82!L;W0@;V8@8V]N9FEG=7)A
M=&EO;B!F:6QE<R!T:&]U9V@N"B`@("`@("`@("`@("`@("!I9B`H)'1Y<&4@
M/3T@)VUU;'1I96YU;2<@?'P@)'1Y<&4@/3T@)VAE861E<B<@?'P*("`@("`@
M("`@("`@("`@("`@("`D='EP92`]/2`G9&5S8W)I<'1I;VXG*2!["B`@("`@
M("`@("`@("`@("`@("`@)')E<75I<F5D(#T@9F%L<V4["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!I9B`H)'1Y<&4@/3T@)VUU;'1I96YU
M;2<@?'P@)'1Y<&4@/3T@)V5N=6TG*2!["B`@("`@("`@("`@("`@("`@("`@
M)'9A<E]P87)A;7,@/2!A<G)A>2@D8V]N9FEG:71E;5LG=F%L=65S)UTI.PH@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D
M=F%R7W!A<F%M<R`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!I9B`H)'1Y<&4@/3T@)W!H<"<I('L*("`@("`@("`@("`@
M("`@("`@("`D='EP92`]("=T97AT)SL*("`@("`@("`@("`@("`@("`@("`D
M9&5S8W)I<'1I;VX@/2`G16YT97(@82!V86QI9"!02%`@97AP<F5S<VEO;BXG
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'8@/2`F)'1H
M:7,M/F%D9%9A<FEA8FQE*"1C;VYF:6=I=&5M6R=D97-C)UTL("1V87)N86UE
M+"`D='EP92P@)')E<75I<F5D+"!F86QS92P@)&1E<V-R:7!T:6]N+"`D=F%R
M7W!A<F%M<RD["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&-O;F9I9VET
M96U;)V1E9F%U;'0G72DI('L*("`@("`@("`@("`@("`@("`@("`D=BT^<V5T
M1&5F875L="@D8V]N9FEG:71E;5LG9&5F875L="==*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?8G5I;&1687)I86)L97,H)&-O;F9I9VET96TL("1P<F5F:7AE9&YA
M;64I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*?0H*8VQA<W,@
M2&]R9&5?0V]N9FEG7T1O8W5M96YT(&5X=&5N9',@2&]R9&5?0V]N9FEG7TYO
M9&4@>PH*("`@(&9U;F-T:6]N(&9A8W1O<GDH)&9I;&4I"B`@("!["B`@("`@
M("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G9&]M>&UL7V]P96Y?9FEL92<I*2![
M"B`@("`@("`@("`@(')E='5R;B!D;VUX;6Q?;W!E;E]F:6QE*"1F:6QE*3L*
M("`@("`@("!](&5L<V5I9B`H=F5R<VEO;E]C;VUP87)E*'!H<'9E<G-I;VXH
M*2P@)S4G+"`G/CTG*2D@>PH@("`@("`@("`@("!R971U<FX@)&1O8R`](&YE
M=R!(;W)D95]#;VYF:6=?1&]C=6UE;G0H)&9I;&4I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@($AO<F1E.CIF871A;"@G1$]-('-U<'!O<G0@;F]T
M('!R97-E;G0N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@
M("!]"@H@("`@9G5N8W1I;VX@2&]R9&5?0V]N9FEG7T1O8W5M96YT*"1F:6QE
M;F%M92D*("`@('L*("`@("`@("`D=&AI<RT^;F]D92`](&YE=R!$3TU$;V-U
M;65N="@I.PH@("`@("`@("1T:&ES+3YN;V1E+3YL;V%D*"1F:6QE;F%M92D[
M"B`@("!]"@H@("`@9G5N8W1I;VX@<F]O="@I"B`@("!["B`@("`@("`@<F5T
M=7)N("1R;V]T(#T@;F5W($AO<F1E7T-O;F9I9U]%;&5M96YT*"1T:&ES+3YN
M;V1E+3YD;V-U;65N=$5L96UE;G0I.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?
M0V]N9FEG7TYO9&4@>PH*("`@('9A<B`D;F]D93L*"B`@("!F=6YC=&EO;B!(
M;W)D95]#;VYF:6=?3F]D92@D841O;4YO9&4I('LD=&AI<RT^;F]D93TD841O
M;4YO9&4[?0H*("`@(&9U;F-T:6]N(%]?9V5T*"1N86UE*0H@("`@>PH@("`@
M("`@('-W:71C:"`H)&YA;64I('L*("`@("`@("!C87-E("=T>7!E)SH*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YN;V1E+3YN;V1E5'EP93L*"B`@("`@
M("`@8V%S92`G=&%G;F%M92<Z"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M;F]D92T^=&%G3F%M93L*"B`@("`@("`@8V%S92`G8V]N=&5N="<Z"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^;F]D92T^=&5X=$-O;G1E;G0["@H@("`@
M("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"B`@("!]"@H@("`@9G5N8W1I;VX@8VAI;&1?;F]D97,H*0H@("`@>PH@
M("`@("`@("1N;V1E3&ES="`]("1T:&ES+3YN;V1E+3YC:&EL9$YO9&5S.PH@
M("`@("`@("1N;V1E4V5T(#T@87)R87DH*3L*("`@("`@("!I9B`H:7-S970H
M)&YO9&5,:7-T*2D@>PH@("`@("`@("`@("`D:2`](#`["B`@("`@("`@("`@
M('=H:6QE("@D;F]D92`]("1N;V1E3&ES="T^:71E;2@D:2DI('L*("`@("`@
M("`@("`@("`@("1N;V1E4V5T6UT@/2!N97<@2&]R9&5?0V]N9FEG7T5L96UE
M;G0H)&YO9&4I.PH@("`@("`@("`@("`@("`@)&DK*SL*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!R971U<FX@)&YO9&53970["B`@("!]"@H@
M("`@9G5N8W1I;VX@9FER<W1?8VAI;&0H*0H@("`@>PH@("`@("`@(')E='5R
M;B!N97<@2&]R9&5?0V]N9FEG7T5L96UE;G0H)'1H:7,M/FYO9&4M/F9I<G-T
M0VAI;&0I.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%]C;VYT96YT*"D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/FYO9&4M/G1E>'1#;VYT96YT.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&AA<U]C:&EL9%]N;V1E<R@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3YN;V1E+3YH87-#:&EL9$YO9&5S*"D["B`@
M("!]"@H@("`@9G5N8W1I;VX@;F5X=%]S:6)L:6YG*"D*("`@('L*("`@("`@
M("!R971U<FX@;F5W($AO<F1E7T-O;F9I9U]%;&5M96YT*"1T:&ES+3YN;V1E
M+3YN97AT4VEB;&EN9RD["B`@("!]"@H@("`@9G5N8W1I;VX@;F]D95]V86QU
M92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YN;V1E+3YN;V1E5F%L
M=64["B`@("!]"@I]"@IC;&%S<R!(;W)D95]#;VYF:6=?16QE;65N="!E>'1E
M;F1S($AO<F1E7T-O;F9I9U].;V1E('L*"B`@("!F=6YC=&EO;B!G971?871T
M<FEB=71E*"1N86UE*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^;F]D
M92T^9V5T071T<FEB=71E*"1N86UE*3L*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+TAO<F1E+T=R;W5P+G!H<```````````````````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#4P-3,T(#$P-3$U-#,S-S0P(#`R,3$V,``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`H*
M<F5Q=6ER95]O;F-E("=(;W)D92]$871A5')E92YP:'`G.PIR97%U:7)E7V]N
M8V4@)TAO<F1E+TAI<W1O<GDN<&AP)SL*"B\J*@H@*B!4:&4@1W)O=7`Z.B!C
M;&%S<R!P<F]V:61E<R!T:&4@2&]R9&4@9W)O=7!S('-Y<W1E;2X*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`N<&AP+'8@,2XV-RXR+C$U
M(#(P,#8O,#<O,3<@,30Z-#`Z,3D@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`Q.3DY+3(P,#8@4W1E<&AA;F4@2'5T:&5R(#QS:'5T:&5R0&)I9V9O;W0N
M8V]M/@H@*B!#;W!Y<FEG:'0@,C`P,2TR,#`V($-H=6-K($AA9V5N8G5C:"`\
M8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@
M4W1E<&AA;F4@2'5T:&5R(#QS:'5T:&5R0&)I9V9O;W0N8V]M/@H@*B!`875T
M:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I
M;F-E("`@2&]R9&4@,BXQ"B`J($!P86-K86=E($AO<F1E7T=R;W5P"B`J+PIC
M;&%S<R!'<F]U<"!["@H@("`@+RHJ"B`@("`@*B!0;VEN=&5R('1O(&$@1&%T
M851R964@:6YS=&%N8V4@=&\@;6%N86=E('1H92!D:69F97)E;G0@9W)O=7!S
M+@H@("`@("H*("`@("`J($!V87(@1&%T851R964*("`@("`J+PH@("`@=F%R
M("1?9&%T871R964["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@
M("HO"B`@("!F=6YC=&EO;B!'<F]U<"@I"B`@("!["B`@("`@("`@9VQO8F%L
M("1C;VYF.PH*("`@("`@("!I9B`H96UP='DH)&-O;F9;)V1A=&%T<F5E)UU;
M)V1R:79E<B==*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH)UEO=2!M
M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E($=R;W5P
M<RXG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@
M)&1R:79E<B`]("1C;VYF6R=D871A=')E92==6R=D<FEV97(G73L*("`@("`@
M("`D=&AI<RT^7V1A=&%T<F5E(#T@)D1A=&%4<F5E.CIS:6YG;&5T;VXH)&1R
M:79E<BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@87)R87E?;65R9V4H2&]R9&4Z.F=E=$1R:79E<D-O;F9I9R@G
M9&%T871R964G+"`D9')I=F5R*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V=R
M;W5P)R`]/B`G:&]R9&4N9W)O=7!S)RDI*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;B!A(&YE=R!G<F]U<"!O8FIE8W0N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;F%M92`@("!4:&4@9W)O=7`G<R!N86UE+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<&%R96YT("!4:&4@9W)O=7`G<R!P87)E;G0G
M<R!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@1&%T851R965/8FIE8W1?
M1W)O=7`@($$@;F5W(&=R;W5P(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@)FYE=T=R;W5P*"1N86UE+"`D<&%R96YT(#T@1$%40512145?4D]/5"D*
M("`@('L*("`@("`@("!I9B`H96UP='DH)&YA;64I*2!["B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D=R;W5P(&YA;65S(&UU<W0@
M8F4@;F]N+65M<'1Y(BDI.PH@("`@("`@('T*"B`@("`@("`@:68@*"1P87)E
M;G0@(3T@1$%40512145?4D]/5"D@>PH@("`@("`@("`@("`D;F%M92`]("1T
M:&ES+3YG971'<F]U<$YA;64H)'!A<F5N="D@+B`G.B<@+B!$871A5')E93HZ
M96YC;V1E3F%M92@D;F%M92D["B`@("`@("`@?0H*("`@("`@("`D9W)O=7`@
M/2`F;F5W($1A=&%4<F5E3V)J96-T7T=R;W5P*"1N86UE*3L*("`@("`@("`D
M9W)O=7`M/G-E=$=R;W5P3V(H)'1H:7,I.PH@("`@("`@(')E='5R;B`D9W)O
M=7`["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@82!$871A5')E94]B
M:F5C=%]'<F]U<"!O8FIE8W0@8V]R<F5S<&]N9&EN9R!T;R!T:&4@;F%M960*
M("`@("`J(&=R;W5P+"!W:71H('1H92!U<V5R<R!A;F0@;W1H97(@9&%T82!R
M971R:65V960@87!P<F]P<FEA=&5L>2X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1N86UE(%1H92!N86UE(&]F('1H92!G<F]U<"!T;R!R971R:65V
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=$=R;W5P*"1N86UE*0H@("`@
M>PH@("`@("`@("\J(&-A8VAE(&]F('!R979I;W5S(')E=')I979E9"!G<F]U
M<',@*B\*("`@("`@("!S=&%T:6,@)&=R;W5P0V%C:&4["@H@("`@("`@(&EF
M("@A:7-?87)R87DH)&=R;W5P0V%C:&4I*2!["B`@("`@("`@("`@("1G<F]U
M<$-A8VAE(#T@87)R87DH*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-S
M970H)&=R;W5P0V%C:&5;)&YA;65=*2D@>PH@("`@("`@("`@("`D9W)O=7!#
M86-H95LD;F%M95T@/2`D=&AI<RT^7V1A=&%T<F5E+3YG971/8FIE8W0H)&YA
M;64L("=$871A5')E94]B:F5C=%]'<F]U<"<I.PH@("`@("`@("`@("!I9B`H
M(6ES7V$H)&=R;W5P0V%C:&5;)&YA;65=+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("`D9W)O=7!#86-H95LD;F%M95TM/G-E=$=R;W5P3V(H
M)'1H:7,I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)&=R;W5P0V%C:&5;)&YA;65=.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N(&$@1&%T851R965/8FIE8W1?1W)O=7`@;V)J96-T(&-O<G)E<W!O
M;F1I;F<@=&\@=&AE(&=I=F5N"B`@("`@*B!U;FEQ=64@240L('=I=&@@=&AE
M('5S97)S(&%N9"!O=&AE<B!D871A(')E=')I979E9`H@("`@("H@87!P<F]P
M<FEA=&5L>2X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8VED("!4
M:&4@=6YI<75E($E$(&]F('1H92!G<F]U<"!T;R!R971R:65V92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@)F=E=$=R;W5P0GE)9"@D8VED*0H@("`@>PH@("`@
M("`@("1G<F]U<"`]("1T:&ES+3Y?9&%T871R964M/F=E=$]B:F5C=$)Y260H
M)&-I9"P@)T1A=&%4<F5E3V)J96-T7T=R;W5P)RD["B`@("`@("`@:68@*"%I
M<U]A*"1G<F]U<"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D9W)O
M=7`M/G-E=$=R;W5P3V(H)'1H:7,I.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@)&=R;W5P.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T(&$@9VQO8F%L
M;'D@=6YI<75E($E$(&9O<B!A(&=R;W5P+@H@("`@("H*("`@("`J($!P87)A
M;2!$871A5')E94]B:F5C=%]'<F]U<"`D9W)O=7`@(%1H92!G<F]U<"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@02!'54E$(')E9F5R<FEN9R!T
M;R`D9W)O=7`N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$=5240H)&=R;W5P
M*0H@("`@>PH@("`@("`@(')E='5R;B`G:&]R9&4Z9W)O=7`Z)R`N("1T:&ES
M+3YG971'<F]U<$ED*"1G<F]U<"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!
M9&0@82!G<F]U<"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X@5&AE(&=R;W5P(&UU
M<W0@9FER<W0@8F4*("`@("`J(&-R96%T960@=VET:"!'<F]U<#HZ;F5W1W)O
M=7`H*2P@86YD(&AA=F4@86YY(&EN:71I86P@=7-E<G,*("`@("`J(&%D9&5D
M('1O(&ET+"!B969O<F4@=&AI<R!F=6YC=&EO;B!I<R!C86QL960N"B`@("`@
M*@H@("`@("H@0'!A<F%M($1A=&%4<F5E3V)J96-T7T=R;W5P("1G<F]U<"`@
M5&AE(&YE=R!G<F]U<"!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D
M9$=R;W5P*"1G<F]U<"D*("`@('L*("`@("`@("!I9B`H(6ES7V$H)&=R;W5P
M+"`G1&%T851R965/8FIE8W1?1W)O=7`G*2D@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@G1W)O=7!S(&UU<W0@8F4@1&%T851R965/
M8FIE8W1?1W)O=7`@;V)J96-T<R!O<B!E>'1E;F0@=&AA="!C;&%S<RXG*3L*
M("`@("`@("!]"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&%T871R964M
M/F%D9"@D9W)O=7`I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@
M("`@?0H*("`@("`@("`O*B!,;V<@=&AE(&%D9&ET:6]N(&]F('1H92!G<F]U
M<"!I;B!T:&4@:&ES=&]R>2!L;V<N("HO"B`@("`@("`@)&AI<W1O<GD@/2`F
M2&]R9&5?2&ES=&]R>3HZ<VEN9VQE=&]N*"D["B`@("`@("`@)&QO9R`]("1H
M:7-T;W)Y+3YL;V<H)'1H:7,M/F=E=$=5240H)&=R;W5P*2P@87)R87DH)V%C
M=&EO;B<@/3X@)V%D9"<I+"!T<G5E*3L*("`@("`@("!I9B`H:7-?82@D;&]G
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D;&]G.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!3=&]R92!U<&1A=&5D(&1A=&$@+2!U<V5R<RP@971C+B`M
M(&]F(&$@9W)O=7`@=&\@=&AE(&)A8VME;F0@<WES=&5M+@H@("`@("H*("`@
M("`J($!P87)A;2!$871A5')E94]B:F5C=%]'<F]U<"`D9W)O=7`@(%1H92!G
M<F]U<"!T;R!U<&1A=&4N"B`@("`@*B\*("`@(&9U;F-T:6]N('5P9&%T94=R
M;W5P*"1G<F]U<"D*("`@('L*("`@("`@("!I9B`H(6ES7V$H)&=R;W5P+"`G
M1&%T851R965/8FIE8W1?1W)O=7`G*2D@>PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@G1W)O=7!S(&UU<W0@8F4@1&%T851R965/8FIE
M8W1?1W)O=7`@;V)J96-T<R!O<B!E>'1E;F0@=&AA="!C;&%S<RXG*3L*("`@
M("`@("!]"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&%T871R964M/G5P
M9&%T941A=&$H)&=R;W5P*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@
M("`@("`@('T*"B`@("`@("`@+RH@3&]G('1H92!U<&1A=&4@;V8@=&AE(&=R
M;W5P('5S97)S(&]N('1H92!H:7-T;W)Y(&QO9RX@*B\*("`@("`@("`D:&ES
M=&]R>2`]("9(;W)D95](:7-T;W)Y.CIS:6YG;&5T;VXH*3L*("`@("`@("`D
M9W5I9"`]("1T:&ES+3YG971'54E$*"1G<F]U<"D["B`@("`@("`@9F]R96%C
M:"`H)&=R;W5P+3YG971!=61I=$QO9R@I(&%S("1U<V5R260@/3X@)&%C=&EO
M;BD@>PH@("`@("`@("`@("`D:&ES=&]R>2T^;&]G*"1G=6ED+"!A<G)A>2@G
M86-T:6]N)R`]/B`D86-T:6]N+"`G=7-E<B<@/3X@)'5S97))9"DL('1R=64I
M.PH@("`@("`@('T*("`@("`@("`D9W)O=7`M/F-L96%R075D:71,;V<H*3L*
M"B`@("`@("`@+RH@3&]G('1H92!G<F]U<"!M;V1I9FEC871I;VXN("HO"B`@
M("`@("`@)&AI<W1O<GDM/FQO9R@D9W5I9"P@87)R87DH)V%C=&EO;B<@/3X@
M)VUO9&EF>2<I+"!T<G5E*3L*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M('T*"B`@("`O*BH*("`@("`J($-H86YG92!T:&4@;F%M92!O9B!A(&=R;W5P
M('=I=&AO=70@8VAA;F=I;F<@:71S(&-O;G1E;G1S(&]R"B`@("`@*B!W:&5R
M92!I="!I<R!I;B!T:&4@9W)O=7!S(&AI97)A<F-H>2X*("`@("`J"B`@("`@
M*B!`<&%R86T@1&%T851R965/8FIE8W1?1W)O=7`@)&=R;W5P("!4:&4@9W)O
M=7`@=&\@<F5N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5W3F%M92`@
M("`@("`@("`@("`@5&AE(&=R;W5P)W,@;F5W(&YA;64N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(')E;F%M94=R;W5P*"1G<F]U<"P@)&YE=TYA;64I"B`@("![
M"B`@("`@("`@:68@*"%I<U]A*"1G<F]U<"P@)T1A=&%4<F5E3V)J96-T7T=R
M;W5P)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)T=R;W5P<R!M=7-T(&)E($1A=&%4<F5E3V)J96-T7T=R;W5P(&]B:F5C=',@
M;W(@97AT96YD('1H870@8VQA<W,N)RD["B`@("`@("`@?0H@("`@("`@("1R
M97-U;'0@/2`D=&AI<RT^7V1A=&%T<F5E+3YR96YA;64H)&=R;W5P+"`D;F5W
M3F%M92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@
M("`@("`@("\J($AI<W1O<GD@3&]G('1H92!N86UE(&-H86YG92!O9B!T:&4@
M9W)O=7`N("HO"B`@("`@("`@)&AI<W1O<GD@/2`F2&]R9&5?2&ES=&]R>3HZ
M<VEN9VQE=&]N*"D["B`@("`@("`@)&AI<W1O<GDM/FQO9R@D=&AI<RT^9V5T
M1U5)1"@D9W)O=7`I+"!A<G)A>2@G86-T:6]N)R`]/B`G<F5N86UE)RDL('1R
M=64I.PH@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5M;W9E(&$@9W)O=7`@9G)O;2!T:&4@9W)O=7!S('-Y<W1E;2!P
M97)M86YE;G1L>2X*("`@("`J"B`@("`@*B!`<&%R86T@1&%T851R965/8FIE
M8W1?1W)O=7`@)&=R;W5P("!4:&4@9W)O=7`@=&\@<F5M;W9E+@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)&9O<F-E("`@("`@("`@("`@("`@1F]R8V4@=&\@
M<F5M;W9E(&5V97)Y(&-H:6QD+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO
M=F5'<F]U<"@D9W)O=7`L("1F;W)C92`](&9A;'-E*0H@("`@>PH@("`@("`@
M(&EF("@A:7-?82@D9W)O=7`L("=$871A5')E94]B:F5C=%]'<F]U<"<I*2![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"='<F]U<',@
M;75S="!B92!$871A5')E94]B:F5C=%]'<F]U<"!O8FIE8W1S(&]R(&5X=&5N
M9"!T:&%T(&-L87-S+B<I.PH@("`@("`@('T*"B`@("`@("`@)&AI<W1O<GD@
M/2`F2&]R9&5?2&ES=&]R>3HZ<VEN9VQE=&]N*"D["B`@("`@("`@)&AI<W1O
M<GDM/FQO9R@D=&AI<RT^9V5T1U5)1"@D9W)O=7`I+"!A<G)A>2@G86-T:6]N
M)R`]/B`G9&5L971E)RDL('1R=64I.PH*("`@("`@("!R971U<FX@)'1H:7,M
M/E]D871A=')E92T^<F5M;W9E*"1G<F]U<"P@)&9O<F-E*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E=')I979E('1H92!N86UE(&]F(&$@9W)O=7`N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&=I9"`@5&AE(&ED(&]F('1H
M92!G<F]U<"!T;R!R971R:65V92!T:&4@;F%M92!F;W(N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!G<F]U<"=S(&YA;64N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=$=R;W5P3F%M92@D9VED*0H@("`@>PH@("`@("`@
M(&EF("AI<U]A*"1G:60L("=$871A5')E94]B:F5C=%]'<F]U<"<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1A=&%T<F5E+3YG971.86UE*"1G
M:60M/F=E=$ED*"DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7V1A=&%T<F5E+3YG971.86UE*"1G:60I.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%-T<FEP<R!A;&P@<&%R96YT(')E
M9F5R96YC97,@;V9F(&]F('1H92!G:79E;B!G<F]U<"!N86UE+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&=R;W5P("!.86UE(&]F('1H92!G<F]U
M<"X*("`@("`J"B`@("`@*B!`<F5T=7)N(%1H92!N86UE(&]F('1H92!G<F]U
M<"!W:71H;W5T('!A<F5N=',N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$=R
M;W5P4VAO<G1.86UE*"1G<F]U<"D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]D871A=')E92T^9V5T4VAO<G1.86UE*"1G<F]U<"D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971R:65V92!T:&4@240@;V8@82!G<F]U<"X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1G<F]U<"`@5&AE(&=R;W5P('1O
M(')E=')I979E('1H92!)1"!F;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!I
M;G1E9V5R("!4:&4@9W)O=7`G<R!)1"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T1W)O=7!)9"@D9W)O=7`I"B`@("!["B`@("`@("`@:68@*&ES7V$H)&=R
M;W5P+"`G1&%T851R965/8FIE8W1?1W)O=7`G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]D871A=')E92T^9V5T260H)&=R;W5P+3YG971.86UE
M*"DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7V1A=&%T<F5E+3YG971)9"@D9W)O=7`I.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($-H96-K(&EF(&$@9W)O=7`@97AI<W1S(&EN('1H
M92!S>7-T96TN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9W)O=7`@
M(%1H92!G<F]U<"!T;R!C:&5C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%1R=64@:68@=&AE(&=R;W5P(&5X:7-T<RP@9F%L<V4@;W1H97)W
M:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>&ES=',H)&=R;W5P*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V1A=&%T<F5E+3YE>&ES=',H)&=R
M;W5P*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A(&QI<W0@;V8@=&AE
M('!A<F5N=',@;V8@82!C:&EL9"!G<F]U<"X*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D9VED(%1H92!I9"!O9B!T:&4@8VAI;&0@9W)O=7`N"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>0H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971'<F]U<%!A<F5N=',H)&=I9"D*("`@('L*("`@("`@("`D;F%M92`]
M("1T:&ES+3YG971'<F]U<$YA;64H)&=I9"D["B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?9&%T871R964M/F=E=%!A<F5N=',H)&YA;64I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N('1H92!S:6YG;&4@<&%R96YT(&]F('1H92!G
M:79E;B!G<F]U<"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9VED
M("!4:&4@1&%T851R964@240@;V8@=&AE(&-H:6QD(&=R;W5P+@H@("`@("H*
M("`@("`J($!R971U<FX@=&AE('!A<F5N="!O9B!T:&4@9VEV96X@9W)O=7`N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$=R;W5P4&%R96YT*"1G:60I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&%T871R964M/F=E=%!A<F5N
M=$)Y260H)&=I9"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!L:7-T
M(&]F('!A<F5N=',@86QL('1H92!W87D@=7`@=&\@=&AE(')O;W0@;V)J96-T
M(&9O<B`D9W)O=7`N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&=I
M9"`@5&AE(&ED(&]F('1H92!G<F]U<"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("!!(&9L870@;&ES="!O9B!A;&P@;V8@=&AE('!A<F5N=',@;V8@
M)&=R;W5P+`H@("`@("H@("`@("`@("`@("`@("`@:&%S:&5D(&EN("1I9"`]
M/B`D;F%M92!F;W)M870N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$=R;W5P
M4&%R96YT3&ES="@D9VED*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M7V1A=&%T<F5E+3YG971087)E;G1,:7-T*"1G:60I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1V5T(&$@;&ES="!O9B!E=F5R>2!G<F]U<"P@:6X@=&AE(&9O
M<FUA="!C:60@/3X@9W)O=7!N86UE+@H@("`@("H*("`@("`J($!P87)A;2!B
M;V]L96%N("1R969R97-H("!)9B!T<G5E+"!T:&4@8V%C:&5D('9A;'5E(&ES
M(&EG;F]R960@86YD('1H92!G<F]U<`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@(&QI<W0@:7,@<F5F<F5S:&5D(&9R;VT@=&AE(&=R;W5P(&)A
M8VME;F0N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@0TE$(#T^(&=R
M;W5P;F%M92!H87-H+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T1W)O=7!S
M*"1R969R97-H(#T@9F%L<V4I"B`@("!["B`@("`@("`@<W1A=&EC("1G<F]U
M<',["@H@("`@("`@(&EF("@D<F5F<F5S:"!\?"!I<U]N=6QL*"1G<F]U<',I
M*2!["B`@("`@("`@("`@("1G<F]U<',@/2`D=&AI<RT^7V1A=&%T<F5E+3YG
M970H1$%40512145?1D]234%47T9,050L($1!5$%44D5%7U)/3U0L('1R=64I
M.PH@("`@("`@("`@("!U;G-E="@D9W)O=7!S6T1!5$%44D5%7U)/3U1=*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D9W)O=7!S.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1V5T(&$@;&ES="!O9B!E=F5R>2!U<V5R('1H870@:7,@
M82!P87)T(&]F('1H:7,@9W)O=7`@3TY,62X*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D9VED("!4:&4@240@;V8@=&AE(&=R;W5P+@H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@(%1H92!U<V5R(&QI<W0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&QI<W15<V5R<R@D9VED*0H@("`@>PH@("`@("`@("1G
M<F]U<$]B(#T@)B1T:&ES+3YG971'<F]U<$)Y260H)&=I9"D["B`@("`@("`@
M:68@*&ES7V$H)&=R;W5P3V(L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1G<F]U<$]B.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I
M<W-E="@D9W)O=7!/8BT^9&%T85LG=7-E<G,G72D@?'P*("`@("`@("`@("`@
M(6ES7V%R<F%Y*"1G<F]U<$]B+3YD871A6R=U<V5R<R==*2D@>PH@("`@("`@
M("`@("!R971U<FX@87)R87DH*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!A<G)A>5]K97ES*"1G<F]U<$]B+3YD871A6R=U<V5R<R==*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($=E="!A(&QI<W0@;V8@979E<GD@=7-E<B!T:&%T
M(&ES('!A<G0@;V8@=&AE('-P96-I9FEE9"!G<F]U<`H@("`@("H@86YD(&%N
M>2!O9B!I=',@<W5B9W)O=7!S+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E
M9V5R("1G<F]U<"`@5&AE($E$(&]F('1H92!P87)E;G0@9W)O=7`N"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&-O;7!L971E('5S97(@;&ES
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=$%L;%5S97)S*"1G:60I"B`@
M("!["B`@("`@("`@+R\@1V5T(&$@;&ES="!O9B!E=F5R>2!G<F]U<"!T:&%T
M(&ES(&$@<W5B+6=R;W5P(&]F("1G<F]U<"X*("`@("`@("`D9W)O=7!S(#T@
M)'1H:7,M/E]D871A=')E92T^9V5T*$1!5$%44D5%7T9/4DU!5%]&3$%4+"`D
M=&AI<RT^9V5T1W)O=7!.86UE*"1G:60I+"!T<G5E*3L*("`@("`@("!I9B`H
M:7-?82@D9W)O=7!S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D9W)O=7!S.PH@("`@("`@('T*"B`@("`@("`@)&=R;W5P<R`](&%R
M<F%Y7VME>7,H)&=R;W5P<RD["B`@("`@("`@)'5S97)S(#T@87)R87DH*3L*
M("`@("`@("!F;W)E86-H("@D9W)O=7!S(&%S("1G<F]U<$ED*2!["B`@("`@
M("`@("`@("1U<V5R<R`](&%R<F%Y7VUE<F=E*"1U<V5R<RP@)'1H:7,M/FQI
M<W15<V5R<R@D9W)O=7!)9"DI.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M87)R87E?=F%L=65S*&%R<F%Y7V9L:7`H87)R87E?9FQI<"@D=7-E<G,I*2D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!L:7-T(&]F(&5V97)Y(&=R
M;W5P('1H870@)'5S97(@:7,@:6XN"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`@)'5S97(@("`@("`@("`@5&AE('5S97(@=&\@9V5T(&=R;W5P<R!F
M;W(N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<&%R96YT1W)O=7!S("!!;'-O
M(')E='5R;B!T:&4@<&%R96YT<R!O9B!A;GD@9W)O=7!S/PH@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y(&]F(&%L;"!G<F]U<',@=&AE
M('5S97(@:7,@:6XN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$=R;W5P365M
M8F5R<VAI<',H)'5S97(L("1P87)E;G1'<F]U<',@/2!F86QS92D*("`@('L*
M("`@("`@("!S=&%T:6,@)&-A8VAE.PH*("`@("`@("!I9B`H96UP='DH)&-A
M8VAE6R1U<V5R72DI('L*("`@("`@("`@("`@)&-R:71E<FEA(#T@87)R87DH
M"B`@("`@("`@("`@("`@("`G04Y$)R`]/B!A<G)A>2@*("`@("`@("`@("`@
M("`@("`@("!A<G)A>2@G9FEE;&0G(#T^("=N86UE)RP@)V]P)R`]/B`G/2<L
M("=T97-T)R`]/B`G=7-E<B<I+`H@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"=F:65L9"<@/3X@)VME>2<L("=O<"<@/3X@)STG+"`G=&5S="<@/3X@)'5S
M97(I*2D["B`@("`@("`@("`@("1G<F]U<',@/2`D=&AI<RT^7V1A=&%T<F5E
M+3YG971">4%T=')I8G5T97,H)&-R:71E<FEA*3L*"B`@("`@("`@("`@(&EF
M("AI<U]A*"1G<F]U<',L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@($AO<F1E.CIL;V=-97-S86=E*"1G<F]U<',L(%]?1DE,15]?+"!?7TQ)
M3D5?7RP@4$5!4E],3T=?15)23U(I.PH@("`@("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)'!A<F5N
M=$=R;W5P<RD@>PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&=R;W5P<R!A
M<R`D:60@/3X@)&<I('L*("`@("`@("`@("`@("`@("`@("`D<&%R96YT<R`]
M("1T:&ES+3Y?9&%T871R964M/F=E=%!A<F5N=$QI<W0H)&ED*3L*("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-?82@D<&%R96YT<RP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'!A<F5N=',[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1G
M<F]U<',@*ST@)'!A<F5N=',["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("1C86-H95LD=7-E<ET@/2`D9W)O=7!S.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1C86-H95LD=7-E<ET["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!387D@:68@82!U<V5R(&ES(&$@;65M8F5R(&]F
M(&$@9W)O=7`@;W(@;F]T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'5S97(@("`@("`@(%1H92!N86UE(&]F('1H92!U<V5R+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&=I9"`@("`@("`@5&AE($E$(&]F('1H92!G<F]U<"X*
M("`@("`J($!P87)A;2!B;V]L96%N("1S=6)G<F]U<',@(%)E='5R;B!T<G5E
M(&EF('1H92!U<V5R(&ES(&EN(&%N>2!S=6)G<F]U<',*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&]F(&=R;W5P('=I=&@@240@)&=I9"P@
M86QS;RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X*("`@("`J+PH@
M("`@9G5N8W1I;VX@=7-E<DES26Y'<F]U<"@D=7-E<BP@)&=I9"P@)'-U8F=R
M;W5P<R`]('1R=64I"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^97AI<W1S
M*"1T:&ES+3YG971'<F]U<$YA;64H)&=I9"DI*2!["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!](&5L<V5I9B`H)'-U8F=R;W5P<RD@>PH@
M("`@("`@("`@("`D9W)O=7!S(#T@)'1H:7,M/F=E=$=R;W5P365M8F5R<VAI
M<',H)'5S97(L('1R=64I.PH@("`@("`@("`@("!I9B`H:7-?82@D9W)O=7!S
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!(;W)D93HZ;&]G
M365S<V%G92@D9W)O=7!S+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'
M7T524BD["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@(')E='5R;B`A96UP='DH)&=R;W5P<ULD9VED
M72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'5S97)S(#T@)'1H
M:7,M/FQI<W15<V5R<R@D9VED*3L*("`@("`@("`@("`@:68@*&ES7V$H)'5S
M97)S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!(;W)D93HZ
M;&]G365S<V%G92@D=7-E<G,L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],
M3T=?15)2*3L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!R971U<FX@:6Y?87)R87DH)'5S97(L("1U
M<V5R<RD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!T:&4@1&%T851R964@;&5V96P@;V8@=&AE(&=I=F5N(&=R;W5P+B`P(&ES
M(')E='5R;F5D(&9O<@H@("`@("H@86YD(&]B:F5C="!D:7)E8W1L>2!B96QO
M=R!$051!5%)%15]23T]4+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R
M("1G:60@(%1H92!$871A5')E92!)1"!O9B!T:&4@9W)O=7`N"B`@("`@*@H@
M("`@("H@0')E='5R;B!4:&4@1&%T851R964@;&5V96P@;V8@=&AE(&=R;W5P
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971,979E;"@D9VED*0H@("`@>PH@
M("`@("`@("1N86UE(#T@)'1H:7,M/E]D871A=')E92T^9V5T3F%M92@D9VED
M*3L*("`@("`@("!R971U<FX@<W5B<W1R7V-O=6YT*"1N86UE+"`G.B<I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N
M8W)E=&4@1W)O=7`@:6YS=&%N8V4@8F%S960@;VX@)&1R:79E<BX*("`@("`J
M"B`@("`@*B!`<&%R86T@;6EX960@)&1R:79E<B`@5&AE('1Y<&4@;V8@8V]N
M8W)E=&4@1W)O=7`@<W5B8VQA<W,@=&\@<F5T=7)N+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO
M;F%L(&-O;F9I9W5R871I;VX@;W(*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!C;VYN96-T:6]N('!A<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N
M965D+@H@("`@("H*("`@("`J($!R971U<FX@1W)O=7`@(%1H92!N97=L>2!C
M<F5A=&5D(&-O;F-R971E($=R;W5P(&EN<W1A;F-E+"!O<B!A"B`@("`@*B`@
M("`@("`@("`@("`@("!014%27T5R<F]R(&]B:F5C="!O;B!A;B!E<G)O<BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH)&1R:79E<B`]("<G+"`D
M<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@("`D9')I=F5R(#T@8F%S96YA
M;64H)&1R:79E<BD["@H@("`@("`@(&EF("A`9FEL95]E>&ES=',H9&ER;F%M
M92A?7T9)3$5?7RD@+B`G+T=R;W5P+R<@+B`D9')I=F5R("X@)RYP:'`G*2D@
M>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@
M+B`G+T=R;W5P+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@($!I;F-L=61E7V]N8V4@)TAO<F1E+T=R;W5P+R<@
M+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T*("`@("`@("`D8VQA<W,@
M/2`G1W)O=7!?)R`N("1D<FEV97(["B`@("`@("`@:68@*&-L87-S7V5X:7-T
M<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1G<F]U<"`]("9N97<@)&-L87-S
M*"1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1G<F]U
M<"`](%!%05(Z.G)A:7-E17)R;W(H)T-L87-S(&1E9FEN:71I;VX@;V8@)R`N
M("1C;&%S<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1G<F]U<#L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S
M('1O(')E='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R971E($=R;W5P(&EN
M<W1A;F-E+@H@("`@("H@270@=VEL;"!O;FQY(&-R96%T92!A(&YE=R!I;G-T
M86YC92!I9B!N;R!'<F]U<"!I;G-T86YC90H@("`@("H@8W5R<F5N=&QY(&5X
M:7-T<RX*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K
M960@87,Z("1V87(@/2`F1W)O=7`Z.G-I;F=L971O;B@I"B`@("`@*@H@("`@
M("H@0')E='5R;B!'<F]U<"`@5&AE(&-O;F-R971E($=R;W5P(')E9F5R96YC
M92P@;W(@9F%L<V4@;VX@86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9S:6YG;&5T;VXH*0H@("`@>PH@("`@("`@('-T871I8R`D9W)O=7`["@H@
M("`@("`@(&EF("@A:7-S970H)&=R;W5P*2D@>PH@("`@("`@("`@("!G;&]B
M86P@)&-O;F8["@H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T%U
M=&@N<&AP)SL*("`@("`@("`@("`@)&%U=&@@/2`F075T:#HZ<VEN9VQE=&]N
M*"1C;VYF6R=A=71H)UU;)V1R:79E<B==*3L*("`@("`@("`@("`@:68@*"1A
M=71H+3YH87-#87!A8FEL:71Y*"=G<F]U<',G*2D@>PH@("`@("`@("`@("`@
M("`@)&=R;W5P(#T@)D=R;W5P.CIF86-T;W)Y*"1A=71H+3YG971$<FEV97(H
M*2P@)&%U=&@I.PH@("`@("`@("`@("!](&5L<V5I9B`H(65M<'1Y*"1C;VYF
M6R=G<F]U<"==6R=D<FEV97(G72D@)B8@)&-O;F9;)V=R;W5P)UU;)V1R:79E
M<B==("$]("=D871A=')E92<I('L*("`@("`@("`@("`@("`@("1G<F]U<"`]
M("9'<F]U<#HZ9F%C=&]R>2@D8V]N9ELG9W)O=7`G75LG9')I=F5R)UTI.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&=R;W5P(#T@
M;F5W($=R;W5P*"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D9W)O=7`["B`@("!]"@I]"@HO*BH*("H@17AT96YS:6]N(&]F
M('1H92!$871A5')E94]B:F5C="!C;&%S<R!F;W(@<W1O<FEN9R!'<F]U<"!I
M;F9O<FUA=&EO;@H@*B!I;B!T:&4@0V%T96=O<FEE<R!D<FEV97(N($EF('EO
M=2!W86YT('1O('-T;W)E('-P96-I86QI>F5D($=R;W5P"B`J(&EN9F]R;6%T
M:6]N+"!Y;W4@<VAO=6QD(&5X=&5N9"!T:&ES(&-L87-S(&EN<W1E860@;V8@
M97AT96YD:6YG"B`J($1A=&%4<F5E3V)J96-T(&1I<F5C=&QY+@H@*@H@*B!`
M875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@
M0'-I;F-E("`@2&]R9&4@,BXQ"B`J($!P86-K86=E($AO<F1E7T=R;W5P"B`J
M+PIC;&%S<R!$871A5')E94]B:F5C=%]'<F]U<"!E>'1E;F1S($1A=&%4<F5E
M3V)J96-T('L*"B`@("`O*BH*("`@("`J(%1H92!'<F]U<"!O8FIE8W0@=VAI
M8V@@=&AI<R!G<F]U<"!I<R!A<W-O8VEA=&5D('=I=&@@+2!N965D960*("`@
M("`J(&9O<B!U<&1A=&EN9R!D871A(&EN('1H92!B86-K96YD('1O(&UA:V4@
M8VAA;F=E<R!S=&EC:RP@971C+@H@("`@("H*("`@("`J($!V87(@1W)O=7`*
M("`@("`J+PH@("`@=F%R("1?9W)O=7!/8CL*"B`@("`O*BH*("`@("`J(%1H
M:7,@=F%R:6%B;&4@8V%C:&5S('1H92!U<V5R<R!A9&1E9"!O<B!R96UO=F5D
M(&9R;VT@=&AE(&=R;W5P"B`@("`@*B!F;W(@2&ES=&]R>2!L;V=G:6YG(&]F
M('5S97(M9W)O=7!S(')E;&%T:6]N<VAI<"X*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V%U9&ET3&]G(#T@87)R87DH*3L*
M"B`@("`O*BH*("`@("`J(%1H92!$871A5')E94]B:F5C=%]'<F]U<"!C;VYS
M=')U8W1O<BX@2G5S="!M86ME<R!S=7)E('1O(&-A;&P*("`@("`J('1H92!P
M87)E;G0@8V]N<W1R=6-T;W(@<V\@=&AA="!T:&4@9W)O=7`G<R!N86UE(&ES
M('-E=`H@("`@("H@<')O<&5R;'DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;F%M92`@5&AE(&YA;64@;V8@=&AE(&=R;W5P+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!$871A5')E94]B:F5C=%]'<F]U<"@D;F%M92D*("`@('L*
M("`@("`@("!P87)E;G0Z.D1A=&%4<F5E3V)J96-T*"1N86UE*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($%S<V]C:6%T97,@82!'<F]U<"!O8FIE8W0@=VET
M:"!T:&ES(&=R;W5P+@H@("`@("H*("`@("`J($!P87)A;2!'<F]U<"`D9W)O
M=7!/8B`@5&AE($=R;W5P(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<V5T1W)O=7!/8B@F)&=R;W5P3V(I"B`@("!["B`@("`@("`@)'1H:7,M/E]G
M<F]U<$]B(#T@)B1G<F]U<$]B.PH@("`@?0H*("`@("\J*@H@("`@("H@1F5T
M8V@@=&AE($E$(&]F('1H:7,@9W)O=7`*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R!4:&4@9W)O=7`G<R!)1`H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971)9"@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9W)O=7!/8BT^
M9V5T1W)O=7!)9"@D=&AI<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3879E
M(&%N>2!C:&%N9V5S('1O('1H:7,@;V)J96-T('1O('1H92!B86-K96YD('!E
M<FUA;F5N=&QY+@H@("`@("HO"B`@("!F=6YC=&EO;B!S879E*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]G<F]U<$]B+3YU<&1A=&5'<F]U<"@D
M=&AI<RD["@H@("`@?0H*("`@("\J*@H@("`@("H@061D<R!A('5S97(@=&\@
M=&AI<R!G<F]U<"P@86YD(&UA:V5S('-U<F4@=&AA="!T:&4@8F%C:V5N9"!I
M<PH@("`@("H@=7!D871E9"!A<R!W96QL+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'5S97)N86UE(%1H92!U<V5R('1O(&%D9"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@861D57-E<B@D=7-E<FYA;64L("1U<&1A=&4@/2!T<G5E
M*0H@("`@>PH@("`@("`@("1T:&ES+3YD871A6R=U<V5R<R==6R1U<V5R;F%M
M95T@/2`Q.PH@("`@("`@("1T:&ES+3Y?875D:71,;V=;)'5S97)N86UE72`]
M("=A9&15<V5R)SL*("`@("`@("!I9B`H)'5P9&%T92`F)B`D=&AI<RT^7V=R
M;W5P3V(M/F5X:7-T<R@D=&AI<RT^9V5T3F%M92@I*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G-A=F4H*3L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!296UO=F5S(&$@=7-E<B!F<F]M('1H:7,@9W)O=7`L(&%N
M9"!M86ME<R!S=7)E('1H870@=&AE(&)A8VME;F0*("`@("`J(&ES('5P9&%T
M960@87,@=V5L;"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R
M;F%M92!4:&4@=7-E<B!T;R!R96UO=F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E;6]V955S97(H)'5S97)N86UE+"`D=7!D871E(#T@=')U92D*("`@('L*
M("`@("`@("!U;G-E="@D=&AI<RT^9&%T85LG=7-E<G,G75LD=7-E<FYA;65=
M*3L*("`@("`@("`D=&AI<RT^7V%U9&ET3&]G6R1U<V5R;F%M95T@/2`G9&5L
M971E57-E<B<["B`@("`@("`@:68@*"1U<&1A=&4I('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YS879E*"D["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@1V5T(&$@;&ES="!O9B!E=F5R>2!U<V5R('1H870@:7,@82!P
M87)T(&]F('1H:7,@9W)O=7`*("`@("`J("AA;F0@;VYL>2!T:&ES(&=R;W5P
M*0H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!U<V5R(&QI<W0*
M("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=%5S97)S*"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]G<F]U<$]B+3YL:7-T57-E<G,H)'1H:7,M/F=E
M=$ED*"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T(&$@;&ES="!O9B!E
M=F5R>2!U<V5R('1H870@:7,@82!P87)T(&]F('1H:7,@9W)O=7`@86YD"B`@
M("`@*B!A;GD@;V8@:70G<R!S=6)G<F]U<',*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("!4:&4@8V]M<&QE=&4@=7-E<B!L:7-T"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&QI<W1!;&Q5<V5R<R@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?9W)O=7!/8BT^;&ES=$%L;%5S97)S*"1T:&ES+3YG971)9"@I
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A;&P@=&AE('5S97)S(')E
M8V5N=&QY(&%D9&5D(&]R(')E;6]V960@9G)O;2!T:&4@9W)O=7`N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$%U9&ET3&]G*"D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]A=61I=$QO9SL*("`@('T*"B`@("`O*BH*("`@("`J
M($-L96%R<R!T:&4@875D:70@;&]G+B!4;R!B92!C86QL960@869T97(@9W)O
M=7`@=7!D871E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;&5A<D%U9&ET3&]G
M*"D*("`@('L*("`@("`@("`D=&AI<RT^7V%U9&ET3&]G(#T@87)R87DH*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($UA<"!T:&ES(&]B:F5C="=S(&%T=')I
M8G5T97,@9G)O;2!T:&4@9&%T82!A<G)A>2!I;G1O(&$@9F]R;6%T"B`@("`@
M*B!T:&%T('=E(&-A;B!S=&]R92!I;B!T:&4@871T<FEB=71E<R!S=&]R86=E
M(&)A8VME;F0N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&%T
M=')I8G5T97,@87)R87DN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]T;T%T=')I
M8G5T97,H*0H@("`@>PH@("`@("`@("\O($1E9F%U;'0@=&\@;F\@871T<FEB
M=71E<RX*("`@("`@("`D871T<FEB=71E<R`](&%R<F%Y*"D["@H@("`@("`@
M("\O($QO;W`@=&AR;W5G:"!A;&P@=7-E<G,L(&EF(&%N>2X*("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/F1A=&%;)W5S97)S)UTI("8F(&ES7V%R<F%Y*"1T
M:&ES+3YD871A6R=U<V5R<R==*2`F)B!C;W5N="@D=&AI<RT^9&%T85LG=7-E
M<G,G72DI('L*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/F1A=&%;)W5S
M97)S)UT@87,@)'5S97(@/3X@)&%C=&EV92D@>PH@("`@("`@("`@("`@("`@
M)&%T=')I8G5T97-;72`](&%R<F%Y*"=N86UE)R`]/B`G=7-E<B<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VME>2<@/3X@)'5S
M97(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W9A
M;'5E)R`]/B`D86-T:79E*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M("`@("`D871T<FEB=71E<UM=(#T@87)R87DH)VYA;64G(#T^("=E;6%I;"<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=K97DG(#T^("<G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=F%L=64G(#T^("1T:&ES
M+3YG970H)V5M86EL)RDI.PH*("`@("`@("!R971U<FX@)&%T=')I8G5T97,[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!486ME(&EN(&$@;&ES="!O9B!A='1R
M:6)U=&5S(&9R;VT@=&AE(&)A8VME;F0@86YD(&UA<"!I="!T;R!O=7(*("`@
M("`J(&EN=&5R;F%L(&1A=&$@87)R87DN"B`@("`@*@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1A='1R:6)U=&5S("!4:&4@;&ES="!O9B!A='1R:6)U=&5S(&9R
M;VT@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&)A8VME
M;F0@*&%T=')I8G5T92!N86UE+"!K97DL(&%N9"!V86QU92DN"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]F<F]M071T<FEB=71E<R@D871T<FEB=71E<RD*("`@
M('L*("`@("`@("`O+R!);FET:6%L:7IE(&1A=&$@87)R87DN"B`@("`@("`@
M)'1H:7,M/F1A=&%;)W5S97)S)UT@/2!A<G)A>2@I.PH*("`@("`@("!F;W)E
M86-H("@D871T<FEB=71E<R!A<R`D871T<BD@>PH@("`@("`@("`@("!I9B`H
M)&%T=');)VYA;64G72`]/2`G=7-E<B<I('L*("`@("`@("`@("`@("`@("1T
M:&ES+3YD871A6R=U<V5R<R==6R1A='1R6R=K97DG75T@/2`D871T<ELG=F%L
M=64G73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T
M:&ES+3YD871A6R1A='1R6R=N86UE)UU=(#T@)&%T=');)W9A;'5E)UT["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+T-I<&AE<BYP:'``````````````````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`V,#0T(#$P-3$U-#,S-S0P(#`R,3(W,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M5&AE($AO<F1E7T-I<&AE<CHZ(&-L87-S('!R;W9I9&5S(&$@8V]M;6]N(&%B
M<W1R86-T960@:6YT97)F86-E('1O"B`J('9A<FEO=7,@0VEP:&5R<R!F;W(@
M96YC<GEP=&EO;B!O9B!A<F)I=')A<GD@;&5N9W1H('!I96-E<R!O9B!D871A
M+@H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI:V4@0V]C:')A;F4@/&UI
M:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]#:7!H97(O0VEP:&5R+G!H<"QV(#$N,38N,3(N."`R
M,#`V+S`Q+S`Q(#(Q.C(X.C$P(&IA;B!%>'`@)`H@*@H@*B!`875T:&]R("!-
M:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN
M8V4@("!(;W)D92`R+C(*("H@0'!A8VMA9V4@2&]R9&5?0VEP:&5R"B`J+PIC
M;&%S<R!(;W)D95]#:7!H97(@>PH*("`@("\J*@H@("`@("H@5&AE(&)L;V-K
M(&UO9&4@9F]R('1H92!C:7!H97(@8VAA:6YI;F<*("`@("`J"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]B;&]C:TUO9&4@/2`G0T)#
M)SL*"B`@("`O*BH*("`@("`J(%1H92!I;FET:6%L:7IA=&EO;B!V96-T;W(*
M("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]I
M=B`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&)L;V-K(&UO9&4@
M9F]R(&-I<&AE<B!C:&%I;FEN9RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1B;&]C:TUO9&4@(%1H92!N97<@8FQO8VMM;V1E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!S971";&]C:TUO9&4H)&)L;V-K36]D92D*("`@('L*("`@
M("`@("`D=&AI<RT^7V)L;V-K36]D92`]("1B;&]C:TUO9&4["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!3970@=&AE($E6+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&EV("!4:&4@;F5W($E6+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!S971)5B@D:78I"B`@("!["B`@("`@("`@)'1H:7,M/E]I=B`]("1I=CL*
M("`@('T*"B`@("`O*BH*("`@("`J($5N8W)Y<'0@82!S=')I;F<N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&QA:6YT97AT("!4:&4@9&%T82!T
M;R!E;F-R>7!T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M96YC<GEP=&5D(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N8W)Y<'0H
M)'!L86EN=&5X="D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M
M92A?7T9)3$5?7RD@+B`G+T-I<&AE<B]";&]C:TUO9&4N<&AP)SL*("`@("`@
M("`D8FQO8VM-;V1E(#T@)DAO<F1E7T-I<&AE<E]";&]C:TUO9&4Z.F9A8W1O
M<GDH)'1H:7,M/E]B;&]C:TUO9&4I.PH@("`@("`@(&EF("@A:7-?;G5L;"@D
M=&AI<RT^7VEV*2D@>PH@("`@("`@("`@("`D8FQO8VM-;V1E+3YS971)5B@D
M=&AI<RT^7VEV*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D8FQO8VM-
M;V1E+3YE;F-R>7!T*"1T:&ES+"`D<&QA:6YT97AT*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($1E8W)Y<'0@82!S=')I;F<N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D8VEP:&5R=&5X="`@5&AE(&1A=&$@=&\@9&5C<GEP="X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&1E8W)Y<'1E9"!D
M871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96-R>7!T*"1C:7!H97)T97AT
M*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?
M*2`N("<O0VEP:&5R+T)L;V-K36]D92YP:'`G.PH@("`@("`@("1B;&]C:TUO
M9&4@/2`F2&]R9&5?0VEP:&5R7T)L;V-K36]D93HZ9F%C=&]R>2@D=&AI<RT^
M7V)L;V-K36]D92D["B`@("`@("`@:68@*"%I<U]N=6QL*"1T:&ES+3Y?:78I
M*2!["B`@("`@("`@("`@("1B;&]C:TUO9&4M/G-E=$E6*"1T:&ES+3Y?:78I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1B;&]C:TUO9&4M/F1E8W)Y
M<'0H)'1H:7,L("1C:7!H97)T97AT*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($%T=&5M<'1S('1O(')E='5R;B!A(&-O;F-R971E($AO<F1E7T-I<&AE<B!I
M;G-T86YC92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C:7!H97(@
M(%1H92!T>7!E(&]F(&-O;F-R971E($AO<F1E7T-I<&AE<B!S=6)C;&%S<R!T
M;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FXN"B`@("`@
M*B!`<&%R86T@87)R87D@)'!A<F%M<R`@($$@:&%S:"!C;VYT86EN:6YG(&%N
M>2!A9&1I=&EO;F%L('!A<F%M971E<G,@80H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@("`J
M($!R971U<FX@2&]R9&5?0VEP:&5R("!4:&4@;F5W;'D@8W)E871E9"!C;VYC
M<F5T92!(;W)D95]#:7!H97(@:6YS=&%N8V4L"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@;W(@4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@("`J+PH@
M("`@9G5N8W1I;VX@)F9A8W1O<GDH)&-I<&AE<BP@)'!A<F%M<R`](&YU;&PI
M"B`@("!["B`@("`@("`@)&1R:79E<B`](&)A<V5N86UE*"1C:7!H97(I.PH*
M("`@("`@("!I9B`H0&9I;&5?97AI<W1S*&1I<FYA;64H7U]&24Q%7U\I("X@
M)R]#:7!H97(O)R`N("1C:7!H97(@+B`G+G!H<"<I*2!["B`@("`@("`@("`@
M(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O0VEP:&5R+R<@
M+B`D8VEP:&5R("X@)RYP:'`G.PH@("`@("`@('T*"B`@("`@("`@)&-L87-S
M(#T@)TAO<F1E7T-I<&AE<E\G("X@)&-I<&AE<CL*("`@("`@("!I9B`H8VQA
M<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@)&-I<&AE<B`]("9N
M97<@)&-L87-S*"1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1C:7!H97(@/2!014%2.CIR86ES945R<F]R*"=#;&%S<R!D969I;FET
M:6]N(&]F("<@+B`D8VQA<W,@+B`G(&YO="!F;W5N9"XG*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D8VEP:&5R.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92]296=I<W1R>2YP:'``````````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#$Q,3<R,R`Q,#4Q-30S,S<T,"`P,C$V-S(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"B\J*B!$
M;R!N;W0@<W1A<G0@82!S97-S:6]N+B`J+PID969I;F4H)TA/4D1%7U-%4U-)
M3TY?3D].12<L(#$I.PH*+RHJ($1O(&YO="!W<FET92!C:&%N9V5S('1O('-E
M<W-I;VXN("HO"F1E9FEN92@G2$]21$5?4T534TE/3E]214%$3TY,62<L(#(I
M.PH*+RHJ"B`J(%1H92!296=I<W1R>3HZ(&-L87-S('!R;W9I9&5S(&$@<V5T
M(&]F(&UE=&AO9',@9F]R(&-O;6UU;FEC871I;VX*("H@8F5T=V5E;B!(;W)D
M92!A<'!L:6-A=&EO;G,@86YD(&ME97!I;F<@=')A8VL@;V8@87!P;&EC871I
M;VX*("H@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;BX*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP+'8@,2XR-#,N
M,BXR,B`R,#`V+S`U+S`T(#(R.C,U.C(V(&IA;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H
M;W)D92YO<F<^"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@06YI;"!-861H879A
M<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`
M875T:&]R("!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!`875T:&]R
M("!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`<VEN
M8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?1G)A;65W;W)K"B`J
M+PIC;&%S<R!296=I<W1R>2!["@H@("`@+RHJ"B`@("`@*B!(87-H('-T;W)I
M;F<@86QL(&]F('1H92!K;F]W;B!S97)V:6-E<R!A;F0@8V%L;&)A8VMS+@H@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?87!I
M0V%C:&4@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@2&%S:"!S=&]R:6YG
M(&%L;"!K;F]W;B!D871A('1Y<&5S+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?='EP94-A8VAE(#T@87)R87DH*3L*"B`@
M("`O*BH*("`@("`J($AA<V@@<W1O<FEN9R!A;&P@;V8@=&AE(')E9VES=&5R
M960@:6YT97)F86-E<R!T:&%T(&%P<&QI8V%T:6]N<PH@("`@("H@<')O=FED
M92X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D
M7VEN=&5R9F%C97,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@2&%S:"!S
M=&]R:6YG(&EN9F]R;6%T:6]N(&]N(&5A8V@@<F5G:7-T<GDM87=A<F4@87!P
M;&EC871I;VXN"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)&%P<&QI8V%T:6]N<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@
M*B!3=&%C:R!O9B!I;BUU<V4@87!P;&EC871I;VYS+@H@("`@("H*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?87!P4W1A8VL@/2!A<G)A
M>2@I.PH*("`@("\J*@H@("`@("H@475I8VL@<&]I;G1E<B!T;R!T:&4@8W5R
M<F5N="!A<'!L:6-A=&EO;BX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("HO"B`@("!V87(@)%]C=7)R96YT07!P(#T@;G5L;#L*"B`@("`O*BH*
M("`@("`J($-A8VAE(&]F("1P<F5F<R!O8FIE8W1S"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P<F5F<T-A8VAE(#T@87)R
M87DH*3L*"B`@("`O*BH*("`@("`J($-A8VAE(&]F(&%P<&QI8V%T:6]N(&-O
M;F9I9W5R871I;VYS+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1?8V]N9D-A8VAE(#T@87)R87DH*3L*"B`@("`O*BH*("`@
M("`J($%R92!W92!U<VEN9R!R96=I<W1R>2!C86-H:6YG/PH@("`@("H*("`@
M("`J($!P87)A;2!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7W5S96-A8VAE
M(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!5<&1A=&4@=&AE<V4@8V%C:&4@
M96YT<FEE<R!O;B!S:'5T9&]W;BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D*("`@("`J+PH@("`@=F%R("1?=7!D871E8V%C:&4@/2!A<G)A>2@I.PH*
M("`@("\J*@H@("`@("H@57!D871E('1H97-E(&UT:6UE(&5N=')I97,@;VX@
M<VAU=&1O=VXN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y"B`@("`@*B\*
M("`@('9A<B`D7W5P9&%T96UT:6UE(#T@87)R87DH*3L*"B`@("`O*BH*("`@
M("`J($1O;B=T('5P9&%T92!C86-H92!A="!E;F0@;V8@<F5Q=65S=#\*("`@
M("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]N
M;V-A8VAE(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<F5F
M97)E;F-E('1O('1H92!G;&]B86P@4F5G:7-T<GD@;V)J96-T+"!O;FQY"B`@
M("`@*B!C<F5A=&EN9R!I="!I9B!I="!D;V5S;B=T(&%L<F5A9'D@97AI<W0N
M"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S
M.B`D<F5G:7-T<GD@/2`F4F5G:7-T<GDZ.G-I;F=L971O;B@I"B`@("`@*@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)'-E<W-I;VY?9FQA9W,@($%N>2!S97-S
M:6]N(&9L86=S+@H@("`@("H*("`@("`J($!R971U<FX@4F5G:7-T<GD@(%1H
M92!(;W)D92!296=I<W1R>2!I;G-T86YC92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@)G-I;F=L971O;B@D<V5S<VEO;E]F;&%G<R`](#`I"B`@("!["B`@("`@
M("`@<W1A=&EC("1R96=I<W1R>3L*"B`@("`@("`@:68@*"%I<W-E="@D<F5G
M:7-T<GDI*2!["B`@("`@("`@("`@("1R96=I<W1R>2`](&YE=R!296=I<W1R
M>2@D<V5S<VEO;E]F;&%G<RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)')E9VES=')Y.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E(&$@;F5W
M(')E9VES=')Y(&EN<W1A;F-E+B!3:&]U;&0@;F5V97(@8F4@8V%L;&5D(&5X
M8V5P=`H@("`@("H@8GD@)E)E9VES=')Y.CIS:6YG;&5T;VXH*2X*("`@("`J
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<V5S<VEO;E]F;&%G<R`@06YY('-E
M<W-I;VX@9FQA9W,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%)E9VES=')Y*"1S97-S:6]N7V9L86=S(#T@
M,"D*("`@('L*("`@("`@("`O*B!);7!O<G0@86YD(&=L;V)A;"!(;W)D92=S
M(&-O;F9I9W5R871I;VX@=F%L=65S+B`J+PH@("`@("`@("1T:&ES+3YI;7!O
M<G1#;VYF:6<H)VAO<F1E)RD["@H@("`@("`@("\J(%-T87)T(&$@<V5S<VEO
M;BX@*B\*("`@("`@("!I9B`H)'-E<W-I;VY?9FQA9W,@)B!(3U)$15]315-3
M24].7TY/3D4I('L*("`@("`@("`@("`@+RH@3F5V97(@<W1A<G0@82!S97-S
M:6]N(&EF('1H92!S97-S:6]N(&9L86=S(&EN8VQU9&4*("`@("`@("`@("`@
M("`@2$]21$5?4T534TE/3E].3TY%+B`J+PH@("`@("`@("`@("`D7U-%4U-)
M3TX@/2!A<G)A>2@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@($AO
M<F1E.CIS971U<%-E<W-I;VY(86YD;&5R*"D["B`@("`@("`@("`@($!S97-S
M:6]N7W-T87)T*"D["B`@("`@("`@("`@(&EF("@D<V5S<VEO;E]F;&%G<R`F
M($A/4D1%7U-%4U-)3TY?4D5!1$].3%DI('L*("`@("`@("`@("`@("`@("\J
M($-L;W-E('1H92!S97-S:6]N(&EM;65D:6%T96QY('-O(&YO(&-H86YG97,@
M8V%N(&)E"B`@("`@("`@("`@("`@("`@("!M861E(&)U="!V86QU97,@87)E
M('-T:6QL(&%V86EL86)L92X@*B\*("`@("`@("`@("`@("`@($!S97-S:6]N
M7W=R:71E7V-L;W-E*"D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7W5S96-A8VAE(#T@=')U93L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@+RH@26YI=&EA;&EZ92!T:&4@;&]C86QI
M>F%T:6]N(')O=71I;F5S(&%N9"!V87)I86)L97,N("HO"B`@("`@("`@3DQ3
M.CIS971,86YG*"D["B`@("`@("`@3DQ3.CIS971497AT9&]M86EN*"=H;W)D
M92<L($A/4D1%7T)!4T4@+B`G+VQO8V%L92<L($Y,4SHZ9V5T0VAA<G-E="@I
M*3L*("`@("`@("!3=')I;F<Z.G-E=$1E9F%U;'1#:&%R<V5T*$Y,4SHZ9V5T
M0VAA<G-E="@I*3L*"B`@("`@("`@)')E9U]M=&EM92`](&9I;&5M=&EM92A(
M3U)$15]"05-%("X@)R]C;VYF:6<O<F5G:7-T<GDN<&AP)RD["@H@("`@("`@
M("\J($QO860@<F5G:7-T<GD@:6YF;W)M871I;VX@9G)O;2!T:&4@<V5S<VEO
M;BP@:68@879A:6QA8FQE+B`J+PH@("`@("`@(&EF("@A96UP='DH)%]315-3
M24].6R=?<F5G:7-T<GEC86-H92==*2`F)@H@("`@("`@("`@("`H)%]315-3
M24].6R=?<F5G:7-T<GEM=&EM92==6R=R96=I<W1R>2YP:'`G72`]/2`D<F5G
M7VUT:6UE*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D7U-%4U-)3TY;)U]R
M96=I<W1R>6-A8VAE)UT@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^)&ME>2`]("1V86P["B`@("`@("`@("`@('T*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`O*B!296%D('1H92!R96=I<W1R>2!C
M;VYF:6=U<F%T:6]N(&9I;&4N("HO"B`@("`@("`@("`@(')E<75I<F5?;VYC
M92!(3U)$15]"05-%("X@)R]C;VYF:6<O<F5G:7-T<GDN<&AP)SL*"B`@("`@
M("`@("`@("\J(%-T;W`@<WES=&5M(&EF($AO<F1E(&ES(&EN86-T:79E+B`J
M+PH@("`@("`@("`@("!I9B`H)'1H:7,M/F%P<&QI8V%T:6]N<ULG:&]R9&4G
M75LG<W1A='5S)UT@/3T@)VEN86-T:79E)RD@>PH@("`@("`@("`@("`@("`@
M2&]R9&4Z.F9A=&%L*%\H(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C
M=&EV871E9"XB*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@+RH@4V-A;B!F;W(@86QL($%027,@<')O=FED960@
M8GD@96%C:"!A<'`L(&%N9"!S970@;W1H97(*("`@("`@("`@("`@("H@8V]M
M;6]N(&1E9F%U;'1S(&QI:V4@=&5M<&QA=&5S(&%N9"!G<F%P:&EC<RX@*B\*
M("`@("`@("`@("`@)&%P<$QI<W0@/2!A<G)A>5]K97ES*"1T:&ES+3YA<'!L
M:6-A=&EO;G,I.PH@("`@("`@("`@("!F;W)E86-H("@D87!P3&ES="!A<R`D
M87!P3F%M92D@>PH@("`@("`@("`@("`@("`@)&%P<"`]("8D=&AI<RT^87!P
M;&EC871I;VYS6R1A<'!.86UE73L*("`@("`@("`@("`@("`@(&EF("@H)&%P
M<%LG<W1A='5S)UT@/3T@)VAE861I;F<G*2!\?`H@("`@("`@("`@("`@("`@
M("`@("@D87!P6R=S=&%T=7,G72`]/2`G:6YA8W1I=F4G*2!\?`H@("`@("`@
M("`@("`@("`@("`@("@D87!P6R=S=&%T=7,G72`]/2`G861M:6XG("8F("%!
M=71H.CII<T%D;6EN*"DI*2!["B`@("`@("`@("`@("`@("`@("`@8V]N=&EN
M=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&%P<%LG<')O=FED97,G72DI('L*("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-?87)R87DH)&%P<%LG<')O=FED97,G72DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)&%P<%LG<')O=FED97,G72!A<R`D:6YT
M97)F86-E*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7VEN=&5R9F%C97-;)&EN=&5R9F%C95T@/2`D87!P3F%M93L*("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YT97)F86-E<ULD
M87!P6R=P<F]V:61E<R==72`]("1A<'!.86UE.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@A
M:7-S970H)&%P<%LG=&5M<&QA=&5S)UTI("8F(&ES<V5T*"1A<'!;)V9I;&5R
M;V]T)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)&%P<%LG=&5M<&QA=&5S
M)UT@/2`D87!P6R=F:6QE<F]O="==("X@)R]T96UP;&%T97,G.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D87!P6R=J
M<W5R:2==*2`F)B!I<W-E="@D87!P6R=W96)R;V]T)UTI*2!["B`@("`@("`@
M("`@("`@("`@("`@)&%P<%LG:G-U<FDG72`]("1A<'!;)W=E8G)O;W0G72`N
M("<O:G,G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D87!P6R=J<V9S)UTI("8F(&ES<V5T*"1A<'!;)V9I;&5R;V]T
M)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)&%P<%LG:G-F<R==(#T@)&%P
M<%LG9FEL97)O;W0G72`N("<O:G,G.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D87!P6R=T:&5M97-U<FDG72D@)B8@
M:7-S970H)&%P<%LG=V5B<F]O="==*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1A<'!;)W1H96UE<W5R:2==(#T@)&%P<%LG=V5B<F]O="==("X@)R]T:&5M
M97,G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"%I
M<W-E="@D87!P6R=T:&5M97-F<R==*2`F)B!I<W-E="@D87!P6R=F:6QE<F]O
M="==*2D@>PH@("`@("`@("`@("`@("`@("`@("1A<'!;)W1H96UE<V9S)UT@
M/2`D87!P6R=F:6QE<F]O="==("X@)R]T:&5M97,G.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!#;&5A<B!O=70@
M=&AE($%022`F(%1Y<&4@8V%C:&5S+"!I9B!T:&5Y(&5X:7-T<RX@*B\*("`@
M("`@("`@("`@)'1H:7,M/E]A<&E#86-H92`]("1T:&ES+3Y?='EP94-A8VAE
M(#T@87)R87DH*3L*"B`@("`@("`@("`@("1T:&ES+3Y?8V%C:&5687)S*&%R
M<F%Y*"=A<'!L:6-A=&EO;G,G+"`G7VEN=&5R9F%C97,G+"`G7V%P:4-A8VAE
M)RP@)U]T>7!E0V%C:&4G*2P@87)R87DH)W)E9VES=')Y+G!H<"<@/3X@)')E
M9U]M=&EM92DI.PH@("`@("`@('T*"B`@("`@("`@+RH@0W)E871E('1H92!G
M;&]B86P@4&5R;7,@;V)J96-T+B`J+PH@("`@("`@("1'3$]"04Q36R=P97)M
M<R==(#T@)E!E<FUS.CIS:6YG;&5T;VXH*3L*"B`@("`@("`@+RH@071T86-H
M(&IA=F%S8W)I<'0@;F]T:69I8V%T:6]N(&QI<W1E;F5R+B`J+PH@("`@("`@
M("1N;W1I9FEC871I;VX@/2`F3F]T:69I8V%T:6]N.CIS:6YG;&5T;VXH*3L*
M("`@("`@("`D;F]T:69I8V%T:6]N+3YA='1A8V@H)VIA=F%S8W)I<'0G*3L*
M"B`@("`@("`@+RH@4F5G:7-T97(@86-C97-S(&ME>2!L;V=G97(@9F]R('1R
M86YS;&%T;W)S+B`J+PH@("`@("`@(&EF("A`)$=,3T)!3%-;)V-O;F8G75LG
M;&]G7V%C8V5S<VME>7,G72D@>PH@("`@("`@("`@("!R96=I<W1E<E]S:'5T
M9&]W;E]F=6YC=&EO;BAC<F5A=&5?9G5N8W1I;VXH)R<L("=(;W)D93HZ9V5T
M06-C97-S2V5Y*&YU;&PL(&YU;&PL('1R=64I.R<I*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@82!L:7-T(&]F('9A<FEA8FQE(&YA
M;65S(&%N9"!M;V1I9FEC871I;VX@=&EM97,@=&\@8F4@8V%C:&5D+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D=F%R<R`@("!!(&QI<W0@;V8@=F%R:6%B;&4@;F%M97,@=&\@
M8F4@8V%C:&5D+@H@("`@("H@0'!A<F%M(&%R<F%Y("1M=&EM97,@($$@;&ES
M="!O9B!F:6QE(&UO9&EF:6-A:6]N('1I;65S('1O(&)E(&-A8VAE9"X*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V-A8VAE5F%R<R@D=F%R<R`](&%R<F%Y*"DL
M("1M=&EM97,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@('-T871I8R`D<F5G
M8V%C:&5S:'5T9&]W;B`](&9A;'-E.PH*("`@("`@("!I9B`H)'1H:7,M/E]U
M<V5C86-H92D@>PH@("`@("`@("`@("`D=&AI<RT^7W5P9&%T96-A8VAE(#T@
M87)R87E?;65R9V4H)'1H:7,M/E]U<&1A=&5C86-H92P@)'9A<G,I.PH@("`@
M("`@("`@("`D=&AI<RT^7W5P9&%T96UT:6UE(#T@87)R87E?;65R9V4H)'1H
M:7,M/E]U<&1A=&5M=&EM92P@)&UT:6UE<RD["B`@("`@("`@("`@(&EF("@A
M)')E9V-A8VAE<VAU=&1O=VXI('L*("`@("`@("`@("`@("`@(')E9VES=&5R
M7W-H=71D;W=N7V9U;F-T:6]N*&%R<F%Y*"8D=&AI<RP@)U]S:'5T9&]W;F-A
M8VAE)RDI.PH@("`@("`@("`@("`@("`@)')E9V-A8VAE<VAU=&1O=VX@/2!T
M<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@4W1O<F5S(&-A8VAE86)L92!M96UB97(@=F%R:6%B;&5S(&EN('1H
M92!S97-S:6]N(&%T('-H=71D;W=N+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?<VAU=&1O=VYC86-H92@I
M"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1?4T534TE/3BD@)B8@075T:#HZ
M9V5T075T:"@I("8F("$D=&AI<RT^7VYO8V%C:&4I('L*("`@("`@("`@("`@
M:68@*"%I<W-E="@D7U-%4U-)3TY;)U]R96=I<W1R>6-A8VAE)UTI*2!["B`@
M("`@("`@("`@("`@("`D7U-%4U-)3TY;)U]R96=I<W1R>6-A8VAE)UT@/2!A
M<G)A>2@I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!F;W)E86-H("AA
M<G)A>5]U;FEQ=64H)'1H:7,M/E]U<&1A=&5C86-H92D@87,@)'9A;"D@>PH@
M("`@("`@("`@("`@("`@)%]315-324].6R=?<F5G:7-T<GEC86-H92==6R1V
M86Q=(#T@)'1H:7,M/B1V86P["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M(&EF("@A:7-S970H)%]315-324].6R=?<F5G:7-T<GEM=&EM92==*2D@>PH@
M("`@("`@("`@("`@("`@)%]315-324].6R=?<F5G:7-T<GEM=&EM92==(#T@
M87)R87DH*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@9F]R96%C:"`H
M87)R87E?=6YI<75E*"1T:&ES+3Y?=7!D871E;71I;64I(&%S("1K97D@/3X@
M)'9A;"D@>PH@("`@("`@("`@("`@("`@)%]315-324].6R=?<F5G:7-T<GEM
M=&EM92==6R1K97E=(#T@)'9A;#L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($-L96%R('1H92!R96=I<W1R>2!C86-H
M92X*("`@("`J"B`@("`@*B!`<VEN8V4@2&]R9&4@,RXQ"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-L96%R0V%C:&4H*0H@("`@>PH@("`@("`@('5N<V5T*"1?
M4T534TE/3ELG7W)E9VES=')Y8V%C:&4G72D["B`@("`@("`@)'1H:7,M/E]N
M;V-A8VAE(#T@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($9I;&QS('1H
M92!R96=I<W1R>2=S($%022!C86-H92!W:71H('1H92!A=F%I;&%B;&4@<V5R
M=FEC97,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]F:6QL05!)0V%C:&4H*0H@("`@>PH@("`@("`@(&EF
M("@A96UP='DH)'1H:7,M/E]A<&E#86-H92DI('L*("`@("`@("`@("`@<F5T
M=7)N.PH@("`@("`@('T*"B`@("`@("`@)'-T871U<R`](&%R<F%Y*"=A8W1I
M=F4G+"`G;F]T;V]L8F%R)RP@)VAI9&1E;B<I.PH@("`@("`@(&EF("A!=71H
M.CII<T%D;6EN*"DI('L*("`@("`@("`@("`@)'-T871U<UM=(#T@)V%D;6EN
M)SL*("`@("`@("!]"B`@("`@("`@)&%P<',@/2`D=&AI<RT^;&ES=$%P<',H
M)'-T871U<RD["B`@("`@("`@9F]R96%C:"`H)&%P<',@87,@)&%P<"D@>PH@
M("`@("`@("`@("`D7W-E<G9I8V5S(#T@)%]T>7!E<R`](&YU;&P["B`@("`@
M("`@("`@("1A<&D@/2`D=&AI<RT^9V5T*"=F:6QE<F]O="<L("1A<'`I("X@
M)R]L:6(O87!I+G!H<"<["B`@("`@("`@("`@(&EF("AI<U]R96%D86)L92@D
M87!I*2D@>PH@("`@("`@("`@("`@("`@:6YC;'5D95]O;F-E("1A<&D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%I<W-E="@D7W-E<G9I8V5S
M*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]A<&E#86-H95LD87!P72`]
M(&%R<F%Y*"D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7V%P:4-A8VAE6R1A<'!=(#T@)%]S97)V:6-E<SL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!I9B`H:7-S970H)%]T>7!E<RDI('L*("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1?='EP97,@87,@)'1Y<&4@/3X@)'!A
M<F%M<RD@>PH@("`@("`@("`@("`@("`@("`@("\J(%!R969I>"!N;VXM2&]R
M9&4@='EP97,@=VET:"!T:&4@87!P;&EC871I;VX*("`@("`@("`@("`@("`@
M("`@("`@*B!N86UE+B`J+PH@("`@("`@("`@("`@("`@("`@("1P<F5F:7@@
M/2`D87!P(#T]("=H;W)D92<@/R`G)R`Z("(D>V%P<'U?(CL*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W1Y<&5#86-H95LD<')E9FEX("X@)'1Y<&5=
M(#T@)'!A<F%M<SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]C86-H959A<G,H87)R87DH)U]A
M<&E#86-H92<L("=?='EP94-A8VAE)RDI.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N(&$@;&ES="!O9B!T:&4@:6YS=&%L;&5D(&%N9"!R96=I<W1E
M<F5D(&%P<&QI8V%T:6]N<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M("`D9FEL=&5R("`@("`@06X@87)R87D@;V8@=&AE('-T871U<V5S('1H870@
M<VAO=6QD(&)E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N960N($1E9F%U;'1S('1O(&YO;BUH:61D96XN"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D87-S;V,@("`@("`@07-S;V-I871I=F4@87)R87D@=VET
M:"!A<'`@;F%M97,@87,@:V5Y<RX*("`@("`J($!P87)A;2!I;G1E9V5R("1P
M97)M:7-S:6]N("!4:&4@<&5R;6ES<VEO;B!L979E;"!T;R!C:&5C:R!F;W(@
M:6X@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;&ES
M="X@1&5F875L=',@=&\@4$5235-?4TA/5RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("!,:7-T(&]F(&%P<',@<F5G:7-T97)E9"!W:71H($AO<F1E
M+B!)9B!N;PH@("`@("H@("`@("`@("`@("`@("`@87!P;&EC871I;VYS(&%R
M92!D969I;F5D(')E='5R;G,@86X@96UP='D@87)R87DN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&QI<W1!<'!S*"1F:6QT97(@/2!N=6QL+"`D87-S;V,@/2!F
M86QS92P@)'!E<FUI<W-I;VX@/2!015)-4U]32$]7*0H@("`@>PH@("`@("`@
M("1A<'!S(#T@87)R87DH*3L*("`@("`@("!I9B`H:7-?;G5L;"@D9FEL=&5R
M*2D@>PH@("`@("`@("`@("`D9FEL=&5R(#T@87)R87DH)VYO=&]O;&)A<B<L
M("=A8W1I=F4G*3L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1T:&ES
M+3YA<'!L:6-A=&EO;G,@87,@)&%P<"`]/B`D<&%R86US*2!["B`@("`@("`@
M("`@(&EF("AI;E]A<G)A>2@D<&%R86US6R=S=&%T=7,G72P@)&9I;'1E<BD@
M)B8*("`@("`@("`@("`@("`@("AD969I;F5D*"=!551(7TA!3D1,15(G*2!\
M?"`D=&AI<RT^:&%S4&5R;6ES<VEO;B@D87!P+"`D<&5R;6ES<VEO;BDI*2![
M"B`@("`@("`@("`@("`@("`D87-S;V,@/R`D87!P<ULD87!P72`]("1A<'`@
M.B`D87!P<UM=(#T@)&%P<#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1A<'!S.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!A;&P@879A:6QA8FQE(')E9VES=')Y($%027,N"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@5&AE($%022!L:7-T+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!L:7-T05!)<R@I"B`@("!["B`@("`@("`@<W1A=&EC("1A<&ES
M(#T@87)R87DH*3L*("`@("`@("!I9B`H)&%P:7,I('L*("`@("`@("`@("`@
M<F5T=7)N("1A<&ES.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H87)R
M87E?:V5Y<R@D=&AI<RT^7VEN=&5R9F%C97,I(&%S("1I;G1E<F9A8V4I('L*
M("`@("`@("`@("`@0&QI<W0H)&%P:2P@*2`](&5X<&QO9&4H)R\G+"`D:6YT
M97)F86-E*3L*("`@("`@("`@("`@)&%P:7-;72`]("1A<&D["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@87)R87E?=6YI<75E*"1A<&ES*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@86QL(&]F('1H92!A=F%I;&%B;&4@
M<F5G:7-T<GD@;65T:&]D<RP@;W(@86QT97)N871E;'D*("`@("`J(&]N;'D@
M=&AO<V4@9F]R(&$@<W!E8VEF:65D($%022X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1A<&D@($1E9FEN97,@=&AE($%022!F;W(@=VAI8V@@=&AE
M(&UE=&AO9',@<VAA;&P@8F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N960N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&UE
M=&AO9"!L:7-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T365T:&]D<R@D
M87!I(#T@;G5L;"D*("`@('L*("`@("`@("`D;65T:&]D<R`](&%R<F%Y*"D[
M"@H@("`@("`@("1T:&ES+3Y?9FEL;$%024-A8VAE*"D["@H@("`@("`@(&9O
M<F5A8V@@*&%R<F%Y7VME>7,H)'1H:7,M/F%P<&QI8V%T:6]N<RD@87,@)&%P
M<"D@>PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/F%P<&QI8V%T:6]N
M<ULD87!P75LG<')O=FED97,G72DI('L*("`@("`@("`@("`@("`@("1P<F]V
M:61E<R`]("1T:&ES+3YA<'!L:6-A=&EO;G-;)&%P<%U;)W!R;W9I9&5S)UT[
M"B`@("`@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1P<F]V:61E<RDI('L*
M("`@("`@("`@("`@("`@("`@("`D<')O=FED97,@/2!A<G)A>2@D<')O=FED
M97,I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)'!R;W9I9&5S(#T@87)R87DH*3L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@9F]R96%C:"`H)'!R;W9I9&5S(&%S("1M971H
M;V0I('L*("`@("`@("`@("`@("`@(&EF("AS=')P;W,H)&UE=&AO9"P@)R\G
M*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-?;G5L
M;"@D87!I*2!\?`H@("`@("`@("`@("`@("`@("`@("`@("`H<W5B<W1R*"1M
M971H;V0L(#`L('-T<FQE;B@D87!I*2D@/3T@)&%P:2DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&UE=&AO9'-;72`]("1M971H;V0["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES7VYU
M;&PH)&%P:2D@?'P@*"1M971H;V0@/3T@)&%P:2DI('L*("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]A<&E#86-H95LD87!P72DI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H87)R87E?:V5Y<R@D
M=&AI<RT^7V%P:4-A8VAE6R1A<'!=*2!A<R`D<V5R=FEC92D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&UE=&AO9'-;72`]("1M971H;V0@+B`G
M+R<@+B`D<V5R=FEC93L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&%R<F%Y7W5N:7%U92@D
M;65T:&]D<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%L;"!O
M9B!T:&4@879A:6QA8FQE(')E9VES=')Y(&1A=&$@='EP97,N"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&1A=&$@='EP92!L:7-T+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!L:7-T5'EP97,H*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?9FEL;$%024-A8VAE*"D["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M='EP94-A8VAE.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&UE
M=&AO9"=S('-I9VYA='5R92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1M971H;V0@(%1H92!F=6QL(&YA;64@;V8@=&AE(&UE=&AO9"!T;R!C:&5C
M:R!F;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!T=V\@9&EM
M96YS:6]N86P@87)R87DN(%1H92!F:7)S="!E;&5M96YT(&-O;G1A:6YS(&%N
M"B`@("`@*B`@("`@("`@("`@("`@("!A<G)A>2!W:71H('1H92!P87)A;65T
M97(@;F%M97,L('1H92!S96-O;F0@;VYE('1H92!R971U<FX*("`@("`J("`@
M("`@("`@("`@("`@('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-I
M9VYA='5R92@D;65T:&]D*0H@("`@>PH@("`@("`@(&EF("@A*"1A<'`@/2`D
M=&AI<RT^:&%S365T:&]D*"1M971H;V0I*2D@>PH@("`@("`@("`@("!R971U
M<FX["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V9I;&Q!4$E#86-H92@I
M.PH*("`@("`@("!`;&ES="@L("1F=6YC=&EO;BD@/2!E>'!L;V1E*"<O)RP@
M)&UE=&AO9"D["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?87!I0V%C:&5;
M)&%P<%U;)&9U;F-T:6]N75LG='EP92==*2`F)@H@("`@("`@("`@("!I<W-E
M="@D=&AI<RT^7V%P:4-A8VAE6R1A<'!=6R1F=6YC=&EO;EU;)V%R9W,G72DI
M('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"1T:&ES+3Y?87!I0V%C:&5;
M)&%P<%U;)&9U;F-T:6]N75LG87)G<R==+"`D=&AI<RT^7V%P:4-A8VAE6R1A
M<'!=6R1F=6YC=&EO;EU;)W1Y<&4G72D["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@1&5T97)M:6YE(&EF(&%N(&EN=&5R9F%C92!I<R!I;7!L
M96UE;G1E9"!B>2!A;B!A8W1I=F4@87!P;&EC871I;VXN"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D:6YT97)F86-E("!4:&4@:6YT97)F86-E('1O
M(&-H96-K(&9O<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@
M87!P;&EC871I;VX@:6UP;&5M96YT:6YG("1I;G1E<F9A8V4@:68@=V4@:&%V
M92!I="P*("`@("`J("`@("`@("`@("`@("`@(&9A;'-E(&EF('1H92!I;G1E
M<F9A8V4@:7,@;F]T(&EM<&QE;65N=&5D+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!H87-);G1E<F9A8V4H)&EN=&5R9F%C92D*("`@('L*("`@("`@("!R971U
M<FX@(65M<'1Y*"1T:&ES+3Y?:6YT97)F86-E<ULD:6YT97)F86-E72D@/PH@
M("`@("`@("`@("`D=&AI<RT^7VEN=&5R9F%C97-;)&EN=&5R9F%C95T@.@H@
M("`@("`@("`@("!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J($1E=&5R
M;6EN92!I9B!A(&UE=&AO9"!H87,@8F5E;B!R96=I<W1E<F5D('=I=&@@=&AE
M(')E9VES=')Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&UE=&AO
M9"`@5&AE(&9U;&P@;F%M92!O9B!T:&4@;65T:&]D('1O(&-H96-K(&9O<BX*
M("`@("`J($!P87)A;2!S=')I;F<@)&%P<"`@("`@3VYL>2!C:&5C:R!T:&ES
M(&%P<&QI8V%T:6]N+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H
M92!A<'!L:6-A=&EO;B!I;7!L96UE;G1I;F<@)&UE=&AO9"!I9B!W92!H879E
M(&ET+`H@("`@("H@("`@("`@("`@("`@("`@9F%L<V4@:68@=&AE(&UE=&AO
M9"!D;V5S;B=T(&5X:7-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!H87--971H
M;V0H)&UE=&AO9"P@)&%P<"`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES
M7VYU;&PH)&%P<"DI('L*("`@("`@("`@("`@0&QI<W0H)&EN=&5R9F%C92P@
M)&-A;&PI(#T@97AP;&]D92@G+R<L("1M971H;V0I.PH@("`@("`@("`@("!I
M9B`H(65M<'1Y*"1T:&ES+3Y?:6YT97)F86-E<ULD;65T:&]D72DI('L*("`@
M("`@("`@("`@("`@("1A<'`@/2`D=&AI<RT^7VEN=&5R9F%C97-;)&UE=&AO
M9%T["B`@("`@("`@("`@('T@96QS96EF("@A96UP='DH)'1H:7,M/E]I;G1E
M<F9A8V5S6R1I;G1E<F9A8V5=*2D@>PH@("`@("`@("`@("`@("`@)&%P<"`]
M("1T:&ES+3Y?:6YT97)F86-E<ULD:6YT97)F86-E73L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1C86QL(#T@
M)&UE=&AO9#L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?9FEL;$%024-A
M8VAE*"D["@H@("`@("`@(')E='5R;B`A96UP='DH)'1H:7,M/E]A<&E#86-H
M95LD87!P75LD8V%L;%TI(#\@)&%P<"`Z(&9A;'-E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N('1H92!H;V]K(&-O<G)E<W!O;F1I;F<@=&\@=&AE
M(&1E9F%U;'0@<&%C:V%G92!T:&%T"B`@("`@*B!P<F]V:61E<R!T:&4@9G5N
M8W1I;VYA;&ET>2!R97%U97-T960@8GD@=&AE("1M971H;V0*("`@("`J('!A
M<F%M971E<BX@)&UE=&AO9"!I<R!A('-T<FEN9R!C;VYS:7-T:6YG(&]F"B`@
M("`@*B`B<&%C:V%G971Y<&4O;65T:&]D;F%M92(N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;65T:&]D("!4:&4@;65T:&]D('1O(&-A;&PN"B`@
M("`@*B!`<&%R86T@87)R87D@)&%R9W,@("`@($%R9W5M96YT<R!T;R!T:&4@
M;65T:&]D+@H@("`@("H*("`@("`J($!R971U<FX@(%1/1$\*("`@("`J("`@
M("`@("`@(%)E='5R;G,@4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@("`J+PH@
M("`@9G5N8W1I;VX@8V%L;"@D;65T:&]D+"`D87)G<R`](&%R<F%Y*"DI"B`@
M("!["B`@("`@("`@0&QI<W0H)&EN=&5R9F%C92P@)&-A;&PI(#T@97AP;&]D
M92@G+R<L("1M971H;V0I.PH*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?
M:6YT97)F86-E<ULD;65T:&]D72DI('L*("`@("`@("`@("`@)&%P<"`]("1T
M:&ES+3Y?:6YT97)F86-E<ULD;65T:&]D73L*("`@("`@("!](&5L<V5I9B`H
M(65M<'1Y*"1T:&ES+3Y?:6YT97)F86-E<ULD:6YT97)F86-E72DI('L*("`@
M("`@("`@("`@)&%P<"`]("1T:&ES+3Y?:6YT97)F86-E<ULD:6YT97)F86-E
M73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@G5&AE(&UE=&AO9"`B)R`N("1M971H;V0@+B`G(B!I<R!N
M;W0@9&5F:6YE9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN)RD["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)'1H:7,M/F-A;&Q">5!A8VMA9V4H)&%P<"P@
M)&-A;&PL("1A<F=S*3L*("`@('T*"B`@("`O*BH*("`@("`J($]U='!U="!T
M:&4@:&]O:R!C;W)R97-P;VYD:6YG('1O('1H92!S<&5C:69I8R!P86-K86=E
M(&YA;65D+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%P<"`@(%1H
M92!A<'!L:6-A=&EO;B!B96EN9R!C86QL960N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1C86QL("!4:&4@;65T:&]D('1O(&-A;&PN"B`@("`@*B!`<&%R86T@
M87)R87D@)&%R9W,@("!!<F=U;65N=',@=&\@=&AE(&UE=&AO9"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N("!43T1/"B`@("`@*B`@("`@("`@("!2971U<FYS
M(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-A
M;&Q">5!A8VMA9V4H)&%P<"P@)&-A;&PL("1A<F=S(#T@87)R87DH*2D*("`@
M('L*("`@("`@("`O*B!.;W1E.B!C86QL:6YG(&AA<TUE=&AO9"@I(&UA:V5S
M('-U<F4@=&AA="!W92=V92!C86-H960*("`@("`@("`@*B`D87!P)W,@<V5R
M=FEC97,@86YD(&EN8VQU9&5D('1H92!!4$D@9FEL92P@<V\@=V4@9&]N)W0@
M=')Y"B`@("`@("`@("H@=&\@9&\@:70@86=A:6X@97AP;&EC:71L>2!I;B!T
M:&ES(&UE=&AO9"X@*B\*("`@("`@("!I9B`H(21T:&ES+3YH87--971H;V0H
M)&-A;&PL("1A<'`I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*'-P<FEN=&8H)U1H92!M971H;V0@(B5S(B!I<R!N;W0@9&5F:6YE
M9"!I;B!T:&4@05!)(&9O<B`E<RXG+"`D8V%L;"P@)&%P<"DI.PH@("`@("`@
M('T*"B`@("`@("`@+RH@3&]A9"!T:&4@05!)(&YO=RX@*B\*("`@("`@("!I
M9B`H(65M<'1Y*"1?4T534TE/3ELG7W)E9VES=')Y8V%C:&4G75LG7V%P:4-A
M8VAE)UTI*2!["B`@("`@("`@("`@("1A<&D@/2`D=&AI<RT^9V5T*"=F:6QE
M<F]O="<L("1A<'`I("X@)R]L:6(O87!I+G!H<"<["B`@("`@("`@("`@(&EF
M("AI<U]R96%D86)L92@D87!I*2D@>PH@("`@("`@("`@("`@("`@:6YC;'5D
M95]O;F-E("1A<&D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("\J($UA:V4@<W5R92!T:&%T('1H92!F=6YC=&EO;B!A8W1U86QL>2!E>&ES
M=',N("HO"B`@("`@("`@)&9U;F-T:6]N(#T@)U\G("X@)&%P<"`N("=?)R`N
M("1C86QL.PH@("`@("`@(&EF("@A9G5N8W1I;VY?97AI<W1S*"1F=6YC=&EO
M;BDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U1H
M92!F=6YC=&EO;B!I;7!L96UE;G1I;F<@)R`N("1C86QL("X@)R`H)R`N("1F
M=6YC=&EO;B`N("<I(&ES(&YO="!D969I;F5D(&EN("<@+B`D87!P("X@)UPG
M<R!!4$DN)RD["B`@("`@("`@?0H*("`@("`@("`D8VAE8VM097)M<R`](&ES
M<V5T*"1T:&ES+3Y?87!I0V%C:&5;)&%P<%U;)&-A;&Q=6R=C:&5C:W!E<FUS
M)UTI(#\*("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?87!I0V%C:&5;
M)&%P<%U;)&-A;&Q=6R=C:&5C:W!E<FUS)UT@.B!T<G5E.PH*("`@("`@("`O
M*B!3=VET8V@@87!P;&EC871I;VX@8V]N=&5X=',@;F]W+"!I9B!N96-E<W-A
M<GDL(&)E9F]R90H@("`@("`@("`J(&EN8VQU9&EN9R!A;GD@9FEL97,@=VAI
M8V@@;6EG:'0@9&\@:70@9F]R('5S+B!2971U<FX@86X*("`@("`@("`@*B!E
M<G)O<B!I;6UE9&EA=&5L>2!I9B!P=7-H07!P*"D@9F%I;',N("HO"B`@("`@
M("`@)'!U<VAE9"`]("1T:&ES+3YP=7-H07!P*"1A<'`L("1C:&5C:U!E<FUS
M*3L*("`@("`@("!I9B`H:7-?82@D<'5S:&5D+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D<'5S:&5D.PH@("`@("`@('T*"B`@("`@
M("`@)')E<R`](&-A;&Q?=7-E<E]F=6YC7V%R<F%Y*"1F=6YC=&EO;BP@)&%R
M9W,I.PH*("`@("`@("`O*B!)9B!W92!C:&%N9V5D(&%P<&QI8V%T:6]N(&-O
M;G1E>'0@:6X@=&AE(&-O=7)S92!O9B!T:&ES"B`@("`@("`@("H@8V%L;"P@
M=6YD;R!T:&%T(&-H86YG92!N;W<N("HO"B`@("`@("`@:68@*"1P=7-H960@
M/3T]('1R=64I('L*("`@("`@("`@("`@)'1H:7,M/G!O<$%P<"@I.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1R97,["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FX@=&AE(&AO;VL@8V]R<F5S<&]N9&EN9R!T;R!T:&4@9&5F
M875L="!P86-K86=E('1H870*("`@("`J('!R;W9I9&5S('1H92!F=6YC=&EO
M;F%L:71Y(')E<75E<W1E9"!B>2!T:&4@)&UE=&AO9`H@("`@("H@<&%R86UE
M=&5R+B`D;65T:&]D(&ES(&$@<W1R:6YG(&-O;G-I<W1I;F<@;V8*("`@("`J
M(")P86-K86=E='EP92]M971H;V1N86UE(BX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1M971H;V0@(%1H92!M971H;V0@=&\@;&EN:R!T;RX*("`@
M("`J($!P87)A;2!A<G)A>2`D87)G<R`@("`@07)G=6UE;G1S('1O('1H92!M
M971H;V0N"B`@("`@*B!`<&%R86T@;6EX960@)&5X=')A("`@($5X=')A+"!N
M;VXM<W1A;F1A<F0@87)G=6UE;G1S('1O('1H92!M971H;V0N"B`@("`@*@H@
M("`@("H@0')E='5R;B`@5$]$3PH@("`@("H@("`@("`@("`@4F5T=7)N<R!0
M14%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:6YK
M*"1M971H;V0L("1A<F=S(#T@87)R87DH*2P@)&5X=')A(#T@)R<I"B`@("![
M"B`@("`@("`@0&QI<W0H)&EN=&5R9F%C92P@)&-A;&PI(#T@97AP;&]D92@G
M+R<L("1M971H;V0I.PH*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?:6YT
M97)F86-E<ULD;65T:&]D72DI('L*("`@("`@("`@("`@)&%P<"`]("1T:&ES
M+3Y?:6YT97)F86-E<ULD;65T:&]D73L*("`@("`@("!](&5L<V5I9B`H(65M
M<'1Y*"1T:&ES+3Y?:6YT97)F86-E<ULD:6YT97)F86-E72DI('L*("`@("`@
M("`@("`@)&%P<"`]("1T:&ES+3Y?:6YT97)F86-E<ULD:6YT97)F86-E73L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@G5&AE(&UE=&AO9"`B)R`N("1M971H;V0@+B`G(B!I<R!N;W0@
M9&5F:6YE9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN)RD["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)'1H:7,M/FQI;FM">5!A8VMA9V4H)&%P<"P@)&-A
M;&PL("1A<F=S+"`D97AT<F$I.PH@("`@?0H*("`@("\J*@H@("`@("H@3W5T
M<'5T('1H92!H;V]K(&-O<G)E<W!O;F1I;F<@=&\@=&AE('-P96-I9FEC('!A
M8VMA9V4@;F%M960N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D87!P
M("`@5&AE(&%P<&QI8V%T:6]N(&)E:6YG(&-A;&QE9"X*("`@("`J($!P87)A
M;2!S=')I;F<@)&-A;&P@(%1H92!M971H;V0@=&\@;&EN:R!T;RX*("`@("`J
M($!P87)A;2!A<G)A>2`D87)G<R`@($%R9W5M96YT<R!T;R!T:&4@;65T:&]D
M+@H@("`@("H@0'!A<F%M(&UI>&5D("1E>'1R82`@17AT<F$L(&YO;BUS=&%N
M9&%R9"!A<F=U;65N=',@=&\@=&AE(&UE=&AO9"X*("`@("`J"B`@("`@*B!`
M<F5T=7)N("!43T1/"B`@("`@*B`@("`@("`@("!2971U<FYS(%!%05)?17)R
M;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI;FM">5!A8VMA
M9V4H)&%P<"P@)&-A;&PL("1A<F=S(#T@87)R87DH*2P@)&5X=')A(#T@)R<I
M"B`@("!["B`@("`@("`@+RH@3F]T93H@8V%L;&EN9R!H87--971H;V0@;6%K
M97,@<W5R92!T:&%T('=E)W9E(&-A8VAE9"`D87!P)W,*("`@("`@("`@*B!S
M97)V:6-E<R!A;F0@:6YC;'5D960@=&AE($%022!F:6QE+"!S;R!W92!D;VXG
M="!T<GD@=&\@9&\*("`@("`@("`@*B!I="!I="!A9V%I;B!E>'!L:6-I=&QY
M(&EN('1H:7,@;65T:&]D+B`J+PH@("`@("`@(&EF("@A)'1H:7,M/FAA<TUE
M=&AO9"@D8V%L;"P@)&%P<"DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H)U1H92!M971H;V0@(B<@+B`D8V%L;"`N("<B(&ES(&YO
M="!D969I;F5D(&EN("<@+B`D87!P("X@)UPG<R!!4$DN)RD["B`@("`@("`@
M?0H*("`@("`@("`O*B!-86ME('-U<F4@=&AE(&QI;FL@:7,@9&5F:6YE9"X@
M*B\*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]A<&E#86-H95LD87!P75LD
M8V%L;%U;)VQI;FLG72DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H)U1H92!L:6YK("<@+B`D8V%L;"`N("<@:7,@;F]T(&1E9FEN
M960@:6X@)R`N("1A<'`@+B`G7"=S($%022XG*3L*("`@("`@("!]"@H@("`@
M("`@("\J($EN:71I86P@;&EN:R!V86QU92X@*B\*("`@("`@("`D;&EN:R`]
M("1T:&ES+3Y?87!I0V%C:&5;)&%P<%U;)&-A;&Q=6R=L:6YK)UT["@H@("`@
M("`@("\J($9I;&P@:6X@:'1M;"UE;F-O9&5D(&%R9W5M96YT<RX@*B\*("`@
M("`@("!F;W)E86-H("@D87)G<R!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@
M("`@("`@)&QI;FL@/2!S=')?<F5P;&%C92@G)2<@+B`D:V5Y("X@)R4G+"!H
M=&UL96YT:71I97,H)'9A;"DL("1L:6YK*3L*("`@("`@("!]"B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3YA<'!L:6-A=&EO;G-;)&%P<%U;)W=E8G)O;W0G
M72DI('L*("`@("`@("`@("`@)&QI;FL@/2!S=')?<F5P;&%C92@G)6%P<&QI
M8V%T:6]N)2<L("1T:&ES+3YG970H)W=E8G)O;W0G+"`D87!P*2P@)&QI;FLI
M.PH@("`@("`@('T*"B`@("`@("`@+RH@4F5P;&%C92!H=&UL96YC;V1E9"!A
M<F=U;65N=',@=&AA="!H879E;B=T(&)E96X@<W!E8VEF:65D('=I=&@*("`@
M("`@("`@("!A;B!E;7!T>2!S=')I;F<@*'1H:7,@:7,@=VAE<F4@=&AE(&1E
M9F%U;'0@=V]U;&0@8F4@<W5B<W1I='5T960*("`@("`@("`@("!I;B!A('-T
M<FEC=&5R(')E9VES=')Y(&EM<&QE;65N=&%T:6]N*2X@*B\*("`@("`@("`D
M;&EN:R`]('!R96=?<F5P;&%C92@G?"4N*R5\52<L("<G+"`D;&EN:RD["@H@
M("`@("`@("\J($9I;&P@:6X@=7)L96YC;V1E9"!A<F=U;65N=',N("HO"B`@
M("`@("`@9F]R96%C:"`H)&%R9W,@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@
M("`@("`@("1L:6YK(#T@<W1R7W)E<&QA8V4H)WPG("X@4W1R:6YG.CIL;W=E
M<B@D:V5Y*2`N("=\)RP@=7)L96YC;V1E*"1V86PI+"`D;&EN:RD["B`@("`@
M("`@?0H*("`@("`@("`O*B!!<'!E;F0@86YY(&5X=')A+"!N;VXM<W1A;F1A
M<F0@87)G=6UE;G1S+B`J+PH@("`@("`@(&EF("AI<U]A<G)A>2@D97AT<F$I
M*2!["B`@("`@("`@("`@("1E>'1R85]A<F=S(#T@)R<["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1E>'1R82!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@
M("`@("`@("1E>'1R85]A<F=S("XM("<F)R`N('5R;&5N8V]D92@D:V5Y*2`N
M("<])R`N('5R;&5N8V]D92@D=F%L*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1E>'1R85]A<F=S(#T@)&5X=')A.PH@
M("`@("`@('T*("`@("`@("`D;&EN:R`]('-T<E]R97!L86-E*"=\97AT<F%\
M)RP@)&5X=')A7V%R9W,L("1L:6YK*3L*"B`@("`@("`@+RH@4F5P;&%C92!H
M=&UL+65N8V]D960@87)G=6UE;G1S('1H870@:&%V96XG="!B965N('-P96-I
M9FEE9"!W:71H"B`@("`@("`@("`@86X@96UP='D@<W1R:6YG("AT:&ES(&ES
M('=H97)E('1H92!D969A=6QT('=O=6QD(&)E('-U8G-T:71U=&5D"B`@("`@
M("`@("`@:6X@82!S=')I8W1E<B!R96=I<W1R>2!I;7!L96UE;G1A=&EO;BDN
M("HO"B`@("`@("`@)&QI;FL@/2!P<F5G7W)E<&QA8V4H)WQ<?"XK7'Q\52<L
M("<G+"`D;&EN:RD["@H@("`@("`@(')E='5R;B`D;&EN:SL*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E<&QA8V4@86YY("5A<'!L:6-A=&EO;B4@<W1R:6YG
M<R!W:71H('1H92!F:6QE<WES=&5M('!A=&@@=&\@=&AE"B`@("`@*B!A<'!L
M:6-A=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4
M:&4@87!P;&EC871I;VX@<W1R:6YG+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M87!P("`@5&AE(&%P<&QI8V%T:6]N(&)E:6YG(&-A;&QE9"X*("`@("`J"B`@
M("`@*B!`<F5T=7)N("!43T1/"B`@("`@*B`@("`@("`@("!2971U<FYS(%!%
M05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%P<&QI
M8V%T:6]N1FEL95!A=&@H)'!A=&@L("1A<'`@/2!N=6QL*0H@("`@>PH@("`@
M("`@(&EF("AI<U]N=6QL*"1A<'`I*2!["B`@("`@("`@("`@("1A<'`@/2`D
M=&AI<RT^7V-U<G)E;G1!<'`["B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3YA<'!L:6-A=&EO;G-;)&%P<%TI*2!["B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B7"(E<UPB(&ES
M(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB*2P@)&%P
M<"DI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('-T<E]R97!L86-E*"<E
M87!P;&EC871I;VXE)RP@)'1H:7,M/F%P<&QI8V%T:6]N<ULD87!P75LG9FEL
M97)O;W0G72P@)'!A=&@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5P;&%C
M92!A;GD@)6%P<&QI8V%T:6]N)2!S=')I;F=S('=I=&@@=&AE('=E8B!P871H
M('1O('1H92!A<'!L:6-A=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1P871H("!4:&4@87!P;&EC871I;VX@<W1R:6YG+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D87!P("`@5&AE(&%P<&QI8V%T:6]N(&)E:6YG(&-A;&QE
M9"X*("`@("`J"B`@("`@*B!`<F5T=7)N("!43T1/"B`@("`@*B`@("`@("`@
M("!2971U<FYS(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&%P<&QI8V%T:6]N5V5B4&%T:"@D<&%T:"P@)&%P<"`](&YU;&PI
M"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D87!P*2D@>PH@("`@("`@("`@
M("`D87!P(#T@)'1H:7,M/E]C=7)R96YT07!P.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N('-T<E]R97!L86-E*"<E87!P;&EC871I;VXE)RP@)'1H:7,M
M/F%P<&QI8V%T:6]N<ULD87!P75LG=V5B<F]O="==+"`D<&%T:"D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&-U<G)E;G0@87!P;&EC871I;VXL
M(&%D9&EN9R!I="!T;R!T:&4@=&]P(&]F('1H92!(;W)D90H@("`@("H@87!P
M;&EC871I;VX@<W1A8VLN($EF('1H:7,@:7,@=&AE(&9I<G-T(&%P<&QI8V%T
M:6]N('1O(&)E"B`@("`@*B!P=7-H960L(')E=')I979E('-E<W-I;VX@:6YF
M;W)M871I;VX@87,@=V5L;"X*("`@("`J"B`@("`@*B!P=7-H07!P*"D@86QS
M;R!R96%D<R!T:&4@87!P;&EC871I;VXG<R!C;VYF:6=U<F%T:6]N(&9I;&4@
M86YD"B`@("`@*B!S971S('5P(&ET<R!G;&]B86P@)&-O;F8@:&%S:"X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D87!P("`@("`@("`@5&AE(&YA
M;64@;V8@=&AE(&%P<&QI8V%T:6]N('1O('!U<V@N"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`D8VAE8VM097)M<R`@36%K92!S=7)E('1H870@=&AE(&-U<G)E
M;G0@=7-E<B!H87,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!P97)M:7-S:6]N<R!T;R!T:&4@87!P;&EC871I;VX@8F5I;F<@;&]A9&5D
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1&5F875L=',@
M=&\@=')U92X@4VAO=6QD($].3%D@8F4@9&ES86)L960@8GD*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!S>7-T96T@<V-R:7!T<R`H8W)O
M;B!J;V)S+"!E=&,N*2!A;F0@<V-R:7!T<PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('1H870@:&%N9&QE(&QO9VEN+@H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE(%]A<'!3
M=&%C:R!W87,@;6]D:69I960N"B`@("`@*B`@("`@("`@("`@("`@("`@(%)E
M='5R;B!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!P=7-H07!P*"1A<'`L("1C:&5C:U!E<FUS(#T@=')U92D*("`@('L*("`@
M("`@("!I9B`H)&%P<"`]/2`D=&AI<RT^7V-U<G)E;G1!<'`I('L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+RH@0F%I
M;"!O=70@:68@87!P;&EC871I;VX@:7,@;F]T('!R97-E;G0@;W(@:6YA8W1I
M=F4N("HO"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^87!P;&EC871I;VYS
M6R1A<'!=*2!\?`H@("`@("`@("`@("`D=&AI<RT^87!P;&EC871I;VYS6R1A
M<'!=6R=S=&%T=7,G72`]/2`G:6YA8W1I=F4G('Q\"B`@("`@("`@("`@("@D
M=&AI<RT^87!P;&EC871I;VYS6R1A<'!=6R=S=&%T=7,G72`]/2`G861M:6XG
M("8F("%!=71H.CII<T%D;6EN*"DI*2!["B`@("`@("`@("`@($AO<F1E.CIF
M871A;"@D87!P("X@)R!I<R!N;W0@86-T:79A=&5D)RP@7U]&24Q%7U\L(%]?
M3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("\J($EF('!E<FUI<W-I;VYS
M(&-H96-K:6YG(&ES(')E<75E<W1E9"P@<F5T=7)N(&%N(&5R<F]R(&EF"B`@
M("`@("`@("H@=&AE(&-U<G)E;G0@=7-E<B!D;V5S(&YO="!H879E(')E860@
M<&5R;7,@=&\@=&AE"B`@("`@("`@("H@87!P;&EC871I;VX@8F5I;F<@;&]A
M9&5D+B!792!A;&QO=R!A8V-E<W,Z"B`@("`@("`@("H*("`@("`@("`@*B`@
M+2!4;R!A;&P@861M:6YS+@H@("`@("`@("`J("`M(%1O(&%L;"!A=71H96YT
M:6-A=&5D('5S97)S(&EF(&YO('!E<FUI<W-I;VX@:7,@<V5T(&]N("1A<'`N
M"B`@("`@("`@("H@("T@5&\@86YY;VYE('=H;R!I<R!A;&QO=V5D(&)Y(&%N
M(&5X<&QI8VET($%#3"!O;B`D87!P+B`J+PH@("`@("`@(&EF("@D8VAE8VM0
M97)M<R`F)B`A)'1H:7,M/FAA<U!E<FUI<W-I;VXH)&%P<"DI('L*("`@("`@
M("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R:6YT9B@G57-E<B`E<R!D;V5S
M(&YO="!H879E(%)%040@<&5R;6ES<VEO;B!F;W(@)7,G+"!!=71H.CIG971!
M=71H*"DL("1A<'`I+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%
M0E5'*3L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R
M:6YT9BA?*")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB*2P@
M075T:#HZ9V5T075T:"@I+"`D=&AI<RT^87!P;&EC871I;VYS6R1A<'!=6R=N
M86UE)UTI+"`G<&5R;6ES<VEO;E]D96YI960G*3L*("`@("`@("!]"@H@("`@
M("`@("\J($EM<&]R="!T:&ES(&%P<&QI8V%T:6]N)W,@8V]N9FEG=7)A=&EO
M;B!V86QU97,N("HO"B`@("`@("`@)'-U8V-E<W,@/2`D=&AI<RT^:6UP;W)T
M0V]N9FEG*"1A<'`I.PH@("`@("`@(&EF("AI<U]A*"1S=6-C97-S+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<W5C8V5S<SL*("`@
M("`@("!]"@H@("`@("`@("\J($QO860@<')E9F5R96YC97,@869T97(@=&AE
M(&-O;F9I9W5R871I;VX@:&%S(&)E96X@;&]A9&5D('1O"B`@("`@("`@("H@
M;6%K92!S=7)E('1H92!P<F5F<R!F:6QE(&AA<R!A;&P@=&AE(&EN9F]R;6%T
M:6]N(&ET(&YE961S+B`J+PH@("`@("`@("1T:&ES+3YL;V%D4')E9G,H)&%P
M<"D["@H@("`@("`@("\J(%)E<V5T('1H92!L86YG=6%G92!I;B!C87-E('1H
M97)E(&ES(&$@9&EF9F5R96YT(&]N90H@("`@("`@("`J('-E;&5C=&5D(&EN
M('1H92!P<F5F97)E;F-E<RX@*B\*("`@("`@("`D;&%N9W5A9V4@/2`G)SL*
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P<F5F<T-A8VAE6R1A<'!=*2`F
M)@H@("`@("`@("`@("!I<W-E="@D=&AI<RT^7W!R969S0V%C:&5;)&%P<%TM
M/E]P<F5F<ULG;&%N9W5A9V4G72DI('L*("`@("`@("`@("`@)&QA;F=U86=E
M(#T@)'1H:7,M/E]P<F5F<T-A8VAE6R1A<'!=+3YG971686QU92@G;&%N9W5A
M9V4G*3L*("`@("`@("!]"B`@("`@("`@3DQ3.CIS971,86YG*"1L86YG=6%G
M92D["B`@("`@("`@3DQ3.CIS971497AT9&]M86EN*"1A<'`L("1T:&ES+3YA
M<'!L:6-A=&EO;G-;)&%P<%U;)V9I;&5R;V]T)UT@+B`G+VQO8V%L92<L($Y,
M4SHZ9V5T0VAA<G-E="@I*3L*("`@("`@("!3=')I;F<Z.G-E=$1E9F%U;'1#
M:&%R<V5T*$Y,4SHZ9V5T0VAA<G-E="@I*3L*"B`@("`@("`@+RH@3VYC92!W
M92!K;F]W(&5V97)Y=&AI;F<@<W5C8V5E9&5D(&%N9"!I<R!I;B!A(&-O;G-I
M<W1E;G0*("`@("`@("`@*B!S=&%T92!A9V%I;BP@<'5S:"!T:&4@;F5W(&%P
M<&QI8V%T:6]N(&]N=&\@=&AE('-T86-K+B`J+PH@("`@("`@("1T:&ES+3Y?
M87!P4W1A8VM;72`]("1A<'`["B`@("`@("`@)'1H:7,M/E]C=7)R96YT07!P
M(#T@)&%P<#L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!296UO=F4@=&AE(&-U<G)E;G0@87!P(&9R;VT@=&AE(&%P<&QI
M8V%T:6]N('-T86-K+"!S971T:6YG('1H92!C=7)R96YT"B`@("`@*B!A<'`@
M=&\@=VAI8VAE=F5R(&%P<"!W87,@8W5R<F5N="!B969O<F4@=&AI<R!O;F4@
M=&]O:R!O=F5R+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M;F%M92!O9B!T:&4@87!P;&EC871I;VX@=&AA="!W87,@<&]P<&5D+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!P;W!!<'`H*0H@("`@>PH@("`@("`@("\J(%!O
M<"!T:&4@8W5R<F5N="!A<'!L:6-A=&EO;B!O9F8@;V8@=&AE('-T86-K+B`J
M+PH@("`@("`@("1P<F5V:6]U<R`](&%R<F%Y7W!O<"@D=&AI<RT^7V%P<%-T
M86-K*3L*"B`@("`@("`@+RH@26UP;W)T('1H92!N97<@86-T:79E(&%P<&QI
M8V%T:6]N)W,@8V]N9FEG=7)A=&EO;B!V86QU97,*("`@("`@("`@*B!A;F0@
M<V5T('1H92!G971T97AT(&1O;6%I;B!A;F0@=&AE('!R969E<G)E9"!L86YG
M=6%G92X@*B\*("`@("`@("`D=&AI<RT^7V-U<G)E;G1!<'`@/2!C;W5N="@D
M=&AI<RT^7V%P<%-T86-K*2`_(&5N9"@D=&AI<RT^7V%P<%-T86-K*2`Z(&YU
M;&P["B`@("`@("`@:68@*"1T:&ES+3Y?8W5R<F5N=$%P<"D@>PH@("`@("`@
M("`@("`D=&AI<RT^:6UP;W)T0V]N9FEG*"1T:&ES+3Y?8W5R<F5N=$%P<"D[
M"B`@("`@("`@("`@("1T:&ES+3YL;V%D4')E9G,H)'1H:7,M/E]C=7)R96YT
M07!P*3L*("`@("`@("`@("`@)&QA;F=U86=E(#T@)$=,3T)!3%-;)W!R969S
M)UTM/F=E=%9A;'5E*"=L86YG=6%G92<I.PH@("`@("`@("`@("!I9B`H:7-S
M970H)&QA;F=U86=E*2D@>PH@("`@("`@("`@("`@("`@3DQ3.CIS971,86YG
M*"1L86YG=6%G92D["B`@("`@("`@("`@('T*("`@("`@("`@("`@3DQ3.CIS
M971497AT9&]M86EN*"1T:&ES+3Y?8W5R<F5N=$%P<"P@)'1H:7,M/F%P<&QI
M8V%T:6]N<ULD=&AI<RT^7V-U<G)E;G1!<'!=6R=F:6QE<F]O="==("X@)R]L
M;V-A;&4G+"!.3%,Z.F=E=$-H87)S970H*2D["B`@("`@("`@("`@(%-T<FEN
M9SHZ<V5T1&5F875L=$-H87)S970H3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1P<F5V:6]U<SL*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;B!T:&4@8W5R<F5N="!A<'!L:6-A=&EO;B`M('1H
M92!A<'`@870@=&AE('1O<"!O9B!T:&4@87!P;&EC871I;VX*("`@("`J('-T
M86-K+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8W5R<F5N
M="!A<'!L:6-A=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T07!P*"D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]C=7)R96YT07!P.PH@("`@
M?0H*("`@("\J*@H@("`@("H@0VAE8VL@<&5R;6ES<VEO;G,@;VX@86X@87!P
M;&EC871I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T
M:&5R(&]R(&YO="!A8V-E<W,@:7,@86QL;W=E9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@:&%S4&5R;6ES<VEO;B@D87!P+"`D<&5R;6ES<VEO;B`](%!%4DU3
M7U)%040I"B`@("!["B`@("`@("`@<F5T=7)N($%U=&@Z.FES061M:6XH*2!\
M?`H@("`@("`@("`@("`H)$=,3T)!3%-;)W!E<FUS)UTM/F5X:7-T<R@D87!P
M*0H@("`@("`@("`@("`@/R`D1TQ/0D%,4ULG<&5R;7,G72T^:&%S4&5R;6ES
M<VEO;B@D87!P+"!!=71H.CIG971!=71H*"DL("1P97)M:7-S:6]N*0H@("`@
M("`@("`@("`@.B`H8F]O;"E!=71H.CIG971!=71H*"DI.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5A9',@=&AE(&-O;F9I9W5R871I;VX@=F%L=65S(&9O
M<B!T:&4@9VEV96X@87!P;&EC871I;VX@86YD(&EM<&]R=',*("`@("`J('1H
M96T@:6YT;R!T:&4@9VQO8F%L("1C;VYF('9A<FEA8FQE+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&%P<"`@5&AE(&YA;64@;V8@=&AE(&%P<&QI
M8V%T:6]N+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O
M;B!S=6-C97-S+"!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!I;7!O<G1#;VYF:6<H)&%P<"D*("`@('L*("`@("`@("`O*B!$
M;VXG="!M86ME(&-O;F9I9R!F:6QE<R!G;&]B86P@)')E9VES=')Y('1H96US
M96QV97,N("HO"B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@
M+RH@0V%C:&4@8V]N9FEG('9A;'5E<R!S;R!T:&%T('=E(&1O;B=T(')E+7)E
M860@9FEL97,@;VX@979E<GD*("`@("`@("`@*B!P;W!!<'`H*2!C86QL+B`J
M+PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]C;VYF0V%C:&5;)&%P<%TI
M*2!["B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]C;VYF0V%C:&5;
M)VAO<F1E)UTI*2!["B`@("`@("`@("`@("`@("`D8V]N9B`](&%R<F%Y*"D[
M"B`@("`@("`@("`@("`@("!O8E]S=&%R="@I.PH@("`@("`@("`@("`@("`@
M)'-U8V-E<W,@/2!I;F-L=61E($A/4D1%7T)!4T4@+B`G+V-O;F9I9R]C;VYF
M+G!H<"<["B`@("`@("`@("`@("`@("`D97)R;W)S(#T@;V)?9V5T7V-O;G1E
M;G1S*"D["B`@("`@("`@("`@("`@("!O8E]E;F1?8VQE86XH*3L*("`@("`@
M("`@("`@("`@(&EF("@A96UP='DH)&5R<F]R<RDI('L*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G1F%I;&5D('1O(&EM
M<&]R="!(;W)D92!C;VYF:6=U<F%T:6]N.B`G("X@<W1R:7!?=&%G<R@D97)R
M;W)S*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H
M(21S=6-C97-S*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H)T9A:6QE9"!T;R!I;7!O<G0@2&]R9&4@8V]N9FEG=7)A
M=&EO;BXG*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O
M*B!);FET:6%L($AO<F1E+7=I9&4@<V5T=&EN9W,N("HO"@H@("`@("`@("`@
M("`@("`@+RH@4V5T('1H92!E<G)O<B!R97!O<G1I;F<@;&5V96P@:6X@86-C
M;W)D86YC92!W:71H"B`@("`@("`@("`@("`@("`@*B!T:&4@8V]N9FEG('-E
M='1I;F=S+B`J+PH@("`@("`@("`@("`@("`@97)R;W)?<F5P;W)T:6YG*"1C
M;VYF6R=D96)U9U]L979E;"==*3L*"B`@("`@("`@("`@("`@("`O*B!3970@
M=&AE(&UA>&EM=6T@97AE8W5T:6]N('1I;64@:6X@86-C;W)D86YC92!W:71H
M"B`@("`@("`@("`@("`@("`@*B!T:&4@8V]N9FEG('-E='1I;F=S+B`J+PH@
M("`@("`@("`@("`@("`@0'-E=%]T:6UE7VQI;6ET*"1C;VYF6R=M87A?97AE
M8U]T:6UE)UTI.PH*("`@("`@("`@("`@("`@("\J(%-E="!T:&4@=6UA<VL@
M86-C;W)D:6YG('1O(&-O;F9I9R!S971T:6YG<RX@*B\*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D8V]N9ELG=6UA<VLG72DI('L*("`@("`@("`@("`@
M("`@("`@("!U;6%S:R@D8V]N9ELG=6UA<VLG72D["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D8V]N
M9B`]("1T:&ES+3Y?8V]N9D-A8VAE6R=H;W)D92==.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!I9B`H)&%P<"`A/3T@)VAO<F1E)RD@>PH@("`@("`@
M("`@("`@("`@;V)?<W1A<G0H*3L*("`@("`@("`@("`@("`@("1S=6-C97-S
M(#T@:6YC;'5D92`D=&AI<RT^87!P;&EC871I;VYS6R1A<'!=6R=F:6QE<F]O
M="==("X@)R]C;VYF:6<O8V]N9BYP:'`G.PH@("`@("`@("`@("`@("`@)&5R
M<F]R<R`](&]B7V=E=%]C;VYT96YT<R@I.PH@("`@("`@("`@("`@("`@;V)?
M96YD7V-L96%N*"D["B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1E<G)O
M<G,I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)T9A:6QE9"!T;R!I;7!O<G0@87!P;&EC871I;VX@8V]N9FEG=7)A
M=&EO;B!F;W(@)R`N("1A<'`@+B`G.B`G("X@<W1R:7!?=&%G<R@D97)R;W)S
M*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H(21S
M=6-C97-S*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H)T9A:6QE9"!T;R!I;7!O<G0@87!P;&EC871I;VX@8V]N9FEG
M=7)A=&EO;B!F;W(@)R`N("1A<'`I.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^7V-A8VAE5F%R<RAA<G)A
M>2@G7V-O;F9#86-H92<I*3L*"B`@("`@("`@("`@("1T:&ES+3Y?8V]N9D-A
M8VAE6R1A<'!=(#T@)B1C;VYF.PH@("`@("`@('T*"B`@("`@("`@)$=,3T)!
M3%-;)V-O;F8G72`]("8D=&AI<RT^7V-O;F9#86-H95LD87!P73L*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($QO861S('1H
M92!P<F5F97)E;F-E<R!F;W(@=&AE(&-U<G)E;G0@=7-E<B!F;W(@=&AE(&-U
M<G)E;G0@87!P;&EC871I;VX*("`@("`J(&%N9"!I;7!O<G1S('1H96T@:6YT
M;R!T:&4@9VQO8F%L("1P<F5F<R!V87)I86)L92X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1A<'`@(%1H92!N86UE(&]F('1H92!A<'!L:6-A=&EO
M;BX*("`@("`J+PH@("`@9G5N8W1I;VX@;&]A9%!R969S*"1A<'`@/2!N=6QL
M*0H@("`@>PH@("`@("`@('-T871I8R`D<')E9G-?9&5F875L="`](&9A;'-E
M.PH*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U!R969S+G!H<"<["@H@
M("`@("`@(&EF("@D87!P(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1A<'`@
M/2`D=&AI<RT^7V-U<G)E;G1!<'`["B`@("`@("`@?0H*("`@("`@("`O*B!)
M9B!T:&5R92!I<R!N;R!L;V=G960@:6X@=7-E<BP@<F5T=7)N(&%N(&5M<'1Y
M(%!R969S.CH*("`@("`@("`@*B!O8FIE8W0@=VET:"!J=7-T(&1E9F%U;'0@
M<')E9F5R96YC97,N("HO"B`@("`@("`@:68@*"%!=71H.CIG971!=71H*"DI
M('L*("`@("`@("`@("`@)'!R969S(#T@)E!R969S.CIF86-T;W)Y*"=S97-S
M:6]N)RP@)&%P<"P@)R<L("<G+"!N=6QL+"!F86QS92D["B`@("`@("`@("`@
M("1P<F5F<RT^<F5T<FEE=F4H*3L*("`@("`@("`@("`@)'1H:7,M/E]P<F5F
M<T-A8VAE6R1A<'!=(#T@)B1P<F5F<SL*("`@("`@("`@("`@)$=,3T)!3%-;
M)W!R969S)UT@/2`F)'1H:7,M/E]P<F5F<T-A8VAE6R1A<'!=.PH@("`@("`@
M("`@("`D<')E9G-?9&5F875L="`]('1R=64["B`@("`@("`@("`@(')E='5R
M;CL*("`@("`@("!]"@H@("`@("`@("\J($-A8VAE('!R969S(&]B:F5C=',@
M<V\@=&AA="!W92!D;VXG="!R92UL;V%D('1H96T@;VX@979E<GD*("`@("`@
M("`@*B!P;W!!<'`H*2!C86QL+B`J+PH@("`@("`@(&EF("@A:7-S970H)'1H
M:7,M/E]P<F5F<T-A8VAE6R1A<'!=*2!\?`H@("`@("`@("`@("`A96UP='DH
M)'!R969S7V1E9F%U;'0I*2!["B`@("`@("`@("`@("1P<F5F<R`]("90<F5F
M<SHZ9F%C=&]R>2@D1TQ/0D%,4ULG8V]N9B==6R=P<F5F<R==6R=D<FEV97(G
M72P@)&%P<"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M($%U=&@Z.F=E=$%U=&@H*2P@075T:#HZ9V5T0W)E9&5N=&EA;"@G<&%S<W=O
M<F0G*2D["B`@("`@("`@("`@("1P<F5F<RT^<F5T<FEE=F4H*3L*("`@("`@
M("`@("`@)'1H:7,M/E]P<F5F<T-A8VAE6R1A<'!=(#T@)B1P<F5F<SL*("`@
M("`@("!]"@H@("`@("`@("1'3$]"04Q36R=P<F5F<R==(#T@)B1T:&ES+3Y?
M<')E9G-#86-H95LD87!P73L*("`@('T*"B`@("`O*BH*("`@("`J(%5N;&]A
M9"!P<F5F97)E;F-E<R!F<F]M(&%N(&%P<&QI8V%T:6]N(&]R("AI9B!N;R!A
M<'!L:6-A=&EO;B!I<PH@("`@("H@<W!E8VEF:65D*2!F<F]M($%,3"!A<'!L
M:6-A=&EO;G,N(%5S969U;"!W:&5N(&$@=7-E<B!H87,@;&]G9V5D"B`@("`@
M*B!O=70@8G5T('EO=2!N965D('1O(&-O;G1I;G5E(&]N('1H92!S86UE('!A
M9V4L(&5T8RX*("`@("`J"B`@("`@*B!!9G1E<B!U;FQO861I;F<L(&EF('1H
M97)E(&ES(&%N(&%P<&QI8V%T:6]N(&]N('1H92!A<'`@<W1A8VL@=&\*("`@
M("`J(&QO860@<')E9F5R96YC97,@9G)O;2P@=&AE;B!W92!R96QO860@82!F
M<F5S:"!S970N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D87!P("!4
M:&4@87!P;&EC871I;VX@=&\@=6YL;V%D('!R969R96YC97,@9F]R+B!)9B!N
M=6QL+`H@("`@("H@("`@("`@("`@("`@("`@("`@("!!3$P@<')E9F5R96YC
M97,@87)E(')E<V5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!U;FQO8610<F5F
M<R@D87!P(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H)&%P<"`]/3T@;G5L
M;"D@>PH@("`@("`@("`@("`D=&AI<RT^7W!R969S0V%C:&4@/2!A<G)A>2@I
M.PH@("`@("`@('T@96QS96EF("AI<W-E="@D=&AI<RT^7W!R969S0V%C:&5;
M)&%P<%TI*2!["B`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?<')E9G-#86-H
M95LD87!P72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES+3Y?8W5R<F5N=$%P<"D@
M>PH@("`@("`@("`@("`D=&AI<RT^;&]A9%!R969S*"D["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!R97%U97-T960@8V]N
M9FEG=7)A=&EO;B!P87)A;65T97(@9F]R('1H92!S<&5C:69I960*("`@("`J
M(&%P<&QI8V%T:6]N+B!)9B!N;R!A<'!L:6-A=&EO;B!I<R!S<&5C:69I960L
M('1H92!V86QU92!O9@H@("`@("H@)'1H:7,M/E]C=7)R96YT07!P("AT:&4@
M8W5R<F5N="!A<'!L:6-A=&EO;BD@:7,@=7-E9"X@2&]W979E<BP*("`@("`J
M(&EF('1H92!P87)A;65T97(@:7,@;F]T('!R97-E;G0@9F]R('1H870@87!P
M;&EC871I;VXL('1H90H@("`@("H@2&]R9&4M=VED92!V86QU92!I<R!U<V5D
M(&EN<W1E860N($EF('1H870@:7,@;F]T('!R97-E;G0L('=E"B`@("`@*B!R
M971U<FX@;G5L;"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P87)A
M;65T97(@(%1H92!C;VYF:6=U<F%T:6]N('9A;'5E('1O(')E=')I979E+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D87!P("`@("`@("!4:&4@87!P;&EC871I
M;VX@=&\@9V5T('1H92!V86QU92!F;W(N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!R97%U97-T960@<&%R86UE=&5R+"!O<B!N=6QL(&EF
M(&ET(&ES(&YO="!S970N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E="@D<&%R
M86UE=&5R+"`D87!P(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L
M;"@D87!P*2D@>PH@("`@("`@("`@("`D87!P(#T@)'1H:7,M/E]C=7)R96YT
M07!P.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YA<'!L
M:6-A=&EO;G-;)&%P<%U;)'!A<F%M971E<ETI*2!["B`@("`@("`@("`@("1P
M=F%L(#T@)'1H:7,M/F%P<&QI8V%T:6]N<ULD87!P75LD<&%R86UE=&5R73L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H)'!A<F%M971E<B`]
M/2`G:6-O;B<I('L*("`@("`@("`@("`@("`@("1P=F%L(#T@)'1H:7,M/E]G
M971)8V]N*"1A<'`I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)'!V86P@/2!I<W-E="@D=&AI<RT^87!P;&EC871I;VYS6R=H;W)D
M92==6R1P87)A;65T97)=*2`_("1T:&ES+3YA<'!L:6-A=&EO;G-;)VAO<F1E
M)UU;)'!A<F%M971E<ET@.B!N=6QL.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!I9B`H)'!A<F%M971E<B`]/2`G;F%M92<I('L*("`@("`@
M("`@("`@<F5T=7)N(%\H)'!V86PI.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(')E='5R;B`D<'9A;#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!&=6YC=&EO;B!T;R!W;W)K(&]U="!A;B!A<'!L:6-A=&EO;B=S
M(&=R87!H:6-S(%5222P@=&%K:6YG(&EN=&\@86-C;W5N=`H@("`@("H@86YY
M('1H96UE<R!D:7)E8W1O<FEE<R!T:&%T(&UA>2!B92!S970@=7`N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D87!P("!4:&4@87!P;&EC871I;VX@
M9F]R('=H:6-H('1O(&=E="!T:&4@:6UA9V4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@9&ER96-T;W)Y+B!)9B!B;&%N:R!W:6QL(&1E9F%U;'0@=&\@
M8W5R<F5N=`H@("`@("H@("`@("`@("`@("`@("`@("`@("!A<'!L:6-A=&EO
M;BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&EM86=E(&1I
M<F5C=&]R>2!U<FD@<&%T:"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T26UA
M9V5$:7(H)&%P<"`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1A
M<'`I*2!["B`@("`@("`@("`@("1A<'`@/2`D=&AI<RT^7V-U<G)E;G1!<'`[
M"B`@("`@("`@?0H*("`@("`@("!S=&%T:6,@)&EM9U]D:7(@/2!A<G)A>2@I
M.PH@("`@("`@(&EF("AI<W-E="@D:6UG7V1I<ELD87!P72DI('L*("`@("`@
M("`@("`@<F5T=7)N("1I;6=?9&ER6R1A<'!=.PH@("`@("`@('T*"B`@("`@
M("`@+RH@5&AI<R!I<R!T:&4@9&5F875L="!L;V-A=&EO;B!F;W(@=&AE(&=R
M87!H:6-S+B`J+PH@("`@("`@("1I;6=?9&ER6R1A<'!=(#T@)'1H:7,M/F=E
M="@G=&AE;65S=7)I)RP@)&%P<"D@+B`G+V=R87!H:6-S)SL*"B`@("`@("`@
M<W1A=&EC("1T:&5M95]I8V]N<SL*"B`@("`@("`@+RH@1FEG=7)E(&]U="!I
M9B!T:&ES(&ES(&=O:6YG('1O(&)E(&]V97)R:61D96X@8GD@86YY('1H96UE
M"B`@("`@("`@("H@<V5T=&EN9W,N("HO"B`@("`@("`@:68@*&ES<V5T*"1'
M3$]"04Q36R=P<F5F<R==*2`F)@H@("`@("`@("`@("`H)'1H96UE(#T@)$=,
M3T)!3%-;)W!R969S)UTM/F=E=%9A;'5E*"=T:&5M92<I*2`F)@H@("`@("`@
M("`@("`H:7-S970H)'1H96UE7VEC;VYS*2!\?`H@("`@("`@("`@("`@*"A`
M:6YC;'5D92`D=&AI<RT^9V5T*"=T:&5M97-F<R<L("=H;W)D92<I("X@)R\G
M("X@)'1H96UE("X@)R]I;F9O+G!H<"<I("8F"B`@("`@("`@("`@("`@:7-S
M970H)'1H96UE7VEC;VYS*2DI("8F"B`@("`@("`@("`@(&EN7V%R<F%Y*"1A
M<'`L("1T:&5M95]I8V]N<RDI('L*("`@("`@("`@("`@)&EM9U]D:7);)&%P
M<%T@/2`D=&AI<RT^9V5T*"=T:&5M97-U<FDG+"`D87!P*2`N("<O)R`N("1T
M:&5M92`N("<O9W)A<&AI8W,G.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1I;6=?9&ER6R1A<'!=.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!T:&4@<&%T:"!T;R!A;B!A<'!L:6-A=&EO;B=S(&EC;VXL(')E<W!E8W1I
M;F<@=VAE=&AE<B!T:&4*("`@("`J(&-U<G)E;G0@=&AE;64@:&%S(&ET<R!O
M=VX@:6-O;G,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D87!P("!4:&4@87!P;&EC871I;VX@
M9F]R('=H:6-H('1O(&=E="!T:&4@:6-O;BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V=E=$EC;VXH)&%P<"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/F=E=$EM86=E1&ER*"1A<'`I("X@)R\G("X@)&%P<"`N("<N<&YG)SL*("`@
M('T*"B`@("`O*BH*("`@("`J(%%U97)Y('1H92!I;FET:6%L('!A9V4@9F]R
M(&%N(&%P<&QI8V%T:6]N("T@=&AE('=E8G)O;W0L(&EF('1H97)E(&ES(&YO
M"B`@("`@*B!I;FET:6%L7W!A9V4@<V5T+"!A;F0@=&AE(&EN:71I86Q?<&%G
M92P@:68@:70@:7,@<V5T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&%P<"`@5&AE(&YA;64@;V8@=&AE(&%P<&QI8V%T:6]N+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!54DP@<&]I;G1I;F<@=&\@=&AE(&EN:71A
M;"!P86=E(&]F('1H92!A<'!L:6-A=&EO;BX*("`@("`J("`@("`@("`@("`@
M("`@("!2971U<FYS(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$EN:71I86Q086=E*"1A<'`@/2!N=6QL*0H@("`@>PH@
M("`@("`@(&EF("AI<U]N=6QL*"1A<'`I*2!["B`@("`@("`@("`@("1A<'`@
M/2`D=&AI<RT^7V-U<G)E;G1!<'`["B`@("`@("`@?0H*("`@("`@("!I9B`H
M(6ES<V5T*"1T:&ES+3YA<'!L:6-A=&EO;G-;)&%P<%TI*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B7"(E<UPB
M(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB*2P@
M)&%P<"DI.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/F%P<&QI
M8V%T:6]N<ULD87!P75LG=V5B<F]O="==("X@)R\G("X@*&ES<V5T*"1T:&ES
M+3YA<'!L:6-A=&EO;G-;)&%P<%U;)VEN:71I86Q?<&%G92==*2`_("1T:&ES
M+3YA<'!L:6-A=&EO;G-;)&%P<%U;)VEN:71I86Q?<&%G92==(#H@)R<I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0'-I;F-E($AO<F1E(#,N,0H@("`@("HO
M"B`@("!F=6YC=&EO;B!?7V=E="@D87!I*0H@("`@>PH@("`@("`@(&EF("AI
M;E]A<G)A>2@D87!I+"`D=&AI<RT^;&ES=$%027,H*2DI('L*("`@("`@("`@
M("`@<F5T=7)N(&YE=R!296=I<W1R>4-A;&QE<B@D=&AI<RP@)&%P:2D["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0VQO;F4@<VAO=6QD(&YE
M=F5R(&)E(&-A;&QE9"!O;B!296=I<W1R>2!O8FIE8W1S+B!)9B!I="!I<RP@
M9&EE+@H@("`@("H*("`@("`J($!S:6YC92!(;W)D92`S+C$*("`@("`J+PH@
M("`@9G5N8W1I;VX@7U]C;&]N92@I"B`@("!["B`@("`@("`@2&]R9&4Z.F9A
M=&%L*"=296=I<W1R>2!O8FIE8W1S('-H;W5L9"!N979E<B!B92!C;&]N960N
M)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@('T*"GT*"B\J*@H@*B!`<&%C
M:V%G92!(;W)D95]&<F%M97=O<FL*("H@0'-I;F-E($AO<F1E(#,N,0H@*B\*
M8VQA<W,@4F5G:7-T<GE#86QL97(@>PH*("`@('9A<B`D<F5G:7-T<GD["B`@
M("!V87(@)&%P:3L*"B`@("!F=6YC=&EO;B!?7V-O;G-T<G5C="@D<F5G:7-T
M<GDL("1A<&DI"B`@("!["B`@("`@("`@)'1H:7,M/G)E9VES=')Y(#T@)')E
M9VES=')Y.PH@("`@("`@("1T:&ES+3YA<&D@/2`D87!I.PH@("`@?0H*("`@
M(&9U;F-T:6]N(%]?8V%L;"@D;65T:&]D+"`D87)G<RD*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/G)E9VES=')Y+3YC86QL*"1T:&ES+3YA<&D@+B`G
M+R<@+B`D;65T:&]D+"`D87)G<RD["B`@("!]"@I]"@``````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92]#;VUP<F5S<RYP:'``````````````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-S4R-R`Q,#4Q-30S,S<T,"`P
M,C$V-C,`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J(%1H92!(;W)D95]#;VUP<F5S<SHZ(&-L87-S('!R
M;W9I9&5S(&%N($%022!F;W(@=F%R:6]U<R!C;VUP<F5S<VEO;@H@*B!T96-H
M;FEQ=65S('1H870@8V%N(&)E('5S960@8GD@2&]R9&4@87!P;&EC871I;VYS
M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<RYP
M:'`L=B`Q+C<N,3(N,3`@,C`P-B\P,2\P,2`R,3HR.#HQ,2!J86X@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L
M=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@
M*B!`875T:&]R("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC
M;VQO<F%D;RYE9'4^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G
M92!(;W)D95]#;VUP<F5S<PH@*B\*8VQA<W,@2&]R9&5?0V]M<')E<W,@>PH*
M("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E=&4@
M2&]R9&5?0V]M<')E<W,@:6YS=&%N8V4@8F%S960@;VX@)&1R:79E<BX*("`@
M("`J"B`@("`@*B!`<&%R86T@;6EX960@)&1R:79E<B`@5&AE('1Y<&4@;V8@
M8V]N8W)E=&4@2&]R9&5?0V]M<')E<W,@<W5B8VQA<W,@=&\*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!R971U<FXN($EF("1D<FEV97(@:7,@86X@
M87)R87DL('1H96X@=V4@=VEL;"!L;V]K"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@:6X@)&1R:79E<ELP72]L:6(O0V]M<')E<W,O(&9O<B!T:&4@
M<W5B8VQA<W,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!I;7!L96UE
M;G1A=&EO;B!N86UE9"`D9')I=F5R6S%=+G!H<"X*("`@("`J($!P87)A;2!A
M<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@861D:71I;VYA
M;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@<&%R86UE=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE960N"B`@("`@*@H@
M("`@("H@0')E='5R;B!(;W)D95]#;VUP<F5S<R`@5&AE(&YE=VQY(&-R96%T
M960@8V]N8W)E=&4@2&]R9&5?0V]M<')E<W,*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@(&EN<W1A;F-E+"!O<B!F86QS92!O;B!A;B!E<G)O<BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M
M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1D<FEV
M97(I*2!["B`@("`@("`@("`@(&QI<W0H)&%P<"P@)&1R:79E<BD@/2`D9')I
M=F5R.PH@("`@("`@('T*"B`@("`@("`@)&1R:79E<B`](&)A<V5N86UE*"1D
M<FEV97(I.PH*("`@("`@("!I9B`H(65M<'1Y*"1A<'`I*2!["B`@("`@("`@
M("`@(')E<75I<F5?;VYC92`D87!P("X@)R]L:6(O0V]M<')E<W,O)R`N("1D
M<FEV97(@+B`G+G!H<"<["B`@("`@("`@?2!E;'-E:68@*$!F:6QE7V5X:7-T
M<RAD:7)N86UE*%]?1DE,15]?*2`N("<O0V]M<')E<W,O)R`N("1D<FEV97(@
M+B`G+G!H<"<I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE
M*%]?1DE,15]?*2`N("<O0V]M<')E<W,O)R`N("1D<FEV97(@+B`G+G!H<"<[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@0&EN8VQU9&5?;VYC92`G
M2&]R9&4O0V]M<')E<W,O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@
M?0H*("`@("`@("`D8VQA<W,@/2`G2&]R9&5?0V]M<')E<W-?)R`N("1D<FEV
M97(["B`@("`@("`@:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@
M("`@("`@("1C;VUP<F5S<R`]("9N97<@)&-L87-S*"1P87)A;7,I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1C;VUP<F5S<R`](&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1C;VUP<F5S<SL*("`@('T*"B`@
M("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(')E9F5R96YC92!T
M;R!A(&-O;F-R971E($AO<F1E7T-O;7!R97-S(&EN<W1A;F-E"B`@("`@*B!B
M87-E9"!O;B`D9')I=F5R+B!)="!W:6QL(&]N;'D@8W)E871E(&$@;F5W(&EN
M<W1A;F-E(&EF(&YO"B`@("`@*B!(;W)D95]#;VUP<F5S<R!I;G-T86YC92!W
M:71H('1H92!S86UE('!A<F%M971E<G,@8W5R<F5N=&QY(&5X:7-T<RX*("`@
M("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z"B`@
M("`@*B`@("1V87(@/2`F2&]R9&5?0V]M<')E<W,Z.G-I;F=L971O;B@I.PH@
M("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D9')I=F5R("!3964@2&]R9&5?
M0V]M<')E<W,Z.F9A8W1O<GDH*2X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R
M86US("!3964@2&]R9&5?0V]M<')E<W,Z.F9A8W1O<GDH*2X*("`@("`J"B`@
M("`@*B!`<F5T=7)N($AO<F1E7T-O;7!R97-S("!4:&4@8V]N8W)E=&4@2&]R
M9&5?0V]M<')E<W,@<F5F97)E;F-E+"!O<B!F86QS90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@;VX@86X@97)R;W(N"B`@("`@*B\*("`@(&9U
M;F-T:6]N("9S:6YG;&5T;VXH)&1R:79E<BP@)'!A<F%M<R`](&%R<F%Y*"DI
M"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T86YC97,@/2!A<G)A>2@I.PH*
M("`@("`@("`D<VEG;F%T=7)E(#T@;60U*'-E<FEA;&EZ92AA<G)A>2@D9')I
M=F5R+"`D<&%R86US*2DI.PH@("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E
M<ULD<VEG;F%T=7)E72DI('L*("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG
M;F%T=7)E72`]("9(;W)D95]#;VUP<F5S<SHZ9F%C=&]R>2@D9')I=F5R+"`D
M<&%R86US*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6YS=&%N8V5S
M6R1S:6=N871U<F5=.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N<W1R=6-T
M;W(N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@(%!A<F%M
M971E<B!A<G)A>2X*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?0V]M<')E
M<W,H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#;VUP<F5S<R!T:&4@9&%T82X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1D871A("`@5&AE(&1A=&$@=&\@8V]M<')E<W,N"B`@("`@*B!`
M<&%R86T@87)R87D@)'!A<F%M<R`@06X@87)R87D@;V8@87)G=6UE;G1S(&YE
M961E9"!T;R!C;VUP<F5S<R!T:&4@9&%T82X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!4:&4@8V]M<')E<W-E9"!D871A+@H@("`@("H@("`@("`@
M("`@("`@("`@4F5T=7)N<R!014%27T5R<F]R(&]B:F5C="!O;B!E<G)O<BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@8V]M<')E<W,H)&1A=&$L("1P87)A;7,@
M/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*"=5;G-U<'!O<G1E9"<I.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5C
M;VUP<F5S<R!T:&4@9&%T82X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1D871A("`@5&AE(&1A=&$@=&\@9&5C;VUP<F5S<RX*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US("!!;B!A<G)A>2!O9B!A<F=U;65N=',@;F5E9&5D
M('1O(&1E8V]M<')E<W,@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@9&%T82X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@9&5C
M;VUP<F5S<V5D(&1A=&$N"B`@("`@*B`@("`@("`@("`@("`@("!2971U<FYS
M(%!%05)?17)R;W(@;V)J96-T(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!D96-O;7!R97-S*"1D871A+"`D<&%R86US(#T@87)R87DH*2D*("`@
M('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G56YS=7!P;W)T
M960G*3L*("`@('T*"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92].3%,N<&AP
M````````````````````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`T
M,#,V-"`Q,#4Q-30S,S<T,"`P,C`U,C``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!.3%,Z.B!C
M;&%S<R!P<F]V:61E<R!.871I=F4@3&%N9W5A9V4@4W5P<&]R="X@5&AI<R!I
M;F-L=61E<R!C;VUM;VX*("H@;65T:&]D<R!F;W(@:&%N9&QI;F<@;&%N9W5A
M9V4@9&5T96-T:6]N(&%N9"!S96QE8W1I;VXL('1I;65Z;VYE<RP@86YD"B`J
M(&AO<W1N86UE+3YC;W5N=')Y(&QO;VMU<',N"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+TY,4R].3%,N<&AP+'8@,2XX,BXT+C$S(#(P,#8O,#$O,C0@,#<Z
M-3`Z,C8@<V5L<VMY($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@
M2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#$Y.3DM
M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P
M>7)I9VAT(#(P,#(M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G
M/@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU
M<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J($!A=71H
M;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T
M:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`875T:&]R
M("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE
M9'4^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95].
M3%,*("HO"F-L87-S($Y,4R!["@H@("`@+RHJ"B`@("`@*B!396QE8W1S('1H
M92!M;W-T('!R969E<G)E9"!L86YG=6%G92!F;W(@=&AE(&-U<G)E;G0@8VQI
M96YT('-E<W-I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!S96QE8W1E9"!L86YG=6%G92!A8F)R979I871I;VXN"B`@("`@*B\*("`@
M(&9U;F-T:6]N('-E;&5C="@I"B`@("!["B`@("`@("`@9VQO8F%L("1N;',L
M("1P<F5F<SL*"B`@("`@("`@)&QA;F<@/2!5=&EL.CIG971&;W)M1&%T82@G
M;F5W7VQA;F<G*3L*"B`@("`@("`@+RH@1FER<W0L(&-H96-K(&EF(&QA;F=U
M86=E('!R968@:7,@;&]C:V5D(&%N9"P@:68@<V\L('-E="!I="!T;R!I=',*
M("`@("`@("`@("!V86QU92`J+PH@("`@("`@(&EF("AI<W-E="@D<')E9G,I
M("8F("1P<F5F<RT^:7-,;V-K960H)VQA;F=U86=E)RDI('L*("`@("`@("`@
M("`@)&QA;F=U86=E(#T@)'!R969S+3YG971686QU92@G;&%N9W5A9V4G*3L*
M("`@("`@("`O*B!#:&5C:R!I9B!T:&4@=7-E<B!S96QE8W1E9"!A(&QA;F=U
M86=E(&9R;VT@=&AE(&QO9VEN('-C<F5E;B`J+PH@("`@("`@('T@96QS96EF
M("@A96UP='DH)&QA;F<I*2!["B`@("`@("`@("`@("1L86YG=6%G92`]("1L
M86YG.PH@("`@("`@("\J($-H96-K(&EF('=E(&AA=F4@82!L86YG=6%G92!S
M970@:6X@82!C;V]K:64@*B\*("`@("`@("!](&5L<V5I9B`H:7-S970H)%]3
M15-324].6R=H;W)D95]L86YG=6%G92==*2D@>PH@("`@("`@("`@("`D;&%N
M9W5A9V4@/2`D7U-%4U-)3TY;)VAO<F1E7VQA;F=U86=E)UT["B`@("`@("`@
M+RH@57-E('-I=&4M=VED92!D969A=6QT+"!I9B!O;F4@:7,@9&5F:6YE9"`J
M+PH@("`@("`@('T@96QS96EF("@A96UP='DH)&YL<ULG9&5F875L=',G75LG
M;&%N9W5A9V4G72DI('L*("`@("`@("`@("`@)&QA;F=U86=E(#T@)&YL<ULG
M9&5F875L=',G75LG;&%N9W5A9V4G73L*("`@("`@("`O*B!4<GD@8G)O=W-E
M<BUA8V-E<'1E9"!L86YG=6%G97,N("HO"B`@("`@("`@?2!E;'-E:68@*"%E
M;7!T>2@D7U-%4E9%4ELG2%144%]!0T-%4%1?3$%.1U5!1T4G72DI('L*("`@
M("`@("`@("`@+RH@5&AE(&)R;W=S97(@<W5P<&QI97,@82!L:7-T+"!S;R!R
M971U<FX@=&AE(&9I<G-T('9A;&ED(&]N92X@*B\*("`@("`@("`@("`@)&)R
M;W=S97)?;&%N9W,@/2!E>'!L;V1E*"<L)RP@)%]315)615);)TA45%!?04-#
M15!47TQ!3D=504=%)UTI.PH@("`@("`@("`@("!F;W)E86-H("@D8G)O=W-E
M<E]L86YG<R!A<R`D;&%N9RD@>PH@("`@("`@("`@("`@("`@+RH@4W1R:7`@
M<75A;&ET>2!V86QU92!F;W(@;&%N9W5A9V4@*B\*("`@("`@("`@("`@("`@
M(&EF("@H)'!O<R`]('-T<G!O<R@D;&%N9RP@)SLG*2D@(3T](&9A;'-E*2![
M"B`@("`@("`@("`@("`@("`@("`@)&QA;F<@/2!S=6)S='(H)&QA;F<L(#`L
M("1P;W,I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&QA
M;F<@/2!.3%,Z.E]M87`H=')I;2@D;&%N9RDI.PH@("`@("`@("`@("`@("`@
M:68@*$Y,4SHZ:7-686QI9"@D;&%N9RDI('L*("`@("`@("`@("`@("`@("`@
M("`D;&%N9W5A9V4@/2`D;&%N9SL*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("\J($EN(&-A
M<V4@;F\@9G5L;"!M871C:"P@<V%V92!B97-T(&=U97-S(&)A<V5D(&]N('!R
M969I>"`J+PH@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D<&%R=&EA;%]L
M86YG*2`F)@H@("`@("`@("`@("`@("`@("`@($Y,4SHZ:7-686QI9"A.3%,Z
M.E]M87`H<W5B<W1R*"1L86YG+"`P+"`R*2DI*2!["B`@("`@("`@("`@("`@
M("`@("`@)'!A<G1I86Q?;&%N9R`]($Y,4SHZ7VUA<"AS=6)S='(H)&QA;F<L
M(#`L(#(I*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@:68@*"%I<W-E="@D;&%N9W5A9V4I*2!["B`@("`@
M("`@("`@(&EF("AI<W-E="@D<&%R=&EA;%]L86YG*2D@>PH@("`@("`@("`@
M("`@("`@)&QA;F=U86=E(#T@)'!A<G1I86Q?;&%N9SL*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("\J($YO(&1I8V4@875T;RUD971E
M8W1I;F<L(&1E9F%U;'0@=&\@55,@16YG;&ES:"X@*B\*("`@("`@("`@("`@
M("`@("1L86YG=6%G92`]("=E;E]54R<["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!B87-E;F%M92@D;&%N9W5A9V4I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@;&%N9W5A9V4N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;&%N9R`@5&AE(&QA;F=U86=E(&%B8G)E
M=FEA=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T3&%N9R@D;&%N9R`]
M(&YU;&PI"B`@("!["B`@("`@("`@:6YC;'5D95]O;F-E($A/4D1%7T)!4T4@
M+B`G+V-O;F9I9R]N;',N<&AP)SL*"B`@("`@("`@:68@*&5M<'1Y*"1L86YG
M*2!\?"`A3DQ3.CII<U9A;&ED*"1L86YG*2D@>PH@("`@("`@("`@("`D;&%N
M9R`]($Y,4SHZ<V5L96-T*"D["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S
M970H)$=,3T)!3%-;)VQA;F=U86=E)UTI*2!["B`@("`@("`@("`@(&EF("@D
M1TQ/0D%,4ULG;&%N9W5A9V4G72`]/2`D;&%N9RD@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F-L96%R0V%C:&4H*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)$=,3T)!3%-;)VQA;F=U86=E
M)UT@/2`D;&%N9SL*("`@("`@("`D7U-%4U-)3TY;)VAO<F1E7VQA;F=U86=E
M)UT@/2`D;&%N9SL*"B`@("`@("`@+RH@1FER<W0@=')Y(&QA;F=U86=E('=I
M=&@@=&AE(&-U<G)E;G0@8VAA<G-E="X@*B\*("`@("`@("`D;&%N9U]C:&%R
M<V5T(#T@)&QA;F<@+B`G+B<@+B!.3%,Z.F=E=$-H87)S970H*3L*("`@("`@
M("!I9B`H)&QA;F=?8VAA<G-E="`A/2!S971L;V-A;&4H3$-?04Q,+"`D;&%N
M9U]C:&%R<V5T*2D@>PH@("`@("`@("`@("`O*B!.97AT('1R>2!L86YG=6%G
M92!W:71H(&ET<R!D969A=6QT(&-H87)S970N("HO"B`@("`@("`@("`@(&=L
M;V)A;"`D;FQS.PH@("`@("`@("`@("`D8VAA<G-E="`]("%E;7!T>2@D;FQS
M6R=C:&%R<V5T<R==6R1L86YG72D@/R`D;FQS6R=C:&%R<V5T<R==6R1L86YG
M72`Z("=)4T\M.#@U.2TQ)SL*("`@("`@("`@("`@)&QA;F=?8VAA<G-E="`]
M("1L86YG("X@)RXG("X@)&-H87)S970["B`@("`@("`@("`@($Y,4SHZ7V-A
M8VAE9$-H87)S970H,"P@)&-H87)S970I.PH@("`@("`@("`@("!I9B`H)&QA
M;F=?8VAA<G-E="`A/2!S971L;V-A;&4H3$-?04Q,+"`D;&%N9U]C:&%R<V5T
M*2D@>PH@("`@("`@("`@("`@("`@+RH@070@;&%S="!T<GD@;&%N9W5A9V4@
M<V]L96QY+B`J+PH@("`@("`@("`@("`@("`@)&QA;F=?8VAA<G-E="`]("1L
M86YG.PH@("`@("`@("`@("`@("`@<V5T;&]C86QE*$Q#7T%,3"P@)&QA;F=?
M8VAA<G-E="D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@0'!U
M=&5N=B@G3$%.1STG("X@)&QA;F=?8VAA<G-E="D["B`@("`@("`@0'!U=&5N
M=B@G3$%.1U5!1T4])R`N("1L86YG7V-H87)S970I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4V5T<R!T:&4@9V5T=&5X="!D;VUA:6XN"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D87!P("`@("`@("!4:&4@87!P;&EC871I;VX@
M;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@)&1I<F5C=&]R>2`@5&AE(&1I
M<F5C=&]R>2!W:&5R92!T:&4@87!P;&EC871I;VXG<PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("!,0U]-15-304=%4R!D:7)E8W1O<GD@<F5S
M:61E<RX*("`@("`J($!P87)A;2!S=')I;F<@)&-H87)S970@("`@5&AE(&-H
M87)S970N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%1E>'1D;VUA:6XH)&%P
M<"P@)&1I<F5C=&]R>2P@)&-H87)S970I"B`@("!["B`@("`@("`@8FEN9'1E
M>'1D;VUA:6XH)&%P<"P@)&1I<F5C=&]R>2D["B`@("`@("`@=&5X=&1O;6%I
M;B@D87!P*3L*"B`@("`@("`@+RH@5&AE(&5X:7-T96YC92!O9B!T:&ES(&9U
M;F-T:6]N(&1E<&5N9',@;VX@=&AE('!L871F;W)M+B`J+PH@("`@("`@(&EF
M("AF=6YC=&EO;E]E>&ES=',H)V)I;F1?=&5X=&1O;6%I;E]C;V1E<V5T)RDI
M('L*("`@("`@("`@("`@3DQ3.CI?8V%C:&5D0VAA<G-E="@P+"!B:6YD7W1E
M>'1D;VUA:6Y?8V]D97-E="@D87!P+"`D8VAA<G-E="DI.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"%H96%D97)S7W-E;G0H*2D@>PH@("`@("`@("`@("!H
M96%D97(H)T-O;G1E;G0M5'EP93H@=&5X="]H=&UL.R!C:&%R<V5T/2<@+B`D
M8VAA<G-E="D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1&5T
M97)M:6YE<R!W:&5T:&5R('1H92!S=7!P;&EE9"!L86YG=6%G92!I<R!V86QI
M9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1L86YG=6%G92`@5&AE
M(&%B8G)E=FEA=&5D(&YA;64@;V8@=&AE(&QA;F=U86=E+@H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&4@;&%N9W5A9V4@:7,@
M=F%L:60L(&9A;'-E(&EF(&ET)W,@;F]T"B`@("`@*B`@("`@("`@("`@("`@
M("`@('9A;&ED(&]R('5N:VYO=VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES
M5F%L:60H)&QA;F=U86=E*0H@("`@>PH@("`@("`@(')E='5R;B`A96UP='DH
M)$=,3T)!3%-;)VYL<R==6R=L86YG=6%G97,G75LD;&%N9W5A9V5=*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($UA<',@;&%N9W5A9V5S('=I=&@@8V]M;6]N
M('1W;RUL971T97(@8V]D97,@*'-U8V@@87,@;FPI('1O('1H90H@("`@("H@
M9G5L;"!G971T97AT(&-O9&4@*&EN('1H:7,@8V%S92P@;FQ?3DPI+B!2971U
M<FYS('1H92!L86YG=6%G90H@("`@("H@=6YM;V1I9FEE9"!I9B!I="!I<VXG
M="!A;B!A;&EA<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1L86YG=6%G92`@5&AE(&QA;F=U
M86=E(&-O9&4@=&\@;6%P+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@;6%P<&5D(&QA;F=U86=E(&-O9&4N"B`@("`@*B\*"B`@("!F=6YC
M=&EO;B!?;6%P*"1L86YG=6%G92D*("`@('L*("`@("`@("!R97%U:7)E7V]N
M8V4@)TAO<F1E+U-T<FEN9RYP:'`G.PH*("`@("`@("`D86QI87-E<R`]("8D
M1TQ/0D%,4ULG;FQS)UU;)V%L:6%S97,G73L*"B`@("`@("`@+R\@5')A;G-L
M871E('1H92`D;&%N9W5A9V4@=&\@9V5T(&)R;V%D97(@;6%T8VAE<RX*("`@
M("`@("`O+R`H96<N(&1E+41%('-H;W5L9"!M871C:"!D95]$12D*("`@("`@
M("`D=')A;G-?;&%N9R`]('-T<E]R97!L86-E*"<M)RP@)U\G+"`D;&%N9W5A
M9V4I.PH@("`@("`@("1L86YG7W!A<G1S(#T@97AP;&]D92@G7R<L("1T<F%N
M<U]L86YG*3L*("`@("`@("`D=')A;G-?;&%N9R`](%-T<FEN9SHZ;&]W97(H
M)&QA;F=?<&%R='-;,%TI.PH@("`@("`@(&EF("AI<W-E="@D;&%N9U]P87)T
M<ULQ72DI('L*("`@("`@("`@("`@)'1R86YS7VQA;F<@+CT@)U\G("X@4W1R
M:6YG.CIU<'!E<B@D;&%N9U]P87)T<ULQ72D["B`@("`@("`@?0H*("`@("`@
M("`O+R!3964@:68@=V4@9V5T(&$@;6%T8V@@9F]R('1H:7,*("`@("`@("!I
M9B`H(65M<'1Y*"1A;&EA<V5S6R1T<F%N<U]L86YG72DI('L*("`@("`@("`@
M("`@<F5T=7)N("1A;&EA<V5S6R1T<F%N<U]L86YG73L*("`@("`@("!]"@H@
M("`@("`@("\O($EF('=E(&=E="!T:&%T(&9A<B!D;W=N+"!T:&4@;&%N9W5A
M9V4@8V%N;F]T(&)E(&9O=6YD+@H@("`@("`@("\O(%)E='5R;B`D=')A;G-?
M;&%N9RX*("`@("`@("!R971U<FX@)'1R86YS7VQA;F<["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('1H92!C:&%R<V5T(&9O<B!T:&4@8W5R<F5N
M="!L86YG=6%G92X*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;W)I
M9VEN86P@($EF('1R=64@<F5T=7)N<R!T:&4@;W)I9VEN86P@8VAA<G-E="!O
M9B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@=')A;G-L
M871I;VXL('1H92!A8W1U86QL>2!U<V5D(&]N92!O=&AE<G=I<V4N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C:&%R86-T97(@<V5T('1H
M870@<VAO=6QD(&)E('5S960@=VET:"!T:&4@8W5R<F5N=`H@("`@("H@("`@
M("`@("`@("`@("`@(&QO8V%L92!S971T:6YG<RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T0VAA<G-E="@D;W)I9VEN86P@/2!F86QS92D*("`@('L*("`@
M("`@("!G;&]B86P@)&QA;F=U86=E+"`D;FQS.PH*("`@("`@("`O*B!'970@
M8V%C:&5D(')E<W5L=',N("HO"B`@("`@("`@)&-A8VAE2V5Y(#T@:6YT=F%L
M*"1O<FEG:6YA;"D["B`@("`@("`@)&-H87)S970@/2!.3%,Z.E]C86-H961#
M:&%R<V5T*"1C86-H94ME>2D["B`@("`@("`@:68@*"%I<U]N=6QL*"1C:&%R
M<V5T*2D@>PH@("`@("`@("`@("!R971U<FX@)&-H87)S970["B`@("`@("`@
M?0H*("`@("`@("!I9B`H)&]R:6=I;F%L*2!["B`@("`@("`@("`@("1C:&%R
M<V5T(#T@96UP='DH)&YL<ULG8VAA<G-E=',G75LD;&%N9W5A9V5=*2`_("=)
M4T\M.#@U.2TQ)R`Z("1N;'-;)V-H87)S971S)UU;)&QA;F=U86=E73L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E
M+T)R;W=S97(N<&AP)SL*("`@("`@("`@("`@)&)R;W=S97(@/2`F0G)O=W-E
M<CHZ<VEN9VQE=&]N*"D["@H@("`@("`@("`@("!I9B`H)&)R;W=S97(M/FAA
M<T9E871U<F4H)W5T9B<I("8F"B`@("`@("`@("`@("`@("`H571I;#HZ97AT
M96YS:6]N17AI<W1S*"=I8V]N=B<I('Q\"B`@("`@("`@("`@("`@("`@571I
M;#HZ97AT96YS:6]N17AI<W1S*"=M8G-T<FEN9R<I*2D@>PH@("`@("`@("`@
M("`@("`@)&-H87)S970@/2`G551&+3@G.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!I9B`H:7-?;G5L;"@D8VAA<G-E="DI('L*("`@("`@
M("`@("`@)&-H87)S970@/2!.3%,Z.F=E=$5X=&5R;F%L0VAA<G-E="@I.PH@
M("`@("`@('T*"B`@("`@("`@3DQ3.CI?8V%C:&5D0VAA<G-E="@D8V%C:&5+
M97DL("1C:&%R<V5T*3L*("`@("`@("!R971U<FX@)&-H87)S970["B`@("!]
M"@H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8W5R<F5N="!C:&%R<V5T
M(&]F('1H92!E;G9I<F]N;65N=`H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@8VAA<F%C=&5R('-E="!T:&%T('-H;W5L9"!B92!U<V5D('=I
M=&@@=&AE(&-U<G)E;G0*("`@("`J("`@("`@("`@("`@("`@("!L;V-A;&4@
M<V5T=&EN9W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$5X=&5R;F%L0VAA
M<G-E="@I"B`@("!["B`@("`@("`@9VQO8F%L("1L86YG=6%G92P@)&YL<SL*
M"B`@("`@("`@+RH@1V5T(&-A8VAE9"!R97-U;'1S+B`J+PH@("`@("`@("1C
M:&%R<V5T(#T@3DQ3.CI?8V%C:&5D0VAA<G-E="@R*3L*("`@("`@("!I9B`H
M(6ES7VYU;&PH)&-H87)S970I*2!["B`@("`@("`@("`@(')E='5R;B`D8VAA
M<G-E=#L*("`@("`@("!]"@H@("`@("`@("1L86YG7V-H87)S970@/2!S971L
M;V-A;&4H3$-?04Q,+"`P*3L*("`@("`@("!I9B`H<W1R<&]S*"1L86YG7V-H
M87)S970L("<[)RD@/3T](&9A;'-E("8F"B`@("`@("`@("`@('-T<G!O<R@D
M;&%N9U]C:&%R<V5T+"`G+R<I(#T]/2!F86QS92D@>PH@("`@("`@("`@("`D
M;&%N9U]C:&%R<V5T(#T@97AP;&]D92@G+B<L("1L86YG7V-H87)S970I.PH@
M("`@("`@("`@("!I9B`H*&-O=6YT*"1L86YG7V-H87)S970I(#T](#(I("8F
M("%E;7!T>2@D;&%N9U]C:&%R<V5T6S%=*2D@>PH@("`@("`@("`@("`@("`@
M3DQ3.CI?8V%C:&5D0VAA<G-E="@R+"`D;&%N9U]C:&%R<V5T6S%=*3L*("`@
M("`@("`@("`@("`@(')E='5R;B`D;&%N9U]C:&%R<V5T6S%=.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@*"%E;7!T>2@D;FQS
M6R=C:&%R<V5T<R==6R1L86YG=6%G95TI*2`_("1N;'-;)V-H87)S971S)UU;
M)&QA;F=U86=E72`Z("=)4T\M.#@U.2TQ)SL*("`@('T*"B`@("`O*BH*("`@
M("`J(%-E=',@;W(@<F5T=7)N<R!T:&4@8VAA<G-E="!U<V5D('5N9&5R(&-E
M<G1A:6X@8V]N9&ET:6]N<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:6YD97@@("!4:&4@
M240@;V8@82!C86-H92!S;&]T+B`P(&9O<B!T:&4@54D@8VAA<G-E="P@,0H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@9F]R('1H92!T<F%N<VQA
M=&EO;B!C:&%R<V5T(&%N9"`R(&9O<B!T:&4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@(&5X=&5R;F%L(&-H87)S970N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1C:&%R<V5T("!)9B!S<&5C:69I960L('1H:7,@8VAA<G-E="!W
M:6QL(&)E('-T;W)E9"!I;B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@(&=I=F5N(&-A8VAE('-L;W0N($]T:&5R=VES92!T:&4@8V]N=&5N
M="!O9B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('-P96-I
M9FEE9"!C86-H92!S;&]T('=I;&P@8F4@<F5T=7)N960N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]C86-H961#:&%R<V5T*"1I;F1E>"P@)&-H87)S970@/2!N
M=6QL*0H@("`@>PH@("`@("`@('-T871I8R`D8V%C:&4["@H@("`@("`@(&EF
M("@A:7-S970H)&-A8VAE*2D@>PH@("`@("`@("`@("`D8V%C:&4@/2!A<G)A
M>2@I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1C:&%R<V5T(#T](&YU;&PI
M('L*("`@("`@("`@("`@<F5T=7)N(&ES<V5T*"1C86-H95LD:6YD97A=*2`_
M("1C86-H95LD:6YD97A=(#H@;G5L;#L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D8V%C:&5;)&EN9&5X72`]("1C:&%R<V5T.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-H87)S970@=&\@
M=7-E(&9O<B!O=71G;VEN9R!E;6%I;',N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!P<F5F97)R960@8VAA<G-E="!F;W(@;W5T9V]I;F<@
M;6%I;',@8F%S960@;VX*("`@("`J("`@("`@("`@("`@("`@("!T:&4@=7-E
M<B=S('!R969E<F5N8V5S(&%N9"!T:&4@8W5R<F5N="!L86YG=6%G92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T16UA:6Q#:&%R<V5T*"D*("`@('L*("`@
M("`@("!G;&]B86P@)'!R969S+"`D;&%N9W5A9V4L("1N;',["@H@("`@("`@
M("1C:&%R<V5T(#T@)'!R969S+3YG971686QU92@G<V5N9&EN9U]C:&%R<V5T
M)RD["B`@("`@("`@:68@*"%E;7!T>2@D8VAA<G-E="DI('L*("`@("`@("`@
M("`@<F5T=7)N("1C:&%R<V5T.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M:7-S970H)&YL<ULG96UA:6QS)UU;)&QA;F=U86=E72D@/R`D;FQS6R=E;6%I
M;',G75LD;&%N9W5A9V5=(#H*("`@("`@("`@("`@("`@*&ES<V5T*"1N;'-;
M)V-H87)S971S)UU;)&QA;F=U86=E72D@/R`D;FQS6R=C:&%R<V5T<R==6R1L
M86YG=6%G95T@.B`G25-/+3@X-3DM,2<I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0VAE8VL@=&\@<V5E(&EF(&-H87)A8W1E<B!S970@:7,@=F%L:60@9F]R
M(&AT;6QS<&5C:6%L8VAA<G,H*2!C86QL<RX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1C:&%R<V5T("!4:&4@8VAA<F%C=&5R('-E="!T;R!C:&5C
M:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@($ES(&-H87)S970@
M=F%L:60@9F]R('1H92!C=7)R96YT('-Y<W1E;3\*("`@("`J+PH@("`@9G5N
M8W1I;VX@8VAE8VM#:&%R<V5T*"1C:&%R<V5T*0H@("`@>PH@("`@("`@('-T
M871I8R`D8VAE8VL["@H@("`@("`@(&EF("AI<U]N=6QL*"1C:&%R<V5T*2!\
M?"!E;7!T>2@D8VAA<G-E="DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1C:&5C:ULD8VAA<G-E
M=%TI*2!["B`@("`@("`@("`@(')E='5R;B`D8VAE8VM;)&-H87)S971=.PH@
M("`@("`@('T@96QS96EF("@A:7-S970H)&-H96-K*2D@>PH@("`@("`@("`@
M("`D8VAE8VL@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@)'9A;&ED
M(#T@=')U93L*"B`@("`@("`@:6YI7W-E="@G=')A8VM?97)R;W)S)RP@,2D[
M"B`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H)R<L($5.5%]#3TU0050L("1C
M:&%R<V5T*3L*("`@("`@("!I9B`H:7-S970H)'!H<%]E<G)O<FUS9RDI('L*
M("`@("`@("`@("`@)'9A;&ED(#T@9F%L<V4["B`@("`@("`@?0H@("`@("`@
M(&EN:5]R97-T;W)E*"=T<F%C:U]E<G)O<G,G*3L*"B`@("`@("`@)&-H96-K
M6R1C:&%R<V5T72`]("1V86QI9#L*"B`@("`@("`@<F5T=7)N("1V86QI9#L*
M("`@('T*"B`@("\J*@H@("`@("H@4V5T<R!T:&4@8VAA<G-E="X*("`@("`J
M($EN(&=E;F5R86PL('1H92!A<'!L:65D(&-H87)S970@:7,@875T;VUA=&EC
M86QL>2!D971E<FUI;F5D(&)Y(&)R;W=S97(*("`@("`J(&QA;F=U86=E(&%N
M9"!B<F]W<V5R(&-A<&%B:6QI=&EE<R!A;F0@=&AE<F4G<R!N;R!N965D('1O
M(&UA;G5A;&QY(&-A;&P*("`@("`J('-E=$-H87)S970N($AO=V5V97(@9F]R
M(&AE861L97-S("A24$,I(&]P97)A=&EO;G,@=&AE(&-H87)S970@;6%Y(&)E
M"B`@("`@*B!S970@;6%N=6%L;'D@=&\@96YS=7)E(&-O<G)E8W0@8VAA<F%C
M=&5R(&-O;G9E<G-I;VX@:6X@=&AE(&)A8VME;F0N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D8VAA<G-E="`@268@<W!E8VEF:65D+"!T:&ES(&-H
M87)S970@=VEL;"!B92!S=&]R960@:6X@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("!G:79E;B!C86-H92!S;&]T+@H@("`@("H*("`@("`J
M($!P87)A;2!I;G1E9V5R("1I;F1E>"`@(%1H92!)1"!O9B!A(&-A8VAE('-L
M;W0N(#`@9F]R('1H92!522!C:&%R<V5T+"`Q"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("!F;W(@=&AE('1R86YS;&%T:6]N(&-H87)S970@86YD
M(#(@9F]R('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@97AT
M97)N86P@8VAA<G-E="X@1&5F875L=',@=&\@,#H@=&AI<R!I<R!T:&4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@(&-H87)S970@<F5T=7)N960@
M8GD@9V5T0VAA<G-E="!A;F0@=7-E9"!F;W(*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@(&-O;G9E<G-I;VXN"B`@("`@*B\*"B`@("!F=6YC=&EO
M;B!S971#:&%R<V5T*"1C:&%R<V5T+"1I;F1E>"`](#`I"B`@("!["B`@("`@
M("`@3DQ3.CI?8V%C:&5D0VAA<G-E="@D:6YD97@L("1C:&%R<V5T*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE(&-U<G)E;G0@=&EM97IO;F4L
M(&EF(&%V86EL86)L92X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T5&EM95IO
M;F4H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<')E9G,["@H@("`@("`@("1T
M>B`]("1P<F5F<RT^9V5T5F%L=64H)W1I;65Z;VYE)RD["B`@("`@("`@:68@
M*"%E;7!T>2@D='HI*2!["B`@("`@("`@("`@($!P=71E;G8H)U1:/2<@+B`D
M='HI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@
M;&]C86QE(&EN9F\@<F5T=7)N960@8GD@;&]C86QE8V]N=B@I+"!B=70@8V%C
M:&4@:70L('1O"B`@("`@*B!A=F]I9"!R97!E871E9"!C86QL<RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@<F5S=6QT<R!O9B!L;V-A;&5C
M;VYV*"DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$QO8V%L94EN9F\H*0H@
M("`@>PH@("`@("`@('-T871I8R`D;&-?:6YF;SL*"B`@("`@("`@:68@*"%I
M<W-E="@D;&-?:6YF;RDI('L*("`@("`@("`@("`@)&QC7VEN9F\@/2!L;V-A
M;&5C;VYV*"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&QC7VEN9F\[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE(&QA;F=U86=E(&EN9F\@
M<F5T=7)N960@8GD@;FQ?;&%N9VEN9F\H*2P@8G5T(&-A8VAE(&ET+"!T;PH@
M("`@("H@879O:60@<F5P96%T960@8V%L;',N"B`@("`@*@H@("`@("H@0'-I
M;F-E($AO<F1E(#,N,0H@("`@("H*("`@("`J($!P87)A;2!C;VYS="`D:71E
M;2`@5&AE(&QA;F=I;F9O(&ET96T@=&\@<F5T=7)N+@H@("`@("H*("`@("`J
M($!R971U<FX@87)R87D@(%1H92!R97-U;'1S(&]F(&YL7VQA;F=I;F9O*"DN
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$QA;F=);F9O*"1I=&5M*0H@("`@
M>PH@("`@("`@('-T871I8R`D;FQ?:6YF;R`](&%R<F%Y*"D["@H@("`@("`@
M(&EF("@A:7-S970H)&YL7VEN9F];)&ET96U=*2D@>PH@("`@("`@("`@("`D
M;FQ?:6YF;ULD:71E;5T@/2!N;%]L86YG:6YF;R@D:71E;2D["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&YL7VEN9F];)&ET96U=.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1V5T(&-O=6YT<GD@:6YF;W)M871I;VX@9G)O;2!A(&AO
M<W1N86UE(&]R($E0(&%D9')E<W,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D:&]S="`@5&AE(&AO<W1N86UE(&]R($E0(&%D9')E<W,N"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@3VX@<W5C8V5S<RP@<F5T=7)N(&%N
M(&%R<F%Y('=I=&@@=&AE(&9O;&QO=VEN9R!E;G1R:65S.@H@("`@("H@("`@
M("`@("`@("`@("`@)V-O9&4G("`]/B`@0V]U;G1R>2!#;V1E"B`@("`@*B`@
M("`@("`@("`@("`@("`G;F%M92<@(#T^("!#;W5N=')Y($YA;64*("`@("`J
M("`@("`@("`@("`@("`@($]N(&9A:6QU<F4L(')E='5R;B!F86QS92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T0V]U;G1R>4)Y2&]S="@D:&]S="D*("`@
M('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@("\J($QI<W0@;V8@
M9V5N97)I8R!D;VUA:6YS('1H870@=V4@:VYO=R!I<R!N;W0@:6X@=&AE(&-O
M=6YT<GD@5$Q$"B`@("`@("`@("`@;&ES="X@4V5E.B!H='1P.B\O=W=W+FEA
M;F$N;W)G+V=T;&0O9W1L9"YH=&T@*B\*("`@("`@("`D9V5N97)I8R`](&%R
M<F%Y*`H@("`@("`@("`@("`G865R;R<L("=B:7HG+"`G8V]M)RP@)V-O;W`G
M+"`G961U)RP@)V=O=B<L("=I;F9O)RP@)VEN="<L("=M:6PG+`H@("`@("`@
M("`@("`G;75S975M)RP@)VYA;64G+"`G;F5T)RP@)V]R9R<L("=P<F\G"B`@
M("`@("`@*3L*"B`@("`@("`@)&-H96-K2&]S="`]("1H;W-T.PH@("`@("`@
M(&EF("AP<F5G7VUA=&-H*"<O7EQD*UPN7&0K7"Y<9"M<+EQD*R0O)RP@)&AO
M<W0I*2!["B`@("`@("`@("`@("1C:&5C:TAO<W0@/2!`9V5T:&]S=&)Y861D
M<B@D:&]S="D["B`@("`@("`@?0H*("`@("`@("`O*B!'970@=&AE(%1,1"!O
M9B!T:&4@:&]S=&YA;64N("HO"B`@("`@("`@)'!O<R`]('-T<G)P;W,H)&-H
M96-K2&]S="P@)RXG*3L*("`@("`@("!I9B`H)'!O<R`]/3T@9F%L<V4I('L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("`D
M9&]M86EN(#T@4W1R:6YG.CIL;W=E<BAS=6)S='(H)&-H96-K2&]S="P@)'!O
M<R`K(#$I*3L*"B`@("`@("`@+RH@5')Y(&QO;VMU<"!V:6$@5$Q$(&9I<G-T
M+B`J+PH@("`@("`@(&EF("@A:6Y?87)R87DH)&1O;6%I;BP@)&=E;F5R:6,I
M*2!["B`@("`@("`@("`@(')E<75I<F4@)TAO<F1E+TY,4R]T;&0N<&AP)SL*
M("`@("`@("`@("`@:68@*&ES<V5T*"1T;&1;)&1O;6%I;ETI*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@87)R87DH)V-O9&4G(#T^("1D;VUA:6XL("=N
M86UE)R`]/B`D=&QD6R1D;VUA:6Y=*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@+RH@5')Y($=E;TE0(&QO;VMU<"!N97AT+B`J+PH@("`@
M("`@(&EF("@A96UP='DH)&-O;F9;)V=E;VEP)UU;)V1A=&%F:6QE)UTI*2![
M"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O3DQ3+T=E;TE0+G!H
M<"<["B`@("`@("`@("`@("1G96]I<"`]("9.3%-?1V5O25`Z.G-I;F=L971O
M;B@D8V]N9ELG9V5O:7`G75LG9&%T869I;&4G72D["B`@("`@("`@("`@("1I
M9"`]("1G96]I<"T^8V]U;G1R>4ED0GE.86UE*"1C:&5C:TAO<W0I.PH@("`@
M("`@("`@("!I9B`H(65M<'1Y*"1I9"DI('L*("`@("`@("`@("`@("`@(')E
M='5R;B!A<G)A>2@G8V]D92<@/3X@4W1R:6YG.CIL;W=E<B@D1TQ/0D%,4ULG
M1T5/25!?0T]53E1265]#3T1%4R==6R1I9%TI+"`G;F%M92<@/3X@)$=,3T)!
M3%-;)T=%3TE07T-/54Y44EE?3D%-15,G75LD:61=*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!A($AO<F1E(&EM86=E(&QI;FL@=&\@=&AE
M(&-O=6YT<GD@9FQA9RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1H
M;W-T("!4:&4@:&]S=&YA;64@;W(@25`@861D<F5S<RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE(&EM86=E(%523"P@;W(@=&AE(&5M<'1Y
M('-T<FEN9R!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5N97)A
M=&5&;&%G26UA9V5">4AO<W0H)&AO<W0I"B`@("!["B`@("`@("`@9VQO8F%L
M("1R96=I<W1R>3L*"B`@("`@("`@)&1A=&$@/2!.3%,Z.F=E=$-O=6YT<GE"
M>4AO<W0H)&AO<W0I.PH@("`@("`@(&EF("@D9&%T82`A/3T@9F%L<V4I('L*
M("`@("`@("`@("`@)&EM9R`]("1D871A6R=C;V1E)UT@+B`G+G!N9R<["B`@
M("`@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D<F5G:7-T<GDM/F=E="@G=&AE
M;65S9G,G+"`G:&]R9&4G*2`N("<O9W)A<&AI8W,O9FQA9W,O)R`N("1I;6<I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@2&]R9&4Z.FEM9R@D:6UG+"`D
M9&%T85LG;F%M92==+"!A<G)A>2@G=&ET;&4G(#T^("1D871A6R=N86UE)UTI
M+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I("X@)R]F;&%G<R<I
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("=;)R`N("1D871A6R=N86UE)UT@+B`G72<["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`G)SL*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@96ET:&5R(&$@<W!E8VEF:6,@;W(@86QL($E33RTS,38V
M(&-O=6YT<GD@;F%M97,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M8V]D92`@5&AE($E33R`S,38V(&-O=6YT<GD@8V]D92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!)9B!A(&-O=6YT<GD@8V]D92!H87,@8F5E;B!R
M97%U97-T960@=VEL;"!R971U<FX@=&AE"B`@("`@*B`@("`@("`@("`@("`@
M("!C;W)R97-P;VYD:6YG(&-O=6YT<GD@;F%M92X@268@96UP='D@=VEL;"!R
M971U<FX@86X*("`@("`J("`@("`@("`@("`@("`@(&%R<F%Y(&]F(&%L;"!T
M:&4@8V]U;G1R>2!C;V1E<R!A;F0@=&AE:7(@;F%M97,N"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9G971#;W5N=')Y25-/*"1C;V1E(#T@)R<I"B`@("!["B`@
M("`@("`@<W1A=&EC("1C;W5N=')I97,@/2!A<G)A>2@I.PH@("`@("`@(&EF
M("AE;7!T>2@D8V]U;G1R:65S*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N
M8V4@)TAO<F1E+TY,4R]C;W5N=')I97,N<&AP)SL*("`@("`@("!]"B`@("`@
M("`@:68@*&5M<'1Y*"1C;V1E*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O
M=6YT<FEE<SL*("`@("`@("!](&5L<V5I9B`H:7-S970H)&-O=6YT<FEE<ULD
M8V]D95TI*2!["B`@("`@("`@("`@(')E='5R;B`D8V]U;G1R:65S6R1C;V1E
M73L*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-R>7!T+G!H<```````
M````````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$R-3<W(#$P
M-3$U-#,S-S0P(#`R,3$W,@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@5&AE($AO<F1E7T-R>7!T.CH@
M8VQA<W,@<')O=FED97,@86X@05!)(&9O<B!V87)I;W5S(&-R>7!T;V=R87!H
M:6,*("H@<WES=&5M<R!U<V5D(&)Y($AO<F1E(&%P<&QI8V%T:6]N<RX*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP+'8@,2XR-RXQ
M,"XY(#(P,#8O,#$O,#$@,C$Z,C@Z,3(@:F%N($5X<"`D"B`J"B`J($-O<'ER
M:6=H="`R,#`R+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O
M<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@
M36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U
M/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?0W)Y
M<'0*("HO"F-L87-S($AO<F1E7T-R>7!T('L*"B`@("`O*BH*("`@("`J(%1H
M92!T96UP;W)A<GD@9&ER96-T;W)Y('1O('5S92X*("`@("`J"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]T96UP9&ER.PH*("`@("\J
M*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E=&4@2&]R9&5?
M0W)Y<'0@:6YS=&%N8V4@8F%S960@;VX@)&1R:79E<BX*("`@("`J"B`@("`@
M*B!`<&%R86T@;6EX960@)&1R:79E<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@
M2&]R9&5?0W)Y<'0@<W5B8VQA<W,@=&\*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!R971U<FXN($EF("1D<FEV97(@:7,@86X@87)R87DL('1H96X@
M=V4@=VEL;"!L;V]K"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@:6X@
M)&1R:79E<ELP72]L:6(O0W)Y<'0O(&9O<B!T:&4@<W5B8VQA<W,*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("!I;7!L96UE;G1A=&EO;B!N86UE9"`D
M9')I=F5R6S%=+G!H<"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!
M(&AA<V@@8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N
M(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<&%R86UE=&5R<R!A
M('-U8F-L87-S(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!(
M;W)D95]#<GEP="`@5&AE(&YE=VQY(&-R96%T960@8V]N8W)E=&4@2&]R9&5?
M0W)Y<'0@:6YS=&%N8V4L(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("!F86QS92!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A
M8W1O<GDH)&1R:79E<BP@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@
M("`@:68@*&ES7V%R<F%Y*"1D<FEV97(I*2!["B`@("`@("`@("`@(&QI<W0H
M)&%P<"P@)&1R:79E<BD@/2`D9')I=F5R.PH@("`@("`@('T*"B`@("`@("`@
M+RH@4F5T=7)N(&$@8F%S92!(;W)D95]#<GEP="!O8FIE8W0@:68@;F\@9')I
M=F5R(&ES('-P96-I9FEE9"X@*B\*("`@("`@("`D9')I=F5R(#T@8F%S96YA
M;64H)&1R:79E<BD["B`@("`@("`@:68@*&5M<'1Y*"1D<FEV97(I('Q\("AS
M=')C;7`H)&1R:79E<BP@)VYO;F4G*2`]/2`P*2D@>PH@("`@("`@("`@("`D
M8W)Y<'0@/2`F;F5W($AO<F1E7T-R>7!T*"D["B`@("`@("`@("`@(')E='5R
M;B`D8W)Y<'0["B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1A<'`I
M*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`D1TQ/0D%,4ULG<F5G:7-T
M<GDG72T^9V5T*"=F:6QE<F]O="<L("1A<'`I("X@)R]L:6(O0W)Y<'0O)R`N
M("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?2!E;'-E:68@*$!F:6QE7V5X
M:7-T<RAD:7)N86UE*%]?1DE,15]?*2`N("<O0W)Y<'0O)R`N("1D<FEV97(@
M+B`G+G!H<"<I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE
M*%]?1DE,15]?*2`N("<O0W)Y<'0O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@0&EN8VQU9&5?;VYC92`G2&]R
M9&4O0W)Y<'0O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?0H@("`@
M("`@("1C;&%S<R`]("=(;W)D95]#<GEP=%\G("X@)&1R:79E<CL*("`@("`@
M("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@)&-R
M>7!T(#T@)FYE=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&-R>7!T(#T@4$5!4CHZ<F%I<V5%<G)O<B@G0VQA<W,@
M9&5F:6YI=&EO;B!O9B`G("X@)&-L87-S("X@)R!N;W0@9F]U;F0N)RD["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&-R>7!T.PH@("`@?0H*("`@("\J
M*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@<F5F97)E;F-E('1O(&$@
M8V]N8W)E=&4@2&]R9&5?0W)Y<'0@:6YS=&%N8V4*("`@("`J(&)A<V5D(&]N
M("1D<FEV97(N($ET('=I;&P@;VYL>2!C<F5A=&4@82!N97<@:6YS=&%N8V4@
M:68@;F\*("`@("`J($AO<F1E7T-R>7!T(&EN<W1A;F-E('=I=&@@=&AE('-A
M;64@<&%R86UE=&5R<R!C=7)R96YT;'D@97AI<W1S+@H@("`@("H*("`@("`J
M(%1H:7,@<VAO=6QD(&)E('5S960@:68@;75L=&EP;&4@8W)Y<'1O(&)A8VME
M;F1S("AA;F0L('1H=7,L"B`@("`@*B!M=6QT:7!L92!(;W)D95]#<GEP="!I
M;G-T86YC97,I(&%R92!R97%U:7)E9"X*("`@("`J"B`@("`@*B!4:&ES(&UE
M=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z("1V87(@/2`F2&]R9&5?0W)Y<'0Z
M.G-I;F=L971O;B@I"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1D<FEV
M97(@(%1H92!T>7!E(&]F(&-O;F-R971E($AO<F1E7T-R>7!T('-U8F-L87-S
M('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N+B!)9B`D
M9')I=F5R(&ES(&%N(&%R<F%Y+"!T:&5N('=E('=I;&P@;&]O:PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@(&EN("1D<FEV97);,%TO;&EB+T-R>7!T
M+R!F;W(@=&AE('-U8F-L87-S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@:6UP;&5M96YT871I;VX@;F%M960@)&1R:79E<ELQ72YP:'`N"B`@("`@
M*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@86YY
M(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!O<@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A('-U8F-L87-S
M(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D95]#<GEP
M="`@5&AE(&-O;F-R971E($AO<F1E7T-R>7!T(')E9F5R96YC92P@;W(@9F%L
M<V4@;VX@86X*("`@("`J("`@("`@("`@("`@("`@("`@("`@(&5R<F]R+@H@
M("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1D<FEV97(L("1P87)A
M;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@('-T871I8R`D:6YS=&%N8V5S
M.PH*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97,I*2!["B`@("`@("`@
M("`@("1I;G-T86YC97,@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@
M)'-I9VYA='5R92`]('-E<FEA;&EZ92AA<G)A>2@D9')I=F5R+"`D<&%R86US
M*2D["B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S6R1S:6=N871U<F5=
M*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S6R1S:6=N871U<F5=(#T@)DAO
M<F1E7T-R>7!T.CIF86-T;W)Y*"1D<FEV97(L("1P87)A;7,I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;)'-I9VYA='5R95T["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!/=71P=71S(&5R<F]R(&UE<W-A9V4@:68@
M=V4@87)E(&YO="!U<VEN9R!A('-E8W5R92!C;VYN96-T:6]N+@H@("`@("H*
M("`@("`J($!R971U<FX@4$5!4E]%<G)O<B`@4F5T=7)N<R!A(%!%05)?17)R
M;W(@;V)J96-T(&EF('1H97)E(&ES(&YO('-E8W5R90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("!C;VYN96-T:6]N+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!R97%U:7)E4V5C=7)E0V]N;F5C=&EO;B@I"B`@("!["B`@("`@("`@9VQO
M8F%L("1B<F]W<V5R.PH*("`@("`@("!I9B`H(21B<F]W<V5R+3YU<VEN9U-3
M3$-O;FYE8W1I;VXH*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BA?*")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@
M<V5C=7)E('=E8B!C;VYN96-T:6]N+B(I*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!%;F-R>7!T('1H92!R97%U97-T960@9&%T82X*("`@
M("`J(%1H:7,@;65T:&]D('-H;W5L9"!B92!P<F]V:61E9"!B>2!A;&P@8VQA
M<W-E<R!T:&%T(&5X=&5N9"!(;W)D95]#<GEP="X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1D871A("`@5&AE(&1A=&$@=&\@96YC<GEP="X*("`@
M("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!;B!A<G)A>2!O9B!A<F=U;65N
M=',@;F5E9&5D('1O(&5N8W)Y<'0@=&AE(&1A=&$N"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@5&AE(&5N8W)Y<'1E9"!D871A+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!E;F-R>7!T*"1D871A+"`D<&%R86US(#T@87)R87DH*2D*
M("`@('L*("`@("`@("!R971U<FX@)&1A=&$["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!$96-R>7!T('1H92!R97%U97-T960@9&%T82X*("`@("`J(%1H:7,@
M;65T:&]D('-H;W5L9"!B92!P<F]V:61E9"!B>2!A;&P@8VQA<W-E<R!T:&%T
M(&5X=&5N9"!(;W)D95]#<GEP="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1D871A("`@5&AE(&1A=&$@=&\@9&5C<GEP="X*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US("!!;B!A<G)A>2!O9B!A<F=U;65N=',@;F5E9&5D
M('1O(&1E8W)Y<'0@=&AE(&1A=&$N"B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>2`@5&AE(&1E8W)Y<'1E9"!D871A+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!D96-R>7!T*"1D871A+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@
M("`@("!R971U<FX@)&1A=&$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A
M=&4@82!T96UP;W)A<GD@9FEL92!T:&%T('=I;&P@8F4@9&5L971E9"!A="!T
M:&4@96YD(&]F('1H:7,*("`@("`J('!R;V-E<W,N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@
M)&1E<V-R:7`@($1E<V-R:7!T:6]N('-T<FEN9R!T;R!U<V4@:6X@9FEL96YA
M;64N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&5L971E("`@1&5L971E('1H
M92!F:6QE(&%U=&]M871I8V%L;'D_"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@($9I;&5N86UE(&]F(&$@=&5M<&]R87)Y(&9I;&4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]C<F5A=&5496UP1FEL92@D9&5S8W)I<"`]("=H;W)D
M92UC<GEP="<L("1D96QE=&4@/2!T<G5E*0H@("`@>PH@("`@("`@(')E='5R
M;B!5=&EL.CIG971496UP1FEL92@D9&5S8W)I<"P@)&1E;&5T92P@)'1H:7,M
M/E]T96UP9&ER+"!T<G5E*3L*("`@('T*"GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+TAO<F1E+T)L;V-K+G!H<```````````````````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#$R-S(W(#$P-3$U-#,S-S0P(#`R,3$R,``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@5&AE(&%B<W1R86-T($AO<F1E7T)L;V-K.CH@8VQA<W,@<F5P<F5S
M96YT<R!A('-I;F=L92!B;&]C:R!W:71H:6X*("H@=&AE($)L;V-K<R!F<F%M
M97=O<FLN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T)L;V-K+T)L;V-K+G!H
M<"QV(#$N,S,N,3`N-2`R,#`V+S`Q+S`Q(#(Q.C(X.C`X(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`
M9W)A9G1O;FAA;&PN8V\N;GH^"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@2F%N
M(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N
M;GH^"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^
M"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]";&]C
M:PH@*B\*8VQA<W,@2&]R9&5?0FQO8VL@>PH*("`@("\J*@H@("`@("H@0FQO
M8VL@<W!E8VEF:6,@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A<F%M<R`](&%R<F%Y*"D["@H@("`@
M+RHJ"B`@("`@*B!!<'!L:6-A=&EO;B!T:&%T('1H:7,@8FQO8VL@;W)I9VEN
M871E9"!F<F]M+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*
M("`@('9A<B`D7V%P<#L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>7QB;V]L96%N("1P87)A;7,@($%N
M>2!P87)A;65T97)S('1H92!B;&]C:R!N965D<RX@268@9F%L<V4L"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@9&5F875L="!P
M87)A;65T97(@=VEL;"!B92!U<V5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!(
M;W)D95]";&]C:R@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!I
M9B`H)'!A<F%M<R`]/3T@9F%L<V4I('L*("`@("`@("`@("`@)'!A<F%M<R`]
M("1T:&ES+3YG971087)A;7,H*3L*("`@("`@("`@("`@9F]R96%C:"`H)'!A
M<F%M<R!A<R`D;F%M92`]/B`D<&%R86TI('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%R86US6R1N86UE72`]("1P87)A;5LG9&5F875L="==.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M
M/E]P87)A;7,@/2`D<&%R86US.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE(&%P<&QI8V%T:6]N('1H870@=&AI<R!B;&]C
M:R!B96QO;F=S('1O+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@87!P;&EC871I;VX@;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M07!P*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]A<'`["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N>2!S971T86)L92!P87)A;65T
M97)S(&9O<B!T:&ES(&)L;V-K+B!4:&ES(&ES(&$*("`@("`J('-T871I8R!M
M971H;V0N($ET(&1O97,@*FYO="H@<F5F97)E;F-E("1T:&ES+3Y?<&%R86US
M.R!T:&%T(&ES"B`@("`@*B!F;W(@<G5N=&EM92!P87)A;65T97)S("AT:&4@
M8VAO:6-E<R!M861E(&9R;VT@=&AE<V4@;W!T:6]N<RDN"B`@("`@*@H@("`@
M("H@0'-T871I8PH@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!B
M;&]C:R=S(&-O;F9I9W5R86)L92!P87)A;65T97)S+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971087)A;7,H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G
M:7-T<GD["@H@("`@("`@("\J(%-W:71C:"!A<'!L:6-A=&EO;B!C;VYT97AT
M<RP@:68@;F5C97-S87)Y+B!2971U<FX@86X@97)R;W(*("`@("`@("`@*B!I
M;6UE9&EA=&5L>2!I9B!P=7-H07!P*"D@9F%I;',N("HO"B`@("`@("`@)&%P
M<%]P=7-H960@/2`D<F5G:7-T<GDM/G!U<VA!<'`H)'1H:7,M/E]A<'`I.PH@
M("`@("`@(&EF("AI<U]A*"1A<'!?<'5S:&5D+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D87!P7W!U<VAE9"T^9V5T365S<V%G92@I
M.PH@("`@("`@('T*"B`@("`@("`@)'!A<F%M<R`]("1T:&ES+3Y?<&%R86US
M*"D["@H@("`@("`@("\J($EF('=E(&-H86YG960@87!P;&EC871I;VX@8V]N
M=&5X="!I;B!T:&4@8V]U<G-E(&]F('1H:7,*("`@("`@("`@*B!C86QL+"!U
M;F1O('1H870@8VAA;F=E(&YO=RX@*B\*("`@("`@("!I9B`H)&%P<%]P=7-H
M960@/3T]('1R=64I('L*("`@("`@("`@("`@)')E9VES=')Y+3YP;W!!<'`H
M*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<&%R86US.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@=&5X="!T;R!G;R!I;B!T:&4@
M=&ET;&4@;V8@=&AI<R!B;&]C:RX*("`@("`J"B`@("`@*B!4:&ES(&9U;F-T
M:6]N(&AA;F1L97,@=&AE(&-H86YG:6YG(&]F(&-U<G)E;G0@87!P;&EC871I
M;VX@87,*("`@("`J(&YE961E9"!S;R!C;V1E(&ES(&5X96-U=&5D(&EN('1H
M92!S8V]P92!O9B!T:&4@87!P;&EC871I;VX@=&AE"B`@("`@*B!B;&]C:R!O
M<FEG:6YA=&5D(&9R;VTN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!B;&]C:R=S('1I=&QE+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714
M:71L92@I"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@
M("`@+RH@4W=I=&-H(&%P<&QI8V%T:6]N(&-O;G1E>'1S+"!I9B!N96-E<W-A
M<GDN(%)E='5R;B!A;B!E<G)O<@H@("`@("`@("`J(&EM;65D:6%T96QY(&EF
M('!U<VA!<'`H*2!F86EL<RX@*B\*("`@("`@("`D87!P7W!U<VAE9"`]("1R
M96=I<W1R>2T^<'5S:$%P<"@D=&AI<RT^7V%P<"D["B`@("`@("`@:68@*&ES
M7V$H)&%P<%]P=7-H960L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1A<'!?<'5S:&5D+3YG971-97-S86=E*"D["B`@("`@("`@?0H*
M("`@("`@("`D=&ET;&4@/2`D=&AI<RT^7W1I=&QE*"D["@H@("`@("`@("\J
M($EF('=E(&-H86YG960@87!P;&EC871I;VX@8V]N=&5X="!I;B!T:&4@8V]U
M<G-E(&]F('1H:7,*("`@("`@("`@*B!C86QL+"!U;F1O('1H870@8VAA;F=E
M(&YO=RX@*B\*("`@("`@("!I9B`H)&%P<%]P=7-H960@/3T]('1R=64I('L*
M("`@("`@("`@("`@)')E9VES=')Y+3YP;W!!<'`H*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D=&ET;&4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!C;VYT96YT(&9O<B!T:&ES(&)L;V-K+@H@("`@("H*("`@
M("`J(%1H:7,@9G5N8W1I;VX@:&%N9&QE<R!T:&4@8VAA;F=I;F<@;V8@8W5R
M<F5N="!A<'!L:6-A=&EO;B!A<PH@("`@("H@;F5E9&5D('-O(&-O9&4@:7,@
M97AE8W5T960@:6X@=&AE('-C;W!E(&]F('1H92!A<'!L:6-A=&EO;B!T:&4*
M("`@("`J(&)L;V-K(&]R:6=I;F%T960@9G)O;2X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(&)L;V-K)W,@8V]N=&5N="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T0V]N=&5N="@I"B`@("!["B`@("`@("`@9VQO8F%L
M("1R96=I<W1R>3L*"B`@("`@("`@+RH@4W=I=&-H(&%P<&QI8V%T:6]N(&-O
M;G1E>'1S+"!I9B!N96-E<W-A<GDN(%)E='5R;B!A;B!E<G)O<@H@("`@("`@
M("`J(&EM;65D:6%T96QY(&EF('!U<VA!<'`H*2!F86EL<RX@*B\*("`@("`@
M("`D87!P7W!U<VAE9"`]("1R96=I<W1R>2T^<'5S:$%P<"@D=&AI<RT^7V%P
M<"D["B`@("`@("`@:68@*&ES7V$H)&%P<%]P=7-H960L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1A<'!?<'5S:&5D+3YG971-97-S
M86=E*"D["B`@("`@("`@?0H*("`@("`@("`D8V]N=&5N="`]("1T:&ES+3Y?
M8V]N=&5N="@I.PH*("`@("`@("`O*B!)9B!W92!C:&%N9V5D(&%P<&QI8V%T
M:6]N(&-O;G1E>'0@:6X@=&AE(&-O=7)S92!O9B!T:&ES"B`@("`@("`@("H@
M8V%L;"P@=6YD;R!T:&%T(&-H86YG92!N;W<N("HO"B`@("`@("`@:68@*"1A
M<'!?<'5S:&5D(#T]/2!T<G5E*2!["B`@("`@("`@("`@("1R96=I<W1R>2T^
M<&]P07!P*"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-O;G1E;G0[
M"B`@("!]"@H@("`@9G5N8W1I;VX@8G5I;&14<F5E*"8D=')E92P@)&EN9&5N
M="`](#`L("1P87)E;G0@/2!N=6QL*0H@("`@>PH@("`@("`@(&=L;V)A;"`D
M<F5G:7-T<GD["@H@("`@("`@("\J(%-W:71C:"!A<'!L:6-A=&EO;B!C;VYT
M97AT<RP@:68@;F5C97-S87)Y+B!2971U<FX@86X@97)R;W(*("`@("`@("`@
M*B!I;6UE9&EA=&5L>2!I9B!P=7-H07!P*"D@9F%I;',N("HO"B`@("`@("`@
M)&%P<%]P=7-H960@/2`D<F5G:7-T<GDM/G!U<VA!<'`H)'1H:7,M/E]A<'`I
M.PH@("`@("`@(&EF("AI<U]A*"1A<'!?<'5S:&5D+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D87!P7W!U<VAE9"T^9V5T365S<V%G
M92@I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]B=6EL9%1R964H)'1R
M964L("1I;F1E;G0L("1P87)E;G0I.PH*("`@("`@("`O*B!)9B!W92!C:&%N
M9V5D(&%P<&QI8V%T:6]N(&-O;G1E>'0@:6X@=&AE(&-O=7)S92!O9B!T:&ES
M"B`@("`@("`@("H@8V%L;"P@=6YD;R!T:&%T(&-H86YG92!N;W<N("HO"B`@
M("`@("`@:68@*"1A<'!?<'5S:&5D(#T]/2!T<G5E*2!["B`@("`@("`@("`@
M("1R96=I<W1R>2T^<&]P07!P*"D["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!T:&4@=&ET;&4@=&\@9V\@:6X@=&AI<R!B;&]C
M:RX*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(&)L;V-K('1I=&QE+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?=&ET;&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G)SL*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('!A<F%M971E<G,@;F5E9&5D
M(&)Y(&)L;V-K+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@(%1H92!B;&]C:R=S('!A<F%M971E<G,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]P87)A;7,H*0H@("`@>PH@("`@("`@(')E
M='5R;B!A<G)A>2@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&ES(&)L;V-K)W,@8V]N=&5N="X*("`@("`J"B`@("`@*B!`86)S=')A8W0*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&)L;V-K)W,@8V]N
M=&5N="X*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;G1E;G0H*0H@("`@>PH@
M("`@("`@(')E='5R;B`G)SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AI<R!B;&]C:R=S(&-O;G1E;G0N"B`@("`@*@H@("`@("H@0&%B<W1R
M86-T"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!B;&]C:R=S
M(&-O;G1E;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]B=6EL9%1R964H)B1T
M<F5E+"`D:6YD96YT(#T@,"P@)'!A<F5N="`](&YU;&PI"B`@("!["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TQ$05`N<&AP````
M````````````````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`U,3,S
M(#$P-3$U-#,S-S0P(#`R,#4W-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@5&AI<R!I<R!A('5T:6QI
M='D@8VQA<W,L(&5V97)Y(&UE=&AO9"!I<R!S=&%T:6,N"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+TQ$05`O3$1!4"YP:'`L=B`Q+C4N,3(N,3`@,C`P-B\P
M,2\P,2`R,3HR.#HR,R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM
M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,BXR"B`J($!P86-K86=E
M($AO<F1E7TQ$05`*("HO"F-L87-S($AO<F1E7TQ$05`@>PH*("`@("\J*@H@
M("`@("H@4F5T=7)N(&$@8F]O;&5A;B!E>'!R97-S:6]N('5S:6YG('1H92!S
M<&5C:69I960@;W!E<F%T;W(N"B`@("`@*@H@("`@("H@0'-T871I8PH@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&QH<R`@5&AE(&%T=')I8G5T92!T
M;R!T97-T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;W`@("!4:&4@;W!E<F%T
M;W(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1R:',@(%1H92!C;VUP87)I<V]N
M('9A;'5E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@3$1!
M4"!S96%R8V@@9G)A9VUE;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&)U:6QD
M0VQA=7-E*"1L:',L("1O<"P@)')H<RD*("`@('L*("`@("`@("!S=VET8V@@
M*"1O<"D@>PH@("`@("`@(&-A<V4@)TQ)2T4G.@H@("`@("`@("`@("!R971U
M<FX@96UP='DH)')H<RD@/PH@("`@("`@("`@("`@("`@<W!R:6YT9B@G*"5S
M/2HI)RP@)&QH<RD@.@H@("`@("`@("`@("`@("`@<W!R:6YT9B@G*"5S/2HE
M<RHI)RP@)&QH<RP@2&]R9&5?3$1!4#HZ<75O=&4H)')H<RDI.PH*("`@("`@
M("!D969A=6QT.@H@("`@("`@("`@("!R971U<FX@<W!R:6YT9B@G*"5S)7,E
M<RDG+"`D;&AS+"`D;W`L($AO<F1E7TQ$05`Z.G%U;W1E*"1R:',I*3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!%<V-A<&4@8VAA<F%C=&5R
M<R!W:71H('-P96-I86P@;65A;FEN9R!I;B!,1$%0('-E87)C:&5S+@H@("`@
M("H*("`@("`J($!S=&%T:6,*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1C;&%U<V4@(%1H92!S=')I;F<@=&\@97-C87!E+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@97-C87!E9"!S=')I;F<N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('%U;W1E*"1C;&%U<V4I"B`@("!["B`@("`@("`@<F5T
M=7)N('-T<E]R97!L86-E*&%R<F%Y*"=<7"<L("`@)R@G+"`@)RDG+"`@)RHG
M+"`@(EPP(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=<
M7#5C)RP@)UPH)RP@)UPI)RP@)UPJ)RP@(EQ<,#`B*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&-L875S92D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!486ME(&%N(&%R<F%Y(&]F($1.(&5L96UE;G1S(&%N9"!P<F]P97)L>2!Q
M=6]T92!I="!A8V-O<F1I;F<@=&\@4D9#"B`@("`@*B`Q-#@U+@H@("`@("H*
M("`@("`J($!S=&%T:6,*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A
M<G1S("!!;B!A<G)A>2!O9B!T=7!L97,@8V]N=&%I;FEN9R!T:&4@871T<FEB
M=71E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!N86UE(&%N9"!T:&%T
M(&%T=')I8G5T92=S('9A;'5E('=H:6-H(&UA:V4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@('5P('1H92!$3BX@17AA;7!L93H*("`@("`J"B`@("`@
M*B`@("`D<&%R=',@/2!A<G)A>2@P(#T^(&%R<F%Y*"=C;B<L("=*;VAN(%-M
M:71H)RDL"B`@("`@*B`@("`@("`@("`@("`@("`@("`Q(#T^(&%R<F%Y*"=D
M8R<L("=E>&%M<&QE)RDL"B`@("`@*B`@("`@("`@("`@("`@("`@("`R(#T^
M(&%R<F%Y*"=D8R<L("=C;VTG*2D["B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!P<F]P97)L>2!Q=6]T960@<W1R:6YG($1.+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!Q=6]T941.*"1P87)T<RD*("`@('L*("`@("`@("`D
M9&X@/2`G)SL*("`@("`@("`D8V]U;G0@/2!C;W5N="@D<&%R=',I.PH@("`@
M("`@(&9O<B`H)&D@/2`P.R`D:2`\("1C;W5N=#L@)&DK*RD@>PH@("`@("`@
M("`@("!I9B`H)&D@/B`P*2!["B`@("`@("`@("`@("`@("`D9&X@+CT@)RPG
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1D;B`N/2`D<&%R='-;)&E=
M6S!=("X@)STG.PH*("`@("`@("`@("`@+R\@4V5E(&EF('=E(&YE960@=&\@
M<75O=&4@=&AE('9A;'5E+@H@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G
M+UY<<WQ<<R1\7'-<<WQ;+"L](EQR7&X\/B,[72\G+"`D<&%R='-;)&E=6S%=
M*2D@>PH@("`@("`@("`@("`@("`@)&1N("X]("<B)R`N('-T<E]R97!L86-E
M*"<B)RP@)UQ<(B<L("1P87)T<ULD:5U;,5TI("X@)R(G.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&1N("X]("1P87)T<ULD:5U;
M,5T["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M9&X["B`@("!]"@I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O261E;G1I='DN<&AP````````````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,S$W-#,@,3`U,34T,S,W-#`@,#(Q
M-C4V`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B!4:&ES(&-L87-S('!R;W9I9&5S(&%N(&EN=&5R9F%C
M92!T;R!A;&P@:61E;G1I=&EE<R!A('5S97(@;6EG:'0@:&%V92X@271S"B`J
M(&UE=&AO9',@=&%K92!C87)E(&]F(&%N>2!S:71E+7-P96-I9FEC(')E<W1R
M:6-T:6]N<R!C;VYF:6=U<F5D(&EN('!R969S+G!H<`H@*B!A;F0@8V]N9BYP
M:'`N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U!R969S+TED96YT:71Y+G!H
M<"QV(#$N,2XR+C(@,C`P-B\P-B\R."`R,#HU,CHU,R!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#$M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R
M9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F%N(%-C:&YE
M:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS+C4*
M("H@0'!A8VMA9V4@2&]R9&5?261E;G1I='D*("HO"F-L87-S($ED96YT:71Y
M('L*"B`@("`O*BH*("`@("`J($%R<F%Y(&-O;G1A:6YI;F<@86QL('1H92!U
M<V5R)W,@:61E;G1I=&EE<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B\*("`@('9A<B`D7VED96YT:71I97,@/2!A<G)A>2@I.PH*("`@("\J
M*@H@("`@("H@02!P;VEN=&5R('1O('1H92!U<V5R)W,@<W1A;F1A<F0@:61E
M;G1I='DN"B`@("`@*B!4:&ES(&]N92!I<R!U<V5D(&)Y('1H92!M971H;V1S
M(')E='5R;FEN9R!V86QU97,@:68@;F\@;W1H97(@;VYE(&ES"B`@("`@*B!S
M<&5C:69I960N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*
M("`@('9A<B`D7V1E9F%U;'0@/2`P.PH*("`@("\J*@H@("`@("H@5&AE('5S
M97(@=VAO<V4@:61E;G1I=&EE<R!T:&5S92!A<F4N"B`@("`@*@H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?=7-E<B`](&YU;&P["@H@
M("`@+RHJ"B`@("`@*B!!<G)A>2!C;VYT86EN:6YG(&%L;"!O9B!T:&4@<')O
M<&5R=&EE<R!I;B!T:&ES(&ED96YT:71Y+@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1?<')O<&5R=&EE<R`](&%R<F%Y*"=I
M9"<L("=F=6QL;F%M92<L("=F<F]M7V%D9'(G*3L*"B`@("`O*BH*("`@("`J
M(%)E9F5R96YC92!T;R!T:&4@<')E9G,@;V)J96-T('1H870@=&AI<R!)9&5N
M=&ET>2!P;VEN=',@=&\N"B`@("`@*@H@("`@("H@0'9A<B!0<F5F<PH@("`@
M("HO"B`@("!V87(@)%]P<F5F<SL*"B`@("`O*BH*("`@("`J(%)E861S(&%L
M;"!T:&4@=7-E<B=S(&ED96YT:71I97,@9G)O;2!T:&4@<')E9G,@;V)J96-T
M(&]R(&)U:6QD<R!A(&YE=PH@("`@("H@:61E;G1I='D@9G)O;2!T:&4@<W1A
M;F1A<F0@=F%L=65S(&=I=F5N(&EN('!R969S+G!H<"X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1U<V5R("!)9B!S<&5C:69I960L('=E(')E860@
M86YO=&AE<B!U<V5R)W,@:61E;G1I=&EE<PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@:6YS=&5A9"!O9B!T:&4@8W5R<F5N="!U<V5R+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!)9&5N=&ET>2@D=7-E<B`](&YU;&PI"B`@("!["B`@
M("`@("`@)'1H:7,M/E]U<V5R(#T@)'5S97(["B`@("`@("`@:68@*"AI<U]N
M=6QL*"1U<V5R*2!\?"`D=7-E<B`]/2!!=71H.CIG971!=71H*"DI("8F"B`@
M("`@("`@("`@(&ES<V5T*"1'3$]"04Q36R=P<F5F<R==*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W!R969S(#T@)B1'3$]"04Q36R=P<F5F<R==.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?<')E9G,@/2`F4')E
M9G,Z.G-I;F=L971O;B@D1TQ/0D%,4ULG8V]N9B==6R=P<F5F<R==6R=D<FEV
M97(G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1'3$]"04Q36R=R96=I<W1R>2==+3YG971!<'`H*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1U<V5R
M+"`G)RP@;G5L;"P@9F%L<V4I.PH@("`@("`@("`@("`D=&AI<RT^7W!R969S
M+3YR971R:65V92@I.PH@("`@("`@('T*"B`@("`@("`@:68@*"$H)'1H:7,M
M/E]I9&5N=&ET:65S(#T@0'5N<V5R:6%L:7IE*"1T:&ES+3Y?<')E9G,M/F=E
M=%9A;'5E*"=I9&5N=&ET:65S)RP@9F%L<V4I*2DI('L*("`@("`@("`@("`@
M+RH@0V]N=F5R="!I9&5N=&ET:65S(&9R;VT@=&AE(&]L9"!F;W)M870N("HO
M"B`@("`@("`@("`@("1T:&ES+3Y?:61E;G1I=&EE<R`]('5N<V5R:6%L:7IE
M*"1T:&ES+3Y?<')E9G,M/F=E=%9A;'5E*"=I9&5N=&ET:65S)RDI.PH@("`@
M("`@('T@96QS96EF("AI<U]A<G)A>2@D=&AI<RT^7VED96YT:71I97,I*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?:61E;G1I=&EE<R`]("1T:&ES+3Y?<')E
M9G,M/F-O;G9E<G1&<F]M1')I=F5R*"1T:&ES+3Y?:61E;G1I=&EE<RP@3DQ3
M.CIG971#:&%R<V5T*"DI.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/G-E
M=$1E9F%U;'0H)'1H:7,M/E]P<F5F<RT^9V5T5F%L=64H)V1E9F%U;'1?:61E
M;G1I='DG*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&$@9&5F
M875L="!I9&5N=&ET>2!I9B!N;VYE(&5X:7-T<R!Y970@86YD('-E=',@=&AE
M('!R969E<F5N8V5S"B`@("`@*B!U<"!I9B!T:&4@:61E;G1I=&EE<R!A<F4@
M;&]C:V5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!I;FET*"D*("`@('L*("`@
M("`@("!I9B`H(6ES7V%R<F%Y*"1T:&ES+3Y?:61E;G1I=&EE<RD@?'P@*&-O
M=6YT*"1T:&ES+3Y?:61E;G1I=&EE<RD@/#T@,"DI('L*("`@("`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/E]P<F]P97)T:65S(&%S("1K97DI('L*("`@("`@
M("`@("`@("`@("1I9&5N=&ET>5LD:V5Y72`]("1T:&ES+3Y?<')E9G,M/F=E
M=%9A;'5E*"1K97DI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AE
M;7!T>2@D:61E;G1I='E;)VED)UTI*2!["B`@("`@("`@("`@("`@("`D:61E
M;G1I='E;)VED)UT@/2!?*")$969A=6QT($ED96YT:71Y(BD["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?:61E;G1I=&EE<R`](&%R<F%Y
M*"1I9&5N=&ET>2D["B`@("`@("`@("`@("1T:&ES+3YV97)I9GDH,"D["B`@
M("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/E]P<F5F<RT^:7-,;V-K960H
M)V1E9F%U;'1?:61E;G1I='DG*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D
M=&AI<RT^7W!R;W!E<G1I97,@87,@)&ME>2D@>PH@("`@("`@("`@("`@("`@
M)'9A;'5E(#T@)'1H:7,M/F=E=%9A;'5E*"1K97DI.PH@("`@("`@("`@("`@
M("`@:68@*&ES7V%R<F%Y*"1V86QU92DI('L*("`@("`@("`@("`@("`@("`@
M("`D=F%L=64@/2!I;7!L;V1E*")<;B(L("1V86QU92D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!R969S+3YS971686QU
M92@D:V5Y+"`D=F%L=64I.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P<F5F
M<RT^<V5T1&ER='DH)&ME>2P@9F%L<V4I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4V%V97,@86QL(&ED96YT:71I
M97,@:6X@=&AE('!R969S(&)A8VME;F0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-A=F4H*0H@("`@>PH@("`@("`@("1I9&5N=&ET:65S(#T@)'1H:7,M/E]I
M9&5N=&ET:65S.PH@("`@("`@(&EF("AI<U]A<G)A>2@D:61E;G1I=&EE<RDI
M('L*("`@("`@("`@("`@)&ED96YT:71I97,@/2`D=&AI<RT^7W!R969S+3YC
M;VYV97)T5&]$<FEV97(H)&ED96YT:71I97,L($Y,4SHZ9V5T0VAA<G-E="@I
M*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?<')E9G,M/G-E=%9A;'5E
M*"=I9&5N=&ET:65S)RP@<V5R:6%L:7IE*"1I9&5N=&ET:65S*2P@9F%L<V4I
M.PH@("`@("`@("1T:&ES+3Y?<')E9G,M/G-E=%9A;'5E*"=D969A=6QT7VED
M96YT:71Y)RP@)'1H:7,M/E]D969A=6QT*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($%D9',@82!N97<@96UP='D@:61E;G1I='D@=&\@=&AE(&%R<F%Y(&]F
M(&ED96YT:71I97,N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4
M:&4@<&]I;G1E<B!T;R!T:&4@8W)E871E9"!I9&5N=&ET>0H@("`@("HO"B`@
M("!F=6YC=&EO;B!A9&0H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:61E;G1I
M=&EE<UM=(#T@87)R87DH*3L*("`@("`@("!R971U<FX@8V]U;G0H)'1H:7,M
M/E]I9&5N=&ET:65S*2`M(#$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO
M=F5S(&%N(&ED96YT:71Y(&9R;VT@=&AE(&%R<F%Y(&]F(&ED96YT:71I97,N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&ED96YT:71Y("!4:&4@
M<&]I;G1E<B!T;R!T:&4@:61E;G1I='D@=&\@8F4@<F5M;W9E9`H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@(%1H92!R96UO=F5D(&ED96YT:71Y"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T92@D:61E;G1I='DI"B`@("!["B`@
M("`@("`@)&1E;&5T960@/2!A<G)A>5]S<&QI8V4H)'1H:7,M/E]I9&5N=&ET
M:65S+"`D:61E;G1I='DL(#$I.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?
M:61E;G1I=&EE<R!A<R`D:60@/3X@)&YU;&PI('L*("`@("`@("`@("`@:68@
M*"1T:&ES+3YS971$969A=6QT*"1I9"DI('L*("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1T:&ES+3YS
M879E*"D["B`@("`@("`@<F5T=7)N("1D96QE=&5D.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!A('!O:6YT97(@=&\@=&AE(&-U<G)E;G0@9&5F
M875L="!I9&5N=&ET>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@
M(%1H92!P;VEN=&5R('1O('1H92!C=7)R96YT(&1E9F%U;'0@:61E;G1I='D*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&5F875L="@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?9&5F875L=#L*("`@('T*"B`@("`O*BH*("`@
M("`J(%-E=',@=&AE(&-U<G)E;G0@9&5F875L="!I9&5N=&ET>2X*("`@("`J
M($EF('1H92!I9&5N=&ET>2!D;V5S;B=T(&5X:7-T+"!T:&4@;VQD(&1E9F%U
M;'0@:61E;G1I='D@<W1A>7,@=&AE('-A;64N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&ED96YT:71Y("!4:&4@<&]I;G1E<B!T;R!T:&4@;F5W
M(&1E9F%U;'0@:61E;G1I='D*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@9F%I;'5R90H@("`@("HO
M"B`@("!F=6YC=&EO;B!S971$969A=6QT*"1I9&5N=&ET>2D*("`@('L*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]I9&5N=&ET:65S6R1I9&5N=&ET>5TI
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?9&5F875L="`]("1I9&5N=&ET>3L*
M("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@82!P<F]P97)T>2!F<F]M(&]N92!O9B!T:&4@
M:61E;G1I=&EE<RX@268@=&AI<R!V86QU92!D;V5S;B=T"B`@("`@*B!E>&ES
M="!O<B!I<R!L;V-K960L('1H92!P<F]P97)T>2!I<R!R971R:65V960@9G)O
M;2!T:&4@<')E9G,@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1K97D@("`@("`@(%1H92!P<F]P97)T>2!T;R!R971R:65V92X*("`@
M("`J($!P87)A;2!I;G1E9V5R("1I9&5N=&ET>2`@5&AE(&ED96YT:71Y('1O
M(')E=')I979E('1H92!P<F]P97)T>2!F<F]M+@H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@(%1H92!V86QU92!O9B!T:&4@<')O<&5R='DN"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=%9A;'5E*"1K97DL("1I9&5N=&ET>2`](&YU
M;&PI"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D:61E;G1I='DI('Q\("%I
M<W-E="@D=&AI<RT^7VED96YT:71I97-;)&ED96YT:71Y72DI('L*("`@("`@
M("`@("`@)&ED96YT:71Y(#T@)'1H:7,M/E]D969A=6QT.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7VED96YT:71I97-;)&ED96YT
M:71Y75LD:V5Y72D@?'P@)'1H:7,M/E]P<F5F<RT^:7-,;V-K960H)&ME>2DI
M('L*("`@("`@("`@("`@)'9A;"`]("1T:&ES+3Y?<')E9G,M/F=E=%9A;'5E
M*"1K97DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1V86P@/2`D
M=&AI<RT^7VED96YT:71I97-;)&ED96YT:71Y75LD:V5Y73L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D=F%L.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!A;B!A<G)A>2!W:71H('1H92!S<&5C:69I960@<')O<&5R='D@
M9G)O;2!A;&P@97AI<W1I;F<*("`@("`J(&ED96YT:71I97,N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("!4:&4@<')O<&5R='D@=&\@<F5T
M<FEE=F4N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&%R<F%Y
M('=I=&@@=&AE('9A;'5E<R!F<F]M(&%L;"!I9&5N=&ET:65S"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=$%L;"@D:V5Y*0H@("`@>PH@("`@("`@("1L:7-T
M(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7VED96YT:71I
M97,@87,@)&ED96YT:71Y(#T^("1N=6QL*2!["B`@("`@("`@("`@("1L:7-T
M6R1I9&5N=&ET>5T@/2`D=&AI<RT^9V5T5F%L=64H)&ME>2P@)&ED96YT:71Y
M*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1L:7-T.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5T<R!A('!R;W!E<G1Y('=I=&@@82!S<&5C:69I960@
M=F%L=64N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("`@("`@
M("!4:&4@<')O<&5R='D@=&\@<V5T"B`@("`@*B!`<&%R86T@;6EX960@)'9A
M;"`@("`@("`@(%1H92!V86QU92!T;R!W:&EC:"!T:&4@<')O<&5R='D@<VAO
M=6QD(&)E('-E=`H@("`@("H@0'!A<F%M(&EN=&5G97(@)&ED96YT:71Y("!4
M:&4@:61E;G1I='D@=&\@<V5T('1H92!P<F]P97)T>2!I;BX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@
M;VX@9F%I;'5R92`H<')O<&5R='D@=V%S(&QO8VME9"D*("`@("`J+PH@("`@
M9G5N8W1I;VX@<V5T5F%L=64H)&ME>2P@)'9A;"P@)&ED96YT:71Y(#T@;G5L
M;"D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1I9&5N=&ET>2DI('L*("`@
M("`@("`@("`@)&ED96YT:71Y(#T@)'1H:7,M/E]D969A=6QT.PH@("`@("`@
M('T*"B`@("`@("`@:68@*"$D=&AI<RT^7W!R969S+3YI<TQO8VME9"@D:V5Y
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VED96YT:71I97-;)&ED96YT:71Y
M75LD:V5Y72`]("1V86P["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1R=64@:68@86QL
M('!R;W!E<G1I97,@87)E(&QO8VME9"!A;F0@=&AE<F5F;W)E(&YO=&AI;F<@
M:6X@=&AE"B`@("`@*B!I9&5N=&ET:65S(&-A;B!B92!C:&%N9V5D+@H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!A;&P@<')O<&5R
M=&EE<R!A<F4@;&]C:V5D+"!F86QS92!O=&AE<G=I<V4*("`@("`J+PH@("`@
M9G5N8W1I;VX@:7-,;V-K960H*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1T
M:&ES+3Y?<')O<&5R=&EE<R!A<R`D:V5Y*2!["B`@("`@("`@("`@(&EF("@A
M)'1H:7,M/E]P<F5F<RT^:7-,;V-K960H)&ME>2DI('L*("`@("`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS('1R=64@:68@=&AE(&=I=F5N(&%D9')E<W,@8F5L;VYG<R!T;R!O;F4@
M;V8@=&AE(&ED96YT:71I97,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D:V5Y("`@(%1H92!I9&5N=&ET>2!K97D@=&\@<V5A<F-H+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=F%L=64@(%1H92!V86QU92!T;R!S96%R8V@@9F]R
M(&EN("1K97DN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E
M(&EF('1H92`D=F%L=64@=V%S(&9O=6YD(&EN("1K97DN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&AA<U9A;'5E*"1K97DL("1V86QU94$I"B`@("!["B`@("`@
M("`@)&QI<W0@/2`D=&AI<RT^9V5T06QL*"1K97DI.PH@("`@("`@(&9O<F5A
M8V@@*"1L:7-T(&%S("1V86QU94(I('L*("`@("`@("`@("`@:68@*'-T<G!O
M<RA3=')I;F<Z.FQO=V5R*"1V86QU94$I+"!3=')I;F<Z.FQO=V5R*"1V86QU
M94(I*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!F86QS
M93L*("`@('T*"B`@("`O*BH*("`@("`J(%9E<FEF:65S(&%N9"!S86YI=&EZ
M97,@86QL(&ED96YT:71Y('!R;W!E<G1I97,N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&ED96YT:71Y("!4:&4@:61E;G1I='D@=&\@=F5R:69Y
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;'QO8FIE8W0@(%1R=64@:68@
M=&AE('!R;W!E<G1I97,@87)E('9A;&ED(&]R(&$@4$5!4E]%<G)O<@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@=VET:"!A;B!E<G)O<B!D97-C<FEP
M=&EO;B!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N('9E<FEF>2@D
M:61E;G1I='D@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)&ED
M96YT:71Y*2D@>PH@("`@("`@("`@("`D:61E;G1I='D@/2`D=&AI<RT^7V1E
M9F%U;'0["B`@("`@("`@?0H*("`@("`@("!I9B`H(21T:&ES+3YG971686QU
M92@G:60G+"`D:61E;G1I='DI*2!["B`@("`@("`@("`@("1T:&ES+3YS9716
M86QU92@G:60G+"!?*")5;FYA;65D(BDL("1I9&5N=&ET>2D["B`@("`@("`@
M?0H*("`@("`@("`O*B!21D,@,C@R,B!;,RXR+C5=(&1O97,@;F]T(&%L;&]W
M('1H92`G7"<@8VAA<F%C=&5R('1O(&)E('5S960@:6X@=&AE"B`@("`@("`@
M("H@<&5R<V]N86P@<&]R=&EO;B!O9B!A;B!E+6UA:6P@<W1R:6YG+B`J+PH@
M("`@("`@(&EF("AS=')P;W,H)'1H:7,M/F=E=%9A;'5E*"=F=6QL;F%M92<L
M("1I9&5N=&ET>2DL("=<7"<I("$]/2!F86QS92D@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")9;W4@8V%N;F]T(&AA=F4@=&AE
M("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+B(I*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1V5N97)A=&5S('1H92!F<F]M(&%D9')E<W,@=&\@=7-E(&9O<B!T:&4@
M9&5F875L="!I9&5N=&ET>2X*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D9G5L;&YA;64@($EN8VQU9&4@=&AE(&9U;&QN86UE(&EN9F]R;6%T:6]N
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9&5F875L="!F
M<F]M(&%D9')E<W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1E9F%U;'1&
M<F]M061D<F5S<R@D9G5L;&YA;64@/2!F86QS92D*("`@('L*("`@("`@("`D
M9G)O;5]A9&1R(#T@)R<["@H@("`@("`@(&EF("@D9G5L;&YA;64I('L*("`@
M("`@("`@("`@)&YA;64@/2`D=&AI<RT^9V5T5F%L=64H)V9U;&QN86UE)RD[
M"B`@("`@("`@("`@(&EF("@A96UP='DH)&YA;64I*2!["B`@("`@("`@("`@
M("`@("`D9G)O;5]A9&1R(#T@)&YA;64@+B`G("<["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@("1A9&1R(#T@)'1H:7,M/F=E=%9A;'5E*"=F
M<F]M7V%D9'(G*3L*("`@("`@("!I9B`H96UP='DH)&%D9'(I*2!["B`@("`@
M("`@("`@("1A9&1R(#T@075T:#HZ9V5T075T:"@I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1F<F]M7V%D9'(@+B`G/"<@+B`D861D<B`N("<^)SL*
M("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(&-O
M;F-R971E($ED96YT:71Y(&EN<W1A;F-E(&)A<V5D(&]N("1T>7!E+@H@("`@
M("H*("`@("`J($!P87)A;2!M:7AE9"`D='EP92`@(%1H92!T>7!E(&]F(&-O
M;F-R971E($ED96YT:71Y('-U8F-L87-S('1O(')E='5R;BX*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@(%1H:7,@:7,@8F%S960@;VX@=&AE('-T;W)A
M9V4@9')I=F5R("@D='EP92DN(%1H90H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@8V]D92!I<R!D>6YA;6EC86QL>2!I;F-L=61E9"X@268@)'1Y<&4@
M:7,@86X@87)R87DL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!T:&5N
M('=E('=I;&P@;&]O:R!I;B`D='EP95LP72]L:6(O261E;G1I='DO(&9O<@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@=&AE('-U8F-L87-S(&EM<&QE
M;65N=&%T:6]N(&YA;65D("1T>7!E6S%=+G!H<"X*("`@("`J($!P87)A;2!S
M=')I;F<@)'5S97(@($EF('-P96-I9FEE9"P@=V4@<F5A9"!A;F]T:&5R('5S
M97(G<R!I9&5N=&ET:65S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!I
M;G-T96%D(&]F('1H92!C=7)R96YT('5S97(N"B`@("`@*@H@("`@("H@0')E
M='5R;B!)9&5N=&ET>2`@5&AE(&YE=VQY(&-R96%T960@8V]N8W)E=&4@261E
M;G1I='D@:6YS=&%N8V4L(&]R(&9A;'-E"B`@("`@*B`@("`@("`@("`@("`@
M("`@("!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O
M<GDH)'1Y<&4@/2`G;F]N92<L("1U<V5R(#T@;G5L;"D*("`@('L*("`@("`@
M("!I9B`H:7-?87)R87DH)'1Y<&4I*2!["B`@("`@("`@("`@("1A<'`@/2`D
M='EP95LP73L*("`@("`@("`@("`@)'1Y<&4@/2`D='EP95LQ73L*("`@("`@
M("!]"@H@("`@("`@("\J(%)E='5R;B!A(&)A<V4@261E;G1I='D@;V)J96-T
M(&EF(&YO(&1R:79E<B!I<R!S<&5C:69I960N("HO"B`@("`@("`@)'1Y<&4@
M/2!B87-E;F%M92@D='EP92D["B`@("`@("`@:68@*&5M<'1Y*"1T>7!E*2!\
M?"`H<W1R8VUP*"1T>7!E+"`G;F]N92<I(#T](#`I*2!["B`@("`@("`@("`@
M("1I;G-T86YC92`]("9N97<@261E;G1I='DH)'5S97(I.PH@("`@("`@("`@
M("`D:6YS=&%N8V4M/FEN:70H*3L*("`@("`@("`@("`@<F5T=7)N("1I;G-T
M86YC93L*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)&%P<"DI('L*
M("`@("`@("`@("`@<F5Q=6ER95]O;F-E("1'3$]"04Q36R=R96=I<W1R>2==
M+3YG970H)V9I;&5R;V]T)RP@)&%P<"D@+B`G+VQI8B])9&5N=&ET>2\G("X@
M)'1Y<&4@+B`G+G!H<"<["B`@("`@("`@?2!E;'-E:68@*$!F:6QE7V5X:7-T
M<RAD:7)N86UE*%]?1DE,15]?*2`N("<O261E;G1I='DO)R`N("1T>7!E("X@
M)RYP:'`G*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?
M7T9)3$5?7RD@+B`G+TED96YT:71Y+R<@+B`D='EP92`N("<N<&AP)SL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!`:6YC;'5D95]O;F-E("=(;W)D
M92])9&5N=&ET>2\G("X@)'1Y<&4@+B`G+G!H<"<["B`@("`@("`@?0H@("`@
M("`@("1C;&%S<R`]("=)9&5N=&ET>5\G("X@)'1Y<&4["B`@("`@("`@:68@
M*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1I;G-T86YC
M92`]("9N97<@)&-L87-S*"1U<V5R*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G0VQA<W,@9&5F:6YI
M=&EO;B!O9B`G("X@)&-L87-S("X@)R!N;W0@9F]U;F0N)RD["B`@("`@("`@
M?0H*("`@("`@("`D:6YS=&%N8V4M/FEN:70H*3L*("`@("`@("!R971U<FX@
M)&EN<W1A;F-E.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@
M<F5T=7)N(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@261E;G1I='D@:6YS
M=&%N8V4@8F%S960@;VX*("`@("`J("1T>7!E+B!)="!W:6QL(&]N;'D@8W)E
M871E(&$@;F5W(&EN<W1A;F-E(&EF(&YO($ED96YT:71Y(&EN<W1A;F-E('=I
M=&@*("`@("`J('1H92!S86UE('!A<F%M971E<G,@8W5R<F5N=&QY(&5X:7-T
M<RX*("`@("`J"B`@("`@*B!4:&ES('-H;W5L9"!B92!U<V5D(&EF(&UU;'1I
M<&QE('1Y<&5S(&]F(&ED96YT:71I97,@*&%N9"P@=&AU<RP*("`@("`J(&UU
M;'1I<&QE($ED96YT:71Y(&EN<W1A;F-E<RD@87)E(')E<75I<F5D+@H@("`@
M("H*("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH@)'9A
M<B`]("9)9&5N=&ET>3HZ<VEN9VQE=&]N*"D*("`@("`J"B`@("`@*B!`<&%R
M86T@;6EX960@)'1Y<&4@("!4:&4@='EP92!O9B!C;VYC<F5T92!)9&5N=&ET
M>2!S=6)C;&%S<R!T;R!R971U<FXN"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("!4:&ES(&ES(&)A<V5D(&]N('1H92!S=&]R86=E(&1R:79E<B`H)'1Y
M<&4I+B!4:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@(&-O9&4@:7,@
M9'EN86UI8V%L;'D@:6YC;'5D960N($EF("1T>7!E(&ES(&%N(&%R<F%Y+`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@=&AE;B!W92!W:6QL(&QO;VL@
M:6X@)'1Y<&5;,%TO;&EB+TED96YT:71Y+R!F;W(*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@('1H92!S=6)C;&%S<R!I;7!L96UE;G1A=&EO;B!N86UE
M9"`D='EP95LQ72YP:'`N"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R("!)
M9B!S<&5C:69I960L('=E(')E860@86YO=&AE<B!U<V5R)W,@:61E;G1I=&EE
M<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@:6YS=&5A9"!O9B!T:&4@
M8W5R<F5N="!U<V5R+@H@("`@("H*("`@("`J($!R971U<FX@261E;G1I='D@
M(%1H92!C;VYC<F5T92!)9&5N=&ET>2!R969E<F5N8V4L(&]R(&9A;'-E(&]N
M(&%N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1T
M>7!E(#T@)VYO;F4G+"`D=7-E<B`](&YU;&PI"B`@("!["B`@("`@("`@<W1A
M=&EC("1I;G-T86YC97,["B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S
M*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S(#T@87)R87DH*3L*("`@("`@
M("!]"@H@("`@("`@("1S:6=N871U<F4@/2!S97)I86QI>F4H87)R87DH)'1Y
M<&4L("1U<V5R*2D["B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S6R1S
M:6=N871U<F5=*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S6R1S:6=N871U
M<F5=(#T@)DED96YT:71Y.CIF86-T;W)Y*"1T>7!E+"`D=7-E<BD["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&EN<W1A;F-E<ULD<VEG;F%T=7)E73L*
M("`@('T*"GT*``````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4V5S<VEO;D]B:F5C=',N<&AP
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,34U,C8@,3`U,34T
M,S,W-#`@,#(S,#(S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B!4:&4@2&]R9&5?4V5S<VEO;D]B:F5C
M=',Z.B!C;&%S<R!P<F]V:61E<R!A('=A>2!F;W(@<W1O<FEN9R!D871A"B`J
M("AU<W5A;&QY+"!B=70@;F]T(&YE8V5S<V%R:6QY+"!O8FIE8W1S*2!I;B!T
M:&4@8W5R<F5N="!U<V5R)W,*("H@<V5S<VEO;BX*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO4V5S<VEO;D]B:F5C=',O4V5S<VEO;D]B:F5C=',N<&AP+'8@
M,2XV+C$R+C@@,C`P-B\P,2\P,2`R,3HR.#HS-2!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#(P,#,M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO
M<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W5Q"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(
M86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@
M,2XS"B`J($!P86-K86=E($AO<F1E7U-E<W-I;VY/8FIE8W1S"B`J+PIC;&%S
M<R!(;W)D95]397-S:6]N3V)J96-T<R!["@H@("`@+RHJ"B`@("`@*B!4:&4@
M;&ES="!O9B!O:61S('1O('!R=6YE(&%T('1H92!E;F0@;V8@82!R97%U97-T
M+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?
M<')U;F5,:7-T(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%1H92!N86UE(&]F
M('1H92!S=&]R92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO
M"B`@("!V87(@)%]N86UE(#T@)VAO<F1E7W-E<W-I;VY?;V)J96-T<R<["@H@
M("`@+RHJ"B`@("`@*B!!;&QO=R!S=&]R92@I('1O(&]V97)W<FET92!C=7)R
M96YT(&]B:F5C=',_"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@
M*B\*("`@('9A<B`D7V]V97)W<FET92`](&9A;'-E.PH*("`@("\J*@H@("`@
M("H@5&AE(&UA>&EM=6T@;G5M8F5R(&]F(&]B:F5C=',@=&AA="!T:&4@<W1O
M<F4@<VAO=6QD(&AO;&0N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@
M("`@*B\*("`@('9A<B`D7W-I>F4@/2`R,#L*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@82!R969E<F5N8V4@=&\@=&AE(&=L;V)A;"!(;W)D95]397-S:6]N
M3V)J96-T<R!O8FIE8W0L"B`@("`@*B!O;FQY(&-R96%T:6YG(&ET(&EF(&ET
M(&1O97-N)W0@86QR96%D>2!E>&ES="X*("`@("`J"B`@("`@*B!4:&ES(&UE
M=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z"B`@("`@*B`@("1O8FIE8W1S=&]R
M92`]("9(;W)D95]397-S:6]N3V)J96-T<SHZ<VEN9VQE=&]N*"D["B`@("`@
M*@H@("`@("H@0')E='5R;B!(;W)D95]397-S:6]N3V)J96-T<R`@5&AE($AO
M<F1E7U-E<W-I;VY/8FIE8W1S(&EN<W1A;F-E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B`F<VEN9VQE=&]N*"D*("`@('L*("`@("`@("!S=&%T:6,@)&]B:F5C
M=#L*"B`@("`@("`@:68@*"%I<W-E="@D;V)J96-T*2D@>PH@("`@("`@("`@
M("`D;V)J96-T(#T@;F5W($AO<F1E7U-E<W-I;VY/8FIE8W1S*"D["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&]B:F5C=#L*("`@('T*"B`@("`O*BH*
M("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A
M>2`D<&%R86US("!4:&4@<&%R86UE=&5R(&%R<F%Y+@H@("`@("H@/'!R93X*
M("`@("`J($]P=&EO;F%L(%!A<F%M971E<G,Z"B`@("`@*B`G;F%M92<@("TM
M("!4:&4@;F%M92!O9B!T:&4@<V5S<VEO;B!V87)I86)L92!T;R!S=&]R92!T
M:&4@;V)J96-T<R!I;BX*("`@("`J("=S:7IE)R`@+2T@(%1H92!M87AI;75M
M('-I>F4@;V8@=&AE("AN;VXM<')U;F%B;&4I(&]B:F5C="!S=&]R92X*("`@
M("`J(#PO<')E/@H@("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]397-S:6]N
M3V)J96-T<R@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H
M:7-S970H)'!A<F%M<ULG;F%M92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7VYA;64@/2`D<&%R86US6R=N86UE)UT["B`@("`@("`@?0H*("`@("`@("!I
M9B`H:7-S970H)'!A<F%M<ULG<VEZ92==*2`F)B!I<U]I;G0H)'!A<F%M<ULG
M<VEZ92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W-I>F4@/2`D<&%R86US
M6R=S:7IE)UT["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@5W)A
M<'!E<B!A<F]U;F0@<W1O<F4@=&AA="!W:6QL(')E='5R;B!T:&4@;VED(&EN
M<W1E860N"B`@("`@*@H@("`@("H@0'-E92!S=&]R90H@("`@("H*("`@("`J
M($!P87)A;2!M:7AE9"`D9&%T82`@("`@5&AE(&1A=&$@=&\@<W1O<F4@:6X@
M=&AE('-E<W-I;VX@<W1O<F4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<')U
M;F4@($EF(&9A;'-E+"!T:&ES(&]B:F5C="!W:6QL(&YO="!B92!P<G5N960@
M9G)O;2!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@<W1O<F4@
M:68@=&AE(&UA>&EM=6T@<W1O<F4@<VEZ92!I<R!E>&-E961E9"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($U$-2!S=')I;F<@<F5P<F5S
M96YT:6YG('1H92!O8FIE8W0G<R!)1"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<W1O<F5/:60H)&1A=&$L("1P<G5N92`]('1R=64I"B`@("!["B`@("`@("`@
M)&]I9"`]("1T:&ES+3YO:60H)&1A=&$I.PH@("`@("`@("1T:&ES+3YS=&]R
M92@D;VED+"`D9&%T82P@)'!R=6YE*3L*("`@("`@("!R971U<FX@)&]I9#L*
M("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O('-T;W)E(&%N(&]B
M:F5C="!I;B!T:&4@<V5S<VEO;B!S=&]R92X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1O:60@("`@($]B:F5C="!)1"!U<V5D(&%S('1H92!S=&]R
M86=E(&ME>2X*("`@("`J($!P87)A;2!M:7AE9"`D9&%T82`@("`@5&AE(&1A
M=&$@=&\@<W1O<F4@:6X@=&AE('-E<W-I;VX@<W1O<F4N"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D<')U;F4@($EF(&9A;'-E+"!T:&ES(&]B:F5C="!W:6QL
M(&YO="!B92!P<G5N960@9G)O;2!T:&4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@<W1O<F4@:68@=&AE(&UA>&EM=6T@<W1O<F4@<VEZ92!I<R!E
M>&-E961E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@
M;VX@<W5C8V5S<RP@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<W1O<F4H)&]I9"P@)&1A=&$L("1P<G5N92`]('1R=64I"B`@("![
M"B`@("`@("`@+RH@4V5T('5P(&]B:F5C="!N;W<N("HO"B`@("`@("`@)&1A
M=&%/8FIE8W0@/2!A<G)A>2@I.PH@("`@("`@("1D871A3V)J96-T6R=D871A
M)UT@/2!S97)I86QI>F4H)&1A=&$I.PH@("`@("`@("1D871A3V)J96-T6R=P
M<G5N92==(#T@)'!R=6YE.PH*("`@("`@("!I9B`H(6ES<V5T*"1?4T534TE/
M3ELD=&AI<RT^7VYA;65=*2D@>PH@("`@("`@("`@("`D7U-%4U-)3TY;)'1H
M:7,M/E]N86UE72`](&%R<F%Y*"D["B`@("`@("`@("`@("1?4T534TE/3ELD
M=&AI<RT^7VYA;65=6R=?7W!R=6YE)UT@/2`P.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"1T:&ES+3Y?;W9E<G=R:71E('Q\("%I<W-E="@D7U-%4U-)3TY;
M)'1H:7,M/E]N86UE75LD;VED72DI('L*("`@("`@("`@("`@)%]315-324].
M6R1T:&ES+3Y?;F%M95U;)&]I9%T@/2`D9&%T84]B:F5C=#L*("`@("`@("`@
M("`@:68@*"1P<G5N92D@>PH@("`@("`@("`@("`@("`@)%]315-324].6R1T
M:&ES+3Y?;F%M95U;)U]?<')U;F4G72LK.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("`O*B!#:&5C:R!F;W(@<')U;F%B;&4@3VED<RX@*B\*
M("`@("`@("`D=&AI<RT^7W!R=6YE3VED<R@I.PH*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($]V97)W<FET97,@82!C=7)R
M96YT(&5L96UE;G0@:6X@=&AE(&]B:F5C="!S=&]R92X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1O:60@("`@($]B:F5C="!)1"!U<V5D(&%S('1H
M92!S=&]R86=E(&ME>2X*("`@("`J($!P87)A;2!M:7AE9"`D9&%T82`@("`@
M5&AE(&1A=&$@=&\@<W1O<F4@:6X@=&AE('-E<W-I;VX@<W1O<F4N"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D<')U;F4@($EF(&9A;'-E+"!T:&ES(&]B:F5C
M="!W:6QL(&YO="!B92!P<G5N960@9G)O;2!T:&4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@<W1O<F4@:68@=&AE(&UA>&EM=6T@<W1O<F4@<VEZ
M92!I<R!E>&-E961E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@;W9E<G=R:71E*"1O:60L("1D871A+"`D<')U;F4@/2!T
M<G5E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;W9E<G=R:71E(#T@=')U93L*
M("`@("`@("`D<W5C8V5S<R`]("1T:&ES+3YS=&]R92@D;VED+"`D9&%T82P@
M)'!R=6YE*3L*("`@("`@("`D=&AI<RT^7V]V97)W<FET92`](&9A;'-E.PH@
M("`@("`@(')E='5R;B`D<W5C8V5S<SL*("`@('T*"B`@("`O*BH*("`@("`J
M($%T=&5M<'1S('1O(')E=')I=F4@86X@;V)J96-T(&9R;VT@=&AE('-T;W)E
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&]I9"`@($]B:F5C="!)
M1"!T;R!Q=65R>2X*("`@("`J($!P87)A;2!E;G5M("1T>7!E("`@($Y/5"!5
M4T5$"B`@("`@*B!`<&%R86T@:6YT96=E<B`D=F%L("!.3U0@55-%1`H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!R97%U97-T960@;V)J96-T
M+"!O<B!F86QS92!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F
M<75E<GDH)&]I9"P@)'1Y<&4@/2!N=6QL+"`D=F%L(#T@;G5L;"D*("`@('L*
M("`@("`@("!I9B`H(6ES<V5T*"1?4T534TE/3ELD=&AI<RT^7VYA;65=*2!\
M?`H@("`@("`@("`@("`H:7-?;G5L;"@D;VED*2!\?"`A:7-S970H)%]315-3
M24].6R1T:&ES+3Y?;F%M95U;)&]I9%TI*2D@>PH@("`@("`@("`@("`D;V)J
M96-T(#T@9F%L<V4["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&]B
M:F5C="`]('5N<V5R:6%L:7IE*"1?4T534TE/3ELD=&AI<RT^7VYA;65=6R1O
M:61=6R=D871A)UTI.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&]B:F5C
M=#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE('!R=6YE(&9L86<@
M;VX@82!S=&]R92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;VED("`@("!4:&4@;V)J96-T($E$+@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)'!R=6YE("!4<G5E('1O(&%L;&]W('!R=6YI;F<L(&9A;'-E(&9O<B!N
M;R!P<G5N:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!S9710<G5N949L86<H
M)&]I9"P@)'!R=6YE*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D7U-%4U-)
M3TY;)'1H:7,M/E]N86UE75LD;VED72D@)B8*("`@("`@("`@("`@*"1?4T53
M4TE/3ELD=&AI<RT^7VYA;65=6R1O:61=6R=P<G5N92==("$]("1P<G5N92DI
M('L*("`@("`@("`@("`@)%]315-324].6R1T:&ES+3Y?;F%M95U;)&]I9%U;
M)W!R=6YE)UT@/2`D<')U;F4["B`@("`@("`@("`@(&EF("@D<')U;F4I('L*
M("`@("`@("`@("`@("`@("1?4T534TE/3ELD=&AI<RT^7VYA;65=6R=?7W!R
M=6YE)UTK*SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1?4T534TE/3ELD=&AI<RT^7VYA;65=6R=?7W!R=6YE)UTM+3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=E;F5R
M871E<R!A;B!/240@9F]R(&%N(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R
M86T@;6EX960@)&1A=&$@(%1H92!D871A('1O('-T;W)E(&EN('1H92!S=&]R
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`D;VED("!!;B!O8FIE
M8W0@240@=&\@=7-E(&%S('1H92!S=&]R86=E(&ME>2X*("`@("`J+PH@("`@
M9G5N8W1I;VX@;VED*"1D871A*0H@("`@>PH@("`@("`@(')E='5R;B!M9#4H
M<V5R:6%L:7IE*"1D871A*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE
M<F%T92!T:&4@;&ES="!O9B!P<G5N86)L92!O:61S+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?<')U;F5/
M:61S*"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^7W!R=6YE
M3&ES="D@)B8*("`@("`@("`@("`@:7-S970H)%]315-324].6R1T:&ES+3Y?
M;F%M95U;)U]?<')U;F4G72D@)B8*("`@("`@("`@("`@*"1?4T534TE/3ELD
M=&AI<RT^7VYA;65=6R=?7W!R=6YE)UT@/B`D=&AI<RT^7W-I>F4I*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?<')U;F5,:7-T(#T@87)R87DH*3L*("`@("`@
M("`@("`@9F]R96%C:"`H)%]315-324].6R1T:&ES+3Y?;F%M95T@87,@)&ME
M>2`]/B`D=F%L*2!["B`@("`@("`@("`@("`@("!I9B`H)'9A;%LG<')U;F4G
M72D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<')U;F5,:7-T6UT@
M/2`D:V5Y.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@("`@(')E9VES=&5R7W-H=71D;W=N7V9U;F-T:6]N*&%R<F%Y*"8D=&AI
M<RP@)U]P<G5N92<I*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!0<G5N92!O;&0@<W1O<F4@96YT<FEE<R!A="!R97%U97-T('-H=71D;W=N
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F
M=6YC=&EO;B!?<')U;F4H*0H@("`@>PH@("`@("`@("1P<G5N94]I9',@/2!A
M<G)A>5]S;&EC92@D=&AI<RT^7W!R=6YE3&ES="P@,"P@)%]315-324].6R1T
M:&ES+3Y?;F%M95U;)U]?<')U;F4G72`M("1T:&ES+3Y?<VEZ92D["B`@("`@
M("`@9F]R96%C:"`H)'!R=6YE3VED<R!A<R`D=F%L*2!["B`@("`@("`@("`@
M('5N<V5T*"1?4T534TE/3ELD=&AI<RT^7VYA;65=6R1V86Q=*3L*("`@("`@
M("!]"B`@("`@("`@)%]315-324].6R1T:&ES+3Y?;F%M95U;)U]?<')U;F4G
M72`M/2!C;W5N="@D<')U;F5/:61S*3L*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O0G)O=W-E<BYP:'``````````````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`Q,3`V,#8@,3`U,34T,S,W-#`@,#(Q-3`T`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"@IR97%U:7)E7V]N8V4@)TAO<F1E+U-T<FEN9RYP:'`G.PH*+RHJ"B`J(%1H
M92!"<F]W<V5R.CH@8VQA<W,@<')O=FED97,@8V%P86)I;&ET>2!I;F9O<FUA
M=&EO;B!F;W(@=&AE(&-U<G)E;G0*("H@=V5B(&-L:65N="X*("H*("H@0G)O
M=W-E<B!I9&5N=&EF:6-A=&EO;B!I<R!P97)F;W)M960@8GD@97AA;6EN:6YG
M('1H92!(5%107U5315)?04=%3E0*("H@96YV:7)O;FUE;G0@=F%R:6%B;&4@
M<')O=FED960@8GD@=&AE('=E8B!S97)V97(N"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`L=B`Q+C$U,RXR+C0W(#(P,#8O
M,#<O,3<@,#DZ-3(Z,#`@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY
M+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O
M<'ER:6=H="`Q.3DY+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\
M8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("!*;VX@4&%R:7-E(#QJ;VY`
M:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@
M2&]R9&5?0G)O=W-E<@H@*B\*8VQA<W,@0G)O=W-E<B!["@H@("`@+RHJ"B`@
M("`@*B!-86IO<B!V97)S:6]N(&YU;6)E<BX*("`@("`J"B`@("`@*B!`=F%R
M(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?;6%J;W)697)S:6]N(#T@,#L*
M"B`@("`O*BH*("`@("`J($UI;F]R('9E<G-I;VX@;G5M8F5R+@H@("`@("H*
M("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]M:6YO<E9E
M<G-I;VX@/2`P.PH*("`@("\J*@H@("`@("H@0G)O=W-E<B!N86UE+@H@("`@
M("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V)R;W=S
M97(@/2`G)SL*"B`@("`O*BH*("`@("`J($9U;&P@=7-E<B!A9V5N="!S=')I
M;F<N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?86=E;G0@/2`G)SL*"B`@("`O*BH*("`@("`J($QO=V5R+6-A<V4@=7-E
M<B!A9V5N="!S=')I;F<N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@
M("`J+PH@("`@=F%R("1?;&]W97)!9V5N="`]("<G.PH*("`@("\J*@H@("`@
M("H@2%144%]!0T-%4%0@<W1R:6YG"B`@("`@*@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1?86-C97!T(#T@)R<["@H@("`@+RHJ"B`@
M("`@*B!0;&%T9F]R;2!T:&4@8G)O=W-E<B!I<R!R=6YN:6YG(&]N+@H@("`@
M("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W!L871F
M;W)M(#T@)R<["@H@("`@+RHJ"B`@("`@*B!+;F]W;B!R;V)O=',N"B`@("`@
M*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]R;V)O=',@
M/2!A<G)A>2@*("`@("`@("`O*B!4:&4@;6]S="!C;VUM;VX@;VYE<RX@*B\*
M("`@("`@("`G1V]O9VQE8F]T)RP*("`@("`@("`G;7-N8F]T)RP*("`@("`@
M("`G4VQU<G`G+`H@("`@("`@("=986AO;R<L"B`@("`@("`@+RH@5&AE(')E
M<W0@86QP:&%B971I8V%L;'DN("HO"B`@("`@("`@)V%P<&EE)RP*("`@("`@
M("`G07)A8VAN;VED96$G+`H@("`@("`@("=!<F-H:71E>'13<&ED97(G+`H@
M("`@("`@("=!<VL@2F5E=F5S)RP*("`@("`@("`G0BUL+6DM="UZ+4)O="<L
M"B`@("`@("`@)T)A:61U<W!I9&5R)RP*("`@("`@("`G0F5C;VUE0F]T)RP*
M("`@("`@("`G8V9E=&-H)RP*("`@("`@("`G0V]N=F5R84-R87=L97(G+`H@
M("`@("`@("=%>'1R86-T;W)0<F\G+`H@("`@("`@("=&05-4+5=E8D-R87=L
M97(G+`H@("`@("`@("=&1%-%(')O8F]T)RP*("`@("`@("`G9FED;R<L"B`@
M("`@("`@)V9I;F1L:6YK<R<L"B`@("`@("`@)T9R86YC:7,G+`H@("`@("`@
M("=G96-K;V)O="<L"B`@("`@("`@)T=I9V%B;W0G+`H@("`@("`@("=':7)A
M9F%B;W0G+`H@("`@("`@("=G<G5B+6-L:65N="<L"B`@("`@("`@)T=U;&QI
M=F5R)RP*("`@("`@("`G2%14<F%C:R<L"B`@("`@("`@)VEA7V%R8VAI=F5R
M)RP*("`@("`@("`G:4-#<F%W;&5R)RP*("`@("`@("`G26YF;U-E96LG+`H@
M("`@("`@("=K:6YJ86)O="<L"B`@("`@("`@)TM)5"U&:7)E8F%L;"<L"B`@
M("`@("`@)VQA<F)I;B<L"B`@("`@("`@)TQ%24$G+`H@("`@("`@("=L;7-P
M:61E<B<L"B`@("`@("`@)VQW<"UT<FEV:6%L)RP*("`@("`@("`G3'EC;W-?
M4W!I9&5R)RP*("`@("`@("`G365D:6%P87)T;F5R<RU';V]G;&4G+`H@("`@
M("`@("=-=7-C871&97)R970G+`H@("`@("`@("=.879E<D)O="<L"B`@("`@
M("`@)T]M;FE%>'!L;W)E<E]";W0G+`H@("`@("`@("=P;VQY8F]T)RP*("`@
M("`@("`G4&]M<&]S)RP*("`@("`@("`G4G5F=7-";W0G+`H@("`@("`@("=3
M8V]O=&5R)RP*("`@("`@("`G4V5E:V)O="<L"B`@("`@("`@)W-P<F]O<V4G
M+`H@("`@("`@("=496]M82<L"B`@("`@("`@)U1H95-U0F]T)RP*("`@("`@
M("`G5'5R;FET:6Y";W0G+`H@("`@("`@("=5;'1R87-E96LG+`H@("`@("`@
M("=6:6]L84)O="<L"B`@("`@("`@)W9O>6%G97(G+`H@("`@("`@("=W96)B
M86YD:70G+`H@("`@("`@("=W=W<N86QM861E;BYI8FTN8V]M+V-S+V-R87=L
M97(G+`H@("`@("`@("=Y86-Y)RP*("`@("`@("`G6GE";W)G)RP*("`@("D[
M"@H@("`@+RHJ"B`@("`@*B!)<R!T:&ES(&$@;6]B:6QE(&)R;W=S97(_"B`@
M("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7VUO
M8FEL92`](&9A;'-E.PH*("`@("\J*@H@("`@("H@1F5A='5R97,N"B`@("`@
M*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]F96%T=7)E
M<R`](&%R<F%Y*`H@("`@("`@("=H=&UL)R`@("`@("`]/B!T<G5E+`H@("`@
M("`@("=H9&UL)R`@("`@("`]/B!F86QS92P*("`@("`@("`G=VUL)R`@("`@
M("`@/3X@9F%L<V4L"B`@("`@("`@)VEM86=E<R<@("`@(#T^('1R=64L"B`@
M("`@("`@)VEF<F%M97,G("`@(#T^(&9A;'-E+`H@("`@("`@("=F<F%M97,G
M("`@("`]/B!T<G5E+`H@("`@("`@("=T86)L97,G("`@("`]/B!T<G5E+`H@
M("`@("`@("=J879A)R`@("`@("`]/B!T<G5E+`H@("`@("`@("=J879A<V-R
M:7!T)R`]/B!T<G5E+`H@("`@("`@("=D;VTG("`@("`@("`]/B!F86QS92P*
M("`@("`@("`G=71F)R`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@)W)T92<@
M("`@("`@(#T^(&9A;'-E+`H@("`@("`@("=H;VUE<&%G92<@("`]/B!F86QS
M92P*("`@("`@("`G86-C97-S:V5Y)R`@/3X@9F%L<V4L"B`@("`@("`@)V]P
M=&=R;W5P)R`@(#T^(&9A;'-E+`H@("`@("`@("=X;6QH='1P<F5Q)R`]/B!F
M86QS92P*("`@("`@("`G8VET92<@("`@("`@/3X@9F%L<V4L"B`@("`I.PH*
M("`@("\J*@H@("`@("H@475I<FMS"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)%]Q=6ER:W,@/2!A<G)A>2@*("`@("`@("`G
M879O:61?<&]P=7!?=VEN9&]W<R<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@
M("=B<F5A:U]D:7-P;W-I=&EO;E]H96%D97(G("`@/3X@9F%L<V4L"B`@("`@
M("`@)V)R96%K7V1I<W!O<VET:6]N7V9I;&5N86UE)R`]/B!F86QS92P*("`@
M("`@("`G8G)O:V5N7VUU;'1I<&%R=%]F;W)M)R`@("`@(#T^(&9A;'-E+`H@
M("`@("`@("=B=6=G>5]C;VUP<F5S<VEO;B<@("`@("`@("`@/3X@9F%L<V4L
M"B`@("`@("`@)V-A8VAE7W-A;65?=7)L)R`@("`@("`@("`@("`]/B!F86QS
M92P*("`@("`@("`G8V%C:&5?<W-L7V1O=VYL;V%D<R<@("`@("`@(#T^(&9A
M;'-E+`H@("`@("`@("=D;W5B;&5?;&EN96)R96%K7W1E>'1A<F5A)R`@/3X@
M9F%L<V4L"B`@("`@("`@)V5M<'1Y7V9I;&5?:6YP=71?=F%L=64G("`@("`]
M/B!F86QS92P*("`@("`@("`G;75S=%]C86-H95]F;W)M<R<@("`@("`@("`@
M(#T^(&9A;'-E+`H@("`@("`@("=N;U]F:6QE;F%M95]S<&%C97,G("`@("`@
M("`@/3X@9F%L<V4L"B`@("`@("`@)VYO7VAI9&1E;E]O=F5R9FQO=U]T86)L
M97,G("`]/B!F86QS92P*("`@("`@("`G;W=?9W5I7S$N,R<@("`@("`@("`@
M("`@("`@(#T^(&9A;'-E+`H@("`@("`@("=P;F=?=')A;G-P87)E;F-Y)R`@
M("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@)W-C<F]L;&)A<E]I;E]W87DG
M("`@("`@("`@("`]/B!F86QS92P*("`@("`@("`G<V-R;VQL7W1D<R<@("`@
M("`@("`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("=W:6YD;W=E9%]C;VYT
M<F]L<R<@("`@("`@("`@/3X@9F%L<V4L"B`@("`I.PH*("`@("\J*@H@("`@
M("H@3&ES="!O9B!V:65W86)L92!I;6%G92!-24U%('-U8G1Y<&5S+@H@("`@
M("H@5&AI<R!L:7-T(&]F('9I97=A8FQE(&EM86=E<R!W;W)K<R!F;W(@244@
M86YD($YE='-C87!E+TUO>FEL;&$N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)%]I;6%G97,@/2!A<G)A>2@G:G!E9R<L("=G
M:68G+"`G<&YG)RP@)W!J<&5G)RP@)W@M<&YG)RP@)V)M<"<I.PH*("`@("\J
M*@H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(')E9F5R96YC92!T;R!T:&4@
M9VQO8F%L($)R;W=S97(@;V)J96-T+"!O;FQY(&-R96%T:6YG(&ET"B`@("`@
M*B!I9B!I="!D;V5S;B=T(&%L<F5A9'D@97AI<W0N"B`@("`@*@H@("`@("H@
M5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.CQP<F4^"B`@("`@*B`@
M("1B<F]W<V5R(#T@)D)R;W=S97(Z.G-I;F=L971O;BA;)'5S97)!9V5N=%LL
M("1A8V-E<'1=72D[/"]P<F4^"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=7-E<D%G96YT("!4:&4@8G)O=W-E<B!S=')I;F<@=&\@<&%R<V4N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1A8V-E<'0@("`@(%1H92!(5%107T%#0T50
M5"!S971T:6YG<R!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!"<F]W
M<V5R("!4:&4@0G)O=W-E<B!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9S:6YG;&5T;VXH)'5S97)!9V5N="`](&YU;&PL("1A8V-E<'0@/2!N=6QL
M*0H@("`@>PH@("`@("`@('-T871I8R`D:6YS=&%N8V5S.PH*("`@("`@("!I
M9B`H(6ES<V5T*"1I;G-T86YC97,I*2!["B`@("`@("`@("`@("1I;G-T86YC
M97,@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@)'-I9VYA='5R92`]
M('-E<FEA;&EZ92AA<G)A>2@D=7-E<D%G96YT+"`D86-C97!T*2D["B`@("`@
M("`@:68@*&5M<'1Y*"1I;G-T86YC97-;)'-I9VYA='5R95TI*2!["B`@("`@
M("`@("`@("1I;G-T86YC97-;)'-I9VYA='5R95T@/2!N97<@0G)O=W-E<B@D
M=7-E<D%G96YT+"`D86-C97!T*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D:6YS=&%N8V5S6R1S:6=N871U<F5=.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0W)E871E(&$@8G)O=W-E<B!I;G-T86YC92`H0V]N<W1R=6-T;W(I+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97)!9V5N="`@5&AE(&)R
M;W=S97(@<W1R:6YG('1O('!A<G-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M86-C97!T("`@("!4:&4@2%144%]!0T-%4%0@<V5T=&EN9W,@=&\@=7-E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!"<F]W<V5R*"1U<V5R06=E;G0@/2!N=6QL
M+"`D86-C97!T(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^;6%T8V@H
M)'5S97)!9V5N="P@)&%C8V5P="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!0
M87)S97,@=&AE('5S97(@86=E;G0@<W1R:6YG(&%N9"!I;FET:71I86QI>F5S
M('1H92!O8FIE8W0@=VET:`H@("`@("H@86QL('1H92!K;F]W;B!F96%T=7)E
M<R!A;F0@<75I<FMS(&9O<B!T:&4@9VEV96X@8G)O=W-E<BX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1U<V5R06=E;G0@(%1H92!B<F]W<V5R('-T
M<FEN9R!T;R!P87)S92X*("`@("`J($!P87)A;2!S=')I;F<@)&%C8V5P="`@
M("`@5&AE($A45%!?04-#15!4('-E='1I;F=S('1O('5S92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@;6%T8V@H)'5S97)!9V5N="`](&YU;&PL("1A8V-E<'0@
M/2!N=6QL*0H@("`@>PH@("`@("`@("\O(%-E="!O=7(@86=E;G0@<W1R:6YG
M+@H@("`@("`@(&EF("AI<U]N=6QL*"1U<V5R06=E;G0I*2!["B`@("`@("`@
M("`@(&EF("AI<W-E="@D7U-%4E9%4ELG2%144%]54T527T%'14Y4)UTI*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7V%G96YT(#T@=')I;2@D7U-%4E9%
M4ELG2%144%]54T527T%'14Y4)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]A9V5N="`]("1U<V5R06=E
M;G0["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?;&]W97)!9V5N="`](%-T
M<FEN9SHZ;&]W97(H)'1H:7,M/E]A9V5N="D["@H@("`@("`@("\O(%-E="!O
M=7(@86-C97!T('-T<FEN9RX*("`@("`@("!I9B`H:7-?;G5L;"@D86-C97!T
M*2D@>PH@("`@("`@("`@("!I9B`H:7-S970H)%]315)615);)TA45%!?04-#
M15!4)UTI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V%C8V5P="`](%-T
M<FEN9SHZ;&]W97(H=')I;2@D7U-%4E9%4ELG2%144%]!0T-%4%0G72DI.PH@
M("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H
M:7,M/E]A8V-E<'0@/2!3=')I;F<Z.FQO=V5R*"1A8V-E<'0I.PH@("`@("`@
M('T*"B`@("`@("`@+R\@0VAE8VL@9F]R(%541B!S=7!P;W)T+@H@("`@("`@
M(&EF("AI<W-E="@D7U-%4E9%4ELG2%144%]!0T-%4%1?0TA!4E-%5"==*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G=71F)RP@<W1R<&]S
M*%-T<FEN9SHZ;&]W97(H)%]315)615);)TA45%!?04-#15!47T-(05)3150G
M72DL("=U=&8G*2`A/3T@9F%L<V4I.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"%E;7!T>2@D=&AI<RT^7V%G96YT*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7W-E=%!L871F;W)M*"D["@H@("`@("`@("`@("!I9B`H<W1R<&]S*"1T:&ES
M+3Y?;&]W97)!9V5N="P@)VUO8FEL965X<&QO<F5R)RD@(3T](&9A;'-E('Q\
M"B`@("`@("`@("`@("`@("!S=')P;W,H)'1H:7,M/E]L;W=E<D%G96YT+"`G
M;W!E;G=A=F4G*2`A/3T@9F%L<V4@?'P*("`@("`@("`@("`@("`@('-T<G!O
M<R@D=&AI<RT^7VQO=V5R06=E;G0L("=O<&5R82!M:6YI)RD@(3T](&9A;'-E
M('Q\"B`@("`@("`@("`@("`@("!S=')P;W,H)'1H:7,M/E]L;W=E<D%G96YT
M+"`G;W!E<F%M:6YI)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^<V5T1F5A='5R92@G9G)A;65S)RP@9F%L<V4I.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VIA=F%S8W)I<'0G+"!F86QS92D[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T475I<FLH)V%V;VED7W!O<'5P
M7W=I;F1O=W,G*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;6]B:6QE(#T@
M=')U93L*("`@("`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H)WQ/<&5R
M85LO(%TH6S`M.2Y=*RE\)RP@)'1H:7,M/E]A9V5N="P@)'9E<G-I;VXI*2![
M"B`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T0G)O=W-E<B@G;W!E
M<F$G*3L*("`@("`@("`@("`@("`@("`@("`@(&QI<W0H)'1H:7,M/E]M86IO
M<E9E<G-I;VXL("1T:&ES+3Y?;6EN;W)697)S:6]N*2`](&5X<&QO9&4H)RXG
M+"`D=F5R<VEO;ELQ72D["B`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M<V5T1F5A='5R92@G:F%V87-C<FEP="<L('1R=64I.PH@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/G-E=%%U:7)K*"=N;U]F:6QE;F%M95]S<&%C97,G
M*3L*"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]M86IO<E9E<G-I;VX@
M/CT@-RD@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E
M*"=D;VTG*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R
M92@G:69R86UE<R<I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&
M96%T=7)E*"=A8V-E<W-K97DG*3L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^<V5T1F5A='5R92@G;W!T9W)O=7`G*3L*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^<V5T475I<FLH)V1O=6)L95]L:6YE8G)E86M?=&5X=&%R96$G
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E:68@*'-T
M<G!O<R@D=&AI<RT^7VQO=V5R06=E;G0L("=E;&%I;F4O)RD@(3T](&9A;'-E
M('Q\"B`@("`@("`@("`@("`@("`@("`@("!S=')P;W,H)'1H:7,M/E]L;W=E
M<D%G96YT+"`G<&%L;7-O=7)C92<I("$]/2!F86QS92!\?`H@("`@("`@("`@
M("`@("`@("`@("`@<W1R<&]S*"1T:&ES+3Y?;&]W97)!9V5N="P@)V1I9VET
M86P@<&%T:',G*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1T:&ES
M+3YS971"<F]W<V5R*"=P86QM)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^
M<V5T1F5A='5R92@G:6UA9V5S)RP@9F%L<V4I.PH@("`@("`@("`@("`@("`@
M)'1H:7,M/G-E=$9E871U<F4H)V9R86UE<R<L(&9A;'-E*3L*("`@("`@("`@
M("`@("`@("1T:&ES+3YS971&96%T=7)E*"=J879A<V-R:7!T)RP@9F%L<V4I
M.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=%%U:7)K*"=A=F]I9%]P;W!U
M<%]W:6YD;W=S)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^7VUO8FEL92`]
M('1R=64["B`@("`@("`@("`@('T@96QS96EF("@H<')E9U]M871C:"@G?$U3
M244@*%LP+3DN72LI?"<L("1T:&ES+3Y?86=E;G0L("1V97)S:6]N*2D@?'P*
M("`@("`@("`@("`@("`@("`@("`@("AP<F5G7VUA=&-H*"=\26YT97)N970@
M17AP;&]R97(O*%LP+3DN72LI?"<L("1T:&ES+3Y?86=E;G0L("1V97)S:6]N
M*2DI('L*"B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T0G)O=W-E<B@G;7-I
M92<I.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=%%U:7)K*"=C86-H95]S
M<VQ?9&]W;FQO861S)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T475I
M<FLH)V-A8VAE7W-A;65?=7)L)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^
M<V5T475I<FLH)V)R96%K7V1I<W!O<VET:6]N7V9I;&5N86UE)RD["@H@("`@
M("`@("`@("`@("`@:68@*'-T<G!O<R@D=F5R<VEO;ELQ72P@)RXG*2`A/3T@
M9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("!L:7-T*"1T:&ES+3Y?;6%J
M;W)697)S:6]N+"`D=&AI<RT^7VUI;F]R5F5R<VEO;BD@/2!E>'!L;V1E*"<N
M)RP@)'9E<G-I;VY;,5TI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7VUA:F]R5F5R<VEO;B`]("1V97)S
M:6]N6S%=.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;6EN;W)697)S
M:6]N(#T@,#L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O
M*B!)12`H/"`W*2!O;B!7:6YD;W=S(&1O97,@;F]T('-U<'!O<G0@86QP:&$@
M=')A;G-P87)E;F-Y(&EN"B`@("`@("`@("`@("`@("`@*B!03D<@:6UA9V5S
M+B`J+PH@("`@("`@("`@("`@("`@:68@*"@D=&AI<RT^7VUA:F]R5F5R<VEO
M;B`\(#<I("8F"B`@("`@("`@("`@("`@("`@("`@<')E9U]M871C:"@G+W=I
M;F1O=W,O:2<L("1T:&ES+3Y?86=E;G0I*2!["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G-E=%%U:7)K*"=P;F=?=')A;G-P87)E;F-Y)RD["B`@("`@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@+RH@244@-B`H<')E+5-0
M,2D@86YD(#4N-2`H<')E+5-0,2D@:&%V92!B=6=G>2!C;VUP<F5S<VEO;BX*
M("`@("`@("`@("`@("`@("`J(%1H92!V97)S:6]N<R!A9F9E8W1E9"!A<F4@
M87,@9F]L;&]W<SH*("`@("`@("`@("`@("`@("`J(#8N,#`N,C0V,BXP,#`P
M("!);G1E<FYE="!%>'!L;W)E<B`V(%!U8FQI8R!0<F5V:65W("A"971A*0H@
M("`@("`@("`@("`@("`@("H@-BXP,"XR-#<Y+C`P,#8@($EN=&5R;F5T($5X
M<&QO<F5R(#8@4'5B;&EC(%!R979I97<@*$)E=&$I"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%)E9G)E<V@*("`@("`@("`@("`@("`@
M("`J(#8N,#`N,C8P,"XP,#`P("!);G1E<FYE="!%>'!L;W)E<B`V("A7:6YD
M;W=S(%A0*0H@("`@("`@("`@("`@("`@("H@-2XU,"XS.#(U+C$S,#`@($EN
M=&5R;F5T($5X<&QO<F5R(#4N-2!$979E;&]P97(@4')E=FEE=R`H0F5T82D*
M("`@("`@("`@("`@("`@("`J(#4N-3`N-#`S,"XR-#`P("!);G1E<FYE="!%
M>'!L;W)E<B`U+C4@)B!);G1E<FYE="!4;V]L<R!"971A"B`@("`@("`@("`@
M("`@("`@*B`U+C4P+C0Q,S0N,#$P,"`@26YT97)N970@17AP;&]R97(@-2XU
M(&9O<B!7:6YD;W=S($UE("@T+CDP+C,P,#`I"B`@("`@("`@("`@("`@("`@
M*B`U+C4P+C0Q,S0N,#8P,"`@26YT97)N970@17AP;&]R97(@-2XU"B`@("`@
M("`@("`@("`@("`@*B`U+C4P+C0S,#@N,CDP,"`@26YT97)N970@17AP;&]R
M97(@-2XU($%D=F%N8V5D(%-E8W5R:71Y(%!R:79A8WD@0F5T80H@("`@("`@
M("`@("`@("`@("H*("`@("`@("`@("`@("`@("`J(%-E93H*("`@("`@("`@
M("`@("`@("`J(#T]/3T*("`@("`@("`@("`@("`@("`J(&AT='`Z+R]S=7!P
M;W)T+FUI8W)O<V]F="YC;VTO:V(O,38T-3,Y.PH@("`@("`@("`@("`@("`@
M("H@:'1T<#HO+W-U<'!O<G0N;6EC<F]S;V9T+F-O;2]D969A=6QT+F%S<'@_
M<V-I9#UK8CME;BUU<SM1,S$R-#DV*0H@("`@("`@("`@("`@("`@("H@:'1T
M<#HO+W-U<'!O<G0N;6EC<F]S;V9T+F-O;2]D969A=6QT+F%S<'@_<V-I9#UK
M8CME;BUU<SM1,S$S-S$R"B`@("`@("`@("`@("`@("`@*B\*("`@("`@("`@
M("`@("`@("1I95]V97)S(#T@)'1H:7,M/F=E=$E%5F5R<VEO;B@I.PH@("`@
M("`@("`@("`@("`@)&)U9V=Y7VQI<W0@/2!A<G)A>2@*("`@("`@("`@("`@
M("`@("`@("`G-BPP,"PR-#8R+#`P,#`G+"`G-BPP,"PR-#<Y+#`P,#8G+"`G
M-BPP,"PR-C`P+#`P,#`G+`H@("`@("`@("`@("`@("`@("`@("<U+#4P+#,X
M,C4L,3,P,"<L("<U+#4P+#0P,S`L,C0P,"<L("<U+#4P+#0Q,S0L,#$P,"<L
M"B`@("`@("`@("`@("`@("`@("`@)S4L-3`L-#$S-"PP-C`P)RP@)S4L-3`L
M-#,P."PR.3`P)PH@("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@("`@
M(&EF("@A:7-?;G5L;"@D:65?=F5R<RD@)B8@:6Y?87)R87DH)&EE7W9E<G,L
M("1B=6=G>5]L:7-T*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS
M9711=6ER:R@G8G5G9WE?8V]M<')E<W-I;VXG*3L*("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("`O*B!3;VUE($AA;F1H96QD<R!H879E('1H
M96ER('-C<F5E;B!R97-O;'5T:6]N(&EN('1H90H@("`@("`@("`@("`@("`@
M("H@=7-E<B!A9V5N="!S=')I;F<L('=H:6-H('=E(&-A;B!U<V4@=&\@;&]O
M:R!F;W(*("`@("`@("`@("`@("`@("`J(&UO8FEL92!A9V5N=',N("HO"B`@
M("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+SL@*#$R,'@Q-C!\,C0P
M>#(X,'PR-#!X,S(P?#,R,'@S,C`I7"DO)RP@)'1H:7,M/E]A9V5N="DI('L*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VUO8FEL92`]('1R=64["B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@<W=I=&-H("@D=&AI
M<RT^7VUA:F]R5F5R<VEO;BD@>PH@("`@("`@("`@("`@("`@8V%S92`W.@H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=J879A<V-R
M:7!T)RP@,2XT*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A
M='5R92@G9&]M)RD["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E
M871U<F4H)VEF<F%M97,G*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M<V5T1F5A='5R92@G=71F)RD["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/G-E=$9E871U<F4H)W)T92<I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YS971&96%T=7)E*"=H;VUE<&%G92<I.PH@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YS971&96%T=7)E*"=A8V-E<W-K97DG*3L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G;W!T9W)O=7`G*3L*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G>&UL:'1T<')E<2<I
M.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@
M(&-A<V4@-CH*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R
M92@G:F%V87-C<FEP="<L(#$N-"D["B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G-E=$9E871U<F4H)V1O;2<I.PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YS971&96%T=7)E*"=I9G)A;65S)RD["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G-E=$9E871U<F4H)W5T9B<I.PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YS971&96%T=7)E*"=R=&4G*3L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^<V5T1F5A='5R92@G:&]M97!A9V4G*3L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G86-C97-S:V5Y)RD["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)V]P=&=R;W5P
M)RD["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)WAM
M;&AT='!R97$G*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T475I
M<FLH)W-C<F]L;&)A<E]I;E]W87DG*3L*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^<V5T475I<FLH)V)R;VME;E]M=6QT:7!A<G1?9F]R;2<I.PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YS9711=6ER:R@G=VEN9&]W961?8V]N
M=')O;',G*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@("`@("!C87-E(#4Z"B`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES
M+3YG9710;&%T9F]R;2@I(#T]("=M86,G*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YS971&96%T=7)E*"=J879A<V-R:7!T)RP@,2XR*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)V]P
M=&=R;W5P)RD["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@35-)12`U(&9O<B!7:6YD;W=S+@H@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G:F%V87-C
M<FEP="<L(#$N-"D["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS
M971&96%T=7)E*"=D;VTG*3L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G-E=$9E871U<F4H)WAM;&AT='!R97$G*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"1T:&ES+3Y?;6EN;W)697)S:6]N(#X](#4I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=R
M=&4G*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS9711
M=6ER:R@G=VEN9&]W961?8V]N=')O;',G*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^<V5T1F5A='5R92@G:69R86UE<R<I.PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=U=&8G*3L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G:&]M97!A9V4G*3L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G86-C97-S:V5Y
M)RD["B`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?;6EN;W)697)S
M:6]N(#T](#4I('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E
M=%%U:7)K*"=B<F5A:U]D:7-P;W-I=&EO;E]H96%D97(G*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/G-E=%%U:7)K*"=B<F]K96Y?;75L=&EP
M87)T7V9O<FTG*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`T.@H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=J879A<V-R:7!T
M)RP@,2XR*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R
M92@G86-C97-S:V5Y)RD["B`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES
M+3Y?;6EN;W)697)S:6]N(#X@,"D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^<V5T1F5A='5R92@G=71F)RD["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M("`@(&-A<V4@,SH*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A
M='5R92@G:F%V87-C<FEP="<L(#$N,2D["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/G-E=%%U:7)K*"=A=F]I9%]P;W!U<%]W:6YD;W=S)RD["B`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H*"=\04Y41G)E<V-O+RA;,"TY
M72LI?"<L("1T:&ES+3Y?86=E;G0L("1V97)S:6]N*2D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/G-E=$)R;W=S97(H)V9R97-C;R<I.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VIA=F%S8W)I<'0G+"`Q+C$I.PH@
M("`@("`@("`@("`@("`@)'1H:7,M/G-E=%%U:7)K*"=A=F]I9%]P;W!U<%]W
M:6YD;W=S)RD["B`@("`@("`@("`@('T@96QS96EF("AS=')P;W,H)'1H:7,M
M/E]L;W=E<D%G96YT+"`G879A;G1G;R<I("$]/2!F86QS92D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/G-E=$)R;W=S97(H)V%V86YT9V\G*3L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?;6]B:6QE(#T@=')U93L*("`@("`@("`@("`@
M?2!E;'-E:68@*'!R96=?;6%T8V@H)WQ+;VYQ=65R;W(O*%LP+3E=*RE\)RP@
M)'1H:7,M/E]A9V5N="P@)'9E<G-I;VXI('Q\"B`@("`@("`@("`@("`@("`@
M("`@("!P<F5G7VUA=&-H*"=\4V%F87)I+RA;,"TY72LI7"X_*%LP+3E=*RD_
M?"<L("1T:&ES+3Y?86=E;G0L("1V97)S:6]N*2D@>PH@("`@("`@("`@("`@
M("`@+R\@2V]N<75E<F]R(&%N9"!!<'!L92=S(%-A9F%R:2!B;W1H('5S92!T
M:&4@2TA434P*("`@("`@("`@("`@("`@("\O(')E;F1E<FEN9R!E;F=I;F4N
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T0G)O=W-E<B@G:V]N<75E<F]R
M)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T475I<FLH)V5M<'1Y7V9I
M;&5?:6YP=71?=F%L=64G*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS9711
M=6ER:R@G;F]?:&ED9&5N7V]V97)F;&]W7W1A8FQE<R<I.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]M86IO<E9E<G-I;VX@/2`D=F5R<VEO;ELQ73L*("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D=F5R<VEO;ELR72DI('L*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7VUI;F]R5F5R<VEO;B`]("1V97)S:6]N
M6S)=.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@(&EF("AS
M=')P;W,H)'1H:7,M/E]A9V5N="P@)U-A9F%R:2<I("$]/2!F86QS92`F)@H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;6%J;W)697)S:6]N(#X](#8P
M*2!["B`@("`@("`@("`@("`@("`@("`@+R\@4V%F87)I+@H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=U=&8G*3L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G:F%V87-C<FEP="<L(#$N
M-"D["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)V1O
M;2<I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=I
M9G)A;65S)RD["B`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?;6%J
M;W)697)S:6]N(#X@,3(U('Q\"B`@("`@("`@("`@("`@("`@("`@("`@("@D
M=&AI<RT^7VUA:F]R5F5R<VEO;B`]/2`Q,C4@)B8*("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?;6EN;W)697)S:6]N(#X](#$I*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=A8V-E<W-K
M97DG*3L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U
M<F4H)WAM;&AT='!R97$G*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("\O($MO
M;G%U97)O<BX*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R
M92@G:F%V87-C<FEP="<L(#$N,2D["B`@("`@("`@("`@("`@("`@("`@<W=I
M=&-H("@D=&AI<RT^7VUA:F]R5F5R<VEO;BD@>PH@("`@("`@("`@("`@("`@
M("`@(&-A<V4@,SH*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E
M=$9E871U<F4H)V1O;2<I.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^<V5T1F5A='5R92@G:69R86UE<R<I.PH@("`@("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H*"=\36]Z
M:6QL82\H6S`M.2Y=*RE\)RP@)'1H:7,M/E]A9V5N="P@)'9E<G-I;VXI*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T0G)O=W-E<B@G;6]Z:6QL82<I
M.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=%%U:7)K*"=M=7-T7V-A8VAE
M7V9O<FUS)RD["@H@("`@("`@("`@("`@("`@;&ES="@D=&AI<RT^7VUA:F]R
M5F5R<VEO;BP@)'1H:7,M/E]M:6YO<E9E<G-I;VXI(#T@97AP;&]D92@G+B<L
M("1V97)S:6]N6S%=*3L*("`@("`@("`@("`@("`@('-W:71C:"`H)'1H:7,M
M/E]M86IO<E9E<G-I;VXI('L*("`@("`@("`@("`@("`@(&-A<V4@-3H*("`@
M("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/F=E=%!L871F;W)M*"D@/3T@
M)W=I;B<I('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=%%U
M:7)K*"=B<F5A:U]D:7-P;W-I=&EO;E]F:6QE;F%M92<I.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A
M='5R92@G:F%V87-C<FEP="<L(#$N-"D["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/G-E=$9E871U<F4H)V1O;2<I.PH@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YS971&96%T=7)E*"=A8V-E<W-K97DG*3L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G;W!T9W)O=7`G*3L*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G>&UL:'1T<')E<2<I
M.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=C:71E
M)RD["B`@("`@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)WQR=CHH
M+BHI7"E\)RP@)'1H:7,M/E]A9V5N="P@)')E=FES:6]N*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H)')E=FES:6]N6S%=(#X](#$I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=I
M9G)A;65S)RD["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*"1R979I<VEO;ELQ72`^/2`Q+C,I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=R
M=&4G*3L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@("`@("!C87-E(#0Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E
M=$9E871U<F4H)VIA=F%S8W)I<'0G+"`Q+C,I.PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YS9711=6ER:R@G8G5G9WE?8V]M<')E<W-I;VXG*3L*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E
M(#,Z"B`@("`@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YS971&96%T=7)E*"=J879A<V-R:7!T)RP@,2D["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/G-E=%%U:7)K*"=B=6=G>5]C;VUP<F5S
M<VEO;B<I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!](&5L<V5I9B`H<')E9U]M871C:"@G?$QY
M;G@O*%LP+3E=*RE\)RP@)'1H:7,M/E]A9V5N="P@)'9E<G-I;VXI*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^<V5T0G)O=W-E<B@G;'EN>"<I.PH@("`@
M("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VEM86=E<R<L(&9A;'-E
M*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=F<F%M97,G
M+"!F86QS92D["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G
M:F%V87-C<FEP="<L(&9A;'-E*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS
M9711=6ER:R@G879O:61?<&]P=7!?=VEN9&]W<R<I.PH@("`@("`@("`@("!]
M(&5L<V5I9B`H<')E9U]M871C:"@G?$QI;FMS(%PH*%LP+3E=*RE\)RP@)'1H
M:7,M/E]A9V5N="P@)'9E<G-I;VXI*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^<V5T0G)O=W-E<B@G;&EN:W,G*3L*("`@("`@("`@("`@("`@("1T:&ES
M+3YS971&96%T=7)E*"=I;6%G97,G+"!F86QS92D["B`@("`@("`@("`@("`@
M("`D=&AI<RT^<V5T1F5A='5R92@G9G)A;65S)RP@9F%L<V4I.PH@("`@("`@
M("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VIA=F%S8W)I<'0G+"!F86QS
M92D["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T475I<FLH)V%V;VED7W!O
M<'5P7W=I;F1O=W,G*3L*("`@("`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T
M8V@H)WQ(;W1*879A+RA;,"TY72LI?"<L("1T:&ES+3Y?86=E;G0L("1V97)S
M:6]N*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$)R;W=S97(H)VAO
M=&IA=F$G*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=J
M879A<V-R:7!T)RP@9F%L<V4I.PH@("`@("`@("`@("!](&5L<V5I9B`H<W1R
M<&]S*"1T:&ES+3Y?86=E;G0L("=54"\G*2`A/3T@9F%L<V4@?'P*("`@("`@
M("`@("`@("`@("`@("`@('-T<G!O<R@D=&AI<RT^7V%G96YT+"`G55`N0B<I
M("$]/2!F86QS92!\?`H@("`@("`@("`@("`@("`@("`@("`@<W1R<&]S*"1T
M:&ES+3Y?86=E;G0L("=54"Y,)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^<V5T0G)O=W-E<B@G=7`G*3L*("`@("`@("`@("`@("`@
M("1T:&ES+3YS971&96%T=7)E*"=H=&UL)RP@9F%L<V4I.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VIA=F%S8W)I<'0G+"!F86QS92D[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G:&1M;"<I.PH@
M("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)W=M;"<I.PH*("`@
M("`@("`@("`@("`@(&EF("AS=')P;W,H)'1H:7,M/E]A9V5N="P@)T=522<I
M("$]/2!F86QS92`F)@H@("`@("`@("`@("`@("`@("`@('-T<G!O<R@D=&AI
M<RT^7V%G96YT+"`G55`N3&EN:R<I("$]/2!F86QS92D@>PH@("`@("`@("`@
M("`@("`@("`@("\J(%1H92!D979I8V4@86-C97!T<R!/<&5N=V%V92!'54D@
M97AT96YS:6]N<R!F;W(*("`@("`@("`@("`@("`@("`@("`@*B!734P@,2XS
M+B!.;VXM55`N3&EN:R!G871E=V%Y<R!S;VUE=&EM97,@:&%V90H@("`@("`@
M("`@("`@("`@("`@("`J('!R;V)L96US+"!S;R!E>&-L=61E('1H96TN("HO
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=%%U:7)K*"=O=U]G=6E?
M,2XS)RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7VUO8FEL92`]('1R=64["B`@("`@("`@("`@('T@96QS96EF("AS=')P
M;W,H)'1H:7,M/E]A9V5N="P@)UAI:6YO+R<I("$]/2!F86QS92D@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/G-E=$)R;W=S97(H)WAI:6YO)RD["B`@("`@
M("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G:&1M;"<I.PH@("`@("`@
M("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)W=M;"<I.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]M;V)I;&4@/2!T<G5E.PH@("`@("`@("`@("!](&5L
M<V5I9B`H<W1R<&]S*"1T:&ES+3Y?86=E;G0L("=086QM<V-A<&4O)RD@(3T]
M(&9A;'-E*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T0G)O=W-E<B@G
M<&%L;7-C87!E)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R
M92@G:F%V87-C<FEP="<L(&9A;'-E*3L*("`@("`@("`@("`@("`@("1T:&ES
M+3YS971&96%T=7)E*"=H9&UL)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^
M<V5T1F5A='5R92@G=VUL)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^7VUO
M8FEL92`]('1R=64["B`@("`@("`@("`@('T@96QS96EF("AS=')P;W,H)'1H
M:7,M/E]A9V5N="P@)TYO:VEA)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^<V5T0G)O=W-E<B@G;F]K:6$G*3L*("`@("`@("`@("`@
M("`@("1T:&ES+3YS971&96%T=7)E*"=H=&UL)RP@9F%L<V4I.PH@("`@("`@
M("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)W=M;"<I.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/G-E=$9E871U<F4H)WAH=&UL)RD["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7VUO8FEL92`]('1R=64["B`@("`@("`@("`@('T@96QS
M96EF("AS=')P;W,H)'1H:7,M/E]A9V5N="P@)T5R:6-S<V]N)RD@(3T](&9A
M;'-E*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T0G)O=W-E<B@G97)I
M8W-S;VXG*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=H
M=&UL)RP@9F%L<V4I.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U
M<F4H)W=M;"<I.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]M;V)I;&4@/2!T
M<G5E.PH@("`@("`@("`@("!](&5L<V5I9B`H<W1R<&]S*"1T:&ES+3Y?;&]W
M97)!9V5N="P@)W=A<"<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/G-E=$)R;W=S97(H)W=A<"<I.PH@("`@("`@("`@("`@("`@)'1H
M:7,M/G-E=$9E871U<F4H)VAT;6PG+"!F86QS92D["B`@("`@("`@("`@("`@
M("`D=&AI<RT^<V5T1F5A='5R92@G:F%V87-C<FEP="<L(&9A;'-E*3L*("`@
M("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=H9&UL)RD["B`@("`@
M("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G=VUL)RD["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7VUO8FEL92`]('1R=64["B`@("`@("`@("`@('T@
M96QS96EF("AS=')P;W,H)'1H:7,M/E]L;W=E<D%G96YT+"`G9&]C;VUO)RD@
M(3T](&9A;'-E('Q\"B`@("`@("`@("`@("`@("`@("`@("!S=')P;W,H)'1H
M:7,M/E]L;W=E<D%G96YT+"`G<&]R=&%L;6UM)RD@(3T](&9A;'-E*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^<V5T0G)O=W-E<B@G:6UO9&4G*3L*("`@
M("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=I;6%G97,G+"!F86QS
M92D["B`@("`@("`@("`@("`@("`D=&AI<RT^7VUO8FEL92`]('1R=64["B`@
M("`@("`@?2!E;'-E:68@*'-T<G!O<R@D=&AI<RT^7V%G96YT+"`G0FQA8VM"
M97)R>2<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E
M=$)R;W=S97(H)V)L86-K8F5R<GDG*3L*("`@("`@("`@("`@("`@("1T:&ES
M+3YS971&96%T=7)E*"=H=&UL)RP@9F%L<V4I.PH@("`@("`@("`@("`@("`@
M)'1H:7,M/G-E=$9E871U<F4H)VIA=F%S8W)I<'0G+"!F86QS92D["B`@("`@
M("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G:&1M;"<I.PH@("`@("`@
M("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)W=M;"<I.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]M;V)I;&4@/2!T<G5E.PH@("`@("`@("`@("!](&5L
M<V5I9B`H<W1R<&]S*"1T:&ES+3Y?86=E;G0L("=-3U0M)RD@(3T](&9A;'-E
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T0G)O=W-E<B@G;6]T;W)O
M;&$G*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=H=&UL
M)RP@9F%L<V4I.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H
M)VIA=F%S8W)I<'0G+"!F86QS92D["B`@("`@("`@("`@("`@("`D=&AI<RT^
M<V5T1F5A='5R92@G:&1M;"<I.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E
M=$9E871U<F4H)W=M;"<I.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]M;V)I
M;&4@/2!T<G5E.PH@("`@("`@("`@("!](&5L<V5I9B`H<W1R<&]S*"1T:&ES
M+3Y?;&]W97)!9V5N="P@)VHM)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^<V5T0G)O=W-E<B@G;6UL)RD["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7VUO8FEL92`]('1R=64["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!-871C:"!T:&4@<&QA=&9O<FT@
M;V8@=&AE(&)R;W=S97(N"B`@("`@*@H@("`@("H@5&AI<R!I<R!A('!R971T
M>2!S:6UP;&ES=&EC(&EM<&QE;65N=&%T:6]N+"!B=70@:70G<R!I;G1E;F1E
M9`H@("`@("H@=&\@;&5T('5S('1E;&P@=VAA="!L:6YE(&)R96%K<R!T;R!S
M96YD+"!S;R!I="=S(&=O;V0@96YO=6=H"B`@("`@*B!F;W(@:71S('!U<G!O
M<V4N"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E(#(N,@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?<V5T4&QA=&9O<FTH*0H@("`@>PH@("`@("`@(&EF("AS
M=')P;W,H)'1H:7,M/E]L;W=E<D%G96YT+"`G=VEN9"<I("$]/2!F86QS92D@
M>PH@("`@("`@("`@("`D=&AI<RT^7W!L871F;W)M(#T@)W=I;B<["B`@("`@
M("`@?2!E;'-E:68@*'-T<G!O<R@D=&AI<RT^7VQO=V5R06=E;G0L("=M86,G
M*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@)'1H:7,M/E]P;&%T9F]R;2`]
M("=M86,G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?
M<&QA=&9O<FT@/2`G=6YI>"<["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N('1H92!C=7)R96YT;'D@;6%T8VAE9"!P;&%T9F]R;2X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('5S97(G<R!P;&%T
M9F]R;2X*("`@("`J"B`@("`@*B!`<VEN8V4@2&]R9&4@,BXR"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=%!L871F;W)M*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]P;&%T9F]R;3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E
M=',@=&AE(&-U<G)E;G0@8G)O=W-E<BX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1B<F]W<V5R("!4:&4@8G)O=W-E<B!T;R!S970@87,@8W5R<F5N
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T0G)O=W-E<B@D8G)O=W-E<BD*
M("`@('L*("`@("`@("`D=&AI<RT^7V)R;W=S97(@/2`D8G)O=W-E<CL*("`@
M('T*"B`@("`O*BH*("`@("`J($1E=&5R;6EN92!I9B!T:&4@9VEV96X@8G)O
M=W-E<B!I<R!T:&4@<V%M92!A<R!T:&4@8W5R<F5N="X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1B<F]W<V5R("!4:&4@8G)O=W-E<B!T;R!C:&5C
M:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@($ES('1H92!G:79E
M;B!B<F]W<V5R('1H92!S86UE(&%S('1H92!C=7)R96YT/PH@("`@("HO"B`@
M("!F=6YC=&EO;B!I<T)R;W=S97(H)&)R;W=S97(I"B`@("!["B`@("`@("`@
M<F5T=7)N("@D=&AI<RT^7V)R;W=S97(@/3T]("1B<F]W<V5R*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($1O('=E(&-O;G-I9&5R('1H92!C=7)R96YT(&)R
M;W=S97(@=&\@8F4@82!M;V)I;&4@9&5V:6-E/PH@("`@("H*("`@("`J($!R
M971U<FX@8F]O;&5A;B`@5')U92!I9B!W92!D;RP@9F%L<V4@:68@=V4@9&]N
M)W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES36]B:6QE*"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/E]M;V)I;&4["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!$971E<FUI;F5S(&EF('1H92!B<F]W<V5R(&ES(&$@<F]B;W0@;W(@
M;F]T+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!B
M<F]W<V5R(&ES(&$@:VYO=VX@<F]B;W0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&ES4F]B;W0H*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<F]B
M;W1S(&%S("1R;V)O="D@>PH@("`@("`@("`@("!I9B`H<W1R<&]S*"1T:&ES
M+3Y?86=E;G0L("1R;V)O="D@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@=')U93L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V
M92!T:&4@8W5R<F5N="!B<F]W<V5R+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@8W5R<F5N="!B<F]W<V5R+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971"<F]W<V5R*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/E]B<F]W<V5R.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F4@=&AE
M(&-U<G)E;G0@8G)O=W-E<B=S(&UA:F]R('9E<G-I;VXN"B`@("`@*@H@("`@
M("H@0')E='5R;B!I;G1E9V5R("!4:&4@8W5R<F5N="!B<F]W<V5R)W,@;6%J
M;W(@=F5R<VEO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T36%J;W(H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VUA:F]R5F5R<VEO;CL*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E=')I979E('1H92!C=7)R96YT(&)R;W=S
M97(G<R!M:6YO<B!V97)S:6]N+@H@("`@("H*("`@("`J($!R971U<FX@:6YT
M96=E<B`@5&AE(&-U<G)E;G0@8G)O=W-E<B=S(&UI;F]R('9E<G-I;VXN"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$UI;F]R*"D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]M:6YO<E9E<G-I;VX["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971R:65V92!T:&4@8W5R<F5N="!B<F]W<V5R)W,@=F5R<VEO;BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-U<G)E;G0@8G)O
M=W-E<B=S('9E<G-I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%9E<G-I
M;VXH*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VUA:F]R5F5R<VEO
M;B`N("<N)R`N("1T:&ES+3Y?;6EN;W)697)S:6]N.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N('1H92!F=6QL(&)R;W=S97(@86=E;G0@<W1R:6YG
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8G)O=W-E<B!A
M9V5N="!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%G96YT4W1R
M:6YG*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]A9V5N=#L*("`@
M('T*"B`@("`O*BH*("`@("`J(%-E="!U;FEQ=64@8F5H879I;W(@9F]R('1H
M92!C=7)R96YT(&)R;W=S97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<75I<FL@(%1H92!B96AA=FEO<B!T;R!S970N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1V86QU92`@4W!E8VEA;"!B96AA=FEO<B!P87)A;65T97(N"B`@
M("`@*B\*("`@(&9U;F-T:6]N('-E=%%U:7)K*"1Q=6ER:RP@)'9A;'5E(#T@
M=')U92D*("`@('L*("`@("`@("`D=&AI<RT^7W%U:7)K<ULD<75I<FM=(#T@
M)'9A;'5E.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VL@=6YI<75E(&)E
M:&%V:6]R(&9O<B!T:&4@8W5R<F5N="!B<F]W<V5R+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'%U:7)K("!4:&4@8F5H879I;W(@=&\@8VAE8VLN
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!$;V5S('1H92!B<F]W
M<V5R(&AA=F4@=&AE(&)E:&%V:6]R('-E=#\*("`@("`J+PH@("`@9G5N8W1I
M;VX@:&%S475I<FLH)'%U:7)K*0H@("`@>PH@("`@("`@(')E='5R;B`A96UP
M='DH)'1H:7,M/E]Q=6ER:W-;)'%U:7)K72D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971R:65V92!U;FEQ=64@8F5H879I;W(@9F]R('1H92!C=7)R96YT
M(&)R;W=S97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<75I<FL@
M(%1H92!B96AA=FEO<B!T;R!R971R:65V92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE('9A;'5E(&9O<B!T:&4@<F5Q=65S=&5D(&)E:&%V
M:6]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9711=6ER:R@D<75I<FLI"B`@
M("!["B`@("`@("`@<F5T=7)N(&ES<V5T*"1T:&ES+3Y?<75I<FMS6R1Q=6ER
M:UTI"B`@("`@("`@("`@("`@(#\@)'1H:7,M/E]Q=6ER:W-;)'%U:7)K70H@
M("`@("`@("`@("`@("`Z(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M970@8V%P86)I;&ET:65S(&9O<B!T:&4@8W5R<F5N="!B<F]W<V5R+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&9E871U<F4@(%1H92!C87!A8FEL
M:71Y('1O('-E="X*("`@("`J($!P87)A;2!S=')I;F<@)'9A;'5E("`@(%-P
M96-I86P@8V%P86)I;&ET>2!P87)A;65T97(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('-E=$9E871U<F4H)&9E871U<F4L("1V86QU92`]('1R=64I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]F96%T=7)E<ULD9F5A='5R95T@/2`D=F%L=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:R!T:&4@8W5R<F5N="!B<F]W
M<V5R(&-A<&%B:6QI=&EE<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1F96%T=7)E("!4:&4@8V%P86)I;&ET>2!T;R!C:&5C:RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@($1O97,@=&AE(&)R;W=S97(@:&%V92!T
M:&4@8V%P86)I;&ET>2!S970_"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA<T9E
M871U<F4H)&9E871U<F4I"B`@("!["B`@("`@("`@<F5T=7)N("%E;7!T>2@D
M=&AI<RT^7V9E871U<F5S6R1F96%T=7)E72D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971R:65V92!T:&4@8W5R<F5N="!B<F]W<V5R(&-A<&%B:6QI='DN
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F5A='5R92`@5&AE(&-A
M<&%B:6QI='D@=&\@<F5T<FEE=F4N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!V86QU92!O9B!T:&4@<F5Q=65S=&5D(&-A<&%B:6QI='DN
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$9E871U<F4H)&9E871U<F4I"B`@
M("!["B`@("`@("`@<F5T=7)N(&ES<V5T*"1T:&ES+3Y?9F5A='5R97-;)&9E
M871U<F5=*0H@("`@("`@("`@("`@("`_("1T:&ES+3Y?9F5A='5R97-;)&9E
M871U<F5="B`@("`@("`@("`@("`@(#H@;G5L;#L*("`@('T*"B`@("`O*BH*
M("`@("`J($1E=&5R;6EN92!I9B!W92!A<F4@=7-I;F<@82!S96-U<F4@*%-3
M3"D@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%1R=64@:68@=7-I;F<@4U-,+"!F86QS92!I9B!N;W0N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('5S:6YG4U-,0V]N;F5C=&EO;B@I"B`@("!["B`@("`@("`@
M<F5T=7)N("@H:7-S970H)%]315)615);)TA45%!3)UTI("8F"B`@("`@("`@
M("`@("`@("`@*"1?4T525D526R=(5%104R==(#T]("=O;B<I*2!\?`H@("`@
M("`@("`@("`@("`@9V5T96YV*"=34TQ?4%)/5$]#3TQ?5D524TE/3B<I*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('-E<G9E<B!P<F]T
M;V-O;"!I;B!U<V4@;VX@=&AE(&-U<G)E;G0@<V5R=F5R+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@2%144"!S97)V97(@<')O=&]C;VP@
M=F5R<VEO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T2%144%!R;W1O8V]L
M*"D*("`@('L*("`@("`@("!I9B`H:7-S970H)%]315)615);)U-%4E9%4E]0
M4D]43T-/3"==*2D@>PH@("`@("`@("`@("!I9B`H*"1P;W,@/2!S=')R<&]S
M*"1?4T525D526R=315)615)?4%)/5$]#3TPG72P@)R\G*2DI('L*("`@("`@
M("`@("`@("`@(')E='5R;B!S=6)S='(H)%]315)615);)U-%4E9%4E]04D]4
M3T-/3"==+"`D<&]S("L@,2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5T
M97)M:6YE(&EF(&9I;&5S(&-A;B!B92!U<&QO861E9"!T;R!T:&4@<WES=&5M
M+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@268@=7!L;V%D<R!A
M;&QO=V5D+"!R971U<FYS('1H92!M87AI;75M('-I>F4@;V8@=&AE"B`@("`@
M*B`@("`@("`@("`@("`@("`@('5P;&]A9"!I;B!B>71E<RX@(%)E='5R;G,@
M,"!I9B!U<&QO861S(&%R92!N;W0*("`@("`J("`@("`@("`@("`@("`@("`@
M86QL;W=E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@86QL;W=&:6QE57!L;V%D
M<R@I"B`@("!["B`@("`@("`@:68@*&EN:5]G970H)V9I;&5?=7!L;V%D<R<I
M*2!["B`@("`@("`@("`@(&EF("@H)&1I<B`](&EN:5]G970H)W5P;&]A9%]T
M;7!?9&ER)RDI("8F"B`@("`@("`@("`@("`@("`A:7-?=W)I=&%B;&4H)&1I
M<BDI('L*("`@("`@("`@("`@("`@(')E='5R;B`P.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1F:6QE<VEZ92`](&EN:5]G970H)W5P;&]A9%]M87A?
M9FEL97-I>F4G*3L*("`@("`@("`@("`@<W=I=&-H("AS=')T;VQO=V5R*'-U
M8G-T<B@D9FEL97-I>F4L("TQ+"`Q*2DI('L*("`@("`@("`@("`@8V%S92`G
M:R<Z"B`@("`@("`@("`@("`@("`D9FEL97-I>F4@/2!I;G1V86PH9FQO871V
M86PH)&9I;&5S:7IE*2`J(#$P,C0I.PH@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("!C87-E("=M)SH*("`@("`@("`@("`@("`@("1F:6QE
M<VEZ92`](&EN='9A;"AF;&]A='9A;"@D9FEL97-I>F4I("H@,3`R-"`J(#$P
M,C0I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!D969A
M=6QT.@H@("`@("`@("`@("`@("`@)&9I;&5S:7IE(#T@:6YT=F%L*"1F:6QE
M<VEZ92D["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D<&]S='-I>F4@/2!I;FE?9V5T*"=P;W-T7VUA>%]S:7IE
M)RD["B`@("`@("`@("`@('-W:71C:"`H<W1R=&]L;W=E<BAS=6)S='(H)'!O
M<W1S:7IE+"`M,2P@,2DI*2!["B`@("`@("`@("`@(&-A<V4@)VLG.@H@("`@
M("`@("`@("`@("`@)'!O<W1S:7IE(#T@:6YT=F%L*&9L;V%T=F%L*"1P;W-T
M<VEZ92D@*B`Q,#(T*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@8V%S92`G;2<Z"B`@("`@("`@("`@("`@("`D<&]S='-I>F4@/2!I
M;G1V86PH9FQO871V86PH)'!O<W1S:7IE*2`J(#$P,C0@*B`Q,#(T*3L*("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@9&5F875L=#H*("`@
M("`@("`@("`@("`@("1P;W-T<VEZ92`](&EN='9A;"@D<&]S='-I>F4I.PH@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@<F5T=7)N(&UI;B@D9FEL97-I>F4L("1P;W-T<VEZ92D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE<R!I9B!T:&4@9FEL92!W87,@
M=7!L;V%D960@;W(@;F]T+B`@268@;F]T+"!W:6QL(')E='5R;B!T:&4*("`@
M("`J(&%P<')O<')I871E(&5R<F]R(&UE<W-A9V4N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D9FEE;&0@(%1H92!N86UE(&]F('1H92!F:65L9"!C
M;VYT86EN:6YG('1H92!U<&QO861E9`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@5&AE
M(&9I;&4@9&5S8W)I<'1I;VX@<W1R:6YG('1O('5S92!I;B!T:&4@97)R;W(*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!M97-S86=E+B`@1&5F875L
M=#H@)V9I;&4G+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@
M;VX@<W5C8V5S<RP@4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@=V%S1FEL955P;&]A9&5D*"1F:65L9"P@)&YA;64@/2!N=6QL
M*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G4$5!4BYP:'`G.PH*("`@
M("`@("!I9B`H:7-?;G5L;"@D;F%M92DI('L*("`@("`@("`@("`@)&YA;64@
M/2!?*")F:6QE(BD["B`@("`@("`@?0H*("`@("`@("!I9B`H(2@D=7!L;V%D
M4VEZ92`]($)R;W=S97(Z.F%L;&]W1FEL955P;&]A9',H*2DI('L*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B1FEL92!U<&QO861S
M(&YO="!S=7!P;W)T960N(BDI.PH@("`@("`@('T*"B`@("`@("`@+RH@1V5T
M(&%N>2!I;F1E>"!O;B!T:&4@9FEE;&0@;F%M92X@*B\*("`@("`@("!R97%U
M:7)E7V]N8V4@)TAO<F1E+T%R<F%Y+G!H<"<["B`@("`@("`@)&EN9&5X(#T@
M2&]R9&5?07)R87DZ.F=E=$%R<F%Y4&%R=',H)&9I96QD+"`D8F%S92P@)&ME
M>7,I.PH*("`@("`@("!I9B`H)&EN9&5X*2!["B`@("`@("`@("`@("\J($EN
M9&5X('!R97-E;G0L(&9E=&-H('1H92!E<G)O<B!V87(@=&\@8VAE8VLN("HO
M"B`@("`@("`@("`@("1K97ES7W!A=&@@/2!A<G)A>5]M97)G92AA<G)A>2@D
M8F%S92P@)V5R<F]R)RDL("1K97ES*3L*("`@("`@("`@("`@)&5R<F]R(#T@
M2&]R9&5?07)R87DZ.F=E=$5L96UE;G0H)%]&24Q%4RP@)&ME>7-?<&%T:"D[
M"@H@("`@("`@("`@("`O*B!);F1E>"!P<F5S96YT+"!F971C:"!T:&4@=&UP
M7VYA;64@=F%R('1O(&-H96-K+B`J+PH@("`@("`@("`@("`D:V5Y<U]P871H
M(#T@87)R87E?;65R9V4H87)R87DH)&)A<V4L("=T;7!?;F%M92<I+"`D:V5Y
M<RD["B`@("`@("`@("`@("1T;7!?;F%M92`]($AO<F1E7T%R<F%Y.CIG971%
M;&5M96YT*"1?1DE,15,L("1K97ES7W!A=&@I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("\J($YO(&EN9&5X+"!S:6UP;&4@<V5T('5P(&]F('9A
M<G,@=&\@8VAE8VLN("HO"B`@("`@("`@("`@(&EF("@A:7-S970H)%]&24Q%
M4ULD9FEE;&1=*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H7R@B3F\@9FEL92!U<&QO861E9"(I+"!54$Q/041?15)27TY/
M7T9)3$4I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1E<G)O<B`]("1?
M1DE,15-;)&9I96QD75LG97)R;W(G73L*("`@("`@("`@("`@)'1M<%]N86UE
M(#T@)%]&24Q%4ULD9FEE;&1=6R=T;7!?;F%M92==.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"%I<W-E="@D7T9)3$53*2!\?"`H)&5R<F]R(#T](%503$]!
M1%]%4E)?3D]?1DE,12DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H<W!R:6YT9BA?*")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(BDL("1N86UE
M*2P@55!,3T%$7T524E].3U]&24Q%*3L*("`@("`@("!](&5L<V5I9B`H*"1E
M<G)O<B`]/2!54$Q/041?15)27T]+*2`F)B!I<U]U<&QO861E9%]F:6QE*"1T
M;7!?;F%M92DI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@
M?2!E;'-E:68@*"@D97)R;W(@/3T@55!,3T%$7T524E])3DE?4TE:12D@?'P*
M("`@("`@("`@("`@("`@("`@*"1E<G)O<B`]/2!54$Q/041?15)27T9/4DU?
M4TE:12DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M<W!R:6YT9BA?*")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L
M;&]W960@<VEZ92`H)60@8GET97,I+B(I+"`D;F%M92P@)'5P;&]A9%-I>F4I
M+"`D97)R;W(I.PH@("`@("`@('T@96QS96EF("@D97)R;W(@/3T@55!,3T%$
M7T524E]005)424%,*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*'-P<FEN=&8H7R@B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H
M92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO
M861E9"XB*2P@)&YA;64I+"`D97)R;W(I.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&AE861E<G,@9F]R(&$@8G)O=W-E
M<B!D;W=N;&]A9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QE
M;F%M92`@5&AE(&9I;&5N86UE(&]F('1H92!D;W=N;&]A9"X*("`@("`J($!P
M87)A;2!S=')I;F<@)&-4>7!E("`@("!4:&4@8V]N=&5N="UT>7!E(&1E<V-R
M:7!T:6]N(&]F('1H92!F:6QE+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&EN
M;&EN92`@(%1R=64@:68@:6YL:6YE+"!F86QS92!I9B!A='1A8VAM96YT+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D8TQE;F=T:"`@(%1H92!C;VYT96YT+6QE
M;F=T:"!O9B!T:&ES(&9I;&4N"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E
M(#(N,@H@("`@("HO"B`@("!F=6YC=&EO;B!D;W=N;&]A9$AE861E<G,H)&9I
M;&5N86UE(#T@)W5N:VYO=VXG+"`D8U1Y<&4@/2!N=6QL+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1I;FQI;F4@/2!F86QS92P@)&-,96YG=&@@
M/2!N=6QL*0H@("`@>PH@("`@("`@("\J(%)E;6]V92!L:6YE8G)E86MS(&9R
M;VT@9FEL92!N86UE<RX@*B\*("`@("`@("`D9FEL96YA;64@/2!S=')?<F5P
M;&%C92AA<G)A>2@B7')<;B(L(")<<B(L(")<;B(I+"`G("<L("1F:6QE;F%M
M92D["@H@("`@("`@("\J(%-O;64@8G)O=W-E<G,@9&]N)W0@;&EK92!S<&%C
M97,@:6X@=&AE(&9I;&5N86UE+B`J+PH@("`@("`@(&EF("@D=&AI<RT^:&%S
M475I<FLH)VYO7V9I;&5N86UE7W-P86-E<R<I*2!["B`@("`@("`@("`@("1F
M:6QE;F%M92`]('-T<G1R*"1F:6QE;F%M92P@)R`G+"`G7R<I.PH@("`@("`@
M('T*"B`@("`@("`@+RH@35-)12!D;V5S;B=T(&QI:V4@;75L=&EP;&4@<&5R
M:6]D<R!I;B!T:&4@9FEL92!N86UE+B!#;VYV97)T"B`@("`@("`@("`@86QL
M('!E<FEO9',@*&5X8V5P="!T:&4@;&%S="!O;F4I('1O('5N9&5R<V-O<F5S
M+B`J+PH@("`@("`@(&EF("@D=&AI<RT^:7-"<F]W<V5R*"=M<VEE)RDI('L*
M("`@("`@("`@("`@:68@*"@D<&]S(#T@<W1R<G!O<R@D9FEL96YA;64L("<N
M)RDI*2!["B`@("`@("`@("`@("`@("`D9FEL96YA;64@/2!S=')T<BAS=6)S
M='(H)&9I;&5N86UE+"`P+"`D<&]S*2P@)RXG+"`G7R<I("X@<W5B<W1R*"1F
M:6QE;F%M92P@)'!O<RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@("\J($-O;G1E;G0M5'EP92]#;VYT96YT+41I<W!O<VET:6]N($AE861E
M<BX@*B\*("`@("`@("!I9B`H)&EN;&EN92D@>PH@("`@("`@("`@("!I9B`H
M(6ES7VYU;&PH)&-4>7!E*2D@>PH@("`@("`@("`@("`@("`@:&5A9&5R*"=#
M;VYT96YT+51Y<&4Z("<@+B!T<FEM*"1C5'EP92DI.PH@("`@("`@("`@("!]
M(&5L<V5I9B`H)'1H:7,M/FES0G)O=W-E<B@G;7-I92<I*2!["B`@("`@("`@
M("`@("`@("!H96%D97(H)T-O;G1E;G0M5'EP93H@87!P;&EC871I;VXO>"UM
M<V1O=VYL;V%D)RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("!H96%D97(H)T-O;G1E;G0M5'EP93H@87!P;&EC871I;VXO;V-T970M
M<W1R96%M)RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@:&5A9&5R*"=#
M;VYT96YT+41I<W!O<VET:6]N.B!I;FQI;F4[(&9I;&5N86UE/2(G("X@)&9I
M;&5N86UE("X@)R(G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I
M9B`H)'1H:7,M/FES0G)O=W-E<B@G;7-I92<I*2!["B`@("`@("`@("`@("`@
M("!H96%D97(H)T-O;G1E;G0M5'EP93H@87!P;&EC871I;VXO>"UM<V1O=VYL
M;V%D)RD["B`@("`@("`@("`@('T@96QS96EF("@A:7-?;G5L;"@D8U1Y<&4I
M*2!["B`@("`@("`@("`@("`@("!H96%D97(H)T-O;G1E;G0M5'EP93H@)R`N
M('1R:6TH)&-4>7!E*2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("!H96%D97(H)T-O;G1E;G0M5'EP93H@87!P;&EC871I;VXO;V-T
M970M<W1R96%M)RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D
M=&AI<RT^:&%S475I<FLH)V)R96%K7V1I<W!O<VET:6]N7VAE861E<B<I*2![
M"B`@("`@("`@("`@("`@("!H96%D97(H)T-O;G1E;G0M1&ES<&]S:71I;VXZ
M(&9I;&5N86UE/2(G("X@)&9I;&5N86UE("X@)R(G*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@(&AE861E<B@G0V]N=&5N="U$:7-P
M;W-I=&EO;CH@871T86-H;65N=#L@9FEL96YA;64](B<@+B`D9FEL96YA;64@
M+B`G(B<I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!#
M;VYT96YT+4QE;F=T:"!(96%D97(N("HO"B`@("`@("`@:68@*"%I<U]N=6QL
M*"1C3&5N9W1H*2D@>PH@("`@("`@("`@("!H96%D97(H)T-O;G1E;G0M3&5N
M9W1H.B`G("X@)&-,96YG=&@I.PH@("`@("`@('T*"B`@("`@("`@+RH@3W9E
M<G=R:71E(%!R86=M83H@86YD(&]T:&5R(&-A8VAI;F<@:&5A9&5R<R!F;W(@
M244N("HO"B`@("`@("`@:68@*"1T:&ES+3YH87-1=6ER:R@G8V%C:&5?<W-L
M7V1O=VYL;V%D<R<I*2!["B`@("`@("`@("`@(&AE861E<B@G17AP:7)E<SH@
M,"<I.PH@("`@("`@("`@("!H96%D97(H)T-A8VAE+4-O;G1R;VPZ(&UU<W0M
M<F5V86QI9&%T92<I.PH@("`@("`@("`@("!H96%D97(H)U!R86=M83H@<'5B
M;&EC)RD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1&5T97)M
M:6YE<R!I9B!A(&)R;W=S97(@8V%N(&1I<W!L87D@82!G:79E;B!-24U%('1Y
M<&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;6EM971Y<&4@(%1H
M92!-24U%('1Y<&4@=&\@8VAE8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!4<G5E(&EF('1H92!B<F]W<V5R(&-A;B!D:7-P;&%Y('1H92!-
M24U%('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES5FEE=V%B;&4H)&UI
M;65T>7!E*0H@("`@>PH@("`@("`@("1M:6UE='EP92`](%-T<FEN9SHZ;&]W
M97(H)&UI;65T>7!E*3L*("`@("`@("!L:7-T*"1T>7!E+"`D<W5B='EP92D@
M/2!E>'!L;V1E*"<O)RP@)&UI;65T>7!E*3L*"B`@("`@("`@:68@*"%E;7!T
M>2@D=&AI<RT^7V%C8V5P="DI('L*("`@("`@("`@("`@)'=I;&1C87)D7VUA
M=&-H(#T@9F%L<V4["@H@("`@("`@("`@("!I9B`H<W1R<&]S*"1T:&ES+3Y?
M86-C97!T+"`D;6EM971Y<&4I("$]/2!F86QS92D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF
M("AS=')P;W,H)'1H:7,M/E]A8V-E<'0L("<J+RHG*2`A/3T@9F%L<V4I('L*
M("`@("`@("`@("`@("`@("1W:6QD8V%R9%]M871C:"`]('1R=64["B`@("`@
M("`@("`@("`@("!I9B`H)'1Y<&4@(3T@)VEM86=E)RD@>PH@("`@("`@("`@
M("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`O*B!I;6%G92]J<&5G(&%N9"!I;6%G
M92]P:G!E9R`J87!P96%R*B!T;R!B92!T:&4@<V%M90H@("`@("`@("`@("`@
M*B!E;G1I='DL(&)U="!-;WII;&QA(&1O97-N)W0@<V5E;2!T;R!W86YT('1O
M(&%C8V5P="!T:&4*("`@("`@("`@("`@("H@;&%T=&5R+B`@1F]R(&]U<B!P
M=7)P;W-E<RP@=V4@=VEL;"!T<F5A="!T:&5M('1H90H@("`@("`@("`@("`@
M*B!S86UE+B`J+PH@("`@("`@("`@("!I9B`H)'1H:7,M/FES0G)O=W-E<B@G
M;6]Z:6QL82<I("8F"B`@("`@("`@("`@("`@("`H)&UI;65T>7!E(#T]("=I
M;6%G92]P:G!E9R<I("8F"B`@("`@("`@("`@("`@("`H<W1R<&]S*"1T:&ES
M+3Y?86-C97!T+"`G:6UA9V4O:G!E9R<I("$]/2!F86QS92DI('L*("`@("`@
M("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("!I9B`H(21W:6QD8V%R9%]M871C:"D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!I9B`H(21T:&ES+3YH87-&96%T=7)E*"=I;6%G97,G*2!\?"`H)'1Y<&4@
M(3T@)VEM86=E)RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N(&EN7V%R<F%Y*"1S=6)T>7!E+"`D=&AI
M<RT^7VEM86=E<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%<V-A<&4@8VAA
M<F%C=&5R<R!I;B!J879A<V-R:7!T(&-O9&4@:68@=&AE(&)R;W=S97(@<F5Q
M=6ER97,@:70N"B`@("`@*B`E,C,L("4R-BP@86YD("4R0B`H9F]R('-O;64@
M8G)O=W-E<G,I(&%N9"`E,C<@;F5E9"!T;R!B92!E<V-A<&5D(&]R"B`@("`@
M*B!E;'-E(&IA=F%S8W)I<'0@=VEL;"!I;G1E<G!R970@:70@87,@82!S:6YG
M;&4@<75O=&4L('!O=6YD('-I9VXL(&]R"B`@("`@*B!A;7!E<G-A;F0@86YD
M(')E9G5S92!T;R!W;W)K+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&-O9&4@(%1H92!*4R!C;V1E('1O(&5S8V%P92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(&5S8V%P960@8V]D92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@97-C87!E2E-#;V1E*"1C;V1E*0H@("`@>PH@("`@("`@("1F
M<F]M(#T@)'1O(#T@87)R87DH*3L*"B`@("`@("`@:68@*"1T:&ES+3YI<T)R
M;W=S97(H)VUS:64G*2!\?`H@("`@("`@("`@("`H)'1H:7,M/FES0G)O=W-E
M<B@G;6]Z:6QL82<I("8F("@D=&AI<RT^9V5T36%J;W(H*2`^/2`U*2D@?'P*
M("`@("`@("`@("`@)'1H:7,M/FES0G)O=W-E<B@G:V]N<75E<F]R)RDI('L*
M("`@("`@("`@("`@)&9R;VT@/2!A<G)A>2@G)3(S)RP@)R4R-B<L("<E,D(G
M*3L*("`@("`@("`@("`@)'1O(#T@87)R87DH=7)L96YC;V1E*"<E,C,G*2P@
M=7)L96YC;V1E*"<E,C8G*2P@=7)L96YC;V1E*"<E,D(G*2D["B`@("`@("`@
M?0H@("`@("`@("1F<F]M6UT@/2`G)3(W)SL*("`@("`@("`D=&];72`]("=<
M)3(W)SL*"B`@("`@("`@<F5T=7)N('-T<E]R97!L86-E*"1F<F]M+"`D=&\L
M("1C;V1E*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@244@=F5R
M<VEO;B!I;B!T:&4@<V5S<VEO;BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1V97(@(%1H92!)12!697)S:6]N('-T<FEN9RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@<V5T245697)S:6]N*"1V97(I"B`@("!["B`@("`@("`@)%]3
M15-324].6R=?7V)R;W=S97(G72`](&%R<F%Y*`H@("`@("`@("`@("`G:65?
M=F5R<VEO;B<@/3X@)'9E<@H@("`@("`@("D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FX@=&AE($E%('9E<G-I;VX@<W1O<F5D(&EN('1H92!S97-S
M:6]N+"!I9B!A=F%I;&%B;&4N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@5&AE($E%(%9E<G-I;VX@<W1R:6YG(&]R(&YU;&P@:68@;F\@<W1R:6YG
M(&ES('-T;W)E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T245697)S:6]N
M*"D*("`@('L*("`@("`@("!R971U<FX@:7-S970H)%]315-324].6R=?7V)R
M;W=S97(G75LG:65?=F5R<VEO;B==*2`_("1?4T534TE/3ELG7U]B<F]W<V5R
M)UU;)VEE7W9E<G-I;VXG72`Z(&YU;&P["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+TYE=```````````````````````````````````````````````````
M`````````````````````````````````````````#`P,#<U-2``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S0P(#`Q-C<U,@`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O3F5T+U--4P``````````````````````
M````````````````````````````````````````````````````````````
M````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T
M,S,W-#`@,#$W-#$T`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<```````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`V,C4S,2`Q,#4Q-30S,S<T,"`P,C,Q-#8`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J($YE=%]3
M35-?<VUS,F5M86EL7VAT='`@0VQA<W,@:6UP;&5M96YT<R!T:&4@2%144"!!
M4$D@9F]R(&%C8V5S<VEN9R!T:&4*("H@<VUS,F5M86EL("AW=W<N<VUS,F5M
M86EL+F-O;2D@4TU3(&=A=&5W87DN"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P
M,#8@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<"QV(#$N,C,N,3`N,3`@,C`P-B\P,2\P,2`R,3HR.#HR.2!J
M86X@17AP("0*("H*("H@0&%U=&AO<B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B
M;&\N8V]M/@H@*B!`<&%C:V%G92!.971?4TU3"B`J+PIC;&%S<R!.971?4TU3
M7W-M<S)E;6%I;%]H='1P(&5X=&5N9',@3F5T7U--4R!["@H@("`@=F%R("1?
M8F%S95]U<FP@/2`G:&]R9&4N<VUS,F5M86EL+F-O;2]H;W)D92\G.PH*("`@
M("\J*@H@("`@("H@06X@87)R87D@;V8@8V%P86)I;&ET:65S+"!S;R!T:&%T
M('1H92!D<FEV97(@8V%N(')E<&]R="!W:&EC:`H@("`@("H@;W!E<F%T:6]N
M<R!I="!S=7!P;W)T<R!A;F0@=VAI8V@@:70@9&]E<VXG="X@4&]S<VEB;&4@
M=F%L=65S(&%R93H\<')E/@H@("`@("H@("!A=71H("`@("`@("`M(%1H92!G
M871E=V%Y(')E<75I<F5S(&%U=&AE;G1I8V%T:6]N(&)E9F]R92!S96YD:6YG
M.PH@("`@("H@("!B871C:"`@("`@("`M($)A=&-H('-E;F1I;F<@:7,@<W5P
M<&]R=&5D.PH@("`@("H@("!M=6QT:2`@("`@("`M(%-E;F1I;F<@;V8@;65S
M<V%G97,@=&\@;75L=&EP;&4@<F5C:7!I96YT<R!I<R!S=7!P;W)T960["B`@
M("`@*B`@(')E8V5I=F4@("`@("T@5VAE=&AE<B!T:&ES(&1R:79E<B!I<R!C
M87!A8FQE(&]F(')E8V5I=FEN9R!335,["B`@("`@*B`@(&-R961I="`@("`@
M("T@27,@=7-E(&]F('1H92!G871E=V%Y(&)A<V5D(&]N(&-R961I=',["B`@
M("`@*B`@(&%D9')E<W-B;V]K("T@07)E(&=A=&5W87D@861D<F5S<V)O;VMS
M('-U<'!O<G1E9#L*("`@("`J("`@;&ES=',@("`@("`@+2!'871E=V%Y('-U
M<'!O<G0@9F]R(&1I<W1R:6)U=&EO;B!L:7-T<RX*("`@("`J(#PO<')E/@H@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1C87!A
M8FEL:71I97,@/2!A<G)A>2@G875T:"<@("`@("`@(#T^(&9A;'-E+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G8F%T8V@G("`@("`@(#T^(#$P
M,"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VUU;'1I)R`@("`@
M("`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5C
M96EV92<@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G8W)E9&ET)R`@("`@(#T^('1R=64L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=A9&1R97-S8F]O:R<@/3X@=')U92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)VQI<W1S)R`@("`@("`]/B!T<G5E*3L*
M"B`@("`O*BH*("`@("`J(%1H:7,@9G5N8W1I;VX@9&]E<R!T:&4@86-T=6%L
M('-E;F1I;F<@;V8@=&AE(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1M97-S86=E
M("!4:&4@87)R87D@8V]N=&%I;FEN9R!T:&4@;65S<V%G92!A;F0@:71S('-E
M;F0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@<&%R86UE=&5R<RX*
M("`@("`J($!P87)A;2!S=')I;F<@)'1O("`@("`@5&AE(&1E<W1I;F%T:6]N
M('-T<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A
M>2!W:71H('1H92!S=6-C97-S('-T871U<R!A;F0@861D:71I;VYA;`H@("`@
M("H@("`@("`@("`@("`@("`@:6YF;W)M871I;VXN"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]S96YD*"8D;65S<V%G92P@)'1O*0H@("`@>PH@("`@("`@("\J
M(%-E="!U<"!T:&4@<V5N9&EN9R!U<FPN("HO"B`@("`@("`@)'5R;"`]('-P
M<FEN=&8H)W!O<W1M<V<N<&AP/W5S97)N86UE/25S)G!A<W-W;W)D/25S)FUE
M<W-A9V4])7,G+`H@("`@("`@("`@("`@("`@("`@("`@('5R;&5N8V]D92@D
M=&AI<RT^7W!A<F%M<ULG=7-E<B==*2P*("`@("`@("`@("`@("`@("`@("`@
M("!U<FQE;F-O9&4H)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UTI+`H@("`@
M("`@("`@("`@("`@("`@("`@('5R;&5N8V]D92@D;65S<V%G95LG=&5X="==
M*2D["@H@("`@("`@("\J($-H96-K(&EF('-O=7)C92!F<F]M(&ES('-E="X@
M*B\*("`@("`@("!I9B`H(65M<'1Y*"1M97-S86=E6R=S96YD7W!A<F%M<R==
M6R=F<F]M)UTI*2!["B`@("`@("`@("`@("1U<FP@+CT@)R9O<FEG/2<@+B!U
M<FQE;F-O9&4H)&UE<W-A9V5;)W-E;F1?<&%R86US)UU;)V9R;VTG72D["B`@
M("`@("`@?0H@("`@("`@("\J($-H96-K(&EF(&UE<W-A9V4@='EP92!I<R!F
M;&%S:"X@*B\*("`@("`@("!I9B`H(65M<'1Y*"1M97-S86=E6R=S96YD7W!A
M<F%M<R==6R=M<V=?='EP92==*2`F)@H@("`@("`@("`@("`D;65S<V%G95LG
M<V5N9%]P87)A;7,G75LG;7-G7W1Y<&4G72`]/2`G4TU37T9,05-()RD@>PH@
M("`@("`@("`@("`D=7)L("X]("<F9FQA<V@],2<["B`@("`@("`@?0H@("`@
M("`@("\J($-H96-K(&EF(&1E;&EV97)Y(')E<&]R="!U<FP@:&%S(&)E96X@
M<V5T+B`J+PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;)V1E
M;&EV97)Y7W)E<&]R="==*2D@>PH@("`@("`@("`@("`D=7)L("X]("<F9&QU
M<FP])R`N('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG9&5L:79E<GE?<F5P
M;W)T)UTI("X*("`@("`@("`@("`@("`@("`@("`G<F5P;W)T8V]D93TE8V]D
M929D97-T:6YA=&EO;FYU;6)E<CTE9&5S="<["B`@("`@("`@?0H*("`@("`@
M("`O*B!,;V]P('1H<F]U9V@@<F5C:7!I96YT<R!A;F0@9&\@<V]M92!M:6YI
M;6%L('9A;&ED:71Y(&-H96-K:6YG+B`J+PH@("`@("`@(&EF("AI<U]A<G)A
M>2@D=&\I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1T;R!A<R`D:V5Y(#T^
M("1V86PI('L*("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7BXJ
M/SP_7"L_*%QD>S<L?2DH/GPD*2\G+"`D=F%L+"`D;6%T8VAE<RDI('L*("`@
M("`@("`@("`@("`@("`@("`D=&];)&ME>5T@/2`D;6%T8VAE<ULQ73L*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@+RH@
M1DE8344Z(%-I;&5N=&QY(&1R;W`@8F%D(')E8VEP:65N=',N(%1H:7,@<VAO
M=6QD(&)E"B`@("`@("`@("`@("`@("`@("`@("H@;&]G9V5D(&%N9"]O<B!R
M97!O<G1E9"X@*B\*("`@("`@("`@("`@("`@("`@("!U;G-E="@D=&];)&ME
M>5TI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1T;R`](&EM<&QO9&4H)RPG+"`D=&\I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7BXJ/SP_7"L_*%QD>S<L
M?2DH/GPD*2\G+"`D=&\L("1M871C:&5S*2D@>PH@("`@("`@("`@("`@("`@
M)'1O(#T@)&UA=&-H97-;,5T["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("!R971U<FX@87)R87DH,"P@<W!R:6YT9BA?*"));G9A;&ED
M(')E8VEP:65N=#H@7"(E<UPB(BDL("1T;RDI.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`O*B!!<'!E;F0@=&AE(')E8VEP:65N=',@;V8@
M=&AI<R!M97-S86=E(&%N9"!C86QL('1H92!U<FPN("HO"B`@("`@("`@)'5R
M;"`N/2`G)G1O7VYU;3TG("X@)'1O.PH@("`@("`@("1R97-P;VYS92`]("1T
M:&ES+3Y?8V%L;%523"@D=7)L*3L*("`@("`@("!I9B`H:7-?82@D<F5S<&]N
M<V4L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y
M*#`L("1R97-P;VYS92T^9V5T365S<V%G92@I*3L*("`@("`@("!]"@H@("`@
M("`@("\J(%!A<G-E('1H92!R97-P;VYS92P@8VAE8VL@9F]R(&YE=R!L:6YE
M<R!I;B!C87-E(&]F(&UU;'1I<&QE"B`@("`@("`@("H@<F5C:7!I96YT<RX@
M*B\*("`@("`@("`D;&EN97,@/2!E>'!L;V1E*")<;B(L("1R97-P;VYS92D[
M"B`@("`@("`@)')E<W!O;G-E(#T@87)R87DH*3L*"B`@("`@("`@:68@*&-O
M=6YT*"1L:6YE<RD@/B`Q*2!["B`@("`@("`@("`@("\J($UU;'1I<&QE(')E
M8VEP:65N=',N("HO"B`@("`@("`@("`@(&9O<F5A8V@@*"1L:6YE<R!A<R`D
M;&EN92D@>PH@("`@("`@("`@("`@("`@)'!A<G1S(#T@97AP;&]D92@G5&\Z
M)RP@)&QI;F4I.PH@("`@("`@("`@("`@("`@)')E8VEP:65N="`]('1R:6TH
M)'!A<G1S6S%=*3L*("`@("`@("`@("`@("`@(&EF("@D;&EN97-;,%T@/3T@
M)T%14TU3+4]+)RD@>PH@("`@("`@("`@("`@("`@("`@("1R97-P;VYS95LD
M<F5C:7!I96YT72`](&%R<F%Y*#$L(&YU;&PI.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D<F5S<&]N<V5;)')E8VEP
M:65N=%T@/2!A<G)A>2@P+"`D;&EN97-;,%TI.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M+RH@4VEN9VQE(')E8VEP:65N="X@*B\*("`@("`@("`@("`@:68@*"1L:6YE
M<ULP72`]/2`G05%335,M3TLG*2!["B`@("`@("`@("`@("`@("`D<F5S<&]N
M<V5;)'1O72`](&%R<F%Y*#$L(&YU;&PI.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)')E<W!O;G-E6R1T;UT@/2!A<G)A>2@P+"`D
M;&EN97-;,%TI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)')E<W!O;G-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!T:&4@8W5R<F5N="!C<F5D:70@8F%L86YC92!O;B!T:&4@9V%T97=A>2X*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&EN=&5G97(@(%1H92!C<F5D:70@8F%L86YC92!A=F%I;&%B;&4@
M;VX@=&AE(&=A=&5W87DN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971"86QA
M;F-E*"D*("`@('L*("`@("`@("`O*B!3970@=7`@=&AE('5R;"!A;F0@8V%L
M;"!I="X@*B\*("`@("`@("`D=7)L(#T@<W!R:6YT9B@G<&]S=&US9RYP:'`_
M=7-E<FYA;64])7,F<&%S<W=O<F0])7,F8VUD/6-R961I="<L"B`@("`@("`@
M("`@("`@("`@("`@("`@=7)L96YC;V1E*"1T:&ES+3Y?<&%R86US6R=U<V5R
M)UTI+`H@("`@("`@("`@("`@("`@("`@("`@('5R;&5N8V]D92@D=&AI<RT^
M7W!A<F%M<ULG<&%S<W=O<F0G72DI.PH@("`@("`@("1R97-P;VYS92`]("1T
M:&ES+3Y?8V%L;%523"@D=7)L*3L*("`@("`@("!I9B`H:7-?82@D<F5S<&]N
M<V4L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-P
M;VYS93L*("`@("`@("!]"@H@("`@("`@("\J(%1R>2!S<&QI='1I;F<@=7`@
M=&AE(')E<W!O;G-E+B`J+PH@("`@("`@("1L:6YE<R`](&5X<&QO9&4H)STG
M+"`D<F5S<&]N<V4I.PH*("`@("`@("!I9B`H)&QI;F5S6S!=(#T]("=!45--
M4RU#4D5$250G*2!["B`@("`@("`@("`@(')E='5R;B`D;&EN97-;,5T["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YG971%
M<G)O<B@D;&EN97-;,%TL(%\H(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E
M<R(I*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@
M8V]N=&%C="!T;R!T:&4@9V%T97=A>2=S(&%D9')E<W-B;V]K+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@(%1H92!N86UE(&9O<B!T
M:&ES(&-O;G1A8W0*("`@("`J($!P87)A;2!I;G1E9V5R("1N=6UB97(@(%1H
M92!C;VYT86-T)W,@<&AO;F4@;G5M8F5R+@H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@(%1H92!R96UO=&4@8V]N=&%C="!)1"!O;B!S=6-C97-S(&]R
M(%!%05(@17)R;W(@;VX*("`@("`J("`@("`@("`@("`@("`@(&9A:6QU<F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$-O;G1A8W0H)&YA;64L("1N=6UB
M97(I"B`@("!["B`@("`@("`@+RH@4V5T('5P('1H92!U<FP@86YD(&-A;&P@
M:70N("HO"B`@("`@("`@)'5R;"`]('-P<FEN=&8H)W!O<W1C;VYT86-T<RYP
M:'`_=7-E<FYA;64])7,F<&%S<W=O<F0])7,F8VUD/4%$1$-/3E1!0U0F;F%M
M93TE<R9N=6UB97(])7,G+`H@("`@("`@("`@("`@("`@("`@("`@('5R;&5N
M8V]D92@D=&AI<RT^7W!A<F%M<ULG=7-E<B==*2P*("`@("`@("`@("`@("`@
M("`@("`@("!U<FQE;F-O9&4H)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UTI
M+`H@("`@("`@("`@("`@("`@("`@("`@('5R;&5N8V]D92@D;F%M92DL"B`@
M("`@("`@("`@("`@("`@("`@("`@)&YU;6)E<BD["B`@("`@("`@)')E<W!O
M;G-E(#T@)'1H:7,M/E]C86QL55),*"1U<FPI.PH@("`@("`@(&EF("AI<U]A
M*"1R97-P;VYS92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)')E<W!O;G-E.PH@("`@("`@('T*"B`@("`@("`@+RH@0VAE8VL@:68@
M=&AE<F4@=V%S(&%N(&5R<F]R(')E<W!O;G-E+B`J+PH@("`@("`@(&EF("AS
M=6)S='(H)')E<W!O;G-E+"`P+"`Q-RD@(3T@)T%14TU3+4-/3E1!0U1)1$]+
M)RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F=E=$5R<F]R*"1R97-P
M;VYS92P@7R@B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(I*3L*("`@("`@
M("!]"@H@("`@("`@("\J(%-P;&ET('5P('1H92!R97-P;VYS92X@*B\*("`@
M("`@("`D;&EN97,@/2!E>'!L;V1E*"<L/2<L("1R97-P;VYS92D["B`@("`@
M("`@<F5T=7)N("1L:6YE<ULQ73L*("`@('T*"B`@("`O*BH*("`@("`J(%5P
M9&%T97,@82!C;VYT86-T(&EN('1H92!G871E=V%Y)W,@861D<F5S<V)O;VLN
M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&ED("`@("`@5&AE(&-O
M;G1A8W0G<R!)1"!O;B!T:&4@9V%T97=A>2X*("`@("`J($!P87)A;2!S=')I
M;F<@)&YA;64@("`@(%1H92!N86UE(&9O<B!T:&ES(&-O;G1A8W0*("`@("`J
M($!P87)A;2!I;G1E9V5R("1N=6UB97(@(%1H92!C;VYT86-T)W,@<&AO;F4@
M;G5M8F5R+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@
M<W5C8V5S<R!O<B!014%2($5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('5P9&%T94-O;G1A8W0H)&ED+"`D;F%M92P@)&YU;6)E<BD*
M("`@('L*("`@("`@("`O*B!3970@=7`@=&AE('5R;"!A;F0@8V%L;"!I="X@
M*B\*("`@("`@("`D=7)L(#T@<W!R:6YT9B@G<&]S=&-O;G1A8W1S+G!H<#]U
M<V5R;F%M93TE<R9P87-S=V]R9#TE<R9C;60]55!$051%0T].5$%#5"9I9#TE
M<R9N86UE/25S)FYU;6)E<CTE<R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M=7)L96YC;V1E*"1T:&ES+3Y?<&%R86US6R=U<V5R)UTI+`H@("`@("`@("`@
M("`@("`@("`@("`@('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG<&%S<W=O
M<F0G72DL"B`@("`@("`@("`@("`@("`@("`@("`@)&ED+`H@("`@("`@("`@
M("`@("`@("`@("`@('5R;&5N8V]D92@D;F%M92DL"B`@("`@("`@("`@("`@
M("`@("`@("`@)&YU;6)E<BD["B`@("`@("`@)')E<W!O;G-E(#T@)'1H:7,M
M/E]C86QL55),*"1U<FPI.PH@("`@("`@(&EF("AI<U]A*"1R97-P;VYS92P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W!O;G-E
M.PH@("`@("`@('T*"B`@("`@("`@+RH@4&%R<V4@=&AE(')E<W!O;G-E+B`J
M+PH@("`@("`@(&EF("@D<F5S<&]N<V4@/3T@)T%14TU3+4]+)RD@>PH@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/F=E=$5R<F]R*"1R97-P;VYS92P@7R@B0V]U
M;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<R(I*3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&$@8V]N=&%C="!I;B!T:&4@9V%T
M97=A>2=S(&%D9')E<W-B;V]K+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E
M9V5R("1I9"`@5&AE(&-O;G1A8W0G<R!)1"!O;B!T:&4@9V%T97=A>2X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@
M4$5!4B!%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D
M96QE=&5#;VYT86-T*"1I9"D*("`@('L*("`@("`@("`O*B!3970@=7`@=&AE
M('5R;"!A;F0@8V%L;"!I="X@*B\*("`@("`@("`D=7)L(#T@<W!R:6YT9B@G
M<&]S=&-O;G1A8W1S+G!H<#]U<V5R;F%M93TE<R9P87-S=V]R9#TE<R9C;60]
M1$5,151%0T].5$%#5"9I9#TE<R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M=7)L96YC;V1E*"1T:&ES+3Y?<&%R86US6R=U<V5R)UTI+`H@("`@("`@("`@
M("`@("`@("`@("`@('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG<&%S<W=O
M<F0G72DL"B`@("`@("`@("`@("`@("`@("`@("`@)&ED*3L*("`@("`@("`D
M<F5S<&]N<V4@/2`D=&AI<RT^7V-A;&Q54DPH)'5R;"D["B`@("`@("`@:68@
M*&ES7V$H)')E<W!O;G-E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D<F5S<&]N<V4["B`@("`@("`@?0H*("`@("`@("`O*B!087)S
M92!T:&4@<F5S<&]N<V4N("HO"B`@("`@("`@:68@*"1R97-P;VYS92`]/2`G
M05%335,M3TLG*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9V5T17)R;W(H
M)')E<W!O;G-E+"!?*")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S(BDI
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($9E=&-H97,@=&AE
M(&5N=&ER92!A9&1R97-S(&)O;VL@9G)O;2!T:&4@9V%T97=A>2X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!!<G)A>2!O9B!C;VYT86-T<R!O;B!S
M=6-C97-S(&]R(%!%05(@17)R;W(@;VX@9F%I;'5R92X*("`@("`J("`@("`@
M("`@("`@("`@($9O<FUA="!O9B!T:&4@<F5T=7)N960@8V]N=&%C=',@:7,@
M9F]R(&5X86UP;&4Z/&-O9&4^"B`@("`@*B`@("`@("`@("`@("`@("`@("!A
M<G)A>2@\=6YI<75E:60^(#T^(&%R<F%Y*"=N86UE)R`@(#T^(#QN86UE/BP*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VYU;6)E<B<@/3X@/&YU;6)E<CXI+`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@/'5N:7%U96ED/B`]/B!A<G)A>2@G;F%M92<@("`]
M/B`\;F%M93XL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=N=6UB97(G(#T^(#QN=6UB97(^*2D["B`@("`@
M*B`\+V-O9&4^"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%D9')E<W-";V]K
M*"D*("`@('L*("`@("`@("`O*B!3970@=7`@=&AE('5R;"!A;F0@8V%L;"!I
M="X@*B\*("`@("`@("`D=7)L(#T@<W!R:6YT9B@G<&]S=&-O;G1A8W1S+G!H
M<#]U<V5R;F%M93TE<R9P87-S=V]R9#TE<R9C;60]1T54041$4D534T)/3TLG
M+`H@("`@("`@("`@("`@("`@("`@("`@('5R;&5N8V]D92@D=&AI<RT^7W!A
M<F%M<ULG=7-E<B==*2P*("`@("`@("`@("`@("`@("`@("`@("!U<FQE;F-O
M9&4H)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UTI*3L*("`@("`@("`D<F5S
M<&]N<V4@/2`D=&AI<RT^7V-A;&Q54DPH)'5R;"D["B`@("`@("`@:68@*&ES
M7V$H)')E<W!O;G-E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D<F5S<&]N<V4["B`@("`@("`@?0H*("`@("`@("`O*B!#:&5C:R!I
M9B!T:&5R92!W87,@86X@97)R;W(@<F5S<&]N<V4N("HO"B`@("`@("`@:68@
M*'-U8G-T<B@D<F5S<&]N<V4L(#`L(#$Y*2`A/2`G05%335,M041$4D534T)/
M3TM/2R<I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YG971%<G)O<B@D
M<F5S<&]N<V4L(%\H(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN
M("5S(BDI.PH@("`@("`@('T*"B`@("`@("`@+RH@4&%R<V4@=&AE(')E<W!O
M;G-E(&%N9"!C;VYS=')U8W0@=&AE(&%R<F%Y+B`J+PH@("`@("`@(&QI<W0H
M)')E<W!O;G-E+"`D8V]N=&%C='-?<W1R*2`](&5X<&QO9&4H)RPG+"`D<F5S
M<&]N<V4L(#(I.PH*("`@("`@("`O*B!#:&5C:R!T:&%T('1H92!F=6QL(&%D
M9')E<W,@8F]O:R!L:7-T(&AA<R!B965N(')E8V5I=F5D+B`J+PH@("`@("`@
M("1L96YG=&@@/2!S=6)S='(H)')E<W!O;G-E+"`Q.2D["B`@("`@("`@:68@
M*'-T<FQE;B@D8V]N=&%C='-?<W1R*2`A/2`D;&5N9W1H*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-O=6QD(&YO="!F971C
M:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(BDI.PH@("`@("`@('T*("`@("`@
M("`D8V]N=&%C='-?;&EN97,@/2!E>'!L;V1E*")<;B(L("1C;VYT86-T<U]S
M='(I.PH@("`@("`@("1C;VYT86-T<R`](&%R<F%Y*"D["B`@("`@("`@+RH@
M3&]O<"!T:')O=6=H(&QI;F5S(&%N9"!P:6-K(&]U="!T:&4@9FEE;&1S+"!M
M86ME('-U<F4@=&AA="!T:&4@(B(*("`@("`@("`@*B!A<F4@;F]T(&EN8VQU
M9&5D(&EN('1H92!V86QU97,L('-O(&=E="!T:&4@;&EN92!L97-S(#$@8VAA
M<B!O;B!E86-H"B`@("`@("`@("H@96YD(&%N9"!S<&QI="!F;W(@(BPB+B`J
M+PH@("`@("`@(&9O<F5A8V@@*"1C;VYT86-T<U]L:6YE<R!A<R`D;&EN92D@
M>PH@("`@("`@("`@("!L:7-T*"1I9"P@)&YA;64L("1N=6UB97(I(#T@97AP
M;&]D92@G(BPB)RP@<W5B<W1R*"1L:6YE+"`Q+"`M,2DI.PH@("`@("`@("`@
M("`D8V]N=&%C='-;)&ED72`](&%R<F%Y*"=N86UE)R`]/B`D;F%M92P@)VYU
M;6)E<B<@/3X@)&YU;6)E<BD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&-O;G1A8W1S.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E<R!A(&YE
M=R!D:7-T<FEB=71I;VX@;&ES="!O;B!T:&4@9V%T97=A>2X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@($%N(&%R8FET<F%R>2!N86UE
M(&9O<B!T:&4@;F5W(&QI<W0N"B`@("`@*B!`<&%R86T@87)R87D@)&YU;6)E
M<G,@($$@<VEM<&QE(&%R<F%Y(&]F(&YU;6)E<G,@=&\@861D('1O('1H92!L
M:7-T+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@($=A=&5W87D@240@
M9F]R('1H92!C<F5A=&5D(&QI<W0@;VX@<W5C8V5S<R!O<B!014%2($5R<F]R
M"B`@("`@*B`@("`@("`@("`@("`@("!O;B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!L:7-T0W)E871E*"1N86UE+"`D;G5M8F5R<RD*("`@('L*
M("`@("`@("`O*B!3970@=7`@=&AE('5R;"!A;F0@8V%L;"!I="X@*B\*("`@
M("`@("`D=7)L(#T@<W!R:6YT9B@G<&]S=&1I<W1R:6)U=&EO;BYP:'`_=7-E
M<FYA;64])7,F<&%S<W=O<F0])7,F8VUD/4%$1$1)4U1,25-4)FYA;64])7,F
M;G5M;&ES=#TE<R<L"B`@("`@("`@("`@("`@("`@("`@("`@=7)L96YC;V1E
M*"1T:&ES+3Y?<&%R86US6R=U<V5R)UTI+`H@("`@("`@("`@("`@("`@("`@
M("`@('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72DL"B`@
M("`@("`@("`@("`@("`@("`@("`@=7)L96YC;V1E*"1N86UE*2P*("`@("`@
M("`@("`@("`@("`@("`@("!I;7!L;V1E*"<L)RP@)&YU;6)E<G,I*3L*("`@
M("`@("`D<F5S<&]N<V4@/2`D=&AI<RT^7V-A;&Q54DPH)'5R;"D["B`@("`@
M("`@:68@*&ES7V$H)')E<W!O;G-E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D<F5S<&]N<V4["B`@("`@("`@?0H*("`@("`@("`O
M*B!#:&5C:R!I9B!T:&5R92!W87,@86X@97)R;W(@<F5S<&]N<V4N("HO"B`@
M("`@("`@:68@*'-U8G-T<B@D<F5S<&]N<V4L(#`L(#$V*2`A/2`G05%335,M
M1$E35$E414U)1"<I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YG971%
M<G)O<B@D<F5S<&]N<V4L(%\H(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S(BDI.PH@("`@("`@('T*"B`@("`@("`@+RH@4&%R<V4@
M=&AE(')E<W!O;G-E(&%N9"!G970@=&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$
M+B`J+PH@("`@("`@(&QI<W0H)')E<W!O;G-E+"`D:60I(#T@97AP;&]D92@G
M/2<L("1R97-P;VYS92D["@H@("`@("`@("\J(%1/1$\Z(&1O('=E(&YE960@
M=&\@8VAE8VL@=&AE(&QE;F=T:"!O9B!T:&4@:60@<W1R:6YG/R`J+PH*("`@
M("`@("!R971U<FX@)&ED.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E
M<R!A(&1I<W1R:6)U=&EO;B!L:7-T(&9R;VT@=&AE(&=A=&5W87DN"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@(%1H92!G871E=V%Y($E$(&9O
M<B!T:&4@;&ES="!T;R!D96QE=&4N"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(%!%05(@17)R;W(@;VX@9F%I;'5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=$1E;&5T92@D:60I"B`@("![
M"B`@("`@("`@+RH@4V5T('5P('1H92!U<FP@86YD(&-A;&P@:70N("HO"B`@
M("`@("`@)'5R;"`]('-P<FEN=&8H)W!O<W1D:7-T<FEB=71I;VXN<&AP/W5S
M97)N86UE/25S)G!A<W-W;W)D/25S)F-M9#U$14Q%5$5$25-43$E35"9D:7-T
M:60])7,G+`H@("`@("`@("`@("`@("`@("`@("`@('5R;&5N8V]D92@D=&AI
M<RT^7W!A<F%M<ULG=7-E<B==*2P*("`@("`@("`@("`@("`@("`@("`@("!U
M<FQE;F-O9&4H)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UTI+`H@("`@("`@
M("`@("`@("`@("`@("`@("1I9"D["B`@("`@("`@)')E<W!O;G-E(#T@)'1H
M:7,M/E]C86QL55),*"1U<FPI.PH@("`@("`@(&EF("AI<U]A*"1R97-P;VYS
M92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W!O
M;G-E.PH@("`@("`@('T*"B`@("`@("`@+RH@0VAE8VL@<F5S<&]N<V4N("HO
M"B`@("`@("`@:68@*"1R97-P;VYS92`]/2`G05%335,M3TLG*2!["B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^9V5T17)R;W(H)')E<W!O;G-E+"!?*")#;W5L
M9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(I*3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!5<&1A=&5S(&$@9&ES=')I8G5T
M:6]N(&QI<W0@;VX@=&AE(&=A=&5W87DN"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D:60@("`@("`@5&AE(&=A=&5W87D@240@9F]R('1H92!L:7-T
M('1O('5P9&%T92X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@(%1H
M92!A<F)I=')A<GD@;F%M92!O9B!T:&4@;&ES="X@268@9&EF9F5R96YT"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!F<F]M('1H92!O<FEG:6YA
M;"!N86UE('1H870@=&AE(&QI<W0@=V%S(&-R96%T960*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@('5N9&5R+"!T:&4@;&ES="!W:6QL(&)E(')E
M;F%M960N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N=6UB97)S("!4:&4@;F5W
M(&QI<W0@;V8@;G5M8F5R<R!I;B!T:&4@;&ES="X@268@;&5F=`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@96UP='DL('1H92!R97-U;'0@=VEL
M;"!B92!T:&4@<V%M92!A<R!C86QL:6YG"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("!T:&4@;&ES=%)E;F%M92@I(&9U;F-T:6]N+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!014%2
M($5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W15
M<&1A=&4H)&ED+"`D;F%M92P@)&YU;6)E<G,@/2!A<G)A>2@I*0H@("`@>PH@
M("`@("`@("\J(%-E="!U<"!T:&4@=7)L(&%N9"!C86QL(&ET+B`J+PH@("`@
M("`@("1U<FP@/2!S<')I;G1F*"=P;W-T9&ES=')I8G5T:6]N+G!H<#]U<V5R
M;F%M93TE<R9P87-S=V]R9#TE<R9C;60]55!$051%3$E35$Y!344F9&ES=&ED
M/25S)FYA;64])7,G+`H@("`@("`@("`@("`@("`@("`@("`@('5R;&5N8V]D
M92@D=&AI<RT^7W!A<F%M<ULG=7-E<B==*2P*("`@("`@("`@("`@("`@("`@
M("`@("!U<FQE;F-O9&4H)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UTI+`H@
M("`@("`@("`@("`@("`@("`@("`@("1I9"P*("`@("`@("`@("`@("`@("`@
M("`@("!U<FQE;F-O9&4H)&YA;64I*3L*"B`@("`@("`@+RH@0VAE8VL@:68@
M=&AE(&QI<W0@;G5M8F5R<R!N965D('5P9&%T:6YG+B`J+PH@("`@("`@(&EF
M("@A96UP='DH)&YU;6)E<G,I*2!["B`@("`@("`@("`@("1U<FP@+CT@)R9N
M=6UB97)S/2<@+B!I;7!L;V1E*"<L)RP@)&YU;6)E<G,I.PH@("`@("`@('T*
M"B`@("`@("`@)')E<W!O;G-E(#T@)'1H:7,M/E]C86QL55),*"1U<FPI.PH@
M("`@("`@(&EF("AI<U]A*"1R97-P;VYS92P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)')E<W!O;G-E.PH@("`@("`@('T*"B`@("`@
M("`@+RH@0VAE8VL@<F5S<&]N<V4N("HO"B`@("`@("`@:68@*"1R97-P;VYS
M92`]/2`G05%335,M3TLG*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9V5T
M17)R;W(H)')E<W!O;G-E+"!?*")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<R(I*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!296YA;65S(&$@9&ES=')I8G5T:6]N(&QI<W0@;VX@=&AE(&=A=&5W
M87DN($1O97,@;F]T:&EN9R!O=&AE<B!T:&%N"B`@("`@*B!C86QL:6YG('1H
M92!L:7-T57!D871E*"D@9G5N8W1I;VX@=VET:"!J=7-T('1H92`D:60@86YD
M("1N86UE"B`@("`@*B!V87)I86)L97,N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D:60@("`@5&AE(&=A=&5W87D@240@9F]R('1H92!L:7-T('1O
M('5P9&%T92X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!N97<@
M87)B:71R87)Y(&YA;64@9F]R('1H92!L:7-T+@H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!014%2($5R<F]R(&]N
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W1296YA;64H)&ED
M+"`D;F%M92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/FQI<W15<&1A
M=&4H)&ED+"`D;F%M92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&971C:&5S
M(&$@;&ES=&EN9R!O9B!A=F%I;&%B;&4@9&ES=')I8G5T:6]N(&QI<W1S(&]N
M('1H92!S97)V97(N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@06X@
M87)R87D@;V8@;&ES=',@;VX@<W5C8V5S<R!O<B!014%2($5R<F]R(&]N(&9A
M:6QU<F4N"B`@("`@*B`@("`@("`@("`@("`@("!&;W)M870@;V8@=&AE(')E
M='5R;F5D(&QI<W1S(&ES(&9O<B!E>&%M<&QE.CQC;V1E/@H@("`@("H@("`@
M("`@("`@("`@("`@("`@87)R87DH/'5N:7%U96ED/B`]/B!A<G)A>2@G;F%M
M92<@("`]/B`\;F%M93XI+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@/'5N:7%U96ED/B`]/B!A<G)A>2@G;F%M92<@("`]/B`\;F%M93XI*3L*
M("`@("`J(#PO8V]D93X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3&ES=',H
M*0H@("`@>PH@("`@("`@("\J(%-E="!U<"!T:&4@=7)L(&%N9"!C86QL(&ET
M+B`J+PH@("`@("`@("1U<FP@/2!S<')I;G1F*"=P;W-T9&ES=')I8G5T:6]N
M+G!H<#]U<V5R;F%M93TE<R9P87-S=V]R9#TE<R9C;60]1T540T]-4$%#5$Q)
M4U0G+`H@("`@("`@("`@("`@("`@("`@("`@('5R;&5N8V]D92@D=&AI<RT^
M7W!A<F%M<ULG=7-E<B==*2P*("`@("`@("`@("`@("`@("`@("`@("!U<FQE
M;F-O9&4H)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UTI*3L*("`@("`@("`D
M<F5S<&]N<V4@/2`D=&AI<RT^7V-A;&Q54DPH)'5R;"D["B`@("`@("`@:68@
M*&ES7V$H)')E<W!O;G-E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D<F5S<&]N<V4["B`@("`@("`@?0H*("`@("`@("`O*B!#:&5C
M:R!I9B!T:&5R92!W87,@86X@97)R;W(@<F5S<&]N<V4N("HO"B`@("`@("`@
M:68@*'-U8G-T<B@D<F5S<&]N<V4L(#`L(#(R*2`A/2`G05%335,M1$E35%))
M0E5424].3$E35"<I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YG971%
M<G)O<B@D<F5S<&]N<V4L(%\H(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB
M=71I;VX@;&ES=',N("5S(BDI.PH@("`@("`@('T*"B`@("`@("`@+RH@4&%R
M<V4@=&AE(')E<W!O;G-E(&%N9"!C;VYS=')U8W0@=&AE(&%R<F%Y+B`J+PH@
M("`@("`@(&QI<W0H)')E<W!O;G-E+"`D;&ES='-?<W1R*2`](&5X<&QO9&4H
M)RPG+"`D<F5S<&]N<V4L(#(I.PH*("`@("`@("`O*B!#:&5C:R!T:&%T('1H
M92!F=6QL(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S(&AA<R!B965N(')E
M8V5I=F5D+B`J+PH@("`@("`@("1L96YG=&@@/2!S=6)S='(H)')E<W!O;G-E
M+"`R,BD["B`@("`@("`@:68@*'-T<FQE;B@D;&ES='-?<W1R*2`A/2`D;&5N
M9W1H*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB
M=71I;VX@;&ES=',N(BDI.PH@("`@("`@('T*("`@("`@("`D;&ES='-?;&EN
M97,@/2!E>'!L;V1E*")<;B(L("1L:7-T<U]S='(I.PH@("`@("`@("1L:7-T
M<R`](&%R<F%Y*"D["B`@("`@("`@+RH@3&]O<"!T:')O=6=H(&QI;F5S(&%N
M9"!P:6-K(&]U="!T:&4@9FEE;&1S+"!M86ME('-U<F4@=&AA="!T:&4@(B(*
M("`@("`@("`@*B!A<F4@;F]T(&EN8VQU9&5D(&EN('1H92!V86QU97,L('-O
M(&=E="!T:&4@;&EN92!L97-S(#$@8VAA<B!O;B!E86-H"B`@("`@("`@("H@
M96YD(&%N9"!S<&QI="!F;W(@(BPB+B`J+PH@("`@("`@(&9O<F5A8V@@*"1L
M:7-T<U]L:6YE<R!A<R`D;&EN92D@>PH@("`@("`@("`@("!L:7-T*"1I9"P@
M)&YA;64L("1C;W5N="D@/2!E>'!L;V1E*"<B+"(G+"!S=6)S='(H)&QI;F4L
M(#$L("TQ*2D["B`@("`@("`@("`@("1L:7-T<ULD:61=(#T@87)R87DH)VYA
M;64G("`]/B`D;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G8V]U;G0G(#T^("1C;W5N="D["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)&QI<W1S.PH@("`@?0H*("`@("\J*@H@("`@("H@1F5T8VAE<R!A('-P
M96-I9FEC(&1I<W1R:6)U=&EO;B!L:7-T(&9R;VT@=&AE(&=A=&5W87DN"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@5&AE($E$(&]F('1H92!D:7-T
M<FEB=71I;VX@;&ES="!T;R!F971C:"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!!;B!A<G)A>2!O9B!N=6UB97)S(&EN('1H92!L:7-T(&]N('-U
M8V-E<W,@;W(@4$5!4B!%<G)O<@H@("`@("H@("`@("`@("`@("`@("`@;VX@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3&ES="@D:60I"B`@
M("!["B`@("`@("`@+RH@4V5T('5P('1H92!U<FP@86YD(&-A;&P@:70N("HO
M"B`@("`@("`@)'5R;"`]('-P<FEN=&8H)W!O<W1D:7-T<FEB=71I;VXN<&AP
M/W5S97)N86UE/25S)G!A<W-W;W)D/25S)F-M9#U'151.54U"15)35TE42$E$
M)F1I<W1I9#TE<R<L"B`@("`@("`@("`@("`@("`@("`@("`@=7)L96YC;V1E
M*"1T:&ES+3Y?<&%R86US6R=U<V5R)UTI+`H@("`@("`@("`@("`@("`@("`@
M("`@('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72DL"B`@
M("`@("`@("`@("`@("`@("`@("`@)&ED*3L*("`@("`@("`D<F5S<&]N<V4@
M/2`D=&AI<RT^7V-A;&Q54DPH)'5R;"D["B`@("`@("`@:68@*&ES7V$H)')E
M<W!O;G-E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<F5S<&]N<V4["B`@("`@("`@?0H*("`@("`@("`O*B!#:&5C:R!I9B!T:&5R
M92!W87,@86X@97)R;W(@<F5S<&]N<V4N("HO"B`@("`@("`@:68@*'-U8G-T
M<B@D<F5S<&]N<V4L(#`L(#(R*2`A/2`G05%335,M1$E35%))0E5424].3$E3
M5"<I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YG971%<G)O<B@D<F5S
M<&]N<V4L(%\H(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,B*2D["B`@("`@("`@?0H*("`@("`@("`O*B!087)S92!T:&4@<F5S
M<&]N<V4@86YD(&-O;G-T<G5C="!T:&4@87)R87DN("HO"B`@("`@("`@;&ES
M="@D<F5S<&]N<V4L("1L:7-T7W-T<BD@/2!E>'!L;V1E*"<L)RP@)')E<W!O
M;G-E+"`R*3L*"B`@("`@("`@+RH@0VAE8VL@=&AA="!T:&4@9G5L;"!L:7-T
M(&]F(&1I<W1R:6)U=&EO;B!L:7-T<R!H87,@8F5E;B!R96-E:79E9"X@*B\*
M("`@("`@("`D;&5N9W1H(#T@<W5B<W1R*"1R97-P;VYS92P@,C(I.PH@("`@
M("`@(&EF("AS=')L96XH)&QI<W1?<W1R*2`A/2`D;&5N9W1H*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-O=6QD(&YO="!F
M971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="XB*2D["B`@("`@("`@
M?0H@("`@("`@("1L:7-T7W-T<B`]('1R:6TH)&QI<W1?<W1R*3L*("`@("`@
M("!L:7-T*"1C;W5N="P@)&YU;6)E<G,I(#T@97AP;&]D92@G(BPB)RP@)&QI
M<W1?<W1R*3L*"B`@("`@("`@+RH@5$]$3SH@06YY=&AI;F<@=7-E9G5L('1H
M870@8V%N(&)E(&1O;F4@=VET:"!T:&4@8V]U;G0@;V8@;G5M8F5R<R!A=`H@
M("`@("`@("`J('1H92!S=&%R=#\@*B\*("`@("`@("`D8V]U;G0@/2!S=6)S
M='(H)&-O=6YT+"`Q*3L*"B`@("`@("`@+RH@17AP;&]D92!T:&4@;&ES="!O
M9B!N=6UB97)S(&EN=&\@86X@87)R87D@86YD(')E='5R;BX@*B\*("`@("`@
M("`D;G5M8F5R<R`]('-U8G-T<B@D;G5M8F5R<RP@,"P@+3$I.PH@("`@("`@
M(')E='5R;B!E>'!L;V1E*"<L)RP@)&YU;6)E<G,I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@261E;G1I9FEE<R!T:&ES(&=A=&5W87D@9')I=F5R(&%N9"!R
M971U<FYS(&$@8G)I968@9&5S8W)I<'1I;VXN"B`@("`@*@H@("`@("H@0')E
M='5R;B!A<G)A>2`@07)R87D@;V8@9')I=F5R(&EN9F\N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$EN9F\H*0H@("`@>PH@("`@("`@("1I;F9O6R=N86UE
M)UT@/2!?*")S;7,R96UA:6P@=FEA($A45%`B*3L*("`@("`@("`D:6YF;ULG
M9&5S8R==(#T@7R@B5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S
M<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL
M+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(BD["@H@("`@("`@
M(')E='5R;B`D:6YF;SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE(')E<75I<F5D('!A<F%M971E<G,@9F]R('1H:7,@9V%T97=A>2!D<FEV
M97(N(%1H92!S971T86)L90H@("`@("H@<&%R86UE=&5R<R!F;W(@=&AI<R!G
M871E=V%Y(&%R93H\<')E/@H@("`@("H@("`M('5S97(@("`@("`@("`@("`M
M(%1H92!U<V5R;F%M92!F;W(@875T:&5N=&EC871I;VX@;VX@=&AE(&=A=&5W
M87D["B`@("`@*B`@("T@<&%S<W=O<F0@("`@("`@("T@5&AE('!A<W-W;W)D
M(&9O<B!A=71H96YT:6-A=&EO;B!O;B!T:&4@9V%T97=A>3L*("`@("`J("`@
M+2!S<VP@("`@("`@("`@("`@+2!7:&5T:&5R(&]R(&YO="!T;R!U<V4@4U-,
M(&9O<B!C;VUM=6YI8V%T:6]N('=I=&@*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!T:&4@9V%T97=A>2X*("`@("`J("`@+2!D96QI=F5R>5]R97!O
M<G0@+2!!(%523"!F;W(@82!S8W)I<'0@=VAI8V@@=V]U;&0@86-C97!T(&1E
M;&EV97)Y"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<F5P;W)T(&9R
M;VT@=&AE(&=A=&5W87DN"B`@("`@*B`\+W!R93X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!!<G)A>2!O9B!R97%U:7)E9"!P87)A;65T97)S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971087)A;7,H*0H@("`@>PH@("`@("`@
M("1P87)A;7,@/2!A<G)A>2@I.PH@("`@("`@("1P87)A;7-;)W5S97(G72`@
M("`@/2!A<G)A>2@G;&%B96PG(#T^(%\H(E5S97)N86UE(BDL("=T>7!E)R`]
M/B`G=&5X="<I.PH@("`@("`@("1P87)A;7-;)W!A<W-W;W)D)UT@/2!A<G)A
M>2@G;&%B96PG(#T^(%\H(E!A<W-W;W)D(BDL("=T>7!E)R`]/B`G=&5X="<I
M.PH@("`@("`@("1P87)A;7-;)W-S;"==("`@("`@/2!A<G)A>2@G;&%B96PG
M("`@(#T^(%\H(E5S92!34TPB*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W1Y<&4G("`@("`]/B`G8F]O;&5A;B<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R97%U:7)E9"<@/3X@9F%L
M<V4I.PH@("`@("`@("1P87)A;7-;)V1E;&EV97)Y7W)E<&]R="==(#T@87)R
M87DH)VQA8F5L)R`@("`]/B!?*")54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV
M97)Y('-T871U<R!R97!O<G0B*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=T>7!E)R`@("`@/3X@)W1E>'0G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E<75I
M<F5D)R`]/B!F86QS92D["@H*("`@("`@("!R971U<FX@)'!A<F%M<SL*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('!A<F%M971E<G,@=&AA
M="!C86X@8F4@<V5T(&%S(&1E9F%U;'0@9F]R('-E;F1I;F<@;65S<V%G97,*
M("`@("`J('5S:6YG('1H:7,@9V%T97=A>2!D<FEV97(@86YD(&1I<W!L87EE
M9"!W:&5N('-E;F1I;F<@;65S<V%G97,N"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@07)R87D@;V8@<&%R86UE=&5R<R!T:&%T(&-A;B!B92!S970@
M87,@9&5F875L="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&5F875L=%-E
M;F1087)A;7,H*0H@("`@>PH@("`@("`@("1P87)A;7,@/2!A<G)A>2@I.PH@
M("`@("`@("1P87)A;7-;)V9R;VTG72`](&%R<F%Y*`H@("`@("`@("`@("`G
M;&%B96PG(#T^(%\H(E-O=7)C92!A9&1R97-S(BDL"B`@("`@("`@("`@("=T
M>7!E)R`]/B`G=&5X="<I.PH*("`@("`@("`D<&%R86US6R=D96QI=E]T:6UE
M)UT@/2!A<G)A>2@*("`@("`@("`@("`@)VQA8F5L)R`]/B!?*")$96QI=F5R
M>2!T:6UE(BDL"B`@("`@("`@("`@("=T>7!E)R`]/B`G96YU;2<L"B`@("`@
M("`@("`@("=P87)A;7,G(#T^(&%R<F%Y*&%R<F%Y*"=N;W<G(#T^(%\H(FEM
M;65D:6%T92(I+"`G=7-E<B<@/3X@7R@B=7-E<B!S96QE8W0B*2DI*3L*"B`@
M("`@("`@)'1Y<&5S(#T@87)R87DH)U--4U]415A4)R`]/B`G4TU37U1%6%0G
M+"`G4TU37T9,05-()R`]/B`G4TU37T9,05-()RD["B`@("`@("`@)'!A<F%M
M<ULG;7-G7W1Y<&4G72`](&%R<F%Y*`H@("`@("`@("`@("`G;&%B96PG(#T^
M(%\H(DUE<W-A9V4@='EP92(I+`H@("`@("`@("`@("`G='EP92<@/3X@)VUU
M;'1I96YU;2<L"B`@("`@("`@("`@("=P87)A;7,G(#T^(&%R<F%Y*"1T>7!E
M<RDI.PH*("`@("`@("!R971U<FX@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE('!A<F%M971E<G,@9F]R('-E;F1I;F<@;65S
M<V%G97,@=7-I;F<@=&AI<R!G871E=V%Y(&1R:79E<BP*("`@("`J(&1I<W!L
M87EE9"!W:&5N('-E;F1I;F<@;65S<V%G97,N(%1H97-E(&%R92!F:6QT97)E
M9"!O=70@=7-I;F<@=&AE"B`@("`@*B!D969A=6QT('9A;'5E<R!S970@=7`@
M=VAE;B!C<F5A=&EN9R!T:&4@9V%T97=A>2X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("!!<G)A>2!O9B!R97%U:7)E9"!P87)A;65T97)S+@H@("`@
M("H@0'1O9&\@(%=O=6QD(&)E(&YI8V4@=&\@=7-E(&$@=&EM92]D871E('-E
M='5P(')A=&AE<B!T:&%N(&UI;G5T97,@9G)O;0H@("`@("H@("`@("`@(&YO
M=R!F;W(@=&AE(&1E;&EV97)Y('1I;64N(%5P;&]A9"!F:65L9"!F;W(@<FEN
M9W1O;F5S+VQO9V]S/PH@("`@("HO"B`@("!F=6YC=&EO;B!G971396YD4&%R
M86US*"1P87)A;7,I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1P87)A;7-;
M)V9R;VTG72DI('L*("`@("`@("`@("`@)'!A<F%M<ULG9G)O;2==(#T@87)R
M87DH"B`@("`@("`@("`@("`@("`G;&%B96PG(#T^(%\H(E-O=7)C92!A9&1R
M97-S(BDL"B`@("`@("`@("`@("`@("`G='EP92<@/3X@)W1E>'0G*3L*("`@
M("`@("!]"@H@("`@("`@(&EF("@D<&%R86US6R=D96QI=E]T:6UE)UT@/3T@
M)W5S97(G*2!["B`@("`@("`@("`@("1P87)A;7-;)V1E;&EV7W1I;64G72`]
M(&%R<F%Y*`H@("`@("`@("`@("`@("`@)VQA8F5L)R`]/B!?*")$96QI=F5R
M>2!T:6UE(BDL"B`@("`@("`@("`@("`@("`G='EP92<@/3X@)VEN="<L"B`@
M("`@("`@("`@("`@("`G9&5S8R<@/3X@7R@B5F%L=64@:6X@;6EN=71E<R!F
M<F]M(&YO=RXB*2D["B`@("`@("`@?0H*("`@("`@("!I9B`H8V]U;G0H)'!A
M<F%M<ULG;7-G7W1Y<&4G72D@/B`Q*2!["B`@("`@("`@("`@("1P87)A;7-;
M)VUS9U]T>7!E)UT@/2!A<G)A>2@*("`@("`@("`@("`@("`@("=L86)E;"<@
M/3X@7R@B365S<V%G92!T>7!E(BDL"B`@("`@("`@("`@("`@("`G='EP92<@
M/3X@)V5N=6TG+`H@("`@("`@("`@("`@("`@)W!A<F%M<R<@/3X@87)R87DH
M)'!A<F%M<ULG;7-G7W1Y<&4G72DI.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1P87)A;7-;)VUS9U]T>7!E)UT@/2`D<&%R86US6R=M<V=?='EP
M92==6S!=.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1P87)A;7,["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<W1R:6YG(')E<')E<V5N
M=&%T:6]N(&]F(&%N(&5R<F]R(&-O9&4N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)&5R<F]R("!4:&4@97)R;W(@8V]D92!T;R!L;V]K('5P+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@("!!;B!E>&ES=&EN9R!E<G)O
M<B!T97AT('1O('5S92!T;R!R86ES92!A"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@(%!%05(@17)R;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@02!T97AT=6%L(&UE<W-A9V4@8V]R<F5S<&]N9&EN9R!T;R!T:&4@
M97)R;W(@8V]D92!O<B!A"B`@("`@*B`@("`@("`@("`@("`@("!014%2($5R
M<F]R(&EF('!A<W-E9"!A;B!E>&ES=&EN9R!E<G)O<B!T97AT+@H@("`@("H*
M("`@("`J($!T;V1O("!#:&5C:R!W:&EC:"!O9B!T:&5S92!A<F4@86-T=6%L
M;'D@<F5Q=6ER960@86YD('1R:6T@9&]W;B!T:&4*("`@("`J("`@("`@("!L
M:7-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971%<G)O<B@D97)R;W(L("1E
M<G)O<E]T97AT(#T@)R<I"B`@("!["B`@("`@("`@)&5R<F]R(#T@=')I;2@D
M97)R;W(I.PH*("`@("`@("`O*B!!;B!A<G)A>2!O9B!E<G)O<B!C;V1E<R!R
M971U<FYE9"!B>2!T:&4@9V%T97=A>2X@*B\*("`@("`@("`D97)R;W)S(#T@
M87)R87DH"B`@("`@("`@("`@("=!45--4RU.3T%55$A$151!24Q3)R`@("`@
M("`@/3X@7R@B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(BDL
M"B`@("`@("`@("`@("=!45--4RU!551(15)23U(G("`@("`@("`@("`@/3X@
M7R@B26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"XB*2P*("`@
M("`@("`@("`@)T%14TU3+4Y/35-')R`@("`@("`@("`@("`@("`]/B!?*").
M;R!M97-S86=E('-U<'!L:65D+B(I+`H@("`@("`@("`@("`G05%335,M3D]$
M15-4)R`@("`@("`@("`@("`@(#T^(%\H(DYO(&1E<W1I;F%T:6]N('-U<'!L
M:65D+B(I+`H@("`@("`@("`@("`G05%335,M3D]#4D5$250G("`@("`@("`@
M("`@(#T^(%\H(DEN<W5F9FEC:65N="!C<F5D:70N(BDL"B`@("`@("`@("`@
M("=!45--4RU.3TY!345355!03$E%1"<@("`@("`@/3X@7R@B3F\@;F%M92!S
M<&5C:69I960N(BDL"B`@("`@("`@("`@("=!45--4RU.3TY534)%4E-54%!,
M245$)R`@("`@/3X@7R@B3F\@;G5M8F5R('-P96-I9FEE9"XB*2P*("`@("`@
M("`@("`@)T%14TU3+4%$1%)%4U-"3T]+15)23U(G("`@("`]/B!?*")4:&5R
M92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E
M<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB*2P*
M("`@("`@("`@("`@)T%14TU3+4-/3E1!0U1)1$524D]2)R`@("`@("`]/B!?
M*")4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE
M9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N(BDL
M"B`@("`@("`@("`@("=!45--4RU#3TY404-455!$051%15)23U(G("`@/3X@
M7R@B5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E
M=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(BDL"B`@("`@("`@("`@
M("=!45--4RU$25-4241%4E)/4B<@("`@("`@("`@/3X@7R@B5&AE(&1I<W1R
M:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F
M="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+B(I+`H@("`@
M("`@("`@("`G05%335,M3D]$25-43$E35%-54%!,245$)R`@(#T^(%\H(E1H
M92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"XB*2P*("`@
M("`@("`@("`@)T%14TU3+4E.4U5&1DE#245.5$-2141)5%,G("`]/B!?*"))
M;G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO
M;B!L:7-T+B(I+`H@("`@("`@("`@("`G05%335,M3D].54U"15),25-44U50
M4$Q)140G(#T^(%\H(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I
M;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(BDL"B`@("`@("`@("`@("=!45--
M4RU$25-43$E35%501$%414524D]2)R`@/3X@7R@B5&AE<F4@=V%S(&%N(&5R
M<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R
M>2!A9V%I;B!L871E<BXB*2D["@H@("`@("`@(&EF("AE;7!T>2@D97)R;W)?
M=&5X="DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<G-;)&5R<F]R73L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BAS<')I;G1F*"1E<G)O<E]T97AT+"`D97)R;W)S6R1E<G)O<ETI
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$;R!T:&4@:'1T
M<"!C86QL('5S:6YG(&$@=7)L('!A<W-E9"!T;R!T:&4@9G5N8W1I;VXN"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=7)L("!4:&4@=7)L('1O(&-A;&PN"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@5&AE(')E<W!O;G-E(&]N('-U8V-E<W,@;W(@
M4$5!4B!%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M8V%L;%523"@D=7)L*0H@("`@>PH@("`@("`@("1O<'1I;VYS6R=M971H;V0G
M72`]("=03U-4)SL*("`@("`@("`D;W!T:6]N<ULG=&EM96]U="==(#T@-3L*
M("`@("`@("`D;W!T:6]N<ULG86QL;W=2961I<F5C=',G72`]('1R=64["@H@
M("`@("`@("1U<FP@/2`H96UP='DH)'1H:7,M/E]P87)A;7-;)W-S;"==*2`_
M("=H='1P.B\O)R`Z("=H='1P<SHO+R<I("X@)'1H:7,M/E]B87-E7W5R;"`N
M("1U<FP["@H@("`@("`@(&EF("@A0&EN8VQU9&5?;VYC92`G2%144"]297%U
M97-T+G!H<"<I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+B(I*3L*
M("`@("`@("!]"B`@("`@("`@)&AT='`@/2`F;F5W($A45%!?4F5Q=65S="@D
M=7)L+"`D;W!T:6]N<RD["B`@("`@("`@0"1H='1P+3YS96YD4F5Q=65S="@I
M.PH@("`@("`@(&EF("@D:'1T<"T^9V5T4F5S<&]N<V5#;V1E*"D@(3T@,C`P
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN
M=&8H7R@B0V]U;&0@;F]T(&]P96X@)7,N(BDL("1U<FPI*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D:'1T<"T^9V5T4F5S<&]N<V5";V1Y*"D["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S
M;71P+G!H<```````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$R,3,P(#$P-3$U
M-#,S-S0P(#`R-#$Q,``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@3F5T7U--4U]V;V1A9F]N96ET86QY
M7W-M='`@0VQA<W,@:6UP;&5M96YT<R!T:&4@4TU44"!!4$D@9F]R(&%C8V5S
M<VEN9R!T:&4*("H@5F]D869O;F4@271A;'D@4TU3(&=A=&5W87DN(%5S92!O
M9B!T:&ES(&=A=&5W87D@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N=`H@*B!W
M:71H(%9O9&%F;VYE($ET86QY("AW=W<N,3DP+FET*2X*("H*("H@0V]P>7)I
M9VAT(#(P,#,M,C`P-B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@
M*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UA='1E;R!:86UB96QL:2`\;6UZ86UB
M94!H;W1M86EL+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@
M9&ED(&YO=`H@*B!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`L=B`Q
M+C$Q+C$P+C@@,C`P-B\P,2\P,2`R,3HR.#HR.2!J86X@17AP("0*("H*("H@
M0&%U=&AO<B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*B!`875T
M:&]R($UA='1E;R!:86UB96QL:2`\;6UZ86UB94!H;W1M86EL+F-O;3X*("H@
M0'!A8VMA9V4@3F5T7U--4PH@*B\*8VQA<W,@3F5T7U--4U]V;V1A9F]N96ET
M86QY7W-M='`@97AT96YD<R!.971?4TU3('L*"B`@("`O*BH*("`@("`J($%N
M(&%R<F%Y(&]F(&-A<&%B:6QI=&EE<RP@<V\@=&AA="!T:&4@9')I=F5R(&-A
M;B!R97!O<G0@=VAI8V@@;W!E<F%T:6]N<PH@("`@("H@:70@<W5P<&]R=',@
M86YD('=H:6-H(&ET(&1O97-N)W0N(%!O<W-I8FQE('9A;'5E<R!A<F4Z/'!R
M93X*("`@("`J("`@875T:"`@("`@("`@+2!4:&4@9V%T97=A>2!R97%U:7)E
M(&%U=&AE;G1I8V%T:6]N(&)E9F]R92!S96YD:6YG.PH@("`@("H@("!B871C
M:"`@("`@("`M($)A=&-H('-E;F1I;F<@:7,@<W5P<&]R=&5D.PH@("`@("H@
M("!M=6QT:2`@("`@("`M(%-E;F1I;F<@;V8@;65S<V%G97,@=&\@;75L=&EP
M;&4@<F5C:7!I96YT<R!I<R!S=7!P;W)T960["B`@("`@*B`@(')E8V5I=F4@
M("`@("T@5VAE=&AE<B!T:&ES(&1R:79E<B!I<R!C87!A8FQE(&]F(')E8V5I
M=FEN9R!335,["B`@("`@*B`@(&-R961I="`@("`@("T@27,@=7-E(&]F('1H
M92!G871E=V%Y(&)A<V5D(&]N(&-R961I=',["B`@("`@*B`@(&%D9')E<W-B
M;V]K("T@07)E(&=A=&5W87D@861D<F5S<V)O;VMS('-U<'!O<G1E9#L*("`@
M("`J("`@;&ES=',@("`@("`@+2!'871E=V%Y('-U<'!O<G0@9F]R(&1I<W1R
M:6)U=&EO;B!L:7-T<RX*("`@("`J(#PO<')E/@H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1C87!A8FEL:71I97,@/2!A<G)A
M>2@G875T:"<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G8F%T8V@G("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G;75L=&DG("`@("`@(#T^(&9A;'-E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5C96EV92<@("`@(#T^
M(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8W)E9&ET
M)R`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G861D<F5S<V)O;VLG(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G;&ES=',G("`@("`@(#T^(&9A;'-E*3L*"B`@("`O*BH*
M("`@("`J(%1H:7,@9G5N8W1I;VX@9&]E<R!T:&4@86-T=6%L('-E;F1I;F<@
M;V8@=&AE(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1M97-S86=E("!4:&4@87)R
M87D@8V]N=&%I;FEN9R!T:&4@;65S<V%G92!A;F0@:71S('-E;F0*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@<&%R86UE=&5R<RX*("`@("`J($!P
M87)A;2!S=')I;F<@)'1O("`@("`@5&AE(&1E<W1I;F%T:6]N('-T<FEN9RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!W:71H('1H
M92!S=6-C97-S('-T871U<R!A;F0@861D:71I;VYA;`H@("`@("H@("`@("`@
M("`@("`@("`@:6YF;W)M871I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S
M96YD*"8D;65S<V%G92P@)'1O*0H@("`@>PH@("`@("`@(&EF("@A0&EN8VQU
M9&5?;VYC92`G36%I;"YP:'`G*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*%\H(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E
M($UA:6PN(BDI.PH@("`@("`@('T*("`@("`@("`D;6%I;&5R(#T@36%I;#HZ
M9F%C=&]R>2@G;6%I;"<I.PH*("`@("`@("`O*B!3:6YC92!T:&ES(&]N;'D@
M=V]R:W,@9F]R($ET86QI86X@;G5M8F5R<RP@=&AI<R!I<R!H87)D8V]D960N
M("HO"B`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>+BH_/#\H7"L_,SDI/RA<
M9'LQ,'TI/C\O)RP@)'1O+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@)&AE
M861E<G-;)T9R;VTG72`]("1T:&ES+3Y?<&%R86US6R=U<V5R)UT["B`@("`@
M("`@("`@("1T;R`]("1M871C:&5S6S)=("X@)T!S;7,N=F]D869O;F4N:70G
M.PH@("`@("`@("`@("`D<F5S=6QT(#T@)&UA:6QE<BT^<V5N9"@D=&\L("1H
M96%D97)S+"`D;65S<V%G95LG=&5X="==*3L*("`@("`@("`@("`@:68@*&ES
M7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(&%R<F%Y*#`L("1R97-U;'0M/F=E=$UE<W-A9V4H*2D["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@87)R87DH
M,2P@;G5L;"D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!R971U<FX@87)R87DH,"P@7R@B66]U(&YE960@=&\@<')O=FED
M92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(I*3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!)9&5N=&EF:65S('1H:7,@9V%T97=A>2!D<FEV
M97(@86YD(')E='5R;G,@82!B<FEE9B!D97-C<FEP=&EO;BX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A>2!O9B!D<FEV97(@:6YF;RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T26YF;R@I"B`@("!["B`@("`@("`@)&EN
M9F];)VYA;64G72`](%\H(E9O9&%F;VYE($ET86QY('9I82!33510(BD["B`@
M("`@("`@)&EN9F];)V1E<V,G72`](%\H(E1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F
M;VYE($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@
M270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F;VYE($ET
M86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(BD["@H@("`@("`@(')E='5R;B`D
M:6YF;SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(')E<75I
M<F5D('!A<F%M971E<G,@9F]R('1H:7,@9V%T97=A>2!D<FEV97(N"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@07)R87D@;V8@<F5Q=6ER960@<&%R
M86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%R86US*"D*("`@
M('L*("`@("`@("`D<&%R86US(#T@87)R87DH*3L*("`@("`@("`D<&%R86US
M6R=U<V5R)UT@("`@("`@/2!A<G)A>2@G;&%B96PG("`]/B!?*")5<V5R;F%M
M92(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T
M>7!E)R`@(#T^("=T97AT)RD["@H@("`@("`@(')E='5R;B`D<&%R86US.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<&%R86UE=&5R<R!T
M:&%T(&-A;B!B92!S970@87,@9&5F875L="!F;W(@<V5N9&EN9R!M97-S86=E
M<PH@("`@("H@=7-I;F<@=&AI<R!G871E=V%Y(&1R:79E<B!A;F0@9&ES<&QA
M>65D('=H96X@<V5N9&EN9R!M97-S86=E<RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("!!<G)A>2!O9B!P87)A;65T97)S('1H870@8V%N(&)E('-E
M="!A<R!D969A=6QT+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971$969A=6QT
M4V5N9%!A<F%M<R@I"B`@("!["B`@("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!P87)A;65T97)S(&9O
M<B!S96YD:6YG(&UE<W-A9V5S('5S:6YG('1H:7,@9V%T97=A>2!D<FEV97(L
M"B`@("`@*B!D:7-P;&%Y960@=VAE;B!S96YD:6YG(&UE<W-A9V5S+B!4:&5S
M92!A<F4@9FEL=&5R960@;W5T('5S:6YG('1H90H@("`@("H@9&5F875L="!V
M86QU97,@<V5T('5P('=H96X@8W)E871I;F<@=&AE(&=A=&5W87DN"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@07)R87D@;V8@<F5Q=6ER960@<&%R
M86UE=&5R<RX*("`@("`J($!T;V1O("!7;W5L9"!B92!N:6-E('1O('5S92!A
M('1I;64O9&%T92!S971U<"!R871H97(@=&AA;B!M:6YU=&5S(&9R;VT*("`@
M("`J("`@("`@("!N;W<@9F]R('1H92!D96QI=F5R>2!T:6UE+B!5<&QO860@
M9FEE;&0@9F]R(')I;F=T;VYE<R]L;V=O<S\*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T4V5N9%!A<F%M<R@D<&%R86US*0H@("`@>PH@("`@("`@(')E='5R
M;B!A<G)A>2@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A('-T
M<FEN9R!R97!R97-E;G1A=&EO;B!O9B!A;B!E<G)O<B!C;V1E+@H@("`@("H*
M("`@("`J($!P87)A;2!I;G1E9V5R("1E<G)O<B`@5&AE(&5R<F]R(&-O9&4@
M=&\@;&]O:R!U<"X*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@("`@06X@
M97AI<W1I;F<@97)R;W(@=&5X="!T;R!U<V4@=&\@<F%I<V4@80H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("!014%2($5R<F]R+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@($$@=&5X='5A;"!M97-S86=E(&-O<G)E<W!O
M;F1I;F<@=&\@=&AE(&5R<F]R(&-O9&4@;W(@80H@("`@("H@("`@("`@("`@
M("`@("`@4$5!4B!%<G)O<B!I9B!P87-S960@86X@97AI<W1I;F<@97)R;W(@
M=&5X="X*("`@("`J"B`@("`@*B!`=&]D;R`@0VAE8VL@=VAI8V@@;V8@=&AE
M<V4@87)E(&%C='5A;&QY(')E<75I<F5D(&%N9"!T<FEM(&1O=VX@=&AE"B`@
M("`@*B`@("`@("`@;&ES="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T17)R
M;W(H)&5R<F]R+"`D97)R;W)?=&5X="`]("<G*0H@("`@>PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<```````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#,Q,3(W(#$P-3$U-#,S-S0P(#`R,S,U-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@3F5T7U--4U]C;&EC:V%T96QL7VAT='`@0VQA<W,@:6UP;&5M96YT<R!T
M:&4@2%144"!!4$D@9F]R(&%C8V5S<VEN9R!T:&4*("H@0VQI8VMA=&5L;"`H
M=W=W+F-L:6-K871E;&PN8V]M*2!335,@9V%T97=A>2X*("H*("H@0V]P>7)I
M9VAT(#(P,#,M,C`P-B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<"QV(#$N,3,N,3`N.2`R,#`V+S`X+S`W
M(#`P.C0R.C,P(&-H=6-K($5X<"`D"B`J"B`J($!A=71H;W(@36%R:V\@1&IU
M:VEC(#QM87)K;T!O8FQO+F-O;3X*("H@0'!A8VMA9V4@3F5T7U--4PH@*B\*
M8VQA<W,@3F5T7U--4U]C;&EC:V%T96QL7VAT='`@97AT96YD<R!.971?4TU3
M('L*"B`@("!V87(@)%]S97-S:6]N7VED(#T@;G5L;#L*("`@('9A<B`D7V)A
M<V5?=7)L(#T@)VAT='`Z+R]A<&DN8VQI8VMA=&5L;"YC;VTO:'1T<"\G.PH*
M("`@("\J*@H@("`@("H@06X@87)R87D@;V8@8V%P86)I;&ET:65S+"!S;R!T
M:&%T('1H92!D<FEV97(@8V%N(')E<&]R="!W:&EC:"!O<&5R871I;VYS"B`@
M("`@*B!I="!S=7!P;W)T<R!A;F0@=VAI8V@@:70@9&]E<VXG="X@4&]S<VEB
M;&4@=F%L=65S(&%R93H\<')E/@H@("`@("H@("!A=71H("`@("`@("`M(%1H
M92!G871E=V%Y(')E<75I<F4@875T:&5N=&EC871I;VX@8F5F;W)E('-E;F1I
M;F<["B`@("`@*B`@(&)A=&-H("`@("`@("T@0F%T8V@@<V5N9&EN9R!I<R!S
M=7!P;W)T960["B`@("`@*B`@(&UU;'1I("`@("`@("T@4V5N9&EN9R!O9B!M
M97-S86=E<R!T;R!M=6QT:7!L92!R96-I<&EE;G1S(&ES('-U<'!O<G1E9#L*
M("`@("`J("`@<F5C96EV92`@("`@+2!7:&5T:&5R('1H:7,@9')I=F5R(&ES
M(&-A<&%B;&4@;V8@<F5C96EV:6YG(%--4SL*("`@("`J("`@8W)E9&ET("`@
M("`@+2!)<R!U<V4@;V8@=&AE(&=A=&5W87D@8F%S960@;VX@8W)E9&ET<SL*
M("`@("`J("`@861D<F5S<V)O;VL@+2!!<F4@9V%T97=A>2!A9&1R97-S8F]O
M:W,@<W5P<&]R=&5D.PH@("`@("H@("!L:7-T<R`@("`@("`M($=A=&5W87D@
M<W5P<&]R="!F;W(@9&ES=')I8G5T:6]N(&QI<W1S+@H@("`@("H@/"]P<F4^
M"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&-A
M<&%B:6QI=&EE<R`](&%R<F%Y*"=A=71H)R`@("`@("`@/3X@=')U92P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)V)A=&-H)R`@("`@("`]/B`Q
M,#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M=6QT:2<@("`@
M("`@/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E
M8V5I=F4G("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)V-R961I="<@("`@("`]/B!T<G5E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G861D<F5S<V)O;VLG(#T^(&9A;'-E+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G;&ES=',G("`@("`@(#T^(&9A;'-E
M*3L*"B`@("`O*BH*("`@("`J($%U=&AE;G1I8V%T92!A="!T:&4@9V%T97=A
M>2!A;F0@<V5T(&$@<V5S<VEO;B!I9"!I9B!S=6-C97-S9G5L+B!#86-H:6YG
M"B`@("`@*B!I<R!U<V5D('1O(&UI;FEM:7-E('1H92!H='1P(&-A;&QS(&9O
M<B!S=6)S97%U96YT(&UE<W-A9V5S+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@
M<W5C8V5S<R!O<B!014%2($5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]A=71H96YT:6-A=&4H*0H@("`@>PH@("`@("`@("\J(%=E
M(&AA=F4@86QR96%D>2!A=71H96YT:6-A=&5D('-O(')E='5R;B!T<G5E+B`J
M+PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]S97-S:6]N7VED*2D@>PH@
M("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("\J
M(%-E="!U<"!T:&4@:'1T<"!A=71H96YT:6-A=&EO;B!U<FPN("HO"B`@("`@
M("`@)'5R;"`]('-P<FEN=&8H)V%U=&@_=7-E<CTE<R9P87-S=V]R9#TE<R9A
M<&E?:60])7,G+`H@("`@("`@("`@("`@("`@("`@("`@('5R;&5N8V]D92@D
M=&AI<RT^7W!A<F%M<ULG=7-E<B==*2P*("`@("`@("`@("`@("`@("`@("`@
M("!U<FQE;F-O9&4H)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UTI+`H@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=A<&E?:60G72D[
M"@H@("`@("`@("\J($1O('1H92!(5%10(&%U=&AE;G1I8V%T:6]N(&%N9"!G
M970@=&AE(')E<W!O;G-E+B`J+PH@("`@("`@("1R97-P;VYS92`]($YE=%]3
M35-?8VQI8VMA=&5L;%]H='1P.CI?8V%L;%523"@D=7)L*3L*("`@("`@("!I
M9B`H:7-?82@D<F5S<&]N<V4L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")!=71H96YT
M:6-A=&EO;B!F86EL960N("5S(BDL("1R97-P;VYS92T^9V5T365S<V%G92@I
M*2D["B`@("`@("`@?0H*("`@("`@("`O*B!3<&QI="!U<"!T:&4@<F5S<&]N
M<V4N("HO"B`@("`@("`@)')E<W!O;G-E(#T@97AP;&]D92@G.B<L("1R97-P
M;VYS92D["B`@("`@("`@:68@*"1R97-P;VYS95LP72`]/2`G3TLG*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?<V5S<VEO;E]I9"`]('1R:6TH)')E<W!O;G-E
M6S%=*3L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YG971%<G)O<B@D<F5S<&]N
M<V5;,5TL(%\H(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B*2D["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@5&AI<R!F=6YC=&EO;B!D;V5S
M('1H92!A8W1U86P@<V5N9&EN9R!O9B!T:&4@;65S<V%G92X*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)&UE<W-A9V4@(%1H92!A<G)A>2!C;VYT86EN:6YG('1H92!M97-S86=E
M(&%N9"!I=',@<V5N9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!P
M87)A;65T97)S+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&\@("`@("!4:&4@
M9&5S=&EN871I;VX@<W1R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@($%N(&%R<F%Y('=I=&@@=&AE('-U8V-E<W,@<W1A='5S(&%N9"!A9&1I
M=&EO;F%L"B`@("`@*B`@("`@("`@("`@("`@("!I;F9O<FUA=&EO;BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@7W-E;F0H)B1M97-S86=E+"`D=&\I"B`@("![
M"B`@("`@("`@+RH@4V5T('5P('1H92!H='1P('-E;F1I;F<@=7)L+B`J+PH@
M("`@("`@("1U<FP@/2!S<')I;G1F*"=S96YD;7-G/W-E<W-I;VY?:60])7,F
M=&5X=#TE<R<L"B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S97-S
M:6]N7VED+`H@("`@("`@("`@("`@("`@("`@("`@('5R;&5N8V]D92@D;65S
M<V%G95LG=&5X="==*2D["@H@("`@("`@("1R97%?9F5A="`](#`["B`@("`@
M("`@:68@*"%E;7!T>2@D;65S<V%G95LG<V5N9%]P87)A;7,G75LG9G)O;2==
M*2D@>PH@("`@("`@("`@("`O*B!)9B!S;W5R8V4@9G)O;2!I<R!S970L(')E
M<75I<F4@:70@9F]R('1R86YS:70@9V%T97=A>7,@86YD(&%P<&5N9`H@("`@
M("`@("`@("`@("!T;R!U<FPN("HO"B`@("`@("`@("`@("1R97%?9F5A="`]
M*R`Q-CL*("`@("`@("`@("`@)'5R;"`N/2`G)F9R;VT])R`N('5R;&5N8V]D
M92@D;65S<V%G95LG<V5N9%]P87)A;7,G75LG9G)O;2==*3L*("`@("`@("!]
M"B`@("`@("`@:68@*"%E;7!T>2@D;65S<V%G95LG<V5N9%]P87)A;7,G75LG
M;7-G7W1Y<&4G72D@)B8*("`@("`@("`@("`@)&UE<W-A9V5;)W-E;F1?<&%R
M86US)UU;)VUS9U]T>7!E)UT@/3T@)U--4U]&3$%32"<I('L*("`@("`@("`@
M("`@+RH@268@;65S<V%G92!T>7!E(&ES(&9L87-H+"!R97%U:7)E(&ET(&9O
M<B!T<F%N<VET(&=A=&5W87ES+B`J+PH@("`@("`@("`@("`D<F5Q7V9E870@
M/2L@-3$R.PH@("`@("`@("`@("`D=7)L("X]("<F;7-G7W1Y<&4])R`N("1M
M97-S86=E6R=S96YD7W!A<F%M<R==6R=M<V=?='EP92==.PH@("`@("`@('T*
M("`@("`@("!I9B`H(65M<'1Y*"1R97%?9F5A="DI('L*("`@("`@("`@("`@
M+RH@268@9F5A='5R97,@:&%V92!B965N(')E<75I<F5D+"!A9&0@=&\@=7)L
M+B`J+PH@("`@("`@("`@("`D=7)L("X]("<F<F5Q7V9E870])R`N("1R97%?
M9F5A=#L*("`@("`@("!]"@H@("`@("`@("\J($%P<&5N9"!T:&4@<F5C:7!I
M96YT<R!O9B!T:&ES(&UE<W-A9V4@86YD(&-A;&P@=&AE('5R;"X@*B\*("`@
M("`@("!F;W)E86-H("@D=&\@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@
M("`@(&EF("AP<F5G7VUA=&-H*"<O7BXJ/SP_7"L_*%QD>S<L?2DH/GPD*2\G
M+"`D=F%L+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@("`@("1T;ULD:V5Y
M72`]("1M871C:&5S6S%=.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@+RH@1DE8344Z(%-I;&5N=&QY(&1R;W`@8F%D(')E8VEP:65N
M=',N(%1H:7,@<VAO=6QD(&)E(&QO9V=E9`H@("`@("`@("`@("`@("`@("H@
M86YD+V]R(')E<&]R=&5D+B`J+PH@("`@("`@("`@("`@("`@=6YS970H)'1O
M6R1K97E=*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D=&\@
M/2!I;7!L;V1E*"<L)RP@)'1O*3L*("`@("`@("`D=7)L("X]("<F=&\])R`N
M("1T;SL*("`@("`@("`D<F5S<&]N<V4@/2!T<FEM*"1T:&ES+3Y?8V%L;%52
M3"@D=7)L*2D["@H@("`@("`@("\J(%5G;'D@<&%R<VEN9R!O9B!T:&4@<F5S
M<&]N<V4L(&)U="!T:&%T)W,@:&]W(&ET(&-O;65S(&)A8VLN("HO"B`@("`@
M("`@)&QI;F5S(#T@97AP;&]D92@B7&XB+"`D<F5S<&]N<V4I.PH@("`@("`@
M("1R97-P;VYS92`](&%R<F%Y*"D["@H@("`@("`@(&EF("AC;W5N="@D;&EN
M97,I(#X@,2D@>PH@("`@("`@("`@("!F;W)E86-H("@D;&EN97,@87,@)&QI
M;F4I('L*("`@("`@("`@("`@("`@("1P87)T<R`](&5X<&QO9&4H)U1O.B<L
M("1L:6YE*3L*("`@("`@("`@("`@("`@("1R96-I<&EE;G0@/2!T<FEM*"1P
M87)T<ULQ72D["B`@("`@("`@("`@("`@("`D;W5T8V]M92`](&5X<&QO9&4H
M)SHG+"`D<&%R='-;,%TI.PH@("`@("`@("`@("`@("`@)')E<W!O;G-E6R1R
M96-I<&EE;G1=(#T@87)R87DH*"1O=71C;VUE6S!=(#T]("=)1"<@/R`Q(#H@
M,"DL("1O=71C;VUE6S%=*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("\J(%-I;F=L92!R96-I<&EE;G0N("HO"B`@("`@
M("`@("`@("1O=71C;VUE(#T@97AP;&]D92@G.B<L("1L:6YE<ULP72D["B`@
M("`@("`@("`@("1R97-P;VYS95LD=&]=(#T@87)R87DH*"1O=71C;VUE6S!=
M(#T]("=)1"<@/R`Q(#H@,"DL("1O=71C;VUE6S%=*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D<F5S<&]N<V4["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!C=7)R96YT(&-R961I="!B86QA;F-E(&]N('1H92!G
M871E=V%Y+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(&-R961I="!B86QA;F-E(&%V
M86EL86)L92!O;B!T:&4@9V%T97=A>2X*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V=E=$)A;&%N8V4H*0H@("`@>PH@("`@("`@("\J(%-E="!U<"!T:&4@=7)L
M(&%N9"!C86QL(&ET+B`J+PH@("`@("`@("1U<FP@/2!S<')I;G1F*"=G971B
M86QA;F-E/W-E<W-I;VY?:60])7,G+`H@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<V5S<VEO;E]I9"D["B`@("`@("`@)')E<W!O;G-E(#T@=')I
M;2@D=&AI<RT^7V-A;&Q54DPH)'5R;"DI.PH*("`@("`@("`O*B!4<GD@<W!L
M:71T:6YG('5P('1H92!R97-P;VYS92X@*B\*("`@("`@("`D;&EN97,@/2!E
M>'!L;V1E*"<])RP@)')E<W!O;G-E*3L*"B`@("`@("`@+RH@4W!L:70@=7`@
M=&AE(')E<W!O;G-E+B`J+PH@("`@("`@("1R97-P;VYS92`](&5X<&QO9&4H
M)SHG+"`D<F5S<&]N<V4I.PH@("`@("`@(&EF("@D<F5S<&]N<V5;,%T@/3T@
M)T-R961I="<I('L*("`@("`@("`@("`@<F5T=7)N('1R:6TH)')E<W!O;G-E
M6S%=*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/F=E=$5R<F]R*"1R97-P;VYS95LQ72P@7R@B0V]U;&0@;F]T(&-H96-K
M(&)A;&%N8V4N("5S(BDI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($ED96YT:69I97,@=&AI<R!G871E=V%Y(&1R:79E<B!A;F0@<F5T=7)N
M<R!A(&)R:65F(&1E<V-R:7!T:6]N+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@($%R<F%Y(&]F(&1R:79E<B!I;F9O+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971);F9O*"D*("`@('L*("`@("`@("`D:6YF;ULG;F%M92==(#T@
M7R@B0VQI8VMA=&5L;"!V:6$@2%144"(I.PH@("`@("`@("1I;F9O6R=D97-C
M)UT@/2!?*")4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E
M<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC
M;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(I.PH*("`@("`@("!R
M971U<FX@)&EN9F\["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!R97%U:7)E9"!P87)A;65T97)S(&9O<B!T:&ES(&=A=&5W87D@9')I=F5R
M+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%R<F%Y(&]F(')E<75I
M<F5D('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A<F%M
M<R@I"B`@("!["B`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"D["B`@("`@("`@
M)'!A<F%M<ULG=7-E<B==("`@("`](&%R<F%Y*"=L86)E;"<@/3X@7R@B57-E
M<FYA;64B*2P@)W1Y<&4G(#T^("=T97AT)RD["B`@("`@("`@)'!A<F%M<ULG
M<&%S<W=O<F0G72`](&%R<F%Y*"=L86)E;"<@/3X@7R@B4&%S<W=O<F0B*2P@
M)W1Y<&4G(#T^("=T97AT)RD["B`@("`@("`@)'!A<F%M<ULG87!I7VED)UT@
M("`](&%R<F%Y*"=L86)E;"<@/3X@7R@B05!)($E$(BDL("=T>7!E)R`]/B`G
M=&5X="<I.PH*("`@("`@("!R971U<FX@)'!A<F%M<SL*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE('!A<F%M971E<G,@=&AA="!C86X@8F4@
M<V5T(&%S(&1E9F%U;'0@9F]R('-E;F1I;F<@;65S<V%G97,*("`@("`J('5S
M:6YG('1H:7,@9V%T97=A>2!D<FEV97(@86YD(&1I<W!L87EE9"!W:&5N('-E
M;F1I;F<@;65S<V%G97,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@
M07)R87D@;V8@<&%R86UE=&5R<R!T:&%T(&-A;B!B92!S970@87,@9&5F875L
M="X*("`@("`J($!T;V1O("!3970@=7`@8F%T8V@@9FEE;&1S+W!A<F%M<RP@
M=V]U;&0@8F4@;FEC92!T;R!H879E(')I;F=T;VYE+VQO9V\*("`@("`J("`@
M("`@("!S=7!P;W)T('1O;RP@<75E=64@8VAO:6-E+"!U;FEC;V1E(&-H;VEC
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&5F875L=%-E;F1087)A;7,H
M*0H@("`@>PH@("`@("`@("1P87)A;7,@/2!A<G)A>2@I.PH@("`@("`@("1P
M87)A;7-;)V9R;VTG72`](&%R<F%Y*`H@("`@("`@("`@("`G;&%B96PG(#T^
M(%\H(E-O=7)C92!A9&1R97-S(BDL"B`@("`@("`@("`@("=T>7!E)R`]/B`G
M=&5X="<I.PH*("`@("`@("`D<&%R86US6R=D96QI=E]T:6UE)UT@/2!A<G)A
M>2@*("`@("`@("`@("`@)VQA8F5L)R`]/B!?*")$96QI=F5R>2!T:6UE(BDL
M"B`@("`@("`@("`@("=T>7!E)R`]/B`G96YU;2<L"B`@("`@("`@("`@("=P
M87)A;7,G(#T^(&%R<F%Y*&%R<F%Y*"=N;W<G(#T^(%\H(FEM;65D:6%T92(I
M+"`G=7-E<B<@/3X@7R@B=7-E<B!S96QE8W0B*2DI*3L*"B`@("`@("`@)'1Y
M<&5S(#T@87)R87DH)U--4U]415A4)R`]/B`G4TU37U1%6%0G+"`G4TU37T9,
M05-()R`]/B`G4TU37T9,05-()RD["B`@("`@("`@)'!A<F%M<ULG;7-G7W1Y
M<&4G72`](&%R<F%Y*`H@("`@("`@("`@("`G;&%B96PG(#T^(%\H(DUE<W-A
M9V4@='EP92(I+`H@("`@("`@("`@("`G='EP92<@/3X@)VUU;'1I96YU;2<L
M"B`@("`@("`@("`@("=P87)A;7,G(#T^(&%R<F%Y*"1T>7!E<RDI.PH*("`@
M("`@("!R971U<FX@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE('!A<F%M971E<G,@9F]R('-E;F1I;F<@;65S<V%G97,@=7-I
M;F<@=&AI<R!G871E=V%Y(&1R:79E<BP*("`@("`J(&1I<W!L87EE9"!W:&5N
M('-E;F1I;F<@;65S<V%G97,N(%1H97-E(&%R92!F:6QT97)E9"!O=70@=7-I
M;F<@=&AE"B`@("`@*B!D969A=6QT('9A;'5E<R!S970@9F]R('1H92!G871E
M=V%Y+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%R<F%Y(&]F(')E
M<75I<F5D('!A<F%M971E<G,N"B`@("`@*B!`=&]D;R`@5V]U;&0@8F4@;FEC
M92!T;R!U<V4@82!T:6UE+V1A=&4@<V5T=7`@<F%T:&5R('1H86X@;6EN=71E
M<R!F<F]M"B`@("`@*B`@("`@("`@;F]W(&9O<B!T:&4@9&5L:79E<GD@=&EM
M92X@57!L;V%D(&9I96QD(&9O<B!R:6YG=&]N97,O;&]G;W,_"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=%-E;F1087)A;7,H)'!A<F%M<RD*("`@('L*("`@
M("`@("!I9B`H96UP='DH)'!A<F%M<ULG9G)O;2==*2D@>PH@("`@("`@("`@
M("`D<&%R86US6R=F<F]M)UT@/2!A<G)A>2@*("`@("`@("`@("`@("`@("=L
M86)E;"<@/3X@7R@B4V]U<F-E(&%D9')E<W,B*2P*("`@("`@("`@("`@("`@
M("=T>7!E)R`]/B`G=&5X="<I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1P
M87)A;7-;)V1E;&EV7W1I;64G72`]/2`G=7-E<B<I('L*("`@("`@("`@("`@
M)'!A<F%M<ULG9&5L:79?=&EM92==(#T@87)R87DH"B`@("`@("`@("`@("`@
M("`G;&%B96PG(#T^(%\H(D1E;&EV97)Y('1I;64B*2P*("`@("`@("`@("`@
M("`@("=T>7!E)R`]/B`G:6YT)RP*("`@("`@("`@("`@("`@("=D97-C)R`]
M/B!?*")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(I*3L*("`@("`@("!]
M"@H@("`@("`@(&EF("AC;W5N="@D<&%R86US6R=M<V=?='EP92==*2`^(#$I
M('L*("`@("`@("`@("`@)'!A<F%M<ULG;7-G7W1Y<&4G72`](&%R<F%Y*`H@
M("`@("`@("`@("`@("`@)VQA8F5L)R`]/B!?*")-97-S86=E('1Y<&4B*2P*
M("`@("`@("`@("`@("`@("=T>7!E)R`]/B`G96YU;2<L"B`@("`@("`@("`@
M("`@("`G<&%R86US)R`]/B!A<G)A>2@D<&%R86US6R=M<V=?='EP92==*2D[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'!A<F%M<ULG;7-G7W1Y
M<&4G72`]("1P87)A;7-;)VUS9U]T>7!E)UU;,%T["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@82!S=')I;F<@<F5P<F5S96YT871I;VX@;V8@86X@97)R;W(@8V]D
M92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D97)R;W(@(%1H92!E
M<G)O<B!C;V1E('1O(&QO;VL@=7`N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T
M97AT("`@($%N(&5X:7-T:6YG(&5R<F]R('1E>'0@=&\@=7-E('1O(')A:7-E
M(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@4$5!4B!%<G)O<BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!!('1E>'1U86P@;65S<V%G
M92!C;W)R97-P;VYD:6YG('1O('1H92!E<G)O<B!C;V1E(&]R(&$*("`@("`J
M("`@("`@("`@("`@("`@(%!%05(@17)R;W(@:68@<&%S<V5D(&%N(&5X:7-T
M:6YG(&5R<F]R('1E>'0N"B`@("`@*@H@("`@("H@0'1O9&\@($-H96-K('=H
M:6-H(&]F('1H97-E(&%R92!A8W1U86QL>2!R97%U:7)E9"!A;F0@=')I;2!D
M;W=N('1H90H@("`@("H@("`@("`@(&QI<W0N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$5R<F]R*"1E<G)O<BP@)&5R<F]R7W1E>'0@/2`G)RD*("`@('L*
M("`@("`@("`O*B!-86ME('-U<F4@=V4@9V5T(&]N;'D@=&AE(&YU;6)E<B!A
M="!T:&4@<W1A<G0@;V8@86X@97)R;W(N("HO"B`@("`@("`@;&ES="@D97)R
M;W(I(#T@97AP;&]D92@G+"<L("1E<G)O<BD["B`@("`@("`@)&5R<F]R(#T@
M=')I;2@D97)R;W(I.PH*("`@("`@("`O*B!!;B!A<G)A>2!O9B!E<G)O<B!C
M;V1E<R!R971U<FYE9"!B>2!T:&4@9V%T97=A>2X@*B\*("`@("`@("`D97)R
M;W)S(#T@87)R87DH)S`P,2<@/3X@7R@B075T:&5N=&EC871I;VX@9F%I;&5D
M(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("<P,#(G(#T^(%\H(E5N:VYO
M=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(BDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("<P,#,G(#T^(%\H(E-E<W-I;VX@240@97AP:7)E9"XB*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@)S`P-"<@/3X@7R@B06-C;W5N="!F<F]Z
M96XN(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("<P,#4G(#T^(%\H(DUI
M<W-I;F<@<V5S<VEO;B!)1"XB*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M)S`P-R<@/3X@7R@B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`G,3`Q)R`]/B!?*"));G9A;&ED(&]R(&UI<W-I
M;F<@<&%R86UE=&5R<RXB*2P*("`@("`@("`@("`@("`@("`@("`@("`@)S$P
M,B<@/3X@7R@B26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@)S$P,R<@/3X@7R@B56YK;F]W;B!A
M<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`G,3`T)R`]/B!?*")5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@
M365S<V%G92!)1"DN(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("<Q,#4G
M(#T^(%\H(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@)S$P-B<@/3X@7R@B26YV86QI9"!S;W5R8V4@
M861D<F5S<RXB*2P*("`@("`@("`@("`@("`@("`@("`@("`@)S$P-R<@/3X@
M7R@B16UP='D@;65S<V%G92XB*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M)S$P."<@/3X@7R@B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@)S$P.2<@/3X@7R@B36ES<VEN9R!M97-S
M86=E($E$+B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`G,3$P)R`]/B!?
M*")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N(BDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("<Q,3$G(#T^(%\H(DEN=F%L:60@<')O=&]C;VPN(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("<Q,3(G(#T^(%\H(DEN=F%L:60@;7-G
M7W1Y<&4N(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("<Q,3,G(#T^(%\H
M(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+B(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`G,3$T)R`]/B!?*")#86YN;W0@<F]U=&4@;65S<V%G92!T
M;R!S<&5C:69I960@;G5M8F5R+B(I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`G,3$U)R`]/B!?*")-97-S86=E(&5X<&ER960N(BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("<Q,38G(#T^(%\H(DEN=F%L:60@=6YI8V]D92!D871A
M+B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`G,C`Q)R`]/B!?*"));G9A
M;&ED(&)A=&-H($E$+B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`G,C`R
M)R`]/B!?*").;R!B871C:"!T96UP;&%T92XB*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@)S,P,2<@/3X@7R@B3F\@8W)E9&ET(&QE9G0N(BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("<S,#(G(#T^(%\H(DUA>"!A;&QO=V5D(&-R
M961I="XB*2D["@H@("`@("`@(&EF("AE;7!T>2@D97)R;W)?=&5X="DI('L*
M("`@("`@("`@("`@<F5T=7)N("1E<G)O<G-;)&5R<F]R73L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS
M<')I;G1F*"1E<G)O<E]T97AT+"`D97)R;W)S6R1E<G)O<ETI*3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$;R!T:&4@:'1T<"!C86QL('5S
M:6YG(&$@=7)L('!A<W-E9"!T;R!T:&4@9G5N8W1I;VXN"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=7)L("!4:&4@=7)L('1O(&-A;&PN"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@5&AE(')E<W!O;G-E(&]N('-U8V-E<W,@;W(@4$5!4B!%<G)O
M<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V%L;%523"@D
M=7)L*0H@("`@>PH@("`@("`@("1O<'1I;VYS6R=M971H;V0G72`]("='150G
M.PH@("`@("`@("1O<'1I;VYS6R=T:6UE;W5T)UT@/2`U.PH@("`@("`@("1O
M<'1I;VYS6R=A;&QO=U)E9&ER96-T<R==(#T@=')U93L*"B`@("`@("`@:68@
M*"%`:6YC;'5D95]O;F-E("=(5%10+U)E<75E<W0N<&AP)RD@>PH@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")-:7-S:6YG(%!%05(@
M<&%C:V%G92!(5%107U)E<75E<W0N(BDI.PH@("`@("`@('T*("`@("`@("`D
M:'1T<"`]("9N97<@2%144%]297%U97-T*"1T:&ES+3Y?8F%S95]U<FP@+B`D
M=7)L+"`D;W!T:6]N<RD["B`@("`@("`@0"1H='1P+3YS96YD4F5Q=65S="@I
M.PH@("`@("`@(&EF("@D:'1T<"T^9V5T4F5S<&]N<V5#;V1E*"D@(3T@,C`P
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN
M=&8H7R@B0V]U;&0@;F]T(&]P96X@)7,N(BDL("1U<FPI*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D:'1T<"T^9V5T4F5S<&]N<V5";V1Y*"D["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H<```````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$R-C0R(#$P-3$U-#,S-S0P(#`R,C8W
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@1V5N97)I8R!E+6UA:6P@8F%S960@4TU3(&1R:79E<@H@
M*@H@*B!#;W!Y<FEG:'0@,C`P-2TR,#`V(%=E8E-P<F]C:V5T<RP@3$Q#"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9`H@*B!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!4:&ES(&1R:79E<B!I;G1E<F9A8V5S('=I=&@@
M=&AE(&5M86EL+71O+7-M<R!G871E=V%Y<R!P<F]V:61E9"!B>2!M86YY"B`J
M(&-A<G)I97)S+"!P87)T:6-U;&%R;'D@=&AO<V4@8F%S960@:6X@=&AE(%4N
M4RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I
M8U]S;71P+G!H<"QV(#$N."XR+C0@,C`P-B\P-R\Q,R`P.#HU-SHT-2!J86X@
M17AP("0*("H*("H@0&-A=&5G;W)Y("`@3F5T=V]R:VEN9PH@*B!`<&%C:V%G
M92`@("!.971?4TU3"B`J($!A=71H;W(@("`@($EA;B!%=7)E(#QI975R94!P
M:'`N;F5T/@H@*B!`<VEN8V4@("`@("!(;W)D92`S+C$*("H@0'-I;F-E("`@
M("`@3F5T7U--4R`P+C`N,@H@*B\*8VQA<W,@3F5T7U--4U]G96YE<FEC7W-M
M='`@97AT96YD<R!.971?4TU3('L*"B`@("`O*BH*("`@("`J($-A<&%B:6QI
M=&EE<R!O9B!T:&ES(&1R:79E<BX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*B\*("`@('9A<B`D8V%P86)I;&ET:65S(#T@87)R87DH"B`@("`@
M("`@)V%U=&@G("`@("`@("`]/B!F86QS92P*("`@("`@("`G8F%T8V@G("`@
M("`@(#T^(&9A;'-E+`H@("`@("`@("=M=6QT:2<@("`@("`@/3X@9F%L<V4L
M"B`@("`@("`@)W)E8V5I=F4G("`@("`]/B!F86QS92P*("`@("`@("`G8W)E
M9&ET)R`@("`@(#T^(&9A;'-E+`H@("`@("`@("=A9&1R97-S8F]O:R<@/3X@
M9F%L<V4L"B`@("`@("`@)VQI<W1S)R`@("`@("`]/B!F86QS90H@("`@*3L*
M"B`@("`O*BH*("`@("`J($1R:79E<B!P87)A;65T97)S+@H@("`@("H*("`@
M("`J($!V87(@87)R87D*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J+PH@("`@=F%R("1?<&%R86US(#T@87)R87DH"B`@("`@("`@)V-A
M<G)I97(G("`@("`]/B!N=6QL+`H@("`@("`@("=M86EL0F%C:V5N9"<@/3X@
M)VUA:6PG+`H@("`@("`@("=M86EL4&%R86US)R`@/3X@87)R87DH*2P*("`@
M("`@("`G;6%I;$AE861E<G,G(#T^(&%R<F%Y*"D*("`@("D["@H@("`@+RHJ
M"B`@("`@*B!#87)R:65R(&5M86EL(&UA<"X*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@('9A<B`D7V-A<G)I97)S(#T@87)R87DH"B`@("`@("`@+RH@52Y3+B!C
M87)R:65R<RX@*B\*("`@("`@("`G871T)R`@("`@("`@("`]/B`G)7-`;6UO
M9&4N8V]M)RP*("`@("`@("`G8VEN9W5L87(G("`@("`]/B`G)7-`;6UO9&4N
M8V]M)RP*("`@("`@("`G=F5R:7IO;B<@("`@("`]/B`G)7-`=G1E>'0N8V]M
M)RP*("`@("`@("`G8F]O<W0G("`@("`@("`]/B`G)7-`;7EB;V]S=&UO8FEL
M92YC;VTG+`H@("`@("`@("=C96QL=6QA<F]N92<@(#T^("<E<T!M>6-E;&QO
M;F4N;F5T)RP*("`@("`@("`G8VEN8WEB96QL)R`@("`]/B`G)7-`9V]C8G<N
M8V]M)RP*("`@("`@("`G<W!R:6YT)R`@("`@("`]/B`G)7-`;65S<V%G:6YG
M+G-P<FEN='!C<RYC;VTG+`H@("`@("`@("=T;6]B:6QE7W5S)R`@(#T^("<E
M<T!T;6]M86EL+F-O;2<L"B`@("`@("`@)W-U;F-O;2<@("`@("`@/3X@)R5S
M0'1M<RYS=6YC;VTN8V]M)RP*("`@("`@("`G86ER8V5L)R`@("`@("`]/B`G
M)7-`86ER<VUS+F-O;2<L"B`@("`@("`@)V%I<G1E;"<@("`@("`@/3X@)R5S
M0&%I<G1E;&UA:6PN8V]M)RP*("`@("`@("`G8G!L;6]B:6QE)R`@("`]/B`G
M)7-`8G!L;6]B:6QE+F-O;2<L"B`@("`@("`@)V)E;&QM;V)I;&ET>2<@/3X@
M)R5S0'1X="YB96QL;6]B:6QI='DN8V$G+`H@("`@("`@("=B;'5E9W)A<W,G
M("`@(#T^("<E<T!S;7,N8FQU96-E;&PN8V]M)RP*("`@("`@("`G8V5L;&9O
M<F-E)R`@("`]/B`G)7-`8V5L9F]R8V4N8V]M)RP*("`@("`@("`G8V5L;'5L
M87)O;F4G("`]/B`G)7-`;7EC96QL;VYE+FYE="<L"B`@("`@("`@+RH@1V5R
M;6%N(&-A<G)I97)S+B`J+PH@("`@("`@("=E<&QU<R<@("`@("`@/3X@)R5S
M0'-M<VUA:6PN97!L=7,N9&4G+`H@("`@("`@("=T;6]B:6QE7V1E)R`@/3X@
M)R5S0'0M;6]B:6QE+7-M<RYD92<L"B`@("`@("`@)W9O9&%F;VYE7V1E)R`]
M/B`G)7-`=F]D869O;F4M<VUS+F1E)RP*("`@("D["@H@("`@+RHJ"B`@("`@
M*B!)9&5N=&EF:65S('1H:7,@9')I=F5R+@H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@($1R:79E<B!I;F9O+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971);F9O*"D*("`@('L*("`@("`@("!R971U<FX@87)R87DH"B`@("`@("`@
M("`@("=N86UE)R`]/B!?*")%;6%I;"UT;RU335,@1V%T97=A>2(I+`H@("`@
M("`@("`@("`G9&5S8R<@/3X@7R@B14UA:6PM=&\M4TU3(&=A=&5W87D@9')I
M=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N
M(BD*("`@("`@("`I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!R
M97%U:7)E9"!P87)A;65T97)S+@H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@($%R<F%Y(&]F(')E<75I<F5D('!A<F%M971E<G,N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%!A<F%M<R@I"B`@("!["B`@("`@("`@<F5T=7)N(&%R
M<F%Y*`H@("`@("`@("`@("`G8V%R<FEE<B<@("`@(#T^(&%R<F%Y*"=L86)E
M;"<@/3X@7R@B0V%R<FEE<B(I+"`G='EP92<@/3X@)W1E>'0G*2P*("`@("`@
M("`@("`@)VUA:6Q"86-K96YD)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(E!%
M05(Z.DUA:6P@8F%C:V5N9"(I+"`G='EP92<@/3X@)W1E>'0G*0H@("`@("`@
M("D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!396YD<R!T:&4@;65S<V%G92X*
M("`@("`J"B`@("`@*B!9;W4@;6%Y(&%L<V\@<W!E8VEF>2!T:&4@8V%R<FEE
M<B!W:71H('1H92`G8V%R<FEE<B<@:V5Y(&]F('1H92!M97-S86=E"B`@("`@
M*B!T;R!A=F]I9"!C<F5A=&EN9R!A(&YE=R!I;G-T86YC92!F;W(@96%C:"!C
M87)R:65R+"!O<B!F:61D;&EN9R!W:71H('1H90H@("`@("H@<&%R86UE=&5R
M<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@)&UE<W-A9V4@($UE<W-A9V4@=&\@<V5N9"X*("`@
M("`J($!P87)A;2!S=')I;F<@)'1O("`@("`@1&5S=&EN871I;VX@<&AO;F4@
M;G5M8F5R+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y
M('=I=&@@=&AE('-U8V-E<W,@<W1A='5S(&%N9"!A9&1I=&EO;F%L"B`@("`@
M*B`@("`@("`@("`@("`@("!I;F9O<FUA=&EO;BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@7W-E;F0H)B1M97-S86=E+"`D=&\I"B`@("!["B`@("`@("`@)')E
M<W!O;G-E(#T@87)R87DH*3L*("`@("`@("`D9&5S=&5M86EL(#T@)'1H:7,M
M/E]G971$97-T*"1T;RD["B`@("`@("`@<F5Q=6ER95]O;F-E("=-86EL+G!H
M<"<["B`@("`@("`@)&T@/2!-86EL.CIF86-T;W)Y*"1T:&ES+3Y?<&%R86US
M6R=M86EL0F%C:V5N9"==+"`D=&AI<RT^7W!A<F%M<ULG;6%I;%!A<F%M<R==
M*3L*"B`@("`@("`@:68@*&ES<V5T*"1M97-S86=E6R=C87)R:65R)UTI*2![
M"B`@("`@("`@("`@("1D97-T(#T@)'1H:7,M/E]G971$97-T*"1T;RP@)&UE
M<W-A9V5;)V-A<G)I97(G72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&1E<W0@/2`D=&AI<RT^7V=E=$1E<W0H)'1O*3L*("`@("`@("!]"@H@
M("`@("`@("1R97,@/28@)&TM/G-E;F0H)&1E<W0L("1T:&ES+3Y?<&%R86US
M6R=M86EL2&5A9&5R<R==+"`D;65S<V%G95LG=&5X="==*3L*("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D<F5S*2D@>PH@("`@("`@("`@("`D<F5S<&]N
M<V5;)'1O72`](&%R<F%Y*#`L("1R97,M/F=E=$UE<W-A9V4H*2D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)')E<W!O;G-E6R1T;UT@/2!A<G)A
M>2@Q+"!N=6QL*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S<&]N
M<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&1E<W1I;F%T:6]N
M(&4M;6%I;"!A9&1R97-S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'!H;VYE("!0:&]N92!N=6UB97(@=&\@<V5N9"!T;RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@1&5S=&EN871I;VX@861D<F5S<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V=E=$1E<W0H)'!H;VYE+"`D8V%R<FEE<B`](&YU
M;&PI"B`@("!["B`@("`@("`@)&-A<G)I97(@/2!I<U]N=6QL*"1C87)R:65R
M*2`_("1T:&ES+3Y?<&%R86US6R=C87)R:65R)UT@.B`D8V%R<FEE<CL*("`@
M("`@("!R971U<FX@<W!R:6YT9B@D=&AI<RT^7V-A<G)I97)S6R1C87)R:65R
M72P*("`@("`@("`@("`@("`@("`@("`@("!P<F5G7W)E<&QA8V4H)R];7C`M
M.5TO)RP@)R<L("1P:&]N92DI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@861D<F5S<R!T96UP;&%T92!F;W(@82!C87)R:65R+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&-A<G)I97(@($-A<G)I97(@;F%M
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!!9&1R97-S('1E;7!L
M871E(&]R(&9A;'-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971!9&1R97-S
M5&5M<&QA=&4H)&-A<G)I97(I"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D
M=&AI<RT^7V-A<G)I97)S6R1C87)R:65R72DI('L*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/E]C
M87)R:65R<ULD8V%R<FEE<ET["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S
M(&$@8V%R<FEE<B!T;R!T:&4@;&ES="X*("`@("`J"B`@("`@*B!!9&1R97-S
M('1E;7!L871E<R!N965D('1O(&)E(&EN('1H92!F;W)M(&]F(&%N(&5M86EL
M(&%D9')E<W,L('=I=&@@80H@("`@("H@)R5S)R!R97!R97-E;G1I;F<@=&AE
M('!L86-E('=H97)E('1H92!D97-T:6YA=&EO;B!P:&]N92!N=6UB97(@9V]E
M<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!#87)R:65R
M(&YA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1A9&1R("!!9&1R97-S('1E
M;7!L871E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1#87)R:65R*"1N86UE
M+"`D861D<BD*("`@('L*("`@("`@("`D=&AI<RT^7V-A<G)I97)S6R1N86UE
M72`]("1A9&1R.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&QI
M<W0@;V8@<&%R86UE=&5R<R!S<&5C:69I8R!F;W(@=&AI<R!D<FEV97(N"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2!$969A=6QT('-E;F1I;F<@<&%R
M86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&5F875L=%-E;F10
M87)A;7,H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TYE="]335,O=VEN
M7VAT='`N<&AP````````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#(R,S$W(#$P-3$U-#,S-S0P(#`R,C`T-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@3F5T7U--4U]W
M:6Y?:'1T<"!#;&%S<R!I;7!L96UE;G1S('1H92!(5%10($%022!F;W(@86-C
M97-S:6YG('1H92!724X*("H@*'=W=RYW:6YP;&,N8V]M*2!335,@9V%T97=A
M>2X*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-87)K;R!$:G5K:6,@/&UA
M<FMO0&]B;&\N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D
M:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP+'8@,2XY+C(N,B`R,#`V
M+S`Q+S`Q(#(Q.C(X.C(Y(&IA;B!%>'`@)`H@*@H@*B!`875T:&]R($UA<FMO
M($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J($!P86-K86=E($YE=%]335,*
M("HO"F-L87-S($YE=%]335-?=VEN7VAT='`@97AT96YD<R!.971?4TU3('L*
M"B`@("!V87(@)%]B87-E7W5R;"`]("=G871E=V%Y,RYG;S)M;V)I;&4N;F5T
M.C$P,#,P+V=A=&5W87DO=C,O9V%T97=A>2YA<W!X)SL*"B`@("`O*BH*("`@
M("`J($%N(&%R<F%Y(&]F(&-A<&%B:6QI=&EE<RP@<V\@=&AA="!T:&4@9')I
M=F5R(&-A;B!R97!O<G0@=VAI8V@@;W!E<F%T:6]N<PH@("`@("H@:70@<W5P
M<&]R=',@86YD('=H:6-H(&ET(&1O97-N)W0N(%!O<W-I8FQE('9A;'5E<R!A
M<F4Z/'!R93X*("`@("`J("`@875T:"`@("`@("`@+2!4:&4@9V%T97=A>2!R
M97%U:7)E<R!A=71H96YT:6-A=&EO;B!B969O<F4@<V5N9&EN9SL*("`@("`J
M("`@8F%T8V@@("`@("`@+2!"871C:"!S96YD:6YG(&ES('-U<'!O<G1E9#L*
M("`@("`J("`@;75L=&D@("`@("`@+2!396YD:6YG(&]F(&UE<W-A9V5S('1O
M(&UU;'1I<&QE(')E8VEP:65N=',@:7,@<W5P<&]R=&5D.PH@("`@("H@("!R
M96-E:79E("`@("`M(%=H971H97(@=&AI<R!D<FEV97(@:7,@8V%P86)L92!O
M9B!R96-E:79I;F<@4TU3.PH@("`@("H@("!C<F5D:70@("`@("`M($ES('5S
M92!O9B!T:&4@9V%T97=A>2!B87-E9"!O;B!C<F5D:71S.PH@("`@("H@("!A
M9&1R97-S8F]O:R`M($%R92!G871E=V%Y(&%D9')E<W-B;V]K<R!S=7!P;W)T
M960["B`@("`@*B`@(&QI<W1S("`@("`@("T@1V%T97=A>2!S=7!P;W)T(&9O
M<B!D:7-T<FEB=71I;VX@;&ES=',N"B`@("`@*B`\+W!R93X*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D8V%P86)I;&ET:65S
M(#T@87)R87DH)V%U=&@G("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V)A=&-H)R`@("`@("`]/B`Q,#`L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=M=6QT:2<@("`@("`@/3X@=')U
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E8V5I=F4G("`@
M("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-R
M961I="<@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)V%D9')E<W-B;V]K)R`]/B!F86QS92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)VQI<W1S)R`@("`@("`]/B!F86QS92D["@H@("`@
M+RHJ"B`@("`@*B!4:&ES(&9U;F-T:6]N(&1O97,@=&AE(&%C='5A;"!S96YD
M:6YG(&]F('1H92!M97-S86=E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D;65S<V%G92`@5&AE
M(&%R<F%Y(&-O;G1A:6YI;F<@=&AE(&UE<W-A9V4@86YD(&ET<R!S96YD"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@('!A<F%M971E<G,N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1T;R`@("`@(%1H92!D97-T:6YA=&EO;B!S=')I
M;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@=VET
M:"!T:&4@<W5C8V5S<R!S=&%T=7,@86YD(&%D9&ET:6]N86P*("`@("`J("`@
M("`@("`@("`@("`@(&EN9F]R;6%T:6]N+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?<V5N9"@F)&UE<W-A9V4L("1T;RD*("`@('L*("`@("`@("`O*B!3=&%R
M="!T:&4@6$U,+B`J+PH@("`@("`@("1X;6P@/2`G/%--4TU%4U-!1T4^/%1%
M6%0^)R`N("1M97-S86=E6R=T97AT)UT@+B`G/"]415A4/B<["@H@("`@("`@
M("\J($-H96-K(&EF('-O=7)C92!F<F]M(&ES('-E="X@*B\*("`@("`@("!I
M9B`H(65M<'1Y*"1M97-S86=E6R=S96YD7W!A<F%M<R==6R=F<F]M)UTI*2![
M"B`@("`@("`@("`@("1X;6P@+CT@)SQ33U520T5?041$4CXG("X@)&UE<W-A
M9V5;)W-E;F1?<&%R86US)UU;)V9R;VTG72`N("<\+U-/55)#15]!1$12/B<[
M"B`@("`@("`@?0H*("`@("`@("`O*B!,;V]P('1H<F]U9V@@<F5C:7!I96YT
M<R!A;F0@9&\@<V]M92!M:6YI;6%L('9A;&ED:71Y(&-H96-K:6YG+B`J+PH@
M("`@("`@(&EF("AI<U]A<G)A>2@D=&\I*2!["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1T;R!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@("`@(&EF
M("AP<F5G7VUA=&-H*"<O7BXJ/SP_*%PK/UQD>S<L?2DH/GPD*2\G+"`D=F%L
M+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@("`@("`@("`D=&];)&ME>5T@
M/2`D;6%T8VAE<ULQ73L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@+RH@268@82!R96-I<&EE;G0@:7,@:6YV86QI9"!S
M=&]P(&%L;"!F=7)T:&5R('-E;F1I;F<N("HO"B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N(&%R<F%Y*#`L('-P<FEN=&8H7R@B26YV86QI9"!R96-I<&EE
M;G0Z(%PB)7-<(B(I+"`D=F%L*2D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1T;R`](&EM<&QO9&4H)SPO1$535$E.
M051)3TY?041$4CX\1$535$E.051)3TY?041$4CXG+"`D=&\I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7BXJ/SP_
M*%PK/UQD>S<L?2DH/GPD*2\G+"`D=&\L("1M871C:&5S*2D@>PH@("`@("`@
M("`@("`@("`@)'1O(#T@)&UA=&-H97-;,5T["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("!R971U<FX@87)R87DH,"P@<W!R:6YT9BA?
M*"));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(BDL("1T;RDI.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@("1X;6P@+CT@)SQ$15-424Y!5$E/
M3E]!1$12/B<@+B`D=&\@+B`G/"]$15-424Y!5$E/3E]!1$12/B<["@H@("`@
M("`@("\J(%1/1$\Z(%-H;W5L9"!W92!H879E('-O;65T:&EN9R!M;W)E(&EN
M=&5L;&EG96YT/R!#;W5L9"!A8W1U86QL>0H@("`@("`@("`J(&)E('!A<G0@
M;V8@<V5N9"!P87)A;65T97)S+B`J+PH@("`@("`@("1X;6P@+CT@)SQ44D%.
M4T%#5$E/3DE$/B<@+B!T:6UE*"D@+B`G/"]44D%.4T%#5$E/3DE$/B<["@H@
M("`@("`@("\J(%1/1$\Z($%D9"!S;VUE(&5X=')A('1A9W,L(&IU<W0@=&%C
M:V5D(&]N(&9O<B!N;W<N("HO"B`@("`@("`@)'AM;"`N/2`G/%194$5)1#XR
M/"]465!%240^/%-%4E9)0T5)1#XQ/"]315)624-%240^/"]335--15-304=%
M/B<["@H@("`@("`@("\J(%-E;F0@=&AI<R!M97-S86=E+B`J+PH@("`@("`@
M("1R97-P;VYS92`]("1T:&ES+3Y?<&]S="@D>&UL*3L*("`@("`@("!I9B`H
M:7-?82@D<F5S<&]N<V4L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N(&%R<F%Y*#`L("1R97-P;VYS92T^9V5T365S<V%G92@I*3L*("`@
M("`@("!]"@H@("`@("`@("\J(%!A<G-E('1H92!R97-P;VYS92P@8VAE8VL@
M9F]R(&YE=R!L:6YE<R!I;B!C87-E(&]F(&UU;'1I<&QE"B`@("`@("`@("H@
M<F5C:7!I96YT<RX@*B\*("`@("`@("`D;&EN97,@/2!E>'!L;V1E*")<;B(L
M("1R97-P;VYS92D["B`@("`@("`@)')E<W!O;G-E(#T@87)R87DH*3L*"B`@
M("`@("`@:68@*&-O=6YT*"1L:6YE<RD@/B`Q*2!["B`@("`@("`@("`@("\J
M($UU;'1I<&QE(')E8VEP:65N=',N("HO"B`@("`@("`@("`@(&9O<F5A8V@@
M*"1L:6YE<R!A<R`D;&EN92D@>PH@("`@("`@("`@("`@("`@)'!A<G1S(#T@
M97AP;&]D92@G5&\Z)RP@)&QI;F4I.PH@("`@("`@("`@("`@("`@)')E8VEP
M:65N="`]('1R:6TH)'!A<G1S6S%=*3L*("`@("`@("`@("`@("`@(&EF("@D
M;&EN97-;,%T@/3T@)T%14TU3+4]+)RD@>PH@("`@("`@("`@("`@("`@("`@
M("1R97-P;VYS95LD<F5C:7!I96YT72`](&%R<F%Y*#$L(&YU;&PI.PH@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D<F5S
M<&]N<V5;)')E8VEP:65N=%T@/2!A<G)A>2@P+"`D;&EN97-;,%TI.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@+RH@4VEN9VQE(')E8VEP:65N="X@*B\*("`@("`@("`@
M("`@:68@*"1L:6YE<ULP72`]/2`G05%335,M3TLG*2!["B`@("`@("`@("`@
M("`@("`D<F5S<&]N<V5;)'1O72`](&%R<F%Y*#$L(&YU;&PI.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)')E<W!O;G-E6R1T;UT@
M/2!A<G)A>2@P+"`D;&EN97-;,%TI.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)')E<W!O;G-E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@261E;G1I9FEE<R!T:&ES(&=A=&5W87D@9')I=F5R(&%N9"!R971U
M<FYS(&$@8G)I968@9&5S8W)I<'1I;VXN"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@07)R87D@;V8@9')I=F5R(&EN9F\N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=$EN9F\H*0H@("`@>PH@("`@("`@("1I;F9O6R=N86UE)UT@
M/2!?*")724X@=FEA($A45%`B*3L*("`@("`@("`D:6YF;ULG9&5S8R==(#T@
M7R@B5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR
M;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@9V%T97=A>2P@=7-I
M;F<@=&AE($A45%`@05!)(BD["@H@("`@("`@(')E='5R;B`D:6YF;SL*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(')E<75I<F5D('!A<F%M
M971E<G,@9F]R('1H:7,@9V%T97=A>2!D<FEV97(N(%1H92!S971T86)L90H@
M("`@("H@<&%R86UE=&5R<R!F;W(@=&AI<R!G871E=V%Y(&%R93H*("`@("`J
M("`@+2!U<V5R("`@("`@("`@("`@+2!4:&4@=7-E<FYA;64@9F]R(&%U=&AE
M;G1I8V%T:6]N(&]N('1H92!G871E=V%Y.PH@("`@("H@("`M('!A<W-W;W)D
M("`@("`@("`M(%1H92!P87-S=V]R9"!F;W(@875T:&5N=&EC871I;VX@;VX@
M=&AE(&=A=&5W87D["B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@07)R
M87D@;V8@<F5Q=6ER960@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T4&%R86US*"D*("`@('L*("`@("`@("`D<&%R86US(#T@87)R87DH
M*3L*("`@("`@("`D<&%R86US6R=U<V5R)UT@("`@(#T@87)R87DH)VQA8F5L
M)R`]/B!?*")5<V5R;F%M92(I+"`G='EP92<@/3X@)W1E>'0G*3L*("`@("`@
M("`D<&%R86US6R=P87-S=V]R9"==(#T@87)R87DH)VQA8F5L)R`]/B!?*")0
M87-S=V]R9"(I+"`G='EP92<@/3X@)W1E>'0G*3L*"B`@("`@("`@<F5T=7)N
M("1P87)A;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!P
M87)A;65T97)S('1H870@8V%N(&)E('-E="!A<R!D969A=6QT(&9O<B!S96YD
M:6YG(&UE<W-A9V5S"B`@("`@*B!U<VEN9R!T:&ES(&=A=&5W87D@9')I=F5R
M(&%N9"!D:7-P;&%Y960@=VAE;B!S96YD:6YG(&UE<W-A9V5S+@H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@($%R<F%Y(&]F('!A<F%M971E<G,@=&AA
M="!C86X@8F4@<V5T(&%S(&1E9F%U;'0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$1E9F%U;'1396YD4&%R86US*"D*("`@('L*("`@("`@("`D<&%R86US
M(#T@87)R87DH*3L*("`@("`@("`D<&%R86US6R=F<F]M)UT@/2!A<G)A>2@*
M("`@("`@("`@("`@)VQA8F5L)R`]/B!?*")3;W5R8V4@861D<F5S<R(I+`H@
M("`@("`@("`@("`G='EP92<@/3X@)W1E>'0G*3L*"B`@("`@("`@)'!A<F%M
M<ULG8V]S=%]I9"==(#T@87)R87DH"B`@("`@("`@("`@("=L86)E;"<@/3X@
M7R@B0V]S="!)1"(I+`H@("`@("`@("`@("`G='EP92<@/3X@)VEN="<I.PH*
M("`@("`@("!R971U<FX@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=&AE('!A<F%M971E<G,@9F]R('-E;F1I;F<@;65S<V%G97,@
M=7-I;F<@=&AI<R!G871E=V%Y(&1R:79E<BP*("`@("`J(&1I<W!L87EE9"!W
M:&5N('-E;F1I;F<@;65S<V%G97,N(%1H97-E(&%R92!F:6QT97)E9"!O=70@
M=7-I;F<@=&AE"B`@("`@*B!D969A=6QT('9A;'5E<R!S970@=7`@=VAE;B!C
M<F5A=&EN9R!T:&4@9V%T97=A>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!!<G)A>2!O9B!R97%U:7)E9"!P87)A;65T97)S+@H@("`@("H@0'1O
M9&\@(%=O=6QD(&)E(&YI8V4@=&\@=7-E(&$@=&EM92]D871E('-E='5P(')A
M=&AE<B!T:&%N(&UI;G5T97,@9G)O;0H@("`@("H@("`@("`@(&YO=R!F;W(@
M=&AE(&1E;&EV97)Y('1I;64N(%5P;&]A9"!F:65L9"!F;W(@<FEN9W1O;F5S
M+VQO9V]S/PH@("`@("HO"B`@("!F=6YC=&EO;B!G971396YD4&%R86US*"1P
M87)A;7,I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1P87)A;7-;)V9R;VTG
M72DI('L*("`@("`@("`@("`@)'!A<F%M<ULG9G)O;2==(#T@87)R87DH"B`@
M("`@("`@("`@("`@("`G;&%B96PG(#T^(%\H(E-O=7)C92!A9&1R97-S(BDL
M"B`@("`@("`@("`@("`@("`G='EP92<@/3X@)W1E>'0G*3L*("`@("`@("!]
M"@H@("`@("`@(&EF("AE;7!T>2@D<&%R86US6R=C;W-T7VED)UTI*2!["B`@
M("`@("`@("`@("1P87)A;7-;)V1E;&EV7W1I;64G72`](&%R<F%Y*`H@("`@
M("`@("`@("`@("`@)VQA8F5L)R`]/B!?*")#;W-T($E$(BDL"B`@("`@("`@
M("`@("`@("`G='EP92<@/3X@)VEN="<I.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1P87)A;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M(&$@<W1R:6YG(')E<')E<V5N=&%T:6]N(&]F(&%N(&5R<F]R(&-O9&4N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&5R<F]R("!4:&4@97)R;W(@
M8V]D92!T;R!L;V]K('5P+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@
M("!!;B!E>&ES=&EN9R!E<G)O<B!T97AT('1O('5S92!T;R!R86ES92!A"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@(%!%05(@17)R;W(N"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@02!T97AT=6%L(&UE<W-A9V4@8V]R
M<F5S<&]N9&EN9R!T;R!T:&4@97)R;W(@8V]D92!O<B!A"B`@("`@*B`@("`@
M("`@("`@("`@("!014%2($5R<F]R(&EF('!A<W-E9"!A;B!E>&ES=&EN9R!E
M<G)O<B!T97AT+@H@("`@("H*("`@("`J($!T;V1O("!#:&5C:R!W:&EC:"!O
M9B!T:&5S92!A<F4@86-T=6%L;'D@<F5Q=6ER960@86YD('1R:6T@9&]W;B!T
M:&4*("`@("`J("`@("`@("!L:7-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971%<G)O<B@D97)R;W(L("1E<G)O<E]T97AT(#T@)R<I"B`@("!["B`@("`@
M("`@)&5R<F]R(#T@=')I;2@D97)R;W(I.PH*("`@("`@("`O*B!!;B!A<G)A
M>2!O9B!E<G)O<B!C;V1E<R!R971U<FYE9"!B>2!T:&4@9V%T97=A>2X@*B\*
M("`@("`@("`D97)R;W)S(#T@87)R87DH"B`@("`@("`@("`@("=!45--4RU.
M3T%55$A$151!24Q3)R`@("`@("`@/3X@7R@B3F\@=7-E<FYA;64@86YD+V]R
M('!A<W-W;W)D('-E;G0N(BDL"B`@("`@("`@("`@("=!45--4RU$25-43$E3
M5%501$%414524D]2)R`@/3X@7R@B5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T
M:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L
M871E<BXB*2D["@H@("`@("`@(&EF("AE;7!T>2@D97)R;W)?=&5X="DI('L*
M("`@("`@("`@("`@<F5T=7)N("1E<G)O<G-;)&5R<F]R73L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS
M<')I;G1F*"1E<G)O<E]T97AT+"`D97)R;W)S6R1E<G)O<ETI*3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$;R!T:&4@:'1T<"!C86QL('5S
M:6YG(&$@=7)L('!A<W-E9"!T;R!T:&4@9G5N8W1I;VXN"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D>&UL("!4:&4@6$U,(&EN9F]R;6%T:6]N('!A<W-E9"!T;R!T:&4@9V%T
M97=A>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@<F5S<&]N
M<V4@;VX@<W5C8V5S<R!O<B!014%2($5R<F]R(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]P;W-T*"1X;6PI"B`@("!["B`@("`@("`@)&]P
M=&EO;G-;)VUE=&AO9"==(#T@)U!/4U0G.PH@("`@("`@("1O<'1I;VYS6R=T
M:6UE;W5T)UT@/2`U.PH@("`@("`@("1O<'1I;VYS6R=A;&QO=U)E9&ER96-T
M<R==(#T@=')U93L*"B`@("`@("`@+RH@5W)A<"!T:&4@>&UL('=I=&@@=&AE
M('-T86YD87)D('1A9W,N("HO"B`@("`@("`@)'AM;"`]("<\/WAM;"!V97)S
M:6]N/2(Q+C`B('-T86YD86QO;F4](FYO(C\^/"%$3T-465!%(%=)3E]$14Q)
M5D5265\R7U--4R!365-414T@(G=I;F)O=6YD7VUE<W-A9V5S7W8Q+F1T9"(^
M/%=)3E]$14Q)5D5265\R7U--4SXG("X@)'AM;"`N("<\+U=)3E]$14Q)5D52
M65\R7U--4SXG.PH*("`@("`@("!I9B`H(4!I;F-L=61E7V]N8V4@)TA45%`O
M4F5Q=65S="YP:'`G*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*%\H(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB
M*2D["B`@("`@("`@?0H@("`@("`@("1H='1P(#T@)FYE=R!(5%107U)E<75E
M<W0H)'1H:7,M/E]B87-E7W5R;"P@)&]P=&EO;G,I.PH*("`@("`@("`O*B!!
M9&0@=&AE(&%U=&AE;G1I8V%T:6]N('9A;'5E<R!T;R!03U-4+B`J+PH@("`@
M("`@("1H='1P+3YA9&10;W-T1&%T82@G57-E<B<L("1T:&ES+3Y?<&%R86US
M6R=U<V5R)UTI.PH@("`@("`@("1H='1P+3YA9&10;W-T1&%T82@G4&%S<W=O
M<F0G+"`D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72D["@H@("`@("`@("\J
M($%D9"!T:&4@6$U,(&%N9"!S96YD('1H92!R97%U97-T+B`J+PH@("`@("`@
M("1H='1P+3YA9&10;W-T1&%T82@G5TE.7UA-3"<L("1X;6PI.PH@("`@("`@
M($`D:'1T<"T^<V5N9%)E<75E<W0H*3L*("`@("`@("!I9B`H)&AT='`M/F=E
M=%)E<W!O;G-E0V]D92@I("$](#(P,"D@>PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D-O=6QD(&YO="!O<&5N("5S
M+B(I+"`D=&AI<RT^7V)A<V5?=7)L*2D["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)&AT='`M/F=E=%)E<W!O;G-E0F]D>2@I.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B].970O24U34```````````````````````````````
M```````````````````````````````````````````````````````P,#`W
M-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<T,"`P
M,3<U,C(`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TYE="])35-0+T%U=&@`
M````````````````````````````````````````````````````````````
M`````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M,#`P(#$P-3$U-#,S-S0P(#`R,#0R,P`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O3F5T+TE-4U`O075T:"]I;71E<W0N<&AP````````````````````````
M````````````````````````````````````````,#`P-S4U(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#8V,C4@,3`U,34T,S,W-#`@,#(R-3,T`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B!4:&4@3F5T7TE-4U!?075T:%]I;71E<W0@8VQA<W,@9F]R($E-4U`@
M875T:&5N=&EC871I;VXN"B`J"B`J(%)E<75I<F5D('!A<F%M971E<G,Z/'!R
M93X*("H@("`G=7-E<FYA;64G("`@("`@("!5<V5R;F%M92!T;R!L;V=O;B!T
M;R!)35-0('-E<G9E<B!A<RX*("H@("`G<&%S<W=O<F0G("`@("`@("!087-S
M=V]R9"!F;W(@8W5R<F5N="!U<V5R+@H@*B`@("=S97)V97(G("`@("`@("`@
M(%1H92!H;W-T;F%M92!O9B!T:&4@24U34"!S97)V97(N"B`J("`@)W!O<G0G
M("`@("`@("`@("`@5&AE('!O<G0@;V8@=&AE($E-4U`@<V5R=F5R+@H@*B`@
M("=S;V-K970G("`@("`@("`@(%1H92!N86UE9"!S;V-K970@=&\@=7-E(&9O
M<B!C;VYN96-T:6]N"B`J("`@)V-O;6UA;F0G("`@("`@("`@4&%T:"!T;R!T
M:&4@:6UT97-T(&-O;6UA;F0@;VX@;&]C86QH;W-T"B`J("`@)V%U=&A?;65C
M:&%N:7-M)R`@075T:&5N=&EC871I;VX@;65T:&]D('1O('5S92!W:71H(&EM
M=&5S=#PO<')E/@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R].971?24U34"])
M35-0+T%U=&@O:6UT97-T+G!H<"QV(#$N,3(N,BXT(#(P,#8O,#$O,#$@,C$Z
M,C@Z,C@@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@("`@
M("!,:6%M($AO96ME;F=A(#QL:6%M<D!U;6EC:"YE9'4^"B`J($-O<'ER:6=H
M="`R,#`S+3(P,#8@36EC:&%E;"!2=6)I;G-K>2`\;7)U8FEN<VM`:&]R9&4N
M;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@3&EA;2!(;V5K96YG
M82`\;&EA;7)`=6UI8V@N961U/@H@*B!`875T:&]R("!-:6-H865L(%)U8FEN
M<VMY(#QM<G5B:6YS:T!H;W)D92YO<F<^"B`J($!P86-K86=E($YE=%])35-0
M"B`J+PIC;&%S<R!.971?24U34%]!=71H7VEM=&5S="!E>'1E;F1S($YE=%])
M35-07T%U=&@@>PH*("`@("\J*@H@("`@("H@4')I=F%T92!A=71H96YT:6-A
M=&EO;B!F=6YC=&EO;BX@(%!R;W9I9&5S(&%C='5A;`H@("`@("H@875T:&5N
M=&EC871I;VX@8V]D92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J($!P87)A;2`@;6EX960@("1P87)A;7,@2&%S:"!O9B!)35-0('!A
M<F%M971E<G,N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@3F5T7TE-
M4U`@;V)J96-T(&-O;FYE8W1E9"!T;R!S97)V97(@:68@<W5C8V5S<V9U;"P*
M("`@("`J("`@("`@("`@("`@("`@(%!%05)?17)R;W(@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@)E]A=71H96YT:6-A=&4H)'!A<F%M<RD*
M("`@('L*("`@("`@("`D:6US<"`]("9.971?24U34#HZ<VEN9VQE=&]N*"=N
M;VYE)RP@)'!A<F%M<RD["B`@("`@("`@)&-O;6UA;F0@/2`G)SL*("`@("`@
M("`D97)R;W)?<F5T=7)N(#T@)R<["@H@("`@("`@(&EF("AS=')T;VQO=V5R
M*"1P87)A;7-;)V%U=&A?;65C:&%N:7-M)UTI(#T]("=G<W-A<&DG("8F"B`@
M("`@("`@("`@(&ES<V5T*"1?4T525D526R=+4D(U0T-.04U%)UTI*2!["B`@
M("`@("`@("`@("`@("`D8V]M;6%N9"`N/2`G2U)"-4-#3D%-13TG("X@)%]3
M15)615);)TM20C5#0TY!344G73L*("`@("`@("!]"@H@("`@("`@("1C;VUM
M86YD("X]("<@)R`@("`N("1P87)A;7-;)V-O;6UA;F0G72X*("`@("`@("`@
M("`@("`@("`@("`G("UM("<@+B`D<&%R86US6R=A=71H7VUE8VAA;FES;2==
M("X*("`@("`@("`@("`@("`@("`@("`G("UU("<@+B!E<V-A<&5S:&5L;&%R
M9R@D<&%R86US6R=U<V5R;F%M92==*2`N"B`@("`@("`@("`@("`@("`@("`@
M)R`M82`G("X@97-C87!E<VAE;&QA<F<H)'!A<F%M<ULG=7-E<FYA;64G72D@
M+@H@("`@("`@("`@("`@("`@("`@("<@+7<@)R`N(&5S8V%P97-H96QL87)G
M*"1P87)A;7-;)W!A<W-W;W)D)UTI+@H@("`@("`@("`@("`@("`@("`@("<@
M+7`@)R`N("1P87)A;7-;)W!O<G0G72`N"B`@("`@("`@("`@("`@("`@("`@
M)R`M6"`G("X@)'!A<F%M<ULG<V]C:V5T)UT@+@H@("`@("`@("`@("`@("`@
M("`@("<@)R`@("`N("1P87)A;7-;)W-E<G9E<B==.PH*("`@("`@("`D8V]N
M;E]A='1E;7!T<R`](#`["B`@("`@("`@=VAI;&4@*"1C;VYN7V%T=&5M<'1S
M*RL@/"`T*2!["B`@("`@("`@("`@("1A='1E;7!T<R`](#`["B`@("`@("`@
M("`@(&EF("@A9FEL95]E>&ES=',H)'!A<F%M<ULG<V]C:V5T)UTI*2!["B`@
M("`@("`@("`@("`@("!E>&5C*"1C;VUM86YD("X@)R`^("]D978O;G5L;"`R
M/B8Q)RD["B`@("`@("`@("`@("`@("!S;&5E<"@Q*3L*("`@("`@("`@("`@
M("`@('=H:6QE("@A9FEL95]E>&ES=',H)'!A<F%M<ULG<V]C:V5T)UTI*2![
M"B`@("`@("`@("`@("`@("`@("`@=7-L965P*#(P,#`P,"D["B`@("`@("`@
M("`@("`@("`@("`@:68@*"1A='1E;7!T<RLK(#X@-2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D97)R;W)?<F5T=7)N(#T@)SH@3F\@<V]C:V5T(&%F
M=&5R(#$P('-E8V]N9',@;V8@=')Y:6YG(2<["B`@("`@("`@("`@("`@("`@
M("`@("`@(&-O;G1I;G5E(#(["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1F<"`]
M($!F<V]C:V]P96XH)'!A<F%M<ULG<V]C:V5T)UTL(#`L("1E<G)O<E]N=6UB
M97(L("1E<G)O<E]S=')I;F<L(#,P*3L*("`@("`@("`@("`@)&5R<F]R7W)E
M='5R;B`]("1E<G)O<E]S=')I;F<["B`@("`@("`@("`@(&EF("@D9G`I(&)R
M96%K.PH@("`@("`@("`@("!U;FQI;FLH)'!A<F%M<ULG<V]C:V5T)UTI.PH*
M("`@("`@("!]"B`@("`@("`@+R]&86EL=7)E/PH@("`@("`@(&EF("@A96UP
M='DH)&5R<F]R7W)E='5R;BDI('L*("`@("`@("`@("`@<F5T=7)N("1I;7-P
M+3YI;7-P17)R;W(H)T-O;FYE8W1I;VX@=&\@24U34"!H;W-T(&9A:6QE9"XG
M("X@)SH@)R`N("1E<G)O<E]R971U<FXL(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@?0H@("`@("`@("\O4W5C8V5S<PH@("`@("`@("1I;7-P+3Y?
M<W1R96%M(#T@)&9P.PH@("`@("`@(')E='5R;B`D:6US<#L*("`@('T*"B`@
M("`O*BH*("`@("`J($9O<F-E(&$@;&]G;W5T(&-O;6UA;F0@=&\@=&AE(&EM
M<W`@<W1R96%M+@H@("`@("H*("`@("`J+PH@("`@9G5N8W1I;VX@;&]G;W5T
M*"D*("`@('L*("`@("`@("`D=&AI<RT^7VEM<W`M/FQO9V]U="@I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@9')I=F5R('1Y<&4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!T>7!E(&]F('1H:7,@
M24U34%]!=71H(&1R:79E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1')I
M=F5R5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=I;71E<W0G.PH@("`@
M?0I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+TYE="])35-0+T%U=&@O8W)A;5]M9#4N<&AP````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`W,C`R(#$P-3$U-#,S-S0P(#`R,C<P,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@5&AE($YE=%])35-07T%U=&A?8W)A;5]M9#4@8VQA<W,@9F]R($E-
M4U`@875T:&5N=&EC871I;VXN"B`J"B`J(%)E<75I<F5D('!A<F%M971E<G,Z
M/'!R93X*("H@("`G=7-E<FYA;64G("!5<V5R;F%M92!T;R!L;V=O;B!T;R!)
M35-0('-E<G9E<B!A<RX*("H@("`G<&%S<W=O<F0G("!087-S=V]R9"!F;W(@
M8W5R<F5N="!U<V5R+@H@*B`@("=S97)V97(G("`@(%1H92!H;W-T;F%M92!O
M9B!T:&4@24U34"!S97)V97(N"B`J("`@)W!O<G0G("`@("`@5&AE('!O<G0@
M;V8@=&AE($E-4U`@<V5R=F5R+CPO<')E/@H@*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R].971?24U34"])35-0+T%U=&@O8W)A;5]M9#4N<&AP+'8@,2XV+C$P
M+CD@,C`P-B\P,2\P,2`R,3HR.#HR."!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#,M,C`P-B!-:6-H865L(%)U8FEN<VMY(#QM<G5B:6YS:T!H;W)D
M92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6-H865L(%)U
M8FEN<VMY(#QM<G5B:6YS:T!H;W)D92YO<F<^"B`J($!P86-K86=E($YE=%])
M35-0"B`J+PIC;&%S<R!.971?24U34%]!=71H7V-R86U?;60U(&5X=&5N9',@
M3F5T7TE-4U!?075T:"!["@H@("`@+RHJ"B`@("`@*B!0<FEV871E(&%U=&AE
M;G1I8V%T:6]N(&9U;F-T:6]N+B`@4')O=FED97,@86-T=6%L"B`@("`@*B!A
M=71H96YT:6-A=&EO;B!C;V1E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H@0'!A<F%M("!M:7AE9"`D<&%R86US($AA<V@@;V8@24U3
M4"!P87)A;65T97)S+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@3F5T
M7TE-4U`@;V)J96-T(&-O;FYE8W1E9"!T;R!S97)V97(@:68@<W5C8V5S<V9U
M;"P*("`@("`J("`@("`@("`@("`@("`@4$5!4E]%<G)O<B!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B`F7V%U=&AE;G1I8V%T92@D<&%R86US
M*0H@("`@>PH@("`@("`@("1I;7-P(#T@)DYE=%])35-0.CIS:6YG;&5T;VXH
M)VYO;F4G+"`D<&%R86US*3L*("`@("`@("`D<F5S=6QT(#T@)&EM<W`M/FEN
M:70H*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@
M("`@("`@)'5S97))9"`]("1P87)A;7-;)W5S97)N86UE)UT["B`@("`@("`@
M)&-R961E;G1I86QS(#T@)'!A<F%M<ULG<&%S<W=O<F0G73L*("`@("`@("`D
M<F5S=6QT(#T@)&EM<W`M/FEM<W!396YD*"=!551(14Y424-!5$4@0U)!32U-
M1#4G*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@
M("`@("`@+RH@1V5T(')E<W!O;G-E(&%N9"!D96-O9&4@:70N($YO=&4@=&AA
M="!W92!R96UO=F4@=&AE(#%S="`R"B`@("`@("`@("H@8VAA<F%C=&5R<R!F
M<F]M('1H92!R97-P;VYS92!T;R!G970@<FED(&]F('1H92`G*R<*("`@("`@
M("`@*B!C;VYT:6YU871I;VX@8VAA<F%C=&5R(&%N9"!T:&4@<W!A8V4@=&AA
M="!I<R!S96YT(&%S('!A<G0*("`@("`@("`@*B!O9B!T:&4@0U)!32U-1#4@
M<F5S<&]N<V4@*&%T(&QE87-T(&]N(&-Y<G5S+6EM<W!D*2X@*B\*("`@("`@
M("`D<V5R=F5R7W)E<W!O;G-E(#T@)&EM<W`M/FEM<W!296-E:79E*"D["B`@
M("`@("`@:68@*&ES7V$H)'-E<G9E<E]R97-P;VYS92P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'-E<G9E<E]R97-P;VYS93L*("`@
M("`@("!]"@H@("`@("`@("1S97)V97)?<F5S<&]N<V4@/2!B87-E-C1?9&5C
M;V1E*'1R:6TH<W5B<W1R*"1S97)V97)?<F5S<&]N<V4L(#(I*2D["@H@("`@
M("`@("\J($)U:6QD(&%N9"!B87-E-C0@96YC;V1E('1H92!R97-P;VYS92!T
M;R!T:&4@8VAA;&QA;F=E+B`J+PH@("`@("`@("1R97-P;VYS95]T;U]S96YD
M(#T@)'5S97))9"`N("<@)R`N("1T:&ES+3Y?:&UA8R@D8W)E9&5N=&EA;',L
M("1S97)V97)?<F5S<&]N<V4I.PH@("`@("`@("1C;VUM86YD7W-T<FEN9R`]
M(&)A<V4V-%]E;F-O9&4H)')E<W!O;G-E7W1O7W-E;F0I.PH*("`@("`@("`O
M*B!396YD('1H92!R97-P;VYS92X@*B\*("`@("`@("`D<F5S=6QT(#T@)&EM
M<W`M/FEM<W!396YD*"1C;VUM86YD7W-T<FEN9RP@9F%L<V4I.PH@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT
M(#T@)&EM<W`M/FEM<W!296-E:79E*"D["B`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("!]"@H@("`@("`@(&EF("@D<F5S=6QT("$]("=/2R<I
M('L*("`@("`@("`@("`@<F5T=7)N("1I;7-P+3YI;7-P17)R;W(H)TQO9VEN
M('1O($E-4U`@:&]S="!F86EL960N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)&EM<W`["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4D9#(#(Q,#0@2$U!0R!I
M;7!L96UE;G1A=&EO;BX@16QI;6EN871E<R!T:&4@<F5L:6%N8V4@;VX@;6AA
M<V@N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R
M86T@('-T<FEN9R`@)&ME>2`@("!4:&4@2$U!0R!K97DN"B`@("`@*B!`<&%R
M86T@('-T<FEN9R`@)&1A=&$@("!4:&4@9&%T82!T;R!H87-H('=I=&@@=&AE
M(&ME>2X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($U$-2!(
M34%#+@H@("`@("HO"B`@("!F=6YC=&EO;B!?:&UA8R@D:V5Y+"`D9&%T82D*
M("`@('L*("`@("`@("`O*B!">71E(&QE;F=T:"!F;W(@;60U+B`J+PH@("`@
M("`@("1B(#T@-C0["@H@("`@("`@(&EF("AS=')L96XH)&ME>2D@/B`D8BD@
M>PH@("`@("`@("`@("`D:V5Y(#T@<&%C:R@G2"HG+"!M9#4H)&ME>2DI.PH@
M("`@("`@('T*"B`@("`@("`@)&ME>2`]('-T<E]P860H)&ME>2P@)&(L(&-H
M<B@P>#`P*2D["B`@("`@("`@)&EP860@/2!S=')?<&%D*"<G+"`D8BP@8VAR
M*#!X,S8I*3L*("`@("`@("`D;W!A9"`]('-T<E]P860H)R<L("1B+"!C:'(H
M,'@U8RDI.PH@("`@("`@("1K7VEP860@/2`D:V5Y(%X@)&EP860["B`@("`@
M("`@)&M?;W!A9"`]("1K97D@7B`D;W!A9#L*("`@("`@("!R971U<FX@;60U
M*"1K7V]P860@+B!P86-K*"=(*B<L(&UD-2@D:U]I<&%D("X@)&1A=&$I*2D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!&;W)C92!A(&QO9V]U="!C;VUM86YD
M('1O('1H92!I;7-P('-T<F5A;2X*("`@("`J"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&QO9V]U="@I"B`@("!["B`@("`@("`@)'1H:7,M/E]I;7-P+3YL;V=O
M=70H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@9')I=F5R
M('1Y<&4*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R!T:&4@='EP92!O
M9B!T:&ES($E-4U!?075T:"!D<FEV97(*("`@("`J+PH@("`@(&9U;F-T:6]N
M(&=E=$1R:79E<E1Y<&4H*0H@("`@('L*("`@("`@("`@<F5T=7)N("=C<F%M
M7VUD-2<["B`@("`@?0H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TYE="])35-0+T%U=&@O<&QA:6YT97AT
M+G!H<```````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`W-#(Q(#$P-3$U
M-#,S-S0P(#`R,S(R-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@5&AE($YE=%])35-07T%U=&A?<&QA
M:6YT97AT(&-L87-S(&9O<B!)35-0(&%U=&AE;G1I8V%T:6]N+@H@*@H@*B!2
M97%U:7)E9"!P87)A;65T97)S.CQP<F4^"B`J("`@)W5S97)N86UE)R`@57-E
M<FYA;64@=&\@;&]G;VX@=&\@24U34"!S97)V97(@87,N"B`J("`@)W!A<W-W
M;W)D)R`@4&%S<W=O<F0@9F]R(&-U<G)E;G0@=7-E<BX*("H@("`G<V5R=F5R
M)R`@("!4:&4@:&]S=&YA;64@;V8@=&AE($E-4U`@<V5R=F5R+@H@*B`@("=P
M;W)T)R`@("`@(%1H92!P;W)T(&]F('1H92!)35-0('-E<G9E<BX\+W!R93X*
M("H*("H@)$AO<F1E.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]!=71H+W!L
M86EN=&5X="YP:'`L=B`Q+C<N,3`N,3$@,C`P-B\P,2\P,2`R,3HR.#HR."!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6-H865L(%)U
M8FEN<VMY(#QM<G5B:6YS:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@
M*B!`875T:&]R("!-:6-H865L(%)U8FEN<VMY(#QM<G5B:6YS:T!H;W)D92YO
M<F<^"B`J($!P86-K86=E($YE=%])35-0"B`J+PIC;&%S<R!.971?24U34%]!
M=71H7W!L86EN=&5X="!E>'1E;F1S($YE=%])35-07T%U=&@@>PH*("`@("\J
M*@H@("`@("H@4')I=F%T92!A=71H96YT:6-A=&EO;B!F=6YC=&EO;BX@(%!R
M;W9I9&5S(&%C='5A;`H@("`@("H@875T:&5N=&EC871I;VX@8V]D92X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!P87)A;2`@;6EX
M960@("1P87)A;7,@2&%S:"!O9B!)35-0('!A<F%M971E<G,N"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@3F5T7TE-4U`@;V)J96-T(&-O;FYE8W1E
M9"!T;R!S97)V97(@:68@<W5C8V5S<V9U;"P*("`@("`J("`@("`@("`@("`@
M("`@(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@)E]A=71H96YT:6-A=&4H)'!A<F%M<RD*("`@('L*("`@("`@("`D:6US
M<"`]("9.971?24U34#HZ<VEN9VQE=&]N*"=N;VYE)RP@)'!A<F%M<RD["B`@
M("`@("`@)')E<W5L="`]("1I;7-P+3YI;FET*"D["B`@("`@("`@:68@*&ES
M7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@("`D=7-E<DED(#T@)'!A
M<F%M<ULG=7-E<FYA;64G73L*("`@("`@("`@)&-R961E;G1I86QS(#T@)'!A
M<F%M<ULG<&%S<W=O<F0G73L*"B`@("`@("`@+RH@4W1A<G0@=&AE(&-O;6UA
M;F0N("HO"B`@("`@("`@)')E<W5L="`]("1I;7-P+3YI;7-P4V5N9"@G3$]'
M24X@)RP@=')U92P@9F%L<V4I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("`@("`@?0H*("`@("`@("`O*B!5<V5R;F%M92!A<R!A('M]/R`J+PH@
M("`@("`@(&EF("AP<F5G7VUA=&-H*$E-4U!?35535%]54T5?3$E415)!3"P@
M)'5S97))9"DI('L*("`@("`@("`@("`@)&)I57-E<B`]('-P<FEN=&8H)WLE
M9'TG+"!S=')L96XH)'5S97))9"DI.PH@("`@("`@("`@("`D<F5S=6QT(#T@
M)&EM<W`M/FEM<W!396YD*"1B:55S97(L(&9A;'-E+"!T<G5E*3L*("`@("`@
M("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@(&EF("@A<')E9U]M871C:"@B+UY<*R\B+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&EM<W`M/FEM<W!296-E:79E*"DI*2!["@H@
M("`@("`@("`@("`@("`@<F5T=7)N("1I;7-P+3YI;7-P17)R;W(H)T1I9"!N
M;W0@<F5C96EV92!E>'!E8W1E9"!C;VUM86YD(&-O;G1I;G5A=&EO;B!R97-P
M;VYS92!F<F]M($E-4U`@<V5R=F5R+B<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@)&EM<W`M
M/FEM<W!396YD*"1U<V5R260@+B`G("<L(&9A;'-E+"!F86QS92D["B`@("`@
M("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@("\J($1O
M;B=T('=A;G0@=&\@;&]G('1H92!P87-S=V]R9"$@*B\*("`@("`@("`D;&]G
M5F%L=64@/2`D:6US<"T^;&]G16YA8FQE9#L*("`@("`@("`D:6US<"T^;&]G
M16YA8FQE9"`](&9A;'-E.PH*("`@("`@("`O*B!087-S(&%S('M]/R`J+PH@
M("`@("`@(&EF("AP<F5G7VUA=&-H*$E-4U!?35535%]54T5?3$E415)!3"P@
M)&-R961E;G1I86QS*2D@>PH@("`@("`@("`@("`D8FE087-S(#T@<W!R:6YT
M9B@G>R5D?2<L('-T<FQE;B@D8W)E9&5N=&EA;',I*3L*("`@("`@("`@("`@
M)')E<W5L="`]("1I;7-P+3YI;7-P4V5N9"@D8FE087-S+"!F86QS92P@=')U
M92D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H(B]>7"LO(BP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I;7-P+3YI;7-P4F5C96EV
M92@I*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1I;7-P+3YI;7-P17)R
M;W(H)T1I9"!N;W0@<F5C96EV92!E>'!E8W1E9"!C;VUM86YD(&-O;G1I;G5A
M=&EO;B!R97-P;VYS92!F<F]M($E-4U`@<V5R=F5R+B<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT
M(#T@)&EM<W`M/FEM<W!396YD*"1C<F5D96YT:6%L<RP@9F%L<V4L('1R=64I
M.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@
M("`O*B!297-T;W)E('1H92!L;V=G:6YG(&)O;VQE86XN("HO"B`@("`@("`@
M)&EM<W`M/FQO9T5N86)L960@/2`D;&]G5F%L=64["@H@("`@("`@("1S97)V
M97)?<F5S<&]N<V4@/2`D:6US<"T^:6US<%)E8V5I=F4H*3L*("`@("`@("!I
M9B`H:7-?82@D<V5R=F5R7W)E<W!O;G-E+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<V5R=F5R7W)E<W!O;G-E.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"1S97)V97)?<F5S<&]N<V4@(3T@)T]+)RD@>PH@("`@
M("`@("`@("!R971U<FX@)&EM<W`M/FEM<W!%<G)O<B@G3&]G:6X@=&\@24U3
M4"!H;W-T(&9A:6QE9"XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1I;7-P.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1F]R8V4@82!L;V=O=70@8V]M;6%N9"!T;R!T:&4@:6US<"!S=')E86TN
M"B`@("`@*@H@("`@("HO"B`@("!F=6YC=&EO;B!L;V=O=70H*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?:6US<"T^;&]G;W5T*"D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FX@=&AE(&1R:79E<B!T>7!E"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@=&AE('1Y<&4@;V8@=&AI<R!)35-07T%U=&@@9')I
M=F5R"B`@("`@*B\*("`@("!F=6YC=&EO;B!G971$<FEV97)4>7!E*"D*("`@
M("!["B`@("`@("`@(')E='5R;B`G<&QA:6YT97AT)SL*("`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TYE="])
M35-0+T)O;VLN<&AP````````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,34R,#,U(#$P-3$U-#,S-S0P(#`R,3(Q,@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`H*<F5Q=6ER95]O
M;F-E("=.970O24U34"]!=71H+G!H<"<["@HO*BH*("H@4W1R:6YG(&]F('-U
M<'!O<G1E9"!!0TP@<FEG:'1S+@H@*B\*9&5F:6YE*"=)35-07T%#3%]224=(
M5%,G+"`G;')W8V1A)RD["@HO*BH*("H@3F5T7TE-4U!?0F]O:R!#;&%S<R`M
M('!R;W9I9&5S(&%P:2!F;W(@9&5A;&EN9R!W:71H($E-4U`*("H@861D<F5S
M<R!B;V]K<RX*("H*("H@4F5Q=6ER960@<&%R86UE=&5R<SH\<')E/@H@*B`@
M("=U<V5R;F%M92<@("`@(%5S97)N86UE('1O(&QO9V]N('1O($E-4U`@<V5R
M=F5R(&%S+@H@*B`@("=P87-S=V]R9"<@("`@(%!A<W-W;W)D(&9O<B!C=7)R
M96YT('5S97(N"B`J("`@)V%U=&A?;65T:&]D)R`@5&AE(&%U=&AE;G1I8V%T
M:6]N(&UE=&AO9"!T;R!U<V4@=&\@;&]G:6XN"B`J("`@)W-E<G9E<B<@("`@
M("`@5&AE(&AO<W1N86UE(&]F('1H92!)35-0('-E<G9E<BX*("H@("`G<&]R
M="<@("`@("`@("!4:&4@<&]R="!O9B!T:&4@24U34"!S97)V97(N/"]P<F4^
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O0F]O:RYP
M:'`L=B`Q+C$V+C(N,C(@,C`P-B\P,2\P,2`R,3HR.#HR."!J86X@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L(%)U8FEN<VMY(#QM
M<G5B:6YS:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!-:6-H865L(%)U8FEN<VMY(#QM<G5B:6YS:T!H;W)D92YO<F<^"B`J($!P
M86-K86=E($YE=%])35-0"B`J+PIC;&%S<R!.971?24U34%]";V]K('L*"B`@
M("`O*BH*("`@("`J(%-O<G0@;W)D97(N"B`@("`@*@H@("`@("H@0'9A<B!S
M=')I;F<*("`@("`J+PH@("`@=F%R("1S;W)T(#T@)V%S8V5N9"<["@H@("`@
M+RHJ"B`@("`@*B!.971?24U34"!O8FIE8W0N"B`@("`@*@H@("`@("H@0'9A
M<B!.971?24U34`H@("`@("HO"B`@("!V87(@)%]I;7-P.PH*("`@("\J*@H@
M("`@("H@4&%R86UE=&5R(&QI<W0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)%]P87)A;7,["@H@("`@+RHJ"B`@("`@*B!#
M;VYS=')U8W1O<B!F=6YC=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)'!A<F%M<R!(87-H(&-O;G1A:6YI;F<@24U34"!P87)A;65T97)S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!.971?24U34%]";V]K*"1P87)A;7,I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@?0H*
M("`@("\J*@H@("`@("H@26YI=&EA;&EZ871I;VX@9G5N8W1I;VX@=&\@8F4@
M8V%L;&5D(&%F=&5R(&]B:F5C="!I<R!R971U<FYE9"X*("`@("`J(%1H:7,@
M86QL;W=S(&5R<F]R<R!T;R!O8V-U<B!A;F0@;F]T(&)R96%K('1H92!S8W)I
M<'0N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C
M97-S(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@:6YI="@I"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7VEM
M<W`I*2!["B`@("`@("`@("`@("1A=71H(#T@)DYE=%])35-07T%U=&@Z.G-I
M;F=L971O;B@D=&AI<RT^7W!A<F%M<ULG875T:%]M971H;V0G72D["B`@("`@
M("`@("`@("1T:&ES+3Y?:6US<"`]("1A=71H+3YA=71H96YT:6-A=&4H)'1H
M:7,M/E]P87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7V$H)'1H
M:7,M/E]I;7-P+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7VEM<W`["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?:6US
M<"T^=W)I=&54;TQO9R@G3F5T7TE-4U!?0F]O:R!I;FET:6%L:7IE9"XG+"!?
M7T9)3$5?7RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?
M3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&%R<F%Y(&-O;G1A
M:6YI;F<@=&AE(&YA;65S(&]F(&%L;"!T:&4@861D<F5S<R!B;V]K<PH@("`@
M("H@879A:6QA8FQE('1O('1H92!L;V=G960@:6X@=7-E<BX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D($%R<F%Y(&]F(&%D9')E<W,@8F]O:R!N86UE
M<R!O<B!014%27T5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971!9&1R
M97-S0F]O:TQI<W0H*0H@("`@>PH@("`@("`@("1C;VUM86YD7W-T<FEN9R`]
M("=!1$1215-30D]/2R`J)SL*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?
M:6US<"T^:6US<%-E;F0H)&-O;6UA;F1?<W1R:6YG*3L*("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT+"=014%27T5R<F]R)RDI('L*("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)T-O;FYE8W1I;VX@=&\@24U3
M4"!H;W-T(&9A:6QE9"XG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*
M"B`@("`@("`@+RH@271E<F%T92!T:')O=6=H('1H92!R97-P;VYS92!A;F0@
M<&]P=6QA=&4@86X@87)R87D@;V8*("`@("`@("`@*B!A9&1R97-S(&)O;VL@
M;F%M97,N("HO"B`@("`@("`@)'-E<G9E<E]R97-P;VYS92`]("1T:&ES+3Y?
M:6US<"T^:6US<%)E8V5I=F4H*3L*("`@("`@("!I9B`H:7-?82@D<V5R=F5R
M7W)E<W!O;G-E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D<V5R=F5R7W)E<W!O;G-E.PH@("`@("`@('T*("`@("`@("`D86)O;VMS
M(#T@87)R87DH*3L*"B`@("`@("`@=VAI;&4@*'!R96=?;6%T8V@H(B]>7"H@
M041$4D534T)/3TLO(BP@)'-E<G9E<E]R97-P;VYS92DI('L*("`@("`@("`@
M("`@+RH@268@=&AI<R!I<R!A;B!!1$1215-30D]/2R!R97-P;VYS92P@=&AE
M;B!T:&ES('=I;&P@97AP;&]D92!A<R!S;SH*("`@("`@("`@("`@("H@6S!=
M(&%N9"!;,5T@8V%N(&)E(&1I<V-A<F1E9`H@("`@("`@("`@("`@*B!;,ET@
M/2!A='1R:6)U=&5S"B`@("`@("`@("`@("`J(%LS72`](&1E;&EM:71E<@H@
M("`@("`@("`@("`@*B!;-%T@/2!A9&1R97-S(&)O;VL@;F%M90H@("`@("`@
M("`@("`@*B\*"B`@("`@("`@("`@("\J($9I<G-T+"!C:&5C:R!F;W(@82![
M?2`J+PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"A)35-07T]#5$547T-/
M54Y4+"`D<V5R=F5R7W)E<W!O;G-E+"`D=&5M<$%R<F%Y*2D@>PH@("`@("`@
M("`@("`@("`@)&%B;V]K<UM=(#T@)'1H:7,M/E]I;7-P+3YR96-E:79E4W1R
M:6YG3&ET97)A;"@D=&5M<$%R<F%Y6S)=*3L*("`@("`@("`@("`@("`@("\J
M($=E="!T:&4@0U),1B!A="!E;F0@;V8@041$4D534T)/3TL@<F5S<&]N<V4*
M("`@("`@("`@("`@("`@("`J('1H870@=&AE('M](&1O97,@;F]T(&EN8VQU
M9&4N("HO"B`@("`@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/G)E8V5I=F53
M=')I;F=,:71E<F%L*#(I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)'!A<G1S(#T@97AP;&]D92@G("<L("1S97)V97)?<F5S<&]N
M<V4I.PH@("`@("`@("`@("`@("`@)&YU;5!A<G1S(#T@8V]U;G0H)'!A<G1S
M*3L*("`@("`@("`@("`@("`@("1N86UE(#T@)'!A<G1S6S1=.PH@("`@("`@
M("`@("`@("`@)&9I<G-T0VAA<B`]('-U8G-T<B@D;F%M92P@,"P@,2D["B`@
M("`@("`@("`@("`@("!I9B`H)&9I<G-T0VAA<B`]/2)<(B(I('L*("`@("`@
M("`@("`@("`@("`@("`D;F%M92`](&QT<FEM*"1N86UE+"`B7"(B*3L*("`@
M("`@("`@("`@("`@("`@("!F;W(@*"1I(#T@-3L@)&D@/"`D;G5M4&%R=',[
M("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&YA;64@+CT@)R`G
M("X@)'!A<G1S6R1I73L*("`@("`@("`@("`@("`@("`@("`@("`@)&QA<W1#
M:&%R(#T@<W5B<W1R*"1P87)T<ULD:5TL('-T<FQE;B@D<&%R='-;)&E=*2`M
M(#$L(#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&QA<W1#:&%R
M(#T](")<(B(I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N86UE
M(#T@<G1R:6TH)&YA;64L(")<(B(I.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`D86)O;VMS6UT@/2`D;F%M93L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D<V5R=F5R7W)E<W!O;G-E(#T@)'1H:7,M/E]I;7-P+3YI;7-P4F5C
M96EV92@I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1S97)V97)?<F5S<&]N
M<V4@(3T@)T]+)RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P
M+3YI;7-P17)R;W(H)T1I9"!N;W0@<F5C96EV92!T:&4@97AP96-T960@<F5S
M<&]N<V4@9G)O;2!T:&4@<V5R=F5R+B<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@
M("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]I;7-P+3YW<FET951O3&]G*"=!
M1$1215-30D]/2R!C;VUM86YD($]++B<L(%]?1DE,15]?+"!?7TQ)3D5?7RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?3$]'7TE.
M1D\I.PH@("`@("`@(')E='5R;B`D86)O;VMS.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!A;B!A<G)A>2!C;VYT86EN:6YG('1H92!N86UE<R!T
M:&%T(&UA=&-H("1S96%R8V@*("`@("`J(&-R:71E<F$@:6X@=&AE(&%D9')E
M<W,@8F]O:R!N86UE9"`D86)O;VLN"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D86)O;VL@($%D9')E<W,@8F]O:R!N86UE('1O('-E87)C:"X*("`@
M("`J($!P87)A;2!A<G)A>2`D<V5A<F-H("!396%R8V@@8W)I=&5R:6$@:6X@
M=&AE(&9O<FT@;V8*("`@("`J("`@("`@("`@("`@("`@("`@("`@("=F:65L
M9$YA;64G(#T^("=S96%R8VA497)M)R`H;6%Y(&EN8VQU9&4@*B!W:6QD(&-A
M<F0I+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@07)R87D@;V8@;F%M
M97,@;V8@=&AE(&5N=')I97,@=&AA="!M871C:"!O<B!014%27T5R<F]R+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!S96%R8V@H)&%B;V]K+"`D<V5A<F-H*0H@
M("`@>PH@("`@("`@("\O268@;F\@9FEE;&0@/3X@=F%L=64@<&%I<G,L(&%S
M<W5M92!W92!A<F4@<V5A<F-H:6YG(&YA;64N"B`@("`@("`@)&-R:71E<FEA
M(#T@87)R87DH*3L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1S96%R8V@I*2![
M"B`@("`@("`@("`@("1C<FET97)I85LG;F%M92==(#T@)'-E87)C:#L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D8W)I=&5R:6$@/2`D<V5A<F-H
M.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US<"T^
M:6US<%-E;F0H)U-%05)#2$%$1%)%4U,@)RP@=')U92P@9F%L<V4I.PH@("`@
M("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`O+R!$
M;R!W92!N965D('1O('-E;F0@=&AE(&%B;V]K(&YA;64@87,@>WT@/PH@("`@
M("`@(&EF("AP<F5G7VUA=&-H*$E-4U!?35535%]54T5?3$E415)!3"P@)&%B
M;V]K*2D@>PH@("`@("`@("`@("`D8FE";V]K(#T@<W!R:6YT9B@B>R5D?2(L
M('-T<FQE;B@D86)O;VLI*3L*"B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI
M<RT^7VEM<W`M/FEM<W!396YD*"1B:4)O;VLL(&9A;'-E+"!T<G5E*3L*("`@
M("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E
M:79E*"D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@B+UY<*R\B
M+"`D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M:6US<"T^:6US<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@97AP96-T960@8V]M
M;6%N9"!C;VYT:6YU871I;VX@<F5S<&]N<V4@9G)O;2!)35-0('-E<G9E<BXG
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(%]?1DE,15]?+%]?3$E.15]?*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@+R]3=&%R="!P87)S:6YG('1H92!S96%R8V@@87)R87DN
M"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H(B1A
M8F]O:R(L(&9A;'-E+"!F86QS92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@("`@("!]"@H@("`@("`@("1C;W5N="`](&-O=6YT*"1C<FET97)I
M82D["B`@("`@("`@)&-U<G)E;G0@/2`Q.PH@("`@("`@(&9O<F5A8V@@*"1C
M<FET97)I82!A<R`D<V5A<F-H7V9I96QD(#T^("1S96%R8V@I('L*("`@("`@
M("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H(B`D<V5A
M<F-H7V9I96QD("(L(&9A;'-E+"!F86QS92D["B`@("`@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O
M+R!(;W<@86)O=70@=&AE('-E87)C:"!T97)M(&%S(&$@>WTN"B`@("`@("`@
M("`@(&EF("AP<F5G7VUA=&-H*$E-4U!?35535%]54T5?3$E415)!3"P@)'-E
M87)C:"DI('L*("`@("`@("`@("`@("`@("1B:5-E87)C:"`]('-P<FEN=&8H
M(GLE9'TB+"!S=')L96XH)'-E87)C:"DI.PH*("`@("`@("`@("`@("`@("1R
M97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1B:5-E87)C:"P@9F%L
M<V4L('1R=64I.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)')E
M<W5L="`]("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*3L*("`@("`@("`@
M("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@B+UY<*R\B
M+"`D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7VEM<W`M/FEM<W!%<G)O<B@G1&ED(&YO="!R96-E:79E(&5X<&5C=&5D
M(&-O;6UA;F0@8V]N=&EN=6%T:6]N(')E<W!O;G-E(&9R;VT@24U34"!S97)V
M97(N)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P
M+3YI;7-P4V5N9"@D<V5A<F-H+"!F86QS92P@)&-U<G)E;G0@/3T@)&-O=6YT
M*3L*("`@("`@("`@("`@("`@("1C=7)R96YT*RL["B`@("`@("`@("`@("`@
M("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O+R!/;FQY
M('-E;F0@=&AE($-R3&8@:68@=&AI<R!I<R!T:&4@;&%S="!F:65L9"]S96%R
M8V@@871O;2X*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM
M<W`M/FEM<W!396YD*"<B)R`N("1S96%R8V@@+B`G(B<L(&9A;'-E+"`D8W5R
M<F5N="`]/2`D8V]U;G0I.PH@("`@("`@("`@("`@("`@)&-U<G)E;G0K*SL*
M("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@+R\@1V5T('1H92!R97-P;VYS92X*("`@("`@("`D<V5R=F5R7W)E<W!O
M;G-E(#T@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH@("`@("`@("1A
M8F]O:TYA;65S(#T@07)R87DH*3L*"B`@("`@("`@=VAI;&4@*'!R96=?;6%T
M8V@H(B]>7"H@4T5!4D-(041$4D534R\B+"`D<V5R=F5R7W)E<W!O;G-E*2D@
M>PH@("`@("`@("`@("`D8VAO<'!E9%]R97-P;VYS92`]"B`@("`@("`@("`@
M("`@("!P<F5G7W)E<&QA8V4H(B]>7"H@4T5!4D-(041$4D534R\B+"`G)RP@
M)'-E<G9E<E]R97-P;VYS92D["@H@("`@("`@("`@("`O+R!'970@<FED(&]F
M(&%N>2!L:6YG97)I;F<@<75O=&5S+@H@("`@("`@("`@("`D8VAO<'!E9%]R
M97-P;VYS92`]('!R96=?<F5P;&%C92@B+UPB+R(L("<G+"`D8VAO<'!E9%]R
M97-P;VYS92D["@H@("`@("`@("`@("`O+R!296UO=F4@86YY(&QI;F=E<FEN
M9R!W:&ET92!S<&%C92!I;B!F<F]N="!O;FQY+@H@("`@("`@("`@("`D=&5M
M<"`](&QT<FEM*"1C:&]P<&5D7W)E<W!O;G-E*3L*"B`@("`@("`@("`@(&EF
M("AP<F5G7VUA=&-H*"(O*'LI*%LP+3E=>S$L?2DH7'TD*2\B+"`D=&5M<"P@
M)'1E;7!!<G)A>2DI('L*("`@("`@("`@("`@("`@("1D871A4VEZ92`]("1T
M96UP07)R87E;,ET["B`@("`@("`@("`@("`@("`D=&5M<"`]("1T:&ES+3Y?
M:6US<"T^<F5C96EV95-T<FEN9TQI=&5R86PH)&1A=&%3:7IE*3L*"B`@("`@
M("`@("`@("`@("`O*B!'970@=&AE($-23$8@<VEN8V4@>WT@9&]E<R!N;W0@
M:6YC;'5D92!I="X@*B\*("`@("`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^
M<F5C96EV95-T<FEN9TQI=&5R86PH,BD["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("1A8F]O:TYA;65S6UT@/2`D=&5M<#L*"B`@("`@("`@("`@("\O
M($=E="!T:&4@;F5X="!R97-P;VYS92!L:6YE(&9R;VT@=&AE('-E<G9E<BX*
M("`@("`@("`@("`@)'-E<G9E<E]R97-P;VYS92`]("1T:&ES+3Y?:6US<"T^
M:6US<%)E8V5I=F4H*3L*("`@("`@("!]"@H@("`@("`@("\O(%-H;W5L9"!C
M:&5C:R!F;W(@3TL@;W(@0D%$(&AE<F4@:G5S="!T;R!B92!C97)T86EN+@H@
M("`@("`@('-W:71C:"`H)'-E<G9E<E]R97-P;VYS92D@>PH@("`@("`@(&-A
M<V4@)T)!1"<Z"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM
M<W!%<G)O<B@G5&AE($E-4U`@<V5R=F5R(&1I9"!N;W0@=6YD97)S=&%N9"!Y
M;W5R(')E<75E<W0N)R`N("`B.B`D8V]M;6%N9%]T97AT(BP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["@H@("`@("`@(&-A<V4@)TY/)SH*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=)35-0('-E<G9E<B!I<R!U
M;F%B;&4@=&\@<&5R9F]R;2!Y;W5R(')E<75E<W0N)R`N("(Z("(@+B`D=&AI
M<RT^7VEM<W`M/FQA<W1287=%<G)O<BP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@
M("`@("`@?0H*("`@("`@("`O*B!4:&ES(&%L;&]W<R!F;W(@;F\@<F5S=6QT
M<R`J+PH@("`@("`@(&EF("AC;W5N="@D86)O;VM.86UE<RD@/"`Q*2!["B`@
M("`@("`@("`@(')E='5R;B`D86)O;VM.86UE<SL*("`@("`@("!]"@H@("`@
M("`@("1T:&ES+3Y?:6US<"T^=W)I=&54;TQO9R@G4T5!4D-(041$4D534R!C
M;VUM86YD($]+)RP@7U]&24Q%7U\L(%]?3$E.15]?+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!014%27TQ/1U])3D9/*3L*"B`@("`@("`@
M+R\@1&5T97)M:6YE('1H92!S;W)T(&1I<F5C=&EO;B!A;F0@<&5R9F]R;2!T
M:&4@<V]R="X*("`@("`@("!S=VET8V@@*"1T:&ES+3YS;W)T*2!["B`@("`@
M("`@8V%S92`G87-C96YD)SH*("`@("`@("`@("`@<V]R="@D86)O;VM.86UE
M<RD["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=D97-C96YD
M)SH*("`@("`@("`@("`@<G-O<G0H)&%B;V]K3F%M97,I.PH@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D86)O;VM.86UE
M<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86X@87-S;V-I871I
M=F4@87)R87D@;V8@82!S:6YG;&4@861D<F5S<R!B;V]K(&5N=')Y+@H@("`@
M("H@3F]T92!T:&%T('1H97)E('=I;&P@86QW87ES(&)E(&$@)VYA;64G(&9I
M96QD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%B;V]K("`@("`@
M($YA;64@;V8@=&AE(&%D9')E<W,@8F]O:R!T;R!S96%R8V@N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1E;G1R>4YA;64@("=N86UE)R!A='1R:6)U=&4@;V8@
M=&AE(&5N=')Y('1O(')E=')I979E"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"!!<G)A>2!C;VYT86EN:6YG(&5N=')Y(&]R(%!%05)?17)R;W(@;VX@
M9F%I;'5R92`O(&YO(&UA=&-H+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971%
M;G1R>2@D86)O;VLL("1E;G1R>4YA;64I"B`@("!["B`@("`@("`@)')E<W5L
M="`]("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H)T9%5$-(041$4D534R`G+"!T
M<G5E+"!F86QS92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@
M("!]"@H@("`@("`@(&EF("AP<F5G7VUA=&-H*$E-4U!?35535%]54T5?3$E4
M15)!3"P@)&%B;V]K*2D@>PH@("`@("`@("`@("`D8FE";V]K(#T@<W!R:6YT
M9B@B>R5D?2(L('-T<FQE;B@D86)O;VLI*3L*"B`@("`@("`@("`@("1R97-U
M;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1B:4)O;VLL(&9A;'-E+"!T
M<G5E*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@B+UY<*R\B
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI
M;7-P4F5C96EV92@I*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?:6US<"T^:6US<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@97AP96-T960@
M8V]M;6%N9"!C;VYT:6YU871I;VX@<F5S<&]N<V4@9G)O;2!)35-0('-E<G9E
M<BXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!3
M96YD*"(D86)O;VL@(BP@9F%L<V4L(&9A;'-E*3L*("`@("`@("!I9B`H:7-?
M82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@:68@*'!R96=?;6%T8V@H
M24U34%]-55-47U5315],251%4D%,+"`D96YT<GE.86UE*2D@>PH@("`@("`@
M("`@("`D8FE.86UE(#T@<W!R:6YT9B@B>R5D?2(L('-T<FQE;B@D96YT<GE.
M86UE*2D["@H@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI
M;7-P4V5N9"@D8FE.86UE+"!F86QS92P@=')U92D["B`@("`@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!I9B`H(7!R96=?;6%T8V@H(B]>7"LO(BP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*2DI('L*("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G
M1&ED(&YO="!R96-E:79E(&5X<&5C=&5D(&-O;6UA;F0@8V]N=&EN=6%T:6]N
M(')E<W!O;G-E(&9R;VT@24U34"!S97)V97(N)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<F5S=6QT(#T@
M)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@D96YT<GE.86UE+"!F86QS92P@=')U
M92D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@
M("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)')E<W5L="`]
M("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H(EPB)&5N=')Y3F%M95PB(BP@9F%L
M<V4L('1R=64I.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)'-E<G9E<E]R97-P
M;VYS92`]("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*3L*"B`@("`@("`@
M<W=I=&-H("@D<V5R=F5R7W)E<W!O;G-E*2!["B`@("`@("`@8V%S92`G0D%$
M)SH*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R
M*"=4:&4@24U34"!S97)V97(@9&ED(&YO="!U;F1E<G-T86YD('EO=7(@<F5Q
M=65S="XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@(&-A<V4@)TY/
M)SH*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R
M*"=.;R!E;G1R>2!I;B!T:&ES(&%D9')E<W,@8F]O:R!M871C:&5S('EO=7(@
M<75E<GDN)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@
M("`@("\O($=E="!T:&4@9&%T82!I;B!A;B!A<W-O8VEA=&EV92!A<G)A>2X*
M("`@("`@("`D96YT<GD@/2`D=&AI<RT^7W!A<G-E1F5T8VA!9&1R97-S4F5S
M<&]N<V4H)'-E<G9E<E]R97-P;VYS92D["@H@("`@("`@("\O1V5T('1H92!N
M97AT('-E<G9E<B!R97-P;VYS92`M+2!T:&ES("IS:&]U;&0J(&)E('1H92!/
M2R!R97-P;VYS92X*("`@("`@("`D<V5R=F5R7W)E<W!O;G-E(#T@)'1H:7,M
M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH*("`@("`@("!I9B`H)'-E<G9E<E]R
M97-P;VYS92`A/2`G3TLG*2!["B`@("`@("`@("`@("\O(%5N97AP96-T960@
M<F5S<&]N<V4@=&AR;W<@97)R;W(@8G5T('-T:6QL(&-O;G1I;G5E(&]N+@H@
M("`@("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G1&ED(&YO="!R
M96-E:79E('1H92!E>'!E8W1E9"!R97-P;VYS92!F<F]M('1H92!S97)V97(N
M)RQ?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@)'1H
M:7,M/E]I;7-P+3YW<FET951O3&]G*"=&151#2$%$1%)%4U,@8V]M<&QE=&5D
M($]+)RP@7U]&24Q%7U\L(%]?3$E.15]?+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@4$5!4E],3T=?24Y&3RD["B`@("`@("`@<F5T=7)N
M("1E;G1R>3L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@82!N97<@
M861D<F5S<R!B;V]K+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%B
M;V]K3F%M92!&54Q,62!154%,249)140@;F%M92!S=6-H("=J9&]E+F-L:65N
M=',G(&5T8RXN+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@5')U92!O
M;B!S=6-C97-S("\@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!C<F5A=&5!9&1R97-S0F]O:R@D86)O;VM.86UE*0H@("`@
M>PH@("`@("`@("1C;VUM86YD7W1E>'0@/2`G0U)%051%041$4D534T)/3TL@
M)SL*"B`@("`@("`@:68@*'!R96=?;6%T8V@H24U34%]-55-47U5315],251%
M4D%,+"`D86)O;VM.86UE*2D@>PH@("`@("`@("`@("`D8FE";V]K(#T@<W!R
M:6YT9B@B>R5D?2(L('-T<FQE;B@D86)O;VM.86UE*2D["@H@("`@("`@("`@
M("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@D8V]M;6%N9%]T
M97AT("X@)&)I0F]O:RP@=')U92P@=')U92D["B`@("`@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I
M9B`H(7!R96=?;6%T8V@H(B]>7"LO(BP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*2DI('L*"B`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)T1I
M9"!N;W0@<F5C96EV92!E>'!E8W1E9"!C;VUM86YD(&-O;G1I;G5A=&EO;B!R
M97-P;VYS92!F<F]M($E-4U`@<V5R=F5R+B<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1R
M97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1A8F]O:TYA;64L(&9A
M;'-E+"!T<G5E*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)')E<W5L=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM
M<W`M/FEM<W!396YD*"1C;VUM86YD7W1E>'0@+B`D86)O;VM.86UE+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T<G5E
M+"!T<G5E*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1S97)V97)?<F5S<&]N
M<V4@/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D["B`@("`@("`@:68@
M*&ES7V$H)'-E<G9E<E]R97-P;VYS92P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'-E<G9E<E]R97-P;VYS93L*("`@("`@("!]"@H@
M("`@("`@('-W:71C:"`H)'-E<G9E<E]R97-P;VYS92D@>PH@("`@("`@(&-A
M<V4@)T]+)SH*("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YW<FET951O3&]G
M*"=#4D5!5$5!1$1215-30D]/2R!C;VUP;&5T960@3TLG+"!?7T9)3$5?7RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?3$E.15]?
M+"!014%27TQ/1U])3D9/*3L*("`@("`@("`@("`@<F5T=7)N('1R=64["@H@
M("`@("`@(&-A<V4@)TY/)SH*("`@("`@("`@("`@+R\@0V]U;&0@;F]T(&-R
M96%T92!A8F]O:RX*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^
M:6US<$5R<F]R*"=)35-0('-E<G9E<B!I<R!U;F%B;&4@=&\@<&5R9F]R;2!Y
M;W5R(')E<75E<W0N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@("`@
M8V%S92`G0D%$)SH*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^
M:6US<$5R<F]R*"=4:&4@24U34"!S97)V97(@9&ED(&YO="!U;F1E<G-T86YD
M('EO=7(@<F5Q=65S="XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@("`@
M("!D969A=6QT.@H@("`@("`@("`@("`O+R!3;VUE=&AI;F<@=6YE>'!E8W1E
M9"X*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R
M*"=$:60@;F]T(')E8V5I=F4@=&AE(&5X<&5C=&5D(')E<W!O;G-E(&9R;VT@
M=&AE('-E<G9E<BXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&%N(&%D9')E<W,@8F]O:R!C
M;VUP;&5T96QY(0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%B;V]K
M3F%M92!.86UE(&]F(&%D9')E<W,@8F]O:R!T;R!D96QE=&4N"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"!T<G5E(&]N('-U8V-E<W,@+R!014%27T5R
M<F]R(&]N(&9A:6QU<F4*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E061D
M<F5S<T)O;VLH)&%B;V]K3F%M92D*("`@('L*("`@("`@("`D8V]M;6%N9%]T
M97AT(#T@)T1%3$5414%$1%)%4U-"3T]+("<["@H@("`@("`@("\O($-H96-K
M(&YE960@9F]R('M]+@H@("`@("`@(&EF("AP<F5G7VUA=&-H*$E-4U!?3553
M5%]54T5?3$E415)!3"P@)&%B;V]K3F%M92DI('L*("`@("`@("`@("`@)&)I
M0F]O:R`]('-P<FEN=&8H(GLE9'TB+"!S=')L96XH)&%B;V]K3F%M92DI.PH*
M("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H
M)&-O;6UA;F1?=&5X="`N("1B:4)O;VLL('1R=64L('1R=64I.PH@("`@("`@
M("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"(O7EPK+R(L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"DI
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P
M17)R;W(H)T1I9"!N;W0@<F5C96EV92!E>'!E8W1E9"!C;VUM86YD(&-O;G1I
M;G5A=&EO;B!R97-P;VYS92!F<F]M($E-4U`@<V5R=F5R+B<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1A8F]O
M:TYA;64L(&9A;'-E+"!T<G5E*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5S=6QT(#T@
M)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@D8V]M;6%N9%]T97AT("X@)&%B;V]K
M3F%M92P@=')U92P@=')U92D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<V5R
M=F5R7W)E<W!O;G-E(#T@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH@
M("`@("`@(&EF("AI<U]A*"1S97)V97)?<F5S<&]N<V4L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1S97)V97)?<F5S<&]N<V4["B`@
M("`@("`@?0H*("`@("`@("!S=VET8V@@*"1S97)V97)?<F5S<&]N<V4I('L*
M("`@("`@("!C87-E("=/2R<Z"B`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^
M=W)I=&54;TQO9R@G1$5,151%041$4D534T)/3TL@8V]M<&QE=&5D($]+)RP@
M7U]&24Q%7U\L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!?7TQ)3D5?7RP@4$5!4E],3T=?24Y&3RD["B`@("`@("`@("`@(')E='5R
M;B!T<G5E.PH*("`@("`@("!C87-E("=.3R<Z"B`@("`@("`@("`@("\O($-O
M=6QD(&YO="!$14Q%5$4@86)O;VLN"B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7VEM<W`M/FEM<W!%<G)O<B@G24U34"!S97)V97(@:7,@=6YA8FQE('1O
M('!E<F9O<FT@>6]U<B!R97%U97-T+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"@H@("`@("`@(&-A<V4@)T)!1"<Z"B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7VEM<W`M/FEM<W!%<G)O<B@G5&AE($E-4U`@<V5R=F5R(&1I9"!N;W0@
M=6YD97)S=&%N9"!Y;W5R(')E<75E<W0N)RP@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@+R\@4V]M971H:6YG
M('5N97AP96-T960N"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M
M/FEM<W!%<G)O<B@G1&ED(&YO="!R96-E:79E('1H92!E>'!E8W1E9"!R97-P
M;VYS92!F<F]M('1H92!S97)V97(N)RP@7U]&24Q%7U\L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7TQ)3D5?7RD["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5N86UE<R!A;B!A9&1R
M97-S(&)O;VLN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D86)O;VM/
M;&1.86UE($]L9"!N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D86)O;VM.
M97=.86UE($YE=R!A9&1R97-S(&)O;VL@;F%M92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D(%1R=64@+R!014%27T5R<F]R"B`@("`@*B\*("`@(&9U
M;F-T:6]N(')E;F%M94%D9')E<W-";V]K*"1A8F]O:T]L9$YA;64L("1A8F]O
M:TYE=TYA;64I"B`@("!["B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US
M<"T^:6US<%-E;F0H)U)%3D%-14%$1%)%4U-"3T]+("<L('1R=64L(&9A;'-E
M*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@
M("`@:68@*'!R96=?;6%T8V@H24U34%]-55-47U5315],251%4D%,+"`D86)O
M;VM/;&1.86UE*2D@>PH@("`@("`@("`@("`D8FE/;&1.86UE(#T@<W!R:6YT
M9B@B>R5D?2(L('-T<FQE;B@D86)O;VM/;&1.86UE*2D["@H@("`@("`@("`@
M("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@D8FE/;&1.86UE
M+"!F86QS92P@=')U92D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^7VEM<W`M
M/FEM<W!296-E:79E*"D["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@
M)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@B)&%B;V]K3VQD3F%M92`B+"!F86QS
M92P@9F%L<V4I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M?0H*("`@("`@("!I9B`H<')E9U]M871C:"A)35-07TU54U1?55-%7TQ)5$52
M04PL("1A8F]O:TYE=TYA;64I*2!["B`@("`@("`@("`@("1B:4YE=TYA;64@
M/2!S<')I;G1F*")[)61](BP@<W1R;&5N*"1A8F]O:TYE=TYA;64I*3L*"B`@
M("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1B
M:4YE=TYA;64L(&9A;'-E+"!T<G5E*3L*("`@("`@("`@("`@:68@*&ES7V$H
M)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M
M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH@("`@("`@('T*"B`@("`@("`@+R\@
M0U),1B!S:6YC92!L87-T('!A<G0N"B`@("`@("`@)')E<W5L="`]("1T:&ES
M+3Y?:6US<"T^:6US<%-E;F0H)&%B;V]K3F5W3F%M92P@9F%L<V4L('1R=64I
M.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@
M("`O+R!'970@<V5R=F5R(')E<W!O;G-E+@H@("`@("`@("1S97)V97)?<F5S
M<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D["@H@("`@("`@
M('-W:71C:"`H)'-E<G9E<E]R97-P;VYS92D@>PH@("`@("`@(&-A<V4@)TY/
M)SH*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R
M*"=)35-0('-E<G9E<B!I<R!U;F%B;&4@=&\@<&5R9F]R;2!Y;W5R(')E<75E
M<W0N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@("`@8V%S92`G0D%$
M)SH*("`@("`@("`@("`@+R\@4WEN=&%X('!R;V)L96TN"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G5&AE($E-4U`@<V5R
M=F5R(&1I9"!N;W0@=6YD97)S=&%N9"!Y;W5R(')E<75E<W0N)RD["@H@("`@
M("`@(&-A<V4@)T]+)SH*("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YW<FET
M951O3&]G*")!9&1R97-S(&)O;VL@)&%B;V]K3VQD3F%M92!S=6-C97-S9G5L
M;'D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C:&%N
M9V5D('1O("1A8F]O:TYE=TYA;64B+"!?7T9)3$5?7RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!?7TQ)3D5?7RP@4$5!4E],3T=?
M24Y&3RD["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH*("`@("`@("!D969A
M=6QT.@H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R
M;W(H)T1I9"!N;W0@<F5C96EV92!T:&4@97AP96-T960@<F5S<&]N<V4@9G)O
M;2!T:&4@<V5R=F5R+B<L(%]?1DE,15]?+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@7U],24Y%7U\I.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($%D9',@86X@861D<F5S<R!B;V]K(&5N
M=')Y('1O(&%N(&%D9')E<W,@8F]O:RX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1A8F]O:R`@("`@3F%M92!O9B!A9&1R97-S(&)O;VL@=&\@861D
M(&5N=')Y('1O+@H@("`@("H@0'!A<F%M(&%R<F%Y("1E;G1R>4EN9F\@($%D
M9')E<W,@8F]O:R!E;G1R>2!I;F9O<FUA=&EO;B`M"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@=&AE<F4@35535"!B92!A(&9I96QD("=N86UE
M)R!C;VYT86EN:6YG('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@(&5N=')Y(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!4
M<G5E(&]N('-U8V-E<W,@+R!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&%D9$5N=')Y*"1A8F]O:RP@)&5N=')Y26YF;RD*
M("`@('L*("`@("`@("`D8V]M;6%N9%]T97AT(#T@)R<["@H@("`@("`@(&EF
M("AG9714>7!E*"1E;G1R>4EN9F\I("$]("=A<G)A>2<I('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*$E-4U!?0D%$7T%2
M1U5-14Y4+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@
M("`@+R\@3&]C:R!T:&4@96YT<GD@:68@:70@86QR96%D>2!E>&ES=',N"B`@
M("`@("`@)')E<W5L="`]("1T:&ES+3YL;V-K16YT<GDH)&%B;V]K+"`D96YT
M<GE);F9O6R=N86UE)UTI.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI;7-P
M4V5N9"@G4U1/4D5!1$1215-3("<L('1R=64L(&9A;'-E*3L*("`@("`@("!I
M9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@+R\@5&%K92!C
M87)E(&]F('1H92!N86UE+@H@("`@("`@("1E;G1R>4YA;64@/2`D96YT<GE)
M;F9O6R=N86UE)UT["@H@("`@("`@("\O('M](&9O<B!B;V]K(&YA;64_"B`@
M("`@("`@:68@*'!R96=?;6%T8V@H24U34%]-55-47U5315],251%4D%,+"`D
M86)O;VLI*2!["B`@("`@("`@("`@("1B:4)O;VL@/2!S<')I;G1F*")[)61]
M(BP@<W1R;&5N*"1A8F]O:RDI.PH*("`@("`@("`@("`@)')E<W5L="`]("1T
M:&ES+3Y?:6US<"T^:6US<%-E;F0H)&)I0F]O:RP@9F%L<V4L('1R=64I.PH@
M("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH@
M("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@B)&%B
M;V]K("(L(&9A;'-E+"!F86QS92D["@H@("`@("`@("\O($1O('=E(&YE960@
M>WT@9F]R(&5N=')Y(&YA;64@87,@=V5L;#\*("`@("`@("!I9B`H<')E9U]M
M871C:"A)35-07TU54U1?55-%7TQ)5$5204PL("1E;G1R>4YA;64I*2!["B`@
M("`@("`@("`@("1B:6YA;64@/2!S<')I;G1F*")[)61](BP@<W1R;&5N*"1E
M;G1R>4YA;64I*3L*("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4V5N
M9"@D8FEN86UE+"!F86QS92P@=')U92D["B`@("`@("`@("`@("1T:&ES+3Y?
M:6US<"T^:6US<%)E8V5I=F4H*3L*("`@("`@("`@("`@)'1H:7,M/E]I;7-P
M+3YI;7-P4V5N9"@D96YT<GE.86UE+"!F86QS92P@9F%L<V4I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H
M(EPB)&5N=')Y3F%M95PB("(L(&9A;'-E+"!F86QS92D["B`@("`@("`@?0H*
M("`@("`@("!W:&EL92`H;&ES="@D:V5Y+"`D=F%L=64I(#T@96%C:"@D96YT
M<GE);F9O*2D@>PH@("`@("`@("`@("`O+R!$;R!N;W0@<V5N="!T:&4@:V5Y
M(&YA;64@)VYA;64G+@H@("`@("`@("`@("!I9B`H)&ME>2`A/2`G;F%M92<I
M('L*("`@("`@("`@("`@("`@("\O(%!R;W1E8W0@9G)O;2!E>'1R86YE;W5S
M('=H:71E('-P86-E"B`@("`@("`@("`@("`@("`D=F%L=64@/2!T<FEM*"1V
M86QU92D["@H@("`@("`@("`@("`@("`@+R\@1F]R('-O;64@<F5A<V]N+"!T
M86)S('-E96T@=&\@8G)E86L@=&AI<RX*("`@("`@("`@("`@("`@("1V86QU
M92`]('!R96=?<F5P;&%C92@B+UQT+R(L(")<;EQR(BP@)'9A;'5E*3L*"B`@
M("`@("`@("`@("`@("`O+R!#:&5C:R!T;R!S964@:68@=V4@;F5E9"![?0H@
M("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H24U34%]-55-47U5315],
M251%4D%,+"`D=F%L=64I*2!["B`@("`@("`@("`@("`@("`@("`@)&-O;6UA
M;F1?=&5X="`N/2`D:V5Y("X@<W!R:6YT9B@B('LE9'TB+"!S=')L96XH)'9A
M;'5E*2D["@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US
M<%-E;F0H)&-O;6UA;F1?=&5X="P@9F%L<V4L('1R=64I.PH@("`@("`@("`@
M("`@("`@("`@("1S97)V97)?<F5S<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM
M<W!296-E:79E*"D["B`@("`@("`@("`@("`@("`@("`@)&-O;6UA;F1?=&5X
M="`]("<G.R`O+T-L96%R('1H92!C;VUM86YD7W1E>'0@8G5F9F5R"@H@("`@
M("`@("`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@B+UY<*R\B+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<V5R=F5R7W)E<W!O
M;G-E*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]I;7-P+3YI;7-P17)R;W(H)T1I9"!N;W0@<F5C96EV92!T:&4@97AP96-T
M960@<F5S<&]N<V4@9G)O;2!T:&4@<V5R=F5R+B<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)
M3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("`@("`@("`@+R\@4V5N9"!T:&4@<W1R:6YG(&]F(&]C=&5T<R!A
M;F0@8F4@<W5R92!.3U0@=&\*("`@("`@("`@("`@("`@("`@("`O+R!E;F0@
M=VET:"!#4DQ&+@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^
M:6US<%-E;F0H)'9A;'5E+"!F86QS92P@9F%L<V4I.PH*("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@+R\@268@=V4@87)E
M(&AE<F4L('1H96X@=V4@9&\@;F]T(&YE960@=&\@<V5N9"!A"B`@("`@("`@
M("`@("`@("`@("`@+R\@>WTN"B`@("`@("`@("`@("`@("`@("`@)'9A;'5E
M(#T@(EPB(B`N("1V86QU92`N(")<(B(["B`@("`@("`@("`@("`@("`@("`@
M)&-O;6UA;F1?=&5X="`N/2`D:V5Y("X@)R`G("X@)'9A;'5E("X@)R`G.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("`O+R!396YD(&%N>71H:6YG('1H870@:7,@;&5F="!O9B!T:&4@8V]M
M;6%N9"X*("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1C;VUM86YD
M7W1E>'0L(&9A;'-E+"!T<G5E*3L*("`@("`@("`D<V5R=F5R7W)E<W!O;G-E
M(#T@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH*("`@("`@("!S=VET
M8V@@*"1S97)V97)?<F5S<&]N<V4I('L*("`@("`@("!C87-E("=.3R<Z"B`@
M("`@("`@("`@("\O4V]R<GDN+BYC86YN;W0@9&\@:70N"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G24U34"!S97)V97(@
M:7,@=6YA8FQE('1O('!E<F9O<FT@>6]U<B!R97%U97-T+B<L(%]?1DE,15]?
M+"!?7TQ)3D5?7RD["@H@("`@("`@(&-A<V4@)T)!1"<Z"B`@("`@("`@("`@
M("\O4V]R<GDN+BYD:60@;F]T('5N9&5R<W1A;F0@>6]U"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G5&AE($E-4U`@<V5R
M=F5R(&1I9"!N;W0@=6YD97)S=&%N9"!Y;W5R(')E<75E<W0N)RP@7U]&24Q%
M7U\L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("!I9B`H)'-E<G9E<E]R
M97-P;VYS92`A/2`G3TLG*2!["B`@("`@("`@("`@("\O($-Y<G5S+4E-4U`@
M<V5R=F5R('-E;F1S(&$@1D540TA!1$1215-3(%)E<W!O;G-E(&AE<F4N"B`@
M("`@("`@("`@("\O($1O(&]T:&5R<S\@("`@(%1H:7,@=V%S(&YO="!I;B!T
M:&4@4D9#+@H@("`@("`@("`@("`D9'5M;7E?87)R87D@/0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)S949E=&-H061D<F5S<U)E<W!O;G-E*"1S97)V
M97)?<F5S<&]N<V4I.PH*("`@("`@("`@("`@)'-E<G9E<E]R97-P;VYS92`]
M("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*3L*"B`@("`@("`@("`@('-W
M:71C:"`H)'-E<G9E<E]R97-P;VYS92D@>PH@("`@("`@("`@("!C87-E("=.
M3R<Z"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P
M17)R;W(H)TE-4U`@<V5R=F5R(&ES('5N86)L92!T;R!P97)F;W)M('EO=7(@
M<F5Q=65S="XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!C
M87-E("="040G.@H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US
M<"T^:6US<$5R<F]R*"=4:&4@24U34"!S97)V97(@9&ED(&YO="!U;F1E<G-T
M86YD('EO=7(@<F5Q=65S="XG+"!?7T9)3$5?7RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7TQ)3D5?7RD["B`@
M("`@("`@("`@(&-A<V4@)T]+)SH*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M:6US<"T^=W)I=&54;TQO9R@G4U1/4D5!1$1215-3($-O;7!L971E9"!S=6-C
M97-S9G5L;'DN)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7TE.1D\I.PH*
M("`@("`@("`@("`@("`@("\O=V4@=V5R92!S=6-C97-S9G5L+BXN<V\@<F5L
M96%S92!T:&4@;&]C:R!O;B!T:&4@96YT<GD*("`@("`@("`@("`@("`@(&EF
M("@A)'1H:7,M/G5N;&]C:T5N=')Y*"1A8F]O:RP@)&5N=')Y26YF;ULG;F%M
M92==*2D@>PH@("`@("`@("`@("`@("`@("`@("\O8V]U;&0@;F]T(')E;&5A
M<V4@;&]C:PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM
M<W`M/FEM<W!%<G)O<B@G5&AA="!A9&1R97-S(&)O;VL@96YT<GD@:7,@;&]C
M:V5D(&]R(')E860@;VYL>2!F;W(@=&AE(&-U<G)E;G0@=7-E<BXG+"!?7T9)
M3$5?7RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@7U],24Y%7U\I.PH@("`@("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E<R!A;B!A8F]O:R!E
M;G1R>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A8F]O:R`@("`@
M3F%M92!O9B!A9&1R97-S(&)O;VL@8V]N=&%I;FEN9R!E;G1R>2X*("`@("`J
M($!P87)A;2!S=')I;F<@)&)O;VM%;G1R>2!.86UE(&]F(&5N=')Y('1O(&1E
M;&5T92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%1R=64@;VX@<W5C
M8V5S<R`O(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9&5L971E16YT<GDH)&%B;V]K+"`D8F]O:T5N=')Y*0H@("`@>PH@
M("`@("`@("\O(%-T87)T('1H92!C;VUM86YD+@H@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"=$14Q%5$5!1$1215-3("<L('1R
M=64L(&9A;'-E*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@
M('T*"B`@("`@("`@+R\@3F5E9"![?2!F;W(@8F]O:R!N86UE/PH@("`@("`@
M(&EF("AP<F5G7VUA=&-H*$E-4U!?35535%]54T5?3$E415)!3"P@)&%B;V]K
M*2D@>PH@("`@("`@("`@("`D8FE";V]K(#T@<W!R:6YT9B@B>R5D?2(L('-T
M<FQE;B@D86)O;VLI*3L*"B`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US
M<%-E;F0H)&)I0F]O:RP@9F%L<V4L('1R=64I.PH*("`@("`@("`@("`@:68@
M*"%P<F5G7VUA=&-H*"(O7EPK+R(L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"DI*2!["@H@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=$:60@
M;F]T(')E8V5I=F4@97AP96-T960@8V]M;6%N9"!C;VYT:6YU871I;VX@<F5S
M<&]N<V4@9G)O;2!)35-0('-E<G9E<BXG+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["B`@("`@("`@("`@('T*"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^
M7VEM<W`M/FEM<W!396YD*"(D86)O;VL@(BP@9F%L<V4L(&9A;'-E*3L*"B`@
M("`@("`@+R](;W<@8F]U="!F;W(@=&AE(&5N=')Y(&YA;64_"B`@("`@("`@
M:68@*'!R96=?;6%T8V@H24U34%]-55-47U5315],251%4D%,+"`D8F]O:T5N
M=')Y*2D@>PH@("`@("`@("`@("`D8FE%;G1R>2`]('-P<FEN=&8H(GLE9'TB
M+"!S=')L96XH)&)O;VM%;G1R>2DI.PH*("`@("`@("`@("`@)'1H:7,M/E]I
M;7-P+3YI;7-P4V5N9"@D8FE%;G1R>2P@9F%L<V4L('1R=64I.PH*("`@("`@
M("`@("`@:68@*"%P<F5G7VUA=&-H*"(O7EPK+R(L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"DI*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R
M;W(H)T1I9"!N;W0@<F5C96EV92!E>'!E8W1E9"!C;VUM86YD(&-O;G1I;G5A
M=&EO;B!R97-P;VYS92!F<F]M($E-4U`@<V5R=F5R+B<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L
M(%]?3$E.15]?*3L*("`@("`@("`@("`@?0H*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D8F]O:T5N=')Y(#T@)'1H:7,M/E]I;7-P+3YQ=6]T95-P
M86-E9%-T<FEN9R@D8F]O:T5N=')Y*3L*("`@("`@("!]"@H@("`@("`@("1T
M:&ES+3Y?:6US<"T^:6US<%-E;F0H)&)O;VM%;G1R>2P@9F%L<V4L('1R=64I
M.PH@("`@("`@("1S97)V97)?<F5S<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM
M<W!296-E:79E*"D["@H@("`@("`@('-W:71C:"`H)'-E<G9E<E]R97-P;VYS
M92D@>PH@("`@("`@(&-A<V4@)TY/)SH*("`@("`@("`@("`@+R]3;W)R>2XN
M8V%N;F]T(&1O(&ET"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M
M/FEM<W!%<G)O<B@G24U34"!S97)V97(@:7,@=6YA8FQE('1O('!E<F9O<FT@
M>6]U<B!R97%U97-T+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@
M8V%S92`G0D%$)SH*("`@("`@("`@("`@+R]$;R!N;W0@:VYO=R!W:&%T('EO
M=7(@=&%L:VEN9R!A8F]U=`H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I
M;7-P+3YI;7-P17)R;W(H)U1H92!)35-0('-E<G9E<B!D:60@;F]T('5N9&5R
M<W1A;F0@>6]U<B!R97%U97-T+B<L(%]?1DE,15]?+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U],24Y%7U\I.PH@("`@
M("`@(&-A<V4@)T]+)SH*("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YW<FET
M951O3&]G*"=$14Q%5$4@0V]M<&QE=&5D('-U8V-E<W-F=6QL>2XG+"!?7T9)
M3$5?7RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?
M3$E.15]?+"!014%27TQ/1U])3D9/*3L*("`@("`@("`@("`@<F5T=7)N('1R
M=64["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@
M=&\@86-Q=6ER92!A('-E;6%P:&]R92!O;B!T:&4@861D<F5S<R!B;V]K(&5N
M=')Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%B;V]K("`@("!!
M9&1R97-S(&)O;VL@;F%M90H@("`@("H@0'!A<F%M('-T<FEN9R`D8F]O:T5N
M=')Y($YA;64@;V8@96YT<GD@=&\@;&]C:PH@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@=')U92!O<B!A<G)A>2!O;B!S=6-C97-S(&%N9"!014%27T5R
M<F]R(&]N(&9A:6QU<F4*("`@("`J("`@("`@("`@("`@("`@*'-E<G9E<B!D
M97!E;F1I;F<I"B`@("`@*B\*("`@(&9U;F-T:6]N(&QO8VM%;G1R>2@D86)O
M;VLL("1B;V]K16YT<GDI"B`@("!["B`@("`@("`@)')E<W5L="`]("1T:&ES
M+3Y?:6US<"T^:6US<%-E;F0H)TQ/0TL@041$4D534T)/3TL@)RP@=')U92P@
M9F%L<V4I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*
M("`@("`@("`O+R!$;R!W92!N965D(&$@<W1R:6YG(&QI=&5R86P_"B`@("`@
M("`@:68@*'!R96=?;6%T8V@H24U34%]-55-47U5315],251%4D%,+"`D86)O
M;VLI*2!["B`@("`@("`@("`@("1B:4)O;VL@/2!S<')I;G1F*")[)61](BP@
M<W1R;&5N*"1A8F]O:RDI.PH*("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI
M;7-P4V5N9"@D8FE";V]K+"!F86QS92P@=')U92D["@H@("`@("`@("`@("!I
M9B`H(7!R96=?;6%T8V@H(B]>7"LO(BP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*2DI('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G1&ED
M(&YO="!R96-E:79E(&5X<&5C=&5D(&-O;6UA;F0@8V]N=&EN=6%T:6]N(')E
M<W!O;G-E(&9R;VT@24U34"!S97)V97(N)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^
M7VEM<W`M/FEM<W!396YD*"(D86)O;VL@(BP@9F%L<V4L(&9A;'-E*3L*"B`@
M("`@("`@+R\@5VAA="!A8F]U="!T:&4@96YT<GD@;F%M93\*("`@("`@("!I
M9B`H<')E9U]M871C:"A)35-07TU54U1?55-%7TQ)5$5204PL("1B;V]K16YT
M<GDI*2!["B`@("`@("`@("`@("1B:45N=')Y(#T@<W!R:6YT9B@B>R5D?2(L
M('-T<FQE;B@D8F]O:T5N=')Y*2D["@H@("`@("`@("`@("`D=&AI<RT^7VEM
M<W`M/FEM<W!396YD*"1B:45N=')Y+"!F86QS92P@=')U92D["@H@("`@("`@
M("`@("!I9B`H(7!R96=?;6%T8V@H(B]>7"LO(BP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*2DI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O
M<B@G1&ED(&YO="!R96-E:79E(&5X<&5C=&5D(&-O;6UA;F0@8V]N=&EN=6%T
M:6]N(')E<W!O;G-E(&9R;VT@24U34"!S97)V97(N)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@
M7U],24Y%7U\I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^
M7VEM<W`M/FEM<W!396YD*"1B;V]K16YT<GDL(&9A;'-E+"!T<G5E*3L*"B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&)O;VM%;G1R>2`]("1T:&ES
M+3Y?:6US<"T^<75O=&53<&%C9613=')I;F<H)&)O;VM%;G1R>2D["B`@("`@
M("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H(B1B;V]K16YT<GDB+"!F
M86QS92P@=')U92D["B`@("`@("`@?0H*("`@("`@("`D<V5R=F5R7W)E<W!O
M;G-E(#T@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH*("`@("`@("!D
M;R!["@H@("`@("`@("`@("!S=VET8V@@*"1S97)V97)?<F5S<&]N<V4I('L*
M"B`@("`@("`@("`@(&-A<V4@)TY/)SH*("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G5&AA="!A9&1R97-S(&)O;VL@
M96YT<GD@:7,@;&]C:V5D(&]R(')E860@;VYL>2!F;W(@=&AE(&-U<G)E;G0@
M=7-E<BXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@(&-A
M<V4@)T)!1"<Z"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P
M+3YI;7-P17)R;W(H)U1H92!)35-0('-E<G9E<B!D:60@;F]T('5N9&5R<W1A
M;F0@>6]U<B!R97%U97-T+B<L(%]?1DE,15]?+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?3$E.15]?*3L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@+R]#:&5C:R!T;R!S964@:68@=&AI
M<R!I<R!A($9%5$-(041$4D534R!R97-O;G-E"B`@("`@("`@("`@("1D=6UM
M>2`]("1T:&ES+3Y?<&%R<V5&971C:$%D9')E<W-297-P;VYS92@D<V5R=F5R
M7W)E<W!O;G-E*3L*"B`@("`@("`@("`@(&EF("@D9'5M;7DI('L*("`@("`@
M("`@("`@("`@("1S97)V97)?<F5S<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM
M<W!296-E:79E*"D["B`@("`@("`@("`@('T*"B`@("`@("`@?2!W:&EL92`H
M)'-E<G9E<E]R97-P;VYS92`A/2`G3TLG*3L*"B`@("`@("`@)'1H:7,M/E]I
M;7-P+3YW<FET951O3&]G*"),3T-+($%$1%)%4U-"3T]+(&]N("1A8F]O:R`D
M8F]O:T5N=')Y($]+(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U])3D9/*3L*"B`@("`@
M("`@+R\@4F5T=7)N(&5I=&AE<B!T<G5E(&]R('1H92!&151#2$%$1%)%4U,@
M<F5S<&]N<V4@:68@:70@97AI<W1S+@H@("`@("`@(&EF("@A)&1U;6UY*2![
M"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E='5R;B`D9'5M;7D["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@56YL;V-K<R!A('!R979I;W5S;'D@;&]C:V5D(&%D9')E
M<W,@8F]O:RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A8F]O:R`@
M("`@3F%M92!O9B!A9&1R97-S(&)O;VL@8V]N=&%I;FEN9R!L;V-K960@96YT
M<GDN"B`@("`@*B!`<&%R86T@<W1R:6YG("1B;V]K16YT<GD@3F%M92!O9B!E
M;G1R>2!T;R!U;FQO8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!4
M<G5E(&]N('-U8V-E<W,L(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@=6YL;V-K16YT<GDH)&%B;V]K+"`D8F]O:T5N=')Y
M*0H@("`@>PH@("`@("`@("\O(%-T87)T('-E;F1I;F<@8V]M;6%N9"X*("`@
M("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@G54Y,3T-+
M($%$1%)%4U-"3T]+("<L('1R=64L(&9A;'-E*3L*("`@("`@("!I9B`H:7-?
M82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@+R\@>WT@9F]R(&)O;VL@
M;F%M93\*("`@("`@("!I9B`H<')E9U]M871C:"A)35-07TU54U1?55-%7TQ)
M5$5204PL("1A8F]O:RDI('L*("`@("`@("`@("`@)&)I0F]O:R`]('-P<FEN
M=&8H(GLE9'TB+"!S=')L96XH)&%B;V]K*2D["@H@("`@("`@("`@("`D=&AI
M<RT^7VEM<W`M/FEM<W!396YD*"1B:4)O;VLL(&9A;'-E+"!T<G5E*3L*"B`@
M("`@("`@("`@(&EF("@A<')E9U]M871C:"@B+UY<*R\B+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US
M<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@97AP96-T960@8V]M;6%N9"!C;VYT
M:6YU871I;VX@<F5S<&]N<V4@9G)O;2!)35-0('-E<G9E<BXG+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,
M15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@('T*"B`@("`@("`@?0H*("`@
M("`@("`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"(D86)O;VL@(BP@9F%L<V4L
M(&9A;'-E*3L*"B`@("`@("`@+R](;W<@8F]U="!F;W(@96YT<GD@;F%M93\*
M("`@("`@("!I9B`H<')E9U]M871C:"A)35-07TU54U1?55-%7TQ)5$5204PL
M("1B;V]K16YT<GDI*2!["B`@("`@("`@("`@("1B:45N=')Y/7-P<FEN=&8H
M(GLE9'TB+"!S=')L96XH)&)O;VM%;G1R>2DI.PH@("`@("`@("`@("`D=&AI
M<RT^7VEM<W`M/FEM<W!396YD*"1B:45N=')Y+"!F86QS92P@=')U92D["@H@
M("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H(B]>7"LO(BP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H
M*2DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM
M<W!%<G)O<B@G1&ED(&YO="!R96-E:79E(&5X<&5C=&5D(&-O;6UA;F0@8V]N
M=&EN=6%T:6]N(')E<W!O;G-E(&9R;VT@24U34"!S97)V97(N)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)
M3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M=&AI<RT^7VEM<W`M/FEM<W!396YD*"1B;V]K16YT<GDL(&9A;'-E+"!T<G5E
M*3L*"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&)O;VM%;G1R>2`]
M("1T:&ES+3Y?:6US<"T^<75O=&53<&%C9613=')I;F<H)&)O;VM%;G1R>2D[
M"B`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H(B1B;V]K16YT
M<GDB+"!F86QS92P@=')U92D["B`@("`@("`@?0H*("`@("`@("`D<F5S<&]N
M<V4@/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D["@H@("`@("`@('-W
M:71C:"`H)')E<W!O;G-E*2!["B`@("`@("`@8V%S92`G3D\G.@H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)TE-4U`@<V5R
M=F5R(&ES('5N86)L92!T;R!P97)F;W)M('EO=7(@<F5Q=65S="XG+"!?7T9)
M3$5?7RP@7U],24Y%7U\I.PH*("`@("`@("!C87-E("="040G.@H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)U1H92!)35-0
M('-E<G9E<B!D:60@;F]T('5N9&5R<W1A;F0@>6]U<B!R97%U97-T+B<L(%]?
M1DE,15]?+"!?7TQ)3D5?7RD["@H@("`@("`@(&-A<V4@)T]+)SH*("`@("`@
M("`@("`@)'1H:7,M/E]I;7-P+3YW<FET951O3&]G*")53DQ/0TL@041$4D53
M4T)/3TL@;VX@)&%B;V]K("1B;V]K16YT<GD@3TLB+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!0
M14%27TQ/1U])3D9/*3L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@06-C97-S($-O;G1R;VP@3&ES
M="`H04-,*2`@365T:&]D<RX*("`@("`J"B`@("`@*B!4:&4@9F]L;&]W:6YG
M(&-H87)A8W1E<G,@87)E(')E8V]G;FEZ960@04-,(&-H87)A8W1E<G,Z(&QR
M=V-D80H@("`@("H@;"`M(")L;V]K=7`B("`H<V5E('1H92!N86UE(&%N9"!E
M>&ES=&5N8V4@;V8@=&AE(&%D9')E<W,@8F]O:RD*("`@("`J('(@+2`B<F5A
M9"(@("`@*'-E87)C:"!A;F0@<F5T<FEE=F4@861D<F5S<V5S(&9R;VT@861D
M<F5S<R!B;V]K*0H@("`@("H@=R`M(")W<FET92(@("`H8W)E871E+V5D:70@
M;F5W(&%D9')E<W,@8F]O:R!E;G1R:65S("T@;F]T(&1E;&5T92D*("`@("`J
M(&,@+2`B8W)E871E(B`@*&-R96%T92!N97<@861D<F5S<R!B;V]K<R!U;F1E
M<B!T:&4@8W5R<F5N="!A9&1R97-S(&)O;VLI"B`@("`@*B!D("T@(F1E;&5T
M92(@("AD96QE=&4@96YT<FEE<R!O<B!E;G1I<F4@8F]O:RD*("`@("`J(&$@
M+2`B861M:6XB("`@*'-E="!!0TP@;&ES=',@9F]R('1H:7,@861D<F5S<R!B
M;V]K("T@=7-U86QL>2!O;FQY"B`@("`@*B`@("`@("`@("`@("`@(&%L;&]W
M960@9F]R('1H92!O=VYE<B!O9B!T:&4@861D<F5S<R!B;V]K*0H@("`@("H*
M("`@("`J(&5X86UP;&5S.@H@("`@("H@(")L<B(@=V]U;&0@8F4@<F5A9"!O
M;FQY(&9O<B!T:&%T('5S97(*("`@("`J("`B;')W(B!W;W5L9"!B92!R96%D
M+W=R:71E"B`@("`@*B\*"B`@("`O*BH*("`@("`J(%-E=',@86X@06-C97-S
M($-O;G1R;VP@3&ES="!F;W(@86X@86)O;VLN"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D86)O;VL@3F%M92!O9B!A9&1R97-S(&)O;VLN"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1I9&5N="!.86UE(&]F('5S97(@9F]R('1H:7,@
M86-L+@H@("`@("H@0'!A<F%M('-T<FEN9R`D86-L("`@86-L(&9O<B!T:&ES
M('5S97(O8F]O:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%1R=64@
M;VX@<W5C8V5S<R`O(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<V5T04-,*"1A8F]O:RP@)&ED96YT+"`D86-L*0H@("`@
M>PH@("`@("`@("\O(%9E<FEF>2!T:&%T("1A8VP@;&]O:W,@9V]O9"X*("`@
M("`@("!I9B`H<')E9U]M871C:"@B+UM>(B`N($E-4U!?04-,7U))1TA44R`N
M(")=+R(L("1A8VPI*2!["B`@("`@("`@("`@("\O97)R;W(N+BYA8VP@;&ES
M="!C;VYT86EN960@=6YR96-O9VEN>F5D(&]P=&EO;G,*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*$E-4U!?0D%$7T%21U5-
M14Y4+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@
M+R\@0F5G:6X@<V5N9&EN9R!C;VUM86YD+@H@("`@("`@("1R97-U;'0@/2`D
M=&AI<RT^7VEM<W`M/FEM<W!396YD*"=3151!0TP@041$4D534T)/3TL@)RP@
M=')U92P@9F%L<V4I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@
M("`@?0H*("`@("`@("`O+R![?2!F;W(@8F]O:R!N86UE/PH@("`@("`@(&EF
M("AP<F5G7VUA=&-H*$E-4U!?35535%]54T5?3$E415)!3"P@)&%B;V]K*2D@
M>PH@("`@("`@("`@("`D8FE";V]K(#T@<W!R:6YT9B@B>R5D?2(L('-T<FQE
M;B@D86)O;VLI*3L*("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4V5N
M9"@D8FE";V]K+"!F86QS92P@=')U92D["@H@("`@("`@("`@("!I9B`H(7!R
M96=?;6%T8V@H(B]>7"LO(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*2DI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G1&ED(&YO="!R
M96-E:79E(&5X<&5C=&5D(&-O;6UA;F0@8V]N=&EN=6%T:6]N(')E<W!O;G-E
M(&9R;VT@24U34"!S97)V97(N)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@
M("`@("`@("`@("!]"@H@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]I;7-P
M+3YI;7-P4V5N9"@B)&%B;V]K("(L(&9A;'-E+"!F86QS92D["@H@("`@("`@
M("\O('M](&9O<B!I9&5N=#\*("`@("`@("!I9B`H<')E9U]M871C:"A)35-0
M7TU54U1?55-%7TQ)5$5204PL("1I9&5N="DI('L*("`@("`@("`@("`@)&)I
M261E;G0@/2!S<')I;G1F*")[)61](BP@<W1R;&5N*"1I9&5N="DI.PH@("`@
M("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1B:4ED96YT+"!F86QS
M92P@=')U92D["@H@("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H(B]>7"LO
M(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^
M:6US<%)E8V5I=F4H*2DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7VEM<W`M/FEM<W!%<G)O<B@G1&ED(&YO="!R96-E:79E(&5X<&5C=&5D
M(&-O;6UA;F0@8V]N=&EN=6%T:6]N(')E<W!O;G-E(&9R;VT@24U34"!S97)V
M97(N)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!]"@H@
M("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@B)&ED
M96YT("(L(&9A;'-E+"!F86QS92D["@H@("`@("`@("\O($YO=R!F:6YI<V@@
M=7`@=VET:"!T:&4@86-T=6%L($%#3"X*("`@("`@("`D=&AI<RT^7VEM<W`M
M/FEM<W!396YD*"1A8VPL(&9A;'-E+"!T<G5E*3L*("`@("`@("`D<F5S<&]N
M<V4@/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D["@H@("`@("`@('-W
M:71C:"`H)')E<W!O;G-E*2!["B`@("`@("`@8V%S92`G3D\G.@H@("`@("`@
M("`@("`O+R!#;W5L9"!N;W0@<V5T($%#3"X*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=)35-0('-E<G9E<B!I<R!U;F%B
M;&4@=&\@<&5R9F]R;2!Y;W5R(')E<75E<W0N)RQ?7T9)3$5?7RP@7U],24Y%
M7U\I.PH*("`@("`@("!C87-E("="040G.@H@("`@("`@("`@("`O+R!"860@
M<WEN=&%X+@H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P
M17)R;W(H)U1H92!)35-0('-E<G9E<B!D:60@;F]T('5N9&5R<W1A;F0@>6]U
M<B!R97%U97-T+B<L7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@("`@8V%S
M92`G3TLG.@H@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/G=R:71E5&],;V<H
M(D%#3"!S970@9F]R("1I9&5N="!O;B`D86)O;VLB+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("!R971U<FX@=')U93L*"B`@
M("`@("`@9&5F875L=#H*("`@("`@("`@("`@+R\@1&\@;F]T(&MN;W<@=VAY
M('=E('=O=6QD(&UA:V4@:70@9&]W;B!H97)E+@H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)T1I9"!N;W0@<F5C96EV92!T
M:&4@97AP96-T960@<F5S<&]N<V4@9G)O;2!T:&4@<V5R=F5R+B<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E=')I979E<R!A;B!A9&1R97-S(&)O;VLG<R!!0TPN"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D86)O;VL@3F%M92!O9B!A9&1R97-S(&)O;VL@
M=&\@<F5T<FEE=F4@86-L(&9O<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D(&%R<F%Y(&-O;G1A:6YI;F<@86-L(&9O<B!E=F5R>2!U<V5R('=I=&@@
M86-C97-S('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(&%D9')E<W,@
M8F]O:R!O<B!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=$%#3"@D86)O;VLI"B`@("!["B`@("`@("`@)')E<W5L="`]
M("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H)T=%5$%#3"!!1$1215-30D]/2R`G
M+"!T<G5E+"!F86QS92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M("`@("!]"@H@("`@("`@("\O('M](&9O<B!B;V]K(&YA;64_"B`@("`@("`@
M:68@*'!R96=?;6%T8V@H24U34%]-55-47U5315],251%4D%,+"`D86)O;VLI
M*2!["B`@("`@("`@("`@("1B:4YA;64@/2!S<')I;G1F*")[)61](BP@<W1R
M;&5N*"1A8F]O:RDI.PH@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!3
M96YD*"1B:4YA;64L(&9A;'-E+"!T<G5E*3L*"B`@("`@("`@("`@(&EF("@A
M<')E9U]M871C:"@B+UY<*R\B+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=$:60@;F]T
M(')E8V5I=F4@97AP96-T960@8V]M;6%N9"!C;VYT:6YU871I;VX@<F5S<&]N
M<V4@9G)O;2!)35-0('-E<G9E<BXG+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?:6US
M<"T^:6US<%-E;F0H)&%B;V]K+"!F86QS92P@=')U92D["@H@("`@("`@("\O
M($=E="!R97-U;'1S+@H@("`@("`@("1R97-P;VYS92`]("1T:&ES+3Y?:6US
M<"T^:6US<%)E8V5I=F4H*3L*"B`@("`@("`@<W=I=&-H("@D<F5S<&]N<V4I
M('L*("`@("`@("!C87-E("=.3R<Z"B`@("`@("`@("`@("\O($-O=6QD(&YO
M="!C;VUP;&5T93\*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^
M:6US<$5R<F]R*"=)35-0('-E<G9E<B!I<R!U;F%B;&4@=&\@<&5R9F]R;2!Y
M;W5R(')E<75E<W0N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@("`@
M8V%S92`G0D%$)SH*("`@("`@("`@("`@+R\@1&\@;F]T(&MN;W<@=VAA="!Y
M;W4@<V%I9"$*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US
M<$5R<F]R*"=4:&4@24U34"!S97)V97(@9&ED(&YO="!U;F1E<G-T86YD('EO
M=7(@<F5Q=65S="XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*
M"B`@("`@("`@+R\@268@=V4@87)E(&AE<F4L('=E(&YE960@=&\@<F5C96EV
M92!T:&4@*B!!0TP@4F5S<&]N<V5S+@H@("`@("`@(&1O('L*("`@("`@("`@
M("`@+RH@1V5T(&%N(&%R<F%Y(&]F(')E<W!O;G-E<RX*("`@("`@("`@("`@
M("H@5&AE(%LS72!E;&5M96YT('-H;W5L9"!B92!T:&4@861D<F5S<R!B;V]K
M(&YA;64*("`@("`@("`@("`@("H@6S1=(&%N9"!;-5T@=VEL;"!B92!U<V5R
M+V=R;W5P(&YA;64@86YD('!E<FUI<W-I;VYS("HO"@H@("`@("`@("`@("`O
M+W1H92!B;V]K(&YA;64@;6EG:'0@8F4@82!L:71E<F%L"B`@("`@("`@("`@
M(&EF("AP<F5G7VUA=&-H*$E-4U!?3T-4151?0T]53E0L("1R97-P;VYS92P@
M)'1E;7!!<G)A>2DI('L*("`@("`@("`@("`@("`@("1D871A(#T@)'1H:7,M
M/E]I;7-P+3YR96-E:79E4W1R:6YG3&ET97)A;"@D=&5M<$%R<F%Y6S)=*3L*
M("`@("`@("`@("`@("`@("\O1V5T('1H92!R97-T"B`@("`@("`@("`@("`@
M("`D<F5S<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1P87)T<R`](&5X<&QO9&4H)R`G
M+"`D<F5S<&]N<V4I.PH*("`@("`@("`@("`@+R\@4'5S:"!T:&4@87)R87D@
M:68@8F]O:R!W87,@82!L:71E<F%L"B`@("`@("`@("`@(&EF("@D9&%T82D@
M>PH@("`@("`@("`@("`@("`@87)R87E?=6YS:&EF="@D<&%R=',L("<@)RP@
M)R`G+"`G("<L("<@)RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@+R\@
M061D<F5S<R!B;V]K(&YA;64@<75O=&5D/PH@("`@("`@("`@("`D;G5M4&%R
M=',@/2!C;W5N="@D<&%R=',I.PH@("`@("`@("`@("`D;F%M92`]("1P87)T
M<ULS73L*("`@("`@("`@("`@)&9I<G-T04-,261X(#T@-#L*("`@("`@("`@
M("`@)&9I<G-T0VAA<B`]('-U8G-T<B@D;F%M92P@,"P@,2D["B`@("`@("`@
M("`@(&EF("@D9FER<W1#:&%R(#T](")<(B(I('L*("`@("`@("`@("`@("`@
M(&9O<B`H)&D@/2`T.R`D:2`\("1N=6U087)T<SL@)&DK*RD@>PH@("`@("`@
M("`@("`@("`@("`@("1L87-T0VAA<B`]('-U8G-T<B@D<&%R='-;)&E=+"!S
M=')L96XH)'!A<G1S6R1I72D@+2`Q+"`Q*3L*("`@("`@("`@("`@("`@("`@
M("`D9FER<W1!0TQ)9'@K*SL*("`@("`@("`@("`@("`@("`@("!I9B`H)&QA
M<W1#:&%R(#T](")<(B(I('L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!F;W(@*"1I(#T@)&9I<G-T04-,
M261X.R`D:2`\(&-O=6YT*"1P87)T<RD[("1I("L](#(I('L*("`@("`@("`@
M("`@("`@("1R97-U;'1S6R1P87)T<ULD:5U=(#T@)'!A<G1S6R1I*S%=.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`D<F5S<&]N<V4@/2`D=&AI<RT^
M7VEM<W`M/FEM<W!296-E:79E*"D["@H@("`@("`@('T@=VAI;&4@*'!R96=?
M;6%T8V@H(B]>7"H@04-,($%$1%)%4U-"3T]++R(L("1R97-P;VYS92DI.PH*
M("`@("`@("`O+R!(;W!E9G5L;'D@=V4@8V%N(')E8V5I=F4@86X@3TL@<F5S
M<&]N<V4@:&5R90H@("`@("`@(&EF("@D<F5S<&]N<V4@(3T@)T]+)RD@>PH@
M("`@("`@("`@("`O+R!3;VUE('=E:7)D('!R;V)L96T*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=$:60@;F]T(')E8V5I
M=F4@=&AE(&5X<&5C=&5D(')E<W!O;G-E(&9R;VT@=&AE('-E<G9E<BXG+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&
M24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?
M:6US<"T^=W)I=&54;TQO9R@B1T5404-,(&]N("1A8F]O:R!C;VUP;&5T960N
M(BP@7U]&24Q%7U\L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%]?3$E.15]?+"!014%27TQ/1U])3D9/*3L*("`@("`@("!R971U<FX@)')E
M<W5L=',["@H@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E<R!A;B!!0TP@
M96YT<GD@9F]R(&%N(&%D9')E<W,@8F]O:RX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1A8F]O:R!.86UE(&]F('1H92!A9&1R97-S(&)O;VLN"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1I9&5N="!.86UE(&]F(&5N=')Y('1O(')E
M;6]V92!A8VP@9F]R+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@=')U
M92!O;B!S=6-C97-S+"!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&1E;&5T94%#3"@D86)O;VLL("1I9&5N="D*("`@('L*
M("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@G1$5,
M151%04-,($%$1%)%4U-"3T]+("<L('1R=64L(&9A;'-E*3L*("`@("`@("!I
M9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@+R\@1&\@=V4@
M;F5E9"!L:71E<F%L(&9O<B!A9&1R97-S(&)O;VL@;F%M93\*("`@("`@("!I
M9B`H<')E9U]M871C:"A)35-07TU54U1?55-%7TQ)5$5204PL("1A8F]O:RDI
M('L*("`@("`@("`@("`@)&)I0F]O:R`]('-P<FEN=&8H(GLE9'TB+"!S=')L
M96XH)&%B;V]K*2D["B`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%-E
M;F0H)&)I0F]O:RP@9F%L<V4L('1R=64I.PH*("`@("`@("`@("`@:68@*"%P
M<F5G7VUA=&-H*"(O7EPK+R(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"DI*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)T1I9"!N;W0@
M<F5C96EV92!E>'!E8W1E9"!C;VUM86YD(&-O;G1I;G5A=&EO;B!R97-P;VYS
M92!F<F]M($E-4U`@<V5R=F5R+B<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M("`@("`@("`@("`@?0H*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?:6US
M<"T^:6US<%-E;F0H(B1A8F]O:R`B+"!F86QS92P@9F%L<V4I.PH*("`@("`@
M("`O+R!,:71E<F%L(&9O<B!I9&5N="!N86UE/PH@("`@("`@(&EF("AP<F5G
M7VUA=&-H*$E-4U!?35535%]54T5?3$E415)!3"P@)&ED96YT*2D@>PH@("`@
M("`@("`@("`D8FE)9&5N="`]('-P<FEN=&8H(GLE9'TB+"!S=')L96XH)&ED
M96YT*2D["B`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H)&)I
M261E;G0L(&9A;'-E+"!T<G5E*3L*"B`@("`@("`@("`@(&EF("@A<')E9U]M
M871C:"@B+UY<*R\B+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=$:60@;F]T(')E8V5I
M=F4@97AP96-T960@8V]M;6%N9"!C;VYT:6YU871I;VX@<F5S<&]N<V4@9G)O
M;2!)35-0('-E<G9E<BXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H
M)&ED96YT+"!F86QS92P@=')U92D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@B7"(D:61E;G1<(B(L(&9A
M;'-E+"!T<G5E*3L*("`@("`@("!]"@H@("`@("`@("\O($=E="!R97-U;'1S
M+@H@("`@("`@("1S97)V97)?<F5S<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM
M<W!296-E:79E*"D["@H@("`@("`@('-W:71C:"`H)'-E<G9E<E]R97-P;VYS
M92D@>PH@("`@("`@(&-A<V4@)TY/)SH*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=)35-0('-E<G9E<B!I<R!U;F%B;&4@
M=&\@<&5R9F]R;2!Y;W5R(')E<75E<W0N)RP@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*"B`@("`@("`@8V%S92`G0D%$)SH*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=4:&4@24U34"!S97)V97(@9&ED(&YO
M="!U;F1E<G-T86YD('EO=7(@<F5Q=65S="XG+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH*("`@("`@("!C87-E("=/2R<Z"B`@("`@("`@("`@("1T:&ES+3Y?
M:6US<"T^=W)I=&54;TQO9R@B1$5,151%1"!!0TP@9F]R("1I9&5N="!O;B`D
M86)O;VLB+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?24Y&3RD["B`@("`@("`@
M("`@(')E='5R;B!T<G5E.PH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)T1I9"!N;W0@<F5C
M96EV92!T:&4@97AP96-T960@<F5S<&]N<V4@9G)O;2!T:&4@<V5R=F5R+B<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@86X@04-,('-T<FEN9R!C;VYT86EN:6YG('1H92!R
M:6=H=',@9F]R('1H92!C=7)R96YT('5S97(*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1A8F]O:R!.86UE(&]F(&%D9')E<W,@8F]O:R!T;R!R971R
M:65V92!A8VPN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!A8VP@;V8@
M8W5R<F5N="!U<V5R(&]R(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@;7E2:6=H=',H)&%B;V]K*0H@("`@>PH@("`@("`@
M("1D871A(#T@)R<["B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US<"T^
M:6US<%-E;F0H)TU94DE'2%13($%$1%)%4U-"3T]+("<L('1R=64L(&9A;'-E
M*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@
M("`@:68@*'!R96=?;6%T8V@H24U34%]-55-47U5315],251%4D%,+"`D86)O
M;VLI*2!["B`@("`@("`@("`@("1B:4)O;VL@/2!S<')I;G1F*")[)61](BP@
M<W1R;&5N*"1A8F]O:RDI.PH@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/FEM
M<W!396YD*"1B:4)O;VLL(&9A;'-E+"!T<G5E*3L*"B`@("`@("`@("`@(&EF
M("@A<')E9U]M871C:"@B+UY<*R\B+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=$:60@
M;F]T(')E8V5I=F4@97AP96-T960@8V]M;6%N9"!C;VYT:6YU871I;VX@<F5S
M<&]N<V4@9G)O;2!)35-0('-E<G9E<BXG+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["B`@("`@("`@("`@('T*"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^
M7VEM<W`M/FEM<W!396YD*"1A8F]O:RP@9F%L<V4L('1R=64I.PH@("`@("`@
M("1S97)V97)?<F5S<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E
M*"D["@H@("`@("`@('-W:71C:"`H)'-E<G9E<E]R97-P;VYS92D@>PH@("`@
M("`@(&-A<V4@)TY/)SH*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US
M<"T^:6US<$5R<F]R*"=)35-0('-E<G9E<B!I<R!U;F%B;&4@=&\@<&5R9F]R
M;2!Y;W5R(')E<75E<W0N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@
M("`@8V%S92`G0D%$)SH*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US
M<"T^:6US<$5R<F]R*"=4:&4@24U34"!S97)V97(@9&ED(&YO="!U;F1E<G-T
M86YD('EO=7(@<F5Q=65S="XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"%P<F5G7VUA=&-H*"(O7EPJ($U94DE'2%13
M($%$1%)%4U-"3T]++R(L("1S97)V97)?<F5S<&]N<V4I*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G1&ED(&YO="!R
M96-E:79E('1H92!E>'!E8W1E9"!R97-P;VYS92!F<F]M('1H92!S97)V97(N
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("`O+R![
M?2!F;W(@=&AE(&%B;V]K(&YA;64_"B`@("`@("`@:68@*'!R96=?;6%T8V@H
M24U34%]/0U1%5%]#3U5.5"P@)'-E<G9E<E]R97-P;VYS92P@)'1E;7!!<G)A
M>2DI('L*("`@("`@("`@("`@)&1A=&$@/2`D=&AI<RT^7VEM<W`M/G)E8V5I
M=F53=')I;F=,:71E<F%L*"1T96UP07)R87E;,ETI.PH@("`@("`@("`@("`O
M+R!'970@=&AE(')E<W0N"B`@("`@("`@("`@("1S97)V97)?<F5S<&]N<V4@
M/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D["B`@("`@("`@?0H*("`@
M("`@("`D<&%R=',@/2!E>'!L;V1E*"<@)RP@)'-E<G9E<E]R97-P;VYS92D[
M"@H@("`@("`@("\O(%!U<V@@=&AE(&%R<F%Y(&EF('=E(&AA9"!A('M]"B`@
M("`@("`@:68@*"1D871A*2!["B`@("`@("`@("`@(&%R<F%Y7W5N<VAI9G0H
M)'!A<G1S+"`G("<L("<@)RP@)R`G+"`G("<I.PH@("`@("`@('T*"B`@("`@
M("`@+R\@475O=&5D(&%D9')E<W,@8F]O:R!N86UE/PH@("`@("`@("1N=6U0
M87)T<R`](&-O=6YT*"1P87)T<RD["B`@("`@("`@)&YA;64@/2`D<&%R='-;
M,UT["B`@("`@("`@)&9I<G-T04-,261X(#T@-#L*("`@("`@("`D9FER<W1#
M:&%R(#T@<W5B<W1R*"1N86UE+"`P+"`Q*3L*("`@("`@("!I9B`H)&9I<G-T
M0VAA<B`]/2`B7"(B*2!["B`@("`@("`@("`@(&9O<B`H)&D@/2`T.R`D:2`\
M("1N=6U087)T<SL@)&DK*RD@>PH@("`@("`@("`@("`@("`@)&QA<W1#:&%R
M(#T@<W5B<W1R*"1P87)T<ULD:5TL('-T<FQE;B@D<&%R='-;)&E=*2`M(#$L
M(#$I.PH@("`@("`@("`@("`@("`@)&9I<G-T04-,261X*RL["B`@("`@("`@
M("`@("`@("!I9B`H)&QA<W1#:&%R(#T](")<(B(I('L*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@)&%C;"`]("1P87)T<ULD9FER<W1!0TQ)
M9'A=.PH@("`@("`@("1S97)V97)?<F5S<&]N<V4@/2`D=&AI<RT^7VEM<W`M
M/FEM<W!296-E:79E*"D["@H@("`@("`@(&EF("@D<V5R=F5R7W)E<W!O;G-E
M("$]("=/2R<I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^
M:6US<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@=&AE(&5X<&5C=&5D(')E<W!O
M;G-E(&9R;VT@=&AE('-E<G9E<BXG+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/G=R:71E
M5&],;V<H(DU94DE'2%13(&]N("1A8F]O:R!C;VUP;&5T960N(BP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],
M24Y%7U\L(%!%05)?3$]'7TE.1D\I.PH@("`@("`@("`@("!R971U<FX@)&%C
M;#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!L
M;V<@:6YF;W)M871I;VX@:6X@=&AE($YE=%])35-0(&]B:F5C="X*("`@("`J
M"B`@("`@*B!`<&%R86T@(&%R<F%Y("!,;V<@<&%R86UE=&5R<RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@4$5!4E]%
M<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971,;V=G
M97(H)'!A<F%M<RD*("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]I
M;7-P*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YS971,
M;V=G97(H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B5&AE($E-4U`@;&]G(&-O=6QD
M(&YO="!B92!I;FET:6%L:7IE9"XB*2D["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@4&%R<V5S(&$@24U34"!F971C:&%D9')E<W,@<F5S<&]N
M<V4@=&5X="!S=')I;F<@:6YT;PH@("`@("H@:V5Y+79A;'5E('!A:7)S"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@('-T
M<FEN9R`@)'-E<G9E<E]R97-P;VYS92!4:&4@<F%W(&9E=&-H861D<F5S<R!R
M97-P;VYS92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("`@061D<F5S
M<R!B;V]K(&5N=')Y(&EN9F]R;6%T:6]N(&%S(&ME>3T^=F%L=64@<&%I<G,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P87)S949E=&-H061D<F5S<U)E<W!O
M;G-E*"1S97)V97)?<F5S<&]N<V4I"B`@("!["B`@("`@("`@)&%B;V]K(#T@
M)R<["@H@("`@("`@(&EF("@A<')E9U]M871C:"@B+UY<*B!&151#2$%$1%)%
M4U,@+R(L("1S97)V97)?<F5S<&]N<V4I*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?:6US<"T^=W)I=&54;TQO9R@G6T524D]272!$:60@;F]T(')E8V5I=F4@
M82!&151#2$%$1%)%4U,@<F5S<&]N<V4@9G)O;2!S97)V97(N)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)
M3D5?7RP@4$5!4E],3T=?15)2*3L*"B`@("`@("`@("`@("1T:&ES+3Y?:6US
M<"T^97AI=$-O9&4@/2`G1&ED(&YO="!R96-E:79E('1H92!E>'!E8W1E9"!R
M97-P;VYS92!F<F]M('1H92!S97)V97(N)SL*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+RH@3D]415,*("`@("`@("`@
M*B!087)S92!O=70@=&AE('-E<G9E<B!R97-P;VYS92!S=')I;F<*("`@("`@
M("`@*@H@("`@("`@("`J($%F=&5R(&-H;W!I;F<@;V9F('1H92!S97)V97(@
M8V]M;6%N9"!R97-P;VYS92!T86=S(&%N9`H@("`@("`@("`J(&5X<&QO9&4H
M*2=I;F<@=&AE('-E<G9E<E]R97-P;VYS92!S=')I;F<*("`@("`@("`@*B!T
M:&4@)'!A<G1S(&%R<F%Y(&-O;G1A:6YS('1H92!C:'5N:W,@;V8@=&AE('-E
M<G9E<B!R971U<FYE9"!D871A+@H@("`@("`@("`J"B`@("`@("`@("H@5&AE
M('!R961I9FEN960@)VYA;64G(&9I96QD('-T87)T<R!I;B`D<&%R='-;,5TN
M"B`@("`@("`@("H@5&AE('-E<G9E<B!S:&]U;&0@<F5T=7)N(&%N>2!S:6YG
M;&4@:71E;2!O9B!D871A"B`@("`@("`@("H@=&AA="!C;VYT86EN<R!S<&%C
M97,@=VET:&EN(&ET(&%S(&$@9&]U8FQE('%U;W1E9"!S=')I;F<N"B`@("`@
M("`@("H@4V\@=V4@8V%N(&EN=&5R<')E="!T:&4@97AI<W1E;F-E(&]F(&$@
M9&]U8FQE('%U;W1E(&%T('1H92!B96=I;FYI;F<*("`@("`@("`@*B!O9B!A
M(&-H=6YK('1O(&UE86X@=&AA="!T:&4@;F5X="!C:'5N:RAS*2!A<F4@<&%R
M="!O9@H@("`@("`@("`J('1H92!S86UE('9A;'5E+B`@02!D;W5B;&4@<75O
M=&4@870@=&AE(&5N9"!O9B!A(&-H=6YK('-I9VYI9FEE<R!T:&4*("`@("`@
M("`@*B!E;F0@;V8@=&AA="!V86QU92!A;F0@=&AE(&-H=6YK(&9O;&QO=VEN
M9R!T:&%T(&-A;B!B92!I;G1E<G!R971E9`H@("`@("`@("`J(&%S(&$@:V5Y
M(&YA;64N"B`@("`@("`@("H*("`@("`@("`@*B!792!A;'-O(&YE960@=&\@
M=V%T8V@@9F]R('1H92!S97)V97(@<F5T=7)N:6YG(&$@>WT@<F5S<&]N<V4@
M9F]R('1H90H@("`@("`@("`J('9A;'5E(&]F('1H92!K97D@87,@=V5L;"X@
M*B\*"B`@("`@("`@+R\@5V%S('1H92!A9&1R97-S(&)O;VL@;F%M92!A("![
M?3\*("`@("`@("!I9B`H<')E9U]M871C:"@B+RA>7"H@1D540TA!1$1215-3
M("DH>RDH6S`M.5U[,2Q]*2A<?20I+R(L"B`@("`@("`@("`@("`@("`@("`@
M("`@)'-E<G9E<E]R97-P;VYS92P@)'1E;7!!<G)A>2DI('L*("`@("`@("`@
M("`@)&%B;V]K(#T@)'1H:7,M/E]I;7-P+3YR96-E:79E4W1R:6YG3&ET97)A
M;"@D=&5M<$%R<F%Y6S-=*3L*("`@("`@("`@("`@)&-H;W!P961?<F5S<&]N
M<V4@/2!T<FEM*"1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*2D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@5&%K92!O9F8@=&AE('-T=69F
M(&9R;VT@=&AE(&)E9VEN;FEN9R!O9B!T:&4@<F5S<&]N<V4*("`@("`@("`@
M("`@)&-H;W!P961?<F5S<&]N<V4@/2!T<FEM*'!R96=?<F5P;&%C92@B+UY<
M*B!&151#2$%$1%)%4U,@+R(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)R<L("1S97)V97)?<F5S<&]N<V4I
M*3L*("`@("`@("!]"@H@("`@("`@("1P87)T<R`](&5X<&QO9&4H)R`G+"`D
M8VAO<'!E9%]R97-P;VYS92D["B`@("`@("`@+RH@268@861D<F5S(&)O;VL@
M=V%S('-E;G0@87,@82![?2!T:&5N('=E(&UU<W0@)W!U<V@G(&$@8FQA;FL*
M("`@("`@("`@*B!V86QU92!T;R!T:&4@<W1A<G0@;V8@=&AI<R!A<G)A>2!S
M;R!T:&4@<F5S="!O9B!T:&4@<F]U=&EN90H@("`@("`@("`J('=I;&P@=V]R
M:R!W:71H('1H92!C;W)R96-T(&EN9&5X97,N("HO"B`@("`@("`@(&EF("@A
M96UP='DH)&%B;V]K*2D@>PH@("`@("`@("`@("!A<G)A>5]U;G-H:69T*"1P
M87)T<RP@)R`G*3L*("`@("`@("!]"@H@("`@("`@("\O(%=A<R!T:&4@861D
M<F5S<R!B;V]K(&YA;64@<75O=&5D/PH@("`@("`@("1N=6U/9E!A<G1S(#T@
M8V]U;G0H)'!A<G1S*3L*("`@("`@("`D;F%M92`]("1P87)T<ULP73L*("`@
M("`@("`D9FER<W1.86UE261X(#T@,3L*("`@("`@("`D9FER<W1#:&%R(#T@
M<W5B<W1R*"1N86UE+"`P+"`Q*3L*("`@("`@("!I9B`H)&9I<G-T0VAA<B`]
M/2)<(B(I('L*("`@("`@("`@("`@9F]R("@D:2`](#$[("1I(#P@)&YU;4]F
M4&%R=',[("1I*RLI('L*("`@("`@("`@("`@("`@("1L87-T0VAA<B`]('-U
M8G-T<B@D<&%R='-;)&E=+"!S=')L96XH)'!A<G1S6R1I72D@+2`Q+"`Q*3L*
M("`@("`@("`@("`@("`@("1F:7)S=$YA;65)9'@K*SL*("`@("`@("`@("`@
M("`@(&EF("@D;&%S=$-H87(@/3T@(EPB(BD@>PH@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`O+R!.;W<@<W1A<G0@=V]R:VEN9R!O;B!T:&4@
M96YT<GD@;F%M90H@("`@("`@("1N86UE(#T@)'!A<G1S6R1F:7)S=$YA;65)
M9'A=.PH@("`@("`@("1F:7)S=$-H87(@/2!S=6)S='(H)&YA;64L,"PQ*3L*
M"B`@("`@("`@+R\@0VAE8VL@=&\@<V5E(&EF('1H92!F:7)S="!C:&%R(&]F
M('1H92!N86UE('-T<FEN9R!I<R!A(&1O=6)L92!Q=6]T90H@("`@("`@("\O
M('-O('=E(&MN;W<@:68@=V4@:&%V92!T;R!E>'1R86-T(&UO<F4@;V8@=&AE
M(&YA;64N"B`@("`@("`@:68@*"1F:7)S=$-H87(@/3T@(EPB(BD@>PH@("`@
M("`@("`@("`D;F%M92`](&QT<FEM*"1N86UE+"`B7"(B*3L*("`@("`@("`@
M("`@9F]R("@D:2`]("1F:7)S=$YA;65)9'@@*R`Q.R`D:2`\("1N=6U/9E!A
M<G1S.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D;F%M92`N/2`@)R`G("X@
M)'!A<G1S6R1I73L*("`@("`@("`@("`@("`@("1L87-T0VAA<B`]('-U8G-T
M<B@D<&%R='-;)&E=+"!S=')L96XH)'!A<G1S6R1I72D@+2`Q+#$I.PH@("`@
M("`@("`@("`@("`@:68@*"1L87-T0VAA<B`]/2`B7"(B*2!["B`@("`@("`@
M("`@("`@("`@("`@)&YA;64@/2!R=')I;2@D;F%M92P@(EPB(BD["B`@("`@
M("`@("`@("`@("`@("`@)&YE>'1+97D@/2`D:2`K(#$["B`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*"B`@("`@("`@+R\@0VAE8VL@9F]R('M]"B`@("`@("`@?2!E;'-E:68@
M*'!R96=?;6%T8V@H)R]<>RA<9"LI7'TO)RP@)&YA;64L("1M871C:&5S*2D@
M>PH@("`@("`@("`@("`D;F%M92`]("1T:&ES+3Y?:6US<"T^<F5C96EV95-T
M<FEN9TQI=&5R86PH)&UA=&-H97-;,5TI.PH@("`@("`@("`@("`D<F5S<&]N
M<V4])'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH@("`@("`@("`@("`D
M<&%R=',@/2!E>'!L;V1E*"<@)RP@)')E<W!O;G-E*3L*("`@("`@("`@("`@
M)&YU;4]F4&%R=',@/2!C;W5N="@D<&%R=',I.PH@("`@("`@("`@("`D;F5X
M=$ME>2`](#`["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@268@
M;VYL>2!O;F4@8VAU;FL@9F]R("=N86UE)R!T:&5N('=E(&IU<W0@:&%V92!T
M;R!P;VEN=`H@("`@("`@("`@("`O+R!T;R!T:&4@;F5X="!C:'5N:R!I;B!T
M:&4@87)R87DN+BYW:&EC:"!W:6QL(&AO<&5F=6QL>0H@("`@("`@("`@("`O
M+R!B92`G,B<*("`@("`@("`@("`@)&YE>'1+97D@/2`D9FER<W1.86UE261X
M("L@,3L*("`@("`@("!]"@H@("`@("`@("1L87-T0VAA<B`]("<G.PH@("`@
M("`@("1E;G1R>5LG;F%M92==(#T@)&YA;64["@H@("`@("`@("\O(%-T87)T
M('!A<G-I;F<@=&AE(')E<W0@;V8@=&AE(')E<W!O;G-E+@H@("`@("`@(&9O
M<B`H)&D@/2`D;F5X=$ME>3L@)&D@/"`D;G5M3V9087)T<SL@)&D@*ST@,BD@
M>PH@("`@("`@("`@("`D:V5Y(#T@)'!A<G1S6R1I73L*("`@("`@("`@("`@
M+RH@0VAE8VL@9F]R('M]("HO"B`@("`@("`@("`@(&EF("A`<')E9U]M871C
M:"A)35-07T]#5$547T-/54Y4+"`D<&%R='-;)&DK,5TL("1T96UP07)R87DI
M*2!["B`@("`@("`@("`@("`@("`D<V5R=F5R7V1A=&$@/2`D=&AI<RT^7VEM
M<W`M/G)E8V5I=F53=')I;F=,:71E<F%L*"1T96UP07)R87E;,ETI.PH@("`@
M("`@("`@("`@("`@)&5N=')Y6R1K97E=(#T@)'-E<G9E<E]D871A.PH*("`@
M("`@("`@("`@("`@("\J(%)E860@86YY(')E;6%I;FEN9R!D871A(&9R;VT@
M=&AE('-T<F5A;2!A;F0@<F5S970*("`@("`@("`@("`@("`@("`J('1H92!C
M;W5N=&5R('9A<FEA8FQE<R!S;R!T:&4@;&]O<"!W:6QL(&-O;G1I;G5E"B`@
M("`@("`@("`@("`@("`@*B!C;W)R96-T;'DN($YO=&4@=V4@<V5T("1I("!T
M;R`M,B!B96-A=7-E(&ET('=I;&P*("`@("`@("`@("`@("`@("`J(&)E(&EN
M8W)E;65N=&5D(&)Y(#(@8F5F;W)E('1H92!L;V]P('=I;&P@<G5N(&%G86EN
M("HO"B`@("`@("`@("`@("`@("`D<&%R=',@/2`D=&AI<RT^7VEM<W`M/F=E
M=%-E<G9E<E)E<W!O;G-E0VAU;FMS*"D["B`@("`@("`@("`@("`@("`D:2`]
M("TR.PH@("`@("`@("`@("`@("`@)&YU;4]F4&%R=',@/2!C;W5N="@D<&%R
M=',I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+R\@
M3F]T(&$@<W1R:6YG(&QI=&5R86P@<F5S<&]N<V4*("`@("`@("`@("`@("`@
M($`D96YT<GE;)&ME>5T@/2`D<&%R='-;)&D@*R`Q73L*("`@("`@("`@("`@
M("`@("`O+R!#:&5C:R!T;R!S964@:68@=&AE('9A;'5E('-T87)T960@=VET
M:"!A(&1O=6)L90H@("`@("`@("`@("`@("`@("\O('%U;W1E+B`@5V4@86QS
M;R!N965D('1O(&-H96-K(&EF('1H92!L87-T(&-H87(@:7,@80H@("`@("`@
M("`@("`@("`@("\O('%U;W1E('1O(&UA:V4@<W5R92!W92!214%,3%D@:&%V
M92!T;R!C:&5C:R!T:&4@;F5X=`H@("`@("`@("`@("`@("`@("\O(&5L96UE
M;G1S(&9O<B!A(&-L;W-I;F<@<75O=&4N"B`@("`@("`@("`@("`@("!I9B`H
M*$!S=6)S='(H)'!A<G1S6R1I("L@,5TL(#`L(#$I(#T]("<B)RD@)B8*("`@
M("`@("`@("`@("`@("`@("`H<W5B<W1R*"1P87)T<ULD:2`K(#%=+`H@("`@
M("`@("`@("`@("`@("`@("!S=')L96XH)'!A<G1S6R1I("L@,5TI("T@,2P@
M,2D@(3T@)R(G*2D@>PH*("`@("`@("`@("`@("`@("`@("!D;R!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1N97AT16QE;65N="`]("1P87)T<ULD:2LR
M73L*"B`@("`@("`@("`@("`@("`@("`@("`@("\O(%=A<R!T:&ES(&5L96UE
M;G0@=&AE(&QA<W0@;VYE/PH@("`@("`@("`@("`@("`@("`@("`@("`D;&%S
M=$-H87(@/2!S=6)S='(H)&YE>'1%;&5M96YT+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R;&5N*"1N97AT16QE;65N
M="D@+2`Q+"`Q*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&5N=')Y6R1K
M97E=("X]("<@)R`N("1N97AT16QE;65N=#L*"B`@("`@("`@("`@("`@("`@
M("`@("`@("\O($Y/5RP@=V4@8V%N(&-H96-K('1H92!L87-T0VAA<BX*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"1L87-T0VAA<B`]/2`G(B<I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D;VYE(#T@=')U93L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1I*RL["B`@("`@("`@("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`O+R!#:&5C:R!T;R!S964@:68@=&AE(&YE>'0@96QE;65N="!I<R!T:&4*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(&QA<W0@;VYE+B!)9B!S
M;RP@=&AE(&1O(&QO;W`@=VEL;"!T97)M:6YA=&4N"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9&]N92`](&9A;'-E.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&QA<W1#:&%R(#T@<W5B<W1R*"1P87)T<ULD:2LS72P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!S=')L96XH)'!A<G1S6R1I*S-=*2`M(#$L,2D["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D:2LK.PH@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@?2!W:&EL92`H)&QA<W1#:&%R("$]("<B
M)RD["@H@("`@("`@("`@("`@("`@("`@("\O($1O('=E(&YE960@=&\@861D
M('1H92!F:6YA;"!E;&5M96YT+"!O<B!W97)E"B`@("`@("`@("`@("`@("`@
M("`@+R\@=&AE<F4@;VYL>2!T=V\@=&]T86P_"B`@("`@("`@("`@("`@("`@
M("`@:68@*"$D9&]N92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;F5X
M=$5L96UE;G0@/2`D<&%R='-;)&DK,ET["B`@("`@("`@("`@("`@("`@("`@
M("`@("1E;G1R>5LD:V5Y72`N/2`G("<@+B`D;F5X=$5L96UE;G0["B`@("`@
M("`@("`@("`@("`@("`@("`@("1I*RL["B`@("`@("`@("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@("`@("`@("`O+R!296UO=F4@=&AE('%U;W1E<R!S
M96YT(&)A8VL@=&\@=7,@9G)O;2!T:&4@<V5R=F5R+@H@("`@("`@("`@("`@
M("`@("`@(&EF("AS=6)S='(H)&5N=')Y6R1K97E=+"`P+"`Q*2`]/2`G(B<I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)&5N=')Y6R1K97E=(#T@<W5B
M<W1R*"1E;G1R>5LD:V5Y72P@,2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('-T<FQE;B@D96YT<GE;)&ME>5TI("T@
M,BD["B`@("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@
M("!I9B`H<W5B<W1R*"1E;G1R>5LD:V5Y72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('-T<FQE;B@D96YT<GE;)&ME>5TI("T@,2P@,2D@/3T@
M)R(G*2!["@H@("`@("`@("`@("`@("`@("`@("`@("`D96YT<GE;)&ME>5T@
M/2!S=6)S='(H)&5N=')Y6R1K97E=+"`P+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R;&5N*"1E;G1R>5LD:V5Y
M72D@+2`R*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1E
M;G1R>3L*("`@('T*"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TYE="])35-0+U5T:6QS
M+G!H<```````````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$P
M-C$Q(#$P-3$U-#,S-S0P(#`R,30Q,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@3F5T7TE-4U!?571I
M;',Z.@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R].971?24U34"])35-0+U5T
M:6QS+G!H<"QV(#$N,RXQ,"XW(#(P,#8O,#$O,#$@,C$Z,C@Z,C@@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EC:&%E;"!2=6)I;G-K
M>2`\;7)U8FEN<VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@36EC:&%E;"!2=6)I;G-K>2`\;7)U8FEN<VM`:&]R9&4N;W)G/@H@
M*B!`<&%C:V%G92!.971?24U34`H@*B\*8VQA<W,@3F5T7TE-4U!?571I;',@
M>PH*("`@("\J*@H@("`@("H@571I;&ET>2!F=6YC=&EO;B!T;R!R971R:65V
M92!T:&4@;F%M97,@;V8@86QL('1H92!A9&1R97-S(&)O;VMS"B`@("`@*B!T
M:&%T('1H92!U<V5R(&AA<R!A8V-E<W,@=&\L(&%L;VYG('=I=&@@=&AE(&%C
M;"!F;W(@=&AO<V4*("`@("`J(&)O;VMS+B`@1F]R(&EN9F]R;6%T:6]N(&%B
M;W5T('1H92`D<V5R=F5R26YF;R!A<G)A>2!S964*("`@("`J('1U<F)A+V-O
M;F9I9R]S;W5R8V5S+G!H<"!A<R!T:&ES(&ES('1H92!C9F=3;W5R8V5S6UT@
M96YT<GD@9F]R"B`@("`@*B!T:&4@861D<F5S<R!B;V]K<RX*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@)'-E<G9E<DEN9F\@($EN9F]R;6%T:6]N(&%B
M;W5T('1H92!S97)V97(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@86YD('1H92!C=7)R96YT('5S97(N"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@26YF;W)M871I;VX@86)O=70@86QL('1H92!A9&1R97-S(&)O
M;VMS(&]R(%!%05)?17)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%L
M;$)O;VMS*"1S97)V97));F9O*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC
M92`G3F5T+TE-4U`N<&AP)SL*("`@("`@("`D9F]U;F1$969A=6QT(#T@9F%L
M<V4["B`@("`@("`@)')E<W5L=',@/2!A<G)A>2@I.PH@("`@("`@("1I;7-P
M(#T@)DYE=%])35-0.CIS:6YG;&5T;VXH)T)O;VLG+"`D<V5R=F5R26YF;ULG
M<&%R86US)UTI.PH@("`@("`@("1R97-U;'0@/2`D:6US<"T^:6YI="@I.PH*
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@
M)&)O;VMS(#T@)&EM<W`M/F=E=$%D9')E<W-";V]K3&ES="@I.PH@("`@("`@
M(&EF("AI<U]A*"1B;V]K<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&)O;VMS.PH@("`@("`@('T*"B`@("`@("`@)&)#;W5N="`]
M(&-O=6YT*"1B;V]K<RD["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&)#
M;W5N=#L@)&DK*RD@>PH@("`@("`@("`@("`D;F5W0F]O:R`]("1S97)V97))
M;F9O.PH@("`@("`@("`@("!I9B`H)&)O;VMS6R1I72`A/2`D<V5R=F5R26YF
M;ULG<&%R86US)UU;)W5S97)N86UE)UTI('L*("`@("`@("`@("`@("`@("1N
M97=";V]K6R=T:71L92==(#T@)TE-4U!?)R`N("1B;V]K<ULD:5T["B`@("`@
M("`@("`@("`@("`D;F5W0F]O:ULG<&%R86US)UU;)VYA;64G72`]("1B;V]K
M<ULD:5T["B`@("`@("`@("`@("`@("`D;F5W0F]O:ULG<&%R86US)UU;)VES
M7W)O;W0G72`](&9A;'-E.PH@("`@("`@("`@("`@("`@)&YE=T)O;VM;)W!A
M<F%M<R==6R=M>5]R:6=H=',G72`]("1I;7-P+3YM>5)I9VAT<R@D8F]O:W-;
M)&E=*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1F
M;W5N9$1E9F%U;'0@/2!T<G5E.PH@("`@("`@("`@("`@("`@)&YE=T)O;VM;
M)W!A<F%M<R==6R=M>5]R:6=H=',G72`]("1I;7-P+3YM>5)I9VAT<R@D8F]O
M:W-;)&E=*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<F5S=6QT<UM=
M(#T@)&YE=T)O;VL["B`@("`@("`@?0H@("`@("`@("\J($EF('1H97)E(&ES
M(&YO(&1E9F%U;'0@861D<F5S<R!B;V]K("AN86UE9"!U<V5R;F%M92D@=&AE
M;B!W92!S:&]U;&0@8W)E871E(&]N92X@*B\*("`@("`@("!I9B`H(21F;W5N
M9$1E9F%U;'0I('L*("`@("`@("`@("`@)')E<W5L="`]("1I;7-P+3YC<F5A
M=&5!9&1R97-S0F]O:R@D<V5R=F5R26YF;ULG<&%R86US)UU;)W5S97)N86UE
M)UTI.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@G3&]G:6X@=&\@24U34"!H;W-T(&9A:6QE9"XG("X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("<Z($1E9F%U;'0@861D<F5S
M<R!B;V]K(&ES(&UI<W-I;F<@86YD(&-O=6QD(&YO="!B92!C<F5A=&5D+B<I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5S
M=6QT<SL*("`@('T*"B`@("`O*BH*("`@("`J(%5T:6QI='D@9G5N8W1I;VX@
M=&\@;6%K92!I="!E87-I97(@9F]R(&-L:65N="!A<'!L:6-A=&EO;G,@=&\@
M9&5L971E"B`@("`@*B!A9&1R97-S(&)O;VMS('=I=&AO=70@:&%V:6YG('1O
M(&-R96%T92!I;7-P(&1R:79E<G,N("!4:&4@)'-O=7)C92!A<G)A>0H@("`@
M("H@:7,@82!H;W)D92]T=7)B82!S='EL92`D8V9G4V]U<F-E<R!E;G1R>2!F
M;W(@=&AE(&%D9')E<W,@8F]O:R!B96EN9PH@("`@("H@9&5L971E9"X*("`@
M("`J"B`@("`@*B!`<&%R86T@87)R87D@)'-O=7)C92`@26YF;W)M871I;VX@
M86)O=70@=&AE(&%D9')E<W,@8F]O:R!B96EN9R!D96QE=&5D+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!014%2
M7T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T
M94)O;VLH)'-O=7)C92D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TYE
M="])35-0+G!H<"<["B`@("`@("`@)&EM<W`@/2`F3F5T7TE-4U`Z.G-I;F=L
M971O;B@G0F]O:R<L("1S;W5R8V5;)W!A<F%M<R==*3L*("`@("`@("`D<F5S
M=6QT(#T@)&EM<W`M/FEN:70H*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@("`@('T*("`@("`@("`D<F5S=6QT(#T@)&EM<W`M/F1E;&5T94%D
M9')E<W-";V]K*"1S;W5R8V5;)W!A<F%M<R==6R=N86UE)UTI.PH@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@571I;&ET>2!F=6YC=&EO;B!T
M;R!H96QP(&-L:65N=',@8W)E871E(&YE=R!A9&1R97-S(&)O;VMS('=I=&AO
M=70@:&%V:6YG"B`@("`@*B!T;R!C<F5A=&4@86X@:6US<"!D<FEV97(@:6YS
M=&%N8V4@9FER<W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1S;W5R
M8V4@("`@26YF;W)M871I;VX@86)O=70@=&AE('5S97(G<R!D969A=6QT($E-
M4U`*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&%D9')E<W,@8F]O
M:RX*("`@("`J($!P87)A;2!S=')I;F<@)&YE=TYA;64@(%1H92!N86UE(&]F
M('1H92!N97<@861D<F5S<R!B;V]K+B`@3F]T92!T:&%T('1H:7,*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@(&ES(&%U=&]M871I8V%L;'D@<75A
M;&EF:65D('=I=&@@=&AE('5S97(G<R!N86UE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("!S;R!S:&]U;&0@;F]T(&)E('!A<W-E9"!A<R!A(&9U
M;&QY('%U86QI9FEE9"!)35-0"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("!A9&1R97-S(&)O;VL@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!T<G5E(&]N('-U8V-E<W,@;W(@4$5!4E]%<G)O<B!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("`@9G5N8W1I;VX@8W)E871E0F]O:R@D<V]U<F-E
M+"`D;F5W3F%M92D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TYE="])
M35-0+G!H<"<["B`@("`@("`@)&EM<W`@/2`F3F5T7TE-4U`Z.G-I;F=L971O
M;B@G0F]O:R<L("1S;W5R8V5;)W!A<F%M<R==*3L*("`@("`@("`D<F5S=6QT
M(#T@)&EM<W`M/FEN:70H*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@
M("`@("`@('T*("`@("`@("`D;F%M92`]("1S;W5R8V5;)W!A<F%M<R==6R=U
M<V5R;F%M92==("X@)RXG("X@)&YE=TYA;64["B`@("`@("`@)')E<W5L="`]
M("1I;7-P+3YC<F5A=&5!9&1R97-S0F]O:R@D;F%M92D["B`@("`@("`@:68@
M*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O3F5T+TE-4U`O3W!T:6]N<RYP:'``````
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,34U-C(@,3`U,34T
M,S,W-#`@,#(Q-S4V`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TYE="])35-0+T%U=&@N
M<&AP)SL*"B\J*@H@*B!.971?24U34%]/<'1I;VYS($-L87-S("T@<')O=FED
M97,@86X@:6YT97)F86-E('1O($E-4U`@<V5R=F5R+6)A<V5D"B`J(&]P=&EO
M;G,@<W1O<F%G92X*("H*("H@4F5Q=6ER960@<&%R86UE=&5R<SH\<')E/@H@
M*B`@("=U<V5R;F%M92<@("`@(%5S97)N86UE('1O(&QO9V]N('1O($E-4U`@
M<V5R=F5R(&%S+@H@*B`@("=P87-S=V]R9"<@("`@(%!A<W-W;W)D(&9O<B!C
M=7)R96YT('5S97(N"B`J("`@)V%U=&A?;65T:&]D)R`@5&AE(&%U=&AE;G1I
M8V%T:6]N(&UE=&AO9"!T;R!U<V4@=&\@;&]G:6XN"B`J("`@)W-E<G9E<B<@
M("`@("`@5&AE(&AO<W1N86UE(&]F('1H92!)35-0('-E<G9E<BX*("H@("`G
M<&]R="<@("`@("`@("!4:&4@<&]R="!O9B!T:&4@24U34"!S97)V97(N/"]P
M<F4^"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O3W!T
M:6]N<RYP:'`L=B`Q+C,N,BXQ-B`R,#`V+S`Q+S`Q(#(Q.C(X.C(X(&IA;B!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($UI8VAA96P@4G5B:6YS
M:WD@/&UR=6)I;G-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($UI8VAA96P@4G5B:6YS:WD@/&UR=6)I;G-K0&AO<F1E+F]R9SX*
M("H@0'!A8VMA9V4@3F5T7TE-4U`*("HO"F-L87-S($YE=%])35-07T]P=&EO
M;G,@>PH*("`@("\J*@H@("`@("H@3F5T7TE-4U`@;V)J96-T+@H@("`@("H*
M("`@("`J($!V87(@3F5T7TE-4U`*("`@("`J+PH@("`@=F%R("1?:6US<#L*
M"B`@("`O*BH*("`@("`J(%!A<F%M971E<B!L:7-T+@H@("`@("H*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<&%R86US.PH*("`@("\J
M*@H@("`@("H@0V]N<W1R=6-T;W(@9G5N8W1I;VXN"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1P87)A;7,@($AA<V@@8V]N=&%I;FEN9R!)35-0('!A
M<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N($YE=%])35-07T]P=&EO
M;G,H)'!A<F%M<RD*("`@('L*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P
M87)A;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!);FET:6%L:7IA=&EO;B!F
M=6YC=&EO;B!T;R!B92!C86QL960@869T97(@;V)J96-T(&ES(')E='5R;F5D
M+@H@("`@("H@5&AI<R!A;&QO=W,@97)R;W)S('1O(&]C8W5R(&%N9"!N;W0@
M8G)E86L@=&AE('-C<FEP="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!4<G5E(&]N('-U8V-E<W,@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!I;FET*"D*("`@('L*("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3Y?:6US<"DI('L*("`@("`@("`@("`@)&%U=&@@/2`F3F5T
M7TE-4U!?075T:#HZ<VEN9VQE=&]N*"1T:&ES+3Y?<&%R86US6R=A=71H7VUE
M=&AO9"==*3L*("`@("`@("`@("`@)'1H:7,M/E]I;7-P(#T@)&%U=&@M/F%U
M=&AE;G1I8V%T92@D=&AI<RT^7W!A<F%M<RD["B`@("`@("`@?0H*("`@("`@
M("!I9B`H:7-?82@D=&AI<RT^7VEM<W`L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<#L*("`@("`@("!]"B`@("`@
M("`@)'1H:7,M/E]I;7-P+3YW<FET951O3&]G*"=.971?24U34%]/<'1I;VYS
M(&EN:71I86QI>F5D+B<L(%]?1DE,15]?+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@1G5N8W1I
M;VX@<V5N9',@82!'150@8V]M;6%N9"!T;R!)35-0('-E<G9E<B!A;F0@<F5T
M<FEE=F5S('9A;'5E<RX*("`@("`J"B`@("`@*B!`<&%R86T@('-T<FEN9R`D
M;W!T:6]N3F%M92!.86UE(&]F(&]P=&EO;B!T;R!R971R:65V92X@06-C97!T
M<R`G*B<*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%S('=I
M;&0@8V%R9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!!<W-O8VEA
M=&EV92!A<G)A>2!C;VYT86EN:6YG(&]P=&EO;CT^=F%L=64@<&%I<G,@;W(*
M("`@("`J("`@("`@("`@("`@("`@(%!%05)?17)R;W(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E="@D;W!T:6]N3F%M92D*("`@('L*("`@("`@("`D;W!T
M:6]N<R`](&%R<F%Y*"D["B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US
M<"T^:6US<%-E;F0H(D=%5"`D;W!T:6]N3F%M92(L('1R=64L('1R=64I.PH@
M("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`D
M<V5R=F5R7W)E<W!O;G-E(#T@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I
M.PH@("`@("`@(&EF("AI<U]A*"1S97)V97)?<F5S<&]N<V4L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1S97)V97)?<F5S<&]N<V4[
M"B`@("`@("`@?0H*("`@("`@("!W:&EL92`H<')E9U]M871C:"@B+UY<*B!/
M4%1)3TXO(BP@)'-E<G9E<E]R97-P;VYS92DI('L*("`@("`@("`@("`@+RH@
M1FER<W0L(&-H96-K(&9O<B!A('M]+B`J+PH@("`@("`@("`@("!I9B`H<')E
M9U]M871C:"A)35-07T]#5$547T-/54Y4+"`D<V5R=F5R7W)E<W!O;G-E+"`D
M=&5M<$%R<F%Y*2D@>PH@("`@("`@("`@("`@("`@)'1E;7`@/2!E>'!L;V1E
M*"<@)RP@)'-E<G9E<E]R97-P;VYS92D["B`@("`@("`@("`@("`@("`D;W!T
M:6]N<ULD=&5M<%LR75T@/2`D=&AI<RT^7VEM<W`M/G)E8V5I=F53=')I;F=,
M:71E<F%L*"1T96UP07)R87E;,ETI.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)'1E;7`@/2!E>'!L;V1E*"<@)RP@)'-E<G9E<E]R
M97-P;VYS92D["B`@("`@("`@("`@("`@("`D;W!T:6]N<ULD=&5M<%LR75T@
M/2!T<FEM*"1T96UP6S-=*3L*("`@("`@("`@("`@("`@("1I(#T@,SL*("`@
M("`@("`@("`@("`@("1L87-T0VAA<B`]("(B.PH@("`@("`@("`@("`@("`@
M)&YE>'1%;&5M96YT(#T@=')I;2@D=&5M<%LS72D["@H@("`@("`@("`@("`@
M("`@+RH@5V%S('1H92!V86QU92!Q=6]T960@86YD('-P86-E9#\@*B\*("`@
M("`@("`@("`@("`@(&EF("@H<W5B<W1R*"1N97AT16QE;65N="PP+#$I(#T]
M("<B)RD@)B8*("`@("`@("`@("`@("`@("`@("`H<W5B<W1R*"1N97AT16QE
M;65N="QS=')L96XH)&YE>'1%;&5M96YT*2`M(#$L(#$I("$]("<B)RDI('L*
M("`@("`@("`@("`@("`@("`@("!D;R!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1N97AT16QE;65N="`]("1T96UP6R1I*S%=.PH@("`@("`@("`@("`@
M("`@("`@("`@("`D;&%S=$-H87(@/2!S=6)S='(H)&YE>'1%;&5M96YT+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R
M;&5N*"1N97AT16QE;65N="D@+2`Q+"`Q*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&]P=&EO;G-;)'1E;7!;,EU=("X]("<@)R`N("1N97AT16QE;65N
M=#L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1L87-T0VAA<B`]/2`G
M(B<I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D;VYE(#T@=')U
M93L*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1D;VYE(#T@9F%L<V4["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D;&%S=$-H87(@/2!S=6)S='(H)'1E;7!;)&DK
M,ETL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<W1R;&5N*"1T96UP6R1I*S)=*2`M(#$L(#$I.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&DK*SL*("`@("`@("`@("`@("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@("`@("`@("!]('=H:6QE("@D;&%S=$-H87(@
M(3T@)R(G*3L*"B`@("`@("`@("`@("`@("`@("`@:68@*"$D9&]N92D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D;F5X=$5L96UE;G0@/2`D=&5M<%LD
M:2LQ73L*("`@("`@("`@("`@("`@("`@("`@("`@)&]P=&EO;G-;)'1E;7!;
M,EU=("X]("<@)R`N("1N97AT16QE;65N=#L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'-E<G9E<E]R97-P;VYS92`]("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I
M=F4H*3L*("`@("`@("`@("`@:68@*&ES7V$H)'-E<G9E<E]R97-P;VYS92P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1S97)V
M97)?<F5S<&]N<V4["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(&EF("@D<V5R=F5R7W)E<W!O;G-E("$]("=/2R<I('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=$:60@;F]T(')E8V5I
M=F4@=&AE(&5X<&5C=&5D(')E<W!O;G-E(&9R;VT@=&AE('-E<G9E<BXG+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&
M24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?
M:6US<"T^=W)I=&54;TQO9R@G1T54(&-O;6UA;F0@3TLN)RP@7U]&24Q%7U\L
M(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@<F5T=7)N("1O
M<'1I;VYS.PH@("`@?0H*("`@("\J*@H@("`@("H@1G5N8W1I;VX@<V5T<R!A
M;B!O<'1I;VX@=F%L=64@;VX@=&AE($E-4U`@<V5R=F5R+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&]P=&EO;DYA;64@($YA;64@;V8@;W!T:6]N
M('1O('-E="X*("`@("`J($!P87)A;2!S=')I;F<@)&]P=&EO;E9A;'5E(%9A
M;'5E('1O(&%S<VEG;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%1R
M=64@;W(@4$5!4E]%<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T*"1O
M<'1I;VY.86UE+"`D;W!T:6]N5F%L=64I"B`@("!["B`@("`@("`@+RH@4V5N
M9"!T:&4@8F5G:6YN:6YG(&]F('1H92!C;VUM86YD+B`J+PH@("`@("`@("1R
M97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*")3150@)&]P=&EO;DYA
M;64@(BP@=')U92P@9F%L<V4I.PH*("`@("`@("`O*B!396YD("1O<'1I;VY6
M86QU92!A<R!A(&QI=&5R86P@>WT_("HO"B`@("`@("`@:68@*'!R96=?;6%T
M8V@H24U34%]-55-47U5315],251%4D%,+"`D;W!T:6]N5F%L=64I*2!["B`@
M("`@("`@("`@("1B:59A;'5E(#T@<W!R:6YT9B@B>R5D?2(L('-T<FQE;B@D
M;W!T:6]N5F%L=64I*3L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?
M:6US<"T^:6US<%-E;F0H)&)I5F%L=64L(&9A;'-E+"!T<G5E*3L*("`@("`@
M("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@(&EF("@A<')E9U]M871C:"@B+UY<*R\B+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US
M<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@97AP96-T960@8V]M;6%N9"!C;VYT
M:6YU871I;VX@<F5S<&]N<V4@9G)O;2!)35-0('-E<G9E<BXG+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,
M15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@("\J($YO=R!S96YD('1H92!R97-T(&]F('1H92!C;VUM86YD+B`J+PH@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1O<'1I
M;VY686QU92P@9F%L<V4L('1R=64I.PH@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("`@("`@?0H*("`@("`@("`D<V5R=F5R7W)E<W!O;G-E(#T@)'1H
M:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH*("`@("`@("!I9B`H:7-?82@D
M<V5R=F5R7W)E<W!O;G-E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D<V5R=F5R7W)E<W!O;G-E.PH@("`@("`@('T@96QS96EF("@D
M<V5R=F5R7W)E<W!O;G-E("$]("=/2R<I('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=4:&4@;W!T:6]N(&-O=6QD(&YO
M="!B92!S970@;VX@=&AE($E-4U`@<V5R=F5R+B<L(%]?1DE,15]?+"!?7TQ)
M3D5?7RD["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7VEM<W`M/G=R:71E
M5&],;V<H)U-%5"!C;VUM86YD($]++B<L(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?1$5"54<I.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4V5T<R!T:&4@;&]G(&EN9F]R;6%T:6]N(&EN('1H
M92!.971?24U34"!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;7,@(%1H92!L;V<@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@4$5!4E]%<G)O<B!O;B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971,;V=G97(H)'!A<F%M
M<RD*("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]I;7-P*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YS971,;V=G97(H)'!A
M<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=4:&4@24U34"!L;V<@8V]U;&0@;F]T
M(&)E(&EN:71I86QI>F5D+B<I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC
M=&EO;B!L;V=O=70H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:6US<"T^;&]G
M;W5T*"D["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O3F5T+TE-4U`O075T:"YP:'``````````````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,3$P-3<@,3`U,34T,S,W-#`@,#(Q,C$W`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"@IR97%U:7)E7V]N8V4@)TYE="])35-0+G!H<"<["@HO*BH*("H@5&AE($YE
M=%])35-07T%U=&@@8VQA<W,@86)S=')A8W0@8VQA<W,@9F]R($E-4U`@875T
M:&5N=&EC871I;VXN"B`J"B`J(%)E<75I<F5D(%!A<F%M971E<G,Z/'!R93X*
M("H@("`G=7-E<FYA;64G("!5<V5R;F%M92!T;R!L;V=O;B!T;R!)35-0('-E
M<G9E<B!A<RX*("H@("`G<&%S<W=O<F0G("!087-S=V]R9"!F;W(@8W5R<F5N
M="!U<V5R+@H@*B`@("=S97)V97(G("`@(%1H92!H;W-T;F%M92!O9B!T:&4@
M24U34"!S97)V97(N"B`J("`@)W!O<G0G("`@("`@5&AE('!O<G0@;V8@=&AE
M($E-4U`@<V5R=F5R+CPO<')E/@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R].
M971?24U34"])35-0+T%U=&@N<&AP+'8@,2XX+C$P+C$Q(#(P,#8O,#$O,#$@
M,C$Z,C@Z,C<@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@
M36EC:&%E;"!2=6)I;G-K>2`\;7)U8FEN<VM`:&]R9&4N;W)G/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!2=6)I;G-K>2`\;7)U8FEN
M<VM`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!.971?24U34`H@*B\*8VQA<W,@
M3F5T7TE-4U!?075T:"!["B`@("`O*BH*("`@("`J($-L87-S('9A<FEA8FQE
M('1O(&AO;&0@=&AE(')E<W5L=&EN9R!.971?24U34"!O8FIE8W0*("`@("`J
M"B`@("`@*B!`=F%R($YE=%])35-0"B`@("`@*B\*("`@('9A<B`D7VEM<W`[
M"@H@("`@("\J*@H@("`@("H@071T96UP=',@=&\@;&]G:6X@=&\@24U34"!S
M97)V97(N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("`@
M("`@("!087)A;65T97)S(&9O<B!.971?24U34`H@("`@("H@0'!A<F%M(&)O
M;VQE86X@)&QO9VEN("`@("`@("!3:&]U;&0@=V4@<F5M86EN(&QO9V=E9"!I
M;B!A9G1E<B!A=71H/PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@("`@
M("`@("`@("`@("`@4F5T=7)N<R!A($YE=%])35-0(&]B:F5C="!C;VYN96-T
M960@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE
M($E-4U`@<V5R=F5R(&EF(&QO9VEN(&ES('1R=64@86YD"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('-U8V-E<W-F=6PN("!2971U<FYS
M(&)O;VQE86X@=')U92!I9@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!S=6-C97-S9G5L(&%N9"!L;V=I;B!I<R!F86QS92X@4F5T=7)N
M<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!014%27T5R
M<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9A=71H96YT
M:6-A=&4H)'!A<F%M<RP@)&QO9VEN(#T@=')U92D*("`@('L*("`@("`@("`D
M=&AI<RT^7VEM<W`@/2`F)'1H:7,M/E]A=71H96YT:6-A=&4H)'!A<F%M<RD[
M"@H@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?:6US<"P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P.PH@("`@("`@
M('T*"B`@("`@("`@:68@*"$D;&]G:6XI('L*("`@("`@("`@("`@)'1H:7,M
M/E]I;7-P+3YL;V=O=70H*3L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4')I=F%T92!A=71H96YT:6-A=&EO;B!F=6YC=&EO
M;BX@4')O=FED97,@86-T=6%L(&%U=&AE;G1I8V%T:6]N"B`@("`@*B!C;V1E
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'!A<F%M
M("!A<G)A>2`@("1P87)A;7,@("`@("!087)A;65T97)S(&9O<B!.971?24U3
M4%]!=71H(&1R:79E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("`@
M("`@("`@("`@("`@(%)E='5R;G,@3F5T7TE-4U`@;V)J96-T(&-O;FYE8W1E
M9"!T;R!S97)V97(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:68@<W5C8V5S<V9U;"P@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@
M("H@0&%B<W1R86-T"B`@("`@*B\*("`@(&9U;F-T:6]N("9?875T:&5N=&EC
M871E*"1P87)A;7,I"B`@("!["@H@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@='EP92!O9B!T:&ES(&1R:79E<BX*("`@("`J"B`@("`@*B!`
M86)S=')A8W0*("`@("`J($!R971U<FX@<W1R:6YG(%1Y<&4@;V8@24U34%]!
M=71H(&1R:79E<B!I;G-T86YC90H@("`@("HO"B`@("!F=6YC=&EO;B!G971$
M<FEV97)4>7!E*"D*("`@('L*"B`@("!]"@H@("`@+RHJ"B`@("`@*B!&;W)C
M92!A(&QO9V]U="!F<F]M('1H92!U;F1E<FQY:6YG($E-4U`@<W1R96%M+@H@
M("`@("H*("`@("`J+PH@("`@9G5N8W1I;VX@;&]G;W5T*"D*("`@('L*"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC
M<F5T92!.971?24U34%]!=71H(&EN<W1A;F-E(&)A<V5D(&]N("1D<FEV97(*
M("`@("`J($UU<W0@8F4@8V%L;&5D(&%S("9.971?24U34%]!=71H.CIF86-T
M;W)Y*"D*("`@("`J"B`@("`@*B!`<&%R86T@('-T<FEN9R`D9')I=F5R(%1Y
M<&4@;V8@3F5T7TE-4U!?075T:"!S=6)C;&%S<R!T;R!R971U<FXN"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&-R96%T960@3F5T7TE-4U!?
M075T:"!S=6)C;&%S<R!O<B!014%27T5R<F]R+@H@("`@("HO"B`@("!F=6YC
M=&EO;B`F9F%C=&]R>2@D9')I=F5R*0H@("`@>PH@("`@("`@("1D<FEV97(@
M/2!B87-E;F%M92@D9')I=F5R*3L*"B`@("`@("`@:68@*&5M<'1Y*"1D<FEV
M97(I('Q\("AS=')C;7`H)&1R:79E<BP@)VYO;F4G*2`]/2`P*2D@>PH@("`@
M("`@("`@("`D875T:"`]("9N97<@24U34%]!=71H*"D["B`@("`@("`@("`@
M(')E='5R;B`D875T:#L*("`@("`@("!]"@H@("`@("`@(&EF("AF:6QE7V5X
M:7-T<RAD:7)N86UE*%]?1DE,15]?*2`N("<O075T:"\G("X@)&1R:79E<B`N
M("<N<&AP)RDI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H
M7U]&24Q%7U\I("X@)R]!=71H+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@
M("`@('T*"B`@("`@("`@)&-L87-S(#T@)TYE=%])35-07T%U=&A?)R`N("1D
M<FEV97(["@H@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@
M("`@("`@("`@("`D875T:"`]("9N97<@)&-L87-S*"D["B`@("`@("`@("`@
M(')E='5R;B`D875T:#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!(
M;W)D93HZ9F%T86PH4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E5N86)L
M92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(I+"`D8VQA<W,I*2P@
M7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC<F5T92!.971?24U3
M4%]!=71H(&EN<W1A;F-E(&)A<V5D(&]N("1D<FEV97(N"B`@("`@*B!7:6QL
M(&]N;'D@8W)E871E(&$@;F5W(&]B:F5C="!I9B!O;F4@=VET:"!T:&4@<V%M
M92!P87)A;65T97)S(&%L<F5A9'D*("`@("`J(&1O97,@;F]T(&5X:7-T+@H@
M("`@("H@375S="!B92!C86QL960@;&EK93H@)'9A<B`]("9.971?24U34%]!
M=71H.CIS:6YG;&5T;VXH)V1R:79E<E]T>7!E)RD["B`@("`@*@H@("`@("H@
M0'!A<F%M("!S=')I;F<@)&1R:79E<B!4>7!E(&]F($E-4U!?075T:"!S=6)C
M;&%S<R!T;R!R971U<FXN"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE8W0@
M4F5F97)E;F-E('1O($E-4U!?075T:"!S=6)C;&%S<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@)G-I;F=L971O;B@D9')I=F5R*0H@("`@>PH@("`@("`@('-T
M871I8R`D:6YS=&%N8V5S.PH@("`@("`@("\J($-H96-K(&9O<B!A;GD@:6UT
M97-T(&1R:79E<B!I;G-T86YC97,@86YD(&MI;&P@=&AE;2X*("`@("`@("`@
M("!/=&AE<G=I<V4L('1H92!S;V-K970@=VEL;"!H86YG(&)E='=E96X@<F5Q
M=65S=',@9G)O;0H@("`@("`@("`@('-E<&5R871E(&1R:79E<G,@*&%N($%U
M=&@@<F5Q=65S="!A;F0@86X@3W!T:6]N<R!R97%U97-T*2XJ+PH@("`@("`@
M(&EF("AI<U]A<G)A>2@D:6YS=&%N8V5S*2D@>PH@("`@("`@("`@("!F;W)E
M86-H("@D:6YS=&%N8V5S(&%S("1O8FHI('L*("`@("`@("`@("`@("`@(&EF
M("@D;V)J+3YG971$<FEV97)4>7!E*"D@/3T@)VEM=&5S="<I('L*("`@("`@
M("`@("`@("`@("`@("`D;V)J+3YL;V=O=70H*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T
M*"1I;G-T86YC97,I*2!["B`@("`@("`@("`@("1I;G-T86YC97,@/2!A<G)A
M>2@I.PH@("`@("`@('T*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA;&EZ
M92AA<G)A>2@D9')I=F5R*2D["B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N
M8V5S6R1S:6=N871U<F5=*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S6R1S
M:6=N871U<F5=(#T@)DYE=%])35-07T%U=&@Z.F9A8W1O<GDH)&1R:79E<BD[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EN<W1A;F-E<ULD<VEG;F%T
M=7)E73L*("`@('T*"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TYE="]335,N<&AP````````````````````````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#(U,C$T(#$P-3$U-#,S-S0P(#`R
M,#(Q,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`H*<F5Q=6ER95]O;F-E("=014%2+G!H<"<["@HO*BH*("H@3F5T
M7U--4R!#;&%S<PH@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UA<FMO($1J
M=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U(&1I9`H@*B!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R].971?4TU3+U--4RYP:'`L=B`Q+C$P+C$P+C$P(#(P
M,#8O,#$O,#$@,C$Z,C@Z,C@@:F%N($5X<"`D"B`J"B`J($!A=71H;W(@($UA
M<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J($!P86-K86=E($YE=%]3
M35,*("HO"F-L87-S($YE=%]335,@>PH*("`@("\J*@H@("`@("H@02!H87-H
M(&-O;G1A:6YI;F<@86YY('!A<F%M971E<G,@9F]R('1H92!C=7)R96YT(&=A
M=&5W87D@9')I=F5R+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1?<&%R86US(#T@87)R87DH*3L*"B`@("!V87(@)%]A=71H
M(#T@;G5L;#L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N>2!P87)A;65T97)S(&YE
M961E9"!F;W(@=&AI<R!G871E=V%Y(&1R:79E<BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@3F5T7U--4R@D<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@("`D
M=&AI<RT^7W!A<F%M<R`]("1P87)A;7,["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&$@;&ES="!O9B!A=F%I;&%B;&4@9V%T97=A>2!D<FEV97)S
M+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y(&]F(&%V
M86EL86)L92!D<FEV97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971$<FEV
M97)S*"D*("`@('L*("`@("`@("!S=&%T:6,@)&1R:79E<G,@/2!A<G)A>2@I
M.PH@("`@("`@(&EF("@A96UP='DH)&1R:79E<G,I*2!["B`@("`@("`@("`@
M(')E='5R;B`D9')I=F5R<SL*("`@("`@("!]"@H@("`@("`@("1D<FEV97)S
M(#T@87)R87DH*3L*"B`@("`@("`@:68@*"1D<FEV97)?9&ER(#T@;W!E;F1I
M<BAD:7)N86UE*%]?1DE,15]?*2`N("<O4TU3+R<I*2!["B`@("`@("`@("`@
M('=H:6QE("AF86QS92`A/3T@*"1F:6QE(#T@<F5A9&1I<B@D9')I=F5R7V1I
M<BDI*2!["B`@("`@("`@("`@("`@("`O*B!(:61E(&1O="!F:6QE<R!A;F0@
M;F]N("YP:'`@9FEL97,N("HO"B`@("`@("`@("`@("`@("!I9B`H<W5B<W1R
M*"1F:6QE+"`P+"`Q*2`A/2`G+B<@)B8@<W5B<W1R*"1F:6QE+"`M-"D@/3T@
M)RYP:'`G*2!["B`@("`@("`@("`@("`@("`@("`@)&1R:79E<B`]('-U8G-T
M<B@D9FEL92P@,"P@+30I.PH@("`@("`@("`@("`@("`@("`@("1D<FEV97)?
M:6YF;R`]($YE=%]335,Z.F=E=$=A=&5W87E);F9O*"1D<FEV97(I.PH@("`@
M("`@("`@("`@("`@("`@("1D<FEV97)S6R1D<FEV97)=(#T@)&1R:79E<E]I
M;F9O6R=N86UE)UT["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("`@("`@8VQO<V5D:7(H)&1R:79E<E]D:7(I.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1D<FEV97)S.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!I;F9O<FUA=&EO;B!O;B!A(&=A=&5W87DL('-U8V@@87,@
M;F%M92!A;F0@82!B<FEE9B!D97-C<FEP=&EO;BP*("`@("`J(&9R;VT@=&AE
M(&1R:79E<B!S=6)C;&%S<R!G971);F9O*"D@9G5N8W1I;VXN"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@;V8@97AT<F$@:6YF;W)M
M871I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$=A=&5W87E);F9O*"1G
M871E=V%Y*0H@("`@>PH@("`@("`@('-T871I8R`D:6YF;R`](&%R<F%Y*"D[
M"B`@("`@("`@:68@*&ES<V5T*"1I;F9O6R1G871E=V%Y72DI('L*("`@("`@
M("`@("`@<F5T=7)N("1I;F9O6R1G871E=V%Y73L*("`@("`@("!]"@H@("`@
M("`@(')E<75I<F5?;VYC92`G3F5T+U--4R\G("X@)&=A=&5W87D@+B`G+G!H
M<"<["B`@("`@("`@)&-L87-S(#T@)TYE=%]335-?)R`N("1G871E=V%Y.PH@
M("`@("`@("1I;F9O6R1G871E=V%Y72`](&-A;&Q?=7-E<E]F=6YC*&%R<F%Y
M*"1C;&%S<RP@)V=E=$EN9F\G*2D["@H@("`@("`@(')E='5R;B`D:6YF;ULD
M9V%T97=A>5T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('!A<F%M
M971E<G,@9F]R(&$@9V%T97=A>2!F<F]M('1H92!D<FEV97(@<W5B8VQA<W,@
M9V5T4&%R86US*"D*("`@("`J(&9U;F-T:6]N+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@(%1H92!N86UE(&]F('1H92!G871E=V%Y(&1R:79E<B!F
M;W(@=VAI8V@@=&\@<F5T=7)N('1H90H@("`@("H@("`@("`@("`@("`@("`@
M<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A
M<G)A>2!O9B!E>'1R82!I;F9O<FUA=&EO;BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T1V%T97=A>5!A<F%M<R@D9V%T97=A>2D*("`@('L*("`@("`@("!S
M=&%T:6,@)'!A<F%M<R`](&%R<F%Y*"D["B`@("`@("`@:68@*&ES<V5T*"1P
M87)A;7-;)&=A=&5W87E=*2D@>PH@("`@("`@("`@("!R971U<FX@)'!A<F%M
M<ULD9V%T97=A>5T["B`@("`@("`@?0H*("`@("`@("!R97%U:7)E7V]N8V4@
M)TYE="]335,O)R`N("1G871E=V%Y("X@)RYP:'`G.PH@("`@("`@("1C;&%S
M<R`]("=.971?4TU37R<@+B`D9V%T97=A>3L*("`@("`@("`D<&%R86US6R1G
M871E=V%Y72`](&-A;&Q?=7-E<E]F=6YC*&%R<F%Y*"1C;&%S<RP@)V=E=%!A
M<F%M<R<I*3L*"B`@("`@("`@<F5T=7)N("1P87)A;7-;)&=A=&5W87E=.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!S96YD('!A<F%M971E<G,@
M9F]R(&$@9V%T97=A>2!F<F]M('1H92!D<FEV97(@<W5B8VQA<W,*("`@("`J
M(&=E=$1E9F%U;'1396YD4&%R86US*"EF=6YC=&EO;BX@5&AE<V4@87)E('!A
M<F%M971E<G,@=VAI8V@@87)E(&%V86EL86)L90H@("`@("H@=&\@=&AE('5S
M97(@9'5R:6YG('-E;F1I;F<L('-U8V@@87,@<V5T=&EN9R!A('1I;64@9F]R
M(&1E;&EV97)Y+"!O<B!T>7!E"B`@("`@*B!O9B!335,@*&YO<FUA;"!T97AT
M(&]R(&9L87-H*2P@;W(@<V]U<F-E(&%D9')E<W,L(&5T8RX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("!4:&4@;F%M92!O9B!T:&4@9V%T97=A>2!D
M<FEV97(@9F]R('=H:6-H('1O(')E='5R;B!T:&4*("`@("`J("`@("`@("`@
M("`@("`@('-E;F0@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("!!;B!A<G)A>2!O9B!A=F%I;&%B;&4@<V5N9"!P87)A;65T97)S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971$969A=6QT4V5N9%!A<F%M<R@D
M9V%T97=A>2D*("`@('L*("`@("`@("!S=&%T:6,@)'!A<F%M<R`](&%R<F%Y
M*"D["B`@("`@("`@:68@*&ES<V5T*"1P87)A;7-;)&=A=&5W87E=*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'!A<F%M<ULD9V%T97=A>5T["B`@("`@("`@
M?0H*("`@("`@("!R97%U:7)E7V]N8V4@)TYE="]335,O)R`N("1G871E=V%Y
M("X@)RYP:'`G.PH@("`@("`@("1C;&%S<R`]("=.971?4TU37R<@+B`D9V%T
M97=A>3L*("`@("`@("`D<&%R86US6R1G871E=V%Y72`](&-A;&Q?=7-E<E]F
M=6YC*&%R<F%Y*"1C;&%S<RP@)V=E=$1E9F%U;'1396YD4&%R86US)RDI.PH*
M("`@("`@("!R971U<FX@)'!A<F%M<ULD9V%T97=A>5T["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!1=65R>2!T:&4@8W5R<F5N="!'871E=V%Y(&]B:F5C="!T
M;R!F:6YD(&]U="!I9B!I="!S=7!P;W)T<R!T:&4@9VEV96X*("`@("`J(&-A
M<&%B:6QI='DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V%P86)I
M;&ET>2`@5&AE(&-A<&%B:6QI='D@=&\@=&5S="!F;W(N"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@5VAE=&AE<B!O<B!N;W0@=&AE(&-A<&%B:6QI
M='D@:7,@<W5P<&]R=&5D(&]R(&%N>2!O=&AE<@H@("`@("H@("`@("`@("`@
M("`@("`@=F%L=64@=&AA="!T:&4@8V%P86)I;&ET>2!W:7-H97,@=&\@<F5P
M;W)T+@H@("`@("HO"B`@("!F=6YC=&EO;B!H87-#87!A8FEL:71Y*"1C87!A
M8FEL:71Y*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/F-A<&%B
M:6QI=&EE<ULD8V%P86)I;&ET>5TI*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^8V%P86)I;&ET:65S6R1C87!A8FEL:71Y73L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@075T
M:&5N=&EC871E<R!A9V%I;G-T('1H92!G871E=V%Y(&EF(')E<75I<F5D+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O
M<B!014%2($5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%U=&AE;G1I8V%T92@I"B`@("!["B`@("`@("`@+RH@1&\@875T:&5N=&EC
M871I;VX@9F]R('1H:7,@9V%T97=A>2!I9B!D<FEV97(@<F5Q=6ER97,@:70N
M("HO"B`@("`@("`@:68@*"1T:&ES+3YH87-#87!A8FEL:71Y*"=A=71H)RDI
M('L*("`@("`@("`@("`@)'1H:7,M/E]A=71H(#T@)'1H:7,M/E]A=71H96YT
M:6-A=&4H*3L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?875T:#L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!396YD<R!A(&UE<W-A9V4@=&\@;VYE(&]R(&UO<F4@<F5C:7!I96YT
M<RX@2&%N9',@;V9F('1H92!A8W1U86P@<V5N9&EN9PH@("`@("H@=&\@=&AE
M(&=A=&5W87D@9')I=F5R+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D
M;65S<V%G92`@5&AE(&UE<W-A9V4@=&\@8F4@<V5N="P@=VAI8V@@:7,@8V]M
M<&]S960@;V8Z"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(#QP<F4^
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@:60@("`M($$@=6YI
M<75E($E$(&9O<B!T:&4@;65S<V%G93L*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("!T;R`@("T@06X@87)R87D@;V8@<F5C:7!I96YT<SL*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("!T97AT("T@5&AE('1E>'0@
M;V8@=&AE(&UE<W-A9V4["B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M(#PO<')E/@H@("`@("H*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4
M<G5E(&]N('-U8V-E<W,@;W(@4$5!4B!%<G)O<B!O;B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S96YD*"8D;65S<V%G92D*("`@('L*("`@("`@
M("`O*B!!=71H96YT:6-A=&4N("HO"B`@("`@("`@:68@*&ES7V$H)'1H:7,M
M/F%U=&AE;G1I8V%T92@I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7V%U=&@["B`@("`@("`@?0H*("`@("`@("`O*B!-
M86ME('-U<F4@=&AE(')E8VEP:65N=',@87)E(&EN(&%N(&%R<F%Y+B`J+PH@
M("`@("`@(&EF("@A:7-?87)R87DH)&UE<W-A9V5;)W1O)UTI*2!["B`@("`@
M("`@("`@("1M97-S86=E6R=T;R==(#T@87)R87DH)&UE<W-A9V5;)W1O)UTI
M.PH@("`@("`@('T*"B`@("`@("`@+RH@07)R87D@=&\@<W1O<F4@96%C:"!S
M96YD+B`J+PH@("`@("`@("1S96YD<R`](&%R<F%Y*"D["@H@("`@("`@("\J
M($EF(&=A=&5W87D@<W5P<&]R=',@8F%T8V@@<V5N9&EN9RP@<')E9F5R96YC
M92!I<R!G:79E;B!T;R!T:&ES"B`@("`@("`@("H@;65T:&]D+B`J+PH@("`@
M("`@(&EF("@D;6%X7W!E<E]B871C:"`]("1T:&ES+3YH87-#87!A8FEL:71Y
M*"=B871C:"<I*2!["B`@("`@("`@("`@("\J(%-P;&ET('5P('1H92!R96-I
M<&EE;G1S(&EN('1H92!M87@@<F5C:7!I96YT<R!P97(@8F%T8V@@87,*("`@
M("`@("`@("`@("H@<W5P<&]R=&5D(&)Y(&=A=&5W87DN("HO"B`@("`@("`@
M("`@("1I36%X(#T@8V]U;G0H)&UE<W-A9V5;)W1O)UTI.PH@("`@("`@("`@
M("`D8F%T8VAE<R`](&-E:6PH)&E-87@@+R`D;6%X7W!E<E]B871C:"D["@H@
M("`@("`@("`@("`O*B!,;V]P('1H<F]U9V@@=&AE(&)A=&-H97,@86YD(&-O
M;7!O<V4@;65S<V%G97,@=&\@8F4@<V5N="X@*B\*("`@("`@("`@("`@9F]R
M("@D8B`](#`[("1B(#P@)&)A=&-H97,[("1B*RLI('L*("`@("`@("`@("`@
M("`@("1R96-I<&EE;G1S(#T@87)R87E?<VQI8V4H)&UE<W-A9V5;)W1O)UTL
M("@D8B`J("1M87A?<&5R7V)A=&-H*2P@)&UA>%]P97)?8F%T8V@I.PH@("`@
M("`@("`@("`@("`@)')E<W!O;G-E(#T@)'1H:7,M/E]S96YD*"1M97-S86=E
M+"`D<F5C:7!I96YT<RD["B`@("`@("`@("`@("`@("!F;W)E86-H("@D<F5C
M:7!I96YT<R!A<R`D<F5C:7!I96YT*2!["B`@("`@("`@("`@("`@("`@("`@
M:68@*"1R97-P;VYS95LD<F5C:7!I96YT75LP72`]/2`Q*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("\J($UE<W-A9V4@=V%S('-E;G0L('-T;W)E(')E
M;6]T92!I9"X@*B\*("`@("`@("`@("`@("`@("`@("`@("`@)')E;6]T95]I
M9"`]("1R97-P;VYS95LD<F5C:7!I96YT75LQ73L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&5R<F]R(#T@;G5L;#L*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`O*B!-97-S86=E(&9A
M:6QE9"P@<W1O<F4@97)R;W(@8V]D92X@*B\*("`@("`@("`@("`@("`@("`@
M("`@("`@)')E;6]T95]I9"`](&YU;&P["B`@("`@("`@("`@("`@("`@("`@
M("`@("1E<G)O<B`]("1R97-P;VYS95LD<F5C:7!I96YT75LQ73L*("`@("`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@("`@("\J(%-T;W)E
M('1H92!S96YD<RX@*B\*("`@("`@("`@("`@("`@("`@("`D<V5N9'-;72`]
M(&%R<F%Y*"=M97-S86=E7VED)R`]/B`D;65S<V%G95LG:60G72P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R96UO=&5?:60G("`]
M/B`D<F5M;W1E7VED+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W)E8VEP:65N="<@(#T^("1R96-I<&EE;G0L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G97)R;W(G("`@("`@/3X@)&5R
M<F]R*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("\J($YO(&)A=&-H('-E;F1I;F<@879A
M:6QA8FQE+"!J=7-T(&QO;W`@=&AR;W5G:"!A;&P@<F5C:7!I96YT<PH@("`@
M("`@("`@("`@*B!A;F0@<V5N9"!A(&UE<W-A9V4@9F]R(&5A8V@@;VYE+B`J
M+PH@("`@("`@("`@("!F;W)E86-H("@D;65S<V%G95LG=&\G72!A<R`D<F5C
M:7!I96YT*2!["B`@("`@("`@("`@("`@("`D<F5S<&]N<V4@/2`D=&AI<RT^
M7W-E;F0H)&UE<W-A9V4L("1R96-I<&EE;G0I.PH@("`@("`@("`@("`@("`@
M:68@*"1R97-P;VYS95LP72`]/2`Q*2!["B`@("`@("`@("`@("`@("`@("`@
M+RH@365S<V%G92!W87,@<V5N="P@<W1O<F4@<F5M;W1E(&ED(&EF(&%N>2X@
M*B\*("`@("`@("`@("`@("`@("`@("`D<F5M;W1E7VED(#T@*&ES<V5T*"1R
M97-P;VYS95LQ72D@/R`D<F5S<&]N<V5;,5T@.B!N=6QL*3L*("`@("`@("`@
M("`@("`@("`@("`D97)R;W(@/2!N=6QL.PH@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`O*B!-97-S86=E(&9A:6QE9"P@
M<W1O<F4@97)R;W(@8V]D92X@*B\*("`@("`@("`@("`@("`@("`@("`D<F5M
M;W1E7VED(#T@;G5L;#L*("`@("`@("`@("`@("`@("`@("`D97)R;W(@/2`D
M<F5S<&]N<V5;,5T["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@
M("`@+RH@4W1O<F4@=&AE('-E;F1S+B`J+PH@("`@("`@("`@("`@("`@)'-E
M;F1S6UT@/2!A<G)A>2@G;65S<V%G95]I9"<@/3X@)&UE<W-A9V5;)VED)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R96UO=&5?:60G
M("`]/B`D<F5M;W1E7VED+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G<F5C:7!I96YT)R`@/3X@)')E8VEP:65N="P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V5R<F]R)R`@("`@(#T^("1E<G)O<BD[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<V5N
M9',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!)9B!T:&4@8W5R<F5N="!D<FEV
M97(@:&%S(&$@8W)E9&ET(&-A<&%B:6QI='DL('%U97)I97,@=&AE(&=A=&5W
M87D@9F]R"B`@("`@*B!A(&-R961I="!B86QA;F-E(&%N9"!R971U<FYS('1H
M92!V86QU92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%9A;'5E
M(&EN9&EC871I;F<@879A:6QA8FQE(&-R961I="!O<B!N=6QL(&EF(&YO=`H@
M("`@("H@("`@("`@("`@("`@("`@("!S=7!P;W)T960N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$)A;&%N8V4H*0H@("`@>PH@("`@("`@("\J($%U=&AE
M;G1I8V%T92X@*B\*("`@("`@("!I9B`H:7-?82@D=&AI<RT^875T:&5N=&EC
M871E*"DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?875T:#L*("`@("`@("!]"@H@("`@("`@("\J($-H96-K(&)A;&%N
M8V4N("HO"B`@("`@("`@:68@*"1T:&ES+3YH87-#87!A8FEL:71Y*"=C<F5D
M:70G*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]G971"86QA;F-E
M*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@
M<F5T=7)N(&$@8V]N8W)E=&4@1V%T97=A>2!I;G-T86YC92!B87-E9"!O;B`D
M9')I=F5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1R:79E<B`@
M5&AE('1Y<&4@;V8@8V]N8W)E=&4@1V%T97=A>2!S=6)C;&%S<R!T;R!R971U
M<FXN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(%1H:7,@:7,@8F%S
M960@;VX@=&AE(&=A=&5W87D@9')I=F5R("@D9')I=F5R*2X*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@5&AE(&-O9&4@:7,@9'EN86UI8V%L;'D@
M:6YC;'5D960N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@($$@:&%S
M:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@;W(*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P87)A
M;65T97)S(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`
M<F5T=7)N($YE=%]335,@(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R971E($=A
M=&5W87D@:6YS=&%N8V4@;W(@9F%L<V4@;VX*("`@("`J("`@("`@("`@("`@
M("`@("`@86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y
M*"1D<FEV97(L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EN
M8VQU9&5?;VYC92`G3F5T+U--4R\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@
M("`@("`D8VQA<W,@/2`G3F5T7U--4U\G("X@)&1R:79E<CL*("`@("`@("!I
M9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@)'-M<R`]
M("9N97<@)&-L87-S*"1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1S;7,@/2!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B0VQA
M<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(BDL("1D<FEV97(I*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<VUS.PH@("`@?0H*("`@("\J
M*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@<F5F97)E;F-E('1O(&$@
M8V]N8W)E=&4@3F5T7U--4R!I;G-T86YC92!B87-E9"!O;@H@("`@("H@)&1R
M:79E<BX*("`@("`J"B`@("`@*B!)="!W:6QL(&]N;'D@8W)E871E(&$@;F5W
M(&EN<W1A;F-E(&EF(&YO($YE=%]335,@:6YS=&%N8V4@=VET:"!T:&4@<V%M
M90H@("`@("H@<&%R86UE=&5R<R!C=7)R96YT;'D@97AI<W1S+@H@("`@("H*
M("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH@)'9A<B`]
M("9.971?4TU3.CIS:6YG;&5T;VXH*0H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&1R:79E<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@3F5T7U--4R!S
M=6)C;&%S<R!T;R!R971U<FXN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@(%1H92!I<R!B87-E9"!O;B!T:&4@9V%T97=A>2!D<FEV97(@*"1D<FEV
M97(I+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!4:&4@8V]D92!I
M<R!D>6YA;6EC86QL>2!I;F-L=61E9"X*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N
M86P@8V]N9FEG=7)A=&EO;B!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE
M960N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&-R96%T960@
M8V]N8W)E=&4@3F5T7U--4R!I;G-T86YC92P@;W(@9F%L<V4@;VX@97)R;W(N
M"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)&1R:79E<BP@)'!A
M<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T86YC
M97,["B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S*2D@>PH@("`@("`@
M("`@("`D:6YS=&%N8V5S(#T@87)R87DH*3L*("`@("`@("!]"@H@("`@("`@
M("1S:6=N871U<F4@/2!S97)I86QI>F4H87)R87DH)&1R:79E<BP@)'!A<F%M
M<RDI.PH@("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E<ULD<VEG;F%T=7)E
M72DI('L*("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E72`]("9.
M971?4TU3.CIF86-T;W)Y*"1D<FEV97(L("1P87)A;7,I.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;)'-I9VYA='5R95T["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B].
M970O24U34"YP:'``````````````````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`S-3$T-R`Q,#4Q-30S,S<T,"`P,C`S,C0`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"FEN8VQU
M9&5?;VYC92`G3&]G+G!H<"<["@HO+R!#;VYS=&%N="!$969I;FET:6]N<PID
M969I;F4H)TE-4U!?3T-4151?0T]53E0G+"`B+RA[*2A;,"TY77LQ+'TI*%Q]
M)"DO(BD["F1E9FEN92@G24U34%]-55-47U5315],251%4D%,)RP@(B];7%==
M+VDB*3L*"B\J*@H@*B!4:&4@3F5T7TE-4U`@8VQA<W,@<')O=FED97,@82!C
M;VUM;VX@:6YT97)F86-E('1O(&%N($E-4U`@<V5R=F5R("X*("H*("H@4F5Q
M=6ER960@<&%R86UE=&5R<SH\<')E/@H@*B`@("=S97)V97(G("!(;W-T;F%M
M92!O9B!)35-0('-E<G9E<BX*("H@("`G<&]R="<@("`@4&]R="!O9B!)35-0
M('-E<G9E<BX\+W!R93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO3F5T7TE-
M4U`O24U34"YP:'`L=B`Q+C$S+C$P+C$Y(#(P,#8O,#(O,3`@,#0Z-3@Z,C8@
M<V5L<VMY($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EC:&%E
M;"!2=6)I;G-K>2`\;7)U8FEN<VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@36EC:&%E;"!2=6)I;G-K>2`\;7)U8FEN<VM`:&]R
M9&4N;W)G/@H@*B!`<&%C:V%G92!.971?24U34`H@*B\*8VQA<W,@3F5T7TE-
M4U`@>PH*("`@("\J*@H@("`@("H@4W1R:6YG(&-O;G1A:6YI;F<@;F%M92])
M4"!A9&1R97-S(&]F($E-4U`@:&]S="X*("`@("`J"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)&EM<W!?<V5R=F5R("`@("`@("`@("`@
M("`@(#T@)VQO8V%L:&]S="<["@H@("`@+RHJ"B`@("`@*B!3=')I;F<@8V]N
M=&%I;FEN9R!P;W)T(&9O<B!)35-0('-E<G9E<BX*("`@("`J"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)&EM<W!?<&]R="`@("`@("`@
M("`@("`@("`@(#T@)S0P-B<["@H@("`@+RHJ"B`@("`@*B!";V]L96%N('1O
M('-E="!I9B!W92!S:&]U;&0@=W)I=&4@=&\@82!L;V<L(&EF(&]N92!I<R!S
M970@=7`N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@
M('9A<B`D;&]G16YA8FQE9"`@("`@("`@("`@("`@("`@/2!T<G5E.PH*("`@
M("\J*@H@("`@("H@4W1R:6YG(&)U9F9E<B!C;VYT86EN:6YG('1H92!L87-T
M(')A=R!.3R!O<B!"040@<F5S<&]N<V4@9G)O;2!T:&4*("`@("`J('-E<G9E
M<BX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@
M)&QA<W1287=%<G)O<B`@("`@("`@("`@("`@/2`G)SL*"B`@("`O+R!0<FEV
M871E($1E8VQA<F%T:6]N<PH@("`@=F%R("1?8V]M;6%N9%!R969I>"`@("`@
M("`@("`@("`]("=!)SL*("`@('9A<B`D7V-O;6UA;F1#;W5N="`@("`@("`@
M("`@("`@/2`Q.PH@("`@=F%R("1?=&%G("`@("`@("`@("`@("`@("`@("`@
M("`]("<G.PH@("`@=F%R("1?<W1R96%M("`@("`@("`@("`@("`@("`@("`]
M(&YU;&P["B`@("!V87(@)%]L87-T0V]M;6%N9%1A9R`@("`@("`@("`@(#T@
M)W5N9&5F:6YE9"<["B`@("!V87(@)%]L;V=G97(@("`@("`@("`@("`@("`@
M("`@(#T@;G5L;#L*("`@('9A<B`D7VQO9U-E="`@("`@("`@("`@("`@("`@
M("`@/2!N=6QL.PH@("`@=F%R("1?;&]G3&5V96P@("`@("`@("`@("`@("`@
M("`](%!%05)?3$]'7TE.1D\["B`@("!V87(@)%]L;V="=69F97(@("`@("`@
M("`@("`@("`@("`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U
M8W1O<B!F=6YC=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A
M<F%M<R!(87-H(&-O;G1A:6YI;F<@<V5R=F5R('!A<F%M971E<G,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N($YE=%])35-0*"1P87)A;7,I"B`@("!["B`@("`@
M("`@:68@*&ES7V%R<F%Y*"1P87)A;7,I("8F("%E;7!T>2@D<&%R86US6R=S
M97)V97(G72DI('L*("`@("`@("`@("`@)'1H:7,M/FEM<W!?<V5R=F5R(#T@
M)'!A<F%M<ULG<V5R=F5R)UT["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?
M87)R87DH)'!A<F%M<RD@)B8@(65M<'1Y*"1P87)A;7-;)W!O<G0G72DI('L*
M("`@("`@("`@("`@)'1H:7,M/FEM<W!?<&]R="`]("1P87)A;7-;)W!O<G0G
M73L*("`@("`@("!]"@H@("`@?0H*("`@("\J*@H@("`@("H@26YI=&EA;&EZ
M871I;VX@9G5N8W1I;VX@=&\@8F4@8V%L;&5D(&%F=&5R(&]B:F5C="!I<R!R
M971U<FYE9"X@(%1H:7,*("`@("`J(&%L;&]W<R!E<G)O<G,@=&\@;V-C=7(@
M86YD(&YO="!B<F5A:R!T:&4@<V-R:7!T+@H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!014%27T5R<F]R(&]N(&-O;FYE
M8W1I;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@:6YI="@I"B`@
M("!["B`@("`@("`@)')E<W5L="`]("1T:&ES+3YI;7-P3W!E;B@I.PH*("`@
M("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@("`@("`D=&AI
M<RT^=W)I=&54;TQO9R@G26YI=&EA;&EZ:6YG($YE=%])35-0(&]B:F5C="XG
M+"!?7T9)3$5?7RP@7U],24Y%7U\L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@4$5!4E],3T=?24Y&3RD["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!,;V=S(&]U="!O9B!T:&4@<V5R=F5R(&%N9"!C
M;&]S97,@=&AE($E-4U`@<W1R96%M"B`@("`@*B\*("`@(&9U;F-T:6]N(&QO
M9V]U="@I"B`@("!["B`@("`@("`@)'1H:7,M/G=R:71E5&],;V<H)T-L;W-I
M;F<@24U34"!#;VYN96-T:6]N+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("!014%27TQ/1U])3D9/*3L*("`@("`@
M("`D8V]M;6%N9%]S=')I;F<@/2`G3$]'3U54)SL*("`@("`@("`D<F5S=6QT
M(#T@)'1H:7,M/FEM<W!396YD*"1C;VUM86YD7W-T<FEN9RD["B`@("`@("`@
M:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!F8VQO<V4H)'1H:7,M/E]S=')E86TI.PH@("`@("`@("`@("!R971U<FX@
M)')E<W5L=#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!F8VQO<V4H
M)'1H:7,M/E]S=')E86TI.PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!R87<@
M8V%P86)I;&ET>2!R97-P;VYS92!F<F]M('1H92!S97)V97(N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!R87<@8V%P86)I;&ET>2!R97-P
M;VYS92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V%P86)I;&ET>2@I"B`@("![
M"B`@("`@("`@)&-O;6UA;F1?<W1R:6YG(#T@)T-!4$%"24Q)5%DG.PH@("`@
M("`@("1R97-U;'0@/2`D=&AI<RT^:6US<%-E;F0H)&-O;6UA;F1?<W1R:6YG
M*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1S97)V97)?<F5S<&]N<V4@/2`D=&AI<RT^:6US<%)E
M8V5I=F4H*3L*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H(B]>7"H@0T%0
M04))3$E462\B+"`D<V5R=F5R7W)E<W!O;G-E*2D@>PH@("`@("`@("`@("`@
M("`@)&-A<&%B:6QI='D@/2!P<F5G7W)E<&QA8V4H(B]>7"H@0T%004))3$E4
M62\B+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)R<L("1S97)V97)?<F5S<&]N<V4I.PH*("`@("`@("`@("`@("`@("1S
M97)V97)?<F5S<&]N<V4@/2`D=&AI<RT^:6US<%)E8V5I=F4H*3L@+R]/2PH*
M("`@("`@("`@("`@("`@(&EF("@A)'-E<G9E<E]R97-P;VYS92`]/2`G3TLG
M*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YI;7-P17)R
M;W(H)T1I9"!N;W0@<F5C96EV92!T:&4@97AP96-T960@<F5S<&]N<V4@9G)O
M;2!T:&4@<V5R=F5R+B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=R
M:71E5&],;V<H)T-!4$%"24Q)5%D@8V]M<&QE=&5D($]+)RP@7U]&24Q%7U\L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U],24Y%
M7U\L(%!%05)?3$]'7TE.1D\I.PH@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D8V%P86)I;&ET>3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O
M(&]P96X@86X@24U34"!S;V-K970@=VET:"!T:&4@<V5R=F5R+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!014%27T5R
M<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&EM<W!/<&5N
M*"D*("`@('L*("`@("`@("`D9G`@/2!`9G-O8VMO<&5N*"1T:&ES+3YI;7-P
M7W-E<G9E<BP@)'1H:7,M/FEM<W!?<&]R="D["B`@("`@("`@:68@*"$D9G`I
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YI;7-P17)R;W(H)T-O;FYE
M8W1I;VX@=&\@24U34"!H;W-T(&9A:6QE9"XG+"!?7T9)3$5?7RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U],24Y%7U\I.PH@("`@
M("`@('T*("`@("`@("`D=&AI<RT^7W-T<F5A;2`]("1F<#L*("`@("`@("`D
M<V5R=F5R7W)E<W!O;G-E(#T@)'1H:7,M/FEM<W!296-E:79E*"D["B`@("`@
M("`@:68@*"%P<F5G7VUA=&-H*"(O7EPJ($]++R(L("1S97)V97)?<F5S<&]N
M<V4I*2!["B`@("`@("`@("`@(&9C;&]S92@D9G`I.PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/FEM<W!%<G)O<B@G1&ED(&YO="!R96-E:79E('1H92!E
M>'!E8W1E9"!R97-P;VYS92!F<F]M('1H92!S97)V97(N)RP@7U]&24Q%7U\L
M(%]?3$E.15]?*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!S96YD(&$@8V]M;6%N
M9"!T;R!T:&4@<V5R=F5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M("1C;VUM86YD5&5X="!497AT('1O('-E;F0@=&\@=&AE('-E<G9E<BX*("`@
M("`J($!P87)A;2!B;V]L96%N("1I;F-L=61E5&%G("!$971E<FUI;F5S(&EF
M(&-O;6UA;F0@=&%G(&ES('!R97!E;F1E9"X*("`@("`J($!P87)A;2!B;V]L
M96%N("`D<V5N9$-23$8@("!$971E<FUI;F5S(&EF($-23$8@:7,@87!P96YD
M960N"B`@("`@*B!`<F5T=7)N(&UI>&5D("`@5')U92!O;B!S=6-C97-S(%!%
M05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@:6US
M<%-E;F0H)&-O;6UA;F1497AT+"`D:6YC;'5D951A9SUT<G5E+"`D<V5N9$-2
M3$8]=')U92D*("`@('L*("`@("`@("`D8V]M;6%N9%]T97AT(#T@)R<["@H@
M("`@("`@(&EF("@A)'1H:7,M/E]S=')E86TI('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YI;7-P17)R;W(H)T-O;FYE8W1I;VX@=&\@24U34"!H;W-T
M(&9A:6QE9"XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"1I;F-L=61E5&%G*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M=&%G(#T@)'1H:7,M/E]G971.97AT0V]M;6%N9%1A9R@I.PH@("`@("`@("`@
M("`D8V]M;6%N9%]T97AT(#T@(B1T:&ES+3Y?=&%G("(["B`@("`@("`@?0H*
M("`@("`@("`D8V]M;6%N9%]T97AT("X]("1C;VUM86YD5&5X=#L*"B`@("`@
M("`@:68@*"1S96YD0U),1BD@>PH@("`@("`@("`@("`D8V]M;6%N9%]T97AT
M("X](")<<EQN(CL*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YW<FET951O
M3&]G*"=4;SH@)R`N("1C;VUM86YD7W1E>'0L(%]?1DE,15]?+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD[
M"@H@("`@("`@(&EF("@A9G!U=',H)'1H:7,M/E]S=')E86TL("1C;VUM86YD
M7W1E>'0I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^:6US<$5R<F]R
M*"=#;VYN96-T:6]N('1O($E-4U`@:&]S="!F86EL960N)RP@7U]&24Q%7U\L
M(%]?3$E.15]?*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296-E
M:79E<R!A('-I;F=L92!#4DQ&('1E<FUI;F%T960@<V5R=F5R(')E<W!O;G-E
M('-T<FEN9PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@)TY/)RP@)T)!
M1"<L("=/2R<L(')A=R!R97-P;VYS92!O<B!014%27T5R<F]R+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!I;7-P4F5C96EV92@I"B`@("!["B`@("`@("`@:68@
M*"$D=&AI<RT^7W-T<F5A;2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/FEM<W!%<G)O<B@G0V]N;F5C=&EO;B!T;R!)35-0(&AO<W0@9F%I;&5D+B<L
M(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@("`@("1R97-U
M;'0@/2!F9V5T<R@D=&AI<RT^7W-T<F5A;2P@-3$R*3L*("`@("`@("!I9B`H
M(21R97-U;'0I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YI;7-P17)R
M;W(H)T1I9"!N;W0@<F5C96EV92!T:&4@97AP96-T960@<F5S<&]N<V4@9G)O
M;2!T:&4@<V5R=F5R+B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@("`@
M("1M971A(#T@<W1R96%M7V=E=%]M971A7V1A=&$H)'1H:7,M/E]S=')E86TI
M.PH@("`@("`@(&EF("@D;65T85LG=&EM961?;W5T)UTI('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YI;7-P17)R;W(H)T-O;FYE8W1I;VX@=&\@24U3
M4"!H;W-T(&9A:6QE9"XG("X@)SH@0V]N;F5C=&EO;B!T:6UE9"!O=70A)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L
M(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("1S97)V97)?<F5S<&]N
M<V4@/2!T<FEM*"1R97-U;'0I.PH@("`@("`@("1T:&ES+3YW<FET951O3&]G
M*"=&<F]M.B`G("X@)'-E<G9E<E]R97-P;VYS92P@7U]&24Q%7U\L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'
M*3L*"B`@("`@("`@+RH@4&%R<V4@;W5T('1H92!R97-P;VYS93H*("`@("`@
M("`@*B!&:7)S="!M86ME('-U<F4@=&AA="!T:&ES(&ES(&YO="!F;W(@82!P
M<F5V:6]U<R!C;VUM86YD+@H@("`@("`@("`J($EF(&ET(&ES+"!I="!M96%N
M<R!W92!D:60@;F]T(')E860@86QL('1H92!S97)V97(@<F5S<&]N<V5S(&9R
M;VT*("`@("`@("`@*B!T:&4@;&%S="!C;VUM86YD+BXN<F5A9"!T:&5M(&YO
M=RP@8G5T('1H<F]W(&%N(&5R<F]R+B`J+PH@("`@("`@('=H:6QE("AP<F5G
M7VUA=&-H*"(O7B(@+B`D=&AI<RT^7VQA<W1#;VUM86YD5&%G"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@+B(O(BP@)'-E<G9E<E]R97-P;VYS92DI('L*
M("`@("`@("`@("`@)'-E<G9E<E]R97-P;VYS92`]"B`@("`@("`@("`@("`@
M("!T<FEM*&9G971S*"1T:&ES+3Y?<W1R96%M+"`U,3(I*3L*("`@("`@("`@
M("`@)'1H:7,M/FEM<W!%<G)O<B@G1&ED(&YO="!R96-E:79E('1H92!E>'!E
M8W1E9"!R97-P;VYS92!F<F]M('1H92!S97)V97(N)R`N("(Z("1S97)V97)?
M<F5S<&]N<V4B+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,
M15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("`D8W5R<F5N=%1A
M9R`]("1T:&ES+3Y?=&%G.PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"(O7B(@
M+B`D8W5R<F5N=%1A9R`N("(@3D\O(BP@)'-E<G9E<E]R97-P;VYS92DI('L*
M("`@("`@("`@("`@)'1H:7,M/FQA<W1287=%<G)O<B`]("1S97)V97)?<F5S
M<&]N<V4["B`@("`@("`@("`@(')E='5R;B`G3D\G.PH@("`@("`@('T*"B`@
M("`@("`@:68@*'!R96=?;6%T8V@H(B]>(B`N("1C=7)R96YT5&%G("X@(B!"
M040O(BP@)'-E<G9E<E]R97-P;VYS92DI('L*("`@("`@("`@("`@)'1H:7,M
M/FEM<W!%<G)O<B@G5&AE($E-4U`@<V5R=F5R(&1I9"!N;W0@=6YD97)S=&%N
M9"!Y;W5R(')E<75E<W0N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@
M("`@("`@)'1H:7,M/FQA<W1287=%<G)O<B`]("1S97)V97)?<F5S<&]N<V4[
M"B`@("`@("`@("`@(')E='5R;B`G0D%$)SL*("`@("`@("!]"@H@("`@("`@
M(&EF("AP<F5G7VUA=&-H*"(O7B(@+B`D8W5R<F5N=%1A9R`N("(@3TLO(BP@
M)'-E<G9E<E]R97-P;VYS92DI('L*("`@("`@("`@("`@<F5T=7)N("=/2R<[
M"B`@("`@("`@?0H*("`@("`@("`O*B!)9B!I="!W87,@;F]T(&$@)TY/)RP@
M)T)!1"<@;W(@)T]+)R!R97-P;VYS92P*("`@("`@("`@*B!T:&5N(&ET)W,@
M=7`@=&\@=&AE(&-A;&QI;F<@9G5N8W1I;VX@=&\@9&5C:61E"B`@("`@("`@
M("H@=VAA="!T;R!D;R!W:71H(&ET+B`J+PH@("`@("`@(')E='5R;B`D<V5R
M=F5R7W)E<W!O;G-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S
M($-23$8@=&5R;6EN871E9"!R97-P;VYS92!F<F]M('-E<G9E<B!A;F0@<W!L
M:71S(&ET(&EN=&\*("`@("`J(&%N(&%R<F%Y(&1E;&EM:71E9"!B>2!A(#QS
M<&%C93XN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2!R97-U;'0@9G)O
M;2!E>'!L;V1E*"DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-E<G9E<E)E
M<W!O;G-E0VAU;FMS*"D*("`@('L*("`@("`@("`D<V5R=F5R7W)E<W!O;G-E
M(#T*("`@("`@("`@("`@=')I;2AF9V5T<R@D=&AI<RT^7W-T<F5A;2P@-3$R
M*2D["B`@("`@("`@)&-H=6YK<R`](&5X<&QO9&4H)R`G+"`D<V5R=F5R7W)E
M<W!O;G-E*3L*("`@("`@("!R971U<FX@)&-H=6YK<SL*("`@('T*"B`@("`O
M*@H@("`@("H@4F5C96EV97,@9FEX960@;G5M8F5R(&]F(&)Y=&5S(&9R;VT@
M24U34"!S;V-K970N(%5S960@=VAE;@H@("`@("H@<V5R=F5R(')E='5R;G,@
M82!S=')I;F<@;&ET97)A;"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D;&5N9W1H("!.=6UB97(@;V8@8GET97,@=&\@<F5A9"!F<F]M('-O8VME
M="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&5X="!O9B!S=')I
M;F<@;&ET97)A;"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5C96EV95-T<FEN
M9TQI=&5R86PH)&QE;F=T:"D*("`@('L*("`@("`@("`D=&5M<"`]('1R:6TH
M9G)E860H)'1H:7,M/E]S=')E86TL("1L96YG=&@I*3L*("`@("`@("`D=&AI
M<RT^=W)I=&54;TQO9R@G1G)O;7M].B`G("X@)'1E;7`L(%]?1DE,15]?+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@(%]?3$E.15]?+"!014%27TQ/1U]$
M14)51RD["B`@("`@("`@<F5T=7)N("1T96UP.PH@("`@?0H*("`@("\J*@H@
M("`@("H@26YC<F5M96YT<R!T:&4@24U34"!C;VUM86YD('1A9R!T;VME;BX*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!R971U<FX@
M<W1R:6YG($YE>'0@8V]M;6%N9"!T86<N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]G971.97AT0V]M;6%N9%1A9R@I"B`@("!["B`@("`@("`@)'1H:7,M/E]L
M87-T0V]M;6%N9%1A9R`]("1T:&ES+3Y?=&%G(#\@)'1H:7,M/E]T86<@.B`G
M=6YD969I;F5D)SL*("`@("`@("!R971U<FX@)'1H:7,M/E]C;VUM86YD4')E
M9FEX("X@<W!R:6YT9B@G)3`T9"<L("1T:&ES+3Y?8V]M;6%N9$-O=6YT*RLI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE<R!I9B!A('-T<FEN
M9R!N965D<R!T;R!B92!Q=6]T960@8F5F;W)E('-E;F1I;F<@=&\@=&AE('-E
M<G9E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S=')I;F<@(%-T
M<FEN9R!T;R!B92!T97-T960N"B`@("`@*B!`<F5T=7)N('-T<FEN9R!/<FEG
M:6YA;"!S=')I;F<@<75O=&5D(&EF(&YE961E9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<75O=&53<&%C9613=')I;F<H)'-T<FEN9RD*("`@('L*("`@("`@
M("!I9B`H<W1R<&]S*"1S=')I;F<L("<@)RD@(3T](&9A;'-E*2!["B`@("`@
M("`@("`@(')E='5R;B`G(B<@+B`D<W1R:6YG("X@)R(G.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B`D<W1R:6YG.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J(%)A:7-E<R!A;B!)35-0(&5R<F]R+B`@
M0F%S:6-A;&QY+"!O;FQY('=R:71E<PH@("`@("H@97)R;W(@;W5T('1O('1H
M92!H;W)D92!L;V=F:6QE(&%N9"!R971U<FYS(%!%05)?17)R;W(*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1E<G(@("`@16ET:&5R(%!%05)?17)R
M;W(@;V)J96-T(&]R('1E>'0@=&\@=W)I=&4@=&\@;&]G+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D9FEL92`@($9I;&4@;F%M92!W:&5R92!E<G)O<B!O8V-U
M<F5D+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&QI;F4@($QI;F4@;G5M8F5R
M('=H97)E(&5R<F]R(&]C8W5R960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&EM
M<W!%<G)O<B@D97)R(#T@)R<L("1F:6QE/5]?1DE,15]?+"`D;&EN93U?7TQ)
M3D5?7RD*("`@('L*("`@("`@("!I9B`H:7-?82@D97)R+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("1L;V=?=&5X="`]("1E<G(M/F=E=$UE<W-A
M9V4H*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;&]G7W1E>'0@
M/2`D97)R.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/G=R:71E5&],;V<H
M)&QO9U]T97AT+"`D9FEL92P@)&QI;F4L(%!%05)?3$]'7T524BD["B`@("`@
M("`@:68@*&ES7V$H)&5R<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&5R<CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D97)R*3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!7<FET97,@82!M97-S86=E('1O('1H92!)35-0
M(&QO9V9I;&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;65S<V%G
M92`@5&5X="!T;R!W<FET92X*("`@("`J+PH@("`@9G5N8W1I;VX@=W)I=&54
M;TQO9R@D;65S<V%G92P@)&9I;&4@/2!?7T9)3$5?7RP*("`@("`@("`@("`@
M("`@("`@("`@("`@)&QI;F4@/2!?7TQ)3D5?7RP@)'!R:6]R:71Y(#T@4$5!
M4E],3T=?24Y&3RD*("`@('L*("`@("`@("!I9B`H*"1T:&ES+3YL;V=%;F%B
M;&5D*2`F)B`H)'1H:7,M/E]L;V=3970I*2!["B`@("`@("`@("`@(&EF("@D
M<')I;W)I='D@/B`D=&AI<RT^7VQO9TQE=F5L*2!["B`@("`@("`@("`@("`@
M("!R971U<FX["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1L;V=-97-S
M86=E(#T@)UMI;7-P72`G("X@)&UE<W-A9V4@+B`G(%MO;B!L:6YE("<@+B`D
M;&EN92`N("<@;V8@(B<@+B`D9FEL92`N("<B72<["B`@("`@("`@("`@("1T
M:&ES+3Y?;&]G9V5R+3YL;V<H)&QO9TUE<W-A9V4L("1P<FEO<FET>2D["B`@
M("`@("`@?2!E;'-E:68@*"@A)'1H:7,M/E]L;V=3970I("8F("@D=&AI<RT^
M;&]G16YA8FQE9"DI('L*("`@("`@("`@("`@)'1H:7,M/E]L;V="=69F97);
M72`](&%R<F%Y*"=M97-S86=E)R`@/3X@)&UE<W-A9V4L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<')I;W)I='DG(#T^("1P
M<FEO<FET>2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=F:6QE)R`@("`@/3X@)&9I;&4L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G;&EN92<@("`@(#T^("1L:6YE"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@82!N97<@3&]G(&]B
M:F5C="!B87-E9"!O;B`D<&%R86US"B`@("`@*@H@("`@("H@0'!A<F%M("!A
M<G)A>2`@)'!A<F%M<R!,;V<@;V)J96-T('!A<F%M971E<G,N"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@4$5!4E]%<G)O<B!O
M;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971,;V=G97(H)'!A
M<F%M<RD*("`@('L*("`@("`@("`D=&AI<RT^7VQO9TQE=F5L(#T@)'!A<F%M
M<ULG<')I;W)I='DG73L*("`@("`@("`D;&]G9V5R(#T@)DQO9SHZ<VEN9VQE
M=&]N*"1P87)A;7-;)W1Y<&4G72P@)'!A<F%M<ULG;F%M92==+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<ULG:61E;G0G72P@
M)'!A<F%M<ULG<&%R86US)UTI.PH@("`@("`@("1T:&ES+3Y?;&]G4V5T(#T@
M=')U93L*"B`@("`@("`@:68@*&ES7V$H)&QO9V=E<BP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^;&]G16YA8FQE9"`](&9A;'-E.PH@
M("`@("`@("`@("!R971U<FX@)&QO9V=E<CL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D=&AI<RT^7VQO9V=E<B`]("8D;&]G9V5R.PH@("`@("`@
M("`@("`D=&AI<RT^;&]G16YA8FQE9"`]('1R=64["B`@("`@("`@("`@("1T
M:&ES+3Y?=W)I=&5,;V="=69F97(H*3L*("`@("`@("`@("`@<F5T=7)N('1R
M=64["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@5W)I=&5S(&]U
M="!C;VYT96YT<R!O9B`D7VQO9T)U9F9E<B!T;R!L;V<@9FEL92X@($%L;&]W
M<R!M97-S86=E<PH@("`@("H@=&\@8F4@;&]G9V5D(&1U<FEN9R!I;FET:6%L
M:7IA=&EO;B!O9B!O8FIE8W0@8F5F;W)E($QO9R!O8FIE8W0@:7,*("`@("`J
M(&EN<W1A;G1I871E9"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J+PH@("`@9G5N8W1I;VX@7W=R:71E3&]G0G5F9F5R*"D*("`@('L*
M("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D=&AI<RT^7VQO9T)U
M9F9E<BD[("1I*RLI('L*("`@("`@("`@("`@)'1H:7,M/G=R:71E5&],;V<H
M)'1H:7,M/E]L;V="=69F97);)&E=6R=M97-S86=E)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;&]G0G5F9F5R6R1I75LG9FEL
M92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VQO
M9T)U9F9E<ELD:5U;)VQI;F4G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]L;V="=69F97);)&E=6R=P<FEO<FET>2==*3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!C<F5A
M=&4@82!.971?24U34"!O8FIE8W0@8F%S960@;VX@)&1R:79E<BX*("`@("`J
M($UU<W0@8F4@8V%L;&5D(&%S("1I;7-P(#T@)DYE=%])35-0.CIF86-T;W)Y
M*"1D<FEV97(L("1P87)A;7,I.PH@("`@("H*("`@("`J($!P87)A;2`@<W1R
M:6YG("1D<FEV97(@5'EP92!O9B!.971?24U34"!O8FIE8W0@=&\@<F5T=7)N
M+@H@("`@("H@0'!A<F%M("!M:7AE9"`@)'!A<F%M<R`@06YY('!A<F%M971E
M<G,@;F5E9&5D(&)Y('1H92!.971?24U34"!O8FIE8W0N"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!4:&4@<F5Q=65S=&5D($YE=%])35-0(&]B:F5C="!O<B!0
M14%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9F
M86-T;W)Y*"1D<FEV97(L("1P87)A;7,I"B`@("!["B`@("`@("`@)&1R:79E
M<B`](&)A<V5N86UE*"1D<FEV97(I.PH@("`@("`@(&EF("AE;7!T>2@D9')I
M=F5R*2!\?"`D9')I=F5R(#T]("=N;VYE)RD@>PH@("`@("`@("`@("`D:6US
M<"`]("9N97<@3F5T7TE-4U`H)'!A<F%M<RD["B`@("`@("`@("`@(')E='5R
M;B`D:6US<#L*("`@("`@("!]"@H@("`@("`@(&EN8VQU9&5?;VYC92!D:7)N
M86UE*%]?1DE,15]?*2`N("<O24U34"\G("X@)&1R:79E<B`N("<N<&AP)SL*
M("`@("`@("`D8VQA<W,@/2`G3F5T7TE-4U!?)R`N("1D<FEV97(["B`@("`@
M("`@:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1I
M;7-P(#T@)FYE=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@("`@(')E='5R
M;B`D:6US<#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!(;W)D93HZ
M9F%T86PH4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E5N86)L92!T;R!L
M;V%D('1H92!D969I;FET:6]N(&]F("5S+B(I+"`D8VQA<W,I*2P@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!='1E;7!T<R!T;R!R971U<FX@82!.971?24U34"!O8FIE8W0@8F%S960@
M;VX@)&1R:79E<BX@($]N;'D*("`@("`J(&-R96%T97,@82!N97<@;V)J96-T
M(&EF(&]N92!W:71H('1H92!S86UE('!A<F%M971E<G,@86QR96%D>0H@("`@
M("H@9&]E<VXG="!E>&ES="X*("`@("`J($UU<W0@8F4@8V%L;&5D(&%S("1I
M;7-P(#T@)DYE=%])35-0.CIS:6YG;&5T;VXH)&1R:79E<BP@)'!A<F%M<RD[
M"B`@("`@*@H@("`@("H@0'!A<F%M("!S=')I;F<@)&1R:79E<B!4>7!E(&]F
M($YE=%])35-0(&]B:F5C="!T;R!R971U<FXN"B`@("`@*B!`<&%R86T@(&UI
M>&5D("`D<&%R86US($%N>2!P87)A;65T97)S(&YE961E9"!B>2!T:&4@3F5T
M7TE-4U`@;V)J96-T+@H@("`@("H@0')E='5R;B!M:7AE9"`@4F5F97)E;F-E
M('1O('1H92!.971?24U34"!O8FIE8W0@;W(@4$5!4E]%<G)O<B!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1D<FEV97(L
M("1P87)A;7,I"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T86YC97,["B`@
M("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S*2D@>PH@("`@("`@("`@("`D
M:6YS=&%N8V5S(#T@87)R87DH*3L*("`@("`@("!]"@H@("`@("`@("1S:6=N
M871U<F4@/2!S97)I86QI>F4H87)R87DH)&1R:79E<BP@)'!A<F%M<RDI.PH@
M("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E<ULD<VEG;F%T=7)E72DI('L*
M("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E72`]("9.971?24U3
M4#HZ9F%C=&]R>2@D9')I=F5R+"`D<&%R86US*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D:6YS=&%N8V5S6R1S:6=N871U<F5=.PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+V)A<V4N<&AP````````
M````````````````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S
M-#8T(#$P-3$U-#,S-S0P(#`Q-S<S-0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@2&]R9&4@8F%S92!I
M;F-L=7-I;VX@9FEL92X*("H*("H@5&AI<R!F:6QE(&)R:6YG<R!I;B!A;&P@
M;V8@=&AE(&1E<&5N9&5N8VEE<R!T:&%T($AO<F1E"B`J(&9R86UE=V]R:RUL
M979E;"!S8W)I<'1S('=I;&P@;F5E9"P@86YD('-E=',@=7`@;V)J96-T<R!T
M:&%T(&%L;`H@*B!S8W)I<'1S('5S92X*("H*("H@3F]T93H@5&AI<R!B87-E
M(&9I;&4@9&]E<R!?;F]T7R!C:&5C:R!A=71H96YT:6-A=&EO;BP@<V\@87,@
M=&\*("H@879O:60@86X@:6YF:6YI=&4@;&]O<"!O;B!T:&4@2&]R9&4@;&]G
M:6X@<&%G92X@66]U)VQL(&YE960@=&\@9&\*("H@:70@>6]U<G-E;&8@:6X@
M9G)A;65W;W)K+6QE=F5L('!A9V5S+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VQI
M8B]B87-E+G!H<"QV(#$N-#`N,3`N,R`R,#`V+S`Q+S`Q(#(Q.C(Y.C`U(&IA
M;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N
M8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@HO+R!#
M:&5C:R!F;W(@82!P<FEO<B!D969I;FET:6]N(&]F($A/4D1%7T)!4T4@*'!E
M<FAA<',@8GD@86X*+R\@875T;U]P<F5P96YD7V9I;&4@9&5F:6YI=&EO;B!F
M;W(@<VET92!C=7-T;VUI>F%T:6]N*2X*:68@*"%D969I;F5D*"=(3U)$15]"
M05-%)RDI('L*("`@($!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?
M1DE,15]?*2`N("<O+BXG*3L*?0H*+R\@3&]A9"!T:&4@2&]R9&4@1G)A;65W
M;W)K(&-O<F4L(&%N9"!S970@=7`@:6YC;'5S:6]N('!A=&AS+@IR97%U:7)E
M7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V-O<F4N<&AP)SL*"B\O(%)E9VES
M=')Y+@HD<V5S<VEO;E]C;VYT<F]L(#T@571I;#HZ;F]N26YP=71687(H)W-E
M<W-I;VY?8V]N=')O;"<I.PII9B`H)'-E<W-I;VY?8V]N=')O;"`]/2`G;F]N
M92<I('L*("`@("1R96=I<W1R>2`]("9296=I<W1R>3HZ<VEN9VQE=&]N*$A/
M4D1%7U-%4U-)3TY?3D].12D["GT@96QS96EF("@D<V5S<VEO;E]C;VYT<F]L
M(#T]("=R96%D;VYL>2<I('L*("`@("1R96=I<W1R>2`]("9296=I<W1R>3HZ
M<VEN9VQE=&]N*$A/4D1%7U-%4U-)3TY?4D5!1$].3%DI.PI](&5L<V4@>PH@
M("`@)')E9VES=')Y(#T@)E)E9VES=')Y.CIS:6YG;&5T;VXH*3L*?0II9B`H
M:7-?82@H)'!U<VAE9"`]("1R96=I<W1R>2T^<'5S:$%P<"@G:&]R9&4G+"`A
M9&5F:6YE9"@G05542%](04Y$3$52)RDI*2P@)U!%05)?17)R;W(G*2D@>PH@
M("`@:68@*"1P=7-H960M/F=E=$-O9&4H*2`]/2`G<&5R;6ES<VEO;E]D96YI
M960G*2!["B`@("`@("`@2&]R9&4Z.F%U=&AE;G1I8V%T:6]N1F%I;'5R95)E
M9&ER96-T*"D["B`@("!]"B`@("!(;W)D93HZ9F%T86PH)'!U<VAE9"P@7U]&
M24Q%7U\L(%]?3$E.15]?+"!F86QS92D["GT*)&-O;F8@/2`F)$=,3T)!3%-;
M)V-O;F8G73L*0&1E9FEN92@G2$]21$5?5$5-4$Q!5$53)RP@)')E9VES=')Y
M+3YG970H)W1E;7!L871E<R<I*3L*"B\O($YO=&EF:6-A=&EO;B!3>7-T96TN
M"B1N;W1I9FEC871I;VX@/2`F3F]T:69I8V%T:6]N.CIS:6YG;&5T;VXH*3L*
M)&YO=&EF:6-A=&EO;BT^871T86-H*"=S=&%T=7,G*3L*"B\J(%-E="!U<"!T
M:&4@;65N=2X@*B\*<F5Q=6ER95]O;F-E("=(;W)D92]-96YU+G!H<"<["B1M
M96YU(#T@)FYE=R!-96YU*"D["@HO+R!#;VUP<F5S<R!O=71P=70*2&]R9&4Z
M.F-O;7!R97-S3W5T<'5T*"D["@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]497-T+G!H<```````````````
M````````````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`U-#<S,B`Q
M,#4Q-30S,S<T,"`P,3<W-#8`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*"B\J*@H@*B!$969I;F4@2$]21$5?0D%3
M12P@:68@:70@:7,@;F]T(&%L<F5A9'D@<V5T+"!A;F0@:6YC;'5D92!T:&4@
M;6%I;@H@*B!(;W)D92!L:6)R87)Y+"!S:6YC92!W92!R97%U:7)E(&ET(&9O
M<B!T:&ES('!A8VMA9V4@=&\@9G5N8W1I;VXN"B`J+PII9B`H(61E9FEN960H
M)TA/4D1%7T)!4T4G*2D@>PH@("`@9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER
M;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD["GT*<F5Q=6ER95]O;F-E($A/4D1%
M7T)!4T4@+B`G+VQI8B]C;W)E+G!H<"<["@HO*BH*("H@4V5T('1H92!P871H
M('1O('1H92!T96UP;&%T97,@;F5E9&5D(&9O<B!T97-T:6YG(&]U='!U="X*
M("HO"F1E9FEN92@G5$535%]414U03$%415,G+"!(3U)$15]"05-%("X@)R]T
M96UP;&%T97,O=&5S="\G*3L*"B\J($EF(&=E='1E>'0@:7,@;F]T(&QO861E
M9"P@9&5F:6YE(&$@9'5M;7D@7R@I(&9U;F-T:6]N('-O('1H870*("H@:6YC
M;'5D:6YG(&%N>2!F:6QE('=I=&@@9V5T=&5X="!S=')I;F=S('=O;B=T(&-A
M=7-E(&$@9F%T86P@97)R;W(L"B`J(&-A=7-I;F<@=&5S="YP:'`@=&\@<F5T
M=7)N(&$@8FQA;FL@<&%G92X@*B\*:68@*"%F=6YC=&EO;E]E>&ES=',H)U\G
M*2D@>PH@("`@9G5N8W1I;VX@7R@D<RD@>R!R971U<FX@)',[('T*?0H*+RHJ
M"B`J(%1H92!(;W)D95]497-T.CH@8VQA<W,@<')O=FED97,@9G5N8W1I;VYS
M('5S960@:6X@=&AE('1E<W0@<V-R:7!T<PH@*B!U<V5D(&EN('1H92!V87)I
M;W5S(&%P<&QI8V%T:6]N<R`H=&5S="YP:'`I+@H@*@H@*B`D2&]R9&4Z(&AO
M<F1E+VQI8B]497-T+G!H<"QV(#$N,S$N-"XQ.2`R,#`V+S`S+S(X(#$R.C,Q
M.C$S(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H87)L
M97,@2BX@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H
M="`Q.3DY+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H@0V]P
M>7)I9VAT(#(P,#(M,C`P-B!"<F5N="!*+B!.;W)D<75I<W0@/&)J;D!H;W)D
M92YO<F<^"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EC:&%E;"!3;'5S87)Z
M(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*B!`875T:&]R("!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@
M*B!`875T:&]R("!"<F5N="!*+B!.;W)D<75I<W0@/&)J;D!H;W)D92YO<F<^
M"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M
M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K
M86=E($AO<F1E7U1E<W0*("HO"F-L87-S($AO<F1E7U1E<W0@>PH*("`@("\J
M*@H@("`@("H@07)R87D@=&AA="!H;VQD<R!T:&4@;&ES="!O9B!(;W)D92!A
M<'!L:6-A=&EO;G,N"B`@("`@*B`H3&]A9&5D(&9R;VT@8V]N9FEG+W)E9VES
M=')Y+G!H<"D*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@
M('9A<B`D87!P;&EC871I;VYS(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J
M($-A8VAE9"!R97-U;'1S(&]F(&=E=$%P<&QI8V%T:6]N<R@I+@H@("`@("H*
M("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?87!P;W5T<'5T
M(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1H92!02%`@=F5R<VEO;B!O
M9B!T:&4@<WES=&5M+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1?<&AP=F5R.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T
M;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7U1E<W0H*0H@("`@>PH@
M("`@("`@(&EN8VQU9&5?;VYC92!(3U)$15]"05-%("X@)R]C;VYF:6<O<F5G
M:7-T<GDN<&AP)SL*("`@("`@("!K<V]R="@D=&AI<RT^87!P;&EC871I;VYS
M*3L*"B`@("`@("`@+RH@4W1O<F4@=&AE(%!(4"!V97)S:6]N(&EN9F]R;6%T
M:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?<&AP=F5R(#T@)'1H:7,M/G-P;&ET
M4$A05F5R<VEO;BAP:'!V97)S:6]N*"DI.PH*("`@("`@("`O*B!792!W86YT
M('1O(&)E(&%S('9E<F)O<V4@87,@<&]S<VEB;&4@:&5R92X@*B\*("`@("`@
M("!E<G)O<E]R97!O<G1I;F<H15]!3$PI.PH*("`@("`@("`O*B!3970@8VAA
M<F%C=&5R(&5N8V]D:6YG+B`J+PH@("`@("`@(&AE861E<B@G0V]N=&5N="UT
M>7!E.B!T97AT+VAT;6P[(&-H87)S970]=71F+3@G*3L*("`@("`@("!H96%D
M97(H)U9A<GDZ($%C8V5P="U,86YG=6%G92<I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4&%R<V4@4$A0('9E<G-I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=F5R<VEO;B`@02!02%`M<W1Y;&4@=F5R<VEO;B!S=')I;F<@
M*%@N6"Y8*2X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@(%1H92!P87)S
M960@<W1R:6YG+@H@("`@("H@("`@("`@("`@("`@("!+97ES.B`G;6%J;W(G
M+"`G;6EN;W(G+"`G<W5B;6EN;W(G+"`G8VQA<W,G"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-P;&ET4$A05F5R<VEO;B@D=F5R<VEO;BD*("`@('L*("`@("`@
M("`O*B!&:7)S="!P:6-K(&]F9B!M86IO<B!V97)S:6]N+"!A;F0@;&]W97(M
M8V%S92!T:&4@<F5S="X@*B\*("`@("`@("!I9B`H*'-T<FQE;B@D=F5R<VEO
M;BD@/CT@,RD@)B8@*"1V97)S:6]N6S%=(#T]("<N)RDI('L*("`@("`@("`@
M("`@)'!H<'9E<ELG;6%J;W(G72`]('-U8G-T<B@D=F5R<VEO;BP@,"P@,RD[
M"B`@("`@("`@("`@("1V97)S:6]N(#T@<W5B<W1R*'-T<G1O;&]W97(H)'9E
M<G-I;VXI+"`S*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<&AP
M=F5R6R=M86IO<B==(#T@)'9E<G-I;VX["B`@("`@("`@("`@("1P:'!V97);
M)V-L87-S)UT@/2`G=6YK;F]W;B<["B`@("`@("`@("`@(')E='5R;B`D<&AP
M=F5R.PH@("`@("`@('T*"B`@("`@("`@:68@*"1V97)S:6]N6S!=(#T]("<N
M)RD@>PH@("`@("`@("`@("`D=F5R<VEO;B`]('-U8G-T<B@D=F5R<VEO;BP@
M,2D["B`@("`@("`@?0H*("`@("`@("`O*B!.97AT+"!D971E<FUI;F4@:68@
M=&AI<R!I<R`T+C!B(&]R(#0N,')C.R!I9B!S;RP@=&AE<F4@:7,@;F\*("`@
M("`@("`@("!M:6YO<BP@=&AE(')E<W0@:7,@=&AE('-U8FUI;F]R+"!A;F0@
M8VQA<W,@:7,@<V5T('1O(&)E=&$N("HO"B`@("`@("`@)',@/2!S=')S<&XH
M)'9E<G-I;VXL("<P,3(S-#4V-S@Y)RD["B`@("`@("`@:68@*"1S(#T](#`I
M('L*("`@("`@("`@("`@)'!H<'9E<ELG<W5B;6EN;W(G72`]("1V97)S:6]N
M.PH@("`@("`@("`@("`D<&AP=F5R6R=C;&%S<R==(#T@)V)E=&$G.PH@("`@
M("`@("`@("!R971U<FX@)'!H<'9E<CL*("`@("`@("!]"@H@("`@("`@("\J
M($]T:&5R=VES92P@=&AI<R!I<R!N;VXM8F5T83L@('1H92!N=6UE<FEC('!A
M<G0@:7,@=&AE(&UI;F]R+`H@("`@("`@("`@('1H92!R97-T(&ES(&5I=&AE
M<B!A(&-L87-S:69I8V%T:6]N("AD978L(&-V<RD@;W(@82!S=6)M:6YO<@H@
M("`@("`@("`@('9E<G-I;VX@*')C/'@^+"!P;#QX/BDN("HO"B`@("`@("`@
M)'!H<'9E<ELG;6EN;W(G72`]('-U8G-T<B@D=F5R<VEO;BP@,"P@)',I.PH@
M("`@("`@(&EF("@H<W1R;&5N*"1V97)S:6]N*2`^("1S*2`F)@H@("`@("`@
M("`@("`H*"1V97)S:6]N6R1S72`]/2`G+B<I('Q\("@D=F5R<VEO;ELD<UT@
M/3T@)RTG*2DI('L*("`@("`@("`@("`@)',K*SL*("`@("`@("!]"B`@("`@
M("`@)'!H<'9E<ELG<W5B;6EN;W(G72`]('-U8G-T<B@D=F5R<VEO;BP@)',I
M.PH@("`@("`@(&EF("@H)'!H<'9E<ELG<W5B;6EN;W(G72`]/2`G8W9S)RD@
M?'P*("`@("`@("`@("`@*"1P:'!V97);)W-U8FUI;F]R)UT@/3T@)V1E=B<I
M('Q\"B`@("`@("`@("`@("AS=6)S='(H)'!H<'9E<ELG<W5B;6EN;W(G72P@
M,"P@,BD@/3T@)W)C)RDI('L*("`@("`@("`@("`@=6YS970H)'!H<'9E<ELG
M<W5B;6EN;W(G72D["B`@("`@("`@("`@("1P:'!V97);)V-L87-S)UT@/2`G
M9&5V)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H(21P:'!V
M97);)W-U8FUI;F]R)UTI('L*("`@("`@("`@("`@("`@('5N<V5T*"1P:'!V
M97);)W-U8FUI;F]R)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1P
M:'!V97);)V-L87-S)UT@/2`G<F5L96%S92<["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)'!H<'9E<CL*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K
M('1H92!L:7-T(&]F(%!(4"!M;V1U;&5S+@H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D;6]D;&ES="`@5&AE(&UO9'5L92!L:7-T+@H@("`@("H@/'!R
M93X*("`@("`J($M%63H@("!M;V1U;&4@;F%M90H@("`@("H@5D%,544Z($5I
M=&AE<B!T:&4@9&5S8W)I<'1I;VX@;W(@86X@87)R87D@=VET:"!T:&4@9F]L
M;&]W:6YG(&5N=')I97,Z"B`@("`@*B`@("`@("`@)V1E<V-R:7`G("`M+2`@
M36]D=6QE($1E<V-R:7!T:6]N"B`@("`@*B`@("`@("`@)V5R<F]R)R`@("`M
M+2`@17)R;W(@365S<V%G90H@("`@("H@("`@("`@("=P:'!V97(G("`@+2T@
M(%1H92!02%`@=F5R<VEO;B!A8F]V92!W:&EC:"!T;R!D;R!T:&4@=&5S=`H@
M("`@("H@/"]P<F4^"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!(5$U,(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I;VX@<&AP36]D=6QE
M0VAE8VLH)&UO9&QI<W0I"B`@("!["B`@("`@("`@)&]U='!U="`]("<G.PH@
M("`@("`@("1O=71P=71?87)R87D@/2!A<G)A>2@I.PH*("`@("`@("!F;W)E
M86-H("@D;6]D;&ES="!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@
M)&5R<F]R7VUS9R`]("1M;V1?=&5S="`]("1S=&%T=7-?;W5T(#T@)&9A=&%L
M(#T@;G5L;#L*("`@("`@("`@("`@)&5N=')Y(#T@87)R87DH*3L*"B`@("`@
M("`@("`@(&EF("AI<U]A<G)A>2@D=F%L*2D@>PH@("`@("`@("`@("`@("`@
M)&1E<V-R:7`@/2`D=F%L6R=D97-C<FEP)UT["B`@("`@("`@("`@("`@("`D
M9F%T86P@/2`A96UP='DH)'9A;%LG9F%T86PG72D["B`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)'9A;%LG<&AP=F5R)UTI("8F"B`@("`@("`@("`@("`@
M("`@("`@*'9E<G-I;VY?8V]M<&%R92AP:'!V97)S:6]N*"DL("1V86Q;)W!H
M<'9E<B==*2`]/2`M,2DI('L*("`@("`@("`@("`@("`@("`@("`D;6]D7W1E
M<W0@/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@("1S=&%T=7-?;W5T(#T@
M)TXO02<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)'9A;%LG97)R;W(G72DI('L*("`@("`@("`@("`@("`@("`@("`D
M97)R;W)?;7-G(#T@)'9A;%LG97)R;W(G73L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1D97-C<FEP
M(#T@)'9A;#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*&ES7VYU
M;&PH)'-T871U<U]O=70I*2!["B`@("`@("`@("`@("`@("`D;6]D7W1E<W0@
M/2!E>'1E;G-I;VY?;&]A9&5D*"1K97DI.PH@("`@("`@("`@("`@("`@)'-T
M871U<U]O=70@/2`D=&AI<RT^7W-T871U<R@D;6]D7W1E<W0L("1F871A;"D[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1E;G1R>5M=(#T@)&1E<V-R
M:7`["B`@("`@("`@("`@("1E;G1R>5M=(#T@)'-T871U<U]O=70["@H@("`@
M("`@("`@("!I9B`H(6ES7VYU;&PH)&5R<F]R7VUS9RD@)B8@(21M;V1?=&5S
M="D@>PH@("`@("`@("`@("`@("`@)&5N=')Y6UT@/2`D97)R;W)?;7-G.PH@
M("`@("`@("`@("`@("`@:68@*"$D9F%T86PI('L*("`@("`@("`@("`@("`@
M("`@("`D96YT<GE;72`](#$["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("1O=71P=70@+CT@)'1H:7,M/E]O=71P=71,
M:6YE*"1E;G1R>2D["@H@("`@("`@("`@("!I9B`H)&9A=&%L("8F("$D;6]D
M7W1E<W0I('L*("`@("`@("`@("`@("`@(&5C:&\@)&]U='!U=#L*("`@("`@
M("`@("`@("`@(&5X:70["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D;W5T<'5T.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE
M8VMS('1H92!L:7-T(&]F(%!(4"!S971T:6YG<RX*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)&UO9&QI<W0@(%1H92!S971T:6YG<R!L:7-T+@H@("`@
M("H@/&-O9&4^"B`@("`@*B!+15DZ("`@<V5T=&EN9R!N86UE"B`@("`@*B!6
M04Q513H@06X@87)R87D@=VET:"!T:&4@9F]L;&]W:6YG(&5N=')I97,Z"B`@
M("`@*B`@("`@("`@)V5R<F]R)R`@("`M+2`@17)R;W(@365S<V%G90H@("`@
M("H@("`@("`@("=S971T:6YG)R`@+2T@($)O;VQE86X@+2!S:&]U;&0@=&AE
M('-E='1I;F<@8F4@;VX@;W(@;V9F"B`@("`@*B`\+V-O9&4^"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!(5$U,(&]U='!U="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<&AP4V5T=&EN9T-H96-K*"1S971T:6YG<U]L:7-T
M*0H@("`@>PH@("`@("`@("1O=71P=70@/2`G)SL*"B`@("`@("`@9F]R96%C
M:"`H)'-E='1I;F=S7VQI<W0@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@
M("`@("1E;G1R>2`](&%R<F%Y*"D["B`@("`@("`@("`@("1R97-U;'0@/2`H
M:6YI7V=E="@D:V5Y*2`]/2`D=F%L6R=S971T:6YG)UTI.PH*("`@("`@("`@
M("`@)&5N=')Y6UT@/2`D:V5Y("X@)R`G("X@*"@D=F%L6R=S971T:6YG)UT@
M/3T]('1R=64I(#\@)V5N86)L960G(#H@)V1I<V%B;&5D)RD["B`@("`@("`@
M("`@("1E;G1R>5M=(#T@)'1H:7,M/E]S=&%T=7,H)')E<W5L="D["@H@("`@
M("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@("`@("1E;G1R
M>5M=(#T@)'9A;%LG97)R;W(G73L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@)&]U='!U="`N/2`D=&AI<RT^7V]U='!U=$QI;F4H)&5N=')Y*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D;W5T<'5T.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0VAE8VL@=&AE(&QI<W0@;V8@4$5!4B!M;V1U;&5S+@H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D<&5A<E]L:7-T("!4:&4@4$5!4B!M
M;V1U;&4@;&ES="X*("`@("`J(#QP<F4^"B`@("`@*B!+15DZ("`@4$5!4B!C
M;&%S<R!N86UE"B`@("`@*B!604Q513H@06X@87)R87D@=VET:"!T:&4@9F]L
M;&]W:6YG(&5N=')I97,Z"B`@("`@*B`@("`@("`@)V1E<&5N9',G("`@+2T@
M(%1H:7,@;6]D=6QE(&1E<&5N9',@;VX@86YO=&AE<B!M;V1U;&4*("`@("`J
M("`@("`@("`G97)R;W(G("`@("`M+2`@17)R;W(@365S<V%G90H@("`@("H@
M("`@("`@("=F=6YC=&EO;B<@("TM("!2969E<F5N8V4@=&\@9G5N8W1I;VX@
M=&\@<G5N(&EF(&UO9'5L92!I<R!F;W5N9`H@("`@("H@("`@("`@("=P871H
M)R`@("`@("TM("!4:&4@<&%T:"!T;R!T:&4@4$5!4B!M;V1U;&4*("`@("`J
M("`@("`@("`G<F5Q=6ER960G("`M+2`@27,@=&AI<R!014%2(&UO9'5L92!R
M97%U:7)E9#\@*&)O;VQE86XI"B`@("`@*B`\+W!R93X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE($A434P@;W5T<'5T+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!014%236]D=6QE0VAE8VLH)'!E87)?;&ES="D*("`@('L*
M("`@("`@("`D;W5T<'5T(#T@)R<["@H@("`@("`@("\J(%1U<FX@=')A8VMI
M;F<@;V8@97)R;W)S(&]N+B`J+PH@("`@("`@(&EN:5]S970H)W1R86-K7V5R
M<F]R<R<L(#$I.PH*("`@("`@("`O*B!0<FEN="!T:&4@:6YC;'5D95]P871H
M+B`J+PH@("`@("`@("1O=71P=70@+CT@)'1H:7,M/E]O=71P=71,:6YE*&%R
M<F%Y*"(\<W1R;VYG/E!%05(@4V5A<F-H(%!A=&@@*%!(4"=S(&EN8VQU9&5?
M<&%T:"D\+W-T<F]N9SXB+"`G)FYB<W`[/'1T/B<@+B!I;FE?9V5T*"=I;F-L
M=61E7W!A=&@G*2`N("<\+W1T/B<I*3L*"B`@("`@("`@+RH@0VAE8VL@9F]R
M(%!%05(@:6X@9V5N97)A;"X@*B\*("`@("`@("!["B`@("`@("`@("`@("1E
M;G1R>2`](&%R<F%Y*"D["B`@("`@("`@("`@("1E;G1R>5M=(#T@)U!%05(G
M.PH@("`@("`@("`@("!`:6YC;'5D95]O;F-E("=014%2+G!H<"<["B`@("`@
M("`@("`@("1E;G1R>5M=(#T@)'1H:7,M/E]S=&%T=7,H(6ES<V5T*"1P:'!?
M97)R;W)M<V<I*3L*("`@("`@("`@("`@:68@*&ES<V5T*"1P:'!?97)R;W)M
M<V<I*2!["B`@("`@("`@("`@("`@("`D96YT<GE;72`]("=#:&5C:R!Y;W5R
M(%!(4"!I;F-L=61E7W!A=&@@<V5T=&EN9R!T;R!M86ME('-U<F4@:70@:&%S
M('1H92!014%2(&QI8G)A<GD@9&ER96-T;W)Y+B<["B`@("`@("`@("`@("`@
M("`D;W5T<'5T("X]("1T:&ES+3Y?;W5T<'5T3&EN92@D96YT<GDI.PH@("`@
M("`@("`@("`@("`@:6YI7W)E<W1O<F4H)W1R86-K7V5R<F]R<R<I.PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1O=71P=70["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)&]U='!U="`N/2`D=&AI<RT^7V]U='!U=$QI;F4H)&5N=')Y
M*3L*("`@("`@("!]"@H@("`@("`@("\J($-H96-K(&9O<B!A(')E8V5N="!0
M14%2('9E<G-I;VXN("HO"B`@("`@("`@)&5N=')Y(#T@87)R87DH*3L*("`@
M("`@("`D;F5W<&5A<B`]("1T:&ES+3YI<U)E8V5N=%!%05(H*3L*("`@("`@
M("`D96YT<GE;72`]("=296-E;G0@4$5!4B<["B`@("`@("`@)&5N=')Y6UT@
M/2`D=&AI<RT^7W-T871U<R@D;F5W<&5A<BD["B`@("`@("`@:68@*"$D;F5W
M<&5A<BD@>PH@("`@("`@("`@("`D96YT<GE;72`]("=4:&ES('9E<G-I;VX@
M;V8@4$5!4B!I<R!N;W0@<F5C96YT(&5N;W5G:"X@4V5E('1H92`\82!H<F5F
M/2)H='1P.B\O=W=W+FAO<F1E+F]R9R]P96%R+R(^2&]R9&4@4$5!4B!P86=E
M/"]A/B!F;W(@9&5T86EL<RXG.PH@("`@("`@('T*("`@("`@("`D;W5T<'5T
M("X]("1T:&ES+3Y?;W5T<'5T3&EN92@D96YT<GDI.PH*("`@("`@("`O*B!'
M;R!T:')O=6=H(&UO9'5L92!L:7-T+B`J+PH@("`@("`@("1S=6-C965D960@
M/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1P96%R7VQI<W0@87,@)&ME
M>2`]/B`D=F%L*2!["B`@("`@("`@("`@("1E;G1R>2`](&%R<F%Y*"D["@H@
M("`@("`@("`@("`O*B!)9B!T:&ES(&UO9'5L92!D97!E;F1S(&]N(&%N;W1H
M97(@;6]D=6QE('1H870@=V4*("`@("`@("`@("`@("H@:&%V96XG="!S=6-C
M97-F=6QL>2!F;W5N9"P@9F%I;"!T:&4@=&5S="X@*B\*("`@("`@("`@("`@
M:68@*"%E;7!T>2@D=F%L6R=D97!E;F1S)UTI("8F(&5M<'1Y*"1S=6-C965D
M961;)'9A;%LG9&5P96YD<R==72DI('L*("`@("`@("`@("`@("`@("1R97-U
M;'0@/2!F86QS93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1R97-U;'0@/2!`:6YC;'5D95]O;F-E("1V86Q;)W!A=&@G73L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D97)R;W)?;7-G(#T@)'9A;%LG97)R
M;W(G73L*("`@("`@("`@("`@:68@*"1R97-U;'0@)B8@:7-S970H)'9A;%LG
M9G5N8W1I;VXG72DI('L*("`@("`@("`@("`@("`@("1F=6YC7V]U='!U="`]
M(&-A;&Q?=7-E<E]F=6YC*"1V86Q;)V9U;F-T:6]N)UTI.PH@("`@("`@("`@
M("`@("`@:68@*"1F=6YC7V]U='!U="D@>PH@("`@("`@("`@("`@("`@("`@
M("1R97-U;'0@/2!F86QS93L*("`@("`@("`@("`@("`@("`@("`D97)R;W)?
M;7-G(#T@)&9U;F-?;W5T<'5T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1E;G1R>5M=(#T@)&ME>3L*("`@("`@("`@
M("`@)&5N=')Y6UT@/2`D=&AI<RT^7W-T871U<R@D<F5S=6QT+"`A96UP='DH
M)'9A;%LG<F5Q=6ER960G72DI.PH*("`@("`@("`@("`@:68@*"1R97-U;'0I
M('L*("`@("`@("`@("`@("`@("1S=6-C965D961;)&ME>5T@/2!T<G5E.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@:68@*"%E;7!T
M>2@D=F%L6R=R97%U:7)E9"==*2D@>PH@("`@("`@("`@("`@("`@("`@("1E
M<G)O<E]M<V<@+CT@)R!42$E3($E3($$@4D5154E2140@34]$54Q%(2<["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D96YT<GE;72`]("1E
M<G)O<E]M<V<["B`@("`@("`@("`@("`@("!I9B`H96UP='DH)'9A;%LG<F5Q
M=6ER960G72DI('L*("`@("`@("`@("`@("`@("`@("`D96YT<GE;72`](#$[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1O=71P=70@+CT@)'1H:7,M/E]O=71P=71,:6YE*"1E;G1R>2D["B`@("`@
M("`@?0H*("`@("`@("`O*B!297-T;W)E('!R979I;W5S('9A;'5E(&]F("=T
M<F%C:U]E<G)O<G,G+B`J+PH@("`@("`@(&EN:5]R97-T;W)E*"=T<F%C:U]E
M<G)O<G,G*3L*"B`@("`@("`@<F5T=7)N("1O=71P=70["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#:&5C:R!T:&4@;&ES="!O9B!R97%U:7)E9"!F:6QE<PH@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D9FEL95]L:7-T("!4:&4@9FEL
M92!L:7-T+@H@("`@("H@/'!R93X*("`@("`J($M%63H@("!F:6QE('!A=&@*
M("`@("`J(%9!3%5%.B!4:&4@97)R;W(@;65S<V%G92!T;R!U<V4@*&YU;&P@
M=&\@=7-E(&1E9F%U;'0@;65S<V%G92D*("`@("`J(#PO<')E/@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@2%1-3"!O=71P=70N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(')E<75I<F5D1FEL94-H96-K*"1F:6QE7VQI<W0I
M"B`@("!["B`@("`@("`@)&]U='!U="`]("<G.PH*("`@("`@("!F;W)E86-H
M("@D9FEL95]L:7-T(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`D
M96YT<GD@/2!A<G)A>2@I.PH@("`@("`@("`@("`D<F5S=6QT(#T@9FEL95]E
M>&ES=',H)RXO)R`N("1K97DI.PH*("`@("`@("`@("`@)&5N=')Y6UT@/2`D
M:V5Y.PH@("`@("`@("`@("`D96YT<GE;72`]("1T:&ES+3Y?<W1A='5S*"1R
M97-U;'0I.PH*("`@("`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@
M("`@("`@("!I9B`H96UP='DH)'9A;"DI('L*("`@("`@("`@("`@("`@("`@
M("`D96YT<GE;72`]("=4:&4@9FEL92`\8V]D93XG("X@)&ME>2`N("<\+V-O
M9&4^(&%P<&5A<G,@=&\@8F4@;6ES<VEN9RX@66]U('!R;V)A8FQY(&IU<W0@
M9F]R9V]T('1O(&-O<'D@/&-O9&4^)R`N("1K97D@+B`G+F1I<W0\+V-O9&4^
M(&]V97(N(%=H:6QE('EO=2!D;R!T:&%T+"!T86ME(&$@;&]O:R!A="!T:&4@
M<V5T=&EN9W,@86YD(&UA:V4@<W5R92!T:&5Y(&%R92!A<'!R;W!R:6%T92!F
M;W(@>6]U<B!S:71E+B<["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("1E;G1R>5M=(#T@)'9A;#L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&]U='!U="`N/2`D
M=&AI<RT^7V]U='!U=$QI;F4H)&5N=')Y*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D;W5T<'5T.PH@("`@?0H*("`@("\J*@H@("`@("H@1&ES<&QA
M>7,@86X@97)R;W(@<V-R965N('=I=&@@82!L:7-T(&]F(&%L;"!C;VYF:6=U
M<F%T:6]N(&9I;&5S('1H870*("`@("`J(&%R92!M:7-S:6YG+"!T;V=E=&AE
M<B!W:71H(&$@9&5S8W)I<'1I;VX@=VAA="!T:&5Y(&1O(&%N9"!H;W<@=&AE
M>2!A<F4*("`@("`J(&-R96%T960N($EF(&$@9FEL92!C86X@8F4@875T;VUA
M=&EC86QL>2!C<F5A=&5D(&9R;VT@=&AE(&1E9F%U;'1S+"!T:&5N"B`@("`@
M*B!W92!D;R!T:&%T(&EN<W1E860@86YD(&1O;B=T(&1I<W!L87D@86X@97)R
M;W(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D87!P("`@("`@("!4
M:&4@87!P;&EC871I;VX@;F%M90H@("`@("H@0'!A<F%M('-T<FEN9R`D87!P
M0F%S92`@("!4:&4@<&%T:"!T;R!T:&4@87!P;&EC871I;VX*("`@("`J($!P
M87)A;2!A<G)A>2`@)&9I;&5S("`@("`@06X@87)R87D@=VET:"!T:&4@(G-T
M86YD87)D(B!C;VYF:6=U<F%T:6]N"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&9I;&5S('1H870@<VAO=6QD(&)E(&-H96-K960N($-U<G)E
M;G1L>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!S=7!P;W)T
M960Z"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("T@8V]N9BYP
M:'`*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@+2!P<F5F<RYP
M:'`*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@+2!M:6UE7V1R
M:79E<G,N<&AP"B`@("`@*B!`<&%R86T@87)R87D@)&%D9&ET:6]N86P@($%N
M(&%S<V]C:6%T:79E(&%R<F%Y(&-O;G1A:6YI;F<@;6]R92!F:6QE<R`H87,*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@:V5Y<RD@86YD(&5R
M<F]R(&UE<W-A9V4@*&%S('9A;'5E<RD@:68@=&AE>0H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("!D;VXG="!E>&ES="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@8V]N9FEG1FEL97--:7-S:6YG*"1A<'`L("1A<'!"87-E+"`D
M9FEL97,L("1A9&1I=&EO;F%L(#T@87)R87DH*2D*("`@('L*("`@("`@("`O
M*B!4<GD@=&\@;&]A9"!A(&)A<VEC(&9R86UE=V]R:R!I9B!W92=R92!T97-T
M:6YG(&%N(&%P<"!O=&AE<B!T:&%N"B`@("`@("`@("H@=&AE($AO<F1E(&)A
M<V4@9FEL97,N("HO"B`@("`@("`@:68@*"1A<'`@(3T@)TAO<F1E)RD@>PH@
M("`@("`@("`@("`D1TQ/0D%,4ULG<F5G:7-T<GDG72`]("9296=I<W1R>3HZ
M<VEN9VQE=&]N*"D["B`@("`@("`@("`@("1'3$]"04Q36R=R96=I<W1R>2==
M+3YP=7-H07!P*"=H;W)D92<L(&9A;'-E*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("@A:7-?87)R87DH)&9I;&5S*2D@>PH@("`@("`@("`@("`D9FEL97,@
M/2!A<G)A>2@D9FEL97,I.PH@("`@("`@('T*("`@("`@("`D9FEL97,@/2!A
M<G)A>5]M97)G92@D9FEL97,L(&%R<F%Y7VME>7,H)&%D9&ET:6]N86PI*3L*
M"B`@("`@("`@+RH@5')Y('1O(&%U=&\M8W)E871E(&UI<W-I;F<@+F1I<W0@
M9FEL97,N("HO"B`@("`@("`@)&EN9&EC97,@/2!A<G)A>5]K97ES*"1F:6QE
M<RD["B`@("`@("`@9F]R96%C:"`H)&EN9&EC97,@87,@)&EN9&5X*2!["B`@
M("`@("`@("`@(&EF("AI<U]R96%D86)L92@D87!P0F%S92`N("<O8V]N9FEG
M+R<@+B`D9FEL97-;)&EN9&5X72DI('L*("`@("`@("`@("`@("`@('5N<V5T
M*"1F:6QE<ULD:6YD97A=*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@(&EF("A`9FEL95]E>&ES=',H)&%P<$)A<V4@+B`G+V-O;F9I
M9R\G("X@)&9I;&5S6R1I;F1E>%T@+B`G+F1I<W0G*2`F)@H@("`@("`@("`@
M("`@("`@("`@($!C;W!Y*"1A<'!"87-E("X@)R]C;VYF:6<O)R`N("1F:6QE
M<ULD:6YD97A=("X@)RYD:7-T)RP@)&%P<$)A<V4@+B`G+V-O;F9I9R\G("X@
M)&9I;&5S6R1I;F1E>%TI*2!["B`@("`@("`@("`@("`@("`@("`@=6YS970H
M)&9I;&5S6R1I;F1E>%TI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("`O*B!2971U<FX@:68@=V4@:&%V92!N
M;R!M:7-S:6YG(&9I;&5S(&QE9G0N("HO"B`@("`@("`@:68@*"%C;W5N="@D
M9FEL97,I*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@
M("`@("1D97-C<FEP=&EO;G,@/2!A<G)A>5]M97)G92AA<G)A>2@*("`@("`@
M("`@("`@)V-O;F8N<&AP)R`]/B!S<')I;G1F*"=4:&ES(&ES('1H92!M86EN
M("5S(&-O;F9I9W5R871I;VX@9FEL92X@)R`N"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G270@8V]N=&%I;G,@<&%T:',@86YD(&]P=&EO
M;G,@9F]R('1H92`E<R`G("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=S8W)I<'1S+B!9;W4@;F5E9"!T;R!L;V=I;B!A<R!A;B`G("X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A9&UI;FES=')A
M=&]R(&%N9"!C<F5A=&4@=&AE(&9I;&4@=VET:"`G("X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=T:&4@=V5B(&9R;VYT96YD('5N9&5R
M(")!9&UI;FES=')A=&EO;B`]/B`G("X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=3971U<"(N)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1A<'`L("1A<'`L("1A<'!"87-E("X@)R]C;VYF:6<G
M*2P*("`@("`@("`@("`@)W!R969S+G!H<"<@/3X@<W!R:6YT9B@G5&AI<R!F
M:6QE(&-O;G1R;VQS('1H92!D969A=6QT('!R969E<F5N8V5S("<@+@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=F;W(@)7,L(&%N9"!A
M;'-O(&-O;G1R;VQS('=H:6-H('!R969E<F5N8V5S("<@+@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=U<V5R<R!C86X@86QT97(N)RP@
M)&%P<"DL"B`@("`@("`@("`@("=M:6UE7V1R:79E<G,N<&AP)R`]/B!S<')I
M;G1F*"=4:&ES(&9I;&4@8V]N=')O;',@;&]C86P@34E-12`G("X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1R:79E<G,@
M9F]R("5S+"!S<&5C:69I8V%L;'D@=VAA="`G("X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)VMI;F1S(&]F(&9I;&5S(&%R
M92!V:65W86)L92!A;F0O;W(@)R`N"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=D;W=N;&]A9&%B;&4N)RP@)&%P<"DL"B`@
M("`@("`@("`@("=B86-K96YD<RYP:'`G(#T^('-P<FEN=&8H)U1H:7,@9FEL
M92!C;VYT<F]L<R!W:&%T(&)A8VME;F1S(&%R92`G("X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G879A:6QA8FQE(&9R;VT@)7,N
M)RP@)&%P<"DL"B`@("`@("`@("`@("=S;W5R8V5S+G!H<"<@/3X@<W!R:6YT
M9B@G5&AI<R!F:6QE(&1E9FEN97,@=&AE(&QI<W0@;V8@879A:6QA8FQE("<@
M+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-O=7)C
M97,@9F]R("5S+B<L("1A<'`I"B`@("`@("`@*2P@)&%D9&ET:6]N86PI.PH*
M("`@("`@("`O*B!)9B!W92!K;F]W('1H92!U<V5R(&ES(&%N(&%D;6EN+"!G
M:79E('1H96T@82!D:7)E8W0@;&EN:R!T;PH@("`@("`@("`J(&=E;F5R871E
M(&-O;F8N<&AP+B!);B!T:&4@9G5T=7)E+"!S:&]U;&0@=V4@=')Y(&=E;F5R
M871I;F<*("`@("`@("`@*B!A(&)A<VEC(&-O;F8N<&AP(&%U=&]M86=I8V%L
M;'D@:&5R93\@*B\*("`@("`@("!I9B`H075T:#HZ:7-!9&UI;B@I*2!["B`@
M("`@("`@("`@("1S971U<%]U<FP@/2!(;W)D93HZ;&EN:RA(;W)D93HZ=7)L
M*"1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G
M*2`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("<O861M:6XO<V5T=7`O8V]N9FEG+G!H<#]A<'`])R`N(%-T<FEN
M9SHZ;&]W97(H)&%P<"DI*2`N"B`@("`@("`@("`@("`@("`G0V]N9FEG=7)A
M=&EO;B!796(@26YT97)F86-E)R`N("<\+V$^)SL*("`@("`@("`@("`@)&1E
M<V-R:7!T:6]N<ULG8V]N9BYP:'`G72`]"B`@("`@("`@("`@("`@("!S<')I
M;G1F*"=4:&ES(&ES('1H92!M86EN("5S(&-O;F9I9W5R871I;VX@9FEL92X@
M)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("='96YE<F%T92!I="!B>2!G
M;VEN9R!T;R!T:&4@)7,N)RP*("`@("`@("`@("`@("`@("`@("`@("`@)&%P
M<"P@)'-E='5P7W5R;"D["B`@("`@("`@?0H*("`@("`@("`D=&ET;&4@/2!S
M<')I;G1F*"<E<R!I<R!N;W0@<')O<&5R;'D@8V]N9FEG=7)E9"<L("1A<'`I
M.PH@("`@("`@("1H96%D97(@/2!S<')I;G1F*"=3;VUE(&]F("5S7"=S(&-O
M;F9I9W5R871I;VX@9FEL97,@87)E(&UI<W-I;F<@;W(@=6YR96%D86)L92<L
M("1A<'`I.PH@("`@("`@("1F;V]T97(@/2!S<')I;G1F*"=#<F5A=&4@=&AE
M<V4@9FEL97,@9G)O;2!T:&5I<B`N9&ES="!V97)S:6]N<R!I;B`E<R!A;F0@
M8VAA;F=E('1H96T@86-C;W)D:6YG('1O('EO=7(@;F5E9',N)RP@)&%P<$)A
M<V4@+B`G+V-O;F9I9R<I.PH*("`@("`@("!E8VAO(#P\/"!(14%$15(*/&AT
M;6P^"CQH96%D/CQT:71L93XD=&ET;&4\+W1I=&QE/CPO:&5A9#X*/&)O9'D@
M<W1Y;&4](F)A8VMG<F]U;F0M8V]L;W(Z('=H:71E.R!C;VQO<CH@8FQA8VL[
M(CX*/&@Q/B1H96%D97(\+V@Q/@I(14%$15(["@H@("`@("`@(&9O<F5A8V@@
M*"1F:6QE<R!A<R`D9FEL92D@>PH@("`@("`@("`@("!I9B`H96UP='DH)&1E
M<V-R:7!T:6]N<ULD9FEL95TI*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU
M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D9&5S8W)I<'1I;VX@/2`D
M9&5S8W)I<'1I;VYS6R1F:6QE73L*("`@("`@("`@("`@96-H;R`\/#P@1DE,
M10H@("`@/&@S/B1F:6QE/"]H,SX\<#XD9&5S8W)I<'1I;VX\+W`^"D9)3$4[
M"B`@("`@("`@?0H*("`@("`@("!E8VAO(#P\/"!&3T]415(*"CQH,CXD9F]O
M=&5R/"]H,CX*/"]B;V1Y/@H\+VAT;6P^"D9/3U1%4CL*("`@("`@("!E>&ET
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VL@=&AE(&QI<W0@;V8@<F5Q
M=6ER960@2&]R9&4@87!P;&EC871I;VYS+@H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D87!P7VQI<W0@(%1H92!A<'!L:6-A=&EO;B!L:7-T+@H@("`@
M("H@/'!R93X*("`@("`J($M%63H@("!A<'!L:6-A=&EO;B!N86UE"B`@("`@
M*B!604Q513H@06X@87)R87D@=VET:"!T:&4@9F]L;&]W:6YG(&5N=')I97,Z
M"B`@("`@*B`@("`@("`@)V5R<F]R)R`@("`M+2`@17)R;W(@365S<V%G90H@
M("`@("H@("`@("`@("=V97)S:6]N)R`@+2T@(%1H92!M:6YI;75M('9E<G-I
M;VX@<F5Q=6ER960*("`@("`J(#PO<')E/@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@2%1-3"!O=71P=70N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(')E<75I<F5D07!P0VAE8VLH)&%P<%]L:7-T*0H@("`@>PH@("`@("`@
M("1O=71P=70@/2`G)SL*"B`@("`@("`@)&%P<',@/2`D=&AI<RT^87!P;&EC
M871I;VY,:7-T*"D["@H@("`@("`@(&9O<F5A8V@@*"1A<'!?;&ES="!A<R`D
M:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@)&5N=')Y(#T@87)R87DH*3L*
M("`@("`@("`@("`@)&5N=')Y6UT@/2`D:V5Y.PH*("`@("`@("`@("`@:68@
M*"%I<W-E="@D87!P<ULD:V5Y72DI('L*("`@("`@("`@("`@("`@("1E;G1R
M>5M=(#T@)'1H:7,M/E]S=&%T=7,H9F%L<V4I.PH@("`@("`@("`@("`@("`@
M)&5N=')Y6UT@/2`D=F%L6R=E<G)O<B==.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@+RH@4W1R:7`@)RUC=G,G(&%N9"!(,R`H=F5R
M*2!F<F]M('9E<G-I;VX@<W1R:6YG+B`J+PH@("`@("`@("`@("`@("`@)&%P
M<'9E<B`]('-T<E]R97!L86-E*"<M8W9S)RP@)R<L("1A<'!S6R1K97E=+3YV
M97)S:6]N*3L*("`@("`@("`@("`@("`@("1A<'!V97(@/2!P<F5G7W)E<&QA
M8V4H)R](,R!<*"@N*BE<*2\G+"`G)#$G+"`D87!P=F5R*3L*("`@("`@("`@
M("`@("`@(&EF("AV97)S:6]N7V-O;7!A<F4H)'9A;%LG=F5R<VEO;B==+"`D
M87!P=F5R*2`]/3T@,2D@>PH@("`@("`@("`@("`@("`@("`@("1E;G1R>5M=
M(#T@)'1H:7,M/E]S=&%T=7,H9F%L<V4I("X@)R`H2&%V92!V97)S:6]N.B`G
M("X@)&%P<'-;)&ME>5TM/G9E<G-I;VX@+B`G.R!.965D('9E<G-I;VXZ("<@
M+B`D=F%L6R=V97)S:6]N)UT@+B`G*2<["B`@("`@("`@("`@("`@("`@("`@
M)&5N=')Y6UT@/2`D=F%L6R=E<G)O<B==.PH@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`D96YT<GE;72`]("1T:&ES+3Y?
M<W1A='5S*'1R=64I("X@)R`H5F5R<VEO;CH@)R`N("1A<'!S6R1K97E=+3YV
M97)S:6]N("X@)RDG.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1O=71P=70@+CT@)'1H:7,M/E]O=71P=71,:6YE*"1E
M;G1R>2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&]U='!U=#L*("`@
M('T*"B`@("`O*BH*("`@("`J($ES('1H:7,@82`G<F5C96YT)R!V97)S:6]N
M(&]F(%!%05(_"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@(%1R=64@
M:68@82!R96-E;G0@=F5R<VEO;B!O9B!014%2+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!I<U)E8V5N=%!%05(H*0H@("`@>PH@("`@("`@($!I;F-L=61E7V]N
M8V4@)U!%05(N<&AP)SL*("`@("`@("`D<&5A<E]M971H;V1S(#T@9V5T7V-L
M87-S7VUE=&AO9',H)U!%05(G*3L*("`@("`@("!R971U<FX@*&ES7V%R<F%Y
M*"1P96%R7VUE=&AO9',I("8F"B`@("`@("`@("`@("`@("`H:6Y?87)R87DH
M)W)E9VES=&5R<VAU=&1O=VYF=6YC)RP@)'!E87)?;65T:&]D<RD@?'P*("`@
M("`@("`@("`@("`@("!I;E]A<G)A>2@G<F5G:7-T97)3:'5T9&]W;D9U;F,G
M+"`D<&5A<E]M971H;V1S*2DI.PH@("`@?0H*("`@("\J*@H@("`@("H@3V)T
M86EN(&EN9F]R;6%T:6]N(&]N('1H92!02%`@=F5R<VEO;BX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&]B:F5C="!S=&1#;&%S<R`@5$]$3PH@("`@("HO"B`@
M("!F=6YC=&EO;B!G9710:'!697)S:6]N26YF;W)M871I;VXH*0H@("`@>PH@
M("`@("`@("1O=71P=70@/2`F;F5W('-T9$-L87-S.PH@("`@("`@("1U<FP@
M/2!U<FQE;F-O9&4H)%]315)615);)U!(4%]314Q&)UTI.PH@("`@("`@("1V
M97)S7V-H96-K(#T@=')U93L*"B`@("`@("`@)'1E<W1S8W)I<'0@/2`D=&AI
M<RT^87!P;&EC871I;VYS6R=H;W)D92==6R=W96)R;V]T)UT@+B`G+W1E<W0N
M<&AP)SL*("`@("`@("`D;W5T<'5T+3YP:'!I;F9O(#T@)'1E<W1S8W)I<'0@
M+B`G/VUO9&4]<&AP:6YF;R9U<FP])R`N("1U<FP["B`@("`@("`@)&]U='!U
M="T^97AT96YS:6]N<R`]("1T97-T<V-R:7!T("X@)S]M;V1E/65X=&5N<VEO
M;G,F=7)L/2<@+B`D=7)L.PH@("`@("`@("1O=71P=70M/G9E<G-I;VX@/2!P
M:'!V97)S:6]N*"D["B`@("`@("`@)&]U='!U="T^;6%J;W(@/2`D=&AI<RT^
M7W!H<'9E<ELG;6%J;W(G73L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P
M:'!V97);)VUI;F]R)UTI*2!["B`@("`@("`@("`@("1O=71P=70M/FUI;F]R
M(#T@)'1H:7,M/E]P:'!V97);)VUI;F]R)UT["B`@("`@("`@?0H@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^7W!H<'9E<ELG<W5B;6EN;W(G72DI('L*("`@
M("`@("`@("`@)&]U='!U="T^<W5B;6EN;W(@/2`D=&AI<RT^7W!H<'9E<ELG
M<W5B;6EN;W(G73L*("`@("`@("!]"B`@("`@("`@)&]U='!U="T^8VQA<W,@
M/2`D=&AI<RT^7W!H<'9E<ELG8VQA<W,G73L*"B`@("`@("`@)&]U='!U="T^
M<W1A='5S7V-O;&]R(#T@)W)E9"<["B`@("`@("`@:68@*"1O=71P=70M/FUA
M:F]R(#P@)S0N,R<I('L*("`@("`@("`@("`@)&]U='!U="T^<W1A='5S(#T@
M)U1H:7,@=F5R<VEO;B!O9B!02%`@:7,@;F]T('-U<'!O<G1E9"X@66]U(&YE
M960@=&\@=7!G<F%D92!T;R!A(&UO<F4@<F5C96YT('9E<G-I;VXN)SL*("`@
M("`@("`@("`@)'9E<G-?8VAE8VL@/2!F86QS93L*("`@("`@("!](&5L<V5I
M9B`H*"1O=71P=70M/FUA:F]R(#T]("<T+C,G*2!\?`H@("`@("`@("`@("`@
M("`@("`H)&]U='!U="T^;6%J;W(@/3T@)S0N-"<I('Q\"B`@("`@("`@("`@
M("`@("`@("@D;W5T<'5T+3YM86IO<B`]/2`G-2XP)RD@?'P*("`@("`@("`@
M("`@("`@("`@*"1O=71P=70M/FUA:F]R(#T]("<U+C$G*2D@>PH@("`@("`@
M("`@("`D;W5T<'5T+3YS=&%T=7,@/2`G66]U(&%R92!R=6YN:6YG(&$@<W5P
M<&]R=&5D('9E<G-I;VX@;V8@4$A0+B<["B`@("`@("`@("`@("1O=71P=70M
M/G-T871U<U]C;VQO<B`]("=G<F5E;B<["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&]U='!U="T^<W1A='5S(#T@)U=O=RP@82!M>7-T:6-A;"!V
M97)S:6]N(&]F(%!(4"!F<F]M('1H92!F=71U<F4N($QE="`\82!H<F5F/2)M
M86EL=&\Z9&5V0&QI<W1S+FAO<F1E+F]R9R(^9&5V0&QI<W1S+FAO<F1E+F]R
M9SPO83X@:VYO=R!W:&%T('9E<G-I;VX@>6]U(&AA=F4@<V\@=V4@8V%N(&9I
M>"!T:&ES('-C<FEP="XG.PH@("`@("`@("`@("`D;W5T<'5T+3YS=&%T=7-?
M8V]L;W(@/2`G;W)A;F=E)SL*("`@("`@("!]"@H@("`@("`@(&EF("@A)'9E
M<G-?8VAE8VLI('L*("`@("`@("`@("`@)&]U='!U="T^=F5R<VEO;E]C:&5C
M:R`]("=(;W)D92!R97%U:7)E<R!02%`@-"XS+C`@;W(@9W)E871E<BXG.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O=71P=70["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!'970@=&AE(&%P<&QI8V%T:6]N(&QI<W0N"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>2`@3&ES="!O9B!S=&1#;&%S<R!O8FIE8W1S
M+@H@("`@("H@("`@("`@("`@("`@("`@2T59.B!A<'!L:6-A=&EO;B!N86UE
M"B`@("`@*B`@("`@("`@("`@("`@("!%3$5-14Y4("=V97)S:6]N)SH@5F5R
M<VEO;B!O9B!A<'!L:6-A=&EO;@H@("`@("H@("`@("`@("`@("`@("`@14Q%
M345.5"`G=&5S="<Z(%1H92!L;V-A=&EO;B!O9B!T:&4@=&5S="!S8W)I<'0@
M*&EF(&%N>2D*("`@("`J+PH@("`@9G5N8W1I;VX@87!P;&EC871I;VY,:7-T
M*"D*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?87!P;W5T<'5T
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]A<'!O=71P=70["B`@
M("`@("`@?0H*("`@("`@("!F;W)E86-H("@D=&AI<RT^87!P;&EC871I;VYS
M(&%S("1M;V0@/3X@)&1E="D@>PH@("`@("`@("`@("!I9B`H*"1D971;)W-T
M871U<R==("$]("=H96%D:6YG)RD@)B8*("`@("`@("`@("`@("`@("@D9&5T
M6R=S=&%T=7,G72`A/2`G8FQO8VLG*2`F)@H@("`@("`@("`@("`@("`@:7-?
M<F5A9&%B;&4H)&1E=%LG9FEL97)O;W0G72`N("<O;&EB+W9E<G-I;VXN<&AP
M)RDI('L*("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`D9&5T6R=F:6QE
M<F]O="==("X@)R]L:6(O=F5R<VEO;BYP:'`G.PH@("`@("`@("`@("`@("`@
M)'9E<G-I;VY?8V]N<W1A;G0@/2!3=')I;F<Z.G5P<&5R*"1M;V0I("X@)U]6
M15)324].)SL*("`@("`@("`@("`@("`@(&EF("AD969I;F5D*"1V97)S:6]N
M7V-O;G-T86YT*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?87!P
M;W5T<'5T6R1M;V1=(#T@)FYE=R!S=&1#;&%S<SL*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7V%P<&]U='!U=%LD;6]D72T^=F5R<VEO;B`](&-O;G-T
M86YT*"1V97)S:6]N7V-O;G-T86YT*3L*("`@("`@("`@("`@("`@("`@("!I
M9B`H*"1M;V0@(3T@)VAO<F1E)RD@)B8*("`@("`@("`@("`@("`@("`@("`@
M("`@0&ES7W)E861A8FQE*"1D971;)V9I;&5R;V]T)UT@+B`G+W1E<W0N<&AP
M)RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A<'!O=71P
M=71;)&UO9%TM/G1E<W0@/2`D9&5T6R=W96)R;V]T)UT@+B`G+W1E<W0N<&AP
M)SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^
M7V%P<&]U='!U=#L*("`@('T*"B`@("`O*BH*("`@("`J($]U='!U="!T:&4@
M<F5S=6QT<R!O9B!A('-T871U<R!C:&5C:RX*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D8F]O
M;"`@("`@(%1H92!R97-U;'0@;V8@=&AE('-T871U<R!C:&5C:RX*("`@("`J
M($!P87)A;2!B;V]L96%N("1R97%U:7)E9"`@5VAE=&AE<B!T:&4@8VAE8VME
M9"!I=&5M(&ES(')E<75I<F5D+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@2%1-3"!O9B!T:&4@<F5S=6QT(&]F('1H92!S=&%T=7,@8VAE
M8VLN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S=&%T=7,H)&)O;VPL("1R97%U
M:7)E9"`]('1R=64I"B`@("!["B`@("`@("`@:68@*"1B;V]L*2!["B`@("`@
M("`@("`@(')E='5R;B`G/&9O;G0@8V]L;W(](F=R965N(CX\<W1R;VYG/EEE
M<SPO<W1R;VYG/CPO9F]N=#XG.PH@("`@("`@('T@96QS96EF("@D<F5Q=6ER
M960I('L*("`@("`@("`@("`@<F5T=7)N("<\9F]N="!C;VQO<CTB<F5D(CX\
M<W1R;VYG/DYO/"]S=')O;F<^/"]F;VYT/B<["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<F5T=7)N("<\9F]N="!C;VQO<CTB;W)A;F=E(CX\<W1R
M;VYG/DYO/"]S=')O;F<^/"]F;VYT/B<["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@26YT97)N86P@;W5T<'5T(&9U;F-T:6]N+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`D96YT<GD@(#,@96QE;65N="!A<G)A>2X*("`@("`J(#QP<F4^"B`@
M("`@*B`Q<W0@=F%L=64Z($AE861E<@H@("`@("H@,FYD('9A;'5E.B!497-T
M(%)E<W5L=`H@("`@("H@,W)D('9A;'5E.B!%<G)O<B!M97-S86=E("AI9B!P
M<F5S96YT*0H@("`@("H@-'1H('9A;'5E.B!%<G)O<B!L979E;"`H:68@<')E
M<V5N="DZ(#`@/2!E<G)O<BP@,2`]('=A<FYI;F<*("`@("`J(#PO<')E/@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!(5$U,(&]U='!U="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V]U='!U=$QI;F4H)&5N=')Y*0H@("`@>PH@
M("`@("`@("1O=71P=70@/2`G/&QI/B<@+B!A<G)A>5]S:&EF="@D96YT<GDI
M("X@)SH@)R`N(&%R<F%Y7W-H:69T*"1E;G1R>2D["B`@("`@("`@:68@*"%E
M;7!T>2@D96YT<GDI*2!["B`@("`@("`@("`@("1M<V<@/2!A<G)A>5]S:&EF
M="@D96YT<GDI.PH@("`@("`@("`@("`D;W5T<'5T("X]("<\8G(@+SX\9F]N
M="!C;VQO<CTB)R`N("AE;7!T>2@D96YT<GDI('Q\("%A<G)A>5]S:&EF="@D
M96YT<GDI(#\@)W)E9"<@.B`G;W)A;F=E)RD@+B`G(CX\<W1R;VYG/B<@+B`D
M;7-G("X@)SPO<W1R;VYG/CPO9F]N=#XG("X@(EQN(CL*("`@("`@("!]"B`@
M("`@("`@)&]U='!U="`N/2`G/"]L:3XG("X@(EQN(CL*"B`@("`@("`@<F5T
M=7)N("1O=71P=70["B`@("!]"@I]"@``````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+G!H<```````````````````````````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,34U,C`R(#$P-3$U-#,S-S0P(#`R,#`V,@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`H*:6YC;'5D
M95]O;F-E("=,;V<N<&AP)SL*:6YC;'5D95]O;F-E("=(;W)D92]5=&EL+G!H
M<"<["@HO*BH*("H@5&AE($AO<F1E.CH@8VQA<W,@<')O=FED97,@=&AE(&9U
M;F-T:6]N86QI='D@<VAA<F5D(&)Y(&%L;"!(;W)D90H@*B!A<'!L:6-A=&EO
M;G,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<"QV
M(#$N-#@Y+C(N-30@,C`P-B\P-R\S,2`P.#HT.3HT-R!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!*;VX@4&%R:7-E
M(#QJ;VY`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!A=71H;W(@
M($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E
M(#$N,PH@*B!`<&%C:V%G92!(;W)D95]&<F%M97=O<FL*("HO"F-L87-S($AO
M<F1E('L*"B`@("`O*BH*("`@("`J($QO9W,@82!M97-S86=E('1O('1H92!G
M;&]B86P@2&]R9&4@;&]G(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&UI>&5D("1M97-S86=E("`@("!%:71H97(@82!S=')I;F<@;W(@82!014%2
M7T5R<F]R(&]B:F5C="X*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&4@("`@
M("`@5VAA="!F:6QE('=A<R!T:&4@;&]G(&9U;F-T:6]N(&-A;&QE9"!F<F]M
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("AE+F<N(%]?1DE,
M15]?*3\*("`@("`J($!P87)A;2!I;G1E9V5R("1L:6YE("`@("`@5VAA="!L
M:6YE('=A<R!T:&4@;&]G(&9U;F-T:6]N(&-A;&QE9"!F<F]M"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("AE+F<N(%]?3$E.15]?*3\*("`@
M("`J($!P87)A;2!I;G1E9V5R("1P<FEO<FET>2`@5&AE('!R:6]R:71Y(&]F
M('1H92!M97-S86=E+B!/;F4@;V8Z"B`@("`@*B`\<')E/@H@("`@("H@4$5!
M4E],3T=?14U%4D<*("`@("`J(%!%05)?3$]'7T%,15)4"B`@("`@*B!014%2
M7TQ/1U]#4DE4"B`@("`@*B!014%27TQ/1U]%4E(*("`@("`J(%!%05)?3$]'
M7U=!4DY)3D<*("`@("`J(%!%05)?3$]'7TY/5$E#10H@("`@("H@4$5!4E],
M3T=?24Y&3PH@("`@("H@4$5!4E],3T=?1$5"54<*("`@("`J(#PO<')E/@H@
M("`@("HO"B`@("!F=6YC=&EO;B!L;V=-97-S86=E*"1M97-S86=E+"`D9FEL
M92P@)&QI;F4L("1P<FEO<FET>2`](%!%05)?3$]'7TE.1D\I"B`@("!["B`@
M("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("!I9B`H(21C;VYF6R=L;V<G
M75LG96YA8FQE9"==*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]
M"@H@("`@("`@(&EF("@D<')I;W)I='D@/B`D8V]N9ELG;&]G)UU;)W!R:6]R
M:71Y)UTI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@
M("`@)&QO9V=E<B`]("9(;W)D93HZ9V5T3&]G9V5R*"D["B`@("`@("`@:68@
M*"%I<U]A*"1L;V=G97(L("=,;V<G*2D@>PH@("`@("`@("`@("!(;W)D93HZ
M9F%T86PH4$5!4CHZ<F%I<V5%<G)O<B@G06X@97)R;W(@:&%S(&]C8W5R<F5D
M+B!&=7)T:&5R;6]R92P@2&]R9&4@96YC;W5N=&5R960@86X@97)R;W(@871T
M96UP=&EN9R!T;R!L;V<@=&AI<R!E<G)O<BX@4&QE87-E(&-H96-K('EO=7(@
M2&]R9&4@;&]G9VEN9R!C;VYF:6=U<F%T:6]N(&EN(&AO<F1E+V-O;F9I9R]C
M;VYF+G!H<"XG*2P@7U]&24Q%7U\L(%]?3$E.15]?+"!F86QS92D["B`@("`@
M("`@?0H*("`@("`@("!I9B`H:7-?82@D;65S<V%G92P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`D=7-E<FEN9F\@/2`D;65S<V%G92T^9V5T57-E
M<DEN9F\H*3L*("`@("`@("`@("`@)&UE<W-A9V4@/2`D;65S<V%G92T^9V5T
M365S<V%G92@I.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1U<V5R:6YF;RDI
M('L*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D=7-E<FEN9F\I*2![
M"B`@("`@("`@("`@("`@("`@("`@)'5S97)I;F9O(#T@0&EM<&QO9&4H)RP@
M)RP@)'5S97)I;F9O*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("1M97-S86=E("X]("<Z("<@+B`D=7-E<FEN9F\["B`@("`@("`@("`@
M('T*("`@("`@("!](&5L<V5I9B`H:7-?8V%L;&%B;&4H87)R87DH)&UE<W-A
M9V4L("=G971-97-S86=E)RDI*2!["B`@("`@("`@("`@("1M97-S86=E(#T@
M)&UE<W-A9V4M/F=E=$UE<W-A9V4H*3L*("`@("`@("!]"@H@("`@("`@("1A
M<'`@/2!I<W-E="@D1TQ/0D%,4ULG<F5G:7-T<GDG72D@/R`D1TQ/0D%,4ULG
M<F5G:7-T<GDG72T^9V5T07!P*"D@.B`G:&]R9&4G.PH@("`@("`@("1M97-S
M86=E(#T@)ULG("X@)&%P<"`N("==("<@+B`D;65S<V%G92`N("<@6V]N(&QI
M;F4@)R`N("1L:6YE("X@)R!O9B`B)R`N("1F:6QE("X@)R)=)SL*"B`@("`@
M("`@+RH@36%K92!S=7)E('1O(&QO9R!I;B!T:&4@<WES=&5M)W,@;&]C86QE
M+B`J+PH@("`@("`@("1L;V-A;&4@/2!S971L;V-A;&4H3$-?5$E-12P@,"D[
M"B`@("`@("`@<V5T;&]C86QE*$Q#7U1)344L("=#)RD["@H@("`@("`@("1L
M;V=G97(M/FQO9R@D;65S<V%G92P@)'!R:6]R:71Y*3L*"B`@("`@("`@+RH@
M4F5S=&]R92!O<FEG:6YA;"!L;V-A;&4N("HO"B`@("`@("`@<V5T;&]C86QE
M*$Q#7U1)344L("1L;V-A;&4I.PH*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O*BH*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=$QO9V=E<B@I
M"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("!I9B`H96UP
M='DH)&-O;F9;)VQO9R==6R=E;F%B;&5D)UTI*2!["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@('-T871I8R`D;&]G8VAE
M8VL["B`@("`@("`@:68@*"%I<W-E="@D;&]G8VAE8VLI*2!["B`@("`@("`@
M("`@("\O(%1R>2!T;R!M86ME('-U<F4@=&AA="!W92!C86X@;&]G(&UE<W-A
M9V5S('-O;65H;W<N"B`@("`@("`@("`@(&EF("AE;7!T>2@D8V]N9ELG;&]G
M)UTI('Q\"B`@("`@("`@("`@("`@("!E;7!T>2@D8V]N9ELG;&]G)UU;)W1Y
M<&4G72D@?'P*("`@("`@("`@("`@("`@(&5M<'1Y*"1C;VYF6R=L;V<G75LG
M;F%M92==*2!\?`H@("`@("`@("`@("`@("`@96UP='DH)&-O;F9;)VQO9R==
M6R=I9&5N="==*2!\?`H@("`@("`@("`@("`@("`@(6ES<V5T*"1C;VYF6R=L
M;V<G75LG<&%R86US)UTI*2!["B`@("`@("`@("`@("`@("!(;W)D93HZ9F%T
M86PH4$5!4CHZ<F%I<V5%<G)O<B@G2&]R9&4@:7,@;F]T(&-O<G)E8W1L>2!C
M;VYF:6=U<F5D('1O(&QO9R!E<G)O<B!M97-S86=E<RX@66]U(&UU<W0@8V]N
M9FEG=7)E(&%T(&QE87-T(&$@=&5X="!F:6QE(&QO9R!I;B!H;W)D92]C;VYF
M:6<O8V]N9BYP:'`N)RDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@9F%L<V4I.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1L;V=C:&5C:R`]('1R=64["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&QO9V=E<B`]("9,;V<Z.G-I;F=L
M971O;B@D8V]N9ELG;&]G)UU;)W1Y<&4G72P@)&-O;F9;)VQO9R==6R=N86UE
M)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&-O;F9;)VQO9R==6R=I9&5N="==+"`D8V]N9ELG;&]G)UU;)W!A<F%M<R==
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($1E<W1R;WES(&%N>2!E>&ES=&EN
M9R!S97-S:6]N(&]N(&QO9VEN(&%N9"!M86ME('-U<F4@=&\@=7-E(&$@;F5W
M"B`@("`@*B!S97-S:6]N($E$+"!T;R!A=F]I9"!S97-S:6]N(&9I>&%T:6]N
M(&ES<W5E<RX@4VAO=6QD(&)E(&-A;&QE9"!B969O<F4*("`@("`J(&-H96-K
M:6YG(&$@;&]G:6XN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-L96%N4V5S
M<VEO;B@I"B`@("!["B`@("`@("`@+R\@36%K92!S=7)E('1O(&9O<F-E(&$@
M8V]M<&QE=&5L>2!N97<@<V5S<VEO;B!)1"!A;F0@8VQE87(*("`@("`@("`O
M+R!A;&P@<V5S<VEO;B!D871A+@H@("`@("`@(&EF("AV97)S:6]N7V-O;7!A
M<F4H<&AP=F5R<VEO;B@I+"`G-"XS+C,G*2`A/3T@+3$I('L*("`@("`@("`@
M("`@<V5S<VEO;E]R96=E;F5R871E7VED*"D["B`@("`@("`@("`@('-E<W-I
M;VY?=6YS970H*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!`<V5S
M<VEO;E]D97-T<F]Y*"D["B`@("`@("`@("`@(&EF("A5=&EL.CIE>'1E;G-I
M;VY%>&ES=',H)W!O<VEX)RDI('L*("`@("`@("`@("`@("`@("1N97=?<V5S
M<VEO;E]I9"`](&UD-2AM:6-R;W1I;64H*2`N('!O<VEX7V=E='!I9"@I*3L*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1N97=?<V5S
M<VEO;E]I9"`](&UD-2AU;FEQ:60H;71?<F%N9"@I+"!T<G5E*2D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@<V5S<VEO;E]I9"@D;F5W7W-E<W-I;VY?
M:60I.PH*("`@("`@("`@("`@+R\@4F5S=&%R="!T:&4@<V5S<VEO;BP@:6YC
M;'5D:6YG('-E='1I;F<@=7`@=&AE('-E<W-I;VX*("`@("`@("`@("`@+R\@
M:&%N9&QE<BX*("`@("`@("`@("`@2&]R9&4Z.G-E='5P4V5S<VEO;DAA;F1L
M97(H*3L*("`@("`@("`@("`@0'-E<W-I;VY?<W1A<G0H*3L*("`@("`@("!]
M"@H@("`@("`@("\J(%)E<V5T(&-O;VMI92!T:6UE;W5T<RP@:68@;F5C97-S
M87)Y+B`J+PH@("`@("`@(&EF("@A96UP='DH)$=,3T)!3%-;)V-O;F8G75LG
M<V5S<VEO;B==6R=T:6UE;W5T)UTI*2!["B`@("`@("`@("`@("1A<'`@/2`D
M1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T07!P*"D["B`@("`@("`@("`@(&EF
M("A396-R970Z.F-L96%R2V5Y*"1A<'`I*2!["B`@("`@("`@("`@("`@("!3
M96-R970Z.G-E=$ME>2@D87!P*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!396-R970Z.G-E=$ME>2@G875T:"<I.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($%B;W)T<R!W:71H(&$@9F%T86P@97)R;W(L(&1I<W!L
M87EI;F<@9&5B=6<@:6YF;W)M871I;VX@=&\@=&AE('5S97(N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&UI>&5D("1E<G)O<B`@($$@4$5!4E]%<G)O<B!O8FIE
M8W0@=VET:"!D96)U9R!I;F9O<FUA=&EO;B!O<B!A;@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@(&5R<F]R(&UE<W-A9V4N"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D9FEL92`@5&AE(&9I;&4@:6X@=VAI8V@@=&AE(&5R<F]R(&]C
M8W5R960N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;&EN92`@5&AE(&QI;F4@
M;VX@=VAI8V@@=&AE(&5R<F]R(&]C8W5R960N"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D;&]G("`@3&]G('1H:7,@;65S<V%G92!V:6$@2&]R9&4Z.FQO9TUE
M<W-A9V4H*3\*("`@("`J+PH@("`@9G5N8W1I;VX@9F%T86PH)&5R<F]R+"`D
M9FEL92P@)&QI;F4L("1L;V<@/2!T<G5E*0H@("`@>PH@("`@("`@($!I;F-L
M=61E7V]N8V4@)TAO<F1E+T%U=&@N<&AP)SL*("`@("`@("!`:6YC;'5D95]O
M;F-E("=(;W)D92]#3$DN<&AP)SL*"B`@("`@("`@)&%D;6EN(#T@8VQA<W-?
M97AI<W1S*"=!=71H)RD@)B8@075T:#HZ:7-!9&UI;B@I.PH@("`@("`@("1C
M;&D@/2!C;&%S<U]E>&ES=',H)TAO<F1E7T-,22<I("8F($AO<F1E7T-,23HZ
M<G5N;FEN9T9R;VU#3$DH*3L*"B`@("`@("`@)&5R<F]R=&5X="`]("<\:#$^
M)R`N(%\H(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(BD@+B`G/"]H,3XG
M.PH@("`@("`@(&EF("AI<U]A*"1E<G)O<BP@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("`D:6YF;R`](&%R<F%Y7VUE<F=E*&%R<F%Y*"=F:6QE)R`]
M/B`G8V]N9BYP:'`G+"`G=F%R:6%B;&4G(#T^("<D8V]N9B<I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1E<G)O<BT^9V5T57-E
M<DEN9F\H*2DI.PH*("`@("`@("`@("`@<W=I=&-H("@D97)R;W(M/F=E=$-O
M9&4H*2D@>PH@("`@("`@("`@("!C87-E($A/4D1%7T524D]27T12259%4E]#
M3TY&24=?34E34TE.1SH*("`@("`@("`@("`@("`@("1M97-S86=E(#T@<W!R
M:6YT9BA?*").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@)7,N(BDL("1I;F9O6R=N86UE)UTI("X@)SQB<B`O/B<@+@H@("`@
M("`@("`@("`@("`@("`@('-P<FEN=&8H7R@B5&AE(&9I;&4@)7,@<VAO=6QD
M(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)V9I;&5R
M;V]T)RD@+B`G+V-O;F9I9R\G("X@)&EN9F];)V9I;&4G72P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('-P<FEN=&8H(B5S6R<E<R==6R=P87)A;7,G
M72(L("1I;F9O6R=V87)I86)L92==+"`D:6YF;ULG9')I=F5R)UTI*3L*("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92!(3U)$15]%
M4E)/4E]$4DE615)?0T].1DE'.@H@("`@("`@("`@("`@("`@)&UE<W-A9V4@
M/2!S<')I;G1F*%\H(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN
M("5S(&-O;F9I9W5R871I;VXN(BDL("1I;F9O6R=F:65L9"==+"`D:6YF;ULG
M;F%M92==*2`N("<\8G(@+SXG("X*("`@("`@("`@("`@("`@("`@("!S<')I
M;G1F*%\H(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN
M9RXB*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1'3$]"04Q36R=R
M96=I<W1R>2==+3YG970H)V9I;&5R;V]T)RD@+B`G+V-O;F9I9R\G("X@)&EN
M9F];)V9I;&4G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@('-P<FEN
M=&8H(B5S6R<E<R==6R=P87)A;7,G75LG)7,G72(L("1I;F9O6R=V87)I86)L
M92==+"`D:6YF;ULG9')I=F5R)UTL("1I;F9O6R=F:65L9"==*2D["B`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@
M("`@("`@("`@("`D;65S<V%G92`]("1E<G)O<BT^9V5T365S<V%G92@I.PH@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1E<G)O<G1E>'0@+CT@)SQH,SXG("X@:'1M;'-P96-I86QC:&%R<R@D
M;65S<V%G92D@+B`G/"]H,SXG.PH@("`@("`@('T@96QS96EF("AI<U]O8FIE
M8W0H)&5R<F]R*2`F)B!M971H;V1?97AI<W1S*"1E<G)O<BP@)V=E=$UE<W-A
M9V4G*2D@>PH@("`@("`@("`@("`D97)R;W)T97AT("X]("<\:#,^)R`N(&AT
M;6QS<&5C:6%L8VAA<G,H)&5R<F]R+3YG971-97-S86=E*"DI("X@)SPO:#,^
M)SL*("`@("`@("!](&5L<V5I9B`H:7-?<W1R:6YG*"1E<G)O<BDI('L*("`@
M("`@("`@("`@)&5R<F]R=&5X="`N/2`G/&@S/B<@+B!H=&UL<W!E8VEA;&-H
M87)S*"1E<G)O<BD@+B`G/"]H,SXG.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"1A9&UI;BD@>PH@("`@("`@("`@("`D97)R;W)T97AT("X]("<\<#X\8V]D
M93XG("X@<W!R:6YT9BA?*");;&EN92`E<R!O9B`E<UTB*2P@)&QI;F4L("1F
M:6QE*2`N("<\+V-O9&4^/"]P/B<["B`@("`@("`@("`@(&EF("AI<U]O8FIE
M8W0H)&5R<F]R*2D@>PH@("`@("`@("`@("`@("`@)&5R<F]R=&5X="`N/2`G
M/&@S/B<@+B!?*")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ
M(BD@+B`G/"]H,SXG.PH@("`@("`@("`@("`@("`@)&5R<F]R=&5X="`N/2`G
M/'`^/'!R93XG("X@:'1M;'-P96-I86QC:&%R<RA5=&EL.CIB=69F97)/=71P
M=70H)W9A<E]D=6UP)RP@)&5R<F]R*2D@+B`G/"]P<F4^/"]P/B<["B`@("`@
M("`@("`@('T*("`@("`@("!](&5L<V5I9B`H)&QO9RD@>PH@("`@("`@("`@
M("`D97)R;W)T97AT("X]("<\:#,^)R`N(%\H(D1E=&%I;',@:&%V92!B965N
M(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(BD@+B`G/"]H,SXG.PH@
M("`@("`@('T*"B`@("`@("`@+R\@3&]G('1H92!E<G)O<B!V:6$@2&]R9&4Z
M.FQO9TUE<W-A9V4H*2!I9B!R97%U97-T960N"B`@("`@("`@:68@*"1L;V<I
M('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)&5R<F]R+"`D9FEL
M92P@)&QI;F4L(%!%05)?3$]'7T5-15)'*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("@D8VQI*2!["B`@("`@("`@("`@(&5C:&\@<W1R:7!?=&%G<RAS=')?
M<F5P;&%C92AA<G)A>2@G/&)R("\^)RP@)SQP/B<L("<\+W`^)RP@)SQH,3XG
M+"`G/"]H,3XG+"`G/&@S/B<L("<\+V@S/B<I+"`B7&XB+"`D97)R;W)T97AT
M*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@96-H;R`\/#P@2%1-
M3`H\:'1M;#X*/&AE860^/'1I=&QE/DAO<F1E(#HZ($9A=&%L($5R<F]R/"]T
M:71L93X\+VAE860^"CQB;V1Y('-T>6QE/2)B86-K9W)O=6YD.B-F9F8[(&-O
M;&]R.B,P,#`B/B1E<G)O<G1E>'0\+V)O9'D^"CPO:'1M;#X*2%1-3#L*("`@
M("`@("!]"B`@("`@("`@97AI=#L*("`@('T*"B`@("`O*BH*("`@("`J($%D
M9',@=&AE(&IA=F%S8W)I<'0@8V]D92!T;R!T:&4@;W5T<'5T("AI9B!O=71P
M=70@:&%S(&%L<F5A9'D@<W1A<G1E9"D*("`@("`J(&]R('1O('1H92!L:7-T
M(&]F('-C<FEP="!F:6QE<R!T;R!I;F-L=61E('9I82!I;F-L=61E4V-R:7!T
M1FEL97,H*2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QE("`@
M("!4:&4@9G5L;"!J879A<V-R:7!T(&9I;&4@;F%M92X*("`@("`J($!P87)A
M;2!S=')I;F<@)&%P<"`@("`@(%1H92!A<'!L:6-A=&EO;B!N86UE+B!$969A
M=6QT<R!T;R!T:&4@8W5R<F5N=`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@87!P;&EC871I;VXN"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&ER
M96-T("!);F-L=61E('1H92!F:6QE(&1I<F5C=&QY('=I=&AO=70@<&%S<VEN
M9R!I=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@=&AR;W5G:"!J
M879A<V-R:7!T+G!H<#\*("`@("`J+PH@("`@9G5N8W1I;VX@861D4V-R:7!T
M1FEL92@D9FEL92P@)&%P<"`](&YU;&PL("1D:7)E8W0@/2!F86QS92D*("`@
M('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH@("`@("`@('-T871I8R`D
M:6YC;'5D960@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H96UP='DH)&%P<"DI
M('L*("`@("`@("`@("`@)&%P<"`]("1R96=I<W1R>2T^9V5T07!P*"D["B`@
M("`@("`@?0H*("`@("`@("`O+R!3:VEP(&%N>2!J<R!F:6QE<R!T:&%T(&AA
M=F4@<VEN8V4@8F5E;B!D97!R96-A=&5D+@H@("`@("`@("1I9VYO<F5D7V9I
M;&5S(#T@87)R87DH)VAO<F1E)R`]/B!A<G)A>2@G=&]O;'1I<"YJ<R<@/3X@
M,2DI.PH@("`@("`@(&EF("@A96UP='DH)&EG;F]R961?9FEL97-;)&%P<%U;
M)&9I;&5=*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@
M("`@("`O+R!$;VXG="!I;F-L=61E('-C<FEP=',@;75L=&EP;&4@=&EM97,N
M"B`@("`@("`@:68@*"%E;7!T>2@D:6YC;'5D961;)&%P<%U;)&9I;&5=*2D@
M>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@("`@("`@("1I;F-L
M=61E9%LD87!P75LD9FEL95T@/2!T<G5E.PH*("`@("`@("`O+R!%>'!L:6-I
M=&QY(&-H96-K(&9O<B!A(&YO;BU02%`@=F5R<VEO;B!O9B!T:&4@<V-R:7!T
M+@H@("`@("`@(&EF("@A)&1I<F5C="`F)B!F:6QE7V5X:7-T<R@D9FEL97LP
M?2`]/2`G+R<@/R`D<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G+"`D87!P*2`N
M("1F:6QE(#H@)')E9VES=')Y+3YG970H)VIS9G,G+"`D87!P*2`N("<O)R`N
M("1F:6QE*2D@>PH@("`@("`@("`@("`D9&ER96-T(#T@=')U93L*("`@("`@
M("!]"@H@("`@("`@("\O($EF(&AE861E<G,@:&%V92!A;')E861Y(&)E96X@
M<V5N="P@=V4@;F5E9"!T;R!O=71P=70@80H@("`@("`@("\O(#QS8W)I<'0^
M('1A9R!D:7)E8W1L>2X*("`@("`@("!I9B`H;V)?9V5T7VQE;F=T:"@I('Q\
M(&AE861E<G-?<V5N="@I*2!["B`@("`@("`@("`@(&EF("@D9&ER96-T*2![
M"B`@("`@("`@("`@("`@("`D=7)L(#T@2&]R9&4Z.G5R;"@D9FEL97LP?2`]
M/2`G+R<@/R`D<F5G:7-T<GDM/F=E="@G=V5B<F]O="<L("1A<'`I("X@)&9I
M;&4@.B`D<F5G:7-T<GDM/F=E="@G:G-U<FDG+"`D87!P*2`N("<O)R`N("1F
M:6QE*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1U
M<FP@/2!(;W)D93HZ=7)L*"1R96=I<W1R>2T^9V5T*"=W96)R;V]T)RP@)VAO
M<F1E)RD@+B`G+W-E<G9I8V5S+VIA=F%S8W)I<'0N<&AP)RD["B`@("`@("`@
M("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1U<FPL(&%R<F%Y
M*"=F:6QE)R`]/B`D9FEL92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%P<"<@(#T^("1A<'`I*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!E8VAO("<\<V-R:7!T('1Y<&4]
M(G1E>'0O:F%V87-C<FEP="(@<W)C/2(G("X@)'5R;"`N("<B/CPO<V-R:7!T
M/B<@+B`B7&XB.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&=L;V)A
M;"`D7VAO<F1E7W-C<FEP=%]F:6QE<SL*("`@("`@("`@("`@)%]H;W)D95]S
M8W)I<'1?9FEL97-;)&%P<%U;72`](&%R<F%Y*"1F:6QE+"`D9&ER96-T*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!);F-L=61E<R!J879A
M<V-R:7!T(&9I;&5S('1H870@=V5R92!N965D960@8F5F;W)E(&%N>2!H96%D
M97)S('=E<F4@<V5N="X*("`@("`J+PH@("`@9G5N8W1I;VX@:6YC;'5D95-C
M<FEP=$9I;&5S*"D*("`@('L*("`@("`@("!G;&]B86P@)%]H;W)D95]S8W)I
M<'1?9FEL97,L("1R96=I<W1R>3L*"B`@("`@("`@+RH@268@=&AE<F4@:7,@
M;F\@:F%V87-C<FEP="!A=F%I;&%B;&4L('1H97)E)W,@;F\@<&]I;G0@:6X@
M:6YC;'5D:6YG"B`@("`@("`@("H@=&AE(')E<W0@;V8@=&AE(&9I;&5S+B`J
M+PH@("`@("`@(&EF("@A)$=,3T)!3%-;)V)R;W=S97(G72T^:&%S1F5A='5R
M92@G:F%V87-C<FEP="<I*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@
M("!]"@H@("`@("`@("\J($%D9"!G96YE<F%L(%5)(&IS(&QI8G)A<GDN("HO
M"B`@("`@("`@2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)VAO<F1E+FIS)RP@)VAO
M<F1E)RP@=')U92D["B`@("`@("`@:68@*"1'3$]"04Q36R=B<F]W<V5R)UTM
M/FAA<U%U:7)K*"=W:6YD;W=E9%]C;VYT<F]L<R<I*2!["B`@("`@("`@("`@
M("\J($9I>&5S(&9O<B!)12!T:&%T(&-A;B=T(&5A<VEL>2!B92!D;VYE('=I
M=&AO=70@8G)O=W-E<@H@("`@("`@("`@("`@*B!D971E8W1I;VXN("HO"B`@
M("`@("`@("`@($AO<F1E.CIA9&138W)I<'1&:6QE*"=H;W)D92YI92YJ<R<L
M("=H;W)D92<L('1R=64I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T
M>2@D7VAO<F1E7W-C<FEP=%]F:6QE<RDI('L*("`@("`@("`@("`@)&)A<V5?
M=7)L(#T@2&]R9&4Z.G5R;"@D<F5G:7-T<GDM/F=E="@G=V5B<F]O="<L("=H
M;W)D92<I("X@)R]S97)V:6-E<R]J879A<V-R:7!T+G!H<"<I.PH@("`@("`@
M("`@("!F;W)E86-H("@D7VAO<F1E7W-C<FEP=%]F:6QE<R!A<R`D87!P(#T^
M("1F:6QE<RD@>PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&9I;&5S(&%S
M("1F:6QE*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D9FEL
M95LQ72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'5R;"`]("1F:6QE
M6S!=>S!](#T]("<O)R`_("1R96=I<W1R>2T^9V5T*"=W96)R;V]T)RP@)&%P
M<"D@+B`D9FEL95LP72`Z("1R96=I<W1R>2T^9V5T*"=J<W5R:2<L("1A<'`I
M("X@)R\G("X@)&9I;&5;,%T["B`@("`@("`@("`@("`@("`@("`@("`@(&5C
M:&\@)SQS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(B!S<F,](B<@+B!(
M;W)D93HZ=7)L*"1U<FPI("X@(EPB/CPO<V-R:7!T/EQN(CL*("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1B87-E7W5R;"P@87)R87DH)V9I
M;&4G(#T^("1F:6QE6S!=+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%P<"<@
M(#T^("1A<'`I*3L*("`@("`@("`@("`@("`@("`@("`@("`@96-H;R`G/'-C
M<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B('-R8STB)R`N("1U<FP@+B`B
M7"(^/"]S8W)I<'0^7&XB.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($EN8VQU9&5S(&IA=F%S8W)I<'0@9FEL97,@=&AA="!W
M97)E(&YE961E9"!B969O<F4@86YY(&AE861E<G,@=V5R92!S96YT+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!I;FQI;F538W)I<'1&:6QE<R@I"B`@("!["B`@
M("`@("`@9VQO8F%L("1?:&]R9&5?<V-R:7!T7V9I;&5S+"`D<F5G:7-T<GD[
M"@H@("`@("`@(&EF("@A96UP='DH)%]H;W)D95]S8W)I<'1?9FEL97,I*2![
M"B`@("`@("`@("`@("1J<U=R87!P97(@/2`D<F5G:7-T<GDM/F=E="@G9FEL
M97)O;W0G+"`G:&]R9&4G*2`N("<O<V5R=FEC97,O:F%V87-C<FEP="YP:'`G
M.PH@("`@("`@("`@("!F;W)E86-H("@D7VAO<F1E7W-C<FEP=%]F:6QE<R!A
M<R`D87!P(#T^("1F:6QE<RD@>PH@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)&9I;&5S(&%S("1F:6QE*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"%E
M;7!T>2@D9FEL95LQ72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@0')E
M861F:6QE*"1F:6QE6S!=>S!](#T]("<O)R`_("1R96=I<W1R>2T^9V5T*"=F
M:6QE<F]O="<L("1A<'`I("X@)&9I;&5;,%T@.B`D<F5G:7-T<GDM/F=E="@G
M:G-F<R<L("1A<'`I("X@)R\G("X@)&9I;&5;,%TI.PH@("`@("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1F:6QE
M(#T@)&9I;&5;,%T["B`@("`@("`@("`@("`@("`@("`@("`@(')E<75I<F4@
M)&IS5W)A<'!E<CL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#:&5C:W,@:68@;&EN:R!S:&]U;&0@8F4@<VAO=VX@86YD(')E
M='5R;B!T:&4@;F5S8V5S<V%R>2!C;V1E+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@("1T>7!E("`@("`@5'EP92!O9B!L:6YK('1O(&1I<W!L87D*
M("`@("`J($!P87)A;2!S=')I;F<@("1A<'`@("`@("`@5&AE(&YA;64@;V8@
M=&AE(&-U<G)E;G0@2&]R9&4@87!P;&EC871I;VXN"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`D;W9E<G)I9&4@($]V97)R:61E($AO<F1E('-E='1I;F=S/PH@
M("`@("H@0'!A<F%M(&)O;VQE86X@)')E9F5R<F5R("!);F-L=61E('1H92!C
M=7)R96YT('!A9V4@87,@=&AE(')E9F5R<F5R("AU<FP]*3\*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($A434P@=&\@8W)E871E('1H92!L
M:6YK+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971397)V:6-E3&EN:R@D='EP
M92P@)&%P<"P@)&]V97)R:61E(#T@9F%L<V4L("1R969E<G)E<B`]('1R=64I
M"B`@("!["B`@("`@("`@:68@*"%(;W)D93HZ<VAO=U-E<G9I8V4H)'1Y<&4I
M("8F("$D;W9E<G)I9&4I('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@<W=I=&-H("@D='EP92D@>PH@("`@("`@(&-A
M<V4@)VAE;'`G.@H@("`@("`@("`@("!I9B`H)$=,3T)!3%-;)V)R;W=S97(G
M72T^:&%S1F5A='5R92@G:F%V87-C<FEP="<I*2!["B`@("`@("`@("`@("`@
M("!(;W)D93HZ861D4V-R:7!T1FEL92@G<&]P=7`N:G,G+"`G:&]R9&4G+"!T
M<G5E*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=7)L(#T@2&]R9&4Z
M.G5R;"@D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=W96)R;V]T)RP@)VAO
M<F1E)RD@+B`G+W-E<G9I8V5S+VAE;'`O)RP@=')U92D["B`@("`@("`@("`@
M(')E='5R;B!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@)VUO9'5L92<L("1A
M<'`I.PH*("`@("`@("!C87-E("=P<F]B;&5M)SH*("`@("`@("`@("`@<F5T
M=7)N($AO<F1E.CIU<FPH)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B
M<F]O="<L("=H;W)D92<I("X@)R]S97)V:6-E<R]P<F]B;&5M+G!H<#]R971U
M<FY?=7)L/2<@+B!U<FQE;F-O9&4H2&]R9&4Z.G-E;&95<FPH=')U92P@=')U
M92P@=')U92DI*3L*"B`@("`@("`@8V%S92`G;&]G;W5T)SH*("`@("`@("`@
M("`@<F5T=7)N($AO<F1E.CIU<FPH075T:#HZ861D3&]G;W5T4&%R86UE=&5R
M<R@D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=W96)R;V]T)RP@)VAO<F1E
M)RD@+B`G+VQO9VEN+G!H<"<L($%55$A?4D5!4T].7TQ/1T]55"DI.PH*("`@
M("`@("!C87-E("=L;V=I;B<Z"B`@("`@("`@("`@(')E='5R;B!!=71H.CIG
M971,;V=I;E-C<F5E;B@G)RP@)')E9F5R<F5R(#\@2&]R9&4Z.G-E;&95<FPH
M=')U92D@.B!N=6QL*3L*"B`@("`@("`@8V%S92`G;W!T:6]N<R<Z"B`@("`@
M("`@("`@(&=L;V)A;"`D8V]N9CL*("`@("`@("`@("`@:68@*"@D8V]N9ELG
M<')E9G,G75LG9')I=F5R)UT@(3T@)R<I("8F("@D8V]N9ELG<')E9G,G75LG
M9')I=F5R)UT@(3T@)VYO;F4G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M($AO<F1E.CIU<FPH)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B<F]O
M="<L("=H;W)D92<I("X@)R]S97)V:6-E<R]P<F5F<RYP:'`_87!P/2<@+B`D
M87!P*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@
M("`J($!P87)A;2!S=')I;F<@)'1Y<&4@(%1H92!T>7!E(&]F(&QI;FLN"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!L:6YK
M(&ES('1O(&)E('-H;W=N+@H@("`@("HO"B`@("!F=6YC=&EO;B!S:&]W4V5R
M=FEC92@D='EP92D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@
M("`@(&EF("AE;7!T>2@D8V]N9ELG;65N=2==6R=L:6YK<R==6R1T>7!E72DI
M('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@
M("`@<W=I=&-H("@D8V]N9ELG;65N=2==6R=L:6YK<R==6R1T>7!E72D@>PH@
M("`@("`@(&-A<V4@)V%L;"<Z"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH*
M("`@("`@("!C87-E("=N979E<B<Z"B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*"B`@("`@("`@8V%S92`G875T:&5N=&EC871E9"<Z"B`@("`@("`@("`@
M(')E='5R;B`H8F]O;"E!=71H.CIG971!=71H*"D["@H@("`@("`@(&1E9F%U
M;'0Z"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!D<FEV97(@<&%R86UE=&5R
M<R!F;W(@=&AE('-P96-I9FEE9"!B86-K96YD+@H@("`@("H*("`@("`J($!P
M87)A;2!M:7AE9"`D8F%C:V5N9"`@5&AE(&)A8VME;F0@<WES=&5M("AE+F<N
M("=P<F5F<R<L("=C871E9V]R:65S)RP*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@)V-O;G1A8W1S)RD@8F5I;F<@=7-E9"X*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@5&AE('5S960@8V]N9FEG=7)A=&EO;B!A<G)A
M>2!W:6QL(&)E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("1C;VYF
M6R1B86-K96YD72X@268@86X@87)R87D@9V5T<R!P87-S960L(&ET('=I;&P*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@8F4@)&-O;F9;)&ME>3%=
M6R1K97DR72X*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@("`@5&AE('1Y
M<&4@;V8@9')I=F5R+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H
M92!C;VYN96-T:6]N('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$1R:79E<D-O;F9I9R@D8F%C:V5N9"P@)'1Y<&4@/2`G<W%L)RD*("`@
M('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@("1C(#T@;G5L;#L*
M("`@("`@("!I9B`H:7-?87)R87DH)&)A8VME;F0I*2!["B`@("`@("`@("`@
M(')E<75I<F5?;VYC92`G2&]R9&4O07)R87DN<&AP)SL*("`@("`@("`@("`@
M)&,@/2!(;W)D95]!<G)A>3HZ9V5T16QE;65N="@D8V]N9BP@)&)A8VME;F0I
M.PH@("`@("`@('T@96QS96EF("AI<W-E="@D8V]N9ELD8F%C:V5N9%TI*2![
M"B`@("`@("`@("`@("1C(#T@)&-O;F9;)&)A8VME;F1=.PH@("`@("`@('T*
M("`@("`@("!I9B`H(6ES7VYU;&PH)&,I("8F(&ES<V5T*"1C6R=P87)A;7,G
M72DI('L*("`@("`@("`@("`@:68@*&ES<V5T*"1C;VYF6R1T>7!E72DI('L*
M("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>5]M97)G92@D8V]N9ELD='EP
M95TL("1C6R=P87)A;7,G72D["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("!R971U<FX@)&-;)W!A<F%M<R==.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@:7-S970H)&-O;F9;)'1Y<&5=
M*2`_("1C;VYF6R1T>7!E72`Z(&%R<F%Y*"D["B`@("!]"@H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@5D93(&1R:79E<B!P87)A;65T97)S(&9O<B!T
M:&4@<W!E8VEF:65D(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;F%M92`@5&AE(%9&4R!S>7-T96T@;F%M92`H92YG+B`G:6UA9V5S
M)RP@)V1O8W5M96YT<R<I"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!B
M96EN9R!U<V5D+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($$@:&%S
M:"!W:71H('1H92!61E,@<&%R86UE=&5R<SL@=&AE(%9&4R!D<FEV97(@:6X@
M)W1Y<&4G"B`@("`@*B`@("`@("`@("`@("`@("!A;F0@=&AE(&-O;FYE8W1I
M;VX@<&%R86UE=&5R<R!I;B`G<&%R86US)RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T5D930V]N9FEG*"1N86UE*0H@("`@>PH@("`@("`@(&=L;V)A;"`D
M8V]N9CL*"B`@("`@("`@:68@*"%I<W-E="@D8V]N9ELD;F%M95U;)W1Y<&4G
M72DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(BDI.PH@("`@("`@
M('T*"B`@("`@("`@:68@*"1C;VYF6R1N86UE75LG='EP92==(#T]("=H;W)D
M92<I('L*("`@("`@("`@("`@)'9F<R`]("1C;VYF6R=V9G,G73L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D=F9S(#T@)&-O;F9;)&YA;65=.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"1V9G-;)W1Y<&4G72`]/2`G<W%L)RD@
M>PH@("`@("`@("`@("`D=F9S6R=P87)A;7,G72`]($AO<F1E.CIG971$<FEV
M97)#;VYF:6<H)&YA;64L("=S<6PG*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D=F9S.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS(&EF(&%L
M;"!N96-E<W-A<GD@<&%R86UE=&5R<R!F;W(@82!D<FEV97(@8V]N9FEG=7)A
M=&EO;@H@("`@("H@87)E('-E="!A;F0@=&AR;W=S(&$@9F%T86P@97)R;W(@
M=VET:"!A(&1E=&%I;&5D(&5X<&QA:6YA=&EO;@H@("`@("H@:&]W('1O(&9I
M>"!T:&ES+"!I9B!S;VUE=&AI;F<@:7,@;6ES<VEN9RX*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@)'!A<F%M<R`@("`@5&AE(&-O;F9I9W5R871I;VX@
M87)R87D@=VET:"!A;&P@<&%R86UE=&5R<RX*("`@("`J($!P87)A;2!S=')I
M;F<@)&1R:79E<B`@("!4:&4@:V5Y(&YA;64@*&EN('1H92!C;VYF:6=U<F%T
M:6]N(&%R<F%Y*2!O9@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M('1H92!D<FEV97(N"B`@("`@*B!`<&%R86T@87)R87D@)&9I96QD<R`@("`@
M06X@87)R87D@=VET:"!M86YD871O<GD@<&%R86UE=&5R(&YA;65S(&9O<@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('1H:7,@9')I=F5R+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@(%1H92!C;&5A<B!T97AT
M(&YA;64@;V8@=&AE(&1R:79E<BX@268@;F]T"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@<W!E8VEF:65D+"!T:&4@87!P;&EC871I;VX@;F%M
M92!W:6QL(&)E('5S960N"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QE("`@
M("`@5&AE(&-O;F9I9W5R871I;VX@9FEL92!T:&%T('-H;W5L9"!C;VYT86EN
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE<V4@<V5T=&EN
M9W,N"B`@("`@*B!`<&%R86T@<W1R:6YG("1V87)I86)L92`@5&AE(&YA;64@
M;V8@=&AE(&-O;F9I9W5R871I;VX@=F%R:6%B;&4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&%S<V5R=$1R:79E<D-O;F9I9R@D<&%R86US+"`D9')I=F5R+"`D
M9FEE;&1S+"`D;F%M92`](&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&9I;&4@/2`G8V]N9BYP:'`G+"`D=F%R:6%B;&4@/2`G)&-O
M;F8G*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@("`@
M("\O($1O;B=T(&=E;F5R871E(&$@9F%T86P@97)R;W(@:68@=V4@9F%I;"!D
M=7)I;F<@;W(@8F5F;W)E"B`@("`@("`@+R\@4F5G:7-T<GD@:6YS=&%N=&EA
M=&EO;BX*("`@("`@("!I9B`H:7-?;G5L;"@D;F%M92DI('L*("`@("`@("`@
M("`@)&YA;64@/2!I<W-E="@D<F5G:7-T<GDI(#\@)')E9VES=')Y+3YG971!
M<'`H*2`Z("=;=6YK;F]W;ETG.PH@("`@("`@('T*("`@("`@("`D9FEL97)O
M;W0@/2!I<W-E="@D<F5G:7-T<GDI(#\@)')E9VES=')Y+3YG970H)V9I;&5R
M;V]T)RD@.B`G)SL*"B`@("`@("`@:68@*"%I<U]A<G)A>2@D<&%R86US*2!\
M?"`A8V]U;G0H)'!A<F%M<RDI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L
M*%!%05(Z.G)A:7-E17)R;W(H"B`@("`@("`@("`@("`@("!S<')I;G1F*%\H
M(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E
M<RXB*2P@)&YA;64I("X@(EQN7&XB("X*("`@("`@("`@("`@("`@('-P<FEN
M=&8H7R@B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T
M:6YG<RXB*2P*("`@("`@("`@("`@("`@("`@("`D9FEL97)O;W0@+B`G+V-O
M;F9I9R\G("X@)&9I;&4L"B`@("`@("`@("`@("`@("`@("`@<W!R:6YT9B@B
M)7-;)R5S)UU;)W!A<F%M<R==(BP@)'9A<FEA8FQE+"`D9')I=F5R*2DI+`H@
M("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]
M"@H@("`@("`@(&9O<F5A8V@@*"1F:65L9',@87,@)&9I96QD*2!["B`@("`@
M("`@("`@(&EF("@A:7-S970H)'!A<F%M<ULD9FEE;&1=*2D@>PH@("`@("`@
M("`@("`@("`@2&]R9&4Z.F9A=&%L*%!%05(Z.G)A:7-E17)R;W(H"B`@("`@
M("`@("`@("`@("`@("`@<W!R:6YT9BA?*")297%U:7)E9"!<(B5S7"(@;F]T
M('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(I+"`D9FEE;&0L("1N
M86UE*2`N(")<;EQN(B`N"B`@("`@("`@("`@("`@("`@("`@<W!R:6YT9BA?
M*")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N(BDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("1F:6QE<F]O="`N("<O8V]N9FEG
M+R<@+B`D9FEL92P*("`@("`@("`@("`@("`@("`@("`@("`@<W!R:6YT9B@B
M)7-;)R5S)UU;)W!A<F%M<R==6R<E<R==(BP@)'9A<FEA8FQE+"`D9')I=F5R
M+"`D9FEE;&0I*2DL"B`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?
M3$E.15]?*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@82!S97-S:6]N+6ED+6EF:65D('9E<G-I;VX@
M;V8@)'5R:2X*("`@("`J($EF(&$@9G5L;"!54DP@:7,@<F5Q=65S=&5D+"!A
M;&P@<&%R86UE=&5R('-E<&%R871O<G,@9V5T(&-O;G9E<G1E9"!T;PH@("`@
M("H@(B8B+"!O=&AE<G=I<V4@=&\@(B9A;7`[(BX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1U<FD@("`@("`@("`@("`@(%1H92!54DD@=&\@8F4@
M;6]D:69I960N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9G5L;"`@("`@("`@
M("`@($=E;F5R871E(&$@9G5L;"`H:'1T<#HO+W-E<G9E<B]P871H+RD*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@55),+@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&%P<&5N9%]S97-S:6]N("`P(#T@;VYL>2!I
M9B!N965D960L(#$@/2!A;'=A>7,L("TQ(#T*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@;F5V97(N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!54DP@=VET:"!T:&4@<V5S<VEO;B!I9"!A<'!E
M;F1E9"`H:68@;F5E9&5D*2X*("`@("`J+PH@("`@9G5N8W1I;VX@=7)L*"1U
M<FDL("1F=6QL(#T@9F%L<V4L("1A<'!E;F1?<V5S<VEO;B`](#`L("1F;W)C
M95]S<VP@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H)&9O<F-E7W-S;"D@
M>PH@("`@("`@("`@("`D9G5L;"`]('1R=64["B`@("`@("`@?0H*("`@("`@
M("!I9B`H)&9U;&PI('L*("`@("`@("`@("`@9VQO8F%L("1C;VYF+"`D<F5G
M:7-T<GDL("1B<F]W<V5R.PH*("`@("`@("`@("`@+RH@4W1O<F4@8V]N;F5C
M=&EO;B!P87)A;65T97)S(&EN(&QO8V%L('9A<FEA8FQE<RX@*B\*("`@("`@
M("`@("`@)'-E<G9E<E]N86UE(#T@)&-O;F9;)W-E<G9E<B==6R=N86UE)UT[
M"B`@("`@("`@("`@("1S97)V97)?<&]R="`]("1C;VYF6R=S97)V97(G75LG
M<&]R="==.PH*("`@("`@("`@("`@)'!R;W1O8V]L(#T@)VAT='`G.PH@("`@
M("`@("`@("!I9B`H)&-O;F9;)W5S95]S<VPG72`]/2`Q*2!["B`@("`@("`@
M("`@("`@("`D<')O=&]C;VP@/2`G:'1T<',G.PH@("`@("`@("`@("!](&5L
M<V5I9B`H)&-O;F9;)W5S95]S<VPG72`]/2`R("8F"B`@("`@("`@("`@("`@
M("`@("`@("`D8G)O=W-E<BT^=7-I;F=34TQ#;VYN96-T:6]N*"DI('L*("`@
M("`@("`@("`@("`@("1P<F]T;V-O;"`]("=H='1P<R<["B`@("`@("`@("`@
M('T@96QS96EF("@D8V]N9ELG=7-E7W-S;"==(#T](#,I('L*("`@("`@("`@
M("`@("`@("1S97)V97)?<&]R="`]("<G.PH@("`@("`@("`@("`@("`@:68@
M*"1F;W)C95]S<VPI('L*("`@("`@("`@("`@("`@("`@("`D<')O=&]C;VP@
M/2`G:'1T<',G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`O*B!)9B!U<VEN9R!N;VXM<W1A;F1A<F0@<&]R=',L(&%D
M9"!T:&4@<&]R="!T;R!T:&4@55),+B`J+PH@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1S97)V97)?<&]R="D@)B8*("`@("`@("`@("`@("`@("@H*"1P<F]T
M;V-O;"`]/2`G:'1T<"<I("8F("@D<V5R=F5R7W!O<G0@(3T@.#`I*2!\?`H@
M("`@("`@("`@("`@("`@("@H)'!R;W1O8V]L(#T]("=H='1P<R<I("8F("@D
M<V5R=F5R7W!O<G0@(3T@-#0S*2DI*2!["B`@("`@("`@("`@("`@("`D<V5R
M=F5R7VYA;64@+CT@)SHG("X@)'-E<G9E<E]P;W)T.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`O*B!3=&]R92!T:&4@=V5B<F]O="!I;B!A(&QO8V%L
M('9A<FEA8FQE+B`J+PH@("`@("`@("`@("`D=V5B<F]O="`]("1R96=I<W1R
M>2T^9V5T*"=W96)R;V]T)RD["@H@("`@("`@("`@("`D=7)L(#T@)'!R;W1O
M8V]L("X@)SHO+R<@+B`D<V5R=F5R7VYA;64["B`@("`@("`@("`@(&EF("AS
M=6)S='(H)'5R:2P@,"P@,2D@(3T@)R\G*2!["B`@("`@("`@("`@("`@("!I
M9B`H<W5B<W1R*"1W96)R;V]T+"`M,2D@/3T@)R\G*2!["B`@("`@("`@("`@
M("`@("`@("`@)'5R;"`N/2`D=V5B<F]O="`N("1U<FD["B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1U<FP@+CT@)'=E
M8G)O;W0@+B`G+R<@+B`D=7)I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'5R;"`N/2`D=7)I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'5R
M;"`]("1U<FD["B`@("`@("`@?0H*("`@("`@("!I9B`H96UP='DH)$=,3T)!
M3%-;)V-O;F8G75LG<V5S<VEO;B==6R=U<V5?;VYL>5]C;V]K:65S)UTI("8F
M"B`@("`@("`@("`@("@H)&%P<&5N9%]S97-S:6]N(#T](#$I('Q\"B`@("`@
M("`@("`@("`H*"1A<'!E;F1?<V5S<VEO;B`]/2`P*2`F)@H@("`@("`@("`@
M("`@("%I<W-E="@D7T-/3TM)15MS97-S:6]N7VYA;64H*5TI*2DI('L*("`@
M("`@("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"!S97-S
M:6]N7VYA;64H*2P@<V5S<VEO;E]I9"@I*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("@D9G5L;"D@>PH@("`@("`@("`@("`O*B!792!N965D('1O(')U;B!T
M:&4@<F5P;&%C92!T=VEC92P@8F5C875S92!W92!O;FQY(&-A=&-H(&5V97)Y
M"B`@("`@("`@("`@("`J('-E8V]N9"!M871C:"X@*B\*("`@("`@("`@("`@
M<F5T=7)N('!R96=?<F5P;&%C92AA<G)A>2@G+R@]/RXJ/RDF86UP.R@N*C\]
M*2\G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<O
M*#T_+BH_*29A;7`[*"XJ/STI+R<I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("<D,28D,B<L("1U<FPI.PH@("`@("`@('T@96QS96EF("AP
M<F5G7VUA=&-H*"<O/2XJ)F%M<#LN*CTO)RP@)'5R;"DI('L*("`@("`@("`@
M("`@<F5T=7)N("1U<FP["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<F5T=7)N(&AT;6QE;G1I=&EE<R@D=7)L*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<V5S<VEO;BUI9"UI9FEE9"!V97)S
M:6]N(&]F("1U<FDL('5S:6YG('1H92!C=7)R96YT"B`@("`@*B!A<'!L:6-A
M=&EO;B=S('=E8G)O;W0@<V5T=&EN9RX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1U<FD@("`@("`@("`@("`@(%1H92!54DD@=&\@8F4@;6]D:69I
M960N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9G5L;"`@("`@("`@("`@($=E
M;F5R871E(&$@9G5L;"`H:'1T<#HO+W-E<G9E<B]P871H+RD*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@55),+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&%P<&5N9%]S97-S:6]N("`P(#T@;VYL>2!I9B!N965D
M960L(#$@/2!A;'=A>7,L("TQ(#T*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@;F5V97(N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!U<FP@=VET:"!T:&4@<V5S<VEO;B!I9"!A<'!E;F1E9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@87!P;&EC871I;VY5<FPH)'5R:2P@)&9U
M;&P@/2!F86QS92P@)&%P<&5N9%]S97-S:6]N(#T@,"D*("`@('L*("`@("`@
M("!I9B`H)&9U;&PI('L*("`@("`@("`@("`@<F5T=7)N($AO<F1E.CIU<FPH
M)'5R:2P@)&9U;&PL("1A<'!E;F1?<V5S<VEO;BD["B`@("`@("`@?0H*("`@
M("`@("!I9B`H<W5B<W1R*"1U<FDL(#`L(#$I("$]("<O)RD@>PH@("`@("`@
M("`@("`D=V5B<F]O="`]("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W=E
M8G)O;W0G*3L*("`@("`@("`@("`@:68@*'-U8G-T<B@D=V5B<F]O="P@+3$I
M("$]("<O)RD@>PH@("`@("`@("`@("`@("`@)'=E8G)O;W0@+CT@)R\G.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1U<FD@/2`D=V5B<F]O="`N("1U
M<FD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@2&]R9&4Z.G5R;"@D=7)I
M+"`D9G5L;"P@)&%P<&5N9%]S97-S:6]N*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@86X@97AT97)N86P@;&EN:R!P87-S960@=&AR;W5G:"!T
M:&4@9&5R969E<G)E<B!T;R!S=')I<"!S97-S:6]N"B`@("`@*B!)1',@9G)O
M;2!T:&4@<F5F97)R97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=7)L("`@5&AE(&5X=&5R;F%L(%523"!T;R!L:6YK('1O+@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)'1A9R`@268@=')U92P@82!C;VUP;&5T92`\83X@=&%G
M(&ES(')E='5R;F5D+"!O;FQY('1H90H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@=7)L(&]T:&5R=VES92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE(&-O<G)E8W0@;&EN:R!T;R!T:&4@9&5R969E<G)E<B!S8W)I
M<'0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X=&5R;F%L57)L*"1U<FPL("1T
M86<@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H:7-S970H)%]#3T]+245;
M<V5S<VEO;E]N86UE*"E=*2D@>PH@("`@("`@("`@("`D97AT(#T@)'5R;#L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D97AT(#T@2&]R9&4Z.G5R
M;"@D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=W96)R;V]T)RP@)VAO<F1E
M)RD@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G+W-E<G9I8V5S
M+V=O+G!H<"<L('1R=64L("TQ*3L*"B`@("`@("`@("`@("\J(%=E(&UU<W0@
M;6%K92!S=7)E('1H97)E(&%R92!N;R`F86UP)W,@:6X@=&AE(%523"X@*B\*
M("`@("`@("`@("`@)'5R;"`]('!R96=?<F5P;&%C92AA<G)A>2@G+R@]/RXJ
M/RDF86UP.R@N*C\]*2\G+"`G+R@]/RXJ/RDF86UP.R@N*C\]*2\G*2P@)R0Q
M)B0R)RP@)'5R;"D["B`@("`@("`@("`@("1E>'0@/2!5=&EL.CIA9&1087)A
M;65T97(H)&5X="P@)W5R;"<L("1U<FPI.PH@("`@("`@('T*("`@("`@("!I
M9B`H)'1A9RD@>PH@("`@("`@("`@("`D97AT(#T@2&]R9&4Z.FQI;FLH)&5X
M="P@)'5R;"P@)R<L("=?8FQA;FLG*3L*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N("1E>'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@55),
M('1O(&)E('5S960@9F]R(&1O=VYL;V%D:6YG+"!T:&%T('1A:V5S(&EN=&\@
M86-C;W5N="!A;GD*("`@("`J('-P96-I86P@8G)O=W-E<B!Q=6ER:W,@*&DN
M92X@244G<R!B<F]K96X@9FEL96YA;64@:&%N9&QI;F<I+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&9I;&5N86UE("!4:&4@9FEL96YA;64@;V8@
M=&AE(&1O=VYL;V%D(&1A=&$N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M
M<R`@("`@06YY(&%D9&ET:6]N86P@<&%R86UE=&5R<R!N965D960N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1U<FP@("`@("`@5&AE(%523"!T;R!A;'1E<BX@
M268@;F]N92!P87-S960@:6XL('=I;&P@=7-E"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@=&AE(&9I;&4@)W9I97<N<&AP)R!L;V-A=&5D(&EN
M('1H92!C=7)R96YT"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M;6]D=6QE)W,@8F%S92!D:7)E8W1O<GDN"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!D;W=N;&]A9"!54DPN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&1O=VYL;V%D57)L*"1F:6QE;F%M92P@)'!A<F%M<R`](&%R<F%Y*"DL
M("1U<FP@/2!N=6QL*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8G)O=W-E<CL*
M"B`@("`@("`@)&AO<F1E7W5R;"`](&9A;'-E.PH*("`@("`@("!I9B`H:7-?
M;G5L;"@D=7)L*2D@>PH@("`@("`@("`@("!G;&]B86P@)')E9VES=')Y.PH@
M("`@("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*$AO<F1E.CIU
M<FPH)')E9VES=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O<V5R
M=FEC97,O9&]W;FQO860O)RDL("=M;V1U;&4G+"`D<F5G:7-T<GDM/F=E=$%P
M<"@I*3L*("`@("`@("`@("`@)&AO<F1E7W5R;"`]('1R=64["B`@("`@("`@
M?0H*("`@("`@("`O*B!!9&0@<&%R86UE=&5R<RX@*B\*("`@("`@("!I9B`H
M(6ES7VYU;&PH)'!A<F%M<RDI('L*("`@("`@("`@("`@)'5R;"`](%5T:6PZ
M.F%D9%!A<F%M971E<B@D=7)L+"`D<&%R86US*3L*("`@("`@("!]"@H@("`@
M("`@("\J($EF('=E(&%R92!U<VEN9R!T:&4@9&5F875L="!(;W)D92!D;W=N
M;&]A9"!L:6YK+"!A9&0@=&AE"B`@("`@("`@("H@9FEL96YA;64@=&\@=&AE
M(&5N9"!O9B!T:&4@55),+B!!;'1H;W5G:"!N;W0@;F5C97-S87)Y(&9O<@H@
M("`@("`@("`J(&UA;GD@8G)O=W-E<G,L('1H:7,@<VAO=6QD(&%L;&]W(&5V
M97)Y(&)R;W=S97(@=&\@9&]W;FQO860*("`@("`@("`@*B!C;W)R96-T;'DN
M("HO"B`@("`@("`@:68@*"1H;W)D95]U<FPI('L*("`@("`@("`@("`@)'5R
M;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`G9FXG+"`G+R<@+B!R87=U
M<FQE;F-O9&4H)&9I;&5N86UE*2D["B`@("`@("`@?2!E;'-E:68@*"1B<F]W
M<V5R+3YH87-1=6ER:R@G8G)E86M?9&ES<&]S:71I;VY?9FEL96YA;64G*2D@
M>PH@("`@("`@("`@("`O*B!3;VUE(&)R;W=S97)S('=I;&P@;VYL>2!O8G1A
M:6X@=&AE(&9I;&5N86UE(&-O<G)E8W1L>0H@("`@("`@("`@("`@*B!I9B!T
M:&4@97AT96YS:6]N(&ES('1H92!L87-T(&%R9W5M96YT(&EN('1H92!Q=65R
M>0H@("`@("`@("`@("`@*B!S=')I;F<@86YD(')E<W0@;V8@=&AE(&9I;&5N
M86UE(&%P<&5A<G,@:6X@=&AE"B`@("`@("`@("`@("`J(%!!5$A?24Y&3R!E
M;&5M96YT+B`J+PH@("`@("`@("`@("`D9FEL96YA;64@/2!R87=U<FQE;F-O
M9&4H)&9I;&5N86UE*3L*"B`@("`@("`@("`@("\J($=E="!T:&4@=V5B<V5R
M=F5R($E$+B`J+PH@("`@("`@("`@("`D<V5R=F5R(#T@2&]R9&4Z.G=E8E-E
M<G9E<DE$*"D["@H@("`@("`@("`@("`O*B!'970@=&AE(&YA;64@86YD(&5X
M=&5N<VEO;B!O9B!T:&4@9FEL92X@($%P86-H92`R(&1O97,*("`@("`@("`@
M("`@("H@3D]4('-U<'!O<G0@4$%42%])3D9/(&EN9F]R;6%T:6]N(&)E:6YG
M('!A<W-E9"!T;R!T:&4*("`@("`@("`@("`@("H@4$A0(&UO9'5L92!B>2!D
M969A=6QT+"!S;R!D:7-A8FQE('1H870*("`@("`@("`@("`@("H@9G5N8W1I
M;VYA;&ET>2X@*B\*("`@("`@("`@("`@:68@*"@D<V5R=F5R("$]("=A<&%C
M:&4R)RDI('L*("`@("`@("`@("`@("`@(&EF("@H)'!O<R`]('-T<G)P;W,H
M)&9I;&5N86UE+"`G+B<I*2D@>PH@("`@("`@("`@("`@("`@("`@("1N86UE
M(#T@)R\G("X@<')E9U]R97!L86-E*"<O7"XO)RP@)R4R12<L('-U8G-T<B@D
M9FEL96YA;64L(#`L("1P;W,I*3L*("`@("`@("`@("`@("`@("`@("`D97AT
M(#T@<W5B<W1R*"1F:6QE;F%M92P@)'!O<RD["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1N86UE(#T@)R\G("X@)&9I
M;&5N86UE.PH@("`@("`@("`@("`@("`@("`@("1E>'0@/2`G)SL*("`@("`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O*B!%;G1E<B!T:&4@4$%4
M2%])3D9/(&EN9F]R;6%T:6]N+B`J+PH@("`@("`@("`@("`@("`@:68@*"@D
M<&]S(#T@<W1R<&]S*"1U<FPL("<_)RDI*2!["B`@("`@("`@("`@("`@("`@
M("`@)'5R;"`]('-U8G-T<B@D=7)L+"`P+"`D<&]S*2`N("1N86UE("X@<W5B
M<W1R*"1U<FPL("1P;W,I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`D=7)L("X]("1N86UE.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!!<'!E;F0@=&AE
M(&5X=&5N<VEO;BP@:68@:70@97AI<W1S+B`J+PH@("`@("`@("`@("!I9B`H
M*"1S97)V97(@/3T@)V%P86-H93(G*2!\?"`A96UP='DH)&5X="DI('L*("`@
M("`@("`@("`@("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@
M)V9N7V5X="<L("<O)R`N("1F:6QE;F%M92D["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D=7)L.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!A;B!A;F-H;W(@=&%G('=I=&@@=&AE(')E;&5V86YT
M('!A<F%M971E<G,*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<FP@
M("`@("`@(%1H92!F=6QL(%523"!T;R!B92!L:6YK960@=&\N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1T:71L92`@("`@(%1H92!L:6YK('1I=&QE+V1E<V-R
M:7!T:6]N+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VQA<W,@("`@("!4:&4@
M0U-3(&-L87-S(&]F('1H92!L:6YK+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=&%R9V5T("`@("!4:&4@=VEN9&]W('1A<F=E="!T;R!P;VEN="!T;RX*("`@
M("`J($!P87)A;2!S=')I;F<@)&]N8VQI8VL@("`@2F%V85-C<FEP="!A8W1I
M;VX@9F]R('1H92`G;VYC;&EC:R<@979E;G0N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1T:71L93(@("`@(%1H92!L:6YK('1I=&QE("AT;V]L=&EP*2`H9&5P
M<F5C871E9"`M(&IU<W0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@=7-E("1T:71L92DN"B`@("`@*B!`<&%R86T@<W1R:6YG("1A8V-E<W-K
M97D@(%1H92!A8V-E<W,@:V5Y('1O('5S92X*("`@("`J($!P87)A;2!A<G)A
M>2`D871T<FEB=71E<R`@06YY(&]T:&5R(&YA;64O=F%L=64@<&%I<G,@=&\@
M861D('1O('1H92`\83X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@=&%G+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&5S8V%P92`@("!7:&5T
M:&5R('1O(&5S8V%P92!S<&5C:6%L(&-H87)A8W1E<G,@:6X@=&AE"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@('1I=&QE(&%T=')I8G5T92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&9U;&P@/&$@:')E
M9CX@=&%G+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:6YK*"1U<FPL("1T:71L
M92`]("<G+"`D8VQA<W,@/2`G)RP@)'1A<F=E="`]("<G+"`D;VYC;&EC:R`]
M("<G+`H@("`@("`@("`@("`@("`@("`D=&ET;&4R(#T@)R<L("1A8V-E<W-K
M97D@/2`G)RP@)&%T=')I8G5T97,@/2!A<G)A>2@I+`H@("`@("`@("`@("`@
M("`@("`D97-C87!E(#T@=')U92D*("`@('L*("`@("`@("!S=&%T:6,@)&-H
M87)S970["B`@("`@("`@:68@*"%I<W-E="@D8VAA<G-E="DI('L*("`@("`@
M("`@("`@)&-H87)S970@/2!.3%,Z.F=E=$-H87)S970H*3L*("`@("`@("!]
M"@H@("`@("`@(&EF("@A96UP='DH)'1I=&QE,BDI('L*("`@("`@("`@("`@
M)'1I=&QE(#T@)'1I=&QE,CL*("`@("`@("!]"@H@("`@("`@("1R970@/2`B
M/&$@:')E9CU<(B1U<FQ<(B(["B`@("`@("`@:68@*"%E;7!T>2@D;VYC;&EC
M:RDI('L*("`@("`@("`@("`@)')E="`N/2`B(&]N8VQI8VL]7"(D;VYC;&EC
M:UPB(CL*("`@("`@("!]"B`@("`@("`@:68@*"%E;7!T>2@D8VQA<W,I*2![
M"B`@("`@("`@("`@("1R970@+CT@(B!C;&%S<SU<(B1C;&%S<UPB(CL*("`@
M("`@("!]"B`@("`@("`@:68@*"%E;7!T>2@D=&%R9V5T*2D@>PH@("`@("`@
M("`@("`D<F5T("X]("(@=&%R9V5T/5PB)'1A<F=E=%PB(CL*("`@("`@("!]
M"B`@("`@("`@:68@*"%E;7!T>2@D=&ET;&4I*2!["B`@("`@("`@("`@(&EF
M("@D97-C87!E*2!["B`@("`@("`@("`@("`@("`D=&ET;&4@/2!N;#)B<BA`
M:'1M;'-P96-I86QC:&%R<RA`:'1M;'-P96-I86QC:&%R<R@D=&ET;&4L($5.
M5%]154]415,L("1C:&%R<V5T*2P@14Y47U%53U1%4RP@)&-H87)S970I*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D<F5T("X]("<@=&ET;&4](B<@
M+B`D=&ET;&4@+B`G(B<["B`@("`@("`@?0H@("`@("`@(&EF("@A96UP='DH
M)&%C8V5S<VME>2DI('L*("`@("`@("`@("`@)')E="`N/2`G(&%C8V5S<VME
M>3TB)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&%C8V5S<VME>2D@+B`G(B<["B`@
M("`@("`@?0H*("`@("`@("!F;W)E86-H("@D871T<FEB=71E<R!A<R`D;F%M
M92`]/B`D=F%L=64I('L*("`@("`@("`@("`@)')E="`N/2`G("<@+B!H=&UL
M<W!E8VEA;&-H87)S*"1N86UE*2`N("<](B<@+B!H=&UL<W!E8VEA;&-H87)S
M*"1V86QU92D@+B`G(B<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@(B1R
M970^(CL*("`@('T*"B`@("`O*BH*("`@("`J(%5S97,@1$]-(%1O;VQT:7!S
M('1O(&1I<W!L87D@=&AE("=T:71L92<@871T<FEB=71E(&9O<@H@("`@("H@
M2&]R9&4Z.FQI;FLH*2!C86QL<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1U<FP@("`@("`@(%1H92!F=6QL(%523"!T;R!B92!L:6YK960@=&\*
M("`@("`J($!P87)A;2!S=')I;F<@)'-T871U<R`@("`@5&AE($IA=F%38W)I
M<'0@;6]U<V4M;W9E<B!S=')I;F<*("`@("`J($!P87)A;2!S=')I;F<@)&-L
M87-S("`@("`@5&AE($-34R!C;&%S<R!O9B!T:&4@;&EN:PH@("`@("H@0'!A
M<F%M('-T<FEN9R`D=&%R9V5T("`@("!4:&4@=VEN9&]W('1A<F=E="!T;R!P
M;VEN="!T;RX*("`@("`J($!P87)A;2!S=')I;F<@)&]N8VQI8VL@("`@2F%V
M85-C<FEP="!A8W1I;VX@9F]R('1H92`G;VYC;&EC:R<@979E;G0N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1T:71L92`@("`@(%1H92!L:6YK('1I=&QE("AT
M;V]L=&EP*2X*("`@("`J($!P87)A;2!S=')I;F<@)&%C8V5S<VME>2`@5&AE
M(&%C8V5S<R!K97D@=&\@=7-E+@H@("`@("H@0'!A<F%M(&%R<F%Y("`D871T
M<FEB=71E<R!!;GD@;W1H97(@;F%M92]V86QU92!P86ER<R!T;R!A9&0@=&\@
M=&AE(#QA/@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!T86<N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!F=6QL(#QA(&AR
M968^('1A9RX*("`@("`J+PH@("`@9G5N8W1I;VX@;&EN:U1O;VQT:7`H)'5R
M;"P@)'-T871U<R`]("<G+"`D8VQA<W,@/2`G)RP@)'1A<F=E="`]("<G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@)&]N8VQI8VL@/2`G)RP@)'1I=&QE
M(#T@)R<L("1A8V-E<W-K97D@/2`G)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("1A='1R:6)U=&5S(#T@87)R87DH*2D*("`@('L*("`@("`@("!S=&%T
M:6,@)&-H87)S970["B`@("`@("`@:68@*"%I<W-E="@D8VAA<G-E="DI('L*
M("`@("`@("`@("`@)&-H87)S970@/2!.3%,Z.F=E=$-H87)S970H*3L*("`@
M("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)'1I=&QE*2D@>PH@("`@("`@
M("`@("`D=&ET;&4@/2`G)FQT.W!R929G=#LG("X@<')E9U]R97!L86-E*&%R
M<F%Y*"<O7&XO)RP@)R\H*#\\(3QB<BE<<WLQ+'TH/SPA7"\^*2DO96TG+"`G
M+SQB<B!<+SX\8G(@7"\^+R<L("<O/&)R(%PO/B\G*2P@87)R87DH)R<L("=S
M=')?<F5P96%T*"(F;F)S<#LB+"!S=')L96XH(B0Q(BDI)RP@)R9L=#MB<B`O
M)F=T.R`F;'0[8G(@+R9G=#LG+"`G)FQT.V)R("\F9W0[)RDL(&YL,F)R*$!H
M=&UL<W!E8VEA;&-H87)S*$!H=&UL<W!E8VEA;&-H87)S*"1T:71L92P@14Y4
M7U%53U1%4RP@)&-H87)S970I+"!%3E1?455/5$53+"`D8VAA<G-E="DI*2`N
M("<F;'0[+W!R929G=#LG.PH@("`@("`@('T*("`@("`@("!R971U<FX@2&]R
M9&4Z.FQI;FLH)'5R;"P@)'1I=&QE+"`D8VQA<W,L("1T87)G970L("1O;F-L
M:6-K+"!N=6QL+"`D86-C97-S:V5Y+"`D871T<FEB=71E<RP@9F%L<V4I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!A;F-H;W(@<V5Q=65N
M8V4@=VET:"!T:&4@<F5L979A;G0@<&%R86UE=&5R<R!F;W(@82!W:61G970*
M("`@("`J('=I=&@@86-C97-S:V5Y(&%N9"!T97AT+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@
M)'5R;"`@("`@(%1H92!F=6QL(%523"!T;R!B92!L:6YK960@=&\N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("`D=&ET;&4@("`@5&AE(&QI;FL@=&ET;&4O9&5S
M8W)I<'1I;VXN"B`@("`@*B!`<&%R86T@<W1R:6YG("`D8VQA<W,@("`@5&AE
M($-34R!C;&%S<R!O9B!T:&4@;&EN:PH@("`@("H@0'!A<F%M('-T<FEN9R`@
M)'1A<F=E="`@(%1H92!W:6YD;W<@=&%R9V5T('1O('!O:6YT('1O+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@)&]N8VQI8VL@($IA=F%38W)I<'0@86-T:6]N
M(&9O<B!T:&4@)V]N8VQI8VLG(&5V96YT+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`@)'1I=&QE,B`@(%1H92!L:6YK('1I=&QE("AT;V]L=&EP*2`H9&5P<F5C
M871E9"`M(&IU<W0@=7-E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1I=&QE*2X*("`@("`J($!P87)A;2!B;V]L96%N("1N;V-H96-K("!$
M;VXG="!C:&5C:R!I9B!T:&4@86-C97-S(&ME>2!A;')E861Y(&AA<R!B965N
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@=7-E9"X@1&5F875L
M=',@=&\@9F%L<V4@*#T@8VAE8VLI+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@9G5L;"`\82!H<F5F/E1I=&QE/"]A/B!S97%U96YC92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@=VED9V5T*"1U<FPL("1T:71L92`]("<G
M+"`D8VQA<W,@/2`G=VED9V5T)RP@)'1A<F=E="`]("<G+`H@("`@("`@("`@
M("`@("`@("`@("1O;F-L:6-K(#T@)R<L("1T:71L93(@/2`G)RP@)&YO8VAE
M8VL@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1T:71L93(I
M*2!["B`@("`@("`@("`@("1T:71L92`]("1T:71L93(["B`@("`@("`@?0H*
M("`@("`@("`D86L@/2!(;W)D93HZ9V5T06-C97-S2V5Y*"1T:71L92P@)&YO
M8VAE8VLI.PH*("`@("`@("!R971U<FX@2&]R9&4Z.FQI;FLH)'5R;"P@)R<L
M("1C;&%S<RP@)'1A<F=E="P@)&]N8VQI8VLL("<G+"`D86LI("X@2&]R9&4Z
M.FAI9VAL:6=H=$%C8V5S<TME>2@D=&ET;&4L("1A:RD@+B`G/"]A/B<["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<V5S<VEO;BUI9"UI9FEE
M9"!V97)S:6]N(&]F("130U))4%1?3D%-12!R97-P+B`D4$A07U-%3$8N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'-C<FEP=%]P87)A;7,@26YC
M;'5D92!S8W)I<'0@<&%R86UE=&5R<R!L:6ME(%%515)97U-44DE.1R!A;F0@
M4$%42%])3D9//PH@("`@("H@0'!A<F%M(&)O;VQE86X@)&YO8V%C:&4@("`@
M("`@26YC;'5D92!A(&YO8V%C:&4@<&%R86UE=&5R(&EN('1H92!54DP_"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B`D9G5L;"`@("`@("`@("!2971U<FX@82!F
M=6QL(%523#\*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E
M<75E<W1E9"!54DDN"B`@("`@*B\*("`@(&9U;F-T:6]N('-E;&95<FPH)'-C
M<FEP=%]P87)A;7,@/2!F86QS92P@)&YO8V%C:&4@/2!T<G5E+"`D9G5L;"`]
M(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`D9F]R8V5?<W-L(#T@9F%L
M<V4I"B`@("!["B`@("`@("`@:68@*'-U8G-T<BAP:'!?<V%P:5]N86UE*"DL
M(#`L(#,I(#T]("=C9VDG*2!["B`@("`@("`@("`@("\O(%=H96X@=7-I;F<@
M0T=)(%!(4"P@4T-225!47TY!344@;6%Y(&-O;G1A:6X@=&AE('!A=&@@=&\*
M("`@("`@("`@("`@+R\@=&AE(%!(4"!B:6YA<GD@:6YS=&5A9"!O9B!T:&4@
M<V-R:7!T(&)E:6YG(')U;CL@=7-E"B`@("`@("`@("`@("\O(%!(4%]314Q&
M(&EN<W1E860N"B`@("`@("`@("`@("1U<FP@/2`D7U-%4E9%4ELG4$A07U-%
M3$8G73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=7)L(#T@:7-S
M970H)%]315)615);)U-#4DE05%].04U%)UTI(#\*("`@("`@("`@("`@("`@
M("1?4T525D526R=30U))4%1?3D%-12==(#H*("`@("`@("`@("`@("`@("1?
M4T525D526R=02%!?4T5,1B==.PH@("`@("`@('T*"B`@("`@("`@:68@*"1S
M8W)I<'1?<&%R86US*2!["B`@("`@("`@("`@(&EF("@A96UP='DH)%]315)6
M15);)U!!5$A?24Y&3R==*2D@>PH@("`@("`@("`@("`@("`@)'5R;"`N/2`D
M7U-%4E9%4ELG4$%42%])3D9/)UT["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*"%E;7!T>2@D7U-%4E9%4ELG455%4EE?4U1224Y')UTI*2!["B`@
M("`@("`@("`@("`@("`D=7)L("X]("<_)R`N("1?4T525D526R=1545265]3
M5%))3D<G73L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)'5R
M;"`]($AO<F1E.CIU<FPH)'5R;"P@)&9U;&PL(#`L("1F;W)C95]S<VPI.PH*
M("`@("`@("!I9B`H)&YO8V%C:&4I('L*("`@("`@("`@("`@<F5T=7)N(%5T
M:6PZ.FYO8V%C:&55<FPH)'5R;"D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@<F5T=7)N("1U<FP["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@0V]N<W1R=6-T<R!A(&-O<G)E8W1L>2UP871H960@;&EN:R!T;R!A
M;B!I;6%G92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S<F,@("!4
M:&4@:6UA9V4@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)&%L="`@(%1E
M>'0@9&5S8W)I8FEN9R!T:&4@:6UA9V4N"B`@("`@*B!`<&%R86T@;6EX960@
M("1A='1R("!!;GD@861D:71I;VYA;"!A='1R:6)U=&5S(&9O<B!T:&4@:6UA
M9V4@=&%G+B!#86X@8F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@(&$@
M<')E+6)U:6QT('-T<FEN9R!O<B!A;B!A<G)A>2!O9B!K97DO=F%L=64@<&%I
M<G,*("`@("`J("`@("`@("`@("`@("`@("`@("`@('1H870@=VEL;"!B92!A
M<W-E;6)L960@86YD(&AT;6PM96YC;V1E9"X*("`@("`J($!P87)A;2!S=')I
M;F<@)&1I<B`@(%1H92!R;V]T(&=R87!H:6-S(&1I<F5C=&]R>2X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&9U;&P@:6UA9V4@=&%G+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!I;6<H)'-R8RP@)&%L="`]("<G+"`D871T
M<B`]("<G+"`D9&ER(#T@;G5L;"D*("`@('L*("`@("`@("!S=&%T:6,@)&-H
M87)S970["B`@("`@("`@:68@*"%I<W-E="@D8VAA<G-E="DI('L*("`@("`@
M("`@("`@)&-H87)S970@/2!.3%,Z.F=E=$-H87)S970H*3L*("`@("`@("!]
M"@H@("`@("`@("\J($EF(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!I;6%G
M97,L('-I;7!L>2!R971U<FX@=&AE($%,5"!T97AT+B`J+PH@("`@("`@(&EF
M("@A)$=,3T)!3%-;)V)R;W=S97(G72T^:&%S1F5A='5R92@G:6UA9V5S)RDI
M('L*("`@("`@("`@("`@<F5T=7)N($!H=&UL<W!E8VEA;&-H87)S*"1A;'0L
M($5.5%]#3TU0050L("1C:&%R<V5T*3L*("`@("`@("!]"@H@("`@("`@("\J
M($EF(&YO(&1I<F5C=&]R>2!H87,@8F5E;B!S<&5C:69I960L(&=E="!I="!F
M<F]M('1H92!R96=I<W1R>2X@*B\*("`@("`@("!I9B`H)&1I<B`]/3T@;G5L
M;"D@>PH@("`@("`@("`@("!G;&]B86P@)')E9VES=')Y.PH@("`@("`@("`@
M("`D9&ER(#T@)')E9VES=')Y+3YG971);6%G941I<B@I.PH@("`@("`@('T*
M"B`@("`@("`@+RH@268@82!D:7)E8W1O<GD@:&%S(&)E96X@<')O=FED960L
M('!R97!E;F0@:70@=&\@=&AE(&EM86=E('-O=7)C92X@*B\*("`@("`@("!I
M9B`H(65M<'1Y*"1D:7(I*2!["B`@("`@("`@("`@("1S<F,@/2`D9&ER("X@
M)R\G("X@)'-R8SL*("`@("`@("!]"@H@("`@("`@("\J($)U:6QD(&%L;"!O
M9B!T:&4@=&%G(&%T=')I8G5T97,N("HO"B`@("`@("`@)&%T=')I8G5T97,@
M/2!A<G)A>2@G<W)C)R`]/B`D<W)C+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)V%L="<@/3X@)&%L="D["B`@("`@("`@:68@*&ES7V%R<F%Y*"1A
M='1R*2D@>PH@("`@("`@("`@("`D871T<FEB=71E<R`](&%R<F%Y7VUE<F=E
M*"1A='1R:6)U=&5S+"`D871T<BD["B`@("`@("`@?0H@("`@("`@(&EF("AE
M;7!T>2@D871T<FEB=71E<ULG=&ET;&4G72DI('L*("`@("`@("`@("`@)&%T
M=')I8G5T97-;)W1I=&QE)UT@/2`G)SL*("`@("`@("!]"@H@("`@("`@("1I
M;6<@/2`G/&EM9R<["B`@("`@("`@9F]R96%C:"`H)&%T=')I8G5T97,@87,@
M)&%T=')I8G5T92`]/B`D=F%L=64I('L*("`@("`@("`@("`@)&EM9R`N/2`G
M("<@+B`D871T<FEB=71E("X@)STB)R`N("@D871T<FEB=71E(#T]("=S<F,G
M(#\@)'9A;'5E(#H@0&AT;6QS<&5C:6%L8VAA<G,H)'9A;'5E+"!%3E1?0T]-
M4$%4+"`D8VAA<G-E="DI("X@)R(G.PH@("`@("`@('T*"B`@("`@("`@+RH@
M268@=&AE('5S97(@<W5P<&QI960@82!P<F4M8G5I;'0@<W1R:6YG(&]F(&%T
M=')I8G5T97,L(&%D9"!T:&%T+B`J+PH@("`@("`@(&EF("AI<U]S=')I;F<H
M)&%T='(I("8F("%E;7!T>2@D871T<BDI('L*("`@("`@("`@("`@)&EM9R`N
M/2`G("<@+B`D871T<CL*("`@("`@("!]"@H@("`@("`@("\J(%)E='5R;B!T
M:&4@8VQO<V5D(&EM86=E('1A9RX@*B\*("`@("`@("!R971U<FX@)&EM9R`N
M("<@+SXG.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE<R!T:&4@
M;&]C871I;VX@;V8@=&AE('-Y<W1E;2!T96UP;W)A<GD@9&ER96-T;W)Y+B!)
M9B!A('-P96-I9FEC"B`@("`@*B!S971T:6YG(&-A;FYO="!B92!F;W5N9"P@
M:70@9&5F875L=',@=&\@+W1M<"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@02!D:7)E8W1O<GD@;F%M92!T:&%T(&-A;B!B92!U<V5D(&9O<B!T
M96UP(&9I;&5S+@H@("`@("H@("`@("`@("`@("`@("`@(%)E='5R;G,@9F%L
M<V4@:68@;VYE(&-O=6QD(&YO="!B92!F;W5N9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T5&5M<$1I<B@I"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF
M.PH*("`@("`@("`O*B!)9B!O;F4@:&%S(&)E96X@<W!E8VEF:6-A;&QY('-E
M="P@=&AE;B!U<V4@=&AA="`J+PH@("`@("`@(&EF("@A96UP='DH)&-O;F9;
M)W1M<&1I<B==*2D@>PH@("`@("`@("`@("`D=&UP(#T@)&-O;F9;)W1M<&1I
M<B==.PH@("`@("`@('T*"B`@("`@("`@+RH@3F5X="P@=')Y(%5T:6PZ.F=E
M=%1E;7!$:7(H*2X@*B\*("`@("`@("!I9B`H96UP='DH)'1M<"DI('L*("`@
M("`@("`@("`@)'1M<"`](%5T:6PZ.F=E=%1E;7!$:7(H*3L*("`@("`@("!]
M"@H@("`@("`@("\J($EF(&ET(&ES('-T:6QL(&5M<'1Y+"!W92!H879E(&9A
M:6QE9"P@<V\@<F5T=7)N(&9A;'-E.PH@("`@("`@("`J(&]T:&5R=VES92!R
M971U<FX@=&AE(&1I<F5C=&]R>2!D971E<FUI;F5D+B`J+PH@("`@("`@(')E
M='5R;B!E;7!T>2@D=&UP*2`_(&9A;'-E(#H@)'1M<#L*("`@('T*"B`@("`O
M*BH*("`@("`J($-R96%T97,@82!T96UP;W)A<GD@9FEL96YA;64@9F]R('1H
M92!L:69E=&EM92!O9B!T:&4@<V-R:7!T+"!A;F0*("`@("`J("AO<'1I;VYA
M;&QY*2!R96=I<W1E<G,@:70@=&\@8F4@9&5L971E9"!A="!R97%U97-T('-H
M=71D;W=N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!R969I>"`@
M(%!R969I>"!T;R!M86ME('1H92!T96UP;W)A<GD@;F%M92!M;W)E"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("!R96-O9VYI>F%B;&4N"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D9&5L971E("!$96QE=&4@=&AE(&9I;&4@870@
M=&AE(&5N9"!O9B!T:&4@<F5Q=65S=#\*("`@("`J($!P87)A;2!S=')I;F<@
M)&1I<B`@("`@($1I<F5C=&]R>2!T;R!C<F5A=&4@=&AE('1E;7!O<F%R>2!F
M:6QE(&EN+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'-E8W5R92`@268@9&5L
M971I;F<@9FEL92P@<VAO=6QD('=E('-E8W5R96QY(&1E;&5T92!T:&4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@(&9I;&4_"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@("!2971U<FYS('1H92!F=6QL('!A=&@M;F%M
M92!T;R!T:&4@=&5M<&]R87)Y(&9I;&4@;W(*("`@("`J("`@("`@("`@("`@
M("`@("`@9F%L<V4@:68@82!T96UP;W)A<GD@9FEL92!C;W5L9"!N;W0@8F4@
M8W)E871E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5&5M<$9I;&4H)'!R
M969I>"`]("=(;W)D92<L("1D96QE=&4@/2!T<G5E+"`D9&ER(#T@)R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`D<V5C=7)E(#T@9F%L<V4I"B`@("![
M"B`@("`@("`@:68@*&5M<'1Y*"1D:7(I('Q\("%I<U]D:7(H)&1I<BDI('L*
M("`@("`@("`@("`@)&1I<B`]($AO<F1E.CIG971496UP1&ER*"D["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@571I;#HZ9V5T5&5M<$9I;&4H)'!R969I
M>"P@)&1E;&5T92P@)&1I<BP@)'-E8W5R92D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3=&%R=',@;W5T<'5T(&-O;7!R97-S:6]N+"!I9B!R97%U97-T960N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;7!R97-S3W5T<'5T*"D*("`@('L*
M("`@("`@("!S=&%T:6,@)'-T87)T960["@H@("`@("`@(&EF("AI<W-E="@D
M<W1A<G1E9"DI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@
M("`@("`@+RH@0V]M<')E<W,@;W5T<'5T(&EF(')E<75E<W1E9"!A;F0@<&]S
M<VEB;&4N("HO"B`@("`@("`@:68@*"1'3$]"04Q36R=C;VYF)UU;)V-O;7!R
M97-S7W!A9V5S)UT@)B8*("`@("`@("`@("`@(21'3$]"04Q36R=B<F]W<V5R
M)UTM/FAA<U%U:7)K*"=B=6=G>5]C;VUP<F5S<VEO;B<I("8F"B`@("`@("`@
M("`@("$H8F]O;"EI;FE?9V5T*"=Z;&EB+F]U='!U=%]C;VUP<F5S<VEO;B<I
M("8F"B`@("`@("`@("`@("$H8F]O;"EI;FE?9V5T*"=Z96YD7V%C8V5L97)A
M=&]R+F-O;7!R97-S7V%L;"<I("8F"B`@("`@("`@("`@(&EN:5]G970H)V]U
M='!U=%]H86YD;&5R)RD@(3T@)V]B7V=Z:&%N9&QE<B<I('L*("`@("`@("`@
M("`@:68@*&]B7V=E=%]L979E;"@I*2!["B`@("`@("`@("`@("`@("!O8E]E
M;F1?8VQE86XH*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!O8E]S=&%R
M="@G;V)?9WIH86YD;&5R)RD["B`@("`@("`@?0H*("`@("`@("`D<W1A<G1E
M9"`]('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S(&EF
M(&]U='!U="!C;VUP<F5S<VEO;B!C86X@8F4@=7-E9"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@;W5T<'5T(&-O;7!R97-S:6]N
M(&-A;B!B92!U<V5D+"!F86QS92!I9B!N;W0N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%L;&]W3W5T<'5T0V]M<')E<W-I;VXH*0H@("`@>PH@("`@("`@(')E
M<75I<F5?;VYC92`G2&]R9&4O0G)O=W-E<BYP:'`G.PH@("`@("`@("1B<F]W
M<V5R(#T@)D)R;W=S97(Z.G-I;F=L971O;B@I.PH*("`@("`@("`O*B!4=7)N
M(&]F9B!C;VUP<F5S<VEO;B!F;W(@8G5G9WD@8G)O=W-E<G,N("HO"B`@("`@
M("`@:68@*"1B<F]W<V5R+3YH87-1=6ER:R@G8G5G9WE?8V]M<')E<W-I;VXG
M*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@*&EN:5]G970H)WIL:6(N;W5T<'5T7V-O;7!R97-S:6]N
M)RD@/3T@)R<@)B8*("`@("`@("`@("`@("`@(&EN:5]G970H)WIE;F1?86-C
M96QE<F%T;W(N8V]M<')E<W-?86QL)RD@/3T@)R<@)B8*("`@("`@("`@("`@
M("`@(&EN:5]G970H)V]U='!U=%]H86YD;&5R)RD@(3T@)V]B7V=Z:&%N9&QE
M<B<I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@5V5B('-E
M<G9E<B!B96EN9R!U<V5D+@H@("`@("H@4$A0('-T<FEN9R!L:7-T(&)U:6QT
M(&9R;VT@=&AE(%!(4"`G8V]N9FEG=7)E)R!S8W)I<'0N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@($$@=V5B('-E<G9E<B!I9&5N=&EF:6-A=&EO
M;B!S=')I;F<N"B`@("`@*B`\<')E/@H@("`@("H@)V%O;'-E<G9E<B<@/2!!
M3TP@4V5R=F5R"B`@("`@*B`G87!A8VAE,2<@("`]($%P86-H92`Q+G@*("`@
M("`J("=A<&%C:&4R)R`@(#T@07!A8VAE(#(N>`H@("`@("H@)V-A=61I=6TG
M("`@/2!#875D:75M"B`@("`@*B`G8V=I)R`@("`@("`](%5N:VYO=VX@<V5R
M=F5R("T@4$A0(&)U:6QT(&%S($-'22!P<F]G<F%M"B`@("`@*B`G8VQI)R`@
M("`@("`]($-O;6UA;F0@3&EN92!);G1E<F9A8V4@8G5I;&0*("`@("`J("=E
M;6)E9"<@("`@(#T@16UB961D960@4$A0"B`@("`@*B`G:7-A<&DG("`@("`]
M(%IE=7,@25-!4$D*("`@("`J("=M:6QT97(G("`@(#T@36EL=&5R"B`@("`@
M*B`G;G-A<&DG("`@("`]($Y305!)"B`@("`@*B`G<&AT='!D)R`@("`](%!(
M5%101`H@("`@("H@)W!I,W=E8B<@("`@/2!0:3-796(*("`@("`J("=R;WAE
M;B<@("`@(#T@4F]X96XO4&EK90H@("`@("H@)W-E<G9L970G("`@/2!397)V
M;&5T"B`@("`@*B`G=&AT='!D)R`@("`]('1H='1P9`H@("`@("H@)W1U>"<@
M("`@("`@/2!4=7@*("`@("`J("=W96)J86UE<R<@(#T@5V5B:F%M97,*("`@
M("`J(#PO<')E/@H@("`@("HO"B`@("!F=6YC=&EO;B!W96)397)V97))1"@I
M"B`@("!["B`@("`@("`@)'-E<G9E<B`]('!H<%]S87!I7VYA;64H*3L*"B`@
M("`@("`@:68@*"1S97)V97(@/3T@)V%P86-H92<I('L*("`@("`@("`@("`@
M<F5T=7)N("=A<&%C:&4Q)SL*("`@("`@("!](&5L<V5I9B`H*"1S97)V97(@
M/3T@)V%P86-H93)F:6QT97(G*2!\?`H@("`@("`@("`@("`@("`@("`H)'-E
M<G9E<B`]/2`G87!A8VAE,FAA;F1L97(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)V%P86-H93(G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B`D<V5R=F5R.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=&AE(#QL:6YK/B!T86=S(&9O<B!T:&4@0U-3('-T>6QE<VAE
M971S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F=\87)R87D@)&%P<"`@
M5&AE($AO<F1E(&%P<&QI8V%T:6]N*',I+@H@("`@("H@0'!A<F%M(&UI>&5D
M("1T:&5M92`@("`@("!4:&4@=&AE;64@=&\@=7-E.R!S<&5C:69Y(&%N(&5M
M<'1Y('9A;'5E('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M(')E=')I979E('1H92!T:&5M92!F<F]M('5S97(@<')E9F5R96YC97,L(&%N
M9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!F86QS92!F;W(@
M;F\@=&AE;64N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D:6YH97)I="`@($EN
M:&5R:70@2&]R9&4M=VED92!#4U,_"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(#QL:6YK/B!T86=S(&9O<B!#4U,@<W1Y;&5S:&5E=',N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-T>6QE<VAE971,:6YK*"1A<'!S(#T@;G5L;"P@
M)'1H96UE(#T@)R<L("1I;FAE<FET(#T@=')U92D*("`@('L*("`@("`@("!I
M9B`H)'1H96UE(#T]/2`G)R`F)B!I<W-E="@D1TQ/0D%,4ULG<')E9G,G72DI
M('L*("`@("`@("`@("`@)'1H96UE(#T@)$=,3T)!3%-;)W!R969S)UTM/F=E
M=%9A;'5E*"=T:&5M92<I.PH@("`@("`@('T*"B`@("`@("`@)')T;"`](&ES
M<V5T*"1'3$]"04Q36R=N;',G75LG<G1L)UU;)$=,3T)!3%-;)VQA;F=U86=E
M)UU=*3L*("`@("`@("`D8W-S(#T@87)R87DH*3L*"B`@("`@("`@)'1H96UE
M<U]F<R`]("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W1H96UE<V9S)RP@
M)VAO<F1E)RD["B`@("`@("`@:68@*"1I;FAE<FET*2!["B`@("`@("`@("`@
M("1T:&5M97-?=7)I(#T@2&]R9&4Z.G5R;"@D1TQ/0D%,4ULG<F5G:7-T<GDG
M72T^9V5T*"=T:&5M97-U<FDG+"`G:&]R9&4G*2P@9F%L<V4L("TQ*3L*("`@
M("`@("`@("`@)&-S<UM=(#T@)'1H96UE<U]U<FD@+B`G+W-C<F5E;BYC<W,G
M.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&5M92D@)B8*("`@("`@("`@
M("`@("`@(&9I;&5?97AI<W1S*"1T:&5M97-?9G,@+B`G+R<@+B`D=&AE;64@
M+B`G+W-C<F5E;BYC<W,G*2D@>PH@("`@("`@("`@("`@("`@)&-S<UM=(#T@
M)'1H96UE<U]U<FD@+B`G+R<@+B`D=&AE;64@+B`G+W-C<F5E;BYC<W,G.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)')T;"D@>PH@("`@("`@
M("`@("`@("`@)&-S<UM=(#T@)'1H96UE<U]U<FD@+B`G+W)T;"YC<W,G.PH@
M("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D=&AE;64I("8F"B`@("`@("`@
M("`@("`@("`@("`@9FEL95]E>&ES=',H)'1H96UE<U]F<R`N("<O)R`N("1T
M:&5M92`N("<O<G1L+F-S<R<I*2!["B`@("`@("`@("`@("`@("`@("`@)&-S
M<UM=(#T@)'1H96UE<U]U<FD@+B`G+R<@+B`D=&AE;64@+B`G+W)T;"YC<W,G
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!I9B`H(65M<'1Y*"1A<'!S*2D@>PH@("`@("`@("`@("!I9B`H
M(6ES7V%R<F%Y*"1A<'!S*2D@>PH@("`@("`@("`@("`@("`@)&%P<',@/2!A
M<G)A>2@D87!P<RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1A<'!S(&%S("1A<'`I('L*("`@("`@("`@("`@("`@(&EF("@D:6YH
M97)I="`F)B`D87!P(#T]("=H;W)D92<I('L*("`@("`@("`@("`@("`@("`@
M("!C;VYT:6YU93L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@
M("`D=&AE;65S7V9S(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=&AE
M;65S9G,G+"`D87!P*3L*("`@("`@("`@("`@("`@("1T:&5M97-?=7)I(#T@
M2&]R9&4Z.G5R;"@D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=T:&5M97-U
M<FDG+"`D87!P*2P@9F%L<V4L("TQ*3L*("`@("`@("`@("`@("`@(&EF("AF
M:6QE7V5X:7-T<R@D=&AE;65S7V9S("X@)R]S8W)E96XN8W-S)RDI('L*("`@
M("`@("`@("`@("`@("`@("`D8W-S6UT@/2`D=&AE;65S7W5R:2`N("<O<V-R
M965N+F-S<R<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I
M9B`H(65M<'1Y*"1T:&5M92D@)B8*("`@("`@("`@("`@("`@("`@("!F:6QE
M7V5X:7-T<R@D=&AE;65S7V9S("X@)R\G("X@)'1H96UE("X@)R]S8W)E96XN
M8W-S)RDI('L*("`@("`@("`@("`@("`@("`@("`D8W-S6UT@/2`D=&AE;65S
M7W5R:2`N("<O)R`N("1T:&5M92`N("<O<V-R965N+F-S<R<["B`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*"1R=&PI('L*("`@("`@
M("`@("`@("`@("`@("!I9B`H9FEL95]E>&ES=',H)'1H96UE<U]F<R`N("<O
M<G1L+F-S<R<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1C<W-;72`]
M("1T:&5M97-?=7)I("X@)R]R=&PN8W-S)SL*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D=&AE;64I("8F
M"B`@("`@("`@("`@("`@("`@("`@("`@(&9I;&5?97AI<W1S*"1T:&5M97-?
M9G,@+B`G+R<@+B`D=&AE;64@+B`G+W)T;"YC<W,G*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D8W-S6UT@/2`D=&AE;65S7W5R:2`N("<O)R`N("1T
M:&5M92`N("<O<G1L+F-S<R<["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`D:'1M;"`]("<G.PH@("`@("`@(&9O<F5A8V@@*"1C<W,@87,@)&-S<U]L
M:6YK*2!["B`@("`@("`@("`@("1H=&UL("X]("<\;&EN:R!H<F5F/2(G("X@
M)&-S<U]L:6YK("X@)R(@<F5L/2)S='EL97-H965T(B!T>7!E/2)T97AT+V-S
M<R(@+SXG("X@(EQN(CL*("`@("`@("!]"@H@("`@("`@("\J($QO860@244@
M4$Y'('1R86YS<&%R96YC>2!C;V1E(&EF(&YE961E9"X@*B\*("`@("`@("!I
M9B`H)$=,3T)!3%-;)V)R;W=S97(G72T^:&%S475I<FLH)W!N9U]T<F%N<W!A
M<F5N8WDG*2`F)@H@("`@("`@("`@("`D1TQ/0D%,4ULG<')E9G,G72T^9V5T
M5F%L=64H)V%L<&AA7V9I;'1E<B<I*2!["B`@("`@("`@("`@("1U<FP@/2!(
M;W)D93HZ=7)L*"1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)VIS=7)I)RP@
M)VAO<F1E)RD@+B`G+V%L<&AA26UA9V5,;V%D97(N<&AP)RP@=')U92P@+3$I
M.PH@("`@("`@("`@("`D:'1M;"`N/2`G/'-T>6QE('1Y<&4](G1E>'0O8W-S
M(CX@:6UG('L@8F5H879I;W(Z('5R;"@B)R`N("1U<FP@+B`G(BD[('T@/"]S
M='EL93XG.PH@("`@("`@('T*"B`@("`@("`@+RH@3&]A9"!B<F]W<V5R('-P
M96-I9FEC('-T>6QE<VAE971S(&EF(&YE961E9"X@*B\*("`@("`@("!I9B`H
M)$=,3T)!3%-;)V)R;W=S97(G72T^:7-"<F]W<V5R*"=M<VEE)RD@)B8@)$=,
M3T)!3%-;)V)R;W=S97(G72T^9V5T36%J;W(H*2`\(#<I('L*("`@("`@("`@
M("`@)&AT;6P@+CT@)SQL:6YK(&AR968](B<@+B`D1TQ/0D%,4ULG<F5G:7-T
M<GDG72T^9V5T*"=T:&5M97-U<FDG+"`G:&]R9&4G*2`N("<O:64V7V]R7VQE
M<W,N8W-S(B!R96P](G-T>6QE<VAE970B('1Y<&4](G1E>'0O8W-S(B`O/B<@
M+B`B7&XB.PH@("`@("`@("`@("!I9B`H)$=,3T)!3%-;)V)R;W=S97(G72T^
M9V5T4&QA=&9O<FTH*2`]/2`G;6%C)RD@>PH@("`@("`@("`@("`@("`@)&AT
M;6P@+CT@)SQL:6YK(&AR968](B<@+B`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^
M9V5T*"=T:&5M97-U<FDG+"`G:&]R9&4G*2`N("<O:64U;6%C+F-S<R(@<F5L
M/2)S='EL97-H965T(B!T>7!E/2)T97AT+V-S<R(@+SXG("X@(EQN(CL*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H)$=,3T)!3%-;)V)R
M;W=S97(G72T^:7-"<F]W<V5R*"=O<&5R82<I*2!["B`@("`@("`@("`@("1H
M=&UL("X]("<\;&EN:R!H<F5F/2(G("X@)$=,3T)!3%-;)W)E9VES=')Y)UTM
M/F=E="@G=&AE;65S=7)I)RP@)VAO<F1E)RD@+B`G+V]P97)A+F-S<R(@<F5L
M/2)S='EL97-H965T(B!T>7!E/2)T97AT+V-S<R(@+SXG("X@(EQN(CL*("`@
M("`@("!]"B`@("`@("`@:68@*"1'3$]"04Q36R=B<F]W<V5R)UTM/FES0G)O
M=W-E<B@G;6]Z:6QL82<I("8F"B`@("`@("`@("`@("1'3$]"04Q36R=B<F]W
M<V5R)UTM/F=E=$UA:F]R*"D@/CT@-2`F)@H@("`@("`@("`@("!P<F5G7VUA
M=&-H*"<O<G8Z*"XJ*5PI+R<L("1'3$]"04Q36R=B<F]W<V5R)UTM/F=E=$%G
M96YT4W1R:6YG*"DL("1R979I<VEO;BD@)B8*("`@("`@("`@("`@)')E=FES
M:6]N6S%=(#P](#$N-"D@>PH@("`@("`@("`@("`D:'1M;"`N/2`G/&QI;FL@
M:')E9CTB)R`N("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W1H96UE<W5R
M:2<L("=H;W)D92<I("X@)R]M;WHQ-"YC<W,B(')E;#TB<W1Y;&5S:&5E="(@
M='EP93TB=&5X="]C<W,B("\^)R`N(")<;B(["B`@("`@("`@?0H@("`@("`@
M(&EF("AS=')P;W,H<W1R=&]L;W=E<B@D1TQ/0D%,4ULG8G)O=W-E<B==+3YG
M971!9V5N=%-T<FEN9R@I*2P@)W-A9F%R:2<I("$]/2!F86QS92D@>PH@("`@
M("`@("`@("`D:'1M;"`N/2`G/&QI;FL@:')E9CTB)R`N("1'3$]"04Q36R=R
M96=I<W1R>2==+3YG970H)W1H96UE<W5R:2<L("=H;W)D92<I("X@)R]S869A
M<FDN8W-S(B!R96P](G-T>6QE<VAE970B('1Y<&4](G1E>'0O8W-S(B`O/B<@
M+B`B7&XB.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1H=&UL.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4V5T<R!A(&-U<W1O;2!S97-S:6]N(&AA;F1L
M97(@=7`L(&EF('1H97)E(&ES(&]N92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<V5T=7!397-S:6]N2&%N9&QE<B@I"B`@("!["B`@("`@("`@9VQO8F%L("1C
M;VYF.PH*("`@("`@("!I;FE?<V5T*"=U<FQ?<F5W<FET97(N=&%G<R<L(#`I
M.PH@("`@("`@(&EF("@A96UP='DH)&-O;F9;)W-E<W-I;VXG75LG=7-E7V]N
M;'E?8V]O:VEE<R==*2D@>PH@("`@("`@("`@("!I;FE?<V5T*"=S97-S:6]N
M+G5S95]O;FQY7V-O;VMI97,G+"`Q*3L*("`@("`@("`@("`@:68@*"%E;7!T
M>2@D8V]N9ELG8V]O:VEE)UU;)V1O;6%I;B==*2`F)@H@("`@("`@("`@("`@
M("`@<W1R<&]S*"1C;VYF6R=S97)V97(G75LG;F%M92==+"`G+B<I(#T]/2!F
M86QS92D@>PH@("`@("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-E
M<W-I;VX@8V]O:VEE<R!W:6QL(&YO="!W;W)K('=I=&AO=70@82!&441.(&%N
M9"!W:71H(&$@;F]N+65M<'1Y(&-O;VMI92!D;VUA:6XN)RP@7U]&24Q%7U\L
M(%]?3$E.15]?+"!014%27TQ/1U]705).24Y'*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!S97-S:6]N7W-E=%]C;V]K:65?<&%R86US*"1C
M;VYF6R=S97-S:6]N)UU;)W1I;65O=70G72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1C;VYF6R=C;V]K:64G75LG<&%T:"==+"`D8V]N
M9ELG8V]O:VEE)UU;)V1O;6%I;B==+"`D8V]N9ELG=7-E7W-S;"==(#T](#$@
M/R`Q(#H@,"D["B`@("`@("`@<V5S<VEO;E]C86-H95]L:6UI=&5R*"1C;VYF
M6R=S97-S:6]N)UU;)V-A8VAE7VQI;6ET97(G72D["B`@("`@("`@<V5S<VEO
M;E]N86UE*'5R;&5N8V]D92@D8V]N9ELG<V5S<VEO;B==6R=N86UE)UTI*3L*
M"B`@("`@("`@)'1Y<&4@/2`A96UP='DH)&-O;F9;)W-E<W-I;VYH86YD;&5R
M)UU;)W1Y<&4G72D@/R`D8V]N9ELG<V5S<VEO;FAA;F1L97(G75LG='EP92==
M(#H@)VYO;F4G.PH*("`@("`@("!I9B`H)'1Y<&4@/3T@)V5X=&5R;F%L)RD@
M>PH@("`@("`@("`@("`D8V%L;',@/2`D8V]N9ELG<V5S<VEO;FAA;F1L97(G
M75LG<&%R86US)UT["B`@("`@("`@("`@('-E<W-I;VY?<V5T7W-A=F5?:&%N
M9&QE<B@D8V%L;'-;)V]P96XG72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1C86QL<ULG8VQO<V4G72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1C86QL<ULG<F5A9"==+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-A;&QS6R=W<FET92==
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-A;&QS
M6R=D97-T<F]Y)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D8V%L;'-;)V=C)UTI.PH@("`@("`@('T@96QS96EF("@D='EP92`A
M/2`G;F]N92<I('L*("`@("`@("`@("`@9VQO8F%L("1?<V5S<VEO;E]H86YD
M;&5R.PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U-E<W-I;VY(
M86YD;&5R+G!H<"<["B`@("`@("`@("`@("1?<V5S<VEO;E]H86YD;&5R(#T@
M)E-E<W-I;VY(86YD;&5R.CIS:6YG;&5T;VXH)&-O;F9;)W-E<W-I;VYH86YD
M;&5R)UU;)W1Y<&4G72D["B`@("`@("`@("`@(&EF("@A96UP='DH)%]S97-S
M:6]N7VAA;F1L97(I("8F"B`@("`@("`@("`@("`@("`A:7-?82@D7W-E<W-I
M;VY?:&%N9&QE<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@
M:6YI7W-E="@G<V5S<VEO;BYS879E7VAA;F1L97(G+"`G=7-E<B<I.PH@("`@
M("`@("`@("`@("`@<V5S<VEO;E]S971?<V%V95]H86YD;&5R*&%R<F%Y*"8D
M7W-E<W-I;VY?:&%N9&QE<BP@)V]P96XG*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@F)%]S97-S:6]N7VAA;F1L
M97(L("=C;&]S92<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*"8D7W-E<W-I;VY?:&%N9&QE<BP@)W)E860G*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@F)%]S97-S:6]N7VAA;F1L97(L("=W<FET92<I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"8D7W-E<W-I;VY?
M:&%N9&QE<BP@)V1E<W1R;WDG*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@F)%]S97-S:6]N7VAA;F1L97(L("=G
M8R<I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@($AO
M<F1E.CIF871A;"A014%2.CIR86ES945R<F]R*"=(;W)D92!I<R!U;F%B;&4@
M=&\@8V]R<F5C=&QY('-T87)T('1H92!C=7-T;VT@<V5S<VEO;B!H86YD;&5R
M+B<I+"!?7T9)3$5?7RP@7U],24Y%7U\L(&9A;'-E*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86X@
M=6XM=7-E9"!A8V-E<W,@:V5Y(&9R;VT@=&AE(&QA8F5L(&=I=F5N+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&QA8F5L("`@("!4:&4@;&%B96P@
M=&\@8VAO;W-E(&%N(&%C8V5S<R!K97D@9G)O;2X*("`@("`J($!P87)A;2!B
M;V]L96%N("1N;V-H96-K("!$;VXG="!C:&5C:R!I9B!T:&4@86-C97-S(&ME
M>2!A;')E861Y(&AA<R!B965N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@=7-E9#\*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@02!S
M:6YG;&4@;&]W97(@8V%S92!C:&%R86-T97(@86-C97-S(&ME>2!O<B!E;7!T
M>0H@("`@("H@("`@("`@("`@("`@("`@('-T<FEN9R!I9B!N;VYE(&-A;B!B
M92!F;W5N9`H@("`@("HO"B`@("!F=6YC=&EO;B!G971!8V-E<W-+97DH)&QA
M8F5L+"`D;F]C:&5C:R`](&9A;'-E+"`D<VAU=&1O=VX@/2!F86QS92D*("`@
M('L*("`@("`@("`O*B!4:&4@86-C97-S(&ME>7,@86QR96%D>2!U<V5D(&EN
M('1H:7,@<&%G92`J+PH@("`@("`@('-T871I8R`D7W5S960@/2!A<G)A>2@I
M.PH*("`@("`@("`O*B!4:&4@;&%B96QS(&%L<F5A9'D@=7-E9"!I;B!T:&ES
M('!A9V4@*B\*("`@("`@("!S=&%T:6,@)%]L86)E;',@/2!A<G)A>2@I.PH*
M("`@("`@("`O*B!3:'5T9&]W;B!C86QL(&9O<B!T<F%N<VQA=&]R<S\@*B\*
M("`@("`@("!I9B`H)'-H=71D;W=N*2!["B`@("`@("`@("`@(&EF("@A8V]U
M;G0H)%]L86)E;',I*2!["B`@("`@("`@("`@("`@("!R971U<FX["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)'-C<FEP="`](&)A<V5N86UE*"1?4T52
M5D526R=02%!?4T5,1B==*3L*("`@("`@("`@("`@)&QA8F5L<R`](&%R<F%Y
M7VME>7,H)%]L86)E;',I.PH@("`@("`@("`@("!S;W)T*"1L86)E;',I.PH@
M("`@("`@("`@("`D=7-E9"`](&%R<F%Y7VME>7,H)%]U<V5D*3L*("`@("`@
M("`@("`@<V]R="@D=7-E9"D["B`@("`@("`@("`@("1R96UA:6YI;F<@/2!S
M=')?<F5P;&%C92@D=7-E9"P@87)R87DH*2P@)V%B8V1E9F=H:6IK;&UN;W!Q
M<G-T=79W>'EZ)RD["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=!
M8V-E<W,@:V5Y(&EN9F]R;6%T:6]N(&9O<B`G("X@)'-C<FEP="P@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H
M)U5S960@;&%B96QS.B`G("X@:6UP;&]D92@G+"<L("1L86)E;',I+"!?7T9)
M3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G
M92@G57-E9"!K97ES.B`G("X@:6UP;&]D92@G)RP@)'5S960I+"!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G
M1G)E92!K97ES.B`G("X@)')E;6%I;FEN9RP@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@+RH@
M57-E(&%C8V5S<R!K97ES(&%T(&%L;#\@*B\*("`@("`@("!S=&%T:6,@)&YO
M='-U<'!O<G1E9#L*("`@("`@("!I9B`H(6ES<V5T*"1N;W1S=7!P;W)T960I
M*2!["B`@("`@("`@("`@("1N;W1S=7!P;W)T960@/2`A)$=,3T)!3%-;)V)R
M;W=S97(G72T^:&%S1F5A='5R92@G86-C97-S:V5Y)RD@?'P*("`@("`@("`@
M("`@("`@("$D1TQ/0D%,4ULG<')E9G,G72T^9V5T5F%L=64H)W=I9&=E=%]A
M8V-E<W-K97DG*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D;F]T<W5P<&]R
M=&5D('Q\("%P<F5G7VUA=&-H*"<O7RA;02U:82UZ72DO)RP@)&QA8F5L+"`D
M;6%T8V@I*2!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("!]"B`@
M("`@("`@)&ME>2`]("1M871C:%LQ73L*"B`@("`@("`@+RH@2&%S('1H:7,@
M:V5Y(&%L<F5A9'D@8F5E;B!U<V5D/R`J+PH@("`@("`@(&EF("AI<W-E="@D
M7W5S961;<W1R=&]L;W=E<B@D:V5Y*5TI("8F"B`@("`@("`@("`@("$H)&YO
M8VAE8VL@)B8@:7-S970H)%]L86)E;'-;)&QA8F5L72DI*2!["B`@("`@("`@
M("`@(')E='5R;B`G)SL*("`@("`@("!]"@H@("`@("`@("\J(%-A=F4@:V5Y
M(&%N9"!L86)E;"X@*B\*("`@("`@("`D7W5S961;<W1R=&]L;W=E<B@D:V5Y
M*5T@/2!T<G5E.PH@("`@("`@("1?;&%B96QS6R1L86)E;%T@/2!T<G5E.PH*
M("`@("`@("!R971U<FX@)&ME>3L*("`@('T*"B`@("`O*BH*("`@("`J(%-T
M<FEP<R!A;B!A8V-E<W,@:V5Y(&9R;VT@82!L86)E;"X*("`@("`J($9O<B!M
M=6QT:6)Y=&4@8VAA<G-E="!S=')I;F=S('1H92!A8V-E<W,@:V5Y(&=E=',@
M<F5M;W9E9"!C;VUP;&5T96QY+`H@("`@("H@;W1H97)W:7-E(&]N;'D@=&AE
M('5N9&5R<V-O<F4@9V5T<R!R96UO=F5D+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&QA8F5L("!4:&4@;&%B96P@8V]N=&%I;FEN9R!A;B!A8V-E
M<W,@:V5Y+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;&%B
M96P@=VET:"!T:&4@86-C97-S(&ME>2!B96EN9R!S=')I<'!E9"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<W1R:7!!8V-E<W-+97DH)&QA8F5L*0H@("`@>PH@
M("`@("`@(&EN8VQU9&5?;VYC92!(3U)$15]"05-%("X@)R]C;VYF:6<O;FQS
M+G!H<"<["B`@("`@("`@)&UU;'1I8GET92`](&ES<V5T*"1'3$]"04Q36R=N
M;',G75LG;75L=&EB>71E)UU;3DQ3.CIG971#:&%R<V5T*'1R=64I72D["@H@
M("`@("`@(')E='5R;B!P<F5G7W)E<&QA8V4H)R]?*%M!+5IA+7I=*2\G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&UU;'1I8GET92`F)B!P<F5G
M7VUA=&-H*"<O6UQX.#`M7'AF9ETO)RP@)&QA8F5L*2`_("<G(#H@)UPQ)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1L86)E;"D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!(:6=H;&EG:'1S(&%N(&%C8V5S<R!K97D@:6X@82!L
M86)E;"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1L86)E;"`@("`@
M(%1H92!L86)E;"!T;R!T;R!H:6=H;&EG:'0@=&AE(&%C8V5S<R!K97D@:6XN
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1A8V-E<W-+97D@(%1H92!A8V-E<W,@
M:V5Y('1O(&AI9VAL:6=H="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE($A434P@=F5R<VEO;B!O9B!T:&4@;&%B96P@=VET:"!T:&4@86-C
M97-S(&ME>0H@("`@("H@("`@("`@("`@("`@("`@(&AI9VAL:6=H=&5D+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!H:6=H;&EG:'1!8V-E<W-+97DH)&QA8F5L
M+"`D86-C97-S2V5Y*0H@("`@>PH@("`@("`@("1S=')I<'!E9%]L86)E;"`]
M($AO<F1E.CIS=')I<$%C8V5S<VME>2@D;&%B96PI.PH*("`@("`@("!I9B`H
M96UP='DH)&%C8V5S<TME>2DI('L*("`@("`@("`@("`@<F5T=7)N("1S=')I
M<'!E9%]L86)E;#L*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D1TQ/
M0D%,4ULG;FQS)UU;)VUU;'1I8GET92==6TY,4SHZ9V5T0VAA<G-E="AT<G5E
M*5TI*2!["B`@("`@("`@("`@(')E='5R;B`D<W1R:7!P961?;&%B96P@+B`G
M*"<@+B`G/'-P86X@8VQA<W,](F%C8V5S<TME>2(^)R`N"B`@("`@("`@("`@
M("`@("!S=')T;W5P<&5R*"1A8V-E<W-+97DI("X@)SPO<W!A;CXG("X@)RDG
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!S=')?<F5P
M;&%C92@G7R<@+B`D86-C97-S2V5Y+"`G/'-P86X@8VQA<W,](F%C8V5S<TME
M>2(^)R`N("1A8V-E<W-+97D@+B`G/"]S<&%N/B<L("1L86)E;"D["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@87!P<F]P
M<FEA=&4@(F%C8V5S<VME>2(@86YD(")T:71L92(@871T<FEB=71E<R!F;W(@
M86X@2%1-3`H@("`@("H@=&%G(&%N9"!T:&4@9VEV96X@;&%B96PN"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;&%B96P@("`@(%1H92!T:71L92!O
M9B!A;B!(5$U,(&5L96UE;G0*("`@("`J($!P87)A;2!B;V]L96%N("1N;V-H
M96-K("!$;VXG="!C:&5C:R!I9B!T:&4@86-C97-S(&ME>2!A;')E861Y(&AA
M<R!B965N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@=7-E9#\*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('1I=&QE+"!A;F0@
M:68@87!P<F]P<FEA=&4L('1H92!A8V-E<W-K97D@871T<FEB=71E<PH@("`@
M("H@("`@("`@("`@("`@("`@(&9O<B!T:&4@96QE;65N="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T06-C97-S2V5Y06YD5&ET;&4H)&QA8F5L+"`D;F]C
M:&5C:R`](&9A;'-E*0H@("`@>PH@("`@("`@("1A:R`]($AO<F1E.CIG971!
M8V-E<W-+97DH)&QA8F5L+"`D;F]C:&5C:RD["B`@("`@("`@)&%T=')I8G5T
M97,@/2`G=&ET;&4](B<@+B!(;W)D93HZ<W1R:7!!8V-E<W-+97DH)&QA8F5L
M*3L*("`@("`@("!I9B`H(65M<'1Y*"1A:RDI('L*("`@("`@("`@("`@)&%T
M=')I8G5T97,@+CT@<W!R:6YT9BA?*"(@*$%C8V5S<VME>2`E<RDB*2P@)&%K
M*3L*("`@("`@("`@("`@)&%T=')I8G5T97,@+CT@)R(@86-C97-S:V5Y/2(G
M("X@)&%K.PH@("`@("`@('T*("`@("`@("`D871T<FEB=71E<R`N/2`G(B<[
M"B`@("`@("`@<F5T=7)N("1A='1R:6)U=&5S.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!A(&QA8F5L(&5L96UE;G0@:6YC;'5D:6YG(&%N(&%C
M8V5S<R!K97D@9F]R('5S86=E(&EN(&-O;FIU8W1I;VX*("`@("`J('=I=&@@
M82!F;W)M(&9I96QD+B!5<V5R('!R969E<F5N8V5S(')E9V%R9&EN9R!A8V-E
M<W,@:V5Y<R!A<F4@<F5S<&5C=&5D+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&9O<B`@("!4:&4@9F]R;2!F:65L9"=S(&ED(&%T=')I8G5T92X*
M("`@("`J($!P87)A;2!S=')I;F<@)&QA8F5L("!4:&4@;&%B96P@=&5X="X*
M("`@("`J($!P87)A;2!S=')I;F<@)&%K("`@("!4:&4@86-C97-S(&ME>2!T
M;R!U<V4N($EF(&YU;&P@82!N97<@86-C97-S(&ME>0H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@('=I;&P@8F4@9V5N97)A=&5D+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@:'1M;"!C;V1E(&9O<B!T:&4@;&%B
M96P@96QE;65N="X*("`@("`J+PH@("`@9G5N8W1I;VX@;&%B96PH)&9O<BP@
M)&QA8F5L+"`D86L@/2!N=6QL*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<')E
M9G,["@H@("`@("`@(&EF("AI<U]N=6QL*"1A:RDI('L*("`@("`@("`@("`@
M)&%K(#T@2&]R9&4Z.F=E=$%C8V5S<VME>2@D;&%B96PL(#$I.PH@("`@("`@
M('T*("`@("`@("`D;&%B96P@/2!(;W)D93HZ:&EG:&QI9VAT06-C97-S2V5Y
M*"1L86)E;"P@)&%K*3L*"B`@("`@("`@<F5T=7)N('-P<FEN=&8H)SQL86)E
M;"!F;W(](B5S(B5S/B5S/"]L86)E;#XG+`H@("`@("`@("`@("`@("`@("`@
M("`@("1F;W(L"B`@("`@("`@("`@("`@("`@("`@("`@(65M<'1Y*"1A:RD@
M/R`G(&%C8V5S<VME>3TB)R`N("1A:R`N("<B)R`Z("<G+`H@("`@("`@("`@
M("`@("`@("`@("`@("1L86)E;"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M961I<F5C=',@=&\@=&AE(&UA:6X@2&]R9&4@;&]G:6X@<&%G92!O;B!A=71H
M96YT:6-A=&EO;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A=71H
M96YT:6-A=&EO;D9A:6QU<F52961I<F5C="@I"B`@("!["B`@("`@("`@<F5Q
M=6ER95]O;F-E("=(;W)D92]#3$DN<&AP)SL*("`@("`@("!I9B`H2&]R9&5?
M0TQ).CIR=6YN:6YG1G)O;4-,22@I*2!["B`@("`@("`@("`@("1C;&D@/2`F
M2&]R9&5?0TQ).CIS:6YG;&5T;VXH*3L*("`@("`@("`@("`@)&-L:2T^9F%T
M86PH7R@B66]U(&%R92!N;W0@875T:&5N=&EC871E9"XB*2D["B`@("`@("`@
M?0H*("`@("`@("`D=7)L(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G
M=V5B<F]O="<L("=H;W)D92<I("X@)R]L;V=I;BYP:'`G.PH@("`@("`@("1U
M<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@87)R87DH)W5R;"<@/3X@
M2&]R9&4Z.G-E;&95<FPH=')U92DL("=N;W-I9&5B87(G(#T^(#$I+"!N=6QL
M+"!F86QS92D["B`@("`@("`@)'5R;"`]($%U=&@Z.F%D9$QO9V]U=%!A<F%M
M971E<G,H)'5R;"D["B`@("`@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N($AO
M<F1E.CIU<FPH)'5R;"P@=')U92DI.PH@("`@("`@(&5X:70["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!0<F]V:61E<R!A('-T86YD87)D:7-E9"!F=6YC=&EO
M;B!T;R!C86QL(&$@2&]R9&4@:&]O:RP@8VAE8VMI;F<@=VAE=&AE<@H@("`@
M("H@82!H;V]K(&-O;F9I9R!F:6QE(&5X:7-T<R!A;F0@=VAE=&AE<B!T:&4@
M9G5N8W1I;VX@:71S96QF(&5X:7-T<RX@268*("`@("`J('1H97-E('1W;R!C
M;VYD:71I;VYS(&%R92!N;W0@<V%T:7-F:65D(&ET('=I;&P@<F5T=7)N('1H
M92!S<&5C:69I960*("`@("`J('9A;'5E("AB>2!D969A=6QT(&$@4$5!4B!E
M<G)O<BDN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:&]O:R`@5&AE
M(&9U;F-T:6]N('1O(&-A;&PN"B`@("`@*B!`<&%R86T@87)R87D@("1A<F=S
M("!!;B!A<G)A>2!O9B!A;GD@87)G=6UE;G1S('1O('!A<W,@=&\@=&AE(&AO
M;VL*("`@("`J("`@("`@("`@("`@("`@("`@("`@(&9U;F-T:6]N+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D87!P("`@268@<W!E8VEF:65D(&QO;VL@9F]R
M(&AO;VMS(&EN('1H92!C;VYF:6<@9&ER96-T;W)Y"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("!O9B!T:&ES(&%P<"X*("`@("`J($!P87)A;2!M:7AE
M9"`D97)R;W(@(%=H870@=&\@<F5T=7)N(&EF("1A<'`O8V]N9FEG+VAO;VMS
M+G!H<"!O<B`D:&]O:PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@9&]E
M<R!N;W0@97AI<W0N($EF('1H:7,@:7,@=&AE('-T<FEN9R`G4$5!4E]%<G)O
M<B<*("`@("`J("`@("`@("`@("`@("`@("`@("`@(&$@4$5!4B!E<G)O<B!O
M8FIE8W0@:7,@<F5T=7)N960@:6YS=&5A9"P@9&5T86EL:6YG"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("!T:&4@9F%I;'5R92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!%:71H97(@=&AE(')E<W5L=',@;V8@=&AE(&AO
M;VL@;W(@4$5!4B!E<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!C86QL2&]O:R@D:&]O:RP@)&%R9W,@/2!A<G)A>2@I+"`D87!P(#T@
M)VAO<F1E)RP@)&5R<F]R(#T@)U!%05)?17)R;W(G*0H@("`@>PH@("`@("`@
M(&=L;V)A;"`D<F5G:7-T<GD["B`@("`@("`@<W1A=&EC("1H;V]K<U]L;V%D
M960["@H@("`@("`@(&EF("@A:7-S970H)&AO;VMS7VQO861E9"DI('L*("`@
M("`@("`@("`@:68@*&9I;&5?97AI<W1S*"1R96=I<W1R>2T^9V5T*"=F:6QE
M<F]O="<L("1A<'`I("X@)R]C;VYF:6<O:&]O:W,N<&AP)RDI('L*("`@("`@
M("`@("`@("`@(')E<75I<F5?;VYC92`D<F5G:7-T<GDM/F=E="@G9FEL97)O
M;W0G+"`D87!P*2`N("<O8V]N9FEG+VAO;VMS+G!H<"<["B`@("`@("`@("`@
M("`@("`D:&]O:W-?;&]A9&5D(#T@=')U93L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1H;V]K<U]L;V%D960@/2!F86QS93L*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H)&AO;VMS7VQO861E
M9"`F)B!F=6YC=&EO;E]E>&ES=',H)&AO;VLI*2!["B`@("`@("`@("`@(')E
M='5R;B!C86QL7W5S97)?9G5N8U]A<G)A>2@D:&]O:RP@)&%R9W,I.PH@("`@
M("`@('T*"B`@("`@("`@:68@*&ES7W-T<FEN9R@D97)R;W(I("8F('-T<F-M
M<"@D97)R;W(L("=014%27T5R<F]R)RD@/3T@,"D@>PH@("`@("`@("`@("`D
M97)R;W(@/2!014%2.CIR86ES945R<F]R*'-P<FEN=&8H)TAO;VL@)7,@:6X@
M87!P;&EC871I;VX@)7,@;F]T(&-A;&QE9"XG+"`D:&]O:RP@)&%P<"DI.PH@
M("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D97)R;W(L(%]?1DE,15]?
M+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1E<G)O<CL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE('-P96-I9FEE9"!P97)M:7-S:6]N(&9O<B!T:&4@8W5R<F5N="!U
M<V5R+@H@("`@("H*("`@("`J($!S:6YC92!(;W)D92`S+C$*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P97)M:7-S:6]N("!!('!E<FUI<W-I;VXL
M(&-U<G)E;G1L>2!O;FQY("=M87A?8FQO8VMS)RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4:&4@=F%L=64@;V8@=&AE('-P96-I9FEE9"!P97)M
M:7-S:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!H87-097)M:7-S:6]N*"1P
M97)M:7-S:6]N*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<&5R;7,["@H@("`@
M("`@(&EF("@A)'!E<FUS+3YE>&ES=',H)VAO<F1E.B<@+B`D<&5R;6ES<VEO
M;BDI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@
M("`@("`D86QL;W=E9"`]("1P97)M<RT^9V5T4&5R;6ES<VEO;G,H)VAO<F1E
M.B<@+B`D<&5R;6ES<VEO;BD["B`@("`@("`@:68@*&ES7V%R<F%Y*"1A;&QO
M=V5D*2D@>PH@("`@("`@("`@("!S=VET8V@@*"1P97)M:7-S:6]N*2!["B`@
M("`@("`@("`@(&-A<V4@)VUA>%]B;&]C:W,G.@H@("`@("`@("`@("`@("`@
M)&%L;&]W960@/2!A<G)A>5]R961U8V4H)&%L;&]W960L(&-R96%T95]F=6YC
M=&EO;B@G)&$L("1B)RP@)W)E='5R;B!M87@H)&$L("1B*3LG*2P@,"D["B`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1A;&QO=V5D.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+W!R969S
M+G!H<```````````````````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#$Q-#,P(#$P-3$U-#,S-S0P(#`R,#$S,@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@)$AO
M<F1E.B!H;W)D92]L:6(O<')E9G,N<&AP+'8@,2XQ.2XT+C$P(#(P,#8O,#$O
M,#$@,C$Z,CDZ,#4@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P
M,#8@0VAA<FQE<R!*+B!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@
M0V]P>7)I9VAT(#$Y.3DM,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J+PH*9G5N8W1I;VX@:&%N9&QE7W-H;W=S=6UM
M87)Y<V5L96-T*"1U<&1A=&5D*0I["B`@("!G;&]B86P@)'!R969S.PH*("`@
M("1S:&]W7W-U;6UA<FEE<R`](%5T:6PZ.F=E=$9O<FU$871A*"=S:&]W7W-U
M;6UA<FEE<R<I.PH@("`@:68@*"%I<U]N=6QL*"1S:&]W7W-U;6UA<FEE<RDI
M('L*("`@("`@("`D<')E9G,M/G-E=%9A;'5E*"=S:&]W7W-U;6UA<FEE<R<L
M("1S:&]W7W-U;6UA<FEE<RD["B`@("`@("`@)'5P9&%T960@/2!T<G5E.PH@
M("`@?0H*("`@(')E='5R;B`D=7!D871E9#L*?0H*9G5N8W1I;VX@:&%N9&QE
M7W1H96UE<V5L96-T*"1U<&1A=&5D*0I["B`@("!G;&]B86P@)'!R969S.PH*
M("`@("1T:&5M92`](%5T:6PZ.F=E=$9O<FU$871A*"=T:&5M92<I.PH@("`@
M:68@*"%I<U]N=6QL*"1T:&5M92DI('L*("`@("`@("`D<')E9G,M/G-E=%9A
M;'5E*"=T:&5M92<L("1T:&5M92D["B`@("`@("`@)'5P9&%T960@/2!T<G5E
M.PH@("`@?0H*("`@(')E='5R;B`D=7!D871E9#L*?0H*9G5N8W1I;VX@:&%N
M9&QE7V-A=&5G;W)Y;6%N86=E;65N="@D=7!D871E9"D*>PH@("`@<F5Q=6ER
M95]O;F-E("=(;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP)SL*("`@
M("1C36%N86=E<B`]("9N97<@4')E9G-?0V%T96=O<GE-86YA9V5R*"D["@H@
M("`@+RH@06QW87ES('-A=F4@8V]L;W)S(&]F(&%L;"!C871E9V]R:65S+B`J
M+PH@("`@)&-O;&]R<R`](&%R<F%Y*"D["B`@("`D8V%T96=O<FEE<R`]("1C
M36%N86=E<BT^9V5T*"D["B`@("!F;W)E86-H("@D8V%T96=O<FEE<R!A<R`D
M8V%T96=O<GDI('L*("`@("`@("!I9B`H)&-O;&]R(#T@571I;#HZ9V5T1F]R
M;41A=&$H)V-O;&]R7R<@+B!B87-E-C1?96YC;V1E*"1C871E9V]R>2DI*2![
M"B`@("`@("`@("`@("1C;VQO<G-;)&-A=&5G;W)Y72`]("1C;VQO<CL*("`@
M("`@("!]"B`@("!]"B`@("!I9B`H)&-O;&]R(#T@571I;#HZ9V5T1F]R;41A
M=&$H)V-O;&]R7R<@+B!B87-E-C1?96YC;V1E*"=?9&5F875L=%\G*2DI('L*
M("`@("`@("`D8V]L;W)S6R=?9&5F875L=%\G72`]("1C;VQO<CL*("`@('T*
M("`@(&EF("@D8V]L;W(@/2!5=&EL.CIG971&;W)M1&%T82@G8V]L;W)?)R`N
M(&)A<V4V-%]E;F-O9&4H)U]U;F9I;&5D7R<I*2D@>PH@("`@("`@("1C;VQO
M<G-;)U]U;F9I;&5D7R==(#T@)&-O;&]R.PH@("`@?0H@("`@)&--86YA9V5R
M+3YS971#;VQO<G,H)&-O;&]R<RD["@H@("`@)&%C=&EO;B`](%5T:6PZ.F=E
M=$9O<FU$871A*"=C06-T:6]N)RD["B`@("`D8V%T96=O<GD@/2!5=&EL.CIG
M971&;W)M1&%T82@G8V%T96=O<GDG*3L*"B`@("!S=VET8V@@*"1A8W1I;VXI
M('L*("`@(&-A<V4@)V%D9"<Z"B`@("`@("`@)&--86YA9V5R+3YA9&0H)&-A
M=&5G;W)Y*3L*("`@("`@("!B<F5A:SL*"B`@("!C87-E("=R96UO=F4G.@H@
M("`@("`@("1C36%N86=E<BT^<F5M;W9E*"1C871E9V]R>2D["B`@("`@("`@
M8G)E86L["@H@("`@9&5F875L=#H*("`@("`@("`O*B!3879E(&)U='1O;BX@
M*B\*("`@("`@("`D=7!D871E9"`]('1R=64["B`@("!]"@H@("`@<F5T=7)N
M("1U<&1A=&5D.PI]"@HO*BH*("H@1&\@86YY=&AI;F<@=&AA="!W92!N965D
M('1O(&1O(&%S(&$@<F5S=6QT(&]F(&-E<G1A:6X@<')E9F5R96YC97,*("H@
M8VAA;F=I;F<N"B`J+PIF=6YC=&EO;B!P<F5F<U]C86QL8F%C:R@I"GL*("`@
M(&=L;V)A;"`D<')E9G,L("1R96=I<W1R>2P@)&YO=&EF:6-A=&EO;BP@)&YL
M<SL*"B`@("!I9B`H)'!R969S+3YI<T1I<G1Y*"=L86YG=6%G92<I('Q\"B`@
M("`@("`@)'!R969S+3YI<T1I<G1Y*"=S:&]W7W-I9&5B87(G*2D@>PH@("`@
M("`@(&EF("@D<')E9G,M/FES1&ER='DH)VQA;F=U86=E)RDI('L*("`@("`@
M("`@("`@3DQ3.CIS971,86YG*"1P<F5F<RT^9V5T5F%L=64H)VQA;F=U86=E
M)RDI.PH@("`@("`@("`@("!.3%,Z.G-E=%1E>'1D;VUA:6XH)')E9VES=')Y
M+3YG971!<'`H*2P@)')E9VES=')Y+3YG970H)V9I;&5R;V]T)RD@+B`G+VQO
M8V%L92<L($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@("`@("`@("`@4W1R:6YG
M.CIS971$969A=6QT0VAA<G-E="A.3%,Z.F=E=$-H87)S970H*2D["B`@("`@
M("`@?0H*("`@("`@("`D=7)L(#T@)')E9VES=')Y+3YG970H)W=E8G)O;W0G
M+"`G:&]R9&4G*3L*("`@("`@("!I9B`H<W5B<W1R*"1U<FPL("TQ*2`A/2`G
M+R<I('L*("`@("`@("`@("`@)'5R;"`N/2`G+R<["B`@("`@("`@?0H@("`@
M("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"`N("=I;F1E>"YP
M:'`G+"`G=7)L)RP@2&]R9&4Z.G-E;&95<FPH=')U92DI.PH@("`@("`@("1N
M;W1I9FEC871I;VXM/G!U<V@H)VEF("AW:6YD;W<N<&%R96YT+F9R86UE<RD@
M=VEN9&]W+G!A<F5N="YF<F%M97,N;&]C871I;VX@/2!<)R<@+B!A9&1S;&%S
M:&5S*$AO<F1E.CIU<FPH)'5R;"P@=')U92DI("X@)UPG.R<L("=J879A<V-R
M:7!T)RD["B`@("!]"@H@("`@:68@*"1P<F5F<RT^:7-$:7)T>2@G<VED96)A
M<E]W:61T:"<I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@G:68@
M*'=I;F1O=RYP87)E;G0@)B8@=VEN9&]W+G!A<F5N="YD;V-U;65N="YG971%
M;&5M96YT0GE)9"A<)VAF7"<I("8F('=I;F1O=RYP87)E;G0N:&]R9&5?;65N
M=2`F)B!W:6YD;W<N<&%R96YT+FAO<F1E7VUE;G4N97AP86YD9613:61E8F%R
M+G-H;W=N*"DI('=I;F1O=RYP87)E;G0N9&]C=6UE;G0N9V5T16QE;65N=$)Y
M260H7"=H9EPG*2YC;VQS(#T@=VEN9&]W+G!A<F5N="YH;W)D95]M96YU+G)T
M;"`_(%PG*BPG("X@)'!R969S+3YG971686QU92@G<VED96)A<E]W:61T:"<I
M("X@)UPG(#H@7"<G("X@)'!R969S+3YG971686QU92@G<VED96)A<E]W:61T
M:"<I("X@)RPJ7"<[)RP@)VIA=F%S8W)I<'0G*3L*("`@('T*"B`@("!I9B`H
M)'!R969S+3YI<T1I<G1Y*"=T:&5M92<I('Q\"B`@("`@("`@)'!R969S+3YI
M<T1I<G1Y*"=M96YU7W9I97<G*2!\?`H@("`@("`@("1P<F5F<RT^:7-$:7)T
M>2@G;65N=5]R969R97-H7W1I;64G*2D@>PH@("`@("`@("1N;W1I9FEC871I
M;VXM/G!U<V@H)VEF("AW:6YD;W<N<&%R96YT+F9R86UE<RYH;W)D95]M96YU
M*2!W:6YD;W<N<&%R96YT+F9R86UE<RYH;W)D95]M96YU+FQO8V%T:6]N+G)E
M;&]A9"@I.R<L("=J879A<V-R:7!T)RD["B`@("!]"GT*"B\J($%S<VEG;B!V
M87)I86)L97,@9F]R('-E;&5C="!L:7-T<RX@*B\*:68@*"$D<')E9G,M/FES
M3&]C:V5D*"=T:6UE>F]N92<I*2!["B`@("`D=&EM97IO;F5?;W!T:6]N<R`]
M("1T>CL*("`@(&%R<F%Y7W5N<VAI9G0H)'1I;65Z;VYE7V]P=&EO;G,L(%\H
M(D1E9F%U;'0B*2D["GT*:68@*"$D<')E9G,M/FES3&]C:V5D*"=I;FET:6%L
M7V%P<&QI8V%T:6]N)RDI('L*("`@(&=L;V)A;"`D<&5R;7,["@H@("`@)&EN
M:71I86Q?87!P;&EC871I;VY?;W!T:6]N<R`](&%R<F%Y*"D["B`@("`D87!P
M<R`]("1R96=I<W1R>2T^;&ES=$%P<',H87)R87DH)V%C=&EV92<I*3L*("`@
M(&9O<F5A8V@@*"1A<'!S(&%S("1A*2!["B`@("`@("`@:68@*&9I;&5?97AI
M<W1S*"1R96=I<W1R>2T^9V5T*"=F:6QE<F]O="<L("1A*2D@)B8*("`@("`@
M("`@("`@*"@D<&5R;7,M/F5X:7-T<R@D82D@)B8@*"1P97)M<RT^:&%S4&5R
M;6ES<VEO;B@D82P@075T:#HZ9V5T075T:"@I+"!015)-4U]214%$*2!\?"!!
M=71H.CII<T%D;6EN*"DI*2!\?`H@("`@("`@("`@("`@(21P97)M<RT^97AI
M<W1S*"1A*2DI('L*("`@("`@("`@("`@)&EN:71I86Q?87!P;&EC871I;VY?
M;W!T:6]N<ULD85T@/2`D<F5G:7-T<GDM/F=E="@G;F%M92<L("1A*3L*("`@
M("`@("!]"B`@("!]"B`@("!A<V]R="@D:6YI=&EA;%]A<'!L:6-A=&EO;E]O
M<'1I;VYS*3L*?0II9B`H(21P<F5F<RT^:7-,;V-K960H)W1H96UE)RDI('L*
M("`@("1T:&5M95]O<'1I;VYS(#T@87)R87DH*3L*("`@("1T:&5M95]B87-E
M(#T@)')E9VES=')Y+3YG970H)W1H96UE<V9S)RP@)VAO<F1E)RD["B`@("`D
M9&@@/2!`;W!E;F1I<B@D=&AE;65?8F%S92D["B`@("!I9B`H(21D:"D@>PH@
M("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H(E1H96UE(&1I<F5C=&]R>2!C
M86XG="!B92!O<&5N960B+"`G:&]R9&4N97)R;W(G*3L*("`@('T@96QS92![
M"B`@("`@("`@=VAI;&4@*"@D9&ER(#T@<F5A9&1I<B@D9&@I*2`A/3T@9F%L
M<V4I('L*("`@("`@("`@("`@:68@*"1D:7(@/3T@)RXG('Q\("1D:7(@/3T@
M)RXN)R!\?"`A(&ES7V1I<B@D=&AE;65?8F%S92XG+R<N)&1I<BDI('L*("`@
M("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`D=&AE;65?;F%M92`](&YU;&P["B`@("`@("`@("`@($!I;F-L=61E
M("1T:&5M95]B87-E("X@)R\G("X@)&1I<B`N("<O:6YF;RYP:'`G.PH@("`@
M("`@("`@("!I9B`H(65M<'1Y*"1T:&5M95]N86UE*2D@>PH@("`@("`@("`@
M("`@("`@)'1H96UE7V]P=&EO;G-;)&1I<ET@/2`D=&AE;65?;F%M93L*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("!A<V]R="@D=&AE;65?
M;W!T:6]N<RD["GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B]3>6YC34PN<&AP````````````````````````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`T,38W,B`Q,#4Q-30S,S<T,"`P,C`Q-S,`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*"FEN
M8VQU9&5?;VYC92`G4WEN8TU,+T-O;6UA;F0N<&AP)SL*:6YC;'5D95]O;F-E
M("=3>6YC34PO0V]M;6%N9"]3=&%T=7,N<&AP)SL*:6YC;'5D95]O;F-E("=3
M>6YC34PO0V]M;6%N9"]!;&5R="YP:'`G.PII;F-L=61E7V]N8V4@)U-Y;F--
M3"]#;VUM86YD+U-Y;F,N<&AP)SL*:6YC;'5D95]O;F-E("=3>6YC34PO0V]M
M;6%N9"]&:6YA;"YP:'`G.PII;F-L=61E7V]N8V4@)U-Y;F--3"]3>6YC+G!H
M<"<["FEN8VQU9&5?;VYC92`G4WEN8TU,+T)A8VME;F0N<&AP)SL*"B\J*@H@
M*B!4:&4@4WEN8TU,7U-Y;F-(9'(@86YD(%-Y;F--3%]3>6YC0F]D>2!C;&%S
M<V5S('!R;W9I9&5S"B`J(&$@4WEN8TAD<B!A;F0@4WEN8T)O9'D@:6X@4WEN
M8TU,(%)E<')E<V5N=&%T:6]N(%!R;W1O8V]L+"!V97)S:6]N"B`J(#$N,2`U
M+C(N,B!A;F0@-2XR+C,N("!-;W-T(&]F('1H92!W;W)K(&ES('!A<W-E9"!O
M;B!T;PH@*B!3>6YC34Q?0V]M;6%N9%]!;&5R="!A;F0@4WEN8TU,7T-O;6UA
M;F1?4WEN8RX*("H*("H@5&AE<F4@87)E('1W;R!G;&]B86P@;V)J96-T<R!T
M:&%T(&%R92!U<V5D(&)Y(%-Y;F--3#H*("H@,2D@)%]315-324].6R=3>6YC
M34PN<W1A=&4G73H*("H@("`@<V5S<VEO;B!O8FIE8W0@=7-E9"!T;R!M86EN
M=&%I;B!T:&4@<W1A=&4@8F5T=V5E;B!T:&4@:6YD:79I9'5A;`H@*B`@("!3
M>6YC34P@;65S<V%G97,N"B`J"B`J(#(I("1'3$]"04Q36R=B86-K96YD)UT*
M("H@("`@0F%C:V5N9"!T;R!H86YD;&4@=&AE(&-O;6UU;FEC871I;VX@=VET
M:"!T:&4@9&%T87-T;W)E+B!#=7)R96YT;'D@=&AE"B`J("`@(&AO<F1E(&)A
M8VME;F0@:7,@=&AE(&]N;'D@8F%C:V5N9"!P<F]V:61E9"X*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO4WEN8TU,+U-Y;F--3"YP:'`L=B`Q+C(Q+C$P+C$P
M(#(P,#8O,#$O,#$@,C$Z,C@Z,S4@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`S+3(P,#8@06YT:&]N>2!-:6QL<R`\86UI;&QS0'!Y<F%M:60V+F-O
M;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($%N=&AO;GD@36EL;',@
M/&%M:6QL<T!P>7)A;6ED-BYC;VT^"B`J($!A=71H;W(@($MA<G-T96X@1F]U
M<FUO;G0@/&9O=7)M;VYT0&=M>"YD93X*("H@0'-I;F-E("`@2&]R9&4@,RXP
M"B`J($!P86-K86=E(%-Y;F--3`H@*B\*8VQA<W,@4WEN8TU,7T-O;G1E;G1(
M86YD;&5R('L*"B`@("`O*BH*("`@("`J($]U='!U="!#;VYT96YT2&%N9&QE
M<B!U<V5D('1O(&]U='!U="!834P@979E;G1S+@H@("`@("H*("`@("`J($!V
M87(@;V)J96-T"B`@("`@*B\*("`@('9A<B`D7V]U='!U=#L*"B`@("`O*BH*
M("`@("`J(%-T86-K(&9O<B!H;VQD:6YG('1H92!X;6P@96QE;65N=',@9'5R
M:6YG(&-R96%T:6]N(&]F('1H92!O8FIE8W0@9G)O;0H@("`@("H@=&AE('AM
M;"!E=F5N="!F;&]W+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1?4W1A8VL@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?8VAA<G,["@H@("`@9G5N
M8W1I;VX@<V5T3W5T<'5T*"8D;W5T<'5T*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?;W5T<'5T(#T@)B1O=71P=70["B`@("!]"@H@("`@9G5N8W1I;VX@<W1A
M<G1%;&5M96YT*"1U<FDL("1E;&5M96YT+"`D871T<G,I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]3=&%C:UM=(#T@)&5L96UE;G0["B`@("!]"@H@("`@9G5N
M8W1I;VX@96YD16QE;65N="@D=7)I+"`D96QE;65N="D*("`@('L*("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]C:&%R<RDI('L*("`@("`@("`@("`@=6YS
M970H)'1H:7,M/E]C:&%R<RD["B`@("`@("`@?0H*("`@("`@("!A<G)A>5]P
M;W`H)'1H:7,M/E]3=&%C:RD["B`@("!]"@H@("`@9G5N8W1I;VX@8VAA<F%C
M=&5R<R@D<W1R*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-H
M87)S*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V-H87)S(#T@)'1H:7,M/E]C
M:&%R<R`N("1S='(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H
M:7,M/E]C:&%R<R`]("1S='(["B`@("`@("`@?0H@("`@?0H*?0H*"B\J*@H@
M*B!$969I;F5D(&EN(%-Y;F--3"!297!R97-E;G1A=&EO;B!0<F]T;V-O;"P@
M=F5R<VEO;B`Q+C$@-2XR+C(*("H*("H@0'!A8VMA9V4@4WEN8TU,"B`J+PIC
M;&%S<R!3>6YC34Q?4WEN8TU,2&1R(&5X=&5N9',@4WEN8TU,7T-O;G1E;G1(
M86YD;&5R('L*"B`@("`O*BH*("`@("`J($1E9FEN960@:6X@4WEN8TU,(%)E
M<')E<V5N=&%T:6]N(%!R;W1O8V]L+"!V97)S:6]N(#$N,2`U+C$N.2X@57-E
M<B!N86UE+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@
M('9A<B`D7VQO8TYA;64["@H@("`@+RHJ"B`@("`@*B!$969I;F5D(&EN(%-Y
M;F--3"!297!R97-E;G1A=&EO;B!0<F]T;V-O;"P@=F5R<VEO;B`Q+C$@-2XQ
M+C$X"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?<V5S<VEO;DE$.PH*("`@("\J*@H@("`@("H@1&5F:6YE9"!I;B!3>6YC
M34P@4F5P<F5S96YT871I;VX@4')O=&]C;VPL('9E<G-I;VX@,2XQ+B`@375S
M="!B92`Q+C`@*#`I"B`@("`@*B!O<B`Q+C$@*#$I+@H@("`@("H*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W9E<G-I;VX["@H@("`@
M+RHJ"B`@("`@*B!$969I;F5D(&EN(%-Y;F--3"!297!R97-E;G1A=&EO;B!0
M<F]T;V-O;"P@=F5R<VEO;B`Q+C$@-2XQ+C$R"B`@("`@*@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?;7-G240["@H@("`@+RHJ"B`@
M("`@*B!$969I;F5D(&EN(%-Y;F--3"!297!R97-E;G1A=&EO;B!0<F]T;V-O
M;"P@=F5R<VEO;B`Q+C$@-2XQ+C$P"B`@("`@*@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1?=&%R9V5T55)).PH*("`@("\J*@H@("`@
M("H@1&5F:6YE9"!I;B!3>6YC34P@4F5P<F5S96YT871I;VX@4')O=&]C;VPL
M('9E<G-I;VX@,2XQ(#4N,2XQ,"P@-2XQ+C(P"B`@("`@*@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?<V]U<F-E55)).PH*("`@('9A
M<B`D7V-R961$871A.PH*("`@('9A<B`D7V-R961&;W)M870["@H@("`@=F%R
M("1?8W)E9%1Y<&4["@H@("`@=F%R("1?;6%X37-G4VEZ93L*"B`@("!F=6YC
M=&EO;B!G9713=&%T949R;VU397-S:6]N*"1S;W5R8V554DDL("1L;V-.86UE
M+"`D<V5S<VEO;DE$*0H@("`@>PH@("`@("`@("1'3$]"04Q36R=B86-K96YD
M)UT@/2`F;F5W(%-Y;F--3%]"86-K96YD7TAO<F1E*"D["@H@("`@("`@("\O
M(%)E;&]A9"!T:&4@2&]R9&4@4V5S<VEO;DAA;F1L97(@:68@;F5C97-S87)Y
M+@H@("`@("`@($AO<F1E.CIS971U<%-E<W-I;VY(86YD;&5R*"D["@H@("`@
M("`@("\O(%-Y;F--3"!P<F]T;V-O;"!D;V5S(&YO="!R97%U:7)E('1H92!C
M;&EE;G0@=&\@<V5N9"!T:&4*("`@("`@("`O+R!U<V5R;F%M92!O;B!A;GD@
M;65S<V%G97,@8G5T('1H92!F:7)S="X@(%-O('5N9F]R='5N871E;'D*("`@
M("`@("`O+R!W92!C86XG="!U<V4@:70@=&\@;6%K92!A('5N:7%U92!S97-S
M:6]N(&ED+@H@("`@("`@('-E<W-I;VY?:60H)W-Y;F-M;"<@+B!P<F5G7W)E
M<&QA8V4H)R];7F$M>D$M6C`M.5TO)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("<G+"`D<V]U<F-E55))("X@)'-E<W-I
M;VY)1"DI.PH@("`@("`@('-E<W-I;VY?<W1A<G0H*3L*"B`@("`@("`@+R\@
M270@=V]U;&0@<V5E;2!M=6QT:7-Y;F,@9&]E<R!N;W0@<V5N9"!T:&4@=7-E
M<B!N86UE(&]N8V4@:70*("`@("`@("`O+R!H87,@8F5E;B!A=71H;W)I>F5D
M+B!-86ME('-U<F4@=V4@:&%V92!A('9A;&ED('-E<W-I;VX@:60N"B`@("`@
M("`@<V5S<VEO;E]I9"@G<WEN8VUL)R`N('!R96=?<F5P;&%C92@G+UM>82UZ
M02U:,"TY72\G+"`G)RP@)'-O=7)C955222`N("1S97-S:6]N240I*3L*("`@
M("`@("!`<V5S<VEO;E]S=&%R="@I.PH*("`@("`@("!I9B`H(6ES<V5T*"1?
M4T534TE/3ELG4WEN8TU,+G-T871E)UTI*2!["B`@("`@("`@("`@("\O($-R
M96%T92!A(&YE=R!S=&%T92!I9B!O;F4@9&]E<R!N;W0@86QR96%D>2!E>&ES
M="X*("`@("`@("`@("`@)$=,3T)!3%-;)V)A8VME;F0G72T^;&]G365S<V%G
M92@G3F5W('-E<W-I;VX@8W)E871E9#H@)PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`N('-E<W-I;VY?:60H*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)5
M1RD["@H@("`@("`@("`@("`D7U-%4U-)3TY;)U-Y;F--3"YS=&%T92==(#T@
M)FYE=R!3>6YC34Q?4W1A=&4H)'-O=7)C955222P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1L
M;V-.86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'-E<W-I;VY)1"D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)$=,3T)!3%-;)V)A8VME;F0G72T^;&]G365S
M<V%G92@G17AI<W1I;F<@<V5S<VEO;B!C;VYT:6YU960Z("<*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@+B!S97-S:6]N7VED*"DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!
M4E],3T=?1$5"54<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1?4T53
M4TE/3ELG4WEN8TU,+G-T871E)UT["B`@("!]"@H@("`@9G5N8W1I;VX@<W1A
M<G1%;&5M96YT*"1U<FDL("1E;&5M96YT+"`D871T<G,I"B`@("!["B`@("`@
M("`@<&%R96YT.CIS=&%R=$5L96UE;G0H)'5R:2P@)&5L96UE;G0L("1A='1R
M<RD["B`@("!]"@H@("`@9G5N8W1I;VX@96YD16QE;65N="@D=7)I+"`D96QE
M;65N="D*("`@('L*("`@("`@("!S=VET8V@@*&-O=6YT*"1T:&ES+3Y?4W1A
M8VLI*2!["B`@("`@("`@8V%S92`Q.@H@("`@("`@("`@("`O+R`\+U-Y;F-(
M9'(^/"]3>6YC34P^"B`@("`@("`@("`@("\O($9I;F0@=&AE('-T871E+@H@
M("`@("`@("`@("`D<W1A=&4@/2`D=&AI<RT^9V5T4W1A=&5&<F]M4V5S<VEO
M;B@D=&AI<RT^7W-O=7)C955222P@)'1H:7,M/E]L;V-.86UE+"`D=&AI<RT^
M7W-E<W-I;VY)1"D["@H@("`@("`@("`@("`D<W1A=&4M/G-E=%9E<G-I;VXH
M)'1H:7,M/E]V97)S:6]N*3L*("`@("`@("`@("`@)'-T871E+3YS971-<V=)
M1"@D=&AI<RT^7VUS9TE$*3L*("`@("`@("`@("`@)'-T871E+3YS971487)G
M97154DDH)'1H:7,M/E]T87)G97154DDI.PH@("`@("`@("`@("`D<W1A=&4M
M/G-E=%!A<W-W;W)D*"1T:&ES+3Y?8W)E9$1A=&$I.PH@("`@("`@("`@("`D
M<W1A=&4M/G-E=%="6$U,*&ES7V$H)'1H:7,M/E]O=71P=70L("=834Q?5T)8
M34Q?16YC;V1E<B<I*3L*"B`@("`@("`@("`@("\O(%-T;W)E(&QO9VEN(&YA
M;64@:6X@<W1A=&4@:68@;F]T(&%L<F5A9'D@<V5T"B`@("`@("`@("`@(&EF
M("AE;7!T>2@D<W1A=&4M/E]L;V-.86UE*2`F)B`A96UP='DH)'1H:7,M/E]L
M;V-.86UE*2D@>PH@("`@("`@("`@("`@("`@)'-T871E+3YS971,;V-.86UE
M*"1T:&ES+3Y?;&]C3F%M92D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M:68@*"%E;7!T>2@D=&AI<RT^7VUA>$US9U-I>F4I*2!["B`@("`@("`@("`@
M("`@("`D<W1A=&4M/G-E=$UA>$US9U-I>F4H)'1H:7,M/E]M87A-<V=3:7IE
M*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'-T<B`]("=A=71H;W)I
M>F5D/2<@+B`D<W1A=&4M/FES075T:&]R:7IE9"@I("X*("`@("`@("`@("`@
M("`@("<@=F5R<VEO;CTG("X@)'-T871E+3YG971697)S:6]N*"D@+@H@("`@
M("`@("`@("`@("`@)R!M<V=I9#TG("X@)'-T871E+3YG971-<V=)1"@I("X*
M("`@("`@("`@("`@("`@("<@<V]U<F-E/2<@+B`D<W1A=&4M/F=E=%-O=7)C
M955222@I("X*("`@("`@("`@("`@("`@("<@=&%R9V5T/2<@+B`D<W1A=&4M
M/F=E=%1A<F=E=%5222@I("X*("`@("`@("`@("`@("`@("<@=7-E<CTG("X@
M)'-T871E+3YG971,;V-.86UE*"D@+@H@("`@("`@("`@("`@("`@)R!C:&%R
M<V5T/2<@+B!.3%,Z.F=E=$-H87)S970H*2`N"B`@("`@("`@("`@("`@("`G
M('=B>&UL/2<@+B`D<W1A=&4M/FES5T)834PH*0H*("`@("`@("`@("`@("`@
M(#L*"B`@("`@("`@("`@("1?4T534TE/3ELG4WEN8TU,+G-T871E)UT@/2`D
M<W1A=&4["@H@("`@("`@("`@("`D1TQ/0D%,4ULG8F%C:V5N9"==+3YL;V=-
M97-S86=E*"1S='(L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"
M54<I.PH*("`@("`@("`@("`@+R\@1V]T('1H92!S=&%T93L@;F]W('=R:71E
M(&]U<B!3>6YC2&1R(&AE861E<BX*("`@("`@("`@("`@)'1H:7,M/F]U='!U
M=%-Y;F-(9'(H)'1H:7,M/E]O=71P=70I.PH@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@8V%S92`R.@H@("`@("`@("`@("!I9B`H)&5L96UE;G0@/3T@
M)U9E<E!R;W1O)RD@>PH@("`@("`@("`@("`@("`@+R\@/"]697)0<F]T;SX\
M+U-Y;F-(9'(^/"]3>6YC34P^"B`@("`@("`@("`@("`@("!I9B`H=')I;2@D
M=&AI<RT^7V-H87)S*2`]/2`G4WEN8TU,+S$N,2<I('L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W9E<G-I;VX@/2`Q.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W9E<G-I;VX@
M/2`P.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V5I9B`H
M)&5L96UE;G0@/3T@)U-E<W-I;VY)1"<I('L*("`@("`@("`@("`@("`@("\O
M(#PO4V5S<VEO;DE$/CPO4WEN8TAD<CX\+U-Y;F--3#X*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<V5S<VEO;DE$(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*
M("`@("`@("`@("`@?2!E;'-E:68@*"1E;&5M96YT(#T]("=-<V=)1"<I('L*
M("`@("`@("`@("`@("`@("\O(#PO37-G240^/"]3>6YC2&1R/CPO4WEN8TU,
M/@H@("`@("`@("`@("`@("`@)'1H:7,M/E]M<V=)1"`](&EN='9A;"AT<FEM
M*"1T:&ES+3Y?8VAA<G,I*3L*("`@("`@("`@("`@?2!E;'-E:68@*"1E;&5M
M96YT(#T]("=#<F5D)RD@>PH@("`@("`@("`@("`@("`@+R\@/"]#<F5D/CPO
M4WEN8TAD<CX\+U-Y;F--3#X*("`@("`@("`@("`@("`@("1T:&ES+3Y?8W)E
M9$1A=&$@/2!B87-E-C1?9&5C;V1E*"1T:&ES+3Y?8W)E9$1A=&$I.PH*("`@
M("`@("`@("`@("`@("1T;7`@/2!E>'!L;V1E*"<Z)RP@)'1H:7,M/E]C<F5D
M1&%T82D["B`@("`@("`@("`@("`@("`D=&AI<RT^7VQO8TYA;64@/2`D=&UP
M6S!=.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C<F5D1&%T82`]("1T;7!;
M,5T["B`@("`@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4WEN8TU,
M.B!R96-E:79E9"!C<F5D96YT:6%L<R!F;W(@=7-E<CTG"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)'1H:7,M
M/E]L;V-.86UE("P@)V-R960])PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`N("1T:&ES+3Y?8W)E9$1A=&$L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`S.@H@
M("`@("`@("`@("!I9B`H)&5L96UE;G0@/3T@)TQO8U5222<I('L*("`@("`@
M("`@("`@("`@(&EF("@D=&AI<RT^7U-T86-K6S%=(#T]("=3;W5R8V4G*2![
M"B`@("`@("`@("`@("`@("`@("`@+R\@/"],;V-54DD^/"]3;W5R8V4^/"]3
M>6YC2&1R/CPO4WEN8TU,/@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<V]U<F-E55))(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@
M("`@('T@96QS96EF("@D=&AI<RT^7U-T86-K6S%=(#T]("=487)G970G*2![
M"B`@("`@("`@("`@("`@("`@("`@+R\@/"],;V-54DD^/"]487)G970^/"]3
M>6YC2&1R/CPO4WEN8TU,/@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M=&%R9V5T55))(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?2!E;'-E:68@*"1E;&5M96YT(#T]("=,;V-.
M86UE)RD@>PH@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?4W1A8VM;,5T@
M/3T@)U-O=7)C92<I('L*("`@("`@("`@("`@("`@("`@("`O+R`\+TQO8TYA
M;64^/"]3;W5R8V4^/"]3>6YC2&1R/CPO4WEN8TU,/@H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?;&]C3F%M92`]('1R:6TH)'1H:7,M/E]C:&%R<RD[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS96EF("@D96QE
M;65N="`]/2`G1&%T82<I('L*("`@("`@("`@("`@("`@("`@("`O+R`\+T1A
M=&$^/"]#<F5D/CPO4WEN8TAD<CX\+U-Y;F--3#X*("`@("`@("`@("`@("`@
M(&EF("@D=&AI<RT^7U-T86-K6S%=(#T]("=#<F5D)RD@>PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?8W)E9$1A=&$@/2!T<FEM*"1T:&ES+3Y?8VAA
M<G,I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V5I9B`H
M)&5L96UE;G0@/3T@)TUA>$US9U-I>F4G*2!["B`@("`@("`@("`@("`@("`O
M+R`\+TUA>$US9U-I>F4^/"]-971A/CPO4WEN8TAD<CX\+U-Y;F--3#X*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?;6%X37-G4VEZ92`](&EN='9A;"@D=&AI
M<RT^7V-H87)S*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@8V%S92`T.@H@("`@("`@("`@("!I9B`H)'1H:7,M/E]3=&%C
M:ULQ72`]/2`G0W)E9"<I('L*("`@("`@("`@("`@("`@(&EF("@D96QE;65N
M="`]/2`G1F]R;6%T)RD@>PH@("`@("`@("`@("`@("`@("`@("\O(#PO1F]R
M;6%T/CPO365T83X\+T-R960^/"]3>6YC2&1R/CPO4WEN8TU,/@H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?8W)E9$9O<FUA="`]('1R:6TH)'1H:7,M
M/E]C:&%R<RD["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&5L96UE;G0@
M/3T@)U1Y<&4G*2!["B`@("`@("`@("`@("`@("`@("`@+R\@/"]4>7!E/CPO
M365T83X\+T-R960^/"]3>6YC2&1R/CPO4WEN8TU,/@H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?8W)E9%1Y<&4@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@<&%R96YT.CIE;F1%;&5M96YT
M*"1U<FDL("1E;&5M96YT*3L*("`@('T*"B`@("!F=6YC=&EO;B!O=71P=713
M>6YC2&1R*"8D;W5T<'5T*0H@("`@>PH@("`@("`@("1A='1R<R`](&%R<F%Y
M*"D["@H@("`@("`@("1S=&%T92`]("8D7U-%4U-)3TY;)U-Y;F--3"YS=&%T
M92==.PH*("`@("`@("`D=7)I(#T@)'-T871E+3YG97154DDH*3L*("`@("`@
M("`D=7)I365T82`]("1S=&%T92T^9V5T55))365T82@I.PH*("`@("`@("`D
M;W5T<'5T+3YS=&%R=$5L96UE;G0H)'5R:2P@)U-Y;F-(9'(G+"`D871T<G,I
M.PH*("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'5R:2P@)U9E<D14
M1"<L("1A='1R<RD["B`@("`@("`@)&-H87)S(#T@*"1T:&ES+3Y?=F5R<VEO
M;B`]/2`Q*2`_("<Q+C$G(#H@)S$N,"<["B`@("`@("`@)&]U='!U="T^8VAA
M<F%C=&5R<R@D8VAA<G,I.PH@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H
M)'5R:2P@)U9E<D141"<I.PH*("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE
M;G0H)'5R:2P@)U9E<E!R;W1O)RP@)&%T=')S*3L*("`@("`@("`D8VAA<G,@
M/2`H)'1H:7,M/E]V97)S:6]N(#T](#$I(#\@)U-Y;F--3"\Q+C$G(#H@)U-Y
M;F--3"\Q+C`G.PH@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)&-H87)S
M*3L*("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1U<FDL("=697)0<F]T
M;R<I.PH*("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'5R:2P@)U-E
M<W-I;VY)1"<L("1A='1R<RD["B`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R
M<R@D=&AI<RT^7W-E<W-I;VY)1"D["B`@("`@("`@)&]U='!U="T^96YD16QE
M;65N="@D=7)I+"`G4V5S<VEO;DE$)RD["@H@("`@("`@("1O=71P=70M/G-T
M87)T16QE;65N="@D=7)I+"`G37-G240G+"`D871T<G,I.PH@("`@("`@("1O
M=71P=70M/F-H87)A8W1E<G,H)'1H:7,M/E]M<V=)1"D["B`@("`@("`@)&]U
M='!U="T^96YD16QE;65N="@D=7)I+"`G37-G240G*3L*"B`@("`@("`@)&]U
M='!U="T^<W1A<G1%;&5M96YT*"1U<FDL("=487)G970G+"`D871T<G,I.PH@
M("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D=7)I+"`G3&]C55)))RP@
M)&%T=')S*3L*("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1T:&ES+3Y?
M<V]U<F-E55))*3L*("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1U<FDL
M("=,;V-54DDG*3L*("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'5R
M:2P@)TQO8TYA;64G+"`D871T<G,I.PH@("`@("`@("1O=71P=70M/F-H87)A
M8W1E<G,H)'-T871E+3YG971,;V-.86UE*"DI.PH@("`@("`@("1O=71P=70M
M/F5N9$5L96UE;G0H)'5R:2P@)TQO8TYA;64G*3L*("`@("`@("`D;W5T<'5T
M+3YE;F1%;&5M96YT*"1U<FDL("=487)G970G*3L*"B`@("`@("`@)&]U='!U
M="T^<W1A<G1%;&5M96YT*"1U<FDL("=3;W5R8V4G+"`D871T<G,I.PH@("`@
M("`@("1O=71P=70M/G-T87)T16QE;65N="@D=7)I+"`G3&]C55)))RP@)&%T
M=')S*3L*("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1T:&ES+3Y?=&%R
M9V5T55))*3L*("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1U<FDL("=,
M;V-54DDG*3L*("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1U<FDL("=3
M;W5R8V4G*3L*"B`@("`@("`@+RH*("`@("`@("!$;R!N;W0@<V5N9"!297-P
M55))($5L96UE;G0N($ET)W,@;W!T:6]N86P@86YD(&UA>2!B92!M:7-L96%D
M:6YG.@H@("`@("`@("1T:&ES+3Y?=&%R9V5T55))(&ES(&1A=&$@9G)O;2!T
M:&4@8VQI96YT(&%N9"!N;W0@9W5A<F%N=&5E9"!T;R!B90H@("`@("`@('1H
M92!C;W)R96-T(%523"!F;W(@86-C97-S+B!,970@=&AE(&-L:65N="!J=7-T
M('-T87D@=VET:"!T:&4@<V%M90H@("`@("`@(%523"!I="!H87,@=7-E9"!F
M;W(@=&AE('!R979I;W5S(')E<75E<W0H<RDN"B`@("`@("`@*B\*("`@("`@
M("`O+R1O=71P=70M/G-T87)T16QE;65N="@D=7)I+"`G4F5S<%5222<L("1A
M='1R<RD["B`@("`@("`@+R\D;W5T<'5T+3YC:&%R86-T97)S*"1T:&ES+3Y?
M=&%R9V5T55))*3L*("`@("`@("`O+R1O=71P=70M/F5N9$5L96UE;G0H)'5R
M:2P@)U)E<W!54DDG*3L*"B`@("`@("`@+RH*("`@("`@("`D;W5T<'5T+3YS
M=&%R=$5L96UE;G0H)'5R:2P@)TUE=&$G+"`D871T<G,I.PH*("`@("`@("`O
M+R!$=6UM>2!-87@@37-Q4VEZ92P@=&AI<R!I<R!J=7-T('!U="!I;B!T;R!M
M86ME('1H92!P86-K970*("`@("`@("`O+R!W;W)K+"!I="!I<R!N;W0@82!R
M96%L('9A;'5E+@H@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D=7)I
M365T82P@)TUA>$US9U-I>F4G+"`D871T<G,I.PH@("`@("`@("1C:&%R<R`]
M("<U,#`P,"<["B`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D8VAA<G,I
M.PH@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'5R:4UE=&$L("=-87A-
M<V=3:7IE)RD["@H@("`@("`@("\O($1U;6UY($UA>$]B:E-I>F4L('1H:7,@
M:7,@:G5S="!P=70@:6X@=&\@;6%K92!T:&4@<&%C:V5T"B`@("`@("`@+R\@
M=V]R:RP@:70@:7,@;F]T(&$@<F5A;"!V86QU92X*("`@("`@("`D;W5T<'5T
M+3YS=&%R=$5L96UE;G0H)'5R:4UE=&$L("=-87A/8FI3:7IE)RP@)&%T=')S
M*3L*("`@("`@("`D8VAA<G,@/2`G-#`P,#`P,"<["B`@("`@("`@)&]U='!U
M="T^8VAA<F%C=&5R<R@D8VAA<G,I.PH@("`@("`@("1O=71P=70M/F5N9$5L
M96UE;G0H)'5R:4UE=&$L("=-87A/8FI3:7IE)RD["@H@("`@("`@("1O=71P
M=70M/F5N9$5L96UE;G0H)'5R:2P@)TUE=&$G*3L*("`@("`@("`J+PH*("`@
M("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1U<FDL("=3>6YC2&1R)RD["B`@
M("!]"@H@("`@9G5N8W1I;VX@9V5T4V]U<F-E55))*"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]S;W5R8V554DD["B`@("!]"@H@("`@9G5N8W1I
M;VX@9V5T3&]C3F%M92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M;&]C3F%M93L*("`@('T*"B`@("!F=6YC=&EO;B!G971397-S:6]N240H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W-E<W-I;VY)1#L*("`@('T*
M"B`@("!F=6YC=&EO;B!G971697)S:6]N*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]V97)S:6]N.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$US
M9TE$*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]M<V=)1#L*("`@
M('T*"B`@("!F=6YC=&EO;B!G971487)G97154DDH*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7W1A<F=E=%5223L*("`@('T*"B`@("!F=6YC=&EO
M;B!O<&%Q=64H)&\I"B`@("!["B`@("!]"@I]"@HO*BH*("H@1&5F:6YE9"!I
M;B!3>6YC34P@4F5P<F5S96YT871I;VX@4')O=&]C;VPL('9E<G-I;VX@,2XQ
M(#4N,BXS"B`J"B`J($!P86-K86=E(%-Y;F--3`H@*B\*8VQA<W,@4WEN8TU,
M7U-Y;F--3$)O9'D@97AT96YD<R!3>6YC34Q?0V]N=&5N=$AA;F1L97(@>PH*
M("`@('9A<B`D7V-U<G)E;G1#;61)1"`](#$["@H@("`@=F%R("1?8W5R<F5N
M=$-O;6UA;F0["@H@("`@=F%R("1?86-T:6]N0V]M;6%N9',@/2!F86QS93L*
M"B`@("!F=6YC=&EO;B!S=&%R=$5L96UE;G0H)'5R:2P@)&5L96UE;G0L("1A
M='1R<RD*("`@('L*("`@("`@("!P87)E;G0Z.G-T87)T16QE;65N="@D=7)I
M+"`D96QE;65N="P@)&%T=')S*3L*"B`@("`@("`@<W=I=&-H("AC;W5N="@D
M=&AI<RT^7U-T86-K*2D@>PH@("`@("`@(&-A<V4@,3H*("`@("`@("`@("`@
M)'-T871E(#T@)B1?4T534TE/3ELG4WEN8TU,+G-T871E)UT["@H@("`@("`@
M("`@("`D=&AI<RT^7V%C=&EO;D-O;6UA;F1S(#T@9F%L<V4[("\O('-O(&9A
M<BP@=V4@:&%V92!N;W0@<V5E;B!C;VUM86YD<R!T:&%T(')E<75I<F4@86-T
M:6]N(&9R;VT@;W5R('-I9&4*"B`@("`@("`@("`@("\O(#Q3>6YC34P^/%-Y
M;F-";V1Y/@H@("`@("`@("`@("`D=7)I(#T@)'-T871E+3YG97154DDH*3L*
M("`@("`@("`@("`@)'1H:7,M/E]O=71P=70M/G-T87)T16QE;65N="@D=7)I
M+"`D96QE;65N="P@)&%T=')S*3L*"B`@("`@("`@("`@("\O(%)I9VAT(&]U
M<B!S=&%T=7,@86)O=70@=&AE(&AE861E<BX*("`@("`@("`@("`@)'-T871U
M<R`]("9N97<@4WEN8TU,7T-O;6UA;F1?4W1A='5S*"@D<W1A=&4M/FES075T
M:&]R:7IE9"@I*2`_"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!215-03TY315]!551(14Y424-!5$E/3E]!0T-%
M4%1%1"`Z(%)%4U!/3E-%7TE.5D%,241?0U)%1$5.5$E!3%,L("=3>6YC2&1R
M)RD["B`@("`@("`@("`@("1S=&%T=7,M/G-E=%-O=7)C95)E9B@D<W1A=&4M
M/F=E=%-O=7)C955222@I*3L*("`@("`@("`@("`@)'-T871U<RT^<V5T5&%R
M9V5T4F5F*"1S=&%T92T^9V5T5&%R9V5T55))*"DI.PH@("`@("`@("`@("`D
M<W1A='5S+3YS971#;612968H,"D["@H@("`@("`@("`@("`D=&AI<RT^7V-U
M<G)E;G1#;61)1"`]("1S=&%T=7,M/F]U='!U="@D=&AI<RT^7V-U<G)E;G1#
M;61)1"P@)'1H:7,M/E]O=71P=70I.PH@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@8V%S92`R.@H@("`@("`@("`@("`O+R`\4WEN8TU,/CQ3>6YC0F]D
M>3X\6T-O;6UA;F1=/@H@("`@("`@("`@("`D=&AI<RT^7V-U<G)E;G1#;VUM
M86YD(#T@4WEN8TU,7T-O;6UA;F0Z.F9A8W1O<GDH)&5L96UE;G0I.PH@("`@
M("`@("`@("`D=&AI<RT^7V-U<G)E;G1#;VUM86YD+3YS=&%R=$5L96UE;G0H
M)'5R:2P@)&5L96UE;G0L("1A='1R<RD["@H@("`@("`@("`@("!I9B`H)&5L
M96UE;G0@(3T@)U-T871U<R<@)B8@)&5L96UE;G0@(3T@)TUA<"<@)B8@)&5L
M96UE;G0@(3T@)T9I;F%L)RD@>PH@("`@("`@("`@("`@("`@+R\@5V4G=F4@
M9V]T('1O(&1O('-O;65T:&EN9R$@5&AI<R!C86XG="!B92!T:&4@;&%S=`H@
M("`@("`@("`@("`@("`@+R\@<&%C:V5T+@H@("`@("`@("`@("`@("`@)'1H
M:7,M/E]A8W1I;VY#;VUM86YD<R`]('1R=64["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@
M("\O(#Q3>6YC34P^/%-Y;F-";V1Y/CQ#;VUM86YD/CPN+BX^"B`@("`@("`@
M("`@("1T:&ES+3Y?8W5R<F5N=$-O;6UA;F0M/G-T87)T16QE;65N="@D=7)I
M+"`D96QE;65N="P@)&%T=')S*3L*("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&5N9$5L96UE;G0H)'5R:2P@)&5L
M96UE;G0I"B`@("!["B`@("`@("`@<W=I=&-H("AC;W5N="@D=&AI<RT^7U-T
M86-K*2D@>PH@("`@("`@(&-A<V4@,3H*("`@("`@("`@("`@+R\@/"]3>6YC
M0F]D>3X\+U-Y;F--3#X*("`@("`@("`@("`@)'-T871E(#T@)B1?4T534TE/
M3ELG4WEN8TU,+G-T871E)UT["@H@("`@("`@("`@("!I9B`H)'-T871E+3YH
M87-096YD:6YG16QE;65N=',H*2D@>PH@("`@("`@("`@("`@("`@+RH@<W1I
M;&P@<V]M971H:6YG('1O(&1O.B!D;VXG="!C;&]S92!S97-S:6]N("HO"B`@
M("`@("`@("`@("`@("`D=&AI<RT^7V%C=&EO;D-O;6UA;F1S(#T@=')U93L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7V-U<G)E;G1#;61)
M1"`](%-Y;F--3%]#;VUM86YD7T9I;F%L.CIO=71P=71&:6YA;"@*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R
M<F5N=$-M9$E$+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]O=71P=70I.PH@("`@("`@("`@("`D=&AI<RT^7V]U
M='!U="T^96YD16QE;65N="@D=7)I+"`D96QE;65N="D["@H@("`@("`@("`@
M("!I9B`H(21T:&ES+3Y?86-T:6]N0V]M;6%N9',I('L*("`@("`@("`@("`@
M("`@("\O(%1H:7,@<&%C:V5T(&1I9"!N;W0@8V]N=&%I;B!A;GD@<F5A;"!A
M8W1I;VYS+"!J=7-T"B`@("`@("`@("`@("`@("`O+R!S=&%T=7,@86YD(&UA
M<"X@5&AI<R!M96%N<R!W92=R92!D;VYE+B!4:&4@<V5S<VEO;@H@("`@("`@
M("`@("`@("`@+R\@8V%N(&)E(&-L;W-E9"!A;F0@=&AE(&%N8VAO<G,@<V%V
M960@9F]R('1H92!N97AT"B`@("`@("`@("`@("`@("`O+R!S>6YC+@H@("`@
M("`@("`@("`@("`@)$=,3T)!3%-;)V)A8VME;F0G72T^;&]G365S<V%G92@G
M<WEN8R<@+B!S97-S:6]N7VED*"D@+@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G(&-O;7!L971E9"!S=6-C97-S
M9G5L;'DA)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("<@4W1O<FEN9R!#;&EE;G0M5%,@)R`N"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S=&%T
M92T^7V-L:65N=$%N8VAO<DYE>'0L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?24Y&3RD["B`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG8F%C
M:V5N9"==+3YW<FET95-Y;F-3=6UM87)Y*`H@("`@("`@("`@("`@("`@("`@
M("1S=&%T92T^9V5T4WEN8TED96YT:69I97(H*2P*("`@("`@("`@("`@("`@
M("`@("`D<W1A=&4M/E]C;&EE;G1!;F-H;W).97AT+`H@("`@("`@("`@("`@
M("`@("`@("1S=&%T92T^7W-E<G9E<D%N8VAO<DYE>'0I.PH@("`@("`@("`@
M("`@("`@)&QO9R`]("1S=&%T92T^9V5T3&]G*"D["B`@("`@("`@("`@("`@
M("`D<R`]("<G.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&QO9R!A<R`D
M:R`]/B`D=BD@>PH@("`@("`@("`@("`@("`@("`@("1S("X]("(@)&L])'8B
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)$=,3T)!3%-;
M)V)A8VME;F0G72T^;&]G365S<V%G92@G4W5M;6%R>3HG("X@)',L(%]?1DE,
M15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?24Y&3RD["@H@("`@("`@("`@("`@
M("`@+R\@4V5S<VEO;B!C86X@8F4@8VQO<V5D(&AE<F4N"B`@("`@("`@("`@
M("`@("!S97-S:6]N7W5N<V5T*"D["B`@("`@("`@("`@("`@("!S97-S:6]N
M7V1E<W1R;WDH*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1'3$]"04Q36R=B86-K96YD)UTM/FQO9TUE<W-A9V4H)U-Y;F--3#H@
M<F5T=7)N(&UE<W-A9V4@8V]M<&QE=&5D)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@(&-A<V4@,CH*("`@("`@("`@("`@+R\@/"];
M0V]M;6%N9%T^/"]3>6YC0F]D>3X\+U-Y;F--3#X*("`@("`@("`@("`@)'1H
M:7,M/E]C=7)R96YT0V]M;6%N9"T^96YD16QE;65N="@D=7)I+"`D96QE;65N
M="D["@H@("`@("`@("`@("`D=&AI<RT^7V-U<G)E;G1#;61)1"`]("1T:&ES
M+3Y?8W5R<F5N=$-O;6UA;F0M/F]U='!U="@D=&AI<RT^7V-U<G)E;G1#;61)
M1"P@)'1H:7,M/E]O=71P=70I.PH*("`@("`@("`@("`@=6YS970H)'1H:7,M
M/E]C=7)R96YT0V]M;6%N9"D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!D969A=6QT.@H@("`@("`@("`@("`O+R`\+RXN+CX\+UM#;VUM86YD73X\
M+U-Y;F-";V1Y/CPO4WEN8TU,/@H@("`@("`@("`@("`D=&AI<RT^7V-U<G)E
M;G1#;VUM86YD+3YE;F1%;&5M96YT*"1U<FDL("1E;&5M96YT*3L*("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("!P87)E;G0Z.F5N9$5L
M96UE;G0H)'5R:2P@)&5L96UE;G0I.PH@("`@?0H*("`@(&9U;F-T:6]N(&-H
M87)A8W1E<G,H)'-T<BD*("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/E]C=7)R96YT0V]M;6%N9"DI('L*("`@("`@("`@("`@)'1H:7,M/E]C=7)R
M96YT0V]M;6%N9"T^8VAA<F%C=&5R<R@D<W1R*3L*("`@("`@("!]"B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O+FAT86-C97-S````````````````````````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,38@,3`U,34T,S,W-#`@,#(P
M,#<V`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`$1E;GD@9G)O;2!A;&P*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+W9E<G-I;VXN<&AP````````````````````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P,#4R(#$P-3$U-#,S-S0P(#`R,#0W-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<"!D969I
M;F4H)TA/4D1%7U9%4E-)3TXG+"`G,RXQ+C,G*2`_/@H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]C;W)E+G!H<```
M````````````````````````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,S,R-B`Q,#4Q-30S,S<T,"`P,3<W-3``(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J($AO<F1E($%P
M<&QI8V%T:6]N($9R86UE=V]R:R!C;W)E('-E<G9I8V5S(&9I;&4N"B`J"B`J
M(%1H:7,@9FEL92!S971S('5P(&%N>2!N96-E<W-A<GD@:6YC;'5D92!P871H
M('9A<FEA8FQE<R!A;F0@:6YC;'5D97,*("H@=&AE(&UI;FEM=6T@<F5Q=6ER
M960@2&]R9&4@;&EB<F%R:65S+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VQI8B]C
M;W)E+G!H<"QV(#$N,C8N-BXW(#(P,#8O,#$O,#<@,38Z-#`Z,C@@8VAU8VL@
M17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U
M8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*+RH@5'5R
M;B!02%`@<W1U9F8@;V9F('1H870@8V%N(')E86QL>2!S8W)E=R!T:&EN9W,@
M=7`N("HO"FEN:5]S970H)VUA9VEC7W%U;W1E<U]S>6)A<V4G+"`P*3L*:6YI
M7W-E="@G;6%G:6-?<75O=&5S7W)U;G1I;64G+"`P*3L*"B\J(%5N<V5T(&%L
M;"!V87)I86)L97,@<&]P=6QA=&5D('1H<F]U9V@@<F5G:7-T97)?9VQO8F%L
M<RX@*B\*:68@*&EN:5]G970H)W)E9VES=&5R7V=L;V)A;',G*2D@>PH@("`@
M9F]R96%C:"`H87)R87E?:V5Y<R@D7T=%5"D@87,@)&ME>2D@>PH@("`@("`@
M('5N<V5T*"0D:V5Y*3L*("`@('T*("`@(&9O<F5A8V@@*&%R<F%Y7VME>7,H
M)%]03U-4*2!A<R`D:V5Y*2!["B`@("`@("`@=6YS970H)"1K97DI.PH@("`@
M?0H@("`@9F]R96%C:"`H87)R87E?:V5Y<R@D7T-/3TM)12D@87,@)&ME>2D@
M>PH@("`@("`@('5N<V5T*"0D:V5Y*3L*("`@('T*("`@(&9O<F5A8V@@*&%R
M<F%Y7VME>7,H)%]%3E8I(&%S("1K97DI('L*("`@("`@("!U;G-E="@D)&ME
M>2D["B`@("!]"B`@("!F;W)E86-H("AA<G)A>5]K97ES*"1?4T525D52*2!A
M<R`D:V5Y*2!["B`@("`@("`@=6YS970H)"1K97DI.PH@("`@?0I]"@HO*B!)
M9B!T:&4@2&]R9&4@1G)A;65W;W)K('!A8VMA9V5S(&%R92!N;W0@:6YS=&%L
M;&5D(&EN(%!(4"=S(&=L;V)A;`H@*B!I;F-L=61E7W!A=&@L('EO=2!M=7-T
M(&%D9"!A;B!I;FE?<V5T*"D@8V%L;"!H97)E('1O(&%D9"!T:&5I<B!L;V-A
M=&EO;B!T;PH@*B!T:&4@:6YC;'5D95]P871H+B`J+PII;FE?<V5T*"=I;F-L
M=61E7W!A=&@G+"!D:7)N86UE*%]?1DE,15]?*2`N(%!!5$A?4T5005)!5$]2
M("X@:6YI7V=E="@G:6YC;'5D95]P871H)RDI.PH*+RH@4$5!4B!B87-E(&-L
M87-S+B`J+PII;F-L=61E7V]N8V4@)U!%05(N<&AP)SL*"B\J($AO<F1E(&-O
M<F4@8VQA<W-E<RX@*B\*:6YC;'5D95]O;F-E("=(;W)D92YP:'`G.PII;F-L
M=61E7V]N8V4@)TAO<F1E+U)E9VES=')Y+G!H<"<["FEN8VQU9&5?;VYC92`G
M2&]R9&4O4W1R:6YG+G!H<"<["FEN8VQU9&5?;VYC92`G2&]R9&4O3DQ3+G!H
M<"<["FEN8VQU9&5?;VYC92`G2&]R9&4O3F]T:69I8V%T:6]N+G!H<"<["FEN
M8VQU9&5?;VYC92`G2&]R9&4O075T:"YP:'`G.PII;F-L=61E7V]N8V4@)TAO
M<F1E+T)R;W=S97(N<&AP)SL*:6YC;'5D95]O;F-E("=(;W)D92]097)M<RYP
M:'`G.PH*+RH@0G)O=W-E<B!D971E8W1I;VX@;V)J96-T+B`J+PII9B`H8VQA
M<W-?97AI<W1S*"="<F]W<V5R)RDI('L*("`@("1B<F]W<V5R(#T@)D)R;W=S
M97(Z.G-I;F=L971O;B@I.PI]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O5D93+G!H<```````````
M````````````````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-C8V
M-S8@,3`U,34T,S,W-#`@,#$W-#<W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)U!%05(N
M<&AP)SL*<F5Q=6ER95]O;F-E("=,;V<N<&AP)SL*"F1E9FEN92@G5D937U%5
M3U1!7TU%5%))0U]"651%)RP@,2D["F1E9FEN92@G5D937U%53U1!7TU%5%))
M0U]+0B<L(#(I.PID969I;F4H)U9&4U]154]405]-151224-?34(G+"`S*3L*
M9&5F:6YE*"=61E-?455/5$%?34544DE#7T=")RP@-"D["@HO*BH*("H@5D93
M($%022!F;W(@86)S=')A8W1E9"!F:6QE('-T;W)A9V4@86YD(&%C8V5S<RX*
M("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5D93+U9&4RYP:'`L=B`Q+C8Y+C0N
M,38@,C`P-B\P."\P-R`P,#HS,#HQ-"!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!P86-K86=E(%9&4PH@*B!`<VEN
M8V4@("!(;W)D92`R+C(*("HO"F-L87-S(%9&4R!["@H@("`@+RHJ"B`@("`@
M*B!(87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@
M("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<&%R86US
M(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($QI<W0@;V8@861D:71I;VYA
M;"!C<F5D96YT:6%L<R!R97%U:7)E9"!F;W(@=&AI<R!61E,@8F%C:V5N9"`H
M97AA;7!L93H*("`@("`J($9O<B!&5%`L('=E(&YE960@82!U<V5R;F%M92!A
M;F0@<&%S<W=O<F0@=&\@;&]G(&EN('1O('1H92!S97)V97(@=VET:"DN"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]C<F5D
M96YT:6%L<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!,:7-T(&]F('!E
M<FUI<W-I;VYS(&%N9"!I9B!T:&5Y(&-A;B!B92!C:&%N9V5D(&EN('1H:7,@
M5D93(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)%]P97)M:7-S:6]N<R`](&%R<F%Y*`H@("`@("`@("=O=VYE
M<B<@/3X@87)R87DH)W)E860G(#T^(&9A;'-E+"`G=W)I=&4G(#T^(&9A;'-E
M+"`G97AE8W5T92<@/3X@9F%L<V4I+`H@("`@("`@("=G<F]U<"<@/3X@87)R
M87DH)W)E860G(#T^(&9A;'-E+"`G=W)I=&4G(#T^(&9A;'-E+"`G97AE8W5T
M92<@/3X@9F%L<V4I+`H@("`@("`@("=A;&PG("`@/3X@87)R87DH)W)E860G
M(#T^(&9A;'-E+"`G=W)I=&4G(#T^(&9A;'-E+"`G97AE8W5T92<@/3X@9F%L
M<V4I*3L*"B`@("`O*BH*("`@("`J($$@4$5!4B!,;V<@;V)J96-T+B!)9B!P
M<F5S96YT+"!W:6QL(&)E('5S960@=&\@;&]G(&5R<F]R<R!A;F0*("`@("`J
M(&EN9F]R;6%T:6]N86P@;65S<V%G97,@86)O=70@5D93(&%C=&EV:71Y+@H@
M("`@("H*("`@("`J($!V87(@3&]G"B`@("`@*B\*("`@('9A<B`D7VQO9V=E
M<B`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!4:&4@;&]G(&QE=F5L('1O('5S
M92`M(&UE<W-A9V5S('=I=&@@82!H:6=H97(@;&]G(&QE=F5L('1H86X@8V]N
M9FEG=7)E9`H@("`@("H@:&5R92!W:6QL(&YO="!B92!L;V=G960N($1E9F%U
M;'1S('1O(&]N;'D@;&]G9VEN9R!E<G)O<G,@;W(@:&EG:&5R+@H@("`@("H*
M("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]L;V=,979E
M;"`](%!%05)?3$]'7T524CL*"B`@("`O*BH*("`@("`J(%1H92!C=7)R96YT
M('-I>F4L(&EN(&)Y=&5S+"!O9B!T:&4@5D93(&ET96TN"B`@("`@*@H@("`@
M("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7W9F<U-I>F4@/2!N
M=6QL.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&-O
M;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@5D93
M*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D
M<&%R86US6R=U<V5R)UTI*2!["B`@("`@("`@("`@("1P87)A;7-;)W5S97(G
M72`]("<G.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)'!A<F%M<ULG
M=F9S7W%U;W1A;&EM:70G72DI('L*("`@("`@("`@("`@)'!A<F%M<ULG=F9S
M7W%U;W1A;&EM:70G72`]("TQ.PH@("`@("`@('T*("`@("`@("!I9B`H96UP
M='DH)'!A<F%M<ULG=F9S7W%U;W1A<F]O="==*2D@>PH@("`@("`@("`@("`D
M<&%R86US6R=V9G-?<75O=&%R;V]T)UT@/2`G+R<["B`@("`@("`@?0H@("`@
M("`@("1T:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*
M("`@("`J($-H96-K<R!T:&4@8W)E9&5N=&EA;',@=&AA="!W92!H879E(&)Y
M(&-A;&QI;F<@7V-O;FYE8W0H*2P@=&\@<V5E(&EF"B`@("`@*B!T:&5R92!I
M<R!A('9A;&ED(&QO9VEN+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1R=64@;VX@<W5C8V5S<RP@4$5!4E]%<G)O<B!D97-C<FEB:6YG('1H92!P
M<F]B;&5M(&EF('1H90H@("`@("H@("`@("`@("`@("`@("`@8W)E9&5N=&EA
M;',@87)E(&EN=F%L:60N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-H96-K0W)E
M9&5N=&EA;',H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V-O;FYE
M8W0H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@8V]N9FEG=7)A=&EO
M;B!P87)A;65T97)S+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R
M86US("!!;B!A<W-O8VEA=&EV92!A<G)A>2!W:71H('!A<F%M971E<B!N86UE
M<R!A<R!K97ES+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971087)A;7,H)'!A
M<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@9F]R96%C:"`H)'!A<F%M
M<R!A<R`D;F%M92`]/B`D=F%L=64I('L*("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)&YA;65=(#T@)'9A;'5E.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@8V]N9FEG=7)A=&EO;B!P87)A;65T97)S+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!P87)A;65T
M97(@=&\@<F5T=7)N+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H
M92!P87)A;65T97(@=F%L=64@;W(@;G5L;"!I9B!I="!D;V5S;B=T(&5X:7-T
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971087)A;2@D;F%M92D*("`@('L*
M("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/E]P87)A;7-;)&YA;65=*2`_
M("1T:&ES+3Y?<&%R86US6R1N86UE72`Z(&YU;&P["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!,;V=S(&$@;65S<V%G92!I9B!A(%!%05(@3&]G(&]B:F5C="!I
M<R!A=F%I;&%B;&4L(&%N9"!T:&4@;65S<V%G92=S"B`@("`@*B!P<FEO<FET
M>2!I<R!L;W=E<B!T:&%N(&]R(&5Q=6%L('1O('1H92!C;VYF:6=U<F5D(&QO
M9R!L979E;"X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@("`D;65S<V%G
M92`@(%1H92!M97-S86=E('1O(&)E(&QO9V=E9"X*("`@("`J($!P87)A;2!I
M;G1E9V5R("1P<FEO<FET>2`@5&AE(&UE<W-A9V4G<R!P<FEO<FET>2X*("`@
M("`J+PH@("`@9G5N8W1I;VX@;&]G*"1M97-S86=E+"`D<')I;W)I='D@/2!0
M14%27TQ/1U]%4E(I"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^
M7VQO9V=E<BD@?'P@)'!R:6]R:71Y(#X@)'1H:7,M/E]L;V=,979E;"D@>PH@
M("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?
M82@D;65S<V%G92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D=7-E
M<FEN9F\@/2`D;65S<V%G92T^9V5T57-E<DEN9F\H*3L*("`@("`@("`@("`@
M)&UE<W-A9V4@/2`D;65S<V%G92T^9V5T365S<V%G92@I.PH@("`@("`@("`@
M("!I9B`H)'5S97)I;F9O*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?87)R
M87DH)'5S97)I;F9O*2D@>PH@("`@("`@("`@("`@("`@("`@("1U<V5R:6YF
M;R`](&EM<&QO9&4H)RP@)RP@)'5S97)I;F9O*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("1M97-S86=E("X]("<Z("<@+B`D=7-E<FEN
M9F\["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J($UA:V4@
M<W5R92!T;R!L;V<@:6X@=&AE('-Y<W1E;2=S(&QO8V%L92X@*B\*("`@("`@
M("`D;&]C86QE(#T@<V5T;&]C86QE*$Q#7U1)344L(#`I.PH@("`@("`@('-E
M=&QO8V%L92A,0U]424U%+"`G0R<I.PH*("`@("`@("`D=&AI<RT^7VQO9V=E
M<BT^;&]G*"1M97-S86=E+"`D<')I;W)I='DI.PH*("`@("`@("`O*B!297-T
M;W)E(&]R:6=I;F%L(&QO8V%L92X@*B\*("`@("`@("!S971L;V-A;&4H3$-?
M5$E-12P@)&QO8V%L92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H
M92!014%2($QO9R!O8FIE8W0@=7-E9"!T;R!L;V<@:6YF;W)M871I;VYA;"!O
M<B!E<G)O<B!M97-S86=E<RX*("`@("`J"B`@("`@*B!`<&%R86T@3&]G("8D
M;&]G9V5R("!4:&4@3&]G(&]B:F5C="!T;R!U<V4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-E=$QO9V=E<B@F)&QO9V=E<BP@)&QO9TQE=F5L(#T@;G5L;"D*
M("`@('L*("`@("`@("!I9B`H(6ES7V$H)&QO9V=E<BP@)TQO9R<I*2!["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1T
M:&ES+3Y?;&]G9V5R(#T@)B1L;V=G97(["B`@("`@("`@:68@*"%I<U]N=6QL
M*"1L;V=,979E;"DI('L*("`@("`@("`@("`@)'1H:7,M/E]L;V=,979E;"`]
M("1L;V=,979E;#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971R:65V97,@=&AE('-I>F4@;V8@82!F:6QE(&9R;VT@=&AE(%9&4RX*("`@
M("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1P871H("!4:&4@<&%T:&YA;64@=&\@=&AE(&9I;&4N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1N86UE("!4:&4@9FEL96YA;64@=&\@<F5T<FEE=F4N
M"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R(%1H92!F:6QE('-I>F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-I>F4H)'!A=&@L("1N86UE*0H@("`@
M>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DYO="!S=7!P
M;W)T960N(BDI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M<VEZ92!O9B!A(&9O;&1E<@H@("`@("H*("`@("`J($!S:6YC92!(;W)D92`S
M+C$*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T
M:"!T;R!T:&4@9F]L9&5R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@
M5&AE(&YA;64@;V8@=&AE(&9O;&1E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&EN=&5G97(@(%1H92!S:7IE(&]F('1H92!F;VQD97(L(&EN(&)Y=&5S+"!O
M<B!014%27T5R<F]R(&]N"B`@("`@*B`@("`@("`@("`@("`@("`@(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$9O;&1E<E-I>F4H)'!A=&@@
M/2!N=6QL+"`D;F%M92`](&YU;&PI"B`@("!["B`@("`@("`@)'-I>F4@/2`P
M.PH@("`@("`@("1R;V]T(#T@*"@A:7-?;G5L;"@D<&%T:"DI(#\@)'!A=&@@
M+B`G+R<@.B`G)RD@+B`D;F%M93L*("`@("`@("`D;V)J96-T7VQI<W0@/2`D
M=&AI<RT^;&ES=$9O;&1E<B@D<F]O="P@;G5L;"P@=')U92P@9F%L<V4L('1R
M=64I.PH@("`@("`@(&9O<F5A8V@@*"1O8FIE8W1?;&ES="!A<R`D:V5Y(#T^
M("1V86PI('L*("`@("`@("`@("`@:68@*&ES<V5T*"1V86Q;)W-U8F1I<G,G
M72DI('L*("`@("`@("`@("`@("`@("1S:7IE("L]("1T:&ES+3YG971&;VQD
M97)3:7IE*"1R;V]T+"`D:V5Y*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1F:6QE<VEZ92`]("1T:&ES+3YS:7IE*"1R;V]T+"`D
M:V5Y*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1F:6QE<VEZ92P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D9FEL
M97-I>F4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<VEZ
M92`K/2`D9FEL97-I>F4["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D<VEZ93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I
M979E<R!A(&9I;&4@9G)O;2!T:&4@5D93+@H@("`@("H*("`@("`J($!A8G-T
M<F%C=`H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P
M871H;F%M92!T;R!T:&4@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)&YA
M;64@(%1H92!F:6QE;F%M92!T;R!R971R:65V92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R!4:&4@9FEL92!D871A+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!R96%D*"1P871H+"`D;F%M92D*("`@('L*("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BA?*").;W0@<W5P<&]R=&5D+B(I*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E=')I979E<R!A('!A<G0@;V8@82!F:6QE(&9R
M;VT@=&AE(%9&4RX@4&%R=&EC=6QA<FQY('5S969U;"!W:&5N"B`@("`@*B!R
M96%D:6YG(&QA<F=E(&9I;&5S('=H:6-H('=O=6QD(&5X8V5E9"!T:&4@4$A0
M(&UE;6]R>2!L:6UI=',@:68@=&AE>0H@("`@("H@=V5R92!S=&]R960@:6X@
M82!S=')I;F<N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@)'!A=&@@("`@("`@5&AE('!A=&AN86UE('1O
M('1H92!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&YA;64@("`@("`@
M5&AE(&9I;&5N86UE('1O(')E=')I979E+@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)&]F9G-E="`@("`@5&AE(&]F9G-E="!O9B!T:&4@<&%R="X@*%1H92!N
M97<@;V9F<V5T('=I;&P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&)E('-T;W)E9"!I;B!H97)E*2X*("`@("`J($!P87)A;2!I;G1E9V5R
M("1L96YG=&@@("`@(%1H92!L96YG=&@@;V8@=&AE('!A<G0N($EF('1H92!L
M96YG=&@@/2`M,2P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('1H92!W:&]L92!P87)T(&%F=&5R('1H92!O9F9S970@:7,@<F5T<FEE=F5D
M+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@268@;6]R92!B
M>71E<R!A<F4@9VEV96X@87,@97AI<W1S(&%F=&5R('1H90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@9VEV96X@;V9F<V5T+B!/;FQY('1H
M92!A=F%I;&%B;&4@8GET97,@87)E"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!R96%D+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')E;6%I
M;FEN9R`@5&AE(&)Y=&5S('1H870@87)E(&QE9G0L(&%F=&5R('1H92!P87)T
M('1H870*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&ES(')E
M=')I979E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R!4:&4@9FEL
M92!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96%D0GET95)A;F=E*"1P
M871H+"`D;F%M92P@)B1O9F9S970L("1L96YG=&@@/2`M,2P@)B1R96UA:6YI
M;F<I"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M3F]T('-U<'!O<G1E9"XB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3=&]R
M97,@82!F:6QE(&EN('1H92!61E,N"B`@("`@*@H@("`@("H@0&%B<W1R86-T
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@("`@(%1H
M92!P871H('1O('-T;W)E('1H92!F:6QE(&EN+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;F%M92`@("`@("`@(%1H92!F:6QE;F%M92!T;R!U<V4N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1T;7!&:6QE("`@("`@5&AE('1E;7!O<F%R>2!F
M:6QE(&-O;G1A:6YI;F<@=&AE(&1A=&$@=&\*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!B92!S=&]R960N"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D875T;V-R96%T92`@075T;VUA=&EC86QL>2!C<F5A=&4@9&ER96-T
M;W)I97,_"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S
M=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@=W)I=&4H)'!A=&@L("1N86UE+"`D=&UP1FEL
M92P@)&%U=&]C<F5A=&4@/2!F86QS92D*("`@('L*("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BA?*").;W0@<W5P<&]R=&5D+B(I*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%-T;W)E<R!A(&9I;&4@:6X@=&AE(%9&4R!F<F]M
M(')A=R!D871A+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'!A=&@@("`@("`@("!4:&4@<&%T:"!T;R!S
M=&]R92!T:&4@9FEL92!I;BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@
M("`@("`@("!4:&4@9FEL96YA;64@=&\@=7-E+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9&%T82`@("`@("`@(%1H92!F:6QE(&1A=&$N"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D875T;V-R96%T92`@075T;VUA=&EC86QL>2!C<F5A=&4@
M9&ER96-T;W)I97,_"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U
M92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@=W)I=&5$871A*"1P871H+"`D;F%M
M92P@)&1A=&$L("1A=71O8W)E871E(#T@9F%L<V4I"B`@("!["B`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B3F]T('-U<'!O<G1E9"XB*2D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!-;W9E<R!A(&9I;&4@=&AR;W5G:"!T
M:&4@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!O9B!T:&4@;W)I
M9VEN86P@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!N
M86UE(&]F('1H92!O<FEG:6YA;"!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9&5S="`@5&AE(&1E<W1I;F%T:6]N(&9I;&4@;F%M92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%2
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!M;W9E*"1P871H+"`D;F%M92P@)&1E<W0I"B`@("!["B`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B3F]T('-U<'!O<G1E9"XB*2D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#;W!I97,@82!F:6QE('1H<F]U9V@@=&AE
M(&)A8VME;F0N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@;V8@=&AE(&]R:6=I
M;F%L(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@;F%M
M92!O9B!T:&4@;W)I9VEN86P@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@
M)&1E<W0@(%1H92!N86UE(&]F('1H92!D97-T:6YA=&EO;B!D:7)E8W1O<GDN
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S
M(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@8V]P>2@D<&%T:"P@)&YA;64L("1D97-T*0H@("`@>PH@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DYO="!S=7!P;W)T
M960N(BDI.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E<R!A(&9I;&4@
M9G)O;2!T:&4@5D93+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H('1O(&1E;&5T
M92!T:&4@9FEL92!F<F]M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@
M5&AE(&9I;&5N86UE('1O(&1E;&5T92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96QE=&5&:6QE
M*"1P871H+"`D;F%M92D*("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BA?*").;W0@<W5P<&]R=&5D+B(I*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E;F%M97,@82!F:6QE(&EN('1H92!61E,N"B`@("`@*@H@("`@
M("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;VQD
M<&%T:"`@5&AE(&]L9"!P871H('1O('1H92!F:6QE+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;VQD;F%M92`@5&AE(&]L9"!F:6QE;F%M92X*("`@("`J($!P
M87)A;2!S=')I;F<@)&YE=W!A=&@@(%1H92!N97<@<&%T:"!O9B!T:&4@9FEL
M92X*("`@("`J($!P87)A;2!S=')I;F<@)&YE=VYA;64@(%1H92!N97<@9FEL
M96YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S
M=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@<F5N86UE*"1O;&1P871H+"`D;VQD;F%M92P@
M)&YE=W!A=&@L("1N97=N86UE*0H@("`@>PH@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*%\H(DYO="!S=7!P;W)T960N(BDI.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!I9B!A(&=I=F5N(&9I;&4@;W(@9F]L9&5R
M(&5X:7-T<R!I;B!A(&9O;&1E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1P871H("!4:&4@<&%T:"!T;R!T:&4@9F]L9&5R+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;F%M92`@5&AE(&9I;&4@;W(@9F]L9&5R(&YA;64N"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF(&ET(&5X:7-T
M<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>&ES
M=',H)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@("1L:7-T(#T@)'1H:7,M
M/FQI<W1&;VQD97(H)'!A=&@I.PH@("`@("`@(&EF("AI<U]A*"1L:7-T+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@:7-S970H)&QI<W1;
M)&YA;65=*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A
M=&5S(&$@9F]L9&5R(&EN('1H92!61E,N"B`@("`@*@H@("`@("H@0&%B<W1R
M86-T"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A
M<F5N="!F;VQD97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@
M;F%M92!O9B!T:&4@;F5W(&9O;&1E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C<F5A=&5&;VQD
M97(H)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(DYO="!S=7!P;W)T960N(BDI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@075T;VUA=&EC86QL>2!C<F5A=&5S(&%N>2!N96-E<W-A<GD@
M<&%R96YT(&1I<F5C=&]R:65S(&EN('1H92!S<&5C:69I960*("`@("`J("1P
M871H+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!6
M1E,@<&%T:"!T;R!A=71O8W)E871E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A
M=71O8W)E871E4&%T:"@D<&%T:"D*("`@('L*("`@("`@("`D9&ER<R`](&5X
M<&QO9&4H)R\G+"`D<&%T:"D["B`@("`@("`@:68@*&ES7V%R<F%Y*"1D:7)S
M*2D@>PH@("`@("`@("`@("`D8W5R(#T@)R\G.PH@("`@("`@("`@("!F;W)E
M86-H("@D9&ER<R!A<R`D9&ER*2!["B`@("`@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1D:7(I*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"$D=&AI<RT^
M:7-&;VQD97(H)&-U<BP@)&1I<BDI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)')E<W5L="`]("1T:&ES+3YC<F5A=&5&;VQD97(H)&-U<BP@)&1I<BD[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&EF("@D8W5R
M("$]("<O)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D8W5R("X]("<O
M)SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M)&-U<B`N/2`D9&ER.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J($-H96-K<R!I9B!A(&=I=F5N(&ET96T@:7,@82!F;VQD97(N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A<F5N
M="!F;VQD97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@:71E
M;2!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I
M9B!I="!I<R!A(&9O;&1E<BP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!I<T9O;&1E<B@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@
M("`@)&9O;&1E<DQI<W0@/2`D=&AI<RT^;&ES=$9O;&1E<B@D<&%T:"P@;G5L
M;"P@=')U92P@=')U92D["B`@("`@("`@<F5T=7)N(&ES<V5T*"1F;VQD97),
M:7-T6R1N86UE72D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&$@
M9F]L9&5R(&9R;VT@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`86)S=')A8W0*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@("!4:&4@
M<&%R96YT(&9O;&1E<BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@
M("`@(%1H92!N86UE(&]F('1H92!F;VQD97(@=&\@9&5L971E+@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)')E8W5R<VEV92`@1F]R8V4@82!R96-U<G-I=F4@
M9&5L971E/PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@
M<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T949O;&1E<B@D<&%T:"P@)&YA;64L
M("1R96-U<G-I=F4@/2!F86QS92D*("`@('L*("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BA?*").;W0@<W5P<&]R=&5D+B(I*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E8W5R<VEV96QY(')E;6]V92!A;&P@9FEL97,@86YD
M('-U8F9O;&1E<G,@9G)O;2!T:&4@9VEV96X*("`@("`J(&9O;&1E<BX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!O9B!T
M:&4@9F]L9&5R('1O(&5M<'1Y+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5M<'1Y1F]L9&5R*"1P
M871H*0H@("`@>PH@("`@("`@("\O($=E="!A;F0@9&5L971E('1H92!S=6)F
M;VQD97)S+@H@("`@("`@("1L:7-T(#T@)'1H:7,M/FQI<W1&;VQD97(H)'!A
M=&@L(&YU;&PL('1R=64L('1R=64I.PH@("`@("`@(&EF("AI<U]A*"1L:7-T
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D;&ES=#L*
M("`@("`@("!]"B`@("`@("`@9F]R96%C:"`H)&QI<W0@87,@)&9O;&1E<BD@
M>PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F1E;&5T949O;&1E<B@D
M<&%T:"P@)&9O;&1E<ELG;F%M92==+"!T<G5E*3L*("`@("`@("`@("`@:68@
M*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("`@("`@+R\@3VYL>2!F:6QE<R!A<F4@;&5F="P@9V5T(&%N9"!D96QE=&4@
M=&AE;2X*("`@("`@("`D;&ES="`]("1T:&ES+3YL:7-T1F]L9&5R*"1P871H
M*3L*("`@("`@("!I9B`H:7-?82@D;&ES="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)&QI<W0["B`@("`@("`@?0H@("`@("`@(&9O
M<F5A8V@@*"1L:7-T(&%S("1F:6QE*2!["B`@("`@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^9&5L971E1FEL92@D<&%T:"P@)&9I;&5;)VYA;64G72D["B`@
M("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@82!F:6QE(&QI<W0@;V8@=&AE(&1I<F5C=&]R
M>2!P87-S960@:6XN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T
M:"`@("`@("`@5&AE('!A=&@@;V8@=&AE(&1I<F5C=&]R>2X*("`@("`J($!P
M87)A;2!M:7AE9"`D9FEL=&5R("`@("`@(%-T<FEN9R]H87-H('1O(&9I;'1E
M<B!F:6QE+V1I<FYA;64@;VXN"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&]T
M9FEL97,@("!3:&]W(&1O=&9I;&5S/PH@("`@("H@0'!A<F%M(&)O;VQE86X@
M)&1I<F]N;'D@("`@4VAO=R!O;FQY(&1I<F5C=&]R:65S/PH@("`@("H@0'!A
M<F%M(&)O;VQE86X@)')E8W5R<VEV92`@4F5T=7)N(&%L;"!D:7)E8W1O<GD@
M;&5V96QS(')E8W5R<VEV96QY/PH@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@($9I;&4@;&ES="!O;B!S=6-C97-S(&]R(%!%05)?17)R;W(@;VX@9F%I
M;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=$9O;&1E<B@D<&%T:"P@
M)&9I;'1E<B`](&YU;&PL("1D;W1F:6QE<R`]('1R=64L"B`@("`@("`@("`@
M("`@("`@("`@("`@("1D:7)O;FQY(#T@9F%L<V4L("1R96-U<G-I=F4@/2!F
M86QS92D*("`@('L*("`@("`@("`D;&ES="`]("1T:&ES+3Y?;&ES=$9O;&1E
M<B@D<&%T:"P@)&9I;'1E<BP@)&1O=&9I;&5S+"`D9&ER;VYL>2D["B`@("`@
M("`@:68@*"$D<F5C=7)S:79E('Q\(&ES7V$H)&QI<W0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1L:7-T.PH@("`@("`@('T*"B`@
M("`@("`@9F]R96%C:"`H)&QI<W0@87,@)&YA;64@/3X@)'9A;'5E<RD@>PH@
M("`@("`@("`@("!I9B`H)'9A;'5E<ULG='EP92==(#T]("<J*F1I<B<I('L*
M("`@("`@("`@("`@("`@("1L:7-T6R1N86UE75LG<W5B9&ER<R==(#T@)'1H
M:7,M/FQI<W1&;VQD97(H)'!A=&@@+B`G+R<@+B`D;F%M92P@)&9I;'1E<BP@
M)&1O=&9I;&5S+"`D9&ER;VYL>2P@)')E8W5R<VEV92D["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;&ES=#L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@86X@86X@=6YS;W)T960@9FEL92!L:7-T
M(&]F('1H92!S<&5C:69I960@9&ER96-T;W)Y+@H@("`@("H*("`@("`J($!A
M8G-T<F%C=`H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@("`@
M("`@5&AE('!A=&@@;V8@=&AE(&1I<F5C=&]R>2X*("`@("`J($!P87)A;2!M
M:7AE9"`D9FEL=&5R("`@("`@4W1R:6YG+VAA<V@@=&\@9FEL=&5R(&9I;&4O
M9&ER;F%M92!O;BX*("`@("`J($!P87)A;2!B;V]L96%N("1D;W1F:6QE<R`@
M4VAO=R!D;W1F:6QE<S\*("`@("`J($!P87)A;2!B;V]L96%N("1D:7)O;FQY
M("`@4VAO=R!O;FQY(&1I<F5C=&]R:65S/PH@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@($9I;&4@;&ES="!O;B!S=6-C97-S(&]R(%!%05)?17)R;W(@
M;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7VQI<W1&;VQD97(H
M)'!A=&@L("1F:6QT97(@/2!N=6QL+"`D9&]T9FEL97,@/2!T<G5E+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@)&1I<F]N;'D@/2!F86QS92D*("`@('L*
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;W0@<W5P<&]R
M=&5D+B(I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-U
M<G)E;G0@=V]R:VEN9R!D:7)E8W1O<GD@;V8@=&AE(%9&4R!B86-K96YD+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8W5R<F5N="!W;W)K
M:6YG(&1I<F5C=&]R>2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0W5R<F5N
M=$1I<F5C=&]R>2@I"B`@("!["B`@("`@("`@<F5T=7)N("<G.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!W:&5T:&5R(&]R(&YO="!A(&9I;&5N
M86UE(&UA=&-H97,@86YY(&9I;'1E<B!E;&5M96YT+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D
M9FEL=&5R("`@("!3=')I;F<O:&%S:"!T;R!B=6EL9"!T:&4@<F5G=6QA<B!E
M>'!R97-S:6]N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@9G)O
M;2X*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&5N86UE("!3=')I;F<@8V]N
M=&%I;FEN9R!T:&4@9FEL96YA;64@=&\@;6%T8V@N"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N("!4<G5E(&]N(&UA=&-H+"!F86QS92!O;B!N;R!M
M871C:"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V9I;'1E<DUA=&-H*"1F:6QT
M97(L("1F:6QE;F%M92D*("`@('L*("`@("`@("`D;F%M969I;'1E<B`](&YU
M;&P["@H@("`@("`@("\O($)U:6QD(&$@<F5G97AP(&)A<V5D(&]N("1F:6QT
M97(N"B`@("`@("`@:68@*"1F:6QT97(@(3T](&YU;&PI('L*("`@("`@("`@
M("`@)&YA;65F:6QT97(@/2`G+R<["B`@("`@("`@("`@(&EF("AI<U]A<G)A
M>2@D9FEL=&5R*2D@>PH@("`@("`@("`@("`@("`@)&]N8V4@/2!F86QS93L*
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1F:6QT97(@87,@)&ET96TI('L*
M("`@("`@("`@("`@("`@("`@("!I9B`H)&]N8V4@(3T]('1R=64I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&YA;65F:6QT97(@+CT@)R@G.PH@("`@
M("`@("`@("`@("`@("`@("`@("`D;VYC92`]('1R=64["B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)&YA
M;65F:6QT97(@+CT@)WPH)SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@)&YA;65F:6QT97(@+CT@)&ET96T@+B`G*2<["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D;F%M969I;'1E<B`N/2`G*"<@+B`D9FEL=&5R("X@)RDG.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1N86UE9FEL=&5R("X]("<O)SL*
M("`@("`@("!]"@H@("`@("`@("1M871C:"`](&9A;'-E.PH@("`@("`@(&EF
M("@D;F%M969I;'1E<B`A/3T@;G5L;"D@>PH@("`@("`@("`@("`D;6%T8V@@
M/2!P<F5G7VUA=&-H*"1N86UE9FEL=&5R+"`D9FEL96YA;64I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1M871C:#L*("`@('T*"B`@("`O*BH*("`@
M("`J($-H86YG97,@<&5R;6ES<VEO;G,@9F]R(&%N(&ET96T@;VX@=&AE(%9&
M4RX*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1P871H("`@("`@("!4:&4@<&%R96YT(&9O;&1E<B!O9B!T
M:&4@:71E;2X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@("`@(%1H
M92!N86UE(&]F('1H92!I=&5M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&5R
M;6ES<VEO;B`@5&AE('!E<FUI<W-I;VX@=&\@<V5T+@H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R
M;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-H
M86YG95!E<FUI<W-I;VYS*"1P871H+"`D;F%M92P@)'!E<FUI<W-I;VXI"B`@
M("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B3F]T('-U
M<'!O<G1E9"XB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@
M<V]R=&5D(&QI<W0@;V8@9F]L9&5R<R!I;B!T:&4@<W!E8VEF:65D(&1I<F5C
M=&]R>2X*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1P871H("`@("`@("`@5&AE('!A=&@@;V8@=&AE(&1I
M<F5C=&]R>2!T;R!G970@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@9&ER96-T;W)Y(&QI<W0@9F]R+@H@("`@("H@0'!A<F%M(&UI
M>&5D("1F:6QT97(@("`@("`@($AA<V@@;V8@:71E;7,@=&\@9FEL=&5R(&)A
M<V5D(&]N(&9O;&1E<FQI<W0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&]T
M9F]L9&5R<R`@26YC;'5D92!D;W1F;VQD97)S/PH@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@($9O;&1E<B!L:7-T(&]N('-U8V-E<W,@;W(@82!014%2
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!L:7-T1F]L9&5R<R@D<&%T:"`]("<G+"`D9FEL=&5R(#T@;G5L;"P@)&1O
M=&9O;&1E<G,@/2!T<G5E*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(DYO="!S=7!P;W)T960N(BDI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!T:&4@;&ES="!O9B!A9&1I=&EO;F%L(&-R961E
M;G1I86QS(')E<75I<F5D+"!I9B!A;GDN"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@0W)E9&5N=&EA;"!L:7-T+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971297%U:7)E9$-R961E;G1I86QS*"D*("`@('L*("`@("`@("!R971U
M<FX@87)R87E?9&EF9B@D=&AI<RT^7V-R961E;G1I86QS+"!A<G)A>5]K97ES
M*"1T:&ES+3Y?<&%R86US*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS(&%N(&%R<F%Y('-P96-I9GEI;F<@=VAA="!P97)M:7-S:6]N<R!A<F4@
M8VAA;F=E86)L92!F;W(@=&AI<PH@("`@("H@5D93(&EM<&QE;65N=&%T:6]N
M+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($-H86YG96%B;&4@<&5R
M;6ES:6]N<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T36]D:69I86)L95!E
M<FUI<W-I;VYS*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]P97)M
M:7-S:6]N<SL*("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E<G1S(&$@<W1R
M:6YG('1O(&%L;"!L;W=E<F-A<V4@8VAA<F%C=&5R<R!I9VYO<FEN9R!T:&4@
M8W5R<F5N=`H@("`@("H@;&]C86QE+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'-T<FEN9R`@5&AE('-T<FEN9R!T;R!B92!L;W=E<F-A<V5D"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!S=')I;F<@=VET:"!L
M;W=E<F-A<V4@8VAA<F%C=&5R<PH@("`@("HO"B`@("!F=6YC=&EO;B!S=')T
M;VQO=V5R*"1S=')I;F<I"B`@("!["B`@("`@("`@)&QA;F=U86=E(#T@<V5T
M;&]C86QE*$Q#7T-465!%+"`P*3L*("`@("`@("!S971L;V-A;&4H3$-?0U19
M4$4L("=E;B<I.PH@("`@("`@("1S=')I;F<@/2!S=')T;VQO=V5R*"1S=')I
M;F<I.PH@("`@("`@('-E=&QO8V%L92A,0U]#5%E012P@)&QA;F=U86=E*3L*
M("`@("`@("!R971U<FX@)'-T<FEN9SL*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=&AE(&-H87)A8W1E<B`H;F]T(&)Y=&4I(&QE;F=T:"!O9B!A
M('-T<FEN9RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S=')I;F<@
M("!4:&4@<W1R:6YG('1O(')E='5R;B!T:&4@;&5N9W1H(&]F+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D8VAA<G-E="`@5&AE(&-H87)S970@=&\@=7-E('=H
M96X@8V%L8W5L871I;F<@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("!S=')I;F<G<R!L96YG=&@N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!S=')I;F<G<R!L96YG=&@N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('-T<FQE;B@D<W1R:6YG+"`D8VAA<G-E="`](&YU;&PI"B`@("!["B`@
M("`@("`@:68@*&5X=&5N<VEO;E]L;V%D960H)VUB<W1R:6YG)RDI('L*("`@
M("`@("`@("`@:68@*&ES7VYU;&PH)&-H87)S970I*2!["B`@("`@("`@("`@
M("`@("`D8VAA<G-E="`]("=)4T\M.#@U.2TQ)SL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D<F5T(#T@0&UB7W-T<FQE;B@D<W1R:6YG+"`D8VAA<G-E
M="D["B`@("`@("`@("`@(&EF("@A96UP='DH)')E="DI('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D<F5T.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@(')E='5R;B!S=')L96XH)'-T<FEN9RD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92!S:7IE(&]F('1H92!61E,@:71E;2X*("`@
M("`J"B`@("`@*B!`<VEN8V4@2&]R9&4@,RXQ"B`@("`@*@H@("`@("H@0')E
M='5R;B!I;G1E9V5R("!4:&4@<VEZ92P@:6X@8GET97,L(&]F('1H92!61E,@
M:71E;2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5D934VEZ92@I"B`@("![
M"B`@("`@("`@:68@*&ES7VYU;&PH)'1H:7,M/E]V9G-3:7IE*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7W9F<U-I>F4@/2`D=&AI<RT^9V5T1F]L9&5R4VEZ
M92@D=&AI<RT^7W!A<F%M<ULG=F9S7W%U;W1A<F]O="==*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=F9S4VEZ93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E=',@=&AE(%9&4R!Q=6]T82!L:6UI="X*("`@("`J"B`@
M("`@*B!`<VEN8V4@2&]R9&4@,RXQ"B`@("`@*@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)'%U;W1A("`@5&AE(&QI;6ET('1O(&%P<&QY+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&UE=')I8R`@5&AE(&UE=')I8R!T;R!M=6QT:7!L>2!T
M:&4@<75O=&$@:6YT;RX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T475O=&$H
M)'%U;W1A+"`D;65T<FEC(#T@5D937U%53U1!7TU%5%))0U]"651%*0H@("`@
M>PH@("`@("`@('-W:71C:"`H)&UE=')I8RD@>PH@("`@("`@(&-A<V4@5D93
M7U%53U1!7TU%5%))0U]+0CH*("`@("`@("`@("`@)'%U;W1A("H]('!O=R@R
M+"`Q,"D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%9&4U]1
M54]405]-151224-?34(Z"B`@("`@("`@("`@("1Q=6]T82`J/2!P;W<H,BP@
M,C`I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!61E-?455/
M5$%?34544DE#7T=".@H@("`@("`@("`@("`D<75O=&$@*CT@<&]W*#(L(#,P
M*3L*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG=F9S7W%U;W1A;&EM:70G72`]("1Q=6]T83L*("`@('T*
M"B`@("`O*BH*("`@("`J(%-E=',@=&AE(%9&4R!Q=6]T82!R;V]T+@H@("`@
M("H*("`@("`J($!S:6YC92!(;W)D92`S+C$*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1D:7(@(%1H92!R;V]T(&1I<F5C=&]R>2!F;W(@=&AE('%U
M;W1A(&1E=&5R;6EN871I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%%U
M;W1A4F]O="@D9&ER*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<&%R86US6R=V
M9G-?<75O=&%R;V]T)UT@/2`D9&ER.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1V5T('%U;W1A(&EN9F]R;6%T:6]N("AU<V5D+V%L;&]C871E9"DL(&EN(&)Y
M=&5S+@H@("`@("H*("`@("`J($!S:6YC92!(;W)D92`S+C$*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!!;B!A<W-O8VEA=&EV92!A<G)A>2X*("`@
M("`J("`@("`@("`@("`@("`@("=L:6UI="<@/2!-87AI;75M('%U;W1A(&%L
M;&]W960*("`@("`J("`@("`@("`@("`@("`@("=U<V%G92<@/2!#=7)R96YT
M;'D@=7-E9"!P;W)T:6]N(&]F('%U;W1A("AI;B!B>71E<RD*("`@("`J("`@
M("`@("`@("`@("`@(%)E='5R;G,@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G9711=6]T82@I"B`@("!["B`@("`@("`@
M:68@*&5M<'1Y*"1T:&ES+3Y?<&%R86US6R=V9G-?<75O=&%L:6UI="==*2D@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;R!Q
M=6]T82!S970N(BDI.PH@("`@("`@('T*"B`@("`@("`@)'5S86=E(#T@)'1H
M:7,M/F=E=%9&4U-I>F4H*3L*("`@("`@("!I9B`H:7-?82@D=7-A9V4L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1U<V%G93L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@87)R87DH)W5S86=E
M)R`]/B`D=7-A9V4L("=L:6UI="<@/3X@)'1H:7,M/E]P87)A;7-;)W9F<U]Q
M=6]T86QI;6ET)UTI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($1E=&5R;6EN97,@=&AE(&QO8V%T:6]N(&]F('1H92!S>7-T96T@=&5M<&]R
M87)Y(&1I<F5C=&]R>2X*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E8W1E
M9`H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!!(&1I<F5C=&]R>2!N
M86UE('=H:6-H(&-A;B!B92!U<V5D(&9O<B!T96UP(&9I;&5S+@H@("`@("H@
M("`@("`@("`@("`@("`@(%)E='5R;G,@9F%L<V4@:68@;VYE(&-O=6QD(&YO
M="!B92!F;W5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=%1E;7!$:7(H
M*0H@("`@>PH@("`@("`@("1T;7!?;&]C871I;VYS(#T@87)R87DH)R]T;7`G
M+"`G+W9A<B]T;7`G+"`G8SI<5U5496UP)RP@)V,Z7'1E;7`G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)V,Z7'=I;F1O=W-<=&5M<"<L("=C
M.EQW:6YN=%QT96UP)RD["@H@("`@("`@("\J(%1R>2!02%`G<R!U<&QO861?
M=&UP7V1I<B!D:7)E8W1I=F4N("HO"B`@("`@("`@)'1M<"`](&EN:5]G970H
M)W5P;&]A9%]T;7!?9&ER)RD["@H@("`@("`@("\J($]T:&5R=VES92P@=')Y
M('1O(&1E=&5R;6EN92!T:&4@5$U01$E2(&5N=FER;VYM96YT('9A<FEA8FQE
M+B`J+PH@("`@("`@(&EF("AE;7!T>2@D=&UP*2D@>PH@("`@("`@("`@("`D
M=&UP(#T@9V5T96YV*"=435!$25(G*3L*("`@("`@("!]"@H@("`@("`@("\J
M($EF('=E('-T:6QL(&-A;FYO="!D971E<FUI;F4@82!V86QU92P@=&AE;B!C
M>6-L92!T:')O=6=H(&$@;&ES="!O9@H@("`@("`@("`J('!R97-E="!P;W-S
M:6)I;&ET:65S+B`J+PH@("`@("`@('=H:6QE("AE;7!T>2@D=&UP*2`F)B!S
M:7IE;V8H)'1M<%]L;V-A=&EO;G,I*2!["B`@("`@("`@("`@("1T;7!?8VAE
M8VL@/2!A<G)A>5]S:&EF="@D=&UP7VQO8V%T:6]N<RD["B`@("`@("`@("`@
M(&EF("A`:7-?9&ER*"1T;7!?8VAE8VLI*2!["B`@("`@("`@("`@("`@("`D
M=&UP(#T@)'1M<%]C:&5C:SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@+RH@268@:70@:7,@<W1I;&P@96UP='DL('=E(&AA=F4@9F%I;&5D
M+"!S;R!R971U<FX@9F%L<V4[(&]T:&5R=VES90H@("`@("`@("`J(')E='5R
M;B!T:&4@9&ER96-T;W)Y(&1E=&5R;6EN960N("HO"B`@("`@("`@<F5T=7)N
M(&5M<'1Y*"1T;7`I(#\@9F%L<V4@.B`D=&UP.PH@("`@?0H*("`@("\J*@H@
M("`@("H@0W)E871E<R!A('1E;7!O<F%R>2!F:6QE+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@("!2971U<FYS('1H92!F=6QL('!A=&@M;F%M92!T;R!T:&4@=&5M<&]R
M87)Y(&9I;&4@;W(*("`@("`J("`@("`@("`@("`@("`@("`@9F%L<V4@:68@
M82!T96UP;W)A<GD@9FEL92!C;W5L9"!N;W0@8F4@8W)E871E9"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V=E=%1E;7!&:6QE*"D*("`@('L*("`@("`@("`D
M=&UP7V1I<B`]("1T:&ES+3Y?9V5T5&5M<$1I<B@I.PH@("`@("`@(&EF("AE
M;7!T>2@D=&UP7V1I<BDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@)'1M<%]F:6QE(#T@=&5M<&YA;2@D=&UP7V1I
M<BP@)W9F<R<I.PH*("`@("`@("`O*B!)9B!T:&4@9FEL92!W87,@8W)E871E
M9"P@=&AE;B!R96=I<W1E<B!I="!F;W(@9&5L971I;VX@86YD"B`@("`@("`@
M("H@<F5T=7)N+B`J+PH@("`@("`@(&EF("AE;7!T>2@D=&UP7V9I;&4I*2![
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!R971U<FX@)'1M<%]F:6QE.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($-H96-K<R!T:&4@<75O=&$@=VAE;B!P<F5P87)I
M;F<@=&\@=W)I=&4@9&%T82X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1M;V1E("`@16ET:&5R
M("=S=')I;F<G(&]R("=F:6QE)RX@($EF("=S=')I;F<G+"`D9&%T82!I<PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@('1H92!D871A('1O(&)E('=R
M:71T96XN("!)9B`G9FEL92<L("1D871A(&ES('1H90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@(&9I;&5N86UE(&-O;G1A:6YI;F<@=&AE(&1A=&$@
M=&\@8F4@=W)I='1E;BX*("`@("`J($!P87)A;2!S=')I;F<@)B1D871A("!%
M:71H97(@=&AE(&1A=&$@;W(@=&AE(&9I;&5N86UE('1O('1H92!D871A+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@(%!%05)?17)R;W(@;VX@97)R
M;W(L('1R=64@;VX@<W5C8V5S<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V-H
M96-K475O=&%7<FET92@D;6]D92P@)B1D871A*0H@("`@>PH@("`@("`@(&EF
M("@D=&AI<RT^7W!A<F%M<ULG=F9S7W%U;W1A;&EM:70G72`A/2`M,2D@>PH@
M("`@("`@("`@("!I9B`H)&UO9&4@/3T@)V9I;&4G*2!["B`@("`@("`@("`@
M("`@("`D9FEL97-I>F4@/2!`9FEL97-I>F4H)&1A=&$I.PH@("`@("`@("`@
M("`@("`@:68@*"1F:6QE<VEZ92`]/3T@9F%L<V4I('L*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@
M<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+B(I*3L*("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)&9I;&5S:7IE(#T@<W1R;&5N*"1D871A*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D=F9S<VEZ92`]("1T:&ES+3YG97161E-3:7IE*"D["B`@
M("`@("`@("`@(&EF("AI<U]A*"1V9G-S:7IE+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)'9F<W-I>F4["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@:68@*"@D=F9S<VEZ92`K("1F:6QE<VEZ92D@/B`D
M=&AI<RT^7W!A<F%M<ULG=F9S7W%U;W1A;&EM:70G72D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(I*3L*("`@
M("`@("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?=F9S4VEZ92`A/3T@,"D@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]V9G-3:7IE("L]("1F:6QE<VEZ93L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@=&AE('%U;W1A('=H96X@
M<')E<&%R:6YG('1O(&1E;&5T92!D871A+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@
M(%1H92!P871H('1H92!F:6QE(&ES(&QO8V%T960@:6XN"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1N86UE("!4:&4@9FEL96YA;64N"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@4$5!4E]%<G)O<B!O;B!E<G)O<BP@=')U92!O;B!S
M=6-C97-S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8VAE8VM1=6]T841E;&5T
M92@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@:68@*"@D=&AI<RT^7W!A
M<F%M<ULG=F9S7W%U;W1A;&EM:70G72`A/2`M,2D@)B8*("`@("`@("`@("`@
M(65M<'1Y*"1T:&ES+3Y?=F9S4VEZ92DI('L*("`@("`@("`@("`@)&9I;&5S
M:7IE(#T@)'1H:7,M/G-I>F4H)'!A=&@L("1N86UE*3L*("`@("`@("`@("`@
M:68@*&ES7V$H)&9I;&5S:7IE+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@
M<F5A9"!61E,@9FEL92`H<VEZ92@I(&9A:6QE9"DN(BDI.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1T:&ES+3Y?=F9S4VEZ92`M/2`D9FEL97-I>F4[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(&-O;F-R971E(%9&4R!I
M;G-T86YC92!B87-E9"!O;B`D9')I=F5R+@H@("`@("H*("`@("`J($!P87)A
M;2!M:7AE9"`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!61E,@<W5B
M8VQA<W,@=&\@<F5T=7)N+B!4:&ES"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@:7,@8F%S960@;VX@=&AE('-T;W)A9V4@9')I=F5R("@D9')I=F5R
M*2X@5&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@8V]D92!I<R!D
M>6YA;6EC86QL>2!I;F-L=61E9"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R
M86US("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U
M<F%T:6]N(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@8V]N;F5C
M=&EO;B!P87)A;65T97)S(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(%9&4R`@5&AE(&YE=VQY(&-R96%T960@8V]N8W)E
M=&4@5D93(&EN<W1A;F-E+"!O<B!A(%!%05)?17)R;W(*("`@("`J("`@("`@
M("`@("`@("!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9F%C
M=&]R>2@D9')I=F5R+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@
M("!I;F-L=61E7V]N8V4@)U9&4R\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@
M("`@("`D8VQA<W,@/2`G5D937R<@+B`D9')I=F5R.PH@("`@("`@(&EF("AC
M;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D=F9S(#T@)FYE
M=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'9F<R`](%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")#;&%S<R!D
M969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB*2P@)&-L87-S*2D["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)'9F<SL*("`@('T*"B`@("`O*BH*("`@
M("`J($%T=&5M<'1S('1O(')E='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R
M971E(%9&4R!I;G-T86YC92!B87-E9"!O;@H@("`@("H@)&1R:79E<BX@270@
M=VEL;"!O;FQY(&-R96%T92!A(&YE=R!I;G-T86YC92!I9B!N;R!61E,@:6YS
M=&%N8V4@=VET:"!T:&4*("`@("`J('-A;64@<&%R86UE=&5R<R!C=7)R96YT
M;'D@97AI<W1S+@H@("`@("H*("`@("`J(%1H:7,@<VAO=6QD(&)E('5S960@
M:68@;75L=&EP;&4@='EP97,@;V8@9FEL92!B86-K96YD<R`H86YD+"!T:'5S
M+`H@("`@("H@;75L=&EP;&4@5D93(&EN<W1A;F-E<RD@87)E(')E<75I<F5D
M+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A
M<SH@)'9A<B`]("961E,Z.G-I;F=L971O;B@I"B`@("`@*@H@("`@("H@0'!A
M<F%M(&UI>&5D("1D<FEV97(@(%1H92!T>7!E(&]F(&-O;F-R971E(%9&4R!S
M=6)C;&%S<R!T;R!R971U<FXN(%1H:7,*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!I<R!B87-E9"!O;B!T:&4@<W1O<F%G92!D<FEV97(@*"1D<FEV
M97(I+B!4:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!C;V1E(&ES
M(&1Y;F%M:6-A;&QY(&EN8VQU9&5D+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P
M87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I
M9W5R871I;VX@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!C;VYN
M96-T:6]N('!A<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@
M("H*("`@("`J($!R971U<FX@5D93("!4:&4@8V]N8W)E=&4@5D93(')E9F5R
M96YC92P@;W(@82!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9S:6YG;&5T;VXH)&1R:79E<BP@)'!A<F%M<R`](&%R<F%Y
M*"DI"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T86YC97,["B`@("`@("`@
M:68@*"%I<W-E="@D:6YS=&%N8V5S*2D@>PH@("`@("`@("`@("`D:6YS=&%N
M8V5S(#T@87)R87DH*3L*("`@("`@("!]"@H@("`@("`@("1S:6=N871U<F4@
M/2!S97)I86QI>F4H87)R87DH)&1R:79E<BP@)'!A<F%M<RDI.PH@("`@("`@
M(&EF("@A:7-S970H)&EN<W1A;F-E<ULD<VEG;F%T=7)E72DI('L*("`@("`@
M("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E72`]("961E,Z.F9A8W1O<GDH
M)&1R:79E<BP@)'!A<F%M<RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&EN<W1A;F-E<ULD<VEG;F%T=7)E73L*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+V%P:2YP:'``
M````````````````````````````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#4R-S<U(#$P-3$U-#,S-S0P(#`Q-S8P-0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@2&]R9&4@
M97AT97)N86P@05!)(&EN=&5R9F%C92X*("H*("H@5&AI<R!F:6QE(&1E9FEN
M97,@2&]R9&4G<R!E>'1E<FYA;"!!4$D@:6YT97)F86-E+B!/=&AE<@H@*B!A
M<'!L:6-A=&EO;G,@8V%N(&EN=&5R86-T('=I=&@@2&]R9&4@=&AR;W5G:"!T
M:&ES($%022X*("H*("H@)$AO<F1E.B!H;W)D92]L:6(O87!I+G!H<"QV(#$N
M-#,N,BXU(#(P,#8O,#4O,#0@,3,Z,C<Z,C@@:F%N($5X<"`D"B`J"B`J($!P
M86-K86=E($AO<F1E"B`J+PH*+RH@0V]M<&QE>"!T>7!E<RX@*B\*)%]T>7!E
M<R`](&%R<F%Y*`H@("`@)WMU<FXZ:&]R9&5]<W1R:6YG07)R87DG(#T^(&%R
M<F%Y*&%R<F%Y*"=I=&5M)R`]/B`G<W1R:6YG)RDI+`H@("`@)VAA<VA)=&5M
M)R`]/B!A<G)A>2@G:V5Y)R`]/B`G<W1R:6YG)RP@)W9A;'5E)R`]/B`G<W1R
M:6YG)RDL"B`@("`G:&%S:"<@/3X@87)R87DH87)R87DH)VET96TG(#T^("=[
M=7)N.FAO<F1E?6AA<VA)=&5M)RDI+`H@("`@)VAA<VA(87-H271E;2<@/3X@
M87)R87DH)VME>2<@/3X@)W-T<FEN9R<L("=V86QU92<@/3X@)WMU<FXZ:&]R
M9&5]:&%S:"<I+`H@("`@)VAA<VA(87-H)R`]/B!A<G)A>2AA<G)A>2@G:71E
M;2<@/3X@)WMU<FXZ:&]R9&5]:&%S:$AA<VA)=&5M)RDI*3L*"B\J($QI<W1I
M;F=S+B`J+PHD7W-E<G9I8V5S6R=P97)M<R==(#T@87)R87DH"B`@("`G87)G
M<R<@/3X@87)R87DH*2P*("`@("=T>7!E)R`]/B`G>W5R;CIH;W)D97US=')I
M;F=!<G)A>2<I.PH*)%]S97)V:6-E<ULG861M:6Y?;&ES="==(#T@87)R87DH
M=')U92D["@HD7W-E<G9I8V5S6R=L:7-T07!P<R==(#T@87)R87DH"B`@("`G
M87)G<R<@/3X@87)R87DH)V9I;'1E<B<@/3X@)WMU<FXZ:&]R9&5]<W1R:6YG
M07)R87DG*2P*("`@("=T>7!E)R`]/B`G>W5R;CIH;W)D97US=')I;F=!<G)A
M>2<**3L*"B1?<V5R=FEC97-;)VQI<W1!4$ES)UT@/2!A<G)A>2@*("`@("=A
M<F=S)R`]/B!A<G)A>2@I+`H@("`@)W1Y<&4G(#T^("=[=7)N.FAO<F1E?7-T
M<FEN9T%R<F%Y)PHI.PH*+RH@0FQO8VMS+B`J+PHD7W-E<G9I8V5S6R=B;&]C
M:U1I=&QE)UT@/2!A<G)A>2@*("`@("=A<F=S)R`]/B!A<G)A>2@G87!P)R`]
M/B`G<W1R:6YG)RP@)VYA;64G(#T^("=S=')I;F<G+"`G<&%R86US)R`]/B`G
M>W5R;CIH;W)D97UH87-H)RDL"B`@("`G='EP92<@/3X@)W-T<FEN9R<**3L*
M"B1?<V5R=FEC97-;)V)L;V-K0V]N=&5N="==(#T@87)R87DH"B`@("`G87)G
M<R<@/3X@87)R87DH)V%P<"<@/3X@)W-T<FEN9R<L("=N86UE)R`]/B`G<W1R
M:6YG)RP@)W!A<F%M<R<@/3X@)WMU<FXZ:&]R9&5]:&%S:"<I+`H@("`@)W1Y
M<&4G(#T^("=S=')I;F<G"BD["@HD7W-E<G9I8V5S6R=B;&]C:W,G72`](&%R
M<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"DL"B`@("`G='EP92<@/3X@)WMU
M<FXZ:&]R9&5]:&%S:"<**3L*"B\J(%5S97(@9&%T82X@*B\*)%]S97)V:6-E
M<ULG9V5T4')E9F5R96YC92==(#T@87)R87DH"B`@("`G87)G<R<@/3X@87)R
M87DH)V%P<"<@/3X@)W-T<FEN9R<L("=P<F5F)R`]/B`G<W1R:6YG)RDL"B`@
M("`G='EP92<@/3X@)W-T<FEN9R<**3L*"B1?<V5R=FEC97-;)W-E=%!R969E
M<F5N8V4G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=A<'`G(#T^
M("=S=')I;F<G+"`G<')E9B<@/3X@)W-T<FEN9R<L("=V86QU92<@/3X@)W-T
M<FEN9R<I+`H@("`@)W1Y<&4G(#T^("=B;V]L96%N)PHI.PH*)%]S97)V:6-E
M<ULG<F5M;W9E57-E<D1A=&$G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R
M<F%Y*"=U<V5R)R`]/B`G<W1R:6YG)RDL"B`@("`G='EP92<@/3X@)V)O;VQE
M86XG"BD["@HO*B!'<F]U<',N("HO"B1?<V5R=FEC97-;)V%D9$=R;W5P)UT@
M/2!A<G)A>2@*("`@("=A<F=S)R`]/B!A<G)A>2@G;F%M92<@/3X@)W-T<FEN
M9R<L("=P87)E;G0G(#T^("=S=')I;F<G*2P*("`@("=T>7!E)R`]/B`G8F]O
M;&5A;B<**3L*"B1?<V5R=FEC97-;)W)E;6]V94=R;W5P)UT@/2!A<G)A>2@*
M("`@("=A<F=S)R`]/B!A<G)A>2@G;F%M92<@/3X@)W-T<FEN9R<I+`H@("`@
M)W1Y<&4G(#T^("=B;V]L96%N)PHI.PH*+R\D7W-E<G9I8V5S6R=G971'<F]U
M<',G73L@/S\_"@HD7W-E<G9I8V5S6R=A9&15<V5R5&]'<F]U<"==(#T@87)R
M87DH"B`@("`G87)G<R<@/3X@87)R87DH)VYA;64G(#T^("=S=')I;F<G+"`G
M=7-E<B<@/3X@)W-T<FEN9R<I+`H@("`@)W1Y<&4G(#T^("=B;V]L96%N)PHI
M.PH*)%]S97)V:6-E<ULG861D57-E<G-4;T=R;W5P)UT@/2!A<G)A>2@*("`@
M("=A<F=S)R`]/B!A<G)A>2@G;F%M92<@/3X@)W-T<FEN9R<L("=U<V5R<R<@
M/3X@)WMU<FXZ:&]R9&5]<W1R:6YG07)R87DG*2P*("`@("=T>7!E)R`]/B`G
M8F]O;&5A;B<**3L*"B1?<V5R=FEC97-;)W)E;6]V955S97)&<F]M1W)O=7`G
M72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=N86UE)R`]/B`G<W1R
M:6YG)RP@)W5S97(G(#T^("=S=')I;F<G*2P*("`@("=T>7!E)R`]/B`G8F]O
M;&5A;B<**3L*"B1?<V5R=FEC97-;)W)E;6]V955S97)S1G)O;4=R;W5P)UT@
M/2!A<G)A>2@*("`@("=A<F=S)R`]/B!A<G)A>2@G;F%M92<@/3X@)W-T<FEN
M9R<L("=U<V5R<R<@/3X@)WMU<FXZ:&]R9&5]<W1R:6YG07)R87DG*2P*("`@
M("=T>7!E)R`]/B`G8F]O;&5A;B<**3L*"B1?<V5R=FEC97-;)VQI<W15<V5R
M<T]F1W)O=7`G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=N86UE
M)R`]/B`G<W1R:6YG)RDL"B`@("`G='EP92<@/3X@)WMU<FXZ:&]R9&5]<W1R
M:6YG07)R87DG"BD["@HO*B!3:&%R97,N("HO"B1?<V5R=FEC97-;)V%D9%-H
M87)E)UT@/2!A<G)A>2@*("`@("=A<F=S)R`]/B!A<G)A>2@G<VAA<F52;V]T
M)R`]/B`G<W1R:6YG)RP@)W-H87)E3F%M92<@/3X@)W-T<FEN9R<L("=S:&%R
M951I=&QE)R`]/B`G<W1R:6YG)RP@)W5S97).86UE)R`]/B`G<W1R:6YG)RDL
M"B`@("`G='EP92<@/3X@)V)O;VQE86XG"BD["@HD7W-E<G9I8V5S6R=R96UO
M=F53:&%R92==(#T@87)R87DH"B`@("`G87)G<R<@/3X@87)R87DH)W-H87)E
M4F]O="<@/3X@)W-T<FEN9R<L("=S:&%R94YA;64G(#T^("=S=')I;F<G*2P*
M("`@("=T>7!E)R`]/B`G8F]O;&5A;B<**3L*"B1?<V5R=FEC97-;)VQI<W13
M:&%R97-/9D]W;F5R)UT@/2!A<G)A>2@*("`@("=A<F=S)R`]/B!A<G)A>2@G
M<VAA<F52;V]T)R`]/B`G<W1R:6YG)RP@)W5S97).86UE)R`]/B`G<W1R:6YG
M)RDL"B`@("`G='EP92<@/3X@)WMU<FXZ:&]R9&5]<W1R:6YG07)R87DG"BD[
M"@HD7W-E<G9I8V5S6R=A9&15<V5R4&5R;6ES<VEO;G,G72`](&%R<F%Y*`H@
M("`@)V%R9W,G(#T^(&%R<F%Y*"=S:&%R95)O;W0G(#T^("=S=')I;F<G+"`G
M<VAA<F5.86UE)R`]/B`G<W1R:6YG)RP@)W5S97).86UE)R`]/B`G<W1R:6YG
M)RP@)W!E<FUI<W-I;VYS)R`]/B`G>W5R;CIH;W)D97US=')I;F=!<G)A>2<I
M+`H@("`@)W1Y<&4G(#T^("=B;V]L96%N)PHI.PH*)%]S97)V:6-E<ULG861D
M1W)O=7!097)M:7-S:6]N<R==(#T@87)R87DH"B`@("`G87)G<R<@/3X@87)R
M87DH)W-H87)E4F]O="<@/3X@)W-T<FEN9R<L("=S:&%R94YA;64G(#T^("=S
M=')I;F<G+"`G9W)O=7!.86UE)R`]/B`G<W1R:6YG)RP@)W!E<FUI<W-I;VYS
M)R`]/B`G>W5R;CIH;W)D97US=')I;F=!<G)A>2<I+`H@("`@)W1Y<&4G(#T^
M("=B;V]L96%N)PHI.PH*)%]S97)V:6-E<ULG<V5T57-E<E!E<FUI<W-I;VYS
M)UT@/2!A<G)A>2@*("`@("=A<F=S)R`]/B!A<G)A>2@G<VAA<F52;V]T)R`]
M/B`G<W1R:6YG)RP@)W-H87)E3F%M92<@/3X@)W-T<FEN9R<L("=U<V5R3F%M
M92<@/3X@)W-T<FEN9R<L("=P97)M:7-S:6]N<R<@/3X@)WMU<FXZ:&]R9&5]
M<W1R:6YG07)R87DG*2P*("`@("=T>7!E)R`]/B`G8F]O;&5A;B<**3L*"B1?
M<V5R=FEC97-;)W-E=$=R;W5P4&5R;6ES<VEO;G,G72`](&%R<F%Y*`H@("`@
M)V%R9W,G(#T^(&%R<F%Y*"=S:&%R95)O;W0G(#T^("=S=')I;F<G+"`G<VAA
M<F5.86UE)R`]/B`G<W1R:6YG)RP@)V=R;W5P3F%M92<@/3X@)W-T<FEN9R<L
M("=P97)M:7-S:6]N<R<@/3X@)WMU<FXZ:&]R9&5]<W1R:6YG07)R87DG*2P*
M("`@("=T>7!E)R`]/B`G8F]O;&5A;B<**3L*"B1?<V5R=FEC97-;)W)E;6]V
M955S97)097)M:7-S:6]N<R==(#T@87)R87DH"B`@("`G87)G<R<@/3X@87)R
M87DH)W-H87)E4F]O="<@/3X@)W-T<FEN9R<L("=S:&%R94YA;64G(#T^("=S
M=')I;F<G+"`G=7-E<DYA;64G(#T^("=S=')I;F<G*2P*("`@("=T>7!E)R`]
M/B`G8F]O;&5A;B<**3L*"B1?<V5R=FEC97-;)W)E;6]V94=R;W5P4&5R;6ES
M<VEO;G,G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=S:&%R95)O
M;W0G(#T^("=S=')I;F<G+"`G<VAA<F5.86UE)R`]/B`G<W1R:6YG)RP@)V=R
M;W5P3F%M92<@/3X@)W-T<FEN9R<I+`H@("`@)W1Y<&4G(#T^("=B;V]L96%N
M)PHI.PH*)%]S97)V:6-E<ULG;&ES=%5S97)097)M:7-S:6]N<R==(#T@87)R
M87DH"B`@("`G87)G<R<@/3X@87)R87DH)W-H87)E4F]O="<@/3X@)W-T<FEN
M9R<L("=S:&%R94YA;64G(#T^("=S=')I;F<G+"`G=7-E<DYA;64G(#T^("=S
M=')I;F<G*2P*("`@("=T>7!E)R`]/B`G>W5R;CIH;W)D97US=')I;F=!<G)A
M>2<**3L*"B1?<V5R=FEC97-;)VQI<W1'<F]U<%!E<FUI<W-I;VYS)UT@/2!A
M<G)A>2@*("`@("=A<F=S)R`]/B!A<G)A>2@G<VAA<F52;V]T)R`]/B`G<W1R
M:6YG)RP@)W-H87)E3F%M92<@/3X@)W-T<FEN9R<L("=G<F]U<$YA;64G(#T^
M("=S=')I;F<G*2P*("`@("=T>7!E)R`]/B`G>W5R;CIH;W)D97US=')I;F=!
M<G)A>2<**3L*"B1?<V5R=FEC97-;)VQI<W15<V5R<T]F4VAA<F4G72`](&%R
M<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=S:&%R95)O;W0G(#T^("=S=')I
M;F<G+"`G<VAA<F5.86UE)R`]/B`G<W1R:6YG)RP@)W!E<FUI<W-I;VYS)R`]
M/B`G>W5R;CIH;W)D97US=')I;F=!<G)A>2<I+`H@("`@)W1Y<&4G(#T^("=[
M=7)N.FAO<F1E?7-T<FEN9T%R<F%Y)PHI.PH*)%]S97)V:6-E<ULG;&ES=$=R
M;W5P<T]F4VAA<F4G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=S
M:&%R95)O;W0G(#T^("=S=')I;F<G+"`G<VAA<F5.86UE)R`]/B`G<W1R:6YG
M)RP@)W!E<FUI<W-I;VYS)R`]/B`G>W5R;CIH;W)D97US=')I;F=!<G)A>2<I
M+`H@("`@)W1Y<&4G(#T^("=[=7)N.FAO<F1E?7-T<FEN9T%R<F%Y)PHI.PH*
M"B\J($QI<W1I;F=S+B`J+PIF=6YC=&EO;B!?:&]R9&5?<&5R;7,H*0I["B`@
M("`D<&5R;7,@/2!A<G)A>2@I.PH*("`@("1P97)M<ULG=')E92==6R=H;W)D
M92==6R=M87A?8FQO8VMS)UT@/2!F86QS93L*("`@("1P97)M<ULG=&ET;&4G
M75LG:&]R9&4Z;6%X7V)L;V-K<R==(#T@7R@B36%X:6UU;2!.=6UB97(@;V8@
M4&]R=&%L($)L;V-K<R(I.PH@("`@)'!E<FUS6R=T>7!E)UU;)VAO<F1E.FUA
M>%]B;&]C:W,G72`]("=I;G0G.PH*("`@(')E='5R;B`D<&5R;7,["GT*"F9U
M;F-T:6]N(%]H;W)D95]A9&UI;E]L:7-T*"D*>PH@("`@<F5T=7)N(&%R<F%Y
M*"=C;VYF:6=U<F%T:6]N)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@
M("`@)VQI;FLG(#T^("<E87!P;&EC871I;VXE+V%D;6EN+W-E='5P+R<L"B`@
M("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B!?*")?4V5T=7`B*2P*("`@
M("`@("`@("`@("`@("`@("`@)VEC;VXG(#T^("=C;VYF:6<N<&YG)RDL"B`@
M("`@("`@("`@("`@("`@)W5S97)S)R`]/B!A<G)A>2@*("`@("`@("`@("`@
M("`@("`@("`@)VQI;FLG(#T^("<E87!P;&EC871I;VXE+V%D;6EN+W5S97(N
M<&AP)RP*("`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^(%\H(E]5<V5R
M<R(I+`H@("`@("`@("`@("`@("`@("`@("`G:6-O;B<@/3X@)W5S97(N<&YG
M)RDL"B`@("`@("`@("`@("`@("`@)V=R;W5P<R<@/3X@87)R87DH"B`@("`@
M("`@("`@("`@("`@("`@("=L:6YK)R`]/B`G)6%P<&QI8V%T:6]N)2]A9&UI
M;B]G<F]U<',N<&AP)RP*("`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^
M(%\H(E]'<F]U<',B*2P*("`@("`@("`@("`@("`@("`@("`@)VEC;VXG(#T^
M("=G<F]U<"YP;F<G*2P*("`@("`@("`@("`@("`@("`G<&5R;7,G(#T^(&%R
M<F%Y*`H@("`@("`@("`@("`@("`@("`@("`G;&EN:R<@/3X@)R5A<'!L:6-A
M=&EO;B4O861M:6XO<&5R;7,O:6YD97@N<&AP)RP*("`@("`@("`@("`@("`@
M("`@("`@)VYA;64G(#T^(%\H(E]097)M:7-S:6]N<R(I+`H@("`@("`@("`@
M("`@("`@("`@("`G:6-O;B<@/3X@)W!E<FUS+G!N9R<I+`H@("`@("`@("`@
M("`@("`@("=D871A=')E92<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@
M("`@("=L:6YK)R`]/B`G)6%P<&QI8V%T:6]N)2]A9&UI;B]D871A=')E92YP
M:'`G+`H@("`@("`@("`@("`@("`@("`@("`G;F%M92<@/3X@7R@B7T1A=&%4
M<F5E(BDL"B`@("`@("`@("`@("`@("`@("`@("=I8V]N)R`]/B`G9&%T871R
M964N<&YG)RDL"B`@("`@("`@("`@("`@("`@)W-E<W-I;VYS)R`]/B!A<G)A
M>2@*("`@("`@("`@("`@("`@("`@("`@)VQI;FLG(#T^("<E87!P;&EC871I
M;VXE+V%D;6EN+W-E<W-I;VYS+G!H<"<L"B`@("`@("`@("`@("`@("`@("`@
M("=N86UE)R`]/B!?*")397-S:6]N<R(I+`H@("`@("`@("`@("`@("`@("`@
M("`G:6-O;B<@/3X@)W5S97(N<&YG)RDL"B`@("`@("`@("`@("`@("`@)W!H
M<'-H96QL)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@)VQI;FLG
M(#T^("<E87!P;&EC871I;VXE+V%D;6EN+W!H<'-H96QL+G!H<"<L"B`@("`@
M("`@("`@("`@("`@("`@("=N86UE)R`]/B!?*")07TA0(%-H96QL(BDL"B`@
M("`@("`@("`@("`@("`@("`@("=I8V]N)R`]/B`G;6EM92]P:'`N<&YG)RDL
M"B`@("`@("`@("`@("`@("`@)W-Q;'-H96QL)R`]/B!A<G)A>2@*("`@("`@
M("`@("`@("`@("`@("`@)VQI;FLG(#T^("<E87!P;&EC871I;VXE+V%D;6EN
M+W-Q;'-H96QL+G!H<"<L"B`@("`@("`@("`@("`@("`@("`@("=N86UE)R`]
M/B!?*")37U%,(%-H96QL(BDL"B`@("`@("`@("`@("`@("`@("`@("=I8V]N
M)R`]/B`G<W%L+G!N9R<I+`H@("`@("`@("`@("`@("`@("=C;61S:&5L;"<@
M/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("=L:6YK)R`]/B`G)6%P
M<&QI8V%T:6]N)2]A9&UI;B]C;61S:&5L;"YP:'`G+`H@("`@("`@("`@("`@
M("`@("`@("`G;F%M92<@/3X@7R@B7T-,22(I+`H@("`@("`@("`@("`@("`@
M("`@("`G:6-O;B<@/3X@)W-H96QL+G!N9R<I+`H@("`@("`@("`@("`@("`@
M("D["GT*"F9U;F-T:6]N(%]H;W)D95]L:7-T07!P<R@D9FEL=&5R(#T@;G5L
M;"D*>PH@("`@<F5T=7)N("1'3$]"04Q36R=R96=I<W1R>2==+3YL:7-T07!P
M<R@D9FEL=&5R*3L*?0H*9G5N8W1I;VX@7VAO<F1E7VQI<W1!4$ES*"D*>PH@
M("`@<F5T=7)N("1'3$]"04Q36R=R96=I<W1R>2==+3YL:7-T05!)<R@I.PI]
M"@HO*B!";&]C:W,N("HO"F9U;F-T:6]N("9?:&]R9&5?8FQO8VLH)&%P<"P@
M)&YA;64L("1P87)A;7,@/2!A<G)A>2@I*0I["B`@("!G;&]B86P@)')E9VES
M=')Y.PH*("`@(')E<75I<F5?;VYC92`G2&]R9&4O0FQO8VLN<&AP)SL*("`@
M(')E<75I<F5?;VYC92`G2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`G.PH*
M("`@("1R97-U;'0@/2`D<F5G:7-T<GDM/G!U<VA!<'`H)&%P<"D["B`@("!I
M9B`H(6ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("1R
M97-U;'0@/2!(;W)D95]";&]C:U]#;VQL96-T:6]N.CIG971";&]C:R@D87!P
M+"`D;F%M92P@)'!A<F%M<RD["B`@("`@("`@)')E9VES=')Y+3YP;W!!<'`H
M)&%P<"D["B`@("!]"B`@("!R971U<FX@)')E<W5L=#L*?0H*9G5N8W1I;VX@
M7VAO<F1E7V)L;V-K5&ET;&4H)&%P<"P@)&YA;64L("1P87)A;7,@/2!A<G)A
M>2@I*0I["B`@("`D8FQO8VL@/2`F7VAO<F1E7V)L;V-K*"1A<'`L("1N86UE
M+"`D<&%R86US*3L*("`@(&EF("AI<U]A*"1B;&]C:RP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@(')E='5R;B`D8FQO8VLM/F=E=$UE<W-A9V4H*3L*("`@
M('T*("`@(')E='5R;B`D8FQO8VLM/F=E=%1I=&QE*"D["GT*"F9U;F-T:6]N
M(%]H;W)D95]B;&]C:T-O;G1E;G0H)&%P<"P@)&YA;64L("1P87)A;7,@/2!A
M<G)A>2@I*0I["B`@("`D8FQO8VL@/2`F7VAO<F1E7V)L;V-K*"1A<'`L("1N
M86UE+"`D<&%R86US*3L*("`@(&EF("AI<U]A*"1B;&]C:RP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@(')E='5R;B`D8FQO8VLM/F=E=$UE<W-A9V4H*3L*
M("`@('T*("`@(')E='5R;B`D8FQO8VLM/F=E=$-O;G1E;G0H*3L*?0H*9G5N
M8W1I;VX@7VAO<F1E7V)L;V-K<R@I"GL*("`@(')E<75I<F5?;VYC92`G2&]R
M9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`G.PH@("`@)&-O;&QE8W1I;VX@/2`F
M2&]R9&5?0FQO8VM?0V]L;&5C=&EO;CHZ<VEN9VQE=&]N*"D["B`@("!I9B`H
M:7-?82@D8V]L;&5C=&EO;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@(')E
M='5R;B`D8V]L;&5C=&EO;CL*("`@('T@96QS92!["B`@("`@("`@<F5T=7)N
M("1C;VQL96-T:6]N+3YG971";&]C:W-,:7-T*"D["B`@("!]"GT*"B\J(%5S
M97(@9&%T82X@*B\*9G5N8W1I;VX@7VAO<F1E7V=E=%!R969E<F5N8V4H)&%P
M<"P@)'!R968I"GL*("`@("1'3$]"04Q36R=R96=I<W1R>2==+3YL;V%D4')E
M9G,H)&%P<"D["B`@("!R971U<FX@)$=,3T)!3%-;)W!R969S)UTM/F=E=%9A
M;'5E*"1P<F5F*3L*?0H*9G5N8W1I;VX@7VAO<F1E7W-E=%!R969E<F5N8V4H
M)&%P<"P@)'!R968L("1V86QU92D*>PH@("`@)$=,3T)!3%-;)W)E9VES=')Y
M)UTM/FQO8610<F5F<R@D87!P*3L*("`@(')E='5R;B`D1TQ/0D%,4ULG<')E
M9G,G72T^<V5T5F%L=64H)'!R968L("1V86QU92D["GT*"F9U;F-T:6]N(%]H
M;W)D95]R96UO=F55<V5R1&%T82@D=7-E<BD*>PH@("`@9VQO8F%L("1C;VYF
M.PH*("`@(')E<75I<F5?;VYC92`G2&]R9&4O4')E9G,N<&AP)SL*("`@("1P
M<F5F<R`]("90<F5F<SHZ<VEN9VQE=&]N*"1C;VYF6R=P<F5F<R==6R=D<FEV
M97(G72P@;G5L;"P@)'5S97(I.PH@("`@:68@*&ES7V$H)')E<W5L="`]("1P
M<F5F<RT^8VQE87(H*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@?0I]"@HO*B!'<F]U<',N("HO"@HO*BH*("H@061D
M<R!A(&=R;W5P('1O('1H92!G<F]U<',@<WES=&5M+@H@*@H@*B!`<&%R86T@
M<W1R:6YG("1N86UE("`@(%1H92!G<F]U<"=S(&YA;64N"B`J($!P87)A;2!S
M=')I;F<@)'!A<F5N="`@5&AE(&=R;W5P)W,@<&%R96YT)W,@;F%M92X*("HO
M"F9U;F-T:6]N(%]H;W)D95]A9&1'<F]U<"@D;F%M92P@)'!A<F5N="`](&YU
M;&PI"GL*("`@(&EF("AE;7!T>2@D<&%R96YT*2D@>PH@("`@("`@("1P87)E
M;G0@/2!$051!5%)%15]23T]4.PH@("`@?0H*("`@(')E<75I<F5?;VYC92`G
M2&]R9&4O1W)O=7`N<&AP)SL*("`@("1G<F]U<',@/2`F1W)O=7`Z.G-I;F=L
M971O;B@I.PH*("`@(&EF("AI<U]A*"1G<F]U<"`]("8D9W)O=7!S+3YN97='
M<F]U<"@D;F%M92P@)'!A<F5N="DL("=014%27T5R<F]R)RDI('L*("`@("`@
M("!R971U<FX@)&=R;W5P.PH@("`@?0H*("`@(')E='5R;B`D9W)O=7!S+3YA
M9&1'<F]U<"@D9W)O=7`I.PI]"@HO*BH*("H@4F5M;W9E<R!A(&=R;W5P(&9R
M;VT@=&AE(&=R;W5P<R!S>7-T96TN"B`J"B`J($!P87)A;2!S=')I;F<@)&YA
M;64@(%1H92!G<F]U<"=S(&YA;64N"B`J+PIF=6YC=&EO;B!?:&]R9&5?<F5M
M;W9E1W)O=7`H)&YA;64I"GL*("`@(')E<75I<F5?;VYC92`G2&]R9&4O1W)O
M=7`N<&AP)SL*("`@("1G<F]U<',@/2`F1W)O=7`Z.G-I;F=L971O;B@I.PH*
M("`@(&EF("AI<U]A*"1G<F]U<"`]("8D9W)O=7!S+3YG971'<F]U<"@D;F%M
M92DL("=014%27T5R<F]R)RDI('L*("`@("`@("!R971U<FX@)&=R;W5P.PH@
M("`@?0H*("`@(')E='5R;B`D9W)O=7!S+3YR96UO=F5'<F]U<"@D9W)O=7`L
M('1R=64I.PI]"@HO*BH*("H@061D<R!A('5S97(@=&\@82!G<F]U<"X*("H*
M("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&=R;W5P)W,@;F%M92X*("H@
M0'!A<F%M('-T<FEN9R`D=7-E<B`@5&AE('5S97(@=&\@861D+@H@*B\*9G5N
M8W1I;VX@7VAO<F1E7V%D9%5S97)4;T=R;W5P*"1N86UE+"`D=7-E<BD*>PH@
M("`@<F5Q=6ER95]O;F-E("=(;W)D92]'<F]U<"YP:'`G.PH@("`@)&=R;W5P
M<R`]("9'<F]U<#HZ<VEN9VQE=&]N*"D["@H@("`@:68@*&ES7V$H)&=R;W5P
M(#T@)B1G<F]U<',M/F=E=$=R;W5P*"1N86UE*2P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@(')E='5R;B`D9W)O=7`["B`@("!]"@H@("`@<F5T=7)N("1G
M<F]U<"T^861D57-E<B@D=7-E<BD["GT*"B\J*@H@*B!!9&1S(&UU;'1I<&QE
M('5S97)S('1O(&$@9W)O=7`N"B`J"B`J($!P87)A;2!S=')I;F<@)&YA;64@
M(%1H92!G<F]U<"=S(&YA;64N"B`J($!P87)A;2!A<G)A>2`D=7-E<G,@(%1H
M92!U<V5R<R!T;R!A9&0N"B`J+PIF=6YC=&EO;B!?:&]R9&5?861D57-E<G-4
M;T=R;W5P*"1N86UE+"`D=7-E<G,I"GL*("`@(')E<75I<F5?;VYC92`G2&]R
M9&4O1W)O=7`N<&AP)SL*("`@("1G<F]U<',@/2`F1W)O=7`Z.G-I;F=L971O
M;B@I.PH*("`@(&EF("AI<U]A*"1G<F]U<"`]("8D9W)O=7!S+3YG971'<F]U
M<"@D;F%M92DL("=014%27T5R<F]R)RDI('L*("`@("`@("!R971U<FX@)&=R
M;W5P.PH@("`@?0H*("`@(&9O<F5A8V@@*"1U<V5R<R!A<R`D=7-E<BD@>PH@
M("`@("`@("1G<F]U<"T^861D57-E<B@D=7-E<BP@9F%L<V4I.PH@("`@?0H*
M("`@(')E='5R;B`D9W)O=7`M/G-A=F4H*3L*?0H*+RHJ"B`J(%)E;6]V97,@
M82!U<V5R(&9R;VT@82!G<F]U<"X*("H*("H@0'!A<F%M('-T<FEN9R`D;F%M
M92`@5&AE(&=R;W5P)W,@;F%M92X*("H@0'!A<F%M('-T<FEN9R`D=7-E<B`@
M5&AE('5S97(@=&\@861D+@H@*B\*9G5N8W1I;VX@7VAO<F1E7W)E;6]V955S
M97)&<F]M1W)O=7`H)&YA;64L("1U<V5R*0I["B`@("!R97%U:7)E7V]N8V4@
M)TAO<F1E+T=R;W5P+G!H<"<["B`@("`D9W)O=7!S(#T@)D=R;W5P.CIS:6YG
M;&5T;VXH*3L*"B`@("!I9B`H:7-?82@D9W)O=7`@/2`F)&=R;W5P<RT^9V5T
M1W)O=7`H)&YA;64I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@<F5T=7)N
M("1G<F]U<#L*("`@('T*"B`@("!R971U<FX@)&=R;W5P+3YR96UO=F55<V5R
M*"1U<V5R*3L*?0H*+RHJ"B`J(%)E;6]V97,@;75L=&EP;&4@=7-E<G,@9G)O
M;2!A(&=R;W5P+@H@*@H@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@9W)O
M=7`G<R!N86UE+@H@*B!`<&%R86T@87)R87D@)'5S97)S("!4:&4@=7-E<G,@
M=&\@861D+@H@*B\*9G5N8W1I;VX@7VAO<F1E7W)E;6]V955S97)S1G)O;4=R
M;W5P*"1N86UE+"`D=7-E<G,I"GL*("`@(')E<75I<F5?;VYC92`G2&]R9&4O
M1W)O=7`N<&AP)SL*("`@("1G<F]U<',@/2`F1W)O=7`Z.G-I;F=L971O;B@I
M.PH*("`@(&EF("AI<U]A*"1G<F]U<"`]("8D9W)O=7!S+3YG971'<F]U<"@D
M;F%M92DL("=014%27T5R<F]R)RDI('L*("`@("`@("!R971U<FX@)&=R;W5P
M.PH@("`@?0H*("`@(&9O<F5A8V@@*"1U<V5R<R!A<R`D=7-E<BD@>PH@("`@
M("`@("1G<F]U<"T^<F5M;W9E57-E<B@D=7-E<BP@9F%L<V4I.PH@("`@?0H*
M("`@(')E='5R;B`D9W)O=7`M/G-A=F4H*3L*?0H*+RHJ"B`J(%)E='5R;G,@
M82!L:7-T(&]F('5S97)S('1H870@87)E('!A<G0@;V8@=&AI<R!G<F]U<"`H
M86YD(&]N;'D@=&AI<R!G<F]U<"D*("H*("H@0')E='5R;B!A<G)A>2`@5&AE
M('5S97(@;&ES="X*("HO"F9U;F-T:6]N(%]H;W)D95]L:7-T57-E<G-/9D=R
M;W5P*"1N86UE*0I["B`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T=R;W5P+G!H
M<"<["B`@("`D9W)O=7!S(#T@)D=R;W5P.CIS:6YG;&5T;VXH*3L*"B`@("!I
M9B`H:7-?82@D9W)O=7`@/2`F)&=R;W5P<RT^9V5T1W)O=7`H)&YA;64I+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@<F5T=7)N("1G<F]U<#L*("`@('T*
M"B`@("!R971U<FX@)&=R;W5P+3YL:7-T57-E<G,H*3L*?0H*+RH@4VAA<F5S
M+B`J+PH*+RHJ"B`J($%D9',@82!S:&%R92!T;R!T:&4@<VAA<F5S('-Y<W1E
M;2X*("H*("H@0'!A<F%M('-T<FEN9R`D<VAA<F52;V]T("`@5&AE(&YA;64@
M;V8@=&AE('-H87)E(')O;W0L(&4N9RX@=&AE"B`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%P<&QI8V%T:6]N('1H870@=&AE('-H87)E(&)E;&]N
M9W,@=&\N"B`J($!P87)A;2!S=')I;F<@)'-H87)E3F%M92`@(%1H92!S:&%R
M92=S(&YA;64N"B`J($!P87)A;2!S=')I;F<@)'-H87)E5&ET;&4@(%1H92!S
M:&%R92=S(&AU;6%N(')E861A8FQE('1I=&QE+@H@*B!`<&%R86T@<W1R:6YG
M("1U<V5R3F%M92`@("!4:&4@<VAA<F4G<R!O=VYE<BX*("HO"F9U;F-T:6]N
M(%]H;W)D95]A9&13:&%R92@D<VAA<F52;V]T+"`D<VAA<F5.86UE+"`D<VAA
M<F54:71L92P@)'5S97).86UE*0I["B`@("!R97%U:7)E7V]N8V4@)TAO<F1E
M+U-H87)E+G!H<"<["B`@("`D<VAA<F5S(#T@)DAO<F1E7U-H87)E.CIS:6YG
M;&5T;VXH)'-H87)E4F]O="D["@H@("`@:68@*&ES7V$H)'-H87)E(#T@)B1S
M:&%R97,M/FYE=U-H87)E*"1S:&%R94YA;64I+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@<F5T=7)N("1S:&%R93L*("`@('T*("`@("1S:&%R92T^<V5T
M*"=O=VYE<B<L("1U<V5R3F%M92D["B`@("`D<VAA<F4M/G-E="@G;F%M92<L
M("1S:&%R951I=&QE*3L*"B`@("!R971U<FX@)'-H87)E<RT^861D4VAA<F4H
M)'-H87)E*3L*?0H*+RHJ"B`J(%)E;6]V97,@82!S:&%R92!F<F]M('1H92!S
M:&%R97,@<WES=&5M('!E<FUA;F5N=&QY+@H@*@H@*B!`<&%R86T@<W1R:6YG
M("1S:&%R95)O;W0@(%1H92!N86UE(&]F('1H92!S:&%R92!R;V]T+"!E+F<N
M('1H90H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&%P<&QI8V%T:6]N
M('1H870@=&AE('-H87)E(&)E;&]N9W,@=&\N"B`J($!P87)A;2!S=')I;F<@
M)'-H87)E3F%M92`@5&AE('-H87)E)W,@;F%M92X*("HO"F9U;F-T:6]N(%]H
M;W)D95]R96UO=F53:&%R92@D<VAA<F52;V]T+"`D<VAA<F5.86UE*0I["B`@
M("!R97%U:7)E7V]N8V4@)TAO<F1E+U-H87)E+G!H<"<["B`@("`D<VAA<F5S
M(#T@)DAO<F1E7U-H87)E.CIS:6YG;&5T;VXH)'-H87)E4F]O="D["@H@("`@
M:68@*&ES7V$H)'-H87)E(#T@)B1S:&%R97,M/F=E=%-H87)E*"1S:&%R94YA
M;64I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@<F5T=7)N("1S:&%R93L*
M("`@('T*"B`@("!R971U<FX@)'-H87)E<RT^<F5M;W9E4VAA<F4H)'-H87)E
M*3L*?0H*+RHJ"B`J(%)E='5R;G,@86X@87)R87D@;V8@86QL('-H87)E<R!T
M:&%T("1U<V5R3F%M92!I<R!T:&4@;W=N97(@;V8N"B`J"B`J($!P87)A;2!S
M=')I;F<@)'-H87)E4F]O="`@5&AE(&YA;64@;V8@=&AE('-H87)E(')O;W0L
M(&4N9RX@=&AE"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@87!P;&EC
M871I;VX@=&AA="!T:&4@<VAA<F4@8F5L;VYG<R!T;RX*("H@0'!A<F%M('-T
M<FEN9R`D=7-E<DYA;64@("!4:&4@<VAA<F4G<R!O=VYE<BX*("H*("H@0')E
M='5R;B!A<G)A>2`@5&AE(&QI<W0@;V8@<VAA<F5S+@H@*B\*9G5N8W1I;VX@
M7VAO<F1E7VQI<W13:&%R97-/9D]W;F5R*"1S:&%R95)O;W0L("1U<V5R3F%M
M92D*>PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92]3:&%R92YP:'`G.PH@("`@
M)'-H87)E<R`]("9(;W)D95]3:&%R93HZ<VEN9VQE=&]N*"1S:&%R95)O;W0I
M.PH*("`@("1S:&%R95]L:7-T(#T@)B1S:&%R97,M/FQI<W13:&%R97,H)'5S
M97).86UE+"!015)-4U]32$]7+"`D=7-E<DYA;64I.PH@("`@)&UY<VAA<F5S
M(#T@87)R87DH*3L*("`@(&9O<F5A8V@@*"1S:&%R95]L:7-T(&%S("1S:&%R
M92D@>PH@("`@("`@("1M>7-H87)E<UM=(#T@)'-H87)E+3YG971.86UE*"D[
M"B`@("!]"@H@("`@<F5T=7)N("1M>7-H87)E<SL*?0H*+RHJ"B`J($=I=F5S
M(&$@=7-E<B!C97)T86EN('!R:79I;&5G97,@9F]R(&$@<VAA<F4N"B`J"B`J
M($!P87)A;2!S=')I;F<@)'-H87)E4F]O="`@(%1H92!N86UE(&]F('1H92!S
M:&%R92!R;V]T+"!E+F<N('1H90H@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<'!L:6-A=&EO;B!T:&%T('1H92!S:&%R92!B96QO;F=S('1O+@H@
M*B!`<&%R86T@<W1R:6YG("1S:&%R94YA;64@("!4:&4@<VAA<F4G<R!N86UE
M+@H@*B!`<&%R86T@<W1R:6YG("1U<V5R3F%M92`@("!4:&4@=7-E<B=S(&YA
M;64N"B`J($!P87)A;2!A<G)A>2`D<&5R;6ES<VEO;G,@($$@;&ES="!O9B!P
M97)M:7-S:6]N<R`H<VAO=RP@<F5A9"P@961I="P@9&5L971E*2X*("HO"F9U
M;F-T:6]N(%]H;W)D95]A9&15<V5R4&5R;6ES<VEO;G,H)'-H87)E4F]O="P@
M)'-H87)E3F%M92P@)'5S97).86UE+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1P97)M:7-S:6]N<RD*>PH@("`@<F5Q=6ER95]O;F-E
M("=(;W)D92]3:&%R92YP:'`G.PH@("`@)'-H87)E<R`]("9(;W)D95]3:&%R
M93HZ<VEN9VQE=&]N*"1S:&%R95)O;W0I.PH*("`@(&EF("AI<U]A*"1S:&%R
M92`]("8D<VAA<F5S+3YG9713:&%R92@D<VAA<F5.86UE*2P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@(')E='5R;B`D<VAA<F4["B`@("!]"@H@("`@)'!E
M<FT@/2`F)'-H87)E+3YG971097)M:7-S:6]N*"D["B`@("!F;W)E86-H("@D
M<&5R;6ES<VEO;G,@87,@)'!E<FUI<W-I;VXI('L*("`@("`@("`D<&5R;6ES
M<VEO;B`](%-T<FEN9SHZ=7!P97(H)'!E<FUI<W-I;VXI.PH@("`@("`@(&EF
M("AD969I;F5D*"=015)-4U\G("X@)'!E<FUI<W-I;VXI*2!["B`@("`@("`@
M("`@("1P97)M+3YA9&15<V5R4&5R;6ES<VEO;B@D=7-E<DYA;64L(&-O;G-T
M86YT*"=015)-4U\G("X@)'!E<FUI<W-I;VXI+"!F86QS92D["B`@("`@("`@
M?0H@("`@?0H@("`@<F5T=7)N("1S:&%R92T^<V5T4&5R;6ES<VEO;B@D<&5R
M;2D["GT*"B\J*@H@*B!':79E<R!A(&=R;W5P(&-E<G1A:6X@<')I=FEL96=E
M<R!F;W(@82!S:&%R92X*("H*("H@0'!A<F%M('-T<FEN9R`D<VAA<F52;V]T
M("`@5&AE(&YA;64@;V8@=&AE('-H87)E(')O;W0L(&4N9RX@=&AE"B`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%P<&QI8V%T:6]N('1H870@=&AE
M('-H87)E(&)E;&]N9W,@=&\N"B`J($!P87)A;2!S=')I;F<@)'-H87)E3F%M
M92`@(%1H92!S:&%R92=S(&YA;64N"B`J($!P87)A;2!S=')I;F<@)&=R;W5P
M3F%M92`@(%1H92!G<F]U<"=S(&YA;64N"B`J($!P87)A;2!A<G)A>2`D<&5R
M;6ES<VEO;G,@($$@;&ES="!O9B!P97)M:7-S:6]N<R`H<VAO=RP@<F5A9"P@
M961I="P@9&5L971E*2X*("HO"F9U;F-T:6]N(%]H;W)D95]A9&1'<F]U<%!E
M<FUI<W-I;VYS*"1S:&%R95)O;W0L("1S:&%R94YA;64L("1G<F]U<$YA;64L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P97)M:7-S
M:6]N<RD*>PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92]3:&%R92YP:'`G.PH@
M("`@<F5Q=6ER95]O;F-E("=(;W)D92]'<F]U<"YP:'`G.PH@("`@)'-H87)E
M<R`]("9(;W)D95]3:&%R93HZ<VEN9VQE=&]N*"1S:&%R95)O;W0I.PH@("`@
M)&=R;W5P<R`]("9'<F]U<#HZ<VEN9VQE=&]N*"D["@H@("`@:68@*&ES7V$H
M)'-H87)E(#T@)B1S:&%R97,M/F=E=%-H87)E*"1S:&%R94YA;64I+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@<F5T=7)N("1S:&%R93L*("`@('T*("`@
M(&EF("AI<U]A*"1G<F]U<$ED(#T@)&=R;W5P<RT^9V5T1W)O=7!)9"@D9W)O
M=7!.86UE*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@(')E='5R;B`D9W)O
M=7!)9#L*("`@('T*"B`@("`D<&5R;2`]("8D<VAA<F4M/F=E=%!E<FUI<W-I
M;VXH*3L*("`@(&9O<F5A8V@@*"1P97)M:7-S:6]N<R!A<R`D<&5R;6ES<VEO
M;BD@>PH@("`@("`@("1P97)M:7-S:6]N(#T@4W1R:6YG.CIU<'!E<B@D<&5R
M;6ES<VEO;BD["B`@("`@("`@:68@*&1E9FEN960H)U!%4DU37R<@+B`D<&5R
M;6ES<VEO;BDI('L*("`@("`@("`@("`@)'!E<FTM/F%D9$=R;W5P4&5R;6ES
M<VEO;B@D9W)O=7!)9"P@8V]N<W1A;G0H)U!%4DU37R<@+B`D<&5R;6ES<VEO
M;BDL(&9A;'-E*3L*("`@("`@("!]"B`@("!]"B`@("!R971U<FX@)'-H87)E
M+3YS971097)M:7-S:6]N*"1P97)M*3L*?0H*9G5N8W1I;VX@7VAO<F1E7W-E
M=%5S97)097)M:7-S:6]N<R@D<VAA<F52;V]T+"`D<VAA<F5.86UE+"`D=7-E
M<DYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!E
M<FUI<W-I;VYS*0I["GT*"F9U;F-T:6]N(%]H;W)D95]S971'<F]U<%!E<FUI
M<W-I;VYS*"1S:&%R95)O;W0L("1S:&%R94YA;64L("1G<F]U<$YA;64L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P97)M:7-S:6]N
M<RD*>PI]"@HO*BH*("H@4F5M;W9E<R!A('5S97(@9G)O;2!A('-H87)E+@H@
M*@H@*B!`<&%R86T@<W1R:6YG("1S:&%R95)O;W0@("!4:&4@;F%M92!O9B!T
M:&4@<VAA<F4@<F]O="P@92YG+B!T:&4*("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@87!P;&EC871I;VX@=&AA="!T:&4@<VAA<F4@8F5L;VYG<R!T
M;RX*("H@0'!A<F%M('-T<FEN9R`D<VAA<F5.86UE("`@5&AE('-H87)E)W,@
M;F%M92X*("H@0'!A<F%M('-T<FEN9R`D=7-E<DYA;64@("`@5&AE('5S97(G
M<R!N86UE+@H@*B\*9G5N8W1I;VX@7VAO<F1E7W)E;6]V955S97)097)M:7-S
M:6]N<R@D<VAA<F52;V]T+"`D<VAA<F5.86UE+"`D=7-E<DYA;64I"GL*("`@
M(')E<75I<F5?;VYC92`G2&]R9&4O4VAA<F4N<&AP)SL*("`@("1S:&%R97,@
M/2`F2&]R9&5?4VAA<F4Z.G-I;F=L971O;B@D<VAA<F52;V]T*3L*"B`@("!I
M9B`H:7-?82@D<VAA<F4@/2`F)'-H87)E<RT^9V5T4VAA<F4H)'-H87)E3F%M
M92DL("=014%27T5R<F]R)RDI('L*("`@("`@("!R971U<FX@)'-H87)E.PH@
M("`@?0H*("`@(')E='5R;B`D<VAA<F4M/G)E;6]V955S97(H)'5S97).86UE
M*3L*?0H*+RHJ"B`J(%)E;6]V97,@82!G<F]U<"!F<F]M(&$@<VAA<F4N"B`J
M"B`J($!P87)A;2!S=')I;F<@)'-H87)E4F]O="`@(%1H92!N86UE(&]F('1H
M92!S:&%R92!R;V]T+"!E+F<N('1H90H@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A<'!L:6-A=&EO;B!T:&%T('1H92!S:&%R92!B96QO;F=S('1O
M+@H@*B!`<&%R86T@<W1R:6YG("1S:&%R94YA;64@("!4:&4@<VAA<F4G<R!N
M86UE+@H@*B!`<&%R86T@<W1R:6YG("1G<F]U<$YA;64@("!4:&4@9W)O=7`G
M<R!N86UE+@H@*B\*9G5N8W1I;VX@7VAO<F1E7W)E;6]V94=R;W5P4&5R;6ES
M<VEO;G,H)'-H87)E4F]O="P@)'-H87)E3F%M92P@)&=R;W5P3F%M92D*>PH@
M("`@<F5Q=6ER95]O;F-E("=(;W)D92]3:&%R92YP:'`G.PH@("`@<F5Q=6ER
M95]O;F-E("=(;W)D92]'<F]U<"YP:'`G.PH@("`@)'-H87)E<R`]("9(;W)D
M95]3:&%R93HZ<VEN9VQE=&]N*"1S:&%R95)O;W0I.PH@("`@)&=R;W5P<R`]
M("9'<F]U<#HZ<VEN9VQE=&]N*"D["@H@("`@:68@*&ES7V$H)'-H87)E(#T@
M)B1S:&%R97,M/F=E=%-H87)E*"1S:&%R94YA;64I+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@<F5T=7)N("1S:&%R93L*("`@('T*("`@(&EF("AI<U]A
M*"1G<F]U<$ED(#T@)&=R;W5P<RT^9V5T1W)O=7!)9"@D9W)O=7!.86UE*2P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@(')E='5R;B`D9W)O=7!)9#L*("`@
M('T*"B`@("!R971U<FX@)'-H87)E+3YR96UO=F5'<F]U<"@D9W)O=7!)9"D[
M"GT*"B\J*@H@*B!2971U<FYS(&%N(&%R<F%Y(&]F(&%L;"!U<V5R('!E<FUI
M<W-I;VYS(&]N(&$@<VAA<F4N"B`J"B`J($!P87)A;2!S=')I;F<@)'-H87)E
M4F]O="`@(%1H92!N86UE(&]F('1H92!S:&%R92!R;V]T+"!E+F<N('1H90H@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<'!L:6-A=&EO;B!T:&%T
M('1H92!S:&%R92!B96QO;F=S('1O+@H@*B!`<&%R86T@<W1R:6YG("1S:&%R
M94YA;64@("!4:&4@<VAA<F4G<R!N86UE+@H@*B!`<&%R86T@<W1R:6YG("1U
M<V5R3F%M92`@("!4:&4@=7-E<B=S(&YA;64N"B`J"B`J($!R971U<FX@87)R
M87D@($%L;"!U<V5R('!E<FUI<W-I;VYS(&9O<B!T:&ES('-H87)E+@H@*B\*
M9G5N8W1I;VX@7VAO<F1E7VQI<W15<V5R4&5R;6ES<VEO;G,H)'-H87)E4F]O
M="P@)'-H87)E3F%M92P@)'5S97).86UE*0I["B`@("`D<&5R;5]M87`@/2!A
M<G)A>2A015)-4U]32$]7(#T^("=S:&]W)RP*("`@("`@("`@("`@("`@("`@
M("`@(%!%4DU37U)%040@/3X@)W)E860G+`H@("`@("`@("`@("`@("`@("`@
M("`@4$5235-?141)5"`]/B`G961I="<L"B`@("`@("`@("`@("`@("`@("`@
M("!015)-4U]$14Q%5$4@/3X@)V1E;&5T92<I.PH*("`@(')E<75I<F5?;VYC
M92`G2&]R9&4O4VAA<F4N<&AP)SL*("`@("1S:&%R97,@/2`F2&]R9&5?4VAA
M<F4Z.G-I;F=L971O;B@D<VAA<F52;V]T*3L*"B`@("!I9B`H:7-?82@D<VAA
M<F4@/2`F)'-H87)E<RT^9V5T4VAA<F4H)'-H87)E3F%M92DL("=014%27T5R
M<F]R)RDI('L*("`@("`@("!R971U<FX@)'-H87)E.PH@("`@?0H*("`@("1P
M97)M(#T@)B1S:&%R92T^9V5T4&5R;6ES<VEO;B@I.PH@("`@)'!E<FUI<W-I
M;VYS(#T@)'!E<FTM/F=E=%5S97)097)M:7-S:6]N<R@I.PH@("`@:68@*&5M
M<'1Y*"1P97)M:7-S:6]N<ULD=7-E<DYA;65=*2D@>PH@("`@("`@(')E='5R
M;B!A<G)A>2@I.PH@("`@?0H*("`@("1U<V5R7W!E<FUI<W-I;VYS(#T@87)R
M87DH*3L*("`@(&9O<F5A8V@@*&%R<F%Y7VME>7,H4&5R;7,Z.FEN=&5G97)4
M;T%R<F%Y*"1P97)M:7-S:6]N<ULD=7-E<DYA;65=*2D@87,@)'!E<FUI<W-I
M;VXI('L*("`@("`@("`D=7-E<E]P97)M:7-S:6]N<UM=(#T@)'!E<FU?;6%P
M6R1P97)M:7-S:6]N73L*("`@('T*"B`@("!R971U<FX@)'5S97)?<&5R;6ES
M<VEO;G,["GT*"B\J*@H@*B!2971U<FYS(&%N(&%R<F%Y(&]F(&%L;"!G<F]U
M<"!P97)M:7-S:6]N<R!O;B!A('-H87)E+@H@*@H@*B!`<&%R86T@<W1R:6YG
M("1S:&%R95)O;W0@("!4:&4@;F%M92!O9B!T:&4@<VAA<F4@<F]O="P@92YG
M+B!T:&4*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@87!P;&EC871I
M;VX@=&AA="!T:&4@<VAA<F4@8F5L;VYG<R!T;RX*("H@0'!A<F%M('-T<FEN
M9R`D<VAA<F5.86UE("`@5&AE('-H87)E)W,@;F%M92X*("H@0'!A<F%M('-T
M<FEN9R`D9W)O=7!.86UE("`@5&AE(&=R;W5P)W,@;F%M92X*("H*("H@0')E
M='5R;B!A<G)A>2`@06QL(&=R;W5P('!E<FUI<W-I;VYS(&9O<B!T:&ES('-H
M87)E+@H@*B\*9G5N8W1I;VX@7VAO<F1E7VQI<W1'<F]U<%!E<FUI<W-I;VYS
M*"1S:&%R95)O;W0L("1S:&%R94YA;64L("1G<F]U<$YA;64I"GL*("`@("1P
M97)M7VUA<"`](&%R<F%Y*%!%4DU37U-(3U<@/3X@)W-H;W<G+`H@("`@("`@
M("`@("`@("`@("`@("`@4$5235-?4D5!1"`]/B`G<F5A9"<L"B`@("`@("`@
M("`@("`@("`@("`@("!015)-4U]%1$E4(#T^("=E9&ET)RP*("`@("`@("`@
M("`@("`@("`@("`@(%!%4DU37T1%3$5412`]/B`G9&5L971E)RD["@H@("`@
M<F5Q=6ER95]O;F-E("=(;W)D92]3:&%R92YP:'`G.PH@("`@)'-H87)E<R`]
M("9(;W)D95]3:&%R93HZ<VEN9VQE=&]N*"1S:&%R95)O;W0I.PH*("`@(&EF
M("AI<U]A*"1S:&%R92`]("8D<VAA<F5S+3YG9713:&%R92@D<VAA<F5.86UE
M*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@(')E='5R;B`D<VAA<F4["B`@
M("!]"@H@("`@)'!E<FT@/2`F)'-H87)E+3YG971097)M:7-S:6]N*"D["B`@
M("`D<&5R;6ES<VEO;G,@/2`D<&5R;2T^9V5T1W)O=7!097)M:7-S:6]N<R@I
M.PH@("`@:68@*&5M<'1Y*"1P97)M:7-S:6]N<ULD9W)O=7!.86UE72DI('L*
M("`@("`@("!R971U<FX@87)R87DH*3L*("`@('T*"B`@("`D9W)O=7!?<&5R
M;6ES<VEO;G,@/2!A<G)A>2@I.PH@("`@9F]R96%C:"`H87)R87E?:V5Y<RA0
M97)M<SHZ:6YT96=E<E1O07)R87DH)'!E<FUI<W-I;VYS6R1G<F]U<$YA;65=
M*2D@87,@)'!E<FUI<W-I;VXI('L*("`@("`@("`D9W)O=7!?<&5R;6ES<VEO
M;G-;72`]("1P97)M7VUA<%LD<&5R;6ES<VEO;ET["B`@("!]"@H@("`@<F5T
M=7)N("1G<F]U<%]P97)M:7-S:6]N<SL*?0H*+RHJ"B`J(%)E='5R;G,@82!L
M:7-T(&]F('5S97)S('=H:6-H(&AA=F4@:&%V92!C97)T86EN('!E<FUI<W-I
M;VYS(&]N(&$@<VAA<F4N"B`J"B`J($!P87)A;2!S=')I;F<@)'-H87)E4F]O
M="`@(%1H92!N86UE(&]F('1H92!S:&%R92!R;V]T+"!E+F<N('1H90H@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<'!L:6-A=&EO;B!T:&%T('1H
M92!S:&%R92!B96QO;F=S('1O+@H@*B!`<&%R86T@<W1R:6YG("1S:&%R94YA
M;64@("!4:&4@<VAA<F4G<R!N86UE+@H@*B!`<&%R86T@87)R87D@)'!E<FUI
M<W-I;VYS("!!(&QI<W0@;V8@<&5R;6ES<VEO;G,@*'-H;W<L(')E860L(&5D
M:70L(&1E;&5T92DN"B`J"B`J($!R971U<FX@87)R87D@($QI<W0@;V8@=7-E
M<G,@=VET:"!T:&4@<W!E8VEF:65D('!E<FUI<W-I;VYS+@H@*B\*9G5N8W1I
M;VX@7VAO<F1E7VQI<W15<V5R<T]F4VAA<F4H)'-H87)E4F]O="P@)'-H87)E
M3F%M92P@)'!E<FUI<W-I;VYS*0I["B`@("!R97%U:7)E7V]N8V4@)TAO<F1E
M+U-H87)E+G!H<"<["B`@("`D<VAA<F5S(#T@)DAO<F1E7U-H87)E.CIS:6YG
M;&5T;VXH)'-H87)E4F]O="D["@H@("`@:68@*&ES7V$H)'-H87)E(#T@)B1S
M:&%R97,M/F=E=%-H87)E*"1S:&%R94YA;64I+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@<F5T=7)N("1S:&%R93L*("`@('T*"B`@("`D<&5R;2`](#`[
M"B`@("!F;W)E86-H("@D<&5R;6ES<VEO;G,@87,@)'!E<FUI<W-I;VXI('L*
M("`@("`@("`D<&5R;6ES<VEO;B`](%-T<FEN9SHZ=7!P97(H)'!E<FUI<W-I
M;VXI.PH@("`@("`@(&EF("AD969I;F5D*"=015)-4U\G("X@)'!E<FUI<W-I
M;VXI*2!["B`@("`@("`@("`@("1P97)M("8](&-O;G-T86YT*"=015)-4U\G
M("X@)'!E<FUI<W-I;VXI.PH@("`@("`@('T*("`@('T*"B`@("!R971U<FX@
M)'-H87)E+3YL:7-T57-E<G,H)'!E<FTI.PI]"@HO*BH*("H@4F5T=7)N<R!A
M(&QI<W0@;V8@9W)O=7!S('=H:6-H(&AA=F4@:&%V92!C97)T86EN('!E<FUI
M<W-I;VYS(&]N(&$@<VAA<F4N"B`J"B`J($!P87)A;2!S=')I;F<@)'-H87)E
M4F]O="`@(%1H92!N86UE(&]F('1H92!S:&%R92!R;V]T+"!E+F<N('1H90H@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<'!L:6-A=&EO;B!T:&%T
M('1H92!S:&%R92!B96QO;F=S('1O+@H@*B!`<&%R86T@<W1R:6YG("1S:&%R
M94YA;64@("!4:&4@<VAA<F4G<R!N86UE+@H@*B!`<&%R86T@87)R87D@)'!E
M<FUI<W-I;VYS("!!(&QI<W0@;V8@<&5R;6ES<VEO;G,@*'-H;W<L(')E860L
M(&5D:70L(&1E;&5T92DN"B`J"B`J($!R971U<FX@87)R87D@($QI<W0@;V8@
M9W)O=7!S('=I=&@@=&AE('-P96-I9FEE9"!P97)M:7-S:6]N<RX*("HO"F9U
M;F-T:6]N(%]H;W)D95]L:7-T1W)O=7!S3V93:&%R92@D<VAA<F52;V]T+"`D
M<VAA<F5.86UE+"`D<&5R;6ES<VEO;G,I"GL*("`@(')E<75I<F5?;VYC92`G
M2&]R9&4O4VAA<F4N<&AP)SL*("`@("1S:&%R97,@/2`F2&]R9&5?4VAA<F4Z
M.G-I;F=L971O;B@D<VAA<F52;V]T*3L*"B`@("!I9B`H:7-?82@D<VAA<F4@
M/2`F)'-H87)E<RT^9V5T4VAA<F4H)'-H87)E3F%M92DL("=014%27T5R<F]R
M)RDI('L*("`@("`@("!R971U<FX@)'-H87)E.PH@("`@?0H*("`@("1P97)M
M(#T@,#L*("`@(&9O<F5A8V@@*"1P97)M:7-S:6]N<R!A<R`D<&5R;6ES<VEO
M;BD@>PH@("`@("`@("1P97)M:7-S:6]N(#T@4W1R:6YG.CIU<'!E<B@D<&5R
M;6ES<VEO;BD["B`@("`@("`@:68@*&1E9FEN960H)U!%4DU37R<@+B`D<&5R
M;6ES<VEO;BDI('L*("`@("`@("`@("`@)'!E<FT@)CT@8V]N<W1A;G0H)U!%
M4DU37R<@+B`D<&5R;6ES<VEO;BD["B`@("`@("`@?0H@("`@?0H*("`@(')E
M='5R;B`D<VAA<F4M/FQI<W1'<F]U<',H)'!E<FTI.PI]"@```'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQO8V%L90``````````````````````````````
M````````````````````````````````````````````````````````````
M```P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S
M,S<T,B`P,38W,3<`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VMM7TM(
M````````````````````````````````````````````````````````````
M`````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,#`P(#$P-3$U-#,S-S0P(#`Q-S<P-@`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L;V-A;&4O:VU?2T@O3$-?34534T%'15,`````````````````````
M````````````````````````````````````````````````,#`P-S4U(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W-#`@,#(Q-#<S
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]K;5]+2"],0U]-15-304=%
M4R]H;W)D92YM;P``````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#$Q,3<U,R`Q
M,#4Q-30S,S<T,"`P,C,R,C``(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````WA($E0````!$`@``'````#P2```%`P``7"0`````
M``!P,```#@```'$P```/````@#````@```"0,```"P```)DP```,````I3``
M`!@```"R,```&P```,LP```,````YS````4```#T,```!0```/HP```&````
M`#$```P````',0``#@```!0Q```.````(S$```@````R,0``"0```#LQ```(
M````13$``!,```!.,0```P```&(Q```(````9C$```<```!O,0``#````'<Q
M```.````A#$```L```"3,0``!P```)\Q```'````IS$```4```"O,0``!0``
M`+4Q```#````NS$``!<```"_,0``#@```-<Q```'````YC$```8```#N,0``
M"````/4Q```*````_C$``!,````),@``"P```!TR```%````*3(``!4````O
M,@``"0```$4R```'````3S(```4```!7,@``"@```%TR```&````:#(```D`
M``!O,@``!P```'DR```5````@3(```H```"7,@``"@```*(R```0````K3(`
M``<```"^,@``!P```,8R```*````SC(```@```#9,@``!P```.(R```'````
MZC(```8```#R,@``!0```/DR```'````_S(```8````',P``"`````XS```$
M````%S,```<````<,P``"0```"0S```&````+C,```<````U,P``%@```#TS
M```$````5#,```@```!9,P``!@```&(S```-````:3,```8```!W,P``'@``
M`'XS```1````G3,```@```"O,P``#````+@S```'````Q3,```,```#-,P``
M"````-$S```(````VC,```@```#C,P``!@```.PS```&````\S,```H```#Z
M,P``!P````4T```'````#30```X````5-```!@```"0T```8````*S0```0`
M``!$-```!@```$DT```%````4#0```4```!6-```$````%PT```%````;30`
M``L```!S-```#````'\T```7````C#0```@```"D-```!0```*TT```'````
MLS0```<```"[-```"P```,,T```'````SS0```<```#7-```"0```-\T```)
M````Z30```H```#S-```%0```/XT```9````%#4```4````N-0``$@```#0U
M```(````1S4```@```!0-0``#````%DU```$````9C4```H```!K-0``!P``
M`'8U```&````?C4```<```"%-0``!````(TU```,````DC4```T```"?-0``
M*````*TU```#````UC4```8```#:-0``$0```.$U```7````\S4```X````+
M-@```@```!HV```%````'38```0````C-@```P```"@V```(````+#8```\`
M```U-@``!P```$4V```&````338```T```!4-@``"@```&(V```'````;38`
M``L```!U-@``"P```($V```)````C38```@```"7-@``"````*`V```2````
MJ38``!\```"\-@``"````-PV```,````Y38```8```#R-@``!P```/DV```$
M`````3<```D````&-P``!0```!`W```+````%C<```4````B-P``#0```"@W
M```;````-C<```D```!2-P``$0```%PW```'````;C<```4```!V-P``!P``
M`'PW```(````A#<```8```"--P``$````)0W```0````I3<```\```"V-P``
M#P```,8W```,````UC<```<```#C-P``!@```.LW```(````\C<``!L```#[
M-P``#0```!<X```#````)3@```@````I.```!````#(X```$````-S@```D`
M```\.```!P```$8X```'````3C@```0```!6.```!0```%LX```*````83@`
M``4```!L.```!@```'(X```&````>3@```T```"`.```$````(XX```;````
MGS@```0```"[.```"0```,`X```%````RC@```8```#0.```!P```-<X```'
M````WS@```4```#G.```"0```.TX```*````]S@```X````".0```@```!$Y
M```)````%#D```8````>.0``$@```"4Y```)````.#D```<```!".0``!@``
M`$HY```*````43D```0```!<.0``"0```&$Y```&````:SD```T```!R.0``
M!@```(`Y```$````ASD```4```",.0``!@```)(Y```'````F3D``"$```"A
M.0``!@```,,Y```$````RCD```0```#/.0``'0```-0Y```$````\CD```P`
M``#W.0``#@````0Z```*````$SH```@````>.@``"0```"<Z```'````,3H`
M``H````Y.@``!P```$0Z```*````3#H```8```!7.@``#P```%XZ```%````
M;CH```D```!T.@``!````'XZ```+````@SH```P```"/.@``!P```)PZ```$
M````I#H```<```"I.@``!@```+$Z```&````N#H```8```"_.@``!0```,8Z
M```'````S#H```<```#4.@``!0```-PZ```6````XCH```8```#Y.@``!```
M```[```$````!3L```<````*.P``"@```!([```%````'3L```H````C.P``
M"````"X[```(````-SL```\```!`.P``!@```%`[```*````5SL```@```!B
M.P``(````&L[```&````C#L```8```"3.P``!P```)H[```$````HCL```<`
M``"G.P``!0```*\[```'````M3L``!8```"].P``#0```-0[```$````XCL`
M``4```#G.P``"0```.T[```*````]SL```@````"/```!@````L\```'````
M$CP```4````:/```"P```"`\```$````+#P```,````Q/```"@```#4\```"
M````0#P```4```!#/```"@```$D\```$````5#P```8```!9/```"````&`\
M```(````:3P```0```!R/```!0```'<\```%````?3P```8```"#/```$```
M`(H\```*````FSP```H```"F/```"0```+$\```#````NSP```<```"_/```
M!P```,<\```'````SSP```8```#7/```!@```-X\```&````Y3P```D```#L
M/```!@```/8\```-````_3P```8````+/0``"````!(]```.````&ST```<`
M```J/0``"@```#(]```'````/3T```D```!%/0``"0```$\]```*````63T`
M``<```!D/0``"0```&P]```'````=CT```H```!^/0``!P```(D]```$````
MD3T```<```"6/0``!0```)X]```%````I#T```L```"J/0``%````+8]```'
M````RST```4```#3/0``#0```-D]```1````YST```L```#Y/0``#`````4^
M```$````$CX```H````7/@``!````"(^```)````)SX```4````Q/@``!P``
M`#<^```%````/SX```0```!%/@```@```$H^```$````33X```X```!2/@``
M&````&$^```&````>CX```4```"!/@``"````(<^```&````D#X``!0```"7
M/@```@```*P^```&````KSX```<```"V/@``!@```+X^```,````Q3X```0`
M``#2/@``%````-<^```0````[#X```<```#]/@``!0````4_```'````"S\`
M``@````3/P``!0```!P_```&````(C\``!`````I/P``"````#H_```(````
M0S\```D```!,/P``!0```%8_```$````7#\```8```!A/P``!P```&@_```H
M````<#\```H```"9/P``"P```*0_```4````L#\```0```#%/P``"P```,H_
M```%````UC\```@```#</P``!@```.4_```&````[#\```@```#S/P``"```
M`/P_```'````!4````@````-0```"@```!9````+````(4````4````M0```
M!0```#-````%````.4````0````_0```!P```$1````-````3$````8```!:
M0```!P```&%````&````:4````4```!P0```!P```'9````1````?D````<`
M``"00```!0```)A````$````GD````<```"C0```"P```*M````,````MT``
M``4```#$0````P```,I````2````SD````8```#A0````P```.A````,````
M[$```!4```#Y0```"P````]!```9````&T$``"`````U00``!0```%9!```*
M````7$$``!4```!G00``#````'U!```$````BD$```P```"/00``!@```)Q!
M```.````HT$```T```"R00``"@```,!!```+````RT$```<```#700``"0``
M`-]!```5````Z4$```T```#_00``"`````U"```#````%D(```4````:0@``
M"@```"!"```$````*T(```8````P0@``#````#="```)````1$(```D```!.
M0@``!````%A"```(````74(```@```!F0@``#P```&]"```'````?T(```P`
M``"'0@``+````)1"```'````P4(```4```#)0@``!````,]"```)````U$(`
M``@```#>0@``!@```.="```-````[D(```<```#\0@``!@````1#```)````
M"T,```<````50P``!0```!U#```'````(T,```L````K0P``!P```#=#```(
M````/T,``!8```!(0P``"0```%]#```&````:4,```L```!P0P``%````'Q#
M```%````D4,``!````"70P``$````*A#```&````N4,```H```#`0P``!0``
M`,M#```0````T4,```L```#B0P``!````.Y#```)````\T,```@```#]0P``
M+P````9$```$````-D0```L````[1```!0```$=$```"````340```4```!0
M1```!````%9$```'````6T0```4```!C1````P```&E$```3````;40```<`
M``"!1```!@```(E$```4````D$0```P```"E1```&````+)$```&````RT0`
M``,```#21```!````-9$```&````VT0```<```#B1```"0```.I$```'````
M]$0```\```#\1```%`````Q%```.````(44```T````P10``)````#Y%```%
M````8T4```<```!I10``!P```'%%```&````>44```8```"`10``!P```(=%
M```$````CT4``!,```"410``"````*A%```)````L44```H```"[10``"```
M`,9%```&````ST4```<```#610``"````-Y%```)````YT4```<```#Q10``
M#P```/E%```'````"48``!0````11@``$0```"9&```'````.$8```,```!`
M1@``"````$1&```&````348```<```!41@``#0```%Q&```.````:D8```4`
M``!Y1@``!@```']&```(````AD8```P```"/1@``"@```)Q&```"````IT8`
M``0```"J1@``!@```*]&```%````MD8```,```"\1@``"0```,!&```*````
MRD8```4```#51@``!@```-M&```(````XD8```@```#K1@``$0```/1&```9
M````!D<``!$````@1P``&````#)'```3````2T<``!P```!?1P``$0```'Q'
M```/````CD<```(```">1P``$0```*%'```2````LT<``!<```#&1P```@``
M`-Y'```$````X4<``!$```#F1P``!@```/A'```8````_T<``!,````82```
M`@```"Q(```,````+T@``!$````\2```#0```$Y(```'````7$@```4```!D
M2```)0$``&I(```M````D$D``$4```"^20``&P````1*```A````($H``!X`
M``!"2@``/0```&%*``!J````GTH``!(````*2P``!0```!U+```5````(TL`
M``D````Y2P``%0```$-+```R````64L``#(```",2P``$P```+]+```*````
MTTL``!(```#>2P``,````/%+```2````(DP``#8````U3```&P```&Q,```M
M````B$P``"H```"V3```)P```.%,```8````"4T``!X````B30``,````$%-
M```2````<DT``!@```"%30``0@```)Y-```H````X4T``!@````*3@``&P``
M`"-.```>````/TX``"<```!>3@``/@```(9.```8````Q4X```P```#>3@``
M)````.M.```>````$$\``!(````O3P``$@```$)/```;````54\```P```!Q
M3P``'@```'Y/```5````G4\``($```"S3P``+0```#50```J````8U```#8`
M``".4```&````,50```2````WE```"0```#Q4```&````!91```;````+U$`
M`!X```!+40``%0```&I1```2````@%$``!@```"340``$@```*Q1```;````
MOU$```D```#;40``$@```.51```D````^%$```P````=4@``#P```"I2``!-
M````.E(``!L```"(4@``&P```*12```)````P%(``!X```#*4@``&````.E2
M``!8`````E,``#P```!;4P``'@```)A3```J````MU,``!@```#B4P```P``
M`/M3```8````_U,``!4````85```&````"Y4```2````1U0``!(```!:5```
M$@```&U4```5````@%0``#````"65```'@```,=4```2````YE0``%$```#Y
M5```"0```$M5```D````554```P```!Z50``"0```(=5```M````D54```\`
M``"_50``(0```,]5```>````\54``"H````05@``&````#M6```)````5%8`
M`"$```!>5@``,P```(!6```D````M%8``!X```#95@``&P```/A6```>````
M%%<``!@````S5P``&````$Q7``!"````95<``%$```"H5P``%0```/I7``!*
M````$%@```@```!;6```#````&18```5````<5@```\```"'6```'@```)=8
M```2````ME@``!(```#)6```%0```-Q8```/````\E@``#P````"60``0@``
M`#]9``"Y````@ED```P````\6@``$@```$E:```A````7%H``"T```!^6@``
M+0```*Q:```"````VEH``!L```#=6@``)P```/E:```,````(5L```P````N
M6P``,0```#M;```8````;5L```P```"&6P``'@```)-;```>````LEL``!@`
M``#16P``'@```.I;```8````"5P```8````B7```&P```"E<```8````15P`
M`#P```!>7```40```)M<```/````[5P``"T```#]7```$@```"M=```;````
M/ET``!L```!:70``&P```'9=```8````DET``"<```"K70``$@```--=```P
M````YET``&@````77@``*@```(!>```P````JUX``!@```#<7@``#P```/5>
M```8````!5\``!@````>7P``$@```#=?```O````2E\``#4```!Z7P``*0``
M`+!?```Y````VE\``"0````48```'@```#E@```2````6&```"H```!K8```
M0@```)9@```A````V6```!(```#[8```$@````YA```;````(6$```\````]
M80``(0```$UA```/````;V$``!L```!_80``$@```)MA```/````KF$``"T`
M``"^80``)````.QA```,````$6(``!(````>8@``-P```#%B```S````:6(`
M`$8```"=8@``!@```.1B```;````ZV(``!4````'8P``&````!UC```;````
M-F,``!X```!28P``$@```'%C```D````A&,``!@```"I8P``'@```,)C```&
M````X6,``#,```#H8P``#P```!QD```<````+&0``!4```!)9```'@```%]D
M```/````?F0``"<```".9```$@```+9D```A````R60``!(```#K9```(0``
M`/YD```;````(&4```0````\90``#````$%E```5````3F4``!(```!D90``
M30```'=E```2````Q64```\```#890``#P```.AE``!1````^&4``!@```!*
M9@``*@```&-F```2````CF8``"<```"A9@``'@```,EF```2````Z&8``!4`
M``#[9@``(0```!%G```8````,V<``"$```!,9P``$@```&YG``!"````@6<`
M``\```#$9P``'@```-1G```5````\V<``!4````):```)````!]H```;````
M1&@``!@```!@:```$@```'EH```>````C&@``!@```"K:```#P```,1H```5
M````U&@``!4```#J:```#`````!I```/````#6D``"`````=:0``&P```#YI
M```2````6FD``!(```!M:0``)P```(!I```G````J&D``!(```#0:0``)```
M`.-I```S````"&H``!@````\:@``&P```%5J```8````<6H``"0```"*:@``
M#````*]J``!U````O&H``!@````R:P``$@```$MK```/````7FL```\```!N
M:P``$@```'YK```2````D6L``!L```"D:P``3P```,!K```A````$&P```D`
M```R;```"0```#QL```;````1FP``"0```!B;```$@```(=L```)````FFP`
M``D```"D;```"0```*YL```D````N&P``"T```#=;```"0````MM```>````
M%6T```(````T;0``$@```#=M```J````2FT``!4```!U;0``%0```(MM```8
M````H6T``!@```"Z;0``#P```--M```5````XVT```P```#Y;0``&P````9N
M```2````(FX``!L````U;@``&P```%%N```8````;6X```P```"&;@``$@``
M`)-N```2````IFX```D```"Y;@``(0```,-N```8````Y6X``!(```#^;@``
M%P```!%O```/````*6\``!4````Y;P``%0```$]O```>````96\``"````"$
M;P``%0```*5O```;````NV\``!4```#7;P``.0```.UO```V````)W```#8`
M``!><```,````)5P```;````QG```!(```#B<```)````/5P```>````&G$`
M``\````Y<0``%0```$EQ```,````7W$``!4```!L<0``&````()Q```M````
MFW$``!(```#)<0``"0```-QQ```G````YG$``"0````.<@``)P```#-R```V
M````6W(``!4```"2<@``*@```*AR```5````TW(``"0```#I<@``%0````YS
M```A````)',```D```!&<P``"0```%!S```&````6G,```\```!A<P``(0``
M`'%S``!%````DW,``!(```#9<P``#P```.QS```8````_',```D````5=```
M)P```!]T```5````1W0```\```!==```#````&UT```;````>G0``#8```"6
M=```#P```,UT``!%````W70``$(````C=0``%0```&9U```2````?'4``!(`
M``"/=0``'@```*)U```/````P74``!@```#1=0``*@```.IU```A````%78`
M`"<````W=@``+````%]V```;````C'8```\```"H=@``$@```+AV```/````
MRW8``&8```#;=@``$@```$)W```2````57<``#P```!H=P``$@```*5W```;
M````N'<``!@```#4=P``&P```.UW```2````"7@``!(````<>```)````"]X
M```2````5'@``"0```!G>```$@```(QX```G````GW@``!L```#'>```#```
M`.-X```2````\'@```P````#>0``"0```!!Y```J````&GD``$$```!%>0``
M)P```(=Y```G````KWD``!(```#7>0``)P```.IY```5````$GH``#`````H
M>@``(0```%EZ```2````>WH``!(```".>@``%0```*%Z```M````MWH``"T`
M``#E>@``&@```!-[```,````+GL``"T````[>P``&````&E[```#````@GL`
M`!X```"&>P``+````*5[```A````TGL``$0```#T>P``30```#E\```2````
MAWP``"$```":?```%0```+Q\```S````TGP``"0````&?0``,0```"M]```5
M````77T``"T```!S?0``,P```*%]```G````U7T``"$```#]?0``'@```!]^
M```/````/GX``$0```!.?@``(0```)-^```,````M7X```\```#"?@``#P``
M`-)^```5````XGX``!(```#X?@``$@````M_```>````'G\``!@````]?P``
M&P```%9_```,````<G\``!L```!_?P``&P```)M_```D````MW\``!4```#<
M?P``-@```/)_``"`````*8```!(```"J@```&````+V````J````UH```!L`
M```!@0``'@```!V!```8````/($``"$```!5@0``&P```'>!```;````DX$`
M`"T```"O@0``$@```-V!```2````\($``!(````#@@``)````!:"```2````
M.X(``!L```!.@@``1P```&J"```D````LH(``!4```#7@@``$@```.V"``!&
M`````(,```\```!'@P``/P```%>#``!1````EX,``!4```#I@P``+0```/^#
M```8````+80``"0```!&A```'@```&N$```2````BH0``!@```"=A```!@``
M`+:$``"1````O80``!L```!/A0``2P```&N%```8````MX4```8```#0A0``
M&````->%```2````\(4``!L````#A@``%0```!^&```/````-88``$0```!%
MA@``&````(J&```/````HX8``!P```"SA@``)````-"&```R````]88``!L`
M```HAP```P```$2'```$````2(<``!X```!-AP``&P```&R'```S````B(<`
M`"<```"\AP``'0```.2'```A`````H@``#`````DB```)P```%6(``!:````
M?8@```P```#8B```'@```.6(```A````!(D``#8````FB0``&P```%V)```D
M````>8D``!L```">B0``10```+J)```M`````(H``#(````NB@``+0```&&*
M```5````CXH```\```"EB@``(0```+6*```,````UXH``"<```#DB@``#```
M``R+``!"````&8L```P```!<BP``1@```&F+```^````L(L``!(```#OBP``
M"0````*,```A````#(P``"0````NC```)````%.,```_````>(P``"T```"X
MC```#P```.:,```0````]HP``"H````'C0``2P```#*-``!1````?HT```(`
M``#0C0``!````-.-```A````V(T```\```#ZC0``$P````J.```J````'HX`
M`"0```!)C@``!@```&Z.```8````=8X``"$```".C@``#````+".``!4````
MO8X``%$````2CP``3@```&2/``!C````LX\``%0````7D```8````&R0``!+
M````S9```$(````9D0```@```%R1``!(````7Y$``#<```"HD0``10```."1
M```(````)I(```\````OD@``10```#^2```2````A9(``%<```"8D@``.0``
M`/"2```"````*I,``"H````MDP``.0```%B3```P````DI,``"$```##DP``
M!0```.63```!````1@```/,!``"X`````````#,!```!`0``_@```!T"``#6
M`0```````"D!```%`@``T@$````````F`````````+,`````````3````+L`
M``#8````DP```+,!```-`@```````%0!``#F````D0```,8````R`@``Q0``
M``````!1````4@$``!T!`````````````$4```#[````X@$```@"```C````
M)0(```````"G````@P$``)D```#G`0``%@(``#\"``##`0```P$``*0!````
M````WP$``+````#`````60````X"```Q`0````````````#5````QP```(\!
M``!``0```````.H!``"6````5@```````````````````!H"``"2````=`$`
M`-$```""````[P```(`````M````F@$``.4!``#)````,@$``!T`````````
MTP```"@"``!W````]0$``/H```"K````^0$`````````````=0$```````#L
M`0``R@````````#5`0``L0$``#P!``"(````+P$``*(```!F`0``%P(``"8!
M````````1@$`````````````ZP```"T!````````-P(`````````````````
M`.\!````````E@$`````````````TP$``-`!``#R`````````(\`````````
M"@(``&H!```X`0``)`````X`````````N@$``*,`````````/@```'D!````
M``````````````#N`````````$D!``"U`````````#,```#?`````````)X`
M````````\`$``&\```!0`0``XP```)X!````````"````&T!``"(`0``````
M`````````````````(L!``#X`````````+X````;`@```````'````!A````
M8`````L"``"'````"0```)L``````````````'8````>`@``O0$```,````0
M`@```````&\!``#H`0``*@```"\`````````K````%@!````````=0```"@!
M```/````=@$``'(```"?````T0$``&D```"R````_P```.T!``"C`0``Q```
M``P`````````1`$``*$!`````````````$T```!"`````````(0````U`@``
M`````,$``````````````+0```#A`0```````!\```"@`0```````+\!```P
M`@```````(H```"J````V0$````````L`@``5````!X!``!#`0``N`$`````
M``````````````````"[`0```````)(!```G`````````.T```"7````I@``
M`&`!``"D````.P$``/<````T````FP$``.`!```]`@```````&<````Y````
M``````````"8`0``$P$``,P!``"N`````````&0```"O````I0```,,```"Y
M`0``H@$``.0`````````.@(```````",````4P$``(4!``!*````<0```#@`
M``!A`0``6@````````!'````,P(``$H!````````[``````````<`0``%0(`
M`#0"```$````,`$``#0!````````\0```*T```"\`0``V@``````````````
M````````````````Q@$``!<```!,`0``I@$``)4```"K`0``*0```$L!```A
M`@``?0$``$@```!M````1`(```````"!`0``=````.<````+`0``#`$``#P`
M``!L`0```````#4````!`@``)`$``$T!````````V@$``!\!``"@````&@``
M``````#W`0``-@$``)H```````````````,"````````0@$``($````)`0``
M8@$``/X!``#(`0``)`(```````#<`0``Y0`````````Z`0```````#8"``!<
M`0``(@```&X`````````C0```%````#$`0``X@`````````L`0``%@```',!
M``"8`````````(,```!%`0``.P```&L```"J`0``0`(``,`!``"L`0``)P$`
M`%4!```E`0``)@(````````*````_`$`````````````!P$``(`!``!;`0``
M`````/H!````````S0````````!\````1`````````#@````G````/0!```9
M````7P```%X!``#2````Z0$``(P!``"Z````>`````````!.````````````
M``".`0``\P````L````5`0``V0```$L```"9`0``%P$``,H!``"W````J`$`
M``````!W`0``*P(``)````!=````7````!D!```I`@``)P(````````2````
M`````),!``"'`0``\@$``#L"``!K`0``_```````````````@@$```8"````
M``````````8````9`@````````````!;````$0(```````!?`0``7@```#D"
M```%`0``+````.D```#+````4P````````"5`0``$@$``/\!```/`0``[@$`
M```"````````K0$``#(````U`0``SP```-`````<`@``.0$``%H!````````
M(P$``,X!``!.`0``^`$``$("``#Q`0``0P(`````````````<P``````````
M````+@```&(```````````````H!````````VP```/4```#A````]````'D`
M````````^0```````````````@$``%<!``"N`0```@```,(!``"G`0``Z```
M``````"1`0``A@```*D````]`0``$P(``,X`````````E````"`!```3````
M(P(``!@!````````XP$``#\!``!X`0``O@$```````````````````````#!
M`0``C0$```````#4`0``W@$``.L!```$`@```````)T!``#,````B0````<"
M```4````50```+8!``"O`0``&`(``&0!````````90`````````P````60$`
M`+(!```A`````````-<````%`````````%$!``!2````.@```"X!````````
MGP$``!0"``"Q````*P```*4!``!^`````````&,!`````````````,<!``#+
M`0``'P(``,D!````````W@```'P!``#F`0``0P```+0!````````_0$`````
M```1`````````+<!``!G`0``M0$```````"&`0``+0(```````!=`0``<@$`
M`(L```#P````!@$``#P"````````V`$`````````````O0```,4!``#4````
M^P$``$$"````````Z@```*@```"A````1P$``(D!```@````2`$`````````
M````U@````````!N`0``OP```&4!````````*@(``#$"``!`````D`$```D"
M``#/`0```````"@``````````````#\```#=````]@```"`"``!7````<0$`
M`&D!```B`0``A`$`````````````$@(``)<!``"I`0``?@$``#<```!!````
M`````'`!````````&P```!`!``````````$``"("```O`@``00$``/T```".
M````(0$``!$!``"Y````:`$``#@"```(`0``W0$``+P```!L````?0````T!
M```4`0``'@``````````````&@$``-L!``!)````>@$``#X!````````%0``
M`!@````E````!P```'L!````````/0```&H```!Z````G0````````#(````
M`````%8!```0`````````&,````-````*@$``"L!```"`@```````'\!```N
M`@```````#$``````````````'L``````````````(H!``#7`0``P@````\"
M``"4`0``-P$``!8!````````W```````````````S0$``%@```!_````/@(`
M`$\```"P`0``!`$``(4```!/`0````````X!```;`0``M@```#8`````````
M#`(``&@```"<`0``Y`$````````<````]@$`````````````9@`````@*"5S
M(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`("AT;V1A>2D`("AT;VUO<G)O
M=RD`("AY97-T97)D87DI`"(E<R(@:7,@;F]T(&$@9&ER96-T;W)Y+@`B)7,B
M(&ES(&YO="!A('9A;&ED(&-H;VEC92X`)60@)7,@86YD("5S`"5S($M"`"5S
M($U"`"5S.B`E<P`M+2!S96QE8W0@+2T`,3(@2&]U<B!&;W)M870`,C0@2&]U
M<B!&;W)M870`,C0@:&]U<G,`/%!R979I;W5S`$%B;W5T+BXN`$%C8V]U;G0@
M26YF;W)M871I;VX`061D`$%D9"!U<V5R`$%D9')E<W,`061D<F5S<R!";V]K
M`$%D;6EN:7-T<F%T:6]N`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!
M;&EA<P!!;&EG;@!!;&P`06QT97)N871E(&5M86EL(&%D9')E<W,`06UE<FEC
M86X@4V%M;V$`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YT87)C=&EC80!!
M;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P<FEL`$%R86)I8R`H
M5VEN9&]W<RTQ,C4V*0!!<F=E;G1I;F$`07)M96YI80!!<G5B80!!='1R:6)U
M=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S=')I80!!=71H96YT:6-A=&EO;B!F
M86EL960`07IE<F)A:6IA;@!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`
M0F%H86UA<P!"86AR86EN`$)A;F=L861E<V@`0F%R8F%D;W,`0F5L87)U<P!"
M96QG:75M`$)E;&EZ90!"96YI;@!"97)M=61A`$)H=71A;@!":7)T:&1A>0!"
M;VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97)S`$)O<VYI82!A
M;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1S=V%N80!";W1T;VT`0F]U=F5T($ES
M;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R
M=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U<FMI;F$@1F%S;P!"=7)U;F1I
M`$-20P!#86QE;F1A<@!#86UB;V1I80!#86UE<F]O;@!#86YA9&$`0V%N8V5L
M`$-A<&4@5F5R9&4`0V%P=&EO;@!#87)R:65R`$-A>6UA;B!)<VQA;F1S`$-E
M;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0VAA9`!#:&%N9V4`0VAI
M;&4`0VAI;F$`0VAR:7-T;6%S($ES;&%N9`!#;&5A<@!#;&5A<B!1=65R>0!#
M;&]S92!7:6YD;W<`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`0V]L;VUB:6$`
M0V]L;W(`0V]M;6%N9`!#;VUM96YT`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M
M<&%N>0!#;VUP=71E<G,`0V]N9&ET:6]N`$-O;F1I=&EO;G,`0V]N9FER;2!%
M;6%I;"!!9&1R97-S`$-O;F9I<FT@;F5W(&5M86EL(&%D9')E<W,`0V]N9V\`
M0V]N;F5C=&EO;B!F86EL960N`$-O;G1A8W1S`$-O;G1I;G5E`$-O;VL@27-L
M86YD<P!#;W!Y`$-O<W1A(%)I8V$`0V]U;G1R>0!#<F5A=&4`0W)O871I80!#
M=6)A`$-U<G)E;G0@5&EM90!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K
M<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-Y<')U<P!#>7)I;&QI
M8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>F5C:"!297!U
M8FQI8P!$1`!$86EL>0!$871E`$1A>0!$96-E;6)E<@!$96-R96%S92!);F1E
M;G0`1&5F875L=`!$96QE=&4`1&5L971E(&-O;'5M;@!$96QE=&4@<F]W`$1E
M;FUA<FL`1&5S8W)I<'1I;VX`1&5V96QO<&UE;G0`1&ER96-T;W)Y`$1J:6)O
M=71I`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$;VXG="!H879E(&%N
M(&%C8V]U;G0_(%-I9VX@=7`N`$1O=VYL;V%D`$1Y;F%M:6,@36%I;`!%+4UA
M:6P`16-U861O<@!%9&ET`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%
M;6%I;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H
M+@!%;6]T:6-O;G,`17%U871O<FEA;"!'=6EN96$`17)I=')E80!%<G)O<@!%
M<W1O;FEA`$5T:&EO<&EA`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y
M(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y(&AA;&8@:&]U<@!%
M=F5R>2!M:6YU=&4`17AE8W5T90!%>'!A;F0`17AP;VYE;G0`1F%L:VQA;F0@
M27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%X`$9E8G)U87)Y
M`$9I:FD`1FEL90!&:6QE($YA;64`1FEL=&5R<P!&:6YL86YD`$9L:7``1FQO
M870`1F]N="!#;VQO<@!&;W)M<P!&<F%M97,`1G)A;F-E`$9R96YC:"!'=6EA
M;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I
M97,`1G)O;0!&=6QL($YA;64`1V%B;VX`1V%M8FEA`$=E;W)G:6$`1V5R;6%N
M>0!':&%N80!':6)R86QT87(`1VEV96X@3F%M90!';&]B86P@3W!T:6]N<P!'
M;P!'<F%Y<V-A;&4`1W)E96-E`$=R965K("A)4T\M.#@U.2TW*0!'<F5E;FQA
M;F0`1W)E;F%D80!'<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'
M=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(86ET:0!(96%D97(`
M2&5A9&5R<P!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`2&5I
M9VAT`$AE;'``2&EG:`!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(
M;VUE`$AO;64@061D<F5S<P!(;VUE($1I<F5C=&]R>0!(;VUE(%!H;VYE`$AO
M;F1U<F%S`$AO;F<@2V]N9P!(=6YG87)Y`$E0($%D9')E<W,`26-E;&%N9`!)
M8V]N<R!/;FQY`$EM86=E<P!);F-R96%S92!);F1E;G0`26YD:6$`26YD;VYE
M<VEA`$EN9F\`26YF;W)M871I;VX`26YS97)T(%1A8FQE`$EN=&5G97(`27)A
M<0!)<F5L86YD`$ES<F%E;`!)<W-U97(`271A;&EC`$ET86QY`$IA;6%I8V$`
M2F%N=6%R>0!*87!A;@!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IO<F1A;@!*
M=6QY`$IU;F4`2G5S=&EF>0!+87IA:VAS=&%N`$ME;GEA`$ME>2!,96YG=&@`
M2V5Y(%1Y<&4`2VER:6)A=&D`2V]R96%N("A%54,M2U(I`$MU=V%I=`!+>7)G
M>7IS=&%N`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B
M;&EC`$QA='9I80!,87EO=70`3&5B86YO;@!,969T`$QE<V]T:&\`3&5V96P`
M3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`
M3&EN:P!,:6YK<P!,:71H=6%N:6$`3&]A9&EN9RXN+@!,;V-A=&EO;@!,;V<@
M:6X`3&]G(&]U=`!,;V=I;@!,;V=I;B!487-K<P!,;W9E`$QO=P!,=7AE;6)O
M=7)G`$U-`$UA8V%O`$UA9&%G87-C87(`36%I;`!-86QA=VD`36%L87ES:6$`
M36%L9&EV97,`36%L:0!-86QT80!-87)C:`!-87)G:6X`36%R<VAA;&P@27-L
M86YD<P!-87)T:6YI<75E`$UA=7)I=&%N:6$`36%U<FET:75S`$UA>0!-87EO
M='1E`$UE;6)E<G,`365S<V%G90!-971H;V0`365X:6-O`$UI9&1L90!-:6UE
M(%1Y<&4`36ER<F]R`$UI<V-E;&QA;F5O=7,`36]N86-O`$UO;F=O;&EA`$UO
M;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;W)O8V-O`$UO=F4@
M1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-
M;W9E('5P`$UO>F%M8FEQ=64`37EA;FUA<@!.86UE`$YA;6EB:6$`3F%U<G4`
M3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N9',@06YT:6QL97,`3F5T=V]R
M:P!.979E<@!.97<@0V%L961O;FEA`$YE=R!-97-S86=E('1O("5S`$YE=R!:
M96%L86YD`$YE=R!P87-S=V]R9`!.97=S`$YE=W-G<F]U<',`3F5X=`!.:6-A
M<F%G=6$`3FEG97(`3FEG97)I80!.:6=H=`!.:75E`$YO`$YO;F4`3F]R9F]L
M:R!)<VQA;F0`3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S`$YO<G=A>0!.;W1E
M<P!.;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3TL`3V)J
M96-T`$]C=&]B97(`3V9F:6-E`$]L9"!P87-S=V]R9`!/;6%N`$]P96X@:6X@
M82!N97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N<P!/=&AE<@!0
M861D:6YG`%!A:VES=&%N`%!A;&%U`%!A;F%M80!087!U82!.97<@1W5I;F5A
M`%!A<F%G=6%Y`%!A<W-W;W)D`%!A<W-W;W)D.@!087-T90!0871H`%!E;W!L
M90!097)C96YT`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L
M;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N<P!097)S;VYA;"!);F9O<FUA
M=&EO;@!097)U`%!H:6QI<'!I;F5S`%!H;VYE`%!I=&-A:7)N`%!I>&5L<P!0
M;VQA;F0`4&]R='5G86P`4')E<W-U<F4`4')E=FEE=P!0<F]J96-T<P!0=6)L
M:6,@2V5Y`%!U97)T;R!2:6-O`%%A=&%R`%%U97)Y`%%U;W1A`%)E860`4F5F
M<F5S:`!2969R97-H(')A=&4Z`%)E;&]A9`!296UA<FMS`%)E;6]V90!297-E
M=`!297-U;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E=6YI;VX`4FEG:'0`4F]L
M90!2;VUA;FEA`%)O=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W=S.@!2=6X`
M4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!34T@`4V%I;G0@2&5L96YA`%-A
M:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@
M86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S
M`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=61I
M($%R86)I80!3879E`%-A=F4@3W!T:6]N<P!396%R8V@`4V5A<F-H($5N9VEN
M97,`4V5L96-T(&$@9&%T90!396QE8W0@86QL`%-E;&5C="!N;VYE`%-E;F5G
M86P`4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I86P@3G5M
M8F5R`%-E<W-I;VYS`%-E=`!3971U<`!397EC:&5L;&5S`%-H;W<`4VAR:6YK
M`%-I97)R82!,96]N90!3:6=N871U<F4`4VEN9V%P;W)E`%-I>F4`4VQO=F%K
M:6$`4VQO=F5N:6$`4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]U=&@@069R
M:6-A`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA
M;F1S`%-P86-I;F<`4W!A:6X`4W!A;0!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A
M='5S`%-T<FEK971H<F]U9V@`4W5B:F5C=`!3=6)M:70`4W5B<V-R:7!T`%-U
M8V-E<W,`4W5D86X`4W5M;6%R>0!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN
M86UE`%-V86QB87)D(&%N9"!*86X@36%Y96X`4W=A>FEL86YD`%-W961E;@!3
M=VET>F5R;&%N9`!3>7)I86X@07)A8B!297!U8FQI8P!486)L90!486)L92!0
M<F]P97)T:65S`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A:FEK:7-T86X`
M5&%S:W,`5&5L97!H;VYE($YU;6)E<@!496UP97)A='5R90!497AT`%1E>'0@
M3VYL>0!4:&%I;&%N9`!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T
M:&ES(&UE<W-A9V4@<&%R=`!4:6UE`%1I;64@9F]R;6%T`%1I=&QE`%1O`%1O
M9&%Y`%1O9V\`5&]K96QA=0!4;VYG80!4;W``5')I;FED860@86YD(%1O8F%G
M;P!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N
M:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!54DP`55),
M.@!59V%N9&$`56MR86EN90!5;F1E<FQI;F4`56YF:6QE9`!5;FEC;V1E("A5
M5$8M."D`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI
M=&5D(%-T871E<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N
M9',`56YI=',`56YK;F]W;@!5;FYA;65D`%5P9&%T90!5<&QO860`57)U9W5A
M>0!5<V5R`%5S97(@061M:6YI<W1R871I;VX`57-E<FYA;64`57-E<FYA;64Z
M`%5Z8F5K:7-T86X`5F%L:61I='D`5F%L=65S`%9A;G5A='4`5F%R:6%B;&4`
M5F5N97IU96QA`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9I97<@)7,`5FER
M9VEN($ES;&%N9',L(%4N4RX`5V%L;&ES(&%N9"!&=71U;F$`5V%R;FEN9P!7
M96(`5V5B(%-I=&4`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E<P!797-T
M97)N(%-A:&%R80!7:61T:`!7:61T:#H`5VES:&QI<W0`5V]R:R!!9&1R97-S
M`%=O<FL@4&AO;F4`65D`65E960!996%R;'D`665M96X`665S`%EO=7(@3F%M
M90!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!::6UB86)W90!?3&]G(&]U=`!A
M9&1R97-S964@=6YK;F]W;@!C86YN;W0@8W)E871E(&]U='!U="!F:6QE`&-A
M;FYO="!O<&5N(&EN<'5T`&-O;6UA;F0@;&EN92!U<V%G92!E<G)O<@!C;VYF
M:6=U<F%T:6]N(&5R<F]R`&-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<`
M9&%T82!F;W)M870@97)R;W(`96YT<GD@;F]T(&9O=6YD`&AH`&AO<W0@;F%M
M92!U;FMN;W=N`&EN<'5T+V]U='!U="!E<G)O<@!I;G1E<FYA;"!S;V9T=V%R
M92!E<G)O<@!M;0!N86UE`'!E<FUI<W-I;VX@9&5N:65D`'!I>&5L<P!R96UO
M=&4@97)R;W(@:6X@<')O=&]C;VP`<V5R=FEC92!U;F%V86EL86)L90!S<P!S
M>7-T96T@97)R;W(`=&5M<&]R87)Y(&9A:6QU<F4`=6YK;F]W;B!E<G)O<@!U
M;FYA;65D`'9#87)D`%!R;VIE8W0M260M5F5R<VEO;CH@24U0"E!/5"U#<F5A
M=&EO;BU$871E.B`R,#`T+3$R+3`X(#$P.C(X*S`Q,#`*4$\M4F5V:7-I;VXM
M1&%T93H@,C`P-2TP-BTQ-2`Q,3HU,RLP-S`P"DQA<W0M5')A;G-L871O<CH@
M3&5A;F<@0VAU;7-O8F5N(#QS;V)E;D!K:&UE<F]S+FEN9F\^"DQA;F=U86=E
M+51E86TZ($MH;65R(#QS=7!P;W)T0&MH;65R;W,N:6YF;SX*34E-12U697)S
M:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/75T
M9BTX"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*`"`H)7,@X9Z0
MX9^2X9Z$X9^#XH"+X9Z`X9Z3X9^2X9Z;X9Z$XH"+X9Z1X9^%*0`@*.&>@N&?
MDN&>FN&>MN&>E.&?B^*`B^&>A>&>N^&>A>*`B^&>E>&?DN&>F^&>O.&>G.*`
MB^&>@.&>MN&>C^&?BR`E<RD`("CAGI#AGY+AGH3AGX/B@(OAGI/AGX'AGX<I
M`"`HX9Z0X9^2X9Z$X9^#XH"+X9Z?X9^2X9ZBX9^"X9Z`*0`@*.&>F.&?DN&>
MG^&>M^&>F^&>F.&?B>&>M^&>B2D`(B5S(B#AGICAGK?AGI/B@(OAGICAGX+A
MGI/B@(OAGH?AGK;B@(OAGI#AGH_B@(OAGJ'AGK[AGIG"H.&?E``B)7,B(.&>
MF.&>M^&>D^*`B^&>F.&?@N&>D^*`B^&>A^&>MN*`B^&>A^&>F.&?DN&>FN&>
MON&>G^*`B^&>C^&?DN&>FN&>N>&>F.&>C^&?DN&>FN&>O.&>G.*`B^&>H>&>
MON&>F<*@X9^4`"5D("5S(.&>D^&>M^&>A"`E<P`E<R!+0@`E<R#AGICAGX'A
MGH#AGK;AGI3AGX,`)7,@X9^6("5S`"TM(.&>A^&?DN&>FN&>ON&>GR`M+0#A
MGI'AGY+AGIKAGH3AGXOAGI'AGY+AGIKAGK;AGID@X9^AX9^B(.&>F.&?B>&?
MA.&>A`#AGI'AGY+AGIKAGH3AGXOAGI'AGY+AGIKAGK;AGID@X9^BX9^D(.&>
MF.&?B>&?A.&>A`#AGZ+AGZ0@X9Z8X9^)X9^$X9Z$`#SAGICAGKOAGI,`X9ZB
MX9^&X9Z6X9ZXXH"++BXN`.&>EN&?D.&>C^&?C.&>F.&>MN&>D^*`B^&>HN&?
MAN&>EN&>N.&>@N&>CN&>D^&>N`#AGI3AGI/AGY+AGI#AGX+AGI@`X9Z4X9Z3
MX9^2X9Z0X9^"X9Z8XH"+XH"+XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z4X9^2X9Z:
MX9Z^`.&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>DP#AGI_AGX#AGISAGI?A
MGX7B@(OAGJ+AGK;AGI_AGIGAGHKAGY+AGHOAGK;AGI,`X9Z`X9ZVX9Z:XH"+
MX9Z"X9^2X9Z:X9Z4X9^+XH"+X9Z"X9^2X9Z:X9Z$`.&>HN&>MN&>H.&?DN&>
M@N&>MN&>D^&>N.&>G^&?DN&>D.&>MN&>DP#AGJ+AGK;AGIOAGXOAGI3AGK;A
MGI/AGK@`X9ZBX9ZVX9Z;X9^+X9Z@X9^2X9Z?X9^!X9Z:X9ZX`.&>B.&?DN&>
MF.&?A.&?A^*`B^&>@.&?DN&>F^&?@N&>A.&>@.&?DN&>F^&>MN&>F0#AGH_A
MGICAGY+AGIKAGKGAGI@`X9Z1X9ZVX9^&X9Z$XH"+X9ZBX9Z?X9^+`.&>E.&?
MDN&>BN&>O.&>FN*`B^&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>D^*`B^&>
MHN&?BN&>N.&>F.&?@N&>FP#AGI_AGK;AGICAGKSAGJ+AGK8@X9ZBX9ZVX9Z8
MX9^!X9Z:X9ZWX9Z``.&>HN&>A.&?B^&>BN&>O.&>FN&?B>&>M@#AGJ+AGH3A
MGXOAGJ#AGY+AGH+AGX3AGJ'AGK8`X9ZBX9Z$X9^+X9Z@X9^2X9Z?X9^*X9ZX
MX9ZAX9ZV`.&>E^&>MN&>@N*`B^&>@>&>MN&>A.*`B^&>C^&?DN&>E.&>O.&>
MA`#AGJ+AGH3AGXOAGI'AGKCAGJ#AGY+AGH+AGK8@X9Z3X9ZWX9Z$(.&>E.&>
MMN&>E.&?BN&>N^&>F>&>BN&>M@#AGH#AGICAGY+AGICAGISAGK?AGI+AGK@`
MX9Z8X9^!X9Z?X9ZV`.&>HN&>MN&>FN&?B>&>MN&>E.&?BR`H5VEN9&]W<RTQ
M,C4V*0#AGJ+AGK;AGJ#AGY+AGI_AGH3AGXOAGI'AGKCAGI,`X9ZBX9ZVX9Z8
MX9^!X9Z3X9ZX`.&>HN&>MN&>FN&>O.&>E.&>M@#AGH+AGKOAGH[AGIOAGH#A
MGY+AGH'AGH[AGX@`X9Z?X9ZXX9Z@X9ZV`.&>HN&>O.&>G^&?DN&>C^&?DN&>
MFN&>MN&>F^&>N`#AGJ+AGKSAGI'AGY+AGIKAGKCAGI\`X9Z`X9ZVX9Z:XH"+
MX9Z5X9^2X9Z1X9^`X9Z$XH"+X9Z5X9^2X9Z1X9ZVX9Z/X9^+XH"+X9Z7X9ZV
MX9Z6XH"+X9Z/X9^2X9Z:X9ZYX9Z8XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4
MX9ZVX9Z3XH"+X9Z4X9Z:X9ZVX9Z'X9^0X9Z9`.&>HN&>MN&>H.&?DN&>G^&?
MBN&?@N&>FN&>E.&?@N&>H.&?DN&>G^&>A.&?BP#AGI7AGY+AGI'AGX/B@(OA
MGH'AGK;AGH3B@(OAGH#AGY+AGIKAGX3AGID`X9Z6X9Z.X9^,XH"+X9Z5X9^2
MX9Z1X9^#XH"+X9Z!X9ZVX9Z$XH"+X9Z`X9^2X9Z:X9^$X9Z9`.&>E.&>MN&>
MH.&>MN&>F.&?B>&>MN&>GP#AGI3AGK;AGIKAGXGAGX+AGI,`X9Z4X9Z$X9^+
MX9Z`X9^2X9Z;X9ZVX9Z*X9^!X9Z?X9^2X9Z@`.&>E.&>MN&>FN&>E.&>MN&>
MBN&>O.&>GP#AGI3AGX'AGJ'AGK;AGIKAGKOAGI_AGY+AGI\`X9Z4X9^"X9Z;
MXH"+X9Z@X9^2X9Z?X9^*X9ZWX9Z``.&>E.&?@>&>F^&>N.&>H.&?DN&>GP#A
MGI3AGX'AGH[AGK;AGX;AGH0`X9Z4X9^*X9^!X9Z:X9Z8X9Z\X9Z*X9ZV`.&>
ME.&?BN&>O.&>C^&>MN&>DP#AGI#AGY+AGH3AGX/AGH#AGX;AGH[AGK[AGH\`
MX9Z*X9ZWX9Z/`.&>E.&>O.&>F^&>N.&>G.&>N`#AGH#AGI/AGY+AGIOAGX+A
MGH3B@(OAGH7AGX;AGH[AGK;AGX8`X9Z?X9^*X9Z[X9Z8`.&>G^&?BN&>N^&>
MF.*`BP#AGI3AGKSAGI_AGY+AGI/AGXKAGK@@X9Z3X9ZWX9Z$(.&>H.&>NN&>
MH.&?DN&>G^&?BN&?@>&>H.&?DN&>@N&?A.&>G.&>N.&>CN&>M@#AGI'AGK;A
MGX;AGH3B@(OAGI;AGKCAGIKB@(L`X9Z4X9Z[X9Z/X9Z?X9^2X9Z<X9ZVX9Z.
MX9ZV`.&>E.&>MN&>CP#AGH#AGX3AGX?B@(OAGI3AGXKAGKSAGISAGXGAGX(`
MX9Z4X9^2X9Z:X9^!X9Z?X9^*X9ZXX9Z;`.&>HN&>MN&>CN&>MN&>A>&>@.&?
MDN&>FN*`B^&>G^&>F.&>N^&>D>&?DN&>FN*`B^&>I>&>CN&?DN&>C.&>MB#A
MGJ+AGH3AGXOAGH+AGY+AGIOAGX'AGI\`X9Z4X9^2X9Z:X9^*X9Z[X9Z9X9Z.
MX9^!XH"+X9Z*X9ZVX9Z:X9^*X9Z[X9Z9X9Z?X9ZVX9ZAX9ZVX9Z8`.&>E.&?
MBN&>N^&>F^&>H.&?DN&>@N&>MN&>FN&>N`#AGI3AGXKAGKSAGIKAGH+AGKCA
MGH[AGK;AGJ#AGY+AGISAGK;AGI_AGKP`X9Z4X9^*X9Z\X9Z:X9Z[X9Z3X9Z,
MX9ZX`$-20P#AGI3AGY+AGIKAGH_AGK?AGI'AGK?AGI,`X9Z`X9Z8X9^2X9Z6
MX9Z[X9Z'X9ZV`.&>@.&>MN&>F.&?B>&>MN&>FN&>O.&>DP#AGH#AGK;AGH[A
MGK;AGHKAGK8`X9Z4X9^$X9^'X9Z4X9Z$X9^+`.&>@.&>MN&>E.&>G.&?@N&>
MF@#AGH7AGX;AGH[AGH3AGH?AGK[AGH0`X9Z<X9Z/X9^2X9Z0X9Z[XH"+X9Z*
MX9ZYX9Z`XH"+X9Z'X9Z)X9^2X9Z'X9Z\X9Z3`.&>@.&?A.&?A^*`B^&>@.&?
M@^&>F.&?B>&>MN&>DP#AGH#AGH[AGY+AGH_AGK;AGIL`X9Z?X9ZVX9Z2X9ZV
MX9Z:X9Z.X9Z:X9Z*X9^2X9Z+XH"+X9ZBX9ZVX9Z@X9^2X9Z<X9^2X9Z:X9ZW
MX9Z`XH"+X9Z`X9Z.X9^2X9Z*X9ZVX9Z;`.&>AN&>MN&>B@#AGI7AGY+AGIOA
MGK;AGI_AGXOB@(OAGI3AGY+AGH_AGKSAGIH`X9Z(X9ZXX9Z;X9ZX`.&>A>&>
MM^&>DP#AGH#AGX3AGX?B@(OAGH+AGY+AGIKAGKCAGI_AGY+AGH_AGICAGXGA
MGK;AGI\`X9Z'X9Z8X9^2X9Z:X9^'`.&>A^&>F.&?DN&>FN&?A^*`B^&>G^&?
MAN&>CN&>O>&>F@#AGI3AGK?AGI'B@(OAGI3AGH3AGY+AGJ+AGKWAGH4`X9Z`
MX9^$X9^'XH"+X9Z`X9Z\X9Z`X9Z\("CAGH/AGKCAGIOAGKCAGH0I`.&>@.&>
MO.&>H>&>N^&?AN&>E.&?BN&>N`#AGI;AGH[AGXP`X9Z6X9ZVX9Z`X9^2X9Z9
MXH"+X9Z4X9Z)X9^2X9Z'X9ZV`.&>G^&?@>&>A>&>@.&?DN&>C^&>N.*`B^*`
MB^&>HN&>DN&>M^&>E.&?DN&>E.&>MN&>F0#AGHCAGY+AGICAGX3AGX?B@(OA
MGI+AGICAGY+AGICAGH_AGK8`X9Z`X9Z[X9^&X9Z8X9^)X9Z\X9Z:X9^)X9Z\
MX9Z?`.&>@.&?DN&>FN&>N^&>F.&>H.&?BN&>N^&>DP#AGH#AGKOAGX;AGI;A
MGY+AGIGAGKSAGI'AGY#AGIH`X9Z;X9Z`X9^2X9Z!X9Z!X9Z.X9^2X9Z,`.&>
MF^&>@.&?DN&>@>&>@>&>CN&?DN&>C`#AGJ+AGX?AGJ+AGK;AGH3B@(OAGJ+A
MGK;AGI_AGIGAGHKAGY+AGHOAGK;AGI/B@(OAGJ+AGXKAGKCAGICAGX+AGIL`
MX9ZBX9^'X9ZBX9ZVX9Z$XH"+X9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3
MXH"+X9ZBX9^*X9ZXX9Z8X9^"X9Z;XH"+X9Z0X9^2X9Z8X9ZX`.&>@.&>N^&>
MA.&>H.&?DN&>@N&?A`#AGH#AGK;AGIKB@(OAGH_AGI?AGY+AGH?AGK;AGI3A
MGXOB@(OAGI3AGK;AGI/B@(OAGI3AGIKAGK;AGH?AGY#AGIGB@(O"H.&?E`!#
M;VYT86-T<P#AGI3AGI/AGY+AGH\`X9Z`X9^$X9^'XH"+X9Z`X9Z\X9Z``.&>
MA>&>F.&?DN&>F^&>A`#AGH#AGKSAGI_AGY+AGH_AGK;AGIKAGKCAGH#AGK8`
MX9Z4X9^2X9Z:X9Z1X9^!X9Z?`.&>E.&>A.&?DN&>@.&>ON&>CP#AGH#AGY+A
MGIKAGKSAGJ+AGK;AGH\`X9Z"X9Z[X9Z9X9Z4X9ZV`.&>EN&?@>&>F^*`B^&>
MG.&?@>&>F^&>MN*`B^&>E.&>A>&?DN&>A>&>N^&>E.&?DN&>E.&>D^&?DN&>
MDP#AGIKAGH7AGI/AGK;AGI3AGY#AGI'AGY+AGICB@(OAGI3AGH7AGY+AGH7A
MGKOAGI3AGY+AGI3AGI/AGY+AGI/B@(L`X9Z4X9^2X9Z/X9Z\X9Z:XH"+X9Z7
MX9ZVX9Z:X9Z`X9ZWX9Z%X9^2X9Z%XH"+X9Z*X9^"X9Z;XH"+X9Z/X9^2X9Z:
MX9Z\X9Z<XH"+X9Z:X9Z/X9^+XH"+X9Z/X9ZVX9Z8XH"+X9Z4X9^&X9Z.X9Z$
M(.&>HN&>MN&>G^&?DN&>FN&?D.&>F>*`B^&>F^&>ON*`B^&>@.&>MN&>FN*`
MB^&>A>&>O.&>F^*`B^&>D>&?A>*`BR`E<R#AGY0`X9Z`X9ZVX9Z/X9^+`.&>
MG^&?BN&>N.&>EN&>FN&?C0#AGI_AGXKAGKCAGIKAGKCAGIOAGKCAGH`@*$M/
M23@M4BD`XH"+XH"+X9Z?X9^*X9ZXX9Z:X9ZXX9Z;X9ZXX9Z`("A7:6YD;W=S
M+3$R-3$I`.&>G^&>MN&>DN&>MN&>FN&>CN*`B^&>FN&>BN&?DN&>B^*`B^&>
MAN&?@>&>@`!$1`#AGIKAGK;AGIOAGXOB@(OAGI#AGY+AGH3AGX,`X9Z`X9ZV
MX9Z;XH"+XH"+X9Z4X9Z:X9ZWX9Z%X9^!X9^2X9Z&X9Z1`.&>D.&?DN&>A.&?
M@P#AGI+AGY+AGI/AGKP`X9Z4X9Z3X9^2X9Z0X9Z9(.&>A>&>O.&>F^*`B^&>
ME.&>D^&?DN&>D>&>MN&>C^&?BP#AGIOAGX;AGI/AGK;AGX;AGHKAGK[AGI@`
MX9Z;X9Z[X9Z4XH"+`.&>F^&>N^&>E.*`B^&>A^&>O>&>FN*`B^&>B.&>F@#A
MGIOAGKOAGI3B@(OAGH?AGKWAGIKAGHKAGX'AGH``X9Z*X9ZVX9Z.X9ZZX9Z8
MX9^)X9ZVX9Z``.&>@.&>MN&>FN&>EN&>M^&>EN&>CN&?C.&>D^&>M@#B@(OA
MGJ+AGI?AGK?AGISAGHSAGY+AGHT`X9Z0X9Z/`.&>H.&?DN&>G^&?BN&>N.&>
ME.&>O.&>D>&>N`#AGHKAGKSAGICAGKCAGI/AGKCAGH#AGK8`X9Z?X9ZVX9Z2
MX9ZVX9Z:X9Z.X9Z:X9Z*X9^2X9Z+XH"+X9Z*X9Z\X9Z8X9ZXX9Z3X9ZXX9Z`
MX9^"X9Z3`.&>F.&>M^&>D^*`B^&>F.&>MN&>D^*`B^&>@N&>CN&>D^&>N,*@
M/R#AGI_AGKSAGICB@(OAGH7AGKOAGX?AGHCAGY+AGICAGX3AGX?"H.&?E`#A
MGI'AGK;AGHGAGIGAGH``X9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:XH"+X9Z0X9ZV
MX9Z8X9Z<X9Z3X9^2X9Z/`.&>HN&?BN&>N.&>F.&?@N&>FP#AGJ+AGX'AGH#A
MGY+AGISAGK;AGHSAGY#AGIH`X9Z`X9^"XH"+X9Z?X9Z8X9^2X9Z:X9Z]X9Z;
M`.&>@.&>MN&>FN*`B^&>HN&>E.&?B^&>FN&?A@#AGJ+AGX'AGJ#AGY+AGI_A
MGXKAGKCAGI0`X9ZBX9^"X9Z;X9Z?X9ZVX9Z;X9^+X9Z<X9^)X9ZVX9Z,X9^0
MX9Z:`.&>HN&?BN&>N.&>F.&?@N&>FP#AGJ+AGK;AGI_AGIGAGHKAGY+AGHOA
MGK;AGI/B@(OAGJ+AGXKAGKCAGICAGX+AGIL`X9ZBX9ZVX9Z?X9Z9X9Z*X9^2
MX9Z+X9ZVX9Z3XH"+X9ZBX9^*X9ZXX9Z8X9^"X9Z;XH"+X9Z/X9^2X9Z:X9Z\
MX9Z<XH"+X9Z/X9^"XH"+X9Z*X9Z\X9Z%X9Z"X9^2X9Z3X9ZVPJ#AGY0`X9Z?
MX9Z)X9^2X9Z)X9ZVXH"+X9ZBX9ZVX9Z:X9Z8X9^2X9Z8X9Z.X9^-`.&>H.&?
MDN&>@N&>N.&>CN&?@>*`B^&>HN&?@>&>@.&?DN&>G.&>MN&>D>&?D.&>F@#A
MGJ+AGX'AGIKAGKCAGI'AGY+AGIKAGK8`X9Z`X9^&X9Z@X9Z[X9Z?`.&>HN&?
M@>&>G^&?DN&>C^&>O.&>D^&>N`#AGJ+AGX'AGH_AGY+AGIGAGKSAGI;AGK@`
MX9ZBX9ZZX9Z:X9^)X9Z[X9Z4`.&>FN&?@.&>A.*`B^&>FN&>MN&>F^&?B^*`
MBR#AGZ'AGZ4@X9Z3X9ZVX9Z1X9ZX`.&>FN&?@.&>A.*`B^&>FN&>MN&>F^&?
MB^*`BR#AGZ/AGZ`@X9Z<X9ZWX9Z3X9ZVX9Z1X9ZX`.&>FN&?@.&>A.*`B^&>
MFN&>MN&>F^&?BR#AGZ4@X9Z3X9ZVX9Z1X9ZX`.&>FN&?@.&>A.*`B^&>FN&>
MMN&>F^&?B^*`B^&>@.&>D^&?DN&>F^&?A^*`B^&>F.&?B>&?A.&>A`#AGIKA
MGX#AGH3B@(OAGIKAGK;AGIOAGXOAGI/AGK;AGI'AGK@`X9Z4X9^2X9Z:X9Z/
MX9ZWX9Z4X9Z/X9^2X9Z/X9ZW`.&>E.&>D^&?DN&>F^&>MN&>F0#AGJ+AGXKA
MGK?AGH7AGI_AGY+AGI3AGKSAGH[AGH3AGXOAGI_AGX+AGIL`X9Z`X9^$X9^'
MXH"+X9Z@X9^2X9Z<X9^)X9Z`X9ZAX9Z$X9^+("CAGICAGXGAGK;AGIOAGXOA
MGISAGKCAGH[AGK8I`.&>@.&?A.&?A^&>H.&?DN&>G.&>MN&>HN&?@>&>FN&>
MO`#AGI'AGKSAGIKAGI_AGK;AGIH`X9Z`X9Z[X9Z8X9^2X9Z7X9^(`.&>H.&?
MDN&>G.&>N.&>H.&?DN&>G^&?BN&>N`#AGJ_AGH#AGI_AGK;AGIH`X9Z(X9^2
MX9Z8X9^$X9^'XH"+X9ZOX9Z`X9Z?X9ZVX9Z:`.&>C^&>F.&?DN&>FN&>A`#A
MGJ#AGY+AGISAGK;AGX;AGH3AGJ'AGH3AGXL`X9Z/X9^2X9Z:X9ZAX9Z4X9^+
M`.&>D>&>G^&>E^&>MN&>@@#AGI;AGH[AGXSB@(OAGI;AGKOAGICAGY+AGI;B
M@(OAGJ+AGH#AGY+AGI_AGIH`X9Z?X9^&X9Z.X9Z[X9^&XH"+XH"+X9Z4X9^"
MX9Z4X9Z4X9Z1`.&>G^&?BN&>N^&>F`#AGI3AGK;AGIKAGK;AGX;AGH0`X9Z@
MX9^2X9Z"X9Z\X9ZBX9^*X9ZXX9Z9X9^)X9ZVX9Z.X9ZV(.&>E.&>MN&>FN&>
MMN&?AN&>A`#AGI3AGXGAGKSAGIOAGKCAGI/AGX'AGI_AGXKAGKCB@(OAGI3A
MGK;AGIKAGK;AGX;AGH0`X9ZBX9ZVX9Z.X9Z%X9Z`X9^2X9Z:XH"+X9Z!X9ZV
MX9Z$XH"+X9Z/X9^2X9Z4X9Z\X9Z$(.&>E.&>MN&>FN&>MN&?AN&>A`#AGI;A
MGK@`X9Z(X9^2X9Z8X9^$X9^'XH"+X9Z6X9^!X9Z)`.&>H.&?DN&>@N&>MN&>
ME.&>N^&>A`#AGJ#AGY+AGH#AGK;AGX;AGI3AGXKAGK@`X9Z@X9^2X9Z?X9Z`
MX9Z@X9^2X9Z?X9^*X9ZX`.&>HN&>MN&>F^&?DN&>F^&>NN&>F.&?B>&>A.&?
MBP#AGJ#AGY+AGH#AGK;AGH[AGK8`X9Z@X9^2X9Z"X9ZXX9Z4X9^2X9Z:X9ZV
MX9Z;X9^+X9Z/X9ZV`.&>D^&>MN&>F.&>@>&?DN&>F^&>O>&>DP#AGH?AGICA
MGY+AGIKAGK[AGI_B@(OAGI_AGH#AGIL`X9Z1X9^%`.&>F.&>MN&>C^&?DN&>
MFN&>BN&?DN&>B^&>MN&>D^*`B^&>E.&?DN&>FN&>E>&?@>&?AP#AGH#AGY+A
MGIKAGK?AGH``X9Z`X9^2X9Z:X9ZWX9Z`("A)4T\M.#@U.2TW*0#AGH+AGY+A
MGIKAGKCAGJ'AGH3AGXL`X9Z@X9^2X9Z"X9^2X9Z:X9ZXX9Z.X9ZVX9Z*X9ZV
M`.&>@.&?DN&>FN&>N^&>F`#AGJ#AGY+AGH+AGKSAGJ+AGK;AGHKAGKKAGIOA
MGKSAGI3AGXGAGX$`X9Z@X9^2X9Z"X9ZVX9^&X9Z8`.&>H.&?DN&>@N&>MN&>
MC^&?@>&>F.&?B>&>MN&>H>&>M@#AGJ#AGY+AGH+AGKCAGH[AGX$`X9Z@X9^2
MX9Z"X9ZXX9Z.X9^!X9Z4X9^*X9ZXX9Z?X9^%`.&>H.&?DN&>@N&>N.&>F>&?
MB>&>MN&>CN&>M@!(5$U,`.&>H.&?@^&>D>&>N`#AGI3AGHOAGICAGH#AGI#A
MGK;B@(L`X9Z4X9Z+X9Z8X9Z`X9Z0X9ZV`.&>@.&?A.&?A^*`B^&>H.&?BN&>
MON&>BB#AGI/AGK?AGH0@X9Z`X9^$X9^'XH"+X9Z8X9^)X9ZVX9Z`X9Z*X9Z\
MX9Z.X9ZVX9Z;X9^+`.&>@.&>F.&?DN&>EN&>G^&?BP#AGH?AGX;AGI/AGKWA
MGID`X9Z!X9^2X9Z6X9Z?X9^+`.&>H.&>O.&>F^&>N.&>G^&?BN&>N"`HX9Z:
MX9Z*X9^2X9Z+XH"+X9Z`X9^2X9Z:X9Z[X9Z$XH"+X9Z<X9^)X9ZVX9Z1X9ZX
MX9Z`X9Z$X9^+*0#AGH+AGX'AGJ#AGI'AGX;AGI;AGY#AGIH`X9ZBX9ZVX9Z?
MX9Z9X9Z*X9^2X9Z+X9ZVX9Z3XH"+X9Z5X9^2X9Z1X9^'`.&>D.&>C^&>E>&?
MDN&>D>&?AP#AGI'AGKSAGIKAGI_AGY#AGI;AGY+AGI'B@(OAGI7AGY+AGI'A
MGX<`X9Z@X9Z[X9Z$X9Z,X9Z\X9Z:X9^)X9ZVX9Z?X9^+`.&>H.&>N^&>A.&>
M@.&>N^&>A`#AGJ#AGKOAGH3AGH+AGY+AGIKAGK@`X9ZBX9ZVX9Z?X9Z9X9Z*
MX9^2X9Z+X9ZVX9Z3XH"+($E0`.&>HN&?BN&>N.&>G^&?DN&>F^&>A.&?BP#A
MGH_AGX+B@(OAGIKAGKSAGI3AGH_AGX;AGH[AGK;AGH0`X9Z:X9Z\X9Z4X9Z7
MX9ZVX9Z6`.&>E.&>A.&?DN&>@.&>ON&>D^*`B^&>@.&>MN&>FN*`B^&>A>&>
MO.&>F^*`B^&>E.&>D^&?DN&>D>&>MN&>C^&?BP#AGJ7AGH[AGY+AGHSAGK8`
MX9ZEX9Z.X9^2X9Z,X9Z\X9Z3X9^!X9Z?X9^*X9ZX`.&>EN&?D.&>C^&?C.&>
MF.&>MN&>DP#AGI;AGY#AGH_AGXSAGICAGK;AGI,`X9Z4X9Z)X9^2X9Z%X9Z\
MX9Z;XH"+X9Z/X9ZVX9Z:X9ZVX9Z$`.&>A>&?AN&>D^&>O>&>D^*`B^&>@N&>
MC^&?BP#AGJ+AGXKAGKCAGIKAGXGAGK;AGH#AGXL`X9ZBX9^`X9Z:X9ZAX9Z$
MX9^+`.&>HN&?BN&>N.&>G^&?DN&>FN&>MN&>HN&?@N&>FP#AGJ+AGY+AGI/A
MGH#B@(OAGH7AGX'AGHD`X9Z1X9^2X9Z:X9^!X9Z/`.&>HN&?BN&>N.&>C^&>
MMN&>F^&>N`#AGH7AGK;AGICAGXGAGX/AGH#AGK8`X9Z8X9Z`X9Z:X9ZV`.&>
MA^&>E.&?B>&>N^&>DP#B@(OAGH?AGI3AGXGAGKOAGI,@*$E33RTR,#(R+4I0
M*0#AGJ#AGY+AGI_AGXKAGH#AGHKAGK;AGI/AGK@`X9Z`X9Z`X9^2X9Z`X9Z*
MX9ZV`.&>F.&>M^&>D.&>N^&>D^&>M@#AGH_AGICAGY+AGIKAGKGAGICB@(OA
MGI_AGH3B@(OAGH'AGK;AGH0`X9Z`X9ZVX9Z@X9^2X9Z?X9ZVX9Z`X9^+X9Z?
MX9^2X9Z/X9Z$X9^+`.&>@.&?@N&>D^&>F>&?B>&>M@#AGI3AGY+AGIKAGISA
MGX+AGH3B@(OAGH#AGKSAGI/AGI_AGX0`X9Z4X9^2X9Z:X9Z7X9^!X9Z1XH"+
MX9Z"X9^2X9Z:X9ZVX9Z4X9^+XH"+X9Z%X9Z[X9Z%`.&>@N&>M^&>FN&>M^&>
ME.&>MN&>D>&>N`#B@(OAGH#AGKSAGIKAGXGAGX$@*$550RU+4BD`X9Z"X9Z[
MX9Z9XH"+X9Z<X9^)X9^"X9Z/`.&>@N&?@.&>FN&>H.&?DN&>@N&>N.&>G^&?
MDN&>C^&>A.&?BP#AGI?AGK;AGI_AGK8`X9Z?X9ZVX9Z2X9ZVX9Z:X9Z.X9Z:
MX9Z*X9^2X9Z+XH"+X9Z4X9^2X9Z:X9Z'X9ZVX9Z2X9ZWX9Z4X9Z/X9^!X9Z9
MX9^2X9Z9XH"+X9Z4X9^2X9Z:X9Z'X9ZVX9Z8X9ZVX9Z3X9ZWX9Z/XH"+X9ZA
MX9ZVX9Z<`.&>H>&>MN&>C^&>G.&>N.&>F>&?B>&>M@#AGI3AGY+AGIOAGH3A
MGXOB@(L`X9Z;X9ZXX9Z4X9Z$X9^+`.&>AN&?DN&>G.&?@>&>A`#AGJ'AGX'A
MGI_AGKSAGH_AGKP`X9Z`X9Z8X9^2X9Z:X9ZWX9Z/`.&>F^&>N.&>E.&?@>&>
MFN&>N.&>F>&?B>&>M@#AGH7AGK;AGICAGXGAGK;AGJ+AGXKAGK?AGIKAGKCA
MGIGAGXGAGK;B@(OAGJ+AGK;AGIKAGXGAGK;AGI3AGXL@X9Z;X9ZXX9Z4X9^*
MX9ZX`.&>F^&>M^&>A>&>D>&?@>&>D^&>G^&?DN&>C^&?@N&>DP#AGH_AGX;A
MGHX`X9Z/X9^&X9Z.`.&>F^&>N.&>D>&>N^&>F>&>HN&>MN&>D^&>N`#AGH#A
MGX;AGI;AGKOAGH3B@(OAGI7AGY+AGI'AGKOAGH`N+BX`X9Z1X9ZXX9Z/X9ZV
MX9^&X9Z$`.&>A>&>O.&>FP#AGH7AGX'AGHD`X9Z%X9Z\X9Z;`.&>E^&>MN&>
MFN&>@.&>M^&>A>&?DN&>A>*`B^&>A>&>O.&>FP#AGI_AGX'AGH7AGH#AGY+A
MGH_AGKCB@(OAGI_AGY+AGIKAGJ'AGK;AGHGAGXL`X9Z1X9ZVX9Z4`.&>F^&>
MN^&>A>&>H.&?DN&>G^&?AN&>E.&>O>&>F@!-30#AGICAGXGAGK;AGH#AGK;A
MGIP`X9Z8X9^)X9ZVX9Z*X9ZVX9Z@X9^2X9Z`X9ZVX9Z?X9^2X9Z`X9ZVX9Z:
M`.&>G^&?AN&>E.&>N^&>C^&?DN&>F@#AGICAGXGAGK;AGJ'AGK;AGISAGX,`
MX9Z8X9^)X9ZVX9ZAX9^!X9Z?X9^*X9ZX`.&>F.&?B>&>MN&>F^&?B^&>C.&>
MN.&>G`#AGICAGXGAGK;AGIOAGK@`X9Z8X9^)X9ZVX9Z;X9^+X9Z/X9ZV`.&>
MF.&>N.&>D^&>M@#AGIKAGKGAGICB@(OAGI'AGX;AGI;AGY#AGIH`X9Z`X9^$
MX9^'($UA<G-H86QL`.&>F.&?B>&>MN&>FN&>D>&>N.&>D^&>N.&>@@#AGICA
MGXGAGKSAGIKAGKCAGH_AGK;AGI/AGK@`X9Z8X9^)X9Z\X9Z:X9ZXX9Z1X9Z[
MX9Z?`.&>I^&>G^&>E^&>M@#AGICAGX/AGJ+AGKSAGH_AGX$`X9Z?X9Z8X9ZV
MX9Z'X9ZWX9Z``.&>G^&>MN&>F@#AGISAGK?AGI+AGKCAGI_AGK;AGI_AGY+A
MGIKAGY+AGH\`X9Z8X9^)X9ZWX9Z%X9Z?X9^*X9ZWX9Z``.&>@.&>CN&?DN&>
MC^&>MN&>FP#AGI3AGY+AGIKAGI?AGX'AGI$@36EM90#AGH;AGY+AGIOAGKOA
MGX<`X9Z5X9^2X9Z?X9^!X9Z$X9^7XH"+`.&>F.&?B>&>O.&>CN&>MN&>@.&>
MO`#AGICAGXGAGKOAGH3AGJ#AGY+AGH+AGX3AGIOAGK@`X9Z!X9^"(.&>D^&>
MM^&>A"#AGH;AGY+AGI/AGK;AGX8`X9Z:X9ZVX9Z;X9^+XH"+X9Z!X9^"`.&>
MF.&?B>&>N^&>A.&>G^&?@>&>FN&?B>&>M@#AGICAGXGAGK;AGIKAGXGAGKOA
MGH``X9Z5X9^2X9Z;X9ZVX9Z?X9^+XH"+X9Z1X9ZXXH"+X9Z%X9Z[X9^'XH"+
MX9Z`X9^2X9Z:X9^$X9Z8`.&>E>&?DN&>F^&>MN&>G^&?B^*`B^&>D>&>N.*`
MB^&>D>&?A>*`B^&>AN&?DN&>G.&?@>&>A`#AGI7AGY+AGIOAGK;AGI_AGXOB
M@(OAGI'AGKCB@(OAGI'AGX7B@(OAGI_AGY+AGH_AGK;AGX8`X9Z5X9^2X9Z;
MX9ZVX9Z?X9^+XH"+X9Z1X9ZXXH"+X9ZAX9Z^X9Z$XH"+X9Z;X9Z^`.&>A>&>
MN^&?A^*`B^&>@.&?DN&>FN&?A.&>F`#AGJ'AGK[AGH3B@(OAGIOAGKX`X9Z8
MX9^)X9Z\X9Z@X9^2X9Z?X9ZVX9^&X9Z4X9^*X9ZWX9Z``.&>F.&>N.&>F>&?
MB>&>MN&>D^&?B^&>F.&?B>&>M@#AGHCAGY+AGICAGX3AGX<`X9Z.X9ZVX9Z8
MX9ZXX9Z4X9^*X9ZX`.&>CN&>O.&>FN&>NP#AGI/AGX'AGI3AGXGAGK;AGIOA
MGXL`XH"+X9Z@X9Z[X9Z;X9^2X9Z;X9Z$X9^+`.&>HN&>A.&?B^&>D>&>N.&>
MF>&?C>*`B^&>H.&>O.&>F^&?DN&>F^&>A.&?BP#AGI3AGH[AGY+AGH_AGK;A
MGHD`X9Z`X9Z[X9^&`.&>D^&>O.&>G.&?@N&>F^&>@.&>MN&>F^&?@>&>BN&>
MO.&>D^&>N`#AGI_AGK;AGIKB@(OAGI#AGY+AGICAGKCB@(OAGI'AGX4@)7,`
MX9Z3X9Z\X9Z<X9^"X9Z;X9Z@X9^*X9^2X9Z?X9^!X9ZAX9Z$X9^+`.&>EN&>
MMN&>@.&?DN&>F>*`B^&>G^&>F.&?DN&>A.&>MN&>C^&?B^*`B^&>D.&?DN&>
MF.&>N`#AGI;AGY#AGH_AGXSAGICAGK;AGI,`X9Z<X9^!X9Z1X9ZWX9Z`X9ZV
MXH"+X9Z6X9^0X9Z/X9^,X9Z8X9ZVX9Z3`.&>E.&>D^&?DN&>D>&>MN&>E.&?
MBP#AGI/AGKCAGH#AGK;AGIKAGXGAGK;AGJ#AGY+AGH+AGY#AGIH`X9Z3X9ZX
MX9Z@X9^2X9Z?X9^!X9Z:`.&>D^&>N.&>H.&?DN&>G^&?@>&>FN&>N.&>F>&?
MB>&>M@#AGIGAGI3AGXL`X9Z3X9ZXX9Z<`.&>D>&?@0#AGH+AGY+AGICAGK;A
MGI,`X9Z`X9^$X9^'XH"+X9Z.X9^)X9Z@X9^2X9Z<X9^)X9Z``.&>@.&?A.&?
MA^*`B^&>F.&?B>&>MN&>FN&?@.&>CN&>MN*`B^&>E^&>MN&>@N*`B^&>@>&>
MMN&>A.*`B^&>A^&>ON&>A`#AGI/AGY#AGIKAGISAGX+AGI\`X9Z%X9^&X9Z.
MX9ZVX9^&`.&>G.&>M^&>A>&?DN&>AN&>M^&>@.&>M@#AGIOAGX'AGH$`X9Z%
MX9^&X9Z3X9Z]X9Z3XH"+X9Z/X9Z]X9ZBX9Z`X9^2X9Z?X9Z:`.&>F>&>F^&?
MB^&>EN&?DN&>FN&>F`#AGISAGH_AGY+AGI#AGKL`X9Z/X9Z[X9Z;X9ZV`.&>
M@.&>MN&>FN&>M^&>F>&>MN&>F^&?D.&>F0#AGI;AGK;AGH#AGY+AGIGB@(OA
MGI_AGICAGY+AGH3AGK;AGH_AGXOB@(OAGH7AGK;AGI_AGXL`X9ZBX9Z\X9Z8
MX9^"X9Z3`.&>E.&>ON&>@.*`B^*`B^&>@.&?DN&>D^&>N^&>A.*`B^*`B^&>
ME.&>A.&?DN&>HN&>O>&>A>*`B^&>D.&?DN&>F.&>N`#AGI3AGY+AGIKAGI;A
MGY#AGI/AGY+AGI+B@(OAGI3AGY+AGIKAGH_AGK?AGI3AGH_AGY+AGH_AGK?A
MGH#AGK;AGIH`X9Z'X9Z8X9^2X9Z:X9Z^X9Z?XH"+`.&>E>&?DN&>G^&?@>&>
MA.&?EP#AGH7AGI/AGY+AGIOAGX3AGX<`X9Z4X9^)X9ZVX9Z"X9ZXX9Z?X9^2
MX9Z0X9ZVX9Z3`.&>E.&?B>&>MN&>H>&>O`#AGI3AGXGAGK;AGH[AGK;AGICA
MGXGAGK8`X9Z4X9^)X9ZVX9Z6X9Z\X9Z)X9Z\X9Z<X9Z@X9^2X9Z"X9ZXX9Z.
MX9^!`.&>E.&?B>&>MN&>FN&?B>&>MN&>H.&?DN&>@N&>MN&>F0#AGI;AGK;A
MGH#AGY+AGIGB@(OAGI_AGICAGY+AGH3AGK;AGH_AGXL`X9Z6X9ZVX9Z`X9^2
MX9Z9XH"+X9Z?X9Z8X9^2X9Z$X9ZVX9Z/X9^+PJ#AGY8`X9Z4X9ZWX9Z1X9Z7
MX9^2X9Z'X9ZVX9Z4X9^+`.&>E>&?DN&>F^&>O.&>G`#AGICAGI/AGKOAGI_A
MGY+AGI\`X9Z7X9ZVX9Z"X9Z:X9Z9`.&>DN&?DN&>G.&>ON*`B^&>E.&?DN&>
MFN&>C^&>M^&>E.&>C^&?DN&>C^&>M^&>@.&>MN&>FN*`B^&>C^&?AN&>H.&?
M@N&>D>&>MN&?AB#AGI;AGX'AGIOB@(OAGH7AGKSAGIL@/P#AGI_AGK?AGI'A
MGY+AGI+AGK<`X9Z?X9ZWX9Z1X9^2X9Z2X9ZW`.&>EN&?D.&>C^&?C.&>F.&>
MMN&>D^*`B^&>E>&?DN&>D>&>MN&>F^&?B^*`B^&>@>&?DN&>F^&>O>&>DP#A
MGI3AGXGAGX'AGIKAGXGAGKP`X9Z@X9^2X9Z<X9ZXX9Z;X9ZXX9Z6X9ZXX9Z3
M`.&>D>&>O.&>FN&>G^&?D.&>EN&?DN&>D0#AGI;AGKCAGH_AGH'AGK;AGIGA
MGIKAGK?AGI,`X9Z7X9ZXX9Z`X9Z?X9^"X9Z;`.&>E.&?B>&>O.&>H>&>O.&>
MB0#AGI;AGY#AGIKAGI'AGKOAGIGAGJ#AGY+AGH+AGK;AGIOAGXL`X9Z?X9Z8
MX9^2X9Z6X9ZVX9Z2`.&>F.&>ON&>F^*`B^&>A^&>MN*`B^*`B^*`B^&>F.&>
MN^&>DP#AGH+AGICAGY+AGIKAGX3AGH0`X9Z`X9Z\X9Z3X9Z?X9^$XH"+X9Z?
MX9ZVX9Z2X9ZVX9Z:X9Z.X9^(`.&>EN&?D.&>FN&>C^&>O.&>FN&>N.&>@.&>
MO`#AGH#AGK;AGH_AGK8`X9Z?X9^&X9Z.X9Z]X9Z:XH"+`.&>@.&>O.&>C^&>
MM@#AGJ+AGK;AGI,`X9Z2X9^2X9Z<X9Z^XH"+X9ZRX9^2X9Z9XH"+X9Z?X9^2
MX9Z:X9Z?X9^+`.&>HN&>C^&?DN&>FN&>MN*`B^&>DN&?DN&>G.&>ON*`B^&>
MLN&?DN&>F>*`B^&>G^&?DN&>FN&>G^&?B\*@X9^6`.&>E>&?DN&>D>&>N^&>
M@.*`B^&>H>&>ON&>A.*`B^&>G.&>M^&>B0#AGH#AGX;AGH[AGH_AGXOB@(OA
MGI_AGICAGY+AGH+AGK;AGIOAGXL`X9Z9X9Z`XH"+X9Z%X9^!X9Z)`.&>@.&?
MAN&>CN&>C^&?B^*`B^&>H>&>ON&>A.*`B^&>G.&>M^&>B0#AGIOAGI'AGY+A
MGI+B@(OAGI7AGIL`X9Z/X9^2X9Z:X9ZAX9Z4X9^+XH"+X9Z1X9^%XH"+X9Z'
MX9Z8X9^2X9Z:X9Z^X9Z?`.&>FN&>N.&>HN&>N^&>F>&>D^&>N.&>F>&?B>&>
MN^&>A`#B@(OAGI_AGY+AGH_AGK;AGX8`X9Z/X9Z]X9Z3X9ZVX9Z1X9ZX`.&>
MFN&>O.&>F.&?B>&>MN&>D^&>N`#AGI3AGH3AGY+AGISAGK?AGIOB@(OAGI'A
MGX7B@(OAGH;AGY+AGISAGX'AGH0`X9Z4X9Z$X9^2X9Z<X9ZWX9Z;XH"+X9Z1
MX9^%XH"+X9Z?X9^2X9Z*X9ZVX9^&`.&>A^&>O>&>FN*`B^&>BN&?@>&>@,*@
MX9^6`.&>FN&>C^&?B^*`BP#AGI_AGJ#AGI;AGY#AGI/AGY+AGI+B@(OAGIKA
MGKOAGI_AGY+AGI_AGXKAGK@`X9Z:X9Z<X9^)X9ZVX9Z3X9^+X9Z*X9ZV`%-3
M2`#AGI_AGH3AGXOB@(OAGJ#AGX'AGJ'AGX'AGH[AGK8`X9Z?X9Z$X9^+X9Z#
MX9ZXX9Z/(.&>D^&>M^&>A"#AGI/AGX'AGISAGKCAGI\`X9Z?X9Z$X9^+X9Z;
MX9Z\X9Z?X9^*X9ZXX9Z9X9^)X9ZV`.&>G^&>A.&?B^*`B^&>EN&?DN&>F>&?
M@N&>FB#AGI/AGK?AGH0@X9Z8X9ZXX9Z"X9Z[X9Z9X9ZBX9^!X9ZAX9Z[X9Z$
M`.&>G^&>A.&?B^&>G.&>MN&?AN&>A.&>G^&>A.&?BR#AGI/AGK?AGH0@XH"+
MX9Z@X9^2X9Z"X9^2X9Z:X9ZXX9Z.X9ZVX9Z,X9ZXX9Z3`.&>G^&>MN&>F.&>
MO.&>HN&>M@#AGI_AGK;AGI/AGXOAGICAGXGAGK;AGIKAGKCAGH[AGKP`4V%O
M(%1O;64@86YD(%!R:6YC:7!E`.&>HN&>MN&>FN&?B>&>MN&>E.&?B^*`B^&>
ME.&?BN&>N.&>G^&>MN&>HN&>O.&>C.&>N`#AGIKAGH#AGY+AGI_AGK;B@(OB
M@(OAGI'AGKOAGH#B@(OB@(L`X9Z:X9Z`X9^2X9Z?X9ZVXH"+X9Z1X9Z[X9Z`
MXH"+(.&>A^&>F.&?DN&>FN&>ON&>GP#AGI_AGY+AGISAGX+AGH3AGIKAGH``
MX9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3XH"+X9Z?X9^2X9Z<X9^"X9Z$X9Z:X9Z`
M`.&>A^&?DN&>FN&>ON&>G^*`B^&>@.&>MN&>F^&>E.&>FN&>M^&>A>&?DN&>
MAN&?@>&>D0#AGH?AGY+AGIKAGK[AGI_B@(OAGI'AGK;AGX;AGH3AGJ+AGI_A
MGXL`X9Z'X9^2X9Z:X9Z^X9Z?XH"+X9Z"X9^2X9Z8X9ZVX9Z3`.&>G^&?@>&>
MCN&?@>&>H.&?DN&>@N&>MN&>F^&?BP#AGH#AGHGAGY+AGHGAGK8`X9Z?X9^"
MX9Z4X9^*X9ZX(.&>D^&>M^&>A"#AGICAGXGAGKOAGH3AGH_AGX'AGH[AGX'A
MGJ#AGY+AGH#AGY+AGIKAGKP`X9Z;X9^!X9Z!XH"+X9Z?X9Z8X9^2X9Z"X9ZV
MX9Z;X9^+`.&>G^&>F.&?D.&>F0#AGH#AGX;AGH[AGH_AGXL`X9Z*X9^&X9ZA
MX9Z^X9Z$`.&>G^&>N.&>G^&?DN&>H.&?@N&>FP#AGI3AGH3AGY+AGJ#AGK;A
MGHD`X9Z4X9Z$X9^2X9Z:X9Z]X9Z)`.&>G^&?@>&>FN&?B>&>MN&>H>&?@>&>
MHN&>O.&>DP#AGJ#AGH_AGY+AGI#AGIOAGX'AGH'AGK8`X9Z?X9ZYX9Z$X9^2
MX9Z@X9Z4X9Z[X9Z:X9ZX`.&>D>&?AN&>H.&?A@#AGI_AGY+AGIOAGKSAGISA
MGXGAGK;AGH+AGK@`X9Z?X9^2X9Z;X9Z\X9Z<X9^)X9ZVX9Z3X9ZX`.&>@.&?
MA.&?A^*`B^&>G^&>O.&>H>&>O.&>F.&?B>&>O.&>DP#AGI_AGKSAGICAGXGA
MGK;AGIOAGK@`X9ZBX9ZVX9Z@X9^2X9Z:X9ZWX9Z`XH"+XH"+X9Z!X9ZVX9Z$
MXH"+X9Z/X9^2X9Z4X9Z\X9Z$`.&>H.&?DN&>G^&>@.&>H.&?DN&>G^&?BN&>
MN.*`B^&>@>&>MN&>A.*`B^&>C^&?DN&>E.&>O.&>A"#AGI/AGK?AGH0@X9Z`
MX9^$X9^'X9Z?X9ZVX9^&X9Z$X9Z<X9ZWX9Z%XH"+X9Z!X9ZVX9Z$XH"+X9Z/
MX9^2X9Z4X9Z\X9Z$`.&>@N&>F.&?DN&>F^&>MN&>CP#AGJ+AGX'AGI_AGXGA
MGY+AGI3AGK;AGHD`X9Z?X9ZVX9Z:XH"+X9ZEX9Z/XH"+X9Z4X9ZVX9Z3XH"+
MX9Z`X9ZVX9Z:`.&>G^&?DN&>FN&>N.&>F^&>A.&?DN&>@.&>M@#AGH'AGY+A
MGI/AGK;AGH_B@(OAGH+AGX;AGIKAGKP`X9Z?X9^2X9Z0X9ZVX9Z3X9Z7X9ZV
MX9Z6`.&>E.&>D^&?DN&>D>&>MN&>C^&?B^*`B^&>AN&>O.&>CP#AGI3AGY+A
MGIKAGI+AGK;AGI/B@(OAGI3AGI$`X9Z*X9ZVX9Z`X9^+XH"+X9Z?X9^2X9Z3
MX9Z^`.&>HN&>@.&?DN&>G^&>FN*`B^&>C^&>O.&>A>*`B^&>@.&?DN&>FN&?
MA.&>F`#AGH?AGX3AGH+AGH?AGY#AGID`X9Z?X9^*X9Z\X9Z*X9Z$X9^+`.&>
MG^&>A.&?DN&>@>&?@>&>E`#AGJ+AGH#AGY+AGI_AGIKB@(OAGH_AGKSAGH7B
M@(OAGIOAGKX`X9Z"X9ZVX9^&X9Z1X9^2X9Z:`.&>G^&?BN&>O.&>FN&>N.&>
MCN&>MN&>F.&>N`#AGI_AGY+AGISAGK;AGIOAGXOAGI3AGK;AGH\@X9Z3X9ZW
MX9Z$(.&>H.&?DN&>G^&>A.&?B^&>F.&?B>&>MN&>F>&?@>&>DP#AGI_AGY+A
MGISAGK;AGJ#AGY+AGI_AGXKAGKCAGJ'AGH3AGXL`X9Z?X9^*X9Z[X9Z9X9ZB
MX9^"X9Z*`.&>G^&?DN&>G.&?BN&>N.&>GP#AGI_AGK;AGI+AGK;AGIKAGH[A
MGIKAGHKAGY+AGHOB@(OAGJ+AGK;AGIKAGXGAGK;AGI3AGXL@X9Z?X9^*X9ZX
MX9Z:X9ZX`.&>C^&>MN&>FN&>MN&>A`#AGIOAGH#AGY+AGH'AGH[AGXCB@(OA
MGI_AGICAGY+AGI3AGH_AGY+AGH_AGK?B@(OAGH_AGK;AGIKAGK;AGH0`X9Z;
MX9Z`X9^2X9Z!X9Z.X9^(XH"+X9Z?X9Z8X9^2X9Z4X9Z/X9^2X9Z/X9ZWXH"+
MX9Z:X9Z4X9Z?X9^+XH"+XH"+X9Z/X9ZVX9Z:X9ZVX9Z$`.&>C^&?@^&>G.&?
MB>&>MN&>D^&?BP#AGH_AGK;AGHKAGJ#AGY+AGI_AGXKAGKCAGH+AGKCAGI_A
MGY+AGH_AGH3AGXL`X9Z7X9ZVX9Z:X9Z`X9ZWX9Z%X9^2X9Z%`.&>F^&?@>&>
M@>*`B^&>D>&>O.&>FN&>G^&?D.&>EN&?DN&>D0#AGI_AGKCAGH_AGKOAGH[A
MGY+AGJ#AGI?AGK;AGI8`X9ZBX9Z/X9^2X9Z0X9Z4X9Z1`.&>C^&?@N&>HN&>
MC^&?DN&>D.&>E.&>D0#AGI#AGX,`X9Z8X9ZVX9Z3XH"+X9Z`X9^&X9Z@X9Z[
MX9Z?XH"+X9Z8X9Z]X9Z9(.&>@.&?DN&>D^&>N^&>A.*`B^&>@.&>MN&>FN*`
MB^&>E.&>A.&?DN&>H.&>MN&>B>*`B^&>E>&?DN&>D^&?@N&>@.*`B^&>FN&>
ME.&>G^&?B^*`B^&>G^&>MN&>FN*`B^&>D^&?@>&?AP#AGI;AGX'AGIOB@(OA
MGISAGX'AGIOAGK;B@(L`X9Z1X9^2X9Z:X9Z$X9^+XH"+X9Z1X9^2X9Z:X9ZV
MX9Z9XH"+XH"+XH"+XH"+X9Z6X9^!X9Z;XH"+XH"+X9Z<X9^!X9Z;X9ZVXH"+
M`.&>A>&?AN&>CN&>A.*`B^&>A^&>ON&>A`#AGI'AGX4`X9Z0X9^2X9Z$X9^#
MXH"+X9Z3X9^!X9^'`.&>C^&>O.&>H.&?DN&>@N&?A`#AGH_AGKSAGH#AGX'A
MGJ'AGK;AGJ+AGXKAGKP`X9Z/X9Z[X9Z$X9Z@X9^2X9Z"X9^$`.&>@.&?AN&>
MEN&>O.&>FP#AGI'AGY+AGIKAGKCAGI/AGKCAGHKAGK;AGHH@X9Z3X9ZWX9Z$
MXH"+XH"+(.&>C^&>O.&>E.&>MN&>H.&?DN&>@N&?A`#AGI'AGKOAGIGAGH[A
MGX'AGI_AGXKAGK@`X9Z1X9Z]X9Z:X9Z"X9ZX`.&>D>&>O>&>FN&>@N&>N"`H
M25-/+3@X-3DM.2D`X9Z1X9Z]X9Z"X9Z8X9^!X9Z3X9ZXX9Z?X9^2X9Z/X9Z$
MX9^+`.&>@.&?A.&?A^*`B^&>D>&>O>&>@"#AGI/AGK?AGH3B@(L@X9Z`X9^#
MX9Z`X9Z\X9Z?`.&>D>&>N^&>F>&>G.&?B>&>MN&>F^&>N^&>F0!54DP`55),
M.@#AGJ+AGXKAGKSAGJ#AGY+AGH+AGH3AGXOAGHKAGK8`X9ZBX9^*X9Z[X9Z9
MX9Z`X9^2X9Z:X9^"X9Z3`.&>@N&>O.&>G^*`B^&>E.&>D^&?DN&>D>&>MN&>
MC^&?B^*`B^&>@.&?DN&>FN&?A.&>F`#AGICAGK?AGI/B@(OAGI3AGK;AGI/B
M@(OAGIKAGX#AGI3AGH7AGX8`X9Z9X9Z\X9Z3X9ZXX9Z`X9Z\X9Z*("A55$8M
M."D`X9ZBX9ZVX9Z:X9^)X9ZVX9Z4X9^+XH"+X9Z:X9Z]X9Z8`.&>A>&>@.&?
MDN&>FN*`B^&>E^&>EN*`B^&>HN&>A.&?B^&>@N&?DN&>F^&?@>&>GP#AGI_A
MGJ#AGIKAGHKAGY+AGHOAGJ+AGK;AGICAGX'AGIKAGK?AGH``X9Z`X9^$X9^'
MXH"+X9Z&X9^2X9Z$X9ZVX9Z9X9^7XH"+X9Z:X9Z4X9Z?X9^+XH"+X9Z?X9Z@
MX9Z:X9Z*X9^2X9Z+XH"+X9ZBX9ZVX9Z8X9^!X9Z:X9ZWX9Z``.&>K^&>@.&>
MC^&>M@#AGICAGK?AGI/B@(OAGI_AGY+AGH+AGK;AGIOAGXL`X9Z"X9^2X9Z8
MX9ZVX9Z3XH"+X9Z(X9^2X9Z8X9^$X9^'`.&>DN&?DN&>G.&>ON*`B^&>LN&?
MDN&>F>*`B^&>D>&>MN&>D^&?B^*`B^&>G^&>F.&?D.&>F0#AGI7AGY+AGI'A
MGKOAGH#B@(OAGJ'AGK[AGH0`X9ZBX9^*X9Z[X9Z9X9Z:X9^)X9ZVX9Z@X9^2
MX9Z"X9ZVX9Z9`.&>HN&?DN&>D^&>@.*`B^&>E.&?DN&>FN&>O@#AGH#AGK;A
MGIKB@(OAGH+AGY+AGIKAGI3AGXOAGH+AGY+AGIKAGH3B@(OAGJ+AGY+AGI/A
MGH#B@(OAGI3AGY+AGIKAGKX`X9Z(X9^2X9Z8X9^$X9^'XH"+X9ZBX9^2X9Z3
MX9Z`XH"+X9Z4X9^2X9Z:X9Z^`.&>B.&?DN&>F.&?A.&?A^*`B^&>HN&?DN&>
MD^&>@.*`B^&>E.&?DN&>FN&>OL*@X9^6`.&>HN&?BN&>O.&>H.&?DN&>G^&>
ME.&?@>&>@N&>N.&>G^&?DN&>C^&>A.&?BP#AGI_AGKOAGI;AGIOAGI?AGK;A
MGI8`X9Z/X9Z8X9^2X9Z;X9^#`.&>G.&?B>&>MN&>D^&>N^&>F>&>HN&>MN&>
MD>&>N^&>F0#AGJ+AGI#AGX'AGIH`X9Z<X9^!X9Z.X9^!X9Z@X9^2X9Z?X9Z[
MX9Z9X9ZBX9^!X9ZAX9ZV`.&>@.&?AN&>CN&?@@#AGH#AGK;AGIKB@(OAGH_A
MGY+AGIKAGKWAGH_B@(OAGI;AGK?AGI/AGK?AGH_AGY+AGIGB@(OAGH#AGX;A
MGH[AGX(`X9Z8X9Z^X9Z;("5S`.&>@.&?A.&?A^*`B^&>G.&>N.&>A^&>N.&>
MDR#AGI_AGJ#AGIKAGHKAGY+AGHOB@(OAGJ+AGK;AGICAGX'AGIKAGK?AGH``
MX9Z<X9^)X9ZVX9Z;X9ZXX9Z?(.&>D^&>M^&>A"#AGJ#AGY+AGISAGXKAGKSB
M@(OAGI'AGKOAGIGAGH[AGK8`X9Z6X9^2X9Z:X9Z8X9ZVX9Z3`.&>G.&>M^&>
ME`#AGH_AGX;AGI3AGI/AGXOAGI3AGH[AGY+AGH_AGK;AGHD`X9Z:X9ZVX9Z;
MX9^+XH"+X9Z?X9Z4X9^2X9Z*X9ZVX9Z@X9^-`.&>G^&>O.&>F.*`B^&>G^&?
MDN&>G.&>MN&>@N&>F.&>D^&?C0#AGI_AGKSAGICB@(OAGI_AGY+AGISAGK;A
MGH+AGICAGI/AGXWB@(OAGICAGH#B@(OAGH#AGK;AGI/AGXL@)7,`X9Z?X9ZV
MX9Z@X9ZVX9Z:X9^)X9ZVXH"+X9Z!X9ZVX9Z$XH"+X9Z;X9ZWX9Z%`.&>D>&>
MD>&>N>&>A.*`BP#AGI'AGI'AGKGAGH0@X9^6`.&>E.&>B>&?DN&>A^&>N.*`
MB^&>E.&?DN&>FN&>MN&>D.&?DN&>D^&>M@#AGJ+AGK;AGI_AGIGAGHKAGY+A
MGHOAGK;AGI/B@(OAGH#AGI/AGY+AGIOAGX+AGH3B@(OAGI+AGY+AGISAGK[B
M@(OAGH#AGK;AGIH`X9Z1X9Z\X9Z:X9Z?X9^0X9Z6X9^2X9Z1XH"+XH"+XH"+
MX9Z`X9Z3X9^2X9Z;X9^"X9Z$XH"+XH"+XH"+X9Z2X9^2X9Z<X9Z^X9Z`X9ZV
MX9Z:`%E9`%E965D`X9Z4X9^2X9Z:X9Z%X9ZVX9^&X9Z&X9^2X9Z3X9ZVX9^&
M`.&>F>&?@>&>F.&?@N&>DP#AGI3AGK;AGI$OX9Z%X9ZVX9Z?`.&>B.&?DN&>
MF.&?A.&?A^*`B^&>FN&>E.&>G^&?B^&>HN&?DN&>D^&>@`#AGIGAGKSAGJ#A
MGY+AGH+AGX3AGI_AGY+AGIOAGK;AGISAGK@`X9Z?X9^#`.&>H.&?DN&>G^&>
MMN&?AN&>E.&?BN&>N`#AGJ#AGY+AGI_AGXKAGKCAGICAGI3AGK;AGISAGXGA
MGX$`7TSAGH7AGX'AGHD@`.&>F.&>M^&>D^*`B^&>G^&?DN&>@N&>MN&>F^&?
MB^*`B^&>HN&?DN&>D^&>@.*`B^&>D>&>D>&>O>&>F^*`B^&>G^&?AN&>E.&>
MN^&>C^&?DN&>F@#AGICAGK?AGI/B@(OAGJ+AGK;AGH7B@(OAGI3AGH3AGY+A
MGH#AGK[AGH_B@(OAGJ_AGH#AGI_AGK;AGIKB@(OAGIOAGI'AGY+AGI+AGI7A
MGIL`X9Z8X9ZWX9Z3XH"+X9ZBX9ZVX9Z%XH"+X9Z4X9Z^X9Z`XH"+X9Z6X9^0
MX9Z/X9^,X9Z8X9ZVX9Z3XH"+X9Z4X9Z)X9^2X9Z%X9Z\X9Z;`.&>@.&?AN&>
MH.&>N^&>G^*`B^&>@.&>MN&>FN*`B^&>E.&?DN&>FN&>ON*`B^&>E.&>D^&?
MDN&>D>&>MN&>C^&?B^*`B^&>EN&>MN&>@.&?DN&>F>&>E.&>B>&?DN&>A^&>
MM@#AGH#AGX;AGJ#AGKOAGI_B@(OAGH#AGK;AGIKB@(OAGH#AGX;AGH[AGH_A
MGXOB@(OAGIKAGH7AGI/AGK;AGI_AGICAGY+AGI;AGY#AGI/AGY+AGI(`X9Z4
MX9ZVX9Z/X9^+XH"+X9ZOX9Z`X9Z?X9ZVX9Z:XH"+X9Z4X9^2X9Z:X9Z6X9^0
MX9Z3X9^2X9Z2XH"+X9Z?X9^&X9Z!X9ZVX9Z3X9^+XH"+X9Z4X9^&X9Z5X9Z[
MX9Z/`.&>@.&?AN&>H.&>N^&>G^*`B^&>D>&?DN&>FN&>A.&?B^&>D>&?DN&>
MFN&>MN&>F>*`B^&>D>&>M^&>D^&?DN&>D^&>D^&?D.&>F0#AGIKAGH#B@(OA
MGICAGK?AGI/B@(OAGH/AGK[AGHGB@(OAGI+AGK;AGH_AGKOB@(OAGI3AGHGA
MGY+AGH7AGKSAGIL`:&@`X9Z8X9ZWX9Z3XH"+X9Z?X9^2X9Z"X9ZVX9Z;X9^+
MXH"+X9Z(X9^2X9Z8X9^$X9^'XH"+X9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3`.&>
M@.&?AN&>H.&>N^&>G^*`B^&>E.&>B>&?DN&>A>&?@>&>B2_AGI3AGHGAGY+A
MGH7AGKSAGIL`X9Z`X9^&X9Z@X9Z[X9Z?XH"+X9Z`X9Z8X9^2X9Z8X9Z<X9ZW
MX9Z2X9ZXXH"+X9Z!X9ZVX9Z$XH"+X9Z`X9^2X9Z:X9^%`.&>F"[AGI@N`.&>
MB.&?DN&>F.&?A.&?AP#AGI_AGK?AGI'AGY+AGI+AGK?B@(OAGH_AGY+AGIKA
MGKSAGISB@(OAGI3AGK;AGI/B@(OAGI3AGHKAGK?AGI_AGX'AGI(`X9Z7X9ZX
MX9Z`X9Z?X9^"X9Z;`.&>@.&?AN&>H.&>N^&>G^*`B^&>EN&>N.*`B^&>A>&>
MF.&?DN&>A.&>MN&>F>*`B^&>@.&?DN&>D^&>N^&>A.*`B^&>EN&>M^&>DN&>
MN.&>@.&>MN&>F@#AGICAGK?AGI/B@(OAGJ+AGK;AGH7B@(OAGIKAGH#B@(OA
MGI_AGX'AGISAGK;B@(OAGI3AGK;AGI,`<W,`X9Z`X9^&X9Z@X9Z[X9Z?XH"+
MX9Z4X9^2X9Z:X9Z6X9^0X9Z3X9^2X9Z2`.&>E.&>FN&>MN&>A^&?D.&>F>*`
MB^&>E.&>CN&?DN&>BN&?A.&?A^&>HN&>MN&>G^&>D^&?DN&>DP#AGICAGK?A
MGI/B@(OAGI_AGY+AGH+AGK;AGIOAGXOB@(OAGH#AGX;AGJ#AGKOAGI\`X9Z"
MX9^2X9Z8X9ZVX9Z3XH"+X9Z(X9^2X9Z8X9^$X9^'`'9#87)D````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]A
M<E]360``````````````````````````````````````````````````````
M```````````````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<T,"`P,3<W,S(`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&]C86QE+V%R7U-9+TQ#7TU%4U-!1T53````````````````
M`````````````````````````````````````````````````````#`P,#<U
M-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S0P(#`R
M,34Q-P`@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O87)?4UDO3$-?3453
M4T%'15,O:&]R9&4N;6\`````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,38T
M,30@,3`U,34T,S,W-#`@,#(S,C0R`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````-X2!)4`````>P```!P```#T`P``IP```,P'
M````````:`H```@```!I"@``!0```'(*```(````>`H```<```"!"@``#```
M`(D*```?````E@H``#D```"V"@``*0```/`*```1````&@L``!8````L"P``
M%@```$,+```(````6@L```@```!C"P``%0```&P+```*````@@L```P```"-
M"P``!@```)H+```'````H0L``"D```"I"P```@```-,+```%````U@L``!``
M``#<"P``%````.T+```O`````@P```\````R#```)@```$(,```%````:0P`
M``T```!O#```!0```'T,```0````@PP``!````"4#```#P```*4,```+````
MM0P```\```#!#```#````-$,```/````W@P``!X```#N#```(0````T-```@
M````+PT```,```!0#0``!````%0-```$````60T```P```!>#0``"@```&L-
M```%````=@T```H```!\#0``#P```(<-```2````EPT``!````"J#0``*```
M`+L-```(````Y`T``!````#M#0``!@```/X-```'````!0X```(````-#@``
M!````!`.```/````%0X```H````E#@``!P```#`.```'````.`X```0```!`
M#@``!0```$4.```"````2PX``#,```!.#@``,P```((.```X````M@X``#$`
M``#O#@``+````"$/```%````3@\```(```!4#P``!P```%</```1````7P\`
M``@```!Q#P``'@```'H/```%````F0\``"@```"?#P``*0```,@/```3````
M\@\```L````&$```$0```!(0```$````)!````P````I$```&@```#80```7
M````41```!<```!I$```&P```($0```?````G1```!,```"]$```$````-$0
M```7````XA````<```#Z$```!0````(1```)````"!$``"$````2$0``'```
M`#01```%````41$```,```!7$0``+P```%L1```@````BQ$``"4```"L$0``
M(````-(1```F````\Q$```P````:$@``#````"<2```(````-!(```<````]
M$@``!@```$42```-````3!(```L```!:$@``#````&82```*````<Q(```(`
M``!^$@``!@```($2```#````B!(``$4```",$@``,````-(2```0`````Q,`
M`!\````4$P``$````#03```/````11,```0```!5$P``!0```%H3``!H`0``
M8!,```<```#)%```#````-$4```)````WA0```<```#H%```"P```/`4```8
M````_!0``"8````5%0``+0```#P5```0````:A4``!\```![%0``(0```)L5
M```+````O14```4```#)%0``%0```,\5```-````Y14```T```#S%0``!@``
M``$6```&````"!8``"H````/%@``"P```#H6```$````1A8``!````!+%@``
M"P```%P6```<````:!8```P```"%%@``*0```)(6```1````O!8```T```#.
M%@```P```-P6```+````X!8```L```#L%@``"@```/@6```'`````Q<```L`
M```+%P``"````!<7```0````(!<``!\````Q%P``'P```%$7```>````<1<`
M``0```"0%P``"````)47```'````GA<```P```"F%P``"P```+,7```%````
MOQ<```L```#%%P``#P```-$7```4````X1<``!$```#V%P``)0````@8```%
M````+A@``!4````T&```!````$H8```$````3Q@```L```!4&```!@```&`8
M```-````9Q@```T```!U&```!0```(,8```&````B1@```4```"0&```!0``
M`)88```"````G!@``"<```"?&```)P```,<8```I````[Q@``"`````9&0``
M'````#H9```'````5QD```4```!?&0``!@```&49```,````;!D```L```!Y
M&0``%````(49```$````FAD``!P```"?&0``*````+P9```+````Y1D```P`
M``#Q&0``$0```/X9```%````$!H```P````6&@``%0```",:```3````.1H`
M`!$```!-&@``%````%\:```2````=!H``!@```"'&@``#````*`:```/````
MK1H```@```"]&@``!P```,8:```&````SAH``",```#5&@``&P```/D:```%
M````%1L```\````;&P``*P```"L;```=````5QL``!\```!U&P``+@```)4;
M```B````Q!L``!(```#G&P``#P```/H;```,````"AP```4````7'```"```
M`!T<```/````)AP```T````V'```"P```$0<```*````4!P```@```!;'```
M!@```&0<```#````:QP``"8```!O'```+0```)8<```(````Q!P``!$```#-
M'```#P```-\<```0````[QP```4`````'0``!0````8=```!````;````'0`
M``!'````"0```#``````````20`````````I````:````%P```!E````8@``
M`"<```!7````!````"\`````````00```%4```!>`````````$`````K````
M````````````````-@```&H```!9````,0```$H```!/````4@``````````
M````0@```!H````*`````````"````!F````-P``````````````4P```&0`
M``!N````!0```%8```!&````=P```!D`````````2P````\`````````&P``
M`%0``````````````',```!M````#0`````````?````$P````(`````````
M;P```$,`````````(@````L```!P````%````!8```!C````+@```&D```!A
M````&````$@````L``````````````!Y````!@```&````!V````.@```'@`
M``!=````/P```#L```!.````<0```!$```!,````,@```!(```!:````#@``
M`#,````=````9P````````````````````````!K````6```````````````
M`````",````0````4```````````````-0```!P`````````1`````@`````
M`````````#@````#`````````!<```!Z````#````#P````^`````````"@`
M````````6P```"T````D````````````````````30`````````E````````
M`!X```!%````!P```"$```!?````%0```#0```!U`````````'L````]````
M40````````!R````.0```"8````J```````````R-"!H;W5R<P!!32]030!!
M9&0@<&%I<@!!9&1R97-S`$%D9')E<W,@0F]O:P!!;B!I;&QE9V%L('9A;'5E
M('=A<R!S<&5C:69I960N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D
M;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!=71H96YT:6-A=&EO;B!R
M96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=F%I;&%B;&4@9FEE;&1S.@!"
M860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`
M0FER=&AD87D`0V%L96YD87(`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-E;&P@
M4&AO;F4`0VQO<V4@5VEN9&]W`$-O;6EC<P!#;VUP86YY`$-O=6QD(&YO="!O
M<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$1$`$1A:6QY`$1E9F%U
M;'0@261E;G1I='D`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5T86EL<R!H879E
M(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&ES<&QA>2!/
M<'1I;VYS`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP
M`$5M86EL`$5M<'1Y(')E<W5L="X`17)R;W(`179E<GD@,34@;6EN=71E<P!%
M=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%
M=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!&
M86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE
M8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S
M97)V97(N`$9A>`!(96QP`$AO;64`2&]M92!!9&1R97-S`$AO;64@4&AO;F4`
M2&]R9&4`26-O;G,@3VYL>0!)8V]N<R!W:71H('1E>'0`26UP;W)T960@9FEE
M;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`2V5R8F5R;W,@<V5R=F5R(')E:F5C
M=&5D(&%U=&AE;G1I8V%T:6]N+@!,86YG=6%G90!,:7-T($AE;'`@5&]P:6-S
M`$QO9R!I;@!,;V<@;W5T`$U-`$UA:6P`36%T8VAI;F<@9FEE;&1S`$UE;G4@
M;6]D93H`365S<V%G90!-;VYT:&QY`$YA;64`3F5V97(`3F\`3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@
M5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@4U%,+49I;&4@5D93+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R
M8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!334(@875T:&5N=&EC871I;VXN`$YO=&5S`$]+`$]P=&EO;G,`3W1H97(@
M26YF;W)M871I;VX`4&%S<W=O<F0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R
M871I;VYS`%!H;VYE`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@
M<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S
M<W=O<F0`4')O8FQE;2!$97-C<FEP=&EO;@!296UO=F4@<&%I<@!2971U<FX@
M=&\@3W!T:6]N<P!2;VQE`%-A=F4@3W!T:6]N<P!396QE8W0@=&AE(&1A=&4@
M9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE
M('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L
M96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P
M;W)T`%-K:7`@36%I;G1E;F%N8V4`4W!E8VEA;"!#:&%R86-T97(@26YP=70`
M4W5C8V5S<P!487-K<P!497AT($]N;'D`5&AI<R!N=6UB97(@;75S="!B92!A
M="!L96%S="!O;F4N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&ET
M;&4`55),`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I
M;&4@)7,O)7,N`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N
M86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O
M(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O('1R86YS;&%T92!T
M:&ES(%=O<F0@9&]C=6UE;G0`56YD;R!#:&%N9V5S`%5S97(@3W!T:6]N<P!5
M<V5R;F%M90!787)N:6YG`%=E96ML>0!796QC;VUE('1O("5S`%=E;&-O;64L
M("5S`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%E9`%EE87)L>0!997,`66]U
M(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N
M9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP
M:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($EN9F]R;6%T:6]N`%EO
M=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`6U!R;V)L96T@4F5P;W)T
M70!;;&EN92`E<R!O9B`E<UT`;F%M90!V0V%R9`!0<F]J96-T+4ED+59E<G-I
M;VXZ($A/4D1%('8R+C`N,`I297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI
M<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q
M-3HQ,BLP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#,M,#0M,S`@,3(Z,#`K
M,#(P,`I,87-T+51R86YS;&%T;W(Z(%!L871I;G5M($1E=F5L;W!M96YT(%1E
M86T@/&1E=G1E86U`<&QA=&EN=6TM<WDN;F5T/@I,86YG=6%G92U496%M.B!!
M<F%B:6,@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N
M,`I#;VYT96YT+51Y<&4Z('1E>'0O:'1M;#L@8VAA<G-E=#U#4#$R-38*0V]N
M=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`,C0@T\?:R0#DY<?1Q_`O
MX>WAQ_``P];=(,ODQ\;M`,?AVN3FQ^0`S]W*T2#:Y,?F[>0`RN,@RLW/[<\@
MWNWCR2#;[=$@X][(YN')`,K#W^W/(,?AV.'((-[(X2#'X<C/P2#(VN/A[<?*
M(,?AU>W'Y,F_`,KC(-'=UB#'X<K-WMX@X^0@Q^'EYNW)(./D(-[(X2#'X>/.
MS^,@T<?/[>;3+@#'X<W>YN$@Q^'CRN;=T<DZ`-_AX\D@X]'FT2#;R-$@X][(
MYN')("C?[='([='FTRD`Q]/C(,?AX]/*SL_C(-O(T2#CWLCFX2`HW^W1R.W1
MYM,I`.WFXR#'X>/MX<?/`,/,Y,_)`,7AV\?!(,?AR.''VR#:Y"#CU-_AR0#'
MX>7'RMT@Q^',YL?A`,7;X<?>(,?AY,?=T,D`T=/FX\?*`,?AU-'?R0#AQ\7C
MW\?D[<D@X=W*S2!-86EN=&5N86YC95]487-K(.'AR-'MX\P@)7,`[>;C("T@
MT=[C[>0`[>;C[0#'X<K-WMX@Q^''W<K1Q];M`-31S2#'X>/4W^')`,KC(,W=
MV2#'X<K=Q]7MX2#AX\_MT2#'X>39Q^,`SNW'T<?*(,?AVM'6`.''(,K/SN$@
MX\C'U-')\"#%X>P@Q^'CX=T@;6%I;G1E;F%N8V4N<&AP`,?AR-'MSR#'X<7A
MW\K1YN3M`.''RN;,SR#DRL?&S"X`SMC#`-_A(#$U(,_>[=[)`-_A(#,P(,_>
M[=[)`-_A(#4@S][MWLD`W^$@S\[FX0#?X2#DU=T@T\?:R0#?X2#/WNW>R0##
MX\OAR2#:X>P@Q^'>[>,Z`.''Q>/?Q^3MR2#AX=K+YM$@VN'L(,?ARMW6[>''
MRBX`X<?%X]_'Y.W)(.'AQ<K5Q^$@R,?AX\[/XR!,1$%0+@#AQ\7CW\?D[<D@
MX>'%RM7'X2#(Q^'CSL_C(%--0BX`W<??TP#'X>/3Q]K/R0#'X<C/Q^W)`-KD
MYL?D(,?AX^32X0#EQ\K=(,?AX^32X0#EYM'/[0##[=[FY,?*(-W>V`##[=[F
MY,?*(./:(.35YM4`Q^'-WN;A(,?AX]/*YM'/R3H@)7,`Q^'-WN;A(,?AX]/*
MYM'/R3H`Q^'CSL_C(-_MT<CMT>;3(-'=UB#'X<K-WMX@X^0@Q^'EYNW)+@#'
MX>';R0#>Q\;CR2#:Y,?F[>0@Q^'CT\?:S\D`S\[FX0#.T>;,`-3ET2`M(-'>
MX^WD`,?AR-'MSP#CV,?(WLD@Q^'-WN;A`.;6VB#'X>/0W]''RCH`T=/'X<D`
MU.71[<?P`,?AQ]/C`,/(S\?P`.''`.''RN;,SR#CVN'FX\?*(,WFX2#%VL_'
MS\?*(,?AW"!&5%`@5D93+@#AQ\KFS,\@X]KAYN/'RB#-YN$@Q=K/Q\_'RB#'
MX=P@4U%,(%9&4RX`X<?*YLS/(./:X>;CQ\H@S>;A(,7:S\?/Q\H@X^'=Q\H@
M4U%,(%9&4RX`X<?*YLS/(-_AX\D@X]'FT2#AX<K-WMX@W^W1R.W1YM,`X<?*
MYLS/(-_AX\D@X]'FT2#AX<K-WMX@4TU"/@#CX<?-V<?*`./FQ]W>`,[MQ]''
MR@#CVN'FX\?*(,+.T>P`W^'CR2#'X>/1YM$`RN3=[=`@VN/A[<?*(,?AU>W'
MY,D`Y<?*W0#'X=',Q\$@RM+F[<_DQR#CX<[5(,?AX]3?X<DN`,?AT<S'P2#*
MTN;MS^3'(,C'T^,@Q^'CT\K.S^,@YM_AX\D@Q^'3T2X`U-'-(,?AX]3?X<D`
MQ=+AR2#'X<ODQ\;M`-KFS\D@Q>'L(,?ASNW'T<?*`,?AS^;1`,W=V2#'X<[M
MQ]''R@#'SLK1(,?AW>;'U>$@X>'*Q]'MSCH`Q\[*T2#*Y-/MWB#'X<K'T>W.
M.@#'SLK1(,KDT^W>(,?AYM[*.@#%SLK1(,W>X>WD(./*X\?+X>WD+@#%SLK1
M(.';RM\@Q^'CW=;AR3H`P]'3X2#*WM'MT<?P(,CCU-_AR2#-U>'*`,7EX^$@
MQ^'5[<?DR0#%S\['T2#-T>;=(,['U<D`RN,@R.3,Q\T`Q^'CY>/'R@#DU2#=
MWM@`[<S((,/D(.W?YN0@Y=#'(,?AT=[C(,/?R-$@X^0@Q^'5W=$`[<S((,/D
M(,K?YN0@Y=#E(,?AWNWCR2#1WN,N`,?AX=[(`-KDYL?D(,?AQ>3*T>3MR@#A
MQR#%X]_'Y.W)(.'*V^WMT2#'X=/CQ\WMQ\H@X>/AW2!61E,@)7,O)7,N`.''
M(,7CW\?D[<D@X>'%RM7'X2#(X\[/XR!344PN`.''(,7CW\?D[<D@X=[1Q\')
M(./,X<\@=F9S<F]O="X`X<<@RN;,SR#%X]_'Y.W)(.'*V^WMT2#'T^,@(./A
MW2#'X=P@5D93("5S+R5S+@#;[=$@WL?/T2#:X>P@RM',X\D@X]/*Y,\@Q^'F
MT<\@Y=#'`,K1Q\S:(-KD(,?ARMOM[=''R@#.[<?1Q\H@Q^'CT\K.S^,`Q]/C
M(,?AX]/*SL_C`,KDR.WE`,/3R.;:[<?P`,/EX<<@R-_C(,7A["`E<P##Y>''
M(.;3Y>''("5S`-KDYL?D(,?AVN/A`.7'RMT@Q^':X^$`T^3)("T@U]<`T^3F
M[<?P`.3:XP#MS,@@U-'-(,?AX]3?X<D@WLCA(,?1T\?A(,K>T>W1Q_`@R.7'
M+@#'Y,KERB#5X<?-[<D@Q^''RM7'X2`E<RX@Q^'1S,?!(,7:Q\_)(,?AS\[F
MX2X`R.W'Y,?*WSH`RN,@RLW/[<L@Q^'.[<?1Q\H`6\K>T>W1(,?AX]3?X<E=
M`%O'X=/8T2`E<R#CY"`E<UT`Q^''T^,`=D-A<F0`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]C85]%4P``````
M````````````````````````````````````````````````````````````
M```````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,#`P,"`Q,#4Q-30S,S<T,"`P,3<V-C<`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&]C86QE+V-A7T53+TQ#7TU%4U-!1T53````````````````````````````
M`````````````````````````````````````````#`P,#<U-2``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S0P(#`R,30U-``@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L;V-A;&4O8V%?15,O3$-?34534T%'15,O:&]R
M9&4N;6\`````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`S-C$R,S$@,3`U,34T
M,S,W-#`@,#(S,3<W`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````-X2!)4`````Q@8``!P```!,-@``'0D``'QL````````\)``
M``X```#QD```#P````"1```-````$)$```@````>D0``"P```">1```,````
M,Y$```0```!`D0``&````$61```,````7I$``!$```!KD0``)0```'V1```/
M````HY$```L```"SD0``#@```+^1```%````SI$``"@```#4D0``"````/V1
M```*````!I(``!4````1D@``$@```">2```+````.I(```X```!&D@``"@``
M`%62```-````8)(``"X```!ND@``#@```)V2```1````K)(```T```"^D@``
M#````,R2```-````V9(```8```#GD@``#P```.Z2```8````_I(```P````7
MDP``&P```"23```.````0),```X```!/DP``"````%Z3```)````9Y,``"X`
M``!QDP``&@```*"3```R````NY,``#@```#NDP``5````">4``!1````?)0`
M`%H```#.E```5P```"F5```T````@94```D```"VE0``#0```,"5```'````
MSI4```H```#6E0``#P```.&5```%````\94```8```#WE0``$0```/Z5```(
M````$)8```D````9E@``"0```".6```E````+98``"````!3E@``$````'26
M```/````A98```H```"5E@```P```*"6```/````I)8``!0```"TE@``"0``
M`,F6```-````TY8``!(```#AE@``#P```/26```*````!)<```\````/EP``
M"````!^7```D````*)<``!0```!-EP``%@```&*7```(````>9<``!\```""
MEP``&0```**7```'````O)<```P```#$EP``+````-&7```.````_I<```,`
M```-F```"P```!&8```'````'9@```<````EF```!0```"V8```%````,Y@`
M``H````YF````P```$28```7````2)@```H```!@F```#P```&N8```.````
M>Y@``!@```"*F```(P```*.8```.````QY@``!0```#6F```%P```.N8```7
M`````YD``!<````;F0``$P```#.9```/````1YD```X```!7F0``'P```&:9
M```=````AID```<```"DF0``!@```*R9```(````LYD```\```"\F0``!@``
M`,R9```*````TYD``!,```#>F0``"P```/*9```0````_ID``!4````/F@``
M%0```"6:```'````.YH``!````!#F@``!0```%2:```5````6IH``!$```!P
MF@``#````(*:```[````CYH```D```#+F@``!P```-6:```4````W9H```,`
M``#RF@``!0```/::```0````_)H```D````-FP``$P```!>;```Y````*YL`
M`!(```!EFP``)P```'B;```L````H)L``"H```#-FP``)0```/B;```*````
M'IP```8````IG```"0```#"<```'````.IP``"\```!"G```-P```'*<```N
M````JIP``%4```#9G```+0```"^=```M````79T``"T```"+G0``0````+F=
M```C````^IT``",````>G@``+0```$*>```S````<)X``!4```"DG@``&0``
M`+J>```I````U)X``"0```#^G@``*````".?```1````3)\```H```!>GP``
M#````&F?```*````=I\``!````"!GP``%@```)*?```6````J9\```<```#`
MGP``!P```,B?```4````T)\```H```#EGP``"````/"?```(````^9\```<`
M```"H```!P````J@```&````$J````4````9H```!P```!^@```&````)Z``
M``@````NH```*0```#>@```.````8:````H```!PH```!````'N@```'````
M@*````D```"(H```!@```)*@```1````F:````<```"KH```%@```+.@```$
M````RJ````@```#/H```!@```-B@```-````WZ````8```#MH```'@```/2@
M```1````$Z$``"(````EH0``%@```$BA```(````7Z$```T```!HH0``#```
M`':A```'````@Z$```,```"+H0```P```(^A```7````DZ$``!,```"KH0``
M'0```+^A```(````W:$```0```#FH0``"````.NA```(````]*$``$$```#]
MH0``(````#^B```&````8*(```8```!GH@``%0```&ZB```8````A*(``"(`
M``"=H@``+@```,"B```=````[Z(``"$````-HP``5````"^C```I````A*,`
M``H```"NHP``!P```+FC```5````P:,```X```#7HP``"@```.:C```/````
M\:,```T````!I```#P````^D```-````'Z0```D````MI```%````#>D```&
M````3*0``!@```!3I```'0```&RD```3````BJ0``!$```">I```%````+"D
M```$````Q:0```8```#*I```5````-&D```$````)J4```X````KI0``!0``
M`#JE```%````0*4``!L```!&I0``&@```&*E```1````?:4``!$```"/I0``
M'````*&E```J````OJ4``!````#II0``(0```/JE```%````'*8``!,````B
MI@``$@```#:F```*````2:8```\```!4I@``#0```&2F```1````<J8``!,`
M``"$I@``#````)BF```&````I:8```P```"LI@``!@```+FF```7````P*8`
M`!````#8I@``$0```.FF```(````^Z8```4````$IP``#`````JG```0````
M%Z<```4````HIP``#0```"ZG```&````/*<```<```!#IP``#0```$NG```'
M````6:<```L```!AIP``!P```&VG```'````=:<``!0```!]IP``"0```)*G
M```*````G*<``!D```"GIP``'0```,&G```,````WZ<``!````#LIP``!0``
M`/VG```E`````Z@``!(````IJ```$P```#RH```K````4*@``#L```!\J```
M(````+BH```V````V:@```@````0J0``#````!FI```&````)JD```0````M
MJ0``#P```#*I```.````0JD```H```!1J0``#0```%RI```A````:JD``!X`
M``",J0``&0```*NI```>````Q:D``!L```#DJ0``)@````"J```>````)ZH`
M`!P```!&J@``)@```&.J```S````BJH``"8```"^J@``*P```.6J```X````
M$:L``"\```!*JP``$@```'JK```I````C:L``!(```"WJP``H@```,JK```6
M````;:P``",```"$K```*````*BL```I````T:P``"@```#[K```'P```"2M
M```@````1*T``"4```!EK0``*````(NM```P````M*T``)(```#EK0``(0``
M`'BN```<````FJX``"8```"WK@``00```-ZN```,````(*\```<````MKP``
M!P```#6O```&````/:\```T```!$KP``$````%*O```2````8Z\``!,```!V
MKP``$@```(JO```'````G:\```0```"EKP``$````*JO```,````NZ\```X`
M``#(KP``#P```->O```3````YZ\```T```#[KP``*`````FP```#````,K``
M``T````VL```!@```$2P```1````2[```!<```!=L```&P```'6P```.````
MD;````(```"@L```!0```*.P```0````J;````0```"ZL```#0```+^P```.
M````S;````,```#<L```#@```."P```(````[[````\```#XL```#P````BQ
M```'````&+$```T````@L0``$````"ZQ```+````/[$```8```!+L0``#```
M`%*Q```1````7[$``!D```!QL0``"P```(NQ```-````E[$``"(```"EL0``
M"@```,BQ```8````T[$``!D```#LL0``%@````:R```-````';(```<````K
ML@``%````#.R```+````2+(``"(```!4L@``+P```'>R```+````I[(```D`
M``"SL@``&0```+VR```+````U[(``!<```#CL@``%P```/NR```)````$[,`
M`!8````=LP``#P```#2S```6````1+,```X```!;LP``&````&JS```(````
M@[,```T```",LP``)@```)JS``!#````P;,```@````%M```$@````ZT```(
M````(;0```L````JM```+P```#:T```.````9K0```4```!UM```!@```'NT
M```#````@K0```<```"&M```!````(ZT```*````D[0```H```">M```#P``
M`*FT```0````N;0``!<```#*M```$0```.*T```7````]+0```D````,M0``
M!0```!:U```+````'+4```H````HM0```@```#.U```%````-K4```T````\
MM0``&P```$JU```7````9K4```D```!^M0``#@```(BU```-````E[4``!(`
M``"EM0``.````+BU```@````\;4```@````2M@``#@```!NV``![````*K8`
M`!@```"FM@``$0```+^V```'````T;8```4```#9M@``&0```-^V```'````
M^;8```@````!MP``!@````JW```&````$;<``!`````8MP``#P```"FW```0
M````.;<```\```!*MP``"P```%JW```/````9K<```P```!VMP``#P```(.W
M```'````D[<```8```";MP``#@```**W```,````L;<``"@```"^MP``#P``
M`.>W```(````][<```@`````N```$P````FX```>````';@``"$````\N```
M(````%ZX```9````?[@``!<```"9N```)0```+&X```7````U[@``!8```#O
MN```!`````:Y```;````"[D```T````GN0``#````#6Y```#````0KD```@`
M``!&N0``"@```$^Y```,````6KD```L```!GN0``$````'.Y```,````A+D`
M``0```"1N0``$P```):Y```4````JKD```P```"_N0``"0```,RY```.````
MUKD```L```#EN0``&P```/&Y```'````#;H```<````5N@``"@```!VZ```-
M````*+H```D````VN@``!````$"Z```%````1;H```,```!+N@``&````$^Z
M```*````:+H```0```!SN@``)@```'BZ```.````G[H``'P```"NN@``%0``
M`"N[```%````0;L```<```!'NP``#````$^[```(````7+L```H```!ENP``
M!@```'"[```(````=[L```(```"`NP``!@```(.[```&````BKL``!0```"1
MNP``#0```*:[```0````M+L``!L```#%NP``!````.&[```)````YKL``!``
M``#PNP``"0````&\```)````"[P```4````5O```&@```!N\```(````-KP`
M``8````_O```&0```$:\```.````8+P```<```!OO```!P```'>\```%````
M?[P```D```"%O```"@```(^\```"````FKP```8```"=O```#0```*2\```)
M````LKP```8```"\O```$@```,.\```)````UKP```<```#@O```%````.B\
M```=````_;P```8````;O0``"@```"*]```$````+;T```D````RO0``"```
M`#R]```1````1;T```D```!7O0``!@```&&]```-````:+T```8```!VO0``
M!````'V]```Y````@KT``#T```"\O0``.@```/J]```>````-;X```4```!4
MO@``#@```%J^```$````:;X```8```!NO@``(0```'6^```5````E[X```8`
M``"MO@``!````+2^```1````N;X```8```#+O@``"@```-*^```B````W;X`
M``0`````OP``!0````6_```=````"[\```0````IOP``#````"Z_```*````
M.[\```@```!&OP``"0```$^_```%````6;\``#H```!?OP``,````)J_```U
M````R[\``"D````!P```1P```"O````X````<\```"D```"LP```/P```-;`
M```N````%L$``"T```!%P0``'P```'/!```/````D\$``!(```"CP0``"P``
M`+;!```F````PL$``"D```#IP0``)````!/"```F````.,(```@```!?P@``
M"@```&C"```)````<\(```<```!]P@``(````(7"```@````IL(``"8```#'
MP@``"@```.["```9````^<(``"D````3PP``%@```#W#```2````5,,```<`
M``!GPP``"@```&_#```,````>L,```\```"'PP``$````)?#``!`````J,,`
M`'````#IPP``9@```%K$```.````P<0```D```#0Q```"@```-K$```2````
MY<0``!,```#XQ```#`````S%```&````&<4```\````@Q0``$@```##%```0
M````0\4``!$```!4Q0``'````&;%```C````@\4``&H```"GQ0``#P```!+&
M```%````(L8``!`````HQ@``"0```#G&```$````0\8```L```!(Q@``&@``
M`%3&```4````;\8```P```"$Q@``#````)'&```/````GL8``!4```"NQ@``
M*0```,3&```J````[L8``"8````9QP``)P```$#'```I````:,<``"H```"2
MQP``&0```+W'``!"````U\<``!$````:R```$@```"S(```3````/\@``!0`
M``!3R```#P```&C(```6````>,@``!<```"/R```$````*?(```1````N,@`
M`#0```#*R```$P```/_(```2````$\D``#4````FR0``%````%S)```'````
M<<D```P```!YR0``(````(;)```4````I\D``!$```"\R0``%P```,[)```<
M````YLD``!,````#R@``%````!?*```:````+,H``!$```!'R@``&@```%G*
M```>````=,H``!H```"3R@``$P```*[*```5````PLH``!$```#8R@``%```
M`.K*```7````_\H``!4````7RP``"0```"W+```9````-\L```0```!1RP``
M!P```%;+```+````7LL``!$```!JRP``!@```'S+```&````@\L```8```"*
MRP``!0```)'+```'````E\L```<```"?RP``!0```*?+```6````K<L```8`
M``#$RP``!@```,O+```$````TLL```0```#7RP``!P```-S+```.````Y,L`
M``P```#SRP``#`````#,```-````#<P```H````;S```#@```";,```%````
M-<P``"@````[S```#@```&3,```,````<\P```\```"`S```"@```)#,```(
M````F\P```D```"DS```*P```*[,```$````VLP```@```#?S```)@```.C,
M```2````#\T```\````BS0``!@```#+-```*````.<T```<```!$S0``"```
M`$S-```@````5<T```D```!VS0``#````(#-```-````C<T```X```";S0``
M%@```*K-```1````P<T```8```#3S0```P```-K-```&````WLT``!D```#E
MS0``!P```/_-```$````!\X```L````,S@``"P```!C.```'````),X```<`
M```LS@``%@```#3.```-````2\X```T```!9S@``"@```&?.```0````<LX`
M``\```"#S@``$0```)/.```7````I<X```H```"]S@``$0```,C.```(````
MVLX```0```#CS@``#P```.C.```Z````^,X```4````SSP``#````#G/```>
M````1L\```X```!ESP``$````'3/```+````A<\```P```"1SP``"0```)[/
M```'````J,\```H```"PSP``"0```+O/```.````Q<\``!````#4SP``&@``
M`.7/```*`````-````D````+T```"@```!70```,````(-````\````MT```
M"````#W0```&````1M````<```!-T```"P```%70``!'````8=````T```"I
MT```"0```+?0```$````P=````,```#&T```$P```,K0```3````WM```!,`
M``#RT```"@````;1```"````$=$```0````4T0``)0```!G1```#````/]$`
M``4```!#T0``*@```$G1```*````=-$```4```!_T0``!````(71```*````
MBM$```T```"5T0``!@```*/1```(````JM$```@```"ST0``!````+S1```%
M````P=$``&@```#'T0``"0```##2```,````.M(```4```!'T@``!@```$W2
M```;````5-(``"\```!PT@``$````*#2```*````L=(```\```"\T@``"@``
M`,S2```)````U](``!,```#AT@``&P```/72```8````$=,``!<````JTP``
M#@```$+3```#````4=,```<```!5TP``"````%W3```'````9M,```H```!N
MTP``"P```'G3```'````A=,``%$```"-TP``$````-_3```,````\-,```T`
M``#]TP``&@````O4``!*````)M0``!D```!QU```!@```(O4```&````DM0`
M``8```"9U```'P```*#4```&````P-0```D```#'U```&````-'4```7````
MZM0```8````"U0``#0````G5```B````%]4``%<````ZU0``$P```)+5```C
M````IM4``!,```#*U0```@```-[5```+````X=4```@```#MU0``#0```/;5
M```*````!-8```<````/U@``%````!?6```&````+-8```@````SU@``#@``
M`#S6```'````2]8```H```!3U@``"P```%[6```'````:M8```P```!RU@``
M#0```'_6```,````C=8```D```":U@``"0```*36```*````KM8```<```"Y
MU@``"0```,'6```'````R]8```H```#3U@``&P```-[6```2````^M8```H`
M```-UP``"0```!C7```0````(M<```<````SUP``$@```#O7```$````3M<`
M``<```!3UP``!0```%O7```%````8=<```L```!GUP``%````'/7```1````
MB-<``!H```":UP``%@```+77```4````S-<``!<```#AUP``&````/G7```<
M````$M@``!D````OV```!P```$G8```%````4=@```T```!7V```#````&78
M```(````<M@``!<```![V```"P```)/8```3````G]@```0```"SV```"@``
M`+C8```$````P]@```T```#(V```#````-;8```%````X]@```D```#IV```
M!0```//8```'````^=@```4````!V0``!`````?9```"````#-D``#@````/
MV0``+````$C9```2````==D``"D```"(V0``,@```++9```*````Y=D``"P`
M``#PV0``+@```!W:```S````3-H``#,```"`V@``.````+3:```/````[=H`
M`!@```#]V@``$````!;;```/````)]L``!,````WVP``%0```$O;```4````
M8=L``!(```!VVP``%````(G;```5````GML``"T```"TVP``+0```.+;```Q
M````$-P``"X```!"W```+P```''<```L````H=P``&(```#.W```$P```#'=
M```-````1=T```@```!3W0``"````%S=```,````9=T``"L```!RW0``(0``
M`)[=```:````P-T```D```#;W0``10```.7=``!!````*]X```0```!MW@``
M$P```'+>```4````AMX```X```";W@``$P```*K>```8````OMX```8```#7
MW@``"0```-[>```*````Z-X```\```#SW@``$`````/?```'````%-\```X`
M```<WP``!0```"O?```;````,=\```@```!-WP``!@```%;?```4````7=\`
M`!$```!RWP``#@```(3?```X````D]\```(```#,WP``!@```,_?```.````
MUM\```4```#EWP``!P```.O?```.````\]\```8````"X```!`````G@```I
M````#N```!<````XX```'P```%#@``!<````<.```!0```#-X```/@```.+@
M```?````(>$``!````!!X0``!P```%+A```.````6N$```P```!IX0``#```
M`';A```3````@^$```H```"7X0``'0```*+A```9````P.$```4```#:X0``
M$0```.#A```1````\N$``"0````$X@``%0```"GB```2````/^(```X```!2
MX@``&0```&'B```(````>^(```D```"$X@``#0```([B```*````G.(```<`
M``"GX@``#P```*_B```&````O^(```L```#&X@``"@```-+B```'````W>(`
M``@```#EX@``!0```.[B```?````].(```8````4XP``$````!OC```(````
M+.,```T````UXP``"````$/C```2````3.,``"P```!?XP``&@```(SC```)
M````I^,```H```"QXP``%0```+SC```%````TN,``!0```#8XP``!````.WC
M```0````\N,```8````#Y```!P````KD```>````$N0``"@````QY```"@``
M`%KD```1````9>0``!H```!WY```%````)+D```$````I^0```0```"LY```
M"P```+'D```%````O>0```8```##Y```"````,KD```&````T^0```H```#:
MY```&P```.7D```T`````>4``#0````VY0``(````&OE```I````C.4``"``
M``"VY0``00```-?E```:````&>8``"@````TY@``*0```%WF```B````A^8`
M``8```"JY@``"````+'F```%````NN8```@```#`Y@``&0```,GF```9````
MX^8``"H```#]Y@``(P```"CG```N````3.<``#0```![YP``"````+#G```7
M````N><```H```#1YP``!P```-SG```A````Y.<``!`````&Z```#@```!?H
M```+````)N@```<````RZ```$P```#KH```(````3N@```L```!7Z```"@``
M`&/H```4````;N@```\```"#Z```,@```)/H```+````QN@```4```#2Z```
M!0```-CH```7````WN@```\```#VZ```!`````;I```*````"^D```D````6
MZ0``"P```"#I```-````+.D```P````ZZ0``#@```$?I```%````5ND```0`
M``!<Z0``#0```&'I```R````;^D``$4```"BZ0``%P```.CI```>`````.H`
M`!0````?Z@``!0```#3J```4````.NH```<```!/Z@``#@```%?J```I````
M9NH```8```"0Z@``#````)?J```-````I.H``!$```"RZ@``"P```,3J```V
M````T.H```H````'ZP``(@```!+K```+````->L```\```!!ZP``,@```%'K
M```E````A.L```X```"JZP``!0```+GK```.````O^L``!,```#.ZP``!P``
M`.+K```1````ZNL```<```#\ZP``%`````3L```8````&>P```<````R[```
M!0```#KL```,````0.P```P```!-[```$@```%KL```$````;>P```<```!R
M[```"@```'KL```+````A>P```P```"1[```#@```)[L```.````K>P```4`
M``"\[```!0```,+L```N````R.P``"8```#W[```(P```![M```#````0NT`
M`!(```!&[0``!@```%GM```>````8.T``!@```!_[0``)0```)CM```-````
MONT```D```#,[0```P```-;M```'````VNT```H```#B[0```@```.WM```,
M````\.T``!4```#][0``"P```!/N```9````'^X``"`````Y[@``$@```%KN
M```%````;>X```H```!S[@``%0```'[N```2````E.X```P```"G[@``!```
M`+3N```'````N>X```P```#![@``4@```,[N```7````(>\``!(````Y[P``
M!P```$SO```&````5.\```X```!;[P``#````&KO```-````=^\``!4```"%
M[P``$@```)OO```/````KN\``!0```"^[P``&P```-/O```0````[^\``&D`
M````\```&@```&KP```7````A?```"<```"=\```&@```,7P```7````X/``
M`!L```#X\```&0```!3Q```?````+O$``!,```!.\0``"````&+Q```'````
M:_$```@```!S\0``"0```'SQ```5````AO$```T```"<\0``(P```*KQ```3
M````SO$```,```#B\0``1@```.;Q```_````+?(``#<```!M\@``5P```*7R
M```%````_?(``!\````#\P``+P```"/S```*````4_,```@```!>\P``#0``
M`&?S```M````=?,```0```"C\P``3P```*CS```E````^/,``!P````>]```
M"P```#OT```?````1_0``!T```!G]```)0```(7T```@````J_0``"0```#,
M]```(````/'T```+````$O4```<````>]0``#0```";U```,````-/4``!<`
M``!!]0``!@```%GU```Y````8/4```P```":]0``!P```*?U```)````K_4`
M`!,```"Y]0``"0```,WU```$````U_4``!````#<]0``"````.WU```(````
M]O4```0```#_]0``"P````3V```,````$/8``!(````=]@``$0```##V```,
M````0O8``!H```!/]@``#P```&KV```'````>O8```T```""]@``%````)#V
M```.````I?8```P```"T]@``&P```,'V```L````W?8``!,````*]P``'```
M`![W```H````._<```8```!D]P``!P```&OW```3````<_<```4```"']P``
M!````(WW```7````DO<```H```"J]P``#````+7W```)````PO<```8```#,
M]P``"0```-/W```(````W?<```D```#F]P``"@```/#W```1````^_<```8`
M```-^```#@```!3X```.````(_@```T````R^```"P```$#X```=````3/@`
M``L```!J^````@```';X```'````>?@```8```"!^```"0```(CX```'````
MDO@``#L```":^```*````-;X```T````__@``!4````T^0``!0```$KY```'
M````4/D```@```!8^0``!P```&'Y```%````:?D```<```!O^0``#@```'?Y
M```)````AOD```8```"0^0``"````)?Y```+````H/D```<```"L^0``"```
M`+3Y```'````O?D``!8```#%^0``"0```-SY```&````YOD```L```#M^0``
M'````/GY```4````%OH```<````K^@``$0```#/Z```(````1?H```@```!.
M^@``$````%?Z```0````:/H```8```!Y^@``&0```(#Z```*````FOH``!P`
M``"E^@``!P```,+Z```%````ROH``!````#0^@``%````.'Z```+````]OH`
M``T````"^P``%P```!#[```$````*/L```D````M^P``"@```#?[```'````
M0OL```(```!*^P``#@```$W[```(````7/L``",```!E^P``.````(G[```Q
M````POL``"<```#T^P``9````!S\```4````@?P``%4```"6_```.````.S\
M``!*````)?T``%L```!P_0``*````,S]```X````]?T``"@````N_@``+```
M`%?^```;````A/X``#X```"@_@``J0$``-_^```C````B0`!`!<```"M``$`
M2````,4``0"%````#@$!`#````"4`0$`00```,4!`0!;````!P(!`$D```!C
M`@$`'0```*T"`0`8````RP(!`"$```#D`@$`'P````8#`0`K````)@,!`"<`
M``!2`P$`'0```'H#`0`1````F`,!`#,```"J`P$`)0```-X#`0`G````!`0!
M`!\````L!`$`,````$P$`0!I````?00!`#T```#G!`$`90```"4%`0!-````
MBP4!`"\```#9!0$`+@````D&`0`P````.`8!`%0```!I!@$`6@```+X&`0!(
M````&0<!`$H```!B!P$`,@```*T'`0`O````X`<!`"P````0"`$`+0```#T(
M`0!Q````:P@!`&\```#="`$`LP```$T)`0`7`````0H!`"4````9"@$`,@``
M`#\*`0`I````<@H!`#X```"<"@$`(@```-L*`0!2````_@H!`"4```!1"P$`
M"P```'<+`0"Q````@PL!`$4````U#`$`(0```'L,`0`P````G0P!`"4```#.
M#`$`'````/0,`0`Q````$0T!``<```!##0$`!P```$L-`0`$````4PT!``T`
M``!8#0$`"P```&8-`0`.````<@T!``L```"!#0$`!0```(T-`0`0````DPT!
M``(```"D#0$`60```*<-`0`%`````0X!`!(````'#@$`!````!H.`0`'````
M'PX!``@````G#@$`!0```#`.`0`#````-@X!`!`````Z#@$`#````$L.`0`3
M````6`X!``T```!L#@$``@```'H.`0`'````?0X!``8```"%#@$`%````(P.
M`0`,````H0X!`!@```"N#@$`!@```,<.`0`2````S@X!``P```#A#@$``P``
M`.X.`0`J````\@X!``0````=#P$`!@```"(/`0`'````*0\!`!\````Q#P$`
M-0```%$/`0`N````AP\!`"\```"V#P$`%P```.8/`0`@````_@\!`!L````?
M$`$`&````#L0`0`D````5!`!`!\```!Y$`$`&@```)D0`0`A````M!`!`"``
M``#6$`$`&@```/<0`0`R````$A$!`"\```!%$0$`*P```'41`0`?````H1$!
M`",```#!$0$`'P```.41`0`:````!1(!`"$````@$@$`)0```$(2`0`F````
M:!(!`"4```"/$@$`)````+42`0`8````VA(!`!T```#S$@$`)````!$3`0`8
M````-A,!`"(```!/$P$`+````'(3`0`O````GQ,!`!4```#/$P$`)0```.43
M`0`\````"Q0!`!\```!(%`$`(P```&@4`0`?````C!0!`"````"L%`$`&@``
M`,T4`0`8````Z!0!`"8````!%0$`'@```"@5`0`I````1Q4!`!X```!Q%0$`
M,0```)`5`0`)````PA4!``P```#,%0$`%P```-D5`0`O````\14!`"0````A
M%@$`!P```$86`0`/````3A8!`!0```!>%@$`#@```',6`0`-````@A8!`"0`
M``"0%@$`!0```+46`0`'````NQ8!`"(```##%@$`)0```.86`0`:````#!<!
M`!T````G%P$`&@```$47`0`'````8!<!`,<```!H%P$`"P```#`8`0`5````
M/!@!``8```!2&`$`"0```%D8`0`+````8Q@!`!<```!O&`$`!@```(<8`0`S
M````CA@!`!,```#"&`$`$P```-88`0`'````ZA@!``\```#R&`$`!P````(9
M`0`R````"AD!`"$````]&0$`$P```%\9`0`,````<QD!`!$```"`&0$`,@``
M`)(9`0`(````Q1D!``D```#.&0$`"@```-@9`0`4````XQD!``H```#X&0$`
M'0````,:`0`(````(1H!`!\````J&@$`"````$H:`0`:````4QH!`"<```!N
M&@$`!@```)8:`0`5````G1H!``<```"S&@$`"````+L:`0`)````Q!H!`#\`
M``#.&@$`!P````X;`0`/````%AL!``X````F&P$`$````#4;`0`)````1AL!
M``D```!0&P$`"````%H;`0`3````8QL!``<```!W&P$`&0```'\;`0`*````
MF1L!`!<```"D&P$`%````+P;`0`*````T1L!``P```#<&P$`%P```.D;`0`$
M`````1P!`"H````&'`$`$0```#$<`0`'````0QP!``(```!+'`$`$````$X<
M`0`8````7QP!``L```!X'`$``P```(0<`0`(````B!P!``8```"1'`$`!P``
M`)@<`0`-````H!P!``L```"N'`$`%````+H<`0`5````SQP!``X```#E'`$`
M+P```/0<`0`@````)!T!`!P```!%'0$`#````&(=`0`Q````;QT!``4```"A
M'0$`$@```*<=`0`_````NAT!`!(```#Z'0$`"@````T>`0`&````&!X!``0`
M```?'@$`!````"0>`0`*````*1X!`!,````T'@$`!0```$@>`0`&````3AX!
M``8```!5'@$`!````%P>`0`,````81X!``H```!N'@$`!0```'D>`0`8````
M?QX!`!D```"8'@$`'P```+(>`0`=````TAX!`!$```#P'@$``@````(?`0`$
M````!1\!``H````*'P$`!@```!4?`0`%````'!\!``,````B'P$`#````"8?
M`0!%````,Q\!`!H```!Y'P$`*````)0?`0!3````O1\!`!D````1(`$`<@``
M`"L@`0`@````GB`!`#4```"_(`$`(0```/4@`0!%````%R$!`#````!=(0$`
M*````(XA`0`I````MR$!`"8```#A(0$`)0````@B`0`H````+B(!`"@```!7
M(@$`(@```(`B`0`P````HR(!`!(```#4(@$`$P```.<B`0`0````^R(!`'D`
M```,(P$`"0```(8C`0!S````D",!`'P````$)`$`*P```($D`0!4````K20!
M`!<````")0$`%@```!HE`0`/````,24!`!\```!!)0$`0````&$E`0`?````
MHB4!`!P```#")0$`40```-\E`0`4````,28!``H```!&)@$`!0```%$F`0`&
M````5R8!``@```!>)@$`!0```&<F`0`2````;28!`!````"`)@$`$P```)$F
M`0`=````I28!``\```##)@$`#P```-,F`0`$````XR8!``D```#H)@$`"P``
M`/(F`0`'````_B8!``4````&)P$`%`````PG`0`'````(2<!``@````I)P$`
M#P```#(G`0`(````0B<!``P```!+)P$`#P```%@G`0`&````:"<!`!0```!O
M)P$`!@```(0G`0`,````BR<!``@```"8)P$`!````*$G`0`*````IB<!``<`
M``"Q)P$`!````+DG`0`9````OB<!``(```#8)P$``@```-LG`0`)````WB<!
M``8```#H)P$`!@```.\G`0`G````]B<!``(````>*`$`!````"$H`0`/````
M)B@!`!,````V*`$`!P```$HH`0`'````4B@!``8```!:*`$`!@```&$H`0`0
M````:"@!`!(```!Y*`$``@```(PH`0`&````CR@!``D```"6*`$`(@```*`H
M`0`'````PR@!``<```#+*`$`"P```-,H`0`%````WR@!``(```#E*`$`"P``
M`.@H`0!=`0``]"@!``P```!2*@$`$@```%\J`0`,````<BH!``8```!_*@$`
M!@```(8J`0`&````C2H!``(```"4*@$`&````)<J`0`*````L"H!`!$```"[
M*@$`+````,TJ`0`6````^BH!``D````1*P$`%````!LK`0`%````,"L!`"H`
M```V*P$`$@```&$K`0`*````="L!`!L```!_*P$`#P```)LK`0`+````JRL!
M`!````"W*P$`"0```,@K`0`2````TBL!`#,```#E*P$`#@```!DL`0`8````
M*"P!``P```!!+`$`$P```$XL`0`7````8BP!``8```!Z+`$`#P```($L`0`5
M````D2P!`!$```"G+`$`&P```+DL`0`2````U2P!`!(```#H+`$`"````/LL
M`0`)````!"T!`#H````.+0$`(@```$DM`0`Y````;"T!`$,```"F+0$`90``
M`.HM`0!B````4"X!`&L```"S+@$`:````!\O`0`[````B"\!``X```#$+P$`
M$P```-,O`0`-````YR\!``\```#U+P$`%@````4P`0`%````'#`!``D````B
M,`$`$P```"PP`0`-````0#`!`!D```!.,`$`%P```&@P`0`O````@#`!`"H`
M``"P,`$`%@```-LP`0`0````\C`!`!`````#,0$`!@```!0Q`0`9````&S$!
M`"(````U,0$`%0```%@Q`0`2````;C$!`!T```"!,0$`%0```)\Q`0`3````
MM3$!`!0```#),0$`$@```-XQ`0`R````\3$!`"`````D,@$`)````$4R`0`0
M````:C(!`"(```![,@$`*@```)XR`0`&````R3(!`!(```#0,@$`0````.,R
M`0`-````)#,!``<````R,P$`"@```#HS`0`'````13,!``<```!-,P$`!0``
M`%4S`0`'````6S,!``H```!C,P$`!````&XS`0`<````<S,!``X```"0,P$`
M$0```)\S`0`3````L3,!`!4```#%,P$`.0```-LS`0`+````%30!`!4````A
M-`$`'````#<T`0`<````5#0!`!X```!Q-`$`%P```)`T`0`0````J#0!``\`
M``"Y-`$`(P```,DT`0`A````[30!``<````/-0$`!@```!<U`0`(````'C4!
M`!4````G-0$`"````#TU`0`)````1C4!`!$```!0-0$`"0```&(U`0`4````
M;#4!`!8```"!-0$`*@```)@U`0`'````PS4!``\```#+-0$`!0```-LU`0`4
M````X34!``\```#V-0$`#@````8V`0`J````%38!``D```!`-@$`!P```$HV
M`0`2````4C8!``,```!E-@$`!0```&DV`0`2````;S8!``P```""-@$`&0``
M`(\V`0!!````J38!`!4```#K-@$`*P````$W`0`T````+3<!`#(```!B-P$`
M-0```)4W`0`(````RS<!``4```#4-P$`"0```-HW`0`'````Y#<!`#<```#L
M-P$`-@```"0X`0`V````6S@!`&,```"2.`$`-0```/8X`0`U````+#D!`#4`
M``!B.0$`3P```)@Y`0`N````Z#D!`#$````7.@$`-0```$DZ`0`[````?SH!
M`"@```"[.@$`*P```.0Z`0`N````$#L!`#P````_.P$`/````'P[`0`2````
MN3L!``L```#,.P$`#````-@[`0`$````Y3L!``X```#J.P$`(````/D[`0`A
M````&CP!``<````\/`$`!P```$0\`0`4````3#P!``L```!A/`$`"````&T\
M`0`*````=CP!``L```"!/`$`!P```(T\`0`&````E3P!``4```"</`$`"```
M`*(\`0`&````JSP!``H```"R/`$`,0```+T\`0`3````[SP!``T````#/0$`
M!P```!$]`0`'````&3T!``D````A/0$`!P```"L]`0`1````,ST!``@```!%
M/0$`%````$X]`0`&````8ST!``@```!J/0$`"````',]`0`.````?#T!``8`
M``"+/0$`)@```)(]`0`1````N3T!`"<```#+/0$`$````/,]`0`(````!#X!
M``X````-/@$`#````!P^`0`'````*3X!``,````Q/@$``P```#4^`0`;````
M.3X!`!<```!5/@$`/P```&T^`0`)````K3X!``4```"W/@$`"````+T^`0`'
M````QCX!`&H```#./@$`,0```#D_`0`&````:S\!``H```!R/P$`(@```'T_
M`0`@````H#\!`"<```#!/P$`-````.D_`0`E````'D`!`"H```!$0`$`<```
M`&]``0`T````X$`!``@````500$`"````!Y!`0`6````)T$!``P````^00$`
M#0```$M!`0`4````64$!`!,```!N00$`%P```()!`0`5````FD$!``T```"P
M00$`%````+Y!`0`'````TT$!`!@```#;00$`&P```/1!`0`6````$$(!`!8`
M```G0@$`&@```#Y"`0`$````64(!``8```!>0@$`=@```&5"`0`$````W$(!
M`!0```#A0@$`!````/9"`0`$````^T(!`!H`````0P$`&````!M#`0`4````
M-$,!`!0```!)0P$`)````%Y#`0`Y````@T,!`!$```"]0P$`+0```,]#`0`(
M````_4,!`"$````&1`$`%````"A$`0`0````/40!`!T```!.1`$`%P```&Q$
M`0`3````A$0!`!,```"81`$`$0```*Q$`0`&````OD0!`!4```#%1`$`"0``
M`-M$`0`8````Y40!`!<```#^1`$`#@```!9%`0`(````)44!``4````N10$`
M$0```#1%`0`1````1D4!``D```!810$`%@```&)%`0`&````>44!``4```"`
M10$`!P```(9%`0`)````CD4!``@```"810$`!P```*%%`0`)````J44!`!<`
M``"S10$`"@```,M%`0`*````UD4!`!L```#A10$`)0```/U%`0`,````(T8!
M`!@````P1@$`!0```$E&`0`@````3T8!`"4```!P1@$`)0```)9&`0`Y````
MO$8!`$8```#V1@$`-0```#U'`0!%````<T<!``D```"Y1P$`"@```,-'`0`&
M````SD<!``8```#51P$`&````-Q'`0`/````]4<!``H````%2`$`#0```!!(
M`0`H````'D@!`"@```!'2`$`(````'!(`0`I````D4@!`"````"[2`$`,0``
M`-Q(`0`I````#DD!`"8````X20$`,P```%])`0`^````DTD!`#(```#220$`
M-0````5*`0!$````.TH!`#T```"`2@$`%P```+Y*`0`Z````UDH!`!@````1
M2P$`S````"I+`0`?````]TL!`#$````73`$`-````$E,`0`V````?DP!`#8`
M``"U3`$`*````.Q,`0`G````%4T!`#(````]30$`-0```'!-`0!(````IDT!
M`*````#O30$`)@```)!.`0`I````MTX!`#8```#A3@$`8P```!A/`0`,````
M?$\!``0```")3P$`!@```(Y/`0`%````E4\!``\```";3P$`$@```*M/`0`1
M````OD\!`!0```#03P$`'@```.5/`0`'````!%`!``0````,4`$`#P```!%0
M`0`,````(5`!`!`````N4`$`#````#]0`0`0````3%`!``P```!=4`$`2@``
M`&I0`0`(````M5`!`!0```"^4`$`!0```--0`0`2````V5`!`!@```#L4`$`
M&P````51`0`/````(5$!``(````Q40$`"@```#11`0`5````/U$!``0```!5
M40$`$@```%I1`0`0````;5$!``,```!^40$`$````()1`0`(````DU$!`!``
M``"<40$`$````*U1`0`-````OE$!`!,```#,40$`&````.!1`0`+````^5$!
M``@````%4@$`#0````Y2`0`/````'%(!`!L````L4@$`#P```$A2`0`0````
M6%(!`"H```!I4@$`#0```)12`0`B````HE(!`!H```#%4@$`%P```.!2`0`2
M````^%(!``D````+4P$`%0```!53`0`*````*U,!`"\````V4P$`-P```&93
M`0`/````GE,!``X```"N4P$`(@```+U3`0`0````X%,!`!(```#Q4P$`$P``
M``14`0`)````&%0!`"H````B5`$`&````$U4`0`8````9E0!`!<```!_5`$`
M%P```)=4`0`(````KU0!``X```"X5`$`*````,=4`0!4````\%0!``@```!%
M50$`%````$Y5`0`+````8U4!``X```!O50$`.P```'Y5`0`2````NE4!``<`
M``#-50$`$0```-55`0`#````YU4!``<```#K50$`!0```/-5`0`*````^54!
M``H````$5@$`#`````]6`0`.````'%8!`!0````K5@$`$0```$!6`0`4````
M4E8!``@```!G5@$`!@```'!6`0`+````=U8!``H```"#5@$`"````(Y6`0`1
M````EU8!`!(```"I5@$`*P```+Q6`0`A````Z%8!``H````*5P$`$@```!57
M`0`2````*%<!`!H````[5P$`10```%97`0`U````G%<!`!,```#25P$`$```
M`.97`0"4````]U<!`"(```",6`$`$0```*]8`0`'````P5@!``4```#)6`$`
M,````,]8`0`'`````%D!``<````(60$`!0```!!9`0`&````%ED!``X````=
M60$`#0```"Q9`0`.````.ED!``T```!)60$`%````%=9`0`/````;%D!``H`
M``!\60$`$0```(=9`0`'````F5D!``D```"A60$`&0```*M9`0`.````Q5D!
M`"\```#460$`$0````1:`0`(````%EH!`!,````?6@$`(@```#-:`0`I````
M5EH!`"T```"`6@$`+````*Y:`0`=````VUH!`!P```#Y6@$`*P```!9;`0`@
M````0EL!`!L```!C6P$`!````'];`0`9````A%L!``L```">6P$`%````*I;
M`0`#````OUL!``8```##6P$`"P```,I;`0`,````UEL!``T```#C6P$`$@``
M`/%;`0`/````!%P!``0````47`$`&P```!E<`0`<````-5P!``\```!27`$`
M#@```&)<`0`1````<5P!`!(```"#7`$`&@```)9<`0`'````L5P!``D```"Y
M7`$`#@```,-<`0`,````TEP!``H```#?7`$`"````.I<`0`,````\UP!``4`
M````70$`&0````9=`0`0````(%T!``8````Q70$`+0```#A=`0`.````9ET!
M`)8```!U70$`&P````Q>`0`*````*%X!``0````S7@$`#@```#A>`0`%````
M1UX!``<```!-7@$`!@```%5>`0`,````7%X!``,```!I7@$`!0```&U>`0`&
M````<UX!`!0```!Z7@$`$````(]>`0`2````H%X!`!P```"S7@$`!@```-!>
M`0`'````UUX!`!,```#?7@$`"P```/->`0`+````_UX!``4````+7P$`*```
M`!%?`0`'````.E\!``8```!"7P$`'````$E?`0`,````9E\!``<```!S7P$`
M"````'M?`0`%````A%\!``D```"*7P$`"P```)1?`0`&````H%\!``4```"G
M7P$`#P```*U?`0`0````O5\!``8```#.7P$`$0```-5?`0`*````YU\!``<`
M``#R7P$`#P```/I?`0`L````"F`!``4````W8`$`"0```#U@`0`$````1V`!
M``D```!,8`$`"````%9@`0`7````7V`!`!,```!W8`$`!@```(M@`0`-````
MDF`!``8```"@8`$`!````*=@`0`Y````K&`!`#L```#F8`$`.````")A`0`C
M````6V$!``4```!_80$`$0```(5A`0`'````EV$!``D```"?80$`&P```*EA
M`0`5````Q6$!``8```#;80$`!0```.)A`0`<````Z&$!`!$````%8@$`"0``
M`!=B`0`=````(6(!``,````_8@$`!0```$-B`0`F````26(!``4```!P8@$`
M$0```'9B`0`2````B&(!``@```";8@$`"0```*1B`0`%````KF(!`$,```"T
M8@$`1P```/AB`0!&````0&,!`#$```"'8P$`1````+EC`0!$````_F,!`"\`
M``!#9`$`5````'-D`0`R````R&0!`#8```#[9`$`+0```#)E`0`1````8&4!
M`!4```!R90$`#````(AE`0`N````E64!`"````#$90$`'@```.5E`0`=````
M!&8!``<````B9@$`"````"IF`0`*````,V8!``<````^9@$`)@```$9F`0`I
M````;68!`$````"79@$`"0```-AF`0`?````XF8!`"\````"9P$`&0```#)G
M`0`7````3&<!``@```!D9P$`#````&UG`0`,````>F<!``\```"'9P$`$```
M`)=G`0!`````J&<!`)$```#I9P$`;0```'MH`0`B````Z6@!`!`````,:0$`
M$0```!UI`0`4````+VD!`!4```!$:0$`%````%II`0`'````;VD!`!(```!W
M:0$`$0```(II`0`0````G&D!`!<```"M:0$`-````,5I`0`J````^FD!`)8`
M```E:@$`$P```+QJ`0`%````T&H!`!,```#6:@$`"0```.IJ`0`*````]&H!
M``H```#_:@$`&@````IK`0`;````)6L!`!,```!!:P$`$@```%5K`0`3````
M:&L!`!H```!\:P$`+````)=K`0`M````Q&L!`"D```#R:P$`*P```!QL`0`K
M````2&P!`"P```!T;`$`&@```*%L`0"$````O&P!`!H```!!;0$`&P```%QM
M`0`:````>&T!`!L```"3;0$`$0```*]M`0`:````P6T!`!L```#<;0$`%P``
M`/AM`0`8````$&X!`"\````I;@$`&````%EN`0`8````<FX!`$0```"+;@$`
M$P```-!N`0`,````Y&X!`!@```#Q;@$`+0````IO`0`4````.&\!`",```!-
M;P$`*@```'%O`0`D````G&\!`"$```#!;P$`)0```.-O`0`N````"7`!`!D`
M```X<`$`-````%)P`0`[````AW`!`"0```##<`$`+````.AP`0`A````%7$!
M`!@````W<0$`'P```%!Q`0`?````<'$!`"$```"0<0$`"0```+)Q`0`;````
MO'$!``0```#8<0$`!P```-UQ`0`+````Y7$!`!(```#Q<0$`!@````1R`0`'
M````"W(!``<````3<@$`!@```!MR`0`'````(G(!``4````J<@$`!````#!R
M`0`5````-7(!``8```!+<@$`"````%)R`0`&````6W(!``0```!B<@$`"@``
M`&=R`0`4````<G(!`!P```"'<@$`%P```*1R`0`5````O'(!``H```#2<@$`
M&P```-UR`0`%````^7(!`#````#_<@$`#@```#!S`0`0````/W,!`!L```!0
M<P$`$P```&QS`0`-````@',!``T```".<P$`-P```)QS`0`$````U',!``@`
M``#9<P$`)P```.)S`0`3````"G0!``X````>=`$`!@```"UT`0`,````-'0!
M``8```!!=`$`!@```$AT`0`E````3W0!``X```!U=`$`#````(1T`0`6````
MD70!`!0```"H=`$`&@```+UT`0`1````V'0!``<```#J=`$`!````/)T`0`'
M````]W0!`"H```#_=`$`!0```"IU`0`(````,'4!`!(````Y=0$`%````$QU
M`0`'````874!``<```!I=0$`!0```'%U`0`-````=W4!``P```"%=0$`"P``
M`))U`0`:````GG4!`!<```"Y=0$`#````-%U`0`6````WG4!``P```#U=0$`
M$@````)V`0`(````%78!``8````>=@$`&````"5V`0!$````/G8!``@```"#
M=@$`#````(QV`0`G````F78!`!H```#!=@$`&0```-QV`0`2````]G8!``P`
M```)=P$`"0```!9W`0`'````('<!``H````H=P$`"0```#-W`0`.````/7<!
M`!````!,=P$`)@```%UW`0`,````A'<!``@```"1=P$`$P```)IW`0`,````
MKG<!``T```"[=P$`"````,EW`0`0````TG<!``0```#C=P$`&0```.AW`0!F
M`````G@!`!8```!I>`$`"@```(!X`0`$````BW@!``0```"0>`$`&0```)5X
M`0`:````KW@!`!L```#*>`$`"0```.9X`0`"````\'@!``0```#S>`$`*0``
M`/AX`0`#````(GD!``4````F>0$`*````"QY`0`*````57D!``4```!@>0$`
M$0```&9Y`0`7````>'D!`!H```"0>0$`!@```*MY`0`(````LGD!``@```"[
M>0$`!````,1Y`0`%````R7D!`'T```#/>0$`"@```$UZ`0`-````6'H!``0`
M``!F>@$`!0```&MZ`0`I````<7H!`#<```";>@$`#@```--Z`0`)````XGH!
M`!8```#L>@$`"@````-[`0`'````#GL!`!0````6>P$`,@```"M[`0`M````
M7GL!`"P```",>P$`#P```+E[`0`$````R7L!``<```#.>P$`"````-9[`0`'
M````WWL!``X```#G>P$`$P```/9[`0`(````"GP!`&,````3?`$`$0```'=\
M`0`1````B7P!``X```";?`$`(0```*I\`0!9````S'P!`"H````F?0$`!@``
M`%%]`0`&````6'T!``4```!??0$`'@```&5]`0`&````A'T!``H```"+?0$`
M+0```)9]`0`L````Q'T!``<```#Q?0$`"P```/E]`0`M````!7X!`%$````S
M?@$`(P```(5^`0`U````J7X!`"````#??@$``P````!_`0`,````!'\!``<`
M```1?P$`#P```!E_`0`0````*7\!``4````Z?P$`%@```$!_`0`&````5W\!
M``@```!>?P$`"0```&=_`0`+````<7\!``H```!]?P$`#````(A_`0`&````
ME7\!`!D```"<?P$`&0```+9_`0`:````T'\!``\```#K?P$`$@```/M_`0`0
M````#H`!``\````?@`$`#P```"^``0`/````/X`!``@```!/@`$`,@```%B`
M`0`1````BX`!``T```"=@`$`#0```*N``0`6````N8`!``<```#0@`$`%P``
M`-B``0`#````\(`!``<```#T@`$`!0```/R``0`%`````H$!``T````(@0$`
M%0```!:!`0`4````+($!`"(```!!@0$`(P```&2!`0`<````B($!`!P```"E
M@0$`(````,*!`0`D````XX$!`!\````(@@$`!0```"B"`0`#````+H(!``X`
M```R@@$`#@```$&"`0`*````4((!`!L```!;@@$`#````'>"`0`9````A((!
M``D```">@@$`$@```*B"`0`'````NX(!`!````##@@$`$````-2"`0`(````
MY8(!``D```#N@@$`!0```/B"`0`'````_H(!``,````&@P$`!`````J#`0`"
M````#X,!`$0````2@P$`-0```%>#`0`;````C8,!`"\```"I@P$`/P```-F#
M`0`-````&80!`"X````GA`$`-P```%:$`0!`````CH0!`$````#/A`$`1P``
M`!"%`0`0````6(4!`"$```!IA0$`&P```(N%`0`9````IX4!`!T```#!A0$`
M'P```-^%`0`>````_X4!`!L````>A@$`'@```#J&`0`C````688!`#P```!]
MA@$`/````+J&`0!`````]X8!`#\````XAP$`/@```'B'`0`[````MX<!`&P`
M``#SAP$`&````&"(`0`C````>8@!``P```"=B`$`"P```*J(`0`8````MH@!
M`#T```#/B`$`,0````V)`0`C````/XD!``P```!CB0$`4````'")`0!'````
MP8D!``,````)B@$`$0````V*`0`4````'XH!``\````TB@$`#@```$2*`0`8
M````4XH!``<```!LB@$`"@```'2*`0`(````?XH!`!(```"(B@$`#P```)N*
M`0`*````JXH!``H```"VB@$`!0```,&*`0`G````QXH!``@```#OB@$`!@``
M`/B*`0`3````_XH!`!(````3BP$`#P```":+`0!7````-HL!``<```".BP$`
M!P```):+`0`4````GHL!``4```"SBP$`!P```+F+`0`4````P8L!``<```#6
MBP$`!````-Z+`0`_````XXL!`!@````CC`$`+@```#R,`0""````:XP!`!H`
M``#NC`$`2P````F-`0`G````58T!`!````!]C0$`!P```(Z-`0`,````EHT!
M``\```"CC0$`#````+.-`0`4````P(T!`!(```#5C0$`'@```.B-`0`;````
M!XX!``4````CC@$`$````"F.`0`7````.HX!`"8```!2C@$`%0```'F.`0`6
M````CXX!`!````"FC@$`'P```+>.`0`(````UXX!`!8```#@C@$`$````/>.
M`0`/````"(\!`!`````8CP$`&````"F/`0`,````0H\!`!(```!/CP$`%P``
M`&*/`0`)````>H\!``@```"$CP$`!0```(V/`0`9````DX\!``8```"MCP$`
M$0```+2/`0`(````QH\!`!4```#/CP$`"P```.6/`0`6````\8\!`#H````(
MD`$`&P```$.0`0`,````7Y`!``T```!LD`$`(@```'J0`0`(````G9`!`!H`
M``"FD`$`!````,&0`0`/````QI`!``0```#6D`$`"P```-N0`0`C````YY`!
M`#\````+D0$`!@```$N1`0`.````4I$!`!D```!AD0$`#P```'N1`0`$````
MBY$!`!0```"0D0$`"0```*61`0`'````KY$!``4```"WD0$`"````+V1`0`&
M````QI$!``8```#-D0$`%````-21`0`L````Z9$!`"\````6D@$`&@```$:2
M`0`I````89(!`!\```"+D@$`/````*N2`0`:````Z)(!`",````#DP$`+0``
M`">3`0`E````59,!``<```![DP$`"````(.3`0`)````C),!``@```"6DP$`
M'````)^3`0`;````O),!`"P```#8DP$`,`````64`0`X````-I0!`$````!O
ME`$`!P```+"4`0`:````N)0!``D```#3E`$`%````-V4`0`U````\I0!``\`
M```HE0$`%````#B5`0`,````394!``@```!:E0$`%P```&.5`0`)````>Y4!
M``X```"%E0$`#````)25`0`9````H94!`!H```"[E0$`0````-:5`0`+````
M%Y8!``4````CE@$`"````"F6`0`9````,I8!`!````!,E@$`!0```%V6`0`4
M````8Y8!`!$```!XE@$`!@```(J6`0`+````D98!``@```"=E@$`#@```*:6
M`0`'````M98!``8```"]E@$`%````,26`0!#````V98!`&@````=EP$`'```
M`(:7`0`H````HY<!`"4```#,EP$`$0```/*7`0`6````!)@!``H````;F`$`
M$````":8`0`I````-Y@!``@```!AF`$`#0```&J8`0`0````>)@!`!8```")
MF`$`$P```*"8`0!!````M)@!``L```#VF`$`(0````*9`0`1````))D!`!4`
M```VF0$`00```$R9`0`E````CID!`!````"TF0$`"````,69`0`8````SID!
M`!@```#GF0$`"0````":`0`/````"IH!``8````:F@$`&0```"&:`0`D````
M.YH!``<```!@F@$`!0```&B:`0`/````;IH!`!(```!^F@$`&````)&:`0`&
M````JIH!``<```"QF@$`"0```+F:`0`2````PYH!`!````#6F@$`%0```.>:
M`0`5````_9H!``8````3FP$`!@```!J;`0`S````(9L!`"<```!5FP$`)```
M`'V;`0`(````HIL!``\```"KFP$`!@```+N;`0`B````PIL!`!H```#EFP$`
M)P````"<`0`/````*)P!`!8````XG`$``P```$^<`0`$````4YP!`!8```!8
MG`$``P```&^<`0`,````<YP!`!D```"`G`$`"P```)J<`0`8````IIP!`!X`
M``"_G`$`$P```-Z<`0`%````\IP!``H```#XG`$`$P````.=`0`6````%YT!
M``X````NG0$`!````#V=`0`'````0IT!`!````!*G0$`6P```%N=`0`A````
MMYT!`!,```#9G0$`!P```.V=`0`%````]9T!``\```#[G0$`%@````N>`0`4
M````(IX!`"8````WG@$`'0```%Z>`0`7````?)X!`"@```"4G@$`*0```+V>
M`0`6````YYX!`'0```#^G@$`)@```'.?`0`A````FI\!`"\```"\GP$`)0``
M`.R?`0`@````$J`!`"<````SH`$`)````%N@`0`>````@*`!`!\```"?H`$`
M"@```+^@`0`'````RJ`!``@```#2H`$`"````-N@`0`3````Y*`!``\```#X
MH`$`/@````BA`0`E````1Z$!``@```!MH0$`3P```':A`0!`````QJ$!`$D`
M```'H@$`=P```%&B`0`,````R:(!`#,```#6H@$`-@````JC`0`*````0:,!
M``<```!,HP$`"@```%2C`0`_````7Z,!``8```"?HP$`/@```*:C`0`Y````
MY:,!`"8````?I`$`%````$:D`0`Y````6Z0!`"L```"5I`$`,0```,&D`0`G
M````\Z0!`"\````;I0$`*````$NE`0`1````=*4!``<```"&I0$`%@```(ZE
M`0`3````I:4!`!0```"YI0$`!@```,ZE`0`P````U:4!``P````&I@$`$```
M`!.F`0`)````)*8!`!8````NI@$`"````$6F`0`$````3J8!`!````!3I@$`
M"@```&2F`0`)````;Z8!``8```!YI@$`#````("F`0`-````C:8!`!P```";
MI@$`&0```+BF`0`.````TJ8!`!\```#AI@$`#`````&G`0`'````#J<!`!``
M```6IP$`*0```">G`0`/````4:<!``H```!AIP$`&````&RG`0`L````A:<!
M``T```"RIP$`'0```,"G`0`R````WJ<!``D````1J`$`!P```!NH`0`3````
M(Z@!``<````WJ`$`#0```#^H`0`A````3:@!``X```!OJ`$`#P```'ZH`0`,
M````CJ@!``<```";J`$`"0```*.H`0`)````K:@!``D```"WJ`$`"P```,&H
M`0`1````S:@!``4```#?J`$`%P```.6H`0`1````_:@!``8````/J0$`$0``
M`!:I`0`>````**D!``L```!'J0$``P```%.I`0`(````5ZD!``4```!@J0$`
M"````&:I`0`$````;ZD!`$X```!TJ0$`,0```,.I`0`_````]:D!`!T````U
MJ@$`!0```%.J`0`%````6:H!``\```!?J@$`#0```&^J`0`*````?:H!``\`
M``"(J@$`'0```)BJ`0`1````MJH!``T```#(J@$`#@```-:J`0`*````Y:H!
M``L```#PJ@$`!P```/RJ`0`&````!*L!`!0````+JP$`"P```""K`0`&````
M+*L!``8````SJP$`)P```#JK`0`6````8JL!``@```!YJP$`$0```(*K`0`)
M````E*L!``D```">JP$`$P```*BK`0`3````O*L!``8```#0JP$`'````->K
M`0`+````]*L!`!P`````K`$`"0```!VL`0`'````)ZP!`!$````OK`$`)```
M`$&L`0`+````9JP!``T```!RK`$`&P```("L`0`$````G*P!``H```"AK`$`
M$0```*RL`0`.````OJP!``,```#-K`$`$P```-&L`0`)````Y:P!`"(```#O
MK`$`.````!*M`0`W````2ZT!`#8```"#K0$`80```+JM`0`9````'*X!`',`
M```VK@$`/0```*JN`0!0````Z*X!`'H````YKP$`+0```+2O`0!$````XJ\!
M`"X````GL`$`,P```%:P`0`:````BK`!`$P```"EL`$`XP$``/*P`0`@````
MUK(!`!@```#WL@$`0@```!"S`0!X````4[,!`#@```#,LP$`0`````6T`0!J
M````1K0!`%D```"QM`$`(0````NU`0`4````+;4!`!\```!"M0$`'````&*U
M`0`J````?[4!`"(```"JM0$`)0```,VU`0`8````\[4!`#<````,M@$`)0``
M`$2V`0`G````:K8!`!X```"2M@$`+P```+&V`0!>````X;8!`$$```!`MP$`
M8P```(*W`0!3````YK<!`#H````ZN`$`.````'6X`0`V````KK@!`&P```#E
MN`$`<0```%*Y`0!<````Q+D!`%T````AN@$`/````'^Z`0`G````O+H!`"<`
M``#DN@$`,P````R[`0"!````0+L!`'X```#"NP$`U@```$&\`0`9````&+T!
M`"X````RO0$`-P```&&]`0`M````F;T!`$\```#'O0$`)@```!>^`0!=````
M/KX!`",```"<O@$`"P```,"^`0#E````S+X!`$\```"ROP$`*0````+``0`V
M````+,`!`"H```!CP`$`(0```([``0`\````L,`!``,```#MP`$`!P```/'`
M`0`$````^<`!`!````#^P`$`#0````_!`0`1````'<$!``X````OP0$`!0``
M`#[!`0`B````1,$!``$```!GP0$`:P```&G!`0`$````U<$!`!4```#:P0$`
M!````/#!`0`'````]<$!``0```#]P0$`!0````+"`0`(````",(!`!D````1
MP@$`"P```"O"`0`1````-\(!``X```!)P@$``P```%C"`0`'````7,(!``<`
M``!DP@$`$0```&S"`0`,````?L(!`!0```"+P@$`!@```*#"`0`:````I\(!
M``H```#"P@$``P```,W"`0`\````T<(!``0````.PP$`!@```!/#`0`'````
M&L,!`"<````BPP$`/@```$K#`0`T````B<,!`#4```"^PP$`&P```/3#`0`H
M````$,0!`"`````YQ`$`(0```%K$`0`J````?,0!`"4```"GQ`$`(````,W$
M`0`H````[L0!`"8````7Q0$`)0```#[%`0`W````9,4!`#4```"<Q0$`/```
M`-+%`0`H````#\8!`"P````XQ@$`*````&7&`0`C````CL8!`"L```"RQ@$`
M,P```-[&`0`M````$L<!`#(```!`QP$`*@```'/'`0`@````GL<!`"4```"_
MQP$`,````.7'`0`@````%L@!`"8````WR`$`1P```%[(`0!`````IL@!`!\`
M``#GR`$`+P````?)`0!/````-\D!`"\```"'R0$`,P```+?)`0`Q````Z\D!
M`#(````=R@$`+````%#*`0`A````?<H!`"T```"?R@$`*````,W*`0!-````
M]LH!`#````!$RP$`0P```'7+`0`*````N<L!`!$```#$RP$`%@```-;+`0`^
M````[<L!`#`````LS`$`#P```%W,`0`/````;<P!`!<```!]S`$`"@```)7,
M`0`,````H,P!`"L```"MS`$`!P```-G,`0`*````X<P!`#L```#LS`$`/```
M`"C-`0`K````9<T!`"<```"1S0$`'````+G-`0`)````ULT!``4!``#@S0$`
M$0```.;.`0`8````^,X!``L````1SP$`#@```!W/`0`4````+,\!`"L```!!
MSP$`"````&W/`0!(````=L\!`!H```"_SP$`&P```-K/`0`'````]L\!`!8`
M``#^SP$`#0```!70`0!$````(]`!`"@```!HT`$`%P```)'0`0`0````J=`!
M`!(```"ZT`$`-0```,W0`0`,`````]$!``T````0T0$`#@```![1`0`4````
M+=$!``H```!"T0$`'0```$W1`0`(````:]$!`"P```!TT0$`"````*'1`0`?
M````JM$!`"D```#*T0$`!@```/31`0`?````^]$!``<````;T@$`"````"/2
M`0`)````+-(!`$4````VT@$`!@```'S2`0`3````@](!`!(```"7T@$`$@``
M`*K2`0`)````O=(!``@```#'T@$`!P```-#2`0`3````V-(!``X```#LT@$`
M(@```/O2`0`4````'M,!`!@````STP$`'````$S3`0`+````:=,!``T```!U
MTP$`(0```(/3`0`+````I=,!`"T```"QTP$`#P```-_3`0`$````[],!``,`
M``#TTP$`$@```/C3`0`J````"]0!``L````VU`$``P```$+4`0`(````1M0!
M``P```!/U`$`"@```%S4`0`/````9]0!``X```!WU`$`%P```(;4`0`8````
MGM0!`!$```"WU`$`.@```,G4`0`@````!-4!`!\````EU0$`#````$75`0`P
M````4M4!``<```"#U0$`&@```(O5`0!$````IM4!`!,```#KU0$`$````/_5
M`0`(````$-8!``0````9U@$`!````![6`0`3````(]8!`!L````WU@$`!0``
M`%/6`0`&````6=8!``<```!@U@$`!0```&C6`0`2````;M8!`!,```"!U@$`
M!0```)76`0`;````F]8!`!L```"WU@$`(````-/6`0`G````]-8!`!$````<
MUP$``@```"[7`0`$````,=<!``X````VUP$`"0```$77`0`%````3]<!``(`
M``!5UP$`#@```%C7`0`\````9]<!`!4```"DUP$`+P```+K7`0!/````ZM<!
M`!@````ZV`$`>@```%/8`0`?````SM@!`#L```#NV`$`(@```"K9`0`Y````
M3=D!`#````"'V0$`-````+C9`0`W````[=D!`#<````EV@$`,0```%W:`0`X
M````C]H!`"T```#(V@$`*````/;:`0!'````']L!`!P```!GVP$`&@```(3;
M`0`4````G]L!`'T```"TVP$`#0```#+<`0""````0-P!`(````##W`$`-@``
M`$3=`0!8````>]T!`!0```#4W0$`&0```.G=`0`,`````]X!`",````0W@$`
M10```#3>`0`D````>MX!`"0```"?W@$`;0```,3>`0`1````,M\!``H```!$
MWP$`!0```$_?`0`&````5=\!``@```!<WP$`!0```&7?`0`3````:]\!`!8`
M``!_WP$`%````);?`0`?````J]\!`!````#+WP$`#0```-S?`0`$````ZM\!
M``\```#OWP$`#@```/_?`0`&````#N`!``8````5X`$`&P```!S@`0`1````
M..`!``4```!*X`$`%0```%#@`0`(````9N`!``D```!OX`$`%````'G@`0`-
M````CN`!`!H```"<X`$`"````+?@`0`2````P.`!``8```#3X`$`!0```-K@
M`0`*````X.`!``L```#KX`$`!0```/?@`0`;````_>`!``(````9X0$``@``
M`!SA`0`(````'^$!``@````HX0$`!P```#'A`0`Y````.>$!``0```!SX0$`
M`P```'CA`0`3````?.$!`!H```"0X0$`#0```*OA`0`+````N>$!``8```#%
MX0$`"P```,SA`0`3````V.$!`!D```#LX0$``@````;B`0`(````">(!`!$`
M```2X@$`-0```"3B`0`(````6N(!``D```!CX@$`%````&WB`0`%````@N(!
M``0```"(X@$`"P```(WB`0`!````O@4``(`%``#;!0``2@4``#<&````````
MQP4```X&````````5@(``%<#```/!0``F0(``!@#```K`0```````*<!````
M````6@4```````!+````A08``*H```!Z`@``5@0``)0`````````.`(``!T&
M``!>`@``````````````````/@```!\!```?````U`4``)T%``!#!@``P@(`
M```````C!@``BP8``&($``#Z`@``"0,``&X%```A!@``8@$``"L```!;`P``
M^@0``%(#``"?!@``$P8``$`"``#M`P``/@,````````$`@``?@(``-H!``"C
M!0``R@(``"\````;!```Z0```"X#``"I````K@0``.($``!L`@```````,\%
M``"<````=P,``%0&````````304``)T!````````70(```("``!P````N@0`
M`%<!``````````````````#O`@``A@0`````````````M@$``%D%``"<!0``
MNP4```````!N`P``@0````````#3`0``%@```%`&``#+!0``*@4````````'
M!@``/08`````````````T`4``'4#``!7````G`$``,8%``"$!```+0,``,,$
M````````#08``#8```!F!@``\P```````````P``E@``````````````\0(`
M`+4!``"#`0````````````!R`P``400``"4$``"'`P``\@$``#L"``!8`P``
MG`(```````#4````M@0```````!1````_`,``$$!```@`@``2@0``$H&``#%
M!0``=`$``.,%````````G@(```````````````````````#%`@``````````
M````````.@```/P!````````_`0```````"\`````````$H"``!H`@``20$`
M`,D#````````^0(``&`!``#9`0``'`(``````````````````-X"````````
M`````-<"````````!04```0$``"7!0``Z@0``(8%```L````!08``.L$``!N
M!```E@4```T```")!@``[@,``$$"```8`@```````+T%``#3!````````#D!
M``"?!0``T0,``&P&``#,`0````````````!A!0``2P4``%0`````````'@4`
M`!(%``!,!```````````````````8@(``-\%``!F`````````!4&``!*````
MPP8``'0$````````)`4``#4#````````$@$``.\`````````<08```````!5
M!````````#<%````````"`,``.4#``"\!@``1`0``,D%```V!@``!0```(\&
M``"'!@``6`0``-\"``#!!```=00``&0&````````1`8``!H$````````R`0`
M`'D#```E!@``&@,``*0!```R`0```````!0````I`@``"@8``%0#```8`0``
M`````/T"``#!`@``\@,``+8`````````Y@```&L$`````````````'L!````
M````,`(``&0$````````A@8``&L#````````908``/@$``"(`0````````L`
M````````90```!8$``#!!@``3@0`````````````"@,``.X"``#M!0``Q00`
M`*H%```V`0``]`$``+X!`````````````"<%``!Z!```#@0``!X!```O!```
ME0,``/T```#'!```N@(``(D!``#]!```V````%H#```"`P``B`4`````````
M````9P4``"$!```F````-P$````````H!0``Z`0```````#.!0``RP0``&<!
M``#8`P``D`,```````````````````````#$!@``$@(``!T"``"R````````
M`&0#``";`````````)`!```:`@``9P0`````````````O0$``#L%```5!0``
MQ0,``$D%``#^!```LP```!,%``!&`P``[0(``-4"``!T!0```````(\%````
M````<P(``"L#````````NP$``(0!````````````````````````20,``!`#
M`````````````/L!``#>!```J`$````````N!@```````($#````````````
M`#P"``"9!```S`4````````0`@``RP,``'0```"&```````````````&!@``
M``````````!B!@```````*`%``!V`0``J@,``+@"````````/`,``#,"``"O
M`@````````````!A`0``F04``)`%```K!````P4```````"*`@``[@```"D$
M``!Y!```R0```*4#````````1P0````````=`````````.L%``"O````-00`
M`)T````1!@``0`,``+T$````````A0(```````"E!@``,P```,(!````````
M`````%D#``#Q!0``2P8```````````````````````"^!@``Y0```(4!``"*
M!0```````#@&``!V!```Y@4``$(!``!R````3@$``&D!````````#@``````
M``#[````+`0``)D`````````=P0``````````````````+<%````````S```
M``````#*`0``\P,``````````````````%D``````````````,@#```6`@``
MP04``&0%```P!```#P,`````````````J@0``````````````0(````````^
M!@``5P8``-P```#D!0``:P4``.,!``#(!0````````L#```F!```````````
M```9!0``/0```)\!``"A!```X`4``!$"``````````````````"Z`P``X@``
M``````!6`P```````+,!`````````````*<"````````E@0```T%````````
MFP8```T#``!>!@``SP(```H"``#-````A@,``%P#``"3`0``]@,``)P#``!;
M!0``7P8``*@$``#/`P``PP```#X!`````````````"@!``#;`@``]P(``%$!
M``!Q`P``P@8```````!]`@```````)0#````````A00```X"``!0!0``8`0`
M``````#Q`P```````%T#``#/!```'0$``.D"`````````````&\$````````
MO0(``'0#````````````````````````E04```````"P`P```````'H!``#^
M!0``(P```%\$``!`!@``8P```,T!``#Z`0``3P,``+,%``#E!0``>P8``/`%
M``#U`@``?`,``)$$``"U`````````"0````Y!@``M`(``-<%``#=`@``&P8`
M`!L%``":````0@8``',$````````\`,```````!5!0``10(``-($``!)!@``
M'P4```````".````]`,`````````````[`0``'4%```C!```W04``"L%```A
M!0``[`,```````#,`@``X0````````!&`@```````#P&````````2P(``#8%
M`````````````-<!```;````(`,``,L!```S!0``!00``%D!````````"@0`
M`"T"`````````````$,%`````````````+D#``#@````4`(``(X"``#D!```
M408```````#V`@``5`(``(\!``!(!@``OP(``.H"``"2!0``/@(``#H%``!8
M````$`8``&\```"[`@``LP0``*\&``#]!0``C`8``!$%``"<!```*P(`````
M``#6`0```````#\&````````/P(``&H&``"K!0``6@(``-D%```>`P``````
M`!L!```S!````````'(&`````````````"H&``"4`@``Y@$``"\%````````
M(P,`````````````L@,````````E`P```````!L"``"X`P``C`0``.<`````
M````O`0``!,$````````%`,```````";`0``$````$8$````````,`,```<`
M```@!```C@8`````````````.P$``-4#```M`0``6@0``(@#````````K`,`
M`)T&```B````@P8`````````````]P,```````"`!@`````````````@!0``
M<@(```````"I!0````````````!]`0``;````&P%``#4!```B`(``#4&```[
M!@``A`,``&L```#6`P``X0,``,0"````````]@0``((&``!I!@``_0,``.`!
M``"J!@``;08``'H%```#!```J`(``#$#``!E`0``%@,``%,!```L`0``"`0`
M`,8$``!F!0``#P````````#8!0```````)@%``!2`@``+@```!@$``#V!0``
M`````"<"``#!`P``/P$``#\```````````````H!``#,`P```````!\$```&
M`@```````````````````````/\%`````````````/@%``"Q!```?P```*$#
M``"0!@``-@0``(\"``#`!@``:P(``,D"```O`P```````(`$```I`0``TP4`
M`%`$``#%!@``(@0``+4%``!_!@``50,``*T#``"&`0``[`$``/($```G!```
M``````````!T!@``I`(``*8$``#O`0``H08``,D$``#8`@``*08``$4```!I
M!0``Q@8``+X#````````BP````````!9!```I````#0"``"F`@``G0(``(D$
M````````3@(``)D!````````G00``*````#B`P``;@(```````!)!```@00`
M``````#Q!```B@,```````!(`0``@`(``%(&``#U`0``P`(``*L"````````
M>`(``$8!`````````````"T$``!'`P``-P(`````````````OP0``/P```#X
M`P``Y@(``/P"```Q````40,```````"A````Y`$``)`"````````Z@$``!8&
M``````````0``.T$``#B!0```````"(!``"@`P```````*,&``"*`0``````
M`````````````````+`$``!K`0``5`4``((```#A`0``J0,``"@$``!O!0``
M`````)8#````````X@$``!@```!H!@``B````*8%`````````````"(%``#-
M`@``_@```*X!``#"!```@@0``-0#````````?P,```````!P!0``,@8`````
M``!(!0```````+$``````````````,$!``"\!0``\P(``)(&```-`0``10,`
M`+$&``#F`P``9P(``'\$````````!P,``-L`````````V@4`````````````
MD08``%P&`````````````#@!```1!```SP$``%<%``#*`````0,``(T%``!Y
M````/@0``((!``!G!@```````%P``````````````!D"``#R````4P8`````
M``#(`0``+@4``*`&``!0`0``VP,``!P!````````K00``%X````*!0``````
M`*L#``"#`@````````<$````````X00``'T````&````K0(``&H"````````
M?04``',#``"G!@```````"0!````````!`8```D$```Q!```K0$``*@&``!N
M!@``Z0,``,8```"*````60(``'L%`````````````#H$``![!```]P0``.@#
M``"I!```$@````````"Y!```-`0``(\$```G!@``WP$``($"````````ZP$`
M`"D#``!O`0```````)8&`````````````-$"```B`P``<0```)4````8!@``
MXP(````````3`P``A04``-4%``!#`0````````````#R!0``=0$``&$````R
M`P``%0```&0!```"````-`8``/D$````````_@(```````#<`0``1`(`````
M`````````````'`#````````;0$``*(#``#[!```D@(``-4!````````````
M`)\"``!?`@``H@4``+@````C`@``808``!D&``";`@``4P````````!M!0``
M`````)8"```>!`````(``&,%```0!0``G`8``#\$``"0````,`8``+8&````
M````5`0``#H"``#L````#`(``/@!``"W`P``B0(``*X```!@````X0(``&@`
M````````<`$``&H`````````S04``(T$``#7`P``M`8```,!````````I`,`
M`-H"```!!@```````.H```"W````)0$``'@%``!3!```HP(````````G`0``
MX`0``$@"``!J!0``VP$```````#G`0``+`(```````!7`@``1P8````````C
M!0``\0````4#```1````IP```)4&```:!@``K`8```````![`@``:`,``-\$
M``"P`@``F@4``$D"``"8!```@P4``/X!````````N0$`````````````"0$`
M``````!S!0``6`$``!H%````````F@(``&X```````````````P#``"1`@``
MW`0``"\"``#Y`P``J````/X#```R`@``@`$````````@!@``W`4`````````
M````#P(```````"6`0``2P$``-8"`````````````,8!`````````````$\!
M``!M`P``000``"8"``!V`P``=@```%H&``!A!````````%($``"K````````
M``````".!0``8P,```````!X!```H0$`````````````508``/4%````````
MQ`0``'P$``````````````````"4!@``/`````````!I`@``J`4``.D!````
M````G@8``+\&``"N!@``;`$```````!%!````````,X"``!Q!0``S`0``"@`
M``!^!0``VP0```<%`````````````#@%``!?!0``^@,``%X!````````````
M``````!/````1`,````````#````C0(`````````````*`,``.D%```:````
MF`$```D&```2!@``M`4``#($````````9@$`````````````_P`````````H
M!@``\P$```````";!0``O0,``&0``````````````)H$```&`P``YP,``%0!
M````````N`4``,,%```7````UP```!<#``"X!```YP0``*X"``"T`0``0P``
M`#$"``#2`0``KP0``$P!``!Y!@``H@```'\!``!)`````````(H&``"K!@``
M"P$``"\!``"F`P``;P(``-`#``!``0``,``````````2!````````,,#``"W
M!```1@````````"D!@``=P````D"``"S!@``"04``%D&``"P!@``_P,``)$#
M``#&`@```````$<```#<`@``_P0``!<!``":`P``^`(``%4"``#%`0``#P$`
M```````B!@```````!X```#W`0``D@,``)\`````````#00``#0!````````
MYP(```````!'`0``9@0``/\"``!I!```:@,``$L$``#X`````````(<`````
M````A````*4$```F`P``B0```(L$````````%00``*,$```G`P``J0(``#T#
M``"C`0``6`4``"4```#"!0```````(8"````````,@4``,0#``##`@``````
M``````!-!@``L`$``#8#```J`P``-`4``$`$```[`P```````!P%````````
M`````$X%``#H``````````````![`P``O`,``.P%```+!````````.0"```5
M`0````8``*`"``"S`@``=0(````````(!0``>0$``!(#``!!!0``%`0``!,!
M````````,0$````````\!0``E0$```````#'`P``%@$``)<"``#M````G@4`
M``@```!S````P`,``*`!``"C``````````````#5````3`(``.4$````````
MIP4``'($``"O`0``\`0``!0"```7!```)04``$\$``"M!0``N@8```T"````
M````!0$``+@!```Z`0``+0```&`"``##`0````````````!/!0``CP``````
M````````R````*4%`````````````/`````U!0``^0$```````#)`0``````
M`#$%``#N`0``6`8``/<%``"0!````````$0!````````_0$``%,%``!A`P``
MJP0````````8!0``K`(``"$````@`0``4P(``$($``"F!@```````-8```"R
M!0``%`$```````!Y!0``T0$``"P&``!L!```900``-,`````````T`0```0#
M````````L@0``(L%``!V`@``&00``%T!``"L````B`8``-T`````````50$`
M``````!R`0``A`(``"@"``!?`0``-0(``!P````6!0``5P0``+4#```"`0``
MS0,``.0#`````````````$8%````````#`$``/`"```\`0``>`8``$,"```[
M!```#@$``"T&``#H!0```````#@$````````M0(``%L!```L!0``0P,``)H&
M```+!@```````'T&```4!0```````.T!`````````````)<!``!X`0``104`
M`*P%``"T````ZP,``)<&```I````E00```````````````````````!6!@``
M+P8``*$%```<`P``XP````````!%!@``[P,``/L%```!`0````````P%````
M````9P,```````#3`P```````+8%````````M@,```````#3`@``3@,`````
M``#2!0``=0```,T$````````U00```X%`````````````+\%``!V!0```@8`
M`+L&```T````````````````````BP,``+D%``#&`P```````+\!```J`@``
M0P0``)(`````````>@8```````#\!0``0````$H#`````````````"L&```Y
M!0````````8$``#C`P``V0````````"1````]00```````!<!0``"`$```($
M``#H`0``,P8````!``!F`P``AP(``,<"````````4P,```````"$!0``[@4`
M``````!=!@```````$<%``"K`0`````````````^!0``O@```$P```"``P``
M$`0``!\#``#'`0``.0(```L"``"M!@``D04``,`$``"T!```9P```'P!``!-
M``````````````!>!````````#`%```D!@```````(P!``````````````0%
M```9`P``J`,``$`%``!0`````````)$!``#`````E0(```````#@`P``'04`
M`/0```!,!@```````!,"````````H@0```````"[`````````-X%```<!@``
M)`0```H```!:````]P`````````3````?`(``!<%```&!0``=P(``+4&``!;
M!```P`4``(L!```$`0``UP0``*,#``!!!@``Z00``!<"``!Q!```T```````
M``!Z`P``:`$``%\`````````Z@4``!X&```````````````````F!0``````
M`.$%``!Z````F`,``((%```J!```=@8``,4```"-`0``WP,``($&``!T`@``
M\`$`````````````3@````````"Z!0``IP,``&,!``#V````A`8```````"_
M````T@```'4&```]`@```````'<%``#R`@``8`,``'`"````````)0(``&$"
M``"#`P``````````````````````````````````>````-H#```,!@``````
M`!4#``#E`0`````````````\!```EP,``,0%````````6P8``"8!```M!0``
M`````'$!``!I`P``6P`````````S`0``N@$``/H%``"-````>`,``)<`````
M````EP0``/,%``""`@``M`,``+(&``#"`P```````-(#`````````04`````
M``#6!0``90,``#0#``"3!@``00```/$!``#K````)@8``+<"``"[`P``;P,`
M`,L"```/!```7@4``%P"``",``````````````!(!````````*4"```'`0``
M`````#4`````````7`$``/,$````````&0$``+\#````````(0,``.L"```,
M````>P```````````````````+````!B`P```````&@$``#*`P``7@,``&(`
M``"[!```]`0```(%````````:P8```````"D!0``40(```````#H`@``?0,`
M`$H!```C`0``/0$``-X```"3`P``)`(``)(!``#"````$`$````````9````
MK`$``#<```">!````````&T$```D`P``F`8``,0!```1`P``(@(``+("``!S
M!@``4@```$0```"Z````DP```-T$````````8`8``/0%```Y`P```````(L"
M```V`@``1@8``*(&``!2!0``0@,```````"4!0``[`(``/0"````````H@$`
M`(<%``"3!```=P$``+`%``!^!@``U@0``',!``"\`0``W`,``$L#````````
M;`,``+$!````````O`(``)X```!C!@``X@(``"D%``";!````````$\"````
M````/00``(````#:!````````(\#````````Y@0``)H!``#1!```H`0``$(`
M```)````<`0``-`!``"#!`````````````"2!```#@,```````",!0``````
M```````N!````````%8```">`0``O08``&T```#_`0``R@4``-T#```/!@``
M`````)@```"O`P```````.X$``#J`P```````"P#````````J08``$(%``!"
M`@```````-X#````````%P8``)D&``!=!0``10$```````"O!0``T`(`````
M````````-0$```,"``#O!0``A0,```<"``!P!@``N`8``#`!``"J`0``90(`
M`%T$````````Q````%4````=`P``00,``),%``""`P``(`````````"^`@``
MR@0``$0%``";`P``<0(``&,"``!J`0```````,L````Q!@``W0$``(<!``#!
M````404``````````````````%8!``"4`0``9@(``)T#`````````````!$!
M``!6!0``4@$``&4%``!D`@``K0````````"F`````````%H!``!J!```/P4`
M`)\#``````````````````!H!0```````+T`````````YP4```````!M`@``
M`````!\&````````L@$``````````````````)X#```J``````````````"(
M!```/P,``%@"``#.````H0(``````````````````&\&`````````P8``($%
M``!=`````00``!4"``"F`0``IP0```````"S`P``R`(``'D"``#9`P``P`$`
M``````"E`````````#<$``#8`0``?@```"<````>`@````````````!.!@``
ML0(``-0!``"'!```8P0```,#``!^`0``?P(```L%``#8!```:0````0```"B
M`@``.0````4"``"Y!@``MP$```````"!`0```````!L#`````````````!T$
M``!-`0``,@```(X!````````J0$``+8"``!0`P``8@4``-0"``"Q`P``SP``
M`(4```!^!````````),"````````V00```8!``!-`P````````@&```4!@``
MC@,``+X$```J`0``30(``(P#````````/04``#D$``#1`````````'T$``!<
M!```B04``$P#``#:````.P``````````````(0(``*X#```A!```;@$``.0`
M````````<@4```````"9`P``W@$``%\#```(`@```````*P$``#E`@``````
M``````!_!0```````(,````N`0``]@$``-D"``"E`0``I`0````%``!,!0``
ME`0`````````````K@4```````#[`@``MP8``,X#``"8`@``'P(``-("``#.
M`0``.@,```````"Q!0``,P,``$T$```X`P``GP0``+D```"*!````````,X$
M``!(`P``&@$``(T&````````-P,```````"J`@``.````-\```!'`@``[P0`
M`(P"``!;`@``C0,``,<```#C!```]0```/D````,!```.@8``$@```!W!@``
M```````````<!````````+4$``!\!@``X`(``-$%````````B0,``/L#``"Y
M`@``?````&`%````````]0,````````N`@```````'P%````````````````
M``#Z````C@0``/D%````````3P8`````````````?@,````@*"5S(&1A>7,@
M86=O*0`@*$%C8V5S<VME>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@
M*'1O;6]R<F]W*0`@*'EE<W1E<F1A>2D`(&%T(``B)7,B(&ES(&YO="!A(&1I
M<F5C=&]R>2X`)60@)7,@86YD("5S`"5D(&)Y=&5S('=R:71T96XN`"5D(&]F
M("5D(&5N=')I97,@;6%R:V5D(&%S('5P+71O+61A=&4`)60M9&%Y(&9O<F5C
M87-T`"5S("T@3F]T:6-E`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT
M96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T=7``)7,@
M4VEG;B!5<``E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D>2!E>&ES
M=',N`"5S(&%T("5S("5S`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@
M;F]T(&9O=6YD+@`E<R!N;W0@9F]U;F0N(%)U;B`G=')A;G-L871I;VX@97AT
M<F%C="<@9FER<W0N`"5S('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K
M`"5S)W,@0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z
M("5S`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`
M+2T@<V5L96-T("TM`"TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0`Q,B!(
M;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P`\4')E=FEO=7,`
M02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K
M+@!!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y
M(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!0
M1U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E
M+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P
M=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O
M34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3
M+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)
M344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!32!#
M;&]U9',`04T@3&EG:'0@4F%I;@!!32!286EN`$%-(%-H;W=E<G,`04T@4VYO
M=R!3:&]W97)S`$%-+U!-`$%022!)1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U
M="XN+@!!8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5S<R!D96YI960@8W)E871I
M;F<@5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@
M9FEL92X`06-C;W5N="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N
M=&EN9P!!9&0`061D($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N
M`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!
M9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D
M('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D
M9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D
M('5S97(`061D:6YG(&YE=R!F:6QE<R!T;R!R97!O<VET;W)Y.@!!9&1I;F<@
M=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S<R!";V]K`$%D;6EN
M:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN
M:7-T<F%T:6]N`$%D<P!!9F=H86YI<W1A;@!!;&)A;FEA`$%L9V5R:6$`06QI
M87,`06QI9VX`06QI9VYM96YT.@!!;&P`06QL($%U=&AE;G1I8V%T960@57-E
M<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@<VED97,`
M06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@;W)D
M97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)35-0
M($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0
M(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T
M96UP;&%T97,`06QT97)N871E('1E>'0Z`$%M97)I8V%N(%-A;6]A`$%N(&EL
M;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06X@=6YK;F]W;B!E<G)O<B!H
M87,@;V-C=7)E9"X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM;W5S
M(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U9&$`
M07!P;&EC871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R
M96%D>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P<F]X:6UA
M=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C:&EV92!&
M:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T
M;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R9V5N=&EN
M80!!<FUE;FEA`$%R;65N:6%N("A!4DU30TE)+3@I`$%R=`!!<G5B80!!<V-E
M;G-I;VX@27-L86YD`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S
M:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O
M<&5R871I;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`071T96UP="!T;R!D96QE
M=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@
M;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO
M;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM
M97AI<W1E;G0@<VAA<F4N`$%T=')I8G5T97,`075G=7-T`$%U<W1R86QI80!!
M=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R
M97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA
M<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM
M96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!297%U:7)E9"!,1$%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D
M9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``075T
M:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5
M;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]M8V%L.B!297%U:7)E9"!-
M0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER
M960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO
M;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A
M=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO
M;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@=&\@=&AE
M(%--0B!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I
M:F%N`$)/1D@@17AC=7-E<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`
M0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N
M`$)A:&%M87,`0F%H<F%I;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D
M97-H`$)A<F)A9&]S`$)A<V5L:6YE`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`
M0F5N:6X`0F5R;75D80!":'5T86X`0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A
M<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO
M8VL@5'EP90!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@
M=&AI8VMN97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T
M:`!";W1S=V%N80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES
M:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U
M:6QD:6YG($U/(&9I;&5S(&9O<B!M;V1U;&4@)7,N+BX`0G5I;&1I;F<@;&]C
M86QE("5S+BXN(`!"=6QG87)I80!"=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S
M;P!"=7)U;F1I`$--4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E
M;&P@4')O<&5R=&EE<RXN+@!#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D
M+@!#86QE;F1A<@!#86QM`$-A;6)O9&EA`$-A;65R;V]N`$-A;B!N;W0@<F5S
M970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN
M:7-T<F%T;W(N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A
M;F%D80!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;FYO="!D96QE
M=&4@9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O
M<GDN`$-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M
M971E<BX`0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E
M;6]V92P@)60@8VAI;&1R96X@97AI<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB
M97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M
M871C:"!N=6UB97(@<W1O<F5D+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S
M<&5C:69I960@;G5M8F5R+@!#87!E(%9E<F1E`$-A<'1I;VX`0V%T96=O<FEE
M<R!A;F0@3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0
M<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@
M<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E
M<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H
M25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!/
M=VYE<@!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H86YG90!#:&%N9V4@
M=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE
M>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA<@!#:&5C7VL@
M3&EN:RXN+@!#:&EL90!#:&EN80!#:&EN97-E(%-I;7!L:69I960@*$=",C,Q
M,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`0VAO;W-E(&$@<&%S<W=O
M<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A
M=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T
M<RD`0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D969I;FET:6]N(&]F("5S(&YO
M="!F;W5N9"X`0VQE87(`0VQE87(@35-/9F9I8V4@=&%G<P!#;&5A<B!O=70@
M=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQE87)I;F<@
M3&%T90!#;&EC:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL('9I82!(5%10`$-L
M;W-E(%=I;F1O=P!#;&]U9',`0VQO=61S($5A<FQY`$-L;W5D>0!#;V-O<R`H
M2V5E;&EN9RD@27-L86YD<P!#;VQL87!S92!3:61E8F%R`$-O;&QA<'-E9"!B
M;W)D97)S`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L
M96-T:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S`$-O;6UA;F0`0V]M
M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N
M>0!#;VUP;W-E($UE<W-A9V4@*"5S*0!#;VUP=71E<G,`0V]N9&ET:6]N<P!#
M;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R871I;VX@:7,@;W5T
M(&]F(&1A=&4N`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O;F=O
M`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4`0V]N;F5C
M=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!R
M969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E
M9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S
M*0!#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#;VYT86-T<R!W
M97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`
M0V]N=&EN=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@9F%I;&5D
M.B`E<P!#;W!Y('-E;&5C=&EO;@!#;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`
M0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3
M+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S
M`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8VAE
M8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,`0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N`$-O=6QD
M(&YO="!D96QE=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&1E;&5T92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C
M:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!F971C:"!C;VUP
M;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D
M:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T
M92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&]B=&%I
M;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P
M96X@)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE
M("5S`$-O=6QD(&YO="!R96%D("5S+@!#;W5L9"!N;W0@<F5S970@=&AE('!A
M<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F
M('1H92!D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O
M;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@
M:&5L<"X`0V]U;&0@;F]T(')E=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE
M=F4@861D<F5S<R!B;V]K+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I
M8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I
M;VX@;&ES=',N("5S`$-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A
M8FEL:71I97,`0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L
M9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A
M(&)A8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P
M(&-O;F9I9W5A=&EO;CH@)7,`0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C
M;VYF:6=U<F%T:6]N(&9I;&4@)7,N`$-O=6QD(&YO="!S879E('1H92!C;VYF
M:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@
M=&AE(&]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O
M<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N`$-O=6QD(&YO="!S
M96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A
M8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S
M`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E
M('1H92!S:61E8F%R(&ES(&]P96XN`$-O=6YT960@=&5X=`!#;W5N=')Y`$-O
M=7)S97,`0W)E871E`$-R96%T92!A(&QI;FL`0W)E871E(&$@;F5W(&]N90!#
M<F5A=&4@<W5B(&9O;&1E<G,`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@
M8V%R9"!N=6UB97(`0W)O871I80!#=6)A`$-U<G)E;G0@-"!0:&%S97,`0W5R
M<F5N="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@5V5A=&AE<@!#=7)R
M96YT(&-O;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE('1A<VMS
M('1O(')U;B!U<&]N(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C=&EO;@!#
M>7!R=7,`0WER:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U
M,2D`0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I`$-Z96-H(%)E<'5B;&EC
M`$1$`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T90!$871E(%)E8V5I=F5D
M`$1A=&4@<V5L96-T:6]N`$1A>0!$95]L971E($-O;'5M;@!$96-E;6)E<@!$
M96-I;6%L(&YU;6)E<G,`1&5C<F5A<V4@26YD96YT`$1E9F%U;'0`1&5F875L
M="!#;VQO<@!$969A=6QT($ED96YT:71Y`$1E9FEN:71I;VYS`$1E;&5T90!$
M96QE=&4@1W)O=7``1&5L971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G
M92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E
M>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E(')O=P!$96QE=&4@
M<V5L96-T960@:61E;G1I='D`1&5L971E('1H92!C=7)R96YT(&-O;'5M;@!$
M96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$
M97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS("AA;'-O
M(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO9V=E
M9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN
M=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I<F5C
M=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T`$1I
M<F5C=&]R>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N
M<P!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R;6%T`$1I<W!O
M<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!N;W0@9&5L971E`$1O
M(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O97,@=&AE
M(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C
M:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B;&EC`$1O
M=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U
M<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$4M
M36%I;`!%4E(`16-U861O<@!%9&ET`$5D:70@0FQO8VL`161I="!'<F]U<`!%
M9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I
M;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS
M(&9O<B`E<P!%9'5C871I;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE;65N="XN
M+@!%;0!%;6%I;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T
M(&UA=&-H+@!%;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%;6]T:6-O;G,`16UP
M='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;7!T>2!S96%R8V@@=&5R;7,`
M16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I
M97,@:6X@=&5X=#\`16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`
M16YD('EE87(`16YL87)G92!%9&ET;W(`16YT97(@82!S96-U<FET>2!Q=65S
M=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R
M97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F
M('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%<75A=&]R
M:6%L($=U:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R('=I=&@@96UA:6P@;65S
M<V%G92X`17-T;VYI80!%=&AI;W!I80!%=&AN:6,`175R;W!E`$5V97)Y(#$U
M(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E
M<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R
M>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X96-U=&4`17AP86YD`$5X<&%N
M9"!3:61E8F%R`$5X<&5C=&5D("<I)P!%>'!E8W1E9"!B87)E('=O<F0@;W(@
M<75O=&5D('-E87)C:"!T97)M`$5X<&ER871I;VX@1&%T90!%>'!O;F5N=`!&
M1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE9"!R971R:65V:6YG
M('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E
M<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D('1O
M(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B)7,B+@!&86EL
M960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T;R!M
M;W9E('1O("(E<R(N`$9A:6QE9"!T;R!R971R:65V93H@)7,`1F%I<@!&86QK
M;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@27-L86YD<P!&871A;"!%
M<G)O<CH`1F%X`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9E
M=R!3:&]W97)S`$9E=R!3;F]W(%-H;W=E<G,`1FEE;&0@;6%T<FEX`$9I:FD`
M1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE
M($UA;F%G97(`1FEL92!.86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D
M`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QT97)S`$9I;FQA;F0`
M1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&EP`$9L;V%T
M`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]N="!#;VQO<@!&;V]D
M`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C
M87-T("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N
M960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R
M9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`
M1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T
M>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S`$9R`$9R
M86UE<P!&<F%N8V4`1G)A;F-E+"!-971R;W!O;&ET86X`1G)E;F-H($=U:6%N
M80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE
M<P!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&
M=6QL($YA;64`1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L
M;&5R>3H`1V%M8FEA`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`1V5N97)A
M=&5D($-O9&4`1V5O<F=I80!'97)M86YY`$=H86YA`$=I8G)A;'1A<@!':79E
M;B!.86UE`$=O`$=O961E;`!';V]G;&4@4V5A<F-H`$=R87ES8V%L90!'<F5E
M8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N861A`$=R;W5P
M($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y
M`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U
M97-T(%!E<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A
M=0!'=7EA;F$`2%1-3`!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E
M;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@
M<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R
M;W<@:6X@=&%B;&4N`$A45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(
M86ET:0!(87-H+4%L9V]R:71H;0!(87IE`$AE861E<@!(96%R9"!)<VQA;F0@
M86YD($UC1&]N86QD($ES;&%N9',`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE
M:6=H=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E
M`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M
M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@061D
M<F5S<P!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D
M92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M
M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S
M('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@
M)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U
M;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T
M:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO
M;@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@
M9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E
M<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)
M344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@
M56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z
M(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A
M;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H
M4&QE87-E(')E<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI
M:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H
M97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(
M=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-05`@;6%I
M;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE=&EO
M;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL
M960Z("5S`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)
M4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)4"!L
M;V-K9&]W;B!V:6]L871I;VXN`$E?;G-E<G0@4F]W($)E9F]R90!)8V5L86YD
M`$EC;VYS($]N;'D`26-O;G,@9F]R("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N
M=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY
M+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@>6]U(&1O;B=T
M('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M
M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A
M;G-P87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA
M9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES
M<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE=SH`26UA9V4@
M55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@
M9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0L(%-T97`@)60`
M26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2
M;W<@069T97(`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E
M8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA
M;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T
M('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N
M`$EN8W)E87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L(%5S97)S`$EN9&]N
M97-I80!);F9O`$EN9F]R;6%T:6]N`$EN:71I86QI>FEN9R!M;V1U;&4@)7,N
M+BX@`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R="!);6%G90!);G-E<G0@
M5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R90!)
M;G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E
M<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T
M(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W
M(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P
M:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B
M969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@86QT97)N871E('1E;7!L
M871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@
M<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E<G0@8V5L;"!A9G1E<@!)
M;G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@
M8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`26YS97)T('!A<F%G<F%P
M:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R90!);G-E<G0@<F]W(&%F
M=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T:&4@<F5Q=6ER960@86YS
M=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`26YS97)T+TUO9&EF>2!)
M;6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F:6-I96YT(&-R961I="!T
M;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="X`26YS=69F:6-I96YT
M(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`26YV86QI9"!51$@N("A5
M<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI
M9"!B871C:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D
M97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L
M:60@;&EC96YS92!K97DN`$EN=F%L:60@;&]C871I;VX@<')O=FED960N`$EN
M=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN
M=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P
M97)M:7-S:6]N+@!);G9A;&ED('!A<G1N97(@:60N`$EN=F%L:60@<')O9'5C
M="!C;V1E+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED('-H87)E(&]B:F5C
M=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T
M82X`26YV96YT;W)Y`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)
M<F5L86YD`$ES;&4@;V8@36%N`$ES;VQA=&5D(%0M4W1O<FUS`$ES<F%E;`!)
M<W-U97(`271A;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A
M;F5S92`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU
M<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F
M=`!*=7-T:69Y(%)I9VAT`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N
M>6$`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+
M97)N96P@3F5W8FEE<P!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME
M>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T
M<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E
M82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P
M=6)L:6,@;V8`2V]R96%N("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$QA
M7WEO=70`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L
M:6,`3&%S="!(86QF`$QA<W0@475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@
M;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@
M3F5V97(`3&%T=FEA`$QA=P!,87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O
M<F1E<@!,96)A;F]N`$QE9G0`3&5F="!H96%D97(`3&5F="!V86QU97,`3&5S
M;W1H;P!,:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS
M=&5I;@!,:6=H="!$<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L
M>0!,:6=H="!286EN($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I
M;B!W:71H(%1H=6YD97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,
M:6UE<FEC:P!,:6YK`$QI;FL@<&]I;G1S('1O.@!,:6YK('1H92!E;6%I;"!A
M9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI
M;FMS`$QI;G5X($-O;VMI90!,:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD
M97(`3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE
M<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/=VYE<@!,
M:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T
M:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI80!,
M;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I
M;VX`3&]G(&EN`$QO9R!O=70`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E
M8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I
M;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`
M3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S`$QO=V5R
M(')O;6%N(&YU;6)E<G,`3'5X96UB;W5R9P!-30!-3U1$`$U3+51.148@071T
M86-H;65N="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI
M82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-861A9V%S8V%R
M`$UA9VEC`$UA:6P`36%I;"!!9&UI;@!-86ME(&QI;E]K+BXN`$UA;&%W:0!-
M86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O
M9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N
M9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA
M<#(T(&UA<`!-87!1=65S="!M87``36%R8V@`36%R9VEN`$UA<FL@=VET:"!3
M965N+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@
M26UP;W)T86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ
M=64`36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET:75S`$UA>"!A
M;&QO=V5D(&-R961I="X`36%X(&UE<W-A9V4@<&%R=',@97AC965D960N`$UA
M>"!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z
M(`!-87AI;75M(&QE;F=T:`!-87D`36%Y;W1T90!-961I8VEN90!-96UB97)S
M`$UE;G4@;6]D93H`365R9V4@8V5L;',`365S<V%G90!-97-S86=E(%9E<FEF
M:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E
M(&-O=6QD(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E>'!I<F5D+@!-97-S
M86=E('1Y<&4`365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA
M8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@
M8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971A<D1"(&ES
M(&YO="!C;VYN96-T960N`$UE=&AO9`!-971R:6,`365X:6-O`$UI8W)O;F5S
M:6$L($9E9&5R871E9"!3=&%T97,@;V8`36ED9&QE`$UI;64@5'EP90!-:6X@
M=&5M<"!L87-T(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``
M36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!014%2('!A8VMA9V4@2%14
M4%]297%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O
M(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L
M:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG(')E<75I<F5D
M(%!%05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@240N`$UO`$UO
M8FEL92!-86EL`$UO9&5R871E`$UO9&EF:65D($1A=&4`36]D:69Y(%523`!-
M;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYG;VQI80!-
M;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1S97)R870`36]O;B!0:&%S97,`
M36]R;V-C;P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D>0!-;W-T;'D@4W5N
M;GD`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V
M92!D;W=N`$UO=F4@=7``36]Z86UB:7%U90!-=6QT:2UL979E;"!D<F]P(&1O
M=VX@;&ES=',`375L=&EP;&4@<V5L96-T:6]N`$UY($%C8V]U;G0`37D@4&]R
M=&%L`$UY(%!O<G1A;"!,87EO=70`37EA;FUA<@!.3RP@22!$;R!.3U0@06=R
M964`3F%M90!.86UI8FEA`$YA=7)U`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE
M<FQA;F1S($%N=&EL;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!
M(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A
M<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A
M<&4@4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O;6UE
M;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R`$YE
M=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!-;V]N`$YE=R!5<V5R;F%M
M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!W:6YD;W<@*%]B;&%N:RD`
M3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="`T(%!H87-E<P!.97AT(&]P=&EO
M;G,`3F5X=#X`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.
M;P!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF
M9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN
M9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T96UP;&%T92X`3F\@8FQO8VL@97AI
M<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VX`3F\@8V%L96YD87(@;F%M
M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BX`3F\@8VAA;F=E
M+@!.;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N
M+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N
M`$YO(&1E<W1I;F%T:6]N('-U<'!L:65D+@!.;R!F:6QE('5P;&]A9&5D`$YO
M(&EC;VYS(&9O=6YD+@!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&QO8V%T:6]N
M('!R;W9I9&5D+@!.;R!M97-S86=E('-U<'!L:65D+@!.;R!N86UE('-P96-I
M9FEE9"X`3F\@;G5M8F5R('-P96-I9FEE9"X`3F\@;V9F96YS:79E(&9O<G1U
M;F5S`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T
M:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A
M=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@
M875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@
M875T:&5N=&EC871I;VXN`$YO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y
M('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O
M('=O<FL@=VET:"!02T-3(#$R(&1A=&$N`$YO('!E;F1I;F<@<VEG;G5P<RX`
M3F\@<75O=&$@<V5T+@!.;R!R=6QE<P!.;R!S:61E<P!.;R!S=6-H(&9I;&4`
M3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.
M;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L:60@6$U,
M(&1A=&$@<F5T=7)N960`3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U;F0@:6X@
M;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T
M:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@
M4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;VYE`$YO;F4@*'5S92!I;7!L
M:6-I="D`3F]R9&EC("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!)<VQA;F0`3F]R
M=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R;B!-87)I86YA($ES;&%N9',`3F]R
M=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E`$YO="!A(&1I<F5C=&]R>0!.;W0@
M:6UP;&5M96YT960N`$YO="!S970`3F]T('-U<'!O<G1E9"X`3F]T97,`3F]T
M:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO=F5M8F5R`$YU;6)E<@!.=6UB
M97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@
M<F]W<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I
M<W1R:6)U=&EO;B!L:7-T+@!/2P!/8FIE8W0`3V)J96-T($-R96%T;W(`3V-T
M86P`3V-T;V)E<@!/9F9E;G-E(&9I;'1E<@!/9F9I8V4`3VUA;@!/;FQY($E-
M05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N
M<VEV92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N
M`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C
M:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H
M87)E`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD
M(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N`$]P
M96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E
M;0!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R9&5R960@3&ES=`!/<F=A;FES
M871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L
M(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E
M<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`3W=N97(@4&5R;6ES<VEO;G,`
M4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!'4"!$:6=I
M=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D($1A=&$`4$=0(%!U8FQI8R!+
M97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`@0V]D90!02%`@4VAE
M;&P`4$T@3&EG:'0@4F%I;@!032!3:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3
M:&]W97)S`%!-(%-U;@!032!4+5-T;W)M<P!07TA0(%-H96QL`%!A9&1I;F<`
M4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE
M9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A>0!087)T;'D@0VQO
M=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!R97%U
M:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H
M(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@
M;75S="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!0
M96YD:6YG(%-I9VYU<',Z`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E
M;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B!$96YI960`4&5R
M;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R<V]N86P@26YF;W)M871I;VX`
M4&5R=0!0971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0
M:7AE;',`4&QA=&ET=61E<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`
M4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E
M;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN
M:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE
M87(N`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ
M`%!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E
M<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T
M:&4@;6]N=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!P
M<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I
M9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E('1Y<&4@=&AE
M(&YE=R!C871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R
M='5G86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O
M9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E
M9"!B>2!)34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ
M(`!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N
M(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``
M4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W
M('=I;F1O=P!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A
M=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0
M<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U
M8FQI8R!+97D@26YF;P!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE
M<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!1871A<@!1=65R>0!2
M4T$@4'5B;&EC($ME>2`H)60@8FET*0!2861I;R!S96QE8W1I;VX`4F%I;@!2
M86EN($5A<FQY`%)A:6X@3&%T90!286EN(%-H;W=E<@!286EN(&%N9"!3;F]W
M`%)A:6X@=&\@4VYO=P!286YD;VT@1F]R='5N90!2871I;P!296%D`%)E860@
M;65S<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N
M;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S
M97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E9&]E
M<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE
M;G1S.@!2969R97-H(%!O<G1A;"!6:65W.@!296=E>`!296QA=&EO;G-H:7`@
M0G)O=W-E<@!296UA<FMS`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT
M='`Z+R]W=W<N97AE;7!L92YE<R]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO
M8VL`4F5M;W9E(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@<&%I
M<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y
M(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@
M=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!297%U
M97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z
M(`!297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N`%)E<75I
M<F5D($9I96QD`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T(%EO=7(@4&%S
M<W=O<F0`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2975N:6]N`%)E=F5R
M="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D
M;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?=R!0<F]P
M97)T:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T
M`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2
M;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S
M(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN
M<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY`%)U
M;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O34E-12!#<GEP=&]G<F%P
M:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`4T%33"!A
M=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@365S<V%G:6YG
M`%-13"!3:&5L;`!34T@`4U5#0T534P!37U%,(%-H96QL`%-A`%-A:6YT($AE
M;&5N80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@
M4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E
M;F%D:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!3
M86\@5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I9&5R`%-A=61I
M($%R86)I80!3879E`%-A=F4@)7,`4V%V92!/<'1I;VYS`%-A=F4@9V5N97)A
M=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R
M=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A
M=&EO;BX`4V-A='1E<F5D(%0M4W1O<FUS`%-C:65N8V4`4V5A<F-H`%-E87)C
M:"!%;F=I;F5S`%-E;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A
M(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R
M=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A;&P@9&%T92!C;VUP
M;VYE;G1S+@!396QE8W0@86X@;V)J96-T`%-E;&5C="!T:&4@8VAA<F%C=&5R
M<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N
M(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+@!396QE
M8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T
M.@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93H`4V5L
M96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L96-T('1H92!T:6UE(&9O<FUA
M=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O
M;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!3
M96YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;F5G86P`4V5N<V]R.B``
M4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I86P@3G5M8F5R
M`%-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N`%-E<W-I;VX@
M240@97AP:7)E9"X`4V5T`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R
M97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T
M('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R
M;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@
M=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A
M<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N
M9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A9&4@
M<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@
M=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3:&]P<&EN9P!3:&]R
M="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M
M;W-T(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R
M96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A
M=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3
M:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H;W<@
M=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O
M;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I
M86QO9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H
M92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@
M<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W97)S
M($5A<FQY`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6:6-I;FET>0!3
M:')I;FL`4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U
M="!O9B!T:&4@=V%Y(&9I<G-T`%-I97)R82!,96]N90!3:6=N('5P`%-I9VYA
M='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@
M36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=P!3;F]W(%-H;W=E
M<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO=V5R
M<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z
M(`!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3;VYG<R`F(%!O96US`%-O<G0@
M;W)D97(@<V5L96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC80!3
M;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@
M=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R
M90!3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@
M8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A
M8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R
M($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R
M=',`4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R="!Y96%R`%-T
M871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R86=E(&9O<FUA=`!3=')E970@
M061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I
M;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=`%-U`%-U8FIE8W0`4W5B
M;6ET`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C
M;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F
M=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY
M('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C
M97-S9G5L;'D@=W)O=&4@)7,`4W5D86X`4W5M;6%R>0!3=6X@4FES90!3=6X@
M4V5T`%-U;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U
M;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U
M<FYA;64`4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N
M`%-W:71Z97)L86YD`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER
M:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M(&%N9"!7:6YD>0!4
M+5-T;W)M<P!44U8@9FEL90!486)L92!0<F]P97)T:65S`%1A8FQE('!R;W!E
M<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI
M<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S
M:W,`5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP
M97)A='5R90!496UP97)A='5R93H@`%1E;7!L871E($%D;6EN:7-T<F%T:6]N
M`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I("A4
M25,M-C(P*0!4:&%I;&%N9`!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A
M:6QA8FQE+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O
M97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D
M:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H
M87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@861M:6YI<W1R871O<B!N965D<R!T
M;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I
M9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED
M92!O;FQY`%1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE
M9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S
M92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R
M(&%D9')E<W,@8F]O:RX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO
M8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`
M5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I
M9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E
M+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H
M92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O
M;FYE8W1I;VXN`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T
M=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T
M:6YG<RX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I
M;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE
M<W-A9V4N`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E
M('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W
M<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@
M(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O
M9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S
M:&5S+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@
M;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@
M1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W
M87)N960N("!0;&5A<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@
M=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B
M(&AA<R!B965N(&1E;&5T960N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H
M92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@
M=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT(&]N
M("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE
M9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@
M8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N
M(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;W!E;G-S;"!M;V1U
M;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L
M87-S+@!4:&4@<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B92!S879E9"!B
M96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M(&%L;&]W86)L
M92!S:7IE`%1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP
M92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE(')I9VAT
M(&%N9"!L969T('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED92!O;FQY
M`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R
M("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@
M)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE('1E;7!O<F%R>2!F:6QE("(E<R(@
M9&]E<R!N;W0@97AI<W0N`%1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY
M`%1H92!T;W`@<VED92!O;FQY`%1H92!U<&QO861E9"!D871A('=A<R!L;W-T
M('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL92!C
M;W5L9"!N;W0@8F4@<V%V960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N
M;W0@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N
M`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL
M:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I
M96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[('EO=2!M=7-T
M(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H
M('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R92!W
M87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S
M(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W960@<VEZ92`H)60@8GET
M97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D
M.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R92!W
M87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A
M+@!4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R
M;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE
M<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R
M97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H
M97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS
M+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G
M86EN(&QA=&5R+@!4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@
M<VAA<FEN9R!F;VQD97)S+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A
M('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B
M92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@
M82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO
M+V-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`
M5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G
M:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A
M>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE
M($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@
M<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F;VYE($ET86QY
M("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N
M`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI<R!F
M:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BX`
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`5&AI
M<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI
M<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M
M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@
M=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N`%1H
M:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`5&AI<R!I<R`E
M<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@
M=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C;&EE;G0@=&AA
M="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R
M(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L:65N=',@<&QE87-E('9I<VET("5S
M`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@
M*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M=7-T(&)E
M(&%T(&QE87-T(&]N92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z
M:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D
M96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES
M('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W
M`%1H=6YD97(`5&EC:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`5&EM92!F;W)M
M870`5&EM92!S96QE8W1I;VX`5&EM;W(M3&5S=&4`5&ET;&4`5&ET;&4@*'1O
M;VQT:7`I.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W
M;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE
M(&-L:6-K:6YG+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME
M;&%U`%1O;6]R<F]W`%1O;F=A`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1R86YS
M;&%T:6]N<P!4<FEN:61A9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L<V4`5'4`
M5'5N:7-I80!4=7)K97D`5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES
M=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L86YD<P!4=79A;'4`5'EP92!Y;W5R
M(&-H;VEC93H@`%4N5BX@:6YD97@Z(`!54DP`55),(&9O<B!Y;W5R('-C<FEP
M="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T`%523#H`56=A;F1A`%5K<F%I;F4`
M56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D
M(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B
M;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N
M86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N
M`%5N86)L92!T;R!C:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C;VYN96-T('1O
M(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B
M;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER
M96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`
M56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!6
M1E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I
M;&4N`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE
M=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T
M;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L
M92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E
M<R(N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE
M=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U
M<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E
M8W1O<GDN`%5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',`
M56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T
M;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B)7,B
M+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`56YA8FQE
M('1O(&]P96X@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S960@
M87)C:&EV92X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@
M9F%I;&5D*2X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE
M*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@9FEL93H@`%5N86)L92!T;R!R
M96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92`E
M<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N
M86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M
M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL
M92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B
M;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S
M)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET92!6
M1E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!61E,@
M9FEL92!D871A+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I
M;&P@8F4@97AC965D960N`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S
M('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E
M<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M
M('-E<G9E<B!T;SH@`%5N9FEL960`56YI8V]D92`H551&+3@I`%5N:71E9"!!
M<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YI
M=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N:VYO
M=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN;W=N
M(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@;&]C871I
M;VX@<')O=FED960N`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N`%5N
M;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M960`56YP<FEV:6QE9V5D
M('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M
M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S
M964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"!S:&]W
M<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI
M<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D
M871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&=R861E('-C<FEP="!D96QE
M=&5D+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I
M;&5S('1O('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@
M<F]M86X@;G5M8F5R<P!5<G5G=6%Y`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,
M`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S
M97)V97(N`%5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R
M($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO
M;@!5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI
M<R!S:71E+@!5<V5R;F%M90!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I
M;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N
M;W0@97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L
M=61E.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L
M=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N`%9A;'5E<P!6
M86QU97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T=0!687)I86)L90!696YE>G5E
M;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V
M92!B965N('1A;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L
M`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E
M<GD@2&EG:`!6:65T($YA;0!6:65T;F%M97-E("A625-#24DI`%9I97<@)7,`
M5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I<F=I;B!)
M<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI
M='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET86QY('9I82!33510`%=!4DX`
M5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=A
M;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S=`!7
M96%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC;VT`5V5B`%=E8B!3
M:71E`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`
M5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I`%=E
M<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L
M87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T
M97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAI8V@@<&AA<V5S
M`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D
M:71O<BX`5VED=&@`5VED=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F('1H92`E
M<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M
M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`5VEK
M:0!7:6YD`%=I;F0@16%R;'D`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7
M:6YD.B``5VES9&]M`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`6"U2
M968`6#4P.78S($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+
M97D@57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y
M=C,@4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!9
M60!965E9`%EA:&]O(2!M87``665A<FQY`%EE;65N`%EE<P!997,L($D@06=R
M964`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N
M('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%U=&AE
M;G1I8V%T960N`%EO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D
M<F5S<RX`66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O
M<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`
M66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@:&%V92!T;R!E;G1E<B!A
M('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@
M;W!T:6]N86P@)RLG(&9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R
M969I>"X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92X`66]U(&UU
M<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P
M<RX`66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N`%EO=2!M=7-T
M(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE
M('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E
M('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@<V5L96-T(&%N('-E<G9E
M<B!T;R!B92!D96QE=&5D+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@
M=&\@8VQE87(@;W5T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@
M<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N
M`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`66]U
M(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S
M="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N`%EO=7(@)7,@<V5S<VEO;B!H
M87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($5M86EL($%D
M9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO
M=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G
M:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E
M8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@
M875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I
M;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O
M<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@
M:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S
M97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO
M9VEN(&%G86EN+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES
M(&9E871U<F4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@
M<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0('1O('!R
M:6YT+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E
M;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@
M)7,@:7,Z("5S`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@
M=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA
M=F4@8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T
M`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA
M:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R(')E
M;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!::6UB86)W
M90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@4F5P;W)T70!;
M4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN
M97-=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I;VX`7T-,20!?1&%T
M851R964`7T1E;&5T92!2;W<`7T=R;W5P<P!?2&5L<`!?26UA9V4@4')O<&5R
M=&EE<RXN+@!?3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN:RXN+@!?3W!T
M:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]3971U<`!?5&%B
M;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`861D<F5S<R!B;V]K`&-A;&5N9&%R
M`&-A;&T`8VQI8VL@:&5R90!F86QL:6YG`&9I;&4`9G)O;2!T:&4@)7,@*"5S
M*2!A="`E<R`E<P!H.@!H:`!I;6UE9&EA=&4`:6YL:6YE`&QI;F5S70!M:VES
M;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RX`;6T`;F%M90!N
M;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D`'!E
M<F-E;G0`<&EX96QS`')I<VEN9P!S:&]W(&1I9F9E<F5N8V5S`'-M<S)E;6%I
M;"!V:6$@2%144`!S<P!S=&5A9'D`=&%S:R!L:7-T`'1Y<&4@=&AE('!A<W-W
M;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5S97(@<V5L
M96-T`'9#87)D`'<Z`'=E871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@
M2&]R9&4@,RXP-0I297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO
M<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-BTP-2TQ,2`Q,CHU,2LP
M,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#<M,30@,3$Z,#@K,#$P,`I,
M87-T+51R86YS;&%T;W(Z($IO<F1I($=I<F%L="`\<')O:F5C=&4N:S)`=7!C
M;F5T+F5D=3X*3&%N9W5A9V4M5&5A;3H@0V%T86QA;B`\9&5V0&QI<W1S+FAO
M<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT
M+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3$*0V]N=&5N="U4<F%N<V9E<BU%
M;F-O9&EN9SH@.&)I=`H`*&9A("5S(&1I97,I`"`H0VQA=2!D)V%C8^ES("5S
M*0`H96X@)7,@9&EE<RD`*&%V=6DI`"AD96W@*0`H86AI<BD`96X`(B5S(B!N
M;R#I<R!U;B!D:7)E8W1O<FDN`"5D("5S(&D@)7,`)60@8GET97,@97-C<FET
M<RX`)60@9&4@)60@96YT<F%D97,@;6%R8V%D97,@8V]M(&%C='5A;&ET>F%D
M97,`<')E=FES:?,@<&5R(&%L(&1I82`E9`!!=NUS("T@)7,`16UP<F5M=&$@
M9&%C=&EL87(@)7,`)7,@2T(`3W!E<F%C:6]N<R!D92!M86YT96YI;65N="`E
M<R`M($-O;F9I<FUA8VGS`$-O;F9I9W5R86-I\R!D92`E<P!!;'1A(&1E("5S
M`$-O;F1I8VEO;G,@9&5L(&-O;G1R86-T92`E<P`E<R!J82!E>&ES=&5I>"X`
M)7,@96X@)7,@)7,`R7,@;F5C97-S87)I("5S+@`E<R!M:6YU=',`3F\@<R=H
M82!T<F]B870@)7,N`"5S(&YO('1R;V)A="X@17AE8W5T82`G=')A;G-L871I
M;VX@97AT<F%C="<@<')I;65R+@`E<R!A;"`E<R!D92`E<P!,;&EB<F5T82!D
M)V%D<F5C97,@9&4@)7,`06=E;F1A(&1E("5S`$)L;V,@9&4@;F]T97,@9&4@
M)7,`3&QI<W1A(&1E('1A<W%U97,@9&4@)7,`)7,Z("5S`"P@=F5N=/-S("5S
M("5S(``L('9A<FEA8FQE(&1E("5S(&$@)7,`+2T@<V5L96-C:6]N87(@+2T`
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM`&9O<FUA="!D92`Q,B!H;W)E
M<P!F;W)M870@9&4@,C0@:&]R97,`,C0@:&]R97,`/$%N=&5R:6]R`%!E<B!A
M(&%Q=65S="!B;&]C(&5S(&YE8V5S<VET82!U;B!M;W1O<B!D92!B87-E<R!D
M92!D861E<RX`4R=H82!P<F]D=>]T('5N(&5R<F]R(&ER<F5P87)A8FQE+@!%
M<R!N96-E<W-I=&$@=6YA(&-L874@4$=0('#Z8FQI8V$@<&5R('AI9G)A<B!U
M;B!M:7-S871G92X`17,@;F5C97-S:71A('5N82!C;&%U(%!'4"!P^F)L:6-A
M('!E<B!V97)I9FEC87(@=6X@;6ES<V%T9V4@<VEG;F%T+@!%<R!N96-E<W-I
M=&5N('5N82!C;&%U(%!'4"!P^F)L:6-A+"!U;F$@8VQA=2!01U`@<')I=F%D
M82!I('5N82!C;VYT<F%S96YY82!P97(@9&5S>&EF<F%R('5N(&UI<W-A=&=E
M+@!%<R!N96-E<W-I=&5N('5N82!C;&%U(%!'4"!P^F)L:6-A+"!U;F$@8VQA
M=2!01U`@<')I=F%D82!I('5N82!C;VYT<F%S96YY82!P97(@<VEG;F%R('5N
M(&UI<W-A=&=E+@!%<R!N96-E<W-I=&5N('5N82!C;&%U(%,O34E-12!P^F)L
M:6-A+"!U;F$@8VQA=2!3+TU)344@<')I=F%D82!I('5N82!C;VYT<F%S96YY
M82!P97(@9&5S>&EF<F%R('5N(&UI<W-A=&=E+@!%<R!N96-E<W-I=&5N('5N
M82!C;&%U(%,O34E-12!P^F)L:6-A+"!U;F$@8VQA=2!3+TU)344@<')I=F%D
M82!I('5N82!C;VYT<F%S96YY82!P97(@<VEG;F%R('5N(&UI<W-A=&=E+@!%
M<R!N96-E<W-I=&$@=6YA(&-L874@4TU)344@</IB;&EC82!P97(@>&EF<F%R
M('5N(&UI<W-A=&=E+@!.^G9O;',@86P@;6%T[0!0;'5J82!F96)L92!A;"!M
M873M`%!L=6IA(&%L(&UA=.T`4G5I>&%T<R!A;"!M873M`%C@9F5C<R!D92!N
M974@86P@;6%T[2X`04TO4$T`240@9&4@05!)`%-O8G)E(&%Q=65S="!E9&ET
M;W(`16X@<75A;G0@82XN+@!!;&EN96%C:?,@:6YF97)I;W(@97AA8W1A`$%L
M:6YE86-I\R!A;"!M:6<@97AA8W1A`%,G:&$@9&5N96=A="!L)V%C8^ES(&5N
M(&-R96%R(&5L(&1I<F5C=&]R:2!61E,N`%,G:&$@9&5N96=A="!L)V%C8^ES
M(&5N(&-R96%R(&PG87)X:74@5D93+@!#;VYT<F%S96YY82!D96P@8V]M<'1E
M`$-O;7!T92!C;VYG96QA="X`0V]M<'1A8FEL:71Z86-I\P!!9F5G:7(`069E
M9VER('5N(&=R=7`@9&5S8V5N9&5N=`!!9F5G:7(@=6YA(&%U=&]R:71Z86-I
M\R!D97-C96YD96YT`$%F96=I<B!A(&-O;G1I;G5A8VGS.@!!9F5G:7(@=6X@
M;F]U(&=R=7``069E9VER('5N82!N;W9A(&%U=&]R:71Z86-I\R``069E9VER
M('5N(&YO=2!U<W5A<FDZ`$%F96=I<B!U;F$@8V]L=6UN82X`069E9VER(&YO
M=7,@;65M8G)E<RX`069E9VER('5N82!P87)E;&QA`$%F96=I<B!E;"!M96[Z
M("5S(&-O;2!U;F$@8F%R<F$@;&%T97)A;"!D92!-;WII;&QA`$%F96=E:7@@
M82!L82!L;&EB<F5T82!D)V%D<F5C97,Z`$%F96=E:7@@82!L82!M979A(&QL
M:6)R971A(&0G861R96-E<P!!9F5G:7(@=6X@=7-U87)I`$%F96=I;G0@;F]U
M<R!F:71X97)S(&%L(')E<&]S:71O<FD`4R=H82!I;FAA8FEL:71A="!L)V]P
M8VGS(&0G869E9VER('5S=6%R:7,N`$%D<F7G80!,;&EB<F5T82!D)V%D<F5C
M97,`061M:6YI<W1R861O<B`M(&1E9FEN96EX(&QE<R!A=71O<FET>F%C:6]N
M<R!P97(@82!A;'1R97,@=7-U87)I<P!!9&UI;FES=')A8VGS`$%N=6YC:7,`
M069G86YI<W1A;@!!;&+@;FEA`$%L9^AR:6$`P&QI97,`06QI;F5A<@!!;&EN
M96%C:?,Z`%1O=',`5&]T<R!E;',@=7-U87)I<R!A=71E;G1I8V%T<P!4;W1S
M(&5L<R!G<G5P<P!4;W1S(&5L<R!P97)M:7-O<P!4;W1S('%U871R92!C;W-T
M871S`%!E<FUE="!M;VQT97,@861R96-E<P!%<R!P97)M970@;&$@8V]N9FEG
M=7)A8VGS(&1E;"!T:7!U<R!D92!L;&ES=&5S(&]R9&5N861E<S\`2F$@97AI
M<W1E:7@`06-CZ7,@24U34"!A;'1E<FYA=&EU`$-O;G1R87-E;GEA($E-4U`@
M86QT97)N871I=F$`3F]M(&0G=7-U87)I($E-4U`@86QT97)N871I=0!!9')E
MYV$@96QE8W1R\FYI8V$@86QT97)N871I=F$`4&QA;G1I;&QE<R!A;'1E<FYA
M=&EV97,`5&5X="!A;'1E<FYA=&EU.@!386UO82!!;65R:6-A;F$`4R=H82!E
M<W!E8VEF:6-A="!U;B!V86QO<B!P<F]H:6)I="X`4R=H82!P<F]D=>]T('5N
M(&5R<F]R(&1E<V-O;F5G=70N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`%-E
M<G9I9&]R(%!R;WAY(&%N\FYI;0!297-P;W-T80!!;G3@<G1I9&$`06YT:6=U
M82!I($)A<F)U9&$`07!L:6-A8VGS`$QL:7-T82!D)V%P;&EC86-I;VYS`$PG
M87!L:6-A8VGS(.ES(&$@<'5N="X`07!L:6-A<B!A(')E8W5R<V]S(&-O;7!A
M<G1I=',@9&5S8V5N9&5N=',N`$%P<F]V87(`36ED82!A<')O>&EM861A`$%B
M<FEL`$%RX&)I8R`H5VEN9&]W<RTQ,C4V`$UI9&$@9&4@;"=A<GAI=0!.;VT@
M9&4@;"=A<GAI=0!6;VQE=2!S=7!R:6UI<B!L82!S;VRW;&EC:71U9"!D)V%L
M=&$@82`E<S\`07)G96YT:6YA`$%R;>AN:6$`07)M96YI("A!4DU30TE)+3@I
M`$%R=`!!<G5B80!);&QA(&1E(&PG07-C96YS:?,`9W+@9FEC($%30TE)`%)E
M9VGS(&1E;"!086/M9FEC(&%S:>!T:6,`5F]L974@8V]N9FER;6%C:?,@86)A
M;G,@9"=E9F5C='5A<B!L97,@;W!E<F%C:6]N<R!D92!M86YT96YI;65N=#\`
M0V]L=6UN97,@9"=A<W-I9VYA8VGS`%,G:&$@:6YT96YT870@<W5P<FEM:7(@
M=6X@9W)U<"!N;R!E>&ES=&5N="X`4R=H82!I;G1E;G1A="!S=7!R:6UI<B!U
M;F$@875T;W)I='IA8VGS(&YO(&5X:7-T96YT+@!3)VAA(&EN=&5N=&%T(&5D
M:71A<B!U;F$@875T;W)I='IA8VGS(&YO(&5X:7-T96YT+@!3)VAA(&EN=&5N
M=&%T(&5D:71A<B!U;B!R96-U<G,@8V]M<&%R=&ET(&YO(&5X:7-T96YT+@!!
M=')I8G5T<P!!9V]S=`!!=7-T<N!L:6$`P'5S=')I80!!=71H7V-Y<G-Q;#H@
M3F\@<R=H82!T<F]B870@;"=E>'1E;G-I\R!I;6%P(&YE8V5S<^!R:6$N`$%U
M=&A?8WER=7,Z($5L(&UO=&]R(&YO('3I(&QE<R!C87!A8VET871S(&YE8V5S
M<^!R:65S+@!!=71H7V-Y<G5S.B!.;R!S)VAA('1R;V)A="!L)V5X=&5N<VGS
M($E-05`@;F5C97-SX')I82X`075T:%]F='`Z($YO(',G:&$@=')O8F%T(&PG
M97AT96YS:?,@1E10(&YE8V5S<^!R:6$N($-A;"!C;VUP:6QA<B!02%`@86UB
M(&5L(&-O;6UU=&%D;W(@+65N86)L92UF='`N`$%U=&A?:6UA<#H@3F\@<R=H
M82!T<F]B870@;"=E>'1E;G-I\R!)34%0(&YE8V5S<^!R:6$N`$%U=&A?:W)B
M-3H@3F\@<R=H82!T<F]B870@;"=E>'1E;G-I\R!K<F(U(&YE8V5S<^!R:6$N
M`$%U=&A?;&1A<#H@3F\@<R=H82!T<F]B870@;"=E>'1E;G-I\R!,1$%0(&YE
M8V5S<^!R:6$N`$%U=&A?;&1A<#H@3F\@<R=H82!P;V=U="!A9F5G:7(@;"=U
M<W5A<FD@)7,N($%I>/(@Z7,@96P@<75E(&AA(&1I="!E;"!S97)V:61O<CH`
M075T:%]L9&%P.B!.;R!S)VAA('!O9W5T('-U<')I;6ER(&PG=7-U87)I("5S
M+@!!=71O7VQD87`Z($YO(',G:&$@<&]G=70@86-T=6%L:71Z87(@;"=U<W5A
M<FD@)7,N`$%U=&]?;6-A;#H@3F\@<R=H82!T<F]B870@;"=E>'1E;G-I\R!-
M0T%,(&YE8V5S<^!R:6$N`$%U=&A?<VUB875T:#H@3F\@<R=H82!T<F]B870@
M;"=E>'1E;G-I\R!334)!551((&YE8V5S<^!R:6$N`%,G:&$@<')O9'7O="!U
M;B!E<G)O<B!E;B!L)V%U=&5N=&EC86-I\RX`4R=H82!P<F]D=>]T('5N(&5R
M<F]R(&5N(&PG875T96YT:6-A8VGS+B`E<P!%;"!S97)V:61O<B!2041)55,@
M:&$@<F5B=71J870@;"=A=71E;G1I8V%C:?,N`%,G:&$@<')O9'7O="!U;B!E
M<G)O<B!E;B!L)V%U=&5N=&EC86-I\R!A;6(@96P@<V5R=FED;W(@1E10+@!3
M)VAA('!R;V1U[W0@=6X@97)R;W(@96X@;"=A=71E;G1I8V%C:?,@86UB(&5L
M('-E<G9I9&]R(%--0BX`0V%M<',@9&ES<&]N:6)L97,Z`$%Z97)B86ED:F%N
M`$)/1D@@17AC=7-E<P!&;VYS`$-O;&]R(&1E;"!F;VYS`$-O;G1R87-E;GEA
M($ME<F)E<F]S(&EN8V]R<F5C=&$N`$YO;2!D)W5S=6%R:2!+97)B97)O<R!I
M;F-O<G)E8W1E+@!"86AA;65S`$)A:')A:6X`0N!L=&EC("A)4T\M.#@U.2TQ
M,RD`0F%N9VQA($1E<V@`0F%R8F%D;W,`3.UN:6$@8F%S90!":65L;W)R^G-I
M80!"Z&QG:6-A`$)E;&EZ90!"96[M;@!"97)M=61E<P!":'5T86X`06YI=F5R
M<V%R:0!.;R!S)VAA('1R;V)A="!E;"!B;&]C("(E<R(@9&4@;"=A<&QI8V%C
M:?,@(B5S(B`N`%!A<N!M971R97,@9&5L(&)L;V,`5&EP=7,@9&4@8FQO8P!.
M96=R971A`$)O;.UV:6$`36%R8V%D;W)S`$-O;G1O<FX`1W)U:7@@9&5L(&-O
M;G1O<FX`0V]N=&]R;G,`0O)S;FEA(&D@2&5R8V5G;W9I;F$`06UB9/-S`$)O
M='-W86YA`$EN9F5R:6]R`$EL;&$@9&4@0F]U=F5T`$)R87-I;`!497)R:71O
M<FD@;V-EX&YI8R!D92!L)\UN9&EA(&)R:73@;FEC80!"<G5N96D@1&%R=7-S
M86QA;0!#;VYT<G5I;G0@9FET>&5R<R!-3R!P97(@86P@;?)D=6P@)7,N+BX`
M0V]N<W1R=6EN="`E<RXN+@!"=6QGX')I80!,;&ES=&$@9&4@<&EC<P!"=7)K
M:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#`%!U;G1S(&1E(&1I<W1R:6)U8VGS
M(&1E($-23`!0<F]P:65T871S(&1E(&-E;+=L82XN+@!.;R!S)VAA(&9I;F%L
M:71Z870@96P@<')O8^ES(&0G:6YI8VEA;&ET>F%C:?,@9&4@;&$@;65M\G)I
M82!C874`0V%L96YD87)I`$-A;&UA`$-A;6)O9&IA`$-A;65R=6X`R7,@:6UP
M;W-S:6)L92!R96EN:6-I87(@;&$@8V]N=')A<V5N>6$@875T;VW@=&EC86UE
M;G0L('!O<V$G="!E;B!C;VYT86-T92!A;6(@;"=A9&UI;FES=')A9&]R(&1E
M;"!S:7-T96UA+@#)<R!I;7!O<W-I8FQE(&-O;FYE8W1A<B!A;6(@96P@<V5R
M=FED;W(@24U!4#H@)7,N`$-A;F%DX`!#86YC96RW;&%R`$-A;F-E;+=L87(@
M;"=I;F9O<FUE(&1E('!R;V)L96UE<RX`3F\@97,@<&]T(&5S8F]R<F%R(&PG
M87)X:74@(B5S(BX`3F\@97,@<&]T('1R;V)A<B!U;B!D:7)E8W1O<FD@=&5M
M<&]R86PN`$YO(&5S('!O="!C;VYT:6YU87(@<V5N<V4@96P@<&%RX&UE=')E
M("=T87)G971&:6QE)RX`3F\@97,@<&]T(&5S8F]R<F%R(&5L(&1I<F5C=&]R
M:2`B)7,B+@!.;R!E<R!P;W0@97-B;W)R87(L(&-O;G3I(&1E<V-E;F1E;G1S
M("5D+B``3F\@97,@<&]T(')E;W)D96YA<BP@96P@;F]M8G)E(&0G96YT<F%D
M97,@<75E(',G:&%N(&1E(')E;W)D96YA<B!N;R!C;VEN8VED96EX(&%M8B!L
M97,@<75E(&AI(&AA(&5M;6%G871Z96UA9&5S+@!.;R!E<R!P;W0@861R9>=A
M<B!E;"!M:7-S871G92!A;"!N;VUB<F4@97-P96-I9FEC870N`$-A<"!697)D
M`$QL96=E;F1A`$-A=&5G;W)I97,@:2!E=&EQ=65T97,`26QL97,@0V%I;6%N
M`%1E;.AF;VX@;?)B:6P`4')O<&EE=&%T<R!D92!C96RW;&$`1F%R8VEM96YT
M(&1E(&-E;+=L80!0<F]P:65T871S(&1E(&QA(&-E;+=L80!%<W!A:6%T(&5N
M=')E(&-E;+=L97,`5&5LZ&9O;B!M\F)I;`!#Z&QT:6,@*$E33RTX.#4Y+3$T
M*0!#96YT<F%R`%)E</IB;&EC82!#96YT<F5A9G)I8V%N80!%=7)O<&$@8V5N
M=')A;"`H25-/+3@X-3DM,BD`1&5T86QL<R!D96P@8V5R=&EF:6-A=`!4:71U
M;&%R(&1E;"!C97)T:69I8V%T`%!O;.UT:7%U97,@9&4@8V5R=&EF:6-A8VGS
M`%1X860`1&5S9NES`$-A;G9I974@96P@;F]M(&D@;"=A9')EYV$@<75E('/S
M;B!V:7-I8FQE<R!Q=6%N(&5S(&QL96=E:7AE;B!O(&5S(')E<W!O;F5N(&5L
M<R!V;W-T<F5S(&UI<W-A=&=E<R!D92!C;W)R974@96QE8W1R\FYI8RX`0VAA
M<@!697)I9FEC82!L)V5N;&QAYRXN+@!8:6QE`%AI;F$`6&ENZ',@<VEM<&QI
M9FEC870@*$=",C,Q,BD`6&ENZ',@=')A9&EC:6]N86P@*$)I9S4I`%1R:6$@
M=6YA(&-O;G1R87-E;GEA`%1R:6$@=6X@;F]M(&0G=7-U87)I`%1R:6$@8V]M
M('9O;',@=FES=6%L:71Z87(@;&5S(&1A=&5S.@!4<FEA('5N('1I<'5S(&0G
M97-T:6P@9&4@;&QI<W1A("AP97(@82!L;&ES=&5S(&]R9&5N861E<RD`26QL
M82!D92!#:')I<W1M87,`3F\@<R=H82!T<F]B870@;&$@9&5F:6YI8VGS(&1E
M(&-L87-S92!D92`@)7,N`$5L:6UI;F%R`$5L:6UI;F$@;&5S(&5T:7%U971E
M<R!D92!-4T]F9FEC90!%<V)O<G)A(&PG=7-U87)I.B`E<P!%<V)O<G)A(&PG
M=7-U87)I`$5S8F]R<F$@;&5S(&1A9&5S(&1E(&PG=7-U87)I`%,G86-L87)I
M<N`@8V%P(&%L('1A<F0N`%!R96UI('!E<B!C;VYT:6YU87(`0VQI8VMA=&5L
M;"!P97(@2%144`!486YC82!L82!F:6YE<W1R80!.^G9O;',`3OIV;VQS(&$@
M<')I;65R82!H;W)A`$5N;G5V;VQA=`!);&QE<R!D92!#;V-O<R`H2V5E;&EN
M9RD`4F5D=>]U(&QA(&)A<G)A(&QA=&5R86P`36%R9V5S(')E9'7O=',`0V]L
M\FUB:6$`0V]L;W(`4V5L96-T;W(@9&4@8V]L;W(`4V5L96-C:?,@9&4@8V]L
M;W(`0V]L=6UN97,Z`%3M=&]L<R!D92!L97,@8V]L=6UN97,`0_)M:6-S`$]R
M9')E`$-O;G-O;&$`0V]M96YT87)I`$YO;2!C;VWZ`$-O;6]R97,`0V]M<&%N
M>6EA`$5S8W)I=2!E;"!M:7-S871G92`H)7,I`$]R9&EN861O<G,`0V]N9&EC
M:6]N<P!$:69E<NAN8VEE<R!D92!C;VYF:6=U<F%C:?,`3&$@8V]N9FEG=7)A
M8VGS(&YO(&5S=.`@86-T=6%L:71Z861A+@!#;VYF:6=U<F$@)7,`0V]N9FER
M;6%R(&QA(&-O;G1R87-E;GEA`$-O;F=O`$-O;F=O+"!297#Z8FQI8V$@1&5M
M;V-RX'1I8V$@9&5L`$YO(.ES('!O<W-I8FQE(')E86QI='IA<B!L82!C;VYN
M97AI\RX`3F\@Z7,@<&]S<VEB;&4@<F5A;&ET>F%R(&QA(&-O;FYE>&GS.@!3
M)VAA(')E8G5T:F%T(&QA(&-O;FYE>&GS(&%L('-E<G9I9&]R(&1E(&-L875S
M('#Z8FQI<75E<RX`4R=H82!R96)U=&IA="!L82!C;VYN97AI\R!A;"!S97)V
M:61O<B!D92!C;&%U<R!P^F)L:7%U97,N(%)A\SH@)7,@*"5S*0!.;R#I<R!P
M;W-S:6)L92!R96%L:71Z87(@;&$@8V]N;F5X:?,@86P@<V5R=FED;W(@1E10
M+@!%;',@8V]N=&%C=&5S(',G:&%N(&%F96=I="!C;W)R96-T86UE;G0@82!L
M82!T979A(&QL:6)R971A(&0G861R96-E<RX`0V]N=&EN=6%R`$EL;&5S($-O
M;VL`1V%L971A`$-O<&EA<@#)<R!I;7!O<W-I8FQE(&-O<&EA<CH@)7,`0V]P
M:6%R('-E;&5C8VGS`$-O<W1A(%)I8V$`0V]S=&$@9"=)=F]R:0!.;R!E<R!P
M;W0@>&EF<F%R(&5L(&UI<W-A=&=E(&%M8B!3+TU)344N`$YO(&5S('!O="!S
M:6=N87(@96P@;6ES<V%T9V4@86UB(%,O34E-12X`3F\@97,@<&]T(&%F96=I
M<B!E;"!C;VYT86-T92X@)7,`3F\@97,@<&]T(&-O;FYE8W1A<B!A;6(@96P@
M<V5R=FED;W(@3$1!4"X`3F\@97,@<&]T(&-O;7!R;W9A<B!E;"!S86QD;RX@
M)7,`3F\@<R=H82!P;V=U="!C<F5A<B!U;F$@;&QI<W1A(&1E(&1I<W1R:6)U
M8VGS+B`E<P!.;R!S)VAA('!O9W5T(&1E<WAI9G)A<B!L97,@9&%D97,@4R]-
M24U%+@!.;R!S)VAA('!O9W5T(&5S8F]R<F%R(&5L(&-O;G1A8W1E+B`E<P!.
M;R!S)VAA('!O9W5T(&5S8F]R<F%R(&QA(&QL:7-T82!D92!D:7-T<FEB=6-I
M\RX@)7,`3F\@<R=H82!P;V=U="!D971E<FUI;F%R(&PG861R9>=A(&5L96-T
M<O)N:6-A(&1E;"!D97-T:6YA=&%R:2X`3F\@<R=H82!P;V=U="!R96-O;&QI
M<B!T;W1A(&QA(&QL:6)R971A(&0G861R96-E<RX`3F\@<R=H82!P;V=U="!R
M96-O;&QI<B!T;W1A(&QA(&QL:7-T82!D92!D:7-T<FEB=6-I\RX`3F\@<R=H
M82!P;V=U="!R96-O;&QI<B!T;W1A(&QA(&QL:7-T82!D92!L97,@;&QI<W1E
M<R!D92!D:7-T<FEB=6-I\RX`3F\@<R=H82!P;V=U="!O8G1E;FER('5N82!C
M;&%U('#Z8FQI8V$@9&5L('-E<G9I9&]R(&1E(&-L875S+@!.;R!S)VAA('!O
M9W5T(&]B<FER("5S+@!.;R!S)VAA('!O9W5T(&]B<FER(&5L(&WR9'5L(&1E
M('1A<W%U97,@9&4@;6%N=&5N:6UE;G0@)7,N`$YO(',G:&$@<&]G=70@;&QE
M9VER("5S+@!.;R!S)VAA('!O9W5T(')E:6YI8VEA<B!L82!C;VYT<F%S96YY
M82!P97(@82!L)W5S=6%R:2!S;VRW;&EC:71A="X@06QG=6YS(&1E=&%L;',@
M;R!T;W1S(&YO('/S;B!C;W)R96-T97,N(%1O<FYA<BUH;R!A(&EN=&5N=&%R
M(&\L('!E<B!A(&WI<R!I;F9O<FUA8VGS+"!P;W-A)W0@96X@8V]N=&%C=&4@
M86UB(&PG861M:6YI<W1R861O<B!D96P@<VES=&5M82X`3F\@<R=H82!P;V=U
M="!R96-U<&5R87(@;&5S($%#3`!.;R!S)VAA('!O9W5T(')E8W5P97)A<B!L
M82!L;&EB<F5T82!D)V%D<F5C97,N("5S`$YO(',G:&$@<&]G=70@<F5C=7!E
M<F%R(&QA(&QL:7-T82!D92!D:7-T<FEB=6-I\RX@)7,`3F\@<R=H82!P;V=U
M="!R96-U<&5R87(@;&5S(&QL:7-T97,@9&4@9&ES=')I8G5C:?,N("5S`$YO
M(',G:&$@<&]G=70@<F5C=7!E<F%R(&QE<R!P;W-S:6)I;&ET871S(&1E;"!S
M97)V:61O<@!.;R!S)VAA('!O9W5T(')E<W1A=7)A<B!L82!C;VYF:6=U<F%C
M:?,N`$YO(',G:&$@<&]G=70@9&5S87(@;&$@8V]N9FEG=7)A8VGS("5S+@!.
M;R!S)VAA('!O9W5T(&1E<V%R('5N82!C;VYF:6=U<F%C:?,@9&4@<V5G=7)E
M=&%T+@!.;R!S)VAA('!O9W5T(&1E<V%R('5N82!C;VYF:6=U<F%C:?,@9&4@
M<V5G=7)E=&%T.B`E<P!.;R!S)VAA('!O9W5T(&1E<V%R(&QA(&/R<&EA(&1E
M('-E9W5R971A="!D92!L)V%R>&EU(&1E(&-O;F9I9W5R86-I\R`E<RX`3F\@
M<R=H82!P;V=U="!D97-A<B!L)V%R>&EU(&1E(&-O;F9I9W5R86-I\R`E<RX@
M4&]T<R!U=&EL:71Z87(@=6YA(&1E(&QE<R!O<&-I;VYS('!E<B!T;W)N87(@
M82!D97-A<B!E;"!C;V1I(&5N("5S(&\@8ND@8V]P:6%R(&UA;G5A;&UE;G0@
M96P@8V]D:2!S96?\96YT(&5N("5S+@!.;R!S)VAA('!O9W5T(&-E<F-A<B!A
M;"!S97)V:61O<B!,1$%0+@!.;R!S)VAA('!O9W5T(&%C='5A;&ET>F%R(&5L
M(&-O;G1A8W1E+B`E<P!.;R!S)VAA('!O9W5T(&%C='5A;&ET>F%R(&QA(&QL
M:7-T82!D92!D:7-T<FEB=6-I\RX@)7,`3F\@<R=H82!P;V=U="!L;V-A;&ET
M>F%R(&QA(&)A<G)A(&QA=&5R86P@9&4@36]Z:6QL82X@0V]M<')O=F$@<75E
M(&QA(&)A<G)A(&QA=&5R86P@97-T:6=U:2!O8F5R=&$N`%1E>'0@8V]M<'1A
M=`!08>US`$-U<G-O<P!#<F5A<@!#<F5A<B!U;B!E;FQL8><`0W)E87(M;F4@
M=6X@9&4@;F]U`$-R96%R('-U8F-A<G!E=&5S`%!E<FUI<V]S(&1E;"!C<F5A
M9&]R`$[Z;65R;R!D92!L82!T87)G971A(&1E(&-RZ&1I=`!#<F_@8VEA`$-U
M8F$`-"!F87-E<R!A8W1U86QS`%1E;7!S(&%C='5A;`!%;"!54DP@86-T=6%L
M(.ES`%1E;7!S(&%C='5A;`!#;VYD:6-I\R!A8W1U86PZ`$5S=&EL(&%C='5A
M;`!097)S;VYA;&ET>F5U(&QE<R!T87-Q=65S('%U92!S)VAA;B!E>&5C=71A
M<B!Q=6%N(',G:6YI8VEA(&QA('-E<W-I\R!A("5S+@!2971A;&QA<@!2971A
M;&QA<B!L82!S96QE8V-I\P!8:7!R90!#:7+M;+=L:6,@*$M/23@M4BD`0VER
M[6RW;&EC("A7:6YD;W=S+3$R-3$I`$-I<NULMVQI8R]58W)A[V[H<R`H2T])
M."U5*0!297#Z8FQI8V$@5'AE8V$`1$0`1&G@<FEA;65N=`!.879E9V%D;W(@
M9&4@1&%T851R964`1&%T80!3)VAA(')E8G5T(&QA(&1A=&$`4V5L96-C:?,@
M9&4@9&%T80!$:6$`4W5P<FEM:7(@8V]L=6UN80!$97-E;6)R90!.;VUB<F5S
M(&1E8VEM86QS`%)E9'7O=2!E;"!S86=N870`4')E9&5T97)M:6YA=`!#;VQO
M<B!P<F5D971E<FUI;F%T`$ED96YT:71A="!P<F5D971E<FUI;F%D80!$969I
M;FEC:6]N<P!3=7!R:6UI<@!3=7!R:6UI<B!G<G5P`%-U<')I;6ER('!E<FWM
M<P!3=7!R:6UI<B!I(&)U:61A<B!M:7-S871G97,`4W5P<FEM:7(@8V5LMVQA
M`%-U<')I;6ER(&-O;'5M;F$`4W5P<FEM:7(@;&$@<&QA;G1I;&QA(&%L=&5R
M;F%T:79A(&5X:7-T96YT`%-U<')I;6ER(&9I;&$`4W5P<FEM:7(@;&$@:61E
M;G1I=&%T('-E;&5C8VEO;F%D80!3=7!R:6UI<B!L82!C;VQU;6YA(&%C='5A
M;`!3=7!R:6UI<B!L82!F:6QA(&%C='5A;`!(;W)A(&1E(&QL:75R86UE;G0`
M1&EN86UA<F-A`$1E<V-R:79I=2!E;"!P<F]B;&5M80!$97-C<FEP8VGS`$1E
M=&%L;',@*'1A;6+I(&%L(&9I='AE<B!D92!R96=I<W1R92!D92!(;W)D92DZ
M`$5L<R!D971A;&QS(&AA;B!E<W1A="!R96=I<W1R871S('!E<B!A(&PG861M
M:6YI<W1R861O<BX`1&5S96YV;VQU<&%M96YT`%!U;G0@9&4@<F]S861A`%!U
M;G0@9&4@<F]S861A(&1E(&QA(&1A<G)E<F$@:&]R83H`4'5N="!D92!R;W-A
M9&$Z(`!$)V5S<75E<G)A(&$@9')E=&$`1&4@9')E=&$@82!E<W%U97)R80!$
M:7)E8W1O<FD`5F]L<R!V:7-U86QI='IA<BUH;R!E;B!F;W)M870@9&4@,C0@
M:&]R97,_`$]P8VEO;G,@9&4@=FES=6%L:71Z86-I\P!-;W-T<F$@;&$@<')E
M=FES:?,@*%1!1BD`1F]R;6%T(&1E('9I<W5A;&ET>F%C:?,`3F]T:69I8V%C
M:?,@9&4@<F5C97!C:?,`1&II8F]U=&D`3F\@:&\@<W5P<FEM:74`3F\@86-C
M961I=2!D:7)E8W1A;65N="!A(&UA:6YT96YA;F-E+G!H<`!,82!P<FEM97)A
M(&9I;&$@8V]N=.D@96QS(&YO;7,@9&5L<R!C86UP<S\@16X@8V%S(&%F:7)M
M871I=2P@86-T:79A(&%Q=65S=&$@8V%S96QL83H`1&]M:6YI8V$`4F5P^F)L
M:6-A($1O;6EN:6-A;F$`1&5S8V%R<F5G87(`1&5S8V%R<F5G87(@)7,`1&5S
M8V%R<F5G87(@;&$@8V]N9FEG=7)A8VGS(&=E;F5R861A(&-O;2!U;F$@<V5Q
M_.AN8VEA(%!(4"X`3&QI<W1A(&1E<W!L96=A8FQE`$1R;V=U97,`0V]R<F5U
M(&5L96-T<O)N:6,`15)2`$5Q=6%D;W(`161I=&$`161I=&$@8FQO8P!%9&ET
M82!G<G5P`$5D:71A('!E<FWM<P!%9&ET82!P97)M:7-O<P!%9&ET82!P97)M
M:7-O<R!D92`E<P!%9&ET82!O<&-I;VYS(&1E.@!%9&ET82!P97)M:7-O<R!D
M92`E<P!%9'5C86-I\P!%9VEP=&4`16P@4V%L=F%D;W(`16QE;65N="XN+@!1
M=6%D<F%T[0!#;W)R974@96QE8W1R\FYI8P!!9')EYV$@96QE8W1R\FYI8V$`
M3&5S(&%D<F5C97,@96QE8W1R\FYI<75E<R!H86X@9&4@8V]I;F-I9&ER+@!#
M;W)R974@96QE8W1R\FYI8R!A;6(@8V]N9FER;6%C:?,`16UO=&EC;VYE<P!-
M:7-S871G92!E;B!B;&%N8RX`4F5S=6QT870@96X@8FQA;F,N`$)U:61A<B!E
M;',@=&5R;65S(&1E(&-E<F-A`$AA8FEL:71A<B!L82!I;G-E<F-I\R!D92!I
M;6%T9V5S(&1E(&QE<R!G86QE<FEE<R!D92!F;W1O<R!E;B!E;"!T97AT/P!(
M86)I;&ET87(@96P@;65N^B!D92!C;VYT97AT(&-L:6-A;G0@96X@96P@8F]T
M\R!D<F5T/P!!;GD@9&4@9FEN86QI='IA8VGS`$%M<&QI87(@;"=E9&ET;W(`
M26YT<F]D=>]U('5N82!P<F5G=6YT82!D92!S96=U<F5T870@<75E('-E('5S
M(&9O<FUU;&%RX"!S:2!U<R!C86P@<F5I;FEC:6%R(&QA(&-O;G1R87-E;GEA
M+"!P97(@97AE;7!L92`G8V]M(&5S(&1I=2!E;"!V;W-T<F4@86YI;6%L(&1E
M(&-O;7!A;GEI83\G.@!);G1R;V1U[W4@87%U[2!E;"!54DP@9&4@;&$@:6UA
M=&=E`$=U:6YE82!%<75A=&]R:6%L`$5R:71R96$`17)R;W(`2&D@:&$@:&%G
M=70@=6X@97)R;W(@86UB(&5L(&UI<W-A=&=E(&5L96-T<O)N:6,N`$5S=/)N
M:6$`171I\G!I80#(=&YI8P!%=7)O<&$`0V%D82`Q-2!M:6YU=',`0V%D82`R
M(&UI;G5T<P!#861A(#,P('-E9V]N<P!#861A(#4@;6EN=71S`$-A9&$@:6YI
M8VD@9&4@<V5S<VGS`$-A9&$@;6ET:F$@:&]R80!#861A(&UI;G5T`%9A;&]R
M<R!D)V5X96UP;&4Z`$5X96-U=&$`17AP86YD96EX`$5X<&%N9&ER(&QA(&)A
M<G)A(&QA=&5R86P`4R=E<W!E<F%V82`G*2<`4R=E<W!E<F%V82!U;B!S;VP@
M;6]T(&\@=6X@=&5R;64@9&4@8V5R8V$@8VET870`1&%T82!D92!V96YC:6UE
M;G0`17AP;VYE;G0`0V]L;W(@9&4@<')I;65R('!L80!#X')R96=A(&1E(&QA
M(&-O;F9I9W5R86-I\R!D96P@1E10`,ES(&EM<&]S<VEB;&4@<F5C=7!E<F%R
M(&QE<R!P<F5F97+H;F-I97,N`,ES(&EM<&]S<VEB;&4@8V]N;F5C=&%R(&%M
M8B!E;"!S97)V:61O<B!,1$%0+@#)<R!I;7!O<W-I8FQE(&-O;FYE8W1A<B!A
M;6(@96P@<V5R=FED;W(@4TU"+@#)<R!I;7!O<W-I8FQE(&-O<&EA<B!D92`B
M)7,B+@#)<R!I;7!O<W-I8FQE(&-O<&EA<B!A("(E<R(N`,ES(&EM<&]S<VEB
M;&4@8W)E87(@=6YA(&YO=F$@8V]N;F5X:?,@4T%33"X`R7,@:6UP;W-S:6)L
M92!T<F%N<V9E<FER(&$@(B5S(BX`R7,@:6UP;W-S:6)L92!R96-U<&5R87(Z
M("5S`$-L87(`26QL97,@1F%L:VQA;F0@*$UA;'9I;F5S*0!);&QE<R!&Z')O
M90!%<G)O<B!I<G)E8W5P97)A8FQE(`!&87@`1F5B<F5R`%-E('-E;G0@8V]M
M`%-E('-E;G0@8V]M.@!0;W%U97,@<&QU9V5S`%!O8W,@>.!F96-S(&1E(&YE
M=0!-871R:74@9&5L(&-A;7``1FEJ:0!296-O;7!T92!D)V%R>&EU<SH@87)X
M:74@)7,`4F5C;VUP=&4@9"=A<GAI=7,Z("5S(&%R>&EU<P!'97-T;W(@9"=A
M<GAI=7,`3F]M(&1E(&PG87)X:74`4V5L96-C:?,@9"=A<GAI=7,`0^!R<F5G
M82!D92!L)V%R>&EU`$YO(.ES('!E<FWH<R!P96YJ87(@87)X:75S`$9I;'1R
M97,`1FEN;.!N9&EA`%!R:6UE<F$@;65I=&%T`%!R:6UE<B!Q=6%R=`!28?,@
M9FEX82,C`$EN=F5R=&EU`$-O;6$@9FQO=&%N=`!";VER80!,82!C87)P971A
M("5S(&YO(&5X:7-T96EX`$-O;&]R(&1E(&QA(&9O;G0`365N:F%R`%!E<B!A
M;',@;F%V96=A9&]R<R!Q=64@;F\@861M971E;B!L97,@:6UA=&=E<P!0<F5V
M:7-I\R`H5$%&*0!0<F5V:7-I\R!P97(@86QS(&1I97,@*'1I;F=U974@<')E
M<V5N="!Q=64@;&$@<')E=FES:?,@9F%C:6QI=&%D82!C;VUP<NAN(&5L(&1I
M82!I(&QA(&YI=#H@=6X@;F]M8G)E(&5L979A="!P;V1R:6$@=&5N:7(@8V]M
M(&$@<F5S=6QT870@=6X@8FQO8R!A;7!L92X`2&5U(&]B;&ED870@;&$@8V]N
M=')A<V5N>6$_`$9O<FUU;&%R:7,`1&ET80!4:7!U<R!D92!D:71E<P!$:71E
M<P!$:71E<R`R`$;R<G5M<P!2965N=FEA;65N=',`1'8N`$UA<F-S`$9R86[G
M80!&<F%NYV$@;65T<F]P;VQI=&%N80!'=6%I86YA($9R86YC97-A`%!O;&EN
MZ'-I82!&<F%N8V5S80!497)R:71O<FES($9R86YC97-O<R!D96P@4W5D`$1E
M<R!D90!$97,@9&5L`$1E<V-R:7!C:?,@8V]M<&QE=&$`3&QU;F$@<&QE;F$`
M3F]M(&-O;7!L970`1V%B;VX`3&$@9V%L97)I82!D92!L82!Q=6%L(',G97AT
M<F5U(&QA(&EM871G90!'86QE<FEA`$?@;6)I80!%<R!G96YE<F$@;&$@8V]N
M9FEG=7)A8VGS("5S`$-O9&D@9V5N97)A=`!'9?)R9VEA`$%L96UA;GEA`$=H
M86YA`$=I8G)A;'1A<@!.;VT@9&4@<&EL80!!;F%R(&$`1_9D96P`0V5R8V$@
M86P@1V]O9VQE`$5S8V%L82!D92!G<FES;W,`1W+H8VEA`$=R96,@*$E33RTX
M.#4Y+3<I`$=R96YLX&YD:6$`1W)A;F%D80!'97-T:?,@9&4@9W)U<',`16QS
M(&YO;7,@9&4@9W)U<"!N;R!E<R!P;V1E;B!D96EX87(@96X@8FQA;F,`1W)U
M<',`1W5A9&%L=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`%!E<FUI<V]S
M(&1E;',@=FES:71A;G1S`$QL:6)R92!D92!V:7-I=&%N=',`1W5I;F5A`$=U
M:6YE82!":7-S874`1W5Y86YA`$A434P`2%1-3$%R96$@;F\@<&5R;65T('-U
M<')I;6ER(&QA(&1A<G)E<F$@8V5LMVQA(&1E(&QA(&9I;&$N`$A434Q!<F5A
M(&YO('!E<FUE="!S=7!R:6UI<B!L82!D87)R97)A(&-O;'5M;F$@9&4@;&$@
M=&%U;&$N`$A434Q!<F5A(&YO('!E<FUE="!S=7!R:6UI<B!L82!D87)R97)A
M(&9I;&$@9&4@;&$@=&%U;&$N`$YO(',G:&$@=')O8F%T(&PG875T96YT:6-A
M8VGS($A45%`N`$AA:73M`$%L9V]R:7-M92!D92!H87-H`$-A;&ET:F$`0V%P
MYV%L97)A`$EL;&$@2&5A<F0@:2!I;&QE<R!-8T1O;F%L9`!(96)R974@*$E3
M3RTX.#4Y+3@M22D`06SG861A`$%J=61A`$%J=61A('!E<B!U=&EL:71Z87(@
M;"=E9&ET;W(`07!L:6-A8VGS(&0G86IU9&$`2&5M:7-F97)I`$%Q=65S="#I
M<R!L)VEN:6-I(&1E;"!F:71X97(Z`$%L=`!);FEC:0!L82!386YT82!3974@
M*$-I=71A="!%<W1A="!D96P@5F%T:6/@*0!);FEC:0!!9')EYV$@<&%R=&EC
M=6QA<@!496SH9F]N('!A<G1I8W5L87(`2&]N9'5R97,`2&]N9R!+;VYG`$AO
M<F1E`$AO<F1E+TMO;&%B.B!3)VAA;B!T<F]B870@9&%D97,@6$U,("5S(&YO
M(';@;&ED97,@96X@96P@;6ES<V%T9V4@)7,`2&]R9&4O2V]L86(Z($YO(&AI
M(&AA(&-A<"!M:7-S871G92!Q=64@97,@8V]R<F5S<&]N9W5I(&%M8B!L)V]B
M:F5C=&4@)7,`2&]R9&4O2V]L86(Z($YO(',G:&$@=')O8F%T(&-A<"!O8FIE
M8W1E(&1E;"!T:7!U<R`E<R!E;B!E;"!M:7-S871G92`E<P!(;W)D92]+;VQA
M8CH@)7,@(B5S(B!H82!E<W1A="!E>'1R970@8V]R<F5C=&%M96YT`$AO<F1E
M+TMO;&%B.B!%;"!M;W1O<B!D)VEN=&5G<F%C:?,@;F5C97-S:71A(&PG97AT
M96YS:?,@4$A0("=D;VUX;6PG`$AO<F1E+TMO;&%B.B!.;R!S)VAA('!O9W5T
M(&-R96%R('5N(&YO=2!A<F)R92!834P@<&5R(&$@;"=O8FIE8W1E("5S`$AO
M<F1E+TMO;&%B.B!.;R!S)VAA('!O9W5T(&5X=')E=7)E("5S("(E<R(Z("5S
M`$AO<F1E+TMO;&%B.B!.;R!S)VAA('!O9W5T(')E8W5P97)A<B!L)VED96YT
M:69I8V%D;W(@34E-12!P97(@82!L82!P87)T(&1E;"!T:7!U<R`E<P!(;W)D
M92]+;VQA8CH@3F\@<R=H82!P;V=U="!S:6YC<F]N:71Z87(@)7,B)7,B.B`E
M<P!(;W)D92]+;VQA8CH@3F\@<R=H82!P;V=U="!S:6YC<F]N:71Z87(@;&5S
M('%U;W1E<SH@)7,`2&]R9&4O2V]L86(Z($5S<&%I(&1I<W!O;FEB;&4@9&5S
M8V]N96=U="`B)7,B`%)E9VQA(&AO<FET>F]N=&%L`$9A<F-I;65N="!H;W)I
M='IO;G1A;`!(;W)I='IO;G1A;#H`0V]M(&AE=2!A<G)I8F%T(&9I;G,@87%U
M[3\@*$9E=2UN;W,M:&\@<V%B97(A*0!1=6%N=&5S(&-O;'5M;F5S('9O;&5U
M(')E9F]N9')E/P!1=6%N=',@8V%M<',@*&-O;'5M;F5S*2!H:2!H83\`475A
M;G1E<R!F:6QE<R!V;VQE=2!R969O;F1R93\`2'5M:71A=`!(=6UI=&%T.@!(
M=6UO<FES=&5S`$AO;F=R:6$`R7,@:6UP;W-S:6)L92!C<F5A<B!L82!B^G-T
M:6$@24U!4#H@)7,`R7,@:6UP;W-S:6)L92!S=7!R:6UI<B!L82!B^G-T:6$@
M24U!4#H@)7,`R7,@:6UP;W-S:6)L92!C<F5A<B!U;B!E<W!A:2!D:7-P;VYI
M8FQE('!E<B!A(&QA(&+Z<W1I82!)34%0.B`E<P!!9')EYV$@25``3"=A9')E
MYV$@25`@;F\@97-TX"!D:7-P;VYI8FQE+@!,)V%D<F7G82!)4"!N;R!E<R!T
M<F]B82!E;B!E;"!B;&]C($-)1%(@<&5R;>AS+@!6:6]L86-I\R!D96P@8FQO
M<75E:6<@25`N`$EN<V5R:74@=6YA(&9I;&$@9&%M=6YT`$ES;.!N9&EA`$YO
M;>ES(&EC;VYE<P!)8V]N97,@9&4@)7,`26-O;F5S(&%M8B!T97AT`$YO;2!D
M)VED96YT:71A=#H`4VD@;F\@97,@=FES=6%L:71Z82!C;W)R96-T86UE;G0L
M(&]B<FEU("5S(&5N('5N82!N;W9A(&9I;F5S=')A+@!3:2!N;R!V:7-U86QI
M='IE=2!C87`@:6-O;F$@;6ET:F%NYV%N="!L)TEN=&5R;F5T($5X<&QO<F5R
M+"#I<R!P;W-S:6)L92!Q=64@:.!G:74@9"=A8W1I=F%R(&%Q=65S="!Q=6%D
M<F4@<&5R(&1E<V%C=&EV87(@;&$@=')A;G-P87+H;F-I82!D92!03D<N`%-I
M('9E:65U(&%Q=65S="!M:7-S871G92!E;B!L;&]C(&1E(&QA(&EM871G92P@
M96P@=F]S=')E(&YA=F5G861O<B!N;R!P;W0@;6]S=')A<B!L82!I;6%T9V4@
M<75E('9O;&5U('!E;FIA<BX`5FES=6%L:71Z86-I\R!P<NAV:6$@9&4@;&$@
M:6UA=&=E.@!54DP@9&4@;&$@:6UA=&=E`%523"!D92!L82!I;6%T9V4Z`$EM
M871G92!D92!L82!G86QE<FEA`$EM871G92!D92!L82!G86QE<FEA.@!#X')R
M96=A(&1E(&QA(&EM871G90!);6%T9V5S`$EM<&]R=&%C:?,L('!A<R`E9`!#
M86UP(&EM<&]R=&%T.B`E<P!#86UP<R!I;7!O<G1A=',Z`$EN<V5R:74@=6YA
M(&9I;&$@82!S;W1A`$5L(&-O9&D@9&4@;"=A8V-I\R!Q=64@<R=H82!F86-I
M;&ET870@Z7,@:6YC;W)R96-T92X`3F]M(&0G=7-U87)I(&DO;R!C;VYT<F%S
M96YY97,@:6YC;W)R96-T97,N`%,G:&$@9F%C:6QI=&%T('5N(&YO;2!D)W5S
M=6%R:2!O('5N82!A9')EYV$@86QT97)N871I=F$@:6YC;W)R96-T97,N(%1O
M<FYE=2UH;R!A(&EN=&5N=&%R(&\@<&]S974M=F]S(&5N(&-O;G1A8W1E(&%M
M8B!L)V%D;6EN:7-T<F%D;W(@<&5R(&$@;>ES(&%J=61A+@!!=6=M96YT87(@
M96P@<V%G;F%T`,UN9&EA`%5S=6%R:7,@:6YD:79I9'5A;',`26YD;V[H<VEA
M`$EN9F]R;6%C:?,`26YF;W)M86-I\P!);FEC:6%L:71Z86YT(&WR9'5L("5S
M+BXN(`!);G-E<F5I>"!U;F$@8V]L=6UN82!A('-O=&$`26YS97)E:7@@=6YA
M(&EM871G90!);G-E<F5I>"!U;F$@=&%U;&$`26YS97)E:7@@96YL;&'G('=E
M8@!);G-E<F5I>"!L82!C;VQU;6YA(&1A;75N=`!);G-E<F5I>"!U;F$@;F]V
M82!C;VQU;6YA(&$@<V]T82!D92!L)V%C='5A;`!);G-E<F5I>"!U;F$@;F]V
M82!C;VQU;6YA(&$@<V]B<F4@9&4@;"=A8W1U86P`26YS97)E:7@@=6YA(&YO
M=F$@9FEL82!A('-O=&$@9&4@;"=A8W1U86P`26YS97)E:7@@=6YA(&YO=F$@
M9FEL82!A('-O8G)E(&1E(&PG86-T=6%L(`!);G-E<F5I>"!U;B!P87+@9W)A
M9B!A('-O=&$@9&5L(&YO9&4@86-T=6%L`$EN<V5R96EX('5N('!A<N!G<F%F
M(&$@<V]B<F4@9&5L(&YO9&4@86-T=6%L`$EN<V5R96EX(&PG86QT<F$@<&QA
M;G1I;&QA`$EN<V5R96EX('5N82!A9')EYV$@9&4@8V]R<F5U('!E<B!R96)R
M92!L82!N;W9A(&-O;G1R87-E;GEA26YS97)I=2!U;F$@861R9>=A(&5L96-T
M<O)N:6-A(&$@;&$@<75A;"!P;V1E=2!R96)R92!L82!N;W9A(&-O;G1R87-E
M;GEA.@!);G-E<F5I>"!U;F$@8V5LMVQA(&$@<V]T80!);G-E<F5I>"!U;F$@
M8V5LMVQA(&$@<V]B<F4`26YS97)I=2!U;F$@8V]L=6UN82!A('-O=&$`26YS
M97)I=2!U;F$@8V]L=6UN82!A('-O8G)E`$EN<V5R:74@;6ES<V%T9V5S`$EN
M<V5R:74@=6X@<&%RX&=R868@82!S;W1A`$EN<V5R:74@=6X@<&%RX&=R868@
M82!S;V)R90!);G-E<FEU('5N82!F:6QA(&$@<V]T80!);G-E<FEU('5N82!F
M:6QA(&$@<V]B<F4`26YS97)I=2!L82!R97-P;W-T82!A(&QA('!R96=U;G1A
M(&1E('-E9W5R971A=#H`26YS97)I<B]-;V1I9FEC87(@:6UA=&=E`$EN<V5R
M:7(O36]D:69I8V%R(&5N;&QAYP!.;R!D:7-P;W-E=2!D92!P<F]U(&-RZ&1I
M="!P97(@96YV:6%R+6QO(&$@;&$@;&QI<W1A(&1E(&1I<W1R:6)U8VGS+@!#
M<NAD:70@:6YS=69I8VEE;G0N`$YO;6)R92!E;G1E<@!,;&ES=&$@9&4@;F]M
M8G)E<R!E;G1E<G,`541((&YO(';@;&ED82X@*$-A<.=A;&5R82!D92!D861E
M<R!D)W5S=6%R:2DN`$%P;&EC86-I\R!N;R!VX&QI9&$N`$PG:61E;G1I9FEC
M861O<B!D96P@;&]T(&YO(.ES(';@;&ED`$QE<R!D861E<R!Q=64@<R=H86X@
M=')A;>AS(&YO('/S;B!VX&QI9&5S+@!,)V%D<F7G82!D92!D97-T:6YA8VGS
M(&YO(.ES(';@;&ED82X`16P@9F]R;6%T(&1E(&PG87)X:74@;F\@Z7,@=N!L
M:60N`$QA(&-L874@9&4@;&$@;&QI8^AN8VEA(&YO(.ES(';@;&ED82X`3&$@
M=6)I8V%C:?,@<75E(&AE=2!P<F]P;W)C:6]N870@;F\@Z7,@=N!L:61A+@!%
M;"!T:7!U<RUM<V<@;F\@Z7,@=N!L:60N`$UA;F-A(&5L(&%P:5]I9"!O(&5L
M('%U92!S)VAA(&9A8VEL:71A="!N;R#I<R!VX&QI9"X`36%N<75E;B!P87+@
M;65T<F5S(&\@96QS('%U92!S)VAA;B!F86-I;&ET870@;F\@<_-N(';@;&ED
M<RX`3"=A=71O<FET>F%C:?,@<&%T97)N82!N;R#I<R!VX&QI9&$N`$5L(&-O
M9&D@9"=I9&5N=&EF:6-A8VGS(&1E('-O8VD@;F\@Z7,@=N!L:60N`$5L(&-O
M9&D@9&5L('!R;V1U8W1E(&YO(.ES(';@;&ED+@!%;"!P<F]T;V-O;"!N;R#I
M<R!VX&QI9"X`3"=O8FIE8W1E(&-O;7!A<G1I="!N;R#I<R!VX&QI9`!,)V%D
M<F7G82!D)V]R:6=E;B!N;R#I<R!VX&QI9&$N`$QE<R!D861E<R!5;FEC;V1E
M(&YO('/S;B!VX&QI9&5S+@!);G9E;G1A<FD`27)A;BP@4F5P^F)L:6-A($ES
M;.!M:6-A(&0G`$ER87$`27)L86YD80!);&QA(&1E($UA;@!496UP97-T97,@
M8>]L;&%D97,`27-R865L`$5M:7-S;W(`0W5R<VEV80!)=.!L:6$`2F%M86EC
M80!'96YE<@!*87#S`$IA<&]NZ',@*$E33RTR,#`R+4I0*0!*97)S97D`2F]R
M9.!N:6$`2G5L:6]L`$IU;GD`2G5S=&EF:6-A<@!*=7-T:69I8V%R(&%L(&-E
M;G1R90!*=7-T:69I8V%R(&$@=&]T<R!D;W,@;6%R9V5S`$IU<W1I9FEC87(@
M82!L)V5S<75E<G)A`$IU<W1I9FEC87(@82!L82!D<F5T80!+87IA:VAS=&%N
M`%9O;&5U(&-O;G-E<G9A<B!L)V]R:6=I;F%L/P!+96YY80!%;"!S97)V:61O
M<B!+97)B97)O<R!H82!R96)U=&IA="!L)V%U=&5N=&EC86-I\RX`2V5R;F5L
M($YE=V)I97,`0W)E86-I\R!D92!C;&%U<P!%;7!R96UT82!D:6=I=&%L(&1E
M(&QA(&-L874`3&]N9VET=60@9&4@;&$@8VQA=0!4:7!U<R!D92!C;&%U`-IS
M(&1E(&QA(&-L874`2F$@97AI<W1E:7@@=6YA(&-L874@96X@96P@<V5R=FED
M;W(@9&4@8VQA=7,@</IB;&EQ=65S+@!.;VES`$MI<FEB871I`$-O<F5A+"!2
M97#Z8FQI8V$@1&5M;V-RX'1I8V$@4&]P=6QA<B!D90!#;W)E82P@4F5P^F)L
M:6-A(&1E`$-O<F7@("A%54,M2U(I`$MU=V%I=`!+:7)G=6EZ:7-T86X`1F]R
M;6%T`$ED:6]M80!297#Z8FQI8V$@1&5M;V-RX'1I8V$@4&]P=6QA<B!D92!,
M86]S`$1A<G)E<F$@;65I=&%T`$1A<G)E<B!Q=6%R=`!$87)R97)A(&%C='5A
M;&ET>F%C:?,Z`$1A<G)E<F$@8V]N;F5X:?,Z("5S`$1A<G)E<F$@8V]N;F5X
M:?,Z("5S(&1E("5S`$1A<G)E<F$@8V]N;F5X:?,Z`$QE=/)N:6$`3&QE:0!$
M:7-S96YY`$1E:7AA<BUH;R!E;B!B;&%N8R!P97(@96QI;6EN87(@96P@8V]N
M=&]R;@!,[6)A;@!%<W%U97)R80!#87#G86QE<F$@97-Q=65R<F$`5F%L;W)S
M(&1E(&PG97-Q=65R<F$`3&5S;W1H;P!,:6+H<FEA`$SM8FEA`$QI96-H=&5N
M<W1E:6X`4&QU9VEM(&9E8FQE`%!L=6IA(&9E8FQE`%!L=6IA(&9E8FQE(&$@
M<')I;65R82!H;W)A`%!L=6IA(&9E8FQE(&-A<"!A;"!T87)D`%)U:7AA="!F
M96)L90!2=6EX870@9F5B;&4@86UB('1R;VYS`$YE=F%D82!F96)L90!8X&9E
M8R!D92!N974@9F5B;&4`3&EM97)I8VL`16YL;&'G`$5N;&QA8^=A<B!E;',@
M<'5N=',@86UB.@!%;FQL8>=A<B!L)V%D<F7G82!E;&5C='+R;FEC82!A(&QA
M('#@9VEN82!D92!R961A8W1A="!Q=6%N(&5S(&UO<W1R:0!%;FQL8>=O<P!'
M86QE=&$@3&EN=7@`3&QI<W1A<B`M($PG=7-U87)I('!O="!V975R92!L82!C
M87)P971A`$QL:7-T87(@;&5S(&)A<V5S(&1E(&1A9&5S`$QL:7-T82!D96QS
M('1E;65S(&0G86IU9&$`3&QI<W1A<B!L97,@=&%U;&5S`$QI<W0M07)C:&EV
M90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T
M+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QA(&QL:7-T82!D)W5S=6%R
M:7,@97-TX"!I;FAA8FEL:71A9&$N`$)I8FQI;V=R869I80!,:71UX&YI80!3
M)V5S=.`@8V%R<F5G86YT+BXN`$AO<F$@;&]C86PZ(`!)9&EO;6$@:2!H;W)A
M`%5B:6-A8VGS`$EN:6-I82!L82!S97-S:?,`4W5R=`!487-Q=65S(&0G:6YI
M8VD@9&4@<V5S<VGS`$AI(&AA(&AA9W5T('5N(&5R<F]R(&1E(&-O;FYE>&GS
M('!E<G%UZ"!H974@:6YT<F]D=>]T(&EN8V]R<F5C=&%M96YT(&5L(&YO;2!D
M)W5S=6%R:2!O(&QA(&-O;G1R87-E;GEA+@!(82!F86QL870@;&$@8V]N;F5X
M:?,N`%1E>'0@;&QA<F<`06UO<@!"86EX`$%L9F%B970@9W)E8R!E;B!M:6[Z
M<V-U;&$`06QF86)E="!L;&%T[2!E;B!M:6[Z<V-U;&$`6&EF<F5S(')O;6%N
M97,@96X@;6EN^G-C=6QA`$QU>&5M8G5R9P!-30!-3U1$`$PG87)X:74@861J
M=6YT($U3+51.148@;F\@8V]N=&5N:6$@9&%D97,N`$U31P!-86-A=0!-86-E
M9/)N:6$L($%N=&EG82!297#Z8FQI8V$@275G;W-L879A(&1E`$UA9&%G87-C
M87(`3>!G:6,`0V]R<F5U(&5L96-T<O)N:6,`061M:6YI<W1R861O<B!D92!C
M;W)R974`4R=E<W3@(&-R96%N="!U;B!E;FQL8><N+BX`36%L87=I`$UA;.!I
M<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`1V5S=&EO;F5U(&QA(&QL:7-T82!D
M92!C871E9V]R:65S(&%M8B!L97,@<75A;',@:&5U(&0G971I<75E=&%R(&5L
M<R!E;&5M96YT<RP@:2!E;',@8V]L;W)S(&%S<V]C:6%T<R!A;6(@87%U97-T
M97,@8V%T96=O<FEE<RX`36%P82!-87`R-`!-87!A($UA<%%U97-T`$UA<N<`
M36%R9V4`36%R8V%R(&%M8B!I;F1I8V%D;W)S('9I<VEB;&5S+VEN=FES:6)L
M97,`36%R8V%R(&%M8B!A;'1R97,@:6YD:6-A9&]R<R`H<"X@92XL(&EM<&]R
M=&%N="]R97-P;W-T*0!);&QE<R!-87)S:&%L;`!-87)T:6YI8V$`0V%M<',@
M<75E(&-O:6YC:61E:7AI;@!-875R:73@;FEA`$UA=7)I8VD`0W+H9&ET(&W@
M>&EM('!E<FWH<RX`4R=H82!S=7!E<F%T(&5L(&YO;6)R92!MX'AI;2!D92!P
M87)T<R!D92!M:7-S871G92X`5&5M<&5R871U<F$@;>!X:6UA(&1E(&QE<R!D
M87)R97)E<R`R-"!H;W)E<SH@`%1E;7!E<F%T=7)A(&W@>&EM82!D92!L97,@
M9&%R<F5R97,@-B!H;W)E<SH@`$QO;F=I='5D(&W@>&EM80!-86EG`$UA>6]T
M=&4`365D:6-I;F$`365M8G)E<P!4:7!U<R!D92!M96[Z.@!2969O;F%R(&QE
M<R!C96RW;&5S`$UI<W-A=&=E`$5L(&UI<W-A=&=E(&AA(&5S=&%T('9E<FEF
M:6-A="!C;W)R96-T86UE;G0L('!E<O(@;F\@<R=H82!P;V=U="!V97)I9FEC
M87(@96P@8V5R=&EF:6-A="!E;"!S:6=N86YT+@!-:7-S871G92!C861U8V%T
M+@!4:7!U<R!D92!M:7-S871G90!496UP<R!D92!-151!4@!%;"!B;&]C($U%
M5$%2(&YO(&5S=.`@9&ES<&]N:6)L92X`16P@8FQO8R!-151!4B!N;R!E<W3@
M(&1I<W!O;FEB;&4N($5L<R!D971A;&QS(&AA;B!E<W1A="!R96=I<W1R871S
M('!E<B!A(&PG861M:6YI<W1R861O<BX`3&$@8F%S92!D92!D861E<R!-151!
M4B!N;R!E<W3@(&-O;FYE8W1A9&$N`$WH=&]D90!-Z'1R:6,`3>AX:6,`36EC
M<F]NZ'-I82P@17-T871S($9E9&5R871S(&1E`$-E;G1R90!4:7!U<R!-24U%
M`%1E;7!E<F%T=7)A(&WM;FEM82!D92!L97,@9&%R<F5R97,@,C0@:&]R97,Z
M(`!496UP97)A='5R82!M[6YI;6$@9&4@;&5S(&1A<G)E<F5S(#8@:&]R97,Z
M(`!2Z'!L:6-A`$UI<V-E;+=L86YI`$9A;'1A(&QA('-O;+=L:6-I='5D($A4
M5%`@<&5R(&%L('!A<75E="!014%2+@!&86QT82!L82!C;VYF:6=U<F%C:?,N
M($PG:&5U(&1E(&=E;F5R87(@87)A('-I('9O;&5U('5T:6QI='IA<B!A<75E
M<W1A(&%P;&EC86-I\RX`1F%L=&$@;"=I9&5N=&EF:6-A9&]R(&1E;"!M:7-S
M871G92X`1F%L=&$@96P@8V]R<F5U(&5L96-T<O)N:6,@9&5L('!A<75E="!0
M14%2(&YE8V5S<V%R:2X`1F%L=&$@;"=I9&5N=&EF:6-A9&]R(&1E('-E<W-I
M\RX`1&PN`$-O<G)E=2!M\F)I;`!-;V1E<F%T`$1A=&$@;6]D:69I8V%D80!-
M;V1I9FEC87(@;&$@55),`$WR9'5L`$UO;&3@=FEA+"!297#Z8FQI8V$@9&4`
M3?)N86-O`$UO;F?R;&EA`$UE<R!I(&%N>0!-96YS=6%L;65N=`!-;VYT<V5R
M<F%T`$9A<V5S(&QU;F%R<P!-87)R;V,`36%J;W)I=.!R:6%M96YT(&1E<V-O
M8F5R=`!-86IO<FETX')I86UE;G0@96YN=79O;&%T`$UA:F]R:73@<FEA;65N
M="!A<W-O;&5L;&%T`$UO=7)E(&-A<"!A=F%L;`!-;W5R92!A(&PG97-Q=65R
M<F$`36]U<F4@82!L82!D<F5T80!-;W5R92!C87`@86UU;G0`36]U<F4@8V%P
M(&%V86QL`$UO=7)E(&-A<"!A;75N=`!-;^=A;6)I8P!,:7-T97,@9&5S<&QE
M9V%B;&5S(&5N;&QAYV%D97,@96X@9&EV97)S;W,@;FEV96QL<P!396QE8V-I
M\R!M^FQT:7!L90!%;"!M974@8V]M<'1E`$5L(&UE=2!P;W)T86P`1&ES<V5N
M>2!D96P@;65U('!O<G1A;`!->6%N;6%R`$Y/+"!.3R!H:2!E<W1I8R!D)V%C
M;W)D`$YO;0!.86WM8FEA`$YA=7)U`$YE<&%L`%!A[W-O<R!"86EX;W,`06YT
M:6QL97,@3F5E<FQA;F1E<V5S`%523"!B87-E(&1E($YE='-C87!E`%523"!D
M92!R979O8V%C:?,@9&4@0T$@9&4@3F5T<V-A<&4`55),(&1E('!O;.UT:7%U
M97,@9&4@0T$@9&4@3F5T<V-A<&4`55),(&1E(')E;F]V86-I\R!D92!.971S
M8V%P90!54DP@9&4@<F5V;V-A8VGS(&1E($YE='-C87!E`$YO;2!D96P@<V5R
M=FED;W(@4U-,(&1E($YE='-C87!E`$-O;65N=&%R:2!D96P@8V5R=&EF:6-A
M="!D92!.971S8V%P90!4:7!U<R!D92!C97)T:69I8V%T(&1E($YE='-C87!E
M`%AA<GAA`$UA:0!.;W9A($-A;&5D\FYI80!.;W9A(&-A=&5G;W)I80!,;'5N
M82!N;W9A`$YO=2!N;VT@9"=U<W5A<FD@*&]P8VEO;F%L*0!.;W9A(%IE;&%N
M9&$`3F]V82!F:6YE<W1R82`H7V5N(&)L86YC*0!-:7-S871G97,`1W)U<',@
M9&4@9&ES8W5S<VGS`%-E9_QE;G0`-"!F87-E<R!S96?\96YT<P!/<&-I;VYS
M('-E9_QE;G1S`%-E9_QE;G0^`$YI8V%R86=U80!.[6=E<@!.:6?H<FEA`$YI
M=`!.:75E`$YO`$YO(&5S(&1I<W!O<V5N(&1E(&1A9&5S(&1E(&-O;F9I9W5R
M86-I\R!P97(@;6]S=')A<B!L97,@9&EF97+H;F-I97,N`$YO(&5S(&1I<W!O
M<V$@9"=U;F$@97-T<F%TZ&=I82!P97(@8W)E87(@:6UA=&=E<R!)4T\N`$YO
M(&AI(&AA('!L86YT:6QL82!D92!L;W1S+@!.;R!E>&ES=&5I>"!C87`@8FQO
M8R!E;B!L82!P;W-I8VGS('-O;+=L:6-I=&%D80!.;R!S)VAA('!R;W!O<F-I
M;VYA="!U;B!N;VT@9"=A9V5N9&$@<&5R(&$@;"=A=71E;G1I8V%C:?,@34-!
M3"X`4V5N<V4@8V%N=FES+@!.;R!E<R!P;V1E;B!A9F5G:7(@9&5S8V5N9&5N
M=',@82!A<75E<W0@<&5R;>US`$YO(',G:&$@97-P96-I9FEC870@;&5S(&1A
M9&5S(&1E(&-O;F9I9W5R86-I\R!P97(@82`E<RX`3F\@<R=H82!E<W!E8VEF
M:6-A="!L97,@9&%D97,@9&4@8V]N9FEG=7)A8VGS('!E<B!A($944"!P97(@
M5D93+@!.;R!S)VAA(&5S<&5C:69I8V%T(&QE<R!D861E<R!D92!C;VYF:6=U
M<F%C:?,@<&5R(&$@4U%,('!E<B!61E,N`$YO(',G:&$@97-P96-I9FEC870@
M;&5S(&1A9&5S(&1E(&-O;F9I9W5R86-I\R!D92!344P@<&5R(&%L(&9I='AE
M<B!344PN`$YO('%U961A(&-RZ&1I="X`3F\@<R=H82!F86-I;&ET870@=6YA
M(&1E<W1I;F%C:?,N`$YO(',G:&$@8V%R<F5G870@8V%P(&%R>&EU+@!.;R!S
M)VAA('1R;V)A="!C87`@:6-O;F$N`$YO(',G:&$@9&5F:6YI="!U;F$@=6)I
M8V%C:?,N`$YO(',G:&$@9F%C:6QI=&%T('5N82!U8FEC86-I\RX`3F\@<R=H
M82!I;G1R;V1U[W0@=6X@;6ES<V%T9V4N`$YO(',G:&$@97-P96-I9FEC870@
M=6X@;F]M+@!.;R!S)VAA(&5S<&5C:69I8V%T('5N82!X:69R82X`3F\@97,@
M<&5R;65T96X@;&5S(&1I=&5S(&]F96YS:79E<RX`3F\@<R=H82!I;G1R;V1U
M[W0@=6YA(&-O;G1R87-E;GEA('!E<B!A(&PG875T96YT:6-A8VGS($A45%`N
M`$YO(',G:&$@:6YT<F]D=>]T('5N82!C;VYT<F%S96YY82!P97(@82!L)V%U
M=&5N=&EC86-I\R!)34%0+@!.;R!S)VAA(&EN=')O9'7O="!U;F$@8V]N=')A
M<V5N>6$@<&5R(&$@;"=A=71E;G1I8V%C:?,@2V5R8F5R;W,N`$YO(',G:&$@
M:6YT<F]D=>]T('5N82!C;VYT<F%S96YY82!P97(@82!L)V%U=&5N=&EC86-I
M\R!D)VEN:6-I+@!.;R!S)VAA(&EN=')O9'7O="!U;F$@8V]N=')A<V5N>6$@
M<&5R(&$@;"=A=71E;G1I8V%C:?,@4$%34U=$+@!.;R!S)VAA(&EN=')O9'7O
M="!U;F$@8V]N=')A<V5N>6$@<&5R(&$@;"=A=71E;G1I8V%C:?,@4TU"+@!.
M;R!S)VAA(&EN9&EC870@;&$@=FEA(&0G86-CZ7,@86P@8FEN87)I($]P96Y3
M4TPN($-A;"!E;"!B:6YA<FD@3W!E;E-33"!P97(@=')E8F%L;&%R(&%M8B!L
M97,@9&%D97,@4$M#4R`Q,BX`3F\@:&D@:&$@86QT97,@<&5N9&5N=',N`$YO
M(',G:&$@9&5F:6YI="!L)V5S<&%I(&1I<W!O;FEB;&4N`%-E;G-E(')E9VQE
M<P!396YS92!C87)E<P!.;R!E>&ES=&5I>"!A<75E<W0@87)X:74`3F\@97,@
M9&ES<&]S82!D92!C87`@9&ER96-T;W)I('1E;7!O<F%L('!E<B!A(&QA(&UE
M;?)R:6$@8V%U+@!.;R!H974@96YV:6%T(&5L(&YO;2!D)W5S=6%R:2!N:2]O
M(&QA(&-O;G1R87-E;GEA`$YO(',G:&%N(')E=&]R;F%T(&1A9&5S(%A-3"!V
MX&QI9&5S`%-E;G-E('9A;&]R<P!.;R!S)VAA('1R;V)A="!L82!V97)S:?,@
M96X@;&$@8V]N9FEG=7)A8VGS(&]R:6=I;F%L+B!296=E;F5R974@;&$@8V]N
M9FEG=7)A8VGS+@!.;R!S)VAA('1R;V)A="!L82!V97)S:?,@96X@;&$@8V]N
M9FEG=7)A8VGS+B!296=E;F5R974@;&$@8V]N9FEG=7)A8VGS+@!#87``0V%P
M("CZ<R!I;7!L[6-I="D`3O)R9&EC("A)4T\M.#@U.2TQ,"D`26QL82!D92!.
M;W)F;VQK`$AE;6ES9F5R:2!N;W)D`$EL;&5S($UA<FEA;FYE<R!D96P@3F]R
M9`!.;W)U96=A`$YO(&1E<W!RZ7,`3F\@86)A;G,`3F\@Z7,@=6X@9&ER96-T
M;W)I`$YO(&EM<&QE;65N=&%T+@!.;R!D969I;FET`$YO('!E<FWH<RX`3F]T
M97,`3F\@:&D@:&$@<F5S(&$@=FES=6%L:71Z87(L(')E=')O8V5D:74N`$YO
M=F5M8G)E`$YO;6)R90!.;VUB<F4@9&4@8V%RX&-T97)S`$YO;6)R92!D92!C
M;VQU;6YE<P!.;VUB<F4@9&4@9FEL97,`3F\@<R=H86X@97-P96-I9FEC870@
M;F]M8G)E<R!Q=64@:&%G:6X@9&4@<V5R(&%C='5A;&ET>F%T<R!E;B!L82!L
M;&ES=&$@9&4@9&ES=')I8G5C:?,N`$0G86-O<F0`3V)J96-T90!#<F5A9&]R
M(&1E(&PG;V)J96-T90!/8W1A;`!/8W1U8G)E`$9I;'1R92!D)VEN9G)A8V-I
M;VYS`$]F:6-I;F$`3VUA;@!.;VWI<R!E;',@<V5R=FED;W)S($E-05`@<&5R
M;65T96X@;"?Z<R!D92!C87)P971E<R!C;VUP87)T:61E<RX`3F]MZ7,@;6ES
M<V%T9V5S(&]F96YS:75S`$YO;>ES(.ES('!E<FUE<V$@=6YA(/IN:6-A(&%D
M<F7G82!E;&5C='+R;FEC82X`3F]MZ7,@96P@<')O<&EE=&%R:2!O(&PG861M
M:6YI<W1R861O<B!D92!S:7-T96UE<R!P;W0@8V%N=FEA<B!L82!P<F]P:65T
M870@;R!E;',@<&5R;6ES;W,@9&5L('!R;W!I971A<FD@<&5R(&$@<F5C=7)S
M;W,@8V]M<&%R=&ET<P!/8G)I=2!E;B!U;F$@;F]V82!F:6YE<W1R80!%<G)O
M<B!/<&5N4U-,.B!N;R!S)VAA;B!P;V=U="!E>'1R975R92!L97,@9&%D97,@
M9&4@;&$@<&%R="!3+TU)344@<VEG;F%D82X`3V)R92!A<75E<W0@96YL;&'G
M(&5N('5N82!N;W9A(&9I;F5S=')A`%-I<W1E;6$@;W!E<F%T:74`3W!C:6]N
M<P!/<&-I;VYS(&0G)7,`3&QI<W1A(&]R9&5N861A`$]R9V%N:71Z86-I\P!5
M;FET870@;W)G86YI='IA=&EV80!3)V5S=.`@;W)G86YI='IA;G0`4&QA;G1I
M;&QA(&0G87!L:6-A8VGS(&]R:6=I;F%L`%!L86YT:6QL97,@;W)I9VEN86QS
M(&5N("5S.@!!;'1R90!!;'1R82!I;F9O<FUA8VGS`%!E<FUI<V]S(&1E;"!P
M<F]P:65T87)I`$PG875T96YT:6-A8VGS(%!!32!N;R!E<W3@(&1I<W!O;FEB
M;&4N`%-I9VYA='5R82!D:6=I=&%L(%!'4`!$861E<R!X:69R861E<R!A;6(@
M4$=0`$-L874@4$=0('#Z8FQI8V$`1&%D97,@<VEG;F%D97,O>&EF<F%D97,@
M86UB(%!'4`!#;V1I(%!(4`!);G3H<G!R970@9"=O<F1R97,@4$A0`%!L=6=I
M;7,@9&4@=&%R9&$`4&QU9V5S(&1E('1A<F1A`$YE=F%D97,@9&4@=&%R9&$`
M6.!F96-S(&1E(&YE=2!A(&QA('1A<F1A`%-O;"!D92!T87)D80!496UP97-T
M97,@9&4@=&%R9&$`26YTZ')P<F5T(&0G;W)D<F5S(%!?2%``4V5P87)A8VGS
M`%!A:VES=&%N`%!A;&%U`%1E<G)I=&]R:2!P86QE<W3M+"!O8W5P870`4&%N
M86W@`%!A<'5A($YO=F$@1W5I;F5A`%!A<F%G=6%I`%!A<F-I86QM96YT(&5N
M;G5V;VQA=`!#;VYT<F%S96YY80!#;VYT<F%S96YY82!I;F-O<G)E8W1A`$-A
M;"!I;G1R;V1U:7(@=6YA(&-O;G1R87-E;GEA('!E<B!A(&PG875T96YT:6-A
M8VGS(%)!1$E54RX`0V]N=')A<V5N>6$@86UB(&-O;F9I<FUA8VGS`$-O;G1R
M87-E;GEA.@!#;VYT<F%S96YY83H@`$QE<R!C;VYT<F%S96YY97,@:&%N(&1E
M(&-O:6YC:61I<BX`16YG86YX87(`16YG86YX87(@9&5L('!O<G1A+7)E=&%L
M;',`0V%M[0!!;'1E<R!P96YD96YT<SH`1V5N=`!097)C96YT871G90!296%L
M:71Z87(@;W!E<F%C:6]N<R!D92!M86YT96YI;65N=`!6;VQE=2!R96%L:71Z
M87(@;W!E<F%C:6]N<R!D92!M86YT96YI;65N="!E;B!I;FEC:6%R(&QA('-E
M<W-I\S\`4&5R;>US`%!E<FUI<R!D96YE9V%T`$%D;6EN:7-T<F%D;W(@9&4@
M<&5R;6ES;W,`1&%D97,@<&5R<V]N86QS`%!E<OH`06YI;6%L<R!D92!C;VUP
M86YY:6$`1FEL:7!I;F5S`%1E;.AF;VX`1F]T;W,`4&ET8V%I<FX`4.UX96QS
M`%3R<&EC<P!#;&EC87(@96X@=6YA(&-E;+=L80!#;VYF:7)M87(@<75E('9O
M;&5U('-U<')I;6ER(&%Q=65S="!E;&5M96YT.@!#;VYF:7)M87(@<75E('9O
M;&5U(&1E<V5N;&QAYV%R(&%Q=65S="!E;&5M96YT+@!);G1R;V1U[W4@=6X@
M;65S(&D@=6X@86YY+@!);G1R;V1U[W4@=6X@;F]M('!E<B!A(&QA(&YO=F$@
M8V%T96=O<FEA.@!);G1R;V1U[W4@=6YA(&%D<F7G82!)4"!VX&QI9&$N`$EN
M=')O9'7O=2!U;F$@9&%T82!VX&QI9&$L(&-O;7!R;W9E=2!E;',@9&EE<R!Q
M=64@=.D@96P@;65S+@!);G1R;V1U[W4@=6YA(&AO<F$@=N!L:61A+@!0<F]P
M;W)C:6]N974@=6X@<F5S=6T@9&5L('!R;V)L96UA+@!0<F]P;W)C:6]N974@
M96P@;F]M(&0G=7-U87)I(&D@;&$@8V]N=')A<V5N>6$`5&5C;&5G974@96P@
M;F]M(&1E(&QA(&YO=F$@8V%T96=O<FEA.@!0;VSR;FEA`%!O;.UT:6-A`$5N
M<75E<W1E<P!0;W)T=6=A;`!#;VRW;&]C86-I\R!D)V%Q=65S=&$@:6UA=&=E
M`$-O;+=L;V-A8VGS(&0G87%U97-T82!T875L80!%;G9I87(@82!A<75E<W1A
M(&-A<G!E=&$@*&YO(&AI(&]B;&EG82!)34%0*0!0<F5C:7!I=&%C:?,@9'5R
M86YT(&QA(&1A<G)E<F$@)7,@:&]R82!O(&AO<F5S.B``4')E9G-?;&1A<#H@
M3F\@<R=H82!T<F]B870@;"=E>'1E;G-I\R!,1$%0('-O;+=L:6-I=&%D82X`
M4')E9G-?<V5S<VEO;CH@3F\@<R=H82!T<F]B870@;"=E>'1E;G-I\R!D92!S
M97-S:?,@<V]LMVQI8VET861A+@!0<F5S<VGS`%!R97-S:?,@86P@;FEV96QL
M(&1E;"!M87(Z`%!R97-S:?,Z(`!6:7-U86QI='IA8VGS('!RZ'9I80!6:7-U
M86QI='IA<B!P<NAV:6%M96YT(&QA(&EM871G92!E;B!U;F$@;F]V82!F:6YE
M<W1R80!/<&-I;VYS('!RZ'9I97,`26UP<FEM:7(@96P@9&]C=6UE;G0`0VQA
M=2!P<FEV861A`%!R;V)L96UA`$1E<V-R:7!C:?,@9&5L('!R;V)L96UA`%!R
M;VIE8W1E<P!497AT(&EN9&EC861O<@!#;&%U('#Z8FQI8V$`06QG;W)I<VUE
M(&1E(&-L874@</IB;&EC80!);F9O<FUA8VGS(&1E(&-L874@</IB;&EC80!.
M;R!S)VAA(&=E;F5R870@8V]R<F5C=&%M96YT(&QA('!A<F5L;&$@9&4@8VQA
M=7,@</IB;&EC82]P<FEV861A`%!U97)T;R!2:6-O`%%A=&%R`$-O;G-U;'1A
M`$-L874@</IB;&EC82!24T$@*"5D(&)I="D`0F]T\R!D92!S96QE8V-I\P!0
M;'5J80!0;'5J82!A('!R:6UE<F$@:&]R80!0;'5J82!C87`@86P@=&%R9`!2
M=6EX870`4&QU:F$@:2!N97<`06EG=6%N974`1&ET82!A;&5A=/)R:6$`4F5L
M86-I\P!,;&5G:74`3&QE9VEU(&5L<R!M:7-S871G97,`0V]N9FER;65U('%U
M92!V;VQE=2!S=7!R:6UI<B`E<S\@07%U97-T82!O<&5R86-I\R!N;R!E<R!P
M;W0@9&5S9F5R+@!#;VYF:7)M974@<75E('9O;&5U('-U<')I;6ER(&QE<R!D
M861E<R!D92!L)W5S=6%R:2!P97(@82!L)W5S=6%R:2`E<S\@07%U97-T82!O
M<&5R86-I\R!N;R!E<R!P;W0@9&5S9F5R+@!4;W)N82!A(&9E<B!L82!D87)R
M97)A(&%C8VGS`%)E9G)E<V-A<B!E;',@96QE;65N=',@9&5L(&UE;OH@9&EN
MX&UI8W,`4F5F<F5S8V%R(&QA('9I<W5A;&ET>F%C:?,@9&5L('!O<G1A;`!%
M>'!R97-S:?,@<F5G=6QA<@!.879E9V%D;W(@9&4@<F5L86-I;VYS`$-O;65N
M=&%R:7,`4V5R=FED;W)S(')E;6]T<P!54DP@<F5M;W0@*&AT='!S.B\O=W=W
M+F5X96UP;&4N97,O:&]R9&4I.@!3=7!R:6UI<@!3=7!R:6UI<B!B;&]C`%-U
M<')I;6ER(&-O;'5M;F$`4W5P<FEM:7(@;&$@9F]R;6%T86-I\P!3=7!R:6UI
M<B!L82!P87)E;&QA`%-U<')I;6ER(&QA('-E<?SH;F-I82!D97-A9&$@9&5L
M(&1I<F5C=&]R:2!T96UP;W)A;"!D96P@<V5R=FED;W(N`%-U<')I;6ER(&5L
M`%-U<')I;6ER(&%Q=65S="!N;V1E(&1E;"!D;V-U;65N=`!3=7!R:6UI<B!L
M)W5S=6%R:0!3=7!R:6UI<B!L)W5S=6%R:3H@)7,`3F\@<R=H82!P;V=U="!R
M97-P;VYD<F4@82!L82!S;VRW;&EC:71U9"X@0V]D:2!D)V5R<F]R(')E=&]R
M;F%T.B``3F\@<R=H82!T<F]B870@96P@<V5R=F5I('-O;+=L:6-I=&%T+@!#
M86UP('-O;+=L:6-I=&%T`%)E:6YI8VEA`%)E:6YI8VEA<B!L82!C;VYT<F%S
M96YY80!296EN:6-I87(@;&$@8V]N=')A<V5N>6$`4F5S=6QT871S`%1O<FYA
M(&$@;W!C:6]N<P!2975N:?,`4F5S=&%U<F%R(&QA(&-O;F9I9W5R86-I\P!/
M<&-I;VYS(&1E(&PG961I=&]R(&1E('1E>'0@96YR:7%U:70`16YI9VUE<P!$
M<F5T80!#87#G86QE<F$@9')E=&$`5F%L;W)S(&1E(&QA(&1R971A`%!R;W!I
M971A=',@9&4@;&$@9FEL82XN+@!&=6YC:?,`4F]M86YI80!':7)A<B`Q.#``
M1VER87(@82!L)V5S<75E<G)A`$=I<F%R(&$@;&$@9')E=&$`4')O<&EE=&%T
M<R!D92!L82!F:6QA`%!R;W!I971A=',@9&4@;&$@9FEL80!&:6QE<SH`4F5G
M;&5S`$%P87)E:7AE<F%N(')E9VQE<R!E;G1R92!T;W1E<R!L97,@9FEL97,@
M:2!C;VQU;6YE<P!!<&%R96EX97)A;B!R96=L97,@;F]MZ7,@96YT<F4@8V]L
M=6UN97,`07!A<F5I>&5R86X@<F5G;&5S(&YO;>ES(&5N=')E(&9I;&5S`$5X
M96-U=&%R`$9E9&5R86-I\R!2=7-S80!2=V%N9&$`4VEG;F%T=7)A(&-R:7!T
M;V=RX&9I8V$@86UB(%,O34E-10!-:7-S871G92!X:69R870@86UB(%,O34E-
M10!,)V%U=&5N=&EC86-I\R!305-,(&YO(&5S=.`@9&ES<&]N:6)L92X`36ES
M<V%T9V5R:6$@4TU3`$EN=.AR<')E="!D)V]R9')E<R!344P`4U-(`,A8250`
M26YTZ')P<F5T(&0G;W)D<F5S(%-13`!$<RX`4V%I;G0@2&5L96YA`%-A:6YT
M($-H<FES=&]P:&5R(&D@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0M4&EE<G)E
M+65T+4UI<75E;&]N`%-A:6YT(%9I;F-E;G0@:2!L97,@1W)E;F%D:6YE<P!-
M871E:7@@;6%R8R`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;>D@
M:2!0<NUN8VEP90!0<F]V9>]D;W(@9&4@<V%TZ&RW;&ET`$%RX&)I82!3875D
M:71A`$1E<V$`1&5S82`E<P!$97-A(&QE<R!O<&-I;VYS`$1E<V5U(&QA(&-O
M;F9I9W5R86-I\R!G96YE<F%D82!C;VT@=6YA('-E<?SH;F-I82!02%`@96X@
M96P@9&ER96-T;W)I('1E;7!O<F%L(&1E;"!S97)V:61O<BX`4R=H82!D97-A
M="!L82!C;VYF:6=U<F%C:?,@9&4@)7,N`%1E;7!E<W1E<R!D:7-P97)S97,`
M0VGH;F-I80!#97)C80!-;W1O<G,@9&4@8V5R8V$`4V5L96-C:6]N87(@96QS
M(&%R>&EU<P!396QE8V-I;VYA<B!U;F$@9&%T80!396QE8V-I;VYA<B!U;B!G
M<G5P('%U92!V=6QG=65U(&%F96=I<@!396QE8V-I;VYE=2!U;B!N;W4@<')O
M<&EE=&%R:0!396QE8V-I;VYE=2!U;B!S97)V:61O<@!396QE8V-I;VYE=2!U
M;B!U<W5A<FD@<75E('9U;&=U974@869E9VER`%-E;&5C8VEO;F5U('1O=',@
M96QS(&5L96UE;G1S(&1E(&QA(&1A=&$N`%-E;&5C8VEO;F5U('5N(&]B:F5C
M=&4`4V5L96-C:6]N974@96QS(&-A<N!C=&5R<R!Q=64@;F5C97-S:71E=2!D
M92!L97,@8V%S96QL97,@9&4@<V]T82X@4&]D974@8V]P:6%R+6QO<R!I(&5N
M9V%N>&%R+6QO<R!D92!L)^!R96$@9&4@=&5X="X`4V5L96-C:6]N87(@96P@
M9&5L:6UI=&%D;W(@9&4@;&$@9&%T83H`4V5L96-C:6]N87(@96P@9F]R;6%T
M(&1E(&QA(&1A=&$Z`%-E;&5C8VEO;F%R(&QA(&ED96YT:71A="!Q=64@=F]L
M974@<75E(&-A;G9I87(Z`%-E;&5C8VEO;F%R(&5L(&1E;&EM:71A9&]R(&1E
M(&PG:&]R83H`4V5L96-C:6]N87(@96P@9F]R;6%T(&1E(&PG:&]R83H`4V5L
M96-C:6]N87(@9&]S(&-A;7!S('%U92!C;VEN8VED96EX:6XN`%-E;&5C8VEO
M;F%R(&QA(&-O;6)I;F%C:?,@9&4@8V]L;W)S+@!396QE8V-I;VYA<B!L)VED
M:6]M82!P<F5F97)I=#H`16YV:6%R(&PG:6YF;W)M92!D96QS('!R;V)L96UE
M<P!%;G9I87(@4TU3`%-E;F5G86P`4V5N<V]R.B``4V5T96UB<F4`4^AR8FEA
M(&D@36]N=&5N96=R;P!.^FUE<F\@9&4@<^AR:64`3&5S(&1A9&5S(&1E;"!S
M97)V:61O<B!S\VX@:6YC;W)R96-T97,@;R!N;R!E<W1A;B!D:7-P;VYI8FQE
M<RX`2&$@8V%D=6-A="!L)VED96YT:69I8V%D;W(@9&4@<V5S<VGS+@!$969I
M;F5I>`!$969I;F5I>"!L97,@;W!C:6]N<R!Q=64@=7,@<&5R;65T96X@<F5I
M;FEC:6%R(&QA(&-O;G1R87-E;GEA('-I(&UA:2!L)V]B;&ED974N`$1E9FEN
M:74@96QS('-E<G9I9&]R<R!R96UO=',@82!Q=>@@=F]L974@86-C961I<B!D
M97,@9&5L('!O<G1A;"X`1&5F:6YI=2!E;"!V;W-T<F4@:61I;VUA('!R969E
M<FET+"!L82!Z;VYA(&AO<N!R:6$@:2!L97,@;W!C:6]N<R!D92!D871A+@!$
M969I;FEU(&PG87!L:6-A8VGS(&0G:6YI8VDL(&QA(&-O;6)I;F%C:?,@9&4@
M8V]L;W)S+"!E;"!R969R97-C86UE;G0@9&4@;&5S('#@9VEN97,@:2!A;'1R
M97,@;W!C:6]N<R!D92!V:7-U86QI='IA8VGS+@!#;VYF:6=U<F%C:?,`2&D@
M:&$@<V5Q_.AN8VEE<R!D)V%C='5A;&ET>F%C:?,@9&4@;&$@8V]N9FEG=7)A
M8VGS`$AI(&AA(&1I=F5R<V5S('5B:6-A8VEO;G,@<&]S<VEB;&5S(&%M8B!E
M;"!P87+@;65T<F4Z(`!397EC:&5L;&5S`$-O;7!R97,`4F5S=6T@8G)E=0!6
M;VQE=2!D969I;FER(&QE<R!C;&%U<R!D)V%C8^ES('!E<B!A(&QA(&UA:F]R
M('!A<G0@9"=E;FQL8>=O<S\`36]S=')A`$UO<W1R82!L97,@9&EF97+H;F-I
M97,@96YT<F4@;&$@8V]N9FEG=7)A8VGS(&1E<V%D82!I(&QA(&YO=F$N`%9O
M;&5U('9I<W5A;&ET>F%R(&PG:&]R82!D92!L82!D87)R97)A('-E<W-I\R!E
M;B!I;FEC:6%R/P!-;W-T<F$@;"=O<&-I\R!D92!C;VYS97)V87(@;"=O<FEG
M:6YA;`!-;W-T<F$@96P@8V%P='5R861O<@!6;VQE=2!V:7-U86QI='IA<B!L
M82!B87)R82!D92!M96[Z(&0G;W!E<F%C:6]N<R!D92!T875L83\`5F]L974@
M=FES=6%L:71Z87(@96P@;65N^B`E<R!D92!L)V5S<75E<G)A/P!-;W-T<F$@
M96P@9&G@;&5G(&1E('!R;W!I971A=',@9&4@8V5LMVQA(&1E('1A=6QA`$UO
M<W1R82!E;"!D:>!L96<@9&4@<')O<&EE=&%T<R!D92!T875L80!-;W-T<F$@
M96P@9&G@;&5G(&1E('!R;W!I971A=',@9&4@9FEL82!D92!T875L80!-;W-T
M<F$@96P@9&G@;&5G(&1E('!R;W!I971A=',@9&4@:6UA=&=E`$UO<W1R82!L
M82!CX')R96=A`%)U:7AA=',`4G5I>&%T<R!A('!R:6UE<F$@:&]R80!2=6EX
M871S(&-A<"!A;"!T87)D`%)U:7AA=',@82!L82!R;V1A;&EA`%)E9'7O=0!0
M<FEM97(@<F5D=>]U(&\@87!A<G1E=2!E;"AS*2!B;&]C*',I(&1E;"!C;W-T
M870`4VEE<G)A($QE;VYE`$1O;F5U+79O<R!D)V%L=&$`4VEG;F%T=7)A`$%L
M9V]R:7-M92!D92!S:6=N871U<F$`4VEN9V%P=7(`36ED80!/;65T(&UA;G1E
M;FEM96YT`$5S;&]VX'%U:6$`17-L;W;H;FEA`$YE=F%D80!8X&9E8R!D92!N
M974`6.!F96-S(&1E(&YE=0!8X&9E8W,@9&4@;F5U(&$@<')I;65R82!H;W)A
M`%C@9F5C<R!D92!N974@8V%P(&%L('1A<F0`1W)U:7@@9&4@;F5U.B``17%U
M:79A;&5N="!D92!L82!N974@96X@86EG=6$Z(`!);&QE<R!386QO;?,`4V]M
MX&QI80!#86[G;VYS(&D@<&]E;65S`%-E;&5C8VGS(&5N(&5L('-E;G1I="!D
M92!L82!C;&%S<VEF:6-A8VGS`$%D<F7G82!D)V]R:6=E;@!3=60MX&9R:6-A
M`%-U9"UE=7)O<&5U("A)4T\M.#@U.2TS*0!'9?)R9VEA(&1E;"!3=60@:2!L
M97,@:6QL97,@4V%N9'=I8V@@9&5L(%-U9`!(96UI<V9E<FD@<W5D`$5S<&%I
M(&5N=')E(&-E;+=L97,@861J86-E;G1S`$5S<&%I(&5N=')E(&5L(&-O;G1I
M;F=U="!I(&5L(&-O;G1O<FX@9&4@;&$@8V5LMVQA`$5S<&%I861O<@!%<W!A
M:6%T`$5S<&%I870@:2!F87)C:6UE;G0`17-P86YY80!#;W)R974@8G)O<W-A
M`$5S8W)I<'1U<F$@9&4@8V%RX&-T97)S(&5S<&5C:6%L<P!$:79I9&ER(&-E
M;+=L80!$:79I9&ER(&-O;'5M;F$`1&EV:61I<B!F:6QA`$5S<&]R=',`4W)I
M($QA;FMA`$5S=.!N9&%R9`!3=&%R(%1R96L`06YY(&0G:6YI8VD`17-T870@
M;R!P<F]V[6YC:6$`17-T870`1F]R;6%T(&0G96UM86=A='IE;6%T9V4`061R
M9>=A('!A<G1I8W5L87(`0F%R<F%T`$QL:7-T82!D92!C861E;F5S`$5L:6UI
M;F5U(&5L(&1O;6EN:2!D92!L)V%D<F7G80!%<W1I;"!;0U-370!$9RX`07-S
M=6UP=&4`16YV:6$`4W5B[6YD97@`R'AI=`!3)VAA(')E<W1A=7)A="!C;W)R
M96-T86UE;G0@;&$@8V]N9FEG=7)A8VGS+B!!8W1U86QI='IE=2!P97(@=F5U
M<F4@96QS(&-A;G9I<RX`4R=H82!D97-A="!C;W)R96-T86UE;G0@;&$@8V]N
M9FEG=7)A8VGS(&1E(&/R<&EA+@!3)VAA(&1E<V%T(&-O<G)E8W1A;65N="!L
M)V%R>&EU(&1E(&QA(&-O;F9I9W5R86-I\R!D92!C\G!I82`E<RX`4R=H82!E
M<V-R:70@8V]R<F5C=&%M96YT("<E<R<`4W5D86X`4F5S=6T`4V]R=&ED82!D
M96P@<V]L`%!O<W1A(&1E;"!S;VP`07-S;VQE;&QA=`!3;W)T:61A(&1E;"!S
M;VP`4V]R=&ED82!D96P@<V]L+U!O<W1A(&1E;"!S;VP`4V]R=&ED82!D96P@
M<V]L.B``4&]S=&$@9&5L('-O;`!0;W-T82!D96P@<V]L.@!3=7!E<NUN9&5X
M`$%S<VES=.AN8VEA`%-U<FEN86T`0V]G;F]M`%-V86QB87)D(&D@2F%N($UA
M>65N`%-W87II;.!N9&EA`%-UZ&-I80!3=>]S<V$`17)R;W(@9&4@<VEN=&%X
M:2!E;B!E;',@=&5R;65S(&1E(&-E<F-A`%)E</IB;&EC82#`<F%B(%-I<FEA
M;F$`5&5M<&5S=&$`5&5M<&5S=&$@:2!V96YT\W,`5&5M<&5S=&5S`$%R>&EU
M(%135@!0<F]P:65T871S(&1E('1A=6QA`%!R;W!I971A=',@9&4@=&%U;&$`
M5&%I=V%N`%1A:7=A;BP@<')O=NUN8VEA(&1E(&QA(%AI;F$`5&%D:FEK:7-T
M86X`5&%N>N!N:6$L(%)E</IB;&EC82!5;FED82!D90!/8FIE8W1I=3H`5&%S
M<75E<P!.^FUE<F\@9&4@=&5LZ&9O;@!496UP97)A='5R82!D=7)A;G0@;&$@
M9&%R<F5R82!H;W)A.B``5&5M<&5R871U<F$`5&5M<&5R871U<F$Z(`!!9&UI
M;FES=')A8VGS(&1E('!L86YT:6QL97,`5&5X=`!.;VWI<R!T97AT`$%L:6YE
M86-I\R!D92!T97AT`$%L:6YE870@82!D86QT`$1J+@!486EL86YDZ',@*%1)
M4RTV,C`I`%1A:6S@;F1I80!,)V5X=&5N<VGS($944"!N;R!E<W3@(&1I<W!O
M;FEB;&4N`$5L(&UO=&]R(&0G:6YT96=R86-I\R!(;W)D92]+;VQA8B!N;R!P
M97)M970@;"?Z<R!D92`B)7,B`$QA(&-L87-S92!-86EN=&5N86YC93HZ(&YO
M(',G:&$@8V%R<F5G870@8V]R<F5C=&%M96YT(R,`4R=H82!T86YC870@;&$@
M9FEN97-T<F$@9"=O<&-I;VYS+B!3;W)T:6YT(&1E;"!S:7-T96UA`%-I('9O
M;&5U('5T:6QI='IA<B!E;',@<&5R;6ES;W,L(&PG861M:6YI<W1R861O<B!H
M82!D92!C;VYF:6=U<F%R('5N(&UO=&]R(&1E('!E<FUI<V]S('!E<FUA;F5N
M="X`3F]MZ7,@96P@8V]N=&]R;B!I;F9E<FEO<@!%;"!N^FUE<F\@:61E;G1I
M9FEC861O<B!D96P@8V]N=&%C=&4@;F\@<R=H82!E<W!E8VEF:6-A="P@<R=H
M82!D96EX870@96X@8FQA;F,@;R!N;R!S)VAA('1R;V)A="!A(&QA(&)A<V4@
M9&4@9&%D97,N`%,G:&$@869E9VET(&-O<G)E8W1A;65N="!E;"!C;VYT86-T
M92!A(&QA(&QL:6)R971A(&0G861R96-E<RX`17,@;F5C97-S:71A(&5L(&)L
M;V,@9&4@<VEG;F%T=7)E<R!01U`@<V5P87)A="!P97(@=F5R:69I8V%R(&5L
M(&UI<W-A=&=E('-I9VYA="X`3"=I9&5N=&EF:6-A9&]R(&1E(&QA(&QL:7-T
M82!D92!D:7-T<FEB=6-I\R!N;R!S)VAA(&5S<&5C:69I8V%T+"!S)VAA(&1E
M:7AA="!E;B!B;&%N8R!O(&YO(',G:&$@=')O8F%T(&$@;&$@8F%S92!D92!D
M861E<RX`3F\@<R=H82!E<W!E8VEF:6-A="!L82!L;&ES=&$@9&4@9&ES=')I
M8G5C:?,N`$QE<R!C87)A8W1E<NUS=&EQ=65S(&1E;"!X:69R871G92!E>&EG
M96EX96X@=6YA(&-O;FYE>&GS('=E8B!F:6%B;&4N`$PG87)X:74@)7,@:&%U
M<FEA(&1E(&-O;G1E;FER('5N('!A<N!M971R92`E<RX`3"=A<GAI=2`E<R!H
M875R:6$@9&4@8V]N=&5N:7(@86QG=6YS('!A<N!M971R97,@)7,N`$PG87)X
M:74@;F\@8V]N=&5N:6$@9&%D97,N`$$@8V]N=&EN=6%C:?,@97,@<')E<V5N
M=&5N(&QE<R!C87#G86QE<F5S(&0G87%U97-T(&UI<W-A=&=E+VUI<W-A=&=E
M(')F8S@R,BX`4R=H82!C;VYS=&%T870@<75E(&5L(&UO9&4@9&4@<&%N=&%L
M;&$@8V]M<&QE=&$@9/-N82!P<F]B;&5M97,@86UB($EN=&5R;F5T($5X<&QO
M<F5R(&$@8V%U<V$@9"=E<G)O<G,@96X@96P@;F%V96=A9&]R('%U92!N;R!H
M96T@<&]G=70@<F5S;VQD<F4N(%!O="!S97(@<75E('9I<W5A;&ET>F5U(&)R
M;W-S82P@=7,@;6%N<75I;B!F=6YC:6]N<R!E;B!L)V5D:71O<B!I+V\@<75E
M(&5L(&YA=F5G861O<B!U<R!F86QL:2!D92!M86YE<F$@86QE873R<FEA+B!3
M:2!T96YI=2!E;"!S:7-T96UA(%=I;F1O=W,@.7@@Z7,@;6]L="!P<F]B86)L
M92!Q=64@97,@<')O9'5E:7AI('5N("=E<G)O<B!D92!P<F]T96-C:?,@9V5N
M97)A;"<@:2!H86=U974@9&4@<F5I;FEC:6%R(&1E(&YO=2X@4VDL('1O="!I
M(&%Q=65S="!A9'9E<G1I;65N="P@96YC87)A('9O;&5U('!R;W9A<B!L)V5D
M:71O<B!D92!P86YT86QL82!C;VUP;&5T82P@<')E;65U($0G86-O<F0N`%,G
M:&$@<W5P<FEM:70@;&$@:61E;G1I=&%T("(E<R(N`$YO;>ES(&5L(&-O<W1A
M="!E<W%U97)R90!,82!U8FEC86-I\R!D96P@8FEN87)I($=N=5!'(',G:&$@
M9"=I;F1I8V%R(&$@;&$@8VQA<W-E($-R>7!T7W!G<"X`4R=H82!M;W-T<F%T
M(&5L(&UI<W-A=&=E(&5N=FEA="!E;"`E<R!A("5S(&%M8B!L)V%S<W5M<'1E
M("(E<R(N($%I>/(@;F\@9V%R86YT96EX('%U92!S)VAA9VD@;&QE9VET(&\@
M96YTZ',@96P@;6ES<V%T9V4N`$5L(&YO;2!Q=64@<R=H82!D)W5T:6QI='IA
M<B!E;B!E;FQL8>=A<B!A;6(@0W)E87(@<.!G:6YA`$5S(&YE8V5S<VET82!E
M;"!M\F1U;"!O<&5N<W-L('!E<B!A(&QA(&-L87-S92!(;W)D95]#<GEP=%]S
M;6EM92X`3F\@<R=H82!P;V=U="!D97-A<B!L82!P<F5F97+H;F-I82`B)7,B
M('!E<G%UZ"!L82!I;F9O<FUA8VGS('%U92!C;VYT96YI82!S=7!E<F%V82!L
M82!M:61A(&W@>&EM82!P97)M97-A+@!.;R!S)VAA('1R;V)A="!E;B!E;"!S
M:7-T96UA(&5L('!R;V=R86UA('5S870@<&5R('9I<W5A;&ET>F%R(&%Q=65S
M="!T:7!U<R!D92!D861E<R`H)7,I+@!.;VWI<R!E;',@8V]S=&%T<R!D<F5T
M(&D@97-Q=65R<F4`3F]MZ7,@96P@8V]S=&%T(&1R970`4R=H82!S=7!R:6UI
M="!E;"!S97)V:61O<B`B)7,B+@!3)VAA(&1E<V%T(&5L('-E<G9I9&]R("(E
M<R(N`%,G:&$@96QI;6EN870@;&$@<V]LMVQI8VET=60@9"=A;'1A(&1E("5S
M+@!.;R!E>&ES=&5I>"!L)V%R>&EU('1E;7!O<F%L("(E<R(N`$YO;>ES(&5L
M<R!C;W-T871S('-U<&5R:6]R(&D@:6YF97)I;W(`3F]MZ7,@96P@8V]S=&%T
M('-U<&5R:6]R`%,G:&%N('!E<F1U="!L97,@9&%D97,@8V%R<F5G861E<R!D
M97,@9&5L('!A<R!A;G1E<FEO<BX`3F\@<R=H82!P;V=U="!D97-A<B!L)V%R
M>&EU(&-A<G)E9V%T+@!%;"!B;&]C('=E871H97(N8V]M(&YO(&5S=.`@9&ES
M<&]N:6)L92X`3F\@:&D@:&$@8V%P(&]P8VGS(&1I<W!O;FEB;&4N`$YO(&AI
M(&AA(&-A<"!P87)T('%U92!E<R!P=6=U:2!M;W-T<F%R(&5N(&SM;FEA`$%Q
M=65S="!C86UP(&-O;G3I(&UA<W-A(&-A<N!C=&5R<RX@2&5U(&EN=')O9'7O
M="`E<R!C87+@8W1E<G,@:2!N)VAE=2!D)VEN=')O9'5I<B!M96YY<R!D92`E
M<RX`2&D@:&$@:&%G=70@=6X@<')O8FQE;6$@96X@8V%R<F5G87(@;"=A<GAI
M=3H@;F\@<R=H82!C87)R96=A="`E<RX`2&D@:&$@:&%G=70@=6X@<')O8FQE
M;6$@96X@8V%R<F5G87(@;"=A<GAI=3H@96P@)7,@97)A('-U<&5R:6]R(&$@
M;&$@;6ED82!MX'AI;6$@<&5R;65S82`H)2!B>71E<RDN`$AI(&AA(&AA9W5T
M('5N('!R;V)L96UA(&5N(&-A<G)E9V%R(&PG87)X:74Z(&YO;>ES(',G:&$@
M8V%R<F5G870@<&%R8VEA;&UE;G0@96P@)7,N`%,G:&$@<')O9'7O="!U;B!E
M<G)O<B!E;B!M;W-T<F%R(&%Q=65S=&$@<&%R="!D96P@;6ES<V%T9V4`4R=H
M82!P<F]D=>]T('5N(&5R<F]R(&5N(&EM<&]R=&%R(&QE<R!D861E<R!D92!C
M;VYT86-T92X`4R=H82!P<F]D=>]T('5N(&5R<F]R(&5N(&EM<&]R=&%R(&QE
M<R!D861E<R!I0V%L96YD87(N`%,G:&$@<')O9'7O="!U;B!E<G)O<B!E;B!E
M;"!F;W)M=6QA<FD@9&4@8V]N9FEG=7)A8VGS+B!0;W1S97(@=7,@:&5U(&1E
M<V-U:61A="!D)V5M<&QE;F%R('5N(&-A;7`@;F5C97-S87)I+@!3)VAA('!R
M;V1U[W0@=6X@97)R;W(@96X@97AE8W5T87(@;&$@9G5N8VGS(&5S<&5C:69I
M8V%D82!D92!L82!L;&EB<F5T82!D)V%D<F5C97,N(%1O<FYE=2UH;R!A(&EN
M=&5N=&%R(&WI<R!T87)D+@!3)VAA('!R;V1U[W0@=6X@97)R;W(@96X@86-T
M=6%L:71Z87(@96QS(&1E=&%L;',@9&4@8V]N=&%C=&4N(%1O<FYE=2UH;R!A
M(&EN=&5N=&%R(&WI<R!T87)D+@!3)VAA('!R;V1U[W0@=6X@97)R;W(@96X@
M86-T=6%L:71Z87(@;&$@;&QI<W1A(&1E(&1I<W1R:6)U8VGS+B!4;W)N974M
M:&\@82!I;G1E;G1A<B!MZ7,@=&%R9"X`07%U97-T('-E<G9I9&]R($E-05`@
M;F\@<&5R;65T(&PG^G,@9&4@8V%R<&5T97,@8V]M<&%R=&ED97,N`$YO('-E
M;6)L82!Q=64@<VEG=6D@=6X@87)X:74@<F%R(';@;&ED+@!.;R!S96UB;&$@
M<75E('-I9W5I('5N(&%R>&EU('II<"!VX&QI9"X`3F\@<V5M8FQA('%U92!A
M<75E<W0@;OIM97)O(&1E('1A<F=E=&$@<VEG=6D@=N!L:60N`$%Q=65S="!C
M;VYT<F]L861O<B!P97)M970@96YV:6%R(&UI<W-A=&=E<R!P97(@;6ET:N`@
M9&4@;&$@<&%S<V%R96RW;&$@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E
M;&PN8V]M*2P@=71I;&ET>F%N="!L82!!4$D@2%144`!!<75E<W0@8V]N=')O
M;&%D;W(@<&5R;65T(&5N=FEA<B!M:7-S871G97,@<&5R(&UI=&K@(&1E(&QA
M('!A<W-A<F5LMVQA('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI
M('5T:6QI='IA;G0@;&$@05!)($A45%``07%U97-T(&-O;G1R;VQA9&]R('!E
M<FUE="!E;G9I87(@;6ES<V%T9V5S('!E<B!V:6$@9&4@4TU44"!A('1R87;I
M<R!D92!L82!P87-S87)E;+=L82!6;V1A9F]N92!D)TETX&QI82P@;F]MZ7,@
M82!N^FUE<F]S(%9O9&%F;VYE+B!#86P@=&5N:7(@=6X@8V]M<'1E(&1E(&-O
M<G)E=2!E;&5C='+R;FEC(&%M8B!6;V1A9F]N92!D)TETX&QI82`H:'1T<#HO
M+W=W=RXQ.3`N:70I+@#)<R!N96-E<W-A<FD@87%U97-T(&-A;7`N`$%Q=65S
M="!C86UP(&YO;>ES('!O="!C;VYT96YI<B!N;VUB<F5S(&5N=&5R<RX`07%U
M97-T(&-A;7`@;F]MZ7,@<&]T(&-O;G1E;FER(&YO;6)R97,@:2!E;',@9&]S
M('!U;G1S+@!!<75E<W0@8V%M<"!N;VWI<R!P;W0@8V]N=&5N:7(@=F%L;W)S
M(&]C=&%L<RX`07%U97-T(&-A;7`@:&$@9&4@<V5R('5N82!L;&ES=&$@9&4@
M;F]M8G)E<R!E;G1E<G,@<V5P87)A=',@<&5R(&-O;65S(&\@97-P86ES+@!!
M<75E<W0@8V%M<"!H82!D92!S97(@=6X@;OIM97)O(';@;&ED+@!!<75E<W0@
M8V%M<"!H82!D92!C;VYT96YI<B!U;B!C;V1I(&1E(&-O;&]R(&1E(&9O<FUA
M="!21T(@:&5X861E8VEM86PL('!E<B!E>&5M<&QE("<C,3(S-&%F)RX`2F$@
M<R=H82!P<F]C97-S870@87%U97-T(&9O<FUU;&%R:2X`06EX\B#I<R`E<RX`
M06EX\B#I<R!U;B!O8FIE8W1E(&1E($MO;&%B($=R;W5P=V%R92X@4&5R('9I
M<W5A;&ET>F%R(&%Q=65S="!O8FIE8W1E+"!U<R!C86P@=6X@8VQI96YT(&1E
M(&-O<G)E=2!E;&5C='+R;FEC('%U92!A9&UE=&D@96P@9F]R;6%T(&1E($MO
M;&%B($=R;W5P=V%R92X@4&5R('1E;FER(&%C8^ES(&$@=6YA(&QL:7-T82!D
M)V%Q=65S=',@8VQI96YT<R!D92!C;W)R974@96QE8W1R\FYI8RP@=FES:71E
M=2`E<P!!<75E<W0@;6ES<V%T9V4@=F$@<V5R(&5S8W)I="!A;6(@=6X@:F]C
M(&1E(&-A<N!C=&5R<R`H)7,I(&1I9F5R96YT(&1E;"!V;W-T<F4N`$%Q=65S
M="!N^FUE<F\@:&$@9&4@<V5R(&-O;2!A(&WM;FEM('5N(#$N`$%Q=65S="!S
M97)V:61O<B!N;R!P;W0@9&5S8V]M<')I;6ER(&%R>&EU<R!Z:7`@:2!G>FEP
M+@!!<75E<W0@<VES=&5M82!E<W3@(&1E<V%C=&EV870@86-T=6%L;65N="X`
M07%U97-T('9A;&]R(&AA(&1E('-E<B!U;B!N^FUE<F\N`$%Q=65S=&$@9FEN
M97-T<F$@<R=H82!D92!C<FED87(@9&5S(&0G=6YA(&9I;F5S=')A(&0G;W!C
M:6]N<P!4<F\`5&EQ=65T<P!(;W)A`$-O;G1R;VP@9&4@=&5M<',`1F]R;6%T
M(&AO<F%R:0!396QE8V-I\R!D92!T96UP<P!4:6UO<B!/<FEE;G1A;`!4[71O
M;`!4[71O;"`H<NAT;VP@:6YD:6-A9&]R(&1E(&9U;F-I\RDZ`$$`4&5R('-E
M;&5C8VEO;F%R(&1I=F5R<V]S(&5L96UE;G1S+"!M86YT:6YG=65U('!I=&IA
M9&$@;&$@=&5C;&$@0V]N=')O;"`H4$,I(&\@0V]M;6%N9"`H36%C*2!M96YT
M<F4@8VQI<75E=2X`079U:0!#;VUM=71E=2!L82!F;VYT($A434P`5&]G;P!4
M;VME;&%U`$1E;>``5&]N9V$`4W5P97)I;W(`36%R8R!S=7!E<FEO<B`H7W-U
M<&5R:6]R*0!4<F%D=6-C:6]N<P!4<FEN:71A="!I(%1O8F%G;P!697)I=&%T
M(&\@9F%L<P!$="X`5'5N[7-I80!4=7)Q=6EA`%1U<F,@*$E33RTX.#4Y+3DI
M`%1U<FMM96YI<W1A;@!);&QE<R!4=7)K<R!I($-A:6-O<P!4=79A;'4`5&5C
M;&5G974@;&$@=F]S=')A(&]P8VGS.B``S6YD97@@558Z(`!54DP`55),(&1E
M;"!V;W-T<F4@:6YF;W)M92!D92!L)V5S=&%T(&1E('1R86UE<V$@9&4@;&$@
M<V5Q_.AN8VEA`%523#H`56=A;F1A`%5C<F'O;F$`3F\@<R=H82!P;V=U="!A
M8V-E9&ER(&%L(&1I<F5C=&]R:2!61E,N`$YO(',G:&$@<&]G=70@869E9VER
M(&WI<R!D861E<R!D92!L)W5S=6%R:2!E;B!E9F5C='5A<B!L)V%L=&$N`$YO
M(',G:&$@<&]G=70@8V%N=FEA<B!E;"!P97)M[7,@9&4@;"=A<GAI=2!61E,@
M(B5S(BX`3F\@<R=H82!P;V=U="!C86YV:6%R(&5L('!E<FWM<R!D92!L)V%R
M>&EU(%9&4R`E<R\E<RX`3F\@<R=H82!P;V=U="!C86YV:6%R(&$@)7,N`$YO
M(',G:&$@<&]G=70@8V]N;F5C=&%R(&%L('-E<G9I9&]R(%-13"X`3F\@<R=H
M82!P;V=U="!C;VYN96-T87(@86UB(%-33"X`3F\@<R=H82!P;V=U="!C;W!I
M87(@;"=A<GAI=2!61E,N`$YO(',G:&$@<&]G=70@8W)E87(@96P@9&ER96-T
M;W)I(%9&4R`B)7,B+@!.;R!S)VAA('!O9W5T(&-R96%R(&5L(&1I<F5C=&]R
M:2!61E,N`$YO(',G:&$@<&]G=70@8W)E87(@;"=A<GAI=2!61E,N`$YO(',G
M:&$@<&]G=70@8W)E87(@;&$@8V%R<&5T82!61E,@(B5S(BX`3F\@<R=H82!P
M;V=U="!C<F5A<B!U;B!A<GAI=2!61E,@8G5I="X`3F\@<R=H82!P;V=U="!D
M97-C;VUP<FEM:7(@;&5S(&1A9&5S+@!.;R!S)VAA('!O9W5T('-U<')I;6ER
M("(E<R(L(&5L(&1I<F5C=&]R:2!N;R!E<W3@(&)U:70N`$YO(',G:&$@<&]G
M=70@<W5P<FEM:7(@)7,L(&5L(&1I<F5C=&]R:2!N;R!E<W3@(&)U:70N`$YO
M(',G:&$@<&]G=70@<W5P<FEM:7(@96P@9&ER96-T;W)I(%9&4R!D92!M86YE
M<F$@<F5C=7)S:79A+@!.;R!S)VAA('!O9W5T('-U<')I;6ER(&5L(&1I<F5C
M=&]R:2!61E,N`$YO(',G:&$@<&]G=70@<W5P<FEM:7(@96P@9&ER96-T;W)I
M(%9&4SH@)7,N`$YO(',G:&$@<&]G=70@<W5P<FEM:7(@;"=A<GAI=2!61E,@
M(B5S(BX`3F\@<R=H82!P;V=U="!S=7!R:6UI<B!L)V%R>&EU(%9&4RX`3F\@
M<R=H82!P;V=U="!S=7!R:6UI<B!L82!C87)P971A(%9&4R`B)7,B+@!.;R!S
M)VAA('!O9W5T('-U<')I;6ER(%9&4R!D92!M86YE<F$@<F5C=7)S:79A.B`E
M<RX`3F\@<R=H82!P;V=U="!D971E<FUI;F%R(&5L(&1I<F5C=&]R:2!A8W1U
M86PN`$YO(',G:&$@<&]G=70@97AT<F5U<F4@96QS(&1E=&%L;',@9&5L(&-E
M<G1I9FEC870N`$YO(',G:&$@<&]G=70@8V%R<F5G87(@;&$@9&5F:6YI8VGS
M(&1E("5S+@!.;R!S)VAA('!O9W5T(&UO=7)E(&PG87)X:74@5D93+@!.;R!S
M)VAA('!O9W5T(&]B<FER(&PG87)X:74@5D93("(E<R(N`$YO(',G:&$@<&]G
M=70@;V)R:7(@;"=A<GAI=2!61E,@<&5R(&5S8W)I=7)E+6AI+@!.;R!S)VAA
M('!O9W5T(&]B<FER(&PG87)X:74@5D93+@!.;R!S)VAA('!O9W5T(&]B<FER
M(&PG87)X:74@8V]M<')I;6ET+@!.;R!S)VAA('!O9W5T(&QL96=I<B!L)V%R
M>&EU(%9&4R`H;&$@;6ED82!D92!L)V%R>&EU*"D@:&$@9&]N870@97)R;W(I
M+@!.;R!S)VAA('!O9W5T(&QL96=I<B!L)V%R>&EU(%9&4R`H9V5T1FEL95-I
M>F4H*2!H82!D;VYA="!E<G)O<BDN`$YO(',G:&$@<&]G=70@;&QE9VER(&PG
M87)X:74Z("X`3F\@<R=H82!P;V=U="!L;&5G:7(@96P@9&ER96-T;W)I(&%R
M<F5L(&1E(%9&4RX`3F\@<R=H82!P;V=U="!C86YV:6%R(&5L(&YO;2!D92`E
M<R!P97(@)7,Z(&QA(&-A<G!E=&$@9&4@9&5S=&EN86-I\R!J82!E>&ES=&5I
M>`!.;R!S)VAA('!O9W5T(&-A;G9I87(@96P@;F]M(&1E;"!D:7)E8W1O<FD@
M5D93+@!.;R!S)VAA('!O9W5T(&-A;G9I87(@96P@;F]M(&1E;"!D:7)E8W1O
M<FD@5D93.B`E<RX`3F\@<R=H82!P;V=U="!C86YV:6%R(&5L(&YO;2!D92!L
M)V%R>&EU(%9&4R`B)7,B+@!.;R!S)VAA('!O9W5T(&-A;G9I87(@96P@;F]M
M(&1E(&PG87)X:74@5D93("5S+R5S+@!.;R!S)VAA('!O9W5T(&-A;G9I87(@
M96P@;F]M(&1E(&PG87)X:74@5D93+@!.;R!S)VAA('!O9W5T(&5X96-U=&%R
M("=M:VES;V9S)RX`3F\@<R=H82!P;V=U="!T<F%D=6ER(&%Q=65S="!D;V-U
M;65N="!D92!7;W)D`$YO(',G:&$@<&]G=70@97-C<FEU<F4@;"=A<GAI=2!6
M1E,@(B5S(BX`3F\@<R=H82!P;V=U="!E<V-R:75R92!L)V%R>&EU(%9&4R`H
M(W,G:&$@<')O9'7O="!U;B!E<G)O<B!E;B!C;W!I87(M;&\H*2`C*2X`3F\@
M<R=H82!P;V=U="!E<V-R:75R92!L97,@9&%D97,@9&4@;"=A<GAI=2!61E,N
M`$YO(',G:&$@<&]G=70@97-C<FEU<F4@;"=A<GAI=2!61E,L('-E('-U<&5R
M87+@(&PG97-P86D@9&ES<&]N:6)L92X`4W5B<F%T;&QA=`!$97-FZ7,@96QS
M(&-A;G9I<P!$97-FX"!L82!D87)R97)A(&%C8VGS`$5L('-E<G9I9&]R(&AA
M(&1O;F%T('5N82!R97-P;W-T82!I;F5S<&5R861A(&5N(&-O;FYE8W1A<BUS
M93H@`$5L('-E<G9I9&]R(&AA(&1O;F%T('5N82!R97-P;W-T82!I;F5S<&5R
M861A(&$Z(`!396YS92!C871E9V]R:6$`56YI8V]D92`H551&+3@I`%5N:?,@
M9&5L<R!%;6ER871S(,!R86)S`%)E9VYE(%5N:70`17-T871S(%5N:71S`$EL
M;&5S(%!E<FEFZ')I<75E<R!-96YO<G,@9&5L<R!%<W1A=',@56YI=',`56YI
M=&%T<P!$97-C;VYE9W5T`&%P:6US9VED("AI9&5N=&EF:6-A9&]R(&1E;"!M
M:7-S871G92!D92!L82!!4$DI(&1E<V-O;F5G=70N`$-L:6US9VED(&1E<V-O
M;F5G=70@*&ED96YT:69I8V%D;W(@9&5L(&UI<W-A=&=E(&1E;"!C;&EE;G0I
M+@!3)VAA('!R;W!O<F-I;VYA="!U;F$@=6)I8V%C:?,@9&5S8V]N96=U9&$N
M`$YO;2!D)W5S=6%R:2!O(&-O;G1R87-E;GEA(&1E<V-O;F5G=71S+@!$97-E
M;FQL8>=A<B!L)V5L96UE;G0@86-T=6%L`%-E;G-E(&YO;0!,97,@<V5Q_.AN
M8VEE<R!S96YS92!P97)M:7-O<R!N;R!P;V1E;B!A8V-E9&ER(&$@4F5T86QL
M87(O0V]P:6%R+T5N9V%N>&%R(&1E(&UA;F5R82!P<F]G<F%MX'1I8V$@<&5R
M(')A;VYS(&1E('-E9W5R971A="X@0VQI<75E=2!E;B!$)V%C;W)D('!E<B!V
M:7-U86QI='IA<B!U;F$@;F]T82!TZ&-N:6-A(&$@;6]Z:6QL82YO<F<@<75E
M('5S(&UO<W1R82!C;VT@<&]D974@9F5R('%U92!U;F$@<V5Q_.AN8VEA(&%C
M8V5D96EX:2!A;"!P;W)T82UR971A;&QS+B``16QI;6EN87(@96P@8V]L;W(`
M17AT96YS:?,@;F\@:6UP;&5M96YT861A`$%C='5A;&ET>F%R`$%C='5A;&ET
M>F%R("5S`$%C='5A;&ET>F%R(&PG=7-U87)I`%,G:&$@<W5P<FEM:70@;&$@
M<V5Q_.AN8VEA(&0G86-T=6%L:71Z86-I\RX`0V%R<F5G87(`4R=H82!C87)R
M96=A="!A;"!S97)V:61O<B!T;W1S(&5L<R!A<GAI=7,@9&4@8V]N9FEG=7)A
M8VGS(&0G87!L:6-A8VEO;G,N`$%L9F%B970@;&QA=.T@96X@;6%J^G-C=6QA
M`%AI9G)E<R!R;VUA;F5S(&5N(&UA:OIS8W5L80!5<G5G=6%I`%5T:6QI='IA
M<B!L)V%C='5A;#H@)7,`571I;&ET>F%R(%-33`!5=&EL:71Z974@<VD@96P@
M;F]M(&\@;&$@8V]N=')A<V5N>6$@<_-N(&1I9F5R96YT<R!A;"!S97)V:61O
M<B!)35-0+@!,)W5S=6%R:2`E<R!N;R!E<W3@(&%U=&]R:71Z870@<&5R(&$@
M)7,N`$%D;6EN:7-T<F%C:?,@9"=U<W5A<FES`$]P8VEO;G,@9"=U<W5A<FD`
M4F5G:7-T<F4@9"=U<W5A<FES`$5L(')E9VES=')E(&0G=7-U87)I<R!D)V%Q
M=65S="!L;&]C(&5S=.`@:6YH86)I;&ET870N`$YO;2!D)W5S=6%R:0!.;VT@
M9"=U<W5A<FDZ`$YO;2!D)W5S=6%R:3H@`%5S=6%R:7,@9&5L('-I<W1E;6$Z
M`%5Z8F5K:7-T86X`16P@9&ER96-T;W)I(%9&4R!N;R!E>&ES=&5I>"X`06)S
MZ&YC:6$`3&5S('5B:6-A8VEO;G,@=N!L:61E<R!Q=64@<R=H86X@=')O8F%T
M('/S;CH`5F%L:61E<V$`5F%L;W(@96X@;6EN=71S(&$@<&%R=&ER(&0G87)A
M+@!%;"!V86QO<B!S=7!E<F$@;&$@;&]N9VET=60@;>!X:6UA(&1E("5S+@!6
M86QO<G,`5F%L;W)S('%U92!S)VAA;B!S96QE8V-I;VYA<B!D90!686YU871U
M`%9A<FEA8FQE`%9E;F7G=65L80!(82!F86QL870@;&$@=F5R:69I8V%C:?,Z
M(.ES('!O<W-I8FQE('%U92!S)VAA9VD@86QT97)A="!E;"!M:7-S871G92X`
M5F5R<VGS`$-O;G1R;VP@9&4@=F5R<VEO;G,`06QI;F5A8VGS('9E<G1I8V%L
M`$9A<F-I;65N="!V97)T:6-A;`!697)T:6-A;#H`36]L="!A;'0`5FEE=&YA
M;0!6:65T;F%M:71A("A625-#24DI`%9I<W5A;&ET>F%R("5S`%9I<W5A;&ET
M>F%R('5N82!PX&=I;F$@=V5B(&5X=&5R;F$`5FES=6%L:71Z87(@8V]M(&$@
M)7,`26QL97,@5F5R9V5S(&)R:73@;FEQ=65S`$EL;&5S(%9E<F=E<R!N;W)D
M+6%M97)I8V%N97,`5FES:6)I;&ET870`5FES:6)I;&ET870Z(`!6;V1A9F]N
M92!D)TETX&QI82!P97(@=FEA(&1E(%--5%``041615)4R$Y#24$`05;-4R$@
M14Q)34E.05(@3$$@4T51W,A.0TE!($U!3E5!3$U%3E0@1$4@)7,N`%=A;&QI
M<R!I($9U='5N80!!=NUS`$1C+@!0<F5V:7-I\R!D96P@=&5M<',`26YF;W)M
M86-I\R!M971E;W)O;/)G:6-A('!R;W!O<F-I;VYA9&$@<&5R`%=E871H97(N
M8V]M`%=E8@!,;&]C('=E8@!3971M86YA;&UE;G0`0F5N=FEN9W5T<P!"96YV
M:6YG=71S(&$@)7,`0F5N=FEN9W5T<RP@)7,`3V-C:61E;G1A;"`H25-/+3@X
M-3DM,2D`3V-C:61E;G1A;"`H25-/+3@X-3DM,34I`%/@:&%R82!/8V-I9&5N
M=&%L`%%U:6YA(&%P;&EC86-I\R!H875R:6$@9&4@;6]S=')A<B`E<R!E;B!I
M;FEC:6%R(&QA('-E<W-I\S\`475I;B#I<R!E;"!C87+@8W1E<B!D96QI;6ET
M861O<C\`475I;B#I<R!E;"!C87+@8W1E<B!D92!C:71A8VGS/P!1=6EN97,@
M9F%S97,`4&QU9VEN<R!H86)I;&ET871S(&1E(&PG961I=&]R(&1E('1E>'0@
M96YR:7%U:70N`$%M<&QA9&$`06UP;&%D82!D92!L97,@=6YI=&%T<R!#4U,`
M06UP;&%D82!D96P@;65N^B`E<R!D92!L)V5S<75E<G)A("AD:7-P;VYI8FQE
M(&5N(&QA('!R;W!E<F$@<V5S<VGS*3H`06UP;&%D82!D92!L82!T875L80!5
M;FET870@9"=A;7!L861A`$%M<&QA9&$Z`%=I:VD`5F5N=`!696YT(&$@<')I
M;65R82!H;W)A`%9E;&]C:71A="!D96P@=F5N="!E;B!N=7-O<P!696YT.@!6
M96YT.B``4V%V:65S80!&96EN80!!9')EYV$@9&4@;&$@9F5I;F$`5&5LZ&9O
M;B!D92!L82!F96EN80!8+5)E9@!,:6UI=&%C:6]N<R!BX'-I<75E<R!8-3`Y
M=C,`VG,@9&4@;&$@8VQA=2!E<W1E<V$@>#4P.78S`$YO;2!A;'1E<FYA=&EU
M(&0G87-S=6UP=&4@6#4P.78S`$ED96YT:69I8V%D;W(@9&4@8VQA=2!D)V%S
M<W5M<'1E(%@U,#EV,P!%>'1E;G-I;VYS(%@U,#AV,P!!00!!04%!`$UA<&$@
M9&4@66%H;V\A`$%N=6%L;65N=`!)96UE;@!3[0!3[2P@:&\@86-C97!T;P!3
M;W4@96X@96P@34]$12!415A4+B!5<V5U(&5L(&)O=/,@6SP^72!P97(@=&]R
M;F%R(&$@5UE325=91RX`3F\@97-T974@875T96YT:6-A=',N`$YO(&AE=2!I
M;G1R;V1U[W0@=6YA(&%D<F7G82!E;&5C='+R;FEC82!VX&QI9&$N`$YO(&AE
M=2!A<W-O8VEA="!C87`@8V%M<"!D92!L)V%R>&EU(&EM<&]R=&%T(&%M8B!E
M;',@8V%M<',@8V]R<F5S<&]N96YT<R!D92`E<RX`2&5U('-O<G1I="!D92!L
M82!S97-S:?,N`$AE=2!D)VEN=')O9'5I<B!U;B!N^FUE<F\@9&4@=&5LZ&9O
M;B!M\F)I;"!VX&QI9"P@;F]MZ7,@9.UG:71S(&%M8B!U;B`G*R<@;W!C:6]N
M86P@<&5R(&%L('!R969I>"!D92!T<G5C861A(&EN=&5R;F%C:6]N86PN`$AE
M=2!D)VEN=')O9'5I<B!U;B!V86QO<B!VX&QI9"X`2&5U(&1E(&-O;F9I9W5R
M87(@=6X@;6]T;W(@9&4@1&%T851R964@<&5R('5T:6QI='IA<B!!;'1E<RX`
M2&5U(&1E(&-O;F9I9W5R87(@=6X@;6]T;W(@9&4@5D93+@!(974@9&4@9&5S
M8W)I=7)E(&5L('!R;V)L96UA(&%B86YS(&0G96YV:6%R+6YE(&PG:6YF;W)M
M92X`2&5U(&0G:6YT<F]D=6ER(&5L(%523"!Q=64@87%U97-T(&5N;&QAYR!I
M;F1I8V$N`$AE=2!D92!S96QE8V-I;VYA<B!U;B!S97)V:61O<B!Q=64@=G5L
M9W5E=2!E;&EM:6YA<BX`2&5U(&0G97-P96-I9FEC87(@=6X@;F]M(&0G=7-U
M87)I('%U92!V=6QG=65U(&5S8F]R<F%R+@!(974@9"=E<W!E8VEF:6-A<B!U
M;B!N;VT@9"=U<W5A<FD@<75E('9U;&=U974@<W5P<FEM:7(N`$AE=2!D)V5S
M<&5C:69I8V%R('%U:6X@;F]M(&0G=7-U87)I('9O;&5U(&%F96=I<BX`2&5U
M(&0G97-P96-I9FEC87(@96P@;F]M(&0G=7-U87)I('%U92!V;VQE=2!A8W1U
M86QI='IA<BX`2&5U(&0G97-P96-I9FEC87(@<75I;F$@86-C:?,@=F]L974@
M97AE8W5T87(N`$AE=2!D92!T96-L96IA<B!U;B!N;W4@;F]M(&1E(&-A=&5G
M;W)I82X`3&$@=F]S=')A('-E<W-I\R!E;B`E<R!H82!E>'!I<F%T+B!3:2!U
M<R!P;&%U+"!I;FEC:65U('5N82!N;W9A('-E<W-I\RX`3&$@=F]S=')A(&%D
M<F7G82!E;&5C='+R;FEC80!,82!T979A(&%D<F7G82!D92!R97-P;W-T80!,
M82!V;W-T<F$@:6YF;W)M86-I\P!,82!V;W-T<F$@861R9>=A(&0G26YT97)N
M970@:&$@8V%N=FEA="!D97,@<75E(&AE=2!C;VUE;N=A="!L82!S97-S:?,@
M)7,N(%!E<B!R86]N<R!D92!S96=U<F5T870L(&AE=2!D92!R96EN:6-I87(@
M;&$@<V5S<VGS+@!%;"!V;W-T<F4@;F]M`$5L('9O<W1R92!M;W1O<B!D)V%U
M=&5N=&EC86-I\R!N;R!P97)M970@<75E(&5S(&QL:7-T:6X@96QS('5S=6%R
M:7,L(&\@8ND@<&5R(&%L9W5N82!R8?,@87%U97-T82!C87)A8W1E<NUS=&EC
M82!E<W3@(&EN:&%B:6QI=&%D82X`4V5M8FQA('%U92!E;"!N879E9V%D;W(@
M:&$@8V%N=FEA="!D97,@<75E('9A=2!C;VUE;N=A<B!L82!S97-S:?,@)7,N
M(%!E<B!R86]N<R!D92!S96=U<F5T870L(&AE=2!D92!T;W)N87(@82!E;G1R
M87(@86P@<VES=&5M82X`16P@=F]S=')E(&YA=F5G861O<B!N;R!A8V-E<'1A
M(&%Q=65S=&$@8V%R86-T97+M<W1I8V$N`$5L('9O<W1R92!N879E9V%D;W(@
M;F\@<&5R;65T(&%Q=65S=&$@;W!C:?,@9"=I;7!R97-S:?,N(%!R96UI($-O
M;G1R;VP@*R!0('!E<B!I;7!R:6UI<BX`6F]N82!H;W+@<FEA(&%C='5A;#H`
M261E;G1I=&%T('!R961E=&5R;6EN861A.@!.;VT@8V]M<&QE=#H`3&$@;F]V
M82!C;VYT<F%S96YY82!P97(@82`E<R#I<SH@)7,`3&5S(&]P8VEO;G,@:&%N
M(&5S=&%T(&%C='5A;&ET>F%D97,@<&5R(&$@;&$@9'5R861A(&0G87%U97-T
M82!S97-S:?,N`$QE<R!O<&-I;VYS(&AA;B!E<W1A="!A8W1U86QI='IA9&5S
M+@!3)VAA(')E:6YI8VEA="!L82!V;W-T<F$@8V]N=')A<V5N>6$`4R=H82!R
M96EN:6-I870@;&$@=F]S=')A(&-O;G1R87-E;GEA+"!R979I<V$@96P@8V]R
M<F5U(&5L96-T<O)N:6,@:2!I;FEC:6$@;&$@<V5S<VGS(&%M8B!L82!N;W9A
M(&-O;G1R87-E;GEA+@!397)V:61O<G,@<F5M;W1S.@!)=6=O<VS@=FEA`%IA
M:7)E`%K@;6)I80!::6UB86)W90!::7!P>0!;3V-U;'1A('1E>'0@8VET871=
M`%M);F9O<FUE(&1E;"!P<F]B;&5M85T`6TUO<W1R82!T97AT(&-I=&%T("T`
M6TUO<W1R82!T97AT(&-I=&%T("T@)7,@;.UN:65S70!;;.UN:6$@)7,@9&4@
M)7-=`%]!9&UN:7-T<F%C:?,`7T-,20!?07)B<F4@9&4@9&%D97,`7U-U<')I
M;6ER(&9I;&$`7T=R=7!S`%]!:G5D80!?4')O<&EE=&%T<R!D92!L82!I;6%T
M9V4N+BX`7TEN:6-I82!L82!S97-S:?,`7U-U<G0`7TUO9&EF:6-A(&PG96YL
M;&'G+BXN`%]/<&-I;VYS`%]097)M:7-O<P!?16QI;6EN82!L)V5N;&QAYRXN
M+@!?0V]N9FEG=7)A8VGS`%]0<F]P:65T871S(&1E(&QA('1A=6QA+BXN`%]5
M<W5A<FES`&QL:6)R971A(&0G861R96-E<P!A9V5N9&$`8V%L;6$`4')E;6D@
M87%U[0!E<W3@(&-A:65N=`!A<GAI=0!D97,@9&5L("5S("@E<RD@82!L97,@
M)7,@)7,`:#H`:&@`:6UM961I870`:6YS97)E:7@`;.UN:65S70!3)VAA('!R
M;V1U[W0@=6X@8V]D:2!D)V5R<F]R("5D(&1E;"!M:VES;V9S(&5N(&-R96%R
M($E33RX`(VUM(P!N;VT`;F\@<R=H82!I;7!L96UE;G1A=`!E;F-A<F$@;F\@
M<R=H82!I;7!L96UE;G1A=`!B;&]C(&1E(&YO=&5S`'!E<F-E;G1A=&=E`'#M
M>&5L<P!E<W3@('!U:F%N=`!M;W-T<F%R(&1I9F5RZ&YC:65S`'-M<S)E;6%I
M;"!P97(@=FEA(&1E($A45%``<W,`8V]N<W1A;G0`;&QI<W1A(&1E('1A<W%U
M97,`=&5C;&5G974@;&$@8V]N=')A<V5N>6$@9'5E<R!V96=A9&5S('!E<B!C
M;VYF:7)M87(M;&$`=6YI9FEC870`<V5N<V4@;F]M`'-E;&5C8VGS(&1E(&PG
M=7-U87)I`'9#87)D`'<Z(R,`=V5A=&AE<BYC;VT`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L;V-A;&4O8G-?0D$`````````````````````````````````
M````````````````````````````````````````````````````,#`P-S4U
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W-#`@,#$W
M-C8S`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]B<U]"02],0U]-15-3
M04=%4P``````````````````````````````````````````````````````
M```````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P
M,"`Q,#4Q-30S,S<T,"`P,C$T-3``(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C
M86QE+V)S7T)!+TQ#7TU%4U-!1T53+VAO<F1E+FUO````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#4U-#,W(#$P-3$U-#,S-S0P(#`R,S(P,P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#>$@25`````(T!
M```<````A`P``!T"``#L&````````&`A```.````82$```T```!P(0``"```
M`'XA```+````AR$```P```"3(0``!````*`A```,````I2$```L```"R(0``
M!0```+XA```H````Q"$```@```#M(0``"@```/8A```5`````2(``!(````7
M(@``"P```"HB```*````-B(```T```!!(@``#@```$\B```1````7B(```T`
M``!P(@``#````'XB```-````BR(```8```"9(@``#````*`B```.````K2(`
M``X```"\(@``"````,LB```:````U"(```4```#O(@``$0```/4B```(````
M!R,``!`````0(P``#P```"$C```*````,2,```,````\(P``"0```$`C```/
M````2B,```H```!:(P``)````&4C```4````BB,```P```"?(P``+````*PC
M```+````V2,```<```#E(P``!P```.TC```#````]2,``",```#Y(P``%```
M`!TD```7````,B0``!<```!*)```'P```&(D```%````@B0``#D```"()```
M!@```,(D```4````R20```H```#>)```!````.DD```'````[B0```D```#V
M)```!@`````E```1````!R4```<````9)0``%@```"$E```$````."4```@`
M```])0``!@```$8E```-````324```8```!;)0``'@```&(E```1````@24`
M``@```"3)0``#0```)PE```,````JB4```<```"W)0```P```+\E```#````
MPR4``!,```#')0``"````-LE```(````Y"4```@```#M)0``(````/8E```&
M````%R8```8````>)@``%0```"4F```5````.R8``!0```!1)@``&````&8F
M```=````?R8```8```"=)@``5````*0F```%````^28```4```#_)@``&P``
M``4G```:````(2<``!$````\)P``$0```$XG```<````8"<``"H```!])P``
M$````*@G```%````N2<``!,```"_)P``$````-,G```'````Y"<```<```#L
M)P``!````/0G```.````^2<```8````(*```#0````\H```0````'2@``!(`
M```N*```*````$$H```%````:B@```0```!P*```"````'4H```'````?B@`
M``T```"&*```$````)0H```+````I2@```8```"Q*```&0```+@H```8````
MTB@``!0```#K*```"P`````I```)````#"D``!8````6*0``#P```"TI```6
M````/2D```@```!4*0``"P```%TI```$````:2D```\```!N*0``$````'XI
M```7````CRD``!$```"G*0``#0```+DI```)````QRD``"````#1*0``$0``
M`/(I```'````!"H```4````,*@``!P```!(J```(````&BH```8````C*@``
M!@```"HJ```0````,2H```\```!"*@``$````%(J```/````8RH```L```!S
M*@``#P```'\J```,````CRH```\```"<*@``"````*PJ```'````M2H```0`
M``"]*@``$````,(J```"````TRH```T```#6*@``$@```.0J```5````]RH`
M``0````-*P``!0```!(K```$````&"L```P````=*P``"@```"HK```(````
M-2L```D````^*P``!0```$@K```*````3BL``!D```!9*P``*0```',K```'
M````G2L```H```"E*P``#````+`K```/````O2L``!````#-*P``#P```-XK
M```'````[BL``!8```#V*P``!`````TL```$````$BP```<````7+```"```
M`!\L```@````*"P```T```!)+```#@```%<L```6````9BP``!$```!]+```
M!@```(\L```#````EBP```8```":+```!P```*$L```'````J2P```<```"Q
M+```%@```+DL```-````T"P```4```#>+```'@```.0L```)`````RT```H`
M```-+0``#````!@M```/````)2T```@````U+0``!@```#XM```'````12T`
M``L```!-+0``1P```%DM```-````H2T```D```"O+0``"@```+DM``!H````
MQ"T```4````M+@``&P```#,N```O````3RX``!````!_+@``"@```)`N```/
M````FRX```H```"K+@``"0```+8N```#````P"X```<```#$+@``"@```,PN
M```+````URX```<```#C+@``"0```.LN```'````]2X``!````#]+@``!```
M``XO```'````$R\```4````;+P``#0```"$O```,````+R\```@````\+P``
M%P```$4O```+````72\``!,```!I+P``!````'TO```*````@B\```0```"-
M+P``#````)(O```)````GR\```4```"I+P``!P```*\O```%````MR\```0`
M``"]+P```@```,(O```A````Q2\```0```#G+P``%````.PO```(`````3``
M``<````*,```$````!(P```'````(S````X````K,```!0```#HP```1````
M0#````@```!2,```!@```%LP```'````8C```!X```!J,```*````(DP```*
M````LC```!H```"],```%````-@P```H````[3```"H````6,0``$````$$Q
M```'````4C$``!,```!:,0``#0```&XQ```>````?#$``!0```";,0``#@``
M`+`Q```J````OS$```4```#J,0``$0```/`Q```'`````C(``!0````*,@``
M&````!\R```,````.#(```8```!%,@``#P```$PR```G````7#(``!D```"$
M,@``'P```)XR```3````OC(```@```#2,@``!P```-LR```(````XS(```D`
M``#L,@``%0```/8R```-````##,``!,````:,P```P```"XS``!&````,C,`
M`#\```!Y,P``-P```+DS``!7````\3,```4```!)-```"@```$\T```-````
M6C0``"T```!H-```!````)8T```E````FS0``!\```#!-```'0```.$T```$
M````_S0``!`````$-0``&P```!4U```'````,34```<````Y-0``!````$$U
M```?````1C4``"<```!F-0``(P```(XU```?````LC4``"\```#2-0``(0``
M``(V```<````)#8``#$```!!-@```@```',V```4````=C8```P```"+-@``
M!P```)@V```/````H#8``!0```"P-@``'0```,4V```'````XS8``#(```#K
M-@``(0```!XW```,````0#<``!$```!--P``"````%\W```'````:#<```<`
M``!P-P``!@```'@W```'````?S<```T```"'-P``"P```)4W```4````H3<`
M`!4```"V-P``#@```,PW```O````VS<``#$````+.```/P```#TX```&````
M?3@```,```"$.```-0```(@X```9````OC@``#````#8.```$@````DY```3
M````'#D``!`````P.0``>0```$$Y```)````NSD``"L```#%.0``%P```/$Y
M```6````"3H```\````@.@``'P```#`Z``!`````4#H``!\```"1.@``'```
M`+$Z``!1````SCH``!0````@.P``"@```#4[```%````0#L```8```!&.P``
M"````$T[```%````5CL``!(```!<.P``$````&\[```3````@#L``!T```"4
M.P``#P```+([```/````PCL```0```#2.P``"0```-<[```+````X3L```<`
M``#M.P``!0```/4[```4````^SL```<````0/```"````!@\```/````(3P`
M``@````Q/```#````#H\```/````1SP```8```!7/```%````%X\```&````
M<SP```P```!Z/```"0```(<\```'````D3P```4```"9/```"P```)\\``!U
M`0``JSP``!`````A/@``#0```#(^```(````0#X```@```!)/@``!P```%(^
M```#````6CX```H```!>/@``#0```&D^```%````=SX``!\```!]/@``#@``
M`)T^```*````K#X``!$```"W/@``#P```,D^```*````V3X```D```#D/@``
M$0```.X^```.`````#\```H````//P``"P```!H_```-````)C\```D````T
M/P``!@```#X_```/````13\```\```!5/P``#P```&4_```'````=3\``!H`
M``!]/P``!0```)@_```.````GC\```T```"M/P``&````+L_```2````U#\`
M``T```#G/P``!0```/4_```,````^S\``!8````(0```#````!]````?````
M+$```!````!,0```!@```%U````V````9$````H```";0```"````*9````%
M````KT````,```"U0```)0```+E````7````WT```!<```#W0```(`````]!
M```?````,$$```4```!000``*P```%9!```&````@D$``!8```")00``"P``
M`*!!```%````K$$```@```"R00``"@```+M!```#````QD$``!````#*00``
M!@```-M!```3````XD$```,```#V00``!P```/I!```#`````D(```T````&
M0@``!@```!1"```F````&T(``!$```!"0@``"````%1"```0````74(```P`
M``!N0@``!P```'M"```#````@T(```,```"'0@``$@```(M"```(````GD(`
M``<```"G0@``!P```*]"```E````MT(```8```#=0@``"````.1"```<````
M[4(``!,````*0P``%0```!Y#```;````-$,``!\```!00P``"````'!#``!1
M````>4,```0```#+0P``!````-!#```A````U4,``!P```#W0P``#P```!1$
M```8````)$0``"(````]1```*P```&!$```/````C$0```8```"<1```%@``
M`*-$```*````ND0```8```#%1```"0```,Q$```'````UD0``!````#>1```
M!P```.]$```,````]T0```P````$10``%@```!%%```[````*$4```8```!D
M10``!0```&M%```(````<44```H```!Z10``#P```(5%```1````E44```H`
M``"G10``!@```+)%```=````N44``!D```#710``)````/%%```$````%D8`
M``H````;1@``)````"9&```.````2T8``!8```!:1@``"````'%&```+````
M>D8```@```"&1@``$````(]&```0````H$8``!8```"Q1@``%0```,A&```,
M````WD8```@```#K1@``*````/1&```5````'4<```@````S1P``!@```#Q'
M```(````0T<```@```!,1P``!P```%5'```&````74<``!````!D1P``#P``
M`'5'```1````A4<```\```"71P``$0```*='```0````N4<```L```#*1P``
M%0```-9'```'````[$<```<```#T1P```@```/Q'```-````_T<```4````-
M2```#P```!-(```2````(T@``!@````V2```!0```$](```(````54@```<`
M``!>2```#0```&9(```.````=$@```@```"#2```"0```(Q(```%````ED@`
M``D```"<2```&````*9(```L````OT@```8```#L2```"@```/-(```+````
M_D@``!`````*20``#P```!M)```0````*TD```8````\20``%@```$-)```$
M````6DD```0```!?20``"0```&1)```%````;DD``"$```!T20``#P```)9)
M```2````IDD``"````"Y20``%0```-I)```'````\$D```4```#X20``"```
M`/Y)```%````!TH```8````-2@``"````!1*```<````'4H```L````Z2@``
M!P```$9*```G````3DH```4```!V2@``"P```'Q*```1````B$H``!H```":
M2@``"````+5*```*````ODH```4```#)2@``#@```,]*``!2````WDH``!4`
M```Q2P``"@```$=+```*````4DL``$H```!=2P``!````*A+```E````K4L`
M`#<```#32P``$`````M,```(````'$P``!(````E3```"P```#A,```*````
M1$P```,```!/3```!P```%-,```-````6TP```L```!I3```!@```'5,```(
M````?$P```@```"%3```%````(Y,```#````HTP```4```"G3```!@```*U,
M```/````M$P```\```#$3```"P```-1,```C````X$P```L````$30``%0``
M`!!-```'````)DT```H````N30``!0```#E-```/````/TT```D```!/30``
M!0```%E-```(````7TT```,```!H30``!````&Q-```"````<4T``"@```!T
M30``!P```)U-```7````I4T```@```"]30``!P```,9-```1````SDT```8`
M``#@30``#````.=-```&````]$T``!(```#[30``!0````Y.```%````%$X`
M``@````:3@``&0```"-.```M````/4X```<```!K3@``)````'-.```1````
MF$X``#4```"J3@``-0```.!.```0````%D\```@````G3P``#0```#!/```.
M````/D\``",```!-3P``&@```'%/```0````C$\``"P```"=3P``!P```,I/
M```/````TD\```<```#B3P``&0```.I/```5````!%````X````:4```!0``
M`"E0```0````+U```"P```!`4```%````&U0```8````@E```!@```";4```
M"P```+10```'````P%````@```#(4```"0```-%0```2````VU````T```#N
M4```%0```/Q0```'````$E$``$@````:40``1P```&-1```\````JU$``&(`
M``#H40``"````$M2```'````5%(```L```!<4@``+````&A2```'````E5(`
M`"\```"=4@``)@```,U2```7````]%(```@````,4P``#P```!53```;````
M)5,```0```!!4P``"````$93```%````3U,``"<```!54P``)@```'U3```:
M````I%,``!8```"_4P``,0```-93```O````"%0``!X````X5```-````%=4
M```"````C%0``!,```"/5```#P```*-4```.````LU0```X```#"5```&@``
M`-%4```C````[%0```@````050``.````!E5```?````4E4``!$```!R50``
M%@```(15```.````FU4```D```"J50``"@```+15```(````OU4```L```#(
M50``$0```-15```/````YE4``!0```#V50``%0````M6```.````(58``"P`
M```P5@``1````%U6``!*````HE8```@```#M5@```@```/96```S````^58`
M`",````M5P``-0```%%7```2````AU<``!(```":5P``$````*U7``"`````
MOE<```@````_6```)@```$A8```8````;U@``!8```"(6```$P```)]8```<
M````LU@``#(```#06```$P````-9```7````%UD``$X````O60``%@```'Y9
M```+````E5D```0```"A60``!P```*99```(````KED```4```"W60``%P``
M`+U9```2````U5D``!D```#H60``)`````):```.````)UH```\````V6@``
M!````$9:```)````2UH```L```!56@``!@```&%:```&````:%H``!$```!O
M6@``"P```(%:```&````C5H``!$```"46@``!P```*9:```(````KEH```\`
M``"W6@``!P```,=:```2````SUH```H```#B6@``!@```.U:```.````]%H`
M``D````#6P``!0````U;```+````$UL```$```#'````8@$`````````````
M`````(H```!!`0``%P```&,````-````:0```!\```"/`````````!<!````
M`````````/<```!2````*0$``+0```")`0`````````````*`0``I@```(,`
M``"_````'P$``&8```"-`0``I```````````````;0$``/P```!H`0``GP``
M``````"[````L@``````````````IP```(L`````````0@$``$<````2`0``
M``````````!9````?`$``&X!``#[``````````````#P````=0```-X```#;
M````^````'\``````````````)0````N`````@$``'`!``!^`````````'8!
M``!,````J````"P````T`0``U0`````````V````6`$````````O````4`$`
M`%X!`````````````*H```!+`0``>0````0``````````````$H```!G`0``
MRP```",!``!;`0``8`$``$0!`````````````"`!``"A`````````"T!````
M````,@```)<````W`0``U@```"0!```#`````````.D````<````50``````
M``"%````$0$```````"N```````````````#`0``-0```.\```"!````D@``
M`%@```!J`0``JP````````#-````/P$`````````````"````!P!``"3````
M;@```(@``````````````/H````)````I0````````",`0``60$```````!#
M`0``,P`````````M`````````((!``!6`0``?``````````*````PP``````
M``""````20$``)X`````````````````````````7`$````````6````=P``
M`*P```#7````5@```)H```!J````#P$```````#`````R@```#@```#4````
MY@````````#:````AP```(X````+`````````(P```!R````$0```$\!```Q
M`0``+P$``"4!``#$```````````````=`````````%4!``````````````8!
M```N`0```````.L```#8`````````+4````````````````````4````````
M`$8!``"1````,P$``)P`````````/0```,\```!Z`````````(D```!T````
M,0````````!"````*@```!X!```[````:P$``%<````.`0``O````#8!````
M````G0```,$```!+````\@```!D````U`0````````````!2`0``````````
M``"^````J0```"(````^`0``Y````"<!````````4`````````#Q````70$`
M`'X!````````!`$``!8!``#"````)0````````"`````=@``````````````
M[0```!D!``!H````@0$``/D`````````TP````X```!P````%0```+D```"&
M````?P$```````#N````YP````4`````````A@$``$@`````````/@```!4!
M``!O`0``W0```(,!``#@`````````$X!```F````FP```(@!````````````
M`+T````:`0```````"L!``"``0``<P$``-$```"Z````F0```',````8````
M-P````````#?````2@$``+$````Z`````````/\````_`````````*``````
M````.0```$@!```P````X0```#D!``!L````W````%,!```(`0``Z@```#0`
M``!-````*0```$4```!W`0``S`````````!)``````````````!Y`0``6@$`
M`-D`````````,@$``#P!````````C0```(0!```'````>P```.@```"%`0``
M%`$``(<!``!X`0``80$```````````````````````#0````$`$````````K
M````#`$````````:`````````%$```!]`````````!L`````````*`$``#P`
M````````6@```#L!``#S````9P`````````B`0````````4!````````````
M``8````>````B@$```````"C````````````````````+`$``"$!``!<````
M0`$``&````!T`0```````"H!``"X````[````#`!``!`````_0```%\!``!B
M````>@$``!@!``"5``````````````!A````/0$``&L```!;`````````&\`
M````````)P````L!``"V````70```%\`````````.`$``/4````2`````@``
M`+````"W````$P``````````````3`$``-(```!.````_@```&D!``!-`0``
MF````'(!``!!````90```*(```#%````'0$```````"O````1````",```#E
M````0P````\```!L`0```````&,!``"0````1@````````"S````!P$``,D`
M``#V`````````&0``````````````$<!```````````````````,````````
M`.(`````````9@$``*T```!]`0``=0$````````Z`0``S@```$4!``!4````
M`````%,````D````>````'L!``!Q`````````,8``````0``&P$``%<!``"$
M````#0$``%$!````````]``````````0````R````%0!``!/````*````.,`
M````````)@$``)8`````````(0`````````@````90$````````)`0``7@``
M``$!``!D`0```````'$!```3`0``;0```(L!````("@E<R!D87ES(&%G;RD`
M("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E<F1A
M>2D`(&%T(``E9"`E<R!A;F0@)7,`)7,@+2!.;W1I8V4`)7,@2T(`)7,@36%I
M;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E
M<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X
M:7-T<RX`)7,@870@)7,@)7,`)7,@;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S
M('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L96YD87(`
M)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"TM('-E;&5C="`M
M+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P!!(&9A
M=&%L(&5R<F]R(&AA<R!O8V-U<G)E9`!!32]030!!8F]U="!T:&ES(&5D:71O
M<@!!8F]U="XN+@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!
M8V-O=6YT:6YG`$%D9`!!9&0@2&5R93H`061D(&$@;F5W('5S97(Z`$%D9"!C
M;VQU;6X`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D
M9"!T;R!A9&1R97-S(&)O;VLZ`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@
M<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9F=H86YI<W1A;@!!
M;&)A;FEA`$%L9V5R:6$`06QL`$%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L
M:7-T('1Y<&4_`$%L=&5R;F%T92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0
M(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S97)N86UE`$%N(&EL;&5G86P@
M=F%L=64@=V%S('-P96-I9FEE9"X`07!R:6P`07-K(&9O<B!C;VYF:7)M871I
M;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%U9W5S
M=`!"86QT:6,@*$E33RTX.#4Y+3$S*0!";&]C:R!4>7!E`$)O;&0`0F]L:79I
M80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O<F1E<G,`
M0F]S;FEA(&%N9"!(97)Z96=O=FEN80!";W1H`$)O='-W86YA`$)O='1O;0!"
M;W5V970@27-L86YD`$)R87II;`!"<FET:7-H($EN9&EA;B!/8V5A;B!497)R
M:71O<GD`0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R:6$`0G5L;&5T960@3&ES
M=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#`$-?96QL(%!R;W!E<G1I
M97,N+BX`0V%L96YD87(`0V%M8F]D:6$`0V%M97)O;VX`0V%N)W0@8V]N;F5C
M="!T;R!)34%0('-E<G9E<CH@)7,`0V%N861A`$-A;F-E;`!#86YC96P@4')O
M8FQE;2!297!O<G0`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-E;'1I8R`H25-/
M+3@X-3DM,30I`$-E;G1R86P@069R:6-A;B!297!U8FQI8P!#96YT<F%L($5U
M<F]P96%N("A)4T\M.#@U.2TR*0!#:&%N9V4`0VAA;F=E('1H92!N86UE(&%N
M9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@
M<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM
M<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#
M:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W
M('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O
M<B!O<F1E<F5D(&QI<W1S*0!#:')I<W1M87,@27-L86YD`$-L96%R`$-L96%R
M($U33V9F:6-E('1A9W,`0V]L;W5R('-E;&5C=&EO;@!#;VUO<F]S`$-O;7!A
M;GD`0V]P>0!#;W!Y('-E;&5C=&EO;@!#<F5A=&4`0W)E871E(&$@;&EN:P!#
M<F5A=&4@82!N97<@;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#=7-T;VUI>F4@
M=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$1A:6QY`$1A=&4`1&5C
M96UB97(`1&5F875L=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`
M1&5F:6YI=&EO;G,`1&5L971E`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`
M1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E<V-R:6)E('1H92!0<F]B;&5M
M`$1E<V-R:7!T:6]N`$1I<F5C=&]R>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_
M`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1O=VYL
M;V%D`$1O=VYL;V%D("5S`$5D:70`161I="!097)M:7-S:6]N`$5D:70@4&5R
M;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I;VYS
M(&9O<CH`16UA:6P@061D<F5S<P!%;6]T:6-O;G,`16YA8FQE(')I9VAT(&-L
M:6-K(&-O;G1E>'0@;65N=3\`17%U871O<FEA;"!'=6EN96$`17)I=')E80!%
M<G)O<@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@,34@
M;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R
M>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y
M(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`1F5B<G5A<GD`1FEL=&5R<P!&<F]M
M`$9U;&P@1&5S8W)I<'1I;VX`1V\`1V]O9VQE(%-E87)C:`!'<F5E:R`H25-/
M+3@X-3DM-RD`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE;'``2&]?;64`2&]M
M90!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`
M2&]R9&4`25`@061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0
M($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$EC96QA
M;F0`26-O;G,@3VYL>0!)8V]N<R!F;W(@)7,`26-O;G,@=VET:"!T97AT`$ED
M96YT:71Y)W,@;F%M93H`26YS97)T(&UE<W-A9V5S`$IA;G5A<GD`2F%P86YE
M<V4@*$E33RTR,#(R+4I0*0!*=6QY`$IU;F4`3&%?>6]U=`!,86YG=6%G90!,
M86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T(%5P9&%T960Z
M`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L
M;V=I;CH@3F5V97(`3&%T=FEA`$QA=P!,87EO=70`3&5B86YO;@!,97-O=&AO
M`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN
M`$QI;FMS`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:71H=6%N
M:6$`3&]A9&EN9RXN+@!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO
M8V%T:6]N`$QO9R!I;@!,;V<@;W5T`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE
M9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R
M960@:6YC;W)R96-T;'DN`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QU>&5M
M8F]U<F<`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@
M=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I
M=&@@=&AO<V4@8V%T96=O<FEE<RX`36%R8V@`36%R:R!W:71H(%-E96XO56YS
M965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A
M;G0O06YS=V5R960I`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-871C
M:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`36%Y`$UE;6)E<G,`
M365N=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UI;64@5'EP90!-;VYT
M:&QY`$UY(%!O<G1A;"!,87EO=70`3F%M90!.971W;W)K`$YE=F5R`$YE=R!#
M86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!-;V]N`$YE=R!5<V5R;F%M92`H
M;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W
M<P!.97=S9W)O=7!S`$YE>'0`3F5X="!O<'1I;VYS`$YI8V%R86=U80!.:6=E
M<@!.:6=E<FEA`$YI9VAT`$YI=64`3F\`3F\@=7-E<FYA;64@86YD+V]R('!A
M<W-W;W)D('-E;G0N`$YO;F4`3F]R9&EC("A)4T\M.#@U.2TQ,"D`3F]V96UB
M97(`3V-T;V)E<@!/<&5R871I;F<@4WES=&5M`$]P=&EO;G,`3W!T:6]N<R!F
M;W(@)7,`3W1H97(`3W1H97(@26YF;W)M871I;VX`4&%S<W=O<F0`4&5O<&QE
M`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O
M<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO
M;@!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!097)S;VYA;"!);F9O<FUA
M=&EO;@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN
M`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0
M<F5V:6]U<R!O<'1I;VYS`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!2
M96%D(&UE<W-A9V5S`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.@!2
M969R97-H(%!O<G1A;"!6:65W.@!296UO=&4@4V5R=F5R<P!296UO=&4@55),
M("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5S970`4F5T=7)N
M('1O($]P=&EO;G,`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H
M(%1E>'0@161I=&]R($]P=&EO;G,`4V%V92!/<'1I;VYS`%-E87)C:`!396QE
M8W0@82!S97)V97(`4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C
M:&%N9V4Z`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@
M<')E9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@
M4TU3`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N
M=&5N96=R;P!397)I86P@3G5M8F5R`%-E<W-I;VX@240@97AP:7)E9"X`4V5T
M`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W
M;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T('5P(')E;6]T92!S97)V
M97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN
M`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A
M=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L
M;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y
M(&]P=&EO;G,N`%-E='5P`%-E>6-H96QL97,`4VAO<G0@4W5M;6%R>0!3:&]U
M;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO
M=P!3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@
M=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O
M;B!T:&4@;&5F=#\`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-O=71H($5U<F]P
M96%N("A)4T\M.#@U.2TS*0!3=6)J96-T`%-U8V-E<W,`5&5X=`!4:&%N:R!Y
M;W4@9F]R('5S:6YG('1H92!S>7-T96TN`%1H92!/<'1I;VYS('=I;F1O=R!H
M87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E
M;B!D96QE=&5D+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H
M97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T
M`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('9A;'5E
M(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D
M(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&\`5'5R:VES:"`H25-/+3@X-3DM
M.2D`56YD;R!#:&%N9V5S`%5N9FEL960`56YI8V]D92`H551&+3@I`%5N:71E
M9"!!<F%B($5M:7)A=&5S`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N
M`%5N;F%M960`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O
M<B!)35-0('-E<G9E<BX`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@
M)7,N`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R;F%M90!6
M:65W("5S`%=A<FYI;F<`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E<P!7
M96QC;VUE+"`E<P!797-T97)N("A)4T\M.#@U.2TQ*0!797-T97)N("A)4T\M
M.#@U.2TQ-2D`5V5S=&5R;B!386AA<F$`5VAA="!A<'!L:6-A=&EO;B!S:&]U
M;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAI8V@@<&QU9VEN<R!T;R!E
M;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+@!7:61T:"!O9B!T:&4@
M)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G
M+6EN*3H`665A<FQY`%EE<P!9;W4@8V%N(&YO="!H879E('1H92`G7"<@8VAA
M<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@:&%V92!B965N(&QO9V=E
M9"!O=70N`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO
M9VEN(&%G86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R
M97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@061D<F5S<R!H
M87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S
M<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I
M;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T('1H:7,@9F5A='5R92X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U
M<B!D969A=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!N97<@
M<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V92!B965N
M('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN`%EO
M=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P87-S=V]R9"!H
M87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C
M:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S
M=V]R9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`675G;W-L879I80!:86ER90!:
M86UB:6$`6FEM8F%B=V4`6FEP<'D`6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B
M;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@
M5&5X="`M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T
M:6]N`%]#3$D`7T1A=&%4<F5E`%]$96QE=&4@4F]W`%]'<F]U<',`7TAE;'``
M7TEM86=E(%!R;W!E<G1I97,N+BX`7TQO9R!I;@!?3&]G(&]U=`!?36]D:69Y
M($QI;FLN+BX`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN:RXN
M+@!?4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`7U5S97)S`&%D9')E<W,@
M8F]O:P!T87-K(&QI<W0`=6YN86UE9`!V0V%R9`!W96%T:&5R+F-O;0!0<F]J
M96-T+4ED+59E<G-I;VXZ(&AO<F1E+6)S"E)E<&]R="U-<V=I9"U"=6=S+51O
M.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U
M+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-2TP-RTP
M,2`Q,SHS,2LP,C`P"DQA<W0M5')A;G-L871O<CH@5F5D<F%N($QJ=6)O=FEC
M(#QV;&IU8F]V:6-`<VUA<G1N970N8F$^"DQA;F=U86=E+51E86TZ($)O<VYI
M86X@/&QO:V%L0&QI;G5X+F]R9RYB83X*34E-12U697)S:6]N.B`Q+C`*0V]N
M=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3(*0V]N
M=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`I8+4=E;F5R871O<CH@2T)A
M8F5L(#$N,3`*`"`H<')I:F4@)7,@9&%N82D`("AZ82`E<R!D86YA*0`@*&1A
M;F%S*0`@*'-U=')A*0`@*&IUZ&4I`"!U(``E9"`E<R!I("5S`"5S("T@3F%P
M;VUE;F$`)7,@2T(`)7,@4V5R=FES;F4@;W!E<F%C:6IE("T@<&]T=G)D80`E
M<R!P;V1EN6%V86YJ90`E<R!P<FEJ879A`"5S('5S;&]V:2!U9V]V;W)A`"5S
M('9EYB!P;W-T;VII+@`E<R!U("5S("5S`"5S(&UI;G5T80`E<R!N:6IE('!R
M;VYA\&5N+@`E<R!Z82`E<R!O9"`E<P`E<R!A9')E<V%R`"5S(&MA;&5N9&%R
M`"5S(&)I;&IEOFYI8V$`)7,@>F%D86-I`"5S.B`E<P`M+2!I>F%B97)I=&4@
M+2T`,3(M<V%T;FD@9F]R;6%T`#(T+7-A=&YI(&9O<FUA=``R-"!S871A`$1O
MN6QO(&IE(&1O(&9A=&%L;F4@9W)EN6ME`$%-+U!-`$\@;W9O;2!E9&ET;W)U
M`$\@<')O9W)A;74N+BX`J6EF<F$@:V]R:7-N:>AK;V<@;F%L;V=A`$YA;&]G
M(&IE('IA;7)Z;G5T+@!28>AU;F]V;V1S='9O`$1O9&%J`$1O9&%J(&]V9&IE
M.@!$;V1A:B!N;W9O9R!K;W)I<VYI:V$Z`$1O9&%J(&MO;&]N=0!$;V1A:B`E
M<R!M96YI('4@36]Z:6QL82!3:61E8F%R`$1O9&%J('4@861R97-A<CH`26UE
M;FEK`$%D;6EN:7-T<FER86YJ92`M('!O9&6Y879A;FIE(&1O>G9O;&$@9')U
M9VEH(&MO<FES;FEK80!!9F=A;FES=&%N`$%L8F%N:6IA`$%LOFER`%-V90!$
M;WIV;VQI('!R879L:F5N:F4@;G5M97)I<V%N:6@@;&ES=&D_`$%L=&5R;F%T
M:79N:2!)35-0(&QO9VEN`$%L=&5R;F%T:79N82!)35-0(+EI9G)A`$%L=&5R
M;F%T:79N;R!)35-0(&MO<FES;FGH:V\@:6UE`%5N9;EE;F$@:F4@:6QE9V%L
M;F$@=G)I:F5D;F]S="X`07!R:6P`4&ET86H@<')I:F4@;V)A=FQJ86YJ82!S
M97)V:7-N:6@@;W!E<F%C:6IA/P!!=6=U<W0`0F%L=&GH:VD@*$E33RTX.#4Y
M+3$S*0!6<G-T82!B;&]K80!-87-N;P!";VQI=FEJ80!:86)I;&IEN6ME`%)U
M8@!$96)L:FEN82!R=6)O=F$Z`%)U8F]V:0!";W-N82!I($AE<F-E9V]V:6YA
M`$]B80!";V-V86YA`$1N;P!";W5V970@;W-T<G9O`$)R87II;`!"<FET86YS
M:V$@26YD:6IS:V\M3VME86YS:V$@5&5R:71O<FEJ80!"<G5N96D@1&%R=7-S
M86QA;0!"=6=A<G-K80!,:7-T82!S82!T8>AK86UA`$)U<FMI;F$@1F%S;P!"
M=7)U;F1I`$--4P!#4D,`3W-O8FEN92#F7V5L:6IE+BXN`$MA;&5N9&%R`$MA
M;6)O\&$`2V%M97)U;@!.92!M;V=U('-E('-P;VII=&D@;F$@24U!4"!S97)V
M97(Z("5S`$MA;F%D80!/9'5S=&%N:0!/9'5S=&%N:2!O9"!P<FEJ879E('!R
M;V)L96UA`$MA=&5G;W)I:F4@:2!O>FYA:V4`2V5L='-K:2`H25-/+3@X-3DM
M,30I`$-E;G1R86QN;RU!9G)IZ&MA(%)E<'5B;&EK80!#96YT<F%L;F\M979R
M;W!S:VD@*$E33RTX.#4Y+3(I`%!R;VUJ96YI`%!R;VUI:F5N:71E(&EM92!I
M(&%D<F5S=2!K;VIE('9I9&4@9')U9VD@:V%D82#H:71A:G4@:2!O9&=O=F%R
M86IU(&YA('9AN64@<&]R=6ME+@#(:6QE`$MI;F$`2VEN97-K:2!P;VIE9&YO
M<W1A=FQJ96YI("A'0C(S,3(I`$MI;F5S:VD@=')A9&EC:6]N86QN:2`H0FEG
M-2D`27IA8F5R:71E(+EI9G)U`$EZ86)E<FET92!K;W)I<VYIZ&MO(&EM90!)
M>F%B97)I=&4@:V%K;R!S92!P<FEK87IU:F4@9&%T=6TZ`$EZ86)E<FET92!V
M<G-T=2!S=&EL82`H>F$@;G5M97)I<V%N92!L:7-T92D`57-K<KEN:F4@;W-T
M<G9O`$_H:7-T:0!/Z&ES=&D@35-/9F9I8V4@=&%G;W9E`$EZ8F]R(&)O:F4`
M2V]M;W)I`$MO;7!A;FEJ80!+;W!I<F%J`$MO<&ER86H@:7IA8G)A;F\`2W)E
M:7)A:@!.87!R879I(&QI;FL`3F%P<F%V:2!N;W9I`%!R879L:F5N:F4@<&]D
M+69O;&1E<F$`4&]D97-I=&4@>F%D871K92!K;VII(.9E('-E(&EZ=G*Y879A
M=&D@;F%K;VX@<')I:F%V92!N82`E<RX`1&YE=FYO`$1A='5M`$1E8V5M8F%R
M`%-T86YD87)D;F\`4W1A;F1A<F1N82!B;VIA`$1E9F%U;'0@:61E;G1I=&5T
M`$1E9FEN:6-I:F4`3V)R:;EI`$)R:7-A;FIE(&D@:7IB86-I=F%N:F4@<&]R
M=6MA`$]B<FFY:2!I>F%B<F%N:2!I9&5N=&ET970`3W!IN6ET92!P<F]B;&5M
M92!U(')A9'4@<V$@=V5B;6%I;&]M`$]P:7,`1&ER96MT;W)I:@!0<FEK8;YI
M('9R:6IE;64@=2`R-"US871N;VT@9F]R;6%T=3\`3W!C:6IE('!R:6MA>F$`
M4')I:V&^:2!P<F]G;F]Z=2`H5$%&*0!$;W=N;&]A9`!$;W=N;&]A9"`E<P!)
M>FUI:F5N:0!)>FUI:F5N:2!D;WIV;VQU`$EZ;6EJ96YI(&1O>G9O;&4`27IM
M:6IE;FD@9&]Z=F]L92!Z82`E<P!)>FUI:F5N:71E(&]P8VEJ92!Z83H`16UA
M:6P@861R97-A`%-M86IL:6II`$%K=&EV:7)A:B!K;VYT96MS="!M96YI(&YA
M(&1E<VYO;2!K;&EK=3\`16MV871O<FEJ86QN82!'=FEN96IA`$5R:71R96IA
M`$=R9;EK80!%<W1O;FEJ80!%=&EO<&EJ80!%=&YIZ&MI`$5V<F]P80!3=F%K
M:6@@,34@;6EN=71A`%-V86MI:"`R(&UI;G5T90!3=F%K:6@@,S`@<V5K=6YD
M:0!3=F%K:6@@-2!M:6YU=&$`2V]D('-V86ME('!R:6IA=F4`4W9A:VEH('!O
M;&$@<V%T80!3=F%K:2!M:6YU=`!6<FEJ961N;W-T:2!P<FEM:F5R:3H`1F5B
M<G5A<@!&:6QT97)I`$]D`$1E=&%L:F%N(&]P:7,`2W)E;FD`1V]O9VQE('!R
M971R86=A`$=RZ&MI("A)4T\M.#@U.2TW*0!(96)R96IS:VD@*$E33RTX.#4Y
M+3@M22D`4&]M;^8`4&_H7V5T86L`4&_H971A:P!!9')E<V$@*&MUYFDI`%1E
M;&5F;VX@*&MUYFDI`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!)4"!A9')E
M<V$`25`@861R97-A(&YI:F4@9&]S='5P;F$N`$E0(&%D<F5S82!N:6IE(&1O
M>G9O;&IE;F$@=6YU=&%R($-)1%(@8FQO:V$N`$ES;&%N9`!386UO(&EK;VYE
M`$EK;VYE('IA("5S`$EK;VYE('-A('1E:W-T;VT`26UE(&ED96YT:71E=&$Z
M`$1O9&%V86YJ92!P;W)U:V$`2F%N=6%R`$IA<&%N<VMI("A)4T\M,C`R,BU*
M4"D`2G5L:0!*=6YI`%)A7W-P;W)E9`!*97II:P!,86\@3F%R;V1N82!$96UO
M:W)A='-K82!297!U8FQI:V$`6F%D;FIA(&EZ;6IE;F$Z`%IA9&YJ82!P<FEJ
M879A.B`E<P!:861N:F$@<')I:F%V83H@)7,@<V$@861R97-E.B`E<P!:861N
M:F$@<')I:F%V83H@3FEK860`3&%T=FEJ80!:86MO;@!287-P;W)E9`!,:6)A
M;@!,97-O=&\`3&EB97)I:F$`3&EB:6IS:V$@07)A<'-K82!$OF%M86AI<FEJ
M80!,:6AT96ZY=&%J;@!,:6YK;W9I`$QI<W1A;FIE("T@:V]R:7-N:6L@;6^^
M92!V:61J971I(&9O;&1E<@!,:71V80!5Z&ET879A;2XN+@!,;VMA;&YO('9R
M:6IE;64Z(`!,;VMA;&YE('!O<W1A=FME(&D@=G)I:F5M90!,;VMA8VEJ80!0
M<FEJ879I('-E`$EZ;&%Z`%IA9&%C:2!P<FEJ879E`%!R:6IA=F$@;FEJ92!U
M<W!J96QA+B!.86IV97)O=F%T;FEJ92!J92!P;V=R9;EN;R!U;F5S96YO(&MO
M<FES;FGH:V\@:6UE(&EL:2"Y:69R82X`4')I:F%V82!N:6IE('5S<&IE;&$N
M`$1U9VD@=&5K<W0`3'5K<V5M8G5R9P!.87!R879I=&4@:V%T96=O<FEJ92!S
M=&%V:VD@:2!Z82!S=F%K=2!O9"!N:FEH(&]D<F5D:71E(&]D9V]V87)A:G7F
M=2!B;VIU+@!-87)T`$]Z;F'H879A;FIE(&MA;R!P<F_H:71A;F\O;F5P<F_H
M:71A;F\`3WIN8>AA=F%N:F4@9')U9VEM(&]Z;F%K86UA("AN<'(N('9AOFYO
M(&EL:2!O9&=O=F]R96YO*0!-87*Y86QO=F$@;W-T<G9A`$UA<G1I;FEK`$]D
M9V]V87)A:G7F82!P;VQJ80!-875R:71A;FEJ80!-875R:6-I:G5S`$UA:@#(
M;&%N;W9I`%9R<W1A(&UE;FEJ83H`4W!O:FD@<&]L:F$`4&]R=6MA`$UI;64@
M=&EP`$UJ97-EZ&YO`%)A<W!O<F5D(&UO9R!P;W)T86QA`$EM90!-<F6^80!.
M:6MA9&$`3F]V82!+86QE9&]N:6IA`$YO=F$@:V%T96=O<FEJ80!.;W9I(&UJ
M97-E8P!.;W9O(&MO<FES;FGH:V\@:6UE("AN:6IE(&]B879E>FYO*0!.;W9I
M(%IE;&%N9`!.;W9I('!R;WIO<B`H7W!R87IA;BD`3F]V;W-T:0!.97=S+6=R
M=7!E`$1A;&IE`%-L:F5D9>9E(&]P8VEJ90!.:6MA<F%G=F$`3FEG97(`3FEG
M97)I:F$`3F_F`$YI=64`3F4`3FEJ92!P;W-L86YO(&MO<FES;FGH:V\@:6UE
M(&DO:6QI(+EI9G)A+@!.:6IE9&%N`$YO<F1I:G-K:2`H25-/+3@X-3DM,3`I
M`$YO=F5M8F%R`$]K=&]B87(`3W!E<F%T:79N:2!S:7-T96T`3W!C:6IE`$]P
M8VEJ92!Z82`E<P!/<W1A;&\`3W-T86QE(&EN9F]R;6%C:6IE`*EI9G)A`$QJ
M=61I`%!R;V-E;F%T`$EZ=G*Y:2!S97)V:7-N92!O<&5R86-I:F4`27IV<KEI
M('-E<G9I<VYE(&]P97)A8VEJ92!P<FEL:6MO;2!L;V=I<F%N:F$_`$1O>G9O
M;&4`061M:6YI<W1R86-I:F$@9&]Z=F]L82`H<')I=FEL96=I:F$I`$QIZ&YE
M(&EN9F]R;6%C:6IE`$UO;&EM;R!D86IT92!K<F%T86L@;W!I<R!V8;EE9R!P
M<F]B;&5M82!S82!W96)M86EL;VTN`%-L86YJ92!U(&]V86H@9F]L9&5R("AN
M:6IE('!R:6YU\&5N;R!O9"!S=')A;F4@24U!4&$I`%!R971H;V1N92!O<&-I
M:F4`4')O8FQE;3\`3W!I<R!P<F]B;&5M80#(:71A;FIE('!O<G5K80!!OG5R
M:7)A:B!D:6YA;6GH:V4@96QE;65N=&4@;65N:6IA.@!!OG5R:7)A:B!P;^AE
M=&YU('-T<F%N:6-U.@!59&%L:F5N:2!S97)V97)I`%5D86QJ96YI(%523"`H
M:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%!O;FFY=&D`3F%Z860@
M;F$@;W!C:6IE`%)E=6YI;VX`5G)A=&D@<W1A<G4@:V]N9FEG=7)A8VEJ=0!/
M<&-I:F4@961I=&]R82!T96MS=&$`4V'H=79A:B!O<&-I:F4`5')AOFD`27IA
M8F5R:71E('-E<G9E<@!)>F%B97)I=&4@:61E;G1I=&5T(&MO:FD@OF5L:71E
M('!R;VUI:F5N:71I.@!)>F%B97)I=&4@N65M=2!B;VIA+@!)>F%B97)I=&4@
MOF5L:F5N:2!J97II:SH`4&^Y86QJ:2!P<FEJ879U('!R;V)L96UA`%!ON6%L
M:FD@4TU3`%-E;F5G86P`4V5N>F]R.B``4V5P=&5M8F%R`%-R8FEJ82!I($-R
M;F$@1V]R80!397)I:G-K:2!B<F]J`$E$('-E<VEJ92!J92!I<W1E:V%O+@!/
M9&%B97)I`%!O9&5S:71E(&]P8VEJ92!K;VIE('9A;2!O;6]G=>9U:G4@9&$@
M<&]N:;ET:71E(+EI9G)U(&%K;R!J92!Z86)O<F%V:71E+@!0;V1E<VET92!U
M9&%L:F5N92!S97)V97)E(&MO:FEM82"^96QI=&4@<')I<W1U<&ET:2!P=71E
M;2!V8;EE9R!P;W)T86QA+@!/9&%B97)I=&4@OF5L:F5N:2!J97II:RP@=G)E
M;65N<VMU('IO;G4@:2!P;W-T879K92!Z82!D871U;2X`4&]D97-I=&4@<W1A
M<G1N=2!K;VUP;VYE;G1U+""Y96UU(&)O:F$L(&]S=FIEOF%V86YJ92!S=')A
M;FEC92!I(&1R=6=E(&]P8VEJ92!K;VIE('-E('1IZ'4@<')I:V%Z82X`4&]S
M=&%V:V4`4V5JN65L:0!+<F%T86L@;W!I<P!$82!L:2!D969I;FES871I('!R
M:7-T=7!N92!T:7!K92!Z82!L:6YK;W9E/P!0<FEK8;YI`%!R:6MAOFD@=G)I
M:F5M92!Z861N:F4@<')I:F%V92!N86MO;B!L;V=I<F%N:F$_`%!R:6MAOFD@
M;65N:2!Z82!M86YI<'5L86-I:F4@=&%B96QA;6$_`%!R:6MAOFD@)7,@;65N
M:2!L:6IE=F\_`%9E;&GH:6YA`%!R97-K;^AI('-E<G9I<P!*=;YN;RUE=G)O
M<'-K:2`H25-/+3@X-3DM,RD`5&5M80!5<W!J9;EN;P!496MS=`!(=F%L82"Y
M=&\@:V]R:7-T:71E($5N97)G;V1A=&$@=V5B;6%I;"X`4')O>F]R('IA(&]P
M8VEJ92!S92!Z871V;W)I;RX@27IL87II;2X`261E;G1I=&5T("(E<R(@:F4@
M;V)R:7-A;BX`3F5M82!D;W-T=7!N:6@@;W!C:6IA+@!$97-I;&$@<V4@9W)E
MN6MA('1O:V]M('!R:6MA>F$@;W9O9R!D:6IE;&$@<&]R=6ME`%9R:6IE9&YO
M<W0@;W9O9R!B<F]J82!M;W)A(&YA:FUA;FIE(&EZ;F]S:71I(#$N`$]V82!V
M<FEJ961N;W-T(&UO<F$@8FET:2!B<F]J+@!/=F%J('!R;WIO<B!S92!S;6EJ
M92!P;WII=F%T:2!S86UO(&EZ('!R;WIO<F$@3W!C:6IE`%IA`%1U<G-K:2`H
M25-/+3@X-3DM.2D`4&]N:;ET:2!I>FUJ96YE`$YE:V%T96=O<FES86YO`%5N
M:6MO9"`H551&+3@I`%5J961I;FIE;FD@07)A<'-K:2!%;6ER871I`$YE<&]Z
M;F%T;R!K;W)I<VYIZ&MO(&EM92!I;&D@N6EF<F$N`$)E>FEM96YI`$MO<FES
M=&ET92!O=F\@86MO('-E(&EM92^Y:69R82!R87IL:6MU:G4@>F$@24U34"!S
M97)V97(N`$MO<FES;FEK("5S(&YE;6$@9&]Z=F]L=2!Z82`E<RX`2V]R:7-N
M:>AK92!O<&-I:F4`4F5G:7-T<F%C:6IA(&MO<FES;FEK80!+;W)I<VYIZ&MO
M(&EM90!0<FEK87H@)7,`57!O>F]R96YJ90!3961M:>AN;P!$;V)R;R!D;[EL
M:0!$;V)R;R!D;[EL:2!N82`E<P!$;V)R;R!D;[EL:2P@)7,`6F%P861N:2`H
M25-/+3@X-3DM,2D`6F%P861N:2`H25-/+3@X-3DM,34I`%IA<&%D;F$@4V%H
M87)A`$MO:G4@:V]M<&]N96YT=2#F92`E<R!P<FEK87IA=&D@;F%K;VX@=6QA
M>F$_`$MO:F4@9&]D871K92"^96QI=&4@86MT:79I<F%T:2!Z82!E9&ET;W(@
M9F]R;6%T:7)A;F]G("AR:6-H*2!T96MS=&$N`*EI<FEN82`E<R!M96YI:F$@
M<V$@;&EJ979E('-T<F%N:6-E("AS='5P82!N82!S;F%G=2!K;V0@<VQJ961E
MYF4@<')I:F%V92DZ`$=O9&FY;FIE`$1A`$YE(&UOOF4@<V%D<KYA=F%T:2`G
M7"<@:V%R86MT97(@=2!T=F]M('!U;F]M(&EM96YU+@!/9&IA=FQJ:79A;FIE
M(&IE('5S<&IEN6YO(&EZ=G*Y96YO+@`@)7,@<V5S:6IA(&IE(&ES=&5K;&$N
M($UO;&EM;R!D82!S92!P;VYO=F\@<')I:F%V:71E+@!68;EA(&4M;6%I;"!A
M9')E<V$`5F&Y82!&<F]M.B!A9')E<V$Z`%9AN64@:6YF;W)M86-I:F4`5F&Y
M82!);G1E<FYE="!A9')E<V$@:F4@<')O;6EJ96YJ96YA(&YA:V]N('!R:6IA
M=FQJ:79A;FIA(&YA("5S+B!$82!B:2!V8;EA('-I9W5R;F]S="!B:6QA('-A
MZ'5V86YA+"!M;W)A=&4@<V4@<&]N;W9O('!R:6IA=FET:2X`5F&Y92!I;64`
M5F&Y(&)R;W=S97(@;F4@<&]D<KYA=F$@;W9U(&UO9W7F;F]S="X`5')E;G5T
M;F$@=G)E;65N<VMA('IO;F$Z`%9AN2!D969A=6QT(&ED96YT:71E=#H`5F&Y
M92!I;64@:2!P<F5Z:6UE.@!68;EA(&YO=F$@N6EF<F$@>F$@)7,@:F4Z("5S
M`%9AN64@;W!C:6IE('-U('-AZ'5V86YE('1O:V]M('1R86IA;FIA(&]V92!S
M97-I:F4N`$]P8VEJ92!S=2!S8>AU=F%N92X`5F&Y82"Y:69R82!J92!P;VYI
MN71E;F$`5F&Y82"Y:69R82!J92!P;VYIN71E;F$L('!R;W9J97)I=&4@=F&Y
M(&4M;6%I;"!I('!R:6IA=FET92!S92!S82!N;W9O;2"Y:69R;VTN`%9AN6D@
M=61A;&IE;FD@<V5R=F5R:3H`2G5G;W-L879I:F$`6F%I<@!:86UB:6IA`%II
M;6)A8G9E`%II<'!Y`%M386MR:6H@8VET:7)A;FD@=&5K<W1=`%M0<FEJ879A
M('!R;V)L96UA70!;4')I:V&^:2!C:71I<F%N:2!T96MS="`M`%M0<FEK8;YI
M(&-I=&ER86YI('1E:W-T("T@)7,@<F5D;W9A70!;<F5D("5S(&]D("5S70!?
M061M:6YI<W1R86-I:F$`7T-,20!?1&%T851R964`7T]B<FFY:2!R960`7T=R
M=7!E`%]0;VUOY@!?3W-O8FEN92!S;&EK92XN+@!?4')I:F%V:2!S90!?27IL
M87H`7TEZ;6EJ96YI(&QI;FLN+BX`7T]P8VEJ90!?1&]Z=F]L90!?56ML;VYI
M(&QI;FLN+BX`7U!O9&5S:0!/<V]B:6YE(%]T86)E;&4N+BX`7TMO<FES;FEC
M:0!I;65N:6L`;&ES=&$@>F%D871A:V$`8F5Z(&EM96YA`'9#87)D`'=E871H
M97(N8V]M````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]D85]$2P``
M````````````````````````````````````````````````````````````
M```````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#`P,"`Q,#4Q-30S,S<T,"`P,3<V-3<`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&]C86QE+V1A7T1++TQ#7TU%4U-!1T53````````````````````````
M`````````````````````````````````````````````#`P,#<U-2``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S0P(#`R,30T-``@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O9&%?1$LO3$-?34534T%'15,O
M:&]R9&4N;6\`````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`T,#4P,#$@,3`U
M,34T,S,W-#`@,#(S,38Q`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````-X2!)4`````BP<``!P```!T/```$PH``,QX````````
M&*$```X````9H0``#P```"BA```-````.*$```@```!&H0``"P```$^A```,
M````6Z$```0```!HH0``&````&VA```;````AJ$``"T```"BH0``'0```-"A
M```D````[J$``"D````3H@``&0```#VB```F````5Z(```P```!^H@``)```
M`(NB```/````L*(```L```#`H@``#@```,RB```%````VZ(``"@```#AH@``
M"`````JC```*````$Z,``!4````>HP``$@```#2C```+````1Z,``(4```!3
MHP``#@```-FC```*````Z*,```T```#SHP``#@````&D```1````$*0```T`
M```BI```#````#"D```-````/:0```8```!+I```E````%*D```*````YZ0`
M``\```#RI```&`````*E```,````&Z4```X````HI0``#@```#>E```(````
M1J4```D```!/I0``+@```%FE```:````B*4``#(```"CI0``.````-:E``!4
M````#Z8``%$```!DI@``6@```+:F``!7````$:<``#0```!IIP``"0```)ZG
M```-````J*<```<```"VIP``"@```+ZG```/````R:<```4```#9IP``!@``
M`-^G```1````YJ<```@```#XIP``"0````&H```)````"Z@``"4````5J```
M(````#NH```3````7*@``!````!PJ```#P```(&H```*````D:@```,```"<
MJ```#P```*"H```4````L*@```D```#%J```#0```,^H```2````W:@``!D`
M``#PJ```'@````JI```/````*:D```H````YJ0``#P```$2I```(````5*D`
M`"0```!=J0``%````(*I```6````EZD```@```"NJ0``3@```+>I```M````
M!JH``!D````TJ@``!P```$ZJ```,````5JH``"P```!CJ@``#@```)"J```#
M````GZH```L```"CJ@``!P```*^J```'````MZH```4```"_J@``!0```,6J
M```*````RZH```,```#6J@``%P```-JJ```*````\JH```\```#]J@``#@``
M``VK```8````'*L``",````UJP``#@```%FK```4````:*L``!<```!]JP``
M%P```)6K```7````K:L``!,```#%JP``#P```-FK```.````Z:L``!\```#X
MJP``'0```!BL```'````-JP```8````^K```"````$6L```/````3JP```8`
M``!>K```"@```&6L```3````<*P```L```"$K```$````)"L```5````H:P`
M`!4```"WK```!P```,VL```0````U:P```4```#FK```%0```.RL```1````
M`JT```P````4K0``.P```"&M```X````7:T```D```"6K0``!P```*"M```4
M````J*T```,```"]K0``!0```,&M```0````QZT```D```#8K0``$P```.*M
M```Y````]JT``!(````PK@``)P```$.N```L````:ZX``"H```"8K@``)0``
M`,.N```*````Z:X```8```#TK@``"0```/NN```'````!:\``"\````-KP``
M-P```#VO```N````=:\``%4```"DKP``+0```/JO```M````*+```#T```!6
ML```/P```)2P```M````U+```$`````"L0``(P```$.Q```C````9[$``$``
M``"+L0``+0```,RQ```S````^K$``"4````NL@``%0```%2R```9````:K(`
M`"D```"$L@``)````*ZR```H````T[(``!$```#\L@``"@````ZS```,````
M&;,```H````FLP``$````#&S```6````0K,``!8```!9LP``!P```'"S```'
M````>+,``!0```"`LP``"@```)6S```(````H+,``"<```"ILP``"````-&S
M```'````VK,```<```#BLP``!@```.JS```%````\;,```<```#WLP``!@``
M`/^S```(````!K0``"D````/M```#@```#FT```*````2+0```0```!3M```
M!P```%BT```)````8+0```8```!JM```$0```'&T```'````@[0``!8```"+
MM```!````**T```(````I[0```8```"PM```#0```+>T```&````Q;0``!X`
M``#,M```$0```.NT```(````_;0```T````&M0``#````!2U```'````(;4`
M``,````IM0```P```"VU```7````,;4``!,```!)M0``'0```%VU```(````
M>[4```0```"$M0``"````(FU```(````DK4``$$```";M0``&@```-VU```K
M````^+4``"`````DM@``%0```$6V```&````6[8```8```!BM@``%0```&FV
M```8````?[8``"(```"8M@``+@```+NV```=````ZK8``"$````(MP``5```
M`"JW```I````?[<```H```"IMP``!P```+2W```'````O+<``!4```#$MP``
M#@```-JW```*````Z;<```\```#TMP``#0````2X```/````$K@```T````B
MN```"0```#"X```4````.K@```8```!/N```&````%:X```=````;[@``!,`
M``"-N```$0```*&X```4````L[@```0```#(N```!@```,VX```4````U+@`
M`%0```#IN```9````#ZY```$````H[D```X```"HN0``!0```+>Y```%````
MO;D``!L```##N0``&@```-^Y```3````^KD``!$````.N@``$0```""Z```<
M````,KH``"H```!/N@``$````'JZ```A````B[H```4```"MN@``$P```+.Z
M```+````Q[H``!(```#3N@``"@```.:Z```/````\;H```T````!NP``$0``
M``^[```3````(;L```P````UNP``!@```$*[```,````2;L```8```!6NP``
M%P```%V[```0````=;L``!$```"&NP``"````)B[```%````H;L```P```"G
MNP``$````+2[```%````Q;L```T```#+NP``!@```-F[```'````X+L```T`
M``#HNP``!P```/:[```+````_KL```<````*O```!P```!*\```)````&KP`
M``D````DO```"@```"Z\```9````.;P``#T```!3O```'0```)&\```,````
MK[P``!````"\O```!0```,V\```E````T[P``!(```#YO```$P````R]```K
M````(+T``#L```!,O0``(````(B]```(````J;T``#8```"RO0``(0```.F]
M```0````"[X```@````<O@``#````"6^```&````,KX```0````YO@``#P``
M`#Z^```.````3KX```<```!=O@``"@```&6^```-````<+X``!\```!^O@``
M'````)Z^```A````N[X``!X```#=O@``&0```/R^```>````%K\``!L````U
MOP``(0```%&_```N````<[\``"8```"BOP``'````,F_```>````YK\``!P`
M```%P```)@```"+````K````2<```#,```!UP```)@```*G````K````T,``
M`#@```#\P```'0```#7!```5````4\$``"\```!IP0``(````)G!```2````
MNL$``"D```#-P0``'@```/?!```@````%L(``!(````WP@``H@```$K"```6
M````[<(``",````$PP``*````"C#```I````4<,``"@```![PP``'P```*3#
M```5````Q,,``"````#:PP``)0```/O#```H````(<0``"T```!*Q```,```
M`'C$``"2````J<0``"$````\Q0``%@```%[%```<````=<4``"8```"2Q0``
M*@```+G%``!!````Y,4``$0````FQ@``#````&O&```'````>,8```<```"`
MQ@``!@```(C&```-````C\8``!````"=Q@``$@```*[&```3````P<8``!(`
M``#5Q@``!P```.C&```$````\,8``!````#UQ@``$`````;'```,````%\<`
M``X````DQP``#0```#/'```/````0<<``!,```!1QP``#0```&7'```H````
M<\<```,```"<QP``#0```*#'```&````KL<``!$```"UQP``%P```,?'```;
M````W\<```X```#[QP```@````K(``!)````#<@```4```!7R```$````%W(
M```/````;L@```0```!^R```#0```(/(```.````D<@```,```"@R```#@``
M`*3(```(````L\@```\```"\R```#P```,S(```'````W,@```T```#DR```
M$````/+(```-`````\D```L````1R0``!@```!W)```+````),D```P````P
MR0``"@```#W)```1````2,D``!D```!:R0``"P```'3)```-````@,D``"(`
M``".R0``#P```+')```;````P<D``#0```#=R0``"@```!+*```8````'<H`
M`!(````VR@``&0```$G*```6````8\H``"(```!ZR@``#0```)W*```'````
MJ\H``!0```"SR@``"P```,C*```B````U,H``"\```#WR@``"P```"?+```)
M````,\L``!D````]RP``"P```%?+```7````8\L``!<```![RP``"0```)/+
M```6````G<L```\```"TRP``&0```,3+```6````WLL```X```#URP``&```
M``3,```(````'<P```T````FS```)@```#3,``!#````6\P```@```"?S```
M$@```*C,```?````N\P```@```#;S```"P```.3,```O````\,P```X````@
MS0``!0```"_-```&````-<T``$4````\S0```P```(+-```'````ALT```0`
M``".S0``"@```)/-```*````GLT```\```"IS0``$````+G-```7````RLT`
M`!$```#BS0``&0```/3-```7````#LX```D````FS@``!0```##.```+````
M-LX```H```!"S@```@```$W.```%````4,X```T```!6S@``&P```&3.```7
M````@,X``!0```"8S@``"0```*W.```.````M\X```T```#&S@``$@```-3.
M```X````Y\X``"`````@SP``"````$'/```.````2L\``'L```!9SP``&```
M`-7/```8````[L\``!$````'T```!P```!G0```%````(=```!@````GT```
M'@```$#0```;````7]```!D```![T```&P```)70```9````L=```!,```#+
MT```!P```-_0```(````Y]````8```#PT```!@```/?0```0````_M````\`
M```/T0``$````!_1```/````,-$```L```!`T0``#P```$S1```,````7-$`
M``\```!IT0``!P```'G1```&````@=$```X```"(T0``#````)?1```H````
MI-$```\```#-T0``"````-W1```(````YM$``!,```#OT0``'@````/2```A
M````(M(``"````!$T@``&0```&72```7````?](``"4```"7T@``%P```+W2
M```6````U=(```0```#LT@``&P```/'2```-````#=,```P````;TP```P``
M`"C3```%````+-,```@````RTP``"@```#O3```,````1M,```L```!3TP``
M$````%_3```,````<-,```X```!]TP``"P```(S3```$````F-,```0```"=
MTP``$P```*+3```4````MM,```P```#+TP``"0```-C3```.````XM,```L`
M``#QTP``&P```/W3```'````&=0```<````AU```"@```"G4```-````--0`
M``D```!"U```!````$S4```%````4=0```,```!7U```&````%O4```*````
M=-0```0```!_U```)@```(34```.````J]0``'P```"ZU```%0```#?5```%
M````3=4```<```!3U0``#````%O5```(````:-4```H```!QU0``!@```'S5
M```(````@]4```(```",U0``!@```(_5```&````EM4``!0```"=U0``#0``
M`++5```0````P-4``!L```#1U0``!````.W5```)````\M4``!````#\U0``
M"0````W6```)````%]8```4````AU@``&@```"?6```(````0M8```8```!+
MU@``&0```%+6```.````;-8```<```![U@``!P```(/6```%````B]8```D`
M``"1U@``"@```)O6```.````IM8```(```"UU@``!@```+C6```+````O]8`
M``T```#+U@``"0```-G6```&````X]8``!(```#JU@``"0```/W6```'````
M!]<``!0````/UP``'0```"37``!"````0M<``"4```"%UP``)0```*O7```&
M````T=<```H```#8UP``!````./7```)````Z-<```@```#RUP``$0```/O7
M```)````#=@```8````7V```#0```![8```&````+-@```0````SV```.0``
M`#C8```]````<M@``#H```"PV```'@```.O8```%````"MD```X````0V0``
M!````!_9```&````)-D```<````KV0``(0```#/9```-````5=D``!4```!C
MV0``!@```'G9```$````@-D``!$```"%V0``!@```)?9```*````GMD``"(`
M``"IV0``!````,S9```%````T=D``!T```#7V0``!````/79```,````^MD`
M``X````'V@``"@```!;:```(````(=H```D````JV@``!0```#3:```Z````
M.MH``#````!UV@``-0```*;:```I````W-H``$<````&VP``.````$[;```I
M````A]L``#\```"QVP``+@```/';```M````(-P``!\```!.W```#P```&[<
M```2````?MP```L```"1W```)@```)W<```I````Q-P``"0```#NW```)@``
M`!/=```(````.MT```H```!#W0``"0```$[=```'````6-T``"````!@W0``
M(````('=```F````HMT```H```#)W0``&0```-3=```I````[MT``!8````8
MW@``$@```"_>```'````0MX```H```!*W@``#````%7>```/````8MX``!``
M``!RW@``0````(/>``!P````Q-X``&8````UWP``#@```)S?```)````J]\`
M``H```"UWP``$@```,#?```3````T]\```P```#GWP``!@```/3?```/````
M^]\``!(````+X```$````![@```1````+^```!P```!!X```(P```%[@``!J
M````@N````\```#MX```!0```/W@```0`````^$```D````4X0``!````![A
M```+````(^$``"`````OX0``%````%#A```,````9>$```P```!RX0``#P``
M`'_A```5````C^$``"D```"EX0``*@```,_A```F````^N$``"<````AX@``
M*0```$GB```J````<^(``!D```">X@``0@```+CB```1````^^(``!(````-
MXP``$P```"#C```4````-.,```\```!)XP``%@```%GC```7````<.,``!``
M``"(XP``$0```)GC```T````J^,``!,```#@XP``$@```/3C```U````!^0`
M`!0````]Y```!P```%+D```,````6N0``"````!GY```$````(CD```4````
MF>0``!$```"NY```%P```,#D```<````V.0``!,```#UY```%`````GE```:
M````'N4``!$````YY0``&@```$OE```>````9N4``!H```"%Y0``$P```*#E
M```5````M.4``!$```#*Y0``%P```-SE```4````].4``!<````)Y@``%0``
M`"'F```)````-^8``!````!!Y@``&0```%+F```$````;.8```<```!QY@``
M"P```'GF```1````A>8```8```"7Y@``!@```)[F```&````I>8```4```"L
MY@``!P```++F```'````NN8```4```#"Y@``%@```,CF```&````W^8```8`
M``#FY@``!````.WF```$````\N8```<```#WY@``#@```/_F```,````#N<`
M``P````;YP``#0```"CG```*````-N<```X```!!YP``!0```%#G```H````
M5N<```X```!_YP``#````([G```/````F^<```H```"KYP``"````+;G```)
M````O^<``"L```#)YP``!````/7G```(````^N<``"8````#Z```$@```"KH
M```/````/>@```8```!-Z```"@```%3H```'````7^@```@```!GZ```(```
M`'#H```)````D>@``!0```";Z```#````+#H```-````O>@```X```#+Z```
M%@```-KH```1````\>@```8````#Z0```P````KI```&````#ND``!D````5
MZ0``!P```"_I```$````-^D```L````\Z0``"P```$CI```'````5.D```4`
M``!<Z0``!P```&+I```6````:ND```T```"!Z0``#0```(_I```*````G>D`
M`!````"HZ0``#P```+GI```1````R>D``!<```#;Z0``"@```//I```1````
M_ND```@````0Z@``!````!GJ```/````'NH``#H````NZ@``!0```&GJ```,
M````;^H``!X```!\Z@``#@```)OJ```0````JNH```L```"[Z@``#````,?J
M```)````U.H```<```#>Z@``"@```.;J```)````\>H```X```#[Z@``$```
M``KK```;````&^L``!@````WZP``&@```%#K```*````:^L```D```!VZP``
M"@```(#K```,````B^L```\```"8ZP``"````*CK```&````L>L``!P```"X
MZP``!P```-7K```%````W>L```L```#CZP``1P```._K```-````-^P```D`
M``!%[```!````$_L```#````5.P``!,```!8[```$P```&SL```3````@.P`
M``H```"4[````@```)_L```$````HNP``"4```"G[````P```,WL```%````
MT>P``"H```#7[```"@````+M```%````#>T```0````3[0``"@```!CM```-
M````(^T```8````Q[0``"````#CM```(````0>T```0```!*[0``!0```$_M
M``!H````5>T```D```"^[0``#````,CM```0````U>T```4```#F[0``!@``
M`.SM```;````\^T``"\````/[@``$````#_N```*````4.X```\```!;[@``
M"@```&ON```)````=NX``!,```"`[@``&P```)3N```8````L.X``!<```#)
M[@``'P```.'N```.`````>\```,````0[P``!P```!3O```(````'.\```<`
M```E[P``"@```"WO```+````..\```<```!$[P``40```$SO```0````GN\`
M``P```"O[P``#0```+SO```:````RN\``$H```#E[P``&0```##P```&````
M2O```!H```!1\```)0```&SP```&````DO````8```"9\```'P```*#P```&
M````P/````D```#'\```&````-'P```7````ZO```"@````"\0``!@```"OQ
M```-````,O$``"(```!`\0``5P```&/Q```3````N_$``",```#/\0``$P``
M`//Q```"````!_(```L````*\@``"````!;R```-````'_(```H````M\@``
M!P```#CR```4````0/(```8```!5\@``"````%SR```.````9?(```<```!T
M\@``"@```'SR```+````A_(``#(```"3\@``!P```,;R```,````SO(```T`
M``#;\@``%P```.GR```,`````?,```D````.\P``"0```!CS```*````(O,`
M``<````M\P``"0```#7S```'````/_,```H```!'\P``&P```%+S```/````
M;O,``!(```!^\P``"@```)'S```6````G/,```D```"S\P``$````+WS```'
M````SO,``!(```#6\P``!````.GS```'````[O,```4```#V\P``!0```/SS
M```+`````O0``!0````.]```$0```"/T```:````-?0``!8```!0]```%```
M`&?T```7````?/0``!@```"4]```'````*WT```9````RO0```<```#D]```
M!0```.ST```-````\O0```P`````]0``"`````WU```7````%O4```L````N
M]0``#````#KU```?````1_4``!H```!G]0``$P```(+U```$````EO4```H`
M``";]0``!````*;U```-````J_4```P```"Y]0``!0```,;U```)````S/4`
M``4```#6]0``!P```-SU```%````Y/4```0```#J]0```@```._U```X````
M\O4``"P````K]@``$@```%CV```I````:_8``#(```"5]@``"@```,CV```L
M````T_8``"X`````]P``,P```"_W```S````8_<``#@```"7]P``#P```-#W
M```8````X/<``!````#Y]P``#P````KX```3````&O@``!4````N^```%```
M`$3X```2````6?@``!0```!L^```%0```('X```M````E_@``"T```#%^```
M,0```//X```N````)?D``"\```!4^0``+````(3Y``!B````L?D``!,````4
M^@``#0```"CZ```(````-OH``!<````_^@``"````%?Z```,````8/H``"L`
M``!M^@``(0```)GZ```:````N_H```D```#6^@``10```.#Z``!!````)OL`
M``0```!H^P``$P```&W[```4````@?L```X```"6^P``$P```*7[```8````
MN?L```8```#2^P``"0```-G[```*````X_L```\```#N^P``$````/[[```'
M````#_P```X````7_```!0```";\```;````+/P```@```!(_```!@```%'\
M```4````6/P``!$```!M_```#@```'_\```X````COP```(```#'_```!@``
M`,K\```.````T?P```4```#@_```!P```.;\```.````[OP```8```#]_```
M*`````3]```,````+?T``!P````Z_0``!````%?]```I````7/T``!<```"&
M_0``'P```)[]``!<````OOT``!0````;_@``/@```##^```?````;_X``!``
M``"/_@``!P```*#^```.````J/X```P```"W_@``#````,3^```3````T?X`
M``H```#E_@``'0```/#^```9````#O\```4````H_P``$0```"[_```1````
M0/\``"0```!2_P``$@```'?_```5````BO\``!(```"@_P``#@```+/_```9
M````PO\```@```#<_P``"0```.7_```-````[_\```<```#]_P``"@````4`
M`0`'````$``!``\````8``$`!@```"@``0`+````+P`!`!H````[``$`"@``
M`%8``0`'````80`!``@```!I``$`!0```'(``0`?````>``!``8```"8``$`
M$````)\``0`(````L``!``T```"Y``$`"````,<``0`>````T``!`!(```#O
M``$`+`````(!`0`:````+P$!``D```!*`0$`"@```%0!`0`5````7P$!``4`
M``!U`0$`%````'L!`0`$````D`$!`!````"5`0$`!@```*8!`0`'````K0$!
M`!X```"U`0$`*````-0!`0`*````_0$!`!P````(`@$`$0```"4"`0`+````
M-P(!`!H```!#`@$`%````%X"`0`$````<P(!``0```!X`@$`"P```'T"`0`%
M````B0(!``8```"/`@$`"````)8"`0`&````GP(!``H```"F`@$`&P```+$"
M`0`T````S0(!`#0````"`P$`(````#<#`0`I````6`,!`"````""`P$`00``
M`*,#`0`:````Y0,!`"@`````!`$`*0```"D$`0!0````4P0!`"(```"D!`$`
M!@```,<$`0`(````S@0!``4```#7!`$`"````-T$`0`9````Y@0!`!D`````
M!0$`*@```!H%`0`C````104!`!D```!I!0$`+@```(,%`0`T````L@4!``@`
M``#G!0$`%P```/`%`0`*````"`8!``<````3!@$`(0```!L&`0`0````/08!
M``X```!.!@$`"P```%T&`0`'````:08!`!,```!Q!@$`"````(4&`0`+````
MC@8!``H```":!@$`%````*4&`0`/````N@8!`#(```#*!@$`"P```/T&`0`.
M````"0<!``4````8!P$`!0```!X'`0`%````)`<!`!<````J!P$`#P```$('
M`0`$````4@<!``H```!7!P$`"0```&('`0`+````;`<!``T```!X!P$`#```
M`(8'`0`.````DP<!``4```"B!P$`!````*@'`0`-````K0<!`#(```"[!P$`
M10```.X'`0`7````-`@!``<```!,"`$`'@```%0(`0`4````<P@!``4```"(
M"`$`%````(X(`0`&````HP@!``<```"J"`$`#@```+((`0`J````P0@!``8`
M``#L"`$`#````/,(`0`-``````D!`!$````."0$`"P```"`)`0`V````+`D!
M``H```!C"0$`(@```&X)`0`+````D0D!``\```"="0$`,@```*T)`0`E````
MX`D!`#`````&"@$`,0```#<*`0`M````:0H!``X```"7"@$`!0```*8*`0`.
M````K`H!`!,```"["@$`$@```,\*`0`'````X@H!`!$```#J"@$`$P```/P*
M`0`'````$`L!`!0````8"P$`&````"T+`0`'````1@L!``4```!."P$`#```
M`%0+`0`,````80L!`!(```!N"P$`!````($+`0`'````A@L!``H```"."P$`
M"P```)D+`0`,````I0L!``X```"R"P$`#@```,$+`0`%````T`L!``4```#6
M"P$`+@```-P+`0`F````"PP!`",````R#`$``P```%8,`0`2````6@P!``8`
M``!M#`$`'@```'0,`0`8````DPP!`"4```"L#`$`#0```-(,`0`)````X`P!
M`!\```#J#`$``P````H-`0`'````#@T!``H````6#0$``@```"$-`0`,````
M)`T!`!4````Q#0$`"P```$<-`0`9````4PT!`"````!M#0$`$@```(X-`0`%
M````H0T!``H```"G#0$`%0```+(-`0`2````R`T!``P```#;#0$`!````.@-
M`0`)````[0T!``<```#W#0$`#````/\-`0!2````#`X!`!<```!?#@$`)```
M`'<.`0`2````G`X!``<```"O#@$`!@```+<.`0`.````O@X!``P```#-#@$`
M#0```-H.`0`5````Z`X!`!(```#^#@$`#P```!$/`0`4````(0\!``H````V
M#P$`&P```$$/`0`0````70\!``L```!N#P$`:0```'H/`0`:````Y`\!`!<`
M``#_#P$`)P```!<0`0`:````/Q`!`!<```!:$`$`&P```'(0`0`9````CA`!
M`!\```"H$`$`$P```,@0`0`(````W!`!``<```#E$`$`"````.T0`0`)````
M]A`!`!4`````$0$`#0```!81`0`C````)!$!``T```!($0$`$P```%81`0`(
M````:A$!``,```!S$0$`1@```'<1`0`_````OA$!`#<```#^$0$`5P```#82
M`0`%````CA(!`!\```"4$@$`+P```+02`0`*````Y!(!``@```#O$@$`#0``
M`/@2`0`M````!A,!``0````T$P$`3P```#D3`0`E````B1,!`!P```"O$P$`
M"P```,P3`0`?````V!,!`!T```#X$P$`)0```!84`0`@````/!0!`"0```!=
M%`$`(````((4`0`+````HQ0!``<```"O%`$`#0```+<4`0`,````Q10!`!<`
M``#2%`$`!@```.H4`0`Y````\10!``P````K%0$`!P```#@5`0`)````0!4!
M`!,```!*%0$`"0```%X5`0`$````:!4!`!````!M%0$`"````'X5`0`(````
MAQ4!``0```"0%0$`"P```)45`0`,````H14!`!(```"N%0$`$0```,$5`0`,
M````TQ4!`!H```#@%0$`#P```/L5`0`'````"Q8!``T````3%@$`%````"$6
M`0`.````-A8!``P```!%%@$`&P```%(6`0`L````;A8!`!,```";%@$`'```
M`*\6`0`H````S!8!``8```#U%@$`!P```/P6`0`3````!!<!``4````8%P$`
M!````!X7`0`7````(Q<!``H````[%P$`#````$87`0`)````4Q<!``8```!=
M%P$`"0```&07`0`(````;A<!``D```!W%P$`"@```($7`0`1````C!<!``8`
M``">%P$`#@```*47`0`.````M!<!``T```##%P$`"P```-$7`0`=````W1<!
M``L```#[%P$``@````<8`0`<````"A@!``<````G&`$`!@```"\8`0!D````
M-A@!``D```";&`$`!P```*48`0`F````K1@!`#@```#4&`$`&@````T9`0`J
M````*!D!`#L```!3&0$`*````(\9`0`T````N!D!`!D```#M&0$`%0````<:
M`0`%````'1H!``<````C&@$`"````"L:`0`'````-!H!``4````\&@$`!P``
M`$(:`0`.````2AH!``D```!9&@$`!@```&,:`0`(````:AH!``L```!S&@$`
M!P```'\:`0`(````AQH!``<```"0&@$`%@```)@:`0`)````KQH!``8```"Y
M&@$`"P```,`:`0`0````S!H!``8```#=&@$`'````.0:`0`4`````1L!``<`
M```6&P$`$0```!X;`0`(````,!L!``X````Y&P$`"````$@;`0`%````41L!
M`!````!7&P$`"0```&@;`0`0````<AL!``8```"#&P$`&0```(H;`0`*````
MI!L!`!P```"O&P$`!P```,P;`0`%````U!L!`!````#:&P$`%````.L;`0`+
M`````!P!``T````,'`$`*````!H<`0`8````0QP!`!<```!<'`$`!````'0<
M`0`)````>1P!``H```"#'`$`!P```(X<`0`"````EAP!``X```"9'`$`"```
M`*@<`0`C````L1P!`!\```#5'`$`.````/4<`0`F````+AT!`#$```!5'0$`
M)P```(<=`0!D````KQT!`!0````4'@$`50```"D>`0`X````?QX!`$H```"X
M'@$`6P````,?`0`H````7Q\!`#@```"('P$`*````,$?`0`L````ZA\!`"8`
M```7(`$`&P```#X@`0`^````6B`!`*D!``"9(`$`(P```$,B`0`7````9R(!
M`$@```!_(@$`A0```,@B`0`P````3B,!`"4```!_(P$`00```*4C`0!;````
MYR,!`$D```!#)`$`,0```(TD`0`=````OR0!`!@```#=)`$`*P```/8D`0`A
M````(B4!`!\```!$)0$`*P```&0E`0`F````D"4!`"$```"W)0$`)P```-DE
M`0`Z`````28!`!T````\)@$`$0```%HF`0`S````;"8!`"4```"@)@$`)P``
M`,8F`0`@````[B8!`!\````/)P$`,````"\G`0!I````8"<!`#$```#*)P$`
M00```/PG`0`S````/B@!`"4```!R*`$`/0```)@H`0!E````UB@!`$T````\
M*0$`+P```(HI`0`N````NBD!`#````#I*0$`5````!HJ`0!:````;RH!`$@`
M``#**@$`2@```!,K`0`R````7BL!`"\```"1*P$`+````,$K`0`M````[BL!
M`'$````<+`$`9@```(XL`0!O````]2P!`+,```!E+0$`%P```!DN`0`E````
M,2X!`#(```!7+@$`*0```(HN`0`^````M"X!`"(```#S+@$`4@```!8O`0`E
M````:2\!``L```"/+P$`L0```)LO`0!%````33`!`"$```"3,`$`,````+4P
M`0`E````YC`!`!P````,,0$`,0```"DQ`0`'````6S$!``<```!C,0$`!```
M`&LQ`0`-````<#$!``L```!^,0$`#@```(HQ`0`+````F3$!``4```"E,0$`
M$````*LQ`0`"````O#$!`%D```"_,0$`!0```!DR`0`2````'S(!``0````R
M,@$`!P```#<R`0`(````/S(!``4```!(,@$`,````$XR`0`#````?S(!`!``
M``"#,@$`#````)0R`0`3````H3(!``T```"U,@$``@```,,R`0`'````QC(!
M``8```#.,@$`%````-4R`0`,````ZC(!`!@```#W,@$`!@```!`S`0`2````
M%S,!``P````J,P$``P```#<S`0`J````.S,!``0```!F,P$`!@```&LS`0`'
M````<C,!`!\```!Z,P$`-0```)HS`0`N````T#,!`"\```#_,P$`%P```"\T
M`0`B````1S0!`"4```!J-`$`(````)`T`0`;````L30!`!@```#--`$`)```
M`.8T`0`?````"S4!`!H````K-0$`(0```$8U`0`@````:#4!`!H```")-0$`
M,@```*0U`0`:````US4!`"\```#R-0$`*P```"(V`0`?````3C8!`",```!N
M-@$`'P```)(V`0`:````LC8!`"$```#--@$`)0```.\V`0`F````%3<!`"4`
M```\-P$`)````&(W`0`8````AS<!`!T```"@-P$`)````+XW`0`8````XS<!
M`"(```#\-P$`+````!\X`0`O````3#@!`!4```!\.`$`)0```)(X`0`\````
MN#@!`!\```#U.`$`(P```!4Y`0`?````.3D!`"````!9.0$`&@```'HY`0`8
M````E3D!`"8```"N.0$`'@```-4Y`0`I````]#D!`!X````>.@$`,0```#TZ
M`0`)````;SH!``P```!Y.@$`%P```(8Z`0`O````GCH!`"0```#..@$`!P``
M`/,Z`0`/````^SH!`!0````+.P$`#@```"`[`0`-````+SL!`"0````].P$`
M!0```&([`0`'````:#L!`"(```!P.P$`)0```),[`0`:````N3L!`!T```#4
M.P$`&@```/([`0`'````#3P!`,<````5/`$`"P```-T\`0`5````Z3P!``8`
M``#_/`$`"0````8]`0`+````$#T!``T````</0$`%P```"H]`0`&````0CT!
M`#,```!)/0$`$P```'T]`0`3````D3T!``<```"E/0$`#P```*T]`0`'````
MO3T!`#(```#%/0$`!````/@]`0`A````_3T!`!,````?/@$`#````#,^`0`1
M````0#X!`#(```!2/@$`%@```(4^`0`(````G#X!`!T```"E/@$`"0```,,^
M`0`*````S3X!`!0```#8/@$`"@```.T^`0`=````^#X!``@````6/P$`'P``
M`!\_`0`(````/S\!`!H```!(/P$`)P```&,_`0`&````BS\!`!4```"2/P$`
M!P```*@_`0`(````L#\!``D```"Y/P$`/P```,,_`0`'`````T`!``\````+
M0`$`#@```!M``0`0````*D`!``D````[0`$`"0```$5``0`(````3T`!`!,`
M``!80`$`!P```&Q``0`9````=$`!``H```".0`$`%P```)E``0`4````L4`!
M``H```#&0`$`#````-%``0`7````WD`!``0```#V0`$`*@```/M``0`,````
M)D$!`!$````S00$`!P```$5!`0`"````34$!`!````!000$`&````&%!`0`+
M````>D$!``,```"&00$`"````(I!`0`&````DT$!``<```":00$`#0```*)!
M`0`+````L$$!`!0```"\00$`%0```-%!`0`.````YT$!`"\```#V00$`(```
M`"9"`0`<````1T(!`!4```!D0@$`#````'I"`0`Q````AT(!``4```"Y0@$`
M$@```+]"`0`_````TD(!`!(````20P$`"@```"5#`0`&````,$,!``0````W
M0P$`!````#Q#`0`*````04,!`!,```!,0P$`!0```&!#`0`&````9D,!``8`
M``!M0P$`"````'1#`0`$````?4,!``P```""0P$`"@```(]#`0`Y````FD,!
M`"X```#40P$`*0````-$`0`%````+40!`!@````S1`$`&0```$Q$`0`?````
M9D0!`!T```"&1`$`$0```*1$`0`"````MD0!``0```"Y1`$`"@```+Y$`0`&
M````R40!``4```#01`$``P```-9$`0`,````VD0!`$4```#G1`$`,@```"U%
M`0`:````8$4!`#0```![10$`*````+!%`0!3````V44!`!D````M1@$`<@``
M`$=&`0`@````ND8!`#4```#;1@$`(0```!%'`0!%````,T<!`#````!Y1P$`
M*````*I'`0`I````TT<!`"8```#]1P$`)0```"1(`0`H````2D@!`"@```!S
M2`$`(@```)Q(`0`K````OT@!`#````#K2`$`$@```!Q)`0`3````+TD!`!``
M``!#20$`>0```%1)`0`)````SDD!`*$```#820$`<P```'I*`0!\````[DH!
M`"L```!K2P$`5````)=+`0`7````[$L!`"<````$3`$`%@```"Q,`0`/````
M0TP!`!<```!33`$`'P```&M,`0!`````BTP!`!\```#,3`$`'````.Q,`0!1
M````"4T!`!H```!;30$`%````'9-`0`*````BTT!``4```"630$`!@```)Q-
M`0`(````HTT!``4```"L30$`$@```+)-`0`0````Q4T!`!,```#630$`'0``
M`.I-`0`/````"$X!``\````83@$`!````"A.`0`)````+4X!``L````W3@$`
M!P```$-.`0`%````2TX!`!0```!13@$`!P```&9.`0`(````;DX!``\```!W
M3@$`"````(=.`0`,````D$X!``\```"=3@$`!@```*U.`0`4````M$X!``8`
M``#)3@$`#````-!.`0`1````W4X!``@```#O3@$`!````/A.`0`9````_4X!
M`!$````73P$`"@```"E/`0`8````-$\!`!,```!-3P$`'````&%/`0`1````
M?D\!``0```"03P$`#P```)5/`0`'````I4\!``0```"M3P$`&0```+)/`0`'
M````S$\!``(```#43P$``@```-=/`0`1````VD\!``D```#L3P$`!@```/9/
M`0`2````_4\!`!<````04`$`!@```"A0`0`G````+U`!``(```!74`$`!```
M`%I0`0`/````7U`!`!,```!O4`$`!P```(-0`0`'````BU`!`!$```"34`$`
M!@```*50`0`8````K%`!``8```#%4`$`$P```,Q0`0`0````X%`!`!(```#Q
M4`$``@````11`0`&````!U$!``P````.40$`"0```!M1`0`1````)5$!`"(`
M```W40$`!P```%I1`0`'````8E$!``L```!J40$`!0```'91`0`"````?%$!
M``L```!_40$`E`$``(M1`0`0````(%,!``\````Q4P$`#0```$%3`0`(````
M3U,!``L```!84P$`"````&13`0`%````;5,!`!@```!S4P$`&P```(Q3`0`O
M````J%,!`!X```#84P$`)0```/=3`0`H````'50!`!H```!&5`$`*@```&%4
M`0`+````C%0!`"````"85`$`#@```+E4`0`+````R%0!``\```#45`$`!0``
M`.14`0`@````ZE0!``P````+50$`#@```!A5`0`3````)U4!`!<````[50$`
M#````%-5`0"*````8%4!``D```#K50$`"P```/55`0`/`````58!``\````1
M5@$`$P```"%6`0`,````-58!``T```!"5@$`"P```%!6`0`&````7%8!`*H`
M``!C5@$`"`````Y7`0`0````%U<!`!H````H5P$`"@```$-7`0`0````3E<!
M`!````!?5P$`"````'!7`0`/````>5<!`"T```")5P$`(0```+=7`0`[````
MV5<!`$8````56`$`6P```%Q8`0!9````N%@!`&(````260$`7@```'59`0`^
M````U%D!``\````36@$`$@```"-:`0`.````-EH!``\```!%6@$`$@```%5:
M`0`%````:%H!``8```!N6@$`$0```'5:`0`%````AUH!``D```"-6@$`"0``
M`)=:`0`J````H5H!`"8```#,6@$`$0```/-:`0`0````!5L!`!(````66P$`
M"@```"E;`0`&````-%L!`!(````[6P$`'@```$Y;`0`+````;5L!`!````!Y
M6P$`$P```(I;`0`;````GEL!`"$```"Z6P$`%0```-Q;`0`.````\EL!`!0`
M```!7`$`"0```!9<`0`G````(%P!`!L```!(7`$`'@```&1<`0`,````@UP!
M`%H```"07`$`,````.M<`0`B````'%T!``<````_70$`#P```$==`0`S````
M5UT!``X```"+70$`"````)I=`0`+````HUT!``@```"O70$`"````+A=`0`)
M````P5T!``H```#+70$`"@```-9=`0`$````X5T!`!,```#F70$`#````/I=
M`0`0````!UX!``\````87@$`&````"A>`0`E````05X!`!,```!G7@$`%0``
M`'M>`0`7````D5X!`!H```"I7@$`$@```,1>`0`6````UUX!`!$```#N7@$`
M$`````!?`0`M````$5\!`!X````_7P$`!P```%Y?`0`&````9E\!``@```!M
M7P$`%````'9?`0`&````BU\!``@```"27P$`$P```)M?`0`+````KU\!`!$`
M``"[7P$`%0```,U?`0`3````XU\!``<```#W7P$`#@```/]?`0`%````#F`!
M`!8````48`$`$@```"M@`0`)````/F`!`$(```!(8`$`0````(M@`0`)````
MS&`!``@```#68`$`$P```-]@`0`%````\V`!``4```#Y8`$`#````/]@`0`)
M````#&$!`!D````680$`1````#!A`0`/````=6$!`#````"%80$`-````+9A
M`0`S````ZV$!`"\````?8@$`"P```$]B`0`&````6V(!``H```!B8@$`!@``
M`&UB`0`P````=&(!`#$```"E8@$`+P```-=B`0!1````!V,!`"X```!98P$`
M+@```(AC`0!'````MV,!`$@```#_8P$`+@```$AD`0`Y````=V0!`"0```"Q
M9`$`)@```-9D`0!+````_60!`"X```!)90$`-````'AE`0`@````K64!``\`
M``#.90$`$P```-YE`0`@````\F4!`",````39@$`(P```#=F`0`4````6V8!
M``L```!P9@$`$P```'QF`0`*````D&8!``X```";9@$`&0```*IF`0`<````
MQ&8!``8```#A9@$`!P```.AF`0`6````\&8!``H````'9P$`"````!)G`0`E
M````&V<!``H```!!9P$`#````$QG`0`'````66<!``8```!A9P$`!0```&AG
M`0`'````;F<!``8```!V9P$`"@```'UG`0`J````B&<!``\```"S9P$`"```
M`,-G`0`#````S&<!``@```#09P$`"0```-EG`0`$````XV<!``X```#H9P$`
M!0```/=G`0`6````_6<!``4````4:`$`"````!IH`0`$````(V@!``D````H
M:`$`"0```#)H`0`:````/&@!`!$```!7:`$`"0```&EH`0`*````<V@!``P`
M``!^:`$`!P```(MH`0`#````DV@!``,```"7:`$`%P```)MH`0`3````LV@!
M`#8```#':`$`"````/YH`0`*````!VD!``@````2:0$`"````!MI`0!!````
M)&D!`!P```!F:0$`*P```(-I`0`E````KVD!`!<```#5:0$`!@```.UI`0`(
M````]&D!`!T```#]:0$`&0```!MJ`0`G````-6H!`#````!=:@$`'0```(YJ
M`0`D````K&H!`&4```#1:@$`+````#=K`0`)````9&L!``L```!N:P$`!P``
M`'IK`0`4````@FL!``L```"7:P$`!0```*-K`0`0````J6L!``T```"Z:P$`
M$````,AK`0`0````V6L!``P```#J:P$`%0```/=K`0`'````#6P!`!X````5
M;`$`'@```#1L`0`3````4VP!``\```!G;`$`%0```'=L`0`%````C6P!``4`
M``"3;`$`$0```)EL`0!?````JVP!`%P````+;0$`!````&AM`0`.````;6T!
M``4```!\;0$`!````()M`0`?````AVT!`!P```"G;0$`$0```,1M`0`/````
MUFT!`!(```#F;0$`'P```/EM`0`D````&6X!``<````^;@$`(P```$9N`0`%
M````:FX!`!L```!P;@$`%````(QN`0`2````H6X!``X```"T;@$`$@```,-N
M`0`-````UFX!`!4```#D;@$`$P```/IN`0`*````#F\!``4````9;P$`#0``
M`!]O`0`%````+6\!`!4````S;P$`%0```$EO`0`3````7V\!``D```!S;P$`
M!0```'UO`0`+````@V\!``D```"/;P$`!0```)EO`0`-````GV\!``L```"M
M;P$`"````+EO`0`-````PF\!``D```#0;P$`"P```-IO`0`)````YF\!``4`
M``#P;P$`"0```/9O`0`'`````'`!``L````(<`$`%P```!1P`0!#````+'`!
M`!P```!P<`$`#0```(UP`0`/````FW`!``4```"K<`$`(````+%P`0`8````
MTG`!`!D```#K<`$`+0````5Q`0`\````,W$!`"<```!P<0$`"0```)AQ`0`Q
M````HG$!`"$```#4<0$`#P```/9Q`0`'````!G(!``P````.<@$`!P```!MR
M`0`&````(W(!`!D````J<@$`$````$1R`0`(````57(!``H```!><@$`#P``
M`&ER`0`@````>7(!`!\```":<@$`(@```+IR`0`A````W7(!`!X```#_<@$`
M(0```!YS`0`A````0',!`"0```!B<P$`-P```(=S`0`I````OW,!`"````#I
M<P$`(@````IT`0`=````+70!`"@```!+=`$`1````'1T`0`O````N70!`"8`
M``#I=`$`*0```!!U`0!"````.G4!`!\```!]=0$`%@```)UU`0`Q````M'4!
M`",```#F=0$`$P````IV`0`L````'G8!`!T```!+=@$`'````&EV`0`3````
MAG8!`+,```":=@$`%````$YW`0`F````8W<!`"<```"*=P$`*````+)W`0`>
M````VW<!`"(```#Z=P$`%@```!UX`0`A````-'@!`"D```!6>`$`+````(!X
M`0`_````K7@!`"\```#M>`$`G@```!UY`0`>````O'D!`"````#;>0$`'P``
M`/QY`0`J````''H!`"P```!'>@$`10```'1Z`0!$````NGH!``P```#_>@$`
M!`````Q[`0`&````$7L!``4````8>P$`$P```!Y[`0`+````,GL!`!`````^
M>P$`$P```$][`0`1````8WL!``@```!U>P$`!````'Y[`0`1````@WL!`!,`
M``"5>P$`"@```*E[`0`0````M'L!`!$```#%>P$`#````-=[`0`0````Y'L!
M``L```#U>P$`.@````%\`0`$````/'P!``D```!!?`$`!@```$M\`0`2````
M4GP!`!@```!E?`$`&P```'Y\`0`(````FGP!``(```"C?`$`20```*9\`0`&
M````\'P!`!(```#W?`$`#P````I]`0`$````&GT!``\````??0$`"````"]]
M`0`#````.'T!``P````\?0$`"````$E]`0`*````4GT!`!$```!=?0$`"```
M`&]]`0`-````>'T!`!(```"&?0$`#0```)E]`0`,````IWT!``0```"T?0$`
M"@```+E]`0`+````Q'T!``L```#0?0$`$````-Q]`0`8````[7T!``H````&
M?@$`#````!%^`0`G````'GX!``T```!&?@$`&0```%1^`0`[````;GX!``H`
M``"J?@$`%0```+5^`0`0````RWX!`!D```#<?@$`%P```/9^`0`@````#G\!
M`!(````O?P$`!P```$)_`0`1````2G\!``L```!<?P$`(0```&A_`0`_````
MBG\!``D```#*?P$`"````-1_`0`:````W7\!``H```#X?P$`&0````.``0`9
M````'8`!``<````W@`$`%0```#^``0`9````58`!`!@```!O@`$`%````(B`
M`0`.````G8`!`!,```"L@`$`"````,"``0`0````R8`!`"@```#:@`$`0@``
M``.!`0`9````1H$!`!D```!@@0$`)@```'J!`0`$````H8$!``<```"F@0$`
M,````*Z!`0`1````WX$!``P```#Q@0$`!@```/Z!`0!(````!8(!``,```!.
M@@$`!P```%*"`0`'````6H(!``H```!B@@$`#````&V"`0`0````>H(!`!$`
M``"+@@$`&````)V"`0`/````MH(!`!H```#&@@$`&````.&"`0`*````^H(!
M``<````%@P$`"P````V#`0`*````&8,!``(````D@P$`!0```">#`0`.````
M+8,!`!L````\@P$`%@```%B#`0`4````;X,!``<```"$@P$`"P```(R#`0`/
M````F(,!``L```"H@P$`.@```+2#`0`@````[X,!``<````0A`$`&0```!B$
M`0"#````,H0!`!H```"VA`$`&P```-&$`0`1````[80!``<```#_A`$`!```
M``>%`0`=````#(4!`"4````JA0$`(P```%"%`0`B````=(4!`"0```"7A0$`
M(0```+R%`0`=````WH4!``<```#\A0$`"`````2&`0`&````#88!``8````4
MA@$`#````!N&`0`.````*(8!`!`````WA@$`#0```$B&`0`/````5H8!``\`
M``!FA@$`"@```':&`0`0````@88!``4```"2A@$`!0```)B&`0`1````GH8!
M``X```"PA@$`*@```+^&`0`/````ZH8!``D```#ZA@$`"`````2'`0`8````
M#8<!`"$````FAP$`+````$B'`0`C````=8<!`!X```"9AP$`'````+B'`0`H
M````U8<!`!L```#^AP$`%````!J(`0`%````+X@!`!D````UB`$`"````$^(
M`0`-````6(@!``,```!FB`$`"@```&J(`0`'````=8@!``4```!]B`$`!P``
M`(.(`0`(````BX@!``L```"4B`$`"P```*"(`0`.````K(@!`!<```"[B`$`
M!````-.(`0`#````V(@!`!,```#<B`$`%0```/"(`0`-````!HD!``<````4
MB0$`!P```!R)`0`*````)(D!`!T````OB0$`!@```$V)`0`'````5(D!``X`
M``!<B0$`#@```&N)`0`8````>HD!``0```"3B0$`"````)B)`0`$````H8D!
M`!@```"FB0$`#@```+^)`0`#````SHD!`#$```#2B0$`$`````2*`0"`````
M%8H!`!(```"6B@$`"@```*F*`0`(````M(H!``L```"]B@$`"@```,F*`0`,
M````U(H!``0```#AB@$`#@```.:*`0`#````]8H!``8```#YB@$`"`````"+
M`0`6````"8L!``T````@BP$`$0```"Z+`0`;````0(L!``,```!<BP$``P``
M`&"+`0`0````9(L!``@```!UBP$`"@```'Z+`0`%````B8L!`"8```"/BP$`
M"````+:+`0`&````OXL!`!@```#&BP$`#@```-^+`0`(````[HL!``@```#W
MBP$`!0````",`0`)````!HP!``<````0C`$`&P```!B,`0`%````-(P!``4`
M```ZC`$`"P```$",`0`.````3(P!``@```!;C`$`"@```&2,`0`2````;XP!
M``@```""C`$`!P```(N,`0`5````DXP!`!X```"IC`$`.0```,B,`0`E````
M`HT!`"<````HC0$`!P```%"-`0`*````6(T!``0```!CC0$`"0```&B-`0`(
M````<HT!`!````![C0$`"````(R-`0`&````E8T!``T```"<C0$`!@```*J-
M`0`$````L8T!`#X```"VC0$`0````/6-`0`^````-HX!`!D```!UC@$`!0``
M`(^.`0`.````E8X!``,```"DC@$`"````*B.`0`,````L8X!`"$```"^C@$`
M#@```.".`0`7````[XX!``4````'CP$`!0````V/`0`<````$X\!``<````P
MCP$`"0```#B/`0`8````0H\!``,```!;CP$`!````%^/`0`8````9(\!``0`
M``!]CP$`#@```(*/`0`-````D8\!``X```"?CP$`"````*Z/`0`)````MX\!
M``4```#!CP$`-@```,>/`0`N````_H\!`#<````MD`$`'0```&60`0!`````
M@Y`!`#4```#$D`$`*````/J0`0`[````(Y$!`"X```!?D0$`+P```(Z1`0`?
M````OI$!``T```#>D0$`"P```.R1`0`(````^)$!`#<````!D@$`+0```#F2
M`0`D````9Y(!`"L```",D@$`"0```+B2`0`+````PI(!``H```#.D@$`!@``
M`-F2`0`D````X)(!`"(````%DP$`+@```"B3`0`*````5Y,!`!T```!BDP$`
M(P```("3`0`6````I),!`!````"[DP$`!@```,R3`0`*````TY,!``T```#>
MDP$`$````.R3`0`/````_9,!`#\````-E`$`?0```$V4`0!N````RY0!`!<`
M```ZE0$`"@```%*5`0`+````794!`!,```!IE0$`%````'V5`0`0````DI4!
M``@```"CE0$`%````*R5`0`6````P94!`!,```#8E0$`$@```.R5`0`@````
M_Y4!`"4````@E@$`?P```$:6`0`0````QI8!``8```#7E@$`%````-Z6`0`*
M````\Y8!``0```#^E@$`"P````.7`0`D````#Y<!`!0````TEP$`#@```$F7
M`0`,````6)<!`!4```!EEP$`$@```'N7`0`G````CI<!`"4```"VEP$`)0``
M`-R7`0`C`````I@!`"L````FF`$`*0```%*8`0`:````?)@!`$(```"7F`$`
M$@```-J8`0`0````[9@!`!0```#^F`$`$@```!.9`0`/````)ID!`!4````V
MF0$`%0```$R9`0`2````8ID!`!````!UF0$`,P```(:9`0`4````NID!`!<`
M``#/F0$`.P```.>9`0`7````(YH!``8````[F@$`#````$*:`0`@````3YH!
M`!$```!PF@$`%0```(*:`0`3````F)H!`!8```"LF@$`%````,.:`0`2````
MV)H!`!0```#KF@$`&@````";`0`1````&YL!`!T````MFP$`(P```$N;`0`>
M````;YL!`!,```".FP$`%0```**;`0`1````N)L!`!8```#*FP$`%@```.&;
M`0`;````^)L!`!4````4G`$`!0```"J<`0`2````,)P!`!L```!#G`$`!```
M`%^<`0`&````9)P!``,```!KG`$`#@```&^<`0`&````?IP!``@```"%G`$`
M"0```(Z<`0`'````F)P!``<```"@G`$`!@```*B<`0`%````KYP!`!4```"U
MG`$`!@```,N<`0`&````TIP!``0```#9G`$`!````-Z<`0`&````XYP!``<`
M``#JG`$`#0```/*<`0`/`````)T!``T````0G0$`"@```!Z=`0`/````*9T!
M``4````YG0$`,0```#^=`0`6````<9T!``X```"(G0$`$@```)>=`0`+````
MJIT!``D```"VG0$`#P```,"=`0`X````T)T!``0````)G@$`"`````Z>`0`(
M````%YX!``D````@G@$`$0```"J>`0`&````/)X!``L```!#G@$`"@```$^>
M`0`%````6IX!``0```!@G@$`#@```&6>`0`6````=)X!``X```"+G@$`$```
M`)J>`0`0````JYX!`!P```"\G@$`%````-F>`0`'````[IX!``,```#VG@$`
M!@```/J>`0`4`````9\!``<````6GP$`!P```!Z?`0`0````)I\!``\````W
MGP$`!@```$>?`0`&````3I\!``@```!5GP$`!@```%Z?`0`-````99\!``@`
M``!SGP$`"````'R?`0`0````A9\!``T```"6GP$`"````*2?`0`3````K9\!
M``<```#!GP$`#````,F?`0`)````UI\!``H```#@GP$`%````.N?`0`^````
M`*`!``P````_H`$`"@```$R@`0`<````5Z`!``X```!TH`$`&0```(.@`0`-
M````G:`!``T```"KH`$`"0```+F@`0`'````PZ`!``H```#+H`$`"0```-:@
M`0`.````X*`!`!````#OH`$`(`````"A`0`?````(:$!`"````!!H0$`"@``
M`&*A`0`'````;:$!``D```!UH0$`"@```'^A`0`3````BJ$!``0```">H0$`
M!P```*.A`0`I````JZ$!``8```#5H0$`!P```-RA`0`-````Y*$!`$@```#R
MH0$`$P```#NB`0`*````3Z(!``D```!:H@$``P```&2B`0`/````:*(!`!$`
M``!XH@$`#````(JB`0`)````EZ(!``(```"AH@$`!````*2B`0`B````J:(!
M``,```#,H@$`!0```-"B`0`O````UJ(!``H````&HP$`!````!&C`0`&````
M%J,!`!0````=HP$`$0```#*C`0`&````1*,!``@```!+HP$`"@```%2C`0`$
M````7Z,!``4```!DHP$`<````&JC`0`*````VZ,!``T```#FHP$`$0```/2C
M`0`%````!J0!``8````,I`$`&````!.D`0`J````+*0!``T```!7I`$`"@``
M`&6D`0`6````<*0!``L```"'I`$`"0```).D`0`3````G:0!`"$```"QI`$`
M'````-.D`0`<````\*0!`!X````-I0$`#@```"RE`0`#````.Z4!``<````_
MI0$`!P```$>E`0`)````3Z4!``X```!9I0$`#````&BE`0`&````=:4!`%4`
M``!\I0$`#P```-*E`0`*````XJ4!``T```#MI0$`&P```/NE`0!4````%Z8!
M`!H```!LI@$`!@```(>F`0`=````CJ8!`"4```"LI@$`"0```-*F`0`&````
MW*8!``L```#CI@$`!````.^F`0`)````]*8!`!P```#^I@$`&P```!NG`0`K
M````-Z<!``8```!CIP$`"P```&JG`0`@````=J<!`&@```"7IP$`$@````"H
M`0`?````$Z@!`!,````SJ`$``P```$>H`0`,````2Z@!``0```!8J`$`#```
M`%VH`0`)````:J@!``<```!TJ`$`!P```'RH`0`&````A*@!``D```"+J`$`
M"P```)6H`0`(````H:@!``H```"JJ`$`"0```+6H`0`U````OZ@!``<```#U
MJ`$`#````/VH`0`*````"JD!`!8````5J0$`"````"RI`0`(````-:D!`!``
M```^J0$`"0```$^I`0`'````6:D!``@```!AJ0$`!P```&JI`0`*````<JD!
M`!\```!]J0$`$````)VI`0`-````KJD!``D```"\J0$`&````,:I`0`*````
MWZD!`!4```#JJ0$`!P````"J`0`5````"*H!``0````>J@$`!P```".J`0`%
M````*ZH!``4````QJ@$`#````#>J`0`3````1*H!`!$```!8J@$`&@```&JJ
M`0`6````A:H!`!0```"<J@$`%P```+&J`0`8````R:H!`!P```#BJ@$`&```
M`/^J`0`'````&*L!``8````@JP$`#0```">K`0`+````-:L!``8```!!JP$`
M&0```$BK`0`+````8JL!``L```!NJP$`'@```'JK`0`8````F:L!`!,```"R
MJP$`!P```,:K`0`-````SJL!``4```#<JP$`#0```.*K`0`-````\*L!``8`
M``#^JP$`"0````6L`0`%````#ZP!``<````5K`$``P```!VL`0`$````(:P!
M``,````FK`$`.P```"JL`0`T````9JP!`!8```";K`$`.@```+*L`0`H````
M[:P!``X````6K0$`,````"6M`0`O````5JT!`#0```"&K0$`-````+NM`0`Y
M````\*T!``X````JK@$`'P```#FN`0`/````6:X!`!,```!IK@$`%@```'VN
M`0`3````E*X!`!4```"HK@$`$P```+ZN`0`5````TJX!`!P```#HK@$`,```
M``6O`0`P````-J\!`#0```!GKP$`*0```)RO`0`J````QJ\!`"8```#QKP$`
M9````!BP`0`=````?;`!`!8```";L`$`#0```+*P`0`9````P+`!``L```#:
ML`$`#P```.:P`0`T````]K`!`"@````KL0$`(0```%2Q`0`-````=K$!`$<`
M``"$L0$`0@```,RQ`0`%````#[(!`!4````5L@$`%0```"NR`0`'````0;(!
M`!(```!)L@$`$P```%RR`0`%````<+(!``\```!VL@$`"````(:R`0`2````
MC[(!`!,```"BL@$`#P```+:R`0`2````QK(!``4```#9L@$`'@```-^R`0`(
M````_K(!``,````'LP$`"@````NS`0`.````%K,!``P````ELP$`-0```#*S
M`0`"````:+,!``8```!KLP$`#````'*S`0`%````?[,!``<```"%LP$`$0``
M`(VS`0`&````G[,!`"T```"FLP$`#P```-2S`0`@````Y+,!``0````%M`$`
M+@````JT`0`:````.;0!`!X```!4M`$`7P```'.T`0`4````T[0!`#\```#H
MM`$`)0```"BU`0`.````3K4!``T```!=M0$`%````&NU`0`,````@+4!``P`
M``"-M0$`%````)JU`0`,````K[4!`!\```"\M0$`'````-RU`0`%````^;4!
M`!$```#_M0$`#P```!&V`0`A````(;8!`!````!#M@$`%````%2V`0`2````
M:;8!`!,```!\M@$`&P```)"V`0`(````K+8!``@```"UM@$`#@```+ZV`0`*
M````S;8!``L```#8M@$`"0```.2V`0`.````[K8!``D```#]M@$`"P````>W
M`0`8````$[<!``@````LMP$`!P```#6W`0`(````/;<!``4```!&MP$`"0``
M`$RW`0`&````5K<!``\```!=MP$`"````&VW`0`-````=K<!``<```"$MP$`
M#P```(RW`0`/````G+<!`"(```"LMP$`%P```,^W`0`(````Y[<!``D```#P
MMP$`&0```/JW`0`&````%+@!`!@````;N`$``P```#2X`0`7````.+@!``0`
M``!0N`$`!P```%6X`0`5````7;@!`"(```!SN`$`"P```):X`0`=````HK@!
M`!$```#`N`$`"P```-*X`0`:````WK@!``@```#YN`$`!`````*Y`0`'````
M![D!``P````/N0$`!P```!RY`0`%````)+D!``@````JN0$`!P```#.Y`0`+
M````.[D!``\```!'N0$`+0```%>Y`0`N````A;D!`!X```"TN0$`)0```-.Y
M`0`=````^;D!`#@````7N@$`(````%"Z`0`Z````<;H!`"8```"LN@$`3```
M`-.Z`0`=````(+L!``4````^NP$`!P```$2[`0`/````3+L!``@```!<NP$`
M%0```&6[`0`8````>[L!`#$```"4NP$`'P```,:[`0`2````YKL!`"T```#Y
MNP$`-0```">\`0`$````7;P!`!4```!BO`$`!@```'B\`0`%````?[P!`"``
M``"%O`$`#P```*:\`0`0````MKP!``P```#'O`$`!P```-2\`0`2````W+P!
M``D```#OO`$`#0```/F\`0`0````![T!`!D````8O0$`&P```#*]`0`Q````
M3KT!``L```"`O0$`#P```(R]`0`%````G+T!``P```"BO0$`!0```*^]`0`<
M````M;T!``X```#2O0$`!````.&]`0`,````YKT!``D```#SO0$`"0```/V]
M`0`+````![X!``0````3O@$`$@```!B^`0`'````*[X!``,````SO@$`#```
M`#>^`0`[````1+X!`$L```"`O@$`&0```,R^`0`'````YKX!`"$```#NO@$`
M&0```!"_`0`/````*K\!``X````ZOP$`"@```$F_`0`%````5+\!``X```!:
MOP$`*0```&F_`0`$````D[\!``D```"8OP$`#0```**_`0`0````L+\!``@`
M``#!OP$`-0```,J_`0`%`````,`!`"`````&P`$`"P```"?``0`/````,\`!
M`#0```!#P`$`(P```'C``0`P````G,`!`#````#-P`$`+P```/[``0`+````
M+L$!``<````ZP0$`#P```$+!`0`3````4L$!`!L```!FP0$`"@```(+!`0`;
M````C<$!`!,```"IP0$`!P```+W!`0`4````Q<$!`"8```#:P0$`!0````'"
M`0`%````!\(!``X````-P@$`#0```!S"`0`3````*L(!``4````^P@$`"```
M`$3"`0`)````3<(!``T```!7P@$`"P```&7"`0`0````<<(!`!````""P@$`
M!P```)/"`0`'````F\(!`"T```"CP@$`)P```-'"`0`E````^<(!``4````?
MPP$`!P```"7#`0`&````+<,!`!T````TPP$`%@```%+#`0`A````:<,!``,`
M``"+PP$`#0```(_#`0`@````G<,!``,```"^PP$`!@```,+#`0`-````R<,!
M``,```#7PP$`"P```-O#`0`3````Y\,!``H```#[PP$`%P````;$`0`<````
M'L0!`!,````[Q`$`!0```$_$`0`*````5<0!`!0```!@Q`$`#@```'7$`0`,
M````A,0!``,```"1Q`$`"````)7$`0`(````GL0!`!,```"GQ`$`3@```+O$
M`0`6````"L4!`#0````AQ0$`#0```%;%`0`)````9,4!``,```!NQ0$`#```
M`'+%`0`*````?\4!``P```"*Q0$`&0```)?%`0`/````L<4!``X```#!Q0$`
M&0```-#%`0`)````ZL4!`!L```#TQ0$`#@```!#&`0`*````'\8!`&$````J
MQ@$`%@```(S&`0`0````H\8!`"4```"TQ@$`%@```-K&`0`0````\<8!`"@`
M```"QP$`'````"O'`0`:````2,<!`!<```!CQP$`"````'O'`0`'````A,<!
M``<```",QP$`"0```)3'`0`5````GL<!``L```"TQP$`*P```,#'`0`5````
M[,<!`!,````"R`$`"0```!;(`0`&````(,@!`%X````GR`$`/@```(;(`0`U
M````Q<@!`&````#[R`$`"P```%S)`0`Q````:,D!`"0```":R0$`#````+_)
M`0`(````S,D!`!````#5R0$`/````.;)`0`#````(\H!`$@````GR@$`,```
M`'#*`0`F````H<H!``L```#(R@$`)@```-3*`0`:````^\H!`"\````6RP$`
M+````$;+`0`O````<\L!`"P```"CRP$`#````-#+`0`%````W<L!``T```#C
MRP$`"@```/'+`0`0````_,L!``8````-S`$`*P```!3,`0`,````0,P!``D`
M``!-S`$`"P```%?,`0`1````8\P!``D```!US`$`"0```'_,`0`;````B<P!
M``D```"ES`$`"0```*_,`0`#````N<P!``<```"]S`$`"````,7,`0`0````
MSLP!``T```#?S`$`"@```.W,`0`6````^,P!``P````/S0$`!P```!S-`0`.
M````),T!``X````SS0$`#P```$+-`0`)````4LT!`!D```!<S0$`)0```';-
M`0`1````G,T!`!8```"NS0$`)````,7-`0`0````ZLT!``D```#[S0$`#P``
M``7.`0`'````%<X!``D````=S@$`'P```"?.`0`)````1\X!``L```!1S@$`
M"0```%W.`0`%````9\X!``D```!MS@$`"````'?.`0`)````@,X!``T```"*
MS@$`%0```)C.`0`&````KLX!``X```"US@$``P```,3.`0`/````R,X!`!``
M``#8S@$`&0```.G.`0`*`````\\!``,````.SP$`'@```!+/`0`$````,<\!
M``<````VSP$`;0```#[/`0`*````K,\!``8```"WSP$`(````+[/`0`O````
MW\\!``T````/T`$`&@```!W0`0`[````.-`!`!H```!TT`$`(````(_0`0`/
M````L-`!``T```#`T`$`!0```,[0`0`'````U-`!``D```#<T`$`"@```.;0
M`0`'````\=`!``D```#YT`$`%`````/1`0`+````&-$!``H````DT0$`#```
M`"_1`0`,````/-$!``4```!)T0$`!P```$_1`0`)````5]$!`!4```!AT0$`
M"0```'?1`0`'````@=$!``<```")T0$`$````)'1`0`&````HM$!`!4```"I
MT0$`!@```+_1`0`&````QM$!``X```#-T0$`!@```-S1`0`.````X]$!``<`
M``#RT0$`!0```/K1`0`0`````-(!``L````1T@$`$````!W2`0`&````+M(!
M`!T````UT@$`"P```%/2`0`(````7](!``0```!HT@$`!P```&W2`0`-````
M==(!`!,```"#T@$`"@```)?2`0`,````HM(!`"D```"OT@$`&@```-G2`0`7
M````]-(!``4````,TP$`"0```!+3`0`/````'-,!``D````LTP$``P```#;3
M`0`.````.M,!``@```!)TP$`)````%+3`0`?````=],!`#8```"7TP$`(0``
M`,[3`0`G````\-,!`"P````8U`$`<0```$74`0`.````M]0!`%D```#&U`$`
M,@```"#5`0!7````4]4!`%````"KU0$`(0```/S5`0`Z````'M8!`"D```!9
MU@$`+@```(/6`0`G````LM8!`!L```#:U@$`-@```/;6`0#'`0``+=<!`!P`
M``#UV`$`$0```!+9`0!#````)-D!`)<```!HV0$`.`````#:`0`D````.=H!
M`#D```!>V@$`7P```)C:`0!;````^-H!`"D```!4VP$`&0```'[;`0`3````
MF-L!`"P```"LVP$`&0```-G;`0`6````\]L!`"H````*W`$`)P```#7<`0`B
M````7=P!`"8```"`W`$`00```*?<`0`/````Z=P!``<```#YW`$`,P````'=
M`0`D````-=T!`"@```!:W0$`(````(/=`0`;````I-T!`#,```#`W0$`70``
M`/3=`0!`````4MX!`$P```"3W@$`.P```.#>`0`R````'-\!`$,```!/WP$`
M:@```)/?`0!)````_M\!`#,```!(X`$`/0```'S@`0`Y````NN`!`%8```#T
MX`$`60```$OA`0!%````I>$!`$8```#KX0$`-0```#+B`0`Q````:.(!`"X`
M``":X@$`,@```,GB`0![````_.(!`'````!XXP$`>0```.GC`0"^````8^0!
M`!4````BY0$`(P```#CE`0`K````7.4!`"L```"(Y0$`1P```+3E`0`G````
M_.4!`$8````DY@$`)P```&OF`0`,````D^8!`*4```"@Y@$`/P```$;G`0`8
M````AN<!`#8```"?YP$`'````-;G`0`=````\^<!`"X````1Z`$`!@```$#H
M`0`%````1^@!``,```!-Z`$`#0```%'H`0`*````7^@!``@```!JZ`$`"P``
M`'/H`0`%````?^@!`!````"%Z`$``P```);H`0!I````FN@!``4````$Z0$`
M$`````KI`0`$````&^D!``<````@Z0$`"````"CI`0`%````,>D!`#\````W
MZ0$``P```'?I`0`0````>^D!``T```",Z0$`$@```)KI`0`0````K>D!``,`
M``"^Z0$`"````,+I`0`'````R^D!`!0```#3Z0$`#````.CI`0`5````]>D!
M``8````+Z@$`$````!+J`0`-````(^H!``,````QZ@$`,0```#7J`0`$````
M9^H!``8```!LZ@$`!P```'/J`0`=````>^H!`#T```"9Z@$`+````-?J`0`M
M````!.L!`!<````RZP$`)@```$KK`0`I````<>L!`"L```";ZP$`(````,?K
M`0`9````Z.L!`"`````"[`$`&P```"/L`0`6````/^P!`"````!6[`$`&@``
M`'?L`0`;````DNP!`"T```"N[`$`&0```-SL`0`J````]NP!`"@````A[0$`
M'````$KM`0`@````9^T!`!T```"([0$`&````*;M`0`?````O^T!`"(```#?
M[0$`(@````+N`0`D````)>X!`"0```!*[@$`&````&_N`0`;````B.X!`"0`
M``"D[@$`%@```,GN`0`@````X.X!`"L````![P$`+@```"WO`0`3````7.\!
M`"````!P[P$`-````)'O`0`<````QN\!`"````#C[P$`'0````3P`0`>````
M(O`!`!@```!!\`$`&P```%KP`0`H````=O`!`!T```"?\`$`*0```+WP`0`<
M````Y_`!`#8````$\0$`#0```#OQ`0`1````2?$!`!D```!;\0$`+0```'7Q
M`0`@````H_$!``P```#$\0$`#P```-'Q`0`:````X?$!``X```#\\0$``P``
M``OR`0`5````#_(!``<````E\@$`!@```"WR`0`A````-/(!`"0```!6\@$`
M%````'OR`0`@````D/(!`!@```"Q\@$`#@```,KR`0#<````V?(!`!4```"V
M\P$`'````,SS`0`'````Z?,!``H```#Q\P$`#@```/SS`0`/````"_0!`"``
M```;]`$`!@```#ST`0`Y````0_0!`!@```!]]`$`#@```);T`0`'````I?0!
M`!0```"M]`$`"````,+T`0`U````R_0!``8````!]0$`(0````CU`0`5````
M*O4!`!,```!`]0$`$P```%3U`0`Y````:/4!`!<```"B]0$`"@```+KU`0`@
M````Q?4!``L```#F]0$`#````/+U`0`3````__4!``H````3]@$`'````![V
M`0`%````._8!`"$```!!]@$`"0```&/V`0`9````;?8!`"T```"']@$`!P``
M`+7V`0`?````O?8!``<```#=]@$`"0```.7V`0`)````[_8!`#X```#Y]@$`
M!P```#CW`0`/````0/<!`!$```!0]P$`#@```&+W`0`'````<?<!``D```!Y
M]P$`!P```(/W`0`5````B_<!``8```"A]P$`%0```*CW`0`*````OO<!`!,`
M``#)]P$`%@```-WW`0`)````]/<!``L```#^]P$`&0````KX`0`$````)/@!
M`"@````I^`$`#````%+X`0`0````7_@!``@```!P^`$``P```'GX`0`*````
M??@!`"8```"(^`$`"P```*_X`0`#````N_@!``<```"_^`$`"````,?X`0`)
M````T/@!`!````#:^`$`#0```.OX`0`4````^?@!`!4````.^0$`"@```"3Y
M`0`N````+_D!`!@```!>^0$`&````'?Y`0`7````D/D!``P```"H^0$`-@``
M`+7Y`0`&````[/D!`!0```#S^0$`1`````CZ`0`2````3?H!``P```!@^@$`
M!P```&WZ`0`$````=?H!``0```!Z^@$`#0```'_Z`0`4````C?H!``4```"B
M^@$`!@```*CZ`0`&````K_H!``H```"V^@$`!P```,'Z`0`1````R?H!`!$`
M``#;^@$`.0```.WZ`0`N````)_L!`#8```!6^P$`!0```(W[`0`8````D_L!
M`!D```"L^P$`'P```,;[`0`=````YOL!`!(````$_`$``@```!?\`0`$````
M&OP!``L````?_`$`!0```"O\`0`%````,?P!``(````W_`$`#P```#K\`0!4
M````2OP!`#D```"?_`$`$0```-G\`0`M````Z_P!`"P````9_0$`8@```$;]
M`0`7````J?T!`&P```#!_0$`(0```"[^`0!+````4/X!`"0```"<_@$`2@``
M`,'^`0`Y````#/\!`"L```!&_P$`+P```'+_`0`O````HO\!`#````#2_P$`
M,0````,``@`N````-0`"`",```!D``(`.````(@``@`Q````P0`"`!(```#S
M``(`$@````8!`@`2````&0$"`(@````L`0(`"````+4!`@"T````O@$"`(,`
M``!S`@(`?0```/<"`@`S````=0,"`%@```"I`P(`%@````($`@`B````&00"
M`!<````\!`(`#P```%0$`@`6````9`0"`!T```![!`(`00```)D$`@`:````
MVP0"`"````#V!`(`6````!<%`@`7````<`4"`!0```"(!0(`"P```)T%`@`%
M````J04"``8```"O!0(`"````+8%`@`%````OP4"`!4```#%!0(`%````-L%
M`@`4````\`4"`!\````%!@(`$P```"4&`@`.````.08"``,```!(!@(`"```
M`$P&`@`*````508"``<```!@!@(`!0```&@&`@`4````;@8"``<```"#!@(`
M!@```(L&`@`5````D@8"``T```"H!@(`"P```+8&`@`2````P@8"``D```#5
M!@(`$P```-\&`@`'````\P8"``\```#[!@(`$`````L'`@`(````'`<"``H`
M```E!P(`&0```#`'`@`5````2@<"``@```!@!P(`)0```&D'`@`2````CP<"
M`!D```"B!P(`$0```+P'`@`'````S@<"`!,```#6!P(`"````.H'`@`#````
M\P<"`!4```#W!P(`"0````T(`@`"````%P@"``(````:"`(`$0```!T(`@`-
M````+P@"``D````]"`(`$P```$<(`@`4````6P@"``<```!P"`(`*@```'@(
M`@`"````HP@"``0```"F"`(`$@```*L(`@`8````O@@"``D```#7"`(`!P``
M`.$(`@`1````Z0@"``<```#["`(`'@````,)`@`(````(@D"`!4````K"0(`
M#0```$$)`@`2````3PD"``(```!B"0(`!P```&4)`@`*````;0D"``L```!X
M"0(`&````(0)`@`J````G0D"``T```#("0(`"@```-8)`@`*````X0D"``4`
M``#L"0(``@```/()`@`+````]0D"``$```#3!```'`0``#$%``!?`P``````
M`)P!``!M`@``H`0```````"4`P``QP$``/T&``!\``````````````"&`@``
M*P<```L!````````@P<``,$```!W!0``%00``/$%```L````VP,``,,&```E
M!P``"`(```$$``"\!0``!`<``#$#````````I@(``/`%``!D`@``L@(```\$
M``"!`P```````````````````````-8$``!1!0``A00`````````````]@$`
M`'`"`````````````'\"```N!````````",!``"D!0```````&0'``#D!0``
MD08``"4!``!R!@``]00``&X"``!P`0``-0<``,(!``#1`@``+P0``&\#``!0
M!P``6@```*(!```S`0``BP<```````![`0``ZP```)@&``#`!0``7@<``$H%
M``#.!@```````)0$``!B`@``\@```"D"``!F`@```````-L$``"&!@``W@4`
M````````````I0```````````````````)@#````````0````.8&````````
MS0$```````"=!```2`(``+\%````````_0(``(H'````````#`4```````!/
M!```S`4``.P"```F!0``%P`````````T````6````+P!`````````````+4"
M``!:!```90,``&H#``!?`0``A`<``````````````````/H!``!D`P``;P``
M`-8!````````?P8````````*!P``D`````````!-`P``FP(````````<`P``
M7P8``/0!``#?````*`,``-P!``#0`0``M@,``$<#````````'0<``!,'```E
M`P``\0```+`%``#2!`````````````"K`P``I`````````#+!0``80,``'D#
M``"5!```"@0```````",!@``P`$```````#A!```>@<``-D#``#G`0``````
M`/\%``!,!P``J0$``%@$``#D`0```````$\```"^`0``````````````````
M+P,``&X'````````L@````````"8!0``9P0``*8&``#B`0``2`8````````J
M````^P$``&@!``!6!P``V@,``"H&``"C!```5@8``%8$``"Q!@```````)T"
M``!;````E`8``(L#``"I`````````*P%``#3````H`,``'H!``!G`@``P@,`
M`"H'``![`P``*P`````````V```````````````Q`@``@P```.0$````````
M]@0``'D$``!&!P```````/<``````````````),"``"Z!0```````!<%``"J
M`P``*P(``'P'````````=`0``#L"`````````````)`"``".`0``B@0``-P`
M``!^!P``5P4``)H#```#`@``/0<``%X#```&`0```````$4$````````+P<`
M`)\#``"E`0````````````!G!0``<0$`````````````1`8``-L````_!P``
M2@`````````"`@```````"D!````````5@,```````"<!````````,P!``!A
M!```%@,````````G!```80``````````````)00``'<```#N`P``:`8`````
M``">!@````8``'L`````````&@8``+$$```#````!0<``-T%``"Y!@``R0,`
M`'P"```8!P``[```````````````8P$```````#N`@``F@```)(```">`P``
M`````)L!```K!0``<0(``/,#``!&`P``O@(``+H!``#=!```V`8``+0#``#C
M!```R@0``*H$````````&@<``!<"``"_!```&`$``+$"`````````````.(#
M``"/`@```````'X!``#^!0``:0$``!@&``#X`0``*@,``$L#``!R`P``1P0`
M`)8!``!'````R`$``'$#``!0!@``.@```&(&``!3````UP8``'8"````````
M+@4``"8"``!U!@``[0````P&```$````Y`(``'X#``"#!0``B0$``),$``#^
M`@``9@<``.<%```7`0```````)\!```/!P``>P(``'X````%!```"P<``"\&
M```V!@```````%("``"_`````````'<#``#_`P````````L````S!0``````
M``````!H!P``*08``-T`````````]`(``$$'````````V`,``-H$````````
M`````&@````-`@``=`8```````#5!@``QP8``'$```"@````_@8``$("````
M````FP0``+D#``#`````!`0``!`&``!,`0``E`(``+D%``"@`0``P0$`````
M```%`````````$X'``#6`@``8P````````#$````````````````````\@0`
M``````!`!0``<0<```````#/!@```````!<#``"#!@````````````!2!0``
M``````````#S!```=P0``*4&``!O!```"````%X```!*!P``N@,``'8%``#>
M````A`,``"0$```[!0``^08``)P#``!W`@```````&H!```^`@``P`8``.X%
M``"^!````````'$&````````B0```*4"````````-08````````>!P``````
M`%4!```B!```.`$```````!M!````````(<"``!Y!0``@`4``-8`````````
M(0(``%$&```W!```,P(`````````````EP,``/\$```"!P``!P,``&L&````
M````\0$``,8```#P`P``CP```%T'`````````````.D&``"%`P``````````
M``#=`@``+@,``%<!``#V!@```````.4!``#^````30```,T$```0!0``````
M`#8!``"0`P``?0$``)<```!9!```?P0``',```"G!0``6`(``(("````````
M0P8``'8!``#^`0```````.<$````````)`````````#X!```:P0``,8$``!9
M`0``(00```8```"?`@``7@(`````````````!`8``)0%````````XP8``(X#
M```^````*P$``!0"``#7`P``DP8``$('````````;`,```````".!```HP``
M``````#%`P``40```+T"```L!```(`0``.D$````````+@8``/8"```P!@``
M6`4``````````````````*D"```D`P````````````"S`0```````'T````G
M`P```````'0'````````D00```````#.`0``\@8```@!````````````````
M`````0``3`4``#H&````````R04``!$!``!?!```^@,``)P```"P`P``Q`$`
M``````!U!```<00``-<"``#*!0``?`$``(P!``````````````````#]!0``
M-00```````!`!P``IP8``-`#``"J!@``[0$``*8`````````[P(`````````
M`````````*T$``#K`0``^00``-\#```H!````````&8$``"?````$08``+D$
M``#J`P```````,D$``!;`@``C`0```````#$`@``O@4``$(%``!V!P``U@4`
M`)4&````````90<`````````````&P0```````#T`P``5````-D`````````
M2````)8`````````5@(``#<````A!@``/`(``',"````````\P(````````(
M!```MP(``*4$``!Y!P```````-P&```5`````````-D$````````_```````
M```?!0``BP4``/<!``#W!0``?`,``-H&``"T!0``E04```,%````````````
M````````````@P0``+\"``#.`@``#@<``)D#``#_`@```````/0$```_`@``
M4P$```````#%!```,@$```````#+`@``C```````````````2P$`````````
M````O`8```D!``#>`0``)@0``*0#``#-!0``<P$``#,$```2!@``BP0``&(`
M````````+P```*(&```X`@``60(``($'``!)!P``C04``!D`````````K0``
M`.\#``#3!@``?`4``#(```"]!0``R@(```````#X!@``N`8``%L%``!$`0``
M```````````=`@``(`<``-T&````````#@4```````!@`0``.0(``$,"``"[
M`0``@`,````````J`0``1@```-`"```5!@```````'\```!"`P``-P<``"T!
M```Q!```X0$```````#2!0``M`(``.@!``!4`P``^`,``'T$````````H@,`
M`-0"``!B`P``ZP4`````````````7P```!\"```R`P``_`(```````!S!```
M`````((&```W!0``.@4``!@$````````=@```*,#````````EP4``&(%```2
M`@``;`$``"(!````````C@````````!J!0```````,4%```:`0``X`$`````
M``"3`P``F`````````"%!0``&``````````L!0``A@0````````<````FP8`
M`&H&``#[`@``A0$```````!,`P``:@<``'H$```0!```90```%0%``#&!@``
M=`(``.```````````````+<#``!U`P````````````````````````````!<
M`0```````#H'``!^`@``;```````````````B`(```````#0!@``"P(```\%
M``!M`0``+0(``.`%``#G`@``3P,```T!``!@````9P````````#!!@``V0(`
M`+L&``````````````````#J````L@0``"@`````````,0<```````#S````
MJ@4``/T!``#5!```&@```````````````````&($````````R@8``&$&``!.
M`````````!,"`````````````$H$```7!@``(P```#\```""!0``J`0``+@"
M``"1!0``Y````$($````````N`4``$$%```?`0``N`$```````";!0``````
M`+4````#!P``+0<`````````````L`0```````!K!P``>P4``&8`````````
M``````````#.!```!P$``%D&`````````````.$&``!B!P``.P$``#L$``!U
M`@``[08``#D$```A!P``_P8``',&```,`0```````$D&``"?!@``O`0``&<&
M```)!0``1P<``````````````````',#``"+````>P<``-(#```!`@``HP$`
M`"P#````````LP0````````F!P```0,``.L"``!P````;P8``-@````3!@``
M10,``%\'``#S!0``Z@8``-$$```_`P```````/L%``!G!P``H08``-("````
M````:P$``-$```"+!@``,````,@"``"A!```[`$``.(```!J`@``I@$``%P"
M````````.`,```````!=!@``*P0``&`#``#A!0```````,\```"6!0``V08`
M`$4"`````````````)4!``````````````@&``!&!0````<```````!)`P``
M;`4``%4'``#3`0``@`$`````````````````````````````_00``&P$```&
M!```/@,``!\$``#?!````````%P#``!^!```$0(``"T&``#+!```&P,`````
M``"`!@``=0````4#``"1`0```````*P`````````!`(``'D!```I!```-@<`
M``````!Z````=```````````````8@$``%0!```-````/P$``-X#``"V!@``
M.0<`````````````)@```````````````````(@%``"/!````````$8$```!
M!@```````+,```!0`0``D@8``+(!```6`@``4`(``(<#``!P!P``]0(``+8`
M``#T!@``\0,``%$!``#B!```[P0```````#1!@```````"\"````````#0<`
M`%``````````5`(```````!-!@``@0(````````=!@```````/4&``"-!@``
MNP```%X&````````^0$``(0```!'!@```````'4!`````````````$0"``!(
M`0``%0,````````D`0``60,``/4```":!0``4P4``-X&```Y`0``&P<`````
M``"(`0``7`4``%<$``!#!P``F@(``#T#```1`P``K@4``$D!````````GP0`
M```````^`0``:@```'X%``"G`P``J08``"``````````K@```$L````2````
MI@0```$!``!Z!@```````-4!``"Z````Y`,``+8!`````````````&@$````
M`````````+X```"Y````<@0````````1````7P4``.8$```@`P``JP$``.8`
M```B`@``H`8``+T!``#R`0``.P8``(0&````````@0```!($``"[`@``/00`
M`'\!```;````LP(```````"]`P``=04``&4"``"%`````````,T"``#%!@``
M?P4```````!7`@``GP4``/`!``"M`P```````(H%``!R`0``L0```($$````
M````\08````````2!P``;P(```````#M`P```````!`"```4`0``+0,``$0$
M````````U0,``-\"````````?08``$D%````````VP4``(<$````````LP8`
M`/<"``"O!```!0(````````A````_`4``'<!```\`P``"P8``/0%``#P`@``
M<04``+@#````````U`,``.@"``!:!@```````'L$``!!`P```````"H"``"<
M!0``Q@4``-H%``!A!0`````````````!!P``>@4``$<"```\````O```````
M````````#P,`````````````$0<``#@&```4!`````````````!A`@``"0<`
M`#,#````````0`$``#T%````````G`8`````````````AP$``,D```#I`P``
MY08``+T```"+`0``O00````````V`P``-0(``!T%````````B`8``*X$```'
M`@``ZP0``+\#``````````````````!)!```4@8``+4$``!S!0``Q`,`````
M``!K`P``V@$``+`!````````DP4```````#+!@``H@4````````)`P``?0,`
M`!,````-!```Q0$```L$````````00(``%4```#C!0```````*P#```#`P``
M&00```<&`````````````.H$``#L!0``"@,``*@%``"W!```%@```%0$```W
M`0``504``*0"``#Y`@```````(`"```C!0``^P,``$,!``!J!```````````
M```_!0``$P$```````#R`P``QP0``+\&````````2`,```````#-`P``704`
M`'P$```^!@``^0```!X%``!&`0```````*L```!6`0``Z`0``(T`````````
MS@,``#D&`````````````,L```"'````W0,`````````````S`0```````!3
M!P```````!D%````````YP,``#$```#,`P``B04``!`!```.````;`<``*<`
M``#/!```8P<``!D&``#:````(0$``*("``"8`@``7@0``"T$```D!P``90$`
M`'@"```5!P``'00``-D%``"<`@``70````````#@!```9@4``$`&``#F`@``
M`````+(%````````!`,``!X$```````````````````$!0```````),!``"'
M!@``=`,``*\#``#[!@```````)($``"%`@``'P8```````#<`P```````%L!
M``!<!P``%`,``/$"```T!P``=`4``*@#``!=`0``+`8`````````````````
M`+`&``#@`P``3@,``/P$```[!P``>`0````````O!0``:08``-0```"@`@``
M^0,````````H!0``AP<``.T%``!R`@```````"D`````````!@(````````,
M!P``Y00```````!3!@`````````````H!P```@8```````!&`@``````````
M````````UP$``,T````W`P``!`$````````L!P``<P<``&0&````````@04`
M`&X!``"O`@``Q`0``"X"``!5!```````````````````A`4``!,$``"1`@``
M6`8``-(```"N`P``2@8``#@'``!]!P```````-`$```;!0```````+H$````
M`````````((!`````````````","``!:`0```````!P'```S!P``(`(``*@"
M```G!P```````#H$``")`@``:P```/,&```Y!0``/`$``!$%````````Y04`
M`(H````<`0``JP0``(D#```&!0```````"(%``!=`@```````.H!````````
M^@0```````#?`0``1P4````````4!@``B````.D"```T!```Y0,``*L%``#.
M!0``QP,````````_!```````````````````Z@(``*$#``#^`P``&`4``#,`
M``#V!0``>`<```````!P!@```````,L#``!O`0``'@,``%D%````````A@``
M`(,!````````M````(\#``"$!```,`0``+<!``"9`@``H`4``+8"``#E`@``
M`````#($``"A````+`(``,@#```+`P```````(P%````````'`8``*P$````
M``````````````!K!0```````-@!````````#@0```D&````````)0```.$#
M``">``````````````!R!0``(`8````````5`0``/@4``!T```#,`@``G@4`
M`(H&``".`@``(04``)8"````````008``$(&``"A`0``H04``"<"````````
M`````"T```!+!P``E0(``%($`````````````#0"``#X!0``=`$``%T#```U
M`0```````$X$``!6!0``H@0```D```##!0``@P,```````!8`0``:0(``.P#
M```9`@```````,("``!;!P``0P,``#P$``"0`0``Y@$``.,#``!1!```````
M``````"L`@``#@(``!P"``!.`0``2`0```H`````````3@8``/P!```N````
MC0$````````N!P``[0(``.D!``#/`0``;`(`````````````V@(``,,"```G
M````LP,``)(%````````;@```!``````````C00``!L!``!P!```=P<````#
M``#?!0``5`<``+(#```(!P``C0,```````"-`@``9P$``((#``"_`0``>`8`
M`&X$``"J````3@(``&0%````````C`,``#`'``""!````````+P#```^!```
M&`(````````W`@``D@,``((`````!```````````````````#P(``!4"``#"
M````NP,```````#2!@``,`4``.X```#!!0```````$@%```4!P``6@<```($
M``!>`0````````````#9`0``2P8``/$$``!N!@``.`4``#P'``":`0``X0``
M`+P"``"^`P``%@0`````````````F04``.H%``#U`P```````$0'```9`P``
M[`0``)4#```"`P``"@8``(\&````````;08``&$'```N`0``)P8```````!F
M!@``:0,```````!@!@``M0,```H"``!)`@``'P````T&``!D`0``````````
M``!/`@````````````"F!0``,@8``+$!```.!@``T@$``#4%``"&`0``7```
M```````\!@``Y@,``!H%``"[!```K0(```````"`````>@,``(D&``#(!0``
MA08``-T!```U`P``[P$`````````````#````)8#``!C`@``G@(``/(%````
M``````````````!D!`````````````#I````M@4``*,&````````'@$``,$#
M```]!@``<`4``(0!``!K`@```````$T$``#H!@```````,@&``"/`0``````
M`,,````?!P```````&,$``!U!P````````T%```]`0``40<``&T#```C!@``
M1````!<'`````````````-@"``!)````.P,``!<$````````[P```&P&````
M````"@4``%,#```'!0``)`4``+<&``"I!```!P0``$<!``!%!@``````````
M````````(`4```````"P````KP```#$&``#P!@``XP`````````D!@``$@,`
M`,$$``#;!@````````````!_`P``#`0``!@#``"L`0```````+D!``#D!@``
MS@````````"2`0``@`<``,4"```"!0```````#0!````````J````"P!```.
M`P```````)`$```9`0``H@```%`%````````ZP8``-4"````````````````
M```)!```F0$``)L#``"J`0``#`(``-4%``#U!0``]0$```T#````````G0$`
M`,4`````````Q@(``%<````X````*`(`````````````_0,``*<$``"[!0``
M`````,(%````````3P$``!T!``#N!@``^@8``)8$``!0!````````*T!````
M`````````*0!``"I!0``L`(``&4&````````U@,``!8%``"F`P```````!H"
M````!0```````(@'``""!P``T04``.,!``"N!@``XP(``,(&``"K`@``<`,`
M`)`%``"O`0```````-,%``"D!@```````+4%````````SP4``&T%````````
M^`(```````#?!@`````````````?`P``?P<``+0$``"H!@```````,0%``"G
M`0``0P```)T#```;`@```````$P$`````````@$``)<"``!/!0``0`,``'L&
M``#<`@```````$@'``!C!0``@08``$0#``#E````304``,0&````````````
M````````````T````%L#``"W````>0(``$,%````````5`8``-<%``!*`@``
M/0```"T%````````?`8``.`"``!@!```&@,``````````````````,,$````
M````TP,``.("``!X`P``E````(D'```:!````````````````````````$$$
M```;!@````````````!2!P```````"D#``#]````5P,`````````````(P<`
M`%$#```Z`@``DP```/,!``!5`@`````````````/!@```````)D$````````
M0@$``%\"``!+!```30<``&X%``"Q`P```````(0"``!/!@```````"8!````
M````VP$```````"Q!0``<@<``-P$``!I!0``M08``"<%```^!P``10<``$H#
M``!I!```SP,```````!H`@``KP4``(`$``!V`P``T0,``%`#``"8`0``X0(`
M`$P"``#"!````````(@$``!M!P``<@```````````````````/H"````````
M,@4``&@#```'!P``(P,``'X&````````Z`,``)<$``"U`0``S`8``,\"```H
M`0``EP$``,L!````````6`<``%,"``!:`P``A@4````````P`@``^````)D`
M````````S````*X"```T!0```````-<`````````I04`````````````````
M`"8&``":!@``[@$``"$#```[````F08``$$!``#&`P``C`(```8'```5!0``
M904``````````````````"(#``"*`@``'@```(4'``!7!P``K04``$4```!W
M!@``.`0``,,!``#4`0``0@```&4$```I!P``;P4``/<&``!6````#@$``/H%
M``!-`@``_@0``%H"``"C!0``!@8``.D%```B````104```````!,!@``F`0`
M`)T&``#!`@```P0`````````````O@8``&X#```6!@``[P8```````!]!0``
MZ````#0#``!:!0``$@4```\!```>`@```````&@%````````+P$``#T"``!-
M`0``,`$``"4"``#5`````````"4%``!F`P``]@```'H"``"0!@``````````
M``"C`@```````*X!``#\`P``80$``+@```"1````````````````````E0``
M`"8#```/``````````````"*`P```````'T"``#'!0``Q@$```````"&`P``
M(@<``)X!````````VP(``,D!```*`0``50,``'D```#4!```PP,```````#*
M`0``$P,``````````````````&\'``#P!```=@0```@#````````/P8``-@$
M````````H0(``&T```"/!0``&0<```````!9!P``*@0```(```!@`@``'`4`
M``````#Y!0``3@4```````#(````#`,``(L"````````I0,```@%````````
M.0,``/\!```0!P``700```D"````````3````)H$``#1`0``*04``.@%````
M````>`````````!F`0``\````.\%``!+`@``MP4```4%````````4@```.L#
M``!+!0``U@8``#D```#(!```G04``,`"``!@!P```P$``'D&``!$!0``X`8`
M````````````!P```#8%```K`P``^@```,D&```6!P```P8``,H```!X`0``
M$@$``/<#``#F!0``K`8``%,$``!2`0````````8#``"Y`@``3P<``!0```"1
M`P``J@(``%P$``#7!```.@,``#`#``#T````0`0```````#>`@``L@8`````
M```%!@``W`4``&,&``#``P``R@,``.T$``!;!```E`$``(@#``!I!P``A@<`
M````````````$P4``(X&``"D!```,@<``(H!``!#!```FP```"(&``#R`@``
M=@8`````````````M@0````````0`P``[`8``&`%````````^P0``)8&``#B
M!0``*P8`````````````]P0```````"Z`@```````+0!``!&!@```````*\&
M``!7!@``/`4```````!!````-@0````````R`@````````$%````````C@4`
M`!T#``"G`@````````````!2`P``*`8``-0%``#\!@```````*@!``!C`P``
M$00`````````````508``"<!``"S!0```````.<&``#3`@```````(<%``"#
M`@``N@8``%@#``"!`0```````.X$```D`@``U`8````````U````O08``,D"
M``"I`P``60`````````Q`0```````.(&``"T!@``"P4``$4!``!<!@``N`0`
M`#<&````````6P8```````!D````)08``,<"````````G0```/\````%`0``
M0`(``(D$``!I````V`4``"`!``">!````````)("```4!0```````#H!``#0
M!0```````!8!````````>`4``,<```#-!@````````````!>!0``(P0``/8#
M```J!0``YP```,`$``"K!@``'@8``$H!```S!@````(``&<#``#>!```-@(`
M````````````^P```*T&``"7!@``40(````````T!@```"`H)7,@9&%Y<R!A
M9V\I`"`H06-C97-S:V5Y("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H
M=&]M;W)R;W<I`"`H>65S=&5R9&%Y*0`@870@`"(E<R(@:7,@;F]T(&$@9&ER
M96-T;W)Y+@`B)7,B(&ES(&YO="!A('9A;&ED(&-H;VEC92X`(B5S(B!I<R!N
M;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN`"(E<R(@=')E
M92!R96YD97)E<B!N;W0@9F]U;F0N`"(E<R(@=V%S(&%D9&5D('1O('1H92!G
M<F]U<',@<WES=&5M+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO
M;G,@<WES=&5M+@`B)7,B('=A<R!N;W0@8W)E871E9#H@)7,N`"4N,F9-0B!U
M<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I`"5D("5S(&%N9"`E<P`E
M9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RX`)60M9&%Y(&9O
M<F5C87-T`"5S("T@3F]T:6-E`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S($UA
M:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T=7``
M)7,@4VEG;B!5<``E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D>2!E
M>&ES=',N`"5S(&%T("5S("5S`"5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@
M=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F
M;W)M(&%T('1H:7,@=&EM92X`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E
M<R!N;W0@9F]U;F0N`"5S('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K
M`"5S)W,@0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z
M("5S`"5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@
M8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG(&%N>2!L:6YK<R!I
M;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S
M;VYA;"!I;F9O<FUA=&EO;BX`+"!G=7-T:6YG(``L(&=U<W1I;F<@)7,@)7,`
M+"!V87)I86)L92!F<F]M("5S('1O("5S`"TM('-E;&5C="`M+0`Q,B!(;W5R
M($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P`\4')E=FEO=7,`02!D
M871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!
M(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES
M(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@
M:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!
M('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L
M:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-
M12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)
M344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@
M:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!32!#;&]U
M9',`04T@3&EG:'0@4F%I;@!!32!286EN`$%-(%-H;W=E<G,`04T@4VYO=R!3
M:&]W97)S`$%-+U!-`$%022!)1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN
M+@!!8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5S<R!D96YI960@8W)E871I;F<@
M5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL
M92X`06-C;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U
M;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D9`!!9&0@0VAI;&0@1W)O=7``061D
M($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D
M($YE=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD(&=R;W5P('1O("(E<R(`061D
M(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`B)7,B`$%D9"!A(&YE=R!U<V5R.@!!
M9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!9&0@=&AE("5S
M($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1O(&%D9')E<W,@8F]O
M:SH`061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1E9"`B)7,B
M('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@
M<VEG;G5P(&EN9F]R;6%T:6]N.B`E<RX`061D960@(B5S(B!T;R!T:&4@<WES
M=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N`$%D9&EN9R!U<V5R<R!I<R!D:7-A
M8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E="!P
M97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S
M`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&EG
M;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S
M`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT:7!L
M92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP
M93\`06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N
M871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT
M97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E
M<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`06X@:6QL96=A;"!V86QU92!W
M87,@<W!E8VEF:65D+@!!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+@!!
M;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`06YS=V5R
M`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D80!!<'!L:6-A=&EO;@!!
M<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L>2!T
M;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<'!R;WAI;6%T92!3:7IE`$%P<FEL
M`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ90!!<F-H
M:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@
M<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)E('EO=2!S=7)E('EO=2!W:7-H
M('1O(&1E;&5T92`B)7,B(&%N9"!A;GD@<W5B+6=R;W5P<S\`07)G96YT:6YA
M`$%R;65N:6$`07)M96YI86X@*$%235-#24DM."D`07)T`$%R=6)A`$%S8V5N
M<VEO;B!)<VQA;F0`07-C:6D@07)T`$%S:6$O4&%C:69I8R!296=I;VX`07-K
M(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P
M97)A=&EO;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1E;7!T('1O(&1E;&5T
M92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N
M;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N
M+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE
M>&ES=&5N="!S:&%R92X`071T<FEB=71E<P!!=6=U<W0`075S=')A;&EA`$%U
M<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E
M<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@
M97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE
M;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I
M<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A
M<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E
M($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N
M(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N
M(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N
M86)L92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U
M<&1A=&4@=7-E<B`E<P!!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO
M="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN`$%U=&A?;6-A;#H@
M4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U
M=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"X`075T
M:&5N=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A
M=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT
M:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A
M=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@=&\@
M=&AE(%--0B!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@9FEE;&1S.@!!>F5R
M8F%I:F%N`$)/1D@@17AC=7-E<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L
M;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA
M;64N`$)A:&%M87,`0F%H<F%I;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG
M;&%D97-H`$)A<F)A9&]S`$)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y("(E<R(@
M;F]T(&9O=6YD+@!"87-E;&EN90!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E
M;FEN`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@87!P
M;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K
M(%1Y<&4`0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H
M:6-K;F5S<SH`0F]R9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`
M0F]T<W=A;F$`0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@
M26YD:6%N($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG
M87)I80!"=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#
M4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN
M+@!#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+@!#86QE;F1A<@!#86QM
M`$-A;6)O9&EA`$-A;65R;V]N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T
M;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B!N
M;W0@=W)I=&4@=&\@9FEL92`B)7,B`$-A;B=T(&%D;6EN:7-T97(@97AT97)N
M86P@<V5S<VEO;B!H86YD;&5R<RX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E
M<G9E<CH@)7,`0V%N)W0@;W!E;B!F:6QE("(E<R(N`$-A;F%D80!#86YC96P`
M0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL92`B)7,B
M+@!#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P
M<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T
M(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI
M;&1R96X@97AI<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE
M<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@
M<W1O<F5D+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M
M8F5R+@!#87!E(%9E<F1E`$-A<'1I;VX`0V%R<FEE<@!#871E9V]R:65S(&%N
M9"!,86)E;',`0V%Y;6%N($ES;&%N9',`0V5L;"!0:&]N90!#96QL(%!R;W!E
M<G1I97,`0V5L;"!P861D:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C
M:6YG.@!#96QL<&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E
M;G1R86P@069R:6-A;B!297!U8FQI8P!#96YT<F%L($5U<F]P96%N("A)4T\M
M.#@U.2TR*0!#97)T:69I8V%T92!$971A:6QS`$-E<G1I9FEC871E($]W;F5R
M`$-E<G1I9FEC871E(%!O;&EC:65S`$-H860`0VAA;F=E`$-H86YG92!9;W5R
M(%!A<W-W;W)D`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E
M;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA
M:6QS+@!#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@
M=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@0V]N=&%C="!Y;W5R
M(&%D;6EN:7-T<F%T;W(N`$-H87(`0VAE8U]K($QI;FLN+BX`0VAI;&4`0VAI
M;F$`0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET
M:6]N86P@*$)I9S4I`$-H;V]S92!!<'!L:6-A=&EO;CH`0VAO;W-E(&$@<&%S
M<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y
M(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L
M:7-T<RD`0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D969I;FET:6]N(&]F("5S
M(&YO="!F;W5N9"X`0VQE87(`0VQE87(@35-/9F9I8V4@=&%G<P!#;&5A<B!1
M=65R>0!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R
M(&1A=&$`0VQE87)I;F<@3&%T90!#;&EC:R!T;R!#;VYT:6YU90!#;&EC:V%T
M96QL('9I82!(5%10`$-L;W-E(%=I;F1O=P!#;&]U9',`0VQO=61S($5A<FQY
M`$-L;W5D>0!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#;VQL87!S92!3:61E
M8F%R`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I
M8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M
M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE
M`$-O;6]R;W,`0V]M<&%N>0!#;VUP=71E<G,`0V]N9&ET:6]N`$-O;F1I=&EO
M;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F%T:6]N(&9O
M<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN
M`$-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N`$-O;F9I9W5R92`E<P!#
M;VYF:7)M(%!A<W-W;W)D`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!2
M97!U8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@
M9F%I;&5D.B``0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y
M<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES
M97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V
M97(@9F%I;&5D+@!#;VYT86-T<P!#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL
M>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&5N="!T>7!E(&]F
M(&-O;7!R97-S960@9FEL93H@`$-O;G1E;G1S(&]F("(E<R(`0V]N=&EN=64`
M0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@9F%I;&5D.B`E<P!#;W!Y
M('-E;&5C=&EO;@!#;W-T($E$`$-O<W1A(%)I8V$`0V]T92!D)TEV;VER90!#
M;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@`$-O=6QD(&YO="!01U`@
M<VEG;B!M97-S86=E.B``0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A
M9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@
M861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R
M+@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-O;FYE
M8W0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E
M<B`B)7,B('5S:6YG($944#H@)7,`0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z(`!#
M;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T
M92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<P!#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T
M("(E<R(N`$-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M
M;6%I;"!A9&1R97-S+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S
M<R!B;V]K+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N
M(&QI<W0N`$-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D
M:7-T<FEB=71I;VX@;&ES=',N`$-O=6QD(&YO="!L;V%D('-T<F%T96=Y("(E
M<R(N`$-O=6QD(&YO="!M:V1I<B`B)7,B+@!#;W5L9"!N;W0@;V)T86EN('!U
M8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`B
M)7,B(&9O<B!W<FET:6YG+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T
M(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T(&]P
M96X@9&ER96-T;W)Y("(E<R(N`$-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S
M97)V97(N`$-O=6QD(&YO="!R96%D("5S+@!#;W5L9"!N;W0@<F5S970@=&AE
M('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL
M(&]F('1H92!D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R
M(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H
M97(@:&5L<"X`0V]U;&0@;F]T(')E=')I979E($%#3`!#;W5L9"!N;W0@<F5T
M<FEE=F4@861D<F5S<R!B;V]K+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB
M=71I;VX@;&ES=',N("5S`$-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C
M87!A8FEL:71I97,`0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#
M;W5L9"!N;W0@<FUD:7(@(B5S(BX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG
M=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N
M+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S`$-O
M=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!#
M;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E
M<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@
M66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T;R!S879E
M('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D
M92!B96QO=R!T;R`E<RX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V
M97(N`$-O=6QD(&YO="!U;FQI;FL@(B5S(BX`0V]U;&0@;F]T('5P9&%T92!C
M;VYT86-T+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<P!#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@(B5S(CH@
M)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U
M<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;&1N)W0@9VEV92!U<V5R("(E
M<R(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@(B5S(CH@
M)7,`0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E
M(&$@;&EN:P!#<F5A=&4@82!N97<@;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#
M<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA
M`$-U8F$`0W5R<F5N="`T(%!H87-E<P!#=7)R96YT(%-E<W-I;VYS`$-U<G)E
M;G0@5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT(%5S97)S`$-U<G)E;G0@
M5V5A=&AE<@!#=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S
M=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+@!#=70`0W5T
M('-E;&5C=&EO;@!#>7!R=7,`0WER:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@
M*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I`$-Z
M96-H(%)E<'5B;&EC`$1$`$133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O
M;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"D`
M1&%I;'D`1&%T851R964@0G)O=W-E<@!$871A8F%S92!,;V]K=7``1&%T90!$
M871E(%)E8V5I=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$95]L971E($-O;'5M
M;@!$96-E;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C<F5A<V4@26YD96YT`$1E
M9F%U;'0`1&5F875L="!#;VQO<@!$969A=6QT($ED96YT:71Y`$1E9F%U;'0@
M4VAE;&P`1&5F:6YI=&EO;G,`1&5L971E`$1E;&5T92!#96QL`$1E;&5T92!'
M<F]U<`!$96QE=&4@3&]G`$1E;&5T92!097)M:7-S:6]N`$1E;&5T92!A;F0@
M<'5R9V4@;65S<V%G97,`1&5L971E(&-E;&P`1&5L971E(&-O;'5M;@!$96QE
M=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E`$1E;&5T92!M97-S86=E
M<P!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(`1&5L971E('!E<FUI<W-I
M;VYS(&9O<B`B)7,B(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@
M<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@<W5B(&9O;&1E
M<G,`1&5L971E('1H92!C=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E
M;G0@<F]W`$1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`1&5L
M:79E<GD@=&EM90!$96YM87)K`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R
M:7!T:6]N`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T
M86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`
M1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R
M.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T
M:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T
M:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9&5T86EL960@9F]R96-A
M<W0`1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA=`!$:7-P
M;W-I=&EO;B!.;W1I9FEC871I;VX`1&II8F]U=&D`1&\@;F]T(&1E;&5T90!$
M;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H
M92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@
M8VAE8VL@=&AI<R!B;W@Z`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$
M;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N`$1O=VYL;V%D`$1O=VYL
M;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(
M4"!S8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$4M36%I;`!%36%I;"UT
M;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V
M:61E('1H:7,@<V5R=FEC92X`15)2`$5C=6%D;W(`161I=`!%9&ET($)L;V-K
M`$5D:70@1W)O=7``161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`
M161I="!097)M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I
M="!P97)M:7-S:6]N<R!F;W(@(B5S(@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E
M<P!%9'5C871I;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%
M;6%I;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H
M+@!%;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%;6%I;"UT;RU335,@1V%T97=A
M>0!%;6]T:6-O;G,`16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;7!T
M>2!S96%R8V@@=&5R;7,`16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O
M;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\`16YA8FQE(')I9VAT(&-L:6-K
M(&-O;G1E>'0@;65N=3\`16YD('EE87(`16YL87)G92!%9&ET;W(`16YT97(@
M82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I
M9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T
M(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!5
M4DP@:&5R90!%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SH`17%U871O<FEA;"!'
M=6EN96$`17)I=')E80!%<G)O<@!%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,`
M17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S`$5R<F]R(&1E;&5T:6YG
M('-Y;F,@;&]G.B`E<P!%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S`$5R<F]R
M('5P9&%T:6YG('!A<W-W;W)D.B`E<P!%<G)O<B!W:71H(&5M86EL(&UE<W-A
M9V4N`$5R<F]R('=R:71I;F<@(B5S(BX`17-T;VYI80!%=&AI;W!I80!%=&AN
M:6,`175R;W!E`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V
M97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V
M97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X
M96-U=&4`17AP86YD`$5X<&%N9"!3:61E8F%R`$5X<&5C=&5D("<I)P!%>'!E
M8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M`$5X<&ER871I
M;VX@1&%T90!%>'!O;F5N=`!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P
M`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N
M;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"
M('-E<G9E<BX`1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@
M8V]P>2!T;R`B)7,B+@!&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE
M8W1I;VXN`$9A:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A:6QE9"!T;R!R971R
M:65V93H@)7,`1F%I<@!&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R
M;V4@27-L86YD<P!&871A;"!%<G)O<CH`1F%X`$9A>&5S`$9E8G)U87)Y`$9E
M96QS($QI:V4`1F5E;',@;&EK93H@`$9E=R!3:&]W97)S`$9E=R!3;F]W(%-H
M;W=E<G,`1FEE;&0@;6%T<FEX`$9I9VQE="!#05!40TA!`$9I9VQE="!F;VYT
M`$9I:FD`1FEL90!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S
M(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`
M1FEL92!U<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E
M<G,`1FEN;&%N9`!&:7)S="!(86QF`$9I<G-T(%%U87)T97(`1FEX(')A=&EO
M`$9L:7``1FQO870`1F]G`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT
M($-O;&]R`$9O;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I
M;6%G97,`1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T
M('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N
M:6=H=#L@82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W
M:61E(&)L;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N
M90!&;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R
M=V%R9',`1G(`1G)A;65S`$9R86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&
M<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N
M(%1E<G)I=&]R:65S`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`
M1G5L;"!-;V]N`$9U;&P@3F%M90!'86)O;@!'86QL97)Y('1O('1A:V4@:6UA
M9V4@9G)O;0!'86QL97)Y.@!'86UB:6$`1V5N97)A=&4@)7,@0V]N9FEG=7)A
M=&EO;@!'96YE<F%T960@0V]D90!'96]R9VEA`$=E<FUA;GD`1VAA;F$`1VEB
M<F%L=&%R`$=I=F5N($YA;64`1VQO8F%L($]P=&EO;G,`1V\`1V]E9&5L`$=O
M;V=L92!-87!S`$=O;V=L92!396%R8V@`1W)A>7-C86QE`$=R965C90!'<F5E
M:R`H25-/+3@X-3DM-RD`1W)E96YL86YD`$=R96YA9&$`1W)O=7`@061M:6YI
M<W1R871I;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O=7!?
M;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H
M92!S97)V97(@<V%I9#H@`$=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@
M9W)O=7`@)7,`1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E
M<P!'<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'
M=65S="!097)M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S
M874`1W5Y86YA`$A434P`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D
M96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N`$A434Q!<F5A(&-O=V%R9&QY
M(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92X`
M2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@
M<F]W(&EN('1A8FQE+@!(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`
M2&%I=&D`2&%S:"U!;&=O<FET:&T`2&%Z90!(96%D97(`2&5A9&5R<P!(96%R
M9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`2&5A=GD@5"U3=&]R;0!(
M96)R97<@*$E33RTX.#4Y+3@M22D`2&5I9VAT`$AE;'``2&5L<"!U<VEN9R!E
M9&ET;W(`2&5L<&5R`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG
M(&]F('1H92!F:6QE.@!(:6=H`$AO7VUE`$AO;'D@4V5E("A6871I8V%N($-I
M='D@4W1A=&4I`$AO;64`2&]M92!!9&1R97-S`$AO;64@1&ER96-T;W)Y`$AO
M;64@4&AO;F4`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B
M.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@
M)7,`2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J
M96-T("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N
M9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M
M;W9E9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG
M:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N`$AO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J
M96-T("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z
M("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F
M;W(@=&AE('!A<G0@;V8@='EP92`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O
M('-Y;F-H<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA8CH@56YK;F]W
M;B!S:&%R92`B)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I
M;F<`2&]R:7IO;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@
M<F5P;W)T(2D`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M
M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO
M=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AU;6ED:71Y
M`$AU;6ED:71Y.B``2'5M;W)I<W1S`$AU;F=A<GD`24U!4"!M86EL8F]X(&-R
M96%T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE
M9#H@)7,`24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`
M25`@061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0($%D9')E
M<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO8VMD;W=N
M('9I;VQA=&EO;BX`25]N<V5R="!2;W<@0F5F;W)E`$EC96QA;F0`26-O;G,@
M3VYL>0!)8V]N<R!F;W(@)7,`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@
M;F%M93H`268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O
M(&]P96X@:70@:6X@82!N97<@=VEN9&]W+@!)9B!Y;W4@9&]N)W0@<V5E(&%N
M>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D
M('1O(&-H96-K('1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N
M8WDN`$EF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE
M(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92!D:7-P;&%Y960@
M8GD@>6]U<B!B<F]W<V5R+@!);6%G92!0<F5V:65W.@!);6%G92!54DP`26UA
M9V4@55),.@!);6%G92!F<F]M(&=A;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y
M.@!);6%G92!U<&QO860`26UA9V5S`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E
M9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E
M<@!);F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R
M;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A
M;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A
M<V4@26YD96YT`$EN9&EA`$EN9&EV:61U86P@57-E<G,`26YD;VYE<VEA`$EN
M9F\`26YF;W)M871I;VX`26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L
M92X`26YS97)T($-?;VQU;6X@069T97(`26YS97)T($EM86=E`$EN<V5R="!4
M86)L90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN
M<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R
M="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@
M82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@
M<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R87!H
M(&%F=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H(&)E
M9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA
M=&4`26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R
M96-E:79E('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN
M<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C
M;VQU;6X@8F5F;W)E`$EN<V5R="!M97-S86=E<P!);G-E<G0@<&%R86=R87!H
M(&%F=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R;W<@869T
M97(`26YS97)T(')O=R!B969O<F4`26YS97)T('1H92!R97%U:7)E9"!A;G-W
M97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.@!);G-E<G0O36]D:69Y($EM
M86=E`$EN<V5R="]-;V1I9GD@3&EN:P!);G-U9F9I8VEE;G0@8W)E9&ET('1O
M('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@
M8W)E9&ET+@!);G1E9V5R`$EN=&5G97(@;&ES=`!);G9A;&ED(%5$2"X@*%5S
M97(@1&%T82!(96%D97(I+@!);G9A;&ED(%I)4"!D871A`$EN=F%L:60@87!P
M;&EC871I;VXN`$EN=F%L:60@8F%T8V@@240N`$EN=F%L:60@9&%T82!S=6)M
M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI9"!F
M:6QE(&9O<FUA=`!);G9A;&ED(&QI8V5N<V4@:V5Y+@!);G9A;&ED(&QO8V%T
M:6]N('!R;W9I9&5D+@!);G9A;&ED(&US9U]T>7!E+@!);G9A;&ED(&]R(&UI
M<W-I;F<@87!I7VED+@!);G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`
M26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P87)T;F5R(&ED
M+@!);G9A;&ED('!R;V1U8W0@8V]D92X`26YV86QI9"!P<F]T;V-O;"X`26YV
M86QI9"!R96-I<&EE;G0Z("(E<R(`26YV86QI9"!S:&%R92!O8FIE8W0`26YV
M86QI9"!S;W5R8V4@861D<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN
M=F5N=&]R>0!);G9E<G0@<V5L96-T:6]N`$ER86XL($ES;&%M:6,@4F5P=6)L
M:6,@;V8`27)A<0!)<F5L86YD`$ES;&4@;V8@36%N`$ES;VQA=&5D(%0M4W1O
M<FUS`$ES<F%E;`!)<W-U97(`271A;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R
M>0!*87!A;@!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86X`
M2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL
M`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MA>F%K:'-T86X`2V5E<"!O
M<FEG:6YA;#\`2V5N>6$`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE
M;G1I8V%T:6]N+@!+97)N96P@3F5W8FEE<P!+97D@0W)E871I;VX`2V5Y($9I
M;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A
M;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+
M:7)I8F%T:0!+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O
M9@!+;W)E82P@4F5P=6)L:6,@;V8`2V]R96%N("A%54,M2U(I`$MU=V%I=`!+
M>7)G>7IS=&%N`$QA7WEO=70`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C
M<F%T:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@4&%S<W=O<F0@0VAA;F=E
M`$QA<W0@475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA
M<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA
M`$QA=P!,87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N
M`$QE9G0`3&5F="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,979E;`!,
M:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,
M:6=H="!$<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H
M="!286EN($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H
M(%1H=6YD97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC
M:P!,:6YK`$QI;FL@<&]I;G1S('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S
M('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI
M;G5X($-O;VMI90!,:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES
M="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T
M+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/=VYE<@!,:7-T+5!O
M<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG('-E
M<W-I;VYS(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!F86EL960Z("5S`$QI
M<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QI=&5R871U<F4`3&ET:'5A;FEA
M`$QO861I;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A
M=&EO;@!,;V<@:6X`3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;@!,;V<@
M;W5T`$QO9VEN`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO
M=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T
M;'DN`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R
M965K(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N
M=6UB97)S`$QU>&5M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@
M8V]N=&%I;F5D(&YO(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&
M;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I8P!-
M86EL`$UA:6P@061M:6X`36%K92!L:6Y?:RXN+@!-86QA=VD`36%L87ES:6$`
M36%L9&EV97,`36%L:0!-86QT80!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O
M<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S
M(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87`R-"!M87``
M36%P475E<W0@;6%P`$UA<'!I;F=S('-T;W)E9"X`36%R8V@`36%R9VEN`$UA
M<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H97(@9FQA
M9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S
M`$UA<G1I;FEQ=64`36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET
M:75S`$UA>"!A;&QO=V5D(&-R961I="X`36%X(&UE<W-A9V4@<&%R=',@97AC
M965D960N`$UA>"!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T
M(#8@:&]U<G,Z(`!-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS`$UA
M>&EM=6T@;&5N9W1H`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365N
M=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@5F5R:69I960@
M4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U
M;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@
M='EP90!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N
M`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N
M(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&%R1$(@:7,@;F]T
M(&-O;FYE8W1E9"X`365T:&]D`$UE=&AO9"`B)7,B(&ES(&YO="!D969I;F5D
M`$UE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,`365T<FEC
M`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F`$UI9&1L
M90!-:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP
M(&QA<W0@-B!H;W5R<SH@`$UI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@
M>65T(&5X<&ER960`36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!014%2
M('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN
M(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U
M<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S
M:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I
M;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF:65D($1A=&4`
M36]D:69Y(%523`!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C
M;P!-;VYG;VQI80!-;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1S97)R870`
M36]O;B!0:&%S97,`36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N
M('1H92!E>'!E8W1E9"`E9"X`36]R;V-C;P!-;W-T;'D@0VQE87(`36]S=&QY
M($-L;W5D>0!-;W-T;'D@0VQO=61Y(&%N9"!7:6YD>0!-;W-T;'D@4W5N;GD`
M36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V92!D
M;W=N`$UO=F4@=7``36]Z86UB:7%U90!-=6QT:2UL979E;"!D<F]P(&1O=VX@
M;&ES=',`375L=&EM87`@54L@;6%P`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!
M8V-O=6YT`$UY($%C8V]U;G0@26YF;W)M871I;VX`37D@4&]R=&%L`$UY(%!O
M<G1A;"!,87EO=70`37EA;FUA<@!.3RP@22!$;R!.3U0@06=R964`3F%M90!.
M86UI8FEA`$YA=7)U`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N
M=&EL;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!(%)E=F]C871I
M;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A
M;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@4U-,('-E
M<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A
M<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R`$YE=R!#86QE9&]N
M:6$`3F5W($-A=&5G;W)Y`$YE=R!-;V]N`$YE=R!5<V5R;F%M92`H;W!T:6]N
M86PI`$YE=R!:96%L86YD`$YE=R!P87-S=V]R9`!.97<@<&%S<W=O<F0@=VEL
M;"!E>'!I<F4@;VX@)7@N`$YE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N`$YE
M=R!W:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="`T
M(%!H87-E<P!.97AT(&]P=&EO;G,`3F5X=#X`3FEC87)A9W5A`$YI9V5R`$YI
M9V5R:6$`3FEG:'0`3FEU90!.;P!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO
M;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@
M<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T96UP
M;&%T92X`3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I
M;VX`3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT
M:6-A=&EO;BX`3F\@8VAA;F=E+@!.;R!C:&EL9')E;B!C86X@8F4@861D960@
M=&\@=&AI<R!P97)M:7-S:6]N+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&
M4RX`3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T:6]N('-U<'!L:65D+@!.
M;R!F:6QE('5P;&]A9&5D`$YO(&EC;VYS(&9O=6YD+@!.;R!L;V-A=&EO;B!I
M<R!S970N`$YO(&QO8V%T:6]N('!R;W9I9&5D+@!.;R!M97-S86=E('-U<'!L
M:65D+@!.;R!N86UE('-P96-I9FEE9"X`3F\@;G5M8F5R('-P96-I9FEE9"X`
M3F\@;V9F96YS:79E(&9O<G1U;F5S`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!(5%10(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@24U!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN`$YO('!A=&@@=&\@
M=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA
M<GD@:7,@;F5C97-S87)Y('1O('=O<FL@=VET:"!02T-3(#$R(&1A=&$N`$YO
M('!E;F1I;F<@<VEG;G5P<RX`3F\@<75O=&$@<V5T+@!.;R!R=6QE<P!.;R!S
M97!A<F%T;W(@<W!E8VEF:65D+@!.;R!S:61E<P!.;R!S=6-H(&9I;&4`3F\@
M=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!U
M<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L:60@6$U,(&1A
M=&$@<F5T=7)N960`3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U;F0@:6X@;W)I
M9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N
M+@!.;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G
M96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;VYE`$YO;F4@*'5S92!I;7!L:6-I
M="D`3F]R9&EC("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!)<VQA;F0`3F]R=&AE
M<FX@2&5M:7-P:&5R90!.;W)T:&5R;B!-87)I86YA($ES;&%N9',`3F]R=V%Y
M`$YO="!!9G1E<@!.;W0@0F5F;W)E`$YO="!A(&1I<F5C=&]R>0!.;W0@:6UP
M;&5M96YT960N`$YO="!S970`3F]T('-U<'!O<G1E9"X`3F]T97,`3F]T:&EN
M9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO=F5M8F5R`$YU;6)E<@!.=6UB97(@
M;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@<F]W
M<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R
M:6)U=&EO;B!L:7-T+@!/2P!/8FIE8W0`3V)J96-T($-R96%T;W(`3V-T86P`
M3V-T;V)E<@!/9F9E;G-E(&9I;'1E<@!/9F9I8V4`3VQD(&%N9"!N97<@<&%S
M<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+@!/;&0@<&%S<W=O<F0`3VQD('!A
M<W-W;W)D(&ES(&YO="!C;W)R96-T+@!/;6%N`$]N;'D@24U!4"!S97)V97)S
M('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N`$]N;'D@;V9F96YS:79E(&9O<G1U
M;F5S`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"X`3VYL>2!T:&4@
M;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE
M<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I
M;B!A(&YE=R!W:6YD;W<`3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A
M8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="X`3W!E;G,@=&AI<R!L
M:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M`$]P=&EO;G,`
M3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A
M;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC871I
M;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/
M=&AE<B!);F9O<FUA=&EO;@!/=VYE<B!097)M:7-S:6]N<P!004T@875T:&5N
M=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4$5!4CHZ36%I;"!B86-K96YD
M`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D($1A=&$`4$=0
M(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`@0V]D
M90!02%`@4VAE;&P`4$T@3&EG:'0@4F%I;@!032!286EN`%!-(%-H;W=E<G,`
M4$T@4VYO=P!032!3;F]W(%-H;W=E<G,`4$T@4W5N`%!-(%0M4W1O<FUS`%!/
M4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG`%!?2%`@4VAE;&P`4&%D9&EN9P!0
M86MI<W1A;@!086QA=0!086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D
M`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A<F%G=6%Y`%!A<G1L>2!#;&]U
M9'D`4&%S<W=O<F0`4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN`%!A
M<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553
M(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!0
M87-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`4&%S
M=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z
M`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E
M<FUI<W-I;VX`4&5R;6ES<VEO;B`B)7,B(&YO="!D96QE=&5D+@!097)M:7-S
M:6]N($1E;FEE9`!097)M:7-S:6]N<P!097)M:7-S:6]N<R!!9&UI;FES=')A
M=&EO;@!097)S;VYA;"!);F9O<FUA=&EO;@!097)U`%!E=',`4&AI;&EP<&EN
M97,`4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!I>&5L<P!0;&%T:71U9&5S`%!L
M96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T
M('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF
M:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="X`4&QE
M87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`4&QE87-E(&5N=&5R(&$@
M;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE87-E(&5N=&5R(&$@=F%L
M:60@25`@861D<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE
M8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"X`4&QE87-E(&5N
M=&5R(&$@=F%L:60@=&EM92X`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F
M('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N
M9"!P87-S=V]R9`!0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO
M=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@<WES=&5M
M+@!0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0
M;VQI=&EC<P!0;VQL<P!0;W)T=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM
M86=E`%!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O
M;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I`%!R96-I<&ET871I;VX@9F]R
M(&QA<W0@)7,@:&]U<BAS*3H@`%!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4`
M4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`%!R97-S=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R
M97-S=7)E.B``4')E=FEE=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W
M:6YD;W<`4')E=FEO=7,@;W!T:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV871E
M($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C=',`4')O
M;7!T('1E>'0`4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L
M:6,@2V5Y($EN9F\`4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A
M=&5D('-U8V-E<W-F=6QL>2X`4'5E<G1O(%)I8V\`4'5R9V4@;65S<V%G97,`
M46%T87(`475E<GD`475O=&$`4E-!(%!U8FQI8R!+97D@*"5D(&)I="D`4F%D
M:6\@<V5L96-T:6]N`%)A:6X`4F%I;B!%87)L>0!286EN($QA=&4`4F%I;B!3
M:&]W97(`4F%I;B!A;F0@4VYO=P!286EN('1O(%-N;W<`4F%N9&]M($9O<G1U
M;F4`4F%T:6\`4F5A9`!296%D(&UE<W-A9V5S`%)E86QL>2!D96QE=&4@)7,_
M(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E86QL>2!R96UO
M=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN
M;W0@8F4@=6YD;VYE+@!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H
M`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.@!2969R97-H(%!O<G1A
M;"!6:65W.@!296=E>`!296QA=&EO;G-H:7`@0G)O=W-E<@!296QO860`4F5M
M87)K<P!296UO=&4@4V5R=F5R<P!296UO=&4@55),("AH='1P.B\O=W=W+F5X
M86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!";&]C:P!296UO=F4@
M8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E;6]V92!P86ER`%)E;6]V92!S
M879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y
M+@!296UO=F4@=&AE`%)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE
M;G0`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z("5S`%)E<75E<W0@8V]U;&1N
M)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@`%)E<75E<W1E
M9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"X`4F5Q=6ER960@(B5S(B!N
M;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E
M<R(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER
M960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN`%)E<75I
M<F5D($9I96QD`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T(%EO=7(@4&%S
M<W=O<F0`4F5S=&]R92!,87-T(%%U97)Y`%)E<W5L=',`4F5T=7)N('1O($]P
M=&EO;G,`4F5T>7!E(&YE=R!P87-S=V]R9`!2975N:6]N`%)E=F5R="!#;VYF
M:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D;&5S`%)I
M9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?=R!0<F]P97)T:65S
M+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T
M92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!2
M=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C
M;VQU;6YS`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY
M`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY`%)U;@!2=7-S
M:6%N($9E9&5R871I;VX`4G=A;F1A`%,O34E-12!#<GEP=&]G<F%P:&EC(%-I
M9VYA='5R90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`4T%33"!A=71H96YT
M:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@365S<V%G:6YG`%-13"!3
M:&5L;`!344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S`%-32`!354-#
M15-3`%-?44P@4VAE;&P`4V$`4V%I;G0@2&5L96YA`%-A:6YT($MI='1S(&%N
M9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@86YD($UI<75E;&]N
M`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S`%-A;64@9G)A;64@
M*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP
M90!3871E;&QI=&4@4')O=FED97(`4V%U9&D@07)A8FEA`%-A=F4`4V%V92`B
M)7,B`%-A=F4@)7,`4V%V92!/<'1I;VYS`%-A=F4@9V5N97)A=&5D(&-O;F9I
M9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M
M<&]R87)Y(&1I<F5C=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V%V
M960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`%-C871T97)E9"!4
M+5-T;W)M<P!38VEE;F-E`%-E87)C:`!396%R8V@@16YG:6YE<P!396QE8W0@
M1FEL97,`4V5L96-T(&$@9&%T90!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L
M96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R
M('1O(&%D9`!396QE8W0@86QL`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S
M+@!396QE8W0@86X@;V)J96-T`%-E;&5C="!N;VYE`%-E;&5C="!T:&4@8VAA
M<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A
M;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A
M+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@
M9F]R;6%T.@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG
M93H`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L96-T('1H92!T:6UE
M(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y
M;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U
M86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;F5G86P`4V5N
M<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I86P@
M3G5M8F5R`%-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N`%-E
M<W-I;VX@061M:6X`4V5S<VEO;B!)1"!E>'!I<F5D+@!397-S:6]N<P!3970`
M4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O
M<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@=7`@<F5M;W1E('-E<G9E
M<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"X`
M4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T
M92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO
M<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L87D@
M;W!T:6]N<RX`4V5T=7``4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L
M90!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T
M97(Z(`!397EC:&5L;&5S`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO=6QD
M(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`
M4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@
M=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@!3:&]W(&QA<W0@
M;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@;W!T:6]N('1O(&ME
M97`@;W)I9VEN86P`4VAO=R!P:6-K97(`4VAO=R!T86)L92!O<&5R871I;VYS
M(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W
M('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A
M8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P
M97)T:65S(&1I86QO9P!3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO
M9P!3:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,
M871E`%-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y`%-H<FEN:P!3:')I;FL@;W(@
M;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER
M<W0`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R92!!
M;&=O<FET:&T`4VEN9V%P;W)E`%-I>F4`4VMI<"!-86EN=&5N86YC90!3;&]V
M86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R`%-N;W<@4VAO=V5R<P!3
M;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W97)S($QA=&4`4VYO=R!D97!T
M:#H@`%-N;W<@97%U:79A;&5N="!I;B!W871E<CH@`%-O;&]M;VX@27-L86YD
M<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R="!O<F1E<B!S96QE8W1I;VX`
M4V]U<F-E(&%D9')E<W,`4V]U=&@@069R:6-A`%-O=71H($5U<F]P96%N("A)
M4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I
M8V@@27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@
M861J86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D
M97(@:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG
M`%-P86EN`%-P86T`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!L:70@8V5L
M;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W`%-P;W)T<P!3<FD@3&%N:V$`4W1A
M;F1A<F0`4W1A<B!4<F5K`%-T87)T('EE87(`4W1A=&4@;W(@4')O=FEN8V4`
M4W1A='5S`%-T;W)A9V4@9F]R;6%T`%-T<F5E="!!9&1R97-S`%-T<FEK971H
M<F]U9V@`4W1R:6YG(&QI<W0`4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E
M<W,`4W1Y;&4@6T-34UT`4W4`4W5B9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD
M+@!3=6)J96-T`%-U8FUI=`!3=6)M:71T960@<F5Q=65S="!T;R!A9&0@(B5S
M(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R
M(')E<75E<W0@:&%S(&)E96X@87!P<F]V960N`%-U8G-C<FEP=`!3=6-C97-S
M`%-U8V-E<W-F=6QL>2!A9&1E9"`B)7,B('1O('1H92!S>7-T96TN`%-U8V-E
M<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S
M>7-T96TN`%-U8V-E<W-F=6QL>2!D96QE=&5D("(E<R(N`%-U8V-E<W-F=6QL
M>2!R96UO=F5D("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@
M<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S
M+@!3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U
M8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL
M92`E<RX`4W5C8V5S<V9U;&QY('5P9&%T960@(B5S(@!3=6-C97-S9G5L;'D@
M=W)O=&4@)7,`4W5D86X`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY
M`%-U;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS
M970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A
M;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L
M86YD`%-Y;F,@;&]G(&1E;&5T960`4WEN8TU,`%-Y;G1A>"!E<G)O<B!I;B!S
M96%R8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T
M;W)M(&%N9"!7:6YD>0!4+5-T;W)M<P!4+5-T;W)M<R!%87)L>0!44U8@9FEL
M90!486)L90!486)L92!0<F]P97)T:65S`%1A8FQE(%-E=`!486)L92!P<F]P
M97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A:FEK
M:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!487)G970Z`%1A
M<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M
M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP97)A='5R93QB<B`O/B@E<TAI
M)7,O)7-,;R5S*2`F9&5G.R5S`%1E;7!L871E("(E<R(@;F]T(&9O=6YD+@!4
M96UP;&%T92!!9&UI;FES=')A=&EO;@!497AT`%1E>'0@3VYL>0!497AT(&%L
M:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AE($94
M4"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`5&AE($AI<W1O<GD@<WES
M=&5M(&ES(&1I<V%B;&5D+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@
M96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@24U34"!L;V<@8V]U
M;&0@;F]T(&)E(&EN:71I86QI>F5D+@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S
M<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O
M=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@861M:6YI<W1R871O<B!N965D
M<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N
M9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@
M<VED92!O;FQY`%1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I
M9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A
M8F%S92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y
M;W5R(&%D9')E<W,@8F]O:RX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@
M8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G
M92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P
M96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B
M87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N
M`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B
M(&-O;FYE8W1I;VXN`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@
M<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S
M971T:6YG<RX`5&AE(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L
M9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@
M87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A
M9V4N`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R
M;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R
M(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO
M=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E
M9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S
M+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK
M96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U
M;'0G(&%N9"!N965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N
M960N("!0;&5A<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y
M('1H92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA
M<R!B965N(&1E;&5T960N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H92!L
M;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@
M=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT(&]N("5S
M('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*
M5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E
M;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI
M;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;G5M8F5R(&]F(&9I96QD
M<R!M=7-T(&)E(&YU;65R:6,N`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U
M:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P
M<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S
M(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE
M('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S
M(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<75O=&4@8VAA<F%C=&5R
M(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!R:6=H="!A;F0@
M;&5F="!S:61E<R!O;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@
M<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!S
M97)V97(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@
M:&%S(&)E96X@<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S
M(&)E96X@<F5M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO
M="!E>&ES="X`5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N`%1H
M92!T96UP;W)A<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5X
M="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S
M8W)E96XN`%1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@
M<VED92!O;FQY`%1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H
M92!P<F5V:6]U<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@
M8F4@<V%V960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA
M8FQE+@!4:&5M97,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!4:&5R92!A
M<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T
M:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA
M;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D
M("5S(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`
M5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@(B5S(B!T;R!T:&4@<WES=&5M
M.B`E<P!4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S
M97(@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M
M(')E;6]V:6YG("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@
M<')O8FQE;2!U<&1A=&EN9R`B)7,B.B`E<P!4:&5R92!W87,@82!P<F]B;&5M
M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E
M<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E
M9"!B>71E<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H
M97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T
M`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T
M82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R
M(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO
M;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD
M+@!4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D
M(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E
M<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E
M=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E
M<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T
M<GD@86=A:6X@;&%T97(N`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P
M<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O
M(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R
M('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T
M;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH
M='1P.B\O8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10
M($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T
M:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2!G871E=V%Y+"!U
M<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS
M,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@
M9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H
M<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D
M869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W
M:71H(%9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@
M9FEE;&0@:7,@<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I
M;B!I;G1E9V5R<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E
M<G,@86YD('1H92!C;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN
M(&]C=&%L('9A;'5E<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@
M<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M
M=7-T(&)E(&$@=F%L:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I
M;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA
M;7!L92`G(S$R,S1A9B<N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R
M;V-E<W-E9"X`5&AI<R!I<R`E<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R
M92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A
M;B!E;6%I;"!C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O
M=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L:65N
M=',@<&QE87-E('9I<VET("5S`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I
M;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4
M:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S97)V97(@
M8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES
M=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T
M(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M
M(&%N($]P=&EO;G,@=VEN9&]W`%1H=6YD97(`5&EC:V5T<P!4:6UE`%1I;64@
M5')A8VMI;F<`5&EM92!F;W)M870`5&EM92!S96QE8W1I;VX`5&EM;W(M3&5S
M=&4`5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4;P!4;R!S96QE8W0@;75L=&EP
M;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA
M;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4;V=G;&4@2%1-
M3"!3;W5R8V4`5&]G;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1O;R!M86YY
M(&EN=F%L:60@;&]G:6YS(&1U<FEN9R!T:&4@;&%S="!M:6YU=&5S+@!4;W``
M5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA=&EO;G,`5')I;FED860@86YD(%1O
M8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U;FES:6$`5'5R:V5Y`%1U<FMI<V@@
M*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES
M;&%N9',`5'5V86QU`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``
M55),`%523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R
M=`!54DPZ`%5G86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I
M<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N
M('=H96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N
M(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I
M;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S
M+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R(N`%5N86)L92!T
M;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S+R5S(BX`56YA8FQE('1O(&-O;FYE
M8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN
M`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&
M4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T
M;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E
M871E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&-R96%T92!E;7!T>2!6
M1E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O
M(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA
M8FQE('1O(&1E;&5T92`B)7,B.B`E<RX`56YA8FQE('1O(&1E;&5T92`E<RP@
M=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E;&5T92!6
M1E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@
M)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O
M(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R
M("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RX`
M56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE
M('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A
M9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@5D93(&9I
M;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!O
M<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@
M9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B
M;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+@!5;F%B
M;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+@!5
M;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE('1O(')E860@=&AE('9F<W)O
M;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T
M:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`56YA8FQE('1O(')E;F%M
M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O
M<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("(E<R(N`%5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4N`%5N86)L92!T;R!R=6X@)VUK:7-O9G,G+@!5;F%B;&4@=&\@
M=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y
M*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N`%5N
M86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E
M9"X`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C
M=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE
M8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B``
M56YF:6QE9`!5;FEC;V1E("A55$8M."D`56YI=&5D($%R86(@16UI<F%T97,`
M56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5;FET960@4W1A=&5S($UI
M;F]R($]U=&QY:6YG($ES;&%N9',`56YI=',`56YK;F]W;@!5;FMN;W=N(&%P
M:6US9VED("A!4$D@365S<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G:60@*$-L
M:65N="!-97-S86=E($E$*2X`56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"X`
M56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YL:6YK('1H92!C=7)R
M96YT(&5L96UE;G0`56YN86UE9`!5;G!R:79I;&5G960@<V-R:7!T<R!C86YN
M;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@
M<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A
M;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO=2!H;W<@=&\@
M86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N`%5N<V5T
M(&-O;&]R`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D871E("5S
M`%5P9&%T92!U<V5R`%5P9&%T960@(B5S(BX`57!G<F%D92!S8W)I<'0@9&5L
M971E9"X`57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F
M:6QE<R!T;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R
M(')O;6%N(&YU;6)E<G,`57)U9W5A>0!5<V4@0W5R<F5N=#H@)7,`57-E(%-3
M3`!5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@
M<V5R=F5R+@!5<V5R`%5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S
M+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES
M=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F
M;W(@=&AI<R!S:71E+@!5<V5R(&%C8V]U;G0@;F]T(&9O=6YD`%5S97)N86UE
M`%5S97)N86UE("(E<R(@86QR96%D>2!E>&ES=',N`%5S97)N86UE.@!5<V5R
M;F%M93H@`%5S97)S(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I
M<F5C=&]R>2!D;V5S(&YO="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C871I
M;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU=&5S
M(&9R;VT@;F]W+@!686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O
M9B`E<RX`5F%L=65S`%9A;'5E<R!T;R!S96QE8W0@9G)O;0!686YU871U`%9A
M<FEA8FQE`%9E;F5Z=65L80!697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M
M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO;@!6
M97)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D9&EN
M9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I970@3F%M`%9I971N86UE<V4@*%9)
M4T-)22D`5FEE=R`E<P!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I97<@
M87,@)7,`5FER9VEN($ES;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N9',L
M(%4N4RX`5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``5F]D869O;F4@271A;'D@
M=FEA(%--5%``5T%23@!705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,
M3%D@1E)/32`E<RX`5TE.('9I82!(5%10`%=A;&QI<R!A;F0@1G5T=6YA`%=A
M<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED
M960@8GD`5V5A=&AE<BYC;VT`5V5B`%=E8B!3:71E`%=E96ML>0!796QC;VUE
M`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM
M,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H870@
M87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H
M870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U
M;W1E(&-H87)A8W1E<C\`5VAE<F5I<R!!=7-T<F%L:6$@;6%P`%=H:6-H('!H
M87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X
M="!E9&ET;W(N`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T
M:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@
M;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z
M`%=I:VD`5VEN9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN
M9#H`5VEN9#H@`%=I<V1O;0!7:7-H;&ES=`!7;W)K`%=O<FL@061D<F5S<P!7
M;W)K(%!H;VYE`%=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@
M17AP96-T960@)60L(&9O=6YD("5D+@!7<F]N9R!N=6UB97(@;V8@9FEE;&1S
M+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG(&]F9G-E="`E9"!W:&EL
M92!R96%D:6YG(&$@5D93(&9I;&4N`%@M4F5F`%@U,#EV,R!"87-I8R!#;VYS
M=')A:6YT<P!8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J
M96-T($%L=&5R;F%T:79E($YA;64`6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT
M:69I97(`6#4P.78S(&5X=&5N<VEO;G,`65D`65E960!986AO;R$@;6%P`%EE
M87)L>0!996UE;@!997,`665S+"!)($%G<F5E`%EO=2!A<F4@:6X@5$585"!-
M3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!7
M65-)5UE'+@!9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H
M86X@)60@8FQO8VMS+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@
M8V%N;F]T(&AA=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA
M;64N`%EO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`
M66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F
M:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&AA
M=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED
M(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N
M86P@)RLG(&9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"X`
M66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N
M9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U
M(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N`%EO=2!M=7-T(&1E<V-R
M:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L
M96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@
M;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B
M92!D96QE=&5D+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE
M87(@;W5T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E
M+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M
M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@
M<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E
M(&$@;F5W(&-A=&5G;W)Y(&YA;64N`%EO=2!N965D('1O('!R;W9I9&4@86X@
M271A;&EA;B!P:&]N92!N=6UB97(`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I
M<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9
M;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E
M<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@
M;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL
M('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT
M:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S
M+B!)9B!Y;W4@=VES:"!T;R!U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R
M(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@875T:&5N=&EC
M871I;VX@8F%C:V5N9"X`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O
M97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@
M:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R
M(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E
M9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S
M96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D
M;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O
M97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R
M;VPO0V]M;6%N9"`K(%`@=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO
M;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9
M;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&QO
M9VEN(&AA<R!E>'!I<F5D+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z
M("5S`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U
M<F%T:6]N(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E
M;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@
M<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD
M(&QO9R!I;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D
M(&AA<R!E>'!I<F5D+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA
M`%IA:7)E`%IA;6)I80!::6UB86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X
M=%T`6U!R;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W
M(%%U;W1E9"!497AT("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?061M
M:6YI<W1R871I;VX`7T-,20!?1&%T851R964`7T1E;&5T92!2;W<`7T=R;W5P
M<P!?2&5L<`!?26UA9V4@4')O<&5R=&EE<RXN+@!?3&]G(&EN`%],;V<@;W5T
M`%]-;V1I9GD@3&EN:RXN+@!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V
M92!,:6YK+BXN`%]3971U<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`
M861D<F5S<R!B;V]K`&%D9')E<W-E92!U;FMN;W=N`&-A;&5N9&%R`&-A;&T`
M8V%N;F]T(&-R96%T92!O=71P=70@9FEL90!C86YN;W0@;W!E;B!I;G!U=`!C
M;&EC:R!H97)E`&-O;6UA;F0@;&EN92!U<V%G92!E<G)O<@!C;VYF:6=U<F%T
M:6]N(&5R<F]R`&-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<`9&%T82!F
M;W)M870@97)R;W(`961I=`!E;G1R>2!N;W0@9F]U;F0`9F%L;&EN9P!F:6QE
M`&9R;VT@=&AE("5S("@E<RD@870@)7,@)7,`9W5S=&EN9P!H.@!H:`!H;W-T
M(&YA;64@=6YK;F]W;@!I;6UE9&EA=&4`:6YL:6YE`&EN<'5T+V]U='!U="!E
M<G)O<@!I;G1E<FYA;"!S;V9T=V%R92!E<G)O<@!L:6YE<UT`;6MI<V]F<R!E
M<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N`&UM`&YA;64`;F]T(&EM
M<&QE;65N=&5D`&YO="!Y970@:6UP;&5M96YT960`;F]T97!A9`!P97)C96YT
M`'!E<FUI<W-I;VX@9&5N:65D`'!I>&5L<P!R96UO=&4@97)R;W(@:6X@<')O
M=&]C;VP`<FES:6YG`'-E<G9I8V4@=6YA=F%I;&%B;&4`<VAO=R!D:69F97)E
M;F-E<P!S;7,R96UA:6P@=FEA($A45%``<W,`<W1E861Y`'-Y<W1E;2!E<G)O
M<@!T87-K(&QI<W0`=&5M<&]R87)Y(&9A:6QU<F4`='EP92!T:&4@<&%S<W=O
M<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M960`=7-E<B!S96QE
M8W0`=D-A<F0`=SH`=V5A=&AE<BYC;VT`4')O:F5C="U)9"U697)S:6]N.B!(
M;W)D92`S+C$N,2UC=G,*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T
M<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#8M,#,M,3$@,3(Z
M,SDK,#$P,`I03RU2979I<VEO;BU$871E.B`R,#`V+3`S+3$Q(#$V.C4R*S`Q
M,#`*3&%S="U4<F%N<VQA=&]R.B!"<FEA;B!4<G5E;'-E;B`\:&]R9&4K:3$X
M;D!B<FEA;G1R=65L<V5N+F1K/@I,86YG=6%G92U496%M.B!$86YI<V@@/&DQ
M.&Y`;&ES=',N:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT
M+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,0I#;VYT96YT
M+51R86YS9F5R+45N8V]D:6YG.B`X8FET"E!L=7)A;"U&;W)M<SH@;G!L=7)A
M;',],CL@<&QU<F%L/2AN("$](#$I.PH`("@E<R!D86=E('-I9&5N*0`@*$%C
M8V5S<VME>2`E<RD`("AO;2`E<R!D86=E*0`@*&D@9&%G*0`@*&D@;6]R9V5N
M*0`@*&D@9^5R*0`@;65D(``B)7,B(&5R(&EK:V4@970@:V%T86QO9RX`(B5S
M(B!E<B!I;G1E="!G>6QD:6=T('9A;&<N`"(E<R(@97(@:6MK92!K;VYF:6=U
M<F5R970@:2!(;W)D97,@9F]R=&5G;F5L<V4N`"(E<R(@='+F+6]P8GEG9V5R
M(&EK:V4@9G5N9&5T+@`B)7,B(&)L978@=&EL9OAJ970@:2!G<G5P<&4M<WES
M=&5M970N`"(E<R(@8FQE=B!T:6QF^&IE="!T:6QL861E;'-E<RUS>7-T96UE
M="X`(B5S(B!B;&5V(&EK:V4@9&%N;F5T.B`E<RX`)2XR9DU"(&)R=6=T('5D
M(&%F("4N,F9-0B!T:6QL861T("@E+C)F)24I`"5D("5S(&]G("5S`"5D(&1A
M9V4@=&EL(&1I="!K;V1E;W)D('5D;/AB97(N`"5D+61A9W,@=61S:6=T`"5S
M("T@3F]T:71S`"5S(&9I;F=E<F%F=')Y:P`E<R!+0@`E<R!6961L:6=E:&]L
M9&5L<V4@+2!"96MRYF9T96QS90`E<R!O<'/F=&YI;F<`)7,@;W!S:W)I=FYI
M;F<`)7,@8G)U9W-B971I;F=E;'-E<@`E<R!E:W-I<W1E<F5R(&%L;&5R961E
M+@`E<R!V960@)7,@)7,`)7,@97(@<&%R870@=&EL(&%T('5D9OAR92!D92!V
M961L:6=E:&]L9&5L<V5S:&%N9&QI;F=E<BP@<V]M(&5R(&UA<FME<F5T(&YE
M9&5N9F]R+B`@4^9T(&AA:R!U9"!F;W(@9&4@:&%N9&QI;F=E<BP@<V]M(&1U
M(/AN<VME<B!U9&;X<G0@;G4N`"5S(&MRYG9E=``E<R!M:6YU='1E<@`E<R!I
M:VME(&9U;F1E="X`)7,@=&EL("5S(&%F("5S`"5S<R!A9')E<W-E:V%R=&]T
M96L`)7-S(&MA;&5N9&5R`"5S<R!N;W1E<V)L;VL`)7-S(&]P9V%V97(`)7,Z
M("5S`"5S.B!$96YN92!B97-K960@97(@;75L:6=V:7,@:6MK92!F<F$@9&5N
M('!E<G-O;BP@<V]M(&1E;B!HYG9D97(@870@=N9R92!F<F$N("!6YG(@=F%R
M<V]M(&UE9"!A="!F^&QG92!H96YV:7-N:6YG97(@96QL97(@9F]R<WEN92!A
M9G-E;F1E<F5N(&UE9"!P97)S;VYL:6=E(&EN9F]R;6%T:6]N97(N`"P@9&ES
M970@`"P@8FSF<V5N9&4@)7,@)7,`+"!S:W)I9G1E;F1E(&9R82`E<R!T:6P@
M)7,`+2T@=N9L9R`M+0`Q,BUT:6UE<G,@9F]R;6%T`#(T+71I;65R<R!F;W)M
M870`,C0@=&EM97(`/$9O<F5GY65N9&4@9&%G`$5N(&1A=&%B87-E+6)A8VME
M;F0@97(@:W+F=F5T(&9O<B!D96YN92!B;&]K+@!$97(@97(@;W!S=.5E="!E
M;B!G<F%V97)E;F1E(&9E:FP`16X@;V9F96YT;&EG(%!'4"UN^&=L92!E<B!K
M<N9V970@9F]R(&%T(&MR>7!T97)E(&5N(&)E<VME9"X`16X@;V9F96YT;&EG
M(%!'4"UN^&=L92!E<B!K<N9V970@9F]R(&%T('9E<FEF:6-E<F4@96X@<VEG
M;F5R970@8F5S:V5D+@!%;B!O9F9E;G1L:6<@4$=0+6[X9VQE+"!P<FEV870@
M4$=0+6[X9VQE(&]G(&5T(&SX<V5N(&5R(&MRYG9E="!F;W(@870@9&5K<GEP
M=&5R92!E;B!B97-K960N`$5N(&]F9F5N=&QI9R!01U`M;OAG;&4L('!R:79A
M="!01U`M;OAG;&4@;V<@970@;/AS96X@97(@:W+F=F5T+"!F;W(@870@<VEG
M;F5R92!E;B!B97-K960N`$5N(&]F9F5N=&QI9R!3+TU)344M;OAG;&4L('!R
M:79A="!3+TU)344M;OAG;&4@;V<@970@;/AS96X@97(@:W+F=F5T+"!F;W(@
M870@9&5K<GEP=&5R92!E;B!B97-K960N`$5N(&]F9F5N=&QI9R!3+TU)344M
M;OAG;&4L('!E<G-O;FQI9R!3+TU)344M;OAG;&4@;V<@;/AS96X@97(@:W+F
M=F5T(&9O<B!A="!S:6=N97)E(&5N(&)E<VME9"X`16X@;V9F96YT;&EG(%,O
M34E-12UN^&=L92!E<B!K<N9V970@9F]R(&%T(&MR>7!T97)E(&5N(&)E<VME
M9"X`1F]R;6ED9&%G(%-K>65T`$9O<FUI9&1A9R!,970@4F5G;@!&;W)M:61D
M86<@4F5G;@!&;W)M:61D86<@0GEG97(`1F]R;6ED9&%G(%-N96)Y9V5R`$%-
M+U!-`$%022!)1`!/;2!D96YN92!S:W)I8F5N=`!/;2XN+@!!8G-B;W1T;VT`
M06)S;6ED9&QE`$%D9V%N9R!NYF=T970@=F5D(&1A;FYE;'-E(&%F(%9&4RUK
M871A;&]G+@!!9&=A;F<@;N9G=&5T('9E9"!D86YN96QS92!A9B!61E,M9FEL
M+@!+;VYT;RUI;F9O<FUA=&EO;@!+;VYT;V5N<R!K;V1E;W)D`$MO;G1O(&EN
M9&5F<F]S<V5T+@!+;VYT97)I;F<N`%1I;&;X:@!4:6QF^&H@=6YD97)G<G5P
M<&4`5&EL9OAJ('5N9&5R;W)D;F5D92!T:6QL861E;'-E`%1I;&;X:B!H97(Z
M`%1I;&;X:B!N>2!G<G5P<&4`5&EL9OAJ(&YY(')E='1I9VAE9`!4:6QF^&H@
M=6YD97)G<G5P<&4@=&EL("(E<R(`5&EL9OAJ(&5N('5N9&5R<F5T=&EG:&5D
M('1I;"`B)7,B`$]P<F5T=&4@96X@;GD@8G)U9V5R.@!4:6QF^&H@:V]L;VYN
M90!4:6QF^&H@;GEE(&UE9&QE;6UE<@!/<')E="!P87(`5&EL9OAJ("5S+6UE
M;G5E;B!S;VT@96X@36]Z:6QL82!3:61E8F%R`%1I;&;X:B!T:6P@861R97-S
M96MA<G1O=&5K.@!4:6QF^&H@=&EL(&UI="!A9')E<W-E:V%R=&]T96L`3W!R
M970@8G)U9V5R`$AA<B!T:6QF^&IE="`B)7,B('1I;"!S>7-T96UE="P@;65N
M(&MU;FYE(&EK:V4@=&EL9OAJ92!E:W-T<F$@;W!S:W)I=FYI;F=S:6YF;W)M
M871I;VXZ("5S+@!4:6QF^&IE="`B)7,B('1I;"!S>7-T96UE="X@1'4@:V%N
M(&QO9V=E(&EN9"!N=2X`3W!R971T96QS92!A9B!B<G5G97)E(&5R('-LY65T
M(&9R80!!9')E<W-E`$%D<F5S<V5K87)T;W1E:P!!9&UI;FES='+I<B`M(&EN
M9'-T:6P@=&EL;&%D96QS97(@9F]R(&%N9')E(&)R=6=E<F4`061M:6YI<W1R
M871I;VX`4F5K;&%M97(`069G:&%N:7-T86X`06QB86YI96X`06QG97)I970`
M2V%L9&5N879N`$]P<W1I;&QI;F<`2G5S=&5R:6YG.@!!;&QE`$%L;&4@YF=T
M961E(&)R=6=E<F4`06QL92!G<G5P<&5R`$%L;&4@=&EL;&%D96QS97(`06QL
M92!F:7)E('-I9&5R`%1I;&QA9"!M=6QT:7!L92!A9')E<W-E<@!4:6QL860@
M86YG:79E;'-E(&%F(&]R9&YE="!L:7-T971Y<&4_`$5K<VES=&5R97(@86QL
M97)E9&4`06QT97)N871I=B!)35-0+6QO9VEN`$%L=&5R;F%T:78@24U34"UK
M;V1E;W)D`$%L=&5R;F%T:78@24U34"UB<G5G97)N879N`$1I;B!E+6UA:6PM
M861R97-S90!!;'1E<FYA=&EV92!S:V%B96QO;F5R`$%L=&5R;F%T:78@=&5K
M<W0Z`$%M97)I:V%N<VL@4V%M;V$`1&5N(';F<F1I+"!D97(@8FQE=B!A;F=I
M=F5T+"!V87(@:6MK92!G>6QD:6<N`$1E<B!E<B!O<'-TY65T(&5N('5K96YD
M="!F96IL+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UI<V5R96YD
M92!P<F]X>0!"97-V87(`4WED<&]L96X`06YT:6=U82!A;F0@0F%R8G5D80!!
M<'!L:6MA=&EO;@!!<'!L:6MA=&EO;G-L:7-T90!!<'!L:6MA=&EO;B!E<B!P
M87)A="X`4.5F^'(@=6YD97)D96QI;F=E<@!';V1K96YD`$-I<FMA<W3X<G)E
M;'-E`$%P<FEL`$%R86)I<VL@*%=I;F1O=W,M,3(U-BD`07)K:78M9FEL<W3X
M<G)E;'-E`$%R:VEV;F%V;@!%<B!D=2!S:6MK97(@<.4L(&%T(&1U('9I;"!S
M;&5T=&4@;W!S:W)I=FYI;F=S86YM;V1N:6YG96X@9F]R("5S(#\`17(@9'4@
M<VEK:V5R+"!A="!D=2#X;G-K97(@870@<VQE='1E("(E<R(@;V<@96YH=F5R
M('5N9&5R9W)U<'!E/P!!<F=E;G1I;F$`07)M96YI96X`07)M96YS:R`H05)-
M4T-)22TX*0!+=6YS=`!!<G5B80!!<V-E;G-I;V[X96X`05-#24D@07)T`$%S
M:6%T:7-K+W-T:6QL96AA=G-R96=I;VX`4W#X<F<@969T97(@8F5K<N9F=&5L
M<V4@9OAR('5D9OAR96QS92!A9B!V961L:6=E:&]L9&5L<V5S:&%N9&QI;F=E
M<C\`5&EL9&5L(&MO;&]N;F5R`$9O<G/X9R!PY2!A="!S;&5T=&4@96X@:6MK
M92UE:W-I<W1E<F5N9&4@9W)U<'!E+@!&;W)S^&<@<.4@870@<VQE='1E(&5N
M(&EK:V4M96MS:7-T97)E;F1E('1I;&QA9&5L<V4N`$9O<G/X9R!PY2!A="#F
M;F1R92!E;B!I:VME+65K<VES=&5R96YD92!T:6QL861E;'-E+@!&;W)S^&<@
M<.4@870@YFYD<F4@96X@:6MK92UE:W-I<W1E<F5N9&4@9&5L:6YG+@!!='1R
M:6)U='1E<@!!=6=U<W0`075S=')A;&EE;@#8<W1R:6<`075T:%]C>7)S<6PZ
M($MRYG9E="!)34%0+75D=FED9&5L<V4@:6MK92!F=6YD970N`$%U=&A?8WER
M=7,Z($)A8VME;F0@:&%R(&EK:V4@9&4@;OAD=F5N9&EG92!E=FYE<BX`075T
M:%]C>7)U<SH@2W+F=F5T($E-05`M=61V:61D96QS92!I:VME(&9U;F1E="X`
M075T:%]F='`Z($MRYG9E="!&5%`M=61V:61D96QS92!I:VME(&9U;F1E="X@
M3W9E<G/F="!02%`@;65D("TM96YA8FQE+69T<"UF;&%G970N`$%U=&A?:6UA
M<#H@2W+F=F5T($E-05`M=61V:61D96QS92!I:VME(&9U;F1E="X`075T:%]K
M<F(U.B!+<N9V970@2U)"-2UU9'9I9&1E;'-E(&EK:V4@9G5N9&5T+@!!=71H
M7VQD87`Z(%1I;&;X:F5L<V4@8G)U9V5R92!E<B!I:VME('5N9&5R<W3X='1E
M="!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%-L971N:6YG(&%F
M(&)R=6=E<F4@97(@:6MK92!U;F1E<G-T^'1T970@=F5D($%C=&EV92!$:7)E
M8W1O<GD`075T:%]L9&%P.B!+<N9V970@3$1!4"UU9'9I9&1E;'-E(&EK:V4@
M9G5N9&5T+@!!=71H7VQD87`Z($MU;FYE(&EK:V4@=&EL9OAJ92!B<G5G97(@
M)7,N(%-E<G9E<F5N('-A9V1E.B``075T:%]L9&%P.B!+86X@:6MK92!S;&5T
M=&4@8G)U9V5R("5S`$%U=&A?;&1A<#H@2V%N(&EK:V4@;W!D871E<F4@8G)U
M9V5R("5S`$%U=&A?;&1A<#H@3W!D871E<FEN9R!A9B!B<G5G97)E(&5R(&EK
M:V4@=6YD97)S=/AT=&5T('9E9"!!8W1I=F4@1&ER96-T;W)Y+@!!=71H7VUC
M86PZ($MRYG9E="!-0T%,+75D=FED9&5L<V4@:6MK92!F=6YD970N`$%U=&A?
M<VUB875T:#H@2W+F=F5T(%--0D%55$@M=61V:61D96QS92!I:VME(&9U;F1E
M="X`QF=T;FEN9R!V960@24U!4"US97)V97(@9F5J;&5D92X`QF=T;FEN9R!F
M96IL961E`,9G=&YI;F<@9F5J;&5D92X@)7,`QF=T;FEN9R!A9G9I<W0@868@
M4D%$2553+7-E<G9E<BX`QF=T;FEN9R!O=F5R9F]R($944"US97)V97(@9F5J
M;&5D92X`QF=T;FEN9R!O=F5R9F]R(%--0BUS97)V97(@9F5J;&5D92X`1F5L
M=&5R('1I;"!RY61I9VAE9#H`07-E<F)A:61J86X`0D]&2"UU;F1S:WEL9&YI
M;F=E<@!"86-K9W)O=6YD`$)A9V=R=6YD<V9A<G9E`$3E<FQI9W0@:V5R8F5R
M;W,M:V]D96]R9"X`1.5R;&EG="!K97)B97)O<RUB<G5G97)N879N+@!"86AA
M;6$`0F%H<F%I;@!"86QT:6MU;2`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`
M0F%R8F%D;W,`0F%S:7,@9W)A9FEK:V%T86QO9R`B)7,B(&EK:V4@9G5N9&5T
M+@!"87-I<VQI;FEE`$AV:61E<G5S;&%N9`!"96QG:65N`$)E;&EZ90!"96YI
M;@!"97)M=61A`$)H=71A;@!&^&1S96QS9&%G`$)L;VL@(B5S(B!A9B!A<'!L
M:6MA=&EO;B`B)7,B(&EK:V4@9G5N9&5T+@!";&]K+65G96YS:V%B97(`0FQO
M:W1Y<&4`1F5D`$)O;&EV:65N`$)O9VWF<FME<@!286YD`%)A;6UE='EK:V5L
M<V4Z`%)A;F1E`$)O<VYI96X@;V<@2&5R>F5G;W9I;F$`0F5G9V4`0F]T<W9A
M;F$`0G5N9`!";W5V973X96X`0G)A<VEL:65N`$)R:71I<VLM26YD:65N($]C
M96%N;VURY61E`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEE;@!0=6YK=&QI
M<W1E`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`0U),(&1I<W1R:6)U
M=&EO;G-S=&5D97(`0V5L;&4M96=E;G-K86)E<BXN+@!);FET:6%L:7-E<FEN
M9R!A9B!M:61L97)T:61I9W0@;&%G97(@:6MK92!FYG)D:6=G:F]R="X`2V%L
M96YD97(`5FEN9'-T:6QL90!+86UB;V1I80!#86UE<F]U;@!+86X@:6MK92!N
M=6QS=&EL;&4@:V]D96]R9"!A=71O;6%T:7-K.R!K;VYT86MT(&1I;B!A9&UI
M;FES=')A=&]R+@!+86X@:6MK92!S:W)I=F4@=&EL(&9I;"`B)7,B`$MA;B!I
M:VME(&CE;F1T97)E(&5K<W1E<FYE('-E<W-I;VYS:.5N9'1A9RX`2V%N(&EK
M:V4@9F]R8FEN9&4@=&EL($E-05`@<V5R=F5R+B`E<P!+86X@:6MK92#E8FYE
M(&9I;"`B)7,B+@!#86YA9&$`06YN=6QL97(`069B<GED(')E<&]R=&5R:6YG
M(&%F('!R;V)L96T`2V%N(&EK:V4@<VQE='1E(&9I;"`B)7,B+@!+86X@:6MK
M92!F:6YD92!E="!M:61L97)T:61I9W0@:V%T86QO9RX`2V%N(&EK:V4@9F]R
M='/F='1E('5D96X@)W1A<F=E=$9I;&4G+7!A<F%M971R96XN`$MA;B!I:VME
M(&9J97)N92!K871A;&]G("(E<R(N`$MA;B!I:VME(&9J97)N92P@)60@8OAR
M;B!E:W-I<W1E<F5R+@!+86X@:6MK92!O;69O<F1E;&4[(&%N=&%L;&5T(&%F
M('!U;FMT97(@86YG:79E="!T:6P@;VUF;W)D96QI;F<@<W9A<F5R(&EK:V4@
M=&EL(&1E="!O<&)E=F%R961E(&%N=&%L+@!+86X@:6MK92!D:7)I9V5R92!B
M97-K960@=&EL(&%N9VEV;F4@;G5M;65R+@!+87`@5F5R9&4`0FEL;&5D=&5K
M<W0`561B>61E<@!+871E9V]R:65R(&]G($WF<FME<@!#87EM86[X97)N90!-
M;V)I;`!#96QL92UE9V5N<VMA8F5R`$-E;&QE9F]R<FEN9SH`0V5L;&4M96=E
M;G-K86)E<@!#96QL92UM96QL96UR=6TZ`$UO8FEL=&5L969O;@!+96QT:7-K
M("A)4T\M.#@U.2TQ-"D`0V5N='+I<@!$96X@8V5N=')A;&%F<FEK86YS:V4@
M4F5P=6)L:6L`0V5N=')A;"UE=7)O<.9I<VL@*$E33RTX.#4Y+3(I`$-E<G1I
M9FEK870M9&5T86QJ97(`0V5R=&EF:6MA="UE:F5R`$-E<G1I9FEK870M<&]L
M:71I:VME<@!48VAA9`#&;F1R90#&;F1R92!D:70@:V]D96]R9`!(97(@:V%N
M(&1U(.9N9')E(&1E="!N879N(&]G(&1E;B!A9')E<W-E+"!S;VT@86YD<F4@
M<V5R+"!NY7(@9&4@;.9S97(@;V<@<W9A<F5R('#E(&1I;F4@92UM86EL+@!+
M;V1E;W)D<^9N9')I;F<@97(@:6MK92!U;F1E<G-T^'1T970@868@9&5N(&YU
M=N9R96YD92!O<'/F=&YI;F<N("!+;VYT86MT(&1I;B!A9&UI;FES=')A=&]R
M+@!496=N`$AA:R!L:6YK(&%F+BXN`$-H:6QE`$MI;F$`4VEM<&QI9FEC97)E
M="!K:6YE<VES:R`H1T(R,S$R*0!4<F%D:71I;VYE;'0@:VEN97-I<VL@*$)I
M9S4I`%;F;&<@87!P;&EK871I;VXZ`%;F;&<@970@:V]D96]R9`!6YFQG(&5T
M(&)R=6=E<FYA=FX`5N9L9R!H=F]R9&%N(&1A=&]E<B!S:V%L('9I<V5S.@!6
MYFQG(&QI<W1E+7-T:6P@*&9O<B!O<F1N961E(&QI<W1E<BD`2G5L9?AE;@!+
M;&%S<V5D969I;FET:6]N(&%F("5S(&EK:V4@9G5N9&5T+@!+;&%R=`!&:F5R
M;B!-4T]F9FEC92UO<&WF<FMN:6YG97(`3G5L<W1I;"!F;W)E<W#X<F=S96P`
M4F5N<R!B<G5G97(@=60Z("5S`$YU;'-T:6P@8G)U9V5R`%9I<VL@8G)U9V5R
M9&%T82!U9`!396X@;W!K;&%R:6YG`$ML:6L@9F]R(&%T(&9O<G1SYG1T90!#
M;&EC:V%T96QL('9I82!(5%10`$QU:R!V:6YD=64`4VMY97(`4VMY97(@=&ED
M;&EG=`!3:WEE=`!#;V-O<R`H2V5E;&EN9RD@V&5R;F4`1F]L9"!S:61E<&%N
M96P@<V%M;65N`%-A;6UE;F9O;&1E9&4@<F%N9&4`2V]L=6UB:65N`$9A<G9E
M`$9A<G9E=N9L9V5R`$9A<G9E=F%L9P!+;VQS.@!+;VQO;FYE=&ET;&5R`%1E
M9VYE<V5R:65R`$MO;6UA;F1O`$MO;6UA;F1O;&EN:64`2V]M;65N=&%R`$-O
M;6UO;B!.86UE`$-O;6]R97)N90!&:7)M80!#;VUP=71E<F4`1F]R:&]L9`!"
M971I;F=E;'-E<@!+;VYF:6=U<F%T:6]N<V9O<G-K96QL90!+;VYF:6=U<F%T
M:6]N('1I;"!S>6YK<F]N:7-E<FEN9R!M960@4$1!97(L(%-M87)T<&AO;F5S
M(&]G($]U=&QO;VLN`$MO;F9I9W5R871I;VYE;B!E<B!F;W+F;&1E="X`2V]N
M9FEG=7+I<B`E<P!"96MRYF9T(&MO9&5O<F0`2V]N9V\`2V]N9V\L($1E;B!D
M96UO:W)A=&ES:V4@<F5P=6)L:6L`1F]R8FEN9&5L<V4@;6ES;'EK:V5D97,N
M`$9O<F)I;F1E;'-E(&UI<VQY:VME9&5S.B``1F]R8FEN9&5L<V4@=&EL(&]F
M9F5N=&QI9R!N^&=L97-E<G9E<B!NYF=T970N`$9O<F)I;F1E;'-E('1I;"!O
M9F9E;G1L:6<@;OAG;&5S97)V97(@;N9G=&5T+B#%<G-A9SH@)7,@*"5S*0!&
M;W)B:6YD96QS92!T:6P@1E10+7-E<G9E<B!M:7-L>6MK961E<RX`2V]N=&%K
M=&5R`$MO;G1A:W1E<B!B;&5V('1I;&;X:F5T('1I;"!D:70@861R97-S96MA
M<G1O=&5K970`26YD:&]L9'-T>7!E(&%F(&MO;7!R:6UE<F5T(&9I;#H@`$EN
M9&AO;&0@868@(B5S(@!&;W)T<^9T`$-O;VL@27-L86YD<P!3;>5K86=E`$MO
M<&EE<@!+;W!I97)I;F<@;6ES;'EK:V5D97,Z("5S`$MO<&GI<B!M87)K97)I
M;F<`1V5B>7(@240`0V]S=&$@4FEC80!%;&9E;F)E;G-K>7-T96X`2W5N;F4@
M:6MK92!01U`M:W)Y<'3I<F4@8F5S:V5D.B``2W5N;F4@:6MK92!01U`M<VEG
M;NER92!B97-K960Z(`!+=6YN92!I:VME(%,O34E-12UK<GEP=&5R92!B97-K
M960N`$MU;FYE(&EK:V4@4R]-24U%+7-I9V[I<F4@8F5S:V5D+@!+=6YN92!I
M:VME('1I;&;X:F4@:V]N=&%K="X@)7,`2W5N;F4@:6MK92!K;V)L92!T:6P@
M3$1!4"US97)V97(N`$MU;FYE(&EK:V4@:V]N=')O;&QE<B!B86QA;F-E+B`E
M<P!+=6YN92!I:VME(&9O<F)I;F1E('1I;"!,1$%0+7-E<G9E<BX`2W5N;F4@
M:6MK92!F;W)B:6YD92!T:6P@<V5R=F5R("(E<R(@=F5D(&)R=6<@868@1E10
M.B`E<P!+=6YN92!I:VME(&]P<F5T=&4@9&ES=')I8G5T:6]N<VQI<W1E+B`E
M<P!+=6YN92!I:VME(&1E:W)Y<'1E<F4@4$=0+61A=&$Z(`!+=6YN92!I:VME
M(&1E:W)Y<'1E<F4@4R]-24U%+61A=&$N`$MU;FYE(&EK:V4@<VQE='1E(&MO
M;G1A:W0N("5S`$MU;FYE(&EK:V4@<VQE='1E(&1I<W1R:6)U=&EO;G-L:7-T
M92X@)7,`2W5N;F4@:6MK92!S;&5T=&4@/&5M/G-C<FEP=#PO96T^("(E<R(@
M=&EL(&]P9W)A9&5R:6YG(&%F(&]P<^9T;FEN9RX`2W5N;F4@:6MK92!B97-T
M96UM92!M;V1T86=E<F5N<R!E+6UA:6PM861R97-S92X`2W5N;F4@:6MK92!H
M96YT92!H96QE(&%D<F5S<V5K87)T;W1E:RX`2W5N;F4@:6MK92!H96YT92!H
M96QE(&1I<W1R:6)U=&EO;G-L:7-T92X`2W5N;F4@:6MK92!H96YT92!F=6QD
M<W3F;F1I9R!F;W)T96=N96QS92!O=F5R(&1I<W1R:6)U=&EO;G-L:7-T97(N
M`$MU;FYE(&EK:V4@:&5N=&4@<W1R871E9VD@(B5S(BX`2W5N;F4@:6MK92!M
M:V1I<B`B)7,B+@!+=6YN92!I:VME(&AE;G1E(&]F9F5N=&QI9R!N^&=L92!F
M<F$@;OAG;&5S97)V97(N`$MU;FYE(&EK:V4@Y6)N92`B)7,B(&9O<B!S:W)I
M=FYI;F<N`$MU;FYE(&EK:V4@Y6)N92`E<RX`2W5N;F4@:6MK92#E8FYE(&UO
M9'5L('1I;"!V961L:6=E:&]L9&5L<V4@)7,`2W5N;F4@:6MK92#E8FYE(&MA
M=&%L;V<@(B5S(BX`2W5N;F4@:6MK92!NY2!,1$%0+7-E<G9E<F5N+@!+=6YN
M92!I:VME(&SF<V4@)7,N`$MU;FYE(&EK:V4@;G5L<W1I;&QE(&MO9&5O<F1E
M="!F;W(@9&5N(&%N;6]D961E(&)R=6=E<BX@($YO9VQE(&5L;&5R(&%L;&4@
M9&5T86QJ97(@97(@=6MO<G)E:W1E+B!0<OAV(&EG96X@96QL97(@:V]N=&%K
M="!D:6X@861M:6YI<W1R871O<BP@:'9I<R!D=2!H87(@8F5H;W8@9F]R('ED
M97)L:6=E<F4@:&KF;'`N`$MU;FYE(&EK:V4@:&5N=&4@04-,`$MU;FYE(&EK
M:V4@:&5N=&4@861R97-S96MA<G1O=&5K970N("5S`$MU;FYE(&EK:V4@:&5N
M=&4@9&ES=')I8G5T:6]N<VQI<W1E+B`E<P!+=6YN92!I:VME(&AE;G1E(&1I
M<W1R:6)U=&EO;G-L:7-T97(N("5S`$MU;FYE(&EK:V4@:&5N=&4@<V5R=F5R
M<R!E=FYE<@!+=6YN92!I:VME(&=E;F1A;FYE(&MO;F9I9W5R871I;VXN`$MU
M;FYE(&EK:V4@<FUD:7(@(B5S(BX`2W5N;F4@:6MK92!G96UM92`E<RUK;VYF
M:6=U<F%T:6]N`$MU;FYE(&EK:V4@9V5M;64@96X@8F%C:W5P+6MO;F9I9W5R
M871I;VXN`$MU;FYE(&EK:V4@9V5M;64@96X@8F%C:W5P+6MO;F9I9W5R871I
M;VXZ("5S`$MU;FYE(&EK:V4@9V5M;64@<V-R:7!T('1I;"!O<&=R861E<FEN
M9R!A9B!O<'/F=&YI;F<@=&EL.B`B)7,B+@!+=6YN92!I:VME(&=E;6UE(&)A
M8VMU<"UK;VYF:6=U<F%T:6]N<V9I;&5N("5S+@!+=6YN92!I:VME(&=E;6UE
M(&MO;F9I9W5R871I;VYS9FEL96X@)7,N($1U(&MA;B!E;G1E;B!A;G9E;F1E
M(&5N(&%F(&UU;&EG:&5D97)N92!F;W(@870@9V5M;64@:V]D96X@=&EL8F%G
M92!PY2`E<R!E;&QE<B!M86YU96QT(&MO<&EE<F4@:V]D96X@;F5D96YF;W(@
M=&EL("5S+@!+=6YN92!I:VME('/X9V4@3$1!4"US97)V97)E;BX`2W5N;F4@
M:6MK92`\96T^=6YL:6YK/"]E;3X@(B5S(BX`2W5N;F4@:6MK92!O<&1A=&5R
M92!K;VYT86MT+B`E<P!+=6YN92!I:VME(&]P9&%T97)E(&1I<W1R:6)U=&EO
M;G-L:7-T92X@)7,`2W5N;F4@:6MK92!S:W)I=F4@:V]N9FEG=7)A=&EO;B!F
M;W(@(B5S(CH@)7,`2W5N;F4@:6MK92!F:6YD92!-;WII;&QA(%-I9&5B87(N
M($9O<G9I<R!D:6<@;VT@870@<VED96)A<F5N(&5R(.5B96XN`$MU;FYE(&EK
M:V4@9VEV92!B<G5G97(@(B5S(B!F^&QG96YD92!R971T:6=H961E<B!T:6P@
M;6%P<&5N("(E<R(Z("5S`$]P=&%L="!T96MS=`!,86YD`$MU<G-E<@!/<')E
M=`!/<')E="!E;B!H96YV:7-N:6YG`$]P<F5T(&5N(&YY`$]P<F5T('5N9&5R
M;6%P<&4`4VMA8F5R<R!R971T:6=H961E<@!+<F5D:71K;W)T+6YU;6UE<@!+
M<F]A=&EE;@!#=6)A`$YU=N9R96YD92`T(&9A<V5R`$EN9&5VYG)E;F1E('-E
M<W-I;VX`06MT=65L('1I9`!.=7;F<F5N9&4@55),(&5R`$YU=N9R96YD92!B
M<G5G97)E`$%K='5E;'0@=F5J<@!.=7;F<F5N9&4@=F5J<CH@`$%K='5E;"!S
M=&EL`%1I;'!A<R!O<&=A=F5R+"!D97(@8FQI=F5R('5D9OAR="P@;N5R(&1U
M(&QO9V=E<B!I;F0@:2`E<RX`2VQI<`!+;&EP('9A;&<`0WEP97)N`$MY<FEL
M;&ES:R`H2T])."U2*0!+>7)I;&QI<VL@*%=I;F1O=W,M,3(U,2D`2WER:6QL
M:7-K+U5K<F%I;G-K("A+3TDX+54I`%1J96MK:65T`$1$`$133B`H<V5E(&AT
M='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N
M9&(N:6YT<F\M9'-N+G!H<"D`1&%G;&EG`$1A=&%4<F5E('-T:69I;F1E<@!$
M871A8F%S92UO<'-L86<`1&%T;P!-;V1T86=E;'-E<V1A=&\`1&%T;W9A;&<`
M1&%G`%-L970@:V]L;VYN90!$96-E;6)E<@!$96-I;6%L=&%L`$UI;F1S:R!I
M;F1R>6MN:6YG`%-T86YD87)D`%-T86YD87)D9F%R=F4`4W1A;F1A<F0M:61E
M;G1I=&5T`%-T86YD87)D+7-K86P`1&5F:6YI=&EO;F5R`%-L970`4VQE="!C
M96QL90!3;&5T(&=R=7!P90!3;&5T(&QO9V)O9P!3;&5T('1I;&QA9&5L<V5R
M`$9J97)N(&]G('5D<VQE="!B97-K961E<@!3;&5T(&-E;&QE`%-L970@:V]L
M;VYN90!3;&5T(&5K<VES=&5R96YD92P@86QT97)N871I=F4@<VMA8F5L;VX`
M4VQE="!B97-K961E<@!3;&5T('1I;&QA9&5L<V5R(&9O<B`B)7,B`%-L970@
M=&EL;&%D96QS97(@9F]R("(E<R(@;V<@86QL92!U;F1E<F]R9&YE9&4@=&EL
M;&%D96QS97(_`%-L970@<N9K:V4`4VQE="!V86QG=&4@:61E;G1I=&5T`%-L
M970@=6YD97)M87!P97(`4VQE="!D96X@86MT=65L;&4@:V]L;VYN90!3;&5T
M(&1E;B!A:W1U96QL92!RYFMK90!/<&=R861E<FEN9W-S8W)I<'0@(B5S(B!S
M;&5T=&5T+@!,979E<FEN9W-T:61S<'5N:W0`1&%N;6%R:P!"97-K<FEV('!R
M;V)L96UE=`!"97-K<FEV96QS90!$971A;&IE<B`H;V=SY2!I($AO<F1E)W,@
M;&]G9FEL*3H`1&5T86QJ97(@97(@<VMR979E="!T:6P@;&]G8F]G96X@868@
M:&5N<WEN('1I;"!A9&UI;FES=')A=&]R96XN`%5D=FEK;&EN9P!$=6=P=6YK
M=`!$=6=P=6YK="!F;W(@<VED<W1E('1I;64Z(`!$=6=P=6YK=#H@`%)E=&YI
M;F<@=F5N<W1R92!T:6P@:/AJ<F4`4F5T;FEN9R!H^&IR92!T:6P@=F5N<W1R
M90!+871A;&]G`%9I<R!T:60@;65D(#(T('1I;65R/P!);F1S=&EL;&EN9V5R
M(&9O<B!V:7-N:6YG`%9I<R!U9&1Y8F5N9&4@=F5J<G5D<VEG=`!6:7,@=F5J
M<G5D<VEG="`H5$%&*0!6:7-N:6YG<V9O<FUA=`!/=F5R9')A9V5L<V5S;F]T
M:71S`$1J:6)O=71I`$9O<G1R>60@<VQE=&YI;F<`1'4@;>4@:6MK92!K86QD
M92!M86EN=&5N86YC92YP:'`@9&ER96MT90!);F1E:&]L9&5R(&1E;B!F^')S
M=&4@<N9K:V4@9F5L=&YA=FYE/R!(=FES(&IA+"!M87)KZ7(@9&5N;F4@8F]K
M<SH`1&5N(&1O;6EN:6MA;G-K92!297!U8FQI:P!$96X@9&]M:6YI:V%N<VME
M(%)E<'5B;&EK`$AA<B!D=2!I:VME(&YO9V5N(&MO;G1O/R!-96QD(&1I9R!T
M:6PN`$AE;G0`2&5N="`E<P!(96YT(&=E;F5R97)E="!K;VYF:6=U<F%T:6]N
M(&YE9"!S;VT@4$A0+7-C<FEP="X`4G5L;&5G87)D:6XM;&ES=&4`365D:6MA
M;65N=&5R`$4M;6%I;`!%36%I;"UT:6PM4TU3(&=A=&5W87DM9')I=F5R+"!F
M;W(@;W!E<F%T^')E<BP@<V]M('5D8GED97(@9&5N;F4@<V5R=FEC92X`15)2
M`$5Q=6%D;W(`4F5D:6=E<@#&;F1R92!B;&]K`,9N9')E(&=R=7!P90#&;F1R
M92!T:6QL861E;'-E`,9N9')E('1I;&QA9&5L<V5R`,9N9')E('1I;&QA9&5L
M<V5R(&9O<B`E<P#&;F1R92!V86QG(&9O<CH`QFYD<F4@=&EL;&%D96QS97(@
M9F]R("(E<R(`QFYD<F4@=&EL;&%D96QS97(@9F]R("5S`%5D9&%N;F5L<V4`
MQF=Y<'1E;@!%;"!386QV861O<@!%;&5M96YT+BXN`$5M`&5-86EL`&4M;6%I
M;"UA9')E<W-E`$4M;6%I;"UA9')E<W-E<B!S:V%L('!A<W-E+@!%+6UA:6P@
M;65D(&)E:W+F9G1E;'-E`$5M86EL+71O+5--4R!'871E=V%Y`%-M:6QE>7,`
M5&]M(&)E<VME9"X`26YT970@<F5S=6QT870N`%1O;70@=61T<GEK`$%K=&EV
MZ7(@:6YD<^9T=&5L<V4@868@8FEL;&5D97(@9G)A($9O=&]G86QL97)I97(@
M:2!T96MS=#\`06MT:7;I<B!H^&IR92UK;&EK(&-O;G1E>'0M;65N=3\`4VQU
M="WE<@!&;W)S=/AR(&5D:71E<FEN9W-VYG)K=/AJ`$EN9'1A<W0@970@<VEK
M:V5R:&5D<W-P^')G<VWE;"P@<V]M(&1U('9I;"!B;&EV92!S<'5R9W0L(&[E
M<B!D=2!H87(@8G)U9R!F;W(@870@YFYD<F4@9&ET(&MO9&5O<F0L(&9X("=H
M=F%D(&5R(&1I="!KYFQE9'ER<R!N879N/R<Z`$EN9'1A<W0@55),('1I;"!B
M:6QL960@:&5R`$EN9'1A<W0@8F]G<W1A=F5R(&YE9&5N9F]R.@#&:W9A=&]R
M:6%L($=U:6YE80#&<FET<F5A`$9E:FP`1F5J;"!V960@9&%N;F5L<V4@868@
M8FQO:SH@)7,`1F5J;"!U;F1E<B!S;&5T;FEN9R!A9B!S>6YC+6CF9W1E.B`E
M<P!&96IL('5N9&5R('-L971N:6YG(&%F('-Y;F,@;&]G.B`E<P!&96IL('5N
M9&5R(&AE;G1N:6YG(&%F(&EN9&AO;&0Z("5S`$9E:FP@=6YD97(@;W!D871E
M<FEN9R!A9B!K;V1E;W)D.B`E<P!&96IL(&9O<F)U;F1E="!M960@92UP;W-T
M(&)E<VME9"X`1F5J;"!U;F1E<B!S:W)I=FYI;F<@868@(B5S(BX`17-T;&%N
M9`#&=&EO<&EE;@!%=&YI<VL`175R;W!A`$AV97(@:W9A<G1E<@!(=F5R="`R
M+B!M:6YU=`!(=F5R(&AA;'9E(&UI;G5T`$AV97(@-2X@;6EN=70`06QT:60@
M=F5D(&QO9VEN`$AV97(@:&%L=F4@=&EM90!(=F5R(&UI;G5T`$5K<V5M<&5L
M=N9R9&EE<CH`561F^'(`561V:60`1F]L9"!S:61E<&%N96P@=60`1F]R=F5N
M=&5D92`G*2<`1F]R=F5N=&5D92!R96YT(&]R9"!E;&QE<B!C:71E<F5T('/X
M9V5T97)M`$9O<N9L9&5L<V5S9&%T;P!%:W-P;VYE;G0`1D<M9F%R=F4`1E10
M+6QA9W)I;F<@868@;W!SYG1N:6YG`$MU;FYE(&EK:V4@YFYD<F4@:6YD<W1I
M;&QI;F=E<FYE+@!+=6YN92!I:VME(&;E(&9O<F)I;F1E;'-E('1I;"!,1$%0
M('-E<G9E<F5N+@!+=6YN92!I:VME(&9O<F)I;F1E('1I;"!334(M<V5R=F5R
M+@!&96IL('5N9&5R(&MO<&EE<FEN9R!F<F$@(B5S(BX`2W5N;F4@:6MK92!K
M;W!I97)E('1I;"`B)7,B+@!+=6YN92!I:VME(&5T86)L97)E(&YY(%-!4TPM
M9F]R8FEN9&5L<V4N`$MU;FYE(&EK:V4@9FQY='1E('1I;"`B)7,B+@!+=6YN
M92!I:VME(&AE;G1E.B`E<P!3;75K=`!&86QK;&%N9'/X97)N92`H36%L=FEN
M87,I`$;F<OAE<FYE`$3X9&5L:6<@9F5J;#H`1F%X`$9A:W-I;6EL97(`1F5B
M<G5A<@!&^&QE<P!&^&QE<SH@`$;E(&)Y9V5R`$;E('-N96)Y9V5R`$9E;'1M
M871R:6-E`$9I9VQE="!#05!40TA!`$9I9VQE="!S:W)I9G1S='EP;V=R869I
M`$9I:FD`1FEL`$%N=&%L(&9I;&5R.B`E<R!F:6P`06YT86P@9FEL97(Z("5S
M(&9I;&5R`$9I;&CE;F1T97)I;F<`1FEL;F%V;@!&:6QV86QG`$9I;&QA9W)I
M;F<`1FEL;&%G<FEN9R!I:VME('5N9&5R<W3X='1E="X`1FEL=')E`$9I;FQA
M;F0`1OAR<W1E(&AA;'9D96P`1OAR<W1E(&MV87)T86P`1FEK<^ER('-T^')R
M96QS97-F;W)H;VQD`$9L:7``1FQY9&5N9&4`5.5G90!-87!P92`E<R!E:W-I
M<W1E<F5R(&EK:V4`5'EP;V=R869I9F%R=F4`36%D`$9O<B!W96)P<F]G<F%M
M;65R+"!S;VT@:6MK92!U;F1E<G-T^'1T97(@8FEL;&5D97(`5F5J<G5D<VEG
M="`H5$%&*0!59'-I9W1S9&%G92`H8F5MYG)K(&%T(&1E;B!R971U<FYE<F4@
M=F5J<G5D<VEG="!V961R^')E<B!BY61E(&1A9R!O9R!N870[(&5T('-T;W)T
M(&%N=&%L(&AE<B!K86X@<F5S=6QT97)E(&D@96X@;65G970@8G)E9"!B;&]K
M*0!';&5M="!D:70@:V]D96]R9#\`1F]R;75L87)E<@!/<F1S<')O9P!%<&EG
M<F%M='EP90!%<&EG<F%M;65R`$5P:6=R86UM97(@,@!&;W)A`%9I9&5R97-E
M;F1E;'-E`$9R90!286UM97(`1G)A;FMR:6<`1G)A;FMR:6<L($UE=')O<&]L
M:71A;@!&<F%N<VL@1W5Y86YA`$9R86YS:R!0;VQY;F5S:65N`$9R86YS:V4@
M<WED;&EG92!497)R:71O<FEE<@!&<F$`1G)A`$9U;&0@8F5S:W)I=F5L<V4`
M1G5L9&WE;F4`1G5L9'0@;F%V;@!'86)O;@!'86QL97)I(&AV;W)F<F$@8FEL
M;&5D92!S:V%L('1A9V5S(&9R80!'86QL97)I.@!'86UB:6$`1V5N97+I<B`E
M<RUK;VYF:6=U<F%T:6]N`$=E;F5R97)E="!K;V1E`$=E;W)G:65N`%1Y<VML
M86YD`$=H86YA`$=I8G)A;'1A<@!&;W)N879N`$=R=6YD;.9G9V5N9&4@:6YD
M<W1I;&QI;F=E<@!59&;X<@!']F1E;`!';V]G;&4@36%P<P!';V]G;&4M<_AG
M;FEN9P!'<N5T;VYE<@!'<N9K96YL86YD`$=RYG-K("A)4T\M.#@U.2TW*0!'
M<OAN;&%N9`!'<F5N861A`$=R=7!P92UA9&UI;FES=')A=&EO;@!'<G5P<&5N
M879N92!MY2!I:VME(';F<F4@=&]M;64`1W)O=7!?;&1A<#H@2V%N(&EK:V4@
M=&EL9OAJ92!G<G5P<&4@)7,N(%-E<G9E<F5N(&UE;&1E<CH@`$=R;W5P7VQD
M87`Z($MA;B!I:VME('-L971T92!G<G5P<&4@)7,`1W)O=7!?;&1A<#H@2V%N
M(&EK:V4@;W!D871E<F4@9W)U<'!E("5S`$=R=7!P97(`1W5A9&5L;W5P90!'
M=6%M`$=U871A;6%L80!'=65R;G-E>0!'YG-T971I;&QA9&5L<V5R`$?F<W1E
M8F]G`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A
M(&[F9W1E<B!PY2!F96H@=FES(&%T('-L971T92!D96X@<VED<W1E(&-E;&QE
M(&D@<N9K:V4N`$A434Q!<F5A(&[F9W1E<B!PY2!F96H@=FES(&%T('-L971T
M92!D96X@<VED<W1E(&MO;&]N;F4@:2!T86)E;"X`2%1-3$%R96$@;N9G=&5R
M('#E(&9E:B!V:7,@870@<VQE='1E(&1E;B!S:61S=&4@<N9K:V4@:2!T86)E
M;"X`2%144"WF9W1N:6YG(&EK:V4@9G5N9&5T+@!(8>]T:0!(87-H+6%L9V]R
M:71M90!$:7,`5&]P=&5K<W0`3W9E<G-K<FEF=&5R`$AE87)D($ES;&%N9"!A
M;F0@36-$;VYA;&0@27-L86YD<P!+<F%F=&EG('1O<F1E;@!(96)R86ES:R`H
M25-/+3@X-3DM."U)*0!(^&ID90!(:N9L<`!(:N9L<"!T:6P@<F5D:6=E<FEN
M9W-VYG)K=/AJ`$AJYFQP97(`2&5M:7-FYG)E`$AE<B!E<B!S=&%R=&5N(&%F
M(&9I;&5N.@!(^&H`2&IE;0!(96QL:6=S^"`H5F%T:6MA;G-T871E;BD`2&IE
M;0!0<FEV870M861R97-S90!(:F5M;65K871A;&]G`%!R:79A="UT96QE9F]N
M`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@56=Y;&1I
M9R`E<R!834P@9&%T82!PY71R=69F970@:2!B97-K960@)7,`2&]R9&4O2V]L
M86(Z($EN9V5N(&)E<VME9"!S=F%R97(@=&EL(&]B:F5K="`E<P!(;W)D92]+
M;VQA8CH@26YT970@;V)J96MT(&%F('1Y<&4@)7,@9G5N9&5T(&D@8F5S:V5D
M("5S`$AO<F1E+TMO;&%B.B!3;&5T=&5D92`E<R`B)7,B`$AO<F1E+TMO;&%B
M.B!);G1E9W)A=&EO;G-M87-K:6YE;B!K<N9V97(@4$A0+75D=FED9&5L<V4@
M)V1O;7AM;"<`2&]R9&4O2V]L86(Z($MA;B!I:VME(&1A;FYE(&YY="!834PM
M='+F(&9O<B!O8FIE:W0@)7,`2&]R9&4O2V]L86(Z($MA;B!I:VME('-L971T
M92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@2V%N(&EK:V4@:6YD:&5N=&4@
M34E-12U)1"!F;W(@9&5L96X@868@='EP92`E<P!(;W)D92]+;VQA8CH@2V%N
M(&EK:V4@<WEN:W)O;FES97)E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!+
M86X@:6MK92!S>6YK<F]N:7-E<F4@9&5L:6YG97(Z("5S`$AO<F1E+TMO;&%B
M.B!5:V5N9'0@9&5L:6YG("(E<R(`5F%N9')E="!S=')E9P!686YD<F5T(&9O
M<@!686YD<F5T.@!(=F]R9&%N(&)A<B!D=2!D:6<@860@;65D(&%T(&AA=FYE
M(&AE<C\@*$EN9')A<'!O<G3I<B$I`$AV;W(@;6%N9V4@:V]L;VYN97(@^&YS
M:V5R(&1U(&%T('-A;6UE;FSF9V=E/P!(=F]R(&UA;F=E(&9E;'1E<B`H:V]L
M;VYN97(I(&5R(&1E<C\`2'9O<B!M86YG92!RYFMK97(@^&YS:V5R(&1U(&%T
M('-A;6UE;FSF9V=E/P!&=6=T:6=H960`1G5G=&EG:&5D.B``2'5M;W)I<W1E
M<@!5;F=A<FX`3W!R971T96QS92!A9B!)34%0+6UA<'!E(&9E:FQE9&4Z("5S
M`%-L971N:6YG(&%F($E-05`M;6%P<&4@9F5J;&5D93H@)7,`1&5F:6YE<FEN
M9R!A9B!K=F]T92!F;W(@24U!4"UM87!P92!F96IL961E.B`E<P!)4"UA9')E
M<W-E`$E0+6%D<F5S<V4@:6MK92!T:6QGYFYG96QI9V4N`$E0+6%D<F5S<V4@
M:6MK92!I;F1E;F9O<B!#2412+6)L;VLN`$E0(&QO8VMD;W=N('9I;VQA=&EO
M;BX`26YD<^9T('+F:VME(&;X<@!)<VQA;F0`2W5N(&EK;VYE<@!):V]N97(@
M9F]R("5S`$EK;VYE<B!M960@=&5K<W0`261E;G1I=&5T<VYA=FXZ`$AV:7,@
M9&5N(&EK:V4@=FES="!K;W)R96MT+"`E<R!F;W(@870@Y6)N92!D96X@:2!E
M="!N>70@=FEN9'5E+@!(=FES(&1U(&EK:V4@<V5R(&YO9V5N(&EK;VYE<B!V
M960@8G)U9R!A9B!);G1E<FYE="!%>'!L;W)E<B!S:V%L(&1U(&WE<VME(&AA
M:VME(&1E;FYE(&)O:W,@868@9F]R(&%T('-LY2!03D<M=')A;G-P87)E;G,@
M9G)A+@!(=FES(&1U('-E<B!D96YN92!B97-K960@:2!S=&5D970@9F]R(&5T
M(&)I;&QE9&4L('/E('9I;"!D=2!I:VME(&MU;FYE('-E(&1E="!I(&1I;B!N
M970M;.9S97(@969T97(@;W!LYF=N:6YG+@!":6QL960M9F]R:.5N9'-V:7-N
M:6YG.@!":6QL960M55),`$)I;&QE9"U54DPZ`$)I;&QE9&4@9G)A(&=A;&QE
M<FD`0FEL;&5D92!F<F$@9V%L;&5R:3H`0FEL;&5D+6]P;.9G;FEN9P!":6QL
M961E<@!);7!O<G1E<FEN9RP@=')I;B`E9`!);7!O<G1E<F5D92!F96QT97(Z
M("5S`$EM<&]R=&5R961E(&9E;'1E<CH`26YD<^9T('+F:VME(&5F=&5R`$9E
M:FQA9W1I9R!H86YD;&EN9W-K;V1E(&%N9VEV970N`%5K;W)R96MT(&)R=6=E
M<FYA=FX@;V<O96QL97(@:V]D96]R9"X`56MO<G)E:W0@8G)U9V5R;F%V;B!E
M;&QE<B!A;'1E<FYA=&EV(&%D<F5S<V4N(%!R^'8@:6=E;B!E;&QE<B!K;VYT
M86MT(&1I;B!A9&UI;FES=')A=&]R+"!H=FES(&1U(&AA<B!B<G5G(&9O<B!Y
M9&5R;&EG97)E(&AJYFQP+@!&;W+X9R!I;F1R>6MN:6YG`$EN9&EE;@!);F1I
M=FED=65L;&4@8G)U9V5R90!);F1O;F5S:65N`$EN9F\`26YF;W)M871I;VX`
M26YF;W)M871I;VX@:6MK92!LYFYG97)E('1I;&?F;F=E;&EG`$EN9'/F="!K
M;VQO;FYE(&5F=&5R`$EN9'/F="!B:6QL961E`$EN9'/F="!T86)E;`!);F1S
MYG0@=V5B+6AE;G9I<VYI;F<`26YD<^9T(&MO;&]N;F4@9OAR`$EN9'/F="!E
M;B!N>2!K;VQO;FYE(&5F=&5R(&1E;B!A:W1U96QL90!);F1SYG0@96X@;GD@
M:V]L;VYN92!F^'(@9&5N(&%K='5E;&QE`$EN9'/F="!E;B!N>2!RYFMK92!E
M9G1E<B!D96X@86MT=65L;&4`26YD<^9T(&5N(&YY('+F:VME(&;X<B!D96X@
M86MT=65L;&4`26YD<^9T(&5N('!A<F%G<F%F(&5F=&5R(&1E="!A:W1U96QL
M92!P=6YK=`!);F1SYG0@96X@<&%R86=R868@9OAR(&1E="!A:W1U96QL92!P
M=6YK=`!);F1SYG0@86QT97)N871I=B!S:V%B96QO;@!);F1T87-T(&5N(&4M
M;6%I;"UA9')E<W-E+"!H=F]R=&EL(&1U(&MA;B!M;V1T86=E(&1E="!N>64@
M:V]D96]R9#H`26YD<^9T(&-E;&QE(&5F=&5R`$EN9'/F="!C96QL92!F^'(`
M26YD<^9T(&MO;&]N;F4@969T97(`26YD<^9T(&MO;&]N;F4@9OAR`$EN9'/F
M="!B97-K961E<@!);F1SYG0@<&%R86=R868@969T97(`26YD<^9T('!A<F%G
M<F%F(&5F=&5R`$EN9'/F="!RYFMK92!E9G1E<@!);F1SYG0@<N9K:V4@9OAR
M`$EN9'1A<W0@9&5T(&MRYG9E9&4@<W9A<B!T:6P@<VEK:V5R:&5D<W-P^')G
M<VWE;&5T.@!);F1SYG0OYFYD<F4@8FEL;&5D90!);F1SYG0OYFYD<F4@:&5N
M=FES;FEN9P!5=&EL<W1RYFMK96QI9R!K<F5D:70@=&EL(&%T('-E;F1E('1I
M;"!D:7-T<FEB=71I;VYS;&ES=&5N+@!5=&EL<W1RYFMK96QI9V4@:W)E9&ET
M+@!(96QT86P`2&5L=&%L<VQI<W1E`%5G>6QD:6<@541(+B`H57-E<B!$871A
M($AE861E<BDN`%5G>6QD:6=E(%I)4"UD871A`%5G>6QD:6=T(&%P<&QI:V%T
M:6]N+@!59WEL9&EG="!S:W)I<'0M240N`%5G>6QD:6=E(&1A=&$@869S96YD
M="X`56=Y;&1I9R!D97-T:6YA=&EO;BX`56=Y;&1I9W0@9FEL9F]R;6%T`%5G
M>6QD:6<@;&EC96YS;OAG;&4N`%5G>6QD:6<@<&QA8V5R:6YG(&%N9VEV970N
M`%5G>6QD:6<@;7-G7W1Y<&4N`%5G>6QD:6<@96QL97(@;6%N9VQE;B!A<&E?
M:60N`%5G>6QD:6=E(&5L;&5R(&UA;F=L96YD92!P87)A;65T<F4N`%5G>6QD
M:6=E(&9O<N9L9')E+71I;&QA9&5L<V5R+@!59WEL9&EG('!A<G1N97(M:60N
M`%5G>6QD:6<@<')O9'5K="UK;V1E+@!59WEL9&EG('!R;W1O:V]L+@!59WEL
M9&EG(&UO9'1A9V5R.B`B)7,B`%5G>6QD:6=T(&1E;&EN9W-O8FIE:W0`56=Y
M;&1I9R!O<')I;F1E;'-E<V%D<F5S<V4N`%5G>6QD:6<@=6YI8V]D92UD871A
M+@!);F1B;P!);G9E<G3I<B!M87)K97)I;F<`27)A;BP@1&5N(&ES;&%M:7-K
M(')E<'5B;&EK`$ER86L`27)L86YD`$UA;@!3=&5D=FES('1O<F1E;@!)<W)A
M96P`561S=&5D97(`271A;&EE;G-K`$ET86QI96X`2F%M86EC80!*86YU87(`
M2F%P86X`2F%P86YS:R`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D96X`2G5L
M:0!*=6YI`$IU<W3I<@!#96YT<NER`$QI9V4@;6%R9V5N97(`5F5N<W1R96IU
M<W1E<F5T`$CX:G)E:G5S=&5R970`2V%S86MH<W1A;@!"979A<B!O<FEG:6YA
M;#\`2V5N>6$`2V5R8F5R;W,@<V5R=F5R(&%F=FES=&4@9V]D:V5N9&5L<V4@
M868@:61E;G1I=&5T+@!+97)N92T\96T^3F5W8FEE<SPO96T^`$[X9VQE+7-K
M86)E;'-E`$[X9VQE+69I;F=E<F%F=')Y:P!.^&=L96SF;F=D90!.^&=L971Y
M<&4`3OAG;&5A;G9E;F1E;'-E`$[X9VQE(&5K<VES=&5R97(@86QL97)E9&4@
M<.4@9&5N(&]F9F5N=&QI9V4@;OAG;&5S97)V97(N`$+X<FX`2VER:6)A=&D`
M4WED:V]R96$`3F]R9&MO<F5A`&MO<F5A;G-K("A%54,M2U(I`$MU=V%I=`!+
M:7)G:7-I<W1A;@!59&9O<FUN:6YG`%-P<F]G`$QA;W,`4VED<W1E(&AA;'9D
M96P`4VED<W1E(&MO9&5O<F1SYFYD<FEN9P!3:61S=&4@:W9A<G1A;`!3:61S
M="!O<&1A=&5R970Z`%-I9'-T92!L;V=I;CH@)7,`4VED<W1E(&EN9&QO9VYI
M;F<Z("5S(&9R82`E<P!3:61S=&4@;&]G:6XZ($%L9')I9P!,971L86YD`$QO
M=@!,87EO=70`5&]M('9E9"!I;F=E;B!R86UM97(`3&EB86YO;@!696YS=')E
M`%9E;G-T<F4@=&]P=&5K<W0`5F5N<W1R92!VYG)D:65R`$QE<V]T;P!.:79E
M874`3&EB97)I96X`3&EB>65N`$QI96-H=&5N<W1E:6X`4W3X=G)E9VX`3&5T
M(')E9VX`3&5T(')E9VX@=&ED;&EG=`!,970@<F5G;B!S96YT`$QE="!B>6=E
M`$QE="!B>6=E(&UE9"!T;W)D96X`3&5T('-N90!,970@<VYE(&)Y9V4`5FET
M=&EG:&5D`$AE;G9I<VYI;F<`1F]R8FEN9"!P=6YK=&5R('1I;#H`1F]R8FEN
M9"!E+6UA:6PM861R97-S96X@;65D(&EN9'-K<FEV;FEN9W-S:61E;B!V960@
M9G)E;79I<VYI;F<`2&5N=FES;FEN9V5R`$QI;G5X+6MI:W,`3&ES=&4@+2!B
M<G5G97(@:V%N('-E(&UA<'!E;@!,:7-T(&1A=&%B87-E<@!/<&QI<W1N:6YG
M(&%F(&AJYFQP965M;F5R`$QI<W0@=&%B96QL97(`3&ES=&4M07)C:&EV90!,
M:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U
M8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1N:6YG(&%F('-E<W-I;VYS
M(&9E:FQE9&4Z("5S`$QI<W1N:6YG(&%F(&)R=6=E<F4@9F5J;&5D93H@)7,`
M5FES;FEN9R!A9B!B<G5G97)E(&5R('-LY65T(&9R82X`3&ET=&5R871U<@!,
M:71A=65N`$AE;G1E<BXN+@!,;VMA;"!T:60Z`%)E9VEO;F%L9&%T82!O9R!T
M:60`4W1E9`!,;V<@:6YD`$QO9R!A9B!T:61L:6=E<F4@<WEN:W)O;FES97)I
M;F=S<V5S<VEO;F5R`$QO9R!U9`!,;V<@:6YD`$QO9VEN+6]P9V%V97(`3&]G
M(&EN9"!F96IL961E(&9O<F1I(&1I="!B<G5G97)N879N(&5L;&5R(&MO9&5O
M<F0@8FQE=B!A;F=I=F5T(&9O<FME<G0N`$QO9VEN9"!M:7-L>6MK961E<RX`
M3&%N9R!T96MS=`!+YG)L:6=H960`3&%V`%-MY2!G<N9S:V4@=&5G;@!3;>4@
M;&%T:6YS:V4@=&5G;@!3;>4@<F]M97)T86P`3'5X96UB;W)G`$U-`$U/5$0`
M35,M5$Y%1BUB:6QA9R!I;F1H;VQD="!I;F=E;B!D871A+@!-4T<`36%C86\`
M36%K961O;FEE;BP@1&5N('1I9&QI9V5R92!J=6=O<VQA=FES:V4@<F5P=6)L
M:6L`36%D86=A<VMA<@!-86=I`$4M;6%I;`!%+6UA:6PM861M:6YI<W1R871O
M<@!$86X@:&5N=FES;FEN9RXN+@!-86QA=VD`36%L87ES:6$`36%L9&EV97)N
M90!-86QI`$UA;'1A`$CE;F1TZ7(@;&ES=&5N(&%F(&MA=&5G;W)I97(L('-O
M;2!D=2!S:V%L(&UA<FME<F4@96UN97(@;65D+"!O9R!F87)V97)N92P@9&5R
M('-K86P@:VYY='1E<R!T:6P@9&ES<V4@:V%T96=O<FEE<BX`36%P,C0M:V]R
M=`!-87!1=65S="UK;W)T`$MO<G1LYF=N:6YG(&=E;70N`$UA<G1S`$UA<F=E
M;@!-87)KZ7(@;65D(%-E="]5<V5T+69L86<`36%R:^ER(&UE9"!A;F1R92!F
M;&%G("AF>"!6:6=T:6<O0F5S=F%R970I`$UA<G-H86QL^&5R;F4`36%R=&EN
M:7%U90!/=F5R96YS<&%S<V5N9&4@9F5L=&5R`$UA=7)I=&%N:65N`$UA=7)I
M=&EU<P!-87@@=&EL;&%D="!K<F5D:70N`$UA:W-I;75M(&)E<VME9"UD96QE
M(&]V97)S:W)E9&5T+@!-86MS+B!T96UP+B!S:61S="`R-"!T:6UE<CH@`$UA
M:W,N('1E;7`N('-I9'-T92`V('1I;65R.B``36%K<VEM=6T@86YT86P@868@
M<&]R=&%L8FQO:VME`$UA:W-I;75M;.9N9V1E`$UA:@!-87EO='1E`$UE9&EC
M:6X`365D;&5M;65R`$UE;G4M=&EL<W1A;F0Z`$9O<NEN(&-E;&QE<@!"97-K
M960`0F5S:V5D('-U8V-E<V9U;&1T('9E<FEF:6-E<F5T(&UE9"!U;F1E<G-K
M<FEV97)E;G,@8V5R=&EF:6MA="!K=6YN92!I:VME('9E<FEF:6-E<F5S+@!"
M97-K960@=61L^&)E="X`0F5S:V5D='EP90!-971A<B!796%T:&5R`$UE=&%R
M8FQO:R!I:VME('1I;&?F;F=E;&EG+@!-971A<F)L;VL@:6MK92!T:6QGYFYG
M96QI9RX@1&5T86QJ97(@97(@8FQE=F5T(&YO=&5R970@=&EL(&)R=6<@9F]R
M(&%D;6EN:7-T<F%T;W)E;BX`365T87)$0B!E<B!I:VME(&9O<F)U;F1E="X`
M365T;V1E`$UE=&]D92`B)7,B(&5R(&EK:V4@9&5F:6YE<F5T`$UE=&]D92!I
M:VME(&1E9FEN960N($UE=&]D92!K86QD=#H@)7,`3>5L965N:&5D`$UE>&EC
M;P!-:6MR;VYE<VEE;@!-:61T`$U)344M='EP90!-:6XN('1E;7`N('-I9'-T
M92`R-"!T:6UE<CH@`$UI;BX@=&5M<"X@<VED<W1E(#8@=&EM97(Z(`!-:6YI
M;75M(&MO9&5O<F1S86QD97(@97(@96YD;G4@:6MK92!U9'-TY65T`%-P96IL
M90!&;W)S:V5L;&EG=`!-86YG;&5R(%!%05(M<&%K:V4@2%144%]297%U97-T
M+@!+;VYF:6=U<F%T:6]N(&UA;F=L97(N($1U(&)L:79E<B!N^&1T('1I;"!A
M="!G96YE<F5R92!D96X@;G4L(&AV:7,@9'4@^&YS:V5R(&%T(&)R=6=E(&1E
M;FYE(&%P<&QI:V%T:6]N+@!-86YG;&5R(&)E<VME9"UI9"X`36%N9VQE<B!K
M<N9V970@4$5!4BUP86MK92!-86EL+@!-86YG;&5R('-E<W-I;VXM240N`$UA
M;@!-;V)I;"!%+7!O<W0`2N9V;@#&;F1R:6YG<V1A=&\`QFYD<F4@55),`$UO
M9'5L=7,`36]L9&]V80!-;VYA8V\`36]N9V]L:65N`$WE;F5D(&]G(.5R`$WE
M;F5D;&EG`$UO;G1S97)R870`3>5N969A<V5R`$9L97)E(&9E;'1E<B!F=6YD
M970@:2!L:6YI92`E9"!E;F0@9&5T(&9O<G9E;G1E9&4@)60N`$UA<F]K:V\`
M365S="!S:WEF<FET`$UE<W0@<VMY970`365S="!S:WEE="!O9R!B;.9S96YD
M90!-97-T('-O;`!&;'ET(&YE9`!&;'ET('1I;"!V96YS=')E`$UO9"!H^&IR
M90!&;'ET(&]P`$9L>70@;F5D`$9L>70@;W``36]C86UB:7%U90!-=6QT:2UN
M:79E874@<G5L;&5G87)D:6YS;&ES=&5R`$UU;'1I;6%P(%5+(&MO<G0`375L
M=&EP;&4@=F%L9P!-:6X@:V]N=&\`36EN92!K;VYT;RUI;F9O<FUA=&EO;F5R
M`$UI;B!0;W)T86P`36EN(%!O<G1A;"UU9&9O<FUN:6YG`$UY86YM87(`3D5*
M+"!J96<@97(@24M+12!E;FEG`$YA=FX`3F%M:6)I80!.875R=0!.97!A;`!.
M961E<FQA;F1E;F4`2&]L;&%N9'-K92!!;G1I;&QE<@!.971S8V%P92!"87-E
M(%523`!.971S8V%P92!#02!2979O8V%T:6]N(%523`!.971S8V%P92!#02!P
M;VQI8WD@55),`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C
M871I;VX@55),`$YE='-C87!E(%-33"!S97)V97(@;F%M90!.971S8V%P92!C
M97)T:69I8V%T92!C;VUM96YT`$YE='-C87!E(&-E<G1I9FEC=&4@='EP90!.
M971VYG)K`$%L9')I9P!.>2!+86QE9&]N:65N`$YY(&MA=&5G;W)I`$YY;>5N
M90!.>70@8G)U9V5R;F%V;B`H=F%L9V9R:70I`$YE=R!:96%L86YD`$YY="!K
M;V1E;W)D`$YY="!K;V1E;W)D('9I;"!U9&SX8F4@9&5N("5X+@!.>64@:V]D
M96]R9"!E<B!I:VME(&5N<RX`3GET('9I;F1U92`H7V)L86YK*0!.>6AE9&5R
M`$YY:&5D<V=R=7!P97(`3N9S=&4`3N9S=&4@-"!F87-E<@!.YG-T92!T:6QV
M86QG`$[F<W1E/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.870`3FEU90!.
M96H`26YG96X@=&EL9^9N9V5L:6=E(&MO;F9I9W5R871I;VYD871A(&%T('9I
M<V4@9F]R<VME;&QE(&9O<BX`26YG96X@=&EL9^9N9V5L:6<@<W1R871E9VD@
M=&EL(&%T(&QA=F4@25-/+6)I;&QE9&5R+@!);F=E;B!S:W)I<'0M<VMA8F5L
M;VXN`$1E<B!E:W-I<W1E<F5R(&EK:V4@;F]G96X@8FQO:R!PY2!D96X@9F]R
M97-P=7)G=&4@<&]S:71I;VX`26YG96X@:V%L96YD97(@86YG:79E="!T:6P@
M34-!3"WF9W1N:6YG+@!);F=E;B#F;F1R:6YG+@!$97(@:V%N(&EK:V4@=&EL
M9OAJ97,@8OAR;B!T:6P@9&5N;F4@=&EL;&%D96QS92X`26YG96X@:V]N9FEG
M=7)A=&EO;BUI;F9O<FUA=&EO;B!A;F=I=F5T(&9O<B`E<RX`26YG96X@:V]N
M9FEG=7)A=&EO;BUI;F9O<FUA=&EO;B!A;F=I=F5T(&9O<B!&5%`@5D93+@!)
M;F=E;B!K;VYF:6=U<F%T:6]N+6EN9F]R;6%T:6]N(&%N9VEV970@9F]R(%-1
M3"!61E,N`$EN9V5N(&MO;F9I9W5R871I;VXM:6YF;W)M871I;VX@86YG:79E
M="!F;W(@4U%,+49I;&4@5D93+@!+<F5D:70@=61T^&UT+@!);G1E="!B97-T
M96UM96QS97-S=&5D(&%N9VEV970N`$EN9V5N(&9I;"!S96YD=`!&86YD="!I
M;F=E;B!I:V]N97(N`$EN=&5T('-T960@:6YD<W1I;&QE="X`26YT970@<W1E
M9"!A;F=I=F5T+@!);F=E;B!B97-K960@86YG:79E="X`26YT970@;F%V;B!A
M;F=I=F5T+@!);G1E="!N=6UM97(@86YG:79E="X`26YG96X@86YS=/AD96QI
M9V4@97!I9W)A;6UE<@!);G1E="!K;V1E;W)D(&%N9VEV970@=&EL(&)R=6<@
M9F]R($A45%`MYF=T;FEN9RX`26YT970@:V]D96]R9"!A;F=I=F5T('1I;"!B
M<G5G(&9O<B!)34%0+>9G=&YI;F<N`$EN=&5T(&MO9&5O<F0@86YG:79E="!T
M:6P@8G)U9R!F;W(@2V5R8F5R;W,MYF=T;FEN9RX`26YT970@:V]D96]R9"!A
M;F=I=F5T(&9O<B!,;V=I;F0MYF=T;FEN9RX`26YT970@:V]D96]R9"!A;F=I
M=F5T="!T:6P@4$%34U=$+>9G=&YI;F<N`$EN=&5T(&MO9&5O<F0@86YG:79E
M="!F;W(@4TU"+>9G=&YI;F<N`%-T:2!T:6P@3W!E;E-33"UB:6)L:6]T96ME
M="!M86YG;&5R+B`@3W!E;E-33"UB:6)L:6]T96ME="!E<B!N^&1V96YD:6=T
M(&9O<B!A="!HY6YD=&5R92!02T-3,3(M9&%T82X`26YG96X@=F5N=&5N9&4@
M;W!S:W)I=FYI;F=E<BX`2W9O=&4@:6MK92!I;F1S=&EL;&5T+@!);F=E;B!S
M=')E9V5R`$EN9V5N('-K:6QL971E9VX@86YG:79E="X`26YG96X@<VED97(`
M26YG96X@<^5D86X@9FEL`$1E<B!M86YG;&5R(&5T(&UI9&QE<G1I9&EG="!K
M871A;&]G('1I;"!M96QL96UL86=E<BX`26YT970@8G)U9V5R;F%V;B!O9R]E
M;&QE<B!K;V1E;W)D('-E;F1T+@!);F=E;B!G>6QD:6=E(%A-3"UD871A(')E
M='5R;F5R970`26YG96X@=N9R9&EE<@!/<FEG:6YA;"!K;VYF:6=U<F%T:6]N
M(&UA;F=L97(@=F5R<VEO;G-N=6UM97(N(%)E9V5N97+I<B!K;VYF:6=U<F%T
M:6]N+@!$:6X@:V]N9FEG=7)A=&EO;B!M86YG;&5R('9E<G-I;VYS;G5M;65R
M+B!296=E;F5RZ7(@:V]N9FEG=7)A=&EO;BX`26YG96X`26YG96X@*&)R=6<@
M:6UP;&EC:70I`$YO<F1I<VL@*$E33RTX.#4Y+3$P*0!.;W)F;VQK`$YO<F1L
M:6=E(&AA;'9K=6=L90!.;W)D;&EG92!-87)I86YA^&5R`$YO<F=E`$EK:V4@
M<V5N97)E(&5N9`!):VME(&;X<@!):VME(&YO9V5T(&MA=&%L;V<`26MK92!I
M;7!L96UE;G1E<F5T+@!):VME(&EN9'-T:6QL970`26MK92!U;F1E<G-T^'1T
M970N`$YO=&5R`$EN=&5T(&%T(&)R;W=S92P@=F5N9"!T:6QB86=E+@!.;W9E
M;6)E<@!486P`06YT86P@=&5G;@!!;G1A;"!K;VQO;FYE<@!!;G1A;"!RYFMK
M97(`5&%L(&EK:V4@86YG:79E="!F;W(@;W!D871E<FEN9R!I(&1I<W1R:6)U
M=&EO;G-L:7-T92X`3TL`3V)J96MT`$]B:F5K=&1A;FYE<@!/:W1A;`!/:W1O
M8F5R`$%N<W3X9&5N9&4@9FEL=&5R`$MO;G1O<@!'86UM96QT(&]G(&YY="!K
M;V1E;W)D('-K86P@=N9R92!F;W)S:V5L;&EG92X`1V%M;65L="!K;V1E;W)D
M`$=A;6UE;'0@:V]D96]R9"!E<B!I:VME(&MO<G)E:W0N`$]M86X`1&5L=&4@
M;6%P<&5R('5N9&5R<W3X='1E<R!K=6X@868@24U!4"US97)V97)E+@!+=6X@
M86YS=/AD96QI9V4@97!I9W)A;6UE<@!+=6X@Z6X@92UP;W-T+6%D<F5S<V4@
M=&EL;&%D="X`16X@9&5L:6YG<R!E:F5R<VMA8B!O9R!E:F5R=&EL;&%D96QS
M97(@;>4@:W5N(.9N9')E(&%F(&5N('-Y<W1E;6%D;6EN:7-T<F%T;W(@96QL
M97(@96IE<F5N('-E;'8`Q6)E;B!I(&5T(&YY="!V:6YD=64`3W!E;E-33"UF
M96IL.B!$871A(&MU;FYE(&EK:V4@=61D<F%G97,@9G)A('-I9VYE<F5T(%,O
M34E-12UD96PN`,5B96X@9&5N;F4@:&5N=FES;FEN9R!I(&5T(&YY="!V:6YD
M=64`3W!E<F%T:79S>7-T96T`26YD<W1I;&QI;F=E<@!);F1S=&EL;&EN9V5R
M(&9O<B`E<P!/<F1N970@;&ES=&4`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&]R
M:7-K(&5N:&5D`$]R9V%N:7-E<FEN9P!/<')I;F1E;&EG(&%P<&QI:V%T:6]N
M<W-K86)E;&]N`$]P<FEN9&5L:6=E('-K86)E;&]N97(@:2`E<SH`06YD96X`
M06YD96X@:6YF;W)M871I;VX`16IE<G)E='1I9VAE9&5R`%!!32WF9W1N:6YG
M(&5R(&EK:V4@=&EL9^9N9V5L:6=E+@!014%2.CI-86EL+6UO=&]R`%!'4"!D
M:6=I=&%L('-I9VYA='5R`%!'4"UK<GEP=&5R970@9&%T80!/9F9E;G1L:6<@
M4$=0+6[X9VQE`%!'4"US:6=N97)E="]K<GEP=&5R970@9&%T80!02%`M:V]D
M90!02%`M<VMA;`!%9G1M+B!L970@<F5G;@!%9G1M+B!R96=N`$5F=&TN(&)Y
M9V5R`$5F=&TN('-N90!%9G1M+B!S;F5B>6=E<@!%9G1M+B!S;VP`169T+B!T
M;W)D96X`4$]325@M=61V:61D96QS92!M86YG;&5R`%!(4"US:V%L`$9O<G)I
M;F<`4&%K:7-T86X`4&%L874`4&%LYG-T:6YA`%!A;F%M80!087!U82!.>2!'
M=6EN96$`4&%R86=U87D`1&5L=FES="!S:WEE=`!+;V1E;W)D`$MO9&5O<F0@
MYFYD<F5T+@!+;V1E;W)D(&9O<FME<G0`2V]D96]R9"!K<N9V970@=F5D(%)!
M1$E54RWF9W1N:6YG+@!+;V1E;W)D(&UE9"!B96MRYF9T96QS90!+;V1E;W)D
M.@!+;V1E;W)D.B``2V]D96]R9&5N92!S:V%L(';F<F4@96YS+@!);F1SYG0`
M26YD<^9T(&9R82!U9&ML:7!S:&]L9&5R`%-T:0!696YT96YD92!O<'-K<FEV
M;FEN9V5R.@!&;VQK`%!R;V-E;G0`561F^'(@=F5D;&EG96AO;&1E;'-E`%5D
M9OAR('9E9&QI9V5H;VQD96QS92!V960@;&]G(&EN9#\`5&EL;&%D96QS97(`
M5&EL;&%D96QS92`B)7,B(&EK:V4@<VQE='1E="X`5&EL;&%D96QS92!NYF=T
M970`5&EL;&%D96QS97(`5&EL;&%D96QS97,M861M:6YI<W1R871I;VX`4')O
M9FEL97(`4&5R=0!+YFQE9'ER`$9I;&EP<&EN97)N90!496QE9F]N`$9O=&]S
M`%!I=&-A:7)N`%!R:6MK97(`0F%N86QI=&5T97(`2VQI:R!I(&5N(&-E;&QE
M`$)E:W+F9G0@870@9'4@^&YS:V5R(&%T('-L971T92!D971T92!E;&5M96YT
M.@!"96MRYF9T(&%T(&1U(/AN<VME<B!A="!A9FSF;FME(&1E='1E(&5L96UE
M;G0N`$EN9'1A<W0@96X@;>5N960@;V<@970@Y7)S=&%L+@!);F1T87-T(&5T
M(&YA=FX@=&EL(&1E;B!N>64@:V%T96=O<FDZ`$EN9'1A<W0@96X@9WEL9&EG
M($E0+6%D<F5S<V4N`$EN9'1A<W0@96X@9WEL9&EG(&1A=&\L('1J96L@86YT
M86QL970@868@9&%G92!I(&WE;F5D96XN`$EN9'1A<W0@96X@9WEL9&EG('1I
M9'-A;F=I=F5L<V4N`%-K<FEV('9E;FQI9W-T+"!H=F%D('!R;V)L96UE="!G
MY7(@=60@<.4@;V<@:'9A9"!D97(@<VME<BX`26YD=&%S="!V96YL:6=S="!B
M<G5G97)N879N(&]G(&MO9&5O<F0`3.9S(&;X;&=E;F1E('1E:W-T+B!$=2!3
M2T%,(';F<F4@96YI9R!I(&)E=&EN9V5L<V5R;F4@9F]R(&%T(&)R=6=E('-Y
M<W1E;65T+@!);F1T87-T(&1E="!N>64@:V%T96=O<FEN879N.@!0;VQE;@!0
M;VQI=&EK`$UE;FEN9W-MY6QI;F=E<@!0;W)T=6=A;`!0;&%C97)I;F<@868@
M8FEL;&5D970`4&QA8V5R:6YG(&%F(&1E;FYE('1A8F5L`%-E;F0@=&EL(&1E
M;FYE(&UA<'!E("AI:VME(&=E;FYE;71V=6YG970@868@24U!4"D`3F5D8OAR
M(&=E;FYE;2!S96YE<W0@)7,@=&EM97(Z(`!.961B^'(\8G(@+SYC:&%N8V4`
M4')E9G-?;&1A<#H@2W+F=F5T($Q$05`M=61V:61D96P@:6MK92!F=6YD970N
M`%!R969S7W-E<W-I;VXZ($MRYG9E="!S97-S:6]N+75D=FED9&5L<V4@:6MK
M92!F=6YD970N`%1R>6L`5')Y:R!V960@;W9E<F9L861E;CH@`%1R>6LZ(`!'
M;&EM=`!"971R86=T(&)I;&QE9&5T(&D@970@;GET('9I;F1U90!&;W)R:6=E
M('1I;'9A;&<`561S:W)I=B!D;VMU;65N=`!0<FEV870@;OAG;&4`4')O8FQE
M;0!0<F]B;&5M8F5S:W)I=F5L<V4`4')O:F5K=&5R`%-T:6MO<F1S=&5K<W0`
M3V9F96YT;&EG92!N^&=L90!/9F9E;G1L:6<M;OAG;&4M86QG;W)I=&UE`$]F
M9F5N=&QI9R!N^&=L92!I;F9O<FUA=&EO;@!/9F9E;G1L:6<O<')I=F%T+6[X
M9VQE<^9T+6=E;F5R97)I;F<@;6ES;'EK:V5D97,N`%!U97)T;R!2:6-O`%5D
M<F5N<R!B97-K961E<@!1871A<@!&;W)E<W#X<F=S96P`2W9O=&4`3V9F96YT
M;&EG(%)302UN^&=L92`H)60@8FET*0!%;FME;'1V:7,@=F%L9P!296=N`%)E
M9VX@=&ED;&EG=`!296=N('-E;G0`4F5G;F)Y9V5R`%)E9VX@;V<@<VYE`%-L
M=60`5&EL9N9L9&EG="!E<&EG<F%M`$9O<FAO;&0`3.9S`$SF<R!B97-K961E
M<@!6:7)K96QI9R!S;&5T=&4@)7,_($1E;FYE(&]P97)A=&EO;B!K86X@:6MK
M92!B;&EV92!O;6=J;W)T+@!6:7)K96QI9R!S;&5T=&4@9&%T82!F;W(@8G)U
M9V5R("5S/R!$96YN92!O<&5R871I;VX@:V%N(&EK:V4@8FQI=F4@;VUG:F]R
M="X`3VUG^'(@9&EN('-I9'-T92!H86YD;&EN9P!/<&1A=&5R`$]P9G)I<VL@
M9'EN86UI<VME(&UE;G4M96QE;65N=&5R.@!'96YO<&9R:7-K('!O<G1A;'9I
M<VYI;F<Z`%)E9W5LYG)T('5D=')Y:P!296QA=&EO;G-LYG-E<@!'96YO<&9R
M:7-K`$YO=&5R`$9J97)N92!S97)V97)E`$9J97)N(%523"`H:'1T<#HO+W=W
M=RYE:W-E;7!E;"YD:R]H;W)D92DZ`%-L970`4VQE="!B;&]K`$9J97)N(&MO
M;&]N;F4`4VQE="!F;W)M871E<FEN9P!3;&5T('!A<@!&:F5R;B!L86=R970@
M<VMR:7!T(&9R82!S97)V97)S(&UI9&QE<G1I9&EG92!K871A;&]G+@!&:F5R
M;@!&:F5R;B!D971T92!P=6YK="!F<F$@9&]K=6UE;G1E=`!3;&5T(&)R=6=E
M<@!3;&5T(&)R=6=E<CH@)7,`06YM;V1N:6YG(&MU;FYE(&EK:V4@8F5S=F%R
M97,N(%)E='5R;F5R970@9F5J;&MO9&4Z(`!!;FUO9&5T('1J96YE<W1E(&MU
M;FYE(&EK:V4@9FEN9&5S+@!+<N9V961E("<E<R<@97(@:6MK92!A;F=I=F5T
M(&D@)7,M:V]N9FEG=7)A=&EO;BX`2W+F=F5T("(E<R(@97(@:6MK92!A;F=I
M=F5T(&D@5D93(&MO;F9I9W5R871I;VXN`$MRYG9E9&4@(B5S(B!E<B!I:VME
M(&%N9VEV970@:2!K;VYF:6=U<F%T:6]N96XN`$MRYG9E="!F96QT`$YU;'-T
M:6P`3G5L<W1I;"!K;V1E;W)D`$YU;'-T:6P@9&ET(&MO9&5O<F0`1V5N<VMA
M8B!S:61S=&4@9F]R97-P^')G<V5L`%)E<W5L=&%T97(`5&EL8F%G92!T:6P@
M:6YD<W1I;&QI;F=E<FYE`$=E;G1A<W0@;GET(&MO9&5O<F0`4F5U;FEO;@!'
M96YD86X@:V]N9FEG=7)A=&EO;@!);F1S=&EL;&EN9V5R(&9O<B!2:6-H(%1E
M>'0M<F5D:6=E<FEN9P!'Y61E<@!(^&IR90!(^&IR92!T;W!T96MS=`!(^&IR
M92!VYG)D:65R`%+F:VME+65G96YS:V%B97(N+BX`4F5G96P`4G5MYFYI96X`
M4F]TZ7(@,3@P`%)O=.ER('9E;G-T<F4`4F]TZ7(@:/AJ<F4`4N9K:V4M96=E
M;G-K86)E<@!2YFMK92UE9V5N<VMA8F5R`%+F:VME<CH`4W1R96=E<@!3=')E
M9V5R('9I;"!O<'1RYF1E(&UE;&QE;2!RYFMK97(@;V<@:V]L;VYN97(`4W1R
M96=E<B!V:6P@:W5N(&]P='+F9&4@;65L;&5M(&MO;&]N;F5R`%-T<F5G97(@
M=FEL(&MU;B!O<'1RYF1E(&UE;&QE;2!RYFMK97(`561F^'(`4G5S;&%N9`!2
M=V%N9&$`2W)Y<'1O9W)A9FES:R!3+TU)344M<VEG;F%T=7(`4R]-24U%+7-I
M9VYE<F5T(&)E<VME9`!305-,+>9G=&YI;F<@97(@:6MK92!T:6QGYFYG96QI
M9RX`4TU3`%-13"UF;W)T;VQK97(`4U%,+75D=')Y:R!F;W(@;W!S;&%G(&%F
M(';F<F1I97(`4U-(`%-50T-%4P!344PM9F]R=&]L:V5R`$SX<@!3:W0N($AE
M;&5N80!3:W0N($MI='1S(&]G($YE=FES`%-K="X@3'5C:6$`4VMT+B!0:65R
M<F4@;V<@36EQ=65L;VX`4VMT+B!6:6YC96YT(&]G($=R96YA9&EN97)N90!3
M86UM92!R86UM92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V]A(%1O;64@
M;V<@4')I;F-I<&4`4V%T96QI='5D8GED97(`4V%U9&EA<F%B:65N`$=E;0!'
M96T@(B5S(@!'96T@(B5S(@!'96UM92!);F1S=&EL;&EN9V5R`$=E;2!G96YE
M<F5R970@:V]N9FEG=7)A=&EO;B!S;VT@4$A0+7-K<FEP="!I(&1I;B!S97)V
M97)S(&UI9&QE<G1I9&EG92!K871A;&]G+@!'96UT("5S+6MO;F9I9W5R871I
M;VXN`$=E;71E('-K<FEP="!F;W(@;W!G<F%D97)I;F<@868@;W!SYG1N:6YG
M('1I;#H@(B5S(BX`4W!R961T('1O<F1E;@!6:61E;G-K86(`4_AG`%/X9V5M
M87-K:6YE<@!6YFQG(&9I;&5R`%;F;&<@96X@9&%T;P!6YFQG(&5N(&=R=7!P
M92!A="!T:6QF^&IE`%;F;&<@96X@;GD@96IE<@!6YFQG(&5N('-E<G9E<@!6
MYFQG(&5N(&)R=6=E<B!A="!T:6QF^&IE`%;F;&<@86QL90!6YFQG(&%L;&4@
M9&%T;RUK;VUP;VYE;G1E<BX`5N9L9R!E="!O8FIE:W0`5N9L9R!I;F=E;@!6
MYFQG(&1E('1E9VX@9'4@:&%R(&)R=6<@9F]R(&9R82!K87-S97)N92!N961E
M;F9O<BX@1&4@:V%N('/E(&ML:7!P97,@;V<@:V]P:65R97,@9G)A('1E>'1F
M96QT970N`%;F;&<@9&%T;RUA9'-K:6QL97)E;CH`5N9L9R!D871O9F]R;6%T
M.@!6YFQG(&1E;B!I9&5N=&ET970L('-O;2!D=2!V:6P@YFYD<F4Z`%;F;&<@
M=&ED<RUA9'-K:6QL97)E;CH`5N9L9R!T:61S9F]R;6%T.@!6YFQG('1O(&9E
M;'1E<BP@9&5R('-V87)E<B!T:6P@:&EN86YD96XN`%;F;&<@9&EN(&9A<G9E
M<V%M;65N<^9T;FEN9RX`5N9L9R!D:70@9F]R971R=6MN92!S<')O9SH`4V5N
M9"!P<F]B;&5M8F5S:W)I=F5L<V4`4V5N9"!335,`4V5N96=A;`!&^&QE<CH@
M`%-E<'1E;6)E<@!397)B:65N(&]G($UO;G1E;F5G<F\`4V5R:65N=6UM97(`
M4V5R=F5R+61A=&$@9F]R:V5R="!E;&QE<B!I:VME('1I;&?F;F=E;&EG+@!3
M97-S:6]N<V%D;6EN:7-T<F%T;W(`4V5S<VEO;BU)1"!U9&SX8F5T+@!397-S
M:6]N97(`3>9N9V1E`$EN9'-T:6QL:6YG97(@9&5R('1I;&QA9&5R(&1I9R!A
M="!N=6QS=&EL;&4@9&ET(&MO9&5O<F0L(&AV:7,@9'4@;F]G96YS:6YD92!S
M:W5L;&4@9VQE;6UE(&1E="X`26YD<W1I;"!F:F5R;F4@<V5R=F5R92P@<V]M
M(&1U(/AN<VME<B!A="!T:6QGY2!F<F$@9&EN('!O<G1A;"X`26YD<W1I;"!D
M:6X@9F]R971R=6MN92!S<')O9RTL('1I9'-Z;VYE+2!O9R!D871O=F%L9RX`
M26YD<W1I;"!D:6YE(&]P<W1A<G1S87!P;&EK871I;VYE<BP@9F%R=F5S86UM
M96YSYG1N:6YG+"!S:61E;W!F<FES:VYI;B!O9R!A;F1R92!V:7-N:6YG<W1I
M;'9A;&<N`$EN9'-T:6QL:6YG`%-K<FEP=',@=&EL(&]P9W)A9&5R:6YG(&%F
M(&]P<^9T;FEN9R!T:6QGYFYG96QI9V4`1FQE<F4@<W1E9&5R(&UU;&EG(&UE
M9"!P87)A;65T97)E;CH@`%-E>6-H96QL97)N90!3:&]P<&EN9P!+;W)T(&]P
M<W5M;65R:6YG`%-K86P@:'5R=&EG+71A<W1E<B!D969I;F5R97,@9F]R(&1E
M(&9L97-T92!H96YV:7-N:6YG97(_("CW*0!6:7,`5FES(&9O<G-K96QL96YE
M(&UE;&QE;2!D96X@9V5M=&4@;V<@9&5N(&YY;&EG="!G96YE<F5R961E(&MO
M;F9I9W5R871I;VXN`%9I<R!T:61S<'5N:W0@9F]R('-E;F5S=&4@=&EL9V%N
M9R!V960@<.5L;V=N:6YG/P!6:7,@;75L:6=H960@9F]R(&%T(&)E:&]L9&4@
M;W!R:6YD96QI9P!6:7,@<VYU<'!E<@!6:7,@5&%B96QO<&5R871I;VYE<BUK
M;F%P<&5N(&D@;65N=65N/P!6:7,@)7,M;65N=65N('1I;"!V96YS=')E/P!6
M:7,@9&EA;&]G=FEN9'5E(&UE9"!E9V5N<VMA8F5R(&9O<B!T86)E;&-E;&QE
M;@!6:7,@9&EA;&]G=FEN9'5E(&UE9"!E9V5N<VMA8F5R(&9O<B!T86)E;&QE
M;@!6:7,@9&EA;&]G=FEN9'5E(&UE9"!E9V5N<VMA8F5R(&9O<B!T86)E;'+F
M:VME;@!6:7,@9&EA;&]G=FEN9'5E(&UE9"!E9V5N<VMA8F5R(&9O<B!B:6QL
M961E=`!6:7,@869S96YD=&4`0GEG97(`0GEG97(@=&ED;&EG=`!">6=E<B!S
M96YT`$)Y9V5R(&D@;N9R:&5D96X`4VMR=6UP`%-K<G5M<"!E;&QE<B!F;'ET
M(&YA8F]B;&]K:V4@868@=F5J96X@9OAR<W0`4VEE<G)A($QE;VYE`%-K<FEV
M(&EN9`!5;F1E<G-K<FEF=`!3:6=N871U<F%L9V]R:71M90!3:6YG87!O<F4`
M4W3X<G)E;'-E`%-P<FEN9R!V961L:6=E:&]L9&5L<V4@;W9E<@!3;&]V86MI
M970`4VQO=F5N:65N`%-N90!3;F5B>6=E`%-N96)Y9V5R`%-N96)Y9V5R('1I
M9&QI9W0`4VYE8GEG97(@<V5N=`!3;F5D>6)D93H@`%-N9>9K=FEV86QE;G0@
M:2!V86YD.B``4V%L;VUO;OAE<FYE`%-O;6%L:6$`4V%N9V4@;V<@<&]E<VD`
M4V]R=&5R:6YG<W9A;&<`069S96YD97)A9')E<W-E`%-Y9&%F<FEK80!3>61E
M=7)O<.9I<VL@*$E33RTX.#4Y+3,I`%-Y9"!'96]R9VEA(&]G($1E('-Y9&QI
M9V4@4V%N9'=I8VCX97(`4WED;&EG92!H86QV:W5G;&4`3'5F="!M96QL96T@
M;F%B;V-E;&QE<@!,=69T(&UE;&QE;2!I;F1H;VQD(&]G(')A;6UE(&D@8V5L
M;&4`365L;&5M<G5M<W1A;F=E=`!-96QL96UR=6T`3'5F="!O9R!F;W)R:6YG
M`%-P86YI96X`4VMI9'1P;W-T`$EN9'1A<W1N:6YG(&9O<B!S<&5C:6%L:V%R
M86MT97(`1&5L(&-E;&QE`$1E;"!K;VQO;FYE`$1E;"!RYFMK90!3<&]R=`!3
M<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K`$)E9WEN9&5L<V5SY7(`1&5L
M<W1A="!E;&QE<B!P<F]V:6YS`%-T871U<P!,86=R:6YG<V9O<FUA=`!696H`
M1V5N;F5M<W1R96=N:6YG`$QI<W1E(&%F('-T<F5N9V4`1FIE<FX@9&]MYFYE
M(&9R82!A9')E<W-E;@!3=&EL(%M#4U-=`%/X;@!5;F1E<FMA=&%L;V<@(B5S
M(B!I:VME(&9U;F1E="X`16UN90!';V1K96YD`$%N;6]D;FEN9R!O;2!A="!T
M:6QF^&IE("(E<R(@=&EL('-Y<W1E;2!A9G-E;F1T+B`@1'4@:V%N(&EK:V4@
M;&]G9V4@<.4@9OAR(&1I;B!A;FUO9&YI;F<@97(@8FQE=F5T(&%N97)K96YD
M="X`3&%V('-K<FEF=`!59&;X<G0`(B5S(B!B;&5V('1I;&;X:F5T('1I;"!S
M>7-T96UE="X`1&%T82!F;W(@8G)U9V5R("(E<R(@8FQE=B!S;&5T=&5T(&9R
M82!S>7-T96UE="X`(B5S(B!S;&5T=&5T+@`B)7,B('-L971T970@9G)A('-Y
M<W1E;65T+@!+;VYF:6=U<F%T:6]N('1I;&)A9V5F^')T+B!'96YI;F1LYG,@
M9F]R(&%T('-E(.9N9')I;F=E<FYE+@!297-E<G9E:V]N9FEG=7)A=&EO;B!G
M96UT+@!297-E<G9E:V]N9FEG=7)A=&EO;F9I;"`E<R!G96UT+@`B)7,B(&]P
M9&%T97)E="X`(B5S(B!S:W)E=F5T+@!3=61A;@!);F1H;VQD`%-O;&]P9V%N
M9P!3;VQN961G86YG`%-O;')I9W0`4V]L;W!G86YG`%-O;&]P9V%N9R]S;VQN
M961G86YG`%-O;&]P9V%N9SH@`%-O;&YE9&=A;F<`4V]L;F5D9V%N9SH@`$CF
M=F5T('-K<FEF=`!(:N9L<`!3=7)I;F%M`$5F=&5R;F%V;@!3=F%L8F%R9"!O
M9R!*86X@36%Y96X`4W=A>FEL86YD`%-V97)I9V4`4V-H=V5I>@!3>6YC(&QO
M9R!S;&5T=&5T`%-Y;F--3`!3>6YT86MS9F5J;"!I('/X9V5L960`4WER:65N
M`%1O<F1E;@!4;W)D96X@;V<@=FEN9`!4;W)D96X`5&]R9&5N('1I9&QI9W0`
M5%-6+69I;`!486)E;`!486)E;"UE9V5N<VMA8F5R`%1A8F5L;>9N9V1E`%1A
M8F5L+65G96YS:V%B97(`5&%I=V%N`%1A:7=A;BP@1&5N(&MI;F5S:7-K92!P
M<F]V:6YS`%1A9&II:VES=&%N`%1A;GIA;FEA`$WE;#H`3W!G879E<@!496QE
M9F]N;G5M;65R`%1E;7`N('-I9'-T92!T:6UE.B``5&5M<&5R871U<@!496UP
M97)A='5R.B``5&5M<&5R871U<CQB<B`O/B@E<TCX:B5S+R5S3&%V)7,I("9D
M96<[)7,`4VMA8F5L;VX@(B5S(B!I:VME(&9U;F1E="X`4VMA8F5L;VXM861M
M:6YI<W1R871I;VX`5&5K<W0`4F5N('1E:W-T`%1E:W-T+6IU<W1E<FEN9P!4
M96MS="UT;W``5&]R`%1H86D@*%1)4RTV,C`I`%1H86EL86YD`$944"UU9'9I
M9&1E;'-E;B!E<B!I:VME('1I;&?F;F=E;&EG+@!(:7-T;W)I:RUS>7-T96UE
M="!E<B!S;.5E="!F<F$N`$AO<F1E+TMO;&%B+6EN=&5G<F%T:6]N<VUO=&]R
M96X@=6YD97)S=/AT=&5R(&EK:V4@(B5S(@!)35-0+6QO9V=E;B!K=6YN92!I
M:VME(&ML87)G^')E<RX`36%I;G1E;F%N8V4Z.BUK;&%S<V5N(&)L978@:6MK
M92!I;F1LYG-T`%1I;'9A;&=S=FEN9'5E="!E<B!B;&5V970@;'5K:V5T+B!!
M9G-L=71T97(N`$%D;6EN:7-T<F%T;W)E;B!B;&EV97(@;OAD="!T:6P@870@
M:V]N9FEG=7)E<F4@96X@<&5R;6%N96YT(%1I;&QA9&5L<V5S+6)A8VME;F0L
M(&AV:7,@9'4@=FEL(&%N=F5N9&4@5&EL;&%D96QS97(N`$MU;B!U;F1E<G-I
M9&5N`$MO;G1A:W0M240M;G5M;65R970@8FQE=B!I:VME(&%N9VEV970L(&5F
M=&5R;&%D="!T;VUT(&5L;&5R(&)L978@:6MK92!F=6YD970@:2!D871A8F%S
M96XN`$MO;G1A:W1E;B!B;&5V('1I;&;X:F5T('1I;"!D:70@861R97-S96MA
M<G1O=&5K970N`$1E;B!L^'-G:F]R=&4@4$=0+7-I9VYA='5R+6)L;VL@97(@
M:W+F=F5T(&9O<B!A="!K=6YN92!V97)I9FEC97)E(&1E;B!S:6=N97)E9&4@
M8F5S:V5D+@!$:7-T<FEB=71I;VYS;&ES=&4M240@97(@96YT96X@:6MK92!A
M;F=I=F5T+"!T;VUT(&5L;&5R(&EK:V4@9G5N9&5T(&D@9&%T86)A<V5N+@!$
M:7-T<FEB=71I;VYS;&ES=&5N(&EK:V4@86YG:79E="X`2W)Y<'1E<FEN9W-F
M86-I;&ET971E<FYE(&MRYG9E<B!E;B!S:6MK97(@=V5B+69O<F)I;F1E;'-E
M+@!&:6QE;B`E<R!B^'(@:6YD96AO;&1E(&5N("5S+6EN9'-T:6QL:6YG+@!&
M:6QE;B`E<R!B^'(@:6YD96AO;&1E(&YO9VQE("5S+6EN9'-T:6QL:6YG97(N
M`$9I;&5N(&MA;B!I:VME(&MO<&EE<F5S(&]V96YPY2!S:6=S96QV+@!&:6QE
M;B!I;F1E:&]L9'0@:6YG96X@9&%T82X`1OAL9V5N9&4@97(@:&]V961E<FYE
M(&9R82!D96YN92!M97-S86=E+W)F8S@R,BUB97-K960N`$9U;&1S:^9R;7-T
M:6QS=&%N9"!V:61E<R!A="!V;VQD92!P<F]B;&5M97(@:2!);G1E<FYE="!%
M>'!L;W)E<B!G<G5N9&5T(&)R;W=S97(M9F5J;"P@<V]M('9I(&EK:V4@:&%R
M(&MU;FYE="!O;6?E+B!$=2!V:6P@;75L:6=V:7,@;W!L979E(&9O<G9A;G-K
M961E('9I<VYI;F=E<BP@;6%N9V5L('#E(&5D:71E<FEN9W-F=6YK=&EO;F5R
M(&]G+V5L;&5R('1I;&;F;&1I9V4@8G)O=W-E<BUN961B<G5D+B!(=FES(&1I
M="!S>7-T96T@97(@5VEN9&]W<R9N8G-P.SEX('9I;"!D=2!M960@:/AJ('-A
M;F1S>6YL:6=H960@;W!L979E("='96YE<F5L(&)E<VMY='1E;'-E<V9E:FPG
M(&]G('9I;"!B;&EV92!N^&1T('1I;"!A="!G96YS=&%R=&4@;6%S:VEN96XN
M7&Y<;D1U(&5R(&YU(&%D=F%R970N("!4<GEK($]+(&AV:7,@9'4@<W1A9&EG
M(/AN<VME<B!A="!P<OAV970@9G5L9'-KYG)M<W)E9&EG97)I;F<N`$ED96YT
M:71E=&5N("(E<R(@97(@<VQE='1E="X`2W5N('9E;G-T<F4@<VED92X`4&QA
M8V5R:6YG96X@868@1VYU4$<M<')O9W)A;6UE="!S:V%L(&=I=F5S('1I;"!#
M<GEP=%]P9W`Z.BUK;&%S<V5N+@!"97-K961E;BP@<V]M(&5R('-E;F1T(&1E
M;B`E<R!T:6P@)7,@;65D(&5M;F5T("(E<R(@97(@8FQE=F5T('9I<W0N"D1E
M='1E(&5R(&EN9V5N(&=A<F%N=&D@9F]R+"!A="!B97-K961E;B!R96YT(&9A
M:W1I<VL@97(@8FQE=F5T(&SF<W0@96QL97(@9F]R<W3E970N`$YA=FYE="P@
M9&5R('-K86P@8G)U9V4L(&[E<B!D97(@:&5N=FES97,@=&EL('-K<FEV97-I
M9&5N`$%N=&%L;&5T(&%F(&9E;'1E<B!S:V%L(';F<F4@970@=&%L+@!O<&5N
M<W-L+6UO9'5L970@97(@:W+F=F5T(&%F($AO<F1E7T-R>7!T7W-M:6UE.CHM
M:VQA<W-E;BX`4'+F9F5R96YC96X@(B5S(B!K=6YN92!I:VME(&=E;6UE<R!F
M;W)D:2!D96YS(&1A=&$@;W9E<G-K<FED97(@9&5N(&UA:W-I;6%L="!T:6QL
M861T92!S=/AR<F5L<V4`4')O9W)A;6UE="P@9&5R(&)R=6=E<R!T:6P@870@
M8F5T<F%G=&4@9&5N;F4@9&%T871Y<&4@*"5S*2P@8FQE=F5T(&EK:V4@9G5N
M9&5T('#E('-Y<W1E;65T+@!#:71A=&EO;G-T96=N970@<VMA;"!VYG)E(&5T
M(&5N:V5L="!T96=N+@!+=6X@:/AJ<F4@;V<@=F5N<W1R92!S:61E`$MU;B!S
M:61E;B!T:6P@:/AJ<F4`061S:VEL;&5L<V5S=&5G;F5T('-K86P@=N9R92!E
M="!E;FME;'0@=&5G;BX`4V5R=F5R96X@(B5S(B!E<B!S;&5T=&5T+@!397)V
M97)E;B`B)7,B(&5R(&=E;70N`$]P<VMR:79N:6YG<V%N;6]D;FEN9V5N(&9O
M<B`E<R!E<B!S;&5T=&5T+@!$96X@86YG:79N92!RYFMK92`H)60I(&5K<VES
M=&5R97(@:6MK92X`1&5N(&%N9VEV;F4@<N9K:V4@96MS:7-T97)E<B!I:VME
M+@!$96X@;6ED;&5R=&ED:6=E(&9I;"`B)7,B(&9I;F1E<R!I:VME+@!$96X@
M=&5K<W0L('-O;2!D=2!I;F1T87-T961E+"!P87-S97(@:6MK92!T:6P@=&5K
M<W1E;B!PY2!S:^9R;65N+@!+=6X@=&]P(&]G(&)U;F0`2W5N('1O<`!$96X@
M869S96YD=&4@:6YF;W)M871I;VX@97(@=&%B="!S:61E;B!S:61S=&4@=')I
M;BX`1&5N(&]V97)F^')T92!F:6P@:W5N;F4@:6MK92!G96UM97,N`'=E871H
M97(N8V]M+6)L;VMK96X@97(@:6MK92!T:6QGYFYG96QI9RX`5&5M82UK871A
M;&]G970@(B5S(B!I:VME(&9U;F1E="X`26YG96X@=&EL=F%L9R!T:6P@<N5D
M:6=H960N`$1E<B!F;W)E9FEN9&5S(&EN9V5N(&1E;&4L('-O;2!K86X@=FES
M97,@:6YD;&5J<F5T+@!$97(@97(@9F]R(&UA;F=E('1E9VX@:2!D971T92!F
M96QT+B!$=2!H87(@:6YD=&%S=&5T("5S('1E9VX[(&1U('-K86P@:6YD=&%S
M=&4@;6EN9')E(&5N9"`E<RX`1&5R(&]P<W1O9"!E="!P<F]B;&5M('5N9&5R
M('1I;&;X:F5L<V5N(&%F("<E<R<@=&EL('-Y<W1E;65T.B`E<P!$97(@;W!S
M=&]D(&5T('!R;V)L96T@=6YD97(@9FIE<FYE;'-E(&%F(&1A=&$@9F]R(&)R
M=6=E<B`B)7,B(&9R82!S>7-T96UE=#H@`$1E<B!O<'-T;V0@970@<')O8FQE
M;2!U;F1E<B!S;&5T;FEN9R!A9B`B)7,B(&9R82!S>7-T96UE=#H@`$1E<B!O
M<'-T;V0@970@<')O8FQE;2!U;F1E<B!O<&1A=&5R:6YG(&%F("(E<R(Z("5S
M`$1E<B!O<'-T;V0@970@<')O8FQE;2!U;F1E<B!F:6QO=F5R9OAR<VQE;CH@
M26YG96X@)7,@8FQE=B!O=F5R9OAR="X`1&5R(&]P<W1O9"!E="!P<F]B;&5M
M('5N9&5R(&9I;&]V97)F^')S;&5N.B`E<R!V87(@<W3X<G)E(&5N9"!D96X@
M;6%K<VEM86QT('1I;&QA9'1E('-T^')R96QS92`H)60@8GET97,I+@!$97(@
M;W!S=&]D(&5T('!R;V)L96T@=6YD97(@9FEL;W9E<F;X<G-L96XZ("5S(&)L
M978@:W5N(&1E;'9I<W0@;W9E<F;X<G0N`$1E<B!O<'-T;V0@96X@9F5J;"!U
M;F1E<B!V:7-N:6YG(&%F(&1E;FYE(&)E<VME9&1E;`!$97(@;W!S=&]D(&5N
M(&9E:FP@=6YD97(@:6UP;W)T97)I;F=E;B!A9B!K;VYT86MT:6YF;W)M871I
M;VXN`$1E<B!O<'-T;V0@96X@9F5J;"!U;F1E<B!I;7!O<G1E<FEN9V5N(&%F
M(&E#86QE;F1A<B!D871A+@!$97(@;W!S=&]D(&5N(&9E:FP@:2!K;VYF:6=U
M<F%T:6]N<V9O<FUU;&%R96XN($YU;&EG=FES(&AA<B!D=2!U9&5L861T(&5T
M(&MRYG9E="!F96QT+@!$97(@;W!S=&]D(&5T('!R;V)L96T@=6YD97(@=61F
M^')E;'-E(&%F(&1E;B!A;F=I=FYE(&%D<F5S<V5K87)T;W1E:W-F=6YK=&EO
M;BX@4'+X=B!I9V5N+@!$97(@;W!S=&]D(&5N(&9E:FP@=6YD97(@;W!D871E
M<FEN9R!A9B!K;VYT86MT+61E=&%L:F5R;F4N(%!R^'8@:6=E;BX`1&5R(&]P
M<W1O9"!E;B!F96IL('5N9&5R(&]P9&%T97)I;F<@868@9&ES=')I8G5T:6]N
M<VQI<W1E;BX@4'+X=B!I9V5N+@!$96YN92!)34%0+7-E<G9E<B!U;F1E<G-T
M^'1T97(@:6MK92!D96QI;F<@868@;6%P<&5R+@!$971T92!T>61E<B!I:VME
M('#E(&%T(';F<F4@970@9WEL9&EG="!R87(M87)K:78N`$1E;FYE('1Y9&5R
M(&EK:V4@<.4@870@=N9R92!E;B!G>6QD:6<@>FEP+69I;"X`1&5T=&4@='ED
M97(@:6MK92!PY2!A="!VYG)E(&5T(&=Y;&1I9W0@:V]R=&YU;6UE<BX`1&5N
M;F4@9')I=F5R('1I;&QA9&5R(&%F<V5N9&5L<V4@868@8F5S:V5D97(@:6=E
M;FYE;2!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&%D9V%N
M9W-P=6YK=&5T('9E9"!B<G5G(&%F($A45%`@05!)`$1E;FYE(&1R:79E<B!T
M:6QL861E<B!A9G-E;F1E;'-E(&%F(&)E<VME9&5R(&EG96YN96T@5TE.("AH
M='1P.B\O=VEN<&QC+F-O;2D@861G86YG<W!U;FMT970@=F5D(&)R=6<@868@
M2%144"!!4$D`1&5N;F4@9')I=F5R('1I;&QA9&5R(&%F<V5N9&5L<V4@868@
M8F5S:V5D97(@:6=E;FYE;2!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN
M8V]M*2!A9&=A;F=S<'5N:W1E="!V960@8G)U9R!A9B!(5%10($%020!$96YN
M92!D<FEV97(@=&EL;&%D97(@869S96YD96QS92!A9B!B97-K961E<B!V:6$@
M4TU44"!I9V5N;F5M(%9O9&%F;VYE($ET86QI96X@861G86YG<W!U;FMT970L
M(&1O9R!K=6X@=&EL(%9O9&%F;VYE+6YU;7)E+B!$96X@:W+F=F5R(&5N(&4M
M;6%I;&MO;G1O(&AO<R!6;V1A9F]N92!)=&%L:65N("AH='1P.B\O=W=W+C$Y
M,"YI="DN`$1E='1E(&9E;'0@97(@:W+F=F5T+@!$971T92!F96QT(&WE(&MU
M;B!I;F1E:&]L9&4@:&5L=&%L+@!$971T92!F96QT(&WE(&MU;B!I;F1E:&]L
M9&4@;G5M<F4@;V<@:V]L;VXN`$1E='1E(&9E;'0@;>4@:W5N(&EN9&5H;VQD
M92!O:W1A;&4@=N9R9&EE<BX`1&5T=&4@9F5L="!S:V%L(';F<F4@96X@:V]M
M;6$M(&5L;&5R(&UE;&QE;7)U;7-A9'-K:6QD="!L:7-T92!A9B!H96QT86P`
M1&5T=&4@9F5L="!S:V%L(';F<F4@970@9WEL9&EG="!N=6UM97(N`$1E='1E
M(&9E;'0@<VMA;"!I;F1E:&]L9&4@96X@9F%R=F5K;V1E(&D@4D="(&AE>"UF
M;W)M870L(&9X("<C,3(S-&%F)RX`1&5N;F4@9F]R;75L87(@97(@86QL97)E
M9&4@<')O8V5S<V5R970N`$1E='1E(&5R("5S+@!$971T92!E<B!E="!+;VQA
M8B!'<F]U<'=A<F4M;V)J96MT+B!&;W(@870@<V4@9&5T=&4@;V)J96MT(&AA
M<B!D=2!B<G5G(&9O<B!E;B!E+6UA:6PM:VQI96YT+"!S;VT@9F]R<W3E<B!+
M;VQA8B!'<F]U<'=A<F4M9F]R;6%T970N($)E<_AG("5S(&9O<B!E;B!L:7-T
M92!A9B!K;&EE;G1E<BX`1&5N;F4@8F5S:V5D(&5R('-K<F5V970@;65D(&5T
M(&%N9&5T('1E9VYSYG0@*"5S*2!E;F0@9&ET(&5G970N`%1A;&QE="!S:V%L
M(';F<F4@;6EN+B`Q+@!$96YN92!S97)V97(@:V%N(&EK:V4@9&5K;VUP<FEM
M97)E('II<"T@;V<@9WII<"UF:6QE<BX`1&5T=&4@<WES=&5M(&5R(&1E86MT
M:79E<F5T+@!$96YN92!VYG)D:2!S:V%L(';F<F4@970@=&%L+@!$971T92!V
M:6YD=64@<VMA;"!K86QD97,@9G)A(&5T(%1I;'9A;&=S=FEN9'5E`%1O<F1E
M;@!386=E<@!4:60`5&ED<V]P9_AR96QS90!4:61S9F]R;6%T`%1I9'-V86QG
M`%1I;6]R+4QE<W1E`%1I=&5L`%1I=&QE("AT;V]L=&EP*3H`5&EL`$9O<B!A
M="!VYFQG92!M=6QT:7!L92!I;F1G86YG92!S:V%L($-T<FPM("A00RD@96QL
M97(@0V]M;6%N9"`H36%C*2UT87-T96X@:&]L9&5S(&YE9&4@;65D96YS(&1E
M<B!K;&EK:V5S+@!)($1A9P!3:VEF="!(5$U,+6MI;&1E`%1O9V\`5&]K96QA
M=0!)(&UO<F=E;@!4;VYG80!&;W(@;6%N9V4@=6=Y;&1I9V4@;&]G:6YD+69O
M<G/X9R!I(&SX8F5T(&%F(&1E('-I9'-T92!M:6YU='1E<BX`5&]P`%1O<"!F
M<F%M92`H7W1O<"D`3W9E<G/F='1E;'-E<@!4<FEN:61A9"!O9R!4;V)A9V\`
M4V%N9"!E;&QE<B!F86QS:P!4:7(`5'5N97-I96X`5'ER:VEE=`!4>7)K:7-K
M("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@;V<@0V%I8V]S(-AE
M<FYE`%1U=F%L=0!3:W)I=B!D:70@=F%L9SH@`%4N5BXM:6YD96MS.B``55),
M`%523"!F;W(@<VMR:7!T('1I;"!M;V1T86=E;'-E(&%F('-T871U<R!R87!P
M;W)T96X`55),.@!59V%N9&$`56MR86EN90!+=6YN92!I:VME('1I;&?E(%9&
M4RUK871A;&]G+@!+86X@:6MK92!T:6QF^&IE(&5K<W1R82!B<G5G97(@:6YF
M;W)M871I;VX@=6YD97(@;W!S:W)I=FYI;F<N`$MA;B!I:VME(.9N9')E('1I
M;&QA9&5L<V5R(&9O<B!61E,M9FEL("(E<R(N`$MA;B!I:VME(.9N9')E('1I
M;&QA9&5L<V5R(&9O<B!61E,M9FEL("5S+R5S+@!+86X@:6MK92!S:VEF=&4@
M=&EL("5S+@!+86X@:6MK92!T:F5K:V4@9FEL<W3X<G)E;'-E;B!A9B`B)7,B
M+@!+86X@:6MK92!T:F5K:V4@9FEL<W3X<G)E;'-E;B!A9B`B)7,O)7,B+@!+
M=6YN92!I:VME(&;E(&9O<F)I;F1E;'-E('1I;"!344P@<V5R=F5R96XN`$MA
M;B!I:VME(&;E(&9O<F)I;F1E;'-E(&UE9"!34TPN`$MA;B!I:VME(&MO<&EE
M<F4@5D93+69I;"X`2V%N(&EK:V4@9&%N;F4@5D93+6MA=&%L;V<@(B5S(BX`
M2V%N(&EK:V4@9&%N;F4@5D93+6MA=&%L;V<N`$MA;B!I:VME(&QA=F4@5D93
M+69I;"X`2V%N(&EK:V4@;W!R971T92!61E,M;6%P<&4@(B5S(BX`2V%N(&EK
M:V4@;&%V92!T;VT@5D93+69I;"X`2V%N(&EK:V4@9&5K;VUP<FEM97)E(&1A
M=&$N`$MA;B!I:VME('-L971T92`B)7,B.R!K871A;&]G970@97(@:6MK92!T
M;VUT+@!+86X@:6MK92!S;&5T=&4@(B5S(CH@)7,N`$MA;B!I:VME('-L971T
M92`E<SL@:V%T86QO9V5T(&5R(&EK:V4@=&]M=`!+86X@:6MK92!S;&5T=&4@
M5D93+6MA=&%L;V=E="!R96MU<G-I=G0N`$MA;B!I:VME('-L971T92!61E,M
M:V%T86QO9RX`2V%N(&EK:V4@<VQE='1E(%9&4RUK871A;&]G.B`E<RX`2V%N
M(&EK:V4@<VQE='1E(%9&4RUF:6P@(B5S(BX`2V%N(&EK:V4@<VQE='1E(%9&
M4RUF:6PN`$MA;B!I:VME('-L971T92!61E,M;6%P<&4@(B5S(BX`2V%N(&EK
M:V4@<VQE='1E(%9&4R!R96MU<G-I=G0Z("5S+@!+86X@:6MK92!B97-T96UM
M92!A:W1U96QT(&MA=&%L;V<N`$MA;B!I:VME('5D9')A9V4@8V5R=&EF:6MA
M="UD971A;&IE<@!+86X@:6MK92!I;F1LYG-E(&1E9FEN:71I;VYE;B!A9B`E
M<RX`2V%N(&EK:V4@9FQY='1E(%9&4RUF:6PN`$MA;B!I:VME(.5B;F4@5D93
M+69I;"`B)7,B+@!+86X@:6MK92#E8FYE(%9&4RUF:6P@=&EL('-K<FEV;FEN
M9RX`2V%N(&EK:V4@Y6)N92!61E,M9FEL+@!+86X@:6MK92#E8FYE(&MO;7!R
M:6UE<F5T(&%R:VEV+@!+86X@:6MK92!LYG-E(%9&4RUF:6P@*&9I;&5S:7IE
M*"D@9F5J;&5D92DN`$MA;B!I:VME(&SF<V4@5D93+69I;"`H9V5T1FEL95-I
M>F4H*2!F96IL961E*2X`2V%N(&EK:V4@;.9S92!F:6PZ(`!+86X@:6MK92!L
MYG-E('9F<W)O;W0M:V%T86QO9V5T+@!+86X@:6MK92!O;63X8F4@)7,@=&EL
M("5S.B!MY6QM87!P96X@9FEN9&5S(&%L;&5R961E`$MA;B!I:VME(&]M9/AB
M92!61E,M:V%T86QO9RX`2V%N(&EK:V4@;VUD^&)E(%9&4RUK871A;&]G.B`E
M<RX`2V%N(&EK:V4@;VUD^&)E(%9&4RUF:6P@(B5S(BX`2V%N(&EK:V4@;VUD
M^&)E(%9&4RUF:6P@)7,O)7,N`$MA;B!I:VME(&]M9/AB92!61E,M9FEL+@!+
M86X@:6MK92!A9G9I:VQE("=M:VES;V9S)RX`2W5N;F4@:6MK92!O=F5R<^9T
M=&4@9&5T=&4@5V]R9"!D;VMU;65N=`!+86X@:6MK92!S:W)I=F4@5D93+69I
M;"`B)7,B+@!+86X@:6MK92!S:W)I=F4@5D93+69I;"`H8V]P>2@I(&9E:FQE
M9&4I+@!+86X@:6MK92!S:W)I=F4@5D93+69I;&1A=&$N`$MA;B!I:VME('-K
M<FEV92!61E,M9FEL.R!K=F]T96X@=FEL(&)L:79E(&]V97)S:W)E9&5T+@!5
M;F1E<FQI;FEE<F5T`$9O<G1R>60@YFYD<FEN9V5R`$]M9_AR(&1I;B!S:61S
M=&4@:&%N9&QI;F<`579E;G1E="!R96%K=&EO;B!F<F$@<V5R=F5R('#E(&9O
M<F)I;F1E;'-E;CH@`%5V96YT970@<F5A:W1I;VX@9G)A('-E<G9E<B!PY3H@
M`$EK:V4@86YB<F%G=`!5;FEC;V1E("A55$8M."D`1F]R96YE9&4@07)A8FES
M:V4@16UI<F%T97(`4W1O<F)R:71T86YI96X`55-!`%5307,@=6YD97)O<F1N
M961E(/AE<@!%;FAE9&5R`%5K96YD=`!5:V5N9'0@87!I;7-G:60@*$%022!-
M97-S86=E($E$*2X`56ME;F1T(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)
M1"DN`%5K96YD="!S=&5D(&%N9VEV970N`%5K96YD="!B<G5G97)N879N(&5L
M;&5R(&MO9&5O<F0N`$CF9W0@86MT=65L="!E;&5M96YT(&%F+@!):VME(&YA
M=FYG:79E=`!5<')I=FEL:6=E<F5D92!S:W)I<'1E<B!K86X@:6MK92!T:6QG
MY2!K;&EP<&4O:V]P:2]I;F1SYG0@<')O9W)A;6WF<W-I9W0@868@<VEK:V5R
M:&5D<^5R<V%G97(N("!+;&EK($]+(&9O<B!A="!S92!E;B!T96MN:7-K(&YO
M=&4@:&]S(&UO>FEL;&$N;W)G+"!S;VT@=FES97(@9&EG+"!H=F]R9&%N(&1U
M(&MA;B!T:6QL861E(&5T('-K<FEP="!A="!T:6QGY2!U9&ML:7!S:&]L9&5R
M96XN`$9A<G9E(&EK:V4@:6YD<W1I;&QE=`!59'9I9&1E;'-E(&EK:V4@=6YD
M97)S=/AT=&5T`$]P9&%TZ7(`3W!D873I<B`E<P!/<&1A=.ER(&)R=6=E<@`B
M)7,B(&]P9&%T97)E="X`3W!G<F%D97)I;F=S+69O<F5S:W)I9G0@<VQE='1E
M="X`57!L;V%D`$]P<^9T;FEN9W-F:6QE<B!T:6P@86QL92!A<'!L:6MA=&EO
M;F5R(&QA9W0@;W`@<.4@<V5R=F5R+@!3=&]R92!L871I;G-K92!B;V=S=&%V
M97(`4W1O<F4@<F]M97)T86P`57)U9W5A>0!!;G9E;F0@;G5VYG)E;F1E.B`E
M<P!"<G5G(%-33`!"<G5G(&AV:7,@;F%V;B]K;V1E;W)D(&5R(&9O<G-K96QL
M:6<@9F]R($E-4U`M<V5R=F5R+@!"<G5G97(`0G)U9V5R("5S(&EK:V4@8F5M
M>6YD:6=E="!T:6P@)7,N`$)R=6=E<BUA9&UI;FES=')A=&EO;@!"<G5G97)I
M;F1S=&EL;&EN9V5R`$)R=6=E<BUR96=I<W1R97)I;F<`0G)U9V5R+7)E9VES
M=')E<FEN9R!E<B!B;&5V970@<VSE970@9G)A('#E(&1E='1E('=E8G-T960N
M`$)R=6=E<FMO;G1O(&EK:V4@9G5N9&5T`$)R=6=E<FYA=FX`0G)U9V5R;F%V
M;B`B)7,B(&9I;F1E<R!A;&QE<F5D92X`0G)U9V5R;F%V;CH`0G)U9V5R;F%V
M;CH@`$)R=6=E<F4@:2!S>7-T96UE=#H`57-B96MI<W1A;@!61E,M:V%T86QO
M9R!E:W-I<W1E<F5R(&EK:V4N`$9E<FEE`$=Y;&1I9V4@9G5N9&5T('-T961E
M<B!I;FML=61E<F5R.@!'>6QD:6=H960`5N9R9&D@97(@;6EN=71T97(@9G)A
M(&YU+@!6YG)D:2!E<B!M97)E(&5N9"!D96X@;6%K<VEM86QE(&SF;F=D92!A
M9B`E<RX`5N9R9&EE<@!6YG)D:65R+"!D97(@:V%N(';F;&=E<R!I8FQA;F1T
M`%9A;G5A='4`4VMI9G1E;F1E`%9E;F5Z=65L80!%9G1E<G!R^'9N:6YG(&9E
M:FQE9&4@+2!D97(@97(@8FQE=F5T('!I;&QE="!V960@9&5N;F4@8F5S:V5D
M+@!697)S:6]N`%9E<G-I;VYS:V]N=')O;`!,;V1R970@;W!S=&EL;&EN9P!,
M;V1R970@9F]R<FEN9P!,;V1R970Z`$UE9V5T(&CX:@!6:65T;F%M`%9I971N
M86UE<VES:R`H5DE30TE)*0!6:7,@)7,`4V4@<.4@96MS=&5R;B!W96)S:61E
M`%9I<R!S;VT@)7,`2F]M9G)U^&5R+"!"<FET:7-K90!*;VUF<G7X97(L($%M
M97)I:V%N<VME`%-Y;FQI9VAE9`!3>6YL:6=H960Z(`!6;V1A9F]N92!)=&%L
M:65N('9I82!33510`%=!4DX`041605)314PA(2$@1DI%4DX@4T-225!4($U!
M3E5%3%0@1E)!("5S+@!724X@=FEA($A45%``5V%L;&ES(&]G($9U='5N80!!
M9'9A<G-E;`!/;G,`5F5J<G5D<VEG=`!696IR:6YF;W)M871I;VX@<W1I;&QE
M="!T:6QRY61I9VAE9"!A9@!796%T:&5R+F-O;0!796(`5V5B<VET90!59V5N
M=&QI9P!696QK;VUM96X`5F5L:V]M;65N('1I;"`E<P!696QK;VUM96XL("5S
M`%9E<W1L:6<@*$E33RTX.#4Y+3$I`%9E<W1L:6<@*$E33RTX.#4Y+3$U*0!6
M97-T<V%H87)A`$AV:6QK96X@87!P;&EK871I;VX@<VMA;"`E<R!V:7-E(&5F
M=&5R(&QO9VEN9#\`2'9A9"!E<B!S97!A<F%T;W)T96=N970_`$AV860@97(@
M8VET871I;VYS=&5G;F5T/P!7:&5R96ES($%U<W1R86QI96XM:V]R=`!(=FEL
M:V4@9F%S97(`2'9I;&ME('!L=6=I;G,@<VMA;"!A:W1I=F5R97,@9F]R(%)I
M8V@@5&5X="UVYG)K=/AJ970N`$)R961D90!"<F5D9&4@:2!#4U,M96YH961E
M<@!"<F5D9&4@868@)7,M;65N=65N('1I;"!V96YS=')E("AB;&EV97(@86MT
M:79E<F5T('9E9"!NYG-T92!L;V=I;F0I.@!"<F5D9&4@868@=&%B96QL96X`
M0G)E9&1E+65N:&5D`$)R961D93H`5VEK:0!6:6YD`$)LYG-T('1I9&QI9W0`
M5FEN9&AA<W1I9VAE9"!I(&MN;V(`5FEN9#H`5FEN9#H@`%9I<V1O;0#8;G-K
M96QI<W1E`$%R8F5J9&4`061R97-S92`H87)B96ID92D`5&5L969O;B`H87)B
M96ID92D`1F]R:V5R="!A;G1A;"!F96QT97(@:2!L:6YI92`E9"X@1F]R=F5N
M=&5D92`E9"P@9F%N9'0@)60N`$9O<FME<G0@86YT86P@9F5L=&5R+B!&;W)V
M96YT961E("5D+"!F86YD="`E9"X`1F]R:V5R="!F;W)S:WED;FEN9R`E9"!U
M;F1E<B!I;F1LYG-N:6YG(&%F(&5N(%9&4RUF:6PN`%@M4F5F`%@U,#EV,R!"
M87-I8R!#;VYS=')A:6YT<P!8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E`%@U
M,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64`6#4P.78S(%-U8FIE8W0@
M2V5Y($ED96YT:69I97(`6#4P.78S('5D=FED9&5L<V5R`,7%`,7%Q<4`66%H
M;V\A+6MO<G0`Q7)L:6<`665M96X`2F$`2F$L(&IE9R!E<B!E;FEG`$1U(&)E
M9FEN9&5R(&1I9R!I(%1%2U-4($U/1%53+B`@0G)U9R!;/#Y=+6MN87!P96X@
M=&EL(&%T('-K:69T92!T:6QB86=E('1I;"!765-)5UE'+@!$=2!H87(@:6MK
M92!T:6QL861E;'-E('1I;"!A="!O<')E='1E(&UE<F4@96YD("5D(&)L;VMK
M92X`1'4@97(@:6MK92#F9W1E="X`1'4@:V%N(&EK:V4@:&%V92`G7"<M=&5G
M;F5T(&D@9&ET(&9U;&1E(&YA=FXN`$1U(&EN9'1A<W1E9&4@:6MK92!E;B!G
M>6QD:6<@92UP;W-T+6%D<F5S<V4N`$9O<B!A="!I;7!O<G1E<F4@<VMA;"!D
M=2!T:6QO<F1N92!F96QT97(@9G)A(&1E;B!F:6P@9'4@:6UP;W)T97)E<B!T
M:6P@9&4@=&EL<W9A<F5N9&4@9F5L=&5R(&D@)7,N`$1U(&5R(&)L979E="!L
M;V=G970@=60N`$1U('-K86P@:6YD=&%S=&4@970@9G5N9V5R96YD92!M;V)I
M;&YU;6UE<CL@:W5N(&-I9G)E(&UE9"!E="!V86QG9G)I("<K)R!F;W(@9&5N
M(&EN=&5R;F%T:6]N86P@<F5T;FEN9W-K;V1E+@!$=2!S:V%L(&EN9'1A<W1E
M(&5N(&=Y;&1I9R!VYG)D:2X`1'4@<VMA;"!K;VYF:6=U<F5R92!E;B!$871A
M5')E92UB86-K96YD(&9O<B!A="!K=6YN92!A;G9E;F1E($]P<VMR:79N:6YG
M97(N`$1U('-K86P@:V]N9FEG=7)E<F4@96YD(%9&4RUB86-K96YD+@!$=2!B
M;&EV97(@;OAD('1I;"!A="!L879E(&5N('!R;V)L96UB97-K<FEV96QS92P@
M9OAR(&1U(&MA;B!S96YD92!D96X@:6YD+@!$=2!S:V%L(&EN9'1A<W1E(&1E
M;B!54DP@:'9O<G1I;"!D96YN92!HYF=T92!S:V%L(&AE;G9I<V4`1'4@<VMA
M;"!VYFQG92!D96X@<V5R=F5R+"!S;VT@<VMA;"!S;&5T=&5S+@!$=2!S:V%L
M(&%N9VEV92!B<G5G97)N879N970L('-O;2!D=2!V:6P@9FIE<FYE+@!$=2!S
M:V%L(&%N9VEV92!B<G5G97)N879N970L('-O;2!D=2!V:6P@9FIE<FYE+@!$
M=2!S:V%L(&%N9VEV92!B<G5G97)N879N970L('-O;2!D=2!V:6P@=&EL9OAJ
M92X`1'4@<VMA;"!A;F=I=F4@8G)U9V5R;F%V;F5T+"!S;VT@9'4@=FEL(&]P
M9&%T97)E+@!$=2!S:V%L(&%N9VEV92!D96X@:&%N9&QI;F<L('-O;2!S:V%L
M('5D9OAR97,N`$1U('-K86P@86YG:79E(&5T(&YY="!K871E9V]R:6YA=FXN
M`$1U(&)L:79E<B!N^&1T('1I;"!A="!A;F=I=F4@970@:71A;&EE;G-K92!T
M96QE9F]N;G5M;65R`$1I;B`E<R!S97-S:6]N(&5R('5D;/AB970N($QO9R!V
M96YL:6=S="!I;F0@:6=E;BX`1&EN(&4M<&]S="UA9')E<W-E`$1I;B!&<F]M
M.B!A9')E<W-E.@!$:6YE(&EN9F]R;6%T:6]N97(`1&EN($EN=&5R;F5T+6%D
M<F5S<V4@97(@<VMI9G1E="!S:61E;B!B96=Y;F1E;'-E;B!A9B!D:6X@)7,M
M<V5S<VEO;BX@1F]R(&%T(&)E<VMY='1E(&1I;B!S:6MK97)H960@8FQI=F5R
M(&1U(&[X9'0@=&EL(&%T(&QO9V=E(&EN9"!I9V5N+@!$:70@;F%V;@!$:6X@
MYF=T;FEN9W,M8F%C:V5N9"!U;F1E<G-T^'1T97(@:6MK92!T:6QF^&IE;'-E
M;B!A9B!B<G5G97)E+B!(=FES(&1U(/AN<VME<B!A="!B<G5G92!(;W)D92!T
M:6P@870@861M:6YI<W1R97)E(&)R=6=E<FMO;G1I+"!B;&EV97(@9'4@;OAD
M="!T:6P@870@8G)U9V4@96X@86YD96X@YF=T;FEN9W,M8F%C:V5N9"X`1&EN
M(&%U=&]R:7-A=&EO;G,M8F%C:V5N9"!U;F1E<G-T^'1T97(@:6MK92!O<&QI
M<W1N:6YG96X@868@8G)U9V5R92!E;&QE<B!E<B!D96X@9G5N:W1I;VX@868@
M96X@96QL97(@86YD96X@9W)U;F0@8FQE=F5T('-LY65T(&9R82X`1&EN(&)R
M;W=S97(@<WEN97,@870@=N9R92!S:VEF=&5T('-I9&5N(&)E9WEN9&5L<V5N
M(&%F(&1I;B`E<RUS97-S:6]N+B!&;W(@870@8F5S:WET=&4@9&EN('-I:VME
M<FAE9"P@<VMA;"!D=2!L;V=G92!I;F0@:6=E;BX`1&EN(&)R;W=S97(@=6YD
M97)S=/AT=&5R(&EK:V4@9&5N;F4@9G5N:W1I;VYA;&ET970N`$1I;B!B<F]W
M<V5R('5N9&5R<W3X='1E<B!I:VME(&1E;FYE('!R:6YT+6UU;&EG:&5D+B!4
M<GEK($-T<FPO0V]M;6%N9"`K(%`@9F]R(&%T('!R:6YT92X`1&EN(&%K='5E
M;&QE('1I9'-Z;VYE.@!$:6X@9F]R=F%L9W1E(&ED96YT:71E="!E<B#F;F1R
M970N`$1I;B!S=&%N9&%R9"UI9&5N=&ET970Z`$1I="!F=6QD92!N879N.@!$
M:70@;&]G:6YD(&5R('5D;/AB970N`$1I="!N>64@:V]D96]R9"!F;W(@)7,@
M97(Z("5S`$1I;F4@=&EL=F%L9R!E<B!B;&5V970@;W!D871E<F5T(&9O<B!V
M87)I9VAE9&5N(&%F(&1E;FYE('-E<W-I;VXN`$1I;F4@=&EL=F%L9R!E<B!O
M<&1A=&5R970N`$1I="!K;V1E;W)D(&5R(&)L979E="!N=6QS=&EL;&5T`$1I
M="!K;V1E;W)D(&5R(&)L979E="!N=6QS=&EL;&4[(&MO;G1R;VQLZ7(@9&EN
M(&EN9&)A:VME(&]G(&QO9R!I;F0@;65D(&1I="!N>64@:V]D96]R9"X`1&ET
M(&MO9&5O<F0@97(@=61L^&)E="X`1&EN92!F:F5R;F4@<V5R=F5R93H`2G5G
M;W-L879I96X`6F'O<F4`6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M3:VIU;"!C
M:71E<F5T('1E:W-T70!;4')O8FQE;6)E<VMR:79E;'-E70!;5FES(&-I=&5R
M970@=&5K<W0@+0!;5FES(&-I=&5R970@=&5K<W0@+2`E<R!L:6YI97)=`%ML
M:6YI92`E<R!U9"!A9B`E<UT`061M:6YI<W1R871I;VX`0TQ)`$1A=&%4<F5E
M`%-L970@<N9K:V4`1W)U<'!E<@!(:N9L<`!":6QL960M96=E;G-K86)E<BXN
M+@!,;V<@:6YD`$QO9R!U9`#&;F1R:6YG(&AE;G9I<VYI;F<N+BX`26YD<W1I
M;&QI;F=E<@!4:6QL861E;'-E<@!3;&5T(&AE;G9I<VYI;F<N+BX`3W!SYG1N
M:6YG`%1A8F5L+65G96YS:V%B97(N+BX`0G)U9V5R90!A9')E<W-E:V%R=&]T
M96L`861R97-S96YT('5K96YD=`!K86QE;F1E<@!V:6YD<W1I;&QE`&MA;B!I
M:VME(&1A;FYE('5D9&%T82UF:6P`:V%N(&EK:V4@Y6)N92!I;F1D871A`&ML
M:6L@:&5R`&9E:FP@=F5D(&%N=F5N9&5L<V4@868@:V]M;6%N9&\M;&EN:64`
M:V]N9FEG=7)A=&EO;G-F96IL`&UA;F=L97(@:W)I=&ES:R!S>7-T96UF:6P`
M9F5J;"!I(&1A=&%F;W)M870`<F5D:6=E<@!I;F1G86YG(&EK:V4@9G5N9&5T
M`&9A;&1E;F1E`&9I;`!F<F$@)7,@*"5S*2!M960@)7,@)7,`<W1O<FUF=6QD
M`&@Z`&AH`'5K96YD="!M87-K:6YN879N`/AJ96)L:6MK96QI9W0`:6YD;&5J
M<F5T`&EN9&1A=&$O=61D871A+69E:FP`:6YT97)N('-O9G1W87)E+69E:FP`
M;&EN:65R70!M:VES;V9S(&9E:FQK;V1E("5D('5N9&5R(&1A;FYE;'-E(&%F
M($E33RX`;6T`;F%V;@!I:VME(&EM<&QE;65N=&5R970`96YD;G4@:6MK92!I
M;7!L96UE;G1E<F5T`&YO=&5S8FQO:P!P<F]C96YT`'1I;&QA9&5L<V4@;N9G
M=&5T`'!R:6MK97(`9F5J;"!I('!R;W1O:V]L(&9R82!F:F5R;B!S:61E`'-T
M:6=E;F1E`'1J96YE<W1E('5T:6QGYFYG96QI9P!V:7,@9F]R<VME;&QE`'-M
M<S)E;6%I;"!V:6$@2%144`!S<P!S=&%B:6QT`'-Y<W1E;69E:FP`;W!G879E
M;&ES=&4`;6ED;&5R=&ED:6<@9F5J;'1I;'-T86YD`&EN9'1A<W0@:V]D96]R
M9&5T('1O(&=A;F=E(&9O<B!A="!B96MRYF9T90!S86UM96YS;65L=&5T`'5N
M879N9VEV96X`8G)U9V5R=F%L9P!V0V%R9`!W.@!W96%T:&5R+F-O;0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+V1A
M7T1++VAE;'`N>&UL````````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`S,S(P(#$P-3$U-#,S-S0P(#`R,30P-@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/WAM;"!V97)S:6]N/2(Q
M+C`B/SX*/"$M+2`D2&]R9&4Z(&AO<F1E+VQO8V%L92]D85]$2R]H96QP+GAM
M;"QV(#$N,B`R,#`T+S`U+S(W(#(P.C(R.C$V(&IA;B!%>'`@)"`M+3X*/&AE
M;'`^"B`@/&5N=')Y(&ED/2)S=6UM87)Y(B!S=&%T93TB;F5W(CX*/'1I=&QE
M/E1H92!0;W)T86P@4&%G93PO=&ET;&4^"B`\<&%R83X*("!4:&ES('!O<G1A
M;"!P86=E('!R;W9I9&5S(&$@<75I8VL@<W5M;6%R>2!O9B!A;&P@>6]U<B!I
M;7!O<G1A;G0*("!I;F9O<FUA=&EO;BX@1F]R(&5X86UP;&4L(&ET(&UI9VAT
M('-H;W<@:&]W(&UA;GD@;F5W(&4M;6%I;"!M97-S86=E<R!Y;W4*("!H879E
M(&EN('EO=7(@24Y"3U@L('5P8V]M:6YG(&5V96YT<R!O;B!Y;W5R(&-A;&5N
M9&%R+"!T87-K<R!O;B!Y;W5R('1O+61O"B`@;&ES="P@:&5A9&QI;F5S(&9R
M;VT@<V5L96-T960@;F5W<R!S97)V:6-E<RP@86YD('-O(&]N+B`@36%N>2!O
M9B!T:&5S90H@('-U;6UA<FEE<R!W:6QL(&-O;G1A:6X@<75I8VL@<VAO<G1C
M=71S('1O(&-O;6UO;B!F=6YC=&EO;G,L('-U8V@@87,*("!C;VUP;W-I;F<@
M82!N97<@;6%I;"!M97-S86=E+"!C<F5A=&EN9R!A(&YE=R!C86QE;F1A<B!E
M=F5N="!O<B!T87-K+"!E=&,N"B`\+W!A<F$^"B`\<&%R83X*("!4:&4@8V]N
M=&5N=',@;V8@=&AI<R!P;W)T86P@<&%G92!A<F4@8W5S=&]M:7IA8FQE('9I
M82!T:&4@3&%Y;W5T(&)U='1O;BX*("!&;W(@97AA;7!L92P@>6]U(&-A;B!C
M:&]O<V4@=VAI8V@@:71E;7,@=&\@:6YC;'5D92!O;B!T:&ES('!O<G1A;"!P
M86=E(&%S"B`@=V5L;"!A<R!I;B!W:&EC:"!O<F1E<B!T:&5Y(&%R92!S:&]W
M;BX*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](FYA=F)A<B(@<W1A
M=&4](FYE=R(^"CQT:71L93Y4:&4@07!P;&EC871I;VX@3F%V:6=A=&EO;B!"
M87(\+W1I=&QE/@H@/'!A<F$^"B`@070@=&AE(&QE9G0@:&%N9"!S:61E(&]F
M('1H92!W96(@<&%G92!I<R!T:&4@87!P;&EC871I;VX@;F%V:6=A=&EO;B!B
M87(N"B`@0VQI8VL@;VX@=&AE(&EC;VYS(&]N('1H:7,@;F%V:6=A=&EO;B!B
M87(@=&\@<75I8VML>2!A;F0@96%S:6QY('-W:71C:`H@(&)E='=E96X@=&AE
M(&%V86EL86)L92!A<'!L:6-A=&EO;G,N"B`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)P<F5F<RUD;U]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!$;R!-86EN
M=&5N86YC93PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L
M:6ME('1O('!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I
M;BP@8VAE8VL@=&AI<R!B;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P<F5F<RUC;VYF:7)M7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($-O;F9I
M<FT@36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@
M=V]U;&0@;&EK92!T;R!C;VYF:7)M(&%L;"!M86EN=&5N86YC92!T87-K<R!B
M969O<F4@=&AE>2!A<F4@<G5N+"!C:&5C:R!T:&ES(&)O>"X@268@;&5F="!U
M;F-H96-K960L(&%L;"!M86EN=&5N86YC92!O<&5R871I;VYS('1H870@;F5E
M9"!T;R!B92!R=6X@=VEL;"!B92!P97)F;W)M960@875T;VUA=&EC86QL>2!W
M:71H(&YO(&-H86YC92!T;R!C86YC96P@;VX@;&]G:6XN"B`@("`\+W!A<F$^
M"CPO96YT<GD^"CPO:&5L<#X*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]D95]$10``
M````````````````````````````````````````````````````````````
M```````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#`P,"`Q,#4Q-30S,S<T,"`P,3<V-34`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&]C86QE+V1E7T1%+TQ#7TU%4U-!1T53````````````````````````
M`````````````````````````````````````````````#`P,#<U-2``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S0P(#`R,30T,@`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O9&5?1$4O3$-?34534T%'15,O
M:&]R9&4N;6\`````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`T,C8S-#`@,3`U
M,34T,S,W-#`@,#(S,3<P`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````-X2!)4`````D`<``!P```"</```'PH``!QY````````
MF*$```X```"9H0``#P```*BA```-````N*$```@```#&H0``"P```,^A```,
M````VZ$```0```#HH0``&````.VA```;````!J(``"T````BH@``'0```%"B
M```D````;J(``"D```"3H@``&0```+VB```F````UZ(```P```#^H@``)```
M``NC```/````,*,```L```!`HP``#@```$RC```%````6Z,``"@```!AHP``
M"````(JC```*````DZ,``!4```">HP``$@```+2C```+````QZ,``(4```#3
MHP``#@```%FD```*````:*0```T```!SI```#@```(&D```1````D*0```T`
M``"BI```#````+"D```-````O:0```8```#+I```E````-*D```*````9Z4`
M``\```!RI0``&````(*E```,````FZ4```X```"HI0``#@```+>E```(````
MQJ4```D```#/I0``+@```-FE```:````"*8``#(````CI@``.````%:F``!4
M````CZ8``%$```#DI@``6@```#:G``!7````D:<``#0```#IIP``"0```!ZH
M```-````**@```T````VJ```!P```$2H```*````3*@```\```!7J```!0``
M`&>H```&````;:@``!$```!TJ```"````(:H```)````CZ@```D```"9J```
M)0```*.H```@````R:@``!,```#JJ```$````/ZH```/````#ZD```H````?
MJ0```P```"JI```/````+JD``!0````^J0``"0```%.I```+````7:D```T`
M``!IJ0``$@```'>I```9````BJD``!X```"DJ0``#P```,.I```*````TZD`
M``@```#>J0``)````.>I```4````#*H``!8````AJ@``"````#BJ``!.````
M0:H``"T```"0J@``&0```+ZJ```'````V*H```P```#@J@``+````.VJ```.
M````&JL```,````IJP``"P```"VK```'````.:L```<```!!JP``!0```$FK
M```%````3ZL```H```!5JP```P```&"K```7````9*L```H```!\JP``#P``
M`(>K```.````EZL``!@```"FJP``(P```+^K```.````XZL``!0```#RJP``
M%P````>L```7````'ZP``!<````WK```$P```$^L```/````8ZP```X```!S
MK```'P```(*L```=````HJP```<```#`K```!@```,BL```(````SZP```\`
M``#8K```!@```.BL```*````[ZP``!,```#ZK```"P````ZM```0````&JT`
M`!4````KK0``%0```$&M```'````5ZT``!````!?K0``!0```'"M```5````
M=JT``!$```",K0``#````)ZM```[````JZT``#@```#GK0``"0```""N```'
M````*JX``!0````RK@```P```$>N```%````2ZX``!````!1K@``"0```&*N
M```3````;*X``#D```"`K@``$@```+JN```G````S:X``"P```#UK@``*@``
M`"*O```E````3:\```H```!SKP``!@```'ZO```)````A:\```<```"/KP``
M+P```)>O```W````QZ\``"X```#_KP``50```"ZP```M````A+```"T```"R
ML```/0```."P```_````'K$``"T```!>L0``0````(RQ```C````S;$``",`
M``#QL0``0````!6R```M````5K(``#,```"$L@``)0```+BR```5````WK(`
M`!D```#TL@``*0````ZS```D````.+,``"@```!=LP``$0```(:S```*````
MF+,```P```"CLP``"@```+"S```0````N[,``!8```#,LP``%@```..S```'
M````^K,```<````"M```%`````JT```*````'[0```@````JM```)P```#.T
M```(````6[0```<```!DM```!P```&RT```&````=+0```4```![M```!P``
M`(&T```&````B;0```@```"0M```*0```)FT```.````P[0```H```#2M```
M!````-VT```'````XK0```D```#JM```!@```/2T```1````^[0```<````-
MM0``%@```!6U```$````++4```@````QM0``!@```#JU```-````0;4```8`
M``!/M0``'@```%:U```1````=;4```@```"'M0``#0```)"U```,````GK4`
M``<```"KM0```P```+.U```#````M[4``!<```"[M0``$P```-.U```=````
MY[4```@````%M@``!`````ZV```(````$[8```@````<M@``*P```"6V```@
M````4;8``!4```!RM@``!@```(BV```&````C[8``!4```"6M@``.@```*RV
M```8````Y[8``"(`````MP``,P```".W```N````5[<``!T```"&MP``(0``
M`*2W``!4````QK<``$`````;N```*0```%RX```9````AK@```H```"@N```
M!P```*NX```'````L[@``!4```"[N```#@```-&X```*````X+@```\```#K
MN```#0```/NX```/````";D```T````9N0``"0```">Y```4````,;D```8`
M``!&N0``&````$VY```=````9KD``!,```"$N0``$0```)BY```4````JKD`
M``0```"_N0``!@```,2Y```4````R[D``%0```#@N0``9````#6Z```$````
MFKH```X```"?N@``!0```*ZZ```%````M+H``!L```"ZN@``&@```-:Z```3
M````\;H``!$````%NP``$0```!>[```<````*;L``"H```!&NP``$````'&[
M```A````@KL```4```"DNP``$P```*J[```+````OKL``!(```#*NP``"@``
M`-V[```/````Z+L```T```#XNP``$0````:\```3````&+P```P````LO```
M!@```#F\```,````0+P```8```!-O```%P```%2\```0````;+P``!$```!]
MO```"````(^\```%````F+P```P```">O```$````*N\```%````O+P```T`
M``#"O```!@```-"\```'````U[P```T```#?O```!P```.V\```+````];P`
M``<````!O0``!P````F]```)````$;T```D````;O0``"@```"6]```9````
M,+T``!T```!*O0``#````&B]```0````=;T```4```"&O0``)0```(R]```2
M````LKT``!,```#%O0``*P```-F]```[````!;X``"````!!O@``"````&*^
M```V````:[X``"$```"BO@``$````,2^```(````U;X```P```#>O@``!@``
M`.N^```$````\KX```\```#WO@``#@````>_```'````%K\```H````>OP``
M#0```"F_```?````-[\``!P```!7OP``(0```'2_```>````EK\``!D```"U
MOP``'@```,^_```;````[K\``"$````*P```+@```"S````F````6\```!P`
M``""P```'@```)_````<````OL```"8```#;P```*P````+!```S````+L$`
M`"8```!BP0``*P```(G!```X````M<$``!T```#NP0``%0````S"```O````
M(L(``"````!2P@``$@```'/"```I````AL(``!X```"PP@``(````,_"```2
M````\,(``*(````#PP``%@```*;#```C````O<,``"@```#APP``*0````K$
M```H````-,0``!\```!=Q```%0```'W$```@````D\0``"4```"TQ```*```
M`-K$```M`````\4``#`````QQ0``D@```&+%```A````]<4``!8````7Q@``
M'````"[&```F````2\8``"H```!RQ@``00```)W&``!$````W\8```P````D
MQP``!P```#''```'````.<<```8```!!QP``#0```$C'```0````5L<``!(`
M``!GQP``$P```'K'```2````CL<```<```"AQP``!````*G'```0````KL<`
M`!````"_QP``#````-#'```.````W<<```T```#LQP``#P```/K'```3````
M"L@```T````>R```*````"S(```#````5<@```T```!9R```!@```&?(```1
M````;L@``!<```"`R```&P```)C(```.````M,@```(```##R```20```,;(
M```%````$,D``!`````6R0``#P```"?)```$````-\D```T````\R0``#@``
M`$K)```#````6<D```X```!=R0``"````&S)```/````=<D```\```"%R0``
M!P```)7)```-````G<D``!````"KR0``#0```+S)```+````RLD```8```#6
MR0``"P```-W)```,````Z<D```H```#VR0``$0````'*```9````$\H```L`
M```MR@``#0```#G*```B````1\H```\```!JR@``&P```'K*```T````ELH`
M``H```#+R@``&````-;*```2````[\H``!D````"RP``%@```!S+```B````
M,\L```T```!6RP``!P```&3+```4````;,L```L```"!RP``(@```(W+```O
M````L,L```L```#@RP``"0```.S+```9````]LL```L````0S```%P```!S,
M```7````-,P```D```!,S```%@```%;,```/````;<P``!D```!]S```%@``
M`)?,```.````KLP``!@```"]S```"````-;,```-````W\P``"8```#MS```
M0P```!3-```(````6,T``!(```!AS0``'P```'3-```(````E,T```L```"=
MS0``+P```*G-```.````V<T```4```#HS0``!@```.[-``!%````]<T```,`
M```[S@``!P```#_.```$````1\X```H```!,S@``"@```%?.```/````8LX`
M`!````!RS@``%P```(/.```1````F\X``!D```"MS@``%P```,?.```)````
MW\X```4```#IS@``"P```._.```*````^\X```(````&SP``!0````G/```-
M````#\\``!L````=SP``%P```#G/```4````4<\```D```!FSP``#@```'#/
M```-````?\\``!(```"-SP``.````*#/```@````V<\```@```#ZSP``#@``
M``/0``![````$M```!@```".T```&````*?0```1````P-````<```#2T```
M!0```-K0```8````X-```!X```#YT```&P```!C1```9````--$``!L```!.
MT0``&0```&K1```3````A-$```<```"8T0``"````*#1```&````J=$```8`
M``"PT0``$````+?1```/````R-$``!````#8T0``#P```.G1```+````^=$`
M``\````%T@``#````!72```/````(M(```<````RT@``!@```#K2```,````
M0=(``"@```!.T@``#P```'?2```(````A](```@```"0T@``$P```)G2```>
M````K=(``"$```#,T@``(````.[2```9````#],``!<````ITP``)0```$'3
M```7````9],``!8```!_TP``!````);3```;````F],```T```"WTP``#```
M`,73```#````TM,```4```#6TP``"````-S3```*````Y=,```P```#PTP``
M"P```/W3```0````"=0```P````:U```#@```"?4```+````-M0```0```!"
MU```!````$?4```3````3-0``!0```!@U```#````'74```)````@M0```X`
M``",U```"P```)O4```;````I]0```<```##U```!P```,O4```*````T]0`
M``T```#>U```"0```.S4```$````]M0```4```#[U````P````'5```8````
M!=4```H````>U0``!````"G5```F````+M4```X```!5U0``?````&35```5
M````X=4```4```#WU0``!P```/W5```,````!=8```@````2U@``"@```!O6
M```&````)M8```@````MU@```@```#;6```&````.=8```8```!`U@``%```
M`$?6```0````7-8```T```!MU@``$````'O6```;````C-8```0```"HU@``
M"0```*W6```0````M]8```D```#(U@``"0```-+6```%````W-8``!H```#B
MU@``"````/W6```&````!M<``!D````-UP``#@```"?7```'````-M<```<`
M```^UP``!0```$;7```)````3-<```H```!6UP``#@```&'7```"````<-<`
M``8```!SUP``"P```'K7```-````AM<```D```"4UP``!@```)[7```2````
MI=<```D```"XUP``!P```,+7```4````RM<``!T```#?UP``0@```/W7```E
M````0-@``"4```!FV```!@```(S8```*````D]@```0```">V```"0```*/8
M```(````K=@``!$```"VV```"0```,C8```&````TM@```T```#9V```!@``
M`.?8```$````[M@``#D```#SV```/0```"W9```Z````:]D``!X```"FV0``
M!0```,79```.````R]D```0```#:V0``!@```-_9```'````YMD``"$```#N
MV0``#0```!#:```5````'MH```8````TV@``!````#O:```1````0-H```8`
M``!2V@``"@```%G:```B````9-H```0```"'V@``!0```(S:```=````DMH`
M``P```"PV@``#@```+W:```*````S-H```@```#7V@``"0```.#:```%````
MZMH``#H```#PV@``,````"O;```U````7-L``"D```"2VP``1P```+S;```X
M````!-P``"D````]W```/P```&?<```N````I]P``"T```#6W```'P````3=
M```/````)-T``!(````TW0``"P```$?=```F````4]T``"D```!ZW0``)```
M`*3=```F````R=T```@```#PW0``"@```/G=```)````!-X```<````.W@``
M(````!;>```@````-]X``"8```!8W@``"@```'_>```9````BMX``"D```"D
MW@``%@```,[>```2````Y=X```<```#XW@``"@````#?```,````"]\```\`
M```8WP``$````"C?``!`````.=\``'````!ZWP``9@```.O?```.````4N``
M``D```!AX```"@```&O@```2````=N```!,```")X```#````)W@```&````
MJN````\```"QX```$@```,'@```0````U.```!$```#EX```'````/?@```C
M````%.$``&H````XX0``#P```*/A```%````L^$``!````"YX0``"0```,KA
M```$````U.$```L```#9X0``(````.7A```1````!N(``!0````8X@``#```
M`"WB```,````.N(```\```!'X@``%0```%?B```I````;>(``"H```"7X@``
M)@```,+B```G````Z>(``"D````1XP``*@```#OC```9````9N,``$(```"`
MXP``$0```,/C```2````U>,``!,```#HXP``%````/SC```/````$>0``!8`
M```AY```%P```#CD```0````4.0``!$```!AY```-````'/D```3````J.0`
M`!(```"\Y```-0```,_D```4````!>4```<````:Y0``#````"+E```@````
M+^4``!````!0Y0``%````&'E```1````=N4``!<```"(Y0``'````*#E```3
M````O>4``!0```#1Y0``&@```.;E```1`````>8``!H````3Y@``'@```"[F
M```:````3>8``!,```!HY@``%0```'SF```1````DN8``!<```"DY@``%```
M`+SF```7````T>8``!4```#IY@``"0```/_F```0````"><``!D````:YP``
M!````#3G```'````.><```L```!!YP``$0```$WG```&````7^<```8```!F
MYP``!@```&WG```%````=.<```<```!ZYP``!P```(+G```%````BN<``!8`
M``"0YP``!@```*?G```&````KN<```0```"UYP``!````+KG```'````O^<`
M``X```#'YP``#````-;G```,````X^<```T```#PYP``"@```/[G```.````
M">@```4````8Z```*````![H```.````1^@```P```!6Z```#P```&/H```*
M````<^@```@```!^Z```"0```(?H```K````D>@```0```"]Z```"````,+H
M```F````R^@``!(```#RZ```#P````7I```&````%>D```H````<Z0``!P``
M`"?I```(````+^D``"`````XZ0``"0```%GI```4````8^D```P```!XZ0``
M#0```(7I```.````D^D``!8```"BZ0``$0```+GI```&````R^D```,```#2
MZ0``!@```-;I```9````W>D```<```#WZ0``!````/_I```+````!.H```L`
M```0Z@``!P```!SJ```%````).H```<````JZ@``%@```#+J```-````2>H`
M``T```!7Z@``"@```&7J```0````<.H```\```"!Z@``$0```)'J```7````
MH^H```H```"[Z@``$0```,;J```(````V.H```0```#AZ@``"````.;J```/
M````[^H```\```#_Z@``"P````_K```)````&^L``#H````EZP``%````&#K
M```%````=>L```P```![ZP``'@```(CK```.````I^L``!````"VZP``"P``
M`,?K```,````T^L```D```#@ZP``!P```.KK```*````\NL```D```#]ZP``
M#@````?L```0````%NP``!L````G[```&````$/L```:````7.P```H```!W
M[```"0```(+L```*````C.P```P```"7[```#P```*3L```(````M.P```8`
M``"][```'````,3L```'````X>P```4```#I[```"P```._L``!'````^^P`
M``T```!#[0``"0```%'M```$````6^T```,```!@[0``$P```&3M```3````
M>.T``!,```",[0``"@```*#M```"````J^T```0```"N[0``)0```+/M```#
M````V>T```4```#=[0``*@```./M```*````#NX```4````9[@``!````!_N
M```*````).X```T````O[@``!@```#WN```(````1.X```@```!-[@``!```
M`%;N```%````6^X``&@```!A[@``"0```,KN```,````U.X``!````#A[@``
M!0```/+N```&````^.X``!L```#_[@``+P```!OO```0````2^\```H```!<
M[P``#P```&?O```*````=^\```D```""[P``$P```(SO```;````H.\``!@`
M``"\[P``%P```-7O```?````[>\```X````-\````P```!SP```'````(/``
M``@````H\```!P```#'P```*````.?````L```!$\```!P```%#P``!1````
M6/```!````"J\```#````+OP```-````R/```!H```#6\```2@```/'P```9
M````//$```8```!6\0``&@```%WQ```E````>/$```8```">\0``!@```*7Q
M```?````K/$```8```#,\0``"0```-/Q```8````W?$``!<```#V\0``*```
M``[R```&````-_(```T````^\@``(@```$SR``!7````;_(``!,```#'\@``
M(P```-OR```3````__(```(````3\P``"P```!;S```(````(O,```T````K
M\P``"@```#GS```'````1/,``!0```!,\P``!@```&'S```(````:/,```X`
M``!Q\P``!P```(#S```*````B/,```L```"3\P``,@```)_S```'````TO,`
M``P```#:\P``#0```.?S```7````]?,```P````-]```"0```!KT```)````
M)/0```H````N]```!P```#GT```)````0?0```<```!+]```"@```%/T```;
M````7O0```\```!Z]```$@```(KT```*````G?0``!8```"H]```"0```+_T
M```0````R?0```<```#:]```$@```.+T```$````]?0```<```#Z]```!0``
M``+U```%````"/4```L````.]0``%````!KU```1````+_4``!H```!!]0``
M%@```%SU```4````<_4``!<```"(]0``&````*#U```<````N?4``!D```#6
M]0``!P```/#U```%````^/4```T```#^]0``#`````SV```(````&?8``!<`
M```B]@``"P```#KV```,````1O8``!\```!3]@``&@```'/V```3````CO8`
M``0```"B]@``"@```*?V```$````LO8```T```"W]@``#````,7V```%````
MTO8```D```#8]@``!0```.+V```'````Z/8```4```#P]@``!````/;V```"
M````^_8``#@```#^]@``+````#?W```2````9/<``"D```!W]P``,@```*'W
M```*````U/<``"P```#?]P``+@````SX```S````._@``#,```!O^```.```
M`*/X```/````W/@``!@```#L^```$`````7Y```/````%OD``!,````F^0``
M%0```#KY```4````4/D``!(```!E^0``%````'CY```5````C?D``"T```"C
M^0``+0```-'Y```Q````__D``"X````Q^@``+P```&#Z```L````D/H``&(`
M``"]^@``$P```"#[```-````-/L```@```!"^P``%P```$O[```(````8_L`
M``P```!L^P``*P```'G[```A````I?L``!H```#'^P``"0```.+[``!%````
M[/L``$$````R_```!````'3\```3````>?P``!0```"-_```#@```*+\```3
M````L?P``!@```#%_```!@```-[\```)````Y?P```H```#O_```#P```/K\
M```*````"OT``!`````5_0``!P```";]```.````+OT```4````]_0``&P``
M`$/]```(````7_T```8```!H_0``%````&_]```1````A/T```X```"6_0``
M.````*7]```"````WOT```8```#A_0``#@```.C]```%````]_T```<```#]
M_0``#@````7^```&````%/X``"@````;_@``#````$3^```<````4?X```0`
M``!N_@``#0```'/^```I````@?X``!<```"K_@``'P```,/^``!<````X_X`
M`!0```!`_P``/@```%7_```?````E/\``!````"T_P``!P```,7_```.````
MS?\```P```#<_P``#````.G_```3````]O\```H````*``$`'0```!4``0`9
M````,P`!``4```!-``$`$0```%,``0`1````90`!`"0```!W``$`$@```)P`
M`0`5````KP`!`!(```#%``$`#@```-@``0`9````YP`!``@````!`0$`"0``
M``H!`0`-````%`$!``<````B`0$`"@```"H!`0`'````-0$!``\````]`0$`
M!@```$T!`0`+````5`$!`!H```!@`0$`"@```'L!`0`'````A@$!``@```".
M`0$`!0```)<!`0`?````G0$!``8```"]`0$`$````,0!`0`(````U0$!``T`
M``#>`0$`"````.P!`0`>````]0$!`!(````4`@$`+````"<"`0`:````5`(!
M``D```!O`@$`"@```'D"`0`5````A`(!``4```":`@$`%````*`"`0`$````
MM0(!`!````"Z`@$`!@```,L"`0`'````T@(!`!X```#:`@$`*````/D"`0`*
M````(@,!`!P````M`P$`$0```$H#`0`+````7`,!`!H```!H`P$`%````(,#
M`0`$````F`,!``0```"=`P$`"P```*(#`0`%````K@,!``8```"T`P$`"```
M`+L#`0`&````Q`,!``H```#+`P$`&P```-8#`0`T````\@,!`#0````G!`$`
M(````%P$`0`I````?00!`"````"G!`$`00```,@$`0`:````"@4!`"@````E
M!0$`*0```$X%`0!0````>`4!`"(```#)!0$`!@```.P%`0`(````\P4!``4`
M``#\!0$`"`````(&`0`9````"P8!`!D````E!@$`*@```#\&`0`C````:@8!
M`!D```".!@$`+@```*@&`0`T````UP8!``@````,!P$`%P```!4'`0`*````
M+0<!``<````X!P$`(0```$`'`0`0````8@<!``X```!S!P$`"P```(('`0`'
M````C@<!`!,```"6!P$`"````*H'`0`+````LP<!``H```"_!P$`%````,H'
M`0`/````WP<!`#(```#O!P$`"P```"((`0`.````+@@!``4````]"`$`!0``
M`$,(`0`%````20@!`!<```!/"`$`#P```&<(`0`$````=P@!``H```!\"`$`
M"0```(<(`0`+````D0@!``T```"="`$`#````*L(`0`.````N`@!``4```#'
M"`$`!````,T(`0`-````T@@!`#(```#@"`$`10```!,)`0`7````60D!``<`
M``!Q"0$`'@```'D)`0`4````F`D!``4```"M"0$`%````+,)`0`&````R`D!
M``<```#/"0$`#@```-<)`0`J````Y@D!``8````1"@$`#````!@*`0`-````
M)0H!`!$````S"@$`"P```$4*`0`V````40H!``H```"("@$`(@```),*`0`+
M````M@H!``\```#""@$`,@```-(*`0`E````!0L!`#`````K"P$`,0```%P+
M`0`M````C@L!``X```"\"P$`!0```,L+`0`.````T0L!`!,```#@"P$`$@``
M`/0+`0`'````!PP!`!$````/#`$`$P```"$,`0`'````-0P!`!0````]#`$`
M&````%(,`0`'````:PP!``4```!S#`$`#````'D,`0`,````A@P!`!(```"3
M#`$`!````*8,`0`'````JPP!``H```"S#`$`"P```+X,`0`,````R@P!``X`
M``#7#`$`#@```.8,`0`%````]0P!``4```#[#`$`+@````$-`0`F````,`T!
M`",```!7#0$``P```'L-`0`2````?PT!``8```"2#0$`'@```)D-`0`8````
MN`T!`"4```#1#0$`#0```/<-`0`)````!0X!`!\````/#@$``P```"\.`0`'
M````,PX!``H````[#@$``@```$8.`0`,````20X!`!4```!6#@$`"P```&P.
M`0`9````>`X!`"````"2#@$`$@```+,.`0`%````Q@X!``H```#,#@$`%0``
M`-<.`0`2````[0X!``P`````#P$`!`````T/`0`)````$@\!``<````<#P$`
M#````"0/`0!2````,0\!`!<```"$#P$`)````)P/`0`2````P0\!``<```#4
M#P$`!@```-P/`0`.````XP\!``P```#R#P$`#0```/\/`0`5````#1`!`!(`
M```C$`$`#P```#80`0`4````1A`!``H```!;$`$`&P```&80`0`0````@A`!
M``L```"3$`$`:0```)\0`0`:````"1$!`!<````D$0$`)P```#P1`0`:````
M9!$!`!<```!_$0$`&P```)<1`0`9````LQ$!`!\```#-$0$`$P```.T1`0`(
M`````1(!``<````*$@$`"````!(2`0`)````&Q(!`!4````E$@$`#0```#L2
M`0`C````21(!``T```!M$@$`$P```'L2`0`(````CQ(!``,```"8$@$`1@``
M`)P2`0`_````XQ(!`#<````C$P$`5P```%L3`0`%````LQ,!`!\```"Y$P$`
M+P```-D3`0`*````"10!``@````4%`$`#0```!T4`0`M````*Q0!``0```!9
M%`$`3P```%X4`0`E````KA0!`!P```#4%`$`"P```/$4`0`?````_10!`!T`
M```=%0$`)0```#L5`0`@````814!`"0```""%0$`(````*<5`0`+````R!4!
M``<```#4%0$`#0```-P5`0`,````ZA4!`!<```#W%0$`!@````\6`0`Y````
M%A8!``P```!0%@$`!P```%T6`0`)````918!`!,```!O%@$`"0```(,6`0`$
M````C18!`!````"2%@$`"````*,6`0`(````K!8!``0```"U%@$`"P```+H6
M`0`,````QA8!`!(```#3%@$`$0```.86`0`,````^!8!`!H````%%P$`#P``
M`"`7`0`'````,!<!``T````X%P$`%````$87`0`.````6Q<!``P```!J%P$`
M&P```'<7`0`L````DQ<!`!,```#`%P$`'````-07`0`H````\1<!``8````:
M&`$`!P```"$8`0`3````*1@!``4````]&`$`!````$,8`0`7````2!@!``H`
M``!@&`$`#````&L8`0`)````>!@!``8```""&`$`"0```(D8`0`(````DQ@!
M``D```"<&`$`"@```*88`0`1````L1@!``8```##&`$`#@```,H8`0`.````
MV1@!``T```#H&`$`"P```/88`0`=`````AD!``L````@&0$``@```"P9`0`<
M````+QD!``<```!,&0$`!@```%09`0!D````6QD!``D```#`&0$`!P```,H9
M`0`F````TAD!`#@```#Y&0$`&@```#(:`0`J````31H!`#L```!X&@$`*```
M`+0:`0`T````W1H!`!D````2&P$`%0```"P;`0`%````0AL!``<```!(&P$`
M"````%`;`0`'````61L!``4```!A&P$`!P```&<;`0`.````;QL!``D```!^
M&P$`!@```(@;`0`(````CQL!``L```"8&P$`!P```*0;`0`(````K!L!``<`
M``"U&P$`%@```+T;`0`)````U!L!``8```#>&P$`"P```.4;`0`0````\1L!
M`!P````"'`$`%````!\<`0`'````-!P!`!$````\'`$`"````$X<`0`.````
M5QP!``@```!F'`$`$````&\<`0`)````@!P!`!````"*'`$`!@```)L<`0`9
M````HAP!``H```"\'`$`'````,<<`0`'````Y!P!``4```#L'`$`$````/(<
M`0`4`````QT!``L````8'0$`#0```"0=`0`H````,AT!`!@```!;'0$`%P``
M`'0=`0`$````C!T!``D```"1'0$`"@```)L=`0`'````IAT!``(```"N'0$`
M#@```+$=`0`(````P!T!`",```#)'0$`'P```.T=`0`X````#1X!`"8```!&
M'@$`,0```&T>`0`G````GQX!`&0```#''@$`%````"P?`0!5````01\!`#@`
M``"7'P$`2@```-`?`0!;````&R`!`"@```!W(`$`.````*`@`0`H````V2`!
M`"P````"(0$`&P```"\A`0`^````2R$!`*D!``"*(0$`(P```#0C`0`7````
M6",!`$@```!P(P$`A0```+DC`0`P````/R0!`"4```!P)`$`00```)8D`0!;
M````V"0!`$D````T)0$`,0```'XE`0`=````L"4!`!@```#.)0$`*P```.<E
M`0`A````$R8!`!\````U)@$`*P```%4F`0`F````@28!`"<```"H)@$`.@``
M`-`F`0`=````"R<!`!$````I)P$`,P```#LG`0`E````;R<!`"<```"5)P$`
M(````+TG`0`?````WB<!`#````#^)P$`:0```"\H`0`Q````F2@!`$$```#+
M*`$`,P````TI`0`E````02D!`#T```!G*0$`90```*4I`0!-````"RH!`"\`
M``!9*@$`+@```(DJ`0`P````N"H!`%0```#I*@$`6@```#XK`0!(````F2L!
M`$H```#B*P$`,@```"TL`0`O````8"P!`"P```"0+`$`+0```+TL`0!Q````
MZRP!`&8```!=+0$`;P```,0M`0"S````-"X!`!<```#H+@$`)0`````O`0`R
M````)B\!`"D```!9+P$`/@```(,O`0`B````PB\!`%(```#E+P$`)0```#@P
M`0`+````7C`!`+$```!J,`$`10```!PQ`0`A````8C$!`#````"$,0$`)0``
M`+4Q`0`<````VS$!`#$```#X,0$`!P```"HR`0`'````,C(!``0````Z,@$`
M#0```#\R`0`+````33(!``X```!9,@$`"P```&@R`0`%````=#(!`!````!Z
M,@$``@```(LR`0!9````CC(!``4```#H,@$`$@```.XR`0`$`````3,!``<`
M```&,P$`"`````XS`0`%````%S,!`#`````=,P$``P```$XS`0`0````4C,!
M``P```!C,P$`$P```'`S`0`-````A#,!``(```"2,P$`!P```)4S`0`&````
MG3,!`!0```"D,P$`#````+DS`0`8````QC,!``8```#?,P$`$@```.8S`0`,
M````^3,!``,````&-`$`*@````HT`0`$````-30!``8````Z-`$`!P```$$T
M`0`?````230!`#4```!I-`$`+@```)\T`0`O````SC0!`!<```#^-`$`(@``
M`!8U`0`E````.34!`"````!?-0$`&P```(`U`0`8````G#4!`"0```"U-0$`
M'P```-HU`0`:````^C4!`"$````5-@$`(````#<V`0`:````6#8!`#(```!S
M-@$`&@```*8V`0`O````P38!`"L```#Q-@$`'P```!TW`0`C````/3<!`!\`
M``!A-P$`&@```($W`0`A````G#<!`"4```"^-P$`)@```.0W`0`E````"S@!
M`"0````Q.`$`&````%8X`0`=````;S@!`"0```"-.`$`&````+(X`0`B````
MRS@!`"P```#N.`$`*````!LY`0`5````1#D!`"4```!:.0$`/````(`Y`0`?
M````O3D!`",```#=.0$`'P````$Z`0`@````(3H!`!H```!".@$`&````%TZ
M`0`F````=CH!`"D```"=.@$`'@```,<Z`0`I````YCH!`!X````0.P$`,0``
M`"\[`0`)````83L!``P```!K.P$`%P```'@[`0`O````D#L!`"0```#`.P$`
M!P```.4[`0`/````[3L!`!0```#].P$`#@```!(\`0`-````(3P!`"0````O
M/`$`!0```%0\`0`'````6CP!`"(```!B/`$`)0```(4\`0`:````JSP!`!T`
M``#&/`$`&@```.0\`0`'````_SP!`,<````'/0$`"P```,\]`0`5````VST!
M``8```#Q/0$`"0```/@]`0`+`````CX!``T````./@$`%P```!P^`0`&````
M-#X!`#,````[/@$`$P```&\^`0`3````@SX!``<```"7/@$`#P```)\^`0`'
M````KSX!`#(```"W/@$`!````.H^`0`A````[SX!`!,````1/P$`#````"4_
M`0`1````,C\!`#(```!$/P$`%@```'<_`0`(````CC\!`!T```"7/P$`"0``
M`+4_`0`*````OS\!`!0```#*/P$`"@```-\_`0`=````ZC\!``@````(0`$`
M'P```!%``0`(````,4`!`!H````Z0`$`)P```%5``0`&````?4`!`!4```"$
M0`$`!P```)I``0`(````HD`!``D```"K0`$`/P```+5``0`'````]4`!``\`
M``#]0`$`#@````U!`0`0````'$$!``D````M00$`"0```#=!`0`(````04$!
M`!,```!*00$`!P```%Y!`0`9````9D$!``H```"`00$`%P```(M!`0`4````
MHT$!``H```"X00$`#````,-!`0`7````T$$!``0```#H00$`*@```.U!`0`,
M````&$(!`!$````E0@$`!P```#="`0`"````/T(!`!````!"0@$`&````%-"
M`0`+````;$(!``,```!X0@$`"````'Q"`0`&````A4(!``<```",0@$`#0``
M`)1"`0`+````HD(!`!0```"N0@$`%0```,-"`0`.````V4(!`"\```#H0@$`
M(````!A#`0`<````.4,!`!4```!60P$`#````&Q#`0`Q````>4,!``4```"K
M0P$`$@```+%#`0`_````Q$,!`!(````$1`$`"@```!=$`0`&````(D0!``0`
M```I1`$`!````"Y$`0`*````,T0!`!,````^1`$`!0```%)$`0`&````6$0!
M``8```!?1`$`"````&9$`0`$````;T0!``P```!T1`$`"@```(%$`0`Y````
MC$0!`"X```#&1`$`*0```/5$`0`%````'T4!`!@````E10$`&0```#Y%`0`?
M````6$4!`!T```!X10$`$0```)9%`0`"````J$4!``0```"K10$`"@```+!%
M`0`&````NT4!``4```#"10$``P```,A%`0`,````S$4!`$4```#910$`,@``
M`!]&`0`:````4D8!`#0```!M1@$`*````*)&`0!3````RT8!`!D````?1P$`
M<@```#E'`0`@````K$<!`#4```#-1P$`(0````-(`0!%````)4@!`#````!K
M2`$`*````)Q(`0`I````Q4@!`"8```#O2`$`)0```!9)`0`H````/$D!`"@`
M``!E20$`(@```(Y)`0`K````L4D!`#````#=20$`$@````Y*`0`3````(4H!
M`!`````U2@$`>0```$9*`0`)````P$H!`*$```#*2@$`<P```&Q+`0!\````
MX$L!`"L```!=3`$`5````(E,`0`7````WDP!`"<```#V3`$`%@```!Y-`0`/
M````-4T!`!<```!%30$`'P```%U-`0!`````?4T!`!\```"^30$`'````-Y-
M`0!1````^TT!`!H```!-3@$`%````&A.`0`*````?4X!``4```"(3@$`!@``
M`(Y.`0`(````E4X!``4```">3@$`$@```*1.`0`0````MTX!`!,```#(3@$`
M'0```-Q.`0`/````^DX!``\````*3P$`!````!I/`0`)````'T\!``L````I
M3P$`!P```#5/`0`4````/4\!``<```!23P$`"````%I/`0`/````8T\!``@`
M``!S3P$`#````'Q/`0`/````B4\!``8```"93P$`%````*!/`0`&````M4\!
M``P```"\3P$`$0```,E/`0`(````VT\!``0```#D3P$`&0```.E/`0`1````
M`U`!``H````54`$`&````"!0`0`3````.5`!`!P```!-4`$`$0```&I0`0`$
M````?%`!``\```"!4`$`!P```)%0`0`$````F5`!`!D```">4`$`!P```+A0
M`0`"````P%`!``(```##4`$`$0```,90`0`)````V%`!``8```#B4`$`$@``
M`.E0`0`7````_%`!``8````440$`)P```!M1`0`"````0U$!``0```!&40$`
M#P```$M1`0`3````6U$!``<```!O40$`!P```'=1`0`1````?U$!``8```"1
M40$`&````)A1`0`&````L5$!`!,```"X40$`$````,Q1`0`2````W5$!``(`
M``#P40$`!@```/-1`0`,````^E$!``D````'4@$`$0```!%2`0`B````(U(!
M``<```!&4@$`!P```$Y2`0`+````5E(!``4```!B4@$``@```&A2`0`+````
M:U(!`%@!``!W4@$`#P```-!3`0`3````X%,!``X```#T4P$`"`````-4`0`)
M````#%0!``H````65`$`!0```"%4`0`:````)U0!`!\```!"5`$`,@```&)4
M`0`P````E50!`"D```#&5`$`*````/!4`0`>````&54!`#,````X50$`#```
M`&Q5`0`G````>54!`!(```"A50$`#````+15`0`0````P54!``4```#250$`
M(0```-A5`0`0````^E4!`!`````+5@$`%@```!Q6`0`5````,U8!``P```!)
M5@$`A0```%96`0`0````W%8!``H```#M5@$`$@```/A6`0`0````"U<!``X`
M```<5P$`#````"M7`0`.````.%<!`!$```!'5P$`!@```%E7`0#!````8%<!
M``<````B6`$`"P```"I8`0`:````-E@!``\```!16`$`$0```&%8`0`1````
M<U@!``H```"%6`$`!P```)!8`0`L````F%@!`"0```#%6`$`50```.I8`0!A
M````0%D!`'D```"B60$`>````!Q:`0!\````E5H!`'L````26P$`6````(Y;
M`0`1````YUL!`!D```#Y6P$`'@```!-<`0`0````,EP!`!(```!#7`$`&```
M`%9<`0`%````;UP!``8```!U7`$`$@```'Q<`0`'````CUP!``T```"77`$`
M#0```*5<`0`W````LUP!`"X```#K7`$`$@```!I=`0`-````+5T!`!(````[
M70$`"P```$Y=`0`*````6ET!`!L```!E70$`&P```(%=`0`0````G5T!`!4`
M``"N70$`%@```,1=`0`6````VUT!`!X```#R70$`'@```!%>`0`E````,%X!
M`!$```!67@$`#P```&A>`0`J````>%X!`!H```"C7@$`'P```+Y>`0`3````
MWEX!`'H```#R7@$`0@```&U?`0`O````L%\!``<```#@7P$`"@```.A?`0`P
M````\U\!``X````D8`$`!P```#-@`0`+````.V`!``@```!'8`$`"````%!@
M`0`)````66`!``L```!C8`$`#````&]@`0`$````?&`!`!0```"!8`$`#```
M`)9@`0`+````HV`!`!````"O8`$`&0```,!@`0`F````VF`!`!$````!80$`
M&@```!-A`0`:````+F$!`!X```!)80$`&@```&AA`0`4````@V$!`!(```"8
M80$`$@```*MA`0`G````OF$!`"<```#F80$`!P````YB`0`&````%F(!``@`
M```=8@$`#@```"9B`0`'````-6(!``D````]8@$`$P```$=B`0`)````6V(!
M``\```!E8@$`%0```'5B`0`8````BV(!``H```"D8@$`#P```*]B`0`%````
MOV(!`!<```#%8@$`"P```-UB`0`*````Z6(!`$L```#T8@$`10```$!C`0`+
M````AF,!``@```"28P$`%0```)MC`0`%````L6,!``4```"W8P$`$````+UC
M`0`+````SF,!`!<```#:8P$`+@```/)C`0`0````(60!`#T````R9`$`/```
M`'!D`0`_````K60!`#\```#M9`$`"0```"UE`0`&````-V4!``H````^90$`
M"@```$EE`0!!````5&4!`#T```"690$`0````-1E`0!Q````%68!`#\```"'
M9@$`0P```,=F`0!3````"V<!`%````!?9P$`/P```+!G`0!1````\&<!`#,`
M``!":`$`-P```'9H`0!7````KF@!`#\````&:0$`0P```$9I`0`J````BFD!
M`"````"U:0$`'````-9I`0`]````\VD!`"D````Q:@$`*0```%MJ`0`2````
MA6H!``T```"8:@$`#0```*9J`0`+````M&H!`!````#`:@$`&P```-%J`0`?
M````[6H!``<````-:P$`!P```!5K`0`6````'6L!``L````T:P$`"````$!K
M`0`M````26L!``H```!W:P$`"@```()K`0`'````C6L!``8```"5:P$`!0``
M`)QK`0`(````HFL!``8```"K:P$`"@```+)K`0`M````O6L!`!(```#K:P$`
M"````/YK`0`$````!VP!``@````,;`$`"P```!5L`0`$````(6P!``P````F
M;`$`!@```#-L`0`3````.FP!``8```!.;`$`"````%5L`0`%````7FP!``L`
M``!D;`$`"0```'!L`0`I````>FP!`!$```"D;`$`"0```+9L`0`3````P&P!
M``P```#4;`$`!P```.%L`0`#````Z6P!``,```#M;`$`%P```/%L`0`7````
M"6T!`#<````A;0$`"````%EM`0`)````8FT!``H```!L;0$`!P```'=M`0`Z
M````?VT!`#P```"Z;0$`*@```/=M`0`&````(FX!``D````I;@$`&````#-N
M`0!.````3&X!`"P```";;@$`)0```,AN`0!2````[FX!`#8```!!;P$`,@``
M`'AO`0`S````JV\!`)$```#?;P$`8P```'%P`0!(````U7`!`"P````><0$`
M"0```$MQ`0`+````57$!``@```!A<0$`'0```&IQ`0`-````B'$!``P```"6
M<0$`$P```*-Q`0`-````MW$!`!,```#%<0$`#@```-EQ`0`,````Z'$!`!8`
M``#U<0$`"0````QR`0`<````%G(!`!T````S<@$`$0```%%R`0`2````8W(!
M`!4```!V<@$`!@```(QR`0`&````DW(!`!<```":<@$`@P```+)R`0![````
M-G,!``<```"R<P$`$P```+IS`0`%````SG,!``4```#4<P$`'P```-IS`0`>
M````^G,!`!0````9=`$`%P```"YT`0`>````1G0!`#0```!E=`$`+P```)IT
M`0`/````RG0!`"@```#:=`$`!@````-U`0`8````"G4!`!0````C=0$`&0``
M`#AU`0`5````4G4!`!4```!H=0$`$0```'YU`0`*````D'4!`!,```";=0$`
M$0```*]U`0`&````P74!``L```#(=0$`!P```-1U`0`+````W'4!``X```#H
M=0$`%P```/=U`0`)````#W8!``4````9=@$`"P```!]V`0`(````*W8!``@`
M```T=@$`%````#UV`0`&````4G8!``8```!9=@$`#````&!V`0`)````;78!
M`!````!W=@$`!P```(AV`0`%````D'8!``@```"6=@$`"P```)]V`0`+````
MJW8!`!H```"W=@$`*P```-)V`0`0````_G8!`!,````/=P$`!0```"-W`0`<
M````*7<!`!H```!&=P$`&P```&%W`0`]````?7<!`$P```"[=P$`*`````AX
M`0`(````,7@!`#T````Z>`$`)````'AX`0`/````G7@!``8```"M>`$`"P``
M`+1X`0`&````P'@!``@```#'>`$`&P```-!X`0`0````['@!``D```#]>`$`
M"@````=Y`0`.````$GD!`#D````A>0$`.0```%MY`0`[````E7D!`#L```#1
M>0$`*P````UZ`0`J````.7H!`"P```!D>@$`*@```)%Z`0!"````O'H!`"\`
M``#_>@$`+@```"][`0`P````7GL!`"@```"/>P$`+P```+A[`0`\````Z'L!
M`$`````E?`$`-````&9\`0`Q````FWP!`#D```#-?`$`+P````=]`0`R````
M-WT!`$8```!J?0$`,````+%]`0`?````XGT!`#H````"?@$`+@```#U^`0`[
M````;'X!`!\```"H?@$`W````,A^`0`?````I7\!`"X```#%?P$`,0```/1_
M`0`R````)H`!`#4```!9@`$`,````(^``0`N````P(`!`#$```#O@`$`.0``
M`"&!`0`\````6X$!`$0```"8@0$`/````-V!`0#%````&H(!`"\```#@@@$`
M(@```!"#`0`O````,X,!`#,```!C@P$`/@```)>#`0!D````UH,!`%T````[
MA`$`#@```)F$`0`$````J(0!``4```"MA`$`"0```+.$`0`.````O80!`!8`
M``#,A`$`%0```..$`0`/````^80!`!(````)A0$`"````!R%`0`$````)84!
M`!$````JA0$`$0```#R%`0`-````3H4!`!````!<A0$`$0```&V%`0`0````
M?X4!`!@```"0A0$`#@```*F%`0!1````N(4!``P````*A@$`%````!>&`0`&
M````+(8!`!,````SA@$`&0```$>&`0`>````888!`!4```"`A@$``@```):&
M`0!+````F88!``<```#EA@$`$````.V&`0`0````_H8!``4````/AP$`#0``
M`!6'`0`-````(X<!``,````QAP$`#P```#6'`0`(````18<!``8```!.AP$`
M$0```%6'`0`(````9X<!``T```!PAP$`$0```'Z'`0`-````D(<!``P```">
MAP$`!P```*N'`0`-````LX<!``X```#!AP$`"P```-"'`0`.````W(<!`"$`
M``#KAP$`#0````V(`0`.````&X@!`"8````JB`$`$P```%&(`0`7````98@!
M`"T```!]B`$`#0```*N(`0`=````N8@!`!,```#7B`$`&P```.N(`0`:````
M!XD!`"X````BB0$`$0```%&)`0`(````8XD!`!L```!LB0$`#````(B)`0`B
M````E8D!`#````"XB0$`"P```.F)`0`(````]8D!`!T```#^B0$`"@```!R*
M`0`5````)XH!`!4````]B@$`"P```%.*`0`C````7XH!`!4```"#B@$`'P``
M`)F*`0`9````N8H!``T```#3B@$`$P```.&*`0`)````]8H!``T```#_B@$`
M+P````V+`0!1````/8L!``@```"/BP$`%P```)B+`0`B````L(L!``T```#3
MBP$`$````.&+`0`T````\HL!``P````GC`$`!@```#2,`0`&````.XP!`$P`
M``!"C`$`!@```(^,`0`'````EHP!``H```">C`$`$````*F,`0`1````NHP!
M`!$```#,C`$`$0```-Z,`0`:````\(P!`!T````+C0$`&@```"F-`0`8````
M1(T!``<```!=C0$`!P```&6-`0`+````;8T!``H```!YC0$``@```(2-`0`&
M````AXT!``X```".C0$`)P```)V-`0`>````Q8T!`!<```#DC0$`!P```/R-
M`0`0````!(X!`!`````5C@$`%````":.`0`[````.XX!`"<```!WC@$`!P``
M`)^.`0`1````IXX!`)<```"YC@$`&0```%&/`0`C````:X\!`!$```"/CP$`
M!P```*&/`0`&````J8\!`"8```"PCP$`,@```->/`0`P````"I`!`"0````[
MD`$`)````&"0`0`?````A9`!`!\```"ED`$`!P```,60`0`)````S9`!``D`
M``#7D`$`!@```.&0`0`/````Z)`!``X```#XD`$`$`````>1`0`.````&)$!
M`!,````GD0$`$0```#N1`0`0````39$!``X```!>D0$`"0```&V1`0`*````
M=Y$!``P```""D0$`/0```(^1`0`-````S9$!``@```#;D0$`$````.21`0`C
M````]9$!`#,````9D@$`)P```$V2`0`F````=9(!`"\```"<D@$`*0```,R2
M`0`V````]I(!`"P````MDP$`%0```%J3`0`&````<),!``X```!WDP$`!@``
M`(:3`0`0````C9,!``,```">DP$`!````**3`0`'````IY,!`!,```"ODP$`
M%0```,.3`0`3````V9,!`!D```#MDP$`"@````>4`0`.````$I0!``L````A
ME`$`!P```"V4`0`%````-90!`!`````[E`$`$@```$R4`0`,````7Y0!``D`
M``!LE`$`#````':4`0`/````@Y0!`#$```"3E`$`!@```,64`0`(````S)0!
M``P```#5E`$`#@```.*4`0`7````\90!``@````)E0$`"````!*5`0`%````
M&Y4!`"(````AE0$`#````$25`0`%````494!`"H```!7E0$`$````(*5`0!Q
M````DY4!`!,````%E@$`"0```!F6`0`*````(Y8!``T````NE@$`"P```#R6
M`0`-````2)8!``4```!6E@$`#0```%R6`0`"````:I8!``8```!ME@$`"@``
M`'26`0`7````?Y8!`!(```"7E@$`$P```*J6`0`6````OI8!`#$```#5E@$`
M`P````>7`0`$````"Y<!`!D````0EP$`"````"J7`0`2````,Y<!``4```!&
MEP$`&0```$R7`0`(````9I<!``8```!OEP$`&0```':7`0`.````D)<!``@`
M``"?EP$`"P```*B7`0`%````M)<!``D```"ZEP$`!P```,27`0`8````S)<!
M``,```#EEP$`!@```.F7`0`+````\)<!``P```#\EP$`"@````F8`0`,````
M%)@!`!<````AF`$`"````#F8`0`'````0I@!`!$```!*F`$`(P```%R8`0!0
M````@)@!`#8```#1F`$`.@````B9`0`'````0YD!``H```!+F0$`!````%:9
M`0`)````6YD!``@```!EF0$`"@```&Z9`0`)````>9D!``8```"#F0$`#0``
M`(J9`0`&````F)D!``0```"?F0$`.P```*29`0`^````X)D!`#T````?F@$`
M)@```%V:`0`%````A)H!`!````"*F@$`!@```)N:`0`+````HIH!``P```"N
MF@$`&0```+N:`0`0````U9H!`!@```#FF@$`!````/^:`0`%````!)L!``L`
M```*FP$`!0```!:;`0`*````')L!`!X````GFP$`!````$:;`0`+````2YL!
M``P```!7FP$`#@```&2;`0`/````<YL!``X```"#FP$`"````)*;`0`)````
MFYL!``4```"EFP$`,P```*N;`0`S````WYL!`#P````3G`$`+P```%"<`0!.
M````@)P!`$@```#/G`$`-0```!B=`0!6````3IT!`#L```"EG0$`3````.&=
M`0`P````+IX!`!$```!?G@$`&0```'&>`0`+````BYX!`$,```"7G@$`+P``
M`-N>`0`B````"Y\!`"X````NGP$`$````%V?`0`2````;I\!``<```"!GP$`
M!@```(F?`0`Q````D)\!`#$```#"GP$`.````/2?`0`*````+:`!`!L````X
MH`$`*0```%2@`0`?````?J`!`!,```">H`$`!@```+*@`0`*````N:`!``P`
M``#$H`$`#P```-&@`0`9````X:`!`%\```#[H`$`?0```%NA`0!Z````V:$!
M``T```!4H@$`"````&*B`0`)````:Z(!`!````!UH@$`$0```(:B`0`.````
MF*(!``8```"GH@$`%P```*ZB`0`5````QJ(!`!,```#<H@$`%````/"B`0`;
M````!:,!`"H````AHP$`EP```$RC`0`1````Y*,!``8```#VHP$`$0```/VC
M`0`*````#Z0!``L````:I`$`#0```":D`0`C````-*0!`!,```!8I`$`%@``
M`&RD`0`/````@Z0!`!````"3I`$`#0```*2D`0`7````LJ0!`"P```#*I`$`
M*P```/>D`0`K````(Z4!`"H```!/I0$`-@```'JE`0`U````L:4!`!P```#G
MI0$`40````2F`0`5````5J8!`!0```!LI@$`%@```(&F`0`5````F*8!`!8`
M``"NI@$`%@```,6F`0`5````W*8!`!4```#RI@$`%`````BG`0`S````':<!
M`!@```!1IP$`&````&JG`0`[````@Z<!`!(```"_IP$`"````-*G`0`4````
MVZ<!`",```#PIP$`%````!2H`0`4````*:@!`!,````^J`$`&0```%*H`0`6
M````;*@!`!8```"#J`$`&P```)JH`0`9````MJ@!`!0```#0J`$`'P```.6H
M`0`B````!:D!`!4````HJ0$`%0```#ZI`0`7````5*D!`!4```!LJ0$`&@``
M`(*I`0`=````G:D!`!L```"[J0$`&````->I`0`(````\*D!`!````#YJ0$`
M&`````JJ`0`$````(ZH!``8````HJ@$`"P```"^J`0`4````.ZH!``8```!0
MJ@$`"@```%>J`0`&````8JH!``<```!IJ@$`!P```'&J`0`&````>:H!``4`
M``"`J@$`%P```(:J`0`&````GJH!``D```"EJ@$`!````*^J`0`$````M*H!
M``D```"YJ@$`"@```,.J`0`)````SJH!`!````#8J@$`$0```.FJ`0`*````
M^ZH!`!4````&JP$`!0```!RK`0`U````(JL!``\```!8JP$`$@```&BK`0`<
M````>ZL!``X```"8JP$`#````*>K`0`.````M*L!`$D```##JP$`!@````VL
M`0`(````%*P!`"$````=K`$`#@```#^L`0`3````3JP!``8```!BK`$`"P``
M`&FL`0`)````=:P!``<```!_K`$`!````(>L`0`-````C*P!`!<```":K`$`
M#P```+*L`0`6````PJP!`!0```#9K`$`&P```.ZL`0`:````"JT!``@````E
MK0$`!@```"ZM`0`&````-:T!`!T````\K0$`!P```%JM`0`%````8JT!`!$`
M``!HK0$`"P```'JM`0`'````AJT!``4```".K0$`!P```)2M`0`&````G*T!
M``T```"CK0$`"@```+&M`0`.````O*T!`!,```#+K0$`%0```-^M`0`4````
M]:T!`!L````*K@$`$P```":N`0`5````.JX!``@```!0K@$`!````%FN`0`(
M````7JX!`!(```!GK@$`$@```'JN`0`)````C:X!``D```"7K@$`&0```*&N
M`0`3````NZX!``4```#/K@$`$0```-6N`0`E````YZX!`!0````-KP$`%@``
M`"*O`0`1````.:\!``T```!+KP$`#````%FO`0`)````9J\!``\```!PKP$`
M#@```("O`0`0````CZ\!`!````"@KP$`,````+&O`0`P````XJ\!`"P````3
ML`$`"0```$"P`0`'````2K`!``<```!2L`$`$````%JP`0`0````:[`!``,`
M``!\L`$`"````("P`0`@````B;`!``@```"JL`$`"````+.P`0`/````O+`!
M`&D```#,L`$`&0```#:Q`0`+````4+$!``4```!<L0$`!P```&*Q`0`:````
M:K$!`!H```"%L0$`$P```*"Q`0`)````M+$!``(```"^L0$`!````,&Q`0`D
M````QK$!``<```#KL0$`!0```/.Q`0`O````^;$!``H````IL@$`!0```#2R
M`0`'````.K(!`!4```!"L@$`$````%BR`0`&````:;(!``@```!PL@$`"0``
M`'FR`0`$````@[(!``4```"(L@$`=````(ZR`0`+`````[,!``X````/LP$`
M&````!ZS`0`$````-[,!``P````\LP$`)@```$FS`0`U````<+,!``X```"F
MLP$`"@```+6S`0`2````P+,!``L```#3LP$`"0```-^S`0`9````Z;,!`"@`
M```#M`$`*0```"RT`0`H````5K0!`"````!_M`$`#@```*"T`0`#````K[0!
M``X```"SM`$`!P```,*T`0`*````RK0!``H```#5M`$`%````."T`0`)````
M];0!`%H```#_M`$`'````%JU`0`.````=[4!``P```"&M0$`&P```).U`0!,
M````K[4!`!T```#\M0$`!P```!JV`0`D````(K8!`#````!'M@$`"````'BV
M`0`&````@;8!`"(```"(M@$`!0```*NV`0`'````L;8!`"D```"YM@$`*```
M`..V`0`T````#+<!``@```!!MP$`#0```$JW`0`>````6+<!`&(```!WMP$`
M&````-JW`0`6````\[<!`!4````*N`$``@```""X`0`,````([@!``4````P
MN`$`#@```#:X`0`.````1;@!``<```!4N`$`#P```%RX`0`&````;+@!``@`
M``!SN`$`#@```'RX`0`)````B[@!``H```"5N`$`"@```*"X`0`W````J[@!
M``<```#CN`$`$@```.NX`0`3````_K@!`!X````2N0$`$@```#&Y`0`*````
M1+D!``H```!/N0$`"P```%JY`0`)````9KD!``H```!PN0$`"0```'NY`0`(
M````A;D!`!\```".N0$`$0```*ZY`0`/````P+D!``H```#0N0$`"@```-NY
M`0`+````YKD!`!$```#RN0$`!0````2Z`0`9````"KH!``0````DN@$`!P``
M`"FZ`0`%````,;H!``4````WN@$`"P```#VZ`0`8````2;H!`!(```!BN@$`
M&0```'6Z`0`;````C[H!`"(```"KN@$`%@```,ZZ`0`7````Y;H!`!(```#]
MN@$`%@```!"[`0`(````)[L!``,````PNP$`#0```#2[`0`.````0KL!``<`
M``!1NP$`'0```%F[`0`*````=[L!``X```""NP$`)@```)&[`0`K````N+L!
M`!8```#DNP$`"P```/N[`0`+````![P!``8````3O`$`$````!J\`0`5````
M*[P!``<```!!O`$`"0```$F\`0`%````4[P!``<```!9O`$`!@```&&\`0`$
M````:+P!``0```!MO`$`0````'*\`0`Z````L[P!`!0```#NO`$`,P````.]
M`0`[````-[T!`!$```!SO0$`3````(6]`0`Z````TKT!`$L````-O@$`2P``
M`%F^`0!1````I;X!`!<```#WO@$`&0````^_`0`7````*;\!`!4```!!OP$`
M'0```%>_`0`3````=;\!`!H```")OP$`%````*2_`0`7````N;\!`!P```#1
MOP$`-P```.Z_`0`W````)L`!`#L```!>P`$`.````)K``0`Y````T\`!`#8`
M```-P0$`=0```$3!`0`C````NL$!`"D```#>P0$`#`````C"`0`<````%<(!
M``P````RP@$`%````#_"`0`T````5,(!`"P```")P@$`,````+;"`0`+````
MY\(!`%P```#SP@$`5@```%##`0`%````I\,!`!D```"MPP$`%@```,?#`0`,
M````WL,!`!0```#KPP$`$@````#$`0`(````$\0!``H````<Q`$`"0```"?$
M`0`0````,<0!``\```!"Q`$`%````%+$`0`0````9\0!`!(```!XQ`$`!P``
M`(O$`0`E````D\0!``@```"YQ`$`!````,+$`0`2````Q\0!`!(```#:Q`$`
M$0```.W$`0`O````_\0!``(````OQ0$`!@```#+%`0`/````.<4!``D```!)
MQ0$`!P```%/%`0`<````6\4!``0```!XQ0$`.P```'W%`0`.````N<4!`!@`
M``#(Q0$`!````.'%`0`-````YL4!`"\```#TQ0$`&0```"3&`0`@````/L8!
M`%X```!?Q@$`%P```+[&`0!'````UL8!`"D````>QP$`#0```$C'`0`-````
M5L<!`!0```!DQP$`$0```'G'`0`,````B\<!`!8```"8QP$`#````*_'`0`=
M````O,<!`!8```#:QP$`"````/''`0`4````^L<!``X````/R`$`*@```![(
M`0`2````2<@!`!D```!<R`$`&````';(`0`:````C\@!`"L```"JR`$`"```
M`-;(`0`)````W\@!`!D```#IR`$`$0````/)`0`3````%<D!`!(````IR0$`
M&0```#S)`0`1````5LD!`!0```!HR0$`&P```'W)`0`*````F<D!``P```"D
MR0$`"````+')`0`%````NLD!`"$```#`R0$`!@```.+)`0`/````Z<D!``@`
M``#YR0$`$0````+*`0`(````%,H!`!X````=R@$`$0```#S*`0`Y````3LH!
M`!@```"(R@$`"0```*'*`0`*````J\H!`"(```"VR@$`"````-G*`0`?````
MXLH!``0````"RP$`'`````?+`0`(````),L!``<````MRP$`'````#7+`0`P
M````4LL!``8```"#RP$`(````(K+`0`2````J\L!``8```"^RP$`$````,7+
M`0`3````ULL!``0```#JRP$`"0```._+`0`+````^<L!``<````%S`$`!0``
M``W,`0`(````$\P!``4````<S`$`"P```"+,`0`?````+LP!`#X```!.S`$`
M3````(W,`0`G````VLP!`#8````"S0$`)P```#G-`0!5````8<T!`"<```"W
MS0$`-P```-_-`0`W````%\X!`(L```!/S@$`*````-O.`0`%````!,\!``<`
M```*SP$`"````!+/`0`(````&\\!`!L````DSP$`'0```$#/`0`J````7L\!
M`"H```")SP$`)@```+3/`0!`````V\\!`$8````<T`$`"0```&/0`0`7````
M;=`!``L```"%T`$`"````)'0`0`X````FM`!`!8```#3T`$`$````.K0`0`2
M````^]`!``@````.T0$`$P```!?1`0`(````*]$!``T````TT0$`%@```$+1
M`0`G````6=$!`"@```"!T0$`0P```*K1`0`+````[M$!`!T```#ZT0$`!0``
M`!C2`0`'````'M(!`!@````FT@$`(P```#_2`0`,````8](!``4```!PT@$`
M"@```';2`0`,````@=(!``P```".T@$`"P```)O2`0`:````I](!``H```#"
MT@$`"@```,W2`0`%````V-(!`!$```#>T@$`20```/#2`0!=````.M,!`!X`
M``"8TP$`#````+?3`0`F````Q-,!`!P```#KTP$`$@````C4`0`3````&]0!
M``T````OU`$`"P```#W4`0`0````2=0!`"T```!:U`$`"0```(C4`0`-````
MDM0!``X```"@U`$`%@```*_4`0`,````QM0!`#X```#3U`$`"````!+5`0`I
M````&]4!`!````!%U0$`%````%;5`0!%````:]4!`#,```"QU0$`-P```.75
M`0`T````'=8!`#````!2U@$`$````(/6`0`,````E-8!`!4```"AU@$`'@``
M`+?6`0`7````UM8!``H```#NU@$`%P```/G6`0`>````$=<!``<````PUP$`
M&@```#C7`0`<````4]<!``8```!PUP$`!@```'?7`0`2````?M<!``P```"1
MUP$`%P```)[7`0`%````MM<!``@```"\UP$`#@```,77`0`1````U-<!`!(`
M``#FUP$`$P```/G7`0`3````#=@!``<````AV`$`!@```"G8`0`H````,-@!
M`!L```!9V`$`&@```'78`0`'````D-@!`!4```"8V`$`!@```*[8`0`C````
MM=@!`",```#9V`$`*P```/W8`0`+````*=D!``D````UV0$`(P```#_9`0`#
M````8]D!``8```!GV0$`"@```&[9`0`"````>=D!``P```!\V0$`%0```(G9
M`0`+````G]D!`!D```"KV0$`(````,79`0`7````YMD!``4```#^V0$`"@``
M``3:`0`5````#]H!`!(````EV@$`#0```#C:`0`)````1MH!``X```!0V@$`
M#````%_:`0`7````;-H!`%@```"$V@$`'0```-W:`0`T````^]H!`!0````P
MVP$`#````$7;`0`%````4ML!``T```!8VP$`$0```&;;`0`/````>-L!`"``
M``"(VP$`&````*G;`0`0````PML!`"(```#3VP$`#@```/;;`0`F````!=P!
M`!`````LW`$`$````#W<`0"1````3MP!`"(```#@W`$`'`````/=`0`Q````
M(-T!`"````!2W0$`&@```'/=`0`L````CMT!`!H```"[W0$`(P```-;=`0`9
M````^MT!``\````4W@$`!P```"3>`0`(````+-X!``D````UW@$`%@```#_>
M`0`,````5MX!`"H```!CW@$`$@```([>`0`6````H=X!``D```"XW@$`#```
M`,+>`0![````S]X!`%0```!+WP$`10```*#?`0!P````YM\!``T```!7X`$`
M)0```&7@`0`L````B^`!``H```"XX`$`!P```,/@`0`5````R^`!`$(```#A
MX`$`!@```"3A`0!4````*^$!`#````"`X0$`(@```+'A`0`2````U.$!`"4`
M``#GX0$`*@````WB`0`O````..(!`"D```!HX@$`+P```)+B`0`E````PN(!
M`!4```#HX@$`!P```/[B`0`,````!N,!``X````3XP$`%P```"+C`0`+````
M.N,!`#T```!&XP$`#````(3C`0`,````D>,!``@```">XP$`$P```*?C`0`(
M````N^,!``4```#$XP$`'0```,KC`0`(````Z.,!``D```#QXP$`!@```/OC
M`0`-`````N0!``T````0Y`$`$@```![D`0`4````,>0!``P```!&Y`$`&```
M`%/D`0`-````;.0!``@```!ZY`$`$0```(/D`0`>````E>0!`!````"TY`$`
M"0```,7D`0`:````S^0!`"P```#JY`$`$P```!?E`0`M````*^4!`"T```!9
MY0$`#0```(?E`0`'````E>4!``@```"=Y0$`!P```*;E`0`$````KN4!`!4`
M``"SY0$`#````,GE`0`-````UN4!``P```#DY0$`!0```/'E`0`)````]^4!
M``@````!Y@$`"0````KF`0`)````%.8!`!@````>Y@$`!@```#?F`0`.````
M/N8!``8```!-Y@$`#P```%3F`0`,````9.8!`"````!QY@$`"@```)+F`0`"
M````G>8!`"4```"@Y@$`!P```,;F`0`*````SN8!`(H```#9Y@$`#````&3G
M`0`&````<><!`",```!XYP$`-````)SG`0`@````T><!`"````#RYP$`5P``
M`!/H`0`Q````:^@!`#0```"=Z`$`(P```-+H`0`@````]N@!``4````7Z0$`
M#P```!WI`0`-````+>D!``\````[Z0$`!@```$OI`0`-````4ND!`!,```!@
MZ0$`#P```'3I`0`/````A.D!`!$```"4Z0$`#````*;I`0`'````L^D!``<`
M``"[Z0$`"````,/I`0`6````S.D!``D```#CZ0$`"````.WI`0`'````]ND!
M`!P```#^Z0$`'0```!OJ`0`9````.>H!``@```!3Z@$`$P```%SJ`0`(````
M<.H!``T```!YZ@$`"0```(?J`0`5````D>H!``<```"GZ@$`%0```*_J`0`&
M````Q>H!`!L```#,Z@$`#0```.CJ`0`<````]NH!``4````3ZP$`"````!GK
M`0`-````(NL!`!\````PZP$`"@```%#K`0`,````6^L!`"D```!HZP$`'```
M`)+K`0`2````K^L!``0```#"ZP$`"````,?K`0`+````T.L!``D```#<ZP$`
M`@```.;K`0`6````Z>L!``@`````[`$`)@````GL`0`F````,.P!`#X```!7
M[`$`+P```);L`0`T````QNP!`#H```#[[`$`;P```#;M`0`)````INT!`&P`
M``"P[0$`.P```!WN`0!3````6>X!`'(```"M[@$`*0```"#O`0!'````2N\!
M`"\```"2[P$`,0```,+O`0`?````].\!`#X````4\`$`Z`$``%/P`0`B````
M//(!``D```!?\@$`20```&GR`0"H````L_(!`"L```!<\P$`-0```(CS`0!#
M````OO,!`'8````"]`$`2````'GT`0!"````PO0!`!0````%]0$`"@```!KU
M`0`]````)?4!`!\```!C]0$`(@```(/U`0`P````IO4!`"H```#7]0$`*0``
M``+V`0!0````+/8!`!(```!]]@$`"````)#V`0!(````F?8!`#<```#B]@$`
M*@```!KW`0`G````1?<!`"8```!M]P$`*P```)3W`0!H````P/<!`$,````I
M^`$`1@```&WX`0!"````M/@!`#L```#W^`$`4````#/Y`0!M````A/D!`%@`
M``#R^0$`00```$OZ`0`]````C?H!`$````#+^@$`9@````S[`0!X````<_L!
M`'````#L^P$`<````%W\`0`X````SOP!`"X````'_0$`+@```#;]`0`P````
M9?T!`(,```"6_0$`>````!K^`0!_````D_X!`-4````3_P$`&@```.G_`0`L
M````!``"`#8````Q``(`*P```&@``@!8````E``"`"T```#M``(`5P```!L!
M`@`J````<P$"``P```">`0(`P````*L!`@!=````;`("`",```#*`@(`.```
M`.X"`@`G````)P,"`"````!/`P(`0P```'`#`@`&````M`,"``<```"[`P(`
M!````,,#`@`-````R`,"``H```#6`P(`"P```.$#`@`+````[0,"``4```#Y
M`P(`$````/\#`@`"````$`0"`%\````3!`(`!0```',$`@`<````>00"``0`
M``"6!`(`!P```)L$`@`&````HP0"``4```"J!`(`.@```+`$`@`$````ZP0"
M`!<```#P!`(`#0````@%`@`3````%@4"`!`````J!0(``@```#L%`@`(````
M/@4"``8```!'!0(`%0```$X%`@`,````9`4"`!<```!Q!0(`!@```(D%`@`.
M````D`4"``H```"?!0(`"````*H%`@`N````LP4"``@```#B!0(`!@```.L%
M`@`'````\@4"`#@```#Z!0(`7````#,&`@!(````D`8"`$D```#9!@(`,@``
M`",'`@`P````5@<"`#,```"'!P(`.````+L'`@`O````]`<"`"H````D"`(`
M-@```$\(`@`Q````A@@"`"L```"X"`(`-@```.0(`@`M````&PD"`"T```!)
M"0(`0@```'<)`@`D````N@D"`#\```#?"0(`.@```!\*`@`Q````6@H"`#4`
M``","@(`,````,(*`@`K````\PH"`#8````?"P(`,@```%8+`@`V````B0L"
M`#4```#`"P(`*P```/8+`@`M````(@P"`#````!0#`(`.P```($,`@`K````
MO0P"`"@```#I#`(`1@```!(-`@!"````60T"`"<```"<#0(`-````,0-`@!/
M````^0T"`#(```!)#@(`-@```'P.`@`Q````LPX"`#(```#E#@(`+````!@/
M`@`I````10\"`"X```!O#P(`1P```)X/`@`S````Y@\"`$8````:$`(`+P``
M`&$0`@!@````D1`"``T```#R$`(`'``````1`@`B````'1$"`$$```!`$0(`
M)0```((1`@`0````J!$"``\```"Y$0(`'````,D1`@`6````YA$"`!(```#]
M$0(`)````!`2`@`)````-1("``D````_$@(`)0```$D2`@`H````;Q("`"<`
M``"8$@(`)P```,`2`@`D````Z!("``D````-$P(``P$``!<3`@`2````&Q0"
M`!T````N%`(`#@```$P4`@`0````6Q0"`!8```!L%`(`&````(,4`@`?````
MG!0"``D```"\%`(`3@```,84`@`:````%14"`!,````P%0(`!P```$05`@`5
M````3!4"``P```!B%0(`60```&\5`@`(````R14"`"D```#2%0(`$@```/P5
M`@`5````#Q8"`!4````E%@(`/@```#L6`@`<````>A8"``P```"7%@(`*```
M`*06`@`-````S18"``X```#;%@(`%0```.H6`@`*`````!<"`"0````+%P(`
M"P```#`7`@`9````/!<"``H```!6%P(`'0```&$7`@`M````?Q<"``4```"M
M%P(`)P```+,7`@`'````VQ<"``<```#C%P(`"0```.L7`@!,````]1<"``<`
M``!"&`(`$0```$H8`@`+````7!@"`!<```!H&`(`"0```(`8`@`)````BA@"
M``<```"4&`(`%@```)P8`@`+````LQ@"`!X```"_&`(`#P```-X8`@`8````
M[A@"`!P````'&0(`!0```"09`@`'````*AD"`!D````R&0(`!P```$P9`@`Q
M````5!D"``T```"&&0(`$0```)09`@`'````IAD"``(```"N&0(`$````+$9
M`@`/````PAD"``L```#2&0(``P```-X9`@`'````XAD"``L```#J&0(`"@``
M`/89`@`1`````1H"``X````3&@(`&P```"(:`@`<````/AH"``H```!;&@(`
M-@```&8:`@`D````G1H"`"H```#"&@(`%P```.T:`@`-````!1L"`#X````3
M&P(`!@```%(;`@`7````61L"`$````!Q&P(`#@```+(;`@`'````P1L"``<`
M``#)&P(`!````-$;`@`$````UAL"``D```#;&P(`'@```.4;`@`%````!!P"
M``8````*'`(`"````!$<`@`,````&AP"``8````G'`(`%````"X<`@`4````
M0QP"`$````!8'`(`-````)D<`@`N````SAP"``P```#]'`(`'@````H=`@`A
M````*1T"`"\```!+'0(`*0```'L=`@`4````I1T"``(```"Z'0(`!````+T=
M`@`,````PAT"``@```#/'0(`!0```-@=`@`"````WAT"`!$```#A'0(`80``
M`/,=`@`N````51X"`!H```"$'@(`.@```)\>`@`Q````VAX"`%X````,'P(`
M%@```&L?`@!]````@A\"`"D`````(`(`5@```"H@`@`I````@2`"`$````"K
M(`(`/@```.P@`@`U````*R$"`$P```!A(0(`-0```*XA`@`W````Y"$"`#D`
M```<(@(`'P```%8B`@`N````=B("`#(```"E(@(`0````-@B`@`3````&2,"
M`!(````M(P(`#````$`C`@")````32,"``@```#7(P(`Q@```.`C`@!Q````
MIR0"`(L````9)0(`+0```*4E`@!E````TR4"`!<````Y)@(`)@```%$F`@`7
M````>"8"`!<```"0)@(`&@```*@F`@`D````PR8"`$,```#H)@(`)@```"PG
M`@`@````4R<"`'<```!T)P(`'````.PG`@`,````"2@"``L````6*`(`!0``
M`"(H`@`&````*"@"``@````O*`(`!0```#@H`@`6````/B@"`!````!5*`(`
M%0```&8H`@`@````?"@"`!$```"=*`(`#P```*\H`@`-````OR@"``D```#-
M*`(`#@```-<H`@`(````YB@"`!4```#O*`(`"0````4I`@`)````#RD"`!,`
M```9*0(`#@```"TI`@`'````/"D"`!(```!$*0(`#@```%<I`@`9````9BD"
M``D```"`*0(`"@```(HI`@`2````E2D"``@```"H*0(`"0```+$I`@`I````
MNRD"`"(```#E*0(`$`````@J`@`E````&2H"`!0````_*@(`&P```%0J`@`1
M````<"H"``H```""*@(`%@```(TJ`@`'````I"H"``4```"L*@(`%0```+(J
M`@`$````R"H"``(```#-*@(``@```-`J`@`2````TRH"``8```#F*@(`!@``
M`.TJ`@`2````]"H"`!<````'*P(`!P```!\K`@`Z````)RL"``(```!B*P(`
M!````&4K`@`3````:BL"`!@```!^*P(`"@```)<K`@`'````HBL"`!(```"J
M*P(`!0```+TK`@`9````PRL"``@```#=*P(`%P```.8K`@`5````_BL"`!,`
M```4+`(``@```"@L`@`.````*RP"``P````Z+`(`#0```$<L`@`6````52P"
M`#H```!L+`(`!P```*<L`@`)````KRP"`!$```"Y+`(`!0```,LL`@`"````
MT2P"``L```#4+`(``0```%\'```P````+P8``"`%````````P`0``*X&```>
M`````````!@'``#H`0``S@0``)0%```M`@```````)<!``"S!0``````````
M````````;@0``&$"```I!```S``````````@`P``G`0````````A````````
M`-L"````````H0(``'L!``"B`P``*@``````````````FP0```````#6`0``
M908``&L!```?`0``E@,```````#'`P``G@(``&P!``"%!P``*````"@"``""
M`0``_0,```````!]!P```````$<"```W!0`````````````?!P``````````
M``#!`P``100```````!X!```30```.H&``!'`0``7@$``$X&```\`@``M@(`
M`*<"````````4P$``$T"````````'P(``'L'``"%`@``J`(````````<`0``
M@`0````````.`0``0@``````````````)@4```````#-````_0(``#,```!A
M!@``U@,``*<$``"7!0``80$`````````````>P0``.T"```!!```;`(`````
M```)!P```````.$!`````````````'$```##`0```````*T&``!X`P``````
M``````!Q!0```````#4$``!K!@``Q@```)`!```2!```]@,``$X!``!W`@``
M5@(````````Q``````````````"F``````````T!``#-!@``!````'8%``!^
M!@```````*L&``#O!@```````"`$```````````````````T````ZP0``+L%
M``"Q!0``TP```"<````=!````````%X$``#K`@``8P0``+@#````````UP(`
M````````````U`,```<$``````````````````#,!@``,@(```````#:`P``
M^0$```````#[`@``&@(````````0!P```````',"``!6````^`,``,0#``"W
M!0``P04``+L!``#@!```E04``&D$``#6!0``4@<```````!W`0``"@```%@'
M````````70$``,X!``!+````[08``(0!``#``P``V`$```````"*!@``````
M`-`$``!?`0``P@```+X&````````PP4``&<&``!B````^0,``$\!```L`@``
M+`0``'8&``!G!0``70```&\#``!4!0```````+,!```$!P``Z@0`````````
M`````````#,&````````````````````````(@,``,,#``">````Q@(``.$#
M`````````````)0&```'`P``OP```(L"````````M04```````#@!@``'0,`
M`!(#``!R!P```````+@&````````AP```,8!``"S!@``\00``)`#````````
M=@$``#$$``!6!0`````````````C!0``H@```!H$````````7@(``#T#``#5
M!0``HP(```````">`P``:@0```P%``#>!@```````"`````J!```S`$``$P&
M``"Z!```)08``$<'``"T!```@`,```````"5`P``TP(``%\#```^`P``V0$`
M`)H!````````?`8```````!P````Y`4`````````````]08```````"/`0``
M#P,``.8%``#@`P``3`<``)P%``!Y!```^@```&0!``!%!@```````"$$```T
M!0``C@```"0&````````N`(``$\&````````W@```$@'``"\`0``BP$``'$'
M``#T`P``/@0``"<$```C`0``:0```+4````2`````````*L%````````M`(`
M`'(```#W`0``?0````(&```1!P``BP`````````!`P``E````,X"````````
MG0$``"$'``"]`P``=P8``%`'``!S!@````````````"M`P``@@4`````````
M`````````#T"``!J`0``5`<``(("``"N`0``FP8``!X"```Q`0``.@8``*$%
M`````````````!T!``!0````O`8``/<&``"N!`````````````#+````````
M`)D#````````X@8``-\```#.!@``XP```/@````T`0```@$``#($``!*````
MJ@,``'\!````````\P``````````````W`4``$\```!G!P``1`<``'(!``"C
M!```I````#('``"(!0``P`$``&T'````````KP$````````%!@```````"\`
M``#\`@```````'0!````````X`$`````````````XP(````````+!@``$0$`
M`!('``#A!```6P```/X!```C!```#P````D%``"0````)04`````````````
M#`0``%L&``!+!@``C08```````!6`0```````.(%```I!0``EP0``/\%``#2
M``````````````![!@```````!(!```X`@``^`8``,(!``!3`@``^`4``,T%
M``"0!P``H0``````````````L`,``*P&``"3!0``I`,``+X%``!I!@``````
M`.\#````````@P8``-("``!O````!@$``$(#```=!P``D@8`````````````
M`````#@#``",````0P$``$X```!?!0``30$```````!8!````````-@"``"Q
M````80,``#\$``!&`0``P08``%P'``#=````GP0````````D````#`$``(0#
M``#H!```A`8``#H!``"T!0``$0```!8$``#>!````````#4!``#0`0``NP(`
M```````Y````Q00`````````````%`0```T'``!.!P``50<``+\#```N`@``
M`````"<#``!J`@``H`0``-L#```B`@```````,8%``#D````"P,``'D!``#*
M!@``;`8```````#R`P``4@0``.4"```Z`P``10$``.@```#*!````````$\"
M``!U`P```````(($````````60(``(\$``#B``````````````"2!0``HP,`
M`#\%``"G!0``O@$``/X%````````O@,``"T#``!(!@``W04``),"``!B!P``
M!`(``#(&```*`P``*P4``*X"``!0`@``!P8``#,'``#@!0``-@8```````!T
M````D@0``/8!``````````(`````````````_@```-@&``#O````/04``(P$
M``!Q`P``<`8`````````````]P```&,"```7`0``1`$``(@$````````O00`
M`#8````L`P``_@0``$\%````````0P4``%P#``"#`P``V08``!H%```_`0``
M;`0``!8'`````````````(`'````````<P<``.@"````````]@```#\"``!0
M!```*@$``)$#```)!```[`(``,<&``#5`0``#`(``(<%```N!```!`0``.($
M``#N!@````````````!]`P````````$!```>!0``B0,```4$``#1`@``.`8`
M`$X#``#?`P``4P```',$```)`P``(P,``.D&`````````````&X#``"2`P``
M`````%,%````````5````#T&``!O`@``)`,```````"=`@``(@<````````3
M!P``?`$``%@```#D!@``>P```"H%``!K!```R@(`````````````HP8``)T`
M``!7`0```````(D%```4!0``=08```8#```E`@``.````%P%````````+0``
M`(\'```F`@```````"8!``!H`````````.4#``!5````,P4``"@!````````
M``````````!+!````````!`%``#Y!0```````'`%```U!0````````````!%
M`````````(D$```[!P``\0,``%T&```9!``````````````M!P```````(H`
M``"V````X`````````!X!@````````````!I!0``"P$````````1`@``````
M````````````ZP$``)L```#3`P``XP,`````````````L0(``&D"``"6!```
M`````$`'````````800``!D#````````"@<``-P`````````V`0``/L$````
M````6@(```````!H!```A00``-`&``#/!0``M````"L$````````BP,``&H'
M``"W````[0```+(%```&!@``&@````````!,````<@0``,T$``#%`P``6@,`
M```````V`@````````````"G`0```@````````"K!```````````````````
MYP,``%D%```J`P``3P,``"4'``#>`0````4``/4%``!'`P``8`````````"P
M!@``%@`````````````````````````\````_````*T$```Y!```U0(``,$"
M``#S!@``'@,``(T```"E`P``3@(```````!F!0```````%L#``#:!0``````
M`(,"````````4@,``/0&``"N`P``U0```-$`````````Y@8``(,```#;!```
M#00``&("```D!0``90<``.T$``#X!```5P(``#$&``#&!@``7P0``,D!``!Q
M!@```````$@$````````A````*($```#`@``M08``%@#``"]````E0$``*(&
M````````````````````````A0```(<&``!0`0``````````````````_@(`
M``````"*`0``X@,````````Z!0``\0(``!,!``"(`0``'@8```````"R````
M&P8``&T!``"#`0```````)8```#G!```/@$``'X!``"/`@``R`(``+\$``!:
M!P```````$P"```1!@``S0,``#8#```+`@``.`4``'H%``#.`P``?`<``$P$
M``!M!0``Y0$````````N`0``4@$``%,$``#;`0``I@,```4!``#.!0``````
M`%H!``#4!0``@0,``+4#``#:````M`$``$,$```U`@``600```X%````````
M2P4``$8#``"H`0``F00``!\```"B`@````````H%````````Q0$``%T'``"?
M`0``_P8````````A!0``\@$``',!````````O`4``'0%``#:`@``!`8`````
M``#=`0```````/P#`````````````#`$``!D````````````````````````
M````````````QP(``/\#```;`@``V`,``!@$``!F`@```````+\"````````
M`````&L#````````R0```!8"``!H!P``EP,``$<%``!6`P``/@``````````
M````(P8```````#(!0``:`8``)D!``````````````<'``!\`@```````+4!
M``"X`````````$X$``"+!```?P```*\%``#/`0```````/L#``"8!@``6`4`
M`#P'``"'!P``*`,``!4```",`P``/00``#\'``!@`@```````"P'````````
M``````````"Y!@``^00``",'``"8````*`0`````````````5P8``-<&``##
M!```MP8``*(!```,````"`$``#0&``!%!P``WP4``)L"````````R00``.H#
M``"V`0``!`4```````!U!P```````'8#``!_!```"`4``$T&``#,!```_0``
M``````!7!P``X0(``!\&``!``P``L08```````#:!@``!P4``.0$````````
M-0````@#``!5`@```````'@!```F!@````````L$``#7`0```````*D&``"-
M`P``00$``,D#``!$!0``D`8``````````````````($`````````A@```!H&
M``!\`P```````/,$``#"`P```````(D&````````,`(``+(&``"3````4@8`
M`*$#``!0!0```````%<```#B`0``F@0``),#``!:!0```````'8"``!Z`P``
M$`8``!D!````````H````(T$`````````````'X'``!#!@``"P4``*(%``!"
M!P```````$D&``!C!@``````````````````KP,``#L```")!P``C@,``)8%
M``"!`@```````!$$````````=`(``%T%``#?!@``I`8``+,`````````$P(`
M`*`!````````#P(``)\"````````%0$````````<!P``6@0``$P!``#?`@``
M`P4````````9!P``;@(```````#F!```-P8``%D#``!&!P``Y@,`````````
M````XP4``!P$``!R!@``K0```!0"``"H!````````+4"````````TP4``*L!
M``"Y`@``ZP8``'<#``!@`0``[0$``*@%```@`@````````````#F`@``)00`
M````````````BP8``"@'`````````````/8%``!G`@```````,T!``!R`@``
M*0(``/0!``#"`@``)0$``!L%```5!@``.P8``%H```!>````=P4``.,!``#_
M`@``.P$``/T$```B!```````````````````Y@$``-X"```3!```K04``*8!
M```'`@``A0,``)("``!J`P```````%<$``#J````P````'@%````````T00`
M```&``";`0````````````!O`0``&08``#X%``"9`@````````````"X!0``
MGP,``#0"``"S!````````(4%``"=!@``30<```$"``"`````'P4``,L!```"
M!P``;P8``,H#``"`!@``&`$``.X!````````8P$``+8%``#U````%P,`````
M``!X`@```````&D!``!>`P```````(X'```O`P```````"8#``#,`@``<`,`
M``````"?`````````````````````````+($``"X`0``N00``-`"````````
M40<``#T'``#Z`P```````-H$```P`P``'`,``(@#``#7`P``.0<```````#2
M!0``^0(``%$`````````V@$```````!C````W`0```T"`````````````)<"
M``"1````^P8````````L!@```````,\"``"K`P``\P(``&8'``#;````````
M`&X'``#$!@```````%$$``!"!@```````/("```I````B@(```````!#!P``
M`````'T!```2!0``6@8``#,"`````````````.("``"[!````````.<"``#/
M````#0```/``````````;00``-$%````````V````.0!``")`0``.P4``,D"
M``":!0``>0,```````#C!@``8P4``"@&````````5`$``.P`````````%04`
M````````````<`$``!("````````I08`````````````Q`0``&,'``"&`@``
M$P8``$\'``#5!@``00<```````"6`0``TP0```````":`P```````-(!``"/
M!@``NP```*0"``#X`@``104``$8$```$`0``40(``&$'````````)`$``)P!
M``#9`P``"@0``+H"``#&`P```````'0&``#/!@``UP0``/`&````````(@4`
M`.H%``"I````.`$```,&```<!@```````#4'```)`0``Z0$``"T!``"V!@``
M``````````"K`@``RP,``/\$````````,`$``$H"``"F!0``'````!<"``"O
M`@``-@0``'0$``"0!```U`$``-\$``#I`P``+P(``&4````Q!0``+@4``+T!
M``":!@``4P8``"0"```C`@``0`4``.X$```!!P````<``!````!B!```````
M`$H#``!8!@``2@<``%4&`````````````(0"``"Q`0``-`,````````B!@``
M&P<`````````````O@```%4%````````@08``.X%``#J`@``KP8```````#E
M!@``&`(``%8$``"E!`````````````#\`0``E`(``-(&```;````=@```+<#
M````````[`$``/<$``#S`P``Y0````````"C````T@,``+("``"=`P``F08`
M````````````8@4``.T#``!=`P``8`0``/T%```G!0``*P<``*<&``"I!```
M``,``*8"````````MP(```,!``!@`P``!0,``/0$``#7!0`````````````"
M!```F`(``&@!``!_!@``20<```4%``#'`0``R@$`````````````Y00`````
M``!E!0```````,,&``!^`@``P@0``.X"```U`P``?`0``.0#``!N`0``````
M`-T$``#N`P``^P$``,(%``#P!0``"0````````",!P``F04``,8$````````
M`````&4"``!N````60`````````#````1@4```8'````````_@8``,4```#%
M`@```````)P&````````>@(````````_`P``````````````````PP(``*0!
M``"/````304``#P%```V!P``"@8``&L"```G`@``4@4```````"_!0```P,`
M``````#<`P``*0<``#@'``".`@``C0$``/4$``"6!@``&P$```````#?`0``
MC04```````"E````9`8``!T%``")`@```````/$%````````'0```"`&````
M````MP$``*`&``"/!0````````````"8`P``#08``#$"``"5`````````'H!
M``!"`0```````!8&````````804``&L%``#*!0``Z`8``(T'````````\@4`
M`.P$``"^!```^08``+H%````````20$``%0"```]`0```````-P"````````
M20(``$`&``#I!0```````(P&``#F````Q`(```$&````````F`4``$@```#S
M!0``0P,```````````````````````"2````/@<``&T"``"3!@``/`$``.H!
M``"-`@```````%P```"(````)`<``+T%``#G`0``J@(``/0````W`0``'@<`
M`&\'``".!0``5`,``,@!`````````````*D!``#(!@```````$@#``#9!0``
MIP````````![!0``W0,``&4!````````G00```````#R`````````+4$````
M````^@$``"H'``#`!0``C@$`````````````5`8``.$%```A`P``````````
M``#R!```E`$``,4%```8!0``?P4`````````````,0<``(<"``!H!0``````
M``<```#W`P``1P8````````<!0``700``,`&``````````````H"```P!@``
M>@0````````S`P``8`8````````W`@``-P<````````7``````````````"\
M!```T````*`%``"^`@``*0$``'`'```5!P``3P0``%(```!M!@````````L'
M```>!```30,```$%`````````````.L````5!```"`(``(8'```5`@``````
M`(,$``"``@```````(8!```/!0```````"$"``"T`P``.@<``,L$````````
M:0,``#0'``!$`@``]@0``&$`````````@`4``'L"``!)!````````',```#_
M`0``B@0``$8&``"D!0``^@0``#D&``#A!@```````$`!``"Q`P``-P``````
M````````6P0````````E````4`8``"<'```A!@``S`4```````!G`P``````
M``````#H`P``=`<``/L%````````H`(``(4&```J!@```````/\````;!```
M`````&(&``#+!@``[P4`````````````H08```X#```6`P```````,T"``#>
M!0``+00``!4#``"7!@```````)\%`````````````$8```"P!```408``#D%
M`````````````,0```"Z`0``MP0``!T"````````A@4```````"3!```U`(`
M`+H````/!P```````,,````N!P````````````#7````$P,``/P&``#^`P``
MJ````$@%``#<`0``.0(``,L%`````````````,\$``#,`P``L00```````#A
M`````````)`%``!L`P``;`````````!C`P``\0```+D!``!5`P```````%L!
M``````````````````"L!0``?08```4"````````404``#H"``"&!```K```
M``````">!0``00,```,$``![`P````````X$``"R`P``;P0``%<%``#1`0``
M&04```````#/`P``L@$``'4!````````^@8`````````````!P$``&4#```K
M`P```````&8&```*`0```````)L#``!M`P``J@0``(P"``!U!0``U0,``%\"
M``#Q!@```````'$!``"A!```R````*@#``!<`@``^0````````#!````#@``
M`&H%````````>04``!,```":````<@,````````/!@```````*<#``#R!@``
M$`0``#L"````````60$``*H&```,!@``QP```(H#```.!@``*08``%X%``!;
M`@``G@$``(@&``!!!@``AP,``(`!```W!```;P4``'H&``"&!@```````$$$
M``"'!```)@<``!<&``"+!P```````/8"``!"!```6`$```````#P`P``Z0(`
M```````F````5`0``!`#```````````````````````````````````B````
M_`4``&H&```N````OP$`````````````?0(``(<!``!J````2@4``)D`````
M````'P,```````#Q`0``D`(``-D`````````2P(`````````````;`<``&@#
M``!.!0``1`0```T#``"5`@``J@4```````""!P``204``"0$``"N````?00`
M`!H!``#4````*P8``&8#`````````````&L'``"I!0``E08``.<&```@!P``
M300``#`'``!W````2P,``-,!````````[04``#,!```"!0``%`$``#T`````
M````````````````````]@8``/0%``#)!0```````$(%``#K!0```````!<'
M````````Z00``&X%```O!`````````````#0`P``?@0``*D"````````(`$`
M`'X%``!(`0``R08```P'````````U`0``$D````&````[@````````".!```
M7`8``$`$```.`@``%````*$!``!;!0``_`0``%X'``"4`P`````````!````
M````9`(````````=!@````````````#4!@``CP,````````;`P``*`4``#\&
M``!D!P``2@8``/T!``!H`@``5@<``'8'``"H!@``"`0``'P````#!P``70(`
M``````!P!````````"T&``!P`@``\P$``#H````J`@```````.0"````````
M````````````````A`<``+,"```R````+P$```````#U`@``#P$``"8$```2
M!@``4P,``*4!````````N@8``,H```!?!@``;0```*T"````````10,```8"
M``!F````5@8``(@"````````@@,``*4"``"\`P``Z0```+`!````````"P``
M`!0'```1!0``M@0``#8%``!G`0````````````#(!````````&0$``"7````
M]0,``#X"````````L````'P%````````=00``)(!````````]0$``'D'```4
M`P``KP```!H#````````@P4``-D$```6`0``+@,``&4$```<`@``K@4``'0#
M````````E00```4````T!```#04```````!*!```!`,``'@'```E`P``<@4`
M`#$#``"8!`````````````````````````````!7`P```````-8"```6!0``
M40,``#X&````````7`$```````"J`0``Z`4`````````````T0,``)8"``"K
M````[P0``)P"``!;!P````````````"<`P``>0(``.4%``!Y!@```````*0$
M``#W`@``9P```.`"``!,`P``#`,```````!D!0``3`4``+T&``#L`P``4@(`
M`(L%`````````````$`"``"[`P````0``#P$``!L!0``[`8``#D#``!B`P``
MT@0```````!D`P``0P(``+@$``"L`P``+`````````"Y!0``\`0``/H"````
M````#P0``*`#``#W!0``W`8````````0`@```@,``!0&``")````(@$``+D#
M```(!P``_08``)X&``#G!0````````````"C`0``+@8``!`!````````OP8`
M`-L%````````9P0``/`"``!_!P``N@,```@```!&`@``%P4``$$"``!$!@``
MK`0``(8#``#P`0``2`(```````!S!0```````"T%``#5!```@0$`````````
M````-P,``"P%``!_`@``B`<```````"1`@``W@,``!@&``#6!```)P$`````
M````````KP0``$L'````````Q`$``"\%```(!@````````````!*`0``G@0`
M`",```#C!```!@0``+T"``"L`0```````+0&```R`0``1P0``)$&````````
MT`4``````````````````!D```"4!`````````````"!!```500``"D#```A
M`0``[`4``-8&``#K`P```````)T%``";!0``A`4``,4&````````"0(``$D#
M``#``@``7`0``%,'````````"08``%\````?!````````'<$```"`@``````
M`,X````:!P``V`4```````!V!```T08```````"%`0``C`$````````K`@``
M.@0``$,```!Z!P``!@4```````#!`0``:P```$("``#'!```NP8``-D"````
M```````````````V`0``@0<``),!``!%`@``D0$``+`%``!'````,@,``)H"
M``#(`P``608`````````````&````'$$``"\`@``4`,``%D'````````````
M`````````````````!<$``!]!0``=0(```X'````````6`(``&8!```K`0``
MW08``&`%``"J````8`<`````````````P00``"P!```K````D00```````!$
M`P```````#L#```1`P``LP,``.\!```P!0``;@8````````\!@``,@4```4'
M``!Q`@``&0(``(P%````````G````-,&``#;!@``40$``+P```!>!@``.`0`
M``````#6````B@<``/@!````````00``````````````8@$``!,%``"V`P``
M2P$```````#T`@```````.\"```G!@``'@$`````````````D04```````"E
M!0``>````($%``"F!@``C@8``(0$`````````````#4&``""!@```````#,$
M```\`P``&`,``$$%``!S`P``+P<``(,'``"*!0``I@0``&D'``!$````````
M`#\`````````YP```-T"``!U````?P,``,<%````````RP(``/H%````````
MP@8``'X```"M`0```````((``````````````'D```"8`0``.P0```````!Z
M````L`(``/L`````````GP8``*P"``!`````J0,``+D````Y`0``=P<``%4!
M``"C!0```````'X#````````Q`4``&8$````("@E<R!D87ES(&%G;RD`("A!
M8V-E<W-K97D@)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O
M=RD`("AY97-T97)D87DI`"!A="``(B5S(B!I<R!N;W0@82!D:7)E8W1O<GDN
M`"(E<R(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO="!C;VYF
M:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!T<F5E(')E;F1E
M<F5R(&YO="!F;W5N9"X`(B5S(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S
M>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T
M96TN`"(E<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`)2XR9DU"('5S960@;V8@
M)2XR9DU"(&%L;&]W960@*"4N,F8E)2D`)60@)7,@86YD("5S`"5D(&1A>7,@
M=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+@`E9"UD87D@9F]R96-A<W0`
M)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N
M8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N
M(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`
M)7,@870@)7,@)7,`)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@8F]X
M(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@
M=&AI<R!T:6UE+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F
M;W5N9"X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#
M86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`)7,Z
M(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@
M=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@86YY(&QI;FMS(&EN(&ET(&]R
M(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN
M9F]R;6%T:6]N+@`L(&=U<W1I;F<@`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA
M8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`#$R($AO=7(@1F]R;6%T
M`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#Q0<F5V:6]U<P!!(&1A=&%B87-E
M(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@
M97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER
M960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@
M<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC
M(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@
M:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@
M<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL
M('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@
M<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-($-L;W5D<P!!32!,
M:6=H="!286EN`$%-($QI9VAT(%-N;W<`04T@4F%I;@!!32!3:&]W97)S`$%-
M(%-N;W<@4VAO=V5R<P!!32]030!!4$D@240`06)O=70@=&AI<R!E9&ET;W(`
M06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E<W,@9&5N:65D(&-R
M96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@
M5D93(&9I;&4N`$%C8V]U;G0@26YF;W)M871I;VX`06-C;W5N="!087-S=V]R
M9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`061D($-H:6QD($=R
M;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@365M8F5R
M<P!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL
M9"!G<F]U<"!T;R`B)7,B`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@(B5S
M(@!!9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@<&%I<@!!9&0@=&AE
M("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1O(&%D9')E<W,@
M8F]O:SH`061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1E9"`B
M)7,B('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N
M86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`E<RX`061D960@(B5S(B!T;R!T:&4@
M<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N`$%D9&EN9R!U<V5R<R!I<R!D
M:7-A8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E
M="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`
M061S`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!
M;&EG;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O
M=7!S`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT
M:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@
M='EP93\`06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT
M97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`
M06QT97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!
M;'1E<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`06X@:6QL96=A;"!V86QU
M92!W87,@<W!E8VEF:65D+@!!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D
M+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`06YS
M=V5R`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D80!!<'!L:6-A=&EO
M;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L
M>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<'!R;WAI;6%T92!3:7IE`$%P
M<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ90!!
M<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T
M:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)E('EO=2!S=7)E('EO=2!W
M:7-H('1O(&1E;&5T92`B)7,B(&%N9"!A;GD@<W5B+6=R;W5P<S\`07)G96YT
M:6YA`$%R;65N:6$`07)M96YI86X@*$%235-#24DM."D`07)T`$%R=6)A`$%S
M8V5N<VEO;B!)<VQA;F0`07-C:6D@07)T`$%S:6$O4&%C:69I8R!296=I;VX`
M07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1E;7!T('1O(&1E
M;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@
M82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@
M;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO
M;BUE>&ES=&5N="!S:&%R92X`071T<FEB=71E<P!!=6=U<W0`075S=')A;&EA
M`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N
M(&YO="!F;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E
M(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I
M;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&
M5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@
M+2UE;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B
M-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z($%D9&EN9R!U<V5R
M<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?
M;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T
M:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@
M)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z
M(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T
M;R!U<&1A=&4@=7-E<B`E<P!!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES
M(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN`$%U=&A?;6-A
M;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M
M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"X`
M075T:&5N=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+@!!=71H96YT
M:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H
M96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT
M:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@
M=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@9FEE;&1S.@!!
M>F5R8F%I:F%N`$)/1D@@17AC=7-E<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@
M0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E
M<FYA;64N`$)A:&%M87,`0F%H<F%I;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"
M86YG;&%D97-H`$)A<F)A9&]S`$)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y("(E
M<R(@;F]T(&9O=6YD+@!"87-E;&EN90!"96QA<G5S`$)E;&=I=6T`0F5L:7IE
M`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@
M87!P;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L
M;V-K(%1Y<&4`0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R
M('1H:6-K;F5S<SH`0F]R9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O
M=&@`0F]T<W=A;F$`0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I
M<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"
M=6QG87)I80!"=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--
M4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE
M<RXN+@!#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+@!#86QE;F1A<@!#
M86QM`$-A;6)O9&EA`$-A;65R;V]N`$-A;B=T(&%D;6EN:7-T97(@97AT97)N
M86P@<V5S<VEO;B!H86YD;&5R<RX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E
M<G9E<CH@)7,`0V%N)W0@;W!E;B!F:6QE("(E<R(N`$-A;F%D80!#86YC96P`
M0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;FYO="!C;W!Y(&9I;&4H<RD@+2!S
M;W5R8V4@86YD(&1E<W1I;F%T:6]N(&%R92!T:&4@<V%M92X`0V%N;F]T(&1E
M;&5T92!F:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C
M=&]R>2X`0V%N;F]T(&UO=F4@9FEL92AS*2`M(&1E<W1I;F%T:6]N(&ES('=I
M=&AI;B!S;W5R8V4N`$-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I
M;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`
M0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N`$-A;FYO="!R96]R
M9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D
M;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#86YN;W0@<F5S970@<&%S
M<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N
M`$-A;FYO="!W<FET92!T;R!F:6QE("(E<R(`0V%P92!697)D90!#87!T:6]N
M`$-A<G)I97(`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA;B!)<VQA;F1S
M`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L
M;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H
M25-/+3@X-3DM,30I`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`
M0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T
M86EL<P!#97)T:69I8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE<P!#
M:&%D`$-H86YG90!#:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@=&AE(&YA
M;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D
M(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=I;F<@>6]U<B!P87-S
M=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG
M=7)A=&EO;BX@($-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#:&%R`$-H
M96-?:R!,:6YK+BXN`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H
M1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@07!P
M;&EC871I;VXZ`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE
M`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y
M;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I`$-H<FES=&UA<R!)<VQA;F0`
M0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%R`$-L96%R
M($U33V9F:6-E('1A9W,`0VQE87(@475E<GD`0VQE87(@;W5T('5S97(Z("5S
M`$-L96%R('5S97(`0VQE87(@=7-E<B!D871A`$-L96%R:6YG($QA=&4`0VQI
M8VL@=&\@0V]N=&EN=64`0VQI8VMA=&5L;"!V:6$@2%144`!#;&]S92!7:6YD
M;W<`0VQO=61S`$-L;W5D<R!%87)L>0!#;&]U9'D`0V]C;W,@*$ME96QI;F<I
M($ES;&%N9',`0V]L;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#
M;VQO;6)I80!#;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#
M;VQS.@!#;VQU;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE
M;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M<'5T
M97)S`$-O;F1I=&EO;@!#;VYD:71I;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R
M96YC97,`0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92X`0V]N9FEG=7)E
M("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L(%1H92!$96UO8W)A
M=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C
M=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI
M8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC
M(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10
M('-E<G9E<B!F86EL960N`$-O;G1A8W1S`$-O;G1A8W1S('=E<F4@<W5C8V5S
M<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT96YT('1Y
M<&4@;V8@8V]M<')E<W-E9"!F:6QE.B``0V]N=&5N=',@;V8@(B5S(@!#;VYT
M:6YU90!#;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P>2!F86EL960Z("5S
M`$-O<'D@<V5L96-T:6]N`$-O<W0@240`0V]S=&$@4FEC80!#;W1E(&0G279O
M:7)E`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E.B``0V]U;&0@;F]T
M(%!'4"!S:6=N(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@
M;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD
M(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S
M97)V97(N`$-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@
M8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-O;FYE8W0@=&\@
M<V5R=F5R("(E<R(@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@8W)E871E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T
M83H@`$-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N;W0@
M9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@(B5S(BX`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT
M)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A
M9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB
M=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T
M(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&QO860@<W1R871E
M9WD@(B5S(BX`0V]U;&0@;F]T(&UK9&ER("(E<R(N`$-O=6QD(&YO="!O8G1A
M:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O
M<&5N("(E<R(@9F]R('=R:71I;F<N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L
M9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N
M;W0@;W!E;B!D:7)E8W1O<GD@(B5S(BX`0V]U;&0@;F]T(')E86-H('1H92!,
M1$%0('-E<G9E<BX`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E
M="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O
M<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A
M:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@
M9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO
M="!R971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I
M<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E
M<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I
M;VXN`$-O=6QD(&YO="!R;61I<B`B)7,B+@!#;W5L9"!N;W0@<V%V92`E<R!C
M;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U
M871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@
M)7,`0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E
M<R(N`$-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F
M:6QE("5S+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE
M("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92!O<'1I;VYS('1O
M('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H
M92!C;V1E(&)E;&]W('1O("5S+@!#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0
M('-E<G9E<BX`0V]U;&0@;F]T('5N;&EN:R`B)7,B+@!#;W5L9"!N;W0@=7!D
M871E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S`$-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B`B
M)7,B.B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA
M:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5L9&XG="!G:79E('5S
M97(@(B5S(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B
M)7,B.B`E<P!#;W5N=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#
M<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD
M97)S`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R
M;V%T:6$`0W5B80!#=7)R96YT(#0@4&AA<V5S`$-U<G)E;G0@4V5S<VEO;G,`
M0W5R<F5N="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@57-E<G,`0W5R
M<F5N="!796%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL
M90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U
M=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I
M;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M
M52D`0WIE8V@@4F5P=6)L:6,`1$0`1%-.("AS964@:'1T<#HO+W!E87(N<&AP
M+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN
M<&AP*0!$86EL>0!$871A5')E92!"<F]W<V5R`$1A=&%B87-E($QO;VMU<`!$
M871E`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@
M0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!);F1E
M;G0`1&5F875L=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F
M875L="!3:&5L;`!$969I;FET:6]N<P!$96QE=&4`1&5L971E($-E;&P`1&5L
M971E($=R;W5P`$1E;&5T92!,;V<`1&5L971E(%!E<FUI<W-I;VX`1&5L971E
M(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN
M`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E(&UE
M<W-A9V5S`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(@!$96QE=&4@<&5R
M;6ES<VEO;G,@9F]R("(E<R(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E
M;&5T92!R;W<`1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!S=6(@
M9F]L9&5R<P!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@
M8W5R<F5N="!R;W<`1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="`B)7,B
M+@!$96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5S8W)I8F4@=&AE(%!R;V)L96T`
M1&5S8W)I<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I
M.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A
M=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T
M(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$
M:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH
M;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!D971A:6QE9"!F
M;W)E8V%S=`!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R;6%T
M`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!N;W0@9&5L
M971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O
M97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@
M>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B
M;&EC`$1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"X`1&]W;FQO860`
M1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@
M87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-86EL`$5-
M86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H
M('!R;W9I9&4@=&AI<R!S97)V:6-E+@!%4E(`16-U861O<@!%9&ET`$5D:70@
M0FQO8VL`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S
M:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R
M.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO;G,@
M9F]R("5S`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN
M`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@
M;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M86EL+71O+5--4R!'
M871E=V%Y`$5M;W1I8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N
M`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E
M<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@
M8VQI8VL@8V]N=&5X="!M96YU/P!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%
M;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S
M:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@
M)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SH`16YT97(@=&AE(&EM
M86=E(%523"!H97)E`$5N=&5R('1H92!L971T97)S(&)E;&]W.@!%<75A=&]R
M:6%L($=U:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R(&-R96%T:6YG(&)L;V-K
M.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,`17)R;W(@9&5L
M971I;F<@<WEN8R!L;V<Z("5S`$5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,`
M17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S`$5R<F]R('=I=&@@96UA:6P@
M;65S<V%G92X`17)R;W(@=W)I=&EN9R`B)7,B+@!%<W1O;FEA`$5T:&EO<&EA
M`$5T:&YI8P!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T
M97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G
M:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E
M<SH`17AE8W5T90!%>'!A;F0`17AP96-T960@)RDG`$5X<&5C=&5D(&)A<F4@
M=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`17AP:7)A=&EO;B!$871E`$5X
M<&]N96YT`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D(')E
M=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$
M05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&
M86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E
M<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I
M;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I;&5D('1O(')E=')I979E.B`E<P!&
M86ER`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S
M`$9A=&%L($5R<F]R.@!&87@`1F%X97,`1F5B<G5A<GD`1F5E;',@3&EK90!&
M965L<R!L:6ME.B``1F5W(%-H;W=E<G,`1F5W(%-N;W<@4VAO=V5R<P!&:65L
M9"!M871R:7@`1FEG;&5T($-!4%1#2$$`1FEG;&5T(&9O;G0`1FEJ:0!&:6QE
M`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL
M92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A
M9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R<P!&:6YL86YD
M`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&:7@@<F%T:6\`1FQI<`!&;&]A
M=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@0V]L;W(`1F]O
M9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<P!&;W)E
M8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R
M;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A(&QA
M<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI
M`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@
M='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M<P!&;W)W87)D<P!&<@!&
M<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI=&%N`$9R965Z:6YG($1R
M:7IZ;&4`1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3
M;W5T:&5R;B!497)R:71O<FEE<P!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R
M:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA;64`1V%B;VX`1V%L;&5R>2!T;R!T
M86ME(&EM86=E(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R871E("5S($-O
M;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`1V5O<F=I80!'97)M86YY`$=H
M86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=L;V)A;"!/<'1I;VYS`$=O`$=O
M961E;`!';V]G;&4@36%P<P!';V]G;&4@4V5A<F-H`$=R87ES8V%L90!'<F5E
M8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N861A`$=R;W5P
M($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y
M`$=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60Z(`!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@
M9&5L971E(&=R;W5P("5S`$=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@
M9W)O=7`@)7,`1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E
M<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W1B;V]K`$=U:6YE80!'=6EN
M96$M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S
M97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+@!(5$U,07)E82!C
M;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@
M=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H
M92!L87-T(')O=R!I;B!T86)L92X`2%144"!!=71H96YT:6-A=&EO;B!N;W0@
M9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE861E
M<G,`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE879Y(%0M
M4W1O<FT`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP`$AE;'`@
M=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E
M9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VQY(%-E92`H5F%T
M:6-A;B!#:71Y(%-T871E*0!(;VUE($%D9')E<W,`2&]M92!$:7)E8W1O<GD`
M2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L
M86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G
M92`E<P!(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O
M8FIE8W0@)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O
M=6YD(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R
M96UO=F5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E
M;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O
M8FIE8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S
M(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$
M(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN
M;W=N('-H87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D
M9&EN9P!(;W)I>F]N=&%L.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S
M92!R97!O<G0A*0!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O
M(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`
M2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I
M='D`2'5M:61I='DZ(`!(=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@
M8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I
M;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E
M<P!)4"!!9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D
M<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C:V1O
M=VX@=FEO;&%T:6]N+@!)7VYS97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N
M<R!/;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG
M<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@
M=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@
M86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE
M960@=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R
M96YC>2X`268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T
M:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE
M9"!B>2!Y;W5R(&)R;W=S97(N`$EM86=E(%!R979I97<Z`$EM86=E(%523`!)
M;6%G92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE
M<GDZ`$EM86=E('5P;&]A9`!);6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R
M=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F
M=&5R`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S
M97)N86UE(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R
M(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R
M(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R
M96%S92!);F1E;G0`26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`
M26YF;P!);F9O<FUA=&EO;@!);F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA
M8FQE+@!);FAE<FET960@365M8F5R<P!);G-E<G0@0U]O;'5M;B!!9G1E<@!)
M;G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E
M<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T
M:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE
M(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E
M;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N
M90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!)
M;G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS
M97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@861D<F5S
M<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`
M26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C
M;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A
M9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B
M969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E
M<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I
M;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN
M<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N
M(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L
M:7-T`$EN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L:60@
M6DE0(&1A=&$`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)
M1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO
M;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;&EC96YS
M92!K97DN`$EN=F%L:60@;&]C871I;VX@<')O=FED960N`$EN=F%L:60@;7-G
M7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@
M;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N
M+@!);G9A;&ED('!A<G1N97(@:60N`$EN=F%L:60@<')O9'5C="!C;V1E+@!)
M;G9A;&ED('!R;W1O8V]L+@!);G9A;&ED(')E8VEP:65N=#H@(B5S(@!);G9A
M;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A
M;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$EN=F5R="!S96QE8W1I;VX`
M27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O
M9B!-86X`27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)=&%L:6,`
M271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R
M,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y
M($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG
M:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY80!+97)B97)O<R!S
M97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME<FYE;"!.97=B:65S
M`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@
M5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I`$MO<F5A+"!$96UO8W)A=&EC
M(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O9@!+;W)E
M86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U=`!,86YG=6%G
M90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T($AA;&8`
M3&%S="!087-S=V]R9"!#:&%N9V4`3&%S="!1=6%R=&5R`$QA<W0@57!D871E
M9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T
M(&QO9VEN.B!.979E<@!,871V:6$`3&%W`$QA>6]U=`!,96%V92!E;7!T>2!F
M;W(@;F\@8F]R9&5R`$QE8F%N;VX`3&5F=`!,969T(&AE861E<@!,969T('9A
M;'5E<P!,97-O=&AO`$QE=F5L`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI
M<FEY80!,:65C:'1E;G-T96EN`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,
M:6=H="!286EN($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H
M;W=E<@!,:6=H="!286EN('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT
M(%-N;W<@4VAO=V5R`$QI;65R:6-K`$QI;FL`3&EN:R!54DP`3&EN:R!A8V-E
M<W,@:V5Y`$QI;FL@<&]I;G1S('1O.@!,:6YK('1A<F=E=`!,:6YK('1E>'0`
M3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H
M96X@9&ES<&QA>6EN9P!,:6YK('1I=&QE(&%T=')I8G5T90!,:6YK<P!,:6YU
M>"!#;V]K:64`3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@
M1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!486)L97,`3&ES="U!
M<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T
M`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!S97-S
M:6]N<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<P!,:7-T
M:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI80!,
M;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I
M;VX`3&]G(&EN`$QO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VX`3&]G(&]U
M=`!,;V=I;@!,;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R
M('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY
M+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E
M:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M
M8F5R<P!,=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O
M;G1A:6YE9"!N;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R
M;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%G:6,`36%I
M;`!-86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA
M;&1I=F5S`$UA;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I
M97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A
M<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA
M<%%U97-T(&UA<`!-87!P:6YG<R!S=&]R960N`$UA<F-H`$UA<F=I;@!-87)K
M('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S
M("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`36%R<VAA;&P@27-L86YD<P!-
M87)T:6YI<75E`$UA=&-H:6YG(&9I96QD<P!-875R:71A;FEA`$UA=7)I=&EU
M<P!-87@@86QL;W=E9"!C<F5D:70N`$UA>"!M97-S86=E('!A<G1S(&5X8V5E
M9&5D+@!-87@@=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V
M(&AO=7)S.B``36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<P!-87AI
M;75M(&QE;F=T:`!-87D`36%Y;W1T90!-961I8VEN90!-96UB97)S`$UE;G4@
M;6]D93H`365R9V4@8V5L;',`365S<V%G90!-97-S86=E(%9E<FEF:65D(%-U
M8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD
M(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E>'!I<F5D+@!-97-S86=E('1Y
M<&4`365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-
M971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L
M;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971A<D1"(&ES(&YO="!C
M;VYN96-T960N`$UE=&AO9`!-971H;V0@(B5S(B!I<R!N;W0@9&5F:6YE9`!-
M971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S`$UE=')I8P!-
M97AI8V\`36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-:61D;&4`
M36EM92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L
M87-T(#8@:&]U<G,Z(`!-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE
M="!E>'!I<F5D`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI<W-I;F<@4$5!4B!P
M86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9
M;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E
M('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@;65S<V%G92!)1"X`36ES<VEN
M9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"X`36ES<VEN9R!S97-S:6]N
M($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T90!-;V1I9FEE9"!$871E`$UO
M9&EF>2!54DP`36]D=6QU<P!-;VQD;W9A+"!297!U8FQI8R!O9@!-;VYA8V\`
M36]N9V]L:6$`36]N=&@@86YD('EE87(`36]N=&AL>0!-;VYT<V5R<F%T`$UO
M;VX@4&AA<V5S`$UO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T
M:&4@97AP96-T960@)60N`$UO<F]C8V\`36]S=&QY($-L96%R`$UO<W1L>2!#
M;&]U9'D`36]S=&QY($-L;W5D>2!A;F0@5VEN9'D`36]S=&QY(%-U;FYY`$UO
M=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W
M;@!-;W9E('5P`$UO>F%M8FEQ=64`375L=&DM;&5V96P@9')O<"!D;W=N(&QI
M<W1S`$UU;'1I;6%P(%5+(&UA<`!-=6QT:7!L92!S96QE8W1I;VX`37D@06-C
M;W5N=`!->2!!8V-O=6YT($EN9F]R;6%T:6]N`$UY(%!O<G1A;`!->2!0;W)T
M86P@3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@3D]4($%G<F5E`$YA;64`3F%M
M:6)I80!.875R=0!.97!A;`!.971H97)L86YD<P!.971H97)L86YD<R!!;G1I
M;&QE<P!.971S8V%P92!"87-E(%523`!.971S8V%P92!#02!2979O8V%T:6]N
M(%523`!.971S8V%P92!#02!P;VQI8WD@55),`$YE='-C87!E(%)E;F5W86P@
M55),`$YE='-C87!E(%)E=F]C871I;VX@55),`$YE='-C87!E(%-33"!S97)V
M97(@;F%M90!.971S8V%P92!C97)T:69I8V%T92!C;VUM96YT`$YE='-C87!E
M(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.979E<@!.97<@0V%L961O;FEA
M`$YE=R!#871E9V]R>0!.97<@36]O;@!.97<@57-E<FYA;64@*&]P=&EO;F%L
M*0!.97<@6F5A;&%N9`!.97<@<&%S<W=O<F0`3F5W('!A<W-W;W)D('=I;&P@
M97AP:7)E(&]N("5X+@!.97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+@!.97<@
M=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@-"!0
M:&%S97,`3F5X="!O<'1I;VYS`$YE>'0^`$YI8V%R86=U80!.:6=E<@!.:6=E
M<FEA`$YI9VAT`$YI=64`3F\`3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@
M9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@879A:6QA8FQE('-T
M<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RX`3F\@8F%T8V@@=&5M<&QA
M=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N
M`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC
M871I;VXN`$YO(&-H86YG92X`3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O
M('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N
M`$YO(&-R961I="!L969T+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@
M9FEL92!U<&QO861E9`!.;R!I8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@
M<V5T+@!.;R!L;V-A=&EO;B!P<F]V:61E9"X`3F\@;65S<V%G92!S=7!P;&EE
M9"X`3F\@;F%M92!S<&5C:69I960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO
M(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M2%144"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($E-05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H
M92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y
M(&ES(&YE8V5S<V%R>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P
M96YD:6YG('-I9VYU<',N`$YO('%U;W1A('-E="X`3F\@<G5L97,`3F\@<V5P
M87)A=&]R('-P96-I9FEE9"X`3F\@<VED97,`3F\@<W5C:"!F:6QE`$YO('1E
M;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E
M<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N`$YO('9A;&ED(%A-3"!D871A
M(')E='5R;F5D`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I
M;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`
M3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N
M97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N90!.;VYE("AU<V4@:6UP;&EC:70I
M`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO<F9O;&L@27-L86YD`$YO<G1H97)N
M($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S`$YO<G=A>0!.
M;W0@069T97(`3F]T($)E9F]R90!.;W0@82!D:7)E8W1O<GD`3F]T(&9O=6YD
M+@!.;W0@:6UP;&5M96YT960N`$YO="!S970`3F]T('-U<'!O<G1E9"X`3F]T
M97,`3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO=F5M8F5R`$YU;6)E
M<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB
M97(@;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG
M(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/8FIE8W0`3V)J96-T($-R96%T
M;W(`3V-T86P`3V-T;V)E<@!/9F9E;G-E(&9I;'1E<@!/9F9I8V4`3VQD(&%N
M9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+@!/;&0@<&%S<W=O
M<F0`3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+@!/;6%N`$]N8VQI8VL@
M979E;G0`3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R
M<RX`3VYL>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D
M<F5S<R!A;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI
M<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S
M:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,
M(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O
M34E-12!P87)T+@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P
M97)A=&EN9R!3>7-T96T`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D
M($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI
M>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T
M96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R
M(%!E<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA
M8FQE+@!014%2.CI-86EL(&)A8VME;F0`4$=0($1I9VET86P@4VEG;F%T=7)E
M`%!'4"!%;F-R>7!T960@1&%T80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D
M+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!(4"!3:&5L;`!032!,:6=H="!2
M86EN`%!-(%)A:6X`4$T@4VAO=V5R<P!032!3;F]W`%!-(%-N;W<@4VAO=V5R
M<P!032!3=6X`4$T@5"U3=&]R;7,`4$]325@@97AT96YS:6]N(&ES(&UI<W-I
M;F<`4%](4"!3:&5L;`!0861D:6YG`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN
M:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN
M96$`4&%R86=U87D`4&%R=&QY($-L;W5D>0!087-S=V]R9`!087-S=V]R9"!C
M:&%N9V5D('-U8V-E<W-F=6QL>2X`4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W
M;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN`%!A<W-W
M;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A
M<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R
M9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R
M;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N("(E
M<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I;VX@1&5N:65D`%!E<FUI<W-I;VYS
M`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN9F]R;6%T
M:6]N`%!E<G4`4&5T<P!0:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`4&ET8V%I
M<FX`4&EX96QS`%!L871I='5D97,`4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C
M96QL`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H
M:7,@96QE;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U
M;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@
M82!Y96%R+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G
M;W)Y.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@
M96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@
M:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+@!0;&5A
M<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P
M<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!R96%D
M('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@
M=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!L96%S92!T>7!E('1H92!N97<@
M8V%T96=O<GD@;F%M93H`4&]L86YD`%!O;&ET:6-S`%!O;&QS`%!O<G1U9V%L
M`%!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI
M<R!T86)L90!0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@
M24U!4"D`4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E
M8VEP:71A=&EO;CQB<B`O/F-H86YC90!0<F5F<U]L9&%P.B!297%U:7)E9"!,
M1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I
M<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`4')E
M<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I
M97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V:6]U<R!O<'1I;VYS
M`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$
M97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U
M8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R!+97D@26YF;P!0=6)L:6,O4')I
M=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R
M=&\@4FEC;P!0=7)G92!M97-S86=E<P!1871A<@!1=65R>0!1=6]T80!24T$@
M4'5B;&EC($ME>2`H)60@8FET*0!2861I;R!S96QE8W1I;VX`4F%I;@!286EN
M($5A<FQY`%)A:6X@3&%T90!286EN(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A
M:6X@=&\@4VYO=P!286YD;VT@1F]R='5N90!2871I;P!296%D`%)E860@;65S
M<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T
M(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@
M)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E9&]E<R!Y
M;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@`4F5F<F5S:"!$>6YA;6EC($UE;G4@
M16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T:6]N
M<VAI<"!"<F]W<V5R`%)E;&]A9`!296UA<FMS`%)E;6]T92!397)V97)S`%)E
M;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO
M=F4`4F5M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I
M;F<`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E
M<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H
M:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!296UO=F4@
M=7-E<CH@)7,`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N
M960@97)R;W)C;V1E.B``4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E
M(&9O=6YD+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@)7,@8V]N
M9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(%9&
M4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@
M:6X@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@1FEE;&0`4F5S970`4F5S970@
M4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R9`!297-T;W)E($QA<W0@475E
M<GD`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2971Y<&4@;F5W('!A<W-W
M;W)D`%)E=6YI;VX`4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D
M:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R`%)I9VAT
M('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA`%)O=&%T
M92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P97)T:65S
M`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E
M87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`
M4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T
M960@365S<V%G90!305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B
M;&4N`%--4R!-97-S86=I;F<`4U%,(%-H96QL`%-13"!S=&%T96UE;G0@9F]R
M('9A;'5E(&QO;VMU<',`4U-(`%-50T-%4U,`4U]13"!3:&5L;`!380!386EN
M="!(96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A
M:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE
M($=R96YA9&EN97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I
M;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3
M875D:2!!<F%B:6$`4V%V90!3879E("(E<R(`4V%V92`E<P!3879E($]P=&EO
M;G,`4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I
M<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E
M9"`E<R!C;VYF:6=U<F%T:6]N+@!3879E9"!S971U<"!U<&=R861E('-C<FEP
M="!T;SH@(B5S(BX`4V-A='1E<F5D(%0M4W1O<FUS`%-C:65N8V4`4V5A<F-H
M`%-E87)C:"!%;F=I;F5S`%-E;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E
M;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T
M(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A;&P`4V5L
M96-T(&%L;"!D871E(&-O;7!O;F5N=',N`%-E;&5C="!A;B!O8FIE8W0`4V5L
M96-T(&YO;F4`4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@
M=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@
M=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI
M;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@:61E
M;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I;64@9&5L
M:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA
M=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE
M8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O
M<G0`4V5N9"!335,`4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`4V5R8FEA
M(&%N9"!-;VYT96YE9W)O`%-E<FEA;"!.=6UB97(`4V5R=F5R(&1A=&$@=W)O
M;F<@;W(@;F]T(&%V86EL86)L92X`4V5S<VEO;B!!9&UI;@!397-S:6]N($E$
M(&5X<&ER960N`%-E<W-I;VYS`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y
M;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@
M:70N`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C
M8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N
M9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T
M87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H
M:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U
M<&=R861E('-C<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O
M<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAO<'!I
M;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE
M9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E
M96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O
M;F9I9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN
M9R!I;C\`4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME
M<@!3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S
M($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R
M=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`
M4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE
M(&EM86=E('!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E<G,`
M4VAO=V5R<R!%87)L>0!3:&]W97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@5FEC
M:6YI='D`4VAR:6YK`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C
M:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U
M<`!3:6=N871U<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ
M90!3:VEP($UA:6YT96YA;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<`4VYO
M=R!3:&]W97(`4VYO=R!3:&]W97)S`%-N;W<@4VAO=V5R<R!%87)L>0!3;F]W
M(%-H;W=E<G,@3&%T90!3;F]W(&1E<'1H.B``4VYO=R!E<75I=F%L96YT(&EN
M('=A=&5R.B``4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]N9W,@)B!0;V5M
M<P!3;W)T(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!
M9G)I8V$`4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G
M:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S`%-O=71H97)N($AE
M;6ES<&AE<F4`4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<P!3<&%C92!B
M971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL`%-P86-E<@!3<&%C
M:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!A:6X`4W!A;0!3<&5C:6%L($-H
M87)A8W1E<B!);G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R
M;W<`4W!O<G1S`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0@
M>65A<@!3=&%T92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O<F%G92!F;W)M870`
M4W1R965T($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I;F<@;&ES=`!3=')I
M<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<P!3='EL92!;0U-370!3=0!3=6)D
M:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%-U8FIE8W0`4W5B;6ET`%-U8FUI
M='1E9"!R97%U97-T('1O(&%D9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C
M86YN;W0@;&]G(&EN('5N=&EL('EO=7(@<F5Q=65S="!H87,@8F5E;B!A<'!R
M;W9E9"X`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D("(E
M<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F
M;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&1E
M;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY(')E;6]V960@(B5S(B!F<F]M('1H
M92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N
M+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"!B
M86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('-A=F5D('1H92!B
M86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C97-S9G5L;'D@=7!D
M871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=61A;@!3=6UM87)Y
M`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E
M=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O
M<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W
M87II;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`4WEN8R!L;V<@9&5L971E9`!3
M>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS`%-Y<FEA;B!!<F%B(%)E<'5B
M;&EC`%0M4W1O<FT`5"U3=&]R;2!A;F0@5VEN9'D`5"U3=&]R;7,`5"U3=&]R
M;7,@16%R;'D`5%-6(&9I;&4`5&%B;&4@4')O<&5R=&EE<P!486)L92!3970`
M5&%B;&4@<')O<&5R=&EE<P!486EW86X`5&%I=V%N+"!0<F]V:6YC92!O9B!#
M:&EN80!486II:VES=&%N`%1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8`
M5&%R9V5T.@!487-K<P!496QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R(&QA<W0@
M:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&5R871U<F4\
M8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<P!496UP;&%T92`B)7,B(&YO
M="!F;W5N9"X`5&5M<&QA=&4@061M:6YI<W1R871I;VX`5&5X=`!497AT($]N
M;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@*%1)4RTV,C`I`%1H86EL
M86YD`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(
M:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"X`5&AE($AO<F1E+TMO;&%B(&EN
M=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T("(E<R(`5&AE($E-
M4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"X`5&AE($UA:6YT96YA
M;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4:&4@3W!T
M:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE(&%D;6EN:7-T
M<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I
M;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+@!4
M:&4@8F]T=&]M('-I9&4@;VYL>0!4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S
M(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I
M;B!T:&4@9&%T86)A<V4N`%1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@
M861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`%1H92!D971A8VAE9"!01U`@
M<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG
M;F5D(&UE<W-A9V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET
M:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD(&EN
M('1H92!D871A8F%S92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@
M<W!E8VEF:65D+@!4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@
M<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N
M=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN
M('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A
M+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S
M86=E+W)F8S@R,B!M97-S86=E+@!4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K
M;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R
M+"!D=64@=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O
M('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92!G87)B86=E(&1I
M<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M
M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES(%=I;F1O=W,@
M.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A
M;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7&Y<;EEO
M=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E('!R97-S($]+(&EF('EO=2!S
M=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+@!4:&4@
M:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@;&5F="UH86YD
M('-I9&4@;VYL>0!4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M
M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RX`5&AE(&UE
M<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@(B5S(B!H87,@
M8F5E;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE
M(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+@!4:&4@;F%M
M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4`5&AE
M(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+@!4:&4@;W!E;G-S
M;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM
M93HZ(&-L87-S+@!4:&4@<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B92!S
M879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M(&%L
M;&]W86)L92!S:7IE`%1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A
M=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE
M('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R
M+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG:'0M:&%N
M9"!S:61E(&]N;'D`5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@
M8VAA<F%C=&5R+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`
M5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P(')E
M<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H92!S<&5C:69I960@
M<F]W("@E9"D@9&]E<R!N;W0@97AI<W0N`%1H92!T96UP;W)A<GD@9FEL92`B
M)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@
M;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN`%1H92!T;W`@86YD
M(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!U<&QO
M861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4
M:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!W96%T
M:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5M97,@9&ER96-T
M;W)Y("(E<R(@;F]T(&9O=6YD+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I
M;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y
M960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T
M:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[('EO
M=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE
M;2!A9&1I;F<@(B5S(B!T;R!T:&4@<WES=&5M.B`E<P!4:&5R92!W87,@82!P
M<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S
M>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG("(E<R(@9G)O
M;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R`B
M)7,B.B`E<P!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L
M;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L96T@
M=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@
M=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E('=A
M<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@
M;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O<B!D
M:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N`%1H97)E('=A<R!A
M;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO
M=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W87,@86X@97)R
M;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC
M=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R
M<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@
M86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@
M9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H
M:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E
M<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R
M8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP
M(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@
M;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E
M<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC
M;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT
M='`Z+R]W:6YP;&,N8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`
M5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G
M:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A
M>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE
M($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@
M<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F;VYE($ET86QY
M("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N
M`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI<R!F
M:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BX`
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`5&AI
M<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI
M<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M
M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@
M=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N`%1H
M:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`5&AI<R!I<R`E
M<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@
M=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C;&EE;G0@=&AA
M="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R
M(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L:65N=',@<&QE87-E('9I<VET("5S
M`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@
M*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M=7-T(&)E
M(&%T(&QE87-T(&]N92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z
M:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D
M96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES
M('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W
M`%1H=6YD97(`5&EC:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`5&EM92!F;W)M
M870`5&EM92!S96QE8W1I;VX`5&EM;W(M3&5S=&4`5&ET;&4`5&ET;&4@*'1O
M;VQT:7`I.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W
M;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE
M(&-L:6-K:6YG+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME
M;&%U`%1O;6]R<F]W`%1O;F=A`%1O;R!M86YY(&EN=F%L:60@;&]G:6YS(&1U
M<FEN9R!T:&4@;&%S="!M:6YU=&5S+@!4;W``5&]P(&9R86UE("A?=&]P*0!4
M<F%N<VQA=&EO;G,`5')I;FED860@86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E
M`%1U`%1U;FES:6$`5'5R:V5Y`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM
M96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU`%1Y<&4@
M>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``55),`%523"!F;W(@>6]U<B!S
M8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R=`!54DPZ`%5G86YD80!5:W)A
M:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O
M(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`
M56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B
M+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S
M+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8VAE8VL@
M9FEL92!S:7IE(&]F("(E<R(N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@
M;V8@(B5S+R5S(BX`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`
M56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN`%5N86)L92!T;R!C;W!Y(%9&
M4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@(B5S(BX`
M56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@8W)E
M871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@(B5S
M(BX`56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92X`56YA8FQE('1O
M(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@
M9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE('1O(&1E;&5T92`B)7,B
M.B`E<RX`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N
M;W0@96UP='D`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R
M<VEV96QY+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L
M92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE
M=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`
M56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!D
M96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN
M92!C=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF
M:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O
M9B`E<RX`56YA8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N
M(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W
M<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P
M96X@8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL
M92`H9FEL97-I>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL
M92`H<VEZ92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D(&9I;&4Z(`!5;F%B
M;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R
M96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X
M:7-T<P!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T
M;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E
M<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92X`56YA8FQE('1O(')U;B`G
M;6MI<V]F<R<N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M
M96YT`%5N86)L92!T;R!T<FEG9V5R(&9R964O8G5S>2!U<&1A=&4@9F]R("5S
M`%5N86)L92!T;R!W<FET92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+@!5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4@9&%T82X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T
M82!W:6QL(&)E(&5X8V5E9&5D+@!5;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N
M9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T960@<F5S<&]N<V4@9G)O
M;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@
M9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N:6-O9&4@*%541BTX*0!5;FET
M960@07)A8B!%;6ER871E<P!5;FET960@2VEN9V1O;0!5;FET960@4W1A=&5S
M`%5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<P!5;FET<P!5
M;FMN;W=N`%5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`56YK
M;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!5;FMN;W=N(&QO
M8V%T:6]N('!R;W9I9&5D+@!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D
M+@!5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N=`!5;FYA;65D`%5N<')I=FEL
M96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O
M9W)A;6%T:6-A;&QY(&9O<B!S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@
M=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@
M<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE
M(&-L:7!B;V%R9"X`56YS970@8V]L;W(`56YS=7!P;W)T960@17AT96YS:6]N
M`%5P9&%T90!5<&1A=&4@)7,`57!D871E('5S97(`57!D871E9"`B)7,B+@!5
M<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO860`57!L;V%D960@86QL(&%P
M<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N`%5P<&5R(&QA
M=&EN(&QE='1E<G,`57!P97(@<F]M86X@;G5M8F5R<P!5<G5G=6%Y`%5S92!#
M=7)R96YT.B`E<P!5<V4@4U-,`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I
M9F9E<F5N="!F;W(@24U34"!S97)V97(N`%5S97(`57-E<B`E<R!I<R!N;W0@
M875T:&]R:7-E9"!F;W(@)7,N`%5S97(@061M:6YI<W1R871I;VX`57-E<B!/
M<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA
M<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N`%5S97(@86-C;W5N="!N
M;W0@9F]U;F0`57-E<FYA;64`57-E<FYA;64@(B5S(B!A;')E861Y(&5X:7-T
M<RX`57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`
M57IB96MI<W1A;@!61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A
M=&EO;@!686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y
M`%9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E(&ES(&]V97(@=&AE
M(&UA>&EM=6T@;&5N9W1H(&]F("5S+@!686QU97,`5F%L=65S('1O('-E;&5C
M="!F<F]M`%9A;G5A='4`5F%R:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO
M;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E
M9"!W:71H+@!697)S:6]N`%9E<G-I;VX@0V]N=')O;`!697)T:6-A;"!A;&EG
M;@!697)T:6-A;"!P861D:6YG`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE="!.
M86T`5FEE=&YA;65S92`H5DE30TE)*0!6:65W("5S`%9I97<@86X@97AT97)N
M86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:7)G:6X@27-L86YD<RP@0G)I=&ES
M:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6:7-I8FEL:71Y`%9I<VEB:6QI='DZ
M(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU44`!705).`%=!4DY)3D<A(2$@4D5-
M3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+@!724X@=FEA($A45%``5V%L
M;&ES(&%N9"!&=71U;F$`5V%R;FEN9P!790!796%T:&5R($9O<F5C87-T`%=E
M871H97(@9&%T82!P<F]V:61E9"!B>0!796%T:&5R+F-O;0!796(`5V5B(%-I
M=&4`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!7
M97-T97)N("A)4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ-2D`5V5S
M=&5R;B!386AA<F$`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA
M>2!A9G1E<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E
M<C\`5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7:&5R96ES($%U<W1R
M86QI82!M87``5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE
M(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@`5VED=&@@:6X@0U-3
M('5N:71S`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME
M<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`
M5VED=&@@=6YI=`!7:61T:#H`5VEK:0!7:6YD`%=I;F0@16%R;'D`5VEN9"!S
M<&5E9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES9&]M`%=I<VAL:7-T`%=O
M<FL`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`5W)O;F<@;G5M8F5R(&]F(&9I
M96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG
M(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O
M;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92X`6"U2968`
M6#4P.78S($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+97D@
M57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y=C,@
M4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!960!9
M65E9`%EA:&]O(2!M87``665A<FQY`%EE;65N`%EE<P!997,L($D@06=R964`
M66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O
M('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%L;&]W960@
M=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!A<F4@;F]T(&%U
M=&AE;G1I8V%T960N`%EO=2!C86YN;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E
M<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&1I9"!N;W0@96YT97(@82!V86QI
M9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R
M;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE
M;&1S(&EN("5S+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E
M('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N
M;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L
M(&1I86QI;F<@<')E9FEX+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A
M;'5E+@!9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O
M('5S92!3:6=N=7!S+@!9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N
M9"X`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C
M86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H
M92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!S96QE
M8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@
M82!U<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U
M<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N
M86UE('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@
M=7!D871E+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O
M<FTN`%EO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U(&YE
M960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9;W5R("5S
M('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U
M<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O
M<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN
M8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E
M8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@
M3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P
M<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O('5S92!(;W)D92!T
M;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I
M9F9E<F5N="!A=71H96YT:6-A=&EO;B!B86-K96YD+@!9;W5R(&%U=&AE;G1I
M8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S
M+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O
M=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA
M;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@
M5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I
M;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E
M+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P
M=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"!T;R!P<FEN="X`66]U
M<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&ED96YT:71Y(&AA
M<R!B965N(&-H86YG960N`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F
M=6QL(&YA;64Z`%EO=7(@;&]G:6X@:&%S(&5X<&ER960N`%EO=7(@;F5W('!A
M<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U
M<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+@!9;W5R
M(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S
M(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE
M8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O
M<F0N`%EO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N`%EO=7(@<F5M;W1E('-E
M<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%II<'!Y
M`%M(:61E(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U
M;W1E9"!497AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI
M;F4@)7,@;V8@)7-=`%]!9&UI;FES=')A=&EO;@!?0TQ)`%]$871A5')E90!?
M1&5L971E(%)O=P!?1W)O=7!S`%]);6%G92!0<F]P97)T:65S+BXN`%],;V<@
M:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]097)M:7-S
M:6]N<P!?4F5M;W9E($QI;FLN+BX`7U-E='5P`%]486)L92!0<F]P97)T:65S
M+BXN`%]5<V5R<P!A9&1R97-S(&)O;VL`861D<F5S<V5E('5N:VYO=VX`8V%L
M96YD87(`8V%L;0!C86YN;W0@8W)E871E(&]U='!U="!F:6QE`&-A;FYO="!O
M<&5N(&EN<'5T`&-L:6-K(&AE<F4`8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R
M`&-O;F9I9W5R871I;VX@97)R;W(`8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES
M<VEN9P!D871A(&9O<FUA="!E<G)O<@!E9&ET`&5N=')Y(&YO="!F;W5N9`!F
M86QL:6YG`&9I;&4`9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!G=7-T:6YG
M`&@Z`&AH`&AO<W0@;F%M92!U;FMN;W=N`&EM;65D:6%T90!I;FQI;F4`:6YP
M=70O;W5T<'5T(&5R<F]R`&EN=&5R;F%L('-O9G1W87)E(&5R<F]R`&QI;F5S
M70!M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RX`;6T`
M;F%M90!N;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E
M<&%D`'!E<F-E;G0`<&5R;6ES<VEO;B!D96YI960`<&EX96QS`')E;6]T92!E
M<G)O<B!I;B!P<F]T;V-O;`!R:7-I;F<`<V5R=FEC92!U;F%V86EL86)L90!S
M:&]W(&1I9F9E<F5N8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S<P!S=&5A9'D`
M<WES=&5M(&5R<F]R`'1A<VL@;&ES=`!T96UP;W)A<GD@9F%I;'5R90!T>7!E
M('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N:69I960`=6YN86UE
M9`!U<V5R('-E;&5C=`!V0V%R9`!W.@!W96%T:&5R+F-O;0!0<F]J96-T+4ED
M+59E<G-I;VXZ($AO<F1E(#,N,2UC=G,*4F5P;W)T+4US9VED+4)U9W,M5&\Z
M(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#8M
M,#<M,S$@,3@Z,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`V+3`X+3`Y
M(#$V.C0U*S`R,#`*3&%S="U4<F%N<VQA=&]R.B!*86X@4V-H;F5I9&5R(#QJ
M86Y`:&]R9&4N;W)G/@I,86YG=6%G92U496%M.B!'97)M86X@/&1E=D!L:7-T
M<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@
M=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ"D-O;G1E;G0M5')A;G-F
M97(M16YC;V1I;F<Z(#@M8FET"@`@*'9O<B`E<R!486=E;BD`("A:=6=R:69F
M<W1A<W1E("5S*0`@*&EN("5S(%1A9V5N*0`@*&AE=71E*0`@*&UO<F=E;BD`
M("AG97-T97)N*0`@;6ET(``B)7,B(&ES="!K96EN(%9E<GIE:6-H;FES+@`B
M)7,B(&ES="!K96EN92!G_&QT:6=E($%U<W=A:&PN`"(E<R(@:7-T(&EN(&1E
M<B!(;W)D92!296=I<W1R>2!N:6-H="!K;VYF:6=U<FEE<G0N`$1E<B!"875M
M+5)E;F1E<F5R(&;\<B`B)7,B('=U<F1E(&YI8VAT(&=E9G5N9&5N+@`B)7,B
M('=U<F1E('IU;2!'<G5P<&5N<WES=&5M(&AI;GIU9V5F_&=T+@`B)7,B('=U
M<F1E('IU;2!296-H=&5S>7-T96T@:&EN>G5G96;\9W0N`"(E<R(@=W5R9&4@
M;FEC:'0@97)S=&5L;'0Z("5S+@`E+C)F34(@*"4S)"XR9B4E*2!V;VX@)3(D
M+C)F34(@97)L875B=&5N('9E<F)R875C:'0`)60@)7,@=6YD("5S`$EN("5D
M(%1A9V5N('=I<F0@26AR(%!A<W-W;W)T('5N9_QL=&EG+@`E9"U486=E+59O
M<FAE<G-A9V4`)7,@+2!(:6YW96ES`"5S($9I;F=E<F%B9')U8VL`)7,@2T(`
M)7,@5V%R='5N9W-A<F)E:71E;B`M($)E<W3D=&EG=6YG`"5S+4MO;F9I9W5R
M871I;VX`)7,@4F5G:7-T<FEE<G5N9P`E<R!.=71Z=6YG<V)E9&EN9W5N9V5N
M`"5S(&5X:7-T:65R="!B97)E:71S+@`E<R!M:70@)7,@)7,`)7,@=VER9"!D
M:64@5V%R='5N9W-A<F)E:71E;B!D=7)C:&;\:')E;BP@9&EE('5N=&5N(&UA
M<FMI97)T('-I;F0N($UA<FMI97)E;B!3:64@86QL92!!=69G86)E;BP@9&EE
M(&IE='IT(&1U<F-H9V5F_&AR="!W97)D96X@<V]L;&5N+@`E<R!I<W0@;F]T
M=V5N9&EG`"5S($UI;G5T96X`)7,@;FEC:'0@9V5F=6YD96XN`"5S(&)I<R`E
M<R!V;VX@)7,`)7-S($%D<F5S<V)U8V@`)7-S($MA;&5N9&5R`"5S<R!.;W1I
M>F)L;V-K`"5S<R!!=69G86)E;FQI<W1E`"5S.B`E<P`E<SH@1&EE<V4@3F%C
M:')I8VAT('-T86UM="!U;G1E<B!5;7-TY&YD96X@;FEC:'0@=F]N(&1E;2!A
M;F=E9V5B96YE;B!!8G-E;F1E<BX@1F]L9V5N(%-I92!K96EN96X@3&EN:W,@
M:6X@9&EE<V5R($YA8VAR:6-H="!U;F0@:/QT96X@4VEE('-I8V@@9&%V;W(L
M(&1E;2!!8G-E;F1E<B!P97)S]FYL:6-H92!$871E;B!P<F5I<WIU9V5B96XN
M`"P@8O9I9R``+"!B:6<@)7,@)7,`+"!S8VAW86YK96YD('9O;B`E<R!B:7,@
M)7,`+2T@075S=^1H;&5N("TM`#$R+5-T=6YD96XM1F]R;6%T`#(T+5-T=6YD
M96XM1F]R;6%T`#(T(%-T=6YD96X`/%IU<OQC:P!&<B!D:65S96X@0FQO8VL@
M=VER9"!E:6YE($1A=&5N8F%N:R!B96YT:6=T+@!%:6X@<V-H=V5R97(@1F5H
M;&5R(&ES="!A=69G971R971E;CH`16EN(/9F9F5N=&QI8VAE<B!01U`M4V-H
M;/QS<V5L('=I<F0@9OQR(&1I92!697)S8VAL_'-S96QU;F<@96EN97(@3F%C
M:')I8VAT(&)E;O9T:6=T+@!%:6X@]F9F96YT;&EC:&5R(%!'4"U38VAL_'-S
M96P@=VER9"!F_'(@9&EE(-QB97)P<OQF=6YG(&5I;F5R('5N=&5R>F5I8VAN
M971E;B!.86-H<FEC:'0@8F5N]G1I9W0N`$5I;B#V9F9E;G1L:6-H97(@=6YD
M(&5I;B!P<FEV871E<B!01U`M4V-H;/QS<V5L('-O=VEE(&5I;B!087-S=V]R
M="!W:7)D(&;\<B!D:64@16YT<V-H;/QS<V5L=6YG(&5I;F5R($YA8VAR:6-H
M="!B96[V=&EG="X`16EN(/9F9F5N=&QI8VAE<B!U;F0@96EN('!R:79A=&5R
M(%!'4"U38VAL_'-S96P@<V]W:64@96EN(%!A<W-W;W)T('=I<F0@9OQR(&1I
M92!5;G1E<GIE:6-H;G5N9R!E:6YE<B!.86-H<FEC:'0@8F5N]G1I9W0N`$5I
M;B#V9F9E;G1L:6-H97(@=6YD(&5I;B!P<FEV871E<B!3+TU)344M4V-H;/QS
M<V5L('-O=VEE(&5I;B!087-S=V]R="!W:7)D(&;\<B!D:64@16YT<V-H;/QS
M<V5L=6YG(&5I;F5R($YA8VAR:6-H="!B96[V=&EG="X`16EN(/9F9F5N=&QI
M8VAE<B!U;F0@96EN('!R:79A=&5R(%,O34E-12U38VAL_'-S96P@<V]W:64@
M96EN(%!A<W-W;W)T('=I<F0@9OQR(&1I92!5;G1E<GIE:6-H;G5N9R!E:6YE
M<B!.86-H<FEC:'0@8F5N]G1I9W0N`$5I;B#V9F9E;G1L:6-H97(@4R]-24U%
M+5-C:&S\<W-E;"!W:7)D(&;\<B!D:64@5F5R<V-H;/QS<V5L=6YG(&5I;F5R
M($YA8VAR:6-H="!B96[V=&EG="X`5F]R;6ET=&%G<R!7;VQK96X`5F]R;6ET
M=&%G<R!L96EC:'1E<B!296=E;@!6;W)M:71T86=S(&QE:6-H=&5R(%-C:&YE
M969A;&P`5F]R;6ET=&%G<R!296=E;@!6;W)M:71T86=S(%-C:&%U97(`5F]R
M;6ET=&%G<R!38VAN965S8VAA=65R`$%-+U!-`$%022!)1`#<8F5R(&1I97-E
M;B!%9&ET;W(`26YF;RXN+@!!8G-O;'5T(%5N=&5N`$%B<V]L=70@36ET=&4`
M6G5G<FEF9B!V97)W96EG97)T(&)E:6T@06YL96=E;B!D97,@5D93+59E<GIE
M:6-H;FES<V5S+@!:=6=R:69F('9E<G=E:6=E<G0@8F5I;2!!;FQE9V5N(&1E
M<B!61E,M1&%T96DN`$MO;G1O:6YF;W)M871I;VYE;@!+;VYT;W!A<W-W;W)T
M`$MO;G1O(&5I;F=E9G)O<F5N+@!"=6-H:&%L='5N9P!(:6YZ=6;\9V5N`$YE
M=64@56YT97)G<G5P<&4@:&EN>G5F_&=E;@!.975E(%5N=&5R<F5C:'1E(&AI
M;GIU9OQG96X`2&EE<B!H:6YZ=6;\9V5N.@!-:71G;&EE9&5R(&AI;GIU9OQG
M96X`3F5U92!'<G5P<&4@:&EN>G5F_&=E;@!.975E(%)E8VAT92!H:6YZ=6;\
M9V5N`%5N=&5R9W)U<'!E('IU("(E<R(@:&EN>G5F_&=E;@!5;G1E<G)E8VAT
M92!Z=2`B)7,B(&AI;GIU9OQG96X`1OQG96X@4VEE(&5I;F5N(&YE=65N($)E
M;G5T>F5R(&AI;GIU.@!3<&%L=&4@:&EN>G5F_&=E;@!086%R(&AI;GIU9OQG
M96X`1&%S("5S+4UE;OP@>G5R($UO>FEL;&$@4VED96)A<B!H:6YZ=6;\9V5N
M`%IU;2!!9')E<W-B=6-H(&AI;GIU9OQG96XZ`%IU(&UE:6YE;2!!9')E<W-B
M=6-H(&AI;GIU9OQG96X`0F5N=71Z97(@:&EN>G5F_&=E;@`B)7,B('=U<F1E
M('IU;2!3>7-T96T@:&EN>G5G96;\9W0L(&%B97(@9&EE('IU<^1T>FQI8VAE
M;B!296=I<W1R:65R=6YG<VEN9F]R;6%T:6]N96X@:V]N;G1E;B!N:6-H="!G
M97-P96EC:&5R="!W97)D96XZ("5S+@`B)7,B('=U<F1E('IU;2!3>7-T96T@
M:&EN>G5G96;\9W0N(%-I92!K]FYN96X@<VEC:"!J971Z="!A;FUE;&1E;BX`
M1&%S($AI;GIU9OQG96X@=F]N($)E;G5T>F5R;B!I<W0@;FEC:'0@;?9G;&EC
M:"X`061R97-S90!!9')E<W-B=6-H`%9E<G=A;'1E;B`M(%)E8VAT92!F_'(@
M86YD97)E($)E;G5T>F5R(&9E<W1L96=E;@!!9&UI;FES=')A=&EO;@!797)B
M=6YG`$%F9VAA;FES=&%N`$%L8F%N:65N`$%L9V5R:65N`%-P:71Z;F%M90!!
M=7-R:6-H='5N9P!!=7-R:6-H='5N9SH`06QL90!!;F=E;65L9&5T92!"96YU
M='IE<@!!;&QE($=R=7!P96X`06QL92!296-H=&4`06QL92!V:65R(%-E:71E
M;@!-96AR97)E($%D<F5S<V5N(&5R;&%U8F5N`$9O<FUA="!V;VX@;G5M;65R
M:65R=&5N($QI<W1E;B#D;F1E<FX_`$5X:7-T:65R="!B97)E:71S`$%L=&5R
M;F%T:79E($E-4U`M06YM96QD=6YG`$%L=&5R;F%T:79E<R!)35-0+5!A<W-W
M;W)T`$%L=&5R;F%T:79E<B!)35-0+4)E;G5T>F5R;F%M90!!;'1E<FYA=&EV
M92!%+4UA:6PM061R97-S90!!;'1E<FYA=&EV92!6;W)L86=E;@!!;'1E<FYA
M=&EV97(@5&5X=#H`06UE<FEK86YI<V-H+5-A;6]A`$5S('=U<F1E(&5I;B!U
M;F?\;'1I9V5R(%=E<G0@86YG96=E8F5N+@!%:6X@=6YB96MA;FYT97(@1F5H
M;&5R(&ES="!A=69G971R971E;BX`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`
M06YO;GEM97(@4')O>'D`06YT=V]R=`!!;G1A<FMT:7,`06YT:6=U82!U;F0@
M0F%R8G5D80!!;G=E;F1U;F<`06YW96YD=6YG<VQI<W1E`$%N=V5N9'5N9R!I
M<W0@8F5R96ET+@!!=68@56YT97)R96-H=&4@86YW96YD96X`0F5S=.1T:6=E
M;@!5;F=E9N1H<F4@1W+VWV4`07!R:6P`07)A8FES8V@@*%=I;F1O=W,M,3(U
M-BD`07)C:&EV9W+VWV4`07)C:&EV;F%M90!3:6YD(%-I92!S:6-H97(L(&1A
M<W,@4VEE(&1I92!296=I<W1R:65R=6YG<V%N9G)A9V4@=F]N("5S(&SV<V-H
M96X@;?9C:'1E;C\`4VEN9"!3:64@<VEC:&5R+"!D87-S(%-I92`B)7,B('5N
M9"!A;&QE(%5N=&5R9W)U<'!E;B!L]G-C:&5N(&WV8VAT96X_`$%R9V5N=&EN
M:65N`$%R;65N:65N`$%R;65N:7-C:"`H05)-4T-)22TX*0!+=6YS=`!!<G5B
M80!!<V-E;G-I;VXM26YS96QN`$%30TE)+4MU;G-T`$%S:65N+U!A>FEF:7-C
M:&4@4F5G:6]N`$%N<W1E:&5N9&4@5V%R='5N9W-A<F)E:71E;B!B97-TY'1I
M9V5N(&QA<W-E;C\`6G5O<F1N=6YG<V9E;&1E<@!%<R!W=7)D92!V97)S=6-H
M="P@96EN92!N:6-H="!E>&ES=&EE<F5N9&4@1W)U<'!E('IU(&SV<V-H96XN
M`$5S('=U<F1E('9E<G-U8VAT+"!E:6X@;FEC:'0@97AI<W1I97)E;F1E<R!2
M96-H="!Z=2!L]G-C:&5N+@!%<R!W=7)D92!V97)S=6-H="P@96EN(&YI8VAT
M(&5X:7-T:65R96YD97,@4F5C:'0@>G4@8F5A<F)E:71E;BX`17,@=W5R9&4@
M=F5R<W5C:'0L(&5I;B!N:6-H="!E>&ES=&EE<F5N9&5S(%)E8VAT('IU(&)E
M87)B96ET96XN`$%T=')I8G5T90!!=6=U<W0`075S=')A;&EE;@#6<W1E<G)E
M:6-H`$%U=&A?8WER<W%L.B!$:64@8F5N]G1I9W1E($E-05`M17)W96ET97)U
M;F<@=W5R9&4@;FEC:'0@9V5F=6YD96XN`$%U=&A?8WER=7,Z($1A<R!"86-K
M96YD(&AA="!N:6-H="!D:64@8F5N]G1I9W1E;B!&Y&AI9VME:71E;BX`075T
M:%]C>7)U<SH@1&EE(&)E;O9T:6=T92!)34%0+45R=V5I=&5R=6YG('=U<F1E
M(&YI8VAT(&=E9G5N9&5N+@!!=71H7V9T<#H@1&EE(&)E;O9T:6=T92!&5%`M
M17)W96ET97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD96XN($MO;7!I;&EE<F5N
M(%-I92!02%`@;6ET(&1E;2`M+65N86)L92UF='`@4&%R86UE=&5R+@!!=71H
M7VEM87`Z($1I92!B96[V=&EG=&4@24U!4"U%<G=E:71E<G5N9R!W=7)D92!N
M:6-H="!G969U;F1E;BX`075T:%]K<F(U.B!$:64@8F5N]G1I9W1E($ME<F)E
M<F]S+45R=V5I=&5R=6YG('=U<F1E(&YI8VAT(&=E9G5N9&5N+@!!=71H7VQD
M87`Z($1A<R!(:6YZ=6;\9V5N('9O;B!"96YU='IE<FX@=VER9"!F_'(@06-T
M:79E($1I<F5C=&]R>2!N:6-H="!U;G1E<G-T_'1Z=`!!=71H7VQD87`Z($1A
M<R!,]G-C:&5N('9O;B!"96YU='IE<FX@=VER9"!F_'(@06-T:79E($1I<F5C
M=&]R>2!N:6-H="!U;G1E<G-T_'1Z=`!!=71H7VQD87`Z($1I92!B96[V=&EG
M=&4@3$1!4"U%<G=E:71E<G5N9R!W=7)D92!N:6-H="!G969U;F1E;BX`075T
M:%]L9&%P.B!$97(@0F5N=71Z97(@)7,@:V]N;G1E(&YI8VAT(&AI;GIU9V5F
M_&=T('=E<F1E;BX@365L9'5N9R!D97,@4V5R=F5R<SH@`$%U=&A?;&1A<#H@
M0F5N=71Z97(@)7,@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;@!!=71H
M7VQD87`Z($)E;G5T>F5R("5S(&MO;FYT92!N:6-H="!A:W1U86QI<VEE<G0@
M=V5R9&5N`$%U=&A?;&1A<#H@1&%S($%K='5A;&ES:65R96X@=F]N($)E;G5T
M>F5R;B!W:7)D(&;\<B!!8W1I=F4@1&ER96-T;W)Y(&YI8VAT('5N=&5R<W3\
M='IT+@!!=71H7VUC86PZ($1I92!B96[V=&EG=&4@34-!3"U%<G=E:71E<G5N
M9R!W=7)D92!N:6-H="!G969U;F1E;BX`075T:%]S;6)A=71H.B!$:64@8F5N
M]G1I9W1E(%-A;6)A+45R=V5I=&5R=6YG('=U<F1E(&YI8VAT(&=E9G5N9&5N
M+@!!;FUE;&1U;F<@8F5I;2!)34%0+5-E<G9E<B!F96AL9V5S8VAL86=E;BX`
M075T:&5N=&EF:7II97)U;F<@9F5H;&=E<V-H;&%G96X`06YM96QD=6YG(&9E
M:&QG97-C:&QA9V5N+B`E<P!$:64@075T:&5N=&EF:7II97)U;F<@=W5R9&4@
M=F]M(%)!1$E54RU397)V97(@>G5R_&-K9V5W:65S96XN`$%N;65L9'5N9R!B
M96EM($944"U397)V97(@9F5H;&=E<V-H;&%G96XN`$%N;65L9'5N9R!B96EM
M(%--0BU397)V97(@9F5H;&=E<V-H;&%G96XN`%9E<F;\9V)A<F4@1F5L9&5R
M.@!!<V5R8F%I9'-C:&%N`$)/1D@M075S<F5D96X`2&EN=&5R9W)U;F0`2&EN
M=&5R9W)U;F1F87)B90!&86QS8VAE<R!+97)B97)O<RU087-S=V]R="X`1F%L
M<V-H97(@2V5R8F5R;W,M0F5N=71Z97)N86UE+@!"86AA;6%S`$)A:')E:6X`
M0F%L=&ES8V@@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-C:`!"87)B861O<P!"
M87-I<RU":6QD97(M5F5R>F5I8VAN:7,@(B5S(B!N:6-H="!G969U;F1E;BX`
M1W)U;F1L:6YI90!796G?<G5L86YD`$)E;&=I96X`0F5L:7IE`$)E;FEN`$)E
M<FUU9&%S`$)H=71A;@!'96)U<G1S=&%G`$)L;V-K("(E<R(@9&5R($%N=V5N
M9'5N9R`B)7,B(&YI8VAT(&=E9G5N9&5N+@!";&]C:V5I;G-T96QL=6YG96X`
M0FQO8VMT>7``1F5T=`!";VQI=FEE;@!,97-E>F5I8VAE;@!286YD`%)A:&UE
M;F1I8VME.@!2Y&YD97(`0F]S;FEE;BU(97)Z96=O=VEN80!"96ED97,`0F]T
M<W=A;F$`56YT96X`0F]U=F5T:6YS96P`0G)A<VEL:65N`$)R:71I<V-H97,@
M5&5R<FET;W)I=6T@:6T@26YD:7-C:&5N($]Z96%N`$)R=6YE:2!$87)U<W-A
M;&%M`$)U;&=A<FEE;@!5;FYU;6UE<FEE<G1E($QI<W1E`$)U<FMI;F$@1F%S
M;P!"=7)U;F1I`$--4P!#4D,`0U),($1I<W1R:6)U=&EO;G-S=&5L;&4`7UIE
M;&QE;F5I9V5N<V-H869T96XN+BX`1&5R(%IW:7-C:&5N<W!E:6-H97(@:V]N
M;G1E(&YI8VAT(&EN:71I86QI<VEE<G0@=V5R9&5N+@!+86QE;F1E<@!7:6YD
M<W1I;&P`2V%M8F]D<V-H80!+86UE<G5N`$5X=&5R;F4@4V5S<VEO;BU(86YD
M;&5R(&OV;FYE;B!N:6-H="!A9&UI;FES=')I97)T('=E<F1E;BX`5F5R8FEN
M9'5N9R!Z=6T@24U!4"U397)V97(@:V%N;B!N:6-H="!H97)G97-T96QL="!W
M97)D96XZ("5S`$1I92!$871E:2`B)7,B(&MA;FX@;FEC:'0@9V7V9F9N970@
M=V5R9&5N+@!+86YA9&$`06)B<F5C:&5N`%!R;V)L96UB97)I8VAT(&%B8G)E
M8VAE;@!$871E:2AE;BD@:_9N;F5N(&YI8VAT(&MO<&EE<G0@=V5R9&5N("T@
M475E;&PM('5N9"!::65L9&%T96EE;B!S:6YD(&ED96YT:7-C:"X`1&EE($1A
M=&5I("(E<R(@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;BX`2V5I;B!T
M96UP;W+D<F5S(%9E<GIE:6-H;FES(&=E9G5N9&5N+@!$871E:2AE;BD@:_9N
M;F5N(&YI8VAT('9E<G-C:&]B96X@=V5R9&5N("T@6FEE;&1A=&5I(&)E9FEN
M9&5T('-I8V@@:6T@475E;&QO<F1N97(N`$9O<G1S971Z=6YG(&]H;F4@(G1A
M<F=E=$9I;&4B+5!A<F%M971E<B!N:6-H="!M]F=L:6-H+@!$87,@5F5R>F5I
M8VAN:7,@(B5S(B!K;VYN=&4@;FEC:'0@96YT9F5R;G0@=V5R9&5N+@!+;VYN
M=&4@;FEC:'0@96YT9F5R;G0@=V5R9&5N+"`E9"!+:6YD97(@97AI<W1I97)E
M;BX`56US;W)T:65R96X@;FEC:'0@;?9G;&EC:"X@1&EE($%N>F%H;"!D97(@
M16EN='+D9V4L(&1I92!U;7-O<G1I97)T('=E<F1E;B!S;VQL96XL('-T:6UM
M="!N:6-H="!M:70@9&5R($%N>F%H;"!D97(@9V5S<&5I8VAE<G1E;B!%:6YT
M<N1G92#\8F5R96EN+@!087-S=V]R="!K86YN(&YI8VAT(&%U=&]M871I<V-H
M('IU<OQC:V=E<V5T>G0@=V5R9&5N+"!B:71T92!W96YD96X@4VEE('-I8V@@
M86X@26AR96X@061M:6YI<W1R871O<BX`1&EE($YA8VAR:6-H="!K;VYN=&4@
M;FEC:'0@86X@9&EE(&%N9V5G96)E($YU;6UE<B!W96ET97)G96QE:71E="!W
M97)D96XN`$1I92!$871E:2`B)7,B(&MA;FX@;FEC:'0@9V5S<&5I8VAE<G0@
M=V5R9&5N`$MA<"!697)D90#<8F5R<V-H<FEF=`!0<F]V:61E<@!+871E9V]R
M:65N('5N9"!"97-C:')I9G1U;F=E;@!#87EM86XM26YS96QN`$UO8FEL=&5L
M969O;@!:96QL96YE:6=E;G-C:&%F=&5N`$EN;F5N86)S=&%N9#H`6F5L;&5N
M96EG96YS8VAA9G1E;@!:96QL96YA8G-T86YD.@!-;V)I;'1E;&5F;VX`2V5L
M=&ES8V@@*$E33RTX.#4Y+3$T*0!:96YT<FEE<G0`6F5N=')A;&%F<FEK86YI
M<V-H92!297!U8FQI:P!-:71T96QE=7)O<.1I<V-H("A)4T\M.#@U.2TR*0!:
M97)T:69I:V%T9&5T86EL<P!:97)T:69I:V%T8F5S:71Z97(`6F5R=&EF:6MA
M=')I8VAT;&EN:65N`%1S8VAA9`#$;F1E<FX`Q&YD97)N(%-I92!):'(@4&%S
M<W=O<G0`Q&YD97)N(%-I92!D96X@3F%M96X@;V1E<B!D:64@061R97-S92P@
M9&EE(&1I92!%;7!FY&YG97(@26AR97(@12U-86EL+4YA8VAR:6-H=&5N('-E
M:&5N+"!W96YN('-I92!D:65S92!L97-E;B!O9&5R(&1A<F%U9B!A;G=O<G1E
M;BX`1&%S(,1N9&5R;B!):')E<R!087-S=V]R=',@=VER9"!V;VX@9&EE<V5M
M(%-Y<W1E;2!Z=7(@6F5I="!N:6-H="!U;G1E<G-T_'1Z="X@0FET=&4@=V5N
M9&5N(%-I92!S:6-H(&%N($EH<F5N($%D;6EN:7-T<F%T;W(N`%IE:6-H96X`
M3&EN:R#\8F5R7W!R_&9E;BXN+@!#:&EL90!#:&EN80!#:&EN97-I<V-H('9E
M<F5I;F9A8VAT("A'0C(S,3(I`$-H:6YE<VES8V@@=')A9&ET:6]N96QL("A"
M:6<U*0!!;G=E;F1U;F<@875S=^1H;&5N.@!7Y&AL96X@4VEE(&5I;B!087-S
M=V]R=`!7Y&AL96X@4VEE(&5I;F5N($)E;G5T>F5R;F%M96X`3&5G96X@4VEE
M(&9E<W0L('=I92!D87,@1&%T=6T@86YG97IE:6=T('=E<F1E;B!S;VQL.@!,
M:7-T96YF;W)M870@875S=^1H;&5N("AF_'(@;G5M;65R:65R=&4@3&ES=&5N
M*0!796EH;F%C:'1S:6YS96P`2VQA<W-E;F1E9FEN:71I;VX@9OQR("5S(&YI
M8VAT(&=E9G5N9&5N+@!(96ET97(`35,M3V9F:6-E+51A9W,@96YT9F5R;F5N
M`$%B9G)A9V4@>G5R_&-K<V5T>F5N`$)E;G5T>F5R9&%T96X@;/9S8VAE;CH@
M)7,`0F5N=71Z97)D871E;B!L]G-C:&5N`$)E;G5T>F5R9&%T96X@;/9S8VAE
M;@!3<.1T97(@075F:VQA<F5N9`!&;W)T9F%H<F5N`$-L:6-K871E;&P@<&5R
M($A45%``1F5N<W1E<B!S8VAL:67?96X`5V]L:V5N`$9R_&@@5V]L:V5N`$)E
M=_9L:W0`2V]K;W-I;G-E;&X`365N_"!E:6YF86AR96X`6G5S86UM96YHY&YG
M96YD92!286AM96X`2V]L=6UB:65N`$9A<F)E`$9A<F)A=7-W86AL`$9A<F)W
M86AL`%-P86QT96XZ`%-P86QT96[\8F5R<V-H<FEF=&5N`$-O;6EC<P!"969E
M:&P`0F5F96AL<WIE:6QE`$MO;6UE;G1A<@!%:6YD975T:6=E<B!.86UE`$MO
M;6]R96X`1FER;6$`0V]M<'5T97(`0F5D:6YG=6YG96X`0F5D:6YG=6YG96X`
M2V]N9FEG=7)A=&EO;G-U;G1E<G-C:&EE9&4`1&EE($MO;F9I9W5R871I;VX@
M;75S<R!A:W1U86QI<VEE<G0@=V5R9&5N+@`E<R!K;VYF:6=U<FEE<F5N`%!A
M<W-W;W)T(&)E<W3D=&EG96X`2V]N9V\`1&5M;VMR871I<V-H92!297!U8FQI
M8R!+;VYG;P!697)B:6YD=6YG(&9E:&QG97-C:&QA9V5N+@!697)B:6YD=6YG
M(&9E:&QG97-C:&QA9V5N.B``5F5R8FEN9'5N9R!Z=6T@]F9F96YT;&EC:&5N
M(%-C:&S\<W-E;'-E<G9E<B!W=7)D92!A8F=E=VEE<V5N+@!697)B:6YD=6YG
M('IU;2#V9F9E;G1L:6-H96X@4V-H;/QS<V5L<V5R=F5R('=U<F1E(&%B9V5W
M:65S96XN($=R=6YD.B`E<R`H)7,I`%9E<F)I;F1U;F<@>G5M($944"U397)V
M97(@9F5H;&=E<V-H;&%G96X`2V]N=&%K=&4`1&EE($MO;G1A:W1E('=U<F1E
M;B!E<F9O;&=R96EC:"!):')E;2!!9')E<W-B=6-H(&AI;GIU9V5F_&=T+@!)
M;FAA;'1S='EP(&1E<B!K;VUP<FEM:65R=&5N($1A=&5I.B``26YH86QT('9O
M;B`B)7,B`%=E:71E<@!#;V]K+4EN<V5L;@!#;V]K:64`2V]P:65R96X`2V]P
M:65R96X@9F5H;&=E<V-H;&%G96XZ("5S`$%U<W=A:&P@:V]P:65R96X`2V]S
M=&5N+4E$`$-O<W1A(%)I8V$`16QF96YB96EN:_QS=&4`1&EE($YA8VAR:6-H
M="!K;VYN=&4@;FEC:'0@;6ET(%!'4"!V97)S8VAL_'-S96QT('=E<F1E;CH@
M`$1I92!.86-H<FEC:'0@:V]N;G1E(&YI8VAT(&UI="!01U`@=6YT97)Z96EC
M:&YE="!W97)D96XZ(`!$:64@3F%C:')I8VAT(&MO;FYT92!N:6-H="!M:70@
M4R]-24U%('9E<G-C:&S\<W-E;'0@=V5R9&5N+@!$:64@3F%C:')I8VAT(&MO
M;FYT92!N:6-H="!M:70@4R]-24U%('5N=&5R>F5I8VAN970@=V5R9&5N+@!+
M;VYT86MT(&MO;FYT92!N:6-H="!G97-P96EC:&5R="!W97)D96XN("5S`%9E
M<F)I;F1U;F<@>G5M($Q$05`M4V5R=F5R(&9E:&QG97-C:&QA9V5N+@!+;VYT
M;W-T86YD(&MO;FYT92!N:6-H="#\8F5R<'+\9G0@=V5R9&5N+B`E<P!697)B
M:6YD=6YG('IU;2!,1$%0+5-E<G9E<B!F96AL9V5S8VAL86=E;BX`1E10+59E
M<F)I;F1U;F<@>G5M(%-E<G9E<B`B)7,B(&MO;FYT92!N:6-H="!H97)G97-T
M96QL="!W97)D96XZ("5S`%9E<G1E:6QE<FQI<W1E(&MO;FYT92!N:6-H="!E
M<G-T96QL="!W97)D96XN("5S`%!'4"U$871E;B!K;VYN=&5N(&YI8VAT(&5N
M='-C:&S\<W-E;'0@=V5R9&5N.B``4R]-24U%+41A=&5N(&MO;FYT96X@;FEC
M:'0@96YT<V-H;/QS<V5L="!W97)D96XN`$MO;G1A:W0@:V]N;G1E(&YI8VAT
M(&=E;/9S8VAT('=E<F1E;BX@)7,`5F5R=&5I;&5R;&ES=&4@:V]N;G1E(&YI
M8VAT(&=E;/9S8VAT('=E<F1E;BX@)7,`1&%S($%K='5A;&ES:65R=6YG<W-K
M<FEP="`B)7,B(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN`$1I92!%
M+4UA:6PM061R97-S92!D97,@16UP9N1N9V5R<R!K;VYN=&4@;FEC:'0@97)M
M:71T96QT('=E<F1E;BX`1&%S($%D<F5S<V)U8V@@:V]N;G1E(&YI8VAT(&MO
M;7!L971T(&=E;&5S96X@=V5R9&5N+@!697)T96EL97)L:7-T92!K;VYN=&4@
M;FEC:'0@875S9V5L97-E;B!W97)D96XN("5S`$QI<W1E(&1E<B!697)T96EL
M97)L:7-T96X@:V]N;G1E(&YI8VAT(&%U<V=E;&5S96X@=V5R9&5N+@!$:64@
M4W1R871E9VEE("(E<R(@:V]N;G1E(&YI8VAT(&=E;&%D96X@=V5R9&5N+@!$
M87,@5F5R>F5I8VAN:7,@(B5S(B!K;VYN=&4@;FEC:'0@86YG96QE9W0@=V5R
M9&5N+@#69F9E;G1L:6-H97(@4V-H;/QS<V5L(&MO;FYT92!N:6-H="!V;VT@
M4V-H;/QS<V5L<V5R=F5R(&=E:&]L="!W97)D96XN`"(E<R(@:V]N;G1E(&YI
M8VAT('IU;2!38VAR96EB96X@9V7V9F9N970@=V5R9&5N+@`E<R!K;VYN=&4@
M;FEC:'0@9V5L97-E;B!W97)D96XN`$1A<R!-86EN=&5N86YC95]487-K($UO
M9'5L("5S(&MO;FYT92!N:6-H="!G9?9F9FYE="!W97)D96X`5F5R>F5I8VAN
M:7,@(B5S(B!K;VYN=&4@;FEC:'0@9V7V9F9N970@=V5R9&5N+@!697)B:6YD
M=6YG('IU;2!,1$%0+5-E<G9E<B!K;VYN=&4@;FEC:'0@:&5R9V5S=&5L;'0@
M=V5R9&5N+@`E<R!K;VYN=&4@;FEC:'0@9V5L97-E;B!W97)D96XN`$1A<R!0
M87-S=V]R="!F_'(@9&5N(&%N9V5G96)E;F5N($)E;G5T>F5R(&MO;FYT92!N
M:6-H="!Z=7+\8VMG97-E='IT('=E<F1E;BP@=V5I;"!E:6YI9V4@06YG86)E
M;B!N:6-H="!R:6-H=&EG('=A<F5N+B!697)S=6-H96X@4VEE(&5S(&5R;F5U
M="!O9&5R('=E;F1E;B!3:64@<VEC:"!A;B!):')E;B!!9&UI;FES=')A=&]R
M+"!W96YN(%-I92!W96ET97)E($AI;&9E(&)E;O9T:6=E;BX`04-,(&MO;FYT
M92!N:6-H="!G96QE<V5N('=E<F1E;@!$87,@061R97-S8G5C:"!K;VYN=&4@
M;FEC:'0@9V5L97-E;B!W97)D96XN("5S`%9E<G1E:6QE<FQI<W1E(&MO;FYT
M92!N:6-H="!A=7-G96QE<V5N('=E<F1E;BX@)7,`5F5R=&5I;&5R;&ES=&5N
M(&MO;FYT92!N:6-H="!A=7-G96QE<V5N('=E<F1E;BX@)7,`1&EE(%-E<G9E
M<F;D:&EG:V5I=&5N(&MO;FYT96X@;FEC:'0@875S9V5L97-E;B!W97)D96X`
M2V]N9FEG=7)A=&EO;B!K;VYN=&4@;FEC:'0@>G5R_&-K9V5S971Z="!W97)D
M96XN`%9E<GIE:6-H;FES("(E<R(@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E
M<F1E;BX`)7,M2V]N9FEG=7)A=&EO;B!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE
M<G0@=V5R9&5N+@!"86-K=7`@9&5R($MO;F9I9W5R871I;VX@:V]N;G1E(&YI
M8VAT(&=E<W!E:6-H97)T('=E<F1E;BX`0F%C:W5P(&1E<B!+;VYF:6=U<F%T
M:6]N(&MO;FYT92!N:6-H="!G97-P96EC:&5R="!W97)D96XZ("5S`$1A<R!!
M:W1U86QI<VEE<G5N9W-S:W)I<'0@:V]N;G1E(&YI8VAT(&YA8V@@(B5S(B!G
M97-P96EC:&5R="!W97)D96XN`$)A8VMU<"!D97(@2V]N9FEG=7)A=&EO;B`E
M<R!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N+@!$:64@2V]N9FEG
M=7)A=&EO;B`E<R!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N+B!3
M:64@:_9N;F5N(&5N='=E9&5R(&5I;F4@9&5R($WV9VQI8VAK96ET96X@=6YT
M97(@)7,@=F5R=V5N9&5N+"!U;2!D96X@0V]D92!Z=2!S<&5I8VAE<FXL(&]D
M97(@9&5N('5N=&5N<W1E:&5N9&5N($-O9&4@;6%N=65L;"!N86-H("5S(&MO
M<&EE<F5N+@!$97(@3$1!4"U397)V97(@:V]N;G1E(&YI8VAT(&1U<F-H<W5C
M:'0@=V5R9&5N+@`B)7,B(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN
M`$1E<B!+;VYT86MT(&MO;FYT92!N:6-H="!G97-P96EC:&5R="!W97)D96XN
M("5S`%9E<G1E:6QE<FQI<W1E(&MO;FYT92!N:6-H="!A:W1U86QI<VEE<G0@
M=V5R9&5N+B`E<P!$:64@2V]N9FEG=7)A=&EO;B!F_'(@(B5S(B!K;VYN=&4@
M;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N.B`E<P!$:64@36]Z:6QL82!3:61E
M8F%R(&MO;FYT92!N:6-H="!G969U;F1E;B!W97)D96XN(%-T96QL96X@4VEE
M('-I8VAE<BP@9&%S<R!D:64@4VED96)A<B!G9?9F9FYE="!I<W0N`$1E;2!"
M96YU='IE<B`B)7,B(&MO;FYT96X@9&EE(&9O;&=E;F1E(%)E8VAT92!F_'(@
M9&5N($]R9&YE<B`B)7,B(&YI8VAT('IU9V5W:65S96X@=V5R9&5N.B`E<P!'
M97KD:&QT97(@5&5X=`!,86YD`$MU<G-E`$5R<W1E;&QE;@!,:6YK(&5R<W1E
M;&QE;@!.975E($ED96YT:73D="!A;FQE9V5N`%5N=&5R;W)D;F5R(&5R<W1E
M;&QE;@!%<G-T96QL97)R96-H=&4`2W)E9&ET:V%R=&5N;G5M;65R`$MR;V%T
M:65N`$MU8F$`06MT=65L;&4@-"!0:&%S96X`06MT=65L;&4@4V5S<VEO;G,`
M06MT=65L;&4@6F5I=`!!:W1U96QL92!54DP@:7-T`$%K='5E;&QE($)E;G5T
M>F5R`$%K='5E;&QE<R!7971T97(`1&5R>F5I=&EG92!"961I;F=U;F=E;CH@
M`$%K='5E;&QE<B!3=&EL`$QE9V5N(%-I92!F97-T+"!W96QC:&4@075F9V%B
M96X@;F%C:"!D97(@06YM96QD=6YG(&)E:2`E<R!E<FQE9&EG="!W97)D96X@
M<V]L;&5N+@!!=7-S8VAN96ED96X`075S=V%H;"!A=7-S8VAN96ED96X`6GEP
M97)N`$MY<FEL;&ES8V@@*$M/23@M4BD`2WER:6QL:7-C:"`H5VEN9&]W<RTQ
M,C4Q*0!+>7)I;&QI<V-H+U5K<F%I;FES8V@@*$M/23@M52D`5'-C:&5C:&ES
M8VAE(%)E<'5B;&EK`%14`$133B`H<VEE:&4@:'1T<#HO+W!E87(N<&AP+FYE
M="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP
M*0!4Y&=L:6-H`$1A=&%4<F5E($)R;W=S97(`1&%T96YB86YK86)F<F%G90!$
M871U;0!%;7!F86YG<V1A='5M`$1A='5M<V%U<W=A:&P`5&%G`%-P86QT92!?
M;/9S8VAE;@!$97IE;6)E<@!:86AL96X`16EN>G5G('9E<G)I;F=E<FX`4W1A
M;F1A<F0`4W1A;F1A<F1F87)B90!3=&%N9&%R9&ED96YT:73D=`!3=&%N9&%R
M9'-H96QL`$1E9FEN:71I;VYE;@!,]G-C:&5N`%IE;&QE(&SV<V-H96X`1W)U
M<'!E(&SV<V-H96X`3&]G(&SV<V-H96X`4F5C:'1E(&SV<V-H96X`3F%C:')I
M8VAT96X@;/9S8VAE;B!U;F0@96YT9F5R;F5N`%IE;&QE(&SV<V-H96X`4W!A
M;'1E(&SV<V-H96X`0F5S=&5H96YD92!A;'1E<FYA=&EV92!6;W)L86=E(&SV
M<V-H96X`3F%C:')I8VAT96X@;/9S8VAE;@!296-H=&4@9OQR("(E<R(@;/9S
M8VAE;@!296-H=&4@9OQR("(E<R(@=6YD(&%L;&4@56YT97)R96-H=&4@;/9S
M8VAE;C\`6F5I;&4@;/9S8VAE;@!!=7-G97?D:&QT92!)9&5N=&ETY'0@;/9S
M8VAE;@!5;G1E<F]R9&YE<B!L]G-C:&5N`$1I92!A:W1U96QL92!3<&%L=&4@
M;/9S8VAE;@!$:64@86MT=65L;&4@6F5I;&4@;/9S8VAE;@!$87,@06MT=6%L
M:7-I97)U;F=S<VMR:7!T("(E<R(@=W5R9&4@9V5L]G-C:'0N`$%U<VQI969E
M<G5N9W-Z96ET`$3D;F5M87)K`$)E<V-H<F5I8F5N(%-I92!D87,@4')O8FQE
M;0!"97-C:')E:6)U;F<`1&5T86EL<R`H875C:"!I;B!(;W)D97,@3&]G9&%T
M96DI.@!$971A:6QS('=U<F1E;B!F_'(@9&5N($%D;6EN:7-T<F%T;W(@;6ET
M9V5L;V=G="X`16YT=VEC:VQU;F<`5&%U<'5N:W0`5&%U<'5N:W0@9&5R(&QE
M='IT96X@4W1U;F1E.B``5&%U<'5N:W0Z(`!6;VX@;&EN:W,@;F%C:"!R96-H
M=',`5F]N(')E8VAT<R!N86-H(&QI;FMS`%9E<GIE:6-H;FES`%IE:70@:6T@
M,C0M4W1U;F1E;BU&;W)M870@86YZ96EG96X_`$%N>F5I9V4M16EN<W1E;&QU
M;F=E;@!$971A:6QI97)T92!6;W)H97)S86=E(&%N>F5I9V5N`%9O<FAE<G-A
M9V4@*%1!1BD@86YZ96EG96X`06YZ96EG969O<FUA=`!%;7!F86YG<V)E<W3D
M=&EG=6YG`$1S8VAI8G5T:0!.:6-H="!L]G-C:&5N`$=R96EF96X@4VEE(&YI
M8VAT(&1I<F5K="!A=68@;6%I;G1E;F%N8V4N<&AP('IU`$5N=&CD;'0@9&EE
M(&5R<W1E(%IE:6QE(&1I92!&96QD;F%M96X_(%=E;FX@:F$L(&1I97-E<R!!
M=7-W86AL:^1S=&-H96X@;6%R:VEE<F5N.@!$;VUI;FEC80!$;VUI;FEK86YI
M<V-H92!297!U8FQI:P!.;V-H(&ME:6YE;B!:=6=A;F<_($AI97(@86YM96QD
M96XN`$AE<G5N=&5R;&%D96X`)7,@2&5R=6YT97)L861E;@!%<GIE=6=T92!+
M;VYF:6=U<F%T:6]N(&%L<R!02%`M4VMR:7!T(&AE<G5N=&5R;&%D96XN`$%U
M<W=A:&QL:7-T90!$<F]G96X`12U-86EL`$4M36%I;"UN86-H+5--4RUG871E
M=V%Y(&;\<B!0<F]V:61E<BP@9&EE(&5I;F5N('-O;&-H96X@1&EE;G-T('5N
M=&5R<W3\='IE;BX`1D5(3$52`$5C=6%D;W(`0F5A<F)E:71E;@!";&]C:R!B
M96%R8F5I=&5N`$=R=7!P92!B96%R8F5I=&5N`%)E8VAT92!B96%R8F5I=&5N
M`%)E8VAT92!B96%R8F5I=&5N`%)E8VAT92!F_'(@)R5S)R!B96%R8F5I=&5N
M`$5I;G-T96QL=6YG96X@8F5A<F)E:71E;B!F_'(Z`%)E8VAT92!F_'(@(B5S
M(B!B96%R8F5I=&5N`%)E8VAT92!F_'(@)7,@8F5A<F)E:71E;@!":6QD=6YG
M`,1G>7!T96X`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%+4UA:6P`12U-
M86EL+4%D<F5S<V4`1&EE($4M36%I;"U!9')E<W-E;B!M_'-S96X@9VQE:6-H
M('-E:6XN`$4M36%I;"U!9')E<W-E(&UI="!"97-TY'1I9W5N9P!%+4UA:6PM
M;F%C:"U335,M1V%T97=A>0!3;6EL97ES`$QE97)E($YA8VAR:6-H="X`3&5E
M<F5S($5R9V5B;FES+@!3=6-H8F5G<FEF9F4@;/9S8VAE;@!%:6YF_&=E;B!V
M;VX@0FEL9&5R;B!A=7,@1F]T;V=A;&5R:65N(&EN(&1E;B!497AT(&5R;&%U
M8F5N/P!+;VYT97AT;65N_"!B96D@4F5C:'1S:VQI8VL@86MT:79I97)E;C\`
M16YD:F%H<@!%9&ET;W(@=F5R9W+VWV5R;@!'96)E;B!3:64@96EN92!3:6-H
M97)H96ET<V9R86=E(&5I;BP@9&EE($EH;F5N(&=E<W1E;&QT('=I<F0L('=E
M;FX@4VEE($EH<B!087-S=V]R="!Z=7+\8VMS971Z96X@;?9C:'1E;BP@>BX@
M0BX@(E=I92!L875T970@9&5R($YA;64@26AR97,@2&%U<W1I97)S/R(Z`$AI
M97(@9&EE($)I;&0M55),(&%N9V5B96X`1V5B96X@<VEE(&1I92!"=6-H<W1A
M8F5N('5N=&5N(&5I;CH`Q'%U871O<FEA;"U'=6EN96$`17)I=')E80!&96AL
M97(`1F5H;&5R(&)E:6T@17)S=&5L;&5N(&5I;F5S($)L;V-K<SH@)7,`1F5H
M;&5R(&)E:6T@3/9S8VAE;B!D97,@4WEN8VAR;VYI<V%T:6]N<V%N:V5R<SH@
M)7,`1F5H;&5R(&)E:6T@3/9S8VAE;B!D97,@4WEN8VAR;VYI<V%T:6]N<VQO
M9W,Z("5S`$9E:&QE<B!B96EM($5R>F5U9V5N(&1E<R!);FAA;'1S.B`E<P!&
M96AL97(@8F5I;2#$;F1E<FX@9&5S(%!A<W-W;W)T<SH@)7,`1F5H;&5R(&EN
M(&1E<B!%+4UA:6PM3F%C:')I8VAT+@!&96AL97(@8F5I;2!38VAR96EB96X@
M=F]N("(E<R(N`$5S=&QA;F0`Q'1H:6]P:65N`$5T;FES8VAE<P!%=7)O<&$`
M06QL92`Q-2!-:6YU=&5N`$%L;&4@,B!-:6YU=&5N`$%L;&4@,S`@4V5K=6YD
M96X`06QL92`U($UI;G5T96X`0F5I(&IE9&5R($%N;65L9'5N9P!!;&QE(&AA
M;&)E(%-T=6YD90!!;&QE(#8P(%-E:W5N9&5N`$)E:7-P:65L=V5R=&4Z`$%U
M<V;\:')E;@!697)G<O;?97)N`"<I)R!E<G=A<G1E=`!%:6YZ96QN97,@5V]R
M="!O9&5R(%-U8VAB96=R:69F(&EN($%N9OQH<G5N9W-Z96EC:&5N(&5R=V%R
M=&5T`%9E<F9A;&QS9&%T=6T`17AP;VYE;G0`5F]R9&5R9W)U;F1F87)B90!(
M;V-H;&%D96X@9&5R($MO;F9I9W5R871I;VX@<&5R($944`!"96YU='IE<F5I
M;G-T96QL=6YG96X@:V]N;G1E;B!N:6-H="!G96QA9&5N('=E<F1E;BX`5F5R
M8FEN9'5N9R!Z=6T@3$1!4"!397)V97(@9V5S8VAE:71E<G0N`%9E<F)I;F1U
M;F<@>G5M(%--0BU397)V97(@9V5S8VAE:71E<G0N`$5S(&MO;FYT92!K96EN
M92!+;W!I92!V;VX@(B5S(B!E<G-T96QL="!W97)D96XN`$5S(&MO;FYT92!N
M:6-H="!N86-H("(E<R(@:V]P:65R="!W97)D96XN`$%U9F)A=2!E:6YE;B!N
M975E;B!305-,+59E<F)I;F1U;F<@:7-T(&9E:&QG97-C:&QA9V5N+@!%<R!K
M;VYN=&4@;FEC:'0@;F%C:"`B)7,B('9E<G-C:&]B96X@=V5R9&5N+@!&96AL
M97(@8F5I;2!,97-E;CH@)7,`2&5I=&5R`$9A;&ML86YD:6YS96QN`$9A<O9E
M<@!38VAW97)E<B!&96AL97(Z`$9A>`!&87AE`$9E8G)U87(`1V5F_&AL=&4@
M5&5M<&5R871U<@!'96;\:&QT92!496UP97)A='5R.B``5F5R96EN>F5L=&4@
M4V-H875E<@!697)E:6YZ96QT92!38VAN965S8VAA=65R`$9E;&1M871R:7@`
M1FEG;&5T($-!4%1#2$$`1FEG;&5T+49O;G0`1FED<V-H:0!$871E:0!!;GIA
M:&PZ("5S($1A=&5I`$%N>F%H;#H@)7,@1&%T96EE;@!$871E:6UA;F%G97(`
M1&%T96EN86UE`$1A=&5I875S=V%H;`!$871E:2U(;V-H;&%D96X`1&%S($AO
M8VAL861E;B!V;VX@1&%T96EE;B!W:7)D(&YI8VAT('5N=&5R<W3\='IT+@!&
M:6QT97(`1FEN;FQA;F0`17)S=&4@2.1L9G1E`$5R<W1E<R!6:65R=&5L`%9E
M<FCD;'1N:7,@>G5R_&-K<V5T>F5N`%5M9')E:&5N`%1E>'1F;'7?`$YE8F5L
M`$1A<R!697)Z96EC:&YI<R`E<R!E>&ES=&EE<G0@;FEC:'0`4V-H<FEF=&9A
M<F)E`$5S<V5N`$;\<B!"<F]W<V5R+"!D:64@:V5I;F4@0FEL9&5R('5N=&5R
M<W3\='IE;@!6;W)H97)S86=E("A4048I`%9O<FAE<F=E<V%G=&4@5&%G92`H
M5F]R:&5R<V%G96X@96YT:&%L=&5N(%1A9V4@=6YD($[D8VAT92P@96EN(&AO
M:&5R(%=E<G0@:V%N;B!Z=2!E:6YE;2!S96AR(&=R;]]E;B!";&]C:R!F_&AR
M96XI`%!A<W-W;W)T('9E<F=E<W-E;C\`1F]R;75L87)E`$=L_&-K<VME:W,`
M1VS\8VMS:V5K<W1Y<`!';/QC:W-K96MS90!';/QC:W-K96MS92`R`$9O<F5N
M`%=E:71E<FQE:71U;F<`1G(`4F%H;65N`$9R86YK<F5I8V@`175R;W#D:7-C
M:&5S($9R86YK<F5I8V@`1V5F<FEE<F5N9&5R(%)E9V5N`$9R86YZ]G-I<V-H
M+4=U87EA;F$`1G)A;GKV<VES8V@M4&]L>6YE<VEE;@!&<F%N>O9S:7-C:&4@
M1V5B:65T92!I;2!S_&1L:6-H96X@26YD:7-C:&5N($]Z96%N`%9O;@!!=7,@
M`%9O;&QS=.1N9&EG92!"97-C:')E:6)U;F<`5F]L;&UO;F0`5F]L;'-TY&YD
M:6=E<B!.86UE`$=A8G5N`$)I;&1E<B!A=7,@9&EE<V5R($=A;&5R:64`1V%L
M97)I93H`1V%M8FEA`"5S+4MO;F9I9W5R871I;VX@97)Z975G96X`17)Z975G
M=&5R($-O9&4`1V5O<F=I96X`1&5U='-C:&QA;F0`1VAA;F$`1VEB<F%L=&%R
M`%9O<FYA;64`06QL9V5M96EN92!%:6YS=&5L;'5N9V5N`$QO<P!';V5D96P`
M1V]O9VQE($UA<',`1V]O9VQE(%-U8VAE`$=R875S='5F96X`1W)I96-H96YL
M86YD`$=R:65C:&ES8V@@*$E33RTX.#4Y+3<I`$=R]FYL86YD`$=R96YA9&$`
M1W)U<'!E;G9E<G=A;'1U;F<`1W)U<'!E;FYA;65N(&3\<F9E;B!N:6-H="!L
M965R('-E:6X`1W)O=7!?;&1A<#H@1&EE($=R=7!P92`E<R!K;VYN=&4@;FEC
M:'0@:&EN>G5G96;\9W0@=V5R9&5N+B!-96QD=6YG(&1E<R!397)V97)S.B``
M1W)O=7!?;&1A<#H@1&EE($=R=7!P92`E<R!K;VYN=&4@;FEC:'0@9V5L]G-C
M:'0@=V5R9&5N`$=R;W5P7VQD87`Z($1I92!'<G5P<&4@)7,@:V]N;G1E(&YI
M8VAT(&%K='5A;&ES:65R="!W97)D96X`1W)U<'!E;@!'=6%D96QO=7!E`$=U
M86T`1W5A=&5M86QA`$=U97)N<V5Y`$=A<W1R96-H=&4`1^1S=&5B=6-H`$=U
M:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$1E<B!%9&ET;W(@:V%N
M;B!D:64@;&5T>G1E(%IE;&QE(&5I;F5R(%IE:6QE(&YI8VAT(&SV<V-H96XN
M`$1E<B!%9&ET;W(@:V%N;B!D:64@;&5T>G1E(%-P86QT92!E:6YE<B!486)E
M;&QE(&YI8VAT(&SV<V-H96XN`$1E<B!%9&ET;W(@:V%N;B!D:64@;&5T>G1E
M(%IE:6QE(&5I;F5R(%1A8F5L;&4@;FEC:'0@;/9S8VAE;BX`2%144"U!=71H
M96YT:69I>FEE<G5N9R!N:6-H="!G969U;F1E;BX`2&%I=&D`2&%S:"U!;&=O
M<FET:&UU<P!$:65S:6<`W&)E<G-C:')I9G0`2V]P9F5I;G1RY&=E`$AE87)D
M+2!U;F0@36-$;VYA;&1I;G-E;&X`4V-H=V5R92!'97=I='1E<@!(96)RY&ES
M8V@@*$E33RTX.#4Y+3@M22D`2/9H90!(:6QF90!%9&ET;W)H:6QF90!(:6QF
M90!(96UI<W!H97)E`$1I97,@:7-T(&1E<B!"96=I;FX@9&5R($1A=&5I.@!(
M;V-H`%]3=&%R='-E:71E`%9A=&EK86YS=&%D=`!!9')E<W-E('!R:79A=`!(
M96EM=F5R>F5I8VAN:7,`5&5L969O;B!P<FEV870`2&]N9'5R87,`2&]N9R!+
M;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!5;F?\;'1I9V4@)7,M6$U,+41A=&5N
M(&EN($YA8VAR:6-H="`E<P!(;W)D92]+;VQA8CH@17,@<&%S<W0@:V5I;F4@
M3F%C:')I8VAT('IU;2!/8FIE:W0@)7,`2&]R9&4O2V]L86(Z($ME:6X@3V)J
M96MT('9O;2!4>7`@)7,@:6X@3F%C:')I8VAT("5S(&=E9G5N9&5N`$AO<F1E
M+TMO;&%B.B`E<R`B)7,B('=U<F1E(&5R9F]L9W)E:6-H(&5N=&9E<FYT`$AO
M<F1E+TMO;&%B.B!$:64@26YT96=R871I;VYS9G5N:W1I;VYE;B!B96[V=&EG
M96X@9&EE(")D;VUX;6PB(%!(4"U%<G=E:71E<G5N9P!(;W)D92]+;VQA8CH@
M1OQR(&1A<R!/8FIE:W0@)7,@:V]N;G1E(&ME:6X@;F5U97(@6$U,+4)A=6T@
M97)Z975G="!W97)D96X`2&]R9&4O2V]L86(Z("5S("(E<R(@:V]N;G1E(&YI
M8VAT(&5N=&9E<FYT('=E<F1E;CH@)7,`2&]R9&4O2V]L86(Z($1I92!-24U%
M+4E$(&1E<R!!8G-C:&YI='1S('9O;2!4>7`@)7,@:V]N;G1E(&YI8VAT(&AE
M<F%U<V=E9G5N9&5N('=E<F1E;BX`2&]R9&4O2V]L86(Z("5S("(E<R(@:V]N
M;G1E(&YI8VAT('-Y;F-H<F]N:7-I97)T('=E<F1E;CH@)7,`2&]R9&4O2V]L
M86(Z($1I92!G96UE:6YS86UE;B!/8FIE:W1E(&MO;FYT96X@;FEC:'0@<WEN
M8VAR;VYI<VEE<G0@=V5R9&5N.B`E<P!(;W)D92]+;VQA8CH@56YB96MA;FYT
M97,@9V5M96EN<V%M97,@3V)J96MT("(E<R(`2&]R:7IO;G1A;&4@3&EN:64`
M2&]R:7IO;G1A;&5R($EN;F5N86)S=&%N9`!(;W)I>F]N=&%L.@!7:64@<VEN
M9"!3:64@:&EE<FAE<F=E;&%N9W0_($)I='1E(&%N(&1I92!%;G1W:6-K;&5R
M('IU<OQC:VUE;&1E;B$I`%=I92!V:65L92!3<&%L=&5N('-O;&QE;B!Z=7-A
M;6UE;F=E9OQG="!W97)D96X_`%=I979I96QE($9E;&1E<B`H4W!A;'1E;BD@
M9VEB="!E<S\`5VEE('9I96QE(%IE:6QE;B!S;VQL96X@>G5S86UM96YG96;\
M9W0@=V5R9&5N/P!,=69T9F5U8VAT:6=K96ET`$QU9G1F975C:'1I9VME:70Z
M(`!+;VUI:V5R`%5N9V%R;@!!;FQE9V5N(&1E<R!)34%0+5!O<W1F86-H<R!I
M<W0@9F5H;&=E<V-H;&%G96XZ("5S`$SV<V-H96X@9&5S($E-05`M4&]S=&9A
M8VAS(&ES="!F96AL9V5S8VAL86=E;CH@)7,`1F5S=&QE9V5N(&1E<B!)34%0
M+5!O<W1F86-H+5%U;W1A(&ES="!F96AL9V5S8VAL86=E;CH@)7,`25`M061R
M97-S90!)4"U!9')E<W-E(&YI8VAT('9E<F;\9V)A<BX`25`M061R97-S92!N
M:6-H="!I;2!E<FQA=6)T96X@0TE$4BU";&]C:RX`5F5R;&5T>G5N9R!D97(@
M9F5S=&=E;&5G=&5N($E0+@!:96EL92!E:6YF_&=E;B!?=F]R`$ES;&%N9`!.
M=7(@0FEL9&5R`$EC;VYS(&;\<B`E<P!":6QD97(@=6YD(%1E>'0`0F5Z96EC
M:&YU;F<@9&5R($ED96YT:73D=`!796YN('-I92!N:6-H="!K;W)R96MT(&%N
M9V5Z96EG="!W:7)D+"`E<RP@=6T@<VEE(&EN(&5I;F5M(&YE=65N($9E;G-T
M97(@86YG97IE:6=T('IU(&)E:V]M;65N+@!796YN(%-I92!M:70@9&5M($EN
M=&5R;F5T($5X<&QO<F5R(&ME:6YE(%-Y;6)O;&4@<V5H96XL(&W\<W-E;B!3
M:64@9&EE<V5S($OD<W1C:&5N(&UA<FMI97)E;BP@=6T@4$Y'+51R86YP87)E
M;GH@875S>G5S=&5L;&5N+@!796YN(%-I92!D:65S92!.86-H<FEC:'0@86X@
M4W1E;&QE(&5I;F4@0FEL9&5S('-E:&5N+"!K86YN($EH<B!"<F]W<V5R(&1A
M<R!":6QD+"!D87,@4VEE(&AO8VAL861E;B!M]F-H=&5N(&YI8VAT(&%N>F5I
M9V5N+@!":6QD=F]R<V-H874Z`$)I;&0M55),`$)I;&0M55),.@!":6QD('9O
M;B!'86QE<FEE`$)I;&0@=F]N($=A;&5R:64Z`$)I;&0M2&]C:&QA9&5N`$)I
M;&1E<@!);7!O<G1I97)E;BP@4V-H<FET="`E9`!);7!O<G1I97)T97,@1F5L
M9#H@)7,`26UP;W)T:65R=&4@1F5L9&5R.@!:96EL92!E:6YF_&=E;B!?;F%C
M:`!5;F?\;'1I9V4@06MT:6]N(&%N9V5G96)E;BX`56YG_&QT:6=E<B!"96YU
M='IE<FYA;64@=6YD+V]D97(@4&%S<W=O<G0N`$9A;'-C:&5R($)E;G5T>F5R
M;F%M92!O9&5R($4M36%I;"U!9')E<W-E+B!697)S=6-H96X@4VEE(&5S(&5R
M;F5U="!O9&5R('=E;F1E;B!3:64@<VEC:"!A;B!):')E;B!3>7-T96UA9&UI
M;FES=')A=&]R+"!W96YN(%-I92!W96ET97)E($AI;&9E(&)E;O9T:6=E;BX`
M16EN>G5G('9E<F=R]M]E<FX`26YD:65N`$5I;GIE;&YE($)E;G5T>F5R`$EN
M9&]N97-I96X`26YF;W)M871I;VX`26YF;W)M871I;VYE;@!);F9O<FUA=&EO
M;F5N(&YI8VAT(&UE:'(@=F5R9OQG8F%R+@!697)E<F)T92!-:71G;&EE9&5R
M`%]3<&%L=&4@9&%V;W(@96EN9OQG96X`0FEL9"!H:6YZ=6;\9V5N`%1A8F5L
M;&4@96EN9OQG96X`3&EN:R!E:6YF_&=E;@!37W!A;'1E(&1A;F%C:"!E:6YF
M_&=E;@!%:6YE(&YE=64@4W!A;'1E(&YA8V@@9&5R(&%K='5E;&QE;B!E:6YF
M_&=E;@!%:6YE(&YE=64@4W!A;'1E('9O<B!D97(@86MT=65L;&5N(&5I;F;\
M9V5N`$5I;F4@;F5U92!:96EL92!N86-H(&1E<B!A:W1U96QL96X@96EN9OQG
M96X`16EN92!N975E(%IE:6QE('9O<B!D97(@86MT=65L;&5N(&5I;F;\9V5N
M`$5I;F5N(&YE=65N($%B<V%T>B!N86-H(&1E;2!A:W1U96QL96X@16QE;65N
M="!E:6YF_&=E;@!%:6YE;B!N975E;B!!8G-A='H@=F]R(&1E;2!A:W1U96QL
M96X@16QE;65N="!E:6YF_&=E;@!!;'1E<FYA=&EV92!6;W)L86=E(&5I;F;\
M9V5N`$=E8F5N(%-I92!E:6YE($4M36%I;"U!9')E<W-E(&%N+"!A;B!D:64@
M9&%S(&YE=64@4&%S<W=O<G0@9V5S8VAI8VMT('=E<F1E;B!S;VQL.@!:96QL
M92!D86YA8V@@96EN9OQG96X`6F5L;&4@9&%V;W(@96EN9OQG96X`4W!A;'1E
M(&1A;F%C:"!E:6YF_&=E;@!3<&%L=&4@9&%V;W(@96EN9OQG96X`3F%C:')I
M8VAT96X@:&EN>G5F_&=E;@!!8G-A='H@9&%N86-H(&5I;F;\9V5N`$%B<V%T
M>B!D879O<B!E:6YF_&=E;@!:96EL92!D86YA8V@@96EN9OQG96X`6F5I;&4@
M9&%V;W(@96EN9OQG96X`1V5B96X@4VEE(&1I92!!;G1W;W)T(&%U9B!D:64@
M4VEC:&5R:&5I='-F<F%G92!E:6XZ`$)I;&0@96EN9OQG96XO8F5A<F)E:71E
M;@!,:6YK(&5I;F;\9V5N+V)E87)B96ET96X`6G4@=V5N:6<@1W5T:&%B96XL
M('5M(&%N(&1I92!697)T96EL97)L:7-T92!Z=2!V97)S8VAI8VME;BX`6G4@
M=V5N:6<@1W5T:&%B96XN`$=A;GIZ86AL`$QI<W1E('9O;B!'86YZ>F%H;&5N
M`%5N9_QL=&EG97(@541(+B`H57-E<B!$871A($AE861E<BDN`%5N9_QL=&EG
M92!:25`M1&%T96XN`%5N9_QL=&EG92!!;G=E;F1U;F<N`%5N9_QL=&EG92!"
M871C:"U)1"X`56YG_&QT:6=E($1A=&5N(&5I;F=E8F5N+@!5;F?\;'1I9V4@
M6FEE;&%D<F5S<V4N`%5N9_QL=&EG97,@1&%T96EF;W)M870`56YG_&QT:6=E
M<B!,:7IE;GIS8VAL_'-S96PN`%5N9_QL=&EG97(@3W)T(&%N9V5G96)E;BX`
M56YG_&QT:6=E<B!M<V=?='EP92X`56YG_&QT:6=E(&]D97(@9F5H;&5N9&4@
M87!I7VED+@!5;F?\;'1I9V4@;V1E<B!F96AL96YD92!087)A;65T97(N`%5N
M9_QL=&EG97,@W&)E<G)E8VAT+@!5;F?\;'1I9V4@4&%R=&YE<BU)1"X`56YG
M_&QT:6=E<B!0<F]D=6MT8V]D92X`56YG_&QT:6=E<R!0<F]T;VMO;&PN`%5N
M9_QL=&EG97(@16UP9N1N9V5R.B`B)7,B`%5N9_QL=&EG97,@9V5M96EN<V%M
M97,@3V)J96MT`%5N9_QL=&EG92!5<G-P<G5N9W-A9')E<W-E+@!5;F?\;'1I
M9V4@56YI8V]D92U$871E;BX`26YV96YT87(`075S=V%H;"!U;6ME:')E;@!)
M<VQA;6ES8VAE(%)E<'5B;&EK($ER86X`27)A:P!)<FQA;F0`27-L92!O9B!-
M86X`5F5R96EN>F5L=&4@1V5W:71T97(`27-R865L`$%U<W-T96QL97(`2W5R
M<VEV`$ET86QI96X`2F%M86EK80!*86YU87(`2F%P86X`2F%P86YI<V-H("A)
M4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;FEE;@!*=6QI`$IU;FD`0FQO8VMS
M871Z`%IE;G1R:65R96X`0FQO8VMS871Z`$QI;FMS(&%U<W)I8VAT96X`4F5C
M:'1S(&%U<W)I8VAT96X`2V%S86-H<W1A;@!/<FEG:6YA;"!B96EB96AA;'1E
M;C\`2V5N:6$`2V5R8F5R;W,M4V5R=F5R(&AA="!!=71H96YT:69I>FEE<G5N
M9R!Z=7+\8VMG97=I97-E;BX`2V5R;F5L+4YE=6QI;F=E`%-C:&S\<W-E;&5R
M>F5U9W5N9P!&:6YG97)A8F1R=6-K(&1E<R!38VAL_'-S96QS`%-C:&S\<W-E
M;&SD;F=E`%-C:&S\<W-E;'1Y<`!38VAL_'-S96QZ=V5C:P!$97(@4V-H;/QS
M<V5L(&)E9FEN9&5T('-I8V@@8F5R96ET<R!A=68@9&5M(/9F9F5N=&QI8VAE
M;B!38VAL_'-S96QS97)V97(N`$MI;F1E<@!+:7)I8F%T:0!$96UO:W)A=&ES
M8VAE(%9O;&MS<F5P=6)L:6,@2V]R96$`4F5P=6)L:6L@2V]R96$`2V]R96%N
M:7-C:"`H155#+4M2*0!+=7=A:70`2VER9VES:7-T86X`06Y?<&%S<V5N`%-P
M<F%C:&4`3&%O<P!,971Z=&4@2.1L9G1E`$QE='IT92!087-S=V]R=.1N9&5R
M=6YG`$QE='IT97,@5FEE<G1E;`!,971Z=&4@06MT=6%L:7-I97)U;F<Z`$QE
M='IT92!!;FUE;&1U;F<Z("5S`$QE='IT92!!;FUE;&1U;F<Z("5S('9O;B`E
M<P!,971Z=&4@06YM96QD=6YG.B!.;V-H(&YI90!,971T;&%N9`!'97-E='H`
M1F]R;6%T`$QE97(@;&%S<V5N(&;\<B!K96EN96X@4F%H;65N`$QI8F%N;VX`
M3&EN:W,`3&EN:V4@W&)E<G-C:')I9G0`3&EN:V4@5V5R=&4`3&5S;W1H;P!%
M8F5N90!,:6)E<FEA`$QI8GEE;@!,:65C:'1E;G-T96EN`%-P<OQH<F5G96X`
M3&5I8VAT97(@4F5G96X`1G+\:"!L96EC:'1E<B!296=E;@!3<.1T97(@3&5I
M8VAT97(@4F5G96X`3&5I8VAT92!296=E;G-C:&%U97(`3&5I8VAT97(@4F5G
M96X@;6ET($=E=VET=&5R`$QE:6-H=&5R(%-C:&YE969A;&P`3&5I8VAT92!3
M8VAN965S8VAA=65R`$QI;65R:6-K`$QI;FL`3&EN:RU54DP`3&EN:RU:=6=R
M:69F<W1A<W1E`$QI;FL@=F5R=V5I<W0@875F.@!,:6YK+5II96P`3&EN:RU4
M97AT`$4M36%I;"U!9')E<W-E('9E<FQI;FME;C\`3&EN:RU4:71L92U!='1R
M:6)U=`!,:6YK<P!,:6YU>"U';/QC:W-K96MS90!,:7-T("T@0F5N=71Z97(@
M:V%N;B!D96X@3W)D;F5R('-E:&5N`$1A=&5N8F%N:V5N(&%N>F5I9V5N`$AI
M;&9E96EN='+D9V4@86YZ96EG96X`5&%B96QL96X@86YZ96EG96X`3&ES=&5N
M+4%R8VAI=@!,:7-T96XM2&EL9F4`3&ES=&5N+4ED`$QI<W1E;BU"97-I='IE
M<@!,:7-T96XM061R97-S90!,:7-T96XM06YM96QD=6YG`$QI<W1E;BU!8FUE
M;&1U;F<`1&%S($%N>F5I9V5N(&1E<B!397-S:6]N<R!I<W0@9F5H;&=E<V-H
M;&%G96XZ("5S`$1A<R!!;GIE:6=E;B!D97(@0F5N=71Z97(@:7-T(&9E:&QG
M97-C:&QA9V5N.B`E<P!$87,@06YZ96EG96X@9&5R($)E;G5T>F5R(&ES="!N
M:6-H="!M]F=L:6-H+@!,:71E<F%T=7(`3&ET875E;@!,861E+BXN`$QO:V%L
M92!5:')Z96ET.B``4W!R86-H92!U;F0@6F5I=`!/<G0`06YM96QD96X`3&]G
M(&1E<B!L971Z=&5N(%-Y;F-H<F]N:7-A=&EO;BX`06)M96QD96X`06YM96QD
M96X`06YM96QD96%U9F=A8F5N`$1I92!!;FUE;&1U;F<@:7-T(&9E:&QG97-C
M:&QA9V5N+"!W96EL(%-I92!):')E;B!"96YU='IE<FYA;65N(&]D97(@26AR
M(%!A<W-W;W)T(&9A;'-C:"!E:6YG96=E8F5N(&AA8F5N+@!!;FUE;&1U;F<@
M9F5H;&=E<V-H;&%G96XN`$QA;F=E<B!497AT`$QI96)E`$YI961R:6<`2VPN
M(&=R:65C:&ES8VAE($)U8VAS=&%B96X`2VPN(&QA=&5I;FES8VAE($)U8VAS
M=&%B96X`2VPN('+V;6ES8VAE(%IA:&QE;@!,=7AE;6)U<F<`34T`34]41`!-
M4RU43D5&+4%N:&%N9R!E;G1H:65L="!K96EN92!$871E;BX`2$E.5T5)4P!-
M86-A;P!$:64@96AE;6%L:6=E($IU9V]S;&%W:7-C:&4@4F5P=6)L:6L@36%Z
M961O;FEE;@!-861A9V%S:V%R`$UA9VEE`%=E8FUA:6P`12U-86EL($%D;6EN
M:7-T<F%T:6]N`$QI;FL@7V%N;&5G96XN+BX`36%L87=I`$UA;&%Y<VEA`$UA
M;&ED:79E;@!-86QI`$UA;'1A`%9E<G=A;'1E;B!3:64@9&EE($MA=&5G;W)I
M96XL(&UI="!D96YE;B!3:64@16QE;65N=&4@=6YD($5I;G1RY&=E(&ME;FYZ
M96EC:&YE;B!K]FYN96XL('-O=VEE(&1I92!Z=6=E:/9R:6=E;B!&87)B96XN
M`$UA<#(T+4MA<G1E`$UA<%%U97-T+4MA<G1E`%IU;W)D;G5N9V5N(&=E<W!E
M:6-H97)T+@!-Y')Z`$%UWV5N86)S=&%N9`!-:70@1V5L97-E;BTO56YG96QE
M<V5N+5-T871U<R!V97)S96AE;@!-:70@86YD97)E;2!3=&%T=7,@=F5R<V5H
M96X@*'HN0BX@5VEC:'1I9R]"96%N=V]R=&5T*0!-87)S:&%L;&EN<V5L;@!-
M87)T:6YI<75E`%IU9V5O<F1N971E($9E;&1E<@!-875R971A;FEE;@!-875R
M:71I=7,`36%X:6UA;"!E<FQA=6)T97(@2W)E9&ET+@!-87AI;6%L92!.86-H
M=&EC:'1E;G1E:6QE(/QB97)S8VAR:71T96XN`$CV8VAS='1E;7!E<F%T=7(@
M9&5R(&QE='IT96X@,C0@4W1U;F1E;CH@`$CV8VAS='1E;7!E<F%T=7(@9&5R
M(&QE='IT96X@-B!3='5N9&5N.B``36%X:6UA;&4@06YZ86AL(&%N(%!O<G1A
M;&)L]F-K96X`36%X:6UA;&4@3.1N9V4`36%I`$UA>6]T=&4@27-L86YD`$UE
M9&EZ:6X`36ET9VQI961E<@!-96[\;6]D=7,Z`%IE;&QE;B!Z=7-A;6UE;F;\
M9V5N`$YA8VAR:6-H=`!$:64@3F%C:')I8VAT(&MO;FYT92!E<F9O;&=R96EC
M:"#\8F5R<'+\9G0@=V5R9&5N(&%B97(@;FEC:'0@9&%S(%IE<G1I9FEK870@
M9&5S($%B<V5N9&5R<RX`3F%C:')I8VAT(&YI8VAT(&UE:'(@9_QL=&EG+@!.
M86-H<FEC:'1E;G1Y<`!-971A<B!7971T97(`365T87)B;&]C:R!N:6-H="!V
M97)F_&=B87(N`$UE=&%R8FQO8VL@;FEC:'0@=F5R9OQG8F%R+B!$971A:6QS
M('=U<F1E;B!F_'(@9&5N($%D;6EN:7-T<F%T;W(@;6ET9V5L;V=G="X`2V5I
M;F4@5F5R8FEN9'5N9R!Z=7(@365T87)$0BX`365T:&]D90!$:64@365T:&]D
M92`B)7,B(&ES="!N:6-H="!D969I;FEE<G0`365T:&]D92!N:6-H="!D969I
M;FEE<G0N($%U9F=E<G5F96YE($UE=&AO9&4Z("5S`$UE=')I<V-H`$UE>&EK
M;P!&]F1E<FEE<G1E(%-T86%T96X@=F]N($UI:W)O;F5S:65N`$UI='1E`$UI
M;65T>7``5&EE9G-T=&5M<&5R871U<B!D97(@;&5T>G1E;B`R-"!3='5N9&5N
M.B``5&EE9G-T=&5M<&5R871U<B!D97(@;&5T>G1E;B`V(%-T=6YD96XZ(`!$
M87,@;6EN:6UA;&4@4&%S<W=O<G1A;'1E<B!I<W0@;F]C:"!N:6-H="!A8F=E
M;&%U9F5N`%-P:65G96QN`%9E<G-C:&EE9&5N97,`4$5!4BU086ME="!(5%10
M7U)E<75E<W0@9F5H;'0N`$9E:&QE;F1E($MO;F9I9W5R871I;VXN(%-I92!M
M_'-S96X@9&EE<V4@:F5T>G0@97)Z975G96XL('=E;FX@4VEE(&1I92!!;G=E
M;F1U;F<@=F5R=V5N9&5N(&WV8VAT96XN`$9E:&QE;F1E($YA8VAR:6-H=&5N
M+4E$+@!014%2+5!A:V5T($UA:6P@9F5H;'0N`$9E:&QE;F1E(%-I='IU;F=S
M+4E$+@!-;P!%+4UA:6P@36]B:6P`3>3?:6<`Q&YD97)U;F=S9&%T=6T`55),
M(&)E87)B96ET96X`36]D=6QU<P!297!U8FQI:R!-;VQD874`36]N86-O`$UO
M;F=O;&5I`$UO;F%T('5N9"!*86AR`$UO;F%T;&EC:`!-;VYT<V5R<F%T`$UO
M;F1P:&%S96X`365H<B!&96QD97(@:6X@6F5I;&4@)60@86QS(&1I92!E<G=A
M<G1E=&5N("5D(&=E9G5N9&5N+@!-87)O:VMO`-QB97)W:65G96YD(&AE:71E
M<@#<8F5R=VEE9V5N9"!"97?V;&MT`-QB97)W:65G96YD($)E=_9L:W0@=6YD
M(%=I;F1I9P#<8F5R=VEE9V5N9"!3;VYN:6<`3F%C:"!U;G1E;@!.86-H(&QI
M;FMS`$YA8V@@<F5C:'1S`$YA8V@@;V)E;@!.86-H('5N=&5N`$YA8V@@;V)E
M;@!-;W-A;6)I:P!!=7-W86AL;&ES=&4@:6X@;65H<F5R96X@16)E;F5N`$UU
M;'1I;6%P+55++4MA<G1E`$UE:')F86-H875S=V%H;`!-96EN($MO;G1O`$UE
M:6X@2V]N=&\`365I;B!0;W)T86P`365I;B!0;W)T86QL87EO=70`0G5R;6$`
M3D5)3BP@:6-H('-T:6UM92!.24-(5"!Z=0!.86UE`$YA;6EB:6$`3F%U<G4`
M3F5P86P`3FEE9&5R;&%N9&4`3FEE9&5R;.1N9&ES8VAE($%N=&EL;&5N`$YE
M='-C87!E+4)A<VES+5523`!.971S8V%P92U#02U3<&5R<G5N9W,M55),`$YE
M='-C87!E+4-!+5)I8VAT;&EN:65N+5523`!.971S8V%P92U:971I9FEK871S
M97)N975E<G5N9W,M55),`$YE='-C87!E+5-P97)R=6YG<RU54DP`3F5T<V-A
M<&4M4U-,+5-E<G9E<FYA;64`3F5T<V-A<&4M2V]M;65N=&%R`$YE='-C87!E
M+5IE<G1I9FEK871T>7``3F5T>G=E<FL`3FEE`$YE=6MA;&5D;VYI96X`3F5U
M92!+871E9V]R:64`3F5U;6]N9`!.975E<B!"96YU='IE<FYA;64@*&]P=&EO
M;F%L*0!.975S965L86YD`$YE=65S(%!A<W-W;W)T`$1A<R!N975E(%!A<W-W
M;W)D('=I<F0@86T@)7@@86)L875F96XN`$1I92!N975E;B!087-S=_9R=&5R
M('-T:6UM96X@;FEC:'0@_&)E<F5I;BX`3F5U97,@1F5N<W1E<B`H7V)L86YK
M*0!.86-H<FEC:'1E;@!.97=S9W)U<'!E;@!796ET97(`3N1C:'-T92`T(%!H
M87-E;@!.Y&-H<W1E($5I;G-T96QL=6YG96X`5V5I=&5R/@!.:6-A<F%G=6$`
M3FEG97(`3FEG97)I80!.86-H=',`3FEU90!.96EN`$ME:6YE($MO;F9I9W5R
M871I;VYS9&%T96X@=F5R9OQG8F%R+"!U;2!5;G1E<G-C:&EE9&4@86YZ=7IE
M:6=E;BX`2V5I;F4@4W1R871E9VEE('IU;2!%<G-T96QL96X@=F]N($E33RU!
M8F)I;&1E<FX@=F5R9OQG8F%R+@!+96EN92!"871C:"U6;W)L86=E+@!%<R!E
M>&ES=&EE<G0@:V5I;B!";&]C:R!A;B!D97(@86YG96=E8F5N96X@4&]S:71I
M;VX`2V5I;B!+86QE;F1E<FYA;64@9OQR(&1I92!-0T%,+4%U=&AE;G1I9FEZ
M:65R=6YG(&%N9V5G96)E;BX`2V5I;F4@Q&YD97)U;F=E;BX`56YT97)H86QB
M(&1I97-E<B!%8F5N92!K]FYN96X@:V5I;F4@=V5I=&5R96X@56YT97)R96-H
M=&4@:&EN>G5G96;\9W0@=V5R9&5N+@!&_'(@)7,@=W5R9&5N(&ME:6YE($MO
M;F9I9W5R871I;VYS:6YF;W)M871I;VYE;B!A;F=E9V5B96XN`$;\<B!D96X@
M1E10+59&4RU4<F5I8F5R('=U<F1E;B!K96EN92!+;VYF:6=U<F%T:6]N<VEN
M9F]R;6%T:6]N96X@86YG96=E8F5N+@!&_'(@9&5N(%-13"U61E,M5')E:6)E
M<B!W=7)D96X@:V5I;F4@2V]N9FEG=7)A=&EO;G-I;F9O<FUA=&EO;F5N(&%N
M9V5G96)E;BX`1OQR(&1E;B!344PM1&%T96DM5D93+51R96EB97(@=W5R9&5N
M(&ME:6YE($MO;F9I9W5R871I;VYS:6YF;W)M871I;VYE;B!A;F=E9V5B96XN
M`$ME:6X@2W)E9&ET(&UE:'(@_&)R:6<N`$ME:6X@16UP9N1N9V5R(&%N9V5G
M96)E;BX`2V5I;F4@1&%T96D@:&]C:&=E;&%D96X`2V5I;F4@26-O;G,@9V5F
M=6YD96XN`$5S('=U<F1E(&ME:6X@3W)T(&9E<W1G96QE9W0N`$ME:6X@3W)T
M(&%N9V5G96)E;BX`2V5I;F4@3F%C:')I8VAT(&%N9V5G96)E;BX`2V5I;B!.
M86UE(&%N9V5G96)E;BX`2V5I;F4@3G5M;65R(&%N9V5G96)E;BX`2V5I;F4@
M86YS=/;?:6=E;B!';/QC:W-K96MS90!+96EN(%!A<W-W;W)T(&;\<B!D:64@
M2%144"U!=71H96YT:69I>FEE<G5N9R!A;F=E9V5B96XN`$ME:6X@4&%S<W=O
M<G0@9OQR(&1I92!)34%0+4%U=&AE;G1I9FEZ:65R=6YG(&%N9V5G96)E;BX`
M2V5I;B!087-S=V]R="!F_'(@9&EE($ME<F)E<F]S+4%U=&AE;G1I9FEZ:65R
M=6YG(&%N9V5G96)E;BX`2V5I;B!087-S=V]R="!F_'(@9&EE($QO9VEN+4%U
M=&AE;G1I9FEZ:65R=6YG(&%N9V5G96)E;BX`2V5I;B!087-S=V]R="!F_'(@
M9&EE(%!!4U-71"U!=71H96YT:69I>FEE<G5N9R!A;F=E9V5B96XN`$ME:6X@
M4&%S<W=O<G0@9OQR(&1I92!334(M075T:&5N=&EF:7II97)U;F<@86YG96=E
M8F5N+@!+96EN(%!F860@>G5M($]P96Y34TPM4')O9W)A;6T@86YG96=E8F5N
M+B!$87,@3W!E;E-33"U0<F]G<F%M;2!W:7)D(&)E;O9T:6=T+"!U;2!02T-3
M+3$R+41A=&5N('9E<F%R8F5I=&5N('IU(&OV;FYE;BX`2V5I;F4@875S<W1E
M:&5N9&5N(%)E9VES=')I97)U;F=E;BX`2V5I;B!3<&5I8VAE<G!L871Z+4MO
M;G1I;F=E;G0@9F5S=&=E;&5G="X`2V5I;F4@4F%H;65N`$ME:6X@5')E;FYZ
M96EC:&5N(&%N9V5G96)E;BX`2V5I;F4@4V5I=&5N`$1A=&5I(&YI8VAT(&=E
M9G5N9&5N`$ME:6YE('1E;7!O<N1R97,@5F5R>F5I8VAN:7,@9OQR(&1E;B!#
M86-H92!G969U;F1E;BX`2V5I;B!"96YU='IE<FYA;64@=6YD+V]D97(@4&%S
M<W=O<G0@86YG96)E;BX`17,@=W5R9&5N(&ME:6YE(&?\;'1I9V5N(%A-3"U$
M871E;B!Z=7+\8VMG96=E8F5N`$ME:6YE(%=E<G1E`$ME:6YE(%9E<G-I;VYS
M;G5M;65R(&EN(&1E<B!/<FEG:6YA;&MO;F9I9W5R871I;VX@9V5F=6YD96XN
M($5R;F5U97)N(%-I92!):')E($MO;F9I9W5R871I;VXN`$ME:6YE(%9E<G-I
M;VYS;G5M;65R(&EN($EH<F5R($MO;F9I9W5R871I;VX@9V5F=6YD96XN($5R
M;F5U97)N(%-I92!):')E($MO;F9I9W5R871I;VXN`$ME:6YE`$ME:6YS("A3
M=&%N9&%R9"!B96YU='IE;BD`3F]R9&ES8V@@*$E33RTX.#4Y+3$P*0!.;W)F
M;VQK:6YS96P`3O9R9&QI8VAE($AE;6ES<&AE<F4`3O9R9&QI8VAE($UA<FEA
M;F5N`$YO<G=E9V5N`$?\;'1I9R!B:7,`1_QL=&EG(&%B`$ME:6X@5F5R>F5I
M8VAN:7,`3FEC:'0@9V5F=6YD96XN`$YI8VAT(&EM<&QE;65N=&EE<G0N`$YI
M8VAT(&9E<W1G96QE9W0`3FEC:'0@=6YT97)S=/QT>G0N`$YO=&EZ96X`3FEC
M:'1S(&%N>G5Z96EG96XL(&)I='1E('IU<OQC:V=E:&5N+@!.;W9E;6)E<@!:
M86AL`$%N>F%H;"!D97(@6F5I8VAE;@!!;GIA:&P@9&5R(%-P86QT96X`06YZ
M86AL(&1E<B!:96EL96X`2V5I;F4@3G5M;65R;B!F_'(@9&EE(%9E<G1E:6QE
M<FQI<W1E(&%N9V5G96)E;BX`3TL`3V)J96MT`$]B:F5K=&5R<W1E;&QE<@!/
M:W1A;'IA:&P`3VMT;V)E<@!&:6QT97(@9OQR(&%N<W3VWVEG92!);FAA;'1E
M`$+\<F\`26AR(&YE=65S(%!A<W-W;W)T(&UU<W,@<VEC:"!V;VX@26AR96T@
M86QT96X@=6YT97)S8VAE:61E;BX`06QT97,@4&%S<W=O<G0`1F%L<V-H97,@
M86QT97,@4&%S<W=O<G0N`$]M86X`3VYC;&EC:RU%=F5N=`!.=7(@24U!4"U3
M97)V97(@=6YT97)S=/QT>F5N(&=E;65I;G-A;64@3W)D;F5R+@!.=7(@86YS
M=/;?:6=E($=L_&-K<VME:W-E`$YU<B!E:6YE($4M36%I;"U!9')E<W-E(&5R
M;&%U8G0N`$YU<B!D97(@0F5S:71Z97(@;V1E<B!D97(@4WES=&5M861M:6YI
M<W1R871O<B!K86YN(&1E;B!"97-I='IE<B!O9&5R(&1I92!"97-I='IE<G)E
M8VAT92#D;F1E<FX`26X@;F5U96T@1F5N<W1E<B#V9F9N96X`3W!E;E-33"U&
M96AL97(Z(%-I9VYI97)T92!3+TU)344M1&%T96X@:V]N;G1E;B!N:6-H="!E
M>'1R86AI97)T('=E<F1E;BX`1&EE<V5N($QI;FL@:6X@96EN96T@;F5U96T@
M1F5N<W1E<B#V9F9N96X`0F5T<FEE8G-Y<W1E;0!%:6YS=&5L;'5N9V5N`$5I
M;G-T96QL=6YG96X@9OQR("5S`$YU;6UE<FEE<G1E($QI<W1E`$]R9V%N:7-A
M=&EO;@!/<F=A;FES871I;VYS86)T96EL=6YG`$]R9V%N:7-I97)E;@!/<FEG
M:6YA;'9O<FQA9V4@9&5R($%N=V5N9'5N9P!/<FEG:6YA;'9O<FQA9V4@:6X@
M)7,Z`%-O;G-T:6=E`$%N9&5R92!);F9O<FUA=&EO;F5N`$)E<VET>F5R<F5C
M:'1E`%!!32U!=71H96YT:69I>FEE<G5N9R!I<W0@;FEC:'0@=F5R9OQG8F%R
M+@!014%2.CI-86EL+4)A8VME;F0`1&EG:71A;&4@4$=0+55N=&5R<V-H<FEF
M=`!01U`M=F5R<V-H;/QS<V5L=&4@1&%T96X`UF9F96YT;&EC:&5R(%!'4"U3
M8VAL_'-S96P`36ET(%!'4"!U;G1E<GIE:6-H;F5T92]V97)S8VAL_'-S96QT
M92!$871E;@!02%`@0V]D90!02%`@4VAE;&P`5F]R;6ET=&%G<R!L96EC:'1E
M<B!296=E;@!.86-H;6ET=&%G<R!296=E;@!.86-H;6ET=&%G<R!38VAA=65R
M`$YA8VAM:71T86=S(%-C:&YE90!.86-H;6ET=&%G<R!38VAN965S8VAA=65R
M`$YA8VAM:71T86=S(%-O;FYE`$YA8VAM:71T86=S($=E=VET=&5R`$1I92!0
M3U-)6"U%<G=E:71E<G5N9R!F96AL=`!?4$A0(%-H96QL`$EN;F5N86)S=&%N
M9`!086MI<W1A;@!086QA=0!"97-E='IT92!086SD<W1I;F5N<VES8VAE($=E
M8FEE=&4`4&%N86UA`%!A<'5A+4YE=6=U:6YE80!087)A9W5A>0!496EL=V5I
M<V4@0F5W]FQK=`!087-S=V]R=`!087-S=V]R="!E<F9O;&=R96EC:"!G9>1N
M9&5R="X`1F%L<V-H97,@4&%S<W=O<G0`2V5I;B!087-S=V]R="!F_'(@9&EE
M(%)!1$E54RU!=71H96YT:69I>FEE<G5N9R!A;F=E9V5B96XN`%!A<W-W;W)T
M(&UI="!"97-TY'1I9W5N9P!087-S=V]R=#H`4&%S<W=O<G0Z(`!$:64@4&%S
M<W?V<G1E<B!M_'-S96X@9VQE:6-H('-E:6XN`$5I;F;\9V5N`%9O;B!D97(@
M6G=I<V-H96YA8FQA9V4@96EN9OQG96X`4&9A9`!!=7-S=&5H96YD92!296=I
M<W1R:65R=6YG96XZ`%!E<G-O;F5N`%!R;WIE;G0`5V%R='5N9W-A<F)E:71E
M;B!D=7)C:&;\:')E;@!787)T=6YG<V%R8F5I=&5N(&YA8V@@9&5R($%N;65L
M9'5N9R!D=7)C:&;\:')E;C\`4F5C:'1E`%)E8VAT("(E<R(@=W5R9&4@;FEC
M:'0@9V5L]G-C:'0N`%IU9W)I9F8@=F5R=V5I9V5R=`!296-H=&4`4F5C:'1E
M=F5R=V%L='5N9P!097)S]FYL:6-H92!!;F=A8F5N`%!E<G4`2&%U<W1I97)E
M`%!H:6QI<'!I;F5N`%1E;&5F;VX`1F]T;W,`4&ET8V%I<FX`4&EX96P`4&QA
M='1H96ET96X`0FET=&4@:VQI8VME;B!3:64@:6X@96EN92!:96QL90!":71T
M92!B97-TY'1I9V5N(%-I92P@9&%S<R!3:64@9&EE<V5S($5L96UE;G0@;/9S
M8VAE;B!M]F-H=&5N.@!":71T92!B973D=&EG96X@4VEE+"!D87-S(%-I92!D
M96X@3&EN:R!V;VX@9&EE<V5M($5L96UE;G0@96YT9F5R;F5N(&WV8VAT96XN
M`$)I='1E(&5I;F5N($UO;F%T('5N9"!E:6X@2F%H<B!A;F=E8F5N+@!":71T
M92!G96)E;B!3:64@96EN96X@3F%M96X@9OQR(&1I92!N975E($MA=&5G;W)I
M92!A;CH`0FET=&4@96EN92!G_&QT:6=E($E0+4%D<F5S<V4@96EN9V5B96XN
M`$)I='1E(&=E8F5N(%-I92!E:6X@9_QL=&EG97,@1&%T=6T@86X[(/QB97)P
M<OQF96X@4VEE(&1I92!:86AL(&1E<B!486=E(&EN(&1E;2!-;VYA="X`0FET
M=&4@96EN96X@9_QL=&EG96X@6F5I='=E<G0@96EN9V5B96XN`$)I='1E(&=E
M8F5N(%-I92!E:6YE(%IU<V%M;65N9F%S<W5N9R!):')E<R!0<F]B;&5M<R!A
M;BX`0FET=&4@9V5B96X@4VEE($EH<F5N($)E;G5T>F5R;F%M96X@=6YD($EH
M<B!087-S=V]R="!A;@!":71T92!L97-E;B!3:64@<VEC:"!D96X@9F]L9V5N
M9&5N(%1E>'0@<V]R9V;D;'1I9R!D=7)C:"X@4VEE($W<4U-%3B!D:65S96X@
M0F5D:6YG=6YG96X@>G5S=&EM;65N+"!W96YN(%-I92!D:65S97,@4WES=&5M
M(&)E;G5T>F5N(&WV8VAT96XN`$)I='1E(&1E;B!N975E;B!+871E9V]R:65N
M86UE;B!E:6YG96)E;CH`4&]L96X`4&]L:71I:P!5;69R86=E;@!0;W)T=6=A
M;`!0;W-I=&EO;FEE<G5N9R!D:65S92!":6QD97,`4&]S:71I;VYI97)U;F<@
M9&EE<V5R(%1A8F5L;&4`4V5N9&5N(&%N(&1I97-E;B!/<F1N97(@*&YI8VAT
M(&1U<F-H($E-05`I`$YI961E<G-C:&QA9R!I;B!D96X@;&5T>G1E;B`E<R!3
M='5N9&4H;BDZ(`!.:65D97)S8VAL86=S+3QB<B`O/G=A:')S8VAE:6YL:6-H
M:V5I=`!0<F5F<U]L9&%P.B!$:64@8F5N]G1I9W1E($Q$05`M17)W96ET97)U
M;F<@=W5R9&4@;FEC:'0@9V5F=6YD96XN`%!R969S7W-E<W-I;VXZ($1I92!B
M96[V=&EG=&4@4V5S<VEO;BU%<G=E:71E<G5N9R!W=7)D92!N:6-H="!G969U
M;F1E;BX`3'5F=&1R=6-K`$QU9G1D<G5C:R!A=68@4V5E:/9H93H@`$QU9G1D
M<G5C:SH@`%9O<G-C:&%U`$5I;F4@5F]R<V-H874@9&5S($)I;&1E<R!I;B!E
M:6YE;2!N975E;2!&96YS=&5R(&%N>F5I9V5N`%9O:&5R:6=E($5I;G-T96QL
M=6YG96X`1&]K=6UE;G0@9')U8VME;@!0<FEV871E<B!38VAL_'-S96P`4')O
M8FQE;64`4')O8FQE;6)E<V-H<F5I8G5N9P!0<F]J96MT90!.86-H9G)A9V5T
M97AT`-9F9F5N=&QI8VAE<B!38VAL_'-S96P`06QG;W)I=&AM=7,@9&5S(/9F
M9F5N=&QI8VAE;B!38VAL_'-S96QS`$EN9F]R;6%T:6]N96X@>G5M(/9F9F5N
M=&QI8VAE;B!38VAL_'-S96P`1&%S(/9F9F5N=&QI8VAE+W!R:79A=&4@4V-H
M;/QS<V5L<&%A<B!K;VYN=&4@;FEC:'0@97)S=&5L;'0@=V5R9&5N+@!0=65R
M=&\@4FEC;P!.86-H<FEC:'1E;B!E;F1G_&QT:6<@;/9S8VAE;@!+871A<@!!
M8F9R86=E`%-P96EC:&5R<&QA='HM2V]N=&EN9V5N=`#69F9E;G1L:6-H97(@
M4E-!(%-C:&S\<W-E;"`H)60@0FET*0!!=7-W86AL:VYO<&8`4F5G96X`1G+\
M:"!296=E;@!3<.1T97(@4F5G96X`4F5G96YS8VAA=65R`%-C:&YE97)E9V5N
M`%)E9V5N(&EN(%-C:&YE92#\8F5R9V5H96YD`$=L_&-K<VME:W,`5F5R:.1L
M=&YI<P!,97-E;@!.86-H<FEC:'1E;B!L97-E;@`E<R!W:7)K;&EC:"!L]G-C
M:&5N/R!$:65S97(@5F]R9V%N9R!K86YN(&YI8VAT('+\8VMGY&YG:6<@9V5M
M86-H="!W97)D96XN`$1A=&5N(&1E<R!"96YU='IE<G,@)7,@=VER:VQI8V@@
M;/9S8VAE;C\@1&EE<V5R(%9O<F=A;F<@:V%N;B!N:6-H="!R_&-K9^1N9VEG
M(&=E;6%C:'0@=V5R9&5N+@!&_&AR="!L971Z=&4@06MT:6]N(&5R;F5U="!A
M=7,`06MT=6%L:7-I97)E`$1Y;F%M:7-C:&4@365N_&5L96UE;G1E(&%K='5A
M;&ES:65R96XZ`%!O<G1A;&%N<VEC:'0@86MT=6%L:7-I97)E;CH`4F5G=6SD
M<F5R($%U<V1R=6-K`%9E<F)I;F1U;F=S+4)R;W=S97(`06MT=6%L:7-I97)E
M;@!"96UE<FMU;F=E;@!%;G1F97)N=&4@4V5R=F5R`%-E<G9E<F%D<F5S<V4@
M*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!%;G1F97)N96X`0FQO
M8VL@;/9S8VAE;@!3<&%L=&4@;/9S8VAE;@!&;W)M871I97)U;F<@96YT9F5R
M;F5N`%!A87(@;/9S8VAE;@!'97-P96EC:&5R=&5S(%-K<FEP="!A=7,@9&5M
M('1E;7!O<N1R96X@5F5R>F5I8VAN:7,@96YT9F5R;F5N+@!%;G1F97)N90!$
M:65S97,@16QE;65N="!A=7,@9&5M($1O:W5M96YT(&5N=&9E<FYE;@!"96YU
M='IE<B!L]G-C:&5N`$)E;G5T>F5R(&SV<V-H96XZ("5S`$%N9G)A9V4@:V]N
M;G1E(&YI8VAT(&)E86YT=V]R=&5T('=E<F1E;BX@6G5R_&-K9V5G96)E;F5R
M($9E:&QE<F-O9&4Z(`!$97(@9V5W_&YS8VAT92!$:65N<W0@:V]N;G1E(&YI
M8VAT(&=E9G5N9&5N('=E<F1E;BX`(B5S(B!W=7)D92!I;B!D97(@2V]N9FEG
M=7)A=&EO;B!F_'(@)7,@;FEC:'0@86YG96=E8F5N+@`B)7,B('=U<F1E(&EN
M(&1E<B!61E,M2V]N9FEG=7)A=&EO;B!N:6-H="!A;F=E9V5B96XN`"(E<R(@
M=W5R9&4@:6X@9&5R($MO;F9I9W5R871I;VX@;FEC:'0@86YG96=E8F5N+@!.
M;W1W96YD:6=E<R!&96QD`%IU<OQC:W-E='IE;@!087-S=V]R="!Z=7+\8VMS
M971Z96X`4V5T>F5N(%-I92!):'(@4&%S<W=O<G0@>G5R_&-K`$QE='IT92!!
M8F9R86=E(&5I;F;\9V5N`$5R9V5B;FES<V4`6G5R_&-K('IU($5I;G-T96QL
M=6YG96X`3F5U97,@4&%S<W=O<G0@97)N975T(&5I;F=E8F5N`%+I=6YI;VX`
M2V]N9FEG=7)A=&EO;B!Z=7+\8VMS971Z96X`5UE325=91RU%9&ET;W(@16EN
M<W1E;&QU;F=E;@!2Y'1S96P`4F5C:'1S`%)E8VAT92#<8F5R<V-H<FEF=`!2
M96-H=&4@5V5R=&4`7UIE:6QE;F5I9V5N<V-H869T96XN+BX`4F]L;&4`4G5M
MY&YI96X`56T@,3@PL"!D<F5H96X`3F%C:"!L:6YK<R!D<F5H96X`3F%C:"!R
M96-H=',@9')E:&5N`%IE:6QE;F5I9V5N<V-H869T96X`6F5I;&5N96EG96YS
M8VAA9G1E;@!:96EL96XZ`%)E9V5L;@!286AM96X@>G=I<V-H96X@86QL96X@
M6F5I;&5N('5N9"!3<&%L=&5N`%)A:&UE;B!N=7(@>G=I<V-H96X@4W!A;'1E
M;@!286AM96X@;G5R('IW:7-C:&5N(%IE:6QE;@!3=&%R=&5N`%)U<W-I<V-H
M92!&]G)D97)A=&EO;@!2=6%N9&$`4R]-24U%(&MR>71O9W)A<&AI<V-H92!5
M;G1E<G-C:')I9G0`36ET(%,O34E-12!V97)S8VAL_'-S96QT92!.86-H<FEC
M:'0`4T%33"U!=71H96YT:69I>FEE<G5N9R!I<W0@;FEC:'0@=F5R9OQG8F%R
M+@!335,M5F5R<V%N9`!344P@4VAE;&P`4U%,+4%N=V5I<W5N9R!Z=7(@06)F
M<F%G92!D97(@5V5R=&4`4U-(`$521D],1P!37U%,(%-H96QL`%-A`%-A:6YT
M($AE;&5N80!386EN="!+:71T<R!U;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I
M;G0@4&EE<G)E('5N9"!-:7%U96QO;@!386EN="!6:6YC96YT('5N9"!D:64@
M1W)E;F%D:6YE;@!';&5I8VAE<B!286AM96X@*%]S96QF*0!386UO80!386X@
M36%R:6YO`%-A;R!4;VUE('5N9"!0<FEN8VEP90!3871E;&QI=&5N<')O=FED
M97(`4V%U9&DM07)A8FEE;@!3<&5I8VAE<FX`(B5S(B!S<&5I8VAE<FX`)7,@
M<W!E:6-H97)N`$5I;G-T96QL=6YG96X@<W!E:6-H97)N`$5R>F5U9W1E($MO
M;F9I9W5R871I;VX@86QS(%!(4"U3:W)I<'0@:6T@=&5M<&]RY')E;B!697)Z
M96EC:&YI<R!):')E<R!397)V97)S('-P96EC:&5R;BX`)7,M2V]N9FEG=7)A
M=&EO;B!G97-P96EC:&5R="X`1&%S($%K='5A;&ES:65R=6YG<W-K<FEP="!W
M=7)D92!I;B`B)7,B(&=E<W!E:6-H97)T+@!697)E:6YZ96QT92!'97=I='1E
M<@!7:7-S96YS8VAA9G0`4W5C:&4`4W5C:&UA<V-H:6YE;@!$871E:65N(&%U
M<W?D:&QE;@!$871U;2!A=7-WY&AL96X`2&EN>G5Z=6;\9V5N9&4@1W)U<'!E
M;B!A=7-WY&AL96X`3F5U96X@0F5S:71Z97(@875S=^1H;&5N`%-E<G9E<B!A
M=7-WY&AL96X`2&EN>G5Z=6;\9V5N9&5N($)E;G5T>F5R(&%U<W?D:&QE;@!!
M;&QE(&%U<W?D:&QE;@!,96=E;B!3:64@86QL92!$871U;7-K;VUP;VYE;G1E
M;B!F97-T+@!/8FIE:W0@875S=^1H;&5N`$ME:6YE;B!A=7-WY&AL96X`5^1H
M;&5N(%-I92!D:64@8F5N]G1I9W1E;B!:96EC:&5N(&%U<R!D96X@:F5W96EL
M:6=E;B!&96QD97)N(&%U<RX@1&%N;B!K]FYN96X@4VEE(&1I97-E(&%U<R!D
M96T@5&5X=&9E;&0@:V]P:65R96X@=6YD(&EN($EH<F4@3F%C:')I8VAT(&5I
M;F;\9V5N+@!7Y&AL96X@4VEE(&1A<R!$871U;7-T<F5N;GIE:6-H96XZ`%?D
M:&QE;B!3:64@9&%S($1A='5M<V9O<FUA=#H`5^1H;&5N(%-I92!D:64@261E
M;G1I=.1T+"!D:64@4VEE(.1N9&5R;B!M]F-H=&5N.@!7Y&AL96X@4VEE(&1A
M<R!:96ET=')E;FYZ96EC:&5N.@!7Y&AL96X@4VEE(&1A<R!:96ET9F]R;6%T
M.@!7Y&AL96X@4VEE('IW96D@>G5S86UM96YG96CV<FEG92!&96QD97(@875S
M+@!7Y&AL96X@4VEE(&5I;B!&87)B<V-H96UA+@!7Y&AL96X@4VEE($EH<F4@
M8F5V;W)Z=6=T92!3<')A8VAE.@!0<F]B;&5M8F5R:6-H="!A8G-C:&EC:V5N
M`%--4R!V97)S8VAI8VME;@!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!3
M97)B:65N('5N9"!-;VYT96YE9W)O`%-E<FEE;FYU;6UE<@!397)V97)D871E
M;B!U;F?\;'1I9R!O9&5R(&YI8VAT('9E<F;\9V)A<BX`4V5S<W-I;VYV97)W
M86QT=6YG`%-E<W-I;VXM240@86)G96QA=69E;BX`4VET>G5N9V5N`$%U<W=A
M:&PM4V%T>@!,96=E;B!3:64@9&EE($5I;G-T96QL=6YG96X@9F5S="P@9&EE
M(&5S($EH;F5N(&5R;&%U8F5N($EH<B!087-S=V]R="!Z=7+\8VMZ=7-E='IE
M;BP@9F%L;',@<VEE(&5S(&5I;FUA;"!V97)G97-S96X@<V]L;'1E;BX`3&5G
M96X@4VEE(&5N=&9E<FYT92!397)V97(@9F5S="P@875F(&1I92!3:64@=F]N
M($EH<F5M(%!O<G1A;"!A=7,@>G5G<F5I9F5N(&WV8VAT96XN`%?D:&QE;B!3
M:64@26AR92!B979O<GIU9W1E(%-P<F%C:&4L(%IE:71Z;VYE('5N9"!$871U
M;7-E:6YS=&5L;'5N9V5N+@!,96=E;B!3:64@9&%S(&1I92!3=&%R=&%N=V5N
M9'5N9RP@9&%S($9A<F)S8VAE;6$L(&1I92!396ET96YA:W1U86QI<VEE<G5N
M9R!U;F0@86YD97)E($%N>F5I9V5E:6YS=&5L;'5N9V5N(&9E<W0N`$MO;F9I
M9W5R871I;VX`06MT=6%L:7-I97)U;F=S<VMR:7!T92!S:6YD('9E<F;\9V)A
M<@!-96AR97)E('!A<W-E;F1E($]R=&4@;6ET(&1I97-E;2!087)A;65T97(Z
M(`!397EC:&5L;&5N`$5I;FMA=68`2W5R>F4@6G5S86UM96YF87-S=6YG`%-O
M;&QE;B!487-T96YK;VUB:6YA=&EO;F5N(&;\<B!D:64@;65I<W1E;B!,:6YK
M<R!A:W1I=FEE<G0@=V5R9&5N/P!:96EG96X`56YT97)S8VAI961E('IW:7-C
M:&5N(&1E<B!A:W1U96QL96X@=6YD(&1E<B!G97)A9&4@97)Z975G=&5N($MO
M;F9I9W5R871I;VX@86YZ96EG96XN`$%N>F5I9V5N+"!W86YN(&1I92!L971Z
M=&4@06YM96QD=6YG(&5R9F]L9W0@:7-T/P!%<FAA;'1E;B!D97,@3W)I9VEN
M86QS(&5R;?9G;&EC:&5N`$%U<W?D:&QE<B!A;GIE:6=E;@!797)K>F5U9VQE
M:7-T92!F_'(@5&%B96QL96X@86YZ96EG96X_`$1A<R`E<RU-96[\(&%U9B!D
M97(@;&EN:V5N(%-E:71E(&%N>F5I9V5N/P!$:6%L;V<@9OQR(%1A8F5L;&5N
M>F5L;&5N96EG96YS8VAA9G1E;B!A;GIE:6=E;@!$:6%L;V<@9OQR(%1A8F5L
M;&5N96EG96YS8VAA9G1E;B!A;GIE:6=E;@!$:6%L;V<@9OQR(%1A8F5L;&5N
M>F5I;&5N96EG96YS8VAA9G1E;B!A;GIE:6=E;@!$:6%L;V<@9OQR($)I;&1E
M:6=E;G-C:&%F=&5N(&%N>F5I9V5N`$AO8VAL861E;B!E<FWV9VQI8VAE;@!3
M8VAA=65R`$9R_&@@4V-H875E<@!3<.1T97(@4V-H875E<@!38VAA=65R(&EN
M(&1E<B!5;6=E8G5N9P!697)K;&5I;F5R;@!697)K;&5I;F5R;B!O9&5R('9E
M<G-C:&EE8F5N(%-I92!E<G-T(&1I92!B96YA8VAB87)T96X@0FSV8VME`%-I
M97)R82!,96]N90!296=I<W1R:65R96X`4VEG;F%T=7(`4VEG;F%T=7)A;&=O
M<FET:&UU<P!3:6YG87!U<@!'<O;?90!787)T=6YG<V%R8F5I=&5N(/QB97)S
M<')I;F=E;@!3;&]W86ME:0!3;&]W96YI96X`4V-H;F5E`%-C:&YE97-C:&%U
M97(`4V-H;F5E<V-H875E<@!&<OQH(%-C:&YE97-C:&%U97(`4W#D=&5R(%-C
M:&YE97-C:&%U97(`4V-H;F5E:/9H93H@`%-C:&YE96UE;F=E(&%L<R!787-S
M97(Z(`!3;VQO;6]N:6YS96QN`%-O;6%L:65N`$QI961E<B`F($=E9&EC:'1E
M`$%U<W=A:&P@9&5R(%-O<G1I97)R96EH96YF;VQG90!5<G-P<G5N9W-A9')E
M<W-E`%/\9&%F<FEK80!3_&1E=7)O<.1I<V-H("A)4T\M.#@U.2TS*0!3_&1G
M96]R9VEE;B!U;F0@9&EE(%/\9&QI8VAE;B!386YD=VEC:&EN<V5L;@!3_&1L
M:6-H92!(96UI<W!H97)E`$%B<W1A;F0@>G=I<V-H96X@875F96EN86YD97(@
M9F]L9V5N9&5N(%IE;&QE;@!!8G-T86YD('IW:7-C:&5N($EN:&%L="!U;F0@
M4F%H;65N('9O;B!:96QL96X`06)S=&%N9&AA;'1E<@!!8G-T86YD`$%B<W3D
M;F1E`%-P86YI96X`4W!A;0!3;VYD97)Z96EC:&5N+45I;F=A8F4`6F5L;&4@
M=&5I;&5N`%-P86QT92!T96EL96X`6F5I;&4@=&5I;&5N`%-P;W)T`%-R:2!,
M86YK80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G1J86AR`$)U;F1E<W-T86%T
M(&]D97(@4')O=FEN>@!3=&%T=7,`4W!E:6-H97)F;W)M870`4W1R8=]E`$1U
M<F-H9V5S=')I8VAE;@!:96EC:&5N;&ES=&4`1&]M86EN(&%U<R!D97(@061R
M97-S92!E;G1F97)N96X`4W1I;"!;0U-370!3;P!5;G1E<G9E<GIE:6-H;FES
M("(E<R(@;FEC:'0@9V5F=6YD96XN`$)E=')E9F8`06)S8VAI8VME;@!$:64@
M4F5G:7-T<FEE<G5N9W-A;F9R86=E(&;\<B`B)7,B('=U<F1E(&%B9V5S8VAI
M8VMT+B!3:64@:_9N;F5N('-I8V@@;F]C:"!N:6-H="!A;FUE;&1E;BP@<V]L
M86YG92!D:64@06YF<F%G92!N;V-H(&YI8VAT(&)E<W3D=&EG="!W=7)D92X`
M5&EE9F=E<W1E;&QT`$5R9F]L9P`B)7,B('=U<F1E(&5R9F]L9W)E:6-H(&AI
M;GIU9V5F_&=T+@!$871E;B!D97,@0F5N=71Z97)S("(E<R(@=W5R9&4@97)F
M;VQG<F5I8V@@9V5L]G-C:'0N`"(E<R(@=W5R9&4@97)F;VQG<F5I8V@@9V5L
M]G-C:'0N`"(E<R(@=W5R9&4@97)F;VQG<F5I8V@@9V5L]G-C:'0N`$MO;F9I
M9W5R871I;VX@97)F;VQG<F5I8V@@>G5R_&-K9V5S971Z="X@4V5I=&4@;F5U
M(&QA9&5N+"!U;2!D:64@Q&YD97)U;F=E;B!A;GIU>F5I9V5N+@!"86-K=7`@
M9&5R($MO;F9I9W5R871I;VX@97)F;VQG<F5I8V@@9V5S<&5I8VAE<G0N`$)A
M8VMU<"!D97(@2V]N9FEG=7)A=&EO;B`E<R!E<F9O;&=R96EC:"!G97-P96EC
M:&5R="X`(B5S(B!W=7)D92!E<F9O;&=R96EC:"!A:W1U86QI<VEE<G0`)7,@
M=W5R9&4@97)F;VQG<F5I8V@@9V5S<&5I8VAE<G0`4W5D86X`6G5S86UM96YF
M87-S=6YG`%-O;FYE;F%U9F=A;F<`4V]N;F5N=6YT97)G86YG`%-O;FYI9P!3
M;VYN96YA=69G86YG`%-O;FYE;F%U9B]U;G1E<F=A;F<`4V]N;F5N875F9V%N
M9SH@`%-O;FYE;G5N=&5R9V%N9P!3;VYN96YU;G1E<F=A;F<Z(`!(;V-H9V5S
M=&5L;'0`4W5P<&]R=`!3=7)I;F%M`$YA8VAN86UE`%-V86QB87)D('5N9"!*
M86X@36%Y96X`4W=A<VEL86YD`%-C:'=E9&5N`%-C:'=E:7H`4WEN8VAR;VYI
M>F%T:6]N<VQO9R!G96SV<V-H=`!&;W)M871F96AL97(@:6X@4W5C:&)E9W)I
M9F9E;@!!<F%B:7-C:&4@4F5P=6)L:6L@4WER:65N`$=E=VET=&5R`$=E=VET
M=&5R('5N9"!7:6YD:6<`1V5W:71T97(`1G+\:"!'97=I='1E<@!44U8M1&%T
M96D`5&%B96QL96YE:6=E;G-C:&%F=&5N`%1A8F5L;&4`5&%B96QL96YE:6=E
M;G-C:&%F=&5N`%1A:7=A;@!486EW86XL(&-H:6YE<VES8VAE(%!R;W9I;GH`
M5&%D<V-H:6MI<W1A;@!697)E:6YI9W1E(%)E<'5B;&EK(%1A;G-A;FEA`%II
M96PZ`$%U9F=A8F5N`%1E;&5F;VYN=6UM97(`5&5M<&5R871U<B!D97(@;&5T
M>G1E;B!3='5N9&4Z(`!496UP97)A='5R`%1E;7!E<F%T=7(Z(`!496UP97)A
M='5R/&)R("\^*"5S36%X)7,O)7--:6XE<RD@)F1E9SLE<P!6;W)L86=E("(E
M<R(@;FEC:'0@9V5F=6YD96XN`%9O<FQA9V5N=F5R=V%L='5N9P!497AT`$YU
M<B!497AT`$%U<W)I8VAT=6YG`%1E>'0@3V)E;@!$;P!4:&%I;.1N9&ES8V@@
M*%1)4RTV,C`I`%1H86EL86YD`$1I92!&5%`M17AT96YS:6]N(&ES="!N:6-H
M="!V97)F_&=B87(N`$1I92!#:')O;FEK('-T96AT(&YI8VAT('IU<B!697)F
M_&=U;F<N`$1I92!(;W)D92]+;VQA8B!);G1E9W)A=&EO;G-F=6YK=&EO;F5N
M('5N=&5R<W3\='IE;B`B)7,B(&YI8VAT`$1I92!)35-0+4QO9V1A=&5I(&MO
M;FYT92!N:6-H="!E<G-T96QL="!W97)D96XN`$1I92!-86EN=&5N86YC93HZ
M($ML87-S92!K;VYN=&4@;FEC:'0@9V5L861E;B!W97)D96X`1&%S($5I;G-T
M96QL=6YG96XM1F5N<W1E<B!I<W0@9V5S8VAL;W-S96X@=V]R9&5N+B!!8F)R
M=6-H+@!$97(@061M:6YI<W1R871O<B!M=7-S(&5I;B!P97)M86YE;G1E<R!2
M96-H=&4M0F%C:V5N9"!E:6YR:6-H=&5N+"!W96YN(%-I92!D:64@4F5C:'1E
M=F5R=V%L='5N9R!N=71Z96X@;?9C:'1E;BX`3G5R('5N=&5N`$1I92!)1"U.
M=6UM97(@9&5S($MO;G1A:W1S('=U<F1E(&YI8VAT(&%N9V5B96XL('=A<B!L
M965R(&]D97(@:V]N;G1E(&EN(&1E<B!$871E;F)A;FL@;FEC:'0@9V5F=6YD
M96X@=V5R9&5N+@!$97(@2V]N=&%K="!W=7)D92!E<F9O;&=R96EC:"!):')E
M;2!!9')E<W-B=6-H(&AI;GIU9V5F_&=T+@!$97(@4$=0+5-I9VYA='5R8FQO
M8VL@=VER9"!B96[V=&EG="P@=6T@9&EE('5N=&5R>F5I8VAN971E($YA8VAR
M:6-H="!Z=2#\8F5R<'+\9F5N+@!$:64@240M3G5M;65R(&1E<B!697)T96EL
M97)L:7-T92!W=7)D92!N:6-H="!A;F=E8F5N+"!W87(@;&5E<B!O9&5R(&MO
M;FYT92!I;B!D97(@1&%T96YB86YK(&YI8VAT(&=E9G5N9&5N('=E<F1E;BX`
M1&EE(%9E<G1E:6QE<FQI<W1E('=U<F1E(&YI8VAT(&%N9V5G96)E;BX`1&EE
M(%9E<G-C:&S\<W-E;'5N9W-F=6YK=&EO;F5N(&)E;O9T:6=E;B!E:6YE('-I
M8VAE<F4@4V5R=F5R=F5R8FEN9'5N9RX`1&EE($1A=&5I("5S('-O;&QT92!E
M:6YE;B`E<R!%:6YT<F%G(&5N=&AA;'1E;BX`1&EE($1A=&5I("5S('-O;&QT
M92!E:6YI9V4@)7,@16EN='+D9V4@96YT:&%L=&5N+@!$:64@1&%T96D@96YT
M:&EE;'0@:V5I;F4@1&%T96XN`$AI97(@<VEN9"!D:64@2V]P9F5I;G1RY&=E
M(&;\<B!D:65S92!M97-S86=E+W)F8S@R,B!.86-H<FEC:'0N`$1E<B!6;VQL
M8FEL9&UO9'5S('9E<G5R<V%C:'0@875F($=R=6YD('9O;B!&96AL97)N(&EM
M($EN=&5R;F5T($5X<&QO<F5R(&)E:V%N;G1E<FUAWV5N(%!R;V)L96UE(&UI
M="!D:65S96T@0G)O=W-E<BP@9&EE('=I<B!N:6-H="!U;6=E:&5N(&OV;FYE
M;BX@56YT97(@56US=.1N9&5N(&5R:&%L=&5N(%-I92!E:6YE(&9E:&QE<FAA
M9G1E($%N>F5I9V4L(&9E:&QE;B!%9&ET;W)F=6YK=&EO;F5N+"!O9&5R(&1E
M<B!"<F]W<V5R('-T_')Z="!A8BX@075F(&5I;F5M(%=I;F1O=R`Y>"!3>7-T
M96T@=V5R9&5N(%-I92!V97)M=71L:6-H(&5I;F4@)T%L;&=E;65I;F4@4V-H
M=71Z=F5R;&5T>G5N9R<@97)H86QT96X@=6YD(&W\<W-E;B!D96X@4F5C:&YE
M<B!N974@<W1A<G1E;BY<;EQN4VEE('=U<F1E;B!G97=A<FYT+B!":71T92!D
M<OQC:V5N(%-I92!A=68@3TLL('=E;FX@4VEE(&YO8V@@:6UM97(@9&5N(%9O
M;&QB:6QD;6]D=7,@=F5R=V5N9&5N(&WV8VAT96XN`$1I92!)9&5N=&ETY'0@
M(B5S(B!W=7)D92!G96SV<V-H="X`3G5R(&QI;FMS`$1E<B!/<G0@9&5S($=N
M=5!'+5!R;V=R86UM<R!M=7-S(&1E<B!#<GEP=%]P9W`Z.B!+;&%S<V4@_&)E
M<F=E8F5N('=E<F1E;BX`1&EE($YA8VAR:6-H="!M:70@9&5M($)E=')E9F8@
M(B4S)',B+"!D:64@86T@)3$D<R!A;B`E,B1S(&=E<V-H:6-K="!W=7)D92P@
M:7-T(&%N9V5Z96EG="!W;W)D96XN"D1A<R!H96G?="!N:6-H="P@9&%S<R!D
M:64@3F%C:')I8VAT(&%U8V@@9V5L97-E;B!O9&5R('9E<G-T86YD96X@=W5R
M9&4N`$YA;64@9OQR(&1E;B!,:6YK('IU<B!.86-H<FEC:'1E;F5R<W1E;&QU
M;F<`1&EE($%N>F%H;"!D97(@1F5L9&5R(&UU<W,@86QS(%IA:&P@86YG96=E
M8F5N('=E<F1E;BX`1&%S($]P96Y34TPM36]D=6P@=VER9"!F_'(@9&EE($AO
M<F1E7T-R>7!T7W-M:6UE.CH@2VQA<W-E(&)E;O9T:6=T+@!$:64@0F5N=71Z
M97)E:6YS=&5L;'5N9R`B)7,B(&MO;FYT92!N:6-H="!G97-P96EC:&5R="!W
M97)D96XL('=E:6P@:6AR92!$871E;B!D:64@;6%X:6UA;"!E<FQA=6)T92!'
M<O;?92#\8F5R<V-H<F5I=&5N`$1A<R!0<F]G<F%M;2!F_'(@9&EE($%N>F5I
M9V4@9&EE<V5S($1A=&5I='EP<R`H)7,I('=U<F1E(&YI8VAT(&=E9G5N9&5N
M+@!$87,@06YF_&AR=6YG<WIE:6-H96X@;75S<R!A;',@96EN>F5L;F5S(%IE
M:6-H96X@86YG96=E8F5N('=E<F1E;BX`3G5R(&QI;FMS('5N9"!R96-H=',`
M3G5R(')E8VAT<P!$87,@5')E;FYZ96EC:&5N(&UU<W,@86QS(&5I;GIE;&YE
M<R!:96EC:&5N(&%N9V5G96)E;B!W97)D96XN`$1E<B!397)V97(@(B5S(B!W
M=7)D92!E;G1F97)N="X`1&5R(%-E<G9E<B`B)7,B('=U<F1E(&=E<W!E:6-H
M97)T+@!$:64@4F5G:7-T<FEE<G5N9W-A;F9R86=E('9O;B`E<R!W=7)D92!E
M;G1F97)N="X`1&EE(&%N9V5G96)E;F4@6F5I;&4@*"5D*2!E>&ES=&EE<G0@
M;FEC:'0N`$1I92!T96UP;W+D<F4@1&%T96D@(B5S(B!E>&ES=&EE<G0@;FEC
M:'0N`$1E<B!497AT+"!D96X@4VEE(&%N9V5G96)E;B!H86)E;BP@96YT<W!R
M:6-H="!N:6-H="!D96T@5&5X="!A=68@9&5M($)I;&1S8VAI<FTN`$YU<B!O
M8F5N('5N9"!U;G1E;@!.=7(@;V)E;@!$:64@:&]C:&=E;&%D96YE;B!$871E
M;B!S:6YD(&YA8V@@9&5M(&QE='IT96X@4V-H<FET="!V97)L;W)E;B!G96=A
M;F=E;BX`1&EE(&AO8VAG96QA9&5N92!$871E:2!K;VYN=&4@;FEC:'0@9V5S
M<&5I8VAE<G0@=V5R9&5N+@!$97(@=V5A=&AE<BYC;VT@0FQO8VL@:7-T(&YI
M8VAT('9E<F;\9V)A<BX`5&AE;65N+59E<GIE:6-H;FES("(E<R(@;FEC:'0@
M9V5F=6YD96XN`$5S('-I;F0@:V5I;F4@16EN<W1E;&QU;F=E;B!V97)F_&=B
M87(N`$5S(&=I8G0@:V5I;F4@86YZ96EG8F%R96X@3F%C:')I8VAT96YT96EL
M92X`1&EE<V5S($9E;&0@96YT:.1L="!Z=2!V:65L92!:96EC:&5N+B!3:64@
M:&%B96X@)7,@6F5I8VAE;B!A;F=E9V5B96X[(%-I92!M_'-S96X@=V5N:6=E
M<B!A;',@)7,@86YG96)E;BX`0F5I;2!(:6YZ=6;\9V5N('9O;B`B)7,B('IU
M;2!3>7-T96T@:7-T(&5I;B!0<F]B;&5M(&%U9F=E=')E=&5N.B`E<P!"96EM
M($SV<V-H96X@9&5R($1A=&5N('9O;B!"96YU='IE<B`B)7,B(&ES="!E:6X@
M4')O8FQE;2!A=69G971R971E;CH@`$)E:6T@3/9S8VAE;B!V;VX@(B5S(B!A
M=7,@9&5M(%-Y<W1E;2!I<W0@96EN(%!R;V)L96T@875F9V5T<F5T96XZ(`!"
M96EM($%K='5A;&ES:65R96X@=F]N("(E<R(@:7-T(&5I;B!0<F]B;&5M(&%U
M9F=E=')E=&5N.B`E<P!"96EM($AO8VAL861E;B!D97(@1&%T96D@:7-T(&5I
M;B!&96AL97(@875F9V5T<F5T96XN("5S('=U<F1E(&YI8VAT(&AO8VAG96QA
M9&5N+@!"96EM($AO8VAL861E;B!D97(@1&%T96D@:7-T(&5I;B!&96AL97(@
M875F9V5T<F5T96XN("5S('=A<B!G<O;?97(@86QS(&1I92!M87AI;6%L(&5R
M;&%U8G1E($=R]M]E("@E9"!">71E<RDN`$)E:6T@2&]C:&QA9&5N(&1E<B!$
M871E:2!I<W0@96EN($9E:&QE<B!A=69G971R971E;BX@)7,@=W5R9&4@;G5R
M('1E:6QW96ES92!H;V-H9V5L861E;BX`0F5I;2!!;GIE:6=E;B!D:65S97,@
M3F%C:')I8VAT96YT96EL<R!I<W0@96EN($9E:&QE<B!A=69G971R971E;BX`
M0F5I;2!);7!O<G1I97)E;B!D97(@2V]N=&%K=&1A=&5N(&ES="!E:6X@1F5H
M;&5R(&%U9F=E=')E=&5N+@!"96EM($EM<&]R=&EE<F5N(&1E<B!I0V%L96YD
M87(@1&%T96X@:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XN`$1A<R!+;VYF
M:6=U<F%T:6]N<RU&;W)M=6QA<B!E;G1H:65L="!E:6YE;B!&96AL97(N(%9I
M96QL96EC:'0@:&%B96X@4VEE(&5I;B!09FQI8VAT9F5L9"!L965R(&=E;&%S
M<V5N+@!"96EM($%U<V;\:')E;B!D97(@86YG96=E8F5N96X@061R97-S8G5C
M:&9U;FMT:6]N(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+B!":71T92!V
M97)S=6-H96X@4VEE(&5S('-PY'1E<B!N;V-H(&5I;FUA;"X`0F5I(&1E<B!!
M:W1U86QI<VEE<G5N9R!D97(@2V]N=&%K=&1E=&%I;',@:7-T(&5I;B!&96AL
M97(@875F9V5T<F5T96XN($)I='1E('9E<G-U8VAE;B!3:64@97,@<W#D=&5R
M(&YO8V@@96EN;6%L+@!"96D@9&5R($%K='5A;&ES:65R=6YG(&1E<B!697)T
M96EL97)L:7-T92!I<W0@96EN($9E:&QE<B!A=69G971R971E;BX@0FET=&4@
M=F5R<W5C:&5N(%-I92!E<R!S<.1T97(@;F]C:"!E:6YM86PN`$1I97-E<B!)
M34%0+5-E<G9E<B!U;G1E<G-T_'1Z="!K96EN92!G96UE:6YS86UE;B!/<F1N
M97(N`$1I97,@<V-H96EN="!K96EN(&?\;'1I9V5S(%)!4BU!<F-H:78@>G4@
M<V5I;BX`1&EE<R!S8VAE:6YT(&ME:6X@9_QL=&EG97,@6DE0+4%R8VAI=B!Z
M=2!S96EN+@!$:65S('-C:&5I;G0@:V5I;F4@9_QL=&EG92!+87)T96YN=6UM
M97(@>G4@<V5I;BX`1&EE<V5R(%1R96EB97(@97)L875B="!D87,@5F5R<V-H
M:6-K96X@=F]N($YA8VAR:6-H=&5N(&1U<F-H(&1E;B!#;&EC:V%T96QL+4=A
M=&5W87D@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@;6ET($AI;&9E(&1E<B!(
M5%10+4%022X`1&EE<V5R(%1R96EB97(@97)L875B="!D87,@5F5R<V-H:6-K
M96X@=F]N($YA8VAR:6-H=&5N(&1U<F-H(&1E;B!724XM1V%T97=A>2`H:'1T
M<#HO+W=I;G!L8RYC;VTI(&UI="!(:6QF92!D97(@2%144"U!4$DN`$1I97-E
M<B!4<F5I8F5R(&5R;&%U8G0@9&%S(%9E<G-C:&EC:V5N('9O;B!.86-H<FEC
M:'1E;B!D=7)C:"!D96X@<VUS,FUA:6PM1V%T97=A>2`H:'1T<#HO+W-M<S)M
M86EL+F-O;2D@;6ET($AI;&9E(&1E<B!(5%10+4%022X`1&EE<V5R(%1R96EB
M97(@97)L875B="!D87,@5F5R<V-H:6-K96X@=F]N($YA8VAR:6-H=&5N('!E
M<B!33510(&1U<F-H(&1E;B!6;V1A9F]N92U)=&%L:65N+4=A=&5W87D@875S
M<V-H;&EEWVQI8V@@86X@5F]D869O;F4M3G5M;65R;BX@1&%F_'(@=VER9"!E
M:6X@12U-86EL+4MO;G1O(&)E:2!6;V1A9F]N92!)=&%L:65N("AH='1P.B\O
M=W=W+C$Y,"YI="D@8F5N]G1I9W0N`$1I97-E<R!&96QD(&ES="!N;W1W96YD
M:6<N`$1I97-E<R!&96QD(&1A<F8@;G5R(&=A;GIE(%IA:&QE;B!E;G1H86QT
M96XN`$1I97-E<R!&96QD(&1A<F8@;G5R(%IA:&QE;B!U;F0@96EN96X@4'5N
M:W0@96YT:&%L=&5N+@!$:65S97,@1F5L9"!D87)F(&YU<B!/:W1A;'IA:&QE
M;B!E;G1H86QT96XN`$1I97-E<R!&96QD(&UU<W,@96EN92!K;VUM82T@;V1E
M<B!L965R>F5I8VAE;F=E=')E;FYT92!,:7-T92!V;VX@9V%N>F5N(%IA:&QE
M;B!E;G1H86QT96X`1&EE<V5S($9E;&0@;75S<R!E:6YE(&?\;'1I9V4@6F%H
M;"!E;G1H86QT96XN`$1I97-E<R!&96QD(&UU<W,@96EN96X@1F%R8G=E<G0@
M:6T@:&5X861E>FEM86QE;B!21T(M1F]R;6%T(&5N=&AA;'1E;BP@>BX@0BX@
M)R,Q,C,T868G+@!$:65S97,@1F]R;75L87(@=W5R9&4@8F5R96ET<R!V97)A
M<F)E:71E="X`1&EE<R!I<W0@)7,N`$1I92!I<W0@96EN($MO;&%B+4=R;W5P
M=V%R92U/8FIE:W0N(%5M(&1I97-E<R!/8FIE:W0@86YZ=7IE:6=E;BP@8F5N
M]G1I9V5N(%-I92!E:6X@12U-86EL+5!R;V=R86UM+"!D87,@9&%S($MO;&%B
M+4=R;W5P=V%R92U&;W)M870@=6YT97)S=/QT>G0N($5I;F4@3&ES=&4@<V]L
M8VAE<B!0<F]G<F%M;64@9FEN9&5N(%-I92!U;G1E<B`E<P!$:65S92!.86-H
M<FEC:'0@=W5R9&4@:6X@96EN96T@6F5I8VAE;G-A='H@*"5S*2!E<G-T96QL
M="P@9&5R(&YI8VAT($EH<F5M(&5I9V5N96X@96YT<W!R:6-H="X`1&EE<V4@
M6F%H;"!M=7-S(#$@;V1E<B!G<O;?97(@<V5I;BX`1&EE<V5R(%-E<G9E<B!K
M86YN(%I)4"T@=6YD($=:25`M1&%T96EN(&YI8VAT(&5N='!A8VME;BX`1&EE
M<V5S(%-Y<W1E;2!I<W0@>G5R(%IE:70@9&5A:W1I=FEE<G0N`$1I97-E<B!7
M97)T(&UU<W,@96EN92!:86AL('-E:6XN`$1I97-E<R!&96YS=&5R(&UU<W,@
M=F]N(&5I;F5M($5I;G-T96QL=6YG96XM1F5N<W1E<B!G9?9F9FYE="!W97)D
M96X`1&]N;F5R`%1I8VME=',`6F5I=`!:96ET97)F87-S=6YG`%IE:71F;W)M
M870`6F5I=&%U<W=A:&P`5&EM;W(M3&5S=&4`5&ET96P`5&ET96P@*%1O;VQT
M:7`I.@!!;@!(86QT96X@4VEE(&)E:6T@2VQI8VME;B!3=')G(&)Z=RX@*%!#
M*2!#;VUM86YD("A-86,I(&=E9'+\8VMT+"!U;2!M96AR97)E($5I;G1RY&=E
M(&%U<WIU=^1H;&5N+@!(975T90!:=2!(5$U,+5%U96QL8V]D92!U;7-C:&%L
M=&5N`%1O9V\`5&]K96QA=0!-;W)G96X`5&]N9V$`6G4@=FEE;&4@=6YG_&QT
M:6=E($%N;65L9&5V97)S=6-H92!I;B!D96X@;&5T>G1E;B!-:6YU=&5N+@!/
M8F5N`,1UWV5R<W1E<B!286AM96X@*%]T;W`I`-QB97)S971Z=6YG96X`5')I
M;FED860@=6YD(%1O8F%G;P!786AR(&]D97(@9F%L<V-H`$1I`%1U;F5S:65N
M`%3\<FME:0!4_')K:7-C:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U
M<FMS+2!U;F0@0V%I8V]S:6YS96QN`%1U=F%L=0!):')E($%U<W=A:&PZ(`!5
M5BU);F1E>#H@`$AO;65P86=E`%523"!):')E<R!3:W)I<'1S(&;\<B!D96X@
M5F5R<V%N9'-T871U<V)E<FEC:'0`061R97-S93H`56=A;F1A`%5K<F%I;F4`
M075F(&1A<R!61E,M5F5R>F5I8VAN:7,@:V]N;G1E(&YI8VAT('IU9V5G<FEF
M9F5N('=E<F1E;BX`1&EE('IU<^1T>FQI8VAE;B!"96YU='IE<FEN9F]R;6%T
M:6]N96X@:V]N;G1E;B!B96D@9&5R(%)E9VES=')I97)U;F<@;FEC:'0@:&EN
M>G5F_&=T('=E<F1E;BX`1&EE(%IU9W)I9F9S<F5C:'1E(&;\<B!D:64@5D93
M+41A=&5I("(E<R(@:V]N;G1E;B!N:6-H="!G9>1N9&5R="!W97)D96XN`$1I
M92!:=6=R:69F<W)E8VAT92!F_'(@9&EE(%9&4RU$871E:2`E<R\E<R!K;VYN
M=&5N(&YI8VAT(&=EY&YD97)T('=E<F1E;BX`17,@:V%N;B!N:6-H="!I;B!6
M97)Z96EC:&YI<R`E<R!G97=E8VAS96QT('=E<F1E;BX`1&EE($=R]M]E('9O
M;B`B)7,B(&MO;FYT92!N:6-H="!B97-T:6UM="!W97)D96XN`$1I92!'<O;?
M92!V;VX@(B5S+R5S(B!K;VYN=&4@;FEC:'0@8F5S=&EM;70@=V5R9&5N+@!6
M97)B:6YD=6YG('IU;2!344P@4V5R=F5R(&MA;FX@;FEC:'0@:&5R9V5S=&5L
M;'0@=V5R9&5N+@!34TPM5F5R8FEN9'5N9R!K;VYN=&4@;FEC:'0@:&5R9V5S
M=&5L;'0@=V5R9&5N+@!$:64@5D93+41A=&5I(&MO;FYT92!N:6-H="!K;W!I
M97)T('=E<F1E;BX`1&%S(%9&4RU697)Z96EC:&YI<R`B)7,B(&MO;FYT92!N
M:6-H="!A;F=E;&5G="!W97)D96XN`$1A<R!61E,M5F5R>F5I8VAN:7,@:V]N
M;G1E(&YI8VAT(&%N9V5L96=T('=E<F1E;BX`1&EE(%9&4RU$871E:2!K;VYN
M=&4@;FEC:'0@86YG96QE9W0@=V5R9&5N+@!$87,@5D93+59E<GIE:6-H;FES
M("(E<R(@:V]N;G1E(&YI8VAT(&%N9V5L96=T('=E<F1E;BX`3&5E<F4@5D93
M+41A=&5I(&MO;FYT92!N:6-H="!A;F=E;&5G="!W97)D96XN`$1I92!$871E
M;B!K;VYN=&5N(&YI8VAT(&1E:V]M<')I;6EE<G0@=V5R9&5N+@`B)7,B(&MO
M;FYT92!N:6-H="!G96SV<V-H="!W97)D96XL(&1A<R!697)Z96EC:&YI<R!I
M<W0@;FEC:'0@;&5E<BX`(B5S(B!K86YN(&YI8VAT(&=E;/9S8VAT('=E<F1E
M;CH@)7,N`"5S(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XL(&1A<R!6
M97)Z96EC:&YI<R!I<W0@;FEC:'0@;&5E<@!$87,@5D93+59E<GIE:6-H;FES
M(&MO;FYT92!N:6-H="!R96MU<G-I=B!G96SV<V-H="!W97)D96XN`$1A<R!6
M1E,M5F5R>F5I8VAN:7,@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;BX`
M1&%S(%9&4RU697)Z96EC:&YI<R!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R
M9&5N.B`E<RX`1&EE(%9&4RU$871E:2`B)7,B(&MO;FYT92!N:6-H="!G96SV
M<V-H="!W97)D96XN`$1I92!61E,M1&%T96D@:V]N;G1E(&YI8VAT(&=E;/9S
M8VAT('=E<F1E;BX`1&%S(%9&4RU697)Z96EC:&YI<R`B)7,B(&MO;FYT92!N
M:6-H="!G96SV<V-H="!W97)D96XN`$1A<R!61E,@:V]N;G1E(&YI8VAT(')E
M:W5R<VEV(&=E;/9S8VAT('=E<F1E;CH@)7,N`$1A<R!A:W1U96QL92!697)Z
M96EC:&YI<R!K;VYN=&4@;FEC:'0@8F5S=&EM;70@=V5R9&5N+@!$:64@6F5R
M=&EF:6MA=&1E=&%I;',@:V]N;G1E;B!N:6-H="!A=7-G96QE<V5N('=E<F1E
M;@!$97(@)7,M5')E:6)E<B!K;VYN=&4@;FEC:'0@9V5L861E;B!W97)D96XN
M`$1I92!61E,M1&%T96D@:V]N;G1E(&YI8VAT('9E<G-C:&]B96X@=V5R9&5N
M+@!$:64@5D93+41A=&5I("(E<R(@:V]N;G1E(&YI8VAT(&=E]F9F;F5T('=E
M<F1E;BX`1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@>G5M($)E<V-H<F5I
M8F5N(&=E]F9F;F5T('=E<F1E;BX`1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC
M:'0@9V7V9F9N970@=V5R9&5N+@!$87,@07)C:&EV(&MO;FYT92!N:6-H="!G
M9?9F9FYE="!W97)D96XN`$1I92!61E,M1&%T96D@:V]N;G1E(&YI8VAT(&=E
M;&5S96X@=V5R9&5N("AF:6QE<VEZ92@I(&9E:&QG97-C:&QA9V5N*2X`1&EE
M(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@9V5L97-E;B!W97)D96X@*'-I>F4H
M*2!F96AL9V5S8VAL86=E;BDN`$1I92!$871E:2!K;VYN=&4@;FEC:'0@9V5L
M97-E;B!W97)D96XZ(`!$87,@=F9S<F]O="U697)Z96EC:&YI<R!K;VYN=&4@
M;FEC:'0@9V5L97-E;B!W97)D96XN`"5S(&MO;FYT92!N:6-H="!N86-H("5S
M('5M8F5N86YN="!W97)D96XZ($1A<R!::65L=F5R>F5I8VAN:7,@97AI<W1I
M97)T(&)E<F5I=',`1&%S(%9&4RU697)Z96EC:&YI<R!K;VYN=&4@;FEC:'0@
M=6UB96YA;FYT('=E<F1E;BX`1&%S(%9&4RU697)Z96EC:&YI<R!K;VYN=&4@
M;FEC:'0@=6UB96YA;FYT('=E<F1E;CH@)7,N`$1I92!61E,M1&%T96D@(B5S
M(B!K;VYN=&4@;FEC:'0@=6UB96YA;FYT('=E<F1E;BX`1&EE(%9&4RU$871E
M:2`E<R\E<R!K;VYN=&4@;FEC:'0@=6UB96YA;FYT('=E<F1E;BX`1&EE(%9&
M4RU$871E:2!K;VYN=&4@;FEC:'0@=6UB96YA;FYT('=E<F1E;BX`(FUK:7-O
M9G,B(&MO;FYT92!N:6-H="!A=7-G96;\:')T('=E<F1E;BX`1&EE<V5S(%=O
M<F0M1&]K=6UE;G0@;.1S<W0@<VEC:"!N:6-H="!A;GIE:6=E;@!$:64@1G)E
M:2]'96)U8VAT+4EN9F]R;6%T:6]N96X@9OQR("5S(&MO;FYT96X@;FEC:'0@
M86MT=6%L:7-I97)T('=E<F1E;@!$:64@5D93+41A=&5I("(E<R(@:V]N;G1E
M(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E;BX`1&EE(%9&4RU$871E:2!K;VYN
M=&4@;FEC:'0@9V5S8VAR:65B96X@=V5R9&5N("AC;W!Y*"D@9F5H;&=E<V-H
M;&%G96XI+@!$:64@5D93+41A=&5N(&MO;FYT96X@;FEC:'0@9V5S8VAR:65B
M96X@=V5R9&5N+@!$:64@5D93+41A=&5I(&MO;FYT92!N:6-H="!G97-C:')I
M96)E;B!W97)D96XL(&1A<R!3<&5I8VAE<G!L871Z+4MO;G1I;F=E;G0@=_QR
M9&4@_&)E<G-C:')I='1E;BX`56YT97)S=')I8VAE;@#$;F1E<G5N9V5N('+\
M8VMGY&YG:6<@;6%C:&5N`$UA8VAT(&1I92!L971Z=&4@06MT:6]N('+\8VMG
MY&YG:6<`56YG_&QT:6=E(%+\8VMM96QD=6YG('9O;2!397)V97(@8F5I;2!(
M97)S=&5L;&5N(&1E<B!697)B:6YD=6YG.B``56YE<G=A<G1E=&4@06YT=V]R
M="!D97,@4V5R=F5R<R!A=68Z(`!.:6-H="!Z=6=E;W)D;F5T`%5N:6-O9&4@
M*%541BTX*0!697)E:6YI9W1E($%R86)I<V-H92!%;6ER871E`%9E<F5I;FEG
M=&5S($OV;FEG<F5I8V@`5F5R96EN:6=T92!3=&%A=&5N`$ML96EN97)E($%M
M97)I:V%N:7-C:&4@W&)E<G-E96EN<V5L;@!%:6YH96ET96X`56YB96MA;FYT
M`%5N8F5K86YN=&4@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`56YB96MA
M;FYT92!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!%<R!W=7)D92!E
M:6X@=6YB96MA;FYT97(@3W)T(&%N9V5G96)E;BX`56YB96MA;FYT97(@0F5N
M=71Z97)N86UE(&]D97(@4&%S<W=O<G0N`$QI;FL@=F]M(&%K='5E;&QE;B!%
M;&5M96YT(&5N=&9E<FYE;@!5;F)E;F%N;G0`075S(%-I8VAE<FAE:71S9W+\
M;F1E;B!D_')F96X@=6YA=71O<FES:65R=&4@4VMR:7!T92!N:6-H="!A=7-C
M:&YE:61E;BP@:V]P:65R96X@=6YD(&5I;F;\9V5N+B!+;&EC:V5N(%-I92!A
M=68@3TLL('5M(&5I;F5N($AI;G=E:7,@875F(&UO>FEL;&$N;W)G(&%N9V5Z
M96EG="!Z=2!B96MO;6UE;BP@9&5R(&)E<V-H<F5I8G0L('=I92!3:64@96EN
M96T@4VMR:7!T(&1E;B!:=6=R:69F(&%U9B!D:64@6G=I<V-H96YA8FQA9V4@
M97)L875B96X@:_9N;F5N+@!&87)B92!Z=7+\8VMS971Z96X`17)W96ET97)U
M;F<@;FEC:'0@=6YT97)S=/QT>G0`06MT=6%L:7-I97)U;F<`)7,@86MT=6%L
M:7-I97)E;@!"96YU='IE<B!A:W1U86QI<VEE<F5N`"(E<R(@=W5R9&4@86MT
M=6%L:7-I97)T+@!!:W1U86QI<VEE<G5N9W-S:W)I<'0@9V5L]G-C:'0N`$AO
M8VAL861E;@!$:64@2V]N9FEG=7)A=&EO;G-D871E:65N(&%L;&5R($%N=V5N
M9'5N9V5N('=U<F1E;B!A=68@9&5N(%-E<G9E<B!H;V-H9V5L861E;BX`1W(N
M(&QA=&5I;FES8VAE($)U8VAS=&%B96X`1W(N('+V;6ES8VAE(%IA:&QE;@!5
M<G5G=6%Y`$%K='5E;&QE(&)E;G5T>F5N.B`E<P!34TP@8F5N=71Z96X`0FET
M=&4@875S9OQL;&5N+"!W96YN(%-I92!E:6YE;B!A;F1E<F5N($)E;G5T>F5R
M;F%M96XO4&%S<W=O<G0@9OQR(&1E;B!)35-0+5-E<G9E<B!H86)E;BX`0F5N
M=71Z97(`0F5N=71Z97(@)7,@:7-T(&;\<B`E<R!N:6-H="!A=71O<FES:65R
M="X`0F5N=71Z97)V97)W86QT=6YG`$)E;G5T>F5R96EN<W1E;&QU;F=E;@!"
M96YU='IE<G)E9VES=')I97)U;F<`1&EE($)E;G5T>F5R<F5G:7-T<FEE<G5N
M9R!W=7)D92!A=68@9&EE<V5M(%-Y<W1E;2!D96%K=&EV:65R="X`0F5N=71Z
M97)K;VYT;R!N:6-H="!G969U;F1E;@!"96YU='IE<FYA;64`1&5R($)E;G5T
M>F5R;F%M92`B)7,B(&5X:7-T:65R="!B97)E:71S+@!"96YU='IE<FYA;64Z
M`$)E;G5T>F5R;F%M93H@`$)E;G5T>F5R(&1E<R!3>7-T96US.@!5<V)E:VES
M=&%N`$1A<R!61E,M5F5R>F5I8VAN:7,@97AI<W1I97)T(&YI8VAT+@!!8G=E
M<V5N:&5I=`!087-S96YD92!G969U;F1E;F4@3W)T93H@`$?\;'1I9VME:70`
M5V5R="!I;B!-:6YU=&5N('9O;B!J971Z="!A;BX`1&5R(%=E<G0@:7-T(/QB
M97(@9&5R(&UA>&EM86QE;B!,Y&YG92!V;VX@)7,N`%=E<G1E`%=E<G1E+"!A
M=7,@9&5N96X@875S9V5WY&AL="!W97)D96X@:V%N;@!686YU871U`$1R96AE
M;F0`5F5N97IU96QA`-QB97)P<OQF=6YG(&9E:&QG97-C:&QA9V5N("T@9&EE
M<V4@3F%C:')I8VAT(&OV;FYT92!M86YI<'5L:65R="!W;W)D96X@<V5I;BX`
M5F5R<VEO;@!697)S:6]N<VMO;G1R;VQL90!!=7-R:6-H='5N9P!697)T:6MA
M;&5R($EN;F5N86)S=&%N9`!697)T:6MA;#H`4V5H<B!(;V-H`%9I971N86T`
M5FEE=&YA;65S:7-C:"`H5DE30TE)*0`E<R!A;GIE:6=E;@!%:6YE(&5X=&5R
M;F4@5V5B<V5I=&4@86YZ96EG96X`06YZ96EG96X@86QS("5S`$)R:71I<V-H
M92!*=6YG9F5R;FEN<V5L;@!!;65R:6MA;FES8VAE($IU;F=F97)N:6YS96QN
M`%-I8VAT`%-I8VAT.B``5F]D869O;F4@271A;&EE;B!P97(@4TU44`!705).
M54Y'`%=!4DY53D<A(2$@3-930TA%3B!3244@1$%3(%-+4DE05"!-04Y514Q,
M($%54R`E<RX`5TE.(/QB97(@2%144`!786QL:7,@=6YD($9U='5N80!787)N
M=6YG`$UI`%=E='1E<G9O<FAE<G-A9V4`5V5T=&5R9&%T96X@=F]N`%=E871H
M97(N8V]M`%=E8@!796)S:71E`%?V8VAE;G1L:6-H`%=I;&QK;VUM96X`5VEL
M;&MO;6UE;B!B96D@)7,`5VEL;&MO;6UE;BP@)7,`5V5S=&5U<F]PY&ES8V@@
M*$E33RTX.#4Y+3$I`%=E<W1E=7)O<.1I<V-H("A)4T\M.#@U.2TQ-2D`5V5S
M='-A:&%R80!796QC:&4@06YW96YD=6YG('-O;&P@)7,@;F%C:"!D96T@06YM
M96QD96X@86YG97IE:6=E;C\`5V5L8VAE<R!4<F5N;GIE:6-H96X@=VER9"!V
M97)W96YD970_`%=E;&-H92!!;F;\:')U;F=S>F5I8VAE;B!W97)D96X@=F5R
M=V5N9&5T/P!7:&5R96ES+4%U<W1R86QI82U+87)T90!796QC:&4@4&AA<V5N
M`%=E;&-H92!0;'5G:6YS(&;\<B!D96X@5UE325=91RU%9&ET;W(@<V]L;&5N
M(&%K=&EV:65R="!W97)D96X_`$)R96ET90!"<F5I=&4@:6X@0U-3+45I;FAE
M:71E;@!"<F5I=&4@9&5S("5S+4UE;OQS(&QI;FMS("AW:7)K<V%M(&YA8V@@
M9&5R(&[D8VAS=&5N($%N;65L9'5N9RDZ`%1A8F5L;&5N8G)E:71E`$5I;FAE
M:70`0G)E:71E.@!7:6MI`%=I;F0`1G+\:"!7:6YD`%=I;F1G97-C:'=I;F1I
M9W1K96ET(&EN($MN;W1E;@!7:6YD.@!7:6YD.B``5V5I<VAE:70`5W5N<V-H
M>F5T=&5L`$%R8F5I=`!!9')E<W-E(&=E<V-HY&9T;&EC:`!496QE9F]N(&=E
M<V-HY&9T;&EC:`!&86QS8VAE($%N>F%H;"!A;B!&96QD97)N(&EN(%IE:6QE
M("5D+B`E9"!E<G=A<G1E="P@)60@9V5F=6YD96XN`$9A;'-C:&4@06YZ86AL
M(&%N($9E;&1E<FXN("5D(&5R=V%R=&5T+"`E9"!G969U;F1E;BX`56YG_&QT
M:6=E<B!/9F9S970@)60@8F5I;2!,97-E;B!D97(@5D93+41A=&5I+@!1=65R
M=F5R=V5I<V4`6#4P.78S($=E;F5R96QL92!%:6YS8VARY&YK=6YG`%@U,#EV
M,R!%<G=E:71E<G1E<B!38VAL_'-S96QZ=V5C:P!8-3`Y=C,@06QT97)N871I
M=F5R($YA;64@9&5S(%IE<G1I9FEK871I;FAA8F5R<P!8-3`Y=C,@261E;G1I
M=.1T(&1E<R!:97)T:69I:V%T<V-H;/QS<V5L<P!8-3`Y=C,@17)W96ET97)U
M;F=E;@!*2@!*2DI*`%EA:&]O(2!+87)T90!*Y&AR;&EC:`!*96UE;@!*80!*
M82P@:6-H('-T:6UM92!Z=0!3:64@8F5F:6YD96X@<VEC:"!I;2!497AT;6]D
M=7,N($)E;G5T>F5N(%-I92!D96X@6SP^72!+;F]P9BP@=6T@:6X@9&5N(%=9
M4TE724<M36]D=7,@>G4@=V5C:'-E;&XN`%-I92!D_')F96X@;FEC:'0@;65H
M<B!A;',@)60@0FSV8VME(&5R<W1E;&QE;BX`4VEE('-I;F0@;FEC:'0@86YG
M96UE;&1E="X`4VEE(&3\<F9E;B!D87,@6F5I8VAE;B`G7"<@;FEC:'0@:6X@
M26AR96T@3F%M96X@=F5R=V5N9&5N+@!3:64@:&%B96X@:V5I;F4@9_QL=&EG
M92!%+4UA:6PM061R97-S92!A;F=E9V5B96XN`%-I92!H86)E;B!K96EN92!&
M96QD97(@875S(&1E;B!I;7!O<G1I97)T96X@1&%T96X@9&5N(&5N='-P<F5C
M:&5N9&5N($9E;&1E<FX@:6X@)7,@>G5G96]R9&YE="X`4VEE('=U<F1E;B!A
M8F=E;65L9&5T+@!3:64@;?QS<V5N(&5I;F4@9_QL=&EG92!-;V)I;'1E;&5F
M;VYN=6UM97(@86YG96)E;BP@;G5R(&%U<R!:86AL96X@=6YD(&=G9BX@96EN
M96T@(BLB(&;\<B!I;G1E<FYA=&EO;F%L92!6;W)W86AL96X@8F5S=&5H96YD
M+@!3:64@;?QS<V5N(&5I;F5N(&?\;'1I9V5N(%=E<G0@86YG96=E8F5N+@!3
M:64@;?QS<V5N(&5I;B!$871A5')E92U"86-K96YD(&MO;F9I9W5R:65R96XL
M('5M(%)E9VES=')I97)U;F=E;B!V97)W96YD96X@>G4@:_9N;F5N+@!3:64@
M;?QS<V5N(&5I;B!61E,M0F%C:V5N9"!K;VYF:6=U<FEE<F5N+@!3:64@;?QS
M<V5N(&1A<R!0<F]B;&5M(&)E<V-H<F5I8F5N+"!U;2!D96X@0F5R:6-H="!A
M8GIU<V-H:6-K96XN`%-I92!M_'-S96X@9&EE(%523"!A;F=E8F5N+"!A=68@
M9&EE(&1I97-E<B!,:6YK('9E<G=E:7-E;B!S;VQL`%-I92!M_'-S96X@97)S
M="!D96X@>G4@96YT9F5R;F5N9&5N(%-E<G9E<B!A=7-WY&AL96XN`%-I92!M
M_'-S96X@96EN96X@0F5N=71Z97)N86UE;B!A;F=E8F5N+"!D97-S96X@1&%T
M96X@9V5L]G-C:'0@=V5R9&5N('-O;&QE;BX`4VEE(&W\<W-E;B!E:6YE;B!Z
M=2!L]G-C:&5N9&5N($)E;G5T>F5R;F%M96X@86YG96)E;BX`4VEE(&W\<W-E
M;B!E:6YE;B!H:6YZ=7IU9OQG96YD96X@0F5N=71Z97)N86UE;B!A;F=E8F5N
M+@!3:64@;?QS<V5N(&1E;B!Z=2!A:W1U86QI<VEE<F5N9&5N($)E;G5T>F5R
M;F%M96X@86YG96)E;BX`4VEE(&W\<W-E;B!E:6YE($%K=&EO;B!A;F=E8F5N
M+@!3:64@;?QS<V5N(&5I;F5N(&YE=65N($MA=&5G;W)I96YA;65N(&%N9V5B
M96XN`%-I92!M_'-S96X@96EN92!)=&%L:65N:7-C:&4@5&5L969O;FYU;6UE
M<B!A;F=E8F5N`$EH<F4@)7,M4V5S<VEO;B!I<W0@86)G96QA=69E;BX@0FET
M=&4@;65L9&5N(%-I92!S:6-H(&5R;F5U="!A;BX`26AR92!%+4UA:6PM061R
M97-S90!):')E(%9O;CH@061R97-S93H`26AR92!!;F=A8F5N`$EH<F4@26YT
M97)N971A9')E<W-E(&AA="!S:6-H(&=EY&YD97)T+"!S96ET(%-I92!D:64@
M)7,M4VET>G5N9R!B96=O;FYE;B!H86)E;BX@6G5M(%-C:'5T>B!):')E<B!3
M:6-H97)H96ET(&W\<W-E;B!3:64@<VEC:"!N974@86YM96QD96XN`$EH<B!.
M86UE`$EH<B!!=71H96YT:69I>FEE<G5N9W-S>7-T96T@97)L875B="!K96EN
M($AI;GIU9OQG96X@=F]N(&YE=65N($)E;G5T>F5R;BX@5V5N;B!3:64@2&]R
M9&4@8F5N=71Z96X@;?9C:'1E;BP@=6T@26AR92!"96YU='IE<B!Z=2!V97)W
M86QT96XL(&W\<W-E;B!3:64@96EN96X@86YD97)E;B!!=71H96YT:69I>FEE
M<G5N9W-T<F5I8F5R(&)E;G5T>F5N+@!):'(@075T:&5N=&EF:7II97)U;F=S
M<WES=&5M(&5R;&%U8G0@9&%S($%N>F5I9V5N(&1E<B!"96YU='IE<B!N:6-H
M="P@;V1E<B!D:65S92!-]F=L:6-H:V5I="!W=7)D92!A=7-G97-C:&%L=&5T
M+@!):'(@0G)O=W-E<B!H870@<VEC:"!A;G-C:&5I;F5N9"!G9>1N9&5R="!S
M96ET(%-I92!D:64@)7,M4VET>G5N9R!B96=O;FYE;B!H86)E;BX@6G5M(%-C
M:'5T>B!):')E<B!3:6-H97)H96ET(&W\<W-E;B!3:64@<VEC:"!N974@86YM
M96QD96XN`$EH<B!"<F]W<V5R('5N=&5R<W3\='IT(&1I97-E($9U;FMT:6]N
M(&YI8VAT+@!):'(@0G)O=W-E<B!U;G1E<G-T_'1Z="!D:65S92!$<G5C:V9U
M;FMT:6]N(&YI8VAT+B!":71T92!D<OQC:V5N(%-I92!3=')G+TMO;6UA;F1O
M("L@4"!U;2!Z=2!D<G5C:V5N+@!):')E(&%K='5E;&QE(%IE:71Z;VYE.@!)
M:')E(%-T86YD87)D:61E;G1I=.1T('=U<F1E(&=EY&YD97)T+@!):')E(%-T
M86YD87)D:61E;G1I=.1T.@!):'(@=F]L;'-TY&YD:6=E<B!.86UE.@!):'(@
M6G5G86YG(&ES="!A8F=E;&%U9F5N+@!):'(@;F5U97,@4&%S<W=O<G0@9OQR
M("5S(&QA=71E=#H@)7,`26AR92!%:6YS=&5L;'5N9V5N('=U<F1E;B!F_'(@
M9&EE($1A=65R(&1I97-E<B!3:71Z=6YG(&=E<W!E:6-H97)T+@!):')E($5I
M;G-T96QL=6YG96X@=W5R9&5N(&=E<W!E:6-H97)T+@!):'(@4&%S<W=O<G0@
M=W5R9&4@>G5R_&-K9V5S971Z=`!):'(@4&%S<W=O<G0@=W5R9&4@>G5R_&-K
M9V5S971Z="X@4G5F96X@4VEE($EH<F4@12U-86EL+4YA8VAR:6-H=&5N(&%B
M('5N9"!M96QD96X@4VEE('-I8V@@;6ET($EH<F5M(&YE=65N(%!A<W-W;W)T
M(&%N+@!):'(@4&%S<W=O<G0@:7-T(&%B9V5L875F96XN`$EH<F4@4V5R=F5R
M.@!*=6=O<VQA=VEE;@!:86ER90!386UB:6$`4VEM8F%B=V4`6FEP<'D`6UII
M=&%T=&5X="!V97)S=&5C:V5N70!;4')O8FQE;6)E<FEC:'1=`%M::71A='1E
M>'0@86YZ96EG96X@+0!;6FET871T97AT(&%N>F5I9V5N("T@)7,@6F5I;&5N
M70!;6F5I;&4@)7,@=F]N("5S70!?061M:6YI<W1R871I;VX`0F5?9F5H;'-Z
M96EL90!?1&%T851R964`6F5I;&4@7VSV<V-H96X`7T=R=7!P96X`7T)I;&1E
M:6=E;G-C:&%F=&5N+BXN`$%N7VUE;&1E;@!!8E]M96QD96X`3&EN:R!?8F5A
M<F)E:71E;BXN+@!?16EN<W1E;&QU;F=E;@!?4F5C:'1E`$QI;FL@7V5N=&9E
M<FYE;BXN+@!?2V]N9FEG=7)A=&EO;@!?5&%B96QL96YE:6=E;G-C:&%F=&5N
M+BXN`%]"96YU='IE<@!!9')E<W-B=6-H`$%D<F5S<V%T('5N8F5K86YN=`!+
M86QE;F1E<@!W:6YD<W1I;&P`075S9V%B961A=&5I(&MO;FYT92!N:6-H="!E
M<G-T96QL="!W97)D96X`16EN9V%B92!K86YN(&YI8VAT(&=E]F9F;F5T('=E
M<F1E;@!K;&EC:V5N(%-I92!H:65R`%5N9_QL=&EG92!"96YU='IU;F<@9&5R
M($MO;6UA;F1O>F5I;&4`2V]N9FEG=7)A=&EO;G-F96AL97(`2W)I=&ES8VAE
M(%-Y<W1E;61A=&5I(&9E:&QT`$1A=&5N9F]R;6%T9F5H;&5R`&)E87)B96ET
M96X`16EN=')A9R!N:6-H="!G969U;F1E;@!F86QL96YD`$1A=&5I`&%U<R`E
M<R`H)7,I(&UI="`E<R`E<P!B]FEG`&@Z`&AH`$AO<W1N86UE('5N8F5K86YN
M=`!S;V9O<G0`26YL:6YE`$5I;BTO075S9V%B969E:&QE<@!);G1E<FYE<B!3
M;V9T=V%R969E:&QE<@!:96EL96Y=`&UK:7-O9G,M1F5H;&5R8V]D92`E9"!B
M96D@9&5R($5R<W1E;&QU;F<@9&5S($E33RU!8F)I;&1E<RX`;6T`3F%M90!N
M:6-H="!I;7!L96UE;G1I97)T`$YO8V@@;FEC:'0@:6UP;&5M96YT:65R=`!.
M;W1I>F)L;V-K`%!R;WIE;G0`6G5G<FEF9B!V97)W96EG97)T`%!I>&5L`%)E
M;6]T969E:&QE<B!I;2!0<F]T;VMO;&P`<W1E:6=E;F0`4V5R=FEC92!N:6-H
M="!V97)F_&=B87(`56YT97)S8VAI961E(&%N>F5I9V5N`'-M<S)E;6%I;"#\
M8F5R($A45%``<W,`9VQE:6-H8FQE:6)E;F0`4WES=&5M9F5H;&5R`$%U9F=A
M8F5N;&ES=&4`5F]R_&)E<F=E:&5N9&5R($9E:&QE<@!G96)E;B!3:64@9&%S
M(%!A<W-W;W)T(&5I;B!Z=V5I=&5S($UA;"!Z=7(@0F5S=.1T:6=U;F<@96EN
M`'5N:69I960`=6YB96YA;FYT`&)E;G5T>F5R9&5F:6YI97)T`'9#87)D`&(Z
M`'=E871H97(N8V]M````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQO8V%L92]D95]$12]H96QP+GAM;```````````````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-#0Q,"`Q,#4Q-30S,S<T,"`P
M,C$T,#4`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]X;6P@=F5R<VEO;CTB,2XP(B!E;F-O9&EN9STB:7-O+3@X-3DM,2(_
M/@H\(2TM("1(;W)D93H@:&]R9&4O;&]C86QE+V1E7T1%+VAE;'`N>&UL+'8@
M,2XU(#(P,#0O,3`O,C(@,3,Z,S<Z,3D@:F%N($5X<"`D("TM/@H\:&5L<#X*
M("`\96YT<GD@:60](G-U;6UA<GDB(&UD-3TB-CAC83,S9C=F,&,Y86%E-&,Q
M,#-E8C0W-#DR8V1C,34B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^
M1&EE(%!O<G1A;'-E:71E/"]T:71L93X*("`@(#QP87)A/@H@("`@("!$:64@
M4&]R=&%L<V5I=&4@97)L875B="!E:6YE(&MU<GIE(-QB97)S:6-H="#\8F5R
M(&%L;&4@26AR92!W:6-H=&EG96X*("`@("`@26YF;W)M871I;VYE;BX@4VEE
M(&MA;FX@>G5M($)E:7-P:65L(&%N>F5I9V5N+"!W:64@=FEE;&4@;F5U92!%
M;6%I;',@4VEE"B`@("`@(&AA8F5N+"!W96QC:&4@5&5R;6EN92!D96UNY&-H
M<W0@86YS=&5H96XL('=E;&-H92!!=69G86)E;B!3:64@;F]C:"!Z=0H@("`@
M("!E<FQE9&EG96X@:&%B96X@;V1E<B!A=6-H(&1I92!N975E<W1E;B!.86-H
M<FEC:'1E;BX@5FEE;&4@9&EE<V5R"B`@("`@(-QB97)S:6-H=&5N(&5N=&AA
M;'1E;B!S8VAN96QL92!:=6=R:69F92!A=68@:.1U9FEG(&)E;O9T:6=T92!&
M=6YK=&EO;F5N+`H@("`@("!W:64@9&%S(%-C:')E:6)E;B!N975E<B!%;6%I
M;',@;V1E<B!D96T@06YL96=E;B!N975E<B!+86QE;F1E<F5I;G1RY&=E"B`@
M("`@(&]D97(@075F9V%B96XN"B`@("`\+W!A<F$^"B`@("`\<&%R83X*("`@
M("`@1&5R($EN:&%L="!D:65S97(@4&]R=&%L<V5I=&4@:V%N;B#\8F5R(&1E
M;B`B06YP87-S96XB+4QI;FL*("`@("`@=F5RY&YD97)T('=E<F1E;BX@4VEE
M(&OV;FYE;B!Z=6T@0F5I<W!I96P@875S=^1H;&5N+"!W96QC:&4@W&)E<G-I
M8VAT96X*("`@("`@:6X@9&EE(%!O<G1A;'-E:71E(&%U9F=E;F]M;65N('=E
M<F1E;B!S;VQL96XL('5N9"!F97-T;&5G96XL(&EN('=E;&-H97(*("`@("`@
M4F5I:&5N9F]L9V4@<VEE(&%N9V5Z96EG="!W97)D96XN"B`@("`\+W!A<F$^
M"B`@/"]E;G1R>3X*"B`@/&5N=')Y(&ED/2)N879B87(B(&UD-3TB8CAC9C!A
M93$Y934W9&9A,&,R8CDV,F4U,38W.#)F-#<B('-T871E/2)U<'1O9&%T92(^
M"B`@("`\=&ET;&4^1&EE($%N=V5N9'5N9W,M3F%V:6=A=&EO;G-L96ES=&4\
M+W1I=&QE/@H@("`@/'!A<F$^"B`@("`@($%U9B!D97(@;&EN:V5N(%-E:71E
M(&1E<R!&96YS=&5R<R!B969I;F1E="!S:6-H(&1I92!.879I9V%T:6]N<VQE
M:7-T90H@("`@("!F_'(@9&EE($%N=V5N9'5N9V5N+B!+;&EC:V5N(%-I92!A
M=68@9&EE(%-Y;6)O;&4@;V1E<B!.86UE;B!D97(*("`@("`@06YW96YD=6YG
M96XL('5M('-C:&YE;&P@=6YD(&5I;F9A8V@@>G=I<V-H96X@9&EE<V5N(&AI
M;BT@=6YD"B`@("`@(&AE<GIU<V-H86QT96XN"B`@("`\+W!A<F$^"B`@/"]E
M;G1R>3X*("`\96YT<GD@:60](G!R969S+61O7VUA:6YT96YA;F-E(B!S=&%T
M93TB=7!T;V1A=&4B(&UD-3TB9&0Y-61F,#=A,#,P,S$R,S)B865A.3$Y,C@X
M8C)D,#`B/@H@("`@/'1I=&QE/D5I;G-T96QL=6YG96XZ($%N;65L9&5A=69G
M86)E;CH@5V%R='5N9W-A<F)E:71E;@H@("`@("!D=7)C:&;\:')E;CPO=&ET
M;&4^"B`@("`\<&%R83X*("`@("`@5V5N;B!3:64@;?9C:'1E;BP@9&%S<R!N
M86-H(&1E<B!!;FUE;&1U;F<@5V%R='5N9W-A<F)E:71E;B!D=7)C:&=E9OQH
M<G0*("`@("`@=V5R9&5N+"!M87)K:65R96X@4VEE(&1I97-E<R!!=7-W86AL
M9F5L9"X*("`@(#PO<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E
M9G,M8V]N9FER;5]M86EN=&5N86YC92(@<W1A=&4](G5P=&]D871E(B!M9#4]
M(F$R,3$V,F-D9F8S8C%D.&9A96%D8C<R.38R-#`P,S9E(CX*("`@(#QT:71L
M93Y%:6YS=&5L;'5N9V5N.B!!;FUE;&1E875F9V%B96XZ(%=A<G1U;F=S87)B
M96ET96X@8F5S=.1T:6=E;CPO=&ET;&4^"B`@("`\<&%R83X*("`@("`@5V5N
M;B!3:64@86QL92!787)T=6YG<V%R8F5I=&5N(&)E<W3D=&EG96X@;?9C:'1E
M;BP@8F5V;W(@9&EE<V4*("`@("`@875S9V5F_&AR="!W97)D96XL(&UA<FMI
M97)E;B!3:64@9&EE<V5S($%U<W=A:&QF96QD+B!796YN(%-I92!D87,@1F5L
M9`H@("`@("!D96%K=&EV:65R="!L87-S96XL('=E<F1E;B!A;&QE(%=A<G1U
M;F=S87)B96ET96X@875T;VUA=&ES8V@*("`@("`@9'5R8VAG96;\:')T+"!O
M:&YE(&1A<W,@4VEE(&)E:2!D97(@06YM96QD=6YG(&1I92!'96QE9V5N:&5I
M="!H86)E;BP*("`@("`@9&EE<V4@86)Z=6)R96-H96XN"B`@("`\+W!A<F$^
M"B`@/"]E;G1R>3X*/"]H96QP/@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]C<U]#6@``````````````
M````````````````````````````````````````````````````````````
M```````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q
M,#4Q-30S,S<T,2`P,3<W,3<`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE
M+V-S7T-:+TQ#7TU%4U-!1T53````````````````````````````````````
M`````````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S0Q(#`R,34P-``@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L;V-A;&4O8W-?0UHO3$-?34534T%'15,O:&]R9&4N;6\`
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`S,S8P,S4@,3`U,34T,S,W-#$@
M,#(S,C,S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````-X2!)4`````F`8``!P```#<-```RP@``)QI````````R(P```X```#)
MC```#P```-B,```-````Z(P```@```#VC```"P```/^,```,````"XT```0`
M```8C0``#````!V-```/````*HT```L````ZC0``#@```$:-```%````58T`
M`"@```!;C0``"````(2-```*````C8T``!4```"8C0``$@```*Z-```+````
MP8T```X```#-C0``"@```-R-```-````YXT```X```#UC0``$0````2.```-
M````%HX```P````DC@``#0```#&.```&````/XX```\```!&C@``&````%:.
M```,````;XX```X```!\C@``#@```(N.```(````FHX``"X```"CC@``&@``
M`-*.```R````[8X``#@````@CP``5````%F/``!1````KH\``%H`````D```
M5P```%N0```T````LY````<```#HD```"@```/"0```/````^Y````4````+
MD0``!@```!&1```1````&)$```@````JD0``"0```#.1```)````/9$``"4`
M``!'D0``(````&V1```0````CI$```\```"?D0``"@```*^1```#````NI$`
M``\```"^D0``%````,Z1```)````XY$```T```#MD0``$@```/N1```/````
M#I(```H````>D@``#P```"F2```(````.9(``"0```!"D@``%````&>2```6
M````?)(```@```"3D@``&0```)R2```'````MI(```P```"^D@``+````,N2
M```.````^)(```,````'DP``"P````N3```'````%Y,```<````?DP``!0``
M`">3```%````+9,```H````SDP```P```#Z3```7````0I,```H```!:DP``
M#P```&63```.````=9,``!@```"$DP``(P```)V3```.````P9,``!0```#0
MDP``%P```.63```7````_9,``!<````5E```$P```"V4```/````090```X`
M``!1E```'P```&"4```'````@)0```8```"(E```"````(^4```/````F)0`
M``8```"HE```"@```*^4```3````NI0```L```#.E```$````-J4```5````
MZY0``!4````!E0``!P```!>5```0````'Y4```4````PE0``%0```#:5```1
M````3)4```P```!>E0``.P```&N5```)````IY4```<```"QE0``%````+F5
M```#````SI4```4```#2E0``$````-B5```)````Z94``!,```#SE0``.0``
M``>6```2````098``"<```!4E@``+````'R6```J````J98``"4```#4E@``
M"@```/J6```&````!9<```D````,EP``!P```!:7```O````'I<``#<```!.
MEP``+@```(:7``!5````M9<``"T````+F```+0```#F8```M````9Y@``$``
M``"5F```(P```-:8```C````^I@``"T````>F0``,P```$R9```5````@)D`
M`!D```"6F0``*0```+"9```D````VID``!$```#_F0``"@```!&:```,````
M')H```H````IF@``$````#2:```6````19H``!8```!<F@``!P```'.:```'
M````>YH``!0```"#F@``"@```)B:```(````HYH```@```"LF@``!P```+6:
M```'````O9H```8```#%F@``!0```,R:```'````TIH```8```#:F@``"```
M`.&:```I````ZIH```X````4FP``"@```".;```$````+IL```<````SFP``
M"0```#N;```&````19L``!$```!,FP``!P```%Z;```6````9IL```0```!]
MFP``"````(*;```&````BYL```T```"2FP``!@```*";```>````IYL``!$`
M``#&FP``"````-B;```-````X9L```P```#OFP``!P```/R;```#````!)P`
M``,````(G```%P````R<```3````))P```@````XG```!````$&<```(````
M1IP```@```!/G```00```%B<```@````FIP```8```"[G```!@```,*<```5
M````R9P``!@```#?G```(@```/B<```N````&YT``!T```!*G0``(0```&B=
M``!4````BIT``"D```#?G0``"@````F>```'````%)X``!4````<G@``#@``
M`#*>```*````09X```\```!,G@``#0```%R>```/````:IX```T```!ZG@``
M"0```(B>```4````DIX```8```"GG@``&````*Z>```=````QYX``!,```#E
MG@``%````/F>```$````#I\```8````3GP``5````!J?```$````;Y\```X`
M``!TGP``!0```(.?```%````B9\``!L```"/GP``&@```*N?```1````QI\`
M`!$```#8GP``'````.J?```J````!Z```!`````RH```(0```$.@```%````
M9:```!,```!KH```$@```'^@```*````DJ````\```"=H```$0```*V@```3
M````OZ````P```#3H```!@```."@```&````YZ```!<```#NH```$`````:A
M```1````%Z$```@````IH0``!0```#*A```,````.*$``!````!%H0``!0``
M`%:A```-````7*$```8```!JH0``!P```'&A```-````>:$```<```"'H0``
M"P```(^A```'````FZ$```<```"CH0``"0```*NA```*````M:$``!D```#`
MH0``#````-JA```0````YZ$```4```#XH0``)0```/ZA```2````)*(``!,`
M```WH@``*P```$NB```[````=Z(``"````"SH@``-@```-2B```(````"Z,`
M``P````4HP``!@```"&C```$````**,```X````MHP``"@```#RC```-````
M1Z,``!X```!5HP``&P```'2C```A````D*,``!X```"RHP``&0```-&C```>
M````ZZ,``!L````*I```)@```":D```;````3:0``!X```!II```'````(BD
M```F````I:0``#,```#,I```)@````"E```K````)Z4``#@```!3I0``+P``
M`(RE```2````O*4``"D```#/I0``$@```/FE``"B````#*8``!8```"OI@``
M(P```,:F```H````ZJ8``"D````3IP``*````#VG```?````9J<``"````"&
MIP``)0```*>G```P````S:<``"$```#^IP``'````""H```F````/:@``$$`
M``!DJ```#````*:H```'````LZ@```<```"[J```!@```,.H```-````RJ@`
M`!````#8J```$@```.FH```3````_*@``!(````0J0``!P```".I```$````
M*ZD```P````PJ0``#@```#VI```/````3*D``!,```!<J0``#0```'"I```H
M````?JD```,```"GJ0``#0```*NI```&````N:D``!$```#`J0``%P```-*I
M```;````ZJD```X````&J@```@```!6J```%````&*H``!`````>J@``!```
M`"^J```-````-*H```X```!"J@```P```%&J```.````5:H```@```!DJ@``
M#P```&VJ```/````?:H```<```"-J@``#0```)6J```0````HZH```L```"T
MJ@``!@```,"J```,````QZH``!$```#4J@``&0```.:J```+`````*L```T`
M```,JP``(@```!JK```*````/:L``!@```!(JP``&0```&&K```6````>ZL`
M``T```"2JP``!P```*"K```4````J*L```L```"]JP``(@```,FK```O````
M[*L```L````<K```"0```"BL```9````,JP```L```!,K```%P```%BL```7
M````<*P```D```"(K```%@```)*L```/````J:P``!8```"YK```#@```-"L
M```8````WZP```@```#XK```#0````&M```F````#ZT``$,````VK0``"```
M`'JM```2````@ZT```@```"6K0``"P```)^M```O````JZT```X```#;K0``
M!0```.JM```&````\*T```,```#WK0``!P```/NM```$`````ZX```H````(
MK@``"@```!.N```/````'JX``!`````NK@``%P```#^N```1````5ZX``!<`
M``!IK@``"0```(&N```%````BZX```L```"1K@``"@```)VN```"````J*X`
M``4```"KK@``#0```+&N```;````OZX``!<```#;K@``"0```/.N```.````
M_:X```T````,KP``$@```!JO```X````+:\``"````!FKP``"````(>O```.
M````D*\``'L```"?KP``&````!NP```1````-+````<```!&L```!0```$ZP
M```9````5+````<```!NL```"````':P```&````?[````8```"&L```$```
M`(VP```/````GK```!````"NL```#P```+^P```+````S[````\```#;L```
M#````.NP```/````^+````<````(L0``!@```!"Q```.````%[$```P````F
ML0``*````#.Q```/````7+$```@```!LL0``"````'6Q```3````?K$``!X`
M``"2L0``(0```+&Q```@````T[$``!D```#TL0``%P````ZR```E````)K(`
M`!<```!,L@``!````&2R```;````:;(```T```"%L@``#````).R```#````
MH+(```@```"DL@``"@```*VR```,````N+(```L```#%L@``$````-&R```,
M````XK(```0```#OL@``$P```/2R```4````"+,```P````=LP``"0```"JS
M```.````-+,```L```!#LP``&P```$^S```'````:[,```<```!SLP``"@``
M`'NS```-````AK,```D```"4LP``!````)ZS```%````H[,```,```"ILP``
M&````*VS```*````QK,```0```#1LP``)@```-:S```.````_;,``'P````,
MM```%0```(FT```%````G[0```<```"EM```#````*VT```(````NK0```H`
M``##M```!@```,ZT```(````U;0```(```#>M```!@```.&T```&````Z+0`
M`!0```#OM```#0````2U```0````$K4``!L````CM0``!````#^U```)````
M1+4``!````!.M0``"0```%^U```)````:;4```4```!SM0``&@```'FU```(
M````E+4```8```"=M0``&0```*2U```.````OK4```<```#-M0``!P```-6U
M```%````W;4```D```#CM0``"@```.VU```"````^+4```8```#[M0``#0``
M``*V```)````$+8```8````:M@``$@```"&V```)````-+8```<````^M@``
M%````$:V```=````6[8```8```!YM@``"@```("V```$````B[8```D```"0
MM@``"````)JV```1````H[8```D```"UM@``!@```+^V```-````QK8```8`
M``#4M@``!````-NV```Y````X+8``#T````:MP``.@```%BW```>````D[<`
M``4```"RMP``#@```+BW```$````Q[<```8```#,MP``(0```-.W```5````
M];<```8````+N```!````!*X```1````%[@```8````IN```"@```#"X```B
M````.[@```0```!>N```!0```&.X```=````:;@```0```"'N```#````(RX
M```*````F;@```@```"DN```"0```*VX```%````M[@``#H```"]N```,```
M`/BX```U````*;D``"D```!?N0``1P```(FY```X````T;D``"D````*N@``
M/P```#2Z```N````=+H``"T```"CN@``'P```-&Z```/````\;H``!(````!
MNP``"P```!2[```F````(+L``"D```!'NP``)````'&[```F````EKL```@`
M``"]NP``"@```,:[```)````T;L```<```#;NP``(````..[```@````!+P`
M`"8````EO```"@```$R\```9````5[P``"D```!QO```%@```)N\```2````
MLKP```<```#%O```"@```,V\```,````V+P```\```#EO```$````/6\``!`
M````!KT``'````!'O0``9@```+B]```.````'[X```D````NO@``"@```#B^
M```2````0[X``!,```!6O@``#````&J^```&````=[X```\```!^O@``$@``
M`(Z^```0````H;X``!$```"RO@``'````,2^```C````X;X``&H````%OP``
M#P```'"_```%````@+\``!````"&OP``"0```)>_```$````H;\```L```"F
MOP``%````+*_```,````Q[\```P```#4OP``#P```.&_```5````\;\``"D`
M```'P```*@```#'````F````7,```"<```"#P```*0```*O````J````U<``
M`!D`````P0``0@```!K!```1````7<$``!(```!OP0``$P```(+!```4````
MEL$```\```"KP0``%@```+O!```7````TL$``!````#JP0``$0```/O!```T
M````#<(``!,```!"P@``$@```%;"```U````:<(``!0```"?P@``!P```+3"
M```,````O,(``"````#)P@``%````.K"```1````_\(``!<````1PP``'```
M`"G#```3````1L,``!$```!:PP``&@```&S#```>````A\,``!H```"FPP``
M$0```,'#```4````T\,``!<```#HPP``%0````#$```)````%L0``!D````@
MQ```!````#K$```'````/\0```L```!'Q```$0```%/$```&````9<0```8`
M``!LQ```!@```'/$```%````>L0```<```"`Q```!P```(C$```%````D,0`
M`!8```"6Q```!@```*W$```&````M,0```0```"[Q```!````,#$```'````
MQ<0```X```#-Q```#````-S$```,````Z<0```T```#VQ```"@````3%```.
M````#\4```4````>Q0``*````"3%```.````3<4```P```!<Q0``#P```&G%
M```*````><4```@```"$Q0``"0```(W%```K````E\4```0```##Q0``"```
M`,C%```F````T<4``!(```#XQ0``#P````O&```&````&\8```H````BQ@``
M!P```"W&```(````-<8``"`````^Q@``"0```%_&```,````:<8```T```!V
MQ@``#@```(3&```6````D\8``!$```"JQ@``!@```+S&```#````P\8```8`
M``#'Q@``&0```,[&```'````Z,8```0```#PQ@``"P```/7&```+`````<<`
M``<````-QP``!P```!7'```6````'<<```T````TQP``#0```$+'```*````
M4,<``!````!;QP``#P```&S'```1````?,<``!<```".QP``"@```*;'```1
M````L<<```@```##QP``!````,S'```/````T<<``#H```#AQP``!0```!S(
M```,````(L@``!X````OR```#@```$[(```0````7<@```L```!NR```#```
M`'K(```)````A\@```<```"1R```"@```)G(```)````I,@```X```"NR```
M$````+W(```:````SL@```H```#IR```"0```/3(```*````_L@```P````)
MR0``#P```!;)```(````)LD```8````OR0``!P```#;)```+````/LD``$<`
M``!*R0``#0```)+)```)````H,D```0```"JR0```P```*_)```3````L\D`
M`!,```#'R0``$P```-O)```*````[\D```(```#ZR0``!````/W)```E````
M`LH```,````HR@``!0```"S*```J````,LH```H```!=R@``!0```&C*```$
M````;LH```H```!SR@``#0```'[*```&````C,H```@```"3R@``"````)S*
M```$````I<H```4```"JR@``:````+#*```)````&<L```P````CRP``!0``
M`##+```&````-LL``!L````]RP``+P```%G+```0````B<L```H```":RP``
M#P```*7+```*````M<L```D```#`RP``$P```,K+```;````WLL``!@```#Z
MRP``%P```!/,```.````*\P```,````ZS```!P```#[,```(````1LP```<`
M``!/S```"@```%?,```+````8LP```<```!NS```40```';,```0````R,P`
M``P```#9S```#0```.;,```:````],P``$H````/S0``!@```%K-```&````
M8<T```8```!HS0``'P```&_-```&````C\T```D```"6S0``&````*#-```7
M````N<T```8```#1S0``#0```-C-```B````YLT``%<````)S@``$P```&'.
M```C````=<X``!,```"9S@```@```*W.```+````L,X```@```"\S@``#0``
M`,7.```*````T\X```<```#>S@``%````.;.```&````^\X```@````"SP``
M#@````O/```'````&L\```H````BSP``"P```"W/```'````.<\```P```!!
MSP``#0```$[/```,````7,\```D```!ISP``"0```'//```*````?<\```<`
M``"(SP``"0```)#/```'````FL\```H```"BSP``&P```*W/```2````R<\`
M``H```#<SP``"0```.?/```0````\<\```<````"T```$@````K0```$````
M'=````<````BT```!0```"K0```%````,-````L````VT```%````$+0```1
M````5]```!H```!IT```%@```(30```4````F]```!<```"PT```&````,C0
M```<````X=```!D```#^T```!P```!C1```%````(-$```T````FT0``#```
M`#31```(````0=$``!<```!*T0``"P```&+1```3````;M$```0```""T0``
M"@```(?1```$````DM$```P```"7T0``"0```*31```%````KM$```<```"T
MT0``!0```+S1```$````PM$```(```#'T0``.````,K1```L`````](``!(`
M```PT@``*0```$/2```R````;=(```H```"@T@``+````*O2```N````V-(`
M`#,````'TP``,P```#O3```X````;],```\```"HTP``&````+C3```0````
MT=,```\```#BTP``$P```/+3```4````!M0``!(````;U```%````"[4```5
M````0]0``"T```!9U```+0```(?4```Q````M=0``"X```#GU```+P```!;5
M```L````1M4``&(```!SU0``$P```-;5```(````ZM4```@```#SU0``*P``
M`/S5```A````*-8``!H```!*U@``"0```&76``!%````;]8``$$```"UU@``
M!````/?6```3````_-8``!0````0UP``#@```"77```3````--<``!@```!(
MUP``!@```&'7```)````:-<```H```!RUP``#P```'W7```0````C=<```<`
M``">UP``#@```*;7```%````M=<``!L```"[UP``"````-?7```&````X-<`
M`!0```#GUP``$0```/S7```.````#M@``#@````=V````@```%;8```&````
M6=@```X```!@V```!0```&_8```'````==@```X```!]V```!@```(S8```$
M````D]@``"D```"8V```%P```,+8```?````VM@``%P```#ZV```%````%?9
M```^````;-D``!\```"KV0``$````,O9```'````W-D```X```#DV0``#```
M`//9```,`````-H``!,````-V@``"@```"':```=````+-H``!D```!*V@``
M!0```&3:```1````:MH``!$```!\V@``)````([:```5````L]H``!(```#)
MV@``#@```-S:```9````Z]H```@````%VP``"0````[;```-````&-L```H`
M```FVP``!P```#';```/````.=L```L```!)VP``"@```%7;```'````8-L`
M``@```!HVP``!0```'';```?````=]L```8```"7VP``$````)[;```(````
MK]L```T```"XVP``"````,;;```2````S]L``"P```#BVP``&@````_<```)
M````*MP```H````TW```%0```#_<```%````5=P``!0```!;W```!````'#<
M```0````==P```8```"&W```!P```(W<```>````E=P``"@```"TW```"@``
M`-W<```:````Z-P``!0````#W0``!````!C=```$````'=T```L````BW0``
M!0```"[=```&````--T```@````[W0``!@```$3=```*````2]T``!L```!6
MW0``-````'+=```T````I]T``"````#<W0``*0```/W=```@````)]X``$$`
M``!(W@``&@```(K>```H````I=X``"D```#.W@``(@```/C>```&````&]\`
M``@````BWP``!0```"O?```(````,=\``!D````ZWP``&0```%3?```J````
M;M\``",```"9WP``+@```+W?```T````[-\```@````AX```%P```"K@```*
M````0N````<```!-X```(0```%7@```0````=^````X```"(X```"P```)?@
M```'````H^```!,```"KX```"````+_@```+````R.````H```#4X```%```
M`-_@```R````].````L````GX0``!0```#/A```%````.>$``!<````_X0``
M#P```%?A```$````9^$```H```!LX0``"0```'?A```+````@>$```T```"-
MX0``#````)OA```.````J.$```4```"WX0``!````+WA```-````PN$``#(`
M``#0X0``10````/B```7````2>(``!X```!AX@``%````(#B```%````E>(`
M`!0```";X@``!P```+#B```.````N.(``"H```#'X@``!@```/+B```,````
M^>(```T````&XP``$0```!3C```+````)N,``#8````RXP``"@```&GC```B
M````=.,```L```"7XP``#P```*/C```R````L^,```X```#FXP``!0```/7C
M```.````^^,``!,````*Y```!P```![D```1````)N0```<````XY```%```
M`$#D```8````5>0```<```!NY```!0```';D```,````?.0```P```")Y```
M$@```);D```$````J>0```<```"NY```"@```+;D```+````P>0```P```#-
MY```#@```-KD```.````Z>0```4```#XY```!0```/[D```N````!.4``"8`
M```SY0``(P```%KE```#````?N4``!(```""Y0``!@```)7E```>````G.4`
M`!@```"[Y0``)0```-3E```-````^N4```D````(Y@```P```!+F```'````
M%N8```H````>Y@```@```"GF```,````+.8``!4````YY@``"P```$_F```9
M````6^8``"````!UY@``$@```);F```%````J>8```H```"OY@``%0```+KF
M```2````T.8```P```#CY@``!````/#F```'````]>8```P```#]Y@``4@``
M``KG```7````7><```<```!UYP``!@```'WG```.````A.<```P```"3YP``
M#0```*#G```5````KN<``!(```#$YP``#P```-?G```4````Y^<``!L```#\
MYP``$````!CH``!I````*>@``!H```"3Z```%P```*[H```G````QN@``!H`
M``#NZ```%P````GI```;````(>D``!D````]Z0``'P```%?I```3````=^D`
M``@```"+Z0``!P```)3I```(````G.D```D```"EZ0``%0```*_I```-````
MQ>D``!,```#3Z0```P```.?I``!&````Z^D``#\````RZ@``-P```'+J``!7
M````JNH```4````"ZP``'P````CK```O````*.L```H```!8ZP``"````&/K
M```-````;.L``"T```!ZZP``!````*CK``!/````K>L``"4```#]ZP``'```
M`"/L```+````0.P``!\```!,[```'0```&SL```E````BNP``"````"P[```
M)````-'L```@````]NP```L````7[0``!P```"/M```-````*^T```P````Y
M[0``%P```$;M```&````7NT``#D```!E[0``#````)_M```'````K.T```D`
M``"T[0``$P```+[M```)````TNT```0```#<[0``$````.'M```(````\NT`
M``@```#[[0``!`````3N```+````">X```P````5[@``$@```"+N```1````
M->X```P```!'[@``&@```%3N```/````;^X```<```!_[@``#0```(?N```4
M````E>X```X```"J[@``#````+GN```;````QNX``"P```#B[@``$P````_O
M```<````(^\``"@```!`[P``!@```&GO```'````<.\``!,```!X[P``!0``
M`(SO```$````DN\``!<```"7[P``"@```*_O```,````NN\```D```#'[P``
M!@```-'O```)````V.\```@```#B[P``"0```.OO```*````]>\``!$`````
M\```!@```!+P```.````&?````X````H\```#0```#?P```+````1?```!T`
M``!1\```"P```&_P```"````>_````<```!^\```!@```(;P```)````C?``
M``<```"7\```.P```)_P```H````V_```#0````$\0``%0```#GQ```%````
M3_$```<```!5\0``"````%WQ```'````9O$```4```!N\0``!P```'3Q```.
M````?/$```D```"+\0``!@```)7Q```(````G/$```L```"E\0``!P```+'Q
M```(````N?$```<```#"\0``%@```,KQ```)````X?$```8```#K\0``"P``
M`/+Q```<````_O$``!0````;\@``!P```##R```(````./(```@```!!\@``
M!0```$KR```0````4/(``!````!A\@``!@```'+R```9````>?(```H```"3
M\@``'````)[R```'````N_(```4```##\@``$````,GR```4````VO(```L`
M``#O\@``#0```/OR```7````"?,```0````A\P``"0```";S```*````,/,`
M``<````[\P```@```$/S```.````1O,```@```!5\P``'P```%[S```C````
M?O,``#@```"B\P``,0```-OS```G````#?0``&0````U]```%````)KT``!5
M````K_0``#@````%]0``2@```#[U``!;````B?4``"@```#E]0``.`````[V
M```H````1_8``"P```!P]@``)P```)WV```;````Q?8``#X```#A]@``J0$`
M`"#W```C````RO@``!<```#N^```2`````;Y``"%````3_D``#````#5^0``
M00````;Z``!;````2/H``$D```"D^@``'0```.[Z```8````#/L``"$````E
M^P``'P```$?[```K````9_L``"$```"3^P``)P```+7[```=````W?L``!$`
M``#[^P``,P````W\```E````0?P``"<```!G_```'P```(_\```P````K_P`
M`&D```#@_```/0```$K]``!E````B/T``$T```#N_0``+P```#S^```N````
M;/X``#````";_@``5````,S^``!:````(?\``$@```!\_P``2@```,7_```R
M````$``!`"\```!#``$`+````',``0`M````H``!`'$```#.``$`;P```$`!
M`0"S````L`$!`!<```!D`@$`)0```'P"`0`R````H@(!`"D```#5`@$`/@``
M`/\"`0`B````/@,!`%(```!A`P$`)0```+0#`0`+````V@,!`+$```#F`P$`
M10```)@$`0`A````W@0!`#``````!0$`)0```#$%`0`<````5P4!`#$```!T
M!0$`!P```*8%`0`'````K@4!``0```"V!0$`#0```+L%`0`+````R04!``X`
M``#5!0$`"P```.0%`0`%````\`4!`!````#V!0$``@````<&`0!9````"@8!
M``4```!D!@$`$@```&H&`0`$````?08!``<```""!@$`"````(H&`0`%````
MDP8!``,```"9!@$`$````)T&`0`,````K@8!`!,```"[!@$`#0```,\&`0`"
M````W08!``<```#@!@$`!@```.@&`0`4````[P8!``P````$!P$`&````!$'
M`0`&````*@<!`!(````Q!P$`#````$0'`0`#````40<!`"H```!5!P$`!```
M`(`'`0`&````A0<!``<```",!P$`'P```)0'`0`U````M`<!`"X```#J!P$`
M+P```!D(`0`7````20@!`"````!A"`$`&P```(((`0`8````G@@!`"0```"W
M"`$`'P```-P(`0`:````_`@!`"`````7"0$`&@```#@)`0`R````4PD!`"\`
M``"&"0$`*P```+8)`0`?````X@D!`",````""@$`'P```"8*`0`:````1@H!
M`"4```!A"@$`)@```(<*`0`E````K@H!`"0```#4"@$`&````/D*`0`=````
M$@L!`"0````P"P$`&````%4+`0`B````;@L!`"4```"1"P$`/````+<+`0`?
M````]`L!`",````4#`$`'P```#@,`0`@````6`P!`!H```!Y#`$`&````)0,
M`0`F````K0P!`!X```#4#`$`*0```/,,`0`>````'0T!``D````\#0$`#```
M`$8-`0`7````4PT!`"\```!K#0$`)````)L-`0`'````P`T!``\```#(#0$`
M%````-@-`0`.````[0T!``T```#\#0$`)`````H.`0`%````+PX!``<````U
M#@$`(@```#T.`0`E````8`X!`!T```"&#@$`&@```*0.`0`'````OPX!`,<`
M``#'#@$`"P```(\/`0`5````FP\!``8```"Q#P$`"0```+@/`0`+````P@\!
M`!<```#.#P$`!@```.8/`0`S````[0\!`!,````A$`$`$P```#40`0`'````
M21`!``\```!1$`$`!P```&$0`0`R````:1`!`"$```"<$`$`$P```+X0`0`,
M````TA`!`!$```#?$`$`,@```/$0`0`(````)!$!``D````M$0$`"@```#<1
M`0`4````0A$!``H```!7$0$`'0```&(1`0`(````@!$!`!\```")$0$`"```
M`*D1`0`:````LA$!``8```#-$0$`%0```-01`0`'````ZA$!``@```#R$0$`
M"0```/L1`0`_````!1(!``<```!%$@$`#P```$T2`0`.````71(!`!````!L
M$@$`"0```'T2`0`)````AQ(!``@```"1$@$`$P```)H2`0`'````KA(!`!D`
M``"V$@$`"@```-`2`0`7````VQ(!`!0```#S$@$`"@````@3`0`,````$Q,!
M`!<````@$P$`!````#@3`0`J````/1,!`!$```!H$P$`!P```'H3`0`"````
M@A,!`!````"%$P$`&````)83`0`+````KQ,!``,```"[$P$`"````+\3`0`&
M````R!,!``<```#/$P$`#0```-<3`0`+````Y1,!`!0```#Q$P$`%0````84
M`0`.````'!0!`"\````K%`$`(````%L4`0`<````?!0!``P```"9%`$`,0``
M`*84`0`%````V!0!`!(```#>%`$`/P```/$4`0`2````,14!``H```!$%0$`
M!@```$\5`0`$````5A4!``0```!;%0$`"@```&`5`0`3````:Q4!``4```!_
M%0$`!@```(45`0`&````C!4!``0```"3%0$`#````)@5`0`*````I14!``4`
M``"P%0$`&````+85`0`9````SQ4!`!\```#I%0$`'0````D6`0`1````)Q8!
M``(````Y%@$`!````#P6`0`*````018!``8```!,%@$`!0```%,6`0`#````
M618!``P```!=%@$`10```&H6`0`:````L!8!`#4```#+%@$`*`````$7`0!3
M````*A<!`!D```!^%P$`<@```)@7`0`@````"Q@!`#4````L&`$`(0```&(8
M`0!%````A!@!`#````#*&`$`*````/L8`0`I````)!D!`"8```!.&0$`)0``
M`'49`0`H````FQD!`"@```#$&0$`(@```.T9`0`P````$!H!`!(```!!&@$`
M$P```%0:`0`0````:!H!`'D```!Y&@$`"0```/,:`0!S````_1H!`'P```!Q
M&P$`*P```.X;`0`7````&AP!`!8````R'`$`#P```$D<`0`?````61P!`$``
M``!Y'`$`'P```+H<`0`<````VAP!`%$```#W'`$`%````$D=`0`*````7AT!
M``4```!I'0$`!@```&\=`0`(````=AT!``4```!_'0$`$@```(4=`0`0````
MF!T!`!,```"I'0$`'0```+T=`0`/````VQT!``\```#K'0$`!````/L=`0`)
M`````!X!``L````*'@$`!P```!8>`0`%````'AX!`!0````D'@$`!P```#D>
M`0`(````01X!``\```!*'@$`"````%H>`0`,````8QX!``\```!P'@$`!@``
M`(`>`0`4````AQX!``8```"<'@$`#````*,>`0`(````L!X!``0```"Y'@$`
M"@```+X>`0`'````R1X!``0```#1'@$`&0```-8>`0`"````\!X!``D```#S
M'@$`!@```/T>`0`&````!!\!`"<````+'P$`!````#,?`0`/````.!\!`!,`
M``!('P$`!P```%P?`0`'````9!\!``8```!L'P$`!@```',?`0`0````>A\!
M`!(```"+'P$`!@```)X?`0`)````I1\!`"(```"O'P$`!P```-(?`0`'````
MVA\!``L```#B'P$`!0```.X?`0`"````]!\!``L```#W'P$`QP$```,@`0`.
M````RR$!`!4```#:(0$`#0```/`A`0`'````_B$!``@````&(@$`"`````\B
M`0`*````&"(!``H````C(@$`$@```"XB`0`-````02(!``@```!/(@$`!0``
M`%@B`0`=````7B(!``P```!\(@$`#0```(DB`0`5````ER(!`!````"M(@$`
M"P```+XB`0`0````RB(!``@```#;(@$`$P```.0B`0`-````^"(!``H````&
M(P$`"P```!$C`0`+````'2,!``\````I(P$`!@```#DC`0`0````0",!`!8`
M``!1(P$`"P```&@C`0`2````=",!`!(```"'(P$`"````)HC`0`M````HR,!
M`!D```#1(P$`.````.LC`0!!````)"0!`%,```!F)`$`40```+HD`0!9````
M#"4!`%<```!F)0$`.P```+XE`0`*````^B4!``X````%)@$`%@```!0F`0`%
M````*R8!``8````Q)@$`&0```#@F`0`,````4B8!`!0```!?)@$`%P```'0F
M`0`G````C"8!`"8```"T)@$`$0```-LF`0`?````[28!``\````-)P$`!```
M`!TG`0`1````(B<!`!`````T)P$`!P```$4G`0`4````32<!`!$```!B)P$`
M&````'0G`0`.````C2<!`!$```"<)P$`"@```*XG`0`I````N2<!`!,```#C
M)P$`%P```/<G`0`0````#R@!`",````@*`$`!@```$0H`0`'````2R@!`$H`
M``!3*`$`#````)XH`0`(````JR@!``L```"T*`$`!P```,`H`0`(````R"@!
M``\```#1*`$`"````.$H`0`*````ZB@!``,```#U*`$`&0```/DH`0`/````
M$RD!`!D````C*0$`%````#TI`0`2````4BD!`"@```!E*0$`#````(XI`0`G
M````FRD!`!<```##*0$`(P```-LI`0`=````_RD!`!(````=*@$`$@```#`J
M`0`.````0RH!`!\```!2*@$`!@```'(J`0`&````>2H!``@```"`*@$`#@``
M`(DJ`0`'````F"H!``H```"@*@$`$0```*LJ`0`(````O2H!``\```#&*@$`
M%@```-8J`0`:````[2H!``@````(*P$`$@```!$K`0`%````)"L!`!8````J
M*P$`'@```$$K`0`-````8"L!`#````!N*P$`"0```)\K`0`'````J2L!`!0`
M``"Q*P$`!0```,8K`0`%````S"L!`!````#2*P$`"P```.,K`0`:````[RL!
M`#,````*+`$`#P```#XL`0`F````3BP!`#,```!U+`$`,0```*DL`0`P````
MVRP!``@````,+0$`!0```!4M`0`)````&RT!``@````E+0$`.0```"XM`0`M
M````:"T!`#@```"6+0$`4P```,\M`0`W````(RX!`#<```!;+@$`-@```),N
M`0`W````RBX!`"4````"+P$`*@```"@O`0`W````4R\!`#T```"++P$`#P``
M`,DO`0`3````V2\!`"<```#M+P$`'````!4P`0`.````,C`!``L```!!,`$`
M#````$TP`0`&````6C`!``P```!A,`$`&@```&XP`0`F````B3`!``8```"P
M,`$`!P```+<P`0`6````OS`!``D```#6,`$`"````.`P`0`&````Z3`!``D`
M``#P,`$`!@```/HP`0`%`````3$!``4````',0$`!P````TQ`0`&````%3$!
M``H````<,0$`)0```"<Q`0`/````33$!``D```!=,0$`!0```&<Q`0`'````
M;3$!``<```!U,0$`!0```'TQ`0`-````@S$!``8```"1,0$`$P```)@Q`0`#
M````K#$!``@```"P,0$`"@```+DQ`0`-````Q#$!``@```#2,0$`(P```-LQ
M`0`1````_S$!``D````1,@$`$@```!LR`0`,````+C(!``<````[,@$``P``
M`$,R`0`#````1S(!`!0```!+,@$`%````&`R`0`(````=3(!``@```!^,@$`
M"````(<R`0`'````D#(!`%<```"8,@$`)````/`R`0`&````%3,!``8````<
M,P$`%P```",S`0`:````.S,!`!P```!6,P$`+````',S`0`;````H#,!`"X`
M``"\,P$`<@```.LS`0`E````7C0!``H```"$-`$`!P```(\T`0`2````ES0!
M`!$```"J-`$`#P```+PT`0`.````S#0!`!0```#;-`$`$````/`T`0`4````
M`34!``\````6-0$`%0```"8U`0`%````/#4!`!<```!"-0$`&P```%HU`0`7
M````=C4!`!0```".-0$``P```*,U`0`&````IS4!`&@```"N-0$`!````!<V
M`0`6````'#8!``4````S-@$`!````#DV`0`>````/C8!`!@```!=-@$`#```
M`'8V`0`8````@S8!`!@```"<-@$`+0```+4V`0`.````XS8!`"(```#R-@$`
M"````!4W`0`:````'C<!`!@````Y-P$`$P```%(W`0`<````9C<!`!@```"#
M-P$`%````)PW`0`+````L3<!``@```"]-P$`!P```,8W`0`0````SC<!`!4`
M``#?-P$`$````/4W`0`(````!C@!``4````/.`$`"P```!4X`0`,````(3@!
M``@````N.`$`#0```#<X`0`'````13@!``8```!-.`$`$0```%0X`0`(````
M9C@!``P```!O.`$`!P```'PX`0`%````A#@!``@```"*.`$`"````),X`0`3
M````G#@!``L```"P.`$`#@```+PX`0`%````RS@!`!T```#1.`$`$````.\X
M`0`1`````#D!`#0````2.0$`1````$<Y`0`?````C#D!`#$```"L.0$`"@``
M`-XY`0`/````Z3D!``<```#Y.0$`"0````$Z`0`/````"SH!``D````;.@$`
M$0```"4Z`0`A````-SH!`"$```!9.@$`)````'LZ`0`D````H#H!`!@```#%
M.@$`(0```-XZ`0`;`````#L!`"4````<.P$`&@```$([`0`=````73L!`!@`
M``![.P$`(P```)0[`0`I````N#L!`!L```#B.P$`)@```/X[`0`P````)3P!
M`"X```!6/`$`$0```(4\`0`I````ESP!``X```#!/`$`L````-`\`0`0````
M@3T!`!@```"2/0$`(P```*L]`0`D````SST!`!\```#T/0$`&P```!0^`0`@
M````,#X!`"$```!1/@$`+@```',^`0`<````HCX!`!X```"_/@$`*0```-X^
M`0!+````"#\!``\```!4/P$`!````&0_`0`2````:3\!``@```!\/P$`#@``
M`(4_`0`.````E#\!`!(```"C/P$`"P```+8_`0`4````PC\!``H```#7/P$`
M!````.(_`0`,````YS\!``\```#T/P$`#P````1``0`3````%$`!``P````H
M0`$`,0```#5``0`+````9T`!`!$```!S0`$`!````(5``0`/````BD`!`!4`
M``":0`$`&````+!``0`/````R4`!``(```#90`$`!0```-Q``0`2````XD`!
M``4```#U0`$`"P```/M``0`,````!T$!``,````400$`#P```!A!`0`(````
M*$$!`!@````Q00$`$````$I!`0`*````6T$!`!````!F00$`$P```'=!`0`(
M````BT$!``8```"400$`#@```)M!`0`,````JD$!`!@```"W00$`#````-!!
M`0`.````W4$!`",```#L00$`#````!!"`0`>````'4(!`!<````\0@$`%0``
M`%1"`0`,````:D(!``8```!W0@$`#@```'Y"`0`%````C4(!`"<```"30@$`
M/P```+M"`0`%````^T(!``D````!0P$`'@````M#`0`+````*D,!`!,````V
M0P$`$P```$I#`0`'````7D,!`!D```!F0P$`$@```(!#`0`8````DT,!`!``
M``"L0P$`%0```+U#`0`(````TT,!``@```#<0P$`)@```.5#`0!(````#$0!
M``@```!51`$`%@```%Y$`0`'````=40!``H```!]1`$`,0```(A$`0`/````
MND0!``4```#*1`$`!@```-!$`0`#````UT0!``<```#;1`$`!P```.-$`0`,
M````ZT0!``\```#X1`$`#0````A%`0`-````%D4!`!0````D10$`%0```#E%
M`0`4````3T4!``4```!D10$`!0```&I%`0`+````<$4!``@```!\10$``@``
M`(5%`0`%````B$4!``\```".10$`(0```)Y%`0`2````P$4!`!````#310$`
M#P```.1%`0`1````]$4!`!X````&1@$`,0```"5&`0`M````5T8!``H```"%
M1@$`#@```)!&`0"+````GT8!`!8````K1P$`$````$)'`0`'````4T<!``4`
M``!;1P$`(0```&%'`0`(````@T<!``<```",1P$`!P```)1'`0`&````G$<!
M`!````"C1P$`#@```+1'`0`1````PT<!``\```#51P$`&P```.5'`0`1````
M`4@!``T````32`$`%P```"%(`0`'````.4@!``D```!!2`$`%````$M(`0`-
M````8$@!`#L```!N2`$`&0```*I(`0`(````Q$@!``T```#-2`$`'0```-M(
M`0`9````^4@!`"$````320$`(````#5)`0`:````5DD!`!L```!Q20$`)0``
M`(U)`0`:````LTD!``4```#.20$`'0```-1)`0`0````\DD!``X````#2@$`
M`P```!)*`0`$````%DH!``T````;2@$`#@```"E*`0`/````.$H!`!<```!(
M2@$`"P```&!*`0`$````;$H!`!@```!Q2@$`&0```(I*`0`/````I$H!``T`
M``"T2@$`#0```,)*`0`.````T$H!`!\```#?2@$`!@```/]*`0`&````!DL!
M``X````-2P$`#@```!Q+`0`-````*TL!``@````Y2P$`"````$)+`0`$````
M2TL!`!0```!02P$`"P```&5+`0`%````<4L!`"0```!W2P$`#P```)Q+`0!K
M````K$L!`!H````83`$`"0```#-,`0`&````/4P!``H```!$3`$`!@```$],
M`0`(````5DP!``0```!?3`$`"@```&1,`0`"````;TP!``0```!R3`$`!P``
M`'=,`0`5````?TP!`!(```"53`$`%````*A,`0`:````O4P!``(```#83`$`
M`@```-M,`0`.````WDP!``8```#M3`$`"@```/1,`0`%````_TP!`!D````%
M30$`"````!]-`0`&````*$T!`!<````O30$`$````$=-`0`)````6$T!``<`
M``!B30$`!0```&I-`0`)````<$T!``T```!Z30$`!@```(A-`0`&````CTT!
M`!D```"630$`"P```+!-`0`%````O$T!`!(```#"30$`!P```-5-`0`'````
MW4T!`!@```#E30$`'0```/Y-`0`'````'$X!``H````D3@$`!````"].`0`)
M````-$X!``@````^3@$`"P```$=.`0`+````4TX!``8```!?3@$`#0```&9.
M`0`&````=$X!``0```![3@$`-P```(!.`0!!````N$X!`#@```#Z3@$`)@``
M`#-/`0`%````6D\!``\```!@3P$`!@```'!/`0`(````=T\!`!\```"`3P$`
M&@```*!/`0`%````NT\!``@```#!3P$`$P```,I/`0`(````WD\!``D```#G
M3P$`%P```/%/`0`&````"5`!``8````04`$`%0```!=0`0`%````+5`!``L`
M```S4`$`#````#]0`0`(````3%`!``D```!54`$`!0```%]0`0`N````95`!
M`#0```"44`$`/````,E0`0`G````!E$!`#X````N40$`.````&U1`0`H````
MIE$!`#(```#/40$`+0````)2`0`U````,%(!`"@```!F4@$`$@```(]2`0`3
M````HE(!``T```"V4@$`,0```,12`0`<````]E(!`!P````34P$`&@```#!3
M`0`'````2U,!``@```!34P$`!P```%Q3`0`(````9%,!`"8```!M4P$`)```
M`)13`0`Q````N5,!``D```#K4P$`&````/53`0`H````#E0!`!8````W5`$`
M$@```$Y4`0`&````850!``L```!H5`$`#````'14`0`.````@50!``\```"0
M5`$`.````*!4`0"`````V50!`&8```!:50$`#P```,%5`0`+````T54!``P`
M``#=50$`$0```.I5`0`2````_%4!``X````/5@$`!P```!Y6`0`/````)E8!
M`!0````V5@$`$0```$M6`0`/````758!`!X```!M5@$`,````(Q6`0!]````
MO58!`!`````[5P$`!0```$Q7`0`4````4E<!``D```!G5P$`"0```'%7`0`)
M````>U<!`!(```"%5P$`#@```)A7`0`.````IU<!`!,```"V5P$`%0```,I7
M`0`?````X%<!`"$`````6`$`'0```")8`0`?````0%@!`"````!@6`$`(@``
M`(%8`0`8````I%@!`#<```"]6`$`#P```/58`0`1````!5D!`!$````760$`
M$P```"E9`0`-````/5D!`!(```!+60$`%````%Y9`0`/````<UD!`!$```"#
M60$`,@```)59`0`6````R%D!`!0```#?60$`/````/19`0`4````,5H!``H`
M``!&6@$`$P```%%:`0`B````95H!`!(```"(6@$`*````)M:`0`9````Q%H!
M`!D```#>6@$`%P```/A:`0`2````$%L!`!\````C6P$`(@```$-;`0`:````
M9EL!`!(```"!6P$`%P```)1;`0`<````K%L!`!8```#)6P$`"````.!;`0`8
M````Z5L!``0````"7`$`!0````=<`0`+````#5P!`!`````97`$`!@```"I<
M`0`,````,5P!``<````^7`$`!@```$9<`0`'````35P!``4```!57`$`"```
M`%M<`0`8````9%P!``8```!]7`$`"0```(1<`0`(````CEP!``8```"77`$`
M"````)Y<`0`1````IUP!`!(```"Y7`$`#P```,Q<`0`0````W%P!``H```#M
M7`$`$0```/A<`0`$````"ET!`"$````/70$`#P```#%=`0`/````05T!`!8`
M``!170$`"P```&A=`0`)````=%T!``L```!^70$`+P```(I=`0`$````NET!
M``@```"_70$`!````,A=`0`%````S5T!`!$```#370$`!@```.5=`0`*````
M[%T!``H```#W70$`!0````)>`0`C````"%X!``X````L7@$`$0```#M>`0`5
M````35X!`!<```!C7@$`'````'M>`0`:````F%X!``4```"S7@$`!0```+E>
M`0`)````OUX!`!D```#)7@$`!P```.->`0`&````ZUX!``T```#R7@$`#@``
M``!?`0`'````#U\!``<````77P$`!0```!]?`0`/````)5\!``X````U7P$`
M"@```$1?`0`0````3U\!`!(```!@7P$`%````'-?`0`4````B%\!``T```"=
M7P$`%@```*M?`0`(````PE\!``4```#+7P$`$@```-%?`0!(````Y%\!``8`
M```M8`$`#P```#1@`0`C````1&`!``\```!H8`$`%0```'A@`0`.````CF`!
M``T```"=8`$`#P```*M@`0`)````NV`!``\```#%8`$`#P```-5@`0`1````
MY6`!`!````#W8`$`'@````AA`0`*````)V$!``@````R80$`#````#MA`0`,
M````2&$!``P```!580$`!0```&)A`0`,````:&$!``D```!U80$`'@```']A
M`0!G````GF$!`!,````&8@$`"P```!IB`0`%````)F(!``4````L8@$`$@``
M`#)B`0`4````16(!`!,```!:8@$`"P```&YB`0`"````>F(!``H```!]8@$`
M+P```(AB`0`#````N&(!``4```"\8@$`)@```,)B`0`*````Z6(!``4```#T
M8@$`!0```/IB`0`3`````&,!`!(````48P$`!@```"=C`0`(````+F,!``<`
M```W8P$`!````#]C`0`%````1&,!`&X```!*8P$`"@```+EC`0`-````Q&,!
M``8```#28P$`!0```-EC`0`I````WV,!`#(````)9`$`$0```#QD`0`*````
M3F0!`!$```!99`$`"@```&MD`0`)````=F0!`!D```"`9`$`)P```)ID`0`I
M````PF0!`"@```#L9`$`#P```!5E`0`&````)64!``<````L90$`"````#1E
M`0`'````/64!``X```!%90$`#````%1E`0`&````864!`$4```!H90$`$```
M`*YE`0`*````OV4!``8```#*90$`'````-%E`0!A````[F4!``8```!09@$`
M"````%=F`0`&````8&8!`!0```!G9@$`"0```'QF`0`(````AF8!`"D```"/
M9@$`*````+EF`0`)````XF8!``4```#L9@$`*P```/)F`0!G````'F<!`"D`
M``"&9P$`+@```+!G`0`8````WV<!``(```#X9P$`#0```/MG`0`%````"6@!
M`!0````/:`$`"@```"1H`0`%````+V@!``@````U:`$`!@```#YH`0`)````
M16@!``L```!/:`$`!P```%MH`0`(````8V@!``L```!L:`$`!@```'AH`0`.
M````?V@!`!````".:`$`$0```)]H`0`-````L6@!``\```"_:`$`$````,]H
M`0`/````X&@!``T```#P:`$`#P```/YH`0`(````#FD!`!X````7:0$`$P``
M`#9I`0`(````2FD!``H```!3:0$`%@```%YI`0`'````=6D!``\```!]:0$`
M!0```(UI`0`'````DVD!``4```";:0$`!0```*%I`0`(````IVD!`!$```"P
M:0$`$0```,)I`0`:````U&D!`!8```#O:0$`%`````9J`0`7````&VH!`!H`
M```S:@$`'P```$YJ`0`8````;FH!``,```"':@$`!0```(MJ`0`.````D6H!
M``X```"@:@$`%@```*]J`0`B````QFH!``L```#I:@$`%````/5J`0`'````
M"FL!``H````2:P$`!0```!UK`0`.````(VL!``D````R:P$`!0```#QK`0`'
M````0FL!``,```!*:P$`!````$YK`0`"````4VL!`#X```!6:P$`-````)5K
M`0`4````RFL!`"H```#?:P$`10````IL`0`*````4&P!`"P```!;;`$`,P``
M`(AL`0`X````O&P!`#@```#U;`$`/0```"YM`0`4````;&T!`!H```"!;0$`
M&P```)QM`0`<````N&T!`!L```#5;0$`'P```/%M`0`;````$6X!`!L````M
M;@$`#@```$EN`0`P````6&X!`#````");@$`-````+IN`0`]````[VX!`#(`
M```M;P$`+P```&!O`0!R````D&\!`"8````#<`$`#````"IP`0`*````-W`!
M`#,```!"<`$`-0```'9P`0`G````K'`!``T```#4<`$`1````.)P`0`_````
M)W$!``4```!G<0$`&P```&UQ`0`6````B7$!`!(```"@<0$`$0```+-Q`0`9
M````Q7$!``8```#?<0$`!P```.9Q`0`)````[G$!``X```#X<0$`%`````=R
M`0`.````''(!`!$````K<@$`"````#UR`0`>````1G(!``@```!E<@$`!0``
M`&YR`0`+````='(!``T```"`<@$`"P```(YR`0`Z````FG(!``(```#5<@$`
M!@```-AR`0`.````WW(!``D```#N<@$`!0```/AR`0`2````_G(!``@````1
M<P$`!````!IS`0`S````'W,!``X```!3<P$`*0```&)S`0!0````C',!`!4`
M``#=<P$`.@```/-S`0`@````+G0!``\```!/=`$`"````%]T`0`/````:'0!
M``\```!X=`$`"@```(AT`0`4````DW0!``P```"H=`$`&@```+5T`0`5````
MT'0!``<```#F=`$`$0```.YT`0`1`````'4!`"$````2=0$`%````#1U`0`2
M````274!`!````!<=0$`(P```&UU`0`'````D74!``L```"9=0$`%````*5U
M`0`2````NG4!`!$```#-=0$`&@```-]U`0`0````^G4!``P````+=@$`!P``
M`!AV`0`(````('8!``4````I=@$`(0```"]V`0`&````478!`!$```!8=@$`
M"````&IV`0`.````<W8!``4```""=@$`#P```(AV`0`O````F'8!`!(```#(
M=@$`!@```-MV`0`'````XG8!`!<```#J=@$`!@````)W`0`2````"7<!``4`
M```<=P$`%0```")W`0`$````.'<!``<````]=P$`%@```$5W`0`Q````7'<!
M``4```".=P$`$P```)1W`0`0````J'<!``0```"Y=P$`#@```+YW`0`(````
MS7<!``<```#6=P$`"@```-YW`0`(````Z7<!``8```#R=P$`!0```/EW`0`@
M````_W<!`#4````@>`$`-0```%9X`0`;````C'@!`"0```"H>`$`(P```,UX
M`0`_````\7@!`!L````Q>0$`)@```$UY`0`M````='D!`"0```"B>0$`!@``
M`,=Y`0`(````SGD!``D```#7>0$`"P```.%Y`0`7````[7D!`!`````%>@$`
M+@```!9Z`0`D````17H!`#0```!J>@$`.````)]Z`0`1````V'H!`"(```#J
M>@$`$@````U[`0`&````('L!`!L````G>P$`$@```$-[`0`1````5GL!``T`
M``!H>P$`!P```'9[`0`.````?GL!``@```"->P$`"P```)9[`0`,````HGL!
M`!L```"O>P$`-````,M[`0`)`````'P!``4````*?`$`"0```!!\`0`:````
M&GP!`!$````U?`$`!````$=\`0`*````3'P!``L```!7?`$`$````&-\`0`.
M````='P!``P```"#?`$`%@```)!\`0`%````IWP!``4```"M?`$`#P```+-\
M`0`L````PWP!`$L```#P?`$`%@```#Q]`0`=````4WT!`!H```!Q?0$`!0``
M`(Q]`0`0````DGT!``<```"C?0$`$0```*M]`0`L````O7T!``D```#J?0$`
M#@```/1]`0`1`````WX!`!4````5?@$`#0```"M^`0`Y````.7X!``D```!S
M?@$`'0```'U^`0`3````FWX!`!<```"O?@$`+P```,=^`0`/````]WX!`!$`
M```'?P$`%P```!E_`0`>````,7\!``@```!0?P$`$@```%E_`0`'````;'\!
M`!0```!T?P$`&@```(E_`0`'````I'\!``<```"L?P$`$````+1_`0`/````
MQ7\!`!$```#5?P$`!0```.=_`0`(````[7\!``T```#V?P$`#0````2``0`.
M````$H`!`!`````A@`$`$````#*``0`&````0X`!``@```!*@`$`+@```%.`
M`0`F````@H`!`"0```"I@`$`!P```,Z``0`.````UH`!``8```#E@`$`%P``
M`.R``0`7````!($!`"(````<@0$`"@```#^!`0`+````2H$!``,```!6@0$`
M!@```%J!`0`,````88$!``(```!N@0$`#````'&!`0`3````?H$!``L```"2
M@0$`&0```)Z!`0`@````N($!`!(```#9@0$`!0```.R!`0`*````\H$!`!4`
M``#]@0$`$0```!."`0`.````)8(!``8````T@@$`"0```#N"`0`0````18(!
M`$H```!6@@$`%P```*&"`0`$````N8(!``@```"^@@$`%````,>"`0`.````
MW((!``P```#K@@$`(@```/B"`0`7````&X,!``T````S@P$`(P```$&#`0`<
M````98,!``T```""@P$`8@```)"#`0`B````\X,!`!8````6A`$`*P```"V$
M`0`@````680!`!0```!ZA`$`'@```(^$`0`6````KH0!`!\```#%A`$`&```
M`.6$`0`*````_H0!``<````)A0$`!P```!&%`0`$````&84!`!,````>A0$`
M#0```#*%`0`1````0(4!``@```!2A0$`00```%N%`0`\````G84!`$(```#:
MA0$`8````!V&`0`)````?H8!`#X```"(A@$`+P```,>&`0`*````]X8!``H`
M```"AP$`#@````V'`0`[````'(<!``@```!8AP$`.````&&'`0`N````FH<!
M`"(```#)AP$`#P```.R'`0`I````_(<!`!@````FB`$`,````#^(`0`B````
M<(@!`"@```"3B`$`(@```+R(`0`/````WX@!``@```#OB`$`#@```/B(`0`/
M````!XD!`!`````7B0$`!P```"B)`0`]````,(D!``P```!NB0$`#@```'N)
M`0`&````BHD!`!4```"1B0$`"````*>)`0`(````L(D!``\```"YB0$`"0``
M`,F)`0`)````TXD!``<```#=B0$`$````.6)`0`0````]HD!`!8````'B@$`
M%P```!Z*`0`1````-HH!`!L```!(B@$`$P```&2*`0`(````>(H!``T```"!
MB@$`#````(^*`0`/````G(H!``P```"LB@$`&0```+F*`0`L````TXH!``\`
M````BP$`'P```!"+`0`H````,(L!``@```!9BP$`!@```&*+`0`0````:8L!
M``D```!ZBP$`!````(2+`0`8````B8L!``X```"BBP$`$````+&+`0`.````
MPHL!``4```#1BP$`"0```->+`0`(````X8L!``D```#JBP$`"P```/2+`0`1
M`````(P!``0````2C`$`#@```!>,`0`%````)HP!``L````LC`$`#@```#B,
M`0`A````1XP!``H```!IC`$``@```'2,`0`'````=XP!``4```!_C`$`"P``
M`(6,`0`'````D8P!`#(```"9C`$`)````,R,`0`Q````\8P!`!<````CC0$`
M!0```#N-`0`'````08T!``<```!)C0$`#````%&-`0`(````7HT!``T```!G
MC0$`$P```'6-`0`/````B8T!``P```"9C0$`#@```*:-`0`+````M8T!``<`
M``#!C0$`"````,F-`0`(````THT!`!8```#;C0$`"0```/*-`0`'````_(T!
M``D````$C@$`(`````Z.`0`%````+XX!``8````UC@$`!@```#R.`0`*````
M0XX!``<```!.C@$`$@```%:.`0`2````:8X!``8```!\C@$`%@```(..`0`+
M````FHX!`!L```"FC@$`!````,*.`0`%````QXX!``\```#-C@$`'````-V.
M`0`'````^HX!``D````"CP$`%0````R/`0`$````(H\!``H````GCP$`#P``
M`#*/`0`*````0H\!``(```!-CP$`$0```%"/`0`'````8H\!`!X```!JCP$`
M'@```(F/`0`S````J(\!`"4```#<CP$`*0````*0`0!=````+)`!`!,```"*
MD`$`5````)Z0`0`N````\Y`!`$$````BD0$`7@```&21`0`@````PY$!`$H`
M``#DD0$`*````"^2`0`R````6)(!`",```"+D@$`'0```*^2`0`L````S9(!
M`.X!``#ZD@$`&P```.F4`0`4````!94!`$8````:E0$`A0```&&5`0`_````
MYY4!`#$````GE@$`2P```%F6`0`X````I98!`!P```#>E@$`%0```/N6`0`8
M````$9<!`!<````JEP$`*P```$*7`0`<````;I<!`!\```"+EP$`$P```*N7
M`0`,````OY<!`"\```#,EP$`'@```/R7`0`?````&Y@!`"$````[F`$`0@``
M`%V8`0!0````H)@!`#4```#QF`$`80```">9`0!&````B9D!`"\```#0F0$`
M)P````":`0`L````*)H!`$<```!5F@$`4````)V:`0!!````[IH!`$X````P
MFP$`+0```'^;`0`E````K9L!`"4```#3FP$`)@```/F;`0!J````()P!`&@`
M``"+G`$`K@```/2<`0`;````HYT!`"H```"_G0$`-@```.J=`0`O````(9X!
M`$4```!1G@$`(````)>>`0!1````N)X!`"$````*GP$`"P```"R?`0"U````
M.)\!`#P```#NGP$`(@```"N@`0`J````3J`!`"L```!YH`$`'````*6@`0`O
M````PJ`!``8```#RH`$`!@```/F@`0`#`````*$!``X````$H0$`"P```!.A
M`0`*````'Z$!``L````JH0$`!0```#:A`0`,````/*$!``0```!)H0$`;@``
M`$ZA`0`$````O:$!`!8```#"H0$`!````-FA`0`'````WJ$!``4```#FH0$`
M!0```.RA`0`$````\J$!`!````#WH0$`"`````BB`0`1````$:(!`!,````C
MH@$``@```#>B`0`'````.J(!``<```!"H@$`%````$JB`0`,````7Z(!`!8`
M``!LH@$`!@```(.B`0`3````BJ(!``P```">H@$``P```*NB`0`H````KZ(!
M``0```#8H@$`!@```-VB`0`(````Y*(!`!L```#MH@$`-`````FC`0`G````
M/J,!`"@```!FHP$`$P```(^C`0`@````HZ,!`!T```#$HP$`&P```.*C`0`@
M````_J,!`!L````?I`$`&@```#ND`0`B````5J0!`!0```!YI`$`,0```(ZD
M`0`O````P*0!`"8```#PI`$`&@```!>E`0`>````,J4!`!X```!1I0$`&0``
M`'"E`0`C````BJ4!`!T```"NI0$`*````,RE`0`:````]:4!`!L````0I@$`
M(````"RF`0`C````3:8!`!D```!QI@$`(0```(NF`0`>````K:8!`#8```#,
MI@$`'@````.G`0`B````(J<!`"(```!%IP$`(P```&BG`0`=````C*<!`!@`
M``"JIP$`(@```,.G`0`A````YJ<!`#(````(J`$`(````#NH`0`*````7*@!
M``L```!GJ`$`%@```'.H`0`H````BJ@!`!T```"SJ`$`"@```-&H`0`/````
MW*@!`!<```#LJ`$`#@````2I`0`6````$ZD!`"$````JJ0$`"````$RI`0`'
M````5:D!`"(```!=J0$`)0```("I`0`E````IJD!`!8```#,J0$`"@```..I
M`0#<````[JD!`!$```#+J@$`%0```-VJ`0`,````\ZH!``\`````JP$`%@``
M`!"K`0`C````)ZL!``8```!+JP$`0````%*K`0`5````DZL!`!0```"IJP$`
M!P```+ZK`0`3````QJL!``H```#:JP$`-P```.6K`0`I````':P!`!8```!'
MK`$`%````%ZL`0`4````<ZP!`#$```"(K`$`$0```+JL`0`2````S*P!`!,`
M``#?K`$`$0```/.L`0`*````!:T!`!<````0K0$`"````"BM`0`@````,:T!
M``@```!2K0$`$P```%NM`0`'````;ZT!`!$```!WK0$`!P```(FM`0`(````
MD:T!``D```":K0$`-@```*2M`0`%````VZT!``\```#AK0$`%````/&M`0`1
M````!JX!``L````8K@$`#````"2N`0`'````,:X!`!,````YK@$`"P```$VN
M`0`;````6:X!`!````!UK@$`&@```(:N`0`7````H:X!``L```"YK@$`#```
M`,6N`0`8````TJX!``D```#KK@$`*@```/6N`0`1````(*\!``H````RKP$`
M`@```#VO`0`0````0*\!`!<```!1KP$`"P```&FO`0`#````=:\!``H```!Y
MKP$`!0```(2O`0`'````BJ\!``P```"2KP$`"P```)^O`0`4````JZ\!`!4`
M``#`KP$`#@```-:O`0`X````Y:\!`!@````>L`$`&````#>P`0`*````4+`!
M`"4```!;L`$`!0```(&P`0`6````A[`!`#P```">L`$`#0```-NP`0`.````
MZ;`!``8```#XL`$`!````/^P`0`$````!+$!``H````)L0$`%P```!2Q`0`%
M````++$!``8````RL0$`"````#FQ`0`%````0K$!`!0```!(L0$`%0```%VQ
M`0`%````<[$!`!<```!YL0$`'@```)&Q`0`?````L+$!`!H```#0L0$`$```
M`.NQ`0`"````_+$!``0```#_L0$`"P````2R`0`%````$+(!``4````6L@$`
M`P```!RR`0`.````(+(!`$P````OL@$`'````'RR`0`J````F;(!`"8```#$
ML@$`3@```.NR`0`?````.K,!`%T```!:LP$`'0```+BS`0!'````UK,!`"``
M```>M`$`,0```#^T`0`S````<;0!`"@```"EM`$`-````,ZT`0`V`````[4!
M`#0````ZM0$`,````&^U`0`H````H+4!`"(```#)M0$`.````.RU`0`4````
M);8!`!4````ZM@$`#@```%"V`0!A````7[8!``H```#!M@$`8P```,RV`0!I
M````,+<!`"<```":MP$`&P```,*W`0`8````WK<!`!$```#WMP$`'0````FX
M`0`Y````)[@!`"(```!AN`$`&P```(2X`0!J````H+@!`!8````+N0$`"@``
M`"*Y`0`$````+;D!``8````RN0$`"````#FY`0`%````0KD!`!4```!(N0$`
M$@```%ZY`0`9````<;D!`",```"+N0$`#P```*^Y`0`-````O[D!``0```#-
MN0$`"0```-*Y`0`-````W+D!``@```#JN0$`"0```/.Y`0`6````_;D!``L`
M```4N@$`"@```""Z`0`5````*[H!``D```!!N@$`!@```$NZ`0`3````4KH!
M``H```!FN@$`%@```'&Z`0`*````B+H!``<```"3N@$`"````)NZ`0`(````
MI+H!``P```"MN@$`!@```+JZ`0`&````P;H!`!D```#(N@$``@```.*Z`0`(
M````Y;H!``8```#NN@$`!@```/6Z`0`I````_+H!``4````FNP$`$P```"R[
M`0`9````0+L!``@```!:NP$`!P```&.[`0`&````:[L!``H```!RNP$`$```
M`'V[`0`9````CKL!``@```"HNP$`#````+&[`0`C````OKL!``H```#BNP$`
M"0```.V[`0`0````][L!``4````(O`$``@````Z\`0`+````$;P!``$````N
M`0``$`4``(@&``#/!```X@4``/\````5`@```````#0%```=`0``/P,`````
M``!(!`````````4#```D````=08`````````````(@$``-4#``!H`0``G@$`
M`"$#``!L!```S@$``$`&``!)`P``0`````````"?`P````````````#@`P``
M*04``)<!````````N0,``)4$````````*0``````````````'`0``$<&````
M````KP,`````````````.@$``&T!``#7!```/0,``/8#```V`P````````D$
M````````+0$``",$``#R!0``7`$`````````````5P,```````"Q`P``G0(`
M`)8#``!=`0``>`0``/X"````````W0(``/H```"5`0```````"X&``#2````
M%`8```<$````````O`,``.0%``"2!```#`,``'(&``"B`P``00$```````#K
M!```````````````````50```#D"``"\````%P8``.`````W!```80````,`
M`````````P$``-,"``"7!```2@,``-(!```)`@```````(8!``#)!```'P(`
M`.$`````````G@,```T$``!.`P``=@,``+<#``#/`````````,<!``!%`0``
M`````"`%``!^!0``)08``.8```#P!```.`,``&T$`````````````!D"``#N
M`@``F`8``'<$``"C`0``S`0``-P```#K`@``30$``!`"``#'````#0,``%,#
M```8!@``0`4```@!````````;@0``$8!````````_P(``'D%``#7`0``K@0`
M`&8`````````*@0``````````````````/0"``!&!@``F`0``.8$``!7!@``
MX@,``"8&``#]`P``RP4``-T#```````````````````F`@```````!X```#@
M!0``S@(``````````````````(D%``"0`P``,P(``/(#``"Y`0``Y`(``'\$
M``!*!0```````-H%``".!@``I0,``'4```#@`0``G@4``"0"````````<@4`
M`,`$``!;`@``1P$``!0$`````````````,8#``"-!0``FP,`````````````
M8`$``(H````M!0``?0,``(0%``!\!0``O@,```@````$!@``YP0``-@$``#:
M!`````````<!```\````.`(``$8```#M!```.P(````````V`````````)`$
M````````VP````````"$!```B`0```````"G`P``4P$``#T"``#E`P``$@$`
M``````";`@```````*0#``"D`@``;`,``%@#``#G`@`````````%``#4`@``
M^`$``#\```"N`0```````(@%``!A`@``Q04``$4"```S!0``I0$``'0#``"-
M!@``D@```+H%``!#`0``O@0```````````````````````"2!@``\0$``(8$
M``"3`0``1`(```````!W!@```````%@```!1`0``J`0``(P"````````9@,`
M`*4"````````J````#0!````````H0```'L!``#8!0``5@8``%(&``!@`P``
M208`````````````<`$``+T$`````````````$T%``"#`P```````$P$``#]
M!```%P(``$D```#C`0``TP,```````"J`0``>````&L#``#L`@``M`0`````
M````````<`4``)P```#"!0``.@```"4"```M!```7@(```````#S`P``"@(`
M``````!P`@``_P0``(0```#)````%@8`````````````30```#,```#E!```
M`````*8!``!>`P``*P$``'<#``"G!0```````#X#``!,`0````````\```"1
M!@``5P(``/``````````P04```\"``"$`@``;0,``'0$```+`P``*````)T$
M``"/`P``@0,``#$#``!Z!```H0$``+H#``"8`P``+@4``%,&`````@``.P,`
M`-(#````````<P0``$H$``".`0``O04``+(%``"L`@``(`(`````````````
MW`4``,8"`````````0(``!4!``#,`@```````!````!=``````````````!`
M`0``JP4``.P#```\`@``"08```````"-`0``C@4```````#&!0``9`$``/,"
M````````(````.,````3!0```````"4$``````````````````!T!@``U0(`
M`'(````8!``````````````T!```W`(```````"?````U@(```,&````````
MD0,```\%``!B`@``.@4`````````````;@4``*X%```9!@``5`8``*\"``"=
M`0``CP````````"I!0```````/<!```6````$@,``,$```!P`P``#@(``",%
M````````;P0`````````````,`8``%0```!8`0``OP$``($$``"#`@``````
M`*D"``"'!@``'````%4"````````)P$```````!#!0``^0(``/@"``#`!0``
M1@4``)D$`````````````#8$```'`P``8P4``(P!````````````````````
M`````````&`$`````````````'8!````````>0(``````````````````+,!
M````````=0$```````#I!```]`4``,$!```````````````````W````@@0`
M`",```!"`0``TP````````#"`````````$X``````````````&<$``![!```
MWP```$X%``#P`P````````````#``0``'0(````````9!0``"P8``+4%``"(
M````Y@4``/4"``#(`@``-`,```````!>!@``8@```%D!``"A`@``C`8``.$$
M``"@!```````````````````C@```.@"```H`P``@`4``&<&```G`@``&P(`
M`)H"``##````4@4```0"``!=!```S`,``)`!``"V`@``>0```(,%```0!@``
M`@(``&L%``"#`0``(P(``!`#``!\`0``YP$``!P!````````4P```+D$``#P
M!0``[0(``.@%``!E````R0(``'H&`````````````%H```"[````[````*T"
M``!4`0```````"D!``"J````B`$``"<&```A`@``&`4``"@&````````````
M`#("``!=!@```````$,#``":!0````````X%``!U!```E@8```$%```9!```
M.0$````````P!```4@,`````````````OP,```````"X!0````````````!6
M`@```````#D&``#)!0``90,``.\%``"S!0``9P,``.T!``#V!```````````
M````````Y04``*@%``!$````Q0$```````!'!0``,P0``!4%```C!@``J`$`
M`'\!```-`@``D@$``-D```!:`0``W@4``'\%```2`@``;P(``'D$``#=!0``
M`P(``$0#``!;!0``?@(``'L```!3!```EP(``(P%````````@`$``,@!``!8
M!```M`4```````#B`````````)X"``"?!0``00(```````"R`P```````'("
M````````3@8``%(!``#W`P``!@,```````#R`0``HP4`````````````````
M`(\!``!8`@``:0(``&X````N!````````!8"``#5!````````-8#``!S`P``
M0@(``!\$``!E`0``5@,````````Q`@``0`0``'8"``"+!0``WP4```````!F
M`@``$08``"`&``#_!0``&`,``((#``!H!0``]00```````"I!```.`0``+H"
M``![!0``&@$``&P```"?`@``````````````````2P```#4%````````SP(`
M``,#```Y!```'08``%4&``"K!```^00``*P$``#T`0``#@$``-@#```'`@``
M`````&`````K!0``F@,``*H$`````````````-D%``#!`@```````,,%``"P
M`P``1`8``)L```````````````````#O`@``B08``$L&````````W@$`````
M``"X````1@(```````!0`@``=0(``"H!````````.P8``!@"``!#!```M@4`
M``````"R!```[P,```````"V!```$0```*0%``"3!@``DP(``%("``"D`0``
MA00````````K````W`$``&,"``````````````````#:`P``B`(``%8!``#'
M`P``2`$``$X$```<`@``/P$```(#```O!````````/D!````````20(`````
M``!W`@``*@,``,L!```_!@```````'@%``!<`@``H@4``,@`````````5P``
M`(P$``#C`P``2P0``(D```"1````D@4``)P!```<!0``<P$``-0%```M`P``
MJP$`````````````H@```+T#``#B`@```````)8"``"W!0````````````!Q
M`0``3P,``/T"``#.!```2@```'X````K!@``%P,``(0#``#W`@```````,H%
M```H`0``Q`(``"8#``#'!0```@4``-L%`````````````!X!```B`@``HP0`
M```````7!0```````/4````!`0``@0$``*`%``#`````.@0``#T!````````
MU@$`````````````]`````````#A`0````````````!F!```D````!X"````
M````'@0``*D```"S`@``,`,``-X```#"`0````````````!0!@``7`,`````
M``!Z`P````````````#Q`P``)`$````````_!0``104``#X```"(`P``````
M``````!!`````````,L`````````808``&0``````````````)4&``"*!0``
M^P,``#(%````````$P8``)0&``#I`@````````````!T````^`,``'8&``!1
M`P``!@8``#T%````````M@,``+@!``#'`@```````(4%````````(`,``!(%
M``"7`P```````'@&``"G!```B@8`````````````HP(``+`"```6`0``(0$`
M`#X$``!1`@``&`$``$<```!$`0``^@(````````A!````````#P$``!D`@``
M\P```#@```!9````S@```&,$``!D!```KP0```````")!```[P0`````````
M````;@(`````````````B@,``+`$``""!0``)P,``$@"``"%`@``````````
M````````'0,``-\!`````````````.$%```6!0``-P8``#4```"%`P``````
M`+`%``!J``````````````#%`P````,``.D!````````VP0```\&``#,!0``
M$P0```````"Q````%P$``,T!``!4`@``)@0```````!N`P````8``(X"``!O
M`P``#`4``(4!```M!@``0P````````"N`P``4@0``*T```";!0``L@(```($
M``#:`0``9@8``)0!``#$`````````+<$``!_````FP0``$`"``!O`0``>@4`
M`*<````$`P``)@```(<#`````0```````/P#``#^!0``9`8```````")`0``
MU`0```````##`0``8@$``.4```!X`P``;P4```````"D!```?08``#L!````
M````3P```"\```!/`@````````````#1`@``Z````-````!@`@``!`0```4`
M``"N`@``#@0```\!``"_`````````+P"``"#!@``````````````````L`$`
M`)H$``#]!0``K00``,@$````````4`4```````#6````E0(``$@&````````
M_@,``%L````5````+`$``*T%````````?`8``,\#```````````````````O
M`P``1P(```````#4`P``:00``&(%``!5`0``+P$```````#U`0```````.0$
M``#C`@``"@4``/T!```E````%````````````````````&`&````````````
M`````````````````!0%``````````````````#7`````````%0#```A!@``
M@`0`````````````$@````````#-````5`4``-(%```E`0``CP0``#D#``#5
M!0``'`8``/\!``#$`0```````%\&``"^`@``<08``-X#``!F`0``<P8`````
M`````````````)$!``!/!0``7@4``&\````N````"@$`````````````T0$`
M`-D$```&`0```````*\```````````````L!```*!```W00````````-`0``
M`````%D&````````E````/@%```J`@``I@(``-<%``"B`0``$0,``'````"1
M`@``````````````````IP(``$\$````````4`,``,P!```G!````````.,$
M``!D!0`````````````:`@```````)8%``#Z`0``2P$``"P`````````````
M`%H"`````````````'T!`````````````+,`````````$0(``#T```!,`@``
MVP(``$(&````````3````)@"``#[`0``(`$``*H#`````````````*8```#.
M`P``EP4``.D#``#D`````````/0$```I`P````````````#M`P``Y`,``.H#
M```E`P````````````!0!```M00``-<"``#9`P``.04``#@&``#N!```G04`
M`+L$``"4!```F0(``!H````Q!@``(@4``)8!``!E!0```````"@%````````
M^`0```````!G`@``8@8``/P%```_`@```````#<"`````````````+0````/
M`P``X0(````$```.`P```````"X#````````-`(``-@`````````6P8``"0#
M``"]`0``)04``/H#````````WP(``%$%``#Y````A`8``"8%``!>````V`(`
M`+8```!S!0```````"D&```2!@``\0```'P"``!O!@``!@(``#8"``##`P``
MV@(``-<#````````2P,````````/!```D`(``)P%``",`P``Y@,``'($``!R
M`0```````%D$``"9``````````````!:`P``504``/L```#^`0```````&H!
M```;!@```````!H%`````````````$4#``!S````F@````````#S!```00,`
M`(0!```=````I0```'H!``!?`P``O@$`````````````A@,`````````````
M-0(``.($``!=`P``+`8``'X$`````````````),#``#"`P``-`````````"/
M!0``!@````````"@`@``Q0```/($````````,`(``%$```##!```(P$``,@%
M``!)!```_@```&L!``"L`````````!L```#@`@```````.L%````````````
M`$4$```4`P``H00``(T$``!)`0````````P"``!?`@```````+\%````````
MWP0```````!?`0``"@8``)H!``"9`0``800``(\&``!@!0```@```'4#``!S
M`@```````!D`````````0@0``&$!``!R`P``!@4``.H$``#&`0``6`8``&L&
M``#J````AP(``,D!````````G`0```````"F!0```````"$```"8!0``;@8`
M`&@"``#\`0``S````(<!``"K`P````````P!``!9`P``3P$```T&````````
M/@$``)8```!C!@``=`(``"L"````````ZP```)@!``"!!@``@````.L#```V
M!0``JP```)T#`````````````)@`````````'@,``!H&``!2````[`0```P`
M```M````>P,```````!*`0```````+4#``"W`@``]P4``'D!```Z`@``?P(`
M`#$```!.`@``908``.<````U!@``"`8``.<#``#2!```6`4``$<#``!>!```
M>P(```````#$!0``$@0```````"X`P````````$&```?`P``\0(```````"E
M!````````#\$```B`P```````&P!``!T`0``^0,````````-````Z04``#($
M````````2`,``,$#````````-@$``"$%``"-````TP$``.8!``">!```````
M``````!L`@``;08``!H$``#W````204``($```#;`P``A0```'X#``#\!```
MQ`,```````#+!```804``+H!``#[`@``>P8``.(!``!&`P``LP0``(T#``"R
M`0``(@0``*T!```8````O`0``)4#```M`@```````-4!``!#!@``?`,`````
M```5!```5P4``%0$`````````````!`$``#"!````````+4```"U`0``?```
M`%\%````````,`4``#(!``"?!```#`8```````"@`0``108``-P#``!L!@``
MG`(``'T%``#O`0``9P$`````````````J@(``$<$`````````P4``+@$``"Y
M````3`4``/@```!^!@```````$@%````````T`,``&,```"&````DP```%,%
M``"D`````````.P%````````-00``+P%``#Q!````````#L%````````RP(`
M``X&```^!0``V0(``*$%``"Z!```>`$``-8$``#N````G0```&8%```@!```
M`````-$`````````K@```$H&``"!!0``7`0`````````````9P```*8#````
M``````````````#3!```WP,``)8$````````1@0``#(```#^!```FP$``&D&
M`````````````)0#``#6!0``[0`````````P`0``"@```'`$``#V`@``900`
M`"P#```B`````@$``!D!````````:@0``),$``#J`0``2P(``+H````%`0``
MNP4``&P%````````Q0(``*("``#(`P``S0,``&($``!H`P``O0(```````#W
M!```H`````<````5`P``V0$``/,!````````Q@```+X%````````$04``((&
M``!0`0```````)`%``!<!0``@`,``(D"```3`@``>`(```````#4`0``_```
M`/,%``!;`0``_`(``.X#``!"!0``_0````````"'!````````.@$````````
M````````````````*P0``$\&`````````````(L"````````+P8``((```!=
M`@``M`(``*D!``"%!@``W0```(L```!J`P``!`$```````!+!0``:P(``%``
M````````M0(```````!!!@``-0$```````#N`0``;0(```L$```?!0``)`4`
M`,T"``````````````````!<````.P0``,H```"L`P``LP,``,\!````````
M`````.L!``!``P``\`(```````"P````4P(````````S!@``V`$```@#``#E
M`@``R@$``'<```"H`P``T@(``&D!`````````````$4```!:!@``W@0``+D"
M``"#!```:@4``+<`````````/`$`````````````H0,``.H"````````B@(`
M`*`#`````````````-$#``")`P``+P(``/D%``"#````*@````````"K`@``
M`````)D#``"-`@``6P0``"D$``"``@``L@```````````````````+\$```L
M!```,@8``+$$````````EP```.@#``!U!0````````D`````````T`(``'P$
M``#.!0````````@$```X!0```````/$%``#5````/`8```D!```"!@``KP$`
M````````````=`4``+<!````````"04`````````````:0```-H```"4`@``
MD@(``"0&``!]`````````(X#``"]````D@,```````#)`P``TP4``&$#``#C
M!0```````!0!````````P@(``"P%``````````````@"`````````````!T%
M``!,`P``=P$``+L#````````M@$``#$%``!(`````````#$$``#E`0``````
M`"\%``!,!@``O@```)X````3````K`4```,$``!7`0``M`$``/4#```]!```
MA@4```````##`@``$00``.@!``!H`````````$T&````````7@$``%\$``!Z
M`@``0@,``&,#```+!0```````,`#``#V````0P(```@%```$````60(`````
M```$!0``.@,``)0%````````&P,``!X&``"9!0``)`0``)4%``!1!```N04`
M`'\#``#G!0```````)<&``!G!0``?00``/L$``!Q!0``*@8``+0#````````
M500``(\"``!!!````````'D#``!6````=@0``"H%```S`P``!P8``,<$```;
M`0``#`0``*,#````````W`0``-`$``""`@``R@0``"8!``"+`0```````&@&
M``"Q`0``)P````L`````````Q`0``,T%```*`P````````````#Z!0``-P,`
M`(<````Z!@``:@(```````#L`0``]04``%L#``!1!@``,`````````"C````
MDP4``#,!````````/@(``$$%````````,0$```````"0!@``A@(```````""
M`0```````&L```"I`P``]@4```X```#O````<0,``"@"``"+`P``=@4``#<%
M``!Z`````````/`!````````;04```````#V`0```````)\!``#*`@``/08`
M``````#&!````````!$!``!6!0``````````````````@0(``$T#``!P!@``
M2@(``(H!```!!```*`0```````!7!```P00``"X"``#;`0``)P4```L"````
M````$P$``#<!``!<!@````````````#Z!```J`(``#0&````````#04``'8`
M``!$!0``6@0```````!]`@``;@$``.X%``!:!0``50,````````\`P``````
M```````C`P``````````````````%@0```8$````````X0,``"L#``!I!0``
M1`0``/(`````````9`,``!\&``#*`P``%@,``'$"``"1!0``X`0`````````
M````SP4``,L#``"&!@``;0`````````7````U````$(````5!@``%`(``/\#
M``#0`0``:P0``$T$``#M!0``7P```/("``!-`@```````+$"````````>08`
M``````#T`P``&0,``#8&````````Q00``-$$``",````BP0````````:`P``
M`````#(#``"`!@``.0```!<$```L`@``'`,`````````````BP8``!L%``#D
M`0``.`$```4"``!.`0```````````````````````*($``!9!0```````+L"
M``"[`0``704``-`%``!B`P``!08``'X!``"G`0```````#P%``#>`@``=P4`
M``````"_`@``N`(```4%````````Z0````````!E`@``C@0``'\&```B!@``
M*0(``!\``````````````!,#``"E!0``KP4``#4#```)`P``:@8``'$````%
M!```<00``)4```"Q!0``'00``/L%````````K`$``!`!``#``@``K0,``+P!
M```>!0``!P4``.8"``"*!````````#X&``#1!0```````&,!``"F!````0,`
M``````"<`P```````*H%``#J!0``.P````````!6!```:`0``&D#````````
M&P0`````````````AP4```````#=`0```````)$$````````'P$``,T$````
M("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I`"`H:6X@)7,@9&%Y<RD`
M("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T97)D87DI`"!A="``)60@)7,@
M86YD("5S`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!&:6YG97)P
M<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER
M;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M
M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!I<R!R97%U
M:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@)7,@;V8@)7,`
M)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`
M)7,G<R!487-K;&ES=``E<SH@)7,`+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B
M;&4@9G)O;2`E<R!T;R`E<P`M+2!S96QE8W0@+2T`,3(@2&]U<B!&;W)M870`
M,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`02!D871A8F%S92!B86-K96YD(&ES
M(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA<R!O
M8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y
M<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O
M('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P
M<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T
M92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG
M;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-
M24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y
M<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O
M34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N
M(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O
M(&5N8W)Y<'0@82!M97-S86=E+@!!32!286EN`$%-(%-H;W=E<G,`04T@4VYO
M=R!3:&]W97)S`$%-+U!-`$%022!)1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U
M="XN+@!!8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5S<R!D96YI960@8W)E871I
M;F<@5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@
M9FEL92X`06-C;W5N="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N
M=&EN9P!!9&0`061D($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N
M`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!
M9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D
M('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D
M9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D
M('5S97(`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E
M<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE
M<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`069G:&%N:7-T86X`06QB86YI
M80!!;&=E<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!=71H
M96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L
M;"!F;W5R('-I9&5S`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S
M971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y(&5X:7-T<P!!
M;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!
M;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S
M<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;65R:6-A
M;B!386UO80!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N9&]R
M<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YT
M87)C=&EC80!!;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI
M8V%T:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H
M:6QD(%-H87)E<P!!<'!R;W9E`$%P<')O>&EM871E(%-I>F4`07!R:6P`07)A
M8FEC("A7:6YD;W=S+3$R-38I`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@
M3F%M90!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N
M=7`@<F5Q=65S="!F;W(@)7,@/P!!<F=E;G1I;F$`07)M96YI80!!<FUE;FEA
M;B`H05)-4T-)22TX*0!!<G0`07)U8F$`07-C96YS:6]N($ES;&%N9`!!<V-I
M:2!!<G0`07-I82]086-I9FEC(%)E9VEO;@!!<VL@9F]R(&-O;F9I<FUA=&EO
M;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`07-S:6=N
M;65N="!C;VQU;6YS`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT
M(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M
M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES
M<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+@!!
M='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y<G-Q
M;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y
M<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET
M97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF='`@<W=I=&-H
M+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I
M<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O
M(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U
M<V5R("5S`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I
M8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@
M4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F
M86EL960N`$%V86EL86)L92!F:65L9',Z`$%Z97)B86EJ86X`0D]&2"!%>&-U
M<V5S`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@
M<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"86AR
M86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`
M0F%S96QI;F4`0F5L87)U<P!"96QG:75M`$)E;&EZ90!"96YI;@!"97)M=61A
M`$)H=71A;@!":7)T:&1A>0!";&]C:R`B)7,B(&]F(&%P<&QI8V%T:6]N("(E
M<R(@;F]T(&9O=6YD+@!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)O;&0`
M0F]L:79I80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O
M<F1E<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN80!";W1H`$)O='-W86YA`$)O
M='1O;0!";W5V970@27-L86YD`$)R87II;`!"<FET:7-H($EN9&EA;B!/8V5A
M;B!497)R:71O<GD`0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R:6$`0G5L;&5T
M960@3&ES=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#`$-23"!$:7-T
M<FEB=71I;VX@4&]I;G1S`$-?96QL(%!R;W!E<G1I97,N+BX`0V%L96YD87(`
M0V%L;0!#86UB;V1I80!#86UE<F]O;@!#86X@;F]T(')E<V5T('!A<W-W;W)D
M(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#
M86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<P!#86YA9&$`0V%N8V5L
M`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN;W0@9&5L971E(&9I;&4@(B5S
M(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@
M<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N`$-A;FYO
M="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D(&-H
M:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I
M97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R
M('-T;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU
M;6)E<BX`0V%P92!697)D90!#87!T:6]N`$-A=&5G;W)I97,@86YD($QA8F5L
M<P!#87EM86X@27-L86YD<P!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE<P!#
M96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E
M;&QP:&]N90!#96QT:6,@*$E33RTX.#4Y+3$T*0!#96YT97(`0V5N=')A;"!!
M9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I
M`$-E<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A=&4@4&]L:6-I97,`0VAA
M9`!#:&%N9V4`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O
M<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I
M;',N`$-H87(`0VAE8U]K($QI;FLN+BX`0VAI;&4`0VAI;F$`0VAI;F5S92!3
M:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I
M`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!H
M;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H
M9F]R(&]R9&5R960@;&ES=',I`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F
M:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%R`$-L96%R($U33V9F:6-E
M('1A9W,`0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S97(`0VQE87(@=7-E
M<B!D871A`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A45%``
M0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES
M;&%N9',`0V]L;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO
M;6)I80!#;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS
M.@!#;VQU;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`
M0V]M;65N=`!#;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M<'5T97)S
M`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U
M<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C
M<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN
M96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B
M;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&
M5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@
M861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O;G1I;G5E`$-O;VL@27-L
M86YD<P!#;V]K:64`0V]P>0!#;W!Y('-E;&5C=&EO;@!#;W-T82!2:6-A`$-O
M=&4@9"=)=F]I<F4`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N`$-O
M=6QD(&YO="!01U`@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%(&5N
M8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N
M`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@
M3$1!4"!S97)V97(N`$-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L
M9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@
M9&5C<GEP="!01U`@9&%T82X`0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A
M=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&1E
M;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E=&5R;6EN
M92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!F
M971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F971C:"!C
M;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H
M92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@
M;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BX`0V]U
M;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A
M<VL@;6]D=6QE("5S`$-O=6QD(&YO="!R96%D("5S+@!#;W5L9"!N;W0@<F5S
M970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@
M;W(@86QL(&]F('1H92!D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G
M86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D
M(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T(')E=')I979E($%#3`!#;W5L9"!N
M;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<P!#;W5L9"!N;W0@<F5T<FEE
M=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!R971R:65V92!D
M:7-T<FEB=71I;VX@;&ES=',N("5S`$-O=6QD(&YO="!R971R:65V92!S97)V
M97(G<R!C87!A8FEL:71I97,`0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T
M:6]N+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N
M;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO="!S879E
M('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N;W0@
M<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5P9&%T92!C;VYT
M86-T+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R
M92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5N=&5D('1E>'0`0V]U;G1R>0!#
M;W5R<V5S`$-R96%T90!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!O;F4`
M0W)E871E('-U8B!F;VQD97)S`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET
M(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT(%1I;64`0W5R<F5N
M="!54DP@:7,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``
M0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G
M;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H
M2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A
M:6YI86X@*$M/23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`1&%I;'D`1&%T851R
M964@0G)O=W-E<@!$871E`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`
M1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$
M96-R96%S92!);F1E;G0`1&5F875L=`!$969A=6QT($-O;&]R`$1E9F%U;'0@
M261E;G1I='D`1&5F:6YI=&EO;G,`1&5L971E`$1E;&5T92!'<F]U<`!$96QE
M=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T
M92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T
M92!T96UP;&%T90!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET
M>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N
M="!R;W<`1&5L:79E<GD@=&EM90!$96YM87)K`$1E<V-R:6)E('1H92!0<F]B
M;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F
M:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI
M<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@
M;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG
M:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D@
M,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9F]R96-A
M<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES<&]S:71I;VX@3F]T:69I8V%T
M:6]N`$1J:6)O=71I`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C
M8V5S<R!M86EN=&5N86YC92YP:'``1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A
M:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$
M;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]W;FQO860`1&]W;FQO860@
M)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C
M<FEP="X`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-86EL`$524@!%8W5A9&]R
M`$5D:70`161I="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%
M9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@
M;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D=6-A=&EO
M;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN`$5M`$5M86EL`$5M86EL
M($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL('=I
M=&@@8V]N9FER;6%T:6]N`$5M;W1I8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T
M>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B;&4@:6YS97)T:6]N
M(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/P!%;F%B
M;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%;F0@>65A<@!%;FQA<F=E
M($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W
M:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@<&%S<W=O
M<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SH`16YT
M97(@=&AE(&EM86=E(%523"!H97)E`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R
M96$`17)R;W(`17)R;W(@=VET:"!E;6%I;"!M97-S86=E+@!%<W1O;FEA`$5T
M:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`R
M(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E
M<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE
M('9A;'5E<SH`17AE8W5T90!%>'!A;F0`17AP86YD(%-I9&5B87(`17AP96-T
M960@)RDG`$5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E
M<FT`17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$9'($-O;&]R`$944"!U<&QO
M860@;V8@<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A
M:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N
M;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N
M`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W
M(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I
M<@!&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@27-L86YD<P!&
M871A;"!%<G)O<CH`1F%X`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E;',@;&EK
M93H@`$9E=R!3:&]W97)S`$9E=R!3;F]W(%-H;W=E<G,`1FEE;&0@;6%T<FEX
M`$9I:FD`1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE
M<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@
M=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QT97)S`$9I
M;FQA;F0`1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&EP
M`$9L;V%T`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]N="!#;VQO
M<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S
M`$9O<F5C87-T("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@
M<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[
M(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B
M;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R
M='5N92!T>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S
M`$9R`$9R86UE<P!&<F%N8V4`1G)A;F-E+"!-971R;W!O;&ET86X`1G)E;F-H
M($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R
M:71O<FEE<P!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@
M36]O;@!&=6QL($YA;64`1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R
M;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`
M1V5N97)A=&5D($-O9&4`1V5O<F=I80!'97)M86YY`$=H86YA`$=I8G)A;'1A
M<@!':79E;B!.86UE`$=O`$=O961E;`!';V]G;&4@4V5A<F-H`$=R87ES8V%L
M90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N861A
M`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N
M+65M<'1Y`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N
M<V5Y`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A
M+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S
M('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RX`2%1-3$%R96$@8V]W
M87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A
M8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@075T:&5N=&EC871I;VX@;F]T(&9O
M=6YD+@!(86ET:0!(87-H+4%L9V]R:71H;0!(87IE`$AE861E<@!(96%R9"!)
M<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`2&5B<F5W("A)4T\M.#@U.2TX
M+4DI`$AE:6=H=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI
M<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG
M:`!(;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO
M;64@061D<F5S<P!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D
M90!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E
M9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E
M<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F
M('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C
M8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN
M=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X
M=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,
M('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E
M;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I
M979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+
M;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O
M2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R
M:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H
M97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@
M>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@
M87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE
M<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-
M05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D
M96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO
M;B!F86EL960Z("5S`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA
M8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K
M+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$E?;G-E<G0@4F]W($)E9F]R90!)
M8V5L86YD`$EC;VYS($]N;'D`26-O;G,@9F]R("5S`$EC;VYS('=I=&@@=&5X
M=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R
M<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@>6]U
M(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L
M('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!0
M3D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@
M;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@
M8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE=SH`
M26UA9V4@55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM86=E
M(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0L(%-T
M97`@)60`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26Y?
M<V5R="!2;W<@069T97(`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!)
M;F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@
M=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C
M;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R
M(&AE;'`N`$EN8W)E87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L(%5S97)S
M`$EN9&]N97-I80!);F9O`$EN9F]R;6%T:6]N`$EN<V5R="!#7V]L=6UN($%F
M=&5R`$EN<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK
M`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F
M=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R
M92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@
M8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E
M;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N
M;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D
M90!);G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A
M9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W
M;W)D.@!);G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS
M97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@
M;65S<V%G97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R
M87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E
M`$EN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q
M=65S=&EO;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI
M;FL`26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB
M=71I;VX@;&ES="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!);G1E
M9V5R(&QI<W0`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV
M86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D
M871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!)
M;G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@
M;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T
M97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!R;W1O
M8V]L+@!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R
M97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$ER86XL($ES
M;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES;&4@;V8@36%N`$ES
M;VQA=&5D(%0M4W1O<FUS`$ES<F%E;`!)<W-U97(`271A;&EC`$ET86QY`$IA
M;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IE
M<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`
M2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MA>F%K
M:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R;W,@<V5R=F5R(')E
M:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N96P@3F5W8FEE<P!+97D@0W)E
M871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y
M(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E82P@1&5M;V-R871I8R!096]P;&4G
M<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`2V]R96%N("A%54,M
M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$QA7WEO=70`3&%N9W5A9V4`3&%O(%!E
M;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@475A
M<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ
M("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA`$QA=P!,87EO
M=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`3&5F
M="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,:6)E<FEA`$QI8GEA;B!!
M<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H="!$<FEZ>FQE`$QI
M9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN($QA=&4`3&EG
M:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG:'0@
M4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6YK`$QI;FL@<&]I
M;G1S('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E
M('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X($-O;VMI90!,:7-T
M("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES
M="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES="U(
M96QP`$QI<W0M260`3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I
M8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D
M+@!,:71E<F%T=7)E`$QI=&AU86YI80!,;V%D:6YG+BXN`$QO8V%L('1I;64Z
M(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O=70`3&]G
M:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O
M<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I
M;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W97(@9W)E96L@;&5T=&5R<P!,
M;W=E<B!L871I;B!L971T97)S`$QO=V5R(')O;6%N(&YU;6)E<G,`3'5X96UB
M;W5R9P!-30!-3U1$`$U3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@
M9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA
M=B!297!U8FQI8R!O9@!-861A9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!9&UI
M;@!-86ME(&QI;E]K+BXN`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-86QI
M`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E
M('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E9"!W
M:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T(&UA<`!-87!1=65S="!M87``
M36%R8V@`36%R9VEN`$UA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-87)K
M('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-
M87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<@9FEE;&1S`$UA
M=7)I=&%N:6$`36%U<FET:75S`$UA>"!A;&QO=V5D(&-R961I="X`36%X(&UE
M<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T96UP(&QA<W0@,C0@:&]U<G,Z
M(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M(&QE;F=T:`!-87D`
M36%Y;W1T90!-961I8VEN90!-96UB97)S`$UE;G4@;6]D93H`365R9V4@8V5L
M;',`365S<V%G90!-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@
M=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE
M9"X`365S<V%G92!E>'!I<F5D+@!-97-S86=E('1Y<&4`365T87(@5V5A=&AE
M<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@
M879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A
M9&UI;FES=')A=&]R+@!-971H;V0`365T<FEC`$UE>&EC;P!-:6-R;VYE<VEA
M+"!&961E<F%T960@4W1A=&5S(&]F`$UI9&1L90!-:6UE(%1Y<&4`36EN('1E
M;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA<W0@-B!H;W5R<SH@`$UI
M<G)O<@!-:7-C96QL86YE;W5S`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?
M4F5Q=65S="X`36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G
M96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC
M871I;VXN`$UI<W-I;F<@;65S<V%G92!)1"X`36ES<VEN9R!R97%U:7)E9"!0
M14%2('!A8VMA9V4@36%I;"X`36ES<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I
M;&4@36%I;`!-;V1E<F%T90!-;V1I9FEE9"!$871E`$UO9&EF>2!54DP`36]D
M=6QU<P!-;VQD;W9A+"!297!U8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N
M=&@@86YD('EE87(`36]N=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO
M<F]C8V\`36]S=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY(%-U;FYY
M`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@
M9&]W;@!-;W9E('5P`$UO>F%M8FEQ=64`375L=&DM;&5V96P@9')O<"!D;W=N
M(&QI<W1S`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY(%!O<G1A
M;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@3D]4($%G<F5E
M`$YA;64`3F%M:6)I80!.875R=0!.97!A;`!.971H97)L86YD<P!.971H97)L
M86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E(%523`!.971S8V%P92!#02!2
M979O8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@55),`$YE='-C87!E
M(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C871I;VX@55),`$YE='-C87!E
M(%-33"!S97)V97(@;F%M90!.971S8V%P92!C97)T:69I8V%T92!C;VUM96YT
M`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.979E<@!.97<@
M0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@36]O;@!.97<@57-E<FYA;64@
M*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@=VEN9&]W("A?8FQA;FLI`$YE
M=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@;W!T:6]N<P!.:6-A<F%G=6$`3FEG
M97(`3FEG97)I80!.:6=H=`!.:75E`$YO`$YO(&%V86EL86)L92!C;VYF:6=U
M<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V86EL
M86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A=&-H
M('1E;7!L871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P
M;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U
M=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A
M9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I
M;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I;VX@<W5P<&QI
M960N`$YO(&9I;&4@=7!L;V%D960`3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%T
M:6]N(&ES('-E="X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C
M:69I960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO(&]F9F5N<VEV92!F;W)T
M=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A
M=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H
M96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U
M=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$
M(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"
M(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R
M>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T
M;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I9VYU<',N
M`$YO(')U;&5S`$YO('-I9&5S`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A
M:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D
M('-E;G0N`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.
M;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E
M9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y
M;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`
M3F]N90!.;VYE("AU<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I
M`$YO<F9O;&L@27-L86YD`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@
M36%R:6%N82!)<VQA;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.
M;W0@82!D:7)E8W1O<GD`3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S
M=7!P;W)T960N`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.
M;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F
M(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D
M(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J96-T
M`$]B:F5C="!#<F5A=&]R`$]C=&%L`$]C=&]B97(`3V9F96YS92!F:6QT97(`
M3V9F:6-E`$]M86X`3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@
M9F]L9&5R<RX`3VYL>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA
M:6P@861D<F5S<R!A;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@
M861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P
M97)M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/
M<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG
M;F5D(%,O34E-12!P87)T+@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN
M9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/
M<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`
M3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG
M:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N
M`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@
M879A:6QA8FQE+@!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E
M9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D($1A
M=&$`4$A0($-O9&4`4$A0(%-H96QL`%!-($QI9VAT(%)A:6X`4$T@4VAO=V5R
M<P!032!3;F]W`%!-(%-N;W<@4VAO=V5R<P!032!4+5-T;W)M<P!07TA0(%-H
M96QL`%!A9&1I;F<`4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET
M;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A
M>0!087)T;'D@0VQO=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&EN8V]R<F5C=`!0
M87-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!0
M87-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z
M(`!087-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP
M8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z`%!E;W!L90!097)C96YT`%!E
M<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO
M;G,@061M:6YI<W1R871I;VX`4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0
M971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE;',`
M4&QA=&ET=61E<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E
M(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT
M.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES
M(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L
M96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S
M92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A
M;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N
M=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!P<F]V:61E
M(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U
M<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E('1Y<&4@=&AE(&YE=R!C
M871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R='5G86P`
M4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES
M('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)
M34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5F
M<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R
M969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F
M;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U
M<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O
M=P!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@2V5Y
M`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@
M=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R]0
M<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U
M97)T;R!2:6-O`%%A=&%R`%%U97)Y`%)302!0=6)L:6,@2V5Y("@E9"!B:70I
M`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A
M:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&
M;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E
M("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@
M<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@
M8V%N;F]T(&)E('5N9&]N92X`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F
M<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I
M97<Z`%)E9V5X`%)E;&%T:6]N<VAI<"!"<F]W<V5R`%)E;6%R:W,`4F5M;W1E
M(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H
M;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E(&-O;'5M;@!296UO
M=F4@9F]R;6%T=&EN9P!296UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T
M(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H
M90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U
M<V5R`%)E;6]V92!U<V5R.B`E<P!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E
M<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!297%U:7)E9"!&:65L9`!297-E
M=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W5L=',`
M4F5T=7)N('1O($]P=&EO;G,`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO
M;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H
M="!H96%D97(`4FEG:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE
M`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`
M4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W
M:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E
M<F%T:6]N`%)W86YD80!3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`
M4R]-24U%($5N8W)Y<'1E9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@
M:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!344P@4VAE;&P`4U-(
M`%-50T-%4U,`4U]13"!3:&5L;`!380!386EN="!(96QE;F$`4V%I;G0@2VET
M=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ
M=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,`4V%M92!F
M<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD(%!R
M:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3875D:2!!<F%B:6$`4V%V90!3
M879E("5S`%-A=F4@3W!T:6]N<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T
M:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R
M>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-C:65N8V4`
M4V5A<F-H`%-E87)C:"!%;F=I;F5S`%-E;&5C="!&:6QE<P!396QE8W0@82!D
M871E`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`
M4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A
M;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@86X@;V)J96-T`%-E;&5C="!T
M:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@
M66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T:&4@=&5X
M="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE
M(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O
M(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L96-T('1H
M92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E
M;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D
M(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;F5G
M86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!3
M97)I86P@3G5M8F5R`%-E<W-I;VX@240@97AP:7)E9"X`4V5T`%-E="!O<'1I
M;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO
M=2!E=F5R(&9O<F=E="!I="X`4V5T('5P(')E;6]T92!S97)V97)S('1H870@
M>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R
M('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N
M<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE
M+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N
M`%-E='5P`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A
M;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y
M8VAE;&QE<P!3:&]P<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@
M:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@9&EF
M9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L
M>2!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I
M;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I
M;F%L`%-H;W<@<&EC:V5R`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A
M<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B
M;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P
M97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D
M:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!U
M<&QO860`4VAO=V5R<P!3:&]W97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:&]W
M97)S(&EN('1H92!6:6-I;FET>0!3:')I;FL`4VAR:6YK(&]R(&UO=F4@;F5I
M9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T`%-I97)R
M82!,96]N90!3:6=N('5P`%-I9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM
M`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO
M=F5N:6$`4VYO=P!3;F]W(%-H;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W
M97)S($5A<FQY`%-N;W<@4VAO=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W
M(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N($ES;&%N9',`4V]M86QI
M80!3;VYG<R`F(%!O96US`%-O<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C92!A
M9&1R97-S`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM
M,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N
M9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N(&%D:F%C96YT
M(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E
M;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3
M<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@
M8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I($QA;FMA`%-T86YD87)D`%-T
M87(@5')E:P!3=&%R="!Y96%R`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3
M=&]R86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T
M<FEN9R!L:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T>6QE
M(%M#4U-=`%-U`%-U8FIE8W0`4W5B;6ET`%-U8G-C<FEP=`!3=6-C97-S`%-U
M8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@
M<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG
M=7)A=&EO;BX`4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG
M=7)A=&EO;B!F:6QE("5S+@!3=6-C97-S9G5L;'D@=W)O=&4@)7,`4W5D86X`
M4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U;G)I<V4`4W5N<FES
M92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP
M=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@86YD($IA;B!-
M87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y;G1A>"!E<G)O
M<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R
M;0!4+5-T;W)M<P!44U8@9FEL90!486)L90!486)L92!0<F]P97)T:65S`%1A
M8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI
M;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A
M<F=E=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO
M=7(Z(`!496UP97)A='5R90!496UP97)A='5R93H@`%1E;7!L871E($%D;6EN
M:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X='1O<`!4
M:`!4:&%I("A425,M-C(P*0!4:&%I;&%N9`!4:&%N:R!Y;W4@9F]R('5S:6YG
M('1H92!S>7-T96TN`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B
M;&4N`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N
M;W0@<W5P<&]R="`B)7,B`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N
M;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C
M;&]S960N($5X:71I;F<N`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O
M;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO
M=2!W86YT('1O('5S92!097)M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N
M;'D`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L
M969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4
M:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D
M<F5S<R!B;V]K+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I
M<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@
M9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D
M+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H
M92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&5N
M8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C
M=&EO;BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG
M+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S
M+@!4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE
M(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H
M92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H
M92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US
M('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@
M=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H
M="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@
M9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@
M>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H
M870@>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N
M9"!N965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0
M;&5A<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F
M=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N
M(&1E;&5T960N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H92!L;V-A=&EO
M;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R
M>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S
M('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I
M<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D
M(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@
M=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q
M=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@
M<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET
M<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE`%1H
M92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A
M<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE(')I9VAT(&%N9"!L969T
M('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S97)V
M97(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S
M(&)E96X@<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E
M96X@<F5M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N
M`%1H92!T96UP;W)A<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@
M=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4
M:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@
M<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4
M:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE<F4@
M87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@
M=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M
M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E
M9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N
M`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO
M("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H
M92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X
M:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A
M<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI
M;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R
M(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@
M;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!P97)F
M;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0
M;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D
M871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L
M871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB
M=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AI<R!)34%0
M('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI
M<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`
M5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`
M5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N
M`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U
M9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T
M97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T
M<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%0
M20!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@
M4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2!G871E=V%Y+"!O;FQY
M('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C
M8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I
M+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I
M;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N;'D@
M8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@;75S="!B92!A(&-O
M;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S`%1H:7,@
M9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M=7-T
M(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@
M9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@
M8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+;VQA8B!'
M<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL
M(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO
M;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I
M;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UE<W-A9V4@=V%S('=R
M:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R
M(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@
M<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4
M:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L
M=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL
M960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R`%1I8VME=',`5&EM
M90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L96-T:6]N`%1I
M;6]R+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`5&\`5&\@<V5L96-T
M(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O
M<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D87D`5&]G
M9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO<G)O=P!4;VYG80!4
M;W``5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA=&EO;G,`5')I;FED860@86YD
M(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U;FES:6$`5'5R:V5Y`%1U<FMI
M<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S
M($ES;&%N9',`5'5V86QU`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X
M.B``55),`%523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E
M<&]R=`!54DPZ`%5G86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@5D93
M(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T
M:6]N('=H96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M:7-S
M:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI
M<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O
M("5S+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@
M=&\@8V]N;F5C="!W:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N
M`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@
M=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93
M(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L
M92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@
M=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@
M)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T
M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O
M<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L
M92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93(')E
M8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I
M<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL
M<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE
M('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E
M<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B
M;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E
M9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O
M<GDN`%5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O
M;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E
M8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N`%5N
M86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92X`
M56YA8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N86)L92!T;R!T<F%N<VQA=&4@
M=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET92!61E,@9FEL92`B
M)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I
M+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`56YD97)L:6YE`%5N
M9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D
M(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C
M=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B``56YF:6QE9`!5;FEC;V1E
M("A55$8M."D`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`
M56YI=&5D(%-T871E<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES
M;&%N9',`56YI=',`56YK;F]W;@!5;FMN;W=N(&%P:6US9VED("A!4$D@365S
M<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$
M*2X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YL:6YK('1H92!C
M=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R:79I;&5G960@<V-R:7!T<R!C
M86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F
M;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN
M:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO=2!H;W<@
M=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N`%5N
M<V5T(&-O;&]R`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D871E
M("5S`%5P9&%T92!U<V5R`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A
M9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE
M('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB
M97)S`%5R=6=U87D`57-E($-U<G)E;G0Z("5S`%5S92!34TP`57-E(&EF(&YA
M;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E
M<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@061M:6YI<W1R
M871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S97(@4F5G
M:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N`%5S
M97)N86UE`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S>7-T
M96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="X`
M5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI
M9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU97,`5F%L=65S
M('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B;&4`5F5N97IU96QA`%9E
M<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E
M;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9E<G-I;VX@0V]N=')O;`!697)T
M:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E<G1I8V%L.@!697)Y($AI
M9V@`5FEE="!.86T`5FEE=&YA;65S92`H5DE30TE)*0!6:65W("5S`%9I97<@
M86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:7)G:6X@27-L86YD
M<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6:7-I8FEL:71Y`%9I
M<VEB:6QI='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU44`!705).`%=!4DY)
M3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+@!786QL:7,@
M86YD($9U='5N80!787)N:6YG`%=E`%=E871H97(@1F]R96-A<W0`5V5A=&AE
M<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!796(@4VET90!7
M965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=E<W1E
M<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T97)N
M(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F
M=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7
M:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H:6-H('!H87-E<P!7:&EC
M:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N
M`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N
M=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`
M5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN
M9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@
M`%=I<V1O;0!7;W)K`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%@M4F5F`%@U
M,#EV,R!"87-I8R!#;VYS=')A:6YT<P!8-3`Y=C,@17AT96YD960@2V5Y(%5S
M86=E`%@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64`6#4P.78S(%-U
M8FIE8W0@2V5Y($ED96YT:69I97(`6#4P.78S(&5X=&5N<VEO;G,`65D`65E9
M60!986AO;R$@;6%P`%EE87)L>0!996UE;@!997,`665S+"!)($%G<F5E`%EO
M=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S
M=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E(&YO="!A=71H96YT:6-A
M=&5D+@!9;W4@8V%N(&YO="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO
M=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL
M(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@
M:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@
M)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@96YT
M97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H
M(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN
M9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO
M=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I
M9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@
M;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD
M('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W
M:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C="!A;B!S
M97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N
M86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE
M('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@
M861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N
M`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U
M(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+@!9;W5R("5S('-E<W-I
M;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I
M;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO
M;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE
M(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U
M<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9
M;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L
M:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE
M9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S
M('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@
M)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S
M="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@
M=&AI<R!F96%T=7)E+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E
M9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&YE=R!P87-S
M=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D
M871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O
M<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B
M965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K
M('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W('!A<W-W;W)D
M+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I
M80!::6UB86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@
M4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT
M("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I;VX`
M7T-,20!?1&%T851R964`7T1E;&5T92!2;W<`7T=R;W5P<P!?2&5L<`!?26UA
M9V4@4')O<&5R=&EE<RXN+@!?3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN
M:RXN+@!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]3
M971U<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`861D<F5S<R!B;V]K
M`&-A;&5N9&%R`&-A;&T`8VQI8VL@:&5R90!F86QL:6YG`&9I;&4`9G)O;2!T
M:&4@)7,@*"5S*2!A="`E<R`E<P!H.@!I;6UE9&EA=&4`:6YL:6YE`&QI;F5S
M70!M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RX`;F%M
M90!N;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D
M`'!E<F-E;G0`<&EX96QS`')I<VEN9P!S:&]W(&1I9F9E<F5N8V5S`'-M<S)E
M;6%I;"!V:6$@2%144`!S=&5A9'D`=&%S:R!L:7-T`'1Y<&4@=&AE('!A<W-W
M;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5S97(@<V5L
M96-T`'9#87)D`'<Z`'=E871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@
M2&]R9&4@,RXP"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R
M9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R
M,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-"TP-RTR,B`Q,3HT.2TP-S`P"DQA
M<W0M5')A;G-L871O<CH@36EL;W,@5VEM;65R(#QW:6UM97)`>F-U+F-Z/@I,
M86YG=6%G92U496%M.B!#>F5C:"`\:3$X;D!L:7-T<RYH;W)D92YO<F<^"DU)
M344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA
M<G-E=#U)4T\M.#@U.2TR"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB
M:70*4&QU<F%L+49O<FUS.B!N<&QU<F%L<STS.R!P;'5R86P]*&XE,3`]/3$@
M)B8@;B4Q,#`A/3$Q(#\@,"`Z(&XE,3`^/3(@)B8@;B4Q,#P]-"`F)B`H;B4Q
M,#`\,3`@?'P@;B4Q,#`^/3(P*2`_(#$@.B`R*3L*`"`H</AE9"`E<R!D;GDI
M`"`H4/CM<W1U<&]V_2!K;.WH("5S*0`@*'8@)7,@9&YE8V@I`"`H9&YE<RD`
M("AZ[71R82D`("AVZ&5R82D`(')Y8VAL;W-T(``E9"`E<R!A("5S`"5D+61E
M;F[M('#X961P;W;L[P`E<R`M(&]Z;N%M96[M`"5S(&]T:7-K`"5S($M"`"5S
M(&]P97)A8V4@^F1ROF)Y("T@<&]T=G)Z96[M`"5S(&YA<W1A=F5N[0`E<R!R
M96=I<W1R86-E`"5S('!O9&WM;FMY('!O=;[M=N%N[0`E<R!J:;X@97AI<W1U
M:F4N`"5S(&YA("5S("5S`"5S(&IE('!OOF%D;W;A;F\`)7,@;6EN=70`)7,@
M;F5B>6QO(&YA;&5Z96YO+@`E<R!AOB`E<R!Z("5S`"5S(&%D<F5SX?@`)7,@
M:V%L96YDX?@`)7,@>N%P:7-N[6L`)7,@<V5Z;F%M(/IK;VSY`"5S.B`E<P`L
M(&[A<F%Z;W;]("5S("5S`"P@<')O;>QN;N$@;V0@)7,@9&\@)7,`+2T@=OUB
M['(@+2T`,3(@:&]D:6YO=OT@9F]R;>%T`#(T(&AO9&EN;W;](&9O<FWA=``R
M-"!H;V1I;@!0<F\@=&5N=&\@8FQO:R!J92!V>;YA9&]VX6X@9&%T86+A>F]V
M_2!Z9')O:BX`5GES:WET;&$@<V4@>N%V8;YNX2!C:'EB80!0<F\@>F&Y:69R
M;W;A;NT@>G!RX79Y(&IE(&YU=&YO('!O=;[M="!V9?AE:F[](%!'4"!K;.WH
M+@!0<F\@=F5R:69I:V%C:2!P;V1E<'-A;ND@>G!RX79Y(&IE(&YU=&YO('!O
M=;[M="!V9?AE:F[](%!'4"!K;.WH+@!0<F\@9&6Y:69R;W;A;NT@>G!RX79Y
M(&IE(&YU=&YO('!O=;[M="!V9?AE:F[](%!'4"!K;.WH+"!P<FEVX71N[2!0
M1U`@:VSMZ"!A(&AE<VQO+@!0<F\@<&]D97!SX6[M('IP<N%V>2!J92!N=71N
M;R!P;W6^[70@=F7X96IN_2!01U`@:VSMZ"P@<')I=N%T;NT@4$=0(&ML[>@@
M82!H97-L;RX`4')O(&1EN6EF<F]VX6[M('IP<N%V>2!J92!N=71N;R!P;W6^
M[70@=F7X96IN_2!3+TU)344@:VSMZ"P@<')I=N%T;NT@4R]-24U%(&ML[>@@
M82!H97-L;RX`4')O('!O9&5P<^%N[2!Z<'+A=GD@:F4@;G5T;F\@<&]UONUT
M('9E^&5J;OT@4R]-24U%(&ML[>@L('!R:7;A=&[M(%,O34E-12!K;.WH(&$@
M:&5S;&\N`%!R;R!Z8;EI9G)O=N%N[2!Z<'+A=GD@:F4@;G5T;F\@<&]UONUT
M('9E^&5J;OT@4R]-24U%(&ML[>@N`%)A;F[M(&3IN;L`4F%N;NT@</AE:.'R
M:WD`4F%N;NT@<V[L:&]VZ2!P^&5HX?)K>0!!32]030!!4$D@240`26YF;W)M
M86-E(&\@=&]M=&\@961I=&]R=0!);F9O<FUA8V4N+BX`5&5X="!D;VSY(&1O
M(&]B<N%Z:W4`5&5X="!D;W!R;W-T^&5D(&]B<N%Z:W4`5GET=F_X96[M(%9&
M4R!A9')A<^'X92!N96)Y;&\@<&]V;VQE;F\N`%9Y='9O^&5N[2!61E,@<V]U
M8F]R=2!N96)Y;&\@<&]V;VQE;F\N`%6^:79A=&5L<VOI(&AE<VQO`%6^:79A
M=&5L:_T@^NAE="!B>6P@>F%B;&]K;W;A;BX`5;YI=F%T96QKZ2#ZZ'1Y`%9L
M;[X`4/AI9&%T('!O9'-K=7!I;G4`4/AI9&%T('!O9"UP<N%V80!0^&ED870Z
M`%#X:61A="!N;W9O=2!S:W5P:6YU`%#X:61A="!N;W;A('!RX79A`%#X:61A
M="!N;W;I:&\@=;YI=F%T96QE.@!0^&ED870@<VQO=7!E8P!0^&ED870@;F]V
MZ2#H;&5N>0!0^&ED870@<.%R`%#X:61A="`E<R!M96YU(&IA:V\@8F_H;NT@
M<VQO=7!E8R!-;WII;&QY`%#X:61A="!D;R!A9')E<^'X93H`4/AI9&%T(&1O
M(&WI:&\@861R97/A^&4`4/AI9&%T('6^:79A=&5L90!0^&EDX7;A;NT@=;YI
M=F%T96SY(&IE('IA8FQO:V]VX6YO+@!!9')E<V$`061R97/A^`!6>6MO;N%V
M870@861M:6YI<W1R86-I("T@;F%S=&%V96[M('#X[7-T=7!O=OUC:"!P<N%V
M('!R;R!O<W1A=&[M('6^:79A=&5L90!!9&UI;FES=')A8V4`26YZ97+A='D`
M069G:.%N:7-TX6X`06QBX6YI90!!;+[M<G-K;P!0^&5Z9.UV:V$O06QI87,`
M6F%R;W9N870`6F%R;W9NX6[M.@!6N64`5KEI8VAN:2!O=NSX96[M('6^:79A
M=&5LZ0!6N65C:&YY('-K=7!I;GD`5KEE8VAN82!UOFEV871E;'-KX2!P<N%V
M80!6N65C:&YY(.AT>?AI('-T<F%N>0!0;W9O;&ET(';M8V4@861R97,`4&]V
M;VQI="!N87-T879E;NT@='EP=2!S973X[63L;OT@<V5Z;F%M/P!*:;X@97AI
M<W1U:F4`06QT97)N871I=F[M($E-4U`@</AI:&SAN65N[2!D;R!S>7-TZ6UU
M`$%L=&5R;F%T:79N[2!)35-0(&AE<VQO`$%L=&5R;F%T:79N[2!)35-0('6^
M:79A=&5L<VOI(&IMZ6YO`$%L=&5R;F%T:79N[2!E+6UA:6QO=N$@861R97-A
M`$%L=&5R;F%T:79N[2!V>F]R>0!!;'1E<FYA=&EV;NT@=&5X=#H`06UE<FEC
M:^$@4V%M;V$`0GEL82!Z863A;F$@;F5P;W9O;&5NX2!H;V1N;W1A+@!!;F1O
M<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6[M('!R;WAY`$]D<&]V[.\`06YT
M87)K=&EK80!!;G1I9W5A(&$@0F%R8G5D80!!<&QI:V%C90!397IN86T@87!L
M:6MA8^T`07!L:6MA8V4@:F4@</AI<')A=F5N80!0;W6^[70@<')O(&3L9&GH
M;ND@<V3M;&5N[0!38VAVX6QI=`!0^&EB;&F^;N$@=F5L:6MO<W0`1'5B96X`
M07)A8G-K>2`H5VEN9&]W<RTQ,C4V*0!696QI:V]S="!A<F-H:79O=F%NZ6AO
M('-O=6)O<G4`2FWI;F\@87)C:&EV=0!5<NAI=.P@8VAC971E('9Y;6%Z870@
MON%D;W-T(&\@</AI:&SAN65N[2!D;R`E<S\`07)G96YT:6YA`$%R;>EN:64`
M07)MZ6YS:_T@*$%235-#24DM."D`56WL;NT`07)U8F$`07-C96YS:6]N($ES
M;&%N9`!!<V-I:2!U;>QN[0!!<VEE+W)E9VEO;B!4:6-HZ6AO(&]C9>%N=0!0
M;[[A9&%T(&\@<&]T=G)Z96[M('#X960@<')O=F5D96[M;2!O<&5R86/M(/ID
M<KYB>3\`4VQO=7!C92!S(/IK;VQY`%!O:W5S(&\@=GEM87KA;NT@;F5E>&ES
M='5J[6/M('-K=7!I;GDN`%!O:W5S(&\@=GEM87KA;NT@;F5E>&ES='5J[6/M
M8V@@=;YI=F%T96QS:_UC:"!P<N%V+@!0;VMU<R!O(/IP<F%V=2!N965X:7-T
M=6KM8^UC:"!UOFEV871E;'-K_6-H('!RX78N`%!O:W5S(&\@^G!R879U(&YE
M97AI<W1U:NUC[6AO('-D[6QE;NEH;R!O8FIE:W1U+@!!=')I8G5T>0!3<G!E
M;@!!=7-T<N%L:64`4F%K;W5S:V\`075T:%]C>7)S<6PZ($YE8GEL82!N86QE
M>F5N82!P;[YA9&]V86[A('#X[7!O;F$@<')O(&EM87`N`$%U=&A?8WER=7,Z
M(%ID<F]J(&YE;>$@<&^^861O=F%NZ2!S8VAO<&YO<W1I+@!!=71H7V-Y<G5S
M.B!.96)Y;&$@;F%L97IE;F$@<&^^861O=F%NX2!P^.UP;VYA('!R;R!I;6%P
M+@!!=71H7V9T<#H@3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM<&]N
M82!P<F\@9G1P+B!+;VUP:6QU:G1E(%!(4"!S("TM96YA8FQE+69T<`!!=71H
M7VEM87`Z($YE8GEL82!N86QE>F5N82!P;[YA9&]V86[A('#X[7!O;F$@<')O
M($E-05`N`$%U=&A?:W)B-3H@3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@
M</CM<&]N82!P<F\@:W)B-2X`075T:%]L9&%P.B!.96)Y;&$@;F%L97IE;F$@
M<&^^861O=F%NX2!P^.UP;VYA('!R;R!,1$%0`$%U=&A?;&1A<#H@3F5L>F4@
M</AI9&%T('6^:79A=&5L92`E<RX@2&SAN65N[2!S97)V97)U.B``075T:%]L
M9&%P.B!.96QZ92!V>6UA>F%T('6^:79A=&5L92`E<P!!=71H7VQD87`Z($YE
M;'IE(&%K='5A;&EZ;W9A="!UOFEV871E;&4@)7,`075T:%]M8V%L.B!.96)Y
M;&$@;F%L97IE;F$@<&^^861O=F%NX2!P^.UP;VYA('!R;R!-0T%,+@!!=71H
M7W-M8F%U=&@Z($YE8GEL82!N86QE>F5N82!P;[YA9&]V86[A('#X[7!O;F$@
M<')O('-M8F%U=&@N`$]V[/AE;NT@<V5L:&%L;P!/=NSX96[M('-E;&AA;&\N
M("5S`$]V[/AE;NT@8GEL;R!Z86WM=&YU=&\@4D%$2553('-E<G9E<F5M+@!3
M96QH86QO(&]V[/AE;NT@1E10('-E=F5R96TN`$1O<W1U<&[A('!O;&4Z`$%Z
M97)B86IDON%N`$)/1D@@=OUM;'5V>0!0;WIA9.T`0F%R=F$@<&]Z863M`*EP
M871NZ2!H97-L;R!P<F\@:V5R8F5R;W,N`*EP871NZ2!UOFEV871E;'-KZ2!J
M;>EN;R!P<F\@:V5R8F5R;W,N`$)A:&%M>0!"86AR86EN`$)A;'1I8VOI("A)
M4T\M.#@U.2TQ,RD`0F%N9VQA9.FY`$)A<F)A9&]S`%KA:VQA9`!"[&QO<G5S
M:V\`0F5L9VEE`$)E;&EZ`$)E;FEN`$)E<FUU9'D`0FCZ=.%N`$YA<F]Z96YI
M;GD`3F5L>F4@;F%LZ7IT(.CA<W0@(B5S(B!A<&QI:V%C92`B)7,B+@!.87-T
M879E;NT@8FQO:W4`5'EP(&)L;VMU`%1UZ&[L`$)O;.UV:64`6N%L;[YK>0!/
M:W)A:@"I[?AK82!O:W)A:F4Z`$]K<F%J90!";W-N82!A($AE<F-E9V]V:6YA
M`$]B80!";W1S=V%N80!$;VQN[2#HX7-T`$)O=79E="!)<VQA;F0`0G)A>NUL
M:64`0G)I='-KX2!T97)I=&]R:6$@=B!);F1I8VOI;2!O8V7A;NP`0G)U;F5I
M($1A<G5S<V%L86T`0G5L:&%R<VMO`%-E>FYA;2!S(&]D<N&^:V%M:0!"=7)K
M:6YA($9A<V\`0G5R=6YD80!#35,`0U)#`$-23"!D:7-T<FEB=>AN[2!B;V1Y
M`%9L87-T;F]S=&D@8E]U\FMY+BXN`$MA;&5N9.'X`$)E>G;L=/CM`$MA;6)O
M9+YA`$MA;65R=6X`2&5S;&\@;F5L>F4@;F%S=&%V:70@875T;VUA=&EC:WDL
M('!R;W/M;2!K;VYT86MT=6IT92!68;EE:&\@<WES=.EM;W;I:&\@861M:6YI
M<W1RX71O<F$N`$YE;'IE('-E('#X:7!O:FET(&L@24U!4"!S97)V97)U.B`E
M<P!+86YA9&$`4W1O<FYO`%-T;W)N;R!H;.&Y96[M('!R;V)LZ6UU`$YE;'IE
M('9Y;6%Z870@<V]U8F]R("(E<R(N`$YE;'IE(&YA:NUT(&1OZ&%S;OT@861R
M97/A^"X`3F5L>F4@<&]K<F'H;W9A="!B97H@<&%R86UE=')U("=T87)G971&
M:6QE)RX`3F5L>F4@=GEM87IA="!A9')E<^'X("(E<R(N`$YE;'IE('9Y;6%Z
M870L('!R;W1OOF4@97AI<W1U:NT@<&]D<VMU<&EN>2`E9"X`3F5L>F4@<')O
M=NES="!Z;>QN=2!U<W!O^.%DX6[M+"!P;^AE="!P;W-K>71N=73]8V@@<&]L
M;[YE:R!P<F\@;F]VZ2!U<W!O^.%DX6[M(&YE;V1P;W;M9.$@<&_H='4@=6QO
MOF5N_6-H('!O;&^^96LN`$YE;'IE('IA<VQA="!Z<'+A=G4@;F$@>F%D86[I
M(.CM<VQO+B``0V%P92!697)D90!4:71U;&MY`$MA=&5G;W)I92!A('IN8>AK
M>0!+86IM86YS:^D@;W-T<F]V>0!-;V)I;&[M('1E;&5F;VX`36^^;F]S=&D@
M8G7R:WD`3V1S='5P(&UE>FD@8G7R:V%M:3H`5FQA<W1N;W-T:2!B=?)K>0!-
M97IE<GD@;65Z:2!B=?)K86UI.@!-;V)I;&[M('1E;&5F;VX`2V5L='-K_2`H
M25-/+3@X-3DM,30I`%-T^&5D`%-T^&5D;V%F<FEC:^$@<F5P=6)L:6MA`%-T
M^&5D;V5V<F]P<VO]("A)4T\M.#@U.2TR*0!0;V1R;V)N;W-T:2!C97)T:69I
M:^%T=0!0;V1M[6YK>2!C97)T:69I:^%T=0#(860`6FWL;FET`$YA<W1A=F5N
M[2!J;>EN82!A(&5M86EL;W;I(&%D<F5S>2X@5'ET;R!P;VQOOFMY(&QI9.D@
M=79I9.TL(&MD>;X@<VD@Z'1O=2!N96)O(&]D<&]V[61A:NT@;F$@5F&Y92!Z
M<'+A=GDN`%IN86L`6FMO;G1?<F]L;W9A="!O9&MA>BXN+@!#:&EL90#([6YA
M`,CM;KET:6YA('IJ961N;V1UN65NX2`H1T(R,S$R*0!4<F%D:>AN[2#H[6ZY
M=&EN82`H0FEG-2D`6G9O;'1E(&AE<VQO`%IV;VQT92!UOFEV871E;'-KZ2!J
M;>EN;P!6>6)R870@>F]B<F%Z96[M(&1A='5M=3H`5GEB<F%T('1Y<"!S='EL
M=2!S97IN86UU("AP<F\@^&%Z96[I('-E>FYA;7DI`%;A;F_H;NT@;W-T<F]V
M`$YE8GEL82!N86QE>F5N82!D969I;FEC92!T^.UD>2`E<RX`5GGH:7-T:70`
M5GGH:7-T:70@>FYAZ&MY('H@35-/9F9I8V4`3V1S=')A;NQN[2!UOFEV871E
M;&4Z("5S`$]D<W1R86YI="!UOFEV871E;&4`3V1S=')A;NQN[2#Z9&%J^2!O
M('6^:79A=&5L:0!+;&EK;NQT92!P<F\@<&]K<F'H;W;A;NT`0VQI8VMA=&5L
M;"!P^&5S($A45%``6F%V^.UT(&]K;F\`6F%T8;YE;F\`3V)L8>AN;P!+;VMO
M<V]VZ2!O<W1R;W9Y`%-K;&%P;F]U="!B;^AN[2!L:;ET=0!3:VQA<&YO=70@
M;VMR86IE`$MO;'5M8FEE`$)A<G9A`%;]8NQR(&)A<F5V`%!A;&5T82!B87)E
M=@!3;&]U<&-E.@!.X7IV>2!S;&]U<&-E`$MO;6EK<WD`4/CM:V%Z`%#X[6MA
M>F]VX2!K;VYZ;VQA`%!O>F[A;6MA`$]B96-NZ2!J;>EN;P!+;VUO<F]S`$9I
M<FUA`%!OZ.UT8>AE`%!O9&WM;FMY`%)O>F3M;'D@=B!N87-T879E;NT`3F%S
M=&%V:70@)7,`4&]T=G)D:70@:&5S;&\`2V]N9V\`2V]N9V\L($1E;6]K<F%T
M:6-KX2!R97!U8FQI:V$`4W!O:F5N[2!S96QH86QO+@!3<&]J96[M('-E;&AA
M;&\Z(`!">6QO('IA;>UT;G5T;R!S<&]J96[M(',@=F7X96IN_6T@:VSMZ&]V
M_6T@<V5R=F5R96TN`$)Y;&\@>F%M[71N=71O('-P;VIE;NT@<R!V9?AE:F[]
M;2!K;.WH;W;];2!S97)V97)E;2X@1/EV;V0@.B`E<R`H)7,I`%-E;&AA;&\@
M<W!O:F5N[2!S($944"!S97)V97)E;2X`2V]N=&%K='D@8GEL>2#Z<W#LN6[L
M('#X:63A;GD@9&\@5F&Y96AO(&%D<F5SX?AE+@!0;VMR8>AO=F%T`$-O;VMO
M=GD@;W-T<F]V>0!+;VSAZ&5K`$MO<.UR;W9A=`!+;W#M<F]V870@=OUB['(`
M2V]S=&%R:6MA`%!O8OAEONT@<VQO;F]V:6YY`%IP<N%V=2!N96QZ92"Y:69R
M;W9A="!P;VUO8^T@4$=0+@!:<'+A=G4@;F5L>F4@<&]D97!S870@<&]M;V/M
M(%!'4"X`6G!RX79U(&YE;'IE(+EI9G)O=F%T('!O;6]C[2!3+TU)344N`%IP
M<N%V=2!N96QZ92!P;V1E<'-A="!P;VUO8^T@4R]-24U%+@!.96QZ92!P^&ED
M870@:V]N=&%K="X@)7,`3F5L>F4@<V4@</AI<&]J:70@:R!,1$%0('-E<G9E
M<G4N`$YE;'IE('IK;VYT<F]L;W9A="#ZZ&5T+B`E<P!.96QZ92!V>71V;_AI
M="!D:7-T<FEB=>AN[2!S97IN86TN("5S`$YE;'IE(&1EN6EF<F]V870@4$=0
M(&1A=&$N`$YE;'IE(&1EN6EF<F]V870@4R]-24U%(&1A=&$N`$YE;'IE('-M
M87IA="!K;VYT86MT+B`E<P!.96QZ92!S;6%Z870@9&ES=')I8G7H;NT@<V5Z
M;F%M+B`E<P!.96QZ92!Z:FES=&ET(&4M;6%I;&]V;W4@861R97-U('#X[6IE
M;6-E+@!.96QZ92!Z[7-K870@^G!L;OT@861R97/A^"X`3F5L>F4@>NUS:V%T
M(/IP;&[](&1I<W1R:6)UZ&[M('-E>FYA;2X`3F5L>F4@>NUS:V%T(/IP;&[]
M('-E>FYA;2!D:7-T<FEB=>AN[6-H('-E>FYA;?DN`$YE;'IE('KM<VMA="!V
M9?AE:F[](&ML[>@@>B!K;.WH;W;I:&\@<V5R=F5R=2X`3F5L>F4@;W1E=OCM
M="`E<RX`3F5L>F4@<')O=NES="!O<&5R86-E(/ID<KYB>2!P<F\@;6]D=6P@
M)7,`3F5L>F4@Z.US="`E<RX`3F5L>F4@<F5S971O=F%T(&AE<VQO('!R;R!D
M86[I:&\@=;YI=F%T96QE+B!6N65C:&YY(&YE8F\@;NQK=&5RZ2!Z('!O9')O
M8FYO<W3M(&YE8GEL>2!S<'+A=F[L('IA9.%N>2X@6FMU<W1E('1O('IN;W9U
M(&YE8F\@<&]K=60@<&]T^&5B=6IE=&4@<&]M;V,L(&MO;G1A:W1U:G1E('-P
M<N%V8V4@<WES=.EM=2X`3F5L>F4@>NUS:V%T($%#3`!.96QZ92!Z[7-K870@
M861R97/A^"X@)7,`3F5L>F4@>NUS:V%T(&1I<W1R:6)UZ&[M('-E>FYA;2X@
M)7,`3F5L>F4@>NUS:V%T(&1I<W1R:6)UZ&[M('-E>FYA;7DN("5S`$YE;'IE
M('KM<VMA="!S8VAO<&YO<W1I('-E<G9E<G4`3F5L>F4@</AE<&YO=70@:V]N
M9FEG=7)A8VDN`$YE;'IE('5L;[YI="!K;VYF:6=U<F%C:2!P<F\@)7,N`$YE
M;'IE('5L;[YI="!ZX6QOOF[M(&MO;F9I9W5R86-I+@!.96QZ92!U;&^^:70@
M>N%L;VAU(&MO;F9I9W5R8>AN[6AO('-O=6)O<G4@)7,N`$YE;'IE(&AL961A
M="!V($Q$05`@<V5R=F5R=2X`3F5L>F4@86MT=6%L:7IO=F%T(&MO;G1A:W0N
M("5S`$YE;'IE(&%K='5A;&EZ;W9A="!D:7-T<FEB=>AN[2!S97IN86TN("5S
M`$YE;'IE(&YA;.EZ="!B;^AN[2!L:;ET=2!P<F\@36]Z:6QL=2X@4')O<^UM
M('#X97-V[&3H=&4@<V4L(+YE(&IE(&]T97;X96[A+@!/9'!OZ.UT86[]('1E
M>'0`6F5M[`!6>77H;W9A8^T@</AE9&WL='D`5GET=F_X:70`5GET=F_X:70@
M;V1K87H`5GET=F_X:70@;F]V;W4`5GET=F_X:70@<&]D<VQOOFMY`%1V^7)C
M92!P<N%V`,CM<VQO(&MR961I=&[M(&MA<G1Y`$-H;W)V871S:V\`2W5B80!!
M:W1UX6QN[2#H87,`06MT=>%L;NT@55),(&IE`$%K='7A;&[M('!OZ&%S[0!!
M:W1UX6QN[2!P;V1M[6YK>3H@`$YY;NQJN>T@<W1Y;`!.87-T879E;NT@^FMO
M;/D@<')O=N%D[&[]8V@@</AI('#X:6ALX;EE;NT@9&\@)7,N`%9Y<W3X:6AN
M;W5T`%9Y<W3X:6AN;W5T(';]8NQR`$MY<'(`07IB=6MA("A+3TDX+5(I`$%Z
M8G5K82`H5VEN9&]W<RTQ,C4Q*0!!>F)U:V$O56MR86II;F$@*$M/23@M52D`
MR&5S:^$@<F5P=6)L:6MA`$1$`$1E;F[L`$1A=&%4<F5E('!R;VAL[;YEZ`!$
M871U;0!0^&EJ871O(&1N90!6_6+L<B!D871U;74`1&5N`%-M85]Z870@<VQO
M=7!E8P!0<F]S:6YE8P#([7-L82!D97/M=&MO=ND@<V]U<W1A=GD`6FUE;KEI
M="!O9'-A>F5N[0!);7!L:6-I=&[M`$EM<&QI8VET;NT@8F%R=F$`26UP;&EC
M:71N[2!I9&5N=&ET80!$969I;FEC90!3;6%Z870`4VUA>F%T('-K=7!I;G4`
M4VUA>F%T('!RX79A`%-M87IA="!A('9YZ&ES=&ET('IP<N%V>0!3;6%Z870@
M8G7R:W4`4VUA>F%T('-L;W5P96,`4VUA>F%T(&5X:7-T=6KM8^T@86QT97)N
M871I=F[M('9Z;W(`4VUA>F%T(/CA9&5K`%-M87IA="!V>6)R86YO=2CI*2!I
M9&5N=&ET=2AY*0!3;6%Z870@<V]UZ&%S;OT@<VQO=7!E8P!3;6%Z870@<V]U
MZ&%S;OT@^.%D96L`R&%S(&1O<G7H96[M`$3A;G-K;P!0;W!S870@<')O8FSI
M;0!0;W!I<P!0;V1R;V)N;W-T:2`H=&%KZ2!V(&QO9R!S;W5B;W)U($AO<F1E
M*3H`4&]D<F]B;F]S=&D@8GEL>2!Z87IN86UE;N%N>2!D;R!L;V<@<V]U8F]R
M=2!P<F\@861M:6YI<W1RX71O<F$N`%;]=F]J`%)O<V[](&)O9`!2;W-N_2!B
M;V0@>F$@<&]S;&5D;NT@:&]D:6YU.B``4F]S;OT@8F]D.B``4VWL<B!Z(&QE
M=F$@9&]P<F%V80!3;>QR('H@<')A=F$@9&]L979A`$%D<F5SX?@`6F]B<F%Z
M:70@,C0M:&]D:6YO=OT@Z&%S/P!-;[YN;W-T:2!Z;V)R87IE;NT`6F]B<F%Z
M:70@</AE9'!O=NSO("A4048I`$9O<FWA="!Z;V)R87IE;NT`1&ES<&]Z:>AN
M[2!U<&]Z;W)N[&[M`$1J:6)O=71I`$YE<VUA>F%T`$YE</AI<W1U<&]V870@
M</CM;6\@9&\@;6%I;G1E;F%N8V4N<&AP`$]B<V%H=6IE('!R=F[M(/CA9&5K
M(&[A>F5V('-L;W5P8_D_(%!O:W5D(&%N;RP@>F&Y:W)T;NQT92!T96YT;R!R
MX6UEZ&5K.@!$;VUI;FEK80!$;VUI;FEKX6YS:^$@<F5P=6)L:6MA`%-T8;YE
M;NT`4W1AOF5N[2`E<P!3=&%H;F]U="!G96YE<F]V86YO=2!K;VYF:6=U<F%C
M:2!J86MO(%!(4"!S:W)I<'0N`%)O;&5T;W;]('-E>FYA;0!$<F]G>0!%+6UA
M:6P`15)2`$5K=N%D;W(`57!R879I=`!5<')A=FET(&)L;VL`57!R879I="!S
M:W5P:6YU`%5P<F%V:70@<'+A=F$`57!R879I="!P<N%V80!5<')A=FET('!R
MX79A('!R;R`E<P!5<')A=FET(&UOOFYO<W1I('!R;SH`57!R879I="!P<N%V
M82!P<F\@)7,`5OUU:V$`16=Y<'0`16P@4V%L=F%D;W(`4')V96LN+BX`16T`
M16UA:6P`16UA:6QO=N$@861R97-A`$5M86EL;W;I(&%D<F5S>2!S92!M=7/M
M('-H;V1O=F%T+@!%;6%I;"!S('!O='9R>F5N[6T`26MO;FMY(',@96UO8V5M
M:0!0<N%Z9&[A('IP<N%V82X`4'+A>F1N_2!V_7-L961E:RX`4'+A>F1N_2!T
M97)M[6X@<')O('9Y:&QE9.%VX6[M`%!O=F]L:70@=FMLX63A;NT@;V)R87IK
M^2!Z(&9O=&\@9V%L97)I[2!D;R!T97AT=3\`06MT:79O=F%T('!R87;I(&ML
M:6MN=73M('!R;R!K;VYT97AT;W;I(&UE;G4_`$MO;F5C(')O:W4`6G;L=+EI
M="!E9&ET;W(`6F%D96IT92!B97IP9>AN;W-T;NT@;W3A>FMU+"!N82!K=&5R
M;W4@8G5D971E(&UU<V5T(&]D<&]V[&3L="!P;VMU9"!S:2!B=61E=&4@8VAT
M[70@<F5S971O=F%T('-VZ2!H97-L;RP@;F%P^"X@)TIA:^D@:F4@:FWI;F\@
M5F&Y96AO('!S83\G.@!:9&4@=FQOOFET(%523"!O8G+A>FMU`%)O=F[M:V]V
MX2!'=6EN96$`17)I=')E80!#:'EB80!.87-T86QA(&-H>6)A(',@<&^Y=&]V
M;NT@>G!RX79O=2X`17-T;VYS:V\`171I;W!I90!%=&YI8VOI`$5V<F]P80!+
M8;YD_6-H(#$U(&UI;G5T`$MAOF3I(#(@;6EN=71Y`$MAOF3]8V@@,S`@<V5K
M=6YD`$MAOF3]8V@@-2!M:6YU=`!+8;YDZ2!P^&EH;.&Y96[M(&1O('-Y<W3I
M;74`2V&^9&]U('#Y;"!H;V1I;G4`2V&^9&]U(&UI;G5T=0!6>F]R;W;]('#X
M[6ML860@:&]D;F]T.@!0<F]VZ7-T`%)O>G9I;F]U=`!2;WIB86QI="!B;^AN
M[2!L:;ET=0!/Z&5KX7;A;F$@)RDG`$_H96OA=N%N;R!S86UO<W1A=&[I('-L
M;W9O(&YE8F\@:&QE9&%N_2!T97)M[6X@=B!U=F]Z;W9KX6-H`$1A='5M('!R
M;R!K;VYE8R!P;&%T;F]S=&D`17AP;VYE;G0`0F%R=F$@<&]P^&5D[0!0^&5N
M;W,@:V]N9FEG=7)A8V4@<&]M;V/M($944`!396QH86QO('KM<VOA;NT@;6^^
M;F]S=.TN`$YE;'IE('-E('#X:7!O:FET(&L@3$1!4"!S97)V97)U+@!.96QZ
M92!S92!P^&EP;VII="!K(%--0B!S97)V97)U+@!396QH86QO(&MO<.UR;W;A
M;NT@>B`B)7,B+@!396QH86QO(&MO<.UR;W;A;NT@9&\@(B5S(BX`4V5L:&%L
M;R!Z86QOOF5N[2!N;W;I:&\@4T%33"!S<&]J96[M+@!396QH86QO('#X97-U
M;G5T[2!D;R`B)7,B+@!$;V)RZ0!&86QK;&%N9'-KZ2!O<W1R;W9Y("A-86QV
M:6YY*0!&87)I:G-KZ2!O<W1R;W9Y`%KA=F&^;N$@8VAY8F$Z`$9A>`#:;F]R
M`$/M=&ET('-E(&IA:V\`0^UT:70@<V4@:F%K;SH`1')O8F[I('#X96CA\FMY
M`$1R;V)NZ2!S;NQH;W;I('#X96CA\FMY`$UA=&EC92!P;VQE`$9I:FD`4&_H
M970@<V]U8F]R^3H@)7,@<V]U8F]R`%!OZ&5T('-O=6)O<ODZ("5S('-O=6)O
M<OD`4W!RX79C92!S;W5B;W+Y`$[A>F5V('-O=6)O<G4`5OUB['(@<V]U8F]R
M=0!0^&5NZ7-T('-O=6)O<@!0^&5N;W,@<V]U8F]R^2!N96[M('!O9'!O<F]V
MX6XN`$9I;'1R>0!&:6YS:V\`4')V;NT@<&]L;W9I;F$`4')V;NT@Z'1V<G1I
M;F$`4&5V;ND@;>SX[71K;P!0^&5H;V1I=`!0;&]V;W5C[0!-;&AA`%-L;[YK
M82`E<R!N965X:7-T=6IE`$)A<G9A('#M<VUA`$KM9&QO`%!R;R!P<F]H;.V^
M9>AE(&YE<&]D<&]R=6KM8^T@;V)RX7IK>0!0^&5D<&]V[.\@*%1!1BD`4/AE
M9'!O=NSO('!OZ&%S[2!P<F\@9&YY("AP;WINX6UK83H@</AE9'!O=NSO(&IE
M('!R;R!D;GD@:2!N;V-I.R!T;W1O(&WYOF4@=GET=F_X:70@<&]M[')N["!O
M8G/A:&S]('-E>FYA;2X`6F%P;VUN[&QI(&IS=&4@5F&Y92!H97-L;S\`1F]R
M;75LX?AE`*ET['-T[0!4>7`@N73L<W3M`*ET['-T[0"I=.QS=.T@,@!&\W)A
M`%#X97!O<VSA;NT`4.$`4N%M>0!&<F%N8VEE`$9R86YC:64L(&UE=')O<&]L
M:71N[0!&<F%N8V]U<VOA($=U86GA;F$`1G)A;F-O=7-KX2!0;VQY;NES:64`
M1G)A;F-O=7-KX2!J:;YN[2!T97)I=&]R:6$`3V0`3V0`4&]D<F]B;OT@<&]P
M:7,`VG!L;NQK`$-E;.D@:FWI;F\`1V%B;VX`1V%L97)I92!P<F\@=OUB['(@
M;V)RX7IK^0!'86QE<FEE.@!'86UB:64`5GET=F_X:70@)7,@:V]N9FEG=7)A
M8VD`5GEG96YE<F]V86[](&OS9`!'<G5Z[6YS:V\`3NQM96-K;P!':&%N80!'
M:6)R86QT87(`2_AE<W1N[2!J;>EN;P!*9&D@;F$`1V]E9&5L`%9Y:&QE9.%V
MX6[M('!O;6]C[2!';V]G;'4`4W1U<&[L(+EE9&D`V&5C:V\`V&5C:^D@*$E3
M3RTX.#4Y+3<I`$=R\VYS:V\`1W)E;F%D80!!9&UI;FES=')A8V4@<')O('-K
M=7!I;GD`375S[2!B_70@>F%DX6YO(&IMZ6YO('-K=7!I;GD`4VMU<&EN>0!'
M=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`%!RX79A(&AO<W3Y
M`$MN:6AA(&AO<W3Y`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,
M`$A434Q!<F5A('IB86+L;&4@;V1M[73A('-M87IA="!P;W-L961N[2!B=?)K
M=2!N82#XX61K=2X`2%1-3$%R96$@>F)A8NQL92!O9&WM=.$@<VUA>F%T('!O
M<VQE9&[M(&)U\FMU('9E('-L;W5P8VD@=&%B=6QK>2X`2%1-3$%R96$@>F)A
M8NQL92!O9&WM=.$@<VUA>F%T('!O<VQE9&[M(/CA9&5K('8@=&%B=6QC92X`
M3W;L^&]VX6[M('!O;6]C[2!(5%10(&YE8GEL;R!N86QE>F5N;RX`2&%I=&D`
M2&%S:"UA;&=O<FET;75S`$UL:&%V;P!(;&%V:>AK80!(96%R9"!)<VQA;F0@
M82!-8T1O;F%L9"!)<VQA;F1S`$AE8G)E:KET:6YA("A)4T\M.#@U.2TX+4DI
M`%;]N6MA`$[A<&]V[&1A`$[A<&]V[&1A('!R;R!E9&ET;W(`4&]M;V-N[6L`
M2&5M:7-FZ7)A`%ID92!J92!Z8>CA=&5K('-O=6)O<G4Z`%9Y<V]KX0!?2&]R
M9&4`4W9A=.D@3>QS=&\@*%9A=&EKX6XI`$AO<F1E`$%D<F5S82!D;VWY`%1E
M;&5F;VX@9&]M^0!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L
M86(Z($YE<&QA=&[I("5S(%A-3"!D871A('9E('IP<N%V["`E<P!(;W)D92]+
M;VQA8CH@KN%D;N$@>G!RX79A('-E(&YE<VAO9'5J92!S(&]B:F5K=&5M("5S
M`$AO<F1E+TMO;&%B.B!.96)Y;"!N86QE>F5N(+[A9&[](&]B:F5K="!T>7!U
M("5S('9E('IP<N%V["`E<P!(;W)D92]+;VQA8CH@VG-P[+ENZ2!O9'-T<F%N
M[&[M("5S("(E<R(`2&]R9&4O2V]L86(Z($EN=&5G<F'H;NT@;N%S=')O:B!P
M;W3X96)U:F4@4$A0('#X[7!O;G4@)V1O;7AM;"<`2&]R9&4O2V]L86(Z($YE
M;'IE('9Y='9O^&ET(&YO=OT@<W1R;VT@6$U,('!R;R!O8FIE:W0@)7,`2&]R
M9&4O2V]L86(Z($YE;'IE(&]D<W1R86YI="`E<R`B)7,B.B`E<P!(;W)D92]+
M;VQA8CH@3F5L>F4@>NUS:V%T($U)344@240@<')O(.CA<W0@='EP=2`E<P!(
M;W)D92]+;VQA8CH@3F5L>F4@<WEN8VAR;VYI>F]V870@)7,@(B5S(CH@)7,`
M2&]R9&4O2V]L86(Z($YE;'IE('-Y;F-H<F]N:7IO=F%T('-D[6QE;ND@;V)J
M96MT>3H@)7,`2&]R9&4O2V]L86(Z($YE>F[A;?T@<V3M;&5N_2!O8FIE:W0@
M(B5S(@!6;V1O<F]V;ND@<')A=NUT:V\`2&]R:7IO;G3A;&[M(&]D<W1U<`!(
M;W)I>F]N=.%L;NTZ`$IA:R!J<W1E('-E('-E;2!D;W-T86QI/R`H6F&Y;&5T
M92!P<F]S[6T@>G!RX79U(2D`2V]L:6L@<VQO=7!C^2!C:&-E=&4@<W!O:FET
M/P!+;VQI:R!J92!T86T@<&]L[2`H<VQO=7!C^2D_`$MO;&EK(/CA9&OY(&-H
M8V5T92!S<&]J:70_`%9L:&MO<W0`5FQH:V]S=#H`2'5M;W)NZ0!-8>]A<G-K
M;P!396QH86QO('9Y='9O^&5N[2!)34%0;W;I('-C:'+A;FMY.B`E<P!396QH
M86QO('-M87KA;NT@24U!4&]VZ2!S8VARX6YK>3H@)7,`4V5L:&%L;R!N87-T
M879E;NT@:W;S='D@<')O($E-05!O=F]U('-C:'+A;FMU.B`E<P!)4"!A9')E
M<V$`25`@861R97-A(&YE;NT@9&]S='5P;N$N`$E0(&%D<F5S82!N96[M('8@
M<&]V;VQE;NEM($-)1%(@<F]Z<V%H=2X`4&]R=;EE;NT@:6YT96=R:71Y($E0
M+@!67VQOOG1E(/CA9&5K('#X960`27-L86YD`%!O=7IE(&EK;VYY`$EK;VYY
M('!R;R`E<P!):V]N>2!S('1E>'1E;0!.X7IE=B!I9&5N=&ET>3H`4&]K=60@
M>F]B<F%Z96[M(&YE;NT@=B!P;_CA9&MU+"`E<R!O=&5V^.UT('8@;F]VZ6T@
M;VMN["X`4&]K=60@<&]UONUVX71E($EN=&5R;F5T($5X<&QO<F5R(&$@;F5V
M:63M=&4@ON%D;ND@:6MO;GDL('KX96IM["!P;W3X96)U:F5T92!O>FYAZ&ET
M('1E;G1O('+A;67H96L@<')O('9Y<&YU=.T@4$Y'('1R86YS<&%R96YC92X`
M4&]K=60@=FED[71E('1U=&\@>G!RX79U(&WM<W1O(&]B<N%Z:W4L(&]B<N%Z
M96L@:W1E<OT@8VAC971E('#X96[I<W0@;F5L>F4@5F&Y[6T@<')O:&SMOF7H
M96T@>F]B<F%Z:70N`$[A:&QE9"!O8G+A>FMU.@!54DP@;V)RX7IK=0!54DP@
M;V)RX7IK=3H`3V)RX7IE:R!Z(&=A;&5R:64`3V)RX7IE:R!Z(&=A;&5R:64Z
M`%#X96YO<R!O8G+A>FMU`$]B<N%Z:WD`26UP;W)T+"!K<F]K("5D`$EM<&]R
M=&]V86[I('!O;&4Z("5S`$EM<&]R=&]V86[A('!O;&4Z`%9L;[YI="#XX61K
M=2!Z80!">6P@>F%DX6X@;F5S<'+A=F[](&%KZ&[M(&OS9"X`3F5S<'+A=F[L
M('IA9&%NZ2!UOFEV871E;'-KZ2!J;>EN;R!A+VYE8F\@:&5S;&\N`$YE<W!R
MX79NZ2!UOFEV871E;'-KZ2!J;>EN;R!N96)O(&%L=&5R;F%T:79N[2!A9')E
M<V$N(%IK=7-T92!J9;ET["!J961N;W4@;F5B;R!K;VYT86MT=6IT92!68;EE
M:&\@<WES=.EM;W;I:&\@861M:6YI<W1RX71O<F$N`%IV['2Y:70@;V1S87IE
M;NT`26YD:64`2F5D;F]T;&EV[2!UOFEV871E;.D`26YD;V[I<VEE`$EN9F]R
M;6%C90!);F9O<FUA8V4`5FQOOFET('-?;&]U<&5C('IA`%9L;[YI="!O8G+A
M>F5K`%9L;[YI="!T86)U;&MU`%9L;[YI="!W96)O=OT@;V1K87H`5FQOOFET
M(%]S;&]U<&5C('#X960@`%9L;[YI="!N;W;]('-L;W5P96,@>F$@<V]UZ&%S
M;OT`5FQOOFET(&YO=OT@<VQO=7!E8R!P^&5D('-O=>AA<V[]`%9L;[YI="!N
M;W;](/CA9&5K('IA('-O=>AA<V[]`%9L;[YI="!N;W;](/CA9&5K('#X960@
M<V]UZ&%S;OT`5FQOOFET(&]D<W1A=F5C('IA('-O=>AA<V[]('5Z96P`5FQO
MOFET(&]D<W1A=F5C('#X960@<V]UZ&%S;OT@=7IE;`!6;&^^:70@86QT97)N
M871I=F[M('9Z;W(`5FQOOG1E(&5M86EL;W9O=2!A9')E<W4L(&YA(&MT97)O
M=2!O8F1RONUT92!N;W;I(&AE<VQO.@!6;&^^:70@8G7R:W4@>F$`5FQOOFET
M(&)U\FMU('#X960`5FQOOFET('-L;W5P96,@>F$`5FQOOFET('-L;W5P96,@
M</AE9`!6;&^^:70@>G!RX79Y`%9L;[YI="!O9'-T879E8R!Z80!6;&^^:70@
M;V1S=&%V96,@</AE9`!6;&^^:70@^.%D96L@>F$`5FQOOFET(/CA9&5K('#X
M960`5FQOOG1E('!OOF%D;W9A;F]U(&]D<&]V[.\@;F$@8F5Z<&7H;F]S=&[M
M(&]TX7IK=3H`5FQOOFET+W5P<F%V:70@;V)RX7IE:P!6;&^^:70O=7!R879I
M="!O9&MA>@!.961O<W1A=&7H;OT@:W)E9&ET(&L@;V1E<VSA;NT@>G!RX79Y
M(&YA(&1I<W1R:6)UZ&[M('-E>FYA;2X`3F5D;W-T871EZ&[](&MR961I="X`
M0V5LZ2#H[7-L;P!397IN86T@8V5L_6-H(.CM<V5L`$YE<W!RX79NZ2!51$@N
M("A5<V5R($1A=&$@2&5A9&5R*2X`3F5P;&%T;N$@87!L:6MA8V4N`$YE<&QA
M=&[I(&ED96YT:69I:V'H;NT@Z.US;&\@*$E$*2!DX79K>2X`0GEL82!Z863A
M;F$@;F5P;&%T;N$@9&%T80!.97!L871NX2!A9')E<V$@</CM:F5M8V4N`$YE
M<&QA=&[](&9O<FWA="!S;W5B;W)U`$YE<&QA=&[](&US9U]T>7!E+@!.97!L
M871NZ2!N96)O(&-H>6+L:NUC[2!A<&E?:60N`$YE<&QA=&[I(&YE8F\@8VAY
M8NQJ[6/M('!A<F%M971R>2X`3F5P;&%T;N$@=FQA<W1N:6-KX2!P<N%V82X`
M3F5P;&%T;OT@<')O=&]K;VPN`$YE<&QA=&[]('-D[6QE;OT@;V)J96MT`$YE
M<&QA=&[A(&%D<F5S82!O9&5S[6QA=&5L92X`3F5P;&%T;N$@9&%T82!U;FEC
M;V1E+@!);G9E;G3A^`#-<N%N+"!)<VSA;7-KX2!R97!U8FQI:V$`27+A:P!)
M<G-K;P!/<W1R;W8@;76^90!/:F5D:6[L;.D@8F]U^&MY`$ES<F%E;`!0;W-K
M>71O=F%T96P`2W5R>NUV80!)=.%L:64`2F%M86IK80!,961E;@!*87!O;G-K
M;P!*87!O;KET:6YA("A)4T\M,C`R,BU*4"D`5')I:V]T`$IO<F3A;G-K;P#(
M97)V96YE8P#(97)V96X`6F%R;W9N870`6F%R;W9N870@;F$@<W3X960`6F%R
M;W9N870@=GEP;&[L;NUM`%IA<F]V;F%T(&1O;&5V80!:87)O=FYA="!D;W!R
M879A`$MA>F%C:'-TX6X`56-H;W9A="!O<FEG:6[A;#\`2V7R80!+97)B97)O
M<R!S97)V97(@>F%M[71N=6P@;W;L^&5N[2X`3F]VX>AC:2!K97)N96QU`%9Y
M='9O^&5N[2!K;.WH90!6>71V;_AE;NT@;W1I<VMU(&ML[>AE`$3I;&MA(&ML
M[>AE`%1Y<"!K;.WH90!5OFET[2!K;.WH90!+;.WH(&IIOB!E>&ES='5J92!N
M82!V9?AE:F[I;2!K;.WH;W;I;2!S97)V97)U+@!$['1I`$MI<FEB871I`$M,
M1%(`2V]R96$`2V]R96IS:WD@*$550RU+4BD`2W5V86IT`$MY<F=I>G-TX6X`
M7U)O>FQOOF5N[0!*87IY:P!,86]S+"!,:61O=NP@1&5M;VMR871I8VMA(%)E
M<'5B;&EK80!$<G5HX2!P;VQO=FEN80!0;W-L961N[2#H='9R=&EN80!0;W-L
M961N[2!A:W1U86QI>F%C93H`4&]S;&5D;NT@</AI:&SAN65N[3H@)7,`4&]S
M;&5D;NT@</AI:&SAN65N[3H@)7,@>B`E<P!0;W-L961N[2!P^&EH;.&Y96[M
M.B!.:6MD>0!,:71V80!0<N%V;P!2;WIL;[YE;NT`3F5C:&%T('!RX7ID;ND@
M8F5Z(&]K<F%J90!,:6)A;F]N`$1O;&5V80!,97;A(&AL879IZ&MA`$AO9&YO
M='D@;F%L979O`$QE<V]T:&\`3&EBZ7)I90!,:6)I90!,:6-H=&5NN71E:FYS
M:V\`3&5H:^D@;7)H;VQE;NT`3&5H:_T@9.FYNP!"<GIK_2!L96AK_2!DZ;F[
M`%!O>F3L:FD@;&5H:_T@9.FYNP!,96AKZ2!D9;F[;W;I('-RX;YK>0!,96AK
M_2!DZ;F[(',@:/AM[&[M;0!,96AKZ2!S;NR^96[M`$QE:&OI('-N[&AO=ND@
M</AE:.'R:WD`3&EM97)I8VL`3V1K87H`3V1K87IY('5K87IU:NT@;F$Z`%!O
M=;[M="!O9&MA>GD@;F$@96UA:6QO=ND@861R97-Y('#X:2!Z;V)R87IO=N%N
M[2!S='+A;FMY('!R;R!P<V%N[2!Z<'+A=@!/9&MA>GD`3&EN=7AO=ND@8V]O
M:VEE`%-E>FYA;2`M('6^:79A=&5L(&WYOF4@=FED['0@<VQOOFMU`%-E>FYA
M;2!D871A8N%Z[0!397IN86T@=.EM870@;N%P;W;L9'D`4V5Z;F%M('1A8G5L
M96L`4V5Z;F%M+4%R8VAI=@!397IN86TM3N%P;W;L9&$`4V5Z;F%M+4ED`%-E
M>FYA;2U6;&%S=&[M:P!397IN86TM3V1E<VSA;NT`4V5Z;F%M+5#X:6ALX;EE
M;NT`4V5Z;F%M+4]D:&SAN65N[0!6_7!I<R!UOFEV871E;/D@;F5N[2!D;W-T
M=7!N_2X`3&ET97)A='5R80!,;W1YN7-K;P!.86ARX7;A;NTN+BX`3>US=&[M
M(.AA<SH@`$QO8V%L92!A(.AA<P!-[7-T;P!0^&EH;.%S:70@<V4`3V1H;.&Y
M96[M`-IK;VQY('!R;W;A9.QNZ2!P^&D@</AI:&SAN65N[0!396QH86QO('#X
M:6ALX;EE;NT@9&\@<WES=.EM=2X@4')A=F3L<&]D;V)N["!68;EE('6^:79A
M=&5L<VOI(&IMZ6YO(&$O;F5B;R!H97-L;R!N96)Y;&\@<W!RX79N["!Z863A
M;F\N`%#X:6ALX;EE;NT@<V5L:&%L;RX`1&QO=6C]('1E>'0`3.%S:V$`3NUZ
M:^$`36%LX2#X96-KX2!P[7-M96YA`$UA;.$@=&ES:V%C[2!P[7-M96YA`$UA
M;.D@^.UM<VOI(.CM<VQI8V4`3'5C96UB=7)S:V\`34T`6G!RX79A(&1N90!0
M^&EP;VIE;OT@<V]U8F]R($U3+4Y4148@;F5O8G-A:'5J92"^X61NX2!D871A
M+@!-4T<`36%K86\`36%K961O;FEE+"!B_79A;.$@4F5P=6)L:6MA($IU9V]S
M;.%V:64`36%D86=A<VMA<@!-86=I90!0;[ET80!!9&UI;FES='+A=&]R('!O
MN71Y`%9Y='9O^&ET(&]D7VMA>BXN+@!-86QA=VD`36%L86IS:64`36%L9&EV
M>0!-86QI`$UA;'1A`%!R;R!U;6^^;NQN[2!O=FSA9.%N[2!K871E9V]R:>T@
M:F4@>F%P;W3X96+M(&]Z;F'H:70@<&]L;[YK>2!B87)V86UI+"!K=&5RZ2!J
M<V]U('#X:?AA>F5N>2!K('3L;71O(&MA=&5G;W)I[6TN`$UA<&$@36%P,C0`
M36%P82!-87!1=65S=`!"^&5Z96X`3VMR86H`3WIN8>AI="!Z;F'H:V]U(%!R
M;VALZ61N=71O+TYE<')O:&SI9&YU=&\`3WIN8>AI="!J:6[];6D@>FYAZ&MA
M;6D@*&IA:V\@1/EL9;YI=.DO3V1P;W;L>F5NZ2D`36%RN6%L<VOI($]S=')O
M=GD`36%R=&EN:7%U90!3:&]D=6KM8^T@<V4@<&]L90!-875R973A;FEE`$UA
M=7)I8VEU<P!-87AI;6%L;NT@<&]V;VQE;OT@:W)E9&ET`$)Y;&$@</AE:W)O
MZ&5N82!M87AI;6%L;NT@9.EL:V$@>G!RX79Y+@!.96IV>;FY[2!T97!L;W1A
M('IA('!O<VQE9&[M8V@@,C0@:&]D:6XZ(`!.96IV>;FY[2!T97!L;W1A('IA
M('!O<VQE9&[M8V@@-B!H;V1I;CH@`$UA>&EMX6QN[2!DZ6QK80!+=NQT96X`
M36%Y;W1T90!-961I8^UN80#(;&5N;W;I`$WS9'D@<')O(&UE;G4Z`%-P;VII
M="!B=?)K>0!:<'+A=F$`6G!RX79A(&)Y;&$@;W;L^&5N82!V('!O^.%D:W4L
M(&%L92!N96QZ92!O=NSX:70@<&]D<&ES;W;](&-E<G1I9FEKX70N`%IP<N%V
M82!P<F]P861L82X`5'EP('IP<N%V>0!0;^AA<^T`0FQO:R!O('!OZ&%S[2!N
M96[M(&1O<W1U<&[]+@!";&]K(&\@<&_H87/M(&YE;NT@9&]S='5P;OTN(%!O
M9')O8FYO<W1I(&)Y;'D@>F%Z;F%M96[A;GD@<')O('-Y<W3I;6]VZ6AO(&%D
M;6EN:7-T<N%T;W)A(&1O(&QO9W4N`$UE=&]D80!-971R:6-K_0!-97AI:V\`
M36EK<F]NZ7-I92P@1F5D97)A8V4`57!R;W-T^&5D`%1Y<"!-:6UE`$YE:FYI
MOKGM('1E<&QO=&$@>F$@<&]S;&5D;NUC:"`R-"!H;V1I;CH@`$YE:FYIOKGM
M('1E<&QO=&$@>F$@<&]S;&5D;NUC:"`V(&AO9&EN.B``6G)C861L;W;L`%+Y
M>F[I`%!R;V=R86UO=OT@8F%L[6L@2%144%]297%U97-T(&-H>6+M('8@4$5!
M4BX`0VAY8NQJ[6/M(&MO;F9I9W5R86-E+B!0;VMU9"!S:2!P^&5J971E('!O
M=;[M=F%T('1U=&\@87!L:6MA8VDL(&UU<^UT92!V>6=E;F5R;W9A="!K;VYF
M:6=U<F'H;NT@<V]U8F]R+@!#:'EB[&KM8^T@240@>G!RX79Y("AI9&5N=&EF
M:6MAZ&[M(.CM<VQO*0!0;[YA9&]V86[]('!R;V=R86UO=OT@8F%L[6L@36%I
M;"!C:'EB[2!V(%!%05(N`$-H>6+L:NUC[2!)1"!P<F\@<F5L86-I+@!0;P!-
M;V)I;&[M('!ON71A`$WM<F[]`$1A='5M('!O<VQE9&[M('IM[&YY`%IM[/)I
M="!54DP`36]D=6P`36]L9.%V:64`36]N86MO`$UO;F=O;'-K;P!-['/M8R!A
M(')O:P!-['/MZ&[L`$UO;G-E<F%T`$;A>F4@3>QS[6-E`$UA<F]K;P!0^&5V
MX;YN["!J87-N;P!0^&5VX;YN["!O8FQAZ&YO`%#X97;AOF[L('-L=6YEZ&YO
M`%!O<W5N;W5T(&1O;/D`4&]S=6YO=70@9&]L979A`%!O<W5N;W5T(&1O<')A
M=F$`4&]S=6YO=70@;F%H;W)U`%!O<W5N;W5T(&1O;/D`4&]S=6YO=70@;F%H
M;W)U`$UO<V%M8FEK`%;M8V4M^G)O=O)O=ND@<F]L971O=ND@<V5Z;F%M>0!6
M[6-E;N%S;V)NX2!S96QE:V-E`$WY:B#ZZ&5T`$WY:B!P;W)TX6P`36]J92!R
M;WIL;[YE;NT@<&]R=.%L=0!->6%N;6%R`$Y%+"!.15-/54A,05/-30!*;>EN
M;P!.86UI8FEE`$YA=7)U`$YE<.%L`$YI>F]Z96WM`$YI>F]Z96US:^D@06YT
M:6QY`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!(%)E=F]C871I;VX@
M55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A;"!5
M4DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`2FWI;F\@3F5T<V-A<&4@4U-,
M('-E<G9E<G4`4&]Z;N%M:V$@:R!C97)T:69I:^%T=2!.971S8V%P=0!4>7`@
M8V5R=&EF:6OA='4@3F5T<V-A<'4`4^V[`$YI:V1Y`$YO=N$@2V%L961O;FEE
M`$YO=N$@:V%T96=O<FEE`$WL<^UC('8@<')V;NT@Z'1V<G1I;NP`3F]VZ2!U
MOFEV871E;'-KZ2!J;>EN;R`H;F5P;W9I;F[I*0!.;W;](%KI;&%N9`!.;W;I
M(&]K;F\@*%]P<N%Z9&[I*0!.;W9I;FMY`$YE=W-G<F]U<',`1&%LN>T`1&%L
MN>T@;6^^;F]S=&D`3FEK87)A9W5A`$YI9V5R`$YI9^ER:64`3F]C`$YI=64`
M3F4`KF%D;N$@:V]N9FEG=7)AZ&[M(&1A=&$@;F5J<V]U(&1O<W1U<&[A('!R
M;R!Z;V)R87IE;NT@<F]Z9.UL^2X`3F5N[2!D;W-T=7!NX2"^X61NX2!S=')A
M=&5G:64@<')O('1V;W)B=2!)4T\@;V)R87KY+@!"97H@9.%V:V]VZ6AO('9Z
M;W)U+@!.82!P;[YA9&]V86[I('!O>FEC:2!N965X:7-T=6IE(+[A9&[](&)L
M;VL`3F5B>6QO('!O<VMY=&YU=&\@ON%D;ND@:FWI;F\@<')O(&MA;&5N9.'X
M('#X:2!O=NSX;W;A;NT@<&]M;V/M($U#04PN`$)E>B!Z;>QN>2X`3F5L>F4@
M</AI9&%T(+[A9&[A('!O9"UP<N%V82!K('3L;71O('!RX7;Y;2X`3F5B>6QY
M('5V961E;GD@ON%D;ND@:V]N9FEG=7)AZ&[M(&EN9F]R;6%C92!P<F\@)7,N
M`$YE8GEL>2!U=F5D96YY(+[A9&[I(&MO;F9I9W5R8>AN[2!I;F9O<FUA8V4@
M<')O($944"!61E,N`$YE8GEL>2!U=F5D96YY(+[A9&[I(&MO;F9I9W5R8>AN
M[2!I;F9O<FUA8V4@<')O(%-13"!61E,N`$YE8GEL>2!U=F5D96YY(+[A9&[I
M(&MO;F9I9W5R8>AN[2!I;F9O<FUA8V4@<')O(%-13"U&:6QE(%9&4RX`3F5M
MX71E(+[A9&[](&MR961I="X`3F5B>6P@<&]S:WET;G5T(+[A9&[](&/M;"X`
MKN%D;OT@<V]U8F]R(&YE8GEL('#X96YE<V5N`$YE8GEL>2!N86QE>F5N>2"^
MX61NZ2!I:V]N>2X`3F5B>6QO('9Y8G+A;F\@ON%D;ND@;>US=&\N`$YE8GEL
M>2!P;W-K>71N=71Y(+[A9&[I('IP<N%V>2X`3F5B>6QO('5V961E;F\@ON%D
M;ND@:FWI;F\N`$YE8GEL;R!U=F5D96YO(+[A9&[I(.CM<VQO+@!"97H@;F5S
M;'6Y;OUC:`!.96)Y;&\@<&]S:WET;G5T;R!H97-L;R!P<F\@;W;L^&5N[2!P
M;VUO8^T@2%144"X`3F5B>6QO('!O<VMY=&YU=&\@:&5S;&\@<')O(&]V[/AE
M;NT@<&]M;V/M($E-05`N`$YE8GEL;R!P;W-K>71N=71O(&AE<VQO('!R;R!O
M=NSX96[M('!O;6]C[2!+97)B97)O<RX`3F5B>6QO('!O<VMY=&YU=&\@:&5S
M;&\@<')O(&]V[/AE;NT@</AI:&SAN65N[2!S92!D;R!S>7-TZ6UU+@!.96)Y
M;&\@<&]S:WET;G5T;R!H97-L;R!P<F\@;W;L^&5N[2!P;VUO8^T@4$%34U=$
M+@!.96)Y;&\@<&]S:WET;G5T;R!H97-L;R!P<F\@;W;L^&5N[2!P;VUO8^T@
M4TU"+@!.96)Y;&$@<&]S:WET;G5T82!C97-T82!K(&)I;N%R;NUM=2!S;W5B
M;W)U($]P96Y34TPN($)I;N%R;NT@<V]U8F]R($]P96Y34TP@:F4@>F%P;W3X
M96+M('!R;R!P<N%C:2!S(%!+0U,@,3(@9&%T>2X`KN%D;ND@;F5V>?CM>F5N
MZ2"^X61O<W1I(&\@</AI:&SAN65N[2X`0F5Z('!R879I9&5L`$)E>B!O:W)A
M:OD`KN%D;OT@>B!D;^AA<V[]8V@@861R97/A^/D@;F5N[2!D;W-T=7!N_2!P
M<F\@8V%C:&4N`$YE8GEL;R!O9&5S;.%N;R"^X61NZ2!UOFEV871E;'-KZ2!J
M;>EN;R!A+VYE8F\@:&5S;&\N`$YE8GEL82!N879RX6-E;F$@ON%D;N$@<&QA
M=&[A(%A-3"!D871A+@"NX61NZ2!H;V1N;W1Y`%8@;W)I9VENX6QN[2!K;VYF
M:6=U<F%C:2!N96)Y;&$@;F%L97IE;F$@=F5R>F4N($]B;F]V=&4@:V]N9FEG
M=7)A8VDN`%9E(%9AN>T@:V]N9FEG=7)A8VD@;F5B>6QA(&YA;&5Z96YA('9E
M<GIE+B!/8FYO=G1E(&MO;F9I9W5R86-I+@"NX61N_0"NX61N_2`H<&]UOFEJ
M=&4@:6UP;&EC:71N[2D`4V5V97)S:_T@*$E33RTX.#4Y+3$P*0!.;W)F;VQK
M<VOI(&]S=')O=GD`4V5V97)N[2!P;VQO:V]U;&4`4V5V97)N[2!-87)IX6YS
M:^D@;W-T<F]V>0!.;W)S:V\`3F5N[2!P;P!.96[M('#X960`3F5N[2!A9')E
M<^'X96T`3F5N[2!I;7!L96UE;G1O=N%N;RX`3F5N[2!N87-T879E;F\`3F5N
M[2!P;V1P;W)O=N%N;RX`4&]Z;N%M:V$`3FEC(&L@<')O:&SI9&YU=.TL(&+L
MOG1E('IP['0N`$QI<W1O<&%D`,CM<VQO`%!OZ&5T('IN86OY`%!OZ&5T('-L
M;W5P8_D`4&_H970@^.%D:_D`3F5B>6QA('IA9.%N82#H[7-L82!P<F\@86MT
M=6%L:7IA8VD@9&ES=')I8G7H;NUH;R!S97IN86UU+@!/2P!/8FIE:W0`5';Y
M<F-E(&]B:F5K=/D`3W-M:>AK;W;]`-CM:F5N`$9I;'1R;W9A="!N97-L=;EN
MZ0!+86YC96SA^`!/;>%N`%-D[6QE;ND@<VQOOFMY(&IS;W4@<&]S:WET;W;A
M;GD@<&]U>F4@24U!4"!S97)V97)Y+@!0;W5Z92!N97-L=;ENZ0!*92!P;W9O
M;&5N82!P;W5Z92!J961N82!E+6UA:6QO=N$@861R97-A+@!0;W5Z92!V;&%S
M=&[M:R!N96)O('-Y<W3I;6]V_2!A9&UI;FES='+A=&]R(&WYOF4@;>QN:70@
M<'+A=F$@<')O('-D[6QE;OT@;V)J96MT+@!/=&5V^.UT('8@;F]VZ6T@;VMN
M["X`0VAY8F$@3W!E;E-33#H@3F5L>F4@>NUS:V%T(&1A=&$@>B!P;V1E<'-A
M;ND@Z.%S=&D@4R]-24U%+@!/=&5V^.UT('1E;G1O(&]D:V%Z('8@;F]VZ6T@
M;VMN[`!/<&5R8>AN[2!S>7-TZ6T`36^^;F]S=&D`36^^;F]S=&D@<')O("5S
M`%-E^&%Z96[]('-E>FYA;0!/<F=A;FEZ86-E`$]R9V%N:7IAZ&[M(&IE9&YO
M=&MA`$]R9V%N:7IO=N%N[0!/<FEG:6[A;&[M('9Z;W(@<')O(+[A9&]S=`!/
M<FEG:6[A;&[M('9Z;W(@=B`E<SH`3W-T871N[0!/<W1A=&[M(&EN9F]R;6%C
M90!5OFEV871E;'-KX2!P<N%V80!/=NSX96[M('!O;6]C[2!004T@;F5N[2!D
M;W-T=7!NZ2X`4$=0(&1I9VETX6QN[2!P;V1P:7,`4$=0(+EI9G)O=F%NX2!D
M871A`%9E^&5J;OT@4$=0(&ML[>@`1&%T82!P;V1E<'-A;N$ON6EF<F]V86[A
M('!O;6]C[2!01U``4$A0(&OS9`!02%`@:V]N>F]L80!/9'!O;&5D;NT@;&5H
M:_T@9.FYNP!/9'!O;&5D;NT@</AE:.'R:WD`3V1P;VQE9&[M('-N[+YE;NT`
M3V1P;VQE9&[M('-N[&AO=ND@</AE:.'R:WD`3V1P;VQE9&[M(&)O=?AK>0!0
M7TA0(&MO;GIO;&$`3V1S='5P>0!0X6MI<W3A;@!086QA=0!086QE<W1I;G-K
MZ2!T97)I=&]R:75M+"!O:W5P;W9A;ND`4&%N86UA`%!A<'5A($YO=N$@1W5I
M;F5A`%!A<F%G=6%Y`$WM<W1Y('IA=&&^96YO`$AE<VQO`$YE<W!RX79NZ2!H
M97-L;P!0<F\@;W;L^&5N[2!P;VUO8^T@4D%$54E3(&IE(&YU=&YO('IA9&%T
M(&AE<VQO+@!(97-L;R!S('!O='9R>F5N[6T`2&5S;&\Z`$AE<VQO.B``2&5S
M;&$@<V4@;75S[2!S:&]D;W9A="X`5FQOOFET`%9L;[YI="!Z92!S8VARX6YK
M>0!#97-T80"NX61O<W1I(&\@</AI:&SAN65N[3H`3&EDZ0!0<F]C96YT`%!R
M;W;I<W0@;W!E<F%C92#Z9'*^8GD`4')O=NES="!O<&5R86-E(/ID<KYB>2!P
M^&D@</AI:&SAN65N[2!D;R!S>7-TZ6UU/P!0<N%V80!!9&UI;FES=')AZ&[M
M('!RX79A`$]S;V)N[2!I;F9O<FUA8V4`4&5R=0!$;VWA8^T@>G;M^&%T80!&
M:6QI<.UN>0!496QE9F]N`$9O=&]G<F%F:64`4&ET8V%I<FX`4&EX96SY`$9R
MX7IE`%!R;W/M;2!K;&EK;NQT92!N82!N[&IA:V]U(&)U\FMU`%!R;W/M;2!P
M;W1V<N]T92P@OF4@<VD@</AE:F5T92!O9'-T<F%N:70@=&5N=&\@<')V96LZ
M`%!R;W/M;2!P;W1V<N]T92P@OF4@<VD@</AE:F5T92!O9'-T<F%N:70@=&5N
M=&\@<')V96LN`%!R;W/M;2!Z861E:G1E(&WL<^UC(&$@<F]K+@!0<F]S[6T@
M>F%D96IT92!NX7IE=B!N;W;I(&MA=&5G;W)I93H`4')O<^UM('IA9&5J=&4@
M<W!RX79N;W4@25`@861R97-U+BX`4')O<^UM('IA9&5J=&4@<W!RX79N_2!D
M871U;2!A('IK;VYT<F]L=6IT92!P;^AE="!D;NT@=B!M['/M8VDN`%!R;W/M
M;2!Z861E:G1E('-P<N%V;OT@Z&%S+@!0<F]S[6T@=79E[W1E('-H<FYU=.T@
M5F&Y96AO('!R;V)LZ6UU+@!0<F]S[6T@>F%D96IT92!68;EE('6^:79A=&5L
M<VOI(&IMZ6YO(&$@:&5S;&\`4')O<^UM('IA9&5J=&4@;F]V_2!NX7IE=B!K
M871E9V]R:64Z`%!O;'-K;P!0;VQI=&EK80!(;&%S;W;A;NT`4&]R='5G86QS
M:V\`56WM<W3L;NT@=&]H;W1O(&]B<N%Z:W4`56WM<W3L;NT@=&%B=6QK>0!:
M87-L870@9&\@=.ET;R!S;&^^:WD@*&YE;NT@<&]S:WET;G5T;R!)34%096TI
M`%-RX;YK>2!Z82!P;W-L961N[2AC:"D@)7,@:&]D:6XH=2DZ(`!0<F5F<U]L
M9&%P.B!.96)Y;&$@;F%L97IE;F$@<&^^861O=F%NX2!P^.UP;VYA($Q$05`N
M`%!R969S7W-E<W-I;VXZ($YE8GEL82!N86QE>F5N82!P;[YA9&]V86[A('#X
M[7!O;F$@<V5K8V4N`$)A<F]M971R:6-K_2!T;&%K`$)A<F]M971R:6-K_2!T
M;&%K(&YA(/IR;W9N:2!M;_AE.B``0F%R;VUE=')I8VO]('1L86LZ`$[A:&QE
M9`!.X6AL960@;V)RX7IK=2!V(&YO=NEM(&]K;NP`4/AE9&-H;WKM(&UOOFYO
M<W1I`%1I<VMN;W5T(&1O:W5M96YT`%!R:7;A=&[M(&ML[>@`4')O8FSI;0!0
M;W!I<R!P<F]B;.EM=0!0<F]J96MT>0!0<F]M<'0@=&5X=`!69?AE:F[](&ML
M[>@`06QG;W)I=&UU<R!P<F\@=F7X96IN_2!K;.WH`%9E^&5J;OTO<')I=N%T
M;NT@:VSMZ&]V_2!PX7(@;F5B>6P@^G-P[+EN["!V>71V;_AE;BX`4&]R=&]R
M:6MO`$MA=&%R`%9Y:&QE9.%N[0!24T$@=F7X96IN_2!K;.WH("@E9"!B:73Y
M*0!3</AAOF5NZ2!T;&'H[71K;P!$Z;F[`$)R>FO](&3IN;L`4&]Z9&[M(&3I
MN;L`1&6YNV]VZ2!P^&5HX?)K>0!$Z;F[('-E('-N[&AE;0!$Z;F[(&&^('-N
M[6@`3N%H;V1N["!V>6)R86[I(+ET['-T[0!0;VWL<@#(=&5C[0!0^&7H=&5N
MZ2!Z<'+A=GD`3W!R879D=2!S;6%Z870@)7,_(%1A=&\@;W!E<F%C92!J92!N
M979R871NX2X`3W!R879D=2!S;6%Z870@=;YI=F%T96QS:^$@9&%T82!P<F\@
M=;YI=F%T96QE("5S/R!4871O(&]P97)A8V4@:F4@;F5V<F%T;N$N`$]P86MO
M=F%T('!O<VQE9&[M(&%K8VD`3V)N;W9I="!D>6YA;6EC:^D@<')V:WD@;65N
M=3H`3V)N;W9A('IO8G)A>F5N[2!P;W)TX6QU.B``4F5G97@`4')O:&SMOF7H
M('9Z=&%H^0!(;V1N;W1Y`%9Z9.%L96[I('-E<G9E<GDN`%9Z9.%L96[A(%52
M3"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`$]D<W1R86YI=`!/
M9'-T<F%N:70@8FQO:P!/9'-T<F%N:70@<VQO=7!E8P!/9'-T<F%N:70@9F]R
M;>%T;W;A;NT`3V1S=')A;FET('#A<@!/9'-T<F%T:70@=6QOOF5N_2!S:W)I
M<'0@>B!D;^AA<V[I:&\@861R97/A^&4@;F$@<V5R=F5R=2X`3V1S=')A;FET
M`$]D<W1R86YI="!T=71O(.CA<W0@9&]K=6UE;G1U`$]D<W1R86YI="!UOFEV
M871E;&4`3V1S=')A;FET('6^:79A=&5L93H@)7,`3F5L>F4@;V1P;W;L9.QT
M(&YA('!OOF%D879E:RX@0VAY8F]VZ2!H;.&Y96[M.B``4&^^861O=F%NZ2!P
M;VQE`%;]8VAO>NT@;F%S=&%V96[M`%;]8VAO>NT@;F%S=&%V96[M(&AE<VQA
M`%;]8VAO>NT@;F%S=&%V96[M(%9AN65H;R!H97-L80!6_7-L961K>0!.X79R
M870@9&\@;6^^;F]S=.T`4F5U;FEO;@!0^&5P;F]U="!K;VYF:6=U<F%C:0!-
M;[YN;W-T:2!2:6-H(%1E>'0@961I=&]R=0!(X61A;FMY`$1O<')A=F$`2&QA
M=FGH:V$@;F%P<F%V;P!(;V1N;W1Y(&YA<')A=F\`5FQA<W1N;W-T:2#XX5]D
M:W4`VFQO:&$`4G5M=6YS:V\`3W1OZ&ET(&\@,3@PL`!/=&_H:70@9&]L979A
M`$]T;^AI="!D;W!R879A`%9L87-T;F]S=&D@^.%D:W4`5FQA<W1N;W-T:2#X
MX61K=0#8X61K>3H`4')A=FED;&$`4')A=FED;&$@<V4@=7!L871N[2!M97II
M(':Y96UI(/CA9&MY(&$@<VQO=7!C:0!0<F%V:61L82!S92!U<&QA=&[M('!O
M=7IE(&UE>FD@<VQO=7!C:0!0<F%V:61L82!S92!U<&QA=&[M('!O=7IE(&UE
M>FD@^.%D:WD`4')O=NES=`!2=7-KX2!F961E<F%C90!2=V%N9&$`4R]-24U%
M(+EI9G)O=F%N_2!P;V1P:7,`4R]-24U%(+EI9G)O=F%NX2!Z<'+A=F$`3W;L
M^&5N[2!P;VUO8^T@4T%33"!N96[M(&1O<W1U<&[I+@!335,@>G!RX79Y`%-1
M3"!K;VYZ;VQA`%-32`#:4U#,0T@`4U]13"!K;VYZ;VQA`%-O`%-V873A($AE
M;&5N80!3=F%T_2!+:71T<R!A($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I
M97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA
M9&EN97,`4W1E:F[]('+A;2`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O
M(%1O;64@86YD(%!R:6YC:7!E`%9L87-T;NUK('-A=&5L:71U`%-A=61S:^$@
M07+A8FEE`%5L;[YI=`!5;&^^:70@)7,`56QOOF5N[2!M;[YN;W-T[0!5;&^^
M:70@=GET=F_X96[](&MO;F9I9W5R8>AN[2!02%`@<VMR:7!T(&1O(&1OZ&%S
M;NEH;R!A9')E<^'X92!N82!S97)V97)U+@!+;VYF:6=U<F%C92`E<R!U;&^^
M96YA+@!6[&1A`%9Y:&QE9&%T`%9Y:&QE9.%V86/M(&[A<W1R;VIE`%9Y8G)A
M="!S;W5B;W)Y`%9Y8G)A="!D871U;0!6>6)R870@<VMU<&EN=2P@:W1E<N$@
M8G5D92!P^&EDX6YA`%9Y8G)A="!N;W;I:&\@=FQA<W1N[6MA`%9Y8G)A="!S
M97)V97(`5GEB<F%T('6^:79A=&5L92P@:W1E<OT@8G5D92!P^&EDX6X`5GEB
M<F%T(':Y96-H;GD@Z.%S=&D@9&%T=6UU+@!6>6)R870@;V)J96MT`%9Y8F5R
M=&4@<&]T^&5B;ND@>FYA:WD@>B!N[;YE('5V961E;OUC:"!B;WCY+B!0;W3I
M(&IE(&WYOF5T92!K;W#M<F]V870@82!V;&^^:70@>B!T97AT;W;I(&]B;&%S
M=&DN`%9Y8F5R=&4@;V1D[&QO=F%C[2!Z;F%K('!R;R!D871U;3H`5GEB97)T
M92!F;W)MX70@9&%T=6UU.@!6>6)E<G1E(&ED96YT:71U+"!K=&5R;W4@<VD@
M</AE:F5T92!Z;>QN:70Z`%9Y8F5R=&4@;V1D[&QO=F%C[2!Z;F%K('!R;R#H
M87,Z`%9Y8F5R=&4@9F]R;>%T(.AA<W4Z`%9Y8F5R=&4@9';L(&]D<&]V[61A
M:NUC[2!P;VQE+@!6>6)E<G1E(&)A<F5V;OT@;6]T:78N`%9Y8F5R=&4@5N%M
M:2!P<F5F97)O=F%N_2!J87IY:SH`4&]S;&%T('IP<N%V=2!O('!R;V)LZ6UU
M`%!O<VQA="!335,`4V5N96=A;`!396YS;W(Z`%KA^.T`4W)B<VMO(&$@R&5R
M;N$@2&]R80!3Z7)I;W;I(.CM<VQO`$E$('-E:V-E('IA;FEK;&\N`$YA<W1A
M=FET`$YA<W1A=FET(&UOOFYO<W1I('!R;R!P;W9O;&5N[2!R97-E='4@:&5S
M;&$L('!O:W5D(&AO('IA<&]M96YE=&4N`$YA<W1A=FET('9Z9.%L96[I('-E
M<G9E<GD@=&%K+""^92!B=61O=2!P^.US='5P;ND@>B!P;W)TX6QU+@!.87-T
M879E;NT@5N%M:2!P<F5F97)O=F%NZ6AO(&IA>GEK82P@Z&%S;W;I:&\@<.%S
M;6$@82!T>7!U(&1A='5M=2X`3F%S=&%V96[M('!OZ.%T9>AN[2!A<&QI:V%C
M92P@8F%R979NZ6AO(&UO=&EV=2P@;V)N;W9O=N%N[2!S='+A;F5K(&$@9&%L
MN>UC:"!M;[YN;W-T[2!Z;V)R87IE;NTN`$YA<W1A=F5N[0!.87-T879O=F%C
M[2!K;VYF:6=U<F'H;NT@<VMR:7!T>2!P<F\@86MT=6%L:7IA8VD@:G-O=2!D
M;W-T=7!NZ0!.[&MT97+A(&WM<W1A(&QZ92!N87-T879I="!S('3M;71O('!A
M<F%M971R96TZ(`!397EC:&5L;&5S`$YA:W5P;W;A;NT`2W+A=&OI('-H<FYU
M=.T`3>QL>2!B>2!B_70@</CM<W1U<&]VZ2!K;.WH92!D969I;F]VX6YY('!R
M;R!V['2Y:6YU(&]D:V%Z^3\`6F]B<F%Z:70`6F]B<F%Z:70@<F]Z9.UL>2!M
M97II('-O=>AA<VYO=2!A('#X961C:&]Z[2!K;VYF:6=U<F%C[2X`6F]B<F%Z
M:70@Z&%S('!O<VQE9&[M:&\@</AI:&SAN65N[2!D;R!S>7-TZ6UU/P!:;V)R
M87II="!M;[YN;W-T('5D<KYE;NT@;W)I9VENX6QU`%IO8G)A>FET('-B[')A
MZ`!:;V)R87II="!M96YU(&]P97)AZ&[M(&QIN71U('!R;R!T86)U;&MY/P!:
M;V)R87II="`E<R!M96YU(&YA;&5V;S\`6F]B<F%Z:70@9&EA;&]G('!R;R!V
M;&%S=&YO<W1I(&)U;NQK('8@=&%B=6QKX6-H`%IO8G)A>FET(&1I86QO9R!V
M;&%S=&YO<W3M('1A8G5L96L`6F]B<F%Z:70@9&EA;&]G('9L87-T;F]S=.T@
M^.%D96L@=&%B=6QE:P!:;V)R87II="!D:6%L;V<@=FQA<W1N;W-T[2!O8G+A
M>FOY`%IO8G)A>FET('#X96YO<P!0^&5HX?)K>0!"<GIKZ2!P^&5HX?)K>0!0
M;WID;NT@</AE:.'R:WD`4/AE:.'R:WD@=B!O:V]L[0!:;65NN6ET`%IM96ZY
M:70@;F5B;R!P;W-U;F]U="!D;R!S;W5S961N[6AO(&)L;VMU*/DI+"!Z(&-E
M<W1Y('!R=F[M;74`4VEE<G)A($QE;VYE`%)E9VES=')O=F%T('-E`%!O9'!I
M<P!!;&=O<FET;75S('!R;R!P;V1P:7,`4VEN9V%P=7(`5F5L:6MO<W0`5GEN
M96-H870@^F1ROF)U`%-L;W9E;G-K;P!3;&]V:6YS:V\`4V[LOF5N[0!3;NQH
M;W;A('#X96CA\FMA`%-N[&AO=ND@</AE:.'R:WD`4F%N;NT@<V[L:&]VZ2!P
M^&5HX?)K>0!0;WID;NT@<V[L:&]VZ2!P^&5HX?)K>0!3;NQH;W;A('!O:W+]
M=FMA.@!6;V1N[2!E:W9I=F%L96YT('!R;R!S;NUH.B``J6%L86UO=6YO=GD@
M;W-T<F]V>0!3;VWA;'-K;P!0[7-N["!A(&+A<V[L`%-M['(@=/CM9.QN[0!:
M9')O:F]VX2!A9')E<V$`2FF^;NT@069R:6MA`$II:&]E=G)O<'-K_2`H25-/
M+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H
M($ES;&%N9',`2FF^;NT@<&]L;VMO=6QE`%!R;W-T;W(@;65Z:2!S;W5S961N
M[6UI(&)U\FMA;6D`4')O<W1O<B!M97II(&]B<V%H96T@82!H<F%N:6-E;6D@
M=B!B=?)C90!-97IE<F[M:P!-97IE<GD`3V1S='5P>2!A(&UE>F5R>0"I<&%N
M[&QS:V\`4W!A;0!6<W1U<"!P<F\@>G9LX;ET;NT@>FYA:WD`4F]Z9.QL:70@
M8G7R:W4`4F]Z9.QL:70@<VQO=7!E8P!2;WID[&QI="#XX61E:P!3<&]R=`!3
M<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K`%)O:R!Z8>CA=&MU`%-TX70@
MZ&D@<')O=FEN8VEE`%-T878`1F]R;>%T('5L;[YE;NT`56QI8V4`4/AEN6MR
M=&YU=/T`4V5Z;F%M(/AE=.QZ8V4`3V1S=')A;FET(&1O;>EN;W;I(&IMZ6YO
M('H@861R97-Y`%-T>6P@6T-34UT`3F4`4/AE9&WL=`!0;V1A=`!$;VQN[2!I
M;F1E>`#:<W#LN6[L`$MO;F9I9W5R86-E(&)Y;&$@^G-P[+EN["!Z;>QN[&YA
M+B!/8FYO=G1E('-T<N%N:W4N`-IS<.RY;ND@=6QOOF5N[2!ZX6QOOF[M(&MO
M;F9I9W5R86-E+@#:<W#LN6[I('5L;[YE;NT@>N%L;VAY(&MO;F9I9W5R8>AN
M[6AO('-O=6)O<G4@)7,N`"5S(&)Y;&\@^G-P[+EN["!Z87!SX6YO`%-U9.%N
M`%-H<FYU=.T`4W;M=.%N[0!:X7!A9"!3;'5N8V4`4VQU;F7H;F\`5OUC:&]D
M(%-L=6YC90!6_6-H;V0O>N%P860@4VQU;F-E`%;]8VAO9"!3;'5N8V4Z(`!:
MX7!A9"!3;'5N8V4`6N%P860@4VQU;F-E.B``2&]R;NT@:6YD97@`4&]D<&]R
M80!3=7)I;F%M90!0^.UJ;65N[0!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W
M87II;'-K;P"I=NED<VMO`*EV_6-A<G-K;P!3>6YT87AO=N$@8VAY8F$@=B!H
M;&5D86[I;2!T97AT=0!3_7)I90!";W7X:V$`0F]U^&MY`%135B!S;W5B;W(`
M5&%B=6QK80!6;&%S=&YO<W1I('1A8G5L:WD`5FQA<W1N;W-T:2!T86)U;&MY
M`%1A:7=A;@!486EW86XL('!R;W9I;F-I92#([6YY`%1A9+YI:VES=.%N`%1A
M;GKA;FEE+"!3<&]J96[A(')E<'5B;&EK80!#[6PZ`-IK;VQY`%1E;&5F;VYN
M[2#H[7-L;P!497!L;W1A('IA('!O<VQE9&[M(&AO9&EN=3H@`%1E<&QO=&$`
M5&5P;&]T83H@`%9Z;W(@<')O(&%D;6EN:7-T<F%C:0!497AT`%!O=7IE('1E
M>'0`6F%R;W9NX6[M('1E>'1U`%9R8V@@=&5X='4`R'0`5&AA:G-K>2`H5$E3
M+38R,"D`5&AA:G-K;P!$[&MU:F5M92!Z82!P;W6^[7;A;NT@<WES=.EM=2X`
M4/CM<&]N82!P<F\@1E10(&YE;NT@9&]S='5P;N$N`$EN=&5G<F'H;NT@86QG
M;W)I=&UY('8@2&]R9&4O2V]L86(@;F5P;V1P;W)U:NT@(B5S(@!.9?IS<.RY
M;ND@;F'H=&5N[2!T^.UD>2!-86EN=&5N86YC93HZ`$)Y;&\@=7IA=OAE;F\@
M;VMN;R!S(&UOOFYO<W1M:2X@56MO;NAE;F\N`$%D;6EN:7-T<NUT;W(@<&]T
M^&5B=6IE(&YA:V]N9FEG=7)O=F%T('1R=F%LX2!P<N%V82!V('-Y<W3I;74L
M('!O:W5D('-I('#X96IE=&4@<&]UONUT('!RX79A+@!0;W5Z92!S<&]D;NT@
M<W1R86YA`$YE8GEL;R!U=F5D96YO($E$('!R;R!K;VYT86MT+"!N96)Y;&\@
M;F%L97IE;F\@=B!D871A8N%Z:2!N96)O(&)Y;&\@^G!L;NP@=GEN96-HX6YO
M+@!+;VYT86MT(&)Y;"#Z<W#LN6[L('#X:63A;B!D;R!68;EE:&\@861R97/A
M^&4N`$L@;W;L^&5N[2!P;V1E<'-A;ND@>G!RX79Y(&IE('3X96)A(&]D9.QL
M96[](&)L;VL@<R!01U`@<&]D<&ES96TN`$YE8GEL;R!U=F5D96YO($E$(&1I
M<W1R:6)UZ&[M:&\@<V5Z;F%M=2P@;F5B>6QO(&YA;&5Z96YO('8@9&%T86+A
M>FD@;F5B;R!B>6QO(/IP;&[L('9Y;F5C:.%N;RX`3F5B>6P@=79E9&5N(&1I
M<W1R:6)UZ&[M('-E>FYA;2X`J6EF<F]V86/M(&UOOFYO<W1I(&QZ92!V>76^
M[70@<&]U>F4@</AI(&)E>G!EZ&[I;2!S<&]J96[M(',@=V5B96T@*&AT='!S
M*2X`4V]U8F]R("5S(&)Y(&WL;"!O8G-A:&]V870@;F%S=&%V96[M("5S+@!3
M;W5B;W(@)7,@8GD@;>QL(&]B<V%H;W9A="!N[&MT97+A('H@;F%S=&%V96[M
M("5S+@!3;W5B;W(@;F5L>F4@:V]P[7)O=F%T('/A;2!D;R!S96)E+@!3;W5B
M;W(@;F5O8G-A:'5J92"^X61NX2!D871A+@!.X7-L961U:NT@:&QA=FGH:WD@
M<')O(&UE<W-A9V4O<F9C.#(R('IP<N%V=0!*92!Z;N%MZ2P@OF4@;?-D('#X
M97,@8V5L;W4@;V)R87IO=FMU('8@26YT97)N970@17AP;&]R97)U('#Y<V]B
M[2!P<F]B;.EM>2P@<')O=&^^92!S92!V(&[L;2!V>7-K>71U:F4@8VAY8F$L
M(&MT97+I('-E(&YE;'IE('9Y:&YO=70N($IA:V\@;N%S;&5D96L@;?F^92!B
M_70@;N%H;V1NZ2!Z:')O=6-E;NT@=&]H;W1O('!R;V=R86UU+"!C:'EB[&KM
M8^T@9G5N:V-E(&5D:71O<G4@;F5B;R!N97-P<N%V;ND@>F]B<F%Z;W;A;NTN
M(%!O:W5D(&IE(%;AN2!S>7-T96WI;2!7:6YO9'=S(#EX+"!J92!V96QM:2!P
M<F%V9.QP;V1O8F[I+""^92!S92!O8FIE=NT@8VAY8F]VZ2!H;.&Y96[M("='
M96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&$@8G5D971E(&UU<V5T(')E<W1A
M<G1O=F%T('!OZ.UT8>@N7&Y<;D)Y;&D@:G-T92!V87)O=N%N:2X@4')O<^UM
M('-T:7-K;NQT92!/2R!P;VMU9"!S:2!P^&5J971E('!O:W)AZ&]V870@=B!M
M\V1U('#X97,@8V5L;W4@;V)R87IO=FMU+@!)9&5N=&ET82`B)7,B(&)Y;&$@
M<VUA>N%N82X`4&]U>F4@;F$@;&5VZ2!S=')A;NP`56WM<W3L;NT@8FENX7)N
M[6AO('-O=6)O<G4@1VYU4$<@;75S[2!B_70@>F%DX6YO(&1O('3X[61Y($-R
M>7!T7W!G<#HZ+@!:<'+A=F$@>F%S;&%NX2!V("5S(&L@)7,@<R!P^&5D;>QT
M96T@(B5S(B!B>6QA('IO8G)A>F5N82X*5&]T;R!N97IA<G7H=6IE+""^92!Z
M<'+A=F$@8GEL82!P^&7H=&5N82!N96)O(+YE(&KM(&%D<F5SX70H:V$I(')O
M>G5M[&PH82DN`$[A>F5V+"!K=&5R_2!B=61E('!O=;YI="!P^&D@;V1K87IO
M=N%N[2!N82!S='+A;F-E('1V;W)B>2!Z<'+A=@!4^.UD82!(;W)D95]#<GEP
M=%]S;6EM93HZ('9YOF%D=6IE(&UO9'5L(&]P96YS<VPN`$YE;'IE('5L;[YI
M="!N87-T879E;NT@(B5S(BP@<')O=&^^92!J96AO('9E;&EK;W-T('#X97/A
M:&QA('!O=F]L96[](&QI;6ET+@!.96)Y;&$@;F%L97IE;F$@87!L:6MA8V4@
M<')O(.AT96[M('1O:&]T;R!T>7!U(&1A="`H)7,I+@!0;W5Z92!N82!P<F%V
MZ2!A(&QE=ND@<W1R86[L`%!O=7IE(&YA('!R87;I('-T<F%N[`!397)V97(@
M(B5S(B!B>6P@=GEM87KA;BX`4V5R=F5R("(E<R(@8GEL('5L;[YE;BX`0GEL
M82!O9'-T<F%N[&YA(+[A9&]S="!O('#X:6ALX;EE;NT@<')O("5S+@!0;[YA
M9&]V86[](/CA9&5K(&YE97AI<W1U:F4N`$1OZ&%S;OT@<V]U8F]R("(E<R(@
M;F5E>&ES='5J92X`4&]U>F4@;F%H;_AE(&$@9&]L90!0;W5Z92!N86AO^&4`
M6G1R871I;&$@<V4@</AE;F5S96[A(&1A=&$@>B!P^&5D8VAO>NUH;R!K<F]K
M=2X`4/AE;F5S96[]('-O=6)O<B!N96QZ92!U;&^^:70N`$)L;VL@=V5A=&AE
M<BYC;VT@;F5N[2!D;W-T=7!N_2X`KN%D;ND@>B!M;[YN;W-T[2!N96IS;W4@
M9&]S='5P;NDN`$YE8GEL>2!N86QE>F5N>2"^X61NZ2#HX7-T:2P@:W1E<ND@
M8GD@8GEL;R!M;[YN;R!Z;V)R87II="!V(/CA9&MU+@!0^.UL:;D@;6YO:&\@
M>FYA:_D@=B!P;VQI+B!:861A;&D@:G-T92`E<R!Z;F%K^3L@;75S[71E('IA
M9&%T(&WI;NP@;F6^("5S('IN86OY+@!.87-T86QA(&-H>6)A('#X:2!P^&5N
M;W-U('-O=6)O<G4Z("5S(&YE8GEL('#X96YE<V5N+@!.87-T86QA(&-H>6)A
M('#X:2!P^&5N;W-U('-O=6)O<G4N("5S(&YE;?F^92!B_70@=NQTN>T@;F6^
M(&UA>&EMX6QN[2!P;W9O;&5NX2!V96QI:V]S="`H)60@8GET^2DN`$YA<W1A
M;&$@8VAY8F$@</AI('#X96YO<W4@<V]U8F]R=3H@8GEL82!P^&5N97-E;F$@
M:F5N(.CA<W0@<V]U8F]R=2`E<RX`1&^Y;&\@:R!C:'EB["!P^&D@>F]B<F%Z
M;W;A;NT@=.ET;R#HX7-T:2!Z<'+A=GD`3F%S=&%L82!C:'EB82!P^&D@:6UP
M;W)T;W;A;NT@:V]N=&%K='4N`%#X:2!I;7!O<G1O=N%N[2!I0V%L96YD87(@
M9&%T(&1ON6QO(&L@8VAY8NPN`$-H>6)A('8@:V]N9FEG=7)AZ&[M;2!F;W)M
M=6SA^&DN(%KX96IM["!J<W1E('9Y;F5C:&%L:2!P;[YA9&]V86[I('!O;&4N
M`$YA<W1A;&$@8VAY8F$@</AI('!R;W;A9.QN[2!Z861A;ND@;W!E<F%C92!V
M(&%D<F5SX?AI+B!0<F]S[6T@>FMU<W1E('1O('!O>F3L:FDN`$YA<W1A;&$@
M8VAY8F$@</AI(&%K='5A;&EZ86-I(&MO;G1A:W1U+B!0<F]S[6T@>FMU<W1E
M('1O('!O>F3L:FDN`$YA<W1A;&$@8VAY8F$@</AI(&%K='5A;&EZ86-I(&1I
M<W1R:6)UZ&[M:&\@<V5Z;F%M=2X@4')O<^UM('IK=7-T92!T;R!P;WID[&II
M+@!496YT;R!)34%0('-E<G9E<B!N97!O9'!O<G5J92!S9.UL96[M('-L;[YE
M:RX`5&]T;R!N979Y<&%DX2!J86MO('!L871N_2!R87(@87)C:&EV+@!4;W1O
M(&YE=GEP863A(&IA:V\@<&QA=&[]('II<"!S;W5B;W(N`%1O=&\@;F5V>7!A
M9.$@:F%K;R!P;&%T;ND@Z.US;&\@:V%R='DN`%1E;G1O(&]V;&%D8>@@=6UO
MOO)U:F4@<&]S[6SA;NT@>G!RX78@<&]M;V/M($-L:6-K871E;&P@*&AT='`Z
M+R]C;&EC:V%T96QL+F-O;2D@8G+A;GD@</AI('!O=;YI=.T@2%144"!!4$D`
M5&5N=&\@;W9L861AZ"!U;6^^\G5J92!P;W/M;.%N[2!Z<'+A=B!P;VUO8^T@
M<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@8G+A;GD@</AI('!O
M=;YI=.T@2%144"!!4$D`5&5N=&\@;W9L861AZ"!U;6^^\G5J92!P;W/M;.%N
M[2!Z<'+A=B!P;VUO8^T@4TU44"!D;R!6;V1A9F]N92!)=&%L>2!B<N%N>2!P
M;W5Z92!P<F\@Z.US;&$@<&]S:WET;G5TZ2!6;V1A9F]N96TN($UU<^UT92!M
M[70@96UA:6QO=OT@^NAE="!U(%9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W
M+C$Y,"YI="DN`%1O=&\@<&]L92!J92!N=71NZ2!V>7!L;FET+@!4;W1O('!O
M;&4@;?F^92!O8G-A:&]V870@<&]U>F4@8V5LX2#H[7-L82X`5&]T;R!P;VQE
M(&WYOF4@;V)S86AO=F%T('!O=7IE(&-E;.$@Z.US;&$@82!D=F]J=&7H:W4N
M`%1O=&\@<&]L92!M^;YE(&]B<V%H;W9A="!P;W5Z92!O<VUIZ&MO=ND@Z.US
M;&$N`%1O=&\@<&]L92!M=7/M(&+]="!S97IN86T@8V5L_6-H(.CM<V5L(&]D
M9.QL96[]8V@@Z.%R:V]U(&YE8F\@;65Z97)O=0!4;W1O('!O;&4@;75S[2!B
M_70@<&QA=&[I(.CM<VQO+@!4;W1O('!O;&4@;75S[2!P8G-A:&]V870@8F%R
M979N_2!K\V0@=B"Y97-T;N%C:V]VZ6T@4D="(&9O<FWA='4L(&YA</@N("<C
M,3(S-&%F)RX`5&5N=&\@9F]R;75LX?@@:FF^(&)Y;"!Z<')A8V]VX6XN`%1O
M=&\@:F4@)7,N`%1O=&\@:F4@;V)J96MT($MO;&%B($=R;W5P=V%R=2X@2R!Z
M:&SI9&YU=.T@=&]H;W1O(&]B:F5K='4@:F4@>F%P;W3X96+M(&WM="!P;[ET
M;W9N[6AO(&ML:65N=&$L(&MT97+](')O>G5M[2!F;W)MX71U($MO;&%B($=R
M;W5P=V%R=2X@4')O('-E>FYA;2!T86MO=OUC:"!K;&EE;G3Y('!R;W/M;2!N
M87:Y=&EV=&4@)7,`5&%T;R!Z<'+A=F$@8GEL82!N87!SX6YA('8@:FENZ2!Z
M;F%K;W;I('-A9.P@*"5S*2!N9;X@5F&Y[2X@`%1O=&\@Z.US;&\@;75S[2!B
M_70@;F5J;>EN["!J961N82X`4V5R=F5R(&YE;?F^92!R;WIB86QI="!Z:7`@
M82!G>FEP('-O=6)O<GDN`%1E;G1O('-Y<W3I;2!J92!V('-O=>AA<VYO<W1I
M(&1E86MT:79O=F%N_2X`5&%T;R!H;V1N;W1A(&UU<^T@8OUT(.CM<VQO+@!4
M;W1O(&]K;F\@;76^92!B_70@=F]LX6YO('!O=7IE('H@;VMN82!M;[YN;W-T
M[0!(^&WL;NT`3.US=&MY`,AA<P!3;&5D;W;A;NT@Z&%S=0!&;W)MX70@Z&%S
M=0!6_6+L<B#H87-U`%1I;6]R+4QE<W1E`%1I='5L`%1I='5L("AT:7`I.@!+
M;VUU`%!O:W5D('-I('#X96IE=&4@=GEB<F%T(';M8V4@<&]L;[YE:RP@>FWA
MZ&MN['1E(&MLX79E<W4@0V]N=')O;"`H4$,I(&YE8F\@0V]M;6%N9"`H36%C
M*2!A(&ML:6MN['1E(&YA('!O;&^^:W4N`$1N97,`4/AE<&YO=70@;F$@2%1-
M3"!Z9')O:@!4;V=O`%1O:V5L874`6NUT<F$`5&]N9V$`5G)C:`!(;W)N[2!R
MX6T@*%]T;W`I`%#X96ML861Y`%1R:6YI9&%D(&$@5&]B86=O`%-P<N%V;NP@
M;F5B;R"Y<&%T;NP`VG0`5'5N:7-K;P!4=7)E8VMO`%1U<F5C:WD@*$E33RTX
M.#4Y+3DI`%1U<FMM96YI<W3A;@!4=7)K<R!A($-A:6-O<R!O<W1R;W9Y`%1U
M=F%L=0!.87!IN71E(%9AN6D@=F]L8G4Z`%4N5BX@:6YD97@Z(`!54DP`55),
M('!R;R!Z<'+A=G4@;R!S=&%V=2!Z87-L86[I:&\@<VMR:7!T=0!54DPZ`%5G
M86YD80!5:W)A:FEN80!61E,@861R97/A^"!J92!N97#X[7-T=7!N_2X`4/AI
M(')E9VES=')A8VD@;F5L>F4@</AI9&%T(&5X=')A('6^:79A=&5L<VOI(/ID
M86IE+@!.96QZ92!Z;>QN:70@<'+A=F$@<')O(%9&4R!S;W5B;W(@(B5S(BX`
M3F5L>F4@>FWL;FET('!RX79A('!R;R!61E,@<V]U8F]R("5S+R5S+@!.96QZ
M92!Z;>QN:70@;F$@)7,N`$YE;'IE('-E('#X:7!O:FET(&L@4U%,('-E<G9E
M<G4N`$YE;'IE('-E('#X:7!O:FET('!O;6]C[2!34TPN`$YE;'IE(&MO<.UR
M;W9A="!61E,@<V]U8F]R+@!.96QZ92!V>71V;_AI="!61E,@861R97/A^"`B
M)7,B+@!.96QZ92!V>71V;_AI="!61E,@861R97/A^"X`3F5L>F4@=GET=F_X
M:70@5D93('-O=6)O<BX`3F5L>F4@=GET=F_X:70@<'+A>F1N_2!61E,@<V]U
M8F]R+@!.96QZ92!R;WIB86QI="!D871A+@!.96QZ92!V>6UA>F%T("(E<R(L
M('!R;W1OOF4@861R97/A^"!N96[M('!RX7ID;OTN`$YE;'IE('9Y;6%Z870@
M)7,L('!R;W1OOF4@861R97/A^"!N96[M('!RX7ID;OTN`$YE;'IE(')E:W5R
M>FEV["!O9'-T<F%N:70@5D93(&%D<F5SX?@N`$YE;'IE('9Y;6%Z870@5D93
M(&%D<F5SX?@N`$YE;'IE('9Y;6%Z870@5D93(&%D<F5SX?@Z("5S+@!.96QZ
M92!V>6UA>F%T(%9&4R!S;W5B;W(@(B5S(BX`3F5L>F4@=GEM87IA="!61E,@
M<V]U8F]R+@!.96QZ92!R96MU<GII=F[L(&]D<W1R86YI="!61E,Z("5S+@!.
M96QZ92!U<NAI="!A:W1UX6QN[2!A9')E<^'X+@!.96QZ92!Z:FES=&ET('!O
M9')O8FYO<W1I(&\@8V5R=&EF:6OA='4N`$1E9FEN:6-E("5S(&YE;NT@9&]S
M='5P;N$N`$YE;'IE('#X97-U;F]U="!61E,@<V]U8F]R+@!.96QZ92!P^&5S
M=6YO=70@5D93('-O=6)O<B`B)7,B+@!61E,@<V]U8F]R(&YE;'IE(&]T97;X
M[70@<')O('KA<&ES+@!.96QZ92!O=&5V^.UT(%9&4R!S;W5B;W(N`$YE;'IE
M(&]T97;X[70@87)C:&EV;W9A;OT@<V]U8F]R+@!.96QZ92#H[7-T('H@=F9S
M<F]O="!A9')E<^'X92X`3F5L>F4@</AE:FUE;F]V870@)7,@;F$@)7,Z(&/M
M;&]VX2!S;&^^:V$@:FF^(&5X:7-T=6IE`%9&4R!A9')E<^'X(&YE;'IE('#X
M96IM96YO=F%T+@!61E,@861R97/A^"!N96QZ92!P^&5J;65N;W9A=#H@)7,N
M`$YE;'IE('#X96IM96YO=F%T(%9&4R!S;W5B;W(@(B5S(BX`3F5L>F4@</AE
M:FUE;F]V870@5D93('-O=6)O<B`E<R\E<RX`3F5L>F4@</AE:FUE;F]V870@
M5D93('-O=6)O<BX`3F5L>F4@<')O=NES="`G;6MI<V]F<R<N`%1E;G1O(&1O
M:W5M96YT(%=O<F0@;F5L>F4@</AE;&^^:70`3F5L>F4@>F%P<V%T(&1O(%9&
M4R!S;W5B;W)U("(E<R(N`$YE;'IE('IA<'-A="!D871A(&1O(%9&4R!S;W5B
M;W)U("AS96QH86QO(&-O<'DH*2DN`$YE;'IE('IA<'-A="!D871A(&1O(%9&
M4R!S;W5B;W)U`%!O9'1R:&YU=.D`4W1O<FYO('IM[&X`4W1O<FYO=F%T('!O
M<VQE;NT@86MC:0!.96_H96OA=F%NX2!O9'!O=NSO('-E<G9E<G4@;F$@<W!O
M:F5N[3H@`$YE;^AE:^%V86[A(&]D<&]V[.\@<V5R=F5R=3H@`$YE=GEP;&[L
M;F\`56YI8V]D92`H551&+3@I`%-P;VIE;ND@07)A8G-KZ2!%;6ERX71Y`%9E
M;&OA($)R:73A;FEE`%-P;VIE;ND@4W3A='D@06UE<FEC:^D`4W!O:F5NZ2!3
M=.%T>2!-96ZY:6YO=OUC:"!O<W1R;W;Y`$IE9&YO=&MY`$YE>F[A;>D`3F5Z
M;N%MZ2!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!.97INX6WI(&-L:6US
M9VED("A#;&EE;G0@365S<V%G92!)1"DN`$YE>F[A;>D@=;YI=F%T96QS:^D@
M:FWI;F\@;F5B;R!H97-L;RX`3V1P;VII="!S;W7H87-N_2!P<G9E:P!"97IE
M(&IMZ6YA`$YE<')I=FEL96=O=F%NZ2!S:W)I<'1Y(&YE;6]H;W4@=GEUONUV
M870@9G5N:V-A(%9Y:FUO=70O2V]P[7)O=F%T+U9L;[X@>B!B97IP9>AN;W-T
M;NUC:"!D^79O9/DN($ML:6MN['1E(&YA($]+(&%B>7-T92!V:63L;&D@=&5C
M:&YI8VMO=2!Z<'+A=G4@>B!M;WII;&QA+F]R9RP@:W1E<N$@=GES=NQT;'5J
M92P@:F%K(&YA<W1A=FET('-K<FEP="!P<F\@</CM<W1U<"!K92!S8VARX6YC
M92X`3F5N87-T879E;N$@8F%R=F$`3F5P;V1P;W)O=F%NX2!P^.UP;VYA`$%K
M='5A;&EZ;W9A=`!!:W1U86QI>F]V870@)7,`06MT=6%L:7IO=F%T('6^:79A
M=&5L90!3:W)I<'0@<')O(&%K='5A;&EZ86-I(&)Y;"!V>6UA>N%N+@!0^&5N
M;W,`5KEE8VAN>2!S;W5B;W)Y('!R;R!N87-T879E;NT@87!L:6MA8^T@8GEL
M>2!P^&5N97-E;GD@;F$@<V5R=F5R+@!696QKX2!T:7-K86/M('#M<VUE;F$`
M5F5L:^D@^.UM<VOI(.CM<VQI8V4`57)U9W5A>0!0;W6^[70@86MT=>%L;NTZ
M("5S`%!O=;[M="!34TP`4&]UONUT('!O:W5D(&IMZ6YO+VAE<VQO(&IS;W4@
M:FENZ2!N9;X@<')O($E-4U`@<V5R=F5R+@!5OFEV871E;"`E<R!N96[M(&]P
M<N%V;NQN(&L@<&]UONUVX6[M("5S+@!!9&UI;FES=')A8V4@=;YI=F%T96SY
M`%6^:79A=&5L<VOI(&UOOFYO<W1I`%)E9VES=')A8V4@=;YI=F%T96SY`$YA
M('1O;71O('-E<G9E<G4@;F5N[2!M;[YNX2!R96=I<W1R86-E('6^:79A=&5L
M^2X`5;YI=F%T96QS:^D@:FWI;F\`5;YI=F%T96QS:^D@:FWI;F\Z`%6^:79A
M=&5L<VOI(&IMZ6YO.B``4V5Z;F%M('6^:79A=&5L^3H`57IB96MI<W3A;@!6
M1E,@861R97/A^"!N965X:7-T=6IE+@!$;W9O;&5NX0!.86QE>F5NX2!P;&%T
M;N$@;>US=&$@>F%H<FYU:NTZ(`!0;&%T;F]S=`!(;V1N;W1A('8@;6EN=73A
M8V@N`$AO9&YO='D`5GEB<F%NZ2!H;V1N;W1Y('H`5F%N=6%T=0!0<F]M[&YN
MZ0!696YE>G5E;&$`4V5L:&%L82!V97)I9FEK86-E("T@=&%T;R!Z<'+A=F$@
M;6]H;&$@8OUT('IF86RY;W;A;F$N`%9E<GIE`%9E<G-I;VX@0V]N=')O;`!6
M97)T:6OA;&[M('IA<F]V;N%N[0!697)T:6OA;&[M(&]D<W1U<`!697)T:6OA
M;&[M.@!696QM:2!V>7-O:^$`5FEE=&YA;0!6:65T;F%M<VMY("A625-#24DI
M`%IO8G)A>FET("5S`%IO8G)A>FET(&5X=&5R;NT@=V5B<W1RX6YK=0!:;V)R
M87II="!J86MO("5S`%!A;FYE;G-KZ2!/<W1R;W9Y+"!"<FET<VOI`%!A;FYE
M;G-KZ2!/<W1R;W9Y+"!5+E,N`%9I9&ET96QN;W-T`%9I9&ET96QN;W-T.@!6
M;V1A9F]N92!)=&%L>2!P^&5S(%--5%``55!/6D]23DE4`%503UI/4D[,3LTA
M(2$@3T135%)!TE1%(%-+4DE05"!25<A.S"!:("5S+@!786QL:7,@86YD($9U
M='5N80!5<&]Z;W)N[&[M`%-T`%#X961P;W;L[R!P;^AA<^T`1&%T82!O('!O
MZ&%S[2!P;W-K>71U:F4`5V5A=&AE<BYC;VT`5V5B`%=E8B!S97)V97(`5/UD
M;NP`5NUT96IT90!6[71E:G1E('8@)7,`5NUT96IT92P@)7,`6N%P861N[2`H
M25-/+3@X-3DM,2D`6N%P861N[2`H25-/+3@X-3DM,34I`%KA<&%D;NT@4V%H
M87)A`$MT97)O=2!A<&QI:V%C:2!MX2`E<R!Z;V)R87II="!P;R!P^&EH;.&Y
M96[M(&1O('-Y<W3I;74_`$IA:_T@:F4@;V1D[&QO=F%C[2!Z;F%K/P!*86O]
M(&IE('IN86L@<')O(&-I=&%C:3\`2W1E<ND@9N%Z90!6;VQB82!R;WJY[?AE
M;NT@<')O(%)I8V@@5&5X="!E9&ET;W(N`*GM^&MA`*GM^&MA('8@0U-3(&IE
M9&YO=&OA8V@`J>WX:V$@)7,@;65N=2!V;&5V;R`H>FWL;F$@<V4@;V)J97;M
M('#X:2!D86RY[6T@</AI:&SAN65N[2DZ`*GM^&MA('1A8G5L:WD`2F5D;F]T
M:V$@N>WX:WD`J>WX:V$Z`%=I:VD`5NUT<@!286YN[2!V[71R`%)Y8VAL;W-T
M(';L=')U('8@=7IL96-H`%;M='(Z`%;M='(Z(`!-;W5D<F]S=`!0<N%C90!!
M9')E<V$@9&\@>F%M['-T;N%N[0!496QE9F]N(&1O('IA;>QS=&[A;NT`6"U2
M968`6#4P.78S('KA:VQA9&[M(&]M97IE;NT`6#4P.78S(')O>KGM^&5NZ2!P
M;W6^:73M(&ML[>AE`%@U,#EV,R!A;'1E<FYA=&EV;NT@:FWI;F\@;W-O8GD`
M6#4P.78S(&ED96YT:69I:^%T;W(@:VSMZ&4`6#4P.78S(')O>KGM^&5N[0!2
M4@!24E)2`$UA<&$@66%H;V\A`%)OZ&[L`$IE;65N`$%N;P!!;F\L('-O=6AL
M87/M;0!*<W1E('8@5$585$]6R4T@3=-$52X@4&]UOFEJ=&4@6SP^72!T;&'H
M[71K82!K('IP['1NZ6UU('#X97!N=73M(&1O(%=94TE764<N`$YE8GEL:2!J
M<W1E('-P<N%V;NP@;W;L^&5N:2X`6FYA:R`G7"<@;F5M^;YE(&+]="!S;W7H
MX7-T[2!68;EE:&\@:FWI;F$N`$)Y;&$@>F%DX6YA(&YE<&QA=&[A(&4M;6%I
M;&]VX2!A9')E<V$N`$YE;6%P;W9A;&D@:G-T92"^X61NX2!P;VQE('H@:6UP
M;W)T;W9A;NEH;R!S;W5B;W)U(&L@;V1P;W;M9&%J[6/M;2!P;VSM;2!V("5S
M+@!">6QI(&IS=&4@;V1H;.&Y96YI('IE('-Y<W3I;74N`%9L;[YT92#H[7-L
M;R!M;V)I;&[M:&\@=&5L969O;G4L('!O=;YI:G1E(&IE;B#H[7-L:6,@;F5B
M;R!P^.UP861N["`G*R<@<')O(&UE>FENX7)O9&[M(.AI<VQA+@!-=7/M=&4@
M>F%D870@<&QA=&YO=2!H;V1N;W1U+@!-=7/M=&4@:V]N9FEG=7)O=F%T(&1A
M=&%BX7II(&1A="P@<&]K=60@<VD@</AE:F5T92!P;W6^[79A="!296=I<W1R
M86-E+@!-=7/M=&4@:V]N9FEG=7)O=F%T(%9&4R!B86-K96YD+@!-=7/M=&4@
M;F5J9/CM=F4@<&]P<V%T('!R;V)LZ6T@82!P;W3I(&AO(&]D97-L870N`$UU
M<^UT92!Z861A="!54DP@;F$@:W1E<ND@8G5D92!T96YT;R!O9&MA>B!U:V%Z
M;W9A=`!-=7/M=&4@=GEB<F%T('-E<G9E<BP@:W1E<OT@8G5D92!S;6%ZX6XN
M`$UU<^UT92!V>6)R870@=;YI=F%T96QS:^D@:FWI;F\L(&MT97+I(&)U9&4@
M<VUA>N%N;RX`375S[71E('IA9&%T('6^:79A=&5L<VOI(&IMZ6YO+"!K=&5R
MZ2!B=61E(&]D<W1R86[L;F\N`$YE=79E9&QI(&IS=&4@=;YI=F%T96QS:^D@
M:FWI;F\L(&MT97+I(&)U9&4@</AI9.%N;RX`3F5U=F5D;&D@:G-T92!UOFEV
M871E;'-KZ2!J;>EN;R!P<F\@86MT=6%L:7IA8VDN`$UU<^UT92!Z861A="!A
M:V-I+"!K=&5RX2!B=61E('!R;W9E9&5N82X`375S[71E('IA9&%T(&IMZ6YO
M(&YO=ND@:V%T96=O<FEE+@!68;EE("5S(')E;&%C92!B>6QA('5K;V[H96YA
M+B!/<.QT('-E('#X:6AL8;ET92P@<')O<^UM+@!68;EE(&5M86EL;W;A(&%D
M<F5S80!68;EE($]D+6MO:&\Z(&%D<F5S83H`5F&Y92!I;F9O<FUA8V4`5B!R
M96QA8VD@)7,@<V4@>FWL;FEL82!68;EE(&EN=&5R;F5T;W;A(&%D<F5S82X@
M6B!B97IP9>AN;W-T;NUC:"!D^79O9/D@<V4@;75S[71E(&]P['0@</AI:&SA
M<VET+@!68;EE(&IMZ6YO`%;AN2!O=NSX;W9A8^T@<WES=.EM(&YE<&]D<&]R
M=6IE(';]<&ES('6^:79A=&5L^2!A;F5B;R!T871O(&UOOFYO<W0@;F5N[2!P
M^.US='5P;N$@>B!J:6[]8V@@9/EV;V3Y+@!:9.$@<V4L(+YE('8@<'+Y8NQH
M=2!R96QA8V4@)7,@<V4@>FWL;FEL(%;AN2!P<F]H;.V^9>@N(%H@8F5Z<&7H
M;F]S=&[M8V@@9/EV;V3Y('-E(&UU<^UT92!O<.QT('#X:6ALX7-I="X`5N&Y
M('!R;VAL[;YEZ"!N97!O9'!O<G5J92!T=71O(&UOOFYO<W0N`%9AN64@<V]U
MZ&%S;ND@Z&%S;W;I('#A<VUO.@!68;EE(&EM<&QI8VET;NT@:61E;G1I=&$`
M5F&Y92#Z<&QNZ2!J;>EN;SH`5F&Y92!N;W;I(&AE<VQO('!R;R`E<R!J93H@
M)7,`5F&Y92!N87-T879E;NT@8GEL;R!A:W1U86QI>F]VX6YO('!R;R!T<G;A
M;NT@=.ET;R!R96QA8V4N`%9AN64@;F%S=&%V96[M(&)Y;&\@86MT=6%L:7IO
M=N%N;RX`5F&Y92!H97-L;R!B>6QO(')E<V5T;W;A;F\N`%9AN64@:&5S;&\@
M8GEL;R!R97-E=&]VX6YO+"!Z:V]N=')O;'5J=&4@<VD@>G!RX79Y(&5L96MT
M<F]N:6-KZ2!P;[ET>2!A('#X:6AL8;ET92!S92!S(%9AN>UM(&YO=OUM(&AE
M<VQE;2X`5F&Y92!V>F3A;&5NZ2!S97)V97)Y.@!*=6=O<VSA=FEE`%IA:7(`
M6F%M8FEE`%II;6)A8G9E`%II<'!Y`%M5:W+]="!C:71O=F%N_2!T97AT70!;
M2&SAN65N[2!P<F]B;.EM=5T`6UIO8G)A>FET(&-I=&]V86[]('1E>'0@+0!;
M6F]B<F%Z:70@8VET;W9A;OT@=&5X="`M("5S(/CA9&OY70!;^.%D96L@)7,@
M>B`E<UT`7T%D;6EN:7-T<F%C90!?0TQ)`%]$871A5')E90!?4VUA>F%T(/CA
M9&5K`%]3:W5P:6YY`%].X7!O=NQD80!?5FQA<W1N;W-T:2!O8G+A>FMU+BXN
M`%]0^&EH;.&Y96[M`%]/9&ALX;EE;NT`7TUO9&EF:6MO=F%T(&]D:V%Z+BXN
M`%]-;[YN;W-T:0!?4'+A=F$`7T]D<W1R86YI="!O9&MA>BXN+@!?3F%S=&%V
M96[M`%]6;&%S=&YO<W1I('1A8G5L:WDN+BX`7U6^:79A=&5LZ0!A9')E<^'X
M`&MA;&5N9.'X`&)E>G;L=/CM`&ML:6MN;W5T('ID90!S<N&^:WD`<V]U8F]R
M`'H@)7,@*"5S*2!R>6-H;&]S=.T@)7,@)7,`:#H`;VMA;;YI=.P`=B#X863L
M`/CA9&OY70!C:'EB;W;](&OS9"!M:VES;V9S("5D('#X:2!V>71VX?AE;NT@
M25-/+@!J;>EN;P!N96[M(&EM<&QE;65N=&]VX6YO`&YE;NT@9&]S=60@:6UP
M;&5M96YT;W;A;F\`>N%P:7-N[6L`<')O8V5N=`!P:7AE;/D`<W1O=7!A:NUC
M[0!Z;V)R87II="!R;WID[6QY`'-M<S)E;6%I;"!Z82!P;W6^:73M($A45%``
M=GET<G9A;.D`<V5Z;F%M(/IK;VSY`'!R;R!P;W1V<GIE;NT@;F%P:;ET92!H
M97-L;R!D=F%K<N%T`'-J961N;V-E;OT`8F5Z(&[A>G9U`'9Y8G)A="!UOFEV
M871E;&4`=D-A<F0`=SH`=V5A=&AE<BYC;VT`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE
M+V-S7T-:+VAE;'`N>&UL````````````````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`S,C8Q(#$P-3$U-#,S-S0Q(#`R,30U,@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/WAM;"!V97)S:6]N
M/2(Q+C`B(&5N8V]D:6YG/2)I<V\M.#@U.2TR(C\^"CPA+2T@)$AO<F1E.B!H
M;W)D92]L;V-A;&4O8W-?0UHO:&5L<"YX;6PL=B`Q+C8@,C`P-"\P."\Q."`P
M.#HT,CHU,2!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB<W5M
M;6%R>2(@<W1A=&4](G5P=&]D871E(B!M9#4](C8X8V$S,V8W9C!C.6%A931C
M,3`S96(T-S0Y,F-D8S$U(CX*/'1I=&QE/E!O<G3A;#PO=&ET;&4^"B`\<&%R
M83X*("!3='+A;FMA(%!O<G3A;'4@<&]S:WET=6IE('-T<G7H;OT@</AE:&QE
M9"!VN65C:"!D^6QEOFET_6-H(&EN9F]R;6%C[2X*("!.87#X[6ML860@;?F^
M92!Z;V)R87IO=F%T('!OZ&5T(&5M86EL^2P@:6YF;W)M86-I(&\@<V-H^7IK
MX6-H('9E(%9A[&5M(&MA;&5N9.'X:2P*("#Z:V]L96-H+"!A=&0N(%;L=+EI
M;F$@=.QC:'1O(&EN9F]R;6/M('!O<VMY='5J[2!L:6YK>2!K(&+LOF[];2!F
M=6YK8^UM+"`*("!J86MO(&YA</CM:VQA9"!V>71V;_AE;NT@;F]VZ2!E;6%I
M;&]VZ2!Z<'+A=GDL('9Y='9O^&5N;>T@;F]VZ2!S8VCY>FMY+"!A=&0N"B`\
M+W!A<F$^"B`\<&%R83X*("!2;WIV<KYE;NT@=.ET;R!S='+A;FMY('!O<G3A
M;'4@;'IE(&YA<W1A=FET('!O;6]C[2!T;&'H[71K82!2;WIL;[YE;NTN"B`@
M3F%P^.UK;&%D+"!M^;YE=&4@<VD@=GEB<F%T+"!K=&5RZ2!P<G9K>2!S:2!P
M^&5J971E('IO8G)A>FET(&$@=&%KZ2!V(&IA:^EM"B`@<&_X863M+B`*(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](FYA=F)A<B(@<W1A=&4](G5P
M=&]D871E(B!M9#4](F(X8V8P864Q.64U-V1F83!C,F(Y-C)E-3$V-S@R9C0W
M(CX*/'1I=&QE/DYA=FEG8>AN[2!,:;ET82!P<F\@07!L:6MA8V4\+W1I=&QE
M/@H@/'!A<F$^"B`@3F%V:6=AZ&[M(&QIN71A(&IE('5M[7-T;NQN82!V;&5V
M;R!N82!W96)S='+A;F-E+B!+;&EK;NQT92!N82!I:V]N:WD*("!TZ71O(&QI
MN71Y('!O<VMY='5J[6/M('#X96AL961N[&JY[2!A(')Y8VAL96JY[2!P^&5P
M[6[A;NT@;65Z:2!A<&QI:V%C96UI+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<')E9G,M9&]?;6%I;G1E;F%N8V4B('-T871E/2)U<'1O9&%T
M92(@;60U/2)D9#DU9&8P-V$P,S`S,3(S,F)A96$Y,3DR.#AB,F0P,"(^"B`@
M("`\=&ET;&4^3F%S=&%V96[M.B#:9'*^8F$Z(%!R;W;I<W0@VF1ROF)U/"]T
M:71L93X*("`@(#QP87)A/@H@("`@3WIN8>AT92!T96YT;R!RX6UEZ&5K+"!P
M;VMU9"!S:2!P^&5J971E('!R;W;I<W0@;W!E<F%C92#Z9'*^8GD@</AI"B`@
M("!P^&EH;.&Y96[M(&1O('-Y=.EM=2X*("`@(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](G!R969S+6-O;F9I<FU?;6%I;G1E;F%N8V4B('-T871E
M/2)U<'1O9&%T92(@;60U/2)A,C$Q-C)C9&9F,V(Q9#AF865A9&(W,CDV,C0P
M,#,V92(^"B`@("`\=&ET;&4^3F%S=&%V96[M.B#:9'*^8F$Z(%!O='9R9&ET
M(-ID<KYB=3PO=&ET;&4^"B`@("`\<&%R83X*("`@($]Z;F'H=&4@=&5N=&\@
M<N%M9>AE:RP@<&]K=60@<VD@</AE:F5T92!P;W1V<F1I="!VN65C:&YY(&]P
M97)A8V4@^F1ROF)Y"B`@("!N9;X@<V4@<')O=F5D;W4N(%!O:W5D('1E;G1O
M('+A;67H96L@>OES=&%N92!N96]Z;F'H96[]+"!P;W3X96)NZ2!O<&5R86-E
M(`H@("`@<V4@<')O=F5D;W4@875T;VUA=&EC:WD@8F5Z(&UOOFYO<W1I('-T
M;W)N82X*("`@(#PO<&%R83X*/"]E;G1R>3X*/"]H96QP/@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]E;%]'
M4@``````````````````````````````````````````````````````````
M```````````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#`P,"`Q,#4Q-30S,S<T,2`P,3<W,#8`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&]C86QE+V5L7T=2+TQ#7TU%4U-!1T53````````````````````
M`````````````````````````````````````````````````#`P,#<U-2``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S0Q(#`R,30W
M,P`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O96Q?1U(O3$-?34534T%'
M15,O:&]R9&4N;6\`````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`S-3<W,3$@
M,3`U,34T,S,W-#$@,#(S,C(V`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````-X2!)4`````"P8``!P```!T,```#P@``,Q@````
M````"($``"4````)@0``2````"^!```.````>($```\```"'@0``#0```)>!
M```(````I8$```L```"N@0``#````+J!```$````QX$```P```#,@0``#P``
M`-F!```+````Z8$``!$```#U@0``#@````>"```H````%H(```@````_@@``
M"@```$B"```5````4X(``!(```!I@@``"P```'R"```4````B((``"8```"=
M@@``)P```,2"```F````[((```X````3@P``"@```"*#```G````+8,``"``
M``!5@P``#@```':#```7````A8,``"(```"=@P``-0```,"#```1````]H,`
M``T````(A```#````!:$```-````(X0``!L````QA```+0```$V$```=````
M>X0``"0```"9A```*0```+Z$```9````Z(0```\````"A0``&````!*%```,
M````*X4```X````XA0``#@```$>%```(````5H4``"(```!?A0``&@```(*%
M```R````G84``#@```#0A0``5`````F&``!1````7H8``%H```"PA@``5P``
M``N'```T````8X<```4```"8AP``$0```)Z'```(````L(<```D```"YAP``
M"0```,.'```.````S8<```@```#<AP``)0```.6'```@````"X@``!`````L
MB```#P```#V(```*````38@```<```!8B````P```&"(```/````9(@``!0`
M``!TB```"0```(F(```-````DX@``!(```"AB```&0```+2(```>````SH@`
M``\```#MB```"@```/V(```/````"(D```@````8B0``)````"&)```7````
M1HD``!0```!>B0``%@```'.)```(````BHD``$X```"3B0``+0```.*)```9
M````$(H```<````JB@``#````#**```L````/XH```X```!LB@``#@```'N*
M```6````BHH```4```"AB@``!0```*>*```*````K8H```,```"XB@``%P``
M`+R*```*````U(H```\```#?B@``#@```.^*```8````_HH``",````7BP``
M#@```#N+```4````2HL``!<```!?BP``%P```'>+```7````CXL``!,```"G
MBP``#P```+N+```?````RXL``!$```#KBP``$0```/V+```/````#XP```8`
M```?C```"P```":,```0````,HP``!4```!#C```%0```%F,```'````;XP`
M``4```!WC```#@```'V,```1````C(P```P```">C```.P```*N,```X````
MYXP```,````@C0``"0```"2-```Y````+HT``!(```!HC0``#P```'N-```Y
M````BXT``"<```#%C0``+````.V-```J````&HX``"4```!%C@``"0```&N.
M```*````=8X```8```"`C@``%0```(>.```9````G8X``"D```"WC@``)```
M`.&.```1````!H\``!$````8CP``"@```"J/```0````-8\``!8```!&CP``
M%@```%V/```$````=(\``"<```!YCP``"````*&/```(````JH\``"D```"S
MCP``#@```-V/```*````[(\```0```#WCP``!P```/R/```$````!)````8`
M```)D```#0```!"0```7````'I````,````VD```$P```#J0```(````3I``
M`!````!7D```"0```&B0```$````<I```$$```!WD```(````+F0```&````
MVI```!4```#AD```&````/>0```B````$)$``"X````SD0``'0```&*1```A
M````@)$``%0```"BD0``*0```/>1```'````(9(``!4````ID@``"@```#^2
M```/````2I(```T```!:D@``#P```&B2```-````>)(```D```"&D@``!@``
M`)"2```3````EY(``!0```"KD@``#````,"2```&````S9(```\```#4D@``
M5````.22```$````.9,```X````^DP``1````$V3```-````DI,``!,```"@
MDP``$0```+23```1````QI,``!$```#8DP``'````.J3```J````!Y0``!,`
M```RE```(0```$:4```%````:)0``!,```!NE```$@```(*4```*````E90`
M``\```"@E```$0```+"4```*````PI0``!$```#-E```#````-^4```0````
M[)0``!$```#]E```!0````^5```,````%94``!`````BE0``!0```#.5```-
M````.94```8```!'E0``!P```$Z5```-````5I4```<```!DE0``"P```&R5
M```'````>)4```D```"`E0``%````(J5```)````GY4```H```"IE0``&0``
M`+25```]````SI4``!T````,E@``'0```"J6```,````2)8``!````!5E@``
M$@```&:6```3````>98``"L```"-E@``.P```+F6```@````]98```X````6
MEP``-@```"67```0````7)<``!L```!MEP``"````(F7```$````DI<```X`
M``"7EP``'@```*:7```;````Q9<``"$```#AEP``'@````.8```9````(I@`
M`!X````\F```&P```%N8```N````=Y@``"8```"FF```&P```,V8```>````
MZ9@``!P````(F0``)@```"69```K````3)D``#,```!XF0``)@```*R9```K
M````TYD``#@```#_F0``'0```#B:```5````5IH``"\```!LF@``$@```)R:
M```@````KYH``"D```#0F@``'@```/J:```2````&9L``*(````LFP``%@``
M`,^;```C````YIL``"@````*G```*0```#.<```H````79P``!\```"&G```
M%0```*:<```@````O)P``"4```#=G```*`````.=```M````+)T``#````!:
MG0``D@```(N=```A````'IX``!8```!`G@``'````%>>```F````=)X``"H`
M``";G@``00```,:>``!$````")\```P```!-GP``!P```%J?```'````8I\`
M``8```!JGP``#0```'&?```0````?Y\``!(```"0GP``$P```*.?```2````
MMY\```<```#*GP``#0```-*?```,````X)\```X```#MGP``#P```/R?```3
M````#*````T````@H```*````"Z@```#````5Z````T```!;H````@```&F@
M```%````;*````0```!RH```$````'>@```6````B*````0```"?H```#0``
M`*2@```.````LJ````,```#!H```#@```,6@```(````U*````\```#=H```
M"````.V@```/````]J````<````&H0``#0````ZA```0````'*$``!,````M
MH0``$P```$&A```+````5:$``!$```!AH0``"0```'.A```&````?:$```P`
M``"$H0``$0```)&A```9````HZ$```L```"]H0``#0```,FA```B````UZ$`
M`!L```#ZH0``-````!:B```*````2Z(``!@```!6H@``&0```&^B```6````
MB:(``"\```"@H@``(@```-"B```-````\Z(```P````!HP``)@````ZC```4
M````-:,```L```!*HP``(@```%:C```O````>:,```L```"IHP``"0```+6C
M```9````OZ,```L```#9HP``%P```.6C```7````_:,```D````5I```%@``
M`!^D```/````-J0``!8```!&I```#@```%VD```8````;*0```T```"%I```
M)@```).D``!#````NJ0```@```#^I```"P````>E```O````$Z4```X```!#
MI0``!0```%*E```$````6*4```H```!=I0``"@```&BE```/````<Z4``!``
M``"#I0``%P```)2E```1````K*4``!<```"^I0``&0```-:E```/````\*4`
M``H`````I@``!0````NF```-````$:8``!L````?I@``%P```#NF```)````
M4Z8```X```!=I@``#0```&RF```2````>J8``#@```"-I@``(````,:F```#
M````YZ8```@```#KI@``#@```/2F``![`````Z<``!@```!_IP``!0```)BG
M```8````GJ<``!D```"WIP``$P```-&G```&````Y:<```8```#LIP``$```
M`/.G```/````!*@``!`````4J```#P```"6H```+````-:@```\```!!J```
M#````%&H```/````7J@```<```!NJ```!@```':H```.````?:@``"````",
MJ```'0```*VH```,````RZ@``"@```#8J```#P````&I```(````$:D```@`
M```:J0``$P```".I```>````-ZD``"$```!6J0``(````'BI```9````F:D`
M`!<```"SJ0``)0```,NI```7````\:D``$(````)J@``!````$RJ```,````
M4:H```,```!>J@``"````&*J```*````:ZH```P```!VJ@``"P```(.J```0
M````CZH```P```"@J@``$P```*VJ```4````P:H```P```#6J@``"0```..J
M```.````[:H```L```#\J@``&P````BK```'````)*L```H````LJP``#0``
M`#>K```)````1:L```0```!/JP``!0```%2K```#````6JL``!@```!>JP``
M"@```'>K```$````@JL``"8```"'JP``%0```*ZK```%````Q*L```<```#*
MJP``#````-*K```(````WZL```H```#HJP``!@```/.K```(````^JL```(`
M```#K```!@````:L```5````#:P```\````CK```$0```#.L```:````1:P`
M``0```!@K```"0```&6L```0````;ZP``!$```"`K```"0```)*L```)````
MG*P``!H```"FK```"````,&L```*````RJP```X```#5K````@```.2L```&
M````YZP``!(```#NK```%`````&M```=````%JT``!$````TK0``!@```$:M
M```1````3:T``!$```!?K0``"0```'&M```>````>ZT```8```":K0``!```
M`*&M```1````IJT```8```"XK0``"@```+^M```1````RJT``"(```#<K0``
M!````/^M```E````!*X```4````JK@``!````#"N```,````-:X```H```!"
MK@``!0```$VN```+````4ZX```P```!?K@``#@```&RN```@````>ZX```\`
M``"<K@``$@```*RN```+````OZX``"8```#+K@``*0```/*N```D````'*\`
M`"8```!!KP``"````&BO```*````<:\```D```!\KP``(````(:O```@````
MIZ\``"8```#(KP``!0```.^O```*````]:\``!D`````L```*0```!JP```6
M````1+````8```!;L```$@```&*P```*````=;````P```"`L```#P```(VP
M```0````G;```$````"NL```<````.^P``!F````8+$```X```#'L0``"0``
M`-:Q```2````X+$``!,```#SL0``#`````>R```&````%+(```8````;L@``
M#@```"*R```/````,;(``!(```!!L@``$````%2R```*````9;(``!$```!P
ML@``'````(*R```C````G[(``&H```##L@``#P```"ZS```0````/K,```0`
M``!/LP``"P```%2S```4````8+,```P```!ULP``#````(*S```/````C[,`
M`!4```"?LP``*0```+6S```J````W[,``"8````*M```)P```#&T```I````
M6;0``"H```"#M```&0```*ZT``!"````R+0``!$````+M0``$@```!VU```3
M````,+4``!0```!$M0``#P```%FU```6````:;4``!<```"`M0``$````)BU
M```1````J;4``#0```"[M0``$P```/"U```2````!+8``#4````7M@``%```
M`$VV```'````8K8```P```!JM@``*P```'>V```@````H[8``!0```#$M@``
M$0```-FV```7````Z[8``!P````#MP``$P```""W```1````-+<``!H```!&
MMP``'@```&&W```:````@+<``!$```";MP``%P```*VW```4````Q;<``!<`
M``#:MP``%0```/*W```)````"+@```8````2N```!P```!FX```$````(;@`
M``0````FN```!P```"NX```.````,[@```P```!"N```#````$^X```-````
M7+@``!````!JN```$0```'NX```0````C;@```X```">N```$0```*VX```H
M````O[@```\```#HN```#@```/BX```,````![D```\````4N0``"@```"2Y
M```(````+[D```D````XN0``*P```$*Y```$````;KD```L```!SN0``#@``
M`'^Y```'````CKD```X```"6N0``"0```*6Y```,````K[D```T```"\N0``
M#@```,JY```6````V;D``!$```#PN0```P````*Z```&````!KH``!D````-
MN@``!````">Z```+````++H```L````XN@``"````$2Z```.````3;H```0`
M``!<N@``#P```&&Z```Z````<;H```4```"LN@``#````+*Z```>````O[H`
M``X```#>N@``$````.VZ```+````_KH``!H````*NP``"@```"6[```,````
M,+L```\````]NP``"````$V[```&````5KL```<```!=NP``"P```&6[``!<
M````<;L```T```#.NP``!@```-R[```)````X[L```0```#MNP```P```/*[
M```3````]KL``!,````*O```$P```!Z\```"````,KP```4````UO```!```
M`#N\```*````0+P```T```!+O```:````%F\```&````PKP``!@```#)O```
M$0```.*\```%````]+P```8```#ZO```&P````&]```O````';T```\```!-
MO0``$P```%V]```;````<;T``!@```"-O0``%P```*:]```.````OKT```,`
M``#-O0``%````-&]```3````YKT``!````#ZO0``#0````N^```.````&;X`
M`!8````HO@``!P```#^^```%````1[X```H```!-O@``"P```%B^```'````
M9+X``%$```!LO@``$````+Z^```,````S[X```T```#<O@``&@```.J^``!*
M````!;\```8```!0OP``&@```%>_```&````<K\```8```!YOP``"0```("_
M```8````BK\``!<```"COP``!@```+N_```-````PK\``"(```#0OP``5P``
M`/._```3````2\```",```!?P```$P```(/````"````E\````L```":P```
M"````*;````-````K\````H```"]P```"@```,C````.````T\````<```#B
MP```$P```.K````+````_L````D````*P0``"0```!3!```*````'L$```<`
M```IP0``"0```#'!```'````.\$``!L```!#P0``$@```%_!```*````<L$`
M``D```!]P0``$````(?!```*````F,$``!````"CP0``$@```+3!```$````
MQ\$```P```#,P0``!P```-G!```%````X<$```P```#GP0``"````/3!```,
M````_<$``!0````*P@``%P```!_"```3````-\(```0```!+P@``"@```%#"
M```$````6\(```D```!@P@``"@```&K"```,````=<(```(```""P@``.```
M`(7"```L````OL(``!(```#KP@``*0```/["```R````*,,```H```!;PP``
M-@```&;#```L````G<,``"X```#*PP``,P```/G#```\````+<0``#H```!J
MQ```.P```*7$```S````X<0``#X````5Q0``.````%3%```/````C<4``!@`
M``"=Q0``$````+;%```/````Q\4``!,```#7Q0``%````.O%```2`````,8`
M`!0````3Q@``%0```"C&```3````/L8``!T```!2Q@``"````'#&```(````
M><8``"L```""Q@``(0```*[&```:````T,8```D```#KQ@``10```/7&``!!
M````.\<```\```!]QP``!````(W'```3````DL<``!,```"FQP``"0```+K'
M```*````Q,<```\```#/QP``$````-_'```'````\,<```X```#XQP``!0``
M``?(```-````#<@```<!```;R```!@```"/)```;````*LD```8```!&R0``
M(P```$W)```(````<<D```8```!ZR0``%````(')```1````ELD``"8```"H
MR0``#@```,_)```X````WLD```8````7R@``#@```![*```:````+<H```4`
M``!(R@``!P```$[*```.````5LH```8```!ER@``#````&S*```I````><H`
M`!<```"CR@``'P```+O*``!<````V\H``!0````XRP``/@```$W+```?````
MC,L``!````"LRP``%````+W+```'````TLL```L```#:RP``#@```.;+```,
M````]<L```P````"S```$P````_,```*````(\P``!T````NS```&0```$S,
M```%````9LP``!$```!LS```$0```'[,```D````D,P``!4```"US```$@``
M`,O,```.````WLP``!D```#MS```"`````?-```)````$,T```H````:S0``
M!P```"7-```(````+<T``"L````VS0``$@```&+-```L````=<T``!H```"B
MS0``"0```+W-```*````Q\T``!4```#2S0``$````.C-```%````^<T``!0`
M``#_S0``!````!3.```0````&<X```8````JS@``!P```#'.```>````.<X`
M`"@```!8S@``"@```('.```<````C,X``!H```"IS@``#P```,3.```4````
MU,X```0```#IS@``!0```.[.```&````],X```8```#[S@``"@````+/```;
M````#<\``#0````ISP``-````%[/```@````D\\``"D```"TSP``(````-[/
M``!!````_\\``!H```!!T```'0```%S0```H````>M```!P```"CT```'```
M`,#0```I````W=```"D````'T0``40```#'1``!7````@]$``"P```#;T0``
M(@````C2```?````*](``!D```!+T@``&0```&72```J````?](``"L```"J
MT@``(P```-;2```N````^M(``#0````ITP``#0```%[3```(````;-,``!<`
M``!UTP``"@```(W3```'````F-,``"$```"@TP``#0```,+3```0````T-,`
M``X```#ATP``"P```/#3```'````_-,``!,````$U```"````!C4```+````
M(=0```H````MU```%````#C4```R````3=0```4```"`U```%P```(;4```/
M````GM0```X```"NU```!0```+W4```$````P]0```T```#(U```,@```-;4
M``!%````"=4``!<```!/U0``'@```&?5```4````AM4``!4```";U0``!0``
M`+'5```4````M]4```<```#,U0``(P```-35```.````^-4``"H````'U@``
M!@```#+6```,````.=8```T```!&U@``$0```%36```7````9M8```L```!^
MU@``-@```(K6```*````P=8``"(```#,U@``"P```._6```/````^]8```L`
M```+UP``(````!?7```G````.-<``"L```!@UP``"0```(S7```R````EM<`
M`#````#)UP``,0```/K7```M````+-@``$````!:V```/0```)O8``!"````
MV=@``#X````<V0``/P```%O9``!"````F]D``#X```#>V0``/P```!W:``!"
M````7=H``#X```"@V@``/P```-_:``!!````']L``#T```!AVP``/@```)_;
M```_````WML``#L````>W```/````%K<```]````E]P``#H```#5W```0@``
M`!#=```^````4]T``#\```"2W0``#@```-+=```4````X=T```4```#VW0``
M#@```/S=```3````"]X```<````?W@``$0```"?>```.````.=X```<```!(
MW@``%````%#>```.````9=X``!@```!TW@``!P```(W>```%````E=X```P`
M``";W@``#````*C>```2````M=X```0```#(W@``"@```,W>```+````V-X`
M``P```#DW@``#@```/'>```.`````-\```4````/WP``!0```!7?```N````
M&]\``"8```!*WP``(P```''?```#````E=\``!X```"9WP``&````+C?```E
M````T=\```T```#WWP``"0````7@```'````#^````H````7X````@```"+@
M```2````)>````T````XX```$@```$;@```$````6>````<```!>X```"0``
M`&;@```,````<.```%(```!]X```%P```-#@```D````Z.````<````-X0``
M!@```!7A```.````'.$```L````KX0``#@```#?A```,````1N$```T```!3
MX0``%0```&'A```2````=^$```\```"*X0``%````)KA```;````K^$``!``
M``#+X0``:````-SA```:````1>(``!<```!@X@``)P```'CB```:````H.(`
M`!<```"[X@``&P```-/B```9````[^(``!\````)XP``%P```"GC```3````
M0>,```@```!5XP``"````%[C```)````9^,```T```!QXP``$P```'_C```#
M````D^,``$8```"7XP``/P```-[C```T````'N0``"0```!3Y```-P```'CD
M``!7````L.0```4````(Y0``'P````[E```O````+N4```@```!>Y0``#0``
M`&?E```.````=>4``"T```"$Y0``!````++E``!/````M^4``"4````'Y@``
M'````"WF```+````2N8``!\```!6Y@``'0```';F```E````E.8``"````"Z
MY@``)````-OF```@`````.<```L````AYP``!@```"WG```Y````-.<```<`
M``!NYP``&0```';G```)````D.<``!,```":YP``!````*[G```0````L^<`
M`#````#$YP``%````/7G```-````"N@```X````8Z```$P```"?H```<````
M.^@``"@```!8Z```!@```('H```'````B.@``!,```"0Z```!````*3H```7
M````J>@```H```#!Z```#````,SH```)````V>@```8```#CZ```!0```.KH
M```*````\.@``!$```#[Z```!@````WI```.````%.D```X````CZ0``#0``
M`#+I```+````0.D``!T```!,Z0``"P```&KI```"````=ND``!P```!YZ0``
M!P```);I```7````GND```8```"VZ0``90```+WI```)````(^H```<````M
MZ@``)@```#7J```X````7.H``!H```"5Z@``*@```+#J```[````V^H``"@`
M```7ZP``-````$#K```9````=>L``!4```"/ZP``!P```*7K```(````K>L`
M``<```"VZP``!P```+[K```.````QNL```D```#5ZP``!@```-_K```(````
MYNL```L```#OZP``!P```/OK```'`````^P``!`````+[```!@```!SL```<
M````(^P```4```!`[```$````$;L```0````5^P```\```!H[```!P```'CL
M```%````@.P```T```"&[```$````)3L```4````I>P```L```"Z[```#0``
M`,;L```8````U.P``!<```#M[```&@````7M```4````(.T```0````U[0``
M"0```#KM```*````1.T```<```!/[0```@```%?M```?````6NT``",```!Z
M[0``.````)[M```Q````U^T``"<````)[@``9````#'N```4````ENX``!P`
M``"K[@``50```,CN```X````'N\``$H```!7[P``6P```*+O```H````_N\`
M`#@````G\```*@```&#P```H````B_```"P```"T\```)P```.'P```;````
M"?$``#X````E\0``J0$``&3Q```C````#O,``!<````R\P``2````$KS```C
M````D_,``(4```"W\P``,````#WT``!!````;O0``%L```"P]```3`````SU
M``"/````6?4``!T```#I]0``&`````?V```A````(/8``!\```!"]@``*P``
M`&+V```A````CO8``"D```"P]@``)P```-KV```=`````O<``!$````@]P``
M,P```#+W```E````9O<``#@```",]P``(````,7W```?````YO<``#`````&
M^```:0```#?X```R````H?@``#$```#4^```00````;Y```S````2/D``"4`
M``!\^0``/0```*+Y``!E````X/D``$T```!&^@``+P```)3Z```N````Q/H`
M`"L```#S^@``,````!_[```J````4/L``#X```![^P``5````+K[``!:````
M#_P``$@```!J_```2@```+/\```4````_OP``#(````3_0``'0```$;]```C
M````9/T``"\```"(_0``+````+C]```M````Y?T``'$````3_@``;P```(7^
M``"S````]?X``!<```"I_P``)0```,'_```R````Y_\``"D````:``$`/@``
M`$0``0`B````@P`!`%(```"F``$`S0```/D``0";````QP$!`*8```!C`@$`
M)0````H#`0`+````,`,!`+$````\`P$`B0```.X#`0!%````>`0!`"$```"^
M!`$`EP```.`$`0`P````>`4!`"4```"I!0$`'````,\%`0`'````[`4!``0`
M``#T!0$`#0```/D%`0`+````!P8!``X````3!@$`!0```"(&`0`0````*`8!
M``(````Y!@$`60```#P&`0`%````E@8!`!(```"<!@$`"````*\&`0`#````
MN`8!`!````"\!@$`#````,T&`0`0````V@8!``T```#K!@$``@```/D&`0`.
M````_`8!`!(````+!P$``P```!X'`0`J````(@<!``0```!-!P$`'P```%('
M`0`U````<@<!`"X```"H!P$`+P```-<'`0`7````!P@!`"`````?"`$`&P``
M`$`(`0`8````7`@!`"0```!U"`$`'P```)H(`0`:````N@@!`"````#5"`$`
M&@```/8(`0`R````$0D!`"\```!$"0$`&@```'0)`0`K````CPD!`!\```"[
M"0$`(P```-L)`0`?````_PD!`!H````?"@$`)0```#H*`0`F````8`H!`"4`
M``"'"@$`)````*T*`0`8````T@H!`!T```#K"@$`)`````D+`0`8````+@L!
M`"(```!'"P$`)0```&H+`0`J````D`L!`#P```"["P$`'P```/@+`0`C````
M&`P!`!\````\#`$`(````%P,`0`:````?0P!`!@```"8#`$`)@```+$,`0`>
M````V`P!`"D```#W#`$`'@```"$-`0`)````0`T!``P```!*#0$`%P```%<-
M`0`7````;PT!`"\```"'#0$`)````+<-`0`'````W`T!`!\```#D#0$`!0``
M``0.`0`'````"@X!`"(````2#@$`)0```#4.`0`=````6PX!`!H```!Y#@$`
M!P```)0.`0#'````G`X!``L```!D#P$`%0```'`/`0`&````A@\!``D```"-
M#P$`&````)</`0`+````L`\!``T```"\#P$`%P```,H/`0`&````X@\!`#,`
M``#I#P$`$P```!T0`0`3````,1`!``\```!%$`$`$0```%40`0`'````9Q`!
M`#(```!O$`$`(0```*(0`0`3````Q!`!``P```#8$`$`$0```.40`0`R````
M]Q`!`!0````J$0$`$````#\1`0`(````4!$!`!T```!9$0$`"0```'<1`0`*
M````@1$!``4```",$0$`%````)(1`0`=````IQ$!``@```#%$0$`'P```,X1
M`0`(````[A$!`!H```#W$0$`!@```!(2`0`5````&1(!``@````O$@$`/P``
M`#@2`0`'````>!(!``\```"`$@$`#@```)`2`0`0````GQ(!``D```"P$@$`
M"0```+H2`0`'````Q!(!`!D```#,$@$`"@```.82`0`*````\1(!``D```#\
M$@$`"@````83`0`,````$1,!`!<````>$P$`!````#83`0`J````.Q,!``<`
M``!F$P$``@```&X3`0`&````<1,!``<```!X$P$`#0```(`3`0`+````CA,!
M`"\```":$P$`,@```,H3`0`@````_1,!`!P````>%`$`#````#L4`0`Q````
M2!0!``4```!Z%`$`$@```(`4`0`_````DQ0!`!(```#3%`$`"@```.84`0`&
M````\10!`!,```#X%`$`!0````P5`0`&````$A4!``8````9%0$`"0```"`5
M`0`$````*A4!``P````O%0$`"@```#P5`0`%````1Q4!`!@```!-%0$`&0``
M`&85`0`?````@!4!`!T```"@%0$`$0```+X5`0`"````T!4!``0```#3%0$`
M!@```-@5`0`#````WQ4!``P```#C%0$`10```/`5`0`:````-A8!`#4```!1
M%@$`*````(<6`0!3````L!8!`!D````$%P$`/@```!X7`0`@````71<!`#4`
M``!^%P$`(0```+07`0!%````UA<!`#`````<&`$`*````$T8`0`I````=A@!
M`"8```"@&`$`)0```,<8`0`H````[1@!`"@````6&0$`(@```#\9`0`P````
M8AD!`!(```"3&0$`$P```*89`0`3````NAD!`!````#.&0$`>0```-\9`0`)
M````61H!`'(```!C&@$`<P```-8:`0!\````2AL!`"L```#'&P$`4P```/,;
M`0`7````1QP!`!8```!?'`$`#P```'8<`0`?````AAP!`$````"F'`$`'P``
M`.<<`0`<````!QT!`%$````D'0$`&P```'8=`0`4````DAT!`!(```"G'0$`
M$````+H=`0`3````RQT!`!T```#?'0$`#P```/T=`0`/````#1X!``L````=
M'@$`!P```"D>`0`%````,1X!`!0````W'@$`!P```$P>`0`(````5!X!``\`
M``!='@$`"````&T>`0`,````=AX!``\```"#'@$`!@```),>`0`4````FAX!
M``8```"O'@$`#````+8>`0`(````PQX!``0```#,'@$`"@```-$>`0`$````
MW!X!`!D```#A'@$``@```/L>`0`)````_AX!``8````('P$`!@````\?`0`G
M````%A\!``0````^'P$`#P```$,?`0`3````4Q\!``<```!G'P$`!P```&\?
M`0`&````=Q\!`!````!^'P$`$@```(\?`0`&````HA\!``D```"I'P$`!0``
M`+,?`0`B````N1\!``<```#<'P$`!P```.0?`0`+````[!\!``4```#X'P$`
M9P$``/X?`0`K````9B$!`%T```"2(0$`%0```/`A`0`6````!B(!``\````=
M(@$`"0```"TB`0`(````-R(!``<```!`(@$`!@```$@B`0`,````3R(!`!``
M``!<(@$`#0```&TB`0`-````>R(!`!8```")(@$`)P```*`B`0`2````R"(!
M``H```#;(@$`#@```.8B`0`/````]2(!``L````%(P$`$````!$C`0`F````
M(B,!`"(```!)(P$`*@```&PC`0`4````ER,!``@```"L(P$`*0```+4C`0`C
M````WR,!``\````#)`$`(````!,D`0`E````-"0!`#<```!:)`$`%0```)(D
M`0`/````J"0!`!$```"X)`$`$@```,HD`0`>````W20!`#@```#\)`$`+0``
M`#4E`0`G````8R4!`"L```"+)0$`&P```+<E`0`/````TR4!`!@```#C)0$`
M#0```/PE`0`+````"B8!``L````6)@$`!P```"(F`0`F````*B8!`!L```!1
M)@$`0P```&TF`0!,````L28!`%\```#^)@$`7P```%XG`0!B````OB<!`&(`
M```A*`$`1@```(0H`0`%````RR@!`!P```#1*`$`!P```.XH`0`-````]B@!
M``P````$*0$`$0```!$I`0`.````(RD!`#@````R*0$`-@```&LI`0`3````
MHBD!`!4```"V*0$`"0```,PI`0`)````UBD!``@```#@*0$`$@```.DI`0`L
M````_"D!``T````I*@$`%````#<J`0`4````3"H!`!L```!A*@$`+P```'TJ
M`0`5````K2H!``\```##*@$`%````-,J`0`0````Z"H!`"4```#Y*@$`(0``
M`!\K`0`=````02L!`"````!?*P$`#P```(`K`0!5````D"L!`#D```#F*P$`
M*````"`L`0`)````22P!`!````!3+`$`+P```&0L`0`*````E"P!`!(```"?
M+`$`&0```+(L`0`)````S"P!``P```#6+`$`#0```.,L`0`#````\2P!`!<`
M``#U+`$`#@````TM`0`1````'"T!`!L````N+0$`)0```$HM`0`O````<"T!
M``L```"@+0$`&````*PM`0`9````Q2T!`!T```#?+0$`&P```/TM`0`3````
M&2X!`!0````M+@$`(@```$(N`0`5````92X!`!<```![+@$`(````),N`0`(
M````M"X!``@```"]+@$`#P```,8N`0`8````UBX!`"<```#O+@$`!P```!<O
M`0`(````'R\!`!(````H+P$`'0```#LO`0`:````62\!`#P```!T+P$`1```
M`+$O`0`%````]B\!``L```#\+P$`.@````@P`0`.````0S`!`!(```!2,`$`
M0P```&4P`0`H````J3`!`"T```#2,`$`,``````Q`0`S````,3$!``\```!E
M,0$`"0```'4Q`0`)````?S$!`!D```"),0$`'0```*,Q`0`T````P3$!`"H`
M``#V,0$`$````"$R`0`4````,C(!``@```!',@$`#P```%`R`0`7````8#(!
M`!P```!X,@$`!0```)4R`0`M````FS(!``T```#),@$`"````-<R`0`M````
MX#(!`!(````.,P$`#@```"$S`0`&````,#,!``0````W,P$`"@```#PS`0`(
M````1S,!`!````!0,P$`$P```&$S`0`H````=3,!`!,```">,P$`"@```+(S
M`0`4````O3,!``L```#2,P$`!@```-XS`0!,````Y3,!`"@````R-`$`!P``
M`%LT`0`<````8S0!`"0```"`-`$`)@```*4T`0`T````S#0!`"0````!-0$`
M*0```"8U`0"`````4#4!`#<```#1-0$`"P````DV`0`7````%38!``\````M
M-@$`$````#TV`0`/````3C8!`!````!>-@$`#P```&\V`0`/````?S8!``8`
M``"/-@$`&P```)8V`0`7````LC8!``@```#*-@$`!@```-,V`0`.````VC8!
M`%H```#I-@$`"@```$0W`0`3````3S<!`%L```!C-P$`$````+\W`0`2````
MT#<!``\```#C-P$`%0```/,W`0`6````"3@!`"P````@.`$`+P```$TX`0`7
M````?3@!`"(```"5.`$`"````+@X`0`D````P3@!`!4```#F.`$`$0```/PX
M`0`;````#CD!`!<````J.0$`$0```$(Y`0`;````5#D!`!(```!P.0$`&P``
M`(,Y`0`6````GSD!``4```"V.0$`$@```+PY`0`0````SSD!``<```#@.0$`
M#0```.@Y`0`&````]CD!``8```#].0$`#P````0Z`0`&````%#H!``L````;
M.@$`"````"<Z`0`,````,#H!`!8````].@$`"P```%0Z`0`(````8#H!`!D`
M``!I.@$`/@```(,Z`0`K````PCH!`"<```#N.@$`$@```!8[`0`3````*3L!
M`!(````].P$`$P```%`[`0`T````9#L!`$0```"9.P$`(P```-X[`0`0````
M`CP!`#<````3/`$`%````$L\`0`;````8#P!``@```!\/`$`"0```(4\`0`2
M````CSP!`"T```"B/`$`*````-`\`0`P````^3P!`"L````J/0$`)0```%8]
M`0`D````?#T!`!\```"A/0$`/@```,$]`0`H`````#X!`"D````I/@$`+```
M`%,^`0`=````@#X!`"8```">/@$`+@```,4^`0`S````]#X!`"\````H/P$`
M+@```%@_`0`U````AS\!`"0```"]/P$`(@```.(_`0!&````!4`!`!8```!,
M0`$`)````&-``0`L````B$`!`",```"U0`$`&````-E``0#`````\D`!`#$`
M``"S00$`)P```.5!`0`F````#4(!`"8````T0@$`,````%M"`0`>````C$(!
M`"@```"K0@$`)````-1"`0`R````^4(!`#4````L0P$`-0```&)#`0`T````
MF$,!`+4```#-0P$`*@```(-$`0`<````KD0!`",```#+1`$`*P```.]$`0`K
M````&T4!`$X```!'10$`2P```)9%`0`1````XD4!``0```#T10$`!P```/E%
M`0`*`````48!`!D````,1@$`%````"9&`0`5````.T8!`!H```!11@$`&0``
M`&Q&`0`+````AD8!``T```"21@$`#````*!&`0`3````K48!``T```#!1@$`
M$@```,]&`0`+````XD8!`#\```#N1@$`!P```"Y'`0`0````-D<!``(```!'
M1P$`"````$I'`0`(````4T<!`!L```!<1P$`)P```'A'`0`*````H$<!`!0`
M``"K1P$`$P```,!'`0`%````U$<!``\```#:1P$`"@```.I'`0`1````]4<!
M``T````'2`$`$0```!5(`0`.````)T@!`!,````V2`$`%P```$I(`0`?````
M8D@!`!\```""2`$`!P```*)(`0`1````JD@!``\```"\2`$`"````,Q(`0`/
M````U4@!`!<```#E2`$`'P```/U(`0`/````'4D!``\````M20$`*0```#U)
M`0`A````9TD!`#T```")20$`#P```,=)`0`7````UTD!`!D```#O20$`&@``
M``E*`0`^````)$H!`"@```!C2@$`"@```(Q*`0`0````ETH!`"\```"H2@$`
M&0```-A*`0`)````\DH!`#H```#\2@$`-0```#=+`0`(````;4L!``X```!V
M2P$`)@```(5+`0`0````K$L!`"4```"]2P$`*````.-+`0`)````#$P!`!T`
M```63`$`$@```#1,`0`9````1TP!``\```!A3`$`$@```'%,`0`-````A$P!
M`$````"23`$`/@```--,`0`)````$DT!``P````<30$`,````"E-`0`0````
M6DT!`!$```!K30$`"P```'U-`0`1````B4T!`!(```";30$`&@```*Y-`0`;
M````R4T!`"(```#E30$`&0````A.`0`B````(DX!`"0```!%3@$`%0```&I.
M`0`+````@$X!``P```",3@$`#P```)E.`0`F````J4X!`!,```#03@$`"0``
M`.1.`0`,````[DX!`!X```#[3@$`&@```!I/`0`_````-4\!`"<```!U3P$`
M!0```)U/`0`+````HT\!`!<```"O3P$`C@```,=/`0`@````5E`!``4```!W
M4`$`(````'U0`0`6````GE`!`!4```"U4`$`!@```,M0`0`&````TE`!``T`
M``#94`$`#````.=0`0`4````]%`!``P````)40$`)````!91`0`-````.U$!
M``H```!)40$`%@```%11`0`(````:U$!``@```!T40$`&0```'U1`0`B````
MEU$!`",```"Z40$`#P```-Y1`0`X````[E$!`!`````G4@$`!P```#A2`0`0
M````0%(!`!@```!14@$`-P```&I2`0`L````HE(!`"(```#/4@$`'0```/)2
M`0`<````$%,!`",````M4P$`&P```%%3`0!-````;5,!``<```"[4P$`$@``
M`,-3`0`#````UE,!``L```#:4P$`"P```.93`0`-````\E,!``P`````5`$`
M$@````U4`0`.````(%0!`!H````O5`$`&@```$I4`0`4````950!``T```!Z
M5`$`#P```(A4`0`2````F%0!`"4```"K5`$`!@```-%4`0`*````V%0!``T`
M``#C5`$`#@```/%4`0`$`````%4!``4````%50$`!@````M5`0`8````$E4!
M``\````K50$`!0```#M5`0`J````054!`!@```!L50$`!@```(55`0`(````
MC%4!``\```"550$`"@```*55`0`,````L%4!``8```"]50$`"@```,15`0`"
M````SU4!``<```#250$`&@```-I5`0`7````]54!`!4````-5@$`(0```"-6
M`0`#````158!``<```!)5@$`$P```%%6`0`4````958!``T```!Z5@$`#```
M`(A6`0`N````E58!``@```#$5@$`"P```,U6`0`0````V58!``@```#J5@$`
M!@```/-6`0`5````^E8!`!$````05P$`+@```")7`0`6````45<!``8```!H
M5P$`#P```&]7`0`/````?U<!``D```"/5P$`+````)E7`0`$````QE<!``<`
M``#+5P$`)@```--7`0`&````^E<!``H````!6`$`%0````Q8`0`=````(E@!
M``0```!`6`$`+````$58`0`-````<E@!``T```"`6`$`$0```(Y8`0`0````
MH%@!``T```"Q6`$`+P```+]8`0`/````[U@!`!````#_6`$`+0```!!9`0`2
M````/ED!`!,```!160$`"@```&59`0`\````<%D!`",```"M60$`'P```-%9
M`0`D````\5D!``<````66@$`"````!Y:`0`,````)UH!`"T````T6@$`*P``
M`&):`0!!````CEH!``L```#06@$`#````-Q:`0`A````Z5H!`"T````+6P$`
M%@```#E;`0`+````4%L!`!4```!<6P$`#@```');`0`0````@5L!`!4```"2
M6P$`$0```*A;`0`\````NEL!`(P```#W6P$`=@```(1<`0`6````^UP!``L`
M```270$`$@```!Y=`0`3````,5T!`!````!%70$`!P```%9=`0`(````7ET!
M`!D```!G70$`$0```(%=`0`5````DUT!`!4```"I70$`#@```+]=`0`5````
MSET!`!\```#D70$`(0````1>`0!R````)EX!`!$```"97@$`$@```*M>`0`+
M````OEX!``L```#*7@$`%````-9>`0`0````ZUX!``\```#\7@$`%0````Q?
M`0`4````(E\!`"8````W7P$`*@```%Y?`0`G````B5\!`"<```"Q7P$`*@``
M`-E?`0`K````!&`!`!X````P8`$`3````$]@`0`4````G&`!`!0```"Q8`$`
M%````,9@`0`4````VV`!`!(```#P8`$`&`````-A`0`8````'&$!`!4````U
M80$`%0```$MA`0`[````86$!`!D```"=80$`&@```+=A`0`T````TF$!`!0`
M```'8@$`"````!QB`0`.````)6(!`"\````T8@$`'@```&1B`0`3````@V(!
M``\```"78@$`&0```*=B`0`;````P6(!`!<```#=8@$`$P```/5B`0`:````
M"6,!`"$````D8P$`&@```$9C`0`5````86,!`!L```!W8P$`(0```)-C`0`;
M````M6,!`!L```#18P$`%````.UC`0`&`````F0!``H````)9`$`!P```!1D
M`0`'````'&0!``P````D9`$`%P```#%D`0`3````260!`!4```!=9`$`$@``
M`'-D`0`5````AF0!`!0```"<9`$`%0```+%D`0`8````QV0!`!8```#@9`$`
M+0```/=D`0`4````)64!``X````Z90$`$P```$EE`0`2````764!``X```!P
M90$`#@```']E`0`.````CF4!`#D```"=90$`!@```-=E`0`.````WF4!`!,`
M``#M90$`!P````%F`0`3````"68!``X````=9@$`$0```"QF`0`4````/F8!
M`",```!39@$`*@```'=F`0`E````HF8!``4```#(9@$`!P```,YF`0`I````
MUF8!``@`````9P$`%`````EG`0`/````'F<!``H````N9P$`$@```#EG`0`'
M````3&<!`!<```!49P$`-0```&QG`0`)````HF<!``P```"L9P$`*````+EG
M`0`6````XF<!`!8```#Y9P$`#0```!!H`0`Q````'F@!``H```!0:`$`#```
M`%MH`0`-````:&@!``D```!V:`$`!P```(!H`0`&````B&@!`!(```"/:`$`
M1P```*)H`0`0````ZF@!``8```#[:`$`#@````)I`0`%````$6D!``8````7
M:0$`%P```!YI`0`7````-FD!`!8```!.:0$``@```&5I`0`&````:&D!``P`
M``!O:0$`$````'QI`0`6````C6D!`#T```"D:0$`"@```.)I`0`:````[6D!
M``\````(:@$`!P```!AJ`0`$````(&H!`#(````E:@$`-@```%AJ`0`4````
MCVH!`!H```"D:@$`&0```+]J`0`H````V6H!`"<````":P$`#0```"IK`0`%
M````.&L!`!(````^:P$`%@```%%K`0`5````:&L!`!8```!^:P$`%P```)5K
M`0`?````K6L!``0```#-:P$`"@```-)K`0`0````W6L!`!$```#N:P$`!@``
M``!L`0!B````!VP!`!````!J;`$`#P```'ML`0`0````BVP!`!H```"<;`$`
M2@```+=L`0`'`````FT!`!L````*;0$`!P```"9M`0`&````+FT!``D````U
M;0$`*@```#]M`0`I````:FT!``D```"4;0$`!P```)YM`0`B````IFT!`&0`
M``#);0$`&P```"YN`0`C````2FX!`!H```!N;@$``@```(EN`0`8````C&X!
M``<```"E;@$`%P```*UN`0`/````Q6X!``T```#5;@$`#@```.-N`0`'````
M\FX!`!<```#Z;@$`#@```!)O`0`+````(6\!``\````M;P$`#````#UO`0`+
M````2F\!``L```!6;P$`"P```&)O`0`G````;F\!`!````"6;P$`$0```*=O
M`0`8````N6\!`"4```#2;P$`#P```/AO`0`5````"'`!``\````><`$`!0``
M`"YP`0`3````-'`!``8```!(<`$`!````$]P`0`-````5'`!``H```!B<`$`
M#````&UP`0`3````>G`!`!X```".<`$`$P```*UP`0`#````P7`!`!L```#%
M<`$`!P```.%P`0`.````Z7`!``P```#X<`$`$0````5Q`0`#````%W$!`#H`
M```;<0$`.P```%9Q`0`>````DG$!`"4```"Q<0$`*0```-=Q`0`5`````7(!
M`$(````7<@$`0@```%IR`0`K````G7(!`#````#)<@$`/@```/IR`0`^````
M.7,!`#\```!X<P$`+P```+AS`0!$````Z',!`#0````M=`$`$P```&)T`0`4
M````=G0!`!0```"+=`$`%@```*!T`0`7````MW0!`!$```#/=`$`$P```.%T
M`0`5````]70!`"(````+=0$`%@```"YU`0`D````174!`!0```!J=0$`%```
M`']U`0`M````E'4!`"8```#"=0$`)````.EU`0`2````#G8!`$`````A=@$`
M1````&)V`0`2````IW8!``8```"Z=@$`'@```,%V`0`1````X'8!``@```#R
M=@$`"````/MV`0`3````!'<!`!4````8=P$`#@```"YW`0`1````/7<!``H`
M``!/=P$`%0```%IW`0!/`0``<'<!``L```#`>`$`'P```,QX`0`,````['@!
M`#\```#Y>`$`"0```#EY`0`'````0WD!`!(```!+>0$`#@```%YY`0`K````
M;7D!``\```"9>0$`-P```*EY`0`+````X7D!`!<```#M>0$`)P````5Z`0`)
M````+7H!``D````W>@$`$````$%Z`0`'````4GH!``X```!:>@$`-P```&EZ
M`0`:````H7H!`"4```"\>@$`@P```.)Z`0`7````9GL!`$H```!^>P$`*@``
M`,E[`0`3````]'L!`!<````(?`$`"````"!\`0`,````*7P!``\````V?`$`
M$@```$9\`0`*````67P!`!````!D?`$`"````'5\`0`;````?GP!`!@```":
M?`$`!````+-\`0`1````N'P!`!D```#*?`$`*@```.1\`0`4````#WT!`!P`
M```D?0$`$@```$%]`0`J````5'T!``L```!_?0$`"P```(M]`0`+````EWT!
M``<```"C?0$`!P```*M]`0`S````LWT!``T```#G?0$`+@```/5]`0`6````
M)'X!``@````[?@$`"0```$1^`0`>````3GX!`!H```!M?@$`"@```(A^`0`;
M````DWX!``@```"O?@$`%@```+A^`0`(````SWX!``<```#8?@$`'P```.!^
M`0`P`````'\!``T````Q?P$`)0```#]_`0`:````97\!`!,```"`?P$`%@``
M`)1_`0`*````JW\!``@```"V?P$`"P```+]_`0`.````RW\!``L```#:?P$`
M(@```.9_`0!`````"8`!`$(```!*@`$`'0```(V``0`N````JX`!`"<```#:
M@`$`3`````*!`0`:````3X$!`"````!J@0$`+````(N!`0`=````N($!`!X`
M``#6@0$`*@```/6!`0`U````(((!`'$```!6@@$`60```,B"`0`U````(H,!
M`"P```!8@P$`)P```(6#`0`6````K8,!`!P```#$@P$`.@```.&#`0`X````
M'(0!`"P```!5A`$`,P```(*$`0`[````MH0!``P```#RA`$`!0```/^$`0`@
M````!84!``<````FA0$`#0```"Z%`0`J````/(4!`!(```!GA0$`%0```'J%
M`0`1````D(4!`!````"BA0$`"````+.%`0`5````O(4!``X```#2A0$`$0``
M`.&%`0`.````\X4!`!P````"A@$`00```!^&`0`'````888!`!L```!IA@$`
M#````(6&`0`/````DH8!``4```"BA@$`"````*B&`0`2````L88!`#\```#$
MA@$`60````2'`0`H````7H<!`"L```"'AP$`(@```+.'`0`@````UH<!``4`
M``#WAP$`$````/V'`0`&````#H@!`"D````5B`$`&P```#^(`0`W````6X@!
M``@```"3B`$`#@```)R(`0`/````JX@!`!4```"[B`$`'@```-&(`0`0````
M\(@!`$D````!B0$`#````$N)`0`H````6(D!``\```"!B0$`$P```)&)`0`2
M````I8D!`"4```"XB0$`1````-Z)`0`V````(XH!``P```!:B@$`00```&>*
M`0`Y````J8H!`#H```#CB@$`-@```!Z+`0!,````58L!`$L```"BBP$`3@``
M`.Z+`0!(````/8P!`$T```"&C`$`3@```-2,`0!(````(XT!`$T```!LC0$`
M3@```+J-`0!(````"8X!`$T```!2C@$`30```*".`0!'````[HX!`$P````V
MCP$`2P```(./`0!%````SX\!`$H````5D`$`20```&"0`0!(````JI`!`$X`
M``#SD`$`2````$*1`0!-````BY$!`!$```#9D0$`%P```.N1`0`)`````Y(!
M``X````-D@$`%@```!R2`0`,````,Y(!`!<```!`D@$`&P```%B2`0`)````
M=)(!`!<```!^D@$`$0```):2`0`L````J)(!``D```#5D@$`!0```-^2`0`1
M````Y9(!``P```#WD@$`%`````23`0`%````&9,!``\````?DP$`$P```"^3
M`0`0````0Y,!`!$```!4DP$`$0```&:3`0`(````>),!``<```"!DP$`00``
M`(F3`0`Q````RY,!`#(```#]DP$`"````#"4`0`>````.90!`!T```!8E`$`
M*P```':4`0`,````HI0!``L```"OE`$`"````+N4`0`,````Q)0!``(```#1
ME`$`%````-24`0`1````Z90!`!$```#[E`$`"@````V5`0`-````&)4!``\`
M```FE0$`$P```#:5`0!F````2I4!`!X```"QE0$`-0```-"5`0`(````!I8!
M``D````/E@$`$@```!F6`0`3````+)8!`!<```!`E@$`#P```%B6`0`7````
M:)8!`!L```"`E@$`%@```)R6`0`4````LY8!`!P```#(E@$`'0```.66`0`9
M`````Y<!`(4````=EP$`(P```*.7`0`L````QY<!`"T```#TEP$`'````"*8
M`0`D````/Y@!`"(```!DF`$`'@```(>8`0`7````II@!`"8```"^F`$`'0``
M`.68`0`,`````YD!``P````0F0$`"P```!V9`0`1````*9D!`!D````[F0$`
M!````%69`0!@````6ID!`$````"[F0$`2````/R9`0`B````19H!`$(```!H
MF@$`>````*N:`0`'````))L!`"P````LFP$`-@```%F;`0`&````D)L!`!``
M``"7FP$`$0```*B;`0!!````NIL!``@```#\FP$`40````6<`0!`````5YP!
M`"\```"8G`$`$0```,B<`0`K````VIP!`",````&G0$`+0```"J=`0`F````
M6)T!`"X```!_G0$`)P```*Z=`0`:````UIT!``H```#QG0$`,0```/R=`0`0
M````+IX!`"@````_G@$`"````&B>`0`4````<9X!``<```"&G@$`$@```(Z>
M`0`W````H9X!`!\```#9G@$`$@```/F>`0`/````#)\!`!`````<GP$`(0``
M`"V?`0`O````3Y\!`!,```!_GP$`!P```).?`0`3````FY\!``0```"OGP$`
M&P```+2?`0`/````T)\!``\```#@GP$`$````/"?`0`(`````:`!``8````*
MH`$`#````!&@`0`2````'J`!``D````QH`$`$0```#N@`0`.````3:`!``X`
M``!<H`$`#````&N@`0`D````>*`!``H```"=H`$``@```*B@`0`=````JZ`!
M``0```#)H`$`)````,Z@`0`(````\Z`!`&P```#\H`$`"@```&FA`0`(````
M=*$!`",```!]H0$`0````*&A`0`7````XJ$!`"8```#ZH0$`40```"&B`0`L
M````<Z(!`#L```"@H@$`%P```-RB`0`3````]*(!`!$````(HP$`!P```!JC
M`0`$````(J,!``<````GHP$`#````"^C`0`)````/*,!``0```!&HP$`!@``
M`$NC`0`+````4J,!``H```!>HP$`!P```&FC`0`L````<:,!``8```">HP$`
M)0```*6C`0`'````RZ,!`!````#3HP$`$````.2C`0`4````]:,!``<````*
MI`$`"````!*D`0`3````&Z0!`!$````OI`$`'P```$&D`0`+````8:0!``T`
M``!MI`$`&P```'ND`0`3````EZ0!`!L```"KI`$`$@```,>D`0`'````VJ0!
M``P```#BI`$`$0```.^D`0`/`````:4!``(````1I0$`,````!2E`0`I````
M1:4!`"L```!OI0$`*@```)NE`0`E````QJ4!`'D```#LI0$`$@```&:F`0`H
M````>:8!`$P```"BI@$`-````.^F`0!7````)*<!`%(```!\IP$`(0```,^G
M`0`Z````\:<!`"D````LJ`$`+P```%:H`0`U````AJ@!`#$```"\J`$`(```
M`.ZH`0!`````#ZD!`/`!``!0J0$`'````$&K`0`6````7JL!`$<```!UJP$`
M*0```+VK`0"`````YZL!`$,```!HK`$`/@```*RL`0!J````ZZP!`&D```!6
MK0$`F@```,"M`0`A````6ZX!`!,```!]K@$`'@```)&N`0`?````L*X!`"0`
M``#0K@$`(0```/6N`0`L````%Z\!`"4```!$KP$`'````&JO`0`2````AZ\!
M`#D```":KP$`*P```-2O`0`U`````+`!`"0````VL`$`(0```%NP`0!`````
M?;`!`&L```"^L`$`,````"JQ`0`P````6[$!`$0```",L0$`+P```-&Q`0`D
M`````;(!`#0````FL@$`?````%NR`0!5````V+(!`$@````NLP$`0@```'>S
M`0`Y````NK,!`#T```#TLP$`.````#*T`0!&````:[0!`%4```"RM`$`<@``
M``BU`0!P````>[4!`%D```#LM0$`&````$:V`0`[````7[8!`"(```";M@$`
M+0```+ZV`0`L````[+8!`"P````9MP$`,0```$:W`0!H````>+<!`&4```#A
MMP$`LP```$>X`0`9````^[@!`"P````5N0$`2````$*Y`0`V````B[D!`%T`
M``#"N0$`,P```""Z`0!:````5+H!`,@```"ON@$`W0```'B[`0"#````5KP!
M`",```#:O`$`#@```/Z\`0#`````#;T!`*\```#.O0$`20```'Z^`0`P````
MR+X!`)H```#YO@$`0P```)2_`0`E````V+\!`"0```#^OP$`"0```"/``0`#
M````+<`!`!0````QP`$`"@```$;``0`,````4<`!``8```!>P`$`$0```&7`
M`0`$````=\`!`'4```!\P`$`!@```/+``0`7````^<`!``4````1P0$`!@``
M`!?!`0`3````'L$!``L````RP0$`%````#[!`0`/````4\$!``(```!CP0$`
M'````&;!`0`@````@\$!`!4```"DP0$`3````+K!`0`6````!\(!`"4````>
MP@$`0P```$3"`0`X````B,(!`#D```#!P@$`&````/O"`0`N````%,,!`"(`
M``!#PP$`(````&;#`0`H````A\,!`",```"PPP$`(0```-3#`0`G````]L,!
M`"`````>Q`$`,P```#_$`0`P````<\0!`!P```"DQ`$`/P```,'$`0`A````
M`<4!`#4````CQ0$`*````%G%`0`C````@L4!`#H```"FQ0$`+@```.'%`0`L
M````$,8!`"$````]Q@$`)````%_&`0`H````A,8!`"\```"MQ@$`(P```-W&
M`0`I`````<<!`#4````KQP$`1@```&''`0`Z````J,<!`"@```#CQP$`+```
M``S(`0`K````.<@!`"P```!ER`$`)@```)+(`0`A````N<@!`"\```#;R`$`
M)@````O)`0`R````,LD!`"L```!ER0$`#@```)')`0`/````H,D!`"(```"P
MR0$`(0```-/)`0`Y````]<D!`#$````OR@$`$0```&'*`0`A````<\H!``<`
M``"5R@$`!P```)W*`0`B````I<H!`"4```#(R@$`'P```.[*`0`>````#LL!
M``<````MRP$`!P$``#7+`0`1````/<P!`!H```!/S`$`"0```&K,`0`,````
M=,P!`"````"!S`$`$````*+,`0`1````L\P!`"0```#%S`$`"````.K,`0`U
M````\\P!`!H````IS0$`&0```$3-`0`3````7LT!`"8```!RS0$`"0```)G-
M`0`V````H\T!`"\```#:S0$`$@````K.`0`/````'<X!``X````MS@$`-P``
M`#S.`0`5````=,X!`!8```"*S@$`#````*'.`0`A````KLX!``T```#0S@$`
M#@```-[.`0`'````[<X!`!0```#US@$`'`````K/`0`(````)\\!`#0````P
MSP$`"@```&7/`0`7````<,\!``4```"(SP$`&@```([/`0`)````J<\!`#L`
M``"SSP$`!@```._/`0`/````]L\!`!,````&T`$`#@```!K0`0`'````*=`!
M``D````QT`$`"P```#O0`0`?````1]`!``\```!GT`$`$@```'?0`0`1````
MBM`!``D```"<T`$`"@```*;0`0`:````L=`!``<```#,T`$`,P```-30`0`-
M````"-$!``(````6T0$`"P```!G1`0`+````)=$!`!(````QT0$`#P```$31
M`0`_````5-$!`#L```"4T0$`)P```-#1`0`E````^-$!``P````>T@$`4P``
M`"O2`0`&````?](!`!4```"&T@$`10```)S2`0`1````XM(!``X```#TT@$`
M!P````/3`0`8````"],!``<````DTP$`"````"S3`0`%````-=,!``\````[
MTP$`!P```$O3`0`2````4],!`!$```!FTP$`!0```'C3`0`:````?M,!`"$`
M``"9TP$`'P```+O3`0`C````V],!`!$```#_TP$``@```!'4`0`$````%-0!
M``8````9U`$``P```"#4`0`,````)-0!`&4````QU`$`&P```)?4`0`X````
ML]0!`"$```#LU`$`4P````[5`0`2````8M4!`$8```!UU0$`(0```+S5`0`^
M````WM4!`",````=U@$`00```$'6`0`X````@]8!`#$```"\U@$`,````.[6
M`0`P````']<!`#````!0UP$`,0```('7`0`L````L]<!`#````#@UP$`00``
M`!'8`0`;````4]@!`!P```!OV`$`$0```(S8`0`2````GM@!`'T```"QV`$`
M#````"_9`0!W````/-D!`'0```"TV0$`B````"G:`0`Q````LMH!`&(```#D
MV@$`%0```$?;`0`?````7=L!`!0```!]VP$`(P```)+;`0!$````MML!`"$`
M``#[VP$`%````!W<`0!4````,MP!`!X```"'W`$`(P```*;<`0`A````RMP!
M`!4```#LW`$`(@````+=`0`N````)=T!`!(```!4W0$`"@```&?=`0`0````
M<MT!``8```"#W0$`!P```(K=`0`4````DMT!``<```"GW0$`!@```*_=`0`8
M````MMT!``@```#/W0$`#P```-C=`0`5````Z-T!``D```#^W0$`$P````C>
M`0`'````'-X!`!`````DW@$`"@```#7>`0`&````0-X!``L```!'W@$`!@``
M`%/>`0`9````6MX!``(```!TW@$`!0```'?>`0`,````?=X!``@```"*W@$`
M,0```)/>`0`%````Q=X!`!4```#+W@$`&P```.'>`0`-````_=X!``H````+
MWP$`#@```!;?`0`1````)=\!`!8````WWP$`"````$[?`0`.````5]\!``4`
M``!FWP$`*P```&S?`0`+````F-\!``<```"DWP$`#@```*S?`0`-````N]\!
M``$```#:!```@P(``$L"``"J`0``3@(``*\%`````````````(($```W````
M`````'0#``"#````;@(``!<%````````:`(``'X%``#6!0``\P0``)H```""
M!0```````)````"I`0``C@0``.@```!L!0``%@,``*4"``">!```````````
M````````(`4``$@$``#@`P``XP```)0!``#X!0````````````!'````IP``
M`.$#``"%`P``[P```)@%``!U!0``_@4``,L!```R`@``AP$``"<!````````
M/P,``-`"``"I!0``>P```&L!```O!```%0,``#D```">`0``504```````"M
M`0``+P,``%L``````P``$@$``*H"``#B`0````````````"G`0``UP4``+L`
M``"H``````````````#J`````````,@!``"K!```"08``.4!``#P`0``-P4`
M``````#M!```%P,`````````````N`,``.0````@`P```````(,!```D`P``
M"@4``$\!```K!0```````#L#``"[`@``F@4`````````````M@$`````````
M````Q`4```````".`0``Z@4``,4"``"&`0```````,@"``#)!```````````
M``#O`P``/@0```````!U`0``FP$``*,#``!\!0``S0$````````;````````
M`#T!````````YP4````````=!```NP0``#L$``"I`@````````````"V`P``
M`````-P%```Z````-@0``"4$``#&!```N@(``%P!``#J`0``4````/4%``#R
M!0``C@4``)P%``"+`0``(@0```````#;`@``(`(````````S!```N`$``'(%
M``#N!0``>04``&D#``#B!```_@````````#H`P```````,H#```1`P``````
M`*T$``"Q`0``H`(```,$```.`0``5`,``#8"````````=P$``*8"``!3!```
ME`0``(L$``#+````U@,``*0```#X`0``O`(````````:`@``SP,``'(#````
M````#0,```````"5`0``1P$``"$"`````````````*(%```;`0``E0,`````
M``#H!0``:0(`````````````4@0``/8$``!,`@``,04```````!N````````
M`+`"``!``P``<@0``(@$``!Z`@``/`(```````!G`P``QP4``",#``#"````
MD0,``-X```#4!```WP4````````/!0``104``%$$````````X0```,8!````
M````/00``%,#`````````````,T```#K`P```````*\!``#O!0``I@```-4"
M``"J`P```````(8"``!%````!0$```````!E!0``R0(```````!.!```7@4`
M``````#*`````````&4"``#;`P``EP,``%0$``#,`P``CP,``"(`````````
M]P(```````!X````S@(``-8"``#*!0``'P0``*P!`````````````.$!``"?
M`0``````````````````8@```,L"``"@!0``#@````````"5`@``%0```"8#
M``"-!0``<P0``"4``````````````$H"````````]`````````!3`0``;P$`
M`,0!``#[````D0$``'`````3````*00``*X!````````9P0``+@$````````
M#P,```````!=````BP,``/H"``!1````Y@,``,0"``#``P```````/D%```5
M!0``E04```````"Y`P````````H!``#;!0``R`,``'X#````````L0,``&$%
M``#K!```80```*P#````````TP0``-0"``![`0``7@0`````````````JP,`
M`*(`````````GP(``&(#````````0P```(8#```U!```:@4```D```"2!```
MP0```$T"````````TP`````````W`0````````````!0!0``)@0```````!J
M````1@(``#X%```(!0``F0,``&,```"Y!```^`0``"@$````````:`$``&T%
M``#&`@``]`(``,8```"3!```F00``$L%``!P`@``6P(``',#``#I`0``#P(`
M````````````1P0```````!C`@``20,``+D%``!;!0``[`0```````"U`@``
MF@$``)0`````````"@8``$P`````````S@4``.T"```J!0``\@$``/$%``!G
M````+@4``"(!``!-!0``Y0(``(\!``"_!```)`$``*H$````````V`$`````
M``!3`@```````-X%```(`0```````&H#``"_!0``-P(``'0"``!7`P``+00`
M``````#C!0``;0(``-H%``!)````'`4`````````````(P(```````!T!```
M_@0``&<%````````W@$``$\#````````;@4``+0!```,`P``7`(``!,$```&
M!0``MP0```@&```Z!0``L@,``)P$```2!```P00``-D#``!W`@```````-8`
M``!+````[@$``/,!````````)0$``"@!``!0`P``N0$``,`$``!H!```#0``
M`$`!``#%`P``BP(``-X#``#4!0``60$``&8#```'`P``+0$```````"%````
M`````,4!``"Z`P``.P```#4!````````+0,```T"``!)`0``"P0``$8$``!P
M`P``````````````````T`$``+<%``#5!0``&@$``+`!``#>`@``?P4``(T"
M``"2`P``_P0``*T#```2``````````````#\`P``SP$``"$#``!]````!0,`
M`-(%``"_````F04``&,$````````C`$``+,!```R`P``5P$``(D"``!V`@``
MS0(``$,#````````Z00``$X```"M`@``<`0```````""`@``=0(``"D#````
M````;`$``!8!``#2````Y@4``($$``".`@```````($!``!K`P```````,4`
M```5`0``U````(0"``#,!```````````````````'@$``#X"````````3`0`
M`#`!``#B````TP$```````![!```G0(``/8!````````PP0``&$!````````
MH04``#D$```%!0```````($%``"E````>00``.0#````````.`(`````````
M````#04``*L```"[`0``2P0``$0```"R`@``)0,```0&``"C!```L`0``/\`
M`````````````(P$```0`P``UP```"P#````````5`4```````#S`P```08`
M`%,%``#"`@``G`(``,H!``#!`0``[`$``#(%```;`P```````.@!````````
M_P$``+0`````````"@0``%H$``!)`@``RP4``'D"````````*`(``*("````
M`````P(``+T#``"N`@``_P(```````````````$``+P`````````T`0``.(#
M```K`@``+P4``*H%````````V0(```````![`P``@`,``"X```!(`@``IP(`
M`/,```"2!0```````/T%``#,!0``@`4``````````````````/P%``!X`P``
M`````/`$``!6!```=`4``#0$````````F0(```````!H````B0$`````````
M`````````'8!``"G!0``^0````X"``#M````O04``/L#``"E!0``S@,`````
M``"%`0``W0$``&P"``!]`P``L00``#0"```G`P````````````#E````E`(`
M`!P$```D`@``P@$```(```#$`P``X`4``)D!````````Z@(``#,!```D!```
M?0$``$H%``````````````````!<!````````%$#``"R!````````/4$````
M````00```*X%``"1`@``#P````````#5`P````````````#P!0``$`4``"L$
M````````8P$```````"L`@``>`0```````#=`P``@@$```(&````````N```
M`,,```"B`0```````'\```````````````````!:`@``5`$```````#T`P``
MG00``*H````>`P``/0```/L!``!'`P```04``+,#``!7!0``W0````````#G
M`0```````#0!``!X`@``GP0``(@"````````^@4``$@#```!`0``G`$`````
M``#K!0``\P(``-L!``!*`P``+P(```````#5!```W`,`````````````A`,`
M`'H$````````R0,``!,#```J`0``5P(````````P`@``XP$``!T```#?`@``
M`````,D```";`@```````/D!```H`P```````"D````/!`````4``/X!``"V
M!```#@4``+<#```8`0``H0$``'@!````````1`(``+D"``#K`@```````/<`
M``#%!0```````!<```#<`@``9`(``'<```!Z````_`0```````"^````````
M`)\``````````````!$```#E`P``&04```````````````8``#`$``"*````
M_00``#P%``!8!0``<@(``#$$`````````````*T```#B!0```````%X```!2
M!0```````.8$``">`P``"0,``(0%``!;!```7P(``"L!```&````H@0``.8"
M```)!````````(H%``"#`P``?`(``+H`````````U0``````````````````
M````````````Y`$``%(`````````7@(``!P!``":!```T`4```````#?````
M:@0``%D"``!Q`P```````/4``````````````.D#``!+`P``,@0``/8#```V
M!0```````!D$``#V`@``GP4```````![!0``_P4``-<$``!1`0```````*D$
M``!H!0``>P(``"`$``!#`@``GP,``)<!````````/04``$\$``#M!0``8P,`
M`%D#``!8`P``6P,``($```!K````+````"8!```+!0``;0$```````!K!0``
M`````)8!````````-0,```````!M`P``Q````.,#``"\!````````/X#````
M````*@0``"`````N`@```````"D"```G`@```````'X!``"W`0``Y`4`````
M```P!0```````)P#````````;``````````Y!0``PP(``%T%````````>0,`
M`'8#``!\````?0(``.````#Y`P```````$P%``"Q!0``LP0``*0#````````
M`````&X!``#;!```"@```/$```"Z!0```````-$#`````````````/0$````
M````AP```*@$```&!````````"8"``##`0``5````!8"```6!```7P4``"<`
M``!4`@``O@$``(0$``!D!0``"P8```8"``!?`0``7P0`````````````<P``
M`!(%``":`P``B`4``!("``!&````LP(``"L#``````````````````!F````
M404``+H$``#"!````````!X```!I!0``5@,``(<"``#I````?`$``+X%``#A
M!0``M@````````"*`0``QP(``'\"```\`P``\````(H$``"D!```&0,``.X`
M``!9!0``'P(```````"C`0``O00``/8`````````D@``````````````8`0`
M`&,%````````````````````````]0,``'\!```C````9`,``(0`````````
MKP````````!2`@``5@````$$````````3@,``$D%``````````````````!`
M````.`,```P"```T`P````````````"7````)04````````$!0``+0```#L%
M```_````FP4``'8````C!0``/P(``*`#``"%`@````````````#C`@``S`$`
M``````#.`0``U@0``-D$````````10$```````#)`0``4@,```````"!`P``
MY@`````````%!@``WP0``.L```"@!`````````($```8`P``````````````
M````*````!X%``#H`@```````.D%```Z`0``O@0``&4#``!!`0``-@$`````
M```\`0``W`$```````#%!```.`0``/$$```_`0``"`(```<&``#M`P``.0,`
M`!`!```7`0``-P,``/(````Q`0``4`0```,!```Z`P````````````!O!0``
MO0````````#L!0``J`,```````#W!```FP,``#8#````````O`4``'\#``"`
M````C@,``/P```"0!```\0$```````#Z`0```````$($````````W04``#@%
M``!6`@``L@$```````"H!0``V@```)$$``"A`@``AP0````````)`@``````
M`.H#``!H`P``T0(``'$!```=`P```````,$#``!Q!0```P,``!H%``#'`P``
M``````````">````W@0``'4```#]`@``4@$``*,%``#?`0````````X#``#Q
M`@``!P``````````````BP````````!:`P``M0``````````````[P$`````
M````````6`(``%H%``#C!```/P0``!`$``"9````SP```#D"```3!0``*04`
M``````"A!```!@8```````!\`P``MP```!0!``!T`0``=P0`````````````
M1@4``#`````>`@```````*D#``#G`P``"P(`````````````9`$````````$
M`@`````````````9`0``]P,``(8%``!Q`@``'`(``+H!``!B!0``0@```'`!
M``#8!0``.@0```````#N`P``\@(``/T!``!S!0``K@```&D!```O`0``3`,`
M`*4!``"H`@```````.0$```+````50````````#8!```"`,``#,"````````
M8`4``+8"````````B04``+0$```;!```?00``$\````A`0``'````"(%``"K
M!0```````#X```"=`0``>@,``.P"``"8`P``"P,``',"``"2`@``^0(`````
M``"G`P``(@,``&D````#!@``X`(````````L!0``(0`````````0````````
M`&\"``#,`@```@4`````````````B`,```<"````````O`,``-@````&`0``
M,0````````!E`0```````-($``!\!```:00``)X"``"/!```A@0``%`!````
M````U0$`````````````8@0```````!>`0``I@$``+`%````````````````
M````````,0,``,P`````````UP,``'8%``#8`@```````+4$``#V!0``'`,`
M`%X#``````````````P%```C`0``&`(``*L!``!$!0``80(``+T"``"6`P``
M+04```````!S`0``,@```"P!```X````%`0``%L!`````````````#(!``#+
M`P``L0`````````%!```%`4``````````````````!$$````````U`,``!4$
M``!O`P```````$(!``"#!```PP4``*\#``"5````DP`````````D````````
M`(`"``!F!```;00````````B`@``H0```#\%``#1!0``IP0```D%``"L!```
MB````%<```#S!0```````&(!```&`P``7P,```P`````````&P4``&\````N
M`0``?@```#T"````````P````/H`````````^`,``/D$````````#0$``#@!
M``"=`````````+````"+!0``+`0``%H!``#$!```NP4```````#-!```2@0`
M`&P#``!(!0```````!0"```T````9P(``*X#````````D04``*@!````````
MT0$``.<"``"Y````HP(``/T```"-`0``7`,```````#<!```DP4``)<"``"%
M!0``F@(``!@$``#3`@```````-<"``!'!0``*@```,,#``#1!```P0(``&<!
M```O`````````#D!``"`!```M`(``,<```#7`0``SP4``(P`````````/`0`
M``````#``@``9`````0!```"`@``_0,``"P"``!5`P``!`0``(X```#1````
MI@4`````````````%`,``)P```!@`P``7`````T$``!!`P```````'H%````
M``````````````",`P``<`4``!H$```?````W````&\$``#P`@```````&8!
M````````G0,``!<$``!,`0``30```.<```"5!`````````\!````````````
M`'0````*`@``HP```-D%````````<0`````$``"U`P``*@(```````"0!0``
MCP````````"/`@``'0$``!\%````````MP(```````!*`0``M`,``-,#```[
M`0``]`$```````!@`0``I`$``!(#```T!0``@0(``$$$``"E`P``Y04``%8!
M``"@````9@4````````D!0``\0,``+L#`````````````*\"````````3P(`
M`-H"``#G!`````(````````N`P``"`0``$8#```C!````````.H$````````
MA`$``.$$``#\`0```````$T#```]`P``?@0``$4#```'`0``10(```L!``!6
M!0``#@0``/@"`````````P4``/(#``!=!```\`,``*8#``!/!0``70,``!H#
M``!-!```G04```H#``!U`P```P```,L$````````P04``%\`````````'0(`
M`,(#````````&P(```````"R!0``R`4``-(!````````DP$``*\$````````
M-0```&0$``"6``````````````"_`0``80,``.\$````````,P```.\"``!9
M!```DP(``#X#``#&`P``^@,``/<!``"R`````````%4"``#(````%````*(#
M``!R`````````$,%``!:``````````````"S!0``40(``!<"````````@@,`
M`%<$``!"`@```````)<$``#;``````````$"``!Q!```W0(`````````````
M)P4``/<%``!K`@``!P0``-(#``";````900`````````````X`$```````#`
M!0``>@$``,<!``!``@````````````"'!0````````````!'`@````````P$
M``````````````````#.`````````&```````````````+4!``#R!```OP,`
M`````````````````'<#``!8`0``/@$```````#-`P`````````````1`0``
MN`(``,<$``#-!0````````````#3!0```````$@!``!%!```D`(``(,%``"E
M!```4P```)0%```N!```-04``%4$``#[`@```````.("``"^`P```````.D"
M``#&!0``C`4``#,#``#^`@``1`$```````#0````F`$``+4%``"*`P``````
M`!X$``"6!````````+0%```A!```W00```````"8`@``````````````````
M;`0``.4$``"&````C00```````!!`@``.P(``$D$``#*`@``800``#4"``!-
M`0``&````&8"````````EP4``%T"``#"!0``ZP$```````#N`@``!0```+P!
M``#/`@``F````$@```!*````%@4``(P"````````H0,````````8!0``@`$`
M``$#````````````````````````R@0``.0"```"`0``````````````````
M=@0``'D!```W!```S@0``(H"``"M!0```````$0$``#/!```$0(```````!5
M`0``?04``'4$```G!```7`4````````Q`@```````(D`````````70$``"4"
M```?`0``V@,````````(````````````````````CP4```````!J`0``````
M`"L`````````>0````P!``!$`P```@,````````=!0``0`0```````"D`@``
M,`,``)@$``!8````FP0```````#U`@``0`4``$X%```F````I@0``&("```@
M`0``.@(```````"P`P``8`(```````"(`0``X`0`````````````_`(``$(#
M```5`@````````````#N!```;0````0#````````WP,``+@%``!.`0``V`,`
M`+T!````````$04``*L"``"4`P``J0````````#:`0```````+8%``"@`0``
M`````````````````````'(!```A!0```````)`!````````*0$``*P%```3
M`@``"0$``(4$```F!0``AP,`````````````&@```/L%``"L````D`,``#,%
M``">!0``'P,``.P#``!E````````````````````````````````````;@,`
M`.P```")`P``0P0```````"Q`@``D@$``/H$````````_P,```````#9````
M+0(```````"S````X0(``+X"````````$`(``.T!````````]`4```````!N
M!```/````+\"```$````^````,D%``!^`@`````````````J`P``````````
M``"-`P``60```((```#2`@``4`(``&L$``"1````E@(``$$%``!"!0``Z`0`
M````````````P`$``-0!``"-````>`4``*0%``!J`@``!0(``)8%``!8!```
M^P0``!,!``!W!0``&0```.8!````````B00``/4!```V````%@```'\$````
M````U@$```````#0`P```````$,!``!+`0``*`4```<%``!&`0``V0$``!D"
M``"3`P```````,@$``"N!````"`@5&AE(&UA:6QB;W@@=')A<V@@:7,@86QR
M96%D>2!E;7!T>2X`("8C,34Q.R`E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H
M92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N`"`H)7,@
M9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D
M87DI`"`H=&]M;W)R;W<I`"`H>65S=&5R9&%Y*0`@870@`"5D("5S(&%N9"`E
M<P`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@061M:6YI<W1R871I
M;VX`)7,@1FEN9V5R<')I;G0`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M
M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F
M($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@
M:&%S(&-A;F-E;&QE9"`E<RX`)7,@:&%S(')E<&QI960@=&\@82!F<F5E+V)U
M<WD@<F5Q=65S="X`)7,@:&%S(')E<&QI960@=&\@=&AE(&EN=FET871I;VX@
M=&\@)7,N`"5S(&AA<R!S96YT('EO=2!F<F5E+V)U<WD@:6YF;W)M871I;VXN
M`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@<F5Q=65S=',@>6]U<B!F
M<F5E+V)U<WD@:6YF;W)M871I;VXN`"5S(')E<75E<W1S('EO=7(@<')E<V5N
M8V4@870@)7,N`"5S('1O("5S(&]F("5S`"5S('=I<VAE<R!T;R!A9&0@=&\@
M)7,N`"5S('=I<VAE<R!T;R!M86ME('EO=2!A=V%R92!O9B`E<RX`)7,@=VES
M:&5S('1O(')E8V5I=F4@=&AE(&QA=&5S="!I;F9O<FUA=&EO;B!A8F]U="`E
M<RX`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P
M860`)7,G<R!487-K;&ES=``G)7,G(&ES(&YO="!A('9A;&ED(&-H;VEC92X`
M)R5S)R!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN
M`"<E<R<@=')E92!R96YD97)E<B!N;W0@9F]U;F0N`"<E<R<@=V%S(&%D9&5D
M('1O('1H92!G<F]U<',@<WES=&5M+@`G)7,G('=A<R!A9&1E9"!T;R!T:&4@
M<&5R;6ES<VEO;G,@<WES=&5M+@`G)7,G('=A<R!N;W0@8W)E871E9#H@)7,N
M`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@
M<V5L96-T("TM`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO
M=7)S`#QB/D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D.CPO8CX`02!F871A
M;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U
M:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I
M<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L
M:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'
M4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y
M+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME
M>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I
M<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04TO4$T`06)O=70@
M=&AI<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E
M<'0@<F5Q=65S=`!!8V-E<'1E9`!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&
M4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N
M`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`
M06-T:6]N<P!!9&0`061D($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S
M:6]N`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO
M;@!!9&0@82!C:&EL9"!G<F]U<"!T;R`G)7,G`$%D9"!A(&-H:6QD('!E<FUI
M<W-I;VX@=&\@)R5S)P!!9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@
M;F5W(&UE;6)E<G,`061D('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z
M:6QL82!3:61E8F%R`$%D9"!T:&ES('1O(&UY(&-A;&5N9&%R`$%D9"!T;R!A
M9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D('5S97(`
M061D960@)R5S)R!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A
M9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N`$%D9&5D("<E<R<@
M=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+@!!9&1I;F<@=7-E
M<G,@:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S<R!";V]K`$%D;6EN:7-T
M97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T
M<F%T:6]N`$%K=&EO;B!!:7)P;W)T`$%L97AA;F1R;W5P;VQI($%I<G!O<G0`
M06QI87,`06QI9VX`06QI9VYM96YT.@!!;&P`06QL($%U=&AE;G1I8V%T960@
M57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@<VED
M97,`06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@
M;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)
M35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)
M35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T
M92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%N(&EL;&5G86P@=F%L=64@
M=V%S('-P96-I9FEE9"X`06YC:&EA;&]S($%I<G!O<G0`06YD<F%V:61A($%I
M<G!O<G0`06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!<'!L:6-A=&EO;@!!<'!L
M:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L>2!T;R!#
M:&EL9"!3:&%R97,`07!P<F]V90!!<')I;`!!<F%X;W,@06ER<&]R=`!!<F-H
M:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W
M86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)E
M('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92`G)7,G(&%N9"!A;GD@<W5B
M+6=R;W5P<S\`07)T`$%S8VEI($%R=`!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B
M969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`07-S:6=N;65N
M="!C;VQU;6YS`$%T:&EN86D@06ER<&]R=`!!='1A8VAE9"!I<R!A;B!I0V%L
M96YD87(@9FEL92!R97!L>2!T;R!A(')E<75E<W0@>6]U('-E;G0`071T96UP
M="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@
M9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@
M961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D
M:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=&5N9&5E<P!!='1R:6)U=&5S
M`$%U9W5S=`!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@
M9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@
M<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`
M079A:6QA8FQE(&9I96QD<SH`07=A:71I;F<@4F5S<&]N<V4`0F%C:V=R;W5N
M9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D
M(&ME<F)E<F]S('5S97)N86UE+@!"87)E`$)A<V4@9W)A<&AI8W,@9&ER96-T
M;W)Y("<E<R<@;F]T(&9O=6YD+@!"87-E;&EN90!":7)T:&1A>0!";&]C:R`B
M)7,B(&]F(&%P<&QI8V%T:6]N("(E<R(@;F]T(&9O=6YD+@!";&]C:R!3971T
M:6YG<P!";&]C:R!4>7!E`$)O;&0`0F]R9&5R<P!";W1H`$)O='1O;0!"=6QL
M971E9"!,:7-T`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S`$-64P!#7V5L;"!0
M<F]P97)T:65S+BXN`$-A;&5N9&%R`$-A;&5N9&%R(%-U;6UA<GD`0V%L96YD
M87(Z`$-A;&T`0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY
M+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0V%N)W0@8V]N;F5C="!T
M;R!)34%0('-E<G9E<CH@)7,`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R
M=`!#86YN;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP
M;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G
M971&:6QE)R!P87)A;65T97(N`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y("(E
M<R(N`$-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@
M<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D
M97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R('-T;W)E9"X`0V%N;F]T(')O=71E
M(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BX`0V%P=&EO;@!#871E9V]R
M:65S(&%N9"!,86)E;',`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`0V5L
M;"!P861D:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL
M<&AO;F4`0V5N=&5R`$-E<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A=&4@
M4&]L:6-I97,`0VAA:7(@4&5R<V]N`$-H86YG90!#:&%N9V4@4&%S<W=O<F0`
M0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W
M:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H87(`
M0VAE8U]K($QI;FLN+BX`0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO
M;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92X`0VAI;W,@
M06ER<&]R=`!#:&]O<V4@07!P;&EC871I;VXZ`$-H;V]S92!A('!A<W-W;W)D
M`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!A;B!A8W1I;VXZ`$-H;V]S92!H
M;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H
M9F]R(&]R9&5R960@;&ES=',I`$-H<GES;W5P;VQI($%I<G!O<G0`0VQA<W,@
M9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%R`$-L96%R($U33V9F
M:6-E('1A9W,`0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S97(`0VQE87(@
M=7-E<B!D871A`$-L:6-K('1O($-O;G1I;G5E`$-L;W-E($AE;'``0VQO<V4@
M2&5L<"!7:6YD;W<`0VQO<V4@5VEN9&]W`$-O;&QA<'-E(%-I9&5B87(`0V]L
M;&%P<V5D(&)O<F1E<G,`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE
M8W1I;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM
M86YD(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M<&%N>0!#;VUP;&5T
M960`0V]M<&]S92!-97-S86=E("@E<RD`0V]M<'5T97)S`$-O;F1I=&EO;G,`
M0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F%T:6]N(&9O<B!S
M>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN`$-O
M;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N`$-O;F9I9W5R871I;VX@;F5E
M9',@=7!D871I;F<N`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O
M;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I
M;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO
M;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S
M("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C
M="!396%R8V@`0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@
M>6]U<B!A9&1R97-S(&)O;VLN`$-O;G1E;G1S(&]F("<E<R<`0V]N=&5N=',@
M;V8@=&AE(%)!4B!A<F-H:79E`$-O;G1I;G5E`$-O<'D`0V]P>2!S96QE8W1I
M;VX`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!0
M1U`@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S
M<V%G92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO
M="!A9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V
M97(N`$-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N
M;F5C="!T;R!S97)V97(@)R5S)R!U<VEN9R!&5%`Z("5S`$-O=6QD(&YO="!C
M<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96-R>7!T
M(%!'4"!D871A+@!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U
M;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5L971E('-E='5P('5P
M9W)A9&4@<V-R:7!T("<E<R<N`$-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E
M8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N;W0@9F5T8V@@8V]M
M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@
M9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE
M=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N`$-O=6QD(&YO="!L;V%D
M('-T<F%T96=Y("<E<R<N`$-O=6QD(&YO="!M:V1I<B`G)7,G+@!#;W5L9"!N
M;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L
M9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@)R5S)R!F;W(@=W)I=&EN
M9RX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`
M0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y("<E<R<N`$-O=6QD(&YO="!R96%D
M("5S+@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q
M=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS(&%R92!N
M;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES
M=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T(')E
M=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E
M<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O
M=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S`$-O=6QD
M(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,`0V]U;&0@;F]T
M(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<FUD:7(@)R5S)RX`
M0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A
M=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A
M8VMU<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD(&YO="!S879E('-E='5P('5P
M9W)A9&4@<V-R:7!T('1O.B`G)7,G+@!#;W5L9"!N;W0@<V%V92!T:&4@8F%C
M:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE
M(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N
M92!O9B!T:&4@;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@
M;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@
M;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U;FQI;FL@
M)R5S)RX`0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@
M=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@=W)I=&4@
M8V]N9FEG=7)A=&EO;B!F;W(@)R5S)SH@)7,`0V]U;&1N)W0@9FEN9"!T:&4@
M36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E
M;BX`0V]U;&1N)W0@9VEV92!U<V5R("<E<R<@=&AE(&9O;&QO=VEN9R!R:6=H
M=',@9F]R('1H92!F;VQD97(@)R5S)SH@)7,`0V]U;G1E9"!T97AT`$-O=6YT
M<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@
M;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R
M961I="!C87)D(&YU;6)E<@!#<F5D:71S`$-U<G)E;G0@4&AA<V4`0W5R<F5N
M="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT
M(&-O;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE('1A<VMS('1O
M(')U;B!U<&]N(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C=&EO;@!$1`!$
M86EL>0!$871A`$1A=&%4<F5E($)R;W=S97(`1&%T86)A<V4@<75E<GD@9F%I
M;&5D+@!$871E`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1E
M7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-L:6YE
M9`!$96-R96%S92!);F1E;G0`1&5F875L=`!$969A=6QT($-O;&]R`$1E9F%U
M;'0@261E;G1I='D`1&5F875L="!097)M:7-S:6]N<P!$969A=6QT('!E<FUI
M<W-I;VYS`$1E9FEN:71I;VYS`$1E;&5G871E('!O<VET:6]N`$1E;&5G871E
M9`!$96QE=&4`1&5L971E($=R;W5P`$1E;&5T92!097)M:7-S:6]N`$1E;&5T
M92!A;F0@<'5R9V4@;65S<V%G97,`1&5L971E(&-E;&P`1&5L971E(&-O;'5M
M;@!$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E`$1E;&5T92!P
M97)M:7-S:6]N<R!F;W(@)R5S)P!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("<E
M<R<@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T92!R;W<`1&5L971E
M('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`
M1&5L971E('1H92!C=7)R96YT(')O=P!$96QE=&4@=&AI<R!P97)M:7-S:6]N
M(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&5D('-E='5P('5P9W)A
M9&4@<V-R:7!T("<E<R<N`$1E;&EV97)Y('1I;64`1&5N>2!R97%U97-T`$1E
M;GD@<F5Q=65S="!F;W(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N`$1E<V-R:6)E
M('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@*&%L<V\@:6X@2&]R
M9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T
M:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0
M;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE
M9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y
M`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L
M87D@9F]R96-A<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES<&]S:71I;VX@
M3F]T:69I8V%T:6]N`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C
M8V5S<R!M86EN=&5N86YC92YP:'``1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A
M:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$
M;W=N;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG
M=7)A=&EO;B!A<R!02%`@<V-R:7!T+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%
M9&ET`$5D:70@0FQO8VL`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I
M="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P
M=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET('!E<FUI
M<W-I;VYS(&9O<B`G)7,G`$5L969S:7,@06ER<&]R=`!%;&5M96YT+BXN`$5M
M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N
M`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M;W1I8V]N<P!%;7!T>2!M97-S
M86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B;&4@
M:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T
M97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%;F0`16YD
M('EE87(`16YL87)G92!%9&ET;W(`16YT97(@82!S96-U<FET>2!Q=65S=&EO
M;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E
M="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO
M=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%<G)O<@!%<G)O
M<B!S96YD:6YG(')E<&QY.B`E<RX`17)R;W(@=VET:"!E;6%I;"!M97-S86=E
M+@!%<G)O<B!W<FET:6YG("<E<R<N`$5T:&YI8P!%=7)O<&4`179E<GD@,34@
M;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R
M>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y
M(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A;F0`17AP86YD
M(%-I9&5B87(`17AP96-T960@(D)%1TE.(B!I;B!T:&4@;&EN92`E9"X`17AP
M96-T960@(D5.1#HE<R(@:6X@;&EN92`E9"X`17AP96-T960@)RDG`$5X<&5C
M=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`17AP:7)A=&EO
M;B!$871E`$5X<&]N96YT`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``
M1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN
M96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@
M<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C
M;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C
M=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I;'5R92!I;B!C:&%N
M9VEN9R!P87-S=V]R9"!F;W(@=7-E<B`E<R!F<F]M(&-L:65N="`E<RP@<F5A
M<V]N("5S`$9A:7(`1F%T86P@17)R;W(Z`$9A>`!&96)R=6%R>0!&965L<R!,
M:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R<P!&97<@4VYO=R!3:&]W97)S
M`$9I96QD(&UA=')I>`!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z
M("5S(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I
M;VX`1FEL92!U<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I
M;'1E<G,`1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&EP
M`$9L;V%T`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]N="!#;VQO
M<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S
M`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@
M='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M<P!&;W)W87)D<P!&<@!&
M<F%M97,`1G)E92]"=7-Y($EN9F]R;6%T:6]N`$9R964O0G5S>2!297!L>0!&
M<F5E+T)U<WD@4F5Q=65S=`!&<F5E+T)U<WD@4F5Q=65S="!297-P;VYS90!&
M<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@1&5S8W)I<'1I
M;VXZ`$9U;&P@36]O;@!&=6QL($YA;64`1V%L;&5R>2!T;R!T86ME(&EM86=E
M(&9R;VT`1V%L;&5R>3H`1VEV96X@3F%M90!';&]B86P@3W!T:6]N<P!';P!'
M<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R;W5P($%D;6EN:7-T<F%T:6]N
M`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P('!E<FUI<W-I
M;VYS`$=R;W5P<P!'=65S="!097)M:7-S:6]N<P!'=65S="!P97)M:7-S:6]N
M<P!'=65S=&)O;VL`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AE
M:6=H=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E
M`$AE<F%K;&EO;B!!:7)P;W)T`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T
M:&4@9FEL93H`2&EG:`!(:7-T;W)Y(&5N=')Y(&YA;65S(&UU<W0@8F4@;F]N
M+65M<'1Y`$AO7VUE`$AO;64`2&]M92!!9&1R97-S`$AO;64@4&AO;F4`2&]R
M9&4`2&]R9&4@3&]G:6X`2&]R9&4@4WES=&5M`$AO<F1E(%=I<F5L97-S`$AO
M<F1E(&ES(&YO="!P<F]P97)L>2!C;VYF:6=U<F5D`$AO<FEZ;VYT86P@4G5L
M90!(;W)I>F]N=&%L('!A9&1I;F<`2&]R:7IO;G1A;#H`2&]W(&1I9"!Y;W4@
M9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2D`2&]W(&UA;GD@8V]L=6UN<R!W
M;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU
M;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@
M=&\@;65R9V4_`$AU;6ED:71Y`$AU;6ED:71Y.B``2'5M;W)I<W1S`$E-05`@
M;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE
M=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F
M86EL960Z("5S`$E.0D]8`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A
M:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L
M;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$E?;F)O>`!)7VYS97)T(%)O
M=R!"969O<F4`26-O;G,@3VYL>0!)8V]N<R!F;W(@)7,`26-O;G,@=VET:"!T
M97AT`$ED96YT:71Y)W,@;F%M93H`268@:70@:7,@;F]T(&1I<W!L87EE9"!C
M;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+@!)9B!Y
M;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E
M<BP@>6]U(&UA>2!N965D('1O(&-H96-K('1H:7,@8F]X('1O('1U<FX@;V9F
M(%!.1R!T<F%N<W!A<F5N8WDN`$EF('EO=2!S964@=&AI<R!M97-S86=E(&)U
M="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG
M="!B92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+@!);6%G92!0<F5V:65W
M.@!);6%G92!54DP`26UA9V4@9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@9V%L
M;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0`26UP;W)T($5R<F]R
M.B``26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E
M9"!F:65L9',Z`$EN(%!R;V-E<W,`26Y?<V5R="!2;W<@069T97(`26YC;W)R
M96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E8W0@=7-E<FYA;64@86YD
M+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E
M(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R
M871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$EN8W)E87-E($EN9&5N
M=`!);F1I=FED=6%L(%5S97)S`$EN9F\`26YF;W)M871I;VX`26YS97)T($-?
M;VQU;6X@069T97(`26YS97)T($EM86=E`$EN<V5R="!486)L90!);G-E<G0@
M5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R="!A(&YE=R!C
M;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!C;VQU
M;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&%F
M=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&)E9F]R92!T
M:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C
M=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R
M<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS97)T(&%N
M(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N
M97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R="!C96QL(&)E
M9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU;6X@8F5F;W)E
M`$EN<V5R="!M97-S86=E<P!);G-E<G0@<&%R86=R87!H(&%F=&5R`$EN<V5R
M="!P87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R;W<@869T97(`26YS97)T(')O
M=R!B969O<F4`26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E
M8W5R:71Y('%U97-T:6]N.@!);G-E<G0O36]D:69Y($EM86=E`$EN<V5R="]-
M;V1I9GD@3&EN:P!);G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE
M(&1I<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@8W)E9&ET+@!);G1E
M9V5R`$EN=&5G97(@;&ES=`!);G9A;&ED($%C=&EO;B!S96QE8W1E9"!F;W(@
M=&AI<R!C;VUP;VYE;G0N`$EN=F%L:60@541(+B`H57-E<B!$871A($AE861E
M<BDN`$EN=F%L:60@87!P;&EC871I;VXN`$EN=F%L:60@8F%T8V@@240N`$EN
M=F%L:60@9&%T82!S=6)M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@861D
M<F5S<RX`26YV86QI9"!F:6QE(&9O<FUA=`!);G9A;&ED(&US9U]T>7!E+@!)
M;G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+@!);G9A;&ED(&]R(&UI<W-I;F<@
M<&%R86UE=&5R<RX`26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV86QI
M9"!P<F]T;V-O;"X`26YV86QI9"!R96-I<&EE;G0Z("<E<R<`26YV86QI9"!S
M:&%R92!O8FIE8W0`26YV86QI9"!S;W5R8V4@861D<F5S<RX`26YV86QI9"!U
M;FEC;V1E(&1A=&$N`$EN=F5N=&]R>0!)=&%L:6,`2F%N=6%R>0!*=6QY`$IU
M;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF
M>2!,969T`$IU<W1I9GD@4FEG:'0`2V%L86UA=&$@06ER<&]R=`!+87)P871H
M;W,@06ER<&]R=`!+87-T;W)I82!!:7)P;W)T`$ME97`@;W)I9VEN86P_`$ME
M9F%L:&YI82!!:7)P;W)T`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H
M96YT:6-A=&EO;BX`2V5R:WER82!!:7)P;W)T`$ME<FYE;"!.97=B:65S`$ME
M>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP
M90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+@!+:61S`$MO<R!!:7)P;W)T`$MO>F%N:2!!:7)P;W)T`$QA
M7WEO=70`3&%R:7-A($%I<G!O<G0`3&%S="!(86QF`$QA<W0@475A<G1E<@!,
M87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R
M;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%W`$QA>6]U=`!,96%V92!E;7!T
M>2!F;W(@;F\@8F]R9&5R`$QE9G0`3&5F="!H96%D97(`3&5F="!V86QU97,`
M3&EM97)I8VL`3&EM;F]S($%I<G!O<G0`3&EN:P!,:6YK('!O:6YT<R!T;SH`
M3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H
M96X@9&ES<&QA>6EN9P!,:6YK<P!,:6YU>"!#;V]K:64`3&ES="`M('5S97(@
M8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4
M;W!I8W,`3&ES="!486)L97,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`
M3&]A9&EN9RXN+@!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T
M:6]N`$QO9R!I;@!,;V<@;W5T`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!F
M;W(@<V]M92!R96%S;VXN($UO<W0@;&EK96QY('EO=7(@=7-E<FYA;64@;W(@
M<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN(&9A:6QE
M9"X`3&]G;W5T`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E:R!L971T
M97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M8F5R<P!-
M30!-86=I8P!-86EL`$UA:6P@061M:6X`36%K92!L:6Y?:RXN+@!-86YA9V4@
M=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M
M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E
M9V]R:65S+@!-86YU86P`36%P($1A=&4@86YD(%1I;64@1FEE;&1S`$UA<"!)
M;7!O<G0@1FEE;&1S`$UA<F-H`$UA<F=I;@!-87)K('=I=&@@4V5E;B]5;G-E
M96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N
M="]!;G-W97)E9"D`36%T8VAI;F<@9FEE;&1S`$UA>"!A;&QO=V5D(&-R961I
M="X`36%X(&UE<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T96UP(&QA<W0@
M,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M(&QE
M;F=T:`!-87D`365E=&EN9R!#86YC96QL871I;VX`365E=&EN9R!);F9O<FUA
M=&EO;@!-965T:6YG(%!R;W!O<V%L`$UE971I;F<@4F5P;'D`365E=&EN9R!5
M<&1A=&4`365E=&EN9R!5<&1A=&4@4F5Q=65S=`!-96UB97)S`$UE;6]S`$UE
M;G4@;6]D93H`365R9V4@8V5L;',`365S<V%G90!-97-S86=E(%9E<FEF:65D
M(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O
M=6QD(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E>'!I<F5D+@!-97-S86=E
M('1Y<&4`365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE
M+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E
M;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971H;V0`365T:&]D
M("<E<R<@:7,@;F]T(&1E9FEN960`365T<FEC`$UI9&1L90!-:6UE(%1Y<&4`
M36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA<W0@-B!H;W5R
M<SH@`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI<W-I;F<@4$5!4B!P86-K86=E
M($A45%!?4F5Q=65S="X`36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V
M92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@
M87!P;&EC871I;VXN`$UI<W-I;F<@;65S<V%G92!)1"X`36ES<VEN9R!R97%U
M:7)E9"!014%2('!A8VMA9V4@36%I;"X`36ES<VEN9R!S97-S:6]N($E$+@!-
M;P!-;V)I;&4@36%I;`!-;V1E<F%T90!-;V1I9FEE9"!$871E`$UO9&EF>2!5
M4DP`36]N=&@@5FEE=P!-;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1H;'D@
M179E;G1S($QI<W0`36]O;B!0:&%S97,`36]V92!$;W=N`$UO=F4@3&5F=`!-
M;W9E(%)I9VAT`$UO=F4@57``36]V92!D;W=N`$UO=F4@=7``375L=&DM;&5V
M96P@9')O<"!D;W=N(&QI<W1S`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O
M=6YT`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T`$UY(%-U;6UA<GD`37ET
M:6QI;FD@06ER<&]R=`!.3RP@22!$;R!.3U0@06=R964`3F%M90!.965D<R!!
M8W1I;VX`3F5T=V]R:P!.979E<@!.97<@0V%T96=O<GD`3F5W($UO;VX`3F5W
M(%!A<W-W;W)D`$YE=R!087-S=V]R9"`H86=A:6XI`$YE=R!5<V5R;F%M92`H
M;W!T:6]N86PI`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S
M`$YE>'0`3F5X="!086=E`$YE>'0@4&AA<V4`3F5X="!O<'1I;VYS`$YO`$YO
M(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E
M;F-E<R!F;W(N`$YO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E3
M3R!I;6%G97,N`$YO(&)A=&-H('1E;7!L871E+@!.;R!B;&]C:R!E>&ES=',@
M870@=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R
M;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO
M(&-H:6QD('!E<FUI<W-I;VYS(&%R92!T;R!B92!A9&1E9"!B96QO=R!T:&ES
M(&QE=F5L+@!.;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M
M:7-S:6]N+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@3$1!4"!0<F5F97)E;F-E<RX`3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!#871E9V]R:65S
M+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M4U%,(%!R969E<F5N8V5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!A=71H96YT:6-A=&EO;BX`3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&
M:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T:6]N('-U<'!L
M:65D+@!.;R!F:6QE('5P;&]A9&5D`$YO(&EC;VYS(&9O=6YD+@!.;R!L;V-A
M=&EO;B!I<R!S970N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E
M8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R
M='5N97,`3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!P<F5F97)E;F-E<R!A<F4@
M879A:6QA8FQE+@!.;R!R=6QE<P!.;R!S:61E<P!.;R!T96UP;W)A<GD@9&ER
M96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O
M<B!P87-S=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.
M;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U
M<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@
M9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I
M9W5R871I;VXN`$YO;B!087)T:6-I<&%N=`!.;VYE`$YO;F4@*'5S92!I;7!L
M:6-I="D`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W0@069T97(`3F]T($)E9F]R
M90!.;W0@82!D:7)E8W1O<GD`3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO
M="!S=7!P;W)T960N`$YO=&5S`$YO=&5S(%-U;6UA<GD`3F]T97,@:7,@86X@
M87!P;&EC871I;VX@=VAI8V@@86QL;W=S('EO=2!T;R!C<F5A=&4@=&AE(&-O
M;7!U=&5R(&5Q=6EV86QE;G0@;V8@<W1I8VMY(&YO=&5S+B!.;W1E<R!C86X@
M8F4@8W)E871E9"P@;6]D:69I960L(&1E;&5T960L(&%N9"!P<FEN=&5D+B!9
M;W4@8V%N(&%L<V\@<V5A<F-H(&]N('EO=7(@;F]T97,@=&\@;&]C871E(&EN
M9F]R;6%T:6]N+B!3=7!P;W)T(&9O<B!I;7!O<G1I;F<@86YD(&5X<&]R=&EN
M9R!N;W1E<R!I<R!A;'-O(&%V86EL86)L92X`3F]T97,Z`$YO=&AI;F<@=&\@
M8G)O=W-E+"!G;R!B86-K+@!.;W1I8V4`3F]T:69I8V%T:6]N(&QI<W1E;F5R
M("5S(&YO="!F;W5N9"X`3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R
M86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!C;VQU;6YS(&EN
M('1H92!S=6UM87)Y('9I97<Z`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T
M('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N
M`$]B:F5C=`!/8FIE8W0@0W)E871O<@!/8FIE8W0@8W)E871O<B!P97)M:7-S
M:6]N<P!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/;&0@
M4&%S<W=O<F0`3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L
M9&5R<RX`3VYL>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@
M861D<F5S<R!A;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M
M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M
M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N
M4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D
M(%,O34E-12!P87)T+@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W
M`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N86P@4&%R=&EC:7!A;G0`3W!T:6]N
M<P!/<'1I;VYS(&9O<@!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G
M86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG
M:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@
M:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E<FUI<W-I
M;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!01U`@
M1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L
M:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0
M(%-H96QL`%!?2%`@4VAE;&P`4&%D9&EN9P!087-S=V]R9`!087-S=V]R9"!C
M:&%N9V5D(&9O<B!U<V5R("5S(&9R;VT@8VQI96YT("5S`%!A<W-W;W)D(&EN
M8V]R<F5C=`!087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I
M8V%T:6]N+@!087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`
M4&%S<W=O<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`4&%S="!%=F5N=',@
M3&ES=`!087-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@
M4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/
M<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L
M;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N("<E<R<@;F]T(&1E;&5T960N
M`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<FUI<W-I;VYS(&9O<@!0
M97)S;VYA;"!);F9O<FUA=&EO;@!0971S`%!H;VYE`%!H;W1O<P!0:7AE;',`
M4&QA=&ET=61E<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E
M(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT
M.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES
M(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L
M96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S
M92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A
M;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N
M=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!P<F]V:61E
M(&$@;F5W('!A<W-W;W)D`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T
M:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!P87-S=V]R9`!0;&5A
M<V4@<')O=FED92!Y;W5R('5S97)N86UE`%!L96%S92!P<F]V:61E('EO=7(@
M=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!P<F]V:61E('EO=7(@=7-E
M<FYA;64@=VET:"!`9&]M86EN`%!L96%S92!R96%D('1H92!F;VQL;W=I;F<@
M=&5X="X@(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T
M:&4@<WES=&5M+@!0;&5A<V4@<F5V:65W('1H92!F;VQL;W=I;F<@:6YF;W)M
M871I;VXL(&%N9"!T:&5N('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@;65N
M=2!B96QO=RX`4&QE87-E('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@;65N
M=2!B96QO=RX`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0
M;&5A<V4@=F5R:69Y('EO=7(@;F5W('!A<W-W;W)D`%!O<VET:6]N:6YG(&]F
M('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T('1O
M('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`4')E8V5D92!Y
M;W5R('-I9VYA='5R92!W:71H(&1A<VAE<R`H)RTM("<I/P!0<F5C:7!I=&%T
M:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5F<U]L9&%P.B!297%U:7)E
M9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E
M<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"X`4')E<V5N=&%T
M:6]N<P!0<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V96PZ(`!0<F5S<W5R
M93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W
M`%!R979I;W5S(%!A9V4`4')E=FEO=7,@;W!T:6]N<P!0<FEN="!D;V-U;65N
M=`!0<FEV871E($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O
M:F5C=',`4')O;7!T('1E>'0`4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R
M:71H;0!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C
M8V5S<V9U;&QY+@!1=65R>0!24T$@4'5B;&EC($ME>2`H)60@8FET*0!2861I
M;R!S96QE8W1I;VX`4F%N9&]M($9O<G1U;F4`4F%T:6\`4F5A9`!296%D(&UE
M<W-A9V5S`%)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO
M="!B92!U;F1O;F4N`%)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R
M("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!2961O97,@
M>6]U<B!L87-T(&%C=&EO;@!2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT
M<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5F<F5S:"!3=6UM87)Y(%9I97<Z
M`%)E9V5X`%)E;&%T:6]N<VAI<"!"<F]W<V5R`%)E;6%R:W,`4F5M96UB97(@
M=&AE(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`4F5M;W1E(%-E<G9E<G,`4F5M
M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V
M90!296UO=F4@0FQO8VL`4F5M;W9E(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN
M9P!296UO=F4@9G)O;2!M>2!C86QE;F1A<@!296UO=F4@<&%I<@!296UO=F4@
M<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R
M>2X`4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M
M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!297!L>2!396YT+@!2
M97!L>2!W:71H($YO="!3=7!P;W)T960@365S<V%G90!297!L>2!W:71H(&9R
M964O8G5S>2!F;W(@;F5X="`R(&UO;G1H<RX`4F5P;'D@=VET:"!R97%U97-T
M960@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@!297!L>3H@)7,`4F5Q=65S="!C
M;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``4F5Q
M=6ER960@)R5S)R!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN
M`%)E<75I<F5D("<E<R<@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A
M=&EO;BX`4F5Q=6ER960@)R5S)R!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R
M871I;VXN`%)E<75I<F5D("=B87-E9&XG(&YO="!S<&5C:69I960@:6X@875T
M:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)V)A<V5D;B<@
M;F]T('-P96-I9FEE9"!I;B!P<F5F97)E;F-E<R!C;VYF:6=U<F%T:6]N+@!2
M97%U:7)E9"`G9&%T86)A<V4G(&YO="!S<&5C:69I960@:6X@875T:&5N=&EC
M871I;VX@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)V1A=&%B87-E)R!N;W0@
M<W!E8VEF:65D(&EN(&-A=&5G;W)I97,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER
M960@)V1A=&%B87-E)R!N;W0@<W!E8VEF:65D(&EN('!R969E<F5N8V5S(&-O
M;F9I9W5R871I;VXN`%)E<75I<F5D("=H;W-T<W!E8R<@;F]T('-P96-I9FEE
M9"!I;B!A=71H96YT:6-A=&EO;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G
M:&]S='-P96,G(&YO="!S<&5C:69I960@:6X@8V%T96=O<FEE<R!C;VYF:6=U
M<F%T:6]N+@!297%U:7)E9"`G:&]S='-P96,G(&YO="!S<&5C:69I960@:6X@
M<')E9F5R96YC97,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W!A<W-W;W)D
M)R!N;W0@<W!E8VEF:65D(&EN(&%U=&AE;G1I8V%T:6]N(&-O;F9I9W5R871I
M;VXN`%)E<75I<F5D("=P87-S=V]R9"<@;F]T('-P96-I9FEE9"!I;B!C871E
M9V]R:65S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=P87-S=V]R9"<@;F]T
M('-P96-I9FEE9"!I;B!P<F5F97)E;F-E<R!C;VYF:6=U<F%T:6]N+@!297%U
M:7)E9"`G<&AP='EP92<@;F]T('-P96-I9FEE9"!I;B!A=71H96YT:6-A=&EO
M;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G<&AP='EP92<@;F]T('-P96-I
M9FEE9"!I;B!C871E9V]R:65S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=P
M:'!T>7!E)R!N;W0@<W!E8VEF:65D(&EN('!R969E<F5N8V5S(&-O;F9I9W5R
M871I;VXN`%)E<75I<F5D("=T86)L92<@;F]T('-P96-I9FEE9"!I;B!A=71H
M96YT:6-A=&EO;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G=&%B;&4G(&YO
M="!S<&5C:69I960@:6X@8V%T96=O<FEE<R!C;VYF:6=U<F%T:6]N+@!297%U
M:7)E9"`G=&%B;&4G(&YO="!S<&5C:69I960@:6X@<')E9F5R96YC97,@8V]N
M9FEG=7)A=&EO;BX`4F5Q=6ER960@)W5I9"<@;F]T('-P96-I9FEE9"!I;B!A
M=71H96YT:6-A=&EO;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G=6ED)R!N
M;W0@<W!E8VEF:65D(&EN('!R969E<F5N8V5S(&-O;F9I9W5R871I;VXN`%)E
M<75I<F5D("=U<V5R;F%M92<@;F]T('-P96-I9FEE9"!I;B!A=71H96YT:6-A
M=&EO;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G=7-E<FYA;64G(&YO="!S
M<&5C:69I960@:6X@8V%T96=O<FEE<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E
M9"`G=7-E<FYA;64G(&YO="!S<&5C:69I960@:6X@<')E9F5R96YC97,@8V]N
M9FEG=7)A=&EO;BX`4F5Q=6ER960@1FEE;&0`4F5Q=6ER960@4&%R=&EC:7!A
M;G0`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R9`!2
M97-U;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E='5R;B!T;R!M86EL`%)E=6YI
M;VX`4F5V97)T($-O;F9I9W5R871I;VX`4FAO9&5S($%I<G!O<G0`4FEC:"!4
M97AT($5D:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R
M`%)I9VAT('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2;W1A=&4@
M,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2
M;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E
M96X@<F]W<R!O;FQY`%)U;@!3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U
M<F4`4R]-24U%($5N8W)Y<'1E9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I
M;VX@:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!344P@4VAE;&P`
M4U5#0T534P!37U%,(%-H96QL`%-A`%-A;64@9G)A;64@*%]S96QF*0!386UO
M<R!!:7)P;W)T`%-A=&5L;&ET92!0<F]V:61E<@!3879E`%-A=F4@)7,`4V%V
M92`G)7,G`%-A=F4@3W!T:6]N<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T
M:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R
M>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-A=F5D('-E
M='5P('5P9W)A9&4@<V-R:7!T('1O.B`G)7,G+@!38VEE;F-E`%-E87)C:`!3
M96%R8V@@16YG:6YE<P!396%R8V@@36%I;`!396%R8V@@4F5S=6QT<P!396QE
M8W0@1FEL97,`4V5L96-T(&$@9&%T90!396QE8W0@82!G<F]U<"!T;R!A9&0`
M4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U
M<V5R('1O(&%D9`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T
M(&%N(&]B:F5C=`!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O
M;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T
M92!T:&5M(&9R;VT@=&AE('1E>'1A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L
M:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&ED
M96YT:71Y('EO=2!W86YT('1O(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E
M;&EM:71E<CH`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M
M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L
M96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD($QA=&5S="!);F9O
M<FUA=&EO;@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;G-O<CH@
M`%-E<'1E;6)E<@!397)I86P@3G5M8F5R`%-E<W-I;VX@240@97AP:7)E9"X`
M4V5T`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A
M<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T('5P(')E;6]T92!S
M97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T
M86PN`%-E="!Y;W5R('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L
M87D@;W!T:6]N<RX`4V5T('EO=7(@<')E9F5R<F5D(&1I<W!L87D@;&%N9W5A
M9V4N`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD
M(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@
M8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P
M;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I
M;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R
M86UE=&5R.B``4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]R="!3=6UM87)Y
M.@!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK
M<S\`4VAO=P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A
M=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H
M;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O<'1I
M;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('1A8FQE(&]P
M97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE
M9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO
M=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@
M4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E<G1I
M97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N
M96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0`4VEG
M;B!U<`!3:6=N('5P(&EF(&YO="!R96=I<W1E<F5D`%-I9VYA='5R90!3:6=N
M871U<F4@06QG;W)I=&AM`%-I>F4`4VMI<"!-86EN=&5N86YC90!3;VUE(&]F
M($AO<F1E)W,@8V]N9FEG=7)A=&EO;B!F:6QE<R!A<F4@;6ES<VEN9SH`4V]R
M="!O<F1E<B!S96QE8W1I;VX`4V]U9&$@06ER<&]R=`!3;W5R8V4@861D<F5S
M<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@861J86-E;G0@
M8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L
M;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P86T`4W!E
M8VEA;"!#:&%R86-T97(@26YP=70`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`
M4W!L:70@<F]W`%-P;W)T<P!3=&%R=`!3=&%R="!Y96%R`%-T871E(&]R(%!R
M;W9I;F-E`%-T871U<P!3=&]R86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3
M=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H
M92!A9&1R97-S`%-T>6QE(%M#4U-=`%-U`%-U8F1I<F5C=&]R>2`G)7,G(&YO
M="!F;W5N9"X`4W5B:F5C=`!3=6)J96-T(%!U8FQI8R!+97D@26YF;P!3=6)M
M:70`4W5B;6ET=&5D(')E<75E<W0@=&\@861D("<E<R<@=&\@=&AE('-Y<W1E
M;2X@66]U(&-A;B!N;W0@;&]G(&EN('5N=&EL('EO=7(@<F5Q=65S="!H87,@
M8F5E;B!A<'!R;W9E9"X`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY
M(&%D9&5D("<E<R<@=&\@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-L96%R
M960@9&%T82!F;W(@=7-E<B`G)7,G(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S
M<V9U;&QY(&1E;&5T960@)R5S)RX`4W5C8V5S<V9U;&QY(')E;6]V960@)R5S
M)R!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF
M:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL
M>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('-A
M=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C97-S
M9G5L;'D@=7!D871E9"`G)7,G`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=6UM
M87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3
M=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`
M4W5R;F%M90!3>6YC(&QO9R!D96QE=&5D`%-Y;F--3`!3>6YT87@@97)R;W(@
M:6X@<V5A<F-H('1E<FUS`%1A8FQE`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@
M<')O<&5R=&EE<P!486YA9W)A($%I<G!O<G0`5&%R9V5T.@!487-K<P!4871O
M:2!!:7)P;W)T`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R
M.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP;&%T92`G)7,G(&YO
M="!F;W5N9"X`5&5M<&QA=&4@061M:6YI<W1R871I;VX`5&5N=&%T:79E;'D@
M06-C97!T(')E<75E<W0`5&5N=&%T:79E;'D@06-C97!T960`5&5X=`!497AT
M($]N;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86YK('EO=2!F;W(@=7-I
M;F<@=&AE('-Y<W1E;2X`5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL
M86)L92X`5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S
M(&YO="!S=7!P;W)T("(E<R(`5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED
M(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4:&4@3W!T:6]N<R!W:6YD;W<@:&%S
M(&-L;W-E9"X@17AI=&EN9RX`5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@
M8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@
M>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+@!4:&4@8F]T=&]M('-I9&4@
M;VYL>0!4:&4@8V%L96YD87(@9&%T82!I<R!I;G9A;&ED`%1H92!C;VYT86-T
M($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W
M87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A8W0@=V%S
M('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`5&AE
M(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@
M=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO;B!L
M:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O
M<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T:6]N
M(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T:6]N(&9E871U
M<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!E=F5N
M="!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R(&-A;&5N9&%R+@!4:&4@9FEL92`E
M<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE("5S('-H
M;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-A;B!N
M;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+@!4:&4@9FEL92!C;VYT86EN960@
M;F\@9&%T82X`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H
M:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&9U;&P@<V-R965N(&UO
M9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%
M>'!L;W)E<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@
M86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@9V%R
M8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R
M(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E;2!I<R!7
M:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@
M)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T
M+EQN7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92!P<F5S<R!/2R!I
M9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O
M<BX`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&QE
M9G0M:&%N9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B
M:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N
M`%1H92!M86EL8F]X('1R87-H(&ES(&%L<F5A9'D@96UP='DN`%1H92!M97-S
M86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T("(E<R(@:&%S(&)E
M96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M
M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"X`5&AE(&YA;64@
M=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H92!O
M<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T
M7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T
M(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM
M=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H
M:7,@;65S<V%G92!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES
M=&5M+@!4:&4@<F5G:7-T<GD@:7,@:&]W($AO<F1E(&%P<&QI8V%T:6]N<R!F
M:6YD(&]U="!H;W<@=&\@=&%L:R!T;R!E86-H(&]T:&5R+B!9;W4@<VAO=6QD
M(&QI<W0@86YY(&EN<W1A;&QE9"!(;W)D92!A<'!L:6-A=&EO;G,@=&AA="!Y
M;W4@:&%V92!H97)E+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4
M:&4@<FEG:'0M:&%N9"!S:61E(&]N;'D`5&AE('-E<G9E<B`B)7,B(&AA<R!B
M965N(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`
M5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4
M:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="X`5&AE('1A<VL@:&%S
M(&)E96X@861D960@=&\@>6]U<B!T87-K;&ES="X`5&AE('1E;7!O<F%R>2!F
M:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H92!T;W`@86YD(&)O='1O;2!S
M:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!U<&QO861E9"!D871A
M('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4:&4@=7!L;V%D
M960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!U<V5R)W,@9G)E92]B
M=7-Y(&EN9F]R;6%T:6]N('=A<R!S=6-E<W-F=6QL>2!S=&]R960N`%1H96UE
M<R!D:7)E8W1O<GD@)R5S)R!N;W0@9F]U;F0N`%1H97)E(&%R92!N;R!O<'1I
M;VYS(&%V86EL86)L92X`5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E
M(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T
M97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C
M=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!W87,@
M82!P<F]B;&5M(&%D9&EN9R`G)7,G('1O('1H92!S>7-T96TN("5S+@!4:&5R
M92!W87,@82!P<F]B;&5M(&%D9&EN9R`G)7,G('1O('1H92!S>7-T96TZ("5S
M`%1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B`G
M)7,G(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@<F5M
M;W9I;F<@)R5S)R!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B
M;&5M('5P9&%T:6YG("<E<R<Z("5S`%1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A
M<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y
M=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@
M=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!E=F5N=#H@)7,N`%1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A
M+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!T87-K.B`E<RX`
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!U<V5R)W,@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N.B`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C
M;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@<F5Q
M=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H
M92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@=')Y
M(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE
M(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE
M<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES
M="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<W-A;&]N:6MI($%I<G!O
M<G0`5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@
M9F]L9&5R<RX`5&AI<R!A8W1I;VX@:7,@;F]T('-U<'!O<G1E9"X`5&AI<R!A
M8W1I;VX@:7,@;F]T('EE="!I;7!L96UE;G1E9"X`5&AI<R!D;V5S(&YO="!A
M<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO
M="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO
M="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K
M871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@
M=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I
M;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E
M<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H
M('1H92!6;V1A9F]N92!)=&%L>2!G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE
M(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"!6
M;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+@!4:&ES(&9I96QD
M(&ES(')E<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT
M96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N
M9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A
M;"!V86QU97,N`%1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E
M('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@;75S="!B
M92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C
M;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@
M)R,Q,C,T868G+@!4:&ES(&9I;&4@8V]N=')O;',@=&AE(&=L;V)A;"!S970@
M;V8@34E-12!D<FEV97)S(&9O<B!T:&4@2&]R9&4@9G)A;65W;W)K+"!A;&QO
M=VEN9R!A<'!L:6-A=&EO;G,@=&\@;6%K92!U<V4@;V8@<')O9W)A;7,@<W5C
M:"!A<R!E;G-C<FEP="!O<B!M<W=O<F1V:65W('1O(')E;F1E<B!C;VYT96YT
M(&EN=&\@2%1-3"!F;W(@=FEE=VEN9R!I;B!A(&)R;W=S97(N`%1H:7,@9FEL
M92!C;VYT<F]L<R!T:&4@<W1Y;&5S:&5E="!T:&%T(&ES('5S960@=&\@<V5T
M(&-O;&]R<R!A;F0@9F]N=',@9F]R('1H92!(;W)D92!F<F%M97=O<FL@86YD
M(&%L;"!A<'!L:6-A=&EO;G,@=&AA="!D;R!N;W0@<')O=FED92!T:&5I<B!O
M=VX@<V5T=&EN9W,N`%1H:7,@9FEL92!M87!S(&9I;&4@97AT96YS:6]N<R!T
M;R!L;V=I8V%L($U)344@='EP97,L(&5N86)L:6YG($AO<F1E(&%P<&QI8V%T
M:6]N<R!T;R!F:6=U<F4@;W5T(&AO=R!T;R!H86YD;&4@<V]M92!C;VYT96YT
M('-U8V@@87,@96UA:6P@871T86-H;65N=',@;W(@0U93(&-H96-K;W5T<RX`
M5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES
M("5S+@!4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE
M=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N="!T
M:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&
M;W(@82!L:7-T(&]F('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES:70@
M)7,`5&AI<R!I<R!T:&4@;6%I;B!(;W)D92!C;VYF:6=U<F%T:6]N(&9I;&4N
M($ET(&-O;G1A:6YS('!A=&AS(&%N9"!B87-I8R!I=&5M<R!T:&%T(&%P<&QY
M('1O('1H92!C;W)E(&9R86UE=V]R:R!A;F0@86QL($AO<F1E(&%P<&QI8V%T
M:6]N<RX`5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R
M('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU
M<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('!R;V)L96T@<F5P;W)T('=A<R!R
M96-E:79E9"!F<F]M("5S+B!4:&4@=7-E<B!C;&EC:V5D('1H92!P<F]B;&5M
M(')E<&]R="!L:6YK(&9R;VT@=&AE(&9O;&QO=VEN9R!L;V-A=&EO;CHE<R!A
M;F0@:7,@=7-I;F<@=&AE(&9O;&QO=VEN9R!B<F]W<V5R.B5S`%1H:7,@<V5R
M=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4:&ES
M('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L=64@
M;75S="!B92!A(&YU;6)E<BX`5&EC:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`
M5&EM92!F;W)M870`5&EM92!S96QE8W1I;VX`5&ET;&4`5&ET;&4@*'1O;VQT
M:7`I.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T
M:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L
M:6-K:6YG+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]M;W)R;W<`5&]P
M`%1O<"!F<F%M92`H7W1O<"D`5')A;G-L871I;VYS`%1R:7!O;&ES($%I<G!O
M<G0`5')U92!O<B!F86QS90!4=0!4>7!E(&UI<VUA=&-H+@!4>7!E('EO=7(@
M8VAO:6-E.B``55),`%523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A
M='5S(')E<&]R=`!54DPZ`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R
M>2X`56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@
M<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!6
M1E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R
M(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B
M;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C
M="!W:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T
M;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E
M(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N
M86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O
M;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C
M=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D
M:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@)R5S)SH@
M)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L
M>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@
M9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&
M4R!F:6QE("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L
M92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E
M=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@
M8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI
M=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T
M;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE
M('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!T
M:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96=I<W1E<B!P<F5F
M97)E;F-E<R!I;B!S97-S:6]N+@!5;F%B;&4@=&\@<F5N86UE("5S('1O("5S
M.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`56YA8FQE('1O
M(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!D
M:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("(E<R(N
M`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R=6X@)VUK:7-O9G,G+@!5;F%B
M;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A
M=&$N`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S="!A
M8W1I;VX`56YE>'!E8W1E9"!E;F0@;V8@9FEL92X`56YE>'!E8W1E9"!R97-P
M;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R
M97-P;VYS92!F<F]M('-E<G9E<B!T;SH@`%5N9FEL960`56YH86YD;&5D(&-O
M;7!O;F5N="!O9B!T>7!E.B`E<P!5;FET<P!5;FMN;W=N`%5N:VYO=VX@87!I
M;7-G:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I9"`H0VQI
M96YT($UE<W-A9V4@240I+@!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D
M+@!5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N=`!5;FYA;65D`%5N<')I=FEL
M96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O
M9W)A;6%T:6-A;&QY(&9O<B!S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@
M=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@
M<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE
M(&-L:7!B;V%R9"X`56YS970@8V]L;W(`56YS=7!P;W)T960@17AT96YS:6]N
M`%5P9&%T90!5<&1A=&4@)7,`57!D871E(')E<W!O;F1E;G0@<W1A='5S`%5P
M9&%T92!U<V5R`%5P9&%T960@)R5S)RX`57!G<F%D92!S8W)I<'0@9&5L971E
M9"X`57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE
M<R!T;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R(')O
M;6%N(&YU;6)E<G,`57-E($-U<G)E;G0Z("5S`%5S92!$969A=6QT(%9A;'5E
M`%5S92!34TP`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O
M<B!)35-0('-E<G9E<BX`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@
M)7,N`%5S97(@061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G
M:7-T<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D
M(&9O<B!T:&ES('-I=&4N`%5S97(@<&%S<W=O<F0@8VAA;F=E`%5S97(@<&5R
M;6ES<VEO;G,`57-E<FYA;64`57-E<FYA;64@)R5S)R!A;')E861Y(&5X:7-T
M<RX`57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,`57-E<G,@:6X@=&AE('-Y
M<W1E;3H`5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="X`5F%C871I;VX`
M5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI9&ET>0!686QU
M92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU97,`5F%L=65S('1O('-E;&5C
M="!F<F]M`%9A<FEA8FQE`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE
M<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9E
M<G-I;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG
M`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE=R`E<P!6:65W(&%N(&5X=&5R;F%L
M('=E8B!P86=E`%9I97<@87,@)7,`5FEE=R!E=F5N=`!6:65W('1A<VL`5FES
M:6)I;&ET>0!6:7-I8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``
M5T%23@!705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E
M<RX`5V%R;FEN9P!790!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E
M;&-O;64L("5S`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@
M869T97(@;&]G:6X_`%=H870@87!P;&EC871I;VX@<VAO=6QD($AO<F1E(&1I
M<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R
M86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAI8V@@<&AA
M<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT
M(&5D:71O<BX`5VED=&@`5VED=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F('1H
M92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L
M;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`
M5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES9&]M`%=I<VAL
M:7-T<P!7;W)K`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%@M4F5F`%@U,#EV
M,R!"87-I8R!#;VYS=')A:6YT<P!8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E
M`%@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64`6#4P.78S(%-U8FIE
M8W0@2V5Y($ED96YT:69I97(`6#4P.78S(&5X=&5N<VEO;G,`65D`65E960!9
M96%R;'D`665S`%EE<RP@22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@
M(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=9
M1RX`66]U(&%R92!N;W0@875T:&5N=&EC871E9"X`66]U(&-A;B!N;W0@:&%V
M92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&1I
M9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T
M(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE
M(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@:&%V92!B965N(&QO
M9V=E9"!O=70N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X\8G(@+SY4:&%N
M:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN`%EO=2!H879E('1O(&5N=&5R
M(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E
M(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A
M(%9&4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B
M969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU
M<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO
M=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU
M<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@
M<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF
M>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U
M<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I
M;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N
M86UE+@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I
M;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@16UA:6P@061D<F5S
M<SH`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@
M26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN
M:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R
M:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@875T
M:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U
M<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O
M;64@;W1H97(@<F5A<V]N+@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@
M9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R
M92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO
M=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@
M8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R
M('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R
M(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&)R;W=S97(@
M9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N
M=')O;"]/<'1I;VX@*R!0('1O('!R:6YT+@!9;W5R(&-U<G)E;G0@=&EM92!Z
M;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9
M;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N<R!H
M879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S
M<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R('!A
M<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@
M<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@
M;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D<R!D;R!N;W0@;6%T8V@`66]U
M<B!R96UO=&4@<V5R=F5R<SH`6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M
M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X
M="`M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N
M`%]$96QE=&4@4F]W`%]'<F]U<',`7TAE;'``7TEM86=E(%!R;W!E<G1I97,N
M+BX`7TQO9R!I;@!?3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`7T]P=&EO;G,`
M7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN:RXN+@!?4V5T=7``7U1A8FQE(%!R
M;W!E<G1I97,N+BX`7U5S97)S`&%D9')E<W,@8F]O:P!C86QE;F1A<@!C86QM
M`&-L:6-K(&AE<F4`9FEL90!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&@Z
M`&EM;65D:6%T90!I;FQI;F4`;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D92`E
M9"!W:&EL92!M86MI;F<@25-/+@!N86UE`&YO="!I;7!L96UE;G1E9`!N;W0@
M>65T(&EM<&QE;65N=&5D`&YO=&5P860`<&5R8V5N=`!P:7AE;',`<VAO=R!D
M:69F97)E;F-E<P!S;7,R96UA:6P@=FEA($A45%``<W1E861Y`'1A<VL@;&ES
M=`!T<F%S:`!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N
M:69I960`=6YN86UE9`!U<V5R('-E;&5C=`!V0V%R9`!0<F]J96-T+4ED+59E
M<G-I;VXZ($AO<F1E.B`S+C`M8W9S"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D
M979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`R+3$Q
M+3`W(#$R.C`V*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-2TP-"TR-B`Q
M,3HQ,RLP,C`P"DQA<W0M5')A;G-L871O<CH@2V]N<W1A;G1I;F]S($,N($UI
M;&]S:7,@/&MM:6QO<VES0'EA:&]O+F-O;3X*3&%N9W5A9V4M5&5A;3H@1W)E
M96L@/&1E=D!L:7-T<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O
M;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TW"D-O
M;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET"@`@(,<@X_'A[.SA]._H
M]?'?Y.$@)^K<Y._R)R#EW^WAZ2#>Y.<@W.3EZ>$N`"`F(S$U,3L@)7,@Q=_M
MX>D@YR#S].GC[-X@[>$@X]_M[_7M(._I(.OEZ?3O]?'CW^7R(//U[?3>\>?S
MY_(@\._U(.7?[>'I(.7PZ>OEX^S=[>7R(/#A\>'JW/3Y+@`@*/#QZ>T@X?#\
M("5S(.?LW?'E\BD`("C*Z^7IY-\@\/'\\^+A\^?R("5S*0`@*//E("5S(.?L
MW?'E\BD`("CSWNSE\>$I`"`HX?WQZ>\I`"`H]^CE\BD`(//TZ?(@`"5D("5S
M(.KAZ2`E<P`E9"WLY?'G(/#Q_.+KY?CG`"5S("T@T^?LY=_Y\^<`)7,MQ.GA
M]^7?\>GSYP`E<R#$X>KT]>OIZOP@X?#O]/WP^>SA`"5S(,OEZ?3O]?'CW^7R
M(-/U[?3>\>?SY_(@+2#%\.GBY>+AW_GSYP`E<RW0X?'A[.7T\>_P[]_G\^<`
M)7,@Q>/C\>'VW@`E<R#/\>_I(/?QWO/G\@`E<R#>Y.<@]?#<\??EZ2X`)7,@
M\^4@)7,@)7,`)7,@X>KU\?[HY^KE("5S+@`E<R#A\-SM].?SY2#SY2#E\?[T
MY^SA(.3IX>CE\^GL_/3G].'R+@`E<R#A\-SM].?SY2#S].?M(/#Q_//JZ^?S
MYR#CZ>$@)7,N`"5S(//A\B#=\_3EZ>OE(/#KY_'O]N_QW^7R(.3IX>CE\^GL
M_/3G].'R+@`E<R#EW^WAZ2#A\.'I]._][.7M[P`E<R#KY?#TW``E<R#SX?(@
MYM[TY_/E(/#KY_'O]N_QW^7R(.3IX>CE\^GL_/3G].'R+@`E<R#FWO3G\^4@
M].?M(/#A\>_U\]_A(//A\B#S].GR("5S+@`E<R#Y\B`E<R#A\/P@)7,`)7,@
MY?#IZ/7LY=\@].?M(/#Q[_/HWNKG(//T[R`E<RX`)7,@Y?#IZ/7LY=\@[>$@
M\^'R(.7MY^SE\?[SY>D@X^GA("5S+@`E<R#E\.GH]>SEWR#MX2#KW.+EZ2#T
MZ?(@].7KY?7TX=_E\B#PZ^?Q[_;O\=_E\B#CZ>$@)7,N`"5S)W,@Q.GE]>CU
M[?/I[^/QW/;O\@`E<R=S(,?LY?'OZ_SCZ>\`)7-S(-/G[.7I^>SA]-SQZ>\`
M)7-S(,O?\_3A(,7QX^'SZ?[M`"<E<R<@Y.7M(.7?[>'I(-WCZO7QYR#E\.GK
M[^/>+@`G)7,G(.3E[2#=]^7I(/'UZ.SI\_3EWR#S].\@<F5G:7-T<GD@].?R
M(.7VX?'L[^/>\B!(;W)D90`E<R#A[>'PX?'A\_3<].?R(.3E[>3QZ>K>\B#D
M[^S>\B#DY>T@XO'=Z.?JY2X`)R5S)R#P\>_S]-WHY^KE(//TZ?(@[^S<Y.7R
M(//U\_3>[.'T[_(N`"<E<R<@\/'O\_3=Z.?JY2#S].GR(-SDY>GE\B#T[_4@
M\_7S]-[LX?3O\BX`)R5S)R#DY>T@Y.?LZ>_U\>/>Z.?JY3H@)7,N`"P@9W5S
M=&EN9R`E<R`E<P`L(.SE].'BZ^?TWB#A\/P@)7,@\^4@)7,`+2T@Y?#IZ^_C
MWB`M+0`Q,OGQYR#L[_'VW@`R-/GQYR#L[_'VW@`R-"#^\>7R`#QB/M#A\>_U
M\^G<\_3GZN4@W>WA(//OXN'Q_"#KW.CO\CH\+V(^`-#A\>_U\^G<\^CGZN4@
MZO'?\^GL[R#KW.CO\@#!\.'I].7?].'I(.3G[/SSZ>\@ZNOEZ>3?(%!'4"#C
MZ>$@].?M(.KQ]?#T[^/QW/;G\^<@Y>W\\B#LY^W][.'T[_(N`,'PX>GTY=_T
MX>D@Y.?L_//I[R#JZ^7IY-\@4$=0(./IX2#E\.GBY>+AW_GSYR#E[?SR(/7P
M[^/EX_'A[.S=[>_U(.SG[?WLX?3O\BX`P?#AZ?3EW_3AZ2#DY^S\\^GO+"#P
M\>_S^?#IZOP@4$=0(.KKY>GDWR#JX>D@Z]WNYRWJ^>3IZOSR(./IX2#MX2#A
M\._J\?7P]._C\>'VWO/E].4@W>WA(.S>[?7LX2X`P?#AZ?3EW_3AZ2#DY^S\
M\^GO+"#P\>_S^?#IZOP@4$=0(.KKY>GDWR#JX>D@Z]WNYRWJ^>3IZOSR(./I
MX2#MX2#U\._C\=SXY?3E(/CG]NGAZMP@W>WA(.S>[?7LX2X`P?#AZ?3EW_3A
MZ2#DY^S\\^GO+"#P\>_S^?#IZOP@4R]-24U%(.KKY>GDWR#JX>D@Z]WNYRWJ
M^>3IZOSR(./IX2#MX2#A\._J\?7P]._C\>'VWO/E].4@W>WA(.S>[?7LX2X`
MP?#AZ?3EW_3AZ2#DY^S\\^GO+"#P\>_S^?#IZOP@4R]-24U%(.KKY>GDWR#J
MX>D@Z]WNYRWJ^>3IZOSR(./IX2#MX2#U\._C\=SXY?3E(/CG]NGAZMP@W>WA
M(.S>[?7LX2X`P?#AZ?3EW_3AZ2#DY^S\\^GO(.KKY>GDWR!3+TU)344@X^GA
M(/3G[2#J\?7P]._C\=SVY_/G(.7M_/(@[.?M_>SA]._R+@#P["_L[`#0Y?'?
M(.'U]._](/3O]2#*Y>GLY>WOX_'<]N_U`-#E\=\N+BX`P?#\Z_7T[R#TW>OO
M\@#!\/SK]?3G(,S=\^<`P?#OY._WWB#AZ?3>[.'T[_(`Q>/I[>4@X?#OY.7J
M]/P`QR#P\?SSXN'SYR#A\._Q\=_VZ.?JY2#JX?3<(/3G(.3G[.GO]?'CW^$@
M5D93(.KA].'K_./O]2X`QR#P\?SSXN'SYR#A\._Q\=_VZ.?JY2#JX?3<(/3G
M(.3G[.GO]?'CW^$@5D93(.'Q]^7?[_4N`,KYY.GJ_/(@R^_CX?'IX?/L[_T`
MSR#K[^/A\>GA\^S\\B#PW./Y\^4N`,KA].'C\>'VW@#%[=WQX^7IY?(`T/'O
M\^C>ZN<`T/'O\^C>ZN<@]?#O[^S<Y.'R`-#Q[_/HWNKG(-SDY>GA\B#U\._O
M[-SDX?(@*&-H:6QD('!E<FUI<W-I;VXI`-#Q[_/HWNKG(.7D_CH`T/'O\^C>
MZN<@S=WA\B#/[-SDX?(`T/'O\^C>ZN<@[=WA\B#<Y.7IX?(`T/'O\^C>ZN<@
M]?#O[^S<Y.'R(//T[R`G)7,G`-#Q[_/HWNKG(-SDY>GA\B`H<&5R;6ES<VEO
M;BD@]?#O[^S<Y.'R(//T[R`G)7,G`-#Q[_/HWNKG(.W=[_4@]_'>\_3G.@#0
M\>_SZ-[JYR#S]-[KY_(`T/'O\^C>ZN<@[=WO]2#LW>OO]?(`T/'O\^C>ZN<@
MYN7]X^_U\@#0\>_SZ-[JYR#T[_4@)7,@\_3O(.SE[>_](/3O]2!-;WII;&QA
M`-#Q[_/HWNKG(.'U]._](//T[R#G[.7Q[^O\X^G\(.SO]0#0\>_SZ-[JYR#S
M].\@Q.GE]>CU[?/I[^/QW/;O.@#0\>_SZ-[JYR#S].\@Q.GE]>CU[?/I[^/Q
MW/;O(.SO]0#0\>_SZ-[JYR#W\=[S].<`T/'O\_3=Z.?JY2`G)7,G(//T[R#S
M_?/TY^SA+"#AZ^O<(.3E[2#L\/SQY?/A(.WA(/#Q[_/HW?/Y(//U[/#KY_'Y
M[.'TZ>K=\B#PZ^?Q[_;O\=_E\@#0\>_S]-WHY^KE("<E<R<@\_3O(//]\_3G
M[.$N(,SP[_'EW_3E(.WA(//U[>3EZ.7?].4@]/[QX2X`QR#P\>_SZ-[JYR#W
M\>?S]/[M(-WWY>D@X?#E[>7QX^_P[^GGZ.7?+@#$Z>7]Z/7M\^<`Q.GE]>CU
M[?/I[^/QW/;O\@#$Z>'WY=_QZ?/G("T@Q/[S].4@Y.GJX>G^[.'TX2#SY2#<
MZ^OO]?(@]_'>\_3E\@#$Z>'WY=_QZ?/G`,'E\>_KZ>S=[>'R(,'J]-_O]0#!
MY?'OZ^GLWNT@P>OE[N'MY/'O_?#OZ^?R`-CE]>3^[?7L[P#%]>CUX_'<[.SI
M\^4`Q?7H]>/QW.SLZ?/G.@#/Z^$`S^OOZ2#OZ2#=X^KU\>_I(/?QWO/TY?(`
MS^OE\B#OZ2#/[-SDY?(`S^OA(/3A(.3IZN'I_NSA].$`RN'I(._I(/3=\_/E
M\>GR("@T*2#PZ^7U\=WR`,WA(.7PZ?3QW?#O[?3AZ2#P[^OKX?#KW?(@Y.GE
M]>C][?/EZ?(`S>$@Y?#I]/'=\._M].'I(/'UZ.S?\^7I\B#TX>[I[>_LZ>S=
M[?GM(.OI\_3^[3L`Q^3G(/7PW/'WY>D`Q>WAZ^OAZO3IZMX@24U34"#%W_/O
MY._R`,7MX>OKX>KTZ>K\\B!)35-0(,KYY.GJ_/(`Q>WAZ^OAZO3IZOP@24U3
M4""\[>_LX2#7\=[S].<`Q>WAZ^OAZO3IZMX@Y.GE_>CU[?/G(&5M86EL`,7M
MX>OKX>KTZ>K<(/#Q_/3U\.$`Q>WAZ^OAZO3IZOP@ZN7?[.7M[SH`S_'?\_3G
MZN4@[-_A(.SG(.7PZ?3QY?#\[.7MYR#TZ>S>+@#!Y?'OZ^GLW>WA\B#!X_??
MX>OO]2X`P>7Q[^OI[-WMX?(@P>WD\>'BW^3A\BX`P>W^[?7L[_(@Q.GA[.SE
M\^_KX>+G]-[R("A0<F]X>2D`P?#<[?3G\^<`Q?;A\>SOX]X`R]_S].$@Q?;A
M\>SOX][R`,<@Y?;A\>SOX]X@Y=_MX>D@W?3OZ>SG+@#%]N'Q[._CWB#JX>D@
M\_3A(.7NX?'T_NSE[>$@ZN_I[?SW\>?S].$`Q>/J\=_M^0#!\/'?Z^GO\@#!
MY?'OZ^GLW>WA\B#!\=SN[_4`S-WCY>CO\B#A\??EW^_U(.'Q]^7I[^C=].?S
MY_(`S^WO[.$@X?'WY=_O]2#A\??EZ>C=].?SY_(`Q=_S].4@\]_C[_7QYR#C
MZ>$@].<@Y.GAX_'A]MX@].?R(.'?].?SY_(@]?#OX_'A]M[R(./IX2`E<R`_
M`,7?\_3E(//?X^_U\>_I(/STZ2#HW>OE].4@[>$@Y.GAX_'<^.7TY2`G)7,G
M(.KAZ2#\Z^7R(/3I\B#U\._O[-SDY?(_`-3=]^WG`$%30TE)(-3=]^WG`,WA
M(.;G].7?].4@Y?#IXN7BX=_Y\^<@\/'?[2#A\/P@ZMSHY2#E[=WQX^7IX2#D
MZ>'WY=_QZ?/G\CL`P>W<Z.7SYR#S].?K_NT`P>7Q[^OI[-WMX?(@P>CG[?[M
M`-3O(//U[>?L[-WM[R#EW^WAZ2#=[>$@X?'WY=_O(.?LY?'OZ^_CW^_U(//E
M(.'PW.WTY_/G(.'I]-[LX?3\\B#SX?(`T/'O\_#<Z.7IX2#DZ>'C\>'VWO(@
M[.<@]?#A\>KTWO(@[^S<Y.'R+@#0\>_S\-SHY>GA(.3IX>/QX?;>\B#LYR#U
M\.'QZO3O_2#DZ>KAZ?[LX?3O\BX`T/'O\_#<Z.7IX2#E\.7NY?'CX?/?X?(@
M[.<@]?#A\>KT[_T@Y.GJX>G^[.'T[_(N`-#Q[_/PW.CEZ>$@Y?#E[N7QX^'S
MW^'R(.SG(/7PX?'J]._](.3IX>SOZ?'A\^S=[>_U+@#0X?'E]?'I\^K\[.7M
M[^D`R>3I_/3G].7R`,']X^_U\_3O\@#'(.'UZ.7M].GJ[_#OW^?SYR#A\-WT
M]??E`,<@X?7HY>WTZ>KO\._?Y_/G(.'PW?3U]^4N("5S`,<@X?7HY>WTZ>KO
M\._?Y_/G(.'P[_'QW_;HY^KE(.'P_"#T[^T@4D%$2553('-E<G9E<BX`QR#A
M]>CE[?3IZN_P[]_G\^<@\_3O[2!&5%`M4V5R=F5R(.'PW?3U]^4N`,3IX>C=
M\^GLX2#0Y>3?X3H`P>WA[-WM[^WTX?(@X?#<[?3G\^<`U?#\XN'H\>\`U_'^
M[.$@]?#\XN'H\>_U`,O<Z._R($ME<F)E<F]S+>KYY.GJ_/(N`,O<Z._R($ME
M<F)E<F]S+;SM[^SA(-?QWO/TYRX`P>3EZ>\`SR#J_?'I[_(@ZN'TW.OOX^_R
M(./QX?;IZO[M("<E<R<@Y.7M(.+QW>CGZN4N`,+A\^GJWB#C\>'L[-X`P^7M
MW>CKZ>$`U.\@].S>[.$@(B5S(B#TY_(@Y?;A\>SOX][R("(E<R(@Y.7M(.+Q
MW>CGZN4N`-'UZ.S?\^7I\B#T[-[LX?3O\@#4_?#O\B#T[-[LX?3O\@"X[?3O
M[>$`O/'IX0#*X>D@].$@Y/WO`,KA]/[TX?3O`,O?\_3A(.SE(/3EZ^7?Y?(`
MT^?LY=_A(.3IX>WO[-[R($-23`#!\??EW^\@ZN7I[-WM[_4@]_GQZ?/LW>WO
M(.SE(.K\[.SA("A#5E,I`,GDZ?STY_3E\B#*Y>OI_NTN+BX`Q^SE\>_K_./I
M[P#0Y?'?Z^?XYR#'[.7Q[^O\X^GO]0#'[.7Q[^O\X^GO.@#'\>7LW^$`P>3]
M[>'TYR#G(.'Q]^GJ[_#OW^?SYR#T[_4@ZOGDZ>KO_2#A]?3\[.'TX2P@Y?#I
MZN_I[?GMWO/TY2#LY2#T[R#DZ>'WY>GQZ?/TW@#!Y/WMX?3G(.<@\_WMY.7S
MYR#LY2#T[^T@24U!4"U397)V97(Z("5S`,'J_?'Y\^<`P>K]\?GSYR#![>'V
M[_'<\B#0\>_BZ][LX?3O\@#!Y/WMX?3G(.<@Y.GAX_'A]MX@]._U(.'Q]^7?
M[_4@(B5S(BX`Q.4@XO'?\^KY(/#Q[_/Y\>GM_"#VW.KEZ^\@*'1E;7`@9&ER
M*2X`P>3][>'TYR#G(//U[=WWY>GA(/?Y\=_R(/3G[2#PX?'<[.7T\>\@(G1A
M<F=E=$9I;&4B+@#!Y/WMX?3G(.<@Y.GAX_'A]MX@]._U(/;AZMWK[_4@(B5S
M(BX`P>3][>'TYR#G(.3IX>/QX?;>+"`E9"#U\/;<ZN7K[_(@]?#<\??EZ2X`
MP>3][>'TYR#G(.7PX>WA].'NZ>W\[.?SYRP@[R#A\>GH[/SR(/3Y[2#EX^/Q
MX?;^[2#P[_4@Y/[SX?3E(./IX2#E\.'MX?3A[NGM_.SG\^<L(.3E[2#TX>GQ
MZ=SFY>D@[.4@]._M(.'QZ>CL_"#T^>T@X?#OZ.?JY?7LW>WY[2X`Q.4@[/#O
M\?X@[>$@Y/'O[._K[^/>\_D@[-[M]>SA(//T[^T@X?'IZ.S\(/#O]2#O\=_S
MX?3E+@#%\.GJY?;AZ]_DX0#*X?3GX^_QW^7R(.KAZ2#%].GJW?3E\@#*Z>WG
M]/P@U.?KW?;Y[>\`R>3I_/3G].7R(,KEZ^GO_0##W>SI\^SA(,KEZ^GO_3H`
MR>3I_/3G].7R(,KEZ^GO_0#$Z=SJY>WO(,KEZ^G^[3H`RNGMY_3\(-3GZ]WV
M^>WO`,K=[?3Q[P#+Y?#T[^S=\>7IY?(@T.GS]._P[^GG].GJ[_T`T._KZ?3I
MZMX@T.GS]._P[^GG].GJ[_T`T/'\Y>3Q[_(`P>OKX>/>`,'KZ^'CWB#J^>3I
MZN_]`,'KZ]SN].4@].\@_.WO[.$@ZN'I(/3G(.3IY?WH]>WSYR#P[_4@Z.$@
MXNO=\._U[2#\].'M(.3IX>+<YN_U[2#>(.'PX>WT[_WM(//E(.SG[?WLX?3<
M(//A\@#7X?'AZO3>\>'R`+CKY>/W[_(@\_WMY.7SY_(N+BX`T^?LY>G^\_3E
M(/3O(/3E]/'AX_GMW^3I[R#CZ>$@[_#OZ>'DWO#O].4@Y?'CX?/?X2CE\BD@
MZ-WKY?3E(.WA(.7J].7KY?/T[_WM(.'U]-X@].<@\_3IX^S>+@#!Y?'OZ^GL
MW>WA\B#7W^_U`,7PZ>O=[O3E(,7VX?'L[^/>.@#%\.GKW>[TY2#J^>3IZOP`
MQ?#IZ]WN].4@_.WO[.$@]_'>\_3G`,7PZ>O=[O3E(.SIX2#E[=WQX^7IX3H`
MQ?#IZ]WN].4@\/GR(.CA(.7L]N'MW^;O[?3AZ2#OZ2#G[.7Q[^SG[=_E\CH`
MQ?#IZ]WN].4@]/WP[R#KW_/TX?(@*./IX2#TX>[I[>_LY^S=[>7R(.O?\_3E
M\BD`P>7Q[^OI[-WMX?(@U_'U\^_]\._KY_(`Q.7M(.+QW>CGZN4@[_'I\^S\
M\B#JZ]SSY_(@]._U("5S+@#*X>C<\>GSY0#*X>CA\>GS[/SR(.7TZ>KE]/[M
M("AT86=S*2!-4RU/9F9I8V4`)\'DY>GA\^SA)R#7\=[S].<Z("5S`,KAZ.'Q
MZ?/L_/(@U_'>\_3G`,KAZ.'QZ?/L_/(@Y.7D[^S=[?GM(/?QWO/TYP#*W.WT
MY2#JZ^GJ(./IX2#S]>W=]^7IX0#*Z^7?\^GL[R#"[][HY>GA\@#*Z^7?\^GL
M[R#0X?'<Z/7Q[_4@PN_>Z.7IX?(`RNOEW_/I[.\@T.'QW.CU\>_U`,'MX>3?
M\.OY\^<@T.OE]?'IZM[R(,SPW/'A\@#![>'DZ?#K^>S=[>$@T.7QZ>C^\>GA
M`-?Q_NSA`,7PZ>O=ZO3G\B#7\?[LX?3O\@#%\.GK[^/>(-?Q_NSA]._R`-/T
MWNOE\CH`U-_TZ^_I(-/TY^O^[0!#;VUI8W,`Q>WT[^O>`,K=Z_7V[_(@Q>WT
M[^O^[0#3]_SKZ>\`RN_I[?P@O.WO[.$`Q?3AZ?'EW^$`S^OOZNOG\?[HY^KE
M`-/][>CE\^<@S.?M_>SA]._R("@E<RD`U?#OZ^_CZ?/TW?(`T_7MZ-[JY?(`
MQ.GA]N_QW?(@T.'QX>SE]/'O\._?Y_/G\@#%\.GK[^/=\B#CZ>$@\_7C]_'O
M[>GS[/P@[.4@4$1!<RP@W>[U\.WA(-3GZ]WV^>WA(.KAZ2!/=71L;V]K+@!$
M:64@2V]N9FEG=7)A=&EO;B!M=7-S(&%K='5A;&ES:65R="!W97)D96XN`,<@
M\.'QX>SE]/'O\._?Y_/G(/?QY>G<YN7TX>D@Y>WG[-WQ^?/G+@#0X?'A[.7T
M\>_P[]_G\^<@)7,`Q?#IXN7BX=_Y\^<@ROGDZ>KO_0#'(//][>3E\^<@X?#=
M]/7WY2X`QR#S_>WDY?/G(.'PW?3U]^4Z(`#!\>WG\^<@\_WMY.7SY_(@X?#\
M(/3O(.3G[/SSZ>\@Y>[U\.?QY?3G]-X@ZNOEZ>3I_NTN`,'Q[>?SYR#S_>WD
MY?/G\B#A\/P@].\@Y.?L_//I[R#E[O7PY_'E].?TWB#JZ^7IY.G^[2X@R_SC
M[_(@.B`E<R`H)7,I`,<@\_WMY.7SYR#LY2#T[R!&5%`M4V5R=F5R(.'PW?3U
M]^4N`,'MX>;>].?SYR#%\.'VWO(`S^D@Y?#A]MWR(/#Q[_/TW>CGZN'M(.7P
MZ?3U]_[R(//T[R#$Z>7UZ/7M\^GOX_'<]N\@\^'R+@#0Y?'IY??\[.7MX2#T
M[_4@)R5S)P#0Y?'IY??\[.7MX2#T^>T@X?'WY=_Y[2!205(`T_7MW??EZ>$`
MP>WTZ>/QX?;>`,'M].GC\>'VWB#%\.GK[^/>\@#!Y/WMX?3G(.<@ZO'U\/3O
MX_'<]N?SYR#T[_4@[.?M_>SA]._R(.SE(%!'4"X`P>3][>'TYR#G(/7P[^/Q
MX?;>(/3O]2#LY^W][.'T[_(@[.4@4$=0+@#!Y/WMX?3G(.<@ZO'U\/3OX_'<
M]N?SYR#T[_4@[.?M_>SA]._R(.SE(%,O34E-12X`P>3][>'TYR#G(/7P[^/Q
MX?;>(/3O]2#LY^W][.'T[_(@[.4@4R]-24U%+@#$Y>T@[/#\\>7SX2#MX2#P
M\>_SZ-WS^2#TY^T@Y?#A]MXN("5S`,'D_>WA].<@YR#S_>WDY?/G(.SE(/3O
M($Q$05`M4V5R=F5R+@#!Y/WMX?3O\B#O(-WKY>/O\B#U\._K[]_P[_4N("5S
M`,'D_>WA].<@YR#S_>WDY?/G(//T[^T@Y>[U\.?QY?3G]-X@)R5S)R#W\>?S
MZ>SP[^G^[?3A\B!&5%`Z("5S`,'D_>WA].<@YR#DY^SI[_7QX]_A(.O?\_3A
M\R#DZ>'M[^S>\BX@)7,`P>3][>'TYR#G(.'P[^KQ]?#T[^/QW/;G\^<@4$=0
M(.3EY._LW>WY[2X`P>3][>'TYR#G(.'P[^KQ]?#T[^/QW/;G\^<@4R]-24U%
M(.3EY._LW>WY[2X`P>3][>'TYR#G(.3IX>/QX?;>(.7PX?;>\BX@)7,`P>3]
M[>'TYR#G(.3IX>/QX?;>(.O?\_3A\B#DZ>'M[^S>\BX@)7,`P>3][>'TYR#G
M(.3IX>/QX?;>('-E='5P('5P9W)A9&4@<V-R:7!T("<E<R<@+@#$Y2#L\._Q
M_B#MX2#DZ>7UZO'I[=[S^2#TYR#DZ>7]Z/7M\^<@]._U(/#A\>'KWO#TYRX`
MP>3][>'TYR#G(/#KWO'G\B#P\?SSXN'SYR#T[_4@Q.GE]>CU[?/I[^/QW/;O
M]2X`P>3][>'TYR#G(/#KWO'G\B#P\?SSXN'SYR#TY_(@Z]_S].'R(.3IX>WO
M[-[R+@#!Y/WMX?3G(.<@\.O>\>?R(/#Q_//BX?/G(.O?\_3A\B#A\/P@Z]_S
M].7R(.3IX>WO[-[R+@#!Y/WMX?3O(/3O(/;\\?3Y[.$@\_3QX?3GX^GJWO(@
M(B5S(BX`P>3][>'TYR#G(.3G[.GO]?'CW^$@]N'JW>OO]2`B)7,B+@#!Y/WM
MX?3G(.<@X>W<ZO3G\^<@Y.?L_//I[_4@ZNOEZ>3I[_T@X?#\(/3O[2#E[O7P
MY_'E].?TWB#$Y^PNRNOEZ>3I_NTN`,'D_>WA].\@].\@W.WOZ>/LX2`E<RX`
MP>3][>'T[R#T[R#<[>_IX^SA("(E<R(@X^GA(.7CX_'A]MXN`,'D_>WA].\@
M].\@W.WOZ>/LX2#T[_4@[-WQ[_7R(,3IX??EW_'I\^?R("5S`,3E[2#L\._Q
M_B#MX2#A[>_?[OD@].\@]MSJY>OO("(E<R(N`,3E[2#L\._Q_B#MX2#DZ>'B
MW//Y("5S+@#!Y/WMX?3G(.<@X?'WZ>KO\._?Y_/G(/3O]2#J^>3IZN_](./I
MX2#T[^T@X>GT[_WLY>WO(/?QWO/TYRX@RMSP[^GA(-X@_.OE\B#OZ2#KY?#T
M[^S=\>7IY?(@Y.7M(.7?[>'I(//Y\_3=\BX@SN'MX>3OZNGLW//TY2#>(.7P
MZ>KOZ>WY[=[S].4@[.4@].\@Y.GA]^7I+?'I\_3>(.'M(/?QY>G<\^7SZ.4@
M\.7QZ?/S_/3E\><@XN_>Z.7IX2X`P>3][>'TYR#G(.'MW.KTY_/G(,O?\_3A
M\B#*X>W\[?GM(-#Q_//BX?/G\B`H04-,*0#!Y/WMX?3G(.<@X>W<ZO3G\^<@
MQ.GE]>CU[?/I[^/QW/;O]2X@)7,`P>3][>'TYR#G(.'MW.KTY_/G(,O?\_3A
M\B#$Z>'M[^S>\BX@)7,`P>3][>'TYR#G(.'MW.KTY_/G(,OI\_3^[2#$Z>'M
M[^S>\BX@)7,`P>3][>'TYR#G(.'MW.KTY_/G(/3Y[2#IY.GO]-[T^>T@]._U
M(.7N]?#G\>7TY_3>`,'D_>WA].<@YR#E\.'MX?;O\=P@\?7H[-_SY?GM+@#!
MY/WMX?3G(.<@Y.GAX_'A]MX@]N'JW>OO]2`H<FUD:7(I("(E<R(N`,3E(.SP
M[_'^(.WA(.'P[^CGZN7]\_D@)7,@\?7H[-_SY>GR+@#$Y2#L\._Q_B#MX2#J
MW.WY(.7VY>3QZ>K\(.'M]-_C\>'V[R#T^>T@\?7H[-_SY?GM+@#$Y2#L\._Q
M_B#MX2#JW.WY(.7VY>3QZ>K\(.'M]-_C\>'V[R#T^>T@\?7H[-_SY?GM.B`E
M<P#$Y2#L\._Q_B#MX2#A\._HY^KE_?/Y(/#Q_./QX>SLX2#E[>?LW?'Y\^?R
M(//T[R`G)7,G+@#$Y2#L\._Q_B#MX2#A\._HY^KE_?/Y(.7VY>3QZ>K\(.'Q
M]^7?[R#Q]>CLW_/E^>T@)7,N`,3E(.SP[_'^(.WA(.'P[^CGZN7]\_D@].\@
MX?'WY=_O(/'UZ.S?\^7Y[2`E<RX@S/#O\>7?].4@Y=_TY2#MX2#W\>?SZ>SO
M\._IWBWSY?3E(.SIX2#A\/P@].GR(.7PZ>OOX]WR(./IX2#MX2#A\._HY^KE
M_?/E].4@\-_S^2#S].\@)7,@WB#A[?3IX_'<^/3E(.SE(/3O(/?=\>D@]._M
M(.K^Y.GJX2#PW_/Y(//T[R`E<RX`P>3][>'TYR#G(.'MX>;>].?SYR#S]._M
M(.7N]?#G\>7TY_3>($Q$05`N`,3E(.SP[_'^(.WA(.'P[_/U[>3=\_D@(B5S
M(BX`Q.4@[/#O\?X@[>$@Y>WG[.7Q_O/Y(/3G[2#E\.'VWBX@)7,`Q.4@[/#O
M\?X@[>$@Y>WG[.7Q_O/Y(/3G(,O?\_3A(,3IX>WO[-[R+B`E<P#$Y2#L\._Q
M_B#MX2#C\=SX^2#TZ?(@\?7LW_/EZ?(@X^GA("<E<R<Z("5S`,3E(.SP[_'^
M(.WA(.+Q_B#TYR#PZ^7U\>GJWB#L\-SQX2#T[_4@36]Z:6QL82X@PN7BX>GY
MZ.7?].'I(/STZ2#EW^WAZ2#A[>_IZO3>+@#$Y2#L\._Q_B#MX2#D_O/Y(//T
M[R#W\=[S].<@)R5S)R#TX2#PX?'AZMST^2#DZ>KAZ?[LX?3A(//T[R#VW.KE
MZ^\@)R5S)SH@)7,`S.7T\>?LW>WO(.KEW^SE[>\`U_[QX0#0[_'EW^7R`,3G
M[.GO]?'CW^$`Q.?LZ>_U\>/?X2#E[?SR(//U[>3=\^SO]0#$Y^SI[_7QX]_A
M(.SIX?(@[=WA\@#$Y^SI[_7QX]_A(/7P[_;AZMWK^>T`Q>[O]?/I[^3O]-[S
MY>GR(,3G[.GO]?'C[_T`P?'IZ.S\\B#0Z?/T^?3IZM[R(,K<\?3A\@#%]??A
M\>GS]-_E\@#4\=WW[_7SX2#6W//G`-3QW??O]?/A(/[QX0#4[R#T\=WW[^T@
M55),(.7?[>'I`-3QW??O[2#*X>GQ_/(`U/'=]^_U\^$@\_7MZ-[JYSH@`-3Q
MW??Y[2#S]/WK`-#A\>'LY?3Q[_#OW^?SYR#DZ>'DZ>KA\^G^[2#P[_4@Y>KT
MY>OO_>WTX>D@ZN'TW"#TY^T@Y=_S[^3O("5S+@#!\._J[_#>`,'P[^KO\-X@
MY?#IZ^_CWO(`S,P`Q^SE\=[SZ>$`Q.7D[^S=[>$`Q>SVW.WI\^<@*$)R;W=S
M97(I($1A=&%4<F5E`,<@X>WAYM[TY_/G(//TYR#"W//G(,3EY._LW>WY[2#A
M\-WT]??E+@#'[.7Q[^SG[=_A`,?LY?'O[.?MW^$@\.'QX>OAXM[R`,7PZ>OO
MX]X@Q^SE\>_LY^W?X?(`Q^S=\>$`Q.GAX_'A]MX@T_3>Z^?R`,3EZMWLXO'I
M[_(`Q.7JX>3IZN_?(.'QZ>CL[]\`N/?O]>T@X?'MY^CEWP#,Y=_Y\^<@T.7Q
MZ>CY\=_O]0#0\>_JX>CO\>GS[-WM[P#0\>_E\.GKY>/LW>WO(-?Q_NSA`-#Q
M[^7PZ>OEX^S=[><@U.'U]/STY_3A`-#Q[^KAZ._QZ?/LW>WE\B#%[N_U\^GO
MY._TWO/EZ?(`T/'OZN'H[_'I\^S=[>7R(,7N[_7SZ>_D[_3>\^7I\@#/\>GS
M[._?`,C=\^<@X>WTZ?#Q[_/^\._U`,'M].GP\>_S^?#G[-WM[P#$Z>'C\>'V
MW@#$Z>'C\>'VWB#/[-SDX?(`Q.GAX_'A]MX@Q>[O]?/I[^3\].?SY_(`Q.GA
MX_'A]MX@ZN'I(.7JZMWM^?/G(.SG[?7LW/3Y[0#$Z>'C\>'VWB#JY>OI[_T`
MQ.GAX_'A]MX@T_3>Z^?R`,3IX>/QX?;>(/7PW/'W[^WT[_(@Y>WAZ^OAZO3I
MZN_](/#Q[_3]\._U`,3IX>/QX?;>(.7N[_7SZ>_D[_3>\^7Y[2#CZ>$@)R5S
M)P#$Z>'C\>'VWB#E[N_U\^GOY._TWO/E^>T@X^GA("<E<R<@ZN'I(.K<Z.4@
M]?#O+>7N[_7SZ>_D_/3G\^<[`,3IX>/QX?;>(//TWNOG\@#0\>_E\.GKY>/L
MW>WG(-3A]?3\].?TX0#$Z>'C\>'VWB#T\=WW[_7SX?(@\_3>Z^?R`,3IX>/Q
MX?;>(/3QW??O]?/A\B#C\>'L[-[R`,3IX>/QX?;>(.'U]-[R(/3G\B#E[N_U
M\^GOY/STY_/G\B#JX>D@ZMSHY2#U\.\MY>[O]?/I[^3\].?SY_([`,3IX>/Q
MW/;GZN4@].\@<V5T=7`@=7!G<F%D92!S8W)I<'0@)R5S)RX`O_'A(-SVZ>[G
M\@#!\>WG\^<@X>GTWNSA]._R`,'Q[>?SYR#AZ?3>[.'T[_(@X^GA(/#KY_'O
M]N_QW^7R(.3IX>CE\^GL_/3G].'R`-#E\>GC\>'VWB#T[_4@T/'OXNO>[.'T
M[_(`T.7QZ>/QX?;>`,OE\/3O[-WQY>GE\B`HY?#?\^?R(.KAZ2#S].\@X?'W
MY=_O(.KA].'C\>'VWO(@]._U($AO<F1E*3H`S^D@Z^7P]._LW?'EZ>7R(-WW
M[_7M(.KA].'C\>'VY=\@X^GA(/3O[2#DZ>'WY>GQZ?/TWBX`P>W<\/3U[N<`
MT^?LY=_O(,3Q[_/IW/(`T^?LY=_O(,3Q[_/IW/(@X^GA(/3G[2#TY>OE]?3A
MW^$@_O'A.B``T^?LY=_O(,3Q[_/IW/(Z(`#*X?3E_>CU[?/G(.'P_"#A\>GS
M].7QW"#P\>_R(/3A(.3E[NG<`,KA].7]Z/7M\^<@X?#\(/3A(.3E[NG<(/#Q
M[_(@].$@X?'I\_3E\=P`RN'TW.OOX^_R`,7L]MSMZ?/G(/[QX?(@\^4@,C3Y
M\><@[._Q]MX[`,7PZ>OOX]WR(,7L]MSMZ?/G\@#%[/;<[>GSYR#P\>_BZ]WX
MY?GM("A4048I`,SO\?;>(,7L]MSMZ?/G\@#%[>?LW?'Y\^<@Q.G<].'NY_(`
MS.<@Y.GAX_'<]N7I\@#,Y^T@Y?#I]^7I\=[SY?3E(.WA(.'M[]_NY?3E(.'P
MY?7HY=_A\B#T[R#A\??EW^\@;6%I;G1E;F%N8V4N<&AP`-#E\>G=]^7I(.<@
M\/'^].<@X_'A[.S>(._M_.SA].$@\.7DW_GM.R#![2#MX>D@]//EZMSQY?3E
M(.'U]/PZ`,KA]-WBX?/LX0#*X?3=XN'S[.$@)7,`RN'TW>+A\^SA(/3O]2#A
M\??EW^_U(/#A\>'LW?3Q^>T@\^'M(%!(4"US8W)I<'0N`,O?\_3A(,KA].'Q
MW.KTY_(`UMSQ[.'JX2WMX?'J^?3IZMP`Q?#E[N7QX^'SW^$`Q?#E[N7QX^'S
MW^$@0FQO8VL`Q?#E[N7QX^'SW^$@S^S<Y.'R`,7PY>[E\>/A\]_A(,7N[_7S
MZ>_D_/3G\^?R`,7PY>[E\>/A\]_A(,7N[_7SZ>_D[_3>\^7Y[0#%\.7NY?'C
MX?/?X2#%[N_U\^GOY._TWO/E^>T@X^GA("5S`,7PY>[E\>/A\]_A(.7PZ>OO
MX_[M(./IX3H`Q?#E[N7QX^'SW^$@Q>[O]?/I[^3O]-[SY?GM(./IX2`E<P#%
M\.7NY?'CX?/?X2#%[N_U\^GOY._TWO/E^>T@X^GA("<E<R<`P>7Q[^OI[-WM
MX?(@Q>OE]?/?[>'R`-/T[^GWY=_O+BXN`,'KZ^?K[^/QX?;?X0#$Z>7]Z/7M
M\^<@16UA:6P`QR#DZ>7]Z/7M\^<@16UA:6P@\/'=\.7I(.WA(/3AZ?'IW.;E
MZ2X`S-[M]>SA(.SE(/'UZ.S?\^7I\@#!Z?/HWNSA].$`RN7M_"#LWNWU[.$N
M`,3E[2#E\.GS]/'<]N?JX>T@P?#O].7KW?/LX?3A+@#!Y.7IY?(@\_7MZ-[J
MY?(@X>WAYM[TY_/G\@#%[>7QX^_P[]_G\^<@Y>GSX>/YX][R(.7IZOSM^>T@
MX?#O(%!H;W1O($-A;&QE<FEE=R#S].\@ZN7?[.7M[SL`S>$@Y>WE\>/O\._I
MY^CEWR#T[R#LY>WO_2#LY2#DY>[?(.KKZ>H[`-3=Z^_R`+CT[_(@U-WK[_7R
M`,SEX]WMZ/7SYR#*Y>GLY>WOX_'<]N_U`,3^\_3E(.SIX2#E\?[TY_/G(.'S
M]N'KY=_A\BP@YR#O\._?X2#HX2#SX?(@YN?TY^CEWR#A[2#W\>7IX?/HY=\@
M[>$@X>OKW.[E+?3E(/3O[2#J^>3IZOP@\^'R+"#P+O<N("?0[^G\(.7?[>'I
M(/3O(/SM[^SA(/3O]2#JX?3OZ>KIY-_O]2#SX?([)SH`Q/[S].4@].<@\_WM
MY.7SYR#TY_(@Y>GJ_.WA\B#EY/X`R]SH[_(`R]SH[_(@X?#O\_3=Z^OO[?3A
M\B#A\-SM].?SYSH@)7,`R]SH[_(@[.4@[-[M]>SA(&5M86EL+@#+W.CO\B#C
M\=SV[^WTX?(@(B5S(BX`Q>CMZ>K\`,7U\?[PYP#*W.CE(#$U(.OE\/3<`,K<
MZ.4@,B#+Y?#TW`#*W.CE(#,P(.3E]?3E\?SKY?#TX0#*W.CE(#4@Z^7P]-P`
MRMSHY2#V[_'<(/#O]2#L\.'?[>7TY2#S].?M(/7PY_'E\]_A`,K<Z.4@[.GS
MWB#^\>$`RMSHY2#KY?#T_`#0X?'AY.7IX^SA].GJW?(@].GLW?(Z`,7J]-WK
MY?/G`,7PW>KTX?/G`,7PW>KTX?/G(-#KY?7QZ>K>\B#,\-SQX?(`P>WA[.7M
M_.SE[>\@(D)%1TE.(B#S].<@X_'A[.S>("5D+@#![>'LY>W\[.7M[R`B14Y$
M.B5S(B#S].<@X_'A[.S>("5D+@#![>'LW>WO[?3A[2`G*2<`P>WA[-WM[^WT
MX>T@X?#KWB#KW>[G(-X@\_7MZ-[JYR#A[>'FWO3G\^?R(//E(.7I\^'C^>/I
MZMP`Q^SE\>_LY^W?X2#+WN[G\@#%ZNC=].?R`-?Q_NSA(/#Q[_/JWNWI[_4`
MT?7H[-_SY>GR(./IX2!&5%`@=7!L;V%D`,'P[_3U]]_A(.KA]-P@].?M(/#Q
M[_/PW.CEZ>$@X>W<ZO3G\^?R(/3Y[2#P\>_TZ>S>\^7Y[2X`P?#O]/7WW^$@
M\_WMY.7SY_(@\_3O[2#DZ>'J[^SI\_3>(,KA].'K_./O]2X`P?#O]/7WW^$@
M\_WMY.7SY_(@\_3O[2!334(M4V5R=F5R+@#!\._T]???X2#A[?3IX_'A]M[R
M(.'P_"`B)7,B+@#!\._T]???X2#A[?3IX_'A]M[R(//E("(E<R(N`,'P[_3U
M]]_A(.3G[.GO]?'CW^'R(//][>3E\^?R(%-!4TPN`,'P[_3U]]_A(.SE].'V
M[_'<\B#SY2`B)7,B+@#!\._T]???X2#JX?3<(/3G[2#AZ^OAX]X@ZOGDZ>KO
M_2#CZ>$@]._M(/?QWO/TYR`E<R#A\/P@].\@\_3AZ.S\("5S+"#K_./O\B`E
M<P#!W^CQZ>_R`-#OZ_T@\^_BX?'\(,O<Z._R.@#6P<X`UN7B\>_UW/'I[_(`
MQ.G<Z.7SYR#CZ>$`Q.G<Z.7SYR#CZ>$Z(`#+W^/E\B#B\>_WW?(`R]_CY?(@
M]^GO[>_P]/[SY>GR`-#?[>'JX?(@T.7DW^_U`,'QZ>CL_/(@X?'WY=_O]3H@
M)7,@X?'WY=_O`,'QZ>CL_/(@X?'WY=_O]3H@)7,@X?'WY=_A`,3IX??EZ?'I
M\_3>\B#!\??EW_GM`+SM[^SA(,'Q]^7?[_4`Q?#IZ^_CWB#!\??EW^_U`"?!
M[=WBX?/LX2<@P?'WY=_O]0`GP>W=XN'S[.$G(,'Q]^7?[_4@Y.7M(/7P[_/T
MY_'?YN7TX>DN`-;?Z_3QX0#0\?[T[R#,Z?/\`-#Q_O3O(-3=].'Q].\`T_3A
MZ.7Q_/(@Z_SC[_(`1FQI<`!&;&]A=`#/[-_WZ^<`SR#VW.KEZ^_R("5S(.3E
M[2#U\-SQ]^7I`-?Q_NSA(./QW.SLX?3O\@#4\>_VW@##Z>$@0G)O=W-E<G,L
M(/#O]2#DY>T@]?#O\_3G\=_F[_7M(.7IZOSMY?(`SN7WW//A].4@]._M(.KY
MY.GJ_"#SX?([`-;\\>SE\@#0\?SBZ^7XYP#4_?#O\B#0\?SBZ^7XY_(`T/'O
MXNO=^.7I\@#0\>_BZ]WXY>GR(#(`1F]R=6US`-#Q[_GHWO/EZ?(`T.$`T.OA
MW_/IX0#0Z^?Q[_;O\=_E\B#$Z>'HY?/I[/STY_3A\@#!\-SM].?SYR#$Z>'H
MY?/I[/STY_3A\@#!W_3G[.$@Q.GAZ.7SZ>S\].?TX?(`P?#<[?3G\^<@\^4@
MX=_TY^SA(,3IX>CE\^GL_/3G].'R`,'P_`#!\/P@].\@`,'MX>OU].GJWB#0
MY?'IX_'A]MX`P>WAZ_7TZ>K>(-#E\>GC\>'VWCH`T.O>\>?R(-/EZ][MYP#0
MZ][QY?(@O.WO[.$`1V%L;&5R>2#A\/P@].?M(._P[]_A(.CA(/#AW_'M[^WT
MX>D@[^D@Y>GJ_.WE\@!'86QL97)Y.@#,Z>KQ_""\[>_LX0##Y>WIZMWR(,7P
MZ>OOX]WR`,SE]-SBX?/G`,7KZ]SDX0#%Z^OG[>GJW"`H25-/+3@X-3DM-RD`
MQ.GA]^7?\>GSYR#/[-SD^>T`U.$@[^W\[.'TX2#T^>T@[^S<Y/GM(.3E[2#P
M\=WPY>D@[>$@Y=_MX>D@ZN7MW`#%[N_U\^GOY._TWO/EZ?(@S^S<Y/GM`,_L
MW.3E\@#)Y.G\].?TY?(@1W5E<W0`R>3I_/3G].7R($=U97-T`$=U97-T8F]O
M:P#4[R#S_?/TY^SA(.'UZ.7M].GJ[_#OW^?SY_(@2%144"#DY2#B\=WHY^KE
M+@"^^._R`,+OWNCEZ>$`PN_>Z.7IX2#CZ>$@].<@]_'>\^<@]._U(.KEZ>SE
M[>_C\=SV[_4`PN_GZ/SR`,?LZ?/VX=_QZ>\`P>7Q[^OI[-WMX?(@Q_'AZNOE
MW^_U`,7D_B#EW^WAZ2#G(.'Q]]X@]._U(.'Q]^7?[_4Z`-CGZ]P`QR#EX^/Q
MX?;>(.GS]._QZ>KO_2#DY>T@\/'=\.7I(.WA(.7?[>'I(.KE[=X`P?'WZ>K>
M(-/EZ]_DX0#!\??IZMX@T^7KW^3A`,3IY?WH]>WSYR#3\.GTZ>_]`-3GZ]WV
M^>WO(-/PZ?3I[_T`P?'WZ>K>(-/EZ]_DX0#%W_/OY._R(//TY^T@U?#G\>7S
MW^$@Q\OEZO3Q[^WIZN_](-3A]_7D\>_LY=_O]0#3_?/TY^SA("=(;W)D92<`
M)TAO<F1E)R#!\_WQ[.'TYP#4[R#P\?SC\>'L[.$@)TAO<F1E)R#DY>T@W??E
MZ2#Q]>CLZ?/TY=\@\_GS]-P`S_'IYOSM].GO\B#*X>W\[>'R`,_QZ>;\[?3I
M[R`GX]WLZ?/LX2<`S_'IYOSM].GO.@#0^?(@]NC<\^'TY2#EY/X[("CPX?'A
MZN'K_B#MX2#T[R#A[>'VW?'E].4@\_3O(.3IX??EZ?'I\_3>(2D`T/SSY?(@
M\_3>Z^7R(.C=Z^7TY2#MX2#E[>_P[^G>\^7TY3L`T/SSX2#PY>3?X2`H\_3>
MZ^7R*2#EW^WAZ2#EZN7?.P#0_//E\B#C\>'L[-WR(.C=Z^7TY2#MX2#E[>_P
M[^G>\^7TY3L`U>/QX?/?X0#5X_'A\]_A.@#7Z>_U[._QW_/TX?(`QR#$Y^SI
M[_7QX]_A(./QX>SLX?3OZ/7QW^3A\B!)34%0(.'PW?3U]^4Z("5S`,<@Y.GA
MX_'A]MX@X_'A[.SA]._H]?'?Y.'R($E-05`@X?#=]/7WY3H@)7,`QR#$Y^SI
M[_7QX]_A(/#EZ?'O\>GS[/[M("AQ=6]T82D@X_'A[.SA]._H]?'?Y.'R($E-
M05`@X?#=]/7WY3H@)7,`Q>GSY?'W_.SE[>$`25`MQ.GE_>CU[?/G`$E0+<3I
MY?WH]>WSYR#DY>T@Y=_MX>D@Y.GAZ-WSZ>SG+@!)4"W$Z>7]Z/7M\^<@[.<@
MY?#I]/'E\/3>(.S=\^$@\^4@0TE$4BU";&]C:RX`RNOEW^3Y[.$MT.'QX>+?
MX?/G($E0+@#%Z?/E\??\[.7MX0#%Z?/AX_GCWB##\>'L[-[R(-#QZ>T`S/SM
M[R#%Z>KO[=_DZ>$`Q>GJ[^W?Y.GA(./IX2`E<P#%Z>KO[=_DZ>$@ZN'I(,KE
MW^SE[>\`S^WO[.$@].'U]/STY_3A\CH`P>T@Y.7M(.7L]N'MW^;E].'I(//Y
M\_3<+"`E<R#CZ>$@[>$@X>WOW^[EZ2#SY2#MW>\@\.'QW.CU\>\N`,'M(.3E
M(.+KW?#E].4@ZN'MW>WA(.7IZN_MW^3I[R#W\>?SZ>SO\._I_NWTX?(@]._M
M($EN=&5R;F5T($5X<&QO<F5R+"#?\_GR(/#QW?#EZ2#MX2#T\^7JW/'E].4@
MY>3^(./IX2#MX2#A\.7MY?'C[_#OZ=[SY?3E(/3G(.3IX?;<[>7IX2!03D<N
M`,'M(.+KW?#E].4@X?7T_"#T[R#LWNWU[.$@]_GQW_(@Y>GJ_.WA+"#G(.7I
MZOSMX2#P[_4@Z-WKY?3E(.WA(.KA].7BW//E].4@Y.4@[/#O\>7?(.WA(.7L
M]N'MZ?/HY=\@X?#\(/3O[2!B<F]W<V5R(//A\BX`T/'OY?#I\^K\\.GSYR#%
MZ>K\[>'R.@!54DP@Q>GJ_.WA\@#%Z>K\[>$@X?#\($=A;&QE<GD`Q>GJ_.WA
M(.'P_"!'86QL97)Y.@#!\._S]._KWB#%Z>K\[>'R`,7IZOSMY?(`Q>GSX>/Y
MX]X`R]SH[_(@ZN'TW"#TY^T@Q>GSX>/YX]XZ(`#%Z?/AX_GCWBP@PM[LX2`E
M9`#0Y>3?[R#P[_4@Y>GSWO?HYSH@)7,`T.7DW^$@\._U(.7I\][WZ.?SX>TZ
M`-/E(,7PY>[E\>/A\]_A`,7I\^'C^>/>(,/QX>SLWO(@S.7TW`#$_.CGZN4@
MZ]SH[_(@ZOGDZ>K\\B#E[=WQX^7IX?(N`,O<Z._R(/SM[^SA(/?QWO/TYR#>
M+^KAZ2#J^>3IZOSR+@#+W.CO\B#\[>_LX2#W\=[S].<@WB#E[>'KZ^'J].GJ
MWB#DZ>7]Z/7M\^<N(,[A[>'D[^KI[-SS].4@WB#E\.GJ[^GM^>W>\_3E(.SE
M(/3O(.3IX??EZ?'I\_3>(./IX2#PY?'AZ?3=\?D@XN_>Z.7IX2X`P?WNY_/G
M(-#E\>GH^?'?[_4`R>3IX=_TY?'OZ2#7\=[S].7R`-#KY_'O]N_QW^7R`-#K
MY_'O]N_QW^7R`,7I\^'C^>/>(-/TWNOG\B#,Y?3<`,7I\^'C^>/>(,7IZOSM
MX?(`Q>GSX>/YX]X@T-_MX>KA`,7I\^'C^>/>(//][>3E\^?R(%=E8@#%Z?/A
MX_GCWB#3]-[KY_(@T/'I[0#%Z?/AX_GCWB#MW>'R(//TWNOG\B#LY?3<(/3G
M[2#T\=WW[_7SX0#%Z?/AX_GCWB#MW>'R(//TWNOG\B#P\>GM(.'P_"#TY^T@
M]/'=]^_U\^$`Q>GSX>/YX]X@[=WA\B#C\>'L[-[R(.SE]-P@].?M(/3QW??O
M]?/A`,7I\^'C^>/>(.W=X?(@X_'A[.S>\B#LY?3<(/3G[2#T\=WW[_7SX0#%
MZ>'C^>/>(/#A\>'C\=SV[_4@[.7TW"#T[^T@]/'=]^_M].$@ZOSLXN\`Q>GS
MX>/YX]X@\.'QX>/QW/;O]2#P\>GM(/3O[2#T\=WW[^WTX2#J_.SB[P#%Z?/A
MX_GCWB#E[>'KZ^'J].GJ[_T@\/'O]/WP[_4`Q/[S].4@96UA:6P@Y.GE_>CU
M[?/G(//TY^T@[_#OW^$@Y?#IZ/7LY=_TY2#MX2#PX?'AZ]SBY?3E(/3O(.W=
M[R#SX?(@ZOGDZ>K\.@#%Z?/AX_GCWB#JY>OI[_T@[.7TW`#%Z?/AX_GCWB#J
MY>OI[_T@\/'I[0#%Z?/AX_GCWB#S]-[KY_(@[.7TW`#%Z?/AX_GCWB#S]-[K
MY_(@\/'I[0#%Z?/AX_GCWB#LY^W][.'T[_(`Q>GSX>/YX]X@\.'QX>/QW/;O
M]2#LY?3<`,7I\^'C^>/>(/#A\>'C\=SV[_4@\/'I[0#%Z?/AX_GCWB#C\>'L
M[-[R(.SE]-P`Q>GSX>/YX]X@X_'A[.S>\B#P\>GM`,7I\^'C^>/>(/3G\B#A
M\.'I]._][.7MY_(@X?#<[?3G\^?R(//TY^T@Y?'^].?SYR#A\_;AZ^7?X?(Z
M`,7I\^'C^>/>+\3I_/'H^?/G(,7IZOSMX?(`Q>GSX>/YX]XOQ.G\\>CY\^<@
MT_WMY.7SY_(`S.<@Y?#A\>K=\B#U\/SK[^GP[R#CZ>$@X?#O\_3OZ]X@\_3G
M(.O?\_3A(.3IX>WO[-[R+@#,YR#E\.'QZMWR(/7P_.OOZ?#O+@#!ZMWQX>GO
M\@#+W_/TX2#!ZN7QX=_Y[0#%\.GKW>[A].4@R]SH[_(@Q>W=\>/EZ>$@X^DG
M(.'U]/P@].\@\_7S].'TZ>K\+@#!ZO7Q[R!51$@N("A5<V5R($1A=&$@2&5A
M9&5R*2X`S.<@W>/J]?'G(.7VX?'L[^/>+@#!ZO7Q[R!"871C:"U)1"X`T_3<
MZ^CGZN'M(.O<Z._R(.3EY._LW>WA+@#!ZO7QYR#DZ>7]Z/7M\^<@\/'O[_'I
M\^SO_2X`S.<@W>/J]?'G(.SO\?;>(.'Q]^7?[_4`S.<@W>/J]?'O(&US9U]T
M>7!E+@#,YR#=X^KU\>\@WB#KY=_PY>D@87!I7VED+@#,YR#=X^KU\>7R(-X@
MY>OKZ?#EW_(@\.'QW.SE]/'OZ2X`26YV86QI9"!P87)E;G0@<&5R;6ES<VEO
M;BX`S.<@W>/J]?'O(/#Q^?3\ZN_KZ^\N`,SG(-WCZO7Q[_(@\.'QX>O>\/3G
M\CH@)R5S)P#,YR#=X^KU\>\@ZN_I[?SW\>?S].\@X>WTZ>KEW^SE[>\`S.<@
MW>/J]?'G(.'Q]^GJWB#DZ>7]Z/7M\^<N`,SG(-WCZO7QX2#DY>3O[-WMX2!5
M;FEC;V1E+@#*X?3<Z^_C[_(@U?#A\??\[?3Y[0#0Z^'CZ>$`R>'M[_7<\>GO
M\@#)[_WKZ>_R`,GO_>WI[_(`Q?7H]>/QW.SLZ?/G`,7UZ/7C\=SL[.GSYR#S
M].\@RMWM]/'O`-#KWO'G\B#%]>CUX_'<[.SI\^<`Q?7H]>/QW.SLZ?/G(,'Q
MZ?/TY?'<`,7UZ/7C\=SL[.GSYR#$Y>[IW`#!Y?'OZ^GLW>WA\B#*X>OA[-ST
MX?(`P>7Q[^OI[-WMX?(@RN'Q\-SH[_4`P>7Q[^OI[-WMX?(@RN'S]._QZ=SR
M`,WA(.KQX?3>\_D@].\@X?7HY>WTZ>K\.P#!Y?'OZ^GLW>WA\B#*Y?;AZ^_M
MZ=SR`$ME<F)E<F]S+5-E<G9E<B#A\>W>Z.?JY2#TY^T@X?7HY>WTZ>KO\._?
MY_/G+@#!Y?'OZ^GLW>WA\B#*W?'J]?'A\@#-W>$@X?#\($ME<FYE;`#$Y^SI
M[_7QX]_A(,KKY>GDZ>_]`,'P[_3]\/GLX2#*Z^7IY.GO_0#,WNKO\B#*Z^7I
MY.GO_0#4_?#O\B#*Z^7IY.GO_0#7\=[SYR#*Z^7IY.GO_0#4[R#JZ^7IY-\@
M]?#<\??EZ2#>Y.<@\_3O[2#E[O7PY_'E].?TWB#DY^S\\^GY[2#JZ^7IY.G^
M[2X`T.'IY.G<`,'E\>_KZ>S=[>'R(,KY`,'E\>_KZ>S=[>'R(,KOYMSMY_(`
MQ.G<].'NYP#!Y?'OZ^GLW>WA\B#+W/'I\^'R`-3EZ^7U].'?[R#,Z?/\`-3E
MZ^7U].'?[R#4W?3A\?3O`-3EZ^7U].'?X2#%[>?LW?'Y\^<Z`-3EZ^7U].'?
MX2#%W_/OY._R(//TY^T@]?#G\>7SW^$Z("5S`-3EZ^7U].'?X2#%W_/OY._R
M(//TY^T@]?#G\>7SW^$Z("5S(.'P_"`E<P#4Y>OE]?3AW^$@Q=_S[^3O\B#S
M].?M(/7PY_'E\]_A.B#0[_3=`,W\[._R`,3IW/3A[N<`P?;>\_3E(.KE[?P@
MX^GA(.WA(.SG[2#U\-SQ]^_U[2#PY?'IZ/[QZ>$`P?'I\_3E\=P`P?'I\_3E
M\=X@Q?#IZN7VX>O?Y.$`P?'I\_3E\=WR(-3I[-WR`-#E[?3<\_3I]^\`P>7Q
M[^OI[-WMX?(@R][L[>_U`-/][>3E\^<`T_WMY.7SYR#P[_4@Y.7?]^WEZ2#S
MY3H`T_WMY.7SYR#TY_(@Y.GE_>CU[?/G(./IX2#<[>_IX^SA(/#A\>'H_?'O
M]2#S_>WHY?/G\CL`T_7MY-WSY>GR`$QI;G5X+4-O;VMI90!,:7-T("T@SR#W
M\=[S].?R(.SP[_'EWR#MX2#DY=\@].\@]MSJY>OO`,O?\_3A(,+<\^7Y[2#$
MY>3O[-WM^>T`R]_S].$@Z.7LW/3Y[2#"[][HY>GA\@#+W_/TX2#0Z>W<ZOGM
M`,<@Y.?LZ>_U\>/?X2#KW_/TX?(@]_'G\_3^[2#=]^7I(.'PY>WE\>/O\._I
MY^CEWRX`UOSQ]/GSYRXN+@#4[_#IZMX@O_'A.B``U/SP[_(@ZN'I(/[QX0#4
M_/#OZ.7SW^$`Q=_S[^3O\@"X[N_D[_(`Q.GE\>/A\]_E\B#EZ?/\Y._U`,<@
MY=_S[^3O\B#!\-WT]??E+B#0Z>CA[?STX?3A(.3\Z.?JY2#KW.CO\B#T[R"\
M[>_LX2#7\=[S].<@WB#O(,KYY.GJ_/(N`,7?\^_D[_(@P?#=]/7WY2X`N.[O
MY._R`,SEX]SK[R#*Y=_LY>WO`,'CW/#G`-?A[.?K_`#,Z>KQW"#%Z^OG[>GJ
MW"#C\=SL[.'TX0#,Z>KQW"#KX?3I[>GJW"#C\=SL[.'TX0#,Z>KQW"#1^>SA
M^NK>(,'QW^CLY_/G`,S,`,SAX^GJ_`#!Z^OGZ^_C\>'VW^$`Q.GA]^7?\>GS
MYR!%;6%I;`#$Y^SI[_7QX]_A(-/][>3E\^?R+BXN`,3IX??EW_'I\^<@ZN'T
MY^/O\>G^[2#JX>D@]_'Y[-ST^>T@\._U(.CA(.7L]N'MW^;O[?3AZ2#A]?3=
M\BX`Q>/WY>GQW^3I[P#0Y>3?X2#'[.7Q[^SG[=_A\B#JX>D@O_'A\@#0Y>3?
MX2#EZ?/AX_GCWO(`S-SQ].GO\@"\\>GO`,SA\>K<\>GS[.$@[.4@W>WDY>GN
MYR#![>'C[?GS[-WM[_4OS.<@X>WAX^WY\^S=[>_U`,SA\>K<\>GS[.$@[.4@
MW.OKYR#=[>3EZ>[G("CP+O<N(-/G[.'M].GJ_"_!\.'M].?LW>WO*0#0Y>3?
MX2#P[_4@].'I\>G<YN_U[0#,W>/I\_3G(.7PZ?3QY?#TWB#PW_/T^?/G+@#5
M\-WQXN'SYR#O\=_O]2#LY^W][.'T[_(N`,S=X^GS].<@Z.7Q[._J\>'SW^$@
M].7KY?7TX=_Y[2`R-"#Y\?[M.B``S-WCZ?/TYR#HY?'L[^KQX?/?X2#TY>OE
M]?3AW_GM(#8@^?'^[3H@`,S=X^GS].\@[-[J[_(`S-SI[_(`P>K]\?GSYR#3
M]>W<[?3G\^?R`-#KY_'O]N_QW^7R(-/U[=SM].?SY_(`T/'\].'SYR#CZ>$@
MT_7MW.WTY_/G`,'PW.WTY_/G(./IX2#3]>W<[?3G\^<`Q>WG[-WQ^?/G(./I
MX2#3]>W<[?3G\^<`P=_TY^SA(.7MY^S=\?GSY_(@X^GA(-/U[=SM].?SYP#,
MW>OG`-/G[.7I_O/EZ?(`RN'TW//TX?/G(,SE[>_].@#3]>/W_NWE]?/G(.KE
MZ^G^[0#,WNWU[.$`U.\@[-[M]>SA(.7PZ>+EXN'I_NCGZN4@Y?#I]/7W_O(L
M(.'KZ]P@].\@\.GS]._P[^GG].GJ_"#T[_4@]?#OX_'<]N_M].$@Y.4@[/#O
M\>7?(.WA(.7PZ>+EXN'I^>CEWRX`U.\@[-[M]>SA(-WKY^[E+@#4_?#O\B#L
MY^W][.'T[_(`RN'I\?SR(.'P_"!-971A<@!-971A<B!B;&]C:R!N;W0@879A
M:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA
M=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@#,W>COY._R
M`,<@S-WH[^3O\B`G)7,G(.3E[2#O\=_SZ.?JY0#,Y?3QZ>K\`,SE\^'?[P!-
M:6UE(%1Y<&4`S.GJ\?STY?'G(.CE\>SOZO'A\]_A(/3EZ^7U].'?^>T@,C0@
M^?'^[3H@`,SIZO'\].7QYR#HY?'L[^KQX?/?X2#TY>OE]?3AW_GM(#8@^?'^
M[3H@`,KAZ/'=\/3G\@#$Z=SV[_'A`$UI<W-I;F<@4$5!4B!P86-K86=E($A4
M5%!?4F5Q=65S="X`R^7?\.7I(/3O(&-O;F9I9W5R871I;VXN(-#QW?#EZ2#M
MX2#T[R#DY^SI[_7QX][SY?3E(.'M(.C=Z^7TY2#MX2#W\>?SZ2WL[_#OZ=[S
MY?3E(.'U]-X@].?M(.7VX?'L[^/>+@#+Y=_PY>D@].\@240@]._U(.SG[?WL
MX?3O\BX`36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"X`R^7?
M\.7I(/3O($E$(/3G\B#S_>WDY?/G\BX`Q.4`16UA:6P@RNGMY_3>\B#4Y^OE
M]OGMW^'R`,S=]/'I[_(`Q^SE\>_LY^W?X2#T\>_P[_#OW^?SY_(`U/'O\._P
M[]_G\^<@55),`,7L]MSMZ?/G(,S>[>$`S-[MX?(@ZN'I(-WT[_(`S.?MZ>'?
MX0#,Y^WIX=_A(,O?\_3A(,/EX^_M_/3Y[0#6W//EZ?(@T^7KWNWG\@#*W^WG
M\^<@ZMST^0#*W^WG\^<@X?'I\_3E\=P`RM_MY_/G(.3E[NG<`,K?[>?SYR#P
MW.WY`,K?[>?SYR#JW/3Y`,K?[>?SYR#PW.WY`-#OZ^OA\.O=\B#KW_/TY?(@
MY?#IZ^_CWO(@*.KA].'Q\=SJ].7R*0#0[^OKX?#KWB#E\.GK[^/>`,\@R^_C
MX?'IX?/L_/(@[._U`,\@Z?/T_/3O\/SR(.SO]2`H<&]R=&%L*0#'(.7L]MSM
MZ?/G(/3O]2#I\_3\]._P[_T@[._U("AP;W)T86PI`,<@T.7QW^OG^.<@[._U
M.@#!Y?'OZ^GLW>WA\B#,]?3GZ][MY_(`S]?)+"#$Q2#S]>SV^>W^`+SM[^SA
M`,'PX>GTY=_TX>D@Y>W=\>/EZ>$`Q-_J]/7O`-#O]-T`S=WA(,KA].?C[_'?
MX0#-W>$@T^7KWNWG`,W=[_(@ROGDZ>K\\@#-W>_R(,KYY.GJ_/(@*.[A[=PI
M`,W=[R#\[>_LX2#7\=[S].<@*/#Q[^'I\>7TZ>K\*0#-W>\@\.'QW.CU\>\@
M*.KE[?PI`,W=X0#/[-SDY?(@X^GA(.W=X2`H;F5W<V=R;W5P<RD`Q?#\[.7M
M[P#%\/SLY>WG(-/EZ]_DX0#%\/SLY>WG(-;<\^<`Q?#\[.7MY?(@Q?#IZ^_C
MW?(`S_?I`,3E[2#U\-SQ]^7I(.3IX>C=\^GL[R!C;VYF:6=U<F%T:6]N(./I
MX2#MX2#DY=_N^2#DZ>'V[_'=\BX`Q.7M(/7PW/'WY>D@Y.GAZ-WSZ>SG(//T
M\>'TY^/IZMX@X^GA(.3G[.GO]?'CW^$@25-/(&EM86=E<RX`Q.7M(/7PW/'W
MY>D@\/'\]/7P[R#CZ>$@0F%T8V@N`,3E[2#U\-SQ]^7I($)L;V-K(//TY^T@
MX>GT[_WLY>WG(.C=\^<`Q.4@Y/SHY^KE(/SM[^SA(./IX2#A]>CE[?3IZN_P
M[]_G\^<@34-!3"X`Q.7M(/7PW/'W[_7M(.'KZ^'CW?(N`,3E(.SP[_'O_>T@
M[>$@\/'O\_3EZ._][2#E[N_U\^GOY._TWO/EZ?(@ZMST^2#A\"<@X?7T_"#T
M[R#E\-_PY>3O+@#$Y>T@[/#O\>_][2#MX2#P\>_S].7H[_WM(/7P[^KA].?C
M[_'?Y?(@\^4@X?7TWB#TY^T@Y>[O]?/I[^3\].?SYRX`Q.7M(._QW_/HY^KA
M[2#PZ^?Q[_;O\=_E\B#Q]>CLW_/E^>T@X^GA("5S+@#$Y>T@[_'?\^CGZN'M
M(/#KY_'O]N_QW^7R(/'UZ.S?\^7Y[2#CZ>$@1E10(%9&4RX`Q.7M(-WW[_7M
M(/'UZ.SI\_3EWR#OZ2#PZ^?Q[_;O\=_E\B#CZ>$@].?M(/7PY_'E\]_A(,KA
M].'K_./O]2X`Q.7M(-WW[_7M(/'UZ.SI\_3EWR#OZ2#PZ^?Q[_;O\=_E\B#C
MZ>$@].GR(.KA].?C[_'?Y?(@].?R(%-13"X`Q.7M(-WW[_7M(/'UZ.SI\_3E
MWR#OZ2#PZ^?Q[_;O\=_E\B#CZ>$@].GR(/#Q[_3I[-[SY>GR(/3G\B!344PN
M`,3E[2#=]^_U[2#Q]>CLZ?/TY=\@[^D@\.OG\>_V[_'?Y?(@X^GA(%-13"!6
M1E,N`,3E[2#=]^_U[2#Q]>CLZ?/TY=\@[^D@\.OG\>_V[_'?Y?(@X^GA(/3G
M[2#A]>CE[?3IZN_P[]_G\^<@\_3G[2!344PN`,3E[2#=]^_U[2#Q]>CLZ?/T
MY=\@[^D@\.OG\>_V[_'?Y?(@X^GA(%-13"U&:6QE(%9&4RX`Q.7M(-WLY>GM
MY2#PW_/T^?/G+@#$Y2#D_O/A].4@\/'O[_'I\^S\+@#$Y2#V[_'T_NCGZN'M
M(.'Q]^7?X0#$Y2#B\=WHY^KA[2#EZ>KO[=_DZ>$N`,3E[2#O\=_SZ.?JY2#T
M[_#OZ.7SW^$N`,3E(.3^\^'TY2#LWNWU[.$N`,3E[2#O\=_SZ.?JY2#\[>_L
MX2X`Q.7M(._QW_/HY^KE(.'QZ>CL_/(N`,3E[2#U\-SQ]^_U[2#D]?/<\>7S
M].7R(/#Q[^+KW?CEZ?(`Q.7M(.7JZO'E[._][2#EW_/OY._I+@#/Z2#P\>_T
MZ>S>\^7I\B#DY>T@Y=_MX>D@Y.GAZ-WSZ>SE\BX`Q.7M(/7PW/'W[_7M(.KA
M[?SMY?(`Q.7M(/7PW/'W[_7M(/#KY?7QW?(`Q.7M(/7PW/'WY>D@\/'O\_GQ
MZ>W\\B#W_O'O\B#CZ>$@[.W>[.<@8V%C:&4N`,3E[2#D_.CGZN4@_.WO[.$@
M]_'>\_3G(-XOZN'I(.KYY.GJ_/(N`,3E[2#E\.GS]/'<]N?JX>T@W>/C]?'A
M(%A-3"#DY>3O[-WMX0#$Y>T@]?#<\??O]>T@].GLW?(`Q.4@XO'=Z.?JY2#=
MZN3O\^<@\_3O(.'Q]^GJ_"!C;VYF:6=U<F%T:6]N+B#.X>WAY.?LZ>_U\>/>
M\_3E(/3O+@#$Y2#B\=WHY^KE(-WJY._SYR#S].\@X?'WZ>K\(//A\B!C;VYF
M:6=U<F%T:6]N+B#.X>WAY.?LZ>_U\>/>\_3E(/3O+@#*X>W=[>'R(-/U[.SE
M]-WW^>T`RN'L[-_A`,KA[=WMX2`HU_'>\^<@\/'OZN'H[_'I\^S=[>_U*0#"
M_/'EZ>\@Q^SI\_;AW_'I[P"\]^D@S.7TW`"\]^D@T/'I[0#$Y>T@Y=_MX>D@
MZN'TW.OOX^_R`,3E[2#=]^7I(._K[^KKY_'YZ.7?+@#$Y>T@W??IY2#TY>CE
MWP#$Y>T@]?#O\_3G\=_FY?3E+@#3Y^SEZ?[SY>GR`-/G[.7I_O/EZ?(@+2#0
MY?'?Z^?XYP#/Z2#SY^SEZ?[SY>GR(.7?[>'I(.SIX2#E]N'Q[._CWB#P[_4@
M\^'R(.7PZ?3QW?#EZ2#MX2#DY^SI[_7QX][SY?3E(/3O(.'M]-_S]._I]^\@
M]/GM(.K?]/'I[?GM(.SIZO'^[2#WX?'TZ?[M(//T[^T@]?#OZ^_CZ?/TWBX@
MS/#O\>7?].4@[>$@Y.?LZ>_U\>/>\^7TY2P@[>$@]/'O\._P[^G>\^7TY2P@
M[>$@Y.GAX_'<^.7TY2#JX>D@[>$@]/7P_O/E].4N(,SP[_'EW_3E(.7PW_/G
M\B#MX2#XW.[E].4@\_3I\B#SY^SEW_GSY>GR(//A\B#CZ>$@[>$@Y>WT[_#?
M\^7TY2#LZ>$@\.OG\>_V[_'?X2X@U?#O\_3G\=_FY?3AZ2#JX>D@Y>GSX>/Y
MX]X@+2#E[N'C^>/>(/3Y[2#SY^SEZ?[SY?GM+@#3Y^SEZ?[SY>GR.@#4W_#O
M].$@X^GA(.7L]MSMZ?/G+"#E\.GS]/'O]MXN`,'MX>KOZ>W^\^7I\@#4[R#P
M\?SC\>'L[.$@\._U(.3IX??EZ?'?YN7TX>D@].GR(.7IY._P[^G>\^7I\B`E
M<R#DY>T@XO'=Z.?JY2X`S>_=[.+QZ>_R`,'QZ>CL_/(`P?'IZ.S\\B#WX?'A
MZO3>\?GM`,'QZ>CL_/(@\_3GZ_[M`,'QZ>CL_/(@\_3GZ_[M(//TY^T@Y>SV
MW.WI\^<@].?R(/#E\=_KY_CG\CH`P?'IZ.S\\B#C\>'L[/[M`,3E[2#O\=_S
MZ.?JY2#A\>GH[/SR(./IX2#E[>?LW?'Y\^<@]/GM(.OI\_3^[2#DZ>'M[^S>
M\BX`P>WTZ>KEW^SE[>\`Q.?LZ>_U\>/\\B#![?3IZN7I[-WM[_4`Q>[O]?/I
M[^3O]-[SY>GR(,3G[.GO]?'C[_T@P>WTZ>KEZ>S=[>_U`,_J].'DZ>K\\@#/
MZO3^XO'I[_(`UM_K]/'O(/#Q[_/B[^O^[0##\>'VY=_O`-#AZ^G\\B#*^>3I
MZOSR`,S\[>\@24U!4"U397)V97)S(/7P[_/TY_'?YN_U[2#J[_7M_/?QY_/T
M[_7R(/;AZMWKZ^_U\BX`S/SM[R#D]?/<\>7S].7R(/#Q[^+KW?CEZ?(`S/SM
M[R#LZ>$@16UA:6P@Y.GE_>CU[?/G(.7PZ?3QW?#E].'I+@#,_.WO(.\@Z>3I
M[^KTWO3G\B#>(.\@Y.GA]^7I\>GS]-[R(//U\_3>[.'T[_(@[/#O\>7?(.WA
M(.'KZ]SNY>D@].?M(.GDZ>_J].?SW^$@WB#TZ?(@Y>[O]?/I[^3O]-[SY>GR
M(/3O]2#IY.GOZO3>].<@X^GA(.KOZ>W>(/?QWO/G+@#![>_IX^SA(//E(.W=
M[R#PX?'<Z/7Q[P!/<&5N4U-,+<O<Z._R.B#$Y>T@[/#O\?X@[>$@XN/<Z_D@
MY.7D[^S=[>$@X?#\(%,O34E-12#U\._CY>/QX>SLW>WO(.S=\>_R+@#![>_I
MX^SA(.'U]-[R(/3G\B#S_>WDY?/G\B#SY2#MW>\@\.'QW.CU\>\`R^7I]._U
M\>/IZOP@T_WS].?LX0#0\>_E\>'I].GJ_/(@T_7L[.7TW??Y[0#%\.GK[^/=
M\@#%\.GK[^/=\B#CZ>$`Q?#IZ^_CW?(@X^GA("5S`-3A[NGM[^SG[-WMYR#+
MW_/TX0#/\>/A[>GS[/SR`-3LWNSA(,_QX^'MZ?/L[_T`S_'CW.WY\^<`P?7H
MY>WTZ>K\(/#Q_/3U\.\@Y?;A\>SOX][R`,'UZ.7M].GJW"#P\?ST]?#A(/-E
M("5S.@#!Z^OO`,'KZ^7R(-#KY_'O]N_QW^7R`,7N[_7SZ>_D[_3>\^7I\B#)
MY.GOZO3>].<`QR#!]>CE[?3IZN_P[]_G\^<@4$%-(.3E[2#EW^WAZ2#DZ>'H
MW?/I[.<N`-CG]NGAZMX@U?#OX_'A]MX@4$=0`,KQ]?#T[^/QX?;G[-WMX2#D
MY>3O[-WMX2!01U``Q.?L_//I[R#*Z^7IY-\@4$=0`-7P[^/EX_'A[.S=[>$O
MRO'U\/3OX_'A]N?LW>WA(%!'4"#DY>3O[-WMX0!02%`@RO[DZ>KA\@!02%`@
MRMWK]?;O\@!02%`@RMWK]?;O\@##W>SI\^SA`,KYY.GJ_/(`SR#J^>3IZOSR
M(-SKZ^'NY2#CZ>$@]._M(/?QWO/TYR`E<R#A\/P@].\@\_3AZ.S\("5S`,O<
MZ._R(.KYY.GJ_/(`P?#AZ?3EW_3AZ2#J^>3IZOSR(./IX2#A]>CE[?3IZN_P
M[]_G\^<@4D%$2553+@#*^>3IZOSR(.SE(.7PZ>+EXN'?^?/G`,KYY.GJ_/(Z
M`,KYY.GJ_/(Z(`#/(.KYY.GJ_/(@\/'=\.7I(.WA(/3AZ?'IW.;EZ2X`R]_S
M].$@T.7QX?/LW>WY[2#CY>/O[?ST^>T`Q?#IZOSKZ^?SYP#%\.GJ_.OKY_/G
M(.'P_"#T[R!C;&EP8F]A<F0`Q.GAY/'O[-X`Q=_S[^3OZ2#P[_4@Y>KJ\>7L
M[_WM.@#![>CQ^?#OZ0#0[_/O\_3\`,7J]-WKY?/G(,OEZ?3O]?'CZ?[M(-/U
M[?3>\>?SY_(`Q>KTW>OE\^<@R^7I]._U\>/I_NT@T_7M]-[QY_/G\B#JX?3<
M(/3G[2#EW_/OY.\[`,7N[_7SZ>_D_/3G\^<`Q>[O]?/I[^3\].?SYR#CZ>$@
M)R5S)R#DY2#DZ>'C\=SVY^KE+@#$Z>'WY=_QZ?/G(,7N[_7SZ>_D[_3>\^7Y
M[0#%[N_U\^GOY._TWO/EZ?(@X^GA`-#Q[_/Y\.GJW?(@\.OG\>_V[_'?Y?(`
MRN'T[^GJW^3IX0#4Y^O=]OGM[P#6^?3OX_'A]M_E\@#%Z>KO[>_S]._I]^7?
MX0#*[^GM[_3U\-_E\@#0X?'AZN'K_B#JW.WTY2#JZ^GJ(//E(.K<\._I[R#J
MY>O?`-#A\>'JX>O^(.7PZ>+EXN'I_O/TY2#\].D@Z-WKY?3E(.WA(.3IX>/Q
MW/CE].4@X?7T_"#T[R#S]._I]^7?[SH`T.'QX>KAZ_X@Y?#IXN7BX>G^\_3E
M(/STZ2#HW>OE].4@[>$@X?#O\_7MY-WSY?3E(.'U]/P@].\@\_3OZ??EW^\N
M`-#A\>'JX>O^(.3^\_3E(.S>[>$@ZN'I(-WT[_(N`-#A\>'JX>O^(.3^\_3E
M(-WMX2#\[>_LX2#CZ>$@].<@[=WA(.KA].?C[_'?X3H`T.'QX>KAZ_X@Y/[S
M].4@[.GA(-WCZO7QYR!)4"#DZ>7]Z/7M\^<N`-#A\>'JX>O^(.3^\_3E(.SI
MX2#=X^KU\><@Y^SE\>_LY^W?X2P@Y>O=[O3E(/3O[2#A\>GH[/P@]/GM(.?L
MY?'^[2#T[_4@[-[MX2X`T.'QX>KAZ_X@Y/[S].4@W>/J]?'G(/[QX2X`T.'Q
MX>KAZ_X@Y/[S].4@].\@[=WO(.KYY.GJ_"#SX?(`T.'QX>KAZ_X@Y/[S].4@
M[.GA(/#E\=_KY_CG(/3O]2#P\>_BZ][LX?3O\BX`T.'QX>KAZ_X@Y/[S].4@
M]._M(.KYY.GJ_"#SX?(`T.'QX>KAZ_X@Y/[S].4@].\@O.WO[.$@U_'>\_3G
M`-#A\>'JX>O^(.3^\_3E(/3O(/SM[^SA(.KAZ2#T[^T@ZOGDZ>K\(//A\@#3
M]>SPZ^?Q_O/TY2#T[R#\[>_LX2#W\=[S].<@[.4@]._M(/3O[-WA("A`97)M
M:7,N>61T*0#0X?'AZN'K_B#DZ>'BW//TY2#T[R#AZOSK[_7H[R#JY=_LY>_M
M+B#0\=WPY>D@[>$@\_7L]OGMY=_TY2#LY2#T[_7R(/SQ[_7R(./IX2#MX2#W
M\>?SZ>SO\._IWO/E].4@X?7T_"#T[R#S_?/TY^SA+@#0X?'AZN'K_B#DY=_T
MY2#TZ?(@X>K\Z^_UZ.7R(/#KY_'O]N_QW^7R(.KAZ2#E\.GKW>[TY2#LZ>$@
MY>W=\>/EZ>$@X?#\(/3O(/#A\>'JW/3Y(.SE[>_]+@#0X?'AZN'K_B#E\.GK
MW>[TY2#LZ>$@Y>W=\>/EZ>$@X?#\(/3O(/#A\>'JW/3Y(.SE[>_]+@#0X?'A
MZN'K_B#D_O/TY2#T[R#\[>_LX2#TY_(@[=WA\B#JX?3GX^_QW^'R.@#0X?'A
MZN'K_B#E\.GBY>+AZ?[S].4@].\@[=WO(.KYY.GJ_"#SX?(`R-WSYR#A]?3>
M\B#TY_(@Y>GJ_.WA\@#4[_#OZ.7T_NWTX?(@X?7T_"#T[^T@\-_MX>KA`,'P
M[_/T[^O>(//E(.'U]/P@].\@]MSJY>OO("CDY>T@]?#O\_3G\=_FY?3AZ2#A
M\/P@].\@24U!4"D`S>$@\/'O]-SS\^_M].'I(.3][R#PX?WKY?(@\/'?[2#T
MY^T@]?#OX_'A]MX@\^'R("@G+2TG*3L`RN'TX>KQWNSMZ?/G(./IX2#TZ?(@
M].7KY?7TX=_E\B`E<R#^\>$HY?(I.B``4')E9G-?;&1A<#H@Q.4@XO'=Z.?J
MY2#G(.'PX>GT[_WLY>WG(.7PW>KTX?/G($Q$05`N`%!R969S7W-E<W-I;VXZ
M(,3E(.+QW>CGZN4@YR#A\.'I]._][.7MYR#E\-WJ].'SYR#S]>WEY/'?X?(N
M`-#A\>_U\^G<\^7I\@#0W^7SYP#0W^7SYR#S].\@Y?#?\.7D[R#TY_(@Z-SK
MX?/SX?(Z(`#0W^7SYSH@`-#Q[^7PZ?/J_/#I\^<`T/'OY?#I\^K\\.GSYR#T
MY_(@Y>GJ_.WOX?(@\^4@[=WO(/#A\=SH]?'O`-#Q[^?C[_WLY>WG(-/EZ]_D
MX0#0\>_GX^_][.7MY?(@Q?#IZ^_CW?(`Q>KT_?#Y\^<@Y>/C\=SV[_4`T/'O
M\_GPZ>K\(,KKY>GDWP#0\?SBZ^?LX0#0Y?'IX_'A]MX@T/'OXNO>[.'T[_(`
MN/'C[R`H<')O:F5C="D`RN7?[.7M[R#P\>_T\>_PWO(`Q.?L_//I[R#*Z^7I
MY-\`P>OC_/'IZ.SO\B#$Y^S\\^GO]2#*Z^7IY.GO_0#4[R#FY?WC[_(@Q.?L
M_//I[_4OT/'O\_GPZ>KO_2#JZ^7IY.GO_2#DY2#DY^SI[_7QX][HY^KE(.7P
MZ?3U]_[R+@#%\?[TY_/G`,3G[/SSZ>\@RNOEZ>3?(%)302`H)60@0FET*0#%
M\.GK[^/?(.7M_/(`U/7WX=_A(-#Q_.+KY?CG`,O\X^_R`,'MW./M^?/G`,'M
MW./M^?/G(.SG[?WLX?3O\@#%W_/TY2#BW>+AZ>_R(./IX2#TYR#DZ>'C\>'V
MWB`E<SL@P?7T_"#DY>T@[/#O\>7?(.WA(.7PX>W=Z^CEZ2X`Q=_S].4@\]_C
M[_7Q[_(@X^GA(/3G(.3IX>/QX?;>(/3Y[2#DY>3O[-WM^>T@]._U(/?QWO/T
MYR`E<SL@P?7T_"#DY>T@[/#O\>7?(.WA(.7PX>W=Z^CEZ2X`Q?#A[>7J]-WK
MY?/G(/3G\B#TY>OE]?3AW^'R(.7QX^'SW^'R(//A\@#![>'MW?GSYR#T^>T@
MY/7MX>SIZO[M(//T[^GWY=_Y[2#T[_4@S.7M[_TZ`,'MX>W=^?/G(/3G\B#E
M[/;<[>GSY_(@]._U(%!O<G1A;#H`P>WA[=WY\^<@].?R(-#Q[^+OZ][R(-#E
M\=_KY_CG\CH`4F5G97@`Q>SVW.WI\^<@T_?=\^7Y[0#3]_SKZ>$`P?#O[.WG
M[/SMY?7SYR#PZ^?Q[_;O\>G^[2#DZ>'HY?/I[/STY_3A\BX`P?#O[.'J\?7S
M[-WM[^D@Q>[U\.?QY?3G]-WR`,'P[^SAZO'U\^S=[><@Y.GE_>CU[?/G("AH
M='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`P?;AW_'E\^<`P?;AW_'E
M\^<@S/#K_.H`P?;AW_'E\^<@T_3>Z^?R`,'VX=_QY?/G(.SO\?;O\._?Y_/G
M\@#!]N'?\>7SYR#A\/P@].\@Y^SE\>_K_./I_"#L[_4`P?;AW_'E\^<@YN7]
MX^_U\@#!]N'?\>7SYR#A\._HY^KE]>S=[>_U('-C<FEP="#A\/P@]._M(/#Q
M[_/Y\>GM_"#JX?3<Z^_C[R#T[_4@Y>[U\.?QY?3G]-XN`,'VX=_QY?/G(/3O
M]0#!]N'?\>7SYR#A]?3O_2#T[_4@ZOSLXN_U(.'P_"#T[R#=X^/QX?;O`,3I
MX>/QX?;>(/?QWO/TYP#$Z>'C\>'VWB#7\=[S].<Z("5S`-/TW.OHY^KE(,'P
MW.WTY_/G+@#!\-SM].?SYR#LY2#,QR#U\._S].?QZ>;\[.7M[R#LWNWU[.$N
M`,'PW.WTY_/G(.SE(/#KY_'O]N_QW^7R(.3IX>CE\^GL_/3G].'R(./IX2#T
M[_7R(.7P_.SE[>_U\B#D_>\@[-[MY?(N`,'PW.WTY_/G(.SE(/3I\B#FY_3O
M_>SE[>7R(/#KY_'O]N_QW^7R(.3IX>CE\^GL_/3G].'R+@#!\-SM].?SYSH@
M)7,`U.\@X=_TY^SA(.3E(.SP[_'EWR#MX2#A\.'M].?HY=\N(,7PZ?/T\>7V
M_.SE[>_R(.KYY.GJ_/(@Z]SH[_7R.B``U.\@X?#AZ?3O_>SE[>\@)R5S)R#D
MY>T@ZN'H[_'?\^CGZN4@\_3O("5S(&-O;F9I9W5R871I;VXN`-3O(.'PX>GT
M[_WLY>WO("<E<R<@Y.7M(.KAZ._QW_/HY^KE(//T[R!61E,@8V]N9FEG=7)A
M=&EO;BX`U.\@X?#AZ?3O_>SE[>\@)R5S)R#DY>T@ZN'H[_'?\^CGZN4@\_3O
M(&-O;F9I9W5R871I;VXN`-3O(.'PX>GT[_WLY>WO("=B87-E9&XG(.3E[2#=
M]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@X?7HY>WTZ>KO\._?Y_/G
M\BX`U.\@X?#AZ?3O_>SE[>\@)V)A<V5D;B<@Y.7M(-WWY>D@ZN'H[_'I\_3E
MWR#S].GR(/'UZ.S?\^7I\B#T^>T@\/'O].GLWO/E^>TN`-3O(.'PX>GT[_WL
MY>WO("=D871A8F%S92<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?
M\^7I\B#A]>CE[?3IZN_P[]_G\^?R+@#4[R#A\.'I]._][.7M[R`G9&%T86)A
M<V4G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@ZN'TY^/O
M\>G^[2X`U.\@X?#AZ?3O_>SE[>\@)V1A=&%B87-E)R#DY>T@W??EZ2#JX>CO
M\>GS].7?(//TZ?(@\?7H[-_SY>GR(/3Y[2#P\>_TZ>S>\^7Y[2X`U.\@X?#A
MZ?3O_>SE[>\@)VAO<W1S<&5C)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@
M\?7H[-_SY>GR(.'UZ.7M].GJ[_#OW^?SY_(N`-3O(.'PX>GT[_WLY>WO("=H
M;W-T<W!E8R<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#J
MX?3GX^_QZ?[M+@#4[R#A\.'I]._][.7M[R`G:&]S='-P96,G(.3E[2#=]^7I
M(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@]/GM(/#Q[_3I[-[SY?GM+@#4
M[R#A\.'I]._][.7M[R`G<&%S<W=O<F0G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@
M\_3I\B#Q]>CLW_/EZ?(@X?7HY>WTZ>KO\._?Y_/G\BX`U.\@X?#AZ?3O_>SE
M[>\@)W!A<W-W;W)D)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_S
MY>GR(.KA].?C[_'I_NTN`-3O(.'PX>GT[_WLY>WO("=P87-S=V]R9"<@Y.7M
M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#T^>T@\/'O].GLWO/E
M^>TN`-3O(.'PX>GT[_WLY>WO("=P:'!T>7!E)R#DY>T@W??EZ2#JX>CO\>GS
M].7?(//TZ?(@\?7H[-_SY>GR(.'UZ.7M].GJ[_#OW^?SY_(N`-3O(.'PX>GT
M[_WLY>WO("=P:'!T>7!E)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H
M[-_SY>GR(.KA].?C[_'I_NTN`-3O(.'PX>GT[_WLY>WO("=P:'!T>7!E)R#D
MY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR(/3Y[2#P\>_TZ>S>
M\^7Y[2X`U.\@X?#AZ?3O_>SE[>\@)W1A8FQE)R#DY>T@W??EZ2#JX>CO\>GS
M].7?(//TZ?(@\?7H[-_SY>GR(.'UZ.7M].GJ[_#OW^?SY_(N`-3O(.'PX>GT
M[_WLY>WO("=T86)L92<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?
M\^7I\B#JX?3GX^_QZ?[M+@#4[R#A\.'I]._][.7M[R`G=&%B;&4G(.3E[2#=
M]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@]/GM(/#Q[_3I[-[SY?GM
M+@#4[R#A\.'I]._][.7M[R`G=6ED)R#DY>T@W??EZ2#JX>CO\>GS].7?(//T
MZ?(@\?7H[-_SY>GR(.'UZ.7M].GJ[_#OW^?SY_(N`-3O(.'PX>GT[_WLY>WO
M("=U:60G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@]/GM
M(/#Q[_3I[-[SY?GM+@#4[R#A\.'I]._][.7M[R`G=7-E<FYA;64G(.3E[2#=
M]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@X?7HY>WTZ>KO\._?Y_/G
M\BX`U.\@X?#AZ?3O_>SE[>\@)W5S97)N86UE)R#DY>T@W??EZ2#JX>CO\>GS
M].7?(//TZ?(@\?7H[-_SY>GR(.KA].?C[_'I_NTN`-3O(.'PX>GT[_WLY>WO
M("=U<V5R;F%M92<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I
M\B#T^>T@\/'O].GLWO/E^>TN`,'PX>GT[_WLY>WO(-#EY-_O`,'PX>GT[_WL
MY>WO\B#3]>SLY?3=]_GM`,7PX>WA]N_QW`#!Z^OAX]X@ROGDZ>KO_0#!Z^O<
M[O3E(/3O[2#*^>3IZOP@\^'R`,'P[_3EZ]WS[.'TX0#%\.GS]/'O]MX@\_3I
M\B#%\.GK[^/=\@#%\.GS]/'O]MX@\_3G[2#AZ^OGZ^_C\>'VW^$`Q?#A[=WM
M^?/G`,7PX>WA]N_QW"!#;VYF:6=U<F%T:6]N`,'E\>_KZ>S=[>'R(-'\Y._U
M`,7PZ>OOX]WR(.7PY>[E\>/A\_3>(.7L\.OO]?3I\^S=[>_U(.KEZ>S=[>_U
M`,'I[=_C[.'TX0#$Y>[IW`#$Y>[IW"#E\.GJY?;AZ]_DX0#$Y>[IW?(@].GL
MW?(`R>3I_/3G].7R(./QX>SLWO(N+BX`T?SK[_(`T.7QZ?/T\>_VWB`Q.#"P
M`-#E\>GS]/'O]MX@P?'I\_3E\=P`T.7QZ?/T\>_VWB#$Y>[IW`#)Y.G\].?T
MY?(@P_'A[.S>\@#)Y.G\].?TY?(@P_'A[.S>\@##\>'L[-WR.@#*X>W\[>7R
M`,_I(.KA[?SMY?(@Z.$@Y>SVX>W?YN_M].'I(.SE].'N_2#\Z_GM(/3Y[2#C
M\>'L[/[M(.KAZ2#T^>T@\_3GZ_[M`,_I(.KA[?SMY?(@Z.$@Y>SVX>W?YN_M
M].'I(.SE].'N_2#T^>T@\_3GZ_[M(.S\[>\`S^D@ZN'M_.WE\B#HX2#E[/;A
M[=_F[^WTX>D@[.7TX>[](/3Y[2#C\>'L[/[M(.S\[>\`Q>KTW>OE\^<`U?#O
MX_'A]MX@RO'U\/3OX_'<]N?SY_(@4R]-24U%`,KQ]?#T[^/QX?;G[-WM[R#L
MWNWU[.$@4R]-24U%`,<@X?7HY>WTZ>KO\._?Y_/G(%-!4TP@Y.7M(.7?[>'I
M(.3IX>C=\^GLYRX`S.?M_>SA].$@4TU3`%-13"#*W>OU]N_R`,70R=35U]G3
M`%-?44P@RMWK]?;O\@#3X0"ZY.GO(/#KX=_SZ>\@*%]S96QF*0#!Y?'OZ^GL
MW>WA\B#3W.SO]0#0W/'O]^_R(,3O\?7V_/'O]0#!\._HWNKE]?/G`,'P[^C>
MZN7U\^<@)7,`P?#OZ-[JY?7SYR`G)7,G`,'P[^C>ZN7U\^<@Q?#IZ^_C_NT`
MP?#OZ-[JY?7SYR#T[_4@8V]N9FEG=7)A=&EO;B#P[_4@Y.?LZ>_U\>/>Z.?J
MY2#SX>T@4$A0(%-C<FEP="#S]._M(/#Q[_/Y\>GM_"#JX?3<Z^_C[R#T[_4@
MY>[U\.?QY?3G]-XN`,'P[^CGZN7U[-WM[R`E<R!C;VYF:6=U<F%T:6]N+@#4
M[R!S8W)I<'0@Y>WG[-WQ^?/G\B#T[R!S971U<"#A\._HY^KE_>CGZN4@\_3O
M.B`G)7,G+@#%\.GS]-[LYP#![>'FWO3G\^<`S.?WX>W=\B#![>'FWO3G\^?R
M`,'MX>;>].?SYR#,Y^WU[-ST^>T`P?#O].7KW?/LX?3A(,'MX>;>].?SY_(`
MQ?#IZ^_CWB#!\??EW_GM`,7PZ>O=[O3E(.SIX2#G[.7Q[^SG[=_A`,7PZ>O=
M[O3E(._LW.3A(./IX2#P\>_SZ-[JYP#%\.GKW>[TY2#MW>\@R>3I[^KTWO3G
M`,7PZ>O=[O3E(.7N]?#G\>7TY_3>`,7PZ>O=[O3E(/?QWO/TYR#CZ>$@\/'O
M\^C>ZN<`Q?#IZ^_CWB#\Z_GM(/3Y[2#G[.7Q[^SG[>G^[2X`Q?#IZ^_CWB#E
M[?SR(.'M].GJY>GLW>WO]0#%\.GKW>[TY2#T[_7R(/?A\>'J]-[QY?(@\._U
M(.C=Z^7TY2#A\/P@].GR(/#A\>'JW/3Y(.O?\_3E\BX@RN'T_/#I[>SP[_'E
MW_3E(.WA(/3A(.'M].GC\=SXY?3E(.KAZ2#MX2#TX2#E\.GJ[^OKWO/E].4@
M\_3O(.S>[?7LX2#SX?(N`,7PZ>OOX]X@]._U(.3IX??Y\>GS]-X@Y^SE\>_L
MY^W?X?(Z`,7PZ>OOX]X@].?R(.SO\?;>\B#P[_4@Z.$@W??EZ2#G(.?LY?'O
M[.?MW^$Z`,7PZ>O=[O3E(/3G(/3A]?3\].?TX2#P[_4@Z-WKY?3E(.WA(.'K
MZ]SNY?3E.@#%\.GKW>[TY2#T[R#DZ>'W^?'I\_3>(/[QX?(Z`,7PZ>O=[O3E
M(/3G(.SO\?;>(/#O]2#HX2#=]^7I(.<@_O'A.@#%\.GKW>[TY2#D_>\@\.7D
MW^$@\._U(/3AZ?'IW.;O]>TN`,7PZ>O=[O3E(/3O(/?Q^>SA].GJ_"`G\_?>
M[.$G+@#%\.GKW>[TY2#TYR#CZ_[S\^$@\^'R.@#!\._S]._KWB#T^>T@\.GO
M(/#Q_//VX?3Y[2#PZ^?Q[_;O\>G^[0#!\._S]._KWB#![>'V[_'<\B#0\>_B
MZ][LX?3O\@#!\._S]._KWB!335,`P>GSZ.?TWO'A\CH@`-/E\/3=[.+QZ>_R
M`-/EZ?'IX>K\\B#!\>GH[/SR`-3O($E$(/3G\B#S_>WDY?/G\B#=Z^?NY2X`
MR-WSY0#(W?/TY2#E\.GK[^/=\B#P[_4@Z.$@\^'R(.7PZ?3QW?#O]>T@[>$@
MX>OKW.;E].4@]._M(.KYY.GJ_"#SX?(L(.'J_.SG(.KAZ2#A[2#T[^T@W??E
M].4@[N7WW//EZ2X`T.'QX>SE]/'O\._?Y_/G(.'P[^SAZO'U\^S=[?GM(.7N
M]?#G\>7TY_3^[2#P[_4@Z-WKY?3E(/#Q_//BX?/G+@#1]>CLW_/TY2#DZ=SV
M[_'E\B#E\.GK[^/=\B#E[/;<[>GSY_(@ZN'I(/3O(/?Q_.WO(.'MX>W=^?/G
M\B#T^>T@\^7KW^3Y[2X`Q?#IZ^_CWB#TY_(@\/'O].GL[_WLY>WG\B#CZ_[S
M\^'R+@#*X>CO\=_S].4@].?M(/#Q[_3I[/[LY>WG(./K_O/SX2P@YO[MYR#^
M\>'R(.KAZ2#L[_'VWB#G[.7Q[^SG[=_A\BX`RN'H[_'?\_3E(/3G[2#E]N'Q
M[._CWB#EZNK?[>?SY_(L(/3A(/#Q[_3I[/[LY>WA(/?Q_NSA].$L(/3G(/#E
M\=_OY.\@X>WA[=WY\^?R(/3G\B#SY>O?Y.'R(.KAZ2#<Z^OE\B#E\.GK[^/=
M\B#E[/;<[>GSY_(N`-']Z.SI\^<`Q=_MX>D@Y.GAZ-WSZ>SA(%-C<FEP=',@
MY>WG[-WQ^?/G\B#Q]>CLW_/E^>T`T._KZ]WR(/3O\._HY?/?Y?(@Y=_MX>D@
M\.GHX>W=\B#LY2#A]?3>(/3G(/#A\=SLY?3Q[SH@`,'C[_'=\@#3_>WT[^SG
M(-#E\=_KY_CG`-/][?3O[.<@T.7QW^OG^.<Z`-#QW?#EZ2#T[R#JZ^7IY-\@
M\/'\\^+A\^?R(.WA(._QZ?/HY=\@X^GA(/#E\>GS\_STY?'E\B#S]>WDW?/E
MZ?([`,7L]MSMZ?/G`,7L]MSMZ?/G(.3IX?;O\?[M(.SE].'N_2#T[_4@X?#O
MZ.?JY?7LW>WO]2#JX>D@]._U(.3G[.GO]?'CY^C=[?3O\B!C;VYF:6=U<F%T
M:6]N+@#%[/;<[>GSYR#TY_(@_O'A\B#TY>OE]?3AW^'R(.7I\_SD[_4@_/3A
M[2#L\.'?[>_U[.4@\_3O(//]\_3G[.$[`,7L]MSMZ?/G(.7PZ>OOX][R(./I
MX2#A\._HWNKE]?/G(/3O]2#A]>CE[?3IZN_]`,7L]MSMZ?/G(//UZ^O=ZO3G
M`,WA(.7L]N'MW^;E].'I(/3O(.SE[>_](.SE(.7QX^'SW^7R(/#?[>'JX3L`
MQ>SVW.WI\^<@]._U("5S(,SE[>_](//TX2#A\>GS].7QW#L`Q>SVW.WI\^<@
M]._U(.3IX>O\X^_U(,GDZ>_TWO3Y[2#*Y>OI_NT@T-_MX>KA`,7L]MSMZ?/G
M(/3O]2#DZ>'K_./O]2#)Y.GO]-[T^>T@T-_MX>KA`,7L]MSMZ?/G(/3O]2#D
MZ>'K_./O]2#)Y.GO]-[T^>T@P_'A[.S^[2#0W^WAZN$`Q>SVW.WI\^<@]._U
M(.3IX>O\X^_U(,GDZ>_TWO3Y[2#%Z>K\[>'R`,7L]MSMZ?/G(/;\\?3Y\^?R
M("AU<&QO860I`-/U\?'?ZNWY\^<`T/'^].$@\_7Q\=_J[?GSYR#>(.SE].'J
MW^WG\^<@X^7I]._MZ>K^[2#T[.?LW/3Y[0#%W_/OY._R+=7P[^/QX?;>`,<@
MQ=_S[^3O\BW5\._C\>'VWB#DY>T@W??EZ2#JX?3A]_GQY^CEWRX`U?#OX_'A
M]MX`P>OC_/'IZ.SO\B#5\._C\>'VWO(`S-WCY>CO\@#!ZOWQ^?/G(-/U[?3>
M\>?SY_(`S.7QZ>K<(.'P_"#TX2#A\??EW^$@Y.GA]^7?\>GSY_(@]._U($AO
M<F1E(-WW[_7M(/?AZ.7?.@#%\.GK[^/>(.KA].7]Z/7M\^?R(/3A[NGM_.SG
M\^?R`,'E\>_KZ>S=[>'R(-/O_>3A\@#$Z>7]Z/7M\^<@T.?CWO(`S?STZ>\@
MQ^SI\_;AW_'I[P#$Z=SS].?LX2#LY?3A[OT@X^7I]._MZ>K^[2#JY>OI_NT`
MQ.G<\_3G[.$@[.7TX>[](/#E\>GE]^_LW>WO]2#JX>D@X_'A[.S>\B#JY>OI
M_NT`T.O>ZO3Q[R#$Z>'S]-[LX?3O\@#!\>'?^?/G`,'QX=_Y\^<@ZN'I(./=
M[.GS[.$`4W!A;0#%Z?/AX_GCWB#%Z>3IZO[M(-?A\>'J]-[Q^>T`Q.GAW_'E
M\^<@ZN7KZ>_]`,3IX=_QY?/G(//TWNOG\@#$Z>'?\>7SYR#C\>'L[-[R`,'H
MZ][LX?3A`+CMX?'NYP"X]._R(+CMX?'NY_(`T._KZ?3EW^$@WB#%\.'Q]]_A
M`,KA]-SS].'SYP#,[_'VWB#A\._HWNKE]?/G\@#$Z>7]Z/7M\^<MS^3\\@#$
MZ>'C\>'L[.GS[-WMX0#+W_/TX2#KW>[E^>T`P?;AW_'E\^<@]._U(&1O;6%I
M;B#A\/P@].<@Y.GE_>CU[?/G`-/T_>L@6T-34UT`RO4`SR#U\._VW.KEZ^_R
M("<E<R<@Y.4@XO'=Z.?JY2X`R-WLX0#(W>SA("?0Z^?Q[_;O\=_E\B#$Y^S\
M\^GO]2#*Z^7IY.GO_2<`P?#O\_3OZ]X`U.\@X=_TY^SA(./IX2#P\>_SZ-[J
MYR`G)7,G(//T[R#S_?/TY^SA(.'PY?/TW.OG+B#$Y2#L\._QY=_TY2#MX2#N
MX>WA[/#EW_3E(.S=]_'I(.WA(.7CZO'IZ.7?(/3O(.'?].?LW"#SX?(N`-7P
M[^3EW^KTY_(`Q?#I]/7WW^$`Q?#I]/7WWO(@\/'O\^C>ZN<@)R5S)R#S].\@
M\_WS].?LX2X`U.$@Y.7D[^S=[>$@]._U(/?QWO/TYR`G)7,G(.3IX>/QW/;G
MZN'M(.7PZ?3U]_[R(.'P_"#T[R#S_?/TY^SA+@#%\.GT]??>\B#DZ>'C\>'V
MWB`G)7,G+@#%\.GT]??>\B#DZ>'C\>'VWB`G)7,G(.'P_"#T[R#S_?/TY^SA
M+@#/Z2#Q]>CLW_/EZ?(@Y?#A[>'VW?'HY^KA[2#E\.GT]??^\BX@RMSM].4@
MY?#A[>'V_/'T^?/G(./IX2#MX2#DY=_TY2#TZ?(@X>OKX>/=\BX`Q?#I]/7W
MWO(@Y?#OZ-[JY?7SYR#E]N7D\>GJ[_T@8V]N9FEG=7)A=&EO;BX`Q?#I]/7W
MWO(@X?#OZ-[JY?7SYR#T[_4@Y?;EY/'IZN_](.'Q]^7?[_4@8V]N9FEG=7)A
M=&EO;B`E<RX`Q?#I]/7WWO(@Y>WG[-WQ^?/G("<E<R<`Q?#I]/7WWO(@Y>/C
M\>'VWB`E<P#3_>WO^.<@+2#0Y?'?Z^?XYP#![>'T[^O>`,3]\^<`P>WA]._K
MW@#![>'T[^O>+\3]\^<`P>WA]._KWCH@`,3]\^<`Q/WSYSH@`-7PY?'DY=_J
M].7R`-7P[_/TWO'I[N<`Q?#?Z.7T[P#4[R#A\??EW^\@ZN'TX>/QX?;>\B#S
M]>/W\>_MZ?/L[_T@Y.GAX_'<]N?JY0!3>6YC34P`R]SH[_(@\_WM].'NY_(@
M\_3O]?(@_/'O]?(@X>WAYM[TY_/G\@#0W^WAZN'R`,GDZ?STY_3E\B#0W^WA
MZN$`R>3I_/3G].7R(-#?[>'JX0#!Y?'OZ^GLW>WA\B#4X>W<X_'A\@#3]/SW
M[_(Z`,7QX^'SW^7R`,'E\>_KZ>S=[>'R(-3A]._Z[_4`P?'IZ.S\\B#4Y^OE
M]O[M[_4`R.7Q[._J\>'SW^$@].?M(/3EZ^7U].'?X2#^\>$Z(`#(Y?'L[^KQ
MX?/?X0#(Y?'L[^KQX?/?X3H@`-3O(/#Q_/3U\.\@)R5S)R#DY2#B\=WHY^KE
M+@#$Z>'WY=_QZ?/G(-#Q[_3]\._U`-#Q[_/Y\>GMWB#!\._D[_?>(.'I]-[L
MX?3O\@#0\>_S^?'I[=P@P?#OY.7J]/P`RN7?[.7M[P#,_.WO(,KEW^SE[>\`
MT_3OW_?G\^<@ZN7I[-WM[_4`RN_Q]?;>(.KEZ>S=[>_U`-3E`,7U]^'QZ?/T
M[_WLY2#P[_4@]_'G\^GL[_#OZ=[SX?3E(/3O(-/]\_3G[-P@[.'R+@#'(.7P
MW>KTX?/G($944"#DY>T@Y=_MX>D@X>K\[.<@Y.GAZ-WSZ>SG+@#4[R#S_?/T
MY^SA($AO<F1E+TMO;&%B(.3E[2#U\._S].?QW^;EZ2`B)7,B`,3IX??EW_'I
M\^<Z.B#'(.KKW//G(.3E(/;O\?3^Z.?JY2#E\.GT]??^\@#4[R#PX?'<Z/7Q
M[R#E\.GK[^/^[2#=ZNOEZ?/E+B"X[N_D[_(N`,\@Y.GA]^7I\>GS]-[R(/#Q
MW?#EZ2#MX2#Q]>CLW_/EZ2#=[>$@[/SMZ>SO(/#KX=_SZ>\@Q>[O]?/I[^3O
M]-[SY?GM+"#CZ>$@[>$@[/#O\>7?].4@[>$@]_'G\^GL[_#OZ=[SY?3E(.7N
M[_7SZ>_D[_3>\^7I\BX`QR#JW/3Y(/#KY?7QW"#L_.WO`-3A(.3EY._LW>WA
M(.?LY?'OZ^_CW^_U(.3E[2#EW^WAZ2#=X^KU\>$`U.\@240@].?R(.7PX?;>
M\B#DY>T@ZN'H[_'?\^CGZN4L(-[TX>T@ZN7M_"#>(.3E(.+QW>CGZN4@\_3G
M(.+<\^<@Y.7D[^S=[?GM+@#'(.7PX?;>(/#Q[_/TW>CGZN4@Y?#I]/7W_O(@
M\_3O(,3IY?7H]>WSZ>_C\=SV[R#SX?(N`-3O(/3LWNSA(%!'4"#P[_4@X?#O
M\_#<\^CGZN4@X?#AZ?3EW_3O(./IX2#TY^T@Y?#AZ][HY?7SYR#T[_4@]?#O
MX^7C\>'L[-WM[_4@[.?MWNSA]._R+@#4[R!)1"#TY_(@Z]_S].'R(.3IX>WO
M[-[R(.3E[2#O\=_SZ.?JY2P@WO3A[2#JY>W\(-X@Y.4@XO'=Z.?JY2#S].<@
MXMSSYR#DY>3O[-WM^>TN`,<@Z]_S].$@Y.GA[>_LWO(@Y.7M(.KAZ._QW_/H
MY^KE+@#/Z2#D]>WA]/STY_3E\B#J\?7P]._C\=SVY_/G\B#A\.'I]._][2#A
M\_;AZ]X@\_WMY.7SYR!714(N`-3O(./EX^_M_/(@\/'O\_3=Z.?JY2#S].\@
MY^SE\>_K_./I_"#SX?(N`-3O(.'Q]^7?[R`E<R#P\=WPY>D@[>$@\.7QZ=WW
MY>D@[.GA("5S(/']Z.SI\^<N`-3O(.'Q]^7?[R`E<R#P\=WPY>D@[>$@\.7Q
MZ=WWY>D@ZMSP[^GE\B`E<R#Q]>CLW_/EZ?(N`-3O(.'Q]^7?[R#DY2#L\._Q
MY=\@[>$@X>WTZ>/QX?;EWR#S]._M(.7A]?3\(/3O]2X`U.\@X?'WY=_O(.3E
M[2#PY?'IW??EZ2#DY>3O[-WMX2X`U.$@\.'QX>K<]/D@Y=_MX>D@Y?#IZN7V
MX>O?Y.7R(./IX2#A]?3\(/3O(.S>[?7LX2]R9F,X,C(@[-[M]>SA+@#'(.KA
M]-SS].'SYR#PZ][Q[_7R(._H_.WG\B#EW^WAZ2#C[?GS]/P@_/3I(.3G[.GO
M]?'CY=\@\/'\XNOG[.$@[.4@]._M($EN=&5R;F5T($5X<&QO<F5R+"#E[N'I
M]-_A\B#P\>_BZ^?LW/3Y[2`H8G5G<RD@]._U(&)R;W=S97(L(/3A(._P[]_A
M(.3E[2#EW^'I(.3U[>'T_"#MX2#NY?#E\>'SZ._][2X@S/#O\>7?(.WA(.3E
MW_3E("?SZN_U\-_DZ>$G(//TY^T@[^C\[><L(/#Q[^+KWNSA].$@\_3G(.OE
MZ?3O]?'CW^$@]._U(&)R;W=S97(@WB#JX>D@ZOSKY^S<(/3O]2X@P>T@].\@
M\_WS].?LW"#SX?(@Y=_MX>D@5VEN9&]W(#EX(.7?[>'I(/#OZ_T@\.GHX>W\
M(.WA(.3EW_3E("?#Y>WIZMX@P?#O]/7WW^$@T/'O\_3A\]_A\B<@ZN'I(.WA
M(/#QW?#EZ2#MX2#E\.'MY>KJZ>W>\^7TY2`H<F5B;V]T*2Y<;ES!]?3>(.7?
M[>'I(/#Q[^7IY._P[]_G\^<N(-#A]-[S].4@S\H@X>T@Z-WKY?3E(.'J_.SG
M(.WA(.3O]>O=^.7TY2#SY2#JX?3<\_3A\^<@\.O>\>_U\B#OZ/SMY_(N`,<@
M].'U]/STY_3A("(E<R(@Y.GAX_'<]N?JY2X`QR#A\>GS].7QWB#PZ^7U\=P@
M[/SM[P#'(.C=\^<@]._U(/#Q[^/QW.SLX?3O\B!';G501R#P\=WPY>D@[>$@
MY._HY=\@X^GA(/3G($-R>7!T7W!G<#HZ(.KKW//G+@#'(./QX>SLX?3OZ/7Q
MW^3A("?JW.3O\B<@Y=_MX>D@WN3G(-SDY>GA+@#4[R#LWNWU[.$@\._U(//T
MW.OHY^KE(//TZ?(@)7,@\_3O[2`E<R#LY2#HW>SA("5S(.7L]N'MW_/HY^KE
M+@K!]?3\(.3E[2#A\._TY>OEWR#E\.GBY>+AW_GSYR#\].D@Y.GAXMSSZ.?J
MY2#JX>D@W>/I[>4@ZN'TX>WOY_3\+@#4[R#\[>_LX2#P[_4@Z.$@]_'G\^GL
M[_#OZ>7?].'I(/STX>T@\_7MY-WE\_3E(//TYR#SY>O?Y.$@\_WMZ.7SY_(N
M`,<@XNGBZ^GOZ-[JYR!/<&5N4U-,(.'PX>GTY=_TX>D@X^GA($AO<F1E7T-R
M>7!T7W-M:6UE.CH@ZNO<\^<N`,<@\/'O]-_LY_/G("(E<R(@Y.7M(.SP_/'E
M\^4@[>$@X?#OZ.?JY?7HY=\@X^GA]-\@].$@Y.7D[^S=[>$@].?R(/7PY?'B
MX=_M[_7M(/3O(.S=X^GS].\@Y?#I]/'E\/3\(.S=X^7H[_(`U.\@\/'\X_'A
M[.SA(/#O]2#W\>?SZ>SO\._IY=_TY2#CZ>$@].?M(.7L]MSMZ?/G(.'U]._]
M(/3O]2#EW^3O]?(@[.?M]>S<]/GM("@E<RD@Y.7M(.+QW>CGZN4@\_3O(//]
M\_3G[.$N`,<@<F5G:7-T<GD@Y=_MX>D@[R#T\?SP[_(@[.4@]._M(._P[]_O
M(._I(.7VX?'L[^/=\B#T[_4@2&]R9&4@Y?#IZN_I[?GM[_WM+B#LY?3A[OT@
M]._U\BX@Q>3^(/#QW?#EZ2#MX2#C\=SXY?3E(/STZ2#E]N'Q[._CW?(@]._U
M($AO<F1E(-WWY?3E(.7CZN'TX?/TWO/EZ2X`QR#A\>GS].7QWB#JX>D@Y.7N
MZ=P@\.OE]?'=\B#L_.WO`,<@Y.7NZ=P@\.OE]?'<(.S\[>\`SR#E[O7PY_'E
M].?TWO(@(B5S(B#DZ>'C\=SGZN4N`,\@Y>[U\.?QY?3>\B`B)7,B(.'P[^CG
MZN7]Z.?JY2X`U.\@X=_TY^SA(.7I\_SD[_4@X^GA("5S(.3IX>/QW/;GZN4N
M`,<@X_'A[.S>(/#O]2#O\=_SX?3E(.3E[2#U\-SQ]^7I+@#'(.7QX^'SW^$@
M\/'O\_3=Z.?JY2#S].<@Z]_S].$@Y?'CX?/I_NT@\^'R+@#4[R#P\>_S^?'I
M[?P@X?'WY=_O("(E<R(@Y.7M(/7PW/'WY>DN`,<@\-SM^2#JX>D@ZMST^2#P
MZ^7U\=WR(.S\[>\`QR#PW.WY(/#KY?7QW"#L_.WO`-3A(.3EY._LW>WA(/#O
M]2#S]-WK[>'TY2#WW.CGZN'M(.'P_"#T[R#P\>_GX^_][.7M[R#BWNSA+@#4
M[R#A\??EW^\@\._U(//TY=_KX?3E(.3E(.SP_/'E\^4@[>$@\_GHY=\N`,_I
M(/#KY_'O]N_QW^7R(.3IX>CE\^GL_/3G].'R(.'P[^CGZN7]Z.?JX>T@Y?#I
M]/7W_O(N`,\@ZN'TW.OOX^_R(.CE[-ST^>T@)R5S)R#DY2#B\=WHY^KE+@#$
MY>T@]?#<\??O]>T@Q?#IZ^_CW?(@Y.GAZ-WSZ>SE\BX`Q.7M(/7PW/'W[_7M
M(/3LWNSA].$@\._U(.3E(.SP[_'O_>T@[>$@Y>SVX>WI\^CO_>T@Y>WS^>SA
M]/GLW>WA+@#5\-SQ]^_U[2#P[^OK[]\@]^'QX>KTWO'E\B#SY2#A]?3\(/3O
M(/#EY-_O+B#%Z?/AX]SCX?3E("5S(/?A\>'J]-[QY?(L(/#QW?#EZ2#MX2#U
M\-SQ]^_U[2#KZ>/\].7Q[^D@X?#\("5S+@#0\?SBZ^?LX2#JX?3<(/3G[2#P
M\>_SZ-[JYR`G)7,G(//T[R#S_?/TY^SA+B`E<RX`T/'\XNOG[.$@ZN'TW"#T
MY^T@\/'O\^C>ZN<@)R5S)R#S].\@\_WS].?LX3H@)7,N`-#Q_.+KY^SA(.KA
M]-P@].<@Y.GAX_'A]MX@Y.7D[^S=[?GM(/3O]2#W\=[S].<@)R5S)R#A\/P@
M].\@\_WS].?LX3H@`-#Q_.+KY^SA(.KA]-P@].<@Y.GAX_'A]MX@)R5S)R#A
M\/P@].\@\_WS].?LX3H@`-#Q_.+KY^SA(.KA]-P@].?M(.7MY^S=\?GSYR`G
M)7,G.B`E<P#0\?SBZ^?LX2#JX?3<(/3G[2#A\._S]._KWB#A\??EW^_U.B#$
MY>T@\_3<Z^CGZN4@)7,N`-#A\>_U\^G<\^CGZN4@\/'\XNOG[.$@ZN'TW"#T
MY^T@X?#O\_3OZ]X@]._U(.'Q]^7?[_4Z(-3O("5S(.7?[>'I(.SEX^'K_?3E
M\>\@X?#\(/3O(.S=X^GS].\@Y?#I]/'E\/SLY>WO(.S=X^7H[_(@*"5D($)Y
M=&5S*2X`T.'Q[_7SZ=SSZ.?JY2#P\?SBZ^?LX2#JX?3<(/3G[2#A\._S]._K
MWB#T[_4@X?'WY=_O]3H@T_3<Z^CGZN4@[/SM[R#=[>$@].S>[.$@]._U("5S
M+@#0X?'O]?/IW//HY^KE(//VW.OLX2#JX?3<(/3G[2#E[/;<[>GSYR#A]?3O
M_2#T[_4@].S>[.'T[_(@]._U(.SG[?WLX?3O\BX`T.'Q[_7SZ=SSZ.?JY2#S
M]MSK[.$@ZN'TW"#TY^T@Y>GSX>/YX]X@Y.7D[^S=[?GM(,3IY?7H]>WSZ>_C
M\=SV[_4N`-#A\>_U\^G<\^CGZN4@\_;<Z^SA(.KA]-P@].?M(.7I\^'C^>/>
M(/3O]2#CY>/O[>_T[_(Z("5S+@#0X?'O]?/IW//HY^KE(//VW.OLX2#JX?3<
M(/3G[2#EZ?/AX_GCWB#DY>3O[-WM^>T@Y^SE\>_K[^/?[_4N`-#A\>_U\^G<
M\^CGZN4@\_;<Z^SA(.KA]-P@].?M(.7I\^'C^>/>(/3G\B#E\>/A\]_A\CH@
M)7,N`-#A\>_U\^G<\^CGZN4@\_;<Z^SA(.KA]-P@].?M(.7I\^'C^>/>(/#K
MY_'O]N_QZ?[M(.3IX>CE\^GL_/3G].'R.B`E<RX`T.'Q[_7SZ=SSZ.?JY2#S
M]MSK[.$@\_3G(/;\\>SA(/'UZ.S?\^7Y[2X@NO/Y\B#A]M[SX?3E(.KE[?P@
MZMSP[^GO(.'PX>GT[_WLY>WO(/#EY-_O+@#0X?'O]?/IW//HY^KE(//VW.OL
MX2#S].?M(.7J]-WKY?/G(/3G\B#JX>CO\>GS[-WMY_(@Z^7I]._U\>/?X?(@
M]._U(,3IY?7H]>WSZ>_C\=SV[_4N(-#A\>'JX>O^(.3OZNGLW//TY2#A\>/\
M].7QX2X`0F5I(&1E<B!!:W1U86QI<VEE<G5N9R!D97(@2V]N=&%K=&1E=&%I
M;',@:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XN($)I='1E('9E<G-U8VAE
M;B!3:64@97,@<W#D=&5R(&YO8V@@96EN;6%L+@#0X?'O]?/IW//HY^KE(//V
MW.OLX2#JX?3<(/3G[2#E[>?LW?'Y\^<@].?R(.O?\_3A\B#DZ>'M[^S>\BX@
MT.'QX>KAZ_X@Y._JZ>S<\_3E(.'QX_STY?'A+@#!Y?'OZ^GLW>WA\B#(Y?/S
MX>OO[=_JY_(`SR#E[O7PY_'E].?TWO(@24U!4"#DY>T@]?#O\_3G\=_FY>D@
MZN_I[?SW\>?S]._U\B#VX>K=Z^_U\BX`P?7TWB#G(.7MW?'CY>GA(.3E[2#U
M\._S].?QW^;E].'I+@#!]?3>(.<@Z^7I]._U\>/?X2#DY>T@W??EZ2#OZ^_J
MZ^?Q^>CEWR#AZOSLYRX`P?7T_"#DY2#VX=_MY?3AZ2#MX2#EW^WAZ2#=X^KU
M\>\@X?'WY=_O(')A<BX`P?7T_"#DY2#VX=_MY?3AZ2#MX2#EW^WAZ2#=X^KU
M\>\@X?'WY=_O('II<"X`P?7T_"#DY2#VX=_MY?3AZ2#MX2#EW^WAZ2#=X^KU
M\>_R(.'QZ>CL_/(@ZMSQ].'R+@#!]?3\\B#O(._DY^/\\B#SX?(@Y?#I]/'=
M\.7I(.WA(//TW>OMY?3E(.SG[?WLX?3A(.S=\_D@0VQI8VMA=&5L;"TH:'1T
M<#HO+V-L:6-K871E;&PN8V]M*2#LW?/Y($A45%`M05!)+@#!]?3\\B#O(._D
MY^/\\B#SX?(@Y?#I]/'=\.7I(.WA(//TW>OMY?3E(.SG[?WLX?3A(.S=\_D@
M<VUS,F5M86EL+2AH='1P.B\O<VUS,FUA:6PN8V]M*2#LW?/Y($A45%`M05!)
M+@#!]?3\\B#O(._DY^/\\B#SX?(@Y?#I]/'=\.7I(.WA(//TW>OMY?3E(.SG
M[?WLX?3A(.S=\_D@4TU44"`@ZN'I(/3G\B!6;V1A9F]N92U)=&%L>2#L_.WO
M(//E(.'QZ>CL[_WR(%9O9&%F;VYE+B#!\.'I].7?(-WMX2#K[^/A\>GA\^S\
M(&5M86EL(//TYR!6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I
M+@#4[R#PY>3?[R#A]?3\(.'PX>GTY=_TX>DN`-3O(/#EY-_O(.'U]/P@[/#O
M\>7?(.WA(-WWY>D@[/SM[R#AZMWQX>GO]?(N`,'U]/P@].\@\.7DW^_U(.SP
M[_'EWR#MX2#PY?'IW??EZ2#L_.WO(.'QZ>CL[_WR(.KAZ2#<[?D@ZMST^2#T
MY>OEW^$@*#HI+@#!]?3\(/3O(/#EY-_O(.SP[_'EWR#MX2#PY?'IW??EZ2#L
M_.WO(._J].'DZ>K=\B#TZ>S=\BX`P?7T_"#T[R#PY>3?[R#L\._QY=\@[>$@
M\.7QZ=WWY>D@[/SM[R#KW_/TX2#A\>GH[/[M(/?Y\>GS[-WM^>T@[.4@ZN7M
M_"#>(.7KZ^?MZ>K\(.7Q^?3G[.'TZ>K\`,'U]/P@].\@\.7DW^\@\/'=\.7I
M(.WA(.7?[>'I(-WMX?(@W>/J]?'O\B#A\>GH[/SR+@#!]?3\(/3O(/#EY-_O
M(/#QW?#EZ2#MX2#PY?'IW??EZ2#J^>3IZOP@]_'^[.'T[_(@\^4@4D="(.3E
MZN'E[N'DZ>K>(.SO\?;>+"#P+O<N("<C,3(S-&%F)RX`P?7T_"#T[R#A\??E
MW^\@\.7QZ=WWY>D@]._U\B!-24U%(&1R:79E<G,@\._U(/?QY_/I[._P[^GO
M_>WTX>D@X?#\(/3G[2#U\.?QY?/?X2#E\.GT\=WP[^WTX?(@Y.G<]N_QX2#P
M\>_C\=SL[.'TX2#MX2#DZ>'WY>GQW^;O[?3AZ2#TX2#PY?'IY??\[.7MX2#T
M^>T@96UA:6P@ZN'I(.WA(/3A(.7L]N'MW^;O]>T@[.4@]._M(.KA]-SKZ^?K
M[R#T\?SP[RX`P?7T_"#T[R#A\??EW^\@Y>O=X_?EZ2#TZ?(@\?7H[-_SY>GR
M(/3Y[2#W\?GLW/3Y[2#JX>D@]/GM(./QX>SLX?3O\^7I\?[M(./IX2#\Z^$@
M].\@\/'\X_'A[.SA(/3O]2!(;W)D92P@ZN'I(./IX2#TZ?(@Y?;A\>SOX]WR
M(/#O]2#EW^WAZ2#EX^KA].7S].?LW>WE\B#SY2#A]?3\(.KAZ2#DY>T@\.'Q
MW??O]>T@Y.GJW?(@]._U\B#E\.GK[^/=\B#CZ>$@X?7TW?(@].GR(/'UZ.S?
M\^7I\BX`P?7T_"#T[R#A\??EW^\@ZN'TX>/QW/;EZ2#TZ?(@Y?#EZO3<\^7I
M\B#T^>T@]/WP^>T@S,G,Q2P@_O/TY2#TX2#PY?'IY??\[.7MX2#O\>GS[-WM
M^>T@;6%I;"#MX2#E[/;A[=_F[^WTX>D@[.4@]._M(.KA]-SKZ^?K[R#T\?SP
M[RX`P?7TWB#G(/;\\>SA(-WWY>D@WN3G(.7PY>[E\>/A\^CEWRX`P?7T_"#E
MW^WAZ2`E<RX`P?7T_"#EW^WAZ2!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B##
MZ>$@[>$@Y.7?].4@].\@X>WTZ>KEW^SE[>\@X?7T_"#W\>7IW.;E\^CE(-WM
MX2#P\?SC\>'L[.$@96UA:6P@\._U(.KA].'KX>+AW^WEZ2#A]?3>(/3G(.SO
M\?;>+B##Z>$@Z]_S].$@]-WT[^GY[2#P\>_C\>'L[-ST^>T@[/#O\>7?].4@
M[>$@Y?#I\^KE]>CEW_3E(/3O("5S`,'U]/P@Y=_MX>D@].\@XN'SZ>K\(.'Q
M]^7?[R#Q]>CLW_/E^>T@]._U(/#Q[^/QW.SLX?3O\B`G2&]R9&4G+B#0Y?'I
MW??EZ2#TX2#L[^WO\-STZ>$@ZN'I(/3A(.+A\^GJW"#LW?'G(/#O]2#W\>?S
MZ>SO\._I[_WM].'I(.'P_"#T[^T@\/7QWNWA(.KAZ2#TZ?(@Y?;A\>SOX]WR
M(/3O]2#S]?/TWNSA]._R+B``U.\@[-[M]>SA(.'U]/P@X_'<]NCGZN4@[.4@
MZOGDZ>KO\^7KW^3A("@E<RD@Y.GA]N_QY?3IZMX@X?#\(/3G(.3IZMX@\^'R
M+@#!]?3\\B#O(.'QZ>CL_/(@\/'=\.7I(.WA(.7?[>'I(/3O]>O<]^GS]._M
M(-WMX2X`U.\@\/'\XNOG[.$@X?7T_"#A[>'VW?'HY^KE(.'P_"`E<RX@SR#W
M\=[S].?R(.K<Z^7SY2#TY^T\8G(O/N'MX?;O\=P@\/'OXNO>[.'T[_(@X?#\
M(/3O(/#A\>'JW/3Y(%523#H\8G(O/B5S(.KAZ2#W\>?SZ>SO\._IY=\@]._M
M(.'J_.OO]>CO(&)R;W=S97(Z/&)R+SXE<P#!]?3\\B#O(.7N]?#G\>7TY_3>
M\B#DY2#L\._QY=\@[>$@X?#O\_7L\.G=\^7I('II<"#JX>D@9WII<"#A\??E
MW^$N`-3O(//]\_3G[.$@X?7T_"#=]^7I(.'PY>WE\>/O\._IY^CEWRX`P?7T
MWB#G(/3I[-X@\/'=\.7I(.WA(.7?[>'I(.'QZ>CL_/(N`,7I\^GTWO'IX0#9
M\>$`R??MY^OA]/[M].'R(/3G[2#^\>$`S._Q]MX@_O'A\@#%\.GK[^/>(/[Q
MX?(`U-_TZ^_R`-3?].OO\B`H5&]O;'1I<"DZ`-#Q_/(`P^GA(.WA(.KQX?3>
M\^7TY2#P[^OKX?#KW"#A[?3IZN7?[.7MX2P@ZO'A]-[S].4@\.'TY^S<[>\@
M].\@0V]N=')O;"`H4$,I(-X@].\@0V]M;6%N9"`H36%C*2#PZ][J]/'O+"#E
M[?X@ZMSMY?3E(.KKZ>HN`-/>[.7QX0#%[>'KZ^'CWB#SY2#PY^/AW^\@2%1-
M3`#!_?'I[P#*[_'U]MX`T-SM^2#PZ^'?\^GO("A?=&]P*0#,Y?3A]O'<\^7I
M\@#!Y?'OZ^GLW>WA\B#4\=_P[^OG\@#!Z^?HW?(@WB#XY?7DW?(`U/$`R^'M
MZ.'S[-WM[_(@]/WP[_(@Y.7D[^S=[?GM+@#0Z^?J]/'OZ^_CWO/TY2#TY^T@
MY?#IZ^_CWB#SX?(Z(`#'Z^7J]/'O[>GJWB#$Z>7]Z/7M\^<`Q^OEZO3Q[^WI
MZMX@Q.GE_>CU[?/G(./IX2#E\.GS]/'O]MX@X>WA]N_QW/(@ZN'TW//TX?/G
M\B#T[_4@\/'OX_'<[.SA]/SR(//A\@#'Z^7J]/'O[>GJWB#$Z>7]Z/7M\^<Z
M`,'D_>WA].<@YR#P\?SSXN'SYR#S]._M(%9&4R#JX?3<Z^_C[RX`P>3][>'T
MYR#G(/#Q[_/HWNKE(.7PZ?#KW>_M(/#KY_'O]N_QZ?[M(.KA]-P@].?M(.7?
M\^_D[R#T[_4@]_'>\_3G+@#!Y/WMX?3G(.<@X>OKX>/>(.7N[_7SZ>_D[_3>
M\^7Y[2#CZ>$@].\@5D93(.'Q]^7?[R`B)7,B+@#!Y/WMX?3G(.<@X>OKX>/>
M(.7N[_7SZ>_D[_3>\^7Y[2#CZ>$@].\@5D93(.'Q]^7?[R`E<R\E<RX`P>3]
M[>'TYR#G(.'KZ^'CWB#T[_4@)7,N`,3E[2#EW^WAZ2#D]>WA]-X@YR#S_>WD
MY?/G(//T[R#DZ>'J[^SI\_3>(%-13"X`Q.7M(.7?[>'I(.3U[>'TWB#G(//]
M[>3E\^<@[.4@4U-,+@#!Y/WMX?3G(.<@X>WTZ>/QX?;>(%9&4R#A\??EW^_U
M+@#!Y/WMX?3G(.<@Y.?LZ>_U\>/?X2#JX?3AZ_SC[_4@5D93("(E<R(N`,'D
M_>WA].<@YR#DY^SI[_7QX]_A(.KA].'K_./O]2!61E,N`,'D_>WA].<@YR#D
MY^SI[_7QX]_A(%9&4R#A\??EW^_U+@#!Y/WMX?3G(.<@Y.?LZ>_U\>/?X2#J
MY>WO_2!61E,@X?'WY=_O]2X`P>3][>'TYR#G(.'P[_/U[/#?Y?/G(.3EY._L
MW>WY[2X`P>3][>'TYR#G(.3IX>/QX?;>("(E<R(L(.\@]MSJY>OO\B#DY>T@
MY=_MX>D@ZN7M_/(N`,'D_>WA].<@YR#DZ>'C\>'VWB`E<RP@[R#VW.KEZ^_R
M(.3E[2#EW^WAZ2#JY>W\\@#!Y/WMX?3G(.<@Y.GAX_'A]MX@)R5S)SH@)7,N
M`,'D_>WA].<@YR#DZ>'C\>'VWB#JX?3AZ_SC[_4@5D93(.7PX>WAZ^SBX>W\
M[.7MX2`H<F5C=7)S:79E;'DI+@#!Y/WMX?3G(.<@Y.GAX_'A]MX@ZN'TX>O\
MX^_U(%9&4RX`1&%S(%9&4RU697)Z96EC:&YI<R!K;VYN=&4@;FEC:'0@9V5L
M]G-C:'0@=V5R9&5N.B`E<RX`P>3][>'TYR#G(.3IX>/QX?;>(/3O]2!61E,@
MX?'WY=_O]2`B)7,B+@#!Y/WMX?3G(.<@Y.GAX_'A]MX@]._U(%9&4R#A\??E
MW^_U+@#!Y/WMX?3G(.<@Y.GAX_'A]MX@5D93(.7PX>WAZ^'LXN'M_.SE[>$@
M*')E8W5R<VEV96QY*3H@)7,N`,3E(.SP[_'^(.WA(/#Q[_/DZ>_QW_/Y(/3O
M[2#T\=WW[^WTX2#JX?3<Z^_C[RX`Q.4@[/#O\?X@[>$@Y>[<X_D@\.OG\>_V
M[_'?Y?(@\.GS]._P[^GG].GJ[_T`P>3][>'TYR#G(/;\\?3Y\^<@[_'I\^SO
M_2#T[_4@)7,N`,'D_>WA].<@YR#LY?3AZM_MY_/G(/3O]2!61E,@X?'WW^_U
M+@#!Y/WMX?3O(/3O(-SM[^GC[.$@]._U(%9&4R#A\??EW^_U("(E<R(N`,'D
M_>WA].\@].\@W.WOZ>/LX2#T[_4@5D93(.'Q]^7?[_4@X^GA(./QW/CI[.\N
M`,'D_>WA].\@].\@W.WOZ>/LX2#T[_4@5D93(.'Q]^7?[_4N`,3E(.SP[_'^
M(.WA(.'M[]_N^2#T[R#S]>SPZ>7S[-WM[R#A\??EW^\N`,3E(.SP[_'^(.WA
M(.3IX>+<\_D@]._M(.K]\>GO(.KA]-SK[^/O(%9&4R`H=F9S<F]O="DN`,3E
M[2#EW^WAZ2#D]>WA]/SM(.WA(.KA].'W^?'GZ._][2#OZ2#P\>_TZ>S>\^7I
M\B#CZ>$@X?7TWB#TY^T@\_WMY.7SYRX`P>3][>'TYR#G(.SE]._M[^SA\]_A
M(/3O]2`E<R#SY2`E<SH@[R#VW.KEZ^OO\B#U\-SQ]^7I(-[DYP#!Y/WMX?3G
M(.<@[.7T[^WO[.'SW^$@]._U(%9&4R#JX?3AZ_SC[_4N`,'D_>WA].<@YR#L
MY?3O[>_LX?/?X2#T[_4@5D93(.KA].'K_./O]3H@)7,N`,'D_>WA].<@YR#L
MY?3O[>_LX?/?X2#T[_4@5D93(.'Q]^7?[_4@(B5S(BX`P>3][>'TYR#G(.SE
M]._M[^SA\]_A(/3O]2!61E,@X?'WY=_O]2`E<R\E<RX`P>3][>'TYR#G(.SE
M]._M[^SA\]_A(/3O]2!61E,@X?'WY=_O]2X`P>3][>'TYR#G(.7J]-WKY?/G
M(/3O]2`B;6MI<V]F<R(N`,3E[2#L\/SQY?/E(.WA(.SE].'V\>'S].7?(.'U
M]/P@].\@W>/C\>'V[R!7;W)D`,3E(.SP[_'^(.WA(./QW/CY(//T[R!61E,@
MX?'WY=_O("(E<R(N`,3E(.SP[_'^(.WA(./QW/CG(//T[R!61E,@X?'WY=_O
M("AC;W!Y*"D@X?#=]/7WY2DN`,3E(.SP[_'^(.WA(./QW/CY(.3EY._LW>WA
M(/3O]2!61E,@X?'WY=_O]2X`U?#OX_'A[.SI\^S=[>$`P>K]\?GSYR#!Z^OA
MX_[M`,'J]?'^[>7I(/3G(/3EZ^7U].'?X2#SX?(@Y>W=\>/EZ>$`S.<@X>WA
M[.7M_.SE[>\@]-WK[_(@]._U(.'Q]^7?[_4N`,SG(.'MX>SE[?SLY>WG(.'P
MW.WTY_/G(.'P_"#T[^T@Y>[U\.?QY?3G]-X@\_3G(//][>3E\^<Z(`#,YR#A
M[>'LY>W\[.7MYR#A\-SM].?SYR#A\/P@]._M(.7N]?#G\>7TY_3>(//T[SH@
M`,SG(,'Q]^7I[^CE].?LW>WO`,SG(/?EZ?'IYOSLY>WO(//T[^GWY=_O(/3]
M\._U.B`E<P#,[^W<Y.7R`,'C[?GS].\`56YK;F]W;B!A<&EM<V=I9"`H05!)
M($UE<W-A9V4@240I+@!5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G
M92!)1"DN`,'C[?GS].\@_.WO[.$@]_'>\_3G(-X@ZOGDZ>K\\BX`P?#O\_WM
MY.7SYR#T\=WW[^WT[_(@\_3OZ??EW^_U`,'M_NWU[.\`S.<@Y>[O]?/I[^3O
M].?LW>WA(/#Q[^/QW.SLX?3A(.3E(.SP[_'O_>T@[>$@W??O]>T@\/'\\^+A
M\^<@\^4@Z^7I]._U\>/?Y?(@X?#OZN_PWO(OX>WTZ>/QX?;>\B_E\.GJ_.OG
M\^?R(./IX2#K_./O]?(@X?/VX>OEW^'R+B#0X?3>\_3E(,_*(./IX2#MX2#D
MY=_TY2#TY??MZ>K=\B#SY^SEZ?[SY>GR(//T[R!M;WII;&QA+F]R9R#P[_4@
M\^'R(.3EW_?M[_7M(/#Y\B#MX2#E\.GT\=WXY?3E(//E(/#Q[^/QW.SLX?3A
M(/3G(/#Q_//BX?/G(//T[R!C;&EP8F]A<F0`S.<@[_'I\^S=[>\@]_'^[.$`
MS.<@]?#O\_3G\>GF_.SE[><@Y?#=ZO3A\^<`Q>WG[-WQ^?/G`,7MY^S=\?GS
MYR`E<P#%[>?LW?'Y\^<@ZN'TW//TX?/G\B#A\.'M].?LW>WO]0#%[>?LW?'Y
M\^<@]_'>\_3G`"<E<R<@Q>WG[.7Q_NCGZN4N`-3O(/#Q_./QX>SLX2#A[>'B
MW.CLZ?/G\B#DZ>'C\=SVY^KE+@#!\._S]._KW@#!\._S]._KWB#\Z_GM(/3Y
M[2#A\??EW_GM(/'UZ.S?\^7Y[2#S]._M(.7N]?#G\>7TY_3>+@#*Y?;AZ^'?
MX2#KX?3I[>GJW"#C\=SL[.'TX0#1^>SA^NKOWR#A\>GH[._?+<KE]N'KX=_A
M`-?QWO/G(/3QW??O[?3O\CH@)7,`S>$@]_'G\^GL[_#OZ>?HY=\@YR#P\>_E
M\.GKY>/LW>WG(/3I[-X`U_'>\^<@4U-,`-?QY_/I[._P[^GEW_3AZ2#A[2#T
M[R#\[>_LX2_J^>3IZOSR(.7?[>'I(.3IX?;O\>7TZ>K<+@#/(/?QWO/TY_(@
M)7,@Y.7M(.7?[>'I(.7N[_7SZ>_D[_3G[-WM[_(@X^GA("5S+@#$Z>'WY=_Q
MZ?/G(-?QY_/T_NT`Q?#IZ^_CW?(@U_'>\_3G`,7CX_'A]MX@U_'>\_3G`,<@
MY>/C\>'VWB#W\=[S].<@W??EZ2#A\.7MY?'C[_#OZ>?HY=\@X^DG(.'U]/P@
M].\@<VET92X`P>OKX>/>(.KYY.GJ[_T@]_'>\_3G`,7N[_7SZ>_D[_3>\^7I
M\B#7\=[S].<`O.WO[.$@U_'>\_3G`-3O(/SM[^SA(/?QWO/TYR`G)7,G(/7P
MW/'WY>D@WN3G+@"\[>_LX2#7\=[S].<Z`+SM[^SA(-?QWO/TYSH@`-?QWO/T
MY?(`U_'>\_3E\B#S].\@T_WS].?LX3H`SR#JX?3<Z^_C[_(@5D93(.3E[2#U
M\-SQ]^7I+@#$Z>'J[_#=\@"XX^KU\>7R(/3O\._HY?/?Y?(@\._U(.+QW>CG
MZN'M(//U[/#E\>GKX>SBW.WO[?3AZ3H@`,7CZO7Q_/3G].$`U.GLWB#SY2#K
MY?#TW"#A\/P@]/[QX2X`U.GLW?(`Q/[S].4@].GLW?(@X^GA(.WA(.7PZ>O=
M[OD`S.7TX>+KY_3>`,<@Y?#IXN7BX=_Y\^<@X?#=]/7WY2`M(.'U]/P@].\@
M[-[M]>SA(.SP[_'EWR#MX2#<Z^OA[N4@[.4N`+CJY._SYP"XZ^7C]^_R(+CJ
MY._SY_(`RMSHY?3G(,7UZ/7C\=SL[.GSYP#*W.CE].\@X]WLZ?/LX0#*W.CE
M].$Z`-#OZ_T@^.?KW@#%[/;<[>GSYR`E<P#%[/;<[>GSYR#E[OGTY?'IZM[R
M(.GS]._SY>O?Y.'R`,7L]MSMZ?/G(//A[2`E<P#%[/;<[>GSYR#CY>/O[?ST
M[_(`Q>SVW.WI\^<@Y?'CX?/?X?(`S_'A]/STY_3A`,_QX?3\].?TX3H`5F]D
M869O;F4@R?3AZ]_A\B#LW?/Y(%--5%``T-'/T\_7QP#0T<_3S]?'(2$A(,'6
MP<G1Q=/4Q2#4SR#0T<_#T<',S,$@S,_-S\D@T\'3(,'0SR`E<RX`T/'OY>GD
M[_#OW^?SYP#4Y0#%XN3O[.'DZ>'?X0#*X>OY\][KZ.'TY0#*X>OY\][KZ.'T
MY2#S].\@)7,`RN'K^?/>Z^CA].4L("5S`-#OZ=P@Y?;A\>SOX]X@Z.$@Y>SV
MX>S?YN7I(/3O("5S(.'V[_T@\_7MY.7HY=_TY2#S].?M(/7PY_'E\]_A.P#0
M[^GA(.7VX?'L[^/>(.WA(.7L]N'MW^;E].'I(.'V[_T@\_7MY.7HY=_TY2#S
M].?M(/7PY_'E\]_A.P#0[^G\\B#EW^WAZ2#O(.3IX??Y\>GS].GJ_/(@]^'Q
MX>KTWO'A\CL`T._I_/(@Y=_MX>D@[R#WX?'AZO3>\>'R(.7I\^'C^>/IZO[M
M.P#0[^G=\B#6W//EZ?(`RN'H[_'?\_3E(/#OZ=P@\/'\\^CE].$@Z.$@Y>WE
M\>/O\._IY^CO_>T@\_3O[2#E\.7NY?'CX?/TWB#E[/#K[_7TZ?/LW>WO]2#J
MY>GLW>WO]2X`T.O<]._R`-#KW/3O\B#SY2#L[^W<Y.7R($-34P#0Z]ST[_(@
M]._U("5S(.SE[>_](//TX2#A\>GS].7QW"`HZ.$@Y?;A\>SO\^CEWR#S].?M
M(.7P_.SE[><@Y=_S[^3O*3H`T.O<]._R(/3O]2#PW^WAZN$`S._MW.3A(/#K
MW/3O]?(`T.O<]._R.@"X[?3A\^<@X>W=[._U(//E(.K\[.+O]?(`P>WE[._R
M.@#![>7L[_(Z(`#3[_;?X0#+W_/TX2#E\.GH]>SI_NT`Q?'CX?/?X0#$Z>7]
MZ/7M\^<@Q?'CX?/?X?(`U.?KW?;Y[>\@Q?'CX?/?X?(`6"U2968`6#4P.78S
M(,+A\^GJ[]\@T.7QZ>_QZ?/L[]\`6#4P.78S(-?QWO/G(.7PY>KTX>S=[>_U
M(.KKY>GDZ>_]`%@U,#EV,R#%[>'KX>KTZ>K\(+SM[^SA(,C=[.'T[_(`6#4P
M.78S(,'MX>/M^?'I\_3IZOP@RNOEZ>3?(,C=[.'T[_(`6#4P.78S(,7PY>KT
MW//EZ?(`Q<4`Q<7%Q0#%]-[SZ>$`S>'?`,WAZ2P@T_7L]OGM_@#%W_/TY2#S
MY2#JX?3<\_3A\^<@RL7)S,7-S]4N(-?QY_/I[._P[^GEW_/TY2#T[R!;/#Y=
M(/#KWNKT\>\@X^GA(.WA(.7PZ?/T\=WXY?3E(//E(.KA]-SS].'SYR!765-)
M5TE'+@#$Y>T@W??E].4@X?7HY>WTZ>KO\._IY^CEWRX`Q.7M(.7PZ?3QW?#E
M].'I(.WA(-WWY?3E(/3O(/?A\>'J]-[QX2`G7"<@\_3O(+SM[^S<(//A\BX`
MQ.4@Y/[SX?3E(-WCX_7QYR#DZ>7]Z/7M\^<@96UA:6PN`,3E[2#A[?3I\_3O
MZ???\^'TY2#JX>W=[>$@\.7DW^\@X?#\(/3O(.'Q]^7?[R#EZ?/AX_GCWO(@
M\^4@X>WTW_/T[^GWX2#PY>3?X2#S].\@)7,N`+CWY?3E(.'P[_/U[>3EZ.7?
M+@"X]^7TY2#A\._S]>WDY>CEWRX\8G(@+S[%]??A\>GS]._][.4@\._U(/?Q
MY_/I[._P[^G>\^'TY2#TY^T@]?#G\>7SW^$N`-#QW?#EZ2#MX2#D_O/E].4@
M[.GA(-WCZO7QYR#TZ>S>+@#0\=WPY>D@[>$@\?7H[-_SY?3E(/3O($1A=&%4
M<F5E(./IX2#MX2#W\>?SZ>SO\._IY=_TY2!3:6=N=7!S+@#0\=WPY>D@[>$@
M\?7H[-_SY?3E(/3O(%9&4RU"86-K96YD+@#0\=WPY>D@[>$@\.7QZ>/QW/CE
M].4@].\@\/'\XNOG[.$@\/'I[2#S].7?Z^7TY2#A[>'V[_'<(./IX2#A]?3\
M+@#0\=WPY>D@[>$@\_7L\.OG\?[SY?3E(/3O(%523"#P[_4@Y.7?]^WEZ2#A
M]?3>(.<@\_WMY.7SYP#0\=WPY>D@[>$@Y?#IZ]WNY?3E(/3O[2#E[O7PY_'E
M].?TWB#CZ>$@Y.GAX_'A]MXN`-#QW?#EZ2#MX2#O\=_SY?3E(-WMX2#\[>_L
MX2#W\=[S].<@X^GA(.3IX>/QX?;>+@#0\=WPY>D@[>$@[_'?\^7TY2#=[>$@
M_.WO[.$@]_'>\_3G(./IX2#DZ>'C\>'VWBX`T/'=\.7I(.WA(._QW_/E].4@
MW>WA(/SM[^SA(/?QWO/TYR#CZ>$@\/'O\^C>ZN<N`-#QW?#EZ2#MX2#O\=_S
MY?3E(-WMX2#\[>_LX2#W\=[S].<@X^GA(.7MY^S=\?GSYRX`T/'=\.7I(.WA
M(._QW_/E].4@[.GA(.7MW?'CY>GA(./IX2#EZO3=Z^7SYRX`T/'=\.7I(.WA
M(.3^\^7TY2#=[>$@_.WO[.$@X^GA(/3G(.W=X2#JX?3GX^_QW^$N`,<@\_WM
MY.7SYR#SX?(@)7,@Y.GAZOSPY^KE+B#0X?'AZN'K_B#D[^KI[-SS].4@[>$@
M[N'MX?/U[>3EZ.7?].4N`,<@Q^OEZO3Q[^WIZMX@\^'R(,3IY?WH]>WSYP#'
M(,?KY>KT\>_MZ>K>(//A\B#$Z>7]Z/7M\^<Z`,<@P?#\.B#$Z>7]Z/7M\^<Z
M`,_I(-#KY_'O]N_QW^7R(//A\@#'($EN=&5R;F5T(.3IY?WH]>WSWB#SX?(@
MW.OKX>[E(.'P_"#TY^T@W>WA\>[G(/3G\B`E<R#S_>WDY?/>\B#SX?(N(,/I
MX2#TY^T@\/'O\_3A\]_A(/3G\B#A\_;<Z^7IX?(@\/'=\.7I(.WA(.[A[>'S
M]>WDY>CEW_3E+@#4[R#\[>_LW"#SX?(`U.\@\_WS].?LX2#A]>CE[?3IZN_P
M[]_G\^?R(.3E[2#U\._S].?QW^;EZ2#P\>_SZ-[JYR#W\>?S]/[M+"#>(.<@
MZ^7I]._U\>/?X2#A]?3>(-WWY>D@X?#E[>7QX^_P[^GGZ.7?(./IX2#JW/#O
MZ>\@Z_SC[RX`U.\@\_WS].?LX2#A]>CE[?3IZN_P[]_G\^?R(.3E[2#U\._S
M].?QW^;EZ2#KW_/TX2#W\>?S]/[M+"#>(.<@Z^7I]._U\>/?X2#A]?3>(-WW
MY>D@X?#E[>7QX^_P[^GGZ.7?(./IX2#JW/#OZ>\@Z_SC[RX`SR!"<F]W<V5R
M(//A\B#VX=_MY?3AZ2#MX2#=]^7I(.'KZ]SNY>D@X?#\(/3G[2#=[>'Q[N<@
M].?R("5S(//][>3E\][R(//A\BX@P^GA(/3G[2#P\>_S].'SW^$@].?R(.'S
M]MSKY>GA\BP@Z.$@\/'=\.7I(.WA(.[A[>'S]>WDY>CEW_3E+@#/($)R;W=S
M97(@\^'R(.3E[2#U\._S].?QW^;EZ2#A]?3>(/3G(.OEZ?3O]?'CW^$N`,\@
M0G)O=W-E<B#SX?(@Y.7M(/7P[_/TY_'?YN7I(.'U]-X@].?M(.7PZ>OOX]X@
MY>KT_?#Y\^?R+B#0X?3>\_3E($-O;G1R;VPO3W!T:6]N("L@4"#CZ>$@Y>KT
M_?#Y\^<N`,<@]/'=]^_U\^$@YO[MYR#^\>'R.@#'(/#Q[^KAZ._QZ?/LW>WG
M(//A\B#TX?7T_/3G].$Z`-3O(/#KWO'E\B#\[>_LW"#SX?(Z`,\@[=WO\B#S
MX?(@ZOGDZ>K\\B#CZ>$@)7,@Y=_MX>DZ("5S`,_I(.7PZ>OOX]WR(//A\B#=
M]^_U[2#E[>?LY?'YZ.7?(./IX2#TYR#DZ=SQZN7IX2#A]?3>\B#TY_(@\_WM
MY.7SY_(N`,_I(.7PZ>OOX]WR(//A\B#=]^_U[2#E[>?LY?'YZ.7?+@#/(.KY
MY.GJ_/(@\^'R(-SKZ^'NY0#/(.KYY.GJ_/(@\^'R(-SKZ^'NY2P@Y>O=X^[T
MY2#TX2#LY^W][.'TW"#SX?(@ZN'I(.K<[?3E(.7?\^_D[R#LY2#T[R#MW>\@
M\^'R(.KYY.GJ_"X`S^D@[=WOZ2#J^>3IZN_?(.3E[2#TX>GQZ=SF[_7M`,_I
M(.'P[^SAZO'U\^S=[>_I(//A\B#E[O7PY_'E].?TW?(Z`%O!\/SJ\?7XYR#J
MY>GLW>WO]2#SY2#EZ?/AX_GCZ>K<70!;P>WA]N_QW"#0\>_BZ][LX?3O\ET`
M6\7L]MSMZ?/G(.KEZ>S=[>_U(//E(.7I\^'C^>/IZMP@+0!;Q>SVW.WI\^<@
MZN7I[-WM[_4@\^4@Y>GSX>/YX^GJW"`M("5S(./QX>SLW?)=`%OC\>'L[-X@
M)7,@X?#\("5S70#$Z>'WY=_QZ?/G`,3IX>/QX?;>(,/QX>SLWO(`S^S<Y.7R
M`,+OWNCEZ>$`R>3I_/3G].7R(,7IZOSMX?(N+BX`Q=_S[^3O\@#%[N_D[_(`
MU/'O\._P[]_G\^<@T_WMY.7S[._U+BXN`,7PZ>OOX]WR`,7N[_7SZ>_D[_3>
M\^7I\@#$Z>'C\>'VWB#3]>WDW?/L[_4N+BX`T?7H[-_SY>GR`,GDZ?STY_3E
M\B#0W^WAZN$N+BX`U_'>\_3E\@#$Z>7UZ/7M\^GOX_'<]N_R`,?LY?'OZ_SC
MZ>\`Y_'E[-_A`/#A]-[S].4@Y>3^`.'Q]^7?[P#A\/P@].\@)7,@*"5S*2#S
M].GR("5S("5S`&@Z`-SLY?/A`.7M\_GLX?3Y[-WM[P#C\>'L[-WR70!M:VES
M;V9S+>KYY.GJ_/(@Z]SH[_7R("5D(.KA]-P@].<@Y.?LZ>_U\>/?X2!)4T\N
M`/SM[^SA`.3E[2#=]^7I(.7CZN'TX?/TX>CEWP#DY>T@W??EZ2#EX^KA].'S
M].'HY=\@X>K\[.<`\^?LY>GY[.'TW/'I[P#T[^GR(.7JX?3\`.7IZN_M[_/T
M[^GWY=_A`.7L]MSMZ?/G(.3IX?;O\?[M`'-M<R#SY2!E;6%I;"#LW?/Y($A4
M5%``\_3AZ.7Q_/(`Z]_S].$@Y?'CX?/I_NT`ZMSD[_(`P_'<^/3E(/3O[2#J
M^>3IZOP@Y/WO(/;O\=WR(./IX2#E\.GBY>+AW_GSYP#E[>_P[^GG[-WMX0#A
M[?[M]>SA`.7PZ>OOX]X@]_'>\_3G`-CG]NGAZMX@RMSQ].$`````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]E;%]'4B]H96QP+GAM
M;```````````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S,R
M,"`Q,#4Q-30S,S<T,2`P,C$T,S4`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]X;6P@=F5R<VEO;CTB,2XP(C\^"CPA+2T@
M)$AO<F1E.B!H;W)D92]L;V-A;&4O96Q?1U(O:&5L<"YX;6PL=B`Q+C(@,C`P
M-"\P-2\R-R`R,#HR,CHQ-B!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R
M>2!I9#TB<W5M;6%R>2(@<W1A=&4](FYE=R(^"CQT:71L93Y4:&4@4&]R=&%L
M(%!A9V4\+W1I=&QE/@H@/'!A<F$^"B`@5&AI<R!P;W)T86P@<&%G92!P<F]V
M:61E<R!A('%U:6-K('-U;6UA<GD@;V8@86QL('EO=7(@:6UP;W)T86YT"B`@
M:6YF;W)M871I;VXN($9O<B!E>&%M<&QE+"!I="!M:6=H="!S:&]W(&AO=R!M
M86YY(&YE=R!E+6UA:6P@;65S<V%G97,@>6]U"B`@:&%V92!I;B!Y;W5R($E.
M0D]8+"!U<&-O;6EN9R!E=F5N=',@;VX@>6]U<B!C86QE;F1A<BP@=&%S:W,@
M;VX@>6]U<B!T;RUD;PH@(&QI<W0L(&AE861L:6YE<R!F<F]M('-E;&5C=&5D
M(&YE=W,@<V5R=FEC97,L(&%N9"!S;R!O;BX@($UA;GD@;V8@=&AE<V4*("!S
M=6UM87)I97,@=VEL;"!C;VYT86EN('%U:6-K('-H;W)T8W5T<R!T;R!C;VUM
M;VX@9G5N8W1I;VYS+"!S=6-H(&%S"B`@8V]M<&]S:6YG(&$@;F5W(&UA:6P@
M;65S<V%G92P@8W)E871I;F<@82!N97<@8V%L96YD87(@979E;G0@;W(@=&%S
M:RP@971C+@H@/"]P87)A/@H@/'!A<F$^"B`@5&AE(&-O;G1E;G1S(&]F('1H
M:7,@<&]R=&%L('!A9V4@87)E(&-U<W1O;6EZ86)L92!V:6$@=&AE($QA>6]U
M="!B=71T;VXN"B`@1F]R(&5X86UP;&4L('EO=2!C86X@8VAO;W-E('=H:6-H
M(&ET96US('1O(&EN8VQU9&4@;VX@=&AI<R!P;W)T86P@<&%G92!A<PH@('=E
M;&P@87,@:6X@=VAI8V@@;W)D97(@=&AE>2!A<F4@<VAO=VXN"B`\+W!A<F$^
M"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)N879B87(B('-T871E/2)N97<B/@H\
M=&ET;&4^5&AE($%P<&QI8V%T:6]N($YA=FEG871I;VX@0F%R/"]T:71L93X*
M(#QP87)A/@H@($%T('1H92!L969T(&AA;F0@<VED92!O9B!T:&4@=V5B('!A
M9V4@:7,@=&AE(&%P<&QI8V%T:6]N(&YA=FEG871I;VX@8F%R+@H@($-L:6-K
M(&]N('1H92!I8V]N<R!O;B!T:&ES(&YA=FEG871I;VX@8F%R('1O('%U:6-K
M;'D@86YD(&5A<VEL>2!S=VET8V@*("!B971W965N('1H92!A=F%I;&%B;&4@
M87!P;&EC871I;VYS+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M<')E9G,M9&]?;6%I;G1E;F%N8V4B('-T871E/2)N97<B/@H@("`@/'1I=&QE
M/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@1&\@36%I;G1E;F%N8V4\+W1I
M=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!P97)F
M;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6XL(&-H96-K('1H
M:7,@8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E
M9G,M8V]N9FER;5]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^"B`@("`\=&ET
M;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!#;VYF:7)M($UA:6YT96YA
M;F-E/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U('=O=6QD(&QI:V4@
M=&\@8V]N9FER;2!A;&P@;6%I;G1E;F%N8V4@=&%S:W,@8F5F;W)E('1H97D@
M87)E(')U;BP@8VAE8VL@=&AI<R!B;W@N($EF(&QE9G0@=6YC:&5C:V5D+"!A
M;&P@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!T:&%T(&YE960@=&\@8F4@<G5N
M('=I;&P@8F4@<&5R9F]R;65D(&%U=&]M871I8V%L;'D@=VET:"!N;R!C:&%N
M8V4@=&\@8V%N8V5L(&]N(&QO9VEN+@H@("`@/"]P87)A/@H\+V5N=')Y/@H\
M+VAE;'`^"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O9F%?25(`````````````````
M````````````````````````````````````````````````````````````
M````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U
M,34T,S,W-#$@,#$W-C<V`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]F
M85])4B],0U]-15-304=%4P``````````````````````````````````````
M```````````````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<T,2`P,C$T-C,`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&]C86QE+V9A7TE2+TQ#7TU%4U-!1T53+VAO<F1E+FUO````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,S4W-S$W(#$P-3$U-#,S-S0Q(#`R
M,S(R-``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#>$@25`````*<%```<````5"T``(L'``",6@```````+AX```.````N7@`
M``\```#(>```#0```-AX```(````YG@```L```#O>```#````/MX```$````
M"'D``"0````->0``*0```#)Y```9````7'D``"8```!V>0``#````)UY```D
M````JGD```\```#/>0``"P```-]Y```.````ZWD```4```#Z>0``*`````!Z
M```(````*7H```H````R>@``%0```#UZ```2````4WH```L```!F>@``A0``
M`')Z```.````^'H```H````'>P``#0```!)[```.````('L``!$````O>P``
M#0```$%[```,````3WL```T```!<>P``!@```&I[```*````<7L```\```!\
M>P``&````(Q[```,````I7L```X```"R>P``#@```,%[```(````T'L``"X`
M``#9>P``&@````A\```R````(WP``#@```!6?```5````(]\``!1````Y'P`
M`%H````V?0``5P```)%]```T````Z7T```T````>?@``!P```"Q^```*````
M-'X```\````_?@``!0```$]^```1````57X```@```!G?@``"0```'!^```)
M````>GX``"4```"$?@``(````*I^```3````RWX``!````#??@``#P```/!^
M```*`````'\```,````+?P``#P````]_```4````'W\```D````T?P``#0``
M`#Y_```2````3'\``!X```!??P``#P```'Y_```*````CG\```\```"9?P``
M"````*E_```D````LG\``!0```#7?P``%@```.Q_```(`````X```!D````,
M@```!P```":````,````+H```"P````[@```#@```&B````#````=X````4`
M``![@```!0```(&````*````AX````,```"2@```%P```):````*````KH``
M``\```"Y@```#@```,F````8````V(```",```#Q@```#@```!6!```4````
M)($``!<````Y@0``%P```%&!```7````:8$``!,```"!@0``#P```)6!```?
M````I8$```\```#%@0``!@```-6!```+````W($``!````#H@0``%0```/F!
M```5````#X(```<````E@@``$````"V"```%````/H(``!4```!$@@``$0``
M`%J"```,````;((``#L```!Y@@``%````+6"```#````RH(``#D```#.@@``
M$@````B#```G````&X,``"P```!#@P``*@```'"#```E````FX,```H```#!
M@P``!@```,R#```O````TX,``#<````#A```+@```#N$``!5````:H0``"T`
M``#`A```+0```.Z$```M````'(4``$````!*A0``(P```(N%```C````KX4`
M`"T```#3A0``,P````&&```5````-88``!D```!+A@``*0```&6&```D````
MCX8``!$```"TA@``"@```,:&```0````T88``!8```#BA@``%@```/F&```4
M````$(<```@````EAP``*0```"Z'```.````6(<```H```!GAP``!````'*'
M```)````=X<```8```"!AP``$0```(B'```'````FH<```0```"BAP``!@``
M`*>'```-````KH<```,```"\AP```P```,"'```7````Q(<``!,```#<AP``
M"````/"'```$````^8<``$$```#^AP``&@```$"(```@````6X@``!4```!\
MB```!@```)*(```5````F8@``!@```"OB```(@```,B(```N````ZX@``!T`
M```:B0``(0```#B)``!4````6HD``"D```"OB0``!P```-F)```'````X8D`
M`!4```#IB0``"@```/^)```/````"HH```T````:B@``#P```"B*```-````
M.(H```D```!&B@``%````%"*```&````98H``!T```!LB@``$P```(J*```4
M````GHH```8```"SB@``%````+J*``!4````SXH``&0````DBP``!````(F+
M```.````CHL```4```"=BP``&P```*.+```:````OXL``!$```#:BP``$0``
M`.R+```<````_HL``"H````;C```(0```$:,```%````:(P``!,```!NC```
M$@```(*,```*````E8P```\```"@C```$0```+",```3````PHP```P```#6
MC```!@```..,```&````ZHP``!````#QC```$0````*-```%````%(T```P`
M```:C0``$````">-```%````.(T```T````^C0``!@```$R-```'````4XT`
M``T```!;C0``!P```&F-```+````<8T```<```!]C0``"0```(6-```)````
MCXT```H```"9C0``&0```*2-```,````OHT``!````#+C0``$@```-R-```3
M````[XT``"L````#C@``.P```"^.```@````:XX```@```",C@``-@```)6.
M```(````S(X```8```#5C@``!````-R.```.````X8X``!X```#PC@``&P``
M``^/```A````*X\``!X```!-CP``&0```&R/```>````AH\``!T```"ECP``
M&P```,./```@````WX\``"8`````D```&P```">0```>````0Y```!P```!B
MD```)@```'^0```S````II```"8```#:D```*P````&1```X````+9$``"\`
M``!FD0``$@```):1```I````J9$``!(```#3D0``H@```.:1```6````B9(`
M`",```"@D@``*````,22```I````[9(``"@````7DP``'P```$"3```@````
M8),``"4```"!DP``*````*>3```P````T),``)(````!E```(0```)24```<
M````MI0``"8```#3E```00```/J4```,````/)4```<```!)E0``!P```%&5
M```&````694```T```!@E0``$````&Z5```2````?Y4``!,```"2E0``$@``
M`*:5```,````N94```X```#&E0``#P```-65```3````Y94```T```#YE0``
M*`````>6```#````,)8```T````TE@``$0```$*6```7````5)8``!L```!L
ME@```@```(B6```%````BY8``!````"1E@``!````**6```-````IY8```X`
M``"UE@```P```,26```.````R)8```@```#7E@``#P```."6```/````\)8`
M``<`````EP``#0````B7```0````%I<```T````GEP``"P```#67```&````
M09<```P```!(EP``$0```%67```9````9Y<```L```"!EP``#0```(V7```B
M````FY<``!L```"^EP``-````-J7```*````#Y@``!@````:F```&0```#.8
M```6````39@```T```!DF```%````'*8```+````AY@``"(```"3F```+P``
M`+:8```+````YI@```D```#RF```&0```/R8```+````%ID``!<````BF0``
M%P```#J9```)````4ID``!8```!<F0``#P```'.9```9````@YD``!8```"=
MF0``#@```+29```8````PYD```T```#<F0``)@```.J9``!#````$9H```@`
M``!5F@``"P```%Z:```O````:IH```X```":F@``!0```*F:```&````KYH`
M``,```"VF@``!````+J:```*````OYH```H```#*F@``#P```-6:```0````
MY9H``!<```#VF@``$0````Z;```9````()L``!<````ZFP``"0```%*;```*
M````7)L```(```!GFP``!0```&J;```-````<)L``!L```!^FP``%P```)J;
M```)````LIL```X```"\FP``#0```,N;```2````V9L``#@```#LFP``(```
M`"6<```(````1IP```X```!/G```>P```%Z<```8````VIP```4```#SG```
M&````/F<```9````$IT``!L````LG0``&0```$B=```&````8IT```8```!I
MG0``$````'"=```/````@9T``!````"1G0``#P```**=```+````LIT```\`
M``"^G0``#````,Z=```/````VYT```<```#KG0``!@```/.=```.````^IT`
M``P````)G@``#P```!:>```(````)IX```@````OG@``$P```#B>```>````
M3)X``"$```!KG@``(````(V>```9````KIX``!<```#(G@``)0```.">```7
M````!I\```0````>GP``#````".?```#````,)\```@````TGP``"P```#V?
M```0````29\``!,```!:GP``%````&Z?```,````@Y\```D```"0GP``#@``
M`)J?```+````J9\``!L```"UGP``!P```-&?```*````V9\```T```#DGP``
M"0```/*?```%````_)\```,````"H```&`````:@```*````'Z````0````J
MH```)@```"^@```.````5J```!4```!EH```!0```'N@```'````@:````P`
M``")H```"````):@```*````GZ````8```"JH```"````+&@```"````NJ``
M``8```"]H```!````,2@```)````R:```!````#3H```"0```.2@```)````
M[J```!H```#XH```"````!.A```9````'*$```X````VH0``"@```$6A```"
M````4*$```T```!3H0``"0```&&A```2````:Z$``!0```!^H0``'0```).A
M```&````L:$``!$```"XH0``"0```,JA```$````U*$``#D```#9H0``/0``
M`!.B```Z````4:(``!X```",H@``#@```*NB```$````NJ(```8```"_H@``
M%0```,:B```&````W*(```0```#CH@``$0```.BB```&````^J(```H````!
MHP``(@````RC```$````+Z,```4````THP``!````#JC```,````/Z,```X`
M``!,HP``"@```%NC```%````9J,``#H```!LHP``,````*>C```U````V*,`
M`"D````.I```.````#BD```I````<:0``#\```";I```+@```-ND```M````
M"J4``!\````XI0``#P```%BE```2````:*4```L```![I0``)@```(>E```I
M````KJ4``"0```#8I0``)@```/VE```(````)*8```H````MI@``(````#BF
M```@````6:8``"8```!ZI@``"@```*&F```9````K*8``"D```#&I@``$@``
M`/"F```*`````Z<```P````.IP``#P```!NG```0````*Z<``$`````\IP``
M<````'VG``!F````[J<```X```!5J```"0```&2H```*````;J@``!(```!Y
MJ```$P```(RH```,````H*@```8```"MJ```#P```+2H```2````Q*@``!``
M``#7J```$0```.BH```<````^J@``",````7J0``:@```#NI```/````IJD`
M`!````"VJ0``!````,>I```+````S*D``"````#8J0``%````/FI```,````
M#JH```P````;J@``#P```"BJ```5````.*H``"D```!.J@``*@```'BJ```F
M````HZH``"<```#*J@``*0```/*J```J````'*L``!D```!'JP``0@```&&K
M```1````I*L``!(```"VJP``$P```,FK```4````W:L```\```#RJP``%@``
M``*L```7````&:P``!`````QK```$0```$*L```T````5*P``!,```")K```
M$@```)VL```U````L*P``!0```#FK```!P```/NL```,`````ZT``"`````0
MK0``%````#&M```1````1JT``!<```!8K0``'````'"M```3````C:T``!$`
M``"AK0``&@```+.M```>````SJT``!H```#MK0``$0````BN```7````&JX`
M`!0````RK@``%P```$>N```5````7ZX```D```!UK@``$````'^N```1````
MD*X```8```"BK@``!@```*FN```'````L*X``!8```"XK@``!@```,^N```$
M````UJX```0```#;K@``!P```."N```.````Z*X```P```#WK@``#`````2O
M```-````$:\```X````?KP``*````"ZO```,````5Z\```\```!DKP``"@``
M`'2O```(````?Z\```D```"(KP``*P```)*O```$````OJ\```\```##KP``
M!P```-.O```(````VZ\```D```#DKP``%````.ZO```,`````[````T````0
ML```#@```!ZP```6````+;```!$```!$L````P```%:P```&````6K````0`
M``!AL```"P```&:P```+````<K````T```!^L```"@```(RP```0````E[``
M``\```"HL```$0```+BP```7````RK````H```#BL```$0```.VP```$````
M_[````\````$L0``.@```!2Q```%````3[$```P```!5L0``'@```&*Q```.
M````@;$``!````"0L0``"P```*&Q```,````K;$```D```"ZL0``!P```,2Q
M```*````S+$```D```#7L0``#@```.&Q```0````\+$``!H````!L@``"@``
M`!RR```*````)[(```P````RL@``#P```#^R```(````3[(```8```!8L@``
M!P```%^R```%````9[(```L```!ML@``1P```'FR```-````P;(```D```#/
ML@``!````-FR```#````WK(``!,```#BL@``$P```/:R```3````"K,```(`
M```>LP``!````"&S```E````)K,```,```!,LP``!0```%"S```$````5K,`
M``H```!;LP``#0```&:S``!H````=+,```D```#=LP``#````.>S```%````
M]+,```8```#ZLP``&P````&T```O````';0```\```!-M```$P```%VT```;
M````<;0``!@```"-M```%P```*:T```.````OK0```,```#-M```"````-&T
M```'````VK0```H```#BM```"P```.VT```'````^;0``%$````!M0``$```
M`%.U```,````9+4```T```!QM0``&@```'^U``!*````FK4```8```#EM0``
M!@```.RU```&````\[4```D```#ZM0``&`````2V```7````';8```8````U
MM@``#0```#RV``!7````2K8``!,```"BM@``$P```+:V```"````RK8```L`
M``#-M@``"````-FV```-````XK8```H```#PM@``#@```/NV```'````"K<`
M``L````2MP``#````!ZW```-````*[<```P````YMP``"0```$:W```)````
M4+<```H```!:MP``!P```&6W```)````;;<```<```!WMP``&P```'^W```2
M````F[<```H```"NMP``%@```+FW```)````T+<``!````#:MP``$@```.NW
M```$````_K<``!$````#N```&@```!6X```6````,+@``!0```!'N```%P``
M`%RX```<````=+@``!D```"1N```!P```*NX```%````L[@```P```"YN```
M"````,:X```7````S[@```P```#GN```'P```/2X```:````%+D``!,````O
MN0``!````$.Y```*````2+D```0```!3N0``#````%BY```%````9;D```(`
M``!KN0``.````&ZY```L````I[D``!(```#4N0``*0```.>Y```R````$;H`
M``H```!$N@``+````$^Z```N````?+H``#,```"KN@``,P```-^Z```X````
M$[L```\```!,NP``&````%R[```0````=;L```\```"&NP``$P```):[```4
M````JKL``!(```"_NP``%````-*[```5````Y[L``"T```#]NP``+0```"N\
M```Q````6;P``"X```"+O```+P```+J\```L````ZKP``!,````7O0``"```
M`"N]```7````-+T```@```!,O0``*P```%6]```A````@;T``!H```"CO0``
M"0```+Z]``!%````R+T``$$````.O@``!````%"^```3````5;X``!0```!I
MO@``$P```'Z^```)````DKX```H```"<O@``#P```*>^```0````M[X```<`
M``#(O@``#@```-"^```%````W[X``!L```#EO@``"`````&_```&````"K\`
M`!0````1OP``$0```":_```.````.+\``#@```!'OP```@```("_```&````
M@[\```X```"*OP``!0```)F_```'````G[\```X```"GOP``!@```+:_```H
M````O;\```P```#FOP``'````/._```I````$,```!<````ZP```'P```%+`
M``!<````<L```!0```#/P```'P```.3````0````!,$```<````5P0``#@``
M`!W!```,````+,$```P````YP0``$P```$;!```*````6L$``!T```!EP0``
M&0```(/!```%````G<$``!$```"CP0``$0```+7!```D````Q\$``!4```#L
MP0``$@````+"```.````%<(``!D````DP@``"````#["```)````1\(```T`
M``!1P@``"@```%_"```'````:L(```\```!RP@``"P```(+"```:````CL(`
M``H```"IP@``!P```+3"```-````O,(```@```#*P@``'@```-/"```2````
M\L(``"P````%PP``&@```#+#```)````3<,```H```!7PP``%0```&+#```%
M````>,,``!0```!^PP``!````)/#```0````F,,```8```"IPP``!P```+##
M```>````N,,``"@```#7PP``"@````#$```<````"\0```L````HQ```&@``
M`#3$```4````3\0```0```!DQ```!0```&G$```&````;\0```8```!VQ```
M&P```'W$```T````F<0``#0```#.Q```(`````/%```I````),4``"````!.
MQ0``00```&_%```:````L<4``"@```#,Q0``*0```/7%``!0````'\8``"(`
M``!PQ@``"````)/&```%````G,8``!D```"BQ@``&0```+S&```J````UL8`
M`",````!QP``+@```"7'```T````5,<```@```")QP``%P```)+'```*````
MJL<```<```"UQP``(0```+W'```0````W\<```X```#PQP``"P```/_'```'
M````"\@``!,````3R```"````"?(```+````,,@```H````\R```%````$?(
M```R````7,@```4```"/R```!0```)7(```7````F\@```\```"SR```!```
M`,/(```*````R,@```D```#3R```"P```-W(```-````Z<@```P```#WR```
M#@````3)```%````$\D```0````9R0``#0```![)```R````+,D``$4```!?
MR0``%P```*7)```>````O<D``!0```#<R0``%````/')```'````!LH```X`
M```.R@``*@```!W*```&````2,H```P```!/R@``#0```%S*```1````:LH`
M``L```!\R@``-@```(C*```*````O\H``"(```#*R@``"P```.W*```/````
M^<H``#(````)RP``#@```#S+```%````2\L```X```!1RP``$P```&#+```'
M````=,L``!$```!\RP``$P```([+```'````HLL``!0```"JRP``&````+_+
M```'````V,L```4```#@RP``#````.;+```,````\\L``!(`````S```!```
M`!/,```*````&,P```L````CS```#````"_,```.````/,P```X```!+S```
M!0```%K,```%````8,P``"X```!FS```)@```)7,```C````O,P```,```#@
MS```&````.3,```E````_<P```T````CS0``"0```#'-```#````.\T```<`
M```_S0``"@```$?-```"````4LT``!(```!5S0``!````&C-```'````;<T`
M``P```!US0``4@```(+-```7````U<T```<```#MS0``!@```/7-```.````
M_,T```P````+S@``#0```!C.```5````)LX``!(````\S@``#P```$_.```4
M````7\X```H```!TS@``&P```'_.```0````F\X```L```"LS@``:0```+C.
M```:````(L\``!<````]SP``)P```%7/```:````?<\``!<```"8SP``&P``
M`+#/```9````S,\``!\```#FSP``$P````;0```(````&M````@````CT```
M"0```"S0```-````-M```!,```!$T````P```%C0``!&````7-```#\```"C
MT```-P```./0``!7````&]$```4```!ST0``'P```'G1```O````F=$```@`
M``#)T0``#0```-+1```M````X-$```0````.T@``3P```!/2```E````8](`
M`!P```")T@``"P```*;2```?````LM(``!T```#2T@``)0```/#2```@````
M%M,``"0````WTP``(````%S3```+````?=,```<```")TP``#0```)'3```,
M````G],```8```"LTP``.0```+/3```'````[=,```D```#UTP``$P```/_3
M```$````$]0``!`````8U```!````"G4```+````+M0```P````ZU```$@``
M`$?4```1````6M0```P```!LU```&@```'G4```-````E-0``!0```"BU```
M#@```+?4```;````QM0``!,```#BU```'````/;4```H````$]4```8````\
MU0``!P```$/5```3````2]4```0```!?U0``%P```&35```*````?-4```P`
M``"'U0``"0```)35```&````GM4```@```"EU0``"0```*[5```*````N-4`
M`!$```##U0``!@```-75```.````W-4```X```#KU0``"P```/K5```+````
M!M8```(````2U@``!P```!76```&````'=8```D````DU@``!P```"[6```:
M````-M8``#L```!1U@``*````(W6```T````MM8``!4```#KU@``!P````'7
M```(````"=<```<````2UP``!0```!K7```'````(-<```X````HUP``"0``
M`#?7```&````0=<```@```!(UP``"P```%'7```'````7=<```<```!EUP``
M'````&W7```'````BM<```@```"2UP``"````)O7```%````I-<``!````"J
MUP``$````+O7```'````S-<```4```#4UP``$````-K7```4````Z]<```L`
M````V```#0````S8```7````&M@```0````RV```"0```#?8```*````0=@`
M``<```!,V````@```%38```.````5]@``!\```!FV```(P```(;8```Q````
MJM@``"<```#<V```9`````39```4````:=D``%4```!^V0``.````-39``!*
M````#=H``%L```!8V@``*````+3:```X````W=H``"@````6VP``+````#_;
M```G````;-L``!L```"4VP``J0$``+#;```C````6MT``!<```!^W0``A0``
M`);=```P````'-X``"4```!-W@``6P```'/>``!)````S]X``!T````9WP``
M&````#??```K````4-\``"$```!\WP``'P```)[?```K````OM\``"$```#J
MWP``)P````S@```=````-.```!$```!2X```,P```&3@```E````F.```"<`
M``"^X```'P```.;@```P````!N$``&D````WX0``/0```*'A``!E````W^$`
M`$T```!%X@``+P```)/B```N````P^(``#````#RX@``5````"/C``!:````
M>.,``$@```#3XP``2@```!SD```R````9^0``"\```":Y```+````,KD```M
M````]^0``!<````EY0``)0```#WE```R````8^4``"D```"6Y0``/@```,#E
M```B````_^4```L````BY@``10```"[F```A````=.8``#````"6Y@``)0``
M`,?F```<````[>8``#$````*YP``!P```#SG```'````1.<```0```!,YP``
M#0```%'G```+````7^<```X```!KYP``!0```'KG```0````@.<```(```"1
MYP``60```)3G```%````[N<```@```#TYP```P```/WG```0`````>@```P`
M```2Z```#0```!_H```"````+>@``!0````PZ```$@```$7H```,````6.@`
M``,```!EZ```!````&GH```?````;N@``#4```".Z```+@```,3H```O````
M\^@``!<````CZ0``(````#OI```;````7.D``!@```!XZ0``)````)'I```?
M````MND``!H```#6Z0``(````/'I```:````$NH``#(````MZ@``&@```&#J
M```O````>^H``"L```"KZ@``'P```-?J```C````]^H``!\````;ZP``&@``
M`#OK```E````5NL``"8```!\ZP``)0```*/K```D````R>L``!@```#NZP``
M'0````?L```D````)>P``!@```!*[```(@```&/L```E````ANP``#P```"L
M[```'P```.GL```C````">T``!\````M[0``(````$WM```:````;NT``!@`
M``")[0``)@```*+M```>````R>T``"D```#H[0``'@```!+N```)````,>X`
M``P````[[@``%P```$CN```O````8.X``"0```"0[@``!P```+7N```/````
MO>X```4```#-[@``!P```-/N```=````V^X``!H```#Y[@``!P```!3O``#'
M````'.\```L```#D[P``%0```/#O```&````!O````D````-\```"P```!?P
M```-````(_```!<````Q\```!@```$GP```S````4/```!,```"$\```$P``
M`)CP```/````K/````<```"\\```,@```,3P```A````]_```!,````9\0``
M#````"WQ```1````.O$``#(```!,\0``%@```'_Q```(````EO$```D```"?
M\0``"@```*GQ```4````M/$``!T```#)\0``"````.?Q```?````\/$```@`
M```0\@``&@```!GR```G````-/(```8```!<\@``%0```&/R```(````>?(`
M``<```""\@``#P```(KR```.````FO(``!````"I\@``"0```+KR```)````
MQ/(``!,```#.\@``!P```.+R```9````ZO(```H````$\P``"@````_S```,
M````&O,``"H````G\P``!P```%+S```"````6O,``!````!=\P``&````&[S
M```+````A_,```,```"3\P``"````)?S```&````H/,```<```"G\P``#0``
M`*_S```+````O?,``!0```#)\P``%0```-[S```O````]/,``"`````D]```
M'````$7T```,````8O0``#$```!O]```!0```*'T```2````I_0``#\```"Z
M]```$@```/KT```*````#?4```8````8]0``!````!_U```$````)/4```H`
M```I]0``$P```#3U```%````2/4```8```!.]0``!@```%7U```$````7/4`
M``P```!A]0``"@```&[U```"````>?4```0```!\]0``!@```('U```#````
MB/4```P```",]0``10```)GU```:````W_4``#4```#Z]0``*````##V``!3
M````6?8``!D```"M]@``<@```,?V```@````.O<``#4```!;]P``(0```)'W
M``!%````L_<``#````#Y]P``*````"KX```I````4_@``"8```!]^```)0``
M`*3X```H````RO@``"@```#S^```(@```!SY```P````/_D``!(```!P^0``
M$P```(/Y```0````E_D``'D```"H^0``"0```"+Z``!S````+/H``'P```"@
M^@``*P```!W[```7````2?L``!8```!A^P``#P```'C[```7````B/L``!\`
M``"@^P``0````,#[```?`````?P``!P````A_```40```#[\```:````D/P`
M`!0```"K_```$@```,#\```0````T_P``!,```#D_```'0```/C\```/````
M%OT```\````F_0``!````#;]```)````._T```L```!%_0``!P```%']```%
M````6?T``!0```!?_0``!P```'3]```(````?/T```\```"%_0``"````)7]
M```,````GOT```\```"K_0``!@```+O]```4````POT```8```#7_0``#```
M`-[]```(````Z_T```0```#T_0``"@```/G]```$````!/X``!D````)_@``
M!P```"/^```"````*_X```D````N_@``!@```#C^```&````/_X```0```!&
M_@``#P```$O^```3````6_X```<```!O_@``!P```'?^```&````?_X```8`
M``"&_@``$````(W^```&````GOX```D```"E_@``(@```*_^```'````TOX`
M``<```#:_@``"P```.+^```%````[OX```(```#T_@``"P```/?^``!Q`0``
M`_\``!,```!U``$`&@```(D``0`0````I``!``T```"U``$`"P```,,``0`-
M````SP`!``8```#=``$`.````.0``0`V````'0$!`"0```!4`0$`.@```'D!
M`0`+````M`$!`#H```#``0$`'````/L!`0`-````&`(!`!0````F`@$`$P``
M`#L"`0`K````3P(!`!\```![`@$`$````)L"`0`6````K`(!`"````##`@$`
M#0```.0"`0##````\@(!`!L```"V`P$`#0```-(#`0`2````X`,!`!(```#S
M`P$`&@````8$`0`-````(00!``P````O!`$`&````#P$`0`&````500!``D`
M``!<!`$`#P```&8$`0`?````=@0!``X```"6!`$`&````*4$`0`8````O@0!
M``\```#7!`$`4@```.<$`0`I````.@4!`%T```!D!0$`;P```,(%`0"4````
M,@8!`(X```#'!@$`D@```%8'`0"1````Z0<!`%L```!["`$`(````-<(`0`9
M````^`@!`!D````2"0$`%P```"P)`0`-````1`D!`"0```!2"0$`#P```'<)
M`0`3````APD!``\```";"0$`.````*L)`0`\````Y`D!`!<````A"@$`%@``
M`#D*`0`3````4`H!`!````!D"@$`$P```'4*`0`E````B0H!`"@```"O"@$`
M&P```-@*`0`E````]`H!`"4````:"P$`-````$`+`0`M````=0L!`!P```"C
M"P$`)P```,`+`0`:````Z`L!`%0````##`$`,0```%@,`0`U````B@P!`!X`
M``#`#`$`-````-\,`0`(````%`T!`!@````=#0$`3````#8-`0`.````@PT!
M``X```"2#0$`"@```*$-`0`1````K`T!``D```"^#0$`!@```,@-`0`X````
MSPT!`!8````(#@$`%@```!\.`0`8````-@X!`!P```!/#@$`20```&P.`0`=
M````M@X!`!P```#4#@$`(0```/$.`0`G````$P\!`#$````[#P$`(````&T/
M`0`6````C@\!`#4```"E#P$`#````-L/`0`(````Z`\!`"````#Q#P$`+P``
M`!(0`0`>````0A`!`#(```!A$`$`"@```)00`0`9````GQ`!``H```"Y$`$`
M%0```,00`0`D````VA`!`!$```#_$`$`=````!$1`0`4````AA$!``8```";
M$0$`7````*(1`0`9````_Q$!`$0````9$@$`1````%X2`0!*````HQ(!`$X`
M``#N$@$`$0```#T3`0`*````3Q,!`#H```!:$P$`70```)43`0`V````\Q,!
M`#8````J%`$`-P```&$4`0`X````F10!`#@```#2%`$`=P````L5`0`Q````
M@Q4!`#P```"U%0$`.````/(5`0`^````*Q8!`"L```!J%@$`+P```)86`0!(
M````QA8!`$(````/%P$`)0```%(7`0`1````>!<!`!@```"*%P$`(P```*,7
M`0`G````QQ<!`!0```#O%P$`#0````08`0!%````$A@!`!<```!8&`$`#P``
M`'`8`0`(````@!@!``T```")&`$`!@```)<8`0`2````GA@!``T```"Q&`$`
M"0```+\8`0`*````R1@!`!H```#4&`$``P```.\8`0`#````\Q@!`!<```#W
M&`$`&@````\9`0`*````*AD!``@````U&0$`E@```#X9`0`Q````U1D!`$\`
M```'&@$`-@```%<:`0`,````CAH!`"<```";&@$`.````,,:`0`X````_!H!
M`%,````U&P$`,@```(D;`0!#````O!L!`,$`````'`$`40```,(<`0`*````
M%!T!``@````?'0$`(0```"@=`0`,````2AT!`!<```!7'0$`$P```&\=`0`7
M````@QT!`"````";'0$`#````+P=`0`4````R1T!``@```#>'0$`'0```.<=
M`0`8````!1X!`!L````>'@$`"P```#H>`0`M````1AX!`)````!T'@$`I```
M``4?`0`*````JA\!`!@```"U'P$``P```,X?`0`;````TA\!`!H```#N'P$`
M'P````D@`0`E````*2`!`#````!/(`$`2@```(`@`0`F````RR`!``8```#R
M(`$`(P```/D@`0`?````'2$!`!H````](0$`)0```%@A`0`G````?B$!`!T`
M``"F(0$`$P```,0A`0`*````V"$!``@```#C(0$`(0```.PA`0`;````#B(!
M``8````J(@$`'@```#$B`0`3````4"(!``T```!D(@$`&0```'(B`0`(````
MC"(!``H```"5(@$`%0```*`B`0`*````MB(!`!$```#!(@$`"````-,B`0`3
M````W"(!``8```#P(@$`"@```/<B`0`A`````B,!`!,````D(P$`&````#@C
M`0`@````42,!`"````!R(P$`.@```),C`0!-````SB,!`#8````<)`$`#```
M`%,D`0!?````8"0!``H```#`)`$`"````,LD`0`,````U"0!`#8```#A)`$`
M/0```!@E`0`Y````5B4!`$````"0)0$`/````-$E`0`X````#B8!`#0```!'
M)@$`,P```'PF`0`R````L"8!`#8```#C)@$`/P```!HG`0`^````6B<!`$$`
M``"9)P$`,P```-LG`0!"````#R@!`%X```!2*`$`1P```+$H`0!'````^2@!
M`%8```!!*0$`5P```)@I`0`G````\"D!`$P````8*@$`)````&4J`0`H`0``
MBBH!`#D```"S*P$`40```.TK`0!1````/RP!`%$```"1+`$`50```.,L`0`Z
M````.2T!`#P```!T+0$`1````+$M`0!)````]BT!`%0```!`+@$`(@$``)4N
M`0`Z````N"\!`#X```#S+P$`3````#(P`0"#````?S`!`!@````#,0$`"```
M`!PQ`0`/````)3$!``H````U,0$`&@```$`Q`0`:````6S$!`"````!V,0$`
M)````)<Q`0`B````O#$!`!$```#?,0$`$P```/$Q`0`9````!3(!`!4````?
M,@$`#P```#4R`0`\````13(!``H```"",@$`%P```(TR`0`1````I3(!`!<`
M``"W,@$`&P```,\R`0`"````ZS(!``P```#N,@$`'@```/LR`0`*````&C,!
M`!X````E,P$`%P```$0S`0`&````7#,!``\```!C,P$`#````',S`0`5````
M@#,!`!P```"6,P$`#0```+,S`0`4````P3,!`!@```#6,P$`&@```.\S`0`,
M````"C0!``8````7-`$`#P```!XT`0`/````+C0!`"<````^-`$`#P```&8T
M`0`/````=C0!`"L```"&-`$`(@```+(T`0!'````U30!``T````=-0$`)0``
M`"LU`0`8````434!`!8```!J-0$`$P```($U`0`/````E34!``H```"E-0$`
M#P```+`U`0!%````P#4!``H````&-@$`$0```!$V`0`P````(S8!`!,```!4
M-@$`'@```&@V`0`>````AS8!``@```"F-@$`.@```*\V`0`>````ZC8!`"@`
M```)-P$`&P```#(W`0`3````3C<!`!$```!B-P$`#P```'0W`0!`````A#<!
M`(0```#%-P$`#@```$HX`0`1````63@!`%(```!K.`$`'````+XX`0`,````
MVS@!`!T```#H.`$``P````8Y`0`,````"CD!`!4````7.0$`%0```"TY`0`5
M````0SD!`!D```!9.0$`)0```',Y`0`A````F3D!`"H```"[.0$`*````.8Y
M`0`.````#SH!``L````>.@$``@```"HZ`0`=````+3H!`"@```!+.@$`4@``
M`'0Z`0`O````QSH!``X```#W.@$`'0````8[`0`<````)#L!`"<```!!.P$`
M50```&D[`0!+````OSL!`!,````+/`$`(@```!\\`0"[````0CP!`#````#^
M/`$`!@```"\]`0`>````-CT!`"````!5/0$`,0```'8]`0`V````J#T!``H`
M``#?/0$`"@```.H]`0`<````]3T!`!0````2/@$`%````"<^`0`6````/#X!
M`!(```!3/@$`%````&8^`0`/````>SX!`!8```"+/@$`"````*(^`0`/````
MJSX!`"(```"[/@$`&0```-X^`0`7````^#X!``X````0/P$`&@```!\_`0`3
M````.C\!`#(```!./P$`.````($_`0`X````NC\!`#8```#S/P$`-P```"I`
M`0`_````8D`!`"T```"B0`$`"````-!``0`1````V4`!``8```#K0`$`"@``
M`/)``0`3````_4`!``\````100$`*````"%!`0`H````2D$!`!4```!S00$`
M$P```(E!`0`9````G4$!`!<```"W00$`.@```,]!`0`.````"D(!``\````9
M0@$`#0```"E"`0`1````-T(!``P```!)0@$`#P```%9"`0`@````9D(!``T`
M``"'0@$`!@```)5"`0!7````G$(!`!````#T0@$`/0````5#`0`*````0T,!
M``@```!.0P$`#P```%=#`0`,````9T,!``\```!T0P$`#@```(1#`0`.````
MDT,!``@```"B0P$`$````*M#`0`$````O$,!``4```#!0P$`#P```,=#`0`/
M````UT,!``\```#G0P$`+````/=#`0`+````)$0!`!X````P1`$`%@```$]$
M`0`6````9D0!``8```!]1`$`%0```(1$`0`7````FD0!`!(```"R1`$`%P``
M`,5$`0`L````W40!`!0````*10$`&0```!]%`0`;````.44!``0```!510$`
M20```%I%`0!)````I$4!`$D```#N10$`+````#A&`0`5````948!``\```![
M1@$`"@```(M&`0`5````ED8!``H```"L1@$`#````+=&`0`S````Q$8!`!$`
M``#X1@$`#P````I'`0`X````&D<!``@```!31P$`"````%Q'`0`(````94<!
M`!$```!N1P$`$P```(!'`0`<````E$<!``@```"Q1P$`6@```+I'`0!'````
M%4@!`$X```!=2`$`-@```*Q(`0!:````XT@!`#(````^20$`7````'%)`0!"
M````SDD!`$L````12@$`+P```%U*`0`3````C4H!`"````"A2@$`"0```,)*
M`0!0````S$H!`#X````=2P$`+@```%Q+`0`\````BTL!``H```#(2P$`#```
M`--+`0`\````X$L!`#@````=3`$`30```%9,`0`+````I$P!`"H```"P3`$`
M2P```-M,`0`H````)TT!`!4```!030$`&@```&9-`0`:````@4T!`!(```"<
M30$`>````*]-`0"8````*$X!`.````#!3@$`'0```*)/`0`.````P$\!``\`
M``#/3P$`&@```-]/`0`;````^D\!`!4````64`$`#````"Q0`0`=````.5`!
M`"4```!74`$`*P```'U0`0`H````J5`!`#4```#24`$`-0````A1`0#=````
M/E$!`!L````<4@$`%0```#A2`0`.````3E(!``X```!=4@$`,````&Q2`0`;
M````G5(!`!$```"Y4@$`#P```,M2`0`6````VU(!`"@```#R4@$`1````!M3
M`0!$````8%,!`$````"E4P$`0````.93`0!!````)U0!`$$```!I5`$`(```
M`*M4`0!F````S%0!`!8````S50$`%@```$I5`0`6````854!`!8```!X50$`
M$0```(]5`0`>````H54!`!X```#`50$`%0```-]5`0`4````]54!`%$````*
M5@$`'````%Q6`0`<````>58!`$H```"65@$`&0```.%6`0`/````^U8!`!H`
M```+5P$`$@```"97`0`L````.5<!`!H```!F5P$`*P```(%7`0`@````K5<!
M`"8```#.5P$`(````/57`0!`````%E@!`#H```!76`$`'@```))8`0`;````
ML5@!`",```#-6`$`/0```/%8`0`D````+UD!`"4```!460$`#````'I9`0`?
M````AUD!``@```"G60$`%0```+!9`0`-````QED!``P```#460$`%@```.%9
M`0`4````^%D!``H````-6@$`"````!A:`0`8````(5H!`!@````Z6@$`&@``
M`%-:`0`6````;EH!`!L```"%6@$`(P```*%:`0`]````Q5H!`!,````#6P$`
M&@```!=;`0`/````,EL!``\```!"6P$`%0```%);`0!+````:%L!`!````"T
M6P$`#P```,5;`0`.````U5L!``@```#D6P$`$0```.U;`0`C````_UL!``T`
M```C7`$`'@```#%<`0`7````4%P!`"````!H7`$`'0```(E<`0`(````IUP!
M``X```"P7`$`!````+]<`0`/````Q%P!`!$```#47`$`%@```.9<`0`5````
M_5P!`"8````370$`)@```#I=`0`C````85T!`"@```"%70$`#0```*Y=`0`;
M````O%T!``H```#870$`&0```.-=`0"`````_5T!`!$```!^7@$`%0```)!>
M`0!"````IEX!`!X```#I7@$`)`````A?`0`5````+5\!`!4```!#7P$`%P``
M`%E?`0`-````<5\!`!,```!_7P$`$P```)-?`0`7````IU\!`!X```"_7P$`
M-````-Y?`0`,````$V`!`!$````@8`$`$P```#)@`0`8````1F`!``P```!?
M8`$`"````&Q@`0`(````=6`!``@```!^8`$`$P```(=@`0!T````FV`!`!\`
M```080$`#P```#!A`0`&````0&$!``H```!'80$`'@```%)A`0`<````<6$!
M`"````".80$``@```*]A`0`1````LF$!`$````#$80$``P````5B`0`(````
M"6(!`!T````28@$`%0```#!B`0`8````1F(!`(,```!?8@$`"0```.-B`0`,
M````[6(!``@```#Z8@$`"@````-C`0!.````#F,!`%P```!=8P$`'@```+IC
M`0`B````V6,!`#0```#\8P$`,P```#%D`0`Q````960!`!,```"79`$`!```
M`*MD`0`*````L&0!``H```"[9`$`%@```,9D`0`7````W60!``H```#U9`$`
MA@````!E`0`:````AV4!`!$```"B90$`%@```+1E`0`K````RV4!`'$```#W
M90$`!@```&EF`0`3````<&8!``8```"$9@$`"P```(MF`0`O````EV8!`"T`
M``#'9@$`"````/5F`0`,````_F8!`*\````+9P$`(@```+MG`0`A````WF<!
M``P`````:`$`$0````UH`0`3````'V@!`"`````S:`$`#@```%1H`0`0````
M8V@!``P```!T:`$`$P```(%H`0`1````E6@!`!,```"G:`$`%P```+MH`0`<
M````TV@!`!H```#P:`$`&@````MI`0`:````)FD!`!P```!!:0$`&@```%YI
M`0`L````>6D!`!4```"F:0$`#0```+QI`0`<````RFD!``\```#G:0$`'@``
M`/=I`0`A````%FH!``8````X:@$`%0```#]J`0`:````56H!`!8```!P:@$`
M%````(=J`0`7````G&H!`!X```"T:@$`&@```--J`0`(````[FH!``@```#W
M:@$`$0````!K`0`+````$FL!`"T````>:P$`%@```$QK`0`M````8VL!`#(`
M``"1:P$`'@```,1K`0`*````XVL!`!H```#N:P$`"`````EL`0`<````$FP!
M``0````O;`$`!````#1L`0!I````.6P!`$\```"C;`$`)0```/-L`0!&````
M&6T!`%D```!@;0$`$P```+IM`0!:````SFT!`$(````I;@$`1P```&QN`0!'
M````M&X!`$P```#\;@$`*0```$EO`0`C````<V\!`"X```"7;P$`)@```,9O
M`0`E````[6\!`"4````3<`$`'P```#EP`0`M````67`!`"0```"'<`$`3@``
M`*QP`0!.````^W`!`%(```!*<0$`4@```)UQ`0!0````\'$!`$T```!!<@$`
M0@```(]R`0`3````TG(!`#,```#F<@$`#P```!IS`0`Y````*G,!`$0```!D
M<P$`10```*ES`0`3````[W,!`'(````#=`$`>0```'9T`0`1````\'0!`#0`
M```"=0$`%````#=U`0`8````3'4!``L```!E=0$`"P```'%U`0`6````?74!
M`!X```"4=0$`$P```+-U`0`9````QW4!`!(```#A=0$`/````/1U`0`,````
M,78!``8````^=@$`'````$5V`0`7````8G8!`!4```!Z=@$`4@```)!V`0`*
M````XW8!``8```#N=@$`'````/5V`0`,````$G<!``H````?=P$`'````"IW
M`0`/````1W<!`%$```!7=P$`&````*EW`0`M````PG<!`&,```#P=P$`(```
M`%1X`0!"````=7@!`)X```"X>`$`*P```%=Y`0`]````@WD!`!,```#!>0$`
M%@```-5Y`0`6````['D!`!@````#>@$`#````!QZ`0`7````*7H!`!(```!!
M>@$`,0```%1Z`0`@````AGH!``@```"G>@$`%P```+!Z`0`:````R'H!`#@`
M``#C>@$`(@```!Q[`0`F````/WL!`!@```!F>P$`-@```'][`0`(````MGL!
M``X```"_>P$`)````,Y[`0`9````\WL!`!4````-?`$`%P```"-\`0`(````
M.WP!`"L```!$?`$`#@```'!\`0`7````?WP!`!,```"7?`$`#@```*M\`0`X
M````NGP!`"(```#S?`$`0@```!9]`0`>````67T!``\```!X?0$`$````(A]
M`0`S````F7T!``X```#-?0$`(P```-Q]`0`(`````'X!`"(````)?@$`"```
M`"Q^`0`(````-7X!`"8````^?@$`2P```&5^`0`(````L7X!`!P```"Z?@$`
M#````-=^`0`;````Y'X!`!<`````?P$`&0```!A_`0`(````,G\!``H````[
M?P$`#@```$9_`0`U````57\!`%T```"+?P$`:P```.E_`0`X````58`!`$$`
M``".@`$`-0```-"``0!T````!H$!`#4```![@0$`0P```+&!`0!.````]8$!
M`(<```!$@@$`.P```,R"`0`.````"(,!``@````7@P$`*P```""#`0`I````
M3(,!`!L```!V@P$`+````)*#`0`Y````OX,!`#\```#Y@P$`"````#F$`0`?
M````0H0!``H```!BA`$`$P```&V$`0`]````@80!`!P```"_A`$`#0```-R$
M`0`1````ZH0!``@```#\A`$`$P````6%`0`1````&84!`!$````KA0$`$P``
M`#V%`0`D````484!`$T```!VA0$`#P```,2%`0`*````U(4!`"0```#?A0$`
M%P````2&`0`*````'(8!`!L````GA@$`&P```$.&`0`8````7X8!`!0```!X
MA@$`%@```(V&`0`5````I(8!``@```"ZA@$`#````,.&`0`<````T(8!`$H`
M``#MA@$`=@```#B'`0`M````KX<!`#H```#=AP$`(P```!B(`0`C````/(@!
M``X```!@B`$`(@```&^(`0`#````DH@!``8```"6B`$`#P```)V(`0`/````
MK8@!`!@```"]B`$`#0```-:(`0!1````Y(@!``8````VB0$`(````#V)`0`1
M````7HD!`!4```!PB0$`5P```(:)`0`@````WHD!`!````#_B0$`'@```!"*
M`0`S````+XH!``H```!CB@$`(P```&Z*`0`N````DHH!`!````#!B@$`)0``
M`-**`0`K````^(H!``P````DBP$`"````#&+`0`3````.HL!`!4```!.BP$`
M&````&2+`0`&````?8L!`!@```"$BP$`$@```)V+`0`6````L(L!`!4```#'
MBP$`%0```-V+`0`+````\XL!``H```#_BP$`4@````J,`0!+````78P!`$D`
M``"IC`$`"````/.,`0`K````_(P!`#D````HC0$`#@```&*-`0`.````<8T!
M``,```"`C0$`$````(2-`0`.````E8T!``@```"DC0$`(````*V-`0`/````
MSHT!`!(```#>C0$`&````/&-`0"!````"HX!`!\```",C@$`!@```*R.`0`/
M````LXX!`!````##C@$`(````-2.`0`<````]8X!`#<````2CP$`(P```$J/
M`0`>````;H\!`#D```"-CP$`$P```,>/`0`T````VX\!`!8````0D`$`'@``
M`">0`0#P````1I`!`"4````WD0$`(0```%V1`0!'````?Y$!`"4```#'D0$`
M'P```.V1`0`E````#9(!`"$````SD@$`+0```%62`0`5````@Y(!``X```"9
MD@$`"@```*B2`0`.````LY(!`!<```#"D@$`)````-J2`0`*````_Y(!`)(`
M```*DP$`D0```)V3`0!2````+Y0!`(````""E`$`&@````.5`0!3````'I4!
M`#X```!RE0$`"````+&5`0`5````NI4!`&0```#0E0$`"@```#66`0!K````
M0)8!`%<```"LE@$`.P````27`0`B````0)<!`%0```!CEP$`0P```+B7`0`]
M````_)<!`"\````ZF`$`-@```&J8`0`Q````H9@!`!4```#3F`$`"````.F8
M`0`;````\I@!`!L````.F0$`#0```"J9`0`Y````.)D!``T```!RF0$`"@``
M`("9`0`;````BYD!``P```"GF0$`(````+29`0`&````U9D!``@```#<F0$`
M"````.69`0`;````[ID!`!L````*F@$`#P```"::`0`=````-IH!`!H```!4
MF@$`)0```&^:`0`5````E9H!`!L```"KF@$`&````,>:`0`M````X)H!`#8`
M```.FP$`%0```$6;`0`*````6YL!`"L```!FFP$`#@```)*;`0`C````H9L!
M`!,```#%FP$`$P```-F;`0`1````[9L!``H```#_FP$`$@````J<`0`*````
M'9P!``\````HG`$`&@```#B<`0`-````4YP!`!P```!AG`$`%0```'Z<`0`3
M````E)P!``X```"HG`$`#````+><`0`*````Q)P!``H```#/G`$`#@```-J<
M`0`0````Z9P!`"8```#ZG`$`D````"&=`0!!````LIT!`%$```#TG0$`*```
M`$:>`0`*````;YX!`!,```!ZG@$`$P```(Z>`0`,````HIX!``@```"OG@$`
M$0```+B>`0`*````RIX!``@```#5G@$`"@```-Z>`0`0````Z9X!`!````#Z
MG@$`%P````N?`0`L````(Y\!``@```!0GP$`"````%F?`0`0````8I\!``@`
M``!SGP$`%P```'R?`0`7````E)\!``<```"LGP$`"@```+2?`0`3````OY\!
M`!P```#3GP$`$P```/"?`0`5````!*`!`!D````:H`$`!@```#2@`0`-````
M.Z`!``\```!)H`$`$0```%F@`0`.````:Z`!``X```!ZH`$`20```(F@`0`G
M````TZ`!`#T```#[H`$`-@```#FA`0"?````<*$!`!H````0H@$`90```"NB
M`0!4````D:(!`&\```#FH@$`80```%:C`0`P````N*,!`&0```#IHP$`.@``
M`$ZD`0`\````B:0!`$D```#&I`$`-````!"E`0`.`0``1:4!`"0```!4I@$`
M%````'FF`0"\````CJ8!`&T```!+IP$`.````+FG`0!\````\J<!`+,```!O
MJ`$`(````".I`0`8````1*D!`#,```!=J0$`)@```)&I`0`F````N*D!`$4`
M``#?J0$`+````"6J`0`P````4JH!`"8```"#J@$`&````*JJ`0!-````PZH!
M`$`````1JP$`,0```%*K`0`R````A*L!`%(```"WJP$`R@````JL`0!2````
MU:P!`(L````HK0$`@@```+2M`0!(````-ZX!`%$```"`K@$`50```-*N`0"(
M````**\!`)0```"QKP$`=@```$:P`0!X````O;`!`%0````VL0$`1@```(NQ
M`0!(````TK$!`$H````;L@$`*````&:R`0!%````C[(!`$P```#5L@$`3@``
M`"*S`0"(````<;,!`#@```#ZLP$`&0```#.T`0"/````3;0!`"\```#=M`$`
M40````VU`0`_````7[4!`"H```"?M0$`60```,JU`0`&````)+8!``P````K
MM@$`"````#BV`0`5````0;8!`!$```!7M@$`%P```&FV`0`*````@;8!`",`
M``",M@$`!````+"V`0"/````M;8!``H```!%MP$`"````%"W`0`(````6;<!
M`"````!BMP$`$0```(.W`0`=````E;<!``T```"SMP$`%````,&W`0`K````
MUK<!`!`````"N`$``P```!.X`0`$````%[@!`#(````<N`$`:@```$^X`0!0
M````NK@!`%8````+N0$`*P```&*Y`0`T````CKD!`"@```##N0$`1@```.RY
M`0`\````,[H!`#<```!PN@$`.P```*BZ`0!`````Y+H!`"X````ENP$`.@``
M`%2[`0`N````C[L!`#@```"^NP$`4````/>[`0`S````2+P!`#@```!\O`$`
M/````+6\`0`W````\KP!`$P````JO0$`/````'>]`0!&````M+T!`#4```#[
MO0$`.P```#&^`0`\````;;X!`$D```"JO@$`-P```/2^`0`Z````++\!`#(`
M``!GOP$`;````)J_`0`\````!\`!`$$```!$P`$`10```(;``0!&````S,`!
M`$`````3P0$`,@```%3!`0`]````A\$!`#<```#%P0$`,@```/W!`0`[````
M,,(!`!,```!LP@$`(0```(#"`0`K````HL(!`$8```#.P@$`-````!7#`0`/
M````2L,!``\```!:PP$`#````&K#`0`9````=\,!`#@```"1PP$`(P```,K#
M`0`+````[L,!`),!``#ZPP$`&@```([%`0`@````J<4!`!(```#*Q0$`%0``
M`-W%`0`=````\\4!`!P````1Q@$`-````"[&`0`3````8\8!`',```!WQ@$`
M'````.O&`0`@````",<!`!P````IQP$`%P```$;'`0!D````7L<!`$````##
MQP$`&0````3(`0`>````'L@!`!@````]R`$`3````%;(`0`C````H\@!`!$`
M``#'R`$`$@```-G(`0`3````[,@!`!P`````R0$`(````!W)`0`.````/LD!
M`$0```!-R0$`#````)+)`0`H````G\D!`$$```#(R0$`#`````K*`0`G````
M%\H!``P````_R@$`"````$S*`0`3````5<H!`!,```!IR@$`(@```'W*`0`+
M````H,H!`!$```"LR@$`$P```+[*`0`+````TLH!`"8```#>R@$`&@````7+
M`0`9````(,L!`!L````ZRP$`3P```%;+`0`,````ILL!`!````"SRP$`&```
M`,3+`0`]````W<L!``L````;S`$`!````"?,`0`-````+,P!``H````ZS`$`
M$0```$7,`0`9````5\P!`!8```!QS`$`%````(C,`0`5````G<P!`%H```"S
MS`$`(P````[-`0`H````,LT!``\```!;S0$`;````&O-`0`&````V,T!`!P`
M``#?S0$`70```/S-`0`3````6LX!`!$```!NS@$`"0```(#.`0`$````BLX!
M``<```"/S@$`&0```)?.`0`O````L<X!``<```#AS@$`"````.G.`0`&````
M\LX!``8```#YS@$`%@````#/`0`6````%\\!``4````NSP$`!````#3/`0`,
M````.<\!``8```!&SP$`%0```$W/`0!R````8\\!`"<```#6SP$`8@```/[/
M`0!3````8=`!`(P```"UT`$`&````$+1`0"Q````6]$!`$D````-T@$`>@``
M`%?2`0!3````TM(!`$H````FTP$`:````''3`0!2````VM,!`%,````MU`$`
M40```('4`0!7````T]0!`%X````KU0$`40```(K5`0`_````W-4!`%8````<
MU@$`)````'/6`0`@````F-8!`!4```"YU@$`O0```,_6`0`-````C=<!`-H`
M``";UP$`N0```';8`0!,````,-D!`#<```!]V0$`(````+79`0`7````UMD!
M`"@```#NV0$`-0```!?:`0!<````3=H!`#L```"JV@$`-````.;:`0"A````
M&]L!`"X```"]VP$`+0```.S;`0`Q````&MP!`!8```!,W`$`*0```&/<`0`R
M````C=P!`!,```#`W`$`#@```-3<`0`#````X]P!`!$```#GW`$`#0```/G<
M`0`4````!]T!``P````<W0$`'````"G=`0`(````1MT!``@```!/W0$`&```
M`%C=`0`1````<=T!``P```"#W0$`%````)#=`0`:````I=T!`!H```#`W0$`
M#@```-O=`0`8````ZMT!``H````#W@$`"`````[>`0`A````%]X!``P````Y
MW@$`%P```$;>`0`&````7MX!``(```!EW@$`"@```&C>`0`(````<]X!``D`
M``!\W@$`!@```(;>`0`<````C=X!`"P```"JW@$`!P```-?>`0`(````W]X!
M``X```#HW@$`"````/?>`0`9`````-\!``\````:WP$`%0```"K?`0!#````
M0-\!`!$```"$WP$`"P```);?`0`7````HM\!``4```"ZWP$``@```,#?`0`+
M````P]\!``$````N````/@```-P$``#"`````````-`$````````[0(`````
M`````````````"L!````````104``(P%``#C`@``9`4```T```"P````2`$`
M`````````````````)D!```/!```H`0```````#=!```%P4```````"9`@``
M>0```.0!````````D0,```````")!````````*($``##`P``\@0````````U
M`@``Z@0``-,"`````````````&8!```:`P``$`,```````#X!```6P,```<!
M``"S`0``TP,```````````````````````!%`P``%`(``)T%``!P!```?P,`
M`'L#````````A0(`````````````#@```)@"````````B@,```````!^`0``
M_00``"\"````````&@(``'P$``"?!0``D@0``*D!``"[`P``LP```+,#``#N
M`0```````'T#````````-@```)@$``"M`0``Z@(``#H#`````````````*8%
M``!7`@``)P4``/L```",`P``D@````````"P!```YP(``-@"````````G`(`
M`-\`````````>`4``%<#```X`P```````#@"```*````?`,``!4%`````P``
M]P,```````!G`0``/`$``$4$```]!0``GP$``'X`````````'P```'8```"_
M`0`````````````9`P```````"\#``#0`````````-8#``"(`0``-0,```,!
M``#X`0``HP$```````#U!```\0(``*X$``#`````&P```$@#````````P`,`
M`)H"``#\!````````*X```!A````:0$```````#2`P``5P4``!\%````````
M1`(``.P``````````````"0$``````````````````#*`@``6`0``!4`````
M````,P```+\"``"3````5`,``.L#``"9!0``,00``'@"``!^`@``70```+@$
M``"@```````````````'!````````/0"````````\P,``%\"``!8`P``````
M``P!``!;`0``<@,```D!````````A@(``````````````````/P"``"+`P``
M`````-H$``!+`0``V@$```````!V`0``KP0``#8!```H`P```````#D#``"N
M`0``YP$``*4"``!!`0``\P$``!0%``!I!0``>@$``#$`````````#@4``,T$
M``!Y`0``B````+<```""`@``&`0```````"1!```90,`````````````````
M`"<```#>!```9@4``($$```7`P``P`$``/\!````````'P,``"0````R`0``
M``````````">`0``"P```/0#````````M`,`````````````<@4`````````
M````@0(``"`!`````````P```.\!``"^`0``AP```.D$``#F````'`(`````
M``"7!0``R`0``*8!``!/`P```````%4$```B`P``UP```"T%``"T````````
M`+@!``#B`P``OP,``!4!```V`P```0,``/$!```7````IP0``,,!``!9````
M*@`````````-!0``)@0``!8%````````X`0``"L"````````M0(``(8%``!9
M`P``304``)`%``````````````````!P`0``!@(``%4"````````B0,`````
M````````O`0``!$%``"0`0``20$``/@"```I``````````\#``!R`@``````
M`.<$``")````V`$``/$```#%!```CP$``&<"``"=!````````#\%``"-````
M<P$`````````````A00``&L#``"E`P```````#D```!O`0``QP0``-8`````
M````=``````````^!0``6`$`````````````(P4``"@%```9!0``?`$```P"
M```D`@``G0```'@`````````H0```.D```#A`@``>@0``"($``"B`0``B@$`
M``````""````CP4``+X````)`@``A@0`````````````"@0``-P"``#F`0``
MHP```'L$``!E!0``/````"0!```R!0``'@,``'```````````````"0#``"(
M`@``4@4``!0#```S!```N`,``%,%```<!0````````````!D`P``5@4``$L$
M``"R`0``$0````````"/!```E@0``$\"``````````````````!M!```DP(`
M`/L$``#[`0``G@(``'H%``#T`````````)D```#9`P````````````#F`P``
MB@0```````#B`@``W@$``$X#``"-`0````````````"K!````````%L%````
M````KP$`````````````#P(``%<$``#&````_0```*$%``"E!0```````-<#
M``"#````;@(``#H!``#O`P``204``%X#``"2!0``BP4``+,$```)`P``$P(`
M`````````````````,@"``#1````/0$``'D#``#9`0``E`4`````````````
MO0$`````````````=0,``(0```#A`0``E@```$X```"0`@``;P,``)<```"G
M`@``/0,```````#K````9P`````````L`0``K0,```````""!```50``````
M``"W`P``2`0``($%```:`````````&@!``"&`P``A`4`````````````J@$`
M`.0"``#V`````````````````````````(@#```6`@``I`$``.X#``#)`@``
M\@(```$$``!5`0``3@$```````#*!```J`````````"_!```S@(``)8#``"T
M!```8@,``$H$```=!0```````!\$``#E`P``/@(```````!Q!```60(`````
M``!@!```WP(``#@%``"D!0````````<"``!2`0``4`0````````3````Q@,`
M`+`"``#L`@```````!0!```W````W````*,%````````ZP$```X#```K!```
M````````````````_@$``%("``!T`@``NP$```````!U`@```````%,!``!=
M!0``C@$``*H```!_````R@$``!D$``"1`0``M0```(0"``!<`P``````````
M``!+`P``R00``.,!```-`@``W@(```X$````````V00```8$``!H`@``^0$`
M`.$$````````#``````````R`@``[0$``%P"``#0`P``J`(``%\%``#K`@``
MQ`(``!T!```8`0``TP$``/(#``!.!0``D@$```````"C!```&P0``+@```!B
M`0``"`4```H"`````@``$0$``````````````````.@#```,!```1@,``.H`
M```2!0``(`(``"$%``"^`@``:@```"T$````````*@0``-($``"8!0``````
M`"P```!:`0``H0$``*8#``#@`0``KP(``)L%```[`@``*P4``$H%```G!```
M'`$``)4#````````N@```*\#````````D@(``#<%```(!``````````````(
M`0```````!X```!^`P``F````$4```#-`0``\P```/H$``"/````B0(``)H#
M````````20,``)@!``"+!```_`$```\````W`0``/@,``,$"```[``````4`
M`+$!``#"`0``)04``'0$``"\`P``3`(``!,%``"-`@``40(`````````````
M_`,```(#``#;`@``N@0```````"7`0``:P4```````!4`@````````<#``!1
M!```>04```````"9`P``1P```%T"````````,04``,D``````````````$X$
M``"?`@``/`4``(<$```)!0``PP````````!/````@P,``,4#```=!```Z0(`
M`%H#````````?````.,$```_````+@(````````Q`P``(0```(,$``"6`@``
MM0$````````7`@```````#L!````````8P(```T#``!S`P``G0,``"8```"Z
M`0``*0(``.H!```8`@```````*L!````````K`(``,<#``#<`P``H@,`````
M``!]`0``W@`````````5`@``M00``$$%`````````````%P!``!H!0``'P(`
M``@"```T`P``^@(```````"!`P``S0(``$<$````````V@(``)$`````````
MS`,``/D#``!A`0```````!H!````````E`0```````#E````$P,``!8!``!"
M`P``60$``*D```"7!```%@,``#T"``!R!````````*P#``!F````%P$``%8#
M``!H`P```````!X%``"S`@``70,``"("````````3`,``"T```"0````Q`,`
M`.,#``#1!```=`$``'0#``!N`````````"(```"R````Y@0``)L#````````
M5@(``,T#``#L`0``#00``'X%``#4`````````(<!``";`0``30```!<$``"/
M`P``6`(````````A!```8P```-4#``"``````````/X#``!S!0``)0$``!4#
M``!/`0``4@0```````#A````]`0``#@$``````````````````#_`P``-0$`
M`&`"````````Q@(``.@$``!J!``````````````P`0``D0(``(P````@````
M$@$``(T#````````1P,``/$$```]!```G0$``"X%`````````````/\```!S
M!```Z````#$!``""!0``8`,``&L```!]!0```````-H#```E`P``8@0``"X#
M```2!```>P4``(,"``"%`0``W0$``)`#````````\P0```````#M````DP$`
M`#0!``"M``````````````!G!```2`````4%`````````````(@$````````
M8P,```````````````````````!>!0``6`4`````````````A`$```````#5
M`@```````-<"``#,````IP,``,X#````````^@,``%H"````````.@4`````
M``"<!```N0(``-8"``!0!0```````!,$``!"`````P,````````1!```\`,`
M`-X#```%`@```````*P!``#8````[P0``&8$``".!````````,\```!6````
M*`0``*T"```,`P``.````-("```0`0``ZP0```````"Y`0````````````"F
M````J@0````````"!```O@0``!\!``#Y````T@```#0%``#+````[`,``+8!
M````````H`4```H%``"J`@```````&T#````````K00```````##`@``40``
M`&(`````````Q@0```L%``!D````?@0``,P$````````E@$```8!``#B!```
MX0,``,L"``!]!```4P(``*4!````````D04``"$!``!O````<`(``/D"```$
M````H0(``+<$```%`0```````-$!```5!```4````!@%``"G`0```````#L$
M``"9!````````'H"````````7@(``*\```!!`P```````"8#```"`@``````
M`*0#```>`@```````.P$``!L`0```````````````````````)`$``!%`@``
MZ`$``%P%`````````````)<"``"+`0``F@4``(\"````````RP,``&0"````
M````L@(`````````````E`(``%L$````````L0(````!``#P`@``H@``````
M``#6`0``<P(```````!$!0``;P4``&T```!+!0``6@```+P!``!G`P``_@0`
M`(`!````````7````*P$``#&`0``$@````4$``"Z`P``?0(``",````[`P``
M`````(`"``")`0```````-@#``#``@``_P0`````````````;0$``/T!```)
M````(`,```````````````````(````:!0``3````$0$``!O`@```````%0$
M``"5!0```````$@%```W!```3`$``$(%``!N!0``O@,``&$#``"#!0``````
M```````:!```U0```.4"``"\````#P$``"L````6`````04``%,````S`0``
MU`,``&H#```P````RP0``.D!``"*````9@,``"0%`````````````&H%``#4
M`@``1@4``%,$``!X`P``[0,``)4`````````$0,``'\"```Y!```"P(``"<"
M``!_!````````/8#```[!0```````,\!```U!```8P0`````````````8P4`
M`(4```"[!```#0$``'4%``#H`@``700``%P$````````7P````````!W````
M8`$``"X$``!E!```Z0,``"@!````````I`(``/@#`````````````/D$``!W
M`0``90```-D"`````````````,D#`````````````+L`````````<04``'$#
M``#"`@```````&P#``#6!```W`$````````M`P``(@$```,$``#$`0``<0``
M``````!:!0``30$``)8%``">!```;@0``-(!``!;````(P0`````````````
M'0```+D#``#.!```R@```-\!``#5`0````````````"[`@````````````"!
M`````````-0$``"3`P``=0```-0!``"<````<`4``,@```"I`@``+`(``(8`
M``#@````C`0``,4```#?!```\````)H```"N`P``[@0``,X!``"D!```+`4`
M`"H"```&````5`$```0#``#N`@``?`4``&H"``#%`@```````%H$````````
M)@4``/@`````````UP$``+$```!X!```9P4``$`#``#!`P``/P0``","```A
M`P```````&T%``#D````"P,``(X```"@`@``)@$``%0%```W`P``]`$``$D`
M````````90(``'D$````````-`0````````L`P```````'H#```U!0``````
M`%\!``!L````Y@(```````")!0``1@(```````"&`0``,P4```````"I`P``
M+P$``"D%``",`@``Q0$``,\"```^`0``S`(``(X"``!U`0``X`,````````*
M`P``$`0```````"A!`````````````!)!````````$@"```8````4`(``.\`
M``"F`@````````````!*`@``$`4````````"!0``/`(```````!V`@``1P(`
M````````````````````````````0@$``#`$``"]`@``;@,``#(````(````
M`````$T#```+`0``3P0``.(`````````<0$``"$"```F`@``]0```/P```!$
M````L@0``%(`````````Q````,<"```(`P``M0,``*@!``![`@``````````
M`````````````)\````1`@``:`0``"P$```O````,@0``$`%``#B`0``!`(`
M```````2`@``HP,``'T````$!```(P$`````````````!P4``!D"````````
MO0```/8$```@!0```````%$%``!E`0```````-D```"D````P`0``+0!``">
M!0``JP,``-H```!Y`@```````)L$``"(!0``000```````"J`P``:00`````
M``"N`@```````-$"``"-!```FP```+8$``"*`@``````````````````!`4`
M`&P$````````0@(`````````````2P(``/L#``"+`@```P(``/<!``"V`P``
M4@,``)0#``">````4`,``'P"``"`!``````````````;`P````````X"````
M`````````(0#``#'````TP``````````````,P(`````````````*@4``(H%
M``!W`@``/`0````````*`0``$`(```````#U`P``>`$``%X!``!M`@``+P0`
M`!(#`````````````)<#``#M!````````&0$``#!!```>P```/`$```&!0``
M`````"(%```<!```1@0`````````````I@0``,$!````````'@$``%X$``"]
M!```,0(``%X```!B`@``V`0``*`#``"E`````````$$"````````3`0``%<!
M``#]`@``8`4``/`!````````DP0`````````````0P,``&\$````````````
M`.\"``#;`0```````-L```#S`@``-````+D```"%`P``7P0``,L!```_`@``
M:0(``$T"```T`@``\@```)P#``!;`@``VP,``+H"````!```O0,``($!````
M````/P,``'\%``!0`0``+P4``$T$``#3!```G@,```0!````````S0```#H`
M``"?`P``:P(``"D!``"Y!```(`0``$`$````````L00```````#W````3`4`
M``````!W`P``O`(``#X$``!P`P``.`$```(!````````,`4``!P```!*````
M`````"4"``!#`0``+@$``"L#``!#`@``GP0``*<%``"5`0``UP0```````#;
M!```P0`````````````````````````C`P```````$,%``!"!```504`````
M``#]`P``&`,````````3`0```````````````````````"@`````````Y`,`
M``````"5!```=P0``((#```G`0``'0(``(L````P`P``AP4`````````````
M`````&D#``"-!0``.04``+@"````````MP$`````````````M@````````!A
M!0``PP0``&P"``!L!0```````&L$```>!````````````````````````$``
M``"2`P```````.H#````````:P$```````#E`0``%@0``#8"````````600`
M``4#``"5`@``,P,``#T``````````````#`"````````&P$```L$``#C````
MJ`0```````!?`P``20(``)@#```Y`0``&0```)P!``!*`0``!P```'(!``#^
M````3@(```$!```R`P``-0```$\%```H`@``*@$``(X%```=`P``````````
M```Y`@```````),%``!3`P``<0(```````!$`P``5`````````!D`0``````
M`/<"``!F`@``C`$``,<!``!W!0``5P``````````````!0``````````````
M1@$``)0!``!J`0``````````````````5@$``%$!``"``P```````'8#````
M`````````)H$``"K````%`0```````"E!````````*P```!9!0``2@,``'0%
M````````:````````````````````(<#``#U`0``J`,``)H!``!C`0``.@0`
M`!````!R````1@````````#1`P``R`,```X!``!N`0``/`,``+\```#=````
M=00```````"$!```]@$``#<"``"4````+0$``'H`````````IP```*D$````
M````^P(```````"C`@``#P4``'8$```M`@``&P4``(`%``!$`0``H0,``.0$
M```_`0``L@,``-`!``"V`@``R`$```````"%!0``.@(``%$#````````&0$`
M`$L```!B!0``:0``````````````X`(``%@```!5`P```````-\#``#_`@``
M-@0``+`#```I!```1P$``/X"``!_`0``!@,``.X```#5!```W0,```$"``"T
M`@``0P0``)L"``"@`0````````````!#````W0(``)T"``!'!0``*0,``$4!
M```)!```0`$```````#U`@``5@0``,D!``"<!0``*@,``!P#``!@````SP0`
M``````!!````L0,``(X#``!A`@``<P```!L"````````SP,``(<"``""`0``
MMP(```````![`0```P4``.<#`````````````$`"``"P`0``-@4```````#R
M`0``]P0```````#Q`P``)P,`````````````]@(``(,!````````70$`````
M``#$!`````````````#Z`0``S`$``.<`````````R@,``*L"``#"!```800`
M``P%```4``````````````!V!0``H@4`````````````T`(```````#.````
M^@```*("`````````````,(#````````Y00``"4````E!````"`H)7,@9&%Y
M<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI
M`"`H=&]M;W)R;W<I`"`H>65S=&5R9&%Y*0`@870@`"(E<R(@=V%S(&%D9&5D
M('1O('1H92!G<F]U<',@<WES=&5M+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@
M<&5R;6ES<VEO;G,@<WES=&5M+@`B)7,B('=A<R!N;W0@8W)E871E9#H@)7,N
M`"4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I`"5D("5S
M(&%N9"`E<P`E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RX`
M)60M9&%Y(&9O<F5C87-T`"5S("T@3F]T:6-E`"5S($9I;F=E<G!R:6YT`"5S
M($M"`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`
M)7,@4V5T=7``)7,@4VEG;B!5<``E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@
M86QR96%D>2!E>&ES=',N`"5S(&%T("5S("5S`"5S(&ES(')E861Y('1O('!E
M<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO
M=RX@0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N
M="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92X`)7,@:7,@<F5Q=6ER960`)7,@
M;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S('1O("5S(&]F("5S`"5S)W,@061D
M<F5S<R!";V]K`"5S)W,@0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S
M:VQI<W0`)7,Z("5S`"P@9W5S=&EN9R``+"!G=7-T:6YG("5S("5S`"P@=F%R
M:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S96QE8W0@+2T`,3(@2&]U<B!&;W)M
M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`02!D871A8F%S92!B86-K96YD
M(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA
M<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N
M8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D
M('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y
M+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I
M=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@
M4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E
M8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E
M(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S
M:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D
M('1O(&5N8W)Y<'0@82!M97-S86=E+@!!32!,:6=H="!286EN`$%-(%)A:6X`
M04T@4VAO=V5R<P!!32!3;F]W(%-H;W=E<G,`04TO4$T`06)O=70@=&AI<R!E
M9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E<W,@9&5N
M:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E
M871I;F<@5D93(&9I;&4N`$%C8V]U;G0@26YF;W)M871I;VX`06-C;W5N="!0
M87-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`061D($-H
M:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@
M3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!P97)M
M:7-S:6]N('1O("(E<R(`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`061D
M(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO
M>FEL;&$@4VED96)A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@
M861D<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE
M9"X`061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E="!P97)M
M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S`$%L
M:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S
M97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S
M`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R
M9&5R960@;&ES="!T>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U3
M4"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U3
M4"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@
M=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;B!I;&QE9V%L('9A;'5E('=A
M<R!S<&5C:69I960N`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`07!P;&EC871I
M;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P
M;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P<F]X:6UA=&4@4VEZ90!!
M<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`
M07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@
M=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R;65N:6%N("A!4DU30TE)
M+3@I`$%R=`!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<S\`07-S:6=N;65N="!C;VQU;6YS`$%T=&5M
M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T('1O
M(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O
M(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E
M9&ET(&$@;F]N+65X:7-T96YT('-H87)E+@!!='1R:6)U=&5S`$%U9W5S=`!!
M=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@
M8V%P86)I;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF
M='`@<W=I=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N
M(&YO="!F;W5N9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E
M<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@
M56YA8FQE('1O(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O
M('5P9&%T92!U<V5R("5S`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U
M=&@@97AT96YS:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@9F%I;&5D
M`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J
M96-T960@8GD@4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10
M('-E<G9E<B!F86EL960N`$%V86EL86)L92!F:65L9',Z`$)A8VMG<F]U;F0`
M0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K
M97)B97)O<R!U<V5R;F%M92X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%S96QI
M;F4`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`
M0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";VQD`$)O;VMM87)K<P!";W)D
M97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!";W1H`$)O='1O;0!"=6QL
M971E9"!,:7-T`$--4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E
M;&P@4')O<&5R=&EE<RXN+@!#86QE;F1A<@!#86QM`$-A;B!N;W0@<F5S970@
M<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T
M<F%T;W(N`$-A;B!N;W0@=W)I=&4@=&\@9FEL92`B)7,B`$-A;B=T(&-O;FYE
M8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;B=T(&]P96X@9FEL92`B)7,B+@!#
M86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL
M92`B)7,B+@!#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A
M;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`
M0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@
M)60@8VAI;&1R96X@97AI<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@
M96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N
M=6UB97(@<W1O<F5D+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I
M960@;G5M8F5R+@!#87!T:6]N`$-A<G)I97(`0V%T96=O<FEE<R!A;F0@3&%B
M96QS`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`
M0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I
M8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#96YT<F%L($5U<F]P96%N("A)4T\M
M.#@U.2TR*0!#97)T:69I8V%T92!$971A:6QS`$-E<G1I9FEC871E(%!O;&EC
M:65S`$-H86YG90!#:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@=&AE(&YA
M;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D
M(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=I;F<@>6]U<B!P87-S
M=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG
M=7)A=&EO;BX@($-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#:&%R`$-H
M96-?:R!,:6YK+BXN`$-H:6QE`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R
M*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@82!P87-S=V]R
M9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T
M97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S
M*0!#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE87(`0VQE
M87(@35-/9F9I8V4@=&%G<P!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E
M<@!#;&5A<B!U<V5R(&1A=&$`0VQI8VL@=&\@0V]N=&EN=64`0VQI8VMA=&5L
M;"!V:6$@2%144`!#;&]S92!7:6YD;W<`0VQO=61S`$-L;W5D>0!#;VQL87!S
M92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]R`$-O;&]R(%!I8VME
M<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S
M`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O
M;7!A;GD`0V]M<'5T97)S`$-O;F1I=&EO;@!#;VYD:71I;VYS`$-O;F9I9W5R
M871I;VX@1&EF9F5R96YC97,`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O
M<F0`0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N
M;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN
M96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O
M;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#
M;VYT86-T<P!#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y
M;W5R(&%D9')E<W,@8F]O:RX`0V]N=&EN=64`0V]O:VEE`$-O<'D`0V]P>2!S
M96QE8W1I;VX`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD
M(&YO="!01U`@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y
M<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O
M=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!
M4"!S97)V97(N`$-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R`$-O=6QD
M(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!L
M9&%P('-E<G9E<@!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82X`0V]U;&0@;F]T(&1E
M8W)Y<'0@4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@
M)7,`0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U
M;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E
M<W,N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O
M=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U
M;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO
M;B!L:7-T<RX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE
M(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N
M($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!R96%D("5S
M+@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S
M=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS(&%R92!N;W0@
M8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A
M=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T(')E=')I
M979E($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<P!#
M;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD
M(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S`$-O=6QD(&YO
M="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,`0V]U;&0@;F]T(')E
M=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U
M<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN
M`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U
M;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N
M`$-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO
M=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T
M:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@
M8F5L;W<@=&\@)7,N`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R
M+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A
M=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO
M>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN
M`$-O=6YT960@=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E871E`$-R96%T92!A
M(&QI;FL`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@<W5B(&9O;&1E<G,`0W)E
M871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`0W5R<F5N="!4
M:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&-O
M;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE('1A<VMS('1O(')U
M;B!U<&]N(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C=&EO;@!#>7)I;&QI
M8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5
M:W)A:6YI86X@*$M/23@M52D`1$0`1&%I;'D`1&%T851R964@0G)O=W-E<@!$
M871E`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@
M0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!);F1E
M;G0`1&5F875L=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F
M875L="!3:&5L;`!$969I;FET:6]N<P!$96QE=&4`1&5L971E($=R;W5P`$1E
M;&5T92!097)M:7-S:6]N`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`1&5L
M971E(&-E;&P`1&5L971E(&-O;'5M;@!$96QE=&4@97AI<W1I;F<@86QT97)N
M871E('1E;7!L871E`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(@!$96QE
M=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(@86YD(&%N>2!S=6(M<&5R;6ES<VEO
M;G,_`$1E;&5T92!R;W<`1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T
M92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$
M96QI=F5R>2!T:6UE`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N
M`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H
M879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO
M<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W
M('!O:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I
M9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`
M1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9&5T86EL960@9F]R96-A<W0`1&ES
M<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA=`!$:7-P;W-I=&EO
M;B!.;W1I9FEC871I;VX`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@
M86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H92!F:7)S="!R;W<@8V]N
M=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z
M`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF
M:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R=6=S
M`$4M36%I;`!%4E(`161I=`!%9&ET($)L;V-K`$5D:70@1W)O=7``161I="!0
M97)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F
M;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I="!P97)M:7-S:6]N<R!F;W(@
M(B5S(@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9'5C871I;VX`16QE;65N
M="XN+@!%;0!%;6%I;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M
M=7-T(&UA=&-H+@!%;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%;6]T:6-O;G,`
M16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;7!T>2!S96%R8V@@=&5R
M;7,`16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL
M97)I97,@:6X@=&5X=#\`16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N
M=3\`16YD('EE87(`16YL87)G92!%9&ET;W(`16YT97(@82!S96-U<FET>2!Q
M=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T
M;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE
M(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%<G)O
M<@!%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,`17)R;W(@9V5T=&EN9R!C;VYT
M96YT.B`E<P!%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,`17)R;W(@=VET
M:"!E;6%I;"!M97-S86=E+@!%=&AN:6,`175R;W!E`$5V97)Y(#$U(&UI;G5T
M97,`179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M
M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU
M=&4`17AA;7!L92!V86QU97,Z`$5X96-U=&4`17AP86YD`$5X<&%N9"!3:61E
M8F%R`$5X<&5C=&5D("<I)P!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`1D<@
M0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN9R!P
M<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N
M`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C
M;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D
M('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V
M92!T;R`B)7,B+@!&86ER`$9A=&%L($5R<F]R.@!&87@`1F5B<G5A<GD`1F5W
M(%-H;W=E<G,`1F5W(%-N;W<@4VAO=V5R<P!&:6QE($-O=6YT.B`E<R!F:6QE
M`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE($YA;64`
M1FEL92!S96QE8W1I;VX`1FEL92!U<&QO860`1FEL92!U<&QO861S(&YO="!S
M=7!P;W)T960N`$9I;'1E<G,`1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I
M>"!R871I;P!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O
M;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T
M(&EM86=E<P!&;W)E8V%S="`H5$%&*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`
M1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@
M,@!&;W)U;7,`1F]R=V%R9',`1G(`1G)A;65S`$9R;VT`1G)O;2!T:&4@`$9U
M;&P@1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@3F%M90!'86QL97)Y('1O
M('1A:V4@:6UA9V4@9G)O;0!'86QL97)Y.@!'96YE<F%T92`E<R!#;VYF:6=U
M<F%T:6]N`$=E;F5R871E9"!#;V1E`$=I=F5N($YA;64`1V\`1V]O9VQE(%-E
M87)C:`!'<F%Y<V-A;&4`1W)E96L@*$E33RTX.#4Y+3<I`$=R;W5P($%D;6EN
M:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P
M<P!'=65S="!097)M:7-S:6]N<P!'=65S=&)O;VL`2%1-3`!(5$U,07)E82!C
M;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O
M=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA
M<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S
M('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@075T:&5N
M=&EC871I;VX@;F]T(&9O=6YD+@!(87-H+4%L9V]R:71H;0!(87IE`$AE861E
M<@!(96)R97<@*$E33RTX.#4Y+3@M22D`2&5I9VAT`$AE;'``2&5L<"!U<VEN
M9R!E9&ET;W(`2&5L<&5R`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN
M:6YG(&]F('1H92!F:6QE.@!(:6=H`$AO7VUE`$AO;64`2&]M92!!9&1R97-S
M`$AO;64@1&ER96-T;W)Y`$AO;64@4&AO;F4`2&]R9&4`2&]R9&4O2V]L86(Z
M($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E
M<P!(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE
M8W0@)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD
M(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO
M=F5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W
M(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R
M971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S`$AO
M<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE
M`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W<@9&ED('EO=2!G
M970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@;6%N>2!C;VQU;6YS('=O
M=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M
M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T
M;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ(`!)34%0(&UA:6QB;W@@8W)E
M871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D
M.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)
M4"!!9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S
M<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`25]N<V5R="!2;W<@
M0F5F;W)E`$EC;VYS($]N;'D`26-O;G,@9F]R("5S`$EC;VYS('=I=&@@=&5X
M=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R
M<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@>6]U
M(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L
M('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!0
M3D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@
M;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@
M8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE=SH`
M26UA9V4@55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM86=E
M(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0L(%-T
M97`@)60`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26Y?
M<V5R="!2;W<@069T97(`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!)
M;F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@
M=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C
M;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R
M(&AE;'`N`$EN8W)E87-E($EN9&5N=`!);F1I=FED=6%L(%5S97)S`$EN9F\`
M26YF;W)M871I;VX`26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92X`
M26YS97)T($-?;VQU;6X@069T97(`26YS97)T($EM86=E`$EN<V5R="!486)L
M90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R
M="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A
M(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N
M97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W
M(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R87!H(&%F
M=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H(&)E9F]R
M92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`
M26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E
M:79E('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R
M="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU
M;6X@8F5F;W)E`$EN<V5R="!M97-S86=E<P!);G-E<G0@<&%R86=R87!H(&%F
M=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R;W<@869T97(`
M26YS97)T(')O=R!B969O<F4`26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@
M=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.@!);G-E<G0O36]D:69Y($EM86=E
M`$EN<V5R="]-;V1I9GD@3&EN:P!);G-U9F9I8VEE;G0@8W)E9&ET('1O('-E
M;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@8W)E
M9&ET+@!);G1E9V5R`$EN=&5G97(@;&ES=`!);G9A;&ED(%5$2"X@*%5S97(@
M1&%T82!(96%D97(I+@!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A
M=&-H($E$+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I
M;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI9"!M
M<V=?='EP92X`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O
M<B!M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I
M;VXN`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<F5C:7!I96YT.B`B)7,B
M`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N
M`$EN=F%L:60@=6YI8V]D92!D871A+@!);G9E;G1O<GD`26YV97)T('-E;&5C
M=&EO;@!)<V]L871E9"!4+5-T;W)M<P!)<W-U97(`271A;&EC`$IA;G5A<GD`
M2F%P86YE<V4@*$E33RTR,#(R+4I0*0!*97)S97D`2G5L>0!*=6YE`$IU<W1I
M9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*
M=7-T:69Y(%)I9VAT`$ME97`@;W)I9VEN86P_`$ME<F)E<F]S('-E<G9E<B!R
M96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5Y($-R96%T:6]N`$ME>2!&:6YG
M97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@86QR
M96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$MI9',`2V]R
M96%N("A%54,M2U(I`$QA7WEO=70`3&%N9W5A9V4`3&%S="!(86QF`$QA<W0@
M4&%S<W=O<F0@0VAA;F=E`$QA<W0@475A<G1E<@!,87-T(%5P9&%T960Z`$QA
M<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I
M;CH@3F5V97(`3&%W`$QA>6]U=`!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L
M=65S`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY
M`$QI9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN
M('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI
M;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@
M=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@
M0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A
M=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C
M:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,
M:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@=7-E<G,@
M:7,@9&ES86)L960N`$QI=&5R871U<F4`3&]A9&EN9RXN+@!,;V-A;"!T:6UE
M.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@;W5T`$QO
M9VEN`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E
M<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO
M9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE
M='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S
M`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A
M+@!-4T<`36%G:6,`36%I;`!-86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`36%N
M86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@
M:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@
M8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-87)C:`!-87)G
M:6X`36%R:R!W:71H(%-E96XO56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE
M<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I`$UA=&-H:6YG(&9I
M96QD<P!-87@@86QL;W=E9"!C<F5D:70N`$UA>"!M97-S86=E('!A<G1S(&5X
M8V5E9&5D+@!-87@@=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S
M="`V(&AO=7)S.B``36%X:6UU;2!L96YG=&@`36%Y`$UE9&EC:6YE`$UE;6)E
M<G,`365N=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@5F5R
M:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A
M=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE
M<W-A9V4@='EP90!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I
M;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V
M92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&AO9`!-
M971R:6,`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S
M.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36ER<F]R`$UI<V-E;&QA;F5O
M=7,`36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T
M92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC871I;VXN
M`$UI<W-I;F<@;65S<V%G92!)1"X`36ES<VEN9R!S97-S:6]N($E$+@!-;P!-
M;V)I;&4@36%I;`!-;V1E<F%T90!-;V1I9FEE9"!$871E`$UO9&EF>2!54DP`
M36]N=&@@86YD('EE87(`36]N=&AL>0!-;V]N(%!H87-E<P!-;W-T;'D@0VQE
M87(`36]S=&QY($-L;W5D>0!-;W-T;'D@4W5N;GD`36]V92!$;W=N`$UO=F4@
M3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V92!D;W=N`$UO=F4@=7``375L
M=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S`$UU;'1I<&QE('-E;&5C=&EO;@!-
M>2!!8V-O=6YT`$UY($%C8V]U;G0@26YF;W)M871I;VX`37D@4&]R=&%L`$UY
M(%!O<G1A;"!,87EO=70`3D\L($D@1&\@3D]4($%G<F5E`$YA;64`3F5T<V-A
M<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A
M<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!296YE=V%L(%523`!.971S8V%P
M92!2979O8V%T:6]N(%523`!.971S8V%P92!C97)T:69I8V%T92!C;VUM96YT
M`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.979E<@!.97<@
M0V%T96=O<GD`3F5W($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W
M('!A<W-W;W)D`$YE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"X`3F5W
M('!A<W-W;W)D<R!D;VXG="!M871C:"X`3F5W('=I;F1O=R`H7V)L86YK*0!.
M97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(&]P=&EO;G,`3FEG:'0`3F\`3F\@
M879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N
M8V5S(&9O<BX`3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/
M(&EM86=E<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A
M="!T:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O
M=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@
M8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10
M(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-R961I="!L969T+@!.;R!D
M97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.;R!I8V]N
M<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!M97-S86=E('-U<'!L
M:65D+@!.;R!N86UE('-P96-I9FEE9"X`3F\@;G5M8F5R('-P96-I9FEE9"X`
M3F\@;V9F96YS:79E(&9O<G1U;F5S`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!(5%10(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@24U!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN`$YO('!E;F1I;F<@
M<VEG;G5P<RX`3F\@<G5L97,`3F\@<V5P87)A=&]R('-P96-I9FEE9"X`3F\@
M<VED97,`3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A
M8VAE+@!.;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L
M:60@6$U,(&1A=&$@<F5T=7)N960`3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U
M;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF
M:6=U<F%T:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A
M=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;VYE`$YO;F4@*'5S
M92!I;7!L:6-I="D`3F]R9&EC("A)4T\M.#@U.2TQ,"D`3F]R=&AE<FX@2&5M
M:7-P:&5R90!.;W0@069T97(`3F]T($)E9F]R90!.;W0@82!D:7)E8W1O<GD`
M3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S=7!P;W)T960N`$YO=&5S
M`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.;W9E;6)E<@!.=6UB97(`
M3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R
M(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I
M;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J96-T`$]B:F5C="!#<F5A=&]R
M`$]C=&%L`$]C=&]B97(`3V9F96YS92!F:6QT97(`3V9F:6-E`$]L9"!A;F0@
M;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="X`3VQD('!A<W-W;W)D
M`$]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="X`3VYL>2!)34%0('-E<G9E
M<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!O9F9E;G-I=F4@9F]R
M='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+@!/;FQY('1H
M92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W
M;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N
M(&EN(&$@;F5W('=I;F1O=P!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN
M9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/
M<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`
M3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG
M:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N
M`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@
M879A:6QA8FQE+@!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E
M9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D($1A
M=&$`4$A0($-O9&4`4$A0(%-H96QL`%!-($QI9VAT(%)A:6X`4$T@4VAO=V5R
M<P!032!3;F]W`%!-(%-N;W<@4VAO=V5R<P!032!4+5-T;W)M<P!03U-)6"!E
M>'1E;G-I;VX@:7,@;6ES<VEN9P!07TA0(%-H96QL`%!A9&1I;F<`4&%R=&QY
M($-L;W5D>0!087-S=V]R9`!087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL
M>2X`4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2
M041)55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T
M:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H
M+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG
M;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R
M871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I
M;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N("(E<R(@;F]T(&1E;&5T960N`%!E
M<FUI<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L
M($EN9F]R;6%T:6]N`%!E=',`4&AO;F4`4&AO=&]S`%!I>&5L<P!0;&5A<V4@
M8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@
M=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T
M:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E
M;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA;64@
M9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A('9A;&ED($E0
M(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H
M92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E<B!A
M('9A;&ED('1I;64N`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@
M<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S
M<W=O<F0`4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@3553
M5"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE
M87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;VQI=&EC<P!0;VQL
M<P!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F('1H
M:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y
M($E-05`I`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@`%!R
M969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`
M4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V96PZ(`!0<F5S
M<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN
M9&]W`%!R979I;W5S(&]P=&EO;G,`4')I;G0@9&]C=6UE;G0`4')I=F%T92!+
M97D`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP
M="!T97AT`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC
M+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`
M475E<GD`475O=&$`4E-!(%!U8FQI8R!+97D@*"5D(&)I="D`4F%D:6\@<V5L
M96-T:6]N`%)A:6X`4F%I;B!%87)L>0!286EN($QA=&4`4F%I;B!3:&]W97(`
M4F%I;B!A;F0@4VYO=P!286EN('1O(%-N;W<`4F%N9&]M($9O<G1U;F4`4F%T
M:6\`4F5A9`!296%D(&UE<W-A9V5S`%)E86QL>2!D96QE=&4@)7,_(%1H:7,@
M;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E86QL>2!R96UO=F4@=7-E
M<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@
M=6YD;VYE+@!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H($1Y;F%M
M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5L871I
M;VYS:&EP($)R;W=S97(`4F5M87)K<P!296UO=&4@4V5R=F5R<P!296UO=&4@
M55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E
M;6]V92!";&]C:P!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E
M;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T
M96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T:&ES(&YO
M9&4@9G)O;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z
M("5S`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R
M<F]R8V]D93H@`%)E<75I<F5D($9I96QD`%)E<V5T`%)E<V5T(%!A<W-W;W)D
M`%)E<V5T(%EO=7(@4&%S<W=O<F0`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N
M<P!2971Y<&4@;F5W('!A<W-W;W)D`%)E=6YI;VX`4F5V97)T($-O;F9I9W5R
M871I;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`
M4FEG:'0@:&5A9&5R`%)I9VAT('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`
M4F]L90!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@
M4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W
M:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@
M87!P96%R(&)E='=E96X@<F]W<R!O;FQY`%)U;@!3+TU)344@16YC<GEP=&5D
M($UE<W-A9V4`4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE
M+@!335,@365S<V%G:6YG`%-13"!3:&5L;`!34T@`4U5#0T534P!37U%,(%-H
M96QL`%-A`%-A;64@9G)A;64@*%]S96QF*0!3879E`%-A=F4@)7,`4V%V92!/
M<'1I;VYS`%-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@
M<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`
M4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V-I96YC90!396%R8V@`4V5A<F-H
M($5N9VEN97,`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@
M9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!S97)V
M97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;`!396QE8W0@86QL
M(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C=`!396QE8W0@;F]N
M90!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X
M97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R
M;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`
M4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I9&5N=&ET>2!Y
M;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z
M`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@
M9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R
M('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD
M(%--4P!396YS;W(Z(`!397!T96UB97(`4V5R:6%L($YU;6)E<@!397-S:6]N
M($E$(&5X<&ER960N`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@
M<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E
M="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F
M<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L
M('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@
M87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A
M;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E
M('-C<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE
M('=I=&@@=&AE('!A<F%M971E<CH@`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`
M4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_
M`%-H;W<`4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E
M9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@!3:&]W
M(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@;W!T:6]N
M('1O(&ME97`@;W)I9VEN86P`4VAO=R!P:6-K97(`4VAO=R!T86)L92!O<&5R
M871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T
M/P!3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@
M=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O
M=R!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!I;6%G92!P<F]P97)T:65S
M(&1I86QO9P!3:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@16%R;'D`4VAO
M=V5R<R!,871E`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@
M8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0`4VEG;B!U<`!3:6=N871U
M<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3:7IE`%-K:7`@36%I;G1E;F%N8V4`
M4VYO=P!3;F]W(%-H;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A
M<FQY`%-N;W<@4VAO=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV
M86QE;G0@:6X@=V%T97(Z(`!3;VYG<R`F(%!O96US`%-O<G0@;W)D97(@<V5L
M96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=71H($5U<F]P96%N("A)4T\M.#@U
M.2TS*0!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@861J86-E
M;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@
M8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P86T`
M4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!L:70@8V5L;`!3<&QI="!C;VQU
M;6X`4W!L:70@<F]W`%-P;W)T<P!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0@
M>65A<@!3=&%T92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O<F%G92!F;W)M870`
M4W1R965T($%D9')E<W,`4W1R:6YG(&QI<W0`4W1Y;&4@6T-34UT`4W4`4W5B
M:F5C=`!3=6)M:70`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&1E
M;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I
M;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY('-A=F5D
M(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@<V%V960@=&AE
M(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E<W-F=6QL>2!W
M<F]T92`E<P!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`4W5N<FES
M90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U
M<&5R<V-R:7!T`%-U<'!O<G0`4W5R;F%M90!3>6YT87@@97)R;W(@:6X@<V5A
M<F-H('1E<FUS`%0M4W1O<FT`5"U3=&]R;7,`5%-6(&9I;&4`5&%B;&4`5&%B
M;&4@4')O<&5R=&EE<P!486)L92!P<F]P97)T:65S`%1A<F=E=#H`5&%S:W,`
M5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A
M='5R90!496UP97)A='5R93H@`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E
M>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I("A425,M
M-C(P*0!4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN`%1H92!&5%`@
M97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!-86EN=&5N86YC93HZ
M(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@
M=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A9&UI;FES=')A=&]R
M(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B
M86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N<RX`5&AE(&)O
M='1O;2!S:61E(&]N;'D`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@
M<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE
M(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D
M('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@9&5T86-H960@4$=0('-I9VYA
M='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M
M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N
M;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@
M9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I
M9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R
M92!W96(@8V]N;F5C=&EO;BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@
M82`E<R!S971T:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE
M("5S('-E='1I;F=S+@!4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O
M(&ET<V5L9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F=6QL
M('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@
M26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W
M92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E
M<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I
M;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S
M>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U
M)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D
M('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@
M<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C
M<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T
M960N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H92!M97-S86=E('-E;G0@
M;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T("(E<R(@:&%S(&)E96X@9&ES<&QA
M>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA
M<R!B965N(')E860@;W(@=6YD97)S=&]O9"X`5&AE(&YA;64@=&\@=7-E('=H
M96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H92!N=6UB97(@;V8@
M9FEE;&1S(&UU<W0@8F4@;G5M97)I8RX`5&AE('!R969E<F5N8V4@(B5S(B!C
M;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T
M:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O
M('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H
M92!S>7-T96TN`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY`%1H92!R
M:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE
M('-I;F=L92!C:&%R86-T97(N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D
M96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S
M:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE('-P
M96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N`%1H92!T96UP;W)A<GD@9FEL
M92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED
M97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4:&4@=7!L;V%D960@9&%T82!W
M87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D
M(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=V5A=&AE<BYC;VT@8FQO
M8VL@:7,@;F]T(&%V86EL86)L92X`5&AE<F4@87)E(&YO(&]P=&EO;G,@879A
M:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA
M>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@
M=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R!Y
M;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N`%1H97)E('=A<R!A('!R;V)L
M96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`
M5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE
M("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@
M*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE
M('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`
M5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A
M<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D
M871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD
M87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T
M:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE
M;&0N`%1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I
M960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA
M=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@
M9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N
M(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E
M('1R>2!A9V%I;B!L871E<BX`5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S
M=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@
M=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E
M87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M
M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@9FEE;&0@:7,@<F5Q
M=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C
M;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E
M<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A
M=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L
M:60@;G5M8F5R+@!4:&ES(&ES("5S+@!4:&ES(&UE<W-A9V4@=V%S('=R:71T
M96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W
M;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@<V5R
M=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4:&ES
M('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L=64@
M;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@
M9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R`%1I8VME=',`5&EM90!4
M:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L96-T:6]N`%1I=&QE
M`%1I=&QE("AT;V]L=&EP*3H`5&\`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US
M+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I
M(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D87D`5&]M;W)R;W<`5&]P`%1O<"!F
M<F%M92`H7W1O<"D`5')A;G-L871I;VYS`%1R=64@;W(@9F%L<V4`5'4`5'5R
M:VES:"`H25-/+3@X-3DM.2D`5'EP92!Y;W5R(&-H;VEC93H@`%4N5BX@:6YD
M97@Z(`!54DP`55),.@!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN
M`%5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I
M9VYI;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93
M(&9I;&4@(B5S(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!6
M1E,@9FEL92`E<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE
M('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@
M=VET:"!34TPN`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@
M8W)E871E(%9&4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!6
M1E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B
M;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP
M<F5S<R!D871A+@!5;F%B;&4@=&\@9&5L971E("(E<R(L('1H92!D:7)E8W1O
M<GD@:7,@;F]T(&5M<'1Y+@!5;F%B;&4@=&\@9&5L971E("(E<R(Z("5S+@!5
M;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T
M>0!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN
M`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(&1E;&5T92!61E,@
M9FEL92`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@
M=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D971E
M<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R86-T(&-E
M<G1I9FEC871E(&1E=&%I;',`56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I
M;VX@;V8@)7,N`%5N86)L92!T;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F
M;W(@=W)I=&EN9RX`56YA8FQE('1O(&]P96X@5D93(&9I;&4N`%5N86)L92!T
M;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`56YA8FQE('1O(')E860@=&AE
M('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE("5S('1O("5S
M.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`56YA8FQE('1O
M(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!D
M:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("(E<R(N
M`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R=6X@)VUK:7-O9G,G+@!5;F%B
M;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A
M=&$N`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S="!A
M8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN
M96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@
M`%5N9FEL960`56YI8V]D92`H551&+3@I`%5N:71S`%5N:VYO=VX`56YK;F]W
M;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YL:6YK('1H92!C=7)R96YT(&5L
M96UE;G0`56YN86UE9`!5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C
M97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I
M='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E
M(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@
M82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N`%5N<V5T(&-O;&]R
M`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D871E("5S`%5P9&%T
M92!U<V5R`%5P9&%T960@(B5S(BX`57!G<F%D92!S8W)I<'0@9&5L971E9"X`
M57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T
M;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R(')O;6%N
M(&YU;6)E<G,`57-E($-U<G)E;G0Z("5S`%5S92!34TP`57-E(&EF(&YA;64O
M<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E<B`E
M<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@061M:6YI<W1R871I
M;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S97(@4F5G:7-T
M<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N`%5S97(@
M86-C;W5N="!N;W0@9F]U;F0`57-E<FYA;64`57-E<FYA;64Z`%5S97)N86UE
M.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`5D93(&1I<F5C=&]R>2!D;V5S(&YO
M="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU
M9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU
M92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RX`5F%L=65S`%9A
M;'5E<R!T;R!S96QE8W0@9G)O;0!687)I86)L90!697)S:6]N`%9E<G-I;VX@
M0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E<G1I
M8V%L.@!697)Y($AI9V@`5FEE=&YA;65S92`H5DE30TE)*0!6:65W("5S`%9I
M97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:7-I8FEL:71Y
M`%9I<VEB:6QI='DZ(`!705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,
M3%D@1E)/32`E<RX`5V%R;FEN9P!790!796%T:&5R($9O<F5C87-T`%=E871H
M97(@9&%T82!P<F]V:61E9"!B>0!796%T:&5R+F-O;0!796(`5V5B(%-I=&4`
M5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!797-T
M97)N("A)4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ-2D`5VAA="!A
M<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA
M="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@<75O
M=&4@8VAA<F%C=&5R/P!7:&EC:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E
M;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+@!7:61T:`!7:61T:"!I
M;B!#4U,@=6YI=',`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@
M*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T
M86)L90!7:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I;F0`5VEN9"!%87)L>0!7
M:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`5V]R:P!7
M;W)K($%D9')E<W,`5V]R:R!0:&]N90!960!965E9`%EE87)L>0!997,`665S
M+"!)($%G<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=
M(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E(&YO
M="!A=71H96YT:6-A=&5D+@!9;W4@8V%N(&YO="!H879E('1H92`G7"<@8VAA
M<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E<B!A
M('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L
M9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN
M9R!F:65L9',@:6X@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U
M(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I
M=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T
M:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L
M:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME
M;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B
M86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@
M>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT
M97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T
M('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<W!E
M8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF
M>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@
M=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M
M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@
M<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+@!9
M;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I
M;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U
M<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG
M960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O
M('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN
M`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N
M;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@
M8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O
M=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN
M:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R
M:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O97,@
M;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&-U<G)E;G0@=&EM92!Z
M;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9
M;W5R(&QO9VEN(&AA<R!E>'!I<F5D+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@
M)7,@:7,Z("5S`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@
M=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA
M=F4@8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T
M`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA
M:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A
M<W-W;W)D(&AA<R!E>'!I<F5D+@!9;W5R(')E;6]T92!S97)V97)S.@!;2&ED
M92!1=6]T960@5&5X=%T`6U!R;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T960@
M5&5X="`M`%M3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=`%ML:6YE("5S
M(&]F("5S70!?061M:6YI<W1R871I;VX`7T-,20!?1&%T851R964`7T1E;&5T
M92!2;W<`7T=R;W5P<P!?2&5L<`!?26UA9V4@4')O<&5R=&EE<RXN+@!?3&]G
M(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN:RXN+@!?3W!T:6]N<P!?4&5R;6ES
M<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]3971U<`!?5&%B;&4@4')O<&5R=&EE
M<RXN+@!?57-E<G,`861D<F5S<R!B;V]K`&-A;&5N9&%R`&-A;&T`8VQI8VL@
M:&5R90!F:6QE`&9R;VT@=&AE("5S("@E<RD@870@)7,@)7,`9W5S=&EN9P!H
M.@!I;6UE9&EA=&4`:6YL:6YE`&QI;F5S70!N86UE`&YO="!I;7!L96UE;G1E
M9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`<&5R8V5N=`!P:7AE;',`
M<FES:6YG`'-H;W<@9&EF9F5R96YC97,`<W1E861Y`'1A<VL@;&ES=`!T>7!E
M('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N:69I960`=6YN86UE
M9`!U<V5R('-E;&5C=`!V0V%R9`!W.@!W96%T:&5R+F-O;0!0<F]J96-T+4ED
M+59E<G-I;VXZ($AO<F1E(#,@"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`
M;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X
M(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-2TP-RTP."`Q-3HR
M-RLP,C`P"DQA<W0M5')A;G-L871O<CI!;6ER:V%B:7(@365T86YE='=O<FMI
M;F<@;'1D+B`\<&5R<VEA;BUH;W)D94!M971A;F5T=V]R:VEN9RYC;VT^"DQA
M;F=U86=E+51E86TZ(%!E<G-I86X@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/@I-
M24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H
M87)S970]551&+3@*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`
M("C8L=F(V+(@V8+8J-F$("5S*0`HVJG9A-N,V*\@V*_8L]BJV+'8L]N,("5S
M*0`HV*_8L2`E<R#8L=F(V+(I`"`HV*?9A=BQV8C8LBD`("C9@=BQV*_8IRD`
M("C8K]N,V+'9B-BR*0`@V*_8L2``(B5S(B#8J-F'(-JOV+'9B-F'XH",V8?8
MI]N,(-BSV*?9A=BGV8;9AR#8I]BVV*?9@=F'(-BTV*\`(B5S(B#8J-F'(-BS
MV*?9A=BGV8;9AR#9A=BLV8C8LN*`C-F'V*<@V*?8MMBGV8'9AR#8M-BO`"(E
M<R(@V*?;C-BLV*?8KR#9AMBTV*_9AR#8J-F(V*\Z("5S+@`E+C)F34(@V*?8
ML]BJV8'8I]BOV8<@V+38K]F'(-BGV+(@)2XR9DU"(-F%V*S8I]BR("@E+C)F
M34(I`"5D("5S(-F(("5S`-BGV+/9A2#8L=F%V+(@V+39A=BG("5D(-BQV8C8
MLB#8K]N,VJ_8L2#9A=BYV*K8J-BQ(-BGV+/8JBX`V;[;C-BTPJW8J-N,V8;;
MC"`E9"W8L=F(V++9AP`E<R`M(-BJV8C8K-F'`-BGV*O8L2#8I]F&VJ_8M-BJ
M("5S`-JIVXS9A-F(V*C8I]N,V*H@)7,`)7,@V+G9A=F$VXS8I]BJ(-F&VJ_9
MA]BOV*?8L=N,("T@V*K8H]N,VXS8KP`@V+'8I]F')B-X,C`P8SO8I]F&V*_8
MI]BRVXP@)7,@`"5S(-BKV*C8JB#9AMBGV84`V+38L=F(V+<@V*K9B-BGV8'9
M@B`E<P`E<R#8I]BR(-F"V*C9A"#9A=F(V*S9B-BO(-BGV+/8J@`E<R#8K]BQ
M("5S("5S`"5S(-BBV878I]BOV8<@V*?8K-BQV*?;C"#8N=F%V83;C-BGV*H@
MV8;:K]F'V*_8I]BQVXP@V*?9AMBJV*[8I]BH(-BTV*_9AR#8I]BSV*HN(-BL
MV+G8J-F'(-F'V+$@V+G9A=F$VXS8I]BJVXP@V+'8IR#:J=F'(-F'V84@V*?:
MJ=F&V8C9AB#9A=N,XH",V*[9B-BGV8?;C-BO(-BGV*S8L=BG(-JIV8;;C-BO
M(-BYV838I]F%V*H@V*C8LMF&VXS8KP`E<R#9A=F(V+'8KR#9AMN,V*?8LB#8
MI]BSV*H`)7,@V*_9@MN,V8+9AP`E<R#9OMN,V*_8IR#9AMBTV*\`)7,@V*C9
MAR`E<R#8I]BR("5S`-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS("5S`-BJV8+9
MB-N,V84@)7,`)7,G<R!.;W1E<&%D`-F!V8?8L=BSV*H@V8C8N-BGVXS9@2`E
M<P`E<SH@)7,`V(P@V*C8I]BO`-B,(-BHV*?8KR`E<R`E<P#8C"#9A=BJV+K;
MC-N,V+$@V*?8LB`E<R#8J-F'("5S`"#8I]F&V*K8KMBGV*@@`-F"V*?9A-BH
M(-NQV[(@V+/8I]BYV*K;C`#9@MBGV838J"#;LMNT(-BSV*?8N=BJVXP`V[+;
MM"#8L]BGV+G8JMF'`-N,VJD@V;[8M-BJVXS8J-BGV88@V*_8I]BOVJ_8I]F&
M(-BHV+'8I]N,(-BGVXS9AB#8J-F$V*?:J2#9A=F(V+'8KR#9AMN,V*?8LB#8
MI]BSV*H`VXS:J2#8KMBWV*?;C"#8K-BOVXP@V+'8KB#8K]BGV*_9AR#8I]BS
MV*H`VXS:J2#:J=F$VXS8KR#8N=F%V8C9A=N,(%!'4"#8J-BQV*?;C"#8L=F%
MV++8J-F&V*_;C"#;C-JI(-F^VXS8NMBGV84@V879B-BQV*\@V8;;C-BGV+(@
MV*?8L]BJ`-N,VJD@VJG9A-N,V*\@V+G9A=F(V87;C"!01U`@V*C8L=BGVXP@
MV*C8I]BRV*C;C-F&VXP@VXS:J2#9OMN,V+K8I]F%(-BGV878MMBGV*$@V+38
MK]F'(-F%V8C8L=BO(-F&VXS8I]BR(-BGV+/8J@#;C-JI(-JIV83;C-BO(-BY
MV879B-F%VXS8C"#;C-JI(-JIV83;C-BO(-BNV+79B-BUVXP@4$=0(-F((-N,
MVJD@V+G8J-BGV+'8JB#:K]BPV+$@V*C8L=BGVXP@V+'9A=BRVJ_8M-BGVXS;
MC"#;C-JI(-F^VXS8NMBGV84@V879B-BQV*\@V8;;C-BGV+(@V*?8L]BJ`-N,
MVJD@VJG9A-N,V*\@V+G9A=F(V87;C-B,(-N,VJD@VJG9A-N,V*\@V*[8M=F(
MV+7;C"!01U`@V8@@VXS:J2#8N=BHV*?8L=BJ(-JOV+#8L2#8J-BQV*?;C"#8
MI]F%V+;8I]BA(-N,VJD@V;[;C-BZV*?9A2#9A=F(V+'8KR#9AMN,V*?8LB#8
MI]BSV*H`VXS:J2#:J=F$VXS8KR#8N=F%V8C9A=N,V(P@VXS:J2#:J=F$VXS8
MKR#8KMBUV8C8M=N,(%,O34E-12#9B"#;C-JI(-BYV*C8I]BQV*H@VJ_8L-BQ
M(-BHV+'8I]N,(-BQV878LMJOV+38I]N,VXP@V;[;C-BZV*?9A2#9A=F(V+'8
MKR#9AMN,V*?8LB#8I]BSV*H`VXS:J2#:J=F$VXS8KR#8N=F%V8C9A=N,V(P@
MVXS:J2#:J=F$VXS8KR#8KMBUV8C8M=N,(%,O34E-12#9B"#;C-JI(-BYV*C8
MI]BQV*H@VJ_8L-BQ(-BHV+'8I]N,(-BGV878MMBGV*$@VXS:J2#9OMN,V+K8
MI]F%(-F%V8C8L=BO(-F&VXS8I]BR(-BGV+/8J@#;C-JI(-JIV83;C-BO(-BY
MV879B-F%VXP@4R]-24U%(-BHV+'8I]N,(-BQV878LMBHV8;8K]N,(-F^VXS8
MNMBGV84@V879B-BQV*\@V8;;C-BGV+(@V*?8L]BJ`-BHV*?8L=BGV88@V+/8
MJ-JI(-BUV*C8K=JOV*?9A]N,`-BHV*?8L=BGV88@V+78J-BMVJ_8I]F'VXP`
MV+':K]BHV*?8L2#8M=BHV*W:K]BGV8?;C`#8JMJOV+':KR#8M=BHV*W:K]BG
MV8?;C`#8M=BHV*TOV+G8M=BQ`-BOV+'8J-BGV+'9AR#8I]N,V88@V8C;C-BQ
MV*?8L]BJV*?8L0#8K]BQV*C8I]BQV8<N+BX`V;[8I]N,VXS9AB#9A=BWV839
M@@#9B-BSV+<@V878M]F$V8(`V*?;C-BLV*?8KR#8M-BGV*[9AR!61E,@V878
MK-F(V+(@V*_8L]BJV+'8L]N,(-F&V*_8I]BQV*\`V*?;C-BLV*?8KR#9OMBQ
MV8C9AMBOV8<@5D93(-F%V*S9B-BR(-BOV+/8JMBQV+/;C"#9AMBOV*?8L=BO
M`-BGV+?9A-BGV+G8I]BJ(-BMV+/8I]BH`-BGV+/9A2#8L=F%V+(@V*W8L]BG
MV*@`V*W8L]BGV*@@V878L]BOV8C8KP#8K=BSV*?8J-BOV*?8L=N,`-BGV+;8
MI]F!V8<@VJG8L=BOV88`V*?8MMBGV8'9AR#:J=BQV*_9AB#:K]BQV8C9AR#9
M@=BQV+G;C`#8I]BVV*?9@=F'(-JIV+'8K]F&(-F%V*S9B-BR(-F!V+'8N=N,
MXH",`-BGVXS9AMBLV*<@V*?8MMBGV8'9AR#:J=F&.@#8I]BVV*?9@=F'(-JI
MV+'8K]F&(-JOV+'9B-F'(-BLV*_;C-BO`-BGV+;8I]F!V8<@VJG8L=BOV88@
MV878K-F(V+(@V*S8K]N,V*\`V*?8MMBGV8'9AR#:J=BQV*_9AB#;C-JI(-F%
MV*S9B-BR(-F!V+'8N=N,(-BHV8<@(B5S(@#8I]BVV*?9@=F'(-JIV+'8K]F&
M(-N,VJD@VJG8I]BQV*C8L2#8K-BOVXS8KSH`V*?8MMBGV8'9AR#:J=BQV*_9
MAB#8L]BJV8C9A@#8I]BVV*?9@=F'(-JIV+'8K]F&(-BGV+G8MMBGVXP@V*S8
MK]N,V*\`V*?8MMBGV8'9AR#:J=BQV*_9AB#8LMF(V*P`(-BGV+;8I]F!V8<@
MVJG8L=BOV88@VJ_8LMN,V8;:K]BGV88@)7,@V*C8N=F&V8C8I]F&(-F&V8C8
MI]BQ(-BLV*?9AMBHVXP@V879B-BRVXS9A-BG`-BGV+;8I]F!V8<@VJG8L=BO
MV88@V*C9AR#:J=BJV*?8J-J&V8?9E"#8HMBOV+'8LSH`V*?8MMBGV8'9AR#:
MJ=BQV*_9AB#8J-F'(-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS(-F%V88`V*?8
MMMBGV8'9AR#9@]BQV*_9AB#:J=BGV+'8J-BQ`-BGV+;8I]F!V8<@VJG8L=BO
MV88@VJG8I]BQV*C8L=BGV88@V8'8N=BGV80@V8;;C-BSV*H`V*+8K]BQV+,`
MVJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@`-BSV+'9OMBQV+/8JB#8L]BGV878
MI]F&V8<M(-BJV+G;C-N,V88@V878K-F(V++9A]BGVXP@VJG8I]BQV*C8L=BG
MV88@V*_;C-JOV+$`V+/8L=F^V+'8L]BJVXP`V*K8J-F$VXS8NMBGV*H`V878
MN=BGV*_9A`#8JMBQV*?8LB#:J=BQV*_9A@#8JMBQV*?8LCH`V8?9A=F'`-BJ
MV878I]F%VXP@VJG8I]BQV*C8L=BGV88@V*K8H]N,VXS8KR#8M=F$V*?8K=N,
MV*H@V+38K]F'`-F'V879AR#:K]BQV8C9A^*`C-F'V*<`V8?9A=F'(-F%V*S9
MB-BRXH",V8?8IP#9A]F%V8?9E"#:AMF'V*?8L2#8L]F%V*H`V*?8K-BGV++9
MAR#:AMF&V*\@V*+8K]BQV+/;C`#8HMN,V*<@V*?8K-BGV++9AR#8JMF&V+C;
MC-F%(-F&V8C8N2#9@=F'V+'8L]BJ(-F%V+'8JMBH(-BOV*?8K]F'(-BTV8C8
MK]B?`-BGV+(@V8+8J-F$(-F%V8C8K-F(V*\@V*?8L]BJ`-F(V+'9B-BO($E-
M4U`@V*S8I]N,VJ_8LMN,V88`V*?8L]F%(-BQV878LB!)35-0(-BLV*?;C-JO
MV++;C-F&`-F&V*?9A2#:J=BGV+'8J-BQVXP@24U34"#8K-BGVXS:K]BRVXS9
MA@#8HMBOV+'8LR#9OMBSV*H@V*?9A-JIV*K8L=F(V8;;C-JI(-BLV*?;C-JO
MV++;C-F&`-BGV83:K]F(XH",V8?8I]N,(-BLV*?;C-JOV++;C-F&`-F%V*K9
MAB#8K-BGVXS:K]BRVXS9ACH`VXS:J2#9A=F"V*_8I]BQ(-F&V*?8K]BQV+/8
MJB#8JMBYVXS;C-F&(-BTV*_9AR#8J-F(V*\`V;[;C-BTVJG8I]BQ`-F^V*?8
ML]BN`-BHV+'9AMBGV879A]F4XH",(-JIV*?8L=BHV+'8K]N,`-F!V8?8L=BS
MV*H@V*C8L=F&V*?9A=F'XH",V8?8I]N,(-JIV*?8L=BHV+'8K]N,`-BHV+'9
MAMBGV879AR#8HMF%V*?8K]F'(-BGV+/8J@#8I]BYV878I]F$(-BHV+$@V+'9
MB-N,(-BGV+38JMBQV*?:J=F'V*?;C"#9@=BQV+G;C`#8JMBUV8C;C-BH`-BG
MV8;8K]BGV++9AR#8JMF"V+';C-BHVXP`V*+9B-BQVXS9A`!!<F%B:6,@*%=I
M;F1O=W,M,3(U-BD`V*?9AMBOV*?8LMF'(-F^V+'9B-F&V*_9AR#8HMBQV+3;
MC-F(`-F&V*?9A2#8HMBQV+3;C-F(`-BBVXS8IR#8M-F%V*<@V878M]F%V*;9
MAMN,V*\@VJG9AR#9A=N,XH",V*[9B-BGV8?;C-BO(-BGV+?9A-BGV+G8I]BJ
M(-BGV8'8JMBJV*?8K2#8K=BSV*?8J"`E<R#8L=BG(-F^V*?:J2#:J=F&VXS8
MK]B?`$%R;65N:6%N("A!4DU30TE)+3@I`-F'V8;8L0#8HMN,V*<@V8+8J-F$
M(-BGV+(@V+G9A=F$VXS8I]BJ(-F&VJ_9A]BOV*?8L=N,(-BHV+'8I]N,(-BJ
MV*/;C-N,V*\@V*+9AB#8L]BFV8C8I]F$(-BTV8C8K]B?(`#8I]F&V*K8L]BG
MV*@@V+/8JMF(V8;9A]BG`-BSV+G;C"#8K]BQ(-BMV+#9@2#:K]BQV8C9A]N,
M(-BTV*_9AR#8I]BSV*H@VJG9AR#9A=F(V*S9B-BO(-F&VXS8L]BJ`-BSV+G;
MC"#8K]BQ(-BMV+#9@2#9A=BLV8C8LMN,(-BTV*_9AR#8I]BSV*H@VJG9AR#9
MA=F(V*S9B-BO(-F&VXS8L]BJ`-BSV+G;C"#8K]BQ(-F(VXS8L=BGVXS8M"#9
MA=BLV8C8LMN,(-BTV*_9AR#8I]BSV*H@VJG9AR#9A=F(V*S9B-BO(-F&VXS8
ML]BJ`-BSV+G;C"#8K]BQ(-F(VXS8L=BGVXS8M"#8I]BTV*K8L=BGVJG;C"#8
MM-BOV8<@V*?8L]BJ(-JIV8<@V879B-BLV8C8KR#9AMN,V+/8J@#B@(S9B-N,
MVIC:K]N,V8?8IP#8HMJOV8C8L]BJ`$%U=&A?8WER<W%L.B#8J-BSV+<@V879
MB-BQV*\@V8;;C-BGV+(@24U!4"#9OMN,V*_8IR#9AMBTV*\`075T:%]C>7)S
M<6PZ(-BSV*?9A=BGV8;9AR#9OMBTV*K;C-BHV*?9AB#9@MBGV*C9A-N,V*K9
MA]BGVXP@V879B-BQV*\@V8;;C-BGV+(@V+'8IR#9AMBOV*?8L=BO`$%U=&AI
M;7`Z(-BHV+/8MR#9A=F(V+'8KR#9AMN,V*?8LB!)34%0(-F^VXS8K]BG(-F&
MV+38KP!!=71H7V9T<#H@V*C8L]BW(-F%V8C8L=BO(-F&VXS8I]BR($944"#9
MOMN,V*_8IR#9AMBTV*\`075T:%]I;7`Z(-BHV+/8MR#9A=F(V+'8KR#9AMN,
MV*?8LB!)34%0(-F^VXS8K]BG(-F&V+38KP!!=71H7VMR8C4Z(-BHV+/8MR#9
MA=F(V+'8KR#9AMN,V*?8LB!K<F(U(-F^VXS8K]BG(-F&V+38KP!!=71H7VQD
M87`Z(-BHV+/8MR#9A=F(V+'8KR#9AMN,V*?8LB!,1$%0(-F^VXS8K]BG(-F&
MV+38KP!!=71H7VQD87`ZV*?8MMBGV8'9AR#:J=BQV*_9AB#:J=BGV+'8J-BQ
M("5S(-F%V87:J=F&(-F&VXS8L]BJ+B#8I]N,V88@VH;;C-BRVXP@V*?8L]BJ
M(-JIV8<@VJG8I]BQV+/8I]BR(-JOV8'8JMF'(-BGV+/8J@!!=71H7VQD87`Z
MV*W8L-F!(-JIV*?8L=BHV+$@)7,@V879A=JIV88@V8;;C-BSV*H@`$%U=&A?
M;&1A<#K8J-BQV8C8LMBQV+/8I]F&VXP@VJG8I]BQV*C8L2`E<R#9A=F%VJG9
MAB#9AMN,V+/8J@!!=71H7VUC86PZ(-BHV+/8MR#9A=F(V+'8KR#9AMN,V*?8
MLB!-0T%,(-F^VXS8K]BG(-F&V+38KP!!=71H7W-M8F%U=&@Z(-BHV+/8MR#9
MA=F(V+'8KR#9AMN,V*?8LB!S;6)A=71H(-F^VXS8K]BG(-F&V+38KP#8JMBU
MV*_;C-F"(-F'V8C;C-F1V*H@V8;8I]F%V8C9@=F1V8(@V*C9B-BO`-BJV+78
MK]N,V8(@V8?9B-N,V9'8JB#9AMBGV879B-F!V9'9@B#8J-F(V*\N("5S`-BJ
MV+78K]N,V8(@V8?9B-N,V9'8JB#8I]BR(-BWV+'9@2#:J=BGV+'8L]BGV+(@
M4D%$2553(-BQV*\@V+38K]F'(-BGV+/8J@#8JMBUV*_;C-F"(-F'V8C;C-F1
MV*H@V*_8L2#:J=BGV+'8L]BGV+(@1E10(-F&V*?9A=F(V8'9D=F"(-BHV8C8
MKR``V8';C-F$V*_9A]BGVXP@V8+8I]BHV80@V*_8L]BJV+'8L]N,.@#9OMBS
MXH",V++9A=N,V8;9AP#8L=F&VJ\@V;[8L^*`C-BRV87;C-F&V8<`V*?8L]F%
M(-BQV878LB#9AMBGV*_8L=BSV*H@:V5R8F5R;W,`V8;8I]F%(-JIV*?8L=BH
MV+$@V8;8I]BOV+'8L]BJ(&ME<F)E<F]S`$)A;'1I8R`H25-/+3@X-3DM,3,I
M`-BNV+<@V878J-F&V*<`V*C9A-F(VJD@(B5S(B#8I]BR(-BHV+'9AMBGV879
MA]F4(-JIV*?8L=BHV+'8K]N,("(E<R(@VXS8I]F!V*H@V8;8M-BO`-BJV8;8
MN-N,V878I]BJ(-BHV839B-JI`-F&V8C8N2#8J-F$V8C:J0#8L]N,V*?9AP#:
MAMF(V*@@V*?9A-F!`-F$V*C9AP#9OMF'V8;8I]N,(-F$V*C9ASH`V838J-F'
MXH",V8?8IP#9A]BQ(-BOV8@`V;[8I]N,VXS9A@#9A-N,V+/8JB#8J-F(V838
MJN*`C-BOV*?8L0!#35,`0U)#`-F&V8+8I]BW(-BJV8C8LMN,V+D@0U),`-BN
MV+79B-BUVXS8I]BJ(-BSV839B-F$+BXN`-BJV8+9B-N,V84`V*+8L=BGV84`
MV8;9A=N,XH",V*K9B-BGV88@V*?8L]F%(-BQV878LB#8L=BG(-BHV+?9B-BQ
M(-BNV8C8K]JIV*?8L2#8K]F(V*C8I]BQV8<@V*C8I]BRV8;8M-BGV8;8K]B,
M(-BHV*<@V+/8L=F^V+'8L]BJ(-BSV*?9A=BGV8;9AR#8KMF(V*\@V*K9A=BG
MV+,@V*C:K]N,V+';C-BO`-F&V87;C.*`C-BJV8C8I]F&(-BOV+$@V;[8L=F(
MV8;8K]F'("(E<R(@V8;9B-BTV*H`V8;9A=N,XH",V*K9B-BGV88@V*C9AR#:
MJ=BGV+'8L]BGV+(@V;[8L]BJ(-BGV83:J=BJV+'9B-F&VXS:J2#9A=BJV+79
MA"#8M-BO.B`E<P#9AMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@(B5S
M(B#8L=BG(-BHV*?8LB#:J=BQV*\`V*?9AMBUV+'8I]F!`-BGV8;8M=BQV*?9
M@2#8I]BR(-BGV+'8L]BGV80@VJ_8LMBGV+'8M`#9AMF%VXSB@(S8JMF(V*?9
MAB#9OMBQV8C9AMBOV8<@(B5S(B#8L=BG(-BMV+#9@2#:J=BQV*\@(`#9AMF%
MVXSB@(S8JMF(V*?9AB#;C-JI(-BTV*?8KMF'(-F%V8C9@MBJ(-F^VXS8K]BG
M(-JIV+'8KP#9AMF%VXSB@(S8JMF(V*?9AB#8J-BOV8C9AB#9OMBGV+'8I]F%
MV*K8L2`GV;[8L=F(V8;8K]F'(-F%V8+8M=BO)R#8I]BOV*?9A=F'(-BOV*?8
MKP#9AMF%VXSB@(S8JMF(V*?9AB#8M-BGV*[9AR`B)7,BV+'8IR#8K=BPV8$@
MVJG8L=BO(`#9AMF%VXSB@(S8JMF(V*?9AB#8K=BPV8$@V8;9A=F(V*_8C"`E
M9"#9@=BQV++9AMBO(-F%V8C8K-F(V*\@V*?8L]BJ`-F&V87;C.*`C-BJV8C8
MI]F&(-BOV8C8J-BGV+'9AR#9A=BQV*K8J"#9AMF%V8C8K]B,(-BHV+'8KMN,
M(-BGV+(@V8C8L=F(V*_;C-F'V*?;C"#9@=BQV*?9A]F%(-BTV*_9AR#8J-BQ
MV*?;C"#9A=BQV*K8J"#8L]BGV++;C"#8J-BG(-BTV878I]BQV8?B@(S9A]BG
MVXP@V+#8KMN,V+'9AR#8M-BOV8?8C"#8L]BGV++:K]BGV+$@V8;;C-BSV*H`
MV8;9A=N,XH",V*K9B-BGV88@V;[;C-BZV*?9A2#8L=BG(-BHV8<@V+39A=BG
MV+'9AR#8JMBYVXS;C-F&(-BTV*_9AR#:K]BPV+$@V*_8I]BO`-BYV8;9B-BG
MV88`V*W8I]F%V80`VJ_8L=F(V8?B@(S9A]BG(-F((-BHV+':AMBSV*C9A]BG
M`-F%V8C8J-BGVXS9A`#8KMBUV8C8M=N,V*?8JB#8L]F$V8C9A`#9@=BGV+79
MA-F'(-BSV839B-F$`-BNV+79B-BUVXS8I]BJ(-BSV839B-F$`-F!V*?8M=F$
MV8?B@(S:K]BPV*?8L=N,(-BSV839B-F$`-F%V8C8J-BGVXS9A`!#96QT:6,@
M*$E33RTX.#4Y+3$T*0#9A=BQVJG8L@!#96YT<F%L($5U<F]P96%N("A)4T\M
M.#@U.2TR*0#8K-BRV*;;C-BGV*H@VJ_9B-BGV8?;C"``V+/;C-BGV+/8JMF'
MV*?;C"#:K]F(V*?9A]N,`-BJV+K;C-N,V+$@`-BGV+/9A2#8L=F%V+(@V*[9
MB-BO(-BQV*<@V*K8NMN,VXS8L2#8K]F'VXS8KP#8JMBZVXS;C-BQV*_8I]BO
MV88@V8;8I]F%(-F((-BBV*_8L=BSVXP@VJG9AR#8I]F!V+'8I]BO(-F'V8;:
MK]BGV84@V*[9B-BGV8;8K]F&(-F((-F^V*?8L]BN(-BOV*?8K]F&(-BHV8<@
MV8;8I]F%V8?9E"#8M-F%V*<@V*[9B-BGV8?9AMBO(-BOVXS8KR``V*K8NMN,
MVXS8L=BOV*?8K]F&(-BGV+/9A2#8L=F%V+(@V+39A=BG(-BOV+$@V;[;C-JI
MV+'8J-F&V*_;C"#9@=BYV83;C"#9OMBTV*K;C-BHV*?9AMN,(-F&V87;C.*`
MC-BTV8C8KRX@V*C8IR#8L]BQV;[8L=BSV*H@V+/8I]F%V*?9AMF'(-BNV8C8
MKR#8JMF%V*?8LR#8J-JOVXS8L=N,V*\`V8;9B-N,V+/9AP#8J-BQV+'8L]N,
M(-F^VXS9B-F&V*\N+BX`XH",`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R
M*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0#8I]F&V*K8KMBGV*@@VXS:
MJ2#8I]BSV84@V+'9A=BR`-BGV8;8JMBNV*?8J"#;C-JI(-F&V*?9A2#:J=BG
MV+'8J-BQVXP`V*?9AMBJV*[8I]BH(-J&VJ_9B-F&VJ_;C"#9AMF%V*?;C-BT
M(-BJV*?8L=N,V*XZ`-BGV8;8JMBNV*?8J"#9AMF(V+D@V+/8J-JI(-F!V8?8
ML=BSV*H@*-BHV+'8I]N,(-F!V8?8L=BSV*K9A]BGVXP@V878L=BJV*@I`-BJ
MV+G8L=N,V8$@VJG9A-BGV+,@)7,@VXS8I]F!V*H@V8;8M-BO`-BUV*?9@0#9
MOMBGVJD@VJG8L=BOV88@V*K:K]F'V*?;C"!-4T]F9FEC90#9OMBGVJD@VJG8
ML=BOV88@VJG8I]BQV*C8L2`Z("5S`-F^V*?:J2#:J=BQV*_9AB#:J=BGV+'8
MJ-BQ`-F^V*?:J2#:J=BQV*_9AB#8K]BGV*_9A]F4(-JIV*?8L=BHV+$`V*C8
ML=BGVXP@V*?8K]BGV879A]B,(-JIV83;C-JI(-JIV8;;C-BO`$-L:6-K871E
M;&P@V*?8LB#8M]BQVXS9@B!(5%10`-BHV+/8JMF&(-F^V8;8K-BQV8<`V*?8
MJ-BQV8?8IP#8I]BHV+';C`#8K-F%V+D@V+38K]F&(-F&V8C8I]BQ(-JIV8;8
MI]BQVXP`VH;9A=BY(-BTV*_9AB#9A-BHV8?B@(S9A]BG`-BQV8;:KP#8I]F&
MV*K8KMBGV*@@VJG9AMF&V*_9AR#8L=F&VJ\`V*?9AMBJV*[8I]BH(-BQV8;:
MKP#8L]BJV8C9AMF'V*<Z`-BYV8;8I]F(VXS9AB#8L]BJV8C9AMF'V*<`V878
MMMBMVJD`V8'8L=F%V*?9A@#9OMF(V+/8JMF'(-F!V+'9A=BGV88`V*K9B-BV
MVXS8K0#9AMBGV84@V+G9A=F(V87;C`#8M-BQVJG8J@#8L=BGVXS8I]F&V8?B
M@(S9A]BG`-BTV+'8MP#8M-BQV*?;C-BW`-BJV8'8I]F(V*K9A]BGVXP@V;[;
MC-JIV+'8J-F&V*_;C`#9OMN,VJG8L=BHV8;8K]N,("5S`-BJV*/;C-N,V*\@
MV*?8L]F%(-BQV878L@#8I]BJV+78I]F$(-F&V*?9A=F(V8'9D=F"(-BHV8C8
MKP#8I]BJV+78I]F$(-F&V*?9A=F(V8'9D=F"(-BHV8C8KP#8I]BJV+78I]F$
M(-BHV8<@VJG8I]BQV+/8I]BR(-JIV83;C-BO(-BYV879B-F%VXP@V+'8KR#8
MM-BO`-BGV*K8M=BGV80@V*C9AR#:J=BGV+'8L]BGV+(@VJG9A-N,V*\@V+G9
MA=F(V87;C"#8L=BO(-BTV*\N(-BOV83;C-F$.B`E<R`H)7,I`-BGV*K8M=BG
MV80@V*C9AR#:J=BGV+'8L]BGV+(@1E10(-F&V*?9A=F(V8'9D=F"(-BHV8C8
MKP#9AMF%V*?8L]F'V*<`V*K9A=BGV+/9A]BG(-BHV*<@V879B-F!V9'9@MN,
MV9'8JB#8J-F'(-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS(-BTV878IR#8I]BV
MV*?9@=F'(-BTV*_9AR#8J-F(V*\`V*?8K]BGV879AP#:J=F(VJG;C`#8L=F(
MV8;9B-BTV*H`V+'9B-F&V8C8M-BJ(-BHV+'8K]BGV+38JMF&(-BGV+(@V*C8
MKMBT(-BGV8;8JMBNV*?8J-N,`-F&V87;C.*`C-BJV8C8I]F&V*\@V;[;C-BZ
MV*?9A2#8L=BG(-BQV878LMBHV8;8K]N,(-JIV8;8KR!01U``V8;9A=N,XH",
MV*K9B-BGV8;8KR#9OMN,V+K8I]F%(-BQV*<@V*?9A=BVV*?8H2#:J=F&V*\@
M4$=0`-F&V87;C.*`C-BJV8C8I]F&V*\@V;[;C-BZV*?9A2#8L=BG(-BQV878
MLMBHV8;8K]N,(-JIV8;8KR!3+TU)344`V8;9A=N,XH",V*K9B-BGV8;8KR#9
MOMN,V+K8I]F%(-BQV*<@V*?9A=BVV*?8H2#:J=F&V*\@4R]-24U%`-F&V87;
MC.*`C-BJV8C8I]F&(-BJV878I]BSV8?8IR#8L=BG(-BGV+;8I]F!V8<@VJG8
ML=BO("5S`-F&V87;C.*`C-BJV8C8I]F&(-BHV8<@VJG8I]BQV+/8I]BR($Q$
M05`@V;[;C-F(V+/8JB``V8;9A=N,XH",V*K9B-BGV88@V*C9AR#:J=BGV+'8
ML]BGV+(@;&1A<"#9OMN,V8C8L]BJ`-F&V87;C.*`C-BJV8C8I]F&(-BHV*?9
MA-BGV8;8LR#8L=BG(-J&VJD@VJG8L=BO("5S`-F&V87;C.*`C-BJV8C8I]F&
M(-BHV8<@VJG8I]BQV+/8I]BR(&QD87`@V878JMBUV80@V+38KP#9AMF%VXSB
M@(S8JMF(V*?9AB#9@=F'V+'8L]BJ(-BJV8C8LMN,V+G;C"#8I]N,V*S8I]BO
M(-JIV+'8KRX@)7,`V8;9A=N,XH",V*K9B-BGV88@V*_8I]BOV8<@4$=0(-BQ
MV*<@V+'9A=BRVJ_8M-BGVXS;C"#9AMF%V8C8KR``V8;9A=N,XH",V*K9B-BG
MV88@V*_8I]BOV8<@4R]-24U%(-BQV*<@V+'9A=BRVJ_8M-BGVXS;C"#9AMF%
MV8C8KR``V8;9A=N,XH",V*K9B-BGV88@V*K9A=BGV+,@V+'8IR#8K=BPV8$@
MV8;9A=F(V*\N("5S`-F&V87;C.*`C-BJV8C8I]F&(-F!V8?8L=BSV*H@V*K9
MB-BRVXS8N=N,(-BQV*<@V*W8L-F!(-F&V879B-BO+B`E<P#9AMF%VXSB@(S8
MJMF(V*?9AB#8HMBOV+'8LR#:K]N,V+'9AMBOV8<@V8;8I]F%V8?9E"#8I]F$
MVJG8JMBQV8C9AMN,VJG;C"#8L=BG(-BJV+38KMN,V+4@V*_8I]BO`-F&V87;
MC.*`C-BJV8C8I]F&(-JIV80@VJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@V+'8
MIR#9B-BGVJG8M-N,(-F&V879B-BO`-F&V87;C.*`C-BJV8C8I]F&(-JIV80@
MV8'9A]BQV+/8JB#8JMF(V++;C-BYVXP@V+'8IR#9B-BGVJG8M-N,(-F&V879
MB-BO`-F&V87;C.*`C-BJV8C8I]F&(-F!V8?8L=BSV*H@VJG8I]F%V80@V8'9
MA]BQV+/8JB#8JMF(V++;C-BYVXP@V+'8IR#9B-BGVJG8M-N,(-F&V879B-BO
M`-F&V87;C.*`C-BJV8C8I]F&(-JIV83;C-BO(-BYV879B-F%VXP@V+'8IR#8
MI]BR(-JIV*?8L=BSV*?8LB#:J=F$VXS8KR#8J-BOV+/8JB#8HMF(V+'8KP#9
MAMF%VXSB@(S8JMF(V*?9AB`E<R#8L=BG(-BHV*?8LB#:J=BQV*\`V8;9A=N,
MXH",V*K9B-BGV88@V878K]F(V80@V8C8N-BGVXS9@2#9AMJOV8?8K]BGV+';
MC"`E<R#8L=BG(-BHV*?8LB#9AMF%V8C8KP#9AMF%VXSB@(S8JMF(V*?9AB`E
M<R#8L=BG(-BNV8C8I]F&V*\`V8;9A=N,XH",V*K9B-BGV88@V*?8L]F%(-BQ
MV878LB#8L=BG(-BHV+'8I]N,(-JIV*?8L=BHV+$@V879B-BQV*\@V8;8N-BQ
M(-BHV*?8LMF&V+38I]F&V*\N(-BHV+G8MMN,(-N,V*<@V8?9A=F'(-BLV++8
MIMN,V*?8JB#9A=BQV*C9B-BW(-BHV8<@V*+9AB#9AMBGV*_8L=BSV*H@V87;
MC.*`C-BHV*?8M-BO+B#8K]F(V*C8I]BQV8<@V+/8N=N,(-JIV8;;C-BO(-N,
MV*<@V*C8L=BGVXP@VJG9A=JI(-BHVXS8M-BJV+$@V*C8IR#8L]BQV;[8L=BS
MV*H@V+/8I]F%V*?9AMF'(-BNV8C8KR#8JMF%V*?8LR#8J-JOVXS8L=N,V*\`
MV8;9A=N,XH",V*K9B-BGV88@04-,(-BQV*<@V*_9B-BHV*?8L=F'(-BHV*_8
ML]BJ(-BBV8C8L=BO`-F&V87;C.*`C-BJV8C8I]F&(-JIV*K8I]BHVH;9A]F4
M(-BBV*_8L=BS(-BQV*<@V*_9B-BHV*?8L=F'(-BHV*_8L]BJ(-BBV8C8L=BO
M+B`E<P#9AMF%VXSB@(S8JMF(V*?9AB#9@=F'V+'8L]BJ(-BJV8C8LMN,V+G;
MC"#8L=BG(-BOV8C8J-BGV+'9AR#8J-BOV+/8JB#8HMF(V+'8KRX@)7,`V8;9
MA=N,XH",V*K9B-BGV88@V8'9A]BQV+/8JB#8JMF(V++;C-BYVXP@V+'8IR#8
MK]F(V*C8I]BQV8<@V*C8K]BSV*H@V*+9B-BQV*\N("5S`-F&V87;C.*`C-BJ
MV8C8I]F&(-F"V*?8J-F$VXS8JMF'V*?;C"#:J=BGV+'8L]BGV+(@V+'8IR#8
MK]F(V*C8I]BQV8<@V*C8K]BSV*H@V*+9B-BQV*\`V8;9A=N,XH",V*K9B-BG
MV88@V;[;C-JIV+'8J-F&V*_;C"#8L=BG(-BHV*?8LMJOV+'8K]BGV8;8KP#9
MAMF%VXSB@(S8JMF(V*?9AB#9OMN,VJG8L=BHV8;8K]N,("5S(-BQV*<@V*_8
MKMN,V+'9AR#:J=BQV*\`V8;9A=N,XH",V*K9B-BGV88@V;[;C-JIV+'8J-F&
MV*_;C"#9OMBTV*K;C-BHV*?9AB#8L=BG(-BMV8'8N"#:J=BQV*\`V8;9A=N,
MXH",V*K9B-BGV88@V;[;C-JIV+'8J-F&V*_;C"#9OMBTV*K;C-BHV*?9AB#8
ML=BG(-BMV8'8N"#:J=BQV*\Z("5S(`#9AMF%VXSB@(S8JMF(V*?9AB#9OMBQ
MV8C9AMBOV8<@V;[8M-BJVXS8J-BGV88@V;[;C-JIV+'8J-F&V*_;C"`E<R#8
ML=BG(-BMV8'8N"#:J=BQV*\`V8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8
MK]F'(-F^VXS:J=BQV*C9AMBOVXP@)7,@V+'8IR#8K=F!V+@@V8;9A=F(V*\N
M(-BTV878IR#9A=N,(-BJV8C8I]F&VXS8KR#8I]BR(-N,VJG;C"#8I]BR(-JO
MV++;C-F&V8?B@(S9A]BG(-BHV+'8I]N,(-BMV8'8N"#:J=BO(-BHV+$@V+'9
MB-N,("5S(-BGV+/8JMF!V*?8K]F'(-F&V878I]N,VXS8KR#9B"#;C-BG(-BG
MVXS9AMJIV8<@V*?8LB#:J=BO(-BHV8<@V+79B-BQV*H@V*_8L]BJVXP@V*_8
ML25S(-BQV8C9AMF(V+38JB#8JMF'VXS9AR#9AMF%V*?;C-N,V*\`V8;9A=N,
MXH",V*K9B-BGV88@VJG8I]BQV+/8I]BR($Q$05`@V+'8IR#8K-BSV*K8K-F(
M(-JIV+'8KP#9AMF%VXSB@(S8JMF(V*?9AB#8JMF%V*?8LR`@V+'8IR#8J-BQ
MV8C8LMBQV+/8I]F&VXP@VJG8L=BO+B`E<P#9AMF%VXSB@(S8JMF(V*?9AB#9
M@=F'V+'8L]BJ(-BJV8C8LMN,V+G;C"#8L=BG(-BHV+'9B-BRV+'8L]BGV8;;
MC"#:J=BQV*\N("5S`-F&V87;C.*`C-BJV8C8I]F&(-F&V8C8I]BQ(-BLV*?9
MAMBHVXP@V879B-BRVXS9A-BG(-BQV*<@V;[;C-BOV*<@VJG8L=BO+B#9A=BW
MV878IMF&(-BTV8C;C-BO(-JIV8<@V8;9B-BGV+$@V*S8I]F&V*C;C"#8J-BG
MV+(@V*?8L]BJ`-F%V*K9AB#8M-F%V*?8L=BT(-BTV*_9AP#:J=BTV8C8L0#8
MK]F(V+'9A^*`C-F'V*<`V*?;C-BLV*?8KP#8I]N,V*S8I]BO(-N,VJD@V;[;
MC-F(V8;8KP#8I]N,V*S8I]BO(-N,VJG;C"#8K-BOVXS8KP#8I]N,V*S8I]BO
M(-BRVXS8L=F^V8C8M-F'XH",V8?8IP#9A=BLV8C8LMF'V*?;C"#8I]N,V*S8
MI]BO(-JIV8;9AMBOV8<`V+39A=BGV+'9AR#:J=BGV+'8JB#8I]BYV*K8J-BG
MV+';C`#8L]BGV+G8JB#9@=BYV83;C`!54DP@V8'8N=F$VXP@V8?8L]BJ`-BB
MV*@@V8@@V8?9B-BGVXP@V8'8N=F$VXP`V+38L=BGVXS8MR#9@=BYV83;C#H@
M`-BSV*C:J2#9@=BYV83;C`#8L]F!V*?8L=BTVXP@VJG8L=BOV88@V8C8N-BG
MVXS9@2#9A]F&VJ_8I]F%(-F(V+'9B-BO(-BHV8<@)7,`V*C8L=N,V*_9A@#8
MJ-BQVXS8K]F&(-BGV8;8JMBNV*?8J`!#>7)I;&QI8R`H2T])."U2*0!#>7)I
M;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M
M52D`1$0`V+'9B-BRV*?9AMF'`-F%V+'9B-BQVJ_8L2#8K]BQV*[8JB#8K]BG
MV*_9AP#8JMBGV+';C-BN`-BJV*?8L=N,V*X@V*_8L=N,V*?9@=BJ(-BTV*_9
MAP#8JMBGV+';C-BN(-BGV8;8JMBNV*?8J`#8L=F(V+(`V*W8L-F!(-BSV*K9
MB-F&`-BOV+/8I]F%V*C8L0#8I]BYV*_8I]BO(-BOV8?8K]F'VXP`VJG9A2#:
MJ=BQV*_9AB#8JMF(V+'9@=BJVJ_;C`#9OMN,V+0@V8'8L=BV`-BQV8;:KR#9
MOMN,V+0@V8'8L=BV`-F'V8C;C-F1V*H@V;[;C-BT(-F!V+'8M@#9OMF(V+/8
MJMF'V90@V;[;C-BT(-F!V+'8M@#8JMBYV*?8L=N,V8$`V*W8L-F!`-BMV+#9
M@2#:K]BQV8C9AP#8K=BPV8$@V878K-F(V+(`V*W8L-F!(-F((-F^V*?:J=BS
MV*?8LMN,(-F^VXS8NMBGV879A]BG`-BMV+#9@2#8L]F$V8C9A`#8K=BPV8$@
MV+/8JMF(V88`V*W8L-F!(-BGV83:K]F(VXP@V*S8I]N,VJ_8LMN,V88@V879
MB-BLV8C8KP#8K=BPV8$@V878K-F(V++9A]BG(-BHV+'8I]N,("`B)7,B`-BB
MVXS8IR#9A=BLV8C8LMF'V*<@V8@@V++;C-BQV878K-F(V++9A]BG(-BHV+'8
MI]N,("(E<R(@V*W8L-F!(-BTV8C8K]B?`-BMV+#9@2#8L]BWV+$`V*W8L-F!
M(-F'V8C;C-F1V*H@V*?9AMBJV*[8I]BH(-BTV*_9AP#8K=BPV8$@V+/8JMF(
MV88@V8'8N=F$VXP`V*W8L-F!(-BSV+?8L2#9@=BYV83;C`#8LMF%V*?9AB#8
MI]BQV+/8I]F$`-BTV+'8K2#9A=BTVJG9A`#8JMF(V+;;C-BM`-BLV++9D-BF
MVXS8I]BJ.@`@V*S8LMBFVXS8I]BJ(-BHV+'8I]N,(-BSV+'9OMBQV+/8JB#8
ML]BGV878I]F&V8<@V*O8J-BJ(-BTV*_9AR#8I]BSV*H`VJ_8L]BJV+'8M`#9
MAMF"V+?9AR#8M-BHV8;9A0#9AMF"V+?9AR#8M-BHV8;9A2#8J-BQV*?;C"#8
ML]BGV+G8JB#:K]BPV+38JMF'.B``V8;9@MBWV8<@V+38J-F&V84Z(`#8K-F'
MV*H@V*?8LB#:AMF^(-BHV8<@V+'8I]BSV*H`V*S9A]BJ(-BGV+(@V+'8I]BS
MV*H@V*C9AR#:AMF^`-BTV*?8KMF'`-BBVXS8IR#8LMF%V*?9AB`R-"#8L]BG
MV+G8JMF'(-F&V878I]N,V+0@V*_8I]BOV8<@V+39B-BOV)\`VJ_8LMN,V8;9
MA^*`C-F'V*?;C"#9AMF%V*?;C-BT`-F&V878I]N,V+0@V*S8LMBFVXS8I]BJ
M(-F^VXS8M,*MV*C;C-F&VXP`V8;9A=BGVXS8M"#9OMN,V+3"K=BHVXS9AMN,
M`-F&V878I]N,V+0@V8+8I]F$V*@`V*W8I]F$V*H@V*K8L-JIV+$`V*W8L-F!
M(-F&V+39B-BO`-BOV+/8JMBQV+/;C"#9A=BSV*K9@MN,V84@V*C9AR!M86EN
M=&5N86YC92YP:'`@V879A=JIV88@V8;;C-BSV*H`V*+;C-BG(-BSV+?8L2#8
MI]F(V80@V+38I]F%V80@V8';C-F$V*\@V8;8I]F%(-F%VXSB@(S8J-BGV+38
MK]B?(-BGVJ_8L2#:AMF&VXS9AB#8I]BSV*K8C"#8I]N,V88@V*S8N=BHV8<@
MV+'8IR#8N=F$V*?9A=BJ(-BHV++9AMN,V*\Z`-BGV+/8JMF"V+'8I]BQ`-BG
MV+/8JMF"V+'8I]BQ("5S`-BGV+/8JMF"V+'8I]BQ(-F^VXS:J=BQV*C9AMBO
MVXP@V*K9B-F$VXS8KR#8M-BOV8<@V*C8N=F&V8C8I]F&(-BOV+/8JB#9AMF(
MVXS8LR!02%``V8'9A]BQV+/8JB#9OMBGVXS;C-F&XH",V;[8L0#8K]BGV+'9
MB-F'V*<`V8;8I]F%V8<@V*?9A-JIV*K8L=F(V8;;C-JIVXP`15)2`-F(VXS8
ML=BGVXS8M`#9B-N,V+'8I]N,V+0@V*C9A-F(VJD`V8C;C-BQV*?;C-BT(-JO
MV+'9B-F'`-F(VXS8L=BGVXS8M"#9A=BLV8C8L@#9B-N,V+'8I]N,V+0@V878
MK-F(V++9A]BG`-F(VXS8L=BGVXS8M"#9A=BLV8C8LMF'V*<@V*C8L=BGVXP@
M)7,`VJ_8LMN,V8;9A^*`C-F'V*?;C"#9B-N,V+'8I]N,V+0Z`-F(VXS8L=BG
MVXS8M"#9A=BLV8C8LN*`C-F'V*<@V*C8L=BGVXP@(B5S(@#9B-N,V+'8I]N,
MV+0@V878K-F(V++B@(S9A]BG(-BHV+'8I]N,("5S`-BJV*W8M=N,V838I]BJ
M`-BYV8;8M=BQ+BXN`$5M`-F&V*?9A=F'(-BGV83:J=BJV+'9B-F&VXS:J=N,
M`-BBV*_8L=BS(-F&V*?9A=F'V90@V*?9A-JIV*K8L=F(V8;;C-JIVXP`V*+8
MK]BQV+/9A]BGVXP@V8;8I]F%V8?B@(S9A]BGVXP@V*?9A-JIV*K8L=F(V8;;
MC-JIVXP@V*C8I]N,V*\@V879AMBWV*C9@B#8J-BGV+38KP#9AMBGV879A]F4
M(-BGV83:J=BJV+'9B-F&VXS:J=N,(-BHV*<@V*K8H]N,VXS8KP#8I]BMV+/8
MI]BSV*?8J@#8KMBGV83;C"#:J=BQV*_9AB#9OMN,V+K8I]F%(`#8KMBGV83;
MC"#:J=BQV*_9AB#9AMBJVXS8K-F'`-BNV*?9A-N,(-JIV+'8K]F&(-F%V8C8
MI]BQV*\@V*S8L]BJV*S9B`#8HMN,V*<@V*_8L=BL(-BJV+78I]F(VXS8L2#8
MI]BR(-JOV*?9A-BQVXS9A]BGVXP@V+G:J=BS(-BOV+$@V878JMF&(-F!V+G8
MI]F$(-BTV8C8K]B?`-BBVXS8IR#:K]BRVXS9AMJOV*?9AB#8LMF%VXS9AMF'
M(-BQV8C;C"#:J=F$VXS:J2#8L=BGV+/8JB#9@=BYV*?9A"#8M-F(V*_8GP#8
MI]F&V*K9A]BGVXP@V+/8I]F$`-BHV++8L=JO(-JIV+'8K]F&(-F(VXS8L=BG
MV+/8JMBGV+$`VXS:J2#8L]BFV8C8I]F$(-BGV879AMN,V*K;C"#8J-BQV*?;
MC"#9OMBQV+/8M"#8I]BR(-BTV878IR#8J-F'(-F'V8;:K]BGV84@V*C8I]BR
MV8;8M-BGV8;8K]F&(-BGV+/9A2#8L=F%V+(@V8C8I]BQV*\@VJG9AMN,V*_8
MC"#9A=BKV838I]F2("?9AMBGV84@V*W;C-F(V*?9AB#8KMBGV8;:K]N,(-BT
MV878IR#:AMN,V+/8JMB?)P!54DP@V*K8M=F(VXS8L2#8L=BG(-BGVXS9AMBL
MV*<@V8C8I]BQV*\@VJG9AMN,V*\`V*[8M]BG`-BHV839B-JI(-BGVXS8K-BG
MV*\@V*[8M]BG.B`E<P#8KMBWV*<@V*_8L2#:J=BSV*@@V878K=BJV8C8ISHE
M<P#8KMBWV*<@V*_8L2#8J-BQV8C8LMBQV+/8I]F&VXP@V*?8L]F%(-BQV878
MLB`Z("5S`-BNV+?8IR#8J-BG(-F^VXS8NMBGV84@V8;8I]F%V8?9E"#8I]F$
MVJG8JMBQV8C9AMN,VJG;C`#8N=BJVXS9@MF'`-BGV+'9B-F^V*<`V8?8L2#9
MOMBGV8;8LMBOV8<@V*_9@MN,V8+9AP#9A]BQ(-BOV8@@V*_9@MN,V8+9AP#9
MA]BQ(-BSVXP@V*_9@MN,V8+9AP#9A]BQ(-F^V8;8K"#8K]F"VXS9@MF'`-BO
MV+$@V8?8L2#9B-BQV8C8KP#9A]BQ(-F&VXS9A2#8L]BGV+G8J@#9A]BQ(-BO
MV8+;C-F"V8<`V879@MBGV*_;C-BQ(-F%V*O8I]F$.@#8I]BLV+'8IP#8J-BG
MV+(@VJG8L=BOV88`V*C8I]BRVJG8L=BOV88@V8;9B-BGV+$@VJG9AMBGV+';
MC`#8I]F&V*K8N-BGV+$@V*C8L=BGVXP@)R@G`-BJV*?8L=N,V*X@V*?9AMF"
MV+;8I]BA`-F&V878I]N,V8;8K]F'`-BQV8;:KR#9OMN,V+3B@(S8LMF%VXS9
MAMF'`$944"!U<&QO860@;V8@<V5T=7``(-BHV*?8LMN,V*?8J-N,(-BJV8+8
MK]F%V*?8JB#9AMBGV879B-F!V9'9@B#8J-F(V*\`(-BGV*K8M=BGV80@V*C9
MAR#:J=BGV+'8L]BGV+(@3$1!4"#9AMBGV879B-F!V9'9@B#8J-F(V*\`(-BG
MV*K8M=BGV80@V*C9AR#:J=BGV+'8L]BGV+(@4TU"(-F&V*?9A=F(V8'9D=F"
M(-BHV8C8KR``(-BJV8?;C-F'(-BQV8C9AMF(V+38JB#8I]BR("(E<R(@V8;8
MI]F%V8C9@=F1V8(@V*C9B-BO`-BGVXS8K-BGV*\@V+'9B-F&V8C8M-BJ(-BO
MV+$@(B5S(B#9AMBGV879B-F!V9'9@B#8J-F(V*\`(-BGVXS8K-BGV*\@VXS:
MJ2#8I]BJV+78I]F$(-BLV*_;C-BO(%-!4TP@V8;8I]F%V8C9@=F1V8(@V*C9
MB-BO`"#8I]F&V*K9@MBGV80@V*C9AR`B)7,B(-F&V*?9A=F(V8'9D=F"(-BH
MV8C8KP#9A-BWVXS9@0#8KMBWV*?;C"#8K-BOVXPZ(`#9@=JIV+,`V8'9B-BQ
MVXS9AP#8L=JOV*C8I]BQ(-BNV8';C-F!`-JIV87;C"#8JMJOV+':KP#8M-F%
MV*?8L=BT(-F^V+'9B-F&V*_9ASH@)7,@V;[8L=F(V8;8K]F'`-BTV878I]BQ
MV+0@V;[8L=F(V8;8K]F'.B`E<R#9OMBQV8C9AMBOV8<`V878K]N,V+$@V;[8
ML=F(V8;8K]F'`-F&V*?9A2#9OMBQV8C9AMBOV8<`V*?9AMBJV*[8I]BH(-F^
MV+'9B-F&V*_9AP#8I]BQV+/8I]F$(-F^V+'9B-F&V*_9AP#8I]BQV+/8I]F$
M(-F^V+'9B-F&V*_9AR#9OMBTV*K;C-BHV*?9AMN,(-F&V87;C.*`C-BTV8C8
MKRXN`-F!VXS9A-BJV+'9A]BG`-F&VXS9A=F'(-BGV8C9A`#8L=BHV+D@V*?9
MB-F$`-F&V+/8J-BJ(-BKV*?8J-BJ`-BGV+G8M-BGV+';C`#9A=F'XH",V*+9
MA-F(V*\`V;[9B-BTV8<@)7,@V879B-BLV8C8KR#9AMN,V+/8JB``V+'9AMJO
M(-F"V839A0#8NMBPV*<`V*C8L=BGVXP@V878L=F(V+':K]BQV8?8I]N,VXP@
MVJG9AR#8JMBUV*?9B-N,V+$@V+'8IR#9OMBTV*K;C-BHV*?9AMN,(-F&V87;
MC.*`C-JIV8;9AMBO`-F^VXS8M,*MV*C;C-F&VXP`V*?8L]F%(-BQV878LB#8
MKMF(V*\@V+'8IR#9@=BQV*?9A=F(V+0@VJG8L=BOV8?B@(S8I^*`C-N,V*_8
MGP#9@=BQV879A]BG`-BWV*?9A-BY`-F&V8C8N2#8M]BGV838N0#8M]BGV838
MN=F'V*<`V+?8I]F$V+G9A]BG(-NR`-BGV8;8K-F%V8;9A]BG`-BGV+'8K-BG
MV+G9A]BG`-BLV878N=F'`-J&V*?8L=J&V8C8J-F'V*<`V*?8L@#8I]BR(`#8
MM-BQV*T@VJG8I]F%V80`V878I]F'(-JIV*?9A=F$`-F&V*?9A2#:J=BGV879
MA`#:K]BGV838L=N,(-BHV+'8I]N,(-BOV+';C-BGV8'8JB#8JMBUV8C;C-BQ
M(`#:K]BGV838L=N,.@#8JMF(V83;C-BO(-F^VXS:J=BQV*C9AMBOVXP@)7,`
MVJG8KR#8JMF(V83;C-BO(-BTV*_9AP#9AMBGV84@V*_8I]BOV8<@V+38K]F'
M`-BHV+'9B`#8K-BSV8;8K-F(VXP@VJ_9B-JOV80`V*_8L=BLV8<@V*[8I]JI
MV+/8JMBQVXP`1W)E96L@*$E33RTX.#4Y+3<I`-BSV+'9OMBQV+/8JMN,(-JO
MV+'9B-F'`-F&V*?9A2#:K]BQV8C9AR#9AMBHV*?;C-BO(-BNV*?9A-N,(-BH
MV*?8M-BO`-JOV+'9B-F')B-X,C`P8SO9A]BG`-F%V*S9B-BRV8?8I]N,(-F%
MV8?9A=BGV88`VJG8JMBGV*C:AMF'V90@VXS8I]BOV*C9B-BO`$A434P`2%1-
M3$%R96$@V*W8L-F!(-BBV*[8L=N,V88@V+/9A-F(V80@V+'8IR#8K]BQ(-BQ
MV*_;C-F!(-BQV*\@V87;C.*`C-JIV8;8KP!(5$U,07)E82#8K=BPV8$@V*+8
MKMBQVXS9AB#8L]BJV8C9AB#8L=BG(-BOV+$@V*S8K]F(V80@V+'8KR#9A=N,
MXH",VJG9AMBO`$A434Q!<F5A(-BMV+#9@2#8HMBNV+';C-F&(-BQV*_;C-F!
M(-BQV*<@V*_8L2#8K-BOV8C9A"#8L=BO(-F%VXSB@(S:J=F&V*\`V*K8M=BO
MVXS9@B#9A]F(VXS9D=BJ($A45%`@VXS8I]F!V*K9AR#9AMBTV*\`V*?9A-JO
MV8C8L=N,V*K9A2!(87-H`-F%V8?B@(S8HMF$V8C8KP#8L]BQV*+9A=BO`$AE
M8G)E=R`H25-/+3@X-3DM."U)*0#8J-F$V8;8K]N,`-BQV*?9A]F&V878IP#8
ML=BGV8?9AMF%V*?;C"#8I]BSV*K9@=BGV*_9AR#8I]BR(-F(VXS8L=BGVXS8
MM-JOV+$`VJG9A=JI(-JIV8;9AMBOV8<`V8;;C-F%XH",VJG8L=F'`-BGVXS9
MAMBLV*<@V*?8J-BJV*_8I]N,(-F^V+'9B-F&V*_9A^*`C"#9A=N,XH",V*C8
MI]BTV*\Z`-BHV*?9A-BG`-BNV*?9AMF'`-BNV*?9AMF'`-BBV*_8L=BS(-BN
MV*?9AMF'`-BTV*?8KMF'V90@V*?8M=F$VXP`V+39A=BGV+'9AR#8JMF$V8'9
MAB#9A=F&V++9A`#9A]F(V+'8KP!(;W)D92]+;VQA8CH@)7,@V*C8IR#8K]BG
MV*_9AR#9AMBGV*_8L=BSV*H@6$U,(-BOV+$@V;[;C-BZV*?9A2`E<R#9A=F(
MV*?8K-F'(-BTV*_9AR#8I]BSV*H`2&]R9&4O2V]L86(Z(-F'VXS:AB#9OMN,
MV+K8I]F%VXP@V878M]BGV*C9@MBJ(-BHV*<@V+3;C-BA("5S(-F&V*_8I]BQ
MV*\`2&]R9&4O2V]L86(Z(-F'VXS:AB#8M-N,V*;;C"#8I]BR(-F&V8C8N2`E
M<R#8K]BQ(-F^VXS8NMBGV84@)7,@VXS8I]F!V*H@V8;8M-BO`$AO<F1E+TMO
M;&%B.B#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@)7,@(B5S(B#8K=BPV8$@V+38
MKP!(;W)D92]+;VQA8CH@V*K9B-F$VXS8KR#;C-JI(-BOV+'8KMBJ(-BLV*_;
MC-BO(%A-3"#8J-BQV*?;C"#8M-N,V*$@)7,@V879@MBOV8C8L2#9AMN,V+/8
MJB``2&]R9&4O2V]L86(Z(-BMV+#9@2`E<R`B)7,B.B5S(-F%V8+8K]F(V+$@
MV8;;C-BSV*H`2&]R9&4O2V]L86(Z(-BHV*?8LMN,V*?8J-N,("!-24U%($E$
M(-BHV+'8I]N,(-F"V+/9A=BJVXP@V*?8LB#9AMF(V+D@)7,@V879@MBOV8C8
ML2#9AMN,V+/8JB``2&]R9&4O2V]L86(Z(-BSV8;:J=BQV8C9AB#:J=BQV*_9
MAB`E<R`B)7,B.B`E<R#9A=F"V*_9B-BQ(-F&VXS8L]BJ`$AO<F1E+TMO;&%B
M.B#8L]F&VJG8L=F(V88@VJG8L=BOV88@V*?8M-BJV+'8I]JIV8?8IR#9A=F"
MV*_9B-BQ(-F&VXS8L]BJ.B`E<P!(;W)D92]+;VQA8CH@V*?8M-BJV+'8I]JI
M(-F&V*?8M-F&V*?8KMBJV8<@(B5S(@#9@MBGV8;9B-F&(-BGV8'9@MN,`-F!
MV*?8M=F$V8?B@(S:K]BPV*?8L=N,(-BGV8'9@MN,`#K8I]F!V8+;C`#:AMJO
MV8C9AMF'(-BHV*<@V*?;C-F&V*S8IR#8HMBTV8;8IR#8M-BOVXS8K]B?("C9
MA-BWV8'8I]F+(-JOV++8I]BQV+0@V*_9A]N,V*\I(0#:AMF&V*\@V+/8JMF(
MV88@V+'8IR#9A=N,XH",V*[9B-BGV8?;C-BO(-BGV*_8NMBGV84@VJG9AMN,
MV*_8GP#:AMF&V*\@V8';C-F$V*\@*-BSV*K9B-F&*2#9B-BLV8C8KR#8K]BG
MV+'8K]B?`-J&V8;8KR#8L]BWV+$@V+'8IR#9A=N,XH",V*[9B-BGV8?;C-BO
M(-BGV*_8NMBGV84@VJG9AMN,V*_8GP#8L=BWV8C8J-BJ`-BQV+?9B-BHV*HZ
M(`#8I]N,V*S8I]BO(-F&V*?9A=F'XH",V*_8I]F&($E-05`@V8;8I]F%V8C9
M@=F1V8(@V*C9B-BO.B`@)7,`V*W8L-F!(-F&V*?9A=F'XH",V*_8I]F&($E-
M05`@V8;8I]F%V8C9@=F1V8(@V*C9B-BO(#H@)7,`V*?;C-BLV*?8KR#9A=BM
MV*_9B-BOVXS9D=BJ(-F&V*?9A=F'XH",V*_8I]F&($E-05`@V8;8I]F%V8C9
M@=F1V8(@V*C9B-BO(#H@)7,`V*+8K]BQV+,@25``V*+8K]BQV+,@25`@V8+8
MI]BHV80@V*_8L]BJV+'8L]N,(-F&VXS8L]BJ`-BBV*_8L=BS($E0(-BOV+$@
MV*_8I]BNV80@V*C9A-F(VJD@0TE$4B#8I]BLV*?8LMF'(-BOV*?8K]F'(-F&
MV87;C.*`C-BTV8C8KP#8I]BHV*K8K]BG(-BSV+?8L2#8L=BG(-F(V*?8L=BO
M(-JIV8;;C-BO`-F!V8+8MR#8HMN,VJG9B-F&V8?8IP#8HMN,VJG9B-F&V8?8
MIR#8J-BQV*?;C"`E<P#8HMN,VJG9B-F&V8?8IR#8J-BG(-F%V*K9A@#9AMBG
MV84@V8?9B-N,V9'8JCH`V*?:K]BQ(-BBV88@V*C9AR#8K]BQV+/8JMN,(-F&
MV878I]N,V+0@V*_8I]BOV8<@V8;8M-BOV(P@)7,@(-BHV+'8I]N,(-BHV*?8
MLB#:J=BQV*_9AB#8HMF&(-BOV+$@VXS:J2#9OMF&V*S8L=F'(-BLV*_;C-BO
M`-BGVJ_8L2#8M-F%V*<@V8?;C-J&(-BBVXS:J=F(V8;;C"#8L=BG(-BOV+$@
MV878L=F(V+':K]BQ(-F&V*C;C-F&VXS8K]B,(-F%V87:J=F&(-BGV+/8JB#9
MA-BGV++9A2#8J-BGV+38KR#:J=F'(%!.1R!4<F%N<W!A<F5N8WD@V+'8IR#8
MKMBGV879B-BT(-JIV8;;C-BO`-BGVJ_8L2#8M-F%V*<@V*?;C-F&(-F^VXS8
MNMBGV84@V+'8IR#9A=BTV*?9A]BOV8<@VJG9AMN,V*\@V*?9A=BG(-BJV+79
MB-N,V+';C"#8L=BG(-F%V+38I]F'V*_9AR#9AMJIV8;;C-BOV(P@V*?;C-F&
M(-BHV8<@V*?;C-F&(-BYV838JB#8KMF(V*?9A]BO(-BHV8C8KR#:J=F'(-F%
MV+'9B-BQVJ_8L2#8M-F%V*<@V8'8I]BOV+$@V*C9AR#9AMF%V*?;C-BT(-BJ
MV+79B-N,V+$@V8;;C-BSV*H@`-F^VXS8M.*`C-F&V878I]N,(-BJV+79B-N,
MV+$Z`%523"#8JMBUV8C;C-BQ`%523"#8JMBUV8C;C-BQ.@#8JMBUV8C;C-BQ
M(-BGV+(@VJ_8I]F$V+';C`#8JMBUV8C;C-BQ(-BGV+(@VJ_8I]F$V+';C#H`
MV*?8L=BSV*?9A"#8JMBUV8C;C-BQ`-BJV+78I]F(VXS8L0#8K]BQV8C9AN*`
MC-BHV+'8K]B,(-JOV*?9A2`E9`#9@=N,V838KR#8K]BQV8C9AN*`C-BHV+'8
MKR#8M-BOV8<Z("5S`-F!VXS9A-BOXH",V8?8I]N,(-BOV+'9B-F&XH",V*C8
ML=BO(-BTV*_9ASH`V*C8N=BOV*?9BR#8L]BWV+$@V+'8IR#9B-BGV+'8KR#:
MJ=F&VXS8KP#:J=BO(-BYV879A-JIV+'8KR#9AMBGV*_8L=BSV*H@V*_8I]BO
MV8<@V+38K]F'(-BGV+/8J@`@V8;8I]F%(-JIV*?8L=BHV+$OV*?8L]F%(-BQ
MV878LB`@V8;8I]BOV+'8L]BJ(-BGV+/8J@#9AMBGV84@VJG8I]BQV*C8L2#;
MC-BG(-BBV*_8L=BS(-BLV*?;C-JOV++;C-F&(-F&V*?8K]BQV+/8JB#9A=N,
MXH",V*C8I]BTV*\N(-F$V+?9@=BG(-F%V*S8K]BOV*?9DB#8L]BYVXP@VJG9
MAMN,V*\@V8@@VXS8IR#8K]BQ(-BUV8C8L=BJ(-F&VXS8I]BR(-BHV8<@VJG9
MA=JI(-BHVXS8M-BJV+$@V*C8IR#8L]BQV;[8L=BSV*H@V+/8I]F%V*?9AMF'
M(-BJV878I]BS(-BHVJ_;C-BQVXS8KP#8I]F!V++8I]N,V+0@V*K9B-BQV8'8
MJMJOVXP`VJG8I]BQV*C8L=BGV88@V*[8I]BU`-BGV+?9A-BGV+G8I]BJ`-BG
MV+?9A-BGV+G8I]BJ`-BGV+?9A-BGV+G8I]BJ(-BOVXS:K]BQ(-BOV+$@V*_8
ML]BJV+'8LR#9AMN,V+/8J@#8K]BQV*P@V+/8JMF(V88@V*C8N=BO(-BGV+(`
MV*_8L=BL(-BJV+79B-N,V+$`V*_8L=BL(-BLV*_9B-F$`-BOV+'8K"#9OMN,
MV8C9AMBO(-F(V*@`V*?8J-BJV*_8IR#8L]BJV8C9AB#8L=BG(-BOV+'8K"#:
MJ=F&VXS8KP#;C-JI(-BSV*K9B-F&(-BLV*_;C-BO(-BHV+G8KR#8I]BR(-BS
MV*K9B-F&(-F!V+G9A-N,(-BOV+'8K"#:J=F&VXS8KP#;C-JI(-BSV*K9B-F&
M(-BLV*_;C-BO(-F"V*C9A"#8I]BR(-BSV*K9B-F&(-F!V+G9A-N,(-BOV+'8
MK"#:J=F&VXS8KP#;C-JI(-BSV+?8L2#8K-BOVXS8KR#8J-BYV*\@V*?8LB#8
ML]BWV+$@V8'8N=F$VXP@V*_8L=BL(-JIV8;;C-BO`-N,VJD@V+/8M]BQ(-BL
MV*_;C-BO(-F"V*C9A"#8I]BR(-BSV+?8L2#9@=BYV83;C"#8K]BQV*P@VJG9
MAMN,V*\`VXS:J2#9OMBGV+'8I]JOV+'8I]F!(-BHV+G8KR#8I]BR(-JOV+'9
MAR#9@=BYV83;C"#8K]BQV*P@VJG9AMN,V*\`VXS:J2#9OMBGV+'8I]JOV+'8
MI]F!(-F"V*C9A"#8I]BR(-JOV+'9AR#9@=BYV83;C"#8K]BQV*P@VJG9AMN,
MV*\`V*_8L=BL(-BGV83:K]F(VXP@V*S8I]N,VJ_8LMN,V88`VXS:J2#8HMBO
MV+'8LR#9OMBSV*H@V*?9A-JIV*K8L=F(V8;;C-JI(-BHV+'8I]N,(-BOV+';
MC-BGV8'8JB#8I]BSV84@V+'9A=BR("#8K-BOVXS8KR#8K]BQV*P@VJG9AMN,
MV*\@`-BOV+'8K"#8L]F$V8C9A"#8J-BYV*\`V*_8L=BL(-BSV839B-F$(-F"
MV*C9A`#8K]BQV*P@V+/8JMF(V88@V*C8N=BO`-BOV+'8K"#8L]BJV8C9AB#9
M@MBHV80`V*_8L=BL(-F^VXS8NMBGV84`V*_8L=BL(-F^V*?8L=BGVJ_8L=BG
MV8$@V*C8N=BO`-BOV+'8K"#9OMBGV+'8I]JOV+'8I]F!(-F"V*C9A`#8K]BQ
MV*P@V+/8M]BQ(-BHV+G8KR``V*_8L=BL(-BSV+?8L2#9@MBHV80`V;[8I]BS
MV*X@V879B-BQV*\@V8;;C-BGV+(@V+'8IR#8J-BQV*?;C"#8L]BFV8C8I]F$
M(-BGV879AMN,V*K;C"#8K]BQV*P@VJG9AMN,V*\Z`-BOV+'8K"_8JMBZVXS;
MC-BQ(-BJV+79B-N,V+$`V*_8L=BL+]BJV+K;C-N,V+$@V;[;C-F(V8;8KP#8
MI]BYV*K8J-BGV+$@V8;8I]JIV*?9@=N,(-BHV+'8I]N,(-BGV+'8L]BGV80@
MV*C9AR#9@=F'V+'8L]BJ(-BJV8C8LMN,V+G;C`#8I]BYV*K8J-BGV+$@V8;8
MI]JIV*?9@=N,`-BYV*_8KR#8M=BMVXS8K0#9@=F'V+'8L]BJ(-BYV*_8KR#8
MM=BMVXS8K0!51$@@V8;8I]F%V+G8JMBHV+$`V*C8L=F&V*?9A=F'V90@VJG8
MI]BQV*C8L=BOVXP@V8;8I]F%V+G8JMBHV+$`V*_8L]BJV8<@240@V8;8I]F%
MV+G8JMBHV+$`V*_8I]BOV8?9E"#9AMBGV878N=BJV*C8L2#8I]BQV*?8IMF'
M(-BTV*_9AP#8HMBOV+'8LR#9A=F"V+78KR#9AMBGV878N=BJV*C8L0#9@MBG
MV838J"#9OMBQV8C9AMBOV8?9E"#9AMBGV878N=BJV*C8L0#9AMF(V+D@V;[;
MC-BZV*?9A2#9AMBGV878N=BJV*C8L0!A<&E?:60@V8;8I]F%V+G8JMBHV+$@
MV*?8L]BJ(-F((-N,V*<@V*?8LB#8J-N,V88@V+'9@=BJV8<@V*?8L]BJ`-F^
MV*?8L=BGV878JMBQ(-F&V*?9A=BYV*K8J-BQ(-F((-N,V*<@V*?8LB#8J-N,
MV88@V+'9@=BJV8<`V878K-F(V+(@V;[8K]BQ(-F&V*?9A=BYV*K8J-BQ`-F^
MV+'9B-BJVJG9A"#9AMBGV878N=BJV*C8L0#:K]N,V+'9AMBOV8?9E"#9AMBG
MV878N=BJV*C8L3H@(B5S(@#8M-N,V*$@V*C9AR#8I]BTV*K8L=BGVJD@VJ_8
ML-BGV+38JMF'(-BTV*_9A]F4(-F&V*?9A=BYV*K8J-BQ`-BBV*_8L=BS(-BS
MV+':AMBTV879AR#9AMBGV878N=BJV*C8L0#8K]BGV*_9AR#;C-F(V8;;C-JI
MV*\@V8;8I]F%V+G8JMBHV+$@`-F%V8C8K-F(V*_;C`#8J-BQVJ_8L=BOV*?9
MAMBOV88@V*?9AMBJV*[8I]BH`%0M4W1O<FUS`-F%V8;8JMBTV+$@VJG9AMF&
MV*_9AP#8K=BQV8C9@2#:J=BL`-J8V*?9AMF(VXS9AP!*87!A;F5S92`H25-/
M+3(P,C(M2E`I`-BRVXS8L=F^VXS8L=BGV8?9AMN,`-J8V8C8IMN,V8<`VIC9
MB-BFV88`V8?9A>*`C-BJV+'8I]BR(-JIV+'8K]F&`-F'V87B@(S8JMBQV*?8
MLMN,(-F(V+/8MP#9A]F%XH",V*K8L=BGV++;C"#:J=BGV879A`#9A]F%XH",
MV*K8L=BGV++;C"#:AMF^`-F'V87B@(S8JMBQV*?8LMN,(-BQV*?8L]BJ(`#8
MI]BUV83;C"#9AMJOV8<@V*_8I]BTV*K9AR#8M-F(V*_8GP#:J=BGV+'8L]BG
MV+(@:V5R8F5R;W-E(-BJV+78K]N,V8(@V8?9B-N,V9'8JB#8L=BG(-BQV*\@
MVJG8L=BO`-BGVXS8K-BGV*\@VJG9A-N,V*\`V*?8J]BQ(-BGV8;:K]BTV*H@
MVJG9A-N,V*\`V+?9B-F$(-JIV83;C-BO`-F&V8C8N2#:J=F$VXS8KP#:J=BG
MV+'8J-BQV*\@VJG9A-N,V*\`VJG9A-N,V*\@V8+8J-F$V*?9BR#8K]BQ(-JI
MV*?8L=BSV*?8LB#8N=F%V8C9A=N,(-JIV83;C-BO(-F%V8C8K-F(V*\@V*?8
ML]BJ`.*`C-BHVH;9A^*`C-F'V*<`2V]R96%N("A%54,M2U(I`-BLV*?9AMF%
MV*?;C-N,`-BRV*C8I]F&`-F&VXS9A=F'V90@V*+8KMBQ`-BJV+K;C-N,V+$@
MV*+8KMBQVXS9AB#8I]BSV84@V+'9A=BR`-BQV*C8N2#8HMBNV+$`V*+8KMBQ
MVXS9AB#8J-BQV8C8LMBQV+/8I]F&VXPZ`-BBV*[8L=N,V88@V8C8L=F(V*\Z
M("5S`-BBV*[8L=N,V88@V8C8L=F(V*\@.B`E<R#8I]BR("5S`-BBV*[8L=N,
MV88@V8C8L=F(V*\Z(-F'V+':K]BR`-BMV8+9B-F"`-BLV*?9AMF%V*?;C-N,
M`-J&V;X`V+/8L=BBV878KR#:AMF^`-F%V8+8I]BOVXS8L2#:AMF^`-F&V87B
M@(S9AMF%(-BHV*?8L=BGV88`V*C8I]BQV8;8K]JOVXP@V+/8J-JI`-BHV*?8
ML=F&V*_:K]N,(-BSV*C:J2#8LMF(V*_9A]F&VJ_8I]F%`-BHV*?8L=F&V*_:
MK]N,(-BSV*C:J2#8K]N,V+'9A]F&VJ_8I]F%`-BHV*?8L=F&V*_:K]N,(-F(
M(-BQVJ_8J-BGV+$@V+/8J-JI`-BHV*?8L=BGV88@V+/8J-JI(-BHV8<@V8?9
MA=BQV*?9AR#8L=BYV*\`V*C8L=F!(-BSV*C:J0#8J-BQV8$@V8@@V+':K]BH
MV*?8L2#8L]BHVJD`V;[;C-F(V8;8KP#9AMF"V*?8MR#9OMN,V8C9AMBO(-BH
MV8<Z`-BBV*_8L=BS(-F^V+/8JB#8I]F$VJG8JMBQV8C9AMN,VJD@V+'8IR#8
MJ-F'(-BUV8'8K=F'(-BGVXS8K-BGV*\@V;[;C-BZV*?9A=B,(-BHV8<@V8?9
MAMJOV*?9A2#9A=BTV*?9A]BOV8?8C"#9OMN,V8C9AMBO(-BOV8?;C-BO`-F^
MVXS9B-F&V*_B@(S9A]BG`-JIV8C:J=N,(-F$VXS9AMF(VJG8LP#9@=F'V+'8
ML]BJ("T@VJG8I]BQV*C8L2#9A=N,XH",V*K9B-BGV8;8KR#9OMF(V+39AR#8
ML=BG(-BHV*C;C-F&V*\`V8'9A]BQV+/8JB#8K]BGV*_:K]BGV8;9A]BGXH",
M`-F!V8?8L=BSV*H@V+G9AMBGV8C;C-F&(-BQV*?9A]F&V878IP#9@=F'V+'8
ML]BJ(-BLV*_8I]F(V80`V8'9A]BQV+/8JB#8HMBQV+3;C-F(`-F!V8?8L=BS
MV*H@V+'8I]F'V8;9A=BG`-F!V8?8L=BSV*H@260`V8'9A]BQV+/8JB#9A=BG
MV83:J0#9@=F'V+'8L]BJ(-F^V+/8JMN,`-F!V8?8L=BSV*H@V+G8MMF(VXS9
MD=BJ`-F!V8?8L=BSV*H@V+G8K]F%(-BYV+;9B-N,V9'8J@#9@=F'V+'8L]BJ
M(-JIV*?8L=BHV+'8I]F&(-F!V+G8I]F$(-F&V87;C.*`C-BHV*?8M-BO`-BG
MV*_8J-N,V*?8J@#8J-BGV+':J=BQV*_9ABXN+@#8L]BGV+G8JB#9A=BMV83;
MC#H@`-F%V*W9A-N,V9'8JB#9B"#8L]BGV+G8J@#9A=F(V8+8N=N,V*H`V8C8
ML=F(V*\`V*[8L=F(V*P`V8C8L=F(V*\`V8C8N-BGVXS9@2#9B-BQV8C8KP#9
MB-BQV8C8KR#9AMBGV879B-F!V9'9@B#8J-F(V*\@V++;C-BQV*<@V8;8I]F%
M(-JIV*?8L=BHV+$@V8@@VXS8IR#8I]BSV84@V+'9A=BR(-F(V*?8L=BO(-BT
MV*_9AR#8I]BTV*K8J-BGV8<@V*C9B-BO(`#9B-BQV8C8KR#9AMBGV879B-F!
MV9'9@B#8J-F(V*\N`-F%V*K9AB#8J-F$V8;8KP#8N=BTV8(`V;[8I]N,VXS9
MA@#8K=BQV8C9@2#:J=F(VH;:J2#;C-F(V8;8I]F&VXP`V*W8L=F(V8$@VJG9
MB-J&VJD@V838I]BJVXS9A@#8I]BYV*_8I]BO(-JIV8C:AMJI(-N,V8C9AMBG
MV8;;C`!-30#9OMN,V+K8I]F%(-BQV8C8L@#9OMN,V8C8L]BJ($U3+51.148@
MV+38I]F%V80@V8?;C-J&(-BOV*?8K]F'XH",V*?B@(S;C-N,(-F&VXS8L]BJ
M`$U31P#8K-BGV*_9B`#9AMBGV879AR#8I]F$VJG8JMBQV8C9AMN,VJG;C`#8
ML]BQV;[8L=BSV*H@V8;8I]F%V8<`V+/8I]BNV*K9AB#9OMN,V8C9AMBO+BXN
M`-F%V*_;C-BQVXS8JB#9B"#8JMBYVXS;C-F&(-BQV8;:KR#8K]BSV*K9A^*`
MC-F'V*?;C-N,(-JIV8<@V+39A=BG(-F%V8C8I]BQV*\@V+'8IR#8J-BG(-BB
MV8;9A]BG(-F&V*?9A>*`C-JOV+#8I]BQVXP@V87;C.*`C-JIV8;;C-BO`$UA
M<#(T(&UA<`!-87!1=65S="!M87``V878I]BQV+,`V*W8I]BTVXS9AP#8N=F$
MV*?9A=BJ(-JOV+#8I]BQVXP@V*C8IR#9OMBQVH;9A2#9A=BTV*?9A]BOV8<@
MV+38K]F'+R#9A=BTV*?9A]BOV8<@V8;8M-BOV8<`(-BYV838I]F%V*H@VJ_8
ML-BGV+';C"#8J-BG(-BYV838I]BFV84@V*_;C-JOV+$@*-F%V*?9AMF&V*\@
MV879A]F%+]F^V*?8L]BN(-BOV*?8K]F'(-BTV*_9ARD`V8';C-F$V*_B@(S9
MA]BGVXP@V*?9AMBWV*C8I]F"`-BHVXS8M-N,V8;9AR#8I]BYV*K8J-BGV+$@
MV878K-BGV+(`V*K8KMBWVXP@V*?8LB#8J-N,V+3;C-F&V8<@V8+8L]F%V*K9
MA]BGVXP@V;[;C-BZV*?9A0#8J-N,V+3;C-F&V8<@V*_9A=BG(-BOV+$@V[+;
MM"#8L]BGV+G8JB#:K]BPV+38JMF'.B``V*C;C-BTVXS9AMF'(-BOV878IR#8
MK]BQ(-NV(-BSV*?8N=BJ(-JOV+#8M-BJV8<Z(`#8J-N,V+3;C-F&V8<@V+?9
MB-F$`-F%VXP`V;[8LMBTVJG;C`#8I]BYV+;8I]BA`-F%V*\@VJ_8LMN,V8;:
MK]BGV8;;C#H`V*?8K]BZV*?9A2#8L]F$V8C9A-F'V*<`V;[;C-BZV*?9A0#9
MOMN,V+K8I]F%(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8J-BGV++8J-N,V8;;
MC"#8M-BO(-BGV878IR#:K]F(V*?9A]N,(-BGV878MMBGV*$@VJG9AMF&V*_9
MAR#9AMF%VXSB@(S8JMF(V*?9AMBO(-BHV*?8LMBHVXS9AMN,(-BTV8C8KP#9
MOMN,V+K8I]F%(-F%V8;9@MBVVXP@V+38KP#9AMF(V+D@V;[;C-BZV*?9A0#8
MHMBH(-F((-F'V8C8I]N,($UE=&%R`-BHV839B-JI($UE=&%R(-F"V*?8J-F$
M(-BOV+/8JMBQV+,@V8;;C-BSV*H`V*C9A-F(VJD@365T87(@V8+8I]BHV80@
MV*_8L]BJV+'8LR#9AMN,V+/8JBX@V*S8LMBFVXS8I]BJ(-BHV+'8I]N,(-BS
MV+'9OMBQV+/8JB#8L]BGV878I]F&V8<@V*O8J-BJ(-BTV*_9AR#8I]BSV*H`
MV+'9B-BT`-BGV8;8K]BGV++9A^*`C-BGVXP`V8C8L]BW`-F&V8C8N2!-:6UE
M`"#:J=F%VXS9AMF'(-BOV878I]N,(-NRV[0@V+/8I]BYV*H@VJ_8L-BTV*K9
MASH@`"#:J=F%VXS9AMF'(-BOV878I]N,(-NV(-BSV*?8N=BJ(-JOV+#8M-BJ
MV8<Z(`#8HMN,V8;9AP#9A=BJV8'8L=F"V8<`V;[;C-JIV+'8J-F&V*_;C"#9
MA=F(V*S9B-BO(-F&VXS8L]BJ+B#8M-F%V*<@V*?:K]BQ(-F%VXSB@(S8KMF(
MV*?9A]N,V*\@V*?8LB#8I]N,V88@V*C8L=F&V*?9A=F'V90@VJG8I]BQV*C8
ML=BOVXP@V*?8L]BJV8'8I]BOV8<@VJG9AMN,V*\@V*C8I]N,V*\@V*+9AMBQ
MV*<@V*K9B-F$VXS8KR#:J=F&VXS8KP#8I]BR(-BHVXS9AB#8L=F!V*K9AB!)
M1"#9OMN,V+K8I]F%`-BGV+(@V*C;C-F&(-BQV8'8JMF&($E$(-F&V+38L]BJ
M(`#8K]F(V+39AMBHV8<`V;[8L]BJ(-BSV839B-F$VXP`V878N=BJV*_9A"#:
MJ=BQV*_9A@#8JMBGV+';C-BN(-BJV+K;C-N,V+$@VXS8I]F!V*K9AP#8JMBZ
MVXS;C-BQ(%523`#9A=BGV8<@V8@@V+/8I]F$`-F%V*?9A]BGV8;9AP#9@=BG
MV++9A]BGVXP@V878I]F'`-BHVXS8M-BJV+$@V+78I]F!`-BHVXS8M-BJV+$@
MV*?8J-BQVXP`V*C;C-BTV*K8L2#8HMF!V*K8I]BHVXP`V*?9AMBJV8+8I]F$
M(-BHV8<@V;[8I]N,VXS9A@#8I]F&V*K9@MBGV80@V*C9AR#8J-BGV838IP#8
MI]F&V*K9@MBGV80@V*C9AR#8L=BGV+/8J@#8I]F&V*K9@MBGV80@V*C9AR#8
MJ-BGV838IP#8I]F&V*K9@MBGV80@V*C9AR#9OMBGVXS;C-F&`-BGV8;8JMF"
MV*?9A"#8J-F'(-BHV*?9A-BG`-F!V8?8L=BSV*H@V;[8I]N,VXS9AN*`C-F^
MV+$@VH;9AMBO(-BSV+?8K=N,`-J&V8;8KR#8I]F&V*K8KMBGV*C;C`#8K=BS
MV*?8J"#9A=F&`-BGV+?9A-BGV+G8I]BJ(-BMV+/8I]BH(-F%V88`V*_8L=JO
MV*?9AR#9A=F&`-BLV*?9AMF%V*?;C-N,(-BOV+':K]BGV8<@V879A@#9AMF'
MV(P@V879AB#9A=F(V*?9@=F"(-F&VXS8L]BJV84`V8;8I]F%`%523"#9OMBG
MVXS9AR!.971S8V%P90!.971S8V%P92!#02!2979O8V%T:6]N(%523`!.971S
M8V%P92!#02!P;VQI8WD@55),`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C
M87!E(%)E=F]C871I;VX@55),`-BJV8C8MMN,V*T@VJ_9B-BGV8?;C"!.971S
M8V%P90#9AMF(V+D@VJ_9B-BGV8?;C"!.971S8V%P90#8M-BHVJG9AP#9A]BQ
MVJ_8L@#8K]BSV*K9AR#8K-BOVXS8KP#9A=BGV8<@V8;9B`#9AMBGV84@VJG8
MI]BQV*C8L=N,(-BLV*_;C-BO("C8I]BNV*K;C-BGV+';C"D`V*?8L]F%(-BQ
MV878LB#8K-BOVXS8KP#8I]BSV84@V+'9A=BR(-F$V+K9B"#8KMF(V*?9A]BO
M(-BTV*\@V*_8L2`E>"``V*?8L]F%(-BQV878LMF'V*?;C"#8K-BOVXS8KR#8
MJMBWV*?8J-F"(-F&V*_8I]BQV*\`V;[9AMBLV+'9AR#8K-BOVXS8KR`HV*[8
MI]F$VXPI`-BGV*[8J-BGV+$`VJ_8L=F(V8?B@(S9A]BGVXP@V*[8J-BQVXP`
MV*C8N=BOVXP`VJ_8LMN,V8;9A^*`C-F'V*?;C"#8J-BYV*_;C`#8M-BH`-F&
MV8<`V*_8I]BOV8<@V;[;C-JIV+'8J-F&V*_;C"#8K]BQ(-BOV+/8JMBQV+/;
MC"#8J-BQV*?;C"#9AMBTV*?9AB#8K]BGV*_9AB#8JMF!V*?9B-BJV8?8IR#9
MB-BLV8C8KR#9AMBOV*?8L=BO`$E33R#9AMN,V+/8JB#8I]BSV*K8L=BGV*K:
MF-N,(-BOV+$@V*_8L]BJV+'8L]N,(-BHV+'8I]N,(-BSV*?8KMBJV88@V*K8
MM=F(VXS8L2``V*?9A-JOV8C;C"#8K]BSV*K9A^*`C-BGVXS;C"#9AMN,V+/8
MJ@#8J-F$V*?:J=N,(-BOV+$@V879B-F"V+G;C-BJ(-BOV+'8KMF(V*?8L]BJ
M(-BTV*_9AR#9A=F(V*S9B-BO(-F&VXS8L]BJ`-F'VXS:AB#9AMBGV84@V*K9
M@MF(VXS9A=N,(-BHV+'8I]N,(-BJV+78K]N,V8(@V8?9B-N,V9'8JB!-0T%,
M(-F!V+'8I]F'V84@V8;8M-BOV8<@V*?8L]BJ`-BHV*_9B-F&(-BJV+K;C-N,
MV+$`V8?;C-J&(-F%V*S9B-BR(-F!V+'8N=N,XH",V*?;C"#9AMF%VXSB@(S8
MJMF(V*?9AMBO(-BHV8<@V*?;C-F&(-F%V*S9B-BR(-BGV+;8I]F!V8<@V+39
MB-BO`-F'VXS:AB#8I]BWV838I]BYV*?8JB#9OMN,VJG8L=BHV8;8K]N,(-BH
MV+'8I]N,("5S(-F%V+38KMBU(-F&V+38KP#9A]N,VH8@V*?8M]F$V*?8N=BG
MV*H@V;[;C-JIV+'8J-F&V*_;C"#8J-BQV*?;C"!&5%`@5D93(-F%V+38KMBU
M(-F&V+38KP#9A]N,VH8@V*?8M]F$V*?8N=BGV*H@V;[;C-JIV+'8J-F&V*_;
MC"#8J-BQV*?;C"!344P@5D93(-F%V+38KMBU(-F&V+38KP#9A]N,VH8@V*?8
MM]F$V*?8N=BGV*H@V;[;C-JIV+'8J-F&V*_;C"#8J-BQV*?;C"!344PM1FEL
M92!61E,@V878M-BNV+4@V8;8M-BO`-F'VXS:AB#8I]BYV*K8J-BGV+';C"#8
MJ-BGV8+;C"#9AMF%V*?9AMBO`-F'VXS:AB#9A=F"V+78K]N,(-F!V+'8I]F'
MV84@V8;8M-BO`-F'VXS:AB#9OMBQV8C9AMBOV8?B@(S8I]N,VXP@V*?8L=BS
MV*?9A"#9AMBTV*\`V8?;C-J&(-BBVXS:J=F(V8;;C.*`C"#9OMN,V*_8IR#9
MAMBTV*\`V8?;C-J&(-F%VJG8I]F&VXP@V*K9AMBXVXS9A2#9AMBTV*_9AP#9
MA]N,VH8@V;[;C-BZV*?9A=N,(-F!V+'8I]F'V84@V8;8M-BO`-F'VXS:AB#9
MAMBGV87;C"#9A=BTV*[8M2#9AMBTV*\`V8?;C-J&(-BTV878I]BQV8?B@(S8
MI^*`C-N,VXP@V878M-BNV+4@V8;8M-BO`-BBVXS9AMBOV8<@V8;8I]F%V+?8
MJ-F(V+G;C"#9AMN,V+/8J@#8J-BQV*?;C"#8JMBUV*_;C-F"(-F'V8C;C-F1
MV*H@2%144"#8I]BSV84@V+'9A=BRVXP@V8'8L=BGV8?9A2#9AMBTV*_9AR#8
MI]BSV*H`V*C8L=BGVXP@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ($E-05`@V*?8
ML]F%(-BQV878LMN,(-F!V+'8I]F'V84@V8;8M-BOV8<@V*?8L]BJ`-BHV+'8
MI]N,(-BJV+78K]N,V8(@V8?9B-N,V9'8JB!+97)B97)O<R#8I]BSV84@V+'9
MA=BRVXP@V8'8L=BGV8?9A2#9AMBTV*_9AR#8I]BSV*H`V*C8L=BGVXP@V*K8
MM=BOVXS9@B#9A]F(VXS9D=BJ(-F(V+'9B-BO(-BGV+/9A2#8L=F%V++;C"#9
M@=BQV*?9A]F%(-F&V+38K]F'(-BGV+/8J@#8J-BQV*?;C"#8JMBUV*_;C-F"
M(-F'V8C;C-F1V*H@4$%34U=$(-BGV+/9A2#8L=F%V++;C"#9@=BQV*?9A]F%
M(-F&V+38K]F'(-BGV+/8J@#8J-BQV*?;C"#8JMBUV*_;C-F"(-F'V8C;C-F1
MV*H@4TU"(-BGV+/9A2#8L=F%V++;C"#9@=BQV*?9A]F%(-F&V+38K]F'(-BG
MV+/8J@#8JMF"V*?8MMBGVXP@V*O8J-BJ(-F&V*?9A=N,(-BOV+$@V*?9AMBJ
MV+C8I]BQ(-BJV*/;C-N,V*\@V8;;C-BSV*H`V*C8K]F(V88@V8+9B-BGV+G8
MKP#9A]N,VH8@V*S8K]BGVJG9AMF&V*_9A^*`C-BGXH",VXS;C"#9A=BTV*[8
MM2#9AMBTV*\`V*C8K]F(V88@V+/9A=BJ`-BTV*?8KMF'(-F%V8C9@MBJVXP@
MV*C8L=BGVXP@VJG8I]BTV8<@V879B-BLV8C8KR#9AMN,V+/8J@#9A]N,VH8@
MV8;8I]F%(-JIV*?8L=BHV+';C"#9B"#;C-BG(-BGV+/9A2#8L=F%V++;C"#8
MI]BQV+/8I]F$(-F&V+38KP#9A]N,VH8@V*_8I]BOV8<@6$U,(-F%V+G8JMBH
MV+';C"#8J-BGV++:K]BQV*_8I]F&V*_9AR#9AMBTV*_9AR#8I]BSV*H`V*C8
MK]F(V88@V879@MBOV*?8L0#9AMBSV*[9A^*`C"#8K]BQ(-F^VXS:J=BQV*C9
MAMBOVXP@V*?8M=F$VXP@V;[;C-BOV*<@V8;8M-BO+B#9OMN,VJG8L=BHV8;8
MK]N,(-BQV*<@V*_9B-BHV*?8L=F'(-BJV8C9A-N,V*\@VJG9AMN,V*\`V8;8
ML]BNV8?B@(P@V*_8L2#9OMN,VJG8L=BHV8;8K]N,(-BTV878IR#9OMN,V*_8
MIR#9AMBTV*_9AR#8I]BSV*HN(-F^VXS:J=BQV*C9AMBOVXP@V+'8IR#8K]F(
MV*C8I]BQV8<@V*K9B-F$VXS8KR#:J=F&VXS8KP#9A]N,VH;B@(S:J=BOV*?9
MA0#9A]N,VH;B@(S:J=BOV*?9A2`HV+;9A=F&VXP@V*?8L]BJV8'8I]BOV8<@
MVJG9AMN,V*\I`$YO<F1I8R`H25-/+3@X-3DM,3`I`-F&VXS9A2#:J=BQV8<@
MV+39A=BGV83;C`#9AMF'(-BHV+G8KP#9AMF'(-F"V*C9A`#;C-JI(-BTV*?8
MKMF'(-F&VXS8L]BJ`-F^VXS8I]BOV8?B@(S8L]BGV++;C"#9AMBTV*_9AP#8
MJMF&V+C;C-F%(-F&V+38K]F'`-F^V+38JMN,V*C8I]F&VXP@V8;8M-BOV8<`
MVXS8I]BOV*_8I]BTV*K9A]BG`-J&VXS8LMN,(-BHV+'8I]N,(-F%V+'9B-BQ
M(-F&VXS8L]BJV(P@V*C9AR#8N=F"V*@@V*C8L=JOV+'8KP#9AMF(V*?9A=BH
MV+$`V+G8K]BO`-BJV+G8K]BGV*\@V8;9B-N,V+/9A^*`C-F'V*<`V*K8N=BO
MV*?8KR#8L]BJV8C9AMF'V*<`V*K8N=BOV*?8KR#8L]BWV+'9A]BG`-BGV+G8
MK]BGV*\@V*C8L=BGVXP@V*C8L=F(V++8L=BSV*?9AMN,(-F!V8?8L=BSV*H@
MV*K9B-BRVXS8N=N,(-F%V+38KMBU(-F&V+38K]F&V*\`V*K8H]N,VXS8KP#8
MM-N,V*$`V*?;C-BLV*?8KR#:J=F&V8;8K]F'(-BTVXS8H0#9A]BTV*K8I]N,
MVXP`V*?:J=BJV*C8L0#9@=N,V838JMBQ(-BHVXSB@(S8K=BQV878JMN,`-BO
MV8'8JMBQ(-JIV*?8L0#8I]BSV84@V+'9A=BR(-BLV*_;C-BO(-F((-BGV+/9
MA2#8L=F%V+(@V8'8N=F$VXP@V*C8I]N,V*\@V878JMF!V*?9B-BJ(-BHV*?8
MM-F&V*\`V*?8L]F%(-BQV878LB#9@MBOVXS9A=N,`-BGV+/9A2#8L=F%V+(@
M(-F"V*_;C-F%VXP@V8;8I]BOV+'8L]BJ(-BGV+/8J@#8JMF&V8?8IR#:J=BG
MV+'8L]BGV++9A]BGVXP@24U!4-F^V8C8M-F'XH",V8?8I]N,(-F%V+38JMBQ
MVJD@V+'8IR#9OMBTV*K;C-BHV*?9AMN,(-F%VXSB@(S:J=F&V8;8KR``V8'9
M@MBW(-BBVXS9AMBOV8<@V8;8I]F%V+?8J-F(V+D`V*K9AMF'V*<@VXS:J2#8
MHMBOV+'8LR#9OMBSV*H@V*?9A-JIV*K8L=F(V8;;C-JIVXP@V878K-BGV+(@
MV*?8L]BJ`-BJV8;9A]BG(-F%V*?9A-JI(-N,V*<@V+/8L=F^V+'8L]BJ(-BS
MV*?9A=BGV8;9AR#9A=N,XH",V*K9B-BGV8;8KR#9A=BGV83:J=N,V*H@VXS8
MIR#9A=BLV8C8LMF'V*?;C"#9A=BGV83:J2#8L=BG(-BHV+'8I]N,(-N,VJD@
MV*?8M-BJV+'8I]JI(-BJV+K;C-N,V+$@V*_9A]BO`-BOV+$@VXS:J2#9OMF&
MV*S8L=F'(-BLV*_;C-BO(-BHV*?8LB#8M-F(V*\`V*?;C-F&(-F^VXS9B-F&
MV*\@V*_8L2#;C-JI(-F^V8;8K-BQV8<@V*S8K]N,V*\@V*C8I]BR(-BTV8C8
MKP#8L]N,V+/8JMF%(-BYV*?9A=F$`-JOV++;C-F&V8<F(W@R,#!C.]F'V*<`
MVJ_8LMN,V8;9A^*`C-F'V*?;C"`E<P#9A-N,V+/8JB#9A=BQV*K8J"#8M-BO
MV8<`V+/8I]BRV878I]F&`-F(V*?8K=BO(-BSV*?8LMF%V*?9AMN,`-BSV*?8
MLMF%V*?9AMBOV8?;C`#8I]F$VJ_9B-N,(-BGV+79A-N,(-BHV+'9AMBGV879
MA]F4(-JIV*?8L=BHV+'8K]N,`-BGV83:K]F(V8?8I]N,(-BGV+79A-N,(-BO
MV+$@)7,Z`-BOVXS:K]BQ`-BGV+?9A-BGV+G8I]BJ(-BOVXS:K]BQ`-F%V*S9
MB-BRXH",V8?8I]N,(-F%V*?9A-JI`-BJV+78K]N,V8(@V8?9B-N,V9'8JB!0
M04T@V8+8I]BHV80@V*_8L]BJV+'8L]N,(-F&VXS8L]BJ`-BGV878MMBGV*'B
M@(P@V*_;C-BLVXS8JMBGV83;C"!01U``V;[;C-BZV*?9A2#8L=F%V++8J-F&
MV*_;C"#8M-BOV8?9E"!01U``(-JIV83;C-BO(-BYV879B-F%VXP@4$=0`-F^
MVXS8NMBGV84@V+'9A=BRV*C9AMBOVXP@V+38K]F'+]BGV878MMBGV*$@V+38
MK]F'(%!'4`#:J=BO(%!(4`#9OMF(V+/8JMF'(%!(4`#8J-BGV+'9AMBOVJ_;
MC"#8L]BHVJD@V+G8M=BQVJ_8I]F'VXP`V+':K]BHV*?8L2#8N=BUV+':K]BG
MV8?;C`#8J-BQV8$@V+G8M=BQVJ_8I]F'VXP`V*K:K]BQVJ\@V+G8M=BQVJ_8
MI]F'VXP`5"U3=&]R;7,`V*C8L]BW(%!/4TE8(-BGV+(@V*C;C-F&(-BQV8'8
MJMF'(.*`C-BGV+/8J@#9OMF(V+/8JMF'(%!(4`#9@=BGV+79A-F'XH",VJ_8
ML-BGV+';C`#9@MBSV878JMN,(-BGV*C8L=N,`-BGV+/9A2#8L=F%V+(@`-BG
MV+/9A2#8L=F%V+(@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BJV+K;C-N,V+$@
MVXS8I]F!V*HN`-BGV+/9A2#8L=F%V+(@(-F&V*?8K]BQV+/8JB#8I]BSV*H`
MV*?8L]F%(-BQV878LB`@V*C9AR#8JMBUV*_;C-F"(-F'V8C;C-F1V*H@4D%$
M2553(-F&VXS8I]BR(-BOV*?8L=BO`-BGV+/9A2#8L=F%V+(@(-BHV*<@V*K8
MH]N,VXS8KP#8I]BSV84@V+'9A=BR(#H`V*?8L]F%(-BQV878LB`Z(`#8I]BS
MV84@V+'9A=BRXH",V8?8IR#8J-BGVXS8KR#9A=F&V+?8J-F"(-BHV*?8M-F&
MV*\`VH;8L]BHV*?9AMBOV88`VH;8L]BHV*?9AMBOV88@V*?8LB#8JMBNV*K9
MAR#8L=BSV84`V878L]N,V+$`V*O8J-BJ(-F&V*?9A=F'V*?;C"#9AMBGV878
MN=F$V8C9A0#9A=BQV*_9A0#8K]BQV+78KP#8I]BLV+'8I]N,(-BYV879A-N,
MV*?8JB#9AMJOV8?8K]BGV+';C`#8HMN,V*<@V+G9A=F$VXS8I]BJ(-F&VJ_9
MA]BOV*?8L=N,(-BOV+$@V838K=BXV8<@V8C8L=F(V*\@V*?8K-BQV*<@V+39
MB-BOV)\`V878K-F(V+(`V878K-F(V+(@("(E<R(@V*W8L-F!(-F&V+38KP#9
MA=BLV8C8LMF'V*<`V+/8L=F^V+'8L]BJVXP@V878K-F(V++9A]BG`-BGV+?9
MA-BGV+G8I]BJ(-BTV*[8M=N,`-BMVXS9B-BGV8;8I]BJ(-BNV*?9AMJOVXP`
MV*K9A-F!V88`V+G:J=BSV8?8IP#9OMN,VJG8L]F$V8?8IP#9A-BWV8'8I]F+
M(-BOV*?8KMF$(-J&V8;8KR#8L]F$V8C9A"#:J=F$VXS:J2#:J=F&VXS8KP#9
MA-BWV8'8I]F+(-BJV*/;C-N,V*\@VJG9AMN,V*\@VJG9AR#9A=N,XH",V*[9
MB-BGV8?;C-BO(-BGVXS9AB#8N=F&V+78L2#8L=BG(-BMV+#9@2#:J=F&VXS8
MKSH`V838M]F!V*?9BR#8JMBCVXS;C-BO(-JIV8;;C-BO(-JIV8<@V87;C.*`
MC-BNV8C8I]F'VXS8KR#9OMN,V8C9AMBO(-BGVXS9AB#8N=F&V+78L=F'V*<@
MV+'8IR#9@MBWV+D@VJG9AMN,V*\`V838M]F!V*?9BR#;C-JI(-F%V*?9AR#9
MB"#;C-JI(-BSV*?9A"#9B-BGV+'8KR#:J=F&VXS8KRX`V838M]F!V*?9BR#9
MAMBGV87;C"#8J-BQV*?;C"#8K]BSV*K9AR#8K-BOVXS8KR#9B-BGV+'8KR#:
MJ=F&VXS8KSH`V838M]F!V*?9BR#8HMBOV+'8LR!)4"#9A=BYV*K8J-BQVXP@
MV8C8I]BQV*\@VJG9AMN,V*\`V838M]F!V*?9BR#;C-JI(-BJV*?8L=N,V*X@
MV878N=BJV*C8L2#9B-BGV+'8KR#:J=F&VXS8K]B,(-BJV+G8K]BGV*\@V+'9
MB-BRV8?8IR#8K]BQ(-F%V*?9AR#8L=BG(-JIV8;8JMBQV80@VJG9AMN,V*\`
MV838M]F!V*?9BR#;C-JI(-BRV878I]F&(-F%V+G8JMBHV+$@V8C8I]BQV*\@
MVJG9AMN,V*\`V838M]F!V*?9BR#8KMF$V*?8M=F'XH",V*?B@(S;C-N,(-BG
MV+(@V878M-JIV80@V+'8IR#8J-F&V8C;C-BSVXS8KP#9A-BWV8'8I]F+(-F&
MV*?9A2#:J=BGV+'8J-BQ(-F((-BGV+/9A2#8L=F%V+(@(-BNV8C8KR#8L=BG
M(-BBV878I]BOV8<@VJG9AMN,V*\`V838M]F!V*?9BR#9A=BJV88@V++;C-BQ
M(-BQV*<@V*C8KMF(V*?9AMN,V*\N(-BTV878IR#8J-BQV*?;C"#8I]BSV*K9
M@=BGV*_9AR#8I]BR(-BSV*?9A=BGV8;9AR#8J-BGVXS8KR#8M-BQV8C8MR#8
ML=BG(-F"V*C9B-F$(-JIV8;;C-BO`-F$V+?9@=BGV8L@V8;8I]F%(-BOV+/8
MJMF'(-BLV*_;C-BO(-BQV*<@V8C8I]BQV*\@VJG9AMN,V*\Z`-BSVXS8I]BS
MV*K9A]BG`-BBV+'8I]BA`-F%V*W9A"#9@MBQV*?8L=JOV+'9@=BJV88@V*?;
MC-F&(-BJV+79B-N,V+$`V878K=F$(-F"V+'8I]BQVJ_8L=F!V*K9AB#8I]N,
MV88@V*S8K]F(V80`V;[8L]BJ(-BHV8<@V*?;C-F&(-F^V8C8M-F'`-BOV+'8
MM=BO(-BQV+?9B-BHV*H@V*_8L2`E<R#8L]BGV+G8JB#9@MBHV80Z`%!R969S
M7VQD87`Z(-BHV+/8MR#9A=F(V+'8KR#9AMN,V*?8LB!,1$%0(-F^VXS8K]BG
M(-F&V+38KP!0<F5F<U]S97-S:6]N.B#8J-BSV+<@V879B-BQV*\@V8;;C-BG
MV+(@<V5S<VEO;B#9OMN,V*_8IR#9AMBTV*\`V8'8M-BGV+$`V8'8M-BGV+$@
MV*_8L2#8L]BWV*T@V*_8L=N,V*<Z(`#9@=BTV*?8L3H@`-F^VXS8M.*`C-F&
MV878I]N,V+0`V;[;C-BTXH",V8;9A=BGVXS8M"#8JMBUV8C;C-BQ(-BOV+$@
MVXS:J2#9OMF&V*S8L=F'(-BLV*_;C-BO(`#:K]BRVXS9AMF'XH",V8?8I]N,
M(-F"V*C9A-N,`-J&V*?9OB#8L]F&V*\`VJG9A-N,V*\@V+38KMBUVXP`V878
MM-JIV80`V*K9B-BVVXS8K2#9A=BTVJG9A`#9OMBQV8C:F-F'XH",V8?8IP#9
MA=BJV88@V*?8N=F$V*?9A@#:J=F$VXS8KR#8N=F%V8C9A=N,`-BGV83:K]F(
MV+';C-BJV84@VJG9A-N,V*\@V+G9A=F(V87;C`#8K-F!V*H@VJG9A-N,V*\@
MV+G9A=F(V87;C"_8KMBUV8C8M=N,(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8
MJMF(V83;C-BO(-F&V+38KP#9OMBQV+/B@(S9B-BLV8@`V+/9A]F%VXS9AP`@
MVJG9A-N,V*\@V+G9A=F(V87;C"!24T$@*"5D(-BHVXS8JBD`V*?9AMBJV*[8
MI]BH(-BQV*?8K]N,V8@`V*C8I]BQV*?9A@#8J-BGV+'8I]F&(-BRV8C8K]F'
MV8;:K]BGV84`V*C8I]BQV*?9AB#8K]N,V+'9A]F&VJ_8I]F%`-BHV*?8L=BG
MV88@V8@@V+':K]BHV*?8L0#8J-BGV+'8I]F&(-F((-BHV+'9@0#8J-BGV+'8
MI]F&(-BHV8<@V*C8L=F!`-BWV*?9A-BY(-BJV+78I]BOV8';C`#9AMBSV*C8
MJ@#8KMF(V*?9AMBOV88`V*[9B-BGV8;8K]F&(-F^VXS8NMBGV879A]BG(`#9
MB-BGV8+8N=BGV9(@)7,@V*W8L-F!(-BTV8C8K]B?(-BGVXS9AB#8N=F%V80@
MV8+8I]BHV80@V8C8I]JOV+'8KR#9AMN,V+/8J@#9B-BGV8+8N=BGV8L@V*_8
MI]BOV8?9E"#:J=BGV+'8J-BQVXP@V*C8L=BGVXP@VJG8I]BQV*C8L2`E<R#8
MK=BPV8$@V+39B-BOV)\@V*?;C-F&(-BYV879A"#9@MBGV*C9A"#9B-BGVJ_8
ML=BO(-F&VXS8L]BJ`-BGV8;8K-BGV84@V*+8KMBQVXS9AB#8N=F%V80@V+39
MA=BG(-BGV+(@V8;9B`#8J-BGV++8HMF(V+';C"#8N=F&V*?8M=BQ(-JOV++;
MC-F&VJ_8I]F&(-BOVXS9AMBGV87;C-JIVXPZ`-BHV*?8LMBBV8C8L=N,(-F&
MV878I]N,(-BOV+':K]BGV8<Z`-F%V+'9B-BQVJ_8L2#8L=BGV*C8M]F'XH",
MV*?B@(S;C-N,`-BJV8C8MMN,V*W8I]BJ`-JIV*?8L=BSV*?8LMF'V*?;C"#8
ML=BGV8?B@(S8K]F(V+$`55),`-BMV+#9@0#8K=BPV8$@V*C9A-F(VJD`V*W8
ML-F!(-BSV*K9B-F&`-BMV+#9@2#9@MBGV838J"#8J-F&V*_;C`#8K=BPV8$@
MV++9B-BL`-BMV+#9@2#8K]BSV*H@XH",V8;9B-N,V+/9A]BGVXP@V*W9@=BX
M(-BTV*_9AR#8K]BQ(-BTV*?8KMF'(-F%V8C9@MBJ(-JIV*?8L=BSV*?8L@#8
MK=BPV8$`V*W8L-F!(-BGVXS9AB#:K]BQV8<@V*?8LB#8L]F&V*\`V*W8L-F!
M(-JIV*?8L=BHV+$`V*W8L-F!(-JIV*?8L=BHV+$Z("5S`-BJV8+8I]BVV*<@
MV8+8I]BHV80@V;[8I]BSV*[:K]F(VXS;C"#9AMN,V+/8JBX@VJG8KR#8KMBW
MV*?;C"#8J-BQVJ_8L=BOV*?9AMBOV8<@V+38K]F'.@#9@=N,V838K]F'V*?;
MC"#9A=F(V+'8KR#9AMN,V*?8L@#8J-BGV++9AMBTV*?9AMN,`-BHV*?8LMF&
MV+38I]F&VXP@V*?8L]F%(-BQV878L@#8I]BSV84@V+'9A=BR(-BNV8C8KR#8
ML=BG(-BHV*?8LMF&V+38I]F&VXP@VJG9AMN,V*\`V8;8JMBGVXS8K`#8J-BG
MV++:K]BTV*H@V*C9AR#:K]BRVXS9AMF'XH",V8?8IP#8JMBGVXS9OB#8K]F(
MV*C8I]BQV8<@V*?8L]F%(-BQV878LB`@V*S8K]N,V*\@`-JOV+'8K]F'V878
MI]N,VXP`V*C8I]BRVJ_8L=BOV*?9AMBOV88@V;[;C-JIV+'8J-F&V*_;C`#:
MK]BRVXS9AMF'XH",V8?8I]N,(-F(VXS8L=BGVXS8M-JOV+$@V878JMF&`-F%
MV+G9A=BGV8?8IP#8L=BGV+/8J@#8L]BQV*+9A=BO(-BQV*?8L]BJ`-F%V8+8
MI]BOVXS8L2#8L=BGV+/8J@#8KMBUV8C8M=N,V*?8JB#8L]BWV+$N+BX`V8;9
M@MBT`-J&V+'8KMBT(-NQV[C;L"#8K]BQV*S9AP#:AMBQV*[8M"#8J-F'(-J&
MV;X`VH;8L=BNV+0@V*C9AR#8L=BGV+/8J@#8KMBUV8C8M=N,V*?8JB#8L]BW
MV+$`V*[8M=F(V+7;C-BGV*H@V+/8M]BQ`-BSV+?8L=F'V*<Z`-F"V8C8I]BY
MV*\`V8+9B-BGV+G8KR#8J-N,V88@V*K9A=BGV84@V+/8M]BQV8?8IR#9B"#8
ML]BJV8C9AMF'V*<@V8;9A=BGVXS8I]F&(-BNV8C8I]F'V*\@V+38KP#9@MF(
MV*?8N=BO(-F!V8+8MR#8J-N,V88@V*K9A=BGV84@V+/8JMF(V8;9A]BG(-F&
MV878I]N,V*?9AB#8KMF(V*?9A]BO(-BTV*\`V8+9B-BGV+G8KR#9@=F"V+<@
MV*C;C-F&(-BJV878I]F%(-BSV+?8L=F'V*<@V8;9A=BGVXS8I]F&(-BNV8C8
MI]F'V*\@V+38KP#8I]BLV+'8IP#9OMN,V+K8I]F%(-BQV878LMBHV8;8K]N,
M("#8M-BOV8?9E"!3+TU)344@`-BJV+78K]N,V8(@V8?9B-N,V9'8JB!305-,
M(-F"V*?8J-F$(-BOV+/8JMBQV+/;C"#9AMN,V+/8J@#9OMN,V+K8I]F%(%--
M4P#9OMF(V+/8JMF'(%-13`!34T@`V879B-F!V9'9@MN,V9'8J@#9OMF(V+/8
MJMF'(%-13`#8M-F&V*C9AP#9A]F%V*?9AB#:AMBGV+':AMF(V*@@*-BNV8C8
MK]BT*0#8K=F!V+@@VJG8L=BOV88`V*W9@=BX(-JIV+'8K]F&("5S`-BMV8'8
MN"#:K]BRVXS9AMF'XH",V8?8IP#9OMN,VJG8L=BHV8;8K]N,(-BJV8C9A-N,
MV*\@V+38K]F'(-BHV+G9AMF(V*?9AB#8K]BSV*H@XH",V8;9B-N,V+,@4$A0
M(-BOV+$@V+38I]BNV8?9E"#9A=F(V8+8JB#:J=BGV+'8L]BGV+(@V+39A=BG
M(-BMV8'8N"#8M-F(V*\`V;[;C-JIV+'8J-F&V*_;C"`E<R#8K=F!V+@@V+38
MKP#8N=F$V84`V*S8L]BJXH",V8C8K-F(`-BLV8C;C-BTVJ_8L=F'V*<`V*?9
MAMBJV*[8I]BH(-F^V+'9B-F&V*_9A^*`C-F'V*<`V*?9AMBJV*[8I]BH(-N,
MVJD@V*K8I]BQVXS8K@#8I]F&V*K8KMBGV*@@VXS:J2#:K]BQV8C9AR#8J-BQ
MV*?;C"#8I]BVV*?9@=F'(-JIV+'8K]F&`-BGV8;8JMBNV*?8J"#;C-JI(-F%
MV*?9A-JI(-BLV*_;C-BO`-BGV8;8JMBNV*?8J"#;C-JI(-JIV*?8L=BSV*?8
ML@#8I]F&V*K8KMBGV*@@VXS:J2#:J=BGV+'8J-BQ(-BHV+'8I]N,(-BGV+;8
MI]F!V8<@VJG8L=BOV88`V*?9AMBJV*[8I]BH(-F'V879AP#8I]F&V*K8KMBG
MV*@@V*K9A=BGV84@V878I-F$V8'9A^*`C-F'V*?;C"#8JMBGV+';C-BN`-BG
MV8;8JMBNV*?8J"#;C-JI(-BTV*8`V*?9AMBJV*[8I]BH(-F'VXS:AN*`C-JI
MV*_8I]F%`-F&V8C;C-BSV8?B@(S9A]BGVXS;C"#:J=F'(-F$V*?8LMF%(-BO
MV*?8L=N,V*\@V+'8IR#8I]BR(-BLV+G8J-F'(-BRVXS8L2#8I]F&V*K8KMBG
MV*@@VJG9AMN,V*\N(-BSV;[8LR#8M-F%V*<@V87;C.*`C-BJV8C8I]F&VXS8
MKR#8I]BR(-BBV8;9A]BG(-BOV+$@V879AMBWV8+9AR#9A=BJV88@V8;8L]BN
MV8?B@(S8J-BQV*_8I]BQVXP@VJG8L=BOV8<@V8@@V*_8L2#9A=BMV80@V*_;
MC-JOV+$@V*C:AMBSV*C8I]F&VXS8KP#8I]F&V*K8KMBGV*@@V878K=BOV8C8
MK]F'(-BJV*?8L=N,V*XZ`-BGV8;8JMBNV*?8J"#9@MBGV838J"#8JMBGV+';
MC-BN.@#8I]F&V*K8KMBGV*@@V8?9B-N,V9'8JMN,(-JIV8<@V87;C.*`C-BN
MV8C8I]F'VXS8KR#8JMBZVXS;C-BQ(-BOV8?;C-BO.@#8I]F&V*K8KMBGV*@@
MV878K=BOV8C8K]F'V90@V++9A=BGV88Z`-BGV8;8JMBNV*?8J"#9@MBGV838
MJ"#8LMF%V*?9ACH`V*?9AMBJV*[8I]BH(-BOV8@@V8';C-F$V*\@V879AMBW
MV*C9@@#8I]F&V*K8KMBGV*@@V+?8L=BM(-BQV8;:KR#8M-F%V*<`V*?9AMBJ
MV*[8I]BH(-BRV*C8I]F&(-F%V8C8L=BO(-F&V+C8L2#8M-F%V*<Z`-BGV+'8
ML]BGV80@VJ_8LMBGV+'8M`#8I]BQV+/8I]F$(%--4P#8K=BSVJ_8L3H@`-BS
MV;[8JMBGV878J-BQ`-BGV+G8K]BGV*\@V*K8L=BJVXS8J-N,`$E$(-F&V+38
ML]BJ(-F%V8;9@MBVVXP@V+38K]F'(-BGV+/8J@#8JMF&V+C;C-F%`-BJV8;8
MN-N,V84@VJ_8LMN,V8;9A^*`C-F'V*<@V*C8L=BGVXP@V*?8K-BGV++9AR#8
MK]BGV*_9AB#8J-F'(-BTV878IR#8J-BQV*?;C"#8J-BGV++9AMBTV*?9AMN,
M(-BGV+/9A2#8L=F%V+(@V*C9AR#9A]F&VJ_8I]F%(-F!V+'8I]F%V8C8M-N,
M(-BBV88@`-BJV8;8N-N,V84@VJG8I]BQV+/8I]BRV8?8I]N,(-BQV*?9AR#8
MK]F(V+';C"#:J=F'(-BTV878IR#9A=N,XH",V*[9B-BGV8?;C-BO(-BGV+(@
MV*_8L=JOV*?9AR#8KMF(V*\@V*C9AR#8HMF&(-BOV+/8JMBQV+/;C"#8K]BG
MV+38JMF'(-BHV*?8M-N,V*\`V*?9AMBJV*[8I]BH(-BRV*C8I]F&(-F%V8C8
ML=BO(-F&V+C8L=B,(-BSV*?8N=BJ(-F((-JOV++;C-F&V8?B@(S9A]BGVXP@
MV*K8I]BQVXS8K@#8I]F&V*K8KMBGV*@@V*C8L=F&V*?9A=F'(-BRV878I]F&
M(-BTV+'9B-BYV(P@V+?8L=BM(-BQV8;:K]B,(-BHV*?8LMBBV8C8L=N,(-BU
MV8'8K=F'(-F((-BHV8+;C-F'(-JOV++;C-F&V8?B@(S9A]BGVXP@V8;9A=BG
MVXS8M`#8L=BGV8<F(W@R,#!C.]BGV8;8K]BGV++;C`#8K]BSV*H@XH",V8;9
MB-N,V+,@(-BHV+'9B-BRV+'8L]BGV8;;C"#8L=BGV8?B@(S8I]F&V*_8I]BR
MVXP@V*_8L2#8K]BSV*K8L=BS(-BGV+/8J@#:AMF&V*_;C-F&(-F%V8C9@MBY
MVXS9D=BJ(-BHV*<@V;[8I]BQV*?9A=BJV+$@V879A=JIV88@V*?8L]BJ.@#8
MKMBQVXS8KP#8KMF$V*?8M=F'(-JIV8C8JMBGV8<`V*+;C-BG(-JIV83;C-BO
MV8?8I]N,(-BOV+/8JMBQV+/;C"#8J-BGVXS8KR#8J-BQV*?;C"#8J-N,V+38
MJMBQ(-F^VXS9B-F&V*_9A]BG(-BJV+G8L=N,V8$@V+39B-F&V*_8GP#9AMF%
MV*?;C-BT`"#9AMF%V*?;C-BT(-BJV8'8I]F(V*K9A]BGVXP@V87;C-BGV88@
MV;[;C-JIV+'8J-F&V*_;C"#8K=F!V+@@V+38K]F'(-F!V+G9A-N,(-F((-BJ
MV8C9A-N,V*\@V+38K]F'(-BLV*_;C-BO`-BBVXS8IR#8LMF%V*?9AB#8HMBN
MV+';C-F&(-F(V+'9B-BO(-BHV8<@V8?9AMJOV*?9A2#9B-BQV8C8KR#9AMBT
MV*?9AB#8K]BGV*_9AR#8M-F(V*_8GP#9AMF%V*?;C-BT(-JOV++;C-F&V8?B
M@(S9A]BG(-BHV+'8I]N,(-F&VJ_9A]BOV*?8L=N,(-BGV+79A`#8I]F&V*K8
MKMBGV*@@V8/9AMF&V*_9AR#9AMF%V*?;C-BT`-BBVXS8IR#9A=N,V839AR#:
MK]BRVXS9AMJOV*?9AB#8N=F%V83;C-BGV*H@V*S8K]F(V83B@(P@V8;9A=BG
MVXS8M"#8K]BGV*_9AR#8M-F(V*_8GP#8HMN,V*<@VJ_8LMN,V8;:K]BGV88@
M)7,@V+/9A=BJ(-BQV*?8L]BJ(-F&V+38I]F&(-BOV*?8K]F'(-BTV8C8K]B?
M`-F&V878I]N,V+0@VJ_9@=BJXH",V8C:K]F(VXP@V*[8M=F(V+7;C-BGV*H@
MV+/9A-F(V80@V*S8K]F(V80`V8;9A=BGVXS8M"#:K]F!V*K:K]F(VXP@V*[8
MM=F(V+7;C-BGV*H@V*S8K]F(V80`V8;9A=BGVXS8M"#:K]F!V*K:K]F(VXP@
MV*[8M=F(V+7;C-BGV*H@V+/8M]BQ(-BLV*_9B-F$`-F&V878I]N,V+0@VJ_9
M@=BJVJ_9B-N,(-BNV+79B-BUVXS8I]BJ(-BJV+79B-N,V+$`V8;9A=BGVXS8
MM"#8I]BQV+/8I]F$`-BJVJ_8L=JO`-BQVJ_8J-BGV+$@V++9B-BOV8?9AMJO
MV*?9A0#8L=JOV*C8I]BQ(-BOVXS8L=F'V8;:K]BGV84`V*S9A=BY(-BTV*_9
MA@#8K-F%V+D@V+38K]F&(-N,V*<@V*?9AMBJV8+8I]F$(-BHV839B-JIV8?8
MI]N,(-F%V*S8I]F(V+$`V*O8J-BJ(-F&V*?9A0#8I]F%V+;8I]BA`-BGV83:
MK]F(V+';C-BJV84@V*?9A=BVV*?8H0#8I]F&V*_8I]BRV8<`V+78L=F!V8;8
MN-BQ(-BGV+(@V8;:K]F'V*_8I]BQVXP`V*C8L=F!`-BJVJ_8L=JO`-BJVJ_8
ML=JO`-BQVJ_8J-BGV+$@V++9B-BOV8?9AMJOV*?9A0#8L=JOV*C8I]BQ(-BO
MVXS8L=F'V8;:K]BGV84`V+G9A=F"(-BHV+'9@3H@`-F%V+G8I]BOV80@V*C8
ML=F!(-BOV+$@V*+8J#H@`-BTV+G8L=F'V*<@V8@@V*+9B-BGV++9A]BG`-BG
MV8;8JMBNV*?8J"#8K-F'V*H@V878L=BJV*@@V+/8I]BRVXP`V*+8K]BQV+,@
MV+/8L=J&V+39A=F'`%-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0#9AMN,
MV84@VJG8L=F'(-BLV8;9B-BHVXP`V8'8I]BUV839A]F4(-BHVXS9AB#8L]F$
MV8C9A-F'V*?;C"#9A=BLV*?9B-BQ`-F!V*?8M=F$V8?9E"#8J-N,V88@V878
MK=BJV8C8IR#9B"#9A-BHV8<@V*_8L2#8L]F$V8C9A`#9@=BGV+79A-F'XH",
MVJ_8L-BGV+$`V8'8I]BUV839AP#9@=BGV+79A-F'XH",VJ_8L-BGV+';C"#9
MB"#8K]BQV++:K]BPV*?8L=N,`-F'V+'8LMF&V*?9A=F'`-JIV*?8L=BGVJG8
MJMBQ(-BNV*?8M2#9B-BGV+'8KR#8M-BO`-BJV8+8L]N,V84@V+/9A-F(V80`
MV*K9@MBSVXS9A2#8L]BJV8C9A@#8JMF"V+/;C-F%(-BSV+?8L0#9B-BQV++8
MM-N,`-BGV+/8JMBGV8;8K]BGV+'8KP#8L]BJV*?8L=F'`-BSV*?9A"#8M-BQ
MV8C8N0#9B-BVV+G;C-BJ(-BMV8C8LMF'XH",V8?8IP#9B-BVV+G;C-BJXH",
M`-F"V*?9A-BH(-BPV*[;C-BQV8<@V+/8I]BRVXP`V*+8K]BQV+,@V*[;C-BG
MV*C8I]F&`-F!V8?8L=BSV*H@V+'8M-BJV8<`V+3;C-F(V8<@6T-34UT`VXS:
MJ=BTV8;8J-F'`-BYV8;9B-BGV88`V*?8L=BSV*?9A`#8LMN,V+'9AMF(VXS8
MLP#9A=F(V8'9D=F"VXS9D=BJ`"(E<R(@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ
M(-BMV+#9@2#8M-BO`-F^VXS:J=BQV*C9AMBOVXP@V*C8IR#9A=F(V8'9D=F"
MVXS9D=BJ(-BHV*?8LMJOV+'8K]BGV8;8K]F'(-BTV*\N(-BHV+'8I]N,(-F%
MV+38I]F'V*_9AR#8JMBZVXS;C-BQV*?8JB#9A=BLV*_8K]BGV9(@V*+9AMBQ
MV*<@V*C8I]BQ(-F&V878I]N,VXS8KP#9OMN,VJG8L=BHV8;8K]N,(-F^V+38
MJMN,V*C8I]F&(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8K=F!V+@@V+38KP#9
MOMBQV8C9AMBOV8<@V;[8M-BJVXS8J-BGV88@V;[;C-JIV+'8J-F&V*_;C"`E
M<R#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@V*W9@=BX(-BTV*\`)7,@V*C8IR#9
MA=F(V8'9D=F"VXS9D=BJ(-F&V8C8M-BJV8<@V+38KP#8KMF$V*?8M=F'`-BW
MV839B-BY(-BBV8'8JMBGV*@`V+K8L=F(V*@@V*+9@=BJV*?8J`#8HMF!V*K8
MI]BHVXP`V+?9A-F(V+D`V+?9A-F(V+DOV+K8L=F(V*@`V+?9A-F(V+DZ(`#8
MNMBQV8C8J`#8NMBQV8C8J#H@`-BHV*?9A-BGV8;9B-N,V+,`V;[8M-BJVXS8
MJ-BGV8;;C`#9AMBGV84@V*[8I]F&V8C8I]BOVJ_;C`#8KMBWV*?;C"#9AMBM
MV8C;C"#8K]BQ(-F%V8C8I]BQV*\@V*S8L]BJV*S9B`!4+5-T;W)M<P!4+5-T
M;W)M<P#9OMBQV8C9AMBOV8<@5%-6`-BLV*_9B-F$`-BNV+79B-BUVXS8I]BJ
M(-BLV*_9B-F$`-BNV+79B-BUVXS8I]BJ(-BLV*_9B-F$`-F'V*_9@3H`V8C8
MN-BGVXS9@0#8M-F%V*?8L=F'(-BJV839@=F&`-BOV878I]N,(-BSV*?8N=BJ
M(-BGV*[;C-BQ.B``V*_8L=BLV8<@V*W8L=BGV+'8J@#8K]BQV*S9AR#8K=BQ
MV*?8L=BJ.B``V*?9A-JOV8C;C"#8L]BQV;[8L=BSV*K;C`#9A=BJV88`V8'9
M@MBW(-F%V*K9A@#8JMBQV*?8LB#9A=BJV88`V*C8I]F$V*?;C"#9A=BJV88`
MV;[9AMBLV+39AMBHV8<`5&AA:2`H5$E3+38R,"D`V*?8LB#8M-F%V*<@V*C9
MAR#8KMBGV+?8L2#8I]BSV*K9@=BGV*_9AR#8I]BR(-BSV*?9A=BGV8;9AR#9
MA=BJV+3:J=BQVXS9A0#8J-BSV+<@1E10(-F"V*?8J-F$(-BOV+/8JMBQV+,@
MV8;;C-BSV*H`V8;:K]F'V*_8I]BQVXPZ.B#:J=F$V*?8LR#8J-BG(-F%V8C9
M@=F1V8+;C-F1V*H@V*C8I]BQ(-F&V+38KP#9OMF&V*S8L=F'V90@VJ_8LMN,
MV8;9A^*`C-F'V*<@V*C8L]BJV8<@V+38KRX@V*[8L=F(V*P`V+/8L=F^V+'8
ML]BJ(-BHV*?;C-BO(-N,VJD@V;[8M-BJVXS8J-BGV88@V878K-F(V++9A]BG
M(-BQV*?8C"`@V*_8L2#8M=F(V+'8JB#8JMF%V*?;C-F$(-BTV878IR#8J-F'
M(-BGV+/8JMF!V*?8K]F'(-BGV+(@V878K-F(V++9A]BGV(P@V;[;C-JIV+'8
MJ-F&V*_;C"#:J=F&V*\N`-BJV8;9A]BG(-BSV878JB#9OMBGVXS;C-F&`-BT
MV878I]BQV8<@240@V*K9A=BGV+,@V878M-BNV+4@V8;8M-BOV8<@V*?8L]BJ
MV(P@V*?;C-F&(-BTV878I]BQV8<@V*_8L2#8K]BGV*_:K]BGV88@VXS8I]F!
MV*H@V8;8M-BO`-BJV878I]BS("`E<R#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@
MV*C9AR#:J=BJV*?8J-J&V8<@V*+8K]BQV+,@V+39A=BG(-BGV+;8I]F!V8<@
MV+38KP#;C-JI(-BHV839B-JI(-BGV878MMBGVXP@4$=0(-BHV+'8I]N,(-BH
MV*?8LMBHVXS9AMN,(-N,VJD@V;[;C-BZV*?9A2#8I]F%V+;8I]BA(-BTV*_9
MAR#9A=F(V+'8KR#9AMN,V*?8LB#8I]BSV*H`240@V8'9A]BQV+/8JB#8JMF(
MV++;C-BYVXP@V878M-BNV+4@V8;8M-BOV8<@V*?8L]BJ(-F((-N,V*<@V*_8
ML2#8K]BGV*_:K]BGV88@V879B-BLV8C8KR#9AMN,V+/8J@#9@=F'V+'8L]BJ
M(-BJV8C8LMN,V+G;C"#9A=BTV*[8M2#9AMBTV*_9AR#8I]BSV*H`V878M-BN
MV+79A^*`C.*`C-F'V*?;C"#8L=F%V++8J-F&V*_;C"#9AMN,V*?8LMF%V8;8
MKR#;C-JI(-BGV+'8JMBUV*?9A"#8I]F%V88@V8C8J"#9A=N,XH",V*C8I]BT
MV8;8KP#9OMBQV8C9AMBOV8<@)7,@V*C8I]N,V*\@V*_8I]BQV*?;C"#8JMF&
MV+C;C-F%("5S(-BHV*?8M-BO`-F^V+'9B-F&V*_9AR`E<R#8J-BGVXS8KR#8
MK=BGV8C;C"#8JMF&V+C;C-F%V*?8JB`E<R#8J-BGV+38KP#9OMBQV8C9AMBO
MV8<@V*C8L2#8L=F(VXP@V*[9B-BOV+0@V8;9A=N,XH",V*K9B-BGV8;8KR#8
ML=F(V8;9B-BTV*H@V+39B-BO`-F^V+'9B-F&V*_9AR#8K=BGV8C;C"#8K]BG
MV*_9A^*`C-BGXH",VXS;C"#9AMN,V+/8JB``V878KR#8JMF%V*?9A2#8M=F!
MV*W9AR#8J-BG($E%(-F%V+3:J=F$(-BOV*?8L=BO(-F((-BGVXS9AB#8I]BR
M(-F%V+3:J=F$V*?8JB#9A=BQV8C8L=JOV+$@V87;C.*`C-BHV*?8M-BO+B#8
MI]JOV+$@V8?9AMF(V+(@V87;C.*`C-BNV8C8I]F'VXS8KR#8K=BGV838JB#9
MB-N,V+'8I]N,V+3:K]BQ(-BJV878I]F%(-BUV8'8K=F'(-BQV*<@V*?9A=BJ
MV*W8I]F&(-JIV8;;C-BOV(P@V838M]F!V*?9BR#:J=F$VXS8KR#8JMBCVXS;
MC-BO(-BQV*<@V8'8M-BGV+$@V*_9A]N,V*\@`-F'V8C;C-F1V*H@(B5S(B#8
MK=BPV8$@V+38K]F'(-BGV+/8J@#8JMF&V8?8IR#8L]F%V*H@VH;9O@#9OMN,
MV+K8I]F%(-F!V+'8L]BJV*?8K]F'(-BTV*_9AR#8L=F(VXP@)7,@V*C9AR`E
M<R#8J-BG(-F%V8C8MMF(V+D@(B5S(B#9AMF%V*?;C-BT(-BOV*?8K]F'(-BT
MV*_9AR#8I]BSV*HN"MBJV+;9A=N,V8;;C"#8J-BQV*?;C"#8KMF(V*?9AMBO
MV8<@V+38K]F&(-F((-N,V*<@V*_8L=JI(-BBV88@V8C8K-F(V*\@V8;8K]BG
MV+'8KP#9AMBGV87;C"#:J=F'(-BHV8<@V8?9AMJOV*?9A2#9OMN,V8C9AMBO
MV*_9A]N,(-BHV8<@V+79@=BMV8<@V*?;C-BLV*?8KR#9AMBGV879AR#8I]BS
MV*K9@=BGV*_9AR#9A=N,XH",V+39B-BO`-BJV+G8K]BGV*\@V8';C-F$V*_B
M@(S9A]BG(-BHV*?;C-BO(-N,VJD@V+G8K]BO(-BHV*?8M-BO`-BGV8C9A-F(
MVXS8JB`B)7,B(-F&V87;C.*`C-BJV8C8I]F&V*\@V*W9@=BX(-JOV+'8K]BO
M(-BRVXS8L=BG(-F%V8+8K]BGV+$@V*_8I]BOV8<@V*+9AB#8I]BR(-BMV*\@
MV878K-BGV+(@V*C;C-BTV*K8L2#8I]BSV*H`V*C8L=F&V*?9A=F'XH",V*?B
M@(S;C-N,(-JIV8<@V*C8L=BGVXP@V878M-BGV8?8K]F'(-BGVXS9AB#9AMF(
MV+D@V*_8I]BOV8<@*"5S*2#9@MBHV838I]F+(-F%V8C8L=BO(-BGV+/8JMF!
MV*?8K]F'(-F"V+'8I]BQ(-F%VXSB@(S:K]BQV8'8JMB,(-BOV+$@V+/8I]F%
MV*?9AMF'(-F%V8C8K-F(V*\@V8;;C-BSV*H`V*K9AMF'V*<@V+/9A=BJ(-BQ
MV*?8L]BJ(-F((-J&V;X`V*K9AMF'V*<@V+/9A=BJ(-BQV*?8L]BJ`-BLV*_8
MIR#:J=F&V8;8K]F'(-BHV*?;C-BO(-N,VJD@V8;9B-N,V+/9AR#8J-BGV+38
MKP#:J=BGV+'8L]BGV+(@(B5S(B#8K=BPV8$@V+38K]F'(-BGV+/8J@#:J=BG
MV+'8L]BGV+(@(B5S(B#8K=F!V+@@V+38K]F'(-BGV+/8J@#8K]BQV*[9B-BG
MV+/8JB#8I]F!V*K8JMBGV*T@V*W8L]BGV*@@V*C8L=BGVXP@)7,@V*W8L-F!
M(-BTV*_9AR#8I]BSV*H`V+'8K]N,V8$@V878M-BNV+4@V+38K]F'(-F(V*S9
MB-BO(-F&V*_8I]BQV*\`V;[8L=F(V8;8K]F'(-F%V8C9@MBJVXP@("(E<R+9
MA=F(V*S9B-BO(-F&VXS8L]BJ`-BJV8;9A]BG(-BSV878JB#8J-BGV838IR#9
MB"#9OMBGVXS;C-F&`-BJV8;9A]BG(-BSV878JB#8J-BGV838IP#8K]BGV*_9
MA]F4(-BGV+'8L]BGV80@V+38K]F'(-BGV+(@VJ_8I]F%(-F"V*C9A-N,(-BG
MV+(@V*_8L]BJ(-BQV8'8JMF'(-BGV+/8J@#9OMBQV8C9AMBOV8<@V*?8L=BS
MV*?9A"#8M-BOV8<@V8;9A=N,XH",V*K9B-BGV8;8KR#8K=F!V+@@V+39B-BO
M`-BHV839B-JI('=E871H97(N8V]M(-F"V*?8J-F$(-BOV+/8JMBQV+,@V8;;
MC-BSV*H`VJ_8LMN,V8;9A^*`C-BGXH",XH",VXS;C"#8K]BQ(-BOV+/8JMBQ
MV+,@V8;;C-BSV*H`V*C8KMBTVXP@VJG9AR#8J-BJV8C8I]F&V*\@V*C8L=BN
MV+<@V8;9A=BGVXS8M"#8K]BGV*_9AR#8M-F(V*\@V879B-BLV8C8KR#9AMN,
MV+/8J@#9AMF(VXS8L]F'XH",V8?8I]N,(-BRVXS8I]BOVXP@V*_8L2#8I]N,
MV88@V8';C-F$V*\@V8+8L=BGV+$@V*_8I]BQV*\N(-BTV878IR`E<R#9AMF(
MVXS8L]F'(-F(V*?8L=BO(-JIV+'8K]F'XH",V*?B@(S;C-BO(-BOV+$@V*W8
MI]F$VXP@VJG9AR#8M-F%V*<@V*C8I]N,V*\@VJG9A=BJV+$@V*?8LB`E<R#9
MAMF(VXS8L]F'(-F(V*?8L=BO(-JIV8;;C-BO`-F%V+3:J=F$VXP@V*_8L2#8
MI]BQV+/8I]F$(-F^V+'9B-F&V*_9AR#8L=BN(-BOV*?8K]F'(-BGV+/8JCH@
M)7,@V*?8L=BSV*?9A"#9AMBTV*\`V878M-JIV83;C"#8K]BQ(-BGV+'8L]BG
MV80@V;[8L=F(V8;8K]F'(-BQV*X@V*_8I]BOV8<@V*?8L]BJ.B#8I]F&V*_8
MI]BRV8<@)7,@V*C;C-BTV*K8L2#8I]BR(-BMV*\@V878K-BGV+(@V*C9B-BO
MV8<@V*?8L]BJ("@@)60@V*C8I]N,V*HI+@#9A=BTVJG9A-N,(-BOV+$@V*?8
ML=BSV*?9A"#9OMBQV8C9AMBOV8<@V8C8K-F(V*\@V*_8I]BTV*K9AR#8I]BS
MV*HZ("`E<R#8J-F'(-BUV8C8L=BJ(-BJVJG9A^*`C-BGXH",VXS;C"#8I]BQ
MV+/8I]F$(-BTV*_9AR#8I]BSV*H@`-BNV+?8I]N,VXP@V*_8L2#9AMF%V*?;
MC-BT(-BGVXS9AB#8J-BNV+0@V;[;C-BZV*?9A2#8L=BN(-BOV*?8K]F'(-BG
MV+/8J@#8KMBWV*?;C-N,(-BOV+$@V*_8L=F(V8;B@(S8J-BQV*\@VJG8L=BO
MV88@V*_8I]BOV8<@V*K9A=BGV+,@V+'8KB#8K]BGV*_9AR#8I]BSV*H`V*[8
MM]BGVXS;C"#8K]BQ(-BOV+'9B-F&XH",V*C8L=BO(-JIV+'8K]F&(-BOV*?8
MK]F'V90@V*K9@MF(VXS9A2#8L=BN(-BOV*?8K]F'(-BGV+/8J@#8KMBWV*?;
MC-N,(-BOV+$@V;[;C-JIV+'8J-F&V*_;C"#9@=BQV84@V+'8KB#8K]BGV*_9
MAR#8I]BSV*HN(-BTV*?;C-BO(-F!VXS9A-BO(-F%V8C8L=BO(-F&VXS8I]BR
MVXP@V+'8IR#8K-BG(-BGV8;8K]BGV*[8JMF'XH",V*?B@(S;C-BO`-BNV+?8
MI]N,VXP@V*_8L2#8I]BLV+'8IR#:J=BQV*_9AB#8N=F%V83;C-BGV*H@V878
MM-BNV+4@V+38K]F'V90@VJG8JMBGV*C:AMF'(-BBV*_8L=BS(-BQV*X@V*_8
MI]BOV8<@V*?8L]BJ+B#9A-BWV8'8I]F+(-BOV8C8J-BGV+'9AR#8L]BYVXP@
MVJG9AMN,V*\`V*[8M]BGVXS;C"#8K]BQ(-BHV+'9B-BRV+'8L]BGV8;;C"#8
MK-BRV*;;C-BGV*H@V*K9A=BGV+,@V+'8KB#8K]BGV*_9AR#8I]BSV*HN(-F$
MV+?9@=BGV8L@V*_9B-BHV*?8L=F'(-BSV+G;C"#:J=F&VXS8KP#8KMBWV*?;
MC-N,(-BOV+$@V*C8L=F(V++8L=BSV*?9AMN,(-F!V8?8L=BSV*H@V*K9B-BR
MVXS8N=N,(-BQV*X@V*_8I]BOV8<@V*?8L]BJ+B#9A-BWV8'8I]F+(-BOV8C8
MJ-BGV+'9AR#8L]BYVXP@VJG9AMN,V*\`(-JIV*?8L=BSV*?8LB!)34%0V;[9
MB-BTV8?B@(S9A]BGVXP@V878M-BJV+':J2#8L=BG(-F^V+38JMN,V*C8I]F&
MVXP@V8;9A=N,XH",VJG9AMBO`"#8J-F'(-F&V+C8L2#9AMF%VXSB@(S8L=BS
MV*\@VJG9AR#8HMBQV+3;C-F((')A<B#9A=BYV*K8J-BQVXP@V*C8I]BTV*\`
M(-BHV8<@V8;8N-BQ(-F&V87;C.*`C-BQV+/8KR#:J=F'(-F^V+'9B-F&V*_9
MAR!Z:7`@V878N=BJV*C8L=N,(-BHV*?8M-BO`-BHV8<@V8;8N-BQ(-F&V87;
MC.*`C-BQV+/8KR#:J=F'(-BTV878I]BQV8<@VJG8I]BQV*H@V878N=BJV*C8
ML=N,(-BHV*?8M-BO`-BGVXS9AB#9@=N,V838KR#9A=F(V+'8KR#9AMN,V*?8
MLB#8I]BSV*H`V*?;C-F&(-F!VXS9A-BO(-F%V87:J=F&(-BGV+/8JB#8M-BG
MV879A"#8I]BYV*_8I]BO(-BUV*W;C-BM(-BHV*?8M-BO`-BGVXS9AB#9@=N,
MV838KR#9A=F%VJG9AB#8I]BSV*H@V+38I]F%V80@V*?8N=BOV*?8KR#9B"#9
MB-N,V+':K]F(V80@V*C8I]BTV*\`V*?;C-F&(-F!VXS9A-BO(-F%V87:J=F&
M(-BGV+/8JB#8M-BGV879A"#9A=F"V*?8K]N,V+$@V8?8M-BJ(-F'V+38JMN,
M(-BHV*?8M-BO`-BGVXS9AB#9@=N,V838KR#8J-BGVXS8KR#8K=BGV8C;C"#:
MJ=BGV878IR#9B"#;C-BG(-F!V8?8L=BSV*K;C"#8I]BR(-BGV+G8K]BGV*\@
MV+78K=N,V*T@V*S8K]BG(-BTV*_9AR#8J-BG(-F&V8C;C-BSV8<@V*[8I]F$
MVXP@V*C8I]BTV*\`V*?;C-F&(-F!VXS9A-BO(-BHV*?;C-BO(-N,VJD@V+G8
MK]BO(-F%V+G8JMBHV+$@V*C8I]BTV*\`V*?;C-F&("5S(-F%VXSB@(S8J-BG
MV+38KP#8I]N,V88@V;[;C-BZV*?9A2#8J-BG(-F%V*S9A=F(V+G9AR#:J=BG
MV+'8I]JIV*K8L2`E<R#9AMF(V+38JMF'(-BTV*_9AR#8I]BSV*H@VJG9AR#8
MJ-BG(-F%V*S9A=F(V+G9AR#:J=BGV+'8I]JIV*K8L2#8M-F%V*<@V878JMF!
MV*?9B-BJ(-BGV+/8J@#8I]N,V88@V+G8K]BO(-BMV*_8I]F"V80@V*C8I]N,
MV*\@VXS:J2#8J-BGV+38KP#8I]N,V88@VJG8I]BQV+/8I]BR(-F^V+'9B-F&
MV*_9A^*`C-F'V*?;C"!Z:7`@V8@@9WII<"#8L=BG(-BHV*?8LB#9AMF%VXSB
M@(S:J=F&V*\`V*?;C-F&(-BSV*?9A=BGV8;9AR#8K]BQ(-BMV*?9A"#8K=BG
MV+;8L2#8NMN,V+$@V8'8N=BGV80@V*?8L]BJ`-BGVXS9AB#9A=F"V*_8I]BQ
M(-BHV*?;C-BO(-BYV*_8KR#8J-BGV+38KP#8I]N,V88@V;[9AMBLV+'9AR#8
MJ-BGVXS8KR#8I]BR(-F^V8;8K-BQV8?9E"#:K]BRVXS9AMF'XH",XH",V8?8
MIR#9@=BQV*?8KMF(V*?9AMN,(-BTV8C8KP#8L=BYV*\`V*C9A-N,V+?9A]BG
M`-BRV878I]F&`-BQV*_;C-BGV*C;C"#8LMF%V*?9A@#9@MBGV838J"#8LMF%
MV*?9A@`@V*?9AMBJV*[8I]BH(-BRV878I]F&(`#8N=F&V8C8I]F&`-BYV8;9
MB-BGV88@*-BQV*?9A]F&V878I]N,(-BBV8;;C"DZ`-BHV8<`V*C8L=BGVXP@
MV*?9AMBJV*[8I]BH(-J&V8;8KR#9@=N,V838K]B,(-BOVJG9A=F'($-T<FP@
MV+'9B-N,("A00RD@VXS8IR!#;VUM86YD(-BQV8C;C"`H36%C*2#8L=BG(-BO
MV+$@V878K]BJ(-JIV83;C-JI(-JIV+'8K]F&(-F&VJ_9A]BOV*?8L=N,V*\`
MV*?9A=BQV8C8L@#9@=BQV*_8IP#8J-BGV838IP#:AMBGV+':AMF(V*@@V*C8
MI]F$V*<@*-BHV*?9A-BG*0#8JMBQV*S9A=F'XH",V8?8IP#8K]BQV+/8JB#9
MB"#;C-BG(-F&V*?8K]BQV+/8J@#8L]F'(-BTV8;8J-F'`%1U<FMI<V@@*$E3
M3RTX.#4Y+3DI`-BGV8;8JMBNV*?8J"#8KMF(V*\@V+'8IR#8JMBGVXS9OB#:
MJ=F&VXS8KSH`V+38I]BNV+4@52Y6+B`Z(`!54DP`55),.@#8I]F%VJG8I]F&
M(-BOV+/8JMBQV+/;C"#8J-F'(-BTV*?8KMF'(%9&4R#9AMN,V+/8J@#8I]F%
MVJG8I]F&(-BGV+;8I]F!V8<@VJG8L=BOV88@V*?8M]F$V*?8N=BGV*H@V*?8
MMMBGV8';C"#:J=BGV+'8J-BQ(-BHV8<@V8?9AMJOV*?9A2#8J]BHV*H@V8;8
MI]F%(-F&VXS8L]BJ`-F&V87;C.*`C-BJV8C8I]F&(-F%V*S9B-BRV8?8IR#8
ML=BG(-BHV+'8I]N,(-F^V+'9B-F&V*_9AR`B)7,B(-BJV+K;C-N,V+$@V*_8
MI]BO`-F&V87;C.*`C-BJV8C8I]F&(-F%V*S9B-BRV8?8IR#8L=BG(-BHV+'8
MI]N,(-F^V+'9B-F&V*_9AR`E<R\E<R!61E,@(-BJV+K;C-N,V+$@V*_8I]BO
M`-F&V87;C.*`C-BJV8C8I]F&(-BOV+$@)7,@V*K8NMN,VXS8L2#8K]BGV*\`
MV8;9A=N,XH",V*K9B-BGV88@V*C9AR#:J=BGV+'8L]BGV+(@4U%,V878JMBU
MV80@V+38KP#9AMF%VXSB@(S8JMF(V*?9AB#8J-BG(%-33"#9A=BJV+79A"#8
MM-BO`-F&V87;C.*`C-BJV8C8I]F&(-BGV+(@V;[8L=F(V8;8K]F'(%9&4R#8
ML=F(V8;9B-BTV*H@V*K9A]N,V8<@V8;9A=F(V*\`V8;9A=N,XH",V*K9B-BG
MV88@V+38I]BNV8<@5D93("(E<R(@V+'8IR#8I]N,V*S8I]BO(-F&V879B-BO
M`-F&V87;C.*`C-BJV8C8I]F&(-BTV*?8KMF'(%9&4R#8L=BG(-BGVXS8K-BG
MV*\@V8;9A=F(V*\`V8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&
M4R#8L=BG(-BGVXS8K-BGV*\@V8;9A=F(V*\`V8;9A=N,XH",V*K9B-BGV88@
MV;[8L=F(V8;8K]F'(-BNV*?9A-N,(%9&4R`@V*?;C-BLV*?8KR#9AMF%V8C8
MKP#9AMF%VXSB@(S8JMF(V*?9AB#8K]BGV*_9AR#8L=BG(-BHV*?8LB#:J=BQ
MV*\@`-BMV+#9@2`B)7,B(-F%V87:J=F&(-F&VXS8L]BJV(P@V+38I]BNV8<@
MV*[8I]F$VXP@V8;;C-BSV*H`V8;9A=N,XH",V*K9B-BGV88@(B5S(B#8L=BG
M(-BMV+#9@2#:J=BQV*\Z("5S+@#8K=BPV8$@)7,@V879A=JIV88@V8;;C-BS
MV*K8C"#8M-BGV*[9AR#8KMBGV83;C"#9AMN,V+/8J@#9AMF%VXSB@(S8JMF(
MV*?9AB#8M-BGV*[9AR!61E,@V+'8IR#8J-F'(-BUV8C8L=BJ(-BJV8@@V*_8
ML2#8JMF((-BMV+#9@2#9AMF%V8C8KP#9AMF%VXSB@(S8JMF(V*?9AB#8M-BG
MV*[9AR!61E,@V+'8IR#8K=BPV8$@V8;9A=F(V*\`V8;9A=N,XH",V*K9B-BG
MV88@V+38I]BNV8<@5D93(-BQV*<@V*W8L-F!(-F&V879B-BO.B`E<RX`V8;9
MA=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&4R`B)7,B(-BQV*<@V*W8
ML-F!(-F&V879B-BO`-F&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR!6
M1E,@V+'8IR#8K=BPV8$@V8;9A=F(V*\`V8;9A=N,XH",V*K9B-BGV88@5D93
M(-BQV*<@V*C9AR#8M=F(V+'8JB#8JMF((-BOV+$@V*K9B"#8K=BPV8$@V8;9
MA=F(V*\Z("5S+@#9AMF%VXSB@(S8JMF(V*?9AB#8M-BGV*[9A]F4(-F!V+G9
MA-N,(-BQV*<@V*K8M-BNVXS8M2#8K]BGV*\`V8;9A=N,XH",V*K9B-BGV88@
MV*S8LMBFVXS8I]BJ(-JOV8C8I]F'VXP@V+'8IR#8I]BSV*K8KMBQV*?8K"#9
MAMF%V8C8KP#9AMF%VXSB@(S8JMF(V*?9AB#8JMBYV+';C-F!("5S("#8L=BG
M(-BHV*?8L2#9AMF%V8C8KP#9AMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBO
MV8<@5D93(-BQV*<@V*?9AMBJV8+8I]F$(-BOV*?8KP#9AMF%VXSB@(S8JMF(
MV*?9AB#9OMBQV8C9AMBOV8<@5D93("(E<R(@V+'8IR#8J-BGV+(@V8;9A=F(
MV*\`V8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&4R#8L=BG(-BH
MV+'8I]N,(-F&V8C8M-BJV88@V*C8I]BR(-JIV+'8KP#9AMF%VXSB@(S8JMF(
MV*?9AB#9OMBQV8C9AMBOV8<@5D93(-BQV*<@V*C8I]BR(-F&V879B-BO`-F&
MV87;C.*`C-BJV8C8I]F&(-BBV+'8M-N,V8@@V8'8M-BQV*_9AR#8L=BG(-BH
MV*?8LB#:J=BQV*\`V8;9A=N,XH",V*K9B-BGV88@V+38I]BNV8<@=F9S<F]O
M="#8L=BG(-BNV8C8I]F&V*\`V8;9A=N,XH",V*K9B-BGV88@)7,@V+'8IR#8
MJ-F'("5S("#8JMBZVXS;C-BQ(-F&V*?9A2#8K]BGV*\Z(-F^V8C8M-F'(-F%
MV8+8M=BO(-BGV+(@V8+8J-F$(-F%V8C8K-F(V*\@V*?8L]BJ`-F&V87;C.*`
MC-BJV8C8I]F&(-BTV*?8KMF'(%9&4R#8L=BG(-BJV+K;C-N,V+$@V8;8I]F%
M(-BOV*?8KP#9AMF%VXSB@(S8JMF(V*?9AB#8M-BGV*[9AR!61E,@V+'8IR#8
MJMBZVXS;C-BQ(-F&V*?9A2#8K]BGV*\Z("5S+@#9AMF%VXSB@(S8JMF(V*?9
MAB#9OMBQV8C9AMBOV8<@5D93("(E<R(@V+'8IR#8JMBZVXS;C-BQ(-F&V*?9
MA2#8K]BGV*\`V8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&4R`E
M<R\E<R#8L=BG(-BJV+K;C-N,V+$@V8;8I]F%(-BOV*?8KP#9AMF%VXSB@(S8
MJMF(V*?9AB#9OMBQV8C9AMBOV8<@5D93(-BQV*<@V*K8NMN,VXS8L2#9AMBG
MV84@V*_8I]BO`-F&V87;C.*`C-BJV8C8I]F&("=M:VES;V9S)R#8L=BG(-BG
MV*S8L=BG(-F&V879B-BO`-F&V87;C.*`C-BJV8C8I]F&(-BGVXS9AB#8L]F&
MV*\@5V]R9"#8L=BG(-BJV+'8K-F%V8<@V8;9A=F(V*\`(-F&V87;C.*`C-BJ
MV8C8I]F&(-BOV+$@V;[8L=F(V8;8K]F'("(E<R(@5D93("#9AMF(V+38J@`@
MV8;9A=N,XH",V*K9B-BGV88@V*_8L2#9OMBQV8C9AMBOV8<@5D93(-F&V8C8
MM-BJ+@#9AMF%VXSB@(S8JMF(V*?9AB#8K]BQ(-F^V+'9B-F&V*_9A]F4(-BO
MV*?8K]F'(%9&4R#9AMF(V+38J@#8LMN,V+'8KMBWXH",V*_8I]BQ`-F(V*?:
MK]BQV*_8I]F&V*_9AB#8JMBZVXS;C-BQV*?8J@#9B-BGVJ_8L=BOV*?9AMBO
MV88@V*+8KMBQVXS9AB#8N=F%V80@V+39A=BG`-F^V*?8L]BN(-BZVXS8L2#9
MA=F&V*K8N-BQV8<@V*?8LB#:J=BGV+'8L]BGV+(@V*C8L2#8L=F(VXP@V*?8
MJMBUV*?9A#H`V;[8I]BSV*X@V+K;C-BQ(-F%V8;8JMBXV+'9AR#8I]BR(-JI
MV*?8L=BSV*?8LB#8J-F'.@#8NMN,V+$@V*W9B-BRV8<`56YI8V]D92`H551&
M+3@I`-F(V*?8K=BOV8?8IP#8K]BGV*_9AR#9AMBGV+39AMBGV*[8JMF'`-F&
MV*?9A2#:J=BGV+'8J-BQ(-F((-N,V*<@V*?8L]F%(-BQV878LB#9AMBGV+39
MAMBGV*[8JMF'`-F"V+?8N2#9OMN,V8C9AMBO(-BYV8;8M=BQ(-F!V+G9A-N,
M`-BHVXP@V8;8I]F%`-BOV+/8JB#B@(S9AMF(VXS8L]F'V*?;C"#8J-BOV8C9
MAB#8I]F%V*K;C-BGV+(@V*C9AR#8K]F$VXS9A"#8I]F%V8;;C-BJVXP@V8;9
MA=N,XH",V*K9B-BGV8;9AMBO(-BGV+(@V+?8L=N,V8(@V*C8L=F&V*?9A=F'
M(-F&V8C;C-BSVXP@V*C8L=N,V*_9AR_8L=F(V8;9B-BTV*H@VJ_8L=F!V*K9
MAR_:AMBSV*C;C-BOV8<@V+39B-F&V*\N(-JIV83;C-BO(-BJV*/;C-N,V*\@
MV+'8IR#9@=BTV*?8L2#8K]F'VXS8KR#8JMBG(-F%V*K9AB#9@=F&VXSB@(S8
MI^*`C-N,VXP@V+'8IR#8K]BQ(&UO>FEL;&$N;W)G(-BHV*<@V+G9AMF(V*?9
MAB#:AMJOV8C9AMJOVXP@V*_8L]BJV+'8L]N,(-N,VJD@V*_8L]BJ(.*`C-F&
MV8C;C-BS(-BHV8<@V*K8KMBJV8?9E"#8L=BSV84@V+'8IR#9A=BTV*?9A]BO
MV8<@VJG9AMN,V*\`V+'9AMJO(-BJV8;8N-N,V84@V8;8M-BOV8<`V*C8L]BW
M(-BHV*_9B-F&(-F^V+38JMN,V*C8I]F&VXP`V*C8L=F(V++8L=BSV*?9AMN,
M`-BHV+'9B-BRV+'8L]BGV8;;C"`E<P#8J-BQV8C8LMBQV+/8I]F&VXP@VJG8
MI]BQV*C8L0`B)7,B(-BHV+'9B-BRV+'8L]BGV8;;C"#8M-BO`-BOV+/8JN*`
MC"#9AMF(VXS8LR#8J-F'VXS9AMF'XH",V+/8I]BRVXP@V*W8L-F!(-BTV*\`
MV*?8L=BSV*?9A"#:J=BQV*_9A@#8JMF%V*?9A2#9OMBQV8C9AMBOV8?B@(SB
M@(S9A]BGVXP@V*K9AMBXVXS9A2#8J-BQV8;8I]F%V8?B@(S9A]BGVXP@VJG8
MI]BQV*C8L=BOVXP@V*C9AR#:J=BGV+'8L]BGV+(@V*?8L=BSV*?9A"#8M-BO
M`-BMV+'9B-F!(-BHV++8L=JO(-F$V*?8JMN,V88`V*?8N=BOV*?8KR#;C-F(
MV8;8I]F&VXP@V*C8LMBQVJ\`(-BGV+/8JMF!V*?8K]F'(-F!V+G9A-N,.B`E
M<P#8I]BSV*K9@=BGV*_9AR#8I]BR(%-33`#8I]JOV+$@V8;8I]F%+]BGV+/9
MA2#8L=F%V+(@V*C8L=BGVXP@VJG8I]BQV+/8I]BR($E-4U`@V878JMF!V*?9
MB-BJ(-BGV+/8JMB,(-BGV+/8JMF!V*?8K]F'(-JIV8;;C-BO`-JIV*?8L=BH
MV+$@)7,@(-BHV+'8I]N,("5S(-BGV*W8L=BGV+(@V8?9B-N,V9'8JB#9AMBT
MV*_9AR#8I]BSV*H`V+/8L=F^V+'8L]BJVXP@VJG8I]BQV*C8L0#:K]BRVXS9
MAMF'XH",V8?8I]N,(-JIV*?8L=BHV+$`V*O8J-BJ(-F&V*?9A2#:J=BGV+'8
MJ-BQ`-BKV*C8JB#:J=BGV+'8J-BQ(-BHV+'8I]N,(-BGVXS9AB#9OMBGVXS:
MK]BGV8<@V+K;C-BQ(-F!V+G8I]F$(-BTV*_9AR#8I]BSV*H`V*W8L]BGV*@@
MVJG8I]BQV*C8L2#9OMN,V*_8IR#9AMBTV*\`V8;8I]F%(-JIV*?8L=BHV+$`
MV8;8I]F%(-JIV*?8L=BHV+$Z`-F&V*?9A2#:J=BGV+'8J-BQ.B``VJG8I]BQ
MV*C8L=BGV88@V+/8I]F%V*?9AMF'.@#8M-BGV*[9AR!61E,@V8C8K-F(V*\@
MV8;8K]BGV+'8KP#8JMBYV+?;C-F$V*?8J@#9A=F(V8+8N=N,V*K9A]BGVXP@
MV878N=BJV*C8L2#;C-BGV8'8JMF'(-BTV*_9AR#8N=BHV*?8L=BJV8;8KR#8
MI]BR.@#8I]BYV*K8J-BGV+$`V879@MBOV*?8L2#8J-F'(-BOV8+;C-F"V8<@
MV*?8LB#8K=BGV838IP#9A=F"V*_8I]BQ(-BGV+(@V*C;C-BTVXS9AMF'(-BW
MV8C9A"#9A=BLV*?8LB`E<R#8J-N,V+38JMBQ(-BGV+/8J@#9A=F"V*?8K]N,
MV+$`V879@MBGV*_;C-BQ(-BHV+'8I]N,(-BGV8;8JMBNV*?8J"#8I]BR`-F%
MV*K8NMN,VXS8L0#9AMBSV*[9AP#:J=F&V*K8L=F$(-F&V+/8KMF'`-BJV+'8
MI]BR(-BYV879B-BOVXP`V8'8I]BUV839A^*`C-JOV+#8I]BQVXP@V+G9A=F(
MV*_;C`#8N=F%V8C8K]N,.@#8KMN,V83;C"#8J-BGV838IP!6:65T;F%M97-E
M("A625-#24DI`-F&V878I]N,("5S`-F&V878I]N,(-N,VJD@V+79@=BMV8<@
MV8C8J"#8KMBGV+'8K-N,`"#9AMF%V*<@V*C9AR#8N=F&V8C8I]F&("5S`-F"
MV*?8J-F$VXS8JB#9A=BTV*?9A]BOV8<`V8+8I]BHV83;C-BJ(-F%V+38I]F'
MV*_9ASH@`-BGV*[8M]BGV+$A(2$@V*_8L]BJ(.*`C-F&V8C;C-BS(-BQV*<@
MV*C8M]F(V+$@V*_8L]BJVXP@V*?8LB`E<R#8K=BPV8$@VJG9AMN,V*\`V*?8
MKMBWV*?8L3H@`-J&V8?8I]BQV+39AMBHV8<`V;[;C-BTXH",V*C;C-F&VXP@
MV8?9B-BG`-BOV*?8K]F'(-BBV*@@V8@@V8?9B-BGVXS;C"#9@=BQV*?9A]F%
M(-BTV*_9AR#8J-F'(-F(V+/;C-F$V8<`=V5A=&AE<BYC;VT`V8C8J`#9B-BH
MXH",VJ_8I]F'`-F'V8'8JMJOVXP`V*[9B-BT(-BBV878K]N,V*\`V*C9AR`E
M<R#8KMF(V+0@V*+9A=BOVXS8KP`E<]B,(-BNV8C8M"#8HMF%V*_;C-BO`%=E
M<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0#:AMF'
M(-BHV+'9AMBGV879A]F4(-JIV*?8L=BHV+'8K]N,(-BQV*<@)7,@V*C8I]N,
MV*\@V*C8N=BO(-BGV+(@V8C8L=F(V*\@V8;8M-BGV88@V*_9A]BOV)\`V8;9
MB-N,V+/9A]F4XH",(-BMV*?8IMF$(-J&VXS8L]BJV)\`V8;9B-N,V+/9A^*`
MC-N,(-F&V8+9A"#9@MF(V80@VH;;C-BSV*K8GP#:J=BOV*?9A2#9@=BGV+(`
MVJG8K]BGV84@V*C8L=F&V*?9A=F'XH",V8?8I]N,(-F%V*K8M=F$XH",VJG9
MAMF&V*_9AR#B@(S8J-BQV*?;C"#9B-N,V+'8I]N,V+3:K]BQ(-F%V*K9AB#9
M@=BYV*?9A"#8J-BGV+39AMBO`-BYV+'8M@`@V;[9A]F&V*<@V*_8L2#9B-BG
MV*W8KR!#4U,@`-F^V8?9AMBGVXP@VJ_8LMN,V8;:K]BGV88@)7,@V*_8L2#8
ML=BGV+/8JB`HV*_8L2#9B-BQV8C8KR#8J-BYV*_;C"#9A=F(V*O8L2#9A=N,
MXH",VJ_8L=BOV*\I.@#9OMF'V8;8I]N,(-BLV*_9B-F$`-F(V*?8K=BO(-F^
MV8?9AMBG`-F^V8?9AMBG.@!7:6MI`-BHV*?8KSH`V*C8I]BO(-BRV8C8K]F'
MV8;:K]BGV84Z(`#8L]BQV+G8JB#8J-BGV*\@V*C8L=BMV+/8J"#9@=F(V*H@
MV*C8L2#8L]BGV+G8J@#8J-BGV*\Z`-BHV*?8KSH@`-BYV8+9A`#:J=BGV+$`
MV*+8K]BQV+,@V878K=F$(-JIV*?8L0#8JMF$V8'9AB#9A=BMV80@VJG8I]BQ
M`.*`C%E9`%E965D`V+/8I]F$V*?9AMF'`-BBV+';C`#8J-F$V8?8C"#9A=F(
MV*?9@=F"V84`V+39A=BG(-BOV+$@V878KR#9A=BJV88@V8?8L]BJVXS8KRX@
MV*?8LB#8K]JIV879AR`@6SP^72#8J-BQV*?;C"#8J-BQVJ_8M-BJV88@V*C9
MAR!765-)5UE'(-BGV+/8JMF!V*?8K]F'(-JIV8;;C-BO`-BTV878IR#8JMBU
MV*_;C-F"(-F'V8C;C-F1V*H@V8;8M-BOVXS8KP#8M-F%V*<@V8;9A=N,XH",
MV*K9B-BGV8;;C-BO(-F&V8C;C-BSV8<@)UPG(-BQV*<@V*_8L2#9AMBGV84@
MVJG8I]F%V80@V*[9B-BO(-BOV*?8M-BJV8<@V*C8I]BTVXS8KP#8M-F%V*<@
MV*+8K]BQV+,@V;[8L]BJ(-BGV83:J=BJV+'9B-F&VXS:J2#9A=BYV*K8J-BQ
MVXP@V8C8I]BQV*\@V8;:J=BQV*_9A^*`C-BGVXS8KP#8M-F%V*<@V8?;C-J&
M(-F!VXS9A-BOVXP@V+'8IR#8K]BQ(-F^V+'9B-F&V*_9AR#8K]BQV8C9AN*`
MC-BHV+'8KR#8M-BOV8<@V*C9AR#9@=N,V838KR#9A=BJV8+8I]BHV83;C"#8
MK]BQ("5S(-F&VJ_8I]BTV*H@V8;:J=BQV*_9A^*`C-BGVXS8KP#8M-F%V*<@
MV*[8I]BQV*P@V+38K]N,V*\`V+39A=BG(-F%V*S8J-F(V+$@V8?8L]BJVXS8
MKR#;C-JI(-BTV878I]BQV8<@V*K9A-F!V88@V878N=BJV*C8L2#9B-BGV+'8
MKR#:J=F&VXS8K]B,(-BGV+(@V+G9A-BGV878JB`G*R<@V*C8L=BGVXP@V+39
MA=BGV+'9A^*`C-F'V*?;C"#8J-N,V88@V*?9A-F%V839A-N,(-BGV+/8JMF!
MV*?8K]F'(-JIV8;;C-BO`-BTV878IR#9A=BLV*C9B-BQ(-F'V+/8JMN,V*\@
MVXS:J2#9A=F"V*_8I]BQ(-F%V+G8JMBHV+$@V8C8I]BQV*\@VJG9AMN,V*\`
MV+39A=BG(-BHV*?;C-BO(-N,VJD@V;[8M-BJVXS8J-BGV88@V*_8L=BNV*H@
MV*_8I]BOV8<@V*C8L=BGVXP@V*?8L]BJV8'8I]BOV8<@V*?8LB#8J]BHV*H@
MV8;8I]F%(-F^VXS:J=BQV*C9AMBOVXP@VJG9AMN,V*\`V+39A=BG(-BHV*?;
MC-BO(-N,VJD@V+/8I]F%V*?9AMF'(-F^V+38JMN,V*C8I]F&(%9&4R#8L=BG
M(-F^VXS:J=BQV*C9AMBOVXP@VJG9AMN,V*\`V8+8J-F$(-BGV+(@V*?8L=BS
MV*?9A"#:K]BRV*?8L=BTV(P@V*C8I]N,V*\@V878M-JIV80@V+'8IR#8M-BQ
MV*T@V*_9A]N,V*\`V+39A=BG(-BHV*?;C-BO(%523-BGVXP@VJG9AR#8I]N,
MV88@V;[;C-F(V8;8KR#8J-F'(-BBV88@V*?8M-BGV+'9AR#9A=N,XH",VJG9
MAMBO(-BQV*<@V8C8I]BQV*\@VJG9AMN,V*\`V+39A=BG(-BHV*?;C-BO(-N,
MVJD@VJG8I]BQV+/8I]BRV(P@V*C8L=BGVXP@V*W8L-F!(-JIV+'8K]F&(-BG
MV8;8JMBNV*?8J"#:J=F&VXS8KP#8M-F%V*<@V*C8I]N,V*\@VXS:J2#9AMBG
MV84@VJG8I]BQV*C8L=B,(-BHV+'8I]N,(-BMV+#9@2#:J=BQV*_9AB#9A=BT
MV*[8M2#:J=F&VXS8KP#8M-F%V*<@V*C8I]N,V*\@VXS:J2#9AMBGV84@VJG8
MI]BQV*C8L=B,(-BHV+'8I]N,(-BMV+#9@2#8M-BOV88@V878M-BNV+4@VJG9
MAMN,V*\`V+39A=BG(-BHV*?;C-BO(-N,VJD@V8;8I]F%(-JIV*?8L=BHV+'8
MC"#8J-BQV*?;C"#8I]BVV*?9@=F'(-JIV+'8K]F&(-F%V+38KMBU(-JIV8;;
MC-BO`-BTV878IR#8J-BGVXS8KR#;C-JI(-BTV8;8I]BSV8<@VJG8I]BQV*C8
ML=B,(-BHV+'8I]N,(-BHV+'9B-BRV+'8L]BGV8;;C"#8I]F&V*K8KMBGV*@@
MVJG9AMN,V*\`V+39A=BG(-BHV*?;C-BO(-F%V+38KMBU(-JIV8;;C-BO(-JI
MV8<@VH;9AR#8N=F%V83;C"#8J-BGVXS8KR#8I]F&V*S8I]F%(-JOVXS8L=BO
M`-BTV878IR#8J-BGVXS8KR#9AMBGV84@V*S8K]N,V*\@V*_8L]BJV8<@V+'8
MIR#8JMBGVXS9OB#:J=F&VXS8KP#9AMBTV+/8JB`E<R#8M-F%V*<@V879AMF"
MV+;;C"#8M-BOV8<@V*?8L]BJ+B#9A-BWV8'8I]F+(-BOV8C8J-BGV+'9AR#9
MB-BGV+'8KR#8M-F(VXS8KP#8HMBOV+'8LR#8I]F$VJG8JMBQV8C9AMN,VJG;
MC"#8M-F%V*<`V*+8K]BQV+,@V8'8L=BSV*K9AMBOV8<Z(-BTV878ISH`V*?8
MM]F$V*?8N=BGV*H@V+39A=BG`-BBV*_8L=BS(-BGVXS9AMBJV+'9AMBJVXP@
MV+39A=BG(-F&V+/8J-BJ(-BHV8<@V*?8J-BJV*_8I]N,(-F&V+38L]BJ("5S
M(-BTV878IR#8JMBZVXS;C-BQ(-JIV+'8K]F'(-BGV+/8JB[8J-BQV*?;C"#8
ML=BYV*?;C-BJ(-F%V+/8I]BFV80@V*?9A=F&VXS8JMN,(-BHV*?;C-BO(-BO
MV8C8J-BGV+'9AR#9B-BGV+'8KR#8M-F(VXS8KP#9AMBGV84@V+39A=BG`-BS
MV*?9A=BGV8;9AR#9OMBTV*K;C-BHV*?9AB#8JMBUV*_;C-F"(-F'V8C;C-F1
MV*H@V+39A=BG(-F!V8?8L=BSV*H@VJG8L=BOV88@VJG8I]BQV*C8L=BGV88@
MV+'8IR#9OMBTV*K;C-BHV*?9AMN,(-F&V87;C.*`C-JIV8;8K]B,(-N,V*<@
MV+38I]N,V*\@V*C9AMBG(-BHV8<@V*_9A-N,V80@V*_;C-JOV+';C"#8I]N,
MV88@VJG8I]BQ(-BGV8;8K-BGV84@V8;9A=N,XH",V+39B-BO`-BXV*?9A]BQ
M(-F%V+'9B-BQVJ_8L2#8M-F%V*<@V8;8L]BHV*H@V*C9AR#8I]BHV*K8K]BG
MVXP@V8;8M-BSV*H@)7,@V+39A=BG(-BJV+K;C-N,V+$@VJG8L=BOV8<@V*?8
ML]BJ+MBHV+'8I]N,(-BQV+G8I]N,V*H@V878L]BGV*;9A"#8I]F%V8;;C-BJ
MVXP@V*C8I]N,V*\@V*_9B-BHV*?8L=F'(-F(V*?8L=BO(-BTV8C;C-BO`-F%
MV+'9B-BQVJ_8L2#8M-F%V*<@V*?;C-F&(-F%V+38KMBUV8<@V+'8IR#9OMBT
MV*K;C-BHV*?9AMN,(-F&V87;C.*`C-JIV8;8KRX`V++9A=BGV88@V8'8N=F$
MVXP@V879AMBWV8+9AR#8K-BZV+'8I]F!VXS8I]N,VXP@V+39A=BG.@#9A]F(
MVXS9D=BJ(-F^VXS8M"#9@=BQV+8@V+39A=BG.@#9AMBGV84@VJG8I]F%V80@
MV+39A=BG.@#9B-BQV8C8KR#8M-F%V*<@V879AMF"V+;;C"#8M-BOV8<@V*?8
ML]BJ`-BGV+/9A2#8L=F%V+(@(-BLV*_;C-BO(-BTV878IR#8J-BQV*?;C"`E
M<R#9A]BSV*HZ("5S`-JOV++;C-F&V8?B@(S9A]BGVXP@V+39A=BG(-BHV+'8
MI]N,(-BWV8C9A"#8I]N,V88@V8;8M-BSV*H@V*C8L=F(V++8L=BSV*?9AMN,
M(-BTV*_9AR#8I]BSV*H@`-JOV++;C-F&V8?B@(S9A]BGVXP@V+39A=BG(-BH
MV+'9B-BRV+'8L]BGV8;;C"#8M-BOV8<@V*?8L]BJ`-BGV+/9A2#8L=F%V+(@
M(-BTV878IR#8J-BGV++9AMBTV*?9AMN,(-BTV*_9AR#8I]BSV*H`V*?8L]F%
M(-BQV878LB#8M-F%V*<@V*C8I]BRV8;8M-BGV8;;C"#8M-BOV8<@V*?8L]BJ
MV(P@V;[8L]BJ(-BGV83:J=BJV+'9B-F&VXS:J2#8KMF(V*\@V+'8IR#:AMJI
M(-JIV8;;C-BO(-F((-BHV*<@V*?8L]F%(-BQV878LB#8K-BOVXS8KR#8KMF(
MV*\@V8C8I]BQV*\@V+39B-N,V*\`V*?8L]F%(-BQV878LB`@V+39A=BG(-F%
MV8;9@MBVVXP@V+38K]F'(-BGV+/8J@#:J=BGV+'8L]BGV++B@(S9A]BGVXP@
MV+'8I]F'XH",V*_9B-BQ(-BTV878ISH`6]F^V8;9A]BGV88@VJG8L=BOV88@
MV878JMF&(-F&V8+9A"#9@MF(V80@V+38K]F'70!;VJ_8LMBGV+'8M"#9A=BT
MVJG9A%T@`%O9AMF%V*?;C-BT(-F%V*K9AB#9AMF"V80@V8+9B-F$(-BTV*_9
MAR`M`-F&V878I]N,V+0@V878JMF&(-F&V8+9A"#9@MF(V80@V+38K]F'6R`M
M("5S(-BNV+==`%O8KMBW("5S(-BGV+(@)7,@72``V+/8L=F^V+'8L]BJVXP`
M0TQ)`-BOV+'8KMBJ(-BOV*?8K]F'`-BMV+#9@2#8L]BWV+$`VJ_8L=F(V8<F
M(W@R,#!C.]F'V*<`V+'8I]F'V8;9A=BG`-BNV+79B-BUVXS8I]BJ(-BJV+79
MB-N,V+$N+BX`V8C8L=F(V*\`V*[8L=F(V*P`V*K8NMN,VXS8L2#9OMN,V8C9
MAMBO+BXN`-JOV++;C-F&V8?B@(S9A]BG`-F%V*S9B-BRV8?8IP#8K=BPV8$@
MV;[;C-F(V8;8KRXN+@#8L=BGV8<F(W@R,#!C.]BGV8;8K]BGV++;C`#8KMBU
MV8C8M=N,V*?8JB#8K-BOV8C9A"XN+@#:J=BGV+'8J-BQV*?9A@#:J=BJV*?8
MJ-J&V8?9E"#8HMBOV+'8LR``V*K9@MF(VXS9A0#8HMBQV*?9A0#8I]N,V8;8
MK-BG(-BQV*<@V8'8M-BGV+$@V*_9A]N,V*\`V;[8L=F(V8;8K]F'`-BGV+(@
M)7,@*"5S*2#8K]BQ("5S("5S`-BHV*?8KP!H.@#9@=F(V+'8I]F+`-BOV+'8
MKMBW`-BNV+?9B-BW70#9AMBGV84`V;[;C-BGV*_9AR#8L]BGV++;C"#9AMBT
MV*_9AP#9A]F&V8C8LB#9OMN,V*?8K]F'(-BSV*?8LMN,(-F&V+38K]F'(-BG
MV+/8J@!N;W1E<&%D`-BOV+'8M=BO`-F^VXS:J=BSV839A]BG`-BWV839B-BY
M`-F&V878I]N,V+0@V*K9@=BGV8C8JMF'V*<`V;[;C.*`C-BOV+'9OMN,`-F!
MV8?8L=BSV*H@V8C8N-N,V8'9AP#8I]BSV84@V+'9A=BR(-BQV*<@V*C8L=BG
MVXP@V*K8H]N,VXS8KR#8K]F(V*C8I]BQ(-F(V*?8L=BO(-JIV8;;C-BO`-N,
MVJ_8I]F&V8<@V+38K]F'`-BHVXP@V8;8I]F%`-BGV8;8JMBNV*?8J"#:J=BG
MV+'8J-BQ`'9#87)D`'<Z`'=E871H97(N8V]M````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L;V-A;&4O9F%?25(O:&5L<"YX;6P`````````````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#0V,30@,3`U,34T,S,W-#$@
M,#(Q-#,T`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_>&UL('9E<G-I;VX](C$N,"(@/SX@#0H\:&5L<#X-"B`\96YT<GD@
M:60](G-U;6UA<GDB(&UD-3TB-CAC83,S9C=F,&,Y86%E-&,Q,#-E8C0W-#DR
M8V1C,34B('-T871E/2)U<'1O9&%T92(^#0H@(#QT:71L93[8K]BQVJ_8I]F'
M/"]T:71L93X@#0H@(#QP87)A/MBGV8K9AB#8K]BQVJ_8I]F'(-BNV838I]BU
MV8?B@(S8I]F*V8H@V*?8LB#8I]BWV838I]BYV*?8JB#9A=F'V84@V+39A=BG
M(-BQV*<@V*_8L2#8I]BNV*K9BMBGV+$@V8+8L=BGV+$@V879BN*`C-BOV8?8
MKRX@V*C8L=BGVXP@V878J]BGV80@V*?9BMF&(-BOV+':K]BGV8<@V8;8M-BG
MV88@V879BN*`C-BOV8?8KR#:J=F'(-J&V8;8KR#9AMBGV879A]F4(-BGV83:
MJ=BJV+'9B-F&V8K:J=N,(-BJV*?8LMF'(-BOV+$@V8;8I]F%V8?B@(S8K]BG
MV88@V+39A=BG(-F%V8C8K-F(V*\@V*?8L]BJV(P@VH;9AR#9B-F"V*?9BMBY
MVXP@V+?8J-F"(-BJV8+9B-F*V84@V+39A=BG(-BQV*X@V*_8I]BOV8<@V*?8
ML]BJV(P@VH;9AR#9B-BXV*?9BMF!VXP@V+?8J-F"(-F$V8K8L]BJ(-F(V+C8
MI]F*V8$@V+39A=BG(-BHV8<@V+G9A]BOV8?B@(S8I]BJV*?9AB#8I]BSV*K8
MC"#8L]BQV*K9BMBJV+'9A]BGVXP@V+/8L=F(V8K8L]F'V*?;C"#8KMBHV+';
MC"#8I]F&V*K8KMBGV*C;C"#8M-F%V*<@VH;9BMBSV*H@V8@@+BXN+CPO<&%R
M83X@#0H@(#QP87)A/MF%V*W8JMF(V*?;C"#8I]F*V88@V*_8L=JOV*?9AR#8
MI]BR(-BWV+'9BMF"(-BOVJ_9A=F'V90@V*S8I]F&V878I]BFVXP@V87;C.*`
MC-BJV8C8I]F&V*\@V*C9AR#8M-JIV80@V*_9A-BNV8C8I]F'(-BTV878IR#8
MK]BQV*C9BMBGV8K8KRX@V*C8L=BGVXP@V878J]BGV80@V+39A=BG(-F%VXSB
M@(S8JMF(V*?9AMF*V*\@V879B-BGV+'8KR#8K]F$V*[9B-BGV8<@V*[9B-BO
M(-BQV*<@V*C8L=BGVXP@V8;9A=BGV8K8M"#8K]BQ(-BOV+':K]BGV8<@V8@@
MV8?9A=J&V8;9BMF&(-BJV+'8JMF*V*@@V8;9A=BGV8K8M"#8HMF&V8?8IR#8
ML=BG(-F&V8K8LB#8JMBYV8K9BMF&(-F&V878I]F*V8K8KRX\+W!A<F$^(`T*
M(#PO96YT<GD^#0H@/&5N=')Y(&ED/2)N879B87(B(&UD-3TB8CAC9C!A93$Y
M934W9&9A,&,R8CDV,F4U,38W.#)F-#<B('-T871E/2)U<'1O9&%T92(^#0H@
M(#QT:71L93[:K]BRVXS9AMJOV*?9AB#9A=BQV8C8L=JOV+$@V*C8L=F&V*?9
MA=F'XH",V8?8ISPO=&ET;&4^(`T*("`\<&%R83[8K]BQ(-BSV878JB#8L=BG
MV+/8JB#8I]F*V88@V*_8L=JOV*?9AR#:K]BRVXS9AMJOV*?9AB#9A=BQV8C8
ML=JOV+$@V*C8L=F&V*?9A=F'XH",V8?8I]N,(-JIV*?8L=BHV+'8K]N,(-F"
MV+'8I]BQ(-BOV*?8L=BO(-JIV8<@V*C8IR#9@=BTV+'8K]F&(-BOVJ_9A=F'
M(-F%V8C8LR#8J-BQ(-BQV8C;C"#9A]BQ(-F*VJD@V*?8LB#8I]F*V88@V*C8
ML=F&V*?9A=F'XH",V8?8IR#8J-F'(-BQV*?8K=BJVXP@V87;C.*`C-BJV8C8
MI]F&V8K8KR#8I]BR(-BBV8;9A]BG(-BGV+/8JMF!V*?8K]F'(-F&V878I]F*
MV8K8KRX\+W!A<F$^(`T*(#PO96YT<GD^#0H@/&5N=')Y(&ED/2)P<F5F<RUD
M;U]M86EN=&5N86YC92(@;60U/2)D9#DU9&8P-V$P,S`S,3(S,F)A96$Y,3DR
M.#AB,F0P,"(@<W1A=&4](G5P=&]D871E(CX-"B`@/'1I=&QE/MBJV+'8K-F*
MV*W8I]BJ(#H@V8;:K]F'V*_8I]BQVXP@.B#8I]F&V*S8I]F%(-F&VJ_9A]BO
MV*?8L=N,/"]T:71L93X@#0H@(#QP87)A/MBGVJ_8L2#8M-F%V*<@V878I]F*
MV80@V*C9AR#8I]F&V*S8I]F%(-BYV879A-F*V*?8JB#9AMJOV8?8K]BGV+';
MC"#8J-F'(-F'V8;:K]BGV84@V8C8L=F(V*\@V87;C.*`C-BHV*?8M-F*V*\@
MV*?9BMF&(-JOV++9BMF&V8<@V+'8IR#8J-BGV8K8KR#8I]F&V*K8KMBGV*@@
MVJG9AMF*V*\N/"]P87)A/B`-"B`\+V5N=')Y/@T*(#QE;G1R>2!I9#TB<')E
M9G,M8V]N9FER;5]M86EN=&5N86YC92(@;60U/2)A,C$Q-C)C9&9F,V(Q9#AF
M865A9&(W,CDV,C0P,#,V92(@<W1A=&4](G5P=&]D871E(CX-"B`@/'1I=&QE
M/MBJV+'8K-F*V*W8I]BJ(#H@V8;:K]F'V*_8I]BQVXP@.B#8JMBCV*;9BMBO
M(-F&VJ_9A]BOV*?8L=N,/"]T:71L93X@#0H@(#QP87)A/MBGVJ_8L2#8M-F%
MV*<@V878I]F*V80@V8?8L]BJV8K8KR#:J=F'(-BYV879A-F*V*?8JB#9AMJO
MV8?8K]BGV+';C"#8L=BG(-F"V*C9A"#8I]BR(-BGV8;8K-BGV84@V*+9AMF'
MV*<@V*K8H]BFV8K8KR#:J=F&V8K8K]B,(-BGV8K9AB#:K]BRV8K9AMF'(-BQ
MV*<@V*?9AMBJV*[8I]BH(-JIV8;9BMBO+B#8K]BQ(-BZV8K8L2#8I]F*V88@
MV+79B-BQV*H@V*K9A=BGV84@V+G9A=F$V8K8I]BJ(-F&VJ_9A]BOV*?8L=N,
M(-BHV8<@V8?9AMJOV*?9A2#9B-BQV8C8KR#8I]F&V*S8I]F%(-F*V*?9@=BJ
MV8<@V8@@V+39A=BG(-BTV*?9AMBSVXP@V*C8L=BGVXP@V879A-BZVXP@VJG8
ML=BOV88@V*+9AB#9AMBNV8C8I]F'V8K8KR#8K]BGV+38JBX\+W!A<F$^(`T*
M(#PO96YT<GD^#0H\+VAE;'`^````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O96Y?55,`````````````
M````````````````````````````````````````````````````````````
M````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@
M,3`U,34T,S,W-#$@,#$W-S(W`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L
M92]E;E]54R]H96QP+GAM;```````````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,S$Q-"`Q,#4Q-30S,S<T,2`P,C$T-3<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]X;6P@=F5R<VEO
M;CTB,2XP(C\^"CQH96QP/@H*/&5N=')Y(&ED/2)S=6UM87)Y(CX*/'1I=&QE
M/E1H92!0;W)T86P@4&%G93PO=&ET;&4^"B`\<&%R83X*("!4:&ES('!O<G1A
M;"!P86=E('!R;W9I9&5S(&$@<75I8VL@<W5M;6%R>2!O9B!A;&P@>6]U<B!I
M;7!O<G1A;G0*("!I;F9O<FUA=&EO;BX@1F]R(&5X86UP;&4L(&ET(&UI9VAT
M('-H;W<@:&]W(&UA;GD@;F5W(&4M;6%I;"!M97-S86=E<R!Y;W4*("!H879E
M(&EN('EO=7(@24Y"3U@L('5P8V]M:6YG(&5V96YT<R!O;B!Y;W5R(&-A;&5N
M9&%R+"!T87-K<R!O;B!Y;W5R('1O+61O"B`@;&ES="P@:&5A9&QI;F5S(&9R
M;VT@<V5L96-T960@;F5W<R!S97)V:6-E<RP@86YD('-O(&]N+B`@36%N>2!O
M9B!T:&5S90H@('-U;6UA<FEE<R!W:6QL(&-O;G1A:6X@<75I8VL@<VAO<G1C
M=71S('1O(&-O;6UO;B!F=6YC=&EO;G,L('-U8V@@87,*("!C;VUP;W-I;F<@
M82!N97<@;6%I;"!M97-S86=E+"!C<F5A=&EN9R!A(&YE=R!C86QE;F1A<B!E
M=F5N="!O<B!T87-K+"!E=&,N"B`\+W!A<F$^"B`\<&%R83X*("!4:&4@8V]N
M=&5N=',@;V8@=&AI<R!P;W)T86P@<&%G92!A<F4@8W5S=&]M:7IA8FQE('9I
M82!T:&4@3&%Y;W5T(&)U='1O;BX*("!&;W(@97AA;7!L92P@>6]U(&-A;B!C
M:&]O<V4@=VAI8V@@:71E;7,@=&\@:6YC;'5D92!O;B!T:&ES('!O<G1A;"!P
M86=E(&%S"B`@=V5L;"!A<R!I;B!W:&EC:"!O<F1E<B!T:&5Y(&%R92!S:&]W
M;BX*(#PO<&%R83X*/"]E;G1R>3X*"CQE;G1R>2!I9#TB;F%V8F%R(CX*/'1I
M=&QE/E1H92!!<'!L:6-A=&EO;B!.879I9V%T:6]N($)A<CPO=&ET;&4^"B`\
M<&%R83X*("!!="!T:&4@;&5F="!H86YD('-I9&4@;V8@=&AE('=E8B!P86=E
M(&ES('1H92!A<'!L:6-A=&EO;B!N879I9V%T:6]N(&)A<BX*("!#;&EC:R!O
M;B!T:&4@:6-O;G,@;VX@=&AI<R!N879I9V%T:6]N(&)A<B!T;R!Q=6EC:VQY
M(&%N9"!E87-I;'D@<W=I=&-H"B`@8F5T=V5E;B!T:&4@879A:6QA8FQE(&%P
M<&QI8V%T:6]N<RX*(#PO<&%R83X*/"]E;G1R>3X*"CQE;G1R>2!I9#TB<')E
M9G,M9&]?;6%I;G1E;F%N8V4B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-
M86EN=&5N86YC93H@1&\@36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^
M"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!P97)F;W)M(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,@;VX@;&]G:6XL(&-H96-K('1H:7,@8F]X+@H@("`@/"]P
M87)A/@H\+V5N=')Y/@H*/&5N=')Y(&ED/2)P<F5F<RUC;VYF:7)M7VUA:6YT
M96YA;F-E(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z
M($-O;F9I<FT@36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)
M9B!Y;W4@=V]U;&0@;&EK92!T;R!C;VYF:7)M(&%L;"!M86EN=&5N86YC92!T
M87-K<R!B969O<F4@=&AE>2!A<F4@<G5N+"!C:&5C:R!T:&ES(&)O>"X@268@
M;&5F="!U;F-H96-K960L(&%L;"!M86EN=&5N86YC92!O<&5R871I;VYS('1H
M870@;F5E9"!T;R!B92!R=6X@=VEL;"!B92!P97)F;W)M960@875T;VUA=&EC
M86QL>2!W:71H(&YO(&-H86YC92!T;R!C86YC96P@;VX@;&]G:6XN"B`@("`\
M+W!A<F$^"CPO96YT<GD^"@H\+VAE;'`^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O97-?
M15,`````````````````````````````````````````````````````````
M````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`P,#`@,3`U,34T,S,W-#$@,#$W-S$T`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQO8V%L92]E<U]%4R],0U]-15-304=%4P``````````````````
M```````````````````````````````````````````````````P,#`W-34@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<T,2`P,C$U
M,#$`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+V5S7T53+TQ#7TU%4U-!
M1T53+VAO<F1E+FUO````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P-#(Q-S,T
M(#$P-3$U-#,S-S0Q(#`R,S(S,0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#>$@25`````(H'```<````;#P``!,*``"\>```
M``````BA```.````":$```\````8H0``#0```"BA```(````-J$```L````_
MH0``#````$NA```$````6*$``!@```!=H0``&P```':A```M````DJ$``!T`
M``#`H0``)````-ZA```I`````Z(``!D````MH@``)@```$>B```,````;J(`
M`"0```![H@``#P```*"B```+````L*(```X```"\H@``!0```,NB```H````
MT:(```@```#ZH@``"@````.C```5````#J,``!(````DHP``"P```#>C``"%
M````0Z,```X```#)HP``"@```-BC```-````XZ,```X```#QHP``$0````"D
M```-````$J0```P````@I```#0```"VD```&````.Z0``)0```!"I```"@``
M`->D```/````XJ0``!@```#RI```#`````NE```.````&*4```X````GI0``
M"````#:E```)````/Z4``"X```!)I0``&@```'BE```R````DZ4``#@```#&
MI0``5````/^E``!1````5*8``%H```"FI@``5P````&G```T````6:<```D`
M``".IP``#0```)BG```'````IJ<```H```"NIP``#P```+FG```%````R:<`
M``8```#/IP``$0```-:G```(````Z*<```D```#QIP``"0```/NG```E````
M!:@``"`````KJ```$P```$RH```0````8*@```\```!QJ```"@```(&H```#
M````C*@```\```"0J```%````*"H```)````M:@```T```"_J```$@```,VH
M```9````X*@``!X```#ZJ```#P```!FI```*````*:D```\````TJ0``"```
M`$2I```D````3:D``!0```!RJ0``%@```(>I```(````GJD``$X```"GJ0``
M+0```/:I```9````)*H```<````^J@``#````$:J```L````4ZH```X```"`
MJ@```P```(^J```+````DZH```<```"?J@``!P```*>J```%````KZH```4`
M``"UJ@``"@```+NJ```#````QJH``!<```#*J@``"@```.*J```/````[:H`
M``X```#]J@``&`````RK```C````):L```X```!)JP``%````%BK```7````
M;:L``!<```"%JP``%P```)VK```3````M:L```\```#)JP``#@```-FK```?
M````Z*L``!T````(K```!P```":L```&````+JP```@````UK```#P```#ZL
M```&````3JP```H```!5K```$P```&"L```+````=*P``!````"`K```%0``
M`)&L```5````IZP```<```"]K```$````,6L```%````UJP``!4```#<K```
M$0```/*L```,````!*T``#L````1K0``.````$VM```)````AJT```<```"0
MK0``%````)BM```#````K:T```4```"QK0``$````+>M```)````R*T``!,`
M``#2K0``.0```.:M```2````(*X``"<````SK@``+````%NN```J````B*X`
M`"4```"SK@``"@```-FN```&````Y*X```D```#KK@``!P```/6N```O````
M_:X``#<````MKP``+@```&6O``!5````E*\``"T```#JKP``+0```!BP```]
M````1K```#\```"$L```+0```,2P``!`````\K```",````SL0``(P```%>Q
M``!`````>[$``"T```"\L0``,P```.JQ```E````'K(``!4```!$L@``&0``
M`%JR```I````=+(``"0```">L@``*````,.R```1````[+(```H```#^L@``
M#`````FS```*````%K,``!`````ALP``%@```#*S```6````2;,```<```!@
MLP``!P```&BS```4````<+,```H```"%LP``"````)"S```G````F;,```@`
M``#!LP``!P```,JS```'````TK,```8```#:LP``!0```.&S```'````Y[,`
M``8```#OLP``"````/:S```I````_[,```X````IM```"@```#BT```$````
M0[0```<```!(M```"0```%"T```&````6K0``!$```!AM```!P```'.T```6
M````>[0```0```"2M```"````)>T```&````H+0```T```"GM```!@```+6T
M```>````O+0``!$```#;M```"````.VT```-````]K0```P````$M0``!P``
M`!&U```#````&;4```,````=M0``%P```"&U```3````.;4``!T```!-M0``
M"````&NU```$````=+4```@```!YM0``"````(*U```[````B[4``#0```#'
MM0``00```/RU```:````/K8``"L```!9M@``(````(6V```5````IK8```8`
M``"\M@``!@```,.V```5````RK8``!@```#@M@``(@```/FV```N````'+<`
M`!T```!+MP``(0```&FW``!4````B[<``"D```#@MP``"@````JX```'````
M%;@```<````=N```%0```"6X```.````.[@```H```!*N```#P```%6X```-
M````9;@```\```!SN```#0```(.X```)````D;@``!0```";N```!@```+"X
M```8````M[@``!T```#0N```$P```.ZX```1`````KD``!0````4N0``!```
M`"FY```&````+KD``!0````UN0``5````$JY``!D````G[D```0````$N@``
M#@````FZ```%````&+H```4````>N@``&P```"2Z```:````0+H``!,```!;
MN@``$0```&^Z```1````@;H``!P```"3N@``*@```+"Z```0````V[H``"$`
M``#LN@``!0````Z[```3````%+L```L````HNP``$@```#2[```*````1[L`
M``\```!2NP``#0```&*[```1````<+L``!,```""NP``#````):[```&````
MH[L```P```"JNP``!@```+>[```7````OKL``!````#6NP``$0```.>[```(
M````^;L```4````"O```#`````B\```0````%;P```4````FO```#0```"R\
M```&````.KP```<```!!O```#0```$F\```'````5[P```L```!?O```!P``
M`&N\```'````<[P```D```![O```"0```(6\```*````C[P``!D```":O```
M/0```+2\```=````\KP```P````0O0``$````!V]```%````+KT``"4````T
MO0``$@```%J]```3````;;T``"L```"!O0``.P```*V]```@````Z;T```@`
M```*O@``-@```!.^```A````2KX``!````!LO@``"````'V^```,````AKX`
M``8```"3O@``!````)J^```/````G[X```X```"OO@``!P```+Z^```*````
MQKX```T```#1O@``'P```-^^```<````_[X``"$````<OP``'@```#Z_```9
M````7;\``!X```!WOP``&P```):_```A````LK\``"X```#4OP``)@````/`
M```<````*L```!X```!'P```'````&;````F````@\```"L```"JP```,P``
M`-;````F````"L$``"L````QP0``.````%W!```=````EL$``!4```"TP0``
M+P```,K!```@````^L$``!(````;P@``*0```"["```>````6,(``"````!W
MP@``$@```)C"``"B````J\(``!8```!.PP``(P```&7#```H````B<,``"D`
M``"RPP``*````-S#```?````!<0``!4````EQ```(````#O$```E````7,0`
M`"@```""Q```+0```*O$```P````V<0``)(````*Q0``(0```)W%```6````
MO\4``!P```#6Q0``)@```//%```J````&L8``$$```!%Q@``1````(?&```,
M````S,8```<```#9Q@``!P```.'&```&````Z<8```T```#PQ@``$````/[&
M```2````#\<``!,````BQP``$@```#;'```'````2<<```0```!1QP``$```
M`%;'```0````9\<```P```!XQP``#@```(7'```-````E,<```\```"BQP``
M$P```++'```-````QL<``"@```#4QP```P```/W'```-`````<@```8````/
MR```$0```!;(```7````*,@``!L```!`R```#@```%S(```"````:\@``$D`
M``!NR```!0```+C(```0````OL@```\```#/R```!````-_(```-````Y,@`
M``X```#RR````P````')```.````!<D```@````4R0``#P```!W)```/````
M+<D```<````]R0``#0```$7)```0````4\D```T```!DR0``"P```'+)```&
M````?LD```L```"%R0``#````)')```*````GLD``!$```"IR0``&0```+O)
M```+````U<D```T```#AR0``(@```._)```/````$LH``!L````BR@``-```
M`#[*```*````<\H``!@```!^R@``$@```)?*```9````JLH``!8```#$R@``
M(@```-O*```-````_LH```<````,RP``%````!3+```+````*<L``"(````U
MRP``+P```%C+```+````B,L```D```"4RP``&0```)[+```+````N,L``!<`
M``#$RP``%P```-S+```)````],L``!8```#^RP``#P```!7,```9````)<P`
M`!8````_S```#@```%;,```8````9<P```@```!^S```#0```(?,```F````
ME<P``$,```"\S```"`````#-```2````"<T``!\````<S0``"````#S-```+
M````1<T``"\```!1S0``#@```('-```%````D,T```8```"6S0``10```)W-
M```#````X\T```<```#GS0``!````._-```*````],T```H```#_S0``#P``
M``K.```0````&LX``!<````KS@``$0```$/.```9````5<X``!<```!OS@``
M"0```(?.```%````D<X```L```"7S@``"@```*/.```"````KLX```4```"Q
MS@``#0```+?.```;````Q<X``!<```#AS@``%````/G.```)````#L\```X`
M```8SP``#0```"?/```2````-<\``#@```!(SP``(````('/```(````HL\`
M``X```"KSP``>P```+K/```8````-M```!@```!/T```$0```&C0```'````
M>M````4```""T```&````(C0```>````H=```!L```#`T```&0```-S0```;
M````]M```!D````2T0``$P```"S1```'````0-$```@```!(T0``!@```%'1
M```&````6-$``!````!?T0``#P```'#1```0````@-$```\```"1T0``"P``
M`*'1```/````K=$```P```"]T0``#P```,K1```'````VM$```8```#BT0``
M#@```.G1```,````^-$``"@````%T@``#P```"[2```(````/M(```@```!'
MT@``$P```%#2```>````9-(``"$```"#T@``(````*72```9````QM(``!<`
M``#@T@``)0```/C2```7````'M,``!8````VTP``!````$W3```;````4M,`
M``T```!NTP``#````'S3```#````B=,```4```"-TP``"````)/3```*````
MG-,```P```"GTP``"P```+33```0````P-,```P```#1TP``#@```-[3```+
M````[=,```0```#YTP``!````/[3```3`````]0``!0````7U```#````"S4
M```)````.=0```X```!#U```"P```%+4```;````7M0```<```!ZU```!P``
M`(+4```*````BM0```T```"5U```"0```*/4```$````K=0```4```"RU```
M`P```+C4```8````O-0```H```#5U```!````.#4```F````Y=0```X````,
MU0``?````!O5```5````F-4```4```"NU0``!P```+35```,````O-4```@`
M``#)U0``"@```-+5```&````W=4```@```#DU0```@```.W5```&````\-4`
M``8```#WU0``%````/[5```-````$]8``!`````AU@``&P```#+6```$````
M3M8```D```!3U@``$````%W6```)````;M8```D```!XU@``!0```(+6```:
M````B-8```@```"CU@``!@```*S6```9````L]8```X```#-U@``!P```-S6
M```'````Y-8```4```#LU@``"0```/+6```*````_-8```X````'UP```@``
M`!;7```&````&=<```L````@UP``#0```"S7```)````.M<```8```!$UP``
M$@```$O7```)````7M<```<```!HUP``%````'#7```=````A=<``$(```"C
MUP``)0```.;7```E````#-@```8````RV```"@```#G8```$````1-@```D`
M``!)V```"````%/8```1````7-@```D```!NV```!@```'C8```-````?]@`
M``8```"-V```!````)38```Y````F=@``#T```#3V```.@```!'9```>````
M3-D```4```!KV0``#@```''9```$````@-D```8```"%V0``!P```(S9```A
M````E-D```T```"VV0``%0```,39```&````VMD```0```#AV0``$0```.;9
M```&````^-D```H```#_V0``(@````K:```$````+=H```4````RV@``'0``
M`#C:```$````5MH```P```!;V@``#@```&C:```*````=]H```@```""V@``
M"0```(O:```%````E=H``#H```";V@``,````-;:```U````!]L``"D````]
MVP``1P```&?;```X````K]L``"D```#HVP``/P```!+<```N````4MP``"T`
M``"!W```'P```*_<```/````S]P``!(```#?W```"P```/+<```F````_MP`
M`"D````EW0``)````$_=```F````=-T```@```";W0``"@```*3=```)````
MK]T```<```"YW0``(````,'=```@````XMT``"8````#W@``"@```"K>```9
M````-=X``"D```!/W@``%@```'G>```2````D-X```<```"CW@``"@```*O>
M```,````MMX```\```##W@``$````-/>``!`````Y-X``'`````EWP``9@``
M`);?```.````_=\```D````,X```"@```!;@```2````(>```!,````TX```
M#````$C@```&````5>````\```!<X```$@```&S@```0````?^```!$```"0
MX```'````*+@```C````O^```&H```#CX```#P```$[A```%````7N$``!``
M``!DX0``"0```'7A```$````?^$```L```"$X0``(````)#A```4````L>$`
M``P```#&X0``#````-/A```/````X.$``!4```#PX0``*0````;B```J````
M,.(``"8```!;X@``)P```(+B```I````JN(``"H```#4X@``&0```/_B``!"
M````&>,``!$```!<XP``$@```&[C```3````@>,``!0```"5XP``#P```*KC
M```6````NN,``!<```#1XP``$````.GC```1````^N,``#0````,Y```$P``
M`$'D```2````5>0``#4```!HY```%````)[D```'````L^0```P```"[Y```
M(````,CD```0````Z>0``!0```#ZY```$0````_E```7````(>4``!P````Y
MY0``$P```%;E```4````:N4``!H```!_Y0``$0```)KE```:````K.4``!X`
M``#'Y0``&@```.;E```3`````>8``!4````5Y@``$0```"OF```7````/>8`
M`!0```!5Y@``%P```&KF```5````@N8```D```"8Y@``$````*+F```9````
ML^8```0```#-Y@``!P```-+F```+````VN8``!$```#FY@``!@```/CF```&
M````_^8```8````&YP``!0````WG```'````$^<```<````;YP``!0```"/G
M```6````*><```8```!`YP``!@```$?G```$````3N<```0```!3YP``!P``
M`%CG```.````8.<```P```!OYP``#````'SG```-````B><```H```"7YP``
M#@```*+G```%````L><``"@```"WYP``#@```.#G```,````[^<```\```#\
MYP``"@````SH```(````%^@```D````@Z```*P```"KH```$````5N@```@`
M``!;Z```)@```&3H```2````B^@```\```">Z```!@```*[H```*````M>@`
M``<```#`Z```"````,CH```@````T>@```D```#RZ```%````/SH```,````
M$>D```T````>Z0``#@```"SI```6````.^D``!$```!2Z0``!@```&3I```#
M````:^D```8```!OZ0``&0```';I```'````D.D```0```"8Z0``"P```)WI
M```+````J>D```<```"UZ0``!0```+WI```'````P^D``!8```#+Z0``#0``
M`.+I```-````\.D```H```#^Z0``$`````GJ```/````&NH``!$````JZ@``
M%P```#SJ```*````5.H``!$```!?Z@``"````''J```$````>NH```\```!_
MZ@``.@```(_J```%````RNH```P```#0Z@``'@```-WJ```.````_.H``!``
M```+ZP``"P```!SK```,````*.L```D````UZP``!P```#_K```*````1^L`
M``D```!2ZP``#@```%SK```0````:^L``!L```!\ZP``&````)CK```:````
ML>L```H```#,ZP``"0```-?K```*````X>L```P```#LZP``#P```/GK```(
M````">P```8````2[```'````!GL```'````-NP```4````^[```"P```$3L
M``!'````4.P```T```"8[```"0```*;L```$````L.P```,```"U[```$P``
M`+GL```3````S>P``!,```#A[```"@```/7L```"`````.T```0````#[0``
M)0````CM```#````+NT```4````R[0``*@```#CM```*````8^T```4```!N
M[0``!````'3M```*````>>T```T```"$[0``!@```)+M```(````F>T```@`
M``"B[0``!````*OM```%````L.T``&@```"V[0``"0```!_N```,````*>X`
M`!`````V[@``!0```$?N```&````3>X``!L```!4[@``+P```'#N```0````
MH.X```H```"Q[@``#P```+SN```*````S.X```D```#7[@``$P```.'N```;
M````]>X``!@````1[P``%P```"KO```?````0N\```X```!B[P```P```''O
M```'````=>\```@```!][P``!P```(;O```*````CN\```L```"9[P``!P``
M`*7O``!1````K>\``!````#_[P``#````!#P```-````'?```!H````K\```
M2@```$;P```9````D?````8```"K\```&@```++P```E````S?````8```#S
M\```!@```/KP```?`````?$```8````A\0``"0```"CQ```8````,O$``!<`
M``!+\0``*````&/Q```&````C/$```T```"3\0``(@```*'Q``!7````Q/$`
M`!,````<\@``(P```##R```3````5/(```(```!H\@``"P```&OR```(````
M=_(```T```"`\@``"@```([R```'````F?(``!0```"A\@``!@```+;R```(
M````O?(```X```#&\@``!P```-7R```*````W?(```L```#H\@``,@```/3R
M```'````)_,```P````O\P``#0```#SS```7````2O,```P```!B\P``"0``
M`&_S```)````>?,```H```"#\P``!P```([S```)````EO,```<```"@\P``
M"@```*CS```;````L_,```\```#/\P``$@```-_S```*````\O,``!8```#]
M\P``"0```!3T```0````'O0```<````O]```$@```#?T```$````2O0```<`
M``!/]```!0```%?T```%````7?0```L```!C]```%````&_T```1````A/0`
M`!H```"6]```%@```+'T```4````R/0``!<```#=]```&````/7T```<````
M#O4``!D````K]0``!P```$7U```%````3?4```T```!3]0``#````&'U```(
M````;O4``!<```!W]0``"P```(_U```,````F_4``!\```"H]0``&@```,CU
M```3````X_4```0```#W]0``"@```/SU```$````!_8```T````,]@``#```
M`!KV```%````)_8```D````M]@``!0```#?V```'````/?8```4```!%]@``
M!````$OV```"````4/8``#@```!3]@``+````(SV```2````N?8``"D```#,
M]@``,@```/;V```*````*?<``"P````T]P``+@```&'W```S````D/<``#,`
M``#$]P``.````/CW```/````,?@``!@```!!^```$````%KX```/````:_@`
M`!,```![^```%0```(_X```4````I?@``!(```"Z^```%````,WX```5````
MXO@``"T```#X^```+0```";Y```Q````5/D``"X```"&^0``+P```+7Y```L
M````Y?D``&(````2^@``$P```'7Z```-````B?H```@```"7^@``%P```*#Z
M```(````N/H```P```#!^@``*P```,[Z```A````^OH``!H````<^P``"0``
M`#?[``!%````0?L``$$```"'^P``!````,G[```3````SOL``!0```#B^P``
M#@```/?[```3````!OP``!@````:_```!@```#/\```)````.OP```H```!$
M_```#P```$_\```0````7_P```<```!P_```#@```'C\```%````A_P``!L`
M``"-_```"````*G\```&````LOP``!0```"Y_```$0```,[\```.````X/P`
M`#@```#O_````@```"C]```&````*_T```X````R_0``!0```$']```'````
M1_T```X```!/_0``!@```%[]```H````9?T```P```"._0``'````)O]```$
M````N/T``"D```"]_0``%P```.?]```?````__T``%P````?_@``%````'S^
M```^````D?X``!\```#0_@``$````/#^```'`````?\```X````)_P``#```
M`!C_```,````)?\``!,````R_P``"@```$;_```=````4?\``!D```!O_P``
M!0```(G_```1````C_\``!$```"A_P``)````+/_```2````V/\``!4```#K
M_P``$@````$``0`.````%``!`!D````C``$`"````#T``0`)````1@`!``T`
M``!0``$`!P```%X``0`*````9@`!``<```!Q``$`#P```'D``0`&````B0`!
M``L```"0``$`&@```)P``0`*````MP`!``<```#"``$`"````,H``0`%````
MTP`!`!\```#9``$`!@```/D``0`0``````$!``@````1`0$`#0```!H!`0`(
M````*`$!`!X````Q`0$`$@```%`!`0`L````8P$!`!H```"0`0$`"0```*L!
M`0`*````M0$!`!4```#``0$`!0```-8!`0`4````W`$!``0```#Q`0$`$```
M`/8!`0`&````!P(!``<````.`@$`'@```!8"`0`H````-0(!``H```!>`@$`
M'````&D"`0`1````A@(!``L```"8`@$`&@```*0"`0`4````OP(!``0```#4
M`@$`!````-D"`0`+````W@(!``4```#J`@$`!@```/`"`0`(````]P(!``8`
M`````P$`"@````<#`0`;````$@,!`#0````N`P$`-````&,#`0`@````F`,!
M`"D```"Y`P$`(````.,#`0!!````!`0!`!H```!&!`$`*````&$$`0`I````
MB@0!`%````"T!`$`(@````4%`0`&````*`4!``@````O!0$`!0```#@%`0`(
M````/@4!`!D```!'!0$`&0```&$%`0`J````>P4!`",```"F!0$`&0```,H%
M`0`N````Y`4!`#0````3!@$`"````$@&`0`7````408!``H```!I!@$`!P``
M`'0&`0`A````?`8!`!````">!@$`#@```*\&`0`+````O@8!``<```#*!@$`
M$P```-(&`0`(````Y@8!``L```#O!@$`"@```/L&`0`4````!@<!``\````;
M!P$`,@```"L'`0`+````7@<!``X```!J!P$`!0```'D'`0`%````?P<!``4`
M``"%!P$`%P```(L'`0`/````HP<!``0```"S!P$`"@```+@'`0`)````PP<!
M``L```#-!P$`#0```-D'`0`,````YP<!``X```#T!P$`!0````,(`0`$````
M"0@!``T````."`$`,@```!P(`0!%````3P@!`!<```"5"`$`!P```*T(`0`>
M````M0@!`!0```#4"`$`!0```.D(`0`4````[P@!``8````$"0$`!P````L)
M`0`.````$PD!`"H````B"0$`!@```$T)`0`,````5`D!``T```!A"0$`$0``
M`&\)`0`+````@0D!`#8```"-"0$`"@```,0)`0`B````SPD!``L```#R"0$`
M#P```/X)`0`R````#@H!`"4```!!"@$`,````&<*`0`Q````F`H!`"T```#*
M"@$`#@```/@*`0`%````!PL!``X````-"P$`$P```!P+`0`2````,`L!``<`
M``!#"P$`$0```$L+`0`3````70L!``<```!Q"P$`%````'D+`0`8````C@L!
M``<```"G"P$`!0```*\+`0`,````M0L!``P```#""P$`$@```,\+`0`$````
MX@L!``<```#G"P$`"@```.\+`0`+````^@L!``P````&#`$`#@```!,,`0`.
M````(@P!``4````Q#`$`!0```#<,`0`N````/0P!`"8```!L#`$`(P```),,
M`0`#````MPP!`!(```"[#`$`!@```,X,`0`>````U0P!`!@```#T#`$`)0``
M``T-`0`-````,PT!``D```!!#0$`'P```$L-`0`#````:PT!``<```!O#0$`
M"@```'<-`0`"````@@T!``P```"%#0$`%0```)(-`0`+````J`T!`!D```"T
M#0$`(````,X-`0`2````[PT!``4````"#@$`"@````@.`0`5````$PX!`!(`
M```I#@$`#````#P.`0`$````20X!``D```!.#@$`!P```%@.`0`,````8`X!
M`%(```!M#@$`%P```,`.`0`D````V`X!`!(```#]#@$`!P```!`/`0`&````
M&`\!``X````?#P$`#````"X/`0`-````.P\!`!4```!)#P$`$@```%\/`0`/
M````<@\!`!0```""#P$`"@```)</`0`;````H@\!`!````"^#P$`"P```,\/
M`0!I````VP\!`!H```!%$`$`%P```&`0`0`G````>!`!`!H```"@$`$`%P``
M`+L0`0`;````TQ`!`!D```#O$`$`'P````D1`0`3````*1$!``@````]$0$`
M!P```$81`0`(````3A$!``D```!7$0$`%0```&$1`0`-````=Q$!`",```"%
M$0$`#0```*D1`0`3````MQ$!``@```#+$0$``P```-01`0!&````V!$!`#\`
M```?$@$`-P```%\2`0!7````EQ(!``4```#O$@$`'P```/42`0`O````%1,!
M``H```!%$P$`"````%`3`0`-````61,!`"T```!G$P$`!````)43`0!/````
MFA,!`"4```#J$P$`'````!`4`0`+````+10!`!\````Y%`$`'0```%D4`0`E
M````=Q0!`"````"=%`$`)````+X4`0`@````XQ0!``L````$%0$`!P```!`5
M`0`-````&!4!``P````F%0$`%P```#,5`0`&````2Q4!`#D```!2%0$`#```
M`(P5`0`'````F14!``D```"A%0$`$P```*L5`0`)````OQ4!``0```#)%0$`
M$````,X5`0`(````WQ4!``@```#H%0$`!````/$5`0`+````]A4!``P````"
M%@$`$@````\6`0`1````(A8!``P````T%@$`&@```$$6`0`/````7!8!``<`
M``!L%@$`#0```'06`0`4````@A8!``X```"7%@$`#````*86`0`;````LQ8!
M`"P```#/%@$`$P```/P6`0`<````$!<!`"@````M%P$`!@```%87`0`'````
M71<!`!,```!E%P$`!0```'D7`0`$````?Q<!`!<```"$%P$`"@```)P7`0`,
M````IQ<!``D```"T%P$`!@```+X7`0`)````Q1<!``@```#/%P$`"0```-@7
M`0`*````XA<!`!$```#M%P$`!@```/\7`0`.````!A@!``X````5&`$`#0``
M`"08`0`+````,A@!`!T````^&`$`"P```%P8`0`"````:!@!`!P```!K&`$`
M!P```(@8`0`&````D!@!`&0```"7&`$`"0```/P8`0`'````!AD!`"8````.
M&0$`.````#49`0`:````;AD!`"H```")&0$`.P```+09`0`H````\!D!`#0`
M```9&@$`&0```$X:`0`5````:!H!``4```!^&@$`!P```(0:`0`(````C!H!
M``<```"5&@$`!0```)T:`0`'````HQH!``X```"K&@$`"0```+H:`0`&````
MQ!H!``@```#+&@$`"P```-0:`0`'````X!H!``@```#H&@$`!P```/$:`0`6
M````^1H!``D````0&P$`!@```!H;`0`+````(1L!`!`````M&P$`!@```#X;
M`0`<````11L!`!0```!B&P$`!P```'<;`0`1````?QL!``@```"1&P$`#@``
M`)H;`0`(````J1L!`!````"R&P$`"0```,,;`0`0````S1L!``8```#>&P$`
M&0```.4;`0`*````_QL!`!P````*'`$`!P```"<<`0`%````+QP!`!`````U
M'`$`%````$8<`0`+````6QP!``T```!G'`$`*````'4<`0`8````GAP!`!<`
M``"W'`$`!````,\<`0`)````U!P!``H```#>'`$`!P```.D<`0`"````\1P!
M``X```#T'`$`"`````,=`0`C````#!T!`!\````P'0$`.````%`=`0`F````
MB1T!`#$```"P'0$`)P```.(=`0!D````"AX!`!0```!O'@$`50```(0>`0`X
M````VAX!`$H````3'P$`6P```%X?`0`H````NA\!`#@```#C'P$`*````!P@
M`0`L````12`!`!L```!R(`$`/@```(X@`0"I`0``S2`!`",```!W(@$`%P``
M`)LB`0!(````LR(!`(4```#\(@$`,````((C`0`E````LR,!`$$```#9(P$`
M6P```!LD`0!)````=R0!`#$```#!)`$`'0```/,D`0`8````$24!`"L````J
M)0$`(0```%8E`0`?````>"4!`"L```"8)0$`)@```,0E`0`G````ZR4!`#H`
M```3)@$`'0```$XF`0`1````;"8!`#,```!^)@$`)0```+(F`0`G````V"8!
M`"``````)P$`'P```"$G`0`P````02<!`&D```!R)P$`,0```-PG`0!!````
M#B@!`#,```!0*`$`)0```(0H`0`]````JB@!`&4```#H*`$`30```$XI`0`O
M````G"D!`"X```#,*0$`,````/LI`0!4````+"H!`%H```"!*@$`2````-PJ
M`0!*````)2L!`#(```!P*P$`+P```*,K`0`L````TRL!`"T`````+`$`<0``
M`"XL`0!F````H"P!`&\````'+0$`LP```'<M`0`7````*RX!`"4```!#+@$`
M,@```&DN`0`I````G"X!`#X```#&+@$`(@````4O`0!2````*"\!`"4```![
M+P$`"P```*$O`0"Q````K2\!`$4```!?,`$`(0```*4P`0`P````QS`!`"4`
M``#X,`$`'````!XQ`0`Q````.S$!``<```!M,0$`!P```'4Q`0`$````?3$!
M``T```"",0$`"P```)`Q`0`.````G#$!``L```"K,0$`!0```+<Q`0`0````
MO3$!``(```#.,0$`60```-$Q`0`%````*S(!`!(````Q,@$`!````$0R`0`'
M````23(!``@```!1,@$`!0```%HR`0`P````8#(!``,```"1,@$`$````)4R
M`0`,````IC(!`!,```"S,@$`#0```,<R`0`"````U3(!``<```#8,@$`!@``
M`.`R`0`4````YS(!``P```#\,@$`&`````DS`0`&````(C,!`!(````I,P$`
M#````#PS`0`#````23,!`"H```!-,P$`!````'@S`0`&````?3,!``<```"$
M,P$`'P```(PS`0`U````K#,!`"X```#B,P$`+P```!$T`0`7````030!`"(`
M``!9-`$`)0```'PT`0`@````HC0!`!L```##-`$`&````-\T`0`D````^#0!
M`!\````=-0$`&@```#TU`0`A````6#4!`"````!Z-0$`&@```)LU`0`R````
MMC4!`!H```#I-0$`+P````0V`0`K````-#8!`!\```!@-@$`(P```(`V`0`?
M````I#8!`!H```#$-@$`(0```-\V`0`E`````3<!`"8````G-P$`)0```$XW
M`0`D````=#<!`!@```"9-P$`'0```+(W`0`D````T#<!`!@```#U-P$`(@``
M``XX`0`L````,3@!`"\```!>.`$`%0```(XX`0`E````I#@!`#P```#*.`$`
M'P````<Y`0`C````)SD!`!\```!+.0$`(````&LY`0`:````C#D!`!@```"G
M.0$`*0```,`Y`0`>````ZCD!`"D````).@$`'@```#,Z`0`Q````4CH!``D`
M``"$.@$`#````(XZ`0`7````FSH!`"\```"S.@$`)````.,Z`0`'````"#L!
M``\````0.P$`%````"`[`0`.````-3L!``T```!$.P$`)````%([`0`%````
M=SL!``<```!].P$`(@```(4[`0`E````J#L!`!H```#..P$`'0```.D[`0`:
M````!SP!``<````B/`$`QP```"H\`0`+````\CP!`!4```#^/`$`!@```!0]
M`0`)````&ST!``L````E/0$`#0```#$]`0`7````/ST!``8```!7/0$`,P``
M`%X]`0`3````DCT!`!,```"F/0$`!P```+H]`0`/````PCT!``<```#2/0$`
M,@```-H]`0`$````#3X!`"$````2/@$`$P```#0^`0`,````2#X!`!$```!5
M/@$`,@```&<^`0`6````FCX!``@```"Q/@$`'0```+H^`0`)````V#X!``H`
M``#B/@$`%````.T^`0`*`````C\!`!T````-/P$`"````"L_`0`?````-#\!
M``@```!4/P$`&@```%T_`0`G````>#\!``8```"@/P$`%0```*<_`0`'````
MO3\!``@```#%/P$`"0```,X_`0`_````V#\!``<````80`$`#P```"!``0`.
M````,$`!`!`````_0`$`"0```%!``0`)````6D`!``@```!D0`$`$P```&U`
M`0`'````@4`!`!D```")0`$`"@```*-``0`7````KD`!`!0```#&0`$`"@``
M`-M``0`,````YD`!`!<```#S0`$`!`````M!`0`J````$$$!``P````[00$`
M$0```$A!`0`'````6D$!``(```!B00$`$````&5!`0`8````=D$!``L```"/
M00$``P```)M!`0`(````GT$!``8```"H00$`!P```*]!`0`-````MT$!``L`
M``#%00$`%````-%!`0`5````YD$!``X```#\00$`+P````M"`0`@````.T(!
M`!P```!<0@$`%0```'E"`0`,````CT(!`#$```"<0@$`!0```,Y"`0`2````
MU$(!`#\```#G0@$`$@```"=#`0`*````.D,!``8```!%0P$`!````$Q#`0`$
M````44,!``H```!60P$`$P```&%#`0`%````=4,!``8```![0P$`!@```()#
M`0`(````B4,!``0```"20P$`#````)=#`0`*````I$,!`#D```"O0P$`+@``
M`.E#`0`I````&$0!``4```!"1`$`&````$A$`0`9````840!`!\```![1`$`
M'0```)M$`0`1````N40!``(```#+1`$`!````,Y$`0`*````TT0!``8```#>
M1`$`!0```.5$`0`#````ZT0!``P```#O1`$`10```/Q$`0`R````0D4!`!H`
M``!U10$`-````)!%`0`H````Q44!`%,```#N10$`&0```$)&`0!R````7$8!
M`"````#/1@$`-0```/!&`0`A````)D<!`$4```!(1P$`,````(Y'`0`H````
MOT<!`"D```#H1P$`)@```!)(`0`E````.4@!`"@```!?2`$`*````(A(`0`B
M````L4@!`"L```#42`$`,`````!)`0`2````,4D!`!,```!$20$`$````%A)
M`0!Y````:4D!``D```#C20$`H0```.U)`0!S````CTH!`'P````#2P$`*P``
M`(!+`0!4````K$L!`!<````!3`$`)P```!E,`0`6````04P!``\```!83`$`
M%P```&A,`0`?````@$P!`$````"@3`$`'P```.%,`0`<`````4T!`%$````>
M30$`&@```'!-`0`4````BTT!``H```"@30$`!0```*M-`0`&````L4T!``@`
M``"X30$`!0```,%-`0`2````QTT!`!````#:30$`$P```.M-`0`=````_TT!
M``\````=3@$`#P```"U.`0`$````/4X!``D```!"3@$`"P```$Q.`0`'````
M6$X!``4```!@3@$`%````&9.`0`'````>TX!``@```"#3@$`#P```(Q.`0`(
M````G$X!``P```"E3@$`#P```+).`0`&````PDX!`!0```#)3@$`!@```-Y.
M`0`,````Y4X!`!$```#R3@$`"`````1/`0`$````#4\!`!D````23P$`$0``
M`"Q/`0`*````/D\!`!@```!)3P$`$P```&)/`0`<````=D\!`!$```"33P$`
M!````*5/`0`/````JD\!``<```"Z3P$`!````,)/`0`9````QT\!``<```#A
M3P$``@```.E/`0`"````[$\!`!$```#O3P$`"0````%0`0`&````"U`!`!(`
M```24`$`%P```"50`0`&````/5`!`"<```!$4`$``@```&Q0`0`$````;U`!
M``\```!T4`$`$P```(10`0`'````F%`!``<```"@4`$`$0```*A0`0`&````
MNE`!`!@```#!4`$`!@```-I0`0`3````X5`!`!````#U4`$`$@````91`0`"
M````&5$!``8````<40$`#````"-1`0`)````,%$!`!$````Z40$`(@```$Q1
M`0`'````;U$!``<```!W40$`"P```']1`0`%````BU$!``(```"140$`"P``
M`)11`0!]`0``H%$!``\````>4P$`$@```"Y3`0`-````05,!``8```!/4P$`
M"0```%93`0`'````8%,!``,```!H4P$`&0```&Q3`0`?````AE,!`#(```"F
M4P$`+P```-E3`0`H````"50!`"T````R5`$`&0```&!4`0`K````>E0!``H`
M``"F5`$`+@```+%4`0`6````X%0!``H```#W5`$`%`````)5`0`%````%U4!
M`"X````=50$`$P```$Q5`0`+````8%4!`!H```!L50$`#0```(=5`0`.````
ME54!`)D```"D50$`#0```#Y6`0`*````3%8!`!<```!75@$`#@```&]6`0`1
M````?E8!``P```"05@$`%@```)U6`0`,````M%8!``8```#!5@$`G0```,A6
M`0`*````9E<!``\```!Q5P$`%0```(%7`0`1````EU<!`!,```"I5P$`$P``
M`+U7`0`(````T5<!``D```#:5P$`-@```.17`0`D````&U@!`#@```!`6`$`
M0P```'E8`0!E````O5@!`&(````C60$`:P```(99`0!H````\ED!`#H```!;
M6@$`#P```)9:`0`5````IEH!``X```"\6@$`$P```,M:`0`9````WUH!``4`
M``#Y6@$`"0```/]:`0`1````"5L!``P````;6P$`#0```"A;`0`-````-EL!
M`#0```!$6P$`,0```'E;`0`)````JUL!`!0```"U6P$`%````,I;`0`,````
MWUL!``8```#L6P$`&0```/-;`0`>````#5P!``P````L7`$`#````#E<`0`1
M````1EP!`",```!87`$`*````'Q<`0`2````I5P!``X```"X7`$`#P```,=<
M`0`*````UUP!`"\```#B7`$`&0```!)=`0`9````+%T!``X```!&70$`7```
M`%5=`0`Z````LET!`"H```#M70$`"0```!A>`0`+````(EX!`#0````N7@$`
M#@```&->`0`(````<EX!``H```![7@$`!P```(9>`0`'````CEX!``4```"6
M7@$`!P```)Q>`0`+````I%X!``4```"P7@$`(0```+9>`0`0````V%X!`!4`
M``#I7@$`#P```/]>`0`;````#U\!`#0````K7P$`"0```&!?`0`7````:E\!
M`!8```""7P$`&````)E?`0`A````LE\!`!<```#47P$`$0```.Q?`0`/````
M_E\!`!\````.8`$`)0```"Y@`0`'````5&`!``8```!<8`$`!P```&-@`0`-
M````:V`!``D```!Y8`$`"0```(-@`0`2````C6`!``H```"@8`$`%0```*M@
M`0`9````P6`!`"P```#;8`$`!P````AA`0`1````$&$!``4````B80$`%@``
M`"AA`0`2````/V$!`!(```!280$`/@```&5A`0`^````I&$!``D```#C80$`
M!P```.UA`0`3````]6$!``0````)8@$`!0````YB`0`.````%&(!``X````C
M8@$`%P```#)B`0!'````2F(!`!8```"28@$`)@```*EB`0`K````T&(!`"P`
M``#\8@$`-````"EC`0`)````7F,!``8```!H8P$`"0```&]C`0`'````>6,!
M`#@```"!8P$`.@```+IC`0`W````]6,!`%P````M9`$`-@```(ID`0`V````
MP60!`$<```#X9`$`2P```$!E`0`V````C&4!`$X```##90$`+````!)F`0`N
M````/V8!`$T```!N9@$`-@```+QF`0`\````\V8!`"X````P9P$`&````%]G
M`0`<````>&<!`#,```"59P$`+0```,EG`0`M````]V<!`!,````E:`$`"@``
M`#EH`0`,````1&@!``4```!1:`$`#@```%=H`0`?````9F@!`"8```"&:`$`
M!P```*UH`0`'````M6@!`!4```"]:`$`"@```--H`0`(````WF@!`#,```#G
M:`$`"@```!MI`0`'````)FD!``<````N:0$`!@```#9I`0`%````/6D!``@`
M``!#:0$`!@```$QI`0`*````4VD!`#0```!>:0$`$@```)-I`0`.````IFD!
M``<```"U:0$`!P```+UI`0`*````Q6D!``4```#0:0$`$0```-9I`0`&````
MZ&D!`!(```#O:0$`!0````)J`0`(````"&H!``@````1:@$`#@```!IJ`0`&
M````*6H!`"D````P:@$`$0```%IJ`0`(````;&H!`!$```!U:@$`#````(=J
M`0`'````E&H!``,```"<:@$``P```*!J`0`:````I&H!`!@```"_:@$`*@``
M`-AJ`0`&`````VL!``4````*:P$`!P```!!K`0`'````&&L!`$@````@:P$`
M3P```&EK`0!E````N6L!`"<````?;`$`.````$=L`0`I````@&P!`"(```"J
M;`$`!@```,UL`0`(````U&P!`!T```#=;`$`)0```/ML`0`G````(6T!`#0`
M``!);0$`*````'YM`0`M````IVT!`&(```#5;0$`-@```#AN`0`*````;VX!
M``D```!Z;@$`"0```(1N`0`6````CFX!``P```"E;@$`#@```+)N`0`4````
MP6X!`!````#6;@$`%````.=N`0`3````_&X!``X````0;P$`%0```!]O`0`'
M````-6\!`!@````];P$`&P```%9O`0`8````<F\!`!L```"+;P$`&0```*=O
M`0`$````P6\!``<```#&;P$`%````,YO`0!8````XV\!`'(````\<`$`!P``
M`*]P`0`5````MW`!``4```#-<`$`!0```--P`0`;````V7`!`!@```#U<`$`
M"P````YQ`0`4````&G$!`!H````O<0$`'@```$IQ`0`[````:7$!``X```"E
M<0$`+````+1Q`0`'````X7$!`!L```#I<0$`#P````5R`0`2````%7(!``X`
M```H<@$`&````#=R`0`0````4'(!`!8```!A<@$`$P```'AR`0`.````C'(!
M``4```";<@$`#P```*%R`0`&````L7(!`!@```"X<@$`%0```-%R`0`/````
MYW(!``@```#W<@$`!0````!S`0`1````!G,!`!(````8<P$`"0```"MS`0`7
M````-7,!``8```!-<P$`!P```%1S`0`1````7',!``H```!N<P$`#````'ES
M`0`'````AG,!``@```".<P$`"P```)=S`0`)````HW,!``L```"M<P$`'P``
M`+ES`0!)````V7,!`"4````C=`$`#0```$ET`0`4````5W0!``4```!L=`$`
M(````')T`0`2````DW0!`!,```"F=`$`.@```+IT`0!*````]70!`"<```!`
M=0$`"0```&AU`0`\````<G4!`"H```"O=0$`$0```-IU`0`)````['4!``H`
M``#V=0$`!@````%V`0`&````"'8!`!(````/=@$`$````")V`0`+````,W8!
M``H````_=@$`#P```$IV`0`L````6G8!`"P```"'=@$`+0```+1V`0`N````
MXG8!`"(````1=P$`)0```#1W`0`B````6G<!`"8```!]=P$`-@```*1W`0`N
M````VW<!`"8````*>`$`*````#%X`0`D````6G@!`#$```!_>`$`10```+%X
M`0!`````]W@!`#4````X>0$`-````&YY`0`^````HWD!`"8```#B>0$`)0``
M``EZ`0`\````+WH!`"4```!L>@$`%0```))Z`0`Y````J'H!`"4```#B>@$`
M)P````A[`0`4````,'L!`,H```!%>P$`&P```!!\`0`Q````+'P!`#````!>
M?`$`,P```(]\`0`Q````PWP!`"<```#U?`$`*````!U]`0`K````1GT!`#(`
M``!R?0$`-0```*5]`0!+````VWT!`#0````G?@$`I````%Q^`0`G`````7\!
M`!T````I?P$`)@```$=_`0`S````;G\!`#$```"B?P$`3@```-1_`0!5````
M(X`!``T```!Y@`$`!````(>``0`&````C(`!``4```"3@`$`#P```)F``0`%
M````J8`!`!$```"O@`$`%@```,&``0`<````V(`!``<```#U@`$`!````/V`
M`0`0`````H$!`!$````3@0$`"P```"6!`0`*````,8$!`!$````\@0$`#0``
M`$Z!`0`2````7($!``T```!O@0$`.@```'V!`0`&````N($!`!````"_@0$`
M!@```-"!`0`1````UX$!`!<```#I@0$`&P````&"`0`/````'8(!``(````M
M@@$`20```#""`0`+````>H(!``P```"&@@$`'````)."`0`%````L((!`!<`
M``"V@@$`$@```,Z"`0`#````X8(!`!$```#E@@$`"0```/>"`0`1`````8,!
M`!`````3@P$`"P```"2#`0`1````,(,!`!4```!"@P$`$0```%B#`0`,````
M:H,!`!0```!W@P$`#@```(R#`0`.````FX,!`!$```"J@P$`$P```+R#`0`:
M````T(,!``X```#K@P$`$````/J#`0`K````"X0!`!$````WA`$`'````$F$
M`0!$````9H0!``T```"KA`$`'P```+F$`0`4````V80!`!D```#NA`$`%@``
M``B%`0!#````'X4!`!````!CA0$`"0```'2%`0`4````?H4!``L```"3A0$`
M-@```)^%`0`U````UH4!``H````,A@$`%0```!>&`0`I````+88!`!<```!7
MA@$`%@```&^&`0`6````AH8!``H```"=A@$`(````*B&`0`9````R88!`!P`
M``#CA@$`&`````"'`0`9````&8<!`!@````SAP$`"````$R'`0`+````58<!
M`"D```!AAP$`6````(N'`0`(````Y(<!`!0```#MAP$`(@````*(`0`)````
M)8@!``P````OB`$`-@```#R(`0`1````<X@!``8```"%B`$`!@```(R(`0!5
M````DX@!``,```#IB`$`!P```.V(`0`5````]8@!`!`````+B0$`#P```!R)
M`0`4````+(D!`!4```!!B0$`&P```%>)`0`6````<XD!`!T```"*B0$`&P``
M`*B)`0`)````Q(D!``8```#.B0$`"P```-6)`0`+````X8D!``(```#MB0$`
M!@```/")`0`3````]XD!`"\````+B@$`%P```#N*`0`5````4XH!``H```!I
MB@$`$0```'2*`0`4````AHH!`!P```";B@$`.0```+B*`0`W````\HH!`!(`
M```JBP$`#P```#V+`0"&````38L!`",```#4BP$`(````/B+`0`1````&8P!
M``<````KC`$`!0```#.,`0`<````.8P!`"T```!6C`$`,P```(2,`0`?````
MN(P!`"4```#8C`$`'P```/Z,`0`7````'HT!``<````VC0$`!P```#Z-`0`&
M````1HT!``8```!-C0$`#P```%2-`0`.````9(T!`!````!SC0$`#@```(2-
M`0`5````DXT!``\```"IC0$`"P```+F-`0`3````Q8T!``@```#9C0$`"```
M`.*-`0`5````ZXT!``\````!C@$`10```!&.`0`4````5XX!``D```!LC@$`
M#@```':.`0`?````A8X!`"````"EC@$`)P```,:.`0`F````[HX!`!@````5
MCP$`%P```"Z/`0`@````1H\!`!@```!GCP$`%@```("/`0`)````EX\!`!D`
M``"ACP$`"P```+N/`0`4````QX\!``,```#<CP$`!0```."/`0`'````YH\!
M``X```#NCP$`$````/V/`0`-````#I`!`!@````<D`$`$````#60`0`1````
M1I`!``\```!8D`$`!````&B0`0`'````;9`!`!H```!UD`$`&P```)"0`0`(
M````K)`!`!$```"UD`$`%````,>0`0`.````W)`!`"<```#KD`$`!P```!.1
M`0`)````&Y$!`!`````ED0$`$````#:1`0`*````1Y$!``<```!2D0$`"P``
M`%J1`0`&````9I$!`!@```!MD0$`#@```(:1`0`&````E9$!`"@```"<D0$`
M$````,61`0";````UI$!`!L```!RD@$`"P```(Z2`0`'````FI(!``\```"B
MD@$`"````+*2`0`*````NY(!``4```#&D@$`"````,R2`0`#````U9(!``8`
M``#9D@$`!P```."2`0`6````Z)(!`!````#_D@$`$@```!"3`0`=````(Y,!
M``(```!!DP$`!````$23`0`4````29,!``H```!>DP$`#P```&F3`0`%````
M>9,!`",```!_DP$`"````*.3`0`&````K),!`!L```"SDP$`#P```,^3`0`'
M````WY,!``@```#GDP$`!0```/"3`0`)````]I,!``\`````E`$`$0```!"4
M`0`"````(I0!``8````EE`$`#P```"R4`0`2````/)0!`!````!/E`$`!@``
M`&"4`0`3````9Y0!``L```![E`$`!P```(>4`0`8````CY0!`#````"HE`$`
M30```-F4`0`K````)Y4!`"T```!3E0$`!@```(&5`0`)````B)4!``0```"2
ME0$`"0```)>5`0`)````H94!`!<```"KE0$`#````,.5`0`&````T)4!``T`
M``#7E0$`!P```.65`0`$````[94!`$$```#RE0$`2````#26`0!!````?98!
M`"<```"_E@$`!0```.>6`0`-````[98!``<```#[E@$`"`````.7`0`)````
M#)<!`!L````6EP$`&0```#*7`0`5````3)<!``8```!BEP$`!0```&F7`0`0
M````;Y<!``@```"`EP$`"@```(F7`0`C````E)<!``0```"XEP$`!P```+V7
M`0`G````Q9<!``8```#MEP$`"0```/27`0`3````_I<!`!,````2F`$`"```
M`":8`0`)````+Y@!``4````YF`$`1P```#^8`0`T````AY@!`$$```"\F`$`
M,@```/Z8`0!)````,9D!`#L```![F0$`+````+>9`0`^````Y)D!`"\````C
MF@$`/0```%.:`0`Q````D9H!`!````##F@$`$0```-2:`0`+````YIH!`#(`
M``#RF@$`(0```"6;`0`?````1YL!`!X```!GFP$`!P```(:;`0`)````CIL!
M``H```"8FP$`!P```*.;`0`I````JYL!`"P```#5FP$`/0````*<`0`,````
M0)P!`",```!-G`$`-@```'&<`0`6````J)P!`!4```"_G`$`"````-6<`0`+
M````WIP!``P```#JG`$`$````/><`0`7````")T!`$4````@G0$`?````&:=
M`0!G````XYT!``T```!+G@$`$````%F>`0`1````:IX!`!0```!\G@$`%0``
M`)&>`0`7````IYX!``@```"_G@$`$0```,B>`0`3````VIX!`!(```#NG@$`
M%0````&?`0`N````%Y\!`"T```!&GP$`EP```'2?`0`1````#*`!``4````>
MH`$`%0```"2@`0`)````.J`!``L```!$H`$`"P```%"@`0`E````7*`!`!@`
M``""H`$`#P```)N@`0`.````JZ`!`!0```"ZH`$`&0```,^@`0`M````Z:`!
M`"X````7H0$`*@```$:A`0`J````<:$!`"8```"<H0$`*````,.A`0`>````
M[*$!`$$````+H@$`%0```$VB`0`4````8Z(!`!<```!XH@$`%@```)"B`0`1
M````IZ(!`!<```"YH@$`%@```-&B`0`4````Z*(!`!0```#]H@$`.P```!*C
M`0`9````3J,!`!H```!HHP$`.@```(.C`0`3````OJ,!``8```#2HP$`$```
M`-FC`0`M````ZJ,!`!0````8I`$`%0```"VD`0`5````0Z0!`"````!9I`$`
M'@```'JD`0`<````F:0!`!P```"VI`$`)P```-.D`0`3````^Z0!`"`````/
MI0$`)@```#"E`0`@````5Z4!`!D```!XI0$`'0```)*E`0`4````L*4!`!P`
M``#%I0$`'````.*E`0`A````_Z4!`!D````AI@$`"@```#NF`0`2````1J8!
M`!L```!9I@$`!````'6F`0`'````>J8!``L```""I@$`$@```(ZF`0`&````
MH:8!``8```"HI@$`!P```*^F`0`&````MZ8!``<```"^I@$`!0```,:F`0`%
M````S*8!`!4```#2I@$`!@```.BF`0`&````[Z8!``4```#VI@$`!0```/RF
M`0`*`````J<!`!$````-IP$`"@```!^G`0`6````*J<!`!0```!!IP$`"@``
M`%:G`0`7````8:<!``4```!YIP$`-0```'^G`0`2````M:<!`!$```#(IP$`
M&@```-JG`0`/````]:<!``T````%J`$`$````!.H`0`T````)*@!``4```!9
MJ`$`"````%^H`0`G````:*@!`!,```"0J`$`$````*2H`0`&````M:@!``H`
M``"\J`$`#0```,>H`0`&````U:@!`"(```#<J`$`$````/^H`0`;````$*D!
M`!`````LJ0$`%0```#VI`0`1````4ZD!`!H```!EJ0$`%````("I`0`&````
ME:D!``4```"<J0$`#````**I`0`F````KZD!``<```#6J0$`"0```-ZI`0`2
M````Z*D!`!<```#[J0$`!P```!.J`0`%````&ZH!``<````AJ@$`%@```"FJ
M`0`-````0*H!``\```!.J@$`#0```%ZJ`0`6````;*H!`!@```"#J@$`#P``
M`)RJ`0`1````K*H!``P```"^J@$`&````,NJ`0`,````Y*H!``<```#QJ@$`
M%````/FJ`0!"````#JL!``@```!1JP$`#````%JK`0`M````9ZL!`!4```"5
MJP$`%0```*NK`0`-````P:L!``P```#/JP$`"0```-RK`0`'````YJL!``H`
M``#NJP$`"0```/FK`0`.`````ZP!`!`````2K`$`*0```".L`0`E````3:P!
M`"H```!SK`$`"@```)ZL`0`(````J:P!``H```"RK`$`#````+VL`0`-````
MRJP!``D```#8K`$`#@```.*L`0`U````\:P!``4````GK0$`#@```"VM`0`:
M````/*T!`%T```!7K0$`&@```+6M`0`.````T*T!``0```#?K0$`!````.2M
M`0`:````Z:T!`!H````$K@$`&@```!^N`0`*````.JX!``(```!%K@$`!```
M`$BN`0`E````3:X!``,```!SK@$`!0```'>N`0`I````?:X!``H```"GK@$`
M!0```+*N`0`&````N*X!``L```"_K@$`$0```,NN`0`&````W:X!``<```#D
MK@$`"````.RN`0`$````]:X!``4```#ZK@$`:P````"O`0`*````;*\!``T`
M``!WKP$`'0```(6O`0`%````HZ\!``8```"IKP$`*0```+"O`0`V````VJ\!
M``X````1L`$`"0```""P`0`3````*K`!``H````^L`$`"````$FP`0`7````
M4K`!`#@```!JL`$`'P```*.P`0`>````P[`!`",```#BL`$`#P````:Q`0`$
M````%K$!``<````;L0$`"````".Q`0`(````++$!`!$````UL0$`#P```$>Q
M`0`'````5[$!`&$```!?L0$`$0```,&Q`0`/````T[$!``\```#CL0$`&P``
M`/.Q`0!1````#[(!`!P```!AL@$`!@```'ZR`0`?````A;(!`"8```"EL@$`
M!P```,RR`0`&````U+(!`"````#;L@$`"````/RR`0`)````!;,!`"$````/
MLP$`(````#&S`0`\````4K,!``@```"/LP$`"@```)BS`0`G````H[,!`%0`
M``#+LP$`&P```""T`0`?````/+0!`!H```!<M`$``P```'>T`0`,````>[0!
M``@```"(M`$`&0```)&T`0`-````J[0!``8```"YM`$`%@```,"T`0`&````
MU[0!``@```#>M`$`"0```.>T`0`,````\;0!``H```#^M`$`$`````FU`0!!
M````&K4!``D```!<M0$`&@```&:U`0`7````@;4!`"$```"9M0$`&````+NU
M`0`5````U+4!`!@```#JM0$`%@````.V`0`6````&K8!`!4````QM@$`%@``
M`$>V`0`*````7K8!`!\```!IM@$`$````(FV`0`2````FK8!``D```"MM@$`
M#````+>V`0`)````Q+8!`!D```#.M@$`!P```.BV`0`7````\+8!``8````(
MMP$`!P````^W`0`%````%[<!``4````=MP$`!P```".W`0`3````*[<!`!0`
M```_MP$`(@```%2W`0`B````=[<!`!T```":MP$`'````+BW`0`B````U;<!
M`"8```#XMP$`'P```!^X`0`#````/[@!``4```!#N`$`#P```$FX`0`/````
M6;@!``H```!IN`$`(@```'2X`0`-````E[@!`!````"EN`$`(P```+:X`0`=
M````VK@!`!8```#XN`$`"`````^Y`0`.````&+D!``D````GN0$`$````#&Y
M`0`3````0KD!``H```!6N0$`"0```&&Y`0`%````:[D!``<```!QN0$`!0``
M`'FY`0`$````?[D!``(```"$N0$`-P```(>Y`0`[````O[D!`!D```#[N0$`
M)@```!6Z`0!&````/+H!``P```"#N@$`-````)"Z`0`[````Q;H!`$0````!
MNP$`1````$:[`0!,````B[L!``\```#8NP$`(````.B[`0`?````";P!`!P`
M```IO`$`'P```$:\`0`?````9KP!`"````"&O`$`(````*>\`0`@````R+P!
M``P```#IO`$`00```/:\`0!!````.+T!`$4```!ZO0$`1@```,"]`0!#````
M![X!`$````!+O@$`>0```(R^`0`5````!K\!`!`````<OP$`"0```"V_`0`C
M````-[\!``<```!;OP$`%````&._`0`Z````>+\!`#@```"SOP$`)````.R_
M`0`+````$<`!`%,````=P`$`2@```''``0`'````O,`!`!<```#$P`$`%0``
M`-S``0`/````\L`!`!`````"P0$`&````!/!`0`'````+,$!``H````TP0$`
M"````#_!`0`3````2,$!`!````!<P0$`#@```&W!`0`2````?,$!``4```"/
MP0$`)````)7!`0`)````NL$!``8```#$P0$`%````,O!`0`2````X,$!``\`
M``#SP0$`2`````/"`0`'````3,(!``8```!4P@$`$@```%O"`0`%````;L(!
M``<```!TP@$`#P```'S"`0`'````C,(!`#4```"4P@$`$@```,K"`0`E````
MW<(!``0````#PP$`.P````C#`0`.````1,,!`"@```!3PP$`AP```'S#`0`:
M````!,0!`$4````?Q`$`)P```&7$`0`1````C<0!``@```"?Q`$`#@```*C$
M`0`.````M\0!``P```#&Q`$`$P```-/$`0`,````Y\0!`"````#TQ`$`'```
M`!7%`0`$````,L4!`!`````WQ0$`&P```$C%`0`J````9,4!`!4```"/Q0$`
M$0```*7%`0`6````M\4!`!$```#.Q0$`'P```.#%`0`*`````,8!``P````+
MQ@$`$P```!C&`0`1````+,8!`!<````^Q@$`$````%;&`0`<````9\8!``X`
M``"$Q@$`%0```)/&`0`B````J<8!``T```#,Q@$`!@```-K&`0`(````X<8!
M``4```#JQ@$`(````/#&`0`&````$<<!`!(````8QP$`"````"O'`0`3````
M-,<!``H```!(QP$`*````%/'`0`5````?,<!`$$```"2QP$`&P```-3'`0`+
M````\,<!``P```#\QP$`)0````G(`0`%````+\@!`!8````UR`$``P```$S(
M`0`1````4,@!``4```!BR`$`"@```&C(`0`E````<\@!`#D```"9R`$`"@``
M`-/(`0`F````WL@!`!,````%R0$`"P```!G)`0`=````)<D!`!0```!#R0$`
M!````%C)`0`(````7<D!``D```!FR0$`"````'#)`0`+````><D!``@```"%
MR0$`!P```([)`0`'````ELD!`!(```">R0$`*@```+')`0`W````W,D!`!L`
M```4R@$`*P```##*`0`C````7,H!`$$```"`R@$`&P```,+*`0`D````WLH!
M`"T````#RP$`3````#'+`0`H````?LL!``<```"GRP$`"````*_+`0`)````
MN,L!``@```#"RP$`%0```,O+`0`4````X<L!`"P```#VRP$`+P```"/,`0`B
M````4\P!`#<```!VS`$`/P```*[,`0`'````[LP!`!H```#VS`$`"0```!'-
M`0`,````&\T!`"X````HS0$`$P```%?-`0`2````:\T!``T```!^S0$`"P``
M`(S-`0`8````F,T!``D```"QS0$`$@```+O-`0`1````SLT!`!H```#@S0$`
M'````/O-`0`Y````&,X!``L```!2S@$`$````%[.`0`%````;\X!``@```!U
MS@$`!0```'[.`0`:````A,X!``\```"?S@$`!@```*_.`0`/````MLX!`!$`
M``#&S@$`"````-C.`0`.````X<X!``X```#PS@$`$P```/_.`0`%````$\\!
M`!`````9SP$`#0```"K/`0`\````.,\!`%(```!USP$`(@```,C/`0`*````
MZ\\!`"<```#VSP$`&P```![0`0`%````.M`!`!<```!`T`$`"0```%C0`0`-
M````8M`!`!(```!PT`$`*@```(/0`0`&````KM`!``T```"UT`$`#@```,/0
M`0`0````TM`!``H```#CT`$`/0```.[0`0`)````+-$!`"`````VT0$`$```
M`%?1`0`4````:-$!`$````!]T0$`)@```+[1`0!"````Y=$!`$,````HT@$`
M/````&S2`0`/````J=(!``<```"YT@$`$@```,'2`0`2````U-(!`!D```#G
MT@$`"@````'3`0`3````#-,!`!L````@TP$`!P```#S3`0`7````1-,!`"@`
M``!<TP$`!@```(73`0`'````C-,!`!````"4TP$`%0```*73`0`7````N],!
M``<```#3TP$`!P```-O3`0`)````X],!`!0```#MTP$`$@````+4`0`3````
M%=0!`!,````IU`$`!@```#W4`0`%````1-0!`#$```!*U`$`*````'S4`0`E
M````I=0!``@```#+U`$`#P```-34`0`&````Y-0!`!H```#KU`$`&0````;5
M`0`K````(-4!``D```!,U0$`#````%;5`0`G````8]4!``,```"+U0$`!0``
M`(_5`0`-````E=4!``,```"CU0$`#````*?5`0`3````M-4!``L```#(U0$`
M%P```-35`0`8````[-4!`!,````%U@$`!0```!G6`0`*````']8!`!8````J
MU@$`%0```$'6`0`.````5]8!``<```!FU@$`#````&[6`0`*````>]8!`!``
M``"&U@$`70```)?6`0`F````]=8!`#P````<UP$`$@```%G7`0`'````;-<!
M``8```!TUP$`"P```'O7`0`4````A]<!`!0```"<UP$`'````+'7`0`?````
MSM<!`!8```#NUP$`'@````78`0`0````)-@!`"T````UV`$`%0```&/8`0`-
M````>=@!`&X```"'V`$`)````/;8`0`@````&]D!`"L````\V0$`(P```&C9
M`0`?````C-D!`",```"LV0$`)0```-#9`0`?````]MD!`!L````6V@$`"@``
M`#+:`0`'````/=H!``@```!%V@$`"@```$[:`0`3````6=H!``\```!MV@$`
M+0```'W:`0`8````J]H!`!P```#$V@$`"````.':`0`*````ZMH!`%(```#U
MV@$`10```$C;`0!`````CML!`'@```#/VP$`#0```$C<`0`P````5MP!`#$`
M``"'W`$`"@```+G<`0`'````Q-P!``T```#,W`$`.@```-K<`0`3````%=T!
M`$0````IW0$`+0```&[=`0`G````G-T!`!````#$W0$`,@```-7=`0`C````
M"-X!`#,````LW@$`*@```&#>`0`R````B]X!`"L```"^W@$`#0```.K>`0`)
M````^-X!`!$````"WP$`$P```!3?`0`8````*-\!``<```!!WP$`-P```$G?
M`0`,````@=\!``0```".WP$`!0```)/?`0`2````F=\!``@```"LWP$`!@``
M`+7?`0`4````O-\!``H```#1WP$`"0```-S?`0`%````YM\!`!$```#LWP$`
M$0```/[?`0`:````$.`!`!P````KX`$`%0```$C@`0`A````7N`!``T```"`
MX`$`!P```([@`0`2````EN`!`"D```"IX`$`"0```-/@`0`)````W>`!`!L`
M``#GX`$`*`````/A`0`.````+.$!`"$````[X0$`-````%WA`0`)````DN$!
M``D```"<X0$`$@```*;A`0`&````N>$!``0```#`X0$`(@```,7A`0`-````
MZ.$!``\```#VX0$`#`````;B`0`(````$^(!``D````<X@$`"````";B`0`)
M````+^(!``T````YX@$`$@```$?B`0`&````6N(!`!D```!AX@$`%0```'OB
M`0`'````D>(!`!````"9X@$`(````*KB`0`,````R^(!``,```#8X@$`)0``
M`-SB`0`&`````N,!``8````)XP$`>P```!#C`0`)````C.,!``4```"6XP$`
M+````)SC`0!&````R>,!`",````0Y`$`+P```#3D`0!0````9.0!`#H```"U
MY`$`/0```/#D`0`D````+N4!`"````!3Y0$`!0```'3E`0`'````>N4!``@`
M``""Y0$`"0```(OE`0`'````E>4!``@```"=Y0$`$@```*;E`0`*````N>4!
M``D```#$Y0$`"P```,[E`0`+````VN4!``<```#FY0$`!P```.[E`0`(````
M]N4!`!0```#_Y0$`"P```!3F`0`&````(.8!``4````GY@$`)````"WF`0`&
M````4N8!`"T```!9Y@$`&````(?F`0`(````H.8!`!0```"IY@$`"0```+[F
M`0`3````R.8!``L```#<Y@$`%````.CF`0`%````_>8!`!0````#YP$`!@``
M`!CG`0`:````'^<!``H````ZYP$`'````$7G`0`(````8N<!``8```!KYP$`
M$@```'+G`0`D````A><!``L```"JYP$`#0```+;G`0`J````Q.<!`"$```#O
MYP$`'````!'H`0`%````+N@!``H````TZ`$`$P```#_H`0`8````4^@!``,`
M``!LZ`$`$P```'#H`0`)````A.@!`"0```".Z`$`*````+/H`0`S````W.@!
M`"@````0Z0$`-0```#GI`0`O````;^D!`&0```"?Z0$`%@````3J`0!<````
M&^H!`#H```!XZ@$`20```+/J`0!K````_>H!`"H```!IZP$`00```)3K`0`Q
M````UNL!`#<````([`$`'0```$#L`0!"````7NP!`-,!``"A[`$`(@```'7N
M`0`7````F.X!`$P```"P[@$`@````/WN`0`W````?N\!`"P```"V[P$`/P``
M`./O`0!>````(_`!`$H```""\`$`*@```,WP`0`B````^/`!`!0````;\0$`
M'P```##Q`0`A````4/$!`"````!R\0$`*P```)/Q`0`D````O_$!`",```#D
M\0$`/@````CR`0`B````1_(!`!4```!J\@$`-P```(#R`0`F````N/(!`"P`
M``#?\@$`*P````SS`0`:````./,!`"T```!3\P$`:0```('S`0`V````Z_,!
M`$D````B]`$`-P```&ST`0`M````I/0!`$````#2]`$`<````!/U`0!2````
MA/4!`#4```#7]0$`-P````WV`0`T````1?8!`&L```!Z]@$`<P```.;V`0!:
M````6O<!`%D```"U]P$`-P````_X`0`I````1_@!`"D```!Q^`$`+P```)OX
M`0!Y````R_@!`&X```!%^0$`=P```+3Y`0#$````+/H!`!8```#Q^@$`)P``
M``C[`0`X````,/L!`"\```!I^P$`30```)G[`0`J````Y_L!`&,````2_`$`
M(P```';\`0`+````FOP!`*@```"F_`$`2@```$_]`0`I````FOT!`#@```#$
M_0$`*@```/W]`0`C````*/X!`#T```!,_@$`!@```(K^`0`+````D?X!``0`
M``"=_@$`"@```*+^`0`/````K?X!`!$```"]_@$`"P```,_^`0`&````V_X!
M`!$```#B_@$`!````/3^`0!F````^?X!``,```!@_P$`%````&3_`0`$````
M>?\!``<```!^_P$`!@```(;_`0`%````C?\!`#0```"3_P$`"````,C_`0`5
M````T?\!``P```#G_P$`$0```/3_`0`1````!@`"``,````8``(`!0```!P`
M`@`'````(@`"`!(````J``(`#````#T``@`4````2@`"``8```!?``(`%0``
M`&8``@`-````?``"``,```"*``(`+@```(X``@`$````O0`"``8```#"``(`
M!P```,D``@`E````T0`"`$<```#W``(`.````#\!`@`Y````>`$"`!@```"R
M`0(`)P```,L!`@`J````\P$"`"8````>`@(`'````$4"`@`A````8@("`"@`
M``"$`@(`(P```*T"`@`@````T0("`"0```#R`@(`)@```!<#`@`B````/@,"
M`#8```!A`P(`'0```)@#`@`S````M@,"`#D```#J`P(`)@```"0$`@`J````
M2P0"`"@```!V!`(`(P```)\$`@`H````PP0"`#(```#L!`(`*P```!\%`@`P
M````2P4"`"8```!\!0(`)````*,%`@`E````R`4"`"X```#N!0(`(````!T&
M`@`G````/@8"`#<```!F!@(`.@```)X&`@`<````V08"`"8```#V!@(`/0``
M`!T'`@`G````6P<"`"L```"#!P(`*````*\'`@`J````V`<"`"0````#"`(`
M'@```"@(`@!.````1P@"`"@```"6"`(`-P```+\(`@`N````]P@"`#D````F
M"0(`"0```&`)`@`0````:@D"`!@```!["0(`,@```)0)`@`E````QPD"``T`
M``#M"0(`#P```/L)`@`6````"PH"``H````B"@(`#@```"T*`@`J````/`H"
M``@```!G"@(`"P```'`*`@`O````?`H"`#$```"L"@(`*0```-X*`@`B````
M"`L"`"0````K"P(`"@```%`+`@#L````6PL"``P```!(#`(`%@```%4,`@`*
M````;`P"``T```!W#`(`$@```(4,`@`7````F`P"`"H```"P#`(`!@```-L,
M`@!2````X@P"`!H````U#0(`&@```%`-`@`'````:PT"``\```!S#0(`"```
M`(,-`@!"````C`T"``<```#/#0(`+0```-<-`@`:````!0X"`!,````@#@(`
M%````#0.`@`T````20X"`"````!^#@(`!P```)\.`@`D````IPX"``@```#,
M#@(`"0```-4.`@`7````WPX"``H```#W#@(`'`````(/`@`(````'P\"`"X`
M```H#P(`!P```%</`@`C````7P\"`"<```"##P(`!P```*L/`@`5````LP\"
M``<```#)#P(`"````-$/`@`)````V@\"`$````#D#P(`!P```"40`@`,````
M+1`"`!,````Z$`(`#P```$X0`@`)````7A`"``@```!H$`(`!P```'$0`@`3
M````>1`"``8```"-$`(`&@```)00`@`+````KQ`"`!H```"[$`(`%````-80
M`@`+````ZQ`"``T```#W$`(`(`````41`@`%````)A$"`#4````L$0(`#```
M`&(1`@`/````;Q$"``L```!_$0(``P```(L1`@`4````CQ$"`"(```"D$0(`
M"P```,<1`@`#````TQ$"``@```#7$0(`#````.`1`@`*````[1$"`!````#X
M$0(`#@````D2`@`2````&!("`!,````K$@(`$0```#\2`@`X````41("`"$`
M``"*$@(`'P```*P2`@`A````S!("``D```#N$@(`-````/@2`@`'````+1,"
M`!<````U$P(`0````$T3`@`3````CA,"`!,```"B$P(`"````+83`@`$````
MOQ,"``8```#$$P(`#P```,L3`@`=````VQ,"``<```#Y$P(`"`````$4`@`)
M````"A0"``8````4%`(`!@```!L4`@`5````(A0"`!0````X%`(`0@```$T4
M`@`S````D!0"`"D```#$%`(`!0```.X4`@`;````]!0"`!T````0%0(`(P``
M`"X5`@`G````4A4"`!(```!Z%0(``@```(T5`@`$````D!4"``\```"5%0(`
M"@```*45`@`%````L!4"``(```"V%0(`#0```+D5`@!(````QQ4"`#<````0
M%@(`%@```$@6`@`W````7Q8"`"P```"7%@(`6@```,06`@`7````'Q<"`(,`
M```W%P(`)0```+L7`@`Z````X1<"`"(````<&`(`-@```#\8`@`X````=A@"
M`"T```"O&`(`+````-T8`@`L````"AD"`"H````W&0(`+@```&(9`@`N````
MD1D"`#(```#`&0(`,P```/,9`@`R````)QH"`!8```!:&@(`#0```'$:`@`.
M````?QH"`(8```".&@(`"0```!4;`@"M````'QL"`'$```#-&P(`A0```#\<
M`@`K````Q1P"`%P```#Q'`(`%````$X=`@`H````8QT"`!8```",'0(`$```
M`*,=`@`D````M!T"`"(```#9'0(`0@```/P=`@`@````/QX"`!X```!@'@(`
M7````'\>`@`:````W!X"`!,```#W'@(`"@````L?`@`%````%A\"``8````<
M'P(`"````",?`@`%````+!\"`!8````R'P(`%0```$D?`@`7````7Q\"`"(`
M``!W'P(`$````)H?`@`/````JQ\"``0```"['P(`#````,`?`@`.````S1\"
M``<```#<'P(`!@```.0?`@`9````ZQ\"``\````%(`(`!@```!4@`@`5````
M'"`"``D````R(`(`#````#P@`@`4````22`"``P```!>(`(`&````&L@`@`)
M````A"`"``L```".(`(`&````)H@`@`&````LR`"``4```"Z(`(`)P```,`@
M`@`;````Z"`"``H````$(0(`&0````\A`@`6````*2$"`"0```!`(0(`&0``
M`&4A`@`)````?R$"`!4```")(0(`"````)\A`@`'````J"$"`!<```"P(0(`
M!P```,@A`@`"````T"$"``(```#3(0(`'P```-8A`@`.````]B$"``@````%
M(@(`%P````XB`@`9````)B("``<```!`(@(`*P```$@B`@`"````="("``8`
M``!W(@(`#P```'XB`@`9````CB("``4```"H(@(`"@```*XB`@`3````N2("
M``<```#-(@(`&0```-4B`@`*````[R("`!<```#Z(@(`$P```!(C`@`2````
M)B,"``(````Y(P(`!P```#PC`@`1````1","``8```!6(P(`#@```%TC`@`P
M````;","``D```"=(P(`"@```*<C`@`4````LB,"``4```#'(P(``@```,TC
M`@`+````T","``$```#5!```'@0``#,%``!A`P```````)X!``!O`@``H@0`
M``````"6`P``R0$``/P&``!\``````````````"(`@``*@<```T!````````
M@@<``,$```!Y!0``%P0``/$%```L````W0,``,(&```D!P``"@(```,$``"^
M!0```P<``#,#````````J`(``+@&``!F`@``M`(``!$$``"#`P``````````
M`````````````-@$``!3!0``AP0`````````````^`$``'("````````````
M`($"```P!````````"4!``"F!0```````&,'``#E!0``D`8``"<!``!Q!@``
M]P0``'`"``!R`0``-`<``,0!``#3`@``,00``'$#``!/!P``6@```*0!```U
M`0``B@<```````!]`0``[0```)<&``#"!0``70<``$P%``#-!@```````)8$
M``!D`@``]````"L"``!H`@```````-T$``"%!@``WP4`````````````I0``
M`````````````````)H#````````0````.4&````````SP$```````"?!```
M2@(``,$%````````_P(``(D'````````#@4```````!1!```S04``.X"```H
M!0``%P`````````T````6````+X!`````````````+<"``!<!```9P,``&P#
M``!A`0``@P<``````````````````/P!``!F`P``;P```-@!````````?@8`
M```````)!P``D`````````!/`P``G0(````````>`P``7@8``/8!``#?````
M*@,``-X!``#2`0``N`,``$D#````````'`<``!('```G`P``\P```+(%``#4
M!`````````````"M`P``I`````````#,!0``8P,``'L#``"7!```#`0`````
M``"+!@``P@$```````#C!```>0<``-L#``#I`0```````/\%``!+!P``JP$`
M`%H$``#F`0```````$\```#``0``````````````````,0,``&T'``"(!@``
ML@````````":!0``:00``*4&``#D`0``1P8````````J````_0$``&H!``!5
M!P``W`,``"D&``"E!```508``%@$``"P!@```````)\"``!;````DP8``(T#
M``"I`````````*X%``#3````H@,``'P!``!I`@``Q`,``"D'``!]`P``*P``
M```````V```````````````S`@``@P```.8$````````^`0``'L$``!%!P``
M`````/D``````````````)4"``"\!0```````!D%``"L`P``+0(``'L'````
M````=@0``#T"`````````````)("``"0`0``C`0``-P```!]!P``604``)P#
M```%`@``/`<``&`#```(`0```````$<$````````+@<``*$#``"G`0``````
M``````!I!0``<P$`````````````0P8``-L````^!P``2@`````````$`@``
M`````"L!````````6`,```````">!````````,X!``!C!```&`,````````I
M!```80``````````````)P0``'<```#P`P``9P8```````"=!@````8``'L`
M````````&08``+,$```#````!`<``-X%````````RP,``'X"```7!P``[@``
M````````````90$```````#P`@``F@```)(```"@`P```````)T!```M!0``
M<P(``/4#``!(`P``P`(``+P!``#?!```UP8``+8#``#E!```S`0``*P$````
M````&0<``!D"``#!!```&@$``+,"`````````````.0#``"1`@```````(`!
M``#^!0``:P$``!<&``#Z`0``+`,``$T#``!T`P``200``)@!``!'````R@$`
M`',#``!/!@``.@```&$&``!3````U@8``'@"````````,`4``"@"``!T!@``
M[P````L&```$````Y@(``(`#``"%!0``BP$``)4$`````P``90<``.@%```9
M`0```````*$!```.!P``?0(``'X````'!```"@<``"X&```U!@```````%0"
M``"_`````````'D#```!!`````````L````U!0````````````!G!P``*`8`
M`-T`````````]@(``$`'````````V@,``-P$`````````````&@````/`@``
M<P8```````#4!@``Q@8``'$```"@````_08``$0"````````G00``+L#``#`
M````!@0```\&``!.`0``E@(``+L%``"B`0``PP$````````%`````````$T'
M``#8`@``8P````````#$````````````````````]`0```````!"!0``<`<`
M``````#.!@```````!D#``""!@````````````!4!0````````````#U!```
M>00``*0&``!Q!```"````%X```!)!P``O`,``'@%``#>````A@,``"8$```]
M!0``^`8``)X#``!Y`@```````&P!``!``@``OP8``.\%``#`!````````'`&
M````````B0```*<"````````-`8````````=!P```````%<!```D!```.@$`
M``````!O!````````(D"``![!0``@@4``-8`````````(P(``%`&```Y!```
M-0(`````````````F0,```$%```!!P``"0,``&H&````````\P$``,8```#R
M`P``CP```%P'`````````````.@&``"'`P````````````#?`@``,`,``%D!
M``#U!@```````.<!`````0``30```,\$```2!0```````#@!``"2`P``?P$`
M`)<```!;!```@00``',```"I!0``6@(``(0"````````0@8``'@!`````@``
M`````.D$````````)`````````#Z!```;00``,@$``!;`0``(P0```8```"A
M`@``8`(`````````````!`8``)8%````````X@8``)`#```^````+0$``!8"
M``#9`P``D@8`````````````;@,```````"0!```HP````````#'`P``40``
M`+\"```N!```(@0``.L$````````+08``/@"```O!@``6@4`````````````
M`````*L"```F`P````````````"U`0```````'T````I`P```````','````
M````DP0```````#0`0``\08```H!```````````````````"`0``3@4``#D&
M````````R@4``!,!``#G````_`,``)P```"R`P``Q@$```````!W!```<P0`
M`-D"``#+!0``?@$``(X!``````````````````#]!0``-P0````````_!P``
MI@8``-(#``"I!@``[P$``*8`````````\0(``````````````````*\$``#M
M`0``^P0``.$#```J!````````&@$``"?````$`8``+L$``#L`P```````,L$
M``!=`@``C@0```````#&`@``P`4``$0%``!U!P``UP4``)0&````````9`<`
M````````````'00```````#V`P``5````-D`````````2````)8`````````
M6`(``#<````@!@``/@(``'4"````````]0(````````*!```N0(``*<$``!X
M!P```````-L&```5`````````-L$````````_@`````````A!0``C04``/D!
M``#W!0``?@,``-D&``"V!0``EP4```4%````````````````````````A00`
M`,$"``#0`@``#0<``)L#```!`P```````/8$``!!`@``50$```````#'!```
M-`$```````#-`@``C`````````!R!@``30$`````````````NP8```L!``#@
M`0``*`0``*8#``#.!0``=0$``#4$```1!@``C00``&(`````````+P```*$&
M```Z`@``6P(``(`'``!(!P``CP4``!D`````````K0```/$#``#2!@``?@4`
M`#(```"_!0``S`(```````#W!@``MP8``%T%``!&`0`````````````?`@``
M'P<``-P&````````$`4```````!B`0``.P(``$4"``"]`0``@@,````````L
M`0``1@```-("```4!@```````'\```!$`P``-@<``"\!```S!```XP$`````
M``#3!0``M@(``.H!``!6`P``^@,``'\$````````I`,``-8"``!D`P``[`4`
M````````````7P```"$"```T`P``_@(```````!U!````````($&```Y!0``
M/`4``!H$````````=@```*4#````````F04``&0%```4`@``;@$``"0!````
M````C@````````!L!0```````,<%```<`0``X@$```````"5`P``F```````
M``"'!0``&``````````N!0``B`0````````<````F@8``&D&``#]`@``AP$`
M``````!.`P``:0<``'P$```2!```90```%8%``#%!@``=@(``.``````````
M`````+D#``!W`P````````````````````````````!>`0```````#D'``"`
M`@``;```````````````B@(```````#/!@``#0(``!$%``!O`0``+P(``.$%
M``#I`@``40,```\!``!@````9P````````#`!@``VP(``+H&````````````
M``````#L````M`0``"@`````````,`<```````#U````K`4``/\!``#7!```
M&@```````````````````&0$````````R08``&`&``!.`````````!4"````
M`````````$P$```6!@``(P```#\```"$!0``J@0``+H"``"3!0``Y````$0$
M````````N@4``$,%```A`0``N@$```````"=!0```````+4````"!P``+`<`
M````````````L@0```````!J!P``?04``&8```````````````````#0!```
M"0$``%@&`````````````.`&``!A!P``/0$``#T$``!W`@``[`8``#L$```@
M!P``_@8``.8````.`0```````$@&``">!@``O@0``&8&```+!0``1@<`````
M`````````````'4#``"+````>@<``-0#```#`@``I0$``"X#````````M00`
M```````E!P```P,``.T"``!P````;@8``-@````2!@``1P,``%X'``#S!0``
MZ08``-,$``!!`P```````/L%``!F!P``H`8``-0"````````;0$``-$```"*
M!@``,````,H"``"C!```[@$``.(```!L`@``J`$``%X"````````.@,`````
M``!<!@``+00``&(#``#B!0```````,\```"8!0``V`8``$<"````````````
M`)<!``````````````<&``!(!0``_P8```````!+`P``;@4``%0'``#5`0``
M@@$`````````````````````````````_P0``&X$```(!```0`,``"$$``#A
M!````````%X#``"`!```$P(``"P&``#-!```'0,```````!_!@``=0````<#
M``"3`0```````*P`````````!@(``'L!```K!```-0<```````!Z````=```
M````````````9`$``%8!```-````00$``.`#``"U!@``.`<`````````````
M)@```````````````````(H%``"1!````````$@$```!!@```````+,```!2
M`0``D08``+0!```8`@``4@(``(D#``!O!P``]P(``+8```#S!@``\P,``%,!
M``#D!```\00```````#0!@```````#$"````````#`<``%``````````5@(`
M``````!,!@``@P(````````<!@```````/0&``",!@``NP```%T&````````
M^P$``(0```!&!@```````'<!`````````````$8"``!*`0``%P,````````F
M`0``6P,``/<```"<!0``504``-T&```[`0``&@<```````"*`0``7@4``%D$
M``!"!P``G`(``#\#```3`P``L`4``$L!````````H00```````!``0``:@``
M`(`%``"I`P``J`8``"``````````K@```$L````2````J`0```,!``!Y!@``
M`````-<!``"Z````Y@,``+@!`````````````&H$`````````````+X```"Y
M````=`0````````1````804``.@$```B`P``K0$``.@````D`@``GP8``+\!
M``#T`0``.@8``(,&````````@0```!0$``"]`@``/P0``($!```;````M0(`
M``````"_`P``=P4``&<"``"%`````````,\"``#$!@``@04```````!9`@``
MH04``/(!``"O`P```````(P%``!T`0``L0```(,$````````\`8````````1
M!P``<0(```````#O`P```````!("```6`0``+P,``$8$````````UP,``.$"
M````````?`8``$L%````````W`4``(D$````````L@8``/D"``"Q!```!P(`
M```````A````_`4``'D!```^`P``"@8``/0%``#R`@``<P4``+H#````````
MU@,``.H"``!9!@```````'T$``!#`P```````"P"``">!0``R`4``-L%``!C
M!0``````````````!P``?`4``$D"```\````O```````````````$0,`````
M````````$`<``#<&```6!`````````````!C`@``"`<``#4#````````0@$`
M`#\%````````FP8`````````````B0$``,D```#K`P``Y`8``+T```"-`0``
MOP0````````X`P``-P(``!\%````````AP8``+`$```)`@``[00``,$#````
M``````````````!+!```408``+<$``!U!0``Q@,```````!M`P``W`$``+(!
M````````E04```````#*!@``I`4````````+`P``?P,``!,````/!```QP$`
M``T$````````0P(``%4```#D!0```````*X#```%`P``&P0```8&````````
M`````.P$``#M!0``#`,``*H%``"Y!```%@```%8$```Y`0``5P4``*8"``#[
M`@```````(("```E!0``_0,``$4!``!L!`````````````!!!0``%0$`````
M``#T`P``R00``+X&````````2@,```````#/`P``7P4``'X$```]!@``^P``
M`"`%``!(`0```````*L```!8`0``Z@0``(T`````````T`,``#@&````````
M`````,L```"'````WP,`````````````S@0```````!2!P```````!L%````
M````Z0,``#$```#.`P``BP4``!(!```.````:P<``*<```#1!```8@<``!@&
M``#:````(P$``*0"``":`@``8`0``"\$```C!P``9P$``'H"```4!P``'P0`
M`-H%``">`@``70````````#B!```:`4``#\&``#H`@```````+0%````````
M!@,``"`$```````````````````&!0```````)4!``"&!@``=@,``+$#``#Z
M!@```````)0$``"'`@``'@8```````#>`P```````%T!``!;!P``%@,``/,"
M```S!P``=@4``*H#``!?`0``*P8``````````````````*\&``#B`P``4`,`
M`/X$```Z!P``>@0````````Q!0``:`8``-0```"B`@``^P,````````J!0``
MA@<``.X%``!T`@```````"D`````````"`(````````+!P``YP0```````!2
M!@`````````````G!P```@8```````!(`@``````````````````V0$``,T`
M```Y`P``!@$````````K!P``<@<``&,&````````@P4``'`!``"Q`@``Q@0`
M`#`"``!7!```````````````````A@4``!4$``"3`@``5P8``-(```"P`P``
M208``#<'``!\!P```````-($```=!0```````+P$`````````````(0!````
M`````````"4"``!<`0```````!L'```R!P``(@(``*H"```F!P```````#P$
M``"+`@``:P```/(&```[!0``/@$``!,%````````Y@4``(H````>`0``K00`
M`(L#```(!0```````"0%``!?`@```````.P!````````_`0```````#A`0``
M204````````3!@``B````.L"```V!```YP,``*T%``#/!0``R0,```````!!
M!```````````````````[`(``*,#````!```&@4``#,```#V!0``=P<`````
M``!O!@```````,T#``!Q`0``(`,``%L%````````A@```(4!````````M```
M`)$#``"&!```,@0``+D!``";`@``H@4``+@"``#G`@``;`8``#0$``"A````
M+@(``,H#```-`P```````(X%````````&P8``*X$``````````````````!M
M!0```````-H!````````$`0```@&````````)0```.,#``">````````````
M``!T!0``'P8````````7`0``0`4``!T```#.`@``H`4``(D&``"0`@``(P4`
M`)@"````````0`8``$$&``"C`0``HP4``"D"`````````````"T```!*!P``
MEP(``%0$`````````````#8"``#X!0``=@$``%\#```W`0```````%`$``!8
M!0``I`0```D```#%!0``A0,```````!:`0``:P(``.X#```;`@```````,0"
M``!:!P``10,``#X$``"2`0``Z`$``.4#``!3!`````````````"N`@``$`(`
M`!X"``!0`0``2@0```H`````````308``/X!```N````CP$````````M!P``
M[P(``.L!``#1`0``;@(`````````````W`(``,4"```G````M0,``)0%````
M````;@```!``````````CP0``!T!``!R!```=@<```(#``#@!0``4P<``+0#
M```'!P``CP,```````"/`@``:0$``(0#``#!`0``=P8``'`$``"J````4`(`
M`&8%````````C@,``"\'``"$!````````+X#``!`!```&@(````````Y`@``
ME`,``((````"!```````````````````$0(``!<"``#"````O0,```````#1
M!@``,@4``/````##!0```````$H%```3!P``60<```0$``!@`0``````````
M``#;`0``2@8``/,$``!M!@``.@4``#L'``"<`0``X0```+X"``#``P``&`0`
M````````````FP4``.L%``#W`P```````$,'```;`P``[@0``)<#```$`P``
M"08``(X&````````800``&`'```P`0``)@8```````!E!@``:P,```````!?
M!@``MP,```P"``!+`@``'P````P&``!F`0````````````!1`@``````````
M``"H!0``,08``+,!```-!@``U`$``#<%``"(`0``7``````````[!@``Z`,`
M`!P%``"]!```KP(```````"`````?`,``$$'````````A`8``-\!```W`P``
M\0$`````````````#````)@#``!E`@``H`(``/(%``````````````````!F
M!`````````````#K````N`4``*(&````````(`$``,,#```\!@``<@4``(8!
M``!M`@```````$\$``#G!@```````,<&``"1`0```````,,````>!P``````
M`&4$``!T!P````````\%```_`0``4`<``&\#```B!@``1````!8'````````
M`````-H"``!)````/0,``!D$````````\0```&L&````````#`4``%4#```)
M!0``)@4``+8&``"K!```"00``$D!``!$!@``````````````````(@4`````
M``"P````KP```#`&``#O!@``XP`````````C!@``%`,``,,$``#:!@``````
M``````"!`P``#@0``!H#``"N`0```````+L!``#C!@``S@````````"4`0``
M?P<``,<"```$!0```````#8!````````J````"X!```0`P```````)($```;
M`0``H@```%(%````````Z@8``-<"```````````````````+!```FP$``)T#
M``"L`0``#@(``-8%``#U!0``]P$```\#````````GP$``,4`````````R`(`
M`%<````X````*@(`````````````_P,``*D$``"]!0```````,0%````````
M40$``!\!``#M!@``^08``)@$``!2!````````*\!`````````````*8!``"K
M!0``L@(``&0&````````V`,``!@%``"H`P```````!P"```"!0```````(<'
M``"!!P``T@4``.4!``"M!@``Y0(``,$&``"M`@``<@,``)(%``"Q`0``````
M`-0%``"C!@```````+<%````````T`4``&\%````````^@(```````#>!@``
M```````````A`P``?@<``+8$``"G!@```````,8%``"I`0``0P```)\#```=
M`@```````$X$````````!`$``)D"``!1!0``0@,``'H&``#>`@```````$<'
M``!E!0``@`8``$8#``#E````3P4``,,&````````````````````````T```
M`%T#``"W````>P(``$4%````````4P8``-@%``!,`@``/0```"\%````````
M>P8``.("``!B!```'`,``````````````````,4$````````U0,``.0"``!Z
M`P``E````(@'```<!````````````````````````$,$```:!@``````````
M``!1!P```````"L#``#_````60,`````````````(@<``%,#```\`@``DP``
M`/4!``!7`@`````````````.!@```````)L$````````1`$``&$"``!-!```
M3`<``'`%``"S`P```````(8"``!.!@```````"@!````````W0$```````"S
M!0``<0<``-X$``!K!0``M`8``"D%```]!P``1`<``$P#``!K!```T0,`````
M``!J`@``L04``(($``!X`P``TP,``%(#``":`0``XP(``$X"``#$!```````
M`(H$``!L!P``<@```````````````````/P"````````-`4``&H#```&!P``
M)0,``'T&````````Z@,``)D$``"W`0``RP8``-$"```J`0``F0$``,T!````
M````5P<``%4"``!<`P``B`4````````R`@``^@```)D`````````S````+`"
M```V!0```````-<`````````IP4``````````````````"4&``"9!@``\`$`
M`",#```[````F`8``$,!``#(`P``C@(```4'```7!0``9P4`````````````
M`````"0#``",`@``'@```(0'``!6!P``KP4``$4```!V!@``.@0``,4!``#6
M`0``0@```&<$```H!P``<04``/8&``!6````$`$``/H%``!/`@````4``%P"
M``"E!0``!08``.H%```B````1P4```````!+!@``F@0``)P&``##`@``!00`
M````````````O08``'`#```5!@``[@8```````!_!0``Z@```#8#``!<!0``
M%`4``!$!```@`@```````&H%````````,0$``#\"``!/`0``,@$``"<"``#5
M`````````"<%``!H`P``^````'P"``"/!@````````````"E`@```````+`!
M``#^`P``8P$``+@```"1````````````````````E0```"@#```/````````
M``````",`P```````'\"``#)!0``R`$```````"(`P``(0<``*`!````````
MW0(``,L!```,`0``5P,``'D```#6!```Q0,```````#,`0``%0,`````````
M`````````&X'``#R!```>`0```H#````````/@8``-H$````````HP(``&T`
M``"1!0``&`<```````!8!P``+`0```(```!B`@``'@4```````#Y!0``4`4`
M``````#(````#@,``(T"````````IP,```H%````````.P,```$"```/!P``
M7P0```L"````````3````)P$``#3`0``*P4``.D%````````>`````````!H
M`0``\@```/`%``!-`@``N04```<%````````4@```.T#``!-!0``U08``#D`
M``#*!```GP4``,("``!?!P``!0$``'@&``!&!0``WP8`````````````!P``
M`#@%```M`P``_````,@&```5!P```P8``,H```!Z`0``%`$``/D#``#G!0``
MJP8``%4$``!4`0````````@#``"[`@``3@<``!0```"3`P``K`(``%X$``#9
M!```/`,``#(#``#V````0@0```````#@`@``L08`````````````W04``&(&
M``#"`P``S`,``.\$``!=!```E@$``(H#``!H!P``A0<`````````````%04`
M`(T&``"F!```,0<``(P!``!%!```FP```"$&``#T`@``=08`````````````
MN`0````````2`P``ZP8``&(%````````_00``)4&``#C!0``*@8`````````
M````^00```````"\`@```````+8!``!%!@```````*X&``!6!@``/@4`````
M``!!````.`0````````T`@````````,%````````D`4``!\#``"I`@``````
M``````!4`P``)P8``-4%``#[!@```````*H!``!E`P``$P0`````````````
M5`8``"D!``"U!0```````.8&``#5`@```````(D%``"%`@``N08``%H#``"#
M`0```````/`$```F`@``TP8````````U````O`8``,L"``"K`P``60``````
M```S`0```````.$&``"S!@``#04``$<!``!;!@``N@0``#8&````````6@8`
M``````!D````)`8``,D"````````G0````$!```'`0``0@(``(L$``!I````
MV04``"(!``"@!````````)0"```6!0```````#P!``#1!0```````!@!````
M````>@4``,<```#,!@````````````!@!0``)00``/@#```L!0``Z0```,($
M``"J!@``'08``$P!```R!@```@(``&D#``#@!```.`(`````````````_0``
M`*P&``"6!@``4P(````````S!@```"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S
M:V5Y("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H
M>65S=&5R9&%Y*0`@870@`"(E<R(@:7,@;F]T(&$@9&ER96-T;W)Y+@`B)7,B
M(&ES(&YO="!A('9A;&ED(&-H;VEC92X`(B5S(B!I<R!N;W0@8V]N9FEG=7)E
M9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN`"(E<R(@=')E92!R96YD97)E<B!N
M;W0@9F]U;F0N`"(E<R(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M
M+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+@`B
M)7,B('=A<R!N;W0@8W)E871E9#H@)7,N`"4N,F9-0B!U<V5D(&]F("4N,F9-
M0B!A;&QO=V5D("@E+C)F)24I`"5D("5S(&%N9"`E<P`E9"!D87ES('5N=&EL
M('EO=7(@<&%S<W=O<F0@97AP:7)E<RX`)60M9&%Y(&9O<F5C87-T`"5S("T@
M3F]T:6-E`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT96YA;F-E($]P
M97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T=7``)7,@4VEG;B!5<``E
M<R!497)M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D>2!E>&ES=',N`"5S(&%T
M("5S("5S`"5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE(&)O>"!F;W(@
M86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@
M=&EM92X`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@9F]U;F0N
M`"5S('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L96YD
M87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"5S.B!4:&ES
M(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E
M+B!"97=A<F4@;V8@9F]L;&]W:6YG(&%N>2!L:6YK<R!I;B!I="!O<B!O9B!P
M<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA
M=&EO;BX`+"!G=7-T:6YG(``L(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L92!F
M<F]M("5S('1O("5S`"TM('-E;&5C="`M+0`Q,B!(;W5R($9O<FUA=``R-"!(
M;W5R($9O<FUA=``R-"!H;W5R<P`\4')E=FEO=7,`02!D871A8F%S92!B86-K
M96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R
M(&AA<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O
M(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@
M:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@
M<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A
M=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV
M871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I
M<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!32!#;&]U9',`04T@3&EG:'0@
M4F%I;@!!32!286EN`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W97)S`$%-+U!-
M`$%022!)1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B;W1T;VT`
M06)S;6ED9&QE`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R
M>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`06-C;W5N="!)
M;F9O<FUA=&EO;@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!
M8V-O=6YT:6YG`$%D9`!!9&0@0VAI;&0@1W)O=7``061D($-H:6QD(%!E<FUI
M<W-I;VX`061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S
M:6]N`$%D9"!A(&-H:6QD(&=R;W5P('1O("(E<R(`061D(&$@8VAI;&0@<&5R
M;6ES<VEO;B!T;R`B)7,B`$%D9"!A(&YE=R!U<V5R.@!!9&0@8V]L=6UN`$%D
M9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-
M;WII;&QA(%-I9&5B87(`061D('1O(&%D9')E<W,@8F]O:SH`061D('1O(&UY
M(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1E9"`B)7,B('1O('1H92!S>7-T
M96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R
M;6%T:6]N.B`E<RX`061D960@(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N
M(&QO9R!I;B!N;W<N`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S
M<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F
M;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S`$%F9VAA;FES=&%N
M`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&EG;FUE;G0Z`$%L;`!!
M;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M:7-S
M:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT:7!L92!A9&1R97-S97,`
M06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR96%D>2!E
M>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@4&%S
M<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N871E(&5M86EL
M(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`
M06UE<FEC86X@4V%M;V$`06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D
M+@!!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+@!!;F1O<G)A`$%N9V]L
M80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`06YS=V5R`$%N=&%R8W1I8V$`
M06YT:6=U82!A;F0@0F%R8G5D80!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!,
M:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L>2!T;R!#:&EL9"!3:&%R
M97,`07!P<F]V90!!<'!R;WAI;6%T92!3:7IE`$%P<FEL`$%R86)I8R`H5VEN
M9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E
M('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E
M<W0@9F]R("5S(#\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92`B
M)7,B(&%N9"!A;GD@<W5B+6=R;W5P<S\`07)G96YT:6YA`$%R;65N:6$`07)M
M96YI86X@*$%235-#24DM."D`07)T`$%R=6)A`$%S8V5N<VEO;B!)<VQA;F0`
M07-C:6D@07)T`$%S:6$O4&%C:69I8R!296=I;VX`07-K(&9O<B!C;VYF:7)M
M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%S
M<VEG;FUE;G0@8V]L=6UN<P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES
M=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@
M<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E
M<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R
M92X`071T<FEB=71E<P!!=6=U<W0`075S=')A;&EA`$%U<W1R:6$`075T:%]C
M>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T
M:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B
M:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO
M="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W
M:71C:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R
M=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5M;W9I;F<@
M=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>0!!
M=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`
M075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L92!T;R!R96UO
M=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E
M<P!!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@
M9F]R($%C=&EV92!$:7)E8W1O<GDN`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!
M3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D
M('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@
M870@24U!4"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO;B!F86EL960`
M075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE
M8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@
M<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V
M97(@9F%I;&5D+@!!=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I:F%N`$)/1D@@
M17AC=7-E<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E
M<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A:&%M87,`
M0F%H<F%I;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A
M9&]S`$)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!"
M87-E;&EN90!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E<FUU9&$`
M0FAU=&%N`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@87!P;&EC871I;VX@(B5S
M(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0F]L9`!"
M;VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R
M9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A;F$`0F]T
M=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N($]C96%N
M(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I80!"=6QL971E
M9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`0U),($1I<W1R
M:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#86-H92!I;FET
M('=A<R!N;W0@8V]M<&QE=&5D+@!#86QE;F1A<@!#86QM`$-A;6)O9&EA`$-A
M;65R;V]N`$-A;B!N;W0@8V]P>2!F:6QE*',I("T@<V]U<F-E(&%N9"!D97-T
M:6YA=&EO;B!A<F4@=&AE('-A;64N`$-A;B!N;W0@;6]V92!F:6QE*',I("T@
M9&5S=&EN871I;VX@:7,@=VET:&EN('-O=7)C92X`0V%N(&YO="!R97-E="!P
M87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R
M871O<BX`0V%N(&YO="!W<FET92!T;R!F:6QE("(E<R(`0V%N)W0@861M:6YI
M<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+@!#86XG="!C;VYN96-T
M('1O($E-05`@<V5R=F5R.B`E<P!#86XG="!O<&5N(&9I;&4@(B5S(BX`0V%N
M861A`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T
M92!F:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R
M>2X`0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE
M=&5R+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M
M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E
M<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA
M=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P
M96-I9FEE9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#87)R:65R`$-A
M=&5G;W)I97,@86YD($QA8F5L<P!#87EM86X@27-L86YD<P!#96QL(%!H;VYE
M`$-E;&P@4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE
M<P!#96QL('-P86-I;F<Z`$-E;&QP:&]N90!#96QT:6,@*$E33RTX.#4Y+3$T
M*0!#96YT97(`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@175R
M;W!E86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I;',`0V5R=&EF
M:6-A=&4@3W=N97(`0V5R=&EF:6-A=&4@4&]L:6-I97,`0VAA9`!#:&%N9V4`
M0VAA;F=E(%EO=7(@4&%S<W=O<F0`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R
M97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@
M=&\@>6]U<B!E;6%I;',N`$-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T
M('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("!#
M;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0VAA<@!#:&5C7VL@3&EN:RXN
M+@!#:&EL90!#:&EN80!#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI
M;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`0VAO;W-E($%P<&QI8V%T:6]N.@!#
M:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W
M('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O
M<B!O<F1E<F5D(&QI<W1S*0!#:')I<W1M87,@27-L86YD`$-L87-S(&1E9FEN
M:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC92!T
M86=S`$-L96%R(%%U97)Y`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R
M`$-L96%R('5S97(@9&%T80!#;&5A<FEN9R!,871E`$-L:6-K('1O($-O;G1I
M;G5E`$-L:6-K871E;&P@=FEA($A45%``0VQO<V4@5VEN9&]W`$-L;W5D<P!#
M;&]U9',@16%R;'D`0VQO=61Y`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`$-O
M;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E<G,`0V]L;VUB:6$`0V]L
M;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L<SH`0V]L=6UN
M('1I=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`
M0V]M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY`$-O;7!U=&5R<P!#;VYD:71I
M;VX`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S`$-O;F9I
M9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A
M;F0@3W5T;&]O:RX`0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92X`0V]N
M9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L(%1H92!$
M96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&9A:6QE9"X`
M0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE
M('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@
M=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A8W1S`$-O;G1A8W1S('=E<F4@
M<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT
M96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B``0V]N=&5N=',@;V8@(B5S
M(@!#;VYT:6YU90!#;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P>2!F86EL
M960Z("5S`$-O<'D@<V5L96-T:6]N`$-O<W0@240`0V]S=&$@4FEC80!#;W1E
M(&0G279O:7)E`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E.B``0V]U
M;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4R]-24U%(&5N
M8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N
M`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@
M3$1!4"!S97)V97(N`$-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L
M9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-O;FYE
M8W0@=&\@<V5R=F5R("(E<R(@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@8W)E
M871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!0
M1U`@9&%T83H@`$-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L
M9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D96QE=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G
M<F%D92!S8W)I<'0@(B5S(BX`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C
M:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!F971C:"!C;VUP
M;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D
M:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T
M92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&QO860@
M<W1R871E9WD@(B5S(BX`0V]U;&0@;F]T(&UK9&ER("(E<R(N`$-O=6QD(&YO
M="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD
M(&YO="!O<&5N("(E<R(@9F]R('=R:71I;F<N`$-O=6QD(&YO="!O<&5N("5S
M+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#
M;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@(B5S(BX`0V]U;&0@;F]T(')E86-H
M('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO
M="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@
M4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4
M<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U
M(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O
M=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R
M971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I
M979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E
M('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I
M9W5R871I;VXN`$-O=6QD(&YO="!R;61I<B`B)7,B+@!#;W5L9"!N;W0@<V%V
M92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C
M;VYF:6=U871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A
M=&EO;CH@)7,`0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@
M=&\Z("(E<R(N`$-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A
M=&EO;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO
M;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92!O<'1I
M;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A
M;&QY('1H92!C;V1E(&)E;&]W('1O("5S+@!#;W5L9"!N;W0@<V5A<F-H('1H
M92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5N;&EN:R`B)7,B+@!#;W5L9"!N
M;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I
M8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N
M(&9O<B`B)7,B.B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B
M87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5L9&XG="!G
M:79E('5S97(@(B5S(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O
M;&1E<B`B)7,B.B`E<P!#;W5N=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R
M96%T90!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U
M8B!F;VQD97)S`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M
M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT(#0@4&AA<V5S`$-U<G)E;G0@4V5S
M<VEO;G,`0W5R<F5N="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@57-E
M<G,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N
M="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@
M)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2
M*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@
M*$M/23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`1%-.("AS964@:'1T<#HO+W!E
M87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R
M;RUD<VXN<&AP*0!$86EL>0!$871A5')E92!"<F]W<V5R`$1A=&%B87-E($QO
M;VMU<`!$871E`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1E
M7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-R96%S
M92!);F1E;G0`1&5F875L=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I
M='D`1&5F875L="!3:&5L;`!$969I;FET:6]N<P!$96QE=&4`1&5L971E($-E
M;&P`1&5L971E($=R;W5P`$1E;&5T92!,;V<`1&5L971E(%!E<FUI<W-I;VX`
M1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@
M8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L
M971E(&UE<W-A9V5S`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(@!$96QE
M=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(@86YD(&%N>2!S=6(M<&5R;6ES<VEO
M;G,_`$1E;&5T92!R;W<`1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T
M92!S=6(@9F]L9&5R<P!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T
M92!T:&4@8W5R<F5N="!R;W<`1&5L971E9"!S971U<"!U<&=R861E('-C<FEP
M="`B)7,B+@!$96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5S8W)I8F4@=&AE(%!R
M;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO
M9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI
M;FES=')A=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O
M<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R
M:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA
M>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!D971A
M:6QE9"!F;W)E8V%S=`!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@
M9F]R;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!N
M;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N
M<&AP`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE
M<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N
M(%)E<'5B;&EC`$1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"X`1&]W
M;FQO860`1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VX@87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-
M86EL`$5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S
M('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+@!%4E(`16-U861O<@!%9&ET
M`$5D:70@0FQO8VL`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!0
M97)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO
M;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES
M<VEO;G,@9F]R("5S`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M
M96YT+BXN`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S
M(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M86EL+71O
M+5--4R!'871E=V%Y`$5M;W1I8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R
M97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B;&4@:6YS97)T:6]N(&]F
M(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@
M<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%;F0@>65A<@!%;FQA<F=E($5D
M:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL
M(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@<&%S<W=O<F0L
M(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SH`16YT97(@
M=&AE(&EM86=E(%523"!H97)E`$5N=&5R('1H92!L971T97)S(&)E;&]W.@!%
M<75A=&]R:6%L($=U:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R(&-R96%T:6YG
M(&)L;V-K.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,`17)R
M;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S`$5R<F]R(&=E='1I;F<@8V]N=&5N
M=#H@)7,`17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S`$5R<F]R('=I=&@@
M96UA:6P@;65S<V%G92X`17)R;W(@=W)I=&EN9R`B)7,B+@!%<W1O;FEA`$5T
M:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`R
M(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E
M<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE
M('9A;'5E<SH`17AE8W5T90!%>'!A;F0`17AP86YD(%-I9&5B87(`17AP96-T
M960@)RDG`$5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E
M<FT`17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$9'($-O;&]R`$944"!U<&QO
M860@;V8@<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A
M:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N
M;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N
M`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W
M(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I
M;&5D('1O(')E=')I979E.B`E<P!&86ER`$9A;&ML86YD($ES;&%N9',@*$UA
M;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A=&%L($5R<F]R.@!&87@`1F%X97,`
M1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME.B``1F5W(%-H;W=E<G,`
M1F5W(%-N;W<@4VAO=V5R<P!&:65L9"!M871R:7@`1FEG;&5T($-!4%1#2$$`
M1FEG;&5T(&9O;G0`1FEJ:0!&:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL
M92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE
M('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O
M<G1E9"X`1FEL=&5R<P!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A<G1E
M<@!&:7@@<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T
M(&5X:7-T`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG
M="!S=7!P;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$87ES
M("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T
M:"!D87D@86YD(&YI9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E
M<W5L="!I;B!A('=I9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&
M;W)M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R
M`$9O<G5M<P!&;W)W87)D<P!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T
M<F]P;VQI=&%N`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N
M8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O;0!&<F]M('1H92``1G5L;"!$
M97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$=A8F]N`$=A;&QE<GD@
M=&\@=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=A;6)I80!'96YE<F%T92`E
M<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E;W)G:6$`1V5R;6%N
M>0!':&%N80!':6)R86QT87(`1VEV96X@3F%M90!';&]B86P@3W!T:6]N<P!'
M;P!';V5D96P`1V]O9VQE($UA<',`1V]O9VQE(%-E87)C:`!'<F%Y<V-A;&4`
M1W)E96-E`$=R965K("A)4T\M.#@U.2TW*0!'<F5E;FQA;F0`1W)E;F%D80!'
M<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE
M;7!T>0!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES
M(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``1W)O=7!?;&1A<#H@56YA8FQE
M('1O(&1E;&5T92!G<F]U<"`E<P!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D
M871E(&=R;W5P("5S`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA
M`$=U97)N<V5Y`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`
M1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!C;W=A<F1L>2!R
M969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RX`2%1-3$%R
M96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN
M(&EN('1A8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T
M92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@075T:&5N=&EC871I;VX@
M;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R:71H;0!(87IE`$AE861E<@!(
M96%D97)S`$AE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<P!(96%V
M>2!4+5-T;W)M`$AE8G)E=R`H25-/+3@X-3DM."U)*0!(96EG:'0`2&5L<`!(
M96QP('5S:6YG(&5D:71O<@!(96QP97(`2&5M:7-P:&5R90!(97)E(&ES('1H
M92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AI9V@`2&]?;64`2&]L>2!3964@
M*%9A=&EC86X@0VET>2!3=&%T92D`2&]M90!(;VUE($%D9')E<W,`2&]M92!$
M:7)E8W1O<GD`2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`
M2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@
M:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P
M;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T
M>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E
M<W-F=6QL>2!R96UO=F5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E
M9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E
M;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T
M<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO
M=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V
M92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S`$AO<F1E+TMO
M;&%B.B!5;FMN;W=N('-H87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ
M;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W<@9&ED('EO=2!G970@:&5R
M93\@*%!L96%S92!R97!O<G0A*0!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO
M=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R
M92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G
M93\`2'5M:61I='D`2'5M:61I='DZ(`!(=6UO<FES=',`2'5N9V%R>0!)34%0
M(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L
M971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@
M9F%I;&5D.B`E<P!)4"!!9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L
M92X`25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`
M25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)7VYS97)T(%)O=R!"969O<F4`26-E
M;&%N9`!)8V]N<R!/;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`
M261E;G1I='DG<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E
M8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D
M;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y
M;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'
M('1R86YS<&%R96YC>2X`268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO
M(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E
M(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EM86=E(%!R979I97<Z`$EM
M86=E(%523`!);6%G92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G92!F
M<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G97,`26UP;W)T+"!3=&5P
M("5D`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E
M<G0@4F]W($%F=&5R`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC
M;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T('5S
M97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N
M=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H
M96QP+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD:79I9'5A;"!5<V5R<P!)
M;F1O;F5S:6$`26YF;P!);F9O<FUA=&EO;@!);F9O<FUA=&EO;B!N;R!L;VYG
M97(@879A:6QA8FQE+@!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA
M9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O;'5M
M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N
M="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@
M;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN
M<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@
M82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@82!P
M87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L=&5R
M;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC
M:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T(&-E
M;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T
M97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R
M="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`26YS
M97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE(')E
M<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R
M="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N
M="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN
M<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN=F%L
M:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L:60@6DE0(&1A=&$`
M26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI
M9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S
M+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;&EC96YS92!K97DN`$EN
M=F%L:60@;&]C871I;VX@<')O=FED960N`$EN=F%L:60@;7-G7W1Y<&4N`$EN
M=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P
M87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED
M('!A<G1N97(@:60N`$EN=F%L:60@<')O9'5C="!C;V1E+@!);G9A;&ED('!R
M;W1O8V]L+@!);G9A;&ED(')E8VEP:65N=#H@(B5S(@!);G9A;&ED('-H87)E
M(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O
M9&4@9&%T82X`26YV96YT;W)Y`$EN=F5R="!S96QE8W1I;VX`27)A;BP@27-L
M86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`27-O
M;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M
M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2F5R
M<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*
M=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2V%Z86MH
M<W1A;@!+965P(&]R:6=I;F%L/P!+96YY80!+97)B97)O<R!S97)V97(@<F5J
M96-T960@875T:&5N=&EC871I;VXN`$ME<FYE;"!.97=B:65S`$ME>2!#<F5A
M=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+97D@
M57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R
M=F5R+@!+:61S`$MI<FEB871I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S
M(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O9@!+;W)E86X@*$550RU+
M4BD`2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U=`!,86YG=6%G90!,86\@4&5O
M<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T($AA;&8`3&%S="!087-S
M=V]R9"!#:&%N9V4`3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`3&%S="!L
M;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.
M979E<@!,871V:6$`3&%W`$QA>6]U=`!,96%V92!E;7!T>2!F;W(@;F\@8F]R
M9&5R`$QE8F%N;VX`3&5F=`!,969T(&AE861E<@!,969T('9A;'5E<P!,97-O
M=&AO`$QE=F5L`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C
M:'1E;G-T96EN`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN
M($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H
M="!286EN('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO
M=V5R`$QI;65R:6-K`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M
M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI
M;F<`3&EN:W,`3&EN=7@@0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE
M(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@
M5&%B;&5S`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W
M;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E
M`$QI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&9A
M:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R
M90!,:71H=6%N:6$`3&]A9&EN9RXN+@!,;V-A;"!T:6UE.B``3&]C86QE(&%N
M9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@;V8@<')E=FEO=7,@<WEN8R!S
M97-S:6]N`$QO9R!O=70`3&]G:6X`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D
M(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E
M9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`3&]V90!,
M;W<`3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S`$QO
M=V5R(')O;6%N(&YU;6)E<G,`3'5X96UB;W5R9P!-30!-3U1$`$U3+51.148@
M071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA8V%O`$UA8V5D
M;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-861A9V%S
M8V%R`$UA9VEC`$UA:6P`36%I;"!!9&UI;@!-86ME(&QI;E]K+BXN`$UA;&%W
M:0!-86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES
M="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L
M(&%N9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N
M`$UA<#(T(&UA<`!-87!1=65S="!M87``36%P<&EN9W,@<W1O<F5D+@!-87)C
M:`!-87)G:6X`36%R:R!W:71H(%-E96XO56YS965N(&9L86=S`$UA<FL@=VET
M:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I`$UA<G-H
M86QL($ES;&%N9',`36%R=&EN:7%U90!-871C:&EN9R!F:65L9',`36%U<FET
M86YI80!-875R:71I=7,`36%X(&%L;&]W960@8W)E9&ET+@!-87@@;65S<V%G
M92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA
M>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@3G5M8F5R(&]F(%!O<G1A
M;"!";&]C:W,`36%X:6UU;2!L96YG=&@`36%Y`$UA>6]T=&4`365D:6-I;F4`
M365M8F5R<P!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G
M92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T
M:69I8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I960N`$UE<W-A9V4@97AP:7)E
M9"X`365S<V%G92!T>7!E`$UE=&%R(%=E871H97(`365T87(@8FQO8VL@;F]T
M(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL
M<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T
M87)$0B!I<R!N;W0@8V]N;F5C=&5D+@!-971H;V0`365T:&]D("(E<R(@:7,@
M;F]T(&1E9FEN960`365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D
M.B`E<P!-971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T
M97,@;V8`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S
M.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36EN:6UU;2!P87-S=V]R9"!A
M9V4@:&%S(&YO="!Y970@97AP:7)E9`!-:7)R;W(`36ES8V5L;&%N96]U<P!-
M:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N`$UI<W-I;F<@8V]N
M9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO
M=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A
M9V4@240N`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN`$UI
M<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D
M:69I960@1&%T90!-;V1I9GD@55),`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L
M:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`
M36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)E(&9I96QD<R!F;W5N9"!I;B!L
M:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+@!-;W)O8V-O`$UO<W1L>2!#
M;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!#;&]U9'D@86YD(%=I;F1Y`$UO
M<W1L>2!3=6YN>0!-;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V
M92!5<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L
M(&1R;W`@9&]W;B!L:7-T<P!-=6QT:6UA<"!52R!M87``375L=&EP;&4@<V5L
M96-T:6]N`$UY($%C8V]U;G0`37D@06-C;W5N="!);F9O<FUA=&EO;@!->2!0
M;W)T86P`37D@4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!
M9W)E90!.86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N9',`3F5T
M:&5R;&%N9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@
M0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S
M8V%P92!296YE=V%L(%523`!.971S8V%P92!2979O8V%T:6]N(%523`!.971S
M8V%P92!34TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M
M;65N=`!.971S8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`
M3F5W($-A;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($UO;VX`3F5W(%5S97)N
M86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W('!A<W-W;W)D`$YE=R!P
M87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"X`3F5W('!A<W-W;W)D<R!D;VXG
M="!M871C:"X`3F5W('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U<',`
M3F5X=`!.97AT(#0@4&AA<V5S`$YE>'0@;W!T:6]N<P!.97AT/@!.:6-A<F%G
M=6$`3FEG97(`3FEG97)I80!.:6=H=`!.:75E`$YO`$YO(&%V86EL86)L92!C
M;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO
M(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO
M(&)A=&-H('1E;7!L871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E
M<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-
M0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A
M;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93
M+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M4U%,+49I;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I;VX@
M<W5P<&QI960N`$YO(&9I;&4@=7!L;V%D960`3F\@:6-O;G,@9F]U;F0N`$YO
M(&QO8V%T:6]N(&ES('-E="X`3F\@;&]C871I;VX@<')O=FED960N`$YO(&UE
M<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N=6UB97(@
M<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`
M3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/
M<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H(%!+0U,@
M,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!Q=6]T82!S970N`$YO
M(')U;&5S`$YO('-E<&%R871O<B!S<&5C:69I960N`$YO('-I9&5S`$YO('-U
M8V@@9FEL90!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@
M8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V
M86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F
M;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O
M;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U
M<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;F4`3F]N92`H
M=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK($ES
M;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA;F$@27-L
M86YD<P!.;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER96-T
M;W)Y`$YO="!I;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.
M;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V96UB97(`3G5M
M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU
M;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I
M;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@0W)E
M871O<@!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/;&0@
M86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N`$]L9"!P87-S
M=V]R9`!/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N`$]M86X`3VYL>2!)
M34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!O9F9E
M;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D
M+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@
M8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S
M:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R.B!#;W5L
M9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+@!/
M<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T
M96T`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI
M<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA
M;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@
M)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E<FUI<W-I;VYS
M`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!014%2.CI-
M86EL(&)A8VME;F0`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T
M960@1&%T80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$
M871A`%!(4"!#;V1E`%!(4"!3:&5L;`!032!,:6=H="!286EN`%!-(%)A:6X`
M4$T@4VAO=V5R<P!032!3;F]W`%!-(%-N;W<@4VAO=V5R<P!032!3=6X`4$T@
M5"U3=&]R;7,`4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<`4%](4"!3:&5L
M;`!0861D:6YG`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R
M>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`
M4&%R=&QY($-L;W5D>0!087-S=V]R9`!087-S=V]R9"!C:&%N9V5D('-U8V-E
M<W-F=6QL>2X`4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E<75I<F5D
M(&9O<B!2041)55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N
M9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T
M(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I
M;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC
M92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O
M;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N("(E<R(@;F]T(&1E;&5T
M960N`%!E<FUI<W-I;VX@1&5N:65D`%!E<FUI<W-I;VYS`%!E<FUI<W-I;VYS
M($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G4`4&5T
M<P!0:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`4&ET8V%I<FX`4&EX96QS`%!L
M871I='5D97,`4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L96%S92!C
M;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#H`
M4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E
M;&5M96YT+@!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A
M<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@
M96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT97(@82!V86QI
M9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H
M+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+@!0;&5A<V4@<')O=FED92!A
M('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@
M=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!R96%D('1H92!F;VQL;W=I
M;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E
M('1H92!S>7-T96TN`%!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M
M93H`4&]L86YD`%!O;&ET:6-S`%!O;&QS`%!O<G1U9V%L`%!O<VET:6]N:6YG
M(&]F('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T
M('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`4')E8VEP
M:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E8VEP:71A=&EO;CQB
M<B`O/F-H86YC90!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@
M97AT96YS:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A
M(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E
M(&EN(&$@;F5W('=I;F1O=P!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M
M96YT`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!0
M<F]J96-T<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG
M;W)I=&AM`%!U8FQI8R!+97D@26YF;P!0=6)L:6,O4')I=F%T92!K97EP86ER
M(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!0=7)G
M92!M97-S86=E<P!1871A<@!1=65R>0!1=6]T80!24T$@4'5B;&EC($ME>2`H
M)60@8FET*0!2861I;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY`%)A:6X@
M3&%T90!286EN(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!2
M86YD;VT@1F]R='5N90!2871I;P!296%D`%)E860@;65S<V%G97,`4F5A;&QY
M(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`
M4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E
M<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E9&]E<R!Y;W5R(&QA<W0@86-T
M:6]N`%)E9G)E<V@`4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z`%)E
M9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T:6]N<VAI<"!"<F]W<V5R
M`%)E;&]A9`!296UA<FMS`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT
M='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L
M;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E('!A
M:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R
M>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M
M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5Q
M=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E
M.B``4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+@!297%U
M:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BX`
M4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T
M:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A
M=&EO;BX`4F5Q=6ER960@1FEE;&0`4F5S970`4F5S970@4&%S<W=O<F0`4F5S
M970@66]U<B!087-S=V]R9`!297-T;W)E($QA<W0@475E<GD`4F5S=6QT<P!2
M971U<FX@=&\@3W!T:6]N<P!2971Y<&4@;F5W('!A<W-W;W)D`%)E=6YI;VX`
M4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS
M`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R`%)I9VAT('9A;'5E<P!2;U]W
M(%!R;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA`%)O=&%T92`Q.#``4F]T871E
M($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O=R!P<F]P97)T
M:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL
M(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C
M;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N
M;'D`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`4R]-24U%($-R>7!T
M;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T960@365S<V%G90!3
M05-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S
M86=I;F<`4U%,(%-H96QL`%-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU
M<',`4U-(`%-50T-%4U,`4U]13"!3:&5L;`!380!386EN="!(96QE;F$`4V%I
M;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A
M;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,`
M4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@
M86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3875D:2!!<F%B:6$`
M4V%V90!3879E("(E<R(`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G96YE
M<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S
M97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U
M<F%T:6]N+@!3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`
M4V-A='1E<F5D(%0M4W1O<FUS`%-C:65N8V4`4V5A<F-H`%-E87)C:"!%;F=I
M;F5S`%-E;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&=R;W5P
M('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E
M;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A;&P`4V5L96-T(&%L;"!D871E
M(&-O;7!O;F5N=',N`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T(&YO;F4`4V5L
M96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E
M;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H
M92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C
M="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A
M;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE
M8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD
M<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F
M97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`
M4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE
M9W)O`%-E<FEA;"!.=6UB97(`4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V
M86EL86)L92X`4V5S<VEO;B!!9&UI;@!397-S:6]N($E$(&5X<&ER960N`%-E
M<W-I;VYS`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@
M>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R
M96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO
M=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z
M;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC
M871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H
M97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C<FEP
M=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@
M=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAO<'!I;F<`4VAO<G0@4W5M
M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L
M:6YK<S\`4VAO=P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY
M('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN
M`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O
M<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('1A8FQE
M(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE
M(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`
M4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B
M;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E
M<G1I97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R<R!%87)L
M>0!3:&]W97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@5FEC:6YI='D`4VAR:6YK
M`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@
M=&AE('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N871U<F4`
M4VEG;F%T=7)E($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ90!3:VEP($UA:6YT
M96YA;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<`4VYO=R!3:&]W97(`4VYO
M=R!3:&]W97)S`%-N;W<@4VAO=V5R<R!%87)L>0!3;F]W(%-H;W=E<G,@3&%T
M90!3;F]W(&1E<'1H.B``4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B``4V]L
M;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]N9W,@)B!0;V5M<P!3;W)T(&]R9&5R
M('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@
M175R;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3
M;W5T:"!386YD=VEC:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`4W!A
M8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<P!3<&%C92!B971W965N(&-O;G1E
M;G0@86YD(&)O<F1E<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@
M86YD('!A9&1I;F<`4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A8W1E<B!);G!U
M=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-R
M:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0@>65A<@!3=&%T92!O
M<B!0<F]V:6YC90!3=&%T=7,`4W1O<F%G92!F;W)M870`4W1R965T($%D9')E
M<W,`4W1R:6ME=&AR;W5G:`!3=')I;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O
M;2!T:&4@861D<F5S<P!3='EL92!;0U-370!3=0!3=6)D:7)E8W1O<GD@(B5S
M(B!N;W0@9F]U;F0N`%-U8FIE8W0`4W5B;6ET`%-U8FUI='1E9"!R97%U97-T
M('1O(&%D9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN
M('5N=&EL('EO=7(@<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"X`4W5B<V-R
M:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y
M<W1E;2X`4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`B)7,B
M(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`
M4W5C8V5S<V9U;&QY(')E;6]V960@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U
M8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@
M<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG
M=7)A=&EO;BX`4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG
M=7)A=&EO;B!F:6QE("5S+@!3=6-C97-S9G5L;'D@=7!D871E9"`B)7,B`%-U
M8V-E<W-F=6QL>2!W<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U
M;B!3970`4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``
M4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`
M4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D
M96X`4W=I='IE<FQA;F0`4WEN8R!L;V<@9&5L971E9`!3>6YC34P`4WEN=&%X
M(&5R<F]R(&EN('-E87)C:"!T97)M<P!3>7)I86X@07)A8B!297!U8FQI8P!4
M+5-T;W)M`%0M4W1O<FT@86YD(%=I;F1Y`%0M4W1O<FUS`%0M4W1O<FUS($5A
M<FQY`%135B!F:6QE`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@4V5T`%1A8FQE
M('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`
M5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E
M=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z
M(`!496UP97)A='5R90!496UP97)A='5R93H@`%1E;7!E<F%T=7)E/&)R("\^
M*"5S2&DE<R\E<TQO)7,I("9D96<[)7,`5&5M<&QA=&4@(B5S(B!N;W0@9F]U
M;F0N`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1E
M>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I("A425,M-C(P*0!4:&%I;&%N9`!4
M:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@2&ES=&]R
M>2!S>7-T96T@:7,@9&ES86)L960N`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A
M=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="`B)7,B`%1H92!)35-0(&QO
M9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N`%1H92!-86EN=&5N86YC93HZ
M(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@
M=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A9&UI;FES=')A=&]R
M(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B
M86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N<RX`5&AE(&)O
M='1O;2!S:61E(&]N;'D`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@
M<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE
M(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D
M('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@9&5T86-H960@4$=0('-I9VYA
M='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M
M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N
M;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@
M9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I
M9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R
M92!W96(@8V]N;F5C=&EO;BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@
M82`E<R!S971T:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE
M("5S('-E='1I;F=S+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82X`5&AE
M(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R
M9F,X,C(@;65S<V%G92X`5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@
M=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E
M('1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K
M87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D:7-P;&%Y
M+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W
M<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET
M)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@4')O
M=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQN7&Y9;W4@:&%V
M92!B965N('=A<FYE9"X@(%!L96%S92!P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@
M=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BX`5&AE(&ED96YT
M:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&QE9G0M:&%N9"!S:61E
M(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B
M92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M97-S86=E
M('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T("(E<R(@:&%S(&)E96X@
M9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S
M86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"X`5&AE(&YA;64@=&\@
M=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H92!N=6UB
M97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RX`5&AE(&]P96YS<VP@;6]D
M=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C
M;&%S<RX`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@
M8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B
M;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y
M<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!Q=6]T
M92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE
M(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED
M92!O;FQY`%1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A
M8W1E<BX`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S
M97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE('-I9VYU<"!R97%U97-T
M(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@<W!E8VEF:65D(')O=R`H
M)60I(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5M<&]R87)Y(&9I;&4@(B5S(B!D
M;V5S(&YO="!E>&ES="X`5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M
M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+@!4:&4@=&]P(&%N9"!B;W1T
M;VT@<VED97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4:&4@=7!L;V%D960@
M9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P
M;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=V5A=&AE<BYC
M;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE;65S(&1I<F5C=&]R>2`B
M)7,B(&YO="!F;W5N9"X`5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE
M+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN
M;&EN92X`5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F
M:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S
M="!E;G1E<B!L97-S('1H86X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@861D
M:6YG("(E<R(@=&\@=&AE('-Y<W1E;3H@)7,`5&AE<F4@=V%S(&$@<')O8FQE
M;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M
M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R`B)7,B(&9R;VT@=&AE
M('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@(B5S(CH@
M)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@
M3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M
M87AI;75M(&%L;&]W960@<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@82!P
M<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@
M<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA
M>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R
M;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F
M="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R('!E
M<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN
M(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U
M<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN
M(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R
M:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&ES($E-
M05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4
M:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E
M+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE
M+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E
M<BX`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR
M;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G
M871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O
M=VEN<&QC+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@
M9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE
M('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S
M:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L
M>2!G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I
M<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H:'1T
M<#HO+W=W=RXQ.3`N:70I+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@
M;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@
M9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE
M;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F
M(&EN=&5G97)S`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`
M5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!2
M1T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O
M<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H
M:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@
M;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD
M97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI
M<W0@;V8@<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES
M(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@
M;W1H97(@=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L
M96%S="!O;F4N`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N
M9"!G>FEP(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I
M=F%T960N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD
M;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N
M9&5R`%1I8VME=',`5&EM90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I
M;64@<V5L96-T:6]N`%1I;6]R+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP
M*3H`5&\`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE
M($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC
M:VEN9RX`5&]D87D`5&]G9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA=0!4
M;VUO<G)O=P!4;VYG80!4;V\@;6%N>2!I;G9A;&ED(&QO9VEN<R!D=7)I;F<@
M=&AE(&QA<W0@;6EN=71E<RX`5&]P`%1O<"!F<F%M92`H7W1O<"D`5')A;G-L
M871I;VYS`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS90!4=0!4
M=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T
M86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@
M8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DP@9F]R('EO=7(@<V-R:7!T
M(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),.@!59V%N9&$`56MR86EN90!5
M;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@
M97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L
M92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA
M8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`
M56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-H96-K(&9I;&4@
M<VEZ92!O9B`B)7,B+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E
M<R\E<R(N`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L
M92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL
M92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y("(E<R(N`%5N86)L
M92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R96%T92!6
M1E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R("(E<R(N`%5N
M86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O
M;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C
M=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@(B5S(CH@)7,N
M`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M
M<'1Y`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L
M>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@
M9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&
M4R!F:6QE("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L
M92!T;R!D96QE=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@9&5L971E
M(%9&4R!R96-U<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D971E<FUI;F4@8W5R
M<F5N="!D:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E
M(&1E=&%I;',`56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N
M`%5N86)L92!T;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@
M9FEL92`B)7,B+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN
M9RX`56YA8FQE('1O(&]P96X@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O
M;7!R97-S960@87)C:&EV92X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I
M;&5S:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E
M=$9I;&53:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@9FEL93H@`%5N
M86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O
M(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@
M97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE
M('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S
M+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N
M("=M:VES;V9S)RX`56YA8FQE('1O('1R:6=G97(@9G)E92]B=7-Y('5P9&%T
M92!F;W(@)7,`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L
M92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T
M;R!W<FET92!61E,@9FEL92!D871A+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4L('%U;W1A('=I;&P@8F4@97AC965D960N`%5N9&5R;&EN90!5;F1O($-H
M86YG97,`56YD;V5S('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P
M;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R
M97-P;VYS92!F<F]M('-E<G9E<B!T;SH@`%5N9FEL960`56YI8V]D92`H551&
M+3@I`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E
M9"!3=&%T97,`56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S
M`%5N:71S`%5N:VYO=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@
M240I+@!5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N
M:VYO=VX@;&]C871I;VX@<')O=FED960N`%5N:VYO=VX@=7-E<FYA;64@;W(@
M<&%S<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M960`
M56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]0
M87-T92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#
M;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R
M9R!W:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C
M8V5S<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!%
M>'1E;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&1A=&5D
M("(E<R(N`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E
M9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`
M57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U
M87D`57-E($-U<G)E;G0Z("5S`%5S92!34TP`57-E(&EF(&YA;64O<&%S<W=O
M<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E<@!5<V5R("5S
M(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO
M;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<B!296=I<W1R
M871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`57-E<B!A
M8V-O=6YT(&YO="!F;W5N9`!5<V5R;F%M90!5<V5R;F%M92`B)7,B(&%L<F5A
M9'D@97AI<W1S+@!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@
M<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI
M<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``
M5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L=64@:7,@
M;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N`%9A;'5E<P!686QU97,@
M=&\@<V5L96-T(&9R;VT`5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`5F5R
M:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N
M('1A;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I
M8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@2&EG
M:`!6:65T($YA;0!6:65T;F%M97-E("A625-#24DI`%9I97<@)7,`5FEE=R!A
M;B!E>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I<F=I;B!)<VQA;F1S
M+"!"<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES
M:6)I;&ET>3H@`%9O9&%F;VYE($ET86QY('9I82!33510`%=!4DX`5T%23DE.
M1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=)3B!V:6$@
M2%144`!786QL:7,@86YD($9U='5N80!787)N:6YG`%=E`%=E871H97(@1F]R
M96-A<W0`5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E
M8@!796(@4VET90!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O
M;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y
M+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E
M<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@
M8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H97)E
M:7,@075S=')A;&EA(&UA<`!7:&EC:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T
M;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+@!7:61T:`!7:61T
M:"!I;B!#4U,@=6YI=',`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE
M9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H(&]F('1H
M92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I;F0`5VEN9"!%87)L
M>0!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`5VES
M:&QI<W0`5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!7<F]N9R!N=6UB
M97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E
M9"X`5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD
M("5D+@!7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE
M+@!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S($5X=&5N
M9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE
M`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I
M;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S`%EE<RP@
M22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B
M=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@
M86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RX`66]U(&%R
M92!N;W0@875T:&5N=&EC871E9"X`66]U(&-A;FYO="!H879E('1H92`G7"<@
M8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E
M<B!A('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F
M:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N
M9&EN9R!F:65L9',@:6X@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`
M66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D
M:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R
M;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@
M=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A
M8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&
M4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O
M<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@
M96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M
M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@
M<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E
M8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T
M:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R
M;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@
M=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE
M+@!9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R
M`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G
M86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9
M;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA
M;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@
M5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I
M;BX`66]U<B!.86UE`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S
M(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@=7-E
M($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@
M=7-E(&$@9&EF9F5R96YT(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0N`%EO=7(@
M875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I
M;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O
M<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@
M:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S
M97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO
M9VEN(&%G86EN+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES
M(&9E871U<F4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@
M<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0('1O('!R
M:6YT+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E
M;G1I='D@:&%S(&)E96X@8VAA;F=E9"X`66]U<B!D969A=6QT(&ED96YT:71Y
M.@!9;W5R(&9U;&P@;F%M93H`66]U<B!L;V=I;B!H87,@97AP:7)E9"X`66]U
M<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V
M92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I
M;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P87-S
M=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E
M<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE
M=R!P87-S=V]R9"X`66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"X`66]U<B!R
M96UO=&4@<V5R=F5R<SH`675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B
M=V4`6FEP<'D`6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`
M6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI
M;F5S70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]#3$D`7T1A
M=&%4<F5E`%]$96QE=&4@4F]W`%]'<F]U<',`7TAE;'``7TEM86=E(%!R;W!E
M<G1I97,N+BX`7TQO9R!I;@!?3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`7T]P
M=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN:RXN+@!?4V5T=7``7U1A
M8FQE(%!R;W!E<G1I97,N+BX`7U5S97)S`&%D9')E<W,@8F]O:P!A9&1R97-S
M964@=6YK;F]W;@!C86QE;F1A<@!C86QM`&-A;FYO="!C<F5A=&4@;W5T<'5T
M(&9I;&4`8V%N;F]T(&]P96X@:6YP=70`8VQI8VL@:&5R90!C;VUM86YD(&QI
M;F4@=7-A9V4@97)R;W(`8V]N9FEG=7)A=&EO;B!E<G)O<@!C<FET:6-A;"!S
M>7-T96T@9FEL92!M:7-S:6YG`&1A=&$@9F]R;6%T(&5R<F]R`&5D:70`96YT
M<GD@;F]T(&9O=6YD`&9A;&QI;F<`9FEL90!F<F]M('1H92`E<R`H)7,I(&%T
M("5S("5S`&=U<W1I;F<`:#H`:&@`:&]S="!N86UE('5N:VYO=VX`:6UM961I
M871E`&EN;&EN90!I;G!U="]O=71P=70@97)R;W(`:6YT97)N86P@<V]F='=A
M<F4@97)R;W(`;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M
M86MI;F<@25-/+@!M;0!N86UE`&YO="!I;7!L96UE;G1E9`!N;W0@>65T(&EM
M<&QE;65N=&5D`&YO=&5P860`<&5R8V5N=`!P97)M:7-S:6]N(&1E;FEE9`!P
M:7AE;',`<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L`')I<VEN9P!S97)V:6-E
M('5N879A:6QA8FQE`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(
M5%10`'-S`'-T96%D>0!S>7-T96T@97)R;W(`=&%S:R!L:7-T`'1E;7!O<F%R
M>2!F86EL=7)E`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`
M=6YI9FEE9`!U;FYA;65D`'5S97(@<V5L96-T`'9#87)D`'<Z`'=E871H97(N
M8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@,RXP+6-V<PI297!O<G0M
M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I
M;VXM1&%T93H@,C`P-BTP-2TQ."`P.#HQ-RLP,C`P"E!/+5)E=FES:6]N+41A
M=&4Z(#(P,#8M,#(M,34@,3<Z,C0K,#$P,`I,87-T+51R86YS;&%T;W(Z($UA
M;G5E;"!0+B!!>6%L82`\;6%Y86QA0'5N97@N97,^"DQA;F=U86=E+51E86TZ
M(&DQ.&Y`;&ES=',N:&]R9&4N;W)G"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E
M;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ"D-O;G1E
M;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*4&QU<F%L+49O<FUS.B!N<&QU
M<F%L<STR.R!P;'5R86P]*&X@(3T@,2D["@`@*&AA8V4@)7,@9.UA<RD`("A!
M8V-E9&EE;F1O(&$@)7,I`"`H96X@)7,@9.UA<RD`("AH;WDI`"`H;6'Q86YA
M*0`@*&%Y97(I`&5N(``B)7,B(&YO(&5S('5N(&1I<F5C=&]R:6\N`"(E<R(@
M;F\@97,@=6YA(&5L96-C:?-N(';A;&ED82X`3F\@<V4@:&$@8V]N9FEG=7)A
M9&\@(B5S(B!E;B!E;"!R96=I<W1R;R!D92!(;W)D92X`3F\@<V4@96YC;VYT
M<O,@96P@9V5N97)A9&]R(&1E(.%R8F]L97,@9&4@(B5S(BX`4V4@:&$@8?%A
M9&ED;R`B)7,B(&%L('-I<W1E;6$@9&4@9W)U<&]S+@!392!H82!A\6%D:61O
M("(E<R(@86P@<VES=&5M82!D92!P<FEV:6QE9VEO<RX`3F\@<V4@:&$@8W)E
M861O("(E<R(Z("5S+@!5<V%D;W,@)2XR9DU"(&1E("4N,F9-0B!P97)M:71I
M9&]S("@E+C)F)24I`"5D("5S('D@)7,`475E9&%N("5D(&3M87,@:&%S=&$@
M<75E(&5X<&ER92!L82!C;VYT<F%S9?%A+@`E9"!P<F]N\W-T:6-O<R!D:6%R
M:6]S`"5S("T@079I<V\`2'5E;&QA(&1I9VET86P@9&4@)7,`)7,@2T(`)7,@
M;W!E<F%C:6]N97,@9&4@;6%N=&5N:6UI96YT;R`M($-O;F9I<FUA8VGS;@!#
M;VYF:6=U<F%C:?-N(&1E("5S`$9I<FUA(&1E("5S`$%C=65R9&]S(&1E(&QI
M8V5N8VEA(&1E("5S`%EA(&5X:7-T92`E<RX`)7,@82!L87,@)7,@)7,`)7,@
M97-TX2!P<F5P87)A9&\@<&%R82!R96%L:7IA<B!L87,@;W!E<F%C:6]N97,@
M9&4@;6%N=&5N:6UI96YT;R!S96QE8V-I;VYA9&%S+D%C=&EV92!L87,@8V%S
M:6QL87,@9&4@;&%S(&]P97)A8VEO;F5S('%U92!D97-E82!E:F5C=71A<B!E
M;B!E<W1A(&]C87-I\VXN`$AA8V4@9F%L=&$@)7,`)7,@;6EN=71O<P!.;R!S
M92!H82!E;F-O;G1R861O("5S+@`E<R!A;"`E<R!D92`E<P!$:7)E8V-I;VYE
M<R!D92`E<P!!9V5N9&$@9&4@)7,`3&EB<F5T82!D92!N;W1A<R!D92`E<P!4
M87)E87,@9&4@)7,`)7,Z("5S`"5S.B!%<W1E(&UE;G-A:F4@<'5E9&4@<75E
M(&YO('!R;V-E9&$@9&4@<75I96X@<&%R96-E('-E<BX@179I=&4@<V5G=6ER
M(&-U86QQ=6EE<B!V[6YC=6QO(&EN8VQU[61O(&\@<W5M:6YI<W1R87(@8W5A
M;'%U:65R(&EN9F]R;6%C:?-N('!E<G-O;F%L(&%L(')E;6ET96YT92X`+"!V
M96YT;W-O(``L('9E;G1O<V\@)7,@)7,`+"!V87)I86)L92!D92`E<R!A("5S
M`"TM('-E;&5C8VEO;F%R("TM`$9O<FUA=&\@9&4@,3(@:&]R87,`1F]R;6%T
M;R!D92`R-"!H;W)A<P`R-"!H;W)A<P`\06YT97)I;W(`4&%R82!E<W1E(&)L
M;W%U92!H86-E(&9A;'1A('5N(&UO=&]R(&1E(&)A<V4@9&4@9&%T;W,N`%-E
M(&AA('!R;V1U8VED;R!U;B!E<G)O<B!I<G)E<&%R86)L90!(86-E(&9A;'1A
M('5N82!C;&%V92!01U`@</IB;&EC82!P87)A(&-I9G)A<B!U;B!M96YS86IE
M+@!(86-E(&9A;'1A('5N82!C;&%V92!01U`@</IB;&EC82!P87)A(&-O;7!R
M;V)A<B!U;B!M96YS86IE(&9I<FUA9&\N`$AA8V5N(&9A;'1A('5N82!C;&%V
M92!01U`@</IB;&EC82P@=6YA(&-L879E(%!'4"!P<FEV861A('D@=6YA(&9R
M87-E(&-L879E('!A<F$@9&5S8VEF<F%R('5N(&UE;G-A:F4N`$AA8V5N(&9A
M;'1A('5N82!C;&%V92!01U`@</IB;&EC82P@=6YA(&-L879E(%!'4"!P<FEV
M861A('D@=6YA(&9R87-E(&-L879E('!A<F$@9FER;6%R('5N(&UE;G-A:F4N
M`$AA8V5N(&9A;'1A('5N82!C;&%V92!3+TU)344@</IB;&EC82P@=6YA(&-L
M879E(%,O34E-12!P<FEV861A('D@=6YA(&9R87-E(&-L879E('!A<F$@9&5S
M8VEF<F%R('5N(&UE;G-A:F4N`$AA8V5N(&9A;'1A('5N82!C;&%V92!3+TU)
M344@</IB;&EC82P@=6YA(&-L879E(%,O34E-12!P<FEV861A('D@=6YA(&9R
M87-E(&-L879E('!A<F$@9FER;6%R('5N(&UE;G-A:F4N`$AA8V4@9F%L=&$@
M=6YA(&-L879E(%--24U%('#Z8FQI8V$@<&%R82!C:69R87(@=6X@;65N<V%J
M92X`3G5B97,@;6%T:6YA;&5S`$QI9V5R82!L;'5V:6$@;6%T:6YA;`!,;'5V
M:6$@;6%T:6YA;`!!9W5A8V5R;W,@;6%T:6YA;&5S`$%G=6%C97)O(&UA=&EN
M86P@9&4@;FEE=F4`04TO4$T`240@9&4@05!)`$%C97)C82!D96P@961I=&]R
M`$%C97)C82!D92XN+@!);F9E<FEO<B!!8G,N`$5N(&UE9&EO($%B<RX`4V4@
M:&$@9&5N96=A9&\@96P@86-C97-O(&%L(&-R96%R(&5L(&1I<F5C=&]R:6\@
M5D93+@!392!H82!D96YE9V%D;R!E;"!A8V-E<V\@86P@8W)E87(@96P@87)C
M:&EV;R!61E,N`$ED96YT:61A9`!#;VYT<F%S9?%A(&1E(&%C8V5S;P!)9&5N
M=&ED860@8FQO<75E861A+@!#;VYT86)I;&ED860`0?%A9&ER`$'Q861I<B!G
M<G5P;R!D97-C96YD:65N=&4`0?%A9&ER('!R:79I;&5G:6\@9&5S8V5N9&EE
M;G1E`$'Q861I<B!A<77M.@!!\6%D:7(@9W)U<&\`0?%A9&ER('!R:79I;&5G
M:6\`0?%A9&ER(&$@(B5S(B!U;B!G<G5P;R!D97-C96YD:65N=&4`0?%A9&ER
M(&$@(B5S(B!U;B!P<FEV:6QE9VEO(&1E<V-E;F1I96YT90!!\6%D:7(@=6X@
M=7-U87)I;SH`0?%A9&ER(&-O;'5M;F$`0?%A9&ER(&UI96UB<F]S`$'Q861I
M<B!P87(`0?%A9&ER(&5L(&UE;OH@)7,@8V]M;R!P86YE;"!L871E<F%L(&1E
M($UO>FEL;&$`0?%A9&ER(&$@;&%S(&1I<F5C8VEO;F5S.@!!\6%D:7(@82!L
M87,@9&ER96-C:6]N97,Z`$'Q861I<B!U<W5A<FEO`%-E(&AA(&'Q861I9&\@
M(B5S(B!A;"!S:7-T96UA+"!P97)O(&YO('-E('!U961E(&'Q861I<B!L82!I
M;F9O<FUA8VGS;B!A9&EC:6]N86P@9&4@86QT83H@)7,N`%-E(&AA(&'Q861I
M9&\@(B5S(B!A;"!S:7-T96UA+B!982!P=65D92!I;FEC:6%R(&QA('-E<VGS
M;BX`3&$@861I8VGS;B!D92!U<W5A<FEO<R!E<W3A(&1E<VAA8FEL:71A9&$N
M`$1I<F5C8VGS;@!$:7)E8V-I;VYE<P!!9&UI;FES=')A9&]R("T@9&5F:6YE
M('!R:79I;&5G:6]S(&1E(&]T<F]S('5S=6%R:6]S`$%D;6EN:7-T<F%C:?-N
M`$%N=6YC:6]S`$%F9V%N:7-TX6X`06QB86YI80!!<F=E;&EA`$%L:6%S`$%L
M:6YE87(`06QI;F5A8VGS;CH`5&]D;W,`5&]D;W,@;&]S('5S=6%R:6]S(&%U
M=&5N=&EF:6-A9&]S`%1O9&]S(&QO<R!G<G5P;W,`5&]D;W,@;&]S('!R:79I
M;&5G:6]S`%1O9&]S(&QO<R!L861O<P!097)M:71I<B!V87)I87,@9&ER96-C
M:6]N97,`OU!E<FUI=&ER(&-O;F9I9W5R86-I\VX@9&4@=&EP;R!D92!L:7-T
M87,@;W)D96YA9&%S/P!982!E>&ES=&4`06-C97-O($E-4U`@86QT97)N871I
M=F\`0VQA=F4@24U34"!A;'1E<FYA=&EV80!5<W5A<FEO($E-4%,@86QT97)N
M871I=F\`1&ER96-C:?-N(&5L96-T<O-N:6-A(&%L=&5R;F%T:79A`%!L86YT
M:6QL87,@86QT97)N871I=F%S`%1E>'1O(&%L=&5R;F%T:79O`%-A;6]A($%M
M97)I8V%N80!392!H82!I;F1I8V%D;R!U;B!V86QO<B!I;&5G86PN`%-E(&AA
M('!R;V1U8VED;R!U;B!E<G)O<B!D97-C;VYO8VED;RX`06YD;W)R80!!;F=O
M;&$`06YG=6EL80!0<F]X>2!A;O-N:6UO`%)E<W!U97-T80!!;G3A<G1I9&$`
M06YT:6=U82!Y($)A<F)A9&]S`$%P;&EC86-I\VX`3&ES=&$@9&4@87!L:6-A
M8VEO;F5S`$QA(&%P;&EC86-I\VX@97-TX2!L:7-T82X`07!L:6-A<B!A(')E
M8W5R<V]S(&-O;7!A<G1I9&]S(&1E<V-E;F1I96YT97,`07!R;V)A<@!486UA
M\6\@87!R;WAI;6%D;P!!8G)I;`!!<N%B:6=O("A7:6YD;W=S+3$R-38I`%1A
M;6'Q;R!D96P@87)C:&EV;P!.;VUB<F4@9&5L(&%R8VAI=F\`OT5S=&$@<V5G
M=7)O(&1E('%U92!D97-E82!E;&EM:6YA<B!L82!S;VQI8VET=60@9&4@86QT
M82!D92`E<S\`OT5S=.$@<V5G=7)O(&1E('%U92!D97-E82!E;&EM:6YA<B`B
M)7,B('D@=&]D;W,@<W5S('-U8F=R=7!O<S\`07)G96YT:6YA`$%R;65N:6$`
M07)M96YI;R`H05)-4T-)22TX*0!!<G1E`$%R=6)A`$ES;&$@07-C96YS:?-N
M`$=RX69I8V]S($%S8VEI`%)E9VGS;B!D92!!<VEA+U!A8^UF:6-O`+]3;VQI
M8VET87(@8V]N9FER;6%C:?-N(&%N=&5S(&1E(')E86QI>F%R(&]P97)A8VEO
M;F5S(&1E(&UA;G1E;FEM:65N=&\_`$-O;'5M;F%S(&1E(&%S:6=N86-I\VX`
M26YT96YT82!E;&EM:6YA<B!U;B!G<G5P;R!I;F5X:7-T96YT92X`26YT96YT
M82!E;&EM:6YA<B!U;B!P<FEV:6QE9VEO(&EN97AI<W1E;G1E+@!);G1E;G1A
M(&UO9&EF:6-A<B!U;B!P<FEV:6QE9VEO(&EN97AI<W1E;G1E+@!);G1E;G1A
M(&UO9&EF:6-A<B!U;B!R96-U<G-O(&-O;7!A<G1I9&\@:6YE>&ES=&5N=&4N
M`$%T<FEB=71O<P!!9V]S=&\`075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S
M<6PZ($YO('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!I;6%P(&YE8V5S87)I
M82X`075T:%]C>7)U<SH@16P@;6]T;W(@8V%R96-E(&1E(&QA<R!C87!A8VED
M861E<R!N96-E<V%R:6%S+@!!=71H7V-Y<G5S.B!.;R!S92!E;F-O;G1R\R!L
M82!E>'1E;G-I\VX@:6UA<"!N96-E<V%R:6$N`$%U=&A?9G1P.B!.;R!S92!E
M;F-O;G1R\R!L82!E>'1E;G-I\VX@1E10(&YE8V5S87)I82X@0V]M<&EL92!0
M2%`@8V]N(&QA(&]P8VGS;B`M+65N86)L92UF='`N`$%U=&A?:6UA<#H@3F\@
M<V4@96YC;VYT<O,@;&$@97AT96YS:?-N($E-05`@;F5C97-A<FEA+@!!=71H
M7VMR8C4Z($YO('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!K<F(U(&YE8V5S
M87)I82X`075T:%]L9&%P.B!.;R!E<W3A('-O<&]R=&%D82!L82!A9&EC:?-N
M(&1E('5S=6%R:6]S(&1E($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!.
M;R!E<W3A('-O<&]R=&%D82!L82!E;&EM:6YA8VGS;B!D92!U<W5A<FEO<R!D
M92!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@3F\@<V4@96YC;VYT<O,@
M;&$@97AT96YS:?-N($Q$05`@;F5C97-A<FEA+@!!=71H7VQD87`Z($YO('-E
M('!U961E(&'Q861I<B!E;"!U<W5A<FEO("5S+B#)<W1O(&5S(&QO('%U92!D
M:6IO(&5L('-E<G9I9&]R.B``075T:%]L9&%P.B!);F-A<&%Z(&1E(&5L:6UI
M;F%R(&5L('5S=6%R:6\@)7,`075T:%]L9&%P.B!);F-A<&%Z(&1E(&%C='5A
M;&EZ87(@96P@=7-U87)I;R`E<P!!=71H7VQD87`Z($YO(&5S=.$@<V]P;W)T
M861A(&QA(&%C='5A;&EZ86-I\VX@9&4@=7-U87)I;W,@9&4@06-T:79E($1I
M<F5C=&]R>0!!=71H7VUC86PZ($YO('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS
M;B!-0T%,(&YE8V5S87)I82X`075T:%]S;6)A=71H.B!.;R!S92!E;F-O;G1R
M\R!L82!E>'1E;G-I\VX@<VUB875T:"!N96-E<V%R:6$N`$9A;&SS(&QA(&%U
M=&5N=&EF:6-A8VGS;B!C;VX@96P@<V5R=FED;W(@24U!4"X`1F%L;/,@;&$@
M875T96YT:69I8V%C:?-N`$9A;&SS(&QA(&%U=&5N=&EF:6-A8VGS;BX@)7,`
M16P@<V5R=FED;W(@4D%$2553(&AA(')E8VAA>F%D;R!L82!A=71E;G1I9FEC
M86-I\VXN`$9A;&SS(&QA(&%U=&5N=&EF:6-A8VGS;B!C;VX@96P@<V5R=FED
M;W(@1E10+@!&86QL\R!L82!A=71E;G1I9FEC86-I\VX@8V]N(&5L('-E<G9I
M9&]R(%--0BX`0V%M<&]S(&1I<W!O;FEB;&5S.@!!>F5R8F%I:F%N`$5X8W5S
M87,@0D]&2`!&;VYD;P!#;VQO<B!D92!F;VYD;P!#;VYT<F%S9?%A(&ME<F)E
M<F]S(&EN8V]R<F5C=&$N`$YO;6)R92!D92!U<W5A<FEO(&ME<F)E<F]S(&EN
M8V]R<F5C=&\N`$)A:&%M87,`0F%H<F%I;@!"X6QT:6-O("A)4T\M.#@U.2TQ
M,RD`0F%N9VQA9&5S:`!"87)B861O<P!.;R!S92!E;F-O;G1R\R!E;"!D:7)E
M8W1O<FEO(&)A<V4@9&4@:6WA9V5N97,@(B5S(BX`3.UN96$@8F%S90!"96QA
M<G5S`$+I;&=I8V$`0F5L:7IE`$)E;FEN`$)E<FUU9&%S`$)H=71A;@!#=6UP
M;&5A\6]S`$YO('-E(&5N8V]N='+S(&5L(&)L;W%U92`B)7,B(&1E(&QA(&%P
M;&EC86-I\VX@(B5S(BX`3W!C:6]N97,@9&4@8FQO<75E`%1I<&\@9&4@8FQO
M<75E`$YE9W)I=&$`0F]L:79I80!-87)C861O<F5S`$)O<F1E`$=R;W-O<B!D
M96P@8F]R9&4Z`$)O<F1E<P!";W-N:6$@2&5R>F5G;W9I;F$`06UB;W,`0F]T
M<W=A;F$`26YF97)I;W(`27-L82!D92!";W5V970`0G)A<VEL`%1E<G)I=&]R
M:6\@;V-EX6YI8V\@9&4@;&$@26YD:6$@8G)I=.%N:6-A`$)R=6YE:2!$87)U
M<W-A;&%M`$)U;&=A<FEA`$QI<W1A(&1E<V]R9&5N861A`$)U<FMI;F$@1F%S
M;P!"=7)U;F1I`$--4P!#4D,`4'5N=&]S(&1E(&1I<W1R:6)U8VGS;B!#4D,`
M4')O<&EE9&%D97,@9&4@7V-E;&1A+BXN`$YO('-E(&AA(&9I;F%L:7IA9&\@
M96P@:6YI8VEO(&1E(&QA(&-A8VCI+@!!9V5N9&$`0V%L;6$`0V%M8F]Y80!#
M86UE<OIN`$YO('-E('!U961E*&XI(&-O<&EA<B!E;"]L;W,@87)C:&EV;RAS
M*2`M(&]R:6=E;B!Y(&1E<W1I;F\@<V]N(&5L(&UI<VUO+@!.;R!S92!P=65D
M92AN*2!T<F%S;&%D87(@96PO;&]S(&%R8VAI=F\H<RD@+2!E;"!D97-T:6YO
M(&5S=.$@9&5N=')O(&1E;"!O<FEG96XN`$YO('-E('!U961E(')E86IU<W1A
M<B!L82!C;&%V92!A=71O;>%T:6-A;65N=&4L('#S;F=A<V4@96X@8V]N=&%C
M=&\@8V]N(&5L(&%D;6EN:7-T<F%D;W(@9&5L('-I<W1E;6$N`$YO('-E('!U
M961E(&5S8W)I8FER(&5N(&5L(&%R8VAI=F\@(B5S(@!.;R!S92!P=65D96X@
M861M:6YI<W1R87(@;6%N96IA9&]R97,@9&4@<V5S:?-N(&5X=&5R;F]S+@!.
M;R!S92!P=65D92!C;VYE8W1A<B!A;"!S97)V:61O<B!)34%0.B`E<P!.;R!S
M92!P=65D92!A8G)I<B!E;"!A<F-H:79O("(E<R(N`$-A;F%DX0!#86YC96QA
M<@!#86YC96QA<B!I;F9O<FUE(&1E('!R;V)L96UA<P!.;R!S92!P=65D92!E
M;&EM:6YA<B!E;"!A<F-H:79O("(E<R(N`$YO('-E(&5N8W5E;G1R82!U;B!D
M:7)E8W1O<FEO('1E;7!O<F%L+@!.;R!S92!P=65D92!C;VYT:6YU87(@<VEN
M(&5L('!A<N%M971R;R`G=&%R9V5T1FEL92<N`$YO('-E('!U961E(&5L:6UI
M;F%R(&5L(&1I<F5C=&]R:6\@(B5S(BX`3F\@<V4@<'5E9&4@96QI;6EN87(L
M('1I96YE("5D(&1E<V-E;F1I96YT97,N`$YO('-E('!U961E(')E;W)D96YA
M<BP@96P@;OIM97)O(&1E(&5N=')A9&%S('%U92!S92!D97-E82!O<F1E;F%R
M(&YO(&-O:6YC:61E(&-O;B!L87,@86QM86-E;F%D87,N`$YO('-E('!U961E
M(&1I<FEG:7(@96P@;65N<V%J92!A;"!N^FUE<F\@97-P96-I9FEC861O+@!#
M86)O(%9E<F1E`%-U8G3M='5L;P!0<F]V965D;W(`0V%T96=O<NUA<R!Y(&5T
M:7%U971A<P!)<VQA<R!#86EMX6X`5&5LZ69O;F\@;?-V:6P`4')O<&EE9&%D
M97,@9&4@8V5L9&$`36%R9V5N(&1E(&-E;&1A.@!0<F]P:65D861E<R!D92!C
M96QD80!%<W!A8VEA9&\@9&4@8V5L9&$Z`%1E;.EF;VYO(&WS=FEL`$/I;'1I
M8V\@*$E33RTX.#4Y+3$T*0!#96YT<F%R`%)E</IB;&EC82!#96YT<F]A9G)I
M8V%N80!%=7)O<&$@0V5N=')A;"`H25-/+3@X-3DM,BD`1&5T86QL97,@9&5L
M(&-E<G1I9FEC861O`%!R;W!I971A<FEO(&1E;"!C97)T:69I8V%D;P!0;VSM
M=&EC87,@9&5L(&-E<G1I9FEC861O`$-H860`0V%M8FEA<@!#86UB:64@;&$@
M8V]N=')A<V7Q80!#86UB:6$@96P@;F]M8G)E('D@;&$@9&ER96-C:?-N(&5L
M96-T<O-N:6-A('9I<VEB;&5S(&%L(&QE97(@;R!R97-P;VYD97(@82!S=7,@
M;65N<V%J97,N`$QA(&-O;F9I9W5R86-I\VX@86-T=6%L(&YO('-O<&]R=&$@
M96P@8V%M8FEO(&1E(&-O;G1R87-E\6%S+B!0\VYG87-E(&5N(&-O;G1A8W1O
M(&-O;B!E;"!A9&UI;FES=')A9&]R(&1E;"!S:7-T96UA+@!'<N%F:6-O`%9E
M<FEF:6-A<B!?=NUN8W5L;RXN+@!#:&EL90!#:&EN80!#:&EN;R!S:6UP;&EF
M:6-A9&\@*$=",C,Q,BD`0VAI;F\@=')A9&EC:6]N86P@*$)I9S4I`$%P;&EC
M86-I\VXZ`$5L:6IA('5N82!C;VYT<F%S9?%A`$5L:6IA('5N(&YO;6)R92!D
M92!U<W5A<FEO`$5L:6IA(&/S;6\@;6]S=')A<B!L87,@9F5C:&%S.@!396QE
M8V-I;VYA<B!T:7!O(&1E(&5S=&EL;R!D92!L:7-T82`H<&%R82!L:7-T87,@
M;W)D96YA9&%S*0!)<VQA(&1E(%!A<V-U80!.;R!S92!E;F-O;G1R\R!L82!D
M969I;FEC:?-N(&1E(&-L87-E(&1E("5S+@!,:6UP:6%R`$5L:6UI;F%R(&5T
M:7%U971A<R!-4T]F9FEC90!";W)R87(@8V]N<W5L=&$`0F]R<F%R('5S=6%R
M:6\Z("5S`$)O<G)A<B!U<W5A<FEO`$)O<G)A<B!D871O<R!D96P@=7-U87)I
M;P!$97-P96IA9&\@=&%R9.UO`$AA9V$@8VQI8VL@<&%R82!S96=U:7(`0VQI
M8VMA=&5L;"!P;W(@2%144`!#97)R87(@=F5N=&%N80!.=6)E<P!.=6)E<R!T
M96UP<F%N87,`;G5B;W-O`$ES;&%S(&1E(&-O8V]S("A+965L:6YG*0!/8W5L
M=&%R(&)A<G)A(&QA=&5R86P`0V]L87!S87(@8F]R9&5S`$-O;&]M8FEA`$-O
M;&]R`%-E;&5C=&]R(&1E(&-O;&]R`%-E;&5C8VGS;B!D92!C;VQO<@!#;VQU
M;6YA<SH`5.UT=6QO<R!D92!L87,@8V]L=6UN87,`0_-M:6-S`$-O;6%N9&\`
M26YTZ7)P<BX@8V]M86YD;W,`0V]M96YT87)I;P!.;VUB<F4@8V]M^FX`0V]M
M;W)O<P!#;VUP8?'M80!/<F1E;F%D;W)E<P!#;VYD:6-I\VX`0V]N9&EC:6]N
M97,`1&EF97)E;F-I87,@9&4@;&$@8V]N9FEG=7)A8VGS;@!#;VYF:6=U<F%C
M:?-N('!A<F$@<VEN8W)O;FEZ86-I\VX@8V]N(%!$07,L($WS=FEL97,@8V]N
M(&%G96YD82!Y($]U=&QO;VLN`$QA(&-O;F9I9W5R86-I\VX@97-TX2!D97-A
M8W1U86QI>F%D82X`0V]N9FEG=7)A<B`E<P!#;VYF:7)M87(@8V]N=')A<V7Q
M80!#;VYG;P!#;VYG;RP@4F5P^F)L:6-A($1E;6]C<N%T:6-A(&1E;`!&86QL
M\R!L82!C;VYE>&GS;BX`1F%L;/,@;&$@8V]N97AI\VXZ(`!392!H82!R96-H
M87IA9&\@;&$@8V]N97AI\VX@86P@<V5R=FED;W(@9&4@8VQA=F5S('#Z8FQI
M8V\N`%-E(&AA(')E8VAA>F%D;R!L82!C;VYE>&GS;B!A;"!S97)V:61O<B!D
M92!C;&%V97,@</IB;&EC;RX@36]T:79O.B`E<R`H)7,I`$AA(&9A;&QA9&\@
M;&$@8V]N97AI\VX@86P@<V5R=FED;W(@1E10+@!#;VYT86-T;W,`4V4@:&%N
M(&'Q861I9&\@8V]R<F5C=&%M96YT92!L;W,@8V]N=&%C=&]S(&$@<W5S(&1I
M<F5C8VEO;F5S`%1I<&\@9&4@8V]N=&5N:61O(&1E;"!A<F-H:79O(&-O;7!R
M:6UI9&\Z(`!#;VYT96YI9&\@9&4@(B5S(@!#;VYT:6YU87(`27-L87,@0V]O
M:P!#;V]K:64`0V]P:6%R`$9A;&SS(&QA(&-O<&EA.B`E<P!#;W!I87(@<V5L
M96-C:?-N`$E$(&1E(&-O<W1E`$-O<W1A(%)I8V$`0V]S=&$@9&4@36%R9FEL
M`$YO('-E('!U961E(&-I9G)A<B!E;"!M96YS86IE(&UE9&EA;G1E(%!'4#H@
M`$YO('-E('!U961E(&9I<FUA<B!E;"!M96YS86IE(&UE9&EA;G1E(%!'4#H@
M`$YO('-E('!U961E(&-I9G)A<B!E;"!M96YS86IE(&UE9&EA;G1E(%,O34E-
M10!.;R!S92!P=65D92!F:7)M87(@96P@;65N<V%J92!M961I86YT92`@4R]-
M24U%`$YO('-E('!U961E(&'Q861I<B!E;"!C;VYT86-T;RX@)7,`3F\@<V4@
M<'5E9&4@96YL87IA<B!A;"!S97)V:61O<B!,1$%0+@!.;R!S92!P=65D92!C
M;VUP<F]B87(@96P@<V%L9&\N("5S`$YO('-E('!U961E(&-O;F5C=&%R(&%L
M('-E<G9I9&]R($Q$05`N`$YO('-E('!U961E(&-O;F5C=&%R(&%L('-E<G9I
M9&]R("(E<R(@;65D:6%N=&4@1E10.B`E<P!.;R!S92!P=65D92!C<F5A<B!L
M82!L:7-T82!D92!D:7-T<FEB=6-I\VXN("5S`$YO('-E('!U961E;B!D97-C
M:69R87(@;&]S(&1A=&]S(%!'4#H@`$YO('-E('!U961E;B!D97-C:69R87(@
M;&]S(&1A=&]S(%,O34E-12X`3F\@<V4@<'5E9&4@96QI;6EN87(@96P@8V]N
M=&%C=&\N("5S`$YO('-E('!U961E(&5L:6UI;F%R(&QA(&QI<W1A(&1E(&1I
M<W1R:6)U8VGS;BX@)7,`3F\@<V4@<'5E9&4@96QI;6EN87(@96P@9W5I\VX@
M9&4@86-T=6%L:7IA8VGS;B!D92!C;VYF:6=U<F%C:?-N("(E<R(N`$YO('-E
M('!U961E(&1E=&5R;6EN87)A(&QA(&1I<F5C8VGS;B!D92!C;W)R96\@9&5L
M(&1E<W1I;F%T87)I;RX`3F\@<V4@<'5E9&4@=')A97(@;&$@;&EB<F5T82!D
M92!D:7)E8V-I;VYE<R!C;VUP;&5T82X`3F\@<V4@<'5E9&4@=')A97(@;&$@
M;&ES=&$@9&4@9&ES=')I8G5C:?-N(&-O;7!L971A+@!.;R!S92!P=65D92!T
M<F%E<B!L82!L:7-T82!C;VUP;&5T82!D92!L:7-T87,@9&4@9&ES=')I8G5C
M:?-N+@!.;R!S92!P=65D92!C87)G87(@;&$@97-T<F%T96=I82`B)7,B+@!.
M;R!S92!P=65D92!C<F5A<B!E;"!D:7)E8W1O<FEO("(E<R(N`$YO('-E('!U
M961E(&]B=&5N97(@;&$@8VQA=F4@</IB;&EC82!D96P@<V5R=FED;W(@9&4@
M8VQA=F5S+@!.;R!S92!P=65D92!A8G)I<B`B)7,B('!A<F$@97-C<FEB:7(N
M`$YO('-E('!U961E(&%B<FER("5S+@!.;R!S92!P=65D92!A8G)I<B!E;"!M
M\V1U;&\@9&4@=&%R96%S(&1E(&UA;G1E;FEM:65N=&\@)7,`3F\@<V4@<'5E
M9&4@86)R:7(@96P@9&ER96-T;W)I;R`B)7,B+@!.;R!S92!P=65D92!L;V-A
M;&EZ87(@96P@<V5R=FED;W(@3$1!4"X`3F\@<V4@<'5E9&4@;&5E<B`E<RX`
M3F\@<V4@<'5E9&4@<F5S=&%B;&5C97(@;&$@8V]N=')A<V7Q82!D96P@=7-U
M87)I;R!S;VQI8VET861O+B!087)T92!D92!L;W,@9&5T86QL97,@;R!T;V1O
M<RP@<V]N(&EN8V]R<F5C=&]S+B!0<G5E8F4@;W1R82!V97H@;R!P\VYG87-E
M(&5N(&-O;G1A8W1O(&-O;B!E;"!A9&UI;FES=')A9&]R(&1E;"!S:7-T96UA
M('!A<F$@;>%S(&EN9F]R;6%C:?-N+@!.;R!S92!P=65D92!O8G1E;F5R(&QA
M($%#3"X`3F\@<V4@<'5E9&4@;V)T96YE<B!L82!L:6)R971A(&1E(&1I<F5C
M8VEO;F5S+B`E<P!.;R!S92!P=65D92!O8G1E;F5R(&QA(&QI<W1A(&1E(&1I
M<W1R:6)U8VGS;BX@)7,`3F\@<V4@<'5E9&5N(&]B=&5N97(@;&%S(&QI<W1A
M<R!D92!D:7-T<FEB=6-I\VXN("5S`$YO('-E('!U961E;B!O8G1E;F5R(&QA
M<R!C87!A8VED861E<R!D96P@<V5R=FED;W(`3F\@<V4@<'5E9&4@<F5S=&%U
M<F%R(&QA(&-O;F9I9W5R86-I\VXN`$YO('-E('!U961E(&5L:6UI;F%R(&5L
M(&1I<F5C=&]R:6\@(B5S(BX`3F\@<V4@<'5E9&4@9W5A<F1A<B!L82!C;VYF
M:6=U<F%C:?-N(&1E("5S+@!.;R!S92!P=65D92!G=6%R9&%R('5N82!C;W!I
M82!D92!L82!C;VYF:6=U<F%C:?-N+@!.;R!S92!P=65D92!G=6%R9&%R('5N
M82!C;W!I82!D92!L82!C;VYF:6=U<F%C:?-N.B`E<P!.;R!S92!P=65D92!G
M=6%R9&%R(&5L(&=U:?-N(&1E(&%C='5A;&EZ86-I\VX@9&4@;&$@8V]N9FEG
M=7)A8VGS;B!E;CH@(B5S(BX`3F\@<V4@<'5E9&4@9W5A<F1A<B!L82!C;W!I
M82`E<R!D92!L82!C;VYF:6=U<F%C:?-N+@!.;R!S92!P=65D92!G=6%R9&%R
M(&5L(&%R8VAI=F\@)7,@9&4@8V]N9FEG=7)A8VGS;BX@4'5E9&4@=71I;&EZ
M87(@=6YA(&1E(&QA<R!O<&-I;VYE<R!P87)A(')E<W1A=7)A<B!E;"!C\V1I
M9V\@9&4@)7,@;R!C;W!I87(@;6%N=6%L;65N=&4@82`E<R!E;"!C\V1I9V\@
M<VEG=6EE;G1E+@!.;R!S92!P=65D92!B=7-C87(@96X@96P@<V5R=FED;W(@
M3$1!4"X`3F\@<V4@<'5E9&4@9&5S=FEN8W5L87(@(B5S(BX`3F\@<V4@<'5E
M9&4@86-T=6%L:7IA<B!E;"!C;VYT86-T;RX@)7,`3F\@<V4@<'5E9&4@86-T
M=6%L:7IA<B!L82!L:7-T82!D92!D:7-T<FEB=6-I\VXN("5S`$YO('-E('!U
M961E(&5S8W)I8FER(&QA(&-O;F9I9W5R86-I\VX@9&4@(B5S(CH@)7,`3F\@
M<V4@<'5E9&4@;&]C86QI>F%R(&5L('!A;F5L(&QA=&5R86P@9&4@36]Z:6QL
M82X@0V]M<')U96)E('%U92!E<W3I(&%B:65R=&\N`$YO('-E('!U961E;B!O
M=&]R9V%R(&%L('5S=6%R:6\@(B5S(B!L;W,@<VEG=6EE;G1E<R!D97)E8VAO
M<R!P87)A(&QA(&-A<G!E=&$@(B5S(CH@)7,`5&5X=&\@8V]N=&%D;P!08>US
M`$-U<G-O<P!#<F5A<@!#<F5A('5N(';M;F-U;&\`0W)E87(`0W)E87(@<W5B
M8V%R<&5T87,`4')I=FEL96=I;W,@9&4@8W)E861O<@!.^FUE<F\@9&4@=&%R
M:F5T82!D92!C<NED:71O`$-R;V%C:6$`0W5B80`T($9A<V5S(&%C='5A;&5S
M`%-E<VEO;F5S(&%C='5A;&5S`$AO<F$@86-T=6%L`%523"!A8W1U86P`57-U
M87)I;W,@86-T=6%L97,`5&EE;7!O(&%C='5A;`!#;VYD:6-I\VX@86-T=6%L
M.B``17-T:6QO(&%C='5A;`!097)S;VYA;&EZ82!L87,@=&%R96%S(&$@96IE
M8W5T87(@86P@:6YI8VEA<B!S97-I\VX@96X@)7,N`$-O<G1A<@!#;W)T87(@
M<V5L96-C:?-N`$-H:7!R90!#:7+M;&EC;R`H2T])."U2*0!#:7+M;&EC;R`H
M5VEN9&]W<RTQ,C4Q*0!#:7+M;&EC;R]58W)A;FEA;F\@*$M/23@M52D`4F5P
M^F)L:6-A($-H96-A`$1$`$133B`H=F5A(&AT='`Z+R]P96%R+G!H<"YN970O
M;6%N=6%L+V5S+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"D`
M1&EA<FEA;65N=&4`P7)?8F]L(&1A=&]S`$-O;G-U;'1A(&1E(&QA(&)A<V4@
M9&4@9&%T;W,`1F5C:&$`4V4@:&$@<F5C:6)I9&\@;&$@9F5C:&$`4V5L96-C
M:?-N(&1E(&9E8VAA`$3M80!%7VQI;6EN87(@8V]L=6UN80!$:6-I96UB<F4`
M3OIM97)O<R!D96-I;6%L97,`4F5D=6-I<B!S86YG<F%D;P!0;W(@;VUI<VGS
M;@!#;VQO<B!P;W(@;VUI<VGS;@!)9&5N=&ED860@<&]R(&]M:7-I\VX`4VAE
M;&P@<&]R(&]M:7-I\VX`1&5F:6YI8VEO;F5S`"9N8G-P.T5L:6UI;F%R)FYB
M<W`[`$5L:6UI;F%R(&-E;&1A`$5L:6UI;F%R(&=R=7!O`$5L:6UI;F%R(')E
M9VES=')O`$5L:6UI;F%R('!R:79I;&5G:6\`16QI;6EN87(@>2!V86-I87(@
M;65N<V%J97,`16QI;6EN87(@8V5L9&$`16QI;6EN87(@8V]L=6UN80!%;&EM
M:6YA<B!P;&%N=&EL;&%S(&%L=&5R;F%T:79A<R!E>&ES=&5N=&5S`$5L:6UI
M;F%R(&UE;G-A:F5S`$5L:6UI;F%R('!R:79I;&5G:6]S(&1E("(E<R(`OT5L
M:6UI;F%R('!R:79I;&5G:6]S('!A<F$@(B5S(B!Y(&-U86QQ=6EE<B!P<FEV
M:6QE9VEO(&1E<V-E;F1I96YT93\`16QI;6EN87(@9FEL80!%;&EM:6YA<B!I
M9&5N=&ED860@<V5L96-C:6]N861A`$5L:6UI;F%R('-U8F-A<G!E=&%S`$5L
M:6UI;F$@;&$@8V]L=6UN82!A8W1U86P`16QI;6EN82!L82!F:6QA(&%C='5A
M;`!392!H82!E;&EM:6YA9&\@96P@9W5I\VX@9&4@86-T=6%L:7IA8VGS;B!D
M92!L82!C;VYF:6=U<F%C:?-N("(E<R(N`$AO<F$@9&4@96YT<F5G83H`1&EN
M86UA<F-A`$1E<V-R:6)A(&5L('!R;V)L96UA`$1E<V-R:7!C:?-N`$1E=&%L
M;&5S("AT86UB:>EN(&5N(&5L(&%R8VAI=F\@9&4@<F5G:7-T<F\@9&4@2&]R
M9&4I.@!392!H86X@<F5G:7-T<F%D;R!L;W,@9&5T86QL97,@<&%R82!E;"!A
M9&UI;FES=')A9&]R+@!$97-A<G)O;&QO`%!U;G1O(&1E(&-O;F1E;G-A8VGS
M;@!0=6YT;R!D92!C;VYD96YS86-I\VX@9&4@;&$@^FQT:6UA(&AO<F$Z(`!0
M=6YT;R!D92!C;VYD96YS86-I\VXZ(`!$92!I>G%U:65R9&$@82!D97)E8VAA
M`$1E(&1E<F5C:&$@82!I>G%U:65R9&$`1&ER96-T;W)I;P"_36]S=')A<B!E
M;B!F;W)M871O(&1E(#(T+6AO<F%S/P!/<&-I;VYE<R!D92!6:7-U86QI>F%C
M:?-N`$UO<W1R87(@<')O;O-S=&EC;R!D971A;&QA9&\`36]S=')A<B!P<F]N
M\W-T:6-O("A4048I`$9O<FUA=&\@9&4@=FES=7IA;&EZ86-I\VX`3F]T:69I
M8V%C:?-N(&1E(&-O;G-U;'1A`$1J:6)O=71I`$YO(&5L:6UI;F%R`$YO(&%C
M8V5D97(@9&ER96-T86UE;G1E(&$@;6%I;G1E;F%N8V4N<&AP`+]#;VYT:65N
M92!L82!P<FEM97)A(&9I;&$@;&]S(&YO;6)R97,@9&4@;&]S(&-A;7!O<S\@
M4VD@97,@87/M+"!S96QE8V-I;VYE(&5S=&$@8V%S:6QL83H`1&]M:6YI8V$`
M4F5P^F)L:6-A($1O;6EN:6-A;F$`OTYO(&1I<W!O;F4@9&4@8W5E;G1A/R!3
M;VQI8^UT96QA+@!$97-C87)G87(`1&5S8V%R9V%R("5S`$1E<V-A<F=A<B!L
M82!C;VYF:6=U<F%C:?-N(&=E;F5R861A(&-O;6\@=6X@9W5I\VX@4$A0+@!,
M:7-T82!D97-P;&5G86)L90!$<F]G87,`0V]R<F5O`$-O;G1R;VQA9&]R(&1E
M('!A<V%R96QA($-O<G)E;RUA+5--4R!P87)A('!R;W9E961O<F5S('%U92!P
M<F]P;W)C:6]N96X@97-T92!S97)V:6-I;RX`15)2`$5C=6%D;W(`)FYB<W`[
M36]D:69I8V%R)FYB<W`[`$UO9&EF:6-A<B!B;&]Q=64`36]D:69I8V%R(&=R
M=7!O`$UO9&EF:6-A<B!P<FEV:6QE9VEO`$UO9&EF:6-A<B!P<FEV:6QE9VEO
M<P!-;V1I9FEC87(@<')I=FEL96=I;W,@9&4@)7,`36]D:69I8V%R(&]P8VEO
M;F5S(&1E.@!-;V1I9FEC87(@<')I=FEL96=I;W,@9&4@(B5S(@!-;V1I9FEC
M87(@<')I=FEL96=I;W,@9&4@)7,`161U8V%C:?-N`$5G:7!T;P!%;"!386QV
M861O<@!%;&5M96YT;RXN+@!%;0!#;W)R96\`1&ER96-C:?-N(&1E(&-O<G)E
M;P!,87,@9&ER96-C:6]N97,@9&4@8V]R<F5O('1I96YE;B!Q=64@8V]I;F-I
M9&ER+@!#;W)R96\@8V]N(&-O;F9I<FUA8VGS;@!087-A<F5L82!#;W)R96\M
M82U335,`16UO=&EC;VYE<P!-96YS86IE(&5N(&)L86YC;P!297-U;'1A9&\@
M96X@8FQA;F-O+@!,:6UP:6%R('3I<FUI;F]S(&1E(&+Z<W%U961A`+]097)M
M:71I<B!I;G-E<F-I\VX@9&4@:6WA9V5N97,@9&4@;&%S($=A;&5R[6%S(&1E
M(&9O=&]S/P"_4&5R;6ET:7(@;65N^B!D92!C;VYT97AT;R!D96P@8F]T\VX@
M9&5R96-H;R!D96P@<F%T\VX_`$'Q;R!D92!T97)M:6YA8VGS;@!!9W)A;F1A
M<B!E9&ET;W(`26YT<F]D=7IC82!U;F$@<')E9W5N=&$@9&4@<V5G=7)I9&%D
M('%U92!S92!L92!F;W)M=6QA<N$@<VD@<')E8VES82!R96%J=7-T87(@;&$@
M8V]N=')A<V7Q82P@<"YE+B`GOT-UX6P@97,@96P@;F]M8G)E(&1E('-U(&UA
M<V-O=&$_)SH`26YT<F]D=7IC82!A<77M(&QA(%523"!D92!L82!I;6%G96X`
M26YT<F]D=7IC82!L87,@;&5T<F%S(&1E(&1E8F%J;SH`1W5I;F5A($5C=6%T
M;W)I86P`17)I=')E80!%<G)O<@!%<G)O<B!A;"!C<F5A<B!E;"!B;&]Q=64Z
M("5S`$5R<F]R(&%L(&5L:6UI;F%R(&%N8VQA(&1E('-I;F-R;VYI>F%C:?-N
M.B`E<P!%<G)O<B!A;"!E;&EM:6YA<B!E;"!R96=I<W1R;R!D92!S:6YC<F]N
M:7IA8VGS;CH@)7,`17)R;W(@86P@;V)T96YE<B!C;VYT96YI9&]S.B`E<P!%
M<G)O<B!A;"!A8W1U86QI>F%R(&QA(&-O;G1R87-E\6$Z("5S`$5R<F]R(&-O
M;B!E;"!M96YS86IE(&1E(&-O<G)E;RX`17)R;W(@86P@97-C<FEB:7(@(B5S
M(BX`17-T;VYI80!%=&EO<.UA`,ET;FEC;P!%=7)O<&$`0V%D82`Q-2!M:6YU
M=&]S`$-A9&$@,B!M:6YU=&]S`$-A9&$@,S`@<V5G=6YD;W,`0V%D82`U(&UI
M;G5T;W,`0V%D82!I;FEC:6\@9&4@<V5S:?-N`$-A9&$@;65D:6$@:&]R80!#
M861A(&UI;G5T;P!686QO<F5S(&1E(&5J96UP;&\Z`$5J96-U=&%R`$5X<&%N
M9&ER`$UO<W1R87(@8F%R<F$@;&%T97)A;`!S92!E<W!E<F%B82`G*2<`4V4@
M97-P97)A8F$@=6YA(/IN:6-A('!A;&%B<F$@;R!U;B!TZ7)M:6YO(&1E(&+Z
M<W%U961A(&5N=')E8V]M:6QL861O`$9E8VAA(&1E('9E;F-I;6EE;G1O`$5X
M<&]N96YT90!#;VQO<B!D92!L971R80!#87)G87(@;&$@8V]N9FEG=7)A8VGS
M;B!P;W(@1E10`$9A;&QO(&%L('1R865R(&QA<R!P<F5F97)E;F-I87,N`$EN
M8V%P87H@9&4@8V]N96-T87)S92!A;"!S97)V:61O<B!,1$%0+@!);F-A<&%Z
M(&1E(&-O;F5C=&%R<V4@86P@<V5R=FED;W(@4TU"+@!&86QL;R!A;"!C;W!I
M87(@9&4@(B5S(BX`1F%L;&\@86P@8V]P:6%R(&$@(B5S(BX`1F%L;&\@86P@
M8W)E87(@=6YA(&-O;F5X:?-N(%-!4TP`1F%L;&\@86P@=')A<VQA9&%R("(E
M<R(N`$9A;&QO(&%L(')E8W5P97)A<CH@)7,`1&5S<&5J861O`$ES;&%S($UA
M;'9I;F%S("A&86QK;&%N9"D`27-L87,@1F%R;V4`17)R;W(@:7)R96-U<&5R
M86)L93H`1F%X`$9A>&5S`$9E8G)E<F\`4V4@<VEE;G1E(&-O;6\`4V4@<VEE
M;G1E(&-O;6\Z(`!0;V-A<R!L;'5V:6%S`$5S8V%S;R!A9W5A8V5R;R!D92!N
M:65V90!-871R:7H@9&4@8V%M<&]S`$-!4%1#2$$@9&4@1FEG;&5T`$QE=')A
M(&1E($9I9VQE=`!&:6II`$%R8VAI=F\`3KH@9&4@87)C:&EV;W,Z("5S(&%R
M8VAI=F\`3KH@9&4@87)C:&EV;W,Z("5S(&%R8VAI=F]S`$%R8VAI=F]S`$YO
M;6)R92!D92!A<F-H:79O`%-E;&5C8VGS;B!D92!A<F-H:79O`$-A<F=A<B!A
M<F-H:79O`$QA(&-A<F=A(&1E(&%R8VAI=F]S(&YO(&5S=.$@<V]P;W)T861A
M+@!&:6QT<F]S`$9I;FQA;F1I80!#=6%R=&\@8W)E8VEE;G1E`$-U87)T;R!C
M<F5C:65N=&4`4F%Z\VX@9FEJ80!6;VQT96%R`$1I<W!O<VEC:?-N`$YI96)L
M80!,82!C87)P971A("5S(&YO(&5X:7-T92X`0V]L;W(@9&4@;&5T<F$`0V]M
M:61A`%!A<F$@;F%V96=A9&]R97,@<75E(&YO(&%D;6ET86X@:6WA9V5N97,`
M4')O;O-S=&EC;R`H5$%&*0!$[6%S(&1E;"!P<F]N\W-T:6-O("AT96YG82!E
M;B!C=65N=&$@<75E(&5L('!R;V[S<W1I8V\@9F%C:6QI=&%D;R!I;F-L=7EE
M('1A;G1O(&5L(&3M82!C;VUO(&QA(&YO8VAE.R!U;B!N^FUE<F\@9W)A;F1E
M('-E('1R861U8VERX2!E;B!U;B!B;&]Q=64@;75Y(&%N8VAO*0"_2&$@;VQV
M:61A9&\@;&$@8V]N=')A<V7Q83\`1F]R;75L87)I;W,`1F]R='5N80!4:7!O
M(&1E(&9O<G1U;F$`1F]R='5N87,`1F]R='5N87,@,@!&;W)O<P!2965N=NUO
M<P!6:64`1G)A;65S`$9R86YC:6$`1G)A;F-I82P@365T<F]P;VQI=&%N80!'
M=6%Y86YA(&9R86YC97-A`%!O;&EN97-I82!F<F%N8V5S80!497)R:71O<FEO
M<R!F<F%N8V5S97,@9&5L('-U<@!$90!$96P@`$1E<V-R:7!C:?-N(&-O;7!L
M971A`$QU;F$@;&QE;F$`3F]M8G)E(&-O;7!L971O`$=A8O-N`$=A;&5R[6$@
M9&4@;&$@<75E(&]B=&5N97(@;&$@:6UA9V5N`$=A;&5R[6$Z`$=A;6)I80!'
M96YE<F%R(&-O;F9I9W5R86-I\VX@9&4@)7,`0_-D:6=O(&=E;F5R861O`$=E
M;W)G:6$`06QE;6%N:6$`1VAA;F$`1VEB<F%L=&%R`$YO;6)R92!I;F1I8V%D
M;P!/<&-I;VYE<R!G;&]B86QE<P!)<@!';V5D96P`36%P87,@9&4@1V]O9VQE
M`$+Z<W%U961A(&5N($=O;V=L90!%<V-A;&$@9&4@9W)I<V5S`$=R96-I80!'
M<FEE9V\@*$E33RTX.#4Y+3<I`$=R;V5N;&%N9&EA`$=R86YA9&$`061M:6YI
M<W1R86-I\VX@9&4@9W)U<&]S`$QO<R!N;VUB<F5S(&1E(&=R=7!O(&YO('!U
M961E;B!D96IA<G-E(&5N(&)L86YC;P!'<F]U<%]L9&%P.B!.;R!S92!P=65D
M92!A\6%D:7(@96P@9W)U<&\@)7,N(,ES=&\@97,@;&\@<75E(&1I:F\@96P@
M<V5R=FED;W(Z(`!'<F]U<%]L9&%P.B!);F-A<&%Z(&1E(&5L:6UI;F%R(&5L
M(&=R=7!O("5S`$=R;W5P7VQD87`Z($EN8V%P87H@9&4@86-T=6%L:7IA<B!E
M;"!G<G5P;R`E<P!'<G5P;W,`1W5A9&%L=7!E`$=U86T`1W5A=&5M86QA`$=U
M97)N97-E>0!0<FEV:6QE9VEO<R!D92!I;G9I=&%D;P!,+B!I;G9I=&%D;W,`
M1W5I;F5A`$=U:6YE82U":7-S874`1W5A>6%N80!(5$U,`$A434P@<V4@;FEE
M9V$@8V]B87)D96UE;G1E(&$@96QI;6EN87(@;&$@^FQT:6UA(&-E;&1A(&1E
M(&QA(&9I;&$N`$A434Q!<F5A('-E(&YI96=A(&-O8F%R9&5M96YT92!A(&5L
M:6UI;F%R(&QA(/IL=&EM82!C;VQU;6YA(&1E(&QA('1A8FQA+@!(5$U,('-E
M(&YI96=A(&-O8F%R9&5M96YT92!A(&5L:6UI;F%R(&QA(/IL=&EM82!F:6QA
M(&1E(&QA('1A8FQA+@!.;R!S92!E;F-O;G1R\R!L82!A=71E;G1I9FEC86-I
M\VX@2%144"X`2&%I=.T`06QG;W)I;6\@2&%S:`!.96)L:6YA`$-A8F5C97)A
M`$-A8F5C97)A<P!)<VQA($AE87)D(&4@27-L87,@36-$;VYA;&0`5&]R;65N
M=&$@=')O<&EC86P@:6YT96YS80!(96)R96\@*$E33RTX.#4Y+3@M22D`06QT
M=7)A`$%Y=61A`$%Y=61A(&1E;"!E9&ET;W(`07EU9&%N=&4`2&5M:7-F97)I
M;P!!<77M('1I96YE(&5L(&-O;6EE;GIO(&1E;"!A<F-H:79O.@!!;'1A`%])
M;FEC:6\`4V%N=&$@4V5D92`H0VEU9&%D+45S=&%D;R!D96P@5F%T:6-A;F\I
M`$EN:6-I;P!$;VUI8VEL:6\`1&ER96-T;W)I;R!P97)S;VYA;`!496SI9F]N
M;R!P87)T:6-U;&%R`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+
M;VQA8CH@4V4@:&%N(&5N8V]N=')A9&\@9&%T;W,@6$U,("5S(&YO(';A;&ED
M;W,@96X@96P@;65N<V%J92`E<P!(;W)D92]+;VQA8CH@3FEN9_IN(&UE;G-A
M:F4@8V]R<F5S<&]N9&4@86P@;V)J971O("5S`$AO<F1E+TMO;&%B.B!.;R!S
M92!E;F-O;G1R\R!U;B!O8FIE=&\@9&4@=&EP;R`E<R!E;B!E;"!M96YS86IE
M("5S`$AO<F1E+TMO;&%B.B!392!H82!E;&EM:6YA9&\@8V]R<F5C=&%M96YT
M92`E<R`B)7,B`$AO<F1E+TMO;&%B.B!%;"!M;W1O<B!D92!I;G1E9W)A8VGS
M;B!P<F5C:7-A(&1E(&QA(&5X=&5N<VGS;B!02%`@)V1O;7AM;"<`2&]R9&4O
M2V]L86(Z($EN8V%P87H@9&4@8W)E87(@;G5E=F\@X7)B;VP@6$U,(&1E;"!O
M8FIE=&\@)7,`2&]R9&4O2V]L86(Z($EN8V%P87H@9&4@96QI;6EN87(@)7,@
M(B5S(CH@)7,`2&]R9&4O2V]L86(Z($EN8V%P87H@9&4@;V)T96YE<B!)1"!-
M24U%(&1E(&QA('!A<G1E(&1E('1I<&\@)7,`2&]R9&4O2V]L86(Z($EN8V%P
M87H@9&4@<VEN8W)O;FEZ87(@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z($EN
M8V%P87H@9&4@<VEN8W)O;FEZ87(@96QE;65N=&]S(&-O;7!A<G1I9&]S.B`E
M<P!(;W)D92]+;VQA8CH@16QE;65N=&\@8V]M<&%R=&ED;R!D97-C;VYO8VED
M;R`B)7,B`$SM;F5A(&AO<FEZ;VYT86P`36%R9V5N(&AO<FEZ;VYT86P`2&]R
M:7IO;G1A;#H`OT/S;6\@;&QE9_,@:&%S=&$@87%U[3\@**%#;VUU;NUQ=65L
M;RP@<&]R(&9A=F]R(2D`OT-U86YT87,@8V]L=6UN87,@9&5S96$@8V]M8FEN
M87(_`+]#=>%N=&]S(&-A;7!O<R`H8V]L=6UN87,I(&AA>3\`OT-U86YT87,@
M9FEL87,@9&5S96$@8V]M8FEN87(_`$AU;65D860`2'5M961A9#H@`$AU;6]R
M:7-T87,`2'5N9W+M80!(82!F86QL861O(&QA(&-R96%C:?-N(&1E;"!B=7KS
M;B!)34%0.B`E<P!(82!F86QL861O(&QA(&5L:6UI;F%C:?-N(&1E;"!B=7KS
M;B!)34%0.B`E<P!(82!F86QL861O(&QA(&-R96%C:?-N(&1E(&5S<&%C:6\@
M87-I9VYA9&\@9&5L(&)U>O-N($E-05`Z("5S`$1I<F5C8VGS;B!)4`!,82!D
M:7)E8V-I\VX@25`@;F\@97-TX2!D:7-P;VYI8FQE+@!,82!D:7)E8V-I\VX@
M25`@;F\@97-TX2!E;G1R92!B;&]Q=65S($-)1%(@<&5R;6ET:61O<RX`5FEO
M;&%C:?-N(&QO8VMD;W=N($E0+@!)7VYS97)T87(@9FEL82!E;F-I;6$`27-L
M86YD:6$`4_-L;R!I8V]N;W,`26-O;F]S(&1E("5S`$EC;VYO<R!C;VX@=&5X
M=&\`3F]M8G)E(&1E(&QA(&ED96YT:61A9#H`4VD@;F\@<V4@;75E<W1R82!C
M;W)R96-T86UE;G1E+"`E<R!P87)A(&%B<FER;&\@96X@=6YA('9E;G1A;F$@
M;G5E=F$N`%-I(&YO('9E(&YI;F?Z;B!I8V]N;R!M961I86YT92!);G1E<FYE
M="!%>'!L;W)E<BP@<'5E9&4@=&5N97(@<75E(&%C=&EV87(@97-T82!C87-I
M;&QA('!A<F$@9&5S86-T:79A<B!L82!T<F%N<W!A<F5N8VEA(%!.1RX`4VD@
M=F4@97-T92!M96YS86IE('-I;B!N:6YG=6YA(&EM86=E;BP@;&$@:6UA9V5N
M('%U92!Q=6EE<F4@8V%R9V%R(&YO('-E('!U961E(&UO<W1R87(@96X@<W4@
M;F%V96=A9&]R+@!6:7-T82!P<F5V:6$Z`%523"!D92!L82!I;6%G96X`55),
M(&1E(&QA(&EM86=E;CH`26UA9V5N(&1E(&QA(&=A;&5R[6$`26UA9V5N(&1E
M(&QA(&=A;&5R[6$Z`%-E(&AA(&-A<F=A9&\@;&$@:6UA9V5N`$EMX6=E;F5S
M`$EM<&]R=&%R+"!P87-O("5D`$-A;7!O(&EM<&]R=&%D;SH@)7,`0V%M<&]S
M(&EM<&]R=&%D;W,Z`$EN7W-E<G1A<B!F:6QA(&1E8F%J;P!392!H82!I;F1I
M8V%D;R!U;B!C\V1I9V\@9&4@86-C:?-N(&EN8V]R<F5C=&\N`$YO;6)R92!D
M92!U<W5A<FEO('DO;R!C;VYT<F%S9?%A(&EN8V]R<F5C=&]S+@!.;VUB<F4@
M9&4@=7-U87)I;R!O(&1I<F5C8VGS;B!A;'1E<FYA=&EV82!I;F-O<G)E8W1O
M<RX@5G5E;'9A(&$@:6YT96YT87)L;R!O('#S;F=A<V4@96X@8V]N=&%C=&\@
M8V]N(&5L(&%D;6EN:7-T<F%D;W(@9&4@<VES=&5M87,@<&%R82!MX7,@:6YF
M;W)M86-I\VXN`$%U;65N=&%R('-A;F=R861O`$EN9&EA`%5S=6%R:6]S(&EN
M9&EV:61U86QE<P!);F1O;F5S:6$`26YF;W)M86-I\VX`26YF;W)M86-I\VX`
M3&$@:6YF;W)M86-I\VX@>6$@;F\@97-TX2!D:7-P;VYI8FQE+@!);G-E<G1A
M<B!C7V]L=6UN82!D971RX7,`26YS97)T87(@:6UA9V5N`$EN<V5R=&%R('1A
M8FQA`$EN<V5R=&%R(';M;F-U;&\@5V5B`$EN<V5R=&%R(%]C;VQU;6YA(&1E
M;&%N=&4`26YS97)T82!U;F$@;G5E=F$@8V]L=6UN82!D971RX7,@9&4@;&$@
M86-T=6%L`$EN<V5R=&$@=6YA(&YU979A(&-O;'5M;F$@9&5L86YT92!D92!L
M82!A8W1U86P`26YS97)T82!U;F$@9FEL82!N=65V82!D96)A:F\@9&4@;&$@
M86-T=6%L`$EN<V5R=&$@=6YA(&9I;&$@;G5E=F$@96YC:6UA(&1E(&QA(&%C
M='5A;`!);G-E<G1A('5N('#A<G)A9F\@=')A<R!E;"!N;V1O(&%C='5A;`!)
M;G-E<G1A('5N('#A<G)A9F\@86YT97,@9&5L(&YO9&\@86-T=6%L`$EN<V5R
M=&%R('!L86YT:6QL82!A;'1E<FYA=&EV80!);G-E<G1A<B!U;F$@9&ER96-C
M:?-N(&1E(&-O<G)E;R!E;B!L82!Q=64@<F5C:6)I<B!L82!C;VYT<F%S9?%A
M.@!);G-E<G1A<B!C96QD82!D971RX7,`26YS97)T87(@8V5L9&$@86YT97,`
M26YS97)T87(@8V]L=6UN82!D971RX7,`26YS97)T87(@8V]L=6UN82!A;G1E
M<P!);G-E<G1A<B!M96YS86IE<P!);G-E<G1A<B!PX7)R869O(&1E='+A<P!)
M;G-E<G1A<B!PX7)R869O(&%N=&5S`$EN<V5R=&%R(&9I;&$@9&5B86IO`$EN
M<V5R=&%R(&9I;&$@96YC:6UA`$EN<V5R=&%R(&QA(')E<W!U97-T82!N96-E
M<V%R:6$@82!L82!P<F5G=6YT82!D92!S96=U<FED860Z`$EN<V5R=&%R+TUO
M9&EF:6-A<B!I;6%G96X`26YS97)T87(O36]D:69I8V%R(';M;F-U;&\`4V%L
M9&\@:6YS=69I8VEE;G1E('!A<F$@96YV:6%R(&$@;&$@;&ES=&$@9&4@9&ES
M=')I8G5C:?-N+@!386QD;R!I;G-U9FEC:65N=&4N`$5N=&5R;P!,:7-T82!D
M92!E;G1E<F]S`%5$2"`H0V%B96-E<F$@9&4@1&%T;W,@9&4@57-U87)I;RD@
M;F\@=N%L:61A+@!$871O<R!:25`@;F\@=N%L:61O<P!!<&QI8V%C:?-N(&YO
M(';A;&ED82X`240@9&4@;&]T92!N;R!VX6QI9&\N`%-E(&AA;B!E;G9I861O
M(&1A=&]S(&YO(';A;&ED;W,N`$1I<F5C8VGS;B!D92!C;W)R96\@;F\@=N%L
M:61A+@!&;W)M871O(&1E(&%R8VAI=F\@;F\@=N%L:61O`$-L879E(&1E(&QI
M8V5N8VEA(&YO(';A;&ED82X`4V4@:&$@:6YD:6-A9&\@=6YA('5B:6-A8VGS
M;B!N;R!VX6QI9&$N`&US9U]T>7!E(&YO(';A;&ED;RX`87!I7VED(&YO(';A
M;&ED;R!O(&1E<V%P87)E8VED;RX`4&%RX6UE=')O<R!N;R!VX6QI9&]S(&\@
M9&5S87!A<F5C:61O<RX`4')I=FEL96=I;R!D96P@<&%D<F4@;F\@=N%L:61O
M<RX`240@9&4@87-O8VEA9&\@;F\@=N%L:61O+@!#\V1I9V\@9&4@<')O9'5C
M=&\@;F\@=N%L:61O+@!0<F]T;V-O;&\@;F\@=N%L:61O+@!$97-T:6YA=&%R
M:6\@;F\@=N%L:61O.B`B)7,B`$]B:F5T;R!C;VUP87)T:61O(&YO(';A;&ED
M;RX`1&ER96-C:?-N(&1E;"!R96UI=&5N=&4@;F\@=N%L:61A`$1A=&]S('5N
M:6-O9&4@;F\@=N%L:61O<RX`26YV96YT87)I;P!);G9E<G1I<B!S96QE8V-I
M\VX`27+A;BP@4F5P^F)L:6-A($ES;.%M:6-A(&1E`$ER87$`27)L86YD80!)
M<VQA(&1E($UA;@!";W)R87-C87,@86ES;&%D87,`27-R865L`$5M:7-O<@!#
M=7)S:79A`$ET86QI80!*86UA:6-A`$5N97)O`$IA</-N`$IA<&]NZ7,@*$E3
M3RTR,#(R+4I0*0!*97)S97D`2F]R9.%N`$IU;&EO`$IU;FEO`$IU<W1I9FEC
M87(`06QI;F5A<B!A;"!C96YT<F\`2G5S=&EF:6-A<@!!;&EN96%R(&$@;&$@
M:7IQ=6EE<F1A`$%L:6YE87(@82!L82!D97)E8VAA`$MA>F%K:'-T86X`OT-O
M;G-E<G9A<B!E;"!O<FEG:6YA;#\`2V5N>6$`16P@<V5R=FED;W(@2V5R8F5R
M;W,@:&$@<F5C:&%Z861O(&QA(&%U=&5N=&EF:6-A8VGS;BX`3F]V871O<R!D
M96P@2V5R;F5L`$-R96%C:?-N(&1E(&-L879E`$AU96QL82!D:6=I=&%L(&1E
M(&QA(&-L879E`%1A;6'Q;R!D92!C;&%V90!4:7!O(&1E(&-L879E`%5S;R!D
M92!L82!C;&%V93H`3&$@8VQA=F4@>6$@97AI<W1E(&5N(&5L('-E<G9I9&]R
M(&1E(&-L879E<R!P^F)L:6-O+@!.:?%O<P!+:7)I8F%T:0!#;W)E82P@4F5P
M^F)L:6-A(%!O<'5L87(@1&5M;V-RX71I8V$@9&4`0V]R96$L(%)E</IB;&EC
M82!D90!#;W)E86YO("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`%]$:7-T
M<FEB=6-I\VX`261I;VUA`$QA;RP@4F5P^F)L:6-A($1E;6]C<N%T:6-A(%!O
M<'5L87(`0W5A<G1O(&UE;F=U86YT90#:;'1I;6\@8V%M8FEO(&1E(&-O;G1R
M87-E\6$`0W5A<G1O(&UE;F=U86YT90#:;'1I;6$@86-T=6%L:7IA8VGS;CH`
MVFQT:6UA('-E<VGS;CH@)7,`VFQT:6UA('-E<VGS;CH@)7,@9&5S9&4@)7,`
MVFQT:6UA('-E<VGS;CH@3G5N8V$`3&%T=FEA`$QE>65S`$1I<W1R:6)U8VGS
M;@!$96IA<B!E;B!B;&%N8V\@<&%R82!E;&EM:6YA<B!E;"!B;W)D90!,96)A
M;F]N`$EZ<75I97)D80!#86)E8V5R82!I>G%U:65R9&$`5F%L;W)E<R!D92!L
M82!I>G%U:65R9&$`3&5S;W1H;P!.:79E;`!,:6)E<FEA`$QI8GEA;B!!<F%B
M($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=E<F$@;&QO=FEZ;F$`3&QU
M=FEA(&QI9V5R80!,;'5V:6$@;&EG97)A(&UA='5T:6YA`$QL=79I82!L:6=E
M<F$@=F5S<&5R=&EN80!!9W5A8V5R;R!L:6=E<F\`3&QU=FEA<R!Y('1R=65N
M;W,`3F5V861A('-U879E`$QI9V5R;R!A9W5A8V5R;R!D92!N:65V90!#:&%S
M8V%R<FEL;&\`5NUN8W5L;P!%;"!V[6YC=6QO(&%P=6YT82!A.@!6:6YC=6QA
M<B!D:7)E8V-I\VX@9&4@8V]R<F5O(&$@;&$@<.%G:6YA(&1E(&-O;7!O<VEC
M:?-N(&%L(&UO<W1R87(`5NUN8W5L;W,`0V]O:VEE($QI;G5X`$QI<W1A<B`M
M(&5L('5S=6%R:6\@<'5E9&4@97AA;6EN87(@;&$@8V%R<&5T80!,:7-T87(@
M8F%S97,@9&4@9&%T;W,`3&ES=&%R('1E;6%S(&1E(&%Y=61A`$QI<W1A<B!T
M86)L87,`3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N
M97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`
M2&$@9F%L;&%D;R!E;"!L:7-T861O(&1E(&QA<R!S97-I;VYE<SH@)7,`2&$@
M9F%L;&%D;R!E;"!L:7-T861O(&1E('5S=6%R:6]S.B`E<P!%;"!L:7-T861O
M(&1E('5S=6%R:6]S(&5S=.$@9&5S:&%B:6QI=&%D;RX`3&ET97)A='5R80!,
M:71U86YI80!,97EE;F1O+BXN`$AO<F$@;&]C86PZ(`!)9&EO;6$@>2!H;W)A
M`%5B:6-A8VGS;@!);FEC:6%R('-E<VGS;@!296=I<W1R;R!D92!L87,@<V5S
M:6]N97,@9&4@<VEN8W)O;FEZ86-I\VX@86YT97)I;W)E<P!386QI<@!);FEC
M:6%R('-E<VGS;@!487)E87,@9&4@:6YI8VEO(&1E('-E<VGS;@!&86QL\R!E
M;"!I;FEC:6\@9&4@<V5S:?-N('!O<G%U92!I;G1R;V1U:F\@:6YC;W)R96-T
M86UE;G1E('-U(&YO;6)R92!D92!U<W5A<FEO(&\@8V]N=')A<V7Q82X`1F%L
M;/,@96P@:6YI8VEO(&1E('-E<VGS;BX`5&5X=&\@8V]M<&QE=&\`06UO<@!"
M86IA`$%L9F%B971O(&=R:65G;R!E;B!M:6[Z<V,N`$%L9F%B971O(&QA=&EN
M;R!E;B!M:6[Z<V,N`$[Z;65R;W,@<F]M86YO<R!E;B!M:6[Z<V,N`$QU>&5M
M8G5R9V\`34T`34]41`!%;"!A9&IU;G1O($U3+51.148@;F\@8V]N=&5N[6$@
M9&%T;W,N`$U31P!-86-A;P!-86-E9&]N:6$L($%N=&EG=6$@4F5P^F)L:6-A
M(%EU9V]S;&%V82!D90!-861A9V%S8V%R`$UA9VEA`$-O<G)E;P!!9&TN(&-O
M<G)E;P!#<F5A<B!?=NUN8W5L;RXN+@!-86QA=VD`36%L87-I80!-86QD:79A
M<P!-86QI`$UA;'1A`$=E<W1I;VYA(&QA(&QI<W1A(&1E(&-A=&5G;W+M87,@
M8V]N(&QA('%U92!E=&EQ=65T87(@96QE;65N=&]S('D@;&]S(&-O;&]R97,@
M87-O8VEA9&]S(&$@9&EC:&%S(&-A=&5G;W+M87,N`$UA<&$@;6%P,C0`36%P
M82!M87!Q=65S=`!#;W)R97-P;VYD96YC:6%S(&%L;6%C96YA9&%S+@!-87)Z
M;P!-87)G96X`36%R8V%R(&-O;B!L87,@8F%N9&5R87,@9&4@3&7M9&\O4VEN
M(&QE97(`36%R8V%R(&-O;B!O=')A<B!B86YD97)A<R`H<"YE+B!);7!O<G1A
M;G1E+U)E<W!O;F1I9&\I`$ES;&%S($UA<G-H86QL`$UA<G1I;FEC80!#86UP
M;W,@8V]I;F-I9&5N=&5S`$UA=7)I=&%N:6$`36%U<FEC:6\`4V%L9&\@;>%X
M:6UO('!E<FUI=&ED;RX`4V4@:&$@<V]B<F5P87-A9&\@96P@;OIM97)O(&WA
M>&EM;R!D92!P87)T97,@9&4@;65N<V%J92X`5&5M<"X@;>%X:6UA(/IL=&EM
M87,@,C0@:&]R87,Z(`!496UP+B!MX7AI;6$@^FQT:6UA<R`V(&AO<F%S.B``
M3OIM97)O(&WA>&EM;R!D92!B;&]Q=65S(&1E;"!P;W)T86P`3&]N9VET=60@
M;>%X:6UA`$UA>6\`36%Y;W1T90!-961I8VEN80!-:65M8G)O<P!&;W)M871O
M(&1E;"!M96[Z.@!#;VUB:6YA<B!C96QD87,`365N<V%J90!392!H82!C;VUP
M<F]B861O(&-O<G)E8W1A;65N=&4@96P@;65N<V%J92!P97)O(&YO('-E('!U
M961E('9E<FEF:6-A<B!E;"!C97)T:69I8V%D;R!D96P@9FER;6%N=&4N`$UE
M;G-A:F4@8V%D=6-A9&\N`%1I<&\@9&4@;65N<V%J90!4:65M<&\@9&4@365T
M87(`0FQO<75E($UE=&%R(&YO(&1I<W!O;FEB;&4N`$)L;W%U92!-971A<B!N
M;R!D:7-P;VYI8FQE+B!392!H86X@<F5G:7-T<F%D;R!L;W,@9&5T86QL97,@
M<&%R82!E;"!A9&UI;FES=')A9&]R+@!.;R!E<W3A(&-O;F5C=&%D82!L82!-
M971A<D1"`$WI=&]D;P!%;"!MZ71O9&\@(B5S(B!N;R!E<W3A(&1E9FEN:61O
M`$WI=&]D;R!N;R!D969I;FED;RX@3>ET;V1O(&QL86UA9&\Z("5S`$WI=')I
M8V\`3>EJ:6-O`$UI8W)O;F5S:6$L($5S=&%D;W,@1F5D97)A9&]S(&1E`$5N
M(&UE9&EO`%1I<&\@36EM90!496UP+B!M[6XN(&QA<R#Z;'1I;6%S(#(T(&AO
M<F%S.B``5&5M<"X@;>UN+B!L87,@^FQT:6UA<R`V(&AO<F%S.B``5&]D87;M
M82!N;R!H82!E>'!I<F%D;R!L82!A;G1I9_QE9&%D(&WM;FEM82!D92!L82!C
M;VYT<F%S9?%A`%)E9FQE:F%R`$UI<V-E;.%N96$`4&%Q=65T92!014%2($A4
M5%!?4F5Q=65S="!D97-A<&%R96-I9&\N`$9A;'1A(&QA(&-O;F9I9W5R86-I
M\VXN(%1I96YE('%U92!G96YE<F%R;&$@86AO<F$@<VD@9&5S96$@=71I;&EZ
M87(@97-T82!A<&QI8V%C:?-N+@!)1"!D92!M96YS86IE(&1E<V%P87)E8VED
M;RX`4&%Q=65T92!014%2($UA:6P@9&5S87!A<F5C:61O+@!)1"!D92!S97-I
M\VX@9&5S87!A<F5C:61O+@!,=6X`0V]R<F5O(&WS=FEL`$UO9&5R861O`%-E
M(&AA(&UO9&EF:6-A9&\@;&$@9F5C:&$`36]D:69I8V%R(%523`!-\V1U;&\`
M36]L9&%V:6$L(%)E</IB;&EC82!D90!-\VYA8V\`36]N9V]L:6$`365S('D@
M8?%O`$UE;G-U86QM96YT90!-;VYT<V5R<F%T`$9A<V5S(&1E(&QA(&QU;F$`
M4V4@:&%N(&5N8V]N=')A9&\@;>%S(&-A;7!O<R!E;B!L82!L[6YE82`E9"!Q
M=64@;&]S("5D(&5S<&5R861O<RX`36%R<G5E8V]S`$9U;F1A;65N=&%L;65N
M=&4@9&5S<&5J861O`$9U;F1A;65N=&%L;65N=&4@;G5B;W-O`$9U;F1A;65N
M=&%L;65N=&4@;G5B;W-O('D@=F5N=&]S;P!&=6YD86UE;G1A;&UE;G1E('-O
M;&5A9&\`1&5S<&QA>F%R(&AA8VEA(&%B86IO`$1E<W!L87IA<B!A(&QA(&EZ
M<75I97)D80!$97-P;&%Z87(@82!L82!D97)E8VAA`$1E<W!L87IA<B!H86-I
M82!A<G)I8F$`1&5S<&QA>F%R(&AA8VEA(&%B86IO`$1E<W!L87IA<B!H86-I
M82!A<G)I8F$`36]Z86UB:7%U90!,:7-T87,@9&5S<&QE9V%B;&5S(&UU;'1I
M+6YI=F5L`$UA<&$@54L@;?IL=&EP;&4`4V5L96-C:?-N(&WZ;'1I<&QE`$ED
M96YT:61A9`!-:2!I9&5N=&ED860`36D@<&]R=&%L`$1I<W1R:6)U8VGS;B!D
M92!M:2!P;W)T86P`37EA;FUA<@!.3RP@3D\@97-T;WD@9&4@86-U97)D;P!.
M;VUB<F4`3F%M:6)I80!.875R=0!.97!A;`!(;VQA;F1A`$%N=&EL;&%S($AO
M;&%N9&5S87,`55),(&)A<V4@9&4@3F5T<V-A<&4`55),(&1E(&%N=6QA8VGS
M;B!D92!#02!D92!.971S8V%P90!54DP@9&4@<&]L[71I8V%S(&1E($-!(&1E
M($YE='-C87!E`%523"!D92!R96YO=F%C:?-N(&1E($YE='-C87!E`%523"!D
M92!A;G5L86-I\VX@9&4@3F5T<V-A<&4`3F]M8G)E(&1E('-E<G9I9&]R(%-3
M3"!D92!.971S8V%P90!#;VUE;G1A<FEO(&1E;"!C97)T:69I8V%D;R!D92!.
M971S8V%P90!4:7!O(&1E(&-E<G1I9FEC861O(&1E($YE='-C87!E`%)E9`!.
M=6YC80!.=65V82!#86QE9&]N:6$`3G5E=F$@8V%T96=O<NUA`$QU;F$@;G5E
M=F$`3G5E=F\@;F]M8G)E(&1E('5S=6%R:6\@*&]P8VEO;F%L*0!.=65V82!:
M96QA;F1A`$-O;G1R87-E\6$@;G5E=F$`3&$@;G5E=F$@8V]N=')A<V7Q82!E
M>'!I<F%RX2!E;"`E>"X`3&%S(&-O;G1R87-E\6%S(&YO(&-O:6YC:61E;BX`
M3G5E=F$@=F5N=&%N82`H7V)L86YK*0!.;W1I8VEA<P!'+B!D92!N;W1I8VEA
M<P!3:6=U:65N=&4`4'+S>&EM87,@-"!F87-E<P!/<&-I;VYE<R!S:6=U:65N
M=&5S`%-I9W5I96YT93X`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3F]C:&4`
M3FEU90!.;P!.;R!H87D@9&%T;W,@9&4@8V]N9FEG=7)A8VGS;B!P87)A(&UO
M<W1R87(@9&EF97)E;F-I87,N`$YO('-E(&1I<W!O;F4@9&4@97-T<F%T96=I
M82!D92!E;&%B;W)A8VGS;B!D92!I;>%G96YE<R!)4T\N`$YO(&AA>2!P;&%N
M=&EL;&$@9&4@;&]T97,`3F\@:&%Y(&)L;W%U97,@96X@;&$@<&]S:6-I\VX@
M:6YD:6-A9&$`3F\@<V4@:&$@:6YT<F]D=6-I9&\@=6X@;F]M8G)E(&1E(&%G
M96YD82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!-0T%,+@!3:6X@8V%M8FEO
M<RX`3F\@<V4@<'5E9&5N(&'Q861I<B!D97-C96YD:65N=&5S(&$@97-T92!P
M<FEV:6QE9VEO+@!.;R!S92!H82!E<W!E8VEF:6-A9&\@:6YF;W)M86-I\VX@
M9&4@8V]N9FEG=7)A8VGS;B!P87)A("5S+@!.;R!S92!H82!E<W!E8VEF:6-A
M9&\@:6YF;W)M86-I\VX@9&4@8V]N9FEG=7)A8VGS;B!P87)A(%9&4R!P;W(@
M1E10+@!.;R!S92!H82!E<W!E8VEF:6-A9&\@:6YF;W)M86-I\VX@9&4@8V]N
M9FEG=7)A8VGS;B!P87)A(%9&4R!P;W(@4U%,+@!.;R!S92!H82!E<W!E8VEF
M:6-A9&\@:6YF;W)M86-I\VX@9&4@8V]N9FEG=7)A8VGS;B!P87)A(%9&4R!P
M;W(@87)C:&EV;R!344PN`$YO('%U961A('-A;&1O+@!.;R!S92!H82!I;G1R
M;V1U8VED;R!E;"!D97-T:6YO+@!.;R!S92!H82!C87)G861O(&YI;F?Z;B!A
M<F-H:79O`$YO('-E(&AA;B!E;F-O;G1R861O(&EC;VYO<RX`3F\@<V4@:&$@
M9&5F:6YI9&\@;&$@=6)I8V%C:?-N+@!.;R!S92!H82!D969I;FED;R!L82!U
M8FEC86-I\VXN`$YO('-E(&AA(&EN=')O9'5C:61O('5N(&UE;G-A:F4N`$YO
M('-E(&AA(&5S<&5C:69I8V%D;R!U;B!N;VUB<F4N`$YO('-E(&AA(&5S<&5C
M:69I8V%D;R!U;B!N^FUE<F\N`$YO(&]F96YS:79A<P!.;R!S92!H82!I;G1R
M;V1U8VED;R!U;F$@8V]N=')A<V7Q82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS
M;B!(5%10+@!.;R!S92!H82!I;G1R;V1U8VED;R!U;F$@8V]N=')A<V7Q82!P
M87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!)34%0+@!.;R!S92!H82!I;G1R;V1U
M8VED;R!U;F$@8V]N=')A<V7Q82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!+
M97)B97)O<RX`3F\@<V4@:&$@:6YT<F]D=6-I9&\@=6YA(&-O;G1R87-E\6$@
M<&%R82!L82!A=71E;G1I9FEC86-I\VX@9&4@:6YI8VEO+@!.;R!S92!H82!I
M;G1R;V1U8VED;R!U;F$@8V]N=')A<V7Q82!P87)A(&QA(&%U=&5N=&EF:6-A
M8VGS;B!005-35T0N`$YO('-E(&AA(&EN=')O9'5C:61O('5N82!C;VYT<F%S
M9?%A('!A<F$@;&$@875T96YT:69I8V%C:?-N(%--0BX`3F\@<V4@:&$@:6YD
M:6-A9&\@=NUA(&1E(&%C8V5S;R!A(&QO<R!B:6YA<FEO<R!/<&5N4U-,+B!0
M87)A('1R86)A:F%R(&-O;B!D871O<R!02T-3(#$R(&AA8V5N(&9A;'1A(&QO
M<R!B:6YA<FEO<R!/<&5N4U-,+@!3:6X@86QT87,@<&5N9&EE;G1E<RX`0V%R
M96-E(&1E('%U;W1A+@!3:6X@<F%Y87,`3F\@<V4@:&$@97-P96-I9FEC861O
M('5N('-E<&%R861O<BX`3FEN9W5N;P!.;R!E>&ES=&4@96P@87)C:&EV;P!.
M;R!S92!D:7-P;VYE(&1E('5N(&1I<F5C=&]R:6\@9&4@86QM86-E;F%M:65N
M=&\@=&5M<&]R86PN`$YO('-E(&AA(&5N=FEA9&\@96P@;F]M8G)E(&1E('5S
M=6%R:6\@>2]O(&QA(&-O;G1R87-E\6$N`$YO('-E(&AA;B!D979U96QT;R!D
M871O<R!834P@=N%L:61O<P!3:6X@=F%L;W)E<P!.;R!S92!E;F-O;G1R\R!L
M82!V97)S:?-N(&5N(&QA(&-O;F9I9W5R86-I\VX@;W)I9VEN86PN(%)E9V5N
M97)A<B!L82!C;VYF:6=U<F%C:?-N+@!.;R!S92!E;F-O;G1R\R!L82!V97)S
M:?-N(&5N(&QA(&-O;F9I9W5R86-I\VXN(%)E9V5N97)A<B!L82!C;VYF:6=U
M<F%C:?-N+@!.:6YG=6YA`$YI;F=U;F\@*'5S;R!I;7!L[6-I=&\I`$[S<F1I
M8V\@*$E33RTX.#4Y+3$P*0!)<VQA(&1E($YO<F9O;&L`2&5M:7-F97)I;R!N
M;W)T90!)<VQA<R!-87)I86YA<R!D96P@3F]R=&4`3F]R=65G80!.;R!D97-P
M=>ES`$YO(&%N=&5S`$YO(&5S('5N(&1I<F5C=&]R:6\`4VEN(&1E<V%R<F]L
M;&%R+@!3:6X@97-T86)L96-E<@!.;R!E<W3A('-O<&]R=&%D;RX`3F]T87,`
M3F\@:&%Y(&YA9&$@=FES=6%L:7IA8FQE+"!R971R;V-E9&$N`$YO=FEE;6)R
M90!.^FUE<F\`3OIM97)O(&1E(&-A<F%C=&5R97,`3OIM97)O(&1E(&-O;'5M
M;F%S`$[Z;65R;R!D92!F:6QA<P!.;R!S92!H86X@97-P96-I9FEC861O(&[Z
M;65R;W,@82!A8W1U86QI>F%R(&5N(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS
M;BX`06-E<'1A<@!/8FIE=&\`0W)E861O<B!D92!O8FIE=&]S`$]C=&%L`$]C
M='5B<F4`1FEL=')A<B!O9F5N<V%S`$]F:6-I;F$`3&$@8V]N=')A<V7Q82!A
M;G1I9W5A('D@;&$@;G5E=F$@9&5B96X@<V5R(&1I<W1I;G1A<RX`0V]N=')A
M<V7Q82!A;G1I9W5A`$QA(&-O;G1R87-E\6$@86YT:6=U82!N;R!E<R!C;W)R
M96-T82X`3VWA;@!3\VQO(&QO<R!S97)V:61O<F5S($E-05`@<V]P;W)T86X@
M;&%S(&-A<G!E=&%S(&-O;7!A<G1I9&%S+@!3\VQO(&]F96YS:79A<P!3\VQO
M('-E('!E<FUI=&4@=6YA(&1I<F5C8VGS;B!D92!C;W)R96\N`%/S;&\@96P@
M<')O<&EE=&%R:6\@;R!U;B!A9&UI;FES=')A9&]R(&1E('-I<W1E;6%S('!U
M961E(&-A;6)I87(@;&$@<')O<&EE9&%D(&\@;&]S('!R:79I;&5G:6]S(&1E
M('!R;W!I971A<FEO(&1E('5N(')E8W5R<V\@8V]M<&%R=&ED;P!!8G)I<B!E
M;B!U;F$@;G5E=F$@=F5N=&%N80!%<G)O<B!/<&5N4U-,.B!.;R!S92!P=65D
M96X@97AT<F%E<B!D871O<R!D92!L82!P87)T92!3+TU)344@9FER;6%D82X`
M06)R:7(@97-T92!V[6YC=6QO(&5N('5N82!V96YT86YA(&YU979A`%-I<W1E
M;6$@;W!E<F%T:79O`$]P8VEO;F5S`$]P8VEO;F5S(&1E("5S`$QI<W1A(&]R
M9&5N861A`$]R9V%N:7IA8VGS;@!5;FED860@;W)G86YI>F%T:79A`$]R9V%N
M:7IA8VGS;@!0;&%N=&EL;&$@9&4@87!L:6-A8VGS;B!O<FEG:6YA;`!0;&%N
M=&EL;&%S(&]R:6=I;F%L97,@96X@)7,Z`$]T<F\`3W1R82!I;F9O<FUA8VGS
M;@!0<FEV:6QE9VEO<R!D96P@<')O<&EE=&%R:6\`3&$@875T96YT:69I8V%C
M:?-N(%!!32!N;R!E<W3A(&1I<W!O;FEB;&4N`%!%05(Z.DUO=&]R(&1E(&-O
M<G)E;P!&:7)M82!D:6=I=&%L(%!'4`!$871O<R!C:69R861O<R!C;VX@4$=0
M`$-L879E(%!'4"!P^F)L:6-A`$1A=&]S(&9I<FUA9&]S+V-I9G)A9&]S(&-O
M;B!01U``0_-D:6=O(%!(4`!);G3I<G!R+B!02%``3&QO=FEZ;F$@=F5S<&5R
M=&EN80!,;'5V:6$@=F5S<&5R=&EN80!#:&%P87)R;VYE<R!V97-P97)T:6YO
M<P!.:65V92!V97-P97)T:6YA`$%G=6%C97)O(&1E(&YI979E('9E<W!E<G1I
M;F\`4V]L('9E<W!E<G1I;F\`0F]R<F%S8V%S('9E<W!E<G1I;F%S`$YO('-E
M(&5N8W5E;G1R82!L82!E>'1E;G-I\VX@4$]325@`26YTZ7)P<BX@4%](4`!-
M87)G96X`4&%K:7-TX6X`4&%L874`4&%L97-T:6YO<RP@5&5R<FET;W)I;W,@
M3V-U<&%D;W,`4&%N86WA`%!A</IA($YU979A($=U:6YE80!087)A9W5A>0!0
M87)C:6%L;65N=&4@;G5B;W-O`$-O;G1R87-E\6$`3&$@8V]N=')A<V7Q82!S
M92!C86UB:6%D;R!C;W)R96-T86UE;G1E+@!#;VYT<F%S9?%A(&EN8V]R<F5C
M=&$`2&%Y('%U92!I;G1R;V1U8VER('5N82!C;VYT<F%S9?%A('!A<F$@;&$@
M875T96YT:69I8V%C:?-N(%)!1$E54RX`0V]N=')A<V7Q82!C;VX@8V]N9FER
M;6%C:?-N`$-O;G1R87-E\6$Z`$-O;G1R87-E\6$Z(`!,87,@8V]N=')A<V7Q
M87,@=&EE;F5N('%U92!C;VEN8VED:7(N`%!E9V%R`%!E9V%R(&1E;"!P;W)T
M87!A<&5L97,`5NUA`$%L=&%S('!E;F1I96YT97,Z`$=E;G1E`%!O<F-E;G1A
M:F4`4F5A;&EZ87(@;W!E<F%C:6]N97,@9&4@;6%N=&5N:6UI96YT;P"_4F5A
M;&EZ87(@;W!E<F%C:6]N97,@9&4@;6%N=&5N:6UI96YT;R!A;"!I;FEC:6%R
M('-E<VGS;C\`4')I=FEL96=I;P!.;R!S92!H82!E;&EM:6YA9&\@96P@<')I
M=FEL96=I;R`B)7,B+@!0<FEV:6QE9VEO(&1E;F5G861O`%!R:79I;&5G:6]S
M`$%D;6EN:7-T<F%C:?-N(&1E('!R:79I;&5G:6]S`$EN9F]R;6%C:?-N('!E
M<G-O;F%L`%!E<OH`36%S8V]T87,`1FEL:7!I;F%S`%1E;.EF;VYO`$9O=&]G
M<F%F[6%S`%!I=&-A:7)N`%#M>&5L97,`5/-P:6-O<P!0=6QS92!E;B!U;F$@
M8V5L9&$`0V]N9FER;64@<75E(&1E<V5A(&5L:6UI;F%R(&5S=&4@96QE;65N
M=&\Z`$-O;F9I<FUE('%U92!D97-E82!E;&EM:6YA<B!E;"!V[6YC=6QO(&$@
M97-T92!E;&5M96YT;RX`26YT<F]D=7IC82!U;B!M97,@>2!U;B!A\6\N`$EN
M=')O9'5Z8V$@96P@;F]M8G)E(&1E(&QA(&YU979A(&-A=&5G;W+M83H`26YT
M<F]D=7IC82!U;F$@9&ER96-C:?-N($E0(';A;&ED82X`26YT<F]D=7IC82!U
M;F$@9F5C:&$@=N%L:61A+"!C;VUP<G5E8F4@96P@;OIM97)O(&1E(&3M87,@
M9&5L(&UE<RX`26YT<F]D=7IC82!U;F$@:&]R82!VX6QI9&$N`%!R;W!O<F-I
M;VYE('5N(')E<W5M96X@9&5L('!R;V)L96UA+@!);G1R;V1U>F-A('-U(&YO
M;6)R92!D92!U<W5A<FEO('D@8V]N=')A<V7Q82X`3&5A(&5L('1E>'1O('-I
M9W5I96YT92X@1$5"12!A8V5P=&%R(&QO<R!TZ7)M:6YO<R!S:2!Q=6EE<F4@
M=7-A<B!E;"!S:7-T96UA+@!);G1R;V1U>F-A(&5L(&YU979O(&YO;6)R92!D
M92!C871E9V]R[6$Z`%!O;&]N:6$`4&]L[71I8V$`16YC=65S=&%S`%!O<G1U
M9V%L`%!O<VEC:?-N(&1E(&QA(&EM86=E;@!0;W-I8VGS;B!D92!L82!T86)L
M80!%;G9I87(@82!E<W1A(&-A<G!E=&$@*&YO(&]B;&EG861O('!O<B!)34%0
M*0!0<F5C:7!I=&%C:6]N97,@9&4@;&$H<RD@^FQT:6UA*',I("5S(&AO<F$H
M<RDZ(`!0<F]B86)I;&ED860\8G(@+SYD92!P<F5C:7!I=&%C:?-N`%!R969S
M7VQD87`Z(&YO('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!,1$%0(')E<75E
M<FED82X`4')E9G-?<V5S<VEO;CH@;F\@<V4@96YC;VYT<O,@;&$@97AT96YS
M:?-N(&1E('-E<VGS;B!R97%U97)I9&$N`%!R97-I\VX`4')E<VGS;B!A;"!N
M:79E;"!D96P@;6%R.B``4')E<VGS;CH@`%9I<W1A('!R979I80!6:7-T82!P
M<F5V:6$@9&4@;&$@:6UA9V5N(&5N('5N82!N=65V82!V96YT86YA`$]P8VEO
M;F5S(&%N=&5R:6]R97,`26UP<FEM:7(@9&]C=6UE;G1O`$-L879E('!R:79A
M9&$`OU!R;V)L96UA<S\`1&5S8W)I<&-I\VX@9&5L('!R;V)L96UA`%!R;WEE
M8W1O<P!497AT;R!D96P@:6YD=6-T;W(`0VQA=F4@4$=0('#Z8FQI8V$`06QG
M;W)I=&UO(&1E(&-L879E('#Z8FQI8V$`26YF;W)M86-I\VX@9&4@8VQA=F4@
M</IB;&EC80!.;R!S92!G96YE<F%R;VX@8V]R<F5C=&%M96YT92!L87,@8VQA
M=F5S(%#Z8FQI8V$O4')I=F%D82X`4'5E<G1O(%)I8V\`3&EM<&EA<B!M96YS
M86IE<P!1871A<@!#;VYS=6QT80!1=6]T80!#;&%V92!24T$@</IB;&EC82`H
M)60@8FET*0!";W3S;B!D92!O<&-I\VX`3&QU=FEA`$QL=79I82!M871U=&EN
M80!,;'5V:6$@=F5S<&5R=&EN80!!9W5A8V5R;P!,;'5V:6$@>2!.:65V90!,
M;'5V:6$@82!.:65V90!2=65D82!D92!L82!F;W)T=6YA`%)A>O-N`"9N8G-P
M.TQE97(F;F)S<#L`3&5E<B!M96YS86IE<P"_16QI;6EN87(@<F5A;&UE;G1E
M("5S/R!%<W1A(&]P97)A8VGS;B!N;R!S92!P=65D92!D97-H86-E<BX`OT5L
M:6UI;F%R(')E86QM96YT92!L;W,@9&%T;W,@9&5L('5S=6%R:6\@)7,_($5S
M=&$@;W!E<F%C:?-N(&YO('-E('!U961E(&1E<VAA8V5R+@!6=65L=F4@82!R
M96%L:7IA<B!L82#Z;'1I;6$@86-C:?-N`$%C='5A;&EZ87(`06-T=6%L:7IA
M<B!E;&5M96YT;W,@9&4@;65N^B!D:6[A;6EC;W,Z`$%C='5A;&EZ87(@=FES
M=&$@9&5L('!O<G1A;`!296=E>`!.879E9V%D;W(@9&4@<F5L86-I;VYE<P!2
M969R97-C87(`3V)S97)V86-I;VYE<P!397)V:61O<F5S(')E;6]T;W,`55),
M(')E;6]T82`H:'1T<#HO+W=W=RYE:F5M<&QO+F-O;2]H;W)D92DZ`%%U:71A
M<@!1=6ET87(@8FQO<75E`%%U:71A<B!C;VQU;6YA`$5L:6UI;F%R(&9O<FUA
M=&\`475I=&%R('!A<@!%;&EM:6YA<B!G=6GS;B!G=6%R9&%D;R!D96P@9&ER
M96-T;W)I;R!T96UP;W)A;"!D96P@<V5R=FED;W(N`$5L:6UI;F%R(`!%;&EM
M:6YA<B!E<W1E(&YO9&\@9&5L(&1O8W5M96YT;P!%;&EM:6YA<B!U<W5A<FEO
M`$5L:6UI;F%R('5S=6%R:6\Z("5S`$YO('-E('!U961E(')E<W!O;F1E<B!A
M(&QA('-O;&EC:71U9"X@0_-D:6=O(&1E(&5R<F]R(&1E=G5E;'1O.B``3F\@
M<V4@96YC;VYT<O,@96P@<V5R=FEC:6\@<V]L:6-I=&%D;RX`3F\@<V4@:&$@
M97-P96-I9FEC861O(&5L("(E<R(@<F5Q=65R:61O(&5N(&QA(&-O;F9I9W5R
M86-I\VX@9&4@)7,N`$YO('-E(&AA(&5S<&5C:69I8V%D;R!E;"`B)7,B(')E
M<75E<FED;R!E;B!L82!C;VYF:6=U<F%C:?-N(&1E(%9&4RX`3F\@<V4@:&$@
M97-P96-I9FEC861O(&5L("(E<R(@<F5Q=65R:61O(&5N(&QA(&-O;F9I9W5R
M86-I\VXN`$-A;7!O(&YE8V5S87)I;P!,:6UP:6%R`$QI;7!I87(@8V]N=')A
M<V7Q80!,:6UP:6%R(&-O;G1R87-E\6$`4F5S=&%U<F%R(/IL=&EM82!C;VYS
M=6QT80!297-U;'1A9&]S`%)E9W)E<V%R(&$@;W!C:6]N97,`4F5E<V-R:6)I
M<B!C;VYT<F%S9?%A(&YU979A`%)E=6YI\VX`4F5S=&%U<F%R(&-O;F9I9W5R
M86-I\VX`3W!C:6]N97,@9&4@961I8VGS;B!D92!T97AT;R!E;G)I<75E8VED
M;P!#<FEB87,`1&5R96-H80!#86)E8V5R82!D97)E8VAA`%9A;&]R97,@9&4@
M;&$@9&5R96-H80!0<F]P:65D861E<R!D92!?9FEL82XN+@!&=6YC:?-N`%)U
M;6%N[6$`1VER87(@,3@P`$=I<F%R(&$@;&$@:7IQ=6EE<F1A`$=I<F%R(&$@
M;&$@9&5R96-H80!0<F]P:65D861E<R!D92!F:6QA`%!R;W!I961A9&5S(&1E
M(&9I;&$`1FEL87,Z`%)A>6%S`$%P87)E8V5RX6X@<F%Y87,@96YT<F4@=&]D
M87,@;&%S(&9I;&%S('D@8V]L=6UN87,`07!A<F5C97+A;B!R87EA<R!S\VQO
M(&5N=')E(&QA<R!C;VQU;6YA<P!!<&%R96-E<N%N(')A>6%S('/S;&\@96YT
M<F4@;&%S(&9I;&%S`$5J96-U=&%R`$9E9&5R86-I\VX@4G5S80!2=6%N9&$`
M1FER;6$@8W)I<'1O9W+A9FEC82!3+TU)344`365N<V%J92!C:69R861O(&5N
M(%,O34E-10!.;R!E<W3A(&1I<W!O;FEB;&4@;&$@875T96YT:69I8V%C:?-N
M(%-!4TPN`$UE;G,N(%--4P!);G3I<G!R+B!344P`4V5N=&5N8VEA(%-13"!P
M87)A(&-O;G-U;'1A<R!D92!V86QO<F5S`%-32`#)6$E43P!);G3I<G!R+B!3
M7U%,`%-A8@!386YT82!(96QE;F$`4V%I;G0@2VET=',@>2!.979I<P!386YT
M82!,=6/M80!386EN="!0:65R<F4@>2!-:7%U96QO;@!386X@5FEC96YT92!Y
M($=R86YA9&EN87,`36ES;6\@9G)A;64@*%]S96QF*0!386UO80!386X@36%R
M:6YO`%-A;G1O(%1O;>%S('D@4'+M;F-I<&4`4')O=F5E9&]R(&1E('-A=.EL
M:71E`$%R86)I82!3875D:71A`$=U87)D87(`1W5A<F1A<B`B)7,B`$=U87)D
M87(@)7,`1W5A<F1A<B!O<&-I;VYE<P!'=6%R9&%R(&QA(&-O;F9I9W5R86-I
M\VX@9V5N97)A9&$@8V]M;R!U;B!G=6GS;B!02%`@96X@96P@9&ER96-T;W)I
M;R!T96UP;W)A;"!D92!S=2!S97)V:61O<BX`4V4@:&$@9W5A<F1A9&\@;&$@
M8V]N9FEG=7)A8VGS;B!D92`E<RX`1W5A<F1A<B!G=6GS;B!D92!A8W1U86QI
M>F%C:?-N(&1E(&QA(&-O;F9I9W5R86-I\VX@96XZ("(E<R(N`$)O<G)A<V-A
M<R!A:7-L861A<P!#:65N8VEA`$)U<V-A<@!-+B!B^G-Q=65D80!396QE8V-I
M;VYA<B!A<F-H:79O<P!396QE8V-I;VYE('5N82!F96-H80!396QE8V-I;VYE
M(&5L(&=R=7!O(&$@8?%A9&ER`%-E;&5C8VEO;F4@=6X@;G5E=F\@<')O<&EE
M=&%R:6\`4V5L96-C:6]N92!U;B!S97)V:61O<@!396QE8V-I;VYE(&5L('5S
M=6%R:6\@82!A\6%D:7(`4V5L96-C:6]N87(@=&]D;P!396QE8V-I;VYE('1O
M9&]S(&QO<R!C;VUP;VYE;G1E<R!D92!L82!F96-H82X`4V5L96-C:6]N87(@
M=6X@;V)J971O`%-I;B!S96QE8V-I\VX`4V5L96-C:6]N92!L;W,@8V%RX6-T
M97)E<R!Q=64@;F5C97-I=&4@9&4@;&%S(&-A<VEL;&%S(&1E(&%B86IO+B!0
M=65D92!C;W!I87)L;W,@>2!P96=A<FQO<R!D96P@X7)E82!D92!T97AT;RX`
M4V5L96-C:6]N92!E;"!D96QI;6ET861O<B!D92!F96-H87,Z`%-E;&5C8VEO
M;F4@96P@9F]R;6%T;R!D92!F96-H87,Z`%-E;&5C8VEO;F4@;&$@:61E;G1I
M9&%D('%U92!Q=6EE<F$@8V%M8FEA<CH`4V5L96-C:6]N92!E;"!D96QI;6ET
M861O<B!D92!H;W)A<SH`4V5L96-C:6]N92!E;"!F;W)M871O(&1E(&AO<F%S
M.@!396QE8V-I;VYE(&1O<R!C86UP;W,@8V]I;F-I9&5N=&5S+@!396QE8V-I
M;VYE('-U(&-O;6)I;F%C:?-N(&1E(&-O;&]R97,N`%-E;&5C8VEO;F4@<W4@
M:61I;VUA('!R969E<FED;SH`16YV:6%R(&EN9F]R;64@9&4@<')O8FQE;6%S
M`$5N=FEA<B!335,`4V5N96=A;`!396YS;W(Z(`!397!T:65M8G)E`%-E<F)I
M82!Y($UO;G1E;F5G<F\`3OIM97)O(&1E('-E<FEE`$1A=&]S(&1E;"!S97)V
M:61O<B!E<G+S;F5O<R!O(&YO(&1I<W!O;FEB;&5S+@!!9&UI;FES=')A8VGS
M;B!D92!S97-I\VX`2&$@8V%D=6-A9&\@96P@240@9&4@<V5S:?-N+@!397-I
M;VYE<P!%<W1A8FQE8V5R`$5S=&%B;&5C92!O<&-I;VYE<R!Q=64@;&4@<&5R
M;6ET96X@<F5A:G5S=&%R('-U(&-O;G1R87-E\6$@<VD@;&QE9V%R82!A(&]L
M=FED87)L82X`0V]N9FEG=7)A('-E<G9I9&]R97,@<F5M;W1O<R!A(&QO<R!Q
M=64@9&5S964@86-C961E<B!D97-D92!E;"!P;W)T86PN`$1E9FEN92!L87,@
M;W!C:6]N97,@<')E9F5R:61A<R!D92!I9&EO;6$L('IO;F$@:&]R87)I82!Y
M(&9E8VAA<RX`1&5F:6YE(&QA(&%P;&EC86-I\VX@9&4@:6YI8VEO+"!L82!C
M;VUB:6YA8VGS;B!D92!C;VQO<F5S+"!L82!A8W1U86QI>F%C:?-N(&1E('#A
M9VEN82!Y(&]T<F%S(&]P8VEO;F5S(&1E('9I<W5A;&EZ86-I\VXN`$-O;F9I
M9W5R86-I\VX`2&%Y(&=U:6]N97,@9&4@86-T=6%L:7IA8VGS;B!D92!L82!C
M;VYF:6=U<F%C:?-N`%9A<FEA<R!U8FEC86-I;VYE<R!D:7-P;VYI8FQE<R!C
M;VX@96P@<&%RX6UE=')O.B``4V5Y8VAE;&QE<P!#;VUP<F%S`%)E<W5M96X@
M8V]R=&\`OT1E9FEN:7(@8VQA=F5S(&1E(&%C8V5S;R!P87)A(&QA(&UA>6]R
M[6$@9&4@;&]S(';M;F-U;&]S/P`F;F)S<#M-;W-T<F%R)FYB<W`[`$UU97-T
M<F$@;&%S(&1I9F5R96YC:6%S(&5N=')E(&QA(&YU979A(&-O;F9I9W5R86-I
M\VX@>2!L82!A;&UA8V5N861A`+]-;W-T<F%R(&AO<F$@9&4@;&$@^FQT:6UA
M('-E<VGS;B!A;"!I;FEC:6%R/P!-;W-T<F%R(&]P8VGS;B!D92!C;VYS97)V
M87(@96P@;W)I9VEN86P`36]S=')A<B!S96QE8W1O<@"_36]S=')A<B!L82!B
M87)R82!D92!M96[Z(&1E(&]P97)A8VEO;F5S(&1E('1A8FQA/P"_36]S=')A
M<B!E;"!M96[Z("5S(&$@;&$@:7IQ=6EE<F1A/P!-=65S=')A(&5L(&1IX6QO
M9V\@9&4@<')O<&EE9&%D97,@9&4@8V5L9&$@9&4@=&%B;&$`375E<W1R82!E
M;"!D:>%L;V=O(&1E('!R;W!I961A9&5S(&1E('1A8FQA`$UU97-T<F$@96P@
M9&GA;&]G;R!D92!P<F]P:65D861E<R!D92!F:6QA(&1E('1A8FQA`$UU97-T
M<F$@96P@9&GA;&]G;R!D92!P<F]P:65D861E<R!D92!I;6%G96X`36]S=')A
M<B!C87)G80!!9W5A8V5R;W,`3&QU=FEA<R!M871U=&EN87,`3&QU=FEA<R!V
M97-P97)T:6YA<P!!9W5A8V5R;W,@96X@;&$@=F5C:6YD860`4F5D=6-I<@!0
M<FEM97)O(')E9'5Z8V$@;R!Q=6ET92!D92!E;FUE9&EO(&QO<R!B;&]Q=65S
M(&-E<F-A;F]S`%-I97)R82!,96]N80!!;'1A`$9I<FUA`$%L9V]R:71M;R!D
M92!F:7)M80!3:6YG87!U<@!486UA\6\`3VUI=&ER(&UA;G1E;FEM:65N=&\`
M17-L;W9A<75I80!%<VQO=F5N:6$`3FEE=F4`06=U86-E<F\@9&4@;FEE=F4`
M06=U86-E<F\@9&4@;FEE=F4`06=U86-E<F\@9&4@;FEE=F4@;6%T=71I;F\`
M06=U86-E<F\@9&4@;FEE=F4@=F5S<&5R=&EN;P!%<W!E<V]R(&1E(&QA(&YI
M979E.B``17%U:79A;&5N=&4@9&4@;&$@;FEE=F4@96X@86=U83H@`$ES;&%S
M(%-A;&]M\VX`4V]M86QI80!#86YC:6]N97,@)B!0;V5M87,`4V5L96-C:?-N
M(&1E;"!S96YT:61O(&1E(&QA(&-L87-I9FEC86-I\VX`4F5M:71E;G1E`%-U
M9.%F<FEC80!%=7)O<&$@9&5L('-U<B`H25-/+3@X-3DM,RD`1V5O<F=I82!D
M96P@4W5R(&4@27-L87,@4V%N9'=I8V@@9&5L(%-U<@!(96UI<V9E<FEO('-U
M<@!%<W!A8VEA9&\@96YT<F4@8V5L9&%S(&%D>6%C96YT97,`17-P86-I861O
M(&5N=')E(&5L(&-O;G1E;FED;R!Y(&5L(&)O<F1E(&1E('5N82!C96QD80!3
M97!A<F%D;W(`17-P86-I861O`$5S<&%C:6%D;R!Y(&UA<F=E;@!%<W!A\6$`
M4W!A;0!%<V-R:71U<F$@9&4@8V%R86-T97)E<R!E<W!E8VEA;&5S`$1I=FED
M:7(@8V5L9&$`1&EV:61I<B!C;VQU;6YA`$1I=FED:7(@9FEL80!$97!O<G1E
M<P!3<FD@3&%N:V$`17-TX6YD87(`4W1A<B!4<F5K`$'Q;R!D92!I;FEC:6\`
M17-T861O(&\@<')O=FEN8VEA`$5S=&%D;P!&;W)M871O(&1E(&%L;6%C96YA
M;6EE;G1O`$1I<F5C8VGS;B!D92!L82!C86QL90!486-H861A`$QI<W1A(&1E
M(&-A9&5N87,`16QI;6EN87(@9&]M:6YI;R!D92!L82!D:7)E8V-I\VX`17-T
M:6QO(%M#4U-=`$1O;0!.;R!S92!E;F-O;G1R\R!E;"!S=6)D:7)E8W1O<FEO
M("(E<R(N`$%S=6YT;P!%;G9I87(`4V4@:&$@96YV:6%D;R!U;F$@<V]L:6-I
M='5D(&1E(&%L=&$@9&4@(B5S(B!E;B!E;"!S:7-T96UA+B!.;R!P;V1RX2!I
M;FEC:6%R('-E<VGS;B!H87-T82!Q=64@<V4@:&%Y82!A<')O8F%D;R!L82!S
M;VQI8VET=60N`%-U8NUN9&EC90#)>&ET;P!392!H82!A\6%D:61O(&-O<G)E
M8W1A;65N=&4@(B5S(B!A;"!S:7-T96UA+@!392!H86X@96QI;6EN861O(&-O
M<G)E8W1A;65N=&4@;&]S(&1A=&]S(&1E;"!U<W5A<FEO("(E<R(@9&5L('-I
M<W1E;6$N`%-E(&AA(&5L:6UI;F%D;R!C;W)R96-T86UE;G1E("(E<R(N`%-E
M(&AA(&5L:6UI;F%D;R!C;W)R96-T86UE;G1E("(E<R(@9&5L('-I<W1E;6$N
M`%-E(&AA(')E<W1A=7)A9&\@8V]R<F5C=&%M96YT92!L82!C;VYF:6=U<F%C
M:?-N+B!2969R97-Q=64@<&%R82!V97(@;&]S(&-A;6)I;W,N`%-E(&AA(&=U
M87)D861O(&-O<G)E8W1A;65N=&$@;&$@8V]P:6$@9&4@;&$@8V]N9FEG=7)A
M8VGS;BX`4V4@:&$@9W5A<F1A9&\@8V]R<F5C=&%M96YT92!L82!C;W!I82`E
M<R!D92!L82!C;VYF:6=U<F%C:?-N+@!392!H82!A8W1U86QI>F%D;R!C;W)R
M96-T86UE;G1E("(E<R(`4V4@:&$@97-C<FET;R!C;W)R96-T86UE;G1E("<E
M<R<`4W5DX6X`4F5S=6UE;@!!;6%N96-E<@!!=&%R9&5C97(`4V]L96%D;P!!
M;6%N96-E<@!!;6%N96-E<B]!=&%R9&5C97(`06UA;F5C97(Z(`!!=&%R9&5C
M97(`071A<F1E8V5R.B``4W5P97+M;F1I8V4`4V]P;W)T90!3=7)I;F%M`$%P
M96QL:61O`%-V86QB87)D('D@2F%N($UA>65N`%-W87II;&%N9&EA`%-U96-I
M80!3=6EZ80!296=I<W1R;R!D92!S:6YC<F]N:7IA8VGS;B!E;&EM:6YA9&\`
M4WEN8TU,`$5R<F]R(&1E('-I;G1A>&ES(&5N(&QO<R!TZ7)M:6YO<R!D92!B
M^G-Q=65D80!297#Z8FQI8V$@P7)A8F4@9&4@4VER:6$`0VAU8F%S8V\`0F]R
M<F%S8V]S;R!Y('9E;G1O<V\`0F]R<F%S8V%S`$)O<G)A<V-A<R!M871U=&EN
M87,`07)C:&EV;R!44U8`4')O<&EE9&%D97,@9&4@=&%B;&$`5&%B;&$`4')O
M<&EE9&%D97,@9&4@=&%B;&$`5&%I=^%N`%1A:7?A;BP@4')O=FEN8VEA(&1E
M($-H:6YA`%1A>6EK:7-TX6X`5&%N>F%N:6$L(%)E</IB;&EC82!5;FED82!D
M90!$97-T:6YO.@!487)E87,`3OIM97)O(&1E('1E;.EF;VYO`%1E;7!E<F%T
M=7)A(&1U<F%N=&4@;&$@^FQT:6UA(&AO<F$Z(`!496UP97)A='5R80!496UP
M97)A='5R83H@`%1E;7!E<F%T=7)A/&)R("\^*"5S3>%X)7,O)7--[6XE<RD@
M)F1E9SLE<P!.;R!S92!E;F-O;G1R\R!L82!P;&%N=&EL;&$@(B5S(BX`061M
M:6YI<W1R86-I\VX@9&4@<&QA;G1I;&QA<P!497AT;P!3\VQO('1E>'1O`$%L
M:6YE86-I\VX@9&4@=&5X=&\`0F]R9&4@<W5P97)I;W(@9&5L('1E>'1O`$IU
M90!486EL86YDZ7,@*%1)4RTV,C`I`%1A:6QA;F1I80!.;R!E<W3A(&1I<W!O
M;FEB;&4@;&$@97AT96YS:?-N($944"X`16P@<VES=&5M82!H:7-T\W)I8V\@
M97-TX2!D97-H86)I;&ET861O+@!%;"!M;W1O<B!D92!I;G1E9W)A8VGS;B!(
M;W)D92]+;VQA8B!N;R!S;W!O<G1A("(E<R(`3F\@<V4@<'5E9&4@:6YI8VEA
M<B!E;"!R96=I<W1R;R!D92!)35-0+@!.;R!S92!H82!C87)G861O(&-O<G)E
M8W1A;65N=&4@;&$@8VQA<V4@36%I;G1E;F%N8V4Z.@!392!H82!C97)R861O
M(&QA('9E;G1A;F$@9&4@;W!C:6]N97,N(%-A;&EE;F1O+@!3:2!D97-E82!U
M=&EL:7IA<B!P97)M:7-O<RP@96P@861M:6YI<W1R861O<B!T:65N92!Q=64@
M8V]N9FEG=7)A<B!U;B!S;W!O<G1E(&1E('!E<FUI<V]S('!E<FUA;F5N=&4N
M`%/S;&\@96P@8F]R9&4@:6YF97)I;W(`16P@240@9&5L(&-O;G1A8W1O(&YO
M('-E(&5S<&5C:69I8_,L('-E(&1E:O,@96X@8FQA;F-O(&\@;F\@<V4@96YC
M;VYT<O,@96X@;&$@8F%S92!D92!D871O<RX`4V4@:&$@8?%A9&ED;R!C;W)R
M96-T86UE;G1E(&5L(&-O;G1A8W1O(&$@<W5S(&1I<F5C8VEO;F5S+@!087)A
M(&-O;7!R;V)A<B!E;"!M96YS86IE(&9I<FUA9&\@:&%C92!F86QT82!E;"!B
M;&]Q=64@9&4@9FER;6$@<V5P87)A9&\N`$5L($E$(&1E(&QA(&QI<W1A(&1E
M(&1I<W1R:6)U8VGS;B!N;R!S92!E<W!E8VEF:6/S+"!S92!D96KS(&5N(&)L
M86YC;R!O(&YO('-E(&5N8V]N='+S(&5N(&QA(&)A<V4@9&4@9&%T;W,N`$YO
M('-E(&5S<&5C:69I8_,@;&$@;&ES=&$@9&4@9&ES=')I8G5C:?-N+@!,87,@
M8V%R86-T97+M<W1I8V%S(&1E(&-I9G)A9&\@;F5C97-I=&%N('5N82!C;VYE
M>&GS;B!W96(@<V5G=7)A+@!%;"!A<F-H:79O("5S('1E;F1R[6$@<75E(&-O
M;G1E;F5R('5N82!O<&-I\VX@)7,N`$5L(&%R8VAI=F\@)7,@=&5N9'+M82!Q
M=64@8V]N=&5N97(@86QG=6YA<R!O<&-I;VYE<R`E<RX`16P@87)C:&EV;R!N
M;R!C;VYT:65N92!D871O<RX`02!C;VYT:6YU86-I\VX@=&EE;F4@;&%S(&-A
M8F5C97)A<R!D92!E<W1E(&UE;G-A:F4@;65S<V%G92]R9F,X,C(N`%-E('-A
M8F4@<75E(&5L(&UO9&\@9&4@<&%N=&%L;&$@8V]M<&QE=&$@9&$@<')O8FQE
M;6%S(&-O;B!);G1E<FYE="!%>'!L;W)E<B!D96)I9&\@82!F86QL;W,@9&5L
M(&YA=F5G861O<B!Q=64@;F\@:&5M;W,@<&]D:61O('-O<VQA>6%R+B!0=65D
M92!S=69R:7(@=FES=6%L:7IA8VGS;B!D92!B87-U<F$L('#I<F1I9&$@9&4@
M9G5N8VEO;F5S(&1E;"!E9&ET;W(@>2]O(&-U96QG=65S(&%L96%T;W)I;W,@
M9&5L(&YA=F5G861O<BX@4VD@<W4@<VES=&5M82!O<&5R871I=F\@97,@5VEN
M9&]W<R`Y>"P@97,@;75Y('!R;V)A8FQE('%U92!S=69R82!U;B!F86QL;R!D
M92!P<F]T96-C:?-N(&=E;F5R86P@>2!T96YG82!Q=64@<F5I;FEC:6%R(&5L
M(&5Q=6EP;RY<;EQN66$@97-TX2!A=FES861O+B!0=6QS92!!8V5P=&%R('-I
M(&'Z;B!D97-E82!P<F]B87(@96P@961I=&]R(&5N(&UO9&\@9&4@<&%N=&%L
M;&$@8V]M<&QE=&$N`%-E(&AA(&5L:6UI;F%D;R!L82!I9&5N=&ED860@(B5S
M(BX`4_-L;R!E;"!B;W)D92!I>G%U:65R9&\`2&%Y('%U92!I;F1I8V%R;&4@
M82!L82!C;&%S92!#<GEP=%]P9W`Z.B!L82!U8FEC86-I\VX@9&4@;&]S(&)I
M;F%R:6]S($=N=5!'+@!392!H82!M;W-T<F%D;R!E;"!M96YS86IE(&5N=FEA
M9&\@96P@)7,@82`E<R!C;VX@96P@87-U;G1O("(E<R(N"LES=&\@;F\@9V%R
M86YT:7IA('%U92!E;"!M96YS86IE(&AA>6$@<VED;R!L96ED;R!O(&-O;7!R
M96YD:61O+@!.;VUB<F4@=71I;&EZ861O(&%L('9I;F-U;&%R(&$@;&$@<.%G
M:6YA(&1E(&-O;7!O<VEC:?-N`$5L(&[Z;65R;R!D92!C86UP;W,@=&EE;F4@
M<75E('-E<B!U;B!N^FUE<F\N`$AA8V4@9F%L=&$@96P@;?-D=6QO(&]P96YS
M<VP@<&%R82!L82!C;&%S92!(;W)D95]#<GEP=%]S;6EM93HZ+@!.;R!S92!P
M=65D92!G=6%R9&%R(&QA('!R969E<F5N8VEA("(E<R(@<&]R<75E('-U<R!D
M871O<R!S;V)R97!A<V%N(&5L('1A;6'Q;R!MX7AI;6\@<&5R;6ET:61O`$YO
M('-E(&5N8V]N='+S(&5N(&5L('-I<W1E;6$@96P@<')O9W)A;6$@<&%R82!V
M97(@97-T92!T:7!O(&1E(&1A=&]S("@E<RDN`$5L(&-A<N%C=&5R(&1E(&-I
M=&$@9&5B92!S97(@<V5R('/S;&\@=6YO+@!3\VQO(&QO<R!L861O<R!I>G%U
M:65R9&\@>2!D97)E8VAO`%/S;&\@96P@;&%D;R!D97)E8VAO`$5L('-E<&%R
M861O<B!D96)E('-E<B!S\VQO('5N;RX`4V4@:&$@96QI;6EN861O(&5L('-E
M<G9I9&]R("(E<R(N`%-E(&AA(&=U87)D861O(&5L('-E<G9I9&]R("(E<R(N
M`%-E(&AA(&5L:6UI;F%D;R!L82!S;VQI8VET=60@9&4@86QT82!D92`E<RX`
M3&$@9FEL82!E<W!E8VEF:6-A9&$@*"5D*2!N;R!E>&ES=&4N`$5L(&%R8VAI
M=F\@=&5M<&]R86P@(B5S(B!N;R!E>&ES=&4N`$5L('1E>'1O('%U92!H82!I
M;G1R;V1U8VED;R!N;R!C;VEN8VED92!C;VX@96P@9&4@;&$@<&%N=&%L;&$N
M`%/S;&\@;&]S(&QA9&]S('-U<&5R:6]R(&4@:6YF97)I;W(`4_-L;R!E;"!L
M861O('-U<&5R:6]R`%-E('!E<F1I97)O;B!L;W,@9&%T;W,@8V%R9V%D;W,@
M9&5S9&4@96P@<&%S;R!A;G1E<FEO<BX`3F\@<V4@<'5D;R!G=6%R9&%R(&5L
M(&%R8VAI=F\@8V%R9V%D;RX`3F\@97-TX2!D:7-P;VYI8FQE(&5L(&)L;W%U
M92!D92!W96%T:&5R+F-O;2X`3F\@<V4@96YC;VYT<O,@96P@9&ER96-T;W)I
M;R!D92!496UA<R`B)7,B+@!.;R!S92!D:7-P;VYE(&1E(&]P8VEO;F5S+@!.
M;R!H87D@<&%R=&5S('%U92!S92!P=65D86X@;6]S=')A<B!E;B!L[6YE82X`
M16X@97-T92!C86UP;R!H87D@9&5M87-I861O<R!C87)A8W1E<F5S+B!(82!I
M;G1R;V1U8VED;R`E<R!C87)A8W1E<F5S('D@=&EE;F4@<75E(&EN=')O9'5C
M:7(@;65N;W,@9&4@)7,N`%-E('!R;V1U:F\@=6X@<')O8FQE;6$@86P@8?%A
M9&ER(&$@(B5S(B!A;"!S:7-T96UA.B`E<P!392!P<F]D=6IO('5N('!R;V)L
M96UA(&%L(&)O<G)A<B!L;W,@9&%T;W,@9&5L('5S=6%R:6\@(B5S(B!D96P@
M<VES=&5M83H@`%-E('!R;V1U:F\@=6X@<')O8FQE;6$@86P@96QI;6EN87(@
M82`B)7,B(&1E;"!S:7-T96UA.B``4V4@<')O9'5J;R!U;B!P<F]B;&5M82!A
M;"!A8W1U86QI>F%R("(E<R(Z("5S`%-E('!R;V1U:F\@=6X@<')O8FQE;6$@
M8V]N(&QA(&-A<F=A(&1E;"!A<F-H:79O.B!.;R!S92!C87)G\R`E<RX`4V4@
M<')O9'5J;R!U;B!P<F]B;&5M82!C;VX@;&$@8V%R9V$@9&5L(&%R8VAI=F\N
M($5L("5S(&5R82!MX7,@9W)A;F1E('%U92!E;"!T86UA\6\@;>%X:6UO('!E
M<FUI=&ED;R`H)60@8GET97,I+@!392!P<F]D=6IO('5N('!R;V)L96UA(&-O
M;B!L82!C87)G82!D96P@87)C:&EV;RX@4_-L;R!S92!C87)G\R!P87)C:6%L
M;65N=&4@96P@)7,N`%-E('!R;V1U:F\@=6X@97)R;W(@86P@;6]S=')A<B!E
M<W1A('!A<G1E(&1E;"!M96YS86IE`%-E('!R;V1U:F\@=6X@97)R;W(@86P@
M:6UP;W)T87(@;&]S(&1A=&]S(&1E;"!C;VYT86-T;RX`4V4@<')O9'5J;R!U
M;B!E<G)O<B!A;"!I;7!O<G1A<B!L;W,@9&%T;W,@:4-A;&5N9&%R+@!392!P
M<F]D=6IO('5N(&5R<F]R(&5N(&5L(&9O<FUU;&%R:6\@9&4@8V]N9FEG=7)A
M8VGS;BX@4'5E9&4@<75E(&AA>6$@;VQV:61A9&\@<F5L;&5N87(@=6X@8V%M
M<&\@;F5C97-A<FEO+@!392!P<F]D=6IO('5N(&5R<F]R(&%L(&5J96-U=&%R
M(&QA(&9U;F-I\VX@97-P96-I9FEC861A(&1E(&QA(&QI8G)E=&$@9&4@9&ER
M96-C:6]N97,N(%9U96QV82!A('!R;V)A<B!MX7,@861E;&%N=&4N`%-E('!R
M;V1U:F\@=6X@97)R;W(@86P@86-T=6%L:7IA<B!L;W,@9&5T86QL97,@9&5L
M(&-O;G1A8W1O+B!6=65L=F$@82!P<F]B87(@;>%S(&%D96QA;G1E+@!392!P
M<F]D=6IO('5N(&5R<F]R(&%L(&%C='5A;&EZ87(@;&$@;&ES=&$@9&4@9&ES
M=')I8G5C:?-N+B!6=65L=F$@82!P<F]B87(@;>%S(&%D96QA;G1E+@!%<W1E
M('-E<G9I9&]R($E-05`@;F\@<V]P;W)T82!L87,@8V%R<&5T87,@8V]M<&%R
M=&ED87,N`,ES=&4@;F\@<&%R96-E('-E<B!U;B!A<F-H:79O(')A<B!VX6QI
M9&\N`,ES=&4@;F\@<&%R96-E('-E<B!U;B!A<F-H:79O('II<"!VX6QI9&\N
M`,ES=&4@;F\@<&%R96-E('-E<B!U;B!N^FUE<F\@9&4@=&%R:F5T82!VX6QI
M9&\N`$5S=&4@8V]N=')O;&%D;W(@<&5R;6ET92!E;G9I87(@;65N<V%J97,@
M82!T<F%VZ7,@9&4@;&$@<&%S87)E;&$@0VQI8VMA=&5L;"`H:'1T<#HO+V-L
M:6-K871E;&PN8V]M*2P@;65D:6%N=&4@;&$@05!)($A45%``17-T92!C;VYT
M<F]L861O<B!P97)M:71E(&5N=FEA<B!M96YS86IE<R!A('1R87;I<R!D92!L
M82!P87-A<F5L82!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2P@;65D:6%N=&4@
M;&$@05!)($A45%``17-T92!C;VYT<F]L861O<B!P97)M:71E(&5N=FEA<B!M
M96YS86IE<R!A('1R87;I<R!D92!L82!P87-A<F5L82!S;7,R96UA:6P@*&AT
M='`Z+R]S;7,R96UA:6PN8V]M*2P@;65D:6%N=&4@;&$@05!)($A45%``17-T
M92!C;VYT<F]L861O<B!P97)M:71E(&5N=FEA<B!M96YS86IE<R!V:6$@4TU4
M4"!A('1R87;I<R!D92!L82!P87-A<F5L82!D92!6;V1A9F]N92!D92!)=&%L
M:6$L('/S;&\@82!N^FUE<F]S(%9O9&%F;VYE+B!(86-E(&9A;'1A('5N82!C
M=65N=&$@9&4@8V]R<F5O(&1E(%9O9&%F;VYE(&1E($ET86QI82`H:'1T<#HO
M+W=W=RXQ.3`N:70I+@!(86-E(&9A;'1A(&5S=&4@8V%M<&\N`$5S=&4@8V%M
M<&\@<_-L;R!P=65D92!C;VYT96YE<B!E;G1E<F]S+@!%<W1E(&-A;7!O('/S
M;&\@<'5E9&4@8V]N=&5N97(@;OIM97)O<R!Y(&QO<R!D;W,@<'5N=&]S+@!%
M<W1E(&-A;7!O('/S;&\@<'5E9&4@8V]N=&5N97(@=F%L;W)E<R!O8W1A;&5S
M+@!%<W1E(&-A;7!O('1I96YE('%U92!S97(@=6YA(&QI<W1A(&1E(&5N=&5R
M;W,@<V5P87)A9&]S('!O<B!C;VUA<R!O(&5S<&%C:6]S+@!%<W1E(&-A;7!O
M('1I96YE('%U92!S97(@=6X@;OIM97)O(';A;&ED;RX`17-T92!C86UP;R!T
M:65N92!Q=64@8V]N=&5N97(@=6X@8_-D:69O(&1E(&-O;&]R(&5N(&9O<FUA
M=&\@4D="($AE>&%D96-I;6%L+"!P;W(@96IE;7!L;R`G(S$R,S1A9B<N`%EA
M('-E(&AA('!R;V-E<V%D;R!E<W1E(&9O<FUU;&%R:6\N`$5S=&\@97,@)7,N
M`,ES=&\@97,@=6X@;V)J971O(&1E($MO;&%B($=R;W5P=V%R92X@4&%R82!V
M97)L;R!N96-E<VET82!U;B!C;&EE;G1E(&1E(&-O<G)E;R`@<75E(&5N=&EE
M;F1A(&5L(&9O<FUA=&\@2V]L86(@1W)O=7!W87)E+B!087)A('9E<B!U;F$@
M;&ES=&$@9&4@9&EC:&]S(&-L:65N=&5S('9I<VET92`E<P!%<W1E(&UE;G-A
M:F4@<V4@97-C<FEB:?,@8V]N('5N(&IU96=O(&1E(&-A<F%C=&5R97,@*"5S
M*2!D:7-T:6YT;R!A;"!S=7EO+@!%<W1E(&[Z;65R;R!D96)E('-E<B!P;W(@
M;&\@;65N;W,@=6X@=6YO+@!%<W1E('-E<G9I9&]R(&YO('!U961E(&1E<V-O
M;7!R:6UI<B!A<F-H:79O<R!Z:7`@>2!G>FEP+@!%<W1E('-I<W1E;6$@86-T
M=6%L;65N=&4@97-TX2!D97-A8W1I=F%D;RX`17-T92!V86QO<B!T:65N92!Q
M=64@<V5R('5N(&[Z;65R;RX`17-T82!V96YT86YA('/S;&\@<'5E9&4@86)R
M:7)S92!D97-D92!U;F$@=F5N=&%N82!D92!O<&-I;VYE<P!4<G5E;F\`26YC
M:61E;F-I87,`2&]R80!#+B!T:65M<&]S`$9O<FUA=&\@:&]R87)I;P!396QE
M8V-I\VX@9&4@:&]R80!4:6UO<BU,97-T90!4[71U;&\`5.UT=6QO("AC;VYS
M96IO*3H`4&%R80!087)A('-E;&5C8VEO;F%R('9A<FEO<R!C86UP;W,L(&UA
M;G1E;F=A('!U;'-A9&$@;&$@=&5C;&$@0V]N=')O;"`H4$,I(&\@0V]M86YD
M;R`H36%C*2!A;"!H86-E<B!C;&EC:RX`2&]Y`$-O;FUU=&%R(&]R:6=E;B!(
M5$U,`%1O9V\`5&]K96QA=0!-8?%A;F$`5&]N9V$`1&5M87-I861O<R!I;G1E
M;G1O<R!F86QL:61O<R!E;B!L;W,@^FQT:6UO<R!M:6YU=&]S+@!3=7!E<FEO
M<@!&<F%M92!S=7!E<FEO<B`H7W1O<"D`5')A9'5C8VEO;F5S`%1R:6YI9&%D
M('D@5&]B86=O`%9E<F1A9&5R;R!O(&9A;'-O`$UA<@!4^FYE>@!4=7)Q=>UA
M`%1U<F-O("A)4T\M.#@U.2TY*0!4=7)K;65N:7-TX6X`27-L87,@5'5R:W,@
M>2!#86EC;W,`5'5V86QU`$5S8W)I8F$@<W4@96QE8V-I\VXZ(`#-;F1I8V4@
M52Y6+CH@`%523`!54DP@9&4@<W4@:6YF;W)M92!D92!E<W1A9&\@9&4@96YV
M[6\@9&5L(&=U:?-N`%523#H`56=A;F1A`%5C<F%N:6$`26YC87!A>B!D92!A
M8V-E9&5R(&%L(&1I<F5C=&]R:6\@5D93+@!);F-A<&%Z(&1E(&'Q861I<B!I
M;F9O<FUA8VGS;B!D92!U<W5A<FEO(&%D:6-I;VYA;"!A;"!R96%L:7IA<B!E
M;"!A;'1A+@!);F-A<&%Z(&1E(&-A;6)I87(@;&]S('!R:79I;&5G:6]S(&1E
M;"!A<F-H:79O(%9&4R`B)7,B+@!);F-A<&%Z(&1E(&-A;6)I87(@;&]S('!R
M:79I;&5G:6]S(&1E;"!A<F-H:79O(%9&4R`E<R\E<RX`26YC87!A>B!D92!C
M86UB:6%R(&$@)7,N`$EN8V%P87H@9&4@8V]M<')O8F%R(&5L('1A;6'Q;R!D
M92`B)7,B+@!);F-A<&%Z(&1E(&-O;7!R;V)A<B!E;"!T86UA\6\@9&4@(B5S
M+R5S(BX`26YC87!A>B!D92!C;VYE8W1A<G-E(&%L('-E<G9I9&]R(%-13"X`
M26YC87!A>B!D92!C;VYE8W1A<B!C;VX@4U-,+@!);F-A<&%Z(&1E(&-O<&EA
M<B!E;"!A<F-H:79O(%9&4RX`26YC87!A>B!D92!C<F5A<B!E;"!D:7)E8W1O
M<FEO(%9&4R`B)7,B+@!);F-A<&%Z(&1E(&-R96%R(&5L(&1I<F5C=&]R:6\@
M5D93+@!);F-A<&%Z(&1E(&-R96%R(&5L(&%R8VAI=F\@5D93+@!);F-A<&%Z
M(&1E(&-R96%R(&QA(&-A<G!E=&$@5D93("(E<R(`26YC87!A>B!D92!C<F5A
M<B!U;B!A<F-H:79O(%9&4R!V86/M;RX`26YC87!A>B!D92!D97-C;VUP<FEM
M:7(@;&]S(&1A=&]S+@!);F-A<&%Z(&1E(&5L:6UI;F%R("(E<R(L(&5L(&1I
M<F5C=&]R:6\@;F\@97-TX2!V86/M;RX`26YC87!A>B!D92!E;&EM:6YA<B`B
M)7,B.B`E<RX`26YC87!A>B!D92!E;&EM:6YA<B`E<RP@96P@9&ER96-T;W)I
M;R!N;R!E<W3A('9A8^UO`$EN8V%P87H@9&4@96QI;6EN87(@96P@9&ER96-T
M;W)I;R!61E,@9&4@9F]R;6$@<F5C=7)S:79A+@!);F-A<&%Z(&1E(&5L:6UI
M;F%R(&5L(&1I<F5C=&]R:6\@5D93+@!);F-A<&%Z(&1E(&5L:6UI;F%R(&5L
M(&1I<F5C=&]R:6\@5D93.B`E<RX`26YC87!A>B!D92!E;&EM:6YA<B!E;"!A
M<F-H:79O(%9&4R`B)7,B+@!);F-A<&%Z(&1E(&5L:6UI;F%R(&5L(&%R8VAI
M=F\@5D93+@!);F-A<&%Z(&1E(&5L:6UI;F%R(&QA(&-A<G!E=&$@5D93("(E
M<R(N`$EN8V%P87H@9&4@96QI;6EN87(@96P@5D93(&1E(&9O<FUA(')E8W5R
M<VEV83H@)7,N`$EN8V%P87H@9&4@9&5T97)M:6YA<B!E;"!D:7)E8W1O<FEO
M(&%C='5A;"X`26YC87!A>B!D92!E>'1R865R(&QO<R!D971A;&QE<R!D96P@
M8V5R=&EF:6-A9&\N`$EN8V%P87H@9&4@8V%R9V%R(&QA(&1E9FEN:6-I\VX@
M9&4@)7,N`$EN8V%P87H@9&4@=')A<VQA9&%R(&5L(&%R8VAI=F\@5D93+@!)
M;F-A<&%Z(&1E(&%B<FER(&5L(&%R8VAI=F\@5D93("(E<R(N`$EN8V%P87H@
M9&4@86)R:7(@96P@87)C:&EV;R!61E,@<&%R82!E<V-R:6)I<BX`26YC87!A
M>B!D92!A8G)I<B!E;"!A<F-H:79O(%9&4RX`26YC87!A>B!D92!A8G)I<B!E
M;"!A<F-H:79O(&-O;7!R:6UI9&\N`$EN8V%P87H@9&4@;&5E<B!U;B!A<F-H
M:79O(%9&4R`H:&$@9F%L;&%D;R!F:6QE<VEZ92@I*2X`26YC87!A>B!D92!L
M965R('5N(&%R8VAI=F\@5D93("AH82!F86QL861O(&=E=$9I;&53:7IE*"DI
M+@!);F-A<&%Z(&1E(&QE97(@=6X@87)C:&EV;SH@`$EN8V%P87H@9&4@;&5E
M<B!E;"!D:7)E8W1O<FEO('9F<W)O;W0N`$EN8V%P87H@9&4@<F5N;VUB<F%R
M("5S(&-O;6\@)7,Z(&QA(&-A<G!E=&$@9&5S=&EN;R!Y82!E>&ES=&4`26YC
M87!A>B!D92!R96YO;6)R87(@96P@9&ER96-T;W)I;R!61E,N`$EN8V%P87H@
M9&4@<F5N;VUB<F%R(&5L(&1I<F5C=&]R:6\@5D93.B`E<RX`26YC87!A>B!D
M92!R96YO;6)R87(@96P@87)C:&EV;R!61E,@(B5S(@!);F-A<&%Z(&1E(')E
M;F]M8G)A<B!E;"!A<F-H:79O(%9&4R`E<R\E<RX`26YC87!A>B!D92!R96YO
M;6)R87(@96P@87)C:&EV;R!61E,N`$EN8V%P87H@9&4@96IE8W5T87(@)VUK
M:7-O9G,G+@!.;R!S92!P=65D92!A8W1I=F%R(&QA(&%C='5A;&EZ86-I\VX@
M9&4@:6YF;W)M86-I\VX@9&4@=&EE;7!O(&1I<W!O;FEB;&4@9&4@)7,`26YC
M87!A>B!D92!E<V-R:6)I<B!E;"!A<F-H:79O(%9&4R`B)7,B+@!);F-A<&%Z
M(&1E(&5S8W)I8FER('5N(&%R8VAI=F\@5D93("AH82!F86QL861O(&-O<'DH
M*2DN`$EN8V%P87H@9&4@97-C<FEB:7(@;&]S(&1A=&]S(&1E;"!A<F-H:79O
M(%9&4RX`26YC87!A>B!D92!E<V-R:6)I<B!U;B!A<F-H:79O(%9&4RP@<V4@
M<W5P97)A<N$@;&$@<75O=&$N`%-U8G)A>6%D80!$97-H86-E<B!C86UB:6]S
M`$1E<VAA8V4@;&$@^FQT:6UA(&%C8VGS;@!297-P=65S=&$@:6YE<W!E<F%D
M82!D96P@<V5R=FED;W(@96X@;&$@8V]N97AI\VXZ(`!297-P=65S=&$@:6YE
M<W!E<F%D82!D96P@<V5R=FED;W(@83H@`%-I;B!C871E9V]R[6$`56YI8V]D
M92`H551&+3@I`$5M:7)A=&]S(,%R86)E<R!5;FED;W,`26YG;&%T97)R80!%
M<W1A9&]S(%5N:61O<P!%<W1A9&]S(%5N:61O<R!M96YO<R!L87,@:7-L87,@
M<&5R:6;I<FEC87,`56YI9&%D97,`1&5S8V]N;V-I9&\`07!I;7-G:60@9&5S
M8V]N;V-I9&\@*$E$(&1E(&UE;G-A:F4@9&4@;&$@05!)*2X`0VQI;7-G:60@
M9&5S8V]N;V-I9&\@*$E$(&1E(&UE;G-A:F4@9&5L(&-L:65N=&4I+@!392!H
M82!D969I;FED;R!U;F$@=6)I8V%C:?-N(&1E<V-O;F]C:61A+@!5<W5A<FEO
M(&\@8V]N=')A<V7Q82!D97-C;VYO8VED;W,N`$5L:6UI;F%R(';M;F-U;&\@
M9&5L(&5L96UE;G1O(&%C='5A;`!3:6X@;F]M8G)E`$QO<R!G=6EO;F5S('-I
M;B!P<FEV:6QE9VEO<R!N;R!P=65D96X@86-C961E<B!D92!F;W)M82!P<F]G
M<F%MX71I8V$@82!#;W)T87(O0V]P:6%R+U!E9V%R('!O<B!R87IO;F5S(&1E
M('-E9W5R:61A9"X@4'5L<V4@06-E<'1A<B!P87)A('9E<B!E;B!M;WII;&QA
M+F]R9R!U;F$@;F]T82!TZ6-N:6-A('%U92!L92!M=65S=')E(&/S;6\@<&5R
M;6ET:7(@<75E('5N(&=U:?-N(&%C8V5D82!A;"!P;W)T87!A<&5L97,N`$%N
M=6QA<B!C;VQO<@!%>'1E;G-I\VX@;F\@<V]P;W)T861A`$%C='5A;&EZ87(`
M06-T=6%L:7IA<B`E<P!!8W1U86QI>F%R('5S=6%R:6\`4V4@:&$@86-T=6%L
M:7IA9&\@(B5S(BX`4V4@:&$@96QI;6EN861O(&5L(&=U:?-N(&1E(&%C='5A
M;&EZ86-I\VXN`$-A<F=A<@!392!H86X@8V%R9V%D;R!E;B!E;"!S97)V:61O
M<B!T;V1O<R!L;W,@87)C:&EV;W,@9&4@8V]N9FEG=7)A8VGS;B!D92!A<&QI
M8V%C:6]N97,N`$%L9F%B971O(&QA=&EN;R!E;B!M87GZ<V,N`$[Z;65R;W,@
M<F]M86YO<R!E;B!M87GZ<V,N`%5R=6=U87D`57-A<B!A8W1U86PZ("5S`%5S
M87(@4U-,`%-E('5S82!S:2!E;"!U<W5A<FEO+V-O;G1R87-E\6$@<V]N(&1I
M<W1I;G1O<R!E;B!E;"!S97)V:61O<B!)35-0+@!5<W5A<FEO`$5L('5S=6%R
M:6\@)7,@8V%R96-E(&1E(&%U=&]R:7IA8VGS;B!P87)A("5S+@!!9&UI;FES
M=')A8VGS;B!D92!U<W5A<FEO<P!/<&-I;VYE<R!D92!U<W5A<FEO`%)E9VES
M=')O(&1E('5S=6%R:6]S`$5S=&$@<V5D92!T:65N92!D97-A8W1I=F%D;R!E
M;"!R96=I<W1R;R!D92!U<W5A<FEO<RX`3F\@<V4@:&$@96YC;VYT<F%D;R!L
M82!I9&5N=&ED860`57-U87)I;P!982!E>&ES=&4@96P@;F]M8G)E(&1E('5S
M=6%R:6\@(B5S(BX`57-U87)I;SH`57-U87)I;SH@`%5S=6%R:6]S(&5N(&5L
M('-I<W1E;6$Z`%5Z8F5K:7-TX6X`3F\@97AI<W1E(&5L(&1I<F5C=&]R:6\@
M5D93+@!!=7-E;F-I80!,87,@=6)I8V%C:6]N97,@=N%L:61A<R!E;F-O;G1R
M861A<R!I;F-L=7EE;CH@`%9A;&ED97H`5F%L;W(@96X@;6EN=71O<R!A('!A
M<G1I<B!D92!A:&]R82X`16P@=F%L;W(@97AC961E(&5L('1A;6'Q;R!MX7AI
M;6\@9&4@)7,N`%9A;&]R97,`5F%L;W)E<R!A('-E;&5C8VEO;F%R`%9A;G5A
M='4`5F%R:6%B;&4`5F5N97IU96QA`$AA(&9A;&QA9&\@;&$@8V]M<')O8F%C
M:?-N("T@97-T92!M96YS86IE('!U961E(&AA8F5R<V4@9F]R>F%D;RX`5F5R
M<VGS;@!#+B!V97)S:6]N97,`06QI;F5A8VGS;B!V97)T:6-A;`!-87)G96X@
M=F5R=&EC86P`5F5R=&EC86PZ`$UU>2!A;'1A`%9I971N86T`5FEE=&YA;6ET
M82`H5DE30TE)*0!697(@)7,`5F5R('5N82!PX6=I;F$@=V5B(&5X=&5R;F$`
M5F5R(&-O;6\@)7,`27-L87,@5NUR9V5N97,L($)R:73A;FEC87,`27-L87,@
M5NUR9V5N97,L(%4N4RX`5FES:6)I;&ED860`5FES:6)I;&ED860Z(`!6;V1A
M9F]N92!D92!)=&%L:6$@;65D:6%N=&4@4TU44`!!5DE33P"AH:%!1%9%4E1%
M3D-)02$A(2!%3$E-24Y%($U!3E5!3$U%3E1%($5,($=52=-.($1%("5S+@!7
M24X@<&]R($A45%``5V%L;&ES('D@1G5T=6YA`$%D=F5R=&5N8VEA`$UI90!0
M<F5V:7-I\VX@9&5L('1I96UP;P!$871O<R!D96P@=&EE;7!O('-U;6EN:7-T
M<F%D;W,@<&]R`%=E871H97(N8V]M`%=E8@!3961E(%=E8@!396UA;F%L;65N
M=&4`0FEE;G9E;FED;P!":65N=F5N:61O<R!A("5S`$)I96YV96YI9&\L("5S
M`$]E<W1E("A)4T\M.#@U.2TQ*0!/97-T92`H25-/+3@X-3DM,34I`%/A:&%R
M82!/8V-I9&5N=&%L`+]1=>D@87!L:6-A8VGS;B!D96)E<NUA(&UO<W1R87(@
M)7,@86P@:6YI8VEA<B!L82!S97-I\VX_`+]#=>%L(&5S(&5L(&-A<N%C=&5R
M(&1E;&EM:71A9&]R/P"_0W7A;"!E<R!E;"!C87+A8W1E<B!D92!C:71A9&\_
M`$UA<&$@9&4@;&]C86QI>F%C:?-N(&1E($%U<W1R86QI80!1=>D@9F%S97,`
M4&QU9VEN<R!H86)I;&ET861O<R!D96P@961I=&]R(&1E('1E>'1O(&5N<FEQ
M=65C:61O+@!!;F-H=7)A`$%N8VAU<F$@96X@=6YI9&%D97,@0U-3`$%N8VAU
M<F$@9&5L(&UE;OH@)7,@:7IQ=6EE<F1O("AD:7-P;VYI8FQE(&5N(&QA('!R
M\WAI;6$@<V5S:?-N*3H`06YC:'5R82!D92!L82!T86)L80!5;FED861E<R!D
M92!A;F-H=7)A`$%N8VAU<F$Z`%=I:VD`5FEE;G1O`%9I96YT;R!M871U=&EN
M80!696QO8VED860@9&5L('9I96YT;R!E;B!N=61O<P!6:65N=&\Z`%9I96YT
M;SH@`%-A8FED=7+M80!$97-E;W,`16UP;&5O`$1I<F5C8VGS;B!D96P@=')A
M8F%J;P!496SI9F]N;R!D96P@=')A8F%J;P!.^FUE<F\@97)R\VYE;R!D92!C
M86UP;W,@96X@;&$@;.UN96$@)60N(%-E(&5S<&5R86)A;B`E9"!Y(&AA>2`E
M9"X`3OIM97)O(&5R<O-N96\@9&4@8V%M<&]S+B!392!E<W!E<F%B86X@)60@
M>2!H87D@)60N`$]F9G-E="`E9"!E<G+S;F5O(&%L(&QE97(@=6X@87)C:&EV
M;R!61E,N`%@M4F5F`$QI;6ET86-I;VYE<R!BX7-I8V%S(%@U,#EV,P!5<V\@
M9&4@8VQA=F4@97AT96YD:61A(%@U,#EV,P!.;VUB<F4@86QT97)N871I=F\@
M9&4@87-U;G1O(%@U,#EV,P!)9&5N=&EF:6-A9&]R(&1E(&-L879E(&1E(&%S
M=6YT;R!8-3`Y=C,`17AT96YS:6]N97,@6#4P.78S`$%!`$%!04$`H4UA<&$@
M9&4@66%H;V\A`$%N=6%L;65N=&4`665M96X`4^T`4^TL(&QO(&%C97!T;P!%
M<W3A(&5N($U/1$\@5$585$\N(%5T:6QI8V4@96P@8F]T\VX@6SP^72!P87)A
M(')E9W)E<V%R(&%L(&UO9&\@5UE325=91RX`3F\@9&ES<&]N92!D92!P<FEV
M:6QE9VEO<R!P87)A(&-R96%R(&WA<R!D92`E9"!B;&]Q=65S+@!.;R!E<W3A
M(&%U=&5N=&EF:6-A9&\N`$YO('!U961E(&EN8VQU:7(@96P@8V%RX6-T97(@
M(EPB(&5N(&5L(&YO;6)R92!C;VUP;&5T;RX`3F\@:6YT<F]D=6IO('5N82!D
M:7)E8V-I\VX@9&4@8V]R<F5O(';A;&ED82X`3F\@87-O8VGS(&YI;F=U;F\@
M9&4@;&]S(&-A;7!O<R!D96P@87)C:&EV;R!I;7!O<G1A9&\@82!L;W,@8V%M
M<&]S(&-O<G)E<W!O;F1I96YT97,@9&4@)7,N`$AA('-A;&ED;R!D92!L82!S
M97-I\VXN`%1I96YE('%U92!I;G1R;V1U8VER('5N(&[Z;65R;R!D92!T96SI
M9F]N;R!M\W9I;"!VX6QI9&\L('/S;&\@9.UG:71O<R!C;VX@=6X@)RLG(&]P
M8VEO;F%L('!A<F$@96P@<')E9FEJ;R!D92!L;&%M861A(&EN=&5R;F%C:6]N
M86PN`%1I96YE('%U92!I;G1R;V1U8VER('5N('9A;&]R(';A;&ED;RX`4&%R
M82!U<V%R($%L=&%S('1I96YE('%U92!C;VYF:6=U<F%R('5N(&UO=&]R(&1E
M($1A=&%4<F5E+@!4:65N92!Q=64@8V]N9FEG=7)A<B!U;B!M;W1O<B!61E,N
M`$1E8F4@9&5S8W)I8FER(&5L('!R;V)L96UA(&%N=&5S(&1E(&5N=FEA<B!E
M;"!I;F9O<FUE+@!4:65N92!Q=64@:6YT<F]D=6-I<B!L82!54DP@82!L82!Q
M=64@87!U;G1A(&5S=&4@=NUN8W5L;P!4:65N92!Q=64@<V5L96-C:6]N87(@
M=6X@<V5R=FED;W(@82!E;&EM:6YA<BX`5&EE;F4@<75E(&5S<&5C:69I8V%R
M('5N('5S=6%R:6\@82!E;&EM:6YA<BX`5&EE;F4@<75E(&5S<&5C:69I8V%R
M('5N('5S=6%R:6\@82!E;&EM:6YA<BX`5&EE;F4@<75E(&5S<&5C:69I8V%R
M(&5L('5S=6%R:6\@82!A\6%D:7(N`%1I96YE('%U92!E<W!E8VEF:6-A<B!E
M;"!U<W5A<FEO(&$@86-T=6%L:7IA<BX`5&EE;F4@<75E(&5S<&5C:69I8V%R
M('%UZ2!A8V-I\VX@<V4@96IE8W5T87+A+@!4:65N92!Q=64@:6YT<F]D=6-I
M<B!U;B!N=65V;R!N;VUB<F4@9&4@8V%T96=O<NUA+@!4:65N92!Q=64@:6YT
M<F]D=6-I<B!U;B!N^FUE<F\@9&4@=&5LZ69O;F\@:71A;&EA;F\`2&$@97AP
M:7)A9&\@<W4@<V5S:?-N("5S+B!6=65L=F$@82!I;FEC:6%R('-E<VGS;BX`
M4W4@9&ER96-C:?-N(&1E(&-O<G)E;P!$:7)E8V-I\VX@1&4Z`%-U(&EN9F]R
M;6%C:?-N`$AA(&-A;6)I861O('-U(&1I<F5C8VGS;B!D92!);G1E<FYE="!D
M97-D92!E;"!C;VUI96YZ;R!D92!S=2!S97-I\VX@)7,N(%!O<B!R87IO;F5S
M(&1E('-E9W5R:61A9"!T:65N92!Q=64@=F]L=F5R(&$@:6YI8VEA<B!L82!S
M97-I\VXN`%-U(&YO;6)R90!3=2!M;W1O<B!D92!A=71E;G1I9FEC86-I\VX@
M;F\@<&5R;6ET92!A\6%D:7(@=7-U87)I;W,N(%-I('%U:7-I97)A('5S87(@
M2&]R9&4@<&%R82!A9&UI;FES=')A<B!C=65N=&%S(&1E('5S=6%R:6\L('1E
M;F1RX2!Q=64@=71I;&EZ87(@=6X@;6]T;W(@9&4@875T96YT:69I8V%C:?-N
M(&1I<W1I;G1O+@!3=2!M;W1O<B!D92!A=71E;G1I9FEC86-I\VX@;F\@<&5R
M;6ET92!L:7-T87(@=7-U87)I;W,L(&\@<V4@:&$@9&5S:&%B:6QI=&%D;R!L
M82!C87)A8W1E<NUS=&EC82!P;W(@86QG^FX@;6]T:79O+@!087)E8V4@<75E
M(&AA(&-A;6)I861O('-U(&YA=F5G861O<B!D97-D92!E;"!C;VUI96YZ;R!D
M92!S=2!S97-I\VX@)7,N(%!O<B!R87IO;F5S(&1E('-E9W5R:61A9"!T:65N
M92!Q=64@=F]L=F5R(&$@:6YI8VEA<B!L82!S97-I\VXN`%-U(&YA=F5G861O
M<B!N;R!A9&UI=&4@97-T82!C87)A8W1E<NUS=&EC82X`16P@;F%V96=A9&]R
M(&YO(&%D;6ET92!E<W1A(&]P8VGS;B!D92!I;7!R97-I\VXN(%!R97-I;VYE
M($-O;G1R;VPO0V]M86YD;R`K(%`@<&%R82!I;7!R:6UI<BX`6F]N82!H;W)A
M<FEA(&%C='5A;#H`4V4@:&$@8V%M8FEA9&\@<W4@:61E;G1I9&%D('!O<B!O
M;6ES:?-N+@!)9&5N=&ED860@<&]R(&]M:7-I\VXZ`$YO;6)R92!C;VUP;&5T
M;SH`4V4@:&$@86=O=&%D;R!S=2!T:65M<&\@9&4@8V]N97AI\VXN`$QA(&YU
M979A(&-O;G1R87-E\6$@<&%R82`E<R!E<SH@)7,`4V4@:&%N(&%C='5A;&EZ
M861O('-U<R!O<&-I;VYE<R!S\VQO('!O<B!L82!D=7)A8VGS;B!D92!L82!S
M97-I\VXN`%-E(&AA;B!A8W1U86QI>F%D;R!S=7,@;W!C:6]N97,N`%-E(&AA
M(')E86IU<W1A9&\@<W4@8V]N=')A<V7Q80!392!H82!R96%J=7-T861O('-U
M(&-O;G1R87-E\6$L(&-O;7!R=65B92!E;"!C;W)R96\@92!I;FEC:64@<V5S
M:?-N(&-O;B!S=2!N=65V82!C;VYT<F%S9?%A+@!,82!C;VYT<F%S9?%A(&AA
M(&5X<&ER861O+@!397)V:61O<F5S(')E;6]T;W,Z`%EU9V]S;&%V:6$`6F%I
M<F4`6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M/8W5L=&%R('1E>'1O(&-I=&%D
M;UT`6TEN9F]R;64@9&4@<')O8FQE;6%=`%M-;W-T<F%R('1E>'1O(&-I=&%D
M;R`M`%M-;W-T<F%R('1E>'1O(&-I=&%D;R`M("5S(&SM;F5A<UT`6VSM;F5A
M("5S(&1E("5S70!?061M:6YI<W1R86-I\VX`7T-,20#!<E]B;VP@9&%T;W,`
M15]L:6UI;F%R(&9I;&$`7T=R=7!O<P!!7WEU9&$`4')O<&EE9&%D97,@9&4@
M7VEM86=E;BXN+@!?26YI8VEA<B!S97-I\VX`7U-A;&ER`$UO9&EF:6-A<B!?
M=NUN8W5L;RXN+@!?3W!C:6]N97,`7U!R:79I;&5G:6]S`%]%;&EM:6YA<B!V
M[6YC=6QO+BXN`$-O;E]F:6=U<F%C+@!0<F]P:65D861E<R!D92!?=&%B;&$N
M+BX`7U5S=6%R:6]S`&1I<F5C8VEO;F5S`&1E<W1I;F%T87)I;R!D97-C;VYO
M8VED;P!A9V5N9&$`8V%L;6$`;F\@<V4@<'5E9&4@8W)E87(@96P@87)C:&EV
M;R!D92!D97-T:6YO`&YO('-E('!U961E(&%B<FER(&5L(&]R:6=E;@!P=6QS
M92!A<77M`&5R<F]R(&1E(&SM;F5A(&1E(&-O;6%N9&\`97)R;W(@9&4@8V]N
M9FEG=7)A8VGS;@!F86QT82!U;B!A<F-H:79O(&-R[71I8V\@9&5L('-I<W1E
M;6$`97)R;W(@9&4@9F]R;6%T;R!D92!D871O<P!M;V1I9FEC87(`96YT<F%D
M82!N;R!E;F-O;G1R861A`&1E<V-E;G-O`&%R8VAI=F\`9&5L("5S("@E<RD@
M82!L87,@)7,@)7,`=F5N=&]S;P!H.@!H:`!N;VUB<F4@9&4@86YF:71R:?-N
M(&1E<V-O;F]C:61O`&EN;65D:6%T86UE;G1E`&5N(&SM;F5A`&5R<F]R(&1E
M(&5N=')A9&$O<V%L:61A`&5R<F]R(&1E('-O9G1W87)E(&EN=&5R;F\`;.UN
M96%S70!C\V1I9V\@9&4@97)R;W(@;6MI<V]F<R`E9"!A;"!R96%L:7IA<B!)
M4T\N`&UM`&YO;6)R90!S:6X@9&5S87)R;VQL87(`8?IN(&YO('-E(&AA(&1E
M<V%R<F]L;&%D;P!N;W1A<P!P;W)C96YT86IE`'!R:79I;&5G:6\@9&5N96=A
M9&\`<.UX96QE<P!E<G)O<B!R96UO=&\@9&4@<')O=&]C;VQO`&5N(&%U;65N
M=&\`<V5R=FEC:6\@;F\@9&ES<&]N:6)L92X`;6]S=')A<B!D:69E<F5N8VEA
M<P!S;7,R96UA:6P@<&]R($A45%``<W,`97-T86)L90!E<G)O<B!D96P@<VES
M=&5M80!T87)E87,`9F%L;&\@=&5M<&]R86P`97-C<FEB82!D;W,@=F5C97,@
M;&$@8V]N=')A<V7Q82!P87)A(&-O;F9I<FUA<FQA`'5N:69I8V%D;P!S:6X@
M;F]M8G)E`'5S=6%R:6\@<V5L96-C:6]N861O`'9#87)D`'<Z`'=E871H97(N
M8V]M`````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]E<U]%4R]H96QP+GAM;```````
M````````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-#,R,R`Q,#4Q
M-30S,S<T,2`P,C$T-#<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]X;6P@=F5R<VEO;CTB,2XP(C\^"CPA+2T@)$AO<F1E
M.B!H;W)D92]L;V-A;&4O97-?15,O:&5L<"YX;6PL=B`Q+C,@,C`P-"\Q,B\Q
M,"`Q-CHQ-SHS-R!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB
M<W5M;6%R>2(@<W1A=&4](G5P=&]D871E(B!M9#4](C8X8V$S,V8W9C!C.6%A
M931C,3`S96(T-S0Y,F-D8S$U(CX*/'1I=&QE/DQA('`F(WA%,3MG:6YA(&1E
M;"!P;W)T86P\+W1I=&QE/@H@/'!A<F$^"B`@17-T82!P)B-X13$[9VEN82!D
M96P@<&]R=&%L('!R;W!O<F-I;VYA('5N('(F(WA%,3MP:61O(')E<W5M96X@
M9&4@=&]D82!S=2!I;F9O<FUA8VDF(WA&,SMN"B`@:6UP;W)T86YT92X@4&]R
M(&5J96UP;&\L('!U961E(&UO<W1R87(@8W4F(WA%,3MN=&]S(&UE;G-A:F5S
M(&YU979O<R!T:65N92!E;B!E;`H@(&)U>B8C>$8S.VX@9&4@16YT<F%D82P@
M86-O;G1E8VEM:65N=&]S(&EN;6EN96YT97,@9&4@;&$@86=E;F1A+"!T87)E
M87,@<&5N9&EE;G1E<PH@(&1E(&QA(&QI<W1A(&1E('1A<F5A<RP@=&ET=6QA
M<F5S(&1E('-E<G9I8VEO<R!D92!N;W1I8VEA<R!S96QE8V-I;VYA9&]S+"!E
M=&,N"B`@375C:&]S(&1E(&5S=&]S(')E<R8C>$9!.VUE;F5S('!O9'(F(WA%
M,3MN(&-O;G1E;F5R(&%T86IO<R!A(&%C=&EV:61A9&5S('5S=6%L97,@=&%L
M97,*("!C;VUO(&QA(')E9&%C8VDF(WA&,SMN(&1E(&YU979O<R!M96YS86IE
M<RP@;&$@8W)E86-I)B-X1C,[;B!D92!A8V]N=&5C:6UI96YT;W,@9&4@;&$*
M("!A9V5N9&$@;R!T87)E87,@;G5E=F%S+"!E=&,N"B`\+W!A<F$^"B`\<&%R
M83X*("!,;W,@8V]N=&5N:61O<R!D92!E<W1A('`F(WA%,3MG:6YA(&1E;"!P
M;W)T86P@<V4@<'5E9&5N('!E<G-O;F%L:7IA<B!M961I86YT92!E;`H@(&)O
M="8C>$8S.VX@1&ES=')I8G5C:28C>$8S.VXN(%!O<B!E:F5M<&QO+"!P=65D
M92!E;&5G:7(@<74F(WA%.3L@96QE;65N=&]S(&EN8VQU:7(@96X@97-T80H@
M('`F(WA%,3MG:6YA(&1E;"!P;W)T86P@87,F(WA%1#L@8V]M;R!E;"!O<F1E
M;B!E;B!E;"!Q=64@<V4@;6]S=')A<B8C>$4Q.VXN"B`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)N879B87(B('-T871E/2)U<'1O9&%T92(@;60U
M/2)B.&-F,&%E,3EE-3=D9F$P8S)B.38R934Q-C<X,F8T-R(^"CQT:71L93Y,
M82!B87)R82!D92!N879E9V%C:28C>$8S.VX@9&4@87!L:6-A8VEO;F5S/"]T
M:71L93X*(#QP87)A/@H@($5N(&5L(&QA9&\@:7IQ=6EE<F1O(&1E(&QA('`F
M(WA%,3MG:6YA('=E8B!S92!E;F-U96YT<F$@;&$@8F%R<F$@9&4@;F%V96=A
M8VDF(WA&,SMN(&1E"B`@87!L:6-A8VEO;F5S+B!0=6QS92!L;W,@:6-O;F]S
M(&1E(&1I8VAA(&)A<G)A('!A<F$@8V%M8FEA<B!R)B-X13$[<&ED82!Y(&8F
M(WA%,3MC:6QM96YT90H@(&5N=')E(&QA<R!A<&QI8V%C:6]N97,@9&ES<&]N
M:6)L97,N"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD
M;U]M86EN=&5N86YC92(@<W1A=&4](G5P=&]D871E(B!M9#4](F1D.35D9C`W
M83`S,#,Q,C,R8F%E83DQ.3(X.&(R9#`P(CX*("`@(#QT:71L93Y0<F5F97)E
M;F-I87,Z($UA;G1E;FEM:65N=&\Z(%)E86QI>F%R(&UA;G1E;FEM:65N=&\\
M+W1I=&QE/@H@("`@/'!A<F$^"B`@("!3:2!D97-E82!R96%L:7IA<B!L87,@
M;W!E<F%C:6]N97,@9&4@;6%N=&5N:6UI96YT;R!A;"!I;FEC:6%R(&QA('-E
M<VDF(WA&,SMN+`H@("`@<V5L96-C:6]N92!E<W1A(&-A<VEL;&$N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUC;VYF:7)M7VUA
M:6YT96YA;F-E(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB83(Q,38R8V1F9C-B
M,60X9F%E861B-S(Y-C(T,#`S-F4B/@H@("`@/'1I=&QE/E!R969E<F5N8VEA
M<SH@36%N=&5N:6UI96YT;SH@0V]N9FER;6%R(&UA;G1E;FEM:65N=&\\+W1I
M=&QE/@H@("`@/'!A<F$^"B`@("!3:2!Q=6ES:65R82!C;VYF:7)M87(@;&%S
M('1A<F5A<R!D92!M86YT96YI;6EE;G1O(&%N=&5S(&1E('%U92!S92!E:F5C
M=71E;BP*("`@('-E;&5C8VEO;F4@97-T82!C87-I;&QA+B!3:2!S92!D96IA
M('-I;B!S96QE8V-I;VYA<BP@<V4@96IE8W5T87(F(WA%,3MN"B`@("!A=71O
M;28C>$4Q.W1I8V%M96YT92!A;"!I;FEC:6%R(&QA('-E<VDF(WA&,SMN('1O
M9&%S(&QA<R!T87)E87,@9&4@;6%N=&5N:6UI96YT;PH@("`@<&5N9&EE;G1E
M<R!S:6X@;&$@<&]S:6)I;&ED860@9&4@8V%N8V5L87)L87,N"B`@("`\+W!A
M<F$^"CPO96YT<GD^"CPO:&5L<#X*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]F:5]&20``
M````````````````````````````````````````````````````````````
M```````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#`P,"`Q,#4Q-30S,S<T,2`P,3<V-S(`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&]C86QE+V9I7T9)+TQ#7TU%4U-!1T53````````````````````````
M`````````````````````````````````````````````#`P,#<U-2``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S0Q(#`R,30U-P`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O9FE?1DDO3$-?34534T%'15,O
M:&]R9&4N;6\`````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`T,3(T,#$@,3`U
M,34T,S,W-#$@,#(S,3<V`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````-X2!)4`````B@<``!P```!L/```$PH``+QX````````
M"*$```X````)H0``#P```!BA```-````**$```@````VH0``"P```#^A```,
M````2Z$```0```!8H0``&````%VA```;````=J$``"T```"2H0``'0```,"A
M```D````WJ$``"D````#H@``&0```"VB```F````1Z(```P```!NH@``)```
M`'NB```/````H*(```L```"PH@``#@```+RB```%````RZ(``"@```#1H@``
M"````/JB```*`````Z,``!4````.HP``$@```"2C```+````-Z,``(4```!#
MHP``#@```,FC```*````V*,```T```#CHP``#@```/&C```1`````*0```T`
M```2I```#````""D```-````+:0```8````[I```E````$*D```*````UZ0`
M``\```#BI```&````/*D```,````"Z4```X````8I0``#@```">E```(````
M-J4```D````_I0``+@```$FE```:````>*4``#(```"3I0``.````,:E``!4
M````_Z4``%$```!4I@``6@```*:F``!7`````:<``#0```!9IP``"0```(ZG
M```-````F*<```<```"FIP``"@```*ZG```/````N:<```4```#)IP``!@``
M`,^G```1````UJ<```@```#HIP``"0```/&G```)````^Z<``"4````%J```
M(````"NH```3````3*@``!````!@J```#P```'&H```*````@:@```,```",
MJ```#P```)"H```4````H*@```D```"UJ```#0```+^H```2````S:@``!D`
M``#@J```'@```/JH```/````&:D```H````IJ0``#P```#2I```(````1*D`
M`"0```!-J0``%````'*I```6````AZD```@```">J0``3@```*>I```M````
M]JD``!D````DJ@``!P```#ZJ```,````1JH``"P```!3J@``#@```("J```#
M````CZH```L```"3J@``!P```)^J```'````IZH```4```"OJ@``!0```+6J
M```*````NZH```,```#&J@``%P```,JJ```*````XJH```\```#MJ@``#@``
M`/VJ```8````#*L``",````EJP``#@```$FK```4````6*L``!<```!MJP``
M%P```(6K```7````G:L``!,```"UJP``#P```,FK```.````V:L``!\```#H
MJP``'0````BL```'````)JP```8````NK```"````#6L```/````/JP```8`
M``!.K```"@```%6L```3````8*P```L```!TK```$````("L```5````D:P`
M`!4```"GK```!P```+VL```0````Q:P```4```#6K```%0```-RL```1````
M\JP```P````$K0``.P```!&M```X````3:T```D```"&K0``!P```)"M```4
M````F*T```,```"MK0``!0```+&M```0````MZT```D```#(K0``$P```-*M
M```Y````YJT``!(````@K@``)P```#.N```L````6ZX``"H```"(K@``)0``
M`+.N```*````V:X```8```#DK@``"0```.NN```'````]:X``"\```#]K@``
M-P```"VO```N````9:\``%4```"4KP``+0```.JO```M````&+```#T```!&
ML```/P```(2P```M````Q+```$````#RL```(P```#.Q```C````5[$``$``
M``![L0``+0```+RQ```S````ZK$``"4````>L@``%0```$2R```9````6K(`
M`"D```!TL@``)````)ZR```H````P[(``!$```#LL@``"@```/ZR```,````
M";,```H````6LP``$````"&S```6````,K,``!8```!)LP``!P```&"S```'
M````:+,``!0```!PLP``"@```(6S```(````D+,``"<```"9LP``"````,&S
M```'````RK,```<```#2LP``!@```-JS```%````X;,```<```#GLP``!@``
M`.^S```(````]K,``"D```#_LP``#@```"FT```*````.+0```0```!#M```
M!P```$BT```)````4+0```8```!:M```$0```&&T```'````<[0``!8```![
MM```!````)*T```(````E[0```8```"@M```#0```*>T```&````M;0``!X`
M``"\M```$0```-NT```(````[;0```T```#VM```#`````2U```'````$;4`
M``,````9M0```P```!VU```7````(;4``!,````YM0``'0```$VU```(````
M:[4```0```!TM0``"````'FU```(````@K4``$$```"+M0``&@```,VU```K
M````Z+4``"`````4M@``%0```#6V```&````2[8```8```!2M@``%0```%FV
M```8````;[8``"(```"(M@``+@```*NV```=````VK8``"$```#XM@``5```
M`!JW```I````;[<```H```"9MP``!P```*2W```'````K+<``!4```"TMP``
M#@```,JW```*````V;<```\```#DMP``#0```/2W```/`````K@```T````2
MN```"0```""X```4````*K@```8````_N```&````$:X```=````7[@``!,`
M``!]N```$0```)&X```4````H[@```0```"XN```!@```+VX```4````Q+@`
M`%0```#9N```9````"ZY```$````D[D```X```"8N0``!0```*>Y```%````
MK;D``!L```"SN0``&@```,^Y```3````ZKD``!$```#^N0``$0```!"Z```<
M````(KH``"H````_N@``$````&JZ```A````>[H```4```"=N@``$P```*.Z
M```+````M[H``!(```##N@``"@```-:Z```/````X;H```T```#QN@``$0``
M`/^Z```3````$;L```P````ENP``!@```#*[```,````.;L```8```!&NP``
M%P```$V[```0````9;L``!$```!VNP``"````(B[```%````D;L```P```"7
MNP``$````*2[```%````M;L```T```"[NP``!@```,F[```'````T+L```T`
M``#8NP``!P```.:[```+````[KL```<```#ZNP``!P````*\```)````"KP`
M``D````4O```"@```!Z\```9````*;P``#T```!#O```'0```(&\```,````
MG[P``!````"LO```!0```+V\```E````P[P``!(```#IO```$P```/R\```K
M````$+T``#L````\O0``(````'B]```(````F;T``#8```"BO0``(0```-F]
M```0````^[T```@````,O@``#````!6^```&````(KX```0````IO@``#P``
M`"Z^```.````/KX```<```!-O@``"@```%6^```-````8+X``!\```!NO@``
M'````(Z^```A````J[X``!X```#-O@``&0```.R^```>````!K\``!L````E
MOP``(0```$&_```N````8[\``"8```"2OP``'````+F_```>````UK\``!P`
M``#UOP``)@```!+````K````.<```#,```!EP```)@```)G````K````P,``
M`#@```#LP```'0```"7!```5````0\$``"\```!9P0``(````(G!```2````
MJL$``"D```"]P0``'@```.?!```@````!L(``!(````GP@``H@```#K"```6
M````W<(``",```#TP@``*````!C#```I````0<,``"@```!KPP``'P```)3#
M```5````M,,``"````#*PP``)0```.O#```H````$<0``"T````ZQ```,```
M`&C$``"2````F<0``"$````LQ0``%@```$[%```<````9<4``"8```""Q0``
M*@```*G%``!!````U,4``$0````6Q@``#````%O&```'````:,8```<```!P
MQ@``!@```'C&```-````?\8``!````"-Q@``$@```)[&```3````L<8``!(`
M``#%Q@``!P```-C&```$````X,8``!````#EQ@``$````/;&```,````!\<`
M``X````4QP``#0```"/'```/````,<<``!,```!!QP``#0```%7'```H````
M8\<```,```",QP``#0```)#'```&````GL<``!$```"EQP``%P```+?'```;
M````S\<```X```#KQP```@```/K'``!)````_<<```4```!'R```$````$W(
M```/````7L@```0```!NR```#0```'/(```.````@<@```,```"0R```#@``
M`)3(```(````H\@```\```"LR```#P```+S(```'````S,@```T```#4R```
M$````.+(```-````\\@```L````!R0``!@````W)```+````%,D```P````@
MR0``"@```"W)```1````.,D``!D```!*R0``"P```&3)```-````<,D``"(`
M``!^R0``#P```*')```;````L<D``#0```#-R0``"@````+*```8````#<H`
M`!(````FR@``&0```#G*```6````4\H``"(```!JR@``#0```(W*```'````
MF\H``!0```"CR@``"P```+C*```B````Q,H``"\```#GR@``"P```!?+```)
M````(\L``!D````MRP``"P```$?+```7````4\L``!<```!KRP``"0```(/+
M```6````C<L```\```"DRP``&0```+3+```6````SLL```X```#ERP``&```
M`/3+```(````#<P```T````6S```)@```"3,``!#````2\P```@```"/S```
M$@```)C,```?````J\P```@```#+S```"P```-3,```O````X,P```X````0
MS0``!0```!_-```&````)<T``$4````LS0```P```'+-```'````=LT```0`
M``!^S0``"@```(/-```*````CLT```\```"9S0``$````*G-```7````NLT`
M`!$```#2S0``&0```.3-```7````_LT```D````6S@``!0```"#.```+````
M)LX```H````RS@```@```#W.```%````0,X```T```!&S@``&P```%3.```7
M````<,X``!0```"(S@``"0```)W.```.````I\X```T```"VS@``$@```,3.
M```X````U\X``"`````0SP``"````#'/```.````.L\``'L```!)SP``&```
M`,7/```8````WL\``!$```#WSP``!P````G0```%````$=```!@````7T```
M'@```##0```;````3]```!D```!KT```&P```(70```9````H=```!,```"[
MT```!P```,_0```(````U]````8```#@T```!@```.?0```0````[M````\`
M``#_T```$`````_1```/````(-$```L````PT0``#P```#S1```,````3-$`
M``\```!9T0``!P```&G1```&````<=$```X```!XT0``#````(?1```H````
ME-$```\```"]T0``"````,W1```(````UM$``!,```#?T0``'@```//1```A
M````$M(``"`````TT@``&0```%72```7````;](``"4```"'T@``%P```*W2
M```6````Q=(```0```#<T@``&P```.'2```-````_=(```P````+TP```P``
M`!C3```%````'-,```@````BTP``"@```"O3```,````-M,```L```!#TP``
M$````$_3```,````8-,```X```!MTP``"P```'S3```$````B-,```0```"-
MTP``$P```)+3```4````IM,```P```"[TP``"0```,C3```.````TM,```L`
M``#ATP``&P```.W3```'````"=0```<````1U```"@```!G4```-````)-0`
M``D````RU```!````#S4```%````0=0```,```!'U```&````$O4```*````
M9-0```0```!OU```)@```'34```.````F]0``'P```"JU```%0```"?5```%
M````/=4```<```!#U0``#````$O5```(````6-4```H```!AU0``!@```&S5
M```(````<]4```(```!\U0``!@```'_5```&````AM4``!0```"-U0``#0``
M`*+5```0````L-4``!L```#!U0``!````-W5```)````XM4``!````#LU0``
M"0```/W5```)````!]8```4````1U@``&@```!?6```(````,M8```8````[
MU@``&0```$+6```.````7-8```<```!KU@``!P```'/6```%````>]8```D`
M``"!U@``"@```(O6```.````EM8```(```"EU@``!@```*C6```+````K]8`
M``T```"[U@``"0```,G6```&````T]8``!(```#:U@``"0```.W6```'````
M]]8``!0```#_U@``'0```!37``!"````,M<``"4```!UUP``)0```)O7```&
M````P=<```H```#(UP``!````-/7```)````V-<```@```#BUP``$0```.O7
M```)````_=<```8````'V```#0````[8```&````'-@```0````CV```.0``
M`"C8```]````8M@``#H```"@V```'@```-O8```%````^M@```X`````V0``
M!`````_9```&````%-D```<````;V0``(0```"/9```-````1=D``!4```!3
MV0``!@```&G9```$````<-D``!$```!UV0``!@```(?9```*````CMD``"(`
M``"9V0``!````+S9```%````P=D``!T```#'V0``!````.79```,````ZMD`
M``X```#WV0``"@````;:```(````$=H```D````:V@``!0```"3:```Z````
M*MH``#````!EV@``-0```);:```I````S-H``$<```#VV@``.````#[;```I
M````=]L``#\```"AVP``+@```.';```M````$-P``!\````^W```#P```%[<
M```2````;MP```L```"!W```)@```(W<```I````M-P``"0```#>W```)@``
M``/=```(````*MT```H````SW0``"0```#[=```'````2-T``"````!0W0``
M(````''=```F````DMT```H```"YW0``&0```,3=```I````WMT``!8````(
MW@``$@```!_>```'````,MX```H````ZW@``#````$7>```/````4MX``!``
M``!BW@``0````'/>``!P````M-X``&8````EWP``#@```(S?```)````F]\`
M``H```"EWP``$@```+#?```3````P]\```P```#7WP``!@```.3?```/````
MZ]\``!(```#[WP``$`````[@```1````'^```!P````QX```(P```$[@``!J
M````<N````\```#=X```!0```.W@```0````\^````D````$X0``!`````[A
M```+````$^$``"`````?X0``%````$#A```,````5>$```P```!BX0``#P``
M`&_A```5````?^$``"D```"5X0``*@```+_A```F````ZN$``"<````1X@``
M*0```#GB```J````8^(``!D```".X@``0@```*CB```1````Z^(``!(```#]
MX@``$P```!#C```4````).,```\````YXP``%@```$GC```7````8.,``!``
M``!XXP``$0```(GC```T````F^,``!,```#0XP``$@```.3C```U````]^,`
M`!0````MY```!P```$+D```,````2N0``"````!7Y```$````'CD```4````
MB>0``!$```">Y```%P```+#D```<````R.0``!,```#EY```%````/GD```:
M````#N4``!$````IY0``&@```#OE```>````5N4``!H```!UY0``$P```)#E
M```5````I.4``!$```"ZY0``%P```,SE```4````Y.4``!<```#YY0``%0``
M`!'F```)````)^8``!`````QY@``&0```$+F```$````7.8```<```!AY@``
M"P```&GF```1````=>8```8```"'Y@``!@```([F```&````E>8```4```"<
MY@``!P```*+F```'````JN8```4```"RY@``%@```+CF```&````S^8```8`
M``#6Y@``!````-WF```$````XN8```<```#GY@``#@```._F```,````_N8`
M``P````+YP``#0```!CG```*````)N<```X````QYP``!0```$#G```H````
M1N<```X```!OYP``#````'[G```/````B^<```H```";YP``"````*;G```)
M````K^<``"L```"YYP``!````.7G```(````ZN<``"8```#SYP``$@```!KH
M```/````+>@```8````]Z```"@```$3H```'````3^@```@```!7Z```(```
M`&#H```)````@>@``!0```"+Z```#````*#H```-````K>@```X```"[Z```
M%@```,KH```1````X>@```8```#SZ````P```/KH```&````_N@``!D````%
MZ0``!P```!_I```$````)^D```L````LZ0``"P```#CI```'````1.D```4`
M``!,Z0``!P```%+I```6````6ND```T```!QZ0``#0```'_I```*````C>D`
M`!````"8Z0``#P```*GI```1````N>D``!<```#+Z0``"@```./I```1````
M[ND```@`````Z@``!`````GJ```/````#NH``#H````>Z@``!0```%GJ```,
M````7^H``!X```!LZ@``#@```(OJ```0````FNH```L```"KZ@``#````+?J
M```)````Q.H```<```#.Z@``"@```-;J```)````X>H```X```#KZ@``$```
M`/KJ```;````"^L``!@````GZP``&@```$#K```*````6^L```D```!FZP``
M"@```'#K```,````>^L```\```"(ZP``"````)CK```&````H>L``!P```"H
MZP``!P```,7K```%````S>L```L```#3ZP``1P```-_K```-````)^P```D`
M```U[```!````#_L```#````1.P``!,```!([```$P```%SL```3````<.P`
M``H```"$[````@```(_L```$````DNP``"4```"7[````P```+WL```%````
MP>P``"H```#'[```"@```/+L```%````_>P```0````#[0``"@````CM```-
M````$^T```8````A[0``"````"CM```(````,>T```0````Z[0``!0```#_M
M``!H````1>T```D```"N[0``#````+CM```0````Q>T```4```#6[0``!@``
M`-SM```;````X^T``"\```#_[0``$````"_N```*````0.X```\```!+[@``
M"@```%ON```)````9NX``!,```!P[@``&P```(3N```8````H.X``!<```"Y
M[@``'P```-'N```.````\>X```,`````[P``!P````3O```(````#.\```<`
M```5[P``"@```!WO```+````*.\```<````T[P``40```#SO```0````CN\`
M``P```"?[P``#0```*SO```:````NN\``$H```#5[P``&0```"#P```&````
M.O```!H```!!\```)0```%SP```&````@O````8```")\```'P```)#P```&
M````L/````D```"W\```&````,'P```7````VO```"@```#R\```!@```!OQ
M```-````(O$``"(````P\0``5P```%/Q```3````J_$``",```"_\0``$P``
M`./Q```"````]_$```L```#Z\0``"`````;R```-````#_(```H````=\@``
M!P```"CR```4````,/(```8```!%\@``"````$SR```.````5?(```<```!D
M\@``"@```&SR```+````=_(``#(```"#\@``!P```+;R```,````OO(```T`
M``#+\@``%P```-GR```,````\?(```D```#^\@``"0````CS```*````$O,`
M``<````=\P``"0```"7S```'````+_,```H````W\P``&P```$+S```/````
M7O,``!(```!N\P``"@```('S```6````C/,```D```"C\P``$````*WS```'
M````OO,``!(```#&\P``!````-GS```'````WO,```4```#F\P``!0```.SS
M```+````\O,``!0```#^\P``$0```!/T```:````)?0``!8```!`]```%```
M`%?T```7````;/0``!@```"$]```'````)WT```9````NO0```<```#4]```
M!0```-ST```-````XO0```P```#P]```"````/WT```7````!O4```L````>
M]0``#````"KU```?````-_4``!H```!7]0``$P```'+U```$````AO4```H`
M``"+]0``!````);U```-````F_4```P```"I]0``!0```+;U```)````O/4`
M``4```#&]0``!P```,SU```%````U/4```0```#:]0```@```-_U```X````
MXO4``"P````;]@``$@```$CV```I````6_8``#(```"%]@``"@```+CV```L
M````P_8``"X```#P]@``,P```!_W```S````4_<``#@```"']P``#P```,#W
M```8````T/<``!````#I]P``#P```/KW```3````"O@``!4````>^```%```
M`#3X```2````2?@``!0```!<^```%0```''X```M````A_@``"T```"U^```
M,0```./X```N````%?D``"\```!$^0``+````'3Y``!B````H?D``!,````$
M^@``#0```!CZ```(````)OH``!<````O^@``"````$?Z```,````4/H``"L`
M``!=^@``(0```(GZ```:````J_H```D```#&^@``10```-#Z``!!````%OL`
M``0```!8^P``$P```%W[```4````<?L```X```"&^P``$P```)7[```8````
MJ?L```8```#"^P``"0```,G[```*````T_L```\```#>^P``$````.[[```'
M````__L```X````'_```!0```!;\```;````'/P```@````X_```!@```$'\
M```4````2/P``!$```!=_```#@```&_\```X````?OP```(```"W_```!@``
M`+K\```.````P?P```4```#0_```!P```-;\```.````WOP```8```#M_```
M*````/3\```,````'?T``!P````J_0``!````$?]```I````3/T``!<```!V
M_0``'P```([]``!<````KOT``!0````+_@``/@```"#^```?````7_X``!``
M``!__@``!P```)#^```.````F/X```P```"G_@``#````+3^```3````P?X`
M``H```#5_@``'0```.#^```9````_OX```4````8_P``$0```![_```1````
M,/\``"0```!"_P``$@```&?_```5````>O\``!(```"0_P``#@```*/_```9
M````LO\```@```#,_P``"0```-7_```-````W_\```<```#M_P``"@```/7_
M```'```````!``\````(``$`!@```!@``0`+````'P`!`!H````K``$`"@``
M`$8``0`'````40`!``@```!9``$`!0```&(``0`?````:``!``8```"(``$`
M$````(\``0`(````H``!``T```"I``$`"````+<``0`>````P``!`!(```#?
M``$`+````/(``0`:````'P$!``D````Z`0$`"@```$0!`0`5````3P$!``4`
M``!E`0$`%````&L!`0`$````@`$!`!````"%`0$`!@```)8!`0`'````G0$!
M`!X```"E`0$`*````,0!`0`*````[0$!`!P```#X`0$`$0```!4"`0`+````
M)P(!`!H````S`@$`%````$X"`0`$````8P(!``0```!H`@$`"P```&T"`0`%
M````>0(!``8```!_`@$`"````(8"`0`&````CP(!``H```"6`@$`&P```*$"
M`0`T````O0(!`#0```#R`@$`(````"<#`0`I````2`,!`"````!R`P$`00``
M`),#`0`:````U0,!`"@```#P`P$`*0```!D$`0!0````0P0!`"(```"4!`$`
M!@```+<$`0`(````O@0!``4```#'!`$`"````,T$`0`9````U@0!`!D```#P
M!`$`*@````H%`0`C````-04!`!D```!9!0$`+@```',%`0`T````H@4!``@`
M``#7!0$`%P```.`%`0`*````^`4!``<````#!@$`(0````L&`0`0````+08!
M``X````^!@$`"P```$T&`0`'````608!`!,```!A!@$`"````'4&`0`+````
M?@8!``H```"*!@$`%````)4&`0`/````J@8!`#(```"Z!@$`"P```.T&`0`.
M````^08!``4````(!P$`!0````X'`0`%````%`<!`!<````:!P$`#P```#('
M`0`$````0@<!``H```!'!P$`"0```%('`0`+````7`<!``T```!H!P$`#```
M`'8'`0`.````@P<!``4```"2!P$`!````)@'`0`-````G0<!`#(```"K!P$`
M10```-X'`0`7````)`@!``<````\"`$`'@```$0(`0`4````8P@!``4```!X
M"`$`%````'X(`0`&````DP@!``<```":"`$`#@```*((`0`J````L0@!``8`
M``#<"`$`#````.,(`0`-````\`@!`!$```#^"`$`"P```!`)`0`V````'`D!
M``H```!3"0$`(@```%X)`0`+````@0D!``\```"-"0$`,@```)T)`0`E````
MT`D!`#````#V"0$`,0```"<*`0`M````60H!``X```"'"@$`!0```)8*`0`.
M````G`H!`!,```"K"@$`$@```+\*`0`'````T@H!`!$```#:"@$`$P```.P*
M`0`'``````L!`!0````("P$`&````!T+`0`'````-@L!``4````^"P$`#```
M`$0+`0`,````40L!`!(```!>"P$`!````'$+`0`'````=@L!``H```!^"P$`
M"P```(D+`0`,````E0L!``X```"B"P$`#@```+$+`0`%````P`L!``4```#&
M"P$`+@```,P+`0`F````^PL!`",````B#`$``P```$8,`0`2````2@P!``8`
M``!=#`$`'@```&0,`0`8````@PP!`"4```"<#`$`#0```,(,`0`)````T`P!
M`!\```#:#`$``P```/H,`0`'````_@P!``H````&#0$``@```!$-`0`,````
M%`T!`!4````A#0$`"P```#<-`0`9````0PT!`"````!=#0$`$@```'X-`0`%
M````D0T!``H```"7#0$`%0```*(-`0`2````N`T!``P```#+#0$`!````-@-
M`0`)````W0T!``<```#G#0$`#````.\-`0!2````_`T!`!<```!/#@$`)```
M`&<.`0`2````C`X!``<```"?#@$`!@```*<.`0`.````K@X!``P```"]#@$`
M#0```,H.`0`5````V`X!`!(```#N#@$`#P````$/`0`4````$0\!``H````F
M#P$`&P```#$/`0`0````30\!``L```!>#P$`:0```&H/`0`:````U`\!`!<`
M``#O#P$`)P````<0`0`:````+Q`!`!<```!*$`$`&P```&(0`0`9````?A`!
M`!\```"8$`$`$P```+@0`0`(````S!`!``<```#5$`$`"````-T0`0`)````
MYA`!`!4```#P$`$`#0````81`0`C````%!$!``T````X$0$`$P```$81`0`(
M````6A$!``,```!C$0$`1@```&<1`0`_````KA$!`#<```#N$0$`5P```"82
M`0`%````?A(!`!\```"$$@$`+P```*02`0`*````U!(!``@```#?$@$`#0``
M`.@2`0`M````]A(!``0````D$P$`3P```"D3`0`E````>1,!`!P```"?$P$`
M"P```+P3`0`?````R!,!`!T```#H$P$`)0````84`0`@````+!0!`"0```!-
M%`$`(````'(4`0`+````DQ0!``<```"?%`$`#0```*<4`0`,````M10!`!<`
M``#"%`$`!@```-H4`0`Y````X10!``P````;%0$`!P```"@5`0`)````,!4!
M`!,````Z%0$`"0```$X5`0`$````6!4!`!````!=%0$`"````&X5`0`(````
M=Q4!``0```"`%0$`"P```(45`0`,````D14!`!(```">%0$`$0```+$5`0`,
M````PQ4!`!H```#0%0$`#P```.L5`0`'````^Q4!``T````#%@$`%````!$6
M`0`.````)A8!``P````U%@$`&P```$(6`0`L````7A8!`!,```"+%@$`'```
M`)\6`0`H````O!8!``8```#E%@$`!P```.P6`0`3````]!8!``4````(%P$`
M!`````X7`0`7````$Q<!``H````K%P$`#````#87`0`)````0Q<!``8```!-
M%P$`"0```%07`0`(````7A<!``D```!G%P$`"@```'$7`0`1````?!<!``8`
M``".%P$`#@```)47`0`.````I!<!``T```"S%P$`"P```,$7`0`=````S1<!
M``L```#K%P$``@```/<7`0`<````^A<!``<````7&`$`!@```!\8`0!D````
M)A@!``D```"+&`$`!P```)48`0`F````G1@!`#@```#$&`$`&@```/T8`0`J
M````&!D!`#L```!#&0$`*````'\9`0`T````J!D!`!D```#=&0$`%0```/<9
M`0`%````#1H!``<````3&@$`"````!L:`0`'````)!H!``4````L&@$`!P``
M`#(:`0`.````.AH!``D```!)&@$`!@```%,:`0`(````6AH!``L```!C&@$`
M!P```&\:`0`(````=QH!``<```"`&@$`%@```(@:`0`)````GQH!``8```"I
M&@$`"P```+`:`0`0````O!H!``8```#-&@$`'````-0:`0`4````\1H!``<`
M```&&P$`$0````X;`0`(````(!L!``X````I&P$`"````#@;`0`%````01L!
M`!````!'&P$`"0```%@;`0`0````8AL!``8```!S&P$`&0```'H;`0`*````
ME!L!`!P```"?&P$`!P```+P;`0`%````Q!L!`!````#*&P$`%````-L;`0`+
M````\!L!``T```#\&P$`*`````H<`0`8````,QP!`!<```!,'`$`!````&0<
M`0`)````:1P!``H```!S'`$`!P```'X<`0`"````AAP!``X```")'`$`"```
M`)@<`0`C````H1P!`!\```#%'`$`.````.4<`0`F````'AT!`#$```!%'0$`
M)P```'<=`0!D````GQT!`!0````$'@$`50```!D>`0`X````;QX!`$H```"H
M'@$`6P```/,>`0`H````3Q\!`#@```!X'P$`*````+$?`0`L````VA\!`"8`
M```'(`$`&P```"X@`0`^````2B`!`*D!``")(`$`(P```#,B`0`7````5R(!
M`$@```!O(@$`A0```+@B`0`P````/B,!`"4```!O(P$`00```)4C`0!;````
MUR,!`$D````S)`$`,0```'TD`0`=````KR0!`!@```#-)`$`*P```.8D`0`A
M````$B4!`!\````T)0$`*P```%0E`0`F````@"4!`"<```"G)0$`.@```,\E
M`0`=````"B8!`!$````H)@$`,P```#HF`0`E````;B8!`"<```"4)@$`(```
M`+PF`0`?````W28!`#````#])@$`:0```"XG`0`Q````F"<!`$$```#*)P$`
M,P````PH`0`E````0"@!`#T```!F*`$`90```*0H`0!-````"BD!`"\```!8
M*0$`+@```(@I`0`P````MRD!`%0```#H*0$`6@```#TJ`0!(````F"H!`$H`
M``#A*@$`,@```"PK`0`O````7RL!`"P```"/*P$`+0```+PK`0!Q````ZBL!
M`&8```!<+`$`;P```,,L`0"S````,RT!`!<```#G+0$`)0```/\M`0`R````
M)2X!`"D```!8+@$`/@```((N`0`B````P2X!`%(```#D+@$`)0```#<O`0`+
M````72\!`+$```!I+P$`10```!LP`0`A````83`!`#````"#,`$`)0```+0P
M`0`<````VC`!`#$```#W,`$`!P```"DQ`0`'````,3$!``0````Y,0$`#0``
M`#XQ`0`+````3#$!``X```!8,0$`"P```&<Q`0`%````<S$!`!````!Y,0$`
M`@```(HQ`0!9````C3$!``4```#G,0$`$@```.TQ`0`$`````#(!``<````%
M,@$`"`````TR`0`%````%C(!`#`````<,@$``P```$TR`0`0````43(!``P`
M``!B,@$`$P```&\R`0`-````@S(!``(```"1,@$`!P```)0R`0`&````G#(!
M`!0```"C,@$`#````+@R`0`8````Q3(!``8```#>,@$`$@```.4R`0`,````
M^#(!``,````%,P$`*@````DS`0`$````-#,!``8````Y,P$`!P```$`S`0`?
M````2#,!`#4```!H,P$`+@```)XS`0`O````S3,!`!<```#],P$`(@```!4T
M`0`E````.#0!`"````!>-`$`&P```'\T`0`8````FS0!`"0```"T-`$`'P``
M`-DT`0`:````^30!`"$````4-0$`(````#8U`0`:````5S4!`#(```!R-0$`
M&@```*4U`0`O````P#4!`"L```#P-0$`'P```!PV`0`C````/#8!`!\```!@
M-@$`&@```(`V`0`A````FS8!`"4```"]-@$`)@```.,V`0`E````"C<!`"0`
M```P-P$`&````%4W`0`=````;C<!`"0```",-P$`&````+$W`0`B````RC<!
M`"P```#M-P$`+P```!HX`0`5````2C@!`"4```!@.`$`/````(8X`0`?````
MPS@!`",```#C.`$`'P````<Y`0`@````)SD!`!H```!(.0$`&````&,Y`0`F
M````?#D!`!X```"C.0$`*0```,(Y`0`>````[#D!`#$````+.@$`"0```#TZ
M`0`,````1SH!`!<```!4.@$`+P```&PZ`0`D````G#H!``<```#!.@$`#P``
M`,DZ`0`4````V3H!``X```#N.@$`#0```/TZ`0`D````"SL!``4````P.P$`
M!P```#8[`0`B````/CL!`"4```!A.P$`&@```(<[`0`=````HCL!`!H```#`
M.P$`!P```-L[`0#'````XSL!``L```"K/`$`%0```+<\`0`&````S3P!``D`
M``#4/`$`"P```-X\`0`-````ZCP!`!<```#X/`$`!@```!`]`0`S````%ST!
M`!,```!+/0$`$P```%\]`0`'````<ST!``\```![/0$`!P```(L]`0`R````
MDST!``0```#&/0$`(0```,L]`0`3````[3T!``P````!/@$`$0````X^`0`R
M````(#X!`!8```!3/@$`"````&H^`0`=````<SX!``D```"1/@$`"@```)L^
M`0`4````ICX!``H```"[/@$`'0```,8^`0`(````Y#X!`!\```#M/@$`"```
M``T_`0`:````%C\!`"<````Q/P$`!@```%D_`0`5````8#\!``<```!V/P$`
M"````'X_`0`)````AS\!`#\```"1/P$`!P```-$_`0`/````V3\!``X```#I
M/P$`$````/@_`0`)````"4`!``D````30`$`"````!U``0`3````)D`!``<`
M```Z0`$`&0```$)``0`*````7$`!`!<```!G0`$`%````']``0`*````E$`!
M``P```"?0`$`%P```*Q``0`$````Q$`!`"H```#)0`$`#````/1``0`1````
M`4$!``<````300$``@```!M!`0`0````'D$!`!@````O00$`"P```$A!`0`#
M````5$$!``@```!800$`!@```&%!`0`'````:$$!``T```!P00$`"P```'Y!
M`0`4````BD$!`!4```"?00$`#@```+5!`0`O````Q$$!`"````#T00$`'```
M`!5"`0`5````,D(!``P```!(0@$`,0```%5"`0`%````AT(!`!(```"-0@$`
M/P```*!"`0`2````X$(!``H```#S0@$`!@```/Y"`0`$````!4,!``0````*
M0P$`"@````]#`0`3````&D,!``4````N0P$`!@```#1#`0`&````.T,!``@`
M``!"0P$`!````$M#`0`,````4$,!``H```!=0P$`.0```&A#`0`N````HD,!
M`"D```#10P$`!0```/M#`0`8`````40!`!D````:1`$`'P```#1$`0`=````
M5$0!`!$```!R1`$``@```(1$`0`$````AT0!``H```",1`$`!@```)=$`0`%
M````GD0!``,```"D1`$`#````*A$`0!%````M40!`#(```#[1`$`&@```"Y%
M`0`T````244!`"@```!^10$`4P```*=%`0`9````^T4!`'(````51@$`(```
M`(A&`0`U````J48!`"$```#?1@$`10````%'`0`P````1T<!`"@```!X1P$`
M*0```*%'`0`F````RT<!`"4```#R1P$`*````!A(`0`H````04@!`"(```!J
M2`$`*P```(U(`0`P````N4@!`!(```#J2`$`$P```/U(`0`0````$4D!`'D`
M```B20$`"0```)Q)`0"A````IDD!`',```!(2@$`?````+Q*`0`K````.4L!
M`%0```!E2P$`%P```+I+`0`G````TDL!`!8```#Z2P$`#P```!%,`0`7````
M(4P!`!\````Y3`$`0````%E,`0`?````FDP!`!P```"Z3`$`40```-=,`0`:
M````*4T!`!0```!$30$`"@```%E-`0`%````9$T!``8```!J30$`"````'%-
M`0`%````>DT!`!(```"`30$`$````)--`0`3````I$T!`!T```"X30$`#P``
M`-9-`0`/````YDT!``0```#V30$`"0```/M-`0`+````!4X!``<````13@$`
M!0```!E.`0`4````'TX!``<````T3@$`"````#Q.`0`/````14X!``@```!5
M3@$`#````%Y.`0`/````:TX!``8```![3@$`%````().`0`&````ETX!``P`
M``">3@$`$0```*M.`0`(````O4X!``0```#&3@$`&0```,M.`0`1````Y4X!
M``H```#W3@$`&`````)/`0`3````&T\!`!P````O3P$`$0```$Q/`0`$````
M7D\!``\```!C3P$`!P```'-/`0`$````>T\!`!D```"`3P$`!P```)I/`0`"
M````HD\!``(```"E3P$`$0```*A/`0`)````ND\!``8```#$3P$`$@```,M/
M`0`7````WD\!``8```#V3P$`)P```/U/`0`"````)5`!``0````H4`$`#P``
M`"U0`0`3````/5`!``<```!14`$`!P```%E0`0`1````85`!``8```!S4`$`
M&````'I0`0`&````DU`!`!,```":4`$`$````*Y0`0`2````OU`!``(```#2
M4`$`!@```-50`0`,````W%`!``D```#I4`$`$0```/-0`0`B````!5$!``<`
M```H40$`!P```#!1`0`+````.%$!``4```!$40$``@```$I1`0`+````35$!
M`%<!``!940$`$P```+%2`0`1````Q5(!``X```#74@$`"0```.92`0`+````
M\%(!``@```#\4@$``0````53`0`5````!U,!`!H````=4P$`*@```#A3`0`A
M````8U,!`"(```"%4P$`&@```*A3`0`2````PU,!`"H```#64P$`"P````%4
M`0`F````#50!`!(````T5`$`#0```$=4`0`.````550!``4```!D5`$`(P``
M`&I4`0`*````CE0!`!````"95`$`#@```*I4`0`2````N50!``\```#,5`$`
M90```-Q4`0`0````0E4!``P```!350$`#P```&!5`0`,````<%4!`!````!]
M50$`#@```(Y5`0`0````G54!`!$```"N50$`!@```,!5`0#"````QU4!``\`
M``"*5@$`%0```)I6`0`5````L%8!``T```#&5@$`%0```-16`0`5````ZE8!
M``D`````5P$`"@````I7`0`\````%5<!`!4```!25P$`,````&A7`0!#````
MF5<!`%X```#=5P$`8````#Q8`0!<````G5@!`&8```#Z6`$`,@```&%9`0`)
M````E%D!`!(```">60$`!P```+%9`0`*````N5D!``X```#$60$`!0```--9
M`0`&````V5D!`!(```#@60$`"@```/-9`0`)````_ED!``T````(6@$`+@``
M`!9:`0`M````15H!`!@```!S6@$`&@```(Q:`0`6````IUH!``H```"^6@$`
M!0```,E:`0`.````SUH!``\```#>6@$`#````.Y:`0`0````^UH!`!$````,
M6P$`&P```!Y;`0`6````.EL!`!0```!16P$`#````&9;`0`3````<UL!``H`
M``"'6P$`*````));`0`4````NUL!`!4```#06P$`#@```.9;`0!;````]5L!
M`#@```!17`$`(0```(I<`0`&````K%P!``L```"S7`$`.0```+]<`0`(````
M^5P!``D````"70$`"@````Q=`0`'````%UT!``<````?70$`!0```"==`0`%
M````+5T!``<````S70$`!@```#M=`0`>````0ET!``T```!A70$`#P```&]=
M`0`9````?UT!`!4```"970$`)P```*]=`0`.````UUT!`"<```#F70$`'```
M``Y>`0`B````*UX!`"(```!.7@$`%0```'%>`0`6````AUX!`!(```">7@$`
M%P```+%>`0`:````R5X!``<```#D7@$`!@```.Q>`0`(````\UX!``X```#\
M7@$`!P````M?`0`)````$U\!`!(````=7P$`!P```#!?`0`,````.%\!`!(`
M``!%7P$`(0```%A?`0`'````>E\!``T```""7P$`"````)!?`0`5````F5\!
M``P```"O7P$`#````+Q?`0`_````R5\!`#\````)8`$`"0```$E@`0`'````
M4V`!`!,```!;8`$`!0```&]@`0`%````=6`!`!````![8`$`"P```(Q@`0`6
M````F&`!`#<```"O8`$`$````.=@`0`E````^&`!`"<````>80$`)P```$9A
M`0`D````;F$!``\```"380$`!@```*-A`0`)````JF$!``@```"T80$`-@``
M`+UA`0`_````]&$!`#4````T8@$`70```&IB`0`T````R&(!`#0```#]8@$`
M00```#)C`0!#````=&,!`#0```"X8P$`1P```.UC`0`H````-60!`"H```!>
M9`$`10```(ED`0`T````SV0!`#H````$90$`+````#]E`0`9````;&4!`!T`
M``"&90$`+@```*1E`0`K````TV4!`"L```#_90$`&P```"MF`0`+````1V8!
M``\```!39@$`!@```&-F`0`*````:F8!`!@```!U9@$`'@```(YF`0`&````
MK68!``<```"T9@$`%````+QF`0`*````T68!``@```#<9@$`+@```.5F`0`*
M````%&<!``P````?9P$`!@```"QG`0`&````,V<!``4````Z9P$`!P```$!G
M`0`&````2&<!``P```!/9P$`*````%QG`0`/````A6<!``P```"59P$`"0``
M`*)G`0`'````K&<!``P```"T9P$`!0```,%G`0`/````QV<!``8```#79P$`
M$@```-YG`0`(````\6<!``@```#Z9P$`!`````-H`0`-````"&@!``@````6
M:`$`)P```!]H`0`0````1V@!``@```!8:`$`#0```&%H`0`,````;V@!``<`
M``!\:`$``P```(1H`0`#````B&@!`!,```",:`$`$````*!H`0`C````L6@!
M``D```#5:`$`!0```-]H`0`)````Y6@!``<```#O:`$`1@```/=H`0`A````
M/FD!`#H```!@:0$`)@```)MI`0`<````PFD!``8```#?:0$`!````.9I`0`2
M````ZVD!`"````#^:0$`(0```!]J`0`O````06H!`"$```!Q:@$`*````)-J
M`0!A````O&H!`"D````>:P$`"0```$AK`0`*````4FL!`!````!=:P$`%0``
M`&YK`0`-````A&L!``P```"2:P$`#````)]K`0`,````K&L!``P```"Y:P$`
M#````,9K`0`,````TVL!`!0```#@:P$`"@```/5K`0`7`````&P!`!L````8
M;`$`$0```#1L`0`3````1FP!`!4```!:;`$`!````'!L`0`%````=6P!`!$`
M``![;`$`2P```(UL`0!3````V6P!``8````M;0$`$P```#1M`0`%````2&T!
M``4```!.;0$`(````%1M`0`8````=6T!``\```".;0$`$````)YM`0`6````
MKVT!`!\```#&;0$`,````.9M`0`+````%VX!`"`````C;@$`!@```$1N`0`5
M````2VX!``T```!A;@$`$P```&]N`0`/````@VX!`!<```"3;@$`$@```*MN
M`0`4````OFX!`!<```#3;@$`#````.MN`0`&````^&X!`!$```#_;@$`"```
M`!%O`0`7````&F\!`!0````R;P$`$@```$=O`0`(````6F\!``0```!C;P$`
M#````&AO`0`+````=6\!``8```"!;P$`$P```(AO`0`*````G&\!``<```"G
M;P$`#0```*]O`0`)````O6\!``P```#';P$`!P```-1O`0`&````W&\!``L`
M``#C;P$`"````.]O`0`*````^&\!``\````#<`$`0P```!-P`0`:````5W`!
M`!(```!R<`$`*@```(5P`0`%````L'`!`!\```"V<`$`$P```-9P`0`4````
MZG`!`#,```#_<`$`0@```#-Q`0`D````=G$!``P```";<0$`)@```*AQ`0`=
M````SW$!``X```#M<0$`!0```/QQ`0`+`````G(!``8````.<@$`!@```!5R
M`0`9````''(!``X````V<@$`!P```$5R`0`*````37(!`!$```!8<@$`)0``
M`&IR`0`Q````D'(!`"<```#"<@$`,P```.IR`0`;````'G,!`#`````Z<P$`
M'0```&MS`0`C````B7,!`#D```"M<P$`'P```.=S`0`G````!W0!`"D````O
M=`$`(0```%ET`0`A````>W0!`"<```"==`$`0@```,5T`0`A````"'4!`"$`
M```J=0$`*P```$QU`0`?````>'4!`!\```"8=0$`.@```+AU`0`B````\W4!
M`!4````6=@$`)P```"QV`0`@````5'8!`"L```!U=@$`%0```*%V`0"2````
MMW8!`!H```!*=P$`'P```&5W`0`?````A7<!`"````"E=P$`+@```,9W`0`=
M````]7<!`!\````3>`$`(````#-X`0`L````5'@!`"X```"!>`$`,````+!X
M`0`O````X7@!`*$````1>0$`*P```+-Y`0`@````WWD!`"0`````>@$`(P``
M`"5Z`0`L````27H!`$````!V>@$`1````+=Z`0`/````_'H!``,````,>P$`
M!P```!![`0`#````&'L!``\````<>P$`"````"Q[`0`9````-7L!`!(```!/
M>P$`$@```&)[`0`'````=7L!``4```!]>P$`&````(-[`0`6````G'L!`!D`
M``"S>P$`%````,U[`0`7````XGL!`!$```#Z>P$`%`````Q\`0`3````(7P!
M`$X````U?`$`!P```(1\`0`/````C'P!``8```"<?`$`$P```*-\`0`9````
MMWP!`!L```#1?`$`$````.U\`0`"````_GP!`%`````!?0$`"@```%)]`0`/
M````77T!``X```!M?0$`!P```'Q]`0`8````A'T!`!,```"=?0$`!0```+%]
M`0`.````MWT!``@```#&?0$`$````,]]`0`3````X'T!``8```#T?0$`"@``
M`/M]`0`.````!GX!`!0````5?@$`"P```"I^`0`&````-GX!``L````]?@$`
M#````$E^`0`+````5GX!``T```!B?@$`*@```'!^`0`+````FWX!``T```"G
M?@$`*P```+5^`0`4````X7X!`!<```#V?@$`00````Y_`0`+````4'\!`!<`
M``!<?P$`&0```'1_`0`5````CG\!`!,```"D?P$`'P```+A_`0`,````V'\!
M``8```#E?P$`#P```.Q_`0`&````_'\!`#D````#@`$`.````#V``0`'````
M=H`!``P```!^@`$`'P```(N``0`.````JX`!`!H```"Z@`$`&@```-6``0`)
M````\(`!`!T```#Z@`$`$0```!B!`0`D````*H$!`!P```!/@0$`"@```&R!
M`0`3````=X$!``@```"+@0$`#@```)2!`0`D````HX$!`$````#(@0$`#@``
M``F"`0`8````&((!`#`````Q@@$`"````&*"`0`+````:X(!`"0```!W@@$`
M#P```)R"`0`'````K((!`!````"T@@$`5@```,6"`0`%````'(,!``<````B
M@P$`!P```"J#`0`.````,H,!``X```!!@P$`$````%"#`0`1````88,!`!@`
M``!S@P$`$@```(R#`0`8````GX,!`!8```"X@P$`"````,^#`0`&````V(,!
M``L```#?@P$`#````.N#`0`"````^(,!``H```#[@P$`$`````:$`0`G````
M%X0!`!D````_A`$`%````%F$`0`&````;H0!``T```!UA`$`#@```(.$`0`/
M````DH0!`#H```"BA`$`+0```-V$`0`.````"X4!`!$````:A0$`9P```"R%
M`0`4````E(4!`!0```"IA0$`%@```+Z%`0`'````U84!``4```#=A0$`'P``
M`..%`0`L`````X8!`"(````PA@$`'@```%.&`0`B````<H8!`!H```"5A@$`
M&P```+"&`0`%````S(8!``<```#2A@$`!P```-J&`0`(````XH8!`!(```#K
MA@$`$0```/Z&`0`2````$(<!`!$````CAP$`(````#6'`0`4````5H<!``\`
M``!KAP$`#P```'N'`0`'````BX<!``@```"3AP$`%````)R'`0`6````L8<!
M`#````#(AP$`#P```/F'`0`+````"8@!``<````5B`$`(````!V(`0`;````
M/H@!`"0```!:B`$`(P```'^(`0`?````HX@!`!\```##B`$`*0```..(`0`<
M````#8D!`!8````JB0$`!@```$&)`0`<````2(D!``H```!EB0$`#0```'")
M`0`%````?HD!``8```"$B0$`"````(N)`0`+````E(D!``T```"@B0$`$```
M`*Z)`0`4````OXD!``X```#4B0$`#@```..)`0`/````\HD!``4````"B@$`
M"`````B*`0`B````$8H!`",````TB@$`%0```%B*`0`.````;HH!`!$```!]
MB@$`$````(^*`0`H````H(H!``L```#)B@$`!0```-6*`0`4````VXH!`!4`
M``#PB@$`#`````:+`0`-````$XL!``<````ABP$`!````"F+`0`<````+HL!
M``\```!+BP$`!0```%N+`0`A````88L!``T```"#BP$`DP```)&+`0`5````
M)8P!``D````[C`$`"@```$6,`0`3````4(P!``P```!DC`$`#@```'&,`0`(
M````@(P!`!(```")C`$``@```)R,`0`(````GXP!``8```"HC`$`$0```*^,
M`0`.````P8P!`!$```#0C`$`'0```.*,`0`)`````(T!``H````*C0$`#P``
M`!6-`0`(````)8T!``D````NC0$`!0```#B-`0`<````/HT!``D```!;C0$`
M!@```&6-`0`0````;(T!``\```!]C0$`!P```(V-`0`%````E8T!``4```";
MC0$`"0```*&-`0`'````JXT!`!$```"SC0$`!````,6-`0`%````RHT!``T`
M``#0C0$`"P```-Z-`0`*````ZHT!``<```#UC0$`%````/V-`0`)````$HX!
M``<````<C@$`#P```"2.`0`C````-(X!`$@```!8C@$`*P```*&.`0`K````
MS8X!``8```#YC@$`"@````"/`0`$````"X\!``D````0CP$`"````!J/`0`4
M````(X\!``L````XCP$`!@```$2/`0`-````2X\!``8```!9CP$`!````&"/
M`0!&````98\!`$\```"LCP$`2P```/R/`0`@````2)`!``4```!ID`$`#@``
M`&^0`0`$````?I`!``8```"#D`$`!@```(J0`0`8````D9`!`!0```"JD`$`
M%0```+^0`0`'````U9`!``0```#=D`$`%@```.*0`0`$````^9`!``\```#^
MD`$`&P````Z1`0`&````*I$!``4````QD0$`)P```#>1`0`$````7Y$!``H`
M``!DD0$`#0```&^1`0`.````?9$!``@```",D0$`"0```)61`0`%````GY$!
M`#````"ED0$`,@```-:1`0`Z````"9(!`"````!$D@$`20```&62`0`Y````
MKY(!`"D```#ID@$`.````!.3`0`J````3),!`"P```!WDP$`(0```*23`0`1
M````QI,!`!````#8DP$`"P```.F3`0`E````]9,!`"<````;E`$`(0```$.4
M`0`C````990!``<```")E`$`"0```)&4`0`*````FY0!``8```"FE`$`*0``
M`*V4`0`I````UY0!`#(````!E0$`"0```#25`0`?````/I4!`"T```!>E0$`
M%@```(R5`0`1````HY4!``<```"UE0$`"P```+V5`0`-````R94!`!````#7
ME0$`#P```.B5`0!`````^)4!`(T````YE@$`9````,>6`0`1````+)<!``@`
M```^EP$`"0```$>7`0`0````49<!`!$```!BEP$`#````'27`0`%````@9<!
M`!````"'EP$`$````)B7`0`.````J9<!`!,```"XEP$`'````,R7`0`F````
MZ9<!`'0````0F`$`$````(68`0`%````EI@!`!4```"<F`$`"0```+*8`0`$
M````O)@!``L```#!F`$`'@```,V8`0`5````[)@!``H````"F0$`#@````V9
M`0`0````')D!`!,````MF0$`(@```$&9`0`@````9)D!`"````"%F0$`'@``
M`*:9`0`D````Q9D!`"(```#JF0$`&@````V:`0`U````*)H!`!(```!>F@$`
M$````'&:`0`2````@IH!`!(```"5F@$`%````*B:`0`5````O9H!`!,```#3
MF@$`$````.>:`0`2````^)H!`"D````+FP$`$P```#6;`0`5````29L!`$H`
M``!?FP$`'````*J;`0`,````QYL!`!$```#4FP$`(0```.:;`0`5````")P!
M`!$````>G`$`$@```#"<`0`=````0YP!`!\```!AG`$`%@```(&<`0`7````
MF)P!`!4```"PG`$`$P```,:<`0`=````VIP!`"````#XG`$`)0```!F=`0`3
M````/YT!`!0```!3G0$`%````&B=`0`<````?9T!`!4```":G0$`%0```+"=
M`0`9````QIT!``L```#@G0$`&P```.R=`0`<````")X!``0````EG@$`!P``
M`"J>`0`)````,IX!`!<````\G@$`!@```%2>`0`1````6YX!``H```!MG@$`
M!@```'B>`0`'````?YX!``@```"'G@$`!@```)">`0`4````EYX!``8```"L
MG@$`"````+.>`0`(````O)X!``<```#%G@$`!P```,V>`0`0````U9X!``X`
M``#FG@$`$@```/6>`0`0````")\!``D````9GP$`%0```".?`0`%````.9\!
M`#`````_GP$`$P```'"?`0`.````A)\!`!````"3GP$`#@```*2?`0`.````
MLY\!``X```#"GP$`*P```-&?`0`&````_9\!``@````$H`$`-0````V@`0`>
M````0Z`!``X```!BH`$`!@```'&@`0`)````>*`!``D```""H`$`!0```(R@
M`0`D````DJ`!`!4```"WH`$`&0```,V@`0`6````YZ`!`!0```#^H`$`(0``
M`!.A`0`E````-:$!`"T```!;H0$`!@```(FA`0`$````D*$!``@```"5H0$`
M'````)ZA`0`'````NZ$!``4```##H0$`#````,FA`0`+````UJ$!``8```#B
MH0$`!````.FA`0`'````[J$!`!4```#VH0$`#`````RB`0`.````&:(!``\`
M```HH@$`&````#BB`0`9````4:(!`!,```!KH@$`'0```'^B`0`3````G:(!
M`!,```"QH@$`"0```,6B`0`&````SZ(!`!````#6H@$`/P```.>B`0`&````
M)Z,!``\````NHP$`'@```#ZC`0`1````7:,!`!4```!OHP$`#````(6C`0`.
M````DJ,!``L```"AHP$`"0```*VC`0`/````MZ,!``P```#'HP$`#0```-2C
M`0`=````XJ,!`"(`````I`$`(@```".D`0`H````1J0!``P```!OI`$`!P``
M`'RD`0`+````A*0!`!,```"0I`$`%````*2D`0`&````N:0!``\```#`I`$`
M(@```-"D`0`-````\Z0!``\````!I0$`'@```!&E`0!E````,*4!`"````"6
MI0$`#````+>E`0`'````Q*4!``8```#,I0$`'@```-.E`0`=````\J4!`!H`
M```0I@$`"0```"NF`0`"````-:8!``0````XI@$`(````#VF`0`&````7J8!
M``4```!EI@$`*@```&NF`0`*````EJ8!``<```"AI@$`"@```*FF`0`/````
MM*8!``X```#$I@$`!@```-.F`0`'````VJ8!``H```#BI@$`!0```.VF`0`%
M````\Z8!`(,```#YI@$`#````'VG`0`/````BJ<!`!@```":IP$`"0```+.G
M`0`*````O:<!`!X```#(IP$`+````.>G`0`/````%*@!``H````DJ`$`$```
M`"^H`0`*````0*@!``D```!+J`$`&@```%6H`0`I````<*@!`"<```":J`$`
M)@```,*H`0`>````Z:@!`!8````(J0$`"````!^I`0`)````**D!``H````R
MJ0$`!P```#VI`0`,````1:D!``T```!2J0$`!@```&"I`0!2````9ZD!``\`
M``"ZJ0$`#@```,JI`0`)````V:D!`"````#CJ0$`60````2J`0`:````7JH!
M``8```!YJ@$`'@```("J`0`M````GZH!``@```#-J@$`!P```-:J`0`?````
MWJH!``@```#^J@$`"P````>K`0`G````$ZL!`"8````[JP$`)0```&*K`0`)
M````B*L!``H```"2JP$`(@```)VK`0!<````P*L!`!0````=K`$`)@```#*L
M`0`4````6:P!``(```!NK`$`$0```'&L`0`+````@ZP!`!8```"/K`$`#@``
M`*:L`0`'````M:P!`!(```"]K`$`!@```-"L`0`(````UZP!`!$```#@K`$`
M#0```/*L`0`*`````*T!``P````+K0$`,P```!BM`0`'````3*T!`!$```!4
MK0$`$@```&:M`0`@````>:T!`!<```":K0$`#P```+*M`0`1````PJT!``\`
M``#4K0$`#P```.2M`0`/````]*T!``\````$K@$`"````!2N`0`<````':X!
M`!X````ZK@$`"P```%FN`0`2````9:X!`!T```!XK@$`#````):N`0`7````
MHZX!``\```"[K@$`#0```,NN`0`$````V:X!``<```#>K@$`!0```.:N`0`%
M````[*X!``H```#RK@$`%0```/VN`0`1````$Z\!`!H````EKP$`%@```$"O
M`0`4````5Z\!`!<```!LKP$`'@```(2O`0`=````HZ\!`!H```#!KP$`!@``
M`-RO`0`*````XZ\!``X```#NKP$`#0```/VO`0`'````"[`!`",````3L`$`
M#0```#>P`0`-````1;`!`!H```!3L`$`)@```&ZP`0`4````E;`!``<```"J
ML`$`$````+*P`0`(````P[`!`!0```#,L`$`$P```.&P`0`)````];`!``D`
M``#_L`$`!0````FQ`0`'````#[$!``(````7L0$`!````!JQ`0`"````'[$!
M`$0````BL0$`0P```&>Q`0`-````J[$!`"(```"YL0$`-@```-RQ`0`,````
M$[(!`"D````@L@$`'0```$JR`0`B````:+(!`"(```"+L@$`)P```*ZR`0`0
M````UK(!`!0```#GL@$`'@```/RR`0`5````&[,!`!@````QLP$`%P```$JS
M`0`3````8K,!`!<```!VLP$`'````(ZS`0`:````J[,!`"\```#&LP$`+P``
M`/:S`0`S````)K0!`#````!:M`$`,0```(NT`0`N````O;0!`&L```#LM`$`
M)0```%BU`0`9````?K4!``L```"8M0$`&P```*2U`0`*````P+4!`!4```#+
MM0$`*@```.&U`0`L````#+8!`"@````YM@$`"0```&*V`0!;````;+8!`$T`
M``#(M@$`"0```!:W`0`@````(+<!`"8```!!MP$`#@```&BW`0`8````=[<!
M`!L```"0MP$`!0```*RW`0`*````LK<!``@```"]MP$`$````,:W`0`2````
MU[<!``L```#JMP$`"@```/:W`0`-`````;@!`"4````/N`$`"0```#6X`0`)
M````/[@!`!(```!)N`$`%0```%RX`0`0````<K@!`#D```"#N`$``@```+VX
M`0`'````P+@!``X```#(N`$`!P```->X`0`'````W[@!`!,```#GN`$`"```
M`/NX`0`X````!+D!``X````]N0$`&0```$RY`0`$````9KD!`#````!KN0$`
M'````)RY`0`L````N;D!`%4```#FN0$`%@```#RZ`0!'````4[H!`",```";
MN@$`$0```+^Z`0`)````T;H!`!````#;N@$`$0```.RZ`0`,````_KH!`!,`
M```+NP$`#````!^[`0`;````++L!`!L```!(NP$``P```&2[`0`+````:+L!
M`!(```!TNP$`*````(>[`0`<````L+L!`!X```#-NP$`$P```.R[`0`2````
M`+P!`"<````3O`$`"0```#N\`0`1````1;P!`!(```!7O`$`!P```&J\`0`*
M````<KP!``<```!]O`$`#@```(6\`0`'````E+P!`!````"<O`$`'````*V\
M`0`2````RKP!``4```#=O`$`"````..\`0`%````[+P!`!P```#RO`$`!@``
M``^]`0`1````%KT!``@````HO0$`$0```#&]`0`(````0[T!`!H```!,O0$`
M#@```&>]`0`K````=KT!`!<```"BO0$`"0```+J]`0`*````Q+T!`!T```#/
MO0$`!0```.V]`0`3````\[T!``4````'O@$`*`````V^`0`'````-KX!``D`
M```^O@$`'````$B^`0`\````9;X!``8```"BO@$`&P```*F^`0`0````Q;X!
M``@```#6O@$`$P```-^^`0`+````\[X!``0```#_O@$`"`````2_`0`+````
M#;\!``<````9OP$`"0```"&_`0`(````*[\!``<````TOP$`!P```#R_`0`5
M````1+\!`"T```!:OP$`.P```(B_`0`7````Q+\!`"````#<OP$`%0```/V_
M`0`^````$\`!`!P```!2P`$`'0```&_``0`E````C<`!`%@```"SP`$`(```
M``S!`0`%````+<$!``H````SP0$`!P```#[!`0`)````1L$!`!(```!0P0$`
M%0```&/!`0`X````><$!`",```"RP0$`'P```-;!`0`U````]L$!`#H````L
MP@$`"@```&?"`0`:````<L(!``P```"-P@$`"@```)K"`0`A````I<(!`!,`
M``#'P@$`$@```-O"`0`.````[L(!``<```#]P@$`#P````7#`0`)````%<,!
M`!`````?PP$`#@```###`0`:````/\,!`!<```!:PP$`,````'+#`0`+````
MH\,!`!\```"OPP$`!0```,_#`0`&````U<,!``<```#<PP$`'@```.3#`0`,
M`````\0!``0````0Q`$`$````!7$`0`/````)L0!``D````VQ`$`#````$#$
M`0`.````3<0!`!8```!<Q`$`!0```'/$`0`$````><0!`!(```!^Q`$`,0``
M`)'$`0!$````P\0!`!<````(Q0$`!P```"#%`0`C````*,4!`!@```!,Q0$`
M%````&7%`0`.````>L4!``\```")Q0$`#0```)G%`0`-````I\4!`"\```"U
MQ0$`!@```.7%`0`+````[,4!``T```#XQ0$`#P````;&`0`+````%L8!`#P`
M```BQ@$`!@```%_&`0`>````9L8!``\```"%Q@$`$P```)7&`0`G````J<8!
M`!\```#1Q@$`.P```/'&`0`\````+<<!`#@```!JQP$`$0```*/'`0`(````
MM<<!`!$```"^QP$`$P```-#'`0`8````Y,<!``@```#]QP$`$`````;(`0`6
M````%\@!``<````NR`$`$0```#;(`0`<````2,@!``L```!ER`$`!0```''(
M`0`,````=\@!``L```"$R`$`$````)#(`0`%````H<@!``<```"GR`$`"@``
M`*_(`0`3````NL@!`!,```#.R`$`#````.+(`0`,````[\@!``8```#\R`$`
M"0````/)`0`V````#<D!`"@```!$R0$`(P```&W)`0`'````D<D!`"````"9
MR0$`!@```+K)`0`D````P<D!`!4```#FR0$`*````/S)`0`1````)<H!`!$`
M```WR@$`'````$G*`0`#````9LH!``@```!JR@$`$@```'/*`0`"````ALH!
M``P```")R@$`%````);*`0`+````J\H!`!@```"WR@$`'````-#*`0`8````
M[<H!``4````&RP$`"@````S+`0`4````%\L!`!P````LRP$`#0```$G+`0`'
M````5\L!``P```!?RP$`"@```&S+`0`1````=\L!`$H```")RP$`'````-3+
M`0`W````\<L!`!@````IS`$`!0```$+,`0`$````2,P!``H```!-S`$`$0``
M`%C,`0`2````:LP!`!<```!]S`$`%0```)7,`0`0````J\P!`!H```"\S`$`
M#@```-?,`0`D````YLP!``\````+S0$`$````!O-`0!K````+,T!`"````"8
MS0$`'@```+G-`0`<````V,T!`"````#US0$`&````!;.`0`D````+\X!`!(`
M``!4S@$`&0```&?.`0`4````@<X!``H```"6S@$`!P```*'.`0`+````J<X!
M``<```"US@$`%````+W.`0`+````TLX!`#H```#>S@$`$P```!G/`0`:````
M+<\!``@```!(SP$`!0```%'/`0!*````5\\!`$\```"BSP$`30```/+/`0!D
M````0-`!``<```"ET`$`*````*W0`0`L````UM`!``H````#T0$`"`````[1
M`0`-````%]$!`#(````ET0$`!0```%C1`0!2````7M$!`"P```"QT0$`)```
M`-[1`0`.`````](!`"`````2T@$`'````#/2`0`C````4-(!`!T```!TT@$`
M(P```)+2`0`:````MM(!``P```#1T@$`!P```-[2`0`0````YM(!`!$```#W
MT@$`%`````G3`0`(````'M,!`$`````GTP$`#````&C3`0`(````==,!``T`
M``!^TP$`&@```(S3`0`)````I],!``0```"QTP$`%@```+;3`0`(````S=,!
M``@```#6TP$`!````-_3`0`+````Y-,!``L```#PTP$`%````/S3`0`3````
M$=0!``X````EU`$`%````#34`0`.````2=0!``<```!8U`$`$````&#4`0`<
M````<=0!``L```".U`$`#0```)K4`0`;````J-0!`"H```#$U`$`&````._4
M`0`>````"-4!`"H````GU0$`!````%+5`0`$````5]4!``T```!<U0$`!P``
M`&K5`0`*````<M4!`!8```!]U0$`"````)35`0`*````G=4!``@```"HU0$`
M!P```+'5`0`)````N=4!``D```##U0$`"0```,W5`0`,````U]4!``X```#D
MU0$`!````//5`0`.````^-4!``H````'U@$`"@```!+6`0`/````'=8!`!P`
M```MU@$`"P```$K6`0`"````5M8!`!\```!9U@$`!P```'G6`0`&````@=8!
M`&@```"(U@$`#````/'6`0`(````_M8!`"@````'UP$`1````##7`0`?````
M==<!`"T```"5UP$`6````,/7`0`F````'-@!`"D```!#V`$`&````&W8`0`=
M````AM@!``4```"DV`$`"@```*K8`0`-````M=@!``T```##V`$`"P```-'8
M`0`-````W=@!`!4```#KV`$`#P````'9`0`-````$=D!``\````?V0$`#P``
M`"_9`0`$````/]D!``<```!$V0$`"````$S9`0`9````5=D!``@```!OV0$`
M!@```'C9`0`'````?]D!`!,```"'V0$`!@```)O9`0`;````HMD!`!8```"^
MV0$`"P```-79`0`9````X=D!``P```#[V0$`%@````C:`0`,````']H!``@`
M```LV@$`#P```#7:`0`2````1=H!``\```!8V@$`!@```&C:`0`7````;]H!
M``L```"'V@$`'@```)/:`0`&````LMH!``@```"YV@$`#0```,+:`0`@````
MT-H!``D```#QV@$`"P```/O:`0`F````!]L!`!@````NVP$`$````$?;`0`&
M````6-L!``L```!?VP$`#@```&O;`0`)````>ML!``(```"$VP$`#@```(?;
M`0`'````EML!`"8```">VP$`*0```,7;`0`K````[]L!`!P````;W`$`+```
M`#C<`0`I````9=P!`%H```"/W`$`#0```.K<`0!-````^-P!`#0```!&W0$`
M4P```'O=`0!,````S]T!`"$````<W@$`,P```#[>`0`F````<MX!`#(```"9
MW@$`*P```,S>`0`3````^-X!`#T````,WP$`F`(``$K?`0`:````X^$!`!``
M``#^X0$`/P````_B`0"%````3^(!`"X```#5X@$`)0````3C`0!$````*N,!
M`$\```!OXP$`2@```+_C`0`L````"N0!`!D````WY`$`$````%'D`0`E````
M8N0!`!L```"(Y`$`'````*3D`0`H````P>0!`"<```#JY`$`*@```!+E`0`P
M````/>4!`!D```!NY0$`#0```(CE`0`K````EN4!`"0```#"Y0$`*````.?E
M`0`A````$.8!`!P````RY@$`.@```$_F`0!E````BN8!`#4```#PY@$`2P``
M`";G`0`U````<N<!`"@```"HYP$`-@```-'G`0!<````".@!`#H```!EZ`$`
M+P```*#H`0`H````T.@!`"P```#YZ`$`5P```";I`0!6````?ND!`$<```#5
MZ0$`10```!WJ`0`O````8^H!`"D```"3Z@$`*0```+WJ`0`I````Y^H!`&@`
M```1ZP$`8@```'KK`0!K````W>L!`+L```!)[`$`&@````7M`0`N````(.T!
M`#<```!/[0$`*````(?M`0!D````L.T!`!@````5[@$`6````"[N`0`<````
MA^X!``L```"D[@$`S````+#N`0!/````?>\!`"(```#-[P$`/````/#O`0`@
M````+?`!`!@```!.\`$`,P```&?P`0`&````F_`!``<```"B\`$`!````*KP
M`0`,````K_`!`!````"\\`$`#````,WP`0`+````VO`!``<```#F\`$`$@``
M`.[P`0`-`````?$!`((````/\0$`!@```)+Q`0`5````F?$!``0```"O\0$`
M!P```+3Q`0`(````O/$!``4```#%\0$`4@```,OQ`0`$````'O(!`!D````C
M\@$`"@```#WR`0`2````2/(!`!````!;\@$``@```&SR`0`'````;_(!``8`
M``!W\@$`$P```'[R`0`,````DO(!`!8```"?\@$`!@```+;R`0`4````O?(!
M``\```#2\@$``P```.+R`0`N````YO(!``0````5\P$`!@```!KS`0`'````
M(?,!`!X````I\P$`/````$CS`0`N````A?,!`"\```"T\P$`%@```.3S`0`H
M````^_,!`#`````D]`$`(@```%7T`0`J````>/0!`"````"C]`$`(P```,3T
M`0`>````Z/0!`!P````']0$`+````"3U`0`D````4?4!`!H```!V]0$`+@``
M`)'U`0`:````P/4!`"P```#;]0$`,`````CV`0`@````.?8!`"0```!:]@$`
M)````'_V`0`?````I/8!`",```#$]@$`+````.CV`0`G````%?<!`"<````]
M]P$`)0```&7W`0`?````B_<!`"0```"K]P$`,````-#W`0`=`````?@!`"H`
M```?^`$`-@```$KX`0`Y````@?@!`!H```"[^`$`)P```-;X`0!-````_O@!
M`"D```!,^0$`+0```';Y`0`M````I/D!`"X```#2^0$`*`````'Z`0`F````
M*OH!`"$```!1^@$`)P```'/Z`0`X````F_H!`"H```#4^@$`-0```/_Z`0`,
M````-?L!``X```!"^P$`(````%'[`0`J````<OL!`"$```"=^P$`#P```+_[
M`0`/````S_L!`!H```#?^P$`&@```/K[`0`+````%?P!`"<````A_`$`#```
M`$G\`0`*````5OP!`"4```!A_`$`*````(?\`0`B````L/P!`"<```#3_`$`
M(@```/O\`0`'````'OT!`-P````F_0$`"P````/^`0`3````#_X!``<````C
M_@$`"@```"O^`0`0````-OX!`!(```!'_@$`'````%K^`0`#````=_X!`#,`
M``![_@$`&P```*_^`0`8````R_X!``<```#D_@$`$@```.S^`0`2````__X!
M`#,````2_P$`"````$;_`0`I````3_\!`!,```!Y_P$`$P```(W_`0`9````
MH?\!`#,```"[_P$`'0```.__`0`.````#0`"`",````<``(`#P```$```@`0
M````4``"`!<```!A``(`"@```'D``@`?````A``"``\```"D``(`'0```+0`
M`@`/````T@`"`!X```#B``(`)@````$!`@`%````*`$"`!`````N`0(`!P``
M`#\!`@`+````1P$"``D```!3`0(`.````%T!`@`&````E@$"``\```"=`0(`
M$0```*T!`@`0````OP$"``L```#0`0(`#P```-P!`@`'````[`$"`!````#T
M`0(`"`````4"`@`;````#@("``@````J`@(`&P```#,"`@`;````3P("``L`
M``!K`@(`#0```'<"`@`<````A0("``@```"B`@(`,0```*L"`@`1````W0("
M`!````#O`@(`"``````#`@`"````"0,"``H````,`P(`&````!<#`@`+````
M,`,"``,````\`P(`"P```$`#`@`+````3`,"``H```!8`P(`%P```&,#`@`.
M````>P,"`!@```"*`P(`'@```*,#`@`,````P@,"`#D```#/`P(`(@````D$
M`@`C````+`0"`!D```!0!`(`#0```&H$`@!%````>`0"``8```"^!`(`&@``
M`,4$`@!6````X`0"``\````W!0(`$````$<%`@`'````6`4"``0```!@!0(`
M!0```&4%`@`1````:P4"`!8```!]!0(`!@```)0%`@`'````FP4"``<```"C
M!0(`"P```*L%`@`#````MP4"``P```"[!0(`#0```,@%`@`Y````U@4"`"X`
M```0!@(`+````#\&`@`%````;`8"`!8```!R!@(`)0```(D&`@`B````KP8"
M`!\```#2!@(`$P```/(&`@`"````!@<"``0````)!P(`#0````X'`@`*````
M'`<"``4````G!P(`!0```"T'`@`/````,P<"`$T```!#!P(`)````)$'`@`7
M````M@<"`"(```#.!P(`,````/$'`@!.````(@@"`!8```!Q"`(`?@```(@(
M`@`>````!PD"`%D````F"0(`*@```(`)`@!/````JPD"`#````#["0(`*```
M`"P*`@`M````50H"`"T```"#"@(`*P```+$*`@`N````W0H"`"D````,"P(`
M*````#8+`@`L````7PL"`#<```","P(`%````,0+`@`:````V0L"``P```#T
M"P(`J`````$,`@`&````J@P"`+D```"Q#`(`A0```&L-`@"@````\0T"`"``
M``"2#@(`5P```+,.`@`0````"P\"`!T````<#P(`$0```#H/`@`'````3`\"
M`!D```!4#P(`'@```&X/`@!!````C0\"`!D```#/#P(`%@```.D/`@!7````
M`!`"`!H```!8$`(`#P```',0`@`*````@Q`"``4```".$`(`!@```)00`@`(
M````FQ`"``4```"D$`(`&0```*H0`@`)````Q!`"`!@```#.$`(`(@```.<0
M`@`/````"A$"``D````:$0(`#@```"01`@`)````,Q$"``P````]$0(`!P``
M`$H1`@`%````4A$"`!````!8$0(`$````&D1`@`.````>A$"`!````")$0(`
M"@```)H1`@`)````I1$"`!````"O$0(`"````,`1`@`3````R1$"``H```#=
M$0(`"P```.@1`@`8````]!$"``D````-$@(`!@```!<2`@`;````'A("`!@`
M```Z$@(`#@```%,2`@`4````8A("``L```!W$@(`)@```(,2`@`4````JA("
M``<```"_$@(`%0```,<2`@`'````W1("``@```#E$@(`(@```.X2`@`+````
M$1,"``(````=$P(``@```"`3`@`:````(Q,"``P````^$P(`!@```$L3`@`(
M````4A,"`!H```!;$P(`!@```'83`@`E````?1,"``(```"C$P(`!````*83
M`@`1````JQ,"`!<```"]$P(`"P```-43`@`)````X1,"`!````#K$P(`"@``
M`/P3`@`6````!Q0"``<````>%`(`'````"84`@`*````0Q0"`!<```!.%`(`
M`@```&84`@`%````:10"`!````!O%`(`#````(`4`@`2````C10"`"D```"@
M%`(`!P```,H4`@`'````TA0"`!$```#:%`(`!0```.P4`@`"````\A0"``L`
M``#U%`(``0```-,$```<!```,04``%\#````````G`$``&T"``"@!```````
M`)0#``#'`0``_`8``'P``````````````(8"```J!P``"P$```````""!P``
MP0```'<%```5!```\04``"P```#;`P``P@8``"0'```(`@```00``+P%```#
M!P``,0,```````"F`@``\`4``&0"``"R`@``#P0``($#````````````````
M````````U@0``%$%``"%!`````````````#V`0``<`(`````````````?P(`
M`"X$````````(P$``*0%````````8P<``.0%``"0!@``)0$``'$&``#U!```
M;@(``'`!```T!P``P@$``-$"```O!```;P,``$\'``!:````H@$``#,!``"*
M!P```````'L!``#K````EP8``,`%``!=!P``2@4``,T&````````E`0``&("
M``#R````*0(``&8"````````VP0``(4&``#>!0````````````"E````````
M````````````F`,```````!`````Y08```````#-`0```````)T$``!(`@``
MOP4```````#]`@``B0<````````,!0```````$\$``#,!0``[`(``"8%```7
M`````````#0```!8````O`$`````````````M0(``%H$``!E`P``:@,``%\!
M``"#!P``````````````````^@$``&0#``!O````U@$```````!^!@``````
M``D'``"0`````````$T#``";`@```````!P#``!>!@``]`$``-\````H`P``
MW`$``-`!``"V`P``1P,````````<!P``$@<``"4#``#Q````L`4``-($````
M`````````*L#``"D`````````,L%``!A`P``>0,``)4$```*!````````(L&
M``#``0```````.$$``!Y!P``V0,``.<!````````_P4``$L'``"I`0``6`0`
M`.0!````````3P```+X!```````````````````O`P``;0<```````"R````
M`````)@%``!G!```I08``.(!``!'!@```````"H```#[`0``:`$``%4'``#:
M`P``*08``*,$``!5!@``5@0``+`&````````G0(``%L```"3!@``BP,``*D`
M````````K`4``-,```"@`P``>@$``&<"``#"`P``*0<``'L#```K````````
M`#8``````````````#$"``"#````Y`0```````#V!```>00``$4'````````
M]P``````````````DP(``+H%````````%P4``*H#```K`@``>P<```````!T
M!```.P(`````````````D`(``(X!``"*!```W````'T'``!7!0``F@,```,"
M```\!P``7@,```8!````````100````````N!P``GP,``*4!````````````
M`&<%``!Q`0````````````!#!@``VP```#X'``!*``````````("````````
M*0$```````!6`P```````)P$````````S`$``&$$```6`P```````"<$``!A
M```````````````E!```=P```.X#``!G!@```````)T&````!@``>P``````
M```9!@``L00```,````$!P``W04``+@&``#)`P``?`(``!<'``#L````````
M``````!C`0```````.X"``":````D@```)X#````````FP$``"L%``!Q`@``
M\P,``$8#``"^`@``N@$``-T$``#7!@``M`,``.,$``#*!```J@0````````9
M!P``%P(``+\$```8`0``L0(`````````````X@,``(\"````````?@$``/X%
M``!I`0``%P8``/@!```J`P``2P,``'(#``!'!```E@$``$<```#(`0``<0,`
M`$\&```Z````808``%,```#6!@``=@(````````N!0``)@(``'0&``#M````
M"P8```0```#D`@``?@,``(,%``")`0``DP0``/X"``!E!P``YP4``!<!````
M````GP$```X'``![`@``?@````4$```*!P``+@8``#4&````````4@(``+\`
M````````=P,``/\#````````"P```#,%`````````````&<'```H!@``W0``
M``````#T`@``0`<```````#8`P``V@0`````````````:`````T"``!S!@``
M`````-0&``#&!@``<0```*````#]!@``0@(```````";!```N0,``,`````$
M!```#P8``$P!``"4`@``N04``*`!``#!`0````````4`````````30<``-8"
M``!C`````````,0```````````````````#R!````````$`%``!P!P``````
M`,X&````````%P,``((&`````````````%(%`````````````/,$``!W!```
MI`8``&\$```(````7@```$D'``"Z`P``=@4``-X```"$`P``)`0``#L%``#X
M!@``G`,``'<"````````:@$``#X"``"_!@``[@4``+X$````````<`8`````
M``")````I0(````````T!@```````!T'````````50$``"($```X`0``````
M`&T$````````AP(``'D%``"`!0``U@`````````A`@``4`8``#<$```S`@``
M``````````"7`P``_P0```$'```'`P``:@8```````#Q`0``Q@```/`#``"/
M````7`<`````````````Z`8``(4#`````````````-T"```N`P``5P$``/4&
M````````Y0$``/X```!-````S00``!`%````````-@$``)`#``!]`0``EP``
M`%D$``!_!```<P```*<%``!8`@``@@(```````!"!@``=@$``/X!````````
MYP0````````D`````````/@$``!K!```Q@0``%D!```A!```!@```)\"``!>
M`@`````````````$!@``E`4```````#B!@``C@,``#X````K`0``%`(``-<#
M``"2!@``00<```````!L`P```````(X$``"C`````````,4#``!1````O0(`
M`"P$```@!```Z00````````M!@``]@(``"\&``!8!0``````````````````
MJ0(``"0#`````````````+,!````````?0```"<#````````<P<```````"1
M!````````,X!``#Q!@``"`$````````````````````!``!,!0``.08`````
M``#)!0``$0$``%\$``#Z`P``G````+`#``#$`0```````'4$``!Q!```UP(`
M`,H%``!\`0``C`$``````````````````/T%```U!````````#\'``"F!@``
MT`,``*D&``#M`0``I@````````#O`@``````````````````K00``.L!``#Y
M!```WP,``"@$````````9@0``)\````0!@``N00``.H#````````R00``%L"
M``",!````````,0"``"^!0``0@4``'4'``#6!0``E`8```````!D!P``````
M```````;!````````/0#``!4````V0````````!(````E@````````!6`@``
M-P```"`&```\`@``<P(```````#S`@````````@$``"W`@``I00``'@'````
M````VP8``!4`````````V00```````#\`````````!\%``"+!0``]P$``/<%
M``!\`P``V08``+0%``"5!0```P4```````````````````````"#!```OP(`
M`,X"```-!P``F0,``/\"````````]`0``#\"``!3`0```````,4$```R`0``
M`````,L"``",``````````````!+`0````````````"[!@``"0$``-X!```F
M!```I`,``,T%``!S`0``,P0``!$&``"+!```8@`````````O````H08``#@"
M``!9`@``@`<``$@'``"-!0``&0````````"M````[P,``-(&``!\!0``,@``
M`+T%``#*`@```````/<&``"W!@``6P4``$0!`````````````!T"```?!P``
MW`8````````.!0```````&`!```Y`@``0P(``+L!``"``P```````"H!``!&
M````T`(``!0&````````?P```$(#```V!P``+0$``#$$``#A`0```````-(%
M``"T`@``Z`$``%0#``#X`P``?00```````"B`P``U`(``&(#``#K!0``````
M``````!?````'P(``#(#``#\`@```````',$````````@08``#<%```Z!0``
M&`0```````!V````HP,```````"7!0``8@4``!("``!L`0``(@$```````".
M`````````&H%````````Q04``!H!``#@`0```````),#``"8`````````(4%
M```8`````````"P%``"&!````````!P```":!@``:08``/L"``"%`0``````
M`$P#``!I!P``>@0``!`$``!E````5`4``,4&``!T`@``X```````````````
MMP,``'4#`````````````````````````````%P!````````.0<``'X"``!L
M``````````````"(`@```````,\&```+`@``#P4``&T!```M`@``X`4``.<"
M``!/`P``#0$``&````!G`````````,`&``#9`@``N@8`````````````````
M`.H```"R!```*``````````P!P```````/,```"J!0``_0$``-4$```:````
M````````````````8@0```````#)!@``8`8``$X`````````$P(`````````
M````2@0``!8&```C````/P```((%``"H!```N`(``)$%``#D````0@0`````
M``"X!0``004``!\!``"X`0```````)L%````````M0````('```L!P``````
M``````"P!````````&H'``![!0``9@```````````````````,X$```'`0``
M6`8`````````````X`8``&$'```[`0``.P0``'4"``#L!@``.00``"`'``#^
M!@``<@8```P!````````2`8``)X&``"\!```9@8```D%``!&!P``````````
M````````<P,``(L```!Z!P``T@,```$"``"C`0``+`,```````"S!```````
M`"4'```!`P``ZP(``'````!N!@``V````!(&``!%`P``7@<``/,%``#I!@``
MT00``#\#````````^P4``&8'``"@!@``T@(```````!K`0``T0```(H&```P
M````R`(``*$$``#L`0``X@```&H"``"F`0``7`(````````X`P```````%P&
M```K!```8`,``.$%````````SP```)8%``#8!@``10(`````````````E0$`
M````````````!P8``$8%``#_!@```````$D#``!L!0``5`<``-,!``"``0``
M``````````````````````````#]!```;`0```8$```^`P``'P0``-\$````
M````7`,``'X$```1`@``+`8``,L$```;`P```````'\&``!U````!0,``)$!
M````````K``````````$`@``>0$``"D$```U!P```````'H```!T````````
M``````!B`0``5`$```T````_`0``W@,``+4&```X!P`````````````F````
M````````````````B`4``(\$````````1@0```$&````````LP```%`!``"1
M!@``L@$``!8"``!0`@``AP,``&\'``#U`@``M@```/,&``#Q`P``40$``.($
M``#O!````````-`&````````+P(````````,!P``4`````````!4`@``````
M`$P&``"!`@```````!P&````````]`8``(P&``"[````708```````#Y`0``
MA````$8&````````=0$`````````````1`(``$@!```5`P```````"0!``!9
M`P``]0```)H%``!3!0``W08``#D!```:!P```````(@!``!<!0``5P0``$('
M``":`@``/0,``!$#``"N!0``20$```````"?!````````#X!``!J````?@4`
M`*<#``"H!@``(`````````"N````2P```!(```"F!````0$``'D&````````
MU0$``+H```#D`P``M@$`````````````:`0`````````````O@```+D```!R
M!````````!$```!?!0``Y@0``"`#``"K`0``Y@```"("``"?!@``O0$``/(!
M```Z!@``@P8```````"!````$@0``+L"```]!```?P$``!L```"S`@``````
M`+T#``!U!0``90(``(4`````````S0(``,0&``!_!0```````%<"``"?!0``
M\`$``*T#````````B@4``'(!``"Q````@00```````#P!@```````!$'``!O
M`@```````.T#````````$`(``!0!```M`P``1`0```````#5`P``WP(`````
M``!\!@``204```````#;!0``AP0```````"R!@``]P(``*\$```%`@``````
M`"$```#\!0``=P$``#P#```*!@``]`4``/`"``!Q!0``N`,```````#4`P``
MZ`(``%D&````````>P0``$$#````````*@(``)P%``#&!0``V@4``&$%````
M```````````'``!Z!0``1P(``#P```"\```````````````/`P``````````
M```0!P``-P8``!0$`````````````&$"```(!P``,P,```````!``0``/04`
M``````";!@````````````"'`0``R0```.D#``#D!@``O0```(L!``"]!```
M`````#8#```U`@``'04```````"'!@``K@0```<"``#K!```OP,`````````
M`````````$D$``!1!@``M00``',%``#$`P```````&L#``#:`0``L`$`````
M``"3!0```````,H&``"B!0````````D#``!]`P``$P````T$``#%`0``"P0`
M``````!!`@``50```.,%````````K`,```,#```9!```!@8`````````````
MZ@0``.P%```*`P``J`4``+<$```6````5`0``#<!``!5!0``I`(``/D"````
M````@`(``",%``#[`P``0P$``&H$`````````````#\%```3`0```````/(#
M``#'!```O@8```````!(`P```````,T#``!=!0``?`0``#T&``#Y````'@4`
M`$8!````````JP```%8!``#H!```C0````````#.`P``.`8`````````````
MRP```(<```#=`P````````````#,!````````%('````````&04```````#G
M`P``,0```,P#``")!0``$`$```X```!K!P``IP```,\$``!B!P``&`8``-H`
M```A`0``H@(``)@"``!>!```+00``",'``!E`0``>`(``!0'```=!```V04`
M`)P"``!=`````````.`$``!F!0``/P8``.8"````````L@4````````$`P``
M'@0```````````````````0%````````DP$``(8&``!T`P``KP,``/H&````
M````D@0``(4"```>!@```````-P#````````6P$``%L'```4`P``\0(``#,'
M``!T!0``J`,``%T!```K!@``````````````````KP8``.`#``!.`P``_`0`
M`#H'``!X!````````"\%``!H!@``U````*`"``#Y`P```````"@%``"&!P``
M[04``'("````````*0`````````&`@````````L'``#E!````````%(&````
M`````````"<'```"!@```````$8"``````````````````#7`0``S0```#<#
M```$`0```````"L'``!R!P``8P8```````"!!0``;@$``*\"``#$!```+@(`
M`%4$``````````````````"$!0``$P0``)$"``!7!@``T@```*X#``!)!@``
M-P<``'P'````````T`0``!L%````````N@0`````````````@@$`````````
M````(P(``%H!````````&P<``#('```@`@``J`(``"8'````````.@0``(D"
M``!K````\@8``#D%```\`0``$04```````#E!0``B@```!P!``"K!```B0,`
M``8%````````(@4``%T"````````Z@$```````#Z!````````-\!``!'!0``
M`````!,&``"(````Z0(``#0$``#E`P``JP4``,X%``#'`P```````#\$````
M``````````````#J`@``H0,``/X#```8!0``,P```/8%``!W!P```````&\&
M````````RP,``&\!```>`P``604```````"&````@P$```````"T````CP,`
M`(0$```P!```MP$``)D"``"@!0``M@(``.4"````````,@0``*$````L`@``
MR`,```L#````````C`4````````;!@``K`0``````````````````&L%````
M````V`$````````.!```"`8````````E````X0,``)X``````````````'(%
M```?!@```````!4!```^!0``'0```,P"``">!0``B08``(X"```A!0``E@(`
M``````!`!@``008``*$!``"A!0``)P(`````````````+0```$H'``"5`@``
M4@0`````````````-`(``/@%``!T`0``70,``#4!````````3@0``%8%``"B
M!```"0```,,%``"#`P```````%@!``!I`@``[`,``!D"````````P@(``%H'
M``!#`P``/`0``)`!``#F`0``XP,``%$$`````````````*P"```.`@``'`(`
M`$X!``!(!```"@````````!-!@``_`$``"X```"-`0```````"T'``#M`@``
MZ0$``,\!``!L`@````````````#:`@``PP(``"<```"S`P``D@4```````!N
M````$`````````"-!```&P$``'`$``!V!P````,``-\%``!3!P``L@,```<'
M``"-`P```````(T"``!G`0``@@,``+\!``!W!@``;@0``*H```!.`@``9`4`
M``````",`P``+P<``(($````````O`,``#X$```8`@```````#<"``"2`P``
M@@`````$```````````````````/`@``%0(``,(```"[`P```````-$&```P
M!0``[@```,$%````````2`4``!,'``!9!P```@0``%X!`````````````-D!
M``!*!@``\00``&T&```X!0``.P<``)H!``#A````O`(``+X#```6!```````
M``````"9!0``Z@4``/4#````````0P<``!D#``#L!```E0,```(#```)!@``
MC@8```````!L!@``8`<``"X!```F!@```````&4&``!I`P```````%\&``"U
M`P``"@(``$D"```?````#`8``&0!`````````````$\"`````````````*8%
M```Q!@``L0$```T&``#2`0``-04``(8!``!<`````````#L&``#F`P``&@4`
M`+L$``"M`@```````(````!Z`P``B`8``,@%``"$!@``W0$``#4#``#O`0``
M```````````,````E@,``&,"``">`@``\@4``````````````````&0$````
M`````````.D```"V!0``H@8````````>`0``P0,``#P&``!P!0``A`$``&L"
M````````300``.<&````````QP8``(\!````````PP```!X'````````8P0`
M`'0'````````#04``#T!``!0!P``;0,``"(&``!$````%@<`````````````
MV`(``$D````[`P``%P0```````#O````:P8````````*!0``4P,```<%```D
M!0``M@8``*D$```'!```1P$``$0&```````````````````@!0```````+``
M``"O````,`8``.\&``#C`````````",&```2`P``P00``-H&````````````
M`'\#```,!```&`,``*P!````````N0$``.,&``#.`````````)(!``!_!P``
MQ0(```(%````````-`$```````"H````+`$```X#````````D`0``!D!``"B
M````4`4```````#J!@``U0(```````````````````D$``"9`0``FP,``*H!
M```,`@``U04``/4%``#U`0``#0,```````"=`0``Q0````````#&`@``5P``
M`#@````H`@````````````#]`P``IP0``+L%````````P@4```````!/`0``
M'0$``.T&``#Y!@``E@0``%`$````````K0$`````````````I`$``*D%``"P
M`@``9`8```````#6`P``%@4``*8#````````&@(````%````````AP<``($'
M``#1!0``XP$``*T&``#C`@``P08``*L"``!P`P``D`4``*\!````````TP4`
M`*,&````````M04```````#/!0``;04```````#X`@```````-X&````````
M`````!\#``!^!P``M`0``*<&````````Q`4``*<!``!#````G0,``!L"````
M````3`0````````"`0``EP(``$\%``!``P``>@8``-P"````````1P<``&,%
M``"`!@``1`,``.4```!-!0``PP8```````````````````````#0````6P,`
M`+<```!Y`@``0P4```````!3!@``UP4``$H"```]````+04```````![!@``
MX`(``&`$```:`P``````````````````PP0```````#3`P``X@(``'@#``"4
M````B`<``!H$````````````````````````000``!H&`````````````%$'
M````````*0,``/T```!7`P`````````````B!P``40,``#H"``"3````\P$`
M`%4"``````````````X&````````F00```````!"`0``7P(``$L$``!,!P``
M;@4``+$#````````A`(``$X&````````)@$```````#;`0```````+$%``!Q
M!P``W`0``&D%``"T!@``)P4``#T'``!$!P``2@,``&D$``#/`P```````&@"
M``"O!0``@`0``'8#``#1`P``4`,``)@!``#A`@``3`(``,($````````B`0`
M`&P'``!R````````````````````^@(````````R!0``:`,```8'```C`P``
M?08```````#H`P``EP0``+4!``#+!@``SP(``"@!``"7`0``RP$```````!7
M!P``4P(``%H#``"&!0```````#`"``#X````F0````````#,````K@(``#0%
M````````UP````````"E!0``````````````````)08``)D&``#N`0``(0,`
M`#L```"8!@``00$``,8#``",`@``!0<``!4%``!E!0``````````````````
M(@,``(H"```>````A`<``%8'``"M!0``10```'8&```X!```PP$``-0!``!"
M````900``"@'``!O!0``]@8``%8````.`0``^@4``$T"``#^!```6@(``*,%
M```%!@``Z04``"(```!%!0```````$L&``"8!```G`8``,$"```#!```````
M``````"]!@``;@,``!4&``#N!@```````'T%``#H````-`,``%H%```2!0``
M#P$``!X"````````:`4````````O`0``/0(``$T!```P`0``)0(``-4`````
M````)04``&8#``#V````>@(``(\&`````````````*,"````````K@$``/P#
M``!A`0``N````)$```````````````````"5````)@,```\`````````````
M`(H#````````?0(``,<%``#&`0```````(8#```A!P``G@$```````#;`@``
MR0$```H!``!5`P``>0```-0$``##`P```````,H!```3`P``````````````
M````;@<``/`$``!V!```"`,````````^!@``V`0```````"A`@``;0```(\%
M```8!P```````%@'```J!````@```&`"```<!0```````/D%``!.!0``````
M`,@````,`P``BP(```````"E`P``"`4````````Y`P``_P$```\'``!=!```
M"0(```````!,````F@0``-$!```I!0``Z`4```````!X`````````&8!``#P
M````[P4``$L"``"W!0``!04```````!2````ZP,``$L%``#5!@``.0```,@$
M``"=!0``P`(``%\'```#`0``>`8``$0%``#?!@`````````````'````-@4`
M`"L#``#Z````R`8``!4'```#!@``R@```'@!```2`0``]P,``.8%``"K!@``
M4P0``%(!````````!@,``+D"``!.!P``%````)$#``"J`@``7`0``-<$```Z
M`P``,`,``/0```!`!````````-X"``"Q!@````````````#<!0``8@8``,`#
M``#*`P``[00``%L$``"4`0``B`,``&@'``"%!P`````````````3!0``C08`
M`*0$```Q!P``B@$``$,$``";````(08``/("``!U!@````````````"V!```
M`````!`#``#K!@``8`4```````#[!```E08``.(%```J!@````````````#W
M!````````+H"````````M`$``$4&````````K@8``%8&```\!0```````$$`
M```V!````````#("`````````04```````".!0``'0,``*<"````````````
M`%(#```G!@``U`4``/L&````````J`$``&,#```1!`````````````!4!@``
M)P$``+,%````````Y@8``-,"````````AP4``(,"``"Y!@``6`,``($!````
M````[@0``"0"``#3!@```````#4```"\!@``R0(``*D#``!9`````````#$!
M````````X08``+,&```+!0``10$``%L&``"X!```-@8```````!:!@``````
M`&0````D!@``QP(```````"=````_P````4!``!``@``B00``&D```#8!0``
M(`$``)X$````````D@(``!0%````````.@$``-`%````````%@$```````!X
M!0``QP```,P&`````````````%X%```C!```]@,``"H%``#G````P`0``*H&
M```=!@``2@$``#(&`````@``9P,``-X$```V`@````````````#[````K`8`
M`)8&``!1`@```````#,&````("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@
M)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T
M97)D87DI`"!A="``(B5S(B!I<R!N;W0@82!D:7)E8W1O<GDN`"(E<R(@:7,@
M;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO="!C;VYF:6=U<F5D(&EN
M('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!T<F5E(')E;F1E<F5R(&YO="!F
M;W5N9"X`(B5S(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN`"(E
M<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"(E<R(@
M=V%S(&YO="!C<F5A=&5D.B`E<RX`)2XR9DU"('5S960@;V8@)2XR9DU"(&%L
M;&]W960@*"4N,F8E)2D`)60@)7,@86YD("5S`"5D(&1A>7,@=6YT:6P@>6]U
M<B!P87-S=V]R9"!E>'!I<F5S+@`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I
M8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T
M:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E
M<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@
M)7,`)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@
M;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE
M+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@
M=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E
M<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`)7,Z(%1H:7,@;65S
M<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E
M=V%R92!O9B!F;VQL;W=I;F<@86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I
M9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N
M+@`L(&=U<W1I;F<@`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@
M)7,@=&\@)7,`+2T@<V5L96-T("TM`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@
M1F]R;6%T`#(T(&AO=7)S`#Q0<F5V:6]U<P!!(&1A=&%B87-E(&)A8VME;F0@
M:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S
M(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC
M<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@
M=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL
M('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV
M871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S
M:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3
M+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C
M<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@
M4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I
M9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@
M=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-($-L;W5D<P!!32!,:6=H="!286EN
M`$%-(%)A:6X`04T@4VAO=V5R<P!!32!3;F]W(%-H;W=E<G,`04TO4$T`05!)
M($E$`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B<V)O='1O;0!!8G-M
M:61D;&4`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+@!!
M8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-O=6YT($EN9F]R
M;6%T:6]N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U
M;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO
M;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`
M061D(&$@8VAI;&0@9W)O=7`@=&\@(B5S(@!!9&0@82!C:&EL9"!P97)M:7-S
M:6]N('1O("(E<R(`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`061D(&YE
M=R!M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL
M;&$@4VED96)A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D
M<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2P@
M8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I
M;VXZ("5S+@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G
M(&EN(&YO=RX`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D
M9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O
M=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`069G:&%N:7-T86X`06QB
M86YI80!!;&=E<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!
M=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS
M`$%L;"!F;W5R('-I9&5S`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO
M=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y(&5X:7-T
M<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R
M9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D
M<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;65R
M:6-A;B!386UO80!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N
M('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N`$%N9&]R<F$`06YG;VQA`$%N
M9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YT87)C=&EC80!!;G1I
M9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N($QI<W0`
M07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H:6QD(%-H87)E<P!!
M<'!R;W9E`$%P<')O>&EM871E(%-I>F4`07!R:6P`07)A8FEC("A7:6YD;W=S
M+3$R-38I`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!<F4@>6]U
M('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F
M;W(@)7,@/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E("(E<R(@
M86YD(&%N>2!S=6(M9W)O=7!S/P!!<F=E;G1I;F$`07)M96YI80!!<FUE;FEA
M;B`H05)-4T-)22TX*0!!<G0`07)U8F$`07-C96YS:6]N($ES;&%N9`!!<V-I
M:2!!<G0`07-I82]086-I9FEC(%)E9VEO;@!!<VL@9F]R(&-O;F9I<FUA=&EO
M;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`07-S:6=N
M;65N="!C;VQU;6YS`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT
M(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M
M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES
M<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+@!!
M='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y<G-Q
M;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y
M<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET
M97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF='`@<W=I=&-H
M+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@
M9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!296UO=FEN9R!U<V5R
M<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?
M;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H
M92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U
M<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S`$%U
M=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@
M06-T:79E($1I<F5C=&]R>2X`075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB
M875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!A="!)
M34%0('-E<G9E<B!F86EL960N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H
M96YT:6-A=&EO;B!F86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D
M(&)Y(%)!1$E54R!S97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V
M97(@9F%I;&5D+@!!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F
M86EL960N`$%V86EL86)L92!F:65L9',Z`$%Z97)B86EJ86X`0D]&2"!%>&-U
M<V5S`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@
M<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"86AR
M86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`
M0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`$)A<V5L
M:6YE`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R;75D80!":'5T
M86X`0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO
M="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";VQD`$)O;&EV
M:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!";W)D97)S
M`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1S=V%N80!";W1T;VT`
M0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E86X@5&5R
M<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U;&QE=&5D($QI
M<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T
M:6]N(%!O:6YT<P!#7V5L;"!0<F]P97)T:65S+BXN`$-A8VAE(&EN:70@=V%S
M(&YO="!C;VUP;&5T960N`$-A;&5N9&%R`$-A;&T`0V%M8F]D:6$`0V%M97)O
M;VX`0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT
M86-T('EO=7(@861M:6YI<W1R871O<BX`0V%N(&YO="!W<FET92!T;R!F:6QE
M("(E<R(`0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L
M97)S+@!#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<P!#86XG="!O
M<&5N(&9I;&4@(B5S(BX`0V%N861A`$-A;F-E;`!#86YC96P@4')O8FQE;2!2
M97!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@
M=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E960@=VET:&]U="`G
M=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R
M>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N
M;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R
M96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO="!R
M;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A<&4@5F5R9&4`
M0V%P=&EO;@!#87)R:65R`$-A=&5G;W)I97,@86YD($QA8F5L<P!#87EM86X@
M27-L86YD<P!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE<P!#96QL('!A9&1I
M;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;&QP:&]N90!#
M96QT:6,@*$E33RTX.#4Y+3$T*0!#96YT97(`0V5N=')A;"!!9G)I8V%N(%)E
M<'5B;&EC`$-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC
M871E($1E=&%I;',`0V5R=&EF:6-A=&4@3W=N97(`0V5R=&EF:6-A=&4@4&]L
M:6-I97,`0VAA9`!#:&%N9V4`0VAA;F=E(%EO=7(@4&%S<W=O<F0`0VAA;F=E
M('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H
M97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H86YG:6YG('EO
M=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT
M(&-O;F9I9W5R871I;VXN("!#;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`
M0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&EL90!#:&EN80!#:&EN97-E(%-I;7!L
M:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`0VAO
M;W-E($%P<&QI8V%T:6]N.@!#:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@82!U
M<V5R;F%M90!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L
M:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#:')I<W1M87,@
M27-L86YD`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A
M<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R(%%U97)Y`$-L96%R(&]U="!U
M<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&5A<FEN9R!,
M871E`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A45%``0VQO
M<V4@5VEN9&]W`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O8V]S("A+
M965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O
M<F1E<G,`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE
M8W1I;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM
M86YD(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY
M`$-O;7!U=&5R<P!#;VYD:71I;VX`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N
M($1I9F9E<F5N8V5S`$-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!0
M1$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RX`0V]N9FEG=7)A=&EO;B!I
M<R!O=70@;V8@9&%T92X`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`
M0V]N9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#
M;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T
M:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I
M;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E
M<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A
M8W1S`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@
M861D<F5S<R!B;V]K+@!#;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE
M.B``0V]N=&5N=',@;V8@(B5S(@!#;VYT:6YU90!#;V]K($ES;&%N9',`0V]O
M:VEE`$-O<'D`0V]P>2!F86EL960Z("5S`$-O<'D@<V5L96-T:6]N`$-O<W0@
M240`0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O=6QD(&YO="!01U`@96YC
M<GEP="!M97-S86=E.B``0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z(`!#
M;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O
M34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`
M0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C:&5C
M:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E
M<BX`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("(E<R(@=7-I;F<@1E10
M.B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#
M;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@`$-O=6QD(&YO="!D96-R>7!T
M(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O
M=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO
M="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`0V]U;&0@;F]T
M(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O
M=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO
M="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T
M(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T
M<RX`0V]U;&0@;F]T(&QO860@<W1R871E9WD@(B5S(BX`0V]U;&0@;F]T(&UK
M9&ER("(E<R(N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H
M92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("(E<R(@9F]R('=R:71I;F<N
M`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC
M95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@(B5S
M(BX`0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T
M(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H
M92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@
M87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N
M;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O
M;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`
M0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L
M9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!R;61I<B`B
M)7,B+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N
M;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO="!S879E
M(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U;&0@;F]T('-A=F4@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`$-O=6QD(&YO="!S879E('1H
M92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V
M92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U
M<V4@;VYE(&]F('1H92!O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O
M;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+@!#
M;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5N
M;&EN:R`B)7,B+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD
M(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!W
M<FET92!C;VYF:6=U<F%T:6]N(&9O<B`B)7,B.B`E<P!#;W5L9&XG="!F:6YD
M('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I
M<R!O<&5N+@!#;W5L9&XG="!G:79E('5S97(@(B5S(B!T:&4@9F]L;&]W:6YG
M(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B.B`E<P!#;W5N=&5D('1E>'0`
M0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@82!L:6YK`$-R96%T92!A
M(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S`$-R96%T;W(@4&5R;6ES<VEO
M;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT(#0@
M4&AA<V5S`$-U<G)E;G0@4V5S<VEO;G,`0W5R<F5N="!4:6UE`$-U<G)E;G0@
M55),(&ES`$-U<G)E;G0@57-E<G,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@
M8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@
M<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U
M<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#
M>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`
M1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G
M92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!$86EL>0!$871A5')E92!"
M<F]W<V5R`$1A=&%B87-E($QO;VMU<`!$871E`$1A=&4@4F5C96EV960`1&%T
M92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM
M86P@;G5M8F5R<P!$96-R96%S92!);F1E;G0`1&5F875L=`!$969A=6QT($-O
M;&]R`$1E9F%U;'0@261E;G1I='D`1&5F875L="!3:&5L;`!$969I;FET:6]N
M<P!$96QE=&4`1&5L971E($-E;&P`1&5L971E($=R;W5P`$1E;&5T92!,;V<`
M1&5L971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$
M96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E
M<FYA=&4@=&5M<&QA=&4`1&5L971E(&UE<W-A9V5S`$1E;&5T92!P97)M:7-S
M:6]N<R!F;W(@(B5S(@!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(@86YD
M(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T92!R;W<`1&5L971E('-E;&5C
M=&5D(&ED96YT:71Y`$1E;&5T92!S=6(@9F]L9&5R<P!$96QE=&4@=&AE(&-U
M<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L971E9"!S
M971U<"!U<&=R861E('-C<FEP="`B)7,B+@!$96QI=F5R>2!T:6UE`$1E;FUA
M<FL`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL<R`H
M86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L
M;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$979E;&]P;65N=`!$97<@
M4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$
M:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F
M=`!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P
M=&EO;G,`1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S=`!$:7-P;&%Y(&9O<F5C
M87-T("A4048I`$1I<W!L87D@9F]R;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A
M=&EO;@!$:FEB;W5T:0!$;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A
M8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT
M86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`
M1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B;&EC`$1O;B=T(&AA=F4@86X@86-C
M;W5N=#\@4VEG;B!U<"X`1&]W;FQO860`1&]W;FQO860@)7,`1&]W;FQO860@
M9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`1')O<"!D
M;W=N(&QI<W0`1')U9W,`12U-86EL`$5-86EL+71O+5--4R!G871E=V%Y(&1R
M:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E
M+@!%4E(`16-U861O<@!%9&ET`$5D:70@0FQO8VL`161I="!'<F]U<`!%9&ET
M(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS
M(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O
M<B`B)7,B`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D=6-A=&EO;@!%9WEP
M=`!%;"!386QV861O<@!%;&5M96YT+BXN`$5M`$5M86EL`$5M86EL($%D9')E
M<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N
M9FER;6%T:6]N`$5M86EL+71O+5--4R!'871E=V%Y`$5M;W1I8V]N<P!%;7!T
M>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%
M;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE
M<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%
M;F0@>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T
M:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E
M<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@
M>6]U<B!P970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5N=&5R('1H
M92!L971T97)S(&)E;&]W.@!%<75A=&]R:6%L($=U:6YE80!%<FET<F5A`$5R
M<F]R`$5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<P!%<G)O<B!D96QE=&EN9R!S
M>6YC(&%N8VAO<CH@)7,`17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S`$5R
M<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,`17)R;W(@=7!D871I;F<@<&%S<W=O
M<F0Z("5S`$5R<F]R('=I=&@@96UA:6P@;65S<V%G92X`17)R;W(@=W)I=&EN
M9R`B)7,B+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@
M,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%
M=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V
M97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A;F0`17AP
M86YD(%-I9&5B87(`17AP96-T960@)RDG`$5X<&5C=&5D(&)A<F4@=V]R9"!O
M<B!Q=6]T960@<V5A<F-H('1E<FT`17AP:7)A=&EO;B!$871E`$5X<&]N96YT
M`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D(')E=')I979I
M;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R
M=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@
M=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A
M:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O
M(&UO=F4@=&\@(B5S(BX`1F%I;&5D('1O(')E=')I979E.B`E<P!&86ER`$9A
M;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A=&%L
M($5R<F]R.@!&87@`1F%X97,`1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L
M:6ME.B``1F5W(%-H;W=E<G,`1F5W(%-N;W<@4VAO=V5R<P!&:65L9"!M871R
M:7@`1FEG;&5T($-!4%1#2$$`1FEG;&5T(&9O;G0`1FEJ:0!&:6QE`$9I;&4@
M0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA
M9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE
M('5P;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R<P!&:6YL86YD`$9I<G-T
M($AA;&8`1FER<W0@475A<G1E<@!&:7@@<F%T:6\`1FQI<`!&;&]A=`!&;V<`
M1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@0V]L;W(`1F]O9`!&;W(@
M8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<P!&;W)E8V%S="`H
M5$%&*0!&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O
M<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A(&QA<F=E(&YU
M;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI`$9O<F=O
M="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&
M;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M<P!&;W)W87)D<P!&<@!&<F%M97,`
M1G)A;F-E`$9R86YC92P@365T<F]P;VQI=&%N`$9R96YC:"!'=6EA;F$`1G)E
M;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O
M;0!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.
M86UE`$=A8F]N`$=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ
M`$=A;6)I80!'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#
M;V1E`$=E;W)G:6$`1V5R;6%N>0!':&%N80!':6)R86QT87(`1VEV96X@3F%M
M90!';&]B86P@3W!T:6]N<P!';P!';V5D96P`1V]O9VQE($UA<',`1V]O9VQE
M(%-E87)C:`!'<F%Y<V-A;&4`1W)E96-E`$=R965K("A)4T\M.#@U.2TW*0!'
M<F5E;FQA;F0`1W)E;F%D80!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<"!N
M86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@
M861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``
M1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<P!'<F]U<%]L
M9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S`$=R;W5P<P!'=6%D96QO
M=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E<FUI<W-I;VYS
M`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C
M96QL(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE
M=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A<F1L
M>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A4
M5%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R
M:71H;0!(87IE`$AE861E<@!(96%D97)S`$AE87)D($ES;&%N9"!A;F0@36-$
M;VYA;&0@27-L86YD<P!(96%V>2!4+5-T;W)M`$AE8G)E=R`H25-/+3@X-3DM
M."U)*0!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP97(`2&5M
M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AI
M9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M90!(
M;VUE($%D9')E<W,`2&]M92!$:7)E8W1O<GD`2&]M92!0:&]N90!(;VYD=7)A
M<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,
M(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@
M3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O2V]L
M86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,`
M2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`2&]R
M9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE
M("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T
M>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@
M(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S
M:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E<R(`2&]R
M:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(
M;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@;6%N
M>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F
M:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L
M9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ(`!(=6UO
M<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E
M<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB
M;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S`$E0($%D
M9')E<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN(&%L
M;&]W960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)7VYS
M97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS(&9O<B`E
M<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I<R!N
M;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE
M=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN
M=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B
M;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U('-E92!T
M:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@
M=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N
M`$EM86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E(&9R
M;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!)
M;6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O
M<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C="!A8W1I
M;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S
M=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S
M+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@
M>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD:6$`
M26YD:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA=&EO;@!)
M;F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+@!);G-E<G0@0U]O;'5M
M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@
M3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M
M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B
M969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@
M=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C
M=7)R96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E
M;G0@;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT
M(&YO9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA
M:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P
M87-S=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E
M`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS
M97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A
M<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E
M9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I
M='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF
M>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES
M=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`
M26YT96=E<B!L:7-T`$EN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN
M`$EN=F%L:60@6DE0(&1A=&$`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI
M9"!B871C:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D
M97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L
M:60@;&EC96YS92!K97DN`$EN=F%L:60@;&]C871I;VX@<')O=FED960N`$EN
M=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN
M=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P
M97)M:7-S:6]N+@!);G9A;&ED('!A<G1N97(@:60N`$EN=F%L:60@<')O9'5C
M="!C;V1E+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED(')E8VEP:65N=#H@
M(B5S(@!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R
M97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$EN=F5R="!S
M96QE8W1I;VX`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA
M;F0`27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E
M<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E
M("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF
M>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU
M<W1I9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY80!+
M97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME<FYE
M;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE
M;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N
M('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I`$MO<F5A+"!$
M96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI
M8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U
M=`!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,
M87-T($AA;&8`3&%S="!087-S=V]R9"!#:&%N9V4`3&%S="!1=6%R=&5R`$QA
M<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O
M;2`E<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`3&%W`$QA>6]U=`!,96%V
M92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N;VX`3&5F=`!,969T(&AE861E
M<@!,969T('9A;'5E<P!,97-O=&AO`$QE=F5L`$QI8F5R:6$`3&EB>6%N($%R
M86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI9VAT($1R:7IZ;&4`3&EG
M:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H
M="!286EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU;F1E<@!,:6=H="!3
M;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K`$QI;FL`3&EN:R!P;VEN
M=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@
M<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O:VEE`$QI<W0@
M+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T
M($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,:7-T+4AE
M;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB
M90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E
M<P!,:7-T:6YG('5S97)S(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!I<R!D
M:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]A9&EN9RXN+@!,;V-A
M;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@
M;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N`$QO9R!O=70`3&]G:6X`3&]G:6X@
M5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P
M87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D
M+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E
M<B!L871I;B!L971T97)S`$QO=V5R(')O;6%N(&YU;6)E<G,`3'5X96UB;W5R
M9P!-30!-3U1$`$U3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T
M82X`35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!2
M97!U8FQI8R!O9@!-861A9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!9&UI;@!-
M86ME(&QI;E]K+BXN`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-86QI`$UA
M;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O
M(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E9"!W:71H
M('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T(&UA<`!-87!1=65S="!M87``36%P
M<&EN9W,@<W1O<F5D+@!-87)C:`!-87)G:6X`36%R:R!W:71H(%-E96XO56YS
M965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A
M;G0O06YS=V5R960I`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-871C
M:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`36%X(&%L;&]W960@
M8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@
M;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM
M=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,`36%X:6UU;2!L96YG=&@`36%Y
M`$UA>6]T=&4`365D:6-I;F4`365M8F5R<P!-96YU(&UO9&4Z`$UE<F=E(&-E
M;&QS`$UE<W-A9V4`365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T
M('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I
M960N`$UE<W-A9V4@97AP:7)E9"X`365S<V%G92!T>7!E`$UE=&%R(%=E871H
M97(`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T
M(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@
M861M:6YI<W1R871O<BX`365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+@!-971H
M;V0`365T:&]D("(E<R(@:7,@;F]T(&1E9FEN960`365T:&]D(&YO="!D969I
M;F5D+B!#86QL960@;65T:&]D.B`E<P!-971R:6,`365X:6-O`$UI8W)O;F5S
M:6$L($9E9&5R871E9"!3=&%T97,@;V8`36ED9&QE`$UI;64@5'EP90!-:6X@
M=&5M<"!L87-T(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``
M36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9`!-:7)R
M;W(`36ES8V5L;&%N96]U<P!-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E
M<75E<W0N`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N
M97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T
M:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@<F5Q=6ER960@4$5!
M4B!P86-K86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE
M($UA:6P`36]D97)A=&4`36]D:69I960@1&%T90!-;V1I9GD@55),`$UO9'5L
M=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H
M(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)E
M(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D
M+@!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!#
M;&]U9'D@86YD(%=I;F1Y`$UO<W1L>2!3=6YN>0!-;W9E($1O=VX`36]V92!,
M969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA
M;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT:6UA<"!5
M2R!M87``375L=&EP;&4@<V5L96-T:6]N`$UY($%C8V]U;G0`37D@06-C;W5N
M="!);F9O<FUA=&EO;@!->2!0;W)T86P`37D@4&]R=&%L($QA>6]U=`!->6%N
M;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YA;6EB:6$`3F%U<G4`3F5P
M86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N9',@06YT:6QL97,`3F5T<V-A<&4@
M0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@
M0T$@<&]L:6-Y(%523`!.971S8V%P92!296YE=V%L(%523`!.971S8V%P92!2
M979O8V%T:6]N(%523`!.971S8V%P92!34TP@<V5R=F5R(&YA;64`3F5T<V-A
M<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.971S8V%P92!C97)T:69I8V%T92!T
M>7!E`$YE='=O<FL`3F5V97(`3F5W($-A;&5D;VYI80!.97<@0V%T96=O<GD`
M3F5W($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`
M3F5W('!A<W-W;W)D`$YE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"X`
M3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"X`3F5W('=I;F1O=R`H7V)L86YK
M*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(#0@4&AA<V5S`$YE>'0@;W!T
M:6]N<P!.97AT/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:6=H=`!.:75E
M`$YO`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D
M:69F97)E;F-E<R!F;W(N`$YO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K
M:6YG($E33R!I;6%G97,N`$YO(&)A=&-H('1E;7!L871E+@!.;R!B;&]C:R!E
M>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N
M86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N
M9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I
M;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@;&5F
M="X`3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&9I;&4@=7!L;V%D960`
M3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;&]C871I
M;VX@<')O=FED960N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E
M8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R
M='5N97,`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-7
M1"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--
M0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA
M<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@
M=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S
M+@!.;R!Q=6]T82!S970N`$YO(')U;&5S`$YO('-E<&%R871O<B!S<&5C:69I
M960N`$YO('-I9&5S`$YO('-U8V@@9FEL90!.;R!T96UP;W)A<GD@9&ER96-T
M;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P
M87-S=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V
M86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T
M:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U
M;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R
M871I;VXN`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E33RTX
M.#4Y+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E`$YO
M<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO="!"
M969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!I;7!L96UE;G1E9"X`3F]T('-E
M=`!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@
M8F%C:RX`3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU
M;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P
M96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+
M`$]B:F5C=`!/8FIE8W0@0W)E871O<@!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@
M9FEL=&5R`$]F9FEC90!/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D
M:69F97)E;G0N`$]L9"!P87-S=V]R9`!/;&0@<&%S<W=O<F0@:7,@;F]T(&-O
M<G)E8W0N`$]M86X`3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@
M9F]L9&5R<RX`3VYL>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA
M:6P@861D<F5S<R!A;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@
M861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P
M97)M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/
M<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG
M;F5D(%,O34E-12!P87)T+@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN
M9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/
M<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`
M3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG
M:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N
M`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@
M879A:6QA8FQE+@!014%2.CI-86EL(&)A8VME;F0`4$=0($1I9VET86P@4VEG
M;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T80!01U`@4'5B;&EC($ME>0!01U`@
M4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!(4"!3:&5L;`!032!,
M:6=H="!286EN`%!-(%)A:6X`4$T@4VAO=V5R<P!032!3;F]W`%!-(%-N;W<@
M4VAO=V5R<P!032!3=6X`4$T@5"U3=&]R;7,`4$]325@@97AT96YS:6]N(&ES
M(&UI<W-I;F<`4%](4"!3:&5L;`!0861D:6YG`%!A:VES=&%N`%!A;&%U`%!A
M;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE
M=R!'=6EN96$`4&%R86=U87D`4&%R=&QY($-L;W5D>0!087-S=V]R9`!087-S
M=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2X`4&%S<W=O<F0@:6YC;W)R96-T
M`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN
M`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R
M9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L
M:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`
M4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S
M:6]N("(E<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I;VX@1&5N:65D`%!E<FUI
M<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN
M9F]R;6%T:6]N`%!E<G4`4&5T<P!0:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`
M4&ET8V%I<FX`4&EX96QS`%!L871I='5D97,`4&QE87-E(&-L:6-K(&EN=&\@
M<V]M92!C96QL`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M
M;W9E('1H:7,@96QE;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N
M="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!M;VYT
M:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W
M(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0
M;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F
M(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE
M+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L
M96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S
M92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET
M:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!L96%S92!T>7!E('1H
M92!N97<@8V%T96=O<GD@;F%M93H`4&]L86YD`%!O;&ET:6-S`%!O;&QS`%!O
M<G1U9V%L`%!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@
M;V8@=&AI<R!T86)L90!0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C
M960@8GD@24U!4"D`4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I
M.B``4')E8VEP:71A=&EO;CQB<B`O/F-H86YC90!0<F5F<U]L9&%P.B!297%U
M:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ
M(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"X`4')E<W-U
M<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W
M`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V:6]U<R!O
M<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O
M8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0=6)L:6,@
M2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R!+97D@26YF;P!0=6)L
M:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY
M+@!0=65R=&\@4FEC;P!0=7)G92!M97-S86=E<P!1871A<@!1=65R>0!1=6]T
M80!24T$@4'5B;&EC($ME>2`H)60@8FET*0!2861I;R!S96QE8W1I;VX`4F%I
M;@!286EN($5A<FQY`%)A:6X@3&%T90!286EN(%-H;W=E<@!286EN(&%N9"!3
M;F]W`%)A:6X@=&\@4VYO=P!286YD;VT@1F]R='5N90!2871I;P!296%D`%)E
M860@;65S<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@
M8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R
M('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E
M9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@`4F5F<F5S:"!$>6YA;6EC
M($UE;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E
M;&%T:6]N<VAI<"!"<F]W<V5R`%)E;&]A9`!296UA<FMS`%)E;6]T92!397)V
M97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I
M.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O
M<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M
M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M
M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!2
M96UO=F4@=7-E<CH@)7,`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@
M4F5T=7)N960@97)R;W)C;V1E.B``4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@
M;F]T(&)E(&9O=6YD+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@
M)7,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D
M(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C
M:69I960@:6X@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@1FEE;&0`4F5S970`
M4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R9`!297-T;W)E($QA
M<W0@475E<GD`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2971Y<&4@;F5W
M('!A<W-W;W)D`%)E=6YI;VX`4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!4
M97AT($5D:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R
M`%)I9VAT('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA
M`%)O=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P
M97)T:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@
M87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E
M87(@8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2
M=V%N9&$`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%
M;F-R>7!T960@365S<V%G90!305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A
M=F%I;&%B;&4N`%--4R!-97-S86=I;F<`4U%,(%-H96QL`%-13"!S=&%T96UE
M;G0@9F]R('9A;'5E(&QO;VMU<',`4U-(`%-50T-%4U,`4U]13"!3:&5L;`!3
M80!386EN="!(96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU
M8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A
M;F0@=&AE($=R96YA9&EN97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A
M;B!-87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V
M:61E<@!3875D:2!!<F%B:6$`4V%V90!3879E("(E<R(`4V%V92`E<P!3879E
M($]P=&EO;G,`4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(
M4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y
M+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3879E9"!S971U<"!U<&=R861E
M('-C<FEP="!T;SH@(B5S(BX`4V-A='1E<F5D(%0M4W1O<FUS`%-C:65N8V4`
M4V5A<F-H`%-E87)C:"!%;F=I;F5S`%-E;&5C="!&:6QE<P!396QE8W0@82!D
M871E`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`
M4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A
M;&P`4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N`%-E;&5C="!A;B!O8FIE
M8W0`4V5L96-T(&YO;F4`4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D
M(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@
M<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T
M92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T
M:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I
M;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@
M='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE
M+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE
M;2!297!O<G0`4V5N9"!335,`4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`
M4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E<FEA;"!.=6UB97(`4V5R=F5R(&1A
M=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92X`4V5S<VEO;B!!9&UI;@!397-S
M:6]N($E$(&5X<&ER960N`%-E<W-I;VYS`%-E=`!3970@;W!T:6]N<R!T;R!A
M;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F
M;W)G970@:70N`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT
M('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R
M960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y
M;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R
M969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3
M971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I
M;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`
M4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@
M9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W(&1I9F9E<F5N8V5S
M(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A
M=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@
M;&]G9VEN9R!I;C\`4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W
M('!I8VME<@!3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@
M=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@
M4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D
M:6%L;V<`4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H
M;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H
M;W=E<G,`4VAO=V5R<R!%87)L>0!3:&]W97)S($QA=&4`4VAO=V5R<R!I;B!T
M:&4@5FEC:6YI='D`4VAR:6YK`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN
M9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`
M4VEG;B!U<`!3:6=N871U<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3:6YG87!O
M<F4`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N
M;W<`4VYO=R!3:&]W97(`4VYO=R!3:&]W97)S`%-N;W<@4VAO=V5R<R!%87)L
M>0!3;F]W(%-H;W=E<G,@3&%T90!3;F]W(&1E<'1H.B``4VYO=R!E<75I=F%L
M96YT(&EN('=A=&5R.B``4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]N9W,@
M)B!0;V5M<P!3;W)T(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3
M;W5T:"!!9G)I8V$`4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H
M($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S`%-O=71H
M97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<P!3
M<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL`%-P86-E
M<@!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!A:6X`4W!A;0!3<&5C
M:6%L($-H87)A8W1E<B!);G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3
M<&QI="!R;W<`4W!O<G1S`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`
M4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O<F%G92!F
M;W)M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I;F<@;&ES
M=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<P!3='EL92!;0U-370!3
M=0!3=6)D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%-U8FIE8W0`4W5B;6ET
M`%-U8FUI='1E9"!R97%U97-T('1O(&%D9"`B)7,B('1O('1H92!S>7-T96TN
M(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@<F5Q=65S="!H87,@8F5E
M;B!A<'!R;W9E9"X`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D
M9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-L96%R960@
M9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U
M;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY(')E;6]V960@(B5S(B!F
M<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U
M<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S
M879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('-A=F5D
M('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C97-S9G5L
M;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=61A;@!3
M=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`4W5N<FES90!3=6YR:7-E
M+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T
M`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA
M>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`4WEN8R!L;V<@9&5L
M971E9`!3>6YC34P`4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<P!3>7)I
M86X@07)A8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O<FT@86YD(%=I;F1Y`%0M
M4W1O<FUS`%0M4W1O<FUS($5A<FQY`%135B!F:6QE`%1A8FQE`%1A8FQE(%!R
M;W!E<G1I97,`5&%B;&4@4V5T`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A
M:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI82P@
M56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5L97!H;VYE($YU
M;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!496UP97)A
M='5R93H@`%1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[
M)7,`5&5M<&QA=&4@(B5S(B!N;W0@9F]U;F0N`%1E;7!L871E($%D;6EN:7-T
M<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X='1O<`!4:`!4
M:&%I("A425,M-C(P*0!4:&%I;&%N9`!4:&4@1E10(&5X=&5N<VEO;B!I<R!N
M;W0@879A:6QA8FQE+@!4:&4@2&ES=&]R>2!S>7-T96T@:7,@9&ES86)L960N
M`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@
M<W5P<&]R="`B)7,B`%1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA
M;&EZ960N`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S
M=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X
M:71I;F<N`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A
M('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O
M('5S92!097)M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&-O
M;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK
M(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C
M="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K
M+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E
M9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@9&ES=')I8G5T
M:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L
M86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB
M=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@
M9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL
M92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL
M92!C86YN;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+@!4:&4@9FEL92!C;VYT
M86EN960@;F\@9&%T82X`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@
M9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&9U;&P@<V-R
M965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E
M<FYE="!%>'!L;W)E<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E
M<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N
M8V4@9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@
M86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E
M;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@
M9V5T(&$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@
M<F5B;V]T+EQN7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92!P<F5S
M<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N
M(&5D:71O<BX`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`
M5&AE(&QE9G0M:&%N9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H92!'
M;G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@
M8VQA<W,N`%1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J
M96-T("(E<R(@:&%S(&)E96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A
M;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S
M=&]O9"X`5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M
M<&]S92!P86=E`%1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I
M8RX`5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R
M9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R969E<F5N8V4@(B5S(B!C
M;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T
M:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O
M('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H
M92!S>7-T96TN`%1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN
M9VQE(&-H87)A8W1E<BX`5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'D`
M5&AE(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S97!A<F%T;W(@;75S="!B
M92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE('-E<G9E<B`B)7,B(&AA<R!B
M965N(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`
M5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4
M:&4@<W!E8VEF:65D(')O=R`H)60I(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5M
M<&]R87)Y(&9I;&4@(B5S(B!D;V5S(&YO="!E>&ES="X`5&AE('1E>'0@>6]U
M(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N
M+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I9&4@
M;VYL>0!4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E
M=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A
M=F5D+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`
M5&AE;65S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`5&AE<F4@87)E(&YO
M(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C
M86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M86YY(&-H
M87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C
M:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N`%1H97)E
M('=A<R!A('!R;V)L96T@861D:6YG("(E<R(@=&\@=&AE('-Y<W1E;3H@)7,`
M5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R("(E
M<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO
M=FEN9R`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L
M96T@=7!D871I;F<@(B5S(CH@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H
M('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R92!W
M87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S
M(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W960@<VEZ92`H)60@8GET
M97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D
M.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R92!W
M87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A
M+@!4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R
M;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE
M<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R
M97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H
M97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS
M+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G
M86EN(&QA=&5R+@!4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@
M<VAA<FEN9R!F;VQD97)S+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A
M('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B
M92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@
M82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO
M+V-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`
M5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G
M:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@9V%T97=A>2P@=7-I;F<@
M=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I
M;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E
M<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H
M('1H92!6;V1A9F]N92!)=&%L>2!G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE
M(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"!6
M;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+@!4:&ES(&9I96QD
M(&ES(')E<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT
M96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N
M9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A
M;"!V86QU97,N`%1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E
M('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@;75S="!B
M92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C
M;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@
M)R,Q,C,T868G+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S
M960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J
M96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA
M:6P@8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R
M92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"!C;&EE;G1S('!L
M96%S92!V:7-I="`E<P!4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C
M:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BX`5&AI<R!N
M=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@<V5R=F5R(&-A;B=T
M('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4:&ES('-Y<W1E;2!I
M<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L=64@;75S="!B92!A
M(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/
M<'1I;VYS('=I;F1O=P!4:'5N9&5R`%1I8VME=',`5&EM90!4:6UE(%1R86-K
M:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L96-T:6]N`%1I;6]R+4QE<W1E`%1I
M=&QE`%1I=&QE("AT;V]L=&EP*3H`5&\`5&\@<V5L96-T(&UU;'1I<&QE(&ET
M96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-
M86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D87D`5&]G9VQE($A434P@4V]U
M<F-E`%1O9V\`5&]K96QA=0!4;VUO<G)O=P!4;VYG80!4;V\@;6%N>2!I;G9A
M;&ED(&QO9VEN<R!D=7)I;F<@=&AE(&QA<W0@;6EN=71E<RX`5&]P`%1O<"!F
M<F%M92`H7W1O<"D`5')A;G-L871I;VYS`%1R:6YI9&%D(&%N9"!4;V)A9V\`
M5')U92!O<B!F86QS90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M
M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S
M`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!5
M4DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),
M.@!59V%N9&$`56MR86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O
M<GDN`%5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N
M('-I9VYI;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@
M5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O
M<B!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA
M8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,B+@!5;F%B;&4@=&\@8VAE
M8VL@9FEL92!S:7IE(&]F("(E<R\E<R(N`%5N86)L92!T;R!C;VYN96-T('1O
M(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B
M;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER
M96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`
M56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!6
M1E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I
M;&4N`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE
M=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T
M;R!D96QE=&4@(B5S(CH@)7,N`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D
M:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@5D93(&1I
M<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER
M96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5
M;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!D96QE
M=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B`B)7,B
M+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N`%5N86)L
M92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N86)L92!T;R!E
M>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',`56YA8FQE('1O(&QO860@=&AE
M(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!M;W9E(%9&4R!F:6QE+@!5
M;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@;W!E;B!6
M1E,@9FEL92!F;W(@=W)I=&EN9RX`56YA8FQE('1O(&]P96X@5D93(&9I;&4N
M`%5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`56YA8FQE('1O
M(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O
M(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2X`56YA8FQE
M('1O(')E860@9FEL93H@`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I
M<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I
M;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93
M(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E
M<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@
M<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS
M;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F
M:6QE("(E<R(N`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A
M:6QE9"DN`%5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F%B;&4@
M=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N`%5N
M9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S="!A8W1I;VX`
M56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N
M.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@`%5N9FEL
M960`56YI8V]D92`H551&+3@I`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N:71E
M9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YI=&5D(%-T871E<R!-:6YO<B!/
M=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N:VYO=VX`56YK;F]W;B!A<&EM<V=I
M9"`H05!)($UE<W-A9V4@240I+@!5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@
M365S<V%G92!)1"DN`%5N:VYO=VX@;&]C871I;VX@<')O=FED960N`%5N:VYO
M=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E
M;&5M96YT`%5N;F%M960`56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C
M8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R
M:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T
M92!A="!M;WII;&QA+F]R9R!W:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W
M(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO
M<@!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A
M=&4@=7-E<@!5<&1A=&5D("(E<R(N`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N
M`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@
M=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA
M;B!N=6UB97)S`%5R=6=U87D`57-E($-U<G)E;G0Z("5S`%5S92!34TP`57-E
M(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E
M<BX`57-E<@!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E
M<B!!9&UI;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I
M;VX`57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H
M:7,@<VET92X`57-E<B!A8V-O=6YT(&YO="!F;W5N9`!5<V5R;F%M90!5<V5R
M;F%M92`B)7,B(&%L<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`57-E<FYA;64Z
M(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O
M<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F
M;W5N9"!I;F-L=61E.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M
M(&YO=RX`5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N
M`%9A;'5E<P!686QU97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T=0!687)I86)L
M90!696YE>G5E;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G
M92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO
M;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R
M=&EC86PZ`%9E<GD@2&EG:`!6:65T($YA;0!6:65T;F%M97-E("A625-#24DI
M`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S
M`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N
M`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET86QY('9I82!3
M3510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($92
M3TT@)7,N`%=)3B!V:6$@2%144`!786QL:7,@86YD($9U='5N80!787)N:6YG
M`%=E`%=E871H97(@1F]R96-A<W0`5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y
M`%=E871H97(N8V]M`%=E8@!796(@4VET90!7965K;'D`5V5L8V]M90!796QC
M;VUE('1O("5S`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E
M<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI
M8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES
M('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C
M:&%R86-T97(_`%=H97)E:7,@075S=')A;&EA(&UA<`!7:&EC:"!P:&%S97,`
M5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I
M=&]R+@!7:61T:`!7:61T:"!I;B!#4U,@=6YI=',`5VED=&@@;V8@=&AE("5S
M(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI
M;BDZ`%=I9'1H(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7:6MI
M`%=I;F0`5VEN9"!%87)L>0!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I
M;F0Z(`!7:7-D;VT`5VES:&QI<W0`5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0
M:&]N90!7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C
M=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP
M96-T960@)60L(&9O=6YD("5D+@!7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A
M9&EN9R!A(%9&4R!F:6QE+@!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN
M=',`6#4P.78S($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!
M;'1E<FYA=&EV92!.86UE`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R
M`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`
M665M96X`665S`%EE<RP@22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@
M(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=9
M1RX`66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D
M(&)L;V-K<RX`66]U(&%R92!N;W0@875T:&5N=&EC871E9"X`66]U(&-A;FYO
M="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9
M;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D
M:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T
M;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@)7,N`%EO=2!H879E(&)E
M96X@;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL
M<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K
M)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H
M879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R
M92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T
M(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T
M:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E
M<&]R="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@
M<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L
M971E9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U
M="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U
M(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S
M<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I
M9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE
M=R!C871E9V]R>2!N86UE+@!9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI
M86X@<&AO;F4@;G5M8F5R`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@
M4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&
M<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@
M061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO
M=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@
M;75S="!L;V=I;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@875T:&5N=&EC871I
M;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@
M>6]U('=I<V@@=&\@=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O
M=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT(&%U=&AE;G1I8V%T:6]N
M(&)A8VME;F0N`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO
M="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B
M965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!B<F]W
M<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI
M;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I
M='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R;W=S97(@9&]E<R!N
M;W0@<W5P<&]R="!T:&ES(&9E871U<F4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO
M="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O
M;6UA;F0@*R!0('1O('!R:6YT+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9
M;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"X`66]U<B!D
M969A=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!L;V=I;B!H
M87,@97AP:7)E9"X`66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9
M;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO
M;B!O9B!T:&ES('-E<W-I;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D
M871E9"X`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W
M;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@
M:6X@=VET:"!Y;W5R(&YE=R!P87-S=V]R9"X`66]U<B!P87-S=V]R9"!H87,@
M97AP:7)E9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`675G;W-L879I80!:86ER
M90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`6TAI9&4@475O=&5D(%1E>'1=`%M0
M<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T
M960@5&5X="`M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T
M<F%T:6]N`%]#3$D`7T1A=&%4<F5E`%]$96QE=&4@4F]W`%]'<F]U<',`7TAE
M;'``7TEM86=E(%!R;W!E<G1I97,N+BX`7TQO9R!I;@!?3&]G(&]U=`!?36]D
M:69Y($QI;FLN+BX`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN
M:RXN+@!?4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`7U5S97)S`&%D9')E
M<W,@8F]O:P!A9&1R97-S964@=6YK;F]W;@!C86QE;F1A<@!C86QM`&-A;FYO
M="!C<F5A=&4@;W5T<'5T(&9I;&4`8V%N;F]T(&]P96X@:6YP=70`8VQI8VL@
M:&5R90!C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(`8V]N9FEG=7)A=&EO;B!E
M<G)O<@!C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG`&1A=&$@9F]R;6%T
M(&5R<F]R`&5D:70`96YT<GD@;F]T(&9O=6YD`&9A;&QI;F<`9FEL90!F<F]M
M('1H92`E<R`H)7,I(&%T("5S("5S`&=U<W1I;F<`:#H`:&@`:&]S="!N86UE
M('5N:VYO=VX`:6UM961I871E`&EN;&EN90!I;G!U="]O=71P=70@97)R;W(`
M:6YT97)N86P@<V]F='=A<F4@97)R;W(`;&EN97-=`&UK:7-O9G,@97)R;W(@
M8V]D92`E9"!W:&EL92!M86MI;F<@25-/+@!M;0!N86UE`&YO="!I;7!L96UE
M;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`<&5R8V5N=`!P97)M
M:7-S:6]N(&1E;FEE9`!P:7AE;',`<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L
M`')I<VEN9P!S97)V:6-E('5N879A:6QA8FQE`'-H;W<@9&EF9F5R96YC97,`
M<VUS,F5M86EL('9I82!(5%10`'-S`'-T96%D>0!S>7-T96T@97)R;W(`=&%S
M:R!L:7-T`'1E;7!O<F%R>2!F86EL=7)E`'1Y<&4@=&AE('!A<W-W;W)D('1W
M:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5S97(@<V5L96-T`'9#
M87)D`'<Z`'=E871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@
M,RXQ+6-V<PI297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E
M+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-BTP,BTR-R`Q.3HU,2LP,C`P
M"E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#(M,C0@,3(Z-3DK,#(P,`I,87-T
M+51R86YS;&%T;W(Z($QE96YA($AE:6YO(#QL:6EN=4!U=&$N9FD^"DQA;F=U
M86=E+51E86TZ($9I;FYI<V@@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/@I-24U%
M+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S
M970]:7-O+3@X-3DM,0I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X+6)I
M=`H`("@E<R!PY&EVY.0@<VET=&5N*0`@*%!I:V%NY'!PY&EN("5S*0`@*"5S
M('#D:7;D<W/D*0`@*'3D;N3D;BD`("AH=6]M96YN82D`("AE:6QE;BD`(``B
M)7,B(&5I(&]L92!H86ME;6ES=&\`(B5S(B!E:2!K96QP86$@=F%L:6YN86MS
M:2X`(B5S(B!E:2!O;&4@87-E;FYE='1U($AO<F1E;B!R96MI<W1E<FES<^0N
M`"(E<R(@<'5I9&5N(&MU=F%A:F%A(&5I(&SV>71Y;GET+@`B)7,B(&QI<^1T
M=&EI;B!R>6AMY&KD<FIE<W1E;&WDY&XN`"(E<R(@;&ESY'1T:6EN(&]I:V5U
M:W-I:6XN`"(E<R(@96D@;'5O='4Z("5S+@`E+C)F34(@:^1Y=&5T='D@)2XR
M9DU"('-A;&QI='5S=&$@*"4N,F8E)2D`)60@)7,@:F$@)7,`4V%L87-A;F%S
M:2!V86YH96YT=74@)60@<.1I=N1N('#DY'-TY"X`)60@<.1I=N1N(&5N;G5S
M='5S`"5S("T@26QM;VET=7,`)7,@4V]R;65N:N1L:VD`)7,@2T(`)7,@66QL
MY'!I=&]T;VEM96YP:71E970@+2!687)M:7-T=7,`)7,@87-E;FYU<P`E<R!K
M:7)J875T=6UI;F5N`"5S(&OD>71T]F5H9&]T`"5S(&]N(&IO(&]L96UA<W-A
M+@`E<R!S=75N=&$@)7,@)7,`)7,@;VX@=F%L;6ES('-U;W)I='1A;6%A;B!Y
M;&SD<&ET;W1O:6UE;G!I=&5I=.0N(%9A;&ET<V4@=F%L:6YT87)U=61U:7-T
M82!S=6]R:71E='1A=F%T('1O:6UE;G!I=&5E="X`)7,@;VX@<&%K;VQL:6YE
M;@`E<R!M:6YU=71T:6$`)7,@96D@;/9Y='EN>70N`"5S("T@)7,@+R`E<P`E
M<SIN(&]S;VET96MI<FIA`"5S.FX@:V%L96YT97)I`"5S.FX@;75I<W1I;&ES
M=&$`)7,Z;B!T96ATY';D;&ES=&$`)7,Z("5S`"5S(#H@5.1MY"!V:65S=&D@
M96D@;VQE(';D;'1TY&WD='3D('-I;'3D(&SD:&5T=.1JY&QTY"P@:F]K82!O
M;B!M97)K:71T>2!LY&AE='3D:N1K<VDN(%-U:'1A=61U('9A<F%U:W-E;&QA
M('9I97-T:7-SY"!O;&5V:6EN(&QI;FMK96EH:6X@:F$@=F%R;R!A;G1A;6%S
M=&$@;.1H971TY&KD;&QE(&UI=.3D;B!Y:W-I;/9I=FGD('1I971O:F$N`"P@
M<'5U<VMI='1A:7-T80`L('!U=7-K:71T86ES=&$@)7,@)7,`+"!V86EH=&5L
M979A82`E<R`M("5S`"TM('9A;&ET<V4@+2T`,3(M='5N;FEN(&KD<FIE<W1E
M;&WD`#(T+71U;FYI;B!JY')J97-T96QMY``R-"!T=6YT:6$`/$5D96QL:6YE
M;@!4:65T;VMA;G1A=&%U<W1A:N1R:F5S=&5L;>3D(&5I(&]L92!MY.1R:71E
M;'1Y('3D;&QE(&]S:6]L;&4`5&%P86AT=6D@=F%K879A('9I<FAE`%9I97-T
M:6X@<V%L875K<V5E;B!T87)V:71A86X@:G5L:VEN96X@4$=0+6%V86EN+@!!
M;&QE:VER:F]I=&5T=6X@=FEE<W1I;B!T87)K:7-T=6MS965N('1A<G9I=&%A
M;B!J=6QK:6YE;B!01U`M879A:6XN`%-A;&%T=6X@=FEE<W1I;B!A=F%A;6ES
M965N('1A<G9I=&%A;B!J=6QK:6YE;B!01U`M879A:6XL('-A;&%I;F5N(%!'
M4"UA=F%I;B!J82!S86QA<V%N871E:W-T:2X`5FEE<W1I;B!A;&QE:VER:F]I
M='1A;6ES96MS:2!T87)V:71A86X@:G5L:VEN96X@4$=0+6%V86EN+"!S86QA
M:6YE;B!01U`M879A:6X@:F$@<V%L87-A;F%T96MS=&DN`%9I97-T:6X@879A
M86UI<V5E;B!T87)V:71A86X@:G5L:VEN96X@4R]-24U%+6%V86EN+"!S86QA
M:6YE;B!3+TU)344M879A:6X@:F$@<V%L87-A;F%T96MS=&DN`%9I97-T:6X@
M86QL96MI<FIO:71T86UI<V5K<VD@=&%R=FET86%N(&IU;&MI;F5N(%,O34E-
M12UA=F%I;BP@<V%L86EN96X@4R]-24U%+6%V86EN(&IA('-A;&%S86YA=&5K
M<W1I+@!6:65S=&EN('-A;&%U:W-E96X@=&%R=FET86%N(&IU;&MI;F5N(%--
M24U%+6%V86EN+@!!32!0:6QV:>0`04T@:V5V>71TY"!S861E='1A`$%-('-A
M9&4`04T@<V%T96ET80!!32!L=6UI<V%T96ET80!!32]030!!4$D@240`5&EE
M=&]J82!E9&ET;W)I<W1A`%1I971O:F$N+BX`06)S+B!A;&EN`$%B<RX@:V5S
M:V5L;.0`4VEN=6QL82!E:2!O;&4@;VEK975K<VEA(&QU;V1A(%9&4RUH86ME
M;6ES=&]A+@!3:6YU;&QA(&5I(&]L92!O:6ME=6MS:6$@;'5O9&$@5D93+71I
M961O<W1O82X`2^1Y='3D:N1T=6YN=6MS96X@=&EE9&]T`$OD>71TY&KD='5N
M;G5K<V5N('-A;&%S86YA`$OD>71TY&KD=&EL:2!S=6QJ971T=2X`2VER:F%N
M<&ET;P!,:7/DY`!,:7/DY"!A;&ER>6AMY`!,:7/DY"!A;&EO:6ME=7,`3&ES
MY.0@=.1HY&XZ`$QI<^3D('5U<VD@<GEH;>0`3&ESY.0@=75S:2!O:6ME=7,`
M3&ESY.0@86QI<GEH;>0@<GEH;>3D;B`B)7,B`$QI<^3D(&%L:6]I:V5U9&5T
M("(E<R(`3&ESY.0@=75S:2!KY'ET=.1JY#H`3&ESY.0@<V%R86ME`$QI<^3D
M('5U<VEA(&KD<V5N:>0`3&ESY.0@<&%R:0!,:7/DY"`E<R!V86QI:VMO($UO
M>FEL;&%N(%-I9&5B87(@;W-I;V]N`$QI<^3D(&]S;VET96MI<FIA86XZ`$QI
M<^3D(&]S;VET96MI<FIA86YI.@!,:7/DY"!KY'ET=.1JY`!,:7/D='1I:6X@
M(B5S(B!JY')J97-T96QMY.1N+"!M=71T82!E:2!V;VD@;&ESY'3D('-I<^3D
M;FMI<FIA=71U;6ES<'EY;F[V;B!L:7/D=&EE=&]J83H@)7,N`$QI<^1T=&EI
M;B`B)7,B(&KD<FIE<W1E;&WDY&XN(%9O:70@;GET(&MI<FIA=71U82!S:7/D
MY&XN`$OD>71TY&II96X@;&ESY.1M:6YE;B!O;B!E<W1E='1Y+@!/<V]I=&4`
M3W-O:71E:VER:F$`5F]I(&%S971T86$@=&%I(&WDY')I=&5L;.0@;VEK975K
M<VEA('1O:7-I;&QE(&OD>71TY&II;&QE`%EL;.1P:71O`$UA:6YO:W-E=`!!
M9F=A;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!487-A80!487-A=7,Z
M`$MA:6MK:0!+86EK:VD@875T96YT:6MO:61U="!KY'ET=.1JY'0`2V%I:VMI
M(')Y:&WD=`!+86EK:VD@;VEK975D970`2V%I:VEL=&$@;F5L:N1L=.0@<VEV
M=6QT80!386QL:2!M;VYE="!O<V]I='1E970`4V%L;&D@:N1R:F5S=&5T>6X@
M;&ES=&%N('1Y>7!I;B!A<V5T=7,N`$]N(&IO(&]L96UA<W-A`%9A:6AT;V5H
M=&]I;F5N($E-4U`M<VESY.1N:VER:F%U='5M:6YE;@!686EH=&]E:'1O:6YE
M;B!)35-0+7-A;&%S86YA`%9A:6AT;V5H=&]I;F5N($E-4U`M:^1Y='3D:N1T
M=6YN=7,`5F%I:'1O96AT;VES970@<^1H:_9P;W-T:6]S;VET=&5E=`!686EH
M=&]E:'1O:7-E="!M86QL:70`5F%I:'1O96AT;VEN96X@=&5K<W1I.@!9:&1Y
M<W9A;'1A:6X@4V%M;V$`06YN971T=2!A<G9O(&5I(&ME;'!A82X`=&%P86AT
M=6D@='5N=&5M871O;B!V:7)H92X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`
M06YO;GEY;6D@<')O>'D`5F%S=&%U<P!!;G1A<FMT:7,`06YT:6=U82!J82!"
M87)B=61A`$]H:F5L;6$`3VAJ96QM86QI<W1A`$]H:F5L;6$@;VX@=F%L;6ES
M+@!,86ET82!KY'ET=/;V;B!K86EK:VD@86QI:F%K;VEH:6X`2'EVY&MS>0!!
M<G9I;VET=2!K;VMO`&AU:'1I:W5U`$%R86)I82`H5VEN9&]W<RTQ,C4V*0!0
M86ME=&EN(&MO:V\`4&%K971I;B!N:6UI`$]L971K;R!V87)M82P@971TY"!H
M86QU870@<&]I<W1A82!S:7/DY&YK:7)J875T=6UI<W!Y>6YN]FX@)7,@/P!/
M;&5T:V\@=F%R;6$L(&5T=.0@:&%L=6%T('!O:7-T86$@(B5S(B!J82!K86EK
M:VD@<V5N(&%L:7)Y:&WD=#\`06=E;G1I:6YA`$%R;65N:6$`07)M96YI82`H
M05)-4T-)22TX*0!486ED90!!<G5B80!!<V-E;G-I;VX@<V%A<F5T`$%S8VEI
M+71A:61E`$%S:6%N+U1Y>6YE;FUE<F5N(&%L=64`2WES>2!V87)M:7-T=7,@
M96YN96X@:W5I;B!T96ADY.1N('EL;.1P:71O=&]I;65N<&ET965T+@!496AT
MY';D<V%R86MK965T`%ER:71E='1I:6X@<&]I<W1A82!O;&5M871O;G1A(')Y
M:&WDY"X`67)I=&5T=&EI;B!P;VES=&%A(&]L96UA=&]N=&$@;VEK975T=&$N
M`%ER:71E='1I:6X@;75O:V%T82!O;&5M871O;G1A(&]I:V5U='1A+@!9<FET
M971T:6EN(&UU;VMA=&$@;VQE;6%T;VYT82!J86MO82X`3&ESY&WDY')I='EK
M<V5T`&5L;VMU=0!!=7-T<F%L:6$`273D=F%L=&$`075T:%]C>7)S<6PZ(%1A
M<G9I='1A=F%A($E-05`M;&%A:F5N;G5S=&$@96D@;/9Y='EN>70N`$%U=&A?
M8WER=7,Z(%1A=7-T86KD<FIE<W1E;&WD(&5I('1U92!T87)V:71T879I82!O
M;6EN86ES=75K<VEA+@!!=71H7V-Y<G5S.B!487)V:71T879A82!)34%0+6QA
M86IE;FYU<W1A(&5I(&SV>71Y;GET+@!!=71H7V9T<#H@=&%R=FET=&%V86$@
M1E10+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET+B!+Y.1N;N0@4$A0(&OD>71T
MY&5N("TM96YA8FQE+69T<"!A<V5T=7-T82X`075T:%]I;6%P.B!487)V:71T
M879A82!)34%0+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET+@!!=71H7VMR8C4Z
M(%1A<G9I='1A=F%A(&MR8C4M;&%A:F5N;G5S=&$@96D@;/9Y='EN>70N`$%U
M=&A?;&1A<#H@:^1Y='3D:FEE;B!L:7/DY&UI;F5N($%C=&EV92!$:7)E8W1O
M<GEY;B!E:2!O;&4@='5E='1U`$%U=&A?;&1A<#H@2^1Y='3D:FEE;B!P;VES
M=&%M:65N;B!!8W1I=F4@1&ER96-T;W)Y<W3D(&5I(&]L92!T=65T='4`075T
M:%]L9&%P.B!487)V:71T879A82!,1$%0+6QA86IE;FYU<W1A(&5I(&SV>71Y
M;GET+@!!=71H7VQD87`Z($5I('9O:61A(&QI<^1TY"!KY'ET=.1JY.0@)7,N
M(%!A;'9E;&EM96X@=FER:&5I;&UO:71U<R!O;&DZ(`!!=71H7VQD87`Z($5I
M('9O:61A('!O:7-T86$@:^1Y='3D:N3D("5S`$%U=&A?;&1A<#H@16D@=F]I
M9&$@<.1I=N1T=.3D(&OD>71TY&KDY"`E<P!!=71H7VQD87`Z($OD>71TY&II
M96X@<.1I=FET=.1M:6YE;B!!8W1I=F4@1&ER96-T;W)Y>6X@96D@;VQE('1U
M971T=2X`075T:%]M8V%L.B!487)V:71T879A82!-0T%,+6QA86IE;FYU<W1A
M(&5I(&SV>71Y;GET+@!!=71H7W-M8F%U=&@Z(%1A<G9I='1A=F%A('-M8F%U
M=&@M;&%A:F5N;G5S=&$@96D@;/9Y='EN>70N`$%U=&5N=&EK;VEN=&D@24U!
M4"UP86QV96QI;65L;&4@97#D;VYN:7-T=6DN`$%U=&5N=&EK;VEN=&D@97#D
M;VYN:7-T=6D`075T96YT:6MO:6YT:2!E<.1O;FYI<W1U:2X@)7,`075T96YT
M:6MO:6YT:2!2041)55,M<&%L=F5L:6UE;'1A(&5PY&]N;FES='5I+@!!=71E
M;G1I:V]I;G1I($944"UP86QV96QI;65L;&4@97#D;VYN:7-T=6DN`$%U=&5N
M=&EK;VEN=&D@4TU"+7!A;'9E;&EM96QL92!E<.1O;FYI<W1U:2X`2^1Y=&5T
M=.1V:7-SY&]L979A="!K96YTY'0Z`$%Z97)B86EZ9&%N`$)/1D@@<V5L:71Y
M:W-E=`!4875S=&$`5&%U<W1A=N1R:0!6Y.1RY"!K97)B97)O<R!S86QA<V%N
M82X`5N3D<N0@:V5R8F5R;W,@:^1Y='3D:N1T=6YN=7,N`$)A:&%M80!"86AR
M86EN`$)A;'1I82`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`
M1W)A9FEI:V]I9&5N('!E<G5S:&%K96UI<W1O82`B)7,B(&5I(&SV>71Y;GET
M+@!097)U<W9I:79A`%9A;&MO+59E;N1JY`!"96QG:6$`0F5L:7IE`$)E;FEN
M`$)E<FUU9&$`0FAU=&%N`%-Y;G1Y;>1PY&EVY`!/<VEO=&$@(B5S(B!O:&IE
M;&UA;&QE("(E<R(@96D@;/9Y='EN>70N`$]S:6]N(&%S971U:W-E=`!/<VEO
M;B!T>7EP<&D`3&EH879O:71U`$)O;&EV:6$`2VER:F%N;65R:VET`%)E=6YA
M`%)E=6YA;B!V86AV=75S.@!2975N870`0F]S;FEA($AE<GIE9V]V:6YA`$UO
M;&5M;6%T`$)O='-W86YA`$%L:6X`0F]U=F5T('-A87)E=`!"<F%S:6QI80!"
M<FET86YN:6%N($EN=&EA;B!V86QT86UE<F5N('1E<G)I=&]R:6\`0G)U;F5I
M($1A<G5S86QA;0!"=6QG87)I80!086QL=6MK86QI<W1A`$)U<FMI;F$@1F%S
M;P!"=7)U;F1I`$--4P!#4D,`0U),+6IA:V5L=6]S;VET=&5E=`!37V]L=6X@
M=&EE9&]T+BXN`%;D;&EM=6ES=&EN(&%L=7-T=7,@96D@=F%L;6ES='5N=70N
M`$MA;&5N=&5R:0!4>7EN:0!+86UP=71S96$`2V%M97)U;@!386QA<V%N86$@
M96D@=F]I('1Y:&IE;G3DY"!A=71O;6%A='1I<V5S=&DL(&]T82!Y:'1E>71T
MY"!Y;&SD<&ETY&KDY&XN`$5I('9O:2!K:7)J;VET=&%A('1I961O<W1O;VX@
M(B5S(@!5;&MO:7-I82!I<W1U;G1O:^1S:71T96QI:O9I=.0@96D@;VQE(&UA
M:&1O;&QI<W1A(&AA;&QI=&$N`$E-05`M<&%L=F5L:6UE96X@96D@<V%A='4@
M>6AT97ET=.0Z("5S`$5I('9O:2!A=F%T82!T:65D;W-T;V$@(B5S(BX`2V%N
M861A`%!E<G4`4&5R=2!O;F=E;&UA=FEE<W1I`$5I('9O:61A('!O:7-T86$@
M=&EE9&]S=&]A("(E<R(N`%;D;&EA:6MA:7-H86ME;6ES=&]A(&5I(&SV>71Y
M;GET+@!%:2!V;VED82!J871K86$@:6QM86X@)W1A<F=E=$9I;&4G("UP87)A
M;65T<FEA+@!%:2!V;VED82!P;VES=&%A(&AA:V5M:7-T;V$@(B5S(BX`16D@
M=F]I9&$@<&]I<W1A82P@)60@86QI=&%S;VIA(&]L96UA<W-A+@!%:2!V;VD@
M=75D96QL965N:N1R:F5S=.3D+"!A;FYE='1U:F5N('1I971U96ED96X@;>3D
M<N0@96D@=F%S=&%A('1A;&QE=&5T='5J96X@=&EE='5E:61E;B!MY.1RY.0N
M`$5I('9O:2!O:&IA=&$@=FEE<W1IY"!A;FYE='1U=6X@;G5M97)O;VXN`$MA
M<"!697)D90!+=79A=&5K<W1I`%!A;'9E;'5N=&%R:F]A:F$`2V%T96=O<FEA
M="!J82!O='-I:V]T`$-A>6UA;B!S86%R970`4'5H96QI;BA'4TTI`%-O;'5N
M('1I961O=`!3;VQU;B!TY'ET93H`4V]L=6X@=&EE9&]T`%-O;'5N(';D;'ES
M.@!-871K87!U:&5L:6X`2V5L='1I("A)4T\M.#@U.2TQ-"D`2V5S:VET971T
M>0!+97-K:2U!9G)I:V%N('1A<V%V86QT80!+97-K:2U%=7)O;W!P82`H25-/
M+3@X-3DM,BD`5F%R;65N=&5E;B!T:65D;W0`5F%R;65N=&5E;B!O;6ES=&%J
M80!687)M96YT965N('!O;&ET:6EK870`5'-A9`!-=75T80!686EH9&$@<V%L
M87-A;F%S:0!6;VET(&UU=71T86$@;.1H971TY&UI<W/D<VD@<^1H:_9P;W-T
M96ES<V$@;N1K>79IY"!N:6UI+2!T86D@;W-O:71E=&EE=&]J82X`4V%L87-A
M;F%N('9A:6AT;R!E:2!O;&4@:^1Y=/9S<^0@;GEK>6ES:6QLY"!A<V5T=6MS
M:6QL82X@3W1A('EH=&5Y='3D('EL;.1P:73D:FEI;BX`365R:VMI`%1A<FMI
M<W1?82!L:6YK:VDN+BX`0VAI;&4`2VEI;F$`2VEI;F$@>6MS:6YK97)T86ES
M=&5T='4@*$=",C,Q,BD`2VEI;F$@<&5R:6YT96EN96X@*$)I9S4I`%9A;&ET
M<V4@;VAJ96QM80!686QI='-E('-A;&%S86YA`%9A;&ET<V4@:^1Y='3D:N1T
M=6YN=7,`5F%L:71S92!PY&EVY&WDY')I96X@97-I='ES87-U.@!686QI='-E
M(&QI<W1A;B!T>7EP<&D@*&KD<FIE<W1E='EI;&QE(&QI<W1O:6QL92D`2F]U
M;'5S86%R970`3'5O:VMA;>3D<FET>7-TY"`E<R!E:2!L]GET>6YY="X`4V5L
M:V7D`%!O:7-T82!-4T]F9FEC92!T86=I=`!0;VES=&$@:WES96QY`%!O:7-T
M82!KY'ET=.1JY#H@)7,`4&]I<W1A(&OD>71TY&KD`%!O:7-T82!KY'ET=.1J
MY&X@=&EE9&]T`%-E;&ME;F5VY.0@;7GV:.3D;@!.87!S875T82!J871K86%K
M<V5S:0!#;&EK871E;&P@2%144#IN(&MA=71T80!3=6QJ92!I:VMU;F$`4&EL
M=FGD`%!I;'9I;F5N(&%I:V%I<VEN`%!I;'9I;F5N`$MO;VMO<R`H2V5E;&EN
M9RD@<V%A<F5T`%!I96YE;F[D('-I=G5V86QI:VMO`%!I96YE;FYE='ET(')E
M=6YA=`!+;VQU;6)I80!6Y')I`%;D<FEV86QI='-I;@!6Y')I=F%L:6YT80!3
M87)A:SH`4V%R86MK96ED96X@;W1S:6MO=`!387)J86MU=F%T`$MO;65N=&\`
M2V]M96YT;W1U;&MK:0!+;VUM96YT=&D`66QE:6YE;B!N:6UI`$MO;6]R:70`
M67)I='ES`%1I971O:V]N965T`$]L;W-U:&1E`$]L;W-U:'1E970`07-E='5K
M<VEE;B!E<F]T`$%S971U:W-E="!01$$M;&%I='1E:61E;BP@Y&QY<'5H96QI
M;6EE;B!J82!/=71L;V]K:6X@<WEN:W)O;F]I=&EI;BX`07-E='5K<VEA('!I
M=.3D('#D:79I='3DY"X`07-E=&$@87-E='5K<V5T("5S`%9A:'9I<W1A(&MI
M<FIO:71T86UA;&QA('-A;&%S86YA('5U9&5S=&%A;@!+;VYG;P!+;VYG;VX@
M9&5M;VMR86%T=&EN96X@=&%S879A;'1A`%EH=&5Y<R!E<.1O;FYI<W1U:2X`
M66AT97ES(&5PY&]N;FES='5I.B``66AT97ES(&IU;&MI<W1E;B!A=F%I;G1E
M;B!P86QV96QI;65L;&4@97#D;VYN:7-T=6DN`%EH=&5Y<R!J=6QK:7-T96X@
M879A:6YT96X@<&%L=F5L:6UE;&QE(&5PY&]N;FES='5I+B!6:7)H93H@)7,@
M*"5S*0!9:'1E>7,@9G1P+7!A;'9E;&EM96QL92!E<.1O;FYI<W1U:2X`66AT
M97ES=&EE9&]T`%EH=&5Y<W1I961O="!L:7/D='1I:6X@;W-O:71E:VER:F%A
M<VDN`%1I:79I<W1E='EN('1I961O<W1O;B!T>7EP<&DZ`"(E<R(Z;B!S:7/D
M;'3V`$IA=&MA`$-O;VL@<V%A<F5T`$5VY'-T90!+;W!I;VD`2V]P:6]I;G1I
M(&5PY&]N;FES='5I.B`E<P!+;W!I;VD@=F%L:6YT80!#;W-T($E$`$-O<W1A
M(%)I8V$`3F]R<W5N;'5U<F%N;FEK:V\`5FEE<W1I;B!01U`M<V%L875S=&$@
M96D@=F]I='4@=&5H9.0Z(`!6:65S=&EI;B!E:2!V;VET=2!M=6]D;W-T86$@
M4$=0+6%L;&5K:7)J;VET=7-T83H@`%9I97-T:6X@4R]-24U%+7-A;&%U<W1A
M(&5I('9O:71U('1E:&3D+@!6:65S=&EI;B!E:2!V;VET=2!M=6]D;W-T86$@
M4R]-24U%+6%L;&5K:7)J;VET=7-T82X`16D@=F]I='4@;W1T86$@>6AT97ET
M=.0N("5S`$QD87`M<&%L=F5L:6UE96X@96D@<V%A='4@875T;W)I<V]I='5A
M('EH=&5Y='3D+@!%:2!V;VET=2!T87)K:7-T86$@<V%L9&]A+B`E<P!,1$%0
M+7!A;'9E;&EM965N(&5I('-A871U('EH=&5Y='3D+@!%:2!V;VET=2!O='1A
M82!Y:'1E>71TY"!P86QV96QI;65E;B`B)7,B(&OD>71TY&5N($944#H@)7,`
M16D@=F]I='4@;'5O9&$@:F%K96QU;&ES=&%A+B`E<P!01U`M<V%L871T=6$@
M=&EE=&]A(&5I('9O:71U(&%U:V%I<W1A.B``4R]-24U%+7-A;&%T='5A('1I
M971O82!E:2!V;VET=2!A=6MA:7-T82X`16D@=F]I='4@<&]I<W1A82!Y:'1E
M>7-T:65T;V$N("5S`$5I('9O:71U('!O:7-T86$@:F%K96QU;&ES=&%A+B`E
M<P!%:2!V;VET=2!P;VES=&%A('#D:79I='ES<VMR:7!T:>0@(B5S(BX`5FEE
M<W1I;B!LY&AE='3D:N1N('/D:&OV<&]S=&EO<V]I=&5T=&$@96D@<'ES='ET
M='D@;>3D<FET=&5L96WDY&XN`$5I('9O:71U(&AA:V5A(&MO:V\@;W-O:71E
M:VER:F%A+@!%:2!V;VET=2!H86ME82!K;VMO(&IA:V5L=6QI<W1A82X`16D@
M=F]I='4@:&%K96$@:V]K;R!L:7-T86$@:F%K96QU;&ES=&]I<W1A+@!%:2!V
M;VET=2!L=6ME82!S=')A=&5G:6%A("(E<R(N`$MO;65N=&\@;6MD:7(@(B5S
M(B!E<.1O;FYI<W1U:2X`2G5L:VES=&5N(&%V86EN=&5N('!A;'9E;&EM96QT
M82!E:2!S86%T=2!J=6QK:7-T82!A=F%I;G1A+@!4:65D;W-T;V]N("(E<R(@
M96D@=F]I(&MI<FIO:71T86$N`$5I('9O:71U(&%U:V%I<W1A("5S+@!9;&SD
M<&ET;VUO9'5U;&EN("5S(&%U:V%I<W4@97#D;VYN:7-T=6D`16D@=F]I(&%U
M:V%I<W1A(&AA:V5M:7-T;V$@(B5S(BX`3$1!4"UP86QV96QI;65L=&$@96D@
M;VQE(&UA:&1O;&QI<W1A(&5T<VGD+@`E<SKDY"!E:2!V;VET=2!L=6ME82X`
M2^1Y='3D:N1N('-A;&%S86YA82!E:2!V;VET=2!N;VQL871A+B!*;W1K=70@
M=&%R=FET=&%V870@=&EE9&]T(&]V870@=N3D<FEN+B!9<FETY"!U=61E<W1A
M86X@=&%I(&]T82!Y:'1E>71TY"!Y;&SD<&ET;V]N(&IO<R!T87)V:71S970@
M;&ESY.0@87!U82X`16D@=F]I='4@:&%K96$@04-,+71I971O:F$`16D@=F]I
M='4@:&%K96$@;W-O:71E:VER:F%A+B`E<P!%:2!V;VET=2!H86ME82!J86ME
M;'5L:7-T86$N("5S`$5I('9O:71U(&AA:V5A(&IA:V5L=6QI<W1O:F$N("5S
M`$5I('9O:71U(&AA:V5A('1I971O:F$@<&%L=F5L:6UE;B!T;VEM:6YN;VES
M=&$`16D@=F]I='4@<&%L875T=&%A(&%S971U:W-I82X`2V]M96YT;R!R;61I
M<B`B)7,B(&5PY&]N;FES='5I+@!%:2!V;VET=2!T86QL971T86$@)7,@87-E
M='5K<VEA+@!%:2!V;VET=2!T86QL971T86$@87-E='5S=&5N('9A<FUU=7-K
M;W!I;W1A+@!%:2!V;VET=2!T86QL971T86$@87-E='5S=&5N('9A<FUU=7-K
M;W!I;W1A("5S`$5I('9O:71U('1A;&QE='1A82!A<V5T=7-PY&EV:71Y<W-K
M<FEP=&GD.B`B)7,B+@!%:2!V;VET=2!T86QL971T86$@87-E='5S=&5N('9A
M<FUU=7-K;W!I;W1A("5S+@!!<V5T=7-T:65D;W-T;VX@)7,@=&%L;&5T=7,@
M97#D;VYN:7-T=6DN(%9O:70@:^1Y='3DY"!J;W1A:VEN(&%S971U<W1A('1A
M;&QE='1A86MS97-I(&MO;V1I;B!T86MA:7-I;B`E<R!T86D@=&%I(&MO<&EO
M:61A(&OD<VEN(&%L;&$@;VQE=F%N(&MO;V1I;B!T:65D;W-T;V]N("5S+@!,
M1$%0+7!A;'9E;&EM96QT82!E:2!O;&4@;6%H9&]L;&ES=&$@971S:>0N`$MO
M;65N=&\@=6YL:6YK("(E<R(@97#D;VYN:7-T=6DN`$5I('9O:71U('#D:79I
M='3DY"!Y:'1E>7-T:65T;VIA+B`E<P!%:2!V;VET=2!PY&EV:71TY.0@:F%K
M96QU;&ES=&%A+B`E<P!6:65S=&5JY"!E:2!V;VET=2!P;VES=&%A(&MA;G-I
M;W-T82`B)7,B.B`E<P!-;WII;&QA(%-I9&5B87(@96D@;/9Y='EN>70N(%9A
M<FUI<W1A(&5T=.0@4VED96)A<B!O<VEO(&]N(&%U:VDN`$OD>71TY&KD;&QE
M("(E<R(@96D@=F]I='4@86YT86$@<V5U<F%A=FEA(&]I:V5U<VEA(&MA;G-I
M;V]N("(E<R(Z("5S`$QA<VME='1U('1E:W-T:0!-86$`2W5R<W-I=`!,=6\`
M3'5O('5U<VD@;&EN:VMI`$QU;R!U=7-I`%9O:2!L=6]D82!U=7-I82!K86YS
M:6]I=&$`3VEK975D970@=&5K:6KD;&SD`$QU;W1T;VMO<G1I;FYU;65R;P!+
M<F]A=&EA`$MU=6)A`%3D;>1N:&5T:VEN96X@-"!V86EH971T80!4Y&WD;FAE
M=&MI<V5T(&ES='5N;F]T`$ME;&QO;F%I:V$@=.1L;.0@:&5T:V5L;.0`5.1M
MY&YH971K:6YE;B!54DP@;VX`5.1MY&YH971K:7-E="!KY'ET=.1JY'0`5.1M
MY&YH971K:6YE;B!SY.0`5.1MY&YH971K:6YE;B!T:6QA.B``5.1MY&YH971K
M:6YE;B!T>7EL:0!6;VET(&UU;VMA=&$@=&5H=.1V:>0L(&IO=&MA('-U;W)I
M=&5T86%N(&MU;B!K:7)J875D=71A86X@<VESY.1N(&]H:F5L;6%A;B`E<RX`
M3&5I:VMA80!,96EK:V%A('9A;&ET='4`2WEP<F]S`$MY<FEL;&EN96X@*$M/
M23@M4BD`2WER:6QL:6YE;B`H5VEN9&]W<RTQ,C4Q*0!+>7)I;&QI;F5N+U5K
M<F%I;F$@*$M/23@M52D`5'-E:VEN('1A<V%V86QT80!04`!$4TX@*&QI<^1T
M:65T;V$@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD
M871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!0Y&EV:71TY&EN`$1A=&%4<F5E
M+7-E;&%I;@!4:65T;VMA;G1A:&%K=0!0Y&EVY'ES`%#D:7;D;>3D<N0@=F%S
M=&%A;F]T971T=0!0Y&EVY&WDY'+D;B!V86QI;G1A`%#D:7;D`%!O7VES=&$@
M<V%R86ME`&IO=6QU:W5U`$1E<VEM86%L:6YU;65R;W0`4&EE;F5N;N0@<VES
M96YN>7-TY`!/;&5T=7,`3VQE='5S=N1R:0!/;&5T=7-P<F]F:6EL:0!/;&5T
M=7,@:V]M96YT;W1U;&MK:0!-Y.1R:71E;&WD=`!0;VES=&$`4&]I<W1A('-O
M;'4`4&]I<W1A(')Y:&WD`%!O:7-T82!L;VMI`%!O:7-T82!O:6ME=7,`5F]I
M('!O:7-T86$@:F$@='5H;W1A('!O:7-T971T=6IA('9I97-T96KD`%!O:7-T
M82!S;VQU`%!O:7-T82!S87)A:V4`4&]I<W1A(&]L96UA<W-A(&]L979A="!V
M86EH=&]E:'1O:6YE;B!M86QL:0!6;VD@<&]I<W1A82!V:65S=&5JY`!0;VES
M=&$@(B5S(CIN(&]I:V5U:W-I80!/;&5T:V\@=F%R;6$L(&5T=.0@:&%L=6%T
M('!O:7-T86$@(B5S(B!J82!K86EK:VD@<V5N(&%L:6]I:V5U9&5T/P!0;VES
M=&$@<FEV:0!0;VES=&$@=F%L:71T=2!P<F]F:6EL:0!6;VD@;'5O9&$@=75S
M:6$@:V%N<VEO:71A`%!O:7-T82!V86QI='1U('-A<F%K90!0;VES=&$@=F%L
M:71T=2!R:79I`%!O:7-T971T=2!PY&EV:71Y<W-K<FEP=&D@(B5S(BX`5&]I
M;6ET=7-A:6MA`%1A;G-K80!/;F=E;&UA;B!K=79A=7,`2W5V875S`%1A<FME
M;6UA="!T:65D;W0@*&SV>71Y=N1T(&UY]G,@2&]R9&4Z;B!L;VMI=&EE9&]S
M=&]S=&$I.@!487)K96UM870@=&EE9&]T(&]N('1A;&QE=&5T='4@>6QLY'!I
M9&]N(&OD<VET96QTY';D:W-I+@!+96AI='ES`$MO<W1E=7-P:7-T90!%9&5L
M;&ES96X@='5N;FEN(&MO<W1E=7-P:7-T93H@`$MO<W1E=7-P:7-T93H@`%-U
M=6YT82!V87-E;6UA;'1A(&]I:V5A;&QE`%-U=6YT82!O:6ME86QT82!V87-E
M;6UA;&QE`$AA:V5M:7-T;P!+Y'ETY"`R-"UT=6YN:6X@86EK865S:71Y<W3D
M+@!.Y&MY;>1N(&%S971U:W-E=`!%<VET>7-T87!A('EK<VET>6ES:V]H=&%I
M;F5N(&5N;G5S=&4`17-I='ES=&%P82!E;FYU<W1E96QL92`H5$%&*0!%<VET
M>7-T87!A`%!E<FEL;&5M96YO:6QM;VET=7,`1&II8F]U=&D`16D@<V%A('!O
M:7-T86$`Q&SD(&OD>73D('-U;W)A86X@;6%I;G1E;F%N8V4N<&AP.G3D`$IO
M<R!E;G-I;6WD:6YE;B!R:79I('-I<^1L=.3D('-A<F%K:V5I9&5N(&]T<VEK
M;W0L(&YI:6X@=F%L:71S93H`1&]M:6YI:V%A;FEN96X`1&]M:6YI:V%A;FEN
M96X@=&%S879A;'1A`$5I:_8@;VQE(&OD>71TY&KD='5N;G5S=&$_($MI<FIA
M=61U(&OD>71TY&KD:W-I+@!486QL96YN80!486QL96YN82`E<P!486QL96YN
M82!L=6]T=2!A<V5T=7,@4$A0+7-K<FEP=&ENY"X`06QA<W9E=&]V86QI:VMO
M`$AU=6UE970`4^1H:_9P;W-T:6]S;VET90!%36%I;"UT;RU335,@9V%T97=A
M>2!A:G5R:2P@;FEI;&QE('!A;'9E;'5N=&%R:F]A:FEL;&4L(&IO=&MA('1A
M<FIO879A="!TY'3D('!A;'9E;'5A+@!625)(10!%8W5A9&]R`$UU;VMK86$`
M375O:VMA82!O<VEO=&$`375O:VMA82!R>6AMY.0`375O:VMA82!O:6ME=71T
M80!-=6]K:V%A(&]I:V5U:W-I80!-=6]K:V%A("<E<R<Z;B!O:6ME=6MS:6$`
M375O:VMA82!A<V5T=6MS:6$Z`$UU;VMK86$@(B5S(CIN(&]I:V5U:W-I80!-
M=6]K:V%A("5S.FX@;VEK975K<VEA`$MO=6QU='5S`$5G>7!T:0!%;"!386QV
M861O<@!%;&5M96YT=&DN+BX`16T`4^1H:_9P;W-T:0!3Y&AK]G!O<W1I;W-O
M:71E`%/D:&OV<&]S=&EO<V]I='1E:61E;B!P:73DY"!O;&QA('-A;6%T+@!3
MY&AK]G!O<W1I('9A<FUI<W1U:W-E;&QA`$5M86EL+71O+5--4R!'871E=V%Y
M`$AY;6GV=`!4>6AJY"!V:65S=&DN`%1Y:&KD('9A<W1A=7,N`%1Y:&KD(&AA
M:W5T97)M:0!386QL:2!K=79I96X@;&%I='1A;6EN96X@:W5V86=A;&QE<FEA
M<W1A('1E:W-T:6X@:F]U:VMO;VXN`$QA:71A('#DY&QL92!O:6ME86X@<&%I
M;FEK:V5E;B!K;VYT96MS=&EM96YU+@!0Y.1T='EM:7-V=6]S:0!3=75R96YN
M82!E9&ET;W)I80!!;FYA(&MY<WEM>7,@:F]K82!K>7-Y=.3D;BP@:F]S('-A
M;&%S86YA<VD@:F]U9'5T86%N(&YO;&QA86UA86X@97-I;65R:VEK<VD@)VUI
M:^0@;VX@;&5M;6EK:VES:2!N:6UI/R<Z`$QA:71A(&MU=F$@55),('3D:.1N
M`$%N;F$@:VER:F%I;65T(&%L;&4Z`$5K=F%T;W)I86%L:6YE;B!'=6EN96$`
M17)I=')E80!6:7)H90!6:7)H92!PY&EV:71E='3D97-SY"!O<VEO=&$Z("5S
M`%9I<FAE('#D:79I=&5T=.1E<W/D('-Y;F,@86YC:&]R("UT:65T;V$Z("5S
M`%9I<FAE('!O:7-T971T865S<V$@<WEN8R!L;VMI83H@)7,`5FER:&4@:&%E
M='1A97-S82!S:7/D;'3VY#H@)7,N`%9I<FAE('#D:79I=&5T=.1E<W/D('-A
M;&%S86YA83H@)7,`5FER:&4@<^1H:_9P;W-T:79I97-T:7-SY"X`5FER:&4@
M:VER:F]I=&5T=&%E<W-A("(E<R(N`$5E<W1I`$5T:6]P:6$`171N:6YE;@!%
M=7)O;W!P80`Q-2!M:6YU=71I;B!VY&QE:6X`,B!M:6YU=71I;B!VY&QE:6X`
M,S`@<V5K=6YN:6X@=N1L96EN`#4@;6EN=75T:6X@=N1L96EN`$IO:V%I<V5L
M;&$@<VESY.1N:VER:F%U='5M:7-E;&QA`%!U;VQE;B!T=6YN:6X@=N1L96EN
M`$UI;G5U=&EN(';D;&5I;@!%<VEM97)K:VEA<G9O=#H`4W5O<FET80!,86%J
M96YN80!,86%J96YN82!S:79U=F%L:6MK;P!/9&]T971T:6EN(&UE<FMK:>0@
M)RDG`%-A;F$@<V5L;&%I<V5N86%N('1A:2!H86MU=&5R;6D@;&%I;F%U<VUE
M<FME:7-SY`!,;W!P=7#D:7;D;>3D<N0`16MS<&]N96YT=&D`1D<@=N1R:0!!
M<V5T=7-T:65D;W-T;VIE;B!T=6]N=&D@1E10.FQLY`!!<V5T=7-T96X@:&%K
M=2!E<.1O;FYI<W1U:2X`66AT97ES($Q$05`M<&%L=F5L:6UE96X@97#D;VYN
M:7-T=6DN`%EH=&5Y<R!334(M<&%L=F5L:6UE96X@97#D;VYN:7-T=6DN`$MO
M<&EO:6YT:2`B)7,B.FQTY"!E<.1O;FYI<W1U:2X`2V]P:6]I;G1I("(E<R(Z
M;&QE(&5PY&]N;FES='5I+@!5=61E;B!305-,+7EH=&5Y9&5N(&QU;VUI;F5N
M(&5PY&]N;FES='5I+@!3:6ER=&\@(B5S(CKDY&X@97#D;VYN:7-T=6DN`%-I
M:7)T;R!E<.1O;FYI<W1U:3H@)7,`2V%U;FES`$9A;&ML86YD:6X@<V%A<F5T
M("A-86QV:6YA<RD`1N1R('-A87)E=`!686MA=F$@=FER:&4Z`$9A:W-I`$9A
M:W-I=`!H96QM:6MU=0!4=6YT=74@:W5I;@!4=6YT=74@:W5I;CH@`$UU=71A
M;6EA('-A=&5I=&$`375U=&%M:6$@;'5M:7-A=&5I=&$`2V5N='3D;6%T<FEI
M<VD`1FEG;&5T($-!4%1#2$$`1FEG;&5T(&MI<FIA<VEN`$9I9'II`%1I961O
M<W1O`%1I961O<W1O:F5N(&QU:W5MY.1RY#H@)7,@=&EE9&]S=&\`5&EE9&]S
M=&]J96X@;'5K=6WDY'+D.B`E<R!T:65D;W-T;V$`5&EE9&]S=&]J96X@:^1S
M:71T96QY`%1I961O<W1O;B!N:6UI`%1I961O<W1O;B!V86QI;G1A`%1I961O
M<W1O;B!T=6]N=&D`5&EE9&]S=&]J96X@='5O;G1I(&5I(&]L92!KY'ET971T
MY'9I<W/D+@!3=6]D871T:6UE=`!3=6]M:0!%;G-I;6WD:6YE;B!P=6]L:7-K
M;P!%;G-I;6WD:6YE;B!N96QJY&YN97,`2V]R:F%A('-U:&1E`$ODY&YNY"!Y
M;7#D<FD`2V5L;'5V80!3=6UU`$MA;G-I;W1A("5S(&5I(&]L92!O;&5M87-S
M82X`2VER:F%S:6UE;B!VY')I`%)U;VMA`%-E;&%I;6EL;&4L(&IO=&MA(&5I
M=N1T('1U92!K=79I80!%;FYU<W1E("A4048I`$5N;G5S=&5T=&%V870@=G5O
M<F]K875D970@*$AU;VUA871H86X@971TY"!E;FYU<W1U:W-E<W-A(&]N('1I
M961O="!S96OD('#D:79I<W3D(&5T=.0@]FES=.0L(&IO=&5N('-U=7)I(&WD
MY'+D('#D:79IY"!A:6AE=71T86$@;&EI86X@;&5V9>1N(&]S:6]N*0!5;F]H
M9&ET:V\@<V%L87-A;F%S:3\`3&]M86MK965T`$UI971E;&%U<V4`36EE=&5L
M875S965N('1Y>7!P:0!-:65T96QA=7-E970`36EE=&5L875S965T(#(`1F]O
M<G5M:70`575D96QL965N;VAJ875K<V5T`'!E`$ME:'EK<V5T`%)A;G-K80!2
M86YS:V$L($UE=')O<&]L:0!286YS:V%N($=U>6%N80!286YS:V%N(%!O;'EN
M97-I80!286YS:V%N(&5T96SD:7-E="!T97)R:71O<FEO=`!,Y&AE='3D:N0`
M4W5U;FYA<W1A(`!0:61E;7!I(&MU=F%U<SH`5.1Y<VEK=74`2V]K;R!N:6UI
M`$=A8F]N`$=A;&QE<FEA+"!J;W-T82!K=79A(&]T971A86X`1V%L;&5R:6$Z
M`$=A;6)I80!4964@)7,@87-E='5K<V5T`$=E;F5R;VET=2!K;V]D:0!'96]R
M9VEA`%-A:W-A`$=H86YA`$=I8G)A;'1A<@!%='5N:6UI`%EL96ES970@87-E
M='5K<V5T`$UE;F4`1_9D96P`1V]O9VQE($MA<G1A=`!';V]G;&4@:&%K=0!(
M87)M86%SY'9Y`$MR96EK:V$`2W)E:6MK82`H25-/+3@X-3DM-RD`1W+V;FQA
M;G1I`$=R96YA9&$`4GEH;>1N('EL;.1P:71O`%)Y:&UI96X@;FEM970@96EV
MY'0@<V%A(&]L;&$@='EH:FGD`$=R;W5P7VQD87`Z($5I('9O:61A(&QI<^1T
MY"!KY'ET=.1JY.0@)7,N(%!A;'9E;&EM96X@=FER:&5I;&UO:71U<R!O;&DZ
M(`!'<F]U<%]L9&%P.B!%:2!V;VED82!PY&EVY'1TY.0@:^1Y='3D:N3D("5S
M`$=R;W5P7VQD87`Z($5I('9O:61A('#D:7;D='3DY"!KY'ET=.1JY.0@)7,`
M4GEH;>1T`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`5FEE
M<F%I;&EJ86X@;VEK975D970`5FEE<F%S:VER:F$`1W5I;F5A`$=U:6YE82U"
M:7-S874`1W5Y86YA`$A434P`2%1-3$%R96$@<&5L:W5R:6UA:7-E<W1I(&MI
M96QTY'ET>7D@<&]I<W1A;6%S=&$@<FEV:6X@=FEI;65I<W3D('-O;'5A+@!(
M5$U,07)E82!P96QK=7)I;6%I<V5S=&D@:VEE;'3D>71Y>2!P;VES=&%M87-T
M82!V:6EM96ES=.0@<V%R86ME='1A('1A=6QU:V]S=&$N`$A434Q!<F5A('!E
M;&MU<FEM86ES97-T:2!K:65L=.1Y='EY('!O:7-T86UA<W1A('9I:6UE:7-T
MY"!R:79IY"!T875L=6MO<W1A+@!(5%10+6%U=&5N=&EK;VEN=&EA(&5I(&SV
M>71Y;GET+@!(86ET:0!(87-H+6%L9V]R:71M:0!5<W9A`$]T<V%K90!/='-A
M:V4`2&5A<F0@:F$@36-$;VYA;&0@<V%A<F5T`%9O:6UA:V%S('5K:V]S;7ER
M<VMY`$AE<')E82`H25-/+3@X-3DM."U)*0!+;W)K975S`$]H:F4`07!U82!E
M9&ET;W)I;B!KY'ET=/;V;@!/:&IE`%!A;&QO;G!U;VQI<VMO.@!4Y'-SY"!O
M;B!T:65D;W-T;VX@86QK=6]S83H`2V]R:V5A`$MO7W1I`%!Y:.0@:7-T=6EN
M("A6871I:V%A;FEN(&MA=7!U;FMI=F%L=&EO*0!+;W1I`$MO=&EO<V]I=&4`
M2V]T:6AA:V5M:7-T;P!0=6AE;&EN("AK;W1I*0!(;VYD=7)A<P!(;VYG($MO
M;F<`2&]R9&4`2&]R9&4O2V]L86(Z($5PY&ME;'!O82`E<R!834PM9&%T86$@
M=FEE<W1I<W/D("5S`$AO<F1E+TMO;&%B.B!9:W-I:^3D;B!V:65S=&D@96D@
M=F%S=&%A(&]B:F5K=&EA("5S`$AO<F1E+TMO;&%B.B!9:'3D:^3D;B!O8FIE
M:W1I82`E<R!E:2!L]GET>6YY="!V:65S=&ES=.0@)7,`2&]R9&4O2V]L86(Z
M(%!O:7-T971T:6EN("5S("(E<R(`2&]R9&4O2V]L86(Z($EN=&5G<F%A=&EO
M:V]N92!V86%T:6D@=&]I;6EA:W-E96X@)V1O;7AM;"<@4$A0+6QA86IE;FYU
M:W-E;@!(;W)D92]+;VQA8CH@16D@=F]I9&$@;'5O9&$@=75T=&$@6$U,+7!U
M=71A(&]B:F5K=&EL;&4@)7,`2&]R9&4O2V]L86(Z($5I('9O:71U('!O:7-T
M86$@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z($5I('9O:61A(&AA:V5A($U)
M344@240ZY"!O<VEO;&QE('1Y>7!P:>0@)7,`2&]R9&4O2V]L86(Z($5I('9O
M:2!S>6MR;VYO:61A("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!%:2!V;VED
M82!S>6YK<F]N;VED82!J86MO:F$Z("5S`$AO<F1E+TMO;&%B.B!4=6YT96UA
M=&]N(&IA:V\@(B5S(@!686%K87-U;W)A('/DY&YT]@!686%K87-U;W)A('3D
M>71E`%9A86MA<W5O<F$Z`$UI=&5N('1U;&ET('3D;FYE/R`H4F%P;W)T;VD@
M:VEI=&]S(2D`2W5I;FMA(&UO;G1A('-A<F%K971T82!H86QU870@>6AD:7-T
MY.0_`$ME;G1T:65N("AS87)A:VME:61E;BD@;'5K=6WDY'+D+@!+=6EN:V$@
M;6]N=&$@<FEV:>0@:&%L=6%T('EH9&ES=.3D/P!+;W-T975S`$MO<W1E=7,Z
M(`!(=6UO<FES=&ET`%5N:V%R:0!)34%0+7!O<W1I;&%A=&EK;VX@;'5O;G1I
M(&5PY&]N;FES='5I.B`E<P!)34%0+7!O<W1I;&%A=&EK;VX@<&]I<W1O(&5P
MY&]N;FES='5I.B`E<P!)34%0+7!O<W1I;&%A=&EK;VX@:VEI;G1I]FX@;'5O
M;G1I(&5PY&]N;FES='5I.B`E<P!)4"UO<V]I=&4`25`M;W-O:71E(&5I(&]L
M92!KY'ET971TY'9I<W/D+@!)4"UO<V]I=&4@96D@;VQE('-A;&QI='5N($-)
M1%(M8FQO:VEN('-I<^1L;.0`25`M<^3D;F[V<W3V;B!R:6MK;VUU<P!,7V%I
M=&$@<FEV:2!E;FYE;@!)<VQA;G1I`%9A:6X@:6MO;FET`$EK;VYI="`E<SIL
M;&4`26MO;FET(&IA('1E:W-T:0!0<F]F:6EL:6X@;FEM:3H`2F]S('-I=G4@
M96D@;N1Y(&MU;FYO;&QA+"!N:6EN(&%U:V%I<V4@)7,@97)I;&QI<V5S<^0@
M:6MK=6YA<W-A+@!*;W,@970@;N1E(&EK;VYE:71A(&OD>71TY&5S<^1S:2!)
M;G1E<FYE="!%>'!L;W)E<B!S96QA:6YT82P@;FEI;B!S:6YU;B!P:73DY"!O
M='1A82!P;VES('#DY&QTY"!03D<@;.1P:6[D:WEV>7ES(')A<W1I='1A;6%L
M;&$@=.1MY"!L86%T:6MK;RX`2F]S(&[D970@=.1MY&X@=FEE<W1I;BP@;75T
M=&$@970@:W5V86$L(&YI:6X@='5O;6%A<VD@:W5V86$@96D@=F]I(&[D>71T
MY.0@:^1Y='3D;>1S<^1S:2!S96QA:6UE<W-A+@!+=79I96X@97-I:V%T<V5L
M=0!+=79A(%523`!+=79A(%523#H`2W5V82!G86QL97)I87-T80!+=79A(&=A
M;&QE<FEA<W1A.@!+=79A;B!V:65N=&D`2W5V870`5'5O;G1I+"!A<VME;"`E
M9`!4=6]T=2!K96YT=.0Z("5S`%1U;V1U="!K96YTY'0Z`$QA7VET82!R:79I
M(&KD;&ME96X`5N3D<N0@=&]I;6EN=&]K;V]D:2!A;FYE='1U+@!+Y'ET=.1J
MY'1U;FYU<R!T86D@<V%L87-A;F$@;VX@=N3D<FEN+@!6Y.1RY"!KY'ET=.1J
MY'1U;FYU<R!T86D@=F%I:'1O96AT;VEN96X@;W-O:71E+B!9<FETY"!U=61E
M<W1A86X@:F$@;W1A('EH=&5Y='3D('EL;.1P:71O;VX@:F]S('1A<G9I='-E
M="!L:7/DY"!A<'5A+@!,:7/DY"!S:7-E;FYY<W3D`$EN=&EA`%EK<VET=.1I
M<V5T(&OD>71TY&KD=`!);F1O;F5S:6$`26YF;P!);F9O<FUA871I;P!4:65T
M;V$@96D@;VQE(&5NY.0@<V%A=&%V:6QL82X`3&%I=&$@<U]A<F%K92!JY&QK
M965N`$QA:71A(&MU=F$`3&%I=&$@=&%U;'5K:V\`3&%I=&$@=W=W+6QI;FMK
M:0!,86ET82!?<V%R86ME(&5N;F5N`$QA:71A('5U<VD@<V%R86ME(&YY:WEI
M<V5N(&KD;&ME96X`3&%I=&$@=75S:2!S87)A:V4@96YN96X@;GEK>6ES=.0`
M3&%I=&$@=75S:2!R:79I(&YY:WEI<V5N(&KD;&ME96X`3&%I=&$@=75S:2!R
M:79I(&5N;F5N(&YY:WEI<W3D`$QA:71A(&MA<'!A;&4@;GEK>6ES96X@;F]D
M96X@:N1L:V5E;@!,86ET82!K87!P86QE(&5N;F5N(&YY:WEI<W3D(&YO9&5A
M`$QA:71A('9A:6AT;V5H=&]I;F5N(&UA;&QI`$%N;F$@<^1H:_9P;W-T:6]S
M;VET92!J;VAO;B!U=7-I('-A;&%S86YA(&SD:&5T973DY&XZ`$QA:71A('-O
M;'4@:N1L:V5E;@!,86ET82!S;VQU(&5N;F5N`$QA:71A('-O;'4@:N1L:V5E
M;@!,86ET82!S87)A:V4@96YN96X`5F]I(&QA:71T86$@=FEE<W1E:N0`3&%I
M=&$@:V%P<&%L92!JY&QK965N`$QA:71A(&MA<'!A;&4@96YN96X`3&%I=&$@
M<FEV:2!E;FYE;@!,86ET82!R:79I(&KD;&ME96X`06YN82!V86%D:71T879A
M('9A<W1A=7,@='5R=F%K>7-Y;7EK<V5E;CH`3&EI=.0O375O:VMA82!K=79I
M80!,:6ETY"]-=6]K:V%A(&QI;FMK:>0`4VEN=6QL82!E:2!O;&4@=&%R<&5E
M:W-I(&MR961I:71T96KD(&SD:&5T=.3D:W-E<VD@=FEE<W1I;B!J86ME;'5L
M:7-T86QL92X`4FEI='3D;>1T=/9MY'-T:2!K<F5D:6ET=&5JY`!+;VMO;F%I
M<VQU:W4`2V]K;VYA:7-L=6MU;&ES=&$`17#D:V5L<&\@(%5$2"`H57-E<B!$
M871A($AE861E<BDN`$5PY&ME;'!O82!:25`M=&EE=&]A+@!%<.1K96QP;R!O
M:&IE;&UA+@!%<.1K96QP;R!B871C:"!)1"X`3.1H971E='1I:6X@97#D:V5L
M<&]A('1I971O82X`17#D:V5L<&\@=F%S=&%A;F]T=&%J86X@;W-O:71E+@!%
M<.1K96QP;R!T:65D;W-T;VUU;W1O`$5PY&ME;'!O(&QI<V5N<W-I879A:6XN
M`$5PY&ME;'!O('!A:6MK871I971O+@!%<.1K96QP;R!M<V=?='EP92`N`$5P
MY&ME;'!O('1A:2!P=75T='5V82!A<&E?:60N`$5PY&ME;'!O('1A:2!P=75T
M='5V82!P87)A;65T<FDN`$5PY&ME;'9O="!O:6ME=61E="!Y;&5M;>1L;.0@
M=&%S;VQL82X`17#D:V5L<&\@<&%R;F5R(&ED+@!%<.1K96QP;R!T=6]T96MO
M;V1I+@!%<.1K96QP;R!P<F]T;VMO;&QA+@!%<.1K96QP;R!V87-T86%N;W1T
M86IA.B`B)7,B`$5PY&ME;'!O(&IA:V\M;V)J96MT:0!%<.1K96QP;R!LY&AD
M96]S;VET92X`17#D:V5L<&]A('5N:6-O9&4M=&EE=&]A+@!);G9E;G1A87)I
M;P!+Y.1N;N0@=F%L:6YT82!KY.1N=&5I<V5K<VD`27)A;BP@27-L86UI;&%I
M;F5N('1A<V%V86QT80!)<F%K`$ER;&%N=&D`36%N+7-A87)I`$5R:6QL:7-I
MY"!5:VMO<VUY<G-K>6KD`$ES<F%E;`!,:6EK:V5E;&QE;&%S:VEJ80!+=7)S
M:79O:71U`$ET86QI80!*86UA:6MA`'1A;6UI:W5U`$IA<&%N:0!*87!A;FD@
M*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N:6$`:&5I;N1K=74`:V5SY&MU
M=0!+97-K:73D`$ME<VMI=.0@:V5S:V5L;&4`2V5S:VETY"!TY'ES:6X`2V5S
M:VETY"!V87-E;6UA;&QE`$ME<VMI=.0@;VEK96%L;&4`2V%Z86MS=&%N`%/D
M:6QY=.0@86QK=7!E<N1I;F5N/P!+96YI80!!=71E;G1I:V]I;G1I(&5PY&]N
M;FES='5I($ME<F)E<F]S+7!A;'9E;&EM96QL92X`2V5R;F5L(&%L;VET=&5L
M:6IA=`!!=F%I;65N(&QU;VYT:0!!=F%I;65N('1U;FYI<W1E`$%V86EM96X@
M<&ET=75S`$%V86EM96X@='EY<'!I`$%V86EM96X@:^1Y='3V`$%V86EN(&]N
M(&IO(&IU;&MI<W1E;B!A=F%I;G1E;B!P86QV96QI;65L;&$`3&%P<V5T`$MI
M<FEB871I`$MO<F5A+"!D96UO:W)A871T:6YE;B!K86YS86YT87-A=F%L=&$@
M*%!O:&IO:7,M2V]R96$I`$MO<F5A+"!T87-A=F%L=&$@*$5T96SD+4MO<F5A
M*0!+;W)E82`H155#+4M2*0!+=7=A:70`2VER9VES=&%N`$%S7V5T=&5L=0!+
M:65L:0!,86]S+"!D96UO:W)A871T:6YE;B!K86YS86YT87-A=F%L=&$`2N1L
M:VEM;>1I;F5N('!U;VQI<VMO`$5D96QL:6YE;B!S86QA<V%N86YV86EH=&\`
M2N1L:VEM;>1I;F5N(&YE;&KD;FYE<P!0Y&EV:71E='1Y('9I:6UE:W-I.@!%
M9&5L;&EN96X@<VESY.1N:VER:F%U='5M:6YE;CH@)7,`161E;&QI;F5N('-I
M<^3D;FMI<FIA=71U;6EN96XZ("5S+"`E<P!%9&5L;&EN96X@<VESY.1N:VER
M:F%U='5M:6YE;CH@16D@;6EL;&]I;FMA86X`3&%T=FEA`$QA:VD`07-E='1E
M;'4`2N1TY"!T>6AJY&MS:2!J;W,@96D@<F5U;F]J80!,:6)A;F]N`%9A<V5N
M`%9A<V5N(&]T<V%K90!687-E;B!A<G9O=`!,97-O=&\`5&%S;P!,:6)E<FEA
M`$QI8GEA($%R86(@2F%M86AI<FEY80!,:6-H=&5N<W1A:6X`2V5V>71TY"!R
MY&YTY.0`2VER:F%U9'4@<VESY.1N`$ME=GET=.0@<V%D971T82!A:6MA:7-I
M;@!+979Y='3D('-A9&5T=&$@;7GV:&5M;6EN`$ME=GEI=.0@<V%D96MU=7)O
M:F$`2V5V>71TY"!S861E='1A(&IA(&UY<G-K>6ES=.0`2V5V>71TY"!L=6UI
M<V%D971T80!+979Y:73D(&QU;6EK=75R;VIA`$QI;65R:6MI=`!,:6YK:VD`
M3&EN:VMI(&]S;VET=&%A.@!,:6YK:73D('/D:&OV<&]S=&EO<V]I=&4@:VER
M:F]I=&$@=75S:2!V:65S=&D@<VEV=6QL92!NY&MY;>1S<^0`3&EN:VET`$QI
M;G5X('!I<&%R96ET80!6;VD@;&ES=&%U:W-E<W-A(&[D:&3D(&MA;G-I;VX`
M3N1Y=.0@=&EE=&]K86YN870`3N1Y=.0@;VAJ96ED96X@86EH965T`$[D>73D
M('1A=6QU=`!,:7-T86XM07)K:7-T;P!,:7-T86XM3VAJ90!,:7-T86XM260`
M3&ES=&%N+4]M:7-T86IA`$QI<W1A+79I97-T:0!,:7-T86XM5&EL875S`$QI
M<W1A;BU4:6QA=6MS96XM;&]P971T86UI;F5N`$ES='5N=&]J96X@;&ES=&%U
M<R!E<.1O;FYI<W1U:3H@)7,`2^1Y='3D:FEE;B!L:7-T875S(&5PY&]N;FES
M='5I.B`E<P!+Y'ET=.1JY'1I971O:F5N(&[D>71TY&UI;F5N(&]N(&5S=&5T
M='DN`$MI<FIA;&QI<W5U<P!,:65T='5A`$QA9&%T86%N+BXN`%!A:6MA;&QI
M<W1A(&%I:V%A.B``3&]K86QI<V%A=&EO(&IA(&%I:V$`4&%I:VMA`$MI<FIA
M=61U('-I<^3D;@!%9&5L;&ES96X@<WEN:W)O;F]I;G1I<V5S<VEO;B!L;VMI
M`$MI<FIA=61U('5L;W,`2VER:F%U9'4@<VESY.1N`%1E:'3D=N1T('-I<^3D
M;FMI<FIA=71U;6ES97-S80!3:7/DY&YK:7)J875T=6UI<V5S:2!E<.1O;FYI
M<W1U:2X@5&]D96YNY&OV:7-E<W1I(&MI<FIO:71I="!VY.1R:6X@:^1Y='3D
M:N1T=6YN=6MS97-I('1A:2!S86QA<V%N87-I+@!3:7/DY&YK:7)J875T=6UI
M;F5N(&5PY&]N;FES='5I+@!0:71KY"!T96MS=&D`4F%K:V%U<P!-871A;&$`
M4&EE;F5T(&MR96EK:V%L86ES970@:VER:F%I;65T`%!I96YE="!L871I;F%L
M86ES970@:VER:F%I;65T`%!I96YE="!R;V]M86QA:7-E="!N=6UE<F]T`$QU
M>&5M8G5R9P!+2P!-3U1$`$U3+51.148@;&EI=&5T:65D;W-T;R!O;&D@='EH
M:N0N`%9)15-420!-86-A;P!-86ME9&]N:6$L($5N=&EN96X@2G5G;W-L879I
M86X@=&%S879A;&QA;BX`36%D86=A<VMA<@!486EK=75S`%/D:&OV<&]S=&D`
M4&]S=&EN('EL;.1P:71O`%1E92!L:6YK7VMI+BXN`$UA;&%W:0!-86QE<VEA
M`$UA;&5D:6EV:70`4&]S=&D`36%L=&$`5F]I="!H86QL:6YN;VED82!L:7-T
M86$@:V%T96=O<FEO:7-T82P@:F]I9&5N(&%V=6QL82!V;VET(&QI:71TY.0@
M87-I;VET82!Y:'1E96X@<V%M;VIE;B!O='-A:VME:61E;B!A;&QE(&IA(&QI
M:71TY.0@;FEI:&EN(';D<F5JY"X`36%P,C0@:V%R='1A`$UA<%%U97-T(&MA
M<G1T80!687-T86%V=75D970@=&%L;&5T971T=2X`;6%A;&ES:W5U`$UA<F=I
M;F%A;&D`5F]I(&UE<FMI=.0@5F%N:&$O575S:2!T:65T;VIA`%9O:2!M97)K
M:73D('9I97-T96KD("AE<VEM+B!4Y')K9>0O5F%S=&%T='4I`$UA<G-H86QL
M('-A87)E=`!-87)T:6YI<75E`%3D<VWDY';D="!K96YTY'0`36%U<FET86YI
M80!-875R:71I=7,`4W5U<FEN('-A;&QI='1Y(&MR961I:71T:2X`4W5U<FEN
M('-A;&QI='1U('9I97-T:6]S:6]MY.1RY"!Y;&ET971T>2X`161E;&QI<V5N
M(#(T('1U;FYI;B!K;W)K96EN(&SD;7#V=&EL83H@`$5D96QL:7-E;B`V('1U
M;FYI;B!K;W)K96EN(&SD;7#V=&EL83H@`%!O<G1A86QI;W-I;VED96X@96YI
M;6WD:7-MY.1RY`!3=75R:6X@<V%L;&ET='4@<&ET=75S`'1O=6MO:W5U`$UA
M>6]N971T90!,Y.1K971I961E`$KD<V5N970`365N=6X@;75O=&\Z`%EH9&ES
M=.0@<V]L=70`5FEE<W1I`%9I97-T:6X@=&%R:VES='5S(&]N;FES='5I+"!M
M=71T82!A;&QE:VER:F]I='1A:F%N('9A<FUE;FYE='1A(&5I('9O:71U('1A
M<FMI<W1A82X`5FEE<W1I('9A;FAE;FDN`%9I97-T:6X@='EY<'!I`$UE=&%R
M('/DY`!-971A<BUO<VEO(&5I(&]L92!KY'ET971TY'9I<W/D+@!-971A<BUO
M<VEO(&5I(&]L92!KY'ET971TY'9I<W/D+B!487)K96UM870@=&EE9&]T(&]N
M('1A;&QE=&5T='4@>6QLY'!I9&]N(&OD<VET96QTY';D:W-I+@!-971A<D1"
M(&5I(&]L92!Y:&1I<W1E='1Y+@!-971O9&D`365T;V1I82`B)7,B(&5I(&]L
M92!MY.1R:71E;'1Y`$UE=&]D:6$@96D@;VQE(&WDY')I=&5L='DN($MU='-U
M=F$@;65T;V1I.B`E<P!-971R:6YE;@!-96MS:6MO`$UI:W)O;F5S:6$L(%EH
M9&ES='EN965T('9A;'1I;W0`2V5S:V5L;.0`36EM92UT>7EP<&D`161E;&QI
M<V5N(#(T('1U;FYI;B!M871A;&EN(&SD;7#V=&EL83H@`$5D96QL:7-E;B`V
M('1U;FYI;B!M871A;&EN(&SD;7#V=&EL83H@`%-A;&%S86YA(&5I(&]L92!V
M:65LY"!T87)P965K<VD@=F%N:&$`4&5I;&EK=79A`%-E:V%L86ES970`4$5!
M4BUP86ME='1I($A45%!?4F5Q=65S="!P=75T='5U+@!0=75T='5V870@87-E
M='5S=&EE9&]S=&\N(%-I;G5N('!I=.3D('1E:&3D(&%S971U<W1I961O<W1O
M(&IO<R!H86QU870@:^1Y='3DY"!TY'3D(&]H:F5L;6%A+@!0=75T='5V82!M
M97-S86=E($E$+@!6Y&QT=.1MY'3V;B!014%2+7!A:V5T=&D@36%I;"!P=75T
M='5U+@!0=75T='5V82!S97-S:6]N($E$+@!M80!-;V)I:6QI<^1H:_9P;W-T
M:0!+;VAT86QA:6YE;@!-=6]K:V%U:W-E;B!PY&EVY&WDY'+D`$UU;VMK86$@
M55),.FEA`$ME<G)O:6X`36]L9&]V82P@=&%S879A;'1A`$UO;F%C;P!-;VYG
M;VQI80!K=75K875S:2!J82!V=6]S:0!+=75K875S:71T86EN`$UO;G1S97)R
M870`2W5U;B!V86EH965T`%)I=FEL=.0@)60@;/9Y='EI(&5N96UMY&X@:V5N
M='1IY"!K=6EN(&]D;W1E='1U("5D+@!-87)O:VMO`$5N:6UMY&MS:2!S96QK
M9>3D`$5N:6UMY&MS:2!P:6QV:7-TY`!%;FEM;>1K<V5E;B!P:6QV:7-TY"!J
M82!T=75L:7-T80!%;FEM;>1K<V5E;B!A=7)I;FMO:7-T80!3:6ER<N0@86QA
M<W#D:6X`4VEI<G+D('9A<V5M;6%L;&4`4VEI<G+D(&]I:V5A;&QE`%-I:7)R
MY"!Y;/9S<.1I;@!3:6ER<N0@86QA<W#D:6X`4VEI<G+D('EL]G-PY&EN`$UO
M<V%M8FEK`$UO;FET87-O:6YE;B!A;&%S=F5T;W9A;&EK:V\`375L=&EM87`@
M27-O+4)R:71A;FYI86X@:V%R='1A`$UO;FEV86QI;G1A`$OD>71TY&KD='5N
M;G5K<V5N:0!/;6%N(&OD>71TY&KD='5N;G5K<V5N('1I961O=`!/;6$@<&]R
M=&%A;&D`3VUA;B!P;W)T86%L:6X@87-E='1E;'4`37EA;FUA<B`H0G5R;6$I
M`$5)+"!%3B!S=6]S='4`3FEM:0!.86UI8FEA`$YA=7)U`$YE<&%L`$%L86YK
M;VUA870`06QA;FMO;6%I9&5N($%N=&EL;&ET`$YE='-C87!E($)A<V4@55),
M`$YE='-C87!E($-!(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC
M>2!54DP`3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO
M;B!54DP`3F5T<V-A<&4@4U-,+7!A;'9E;&EM96X@;W-O:71E`$YE='-C87!E
M('9A<FUE;G1E96X@:V]M;65N='1I`$YE='-C87!E('9A<FUE;G1E96X@='EY
M<'!I`%9E<FMK;P!%:2!K;W-K86%N`%5U<VDM2V%L961O;FEA`%5U<VD@;'5O
M:VET=7,`575S:6MU=0!5=7-I(&OD>71TY&KD='5N;G5S("AV87!A865H=&]I
M;F5N*0!5=7-I+5-E96QA;G1I`%5U<VD@<V%L87-A;F$`575S:2!S86QA<V%N
M82!V86YH96YE92`E>"X`06YT86UA<VD@=75D970@<V%L87-A;F%T(&5I=N1T
M('3D<VWDY"X`575S:2!I:VMU;F$@*%]B;&%N:RD`575T:7-E=`!+97-K=7-T
M96QU<GEH;>1T`%-E=7)A879A`%-E=7)A879A="`T('9A:6AE='1A`%-E=7)A
M879A="!A<V5T=6MS970`4V5U<F%A=F$^`$YI8V%R86=U80!.:6=E<@!.:6=E
M<FEA`%GV`$YI=64`16D`07-E='5S=&EE=&]J82!E:2!O;&4@<V%A=&%V:6QL
M82P@:F]S=&$@=F]I<VD@;N1Y='3DY"!E<F]A=F%I<W5U:W-I82X`16D@;VQE
M('-A871A=FEL;&$@<W5U;FYI=&5L;6%A($E33R!L979Y:W5V871I961O<W1O
M:F5N('1E:V5M:7-E:W-I+@!%:2!E<N1M86QL:6$N`$]S:6]T82!E:2!O;&4@
M<'EY9&5T>7-SY"!P86EK87-S82X`2V%L96YT97)I;B!N:6UEY"!E:2!O;&4@
M86YN971T=2!-0T%,+6%U=&5N=&EK;VEN;FEL;&4N`$5I(&UU=71O<W1A+@!!
M;&ET87-O:F$@96D@=F]I(&QI<^1TY"!TY&QL92!O:6ME=61E;&QE+@!!<V5T
M=6MS:6$@96D@;/9Y='EN>70@)7,Z;&QE+@!!<V5T=6MS:6$@96D@;/9Y='EN
M>70@1E10(%9&4SIL;&4N`$%S971U:W-I82!E:2!L]GET>6YY="!344P@5D93
M.FQL92X`07-E='5K<VEA(&5I(&SV>71Y;GET(%-13"U&:6QE(%9&4SIL;&4N
M`$MR961I:71I="!L;W!P=2X`2V]H9&5T=&$@96D@86YN971T=2X`16D@='5O
M='4@86EN=71T86MA86X@=&EE9&]S=&]A`$EK;VYE:71A(&5I(&SV>71Y;GET
M+@!086EK:V%A(&5I(&]L92!A<V5T971T=2X`4&%I:VMA82!E:2!O;&4@86YN
M971T=2X`16D@86YN971T=2!V:65S=&GD+@!.:6UEY"!E:2!O;&QU="!A;FYE
M='1U+@!,=6MU;>3D<N3D(&5I(&]L;'5T(&%N;F5T='4N`$5I(&QO=6MK86%V
M870@;6EE=&5L875S965T`%-A;&%S86YA82!E:2!O;&4@86YN971T=2!(5%10
M+6%U=&5N=&EK;VEN;FES<V$N`%-A;&%S86YA82!E:2!O;&4@86YN971T=2!)
M34%0+6%U=&5N=&EK;VEN;FES<V$N`%-A;&%S86YA82!E:2!O;&4@86YN971T
M=2!+97)B97)O<RUA=71E;G1I:V]I;FYI<W-A+@!386QA<V%N86$@96D@;VQE
M(&%N;F5T='4@3&]G:6X@875T96YT:6MO:6YN:7-S82X`4V%L87-A;F%A(&5I
M(&]L92!A;FYE='1U(%!!4U-71"UA=71E;G1I:V]I;FYI<W-A+@!386QA<V%N
M86$@96D@;VQE(&%N;F5T='4@4TU"+6%U=&5N=&EK;VEN;FES<V$N`%!O;&MU
M82!/<&5N4U-,(&MO;65N=&]O;B!E:2!O;&4@;>3D<FET96QT>2X@3W!E;E-3
M3"!P:73DY"!O;&QA(&OD>71E='3D=FES<^0@:F]S(&OD<VET96QLY.1N(%!+
M0U,@,3(@9&%T86$N`$5I('-I<^3D;FMI<FIA=71U;6ES<'EY;G3V:N0@:F]N
M;W-S82X`2VEI;G1I]G3D(&5I(&]L92!A<V5T971T=0!%:2!SY.1N=/9JY`!%
M<F]T:6YT82!E:2!O;&4@;>3D<FET96QT>2X`16D@<F5U;F]J80!%:2!L]GET
M>6YY="!T:65D;W-T;V$`5N1L:6UU:7-T:6QL92!E:2!O;&4@=N1L:6%I:V%I
M<VAA:V5M:7-T;V$N`$OD>71TY&KD='5N;G5S=&$@=&%I('-A;&%S86YA82!E
M:2!LY&AE=&5T='DN`$MA:6MK:2!P86QA=71U;G5T(%A-3"UD871A(&]L:2!E
M<.1K96QP;V$`16D@87)V;VIA`%9E<G-I;W1I971O:F$@96D@;/9Y='EN>70@
M86QK=7!E<N1I<VETY"!A<V5T=6MS:7-T82X@4VEN=6X@<&ETY.0@=&5H9.0@
M87-E='5K<V5T('5U9&5S=&%A;BX`5F5R<VEO=&EE=&]J82!E:2!L]GET>6YY
M="!A<V5T=6MS:7-T82X@4VEN=6X@<&ETY.0@=&5H9.0@87-E='5K<V5T('5U
M9&5S=&%A;BX`16D@;6ETY.1N`$5I(&UI=.3D;B`H2^1Y=.0@:6UP;&ES:6ET
M=&ES=.0I`$QA<'!I+U!O:&IO:7-M86%T+T5S:VEM;R`H25-/+3@X-3DM,3`I
M`$YO<F9O;&L@<V%A<F5T`%!O:&IO:6YE;B!P86QL;VYP=6]L:7-K;P!0;VAJ
M;VES970@36%R:6%A;FEE;B!S86%R970`3F]R:F$`16D@:N1L:V5E;@!%:2!E
M;FYE;@!%:2!O;&4@:&%K96UI<W1O`$5I(&]L92!T;W1E=71E='1U+@!%:2!A
M<V5T971T=0!%:2!T=65T='4N`$UU:7-T:6EN<&%N;W0`16D@;6ETY.1N('-E
M;&%T=&%V86$L('!A;&%A('1A:V%I<VEN+@!M87)R87-K=74`3'5K=6WDY'+D
M`$UE<FMK:65N(&QU:W5MY.1RY`!387)A:VME:61E;B!L=6MU;>3D<N0`4FEV
M:65N(&QU:W5MY.1RY`!*86ME;'5L:7-T86X@;G5M97)O:71A(&5I(&]L92!M
MY.1R:71E;'1Y('#D:79I=&5T=.1VY&MS:2X`3TL`3V)J96MT:0!/8FIE:W1I
M;B!L=6]J80!/:W1A86QI`&QO:V%K=74`3&]U:VMA879U=7-S=6]D871I;@!4
M;VEM:7-T;P!5=7-I('-A;&%S86YA(&5I('-A82!O;&QA('-A;6$@:W5I;B!N
M>6MY:6YE;B!S86QA<V%N87-I+@!686YH82!S86QA<V%N80!686YH82!S86QA
M<V%N82!O;B!VY.1R:6XN`$]M86X`5F%I;B!)34%0+7!A;'9E;&EM970@='5K
M979A="!J865T='5J82!K86YS:6]I=&$N`%9A:6X@;&]U:VMA879A="!M:65T
M96QA=7-E970`5F]I="!L86ET=&%A('9A:6X@>6AD96X@<^1H:_9P;W-T:6]S
M;VET=&5E;BX`5F%I;B!O;6ES=&%J82!T86D@:N1R:F5S=&5L;>1N('EL;.1P
M:73D:N0@=F]I(&UU=71T86$@:F%K;VIE;B!O;6ES=&%J:6$@=&%I(&]I:V5U
M:W-I80!!=F%A('5U9&5S<V$@:6MK=6YA<W-A`$]P96Y34TP@=FER:&4Z(%1I
M971O:F$@96D@<V%A='4@97-I;&QE(&%L;&5K:7)J;VET971U<W1A(%,O34E-
M12UO<V%S=&$N`$%V86$@=.1MY&X@;&EN:VEN('5U9&5S<V$@:6MK=6YA<W-A
M`$OD>71T]FKD<FIE<W1E;&WD`$%S971U:W-E=`!!<V5T=6MS970@)7,Z;&QE
M`$KD<FIE<W1E='1Y(&QI<W1A`$]R9V%N:7-A871I;P!/<F=A;FES86%T:6]Y
M:W-I:VOV`$]R9V%N:7-O:6YT:0!!;&MU<&5RY&EN96X@;VAJ96QM86X@;6%L
M;&D`06QK=7!E<N1I<V5T(&UA;&QI="`E<SIS<^0Z`$UU=0!-=75T('1I961O
M=`!/;6ES=&%J86X@;VEK975D970`4$%-+6%U=&5N=&EK;VEN=&EA(&5I(&]L
M92!KY'ET971TY'9I<W/D+@!014%2.CI-86EL('1A=7-T86KD<FIE<W1E;&WD
M`$1I9VET86%L:6YE;B!01U`M86QL96MI<FIO:71U<P!01U`M<V%L871T=6$@
M=&EE=&]A`$IU;&MI;F5N(%!'4"UA=F%I;@!01U`M86QL96MI<FIO:71E='1U
M82!J82!S86QA='1U82!T:65T;V$`4$A0+6MO;V1I`%!(4"UK;VUE;G1O='5L
M:VMI`%!-(&ME=GET=.0@<V%D971T80!032!S861E`%!-(&MU=7)O:F$`4$T@
M;'5M:0!032!L=6UI<V%T96ET80!032!L=6UI`%!-('5K:V]S;7ER<VMY:N0`
M4$]325@M;&%A:F5N;G5K<V5T('!U=71T=79A=`!07TA0+6MO;65N=&]T=6QK
M:VD`5.1Y=&4`4&%K:7-T86X`4&%L874`4&%L97-T:6EN82`H;6EE:&ET971T
M>2!A;'5E*0!086YA;6$`4&%P=6$@575S:2U'=6EN96$`4&%R86=U87D`3W-I
M='1A:6X@<&EL=FES=.0`4V%L87-A;F$`4V%L87-A;F%N('9A:6AT;R!O;FYI
M<W1U:2X`5N3D<N0@<V%L87-A;F$`4V%L87-A;F%A('1A<G9I=&%A;B!2041)
M55,M875T96YT:6MO:6YT:6EN+@!386QA<V%N82!V87)M:7-T=6MS96QL80!3
M86QA<V%N83H`4V%L87-A;F$Z(`!386QA<V%N;VIE;B!P:73DY"!O;&QA('-A
M;6%T+@!,:6ETY`!,:6ETY"!L96EK97#V>63D;'3D`%!O;&MU`$IO;F]S<V$@
M;VQE=F%T('-I<^3D;FMI<FIA=71U;6ES<'EY;F[V=#H`26AM:7-E=`!0<F]S
M96YT=&D`4W5O<FET82!Y;&SD<&ET;W1O:6UE;G!I=&5E=`!3=6]R:71A('EL
M;.1P:71O=&]I;65N<&ET965T('-I<^3D;FMI<FIA=71U;6ES96X@>6AT97ED
M97-SY"X`3VEK975S`$]I:V5U='1A("(E<R(@96D@<&]I<W1E='1U+@!+Y'ET
M=/8@:VEE;&QE='1Y`$]I:V5U9&5T`$]I:V5U:W-I96X@>6QLY'!I=&\`3VUA
M="!T:65D;W0`4&5R=0!,96UM:6MI=`!&:6QI<'!I:6YI=`!0=6AE;&EN`%9A
M;&]K=79A=`!0:71C86ER;@!0:6MS96QI`$ML:7-E970`3F%P<V%U=&$@:F]T
M86EN('-O;'5A`%9A<FUI<W1A(&5T=.0@:&%L=6%T('!O:7-T86$@=.1MY&X@
M96QE;65N=&EN.@!687)M:7-T82!E='3D(&AA;'5A="!P;VES=&%A(&QI;FMI
M='EK<V5N('3D:.1N(&5L96UE;G1T:6EN+@!!;FYA(&MU=6MA=7-I(&IA('9U
M;W-I+@!!;FYA(&YI;6D@=75D96QL92!L=6]K:71U:W-E;&QE.@!!;FYA(&]I
M:V5A($E0+6]S;VET92X`06YN82!O:6ME82!PY&EVY&WDY'+D.R!487)K:7-T
M82!PY&EV:65N(&QU:W5MY.1RY"!K=75K875D97-S82X`06YN82!A:6MA(&]I
M:V5A<W-A(&UU;V1O<W-A+@!!;FYA(&QY:'ET(&MU=F%U<R!O;F=E;&UA<W1A
M+@!!;FYA(&OD>71TY&KD='5N;G5K<V5S:2!J82!S86QA<V%N87-I`$QU92!S
M975R86%V82!T96MS=&DN(%-I;G5N(%!)5,3$('-U;W-T=6$@:^1Y='3V96AT
M;VEH:6X@=F]I9&%K<V5S:2!KY'ET=.3D(&KD<FIE<W1E;&WDY"X`06YN82!N
M:6UI('5U9&5L;&4@;'5O:VET=6MS96QL93H`4'5O;&$`4&]L:71I:6MK80!+
M>7-E;'ET`%!O<G1U9V%L:0!4Y&WD;B!K=79A;B!P86EK:V$`5.1MY&X@=&%U
M;'5K;VX@<&%I:VMA`%9O:2!LY&AE='3DY"!V:65S=&5JY"!K86YS:6]O;B`H
M96D@:V]S:V4@24U!4"!Y:'1E>6MS:>0I`%-A9&5MY.1RY"!E9&5L;&ES:6QL
M92`E<R!T=6YN:6QL93H@`$AA:6AT=79U=7,@/&)R("\^=&]D96YNY&OV:7-Y
M>7,`4')E9G-?;&1A<#H@5&%R=FET=&%V86$@3$1!4"UL86%J96YN=7-T82!E
M:2!L]GET>6YY="X`4')E9G-?<V5S<VEO;CH@5&%R=FET=&%V86$@<V5S<VEO
M;BUL86%J96YN=7-T82!E:2!L]GET>6YY=`!);&UA;G!A:6YE`$EL;6%N<&%I
M;F4@;65R96YP:6YN87-S83H@`$EL;6%N<&%I;F4Z(`!%<VEK871S96QU`$5S
M:6MA='-E;&4@:W5V82!U=61E<W-A(&EK:W5N87-S80!%9&5L;&ES970@87-E
M='5K<V5T`%1U;&]S=&$@9&]K=6UE;G1T:0!386QA:6YE;B!A=F%I;@!/;F=E
M;&UA`$]N9V5L;6%N(&MU=F%U<P!0<F]J96MT:70`2V5H;W1T965N('1E:W-T
M:0!*=6QK:6YE;B!A=F%I;@!*=6QK:7-E;B!A=F%I;65N(&%L9V]R:71M:0!*
M=6QK:7-E;B!A=F%I;65N('1I961O=`!*=6QK:7-E;B]S86QA:7-E;B!A=F%I
M;G!A<FEN(&QU;VYT:2!E<.1O;FYI<W1U:2X`4'5E<G1O(%)I8V\`5F]I('1U
M:&]T82!P;VES=&5T='5J82!V:65S=&5JY`!1871A<@!+>7-E;&4`2VEI;G1I
M]@!24T$@2G5L:VEN96X@879A:6X@*"5D(&)I='1IY"D`4F%D:6]P86EN:6ME
M`%-A9&4`4V%D971T82!A:6MA:7-I;@!3861E='1A(&UY]FCDY&X`4V%D96MU
M=7)O`%9E<VD@:F$@;'5M:0!6961E<W3D(&QU;65E;@!3871U;FYA:6YE;B!M
M:65T96QA=7-E`%-U:&1E`$QU:W4`5F]I(&QU:V5A('9I97-T96KD`%!O:7-T
M971A86YK;R`E<S\@5.1TY"!T;VEM:6YT;V$@96D@=F]I('!E<G5U='1A82X`
M4&]I<W1E=&%A;FMO('1I961O="!KY'ET=.1JY'-TY"`E<S\@5.1TY"!T;VEM
M:6YT;V$@96D@=F]I('!E<G5U='1A82X`5&5E(&UU=71O:W-E="!U=61E<W1A
M86X`4.1I=FETY`!0Y&EVY'0@9'EN86%M:7-E="!V86QI:VMO96QE;65N=&ET
M.@!0Y&EV:73D('!O<G1A86QI;N1K>6WDY#H`4^3D;F[V;&QI;F5N(&QA=7-E
M:V4`4F5L86%T:6]S96QA:6X`3&%T86$@=75D96QL965N`$UU:7-T:6EN<&%N
M;W0`173D<&%L=F5L:6UE=`!%=.1P86QV96QU;B!54DP@*&AT='`Z+R]W=W<N
M97AA;7!L92YC;VTO:&]R9&4I.@!0;VES=&$`4&]I<W1A(&]S:6\`4&]I<W1A
M('-A<F%K90!0;VES=&$@;75O=&]I;'4`4&]I<W1A('!A<FD`4&]I<W1A('1A
M;&QE=&5T='4@<VMR:7!T:2!P86QV96QI;65N(';D;&EA:6MA:7-H86ME;6ES
M=&]S=&$N`%!O:7-T80!0;VES=&$@=.1MY"!N;V]D:2!D;VMU;65N=&ES=&$`
M4&]I<W1A(&OD>71TY&KD`%!O:7-T82!KY'ET=.1JY#H@)7,`4'EY;G3V]FX@
M96D@=F]I='4@=F%S=&%T82X@5FER:&5K;V]D:3H@`%!Y>61E='1YY"!P86QV
M96QU82!E:2!L]GET>6YY="X`5&%R=FET=&%V86$@(B5S(BUT:65T;V$@96D@
M;VQL=70@;>3D<FET96QT>2`E<R!A<V5T=6MS:7-S82X`5&%R=FET=&%V86$@
M(B5S(BUT:65T;V$@96D@;VQL=70@;>3D<FET96QT>2!61E,@87-E='5K<VES
M<V$N`%1A<G9I='1A=F%A("(E<R(M=&EE=&]A(&5I(&]L;'5T(&WDY')I=&5L
M='D@87-E='5K<VES<V$N`%!A:V]L;&EN96X@:V5N='3D`%1Y:&IE;F[D`%1Y
M:&IE;F[D('-A;&%S86YA`%1Y:&IE;F[D('-A;&%S86YA<VD`4&%L875T82!E
M9&5L;&EN96X@:WES96QY`%1U;&]K<V5T`%!A;&%A(&%S971U:W-I:6X`5F%H
M=FES=&$@=75S:2!S86QA<V%N80!2975N:6]N`%!A;&%U=&$@87-E='5K<V5T
M`%)I8V@@5&5X="!%9&ET;W)I;B!A<V5T=6MS970`07)V;VET=6MS970`3VEK
M96$`3VEK96$@;W1S86ME`$]I:V5A(&%R=F]T`%)I=FE?;B!T:65D;W0N+BX`
M4F]O;&D`4F]M86YI80!+Y.1N;N0@,3@P`$ODY&YNY"!V87-T87#D:7;DY&X`
M2^3D;F[D(&UY]G3D<.1I=N3D;@!2:79I;B!T:65D;W0`4FEV:6X@=&EE9&]T
M`%)I=FET.@!6:6EV;VET:6X`5FEI=F]I=&EN(&[D:WEY(&MA:6MK:65N(')I
M=FEE;B!J82!S87)A:VME:61E;B!VY&QI;&SD`%9I:79O:71I;B!NY&MY>2!V
M86EN('-A<F%K:V5I9&5N(';D;&EL;.0`5FEI=F]I=&EN(&[D:WEY('9A:6X@
M<FEV:65N(';D;&EL;.0`4W5O<FET80!696[D:N1N($9E9&5R871I:79I;F5N
M('1A<V%V86QT80!2=6%N9&$`4R]-24U%(&MR>7!T;V=R86%F:6YE;B!A;&QE
M:VER:F]I='5S`%,O34E-12!S86QA='1U('9I97-T:0!305-,+6%U=&5N=&EK
M;VEN=&D@96D@;VQE(&OD>71E='3D=FES<^0N`%--4R!496MS=&EV:65S=&ET
M`%-13"UK;VUE;G1O='5L:VMI`%-13"UL875S92!A<G9O:F5N(&AA:V5M:7-E
M96X`4U-(`$].3DE35%5)`%-?44PM:V]M96YT;W1U;&MK:0!L80!386EN="!(
M96QE;F$`4V%I;G0@2VET=',@:F$@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@
M4&EE<G)E(&IA($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@:F$@1W)E;F%D:6EN
M:70`4V%M86%N(&ME:'EK<V5E;B`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`
M4V%O(%1O;64@:F$@4')I;F-I<&4`4V%T96QL:6ET=&D@<&%L=F5L=6YT87)J
M;V%J80!3875D:6$@07)A8FEA`%1A;&QE=&$`5&%L;&5T82`B)7,B`%1A;&QE
M=&$@)7,`5&%L;&5T82!A<V5T=6MS970`5&%L;&5T82!L=6]D=70@87-E='5K
M<V5T(%!(4"US:W)I<'1I;N0@<&%L=F5L:6UE<VD@=N1L:6%I:V%I<VAA:V5M
M:7-T;V]N+B``5&%L;&5T971T:6EN("5S.FX@87-E='5K<V5T+@!!<V5T=7-T
M96X@<.1I=FET>7-S:W)I<'1I(&]N('1A;&QE=&5T='4@<&%I:VMA86XZ("(E
M<R(N`$AA:F%N86ES:6$@=6MK;W-M>7)S:WEJY`!4:65D90!(86MU`$AA:W5K
M;VYE970`5F%L:71S92!T:65D;W-T;W0`5F%L:71S92!PY&EVY&WDY'+D`%9A
M;&ET<V4@;&ESY'1TY';D(')Y:&WD`%9A;&ET<V4@=75S:2!O;6ES=&%J80!6
M86QI='-E('!A;'9E;&EN`%9A;&ET<V4@;&ESY'1TY';D(&OD>71TY&KD`%9A
M;&ET<V4@:V%I:VMI`%9A;&ET<V4@:V%I:VMI('#D:7;D;>3D<N1K;VUP;VYE
M;G1I=`!686QI='-E(&]B:F5K=&D`5'EH:F5N;N0@=F%L:6YT80!686QI='-E
M('1A<G9I='1A=F%T(&UE<FMI="!A;&QA(&]L979I<W1A('9A;&EK;VES=&$N
M(%9O:70@<V5N(&KD;&ME96X@:V]P:6]I9&$@:F$@;&EI='3DY"!M97)K:70@
M=&5K<W1I:7-I+@!686QI='-E('#D:7;D>6MS96X@97)O=&EN;65R:VMI.@!6
M86QI='-E('#D:7;D>6MS96X@97-I='ES=&%P83H`5F%L:71S92!M=75T971T
M879A('!R;V9I:6QI.@!686QI='-E(&ME;&QO;F%J86X@97)O=&EN;65R:VMI
M.@!686QI='-E(&%J86X@97-I='ES=&%P83H`5F%L:71S92!K86MS:2!Y:'1E
M96YS;W!I=F%A(&ME;G1TY.0N`%9A;&ET<V4@=N1R:71E96UA+@!686QI='-E
M(&OD>71E='3D=N0@:VEE;&DZ`$SD:&5TY"!O;F=E;&UA=FEE<W1I`$SD:&5T
MY"!335,`4V5N96=A;`!4=6YN:7-T:6XZ(`!S>7ES:W5U`%-E<F)I82!J82!-
M;VYT96YE9W)O`%-A<FIA;G5M97)O`%!A;'9E;&EM96X@=&EE9&]T(&]V870@
M=N3D<FGD('1A:2!E:7;D="!O;&4@:^1Y=&5T=.1V:7-SY"X`27-T=6YT;VIE
M;B!H86QL:6YT80!397-S:6]N($E$(&]N('9A;FAE;G1U;G5T+@!)<W1U;FYO
M=`!!<V5T80!386QA<V%N86X@<F5S971O:6YT:6EN(&QI:71T>79IY"!A<V5T
M=6MS:6$L(&IO<R!J;W-K=7,@=6YO:&1A="!S86QA<V%N87-I+@!6;VET(&%S
M971T86$@=6QK;VES=&5N('!A;'9E;&EM:65N(&%S971U:W-E="P@:F]I=&$@
M:&%L=6%T(&OD>71TY.0@<&]R=&%A;&ES<V$N`%9O:70@87-E='1A82!KY'ET
M971TY';D;B!K:65L96XL(&%I:V%V>?9H>6MK965N(&IA(&UU:71A('#D:7;D
M;>3D<N1A<V5T=6MS:6$N`%9O:70@87-E='1A82!A;&]I='5S;VAJ96QM86XL
M(';D<FET965M86XL(&[D:WEMY&X@<.1I=FET>6MS96X@:F$@;75I=&$@;N1K
M>6WDY&X@;&EI='1Y=FGD(&%S971U:W-I82X`07-E;FYU<P!!<V5N;G5K<V5N
M('#D:79I='ES<VMR:7!T:2!O;B!S86%T879I;&QA`%5S96%T('!A:6MA="!S
M;W!I=F%T(&%N;F5T='5U;B!P87)A;65T<FEI;CH@`%-E>6-H96QL:70`3W-T
M;VMS970`3'EH>70@:W5V875S.@!!<V5T971A('!I:V%V86QI;G1A;N1P<.1I
M;65T('5S96EM;6EL;&4@;&EN:V5I;&QE+@!.Y'ETY`!.Y'ETY"!E<F]A=F%I
M<W5U9&5T(&%S971U:W-I96X@=&%L;&5T971U<W-A(&IA('5U9&5S<V$@:G5U
M<FD@;75O:V%T=7-S82!V97)S:6]S<V$N`$[D>73D(&5D96QL:7-E;B!S:7/D
MY&YK:7)J875T=6UI<V5N('#D:7;D>7,N`$[D>73D(&%S971U<R!P:73DY&MS
M97-I(&%L:W5P97+D:7-E;@!.Y'ETY"!V86QI='-I;@!.Y'ETY"!T875L=6MK
M;W1O:6UI;FYO="!V86QI:VMO+@!.Y'ETY"!V87-E;6UA;&QA("5S('9A;&EK
M:V\N`$[D>73D('1A=6QU:V]N('-O;'5N('1I961O="!D:6%L;V=I`$[D>73D
M('1A=6QU:V]N('1I961O="!D:6%L;V=I`$[D>73D('1A=6QU:V]N(')I=FEN
M('1I961O="!D:6%L;V=I`$[D>73D(&MU=F%N('1I961O="!D:6%L;V=I`$[D
M>73D('1U;VYT:0!3871E:71A`%-A=&5I=&$@86EK86ES:6X`4V%T96ET82!M
M>?9H96UM:6X`4V%T96ET82!LY&AE='1Y=FEL;&$`4&EE;F5N;N0`4&EE;F5N
M;N0@=&%I('-I:7)RY"!V:65R96ES:>0@;W-I;VET82P@:F]T=&$@;F4@96EV
MY'0@;VQE('1I96QLY`!3:65R<F$@3&5O;F4`2VER:F%U9'4`06QL96MI<FIO
M:71U<P!!;&QE:VER:F]I='5K<V5N(&%L9V]R:71M:0!3:6YG87!O<F4`2V]K
M;P!/:&ET82!Y;&SD<&ET;W1E:'3D=N1T`%-L;W9A:VEA`%-L;W9E;FEA`$QU
M;6D`3'5M:7-A9&5T=&$`3'5M:7-A=&5I=&$`3'5M:7-A=&5I=&$@86EK86ES
M:6X`3'5M:7-A=&5I=&$@;7GV:.3D;@!,=6UE;B!S>79Y>7,Z(`!,=6UE;B!M
MY.1RY"!V971E;N0Z(`!386QO;6]N('-A87)E=`!3;VUA;&EA`$QA=6QU="!J
M82!2=6YO=7,`2N1R:F5S='EK<V5N('-U=6YN86X@=F%L:6YT80!,Y&AD96]S
M;VET90!%=&5LY"U!9G)I:VMA`$5T96SD+45U<F]O<'!A("A)4T\M.#@U.2TS
M*0!%=&5LY"U'96]R9VEA(&IA(&5T96SD:7-E="!386YD=VEC:"!S86%R970`
M171E;.1I;F5N('!A;&QO;G!U;VQI<VMO`%;D;&D@=FEE<F5I<V5T('-O;'5J
M96X@=N1L:7-SY`!6Y&QI('-O;'5N(&QE:7#D=&5K<W1I;B!J82!R975N86X@
M=N1L:7-SY"``5N1L:0!6Y&QI`%;D;&D@:F$@=.1Y=&4`17-P86YJ80!2;W-K
M87!O<W1I`$5R:6MO:7-M97)K:VEE;B!S>?9T=/8`2F%A('-O;'4`2F%A('-A
M<F%K90!*86$@<FEV:0!5<FAE:6QU`%-R:2!,86YK80!3=&%N9&%R9&D`4W1A
M<B!4<F5K`$%L:V%M:7-V=6]S:0!,Y.1N:2!T86D@86QU90!4:6QA`%1A;&QE
M;FYU<VUU;W1O`$MA='5O<V]I=&4`3.1P:6QY]FYT:0!-97)K:VEJ;VYO;&ES
M=&$`4&]I<W1A('1O:6UI86QU92!O<V]I='1E97-T80!4>7EL:2!;0U-370!S
M=0!!;&EH86ME;6ES=&]A("(E<R(@96D@;/9Y='EN>70N`$]T<VEK:V\`3.1H
M973D`$SD:&5T971T:6EN("(E<R(Z;B!L:7/D>7-P>7EN=/8N($5T('9O:2!K
M:7)J875T=6$@<VESY.1N(&5N;F5N(&MU:6X@<'EY;G3V<VD@;VX@:^1S:71E
M;'1Y(&IA(&AY=N1K<WET='DN`$%L:6MI<FIO:71U<P!/;FYI<W1U:0`B)7,B
M.B!L:7/DY&UI;F5N(&KD<FIE<W1E;&WDY&X@;VYN:7-T=6DN`$OD>71TY&KD
M;B`B)7,B(&OD>71TY&KD=&EE=&]J96X@<&]I<W1A;6EN96X@:N1R:F5S=&5L
M;>1S=.0@;VYN:7-T=6DN`"(E<R(@<&]I<W1E='1I:6X@;VYN:7-T=6YE97-T
M:2X`(B5S(CH@;VYN:7-T=71T:6EN('!O:7-T86UA86X@:N1R:F5S=&5L;>1S
M=.0N`%!A;&%T=&EI;B!O;FYI<W1U;F5E<W1I('9A;FAO:6AI;B!A<V5T=6MS
M:6EN+B!,871A82!S:79U('5U9&5S=&%A;B!NY&ADY&MS97-I(&UU=71O:W-E
M="X`5&%L;&5N;F5T=&EI;B!A<V5T=6MS:65N('9A<FUU=7-K;W!I;RX`5&%L
M;&5N;F5T=&EI;B!A<V5T=6MS:65N('9A<FUU=7-K;W!I;R`E<RX`)R5S)SH@
M<.1I=FET>7,@;VYN:7-T=6DN`"5S.FX@:VER:F]I='1A;6EN96X@;VYN:7-T
M=6DN`%-U9&%N`%EH=&5E;G9E=&\`075R:6YG;VYN;W5S=0!!=7)I;F=O;FQA
M<VMU`$%U<FEN:V]I;F5N`$%U<FEN9V]N;F]U<W4`075R:6YK;R!N;W5S964O
M;&%S:V5E`$%U<FEN9V]N;F]U<W4Z(`!!=7)I;F=O;FQA<VMU`$%U<FEN9V]N
M;&%S:W4Z(`!0Y.1L;&5K:7)J;VET=7,`5'5K:0!3=7)I;F%M`%-U:W5N:6UI
M`$AU:7!P=79U;W)E="!J82!*86X@36%Y96X`4W=A>FEM86$`4G5O='-I`%-V
M96ET<VD`4WEN8R!L;VMI('!O:7-T971T=0!3>6YC34P`4WEN=&%K<VEV:7)H
M92!H86MU=&5R;65I<W/D`%-Y>7)I82P@87)A8FET87-A=F%L=&$`56MK;W-M
M>7)S:WD`56MK;W-M>7)S:WEJY"!J82!T=75L:7-T80!5:VMO<VUY<G-K>70`
M56MK;W-M>7)S:WEJY"!A:6MA:7-I;@!44U8M=&EE9&]S=&\`5&%U;'5K:V\`
M5&%U;'5K;VX@=&EE9&]T`%1A=6QU:V]N(&%S971U:W-E=`!4875L=6MO;B!T
M:65D;W0`5&%I=V%N`%1A:7=A;BP@2VEI;F%N(&UA86MU;G1A`%1A9'II:VES
M=&%N`%1A;GIA;FEA+"!9:&1I<W1Y;GET('1A<V%V86QT80!+;VAD93H`5&5H
M=.1VY'0`4'5H96QI;FYU;65R;P!,Y&UP]G1I;&$@961E;&QI<V5L;&4@='5N
M;FEL;&4Z(`!,Y&UP]G1I;&$`3.1M</9T:6QA.B``3.1M</9T:6QA/&)R("\^
M*"5S2&DE<R\E<TQO)7,I("9D96<[)7,`36%L;&EA("(E<R(@96D@;/9Y='EN
M>70N`$UA;&QI96X@:&%L;&EN=&$`5&5K<W1I`%9A:6X@=&5K<W1I`%1E:W-T
M:6X@=&%S875S`%1E:W-T:71O<`!T;P!4:&%I("A425,M-C(P*0!4:&%I;6%A
M`$944"UL:7/D=&]I;6EN=&\@96D@;VQE(&OD>71E='3D=FES<^0N`$AI<W1O
M<GD@:N1R:F5S=&5L;>0@96D@;VQE(&OD>71E='3D=FES<^0N`$AO<F1E+TMO
M;&%B(&EN=&5G<F]I;G1I;6]O='1O<FD@96D@='5E("(E<R(`24U34"!L;VMI
M82!E:2!V;VET=2!A;'5S=&%A+@!-86EN=&5N86YC93HZ("UL=6]K86X@;&%T
M86%M:6YE;B!E<.1O;FYI<W1U:0!!<V5T=6MS970@:6MK=6YA(&]N('-U;&IE
M='1U+B!0;VES='5T86%N+@!9;&SD<&ED;VX@<&ETY.0@;W1T86$@:^1Y='3V
M]FX@<'ES>7;D('1A;&QE='5S='EY<'!I(%!E<FUI<W-I;VXL(&IO<R!H86QU
M870@:^1Y='3DY"!N:6ETY"X`5F%I;B!A;&%P=6]L:0!#;VYT86-T(&ED(&YU
M;65R;V$@96D@;VQE(&WDY')I=&5L='DL(&]N('1Y:&KD('1A:2!E:2!L]GET
M>6YY="!T:65T;VMA;FYA<W1A+@!9:'1E>7-T:65D;W0@;&ESY'1T:6EN(&]N
M;FES='5N965S=&D@;W-O:71E:VER:F%A<VDN`%9I97-T:6X@86QL96MI<FIO
M:71U:W-E;B!T87)K:7-T86UI<V5E;B!T87)V:71A86X@97)I;&QI;F5N(%!'
M4"UA;&QE:VER:F]I='5S;&]H:V\N`$IA:V5L=6QI<W1A;B!)1"!E:2!O;&QU
M="!MY.1R:71E;'1Y+"!O;B!T>6AJY"!T86D@96D@;/9Y='EN>70@=&EE=&]K
M86YN87-T82X`2F%K96QU;&ES=&%A(&5I(&]L;'5T(&WDY')I=&5L='DN`%-A
M;&%U<W1O:6UI;FYO;B!KY'ET=/8@=F%A=&D@<V%L871T=6$@5U=7+7EH=&5Y
M='3D+@!4:65D;W-T;W-S82`E<R!P:73D:7-I(&]L;&$@)7,@87-E='5S+@!4
M:65D;W-T;W-S82`E<R!P:73D:7-I(&]L;&$@:F]I=&%K:6X@)7,@87-E='5K
M<VEA+@!4:65D;W-T;V$@96D@=F]I9&$@:V]P:6]I9&$@:71S96YSY"!PY.1L
M;&4N`%1I961O<W1O(&]L:2!T>6AJY"X`4V5U<F%A=F%S<V$@;VX@;W1S:6MK
M;W1I961O="!TY'-TY"!M97-S86=E+W)F8S@R,B`M=FEE<W1I<W3D+@!+;VMO
M<G5U9'5N(&[D>71T]G1I;&$@86EH975T=&%A(&]N9V5L;6EA(&IO:6QL86MI
M;B!);G1E<FYE="!%>'!L;W)E<B!S96QA:6UE;B!KY'ET=.1J:6QLY"X@5F%L
M:71E='1A=F%S=&D@:WES96EN96X@<V5L86EN('-I<^1L=.3D('!I:7)T96ET
MY"!J82!V:7)H96ETY"!J;VEH:6X@96D@;VQE(&SV>71Y;GET(&MO<FIA=7-T
M82!T86D@:V5I;F]A(&MI97)TY.0@;VYG96QM82X@2'5O;6%A=&AA;B!E='3D
M(&IO<R!KY'ETY'0@=.1TY"!NY'ET=/9T:6QA82!J82!);G1E<FYE="!%>'!L
M;W)E<B!S96QA:6YT82P@;FEI;B!NY'ET=/8@<V%A='1A82!M96YNY"!S96MA
M:7-I;BP@:F]T:W5T('1O:6UI;FYO="!E:7;D="!T;VEM:2!T86D@<V5L86EN
M('-A871T86$@:V%A='5A+B!*;W,@:^1Y=.1T(%=I;F1O=W,@.7@@=&%I($U%
M('9E<G-I;W1A+"!N:6EN(&]N(&UA:&1O;&QI<W1A(&5T=.0@:^1Y='3V:N1R
M:F5S=&5L;>0@:V%A='5U(&YS+B`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT
M)R`M=FER:&5E<V5E;B!J82!S:6YU;B!P:73DY"!KY'EN;FES=.3D(&MO;F4@
M=75D97-T86%N+EQN7&X@375I<W1A(&5T=.0@<VEN=6$@;VX@=F%R;VET971T
M=2X@3F%P<V%U=&$@3TLM;F%P<'5L86$@:F]S(&AA;'5A="!K;VME:6QL92!E
M9&ET;W)I;B!K;VMO<G5U='4@;N1Y='3V=&EL86$N`%!O:7-T971T:6EN('!R
M;V9I:6QI("(E<R(N`%9A:6X@=F%S96X@<'5O;&D`1VYU4$<@;VAJ96QM86X@
M<VEJ86EN=&D@<&ETY.0@;>3D<FET96QLY"!#<GEP=%]P9W`Z.B`M;'5O:V%S
M<V$N`%9I97-T:2!LY&AE=&5T='D@)7,@=F%S=&%A;F]T=&%J86QL92`E<R!O
M='-I:VMO;F$@(B5S(B!O;B!NY'ET971T>2X*16D@;VQE(&UI=.3D;B!T86ME
M:71A('-I:73D(&5T=.0@=FEE<W1I(&]N(&QU971T=2!T86D@>6UMY')R971T
M>2X`3FEM:2!J;W1A(&OD>71E=.3D;B!L:6YK:71E='3D97-S82!L=6\@<VEV
M=6QL90!+96YT=&EE;B!MY.1RY"!P:73DY"!A;G1A82!N=6UE<F]I;F$N`$UO
M9'5U;&D@;W!E;G-S;"!T87)V:71A86X@2&]R9&5?0W)Y<'1?<VUI;64Z.B`M
M;'5O:V%N(&OD>71TY&UI<V5K<VDN`$%S971U<W1A("(E<R(@:V]S:V$@<V5N
M('1I961O="!Y;&ET=&EVY'0@=&%L;&5T=7-T879A;B!S=75R:6UM86X@<V%L
M;&ET=6X@<F%J86X`3VAJ96QM86$L(&IO;&QA('9O:2!K871S;V$@=FEE<W1I
M='EY<'!IY"`H)7,I+"!E:2!L]GET>6YY="!JY')J97-T96QMY'-TY"X`3&%I
M;F%U<VUE<FMK:2!P:73DY"!O;&QA('EK<VET=.1I;F5N(&UE<FMK:2X`5F%I
M;B!O:6ME82!J82!V87-E;B!P=6]L:0!686EN(&]I:V5A('!U;VQI`$5R;W1I
M;B!P:73DY"!O;&QA('EK<VET=.1I;F5N(&UE<FMK:2X`4&%L=F5L:6X@(B5S
M(B!O;B!P;VES=&5T='4N`%!A;'9E;&EN("(E<R(@;VX@=&%L;&5T971T=2X`
M4VESY.1N:VER:F%U='5M:7-P>7EN=/8@)7,@;VX@<&]I<W1E='1U+@!-Y.1R
M:71E;'1YY"!R:79IY"`H)60I(&5I(&]L92!O;&5M87-S82X`5F%L:>1A:6MA
M:7-T:65D;W-T;V$@(B5S(B!E:2!O;&4@;VQE;6%S<V$N`$MI<FIO:71T86UA
M<VD@=&5K<W1I(&5I('9A<W1A82!T96MS=&GD(')U=61U;&QA+@!686EN('EL
MY'!U;VQI(&IA(&%L87!U;VQI`%9A:6X@>6SD<'5O;&D`5'5O='4@=&EE=&\@
M:.1V:7-I(&5D96QL:7-E;B!K;VAD86X@86EK86YA+@!4=6]T=6$@=&EE9&]S
M=&]A(&5I('9O:71U('1A;&QE='1A82X`3W-I;W1A('=E871H97(N8V]M(&5I
M(&]L92!KY'ET971TY'9I<W/D+@!4965M86AA:V5M:7-T;V$@(B5S(B!E:2!L
M]GET>6YY="X`07-E='5K<VEA(&5I(&]L92!S86%T879I;&QA+@!%:2!O;&4@
M;W-I;VET82P@:F]T:V$@=F]I9&%A;B!NY'ET=.3D('9I97-T:65N('EH=&5Y
M9&5S<^0N`%3D<W/D(&ME;G3D<W/D(&]N(&QI:6%N(&UO;G1A(&UE<FMK:>0N
M($%N;F]I="`E<R!M97)K:VGD.R!S:6YU;B!P:73DY"!A;G1A82!VY&AE;6WD
M;B!K=6EN("5S(&UE<FMK:>0N`$IO:71A:VEN(&]N9V5L;6EA("(E<R(@;&ES
MY.1M:7-E<W/D(&KD<FIE<W1E;&WDY&XZ("5S`$OD>71TY&KD;B`B)7,B(&OD
M>71TY&KD=&EE=&]J96X@<&]I<W1A;6ES97-S82!JY')J97-T96QMY'-SY"!O
M;&D@;VYG96QM:6$Z(`!*;VET86MI;B!O;F=E;&UI82`B)7,B('!O:7-T86UI
M<V5S<V$@:N1R:F5S=&5L;>1S=.0Z(`!*;VET86MI;B!O;F=E;&UI82`B)7,B
M('#D:79I='EK<V5S<^0Z("5S`%1I961O<W1O;B!T=6]N;FES<V$@;VQI(&]N
M9V5L;6EA+B!9:'3DY&X@)7,Z82!E:2!T=6]T=0!4:65D;W-T;VX@='5O;FYI
M<W-A(&]L:2!O;F=E;&UI82X@)7,@:V]K;R!O;&D@<W5U<F5M<&D@:W5I;B!S
M=75R:6X@<V%L;&ET='4@:V]K;R`H)60@=&%V=6$I+@!4:65D;W-T;VX@='5O
M;FYI<W-A(&]L:2!O;F=E;&UI82X@)7,@;&%T875T=6D@=F%I;B!O<V%K<VDN
M`%1A<&%H='5I('9I<FAE(&[D>71E='3D97-SY"!V:65S=&EN('3D=.0@;W-I
M;W1A`%EH=&5Y<W1I971O:F5N('1U;VYN:7-S82!T87!A:'1U:2!V:7)H92X`
M:4-A;&5N9&%R+71I971O:F5N('1U;VYN:7-S82!T87!A:'1U:2!V:7)H92X`
M07-E='5S=&EE=&]L;VUA:VME97-S82!O;B!J;VMI;B!V:7)H92X@16AKY"!J
MY'1I="!J;VYK=6X@<&%K;VQL:7-E;B!K;VAD86X@=.1Y='3D;>1T=.0N`%1A
M<&%H='5I('9I<FAE('ER:71E='3D97-SY"!S=6]R:71T86$@;W-O:71E:VER
M:F%T;VEM:6YT;V$N(%ER:73D(&UY]FAE;6UI;B!U=61E<W1A86XN`%EH=&5Y
M<W1I971O:F5N('#D:79I='EK<V5S<^0@=&%P86AT=6D@=FER:&4N(%ER:73D
M(&UY]FAE;6UI;B!U=61E<W1A86XN`$IA:V5L=6QI<W1A;B!PY&EV:71Y:W-E
M<W/D('1A<&%H='5I('9I<FAE+B!9<FETY"!M>?9H96UM:6X@=75D97-T86%N
M+@!4Y&WD($E-05`@<&%L=F5L:6X@96D@='5E(&MA;G-I;VED96X@:F%K86UI
M<W1A+@!4Y&WD('1I961O<W1O(&5I('9A:6MU=&$@<F%R+71I961O<W1O;'1A
M+@!4Y&WD('1I961O<W1O(&5I('9A:6MU=&$@>FEP+71I961O<W1O;'1A+@!4
MY&WD(&5I('9A:6MU=&$@;VEK96%L=&$@:V]R='1I;G5M97)O;'1A+@!4Y&QL
MY"!A:G5R:6QL82!V;VD@;.1H971TY.0@=FEE<W1E:N0@0VQI8VMA=&5L;&EN
M("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&=A=&5W87D@<&%L=F5L=6$@2%14
M4"!!4$DZ;&QA+@!4Y&QLY"!A:G5R:6QL82!V;VD@;.1H971TY.0@=FEE<W1E
M:N0@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@9V%T97=A>2!P86QV96QU;B!K
M875T=&$@2%144"!!4$DZ;&QA+@!4Y&QLY"!A:G5R:6QL82!V;VD@;.1H971T
MY.0@=FEE<W1E:N0@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@
M9V%T97=A>2!P86QV96QU;B!K875T=&$@2%144"!!4$DZ;&QA+@!4Y&QLY"!A
M:G5R:6QL82!V;VD@;.1H971TY.0@=FEE<W1E:N0@5F]D869O;F5N(&YU;65R
M;VEH:6X@4TU44#IL;.0@:^1Y='3D96X@5F]D869O;F4@271A;'D@9V%T97=A
M>2!P86QV96QU82X@5.1TY"!P86QV96QU82!V;VD@:^1Y='3DY"!V86EN(%9O
M9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="D@='5N;G5K<VEL;&$N
M`%3D;>0@:V5N='3D(&]N('!A:V]L;&EN96XN`%3D<W/D(&ME;G3D<W/D('!I
M=.3D(&]L;&$@=F%I;B!K;VMO;F%I<VQU:W5J82X`5.1S<^0@:V5N=.1S<^0@
M<&ETY.0@;VQL82!N=6UE<F]I=&$@:F$@<&EL:VMU+6UE<FMK96KD+@!4Y'-S
MY"!K96YTY'-SY"!P:73DY"!O;&QA(&]K=&%A;&EL=6MU:F$N`%3D<W/D(&ME
M;G3D<W/D('!I=.3D(&]L;&$@;&ES=&$@:V]K;VYA:7-L=6MU:F$L(&IO=&MA
M('!I=.3D(&]L;&$@97)O=&5T='4@<&EL:W5L;&$@=&%I(';D;&EL>?9N;FEL
M;.0`07)V;VX@<&ETY.0@;VQL82!N=6UE<F\N`%3D<W/D(&ME;G3D<W/D(&]N
M(';D<FEMY.1R:71Y<RP@:F]N:V$@<&ETY.0@;VQL82!21T(@2&5X(&UU;V1O
M<W,L(&5S:6UE<FMI:W-I("<C,3(S-&%F)RX`5.1MY"!L;VUA:V4@;VX@:F\@
M:^1S:71E;'1Y+@!4Y&WD(&]N("5S+@!4Y&WD(&]N($MO;&%B($=R;W5P=V%R
M92!O8FIE:W1I+B!+871S;V%K<V5S:2!TY&WD;B!O8FIE:W1I;B!S:6YU;&QA
M('!I=.3D(&]L;&$@<^1H:_9P;W-T:6]H:F5L;6$L(&IO:V$@>6UMY')TY.0@
M2V]L86(@1W)O=7!W87)E(&9O<FUA871T:6$N($QI<W1A('EH=&5E;G-O<&EV
M:7-T82!SY&AK]G!O<W1I;VAJ96QM:7-T82!L]GET>7D@;W-O:71T965S=&$@
M)7,`5.1MY"!V:65S=&D@;VX@:VER:F]I=&5T='4@97)I(&UE<FMI<W3V;&SD
M("@E<RD@:W5I;B!M:6OD('-I;G5L;&$@;VX@:^1Y=/9S<^0N(`!.=6UE<F]N
M('!I=.3D(&]L;&$@=N1H:6YTY.1N('EK<VDN`%3D;&SD('!A;'9E;&EM96QL
M82!E:2!V;VD@875K86ES=&$@>FEP+2!T86D@9WII<"UT:65D;W-T;VIA+@!4
MY&WD(&KD<FIE<W1E;&WD(&]N('!O:7,@<.3D;'3D+@!!<G9O;B!P:73DY"!O
M;&QA(&YU;65R;RX`5.1MY&X@:6MK=6YA;B!V;VD@875K86ES=&$@=F%I;B!!
M<V5T=6MS970@:6MK=6YA<W1A`$UY<G-K>0!4:6ME=&ET`$%I:V$`06IA;G-E
M=7)A;G1A`$%J86X@97-I='ES;75O=&\`06IA;B!V86QI;G1A`%1I;6]R+4QE
M<W1E`%1I='1E;&D`3W1S:6MK;R`H=&]O;'1I<"DZ`%9A<W1A86YO='1A:F$`
M5F]I9&%K<V5S:2!V86QI=&$@=7-E86UP:6$@=F%I:'1O96AT;VIA+"!P:63D
M($-O;G1R;VPM("A00RD@=&%I($-O;6UA;F0M("A-86,I(&[D<'#D:6YTY"!P
M;VAJ87-S82!K=6X@;F%P<V%U=&%T(&AI:7)E;B!P86EN:6ME='1A+@!4Y&[D
MY&X`3N1Y=.0@2%1-3"ULY&AD96MO;V1I`%1O9V\`5&]K96QA=0!(=6]M96YN
M80!4;VYG80!,:6EA;B!M;VYT82!E<.1O;FYI<W1U;G5T=&$@:VER:F%U='5M
M:7-Y<FET>7-TY"!V:6EM96ES:6UP:65N(&UI;G5U='1I96X@:W5L=65S<V$N
M`%EL]G,`66QI;7#DY&X@:V5H>6MS965N("A?=&]P*0!+Y.1N;O9K<V5T`%1R
M:6YI9&%D(&IA(%1O8F%G;P!4;W-I('9A:2!E<.1T;W-I`'1I`%1U;FES:6$`
M5'5R:VMI`%1U<FMK:2`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS
M(&IA($-A:6-O<R!S86%R970`5'5V86QU`$MI<FIO:71A('9A;&EN=&%S:3H@
M`%4N5BX@+6EN9&5K<VDZ(`!54DP`55),(&IO:&]N('!A;&%U=&5T86%N('-K
M<FEP=&EN('-T871U<R!R87!O<G1T:0!54DPZ`%5G86YD80!5:W)A:6YA`%9&
M4RUH86ME;6ES=&]A(&5I('9O:71U(&QU:V5A+@!+Y'ET=.1JY&X@;&ESY'1I
M971O:F5N(&QI<^1Y<R!E:2!O;FYI<W1U;G5T(&MI<FIA=71U;6ES97-S82X`
M16D@=F]I('9A:6AT86$@;VEK975K<VEA(%9&4RUT:65D;W-T;VQL92`B)7,B
M+@!%:2!V;VD@=F%I:'1A82!O:6ME=6MS:6$@5D93+71I961O<W1O;&QE("5S
M+R5S+@!%:2!V;VED82!V86EH=&%A("5S.FXN`%1I961O<W1O;B`B)7,B(&MO
M:V]A(&5I('9O:71U('1A<FMI<W1A82X`16D@=F]I9&$@;FEM973D('5U9&5L
M;&5E;B!61E,M=&EE9&]S=&]A("(E<R\E<R(N`%-13"UP86QV96QI;65E;B!E
M:2!S86%D82!Y:'1E>71TY"X`66AT97ET=.0@96D@=F]I9&$@;75O9&]S=&%A
M(%-33"US86QA='1U;F$N`%9&4RUT:65D;W-T;V$@96D@=F]I9&$@:V]P:6]I
M9&$N`$5I('9O:61A(&QU;V1A(%9&4RUH86ME;6ES=&]A("(E<R(N`$5I('9O
M:61A(&QU;V1A(%9&4RUH86ME;6ES=&]A+@!%:2!V;VET=2!L=6]D82!61E,M
M=&EE9&]S=&]A`$5I('9O:61A(&YI;65TY"!U=61E;&QE96X@5D93+6MA;G-I
M;W1A("(E<R(N`$5I('9O:71U(&QU;V1A('1Y:&KDY"!61E,M=&EE9&]S=&]A
M+@!4:65T;V$@96D@=F]I9&$@;&%A:F5N=&%A+@!%:2!V;VED82!P;VES=&%A
M("(E<R(L(&AA:V5M:7-T;R!E:2!O;&4@='EH:N0N`$5I('9O:61A('!O:7-T
M86$@(B5S(CH@)7,N`$5I('9O:61A('!O:7-T86$@)7,L(&AA:V5M:7-T;R!E
M:2!O;&4@='EH:N0N`$5I('9O:61A('!O:7-T86$@5D93+6AA:V5M:7-T;V$@
M<F5K=7)S:6EV:7-E<W1I+@!%:2!V;VED82!P;VES=&%A(%9&4RUH86ME;6ES
M=&]A+@!%:2!V;VED82!P;VES=&%A(%9&4RUH86ME;6ES=&]A.B`E<RX`16D@
M=F]I9&$@<&]I<W1A82!61E,M=&EE9&]S=&]A("(E<R(N`$5I('9O:61A('!O
M:7-T86$@5D93+71I961O<W1O82X`16D@=F]I9&$@<&]I<W1A82!61E,M:V%N
M<VEO=&$@(B5S(BX`16D@=F]I9&$@<&]I<W1A82!61E,ZY.0@<F5K=7)S:6EV
M:7-E<W1I.B`E<RX`3GEK>6ES=.0@:&%K96UI<W1O82!E:2!V;VET=2!S96QV
M:71TY.0N`%9A<FUE;G1E96X@=&EE=&]J82!E:2!V;VED82!E>'1R86MT;VED
M80!-Y.1R:71Y:W-E;B`E<R!L=6ME;6EN96X@97#D;VYN:7-T=6DN`$5I('9O
M:61A('-I:7)TY.0@5D93+71I961O<W1O82X`16D@=F]I9&$@<&]I<W1A82!6
M1E,M=&EE9&]S=&]A("(E<R(N`$5I('9O:61A(&%V871A(%9&4RUT:65D;W-T
M;V$@:VER:F]I='5S=&$@=F%R=&5N+@!%:2!V;VED82!A=F%T82!61E,M=&EE
M9&]S=&]A+@!4:6EV:7-T971Y;B!T:65D;W-T;VX@875K86ES=2!E<.1O;FYI
M<W1U:2X`16D@=F]I='4@;'5K96$@5D93+71I961O<W1O82`H9FEL97-I>F4H
M*2!E<.1O;FYI<W1U:2DN`$5I('9O:61A(&QU:V5A(%9&4RUT:65D;W-T;V$@
M*&=E=$9I;&53:7IE*"D@97#D;VYN:7-T=6DI+@!%:2!V;VET=2!L=6ME82!T
M:65D;W-T;V$Z(`!V9G-R;V]T(&IU=7)I:&%K96UI<W1O82!E:2!V;VET=2!L
M=6ME82X`575D96QL965N;FEM9>1M:6YE;B`E<R`E<SIK<VD@97#D;VYN:7-T
M=6D@:V]S:V$@:V]H9&5H86ME;6ES=&\@;VX@:F\@;VQE;6%S<V$`16D@=F]I
M9&$@;FEM973D('5U9&5L;&5E;B!61E,M:&%K96UI<W1O82X`16D@=F]I9&$@
M;FEM973D('5U9&5L;&5E;B!61E,M:&%K96UI<W1O83H@)7,N`$5I('9O:61A
M(&YI;65TY"!U=61E;&QE96X@5D93+71I961O<W1O82`B)7,B+@!%:2!V;VED
M82!N:6UE=.0@=75D96QL965N(%9&4RUT:65D;W-T;V$@)7,O)7,N`$5I('9O
M:71U(&YI;65TY"!U=61E;&QE96X@5D93+71I961O<W1O82X`16D@=F]I9&$@
M<W5O<FET=&%A(&MO;65N=&]A("=M:VES;V9S)RX`5V]R9"UD;VMU;65N='1I
M82!E:2!V;VET=2!KY.1N=.3D`$5I('9O:61A(&MI<FIO:71T86$@5D93+71I
M961O<W1O82`B)7,B+@!%:2!V;VED82!K:7)J;VET=&%A(%9&4RUT:65D;W-T
M;V]N("AC;W!Y*"D@97#D;VYN:7-T=6DI+@!%:2!V;VED82!K:7)J;VET=&%A
M(%9&4RUT:65D;W-T;VX@=&EE=&]J82X`16D@=F]I9&$@:VER:F]I='1A82!6
M1E,M=&EE9&]S=&]A+"!K:6EN=&GV(&]N('3D>6YNY"X`06QL979I:79A='1U
M`%!E<G4@;75U=&]K<V5T`%!E<G5U='1A82!E9&5L;&ES96X@=&]I;65N<&ET
M965N`%1U;G1E;6%T;VX@=F%S=&%U<R!P86QV96QI;65L=&$@>6AT97ET965N
M.@!4=6YT96UA=&]N('9A<W1A=7,@<&%L=F5L:6UE;'1A.B``3'5O:VET=&5L
M96UA=&]N`%5N:6-O9&4@*%541BTX*0!9:&1I<W1Y;F5E="!A<F%B:65M:7)A
M871I=`!9:&1I<W1Y;F5E="!K=6YI;F=A<VMU;FYA=`!9:&1Y<W9A;&QA=`!9
M:&1Y<W9A;'1O:F5N(%1Y>6YE;FUE<F5N(&5R:6QL:7-S86%R970`36ET=&%Y
M:W-I:_9T`%1U;G1E;6%T;VX`5'5N=&5M871O;B!A<&EM<V=I9"`H05!)($UE
M<W-A9V4@240I+@!4=6YT96UA=&]N(&-L:6US9VED("A#;&EE;G0@365S<V%G
M92!)1"DN`$%N;F5T='4@<&%I:VMA=&EE=&\@;VX@='5N=&5M871O;BX`5'5N
M=&5M871O;B!KY'ET=.1JY'1U;FYU<R!T86D@<V%L87-A;F$N`%!O:7-T82!N
M>6MY:7-E;B!E;&5M96YT:6X@;&EN:VET>7,`3FEM973V;@!4:65T;W1U<G9A
M<WEI<W3D(&5I+7!R:79I;&5E9VES970@<VMR:7!T:70@96EVY'0@=F]I(&MU
M='-U82!,96EK:V%A+TMO<&EO:2],:6ETY"!T;VEM:6YT;VIA+B!.87!S875T
M82!/2RUN87!P=6QA82!NY&ADY&MS97-I(&UO>FEL;&$N;W)G('-I=G5I;&QA
M(&]L979A;B!O:&IE96XL(&IO<W-A(&YE=79O=&%A;B!M:71E;B!S:W)I<'1I
M<VD@=F]I=F%T(&OD>71TY.0@;&5I:V5P]GETY.0N`%!O:7-T82!VY')I`$5I
M+71U971T=2!L86%J96YN=7,`4.1I=FETY`!0Y&EV:73D("5S`%#D:79I=.0@
M:^1Y='3D:N0`4.1I=FET971T:6EN("(E<R(N`%#D:79I='ES<VMR:7!T:2!P
M;VES=&5T=&EI;BX`5'5O`'1U;R!K86EK:VD@;VAJ96QM:65N(&%S96YN=7-T
M:65D;W-T;W0@<&%L=F5L:6UE;&QE+@!)<V]T(&QA=&EN86QA:7-E="!K:7)J
M86EM970`27-O="!R;V]M86QA:7-E="!N=6UE<F]T`%5R=6=U87D`2^1Y=.0@
M;GEK>6ES=.0Z("5S`$OD>73D(%-33"US86QA=7-T80!+Y'ETY"!J;W,@='5N
M;G5S+W-A;&%S86YA(&]N(&5R:2!)35-0+7!A;'9E;&EM96QL92X`2^1Y='3D
M:N0`2^1Y='3D:N1L;.0@)7,@96D@;VQE(&]I:V5U:W-I82!T96ADY"`E<RX`
M2^1Y='3D:FEE;B!Y;&SD<&ET;P!+Y'ET=.1JY&X@87-E='5K<V5T`$OD>71T
MY&KD;B!R96MI<W1E<O9I;6EN96X`5.1S<^0@:N1R:F5S=&5L;>1S<^0@96D@
M=F]I(')E:VES=&5R]FEDY"!KY'ET=.1J:>0N`$OD>71TY&KD='5N;G5S=&$@
M96D@;/9Y='EN>70N`$OD>71TY&KD='5N;G5S`$OD>71TY&KD='5N;G5S("(E
M<R(@;VX@:F\@;VQE;6%S<V$N`$OD>71TY&KD='5N;G5S.@!+Y'ET=.1JY'1U
M;FYU<SH@`$KD<FIE<W1E;&WD;B!KY'ET=.1JY'0Z`%5Z8F5K:7-T86X`5D93
M+6AA:V5M:7-T;V$@96D@;VQE(&]L96UA<W-A+@!0;VES<V%O;&]V:65S=&D`
M4&%I:VMO:F$@;/9Y='EI(&5S:6UE<FMI:W-I.B``5F]I;6%S<V%O;&]A:6MA
M`$%R=F\@;6EN=75T96ES<V$@;GEK>6AE=&ME<W3D+@!!<G9O(&]N('EL:2!P
M:71U=61E;B!M86MS:6UI87)V;VX@)7,N/`!!<G9O=`!686QI='1A=F%T(&%R
M=F]T`%9A;G5A='4`5F%I:'1E;&5V86$`5F5N97IU96QA`%1A<FMI<W1U<R!E
M<.1O;FYI<W1U:2`M(%3D=.0@=FEE<W1IY"!O;B!V;VET=2!KY'-I=&5L;.0N
M`%9E<G-I;P!697)S:6]N:&%L;&EN=&$`4'ES='ES=6]R82!T87-A=7,`4'ES
M='ES=6]R82!TY'ET90!0>7-T>7-U;W)A.@!%<FET=.1I;B!K;W)K96$`5FEE
M=&YA;0!6:65T;F%M("A625-#24DI`$[D>73D("5S`$[D>73D(&5R:6QL:7-E
M;N0@=W=W+7-I=G5N80!.Y'ETY"`E<P!.96ET<WET<V%A<F5T+"!"<FET=&EL
MY&EN96X`3F5I='-Y='-A87)E="P@66AD>7-V86QT86EN`$[D:WEVY&ES>7ES
M`$[D:WEVY&ES>7ES.B``5F]D869O;F4@271A;'D@4TU44#IN(&%V=6QL80!6
M05)/25154P!605)/25154R$A(2!03TE35$$@4TM225!422!+Y%-)3B!004Q6
M14Q)345,5$$@)7,N`%=)3B!(5%10.FX@879U;&QA`%=A;&QI<R!J82!&=71U
M;F$`5F%R;VET=7,`:V4`4^3D96YN=7-T90!3Y.1T:65D;W0@;VX@=&]I;6ET
M=&%N=70`5V5A=&AE<BYC;VT`5U=7`%=75RUS:79U<W1O`%9I:6MO:71T86EN
M`%1E<G9E='5L;V$`5&5R=F5T=6QO82!O:&IE;&UA86X@)7,`5&5R=F5T=6QO
M82P@)7,`3.1N<VEM86EN96X@*$E33RTX.#4Y+3$I`$SD;G-I;6%I;F5N+T5U
M<F\@*$E33RTX.#4Y+3$U*0!,Y&YS:2U386AA<F$`36EN:^0@;VAJ96QM86X@
M)7,@:^1Y;FYI<W3DY"!S:7/DY&YK:7)J875T=6UI<V5N(&KD;&ME96XN`$UI
M=.0@;65R:VMIY"!KY'ET973DY&X@97)O='1I;65N83\`36ETY"!M97)K:VGD
M(&OD>71E=.3D;B!L86EN875K<V5E;C\`5VAE<F5I<R!!=7-T<F%L:6%N(&MA
M<G1T80!-:71KY"!V86EH965T`%9O:70@;>3D<FET96QLY"!L:7/D=&]I;6EN
M=&]J82!L86ET971A86X@<.3D;&QE(%)I8V@@5&5X="!E9&ET;W)I<W-A+@!,
M979E>7,`3&5V97ES($-34R!M:71T87EK<VEK:_9I;N0`5F%S96UM86QL82!O
M;&5V86X@)7,@=F%L:6MO;B!L979E>7,@*'1U;&5E('9O:6UA86X@<V5U<F%A
M=F%L;&$@<VESY.1N:VER:F%U='5M:7-E;&QA*3H`5&%U;'5K;VX@;&5V97ES
M`$QE=F5Y9&5N('EK<VEK:_8`3&5V97ES.@!7:6MI`%1U=6QI`%1U=6QI<W1A
M(&%I:V%I<VEN`%1U=6QE;FYO<&5U<R!S;VQM=6ES<V$`5'5U;&DZ`%1U=6QI
M.B``5FEI<V%U<P!4;VEV96QI<W1A=`!4>?8`3W-O:71E("AT>?8I`%!U:&5L
M:6X@*'1Y]BD`5N3D<N0@;>3D<N0@:V5N='1IY"!R:79I;&SD("5D+B!/9&]T
M971T:6EN("5D+"!L]GET>6D@)60N`%;DY'+D(&WDY'+D(&ME;G1T:>0N($]D
M;W1E='1I:6X@)60L(&SV>71Y:2`E9"X`5N3D<N0@<&]I:VME86UA("5D(&QU
M971T865S<V$@5D93+71I961O<W1O82X`6"U2968`6#4P.78S('!E<G5S<F%J
M;VET=&5E=`!8-3`Y=C,@;&ESY'1O:6UI;FYO="!A=F%I;65N(&OD>73V;&QE
M`%@U,#EV,R!+;VAT965N('9A:6AT;V5H=&]I;F5N(&YI;6D`6#4P.78S($MO
M:'1E96X@879A:6UE;B!T=6YN:7-T90!8-3`Y=C,M;&%A:F5N;G5K<V5T`%96
M`%965E8`66%H;V\A(&MA<G1T80!6=6]S:71T86EN`$IE;65N`$MY;&SD`$MY
M;&SD+"!S=6]S='5N+@!+Y'ETY'0@5$5+4U1)5$E,04$N($OD>73D(%L\/ET@
M;F%P<'5L86$@=F%I:'1A86MS97-I('1A:V%I<VEN(%=94TE764<M=&EL86%N
M+@!%="!V;VD@=&5H9.0@96YE;7#DY"!K=6EN("5D(&]S:6]T82X`170@;VQE
M(&%U=&5N=&EK;VET=6YU="X`3FEM97-SY'-I(&5I('-A82!O;&QA("=<)RUM
M97)K:VGD+@!%="!A;G1A;G5T(&]I:V5A;B!M=6]T;VES=&$@<^1H:_9P;W-T
M:6]S;VET971T82X`170@;>3D<FET96QL>70@;6ET:^0@='5O9'5N('1I961O
M<W1O;B!K96YTY'0@=F%S=&%A=F%T(&UI=.1K:6X@:V5N='1IY"`E<SIS<^0N
M`$]L970@:VER:F%U='5N=70@=6QO<RX`4VEN=6X@<&ETY.0@86YT86$@;VEK
M96$@;6%T:V%P=6AE;&EN;G5M97)O+"!V86EN(&YU;65R;VET82!J82!M86AD
M;VQL:7-E<W1I("<K)R!J;W,@:^1Y=.1T(&MA;G-A:6YVY&QI<W3D('!U:&5L
M:6YN=6UE<F]M=6]T;V$N`%-I;G5N('3D>71Y>2!A;G1A82!O:6ME82!A<G9O
M+@!3:6YU;B!P:73DY"!A<V5N=&%A($1A=&%4<F5E+71A=7-T86KD<FIE<W1E
M;&WD(&5N;F5N(&MU:6X@=F]I="!KY'ET=.3D(%-I9VYU<"UT;VEM:6YT;VIA
M+@!3:6YU;B!P:73DY"!A<V5N=&%A(%9&4RUT875S=&%JY')J97-T96QMY"X`
M4VEN=6X@='5L964@:W5V86EL;&$@;VYG96QM871I;&%N;F5T=&$@96YN96X@
M:W5I;B!V;VET(&SD:&5T=.3D(&]N9V5L;6%V:65S=&EN+@!3:6YU;B!P:73D
MY"!A;G1A82!54DP@;6EH:6X@=.1MY"!L:6YK:VD@;W-O:71T86$`4VEN=6X@
M<&ETY.0@=F%L:71A('!O:7-T971T879A('!A;'9E;&EN+@!3:6YU;B!P:73D
MY"!A;G1A82!P;VES=&5T=&%V82!KY'ET=.1JY'1U;FYU<RX`4VEN=6X@<&ET
MY.0@86YT86$@<&]I<W1E='1A=F$@:^1Y='3D:N1T=6YN=7,N`%-I;G5N('!I
M=.3D(&%N=&%A(&QI<^1T=.1VY"!KY'ET=.1JY'1U;FYU<RX`4VEN=6X@<&ET
MY.0@86YT86$@<.1I=FET971TY';D(&OD>71TY&KD='5N;G5S+@!3:6YU;B!P
M:73DY"!V86QI=&$@<W5O<FET971T879A('1O:6UI;G1O+@!3:6YU;B!P:73D
MY"!A;G1A82!U=61E;B!K871E9V]R:6%N(&YI;6DN`%-I;G5N('!I=.3D(&%N
M=&%A(&ET86QI86QA:6YE;B!P=6AE;&EN;G5M97)O`$ES='5N=&]S:2`E<R!O
M;B!V86YH96YT=6YU="X@2VER:F%U9'4@=75D96QL965N('-I<^3D;BX`4^1H
M:_9P;W-T:6]S;VET=&5E<VD`4VEN=6X@;.1H971TY&KD;W-O:71T965S:3H`
M3VUA="!T:65T;W-I`%-I;G5N('1I971O:V]N965S:2!KY'ET=.1MY"!T:65T
M;W9E<FMK;RUO<V]I=&4@;VX@;75U='1U;G5T('-E;B!JY&QK965N(&MU;B!O
M;&5T(&%L;VET=&%N=70@)7,@:7-T=6YN;VXN(%1I971O='5R=F%S>6ES=.0@
M<VEN=6X@<&ETY.0@:VER:F%U='5A('5U9&5S=&%A;B!JY')J97-T96QMY.1N
M+@!.:6UE<VD`2^1Y='3D;>1S:2!A=71H96YT:6-A=&EO;B!T875S=&%JY')J
M97-T96QMY"!E:2!T=64@:^1Y='3D:FEE;B!L:7/DY&UI<W3D+B!*;W,@:&%L
M=6%T(&AA;&QI;FYO:61A(&OD>71TY&KD='5N;G5K<VEA+"!S:6YU;B!P:73D
MY"!KY'ET=.3D(&IO=&%K:6X@=&]I<W1A(&%U=&AE;G1I8V%T:6]N('1A=7-T
M86KD<FIE<W1E;&WDY"X`2^1Y='3D;>1S:2!A=71H96YT:6-A=&EO;B!T875S
M=&%JY')J97-T96QMY"!E:2!T=64@:^1Y='3D:N1T:65T;VIE;B!NY'ET=.1M
M:7-TY"!T86D@=.1MY"!P:6ER<F4@96D@;VQE(&IO<W1A:VEN('-Y>7-TY"!K
MY'ET971TY'9I<W/D+@!3:6YU;B!KY'ET=.1MY'-I('=W=RUS96QA:6X@;N1Y
M='3DY"!O;&5V86X@;75U='1U;G5T('-E;B!JY&QK965N(&MU;B!O;&5T(&%L
M;VET=&%N=70@)7,@:7-T=6YN;VXN(%1I971O='5R=F%S>6ES=.0@<VEN=6X@
M<&ETY.0@:VER:F%U='5A('5U9&5S=&%A;FKD<FIE<W1E;&WDY&XN`%-E;&%I
M;65S:2!E:2!T=64@=.1TY"!T;VEM:6YT;V$N`%-E;&%I;65S:2!E:2!T=64@
M=&%R=FET=&%V86$@='5L;W-T=7-T;VEM:6YT;V$N(%!A:6YA($-O;G1R;VPO
M3W!T:6]N("L@4"!T=6QO<W1A86MS97-I+@!!:6MA=GGV:'EK:V5E<VDZ`$]L
M971U<W!R;V9I:6QI<VD@;VX@;75U=&5T='4N`$]L971U<W!R;V9I:6QI<VDZ
M`$YI;65S:3H`27-T=6YT;W-I(&]N('9A;FAE;G1U;G5T+@!3:6YU;B!S86QA
M<V%N87-I("5S.FQL92!O;CH@)7,`07-E='5K<V5S:2!O;B!PY&EV:71E='1Y
M(&IA(&YE(&]V870@=F]I;6%S<V$@=.1MY&X@:7-T=6YN;VX@86IA;BX`07-E
M='5K<V5S:2!O;B!PY&EV:71E='1Y+@!386QA<V%N87-I(&]N(&YO;&QA='1U
M`%-A;&%S86YA<VD@;VX@;F]L;&%T='4L('1A<FMI<W1A('/D:&OV<&]S=&ES
M:2!J82!K:7)J875D=2!S:7/DY&X@=75D96QL82!S86QA<V%N86QL87-I+@!3
M86QA<V%N87-I(&]N('9A;FAE;G1U;G5T+@!%=.1P86QV96QI;65S:3H`2G5G
M;W-L879I80!:86ER90!386UB:6$`6FEM8F%B=V4`6FEP<'D`6U!I:6QO=&$@
M;&%I;F%T='4@=&5K<W1I70!;3VYG96QM85T`6T[D>73D(&QA:6YA='1U('1E
M:W-T:2`M`%M.Y'ETY"!L86EN871T=2!T96MS=&D@+2`E<R!R:79IY%T`6W)I
M=FEL;.0@)7,O)7-=`%]9;&SD<&ET;P!?2V]M96YT;W1U;&MK:0!?1&%T851R
M964`7U!O:7-T82!R:79I`%]2>6AMY'0`7T]H:F4`7TMU=F%N('1I961O="XN
M+@!?2VER:F%U9'4@<VESY.1N`%]+:7)J875D=2!U;&]S`%]-=6]K:V%A(&QI
M;FMK:>0`7T%S971U:W-E=`!?3VEK975D970`4&]I<W1A(&QI;FMK:2XN+@!?
M07-E;FYU<P!?5&%U;'5K;VX@=&EE9&]T+BXN`%]+Y'ET=.1JY'0`;W-O:71E
M:VER:F$`=F%S=&%A;F]T=&%J82!T=6YT96UA=&]N`&MA;&5N=&5R:0!T>7EN
M=.0`96D@=F]I(&QU;V1A('1U;&]S=&EE9&]S=&]A`&5I('9O:2!A=6MA:7-T
M82!LY&AD971TY`!N87!S875T82!TY'-TY`!V:7)H92!K;VUE;G1O<FEV:6QL
MY`!A<V5T=7-V:7)H90!K<FEI='1I;F5N(&KD<FIE<W1E;&WD=&EE9&]S=&\@
M<'5U='1U=0!M=6]T;W9I<FAE('1I961O:7-S80!M=6]K:V%A`'1I971U971T
M82!E:2!L]GET>6YY=`!L87-K979A`'1I961O<W1O`'-U=6YN87-T82`E<R`H
M)7,I(&YO<&5U9&5L;&$@)7,@)7,`<'5U<VMI='1A:6X`:#H`:&@`='5N=&5M
M871O;B!P86QV96QI;65N(&YI;6D`=N1L:71T]FWD<W1I`&EN;&EN90!I;RUV
M:7)H90!O:&IE;&UI<W1O;B!S:7/D:6YE;B!V:7)H90!R:79I=%T`;6MI<V]F
M<R!V:7)H96MO;V1I("5D($E33SIA('1E:&1E<W/D+@!M;0!N:6UI`&5I(&]L
M92!T;W1E=71E='1U`&5I(&]L92!V:65LY"!T;W1E=71E='1U`&UU:7-T:6QI
M<W1A`'!R;W-E;G1T:0!KY'ET=/8@:VEE;&QE='1Y`'!I:W-E;&5I=.0`973D
M=FER:&4@<')O=&]K;VQL87-S80!N;W5S979A`'!A;'9E;'4@96D@;VQE(&OD
M>71E='3D=FES<^0`;N1Y=.0@97)O=`!S;7,R96UA:6P@2%144#IN(&%V=6QL
M80!S<P!V86MA80!JY')J97-T96QMY'9I<FAE`'1E:'3D=N1L:7-T80!VY&QI
M86EK86EN96X@=FER:&4`=F%R;6ES=&%A:W-E<VD@:VER:F]I=&$@<V%L87-A
M;F$@:V%H9&5S=&D`=6YI9FEE9`!N:6UE=/9N`&OD>71TY&KD;B!V86QI;G1A
M`'9#87)D`'<Z`'=E871H97(N8V]M````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]F:5]&22]H
M96QP+GAM;```````````````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P-#,S-R`Q,#4Q-30S,S<T,2`P,C$T,S(`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]X;6P@=F5R<VEO;CTB,2XP(C\^
M"CPA+2T@)$AO<F1E.B!H;W)D92]L;V-A;&4O9FE?1DDO:&5L<"YX;6PL=B`Q
M+C,N,3`N,R`R,#`V+S`R+S(P(#$Q.C(P.C$Q(&IA;B!%>'`@)"`M+3X*/&AE
M;'`^"B`@/&5N=')Y(&ED/2)S=6UM87)Y(B!M9#4](C8X8V$S,V8W9C!C.6%A
M931C,3`S96(T-S0Y,F-D8S$U(B!S=&%T93TB=7!T;V1A=&4B/@H\=&ET;&4^
M4&]R=&%A;&D\+W1I=&QE/@H@/'!A<F$^"B`@4&]R=&%A;&ES<V$@=F]I="!N
M)B-X130[:&0F(WA%-#L@<&EK86ES97-T:2!L>6AY96X@>6AT965N=F5D;VX@
M="8C>$4T.W)K928C>$4T.VMS:0H@(&UE<FMI='-E;6ES="8C>$4T.R!A<VEO
M:7-T82X@17-I;65R:VEK<VD@=F]I="!N)B-X130[:&0F(WA%-#L@;6]N=&%K
M;R!U=71T80H@(',F(WA%-#MH:R8C>$8V.W!O<W1I=FEE<W1I)B-X130[('-I
M;G5L;&4@;VX@='5L;'5T($E.0D]8(&MA;G-I;V]N+"!T=6QE=F%T"B`@=&%P
M86AT=6UA="!K86QE;G1E<FES<V$L('1E:'0F(WA%-#MV)B-X130[="!T;RUD
M;R!L:7-T86QL82P@;W1S:6MO=`H@('9A;&ET<V5M:7-T87-I('5U=&ES<&%L
M=F5L=6ES=&$@:FYE+B!-;VYE="!N)B-X130[:7-T)B-X130[('EH=&5E;G9E
M9&]I<W1A"B`@<VES)B-X130[;'0F(WA%-#MV)B-X130[="!L:6YK:V5J)B-X
M130[('EL96ES:6UP:6EN('1O:6UI;G1O:6AI;B!K=71E;B!E<VEM97)K:6MS
M:2!V:65S=&EN"B`@:VER:F]I='5S+"!K86QE;G1E<FEM97)K:6YN)B-X130[
M;B!T86D@=&5H="8C>$4T.W8F(WA%-#MN(&QI<R8C>$4T.WES(&IN92X*(#PO
M<&%R83X*(#QP87)A/@H@(%!O<G1A86QI;B!S:7,F(WA%-#ML="8C>$8V.R!O
M;B!M=6]K871T879I<W-A($%S971T96QU('!A:6YI:VME96X@:V%U='1A+B!6
M;VET"B`@97-I;65R:VEK<VD@=F%L:71A(&UI=&LF(WA%-#L@87-I870@;&EI
M=&5T)B-X130[)B-X130[;B!P;W)T86%L:6EN(&IA(&UI<W,F(WA%-#L*("!J
M)B-X130[<FIE<W1Y:W-E<W,F(WA%-#L@;F4@;B8C>$4T.WET970F(WA%-#LF
M(WA%-#MN+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB;F%V8F%R
M(B!M9#4](F(X8V8P864Q.64U-V1F83!C,F(Y-C)E-3$V-S@R9C0W(B!S=&%T
M93TB=7!T;V1A=&4B/@H\=&ET;&4^3VAJ96QM:65N(&YA=FEG;VEN=&EV86QI
M:VMO/"]T:71L93X*(#QP87)A/@H@(%=W=RUS:79U;B!V87-E;6%L;&$@;&%I
M9&%L;&$@;VX@;F%V:6=O:6YT:79A;&EK:V\@97)I(&]H:F5L;6EI;BX*("!.
M87!S875T=&%M86QL82!I:V]N96ET82!N879I9V]I;G1I=F%L:6MO<W-A('9O
M:70@:&5L<&]S=&D@:F$*("!N;W!E87-T:2!V86EH=&%A(&]H:F5L;6%S=&$@
M=&]I<V5E;BX*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S
M+61O7VUA:6YT96YA;F-E(B!M9#4](F1D.35D9C`W83`S,#,Q,C,R8F%E83DQ
M.3(X.&(R9#`P(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/D%S971U
M:W-E=#H@66QL)B-X130[<&ET;W1O:6UE;G!I=&5E=#H@4W5O<FET82!Y;&PF
M(WA%-#MP:71O=&]I;65T/"]T:71L93X*("`@(#QP87)A/@H@("`@2F]S(&AA
M;'5A="!S=6]R:71T86$@>6QL)B-X130[<&ET;W1O:6UE;G!I=&5I="8C>$4T
M.R!S:7,F(WA%-#LF(WA%-#MN:VER:F%U='5M:7-E;@H@("`@>6AT97ED97-S
M)B-X130[+"!N:6EN(&%S971A('0F(WA%-#MM)B-X130[('1O:6UI;G1O('`F
M(WA%-#LF(WA%-#ML;&4@=F%L:6YT87)U=61U<W1A+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M8V]N9FER;5]M86EN=&5N86YC
M92(@;60U/2)A,C$Q-C)C9&9F,V(Q9#AF865A9&(W,CDV,C0P,#,V92(@<W1A
M=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y!<V5T=6MS970Z(%EL;"8C>$4T
M.W!I=&]T;VEM96YP:71E970Z(%9A<FUI<W1A('EL;"8C>$4T.W!I=&]T;VEM
M970\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!*;W,@:&%L=6%T('9A<FUI<W1A
M82!K86EK:VD@>6QL)B-X130[<&ET;W1O:6UE;G!I=&5E="!E;F5N;FMU:6X@
M;F4*("`@('-U;W)I=&5T86%N+"!N:6EN(&%S971A('0F(WA%-#MM)B-X130[
M('1O:6UI;G1O('`F(WA%-#LF(WA%-#ML;&4*("`@('9A;&EN=&%R=75D=7-T
M82X@2F]S('9A<FUI<W1U<W1A(&5I(&]L92!P)B-X130[)B-X130[;&PF(WA%
M-#LL(&YI:6X@:V%I:VMI"B`@("!Y;&PF(WA%-#MP:71O=&]I;65N<&ET965T
M('-U;W)I=&5T86%N(&%U=&]M86%T=&ES97-T:2!J82!N:6ET)B-X130[(&5I
M('9O:0H@("`@<&5R=6$N"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L<#X*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO
M8V%L92]E=%]%10``````````````````````````````````````````````
M```````````````````````````````````````P,#`W-34@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<T,2`P,3<V-S<`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&]C86QE+V5T7T5%+TQ#7TU%4U-!1T53````````
M````````````````````````````````````````````````````````````
M`#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S
M-S0Q(#`R,30V-``@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O971?144O
M3$-?34534T%'15,O:&]R9&4N;6\`````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`T,#(R,S(@,3`U,34T,S,W-#$@,#(S,C`T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````-X2!)4`````CP<``!P```"4/```
M'PH```QY````````B*$```X```")H0``#P```)BA```-````J*$```@```"V
MH0``"P```+^A```,````RZ$```0```#8H0``&````-VA```;````]J$``"T`
M```2H@``'0```$"B```D````7J(``"D```"#H@``&0```*VB```F````QZ(`
M``P```#NH@``)````/NB```/````(*,```L````PHP``#@```#RC```%````
M2Z,``"@```!1HP``"````'JC```*````@Z,``!4```".HP``$@```*2C```+
M````MZ,``(4```##HP``#@```$FD```*````6*0```T```!CI```#@```'&D
M```1````@*0```T```"2I```#````*"D```-````K:0```8```"[I```E```
M`,*D```*````5Z4```\```!BI0``&````'*E```,````BZ4```X```"8I0``
M#@```*>E```(````MJ4```D```"_I0``+@```,FE```:````^*4``#(````3
MI@``.````$:F``!4````?Z8``%$```#4I@``6@```":G``!7````@:<``#0`
M``#9IP``"0````ZH```-````&*@```<````FJ```"@```"ZH```/````.:@`
M``4```!)J```!@```$^H```1````5J@```@```!HJ```"0```'&H```)````
M>Z@``"4```"%J```(````*NH```3````S*@``!````#@J```#P```/&H```*
M`````:D```,````,J0``#P```!"I```4````(*D```D````UJ0``#0```#^I
M```2````3:D``!D```!@J0``'@```'JI```/````F:D```H```"IJ0``#P``
M`+2I```(````Q*D``"0```#-J0``%````/*I```6````!ZH```@````>J@``
M3@```">J```M````=JH``!D```"DJ@``!P```+ZJ```,````QJH``"P```#3
MJ@``#@````"K```#````#ZL```L````3JP``!P```!^K```'````)ZL```4`
M```OJP``!0```#6K```*````.ZL```,```!&JP``%P```$JK```*````8JL`
M``\```!MJP``#@```'VK```8````C*L``",```"EJP``#@```,FK```4````
MV*L``!<```#MJP``%P````6L```7````':P``!,````UK```#P```$FL```.
M````6:P``!\```!HK```'0```(BL```'````IJP```8```"NK```"````+6L
M```/````OJP```8```#.K```"@```-6L```3````X*P```L```#TK```$```
M``"M```5````$:T``!4````GK0``!P```#VM```0````1:T```4```!6K0``
M%0```%RM```1````<JT```P```"$K0``.P```)&M```X````S:T```D````&
MK@``!P```!"N```4````&*X```,````MK@``!0```#&N```0````-ZX```D`
M``!(K@``$P```%*N```Y````9JX``!(```"@K@``)P```+.N```L````VZX`
M`"H````(KP``)0```#.O```*````6:\```8```!DKP``"0```&NO```'````
M=:\``"\```!]KP``-P```*VO```N````Y:\``%4````4L```+0```&JP```M
M````F+```#T```#&L```/P````2Q```M````1+$``$````!RL0``(P```+.Q
M```C````U[$``$````#[L0``+0```#RR```S````:K(``!4```">L@``&0``
M`+2R```I````SK(``"0```#XL@``*````!VS```1````1K,```H```!8LP``
M#````&.S```*````<+,``!````![LP``%@```(RS```6````H[,```<```"Z
MLP``!P```,*S```4````RK,```H```#?LP``"````.JS```G````\[,```@`
M```;M```!P```"2T```'````++0```8````TM```!0```#NT```'````0;0`
M``8```!)M```"````%"T```I````6;0```X```"#M```"@```)*T```$````
MG;0```<```"BM```"0```*JT```&````M+0``!$```"[M```!P```,VT```6
M````U;0```0```#LM```"````/&T```&````^K0```T````!M0``!@````^U
M```>````%K4``!$````UM0``"````$>U```-````4+4```P```!>M0``!P``
M`&NU```#````<[4```,```!WM0``%P```'NU```3````D[4``!T```"GM0``
M"````,6U```$````SK4```@```#3M0``"````-RU``!!````Y;4``!H````G
MM@``*P```$*V```@````;K8``!4```"/M@``!@```*6V```&````K+8``!4`
M``"SM@``&````,FV```B````XK8``"X````%MP``'0```#2W```A````4K<`
M`%0```!TMP``*0```,FW```*````\[<```<```#^MP``!P````:X```5````
M#K@```X````DN```"@```#.X```/````/K@```T```!.N```#P```%RX```-
M````;+@```D```!ZN```%````(2X```&````F;@``!@```"@N```'0```+FX
M```3````U[@``!$```#KN```%````/VX```$````$KD```8````7N0``%```
M`!ZY``!4````,[D``&0```"(N0``!````.VY```.````\KD```4````!N@``
M!0````>Z```;````#;H``!H````IN@``$P```$2Z```1````6+H``!$```!J
MN@``'````'RZ```J````F;H``!````#$N@``(0```-6Z```%````][H``!,`
M``#]N@``"P```!&[```2````';L```H````PNP``#P```#N[```-````2[L`
M`!$```!9NP``$P```&N[```,````?[L```8```",NP``#````).[```&````
MH+L``!<```"GNP``$````+^[```1````T+L```@```#BNP``!0```.N[```,
M````\;L``!````#^NP``!0````^\```-````%;P```8````CO```!P```"J\
M```-````,KP```<```!`O```"P```$B\```'````5+P```<```!<O```"0``
M`&2\```)````;KP```H```!XO```&0```(.\```]````G;P``!T```#;O```
M#````/F\```0````!KT```4````7O0``)0```!V]```2````0[T``!,```!6
MO0``*P```&J]```[````EKT``"````#2O0``"````/.]```V````_+T``!``
M```SO@``"````$2^```,````3;X```8```!:O@``!````&&^```/````9KX`
M``X```!VO@``!P```(6^```*````C;X```T```"8O@``'@```*:^```;````
MQ;X``"$```#AO@``'@````._```9````(K\``!X````\OP``'0```%N_```;
M````>;\``"$```"5OP``+@```+>_```F````YK\``!L````-P```'@```"G`
M```<````2,```"8```!EP```*P```(S````S````N,```"8```#LP```*P``
M`!/!```X````/\$``!T```!XP0``%0```);!```O````K,$``"````#<P0``
M$@```/W!```I````$,(``!X````ZP@``(````%G"```2````>L(``*(```"-
MP@``%@```###```C````1\,``"@```!KPP``*0```)3#```H````OL,``!\`
M``#GPP``%0````?$```@````'<0``"4````^Q```*````&3$```M````C<0`
M`#````"[Q```D@```.S$```A````?\4``!8```"AQ0``'````+C%```F````
MU<4``"H```#\Q0``00```"?&``!$````:<8```P```"NQ@``!P```+O&```'
M````P\8```8```#+Q@``#0```-+&```0````X,8``!(```#QQ@``$P````3'
M```2````&,<```<````KQP``!````#/'```0````.,<``!````!)QP``#```
M`%K'```.````9\<```T```!VQP``#P```(3'```3````E,<```T```"HQP``
M*````+;'```#````W\<```T```#CQP``!@```/''```1````^,<``!<````*
MR```&P```"+(```.````/L@```(```!-R```20```%#(```%````FL@``!``
M``"@R```#P```+'(```$````P<@```T```#&R```#@```-3(```#````X\@`
M``X```#GR```"````/;(```/````_\@```\````/R0``!P```!_)```-````
M)\D``!`````UR0``#0```$;)```+````5,D```8```!@R0``"P```&?)```,
M````<\D```H```"`R0``$0```(O)```9````G<D```L```"WR0``#0```,/)
M```B````T<D```\```#TR0``&P````3*```T````(,H```H```!5R@``&```
M`&#*```9````><H``!8```"3R@``(@```*K*```-````S<H```<```#;R@``
M%````./*```+````^,H``"(````$RP``+P```"?+```+````5\L```D```!C
MRP``&0```&W+```+````A\L``!<```"3RP``%P```*O+```)````P\L``!8`
M``#-RP``#P```.3+```9````],L``!8````.S```#@```"7,```8````-,P`
M``@```!-S```#0```%;,```F````9,P``$,```"+S```"````,_,```2````
MV,P``!\```#KS```"`````O-```+````%,T``"\````@S0``#@```%#-```%
M````7\T```8```!ES0``10```&S-```#````LLT```<```"VS0``!````+[-
M```*````P\T```H```#.S0``#P```-G-```0````Z<T``!<```#ZS0``$0``
M`!+.```9````),X``!<````^S@``"0```%;.```%````8,X``#T```!FS@``
M"P```*3.```*````L,X```(```"[S@``!0```+[.```-````Q,X``!L```#2
MS@``%P```.[.```4````!L\```D````;SP``#@```"7/```-````-,\``!(`
M``!"SP``.````%7/```@````CL\```@```"OSP``#@```+C/``![````Q\\`
M`!@```!#T```&````%S0```1````==````<```"'T```!0```(_0```8````
ME=```!X```"NT```&P```,W0```9````Z=```!L````#T0``&0```!_1```3
M````.=$```<```!-T0``"````%71```&````7M$```8```!ET0``$````&S1
M```/````?=$``!````"-T0``#P```)[1```+````KM$```\```"ZT0``#```
M`,K1```/````U]$```<```#GT0``!@```._1```.````]M$```P````%T@``
M*````!+2```/````.](```@```!+T@``"````%32```3````7=(``!X```!Q
MT@``(0```)#2```@````LM(``!D```#3T@``%P```.W2```E````!=,``!<`
M```KTP``%@```$/3```$````6M,``!L```!?TP``#0```'O3```,````B=,`
M``,```"6TP``!0```)K3```(````H-,```H```"ITP``#````+33```+````
MP=,``!````#-TP``#````-[3```.````Z],```L```#ZTP``!`````;4```$
M````"]0``!,````0U```%````"34```,````.=0```D```!&U```#@```%#4
M```+````7]0``!L```!KU```!P```(?4```'````C]0```H```"7U```#0``
M`*+4```)````L-0```0```"ZU```!0```+_4```#````Q=0``!@```#)U```
M"@```.+4```$````[=0``"8```#RU```#@```!G5``!\````*-4``!4```"E
MU0``!0```+O5```'````P=4```P```#)U0``"````-;5```*````W]4```8`
M``#JU0``"````/'5```"````^M4```8```#]U0``!@````36```4````"]8`
M``T````@U@``$````"[6```;````/]8```0```!;U@``"0```&#6```0````
M:M8```D```![U@``"0```(76```%````C]8``!H```"5U@``"````+#6```&
M````N=8``!D```#`U@``#@```-K6```'````Z=8```<```#QU@``!0```/G6
M```)````_]8```H````)UP``#@```!37```"````(]<```8````FUP``"P``
M`"W7```-````.=<```D```!'UP``!@```%'7```2````6-<```D```!KUP``
M!P```'77```4````?=<``!T```"2UP``0@```+#7```E````\]<``"4````9
MV```!@```#_8```*````1M@```0```!1V```"0```%;8```(````8-@``!$`
M``!IV```"0```'O8```&````A=@```T```",V```!@```)K8```$````H=@`
M`#D```"FV```/0```.#8```Z````'MD``!X```!9V0``!0```'C9```.````
M?MD```0```"-V0``!@```)+9```'````F=D``"$```"AV0``#0```,/9```5
M````T=D```8```#GV0``!````.[9```1````\]D```8````%V@``"@````S:
M```B````%]H```0````ZV@``!0```#_:```=````1=H```0```!CV@``#```
M`&C:```.````==H```H```"$V@``"````(_:```)````F-H```4```"BV@``
M.@```*C:```P````X]H``#4````4VP``*0```$K;``!'````=-L``#@```"\
MVP``*0```/7;```_````']P``"X```!?W```+0```([<```?````O-P```\`
M``#<W```$@```.S<```+````_]P``"8````+W0``*0```#+=```D````7-T`
M`"8```"!W0``"````*C=```*````L=T```D```"\W0``!P```,;=```@````
MSMT``"````#OW0``)@```!#>```*````-]X``!D```!"W@``*0```%S>```6
M````AMX``!(```"=W@``!P```+#>```*````N-X```P```##W@``#P```-#>
M```0````X-X``$````#QW@``<````#+?``!F````H]\```X````*X```"0``
M`!G@```*````(^```!(````NX```$P```$'@```,````5>````8```!BX```
M#P```&G@```2````>>```!````",X```$0```)W@```<````K^```",```#,
MX```:@```/#@```/````6^$```4```!KX0``$````''A```)````@N$```0`
M``",X0``"P```)'A```@````G>$``!0```"^X0``#````-/A```,````X.$`
M``\```#MX0``%0```/WA```I````$^(``"H````]X@``)@```&CB```G````
MC^(``"D```"WX@``*@```.'B```9````#.,``$(````FXP``$0```&GC```2
M````>^,``!,```".XP``%````*+C```/````M^,``!8```#'XP``%P```-[C
M```0````]N,``!$````'Y```-````!GD```3````3N0``!(```!BY```-0``
M`'7D```4````J^0```<```#`Y```#````,CD```@````U>0``!````#VY```
M%`````?E```1````'.4``!<````NY0``'````$;E```3````8^4``!0```!W
MY0``&@```(SE```1````I^4``!H```"YY0``'@```-3E```:````\^4``!,`
M```.Y@``%0```"+F```1````..8``!<```!*Y@``%````&+F```7````=^8`
M`!4```"/Y@``"0```*7F```0````K^8``!D```#`Y@``!````-KF```'````
MW^8```L```#GY@``$0```//F```&````!><```8````,YP``!@```!/G```%
M````&N<```<````@YP``!P```"CG```%````,.<``!8````VYP``6P```$WG
M```&````J><```8```"PYP``!````+?G```$````O.<```<```#!YP``#@``
M`,GG```,````V.<```P```#EYP``#0```/+G```*`````.@```X````+Z```
M!0```!KH```H````(.@```X```!)Z```#````%CH```/````9>@```H```!U
MZ```"````(#H```)````B>@``"L```"3Z```!````+_H```(````Q.@``"8`
M``#-Z```$@```/3H```/````!^D```8````7Z0``"@```![I```'````*>D`
M``@````QZ0``(````#KI```)````6^D``!0```!EZ0``#````'KI```-````
MA^D```X```"5Z0``%@```*3I```1````N^D```8```#-Z0```P```-3I```&
M````V.D``!D```#?Z0``!P```/GI```$`````>H```L````&Z@``"P```!+J
M```'````'NH```4````FZ@``!P```"SJ```6````-.H```T```!+Z@``#0``
M`%GJ```*````9^H``!````!RZ@``#P```(/J```1````D^H``!<```"EZ@``
M"@```+WJ```1````R.H```@```#:Z@``!````./J```/````Z.H``#H```#X
MZ@``!0```#/K```,````.>L``!X```!&ZP``#@```&7K```0````=.L```L`
M``"%ZP``#````)'K```)````GNL```<```"HZP``"@```+#K```)````N^L`
M``X```#%ZP``$````-3K```;````Y>L``!@````![```&@```!KL```*````
M->P```D```!`[```"@```$KL```,````5>P```\```!B[```"````'+L```&
M````>^P``!P```""[```!P```)_L```%````I^P```L```"M[```1P```+GL
M```-`````>T```D````/[0``!````!GM```#````'NT``!,````B[0``$P``
M`#;M```3````2NT```H```!>[0```@```&GM```$````;.T``"4```!Q[0``
M`P```)?M```%````F^T``"H```"A[0``"@```,SM```%````U^T```0```#=
M[0``"@```.+M```-````[>T```8```#[[0``"`````+N```(````"^X```0`
M```4[@``!0```!GN``!H````'^X```D```"([@``#````)+N```0````G^X`
M``4```"P[@``!@```+;N```;````O>X``"\```#9[@``$`````GO```*````
M&N\```\````E[P``"@```#7O```)````0.\``!,```!*[P``&P```%[O```8
M````>N\``!<```"3[P``'P```*OO```.````R^\```,```#:[P``!P```-[O
M```(````YN\```<```#O[P``"@```/?O```+`````O````<````.\```40``
M`!;P```0````:/````P```!Y\```#0```(;P```:````E/```$H```"O\```
M&0```/KP```&````%/$``!H````;\0``)0```#;Q```&````7/$```8```!C
M\0``'P```&KQ```&````BO$```D```"1\0``&````)OQ```7````M/$``"@`
M``#,\0``!@```/7Q```-````_/$``"(````*\@``5P```"WR```3````A?(`
M`",```"9\@``$P```+WR```"````T?(```L```#4\@``"````.#R```-````
MZ?(```H```#W\@``!P````+S```4````"O,```8````?\P``"````";S```.
M````+_,```<````^\P``"@```$;S```+````4?,``#(```!=\P``!P```)#S
M```,````F/,```T```"E\P``%P```+/S```,````R_,```D```#8\P``"0``
M`.+S```*````[/,```<```#W\P``"0```/_S```'````"?0```H````1]```
M&P```!ST```/````./0``!(```!(]```"@```%OT```6````9O0```D```!]
M]```$````(?T```'````F/0``!(```"@]```!````+/T```'````N/0```4`
M``#`]```!0```,;T```+````S/0``!0```#8]```$0```.WT```:````__0`
M`!8````:]0``%````#'U```7````1O4``!@```!>]0``'````'?U```9````
ME/4```<```"N]0``!0```+;U```-````O/4```P```#*]0``$0```-?U```(
M````Z?4``!<```#R]0``"P````KV```,````%O8``!\````C]@``&@```$/V
M```3````7O8```0```!R]@``"@```'?V```$````@O8```T```"']@``#```
M`)7V```%````HO8```D```"H]@``!0```++V```'````N/8```4```#`]@``
M!````,;V```"````R_8``#@```#.]@``+`````?W```2````-/<``"D```!'
M]P``,@```''W```*````I/<``"P```"O]P``+@```-SW```S````"_@``#,`
M```_^```.````'/X```/````K/@``!@```"\^```$````-7X```/````YO@`
M`!,```#V^```%0````KY```4````(/D``!(````U^0``%````$CY```5````
M7?D``"T```!S^0``+0```*'Y```Q````S_D``"X````!^@``+P```##Z```L
M````8/H``&(```"-^@``$P```/#Z```-````!/L```@````2^P``%P```!O[
M```(````,_L```P````\^P``*P```$G[```A````=?L``!H```"7^P``"0``
M`++[``!%````O/L``$$````"_```!````$3\```3````2?P``!0```!=_```
M#@```'+\```3````@?P``!@```"5_```!@```*[\```)````M?P```H```"_
M_```#P```,K\```0````VOP```<```#K_```#@```//\```%`````OT``!L`
M```(_0``"````"3]```&````+?T``!0````T_0``$0```$G]```.````6_T`
M`#@```!J_0```@```*/]```&````IOT```X```"M_0``!0```+S]```'````
MPOT```X```#*_0``!@```-G]```H````X/T```P````)_@``'````!;^```$
M````,_X``"D````X_@``%P```&+^```?````>OX``%P```":_@``%````/?^
M```^````#/\``!\```!+_P``$````&O_```'````?/\```X```"$_P``#```
M`)/_```,````H/\``!,```"M_P``"@```,'_```=````S/\``!D```#J_P``
M!0````0``0`1````"@`!`!$````<``$`)````"X``0`2````4P`!`!4```!F
M``$`$@```'P``0`.````CP`!`!D```">``$`"````+@``0`)````P0`!``T`
M``#+``$`!P```-D``0`*````X0`!``<```#L``$`#P```/0``0`&````!`$!
M``L````+`0$`&@```!<!`0`*````,@$!``<````]`0$`"````$4!`0`%````
M3@$!`!\```!4`0$`!@```'0!`0`0````>P$!``@```",`0$`#0```)4!`0`(
M````HP$!`!X```"L`0$`$@```,L!`0`L````W@$!`!H````+`@$`"0```"8"
M`0`*````,`(!`!4````[`@$`!0```%$"`0`4````5P(!``0```!L`@$`$```
M`'$"`0`&````@@(!``<```")`@$`'@```)$"`0`H````L`(!``H```#9`@$`
M'````.0"`0`1`````0,!``L````3`P$`&@```!\#`0`4````.@,!``0```!/
M`P$`!````%0#`0`+````60,!``4```!E`P$`!@```&L#`0`(````<@,!``8`
M``![`P$`"@```((#`0`;````C0,!`#0```"I`P$`-````-X#`0`@````$P0!
M`"D````T!`$`(````%X$`0!!````?P0!`!H```#!!`$`*````-P$`0`I````
M!04!`%`````O!0$`(@```(`%`0`&````HP4!``@```"J!0$`!0```+,%`0`(
M````N04!`!D```#"!0$`&0```-P%`0`J````]@4!`",````A!@$`&0```$4&
M`0`N````7P8!`#0```".!@$`"````,,&`0`7````S`8!``H```#D!@$`!P``
M`.\&`0`A````]P8!`!`````9!P$`#@```"H'`0`+````.0<!``<```!%!P$`
M$P```$T'`0`(````80<!``L```!J!P$`"@```'8'`0`4````@0<!``\```"6
M!P$`,@```*8'`0`+````V0<!``X```#E!P$`!0```/0'`0`%````^@<!``4`
M````"`$`%P````8(`0`/````'@@!``0````N"`$`"@```#,(`0`)````/@@!
M``L```!("`$`#0```%0(`0`,````8@@!``X```!O"`$`!0```'X(`0`$````
MA`@!``T```")"`$`,@```)<(`0!%````R@@!`!<````0"0$`!P```"@)`0`>
M````,`D!`!0```!/"0$`!0```&0)`0`4````:@D!``8```!_"0$`!P```(8)
M`0`.````C@D!`"H```"="0$`!@```,@)`0`,````SPD!``T```#<"0$`$0``
M`.H)`0`+````_`D!`#8````("@$`"@```#\*`0`B````2@H!``L```!M"@$`
M#P```'D*`0`R````B0H!`"4```"\"@$`,````.(*`0`Q````$PL!`"T```!%
M"P$`#@```',+`0`%````@@L!``X```"("P$`$P```)<+`0`2````JPL!``<`
M``"^"P$`$0```,8+`0`3````V`L!``<```#L"P$`%````/0+`0`8````"0P!
M``<````B#`$`!0```"H,`0`,````,`P!``P````]#`$`$@```$H,`0`$````
M70P!``<```!B#`$`"@```&H,`0`+````=0P!``P```"!#`$`#@```(X,`0`.
M````G0P!``4```"L#`$`!0```+(,`0`N````N`P!`"8```#G#`$`(P````X-
M`0`#````,@T!`!(````V#0$`!@```$D-`0`>````4`T!`!@```!O#0$`)0``
M`(@-`0`-````K@T!``D```"\#0$`'P```,8-`0`#````Y@T!``<```#J#0$`
M"@```/(-`0`"````_0T!``P`````#@$`%0````T.`0`+````(PX!`!D````O
M#@$`(````$D.`0`2````:@X!``4```!]#@$`"@```(,.`0`5````C@X!`!(`
M``"D#@$`#````+<.`0`$````Q`X!``D```#)#@$`!P```-,.`0`,````VPX!
M`%(```#H#@$`%P```#L/`0`D````4P\!`!(```!X#P$`!P```(L/`0`&````
MDP\!``X```":#P$`#````*D/`0`-````M@\!`!4```#$#P$`$@```-H/`0`/
M````[0\!`!0```#]#P$`"@```!(0`0`;````'1`!`!`````Y$`$`"P```$H0
M`0!I````5A`!`!H```#`$`$`%P```-L0`0`G````\Q`!`!H````;$0$`%P``
M`#81`0`;````3A$!`!D```!J$0$`'P```(01`0`3````I!$!``@```"X$0$`
M!P```,$1`0`(````R1$!``D```#2$0$`%0```-P1`0`-````\A$!`",`````
M$@$`#0```"02`0`3````,A(!``@```!&$@$``P```$\2`0!&````4Q(!`#\`
M``":$@$`-P```-H2`0!7````$A,!``4```!J$P$`'P```'`3`0`O````D!,!
M``H```#`$P$`"````,L3`0`-````U!,!`"T```#B$P$`!````!`4`0!/````
M%10!`"4```!E%`$`'````(L4`0`+````J!0!`!\```"T%`$`'0```-04`0`E
M````\A0!`"`````8%0$`)````#D5`0`@````7A4!``L```!_%0$`!P```(L5
M`0`-````DQ4!``P```"A%0$`%P```*X5`0`&````QA4!`#D```#-%0$`#```
M``<6`0`'````%!8!``D````<%@$`$P```"86`0`)````.A8!``0```!$%@$`
M$````$D6`0`(````6A8!``@```!C%@$`!````&P6`0`+````<18!``P```!]
M%@$`$@```(H6`0`1````G18!``P```"O%@$`&@```+P6`0`/````UQ8!``<`
M``#G%@$`#0```.\6`0`4````_18!``X````2%P$`#````"$7`0`;````+A<!
M`"P```!*%P$`$P```'<7`0`<````BQ<!`"@```"H%P$`!@```-$7`0`'````
MV!<!`!,```#@%P$`!0```/07`0`$````^A<!`!<```#_%P$`"@```!<8`0`,
M````(A@!``D````O&`$`!@```#D8`0`)````0!@!``@```!*&`$`"0```%,8
M`0`*````71@!`!$```!H&`$`!@```'H8`0`.````@1@!``X```"0&`$`#0``
M`)\8`0`+````K1@!`!T```"Y&`$`"P```-<8`0`"````XQ@!`!P```#F&`$`
M!P````,9`0`&````"QD!`&4````2&0$`"0```'@9`0`'````@AD!`"8```"*
M&0$`.````+$9`0`:````ZAD!`"H````%&@$`.P```#`:`0`H````;!H!`#0`
M``"5&@$`&0```,H:`0`5````Y!H!``4```#Z&@$`!P`````;`0`(````"!L!
M``<````1&P$`!0```!D;`0`'````'QL!``X````G&P$`"0```#8;`0`&````
M0!L!``@```!'&P$`"P```%`;`0`'````7!L!``@```!D&P$`!P```&T;`0`6
M````=1L!``D```",&P$`!@```)8;`0`+````G1L!`!````"I&P$`!@```+H;
M`0`<````P1L!`!0```#>&P$`!P```/,;`0`1````^QL!``@````-'`$`#@``
M`!8<`0`(````)1P!``4````N'`$`$````#0<`0`)````11P!`!````!/'`$`
M!@```&`<`0`9````9QP!``H```"!'`$`'````(P<`0`'````J1P!``4```"Q
M'`$`$````+<<`0`4````R!P!``L```#='`$`#0```.D<`0`H````]QP!`!@`
M```@'0$`%P```#D=`0`$````41T!``D```!6'0$`"@```&`=`0`'````:QT!
M``(```!S'0$`#@```'8=`0`(````A1T!`!\```".'0$`(P```*X=`0`?````
MTAT!`#@```#R'0$`)@```"L>`0`Q````4AX!`"<```"$'@$`9````*P>`0`4
M````$1\!`%4````F'P$`.````'P?`0!*````M1\!`%L`````(`$`*````%P@
M`0`X````A2`!`"@```"^(`$`+````.<@`0`G````%"$!`!L````\(0$`/@``
M`%@A`0"I`0``ER$!`",```!!(P$`%P```&4C`0!(````?2,!`(4```#&(P$`
M,````$PD`0`E````?20!`$$```"C)`$`6P```.4D`0!)````024!`#$```"+
M)0$`'0```+TE`0`8````VR4!`"L```#T)0$`(0```"`F`0`?````0B8!`"L`
M``!B)@$`)@```(XF`0`A````M28!`"<```#7)@$`.@```/\F`0`=````.B<!
M`!$```!8)P$`,P```&HG`0`E````GB<!`"<```#$)P$`(````.PG`0`?````
M#2@!`#`````M*`$`:0```%XH`0`Q````R"@!`$$```#Z*`$`,P```#PI`0`E
M````<"D!`#T```"6*0$`90```-0I`0!-````.BH!`"\```"(*@$`+@```+@J
M`0`P````YRH!`%0````8*P$`6@```&TK`0!(````R"L!`$H````1+`$`,@``
M`%PL`0`O````CRP!`"P```"_+`$`+0```.PL`0!Q````&BT!`&8```",+0$`
M;P```/,M`0"S````8RX!`!<````7+P$`)0```"\O`0`R````52\!`"D```"(
M+P$`/@```+(O`0`B````\2\!`%(````4,`$`)0```&<P`0`+````C3`!`+$`
M``"9,`$`10```$LQ`0`A````D3$!`#````"S,0$`)0```.0Q`0`<````"C(!
M`#$````G,@$`!P```%DR`0`'````83(!``0```!I,@$`#0```&XR`0`+````
M?#(!``X```"(,@$`"P```)<R`0`%````HS(!`!````"I,@$``@```+HR`0!9
M````O3(!``4````7,P$`$@```!TS`0`$````,#,!``<````U,P$`"````#TS
M`0`%````1C,!`#````!,,P$``P```'TS`0`0````@3,!``P```"2,P$`$P``
M`)\S`0`-````LS,!``(```#!,P$`!P```,0S`0`&````S#,!`!0```#3,P$`
M#````.@S`0`8````]3,!``8````.-`$`$@```!4T`0`,````*#0!``,````U
M-`$`*@```#DT`0`$````9#0!``8```!I-`$`!P```'`T`0`?````>#0!`#4`
M``"8-`$`+@```,XT`0`O````_30!`!<````M-0$`(@```$4U`0`E````:#4!
M`"````".-0$`&P```*\U`0`8````RS4!`"0```#D-0$`'P````DV`0`:````
M*38!`"$```!$-@$`(````&8V`0`:````AS8!`#(```"B-@$`&@```-4V`0`O
M````\#8!`"L````@-P$`'P```$PW`0`C````;#<!`!\```"0-P$`&@```+`W
M`0`A````RS<!`"4```#M-P$`)@```!,X`0`E````.C@!`"0```!@.`$`&```
M`(4X`0`=````GC@!`"0```"\.`$`&````.$X`0`B````^C@!`"P````=.0$`
M+P```$HY`0`5````>CD!`"4```"0.0$`/````+8Y`0`?````\SD!`",````3
M.@$`'P```#<Z`0`@````5SH!`!H```!X.@$`&````),Z`0`F````K#H!`!X`
M``#3.@$`*0```/(Z`0`>````'#L!`#$````[.P$`"0```&T[`0`,````=SL!
M`!<```"$.P$`+P```)P[`0`D````S#L!``<```#Q.P$`#P```/D[`0`4````
M"3P!``X````>/`$`#0```"T\`0`D````.SP!``4```!@/`$`!P```&8\`0`B
M````;CP!`"4```"1/`$`&@```+<\`0`=````TCP!`!H```#P/`$`!P````L]
M`0#'````$ST!``L```#;/0$`%0```.<]`0`&````_3T!``D````$/@$`"P``
M``X^`0`-````&CX!`!<````H/@$`!@```$`^`0`S````1SX!`!,```![/@$`
M$P```(\^`0`'````HSX!``\```"K/@$`!P```+L^`0`R````PSX!``0```#V
M/@$`(0```/L^`0`3````'3\!``P````Q/P$`$0```#X_`0`R````4#\!`!8`
M``"#/P$`"````)H_`0`=````HS\!``D```#!/P$`"@```,L_`0`4````UC\!
M``H```#K/P$`'0```/8_`0`(````%$`!`!\````=0`$`"````#U``0`:````
M1D`!`"<```!A0`$`!@```(E``0`5````D$`!``<```"F0`$`"````*Y``0`)
M````MT`!`#\```#!0`$`!P````%!`0`/````"4$!``X````900$`$````"A!
M`0`)````.4$!``D```!#00$`"````$U!`0`3````5D$!``<```!J00$`&0``
M`')!`0`*````C$$!`!<```"700$`%````*]!`0`*````Q$$!``P```#/00$`
M%P```-Q!`0`$````]$$!`"H```#Y00$`#````"1"`0`1````,4(!``<```!#
M0@$``@```$M"`0`0````3D(!`!@```!?0@$`"P```'A"`0`#````A$(!``@`
M``"(0@$`!@```)%"`0`'````F$(!``T```"@0@$`"P```*Y"`0`4````ND(!
M`!4```#/0@$`#@```.5"`0`O````]$(!`"`````D0P$`'````$5#`0`5````
M8D,!``P```!X0P$`,0```(5#`0`%````MT,!`!(```"]0P$`/P```-!#`0`2
M````$$0!``H````C1`$`!@```"Y$`0`$````-40!``0````Z1`$`"@```#]$
M`0`3````2D0!``4```!>1`$`!@```&1$`0`&````:T0!``@```!R1`$`!```
M`'M$`0`,````@$0!``H```"-1`$`.0```)A$`0`N````TD0!`"D````!10$`
M!0```"M%`0`8````,44!`!D```!*10$`'P```&1%`0`=````A$4!`!$```"B
M10$``@```+1%`0`$````MT4!``H```"\10$`!@```,=%`0`%````SD4!``,`
M``#410$`#````-A%`0!%````Y44!`#(````K1@$`&@```%Y&`0`U````>48!
M`"@```"O1@$`4P```-A&`0`9````+$<!`'(```!&1P$`(````+E'`0`U````
MVD<!`"$````02`$`10```#)(`0`P````>$@!`"@```"I2`$`*0```-)(`0`F
M````_$@!`"4````C20$`*````$E)`0`H````<DD!`"(```";20$`*P```+Y)
M`0`P````ZDD!`!(````;2@$`$P```"Y*`0`0````0DH!`'D```!32@$`"0``
M`,U*`0"A````UTH!`',```!Y2P$`?````.U+`0`K````:DP!`%0```"63`$`
M%P```.M,`0`G`````TT!`!8````K30$`#P```$)-`0`7````4DT!`!\```!J
M30$`0````(I-`0`?````RTT!`!P```#K30$`40````A.`0`:````6DX!`!0`
M``!U3@$`"@```(I.`0`%````E4X!``8```";3@$`"````*).`0`%````JTX!
M`!(```"Q3@$`$````,1.`0`3````U4X!`!T```#I3@$`#P````=/`0`/````
M%T\!``0````G3P$`"0```"Q/`0`+````-D\!``<```!"3P$`!0```$I/`0`4
M````4$\!``<```!E3P$`"````&U/`0`/````=D\!``@```"&3P$`#````(]/
M`0`/````G$\!``8```"L3P$`%````+-/`0`&````R$\!``P```#/3P$`$0``
M`-Q/`0`(````[D\!``0```#W3P$`&0```/Q/`0`1````%E`!``H````H4`$`
M&````#-0`0`3````3%`!`!P```!@4`$`$0```'U0`0`$````CU`!``\```"4
M4`$`!P```*10`0`$````K%`!`!D```"Q4`$`!P```,M0`0`"````TU`!``(`
M``#64`$`$0```-E0`0`)````ZU`!``8```#U4`$`$@```/Q0`0`7````#U$!
M``8````G40$`)P```"Y1`0`"````5E$!``0```!940$`#P```%Y1`0`3````
M;E$!``<```""40$`!P```(I1`0`1````DE$!``8```"D40$`&````*M1`0`&
M````Q%$!`!,```#+40$`$````-]1`0`2````\%$!``(````#4@$`!@````92
M`0`5````#5(!``P````C4@$`"0```#!2`0`1````.E(!``D```!,4@$`(@``
M`%92`0`'````>5(!``<```"!4@$`"P```(E2`0`%````E5(!``(```";4@$`
M"P```)Y2`0!<`0``JE(!`!(````'5`$`#P```!I4`0`2````*E0!``<````]
M5`$`"````$54`0`'````3E0!``L```!65`$`%0```&)4`0`;````>%0!`"@`
M``"45`$`'````+U4`0`>````VE0!`!T```#Y5`$`$P```!=5`0`I````*U4!
M``L```!550$`(@```&%5`0`1````A%4!``\```"650$`#````*95`0`%````
MLU4!`!D```"Y50$`#````--5`0`3````X%4!`!0```#T50$`$@````E6`0`2
M````'%8!`%H````O5@$`$0```(I6`0`*````G%8!``T```"G5@$`$````+56
M`0`:````QE8!`!0```#A5@$`$P```/96`0`5````"E<!``8````@5P$`FP``
M`"=7`0`-````PU<!`!(```#15P$`%@```.17`0`*````^U<!`!$````&6`$`
M$0```!A8`0`(````*E@!``@````S6`$`(````#Q8`0`3````75@!`#$```!Q
M6`$`-````*-8`0!8````V%@!`%,````Q60$`7@```(59`0!9````Y%D!`#,`
M```^6@$`"@```'):`0`-````?5H!``<```"+6@$`"@```)-:`0`1````GEH!
M``4```"P6@$`!@```+9:`0`2````O5H!``<```#06@$`"0```-A:`0`)````
MXEH!`"L```#L6@$`*````!A;`0`*````05L!``X```!,6P$`$0```%M;`0`/
M````;5L!``0```!]6P$`#@```();`0`.````D5L!``H```"@6P$`#@```*M;
M`0`.````NEL!`!0```#)6P$`%````-Y;`0`2````\UL!``H````&7`$`$0``
M`!%<`0`)````(UP!`!\````M7`$`&````$U<`0`<````9EP!``T```"#7`$`
M3P```)%<`0`M````X5P!`"$````/70$`!P```#%=`0`.````.5T!`"<```!(
M70$`!@```'!=`0`'````=UT!``H```!_70$`"````(I=`0`(````DUT!``4`
M``"<70$`!P```*)=`0`(````JET!``0```"S70$`&P```+A=`0`+````U%T!
M``P```#@70$`#P```.U=`0`3````_5T!`"0````17@$`#@```#9>`0`8````
M15X!`!L```!>7@$`'P```'I>`0`=````FEX!`!4```"X7@$`%````,Y>`0`.
M````XUX!`!L```#R7@$`%`````Y?`0`'````(U\!``<````K7P$`"````#-?
M`0`3````/%\!``8```!07P$`"@```%=?`0`2````8E\!``@```!U7P$`$P``
M`'Y?`0`6````DE\!`!0```"I7P$`!P```+Y?`0`1````QE\!``8```#87P$`
M%@```-]?`0`.````]E\!``P````%8`$`-````!)@`0!&````1V`!``H```".
M8`$`"````)E@`0`4````HF`!``4```"W8`$`!0```+U@`0`-````PV`!``\`
M``#18`$`'0```.%@`0`F````_V`!``8````F80$`(````"UA`0`@````3F$!
M`!P```!O80$`&@```(QA`0`*````IV$!``8```"R80$`"@```+EA`0`'````
MQ&$!`#````#,80$`,````/UA`0`O````+F(!`%$```!>8@$`+@```+!B`0`N
M````WV(!`#\````.8P$`0````$YC`0`N````CV,!`#4```"^8P$`*````/1C
M`0`D````'60!`#P```!"9`$`+@```']D`0`T````KF0!`!0```#C9`$`&```
M`/AD`0`F````$64!`"0````X90$`)````%UE`0`3````@F4!``P```"690$`
M$````*-E`0`%````M&4!``L```"Z90$`&````,9E`0`<````WV4!``8```#\
M90$`!P````-F`0`3````"V8!``H````?9@$`"````"IF`0`F````,V8!``@`
M``!:9@$`"0```&-F`0`&````;68!``8```!T9@$`!0```'MF`0`'````@68!
M``8```")9@$`"0```)!F`0`F````FF8!``\```#!9@$`"@```-%F`0`)````
MW&8!``@```#F9@$`#````.]F`0`(````_&8!``T````%9P$`"@```!-G`0`7
M````'F<!``<````V9P$`"````#YG`0`$````1V<!``L```!,9P$`"0```%AG
M`0`@````8F<!`!(```"#9P$`"0```)9G`0`'````H&<!``P```"H9P$`!P``
M`+5G`0`*````O6<!``,```#(9P$`'P```,QG`0`3````[&<!`"X`````:`$`
M"````"]H`0`&````.&@!``D````_:`$`!P```$EH`0!'````46@!`!\```"9
M:`$`.@```+EH`0`B````]&@!`!L````7:0$`!@```#-I`0`%````.FD!``4`
M``!`:0$`(````$9I`0`9````9VD!`"X```"!:0$`)````+!I`0`C````U6D!
M`%X```#Y:0$`*````%AJ`0`5````@6H!``@```"7:@$`#@```*!J`0`8````
MKVH!``X```#(:@$`#0```-=J`0`/````Y6H!`!$```#U:@$`#P````=K`0`4
M````%VL!``T````L:P$`$P```#IK`0`'````3FL!`!4```!6:P$`&0```&QK
M`0`7````AFL!`!,```">:P$`%P```+)K`0`&````RFL!``4```#1:P$`#@``
M`-=K`0!8````YFL!`%8````_;`$`!````)9L`0`3````FVP!``<```"O;`$`
M!0```+=L`0`;````O6P!`!T```#9;`$`#@```/=L`0`-````!FT!`!$````4
M;0$`&P```"9M`0`N````0FT!``L```!Q;0$`'P```'UM`0`%````G6T!`!H`
M``"C;0$`#P```+YM`0`4````SFT!`!````#C;0$`&````/1M`0`.````#6X!
M`!(````<;@$`$P```"]N`0`)````0VX!``8```!-;@$`#P```%1N`0`&````
M9&X!`!X```!K;@$`#@```(IN`0`3````F6X!``@```"M;@$`!````+9N`0`*
M````NVX!``L```#&;@$`!P```-)N`0`3````VFX!``D```#N;@$`!````/AN
M`0`(````_6X!``H````&;P$`"````!%O`0`(````&F\!``4````C;P$`!P``
M`"EO`0`#````,6\!``,````U;P$`&P```#EO`0!"````56\!`!4```"8;P$`
M"P```*YO`0`0````NF\!``4```#+;P$`&P```-%O`0`/````[6\!`!````#]
M;P$`)`````YP`0`T````,W`!`!T```!H<`$`"0```(9P`0`R````D'`!``D`
M``##<`$`!0```,UP`0`,````TW`!``D```#@<`$`!P```.IP`0`6````\G`!
M``T````)<0$`!P```!=Q`0`*````'W$!``T````J<0$`'P```#AQ`0`D````
M6'$!`"(```!]<0$`)P```*!Q`0`=````R'$!`"````#F<0$`'P````=R`0`D
M````)W(!`"(```!,<@$`+@```&]R`0`B````GG(!`"$```#!<@$`)````.-R
M`0`@````"',!`"<````I<P$`-P```%%S`0`U````B7,!`"L```"_<P$`*P``
M`.MS`0`W````%W0!`"<```!/=`$`$@```'=T`0`N````BG0!`"(```"Y=`$`
M$@```-QT`0`K````[W0!`!\````;=0$`'@```#MU`0`3````6G4!`)(```!N
M=0$`&@````%V`0`I````''8!`"D```!&=@$`*P```'!V`0`H````G'8!`"<`
M``#%=@$`&0```.UV`0`B````!W<!`#`````J=P$`,P```%MW`0`_````CW<!
M`#X```#/=P$`FP````YX`0`3````JG@!`!,```"^>`$`'@```-)X`0`E````
M\7@!`"<````7>0$`/````#]Y`0!"````?'D!`!@```"_>0$`!````-AY`0`(
M````W7D!``,```#F>0$`"0```.IY`0`(````]'D!`!````#]>0$`#@````YZ
M`0`4````'7H!``D````R>@$`!0```#QZ`0`1````0GH!`!0```!4>@$`"```
M`&EZ`0`/````<GH!`!,```"">@$`#````)9Z`0`-````HWH!``X```"Q>@$`
M+````,!Z`0`%````[7H!``L```#S>@$`!@```/]Z`0`3````!GL!`!D````:
M>P$`&P```#1[`0`/````4'L!``(```!@>P$`2P```&-[`0`(````KWL!`!``
M``"X>P$`$````,E[`0`'````VGL!`!$```#B>P$`#@```/1[`0`$`````WP!
M``X````(?`$`"0```!=\`0`.````(7P!`!$````P?`$`"0```$)\`0`.````
M3'P!``\```!;?`$`#P```&M\`0`-````>WP!``<```")?`$`#@```)%\`0`-
M````H'P!``P```"N?`$`#0```+M\`0`9````R7P!``X```#C?`$`#0```/)\
M`0`E`````'T!`!,````F?0$`%P```#I]`0`L````4GT!``P```!_?0$`&@``
M`(Q]`0`6````IWT!`!4```"^?0$`+@```-1]`0`4`````WX!``4````8?@$`
M$@```!Y^`0`)````,7X!`"<````[?@$`*````&-^`0`'````C'X!``H```"4
M?@$`&````)]^`0`+````N'X!`!<```#$?@$`%P```-Q^`0`(````]'X!`!P`
M``#]?@$`#@```!I_`0`:````*7\!`!4```!$?P$`#@```%I_`0`8````:7\!
M``@```""?P$`"P```(M_`0`N````EW\!`#H```#&?P$`"`````&``0`4````
M"H`!`!T````?@`$`"````#V``0`+````1H`!`"@```!2@`$`"````'N``0`'
M````A(`!``8```",@`$`2@```).``0`#````WH`!``<```#B@`$`!0```.J`
M`0`,````\(`!``P```#]@`$`#`````J!`0`,````%X$!``\````D@0$`#@``
M`#2!`0`1````0X$!``\```!5@0$`!P```&6!`0`'````;8$!`$0```!U@0$`
M"P```+J!`0`*````QH$!``(```#1@0$`!@```-2!`0`/````VX$!`"(```#K
M@0$`$@````Z"`0`2````(8(!``<````T@@$`#@```#R"`0`0````2X(!`!<`
M``!<@@$`+@```'2"`0`=````HX(!``H```#!@@$`#P```,R"`0!K````W((!
M`!8```!(@P$`$P```%^#`0`1````<X,!``<```"%@P$`!````(V#`0`7````
MDH,!`"L```"J@P$`+````-:#`0`8`````X0!`!L````<A`$`%````#B$`0`7
M````380!``4```!EA`$`"````&N$`0`)````=(0!``<```!^A`$`%````(:$
M`0`3````FX0!`!4```"OA`$`$P```,6$`0`3````V80!`!8```#MA`$`#```
M``2%`0`0````$84!``<````BA0$`!P```"J%`0`.````,H4!``L```!!A0$`
M,P```$V%`0`0````@84!``D```"2A0$`"P```)R%`0`B````J(4!`!P```#+
MA0$`(@```.B%`0`A````"X8!`!P````MA@$`&P```$J&`0`A````9H8!`!<`
M``"(A@$`%````*"&`0`#````M88!`!P```"YA@$`#````-:&`0`-````XX8!
M``0```#QA@$`!@```/:&`0`(````_88!``L````&AP$`#0```!*'`0`1````
M((<!`!0````RAP$`#````$>'`0`.````5(<!``L```!CAP$`!0```&^'`0`$
M````=8<!`!0```!ZAP$`%0```(^'`0`+````I8<!``H```"QAP$`"P```+R'
M`0`3````R(<!`"$```#<AP$`!P```/Z'`0`%````!H@!``P````,B`$`#P``
M`!F(`0`,````*8@!``@````VB`$`!@```#^(`0`#````1H@!`!@```!*B`$`
M"P```&.(`0`$````;X@!`"4```!TB`$`#@```)J(`0!P````J8@!`!,````:
MB0$`!@```"Z)`0`$````-8D!``H````ZB0$`!@```$6)`0`(````3(D!``@`
M``!5B0$`!P```%Z)`0`"````9HD!``8```!IB0$`"P```'")`0`8````?(D!
M`!(```"5B0$`%````*B)`0`3````O8D!``<```#1B0$`"````-F)`0`2````
MXHD!``<```#UB0$`"````/V)`0`%````!HH!`!@````,B@$`"````"6*`0`&
M````+HH!`!P````UB@$`$0```%**`0`'````9(H!``@```!LB@$`!0```'6*
M`0`)````>XH!``<```"%B@$`#@```(V*`0`$````G(H!``4```"AB@$`#@``
M`*>*`0`-````MHH!``X```#$B@$`!@```-.*`0`3````VHH!``D```#NB@$`
M!P```/B*`0`/`````(L!`"$````0BP$`,P```#*+`0`F````9HL!`"(```"-
MBP$`!@```+"+`0`*````MXL!``0```#"BP$`"@```,>+`0`(````THL!`!``
M``#;BP$`#P```.R+`0`%````_(L!``P````"C`$`"`````^,`0`$````&(P!
M`#\````=C`$`00```%V,`0`_````GXP!`!L```#?C`$`!@```/N,`0`,````
M`HT!``0````/C0$`!````!2-`0`&````&8T!`!\````@C0$`#P```$"-`0`6
M````4(T!``8```!GC0$``P```&Z-`0`6````<HT!``<```")C0$`"````)&-
M`0`3````FHT!``4```"NC0$`"````+2-`0`=````O8T!``D```#;C0$`#@``
M`.6-`0`,````](T!``X````!C@$`"0```!".`0`(````&HX!``4````CC@$`
M+````"F.`0`M````5HX!`#<```"$C@$`)P```+R.`0`^````Y(X!`#8````C
MCP$`*0```%J/`0`\````A(\!`"\```#!CP$`+P```/&/`0`?````(9`!``\`
M``!!D`$`%P```%&0`0`.````:9`!`"<```!XD`$`)````*"0`0`<````Q9`!
M`"(```#BD`$`!P````61`0`(````#9$!``H````6D0$`!@```"&1`0`A````
M*)$!`"4```!*D0$`*````'"1`0`*````F9$!`!8```"DD0$`*````+N1`0`6
M````Y)$!``\```#[D0$`!@````N2`0`.````$I(!``H````AD@$`$````"R2
M`0`1````/9(!`#D```!/D@$`>P```(F2`0!X````!9,!``\```!^DP$`"0``
M`(Z3`0`*````F),!``X```"CDP$`#P```+*3`0`3````PI,!``8```#6DP$`
M#P```-V3`0`3````[9,!`!(````!E`$`$0```!24`0`;````)I0!`"````!"
ME`$`7P```&.4`0`2````PY0!``4```#6E`$`$0```-R4`0`*````[I0!``0`
M``#YE`$`#0```/Z4`0`>````#)4!`!(````KE0$`"0```#Z5`0`*````2)4!
M``X```!3E0$`$````&*5`0`D````<Y4!`"(```"8E0$`(0```+N5`0`?````
MW94!`"$```#]E0$`'P```!^6`0`7````/Y8!`#@```!7E@$`$@```)"6`0`0
M````HY8!`!$```"TE@$`#P```,:6`0`+````UI8!`!````#BE@$`#@```/.6
M`0`0`````I<!``X````3EP$`(0```"*7`0`/````1)<!``\```!4EP$`+P``
M`&27`0`2````E)<!``<```"GEP$`$P```*^7`0`>````PY<!`!,```#BEP$`
M$````/:7`0`-````!Y@!`!D````5F`$`$P```"^8`0`1````0Y@!`!4```!5
MF`$`&````&N8`0`/````A)@!`!L```"4F`$`(0```+"8`0`1````TI@!`!(`
M``#DF`$`$0```/>8`0`1````"9D!`!(````;F0$`%0```"Z9`0`4````1)D!
M`!<```!9F0$`"````'&9`0`*````>ID!`!4```"%F0$`!0```)N9`0`'````
MH9D!``D```"IF0$`%````+.9`0`'````R)D!``H```#0F0$`"````-N9`0`'
M````Y)D!``<```#LF0$`!P```/29`0`&````_)D!`!4````#F@$`4@```!F:
M`0`&````;)H!``D```!SF@$`!0```'V:`0`%````@YH!``@```")F@$`!P``
M`)*:`0`(````FIH!``@```"CF@$`"````*R:`0`)````M9H!`!(```"_F@$`
M!@```-*:`0`B````V9H!``\```#\F@$`#0````R;`0`/````&IL!``P````J
MFP$`"@```#>;`0`-````0IL!`"8```!0FP$`!@```'>;`0`(````?IL!`"``
M``"'FP$`#@```*B;`0`.````MYL!``8```#&FP$`"@```,V;`0`)````V)L!
M``0```#BFP$`(````.>;`0`,````")P!`!8````5G`$`#P```"R<`0`1````
M/)P!`!0```!.G`$`(@```&.<`0`>````AIP!``0```"EG`$`!@```*J<`0`(
M````L9P!`"$```"ZG`$`"````-R<`0`%````Y9P!``H```#KG`$`$0```/:<
M`0`'````")T!``0````0G0$`"````!6=`0`7````'IT!``T````VG0$`#0``
M`$2=`0`)````4IT!`!8```!<G0$`$P```'.=`0`-````AYT!`!(```"5G0$`
M#@```*B=`0`.````MYT!``<```#&G0$`!````,Z=`0`5````TYT!`#(```#I
MG0$`!@```!R>`0`.````(YX!`"`````RG@$`%````%.>`0`8````:)X!`!``
M``"!G@$`#````)*>`0`)````GYX!``<```"IG@$`"@```+&>`0`)````O)X!
M``X```#&G@$`$````-6>`0`J````YIX!`"D````1GP$`)P```#N?`0`)````
M8Y\!``4```!MGP$`!P```'.?`0`-````>Y\!``X```")GP$`!P```)B?`0`*
M````H)\!`!X```"KGP$`"@```,J?`0`,````U9\!`!,```#BGP$`/P```/:?
M`0`5````-J`!``H```!,H`$`"````%>@`0`%````8*`!`!$```!FH`$`$0``
M`'B@`0`6````BJ`!``H```"AH`$``@```*R@`0`$````KZ`!`"4```"TH`$`
M`P```-J@`0`%````WJ`!`"@```#DH`$`"@````VA`0`&````&*$!``8````?
MH0$`%````":A`0`)````.Z$!``8```!%H0$`"````$RA`0`)````5:$!``0`
M``!?H0$`!0```&2A`0!I````:J$!``L```#4H0$`#@```."A`0`7````[Z$!
M``4````'H@$`!`````VB`0`?````$J(!`"D````RH@$`$````%RB`0`*````
M;:(!``X```!XH@$`"P```(>B`0`*````DZ(!`!<```">H@$`'0```+:B`0`F
M````U*(!`"4```#[H@$`'````"&C`0`-````/J,!``,```!,HP$`!P```%"C
M`0`)````6*,!``<```!BHP$`#0```&JC`0`.````>*,!``4```"'HP$`4P``
M`(VC`0`1````X:,!``H```#SHP$`"0```/ZC`0`<````"*0!`$4````EI`$`
M%P```&ND`0`&````@Z0!`!\```"*I`$`,0```*JD`0`&````W*0!``<```#C
MI`$`&````.ND`0`'````!*4!``D````,I0$`)@```!:E`0`D````/:4!`"<`
M``!BI0$`"````(JE`0`+````DZ4!`"````"?I0$`8@```,"E`0`1````(Z8!
M`"`````UI@$`%````%:F`0`"````:Z8!``\```!NI@$`"````'ZF`0`0````
MAZ8!``D```"8I@$`!````**F`0`0````IZ8!``8```"XI@$`"0```+^F`0`,
M````R:8!``D```#6I@$`"@```."F`0`)````ZZ8!`"L```#UI@$`!@```"&G
M`0`/````**<!`!`````XIP$`&P```$FG`0`;````9:<!``L```"!IP$`#P``
M`(VG`0`/````G:<!``L```"MIP$`"P```+FG`0`+````Q:<!``D```#1IP$`
M%0```-NG`0`1````\:<!``4````#J`$`"@````FH`0`/````%*@!``P````D
MJ`$`%@```#&H`0`'````2*@!`!(```!0J`$`!````&.H`0`(````:*@!``4`
M``!QJ`$`!@```'>H`0`'````?J@!`!$```"&J`$`$0```)BH`0`9````JJ@!
M`!8```#$J`$`%0```-NH`0`6````\:@!`!D````(J0$`(````"*I`0`:````
M0ZD!``0```!>J0$`#````&.I`0`.````<*D!``X```!_J0$`#@```(ZI`0`'
M````G:D!`",```"EJ0$`"P```,FI`0`,````U:D!`!8```#BJ0$`&@```/FI
M`0`3````%*H!``<````HJ@$`!@```#"J`0`(````-ZH!`!$```!`J@$`$```
M`%*J`0`)````8ZH!``H```!MJ@$`!0```'BJ`0`(````?JH!``(```"'J@$`
M!````(JJ`0`"````CZH!`#@```"2J@$`(@```,NJ`0`,````[JH!`!T```#[
MJ@$`,@```!FK`0`1````3*L!`"<```!>JP$`&````(:K`0`=````GZL!`!T`
M``"]JP$`(@```-NK`0`6````_JL!`!,````5K`$`#P```"FL`0`1````.:P!
M`!(```!+K`$`$0```%ZL`0`-````<*P!``P```!^K`$`#@```(NL`0`6````
MFJP!`"$```"QK`$`(0```-.L`0`E````]:P!`"(````;K0$`(P```#ZM`0`@
M````8JT!`&4```"#K0$`&P```.FM`0`1````!:X!``@````7K@$`%P```""N
M`0`0````.*X!`!0```!)K@$`)P```%ZN`0`I````AJX!`"4```"PK@$`$@``
M`-:N`0!'````Z:X!`$8````QKP$`"0```'BO`0`)````@J\!`!<```",KP$`
M#0```*2O`0`-````LJ\!`!4```#`KP$`!0```-:O`0`0````W*\!``\```#M
MKP$`#P```/VO`0`/````#;`!``D````=L`$`$````">P`0`'````.+`!`"$`
M``!`L`$`"````&*P`0`#````:[`!``L```!OL`$`#````'NP`0`*````B+`!
M`#L```"3L`$``@```,^P`0`&````TK`!``T```#9L`$`#P```.>P`0`(````
M][`!``X`````L0$`"@````^Q`0`K````&K$!`!$```!&L0$`'@```%BQ`0`%
M````=[$!`"P```!]L0$`&0```*JQ`0`F````Q+$!`%4```#KL0$`#@```$&R
M`0!$````4+(!`!L```"5L@$`$P```+&R`0`&````Q;(!``T```#,L@$`$P``
M`-JR`0`.````[K(!``@```#]L@$`!`````:S`0`4````"[,!`!P````@LP$`
M`P```#VS`0`(````0;,!``\```!*LP$`(````%JS`0`/````>[,!`!,```"+
MLP$`%````)^S`0`/````M+,!`",```#$LP$`"````.BS`0`,````\;,!``T`
M``#^LP$`!P````RT`0`,````%+0!``<````AM`$`$````"FT`0`(````.K0!
M``T```!#M`$`%0```%&T`0`-````9[0!``4```!UM`$`"````'NT`0`%````
MA+0!`",```"*M`$`!@```*ZT`0`0````M;0!``@```#&M`$`$0```,^T`0`(
M````X;0!`!(```#JM`$`#0```/VT`0`I````"[4!`!0````UM0$`"0```$JU
M`0`*````5+4!`!H```!?M0$`!0```'JU`0`3````@+4!``<```"4M0$`%0``
M`)RU`0`(````LK4!``D```"[M0$`$P```,6U`0`>````V;4!``4```#XM0$`
M&@```/ZU`0`3````&;8!``<````MM@$`#@```#6V`0`,````1+8!``4```!1
MM@$`#````%>V`0`*````9+8!``<```!OM@$`!0```'>V`0`(````?;8!``<`
M``"&M@$`"@```(ZV`0`6````F;8!`"L```"PM@$`,````-RV`0`5````#;<!
M`"(````CMP$`'0```$:W`0`W````9+<!`!8```"<MP$`$P```+.W`0`D````
MQ[<!`$D```#LMP$`'````#:X`0`%````4[@!``D```!9N`$`"@```&.X`0`(
M````;K@!`!0```!WN`$`%0```(RX`0`K````HK@!`!H```#.N`$`%P```.FX
M`0`O`````;D!`#4````QN0$`!P```&>Y`0`3````;[D!``@```"#N0$`"```
M`(RY`0`9````E;D!``\```"ON0$`#@```+^Y`0`-````SKD!``@```#<N0$`
M$P```.6Y`0`)````^;D!``X````#N@$`"P```!*Z`0`6````'KH!`!(````U
MN@$`)P```$BZ`0`+````<+H!`!X```!\N@$`!0```)NZ`0`&````H;H!``<`
M``"HN@$`&@```+"Z`0`%````R[H!``0```#1N@$`#0```-:Z`0`*````Y+H!
M``<```#ON@$`#````/>Z`0`,````!+L!``T````1NP$`"````!^[`0`#````
M*+L!``D````LNP$`,P```#:[`0!#````:KL!`!@```"NNP$`"0```,>[`0`G
M````T;L!`!D```#YNP$`#P```!.\`0`.````([P!``H````RO`$`"````#V\
M`0`0````1KP!`"H```!7O`$`!P```(*\`0`-````BKP!``T```"8O`$`$```
M`*:\`0`,````M[P!`#D```#$O`$`!P```/Z\`0`3````!KT!`!`````:O0$`
M%````"N]`0`V````0+T!`!T```!WO0$`(P```)6]`0`D````N;T!`"````#>
MO0$`$````/^]`0`(````$+X!``X````9O@$`%@```"B^`0`5````/[X!``D`
M``!5O@$`$@```%^^`0`2````<KX!``<```"%O@$`&P```(V^`0`;````J;X!
M``L```#%O@$`!0```-&^`0`*````U[X!`!$```#BO@$`#@```/2^`0`$````
M`[\!``@````(OP$`"0```!&_`0`.````&[\!``X````JOP$`"@```#F_`0`*
M````1+\!``4```!/OP$`!@```%6_`0`N````7+\!`"4```"+OP$`(P```+&_
M`0`'````U;\!`!$```#=OP$`!@```.^_`0`?````]K\!`!4````6P`$`(0``
M`"S``0`/````3L`!``P```!>P`$`(````&O``0`#````C,`!``@```"0P`$`
M#0```)G``0`"````I\`!``P```"JP`$`%````+?``0`+````S,`!`!@```#8
MP`$`'````/'``0`4````#L$!``4````CP0$`"@```"G!`0`4````-,$!`!8`
M``!)P0$`#0```&#!`0`)````;L$!``T```!XP0$`"P```(;!`0`2````DL$!
M`$\```"EP0$`'P```/7!`0`U````%<(!`!$```!+P@$`!@```%W"`0`&````
M9,(!``\```!KP@$`"P```'O"`0`,````A\(!`!(```"4P@$`#P```*?"`0`+
M````M\(!`!4```##P@$`"0```-G"`0`?````X\(!``L````#PP$`#P````_#
M`0!&````'\,!`!<```!FPP$`&0```'[#`0`B````F,,!`!<```"[PP$`&0``
M`-/#`0`8````[<,!`!`````&Q`$`%````!?$`0`9````+,0!``D```!&Q`$`
M!P```%#$`0`(````6,0!``D```!AQ`$`%````&O$`0`+````@,0!`"4```",
MQ`$`$@```++$`0`8````Q<0!``L```#>Q`$`!````.K$`0!,````[\0!`#T`
M```\Q0$`-@```'K%`0!;````L<4!``D````-Q@$`*P```!?&`0`L````0\8!
M``H```!PQ@$`"0```'O&`0`-````A<8!`#,```"3Q@$`!0```,?&`0!"````
MS<8!`"\````0QP$`)P```$#'`0`-````:,<!`"````!VQP$`%P```)?'`0`E
M````K\<!`!X```#5QP$`(@```/3'`0`=````%\@!``T````UR`$`!P```$/(
M`0`2````2\@!``\```!>R`$`%@```&[(`0`(````A<@!`#D```".R`$`#```
M`,C(`0`%````U<@!``<```#;R`$`$0```./(`0`(````]<@!``8```#^R`$`
M$P````7)`0`)````&<D!``D````CR0$`!````"W)`0`-````,LD!`!$```!`
MR0$`&@```%+)`0`7````;<D!``T```"%R0$`%0```)/)`0`0````J<D!``@`
M``"ZR0$`%````,/)`0`;````V,D!``P```#TR0$`#0````'*`0`:````#\H!
M`"<````JR@$`#0```%+*`0`3````8,H!`!X```!TR@$`"````)/*`0`$````
MG,H!`!(```"AR@$`"0```+3*`0`)````OLH!`!,```#(R@$`#@```-S*`0`,
M````Z\H!``L```#XR@$`!0````3+`0`)````"LL!``@````4RP$`"0```!W+
M`0`*````)\L!`!,````RRP$`!````$;+`0`0````2\L!``T```!<RP$`$@``
M`&K+`0`/````?<L!`!@```"-RP$`"P```*;+`0`"````LLL!`!T```"URP$`
M!0```-/+`0`'````V<L!`&H```#ARP$`"0```$S,`0`*````5LP!`!D```!A
MS`$`)0```'O,`0`3````H<P!`!X```"US`$`1P```-3,`0`P````',T!`#@`
M``!-S0$`%P```(;-`0`7````GLT!``8```"VS0$`#0```+W-`0`+````R\T!
M``X```#7S0$`$0```.;-`0`+````^,T!`!,````$S@$`#0```!C.`0`.````
M)LX!`!`````US@$`"0```$;.`0`$````4,X!``@```!5S@$`#0```%[.`0`5
M````;,X!``D```""S@$`!@```(S.`0`'````D\X!`"$```";S@$`!@```+W.
M`0`<````Q,X!`!<```#AS@$`"@```/G.`0`5````!,\!``X````:SP$`%P``
M`"G/`0`(````0<\!``4```!*SP$`#P```%#/`0`-````8,\!``\```!NSP$`
M!@```'[/`0`6````A<\!``L```"<SP$`%P```*C/`0`*````P,\!``0```#+
MSP$`#@```-#/`0`:````W\\!``L```#ZSP$`#0````;0`0`J````%-`!`!4`
M```_T`$`#@```%70`0`%````9-`!``P```!JT`$`#@```'?0`0`'````AM`!
M``(```".T`$`#0```)'0`0`#````G]`!`!,```"CT`$`'0```+?0`0`C````
MU=`!`#````#YT`$`(@```"K1`0`E````3=$!`"````!ST0$`4@```)31`0`3
M````Y]$!`$H```#[T0$`+@```$;2`0!'````==(!`$8```"]T@$`'0````33
M`0`M````(M,!`"4```!0TP$`+@```';3`0`F````I=,!`!L```#,TP$`+```
M`.C3`0#7`0``%=0!`!X```#MU0$`$0````S6`0!%````'M8!`'4```!DU@$`
M+````-K6`0`;````!]<!`#$````CUP$`5P```%77`0!-````K=<!`!T```#[
MUP$`&@```!G8`0`1````--@!`!T```!&V`$`&@```&38`0`;````?]@!`!X`
M``";V`$`'P```+K8`0`:````VM@!`!\```#UV`$`,````!79`0`>````1MD!
M`!,```!EV0$`*@```'G9`0`D````I-D!`"4```#)V0$`)````._9`0`9````
M%-H!`"<````NV@$`6````%;:`0`K````K]H!`#\```#;V@$`+@```!O;`0`B
M````2ML!`#H```!MVP$`7````*C;`0!'````!=P!`"8```!-W`$`*````'3<
M`0`M````G=P!`$L```#+W`$`6P```!?=`0!#````<]T!`$0```"WW0$`+@``
M`/S=`0`F````*]X!`"0```!2W@$`)P```'?>`0!G````G]X!`%T````'WP$`
M9@```&7?`0"R````S-\!`!@```!_X`$`)@```)C@`0`T````O^`!`"T```#T
MX`$`0@```"+A`0`B````9>$!`$0```"(X0$`'P```,WA`0`*````[>$!`*T`
M``#XX0$`/@```*;B`0`@````Y>(!`#4````&XP$`)@```#SC`0`?````8^,!
M`",```"#XP$`!````*?C`0`(````K.,!``,```"UXP$`"P```+GC`0`*````
MQ>,!``D```#0XP$`"0```-KC`0`(````Y.,!`!(```#MXP$`!P````#D`0!:
M````".0!``0```!CY`$`$0```&CD`0`$````>N0!``<```!_Y`$`!0```(?D
M`0`%````C>0!`#H```"3Y`$`!````,[D`0`7````T^0!``8```#KY`$`$@``
M`/+D`0`-````!>4!``(````3Y0$`"````!;E`0`%````'^4!`!(````EY0$`
M#````#CE`0`/````1>4!``8```!5Y0$`$@```%SE`0`+````;^4!``,```![
MY0$`)P```'_E`0`$````I^4!``8```"LY0$`!P```+/E`0`>````N^4!`#8`
M``#:Y0$`(P```!'F`0`D````->8!`!H```!:Y@$`+0```'7F`0`P````H^8!
M`!X```#4Y@$`'P```//F`0`=````$^<!`"(````QYP$`'0```%3G`0`9````
M<N<!`!\```",YP$`'````*SG`0`6````R><!`"P```#@YP$`&@````WH`0`I
M````*.@!`"0```!2Z`$`(0```'?H`0`C````F>@!`"````"]Z`$`'0```-[H
M`0`A````_.@!`"@````>Z0$`*````$?I`0`C````<.D!`"(```"4Z0$`'P``
M`+?I`0`<````U^D!`"(```#TZ0$`&0```!?J`0`?````,>H!`"P```!1Z@$`
M+P```'[J`0`9````KNH!`"(```#(Z@$`.0```.OJ`0`E````)>L!`"<```!+
MZP$`)0```'/K`0`H````F>L!`"$```#"ZP$`'P```.3K`0`J````!.P!`"``
M```O[`$`*P```%#L`0`F````?.P!`#,```"C[`$`$@```-?L`0`.````ZNP!
M`!T```#Y[`$`+0```!?M`0`;````1>T!``P```!A[0$`#P```&[M`0`6````
M?NT!``T```"5[0$`%````*/M`0`A````N.T!``8```#:[0$`"````.'M`0`C
M````ZNT!`"8````.[@$`&0```#7N`0`C````3^X!`!D```!S[@$`!@```(WN
M`0"\````E.X!``P```!1[P$`$@```%[O`0`'````<>\!``@```!Y[P$`#@``
M`(+O`0`.````D>\!`!L```"@[P$`#@```+SO`0`T````R^\!`!``````\`$`
M%````!'P`0`'````)O`!`!,````N\`$`"P```$+P`0`W````3O`!``@```"&
M\`$`'P```(_P`0`.````K_`!`!(```"^\`$`&````-'P`0`W````ZO`!`!@`
M```B\0$`#````#OQ`0`A````2/$!``T```!J\0$`#0```'CQ`0`4````AO$!
M``H```";\0$`&@```*;Q`0`&````P?$!`"4```#(\0$`"````.[Q`0`G````
M]_$!`"(````?\@$`"0```$+R`0`>````3/(!``<```!K\@$`!P```'/R`0`+
M````>_(!`$(```"'\@$`"P```,KR`0`/````UO(!`!,```#F\@$`%0```/KR
M`0`,````$/,!``H````=\P$`!P```"CS`0`1````,/,!``@```!"\P$`%P``
M`$OS`0`,````8_,!`!(```!P\P$`$````(/S`0`(````E/,!``H```"=\P$`
M%P```*CS`0`'````P/,!`#$```#(\P$`#````/KS`0`0````!_0!``<````8
M]`$``@```"#T`0`,````(_0!`!$````P]`$`"P```$+T`0`$````3O0!``D`
M``!3]`$`#````%WT`0`-````:O0!`!(```!X]`$`$0```(OT`0`2````G?0!
M`!,```"P]`$`#````,3T`0`V````T?0!`"4````(]0$`)@```"[U`0`7````
M5?4!``\```!M]0$`+@```'WU`0`%````K/4!`!(```"R]0$`0````,7U`0`,
M````!O8!``D````3]@$`!@```!WV`0`$````)/8!``0````I]@$`#0```"[V
M`0`5````//8!``4```!2]@$`!@```%CV`0`&````7_8!``T```!F]@$``P``
M`'3V`0`/````>/8!``H```"(]@$`-0```)/V`0`J````R?8!`"<```#T]@$`
M!0```!SW`0`:````(O<!`!\````]]P$`(@```%WW`0`D````@/<!`!$```"E
M]P$``@```+?W`0`$````NO<!``P```"_]P$`"P```,SW`0`&````V/<!``,`
M``#?]P$`#@```./W`0!!````\O<!`"D````T^`$`&````%[X`0`I````=_@!
M`"T```"A^`$`/0```,_X`0`2````#?D!`)`````@^0$`)0```+'Y`0`W````
MU_D!`"`````/^@$`+@```##Z`0`K````7_H!`"$```"+^@$`*@```*WZ`0`I
M````V/H!`"8````"^P$`)0```"G[`0`H````3_L!`",```!X^P$`)0```)S[
M`0`U````POL!`!4```#X^P$`%`````[\`0`)````(_P!`&@````M_`$`"0``
M`);\`0"-````H/P!`'<````N_0$`;P```*;]`0`V````%OX!`%\```!-_@$`
M#@```*W^`0`A````O/X!`!4```#>_@$`$@```/3^`0`>````!_\!`!L````F
M_P$`,0```$+_`0`:````=/\!`!H```"/_P$`2P```*K_`0`9````]O\!`!8`
M```0``(`"P```"<``@`$````,P`"``8````X``(`"````#\``@`%````2``"
M`!<```!.``(`$````&8``@`9````=P`"`"(```"1``(`#P```+0``@`'````
MQ``"``D```#,``(`"0```-8``@`-````X``"``<```#N``(`!````/8``@`2
M````^P`"``L````.`0(`"P```!H!`@`/````)@$"``H````V`0(`"````$$!
M`@`0````2@$"``H```!;`0(`$P```&8!`@`*````>@$"``X```"%`0(`$@``
M`)0!`@`(````IP$"``8```"P`0(`&P```+<!`@`6````TP$"``L```#J`0(`
M%P```/8!`@`/````#@("`!\````>`@(`%0```#X"`@`%````5`("`!````!:
M`@(`!@```&L"`@`$````<@("`!T```!W`@(`"P```)4"`@`"````H0("``(`
M``"D`@(`$@```*<"`@`+````N@("``8```#&`@(`$P```,T"`@`6````X0("
M``4```#X`@(`(````/X"`@`"````'P,"``0````B`P(`#@```"<#`@`3````
M-@,"``<```!*`P(`"0```%(#`@`0````7`,"``<```!M`P(`'````'4#`@`&
M````D@,"`!<```"9`P(`#P```+$#`@`2````P0,"``(```#4`P(`!P```-<#
M`@`7````WP,"``T```#W`P(`$P````4$`@`-````&00"``T````G!`(`,```
M`#4$`@`(````9@0"``8```!O!`(`#@```'8$`@`%````A00"``(```"+!`(`
M"P```(X$`@`!````7`<``#`````L!@``&`4```````"X!```J@8``!X`````
M````"08``.0!``#&!```C`4``"L"````````E`$``*L%````````````````
M``!F!```7@(``",$``#*`````````!T#``"4!````````"$`````````V0(`
M``````"?`@``>`$``)L#```J````[`8```````"3!````````-(!``#*!0``
M:`$``!L!``"/`P```````,`#``";`@``:0$``(('```H````)@(``'\!``#V
M`P```````'H'````````10(``"\%`````````````!L'`````````````+H#
M`````````````'`$``!,````Y@8``$0!````````2P8``#H"``"T`@``I0(`
M``````!/`0``2P(````````=`@``>`<``(("``"F`@``"@<``!@!``!X!```
M``````H!``!!```````````````>!0```````,L```#Z`@``,P```%X&``#/
M`P``GP0``(\%``!>`0```````%L!``!S!```Z@(``/L#``!I`@```````/8$
M````````W0$`````````````<````+\!````````J08``'$#````````````
M`&D%````````+P0``&@&``#$````C0$```P$``#O`P``2@$``'0"``!4`@``
M`````#$``````````````*4`````````"0$``,D&```$````;@4``'L&````
M````IP8``.L&````````&@0``````````````````#0```#C!```LP4`````
M``#1````)P```!<$````````5@0``.@"``!;!```L0,```````#5`@``````
M``````#-`P```00``````````````````#\'```P`@```````-,#``#V`0``
M`````/@"```7`@````````P'````````<`(``%4```#Q`P``O0,``*\%``"Y
M!0``N`$``-@$``"-!0``800``-`%``!.!P```````'0!```*````50<`````
M``!:`0``R@$``$H```#I!@``@0$``+D#``#4`0```````(<&````````R`0`
M`%P!``#`````N@8```````"[!0``9`8``&$```#R`P``2P$``"H"```F!```
M<P8``%\%``!<````:`,``$P%````````L`$````'``#B!``````````````X
M!P``,`8````````/`P`````````````@`P``O`,``)T```#$`@``V@,`````
M````````D`8```0#``"]````B`(```````"M!0```````-P&```:`P``G`(`
M`&\'````````M`8```````"&````P@$``*\&``#I!```B0,```````!S`0``
M*P0``$X%`````````````!L%``"A````%`0```````!;`@``.P,``,\%``"A
M`@```````)<#``!B!```!`4``-H&````````(````"0$``#(`0```````+($
M```B!@``0P<``*P$``!Y`P```````(X#``#1`@``6P,``#P#``#5`0``EP$`
M``````!Y!@```````&\```#>!0````````````#Q!@```````(P!```,`P``
MX`4``-D#``!(!P``E`4``'$$``#V````80$``$(&````````&P0``"P%``"-
M````(08```````"V`@``3`8```````#<````1`<``+D!``"(`0``;@<``.T#
M```X!```(00``!\!``!H````LP```!(`````````HP4```````"R`@``<0``
M`/0!``!\````_@4```T'``"*`````````/X"``"3````S`(```````":`0``
M'0<``+8#``!#!@``3`<``'`&`````````````*8#``!Z!0``````````````
M````.P(``&<!``!1!P``?P(``*L!````````'`(``"T!```W!@``F04`````
M````````&0$``$X```"X!@``\P8``*8$`````````````,D`````````D@,`
M``````#>!@``W0```,H&``#A````]````#`!``#^````+`0``$D```"C`P``
M?`$```````#Q``````````````#6!0```````&0'``!`!P``;P$``)L$``"C
M````+@<``(`%````````:@<```````"L`0```````$D&````````+P```/D"
M````````<0$```````#<`0````````````#@`@````````@&```-`0``#@<`
M`-D$``!:````^P$``!T$```/`````04``(\````=!0`````````````&!```
M6`8``$@&``"*!@```````%(!``!B!@``W`4``"$%``"/!```^P4``-``````
M`````````'@&````````#@$``#8"``#T!@``O@$``%$"``#T!0``Q@4``(\'
M``"@``````````````"I`P``J`8``(L%``"=`P``M@4``&8&````````Z`,`
M``````"`!@``T`(``&X````"`0``0`,``!D'``".!@``````````````````
M-@,``(L```!``0``30```%<%``!)`0```````%$$````````U@(``*\```#W
M!@``.00``$,!``"]!@``60<``-L```"7!````````"0````(`0``?0,``)<&
M````````-@$``*P%```1````$`0``-8$````````,0$``,P!``"Y`@``````
M`#D```"]!``````````````.!```"0<``$H'``!2!P``1@<``"P"````````
M)0,``&<"``"8!```U`,``"`"````````O@4``.(````(`P``=@$``,8&``!I
M!@```````.L#``!+!```X@(``#@#``!"`0``Z````,($````````30(``&X#
M````````>@0```````!7`@``AP0``.```````````````(H%``"<`P``-P4`
M`)\%``"[`0``^@4```````"W`P``*P,``$4&``#7!0``D`(``%\'```!`@``
M+P8```<#```C!0``K`(``$X"```#!@```````-H%```S!@```````',```"*
M!```\P$```````#]`0````````````#Z````U`8``.X````U!0``A`0``&H#
M``!M!@````````````!/!```8`(``!,!``!!`0``@`0```````"U!```-@``
M`"H#``!0`0``1P4``'P'```[!0``6@,``'P#``#5!@``$@4``#P!``!D!```
M$@<`````````````?0<```````!P!P``Y0(```````#S````/0(``$D$```F
M`0``B@,```,$``#I`@``PP8``-$!```)`@``?P4``"@$``#^`P``V@0``.H&
M`````````````'8#````````_0```!8%``""`P``_P,``,\"```U!@``3`,`
M`-@#``!1````:P0```8#```A`P``Y08`````````````9P,``(L#````````
M2P4```````!2````.@8``&P"```B`P```````)H"```>!P````````\'``!Y
M`0``5P```.`&``!Z````(@4``&,$``#(`@`````````````'!@``G````%,!
M``#.`0``@04```P%``!R!@```P,``","```X````5`4````````M````C@<`
M`"0"````````(@$``&<`````````W@,``%,````K!0``)`$`````````````
M`````$0$````````"`4``/4%````````:`4``"T%`````````````$0`````
M````5@$``#<'``#J`P``6@8``!,$`````````````"D'````````B0```+0`
M``#>`````````'4&`````````````&$%```'`0````````X"````````````
M``````#G`0``F@```,P#``#<`P````````````"O`@``9@(``(X$````````
M/`<```````!9!```%@,````````&!P``V@````````#0!```\P0```````!8
M`@```````&`$``!]!```S`8``,@%``"R````)00```````"$`P``9P<``+4`
M```"!0``J@4```(&```:````<@4``$L```!J!```Q00``+X#``!8`P``````
M`#0"`````````````*0!```"`````````*,$``````````````````#@`P``
M404``"@#``!-`P``(0<``-H!``#X!```\`4``$4#``!?`````````*P&```6
M`````````````````````````#L```!4````I00``#,$``#3`@``OP(``.\&
M```;`P``C````)X#``!,`@```````%X%````````60,``-0%````````@`(`
M``````!0`P``\`8``*<#``#3````SP````````#B!@``@@```-,$```'!```
M7P(``!P%``!B!P``Y00``/`$``!5`@``+@8``,(&``!7!```Q0$``&X&````
M````000```````"#````F@0````"``"Q!@``5@,``+L```"2`0``G@8`````
M``````````````````"$````A`8``$P!``````````````````#[`@``````
M`(<!``#;`P```````#(%``#N`@``#P$``(4!```;!@```````+`````8!@``
M:@$``(`!````````E0```-\$```[`0``>P$``(P"``#&`@``MP0``%<'````
M````2@(```X&``#&`P``-`,```@"```P!0``40$``,<#```4!P``100``&4%
M``#A`0```````"H!``!.`0``3`0``-<!``"?`P```0$``,<%````````5P$`
M`,X%``!Z`P``K@,``-@```"Q`0``/00``#,"``!2!```!@4```````!#!0``
M1`,``*4!``"1!```'P```*`"``````````````````#!`0``6@<``)P!``#[
M!@```````!D%``#O`0``<`$```````"T!0``;`4``-@"````!@```````-D!
M````````]0,```````"!!@``*@0``&,`````````````````````````````
M``````#%`@``^`,``!@"``#1`P``$@0``&,"````````O0(`````````````
M9`,```````#'````$P(``&4'``"0`P``/P4``%0#```]```````````````@
M!@```````,`%``!E!@``E@$``````````````P<``'D"````````L@$``+8`
M````````1P0``(,$``!^````IP4``,L!````````]`,``)0&``!0!0``!0<`
M`(4'```F`P``%0```(4#```W!```.P<``%T"````````*`<`````````````
M`````+4&``#Q!```'P<``)<````B!`````````````!4!@``TP8``+L$``"S
M!@``GP$```P````$`0``,08``$$'``#9!0``F`(```````#!!```XP,``+,!
M``#\!````````'('````````;P,``'<$````!0``2@8``,0$``#Y````````
M`%0'``#>`@``'`8``.8```"M!@```````-8&``#_!```W`0````````U````
M!0,``%,"````````=0$``",&````````!00``-,!````````I08``(8#```^
M`0``P@,``#P%``",!@``````````````````@`````````"%````%P8``'4#
M````````ZP0``+L#````````A@8````````N`@``K@8``)(```!/!@``F@,`
M`$@%````````5@```-X!``"2!```C`,``%(%````````<P(``',#```-!@``
M%0$```````"?````A00``````````````````$`&```#!0``F@4``#X'````
M````1@8``&`&``````````````````"H`P``D04``(<'``"'`P``C@4``'X"
M````````"P0```````!Q`@``504``-L&``"@!@``L0`````````0`@``G0$`
M```````,`@``G0(````````1`0````````````!3!```2`$``-T"``#[!```
M`````!4'``!K`@```````-X$```T!@``5P,``$('``#?`P````````````#=
M!0``%@0``&\&``"L````$0(``*`$````````LP(```````#-!0``J`$``+<"
M``#G!@``<`,``%T!``#I`0``H`4``!X"`````````````.,"```?!```````
M``````"(!@``)`<`````````````\04``&0"````````R0$``&\"```G`@``
M\0$``,`"```A`0``'@,``!(&```X!@``60```%T```!O!0``WP$``/P"```W
M`0``]00``!P$``````````````````#B`0``W`(```T$``"E!0``HP$```0"
M``!^`P``CP(``&,#````````4`0``.H```"^````<`4```````#)!```_`4`
M`)@!`````````````&P!```6!@``-@4``)8"`````````````+`%``"8`P``
M,@(``*L$````````?04``)D&``!)!P``_@$``'\````7!0``QP$``/X&``!L
M!@``$00``!,%```4`0``Z@$```````!@`0``K@4``,,#```4`P```````'4"
M````````9@$`````````````C0<``"T#````````)`,``,H"``!I`P``````
M`)X`````````````````````````J@0``+4!``"Q!```S@(```````!-!P``
M.0<``/,#````````T@0``"X#```9`P``@0,``-`#```U!P```````,P%``#V
M`@``3P````````#6`0```````&(```#4!```"@(`````````````E`(``)``
M`````````````"D&````````S0(``*0#``#P`@``8P<``-D`````````:P<`
M`,`&````````2@0``#\&````````[P(``"D```"'`@```````'T&````````
M>@$```H%``!7!@``,0(`````````````WP(``+,$````````Y`(``,T````-
M````+P<```````!E!```RP4```````#6````X`$``(8!```S!0``QP(``)(%
M``!R`P```````-\&``!;!0``)08`````````````[``````````-!0``````
M``````!M`0``#P(```````"A!@````````````"\!```8`<``(,"```0!@``
M2P<``-$&```]!P```````),!``#+!````````),#````````.0$``)P&``"Y
M````H@(``/4"```]!0``/P0````!``!/`@``7@<````````@`0``F0$``-(#
M```$!```N`(``+\#````````<08``,L&``#/!```DP8````````:!0``Y04`
M`*@````T`0``_P4``!D&``#Y`P``,0<```4!``#E`0``*0$``+(&````````
M`````*D"``#$`P``]P0````````L`0``2`(``)X%```<````%`(``*T"```P
M!```;`0``(@$``#0`0``UP0``.(#```M`@``9````"D%```F!0``N@$``)8&
M``!0!@``(@(``"$"```X!0``Y@0``/T&``#\!@``$````%H$````````2`,`
M`%4&````````4@8```````#I!0``@0(``*X!```R`P```````!\&```7!P``
M``````````"\````304```````!^!@``R04``.<"``"K!@```````.$&```5
M`@``X`0``)T$`````````````/D!``"1`@``S@8``!L```!U````L`,`````
M``#H`0``[P0``.P#``#C`````````*(```#+`P``L`(``)8#``"5!@``````
M``````!:!0``Y@,``&\$``!8!```^04``!\%```G!P``HP8``*$$``#]`@``
MI`(```````"U`@``_P```+@#```"`P``[`0``-$%`````````````/P#``"5
M`@``90$``'P&``!%!P``_00``,,!``#&`0```````!@'``#=!````````%T%
M````````OP8``'L"``"Z!```ZP(``#,#``!T!```W0,``&L!````````U00`
M`.<#``#X`0``N@4``.L%```)`````````(L'``#(!@``O@0`````````````
M8@(``&T```!8``````````,````^!0```@<```````#Z!@``PP```,,"````
M````F`8```````!W`@```````#T#``````````````````#!`@``H0$``(X`
M``!%!0``-`4``#('```&!@``:`(``"4"``!*!0```````+<%`````P``````
M`-4#```E!P``-`<``(L"``"*`0``[00``)(&```7`0```````-L!````````
M`````*0```!A!@``%04``(8"````````[`4````````=````'08```````"T
M`0```````(<%`````````````)$#```*!@``+P(``)0`````````=P$``#\!
M````````$P8```````!9!0``8P4``,,%``#D!@``C`<```````#M!0``Y`0`
M`+8$``#U!@``L@4````````D!0``4@(``#H!````````V@(```````!'`@``
M/08``.0%````````B08``.0```#"`@``_04```````"0!0``1P```.X%``!!
M`P```````````````````````)$````Z!P``:@(``(\&```X`0``Y@$``(H"
M````````6P```(<````@!P``M04``.,!``"H`@``\@```#,!```:!P``;`<`
M`(8%``!2`P``Q`$`````````````I@$``,0&````````1@,``-,%``"F````
M`````',%``#6`P``8@$```````"5!````````/``````````K00```````#W
M`0``)@<``+@%``"+`0````````````!1!@``VP4``!\#`````````````.H$
M``"1`0``O04``!`%``!W!0`````````````M!P``A`(``&`%````````!P``
M`/`#``!$!@```````!0%``!5!```O`8``*(%````````!P(``"T&``!R!```
MA`<``#$#``!=!@```````#4"```S!P```````!<``````````````+0$``#.
M````F`4``+P"```E`0``;0<``!$'``#N`0``4````&H&````````!P<``!@$
M``!+`P``^00`````````````ZP````\$```%`@```````!("````````>P0`
M`'T"````````@P$```<%````````'P(``*T#```V!P``PP0```````!B`P``
M,`<``$("``#N!```8`````````!X!0``>`(``$($````````<@```/P!``""
M!```/@,``)P%``#R!```Y0```-T&````````/0$``*H#```W````````````
M``!4!````````"4```!-!@``(P<``!X&``#%!0```````&`#````````````
M`.$#``!Q!P``]P4```````">`@``@@8``"<&````````^P```!4$````````
M7P8``,<&``#J!0````````````"=!@``"P,``!,#````````RP(``-@%```G
M!```$@,``#8&````````EP4`````````````10```*@$``!.!@``,04`````
M````````P@```+<!``"O!```&P(```````!^!0```````(L$``#2`@``N```
M``L'````````P0```"H'````````&@(``-4````0`P``^`8``/<#``"G````
M0`4``-@!```W`@``Q`4`````````````QP0``,4#``"I!````````-\`````
M````B`4``&4#``!K``````````````#O````M@$``%,#````````6`$`````
M`````````````*0%``!Z!@```@(```````!)!0``.`(``'X$``"K````````
M`)8%```_`P``_0,``'0#````````"`0``*L#``!G!```3P4``,T!```1!0``
M`````,@#``"O`0``<@$```````#V!@`````````````#`0``7@,``"D#````
M````8P8```8!````````E`,``&8#``"B!```B0(``&T%``#.`P``7`(``.T&
M````````;@$``)D$``#&````H0,``(4%``#U`````````+\````.````8@4`
M``````!Q!0``$P```)D```!K`P````````P&````````H`,``.X&```*!```
M.0(```````!5`0``I@8``,$%``#%````@P,```L&```F!@``5@4``%D"``";
M`0``A08``#X&``"``P``?0$``#$$``!G!0``=P8``(,&````````.P0``'\$
M```B!P``%`8``(H'````````\P(``#P$``!4`0```````.D#``#F`@``````
M`"8```!-!```#0,```````````````````````!0!P```````"(```#X!0``
M9P8``"X```"\`0````````````!Z`@``A`$``&D```!"!0``F``````````<
M`P```````.T!``"-`@``UP````````!)`@````````````!I!P``80,``$8%
M```^!```"@,``)("`````````````'\'``!!!0``'@0``'L'``!U!```%@$`
M`-(````H!@``7P,``(@'````````:`<``*$%``"1!@``XP8``!P'``!&!```
M+`<``'8```!)`P``SP$```````#H!0``+P$``/H$```0`0``/```````````
M``````````````#R!@``[P4``,(%````````.@4``.8%````````$P<`````
M``#A!```9@4``"D$`````````````,D#``!V!```IP(````````<`0``=@4`
M`$4!``#%!@``"`<```````#,!```2`````8```#M`````````(8$``!9!@``
M.@0```L"```4````G@$``%,%``#T!```6P<``(T#````````_`````````!A
M`@``X04``!H&``#X`````````-`&``"(`P``=`8``!@#```@!0``/`8``&$'
M``!'!@``^@$``&4"``!3!P``<P<``*0&```"!```>P```/\&``!:`@``````
M`&@$````````*@8``&T"``#P`0``.@```"@"````````X0(`````````````
M``````````"!!P``L0(``#(````K`0```````/("```+`0``(`0```\&``!1
M`P``H@$``'D'``"V!@``R````%P&``!L````JP(```````!#`P```P(``&4`
M``!3!@``A0(```````![`P``HP(``+4#``#I````K0$````````+````$`<`
M``D%``"N!```+@4``&0!`````````````,`$````````7`0``)8```#N`P``
M/`(```````"N````=`4```````!M!```CP$```````#R`0``=@<``!$#``"M
M````%P,```````![!0``T00``!(!```L`P``700``!D"``"F!0``;0,`````
M``"-!```!0```"X$```%!0```````$,$```!`P``=0<``",#``!J!0``+P,`
M`)`$`````````````````````````````%4#````````U`(```X%``!/`P``
M.P8```````!9`0```````*<!``#C!0````````````#*`P``DP(``*H```#G
M!```F0(``%@'`````````````)4#``!V`@``WP4``'8&````````G`0``/0"
M``!F`````````$H#```)`P```````%P%``!$!0``N08``.4#``!0`@``@P4`
M````````````/@(``+0#``#Z`P``-@0``&0%``#H!@``-P,``%P#``#*!```
M`````%T#``!!`@``L`0``*4#```L`````````+$%``#H!```]P(````````)
M!```F0,``/,%``#8!@````````T"``#_`@``$08``(@````>`0``L@,```0'
M``#Y!@``F@8``.(%`````````````*`!```K!@``#`$```````"[!@``U04`
M``````!?!```[0(``)\&``"S`P``"````$0"```/!0``/P(``$$&``"D!```
M?P,``.P!``!&`@``2`0``&L%````````)04``,T$``!^`0`````````````U
M`P```````'P"``"&!P```````(X"``#7`P``%08``,X$```C`0``````````
M``"G!```1P<```````#``0``)P4```0&`````````````$8!``"6!```(P``
M`-L$````!```NP(``*D!````````L`8``"X!``!`!```C08```````"!!```
M````````````````&0```(P$`````````````'D$``!.!```)P,``!T!``#G
M!0``T@8``.0#````````E04``),%``!\!0``P08````````&`@``1P,``+X"
M``"#!P``3P<````````%!@``7@```!D$`````````08``/\!````````S```
M`!8'``#2!0```````&X$``#-!@```````((!``")`0```````"D"```T!```
M0@```'<'``#^!````````+T!``!J````0`(``+\$``"W!@``UP(`````````
M`````````#(!``!^!P``D`$``$,"``".`0``J`4``$8````P`P``EP(``,$#
M``!6!@`````````````8````:00``+H"``!.`P``5@<`````````````````
M````````````J04``'4%``!R`@``\@4```````!6`@``8P$``"<!``#9!@``
M6`4``*D```!=!P````````````"Y!```*`$``"L```")!````````$(#````
M````.0,```X#``"L`P``ZP$``"@%``!K!@```````#D&```J!0```0<``&X"
M```6`@``A`4```````";````SP8``-<&``!-`0``N@```%L&```R!```````
M`-0```")!P``]0$```````!```````````````!?`0``"P4``*\#``!'`0``
M`````/$"````````[`(``"0&```:`0````````````")!0```````)T%``!W
M````>04``*(&``"+!@``?`0`````````````,@8``'\&````````+00``#H#
M```5`P``.04``&P#```K!P``@`<``((%``">!```9@<``$,`````````/@``
M``````#G````VP(``'0```!X`P``OP4```````#)`@``]@4```````"^!@``
M?0```*H!````````@0``````````````>````)4!```U!````````'D```"N
M`@``]P````````";!@``J@(``#\```"B`P``MP```#4!``!T!P```````)L%
M````````=P,```````"\!0``7@0````@*"5S(&1A>7,@86=O*0`@*$%C8V5S
M<VME>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@
M*'EE<W1E<F1A>2D`(&%T(``B)7,B(&ES(&YO="!A(&1I<F5C=&]R>2X`(B5S
M(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N`"(E<R(@:7,@;F]T(&-O;F9I9W5R
M960@:6X@=&AE($AO<F1E(%)E9VES=')Y+@`B)7,B('1R964@<F5N9&5R97(@
M;F]T(&9O=6YD+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E
M;2X`(B5S(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`
M(B5S(B!W87,@;F]T(&-R96%T960Z("5S+@`E+C)F34(@=7-E9"!O9B`E+C)F
M34(@86QL;W=E9"`H)2XR9B4E*0`E9"`E<R!A;F0@)7,`)60@9&%Y<R!U;G1I
M;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N`"5D+61A>2!F;W)E8V%S=``E<R`M
M($YO=&EC90`E<R!&:6YG97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/
M<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``
M)7,@5&5R;7,@;V8@06=R965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A
M="`E<R`E<P`E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC
M92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92!B;W@@9F]R
M(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES
M('1I;64N`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD
M+@`E<R!T;R`E<R!O9B`E<P`E<R=S($%D9')E<W,@0F]O:P`E<R=S($-A;&5N
M9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B`E<P`E<SH@5&AI
M<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B
M92X@0F5W87)E(&]F(&9O;&QO=VEN9R!A;GD@;&EN:W,@:6X@:70@;W(@;V8@
M<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M
M871I;VXN`"P@9W5S=&EN9R``+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@
M9G)O;2`E<R!T;R`E<P`M+2!S96QE8W0@+2T`,3(@2&]U<B!&;W)M870`,C0@
M2&]U<B!&;W)M870`,C0@:&]U<G,`/%!R979I;W5S`$$@9&%T86)A<V4@8F%C
M:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O
M<B!H87,@;V-C=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T
M;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U
M:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0
M(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL
M('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV
M871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I
M=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U
M:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04T@0VQO=61S`$%-($QI9VAT
M(%)A:6X`04T@4F%I;@!!32!3:&]W97)S`$%-(%-N;W<@4VAO=V5R<P!!32]0
M30!!4$D@240`06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M
M`$%B<VUI9&1L90!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O
M<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V]U;G0@
M26YF;W)M871I;VX`06-C;W5N="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`
M06-C;W5N=&EN9P!!9&0`061D($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M
M:7-S:6]N`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES
M<VEO;@!!9&0@82!C:&EL9"!G<F]U<"!T;R`B)7,B`$%D9"!A(&-H:6QD('!E
M<FUI<W-I;VX@=&\@(B5S(@!!9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!
M9&0@;F5W(&UE;6)E<G,`061D('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@
M36]Z:6QL82!3:61E8F%R`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M
M>2!A9&1R97-S(&)O;VL`061D('5S97(`061D960@(B5S(B!T;R!T:&4@<WES
M=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O
M<FUA=&EO;CH@)7,N`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A
M;B!L;V<@:6X@;F]W+@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E
M<W,`061D<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@
M9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI<W1A
M;@!!;&)A;FEA`$%L9V5R:6$`06QI87,`06QI9VX`06QI9VYM96YT.@!!;&P`
M06QL($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES
M<VEO;G,`06QL(&9O=7(@<VED97,`06QL;W<@;75L=&EP;&4@861D<F5S<V5S
M`$%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@
M97AI<W1S`$%L=&5R;F%T92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A
M<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I
M;"!A9&1R97-S`$%L=&5R;F%T92!T96UP;&%T97,`06QT97)N871E('1E>'0Z
M`$%M97)I8V%N(%-A;6]A`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE
M9"X`06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"X`06YD;W)R80!!;F=O
M;&$`06YG=6EL;&$`06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A
M`$%N=&EG=6$@86YD($)A<F)U9&$`07!P;&EC871I;VX`07!P;&EC871I;VX@
M3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P;'D@=&\@0VAI;&0@4VAA
M<F5S`$%P<')O=F4`07!P<F]X:6UA=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I
M;F1O=W,M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R
M92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U
M97-T(&9O<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@
M(B5S(B!A;F0@86YY('-U8BUG<F]U<',_`$%R9V5N=&EN80!!<FUE;FEA`$%R
M;65N:6%N("A!4DU30TE)+3@I`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L86YD
M`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER
M;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!
M<W-I9VYM96YT(&-O;'5M;G,`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI
M<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT
M('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P
M97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA
M<F4N`$%T=')I8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?
M8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A
M8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S
M=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O
M<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E;6]V:6YG
M('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`
M075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H
M870@=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M
M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@
M)7,`075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D
M(&9O<B!!8W1I=F4@1&ER96-T;W)Y+@!!=71H7VUC86PZ(%)E<75I<F5D($U#
M04P@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E
M9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N
M(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F86EL960N("5S`$%U=&AE;G1I8V%T
M:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N`$%U=&AE;G1I8V%T:6]N
M('1O($944"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO;B!T;R!T:&4@
M4TU"('-E<G9E<B!F86EL960N`$%V86EL86)L92!F:65L9',Z`$%Z97)B86EJ
M86X`0D]&2"!%>&-U<V5S`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"
M860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`
M0F%H86UA<P!"86AR86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A;F=L861E
M<V@`0F%R8F%D;W,`0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@(B5S(B!N;W0@
M9F]U;F0N`$)A<V5L:6YE`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`
M0F5R;75D80!":'5T86X`0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A<'!L:6-A
M=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP
M90!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN
M97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1S
M=V%N80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I
M86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA
M`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!#
M4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P97)T:65S+BXN`$-A
M8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N`$-A;&5N9&%R`$-A;&T`0V%M
M8F]D:6$`0V%M97)O;VX`0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T
M:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0V%N(&YO="!W
M<FET92!T;R!F:6QE("(E<R(`0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S
M97-S:6]N(&AA;F1L97)S+@!#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R
M.B`E<P!#86XG="!O<&5N(&9I;&4@(B5S(BX`0V%N861A`$-A;F-E;`!#86YC
M96P@4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A
M;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E
M960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@<F5M
M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E
M;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U
M<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R
M960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N
M`$-A<&4@5F5R9&4`0V%P=&EO;@!#87)R:65R`$-A=&5G;W)I97,@86YD($QA
M8F5L<P!#87EM86X@27-L86YD<P!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE
M<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z
M`$-E;&QP:&]N90!#96QT:6,@*$E33RTX.#4Y+3$T*0!#96YT97(`0V5N=')A
M;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y
M+3(I`$-E<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A=&4@3W=N97(`0V5R
M=&EF:6-A=&4@4&]L:6-I97,`0VAA9`!#:&%N9V4`0VAA;F=E(%EO=7(@4&%S
M<W=O<F0`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE
M('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N
M`$-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H
M('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("!#;VYT86-T('EO=7(@861M
M:6YI<W1R871O<BX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&EL90!#:&EN80!#
M:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA
M;"`H0FEG-2D`0VAO;W-E($%P<&QI8V%T:6]N.@!#:&]O<V4@82!P87-S=V]R
M9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T
M97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S
M*0!#:')I<W1M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T
M(&9O=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R(%%U97)Y
M`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T
M80!#;&5A<FEN9R!,871E`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@
M=FEA($A45%``0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO
M=61Y`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`
M0V]L;&%P<V5D(&)O<F1E<G,`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R
M`$-O;&]U<B!S96QE8W1I;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`
M0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M
M;W)O<P!#;VUP86YY`$-O;7!U=&5R<P!#;VYD:71I;VX`0V]N9&ET:6]N<P!#
M;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R871I;VX@9F]R('-Y
M;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RX`0V]N
M9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92X`0V]N9FEG=7)E("5S`$-O;F9I
M<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B
M;&EC(&]F('1H90!#;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL
M960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V
M97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E
M<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F
M86EL960N`$-O;G1A8W1S`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D
M9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT96YT<R!O9B`B)7,B`$-O
M;G1I;G5E`$-O;VL@27-L86YD<P!#;V]K:64`0V]P>0!#;W!Y(&9A:6QE9#H@
M)7,`0V]P>2!S96QE8W1I;VX`0V]S="!)1`!#;W-T82!2:6-A`$-O=&4@9"=)
M=F]I<F4`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO
M="!01U`@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@
M;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD
M(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S
M97)V97(N`$-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R`$-O=6QD(&YO
M="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0
M('-E<G9E<BX`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("(E<R(@=7-I
M;F<@1E10.B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82X`0V]U;&0@;F]T(&1E
M8W)Y<'0@4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@
M)7,`0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U
M;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!#;W5L
M9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S
M<RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U
M;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L
M9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N
M(&QI<W1S+@!#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2`B)7,B+@!#;W5L9"!N
M;W0@;6MD:7(@(B5S(BX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R
M;VT@=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I
M=&EN9RX`0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT
M96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R
M>2`B)7,B+@!#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L
M9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F
M;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T
M86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO
M=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O
M=6QD(&YO="!R971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E
M<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S
M+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S
M`$-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T(')M
M9&ER("(E<R(N`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O
M=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T
M('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V
M92!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`0V]U;&0@;F]T('-A
M=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`$-O=6QD(&YO
M="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET
M:&5R('5S92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B
M86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@
M)7,N`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N
M;W0@=6YL:6YK("(E<R(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`
M0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@
M;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R("(E<R(Z("5S`$-O=6QD;B=T
M(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E
M8F%R(&ES(&]P96XN`$-O=6QD;B=T(&=I=F4@=7-E<B`B)7,B('1H92!F;VQL
M;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R("(E<R(Z("5S`$-O=6YT960@
M=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E871E`$-R96%T92!A(&QI;FL`0W)E
M871E(&$@;F5W(&]N90!#<F5A=&4@<W5B(&9O;&1E<G,`0W)E871O<B!097)M
M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`0W)O871I80!#=6)A`$-U<G)E
M;G0@-"!0:&%S97,`0W5R<F5N="!397-S:6]N<P!#=7)R96YT(%1I;64`0W5R
M<F5N="!54DP@:7,`0W5R<F5N="!5<V5R<P!#=7)R96YT(%=E871H97(`0W5R
M<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K
M<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`
M0WEP<G5S`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R
M-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*0!#>F5C:"!297!U8FQI
M8P!$1`!$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P
M86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I`$1A:6QY`$1A=&%4
M<F5E($)R;W=S97(`1&%T86)A<V4@3&]O:W5P`$1A=&4`1&%T92!296-E:79E
M9`!$871E('-E;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`
M1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U
M;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969A=6QT(%-H96QL`$1E9FEN
M:71I;VYS`$1E;&5T90!$96QE=&4@0V5L;`!$96QE=&4@1W)O=7``1&5L971E
M($QO9P!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A
M9V5S`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG
M(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@;65S<V%G97,`1&5L971E('!E
M<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S
M(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E(')O=P!$96QE=&4@
M<V5L96-T960@:61E;G1I='D`1&5L971E('1H92!C=7)R96YT(&-O;'5M;@!$
M96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T960@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@(B5S(BX`1&5L:79E<GD@=&EM90!$96YM87)K`$1E<V-R:6)E('1H
M92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G
M<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@
M861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN
M="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE9G0@
M=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I
M<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@
M9&5T86EL960@9F]R96-A<W0`1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P
M;&%Y(&9O<FUA=`!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`1&II8F]U=&D`
M1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA
M;F-E+G!H<`!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@
M;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;6EN:6-A`$1O;6EN
M:6-A;B!297!U8FQI8P!$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N
M`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF
M:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R=6=S
M`$4M36%I;`!%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R
M:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92X`15)2`$5C=6%D;W(`
M161I=`!%9&ET($)L;V-K`$5D:70@1W)O=7``161I="!097)M:7-S:6]N`$5D
M:70@4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`161I="!O
M<'1I;VYS(&9O<CH`161I="!P97)M:7-S:6]N<R!F;W(@(B5S(@!%9&ET('!E
M<FUI<W-I;VYS(&9O<B`E<P!%9'5C871I;VX`16=Y<'0`16ET:&5R(&5N86)L
M92!I="!T:&5N.B`E<RP@;W(@=7-E('1H92!B87-I8R!(5$U,('9E<G-I;VXZ
M("5S+@!%;"!386QV861O<@!%;&5M96YT+BXN`$5M`$5M86EL`$5M86EL($%D
M9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@
M8V]N9FER;6%T:6]N`$5M86EL+71O+5--4R!'871E=V%Y`$5M;W1I8V]N<P!%
M;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M
M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE
M<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU
M/P!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U
M97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O
M(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@
M;V8@>6]U<B!P970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5N=&5R
M('1H92!L971T97)S(&)E;&]W.@!%<75A=&]R:6%L($=U:6YE80!%<FET<F5A
M`$5R<F]R`$5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<P!%<G)O<B!D96QE=&EN
M9R!S>6YC(&%N8VAO<CH@)7,`17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S
M`$5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,`17)R;W(@=7!D871I;F<@<&%S
M<W=O<F0Z("5S`$5R<F]R('=I=&@@96UA:6P@;65S<V%G92X`17)R;W(@=W)I
M=&EN9R`B)7,B+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E
M<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD
M<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R
M`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A;F0`
M17AP86YD(%-I9&5B87(`17AP96-T960@)RDG`$5X<&5C=&5D(&)A<F4@=V]R
M9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`17AP:7)A=&EO;B!$871E`$5X<&]N
M96YT`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D(')E=')I
M979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@
M<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL
M960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N
M`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D
M('1O(&UO=F4@=&\@(B5S(BX`1F%I;&5D('1O(')E=')I979E.B`E<P!&86ER
M`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A
M=&%L($5R<F]R.@!&87@`1F%X97,`1F5B<G5A<GD`1F5E;',@3&EK90!&965L
M<R!L:6ME.B``1F5W(%-H;W=E<G,`1F5W(%-N;W<@4VAO=V5R<P!&:65L9"!M
M871R:7@`1FEG;&5T($-!4%1#2$$`1FEG;&5T(&9O;G0`1FEJ:0!&:6QE`$9I
M;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-
M86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&
M:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R<P!&:6YL86YD`$9I
M<G-T($AA;&8`1FER<W0@475A<G1E<@!&:7@@<F%T:6\`1FQI<`!&;&]A=`!&
M;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@0V]L;W(`1F]O9`!&
M;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<P!&;W)E8V%S
M="`H5$%&*0!&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D
M(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A(&QA<F=E
M(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI`$9O
M<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@='EP
M90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M<P!&;W)W87)D<P!&<@!&<F%M
M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI=&%N`$9R96YC:"!'=6EA;F$`
M1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`
M1G)O;0!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L
M;"!.86UE`$=A8F]N`$=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A;&QE
M<GDZ`$=A;6)I80!'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E
M9"!#;V1E`$=E;W)G:6$`1V5R;6%N>0!':&%N80!':6)R86QT87(`1VEV96X@
M3F%M90!';&]B86P@3W!T:6]N<P!';P!';V5D96P`1V]O9VQE($UA<',`1V]O
M9VQE(%-E87)C:`!'<F%Y<V-A;&4`1W)E96-E`$=R965K("A)4T\M.#@U.2TW
M*0!'<F5E;FQA;F0`1W)E;F%D80!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U
M<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<%]L9&%P.B!5;F%B;&4@
M=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M.B``1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<P!'<F]U
M<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S`$=R;W5P<P!'=6%D
M96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E<FUI<W-I
M;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-
M3`!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!C96QL(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D
M96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A
M<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N
M`$A45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L
M9V]R:71H;0!(87IE`$AE861E<@!(96%D97)S`$AE87)D($ES;&%N9"!A;F0@
M36-$;VYA;&0@27-L86YD<P!(96%V>2!4+5-T;W)M`$AE8G)E=R`H25-/+3@X
M-3DM."U)*0!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP97(`
M2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z
M`$AI9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M
M90!(;VUE($%D9')E<W,`2&]M92!$:7)E8W1O<GD`2&]M92!0:&]N90!(;VYD
M=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@
M6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA
M8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O
M2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@
M)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`
M2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@
M=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O
M9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@
M)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES
M92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E<R(`
M2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L
M.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@
M;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N
M>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W
M;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ(`!(
M=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D
M.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA
M:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S`$E0
M($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN
M(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)
M7VYS97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS(&9O
M<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I
M<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A
M(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG
M($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI
M<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U('-E
M92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A
M;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S
M97(N`$EM86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E
M(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A
M9`!);6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E<P!)
M;7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C="!A
M8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P
M87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R
M97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@
M:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD
M:6$`26YD:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA=&EO
M;@!);F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+@!);G-E<G0@0U]O
M;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!7
M96(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O
M;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M
M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T
M97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H
M92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U
M<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R
M96YT(&YO9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@
M96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE
M=R!P87-S=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F
M;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`
M26YS97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T
M('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W
M(&)E9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C
M=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO
M9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@
M9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G
M97(`26YT96=E<B!L:7-T`$EN=F%L:60@541(+B`H57-E<B!$871A($AE861E
M<BDN`$EN=F%L:60@6DE0(&1A=&$`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV
M86QI9"!B871C:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI
M9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN
M=F%L:60@;&EC96YS92!K97DN`$EN=F%L:60@;&]C871I;VX@<')O=FED960N
M`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N
M`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N
M="!P97)M:7-S:6]N+@!);G9A;&ED('!A<G1N97(@:60N`$EN=F%L:60@<')O
M9'5C="!C;V1E+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED(')E8VEP:65N
M=#H@(B5S(@!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A
M9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$EN=F5R
M="!S96QE8W1I;VX`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER
M96QA;F0`27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES
M<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N
M97-E("A)4T\M,C`R,BU*4"D`2F%V87-C<FEP="!H87,@8F5E;B!D:7-A8FQE
M9"!O;B!Y;W5R(&)R;W=S97(@86YD('1H:7,@<&%G92!M87D@;F]T(&)E(&1I
M<W!L87EI;F<@8V]R<F5C=&QY+@!*97)S97D`2F]R9&%N`$IU;'D`2G5N90!*
M=7-T:69Y`$IU<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE
M9G0`2G5S=&EF>2!2:6=H=`!+87IA:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME
M;GEA`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`
M2V5R;F5L($YE=V)I97,`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+
M97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES
M=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$MI9',`2VER:6)A=&D`2V]R
M96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E
M<'5B;&EC(&]F`$MO<F5A;B`H155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,
M85]Y;W5T`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B
M;&EC`$QA<W0@2&%L9@!,87-T(%!A<W-W;W)D($-H86YG90!,87-T(%%U87)T
M97(`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E
M<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA='9I80!,87<`3&%Y;W5T
M`$QE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(`3&5B86YO;@!,969T`$QE9G0@
M:&5A9&5R`$QE9G0@=F%L=65S`$QE<V]T:&\`3&5V96P`3&EB97)I80!,:6)Y
M86X@07)A8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`3&EG:'0@1')I>GIL
M90!,:6=H="!286EN`$QI9VAT(%)A:6X@16%R;'D`3&EG:'0@4F%I;B!,871E
M`$QI9VAT(%)A:6X@4VAO=V5R`$QI9VAT(%)A:6X@=VET:"!4:'5N9&5R`$QI
M9VAT(%-N;W<`3&EG:'0@4VYO=R!3:&]W97(`3&EM97)I8VL`3&EN:P!,:6YK
M('!O:6YT<R!T;SH`3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M
M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9P!,:6YK<P!,:6YU>"!#;V]K:64`
M3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@1&%T86)A<V5S
M`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!486)L97,`3&ES="U!<F-H:79E`$QI
M<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B
M<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!S97-S:6]N<R!F86EL
M960Z("5S`$QI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S
M(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI80!,;V%D:6YG+BXN
M`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN
M`$QO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VX`3&]G(&]U=`!,;V=I;@!,
M;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE
M(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F
M86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E:R!L971T97)S
M`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M8F5R<P!,=7AE
M;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N
M;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S
M;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%G:6,`36%I;`!-86EL($%D
M;6EN`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA
M;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA
M=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D
M('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA
M<`!-87!P:6YG<R!S=&]R960N`$UA<F-H`$UA<F=I;@!-87)K('=I=&@@4V5E
M;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM
M<&]R=&%N="]!;G-W97)E9"D`36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E
M`$UA=&-H:6YG(&9I96QD<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87@@86QL
M;W=E9"!C<F5D:70N`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@
M=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``
M36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<P!-87AI;75M(&QE;F=T
M:`!-87D`36%Y;W1T90!-961I8VEN90!-96UB97)S`$UE;G4@;6]D93H`365R
M9V4@8V5L;',`365S<V%G90!-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL
M>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V
M97)I9FEE9"X`365S<V%G92!E>'!I<F5D+@!-97-S86=E('1Y<&4`365T87(@
M5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C
M:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R
M('1H92!A9&UI;FES=')A=&]R+@!-971A<D1"(&ES(&YO="!C;VYN96-T960N
M`$UE=&AO9`!-971H;V0@(B5S(B!I<R!N;W0@9&5F:6YE9`!-971H;V0@;F]T
M(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S`$UE=')I8P!-97AI8V\`36EC
M<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-:61D;&4`36EM92!4>7!E
M`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U
M<G,Z(`!-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D
M`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI<W-I;F<@4$5!4B!P86-K86=E($A4
M5%!?4F5Q=65S="X`36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T
M;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@87!P
M;&EC871I;VXN`$UI<W-I;F<@;65S<V%G92!)1"X`36ES<VEN9R!R97%U:7)E
M9"!014%2('!A8VMA9V4@36%I;"X`36ES<VEN9R!S97-S:6]N($E$+@!-;P!-
M;V)I;&4@36%I;`!-;V1E<F%T90!-;V1I9FEE9"!$871E`$UO9&EF>2!54DP`
M36]D=6QU<P!-;VQD;W9A+"!297!U8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`
M36]N=&@@86YD('EE87(`36]N=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S
M`$UO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T
M960@)60N`$UO<F]C8V\`36]S=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S
M=&QY($-L;W5D>2!A;F0@5VEN9'D`36]S=&QY(%-U;FYY`$UO=F4@1&]W;@!-
M;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E('5P
M`$UO>F%M8FEQ=64`375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S`$UU;'1I
M;6%P(%5+(&UA<`!-=6QT:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!!
M8V-O=6YT($EN9F]R;6%T:6]N`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T
M`$UY86YM87(`3D\L($D@1&\@3D]4($%G<F5E`$YA;64`3F%M:6)I80!.875R
M=0!.97!A;`!.971H97)L86YD<P!.971H97)L86YD<R!!;G1I;&QE<P!.971S
M8V%P92!"87-E(%523`!.971S8V%P92!#02!2979O8V%T:6]N(%523`!.971S
M8V%P92!#02!P;VQI8WD@55),`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C
M87!E(%)E=F]C871I;VX@55),`$YE='-C87!E(%-33"!S97)V97(@;F%M90!.
M971S8V%P92!C97)T:69I8V%T92!C;VUM96YT`$YE='-C87!E(&-E<G1I9FEC
M871E('1Y<&4`3F5T=V]R:P!.979E<@!.97<@0V%L961O;FEA`$YE=R!#871E
M9V]R>0!.97<@365S<V%G92!T;R`E<P!.97<@36]O;@!.97<@57-E<FYA;64@
M*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@<&%S<W=O<F0`3F5W('!A<W-W
M;W)D('=I;&P@97AP:7)E(&]N("5X+@!.97<@<&%S<W=O<F1S(&1O;B=T(&UA
M=&-H+@!.97<@=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5W<V=R;W5P<P!.97AT
M`$YE>'0@-"!0:&%S97,`3F5X="!O<'1I;VYS`$YE>'0^`$YI8V%R86=U80!.
M:6=E<@!.:6=E<FEA`$YI9VAT`$YI=64`3F\`3F\@879A:6QA8FQE(&-O;F9I
M9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@879A
M:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RX`3F\@8F%T
M8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D
M('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@
M875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@8VAI;&1R96X@8V%N(&)E
M(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N`$YO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM
M1FEL92!61E,N`$YO(&-R961I="!L969T+@!.;R!D97-T:6YA=&EO;B!S=7!P
M;&EE9"X`3F\@9FEL92!U<&QO861E9`!.;R!I8V]N<R!F;W5N9"X`3F\@;&]C
M871I;VX@:7,@<V5T+@!.;R!L;V-A=&EO;B!P<F]V:61E9"X`3F\@;65S<V%G
M92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I960N`$YO(&YU;6)E<B!S<&5C
M:69I960N`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P
M871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y3
M4TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D
M871A+@!.;R!P96YD:6YG('-I9VYU<',N`$YO('%U;W1A('-E="X`3F\@<G5L
M97,`3F\@<V5P87)A=&]R('-P96-I9FEE9"X`3F\@<VED97,`3F\@<W5C:"!F
M:6QE`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H
M92X`3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N`$YO('9A;&ED
M(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD
M(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG
M=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I
M;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N90!.;VYE("AU<V4@
M:6UP;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO<F9O;&L@27-L86YD
M`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S
M`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@82!D:7)E8W1O<GD`
M3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S=7!P;W)T960N`$YO=&5S
M`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.;W9E;6)E<@!.=6UB97(`
M3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R
M(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I
M;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J96-T`$]B:F5C="!#<F5A=&]R
M`$]C=&%L`$]C=&]B97(`3V9F96YS92!F:6QT97(`3V9F:6-E`$]L9"!A;F0@
M;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="X`3VQD('!A<W-W;W)D
M`$]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="X`3VUA;@!/;FQY($E-05`@
M<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N<VEV
M92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N
M;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N
M9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E
M`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO
M="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N`$]P96YS
M('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/
M<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R9&5R960@3&ES=`!/<F=A;FES871I
M;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L(&%P
M<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E<SH`
M3W1H97(`3W1H97(@26YF;W)M871I;VX`3W=N97(@4&5R;6ES<VEO;G,`4$%-
M(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!%05(Z.DUA:6P@
M8F%C:V5N9`!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$
M871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D($1A=&$`
M4$A0($-O9&4`4$A0(%-H96QL`%!-($QI9VAT(%)A:6X`4$T@4F%I;@!032!3
M:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S`%!-(%-U;@!032!4+5-T
M;W)M<P!03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9P!07TA0(%-H96QL`%!A
M9&1I;F<`4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/
M8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A>0!087)T
M;'D@0VQO=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U
M;&QY+@!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@<F5Q=6ER960@9F]R
M(%)!1$E54R!A=71H96YT:6-A=&EO;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M
M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T
M8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3
M:6=N=7!S.@!096]P;&4`4&5R8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P
M97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO
M9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VX@(B5S(B!N;W0@9&5L971E9"X`
M4&5R;6ES<VEO;B!$96YI960`4&5R;6ES<VEO;G,`4&5R;6ES<VEO;G,@061M
M:6YI<W1R871I;VX`4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0971S`%!H
M:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE;',`4&QA=&ET
M=61E<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I
M<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A
M<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE
M;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E
M;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S92!E;G1E
M<B!A('9A;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A;&ED(&1A
M=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L
M96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!P<F]V:61E(&$@<W5M
M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R
M;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T
M97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE
M('-Y<W1E;2X`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0
M;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R='5G86P`4&]S:71I;VYI;F<@;V8@
M=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@
M=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0<F5C:7!I=&%T
M:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5C:7!I=&%T:6]N/&)R("\^
M8VAA;F-E`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO
M="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V
M96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@
M82!N97<@=VEN9&]W`%!R979I;W5S(&]P=&EO;G,`4')I;G0@9&]C=6UE;G0`
M4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE
M8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET
M:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T
M(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O`%!U<F=E(&UE
M<W-A9V5S`%%A=&%R`%%U97)Y`%%U;W1A`%)302!0=6)L:6,@2V5Y("@E9"!B
M:70I`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E
M`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O
M;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E<P!296%L;'D@9&5L
M971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L
M;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I
M;VX@8V%N;F]T(&)E('5N9&]N92X`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`
M4F5F<F5S:`!2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S
M:"!0;W)T86P@5FEE=SH`4F5G97@`4F5L871I;VYS:&EP($)R;W=S97(`4F5L
M;V%D`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO
M+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`
M4F5M;W9E(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@<&%I<@!2
M96UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I
M<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE
M(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!297%U97-T
M(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!2
M97%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N`%)E<75I<F5D
M("(E<R(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+@!297%U
M:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN
M`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N
M+@!297%U:7)E9"!&:65L9`!297-E=`!297-E="!087-S=V]R9`!297-E="!9
M;W5R(%!A<W-W;W)D`%)E<W1O<F4@3&%S="!1=65R>0!297-U;'1S`%)E='5R
M;B!T;R!/<'1I;VYS`%)E='EP92!N97<@<&%S<W=O<F0`4F5U;FEO;@!2979E
M<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4FED
M9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG:'0@=F%L=65S`%)O7W<@4')O
M<&5R=&EE<RXN+@!2;VQE`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A=&4@3&5F
M=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`
M4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W
M<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M
M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>0!2
M=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3+TU)344@0W)Y<'1O9W)A
M<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E9"!-97-S86=E`%-!4TP@
M875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN
M9P!344P@4VAE;&P`4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P<P!3
M4T@`4U5#0T534P!37U%,(%-H96QL`%-A`%-A:6YT($AE;&5N80!386EN="!+
M:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE<G)E(&%N9"!-
M:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<P!386UE
M(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!A;F0@
M4')I;F-I<&4`4V%T96QL:71E(%!R;W9I9&5R`%-A=61I($%R86)I80!3879E
M`%-A=F4@(B5S(@!3879E("5S`%-A=F4@3W!T:6]N<P!3879E(&=E;F5R871E
M9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E
M<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R871I
M;VXN`%-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!38V%T
M=&5R960@5"U3=&]R;7,`4V-I96YC90!396%R8V@`4V5A<F-H($5N9VEN97,`
M4V5L96-T($9I;&5S`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@9W)O=7`@=&\@
M861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!S97)V97(`4V5L96-T
M(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;`!396QE8W0@86QL(&1A=&4@8V]M
M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C=`!396QE8W0@;F]N90!396QE8W0@
M=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N
M(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E
M>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H
M92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T
M;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T
M:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!3
M96QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E
M9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD(%--4P!396YE
M9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:6$@86YD($UO;G1E;F5G<F\`
M4V5R:6%L($YU;6)E<@!397)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA
M8FQE+@!397-S:6]N($%D;6EN`%-E<W-I;VX@240@97AP:7)E9"X`4V5S<VEO
M;G,`4V5T`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R
M('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T('5P(')E;6]T
M92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P
M;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@
M86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO
M;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D
M:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A
M=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@
M<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3:&]P<&EN9P!3:&]R="!3=6UM87)Y
M`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS
M/P!3:&]W`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V
M960@86YD('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX`4VAO
M=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W(&]P=&EO
M;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H;W<@=&%B;&4@;W!E
M<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F
M=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9P!3:&]W
M('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!2
M;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE
M<R!D:6%L;V<`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W97)S($5A<FQY`%-H
M;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6:6-I;FET>0!3:')I;FL`4VAR
M:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@
M=V%Y(&9I<G-T`%-I97)R82!,96]N90!3:6=N('5P`%-I9VYA='5R90!3:6=N
M871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N
M8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=P!3;F]W(%-H;W=E<@!3;F]W(%-H
M;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO=V5R<R!,871E`%-N
M;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N
M($ES;&%N9',`4V]M86QI80!3;VYG<R`F(%!O96US`%-O<G0@;W)D97(@<V5L
M96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC80!3;W5T:"!%=7)O
M<&5A;B`H25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H
M(%-A;F1W:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B
M971W965N(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A
M;F0@8F]R9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@
M<&%D9&EN9P!3<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P
M;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I($QA
M;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R="!Y96%R`%-T871E(&]R(%!R
M;W9I;F-E`%-T871U<P!3=&]R86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3
M=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H
M92!A9&1R97-S`%-T>6QE(%M#4U-=`%-U`%-U8F1I<F5C=&]R>2`B)7,B(&YO
M="!F;W5N9"X`4W5B:F5C=`!3=6)M:70`4W5B;6ET=&5D(')E<75E<W0@=&\@
M861D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@;&]G(&EN('5N
M=&EL('EO=7(@<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"X`4W5B<V-R:7!T
M`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E
M;2X`4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R
M;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C
M8V5S<V9U;&QY(')E;6]V960@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E
M<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E
M(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A
M=&EO;BX`4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A
M=&EO;B!F:6QE("5S+@!3=6-C97-S9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E
M<W-F=6QL>2!W<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3
M970`4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N
M<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R
M;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`
M4W=I='IE<FQA;F0`4WEN8R!L;V<@9&5L971E9`!3>6YC34P`4WEN=&%X(&5R
M<F]R(&EN('-E87)C:"!T97)M<P!3>7)I86X@07)A8B!297!U8FQI8P!4+5-T
M;W)M`%0M4W1O<FT@86YD(%=I;F1Y`%0M4W1O<FUS`%0M4W1O<FUS($5A<FQY
M`%135B!F:6QE`%1A8FQE`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@4V5T`%1A
M8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI
M;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A
M<F=E=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO
M=7(Z(`!496UP97)A='5R90!496UP97)A='5R93H@`%1E;7!E<F%T=7)E/&)R
M("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,`5&5M<&QA=&4@(B5S(B!N;W0@
M9F]U;F0N`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY
M`%1E>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I("A425,M-C(P*0!4:&%I;&%N
M9`!4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN`%1H92!&5%`@97AT
M96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(:7-T;W)Y('-Y<W1E;2!I
M<R!D:7-A8FQE9"X`5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN
M92!D;V5S(&YO="!S=7!P;W)T("(E<R(`5&AE($E-4U`@;&]G(&-O=6QD(&YO
M="!B92!I;FET:6%L:7IE9"X`5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED
M(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4:&4@3W!T:6]N<R!W:6YD;W<@:&%S
M(&-L;W-E9"X@17AI=&EN9RX`5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@
M8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@
M>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+@!4:&4@8F]T=&]M('-I9&4@
M;VYL>0!4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L
M(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N
M`%1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A
M9&1R97-S(&)O;VLN`%1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K
M(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N`%1H
M92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I
M960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`
M5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+@!4:&4@
M96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN
M96-T:6]N+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I
M;F<N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN
M9W,N`%1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+@!4
M:&4@9FEL92!C;VYT86EN960@;F\@9&%T82X`5&AE(&9O;&QO=VEN9R!A<F4@
M=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92X`
M5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE
M;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E('1O(&)R;W=S97(@8G5G
M<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI
M9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O
M<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)
M9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@
M=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@
M86YD(&YE960@=&\@<F5B;V]T+EQN7&Y9;W4@:&%V92!B965N('=A<FYE9"X@
M(%!L96%S92!P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE
M(&9U;&P@<V-R965N(&5D:71O<BX`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E
M96X@9&5L971E9"X`5&AE(&QE9G0M:&%N9"!S:61E(&]N;'D`5&AE(&QO8V%T
M:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@
M0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@
M)7,@=VET:"!S=6)J96-T("(E<R(@:&%S(&)E96X@9&ES<&QA>65D+@I4:&ES
M(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E
M860@;W(@=6YD97)S=&]O9"X`5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN
M9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H92!N=6UB97(@;V8@9FEE;&1S(&UU
M<W0@8F4@;G5M97)I8RX`5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D
M(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R969E
M<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T
M82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O
M9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T
M(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!Q=6]T92!C:&%R86-T97(@;75S
M="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE(')I9VAT(&%N9"!L969T
M('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S97!A
M<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE('-E<G9E
M<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@
M8F5E;B!S879E9"X`5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E
M;B!R96UO=F5D+@!4:&4@<W!E8VEF:65D(')O=R`H)60I(&1O97,@;F]T(&5X
M:7-T+@!4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="X`5&AE('1E
M;7!O<F%R>2!F:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H92!T97AT('EO
M=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E
M;BX`5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`5&AE('1O<"!S:61E
M(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R
M979I;W5S('-T97`N`%1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S
M879E9"X`5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N
M`%1H96UE<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%1H97)E(&%R92!N
M;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@87)E(&YO('!A<G1S('1H870@
M8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C
M:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@
M8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+@!4:&5R
M92!W87,@82!P<F]B;&5M(&%D9&EN9R`B)7,B('1O('1H92!S>7-T96TZ("5S
M`%1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B`B
M)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@<F5M
M;W9I;F<@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B
M;&5M('5P9&%T:6YG("(E<R(Z("5S`%1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A
M<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y
M=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@
M=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T
M82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O
M<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H
M97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D
M<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4
M:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL
M<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R
M('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A
M9V%I;B!L871E<BX`5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T
M('-H87)I;F<@9F]L9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@
M82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@
M8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E
M(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z
M+R]C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)
M`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U
M9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI(&=A=&5W87DL('5S:6YG
M('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA
M:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G
M:"!T:&4@5F]D869O;F4@271A;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N
M92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@
M5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L
M9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN
M=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A
M;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T
M86P@=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C
M92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@
M8F4@82!V86QI9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@
M8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE
M("<C,3(S-&%F)RX`5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S
M<V5D+@!4:&ES(&ES("5S+@!4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B
M:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M
M86EL(&-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A
M<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@8VQI96YT<R!P
M;&5A<V4@=FES:70@)7,`5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@
M8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@
M;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG
M="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@
M:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@
M82!N=6UB97(N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@
M3W!T:6]N<R!W:6YD;W<`5&AU;F1E<@!4:6-K971S`%1I;64`5&EM92!4<F%C
M:VEN9P!4:6UE(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T90!4
M:71L90!4:71L92`H=&]O;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT:7!L92!I
M=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H
M36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O
M=7)C90!4;V=O`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`5&]O(&UA;GD@:6YV
M86QI9"!L;V=I;G,@9'5R:6YG('1H92!L87-T(&UI;G5T97,N`%1O<`!4;W`@
M9G)A;64@*%]T;W`I`%1R86YS;&%T:6]N<P!4<FEN:61A9"!A;F0@5&]B86=O
M`%1R=64@;W(@9F%L<V4`5'4`5'5N:7-I80!4=7)K97D`5'5R:VES:"`H25-/
M+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L86YD
M<P!4=79A;'4`5'EP92!Y;W5R(&-H;VEC93H@`%4N5BX@:6YD97@Z(`!54DP`
M55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T`%52
M3#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T
M;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE
M;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R
M(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F
M;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N9V4@=&\@)7,N`%5N
M86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S(BX`56YA8FQE('1O(&-H
M96-K(&9I;&4@<VEZ92!O9B`B)7,O)7,B+@!5;F%B;&4@=&\@8V]N;F5C="!T
M;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"X`56YA
M8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I
M<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN
M`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@
M5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F
M:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B;&4@=&\@9&5L
M971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+@!5;F%B;&4@
M=&\@9&5L971E("(E<R(Z("5S+@!5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@
M9&ER96-T;W)Y(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@9&5L971E(%9&4R!D
M:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L92!T;R!D96QE=&4@5D93(&1I
M<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RX`
M56YA8FQE('1O(&1E;&5T92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@9&5L
M971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@(B5S
M(BX`56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B
M;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@
M97AT<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N86)L92!T;R!L;V%D('1H
M92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL92X`
M56YA8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P96X@
M5D93(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T
M;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN`%5N86)L92!T
M;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN`%5N86)L
M92!T;R!R96%D(&9I;&4Z(`!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D
M:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T
M:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@<F5N86UE(%9&
M4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@
M)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O
M(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E;F%M92!61E,@
M9FEL92X`56YA8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N86)L92!T;R!T<F%N
M<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET92!61E,@
M9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F
M86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+@!5
M;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N
M`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO
M;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I
M;&5D`%5N:6-O9&4@*%541BTX*0!5;FET960@07)A8B!%;6ER871E<P!5;FET
M960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N:71E9"!3=&%T97,@36EN;W(@
M3W5T;'EI;F<@27-L86YD<P!5;FET<P!5;FMN;W=N`%5N:VYO=VX@87!I;7-G
M:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT
M($UE<W-A9V4@240I+@!5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+@!5;FMN
M;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE(&-U<G)E;G0@
M96QE;65N=`!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A
M8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S96-U
M<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO
M=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A;&QO
M=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`56YS970@8V]L
M;W(`56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`57!D
M871E('5S97(`57!D871E9"`B)7,B+@!5<&=R861E('-C<FEP="!D96QE=&5D
M+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S
M('1O('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M
M86X@;G5M8F5R<P!5<G5G=6%Y`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,`%5S
M92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V
M97(N`%5S97(`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S
M97(@061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T
M:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T
M:&ES('-I=&4N`%5S97(@86-C;W5N="!N;W0@9F]U;F0`57-E<FYA;64`57-E
M<FYA;64@(B5S(B!A;')E861Y(&5X:7-T<RX`57-E<FYA;64Z`%5S97)N86UE
M.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@9&ER96-T
M;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A=&EO;G,@
M9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O
M;2!N;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S
M+@!686QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B
M;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A
M9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9E<G-I
M;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E
M<G1I8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE=&YA;65S92`H5DE30TE)
M*0!6:65W("5S`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E
M<P!6:7)G:6X@27-L86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3
M+@!6:7-I8FEL:71Y`%9I<VEB:6QI='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@
M4TU44`!705).`%=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&
M4D]-("5S+@!724X@=FEA($A45%``5V%L;&ES(&%N9"!&=71U;F$`5V%R;FEN
M9P!790!796%T:&5R($9O<F5C87-T`%=E871H97(@9&%T82!P<F]V:61E9"!B
M>0!796%T:&5R+F-O;0!796(`5V5B(%-I=&4`5V5E:VQY`%=E;&-O;64`5V5L
M8V]M92!T;R`E<P!796QC;VUE+"`E<P!797-T97)N("A)4T\M.#@U.2TQ*0!7
M97-T97)N("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!386AA<F$`5VAA="!A<'!L
M:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I
M<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@
M8VAA<F%C=&5R/P!7:&5R96ES($%U<W1R86QI82!M87``5VAI8V@@<&AA<V5S
M`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D
M:71O<BX`5VED=&@`5VED=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F('1H92`E
M<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M
M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`5VEK
M:0!7:6YD`%=I;F0@16%R;'D`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7
M:6YD.B``5VES9&]M`%=I<VAL:7-T`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@
M4&AO;F4`5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E
M8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X
M<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@;V9F<V5T("5D('=H:6QE(')E
M861I;F<@82!61E,@9FEL92X`6"U2968`6#4P.78S($)A<VEC($-O;G-T<F%I
M;G1S`%@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4`6#4P.78S(%-U8FIE8W0@
M06QT97)N871I=F4@3F%M90!8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE
M<@!8-3`Y=C,@97AT96YS:6]N<P!960!965E9`%EA:&]O(2!M87``665A<FQY
M`%EE;65N`%EE<P!997,L($D@06=R964`66]U(&%R92!I;B!415A4($U/1$4N
M("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE7
M64<N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E
M9"!B;&]C:W,N`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO=2!C86X@
M;F]T(&AA=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N
M`%EO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U
M(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE
M('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&AA=F4@
M8F5E;B!L;V=G960@;W5T+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E
M;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@
M)RLG(&9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"X`66]U
M(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG
M=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU
M<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N`%EO=2!M=7-T(&1E<V-R:6)E
M('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@
M<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN
M:R!P;VEN=',@=&\`66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D
M96QE=&5D+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@
M;W5T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9
M;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T
M('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@<W!E
M8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E(&$@
M;F5W(&-A=&5G;W)Y(&YA;64N`%EO=2!N965D('1O('!R;W9I9&4@86X@271A
M;&EA;B!P:&]N92!N=6UB97(`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D
M+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R
M($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE
M="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@
M>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO
M=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A
M=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)
M9B!Y;W4@=VES:"!T;R!U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C
M8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@875T:&5N=&EC871I
M;VX@8F%C:V5N9"X`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@
M;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S
M(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R
M;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN
M;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U
M<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S
M(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@
M;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO
M0V]M;6%N9"`K(%`@=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z
M`%EO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R
M(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&QO9VEN
M(&AA<R!E>'!I<F5D+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S
M`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T
M:6]N(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U
M<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S
M<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO
M9R!I;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D(&AA
M<R!E>'!I<F5D+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA
M:7)E`%IA;6)I80!::6UB86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`
M6U!R;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U
M;W1E9"!497AT("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?061M:6YI
M<W1R871I;VX`7T-,20!?1&%T851R964`7T1E;&5T92!2;W<`7T=R;W5P<P!?
M2&5L<`!?26UA9V4@4')O<&5R=&EE<RXN+@!?3&]G(&EN`%],;V<@;W5T`%]-
M;V1I9GD@3&EN:RXN+@!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,
M:6YK+BXN`%]3971U<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`861D
M<F5S<R!B;V]K`&%D9')E<W-E92!U;FMN;W=N`&-A;&5N9&%R`&-A;&T`8V%N
M;F]T(&-R96%T92!O=71P=70@9FEL90!C86YN;W0@;W!E;B!I;G!U=`!C;&EC
M:R!H97)E`&-O;6UA;F0@;&EN92!U<V%G92!E<G)O<@!C;VYF:6=U<F%T:6]N
M(&5R<F]R`&-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<`9&%T82!F;W)M
M870@97)R;W(`961I=`!E;G1R>2!N;W0@9F]U;F0`9F%L;&EN9P!F:6QE`&9R
M;VT@=&AE("5S("@E<RD@870@)7,@)7,`9W5S=&EN9P!H.@!H:`!H;W-T(&YA
M;64@=6YK;F]W;@!I;6UE9&EA=&4`:6YL:6YE`&EN<'5T+V]U='!U="!E<G)O
M<@!I;G1E<FYA;"!S;V9T=V%R92!E<G)O<@!L:6YE<UT`;6MI<V]F<R!E<G)O
M<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N`&UM`&YA;64`;F]T(&EM<&QE
M;65N=&5D`&YO="!Y970@:6UP;&5M96YT960`;F]T97!A9`!P97)C96YT`'!E
M<FUI<W-I;VX@9&5N:65D`'!I>&5L<P!R96UO=&4@97)R;W(@:6X@<')O=&]C
M;VP`<FES:6YG`'-E<G9I8V4@=6YA=F%I;&%B;&4`<VAO=R!D:69F97)E;F-E
M<P!S;7,R96UA:6P@=FEA($A45%``<W,`<W1E861Y`'-W:71C:"!O9F8@:F%V
M87-C<FEP=`!S>7-T96T@97)R;W(`=&%S:R!L:7-T`'1E;7!O<F%R>2!F86EL
M=7)E`'1R>2!A9V%I;@!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF
M:7)M`'5N:69I960`=6YN86UE9`!U<V5R('-E;&5C=`!V0V%R9`!W.@!W96%T
M:&5R+F-O;0!0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,2UC=G,*4F5P
M;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R
M96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO
M;BU$871E.B`R,#`V+3`S+3,P(#$V.C$Q*S`S,#`*3&%S="U4<F%N<VQA=&]R
M.B!4;V]M87,@06%S(#QT;V]M87,N86%S0&UA:6PN964^"DQA;F=U86=E+51E
M86TZ($5S=&]N:6%N(#QD979`;&ES=',N:&]R9&4N;W)G/@I-24U%+59E<G-I
M;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/
M+3@X-3DM,3,*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`("@E
M<R!PY&5V82!T86=A<VDI`"`H2VEI<FML86AV("5S*0`@*"5S('#D979A('#D
M<F%S="D`("ATY&YA*0`@*&AO;6UE*0`@*&5I;&4I`"!K:6ER=7-E9V$@`"(E
M<R(@96D@;VQE(&MA=&%L;V]G+@`B)7,B(&5I(&]L92!V]6EM86QI:R!V86QI
M:RX`(B5S(B!E:2!O;&4@2&]R9&4@<F5G:7-T<FES(&CDY&QE<W1A='5D+@`B
M)7,B('!U=2!E<VET86IA="!E:2!L96ET=60N`"(E<R(@;&ES871I(&=R=7!P
M:61E('/\<W1E96UI+@`B)7,B(&QI<V%T:2#U:6=U<W1E('/\<W1E96UI+@`B
M)7,B(&5I(&QO;V1U9#H@)7,N`"4N,F9-0B!K87-U=&%T=60@:V]K:W4@)2XR
M9DU"+7-T("@E+C)F)24I`"5D("5S(&IA("5S`%-I;G4@<&%R;V]L(&%E9W5B
M("5D('#D979A('#D<F%S="X`)60@<.1E=F$@96YN=7-T=7,`)7,@+2!4Y&AE
M;&5P86YU`"5S('/U<FUE:N1L9P`E<R!+0@`E<R!H;V]L9'5S=/;V9"`M(&MI
M;FYI='5S`"5S('!A:6=A;&1U<P`E<R!K;VYT;R!T86]T;&5M:6YE`"5S(&MA
M<W5T=7-T:6YG:6UU<V5D`"5S(&]N(&IU8F$@;VQE;6%S+@`E<R!K:6ER=7-E
M9V$@)7,@)7,`)7,@;VX@=F%L;6ES('1E9V5M82!A;&QP;V]L(&QO971L971U
M9"!H;V]L9'5S=/;V9"X@3>1R9VES=&$@=/;V9"P@;6ED82!S;V]V:60@<')A
M96=U('1E:&$N`"5S(&]N(&MO:'5S='5S;&EK`"5S(&UI;G5T:70`)7,@96D@
M;&5I='5D+@`E<R!K=6YI("5S("5S+7-T`$MA<W5T86IA("5S(&%A9')E<W-I
M<F%A;6%T`$MA<W5T86IA("5S(&MA;&5N9&5R`$MA<W5T86IA("5S(&WD<FMM
M960`2V%S=71A:F$@)7,@_&QE<V%N9&5D`"5S.B`E<P`E<SH@4V5E('1E861E
M(&5I('!R=75G:2!O;&QA('-A871J86QT+"!K96QL96QT('-E92!P86ES=&%B
M(&]L979A="X@Q')A(&MI:7)U<W1A(&ML]7!S86UA('-E;&QE<R!E<VEN979A
M:60@;&EN:V4@=O5I(&5S:71A;6$@<V%A=&IA;&4@;6EN9VET:7-I:VQI:VMU
M(&EN9F]T+@`L('1U=6QE:6EL:60@`"P@='5U;&5I:6QI9"`E<R`E<P`L('9A
M:&5M:6MU<R`E<R!K=6YI("5S`"TM('9A;&D@+2T`,3(M='5N;FEN92!E<VET
M=7,`,C0M='5N;FEN92!E<VET=7,`,C0@='5N9&D`/$5E;&UI;F4`4V5E(&)L
M;VMK('9A:F%B(&%N9&UE8F%A<VD@='5G92X`2G5H='5S(&MO:'5T878@=FEG
M80!+:7)J82!K<OQP=&5E<FEM:7-E:W,@;VX@=F%J82!A=F%L:6MK=2!01U`@
M=O5T:70N`$%L;&MI<FIA(&MO;G1R;VQL:6UI<V5K<R!O;B!V86IA(&%V86QI
M:VMU(%!'4"!V]71I="X`2W+\<'1E97)I='5D(&MI<FIA(&%V86UI<V5K<R!O
M;B!V86IA(&%V86QI:VMU(%!'4"!V]71I="P@<V%L86IA<W0@4$=0(';U=&ET
M(&IA('-A;&%S]6YA+@!+:7)J82!A;&QK:7)J87-T86UI<V5K<R!O;B!V86IA
M(&%V86QI:VMU(%!'4"!V]71I="P@<V%L86IA<W0@4$=0(';U=&ET(&IA('-A
M;&%S]6YA+@!+<OQP=&5E<FET=60@:VER:F$@879A;6ES96MS(&]N('9A:F$@
M879A;&EK:W4@4R]-24U%(';U=&ET+"!S86QA:F%S="!3+TU)344@=O5T:70@
M:F$@<V%L87/U;F$N`$MI<FIA(&%L;&MI<FIA<W1A;6ES96MS(&]N('9A:F$@
M879A;&EK:W4@4R]-24U%(';U=&ET+"!S86QA:F%S="!3+TU)344@=O5T:70@
M:F$@<V%L87/U;F$N`$MI<FIA(&MR_'!T965R:6UI<V5K<R!O;B!V86IA(&%V
M86QI:VMU(%,O34E-12!V]71I=`!%3"!P:6QV:6YE`$5,(&ME<F=E('9I:&T`
M14P@=FEH;0!%3"!H;V]V:6AM`$5,('1U9V5V(&QU;65S861U`$5,+U!,`$%0
M22!)1`!396QL92!E9&ET;W)I(&EN9F\`26YF;RXN+@!!8G-B;W1T;VT`06)S
M;6ED9&QE`%9&4R!K871A;&]O9VD@;&]O;6ES96MS(&IU=7)D97#DY',@:V5E
M;&%T=60`5D93(&9A:6QI(&QO;VUI<V5K<R!J=75R9&5PY.1S(&ME96QA='5D
M+@!+;VYT;R!I;F9O`$MO;G1O('-A;&%S]6YA`$MO;G1O(&QU:W5S=&%T=60N
M`%)A86UA='5P:61A;6EN90!,:7-A`$QI<V$@86QA;6=R=7!P`$QI<V$@86QA
M;?5I9W5S`$QI<V$@<VEI83H`3&ES82!U=7,@9W)U<'``3&ES82!U=7,@]6EG
M=7,`3&ES82!G<G5P<"`B)7,B(&%L;&$`3&ES82#U:6=U<R`B)7,B(&%L;&$`
M3&ES82!U=7,@:V%S=71A:F$Z`$QI<V$@=F5E<F<`3&ES82!U=65D(&QI:6MM
M960`3&ES82!P86%R`%1E92`E<R!M96[\_"!-;WII;&QA(&O\;&=R:6)A:W,`
M3&ES82!A861R97-S:7)A86UA='5S<V4Z`$QI<V$@;6EN=2!A861R97-S:7)A
M86UA='5S<V4`3&ES82!K87-U=&%J80`B)7,B(&QI<V%T:2!S_'-T965M:2P@
M:W5I9"!TY&EE;F1A=F%T(&QI:71U;6ES:6YF;W0@<&]L;G5D(';U:6UA;&EK
M(&QI<V%D83H@)7,N`"(E<R(@;&ES871I('/\<W1E96UI+B!._/QD(';U:60@
M<VES<V4@;&]G:61A+@!+87-U=&%J871E(&QI<V%M:6YE('!O;&4@;'5B871U
M9"X`06%D<F5S<P!!861R97-S:7)A86UA=`!(86QD=7,@+2!M=75D82!T96ES
M=&4@:V%S=71A:F%T92#U:6=U<VD`2&%L9'5S`%)E:VQA86T`069G86YI<W1A
M;@!!;&)A86YI80!!;'IE97)I80!!;&EA<P!*;V]N9'5S`$IO;VYD=7,Z`$OU
M:6L`2_5I:R!S:7-S96QO9VET=60@:V%S=71A:F%D`$OU:6L@9W)U<&ED`$OU
M:6L@]6EG=7-E9`!+]6EK(&YE;&D@:_QL9V4`3'5B82!M:71U="!A861R97-S
M:0!,=6)A(&WDY')A=&$@:N1R:F5S=&%T=60@;&]E;F1I('3\_'``3VX@:G5B
M82!O;&5M87,`06QT97)N871I:79N92!)35-0(&MO;G1O`$%L=&5R;F%T:6EV
M;F4@24U34"!S86QA<_5N80!!;'1E<FYA=&EI=FYE($E-4U`@:V%S=71A:F%N
M:6UI`$%L=&5R;F%T:6EV;F4@92UP;W-T:2!A861R97-S`$%L=&5R;F%T:6EV
M<V5D(&UA;&QI9`!!;'1E<FYA=&EI=FYE('1E:W-T.@!!;65E<FEK82!386UO
M80!3:7-E<W1A=&D@;'5B86UA='4@=N3D<G1U<RX`2G5H='5S('1U;F1M871U
M('9I9V$`06YD;W)R80!!;F=O;VQA`$%N9W5I;&QA`$%N;V[\_&UN92!V86AE
M;F1A:F$`5F%S='5S`$%N=&%R:W1I:V$`06YT:6=U82!J82!"87)B=61A`%)A
M:V5N9'5S`%)A:V5N9'5S=&4@;FEM96MI<FD`4F%K96YD=7,@;VX@=/;V=F%L
M;6ES+@!286ME;F1A(&%L86UJ86=U9&5L90!+:6YN:71A`$QI9VEK875D;F4@
M<W5U<G5S`$%P<FEL;`!!<F%A8FEA("A7:6YD;W=S+3$R-38I`$%R:&EI=FD@
M<W5U<G5S`$%R:&EI=FD@;FEM:0!/;&5D('-A(&MI;F1E;"!E="!S;V]V:60@
M)7,@;&EI='5M:7-S;V]V:2!K=7-T=71A9&$_`$]L960@<V$@:VEN9&5L(&5T
M('-O;W9I9"!K=7-T=71A9&$@9W)U<&D@(B5S(B!J82!K]6EK('1E;6$@86QA
M;6=R=7!I9#\`07)G96YT:6EN80!!<FUE96YI80!!<FUE96YI82`H05)-4T-)
M22TX*0!+=6YS=`!!<G5B80!,:6AA=O5T=&5S86%R`$%30TE)(&IO;VYI<W1U
M<P!!87-I82]686EK<V4@;V]K96%N:2!P:6ER:V]N9`!+_'-I(&AO;VQD=7-T
M]O9D92!T96=E;6ES96MS(&MI;FYI='5S=`!6965R=60`2V%T<V4@:W5S='5T
M861A(&]L96UA='5T(&=R=7!P:2X`2V%T<V4@:W5S='5T861A(&]L96UA='5T
M(/5I9W5S="X`2V%T<V4@;75U=&$@;VQE;6%T=70@]6EG=7-T+@!+871S92!M
M=75T82!O;&5M871U="!J86=U+@!!=')I8G5U9&ED`$%U9W5S=`!!=7-T<F%A
M;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ('9A:F%L:6MK=2!)34%0(&QA:65N
M9'5S="!E:2!L96ET=60N`$%U=&A?8WER=7,Z('/\<W1E96UI;"!P=75D=79A
M9"!V86IA;&EK=60@=O5I;65D+@!!=71H7V-Y<G5S.B!V86IA;&EK:W4@24U!
M4"!L86EE;F1U<W0@96D@;&5I='5D+@!!=71H7V9T<#H@5F%J86QI:VMU($94
M4"!L86EE;F1U<W0@96D@;&5I='5D+B!+;VUP:6QE97)I(%!(4"!V]71M96=A
M("TM96YA8FQE+69T<"X`075T:%]I;6%P.B!686IA;&EK:W4@24U!4"!L86EE
M;F1U<W0@96D@;&5I='5D+@!!=71H7VMR8C4Z(%9A:F%L:6MK=2!K<F(U(&QA
M:65N9'5S="!E:2!L96ET=60N`$%U=&A?;&1A<#H@06-T:79E($1I<F5C=&]R
M>2=S<V4@:V%S=71A:F%T92!L:7-A;6ES92!T=6=I('!U=61U8@!!=71H7VQD
M87`Z($%C=&EV92!$:7)E8W1O<GES="!K87-U=&%J871E(&5E;6%L9&%M:7-E
M('1U9VD@<'5U9'5B`$%U=&A?;&1A<#H@5F%J86QI:VMU($Q$05`@;&%I96YD
M=7-T(&5I(&QE:71U9"X`075T:%]L9&%P.B!%:2!S86$@;&ES861A(&MA<W5T
M86IA="`E<RX@4V5R=F5R(/QT;&5S.B``075T:%]L9&%P.B!%:2!S86$@965M
M86QD861A(&MA<W5T86IA="`E<P!!=71H7VQD87`Z($5I('-A82!M=75T82!K
M87-U=&%J870@)7,`075T:%]L9&%P.B!!8W1I=F4@1&ER96-T;W)Y(&MA<W5T
M86IA=&4@;75U=&UI<V4@='5G:2!P=75D=6(N`$%U=&A?;6-A;#H@5F%J86QI
M:VMU($U#04P@;&%I96YD=7-T(&5I(&QE:71U9"X`075T:%]S;6)A=71H.B!6
M86IA;&EK:W4@<VUB875T:"!L86EE;F1U<W0@96D@;&5I='5D+@!3:7-S96QO
M9VEM:6YE(&YU<FIU<P!3:7-S96QO9VEM:6YE(&YU<FIU<RX@)7,`4D%$2553
M('-E<G9E<B!E:2!L=6)A;G5D('-I<W-E(&QO9VED82X`1E10('-E<G9E<FES
M<V4@<VES<V5L;V=I;6EN92!N=7)J=7,N`%--0B!S97)V97)I<W-E('-I<W-E
M;&]G:6UI;F4@;G5R:G5S+@!+87-U=&%T879A9"!VY&QJ860Z`$%S97)B86ED
M>F%A;@!"3T9((&5T=&5KY.1N9&5D`%1A=7-T`%1A=7-T82!VY')V`%9A;&4@
M:V5R8F5R;W-E('-A;&%S]6YA+@!686QE(&ME<F)E<F]S92!K87-U=&%J86YI
M;6DN`$)A:&%M80!"86AR96EN`$)A;'1I("A)4T\M.#@U.2TQ,RD`0F%N9VQA
M9&5S:`!"87)B861O<P!'<F%A9FEK82!P]6AI:V%T86QO;V=I("(E<R(@96D@
M;&5I='5D+@!"87-E;&EN90!686QG979E;F4`0F5L9VEA`$)E;&EZ90!"96YI
M;@!"97)M=61A`$)H=71A;@!3_&YN:7#D978`0FQO:VMI("(E<R(@<F%K96YD
M=7-E<R`B)7,B(&5I(&QE:71U9"X`0FQO:VD@:.3D;&5S='5S`$)L;VMI('3\
M_'``4&%K<R!K:7)I`$)O;&EI=FEA`$KD<FIE:&]I9&IA9`!0:6ER:F]O;@!*
M;V]N92!P86MS=7,Z`%!I:7)J;V]N960`0F]S;FEA(&IA($AE<G1S96=O=FEI
M;F$`3?5L96UA9`!";W1S=V%N80!!;&QA`$)O=79E="!S86%R`$)R87-I:6QI
M80!"<FET:2!);F1I82!/;VME86YI(%1E<G)I=&]O<FEU;0!"<G5N96D@4W5L
M=&%N:7)I:6L`0G5L9V%A<FEA`$QO971E;'4`0G5R:VEN82!&87-O`$)U<G5N
M9&D`4VES=6AA;&1U<P!#4D,`5/QH:7-T=7-N:6UE:VER:F$@:F%O='5S<'5N
M:W1I9`!,7V%H=')I(&]M861U<V5D+BXN`%9A:&5MY&QU(&EN:71S:6%L:7-E
M97)I;6EN92!E:2!J]75D;G5D(&SU<'5L92X`2V%L96YD97(`5F%I:VYE`$MA
M;6)O9'IH80!+86UE<G5N`%!A<F]O;&D@96D@<V%A(&%U=&]M86%T<V5L="!T
M_&AI<W1A9&$L(';U=&$@_&AE;F1U<W0@861M:6YI<W1R86%T;W)I9V$N`$5I
M(/5N;F5S='4@:VER:G5T861A(&9A:6QI("(E<R(`5N1L:7-E:60@<V5S<VEO
M;VYI:&%L9'5R96ED('!O;&4@=O5I;6%L:6L@861M:6YI<W1R965R:61A+@!%
M:2!S86$@_&AE;F1U<W0@24U!4"!S97)V97)I9V$Z("5S`$5I(/5N;F5S='4@
M879A9&$@9F%I;&D@(B5S(@!+86YA9&$`3&]O8G4`3&]O8G4`16D@]6YN97-T
M=2!K=7-T=71A9&$@9F%I;&D@(B5S(BX`16D@;&5I82!A:G5T:7-T(&MA=&%L
M;V]G:0!);&UA("=T87)G971&:6QE)R!P87)A;65E=')I=&$@96D@<V%A(&KD
M=&MA=&$N`$5I(/5N;F5S='4@965M86QD861A(&MA=&%L;V]G:2`B)7,B+@!%
M:2!S86$@965M86QD861A+"`E9"UL(&]N(&%L;'5V86ED+@!%:2!S86$@_&UB
M97(@:N1R:F5S=&%D82P@_&UB97)JY')J97-T86UI<V5K<R!MY.1R871U9"!K
M86YN971E(&%R=B!E:2!K;&%P:2!S86QV97-T871U9"!A<G9U9V$N`$5I('-A
M82!S=75N871A('1E861E="!MY.1R871U9"!N=6UB<FEL92X`4F]H96QI<V4@
M3F5E;64@<V%A<F5D`%!E86QK:7)I`%1E96YU<V5P86MK=6IA`$MA=&5G;V]R
M:6%D(&IA(&WD<F=E;F1I9`!#87EM86YI(%-A87)E9`!-;V)I:6QT96QE9F]N
M`$QA:'1R:2!O;6%D=7-E9`!,86AT<FD@=F]O9&5R9'5S.@!,86AT<FD@;VUA
M9'5S960`3&%H=')I=&4@=F%H96MA=6=U<SH`36]B:6EL=&5L969O;@!+96QT
M:2`H25-/+3@X-3DM,30I`$ME<VME;&4`2V5S:RU!869R:6MA(%9A8F%R:6EK
M`$ME<VLM175R;V]P82`H25-/+3@X-3DM,BD`4V5R=&EF:6MA861I(/QK<VEK
M87-J860`4V5R=&EF:6MA861I(&]M86YI:P!397)T:69I:V%A9&D@<&]L:6ET
M:6MA9`!4<VAA860`375U9&$`375U9&$@<V%L87/U;F$`375U9&$@;FEM92!J
M82!A861R97-S:2!M:61A(&EN:6UE<V5D(&[D979A9"!K=6D@;F%D('-I;G4@
M:VER:G4@;&]E=F%D(&IA(&YE:6QE('9A<W1A=F%D+@!3_'-T965M:2!K;VYF
M:6=U<F%T<VEO;VX@96D@=O5I;6%L9&$@<V%L87/U;F$@;75U=&$N(%;U=&$@
M_&AE;F1U<W0@(&%D;6EN:7-T<F%A=&]R:6=A+@!-Y')K`%]+;VYT<F]L;&D@
M;&EN:VDN+BX`5'-H:6EL:0!(:6EN80!(:6EN82!L:6AT<W5S=&%T=60@*$="
M,C,Q,BD`2&EI;F$@=')A9&ET<VEO;VYI;&EN92`H0FEG-2D`5F%L:2!R86ME
M;F1U<SH`5F%L:2!S86QA<_5N80!686QI(&MA<W5T86IA;FEM:0!686QI(&MU
M=7#D979A9&4@97-I='5S=FEI<SH`5F%L:2!L;V5N9&D@<W1I:6P@*&KD<FIE
M<W1A='5D(&QO96YD:71E(&IA;VMS*0!*]75L=7-A87)E9`!+;&%S<VD@)7,@
M:VER:F5L9'5S="!E:2!L96ET=60N`%-E;&=E`$5E;6%L9&$@35-/9F9I8V4@
M;>1R9V5N9&ED`%3\:&IE;F1A('#D<FEN9P!%96UA;&1A(&MA<W5T86IA.B`E
M<P!%96UA;&1A(&MA<W5T86IA`%3\:&IE;F1A(&MA<W5T86IA(&%N9&UE9`#5
M:'1U;"!S96QG:6YE8@!+;/5P<V$@:N1T:V%M:7-E:W,`0VQI8VMA=&5L;"#\
M;&4@2%144`!3=6QE(&%K96X`4&EL=F5D`$AO;6UI:W5L('!I;'9E<P!0:6QV
M97,`2V]O:V]S<V%A<F5D("A+965L:6YG:2!S86%R960I`%!E:61A(&O\;&=R
M:6)A`%!E:61E='5D('!I:7)J;V]N960`2V]L=6UB:6$`5N1R=@!6Y')V:79A
M;&EK`%;D<G9I('9A;&EK`%9E97)G93H`5F5E<F=U9&4@<&5A;&MI<FIA9`!+
M;V]M:6MS:60`2^1S:P!+Y'-U<FED80!+;VUM96YT86%R`$QI:'1N:6UI`$MO
M;6]O<FED`$9I<FUA`$%R=G5T:60`26QM`$EL;0!+;VYF:6=U<F%T<VEO;VYI
M(&5R:6YE=G5S960`4V5A9&ES='5S('/\;FMR;VYI<V5E<FEM:7-E:W,@4$1!
M9&4L(&YU=&ET96QE9F]N:61E(&IA($]U=&QO;VMI9V$N`%-E861I<W1U<R!O
M;B!A96=U;G5D+@!396%D:7-T82`E<P!+:6YN:71A('-A;&%S]6YA`$MO;F=O
M`$MO;F=O($1E;6]K<F%A=&QI:R!686)A<FEI:P#<:&5N9'5S(&YU<FIU<RX`
MW&AE;F1U<R!N=7)J=7,Z(`!!=F%L:6L@=O5T;65S97)V97(@96D@86YN82#\
M:&5N9'5S="X`079A;&EK(';U=&UE<V5R=F5R(&5I(&%N;F$@_&AE;F1U<W0N
M(%#U:&IU<SH@)7,@*"5S*0#<:&5N9'5S($944"!S97)V97)I9V$@;G5R:G5S
M+@!+;VYT86MT:60`2V]N=&%K=&ED(/5N;F5S='5S(&QI<V%D82!S:6YU(&%A
M9')E<W-I<F%A;6%T=7-S92X`(B5S(B!S:7-U`$KD=&MA`$-O;VMI(%-A87)E
M9`!-]71T971E<F$`2V]P965R:0!+;W!E97)I;6EN92!N=7)J=7,Z("5S`$MO
M<&5E<FD@=F%L:6L`0V]S="!)1`!+;W-T87)I:6MA`$-O=&4@9"=)=F]I<F4`
M16D@<V%A;G5D(&MI<FIA(%!'4&=A(&MR_'!T:61A+@!%:2!S86%N=60@:VER
M:F$@4$=09V$@86QL:VER:F%S=&%D82X`16D@<V%A;G5D(&MI<FIA(%,O34E-
M16=A(&MR_'!T:61A+@!%:2!S86%N=60@:VER:F$@4R]-24U%9V$@86QL:VER
M:F%S=&%D82X`16D@<V%A;G5D(&QI<V%D82!K;VYT86MT:2X@)7,`16D@<V%A
M;G5D('-I<W-E($Q$05`@<V5R=F5R:7-S92X`16D@<V%A;G5D('-I<W-E($Q$
M05`@<V5R=F5R:7-S90!%:2!S86%N=60@:V]N=&]JY.1K:2!K;VYT<F]L;&ED
M82X@)7,`16D@<V%A;G5D(/QH96YD=7-T($Q$05`@<V5R=F5R:6=A+@!%:2!S
M86%N=60@<V5R=F5R:6=A("(E<R(@1E10(&%B:6P@_&AE;F1U<W0Z("5S`$IA
M;W1U<VYI;65K:7)J82!L;V]M:6YE(&YU<FIU<RX@)7,`16D@<V%A;G5D(%!'
M4"!A;F1M96ED(&1E:W+\<'1I9&$N`$5I('-A86YU9"!3+TU)344@86YD;65I
M9"!D96MR_'!T:61A+@!%:2!S86%N=60@:W5S='5T861A(&MO;G1A:W1I+B`E
M<P!%:2!S86%N=60@:W5S='5T861A(&IA;W1U<VYI;65K:7)J82X@)7,`16D@
M<V%A;G5D(&MU<W1U=&%D82!P86EG86QD=7-E('5U96YD86UI<V4@<VMR:7!T
M:2`B)7,B+@!%:2!S=75T;G5D(';D;&IA('-E;&=I=&%D82!A9')E<W-A861I
M(&4M<&]S=&D@86%D<F5S<P!+;V=U(&%A9')E<W-I<F%A;6%T=2!K;VAA;&5T
M:7)I;6EN92!N=7)J=7,N`$MO9W4@:F%O='5S;FEM96MI<FIA(&MO:&%L971I
M<FEM:6YE(&YU<FIU<RX`2V]G=2!J86]T=7-N:6UE:VER:F%D92!N:6UE:VER
M:F$@:V]H86QE=&ER:6UI;F4@;G5R:G5S+@!%:2#U;FYE<W1U;G5D(&QA861I
M9&$@<W1R871E96=I870@(B5S(BX`;6MD:7(@(B5S(B!N=7)J=7,N`$5I('-A
M86YU9"!V]71M97-E<G9E<FES="!A=F%L:6MK=2!V]71I="!KY'1T92X`(B5S
M(B!A=F%M:6YE(&MI<FIU=&%M:7-E:W,@;G5R:G5S+@`E<R!A=F%M:6YE(&YU
M<FIU<RX`16D@<W5U=&YU9"!KY&EV:71A9&$@:&]O;&1U<W3V]B!M;V]D=6QI
M="`E<P!%:2!S86%N=60@879A9&$@:V%T86QO;V=I("(E<R(N`$5I('-A86YU
M9"!KY'1T92!,1$%0('-E<G9E<FET+@`E<R!L=6=E;6EN92!N=7)J=7,N`%-O
M;W9I='5D(&MA<W5T86IA('!A<F]O;&D@=/QH:F5N9&%M:6YE(&YU<FIU<RX@
M3?5N960@86YD;65D(&5I(&]L92#U:6=E9"X@4')O;W9I('5U97-T:2!V]6D@
M=O5T82#\:&5N9'5S="!A9&UI;FES=')A871O<FEG82P@:W5I('9A:F%D('-I
M:7-K:2!A8FDN`$%#3&D@;&%A9&EM:6YE(&5B8?5N;F5S='5S`$%A9')E<W-I
M<F%A;6%T=2!L86%D:6UI;F4@96)A]6YN97-T=7,N("5S`$IA;W1U<VYI;65K
M:7)J82!L86%D:6UI;F4@96)A]6YN97-T=7,N("5S`$IA;W1U<VYI;65K:7)J
M861E(&QA861I;6EN92!E8F'U;FYE<W1U<RX@)7,`4V5R=F5R:2!V]6EM86QU
M<W1E(&QA861I;6EN92!E8F'U;FYE<W1U<P!+;VYF:6=U<F%T<VEO;VYI('1A
M9V%S:6UU=71M:6YE(&YU<FIU<RX`<FUD:7(@(B5S(B!E:2#U;FYE<W1U;G5D
M+@`E<R!S96%D:7-T=7-E('-A;'9E<W1A;6EN92!N=7)J=7,N`$MO;F9I9W5R
M871S:6]O;FD@=F%R=6MO;W!I82!S86QV97-T86UI;F4@;G5R:G5S+@!+;VYF
M:6=U<F%T<VEO;VYI('9A<G5K;V]P:6$@<V%L=F5S=&%M:6YE(&YU<FIU<SH@
M)7,`4&%I9V%L9'5S92!U=65N9&%M:7-E('-K<FEP=&D@96D@<V%A;G5D('-A
M;'9E<W1A9&$@:V]H=&$Z("(E<R(N`$5I(/5N;F5S='5N=60@<V%L=F5S=&%D
M82!K;VYF:6=U<F%T<VEO;VYI9F%I;&D@=F%R=6MO;W!I870@)7,N`$MO;F9I
M9W5R871S:6]O;FEF86EL:2`E<R!E:2#U;FYE<W1U;G5D('-A;'9E<W1A9&$N
M(%-A(';U:60@:V%S=71A9&$@_&AT(';U:6UA;'5S="!K;V]D:2!S86QV97-T
M86UI<V5K<R!T86=A<VD@9F%I;&D@)7,@=O5I(&MO<&5E<FED82!K;V]D(&OD
M<VET<VD@9F%I;&D@)7,N`$Q$05`@;W1S:6YG(&YU<FIU<RX`=6YL:6YK("(E
M<R(@;G5R:G5S+@!+;VYT86MT:2!U=65N9&%M:6YE(&YU<FIU<RX@)7,`2F%O
M='5S;FEM96MI<FIA('5U96YD86UI;F4@;G5R:G5S+B`E<P`B)7,B('-E861I
M<W1U<V4@<V%L=F5S=&%M:6YE(&YU<FIU<SH@)7,`16D@;&5I9&YU9"!-;WII
M;&QA(&O\;&=I<F)A+B!686%T82!E="!K_&QG<FEB82!O;&5K<R!A=F%T=60N
M`$MA<W5T86IA;&4@(B5S(B!E:2!S86%N=60@86YD82!JY')G;6ES:2#U:6=U
M<V5I9"!K875S=&%L92`B)7,B.B`E<P!0:6ER871U9"!P:6MK=7-E9V$@=&5K
M<W0`4FEI:P!+=7)S=7-E9`!,;V\`3&ES82!L:6YK`$QI<V$@=75S`$QI<V$@
M86QA;6MA=7-T860`075T;W)I(/5I9W5S960`2W)E9&EI=&MA87)D:2!N=6UB
M97(`2&]R=F%A=&EA`$MU=6)A`%!R865G=7-E9"`T(&9A87-I`$%K=&EI=G-E
M9"!S97-S:6]O;FED`$ME;&QA865G`%!R865G=6YE(%523"!O;@!!:W1I:79S
M960@:V%S=71A:F%D`%!R865G=6YE(&EL;0!0<F%E9W5N92!I;&TZ`%!R865G
M=6YE('-T:6EL`$CDY&QE<W1A('3V:60@;6ED82!T96AA:W-E('-I<V5N96UI
M<V5L("5S+6DN`$SU:6MA`$SU:6MA('9A;&EK`$O\<')O<P!+:7)I;&QI='-A
M("A+3TDX+5(I`$MI<FEL;&ET<V$@*%=I;F1O=W,M,3(U,2D`2VER:6QL:71S
M82]5:W)A:6YA("A+3TDX+54I`%1S96AH:2!686)A<FEI:P!04`!$4TX@*'9A
M871A(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T
M86)A<V4N9&(N:6YT<F\M9'-N+G!H<"D`26=A('#D978`1&%T851R964@<VER
M=FEJ80!!;F1M96)A87-I;W1S:6YG`$MU=7#D978`4V%A8G5M:7-E(&MU=7#D
M978`2W5U<.1E=F$@=F%L:6L`4.1E=@!+=5]S='5T82!V965R9P!$971S96UB
M97(`2_QM;F5N9&YU;6)R:60`5N1H96YD82!T86%N9')I9&$`5F%I:VEM:7-I
M`%9A:6MI;6ES:2!VY')V`%9A:6ME:61E;G1I=&5E=`!686EK:6UI<VD@<VAE
M;&P`4_5N87-E;&5T=7-E9`!+=7-T=71A`$MU<W1U=&$@;&%H=&5R`$MU<W1U
M=&$@9W)U<'``2W5S='5T82!L;V=I`$MU<W1U=&$@]6EG=7,`2W5S='5T82!J
M82!E96UA;&1A(&MI<FIA9`!+=7-T=71A(&QA:'1E<@!+=7-T=71A('9E97)G
M`$MU<W1U=&$@;VQE;6%S;VQE=B!A;'1E<FYA=&EI=FYE(&UA;&P`2VER:F%D
M92!K=7-T=71A;6EN90!+=7-T=71A(/5I9W5S960@(B5S(BUL90!+=7-T=71A
M(/5I9W5S960@(B5S(BUL92!J82!K]6EK(&%L86WU:6=U<V5D/P!+=7-T=71A
M(')I9&$`2W5S='5T82!V86QI='5D(&ED96YT:71E970`2W5S='5T82!A:W1I
M:79N92!V965R9P!+=7-T=71A(&%K=&EI=FYE(')I9&$`2W5S='5T87-I;B!P
M86EG86QD=7-E('5U96YD86UI<V4@<VMR:7!T:2`B)7,B+@!+Y'1T971O:6UE
M=&%M:7-E(&%E9P!486%N:0!+:7)J96QD82!P<F]B;&5E;6D`2VER:F5L9'5S
M`-QK<VEK87-J860@*&MA;G1U9"!K82!(;W)D92!L;V=I9F%I;&DI.@#<:W-I
M:V%S:F%D(&QO9VET:2!A9&UI;FES=')A871O<FD@:F%O:W,N`$%R96YD=7,`
M2V%S=&5P=6YK=`!%96QM:7-E('1U;FYI(&MA<W1E<'5N:W0`2V%S=&5P=6YK
M=#H`4W5U;F0@=F%S86MU;'0@<&%R96UA;&4`4W5U;F0@<&%R96UA;'0@=F%S
M86MU;&4`2V%T86QO;V<`17-I=&$@:V5L;&%A:F%D(#(T+71U;FYI<V5N80!%
M:W)A86YI('-E861E9`!.Y&ET82!P]6AJ86QI:VMU(&5N;G5S='5S=`!.Y&ET
M82!E;FYU<W1U<W0@*%1!1BD`16MR86%N:2!S96%D960`1&ES<&]S:71I;VX@
M3F]T:69I8V%T:6]N`$1J:6)O=71I`,1R82!K=7-T=71A`,1R82#\<FET82!M
M86EN=&5N86YC92YP:'`@9F%I;&D@;W1S92!KY&EV:71A9&$`2W5I(&5S:6UE
M;F4@<FED82!S:7-A;&1A8B!VY&QJ861E(&YI;65S:60L(&WD<F=I('-E92!R
M=75T.@!$;VUI;FEC80!$;VUI;FEK86%N:2!686)A<FEI:P!3=6P@<&]L92!K
M;VYT;W0_(%)E9VES=')E97)U+@!386QV97-T80!386QV97-T82`E<P!386QV
M97-T82!L;V]D=60@<V5A9&ES='5S(%!(4"!S:W)I<'1I;F$N`$YI;65K:7)I
M`%)A=FEM:60`12UP;W-T`$4M<&]S="U335-I;&4@=F%H96YD=7-D<F%I=F5R
M+"!T965N=7-E<&%K:W5J871E;&4@:V5L;&5L('-E;&QI;F4@=&5E;G5S(&]N
M`$524@!%:W5A9&]R`$UU=61A`$UU=61A(&)L;VMK:0!-=75D82!G<G5P<&D`
M375U9&$@]6EG=7-T`$UU=61A(/5I9W5S:0!-=75D82`E<R#U:6=U<VD`375U
M9&$@<V5A9&5I9#H`375U9&$@(B5S(B#U:6=U<VD`375U9&$@)7,@]6EG=7-I
M`$AA<FED=7,`16=I<'1U<P!,_&QI=&$@<V5E('-I<W-E(&IA('-I:7,Z("5S
M+"!V]6D@:V%S=71A(&QI:'1S870@2%1-3"!V97)S:6]O;FDZ("5S+@!%;"!3
M86QV861O<@!%;&5M96YT+BXN`$5M`$4M<&]S=`!%+7!O<W1I(&%A9')E<W,`
M12UP;W-T:2!A861R97-S:60@<&5A=F%D(&ML87!P:6UA+@!%+7!O<W0@:VEN
M;FET=7-E9V$`12UP;W-T+5--4VEL92!L_/QS`%-M86EL:60`4_5N=6T@;VX@
M=/QH:2X`5'5L96UU<R!O;B!T_&AI+@!/='-I;F=U=&EN9VEM=7,@;VX@=/QH
M:0!,=6)A('1E:W-T:2!S:7-S92!L:7-A9&$@<&EL=&4@9F]T;V=A;&5R:6ED
M97-T`$QU8F$@<&%R96UK;/5P<W5G82!H_'!I:VUE;OS\`$%A<W1A(&SU<'``
M4W5U<F5N9&$@961I=&]R`%-I<V5S=&$@<V%L86IA;F4@:_QS:6UU<R!M:61A
M('-I;G5L="!K_'-I=&%K<V4@<&%R;V]L:2!M=75T;6ES96MS+"!NY&ET96MS
M("=M:7,@;VX@<VEN=2!L96UM:6ML;V]M82!N:6UI/R<Z`%-I<V5S=&$@<VEI
M82!P:6QD:2!54DP`4VES97-T82!A;&QA('3D:&5D.@!%:W9A=&]R:6%A;"U'
M:6YE80!%<FET<F5A`%9I9V$`5FEG82!B;&]K:2!L;V]M:7-E;#H@)7,`5FEG
M82!S_&YK<F]N:7-E97)I;6ES86YK<G4@:W5S='5T86UI<V5L.B`E<P!6:6=A
M('/\;FMR;VYI<V5E<FEM:7-E(&QO9VD@:W5S='5T86UI<V5L.B`E<P!6:6=A
M('-I<W4@;&%A9&EM:7-E;#H@)7,`5FEG82!S86QA<_5N82!M=75T;6ES96PZ
M("5S`%9I9V$@92UP;W-T:2!T96%T97,N`%9I9V$@(B5S(B!K:7)J=71A;6ES
M96PN`$5E<W1I`$5T:6]O<&EA`%)A:'9U<VQI:P!%=7)O;W!A`$EG82`Q-2!M
M:6YU=&D@=&%G86YT`$EG82`R(&UI;G5T:2!T86=A;G0`26=A(#,P('-E:W5N
M9&D@=&%G86YT`$EG82`U(&UI;G5T:2!T86=A;G0`26=A;"!S:7-S96QO9VEM
M:7-E;`!)9V$@<&]O;&4@='5N;FD@=&%G86YT`$MO<F0@;6EN=71I<P!.Y&ED
M:7-VY.1R='5S960Z`$OD:79I=&$`3&%I96YD80!.Y&ET82!K_&QG<FEB80!/
M;W1A<VEN("<I)P!/;W1A<VEN(&QI:'1S870@<_5N82!V]6D@:G5T=6WD<FMI
M9&5S(&]T<VEN9W5F<F%A<VD`065G=6UI<V4@:W5U<.1E=@!%:W-P;VYE;G0`
M5&5K<W1I(';D<G8`4V5A9&ES='5S92#\;&5S;&%A9&EM:6YE($944"!K875D
M=0!(Y.1L97-T=7-E(&QA861I;6EN92!N=7)J=7,N`$5I('-A86YU9"#\:&5N
M9'5S="!,1$%0('-E<G9E<FEG82X`16D@<V%A;G5D(/QH96YD=7-T(%--0B!S
M97)V97)I9V$N`$5I('-A86YU9"!K;W!E97)I9&$@(B5S(BUS="X`16D@<V%A
M;G5D(&MO<&5E<FED82`B)7,B+6DN`%5U92!305-,(/QH96YD=7-E(&QO;VUI
M;F4@;G5R:G5S+@!%:2!S86%N=60@=/5S=&$@(B5S(BUI+@!%:2!S86%N=60@
M=&ER:61A.B`E<P!(96$`1F%L:VQA;F1I('-A87)E9"`H36%L=FEI;FED*0!&
MY.1R:2!S86%R960`2V]H=71A=B!V:6=A.@!&86MS`$9A:W-I9`!6965B<G5A
M<@!4=6YD=6(@;F%G=0!4=6YD=6(@;F%G=3H@`-QK<VEK=60@=FEH;6%H;V]D
M`-QK<VEK=60@;'5M97-A:G5H;V]D`$9I96QD(&UA=')I>`!&:6=L970@0T%0
M5$-(00!&:6=L970@9F]N=`!&:61Z:0!&86EL`$9A:6QI9&4@87)V.B`E<R!F
M86EL`$9A:6QI9&4@87)V.B`E<R!F86EL:0!&86EL:6AA;&1U<@!&86EL:2!N
M:6UI`$9A:6QI('9A;&EK`$9A:6QI(/QL97-L86%D:6UI;F4`1F%I;&ED92#\
M;&5S;&%A9&EM:7-T(&5I('1O971A=&$N`$9I;'1R:60`4V]O;64`17-I;65N
M92!P;V]L`$5S:6UE;F4@=F5E<F%N9`!3Y&EL:71A('-U:&4`4&5E9V5L9&$`
M2/5L:G5V`%5D=0!+871A;&]O9VD@)7,@<&]L92!O;&5M87,`5&5K<W1I(';D
M<G8`5&]I=`!6965B:6QE:&ET<V5J871E;&4@;6ES('!I;'1E(&5I('1O971A
M`$5N;G5S='5S("A4048I`%#D979A9&4@87)V("AO;&=U(/9E;&1U9"!E="!T
M86=A<W1A=&%V(&5N;G5S='5S('-I<V%L9&%B(&YI:2!PY&5V:2!K=6D@]FED
M.R!S=75R(&%R=B!V]6EB(&)L;VMI(&QA:6%K<R!V96YI=&%D82D`56YU<W1A
M<VED('-A;&%S]6YA/P!6;W)M:60`2VEL9`!+:6QL=2!T_/QP`$MI;&QU9`!+
M:6QL=60@,@!&;V]R=6UI9`!%9&%S='5S`%)E`%)A86UI9`!0<F%N='-U<VUA
M80!0<F%N='-U<VUA82P@175R;V]P82UO<V$`4')A;G1S=7-E($=U86IA86YA
M`%!R86YT<W5S92!0;VS\;F5E<VEA`%!R86YT<W5S92!,]75N86%L860`2V5L
M;&5L=`!3=75N86=A(`!0]6AJ86QI:R!K:7)J96QD=7,`5.1I<VMU=0!4Y&ES
M;FEM:0!'86)O;@!'86QE<FEI+"!K=7-T('!I;'0@=O5T=&$`1V%L97)I:3H`
M1V%M8FEA`$=E;F5R965R:2`E<R!K;VYF:6=U<F%T<VEO;VX`1V5N97)E97)I
M='5D(&MO;V0`1W)U=7-I80!386MS86UA80!'86%N80!':6)R86QT87(`165S
M;FEM:0#<;&1I<V5D('-E861E9`!-:6YE`$?V9&5L`$=O;V=L92!K86%R9&ED
M`$=O;V=L92!O='-I;F<`2&%L;'1O;VYI9&5S<V4`2W)E96MA`$MR965K82`H
M25-/+3@X-3DM-RD`1W+V]FYI;6%A`$=R96YA9&$`1W)U<'!I9&4@:&%L9'5S
M`$=R=7!P:61E(&YI;65D(&5I(';U:2!O;&QA('3\:&IA9`!'<F]U<%]L9&%P
M.B!%:2!S86$@;&ES861A(&=R=7!P:2`E<RX@4V5R=F5R(/QT;&5S.B``1W)O
M=7!?;&1A<#H@16D@<V%A(&MU<W1U=&%D82!G<G5P<&D@)7,`1W)O=7!?;&1A
M<#H@16D@<V%A(&UU=71A(&=R=7!P:2`E<P!'<G5P:60`1W5A9&5L;W5P90!'
M=6%M`$=U871E;6%A;&$`1W5E<FYS97D`2_QL86QI<V4@]6EG=7-E9`!+_&QA
M;&ES=&5R86%M870`1VEN96$`1VEN96$M0FES<V%U`$=U86IA86YA`$A434P`
M2%1-3$%R96$@:V5E;&1U8B!A<F=P_&MS;&EK=6QT(&MU<W1U=&%M87-T(')E
M82!V:6EM87-T(&QA:'1R:70N`$A434Q!<F5A(&ME96QD=6(@87)G</QK<VQI
M:W5L="!K=7-T=71A;6%S="!T86)E;&D@=FEI;6%S="!V965R9W4N`$A434Q!
M<F5A(&ME96QD=6(@87)G</QK<VQI:W5L="!K=7-T=71A;6%S="!T86)E;&D@
M=FEI;6%S="!R:61A+@!(5%10(&%U=&5N=&EM:7-T(&5I(&QE:71U9"X`2&%I
M:71I`%+D<VEA;&=O<FET;0!(Y&=U`%#D:7,`4.1I<V5D`$AE87)D:2!S86%R
M(&IA($UC1&]N86QD:2!S86%R960`4N1N:R#D:6ME<V5T;W)M`$AE96)R96$@
M*$E33RTX.#4Y+3@M22D`2_5R9W5S`$%B:0!%9&ET;W)I(&MA<W5T86UI<V4@
M86)I`$%B:6QI;F4`<&]O;&ME<F$`4VEI;B!O;B!F86EL:2!A;&=U<P!+]7)G
M90!?079A;&5H=`!0_&AA(%1O;VP@*%9A=&EK86YI($QI;FYR:6EK*0!!=F%L
M96AE;&4`2V]D=6YE(&%A9')E<W,`2V]D=6MA=&%L;V]G`$MO9'5N92!T96QE
M9F]N`$AO;F1U=7)A<P!(;VYG:V]N9P!(;W)D90!(;W)D92]+;VQA8CH@5FEG
M87-E9"`E<R!834P@86YD;65D(&MI<FIA<R`E<P!(;W)D92]+;VQA8CH@3V)J
M96MT:6QE("5S(&5I('9A<W1A(/QK<VMI(&MI<FD`2&]R9&4O2V]L86(Z($5I
M(&QE:71U9"#\:'1K:2`E<R!T_/QP:2!O8FIE:W1I(&MI<FIA<R`E<P!(;W)D
M92]+;VQA8CH@U6YN97-T=7,@965M86QD861A("5S("(E<R(`2&]R9&4O2V]L
M86(Z($EN=&5G<F%T<VEO;VYI;6]O=&]R('9A:F%B("=D;VUX;6PG(%!(4"!L
M86EE;F1U<W0`2&]R9&4O2V]L86(Z($5I('-A82!L=75A('5U="!834P@<'5U
M9"!O8FIE:W1I("5S(&IA;VMS`$AO<F1E+TMO;&%B.B!%:2!S86$@965M86QD
M861A("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!%:2#U;FYE<W1U(&AA;FMI
M9&$@34E-12!)1"UD("5S('3\_'!I(&]S82!J86]K<P!(;W)D92]+;VQA8CH@
M16D@<V%A('/\;FMR;VYI<V5E<FED82`E<R`B)7,B.B`E<P!(;W)D92]+;VQA
M8CH@16D@<V%A('/\;FMR;VYI<V5E<FED82!J86=U<VED.B`E<P!(;W)D92]+
M;VQA8CH@5'5N9&UA='4@:F%G=2`B)7,B`$AO<FES;VYT86%L:F]O;@!(;W)I
M<V]N=&%A;&YE('9O;V1E<F1U<P!(;W)I<V]N=&%A;&YE.@!+=6ED87,@<V$@
M<VEI82!S871T=7-I9#\@*%!A;'5N('1E871A(2D`2W5I('!A;&IU('9E97)G
M92!S;V]V:6MS:60@_&AE;F1A9&$_`$MU:2!P86QJ=2!VY&QJ=2`H=F5E<F=E
M*2!O;C\`2W5I('!A;&IU(')I9'4@<V]O=FEK<VED(/QH96YD861A/P!.:6ES
M:W5S`$YI:7-K=7,Z`$AU;6]R:7-T:60`56YG87)I`$E-05`@<&]S=&MA<W1I
M(&QO;VUI;F4@;G5R:G5S.B`E<P!)34%0('!O<W1K87-T:2!K=7-T=71A;6EN
M92!N=7)J=7,Z("5S`$E-05`@<&]S=&MA<W1I(&MV;V]D:2!L;V]M:6YE(&YU
M<FIU<SH@)7,`25`@86%D<F5S<P!)4"!A861R97-S('!O;&4@=&5A9&$N`$E0
M(&%A9')E<W,@96D@:W5U;'4@;'5B871U9"!#2412(&)L;VMK:2X`25`@<&EI
M<F%N9W4@<FEK:W5M:6YE+@!,:7-A(')I9&$@7V5N;F4`27-L86YD`$%I;G5L
M="!I:V]O;FED`"5S(&EK;V]N:60`26MO;VYI9"!J82!T96MS=`!)9&5N=&ET
M965D:2!N:6UI.@!+=6D@<V5D82#U:65T:2!E:2!NY&ED871A+"`E<R!J82!S
M964@879A=&%K<V4@=75E<R!A:VYA<RX`2W5I('-A(&MA<W5T860@26YT97)N
M970@17AP;&]R97)I="!J82!E:2!NY&4@_&QD<V4@:6MO;VYE+"!S:6ES('!R
M;V]V:2!MY')K:61A('-E92!R=75T+"!L_&QI=&%M86MS('-I<W-E(%!.1R!L
MY&)I<&%I<W1V=7,N`$MU:2!S82!NY&5D('-E9&$@=&5A9&5T(&%G82!P:6QT
M:2!E:2!NY&4L('-I:7,@96D@;W-K82!S:6YU('9E96)I;&5H:71S96IA(&[D
M:61A=&$@<V5D82!P:6QT:2P@;6ED82!S;V]V:60@_&QE<R!L86%D:61A+@!0
M:6QD:2!E96QV86%D93H`4&EL9&D@55),`%!I;&1I(%523#H`4&EL="!G86QE
M<FEI<W0`4&EL="!G86QE<FEI<W0Z`%!I;&1I(/QL97-L86%D:6UI;F4`4&EL
M9&ED`$EM<&]R="P@<V%M;2`E9`!);7!O<F1I='5D(';D;&DZ("5S`$EM<&]R
M9&ET=60@=N1L:F%D.@!,:7-A(')I9&$@7W#D<F%S=`!%<VET871I('9A;&4@
M=&5G979U<V4@:V]O9"X`5F%L92!K87-U=&%J86YI;6D@:F$O=O5I('!A<F]O
M;"X`5F%L92!K87-U=&%J86YI;6D@=O5I(&%L=&5R;F5T:6EV;F4@86%D<F5S
M<RX@4')O;W9I('5U97-T:2!V]6D@=O5T82#\:&5N9'5S="!A9&UI;FES=')A
M871O<FEG82X`4W5U<F5N9&$@=&%A;F1R:61A`$EN9&EA`-QK<VEK=60@:V%S
M=71A:F%D`$EN9&]N965S:6$`26YF;P!);F9O<FUA='-I;V]N`%1E879E(&5I
M(&]L92!E;F%M(&OD='1E<V%A9&%V+@!,:7-A(%]V965R9R!PY')A<W0`3&ES
M82!P:6QT`$QI<V$@=&%B96P`3&ES82!H_'!E<FQI;FL`3&ES82!V965?<F<@
M96YN90!,:7-A('5U<R!V965R9R!A:W1I:79S92!V965R=2!JY')E;&4`3&ES
M82!U=7,@=F5E<F<@86MT:6EV<V4@=F5E<G4@971T90!,:7-A('5U<R!R:61A
M(&%K=&EI=G-E(')E82!JY')E;&4`3&ES82!U=7,@<FED82!A:W1I:79S92!R
M96$@971T90!,:7-A(&SU:6L@<')A96=U<V4@87-U:V]H82!JY')E;&4`3&ES
M82!L]6EK('!R865G=7-E(&%S=6MO:&$@971T90!,:7-A(&%L=&5R;F%T:6EV
M;F4@;6%L;`!3:7-E<W1A(&UA:6QI86%D<F5S<R!K=6AU('-A86MS('-U;&QE
M('5U92!P87)O;VQI('-A871A.@!,:7-A(&QA:'1E<B!PY')A<W0`3&ES82!L
M86AT97(@96YN90!,:7-A('9E97)G('#D<F%S=`!,:7-A('9E97)G(&5N;F4`
M3&ES82!K:7)J860`3&ES82!L]6EK('#D<F%S=`!,:7-A(&SU:6L@96YN90!,
M:7-A(')I9&$@<.1R87-T`$QI<V$@<FED82!E;FYE`$MI<FIU=&$@<V%L86O\
M<VEM=7-E(/5I9V4@=F%S='5S.@!,:7-A+VUU=61A('!I;'0`3&ES82]M=75D
M82!L:6YK`$IA;W1U<VYI;65K:7)J86QE('-A871M:7-E:W,@96D@:N1T:W4@
M:W)E9&EI=&DN`$MR961I:71I(&5I(&KD=&MU+@!4Y&ES87)V`%3D:7-A<G9U
M9&4@;FEM96MI<FD`5FEG86YE(%5$2"`H57-E<B!$871A($AE861E<BDN`%9I
M9V%S960@6DE0(&%N9&UE9"X`5FEG86YE(')A:V5N9'5S+@!686QE(&)A=&-H
M($E$`%-I<V5S=&%T:2!V:6=A<V5D(&%N9&UE9"X`5FEG86YE('-I:'1A861R
M97-S+@!686QE(&9A:6QI9F]R;6%A=`!6:6=A;F4@;&ET<V5N='-I=O5T:2X`
M4VES97-T871I('9I9V%N92!A<W5K;VAT`%9I9V%N92!M<V=?='EP90!A<&E?
M:60@;VX@<'5U9'4@=O5I('9I9V%N92X`5FEG87-E9"!V]6D@<'5U9'5V860@
M<&%R86UE971R:60N`%9I9V%N92#\;&5M]6EG=7,N`%9I9V%N92!P87)T;F5R
M:2!)1`!6:6=A;F4@=&]O=&5K;V]D+@!6:6=A;F4@<')O=&]K;VQL+@!6:6=A
M;F4@<V%A:F$Z("(E<R(`5FEG86YE(&IA9V%T=60@;V)J96MT`%9I9V%N92!L
MY&AT96%A9')E<W,N`%9I9V%S960@=6YI8V]D92!A;F1M960N`$YI;65K:7)I
M`%#V]G)D=F%L:6L`27)A86YI($ES;&%M:79A8F%R:6EK`$ER86%K`$EI<FEM
M86$`36%N:2!S86%R`-QK<VEK=60@Y&EK97-E=&]R;6ED`$EI<W)A96P`5N1L
M:F%A;F1J80!+86QD:VER:0!)=&%A;&EA`$IA;6%I:V$`2F%A;G5A<@!*86%P
M86X`2F%A<&%N:2`H25-/+3(P,C(M2E`I`$MU;F$@<VEN=2!V965B:6QE:&ET
M<V5J87,@;VX@2F%V87-C<FEP="!K965L871U9"P@96D@<')U=6=I('-E92!L
M96AT(/5I971I('!A:7-T82X`2F5R<V5Y`$IO<F1A86YI80!*=75L:0!*=75N
M:0!2]O9P<V5L=`!+97-K96QE`%+V]G!S96QT`%9A<V%K=6QE`%!A<F5M86QE
M`$MA<V%H<W1A;@!3Y&EL:71A(&]R:6=I;F%A;#\`2V5E;FEA`$ME<F)E<F]S
M92!S97)V97(@96D@;&%S:VYU9"!S:7-S92X`2V5R;F5L:2!V]6AI:W5D`%;U
M=&UE(&QO;VUI;F4`5O5T;64@<_5R;65JY&QG`%;U=&UE('!I:VMU<P!6]71M
M92!T_/QP`%;U=&UE(&MA<W5T=7,`5O5T:2!O;B!A=F%L:6MU<R!S97)V97)I
M<R!J=6)A(&]L96UA<RX`3&%P<V5D`$MI<FEB871I`$MO<F5A(%)A:'9A9&5M
M;VMR86%T;&EK(%9A8F%R:6EK`$MO<F5A(%9A8F%R:6EK`$MO<F5A("A%54,M
M2U(I`$MU=F5I=`!+]7)G]7IS=&%N`%]+=6IU;F1U<P!+965L`$QA;W-E(%)A
M:'9A9&5M;VMR86%T;&EK(%9A8F%R:6EK`%9I:6UA;F4@<&]O;`!6:6EM86YE
M('!A<F]O;&D@;75U='5S`%9I:6UA;F4@=F5E<F%N9`!6:6EM871I(&UU=61E
M='5D.@!%96QM:6YE(&O\;&%S='5S.B`E<P!%96QM:6YE(&O\;&%S='5S.B`E
M<R!A861R97-S:6QT("5S`$5E;&UI;F4@:_QL87-T=7,Z(&UI='1E(&MU;F%G
M:0!,Y'1I`%-E861U<P!+=6IU;F1U<P!4_&AI('3D:&5N9&%B('!I:7)J;V]N
M92!P=75D=6UI<W0`3&EI8F%N;VX`5F%S86L`5F%S86L@<.1I<P!687-A:W5D
M(';DY')T=7-E9`!,97-O=&AO`%1A<V4`3&EB965R:6$`3&EI8OQA($%R86%B
M:6$@5F%B87)I:6L`3&EE8VAT96YS=&5I;@!4:6)U=&%B('9I:&UA`%-E96YE
M=FEH;0!(;VUM:6MU;"!T:6)U=&%B('9I:&UA`-5H='5L('1I8G5T86(@=FEH
M;6$`2V5R9V4@:&]O=FEH;0!+97)G92!V:6AM(&IA(.1I:V4`2V5R9V4@;'5M
M97-A9'4`2V5R9V4@;'5M971O<FT`3&EM97)I:P!,:6YK`$QI;FL@=FEI=&%B
M(&%S=6MO:'1A.@!%<VET86UI<V5L('-E;W-T82!E+7!O<W1I(&%A9')E<W,@
M=75E(&MI<FIA(&%K;F%G80!,:6YG:60`3&EN=7AI('!RY.1N:6L`3&ES="`M
M(&MA<W5T86IA(';U:6(@:V%U<W1A(&[D:&$`06YD;65B86%S:61E(&QO971E
M;'4`06)I:6YF;R!T965M861E(&YI;65K:7)I`%1A8F5L:71E(&QO971E;'4`
M3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES
M="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`4V5S<VEO
M;VYI9&4@;FEM96MI<FIA(&5S:71A;6EN92!N=7)J=7,Z("5S`$MA<W5T86IA
M=&4@;FEM96MI<FIA(&5S:71A;6EN92!N=7)J=7,Z("5S`$MA<W5T86IA=&4@
M;FEM96MI<FIA('!O;&4@;'5B871U9"!NY&AA+@!+:7)J86YD=7,`3&5E9'4`
M3&%E;BXN+@!+;VAA;&EK(&%E9SH@`%)E9VEO;VX@:F$@865G`$%S=6MO:'0`
M3&]G:2!S:7-S90!%96QM:7-E('/\;FMR;VYI<V5E<FEM:7-E(&QO9VD`3&]G
M:2!VY&QJ80!+87-U=&%J86YI;6D`5/;V9"!S:7-S96QO9VEM:7-E;`!3:7-S
M96QO9VEM:6YE(&YU<FIU<RP@:W5N82!K87-U=&%J86YI;6D@=O5I('!A<F]O
M;"!P;VQN=60@]6EG92X`4VES<V5L;V=I;6EN92!N=7)J=7,N`%!I:VL@=&5K
M<W0`07)M87-T=7,`36%D86P`2W)E96MA(';D:6ME=.1H960`3&%D:6YA(';D
M:6ME=.1H960`5N1I:V5S960@<F]O;6$@;G5M8G)I9`!,=6MS96UB=7)G`$M+
M`$U/5$0`35,M5$Y%1B!L:7-A;F0@96D@<VES86QD86YU9"!A;F1M96ED+@!-
M4T<`36%K86\`36%K961O;VYI82`H16YD:6YE($IU9V]S;&%A=FEA(%9A8F%R
M:6EK*0!-861A9V%S:V%R`$UA86=I80!%+7!O<W0`4&]S=&D@861M:6YI<W1R
M86%T;W(`7U1E92!L:6YK`$UA;&%W:0!-86QA:7-I80!-86QD:6EV:60`36%L
M:0!-86QT80!396%D:7-T82!K871E9V]O<FEA:60L(&UI9&$@:V%S=71A=&%K
M<V4@_&MS=7-T92!MY')G96YD86UI<V5K<R!J82!N96YD96QE(&MA=&5G;V]R
M:6%T96QE('9A<W1A=F%I9"!VY')V92X`36%P,C0@:V%A<G0`36%P475E<W0@
M:V%A<G0`5F%S=&%V=7-E9"!S86QV97-T871U9"X`3>1R=',`4V5R=@!4Y&AI
M<W1A(&QO971U9"]L=6=E;6%T82!S=&%A='5S`%3D:&ES=&$@;75U('-T86%T
M=7,@*&YT+B!TY&AT:7,O=F%S=&%T=60I`$UA<G-H86QL:2!S86%R960`36%R
M=&EN:7%U90!3;V)I=F%D(';D;&IA9`!-875R971A86YI80!-875R:6ET:75S
M`%-U=7)I;2!L=6)A='5D(&MR961I:70N`$MI<FIA(&]S861E('!I:7)A;F<@
M_&QE=&%T=60N`%9I:6UA<V4@,C0@='5N;FD@:_5R9V5I;2!T96UP97)A='5U
M<CH@`%9I:6UA<V4@-B!T=6YN:2!K]7)G96EM('1E;7!E<F%T=75R.B``4W5U
M<FEM('!O<G1A86QI(&)L;VMK:61E(&%R=@!3=75R:6T@<&EK:W5S`$UA:0!-
M87EO='1E`$UE9&ET<VEI;@!,:6EK;65D`$UE;OS\(&5S:71U<SH`W&AE;F1A
M(&QA:'1R:60`5&5A9&4`2VER:2!O;B!E9'5K86QT(&MO;G1R;VQL:71U9"P@
M96YT(&%L;&MI<FIA<W1A:F$@<V5R=&EF:6MA871I(&5I('-A86YU9"!K;VYT
M<F]L;&ED82X`5&5A9&4@;VX@865G=6YU9"X`5&5A=&4@=/S\<`!-971A<B!I
M;&T`365T87(@8FQO:VL@96D@;VQE('-A861A=F%L+@!-971A<B!B;&]K:R!E
M:2!O;&4@<V%A9&%V86PN(-QK<VEK87-J860@;&]G:71I(&%D;6EN:7-T<F%A
M=&]R:2!J86]K<RX`365T87)$0B#\:&5N9'5S('!U=61U8BX`365E=&]D`$UE
M971O9"`B)7,B(&5I(&]L92!D969I;F5E<FET=60`365E=&]D(&5I(&]L92!D
M969I;F5E<FET=60N($OD:79I=&%T=60@;65E=&]D.B`E<P!-965T97(`365H
M:&EK;P!-:6MR;VYE97-I82!&]F1E<F%T<VEO;VX`2V5S:V5L90!-24U%('3\
M_'``5FEI;6%S92`R-"!T=6YN:2!M861A;&%I;2!T96UP97)A='5U<CH`5FEI
M;6%S92`V('1U;FYI(&UA9&%L86EM('1E;7!E<F%T=75R`%!A<F]O;&D@;6EN
M:6UA86QN92!V86YU<R!P;VQE('9E96P@=.1I<P!0965G96QD80!-:71M97-U
M9W5S=`!0=75D=6(@4$5!4B!P86ME='0@2%144%]297%U97-T+@!+;VYF:6=U
M<F%T<VEO;VX@<'5U9'5B+B!+=6D@=&%H860@<V5D82!R86ME;F1U<W0@:V%S
M=71A9&$L('!E860@96YN92!G96YE<F5E<FEM82!K;VYF:6=U<F%T<VEO;VYI
M+@!0=75D=6(@<_5N=6UI($E$+@!0=75D=6(@=F%J86QI:R!014%2('!A:V5T
M="!-86EL+@!0=75D=6(@<V5S<VEO;VYI($E$+@!%<P!-;V)I:6QN92!E+7!O
M<W0`3?7U9'5K87,`375U=&UI<V4@:W5U<.1E=@!-=75D82!54DP`2N3D:P!-
M;VQD;W9A(%9A8F%R:6EK`$UO;F%K;P!-;VYG;V]L:6$`2W5U(&IA(&%A<W1A
M`$MO<F0@:W5U<P!-;VYT<V5R<F%T`$MU=69A87-I9`!296%S("5D(&QE:71I
M(')O:&ME;2!VY&QJ=2!K=6D@965L9&%T878@)60N`$UA<F]K;P!686QD879A
M;'0@<V5L9V4`5F%L9&%V86QT('!I;'9E<P!686QD879A;'0@<&EL=F5S(&IA
M('1U=6QI;F4`5F%L9&%V86QT('#D:6ME<V5P86ES=&5L:6YE`$YI:'5T82!A
M;&QA`$YI:'5T82!V87-A:W5L90!.:6AU=&$@<&%R96UA;&4`3FEH=71A(/QL
M97,`3FEH=71A(&%L;&$`3FEH=71A(/QL97,`36]S86UB:6EK`$UI=&UE=&%S
M96UE;&EN92!L;V5N9`!-=6QT:6UA<"!52R!K86%R=`!686QI:P!-:6YU(&MO
M;G1O`$UI;G4@:V]N=&\@:6YF;P!-:6YU('!O<G1A86P`36EN=2!P;W)T86%L
M:2!K=6IU;F1U<P!->6%N;6%R`$5)+"!M82!%22!/3$4@;O5U<P!.:6UI`$YA
M;6EI8FEA`$YA=7)U`$YE<&%A;`!(;VQL86YD`$AO;&QA;F1I($%N=&EL;&ED
M`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!('3\:&ES='5S92!54DP`
M3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!U=65N9'5S92!54DP`
M3F5T<V-A<&4@=/QH:7-T=7-E(%523`!.971S8V%P92!34TP@<V5R=F5R:2!N
M:6UI`$YE='-C87!E('-E<G1I9FEK86%D:2!K;VUM96YT86%R`$YE='-C87!E
M('-E<G1I9FEK86%D:2!T_/QP`%;U<FL`36ET=&4@:W5N86=I`%5U<RU+86QE
M9&]O;FEA`%5U<R!K871E9V]O<FEA`%5U<R!K:7)I("5S+6QE`$YO;W)K=74`
M575S(&MA<W5T86IA;FEM:2`H<&]L92!K;VAU<W1U<VQI:RD`575S+4UE<F5M
M86$`575S('-A;&%S]6YA`%5U<R!S86QA<_5N82!A96=U8B`E>"X`4V%L87/U
M;F%D('!E879A9"!K;&%P<&EM82X`575E<R!A:VYA<R`H7V)L86YK*0!5=61I
M<V5D`$=R=7!I9`!*Y')G;6EN90!*Y')G;6ES960@-"!F86%S:0!*Y')G;6ES
M960@<V5A9&5D`$KD<F=M:6YE/@!.:6MA<F%A9W5A`$YI9V5R`$YI9V5E<FEA
M`-;V`$YI=64`16D`4'5U9'5V860@:V]N9FEG=7)A='-I;V]N:6%N9&UE9"!M
M:6QL92!E<FEN979U<VD@;N1I9&%T82X`4'5U9'5B('-T<F%T965G:6$@25-/
M9&4@;&]O;6ES96MS+@!0=75D=6(@;6%L;"X`4V5L;&5S(&%S=6MO:&%S(&5I
M(&]L92!B;&]K:VD`34-!3"!A=71E;G1I;6ES96MS('9A:F%L:6L@:V%L96YD
M<FD@;FEM:2!O;B!P=75D=2X`17)I;F5V=7-I(&5I(&]L92X`4V5L;&5L92#U
M:6=U<V5L92!E:2!S86$@86QA;6%I9"!L:7-A9&$N`"5S(&CDY&QE<W1U<VEN
M9F\@<'5U9'5B+@!&5%`@5D93(&CDY&QE<W1U<VEN9F\@<'5U9'5B+@!344P@
M5D93(&CDY&QE<W1U<VEN9F\@<'5U9'5B+@!344PM1FEL92!61E,@:.3D;&5S
M='5S:6YF;R!P=75D=6(N`$MR961I:70@;VX@86UM96YD871U9"X`4VEH=&MO
M:'0@;>3D<F%M871A+@!&86EL:2!E:2!L865T=60`26MO;VYE(&5I(&QE:71U
M9"X`07-U:V]H="!MY.1R86UA=&$N`$%S=6MO:'0@;>3D<F%M871A`%/U;G5M
M('!U=61U8BX`3FEM:2!P=75D=6(N`$YU;6)E<B!P=75D=6(N`$%I;G5L="!V
M:6ES86MA9"!K:6QL=60`2%144"!A=71E;G1I;6ES92!S86QA<_5N82!P=75D
M=6(N`$E-05`@875T96YT:6UI<V4@<V%L87/U;F$@<'5U9'5B+@!+97)B97)O
M<R!A=71E;G1I;6ES92!S86QA<_5N82!P=75D=6(N`$QO9VEN(&%U=&5N=&EM
M:7-E('-A;&%S]6YA('!U=61U8BX`4$%34U=$(&%U=&5N=&EM:7-E('-A;&%S
M]6YA('!U=61U8BX`4TU"(&%U=&5N=&EM:7-E('-A;&%S]6YA('!U=61U8BX`
M3W!E;E-33"!P<F]G<F%M;6D@87-U:V]H="!E:2!O;&4@;>3D<F%T=60N($]P
M96Y34TP@<')O9W)A;6T@;VX@=F%J86QI:R!02T-3(S$R(&%N9&UE=&5G82!T
M]O9T86UI<V5K<RX`3V]T96P@;&EI='5M:7-S;V]V92!E:2!O;&4N`%!I:7)A
M;F=U="!E:2!O;&4N`%!U=61U=F%D`$5R86QD86IA('!O;&4@;>3D<F%T=60N
M`$UI='1E(/QK<VMI(&O\;&<`4V5L;&ES="!F86EL:2!E:2!O;&4`4'5H=F5R
M9&%M:7-E:W,@<'5U9'5B(&%J=71I;F4@:V%T86QO;V<N`$MA<W5T86IA;FEM
M92!J82]V]6D@<V%L87/U;F$@96D@<V%A9&5T=60N`$5I('1A9V%S=&%T=60@
M:V]R<F5K='-E:60@6$U,(&%N9&UE:60`5N3D<G1U<V5D('!U=61U=F%D`$%L
M9VYE(&MO;F9I9W5R871S:6]O;B!E:2!S:7-A;&1A('9E<G-I;V]N:2X@3&]O
M(&MO;F9I9W5R871S:6]O;B!U=65S=&DN`%-I;G4@:V]N9FEG=7)A='-I;V]N
M(&5I('-I<V%L9&$@=F5R<VEO;VYI+B!,;V\@:V]N9FEG=7)A='-I;V]N('5U
M97-T:2X`3>3D<F%M871A`$WDY')A;6%T80!0]6AJ86UA860@*$E33RTX.#4Y
M+3$P*0!.;W)F;VQK:2!S86%R`%#U:&IA<&]O;&ME<F$`4/5H:F$M36%R:6%A
M;FD@<V%A<F5D`$YO<G)A`$UI='1E(&AI;&IE;2!K=6D`36ET=&4@=F%R96T@
M:W5I`$5I(&]L92!K871A;&]O9P!0;VQE('1E;W-T871U9"X`3>3D<F%M871A
M`$5I(&]L92!T;V5T871U9"X`3>1R:VUE9`!0;VQE(&UI9&%G:2!S:7)V:61A
M+"!M:6YE('1A9V%S:2X`3F]V96UB97(`07)V`$WD<FMI9&4@87)V`%9E97)G
M=61E(&%R=@!2:61A9&4@87)V`$IA;W1U<VYI;65K:7)J87,@;75U=&UI<V5L
M92!K=75L=79A9"!N=6UB<FED('!O;&4@;>3D<F%T=60N`$]+`$]B:F5K=`!/
M8FIE:W1I(&QO;VIA`$MA:&5K<V%N9&YU;6)E<@!/:W1O;V)E<@!6:6ES86MU
M<V4@87-T90!+;VYT;W)I=/;V`%9A;F$@:F$@=75S('-A;&%S]6YA('!E879A
M9"!O;&5M82!E<FEN979A9"X`4')A96=U;F4@<V%L87/U;F$`4')A96=U;F4@
M<V%L87/U;F$@96D@;VQE(/5I9V4N`$]M86%N`-QH:7-K875S='4@=O5I;6%L
M9&%V860@86EN=6QT($E-05`@<V5R=F5R:60N`$%I;G5L="!E8F%V:6ES86MA
M9"!K:6QL=60`3'5B871U9"!O;B!A:6YU;'0@_&MS(&4M<&]S=&D@86%D<F5S
M<RX`2F%O(&]M86YI:VMU(';U:2!O;6%N:6MU(/5I9W5S:2!S86%B(&UU=71A
M(&%I;G5L="!O;6%N:6L@=O5I('/\<W1E96UI(&%D;6EN:7-T<F%A=&]R+@!!
M=F$@=75E<R!A:VYA<P!/<&5N4U-,('9I9V$Z($%N9&UE=&4@97)A;&1A;6EN
M92!A;&QK:7)J87-T871U9"!3+TU)344@;W-A<W0@;G5R:G5S+@!!=F%B('-E
M;&QE(&QI;F=I('5U97,@86MN87,`3W!E<F%T<VEO;VYI<_QS=&5E;0!396%D
M960`4V5A9&ES='5S.B`E<P!.=6UM97)D871U9"!L;V5T96QU`$]R9V%N:7-A
M='-I;V]N`$%L;/QK<W5S`$EN9F\`4F%K96YD=7-E(&%L9VYE(&UA;&P`06QG
M<V5D(&UA;&QI9"!K871A;&]O9VES("5S.@!-=74`375U(&EN9F\`3VUA;FEK
M=2#U:6=U<V5D`%!!32!A=71E;G1I;6EN92!E:2!O;&4@<V%A9&%V86PN`%!%
M05(Z.DUA:6P@='5G:0!01U`@9&EG:71A86QA;&QK:7)I`%!'4"!K<OQP=&ET
M=60@86YD;65D`%!'4"!A=F%L:6L@=O5T:0!01U`@86QL:VER:F%S=&%T=60O
M:W+\<'1I='5D(&%N9&UE9`!02%`@:V]O9`!02%`@:^1S=7)I9&$`4$P@:V5R
M9V4@=FEH;0!03"!V:6AM`%!,(&AO;W9I:&UA9`!03"!L=6UI`%!,('1I:&4@
M;'5M97-A9'4`4$P@<.1I:V4`4$P@Y&EK97-E=&]R;0!03U-)6"!L86EE;F1U
M<R!P=75D=6(`4%](4"!KY'-U<FED80!4Y&ED90!086MI<W1A;@!086QA=0!0
M86QE<W1I:6YA(&]K=7!E97)I='5D('1E<G)I=&]O<FEU;0!086YA;6$`4&%A
M<'5A(%5U<RU':6YE80!087)A9W5A:0!686AE;&1U=B!P:6QV:7-U<P!386QA
M<_5N80!386QA<_5N82!M=75D971U9"X`5F%L92!S86QA<_5N80!2041)55,@
M875T96YT:6UI<V5K<R!O;B!V86IA;&EK('-A;&%S]6YA+@!386QA<_5N82!K
M:6YN:71U<V5G80!386QA<_5N83H`4V%L87/U;F$Z(`!386QA<_5N860@<&5A
M=F%D(&ML87!P:6UA+@!!<V5T80!!<V5T82!L]6EK97!U:'9R:7-T`$%S=6MO
M:'0`3V]T96P@;&EI='5M:7-S;V]V:60Z`$EN:6UE<V5D`%!R;W1S96YT:0!+
MY&EV:71A(&AO;VQD=7-T]O9D`%1E92!S:7-S96QO9VEM:7-E;"!H;V]L9'5S
M=/9I9`#5:6=U<P#5:6=U<W0@(B5S(B!E:2!K=7-T=71A='5D+@!*=75R9&5P
MY.1S(&ME96QA='5D`-5I9W5S960`U6EG=7-T92!H86QD=7,`27-I:VQI:R!I
M;F9O`%!E<G5U`$QE;6UI:VQO;VUA9`!&:6QI<&EI;FED`%1E;&5F;VX`1F]T
M;V0`4&ET8V%I<FX`4&EK<VQI=`!-]71T971U<V5D`$ML]7!S82!M]6YD82!L
M86AT<FES<V4`2VEN;FET82!E="!S;V]V:60@<V5L;&4@96QE;65N9&D@965M
M86QD861A.@!+:6YN:71A(&5T('-O;W9I9"!S96QL92!E;&5M96YD:2!L86AT
M:2#\:&5N9&%D82X`4VES97-T82!K=74@:F$@86%S=&$N`%-I<V5S=&$@<V5L
M;&4@=75E(&MA=&5G;V]R:6$@;FEM:3H`4VES97-T82!K;W)R96MT;F4@25`@
M86%D<F5S<RX`4VES97-T82!K;W)R96MT;F4@:W5U<.1E=BP@:V]N=')O;&QI
M('#D979A9&4@87)V=2!K=75S+@!3:7-E<W1A(&MO<G)E:W1N92!A96<N`$MI
M<FIE;&1A('!R;V)L965M:2X`4VES97-T82!O;6$@:V%S=71A:F%N:6UI(&IA
M('-A;&%S]6YA`$QO92!JY')G;F5V('1E:W-T(&SD8FDN(%/\<W1E96UI(&MA
M<W5T86UI<V5K<R!014%$('1I;F=I;75S=&5G82!N]75S='5M82X`2VER:G5T
M82!U=64@:V%T96=O;W)I82!N:6UI.@!0;V]L80!0;VQI:71I:V$`2_QS:71L
M=7-E9`!0;W)T=6=A;`!396QL92!P:6QD:2!P86EG=71U<P!396QL92!T86)E
M;&D@<&%I9W5T=7,`2VER:G5T82!S96QL97-S92!K875S=&$@*$E-05`@96D@
M:V]N=')O;&QI*0!6:6EM87-E("5S('1U;FYI('-A9&5M960Z(`!3861E;65T
M93QB<B`O/G3U96[D;W-U<P!0<F5F<U]L9&%P.B!686IA;&EK:W4@3$1!4"!L
M86EE;F1U<W0@96D@;&5I='5D+@!0<F5F<U]S97-S:6]N.B!686IA;&EK:W4@
M<V5S<VEO;B!L86EE;F1U<W0@96D@;&5I='5D+@#5:'5R]6AK`-5H=7+U:&L@
M;65R97!I;FYA;#H`U6AU<O5H:SH`165L=F%A9&4`4&EL9&D@965L=F%A9&4@
M=75E<R!A:VYA<P!%96QM:7-E9"!S96%D960`5'+\:VD@9&]K=6UE;G0`4V%L
M86IA;F4@=O5T:0!0<F]B;&5E;0!0<F]B;&5E;6D@:VER:F5L9'5S`%!R;VIE
M:W1I9`!396QG:71A=B!T96MS=`!!=F%L:6L@=O5T:0!!=F%L:6MU(';U=&UE
M(&%L9V]R:71M`$%V86QI:W4@=O5T;64@:6YF;P!6]71M97!A87)I(&=E;F5R
M965R:6UI;F4@96D@]6YN97-T=6YU9"X`4'5E<G1O<FEI:V\`2W5S='5T871U
M9"!K:7)J861E(&5E;6%L9&%M:6YE`$MA=&%R`%#D<FEN9P!0:6ER86YG`%)3
M02!A=F%L:6L@=O5T:2`H)60@8FET=&DI`%9A;&EK`%9I:&T`2&]M;6EK=6P@
M=FEH;0#5:'1U;"!V:6AM`$AO;W9I:&T`5FEH;2!J82!L=6UI`%9I:&T@:F$@
M;'5M:0!*=6AU<VQI:R!K:6QD`%!R;W1S96YT`$QO90!,;V4@:VER:G4`2V%S
M('3U97-T:2!K=7-T=71A9&$@)7,_(%-E92!T;VEM:6YG(&]N('#V]G)D=6UA
M='4N`$MA<R!T]65S=&D@:W5S='5T861A(&MA<W5T86IA("5S(&%N9&UE9#\@
M4V5E('1O:6UI;F<@;VX@</;V<F1U;6%T=2X`5&%A<W1A8B!V:6EM87-E('1E
M9V5V=7-E`%;D<G-K96YD80!6Y')S:V5N9&$@9/QN86%M:6QI<V5D(&UE;OS\
M(&5L96UE;F1I9#H`5N1R<VME;F1A('!O<G1A86QI('9A861E.@!296=U;&%A
M<F%V86QD:7,`4W5H971E('-I<G9I:F$`3&%E('5U97-T:0!-Y')K=7-E9`!6
MY&QI<V5D('-E<G9E<FED`%;D;&EN92!54DP@*&AT='`Z+R]W=W<N97AA;7!L
M92YC;VTO:&]R9&4I.@!%96UA;&1A`$5E;6%L9&$@8FQO:VL`2W5S='5T82!V
M965R9P!%96UA;&1A(&MU:G5N9'5S`$5E;6%L9&$@<&%A<@!+=7-T=71A('-A
M;'9E<W1A='5D('-K<FEP="!S97)V97)I(&%J=71I<V5S="!K871A;&]O9VES
M="X`165M86QD80!%96UA;&1A(&1O:W5M96YD:7-T`$MU<W1U=&$@:V%S=71A
M:F$`2W5S='5T82!K87-U=&%J83H@)7,`4.1R:6YG=6QE('!O;&YU9"!V]6EM
M86QI:R!V87-T871A+B!486=A<W1A=&D@=F5A:V]O9#H@`%-O;W9I=&%V870@
M=&5E;G5S="!E:2!L96ET=60N`%9A:F%L:6L@(B5S(B!P=75D=6(@)7,@<V5A
M9&ES='5S97,N`%9A:F%L:6L@(B5S(B!P=75D=6(@5D93('-E861I<W1U<V5S
M+@!686IA;&EK("(E<R(@<'5U9'5B('-E861I<W1U<V5S+@!+;VAU<W1U<VQI
M:R!VY&QI`%3\:&IE;F1A`$UU=61A('-A;&%S]6YA`%5N=7-T87-I;B!O;6$@
M<V%L87/U;F$`5&%A<W1A(&5E;&UI;F4@<.1R:6YG`%1U;&5M=7-E9`!486=A
M<VD@<V5A9&ES='5S<V4`2V]R9&$@=75T('-A;&%S]6YA`%)E=6YI;VX`5O5T
M82!K;VYF:6=U<F%T<VEO;VX@=&%G87-I`%)I8V@@5&5X="!%9&ET;W)I('-E
M861I<W1U<P!-]6ES=&%T=7-E9`!087)E;0!087)E;2!PY&ES`%!A<F5M860@
M=N3D<G1U<V5D`%]296$@<V5A9&5D+BXN`%)O;&P`4G5M965N:6$`4/;V<F$@
M,3@P`%#V]G)A('9A<V%K=6QE`%#V]G)A('!A<F5M86QE`%)E82!S96%D960`
M4F5A('-E861E9`!2:61U.@!*;V]N960`2F]O;F5D('1E:VEV860@:_5I9VD@
M<FED861E(&IA('9E97)G=61E('9A:&5L90!*;V]N960@=&5K:79A9"!A:6YU
M;'0@=F5E<F=U9&4@=F%H96QE`$IO;VYE9"!T96MI=F%D(&%I;G5L="!R:61A
M9&4@=F%H96QE`$OD:79I=&$`5F5N92!&]F1E<F%T<VEO;VX`4G5A;F1A`%,O
M34E-12!K<OQP=&]G<F%A9FEL:6YE(&%L;&MI<FD`4R]-24U%(&MR_'!T:71U
M9"!K:7)I`%-!4TP@875T96YT:6UI;F4@96D@;VQE('-A861A=F%L+@!335,@
M;/QH:7/U;G5M:60`4U%,(&OD<W5R:61A`%-13"!A=F%L9&ES(';DY')T=7-T
M92!L96ED;6ES96MS`%-32`#53DY%4U154P!37U%,(&OD<W5R:61A`$QA`%-A
M:6YT($AE;&5N80!386EN="!+:71T<R!J82!.979I<P!386EN="!,=6-I80!3
M86EN="!0:65R<F4@:F$@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!J82!'<F5N
M861I:6YI9`!386UA<R!R86%M:7,@*%]S96QF*0!386UO80!386X@36%R:6YO
M`%-A;R!4;VUE(&IA(%!R:6YC:7!E`%-A=&5L;&EI='-I9&4@:V%S=71A:F$`
M4V%U9&D@07)A86)I80!386QV97-T82``4V%L=F5S=&$@(B5S(@!386QV97-T
M82`E<P!386QV97-T82!S96%D:7-T=7,`4V%L=F5S=&$@9V5N97)E97)I='5D
M(&MO;F9I9W5R871S:6]O;B!02%`@<VMR:7!T:6YA('-E<G9E<FD@86IU=&ES
M<V4@:V%T86QO;V=I+@`E<R!K;VYF:6=U<F%T<VEO;VX@<V%L=F5S=&%T=60N
M`%!A:6=A;&1U<V4@=75E;F1A;6ES92!S:W)I<'0@<V%L=F5S=&%T=60@9F%I
M;&DZ("(E<R(N`$AA:G5S860@Y&EK97-H;V]D`%1E861U<P!/='-I;F<`3W1S
M:6YG=6UO;W1O<FED`%9A;&D@9F%I;&ED`%9A;&D@:W5U<.1E=@!686QI(&QI
M<V%T878@9W)U<'``5F%L:2!U=7,@;VUA;FEK`%9A;&D@<V5R=F5R`%9A;&D@
M;&ES871A=B!K87-U=&%J80!686QI(&OU:6L`5F%L:2!K]6EK(&MU=7#D979A
M(&MO;W-T:7-O<V%D+@!686QI(&]B:F5K=`#$<F$@=F%L:2!M:61A9VD`5F%L
M:2!V86IA;&EK=60@;>1R9VED(&MA<W1I9&5S="X@4VEI<R!S86%D(&YE960@
M:V]P965R:61A(&MI<FIA('-I<W-E+@!686QI(&MU=7#D979A(&5R86QD86IA
M.@!686QI(&MU=7#D979A(&5S:71U<W9I:7,Z`%9A;&D@:61E;G1I=&5E="!M
M:61A('-O;W9I9"!M=75T83H`5F%L:2!K96QL86%J82!E<F%L9&%J83H`5F%L
M:2!K96QL86%J82!E<VET=7-V:6ES.@!686QI(&MA:W,@<V]B:79A="!VY&QJ
M82X`5F%L:2!VY')V:7-K965M+@!686QI(&]M82!L96UM:6MK965L.@!386%D
M82!P<F]B;&5E;6D@:VER:F5L9'5S`%-A861A(%--4P!396YE9V%L`%-E;G-O
M<CH@`%-E<'1E;6)E<@!397)B:6$@:F$@36]N=&5N96=R;P!*Y')J96YU;6)E
M<@!397)V97)I(&%N9&UE9"!O;B!V86QE9"!V]6D@<'5U9'5V860N`%-E<W-I
M;V]N:61E(&AA;&1U<P!397-S:6]O;FD@240@;VX@865G=6YU9"X`4U]E<W-I
M;V]N:60`2'5L:P!-Y.1R82!A;F1M960@;6ES(';U:6UA;&1A=F%D('-U;"!O
M;6$@<&%R;V]L:2#D<F$@;75U=&$@:W5I('-A('-E;&QE('5N=7-T860N`%-E
M861I<W1A(';D;&ES960@<V5R=F5R:60@;6ED82!S;V]V:60@;VUA('!O<G1A
M86QI<R!K87-U=&%D82X`4&%N92!P86EK82!O;6$@:V5E;&4L(&%J87;V]FYD
M:2!J82!K=75PY&5V82!S96%D:7-T=7,N`$WDY')A(&]M82!A;&=R86ME;F1U
M<RP@=N1R=FES:V5E;2P@;&5H96O\;&IE(';D<G-K96YD86UI<V4@<V%G961U
M<R!J82!M=75D("!E<VET=7-E('-E861E9"X`4&%I9V%L9'5S`$]L96UA<V]L
M979A9"!P86EG86QD=7-E('5U96YD86UI<V4@<VMR:7!T:60`4&%R86UE971E
M<B!MY.1R86(@;6ET=2!V]6EM86QI:VMU(&%S=6MO:'1A.B``4V5I<VAE;&QI
M9`!/<W1L96UI;F4`3/QH:6MO:VMU=O5T90!+87,@96YA;75S96QE(&QI;FMI
M9&5L92!T=6QE:W,@;>3D<F%T82!K:6ER:VQA:'9I9#\`3N1I=&$`3N1I=&$@
M;VQE;6%S;VQE=F$@:F$@Y'-J82!G96YE<F5E<FET=60@:V]N9FEG=7)A='-I
M;V]N:2!E<FEN979U<VDN`$[D:71A('-I<W-E;&]G:6UI<V5L(&5E;&UI<V4@
M<VES<V5L;V=I;6ES92!A96=A`%!A:W4@=O5I;6%L=7-T(&]R:6=I;F%A;&D@
M<^1I;&ET86UI<V5K<P!.Y&ET82!V86QI:F%T`$[D:71A('1A8F5L:71O:6UI
M;F=U=&4@;65N_/QR:6)A`$[D:71A('9A<V%K=6P@)7,@;65N_/QD`$[D:71A
M('1A8F5L:2!L86AT<FD@;VUA9'5S=&4@9&EA;&]O9VD`3N1I=&$@=&%B96QI
M(&]M861U<W1E(&1I86QO;V=I`$[D:71A('1A8F5L:2!R96$@;VUA9'5S=&4@
M9&EA;&]O9VD`3N1I=&$@<&EL9&D@;VUA9'5S=&4@9&EA;&]O9VD`3N1I=&$@
M=7!L;V%D:0!(;V]V:6AM`$AO;6UI:W5L(&AO;W9I:&UA9`#5:'1U;"!H;V]V
M:6AM860`2&]O=FEH;6%D(/QM8G)U<VMO;FYA<P!+:71S96YD80!+:71S96YD
M82!K]6EG97!E86QT(&YA86)E<F)L;VMK92!V]6D@;FEH=71A(&YE960@965S
M="#D<F$`4VEE<G)A($QE;VYE`$QI:71U`$%L;&MI<FD`06QL:VER:F$@86QG
M;W)I=&T`4VEN9V%P=7(`4W5U<G5S`$KD=&$@:&]O;&1U<R!V86AE;&4`4VQO
M=F%K:VEA`%-L;W9E96YI80!,=6UI`%1I:&4@;'5M97-A9'4`5&EH961A9"!L
M=6UE<V%J=60`2&]M;6EK=6P@=&EH961A9"!L=6UE<V%J=60`U6AT=6P@=&EH
M961A9"!L=6UE<V%J=60`3'5M92!P86MS=7,Z(`!,=6UE('9E92UE:W9I=F%L
M96YT.B``4V%A;&]M;VYI('-A87)E9`!3;VUA86QI80!,875L=60@:F$@;'5U
M;&5T=7-E9`!3;W)T965R:6UI<VKD<FIE:V]R<F$@=F%L:6L`3.1H=&5A861R
M97-S`$SU=6YA+4%A9G)I:V$`3/5U;F$M175R;V]P82`H25-/+3@X-3DM,RD`
M3/5U;F$M1V5O<F=I82!J82!,]75N82U386YD=VEC:&D@4V%A<F5D`$SU=6YA
M<&]O;&ME<F$`5F%H92!L86AT<FET92!V86AE;`!686AE(&QA:'1R:2!S:7-U
M(&IA(.3D<F4@=F%H96P`17)A;&1A:F$`5F%H90!686AE9"!J82!V;V]D97)D
M=7,`2&ES<&%A;FEA`%+D;7!S<&]S=`!%<FEMY')K:61E('-I<V5S='5S`$5R
M86QD82!L86AT<FED`$QA:'5T82!V965R9P!,86AU=&$@<FED80!3<&]R=`!3
M<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K`$%L9W5S86%S=&$`3W-A<FEI
M:R!V]6D@;6%A:V]N9`!/;&5K`%-A;'9E<W1U<V9O<FUA870`5.1N878@:F$@
M;6%J80!,Y&)I:F]O;FET=60@=&5K<W0`4W1R:6YG:61E(&QO96YD`$5R86QD
M82!D;VUE96X@86%D<F5S<VES=`!3=&EI;"!;0U-370!0_`!!;&%M:V%T86QO
M;V=I("(E<R(@96D@;&5I='5D+@!4965M80!+:6YN:71A`%-O;W8@(B5S(B!L
M:7-A;6ES96MS('/\<W1E96UI(&]N('-A;'9E<W1A='5D+B!382!E:2!S86$@
M<VES<V4@;&]G:61A(&5N;F4@:W5I('-I;G4@<V]O=B!O;B!H96%K<R!K:6ED
M971U9"X`06QA:6YD96MS`$SD:W,@:V]R9&$`(B5S(B!O;B!S_'-T965M:2!L
M:7-A='5D+@`B)7,B(&%N9&UE9"!O;B!S_'-T965M:7-T(&5E;6%L9&%T=60N
M`"(E<R(@;VX@:W5S='5T871U9"X`(B5S(B!O;B!S_'-T965M:7-T(&5E;6%L
M9&%T=60N`$MO;F9I9W5R871S:6]O;B!O;B!T86=A<VD@=O5E='5D+B!-=75T
M=7-T92!NY&=E;6ES96MS(';D<G-K96YD82!V86%D970N`$MO;F9I9W5R871S
M:6]O;FD@=F%R=6MO;W!I82#U;FYE<W1U<R!S86QV97-T861A+@!+;VYF:6=U
M<F%T<VEO;VYI9F%I;&D@=F%R=6MO;W!I82`E<R#U;FYE<W1U<R!S86QV97-T
M861A+@`B)7,B(&UU=71M:6YE(/5N;F5S='5S+@`E<R!K:7)J=71A;6EN92#U
M;FYE<W1U<P!3=61A86X`4VES=6MO:VMU=O5T90!0Y&EK97-E=/5U<P!0Y&EK
M97-E;&]O:F%N9P!0Y&EK97-E<&%I<W1E;&EN90!0Y&EK97-E=/5U<P!0Y&EK
M97-E=/5U<R]L;V]J86YG`%#D:6ME<V5T]75S.B``4.1I:V5S96QO;VIA;F<`
M4.1I:V5S96QO;VIA;F<Z(`#<;&%I;F1E:W,`5'5G:0!3=7)I;F%M:0!097)E
M:V]N;F%N:6UI`%-V86QB87)D(&IA($IA;B!-87EE;@!3=F%A<VEM86$`4F]O
M='-I`%-H=F5I=',`4_QN:W)O;FES965R:6UI<V4@;&]G:2!K=7-T=71A='5D
M`%-Y;F--3`!+:7)J879I9V$@;W1S:6YG=71I;F=I;75S=&5S`%/\_')I82!!
M<F%A8FEA(%9A8F%R:6EK`,1I:V5S971O<FT`5'5U;&EN92!J82#D:6ME<V5L
M:6YE`,1I:V5S97!U:&%N9W5D`$AO;6UI:W5L(.1I:V5S97!U:&%N9W5D`%13
M5B!F86EL`%1A8F5L`%1A8F5L:2!O;6%D=7-E9`!486)E;&ET92!H=6QK`%1A
M8F5L:2!O;6%D=7-E9`!486EV86X`5&%I=F%N+"!(:6EN82!P<F]V:6YT<P!4
M861Z:6MI<W1A;@!486YS86%N:6$@W&AE;F1V86)A<FEI:P!!=F%N96UI;F4Z
M`%3V]F0`5&5L969O;FEN=6UB97(`5FEI;6%S92!T=6YN:2!T96UP97)A='5U
M<CH`5&5M<&5R871U=7(`5&5M<&5R871U=7(Z(`!496UP97)A='5U<CQB<B`O
M/B@E<TUA>"5S+R5S36EN)7,I("9D96<[)7,`36%L;&D@(B5S(B!E:2!L96ET
M=60N`$UA;&QI9&4@:&%L9'5S`%1E:W-T`$%I;G5L="!T96MS=`!496MS=&D@
M:F]O;F1U<P!497AT=&]P`$YE`%1A:2`H5$E3+38R,"D`5&%I`%3D;F%M92!K
M_&QA<W1A;6%S="X`1E10(&QA:65N9'5S(&5I(&]L92!S86%D879A;"X`2&ES
M=&]R>2!S_'-T965M(&]N(';D;&IA(&S\;&ET871U9"X`2&]R9&4O2V]L86(@
M:6YT96=R871S:6]O;FEM;V]T;W(@96D@=&]E=&$@(B5S(BUI`$E-4U`@;&]G
M:2!A;&=VY.1R='5S=&%M:6YE(&YU<FIU<RX`36%I;G1E;F%N8V4Z.B!K;&%S
M<VD@;&%A9&EM:6YE(&YU<FIU<P!396%D971E(&%K96X@;VX@<W5L971U9"X@
M5N1L:G5N+@!+=6D@=&%H860@:V%S=71A9&$@]6EG=7-I+"!P96%B(&%D;6EN
M:7-T<F%A=&]R('-E861I<W1A;6$@</QS:79A(/5I9W5S=&4@<_QS=&5E;6DN
M`$%I;G5L="!A;'5M:6YE(&O\;&<`2V]N=&%K=&D@240@;G5M8G)I="!E:2!M
MY.1R871U9"P@:N1E=&D@=/QH:F%K<R!V]6D@<V5E('!U=61U8B!A;F1M96)A
M87-I<RX`2VER:F4@]6YN97-T=7,@;&ES861A('-I;G4@86%D<F5S<VER86%M
M871U<W-E+@!!;&QK:7)J87-T871U9"!K:7)J82!K;VYT<F]L;&EM:7-E:W,@
M;VX@=F%J82!E<F%L9&D@4$=0(&%L;&MI<FIA8FQO:VMI+@!*86]T=7-N:6UE
M:VER:F$@240@;VX@;>3D<F%M871A+"!JY&5T:2!T_&AJ86MS(';U:2!P=75D
M=6(@86YD;65B86%S:7,N`$IA;W1U<VYI;65K:7)I('!O;&4@;>3D<F%T=60N
M`$MR_'!T:6UI<V5K<R!O;B!V86IA('1U<G9A;&ES="!(5%10(/QH96YD=7-T
M+@!&86EL("5S('!E86MS('-I<V%L9&%M82`E<R!MY.1R86YG=70N`$9A:6P@
M)7,@<&5A:W,@<VES86QD86UA(&UI;F=E:60@)7,@;>3D<F%N9W5I9"X`1F%I
M;&D@96D@<V%A(&MO<&5E<FED82!I<V5E;F1A;&4@;W1S82X`1F%I;"!E:2!S
M:7-A;&1A;G5D(&%N9&UE:60N`$KD<F=N979A9"!S96QL92!M97-S86=E+W)F
M8S@R,B!K:7)J82!PY&ES960N`%3D:7-E:W)A86YI<F5Z:6EM:2!K87-U=&%M
M:6YE('1E:VET86(@<')O8FQE96UE($EN=&5R;F5T($5X<&QO<F5R:7,@=.1N
M=2!S96QL92!V965B:6QE:&ET<V5J82!V:6=A9&5L92P@;6ED82!M96EL(&5I
M(/5N;F5S='4@;6%H82!S=7)U9&$N($5S:6YE9&$@=O5I8B!LY&)U(&MU:G5T
M:7-E<RP@961I=&]R:2!F=6YK='-I;V]N:61E('!U=61U;6ES="!J82]V]6D@
M=F5E8FEL96AI='-E:F$@:G5H=7-L:6MK=2!K:6YN:6IO;VMS;6ES="X@2W5I
M('-I;G4@87)V=71I(&]P97)A='-I;V]N:6MS(&]N(%=I;F1O=W,@.7@L('-I
M:7,@;VX@=N1G82!T]65NY&]L:6YE(&5T('-A860@(D=E;F5R86P@4')O=&5C
M=&EO;B!&875L="(@=F5A=&5A=&4@:F$@<&5A9"!A<G9U=&D@=&%A<VOD:79I
M=&%M82Y<;EQN4VEN9"!O;B!H;VEA=&%T=60N($ML]7!S82!/2RP@:W5I('-O
M;W9I9"!S:6ES:VD@=.1I<V5K<F%A;FER97II:6UI('!R;V]V:61A+@!)9&5N
M=&ET965T("(E<R(@;VX@:W5S='5T871U9"X`06EN=6QT('9A<V%K(&O\;&<`
M0W)Y<'1?<&=P.CH@:VQA<W-I(&IA;VMS('!E86(@;VQE;6$@;>3D<F%T=60@
M1VYU4$<@<')O9W)A;6UI(&%S=6MO:'0N`$MI<FD@;6ES('-A861E=&D@)7,@
M86%D<F5S<VEL92`E<R!T965M86=A("(E<R(@;VX@879A='5D+@I3964@96D@
M9V%R86YT965R:2!E="!K:7)I(&SD8FD@;&]E=&D@=O5I('-E;&QE<W0@87)U
M('-A861I+@!.:6UI(&UI9&$@:V%S=71A9&$@961I=&]R:2!L96AE9V$@;&EN
M:VEM:7-E;`!6Y&QJ861E(&%R=B!P96%B(&]L96UA(&%R=BX`2&]R9&5?0W)Y
M<'1?<VUI;64Z.B!K;&%S<R!V86IA8B!O<&5N<W-L(&UO;V1U;&ET+@!%96QI
M<W1U<W0@(B5S(B!E:2#U;FYE<W1U;G5D('-A;'9E<W1A9&$L(&MU;F$@86YD
M;65T92!H=6QK(/QL971A<R!S=75R:6UA(&QU8F%T=60@;>3D<F$`4V5D82!T
M_/QP:2!A;F1M971E("@E<RD@=F%A=&%M:7-E:W,@=F%J86QI:VMU('!R;V=R
M86UM:2!E:2!L96ET=60@<_QS=&5E;6ES="X`2G5T=6WD<FL@<&5A8B!O;&5M
M82#\:W,@;>1R:RX`06EN=6QT('9A<V%K(&IA('!A<F5M(&O\;&<`06EN=6QT
M('!A<F5M(&O\;&<`17)A;&1A:F$@<&5A8B!O;&5M82#\:W,@;>1R:RX`4V5R
M=F5R("(E<R(@;VX@:W5S='5T871U9"X`4V5R=F5R("(E<R(@;VX@<V%L=F5S
M=&%T=60N`"5S(&QI:71U;6ES<V]O=B!O;B!E96UA;&1A='5D+@!-Y.1R871U
M9"!R:61A("@E9"D@<&]L92!O;&5M87,N`$WDY')A='5D(')I9&$@<&]L92!O
M;&5M87,N`$%J=71I<W0@9F%I;&D@(B5S(B!P;VQE(&]L96UA<RX`4VEN=2!S
M:7-E<W1A='5D('1E:W-T(&5I(&MA='1U(&5K<F%A;FEL(&]L979A9V$N`$%I
M;G5L="#\;&5M:6YE(&IA(&%L=6UI;F4@:_QL9P!!:6YU;'0@_&QE;6EN92!K
M_&QG`%-A861E='5D(&%N9&UE9"!O;B!V86AE<&5A;"!K86]T<VD@;.1I;G5D
M+@!386%D971U9"!F86EL:2!E:2!S86%N=60@<V%L=F5S=&%D82X`=V5A=&AE
M<BYC;VT@8FQO:VL@96D@;VQE(&OD='1E<V%A9&%V+@!+=6IU;F1U<W1E(&MA
M=&%L;V]G:2`B)7,B(&5I(&QE:71U9"X`16D@;VQE(&UI9&%G:2!S96%D:7-T
M861A+@!+:7)J86P@96D@;VQE('9A:&5T=6QT(&5S:71A=&%V86ED(&]S:2X`
M4V5L;&5S(';D;&IA<R!O;B!L:6EA;'0@<&%L:G4@;>1R:V4N(%-A('-I<V5S
M=&%S:60@)7,@;>1R:VD[(&QU8F%T=60@<&]L92!R;VAK96T@:W5I("5S+@`B
M)7,B(&QI<V%M:7-E;"!S_'-T965M:2!T96MK:7,@<')O8FQE96TZ("5S`$MA
M<W5T86IA("(E<R(@86YD;65T92!S_'-T965M:7-T(&5E;6%L9&%M:7-E;"!T
M96MK:7,@<')O8FQE96TZ(``B)7,B(&5E;6%L9&%M:7-E;"!S_'-T965M:7-T
M('1E:VMI<R!P<F]B;&5E;3H@`"(E<R(@;75U=&UI<V5L('1E:VMI<R!P<F]B
M;&5E;3H@)7,`1F%I;&D@;&%A9&EM:7-E;"!S97)V97)I<W-E('1E:VMI<R!P
M<F]B;&5E;3H@)7,@96D@;&%E='5D+@!&86EL:2!L86%D:6UI<V5L('-E<G9E
M<FES<V4@=&5K:VES('!R;V)L965M.B`E<R!O;&D@<W5U<F5M(&MU:2!V]6EM
M86QD86(@<&EI<F%N9R`H)60@8F%I=&DI+@!&86EL:2!L86%D:6UI<V5L('-E
M<G9E<FES<V4@=&5K:VES('!R;V)L965M.B`E<R!L865T:2!A:6YU;'0@;W-A
M;&ES96QT+@!396QL92!K:7)J82!O<V$@97-I=&%M:7-E;"!T96MK:7,@=FEG
M80!+;VYT86MT86YD;65T92!I;7!O<G1I;6ES96P@=&5K:VES('9I9V$N`&E#
M86QE;F1A<B=I(&%N9&UE=&4@:6UP;W)T:6UI<V5L('1E:VMI<R!V:6=A+@!3
M96%D:7-T=7-E('9O<FUI;"!E<VEN97,@=FEG82X@16AK(&KD='-I9"!TY&ET
M;6%T82!M]6YE(&MO:'5S='5S;&EK=2!VY&QJ82X`4V]O=FET=60@86%D<F5S
M<VER86%M871U(&]P97)A='-I;V]N:2!S;V]R:71A;6ES96P@=&5K:VES('9I
M9V$N(%!A;'5N('!R;V]V:2!H:6QJ96T@=75E<W1I+@!+;VYT86MT86YD;65T
M92!U=65N9&%M:7-E;"!T96MK:7,@=FEG82X@4&%L=6X@<')O;W9I(&AI;&IE
M;2!U=65S=&DN`$IA;W1U<VYI;65K:7)J82!U=65N9&%M:7-E;"!T96MK:7,@
M=FEG82X@4&%L=6X@<')O;W9I(&AI;&IE;2!U=65S=&DN`%-E92!)34%0('-E
M<G9E<B!E:2!V]6EM86QD82!K875S=&%D92!J86=A;6ES="X`4V5E(&5I(&[D
M:2!O;&5V870@:V]R<F%L:6L@4D%2(&%R:&EI=BX`4V5E(&5I(&[D:2!O;&5V
M870@:V]R<F%L:6L@6DE0(&9A:6PN`%-E92!E:2!NY&D@;VQE=F%T(&ME:'1I
M=B!K86%R9&D@;G5M8F5R+@!3964@9')A:79E<B!V]6EM86QD86(@<V%A=&$@
M<_5N=6UE:60@;.1B:2!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC
M;VTI(&S\_'-I+"!K87-U=&%D97,@2%144"!!4$ET`%-E92!D<F%I=F5R(';U
M:6UA;&1A8B!S86%T82!S]6YU;65I9"!LY&)I(%=)3B`H:'1T<#HO+W=I;G!L
M8RYC;VTI(&S\_'-I+"!K87-U=&%D97,@2%144"!!4$ET+@!3964@9')A:79E
M<B!V]6EM86QD86(@<V%A=&$@<_5N=6UE:60@;.1B:2!S;7,R96UA:6P@*&AT
M='`Z+R]S;7,R96UA:6PN8V]M*2!L_/QS:2P@:V%S=71A9&5S($A45%`@05!)
M="X`4V5E(&1R86EV97(@=O5I;6%L9&%B('/U;G5M:71E('-A871M:7-T(%--
M5%`@<')O=&]K;VQL:6=A(&SD8FD@5F]D869O;F4@271A;'D@;/S\<VDL(&%I
M;G5L="!6;V1A9F]N92!N=6UB<FET96QE+B!396QL96MS(&]N('9A:F$@5F]D
M869O;F4@271A;'D@92UP;W-T:2!K;VYT;W0@*&AT='`Z+R]W=W<N,3DP+FET
M*0!3964@=N1L:2!O;B!K;VAU<W1U<VQI:RX`4V5E(';D;&D@=O5I8B!S:7-A
M;&1A9&$@=F%I9"!TY&ES87)V92X`4V5E(';D;&D@=O5I8B!S:7-A;&1A9&$@
M86EN=6QT(&YU;6)R96ED(&IA(&MO;VQO;FET+@!3964@=N1L:2!V]6EB('-I
M<V%L9&%D82!A:6YU;'0@:V%H96MS86YD87)V92X`4V5E(';D;&D@<&5A8B!O
M;&5M82!K;VUA9V$@=O5I('3\:&EK=6=A(&5R86QD871U9"!TY&ES87)V=61E
M(&QO96YD`%-E92!VY&QI('!E86(@;VQE;6$@:V]R<F5K=&YE(&%R=BX`4V5E
M(';D;&D@<&5A8B!S:7-A;&1A;6$@=N1R=FEK;V]D:2!21T(@2&5X(&MU:G5L
M+"!NY&ET96MS("<C,3(S-&%F)RX`4V5E('9O<FT@;VX@:G5B82!LY&)I('3V
M]G1A='5D+@!3964@;VX@)7,N`%-E92!O;B!+;VQA8B!'<F]U<'=A<F4@;V)J
M96MT+B!396QL92!O8FIE:W1I('9A871A;6ES96MS('9A:F%D(&4M<&]S=&D@
M:VQI96YT:2!M:7,@;?5I<W1A8B!+;VQA8B!'<F]U<'=A<F4@9F]R;6%A=&DN
M(%-E;&QI<W1E(&4M<&]S=&D@:VQI96YT:61E(&YI;65K:7)J82!L96EA9"!A
M861R97-S:6QT("5S`%-E92!K:7)I(&]N(&MI<FIU=&%T=60@;>1R9VES=&EK
M=7,@*"5S*2!M:7,@97)I;F5B('-I;G4@;VUA<W0N`%-E92!A<G8@<&5A8B!O
M;&5M82!VY&AE;6%L="#\:W,N`%-E92!S97)V97(@96D@;?5I<W1A(&QA:'1I
M('!A:VMI9&$@>FEP(&IA(&=Z:7`@9F%I;&4N`%-E92!S_'-T965M(&]N('!R
M865G=2!VY&QJ82!L_&QI=&%T=60N`%-E;&QE(&MO:&$@<&5A;"!P96%B(&]L
M96UA(&%R=BX`4V5E(&%K96X@='5L96(@879A9&$@4V5A9&5T92!A:VYA<W0`
MQ&EK90!(96QP9&5S:P!!96<`5/;V86IA=&%B96P`06IA(&5S:71U<P!!:F$@
M=F%L:6L`261A+51I;6]R`%!E86QK:7)I`%!E86QK:7)I("AT;V]L=&EP*0!+
M96QL96QE`$UI=&UE(&]B:F5K=&D@=F%L:6UI<V5K<R!H;VEA(&%L;"!#=')L
M("A00RD@=O5I($-O;6UA;F0@*$UA8RD@:VQA:'9I(&IA(&ML]7!S82!O8FIE
M:W1I9&5L+@!4Y&YA`$A434P@:V]O9&D@<F5Z:6EM`%1O9V\`5&]K96QA=0!(
M;VUM90!4;VYG80!6:6EM87-T96P@;6EN=71I=&5L(&]N(&QI:6=A('!A;&IU
M(&YU<FIU;G5D('-I<W-E;&]G:6UI<VDN`-QL97,`4&5A;&UI<V5S(')A86UI
M<R`H7W1O<"D`5/5L:V5D`%1R:6YI9&%D(&IA(%1O8F%G;P!4]61E(';U:2!V
M86QE`%1E`%1U;F5E<VEA`%3\<F=I`%3\<F=I("A)4T\M.#@U.2TY*0!4=7)K
M;65N:7-T86X`5'5R:W,@:F$@0V%I8V]S`%1U=F%L=0!+:7)J=71A(&]M82!V
M86QI:SH`558M:6YD96MS.B``55),`%-I;G4@<VMR:7!T:2!KY'1T971O:6UE
M=&%M:7-R87!O<G1I(%523`!54DPZ`%5G86YD80!5:W)A:6YA`$5I('#DY'-E
M(&QI9VD@5D93(&MA=&%L;V]G:6QE+@!4Y&EE;F1A=F$@:V%S=71A:F%I;F9O
M(&QI<V%M:6YE(&QI:71U;6ES96P@96D@]6YN97-T=2X`16D@<V%A(&UU=71A
M(%9&4R!F86EL:2`B)7,B(/5I9W5S:2X`16D@<V%A(&UU=71A(%9&4R!F86EL
M:2`E<R\E<R#U:6=U<VDN`$5I('-A82!M:6YN82!K871A;&]O9VD@)7,N`$9A
M:6QI("(E<R(@<W5U<G5S="!P;VQE(';U:6UA;&EK(&MO;G1R;VQL:61A+@!&
M86EL:2`B)7,O)7,B('-U=7)U<W0@<&]L92!V]6EM86QI:R!K;VYT<F]L;&ED
M82X`16D@<V%A(/QH96YD=7-T(%-13"!S97)V97)I9V$N`%-33"#\:&5N9'5S
M92!A;&=A=&%M:6YE(&YU<FIU<RX`5D93(&9A:6QI(&MO<&5E<FEM:6YE(&YU
M<FIU<RX`5D93(&MA=&%L;V]G:2`B)7,B(&QO;VUI;F4@;G5R:G5S+@!61E,@
M:V%T86QO;V=I(&QO;VUI;F4@;G5R:G5S+@!61E,@9F%I;&D@;&]O;6EN92!N
M=7)J=7,N`%9&4R!K875S=&$@(B5S(B!L;V]M:6YE(&YU<FIU<RX`16D@<V%A
M(&QU=6$@=/QH:F$@5D93(&9A:6QI+@!,86AT:7!A:VMI;6EN92!N=7)J=7,N
M`"(E<R(@96D@<V%A(&MU<W1U=&%D82P@:V%T86QO;V<@96D@;VQE('3\:&DN
M`$5I('-A82!K=7-T=71A9&$@(B5S(CH@)7,N`"5S(&5I('-A82!K=7-T=71A
M9&$L(&MA=&%L;V]G(&5I(&]L92!T_&AI`%9&4R!K871A;&]O9VEP=74@:W5S
M='5T86UI;F4@;G5R:G5S+@!61E,@:V%T86QO;V=I(&MU<W1U=&%M:6YE(&YU
M<FIU<RX`16D@<V%A(&MU<W1U=&%D82!61E,@:V%T86QO;V=I.B`E<RX`16D@
M<V%A(&MU<W1U=&%D82!61E,@9F%I;&D@(B5S(BX`5D93(&9A:6QI(&MU<W1U
M=&%M:6YE(&YU<FIU<RX`16D@<V%A(&MU<W1U=&%D82!61E,@:V%U<W1A("(E
M<R(N`$5I('-A82!K=7-T=71A9&$@5D93:2!R96MU<G-I:79S96QT.B`E<RX`
M2F]O:W-V870@:V%T86QO;V=I(&5I(/5N;F5S='4@='5V87-T861A+@!%:2!S
M86$@:^1T=&4@<V5R=&EF:6MA861I(/QK<VEK87-J=0`E<R!D969I;FET<VEO
M;VYI(&QA861I;6EN92!N=7)J=7,N`%9&4R!F86EL:2#\;6)E<G3U<W1M:6YE
M(&YU<FIU<RX`16D@<V%A(&%V861A(%9&4R!F86EL:2`B)7,B+@!%:2!S86$@
M879A9&$@5D93(&9A:6QI(&UU=71M:7-E:W,N`%9&4R!F86EL:2!A=F%M:6YE
M(&YU<FIU<RX`4&%K:71U9"!A<FAI:79I(&%V86UI;F4@;G5R:G5S+@!%:2!S
M86$@;'5G961A(%9&4R!F86EL:2`H9FEL97-I>F4H*2!N=7)J=7,I+@!%:2!S
M86$@;'5G961A(%9&4R!F86EL:2`H9V5T1FEL95-I>F4H*2!N=7)J=7,I+@!%
M:2#U;FYE<W1U(&QU9V5D82!F86EL:3H@`'9F<W)O;W0@:V%T86QO;V=I(&QU
M9V5M:6YE(&YU<FIU<RX`)7,@96D@<V%A(/QM8F5R(&YI;65T861A("5S+6MS
M.B!S:6AT:V%U<W0@;VX@:G5B82!O;&5M87,N`%9&4R!K871A;&]O9VD@_&UB
M97)N:6UE=&%M:6YE(&YU<FIU<RX`16D@<V%A(/QM8F5R(&YI;65T861A(%9&
M4R!K871A;&]O9VDZ("5S`$5I('-A82#\;6)E<B!N:6UE=&%D82!61E,@9F%I
M;&D@(B5S(BX`16D@<W5U9&$@_&UB97(@;FEM971A9&$@5D93(&9A:6QI("5S
M+R5S+@!61E,@9F%I;&D@_&UB97)N:6UE=&%M:6YE(&YU<FIU<RX`16D@]6YN
M97-T=2!KY&EV:71A9&$@)VUK:7-O9G,G+@!3961A(%=O<F1I(&1O:W5M96YT
M:2!O;B!V]6EM871U('3U;&=E;F1A9&$`16D@<V%A(&MI<FIU=&%D82!61E,@
M9F%I;&D@(B5S(BX`16D@<V%A(&MI<FIU=&%D82!61E,@9F%I;&D@*&-O<'DH
M*2!N=7)J=7,I+@!61E,@9F%I;&D@86YD;65T92!S86QV97-T86UI;F4@;G5R
M:G5S+@!%:2!S86$@:VER:G5T861A(%9&4R!F86EL:2P@:V5T=&%K=F]O="!L
MY&AE8B!L]6AK:2X`06QL86IO;VYI='5D('1E:W-T`%1A87-T82!A;&=S96ES
M`%;U=&%B('9I:6UA<V4@=&5G979U<V4@=&%G87-I`$]O=&%M871U('9A<W1U
M<R!S97)V97)I;'0@_&AE;F1U<V4@;&]O;6ES96PZ(`!/;W1A;6%T=2!V87-T
M=7,@<V5R=F5R:6QT.B``2V%T96=O;W)I871A`%5N:6-O9&4@*%541BTX*0!!
M<F%A8FEA(-QH96YD96UI<F%A9&ED`%-U=7)B<FET86YN:6$`06UE97)I:V$@
MW&AE;F1R:6EG:60`06UE97)I:V$@W&AE;F1R:6EK:61E(';D:6ME<V%A<F5D
M`-QH:6MU9`!4=6YD;6%T=0!4=6YD;6%T=2!A<&EM<V=I9"`H05!)($UE<W-A
M9V4@240I+@!4=6YD;6%T=2!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I
M+@!-Y.1R871I('1U;F1M871U(&%S=6MO:'0N`%1U;F1M871U(&MA<W5T86IA
M;FEM:2!J82!S86QA<_5N;F$N`-QH96YD82!S964@96QE;65N="!L86AT:2X`
M3FEM971U`-5I9W5S=&5T82!S:W)I<'1I9"!E:2!S86$@='5R=F%K86%L=71L
M=7-T96P@<')O9W)A;7-E;'0@<V]O<FET861A(&SU:6MA;6ES="]K;&5E<&EM
M:7-T+B!+=6D@:VSU<'-A9"!/2RP@;N1E9"!M;WII;&QA+F]R9R!T96AN:6QI
M<W0@<V5L9VET=7-T(&MU:61A<R!L=6)A9&$@<VMR:7!T:61E;"!L]6EK97!U
M:'9R:70@:V%S=71A9&$N`$5E;6%L9&$@=N1R=@!4;V5T86UA=&$@;&%I96YD
M=7,`2VEN;FET80!-=75D82`E<P!-=75D82!K87-U=&%J80`B)7,B(&UU=61E
M='5D+@!5=65N9'5S92!S:W)I<'0@:W5S='5T871U9"X`3&%E('-E<G9E<FES
M<V4`2_5I:R!R86ME;F1U<V4@<&%I9V%L9'5S9F%I;&ED(&]N('-E<G9E<FES
M<V4@;&%E='5D+@!,861I;F$@<W5U<G3D:&5D`%-U=7)E9"!R;V]M82!N=6UB
M<FED`%5R=6=U86D`2V%S=71A('!R865G=7-T.B`E<P!+87-U=&$@4U-,:0!+
M87-U=&$@:G5H=6P@:W5I(&YI;6DO<V%L87/U;F$@24U34"!S97)V97)I<R!O
M;B!E<FEN978N`$MA<W5T86IA`$MA<W5T86IA;"`E<R!E:2!O;&4@;'5B871U
M9"`E<RX`2V%S=71A:F%H86QD=7,`2V%S=71A:F$@<V5A9&ES='5S`$MA<W5T
M86IA(')E9VES=')E97)I;6EN90!396QL97,@<V%I9&ES(&MA<W5T86IA=&4@
M<F5G:7-T<F5E<FEM:7-T(&5I(';U:6UA;&1A=&$N`$MA<W5T86IA:V]N=&]T
M(&5I(&QE:71U9`!+87-U=&%J86YI;6D`2V%S=71A:F%N:6UI("(E<R(@;VX@
M:G5B82!O;&5M87,N`$MA<W5T86IA;FEM:3H`2V%S=71A:F%N:6UI.@!+87-U
M=&%J860@<_QS=&5E;6ES.@!5<V)E:VES=&%N`%9&4R!K871A;&]O9VD@<&]L
M92!O;&5M87,N`%!U:&MU<P!/;&5M87-O;&5V860@:V]R<F5K='-E9"!A<W5K
M;VAA9"!O;CH@`$ME:'1I=G5S`$UI;G5T:71E(&%R=B!P<F%E9W5S97-T(&AE
M=&ME<W0@86QA=&5S+@!6Y.1R='5S(/QL971A8B`E<R!M86MS:6UU;7!I:VMU
M<V4N`%;DY')T=7-E9`!6Y.1R='5S960@;6EL;&4@:'5L9V%S="!V86QI9&$`
M5F%N=6%T=0!-=75T;&EK`%9E;F5T<W5E96QA`$MO;G1R;VQL:6UI;F4@;G5R
M:G5S("T@<V5E(&MI<FD@=O5I8B!O;&QA('!A:&%T86AT;&EK=6QT(&UU=61E
M='5D+@!*Y')J96YU;6)E<@!697)S:6]O;FEH86QD=7,`5F5R=&EK86%L;F4@
M:F]O;F1U<P!697)T:6MA86QN92!V;V]D97)D=7,`5F5R=&EK86%L;F4Z`%;D
M9V$@:_5R9V4`5FEE=&YA;0!6:65T;F%M:2`H5DE30TE)*0!686%T82`E<P!6
M86%T82!VY&QI<W0@=F5E8FEL96AT90!686%T82!K=6D@)7,`0G)I=&D@3F5I
M='-I<V%A<F5D`%5302!.96ET<VES86%R960`3N1H=&%V=7,`3N1H=&%V=7,Z
M(`!6;V1A9F]N92!)=&%L>2#\;&4@4TU44`!(3TE!5%53`$A/24%455,A(2$@
M2U535%5402!32U))4%0@2\13251322!+051!3$]/1TE35"`E<RX`5TE.(/QL
M92!(5%10`%=A;&QI<R!J82!&=71U;F$`2&]I871U<P!+;P!);&UA96YN=7-T
M=7,`26QM86%N9&UE:60@<&%K=6(`5V5A=&AE<BYC;VT`5F5E8@!6965B:7-A
M:70`2V]R9"!NY&1A;&%S`%1E<F4@='5L96UA<W0`5&5R92!T=6QE;6%S="`E
M<RUI`%1E<F4@='5L96UA<W0L("5S`$SDY&YE("A)4T\M.#@U.2TQ*0!,Y.1N
M92`H25-/+3@X-3DM,34I`$SDY&YE+5-A:&%R80!-:6QL:7-E(')A:V5N9'5S
M92!P96%K<R`E<R!PY')A<W0@<VES<V5L;V=I;6ES="!A=F%M83\`36EL;&ES
M="!MY')K:2!K87-U=&%T86MS92!E<F%L9&%J86YA/P!-:6QL:7-T(&WD<FMI
M(&MA<W5T871A:W-E(&IU='5MY')G:6YA/P!7:&5R96ES($%U<W1R86QI82!K
M86%R=`!-:6QL:7-E9"!F86%S:60`36EL;&ES96ED('!L=6=I;F%I9"!L=6)A
M9&$@4FEC:"!497AT(&5D:71O<FES+@!,86EU<P!,86EU<R!#4U,@_&AI:W5T
M97,`)7,@;65N_/P@;&%I=7,@=F%S86MU;"`H:&%K:V%B(&WU:G5M82!JY')G
M;6ES96P@<VES<V5L;V=I;6ES96PI.@!486)E;&D@;&%I=7,`3&%I=7/\:&EK
M`$QA:75S.@!7:6MI`%1U=6P`2&]M;6EK=6P@='5U;`!4=75L92!K:6ER=7,@
M<_5L;65D97,`5'5U;#H`5'5U;#H@`%1A<FMU<P!3;V]V:6YI;65K:7)I`%3V
M]@!4]O9K;VAA(&%A9')E<W,`5/;V=&5L969O;@!296%S("5D(&]N('9A;&4@
M87)V(';D;&IU+B!096%K<R!O;&5M82`E9"P@86=A(&]N("5D+@!686QE(&%R
M=B!VY&QJ=2X@4&5A:W,@;VQE;6$@)60L(&%G82!O;B`E9"X`5F%L92!A;&=U
M<W!U;FMT("5D(%9&4R!F86EL:2!L=6=E;6ES96PN`%@M4F5F`%@U,#EV,R!P
M]6AI;&ES960@<&EI<F%N9W5D`%@U,#EV,R!V]71M92!L86EE;F1A='5D(&MA
M<W5T=7,`6#4P.78S('-U8FIE:W1I(&%L=&5R;F%T:6EV;F4@;FEM:0!8-3`Y
M=C,@<W5B:F5K=&D@=O5T;64@:61E;G1I9FEK86%T;W(`6#4P.78S(&QA:65N
M9'5S960`04$`04%!00!986AO;R$@:V%A<G0`2V]R9"!A87-T87,`2F5E;65N
M`$IA:`!*86@L(&]L96X@;O5U<P!/;&5D(%1%2U-425)%6DE)34E3+B!+;/5P
M<V$@6SP^72!E="!M:6YN82!T86=A<VD@5UE325=91R!R97II:6UI+@!%:2!O
M;&4@;'5B871U9"!L=75A(')O:&ME;2!K=6D@)60@8FQO:VMI+@!382!E:2!O
M;&4@<VES<V4@;&]G:71U9"X`4VEN=2!TY&ES;FEM:2!E:2!V]6D@<VES86QD
M861A("=<)R!MY')K:2X`4V$@96D@<VES97-T86YU9"!K;W)R96MT<V5T(&4M
M<&]S=&D@86%D<F5S<VDN`%-A(&5I('-E861N=60@:6UP;W)D:71U9"!F86EL
M:2!VY&QJ=2!V87-T879U<W-E("5S(';D;&IA9&5G82X`4VEN9"!L;V=I=&D@
M=N1L:F$N`%-A('!E860@<VES97-T86UA(&ME:'1I=F$@;6]B:6EL=&5L969O
M;FD@;G5M8G)I(&UI<R!S:7-A;&1A8B!A:6YU;'0@;G5M8G)E:60@:F$@;6EL
M;&4@86QG=7-E<R!V]6EB(&]L;&$@)RLG(')A:'9U<W9A:&5L:7-E('-U=6YA
M:V]O9&D@='5N;G5S96YA+@!382!P96%D('-I<V5S=&%M82!K;W)R96MT<V4@
M=N3D<G1U<V4N`$QI:71U;6ES92!L=6)A;6ES96MS('!E860@<V5A9&ES=&%M
M82!$871A5')E92!S_'-T965M:2X`4V$@<&5A9"!S96%D:7-T86UA(%9&4R!S
M_'-T965M:2X`16YN92!S86%T;6ES="!O;&5K<R!T87)K('!R;V)L965M:2!K
M:7)J96QD861A+@!382!P96%D('-I<V5S=&%M82!54DQI(&MU:'4@<V5E(&QI
M;FL@=FEI=&%B`%!E860@;>3D<F%M82!K=7-T=71A=&%V82!S97)V97)I+@!0
M96%D(&WDY')A;6$@:V%S=71A:F%N:6UE(&UI9&$@=/QH:F5N9&%D82X`4&5A
M9"!MY.1R86UA(&MA<W5T86IA;FEM92!M:61A(&5E;6%L9&%D82X`4&5A9"!M
MY.1R86UA(&MA<W5T86IA;FEM92!M:61A(&QI<V%D82X`4&5A9"!MY.1R86UA
M(&MA<W5T86IA;FEM92!M:61A(&UU=71A+@!096%D(&WDY')A;6$@=&5G979U
M<V4L(&UI9&$@<V]O=FED('1E:&$N`%!E860@<VES97-T86UA('5U92!K871E
M9V]O<FEA(&YI;64N`%!E860@<VES97-T86UA($ET86%L:6$@=&5L969O;FEN
M=6UB<FD`4VEN=2`E<R!S97-S:6]O;B!O;B!A96=U;G5D+B!086QU;B!L;V=I
M('5U97-T:2!S:7-S92X`4VEN=2!E+7!O<W1I(&%A9')E<W,Z`%-I;G4@<V%A
M=&IA(&%A9')E<W,Z`%-I;G4@:6YF;P!3:6YU(&EN=&5R;F5T:6%A9')E<W,@
M;VX@)7,@<V5S<VEO;VYI(&IO;VMS=6P@;75U='5N=60N(%1U<G9A;&ES=7-E
M('1A9V%M:7-E:W,@<&5A9"!U=65S=&D@<VES<V4@;&]G:6UA+@!3:6YU(&YI
M;6D`4VEN=2!A=71E;G1I;6ES<_QS=&5E;2!E:2!V]6EM86QD82!K87-U=&%J
M86ED(&QI<V%D82X@2W5I('-O;W9I9"!(;W)D92!A8FEL(&MA<W5T86IA:60@
M:&%L;&%T82P@<&5A9"!K87-U=&%M82!T96ES='-U9W5S="!A=71E;G1I;6ES
M<_QS=&5E;6DN`%-I;G4@875T96YT:6UI<W/\<W1E96T@96D@=O5I;6%L9&$@
M:V%S=71A:F%T92!N:6UE:VER:F$@;N1H82P@=O5I(&]N('-E92!V]6EM86QU
M<R!M:6YG:6P@;75U;"!P]6AJ=7-E;"!VY&QJ82!L_&QI=&%T=60N`%-I;G4@
M=F5E8FEL96AI='-E:F$@;N1I8B!O;&5V870@)7,@<V5S<VEO;VYI(&IO;VMS
M=6P@;75U='5N=60N(%1U<G9A;&ES=7-E('1A9V%M:7-E:W,@<&5A9"!U=65S
M=&D@<VES<V4@;&]G:6UA+@!3:6YU('9E96)I;&5H:71S96IA(&5I(';U:6UA
M;&1A('-E9&$@;VUA9'5S="!K87-U=&%D82X`4VEN=2!V965B:6QE:&ET<V5J
M82!E:2!V]6EM86QD82!N:6EM;V]D:2!T<OQK:VED82X@5F%J=71A('1R_&MK
M:6UI<V5K<R!#;VYT<F]L*U`@=O5I($-O;6UA;F0K4"X`4VEN=2!A:F%V]O9N
M9#H`4VEN=2!V86EK96ED96YT:71E970@;VX@;75U9&5T=60N`%-I;G4@=F%I
M:V5I9&5N=&ET965T.@!3:6YU('3D:65L:6L@;FEM:3H`4VEN=2!S:7-S96QO
M9VEM:6YE(&]N(&%E9W5N=60N`%-I;G4@=75S("5S('-A;&%S]6YA(&]N.B`E
M<P!-=75D871U<V5D(&]N('-A;'9E<W1A='5D('-E;&QE('-E<W-I;V]N:2!L
M]7!U;FDN`$UU=61A='5S960@;VX@<V%L=F5S=&%T=60N`%-I;G4@<V%L87/U
M;F$@;VX@=F%H971A='5D`%-I;G4@<V%L87/U;F$@;VX@=F%H971A='5D+"!V
M86%T82!O;6$@92UP;W-T:2!J82!L;V=I('-I<W-E('5U92!S86QA<_5N86=A
M+@!3:6YU('-A;&%S]6YA(&]N(&%E9W5N=60N`%-I;G4@=N1L:7-E9"!S97)V
M97)I9#H`2G5G;W-L86%V:6$`6F%I<@!386UB:6$`6FEM8F%B=V4`6FEP<'D`
M6U!E:61A(&]S=6YD871U9"!T96MS=%T`6TAO<F1E('!R;V)L965M70!;3N1I
M=&$@;W-U;F1A='5D('1E:W-T:2`M`%M.Y&ET82!O<W5N9&%T=60@=&5K<W1I
M("T@)7,@<FED85T`6W)I9&$@)7,@)7,M<W1=`%](86QD=7,`2^1S=5]R:61A
M`%]$871A5')E90!?2W5S='5T82!R:61A`%]'<G5P:60`05]B:0!?4&EL9&D@
M;VUA9'5S960N+BX`7TQO9VD@<VES<V4`7TQO9VD@=N1L:F$`7TUU=61A(&QI
M;FMI+BXN`%]396%D:7-T=7,`U6EG7W5S960`7T5E;6%L9&$@;&EN:RXN+@!?
M4&%I9V%L9'5S`%]486)E;&D@;VUA9'5S960N+BX`7TMA<W5T86IA9`!A861R
M97-S:7)A86UA=`!A9')E<W-A870@='5N9&UA='4`:V%L96YD97(`=F%I:VYE
M`';D;&IU;F1F86EL:2!L;V]M:6YE(&YU<FIU<P!S:7-E;F1I(&%V86UI;F4@
M;G5R:G5S`&ML]7!S82!S:6EA`&OD<W5R96$@:V%S=71A;6ES92!V:6=A`'-E
M861I<W1U<V4@=FEG80!E;'5TY&AT:7,@<_QS=&5E;6EF86EL(&]N('!U=61U
M`&%N9&UE=&4@9F]R;6%A9&D@=FEG80!M=75D80!K86YN970@96D@;&5I='5D
M`&QA;F=E8@!F86EL`'-U=6YD("5S("@E<RD@:F$@:VEI<G5S("5S("5S`'!U
M:&%N9W5L:6YE`&LZ`'1T`'1U;F1M871U(&AO<W1I;FEM:0!V:6EV:71A;6%T
M=0!I;FQI;F4`<VES96YD+W;D;&IU;F0@=FEG80!T87)K=F%R82!S965S;6EN
M92!V:6=A`')I9&%=`&UK:7-O9G,@=F5A:V]O9"`E9"!)4T\@;&]O;6ES96PN
M`&UM`&YI;6D`<&]L92!T96]S=&%T=60`<&]L92!V965L('1E;W-T871U9`!M
MY')K;6EK`'!R;W1S96YT:0#U:6=U<V5D('!U=61U=F%D`'!I:W-L:70`<')O
M=&]K;VQL:2!V:6=A('1E:7-E<R!O='-A<P!T]75S96(`=&5E;G5S('!O;&4@
M:^1T=&5S86%D878`;N1I=&$@97)I;F5V=7-I`'-M<S)E;6%I;"#\;&4@2%14
M4`!S<P#\:'1L86YE`&S\;&ET82!J879A<V-R:7!T(';D;&IA`'/\<W1E96UI
M('9I9V$`_&QE<V%N;F5T92!N:6UE:VER:0!A:G5T:6YE('3U<F=E`'!R;V]V
M:2!U=65S=&D`:VER:G5T82!S86QA<_5N82!E:W-I='5S92!VY&QT:6UI<V5K
M<R!K86MS(&MO<F1A`/QH:71A='5D`&YI;65T=0!K87-U=&%J82!V86QI:P!V
M0V%R9`!L.@!W96%T:&5R+F-O;0``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C
M86QE+V5T7T5%+VAE;'`N>&UL````````````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`S,S(P(#$P-3$U-#,S-S0Q(#`R,30R-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/WAM;"!V97)S
M:6]N/2(Q+C`B/SX*/"$M+2`D2&]R9&4Z(&AO<F1E+VQO8V%L92]E=%]%12]H
M96QP+GAM;"QV(#$N,B`R,#`T+S`U+S(W(#(P.C(R.C$U(&IA;B!%>'`@)"`M
M+3X*/&AE;'`^"B`@/&5N=')Y(&ED/2)S=6UM87)Y(B!S=&%T93TB;F5W(CX*
M/'1I=&QE/E1H92!0;W)T86P@4&%G93PO=&ET;&4^"B`\<&%R83X*("!4:&ES
M('!O<G1A;"!P86=E('!R;W9I9&5S(&$@<75I8VL@<W5M;6%R>2!O9B!A;&P@
M>6]U<B!I;7!O<G1A;G0*("!I;F9O<FUA=&EO;BX@1F]R(&5X86UP;&4L(&ET
M(&UI9VAT('-H;W<@:&]W(&UA;GD@;F5W(&4M;6%I;"!M97-S86=E<R!Y;W4*
M("!H879E(&EN('EO=7(@24Y"3U@L('5P8V]M:6YG(&5V96YT<R!O;B!Y;W5R
M(&-A;&5N9&%R+"!T87-K<R!O;B!Y;W5R('1O+61O"B`@;&ES="P@:&5A9&QI
M;F5S(&9R;VT@<V5L96-T960@;F5W<R!S97)V:6-E<RP@86YD('-O(&]N+B`@
M36%N>2!O9B!T:&5S90H@('-U;6UA<FEE<R!W:6QL(&-O;G1A:6X@<75I8VL@
M<VAO<G1C=71S('1O(&-O;6UO;B!F=6YC=&EO;G,L('-U8V@@87,*("!C;VUP
M;W-I;F<@82!N97<@;6%I;"!M97-S86=E+"!C<F5A=&EN9R!A(&YE=R!C86QE
M;F1A<B!E=F5N="!O<B!T87-K+"!E=&,N"B`\+W!A<F$^"B`\<&%R83X*("!4
M:&4@8V]N=&5N=',@;V8@=&AI<R!P;W)T86P@<&%G92!A<F4@8W5S=&]M:7IA
M8FQE('9I82!T:&4@3&%Y;W5T(&)U='1O;BX*("!&;W(@97AA;7!L92P@>6]U
M(&-A;B!C:&]O<V4@=VAI8V@@:71E;7,@=&\@:6YC;'5D92!O;B!T:&ES('!O
M<G1A;"!P86=E(&%S"B`@=V5L;"!A<R!I;B!W:&EC:"!O<F1E<B!T:&5Y(&%R
M92!S:&]W;BX*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](FYA=F)A
M<B(@<W1A=&4](FYE=R(^"CQT:71L93Y4:&4@07!P;&EC871I;VX@3F%V:6=A
M=&EO;B!"87(\+W1I=&QE/@H@/'!A<F$^"B`@070@=&AE(&QE9G0@:&%N9"!S
M:61E(&]F('1H92!W96(@<&%G92!I<R!T:&4@87!P;&EC871I;VX@;F%V:6=A
M=&EO;B!B87(N"B`@0VQI8VL@;VX@=&AE(&EC;VYS(&]N('1H:7,@;F%V:6=A
M=&EO;B!B87(@=&\@<75I8VML>2!A;F0@96%S:6QY('-W:71C:`H@(&)E='=E
M96X@=&AE(&%V86EL86)L92!A<'!L:6-A=&EO;G,N"B`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD;U]M86EN=&5N86YC92(@<W1A=&4]
M(FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!$
M;R!-86EN=&5N86YC93PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W
M;W5L9"!L:6ME('1O('!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O
M;B!L;V=I;BP@8VAE8VL@=&AI<R!B;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P<F5F<RUC;VYF:7)M7VUA:6YT96YA;F-E(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z
M($-O;F9I<FT@36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)
M9B!Y;W4@=V]U;&0@;&EK92!T;R!C;VYF:7)M(&%L;"!M86EN=&5N86YC92!T
M87-K<R!B969O<F4@=&AE>2!A<F4@<G5N+"!C:&5C:R!T:&ES(&)O>"X@268@
M;&5F="!U;F-H96-K960L(&%L;"!M86EN=&5N86YC92!O<&5R871I;VYS('1H
M870@;F5E9"!T;R!B92!R=6X@=VEL;"!B92!P97)F;W)M960@875T;VUA=&EC
M86QL>2!W:71H(&YO(&-H86YC92!T;R!C86YC96P@;VX@;&]G:6XN"B`@("`\
M+W!A<F$^"CPO96YT<GD^"CPO:&5L<#X*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]F
M<E]&4@``````````````````````````````````````````````````````
M```````````````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<T,2`P,3<W,30`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&]C86QE+V9R7T92+TQ#7TU%4U-!1T53````````````````
M`````````````````````````````````````````````````````#`P,#<U
M-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S0Q(#`R
M,34P,0`@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O9G)?1E(O3$-?3453
M4T%'15,O:&]R9&4N;6\`````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`T,C4U
M-C<@,3`U,34T,S,W-#$@,#(S,C0Q`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````-X2!)4`````B0<``!P```!D/```$PH``*QX
M````````^*````X```#YH```#P````BA```-````&*$```@````FH0``"P``
M`"^A```,````.Z$```0```!(H0``&````$VA```;````9J$``"T```""H0``
M'0```+"A```D````SJ$``"D```#SH0``&0```!VB```F````-Z(```P```!>
MH@``)````&NB```/````D*(```L```"@H@``#@```*RB```%````NZ(``"@`
M``#!H@``"````.JB```*````\Z(``!4```#^H@``$@```!2C```+````)Z,`
M`(4````SHP``#@```+FC```*````R*,```T```#3HP``#@```.&C```1````
M\*,```T````"I```#````!"D```-````':0```8````KI```E````#*D```*
M````QZ0```\```#2I```&````.*D```,````^Z0```X````(I0``#@```!>E
M```(````)J4```D````OI0``+@```#FE```:````:*4``#(```"#I0``.```
M`+:E``!4````[Z4``%$```!$I@``6@```):F``!7````\:8``#0```!)IP``
M"0```'ZG```-````B*<```<```"6IP``"@```)ZG```/````J:<```4```"Y
MIP``!@```+^G```1````QJ<```@```#8IP``"0```.&G```)````ZZ<``"4`
M``#UIP``(````!NH```3````/*@``!````!0J```#P```&&H```*````<:@`
M``,```!\J```#P```("H```4````D*@```D```"EJ```#0```*^H```2````
MO:@``!D```#0J```'@```.JH```/````":D```H````9J0``#P```"2I```(
M````-*D``"0````]J0``%````&*I```6````=ZD```@```".J0``3@```)>I
M```M````YJD``!D````4J@``!P```"ZJ```,````-JH``"P```!#J@``#@``
M`'"J```#````?ZH```L```"#J@``!P```(^J```'````EZH```4```"?J@``
M!0```*6J```*````JZH```,```"VJ@``%P```+JJ```*````TJH```\```#=
MJ@``#@```.VJ```8````_*H``",````5JP``#@```#FK```4````2*L``!<`
M``!=JP``%P```'6K```7````C:L``!,```"EJP``#P```+FK```.````R:L`
M`!\```#8JP``'0```/BK```'````%JP```8````>K```"````"6L```/````
M+JP```8````^K```"@```$6L```3````4*P```L```!DK```$````'"L```5
M````@:P``!4```"7K```!P```*VL```0````M:P```4```#&K```%0```,RL
M```1````XJP```P```#TK```.P````&M```X````/:T```D```!VK0``!P``
M`("M```4````B*T```,```"=K0``!0```*&M```0````IZT```D```"XK0``
M$P```,*M```Y````UJT``!(````0K@``)P```".N```L````2ZX``"H```!X
MK@``)0```*.N```*````R:X```8```#4K@``"0```-NN```'````Y:X``"\`
M``#MK@``-P```!VO```N````5:\``%4```"$KP``+0```-JO```M````"+``
M`#T````VL```/P```'2P```M````M+```$````#BL```(P```".Q```C````
M1[$``$````!KL0``+0```*RQ```S````VK$``"4````.L@``%0```#2R```9
M````2K(``"D```!DL@``)````(ZR```H````L[(``!$```#<L@``"@```.ZR
M```,````^;(```H````&LP``$````!&S```6````(K,``!8````YLP``!P``
M`%"S```'````6+,``!0```!@LP``"@```'6S```(````@+,``"<```")LP``
M"````+&S```'````NK,```<```#"LP``!@```,JS```%````T;,```<```#7
MLP``!@```-^S```(````YK,``"D```#OLP``#@```!FT```*````*+0```0`
M```SM```!P```#BT```)````0+0```8```!*M```$0```%&T```'````8[0`
M`!8```!KM```!````(*T```(````A[0```8```"0M```#0```)>T```&````
MI;0``!X```"LM```$0```,NT```(````W;0```T```#FM```#````/2T```'
M`````;4```,````)M0```P````VU```7````$;4``!,````IM0``'0```#VU
M```(````6[4```0```!DM0``"````&FU```(````<K4``$$```![M0``&@``
M`+VU```K````V+4``"`````$M@``%0```"6V```&````.[8```8```!"M@``
M%0```$FV```8````7[8``"(```!XM@``+@```)NV```=````RK8``"$```#H
MM@``5`````JW```I````7[<```H```")MP``!P```)2W```'````G+<``!4`
M``"DMP``#@```+JW```*````R;<```\```#4MP``#0```.2W```/````\K<`
M``T````"N```"0```!"X```4````&K@```8````ON```&````#:X```=````
M3[@``!,```!MN```$0```(&X```4````D[@```0```"HN```!@```*VX```4
M````M+@``%0```#)N```9````!ZY```$````@[D```X```"(N0``!0```)>Y
M```%````G;D``!L```"CN0``&@```+^Y```3````VKD``!$```#NN0``$0``
M``"Z```<````$KH``"H````ON@``$````%JZ```A````:[H```4```"-N@``
M$P```).Z```+````I[H``!(```"SN@``"@```,:Z```/````T;H```T```#A
MN@``$0```.^Z```3`````;L```P````5NP``!@```"*[```,````*;L```8`
M```VNP``%P```#V[```0````5;L``!$```!FNP``"````'B[```%````@;L`
M``P```"'NP``$````)2[```%````I;L```T```"KNP``!@```+F[```'````
MP+L```T```#(NP``!P```-:[```+````WKL```<```#JNP``!P```/*[```)
M````^KL```D````$O```"@````Z\```9````&;P``#T````SO```'0```'&\
M```,````C[P``!````"<O```!0```*V\```E````L[P``!(```#9O```$P``
M`.R\```K`````+T``#L````LO0``(````&B]```(````B;T``#8```"2O0``
M(0```,F]```0````Z[T```@```#\O0``#`````6^```&````$KX```0````9
MO@``#P```!Z^```.````+KX```<````]O@``"@```$6^```-````4+X``!\`
M``!>O@``'````'Z^```A````F[X``!X```"]O@``&0```-R^```>````]KX`
M`!L````5OP``(0```#&_```N````4[\``"8```""OP``'````*F_```>````
MQK\``!P```#EOP``)@````+````K````*<```#,```!5P```)@```(G````K
M````L,```#@```#<P```'0```!7!```5````,\$``"\```!)P0``(````'G!
M```2````FL$``"D```"MP0``'@```-?!```@````]L$``!(````7P@``H@``
M`"K"```6````S<(``",```#DP@``*`````C#```I````,<,``"@```!;PP``
M'P```(3#```5````I,,``"````"ZPP``)0```-O#```H`````<0``"T````J
MQ```,````%C$``"2````B<0``"$````<Q0``%@```#[%```<````5<4``"8`
M``!RQ0``*@```)G%``!!````Q,4``$0````&Q@``#````$O&```'````6,8`
M``<```!@Q@``!@```&C&```-````;\8``!````!]Q@``$@```([&```3````
MH<8``!(```"UQ@``!P```,C&```$````T,8``!````#5Q@``$````.;&```,
M````]\8```X````$QP``#0```!/'```/````(<<``!,````QQP``#0```$7'
M```H````4\<```,```!\QP``#0```(#'```&````CL<``!$```"5QP``%P``
M`*?'```;````O\<```X```#;QP```@```.K'``!)````[<<```4````WR```
M$````#W(```/````3L@```0```!>R```#0```&/(```.````<<@```,```"`
MR```#@```(3(```(````D\@```\```"<R```#P```*S(```'````O,@```T`
M``#$R```$````-+(```-````X\@```L```#QR```!@```/W(```+````!,D`
M``P````0R0``"@```!W)```1````*,D``!D````ZR0``"P```%3)```-````
M8,D``"(```!NR0``#P```)')```;````H<D``#0```"]R0``"@```/+)```8
M````_<D``!(````6R@``&0```"G*```6````0\H``"(```!:R@``#0```'W*
M```'````B\H``!0```"3R@``"P```*C*```B````M,H``"\```#7R@``"P``
M``?+```)````$\L``!D````=RP``"P```#?+```7````0\L``!<```!;RP``
M"0```'/+```6````?<L```\```"4RP``&0```*3+```6````OLL```X```#5
MRP``&````.3+```(````_<L```T````&S```)@```!3,``!#````.\P```@`
M``!_S```$@```(C,```?````F\P```@```"[S```"P```,3,```O````T,P`
M``X`````S0``!0````_-```&````%<T``$4````<S0```P```&+-```'````
M9LT```0```!NS0``"@```'/-```*````?LT```\```")S0``$````)G-```7
M````JLT``!$```#"S0``&0```-3-```7````[LT```D````&S@``!0```!#.
M```+````%LX```H````BS@```@```"W.```%````,,X```T````VS@``&P``
M`$3.```7````8,X``!0```!XS@``"0```(W.```.````E\X```T```"FS@``
M$@```+3.```X````Q\X``"``````SP``"````"'/```.````*L\``'L````Y
MSP``&````+7/```8````SL\``!$```#GSP``!P```/G/```%`````=```!@`
M```'T```'@```"#0```;````/]```!D```!;T```&P```'70```9````D=``
M`!,```"KT```!P```+_0```(````Q]````8```#0T```!@```-?0```0````
MWM````\```#OT```$````/_0```/````$-$```L````@T0``#P```"S1```,
M````/-$```\```!)T0``!P```%G1```&````8=$```X```!HT0``#````'?1
M```H````A-$```\```"MT0``"````+W1```(````QM$``!,```#/T0``'@``
M`./1```A`````M(``"`````DT@``&0```$72```7````7](``"4```!WT@``
M%P```)W2```6````M=(```0```#,T@``&P```-'2```-````[=(```P```#[
MT@```P````C3```%````#-,```@````2TP``"@```!O3```,````)M,```L`
M```STP``$````#_3```,````4-,```X```!=TP``"P```&S3```$````>-,`
M``0```!]TP``$P```(+3```4````EM,```P```"KTP``"0```+C3```.````
MPM,```L```#1TP``&P```-W3```'````^=,```<````!U```"@````G4```-
M````%-0```D````BU```!````"S4```%````,=0```,````WU```&````#O4
M```*````5-0```0```!?U```)@```&34```.````B]0``'P```":U```%0``
M`!?5```%````+=4```<````SU0``#````#O5```(````2-4```H```!1U0``
M!@```%S5```(````8]4```(```!LU0``!@```&_5```&````=M4``!0```!]
MU0``#0```)+5```0````H-4``!L```"QU0``!````,W5```)````TM4``!``
M``#<U0``"0```.W5```)````]]4```4````!U@``&@````?6```(````(M8`
M``8````KU@``&0```#+6```.````3-8```<```!;U@``!P```&/6```%````
M:]8```D```!QU@``"@```'O6```.````AM8```(```"5U@``!@```)C6```+
M````G]8```T```"KU@``"0```+G6```&````P]8``!(```#*U@``"0```-W6
M```'````Y]8``!0```#OU@``'0````37``!"````(M<``"4```!EUP``)0``
M`(O7```&````L=<```H```"XUP``!````,/7```)````R-<```@```#2UP``
M$0```-O7```)````[=<```8```#WUP``#0```/[7```&````#-@```0````3
MV```.0```!C8```]````4M@``#H```"0V```'@```,O8```%````ZM@```X`
M``#PV```!````/_8```&````!-D```<````+V0``(0```!/9```-````-=D`
M`!4```!#V0``!@```%G9```$````8-D``!$```!EV0``!@```'?9```*````
M?MD``"(```")V0``!````*S9```%````L=D``!T```"WV0``!````-79```,
M````VMD```X```#GV0``"@```/;9```(`````=H```D````*V@``!0```!3:
M```Z````&MH``#````!5V@``-0```(;:```I````O-H``$<```#FV@``.```
M`"[;```I````9]L``#\```"1VP``+@```-';```M`````-P``!\````NW```
M#P```$[<```2````7MP```L```!QW```)@```'W<```I````I-P``"0```#.
MW```)@```//<```(````&MT```H````CW0``"0```"[=```'````.-T``"``
M``!`W0``(````&'=```F````@MT```H```"IW0``&0```+3=```I````SMT`
M`!8```#XW0``$@````_>```'````(MX```H````JW@``#````#7>```/````
M0MX``!````!2W@``0````&/>``!P````I-X``&8````5WP``#@```'S?```)
M````B]\```H```"5WP``$@```*#?```3````L]\```P```#'WP``!@```-3?
M```/````V]\``!(```#KWP``$````/[?```1````#^```!P````AX```(P``
M`#[@``!J````8N````\```#-X```!0```-W@```0````X^````D```#TX```
M!````/[@```+`````^$``"`````/X0``%````##A```,````1>$```P```!2
MX0``#P```%_A```5````;^$``"D```"%X0``*@```*_A```F````VN$``"<`
M```!X@``*0```"GB```J````4^(``!D```!^X@``0@```)CB```1````V^(`
M`!(```#MX@``$P````#C```4````%.,```\````IXP``%@```#GC```7````
M4.,``!````!HXP``$0```'GC```T````B^,``!,```#`XP``$@```-3C```U
M````Y^,``!0````=Y```!P```#+D```,````.N0``"````!'Y```$````&CD
M```4````>>0``!$```".Y```%P```*#D```<````N.0``!,```#5Y```%```
M`.GD```:````_N0``!$````9Y0``&@```"OE```>````1N4``!H```!EY0``
M$P```(#E```5````E.4``!$```"JY0``%P```+SE```4````U.4``!<```#I
MY0``%0````'F```)````%^8``!`````AY@``&0```#+F```$````3.8```<`
M``!1Y@``"P```%GF```1````9>8```8```!WY@``!@```'[F```&````A>8`
M``4```",Y@``!P```)+F```'````FN8```4```"BY@``%@```*CF```&````
MO^8```8```#&Y@``!````,WF```$````TN8```<```#7Y@``#@```-_F```,
M````[N8```P```#[Y@``#0````CG```*````%N<```X````AYP``!0```##G
M```H````-N<```X```!?YP``#````&[G```/````>^<```H```"+YP``"```
M`);G```)````G^<``"L```"IYP``!````-7G```(````VN<``"8```#CYP``
M$@````KH```/````'>@```8````MZ```"@```#3H```'````/^@```@```!'
MZ```(````%#H```)````<>@``!0```![Z```#````)#H```-````G>@```X`
M``"KZ```%@```+KH```1````T>@```8```#CZ````P```.KH```&````[N@`
M`!D```#UZ```!P````_I```$````%^D```L````<Z0``"P```"CI```'````
M-.D```4````\Z0``!P```$+I```6````2ND```T```!AZ0``#0```&_I```*
M````?>D``!````"(Z0``#P```)GI```1````J>D``!<```"[Z0``"@```-/I
M```1````WND```@```#PZ0``!````/GI```/````_ND``#H````.Z@``!0``
M`$GJ```,````3^H``!X```!<Z@``#@```'OJ```0````BNH```L```";Z@``
M#````*?J```)````M.H```<```"^Z@``"@```,;J```)````T>H```X```#;
MZ@``$````.KJ```;````^^H``!@````7ZP``&@```##K```*````2^L```D`
M``!6ZP``"@```&#K```,````:^L```\```!XZP``"````(CK```&````D>L`
M`!P```"8ZP``!P```+7K```%````O>L```L```##ZP``1P```,_K```-````
M%^P```D````E[```!````"_L```#````-.P``!,````X[```$P```$SL```3
M````8.P```H```!T[````@```'_L```$````@NP``"4```"'[````P```*WL
M```%````L>P``"H```"W[```"@```.+L```%````[>P```0```#S[```"@``
M`/CL```-`````^T```8````1[0``"````!CM```(````(>T```0````J[0``
M!0```"_M``!H````->T```D```">[0``#````*CM```0````M>T```4```#&
M[0``!@```,SM```;````T^T``"\```#O[0``$````!_N```*````,.X```\`
M```[[@``"@```$ON```)````5NX``!,```!@[@``&P```'3N```8````D.X`
M`!<```"I[@``'P```,'N```.````X>X```,```#P[@``!P```/3N```(````
M_.X```<````%[P``"@````WO```+````&.\```<````D[P``40```"SO```0
M````?N\```P```"/[P``#0```)SO```:````JN\``$H```#%[P``&0```!#P
M```&````*O```!H````Q\```)0```$SP```&````<O````8```!Y\```'P``
M`(#P```&````H/````D```"G\```&````+'P```7````RO```"@```#B\```
M!@````OQ```-````$O$``"(````@\0``5P```$/Q```3````F_$``",```"O
M\0``$P```-/Q```"````Y_$```L```#J\0``"````/;Q```-````__$```H`
M```-\@``!P```!CR```4````(/(```8````U\@``"````#SR```.````1?(`
M``<```!4\@``"@```%SR```+````9_(``#(```!S\@``!P```*;R```,````
MKO(```T```"[\@``%P```,GR```,````X?(```D```#N\@``"0```/CR```*
M`````O,```<````-\P``"0```!7S```'````'_,```H````G\P``&P```#+S
M```/````3O,``!(```!>\P``"@```''S```6````?/,```D```"3\P``$```
M`)WS```'````KO,``!(```"V\P``!````,GS```'````SO,```4```#6\P``
M!0```-SS```+````XO,``!0```#N\P``$0````/T```:````%?0``!8````P
M]```%````$?T```7````7/0``!@```!T]```'````(WT```9````JO0```<`
M``#$]```!0```,ST```-````TO0```P```#@]```"````.WT```7````]O0`
M``L````.]0``#````!KU```?````)_4``!H```!']0``$P```&+U```$````
M=O4```H```![]0``!````(;U```-````B_4```P```"9]0``!0```*;U```)
M````K/4```4```"V]0``!P```+SU```%````Q/4```0```#*]0```@```,_U
M```X````TO4``"P````+]@``$@```#CV```I````2_8``#(```!U]@``"@``
M`*CV```L````L_8``"X```#@]@``,P````_W```S````0_<``#@```!W]P``
M#P```+#W```8````P/<``!````#9]P``#P```.KW```3````^O<``!4````.
M^```%````"3X```2````.?@``!0```!,^```%0```&'X```M````=_@``"T`
M``"E^```,0```-/X```N````!?D``"\````T^0``+````&3Y``!B````D?D`
M`!,```#T^0``#0````CZ```(````%OH``!<````?^@``"````#?Z```,````
M0/H``"L```!-^@``(0```'GZ```:````F_H```D```"V^@``10```,#Z``!!
M````!OL```0```!(^P``$P```$W[```4````8?L```X```!V^P``$P```(7[
M```8````F?L```8```"R^P``"0```+G[```*````P_L```\```#.^P``$```
M`-[[```'````[_L```X```#W^P``!0````;\```;````#/P```@````H_```
M!@```#'\```4````./P``!$```!-_```#@```%_\```X````;OP```(```"G
M_```!@```*K\```.````L?P```4```#`_```!P```,;\```.````SOP```8`
M``#=_```*````.3\```,````#?T``!P````:_0``!````#?]```I````//T`
M`!<```!F_0``'P```'[]``!<````GOT``!0```#[_0``/@```!#^```?````
M3_X``!````!O_@``!P```(#^```.````B/X```P```"7_@``#````*3^```3
M````L?X```H```#%_@``'0```-#^```9````[OX```4````(_P``$0````[_
M```1````(/\``"0````R_P``$@```%?_```5````:O\``!(```"`_P``#@``
M`)/_```9````HO\```@```"\_P``"0```,7_```-````S_\```<```#=_P``
M"@```.7_```'````\/\```\```#X_P``!@````@``0`+````#P`!`!H````;
M``$`"@```#8``0`'````00`!``@```!)``$`!0```%(``0`?````6``!``8`
M``!X``$`$````'\``0`(````D``!``T```"9``$`"````*<``0`>````L``!
M`!(```#/``$`+````.(``0`:````#P$!``D````J`0$`"@```#0!`0`5````
M/P$!``4```!5`0$`%````%L!`0`$````<`$!`!````!U`0$`!@```(8!`0`'
M````C0$!`!X```"5`0$`*````+0!`0`*````W0$!`!P```#H`0$`$0````4"
M`0`+````%P(!`!H````C`@$`%````#X"`0`$````4P(!``0```!8`@$`"P``
M`%T"`0`%````:0(!``8```!O`@$`"````'8"`0`&````?P(!``H```"&`@$`
M&P```)$"`0`T````K0(!`#0```#B`@$`(````!<#`0`I````.`,!`"````!B
M`P$`00```(,#`0`:````Q0,!`"@```#@`P$`*0````D$`0!0````,P0!`"(`
M``"$!`$`!@```*<$`0`(````K@0!``4```"W!`$`"````+T$`0`9````Q@0!
M`!D```#@!`$`*@```/H$`0`C````)04!`!D```!)!0$`+@```&,%`0`T````
MD@4!``@```#'!0$`%P```-`%`0`*````Z`4!``<```#S!0$`(0```/L%`0`0
M````'08!``X````N!@$`"P```#T&`0`'````208!`!,```!1!@$`"````&4&
M`0`+````;@8!``H```!Z!@$`%````(4&`0`/````F@8!`#(```"J!@$`"P``
M`-T&`0`.````Z08!``4```#X!@$`!0```/X&`0`%````!`<!`!<````*!P$`
M#P```"('`0`$````,@<!``H````W!P$`"0```$('`0`+````3`<!``T```!8
M!P$`#````&8'`0`.````<P<!``4```""!P$`!````(@'`0`-````C0<!`#(`
M``";!P$`10```,X'`0`7````%`@!``<````L"`$`'@```#0(`0`4````4P@!
M``4```!H"`$`%````&X(`0`&````@P@!``<```"*"`$`#@```)((`0`J````
MH0@!``8```#,"`$`#````-,(`0`-````X`@!`!$```#N"`$`"P`````)`0`V
M````#`D!``H```!#"0$`(@```$X)`0`+````<0D!``\```!]"0$`,@```(T)
M`0`E````P`D!`#````#F"0$`,0```!<*`0`M````20H!``X```!W"@$`!0``
M`(8*`0`.````C`H!`!,```";"@$`$@```*\*`0`'````P@H!`!$```#*"@$`
M$P```-P*`0`'````\`H!`!0```#X"@$`&`````T+`0`'````)@L!``4````N
M"P$`#````#0+`0`,````00L!`!(```!."P$`!````&$+`0`'````9@L!``H`
M``!N"P$`"P```'D+`0`,````A0L!``X```"2"P$`#@```*$+`0`%````L`L!
M``4```"V"P$`+@```+P+`0`F````ZPL!`",````2#`$``P```#8,`0`2````
M.@P!``8```!-#`$`'@```%0,`0`8````<PP!`"4```",#`$`#0```+(,`0`)
M````P`P!`!\```#*#`$``P```.H,`0`'````[@P!``H```#V#`$``@````$-
M`0`,````!`T!`!4````1#0$`"P```"<-`0`9````,PT!`"````!-#0$`$@``
M`&X-`0`%````@0T!``H```"'#0$`%0```)(-`0`2````J`T!``P```"[#0$`
M!````,@-`0`)````S0T!``<```#7#0$`#````-\-`0!2````[`T!`!<````_
M#@$`)````%<.`0`2````?`X!``<```"/#@$`!@```)<.`0`.````G@X!``P`
M``"M#@$`#0```+H.`0`5````R`X!`!(```#>#@$`#P```/$.`0`4`````0\!
M``H````6#P$`&P```"$/`0`0````/0\!``L```!.#P$`:0```%H/`0`:````
MQ`\!`!<```#?#P$`)P```/</`0`:````'Q`!`!<````Z$`$`&P```%(0`0`9
M````;A`!`!\```"($`$`$P```*@0`0`(````O!`!``<```#%$`$`"````,T0
M`0`)````UA`!`!4```#@$`$`#0```/80`0`C````!!$!``T````H$0$`$P``
M`#81`0`(````2A$!``,```!3$0$`1@```%<1`0`_````GA$!`#<```#>$0$`
M5P```!82`0`%````;A(!`!\```!T$@$`+P```)02`0`*````Q!(!``@```#/
M$@$`#0```-@2`0`M````YA(!``0````4$P$`3P```!D3`0`E````:1,!`!P`
M``"/$P$`"P```*P3`0`?````N!,!`!T```#8$P$`)0```/83`0`@````'!0!
M`"0````]%`$`(````&(4`0`+````@Q0!``<```"/%`$`#0```)<4`0`,````
MI10!`!<```"R%`$`!@```,H4`0`Y````T10!``P````+%0$`!P```!@5`0`)
M````(!4!`!,````J%0$`"0```#X5`0`$````2!4!`!````!-%0$`"````%X5
M`0`(````9Q4!``0```!P%0$`"P```'45`0`,````@14!`!(```".%0$`$0``
M`*$5`0`,````LQ4!`!H```#`%0$`#P```-L5`0`'````ZQ4!``T```#S%0$`
M%`````$6`0`.````%A8!``P````E%@$`&P```#(6`0`L````3A8!`!,```![
M%@$`'````(\6`0`H````K!8!``8```#5%@$`!P```-P6`0`3````Y!8!``4`
M``#X%@$`!````/X6`0`7`````Q<!``H````;%P$`#````"87`0`)````,Q<!
M``8````]%P$`"0```$07`0`(````3A<!``D```!7%P$`"@```&$7`0`1````
M;!<!``8```!^%P$`#@```(47`0`.````E!<!``T```"C%P$`"P```+$7`0`=
M````O1<!``L```#;%P$``@```.<7`0`<````ZA<!``<````'&`$`!@````\8
M`0!D````%A@!``D```![&`$`!P```(48`0`F````C1@!`#@```"T&`$`&@``
M`.T8`0`J````"!D!`#L````S&0$`*````&\9`0`T````F!D!`!D```#-&0$`
M%0```.<9`0`%````_1D!``<````#&@$`"`````L:`0`'````%!H!``4````<
M&@$`!P```"(:`0`.````*AH!``D````Y&@$`!@```$,:`0`(````2AH!``L`
M``!3&@$`!P```%\:`0`(````9QH!``<```!P&@$`%@```'@:`0`)````CQH!
M``8```"9&@$`"P```*`:`0`0````K!H!``8```"]&@$`'````,0:`0`4````
MX1H!``<```#V&@$`$0```/X:`0`(````$!L!``X````9&P$`"````"@;`0`0
M````,1L!``D```!"&P$`$````$P;`0`&````71L!`!D```!D&P$`"@```'X;
M`0`<````B1L!``<```"F&P$`!0```*X;`0`0````M!L!`!0```#%&P$`"P``
M`-H;`0`-````YAL!`"@```#T&P$`&````!T<`0`7````-AP!``0```!.'`$`
M"0```%,<`0`*````71P!``<```!H'`$``@```'`<`0`.````<QP!``@```""
M'`$`(P```(L<`0`?````KQP!`#@```#/'`$`)@````@=`0`Q````+QT!`"<`
M``!A'0$`9````(D=`0`4````[AT!`%4````#'@$`.````%D>`0!*````DAX!
M`%L```#='@$`*````#D?`0`X````8A\!`"@```";'P$`+````,0?`0`F````
M\1\!`!L````8(`$`/@```#0@`0"I`0``<R`!`",````=(@$`%P```$$B`0!(
M````62(!`(4```"B(@$`,````"@C`0`E````62,!`$$```!_(P$`6P```,$C
M`0!)````'20!`#$```!G)`$`'0```)DD`0`8````MR0!`"L```#0)`$`(0``
M`/PD`0`?````'B4!`"L````^)0$`)@```&HE`0`G````D24!`#H```"Y)0$`
M'0```/0E`0`1````$B8!`#,````D)@$`)0```%@F`0`G````?B8!`"````"F
M)@$`'P```,<F`0`P````YR8!`&D````8)P$`,0```((G`0!!````M"<!`#,`
M``#V)P$`)0```"HH`0`]````4"@!`&4```".*`$`30```/0H`0`O````0BD!
M`"X```!R*0$`,````*$I`0!4````TBD!`%H````G*@$`2````((J`0!*````
MRRH!`#(````6*P$`+P```$DK`0`L````>2L!`"T```"F*P$`<0```-0K`0!F
M````1BP!`&\```"M+`$`LP```!TM`0`7````T2T!`"4```#I+0$`,@````\N
M`0`I````0BX!`#X```!L+@$`(@```*LN`0!2````SBX!`"4````A+P$`"P``
M`$<O`0"Q````4R\!`$4````%,`$`(0```$LP`0`P````;3`!`"4```">,`$`
M'````,0P`0`Q````X3`!``<````3,0$`!P```!LQ`0`$````(S$!``T````H
M,0$`"P```#8Q`0`.````0C$!``L```!1,0$`!0```%TQ`0`0````8S$!``(`
M``!T,0$`60```'<Q`0`%````T3$!`!(```#7,0$`!````.HQ`0`'````[S$!
M``@```#W,0$`!0`````R`0`P````!C(!``,````W,@$`$````#LR`0`,````
M3#(!`!,```!9,@$`#0```&TR`0`"````>S(!``<```!^,@$`!@```(8R`0`4
M````C3(!``P```"B,@$`&````*\R`0`&````R#(!`!(```#/,@$`#````.(R
M`0`#````[S(!`"H```#S,@$`!````!XS`0`&````(S,!``<````J,P$`'P``
M`#(S`0`U````4C,!`"X```"(,P$`+P```+<S`0`7````YS,!`"(```#_,P$`
M)0```"(T`0`@````2#0!`!L```!I-`$`&````(4T`0`D````GC0!`!\```##
M-`$`&@```.,T`0`A````_C0!`"`````@-0$`&@```$$U`0`R````7#4!`!H`
M``"/-0$`+P```*HU`0`K````VC4!`!\````&-@$`(P```"8V`0`?````2C8!
M`!H```!J-@$`(0```(4V`0`E````IS8!`"8```#--@$`)0```/0V`0`D````
M&C<!`!@````_-P$`'0```%@W`0`D````=C<!`!@```";-P$`(@```+0W`0`L
M````US<!`"\````$.`$`%0```#0X`0`E````2C@!`#P```!P.`$`'P```*TX
M`0`C````S3@!`!\```#Q.`$`(````!$Y`0`:````,CD!`!@```!-.0$`)@``
M`&8Y`0`>````C3D!`"D```"L.0$`'@```-8Y`0`Q````]3D!``D````G.@$`
M#````#$Z`0`7````/CH!`"\```!6.@$`)````(8Z`0`'````JSH!``\```"S
M.@$`%````,,Z`0`.````V#H!``T```#G.@$`)````/4Z`0`%````&CL!``<`
M```@.P$`(@```"@[`0`E````2SL!`!H```!Q.P$`'0```(P[`0`:````JCL!
M``<```#%.P$`QP```,T[`0`+````E3P!`!4```"A/`$`!@```+<\`0`)````
MOCP!``L```#(/`$`#0```-0\`0`7````XCP!``8```#Z/`$`,P````$]`0`3
M````-3T!`!,```!)/0$`!P```%T]`0`/````93T!``<```!U/0$`,@```'T]
M`0`$````L#T!`"$```"U/0$`$P```-<]`0`,````ZST!`!$```#X/0$`,@``
M``H^`0`6````/3X!``@```!4/@$`'0```%T^`0`)````>SX!``H```"%/@$`
M%````)`^`0`*````I3X!`!T```"P/@$`"````,X^`0`?````USX!``@```#W
M/@$`&@`````_`0`G````&S\!``8```!#/P$`%0```$H_`0`'````8#\!``@`
M``!H/P$`"0```'$_`0`_````>S\!``<```"[/P$`#P```,,_`0`.````TS\!
M`!````#B/P$`"0```/,_`0`)````_3\!``@````'0`$`$P```!!``0`'````
M)$`!`!D````L0`$`"@```$9``0`7````44`!`!0```!I0`$`"@```'Y``0`,
M````B4`!`!<```"60`$`!````*Y``0`J````LT`!``P```#>0`$`$0```.M`
M`0`'````_4`!``(````%00$`$`````A!`0`8````&4$!``L````R00$``P``
M`#Y!`0`(````0D$!``8```!+00$`!P```%)!`0`-````6D$!``L```!H00$`
M%````'1!`0`5````B4$!``X```"?00$`+P```*Y!`0`@````WD$!`!P```#_
M00$`%0```!Q"`0`,````,D(!`#$````_0@$`!0```'%"`0`2````=T(!`#\`
M``"*0@$`$@```,I"`0`*````W4(!``8```#H0@$`!````.]"`0`$````]$(!
M``H```#Y0@$`$P````1#`0`%````&$,!``8````>0P$`!@```"5#`0`(````
M+$,!``0````U0P$`#````#I#`0`*````1T,!`#D```!20P$`+@```(Q#`0`I
M````NT,!``4```#E0P$`&````.M#`0`9````!$0!`!\````>1`$`'0```#Y$
M`0`1````7$0!``(```!N1`$`!````'%$`0`*````=D0!``8```"!1`$`!0``
M`(A$`0`#````CD0!``P```"21`$`10```)]$`0`R````Y40!`!H````810$`
M-````#-%`0`H````:$4!`%,```"110$`&0```.5%`0!R````_T4!`"````!R
M1@$`-0```)-&`0`A````R48!`$4```#K1@$`,````#%'`0`H````8D<!`"D`
M``"+1P$`)@```+5'`0`E````W$<!`"@````"2`$`*````"M(`0`B````5$@!
M`"L```!W2`$`,````*-(`0`2````U$@!`!,```#G2`$`$````/M(`0!Y````
M#$D!``D```"&20$`H0```)!)`0!S````,DH!`'P```"F2@$`*P```"-+`0!4
M````3TL!`!<```"D2P$`)P```+Q+`0`6````Y$L!``\```#[2P$`%P````M,
M`0`?````(TP!`$````!#3`$`'P```(1,`0`<````I$P!`%$```#!3`$`&@``
M`!--`0`4````+DT!``H```!#30$`!0```$Y-`0`&````5$T!``@```!;30$`
M!0```&1-`0`2````:DT!`!````!]30$`$P```(Y-`0`=````HDT!``\```#`
M30$`#P```-!-`0`$````X$T!``D```#E30$`"P```.]-`0`'````^TT!``4`
M```#3@$`%`````E.`0`'````'DX!``@````F3@$`#P```"].`0`(````/TX!
M``P```!(3@$`#P```%5.`0`&````94X!`!0```!L3@$`!@```(%.`0`,````
MB$X!`!$```"53@$`"````*=.`0`$````L$X!`!D```"U3@$`$0```,].`0`*
M````X4X!`!@```#L3@$`$P````5/`0`<````&4\!`!$````V3P$`!````$A/
M`0`/````34\!``<```!=3P$`!````&5/`0`9````:D\!``<```"$3P$``@``
M`(Q/`0`"````CT\!`!$```"23P$`"0```*1/`0`&````KD\!`!(```"U3P$`
M%P```,A/`0`&````X$\!`"<```#G3P$``@````]0`0`$````$E`!``\````7
M4`$`$P```"=0`0`'````.U`!``<```!#4`$`$0```$M0`0`&````75`!`!@`
M``!D4`$`!@```'U0`0`3````A%`!`!````"84`$`$@```*E0`0`"````O%`!
M``8```"_4`$`#````,90`0`)````TU`!`!$```#=4`$`(@```.]0`0`'````
M$E$!``<````:40$`"P```")1`0`%````+E$!``(````T40$`"P```#=1`0!_
M`0``0U$!`!(```##4@$`&P```-92`0`0````\E(!``X````#4P$`"0```!)3
M`0`'````'%,!``,````D4P$`&P```"A3`0`A````1%,!`#4```!F4P$`,0``
M`)Q3`0`K````SE,!`"\```#Z4P$`'0```"I4`0`M````2%0!``L```!V5`$`
M,@```()4`0`4````M50!``L```#*5`$`$P```-94`0`%````ZE0!`#$```#P
M5`$`$````")5`0`1````,U4!`!X```!%50$`#P```&15`0`+````=%4!`)8`
M``"`50$`$@```!=6`0`*````*E8!``T````U5@$`#0```$-6`0`7````458!
M``P```!I5@$`$````'96`0`5````AU8!``<```"=5@$`G0```*56`0`,````
M0U<!``P```!05P$`%````%U7`0`2````<E<!`!````"%5P$`$````)97`0`)
M````IU<!``H```"Q5P$`1````+Q7`0`@`````5@!`#X````B6`$`30```&%8
M`0!N````KU@!`&H````>60$`=````(E9`0!P````_ED!`$$```!O6@$`#P``
M`+%:`0`5````P5H!``X```#76@$`$````.9:`0`8````]UH!``4````06P$`
M!@```!9;`0`7````'5L!``L````U6P$`"@```$%;`0`-````3%L!`#0```!:
M6P$`,````(];`0`4````P%L!`!8```#56P$`#@```.Q;`0`'````^UL!``<`
M```#7`$`%@````M<`0`D````(EP!``T```!'7`$`&0```%5<`0`?````;UP!
M`!\```"/7`$`)0```*]<`0`?````U5P!`!,```#U7`$`&P````E=`0`1````
M)5T!`"@````W70$`'@```&!=`0`?````?UT!`!8```"?70$`80```+9=`0`P
M````&%X!`#(```!)7@$`!P```'Q>`0`1````A%X!`$,```"67@$`#@```-I>
M`0`$````Z5X!``L```#N7@$`!P```/I>`0`'`````E\!``4````*7P$`!P``
M`!!?`0`,````&%\!``0````E7P$`(@```"I?`0`0````35\!`!8```!>7P$`
M$````'5?`0`L````AE\!`#$```"S7P$`"P```.5?`0`A````\5\!`!P````3
M8`$`(0```#!@`0`?````4F`!``X```!R8`$`$@```(%@`0`/````E&`!`"0`
M``"D8`$`(P```,E@`0`'````[6`!``8```#U8`$`"````/Q@`0`-````!6$!
M``<````380$`"P```!MA`0`2````)V$!``L````Z80$`%````$9A`0`7````
M6V$!`!L```!S80$`"````(]A`0`4````F&$!``4```"M80$`%````+-A`0`9
M````R&$!`!````#B80$`30```/-A`0!!````06(!``D```"#8@$`!P```(UB
M`0`4````E6(!``,```"J8@$`!0```*YB`0`/````M&(!``D```#$8@$`%0``
M`,YB`0!)````Y&(!`!,````N8P$`+@```$)C`0`U````<6,!`#<```"G8P$`
M,@```-]C`0`*````$F0!``0````=9`$`"0```")D`0`(````+&0!`#`````U
M9`$`-P```&9D`0`O````GF0!`%X```#.9`$`+P```"UE`0`O````764!`$L`
M``"-90$`3@```-EE`0`O````*&8!`%0```!89@$`-````*UF`0`W````XF8!
M`%<````:9P$`+P```')G`0`U````HF<!`"P```#89P$`&P````5H`0`>````
M(6@!`"X```!`:`$`*P```&]H`0`K````FV@!`!0```#':`$`"P```-QH`0`,
M````Z&@!``\```#U:`$`#P````5I`0`=````%6D!`"$````S:0$`!P```%5I
M`0`'````76D!`!,```!E:0$`"@```'EI`0`'````A&D!`"P```",:0$`#0``
M`+EI`0`'````QVD!``@```#/:0$`!@```-AI`0`%````WVD!``@```#E:0$`
M!P```.YI`0`,````]FD!`"H````#:@$`$P```"YJ`0`,````0FH!``0```!/
M:@$`!P```%1J`0`'````7&H!``<```!D:@$`&0```&QJ`0`%````AFH!`!(`
M``",:@$`"````)]J`0`(````J&H!``,```"Q:@$`!@```+5J`0`&````O&H!
M`"H```##:@$`$@```.YJ`0`(`````6L!``T````*:P$`#````!AK`0`'````
M)6L!`!(````M:P$``P```$!K`0!!````1&L!`!D```"&:P$`,````*!K`0`&
M````T6L!``4```#8:P$`"````-YK`0`(````YVL!`&0```#P:P$`*@```%5L
M`0`_````@&P!`"H```#`;`$`)@```.ML`0`&````$FT!``<````9;0$`'@``
M`"%M`0`J````0&T!`"X```!K;0$`-P```)IM`0`M````TFT!`#<`````;@$`
M;P```#AN`0`S````J&X!``@```#<;@$`!P```.5N`0`,````[6X!`!@```#Z
M;@$`"P```!-O`0`4````'V\!`!@````T;P$`(@```$UO`0`8````<&\!`!H`
M``");P$`%0```*1O`0`3````NF\!``<```#.;P$`&0```-9O`0`=````\&\!
M`!4````.<`$`&@```"1P`0`:````/W`!``4```!:<`$`"````&!P`0`;````
M:7`!`'(```"%<`$`>0```/AP`0`$````<G$!`!$```!W<0$`!0```(EQ`0`%
M````CW$!`!H```"5<0$`&P```+!Q`0`7````S'$!`!<```#D<0$`&P```/QQ
M`0`G````&'(!`#8```!`<@$`#@```'=R`0`J````AG(!``<```"Q<@$`'@``
M`+ER`0`2````V'(!`!D```#K<@$`%0````5S`0`D````&W,!`!\```!`<P$`
M%P```&!S`0`3````>',!`!$```",<P$`!@```)YS`0`/````I7,!``<```"U
M<P$`"@```+US`0`8````R',!`!$```#A<P$`"````/-S`0`'````_',!`!,`
M```$=`$`%P```!AT`0`&````,'0!`!$````W=`$`!````$ET`0`(````3G0!
M``X```!7=`$`"P```&9T`0`)````<G0!``<```!\=`$`!P```(1T`0`+````
MC'0!``D```"8=`$`"@```*)T`0`<````K70!`$D```#*=`$`(@```!1U`0`-
M````-W4!`!D```!%=0$`!0```%]U`0`@````974!`!4```"&=0$`&````)QU
M`0`M````M74!`#\```#C=0$`)````"-V`0`(````2'8!`#P```!1=@$`)P``
M`(YV`0`1````MG8!``H```#(=@$`"0```--V`0`/````W78!``8```#M=@$`
M%@```/1V`0`5````"W<!``@````A=P$`"@```"IW`0`-````-7<!`"0```!#
M=P$`)@```&AW`0`N````CW<!`"<```"^=P$`(````.9W`0`E````!W@!`"H`
M```M>`$`)@```%AX`0`T````?W@!`#````"T>`$`*P```.5X`0`L````$7D!
M`",````^>0$`,0```&)Y`0`V````E'D!`#8```#+>0$`*P````)Z`0`Q````
M+GH!`$$```!@>@$`*@```*)Z`0`I````S7H!`$,```#W>@$`*P```#M[`0`;
M````9WL!`#$```"#>P$`)P```+5[`0`G````W7L!`!H````%?`$`LP```"!\
M`0`?````U'P!`"H```#T?`$`+@```!]]`0`P````3GT!`"T```!_?0$`,@``
M`*U]`0`I````X'T!`"L````*?@$`.P```#9^`0`[````<GX!`$````"N?@$`
M0@```.]^`0"R````,G\!`"<```#E?P$`(0````V``0`E````+X`!`#(```!5
M@`$`.0```(B``0!&````PH`!`$\````)@0$`#````%F!`0`$````9H$!``4`
M``!K@0$`!0```'&!`0`-````=X$!`!````"%@0$`%0```):!`0`7````K($!
M`!D```#$@0$`!P```-Z!`0`$````YH$!`!(```#K@0$`$0```/Z!`0`.````
M$((!`!H````?@@$`%````#J"`0`6````3X(!`!4```!F@@$`#0```'R"`0`Y
M````BH(!``8```#$@@$`$P```,N"`0`&````WX(!`!,```#F@@$`&0```/J"
M`0`=````%(,!`!(````R@P$``@```$6#`0!)````2(,!``L```"2@P$`%@``
M`)Z#`0`0````M8,!``0```#&@P$`$0```,N#`0`4````W8,!``0```#R@P$`
M%0```/>#`0`(````#80!`!`````6A`$`%@```">$`0`&````/H0!`!(```!%
MA`$`$P```%B$`0`C````;(0!``L```"0A`$`!P```)R$`0`2````I(0!`!,`
M``"WA`$`$````,N$`0`8````W(0!`"````#UA`$`$@```!:%`0`2````*84!
M`"(````\A0$`%@```%^%`0`E````=H4!`$4```"<A0$`$0```.*%`0`A````
M](4!`!D````6A@$`&P```#"&`0`:````3(8!`#<```!GA@$`$@```)^&`0`(
M````LH8!`!,```"[A@$`"P```,^&`0`T````VX8!`#0````0AP$`#0```$6'
M`0`.````4X<!`"@```!BAP$`$0```(N'`0`2````G8<!`!(```"PAP$`"@``
M`,.'`0`8````SH<!`!,```#GAP$`'P```/N'`0`;````&X@!`!(````WB`$`
M$0```$J(`0`(````7(@!`!````!EB`$`+````':(`0!B````HX@!``D````&
MB0$`%@```!")`0`M````)XD!``L```!5B0$`#@```&&)`0`X````<(D!`!``
M``"IB0$`!P```+J)`0`5````PHD!`$D```#8B0$``P```"**`0`(````)HH!
M``@````OB@$`#@```#B*`0`0````1XH!`!4```!8B@$`%@```&Z*`0`B````
MA8H!`!D```"HB@$`(@```,**`0`>````Y8H!``D````$BP$`!@````Z+`0`(
M````%8L!``H````>BP$``@```"F+`0`4````+(L!`!0```!!BP$`,````%:+
M`0`:````AXL!`!D```"BBP$`"@```+R+`0`-````QXL!``X```#5BP$`&```
M`.2+`0!%````_8L!`"\```!#C`$`#@```'.,`0`2````@HP!`*````"5C`$`
M)@```#:-`0`?````78T!`!(```!]C0$`"````)"-`0`&````F8T!`"<```"@
MC0$`0````,B-`0!`````"8X!`"X```!*C@$`,@```'F.`0`7````K(X!`"H`
M``#$C@$`!P```.^.`0`(````]XX!``@`````CP$`!@````F/`0`9````$(\!
M`!0````JCP$`%@```#^/`0`4````5H\!`!(```!KCP$`&@```'Z/`0`2````
MF8\!`!0```"LCP$`"````,&/`0`*````RH\!`!@```#5CP$`#@```.Z/`0`S
M````_8\!`!$````QD`$`#````$.0`0`4````4)`!`#H```!ED`$`(P```*"0
M`0`F````Q)`!`"4```#KD`$`(````!&1`0`?````,I$!`"\```!2D0$`(0``
M`(*1`0`B````I)$!``0```#'D0$`&0```,R1`0`*````YI$!``\```#QD0$`
M`P````&2`0`*````!9(!``<````0D@$`%0```!B2`0`8````+I(!`!````!'
MD@$`&````%B2`0`2````<9(!``X```"$D@$`&@```).2`0`%````KI(!``<`
M``"TD@$`%P```+R2`0`7````U)(!`!@```#LD@$`#@````63`0`0````%),!
M`!D````EDP$`+0```#^3`0`'````;9,!``@```!UDP$`#@```'Z3`0`0````
MC9,!``X```">DP$`"0```*V3`0`(````MY,!``H```#`DP$`%@```,N3`0`1
M````XI,!``H```#TDP$`,0```/^3`0`/````,90!`(0```!!E`$`)0```,:4
M`0`+````[)0!``@```#XE`$`$`````&5`0`)````$I4!``L````<E0$`!@``
M`"B5`0`+````+Y4!``(````[E0$`!@```#Z5`0`&````194!`!4```!,E0$`
M$````&*5`0`3````<Y4!`"L```"'E0$``@```+.5`0`#````MI4!`!0```"Z
ME0$`"P```,^5`0`+````VY4!``4```#GE0$`&@```.V5`0`'````")8!``8`
M```0E@$`'@```!>6`0`+````-I8!``<```!"E@$`"0```$J6`0`%````5)8!
M``D```!:E@$`!@```&26`0`0````:Y8!``4```!\E@$`!@```(*6`0`-````
MB98!`!````"7E@$`#@```*B6`0`%````MY8!`!$```"]E@$`"0```,^6`0`'
M````V98!`!H```#AE@$`+````/R6`0!0````*9<!`#````!ZEP$`,0```*N7
M`0`'````W9<!``H```#EEP$`!````/"7`0`)````]9<!``D```#_EP$`%P``
M``F8`0`*````(9@!``8````LF`$`#0```#.8`0`&````09@!``0```!(F`$`
M1@```$V8`0!$````E)@!`$,```#9F`$`(@```!V9`0`%````0)D!`!4```!&
MF0$`"P```%R9`0`'````:)D!``@```!PF0$`%@```'F9`0`/````D)D!`!4`
M``"@F0$`!P```+:9`0`$````OID!`!,```##F0$`!````->9`0`*````W)D!
M`!L```#GF0$`!0````.:`0`(````"9H!``\````2F@$`!P```"*:`0`3````
M*IH!`!0````^F@$`$P```%.:`0`(````9YH!``D```!PF@$`!0```'J:`0!$
M````@)H!`#4```#%F@$`/@```/N:`0`L````.IL!`$L```!GFP$`10```+.;
M`0`Q````^9L!`%(````KG`$`-P```'Z<`0`Z````MIP!`"0```#QG`$`$0``
M`!:=`0`6````*)T!``P````_G0$`,P```$R=`0`K````@)T!`"<```"LG0$`
M*@```-2=`0`(````_YT!``L````(G@$`"@```!2>`0`'````'YX!`"\````G
MG@$`,@```%>>`0`Y````BIX!``H```#$G@$`&@```,^>`0`D````ZIX!`!@`
M```/GP$`%0```"B?`0`'````/I\!`!````!&GP$`#@```%>?`0`1````9I\!
M``\```!XGP$`30```(B?`0"+````UI\!`'<```!BH`$`$P```-J@`0`6````
M[J`!`!@````%H0$`$````!ZA`0`2````+Z$!`!<```!"H0$`!@```%JA`0`5
M````8:$!`!(```!WH0$`$0```(JA`0`5````G*$!`!@```"RH0$`-0```,NA
M`0!X`````:(!`!<```!ZH@$`!````)*B`0`8````EZ(!``D```"PH@$`!```
M`+JB`0`,````OZ(!`"0```#,H@$`%@```/&B`0`-````"*,!`!(````6HP$`
M$P```"FC`0`6````/:,!`#8```!4HP$`-@```(NC`0`T````PJ,!`#0```#W
MHP$`,````"RD`0`P````7:0!`!<```".I`$`5````*:D`0`5````^Z0!`!4`
M```1I0$`%0```">E`0`5````/:4!`!0```!3I0$`&````&BE`0`8````@:4!
M`!0```":I0$`%````*^E`0`P````Q*4!`!H```#UI0$`'````!"F`0`[````
M+:8!`!,```!II@$`!@```'VF`0`.````A*8!`!\```"3I@$`%````+.F`0`5
M````R*8!`!,```#>I@$`&P```/*F`0`@````#J<!`!L````OIP$`&0```$NG
M`0`=````9:<!`!0```"#IP$`'@```)BG`0`B````MZ<!`!0```#:IP$`&P``
M`.^G`0`9````"Z@!`!,````EJ`$`'@```#FH`0`9````6*@!`!@```!RJ`$`
M&````(NH`0`*````I*@!`!4```"OJ`$`!````,6H`0`$````RJ@!``<```#/
MJ`$`"@```->H`0`0````XJ@!``8```#SJ`$`"````/JH`0`(`````ZD!``8`
M```,J0$`"````!.I`0`'````'*D!``4````DJ0$`%@```"JI`0`&````0:D!
M``@```!(J0$`!P```%&I`0`$````6:D!``D```!>J0$`!P```&BI`0`)````
M<*D!`!````!ZJ0$`$````(NI`0`*````G*D!`!,```"GJ0$`!0```+NI`0`P
M````P:D!`!(```#RJ0$`$`````6J`0`4````%JH!`!,````KJ@$`#````#^J
M`0`6````3*H!`#8```!CJ@$`!P```)JJ`0`(````HJH!``T```"KJ@$`#```
M`+FJ`0`/````QJH!``8```#6J@$`#````-VJ`0`-````ZJH!``8```#XJ@$`
M!````/^J`0`.````!*L!`"4````3JP$`$````#FK`0`6````2JL!`!<```!A
MJP$`)@```'FK`0`;````H*L!``@```"\JP$``P```,6K`0`,````R:L!`"D`
M``#6JP$`!0````"L`0`&````!JP!``T````-K`$`$0```!NL`0`'````+:P!
M``8````UK`$`!P```#RL`0`%````1*P!``T```!*K`$`#0```%BL`0`,````
M9JP!`"````!SK`$`$0```)2L`0`/````IJP!`!H```"VK`$`$P```-&L`0`6
M````Y:P!``4```#\K`$`!`````*M`0`5````!ZT!`$P````=K0$`!0```&JM
M`0`-````<*T!`"@```!^K0$`&@```*>M`0`/````PJT!`!,```#2K0$`%```
M`.:M`0`0````^ZT!``\````,K@$`&````!RN`0`0````-:X!`!4```!&K@$`
M&0```%RN`0`C````=JX!`"<```":K@$`-P```,*N`0`+````^JX!``@````&
MKP$`#0````^O`0`/````':\!``\````MKP$`!````#VO`0`)````0J\!`"\`
M``!,KP$`"P```'RO`0`)````B*\!`!,```"2KP$`:P```*:O`0`3````$K`!
M``H````FL`$`!0```#&P`0`&````-[`!`!H````^L`$`&0```%FP`0`9````
M<[`!``H```"-L`$``@```)BP`0`6````F[`!`#,```"RL`$``P```.:P`0`%
M````ZK`!`!<```#PL`$`"@````BQ`0`%````$[$!``@````9L0$`&@```"*Q
M`0`.````/;$!``8```!,L0$`"````%.Q`0`(````7+$!``0```!EL0$`!0``
M`&JQ`0!*````<+$!``\```"[L0$`$@```,NQ`0`=````WK$!``0```#\L0$`
M!0````&R`0`E````![(!`#D````ML@$`#0```&>R`0`*````=;(!`!$```"`
ML@$`"@```)*R`0`+````G;(!`!8```"IL@$`&P```,"R`0`O````W+(!`"X`
M```,LP$`(@```#NS`0`0````7K,!``,```!OLP$`!P```'.S`0`*````>[,!
M``<```"&LP$`#@```(ZS`0`6````G;,!``<```"TLP$`6@```+RS`0`/````
M%[0!``\````GM`$`"P```#>T`0`G````0[0!`%T```!KM`$`&P```,FT`0`'
M````Y;0!`",```#MM`$`*0```!&U`0`(````.[4!``<```!$M0$`&P```$RU
M`0`&````:+4!``D```!OM0$`+@```'FU`0`M````J+4!`#<```#6M0$`!@``
M``ZV`0`&````%;8!`"P````<M@$`9@```$FV`0`7````L+8!`"0```#(M@$`
M%P```.VV`0`"````!;<!`!$````(MP$`!@```!JW`0`4````(;<!``X````V
MMP$`!@```$6W`0`(````3+<!``8```!5MP$`"````%RW`0`-````9;<!``T`
M``!SMP$`"@```(&W`0`1````C+<!`#L```">MP$`!0```-JW`0`7````X+<!
M`!0```#XMP$`(0````VX`0`7````+[@!``L```!'N`$`$0```%.X`0`1````
M9;@!``P```!WN`$`"P```(2X`0`,````D+@!``H```"=N`$`(````*BX`0`5
M````R;@!`!(```#?N`$`%0```/*X`0`8````"+D!``L````AN0$`&P```"VY
M`0`(````2;D!`!4```!2N0$``P```&BY`0`'````;+D!``4```!TN0$`!0``
M`'JY`0`(````@+D!`!8```")N0$`%P```*"Y`0`D````N+D!`",```#=N0$`
M'@````&Z`0`:````(+H!`!L````[N@$`(@```%>Z`0`;````>KH!``8```"6
MN@$`!@```)VZ`0`2````I+H!`!(```"WN@$`#0```,JZ`0`E````V+H!`!``
M``#^N@$`%`````^[`0`G````)+L!`"4```!,NP$`&0```'*[`0`)````C+L!
M``8```"6NP$`!P```)V[`0`2````I;L!`!$```"XNP$`"````,J[`0`)````
MT[L!``4```#=NP$`!P```..[`0`$````Z[L!``0```#PNP$``P```/6[`0!(
M````^;L!`#8```!"O`$`)0```'F\`0`J````G[P!`$$```#*O`$`#`````R]
M`0!`````&;T!`#8```!:O0$`.0```)&]`0`Y````R[T!`#X````%O@$`&```
M`$2^`0`;````7;X!`!0```!YO@$`$P```(Z^`0`<````HKX!`"````"_O@$`
M%````."^`0`3````];X!`!8````)OP$`&@```""_`0`[````.[\!`#L```!W
MOP$`/P```+._`0`T````\[\!`#L````HP`$`.````&3``0![````G<`!`!X`
M```9P0$`&````#C!`0`-````4<$!`!H```!?P0$`#````'K!`0`2````A\$!
M`#@```":P0$`,P```-/!`0`J````!\(!``T````RP@$`4P```$#"`0!,````
ME,(!``4```#AP@$`'@```.?"`0`6````!L,!``L````=PP$`#P```"G#`0`6
M````.<,!``<```!0PP$`"0```%C#`0`)````8L,!``X```!LPP$`#P```'O#
M`0`'````B\,!`!,```"3PP$`!0```*?#`0`F````K<,!``@```#4PP$`!@``
M`-W#`0`4````Y,,!`!(```#YPP$`$0````S$`0!$````'L0!``(```!CQ`$`
M!0```&;$`0`0````;,0!``4```!]Q`$`!P```(/$`0`5````B\0!``8```"A
MQ`$`/0```*C$`0`3````YL0!`",```#ZQ`$`!````![%`0`X````(\4!`"8`
M``!<Q0$`)@```(/%`0!=````JL4!`"`````(Q@$`30```"G&`0`J````=\8!
M`!8```"BQ@$`!P```+G&`0`/````P<8!``\```#1Q@$`#````.'&`0`7````
M[L8!``P````&QP$`'0```!/'`0`;````,<<!``4```!-QP$`$P```%/'`0`;
M````9\<!`"P```"#QP$`$0```+#'`0`7````PL<!`!4```#:QP$`$0```/#'
M`0`=`````L@!``@````@R`$`$````"G(`0`9````.L@!`!(```!4R`$`%```
M`&?(`0`2````?,@!`!P```"/R`$`$P```*S(`0`3````P,@!`!<```#4R`$`
M$0```.S(`0`+````_L@!``@````*R0$`!0```!/)`0`=````&<D!``8````W
MR0$`&0```#[)`0`(````6,D!`!4```!AR0$`#````'?)`0`D````A,D!`!8`
M``"IR0$`,P```,#)`0`>````],D!``X````3R@$`#P```"+*`0`J````,LH!
M``8```!=R@$`'P```&3*`0`&````A,H!`!H```"+R@$`"0```*;*`0`+````
ML,H!`"<```"\R@$`.````.3*`0`*````'<L!`"D````HRP$`$@```%++`0`+
M````9<L!`!X```!QRP$`%````)#+`0`%````I<L!``<```"KRP$`"P```+/+
M`0`)````O\L!``8```#)RP$`"````-#+`0`&````V<L!``H```#@RP$`'```
M`.O+`0`M````",P!`#$````VS`$`)0```&C,`0`S````CLP!`"8```#"S`$`
M1P```.G,`0`A````,<T!`"<```!3S0$`/@```'O-`0!<````NLT!`#`````7
MS@$`!P```$C.`0`)````4,X!``@```!:S@$`"````&/.`0`7````;,X!`!8`
M``"$S@$`+````)O.`0`N````R,X!`!D```#WS@$`,````!'/`0`Z````0L\!
M``@```!]SP$`'P```(;/`0`+````IL\!``8```"RSP$`*P```+G/`0`3````
MY<\!`!0```#YSP$`"P````[0`0`(````&M`!`!<````CT`$`!P```#O0`0`+
M````0]`!``T```!/T`$`&P```%W0`0`A````>=`!`#P```";T`$`"@```-C0
M`0`3````X]`!``4```#WT`$`!P```/W0`0`%````!=$!`!L````+T0$`#P``
M`"?1`0`%````-]$!`!(````]T0$`&@```%#1`0`'````:]$!``X```!ST0$`
M$````(+1`0`3````D]$!``0```"GT0$`!````*S1`0`,````L=$!`!X```"^
MT0$`6@```-W1`0`?````.-(!``H```!8T@$`*P```&/2`0`@````C](!`!8`
M``"PT@$`%@```,?2`0`)````WM(!``D```#HT@$`$0```/+2`0`N````!-,!
M``<````STP$`#P```#O3`0`2````2],!`!0```!>TP$`$````'/3`0!!````
MA-,!``H```#&TP$`'````-'3`0`5````[M,!`!H````$U`$`.0```!_4`0`C
M````6=0!`$P```!]U`$`4````,K4`0!)````&]4!`!$```!EU0$``P```'?5
M`0`=````>]4!`"(```"9U0$`'0```+S5`0`)````VM4!`!,```#DU0$`(0``
M`/C5`0`'````&M8!`"4````BU@$`'@```$C6`0`*````9]8!``8```!RU@$`
M$````'G6`0`1````BM8!`!P```"<U@$`!````+G6`0`(````OM8!``L```#'
MU@$`$````-/6`0`0````Y-8!`!<```#UU@$`%P````W7`0`)````)=<!``8`
M```OUP$`0````#;7`0`T````=]<!`#,```"LUP$`!@```.#7`0`&````Y]<!
M``8```#NUP$`'0```/77`0`6````$]@!`"P````JV`$`#@```%?8`0`0````
M9M@!`"0```!WV`$``P```)S8`0`&````H-@!`!$```"GV`$``@```+G8`0`-
M````O-@!`!H```#*V`$`#````.78`0`8````\M@!`!\````+V0$`$@```"O9
M`0`2````/MD!``L```!1V0$`%````%W9`0`5````<MD!``\```"(V0$`"P``
M`)C9`0`2````I-D!``X```"WV0$`%P```,;9`0!H````WMD!`"(```!'V@$`
M/P```&K:`0`-````JMH!``<```"XV@$`"0```,#:`0`4````RMH!`!<```#?
MV@$`%0```/?:`0`@````#=L!`"0````NVP$`%P```%/;`0`E````:]L!`!$`
M``"1VP$`+P```*/;`0`3````T]L!`!4```#GVP$`D````/W;`0`D````CMP!
M`"````"SW`$`,0```-3<`0`D````!MT!`",````KW0$`)````$_=`0`E````
M=-T!`"0```":W0$`'0```+_=`0`+````W=T!``<```#IW0$`"````/'=`0`)
M````^MT!`!0````$W@$`#P```!G>`0`W````*=X!`!L```!AW@$`%@```'W>
M`0`(````E-X!``P```"=W@$`:@```*K>`0!"````%=\!`$H```!8WP$`@```
M`*/?`0`-````).`!`#$````RX`$`,0```&3@`0`*````EN`!``4```"AX`$`
M!@```*?@`0!%````KN`!``@```#TX`$`9@```/W@`0`U````9.$!`"@```":
MX0$`%````,/A`0`G````V.$!`!X`````X@$`+0```!_B`0`W````3>(!`$0`
M``"%X@$`-P```,KB`0`;`````N,!``<````>XP$`&P```";C`0`7````0N,!
M`!4```!:XP$`"0```'#C`0`T````>N,!``P```"OXP$`"@```+SC`0`)````
MQ^,!`!<```#1XP$`"0```.GC`0`&````\^,!`!8```#ZXP$`"0```!'D`0`(
M````&^0!``4````DY`$`#P```"KD`0`0````.N0!`"0```!+Y`$`(````'#D
M`0`3````D>0!`#0```"EY`$`#````-KD`0`'````Y^0!`!(```#OY`$`&P``
M``+E`0`.````'N4!``X````MY0$`&0```#SE`0`F````5N4!``X```!]Y0$`
M(````(SE`0`V````K>4!``@```#DY0$`"@```.WE`0`9````^.4!``<````2
MY@$`"````!KF`0`3````(^8!`!(````WY@$`$@```$KF`0`1````7>8!``8`
M``!OY@$`"0```';F`0`(````@.8!``D```")Y@$`#@```)/F`0`0````HN8!
M``8```"SY@$`%````+KF`0`#````S^8!``4```#3Y@$`$````-GF`0`?````
MZN8!``L````*YP$``@```!;G`0`A````&><!``4````[YP$`!0```$'G`0!R
M````1^<!``8```"ZYP$`!@```,'G`0`<````R.<!`$8```#EYP$`'@```"SH
M`0`<````2^@!`%L```!HZ`$`.P```,3H`0!/`````.D!`"````!0Z0$`%0``
M`''I`0`&````A^D!``@```".Z0$`#P```)?I`0`1````I^D!``H```"YZ0$`
M#P```,3I`0`7````U.D!`!$```#LZ0$`$0```/[I`0`4````$.H!``@````E
MZ@$`"@```"[J`0`=````.>H!``X```!7Z@$`&@```&;J`0`)````@>H!``4`
M``"+Z@$`!@```)'J`0`C````F.H!``8```"\Z@$`+@```,/J`0`%````\NH!
M``8```#XZ@$`#0```/_J`0`&````#>L!``\````4ZP$`"P```"3K`0`5````
M,.L!`!(```!&ZP$`%0```%GK`0`&````;^L!`!D```!VZP$`"@```)#K`0`(
M````F^L!``<```"DZP$`!@```*SK`0`3````L^L!`"4```#'ZP$`"P```.WK
M`0`.````^>L!`"@````([`$`&````#'L`0`:````2NP!``4```!E[`$`"@``
M`&OL`0`3````=NP!``T```"*[`$``@```)CL`0`.````F^P!``D```"J[`$`
M)0```+3L`0`?````VNP!`#H```#Z[`$`*P```#7M`0`X````8>T!`"P```":
M[0$`9P```,?M`0`;````+^X!`&````!+[@$`.````*SN`0!*````Y>X!`%D`
M```P[P$`+P```(KO`0`Q````NN\!`"L```#L[P$`,0```!CP`0`O````2O`!
M`"8```!Z\`$`/0```*'P`0`B`@``W_`!`",````"\P$`&````";S`0!*````
M/_,!`($```"*\P$`,P````ST`0`O````0/0!`$````!P]`$`6@```+'T`0!0
M````#/4!`#D```!=]0$`(P```)?U`0`7````N_4!`"P```#3]0$`(0````#V
M`0`C````(O8!`#,```!&]@$`)````'KV`0`J````G_8!`#8```#*]@$`&P``
M``'W`0`1````'?<!`%0````O]P$`*P```(3W`0`M````L/<!`"<```#>]P$`
M(@````;X`0`M````*?@!`%D```!7^`$`-0```+'X`0!4````Y_@!`#H````\
M^0$`/````'?Y`0!.````M/D!`&\````#^@$`6````'/Z`0!'````S/H!`$H`
M```4^P$`20```%_[`0!K````J?L!`'4````5_`$`:0```(O\`0!F````]?P!
M`#\```!<_0$`+0```)S]`0`L````ROT!`#````#W_0$`=P```"C^`0!F````
MH/X!`'4````'_P$`P````'W_`0`9````/@`"`"H```!8``(`/0```(,``@`R
M````P0`"`%(```#T``(`)````$<!`@!;````;`$"`"````#(`0(`"0```.D!
M`@"]````\P$"`$H```"Q`@(`(P```/P"`@`]````(`,"`"8```!>`P(`(0``
M`(4#`@`^````IP,"``@```#F`P(`!P```.\#`@`%````]P,"``T```#]`P(`
M#@````L$`@`4````&@0"``X````O!`(`!0```#X$`@`3````1`0"``$```!8
M!`(`>0```%H$`@`+````U`0"`!,```#@!`(`!````/0$`@`'````^00"``8`
M```!!0(`!0````@%`@`\````#@4"``0```!+!0(`%````%`%`@`+````904"
M`!$```!Q!0(`#````(,%`@`"````D`4"``<```"3!0(`!P```)L%`@`1````
MHP4"``P```"U!0(`%P```,(%`@`&````V@4"`!4```#A!0(`#````/<%`@`#
M````!`8"`"T````(!@(`!````#8&`@`'````.P8"``<```!#!@(`*0```$L&
M`@!&````=08"`$(```"\!@(`00```/\&`@`>````00<"`#8```!@!P(`.0``
M`)<'`@`D````T0<"`!L```#V!P(`)````!((`@`M````-P@"`"8```!E"`(`
M(P```(P(`@`M````L`@"`"D```#>"`(`+@````@)`@`\````-PD"`"8```!T
M"0(`-P```)L)`@`P````TPD"`"D````$"@(`+P```"X*`@`M````7@H"`"8`
M``","@(`,````+,*`@`J````Y`H"`"P````/"P(`+P```#P+`@`J````;`L"
M`"8```"7"P(`*@```+X+`@`O````Z0L"`",````9#`(`+0```#T,`@`X````
M:PP"`#L```"D#`(`(````.`,`@`L`````0T"`#X````N#0(`*0```&T-`@`N
M````EPT"`"T```#&#0(`+````/0-`@`F````(0X"`"````!(#@(`*````&D.
M`@`J````D@X"`$,```"]#@(`+P````$/`@`\````,0\"``D```!N#P(`%P``
M`'@/`@`<````D`\"`#4```"M#P(`(@```.,/`@`.````!A`"``\````5$`(`
M$P```"40`@`+````.1`"``H```!%$`(`'P```%`0`@`&````<!`"``<```!W
M$`(`(@```'\0`@`E````HA`"`"````#($`(`*@```.D0`@`8````%!$"``@`
M```M$0(`^````#81`@`:````+Q("`!T```!*$@(`"````&@2`@`+````<1("
M`!8```!]$@(`%@```)02`@`E````JQ("``<```#1$@(`4P```-D2`@`:````
M+1,"`!H```!($P(`!P```&,3`@`9````:Q,"``P```"%$P(`3````)(3`@`+
M````WQ,"`#````#K$P(`'P```!P4`@`8````/!0"`!\```!5%`(`/````'44
M`@`=````LA0"`!$```#0%`(`)P```.(4`@`3````"A4"`!0````>%0(`%@``
M`#,5`@`+````2A4"`!H```!6%0(`"````'$5`@`L````>A4"``@```"G%0(`
M*0```+`5`@`O````VA4"``<````*%@(`&0```!(6`@`'````+!8"``@````T
M%@(`"0```#T6`@!%````1Q8"``<```"-%@(`$P```)46`@`3````J18"`!0`
M``"]%@(`"@```-(6`@`*````W18"``<```#H%@(`%````/`6`@`'````!1<"
M`!D````-%P(`#0```"<7`@`9````-1<"`!L```!/%P(`"@```&L7`@`-````
M=A<"`!<```"$%P(`!@```)P7`@`T````HQ<"``P```#8%P(`$````.47`@`)
M````]A<"``(`````&`(`$`````,8`@`:````%!@"``L````O&`(``P```#L8
M`@`(````/Q@"``X```!(&`(`"0```%<8`@`.````81@"``T```!P&`(`%P``
M`'X8`@`8````EA@"`!$```"O&`(`/````,$8`@`E````_A@"`",````D&0(`
M%P```$@9`@`.````8!D"`#0```!O&0(`!P```*09`@`5````K!D"`%D```#"
M&0(`$@```!P:`@`0````+QH"``D```!`&@(`!````$H:`@`$````3QH"`!$`
M``!4&@(`'@```&8:`@`&````A1H"``<```",&@(`!P```)0:`@`3````G!H"
M``<```"P&@(`%P```+@:`@`7````T!H"`$(```#H&@(`-````"L;`@`X````
M8!L"``4```"9&P(`&P```)\;`@`A````NQL"`!D```#=&P(`(@```/<;`@`1
M````&AP"``(````L'`(`!````"\<`@`1````-!P"``P```!&'`(`!0```%,<
M`@`#````61P"``X```!='`(`5@```&P<`@`R````PQP"`!P```#V'`(`00``
M`!,=`@`V````51T"`%@```",'0(`&0```.4=`@![````_QT"`"@```!['@(`
M2````*0>`@`D````[1X"`$<````2'P(`+````%H?`@`L````AQ\"`"\```"T
M'P(`+@```.0?`@`N````$R`"`#@```!"(`(`+````'L@`@`T````J"`"`"T`
M``#=(`(`-0````LA`@`9````02$"`",```!;(0(`&````'\A`@!Z````F"$"
M``D````3(@(`RP```!TB`@"0````Z2("`'P```!Z(P(`+0```/<C`@!N````
M)20"`!T```"4)`(`)@```+(D`@`3````V20"`!,```#M)`(`%@````$E`@`J
M````&"4"`$````!#)0(`(0```(0E`@`E````IB4"`'$```#,)0(`'````#XF
M`@`7````6R8"``L```!S)@(`!0```'\F`@`&````A28"``@```",)@(`!0``
M`)4F`@`6````FR8"`!4```"R)@(`&0```,@F`@`D````XB8"`!`````')P(`
M#P```!@G`@`2````*"<"``D````[)P(`%````$4G`@`(````6B<"``4```!C
M)P(`&0```&DG`@`*````@R<"``P```".)P(`&````)LG`@`(````M"<"``P`
M``"])P(`$````,HG`@`.````VR<"`!8```#J)P(`#0````$H`@`1````#R@"
M`!0````A*`(`!@```#8H`@`%````/2@"`"@```!#*`(`'````&PH`@`+````
MB2@"`"P```"5*`(`%P```,(H`@`E````VB@"`!H`````*0(`"````!LI`@`1
M````)"D"``<````V*0(`!P```#XI`@`9````1BD"``D```!@*0(``P```&HI
M`@`"````;BD"`!(```!Q*0(`#0```(0I`@`*````DBD"`!8```"=*0(`&0``
M`+0I`@`'````SBD"`"8```#6*0(``@```/TI`@`#`````"H"`!(````$*@(`
M&0```!<J`@`*````,2H"``L````\*@(`$@```$@J`@`&````6RH"`"$```!B
M*@(`"0```(0J`@`7````CBH"`!<```"F*@(`$@```+XJ`@`"````T2H"``0`
M``#4*@(`#@```-DJ`@`/````Z"H"`!````#X*@(`+P````DK`@`&````.2L"
M``@```!`*P(`%P```$DK`@`%````82L"``,```!G*P(`"P```&LK`@`!````
MTP0``!P$```Q!0``7P,```````"<`0``;0(``*`$````````E`,``,<!``#[
M!@``?```````````````A@(``"D'```+`0```````($'``#!````=P4``!4$
M``#P!0``+````-L#``#!!@``(P<```@"```!!```O`4```('```Q`P``````
M`*8"``#O!0``9`(``+("```/!```@0,```````````````````````#6!```
M404``(4$`````````````/8!``!P`@````````````!_`@``+@0````````C
M`0``I`4```````!B!P``XP4``(\&```E`0``<`8``/4$``!N`@``<`$``#,'
M``#"`0``T0(``"\$``!O`P``3@<``%H```"B`0``,P$``(D'````````>P$`
M`.L```"6!@``P`4``%P'``!*!0``S`8```````"4!```8@(``/(````I`@``
M9@(```````#;!```A`8``-T%`````````````*4```````````````````"8
M`P```````$````#D!@```````,T!````````G00``$@"``"_!0```````/T"
M``"(!P````````P%````````3P0``,L%``#L`@``)@4``!<`````````-```
M`%@```"\`0````````````"U`@``6@0``&4#``!J`P``7P$``(('````````
M``````````#Z`0``9`,``&\```#6`0```````'T&````````"`<``)``````
M````30,``)L"````````'`,``%T&``#T`0``WP```"@#``#<`0``T`$``+8#
M``!'`P```````!L'```1!P``)0,``/$```"P!0``T@0`````````````JP,`
M`*0`````````R@4``&$#``!Y`P``E00```H$````````B@8``,`!````````
MX00``'@'``#9`P``YP$```````#^!0``2@<``*D!``!8!```Y`$```````!/
M````O@$``````````````````"\#``!L!P```````+(`````````F`4``&<$
M``"D!@``X@$``$8&````````*@```/L!``!H`0``5`<``-H#```H!@``HP0`
M`%0&``!6!```KP8```````"=`@``6P```)(&``"+`P``J0````````"L!0``
MTP```*`#``!Z`0``9P(``,(#```H!P``>P,``"L`````````-@``````````
M````,0(``(,```#D!````````/8$``!Y!```1`<```````#W````````````
M``"3`@``N@4````````7!0``J@,``"L"``!Z!P```````'0$```[`@``````
M``````"0`@``C@$``(H$``#<````?`<``%<%``":`P```P(``#L'``!>`P``
M!@$```````!%!````````"T'``"?`P``I0$`````````````9P4``'$!````
M`````````$(&``#;````/0<``$H``````````@(````````I`0```````%8#
M````````G`0```````#,`0``800``!8#````````)P0``&$`````````````
M`"4$``!W````[@,``&8&````````G`8``/\%``![`````````!@&``"Q!```
M`P````,'``#<!0``MP8``,D#``!\`@``%@<``.P``````````````&,!````
M````[@(``)H```"2````G@,```````";`0``*P4``'$"``#S`P``1@,``+X"
M``"Z`0``W00``-8&``"T`P``XP0``,H$``"J!````````!@'```7`@``OP0`
M`!@!``"Q`@````````````#B`P``CP(```````!^`0``_04``&D!```6!@``
M^`$``"H#``!+`P``<@,``$<$``"6`0``1P```,@!``!Q`P``3@8``#H```!@
M!@``4P```-4&``!V`@```````"X%```F`@``<P8``.T````*!@``!````.0"
M``!^`P``@P4``(D!``"3!```_@(``&0'``#F!0``%P$```````"?`0``#0<`
M`'L"``!^````!00```D'```M!@``-`8```````!2`@``OP````````!W`P``
M_P,````````+````,P4`````````````9@<``"<&``#=`````````/0"```_
M!P```````-@#``#:!`````````````!H````#0(``'(&````````TP8``,4&
M``!Q````H````/P&``!"`@```````)L$``"Y`P``P`````0$```.!@``3`$`
M`)0"``"Y!0``H`$``,$!````````!0````````!,!P``U@(``&,`````````
MQ````````````````````/($````````0`4``&\'````````S08````````7
M`P``@08`````````````4@4`````````````\P0``'<$``"C!@``;P0```@`
M``!>````2`<``+H#``!V!0``W@```(0#```D!```.P4``/<&``"<`P``=P(`
M``````!J`0``/@(``+X&``#M!0``O@0```````!O!@```````(D```"E`@``
M`````#,&````````'`<```````!5`0``(@0``#@!````````;00```````"'
M`@``>04``(`%``#6`````````"$"``!/!@``-P0``#,"`````````````)<#
M``#_!`````<```<#``!I!@```````/$!``#&````\`,``(\```!;!P``````
M``````#G!@``A0,`````````````W0(``"X#``!7`0``]`8```````#E`0``
M_@```$T```#-!```$`4````````V`0``D`,``'T!``"7````600``'\$``!S
M````IP4``%@"``""`@```````$$&``!V`0``_@$```````#G!````````"0`
M````````^`0``&L$``#&!```60$``"$$```&````GP(``%X"````````````
M``,&``"4!0```````.$&``".`P``/@```"L!```4`@``UP,``)$&``!`!P``
M`````&P#````````C@0``*,`````````Q0,``%$```"]`@``+`0``"`$``#I
M!````````"P&``#V`@``+@8``%@%``````````````````"I`@``)`,`````
M````````LP$```````!]````)P,```````!R!P```````)$$````````S@$`
M`/`&```(`0````````````````````$``$P%```X!@```````,@%```1`0``
M7P0``/H#``"<````L`,``,0!````````=00``'$$``#7`@``R04``'P!``",
M`0``````````````````_`4``#4$````````/@<``*4&``#0`P``J`8``.T!
M``"F`````````.\"``````````````````"M!```ZP$``/D$``#?`P``*`0`
M``````!F!```GP````\&``"Y!```Z@,```````#)!```6P(``(P$````````
MQ`(``+X%``!"!0``=`<``-4%``"3!@```````&,'`````````````!L$````
M````]`,``%0```#9`````````$@```"6`````````%8"```W````'P8``#P"
M``!S`@```````/,"````````"`0``+<"``"E!```=P<```````#:!@``%0``
M``````#9!````````/P`````````'P4``(L%``#W`0``]@4``'P#``#8!@``
MM`4``)4%```#!0```````````````````````(,$``"_`@``S@(```P'``"9
M`P``_P(```````#T!```/P(``%,!````````Q00``#(!````````RP(``(P`
M`````````````$L!`````````````+H&```)`0``W@$``"8$``"D`P``S`4`
M`',!```S!```$`8``(L$``!B`````````"\```"@!@``.`(``%D"``!_!P``
M1P<``(T%```9`````````*T```#O`P``T08``'P%```R````O04``,H"````
M````]@8``+8&``!;!0``1`$`````````````'0(``!X'``#;!@````````X%
M````````8`$``#D"``!#`@``NP$``(`#````````*@$``$8```#0`@``$P8`
M``````!_````0@,``#4'```M`0``,00``.$!````````T04``+0"``#H`0``
M5`,``/@#``!]!````````*(#``#4`@``8@,``.H%`````````````%\````?
M`@``,@,``/P"````````<P0```````"`!@``-P4``#H%```8!````````'8`
M``"C`P```````)<%``!B!0``$@(``&P!```B`0```````(X`````````:@4`
M``````#%!0``&@$``.`!````````DP,``)@`````````A04``!@`````````
M+`4``(8$````````'````)D&``!H!@``^P(``(4!````````3`,``&@'``!Z
M!```$`0``&4```!4!0``Q`8``'0"``#@``````````````"W`P``=0,`````
M````````````````````````7`$````````X!P``?@(``&P`````````````
M`(@"````````S@8```L"```/!0``;0$``"T"``#?!0``YP(``$\#```-`0``
M8````&<`````````OP8``-D"``"Y!@``````````````````Z@```+($```H
M`````````"\'````````\P```*H%``#]`0``U00``!H`````````````````
M``!B!````````,@&``!?!@``3@`````````3`@````````````!*!```%08`
M`",````_````@@4``*@$``"X`@``D04``.0```!"!````````+@%``!!!0``
M'P$``+@!````````FP4```````"U`````0<``"L'`````````````+`$````
M````:0<``'L%``!F````````````````````S@0```<!``!7!@``````````
M``#?!@``8`<``#L!```[!```=0(``.L&```Y!```'P<``/T&``!Q!@``#`$`
M``````!'!@``G08``+P$``!E!@``"04``$4'``````````````````!S`P``
MBP```'D'``#2`P```0(``*,!```L`P```````+,$````````)`<```$#``#K
M`@``<````&T&``#8````$08``$4#``!=!P``\@4``.@&``#1!```/P,`````
M``#Z!0``90<``)\&``#2`@```````&L!``#1````B08``#````#(`@``H00`
M`.P!``#B````:@(``*8!``!<`@```````#@#````````6P8``"L$``!@`P``
MX`4```````#/````E@4``-<&``!%`@````````````"5`0`````````````&
M!@``1@4``/X&````````20,``&P%``!3!P``TP$``(`!````````````````
M`````````````/T$``!L!```!@0``#X#```?!```WP0```````!<`P``?@0`
M`!$"```K!@``RP0``!L#````````?@8``'4````%`P``D0$```````"L````
M``````0"``!Y`0``*00``#0'````````>@```'0``````````````&(!``!4
M`0``#0```#\!``#>`P``M`8``#<'`````````````"8`````````````````
M``"(!0``CP0```````!&!`````8```````"S````4`$``)`&``"R`0``%@(`
M`%`"``"'`P``;@<``/4"``"V````\@8``/$#``!1`0``X@0``.\$````````
MSP8````````O`@````````L'``!0`````````%0"````````2P8``($"````
M````&P8```````#S!@``BP8``+L```!<!@```````/D!``"$````108`````
M``!U`0````````````!$`@``2`$``!4#````````)`$``%D#``#U````F@4`
M`%,%``#<!@``.0$``!D'````````B`$``%P%``!7!```00<``)H"```]`P``
M$0,``*X%``!)`0```````)\$````````/@$``&H```!^!0``IP,``*<&```@
M`````````*X```!+````$@```*8$```!`0``>`8```````#5`0``N@```.0#
M``"V`0````````````!H!`````````````"^````N0```'($````````$0``
M`%\%``#F!```(`,``*L!``#F````(@(``)X&``"]`0``\@$``#D&``""!@``
M`````($````2!```NP(``#T$``!_`0``&P```+,"````````O0,``'4%``!E
M`@``A0````````#-`@``PP8``'\%````````5P(``)\%``#P`0``K0,`````
M``"*!0``<@$``+$```"!!````````.\&````````$`<``&\"````````[0,`
M```````0`@``%`$``"T#``!$!````````-4#``#?`@```````'L&``!)!0``
M`````-H%``"'!````````+$&``#W`@``KP0```4"````````(0```/L%``!W
M`0``/`,```D&``#S!0``\`(``'$%``"X`P```````-0#``#H`@``6`8`````
M``![!```00,````````J`@``G`4``,8%``#9!0``804`````````````_P8`
M`'H%``!'`@``/````+P```````````````\#``````````````\'```V!@``
M%`0`````````````80(```<'```S`P```````$`!```]!0```````)H&````
M`````````(<!``#)````Z0,``.,&``"]````BP$``+T$````````-@,``#4"
M```=!0```````(8&``"N!```!P(``.L$``"_`P``````````````````200`
M`%`&``"U!```<P4``,0#````````:P,``-H!``"P`0```````),%````````
MR08``*(%````````"0,``'T#```3````#00``,4!```+!````````$$"``!5
M````X@4```````"L`P```P,``!D$```%!@````````````#J!```ZP4```H#
M``"H!0``MP0``!8```!4!```-P$``%4%``"D`@``^0(```````"``@``(P4`
M`/L#``!#`0``:@0`````````````/P4``!,!````````\@,``,<$``"]!@``
M`````$@#````````S0,``%T%``!\!```/`8``/D````>!0``1@$```````"K
M````5@$``.@$``"-`````````,X#```W!@````````````#+````AP```-T#
M`````````````,P$````````40<````````9!0```````.<#```Q````S`,`
M`(D%```0`0``#@```&H'``"G````SP0``&$'```7!@``V@```"$!``"B`@``
MF`(``%X$```M!```(@<``&4!``!X`@``$P<``!T$``#8!0``G`(``%T`````
M````X`0``&8%```^!@``Y@(```````"R!0````````0#```>!```````````
M````````!`4```````"3`0``A08``'0#``"O`P``^08```````"2!```A0(`
M`!T&````````W`,```````!;`0``6@<``!0#``#Q`@``,@<``'0%``"H`P``
M70$``"H&``````````````````"N!@``X`,``$X#``#\!```.0<``'@$````
M````+P4``&<&``#4````H`(``/D#````````*`4``(4'``#L!0``<@(`````
M```I``````````8"````````"@<``.4$````````408`````````````)@<`
M``$&````````1@(``````````````````-<!``#-````-P,```0!````````
M*@<``'$'``!B!@```````($%``!N`0``KP(``,0$```N`@``500`````````
M`````````(0%```3!```D0(``%8&``#2````K@,``$@&```V!P``>P<`````
M``#0!```&P4```````"Z!`````````````""`0`````````````C`@``6@$`
M```````:!P``,0<``"`"``"H`@``)0<````````Z!```B0(``&L```#Q!@``
M.04``#P!```1!0```````.0%``"*````'`$``*L$``")`P``!@4````````B
M!0``70(```````#J`0```````/H$````````WP$``$<%````````$@8``(@`
M``#I`@``-`0``.4#``"K!0``S04``,<#````````/P0`````````````````
M`.H"``"A`P``_@,``!@%```S````]04``'8'````````;@8```````#+`P``
M;P$``!X#``!9!0```````(8```"#`0```````+0```"/`P``A`0``#`$``"W
M`0``F0(``*`%``"V`@``Y0(````````R!```H0```"P"``#(`P``"P,`````
M``",!0```````!H&``"L!```````````````````:P4```````#8`0``````
M``X$```'!@```````"4```#A`P``G@``````````````<@4``!X&````````
M%0$``#X%```=````S`(``)X%``"(!@``C@(``"$%``"6`@```````#\&``!`
M!@``H0$``*$%```G`@`````````````M````20<``)4"``!2!```````````
M```T`@``]P4``'0!``!=`P``-0$```````!.!```5@4``*($```)````PP4`
M`(,#````````6`$``&D"``#L`P``&0(```````#"`@``60<``$,#```\!```
MD`$``.8!``#C`P``400`````````````K`(```X"```<`@``3@$``$@$```*
M`````````$P&``#\`0``+@```(T!````````+`<``.T"``#I`0``SP$``&P"
M`````````````-H"``##`@``)P```+,#``"2!0```````&X````0````````
M`(T$```;`0``<`0``'4'`````P``W@4``%('``"R`P``!@<``(T#````````
MC0(``&<!``""`P``OP$``'8&``!N!```J@```$X"``!D!0```````(P#```N
M!P``@@0```````"\`P``/@0``!@"````````-P(``)(#``""``````0`````
M``````````````\"```5`@``P@```+L#````````T`8``#`%``#N````P04`
M``````!(!0``$@<``%@'```"!```7@$`````````````V0$``$D&``#Q!```
M;`8``#@%```Z!P``F@$``.$```"\`@``O@,``!8$`````````````)D%``#I
M!0``]0,```````!"!P``&0,``.P$``"5`P```@,```@&``"-!@```````&L&
M``!?!P``+@$``"4&````````9`8``&D#````````7@8``+4#```*`@``20(`
M`!\````+!@``9`$`````````````3P(`````````````I@4``#`&``"Q`0``
M#`8``-(!```U!0``A@$``%P`````````.@8``.8#```:!0``NP0``*T"````
M````@````'H#``"'!@```````(,&``#=`0``-0,``.\!``````````````P`
M``"6`P``8P(``)X"``#Q!0``````````````````9`0`````````````Z0``
M`+8%``"A!@```````!X!``#!`P``.P8``'`%``"$`0``:P(```````!-!```
MY@8```````#&!@``CP$```````##````'0<```````!C!```<P<````````-
M!0``/0$``$\'``!M`P``(08``$0````5!P````````````#8`@``20```#L#
M```7!````````.\```!J!@````````H%``!3`P``!P4``"0%``"U!@``J00`
M``<$``!'`0``0P8``````````````````"`%````````L````*\````O!@``
M[@8``.,`````````(@8``!(#``#!!```V08`````````````?P,```P$```8
M`P``K`$```````"Y`0``X@8``,X`````````D@$``'X'``#%`@```@4`````
M```T`0```````*@````L`0``#@,```````"0!```&0$``*(```!0!0``````
M`.D&``#5`@``````````````````"00``)D!``";`P``J@$```P"``#4!0``
M]`4``/4!```-`P```````)T!``#%`````````,8"``!7````.````"@"````
M`````````/T#``"G!```NP4```````#"!0```````$\!```=`0``[`8``/@&
M``"6!```4`0```````"M`0````````````"D`0``J04``+`"``!C!@``````
M`-8#```6!0``I@,````````:`@````4```````"&!P``@`<``-`%``#C`0``
MK`8``.,"``#`!@``JP(``'`#``"0!0``KP$```````#2!0``H@8```````"U
M!0```````,X%``!M!0```````/@"````````W08`````````````'P,``'T'
M``"T!```I@8```````#$!0``IP$``$,```"=`P``&P(```````!,!```````
M``(!``"7`@``3P4``$`#``!Y!@``W`(```````!&!P``8P4``'\&``!$`P``
MY0```$T%``#"!@```````````````````````-````!;`P``MP```'D"``!#
M!0```````%(&``#6!0``2@(``#T````M!0```````'H&``#@`@``8`0``!H#
M``````````````````##!````````-,#``#B`@``>`,``)0```"'!P``&@0`
M``````````````````````!!!```&08`````````````4`<````````I`P``
M_0```%<#`````````````"$'``!1`P``.@(``),```#S`0``50(`````````
M````#08```````"9!````````$(!``!?`@``2P0``$L'``!N!0``L0,`````
M``"$`@``308````````F`0```````-L!````````L04``'`'``#<!```:04`
M`+,&```G!0``/`<``$,'``!*`P``:00``,\#````````:`(``*\%``"`!```
M=@,``-$#``!0`P``F`$``.$"``!,`@``P@0```````"(!```:P<``'(`````
M``````````````#Z`@```````#(%``!H`P``!0<``",#``!\!@```````.@#
M``"7!```M0$``,H&``#/`@``*`$``)<!``#+`0```````%8'``!3`@``6@,`
M`(8%````````,`(``/@```"9`````````,P```"N`@``-`4```````#7````
M`````*4%```````````````````D!@``F`8``.X!```A`P``.P```)<&``!!
M`0``Q@,``(P"```$!P``%04``&4%```````````````````B`P``B@(``!X`
M``"#!P``50<``*T%``!%````=08``#@$``##`0``U`$``$(```!E!```)P<`
M`&\%``#U!@``5@````X!``#Y!0``30(``/X$``!:`@``HP4```0&``#H!0``
M(@```$4%````````2@8``)@$``";!@``P0(```,$`````````````+P&``!N
M`P``%`8``.T&````````?04``.@````T`P``6@4``!(%```/`0``'@(`````
M``!H!0```````"\!```]`@``30$``#`!```E`@``U0`````````E!0``9@,`
M`/8```!Z`@``C@8`````````````HP(```````"N`0``_`,``&$!``"X````
MD0```````````````````)4````F`P``#P``````````````B@,```````!]
M`@``QP4``,8!````````A@,``"`'``">`0```````-L"``#)`0``"@$``%4#
M``!Y````U`0``,,#````````R@$``!,#``````````````````!M!P``\`0`
M`'8$```(`P```````#T&``#8!````````*$"``!M````CP4``!<'````````
M5P<``"H$```"````8`(``!P%````````^`4``$X%````````R`````P#``"+
M`@```````*4#```(!0```````#D#``#_`0``#@<``%T$```)`@```````$P`
M``":!```T0$``"D%``#G!0```````'@`````````9@$``/````#N!0``2P(`
M`+<%```%!0```````%(```#K`P``2P4``-0&```Y````R`0``)T%``#``@``
M7@<```,!``!W!@``1`4``-X&``````````````<````V!0``*P,``/H```#'
M!@``%`<```(&``#*````>`$``!(!``#W`P``Y04``*H&``!3!```4@$`````
M```&`P``N0(``$T'```4````D0,``*H"``!<!```UP0``#H#```P`P``]```
M`$`$````````W@(``+`&`````````````-L%``!A!@``P`,``,H#``#M!```
M6P0``)0!``"(`P``9P<``(0'`````````````!,%``",!@``I`0``#`'``"*
M`0``0P0``)L````@!@``\@(``'0&`````````````+8$````````$`,``.H&
M``!@!0```````/L$``"4!@``X04``"D&`````````````/<$````````N@(`
M``````"T`0``1`8```````"M!@``508``#P%````````00```#8$````````
M,@(````````!!0```````(X%```=`P``IP(`````````````4@,``"8&``#3
M!0``^@8```````"H`0``8P,``!$$`````````````%,&```G`0``LP4`````
M``#E!@``TP(```````"'!0``@P(``+@&``!8`P``@0$```````#N!```)`(`
M`-(&````````-0```+L&``#)`@``J0,``%D`````````,0$```````#@!@``
ML@8```L%``!%`0``6@8``+@$```U!@```````%D&````````9````",&``#'
M`@```````)T```#_````!0$``$`"``")!```:0```-<%```@`0``G@0`````
M``"2`@``%`4````````Z`0``SP4````````6`0```````'@%``#'````RP8`
M````````````7@4``",$``#V`P``*@4``.<```#`!```J08``!P&``!*`0``
M,08````"``!G`P``W@0``#8"`````````````/L```"K!@``E08``%$"````
M````,@8````@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`("AI;B`E
M<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E<F1A>2D`(&%T
M(``B)7,B(&ES(&YO="!A(&1I<F5C=&]R>2X`(B5S(B!I<R!N;W0@82!V86QI
M9"!C:&]I8V4N`"(E<R(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E
M(%)E9VES=')Y+@`B)7,B('1R964@<F5N9&5R97(@;F]T(&9O=6YD+@`B)7,B
M('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W87,@861D
M960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@;F]T(&-R
M96%T960Z("5S+@`E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR
M9B4E*0`E9"`E<R!A;F0@)7,`)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D
M(&5X<&ER97,N`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!&:6YG
M97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N
M9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R
M965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!I<R!R
M96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H
M96-K960@8F5L;W<N($-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH
M<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`"5S(&ES(')E
M<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E<R!O9B`E
M<P`E<R=S($%D9')E<W,@0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A
M9``E<R=S(%1A<VML:7-T`"5S.B`E<P`E<SH@5&AI<R!M97-S86=E(&UA>2!N
M;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O
M;&QO=VEN9R!A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S
M96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN`"P@9W5S=&EN
M9R``+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M
M+2!S96QE8W0@+2T`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@
M:&]U<G,`/%!R979I;W5S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E
M9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`
M02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S
M<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@
M82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!0
M1U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP
M="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S
M86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL
M(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S
M<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A
M9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T
M(&$@;65S<V%G92X`04T@0VQO=61S`$%-($QI9VAT(%)A:6X`04T@4F%I;@!!
M32!3:&]W97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!4$D@240`06)O=70@
M=&AI<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E
M<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI
M960@8W)E871I;F<@5D93(&9I;&4N`$%C8V]U;G0@26YF;W)M871I;VX`06-C
M;W5N="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`
M061D($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E
M.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL
M9"!G<F]U<"!T;R`B)7,B`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@(B5S
M(@!!9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`
M061D('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R
M`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`
M061D('5S97(`061D960@(B5S(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@
M;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N`$%D
M9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+@!!
M9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S<R!";V]K
M`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S
M`$%D;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI<W1A;@!!;&)A;FEA`$%L9V5R
M:6$`06QI87,`06QI9VX`06QI9VYM96YT.@!!;&P`06QL($%U=&AE;G1I8V%T
M960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@
M<VED97,`06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@
M;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T
M92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T
M92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R
M;F%T92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%M97)I8V%N(%-A;6]A
M`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06X@=6YK;F]W;B!E
M<G)O<B!H87,@;V-C=7)E9"X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO
M;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A
M<F)U9&$`07!P;&EC871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO
M;B!I<R!R96%D>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P
M<F]X:6UA=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C
M:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@
M=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R
M92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@(B5S(B!A;F0@86YY('-U
M8BUG<F]U<',_`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!4DU30TE)
M+3@I`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L86YD`$%S8VEI($%R=`!!<VEA
M+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D
M;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O;'5M
M;G,`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T
M=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T
M=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E
M;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I8G5T97,`
M075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E
M9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME
M;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C
M>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I
M;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA
M<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR
M8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L
M9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E
M($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S
M=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!297%U
M:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA
M8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T
M:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]L9&%P.B!5
M<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER
M96-T;W)Y+@!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R
M(&9A:6QE9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N
M(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553
M('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N
M`$%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"X`079A
M:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"3T9(($5X8W5S97,`0F%C:V=R
M;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`
M0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC
M("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!"87-E(&=R87!H
M:6-S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`0F%S96QI;F4`0F5L87)U
M<P!"96QG:75M`$)E;&EZ90!"96YI;@!"97)M=61A`$)H=71A;@!":7)T:&1A
M>0!";&]C:R`B)7,B(&]F(&%P<&QI8V%T:6]N("(E<R(@;F]T(&9O=6YD+@!"
M;&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)O;&0`0F]L:79I80!";V]K;6%R
M:W,`0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]S;FEA(&%N
M9"!(97)Z96=O=FEN80!";W1H`$)O='-W86YA`$)O='1O;0!";W5V970@27-L
M86YD`$)R87II;`!"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GD`0G)U
M;F5I($1A<G5S<V%L86T`0G5L9V%R:6$`0G5L;&5T960@3&ES=`!"=7)K:6YA
M($9A<V\`0G5R=6YD:0!#35,`0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S
M`$-?96QL(%!R;W!E<G1I97,N+BX`0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L
M971E9"X`0V%L96YD87(`0V%L;0!#86UB;V1I80!#86UE<F]O;@!#86X@;F]T
M(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R+@!#86X@;F]T('=R:71E('1O(&9I;&4@(B5S(@!#86XG
M="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N`$-A;B=T
M(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;B=T(&]P96X@9FEL92`B
M)7,B+@!#86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN
M;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@
M9&ER96-T;W)Y+@!#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE
M)R!P87)A;65T97(N`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A
M;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E
M<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E
M<R!N;W0@;6%T8V@@;G5M8F5R('-T;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A
M9V4@=&\@<W!E8VEF:65D(&YU;6)E<BX`0V%P92!697)D90!#87!T:6]N`$-A
M<G)I97(`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-E
M;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P
M<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/
M+3@X-3DM,30I`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N
M=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL
M<P!#97)T:69I8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D
M`$-H86YG90!#:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@=&AE(&YA;64@
M86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N
M9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=I;F<@>6]U<B!P87-S=V]R
M9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A
M=&EO;BX@($-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#:&%R`$-H96-?
M:R!,:6YK+BXN`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R
M,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@07!P;&EC
M871I;VXZ`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H
M;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@
M='EP92`H9F]R(&]R9&5R960@;&ES=',I`$-H<FES=&UA<R!)<VQA;F0`0VQA
M<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%R`$-L96%R($U3
M3V9F:6-E('1A9W,`0VQE87(@475E<GD`0VQE87(@;W5T('5S97(Z("5S`$-L
M96%R('5S97(`0VQE87(@=7-E<B!D871A`$-L96%R:6YG($QA=&4`0VQI8VL@
M=&\@0V]N=&EN=64`0VQI8VMA=&5L;"!V:6$@2%144`!#;&]S92!7:6YD;W<`
M0VQO=61S`$-L;W5D<R!%87)L>0!#;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES
M;&%N9',`0V]L;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO
M;6)I80!#;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS
M.@!#;VQU;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`
M0V]M;65N=`!#;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M<'5T97)S
M`$-O;F1I=&EO;@!#;VYD:71I;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R96YC
M97,`0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T
M<&AO;F5S(&%N9"!/=71L;V]K+@!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D
M871E+@!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYG;P!#;VYG
M;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@
M9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E
M9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D
M('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N
M;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C=',`0V]N=&%C
M=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O
M;VLN`$-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z(`!#;VYT96YT
M<R!O9B`B)7,B`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#;V]K:64`0V]P>0!#
M;W!Y(&9A:6QE9#H@)7,`0V]P>2!S96QE8W1I;VX`0V]S="!)1`!#;W-T82!2
M:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A
M9V4Z(`!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G93H@`$-O=6QD(&YO="!3
M+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%('-I9VX@
M;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L9"!N;W0@
M8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N
M("5S`$-O=6QD(&YO="!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N
M;W0@8V]N;F5C="!T;R!S97)V97(@(B5S(B!U<VEN9R!&5%`Z("5S`$-O=6QD
M(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D
M96-R>7!T(%!'4"!D871A.B``0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A
M=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&1E
M;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E;&5T92!S
M971U<"!U<&=R861E('-C<FEP="`B)7,B+@!#;W5L9"!N;W0@9&5T97)M:6YE
M('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E
M=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O
M;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE
M(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N
M;W0@;&]A9"!S=')A=&5G>2`B)7,B+@!#;W5L9"!N;W0@;6MD:7(@(B5S(BX`
M0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E
M<BX`0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN9RX`0V]U;&0@;F]T
M(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D
M=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B)7,B+@!#;W5L9"!N
M;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@<F5A9"`E<RX`
M0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E
M9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@;F]T(&-O
M<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O
M<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R971R:65V
M92!!0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,`0V]U
M;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N
M;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@
M<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO="!R979E
M<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T(')M9&ER("(E<R(N`$-O=6QD
M(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@
M8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@
M8V]N9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E
M('-C<FEP="!T;SH@(B5S(BX`0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C
M;VYF:6=U<F%T:6]N(&9I;&4@)7,N`$-O=6QD(&YO="!S879E('1H92!C;VYF
M:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@
M=&AE(&]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O
M<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N`$-O=6QD(&YO="!S
M96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@=6YL:6YK("(E<R(N
M`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T('=R:71E(&-O;F9I
M9W5R871I;VX@9F]R("(E<R(Z("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL
M;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN`$-O
M=6QD;B=T(&=I=F4@=7-E<B`B)7,B('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O
M<B!T:&4@9F]L9&5R("(E<R(Z("5S`$-O=6YT960@=&5X=`!#;W5N=')Y`$-O
M=7)S97,`0W)E871E`$-R96%T92!A(&QI;FL`0W)E871E(&$@;F5W(&]N90!#
M<F5A=&4@<W5B(&9O;&1E<G,`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@
M8V%R9"!N=6UB97(`0W)O871I80!#=6)A`$-U<G)E;G0@-"!0:&%S97,`0W5R
M<F5N="!397-S:6]N<P!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R
M<F5N="!5<V5R<P!#=7)R96YT(%=E871H97(`0W5R<F5N="!C;VYD:71I;VXZ
M(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L
M;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Y<FEL;&EC
M("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K
M<F%I;FEA;B`H2T])."U5*0!#>F5C:"!297!U8FQI8P!$1`!$4TX@*'-E92!H
M='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E
M+F1B+FEN=')O+61S;BYP:'`I`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T
M86)A<V4@3&]O:W5P`$1A=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO
M;@!$87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S
M`$1E8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L
M="!)9&5N=&ET>0!$969A=6QT(%-H96QL`$1E9FEN:71I;VYS`$1E;&5T90!$
M96QE=&4@0V5L;`!$96QE=&4@1W)O=7``1&5L971E($QO9P!$96QE=&4@4&5R
M;6ES<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL
M`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP
M;&%T90!$96QE=&4@;65S<V%G97,`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B
M)7,B`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(B!A;F0@86YY('-U8BUP
M97)M:7-S:6]N<S\`1&5L971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I
M='D`1&5L971E('-U8B!F;VQD97)S`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU
M;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$96QE=&5D('-E='5P('5P9W)A
M9&4@<V-R:7!T("(E<R(N`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$97-C<FEB
M92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS("AA;'-O(&EN($AO
M<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@
M=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$97<@
M4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I<F5C=&EO;B!L
M969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T`$1I<F5C=&]R
M>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P
M;&%Y(&1E=&%I;&5D(&9O<F5C87-T`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`
M1&ES<&QA>2!F;W)M870`1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N`$1J:6)O
M=71I`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN
M=&5N86YC92YP:'``1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I
M96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$
M;VUI;FEC86X@4F5P=6)L:6,`1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N
M('5P+@!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T960@
M8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+@!$<F]P(&1O=VX@;&ES=`!$
M<G5G<P!%+4UA:6P`14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@
M8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N`$524@!%8W5A
M9&]R`$5D:70`161I="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO
M;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D
M:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("(E<R(`161I
M="!P97)M:7-S:6]N<R!F;W(@)7,`161U8V%T:6]N`$5G>7!T`$5L(%-A;'9A
M9&]R`$5L96UE;G0N+BX`16T`16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A
M9&1R97-S97,@;75S="!M871C:"X`16UA:6P@=VET:"!C;VYF:7)M871I;VX`
M16UA:6PM=&\M4TU3($=A=&5W87D`16UO=&EC;VYS`$5M<'1Y(&UE<W-A9V4N
M`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N86)L92!I;G-E
M<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_
M`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N9"!Y96%R`$5N
M;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@
M>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B!P
M87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G
M.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`16YT97(@=&AE(&QE='1E<G,@
M8F5L;W<Z`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R96$`17)R;W(`17)R;W(@
M8W)E871I;F<@8FQO8VLZ("5S`$5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R
M.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,`17)R;W(@9V5T=&EN
M9R!C;VYT96YT.B`E<P!%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,`17)R
M;W(@=VET:"!E;6%I;"!M97-S86=E+@!%<G)O<B!W<FET:6YG("(E<R(N`$5S
M=&]N:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S
M`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN
M=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E
M`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A;F0@4VED96)A
M<@!%>'!E8W1E9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S
M96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`1D<@0V]L;W(`
M1E10('5P;&]A9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E
M;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE
M9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R
M;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R
M96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T;R`B
M)7,B+@!&86EL960@=&\@<F5T<FEE=F4Z("5S`$9A:7(`1F%L:VQA;F0@27-L
M86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z`$9A
M>`!&87AE<P!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@
M4VAO=V5R<P!&97<@4VYO=R!3:&]W97)S`$9I96QD(&UA=')I>`!&:6=L970@
M0T%05$-(00!&:6=L970@9F]N=`!&:6II`$9I;&4`1FEL92!#;W5N=#H@)7,@
M9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.
M86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N
M;W0@<W5P<&]R=&5D+@!&:6QT97)S`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S
M="!1=6%R=&5R`$9I>"!R871I;P!&;&EP`$9L;V%T`$9O9P!&;VQD97(@)7,@
M9&]E<R!N;W0@97AI<W0`1F]N="!#;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T
M:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4048I`$9O<F5C
M87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T
M=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@
M8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S
M<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O
M<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S`$9R`$9R86UE<P!&<F%N8V4`1G)A
M;F-E+"!-971R;W!O;&ET86X`1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE
M<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&<F]M`$9R;VT@=&AE
M(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA;64`1V%B;VX`
M1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=E
M;F5R871E("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`1V5O<F=I
M80!'97)M86YY`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=L;V)A;"!/
M<'1I;VYS`$=O`$=O961E;`!';V]G;&4@36%P<P!';V]G;&4@4V5A<F-H`$=R
M87ES8V%L90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R965N;&%N9`!'
M<F5N861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@
M8F4@;F]N+65M<'1Y`$=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@
M)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!'<F]U<%]L9&%P
M.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S`$=R;W5P7VQD87`Z(%5N86)L
M92!T;R!U<&1A=&4@9W)O=7`@)7,`1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'
M=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W1B;V]K
M`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A(&-O
M=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W
M+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@
M=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92X`2%144"!!=71H96YT
M:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`
M2&5A9&5R`$AE861E<G,`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA
M;F1S`$AE879Y(%0M4W1O<FT`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H
M=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE
M<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(
M;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@061D<F5S
M<P!(;VUE($1I<F5C=&]R>0!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N
M9P!(;W)D90!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O
M=6YT97)E9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E
M(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J
M96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA
M8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@
M5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@
M4$A0(&5X=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N
M97<@6$U,('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE
M('1O(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O
M(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(
M;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`
M2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U
M;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U
M(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@
M=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L
M=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME
M('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG
M87)Y`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I
M;&)O>"!D96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C
M<F5A=&EO;B!F86EL960Z("5S`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@
M879A:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412
M(&)L;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$E?;G-E<G0@4F]W($)E
M9F]R90!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@9F]R("5S`$EC;VYS('=I
M=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y
M960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`
M268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP
M;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N
M(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G
M92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@
M8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@4')E
M=FEE=SH`26UA9V4@55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y
M`$EM86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O
M<G0L(%-T97`@)60`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD
M<SH`26Y?<V5R="!2;W<@069T97(`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I
M=F5N+@!);F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O
M<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I
M;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F
M=7)T:&5R(&AE;'`N`$EN8W)E87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L
M(%5S97)S`$EN9&]N97-I80!);F9O`$EN9F]R;6%T:6]N`$EN9F]R;6%T:6]N
M(&YO(&QO;F=E<B!A=F%I;&%B;&4N`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN
M<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R
M="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H
M92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@
M8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N
M="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE
M`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN
M<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E
M<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S
M('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!)
M;G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O
M;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G
M97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E
M9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R
M="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO
M;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS
M=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@
M;&ES="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI
M<W0`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!:
M25`@9&%T80!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$
M+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T:6]N
M(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI9"!L:6-E;G-E
M(&ME>2X`26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"X`26YV86QI9"!M<V=?
M='EP92X`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O<B!M
M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN
M`$EN=F%L:60@<&%R=&YE<B!I9"X`26YV86QI9"!P<F]D=6-T(&-O9&4N`$EN
M=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<F5C:7!I96YT.B`B)7,B`$EN=F%L
M:60@<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L
M:60@=6YI8V]D92!D871A+@!);G9E;G1O<GD`26YV97)T('-E;&5C=&EO;@!)
M<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F`$ER87$`27)E;&%N9`!)<VQE(&]F
M($UA;@!)<V]L871E9"!4+5-T;W)M<P!)<W)A96P`27-S=65R`$ET86QI8P!)
M=&%L>0!*86UA:6-A`$IA;G5A<GD`2F%P86X`2F%P86YE<V4@*$E33RTR,#(R
M+4I0*0!*97)S97D`2F]R9&%N`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I9GD@
M0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H
M=`!+87IA:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA`$ME<F)E<F]S('-E
M<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5R;F5L($YE=V)I97,`
M2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4
M>7!E`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI
M8R!K97ES97)V97(N`$MI9',`2VER:6)A=&D`2V]R96$L($1E;6]C<F%T:6,@
M4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F`$MO<F5A
M;B`H155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,85]Y;W5T`$QA;F=U86=E
M`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@2&%L9@!,
M87-T(%!A<W-W;W)D($-H86YG90!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D
M.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@
M;&]G:6XZ($YE=F5R`$QA='9I80!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O
M<B!N;R!B;W)D97(`3&5B86YO;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L
M=65S`$QE<V]T:&\`3&5V96P`3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER
M:7EA`$QI96-H=&5N<W1E:6X`3&EG:'0@1')I>GIL90!,:6=H="!286EN`$QI
M9VAT(%)A:6X@16%R;'D`3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A:6X@4VAO
M=V5R`$QI9VAT(%)A:6X@=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`3&EG:'0@
M4VYO=R!3:&]W97(`3&EM97)I8VL`3&EN:P!,:6YK('!O:6YT<R!T;SH`3&EN
M:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@
M9&ES<&QA>6EN9P!,:6YK<P!,:6YU>"!#;V]K:64`3&ES="`M('5S97(@8V%N
M('-E92!T:&4@9F]L9&5R`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I
M8W,`3&ES="!486)L97,`3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED
M`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS
M=6)S8W)I8F4`3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S`$QI<W1I;F<@
M=7-E<G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,
M:71E<F%T=7)E`$QI=&AU86YI80!,;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,
M;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O9B!P<F5V:6]U
M<R!S>6YC('-E<W-I;VX`3&]G(&]U=`!,;V=I;@!,;V=I;B!487-K<P!,;V=I
M;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A
M<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QO;F<@=&5X
M=`!,;W9E`$QO=P!,;W=E<B!G<F5E:R!L971T97)S`$QO=V5R(&QA=&EN(&QE
M='1E<G,`3&]W97(@<F]M86X@;G5M8F5R<P!,=7AE;6)O=7)G`$U-`$U/5$0`
M35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+@!-4T<`36%C
M86\`36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F
M`$UA9&%G87-C87(`36%G:6,`36%I;`!-86EL($%D;6EN`$UA:V4@;&EN7VLN
M+BX`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`36%N86=E
M('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E
M;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T
M96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-87!P:6YG<R!S=&]R
M960N`$UA<F-H`$UA<F=I;@!-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`
M36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E
M9"D`36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H:6YG(&9I96QD
M<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87@@86QL;W=E9"!C<F5D:70N`$UA
M>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M<"!L87-T(#(T(&AO
M=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``36%X:6UU;2!.=6UB97(@
M;V8@4&]R=&%L($)L;V-K<P!-87AI;75M(&QE;F=T:`!-87D`36%Y;W1T90!-
M961I8VEN90!-96UB97)S`$UE;G4@;6]D93H`365R9V4@8V5L;',`365S<V%G
M90!-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE
M<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`365S<V%G
M92!E>'!I<F5D+@!-97-S86=E('1Y<&4`365T87(@5V5A=&AE<@!-971A<B!B
M;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE
M+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A
M=&]R+@!-971A<D1"(&ES(&YO="!C;VYN96-T960N`$UE=&AO9`!-971H;V0@
M(B5S(B!I<R!N;W0@9&5F:6YE9`!-971H;V0@;F]T(&1E9FEN960N($-A;&QE
M9"!M971H;V0Z("5S`$UE=')I8P!-97AI8V\`36EC<F]N97-I82P@1F5D97)A
M=&5D(%-T871E<R!O9@!-:61D;&4`36EM92!4>7!E`$UI;B!T96UP(&QA<W0@
M,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-:6YI;75M('!A
M<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D`$UI<G)O<@!-:7-C96QL
M86YE;W5S`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="X`36ES
M<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N
M;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC871I;VXN`$UI<W-I
M;F<@;65S<V%G92!)1"X`36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@
M36%I;"X`36ES<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E
M<F%T90!-;V1I9FEE9"!$871E`$UO9&EF>2!54DP`36]D=6QU<P!-;VQD;W9A
M+"!297!U8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N=&@@86YD('EE87(`
M36]N=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO<F4@9FEE;&1S(&9O
M=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N`$UO<F]C8V\`
M36]S=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY($-L;W5D>2!A;F0@
M5VEN9'D`36]S=&QY(%-U;FYY`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2
M:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E('5P`$UO>F%M8FEQ=64`375L
M=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S`$UU;'1I;6%P(%5+(&UA<`!-=6QT
M:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!!8V-O=6YT($EN9F]R;6%T
M:6]N`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM87(`3D\L($D@
M1&\@3D]4($%G<F5E`$YA;64`3F%M:6)I80!.875R=0!.97!A;`!.971H97)L
M86YD<P!.971H97)L86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E(%523`!.
M971S8V%P92!#02!2979O8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@
M55),`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C871I;VX@
M55),`$YE='-C87!E(%-33"!S97)V97(@;F%M90!.971S8V%P92!C97)T:69I
M8V%T92!C;VUM96YT`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R
M:P!.979E<@!.97<@0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@36]O;@!.
M97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@<&%S<W=O
M<F0`3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+@!.97<@<&%S<W=O
M<F1S(&1O;B=T(&UA=&-H+@!.97<@=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5W
M<V=R;W5P<P!.97AT`$YE>'0@-"!0:&%S97,`3F5X="!O<'1I;VYS`$YE>'0^
M`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI9VAT`$YI=64`3F\`3F\@879A
M:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S
M(&9O<BX`3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM
M86=E<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T
M:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED
M960@9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@8VAI
M;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&
M4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-R961I="!L969T+@!.;R!D97-T
M:6YA=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.;R!I8V]N<R!F
M;W5N9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!L;V-A=&EO;B!P<F]V:61E
M9"X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I960N`$YO
M(&YU;6)E<B!S<&5C:69I960N`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO
M;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T
M:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E
M9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R!W;W)K('=I
M=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I9VYU<',N`$YO('%U;W1A
M('-E="X`3F\@<G5L97,`3F\@<V5P87)A=&]R('-P96-I9FEE9"X`3F\@<VED
M97,`3F\@<W5C:"!F:6QE`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA
M8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E
M;G0N`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V
M97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N
M97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R
M(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N
M90!.;VYE("AU<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO
M<F9O;&L@27-L86YD`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R
M:6%N82!)<VQA;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@
M82!D:7)E8W1O<GD`3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S=7!P
M;W)T960N`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.;W9E
M;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O
M;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O
M<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J96-T`$]B
M:F5C="!#<F5A=&]R`$]C=&%L`$]C=&]B97(`3V9F96YS92!F:6QT97(`3V9F
M:6-E`$]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="X`
M3VQD('!A<W-W;W)D`$]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="X`3VUA
M;@!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/
M;FQY(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S
M(&%L;&]W960N`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A
M=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS
M(&9O<B!A('-H87)E`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R
M;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%
M('!A<G0N`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T
M:6YG(%-Y<W1E;0!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R9&5R960@3&ES
M=`!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG
M`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E;7!L
M871E<R!I;B`E<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`3W=N97(@4&5R
M;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N
M`%!%05(Z.DUA:6P@8F%C:V5N9`!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0
M($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC
M<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H96QL`%!-($QI9VAT(%)A:6X`
M4$T@4F%I;@!032!3:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S`%!-
M(%-U;@!032!4+5-T;W)M<P!03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9P!0
M7TA0(%-H96QL`%!A9&1I;F<`4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@
M5&5R<FET;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!0
M87)A9W5A>0!087)T;'D@0VQO=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&-H86YG
M960@<W5C8V5S<V9U;&QY+@!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@
M<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BX`4&%S<W=O<F0@
M=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O
M<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!A
M=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N=`!097)F;W)M($UA
M:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R
M871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VX@(B5S(B!N
M;W0@9&5L971E9"X`4&5R;6ES<VEO;B!$96YI960`4&5R;6ES<VEO;G,`4&5R
M;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R<V]N86P@26YF;W)M871I;VX`
M4&5R=0!0971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0
M:7AE;',`4&QA=&ET=61E<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`
M4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E
M;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN
M:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE
M87(N`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ
M`%!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E
M<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T
M:&4@;6]N=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!P
M<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I
M9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E(')E860@=&AE
M(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M
M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E
M9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R='5G86P`4&]S
M:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A
M8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0
M*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5C:7!I
M=&%T:6]N/&)R("\^8VAA;F-E`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@
M97AT96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@
M<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R
M92!A="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T
M:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S(&]P=&EO;G,`4')I
M;G0@9&]C=6UE;G0`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E<V-R
M:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`4'5B;&EC
M($ME>2!!;&=O<FET:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R]0<FEV871E
M(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2
M:6-O`%!U<F=E(&UE<W-A9V5S`%%A=&%R`%%U97)Y`%%U;W1A`%)302!0=6)L
M:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R
M;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T
M;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E
M<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@
M=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@
M5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5D;V5S('EO=7(@
M;&%S="!A8W1I;VX`4F5F<F5S:`!2969R97-H($1Y;F%M:6,@365N=2!%;&5M
M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G97@`4F5L871I;VYS:&EP
M($)R;W=S97(`4F5L;V%D`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E
M(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!2
M96UO=F4@0FQO8VL`4F5M;W9E(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN9P!2
M96UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@
M=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@=&AI<R!N
M;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R
M.B`E<P!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E
M<G)O<F-O9&4Z(`!297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U
M;F0N`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U
M<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@5D93(&-O
M;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!C
M;VYF:6=U<F%T:6]N+@!297%U:7)E9"!&:65L9`!297-E=`!297-E="!087-S
M=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W1O<F4@3&%S="!1=65R>0!2
M97-U;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E='EP92!N97<@<&%S<W=O<F0`
M4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R
M($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG:'0@=F%L
M=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N:6$`4F]T871E(#$X
M,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I97,`4F]W
M('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N
M(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3+TU)
M344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E9"!-
M97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`
M4TU3($UE<W-A9VEN9P!344P@4VAE;&P`4U%,('-T871E;65N="!F;W(@=F%L
M=64@;&]O:W5P<P!34T@`4U5#0T534P!37U%,(%-H96QL`%-A`%-A:6YT($AE
M;&5N80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@
M4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E
M;F%D:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!3
M86\@5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I9&5R`%-A=61I
M($%R86)I80!3879E`%-A=F4@(B5S(@!3879E("5S`%-A=F4@3W!T:6]N<P!3
M879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T
M;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S
M(&-O;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O
M.B`B)7,B+@!38V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!396%R8V@`4V5A
M<F-H($5N9VEN97,`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A=&4`4V5L96-T
M(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!S
M97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;`!396QE8W0@
M86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C=`!396QE8W0@
M;F]N90!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@
M8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M
M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E
M<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I9&5N=&ET
M>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET
M97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI
M;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y
M;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!3
M96YD(%--4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:6$@86YD
M($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397)V97(@9&%T82!W<F]N9R!O
M<B!N;W0@879A:6QA8FQE+@!397-S:6]N($%D;6EN`%-E<W-I;VX@240@97AP
M:7)E9"X`4V5S<VEO;G,`4V5T`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T
M;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`
M4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S
M(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G
M92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U
M<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L
M(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A
M9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB
M;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3:&]P<&EN9P!3
M:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O
M<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C
M=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG
M=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN
M/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H
M;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N
M=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S
M(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W
M('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA
M9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W
M97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6:6-I;FET
M>0!3:')I;FL`4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I
M(&]U="!O9B!T:&4@=V%Y(&9I<G-T`%-I97)R82!,96]N90!3:6=N('5P`%-I
M9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K
M:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=P!3;F]W(%-H
M;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO
M=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T
M97(Z(`!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3;VYG<R`F(%!O96US`%-O
M<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC
M80!3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A
M;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P
M:&5R90!3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E
M96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`
M4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C
M=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3
M<&]R=',`4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R="!Y96%R
M`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R86=E(&9O<FUA=`!3=')E
M970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP(&1O
M;6%I;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=`%-U`%-U8F1I<F5C
M=&]R>2`B)7,B(&YO="!F;W5N9"X`4W5B:F5C=`!3=6)M:70`4W5B;6ET=&5D
M(')E<75E<W0@=&\@861D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO
M="!L;V<@:6X@=6YT:6P@>6]U<B!R97%U97-T(&AA<R!B965N(&%P<')O=F5D
M+@!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@861D960@(B5S(B!T
M;R!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U
M<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@9&5L971E
M9"`B)7,B+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`B)7,B(&9R;VT@=&AE('-Y
M<W1E;2X`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E
M;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU
M<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU
M<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E<W-F=6QL>2!U<&1A=&5D
M("(E<R(`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U9&%N`%-U;6UA<GD`4W5N
M(%)I<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U;G)I<V4O4W5N<V5T`%-U
M;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I<'0`4W5P<&]R=`!3
M=7)I;F%M90!3=7)N86UE`%-V86QB87)D(&%N9"!*86X@36%Y96X`4W=A>FEL
M86YD`%-W961E;@!3=VET>F5R;&%N9`!3>6YC(&QO9R!D96QE=&5D`%-Y;F--
M3`!3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS`%-Y<FEA;B!!<F%B(%)E
M<'5B;&EC`%0M4W1O<FT`5"U3=&]R;2!A;F0@5VEN9'D`5"U3=&]R;7,`5"U3
M=&]R;7,@16%R;'D`5%-6(&9I;&4`5&%B;&4@4')O<&5R=&EE<P!486)L92!3
M970`5&%B;&4@<')O<&5R=&EE<P!486EW86X`5&%I=V%N+"!0<F]V:6YC92!O
M9B!#:&EN80!486II:VES=&%N`%1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@
M;V8`5&%R9V5T.@!487-K<P!496QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R(&QA
M<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&5R871U
M<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<P!496UP;&%T92`B)7,B
M(&YO="!F;W5N9"X`5&5M<&QA=&4@061M:6YI<W1R871I;VX`5&5X=`!497AT
M($]N;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@*%1)4RTV,C`I`%1H
M86EL86YD`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H
M92!(:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"X`5&AE($AO<F1E+TMO;&%B
M(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T("(E<R(`5&AE
M($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"X`5&AE($UA:6YT
M96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4:&4@
M3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE(&%D;6EN
M:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI
M<W-I;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS
M+@!4:&4@8F]T=&]M('-I9&4@;VYL>0!4:&4@8V]N=&%C="!)1"!N=6UB97(@
M=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N
M9"!I;B!T:&4@9&%T86)A<V4N`%1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L
M;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`%1H92!D971A8VAE9"!0
M1U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@
M<VEG;F5D(&UE<W-A9V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@
M96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD
M(&EN('1H92!D871A8F%S92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N
M;W0@<W!E8VEF:65D+@!4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E
M(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4:&4@9FEL92`E<R!S:&]U;&0@
M8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT
M86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-A;FYO="!B92!C;W!I
M960@;VYT;R!I='-E;&8N`%1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4
M:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E
M+W)F8S@R,B!M97-S86=E+@!4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W
M;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D
M=64@=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O
M<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92!G87)B86=E(&1I<W!L
M87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R
M;W=S97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@
M:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"!0
M<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7&Y<;EEO=2!H
M879E(&)E96X@=V%R;F5D+B`@4&QE87-E('!R97-S($]+(&EF('EO=2!S=&EL
M;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+@!4:&4@:61E
M;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@;&5F="UH86YD('-I
M9&4@;VYL>0!4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T
M(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RX`5&AE(&UE<W-A
M9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@(B5S(B!H87,@8F5E
M;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE
M<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+@!4:&4@;F%M92!T
M;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4`5&AE(&YU
M;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+@!4:&4@;W!E;G-S;"!M
M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ
M(&-L87-S+@!4:&4@<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B92!S879E
M9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M(&%L;&]W
M86)L92!S:7IE`%1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@
M='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE('%U
M;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4
M:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG:'0M:&%N9"!S
M:61E(&]N;'D`5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA
M<F%C=&5R+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE
M('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P(')E<75E
M<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H92!S<&5C:69I960@<F]W
M("@E9"D@9&]E<R!N;W0@97AI<W0N`%1H92!T96UP;W)A<GD@9FEL92`B)7,B
M(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T
M(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN`%1H92!T;W`@86YD(&)O
M='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!U<&QO861E
M9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4:&4@
M=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!W96%T:&5R
M+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5M97,@9&ER96-T;W)Y
M("(E<R(@;F]T(&9O=6YD+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B
M;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@
M:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES
M(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[('EO=2!M
M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!A
M9&1I;F<@(B5S(B!T;R!T:&4@<WES=&5M.B`E<P!4:&5R92!W87,@82!P<F]B
M;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T
M96TZ(`!4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG("(E<R(@9G)O;2!T
M:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R`B)7,B
M.B`E<P!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D
M.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE
M(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E('=A<R!A
M('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL
M>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P
M;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N`%1H97)E('=A<R!A;B!E
M<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L
M969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W87,@86X@97)R;W(@
M<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO
M;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R
M('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A
M:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES
M=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H:7,@
M24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N
M`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI
M=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I
M;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M
M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T
M:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI
M(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO
M=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z
M+R]W:6YP;&,N8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T
M:&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@
M=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG
M(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET
M86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q
M=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F;VYE($ET86QY("AH
M='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N`%1H
M:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BX`5&AI
M<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`5&AI<R!F
M:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@
M;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R
M+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE
M(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N`%1H:7,@
M9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`5&AI<R!I<R`E<RX`
M5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI
M<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C;&EE;G0@=&AA="!U
M;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@
M;&ES="!O9B!S=6-H(&5M86EL(&-L:65N=',@<&QE87-E('9I<VET("5S`%1H
M:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S
M*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T
M(&QE87-T(&]N92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@
M86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C
M=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I
M;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H
M=6YD97(`5&EC:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`5&EM92!F;W)M870`
M5&EM92!S96QE8W1I;VX`5&EM;W(M3&5S=&4`5&ET;&4`5&ET;&4@*'1O;VQT
M:7`I.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T
M:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L
M:6-K:6YG+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME;&%U
M`%1O;6]R<F]W`%1O;F=A`%1O;R!M86YY(&EN=F%L:60@;&]G:6YS(&1U<FEN
M9R!T:&4@;&%S="!M:6YU=&5S+@!4;W``5&]P(&9R86UE("A?=&]P*0!4<F%N
M<VQA=&EO;G,`5')I;FED860@86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U
M`%1U;FES:6$`5'5R:V5Y`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI
M<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU`%1Y<&4@>6]U
M<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``55),`%523"!F;W(@>6]U<B!S8W)I
M<'0@9&5L:79E<GD@<W1A='5S(')E<&]R=`!54DPZ`%5G86YD80!5:W)A:6YE
M`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D
M9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`56YA
M8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5
M;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S
M+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8VAE8VL@9FEL
M92!S:7IE(&]F("(E<R(N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@
M(B5S+R5S(BX`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA
M8FQE('1O(&-O;FYE8W0@=VET:"!34TPN`%5N86)L92!T;R!C;W!Y(%9&4R!F
M:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@(B5S(BX`56YA
M8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@8W)E871E
M(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@(B5S(BX`
M56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92X`56YA8FQE('1O(&1E
M8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER
M96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E
M<RX`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@
M96UP='D`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV
M96QY+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T
M;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@
M5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA
M8FQE('1O(&1E;&5T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!D96QE
M=&4@5D93(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C
M=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A
M=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E
M<RX`56YA8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&
M4R!F:6QE("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET
M:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@
M8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H
M9FEL97-I>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H
M9V5T1FEL95-I>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!F:6QE.B``
M56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@
M=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D
M>2!E>&ES=',`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B
M;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N
M86UE(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@
M)7,O)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R
M=6X@)VUK:7-O9G,G+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D
M;V-U;65N=`!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O
M('=R:71E(%9&4R!F:6QE(&1A=&$N`%5N86)L92!T;R!W<FET92!61E,@9FEL
M92P@<75O=&$@=VEL;"!B92!E>&-E961E9"X`56YD97)L:6YE`%5N9&\@0VAA
M;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O
M;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E
M<W!O;G-E(&9R;VT@<V5R=F5R('1O.B``56YF:6QE9`!5;FEC;V1E("A55$8M
M."D`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D
M(%-T871E<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`
M56YI=',`56YK;F]W;@!5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)
M1"DN`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`56YK
M;F]W;B!L;V-A=&EO;B!P<F]V:61E9"X`56YK;F]W;B!U<V5R;F%M92!O<B!P
M87-S=V]R9"X`56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5
M;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A
M<W1E('!R;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L
M:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G
M('=H:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C
M97-S('1H92!C;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($5X
M=&5N<VEO;@!5<&1A=&4`57!D871E("5S`%5P9&%T92!U<V5R`%5P9&%T960@
M(B5S(BX`57!G<F%D92!S8W)I<'0@9&5L971E9"X`57!L;V%D`%5P;&]A9&5D
M(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+@!5
M<'!E<B!L871I;B!L971T97)S`%5P<&5R(')O;6%N(&YU;6)E<G,`57)U9W5A
M>0!5<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@:68@;F%M92]P87-S=V]R
M9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R`%5S97(@)7,@
M:7,@;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N
M`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A
M=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R(&%C
M8V]U;G0@;F]T(&9O=6YD`%5S97)N86UE`%5S97)N86UE("(E<R(@86QR96%D
M>2!E>&ES=',N`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S
M>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES
M="X`5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!6
M86QI9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU92!I<R!O
M=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RX`5F%L=65S`%9A;'5E<R!T
M;R!S96QE8W0@9G)O;0!686YU871U`%9A<FEA8FQE`%9E;F5Z=65L80!697)I
M9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@
M=&%M<&5R960@=VET:"X`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`5F5R=&EC
M86P@86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H
M`%9I970@3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE=R`E<P!6:65W(&%N
M(&5X=&5R;F%L('=E8B!P86=E`%9I97<@87,@)7,`5FER9VEN($ES;&%N9',L
M($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES:6)I;&ET>0!6:7-I
M8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!705).24Y'
M(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5TE.('9I82!(
M5%10`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E
M8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC;VT`5V5B
M`%=E8B!3:71E`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M
M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM
M,34I`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S
M(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C
M:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAE<F5I
M<R!!=7-T<F%L:6$@;6%P`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O
M(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H`%=I9'1H
M(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F
M="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@;V8@=&AE
M('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN9`!7:6YD($5A<FQY
M`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O;0!7:7-H
M;&ES=`!7;W)K`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%=R;VYG(&YU;6)E
M<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D
M+@!7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@
M)60N`%=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N
M`%@M4F5F`%@U,#EV,R!"87-I8R!#;VYS=')A:6YT<P!8-3`Y=C,@17AT96YD
M960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64`
M6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(`6#4P.78S(&5X=&5N<VEO
M;G,`65D`65E960!986AO;R$@;6%P`%EE87)L>0!996UE;@!997,`665S+"!)
M($%G<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U
M='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E(&YO="!A
M;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+@!9;W4@87)E
M(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N;F]T(&AA=F4@=&AE("=<)R!C
M:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!D:60@;F]T(&5N=&5R
M(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I9&XG="!M87`@86YY(&9I
M96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD
M:6YG(&9I96QD<R!I;B`E<RX`66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9
M;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I
M9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG(&9O<B!T:&4@:6YT97)N
M871I;VYA;"!D:6%L:6YG('!R969I>"X`66]U(&AA=F4@=&\@96YT97(@82!V
M86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C
M:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93
M(&)A8VME;F0N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R
M92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E
M;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU
M<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+@!9;W4@;75S="!S
M<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@;75S="!S<&5C
M:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H
M92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N
M86UE('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T
M;R!P97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N
M`%EO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(`
M66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A
M:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO
M=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N
M9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4
M;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN
M+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@
M;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R!U<V4@
M2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U
M<V4@82!D:69F97)E;G0@875T:&5N=&EC871I;VX@8F%C:V5N9"X`66]U<B!A
M=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN
M9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R
M('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H
M879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E
M<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G
M:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@
M9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P
M<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@=&\@<')I
M;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!I9&5N
M=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ
M`%EO=7(@9G5L;"!N86UE.@!9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+@!9;W5R
M(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N<R!H879E
M(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO
M;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W
M;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S
M970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W
M('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+@!9;W5R(')E
M;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!::6UB86)W
M90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@4F5P;W)T70!;
M4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN
M97-=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I;VX`7T-,20!?1&%T
M851R964`7T1E;&5T92!2;W<`7T=R;W5P<P!?2&5L<`!?26UA9V4@4')O<&5R
M=&EE<RXN+@!?3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN:RXN+@!?3W!T
M:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]3971U<`!?5&%B
M;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`861D<F5S<R!B;V]K`&%D9')E<W-E
M92!U;FMN;W=N`&-A;&5N9&%R`&-A;&T`8V%N;F]T(&-R96%T92!O=71P=70@
M9FEL90!C86YN;W0@;W!E;B!I;G!U=`!C;&EC:R!H97)E`&-O;6UA;F0@;&EN
M92!U<V%G92!E<G)O<@!C;VYF:6=U<F%T:6]N(&5R<F]R`&-R:71I8V%L('-Y
M<W1E;2!F:6QE(&UI<W-I;F<`9&%T82!F;W)M870@97)R;W(`961I=`!E;G1R
M>2!N;W0@9F]U;F0`9F%L;&EN9P!F:6QE`&9R;VT@=&AE("5S("@E<RD@870@
M)7,@)7,`9W5S=&EN9P!H.@!H:`!H;W-T(&YA;64@=6YK;F]W;@!I;6UE9&EA
M=&4`:6YL:6YE`&EN<'5T+V]U='!U="!E<G)O<@!I;G1E<FYA;"!S;V9T=V%R
M92!E<G)O<@!L:6YE<UT`;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA
M:VEN9R!)4T\N`&UM`&YA;64`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@:6UP
M;&5M96YT960`;F]T97!A9`!P97)C96YT`'!E<FUI<W-I;VX@9&5N:65D`'!I
M>&5L<P!R96UO=&4@97)R;W(@:6X@<')O=&]C;VP`<FES:6YG`'-E<G9I8V4@
M=6YA=F%I;&%B;&4`<VAO=R!D:69F97)E;F-E<P!S;7,R96UA:6P@=FEA($A4
M5%``<W,`<W1E861Y`'-Y<W1E;2!E<G)O<@!T87-K(&QI<W0`=&5M<&]R87)Y
M(&9A:6QU<F4`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U
M;FEF:65D`'5N;F%M960`=7-E<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE<BYC
M;VT`4')O:F5C="U)9"U697)S:6]N.B!F<E]&4@I297!O<G0M37-G:60M0G5G
M<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@
M,C`P-BTP,RTP-B`Q,CHT-RLP,3`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M
M,#,M,S$@,C(Z,S`K,#(P,`I,87-T+51R86YS;&%T;W(Z(%1H:65R<GD@5&AO
M;6%S(#QT:&EE<G)Y0'!O;7!O+FYE=#X*3&%N9W5A9V4M5&5A;3H@1G)E;F-H
M(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N
M=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3$*0V]N
M=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`I0;'5R86PM1F]R;7,Z(&YP
M;'5R86QS/3([('!L=7)A;#TH;B`^(#$I.PH`("AI;"!Y(&$@)7,@:F]U<G,I
M`"`H5&]U8VAE(&0G86-CZ',@<F%P:61E("5S*0`@*&1A;G,@)7,@:F]U<G,I
M`"`H875J;W5R9"=H=6DI`"`H9&5M86EN*0`@*&AI97(I`"#@(`"KH"5SH+L@
M;B=E<W0@<&%S('5N(&1O<W-I97(`JZ`E<Z"[(&XG97-T('!A<R!U;B!C:&]I
M>"!V86QI9&4N`*N@)7.@NR!N)V5S="!P87,@8V]N9FEG=7+I(&1A;G,@;&4@
M<F5G:7-T<F4@9&4@2&]R9&4N`$PG:6YT97)P<NET975R(&0G87)B<F4@JZ`E
M<Z"[(&XG82!P87,@Z73I('1R;W5VZ2X`JZ`E<Z"[(&$@Z73I(&%J;W5TZ2!A
M=2!S>7-TZ&UE(&1E<R!G<F]U<&5S+@"KH"5SH+L@82#I=.D@86IO=73I(&%U
M('-Y<W3H;64@9&5S('!E<FUI<W-I;VYS+@"KH"5SH+L@;B=A('!A<R#I=.D@
M8W+IZ:`Z("5S+@`E+C)FH$UO('5T:6QI<^ES('-U<B`E+C)FH$UO('!E<FUI
M<R`H)2XR9J`E)2D`)60@)7,@970@)7,`)60@:F]U<G,@879A;G0@;"=E>'!I
M<F%T:6]N(&1E('9O=')E(&UO="!D92!P87-S92X`)60M<'+I=FES:6]N(&1U
M(&IO=7(`)7,@+2!.;W1I8V4`16UP<F5I;G1E(%!'4"!D92`E<P`E<Z!+;P`E
M<R!O<.ER871I;VYS(&1E(&UA:6YT96YA;F-E("9N9&%S:#L@0V]N9FER;6%T
M:6]N`$-O;F9I9W5R871I;VX@)7,`26YS8W)I<'1I;VX@9&4@)7,`0V]N9&ET
M:6]N<R!D)W5T:6QI<V%T:6]N(&1E("5S`"5S(&5X:7-T92!DZ6K@+@`@)7.@
MX"`E<R`E<P`E<R!E<W0@<'+J="#@(&5F9F5C='5E<B!L97,@;W#I<F%T:6]N
M<R!D92!M86EN=&5N86YC92!C;V-HZ65S(&-I+61E<W-O=7,N(%/I;&5C=&EO
M;FYE>B!L82!O=2!L97,@;W#I<F%T:6]N*',I('%U92!V;W5S('9O=6QE>B!E
M9F9E8W1U97(@8V5T=&4@9F]I<RUC:2X`)7,@97-T(&]B;&EG871O:7)E`"5S
M(&UI;G5T97,`)7,@;F]N('1R;W5VZ0`E<Z#@("5S(&1E("5S`$-A<FYE="!D
M)V%D<F5S<V5S(&1E("5S`$%G96YD82!D92`E<P!";&]C+6YO=&5S(&1E("5S
M`$QI<W1E(&1E('3B8VAE<R!D92`E<P`E<Z`Z("5S`"5SH#H@;"?I;65T=&5U
M<B!D92!C92!M97-S86=E(&$@<'4@ZG1R92!F86QS:69IZ2X@071T96YT:6]N
M(&5N('-U:79A;G0@;&5S(&QI96YS('%U)VEL(&-O;G1I96YT(&]U(&5N(&9O
M=7)N:7-S86YT(&1E<R!I;F9O<FUA=&EO;G,@<&5R<V]N;F5L;&5S(.`@;"?I
M;65T=&5U<BX`+"!E;B!R869A;&4@`')A9F%L92`E<R`E<P!V87)I86)L92!D
M=2`E<R!A=2`E<P`M+2!3Z6QE8W1I;VYN97(@+2T`1F]R;6%T(#$R(&AE=7)E
M<P!&;W)M870@,C0@:&5U<F5S`#(T(&AE=7)E<P`\4'+I8^ED96YT`%5N92!B
M87-E(&1E(&1O;F[I97,@<')I;F-I<&%L92`H8F%C:V5N9"D@97-T(&[I8V5S
M<V%I<F4@<&]U<B!C92!B;&]C`%5N92!E<G)E=7(@9F%T86QE(',G97-T('!R
M;V1U:71E`%5N92!C;&5F('!U8FQI<75E(%!'4"!E<W0@;NEC97-S86ER92!P
M;W5R(&-H:69F<F5R('5N(&UE<W-A9V4N`%5N92!C;&5F('!U8FQI<75E(%!'
M4"!E<W0@;NEC97-S86ER92!P;W5R(';I<FEF:65R(&QA('-I9VYA='5R92!D
M)W5N(&UE<W-A9V4N`%5N92!C;&5F('!U8FQI<75E(%!'4"P@=6YE(&-L968@
M<')I=NEE(%!'4"P@970@=6YE('!H<F%S92!S96-RZ'1E('-O;G0@;NEC97-S
M86ER97,@<&]U<B!DZ6-H:69F<F5R('5N(&UE<W-A9V4N`%5N92!C;&5F('!U
M8FQI<75E(%!'4"P@=6YE(&-L968@<')I=NEE(%!'4"P@970@=6YE('!H<F%S
M92!S96-RZ'1E('-O;G0@;NEC97-S86ER97,@<&]U<B!S:6=N97(@=6X@;65S
M<V%G92X`56YE(&-L968@<'5B;&EQ=64@4R]-24U%+"!U;F4@8VQE9B!P<FEV
MZ64@4R]-24U%+"!E="!U;F4@<&AR87-E('-E8W+H=&4@<V]N="!NZ6-E<W-A
M:7)E<R!P;W5R(&3I8VAI9F9R97(@=6X@;65S<V%G92X`56YE(&-L968@<'5B
M;&EQ=64@4R]-24U%+"!U;F4@8VQE9B!P<FEVZ64@4R]-24U%+"!E="!U;F4@
M<&AR87-E('-E8W+H=&4@<V]N="!NZ6-E<W-A:7)E<R!P;W5R('-I9VYE<B!U
M;B!M97-S86=E+@!5;F4@8VQE9B!P=6)L:7%U92!3+TU)344@97-T(&[I8V5S
M<V%I<F4@<&]U<B!C:&EF9G)E<B!U;B!M97-S86=E+@!.=6%G97,@;&4@;6%T
M:6X`4&QU:64@;.EGZ')E(&QE(&UA=&EN`%!L=6EE(&QE(&UA=&EN`$%V97)S
M97,@;&4@;6%T:6X`0VAU=&5S(&1E(&YE:6=E(&QE(&UA=&EN`$%-+U!-`$%0
M22!)1`#`('!R;W!O<R!D92!C970@Z61I=&5U<@#`('!R;W!O<RXN+@!"87,@
M86)S;VQU`$UI;&EE=2!A8G-O;'4`06-CZ',@<F5F=7/I(&QO<G,@9&4@;&$@
M8W+I871I;VX@9&4@<NEP97)T;VER92!61E,@+@!!8V/H<R!R969U<^D@;&]R
M<R!D92!L82!C<NEA=&EO;B!D92!F:6-H:65R(%9&4RX`1&]N;NEE<R!P97)S
M;VYN96QL97,`36]T(&1E('!A<W-E(&1U(&-O;7!T90!#;VUP=&4@:6YA8W1I
M9@!#;VUP=&5S`$%J;W5T97(`06IO=71E<B!U;B!S;W5S+6=R;W5P90!!:F]U
M=&5R('5N92!N;W5V96QL92!S;W5S+7!E<FUI<W-I;VX`06IO=71E<B!I8VF@
M.@!!:F]U=&5R('5N(&YO=79E874@9W)O=7!E`$%J;W5T97(@=6YE(&YO=79E
M;&QE('!E<FUI<W-I;VX`06IO=71E<B!U;B!G<F]U<&4@9FEL<R#@(*N@)7.@
MNP!!:F]U=&5R('5N92!P97)M:7-S:6]N(&9I;&QE(.`@JZ`E<Z"[`$%J;W5T
M97(@=6X@;F]U=F5L('5T:6QI<V%T975RH#H`06IO=71E<B!U;F4@8V]L;VYN
M90!!:F]U=&5R(&1E(&YO=79E875X(&UE;6)R97,`06IO=71E<B!U;F4@<&%I
M<F4`06IO=71E<B!L92!M96YU("5S(.`@;&$@8F%R<F4@9&4@36]Z:6QL80!!
M:F]U=&5R(&%U(&-A<FYE="!D)V%D<F5S<V5SH#H`06IO=71E<B#@(&UO;B!C
M87)N970@9"=A9')E<W-E<P!!:F]U=&5R('5N('5T:6QI<V%T975R`*N@)7.@
MNR!A(.ETZ2!A:F]U=.D@874@<WES=.AM92P@;6%I<R!L)V%J;W5T(&0G:6YF
M;W)M871I;VX@<W5P<&SI;65N=&%I<F5S("5S(&XG97-T('!A<R!P;W-S:6)L
M92X`JZ`E<Z"[(&$@Z73I(&%J;W5TZ2X@5F]U<R!P;W5V97H@=F]U<R!C;VYN
M96-T97(N`$QA(&9O;F-T:6]N(&0G86IO=70@9"=U=&EL:7-A=&5U<G,@97-T
M(&3I<V%C=&EVZ64N`$%D<F5S<V4`0V%R;F5T(&0G861R97-S97,`061M:6YI
M<W1R871E=7(@+2!A:G5S=&5R(&QE<R!P97)M:7-S:6]N<R!P;W5R(&0G875T
M<F5S('5T:6QI<V%T975R<P!!9&UI;FES=')A=&EO;@!0=6)S`$%F9VAA;FES
M=&%N`$%L8F%N:64`06QGZ7)I90!!;&EA<P!!;&EG;F5R`$%L:6=N96UE;G2@
M.@!4;W5T`%1O=7,@;&5S('!A<G1I8VEP86YT<R!A=71H96YT:69IZ7,`5&]U
M<R!L97,@9W)O=7!E<P!4;W5T97,@;&5S('!E<FUI<W-I;VYS`$QE<R!Q=6%T
M<F4@8_1TZ7,`4&5R;65T=')E(&1E<R!A9')E<W-E<R!D92!C;W5R<FEE;"!M
M=6QT:7!L97,`075T;W)I<V5R(&QA(&UI<V4@96X@<&QA8V4@9&4@;&ES=&5S
M(&YU;>ER;W3I97.@/P!%>&ES=&4@9.EJX`!.;VT@9"=U=&EL:7-A=&5U<B!)
M35-0(&%L=&5R;F%T:68`36]T(&1E('!A<W-E($E-4U`@86QT97)N871I9@!.
M;VT@9"=U=&EL:7-A=&5U<B!)35-0(&%L=&5R;F%T:68`061R97-S92!D92!C
M;W5R<FEE;"!A;'1E<FYA=&EV90!!=71R97,@;6]DZ&QE<P!497AT92!A;'1E
M<FYA=&EFH#H`4V%M;V$@06WI<FEC86EN`%5N92!V86QE=7(@:6QLZ6=A;&4@
M82#I=.D@<W#I8VEF:>EE+@!5;F4@97)R975R(&EN8V]N;G5E(',G97-T('!R
M;V1U:71E+@!!;F1O<G)E`$%N9V]L80!!;F=U:6QL80!0<F]X>2!A;F]N>6UE
M`%+I<&]N<V4`06YT87)C=&EQ=64`06YT:6=U82UE="U"87)B=61A`$%P<&QI
M8V%T:6]N`$QI<W1E(&0G87!P;&EC871I;VYS`$PG87!P;&EC871I;VX@97-T
M('!RZG1E`$%P<&QI<75E<B!A=7@@<&%R=&%G97,@9FEL<P!!<'!R;W5VZ0!4
M86EL;&4@87!P<F]X:6UA=&EV90!!=G)I;`!!<F%B92`H5VEN9&]W<RTQ,C4V
M*0!486EL;&4@9'4@9FEC:&EE<B!A<F-H:79E`$YO;2!D92!L)V%R8VAI=F4`
MRG1E<RUV;W5S(&-E<G1A:6X@9&4@=F]U;&]I<B!S=7!P<FEM97(@8V5T=&4@
M<F5Q=>IT92!D)VEN<V-R:7!T:6]N("!P;W5R("5SH#\`RG1E<RUV;W5S(&-E
M<G1A:6X@9&4@=F]U;&]I<B!E9F9A8V5R(*N@)7.@NR!E="!S97,@<V]U<RUG
M<F]U<&5SH#\`07)G96YT:6YE`$%R;>EN:64`07)MZ6YI96X@*$%235-#24DM
M."D`07)T`$%R=6)A`$%S8V5N<VEO;B`HSFQE*0!!<G0@05-#24D`4NEG:6]N
M($%S:64O4&%C:69I<75E`$1E;6%N9&5R('5N92!C;VYF:7)M871I;VX@879A
M;G0@9&4@;&%N8V5R(&QE<R!O<.ER871I;VYS(&1E(&UA:6YT96YA;F-EH#\`
M0V]L;VYN97,@9&5S('3B8VAE<P!496YT871I=F4@9"=E9F9A8V5M96YT(&0G
M=6X@9W)O=7!E(&EN97AI<W1A;G0N`%1E;G1A=&EV92`@9"=E9F9A8V5M96YT
M(&0G=6YE('!E<FUI<W-I;VX@:6YE>&ES=&%N=&4N`%1E;G1A=&EV92!D92!M
M;V1I9FEC871I;VX@9"=U;F4@<&5R;6ES<VEO;B!I;F5X:7-T86YT92X`5&5N
M=&%T:79E(&1E(&UO9&EF:6-A=&EO;B!D)W5N('!A<G1A9V4@:6YE>&ES=&%N
M="X`4')O<')IZ73I<P!!;_MT`$%U<W1R86QI90!!=71R:6-H90!!=71H7V-Y
M<G5SH#H@17AT96YS:6]N(')E<75I<V4@24U!4"!N;VX@=')O=7;I92X`075T
M:%]C>7)U<Z`Z(&QE(&)A8VME;F0@;B=A('!A<R!L97,@8V%P86-I=.ES(')E
M<75I<V5S+@!!=71H7V-Y<G5SH#H@97AT96YS:6]N(')E<75I<V4@24U!4"!N
M;VX@=')O=7;I90!!=71H7V9T<*`Z(&5X=&5N<VEO;B!R97%U:7-E($944"!N
M;VX@=')O=7;I92X@26P@9F%U="!C;VUP:6QE<B!02%`@879E8R!L)V]P=&EO
M;B`M+65N86)L92UF='`N`$%U=&A?:6UA<*`Z(&5X=&5N<VEO;B!R97%U:7-E
M($E-05`@;F]N('1R;W5VZ64N`$%U=&A?:W)B-:`Z(&5X=&5N<VEO;B!R97%U
M:7-E(&MR8C4@;F]N('1R;W5VZ64N`$%U=&A?;&1A<*`Z(&PG86IO=70@9"=U
M=&EL:7-A=&5U<G,@;B=E<W0@<&%S('-U<'!O<G3I(&%V96,@06-T:79E($1I
M<F5C=&]R>0!!=71H7VQD87"@.B!L92!R971R86ET(&0G=71I;&ES871E=7)S
M(&XG97-T('!A<R!S=7!P;W)TZ2!A=F5C($%C=&EV92!$:7)E8W1O<GD`075T
M:%]L9&%PH#H@97AT96YS:6]N(')E<75I<V4@3$1!4"!N;VX@=')O=7;I92X`
M075T:%]L9&%PH#H@:6UP;W-S:6)L92!D)V%J;W5T97(@;"=U=&EL:7-A=&5U
M<B`E<RX@0V5C:2!E<W0@;&$@<NEP;VYS92!D=2!S97)V975RH#H@`$%U=&A?
M;&1A<*`Z(&EM<&]S<VEB;&4@9&4@<W5P<')I;65R(&PG=71I;&ES871E=7(@
M)7,`075T:%]L9&%PH#H@;6]D:69I8V%T:6]N(&EM<&]S<VEB;&4@9&4@;"=U
M=&EL:7-A=&5U<B`E<P!!=71H7VQD87"@.B!L82!M;V1I9FEC871I;VX@9&5S
M('5T:6QI<V%T975R<R!N)V5S="!P87,@<W5P<&]R=.EE(&%V96,@06-T:79E
M($1I<F5C=&]R>2X`075T:%]M8V%LH#H@97AT96YS:6]N(')E<75I<V4@34-!
M3"!N;VX@=')O=7;I92X`075T:%]S;6)A=71HH#H@97AT96YS:6]N(')E<75I
M<V4@<VUB875T:"!N;VX@=')O=7;I92X`R6-H96,@9&4@;"=A=71H96YT:69I
M8V%T:6]N(&%U('-E<G9E=7(@24U!4"X`R6-H96,@9&4@;"=A=71H96YT:69I
M8V%T:6]N`,EC:&5C(&1E(&PG875T:&5N=&EF:6-A=&EO;B`E<P!,92!S97)V
M975R(%)!1$E54R!A(')E:F5TZ2!L)V%U=&AE;G1I9FEC871I;VXN`,EC:&5C
M(&1E(&PG875T:&5N=&EF:6-A=&EO;B!A=2!S97)V975R($944"X`R6-H96,@
M9&4@;"=A=71H96YT:69I8V%T:6]N(&%U('-E<G9E=7(@4TU"+@!#:&%M<',@
M9&ES<&]N:6)L97.@.@!!>F5R8F'O9&IA;@!%>&-U<V5S($)/1D@`0V]U;&5U
M<B!D92!F;VYD`$-O=6QE=7(@9&4@9F]N9`!-;W0@9&4@<&%S<V4@2V5R8F5R
M;W,@97)R;V[I+@!.;VT@9&4@8V]N;F5X:6]N($ME<F)E<F]S(&5R<F]NZ2X`
M0F%H86UA<P!"86AR9>]N`$)A;'1E("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S
M:`!"87)B861E`%+I<&5R=&]I<F4@9&5S(&=R87!H:7%U97,@JZ`E<Z"[(&YO
M;B!T<F]U=NDN`$QI9VYE(&1E(&)A<V4`0NEL87)U<P!"96QG:7%U90!"96QI
M>F4`0NEN:6X`0F5R;75D97,`0FAO=71A;@!!;FYI=F5R<V%I<F4`0FQO8R"K
M)7,@NR!D92!L)V%P<&QI8V%T:6]N(*N@)7.@NR!I;F-O;FYU`%!RZ6;I<F5N
M8V5S(&1E(&)L;V,`5'EP92!D92!B;&]C`$=R87,`0F]L:79I90!3:6=N971S
M`$)O<F1U<F4`R7!A:7-S975R(&1E(&QA(&)O<F1U<F6@.@!";W)D<P!";W-N
M:64M2&5R>NEG;W9I;F4`3&5S(&1E=7@`0F]T<W=A;F$`0F%S`$)O=79E=`!"
M<NES:6P`5&5R<FET;VER97,@8G)I=&%N;FEQ=65S(&1E(&PG3V/I86X@26YD
M:65N`%-U;'1A;F%T(&1U($)R=6[I:0!"=6QG87)I90!,:7-T92#@('!U8V5S
M`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$=E<W1I;VX@9&4@8V]N=&5N=0!#4D,`
M1&ES=')I8G5T:6]N(&1E<R!P;VEN=',@3%)#("A,:7-T92!D92!RZ79O8V%T
M:6]N(&1E<R!C97)T:69I8V%T<RD`4')O<')IZ73I<R!D92!L82!#7V5L;'5L
M90!,)VEN:71I86QI<V%T:6]N(&1U(&-A8VAE(&YE(',G97-T('!A<R!T97)M
M:6[I92X`06=E;F1A`$-A;&UE`$-A;6)O9&=E`$-A;65R;W5N`$EM<&]S<VEB
M;&4@9&4@<NEI;FET:6%L:7-E<B!L92!M;W0@9&4@<&%S<V4@875T;VUA=&EQ
M=65M96YT+"!C;VYT86-T97H@=F]T<F4@861M:6YI<W1R871E=7(@<WES=.AM
M92X`26UP;W-S:6)L92!D92!S=7!P<FEM97(@;&4@9FEC:&EE<B"KH"5SH+LN
M`$EM<&]S<VEB;&4@9"=A9&UI;FES=')E<B!D97,@9V5S=&EO;FYA:7)E<R!D
M92!S97-S:6]N(&5X=&5R;F5S+@#)8VAE8R!D92!L82!C;VYN97AI;VX@874@
M<V5R=F5U<B!)34%0H#H@)7,`26UP;W-S:6)L92!D)V]U=G)I<B!L92!F:6-H
M:65R(*N@)7.@NRX`0V%N861A`$%N;G5L97(`06YN=6QE<B!L92!R87!P;W)T
M(&1U('!R;V)LZ&UE`$EM<&]S<VEB;&4@9&4@<W5P<')I;65R(&QE(&9I8VAI
M97(@JZ`E<Z"[+@!);7!O<W-I8FQE(&1E('1R;W5V97(@=6X@<NEP97)T;VER
M92!T96UP;W)A:7)E`$EM<&]S<VEB;&4@9&4@<')O8^ED97(@<V%N<R!L92!P
M87)A;>AT<F4@JR!T87)G971&:6QE(+L`26UP;W-S:6)L92!D92!S=7!P<FEM
M97(@;&4@<NEP97)T;VER92"KH"5SH+LN`%-U<'!R97-S:6]N(&EM<&]S<VEB
M;&4L(&EL('D@82`E9"!E;G)E9VES=')E;65N=',@9FEL<RX`26UP;W-S:6)L
M92!D92!RZ6]R9&]N;F5R+"!L92!N;VUB<F4@9"?I;.EM96YT<R#@('+I;W)D
M;VYN97(@;F4@8V]R<F5S<&]N9"!P87,@874@;F]M8G)E(&0GZ6SI;65N=',@
M96YR96=I<W1RZ7,N`$YE('!E=70@9&ER:6=E<B!L92!M97-S86=E('9E<G,@
M;&4@;F]M8G)E('-PZ6-I9FGI+@!#87`M5F5R=`!,Z6=E;F1E`%1R86YS<&]R
M=&5U<@!#873I9V]R:65S(&5T(,ET:7%U971T97,`SFQE<R!#8>]M86X`5.EL
MZ7!H;VYE(&-E;&QU;&%I<F4`4')O<')IZ73I<R!D92!L82!C96QL=6QE`%)E
M;7!L:7-S86=E(&%U=&]U<B!D92!L82!C96QL=6QEH#H`4')O<')IZ73I<R!D
M92!L82!C96QL=6QE`$5S<&%C96UE;G0@9&4@;&$@8V5L;'5L9:`Z`%3I;.EP
M:&]N92!C96QL=6QA:7)E(`!#96QT92`H25-/+3@X-3DM,30I`$-E;G1R97(`
M4NEP=6)L:7%U92!C96YT<F%F<FEC86EN90!%=7)O<.EE;B!C96YT<F%L("A)
M4T\M.#@U.2TR*0!$Z71A:6QS(&1U(&-E<G1I9FEC870`4')O<')IZ71A:7)E
M(&1U(&-E<G1I9FEC870`4&]L:71I<75E(&1E(&-E<G1I9FEC871I;VX`5&-H
M860`36]D:69I97(`36]D:69I97(@=F]T<F4@;6]T(&1E('!A<W-E`$-H86YG
M97(@;&4@;F]M+"!L)V%D<F5S<V4@970@;&$@<VEG;F%T=7)E('%U92!L97,@
M<&5R<V]N;F5S('9O:65N="!Q=6%N9"!E;&QE<R!L:7-E;G0@970@<NEP;VYD
M96YT(.`@=F]S(&UE<W-A9V5S+@!,82!M;V1I9FEC871I;VX@9&4@=F]T<F4@
M;6]T(&1E('!A<W-E(&XG97-T('!A<R!S=7!P;W)TZ64@879E8R!L82!C;VYF
M:6=U<F%T:6]N(&%C='5E;&QE+B!#;VYT86-T97H@=F]T<F4@861M:6YI<W1R
M871E=7(N`$-H87(`5NE?<FEF:65R(&QE(&QI96X`0VAI;&D`0VAI;F4`0VAI
M;F]I<R!S:6UP;&EF:>D@*$=",C,Q,BD`0VAI;F]I<R!T<F%D:71I;VYN96P@
M*$)I9S4I`$-H;VES:7(@;"=A<'!L:6-A=&EO;J`Z`$-H;VES:7(@=6X@;6]T
M(&1E('!A<W-E`$-H;VES:7(@=6X@;F]M(&1E(&-O;FYE>&EO;@!#:&]I<VER
M(&QE(&UO9&4@9"=A9F9I8VAA9V4@9&5S(&1A=&5SH#H`0VAO:7-I<B!L92!S
M='EL92!D92!L:7-T92`H<&]U<B!L97,@;&ES=&5S(&YU;>ER:7%U97,I`,YL
M97,@0VAR:7-T;6%S`$3I9FEN:71I;VX@9&4@;&$@8VQA<W-E(&1E("5S(&YO
M;B!T<F]U=NEE+@!%9F9A8V5R`$YE='1O>65R(&QE<R!B86QI<V5S($U3+4]F
M9FEC90!%9F9A8V5R(&QA(')E<77J=&4`4F5T:7)E<B!L)W5T:6QI<V%T975R
M.B`E<P!%9F9A8V5R(&PG=71I;&ES871E=7(`169F86-E<B!L97,@9&]N;NEE
M<R!D92!L)W5T:6QI<V%T975R`,EC;&%I<F-I97,@=&%R9"!D86YS(&QA(&IO
M=7)NZ64`0VQI<75E<B!P;W5R('!O=7)S=6EV<F4`0VQI8VMA=&5L;"!V:6$@
M2%144`!&97)M97(@;&$@9F5NZG1R90!.=6%G97,`3G5A9V5S(&UA=&EN875X
M`$YU86=E=7@`SFQE<R!#;V-O<P!297!L:65R(&QA(&)A<G)E(&1E(&/T=.D`
M4NED=6ER92!L97,@8F]R9',`0V]L;VUB:64`0V]U;&5U<@!086QE='1E(&1E
M(&-O=6QE=7)S`%/I;&5C=&EO;B!D)W5N92!C;W5L975R`$-O;'.@.@!4:71R
M97,@9&4@8V]L;VYN90!"+D0N`$-O;6UA;F1E`$-O;6UA;F1E('-H96QL`$-O
M;6UE;G1A:7)E`$YO;2!U<W5E;`!#;VUO<F5S`%-O8VGI=.D`3W)D:6YA=&5U
M<G,`0V]N9&ET:6]N`$-O;F1I=&EO;G,`1&EF9NER96YC97,@9&4@8V]N9FEG
M=7)A=&EO;@!3>6YC:')O;FES871I;VX@9&5S(&%S<VES=&%N=',@<&5R<V]N
M;F5L<RP@/$D^<VUA<G1P:&]N97,\+TD^(&5T($]U=&QO;VLN`$QA(&-O;F9I
M9W5R871I;VX@;B=E<W0@<&%S(.`@:F]U<BX`0V]N9FEG=7)E<B`E<P!#;VYF
M:7)M97(@;&4@;6]T(&1E('!A<W-E`$-O;F=O`%+I<'5B;&EQ=64@9.EM;V-R
M871I<75E(&1U($-O;F=O`,EC:&5C(&1E(&QA(&-O;FYE>&EO;@#)8VAE8R!D
M92!L82!C;VYN97AI;VZ@.B``0V]N;F5X:6]N(&%U('-E<G9E=7(@9&4@8VQE
M9G,@<'5B;&EC(')E9G5SZ64N`$-O;FYE>&EO;B!A=2!S97)V975R(&1E(&-L
M969S('!U8FQI8R!R969U<^EE+B!286ES;VZ@.B`@)7,@*"5S*0#)8VAE8R!D
M92!L82!C;VYN97AI;VX@874@<V5R=F5U<B!&5%``0V]N=&%C=',`0V5S(&-O
M;G1A8W1S(&]N="!B:65N(.ETZ2!A:F]U=.ES(.`@=F]T<F4@8V%R;F5T(&0G
M861R97-S97,N`%1Y<&4@9&4@8V]N=&5N=2!D=2!F:6-H:65R(&-O;7!R97-S
MZ:`Z(`!#;VYT96YU(&1E(*N@)7.@NP!0;W5R<W5I=G)E`,YL97,@0V]O:P!4
MZ6UO:6X@*&-O;VMI92D`0V]P:65R`,EC:&5C(&1E(&QA(&-O<&EEH#H@)7,`
M4^EL96-T:6]N(&0G=6YE(&-O<&EE`$ED+B!C;_MT`$-O<W1A(%)I8V$`0_1T
M92!D)TEV;VER90!);7!O<W-I8FQE(&1E(&-H:69F<F5R(&QE(&UE<W-A9V6@
M.B``4VEG;F%T=7)E(%!'4"!D=2!M97-S86=E(&EM<&]S<VEB;&6@.B``26UP
M;W-S:6)L92!D92!C:&EF9G)E<B!L92!M97-S86=E(&%V96,@4R]-24U%+@!3
M:6=N871U<F4@4R]-24U%(&1U(&UE<W-A9V4@:6UP;W-S:6)L92X`06IO=70@
M9'4@8V]N=&%C="`E<R!I;7!O<W-I8FQE+B``3F4@<&5U="!S92!C;VYN96-T
M97(@874@<V5R=F5U<B!,1$%0+@!6Z7)I9FEC871I;VX@9&4@;&$@8F%L86YC
M92`E<R!I;7!O<W-I8FQE+B``R6-H96,@9&4@;&$@8V]N;F5X:6]N(&%U('-E
M<G9E=7(@3$1!4"X`R6-H96,@9&4@;&$@8V]N;F5X:6]N(&%U('-E<G9E=7(@
MJZ`E<Z"[('9I82!&5%"@.B`E<P!#<NEA=&EO;B!D92!L:7-T92!D92!D:7-T
M<FEB=71I;VX@:6UP;W-S:6)L92X@)7,`26UP;W-S:6)L92!D92!DZ6-H:69F
M<F5R(&QE<R!D;VYNZ65S(%!'4*`Z(`!);7!O<W-I8FQE(&1E(&3I8VAI9F9R
M97(@;&5S(&1O;F[I97,@4R]-24U%+@!.92!P975T('!A<R!S=7!P<FEM97(@
M;&4@8V]N=&%C="`E<P!.92!P975T('!A<R!S=7!P<FEM97(@;&$@;&ES=&4@
M9&4@9&ES=')I8G5T:6]N("5S`$YE('!E=70@<&%S('-U<'!R:6UE<B!L92!S
M8W)I<'0@9&4@;6ES92#@(&IO=7(@JZ`E<Z"[+@!$Z71E<FUI;F%T:6]N(&1E
M(&PG861R97-S92!D=2!D97-T:6YA=&%I<F4@:6UP;W-S:6)L92X`3F4@<&5U
M="!RZ6-U<.ER97(@=&]U="!L92!C87)N970@9"=A9')E<W-E+@!.92!P975T
M('+I8W5PZ7)E<B!T;W5T92!L82!L:7-T92!D92!D:7-T<FEB=71I;VXN`$XG
M82!P87,@<'4@<NEC=7#I<F5R(&QA(&QI<W1E(&-O;7!LZ'1E(&1E(&QI<W1E
M<R!D92!D:7-T<FEB=71I;VXN`$EM<&]S<VEB;&4@9&4@8VAA<F=E<B!L82!S
M=')A=.EG:64@JZ`E<Z"[+@!);7!O<W-I8FQE(&1E(&-RZ65R(&QE('+I<&5R
M=&]I<F4@JZ`E<Z"[+@!);7!O<W-I8FQE(&0G;V)T96YI<B!L82!C;&5F('!U
M8FQI<75E(.`@<&%R=&ER(&1U('-E<G9E=7(@9&4@8VQE9G,N`$]U=F5R='5R
M92!D92"KH"5SH+L@:6UP;W-S:6)L92!E;B#I8W)I='5R92X`3W5V97)T=7)E
M(&1E("5S(&EM<&]S<VEB;&4N`$EM<&]S<VEB;&4@9"=O=79R:7(@;&4@;6]D
M=6QE($UA:6YT96YA;F-E7U1A<VL@)7,`3W5V97)T=7)E(&1U(&1O<W-I97(@
MJZ`E<Z"[(&EM<&]S<VEB;&4N`$EM<&]S<VEB;&4@9"=A='1E:6YD<F4@;&4@
M<V5R=F5U<B!,1$%0+@!,96-T=7)E(&1E("5S(&EM<&]S<VEB;&4N(`!.)V$@
M<'4@<F5M971T<F4@X"!ZZ7)O(&QE(&UO="!D92!P87-S92!P;W5R(&PG=71I
M;&ES871E=7(@9&5M86YDZ2X@0V5R=&%I;G,@*&]U('1O=7,I(&QE<R!DZ71A
M:6QS(&YE('-O;G0@<&%S(&-O<G)E8W1S+B!2Z65S<V%Y97H@;W4@8V]N=&%C
M=&5Z('9O=')E(&%D;6EN:7-T<F%T975R('!O=7(@9&4@;"=A:61E+@!2Z6-U
M<.ER871I;VX@9&5S($%#3"!I;7!O<W-I8FQE`$YE('!E=70@<NEC=7#I<F5R
M(&QE(&-A<FYE="!D)V%D<F5S<V5S+B`E<P!.92!P975T('+I8W5PZ7)E<B!L
M82!L:7-T92!D92!D:7-T<FEB=71I;VXN("5S`$YE('!E=70@<NEC=7#I<F5R
M(&QE<R!L:7-T97,@9&4@9&ES=')I8G5T:6]N+B`E<P!.92!P975T('+I8W5P
MZ7)E<B!L97,@<&]S<VEB:6QI=.ES(&1U('-E<G9E=7(`3F4@<&5U="!P87,@
M<F5V96YI<B#@(&QA(&-O;F9I9W5R871I;VX@<'+I8^ED96YT92X`169F86-E
M;65N="!D=2!D;W-S:65R(*N@)7.@NR!I;7!O<W-I8FQE+B``3F4@<&5U="!P
M87,@96YR96=I<W1R97(@;&$@8V]N9FEG=7)A=&EO;B`E<P!.92!P975T('!A
M<R!E;G)E9VES=')E<B!U;F4@<V%U=F5G87)D92!D92!L82!C;VYF:6=U<F%T
M:6]N+@!);7!O<W-I8FQE(&0G96YR96=I<W1R97(@=6YE(&-O<&EE(&1E(&QA
M(&-O;F9I9W5R871I;VZ@.B`E<P!);7!O<W-I8FQE(&0G96YR96=I<W1R97(@
M;&4@<V-R:7!T(&1E(&UI<V4@X"!J;W5R(&1A;G.@.B"KH"5SH+LN`$EM<&]S
M<VEB;&4@9"=E;G)E9VES=')E<B!U;F4@8V]P:64@9'4@9FEC:&EE<B!D92!C
M;VYF:6=U<F%T:6]N("5S+@!);7!O<W-I8FQE(&0G96YR96=I<W1R97(@;&4@
M9FEC:&EE<B!D92!C;VYF:6=U<F%T:6]N("5S+B!6;W5S('!O=79E>B!S;VET
M('5T:6QI<V5R('5N92!D97,@;W!T:6]N<R!P;W5R('-A=79E<B!L92!C;V1E
M('-U<B`E<R!S;VET(&-O<&EE<B!M86YU96QL96UE;G0@;&4@8V]D92!C:2UD
M97-S;W5S(&1A;G,@)7,N`$YE('!E=70@<&%S(')E8VAE<F-H97(@;&4@<V5R
M=F5U<B!,1$%0+@!3=7!P<F5S<VEO;B!D92"KH"5SH+L@:6UP;W-S:6)L92X`
M36ES92#@(&IO=7(@9'4@8V]N=&%C="!I;7!O<W-I8FQE+B`E<P!.92!P975T
M(&UE='1R92#@(&IO=7(@;&$@;&ES=&4@9&4@9&ES=')I8G5T:6]N+B`E<P!.
M92!P975T('!A<R!E;G)E9VES=')E<B!L82!C;VYF:6=U<F%T:6]N('!O=7(@
MJZ`E<Z"[H#H@)7,`3F4@<&5U="!T<F]U=F5R(&QA(&)A<G)E(&1E($UO>FEL
M;&$N("!!<W-U<F5Z+79O=7,@<74G96QL92!E<W0@86-T:79E+@!.92!P975T
M(&%T=')I8G5E<B!C97,@9')O:71S(.`@;"=U=&EL:7-A=&5U<B"KH"5SH+L@
M('-U<B!L92!D;W-S:65R(*N@)7.@NZ`Z("5S`%1E>'1E(&-O;7!TZ0!087ES
M`$-O=7)S`$-RZ65R`$-RZ65R('5N(&QI96X`0W+I97(@=6X@;F]U=F5A=0!#
M<NEE<B!U;B!S;W5S+61O<W-I97(`4&5R;6ES<VEO;G,@1&4@0W+I871E=7(`
M3G5MZ7)O(&1E(&-A<G1E(&1E(&-RZ61I=`!#<F]A=&EE`$-U8F$`-"!P:&%S
M97,@8V]U<F%N=&5S`%-E<W-I;VYS(&5N(&-O=7)S`$AE=7)E(&%C='5E;&QE
M`$PG861R97-S92!54DP@86-T=65L;&4@97-T`%5T:6QI<V%T975R<R!A8W1U
M96QS`$]B<V5R=F%T:6]N<R!A8W1U96QL97,`0V]N9&ET:6]N(&%C='5E;&QE
MH#H@`%-T>6QE(&-O=7)A;G0`1.EF:6YI<B!L97,@=.)C:&5S(.`@969F96-T
M=65R(&QO<G,@9&4@;&$@8V]N;F5X:6]N(.`@)7,N`$-O=7!E<@!#;W5P97(@
M;&$@<^EL96-T:6]N`$-H>7!R90!#>7)I;&QI<75E("A+3TDX+5(I`$-Y<FEL
M;&EQ=64@*%=I;F1O=W,M,3(U,2D`0WER:6QL:7%U92]5:W)A:6YI96X@*$M/
M23@M52D`4NEP=6)L:7%U92!48VCH<75E`$I*`$133B`H0V8N(&AT='`Z+R]P
M96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT
M<F\M9'-N+G!H<"D`0VAA<75E(&IO=7(`3F%V:6=A=&5U<B!D92!$871A5')E
M90!!;&EA<R!D92!L82!B87-E`$1A=&4`1&%T92!D92!RZ6-E<'1I;VX`4^EL
M96-T:6]N(&0G=6YE(&1A=&4`2F]U<@!3=7!P<FEM97(@7VQA(&-O;&]N;F4`
M1.EC96UB<F4`3F]M8G)E<R!DZ6-I;6%U>`!$:6UI;G5E<B!L)VEN9&5N=&%T
M:6]N`$3I9F%U=`!#;W5L975R('!A<B!DZ69A=70`261E;G1I=.D@<&%R(&3I
M9F%U=`!);G1E<G!RZ71E=7(@9&4@8V]M;6%N9&4@<&%R(&3I9F%U=`!$Z69I
M;FET:6]N<P!%9F9A8V5R`$5F9F%C97(@;&$@8V5L;'5L90!3=7!P<FEM97(@
M=6X@9W)O=7!E`$5F9F%C97(@;&$@=')A8V4`4W5P<')I;65R('5N92!P97)M
M:7-S:6]N`%-U<'!R:6UE<B!E="!P=7)G97(@;&5S(&UE<W-A9V5S`$5F9F%C
M97(@;&$@8V5L;'5L90!%9F9A8V5R(&QA(&-O;&]N;F4`4W5P<')I;65R('5N
M(&%U=')E(&UO9.AL92!E>&ES=&%N=`!3=7!P<FEM97(@;&5S(&UE<W-A9V5S
M`%-U<'!R:6UE<B!L97,@<&5R;6ES<VEO;G,@<&]U<B"KH"5SH+L`RG1E<RUV
M;W5S(&-E<G1A:6X@9&4@=F]U;&]I<B!E9F9A8V5R(*N@)7.@NR!E="!S97,@
M<V]U<RUP97)M:7-S:6]N<Z`_`$5F9F%C97(@;&$@<F%N9^EE`%-U<'!R:6UE
M<B!L)VED96YT:73I('/I;&5C=&EO;F[I90!3=7!P<FEM97(@=6X@<V]U<RUD
M;W-S:65R`$5F9F%C97(@;&$@8V]L;VYN92!A8W1U96QL90!%9F9A8V5R(&QA
M(')A;F?I92!A8W1U96QL90!38W)I<'0@9&4@8V]N9FEG=7)A=&EO;B!D92!M
M:7-E(.`@:F]U<B!S=7!P<FEMZ2"KH"5SH+LN`$AE=7)E(&1E(&QI=G)A:7-O
M;@!$86YE;6%R:P!$Z6-R:7)E(&QE('!R;V)LZ&UE`$1E<V-R:7!T:6]N`$3I
M=&%I;',@*&%U<W-I(&1A;G,@;&4@9FEC:&EE<B!D92!T<F%C97,@9&4@2&]R
M9&4IH#H`3&5S(&3I=&%I;',@;VYT(.ETZ2!C;VYS:6=NZ7,@<&]U<B!L)V%D
M;6EN:7-T<F%T975R+@!$Z79E;&]P<&5M96YT`%!O:6YT(&1E(')O<^EE`%!O
M:6YT(&1E(')O<^EE('!O=7(@;&$@9&5R;FGH<F4@:&5U<F6@.B``4&]I;G0@
M9&4@<F]SZ66@.B``1&4@9V%U8VAE(.`@9')O:71E`$1E(&1R;VET92#@(&=A
M=6-H90!2Z7!E<G1O:7)E`$%F9FEC:&5R('-U<B`R-"!H975R97.@/P!/<'1I
M;VYS(&0G869F:6-H86=E`$%F9FEC:&5R(&QA('!RZ79I<VEO;B!DZ71A:6QL
MZ64`069F:6-H97(@;&$@<'+I=FES:6]N("A4048I`$9O<FUA="!D)V%F9FEC
M:&%G90!!=FES(&1E(&QI=G)A:7-O;@!$:FEB;W5T:0!.92!P87,@<W5P<')I
M;65R`$YE('!A<R!A8V/I9&5R(&1I<F5C=&5M96YT(.`@;6%I;G1E;F%N8V4N
M<&AP`$QE('!R96UI97(@96YR96=I<W1R96UE;G0@8V]N=&EE;G0M:6P@;&4@
M;F]M(&1E<R!C:&%M<'.@/R!$86YS(&PG869F:7)M871I=F4L(&-O8VAE>B!C
M971T92!B;^YT9:`Z`$1O;6EN:7%U90!2Z7!U8FQI<75E(&1O;6EN:6-A:6YE
M`%9O=7,@;B=A=F5Z('!A<R!D92!C;VUP=&6@/R!%;G)E9VES=')E>BUV;W5S
M+@!4Z6SI8VAA<F=E<@!4Z6SI8VAA<F=E<B`E<P!4Z6SI8VAA<F=E<B!L82!C
M;VYF:6=U<F%T:6]N(&?I;NERZ64@8V]M;64@=6X@<V-R:7!T(%!(4`!,:7-T
M92!DZ7)O=6QA;G1E`$1R;V=U97,`0V]U<G)I97(@Z6QE8W1R;VYI<75E`%!I
M;&]T92!D92!P87-S97)E;&QE(&-O=7)R:65R("\@4TU3+"!P;W5R(&QE<R!F
M;W5R;FES<V5U<G,@9&4@8V4@<V5R=FEC92X`15)2`,EQ=6%T975R`$UO9&EF
M:65R`,ED:71E<B!L92!B;&]C`,ED:71E<B!U;B!G<F]U<&4`R61I=&5R('5N
M92!P97)M:7-S:6]N`,ED:71E<B!L97,@<&5R;6ES<VEO;G,`R61I=&5R(&QE
M<R!P97)M:7-S:6]N<R!P;W5R(*N@)7.@NP#)9&ET97(@;&5S(&]P=&EO;G,@
M<&]U<J`Z`,ED:71E<B!L97,@<&5R;6ES<VEO;G,@<&]U<B"KH"5SH+L`R61I
M=&5R(&QE<R!P97)M:7-S:6]N<R!P;W5R("5S`,ED=6-A=&EO;@#)9WEP=&4`
M4V%L=F%D;W(`R6SI;65N="XN+@!%;0!!9')E<W-E(.EL96-T<F]N:7%U90!!
M9')E<W-E(.EL96-T<F]N:7%U90!,97,@861R97-S97,@Z6QE8W1R;VYI<75E
M<R!D;VEV96YT(&-O<G)E<W!O;F1R92X`0V]U<G)I97(@879E8R!C;VYF:7)M
M871I;VX`4&%S<V5R96QL92!C;W5R<FEE<B`O(%--4P#);6]T:6/T;F5S`$UE
M<W-A9V4@=FED92X`4NES=6QT870@=FED92X`5&5R;65S(&1E(')E8VAE<F-H
M92!V:61E`$%C=&EV97(@;"=I;G-E<G1I;VX@9"=I;6%G97,@=F5N86YT(&1E
M<R!A;&)U;7,@<&AO=&]S(&1A;G,@;&4@=&5X=&6@/P!!8W1I=F5R(&QE(&UE
M;G4@8V]N=&5X='5E;"!A=F5C('5N(&-L:6,@9')O:72@/P!&:6X@9&4@;"=A
M;F[I90!!9W)A;F1I<B!L)^ED:71E=7(`R6-R:79E>B!U;F4@<75E<W1I;VX@
M9&4@<^EC=7)I=.D@<74G;VX@=F]U<R!P;W-E<F$@<VD@=F]U<R!D979E>B!R
M96UE='1R92#@('KI<F\@=F]T<F4@;6]T(&1E('!A<W-E+"!P87(@97AE;7!L
M92"K(%%U96P@97-T(&QE(&YO;2!D92!V;W1R92!A;FEM86P@<'+I9NERZ:`_
MH+N@.@!);G-C<FEV97H@;"=A9')E<W-E(%523"!D92!L)VEM86=E(&EC:0!%
M;G1R97H@;&5S(&QE='1R97,@8VDM9&5S<V]U<Z`Z`$=U:6[I92#I<75A=&]R
M:6%L90#)<GET:'+I90!%<G)E=7(`17)R975R(&QO<G,@9&4@;&$@8W+I871I
M;VX@9'4@8FQO8Z`Z("5S`$5R<F5U<B!L;W)S(&1E(&QA('-U<'!R97-S:6]N
M(&1E(&PG86YC<F4@9&4@<WEN8VAR;VYI<V%T:6]NH#H@)7,`17)R975R(&QO
M<G,@9&4@;&$@<W5P<')E<W-I;VX@9'4@:F]U<FYA;"!D92!S>6YC:')O;FES
M871I;VZ@.B`E<P!%<G)E=7(@;&]R<R!D92!L82!RZ6-U<.ER871I;VX@9'4@
M8V]N=&5N=:`Z("5S`$5R<F5U<B!L;W)S(&1E(&QA(&UI<V4@X"!J;W5R(&1U
M(&UO="!D92!P87-S9:`Z("5S`$5R<F5U<B!A=F5C(&QE(&UE<W-A9V4N`$5R
M<F5U<B!L;W)S(&1E(&PG96YR96=I<W1R96UE;G0@9&4@JZ`E<Z"[+@!%<W1O
M;FEE`,ET:&EO<&EE`$5T:&YI<75E`$5U<F]P90!4;W5S(&QE<R`F9G)A8S$T
M.R!D)VAE=7)E`%1O=71E<R!L97,@,B!M:6YU=&5S`%1O=71E<R!L97,@,S`@
M<V5C;VYD97,`5&]U=&5S(&QE<R`U(&UI;G5T97,`P"!C:&%Q=64@8V]N;F5X
M:6]N`%1O=71E<R!L97,@)F9R86,Q,CL@:&5U<F5S`%1O=71E<R!L97,@;6EN
M=71E<P!%>&5M<&QE(&1E('9A;&5U<G.@.@!%>.EC=71E<@!$Z79E;&]P<&5R
M`$3I<&QI97(@;&$@8F%R<F4@9&4@8_1TZ0"K("D@NR!A='1E;F1U90!5;B!S
M975L(&UO="!O=2!E>'!R97-S:6]N(&5N=')E(&=U:6QL96UE=',@871T96YD
M=7,`1&%T92!D)V5X<&ER871I;VX`4F5P<NES96YT86YT`$-O=6QE=7(@9"=A
M=F%N="UP;&%N`%3I;.EC:&%R9V5M96YT('9E<G,@;&4@<V5R=F5U<B!D92!L
M82!C;VYF:6=U<F%T:6]N('!A<B!&5%``3&5C='5R92!D97,@<'+I9NER96YC
M97,@:6UP;W-S:6)L92X`R6-H96,@9&4@;&$@8V]N;F5X:6]N(&%U('-E<G9E
M=7(@3$1!4"X`R6-H96,@9&4@;&$@8V]N;F5X:6]N(&%U('-E<G9E=7(@4TU"
M+@#)8VAE8R!D92!L82!C;W!I92!D97!U:7,@JZ`E<Z"[+@#)8VAE8R!D92!L
M82!C;W!I92!V97)S(""KH"5SH+LN`$EM<&]S<VEB;&4@9&4@8W+I97(@=6YE
M(&YO=79E;&QE(&-O;FYE>&EO;B!305-,`,EC:&5C(&1U(&3I<&QA8V5M96YT
M('9E<G,@JZ`E<Z"[+@#)8VAE8R!L;W)S(&1E(&QA('+I8W5PZ7)A=&EO;J`Z
M("5S`$)E874`SFQE<R!&86QK;&%N9"`H36%L;W5I;F5S*0#.;&5S($;I<F_I
M`$5R<F5U<B!F871A;&6@.@!&87@`5.ELZ6-O<&EE<P!&Z79R:65R`%1E;7#I
M<F%T=7)E(')E<W-E;G1I90!496UPZ7)A='5R92!R97-S96YT:66@.B``475E
M;'%U97,@879E<G-E<P!1=65L<75E<R!C:'5T97,@9&4@;F5I9V4`36%T<FEC
M92!D97,@8VAA;7!S`$9I9VQE="!#05!40TA!`%!O;&EC92!D92!L82`\23YF
M:6=L970\+TD^`$9I9&II`$9I8VAI97(`3F]M8G)E(&1E(&9I8VAI97)SH#H@
M)7,`3F]M8G)E(&1E(&9I8VAI97)SH#H@)7,`1V5S=&EO;FYA:7)E(&1E(&9I
M8VAI97)S`$YO;2!D=2!F:6-H:65R`$-H;VEX(&1E(&9I8VAI97(`5.ELZ6-H
M87)G96UE;G0@9&4@9FEC:&EE<@!,)V5N=F]I(&1E(&9I8VAI97)S(&XG97-T
M('!A<R!P<FES(&5N(&-O;7!T92X`1FEL=')E<P!&:6YL86YD90!0<F5M:>AR
M92!D96UI90!0<F5M:65R('%U87)T:65R`$9I>&5R(&QE(')A=&EO`%)E=&]U
M<FYE<@!&;&]T=&%N=`!"<F]U:6QL87)D`$1O<W-I97(@)7,@:6YE>&ES=&%N
M="X`0V]U;&5U<B!D92!P;VQI8V4`3F]U<G)I='5R90!0;W5R(&QE<R!N879I
M9V%T975R<R!N92!S=7!P;W)T86YT('!A<R!L97,@:6UA9V5S`%!RZ79I<VEO
M;B`H5$%&*0!*;W5R<R!D92!P<NEV:7-I;VX@*&YO=&5Z('%U92!L97,@<'+I
M=FES:6]N<R!F;W5R;FEE<R!D;VYN96YT(&QE(&IO=7(@970@;&$@;G5I=*`[
M('5N(&=R86YD(&YO;6)R92!I8VD@<&5U="!F86ER92!U;B!B;&]C('1RZ',@
M;&%R9V4`5F]U<R!A=F5Z(&]U8FQIZ2!V;W1R92!M;W0@9&4@<&%S<V6@/P!&
M;W)M=6QA:7)E<P!#:71A=&EO;@!4>7!E(&1E(&-I=&%T:6]N`$-I=&%T:6]N
M<P!#:71A=&EO;G,@,@!&;W)U;7,`4F5D:7)E8W1I;VX`5F4`0V%D<F5S`$9R
M86YC90!&<F%N8V4@;>ET<F]P;VQI=&%I;F4`1W5Y86YE(&9R86[G86ES90!0
M;VQY;NES:64@9G)A;N=A:7-E`%1E<G)E<R!A=7-T<F%L97,@970@86YT87)C
M=&EQ=65S(&9R86[G86ES97,`1&4`1'4@`$1E<V-R:7!T:6]N(&-O;7!LZ'1E
M`%!L96EN92!L=6YE`$YO;2!C;VUP;&5T`$=A8F]N`$%L8G5M(&0G;W)I9VEN
M92!D92!L)VEM86=E`$%L8G5MH#H`1V%M8FEE`$?I;NER97(@;&$@8V]N9FEG
M=7)A=&EO;B!D92`E<P!#;V1E(&?I;NERZ0!'Z6]R9VEE`$%L;&5M86=N90!'
M:&%N80!':6)R86QT87(`4'+I;F]M`$]P=&EO;G,@9VQO8F%L97,`06QL97(`
M1V]E9&5L`$-A<G1E<R!';V]G;&4`4F5C:&5R8VAE($=O;V=L90!.:79E874@
M9&4@9W)I<P!'<NAC90!'<F5C("A)4T\M.#@U.2TW*0!'<F_K;FQA;F0`1W)E
M;F%D90!!9&UI;FES=')A=&EO;B!D97,@9W)O=7!E<P!,97,@;F]M<R!D92!G
M<F]U<&4@;F4@<&5U=F5N="!P87,@ZG1R92!V:61E<P!'<F]U<%]L9&%PH#H@
M:6UP;W-S:6)L92!D)V%J;W5T97(@;&4@9W)O=7!E("5S+B!#96-I(&5S="!L
M82!RZ7!O;G-E(&1U('-E<G9E=7*@.@!'<F]U<%]L9&%PH#H@<W5P<')E<W-I
M;VX@:6UP;W-S:6)L92!D=2!G<F]U<&4@)7,`1W)O=7!?;&1A<*`Z(&UO9&EF
M:6-A=&EO;B!I;7!O<W-I8FQE(&1U(&=R;W5P92`E<P!'<F]U<&5S`$=U861E
M;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYE<V5Y`%!E<FUI<W-I;VYS(&1E
M<R!I;G9I=.ES`$QI=G)E(&0G;W(`1W5I;NEE`$=U:6[I92U":7-S874`1W5Y
M86YA`$A434P`2%1-3$%R96$@<F5F=7-E(&+J=&5M96YT(&1E('-U<'!R:6UE
M<B!L82!D97)N:>AR92!C96QL=6QE(&1E(&QA(')A;F?I90!(5$U,07)E82!R
M969U<V4@8NIT96UE;G0@9&4@<W5P<')I;65R(&QA(&1E<FYIZ')E(&-O;&]N
M;F4@9'4@=&%B;&5A=0!(5$U,07)E82!R969U<V4@8NIT96UE;G0@9&4@<W5P
M<')I;65R(&QA(&1E<FYIZ')E(')A;F?I92!D=2!T86)L96%U`$%U=&AE;G1I
M9FEC871I;VX@2%144"!N;VX@=')O=7;I92X`2&'O=&D`06QG;W)I=&AM92!D
M92!H86-H86=E`$)R=6UE('/H8VAE`$5N+73J=&4`16XM=.IT97,`SFQE<R!(
M96%R9"!E="!-8T1O;F%L9`!/<F%G97,@=FEO;&5N=',`2.EB<F5U("A)4T\M
M.#@U.2TX+4DI`$AA=71E=7(`06ED90!!:61E('!O=7(@;"?I9&ET975R`$%I
M9&4`2.EM:7-P:.AR90!6;VEC:2!L92!DZ6)U="!D=2!F:6-H:65RH#H`2&%U
M=&4`05]C8W5E:6P`0VETZ2!D=2!6871I8V%N`$%C8W5E:6P`061R97-S92!P
M97)S;VYN96QL90!2Z7!E<G1O:7)E('!E<G-O;FYE;`!4Z6SI<&AO;F4@<&5R
M<V]N;F5L`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8J`Z
M(&1O;F[I97,@6$U,("5S(&EN=F%L:61E<R!R971R;W5VZ65S(&1A;G,@;&4@
M;65S<V%G92`E<P!(;W)D92]+;VQA8J`Z(&%U8W5N(&UE<W-A9V4@;F4@8V]R
M<F5S<&]N9"!A=2!S=6IE="`E<P!(;W)D92]+;VQA8J`Z('!A<R!D)V]B:F5T
M(&1E('1Y<&4@)7,@=')O=7;I(&1A;G,@;&4@;65S<V%G92`E<P!(;W)D92]+
M;VQA8J`Z("5S('-U<'!R:6WI(*N@)7.@NR!A=F5C('-U8V/H<P!(;W)D92]+
M;VQA8J`Z(&QE(&UO=&5U<B!D)VEN=.EG<F%T:6]N(&[I8V5S<VET92!L)V5X
M=&5N<VEO;B`G9&]M>&UL)R!D92!02%``2&]R9&4O2V]L86*@.B!I;7!O<W-I
M8FQE(&1E(&-RZ65R('5N(&YO=79E;"!A<F)R92!834P@<&]U<B!L)V]B:F5T
M("5S`$AO<F1E+TMO;&%BH#H@:6UP;W-S:6)L92!D)V5N;&5V97(@)7,@JZ`E
M<Z"[H#H@)7,`2&]R9&4O2V]L86*@.B!I;7!O<W-I8FQE(&1E('+I8W5PZ7)E
M<B!L)VED96YT:69I86YT($U)344@<&]U<B!L82!P87)T:64@9&4@='EP92`E
M<P!(;W)D92]+;VQA8J`Z(&EM<&]S<VEB;&4@9&4@<WEN8VAR;VYI<V5R("5S
M(*N@)7.@NZ`Z("5S`$AO<F1E+TMO;&%BH#H@:6UP;W-S:6)L92!D92!S>6YC
M:')O;FES97(@;&5S('!A<G1A9V5SH#H@)7,`2&]R9&4O2V]L86*@.B!P87)T
M86=E(&EN8V]N;G4@JZ`E<Z"[`$QI9VYE(&AO<FEZ;VYT86QE`%)E;7!L:7-S
M86=E(&AO<FEZ;VYT86P`2&]R:7IO;G1A;*`Z`$-O;6UE;G0@ZG1E<RUV;W5S
M(&%R<FEVZ2!I8VF@/R`H4U90(')A<'!O<G1E>BUL9:`A*0!#;VUB:65N(&1E
M(&-O;&]N;F5S('9O=6QE>BUV;W5S(&9U<VEO;FYE<J`_`$-O;6)I96X@9&4@
M8VAA;7!S("AC;VQO;FYE<RD@>2!A+70M:6R@/P!#;VUB:65N(&1E(')A;F?I
M97,@=F]U;&5Z+79O=7,@9G5S:6]N;F5RH#\`2'5M:61I=.D`2'5M:61I=.F@
M.B``2'5M;W)I<W1E<P!(;VYG<FEE`,EC:&5C(&QO<G,@9&4@;&$@8W+I871I
M;VX@9&4@;&$@8F_N=&4@24U!4*`Z("5S`,EC:&5C(&QO<G,@9&4@;&$@<W5P
M<')E<W-I;VX@9&4@;&$@8F_N=&4@24U!4*`Z("5S`,EC:&5C(&QO<G,@9&4@
M;&$@8W+I871I;VX@9'4@<75O=&$@<W5R(&QA(&)O[G1E($E-05"@.B`E<P!!
M9')E<W-E($E0`$%D<F5S<V4@25`@;F]N(&1I<W!O;FEB;&4N`$%D<F5S<V4@
M25`@:&]R<R!D=2!B;&]C($-)1%(@86QL;W7I+@!6:6]L871I;VX@9&4@8FQO
M8V%G92!)4"X`25]N<^ER97(@<F%N9^EE(&%V86YT`$ES;&%N9&4`26/T;F5S
M('-E=6QE;65N=`!)8_1N97,@<&]U<B`E<P!)8_1N97,@<&QU<R!T97AT90!.
M;VT@9'4@8V]M<'1EH#H`4VD@;"=A9F9I8VAA9V4@;B=E<W0@<&%S(&-O<G)E
M8W0L("5S('!O=7(@;"=O=79R:7(@9&%N<R!U;F4@;F]U=F5L;&4@9F5NZG1R
M92X`4VD@=F]U<R!N92!V;WEE>B!A=6-U;B!I8_1N92!E;B!U=&EL:7-A;G0@
M26YT97)N970@17AP;&]R97(L('9O=7,@<&]U=F5Z(&%V;VER(.`@8V]C:&5R
M(&-E='1E(&-A<V4@<&]U<B!DZ7-A8W1I=F5R(&QA('1R86YS<&%R96YC92!D
M97,@4$Y'+@!3:2!V;W5S('9O>65Z(&-E(&UE<W-A9V4@;6%I<R!A=6-U;F4@
M:6UA9V4L(&PG:6UA9V4@<75E('9O=7,@=F]U;&5Z(&5N=F]Y97(@;F4@<&5U
M="#J=')E(&%F9FEC:.EE('!A<B!V;W1R92!N879I9V%T975R+@!!<&5RYW4@
M9&4@;"=I;6%G9:`Z`$%D<F5S<V4@55),(&1E(&PG:6UA9V4`061R97-S92!5
M4DP@9&4@;"=I;6%G9:`Z`$EM86=E(&1E(&PG86QB=6T`26UA9V4@9&4@;"=A
M;&)U;:`Z`%3I;.EC:&%R9V5M96YT(&0G:6UA9V5S`$EM86=E<P!);7!O<G1A
M=&EO;BP@Z71A<&4@)60`0VAA;7`@:6UP;W)TZ:`Z("5S`$-H86UP<R!I;7!O
M<G3I<Z`Z`$EN7W/I<F5R(')A;F?I92!A<'+H<P!#;V1E(&0G86-T:6]N(&EN
M8V]R<F5C="X`3F]M(&0G=71I;&ES871E=7(@970O;W4@=F]T<F4@;6]T(&1E
M('!A<W-E(&EN8V]R<F5C="X`3F]M(&0G=71I;&ES871E=7(@;W4@861R97-S
M92!A;'1E<FYA=&EV92!I;F-O<G)E8W0N("!2Z65S<V%Y97H@;W4@8V]N=&%C
M=&5Z('9O=')E(&%D;6EN:7-T<F%T975R('-Y<W3H;64@<&]U<B!D92!L)V%I
M9&4N`$%U9VUE;G1E<B!L)VEN9&5N=&%T:6]N`$EN9&4`571I;&ES871E=7)S
M(&EN9&EV:61U96QS`$EN9&]NZ7-I90!);F9O`$EN9F]R;6%T:6]N<P!,)VEN
M9F]R;6%T:6]N(&XG97-T('!L=7,@9&ES<&]N:6)L92X`26YSZ7)E<B!C7V]L
M;VYN92!A<'+H<P!);G/I<F5R(&EM86=E`$EN<^ER97(@=6X@=&%B;&5A=0!)
M;G/I<F5R('5N(&QI96X@=V5B`$EN<^ER97(@7V-O;&]N;F4@879A;G0`26YS
MZ7)E<B!U;F4@;F]U=F5L;&4@8V]L;VYN92!A<'+H<R!L82!C;VQO;FYE(&%C
M='5E;&QE`$EN<^ER97(@=6YE(&YO=79E;&QE(&-O;&]N;F4@879A;G0@;&$@
M8V]L;VYN92!A8W1U96QL90!);G/I<F5R('5N92!N;W5V96QL92!R86YGZ64@
M87!RZ',@;&$@<F%N9^EE(&%C='5E;&QE`$EN<^ER97(@=6YE(&YO=79E;&QE
M(')A;F?I92!A=F%N="!L82!R86YGZ64@86-T=65L;&4`26YSZ7)E<B!U;B!P
M87)A9W)A<&AE(&%P<NAS(&QE(&XF;V5L:6<[=60@86-T=65L`$EN<^ER97(@
M=6X@<&%R86=R87!H92!A=F%N="!L92!N)F]E;&EG.W5D(&%C='5E;`!);G/I
M<F5R('5N(&%U=')E(&UO9.AL90!);G-C<FEV97H@=6YE(&%D<F5S<V4@9&4@
M8V]U<G)I97(@X"!L87%U96QL92!V;W5S(')E8V5V<F5Z(&QE(&YO=79E874@
M;6]T(&1E('!A<W-EH#H`26YSZ7)E<B!C96QL=6QE(&%P<NAS`$EN<^ER97(@
M8V5L;'5L92!A=F%N=`!);G/I<F5R(&-O;&]N;F4@87!RZ',`26YSZ7)E<B!C
M;VQO;FYE(&%V86YT`$EN<^ER97(@;&5S(&UE<W-A9V5S`$EN<^ER97(@<&%R
M86=R87!H92!A<'+H<P!);G/I<F5R('!A<F%G<F%P:&4@879A;G0`26YSZ7)E
M<B!R86YGZ64@87!RZ',`26YSZ7)E<B!R86YGZ64@879A;G0`26YS8W)I=F5Z
M(&QA('+I<&]N<V4@X"!L82!Q=65S=&EO;B!D92!SZ6-U<FETZ:`Z`$EN<^ER
M97(O36]D:69I97(@=6YE(&EM86=E`$EN<^ER97(O36]D:69I97(@=6X@;&EE
M;B!W96(`0W+I9&ET(&EN<W5F9FES86YT('!O=7(@96YV;WEE<B#@(&QA(&QI
M<W1E(&1E(&1I<W1R:6)U=&EO;BX`0W+I9&ET(&EN<W5F9FES86YT+@!%;G1I
M97(`3&ES=&4@8V]M<&SH=&4`541(("A5<V5R($1A=&$@2&5A9&5R*2!I;G9A
M;&ED90!$;VYNZ64@6DE0(&EN=F%L:61E+@!!<'!L:6-A=&EO;B!I;G9A;&ED
M92X`1W)O=7!E($E$(&EN=F%L:61E+@!%;G9O:2!D92!D;VYNZ65S(&EN=F%L
M:61E<RX`061R97-S92!D92!D97-T:6YA=&EO;B!I;G9A;&ED92X`1F]R;6%T
M(&1E(&9I8VAI97(@:6YV86QI9&4N`$-L968@9&4@;&EC96YC92!I;G9A;&ED
M92X`16UP;&%C96UE;G0@:6YD:7%UZ2!I;G9A;&ED92X`JVUS9U]T>7!ENR!I
M;G9A;&ED92X`JV%P:5]I9+L@:6YV86QI9&4@;W4@;6%N<75A;G0N`%!A<F%M
MZ'1R97,@:6YV86QI9&5S(&]U(&UA;G%U86YT<RX`4&5R;6ES<VEO;B!I;G9A
M;&ED92X`260N(&1E('!A<G1E;F%I<F4@:6YV86QI9&4N`$-O9&4@9&4@<')O
M9'5I="!I;G9A;&ED92X`4')O=&]C;VQE(&EN=F%L:61E+@!$97-T:6YA=&%I
M<F4@:6YV86QI9&6@.B"KH"5SH+L`3V)J970@9&4@<&%R=&%G92!I;G9A;&ED
M90!!9')E<W-E('-O=7)C92!I;G9A;&ED92X`1&]N;NEE(%5N:6-O9&4@:6YV
M86QI9&4N`$EN=F5N=&%I<F4`26YV97)S97(@;&$@<^EL96-T:6]N`$ER86X`
M27)A:P!)<FQA;F1E`,YL92!D92!-86X`5&5M<.IT97,@:7-O;.EE<P!)<W)A
MZVP`R6UE='1E=7(`271A;&EQ=64`271A;&EE`$IA;6'O<75E`$IA;G9I97(`
M2F%P;VX`2F%P;VYA:7,@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N:64`
M2G5I;&QE=`!*=6EN`$IU<W1I9FEE<@!#96YT<F5R`$IU<W1I9FEE<@!!;&EG
M;F5R(.`@9V%U8VAE`$%L:6=N97(@X"!D<F]I=&4`2V%Z86MH<W1A;@!'87)D
M97(@;"=O<FEG:6YA;*`_`$ME;GEA`$QE('-E<G9E=7(@2V5R8F5R;W,@82!R
M96IE=.D@;"=A=71H96YT:69I8V%T:6]N+@!$Z6)U=&%N=',@9'4@;F]Y874`
M0W+I871I;VX@9&4@8VQE9@!%;7!R96EN=&4@9&4@;&$@8VQE9@!,;VYG=65U
M<B!D92!L82!C;&5F`%1Y<&4@9&4@8VQE9@!5=&EL:7-A=&EO;B!D92!L82!C
M;&5F`$QA(&-L968@<V4@=')O=79E(&3I:N`@<W5R(&QE('-E<G9E=7(@9&4@
M8VQE9G,@<'5B;&EC+@!%;F9A;G1S`$MI<FEB871I`$-O<NEE(&1U($YO<F0`
M0V]RZ64@9'4@4W5D`$-O<NEE;B`H155#+4M2*0!+;W=E[W0`2VER9VAI>FES
M=&%N`%!RZ5]S96YT871I;VX`3&%N9W5E`$QA;W,`1&5R;FGH<F4@9&5M:64`
M1&5R;FGH<F4@;6]D:69I8V%T:6]N(&1U(&UO="!D92!P87-S90!$97)N:65R
M('%U87)T:65R`$1E<FYIZ')E(&UI<V4@X"!J;W5RH#H`1&5R;FGH<F4@8V]N
M;F5X:6]NH#H@)7,`1&5R;FGH<F4@8V]N;F5X:6]NH#H@)7,@X"!P87)T:7(@
M9&4@)7,`1&5R;FGH<F4@8V]N;F5X:6]NH#H@:F%M86ES`$QE='1O;FEE`$QO
M:0!0<NES96YT871I;VX`3&%I<W-E<B!V:61E('!O=7(@;F4@<&%S(&%V;VER
M(&1E(&)O<F1U<F4`3&EB86X`1V%U8VAE`$5N=.IT92!G875C:&4`5F%L975R
M<R!D92!G875C:&4`3&5S;W1H;P!.:79E874`3&EBZ7)I80!,:6)Y90!,:65C
M:'1E;G-T96EN`$)R=6EN92!LZ6?H<F4`4&QU:64@;.EGZ')E`%!L=6EE(&SI
M9^AR92!T]'0@9&%N<R!L82!J;W5R;NEE`%!L=6EE(&SI9^AR92!T87)D`$%V
M97)S97,@;.EGZ')E<P!0;'5I92!LZ6?H<F4@879E8R!T;VYN97)R90!.96EG
M92!I;G1E<FUI='1E;G1E`$%V97)S92!D92!N96EG92!LZ6?H<F4`4FEM97,`
M3&EE;@!,92!L:65N('!O:6YT92!V97)SH#H`3&EE(&PG861R97-S92!D92!C
M;W5R<FEE;"#@(&QA('!A9V4@9&4@8V]M<&]S:71I;VX@9'4@;65S<V%G92!E
M;B!L)V%F9FEC:&%N=`!,:65N<P!":7-C=6ET($QI;G5X`$QI<W1E("T@=71I
M;&ES871E=7(@<&5U="!V;VER(&QE(&1O<W-I97(`3&ES=&4@9&5S(&)A<V5S
M(&1E(&1O;F[I97,`26YD97@@9&4@;"=A:61E`$%F9FEC:&5R(&QE<R!T86)L
M97,`07)C:&EV97,@9&4@;&$@;&ES=&4`06ED92!D92!L82!L:7-T90!)9"X@
M9&4@;&$@;&ES=&4`4')O<')IZ71A:7)E(&1E(&QA(&QI<W1E`$5N=F]I(.`@
M;&$@;&ES=&4`06)O;FYE;65N="#@(&QA(&QI<W1E`$3I<V%B;VYN96UE;G0@
M9&4@;&$@;&ES=&4`R6-H96,@9&4@;&$@;&ES=&4@9&5S('-E<W-I;VYSH#H@
M)7,`R6-H96,@9&4@;&$@;&ES=&4@9&5S('5T:6QI<V%T975R<Z`Z("5S`$PG
M869F:6-H86=E(&1E(&QA(&QI<W1E(&1E<R!U=&EL:7-A=&5U<G,@97-T(&3I
M<V%C=&EVZ2X`3&ET=.ER871U<F4`3&ET=6%N:64`0VAA<F=E;65N="XN+@!(
M975R92!L;V-A;&6@.B``2&5U<F4@970@;&]C86QE`$QI974`0V]N;F5X:6]N
M`%1R86-E(&1E(&QA(&1E<FYIZ')E('-E<W-I;VX@9&4@<WEN8VAR;VYI<V%T
M:6]N`$3I8V]N;F5X:6]N`$-O;FYE>&EO;@!4XF-H97,@9&4@8V]N;F5X:6]N
M`$QA(&-O;FYE>&EO;B!E<W0@<F5F=7/I92X@26P@97-T('!R;V)A8FQE('%U
M92!V;W1R92!N;VT@9"=U=&EL:7-A=&5U<B!O=2!V;W1R92!M;W0@9&4@<&%S
M<V4@82#I=.D@;6%L('-A:7-I`,EC:&5C(&1E(&-O;FYE>&EO;BX`5&5X=&4@
M;&]N9P!!;6]U<@!&86EB;&4`3&5T=')E(&=R96-Q=65S(&UI;G5S8W5L97,`
M3&5T=')E(&QA=&EN97,@;6EN=7-C=6QE<P!.;VUB<F4@<F]M86EN<R!M:6YU
M<V-U;&5S`$QU>&5M8F]U<F<`34T`365S<V%G92!D=2!J;W5R("A-3U1$*0!,
M82!P:>AC92!J;VEN=&4@35,M5$Y%1B!N92!C;VYT96YA:70@875C=6YE(&1O
M;F[I92X`35-'`$UA8V%O`%+I<'5B;&EQ=64@9&4@36%CZ61O:6YE`$UA9&%G
M87-C87(`36%G:64`0V]U<G)I97(`061M:6YI<W1R871I;VX@9'4@8V]U<G)I
M96P`1F%I<F4@=6X@;&EE7VX`36%L87=I`$UA;&%I<VEE`$UA;&1I=F5S`$UA
M;&D`36%L=&4`061M:6YI<W1R97H@;&$@;&ES=&4@9&4@8V%TZ6=O<FEE<R!E
M="!L97,@8V]U;&5U<G,@;&GI97,@X"!C97,@8V%TZ6=O<FEE<RX`0V%R=&4@
MJR!-87`R-""[`$-A<G1E(*L@36%P<75E<W0@NP!#;W)R97-P;VYD86YC97,@
M96YR96=I<W1RZ65S+@!-87)S`$UA<F=E`$UA<G%U97(@879E8R!D97,@Z71I
M<75E='1E<R!6=2].;VX@=G4`36%R<75E<B!A=F5C(&0G875T<F5S(.ET:7%U
M971T97,@*&5X+CH@26UP;W)T86YT+U+I<&]N9'4I`,YL97,@36%R<VAA;&P`
M36%R=&EN:7%U90!#:&%M<',@87!P87)E;G3I<P!-875R:71A;FEE`,YL92!-
M875R:6-E`$-RZ61I="!M87AI;75M(&%L;&]UZ2X`3&EM:71E(&1U(&UE<W-A
M9V4@9.EP87-SZ64N`%1E;7#I<F%T=7)E(&UA>&EM86QE(&1E<R`R-"!D97)N
M:>AR97,@:&5U<F5SH#H@`%1E;7#I<F%T=7)E(&UA>&EM86QE(&1E<R`V(&1E
M<FYIZ')E<R!H975R97.@.B``3F]M8G)E(&UA>&EM=6T@9&4@8FQO8W,@9'4@
M<&]R=&%I;`!,;VYG=65U<B!M87AI;75M`$UA:0!-87EO='1E`$WI9&EC86UE
M;G0`365M8G)E<P!4>7!E(&1E(&UE;G6@.@!&=7-I;VYN97(@;&5S(&-E;&QU
M;&5S`$UE<W-A9V4`5NER:69I8V%T:6]N(&1U(&UE<W-A9V4@<NEU<W-I92P@
M;6%I<R!L92!C97)T:69I8V%T(&1U('-I9VYA=&%I<F4@;B=A('!A<R!P=2#J
M=')E(';I<FEF:>DN`$UE<W-A9V4@97AP:7+I+@!4>7!E(&1E(&UE<W-A9V4`
M3>ETZ6\@365T87(`3&4@8FQO8R"K($UE=&%R(+L@;B=E<W0@<&%S(&1I<W!O
M;FEB;&4N`$QE(&)L;V,@JR!-971A<B"[(&XG97-T('!A<R!D:7-P;VYI8FQE
M+B`@3&5S(&3I=&%I;',@;VYT(.ETZ2!C;VYS:6=NZ7,@<&]U<B!L)V%D;6EN
M:7-T<F%T975R+@!-971A<D1"(&XG97-T('!A<R!C;VYN96-TZ2X`3>ET:&]D
M90!,82!MZ71H;V1E(*N@)7.@NR!N)V5S="!P87,@9.EF:6YI90!-Z71H;V1E
M(&YO;B!DZ69I;FEE+B!-Z71H;V1E(&%P<&5LZ66@.B`E<P!-Z71R:7%U90!-
M97AI<75E`,ET871S(&;I9.ERZ7,@9&4@36EC<F]NZ7-I90!-:6QI974`5'EP
M92!-24U%`%1E;7#I<F%T=7)E(&UI;FEM=6T@9&5S(#(T(&1E<FYIZ')E<R!H
M975R97.@.B``5&5M<.ER871U<F4@;6EN:6UU;2!D97,@-B!D97)N:>AR97,@
M:&5U<F5SH#H@`$QA(&1U<NEE(&UI;FEM86QE(&1U(&UO="!D92!P87-S92!N
M)V$@<&%S(&5N8V]R92!E>'!I<ND`36ER;VER`%9A<FGI<P!,92!P87%U971A
M9V4@2%144%]R97%U97-T(%!%05(@97-T(&UA;G%U86YT+@!#;VYF:6=U<F%T
M:6]N(&EN97AI<W1A;G1E+B!6;W5S(&1E=F5Z(&QA(&?I;NER97(@;6%I;G1E
M;F%N="!S:2!V;W5S('9O=6QE>B!U=&EL:7-E<B!C971T92!A<'!L:6-A=&EO
M;BX`240@9'4@;65S<V%G92!M86YQ=6%N="X`3&4@<&%Q=65T86=E(%!%05(@
M36%I;"!E<W0@;6%N<75A;G0N`$E$(&1E('-E<W-I;VX@;6%N<75A;G0N`$QU
M`$-O=7)R:65L('-A;G,@9FEL`$UO9.ERZ0!$871E(&1E(&UO9&EF:6-A=&EO
M;@!-;V1I9FEE<B!L)U523`!-;V1U;&\`36]L9&%V:64`36]N86-O`$UO;F=O
M;&EE`$UO:7,@970@86YNZ64`365N<W5E;&QE;65N=`!-;VYT<V5R<F%T`%!H
M87-E<R!D92!L82!L=6YE`$-H86UP<R!S=7!P;.EM96YT86ER97,@=')O=7;I
M<R#@(&QA(&QI9VYE("5D("AA='1E;F1U<R`E9"DN`$UA<F]C`$?I;NER86QE
M;65N="!E;G-O;&5I;&SI`$?I;NER86QE;65N="!N=6%G975X`%!R:6YC:7!A
M;&5M96YT(&YU86=E=7@@970@=F5N=&5U>`!'Z6[I<F%L96UE;G0@96YS;VQE
M:6QLZ0!697)S(&QE(&)A<P!$Z7!L86-E<B#@(&=A=6-H90!$Z7!L86-E<B#@
M(&1R;VET90!697)S(&QE(&AA=70`5F5R<R!L92!B87,`5F5R<R!L92!H875T
M`$UO>F%M8FEQ=64`3&ES=&5S(&3I<F]U;&%N=&5S(&UU;'1I+6YI=F5A=7@`
M0V%R=&4@JZ!-=6QT:6UA<"!52Z"[`%/I;&5C=&EO;B!M=6QT:7!L90!087)A
M;>ET<F%G92!D=2!C;VUP=&4`365S(&1O;F[I97,@<&5R<V]N;F5L;&5S`$UO
M;B!P;W)T86EL`%!RZ7-E;G1A=&EO;B!D92!M;VX@<&]R=&%I;`!":7)M86YI
M90!.3TXL(&IE(&XG86-C97!T92!P87,`3F]M`$YA;6EB:64`3F%U<G4`3NEP
M86P`4&%Y<RU"87,`06YT:6QL97,@;NEE<FQA;F1A:7-E<P!54DP@9&4@8F%S
M92!D92!.971S8V%P90!54DP@9&4@<NEV;V-A=&EO;B!D92!L)T$N0RX@3F5T
M<V-A<&4`55),(&1E(&QA('!O;&ET:7%U92!D)T$N0RX@3F5T<V-A<&4`55),
M(&1E(')E;F]U=F5L;&5M96YT($YE='-C87!E`%523"!D92!RZ79O8V%T:6]N
M($YE='-C87!E`$YO;2!D=2!S97)V975R(%-33"!.971S8V%P90!#;VUM96YT
M86ER92!D=2!C97)T:69I8V%T($YE='-C87!E`%1Y<&4@9'4@8V5R=&EF:6-A
M="!.971S8V%P90!2Z7-E874`2F%M86ES`$YO=79E;&QE+4-A;.ED;VYI90!.
M;W5V96QL92!C873I9V]R:64`3F]U=F5L;&4@;'5N90!.;W5V96%U(&YO;2!D
M92!C;VYN97AI;VX@*&9A8W5L=&%T:68I`$YO=79E;&QE+5KI;&%N9&4`3F]U
M=F5A=2!M;W0@9&4@<&%S<V4`3&4@;F]U=F5A=2!M;W0@9&4@<&%S<V4@97AP
M:7)E<F$@;&4@)7@N`$QE<R!N;W5V96%U>"!M;W1S(&1E('!A<W-E(&1I9F;H
M<F5N="X`3F]U=F5L;&4@9F5NZG1R92`H7V)L86YK*0!.;W5V96QL97,`1F]R
M=6US`%-U:79A;G0`-"!P:&%S97,@<W5I=F%N=&5S`$]P=&EO;G,@<W5I=F%N
M=&5S`%-U:79A;G0^`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YU:70`3FEU
M90!.;VX`4&%S(&1E(&1O;F[I97,@9&4@8V]N9FEG=7)A=&EO;B!P;W5R(&QE
M<W%U96QL97,@;6]N=')E<B!L97,@9&EF9NER96YC97,N`%!A<R!D92!S=')A
M=.EG:64@9&ES<&]N:6)L92!P;W5R(&9A:7)E(&1E<R!I;6%G97,@25-/+@!0
M87,@9&4@9V%B87)I="!E;B!T<F%I=&5M96YT('!A<B!L;W0N`$%U8W5N(&)L
M;V,@;B=E>&ES=&4@X"!L82!P;W-I=&EO;B!D96UA;F3I90!087,@9&4@;F]M
M(&1E(&-A;&5N9')I97(@9F]U<FYI('!O=7(@;"=A=71H96YT:69I8V%T:6]N
M('!A<B!-0T%,+@!.;VX@;6]D:69IZ2X`075C=6YE('-O=7,M<&5R;6ES<VEO
M;B!N)V$@8F5S;VEN(&0GZG1R92!A:F]U=.EE('-O=7,@8V4@;FEV96%U+@!!
M=6-U;F4@:6YF;W)M871I;VX@9&4@8V]N9FEG=7)A=&EO;B!S<.EC:69IZ64@
M<&]U<B`E<RX`075C=6YE(&EN9F]R;6%T:6]N(&1E(&-O;F9I9W5R871I;VX@
M9F]U<FYI92!P;W5R($944"!61E,N`$%U8W5N92!I;F9O<FUA=&EO;B!D92!C
M;VYF:6=U<F%T:6]N(&9O=7)N:64@<&]U<B!344P@5D93+@!!=6-U;F4@:6YF
M;W)M871I;VX@9&4@8V]N9FEG=7)A=&EO;B!F;W5R;FEE('!O=7(@4U%,+49I
M;&4@5D93+@!!=6-U;B!C<NED:70@9&ES<&]N:6)L92X`075C=6YE(&1E<W1I
M;F%T:6]N('1R;W5VZ64N`$%U8W5N(&9I8VAI97(@96YV;WGI`$%U8W5N(&EC
M]&YE('1R;W5VZ2X`075C=6X@;&EE=2!N)V5S="!SZ6QE8W1I;VYNZ0!!=6-U
M;B!E;7!L86-E;65N="!N)V5S="!I;F1I<77I+@!!=6-U;B!M97-S86=E(&9O
M=7)N:0!!=6-U;B!N;VT@<W#I8VEF:>DN`$%U8W5N(&YO;6)R92!S<.EC:69I
MZ2X`4&%S(&0G87!H;W)I<VUE<R!C:&]Q=6%N=',`075C=6X@;6]T(&1E('!A
M<W-E(&9O=7)N:2!P;W5R(&PG875T:&5N=&EF:6-A=&EO;B!P87(@2%144"X`
M075C=6X@;6]T(&1E('!A<W-E(&9O=7)N:2!P;W5R(&PG875T:&5N=&EF:6-A
M=&EO;B!P87(@24U!4"X`075C=6X@;6]T(&1E('!A<W-E(&9O=7)N:2!P;W5R
M(&PG875T:&5N=&EF:6-A=&EO;B!P87(@2V5R8F5R;W,N`$%U8W5N(&UO="!D
M92!P87-S92!S<.EC:69IZ2!P;W5R(&PG875T:&5N=&EF:6-A=&EO;BX`075C
M=6X@;6]T(&1E('!A<W-E('-PZ6-I9FGI('!O=7(@;"=A=71H96YT:69I8V%T
M:6]N(%!!4U-71"X`075C=6X@;6]T(&1E('!A<W-E('-PZ6-I9FGI('!O=7(@
M;"=A=71H96YT:69I8V%T:6]N(%--0BX`075C=6X@8VAE;6EN('9E<G,@;&4@
M8FEN86ER92!/<&5N4U-,(&9O=7)N:2X@3&4@8FEN86ER92!D)T]P96Y34TP@
M97-T(&[I8V5S<V%I<F4@<&]U<B!F;VYC=&EO;FYE<B!A=F5C(&1E<R!D;VYN
MZ65S(%!+0U,@,3(N`$%U8W5N92!C;VYF:7)M871I;VX@96X@871T96YT90!0
M87,@9&4@<75O=&$@<&]S:71I;VYNZ2X`4&%S(&1E('+H9VQE<P!!=6-U;B!S
MZ7!A<F%T975R('-PZ6-I9FGI+@!087,@9&4@8_1TZ7,`1FEC:&EE<B!I;F5X
M:7-T86YT`$%U8W5N('+I<&5R=&]I<F4@=&5M<&]R86ER92!E<W0@9&ES<&]N
M:6)L92!P;W5R(&QA(&-A8VAE`$%U8W5N(&YO;2!D)W5T:6QI<V%T975R(&5T
M("]O=2!M;W0@9&4@<&%S<V4@96YV;WGI+@!!=6-U;F4@9&]N;NEE(%A-3"!V
M86QI9&4@;B=A(.ETZ2!R971O=7)NZ64`4&%S(&1E('9A;&5U<@!087,@9&4@
M=F5R<VEO;B!T<F]U=NEE(&1A;G,@;&$@8V]N9FEG=7)A=&EO;B!O<FEG:6YA
M;&4N(%+I9^ENZ7)E>B!L82!C;VYF:6=U<F%T:6]N+@!087,@9&4@=F5R<VEO
M;B!T<F]U=NEE(&1A;G,@=F]T<F4@8V]N9FEG=7)A=&EO;BX@4NEGZ6[I<F5Z
M(&QA(&-O;F9I9W5R871I;VXN`$%U8W5N`$%U8W5N("AU=&EL:7-E<B!I;7!L
M:6-I=&5M96YT*0!.;W)D:7%U92`H25-/+3@X-3DM,3`I`,YL92!.;W)F;VQK
M`$CI;6ES<&CH<F4@3F]R9`#.;&5S($UA<FEA;FYE<R!D=2!N;W)D`$YO<G;H
M9V4`4&%S(&%P<NAS`%!A<R!A=F%N=`!087,@=6X@9&]S<VEE<@!.;VX@:6UP
M;.EM96YTZ2X`26YA8W1I9@!.;VX@<')I<R!E;B!C;VUP=&4N`$YO=&5S`%)I
M96X@X"!N879I9W5E<BP@<F5T;W5R;F5Z(&5N(&%R<FGH<F4N`$YO=F5M8G)E
M`$YO;6)R90!.;VUB<F4@9&4@8V%R86-TZ')E<P!.;VUB<F4@9&4@8V]L;VYN
M97,`3F]M8G)E(&1E(')A;F?I97,`3F]M8G)E(&YO;B!S<.EC:69IZ2!P;W5R
M(&QA(&UI<V4@X"!J;W5R(&1E(&QA(&QI<W1E(&1E(&1I<W1R:6)U=&EO;BX`
M3TL`3V)J970`0W+I871E=7(@9"=O8FIE=`!/8W1A;`!/8W1O8G)E`$9I;'1R
M92!A;G1I+6]F9F5N<V%N=`!"=7)E874`3"=A;F-I96X@970@;&4@;F]U=F5A
M=2!M;W1S(&1E('!A<W-E(&1O:79E;G0@ZG1R92!D:69FZ7)E;G1S+@!!;F-I
M96X@;6]T(&1E('!A<W-E`$PG86YC:65N(&UO="!D92!P87-S92!E<W0@:6YC
M;W)R96-T`$]M86X`4V5U;"!L97,@<V5R=F5U<G,@24U!4"!S=7!P;W)T96YT
M(&QE<R!D;W-S:65R<R!P87)T86?I<RX`4V5U;&5M96YT(&QE<R"KH&9O<G1U
M;F5SH+L@;V9F96YS86YT97,`56YE('-E=6QE(&%D<F5S<V4@9&4@8V]U<G)I
M96P@<&5R;6ES92X`4V5U;',@;&4@<')O<')IZ71A:7)E(&]U(&PG861M:6YI
M<W1R871E=7(@<WES=.AM92!P975T(&UO9&EF:65R(&QE<R!P97)M:7-S:6]N
M<R!D)W5N('!A<G1A9V4N`$]U=G)I<B!D86YS('5N92!N;W5V96QL92!F96[J
M=')E`$5R<F5U<B!/<&5N4U-,H#H@:6UP;W-S:6)L92!D)V5X=')A:7)E(&QE
M<R!D;VYNZ65S(&1E(&QA('!A<G1I92!S:6=NZ64@4R]-24U%`$]U=G)I<B!L
M97,@;&EE;G,@9&%N<R!U;F4@;F]U=F5L;&4@9F5NZG1R90!3>7-TZ&UE(&0G
M97AP;&]I=&%T:6]N`$]P=&EO;G,`3W!T:6]N<R!P;W5R("5S`$QI<W1E(&YU
M;>ER;W3I90!/<F=A;FES871I;VX`56YI=.D@;W)G86YI<V%T:6]N;F5L;&4`
M3W)G86YI<V%T:6]N`$UO9.AL92!O<FEG:6YA;"!D)V%P<&QI8V%T:6]N`$UO
M9.AL97,@;W)I9VEN875X(&1A;G,@)7.@.@!!=71R90!!=71R97,@:6YF;W)M
M871I;VYS`%!E<FUI<W-I;VYS(&1U('!R;W!R:>ET86ER90!,)V%U=&AE;G1I
M9FEC871I;VX@4$%-(&XG97-T('!A<R!D:7-P;VYI8FQE+@!-;V1U;&4@4$5!
M4CHZ36%I;`!3:6=N871U<F4@;G5MZ7)I<75E(%!'4`!$;VYNZ65S(%!'4"!C
M:&EF9G+I97,`0VQE9B!P=6)L:7%U92!01U``1&]N;NEE<R!01U`@<VEG;NEE
M<R]C:&EF9G+I97,`0V]D92!02%``26YT97)P<NET975R(%!(4`!0;'5I92!L
MZ6?H<F4@;"=A<'+H<RUM:61I`%!L=6EE(&PG87!RZ',M;6ED:0!!=F5R<V5S
M(&PG87!RZ',M;6ED:0!.96EG92!L)V%P<NAS+6UI9&D`0VAU=&5S(&1E(&YE
M:6=E(&PG87!RZ',M;6ED:0!3;VQE:6P@;"=A<'+H<RUM:61I`$]R86=E<R!L
M)V%P<NAS+6UI9&D`17AT96YS:6]N(%!/4TE8(&%B<V5N=&4`26YT97)P<NET
M975R(%!?2%``4F5M<&QI<W-A9V4`4&%K:7-T86X`0F5L874`4&%L97-T:6YE
M("AT97)R:71O:7)E(&]C8W5PZ2D`4&%N86UA`%!A<&]U87-I92U.;W5V96QL
M92U'=6ENZ64`4&%R86=U87D`4&%R=&EE;&QE;65N="!N=6%G975X`$UO="!D
M92!P87-S90!#:&%N9V5M96YT(&1U(&UO="!D92!P87-S92!E9F9E8W1UZ2X`
M36]T(&1E('!A<W-E(&EN8V]R<F5C=`!-;W0@9&4@<&%S<V4@<F5Q=6ES('!O
M=7(@;"=A=71H96YT:69I8V%T:6]N(%)!1$E54RX`36]T(&1E('!A<W-E(&%V
M96,@8V]N9FER;6%T:6]N`$UO="!D92!P87-S9:`Z`$UO="!D92!P87-S9:`Z
M(`!,97,@;6]T<R!D92!P87-S92!D;VEV96YT(.IT<F4@:61E;G1I<75E<RX`
M0V]L;&5R`$-O;&QE<B!D97!U:7,@;&4@<')E<W-E+7!A<&EE<G,`0VAE;6EN
M`$-O;F9I<FUA=&EO;G,@96X@871T96YT9:`Z`%!E<G-O;FYE<P!0;W5R8V5N
M=&%G90!%9F9E8W1U97(@;&5S(&]PZ7)A=&EO;G,@9&4@;6%I;G1E;F%N8V4`
M169F96-T=65R(&QE<R!O<.ER871I;VYS(&1E(&UA:6YT96YA;F-E(.`@;&$@
M8V]N;F5X:6]NH#\`4&5R;6ES<VEO;@!,82!P97)M:7-S:6]N(*N@)7.@NR!N
M)V5S="!P87,@<W5P<')I;>EE+@!097)M:7-S:6]N(')E9G5SZ64`4&5R;6ES
M<VEO;G,`061M:6YI<W1R871I;VX@9&5S('!E<FUI<W-I;VYS`$1O;F[I97,@
M<&5R<V]N;F5L;&5S`%#I<F]U`$%N:6UA=7@`4&AI;&EP<&EN97,`5.ELZ7!H
M;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE;',`4&QA=&ET=61E<P!35E`@8VQI
M<75E>B!D86YS('5N92!C96QL=6QE`%-64"!C;VYF:7)M97H@;&$@<W5P<')E
M<W-I;VX@9&4@8V5T(.ELZ6UE;G2@.@!35E`@8V]N9FER;65Z('%U92!V;W5S
M('9O=6QE>B!DZ6QI97(@8V5T(.ELZ6UE;G0N`%9E=6EL;&5Z('-A:7-I<B!U
M;B!M;VES(&5T('5N92!A;F[I92X`5F5U:6QL97H@<V%I<VER('5N(&YO;2!P
M;W5R(&QA(&YO=79E;&QE(&-A=.EG;W)I9:`Z`%9E=6EL;&5Z(&5N=')E<B!U
M;F4@861R97-S92!)4"!V86QI9&4N`%9E=6EL;&5Z(&5N=')E<B!U;F4@9&%T
M92!V86QI9&6@.R!VZ7)I9FEE>B!L92!N;VUB<F4@9&4@:F]U<G,@9'4@;6]I
M<RX@`%9E=6EL;&5Z(&5N=')E<B!U;F4@:&5U<F4@=F%L:61E+@!6975I;&QE
M>B!F;W5R;FER('5N('+I<W5MZ2!D=2!P<F]B;.AM92X`5F5U:6QL97H@9F]U
M<FYI<B!V;W1R92!N;VT@9"=U=&EL:7-A=&5U<B!E="!V;W1R92!M;W0@9&4@
M<&%S<V4`5F5U:6QL97H@;&ER92!L92!T97AT92!S=6EV86YT+B!6;W5S(&1E
M=F5Z(&%C8V5P=&5R(&QE<R!C;VYD:71I;VYS('!O=7(@=71I;&ES97(@;&4@
M<WES=.AM92X`5F5U:6QL97H@96YT<F5R(&QE(&YO=79E874@;F]MH&1E(&QA
M(&-A=.EG;W)I9:`Z`%!O;&]G;F4`4&]L:71I<75E`%-C<G5T:6YS`%!O<G1U
M9V%L`%!O<VET:6]N(&1E(&-E='1E(&EM86=E`%!O<VET:6]N(&1E(&-E('1A
M8FQE874`16YV;WEE<B#@(&-E(&1O<W-I97(@*&YO;B!A<'!L:7%UZ2!P87(@
M24U!4"D`4'+I8VEP:71A=&EO;G,@<&]U<B!L97,@)7,@9&5R;FGH<F5S(&AE
M=7)E<Z`Z(`!0<F]B86)I;&ETZ3QB<B`O/F1E('!L=6EE`%!R969S7VQD87"@
M.B!E>'1E;G-I;VX@<F5Q=6ES92!,1$%0(&YO;B!T<F]U=NEE+@!0<F5F<U]S
M97-S:6]NH#H@97AT96YS:6]N(')E<75I<V4@JZ!S97-S:6]NH+L@;F]N('1R
M;W5VZ64N`%!R97-S:6]N`%!R97-S:6]N(&%U(&YI=F5A=2!D92!L82!M97*@
M.B``4')E<W-I;VZ@.B``07!E<N=U`$%P97+G=2!D92!L)VEM86=E(&1A;G,@
M=6YE(&YO=79E;&QE(&9E;NIT<F4`3W!T:6]N<R!P<NECZ61E;G1E<P!);7!R
M:6UE<B!L92!D;V-U;65N=`!#;&5F('!R:7;I90!0<F]B;.AM90!$97-C<FEP
M=&EO;B!D=2!P<F]B;.AM90!0<F]J971S`%1E>'1E(&-O=7)T`$-L968@<'5B
M;&EQ=64`06QG;W)I=&AM92!D92!C;&5F('!U8FQI<75E`$EN9F]R;6%T:6]N
M<R!S=7(@;&$@8VQE9B!P=6)L:7%U90#)8VAE8R!D92!L82!GZ6[I<F%T:6]N
M(&1E(&QA('!A:7)E(&1E(&-L969S('!U8FQI<75E+W!R:7;I92X`4&]R=&\@
M4FEC;P!0=7)G97(@;&5S(&UE<W-A9V5S`%%A=&%R`%)E<77J=&4`475O=&$`
M0VQE9B!P=6)L:7%U92!24T$@*"5D(&)I=',I`%/I;&5C=&EO;B!R861I;P!0
M;'5I90!0;'5I92!T]'0@;&4@;6%T:6X`4&QU:64@=&%R9"!D86YS(&QA(&IO
M=7)NZ64`079E<G-E<P!0;'5I92!E="!N96EG90!0;'5I92!P=6ES(&YE:6=E
M`$%P:&]R:7-M92!A=2!H87-A<F0`5&%U>`!,:7)E`$UE<W-A9V5S(&QU<P!3
M=7!P<F5S<VEO;B!DZ69I;FET:79E(&1E("5SH#\`4W5P<')E<W-I;VX@9.EF
M:6YI=&EV92!D97,@9&]N;NEE<R!P;W5R(&PG=71I;&ES871E=7(@)7.@/R!#
M971T92!O<.ER871I;VX@97-T(&3I9FEN:71I=F4N`%)E<')E;F1R92!V;W1R
M92!D97)N:>AR92!A8W1I;VX`4F%F<F'N8VAI<@!2869R8>YC:&ER(&QE<R#I
M;.EM96YT<R!D=2!M96YU(&1Y;F%M:7%U9:`Z`%)A9G)A[F-H:7(@;"?I8W)A
M;B!D=2!S;VUM86ER9:`Z`$5X<')E<W-I;VX@<F%T:6]N;F5L;&4`3F%V:6=A
M=&5U<B!R96QA=&EO;FYE;`!296-H87)G97(`4F5M87)Q=65S`%-E<G9E=7)S
M(&1I<W1A;G1S`%523"!D:7-T86YT92`H:'1T<#HO+W=W=RYE>&5M<&QE+F-O
M;2]H;W)D92\IH#H`4F5T:7)E<@!2971I<F5R(&QE(&)L;V,`4F5T:7)E<B!L
M82!C;VQO;FYE`%)E=&ER97(@;&4@9F]R;6%T86=E`%)E=&ER97(@;&$@<&%I
M<F4`16YL979E<B!L92!S8W)I<'0@96YR96=I<W1RZ2!D=2!RZ7!E<G1O:7)E
M('1E;7!O<F%I<F4@9'4@<V5R=F5U<BX`4F5T:7)E<B!L90!2971I<F5R(&-E
M(&YO975D(&1U(&1O8W5M96YT`%)E=&ER97(@;"=U=&EL:7-A=&5U<@!2971I
M<F5R(&PG=71I;&ES871E=7*@.B`E<P!!=6-U;F4@<NEP;VYS92#@('9O=')E
M(')E<77J=&4N($-O9&4@9"=E<G)E=7(@<F5T;W5R;NF@.B``3&4@<V5R=FEC
M92!D96UA;F3I(&5S="!I;G1R;W5V86)L92X`3&4@<&%R86WH=')E(&]B;&EG
M871O:7)E(*N@)7.@NR!N)V5S="!P87,@<W#I8VEF:>D@9&%N<R!L82!C;VYF
M:6=U<F%T:6]N("5S+@!,92!P87)A;>AT<F4@;V)L:6=A=&]I<F4@JZ`E<Z"[
M(&XG97-T('!A<R!S<.EC:69IZ2!D86YS(&QA(&-O;F9I9W5R871I;VX@9'4@
M5D93+@!,92!P87)A;>AT<F4@;V)L:6=A=&]I<F4@JZ`E<Z"[(&XG97-T('!A
M<R!S<.EC:69IZ2!D86YS(&QA(&-O;F9I9W5R871I;VXN`$-H86UP(&]B;&EG
M871O:7)E`%+`6@!296UI<V4@X"!ZZ7)O(&1U(&UO="!D92!P87-S90!296UE
M='1R92#@('KI<F\@=F]T<F4@;6]T(&1E('!A<W-E`%)E=F5N:7(@X"!L82!D
M97)N:>AR92!R97%UZG1E`%+I<W5L=&%T<P!2979E;FER(&%U>"!O<'1I;VYS
M`%+I+65N=')E<B!L92!N;W5V96%U(&UO="!D92!P87-S90!2Z75N:6]N`%)E
M=F5N:7(@X"!L82!C;VYF:6=U<F%T:6]N('!RZ6/I9&5N=&4`3W!T:6]N<R!D
M92!L)^ED:71E=7(@4FEC:"!497AT`$1E=FEN971T97,`1')O:71E`$5N=.IT
M92!D92!D<F]I=&4`5F%L975R<R!C;W)R96-T97,`4')O<')IZ73I<R!D92!L
M82!R86Y?9^EE("XN+@!2]&QE`%)O=6UA;FEE`%!I=F]T97(@,3@P`%!I=F]T
M97(@X"!G875C:&4`4&EV;W1E<B#@(&1R;VET90!0<F]P<FGI=.ES(&1E(&QA
M(')A;F?I90!0<F]P<FGI=.ES(&1E(&QA(')A;F?I90!286YGZ65SH#H`4NAG
M;&5S`$1E<R!F:6QE=',@87!P87)A[G1R;VYT(&5N=')E('1O=71E<R!L97,@
M<F%N9^EE<R!E="!L97,@8V]L;VYN97,`1&5S(&9I;&5T<R!A<'!A<F'N=')O
M;G0@96YT<F4@;&5S(&-O;&]N;F5S('-E=6QE;65N=`!$97,@9FEL971S(&%P
M<&%R8>YT<F]N="!E;G1R92!L97,@<F%N9^EE<R!S975L96UE;G0`3&%N8V5R
M`%)U<W-I90!2=V%N9&$`4VEG;F%T=7)E(.EL96-T<F]N:7%U92!3+TU)344`
M365S<V%G92!C:&EF9G+I(%,O34E-10!,)V%U=&AE;G1I9FEC871I;VX@4T%3
M3"!N)V5S="!P87,@9&ES<&]N:6)L90!-97-S86=E<FEE(%--4P!);G1E<G!R
MZ71E=7(@4U%,`$]R9')E(%-13"!P;W5R(')E=&]U<FYE<B!L97,@=F%L975R
M<P!34T@`4U5#0\A3`$EN=&5R<'+I=&5U<B!37U%,`%-A`%-A:6YT92U(Z6SH
M;F4`4V%I;G0M0VAR:7-T;W!H92UE="U.:>EVZ',`4V%I;G1E+4QU8VEE`%-A
M:6YT+5!I97)R92!E="!-:7%U96QO;@!386EN="U6:6YC96YT+65T+6QE<R!'
M<F5N861I;F5S`$WJ;64@8V%D<F4@*%]S96QF*0!386UO82!O8V-I9&5N=&%L
M97,`4V%I;G0M36%R:6X`4V%O+51O;>DM970M4')I;F-I<&4`1F]U<FYI<W-E
M=7(@<V%T96QL:71E`$%R86)I92!386]U9&ET90!%;G)E9VES=')E<@!%;G)E
M9VES=')E<B"KH"5SH+L`16YR96=I<W1R97(@)7,`16YR96=I<W1R97(@;&5S
M(&]P=&EO;G,`16YR96=I<W1R97(@;&$@8V]N9FEG=7)A=&EO;B!GZ6[I<NEE
M(&-O;6UE('5N('-C<FEP="!02%`@9&%N<R!L92!RZ7!E<G1O:7)E('1E;7!O
M<F%I<F4@9&4@=F]T<F4@<V5R=F5U<BX`16YR96=I<W1R97(@;&$@8V]N9FEG
M=7)A=&EO;B!D92`E<P!38W)I<'0@9&4@;6ES92#@(&IO=7(@9&4@8V]N9FEG
M=7)A=&EO;B!E;G)E9VES='+I('-O=7.@.B"K("5SH+L`3W)A9V5S(&ES;VSI
M<P!38VEE;F-E`%)E8VAE<F-H90!-;W1E=7)S(&1E(')E8VAE<F-H90!#:&]I
M<VES<V5Z(&QE<R!F:6-H:65R<P!3Z6QE8W1I;VYN97H@=6YE(&1A=&4`4^EL
M96-T:6]N;F5Z('5N(&=R;W5P92#@(&%J;W5T97(`4^EL96-T:6]N;F5Z('5N
M(&YO=79E874@<')O<')IZ71A:7)E`%/I;&5C=&EO;FYE>B!U;B!S97)V975R
M`%/I;&5C=&EO;FYE>B!U;B!U=&EL:7-A=&5U<B#@(&%J;W5T97(`5&]U="!S
MZ6QE8W1I;VYN97(`4^EL96-T:6]N;F5Z('1O=71E<R!L97,@8V]M<&]S86YT
M97,@9&4@;&$@9&%T92X`0VAO:7-I<W-E>B!U;B!O8FIE=`!.92!SZ6QE8W1I
M;VYN97(@875C=6X`4^EL96-T:6]N;F5Z(&QE<R!C87)A8W3H<F5S(&1O;G0@
M=F]U<R!A=F5Z(&)E<V]I;B#@(&PG86ED92!D92!L)V]U=&EL(&-I+61E<W-O
M=7,N(%9O=7,@<&]U=F5Z(&5N<W5I=&4@;&5S(&-O<&EE<B!E="!L97,@8V]L
M;&5R(&1A;G,@=F]T<F4@=&5X=&4N`%/I;&5C=&EO;FYE>B!L92!DZ6QI;6ET
M975R(&1E(&1A=&6@.@!3Z6QE8W1I;VYN97H@;&4@9F]R;6%T(&1E(&1A=&6@
M.@!3Z6QE8W1I;VYN97(@;&4@<')O9FEL('%U92!V;W5S(&3I<VER97H@;6]D
M:69I97(Z`%/I;&5C=&EO;FYE>B!L92!DZ6QI;6ET975R(&0G:&5U<F6@.@!3
MZ6QE8W1I;VYN97H@;&4@9F]R;6%T(&1E(&PG:&5U<F6@.@!3Z6QE8W1I;VYN
M97H@9&5U>"!C:&%M<',@87!P87)E;G3I<RX`4^EL96-T:6]N;F5Z('9O=')E
M('1HZ&UE(&1E(&-O=6QE=7)S+@!3Z6QE8W1I;VYN97H@=F]T<F4@;&%N9W5E
M('!RZ6;I<NEEH#H`16YV;WEE<B!L92!R87!P;W)T(&0G86YO;6%L:64`16YV
M;WEE<B!335,`4^ENZ6=A;`!3;VYD9:`Z(`!397!T96UB<F4`4V5R8FEE(&5T
M($UO;G1E;F5G<F\`3G5MZ7)O(&1E('/I<FEE`$QE<R!D;VYNZ65S(&1U('-E
M<G9E=7(@<V]N="!F875S<V5S(&]U(&YO;B!D:7-P;VYI8FQE<RX`061M:6YI
M<W1R871I;VX@9&5S('-E<W-I;VYS`$ED+B!D92!S97-S:6]N(&5X<&ERZ2X`
M4V5S<VEO;G,`4^EL96-T:6]N;F5R`$-O;F9I9W5R97(@;&5S(&]P=&EO;G,@
M<&]U<B!V;W5S('!E<FUE='1R92!D92!R96UE='1R92#@('KI<F\@=F]T<F4@
M;6]T(&1E('!A<W-E('-I(&IA;6%I<R!V;W5S(&PG;W5B;&EE>BX`0V]N9FEG
M=7)E<B!L97,@<V5R=F5U<G,@9&ES=&%N=',@86-C97-S:6)L97,@9&5P=6ES
M('9O=')E('!O<G1A:6PN`%/I;&5C=&EO;FYE>B!V;W1R92!L86YG=64@<'+I
M9NERZ64L(&9U<V5A=2!H;W)A:7)E(&5T(&QE<R!O<'1I;VYS(&1E(&1A=&4N
M`$3I9FEN:7-S97H@;&$@<')E;6GH<F4@87!P;&EC871I;VX@;&%N8^EE+"!L
M92!T:.AM92!D92!C;W5L975R<RP@;&4@<F%F<F'N8VAI<W-E;65N="!D97,@
M<&%G97,L(&5T(&0G875T<F5S(&]P=&EO;G,@9"=A9F9I8VAA9V4N`$-O;F9I
M9W5R871I;VX`4V-R:7!T(&1E(&-O;F9I9W5R871I;VX@9&4@;6ES92#@(&IO
M=7(@9&ES<&]N:6)L90!0;'5S:65U<G,@96YD<F]I=',@<&]S<VEB;&5S(&%V
M96,@;&4@<&%R86WH=')EH#H@`%-E>6-H96QL97,`06-H870`4NES=6WI`$1O
M:70M;VX@9.EF:6YI<B!D97,@=&]U8VAE<R!D92!R86-C;W5R8VES('!O=7(@
M;&$@<&QU<&%R="!D97,@;&EE;G.@/P!!9F9I8VAE<@!-;VYT<F5R(&QE<R!D
M:69FZ7)E;F-E<R!E;G1R92!L82!C;VYF:6=U<F%T:6]N(&5N<F5G:7-T<NEE
M(&%C='5E;&QE;65N="!E="!C96QL92!N;W5V96QL96UE;G0@9^ENZ7+I92X`
M36]N=')E<B!L)VAE=7)E(&1E(&QA(&1E<FYIZ')E(&-O;FYE>&EO;B#@(&PG
M96YT<NEEH#\`36]N=')E<B!L)V]P=&EO;B!D92!C;VYS97)V97(@;"=O<FEG
M:6YA;`!-;VYT<F5R(&QE('/I;&5C=&5U<@!!9F9I8VAE<B!L82!B87)R92!D
M92!M96YU(&1E('1A8FQE875XH#\`069F:6-H97(@;&4@;65N=2`E<R#@(&=A
M=6-H9:`_`$%F9FEC:&5R(&QA(&)O[G1E(&1E(&1I86QO9W5E('1A8FQE874@
M8V5L;'5L90!!9F9I8VAE<B!L82!B;^YT92!D92!D:6%L;V=U92!D97,@<')O
M<')IZ73I<R!D=2!T86)L96%U`$%F9FEC:&5R(&QA(&)O[G1E(&1E(&1I86QO
M9W5E(&1E<R!P<F]P<FGI=.ES(&1E(&QA(')A;F?I92!D=2!T86)L96%U`$%F
M9FEC:&5R(&QA(&)O[G1E(&1E(&1I86QO9W5E(&1E<R!P<F]P<FGI=.ES(&1E
M(&PG:6UA9V4`069F:6-H97(@;"=E;G9O:2!D92!F:6-H:65R`$%V97)S97,`
M079E<G-E<R!T]'0@9&%N<R!L82!J;W5R;NEE`$%V97)S97,@=&%R9"!E;B!J
M;W5R;NEE`$%V97)S97,@875X(&%L96YT;W5R<P!297-S97)R97(`4F5S<V5R
M<F5R(&]U(&3I9V%G97(@9"=A8F]R9"!L92AS*2!B;&]C*',I('9O:7-I;BAS
M*0!3:65R<F$@3&5O;F4`4R=I;G-C<FER90!3:6=N871U<F4`06QG;W)I=&AM
M92!D92!S:6=N871U<F4`4VEN9V%P;W5R`%1A:6QL90!!;FYU;&5R(&QA(&UA
M:6YT96YA;F-E`%-L;W9A<75I90!3;&]VZ6YI90!.96EG90!!=F5R<V4@9&4@
M;F5I9V4`079E<G-E<R!D92!N96EG90!!=F5R<V5S(&1E(&YE:6=E('3T="!D
M86YS(&QA(&IO=7)NZ64`079E<G-E<R!D92!N96EG92!T87)D(&5N(&IO=7)N
MZ64`2&%U=&5U<B!D92!N96EG9:`Z(`!1=6%N=&ETZ2!D)V5A=2#I<75I=F%L
M96YT92#@(&QA('%U86YT:73I(&1E(&YE:6=EH#H@`,YL97,@4V%L;VUO;@!3
M;VUA;&EE`$-H86YS;VYS(&5T('!OZ&UE<P!3Z6QE8W1I;VX@9&4@;"=O<F1R
M92!D92!T<FD`061R97-S92!S;W5R8V4`069R:7%U92!D=2!S=60`4W5D+65U
M<F]PZ65N("A)4T\M.#@U.2TS*0!'Z6]R9VEE+61U+7-U9"!E="#N;&5S(%-A
M;F1W:6-H+61U+7-U9`!(Z6UI<W!HZ')E(%-U9`!%<W!A8V4@96YT<F4@8V5L
M;'5L97,@861J86-E;G1E<P!%<W!A8V4@96YT<F4@;&4@8V]N=&5N=2!E="!L
M82!B;W)D=7)E(&1A;G,@=6YE(&-E;&QU;&4`17-P86-E=7(`17-P86-E;65N
M=`!%<W!A8V5M96YT(&5T(')E;7!L:7-S86=E`$5S<&%G;F4`4&]U<G)I96P`
M0V%R86-TZ')E<R!S<.EC:6%U>`!38VEN9&5R(&QA(&-E;&QU;&4`4V-I;F1E
M<B!L82!C;VQO;FYE`%-C:6YD97(@;&$@<F%N9^EE`%-P;W)T<P!3<FD@3&%N
M:V$`4W1A;F1A<F0`4W1A<B!4<F5K`$%N;NEE(&1E(&3I8G5T`,ET870@;W4@
M<')O=FEN8V4`4W1A='5T`$9O<FUA="!D92!S875V96=A<F1E`%)U90!"87)R
MZ0!,:7-T92!D92!C:&'N;F5S`%)E=&ER97(@;&4@9&]M86EN92!D92!L)V%D
M<F5S<V4`4W1Y;&4@6T-34UT`1&D`4V]U<RURZ7!E<G1O:7)E(*N@)7.@NR!N
M;VX@=')O=7;I`%-U:F5T`$5N=F]I`$QA(&1E;6%N9&4@9"=A:F]U="!D92"K
MH"5SH+L@874@<WES=.AM92!A(.ETZ2!S;W5M:7-E+B!6;W5S(&YE('!O=7)R
M97H@<&%S('9O=7,@8V]N;F5C=&5R(&IU<W%U)^`@<V]N(&%P<')O8F%T:6]N
M+@!);F1I8V4`4W5C8^AS`*N@)7.@NR!A(&)I96X@Z73I(&%J;W5TZ2AE*2X`
M3&5S(&1O;F[I97,@9&4@;"=U=&EL:7-A=&5U<B"KH"5SH+L@;VYT(&)I96X@
MZ73I(')E=&ERZ65S(&1U('-Y<W3H;64N+@"KH"5SH+L@82!B:65N(.ETZ2!S
M=7!P<FEMZ2AE*2X`JZ`E<Z"[(&$@8FEE;B#I=.D@<F5T:7+I*&4I+@!2971O
M=7(@X"!L82!C;VYF:6=U<F%T:6]N(&EN:71I86QE('+I=7-S:2X@(%)A9G)A
M[F-H:7(@;&$@<&%G92!P;W5R('9O:7(@;&5S(&UO9&EF:6-A=&EO;G,N`$5N
M<F5G:7-T<F5M96YT(&1E(&QA(&-O;F9I9W5R871I;VX@9&4@;&$@<V%U=F5G
M87)D92!RZ75S<VDN`$5N<F5G:7-T<F5M96YT('+I=7-S:2!D92!L82!C;W!I
M92!D92!S875V96=A<F1E(&1U(&9I8VAI97(@9&4@8V]N9FEG=7)A=&EO;B`E
M<RX`JZ`E<Z"[(&$@8FEE;B#I=.D@;6ES*&4I(.`@:F]U<BX`R6-R:71U<F4@
M9&4@)7,@<NEU<W-I`%-O=61A;@!3;VUM86ER90!,979E<B!D=2!3;VQE:6P`
M0V]U8VAE<B!D=2!3;VQE:6P`16YS;VQE:6QLZ0!,979E<B!D=2!3;VQE:6P`
M3&5V97(O0V]U8VAE<B!D=2!3;VQE:6P`3&5V97(@9'4@4V]L96EL.B``0V]U
M8VAE<B!D=2!3;VQE:6P`0V]U8VAE<B!D=2!3;VQE:6R@.B``17AP;W-A;G0`
M07-S:7-T86YC90!3=7)I;F%M(&]U($=U>6%N92!H;VQL86YD86ES90!.;VT@
M9&4@9F%M:6QL90#.;&5S(%-V86QB87)D(&5T($IA;B!-87EE;@!3=V%Z:6QA
M;F0`4W7H9&4`4W5I<W-E`$IO=7)N86P@9&4@<WEN8VAR;VYI<V%T:6]N('-U
M<'!R:6WI`%-Y;F--3`!%<G)E=7(@9&4@<WEN=&%X92!D86YS(&QE<R!T97)M
M97,@9&4@<F5C:&5R8VAE`%-Y<FEE`$]R86=E<P!/<F%G92!E="!V96YT`$]R
M86=E<P!/<F%G97,@;6%T:6YA=7@`1FEC:&EE<B!44U8`4')O<')IZ73I<R!D
M=2!T86)L96%U`%1A8FQE874@9&4@=F%L975R<P!0<F]P<FGI=.ES(&1U('1A
M8FQE874`5&'O=V%N`%1A[W=A;BP@<')O=FEN8V4@9&4@0VAI;F4`5&%J:6MI
M<W1A;@!486YZ86YI90!#:6)L9:`Z`%3B8VAE<P!.=6WI<F\@9&4@=.ELZ7!H
M;VYE`%1E;7#I<F%T=7)E('!O=7(@;&$@9&5R;FGH<F4@:&5U<F6@.B``5&5M
M<.ER871U<F4`5&5M<.ER871U<F6@.B``5&5M<.ER871U<F4\8G(@+SXH)7-(
M825S+R5S0F$E<RD@)F1E9SLE<P!0<F]F:6P@JZ`E<Z"[(&YO;B!T<F]U=ND`
M061M:6YI<W1R871I;VX@9&5S(&UO9.AL97,`5&5X=&4`5&5X=&4@<V5U;`!!
M;&EG;F5M96YT(&1U('1E>'1E`%1E>'1E(&5N(&AA=70`2F4`5&AA[R`H5$E3
M+38R,"D`5&AA[VQA;F1E`$PG97AT96YS:6]N($944"!N)V5S="!P87,@9&ES
M<&]N:6)L92X`3"=H:7-T;W)I<V%T:6]N(&5S="!DZ7-A8W1I=NEE+@!,92!M
M;W1E=7(@9"=I;G3I9W)A=&EO;B!(;W)D92]+;VQA8B!N92!S=7!P;W)T92!P
M87,@JZ`E<Z"[`$QE(&IO=7)N86P@24U34"!N)V$@<&%S('!U(.IT<F4@:6YI
M=&EA;&ESZ2X`3&$@8VQA<W-E($UA:6YT96YA;F-E.CH@;B=A('!A<R#I=.D@
M8VAA<F?I92!C;W)R96-T96UE;G0`3&$@9F5NZG1R92!D97,@;W!T:6]N<R!S
M)V5S="!F97)MZ64N(%-O<G1I92X`3"=A9&UI;FES=')A=&5U<B!D;VET(&-O
M;F9I9W5R97(@=6X@8F%C:V5N9"!P97)M86YE;G0@<&]U<B!L97,@<&5R;6ES
M<VEO;G,@<VD@=F]U<R!V;W5L97H@;&5S(&5M<&QO>65R+@!,82!B;W)D=7)E
M(&1U(&)A<R!S975L96UE;G0`3"=)1"!D=2!C;VYT86-T(&XG82!P87,@Z73I
M('-PZ6-I9FGI+"!L86ES<^D@=FED92!O=2!N)V$@<&%S(.ETZ2!T<F]U=ND@
M9&%N<R!L82!B87-E(&1E(&1O;F[I97,N`$-E(&-O;G1A8W0@82!B:65N(.ET
MZ2!A:F]U=.D@X"!V;W1R92!C87)N970@9"=A9')E<W-E<RX@`$QE(&)L;V,@
M9&4@<VEG;F%T=7)E(%!'4"!SZ7!A<ND@97-T(&[I8V5S<V%I<F4@<&]U<B!V
MZ7)I9FEE<B!L82!S:6=N871U<F4N`$PG240@9&4@;&$@;&ES=&4@;B=A('!A
M<R#I=.D@<W#I8VEF:>DL(&QA:7-SZ2!V:61E(&]U(&YO;B!T<F]U=ND@9&%N
M<R!L82!B87-E(&1E(&1O;F[I97,N`$QA(&QI<W1E(&1E(&1I<W1R:6)U=&EO
M;B!N)V$@<&%S(.ETZ2!S<.EC:69IZ64N`$QE(&-H:69F<F5M96YT(&[I8V5S
M<VET92!U;F4@8V]N;F5X:6]N('/I8W5R:7/I92X`3&4@9FEC:&EE<B`E<R!D
M;VET(&-O;G1E;FER(&QE<R!O<'1I;VYS("5S+@!,92!F:6-H:65R("5S(&1O
M:70@8V]N=&5N:7(@8V5R=&%I;F5S(&]P=&EO;G,@)7,N`$QE(&9I8VAI97(@
M;F4@<&5U="!P87,@ZG1R92!C;W!IZ2!S=7(@;'5I+6WJ;64N`$QE(&9I8VAI
M97(@;F4@8V]N=&5N86ET(&%U8W5N92!D;VYNZ64N`$-E('%U:2!S=6ET('-O
M;G0@;&5S(&5N+73J=&5S('!O=7(@8V4@;65S<V%G92!M97-S86=E+U)&0S@R
M,BX`3&4@;6]D92!P;&5I;B#I8W)A;B!C875S92!D97,@<')O8FSH;65S(&%V
M96,@26YT97)N970@17AP;&]R97(@9/L@X"!D97,@8F]G=65S(&1U(&YA=FEG
M871E=7(@<75I(&XG;VYT('!U(.IT<F4@8V]N=&]U<F[I<RX@5F]U<R!P;W5V
M97H@ZG1R92!C;VYF<F]N=.ES(.`@9&4@;"=A9F9I8VAA9V4@9&4@8V%R86-T
MZ')E<R#I=')A;F=E<RP@874@;F]N+69O;F-T:6]N;F5M96YT(&1E<R!C97)T
M86EN97,@9F]N8W1I;VYS(&5T+V]U(&%U('!L86YT86=E(&%LZ6%T;VER92!D
M=2!N879I9V%T975R+B!3:2!V;W1R92!S>7-TZ&UE(&5S="!U;B!7:6YD;W=S
M(#EX+"!I;"!E<W0@='+H<R!P;W-S:6)L92!Q=64@=F]U<R!A=7)E>B!U;F4@
M)T9A=71E(&?I;NER86QE(&1E('!R;W1E8W1I;VXG(&5T('%U92!V;W5S(&1E
M=G)E>B!R963I;6%R<F5R('9O=')E(&]R9&EN871E=7(N7&Y<;E9O=7,@879E
M>B#I=.D@<'+I=F5N=7,N(%-64"!A<'!U>65Z('-U<B!/2R!S:2!V;W5S('9O
M=6QE>B!T;W5J;W5R<R!E<W-A>65R(&QE(&UO9&4@<&QE:6X@Z6-R86X@9&4@
M;"?I9&ET975R`$PG:61E;G1I=.D@JZ`E<Z"[("!A(.ETZ2!S=7!P<FEMZ64N
M`$QE(&/T=.D@9V%U8VAE('-E=6QE;65N=`!,)V5M<&QA8V5M96YT(&1U('!R
M;V=R86UM92!';G501R!D;VET(.IT<F4@9F]U<FYI(.`@;&$@8VQA<W-E($-R
M>7!T7W!G<#HZ+@!,92!M97-S86=E(&5N=F]YZ2!L92`E<R#@("5S(&%V96,@
M8V]M;64@<W5J970@JZ`E<Z"[(&$@Z73I(&%F9FEC:.DN(`I);"!N)WD@82!A
M=6-U;F4@9V%R86YT:64@<75E(&-E(&UE<W-A9V4@82#I=.D@;'4@;W4@8V]M
M<')I<RX`3&4@;F]M(.`@=71I;&ES97(@96X@;&EA;G0@X"!L82!P86=E(&1E
M(&-O;7!O<VET:6]N`$QE(&YO;6)R92!D92!C:&%M<',@9&]I="#J=')E('5N
M(&YO;6)R92!V86QI9&4N`$QE(&UO9'5L92!/<&5N4U-,(&5S="!R97%U:7,@
M<&]U<B!L82!C;&%S<V4@2&]R9&5?0W)Y<'1?<VUI;64Z.BX`3&$@<'+I9NER
M96YC92"KH"5SH+L@;B=A('!A<R!P=2#J=')E(&5N<F5G:7-T<NEE(&-A<B!S
M82!T86EL;&4@9.EP87-S92!L92!M87AI;75M(&%U=&]R:7/I`$QE('!R;V=R
M86UM92!U=&EL:7/I('!O=7(@=FES=6%L:7-E<B!C92!T>7!E(&1E(&1O;F[I
M97,@*"5S*2!N)V$@<&%S(.ETZ2!T<F]U=NDN`$QE(&-A<F%C=.AR92!D92!P
M<F]T96-T:6]N(&1O:70@ZG1R92!U;B!C87)A8W3H<F4@=6YI<75E+@!,97,@
M8_1TZ7,@9V%U8VAE(&5T(&1R;VET('-E=6QE;65N=`!,92!C]'3I(&1R;VET
M('-E=6QE;65N=`!,92!SZ7!A<F%T975R(&1O:70@ZG1R92!U;B!C87)A8W3H
M<F4@=6YI<75E+@!,92!S97)V975R(*N@)7.@NR!A(.ETZ2!S=7!P<FEMZ2X`
M3&4@<V5R=F5U<B"KH"5SH+L@82#I=.D@96YR96=I<W1RZ2X`3&$@<F5Q=>IT
M92!D)V5N<F5G:7-T<F5M96YT('!O=7(@)7,@82#I=.D@9.EP;&%CZ64N`$QA
M(&QI9VYE(&1E;6%N9.EE("@E9"D@;B=E>&ES=&4@<&%S+@!,92!F:6-H:65R
M('1E;7!O<F%I<F4@JR`E<Z"[(&XG97AI<W1E('!A<RX`3&4@=&5X=&4@96YT
M<ND@;F4@8V]R<F5S<&]N9"!P87,@874@=&5X=&4@<W5R(&PGZ6-R86XN`$QE
M(&AA=70@970@;&4@8F%S('-E=6QE;65N=`!,92!H875T('-E=6QE;65N=`!,
M97,@9&]N;NEE<R!TZ6SI8VAA<F?I97,@=F5R<R!L92!S97)V975R(&]N="#I
M=.D@<&5R9'5E<R!D97!U:7,@;"?I=&%P92!P<NECZ61E;G1E+B``3&4@9FEC
M:&EE<B#I;6ES(&XG82!P87,@<'4@ZG1R92!E;G)E9VES='+I+@!,92!B;&]C
M(*N@=V5A=&AE<BYC;VV@NR!N)V5S="!P87,@9&ES<&]N:6)L92X`4NEP97)T
M;VER92!D97,@=&CH;65S(*N@)7.@NR!N;VX@=')O=7;I`$EL(&XG>2!A('!A
M<R!D)V]P=&EO;G,@9&ES<&]N:6)L97,`075C=6YE('!A<G1I92!N92!P975T
M(.IT<F4@869F:6-HZ64@96X@;&EG;F4N`$EL('D@(&$@=')O<"!D92!C87)A
M8W3H<F5S(&1A;G,@8V4@8VAA;7`N(%9O=7,@96X@879E>B!E;G1RZ2`E<Z`[
M(&EL(&5N(&9A=70@;6]I;G,@9&4@)7,N`%5N('!R;V)LZ&UE(&5S="!A<'!A
M<G4@;&]R<R!D92!L)V%J;W5T(&1E(*N@)7.@NZ`Z("5S`%5N('!R;V)LZ&UE
M(&5S="!A<'!A<G4@;&]R<R!D92!L82!S=7!P<F5S<VEO;B!D97,@9&]N;NEE
M<R!D92!L)W5T:6QI<V%T975R(*N@)7.@NZ`Z(`!5;B!P<F]B;.AM92!E<W0@
M87!P87)U(&QO<G,@9&4@;&$@<W5P<')E<W-I;VX@9&4@JZ`E<Z"[H#H@`%5N
M('!R;V)LZ&UE(&5S="!A<'!A<G4@;&]R<R!D92!L82!M:7-E(.`@:F]U<B!D
M92"KH"5SH+N@.B`E<P!5;B!P<F]B;.AM92!E<W0@87!P87)U(&QO<G,@9&4@
M;"=E;G9O:2!D=2!F:6-H:65RH#H@875C=6X@)7,@;B=A(.ETZ2!T<F%N<VUI
M<RX`56YE(&5R<F5U<B!E<W0@<W5R=F5N=64@;&]R<R!D92!L)V5N=F]I(&1U
M(&9I8VAI97*@.B!L92`E<R#I=&%I="!P;'5S(&=R;W,@<75E(&QE(&UA>&EM
M=6T@875T;W)I<^D@*"5D(&]C=&5T<RDN`%5N92!E<G)E=7(@97-T('-U<G9E
M;G5E(&QO<G,@9&4@;"=E;G9O:2!D=2!F:6-H:65RH#H@;&4@)7,@82#I=.D@
M=')A;G-M:7,@<&%R=&EE;&QE;65N="X`56YE(&5R<F5U<B!S)V5S="!P<F]D
M=6ET92!L;W)S(&1E(&PG869F:6-H86=E(&1E(&-E='1E('!A<G1E(&1U(&UE
M<W-A9V4`56YE(&5R<F5U<B!S)V5S="!P<F]D=6ET92!L;W)S(&1E(&PG:6UP
M;W)T871I;VX@9&5S(&1O;F[I97,@9&4@8V4@8V]N=&%C="X`56YE(&5R<F5U
M<B!S)V5S="!P<F]D=6ET92!L;W)S(&1E(&PG:6UP;W)T871I;VX@9&4@8V5T
M=&4@8V%R=&4@:4-A;&5N9&%R+@!);"!Y(&%V86ET('5N92!E<G)E=7(@9&%N
M<R!L92!F;W)M=6QA:7)E(&1E(&-O;F9I9W5R871I;VXN(%!E=70MZG1R92!A
M=F5Z+79O=7,@;&%I<W/I('5N(&-H86UP(')E<75I<R!V:61E+@!5;F4@97)R
M975R(',G97-T('!R;V1U:71E(&QO<G,@9&4@;"=E>.EC=71I;VX@9&4@8V5T
M=&4@9F]N8W1I;VX@9'4@8V%R;F5T(&0G861R97-S92X@4U90(&5S<V%Y97(@
MX"!N;W5V96%U('!L=7,@=&%R9"X`26P@>2!A(&5U('5N92!E<G)E=7(@;&]R
M<R!D92!L82!M:7-E(.`@:F]U<B!D97,@:6YF;W)M871I;VYS('-U<B!L92!C
M;VYT86-T+B`@5F5U:6QL97H@97-S87EE<B#@(&YO=79E874N`$EL('D@82!E
M=2!U;F4@97)R975R(&QO<G,@9&4@;&$@;6ES92#@(&IO=7(@9&4@;&$@;&ES
M=&4@9&4@9&ES=')I8G5T:6]N+B`@5F5U:6QL97H@97-S87EE<B!D92!N;W5V
M96%U+@!,92!P<NES96YT('-E<G9E=7(@24U!4"!N92!S=7!P;W)T92!P87,@
M;&4@<&%R=&%G92!D92!D;W-S:65R<RX`QV$@;F4@<V5M8FQE('!A<R#J=')E
M('5N92!A<F-H:79E(%)!4B!V86QI9&4N`,=A(&YE('-E;6)L92!P87,@ZG1R
M92!U;B!F:6-H:65R(%I)4"!V86QI9&4N`,=A(&YE('-E;6)L92!P87,@ZG1R
M92!U;B!N=6WI<F\@9&4@8V%R=&4@=F%L:61E+@!#92!P:6QO=&4@<&5R;65T
M(&PG96YV;VD@9&4@;65S<V%G97,@X"!T<F%V97)S(&QA('!A<W-E<F5L;&4@
M0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!E;B!U=&EL:7-A
M;G0@;"=!4$D@2%144`!#92!P:6QO=&4@<&5R;65T(&PG96YV;VD@9&4@;65S
M<V%G97,@=FEA(&QA('!A<W-E<F5L;&4@5TE.("AH='1P.B\O=VEN<&QC+F-O
M;2D@96X@=71I;&ES86YT(&PG05!)($A45%``0V4@<&EL;W1E('!E<FUE="!L
M)V5N=F]I(&1E(&UE<W-A9V5S(.`@=')A=F5R<R!L82!P87-S97)E;&QE('-M
M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&5N('5T:6QI<V%N="!L
M)T%022!(5%10`$-E('!I;&]T92!P97)M970@;"=E;G9O:2!D92!M97-S86=E
M<R!P87(@4TU44"#@('1R879E<G,@;&$@<&%S<V5R96QL92!6;V1A9F]N92!)
M=&%L:64L('-E=6QE;65N="!A=7@@;G5MZ7)O<R!6;V1A9F]N92X@0V5L82!N
MZ6-E<W-I=&4@=6X@8V]M<'1E(&1E(&-O=7)R:65L(%9O9&%F;VYE($ET86QI
M92`H:'1T<#HO+W=W=RXQ.3`N:70I+@!#92!C:&%M<"!E<W0@;V)L:6=A=&]I
M<F4N`$-E(&-H86UP(&YE(&1O:70@8V]N=&5N:7(@<75E(&1E<R!E;G1I97)S
M+@!#92!C:&%M<"!N92!D;VET(&-O;G1E;FER('%U92!D97,@;F]M8G)E<R!E
M="!L97,@9&5U>"UP;VEN=',N`$-E(&-H86UP(&YE(&1O:70@8V]N=&5N:7(@
M<75E(&1E<R!V86QE=7)S(&]C=&%L97,N`$-E(&-H86UP(&1O:70@8V]N=&5N
M:7(@=6YE(&QI<W1E(&0G96YT:65R<R!SZ7!A<NES('!A<B!D97,@=FER9W5L
M97,@;W4@9&5S(&5S<&%C97,`0V4@8VAA;7`@9&]I="#J=')E('5N(&YO;6)R
M92!V86QI9&4N`$-E(&-H86UP(&1O:70@8V]N=&5N:7(@=6X@8V]D92!D92!C
M;W5L975R(&%U(&9O<FUA="!21T(@:&5X863I8VEM86PL('!A<B!E>&5M<&QE
M("<C,3(S-&%F)RX`0V4@9F]R;75L86ER92!A(&3I:N`@Z73I('1R86ETZ2X`
M0R=E<W0@)7,N`$-E8VD@97-T('5N(&]B:F5T($MO;&%B($=R;W5P=V%R92X@
M4&]U<B!V;VER(&-E="!O8FIE="P@=F]U<R!D979R97H@879O:7(@=6X@8VQI
M96YT(&1E(&-O=7)R:65L('%U:2!C;VUP<F5N9"!L92!F;W)M870@2V]L86(@
M1W)O=7!W87)E+B!0;W5R('5N92!L:7-T92!D92!C97,@8VQI96YT<R!D92!C
M;W5R<FEE;"P@=FES:71E>B`E<P!#92!M97-S86=E(&$@Z73I(.EC<FET(&1A
M;G,@=6X@8V]D92!D92!C87)A8W3H<F5S("@E<RD@875T<F4@<75E(&QE(';T
M=')E+@!#92!N;VUB<F4@9&]I="#J=')E('-U<.ER:65U<B#@('5N+@!#92!S
M97)V975R(&YE('!E=70@<&%S(&3I8V]M<')E<W-E<B!L97,@9FEC:&EE<G,@
M6DE0(&5T(&=Z:7`N`$-E('-Y<W3H;64@97-T('!RZ7-E;G1E;65N="!DZ7-A
M8W1I=NDN`$-E='1E('9A;&5U<B!D;VET(.IT<F4@=6X@;F]M8G)E+@!#971T
M92!F96[J=')E(&1O:70@ZG1R92!A<'!E;.EE(&1E<'5I<R!U;F4@9F5NZG1R
M92!D97,@;W!T:6]N<P!4;VYN97)R90!4:6-K971S`$AE=7)E`%-U:79I(&AO
M<F%I<F4`1F]R;6%T(&0G:&5U<F4`4^EL96-T:6]N(&1E(&PG:&5U<F4`5&EM
M;W(@;W)I96YT86P`5&ET<F4`5&ET<F4@*&EN9F]B=6QL92F@.@#``%!O=7(@
M<^EL96-T:6]N;F5R('!L=7-I975R<R!I=&5M<R#@(&QA(&9O:7,L(&UA:6YT
M96YE>B!E;F9O;F/I(&QE(&)O=71O;B"KH$-T<FR@NR`H4$,I(&]U(*N@0V]M
M;6%N9&6@NR`H36%C*2!E;B!C;&EQ=6%N="X`075J;W5R9"=H=6D`5F]I<B!L
M82!S;W5R8V4@2%1-3`!4;V=O`%1O:V5L874`1&5M86EN`%1O;F=A`%1R;W`@
M9&4@8V]N;F5X:6]N<R!I;F9R=6-T=65U<V5S(&1A;G,@;&5S(&1E<FYIZ')E
M<R!M:6YU=&5S+@!(875T`$-A9')E(&1U(&AA=70@*%]T;W`I`%1R861U8W1I
M;VYS`%1R:6YI=.DM970M5&]B86=O`%9R86D@;W4@9F%U>`!-80!4=6YI<VEE
M`%1U<G%U:64`5'5R8R`H25-/+3@X-3DM.2D`5'5R:VWI;FES=&%N`,YL97,@
M5'5R<75E<R!E="!#8>]Q=65S`%1U=F%L=0!%;G1R97H@=F]T<F4@8VAO:7B@
M.B``26YD:6-E(%56H#H@`%523`!54DP@<&]U<B!V;W1R92!R87!P;W)T(&1E
M(&QI=G)A:7-O;B!D=2!S8W)I<'0`55),.@!/=6=A;F1A`%5K<F%I;F4`26UP
M;W-S:6)L92!D)V%T=&5I;F1R92!L92!RZ7!E<G1O:7)E(%9&4RX`26UP;W-S
M:6)L92!D)V%J;W5T97(@9&5S(&EN9F]R;6%T:6]N<R!C;VUP;.EM96YT86ER
M97,@X"!L)VEN<V-R:7!T:6]N+@!);7!O<W-I8FQE(&1E(&UO9&EF:65R(&QE
M<R!P97)M:7-S:6]N<R!P;W5R(&QE(&9I8VAI97(@5D93(*N@)7.@NRX`26UP
M;W-S:6)L92!D92!M;V1I9FEE<B!L97,@<&5R;6ES<VEO;G,@<&]U<B!L92!F
M:6-H:65R(%9&4R`E<R\E<RX`26UP;W-S:6)L92!D92!C:&%N9V5R('!O=7(@
M)7,N`$EM<&]S<VEB;&4@9&4@=NER:69I97(@;&$@=&%I;&QE(&1U(&9I8VAI
M97(@9&4@JZ`E<Z"[+@!);7!O<W-I8FQE(&1E(';I<FEF:65R(&QA('1A:6QL
M92!D=2!F:6-H:65R(&1E(*L@)7,O)7,@NRX`0V]N;F5X:6]N(&EM<&]S<VEB
M;&4@874@<V5R=F5U<B!344PN`$-O;FYE>&EO;B!I;7!O<W-I8FQE(&5N(%-3
M3`!);7!O<W-I8FQE(&1E(&-O<&EE<B!U;B!F:6-H:65R(%9&4RX`26UP;W-S
M:6)L92!D92!C<NEE<B!U;B!RZ7!E<G1O:7)E(%9&4R"KH"5SH+LN`$EM<&]S
M<VEB;&4@9&4@8W+I97(@=6X@<NEP97)T;VER92!61E,N`$EM<&]S<VEB;&4@
M9&4@8W+I97(@;&4@9FEC:&EE<B!61E,N`$EM<&]S<VEB;&4@9&4@8W+I97(@
M;&4@<NEP97)T;VER92!61E,@JZ`E<Z"[+@!);7!O<W-I8FQE(&1E(&-RZ65R
M('5N(&9I8VAI97(@5D93('9I9&4N(`!/=79E<G1U<F4@:6UP;W-S:6)L92!D
M92!L)V%R8VAI=F4@8V]M<')E<W/I92X@`%-U<'!R97-S:6]N(&EM<&]S<VEB
M;&4@9&4@JZ`E<Z"[+"!L92!D;W-S:65R(&XG97-T('!A<R!V:61E+@!3=7!P
M<F5S<VEO;B!I;7!O<W-I8FQE(&1E(*N@)7.@NZ`Z("5S+@!3=7!P<F5S<VEO
M;B!I;7!O<W-I8FQE(&1E("5S+"!L92!D;W-S:65R(&XG97-T('!A<R!V:61E
M`%-U<'!R97-S:6]N('+I8W5R<VEV92!D=2!D;W-S:65R(%9&4R!I;7!O<W-I
M8FQE+@!3=7!P<F5S<VEO;B!D=2!RZ7!E<G1O:7)E(%9&4R!I;7!O<W-I8FQE
M+@!);7!O<W-I8FQE(&1E('-U<'!R:6UE<B!L92!RZ7!E<G1O:7)E(%9&4Z`Z
M("5S+@!3=7!P<F5S<VEO;B!I;7!O<W-I8FQE(&1U(&9I8VAI97(@5D93(*N@
M)7.@NRX`4W5P<')E<W-I;VX@:6UP;W-S:6)L92!D=2!F:6-H:65R(%9&4RX`
M4W5P<')E<W-I;VX@:6UP;W-S:6)L92!D=2!RZ7!E<G1O:7)E(%9&4R"KH"5S
MH+LN`%-U<'!R97-S:6]N(%9&4R!RZ6-U<G-I=F4@:6UP;W-S:6)L9:`Z("5S
M+@!);7!O<W-I8FQE(&1E(&3I=&5R;6EN97(@;&4@9&]S<VEE<B!C;W5R86YT
M+@!);7!O<W-I8FQE(&0G97AT<F%I<F4@;&5S(&3I=&%I;',@9'4@8V5R=&EF
M:6-A=`!);7!O<W-I8FQE(&1E(&-H87)G97(@;&$@9.EF:6YI=&EO;B!D92`E
M<RX`26UP;W-S:6)L92!D92!DZ7!L86-E<B!L92!F:6-H:65R(%9&4RX`26UP
M;W-S:6)L92!D)V]U=G)I<B!L92!F:6-H:65R(%9&4R"KH"5SH+LN`$EM<&]S
M<VEB;&4@9"=O=79R:7(@=6X@9FEC:&EE<B!61E,@96X@Z6-R:71U<F4N`$EM
M<&]S<VEB;&4@9"=O=79R:7(@=6X@9FEC:&EE<B!61E,N`$]U=F5R='5R92!I
M;7!O<W-I8FQE(&1E(&PG87)C:&EV92!C;VUP<F5S<^EE+@!);7!O<W-I8FQE
M(&1E(&QI<F4@;&4@9FEC:&EE<B!61E,@*.EC:&5C(&1E(&9I;&5S:7IE*"DI
M+@!);7!O<W-I8FQE(&1E(&QI<F4@;&4@9FEC:&EE<B!61E,@*.EC:&5C(&1E
M(&=E=$9I;&53:7IE*"DI+@!);7!O<W-I8FQE(&1E(&QI<F4@;&4@9FEC:&EE
M<J`Z(`!,96-T=7)E(&1U('+I<&5R=&]I<F4@<F%C:6YE(%9&4R!I;7!O<W-I
M8FQE+@!);7!O<W-I8FQE(&1E(')E;F]M;65R("5S(&5N("5SH#H@;&4@9&]S
M<VEE<B!C:6)L92!E>&ES=&4@9.EJX`!);7!O<W-I8FQE(&1E(')E;F]M;65R
M(&QE('+I<&5R=&]I<F4@5D93+@!);7!O<W-I8FQE(&1E(')E;F]M;65R(&QE
M('+I<&5R=&]I<F4@5D93H#H@)7,N`$EM<&]S<VEB;&4@9&4@<F5N;VUM97(@
M;&4@9FEC:&EE<B!61E,@JZ`E<Z"[+@!);7!O<W-I8FQE(&1E(')E;F]M;65R
M(&QE(&9I8VAI97(@5D93("5S+R5S+@!);7!O<W-I8FQE(&1E(')E;F]M;65R
M(&QE(&9I8VAI97(@5D93+@!);7!O<W-I8FQE(&0G97CI8W5T97(@)VUK:7-O
M9G,G+@!);7!O<W-I8FQE(&1E('1R861U:7)E(&-E(&1O8W5M96YT(%=O<F0N
M`$EM<&]S<VEB;&4@9"?I8W)I<F4@;&4@9FEC:&EE<B!61E,@JZ`E<Z"[+@!)
M;7!O<W-I8FQE(&0GZ6-R:7)E(&QE<R!D;VYNZ65S(&1U(&9I8VAI97(@5D93
M("AC;W!Y*"D@:6UP;W-S:6)L92DN`$EM<&]S<VEB;&4@9"?I8W)I<F4@;&5S
M(&1O;F[I97,@9'4@9FEC:&EE<B!61E,N`$EM<&]S<VEB;&4@9"?I8W)I<F4@
M;&4@9FEC:&EE<B!61E,L(&QE('%U;W1A('-E<F%I="!DZ7!A<W/I+@!3;W5L
M:6=N97(`06YN=6QE<B!L97,@8VAA;F=E;65N=',`06YN=6QE('9O=')E(&1E
M<FYIZ')E(&%C=&EO;@!2Z7!O;G-E(&EN871T96YD=64@9'4@<V5R=F5U<B!L
M;W)S(&1E(&QA(&-O;FYE>&EO;J`Z(`!2Z7!O;G-E(&EN871T96YD=64@9'4@
M<V5R=F5U<B#@H#H@`$AO<G,@8V%TZ6=O<FEE`%5N:6-O9&4@*%541BTX*0#)
M;6ER871S($%R86)E<R!5;FES`%)O>6%U;64M56YI`,ET871S+55N:7,`SFQE
M<R!E>'3I<FEE=7)E<R!D97,@R71A=',M56YI<P!5;FETZ7,`26YC;VYN=0!A
M<&EM<V=I9"!I;F-O;FYU("A!4$D@365S<V%G92!)1"DN`&-L:6US9VED(&EN
M8V]N;G4@*$-L:65N="!-97-S86=E($E$*2X`16UP;&%C96UE;G0@<^EL96-T
M:6]N;ND@:6YC;VYN=2X`3F]M(&0G=71I;&ES871E=7(@;W4@;6]T(&1E('!A
M<W-E(&EN8V]N;G4N`$3I;&EE<B!L)^ELZ6UE;G0@8V]U<F%N=`!386YS(&YO
M;0!,97,@<V-R:7!T<R!N;VXM<')I=FELZ6=IZ7,@;F4@<&5U=F5N="!A8V/I
M9&5R(&%U>"!F;VYC=&EO;G,@8V]U<&5R+V-O<&EE<B]C;VQL97(@<&]U<B!D
M97,@<F%I<V]N<R!D92!SZ6-U<FETZ2X@07!P=7EE>B!S=7(@3TL@<&]U<B!V
M;VER('5N92!N;W1E('1E8VAN:7%U92!S=7(@;6]Z:6QL82YO<F<@<75I('9O
M=7,@97AP;&EQ=65R82!C;VUM96YT(&%U=&]R:7-E<B!U;B!S8W)I<'0@X"!U
M=&EL:7-E<B!L92!P<F5S<V4M<&%P:65R<P!296UE='1R92!L82!C;W5L975R
M(.`@>NER;P!%>'1E;G-I;VX@;F]N('!R:7-E(&5N(&-O;7!T90!-;V1I9FEE
M<@!-;V1I9FEE<B`E<P!-;V1I9FEE<B!L)W5T:6QI<V%T975R`$UI<V4@X"!J
M;W5R(&1E(*N@)7.@NRX`3&4@<V-R:7!T(&1E(&UI<V4@X"!J;W5R(&5S="!S
M=7!P<FEMZ0!#:&%R9V5R`%1O=7,@;&5S(&9I8VAI97)S(&1E(&-O;F9I9W5R
M871I;VX@9&5S(&%P<&QI8V%T:6]N<R!O;G0@Z73I(&5N=F]YZ7,@<W5R(&QE
M('-E<G9E=7(N`$QE='1R97,@;&%T:6YE<R!M86IU<V-U;&5S`$YO;6)R97,@
M<F]M86EN<R!M86IU<V-U;&5S`%5R=6=U87D`16UP;&]YZ2!A8W1U96QL96UE
M;G2@.B`E<P!5=&EL:7-E<B!34TP`571I;&ES97(@<VD@;&4@;F]M(&0G=71I
M;&ES871E=7(O;6]T(&1E('!A<W-E(&5S="!D:69FZ7)E;G0@9'4@<V5R=F5U
M<B!)35-0+@!5=&EL:7-A=&5U<@!,)W5T:6QI<V%T975R("5S(&XG82!P87,@
M;"=A=71O<FES871I;VX@<&]U<B`E<RX`061M:6YI<W1R871I;VX@9&5S('5T
M:6QI<V%T975R<P!0<NEFZ7)E;F-E<R!P97)S;VYN96QL97,`16YR96=I<W1R
M96UE;G0@9&5S('5T:6QI<V%T975R<P!,)V5N<F5G:7-T<F5M96YT(&0G=71I
M;&ES871E=7(@97-T(&3I<V%C=&EVZ2!S=7(@8V4@<WES=.AM92X`0V]M<'1E
M('5T:6QI<V%T975R(&YO;B!T<F]U=ND`3F]M(&0G=71I;&ES871E=7(`3&4@
M;F]M(&1E(&-O;FYE>&EO;B"KH"5SH+L@97AI<W1E(&3I:N`N`$YO;2!D)W5T
M:6QI<V%T975RH#H`3F]M(&0G=71I;&ES871E=7*@.B``571I;&ES871E=7)S
M(&3I9FEN:7.@.@!/=7IBZ6MI<W1A;@!2Z7!E<G1O:7)E(%9&4R!I;F5X:7-T
M86YT+@!!8G-E;F-E<P!,97,@96UP;&%C96UE;G1S('9A;&ED97,@=')O=7;I
M<R!I;F-L=65N=*`Z(`!686QI9&ETZ0!686QE=7(@96X@;6EN=71E<R#@('!A
M<G1I<B!D92!M86EN=&5N86YT+@!686QE=7(@<W5PZ7)I975R92#@(&QA(&QO
M;F=U975R(&UA>&EM86QE(&1E("5S+@!686QE=7)S`%9A;&5U<G,@X"!SZ6QE
M8W1I;VYN97(@9&4`5F%N=6%T=0!687)I86)L90!6Z6[I>G5E;&$`R6-H96,@
M9&4@;&$@=NER:69I8V%T:6]N("9M9&%S:#L@8V4@;65S<V%G92!A('!E=70M
MZG1R92#I=.D@9F%L<VEF:>DN`%9E<G-I;VX`0V]N='+T;&4@9&4@=F5R<VEO
M;@!!;&EG;F5M96YT('9E<G1I8V%L`%)E;7!L:7-S86=E('9E<G1I8V%L`%9E
M<G1I8V%LH#H`5'+H<R!H875T90!6:65T;F%M`%9IZG0M;F%M:65N("A625-#
M24DI`%9O:7(@)7,`5F]I<B!U;F4@<&%G92!W96(@97AT97)N90!6;VER(&-O
M;6UE("5S`,YL97,@5FEE<F=E<R!B<FET86YN:7%U97,`SFQE<R!6:65R9V5S
M(&1E<R#)=&%T<RU5;FES`%9I<VEB:6QI=.D`5FES:6)I;&ETZ:`Z(`!6;V1A
M9F]N92!)=&%L>2!V:6$@4TU44`!.3U1)0T4`051414Y424].(2$A("!355!0
M4DE-15(@3$4@4T-225!4($U!3E5%3$Q%345.5"!$12`E<P!724X@=FEA($A4
M5%``5V%L;&ES(&5T($9U='5N80!!='1E;G1I;VX`364`4'+I=FES:6]N<R!M
MZ73I;P!$;VYNZ65S(&WI=.EO(&9O=7)N:65S('!A<@!796%T:&5R+F-O;0!7
M96(`4VET92!W96(`0VAA<75E('-E;6%I;F4`0FEE;G9E;G5E`$)I96YV96YU
M92#@("5S`$)I96YV96YU92P@)7,`3V-C:61E;G1A;"`H25-/+3@X-3DM,2D`
M3V-C:61E;G1A;"`H25-/+3@X-3DM,34I`%-A:&%R82!/8V-I9&5N=&%L`%%U
M96QL92!A<'!L:6-A=&EO;B`E<R!D;VET+6EL('!RZ7-E;G1E<B!A<'+H<R!L
M82!C;VYN97AI;VZ@/P!1=65L(&5S="!L92!C87)A8W3H<F4@9&4@<^EP87)A
M=&EO;J`_`%%U96P@97-T(&QE(&-A<F%C=.AR92!D92!C:71A=&EO;J`_`$-A
M<G1E(%=H97)E:7,@075S=')A;&EE`%%U96QL97,@<&AA<V5S`%%U96QL97,@
M97AT96YS:6]N<R!A8W1I=F5R('!O=7(@;"?I9&ET975R(%)I8V@@5&5X="X`
M3&%R9V5U<@!,87)G975R(&5N('5N:73I<R!#4U,`3&%R9V5U<B!D=2!M96YU
M(&1E(&=A=6-H92`E<R`@*&QA(&-O;F9I9W5R871I;VX@<')E;F1R82!E9F9E
M="#@(&QA('!R;V-H86EN92!C;VYN97AI;VXIH#H`3&%R9V5U<B!D=2!T86)L
M96%U`%5N:73I(&1E(&QA<F=E=7(`3&%R9V5U<J`Z`%=I:VD`5F5N=`!696YT
M('3T="!L92!M871I;@!6:71E<W-E(&1U('9E;G0@96X@;B9O96QI9SMU9',`
M5F5N=*`Z`%9E;G2@.B``4V%G97-S90!,:7-T92!D92!V)F]E;&EG.W5X`%1R
M879A:6P`061R97-S92!P<F]F97-S:6]N;F5L;&4`5.ELZ7!H;VYE('!R;V9E
M<W-I;VYN96P`3F]M8G)E(&1E(&-H86UP<R!I;F-O<G)E8W0@X"!L82!L:6=N
M92`E9"X@)60@871T96YD=7,L("5D('1R;W5VZ7,N`$YO;6)R92!D92!C:&%M
M<',@:6YC;W)R96-T+B`E9"!A='1E;F1U<RP@)60@=')O=7;I<RX`1.EC86QA
M9V4@)60@:6YC;W)R96-T(&QO<G,@9&4@;&$@;&5C='5R92!D92!F:6-H:65R
M(%9&4RX`6"U2968`0V]N=')A:6YT97,@8F%S:7%U97,@6#4P.78S`%5T:6QI
M<V%T:6]N(&1E(&-LZ2#I=&5N9'5E(%@U,#EV,P!!=71R92!N;VT@9'4@<W5J
M970@6#4P.78S`$ED96YT:69I86YT(&1E(&-LZ2!D=2!S=6IE="!8-3`Y=C,`
M17AT96YS:6]N<R!8-3`Y=C,`04$`04%!00!#87)T92"KH%EA:&]OH"&@NP!!
M;FYU96QL96UE;G0`6>EM96X`3W5I`$]U:2P@:B=A8V-E<'1E`%9O=7,@ZG1E
M<R!E;B!M;V1E(*N@5&5X=&6@NRX@571I;&ES97H@;&4@8F]U=&]N(%L\/ET@
M<&]U<B!R979E;FER(&%U(&UO9&4@JZ!765-)5UE'H+LN`%9O=7,@;B?J=&5S
M('!A<R!A=71O<FESZ2#@(&-RZ65R('!L=7,@9&4@)60@8FQO8W,N`%9O=7,@
M;B?J=&5S('!A<R!A=71H96YT:69IZ2X`5F]U<R!N92!P;W5V97H@<&%S(&%V
M;VER(&QE(&-A<F%C=.AR92"K7+L@9&%N<R!V;W1R92!N;VT@8V]M<&QE="X`
M5F]U<R!N)V%V97H@<&%S('-A:7-I('5N92!A9')E<W-E(.EL96-T<F]N:7%U
M92!V86QI9&4N`%9O=7,@;B=A=F5Z('!A<R!A<W-O8VGI(&QE<R!C:&%M<',@
M9'4@9FEC:&EE<B!I;7!O<G3I(&%U>"!C:&%M<',@8V]R<F5S<&]N9&%N=',@
M9&%N<R`E<RX`5F]U<R!A=F5Z(.ETZ2!DZ6-O;FYE8W3I+@!6;W5S(&1E=F5Z
M(&EN<V-R:7)E('5N(&YU;>ER;R!D92!C96QL=6QA:7)E('9A;&ED92P@<V5U
M;',@9&5S(&YO;6)R97,@970@=6X@JZ`KH+L@;W!T:6]N;F5L('!O=7(@;&5S
M(&%P<&5L<R!I;G1E<FYA=&EO;F%U>"X`5F]U<R!N)V%V97H@<&%S('-A:7-I
M('5N92!E;G1RZ64@=F%L:61E+@!6;W5S(&1E=F5Z(&-O;F9I9W5R97(@=6X@
M8F%C:V5N9"!$871A5')E92!P;W5R('5T:6QI<V5R(&QE<R!I;G-C<FEP=&EO
M;G,`5F]U<R!D979E>B!C;VYF:6=U<F5R('5N(&UO9'5L92!61E,N`%9O=7,@
M9&5V97H@9.EC<FER92!L92!P<F]B;.AM92!A=F%N="!D92!N;W5S(&9A:7)E
M('!A<G9E;FER(&QE(')A<'!O<G0N`%9O=7,@9&5V97H@96YT<F5R('5N92!5
M4DP@;_D@<&]I;G1E(&1E(&QI96XN`$EL(&9A=70@<^EL96-T:6]N;F5R('5N
M('-E<G9E=7(@X"!S=7!P<FEM97(N`%9O=7,@9&5V97H@<W#I8VEF:65R('5N
M('5T:6QI<V%T975R(.`@<F5T:7)E<BX@`%9O=7,@9&5V97H@<W#I8VEF:65R
M('5N('5T:6QI<V%T975R(.`@<F5T:7)E<BX`5F]U<R!D979E>B!S<.EC:69I
M97(@=6X@=71I;&ES871E=7(@X"!A:F]U=&5R+@!6;W5S(&1E=F5Z('-PZ6-I
M9FEE<B!L92!N;VT@9&4@;"=U=&EL:7-A=&5U<B#@(&UO9&EF:65R+@!6;W5S
M(&1E=F5Z(&EN9&EQ=65R('%U96QL92!A8W1I;VX@86-C;VUP;&ER+@!6;W5S
M(&1E=F5Z(.EC<FER92!U;B!N;VT@<&]U<B!L82!N;W5V96QL92!C873I9V]R
M:64N`%9O=7,@9&5V97H@9F]U<FYI<B!U;B!NL"!D92!TZ6SI<&AO;F4@:71A
M;&EE;@!6;W1R92!S97-S:6]N("5S(&$@97AP:7+I+B!6975I;&QE>B!V;W5S
M(')E8V]N;F5C=&5R+@!6;W1R92!A9')E<W-E(&1E(&-O=7)R:65L`%9O=')E
M(&%D<F5S<V4@9&4@8V]U<G)I96P@JR!$93H@NZ`Z`%9O<R!D;VYNZ65S('!E
M<G-O;FYE;&QE<P!6;W1R92!A9')E<W-E($EN=&5R;F5T(&$@8VAA;F?I(&1E
M<'5I<R!L)V]U=F5R='5R92!D92!V;W1R92!S97-S:6]N("5S+B`@4&]U<B!V
M;W1R92!SZ6-U<FETZ2P@=F]U<R!D979E>B!V;W5S(')E8V]N;F5C=&5R+@!6
M;W1R92!N;VT`5F]T<F4@;6]D=6QE(&0G875T:&5N=&EF:6-A=&EO;B!N92!S
M=7!P;W)T92!P87,@;"=A:F]U="!D)W5T:6QI<V%T975R<RP@4VD@=F]U<R!S
M;W5H86ET97H@=71I;&ES97H@2&]R9&4@<&]U<B!A9&UI;FES=')E<B!L97,@
M8V]M<'1E<R!U=&EL:7-A=&5U<G,L('9O=7,@9&5V97H@=71I;&ES97(@=6X@
M875T<F4@;6]D=6QE(&0G875T:&5N=&EF:6-A=&EO;BX`5F]T<F4@;6]D=6QE
M(&0G875T:&5N=&EF:6-A=&EO;B!N)V5S="!P87,@96X@;65S=7)E(&0GZ71A
M8FQI<B!U;F4@;&ES=&4@9&5S('5T:6QI<V%T975R<RP@;W4@8V5T=&4@9F]N
M8W1I;VX@82#I=.D@<F5T:7+I92!P;W5R('5N92!A=71R92!R86ES;VXN`%9O
M=')E(&YA=FEG871E=7(@<V5M8FQE(&%V;VER(&-H86YGZ2!D97!U:7,@;&4@
M9.EB=70@9&4@=F]T<F4@<V5S<VEO;B`E<RX@(%!O=7(@=F]T<F4@<^EC=7)I
M=.DL('9O=7,@9&5V97H@=F]U<R!R96-O;FYE8W1E<BX`5F]T<F4@;F%V:6=A
M=&5U<B!N92!S=7!P;W)T92!P87,@8V5T=&4@;W!T:6]N`%9O=')E(&YA=FEG
M871E=7(@;F4@<')E;F0@<&%S(&5N(&-O;7!T92!C971T92!O<'1I;VX@9"=I
M;7!R97-S:6]N+B!0<F5S<V5Z($-O;G1R]&QE+T-O;6UA;F1E("L@4"!P;W5R
M(&EM<')I;65R`%9O=')E(&9U<V5A=2!H;W)A:7)E(&%C='5E;*`Z`%9O=')E
M('!R;V9I;"!P87(@9.EF875T(&$@Z73I(&UO9&EF:>DN`%!R;V9I;"!P87(@
M9.EF875TH#H`5F]T<F4@;F]M(&-O;7!L972@.@!6;W1R92!C;VUP=&4@82!E
M>'!I<NDN`%9O=')E(&YO=79E874@;6]T(&1E('!A<W-E('!O=7(@)7,@97-T
MH#HE<P!6;W,@;W!T:6]N<R!O;G0@Z73I(&UI<V5S(.`@:F]U<B!P;W5R(&QA
M(&1U<NEE(&1E(&-E='1E('-E<W-I;VXN`%9O<R!O<'1I;VYS(&]N="#I=.D@
M;6ES97,@X"!J;W5R+@!6;W1R92!M;W0@9&4@<&%S<V4@82#I=.D@<F5M:7,@
MX"!ZZ7)O`%9O=')E(&UO="!D92!P87-S92!A(.ETZ2!R96UI<R#@('KI<F\L
M(';I<FEF:65R('9O=')E(&-O=7)R:65R(&5T(&-O;FYE8W1E>BUV;W5S(&%V
M97H@=F]T<F4@;F]U=F5A=2!M;W0@9&4@<&%S<V4N`%9O=')E(&UO="!D92!P
M87-S92!A(&5X<&ERZ2X`5F]S('-E<G9E=7)S(&1I<W1A;G1SH#H`66]U9V]S
M;&%V:64`6F'O<F4`6F%M8FEE`%II;6)A8G=E`%II<'!Y`%M#86-H97(@;&5S
M(&-I=&%T:6]N<UT`6U)A<'!O<G0@9&4@<')O8FSH;65=`%M!9F9I8VAE<B!L
M92!T97AT92!C:73I("T`6T%F9FEC:&5R(&QE('1E>'1E(&-I=.D@+2`E<R!L
M:6=N97-=`%ML:6=N92`E<R!D92`E<UT`7T%D;6EN:7-T<F%T:6]N`$QI9VYE
M(&1E(%]C;VUM86YD90!?1&%T851R964`4W5P<')I;65R(&QA(%]R86YGZ64`
M7T=R;W5P97,`7T%I9&4`4')O<')?:>ETZ7,@9&4@;"=I;6%G92XN+@!?0V]N
M;F5X:6]N`%]$Z6-O;FYE>&EO;@!?36]D:69I97(@=6X@;&EE;B!W96(N+BX`
M7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]2971I<F5R('5N(&QI96X`7T-O;F9I
M9W5R871I;VX`4')O<')IZ73I<R!D=2!?=&%B;&5A=0!?571I;&ES871E=7)S
M`&-A<FYE="!D)V%D<F5S<V5S`&1E<W1I;F%T86ER92!I;F-O;FYU`&%G96YD
M80!C86QM90!I;7!O<W-I8FQE(&1E(&-RZ65R(&QE(&9I8VAI97(@9&4@<V]R
M=&EE`&EM<&]S<VEB;&4@9"=O=79R:7(@;"=E;G1RZ64`8VQI<75E>B!I8VD`
M97)R975R(&0G=71I;&ES871I;VX@9&4@;&$@;&EG;F4@9&4@8V]M;6%N9&4`
M97)R975R(&1E(&-O;F9I9W5R871I;VX`86)S96YC92!C<FET:7%U92!D)W5N
M(&9I8VAI97(@<WES=.AM90!E<G)E=7(@9&4@9F]R;6%T(&1E(&1O;F[I90!M
M;V1I9FEE<@!E;G1RZ64@;F]N('1R;W5VZ0!T;VUB86YT`&9I8VAI97(`9&5P
M=6ES(&QE("5S("@E<RD@X"`E<R`E<P!E;B!R869A;&4`:*`Z`&AH`&YO;2!D
M)VCT=&4@:6YC;VYN=0!I;6WI9&EA=&5M96YT`&EN8V]R<&]RZ64`97)R975R
M(&0G96YT<NEE+W-O<G1I90!E<G)E=7(@;&]G:6-I96QL92!I;G1E<FYE`&QI
M9VYE<UT`97)R975R(&UK:7-O9G,@8V]D92`E9"!E;B!C<NEA;G0@;"=)4T\`
M;6T`;F]M`&YO;B!P<FES(&5N(&-O;7!T90!P87,@96YC;W)E('!R:7,@96X@
M8V]M<'1E`&)L;V,M;F]T97,`<&]U<F-E;G1A9V4`<&5R;6ES<VEO;B!R969U
M<^EE`'!I>&5L<P!E<G)E=7(@9&ES=&%N=&4@9&%N<R!L92!P<F]T;V-O;&4`
M<R?I;&5V86YT`'-E<G9I8V4@;F]N(&1I<W!O;FEB;&4N`&UO;G1R97(@;&5S
M(&1I9F;I<F5N8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S<P!F:7AE`&5R<F5U
M<B!S>7-TZ&UE`&QI<W1E(&1E('3B8VAE<P#I8VAE8R!T96UP;W)A:7)E`&5N
M=')E>B!L92!M;W0@9&4@<&%S<V4@9&5U>"!F;VES('!O=7(@8V]N9FER;65R
M`'5N:69IZ0!S86YS(&YO;0!3Z6QE8W1I;VX@9"=U=&EL:7-A=&5U<@!V0V%R
M9`!LH#H`=V5A=&AE<BYC;VT`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M;V-A;&4O9G)?1E(O:&5L<"YX;6P`````````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#0P,C,@,3`U,34T,S,W-#$@,#(Q-#0T`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_>&UL('9E
M<G-I;VX](C$N,"(@96YC;V1I;F<](FES;RTX.#4Y+3$B/SX*/"$M+2`D2&]R
M9&4Z(&AO<F1E+VQO8V%L92]F<E]&4B]H96QP+GAM;"QV(#$N,BXQ,"XQ(#(P
M,#4O,3(O,#4@,3`Z,S`Z-#4@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT
M<GD@:60](G-U;6UA<GDB('-T871E/2)U<'1O9&%T92(@;60U/2(V.&-A,S-F
M-V8P8SEA864T8S$P,V5B-#<T.3)C9&,Q-2(^"CQT:71L93Y,82!P86=E('!O
M<G1A:6P@/"]T:71L93X*(#QP87)A/@H@($-E='1E('!A9V4@<&]R=&%I;"!V
M;W5S(&9O=7)N:70@=6X@<NES=6WI(&1E('9O<R!I;F9O<FUA=&EO;G,@:6UP
M;W)T86YT97,N(%!A<B!E>&5M<&QE+"!C96QA('!O=7)R86ET('9O=7,@<&5R
M;65T=')E(&0G869F:6-H97(@;&4@;F]M8G)E(&1E(&YO=79E875X(&UE<W-A
M9V5S(&1A;G,@=F]T<F4@8F_N=&4@9&4@<NEC97!T:6]N+"!L97,@;F]U=F5A
M=7@@Z7;H;F5M96YT<R!D92!V;W1R92!C86QE;F1R:65R+"!L97,@=.)C:&5S
M(&1E('9O=')E(&QI<W1E(&1E('1R879A=7@@X"!F86ER92P@;&5S(&=R86YD
M<R!T:71R97,@9&4@;F]U=F5L;&5S+"!E=&,N($QA('!L=7!A<G0@9&5S('+I
M<W5MZ7,@8V]N=&EE;F1R;VYT(&1E<R!R86-C;W5R8VES('9E<G,@9&5S(&9O
M;F-T:6]N<R!C;&%S<VEQ=65S(&-O;6UE(&QA(&-O;7!O<VET:6]N(&0G=6X@
M;F]U=F5A=2!M97-S86=E+"!L82!C<NEA=&EO;B!D)W5N(&YO=79E;"#I=NAN
M96UE;G0@9&%N<R!L92!C86QE;F1R:65R(&]U(&0G=6YE(&YO=79E;&QE('3B
M8VAE+@H@/"]P87)A/@H@/'!A<F$^"B`@3&4@8V]N=&5N=2!D92!C971T92!P
M86=E('!O<G1A:6P@<&5U="#J=')E('!E<G-O;FYA;&ESZ2#@(&PG86ED92!D
M=2!B;W5T;VX@)U!RZ7-E;G1A=&EO;B<N(%!A<B!E>&5M<&QE+"!V;W5S('!O
M=79E>B!C:&]I<VER(&QE<R!P;VEN=',@<'+I<V5N=',@<W5R(&-E='1E('!A
M9V4@<&]R=&%I;"!E="!L)V]R9')E(&1A;G,@;&5Q=65L(&EL<R!S97)O;G0@
M<'+I<V5N=.ES+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB;F%V
M8F%R(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB8CAC9C!A93$Y934W9&9A,&,R
M8CDV,F4U,38W.#)F-#<B/@H\=&ET;&4^3&4@;65N=2!(;W)D93PO=&ET;&4^
M"B`\<&%R83X*("!3=7(@;&4@8_1TZ2!G875C:&4@9&4@;&$@<&%G92!S92!T
M<F]U=F4@;&4@;65N=2!(;W)D92X*("!#;&EQ=65Z('-U<B!L97,@:6/T;F5S
M(&1E(&-E(&UE;G4@2&]R9&4@<&]U<B!A8V/I9&5R(')A<&ED96UE;G0@970@
M<VEM<&QE;65N="!A=7@@87!P;&EC871I;VYS(&1I<W!O;FEB;&5S+B`*(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61O7VUA:6YT96YA
M;F-E(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB9&0Y-61F,#=A,#,P,S$R,S)B
M865A.3$Y,C@X8C)D,#`B/@H@("`@/'1I=&QE/E!RZ6;I<F5N8V5S.B!-86EN
M=&5N86YC93H@169F96-T=65R(&QE<R!O<.ER871I;VYS(&1E(&UA:6YT96YA
M;F-E/"]T:71L93X*("`@(#QP87)A/@H@("`@4VD@=F]U<R!V;W5L97H@969F
M96-T=65R(&QE<R!O<.ER871I;VYS(&1E(&UA:6YT96YA;F-E(.`@;&$@8V]N
M;F5X:6]N+"!C;V-H97H@8V5T=&4@8V%S92X*("`@(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](G!R969S+6-O;F9I<FU?;6%I;G1E;F%N8V4B('-T
M871E/2)U<'1O9&%T92(@;60U/2)A,C$Q-C)C9&9F,V(Q9#AF865A9&(W,CDV
M,C0P,#,V92(^"B`@("`\=&ET;&4^4'+I9NER96YC97,Z($UA:6YT96YA;F-E
M.B!#;VYF:7)M97(\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!3:2!V;W5S('9O
M=6QE>B!D979O:7(@8V]N9FER;65R(&%V86YT(&1E(&QA;F-E<B!L97,@;W#I
M<F%T:6]N<R!D92!M86EN=&5N86YC92P@8V]C:&5Z(&-E='1E(&-A<V4N(%-I
M('9O=7,@;F4@;&$@8V]C:&5Z('!A<RP@=&]U=&5S(&QE<R!O<.ER871I;VYS
M(&1E(&UA:6YT96YA;F-E('-E<F]N="!A=71O;6%T:7%U96UE;G0@;&%N8^EE
M<R#@(&QA(&-O;FYE>&EO;B!S86YS(&%U8W5N92!C:&%N8V4@9"=A;FYU;&%T
M:6]N+@H@("`@/"]P87)A/@H\+V5N=')Y/@H\+VAE;'`^"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L;V-A;&4O9VQ?15,`````````````````````````````
M````````````````````````````````````````````````````````,#`P
M-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W-#$@
M,#$W-S`W`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]G;%]%4R],0U]-
M15-304=%4P``````````````````````````````````````````````````
M```````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,#`P,"`Q,#4Q-30S,S<T,2`P,C$T-S0`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&]C86QE+V=L7T53+TQ#7TU%4U-!1T53+VAO<F1E+FUO````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#$T,#(U(#$P-3$U-#,S-S0Q(#`R,S(Q,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````#>$@25````
M`&0````<````/`,``(D```!<!@```````(`(```H````@0@```@```"J"```
M!0```+,(```(````N0@```<```#""```!0```,H(```?````T`@``!$```#P
M"```"`````()```(````"PD``!4````4"0``"@```"H)```,````-0D```<`
M``!""0``*0```$H)```"````=`D```4```!W"0``$````'T)```4````C@D`
M`"\```"C"0``#P```-,)```F````XPD```4````*"@``#0```!`*```%````
M'@H``!`````D"@``$````#4*```/````1@H```L```!6"@``#P```&(*```,
M````<@H```\```!_"@``'@```(\*```A````K@H```,```#0"@``!````-0*
M```,````V0H```H```#F"@``!0```/$*```2````]PH``!`````*"P``"```
M`!L+```0````)`L```8````U"P``!P```#P+```"````1`L```0```!'"P``
M#P```$P+```'````7`L```<```!D"P``!````&P+```%````<0L```4```!W
M"P``!P```'T+```1````A0L```@```"7"P``'@```*`+```%````OPL``"@`
M``#%"P``*0```.X+```3````&`P```L````L#```$0```#@,```$````2@P`
M``P```!/#```&@```%P,```7````=PP``!<```"/#```&P```*<,```?````
MPPP``!,```#C#```$````/<,```7````"`T```<````@#0``!0```"@-```A
M````+@T``!P```!0#0``!0```&T-```#````<PT``"````!W#0``)@```)@-
M```,````OPT```P```#,#0``"````-D-```'````X@T```8```#J#0``#0``
M`/$-```+````_PT```P````+#@``"@```!@.```"````(PX```8````F#@``
M10```"T.```P````<PX``!````"D#@``'P```+4.```0````U0X```\```#F
M#@``!0```/8.``!O`0``_`X``"H```!L$```"````)<0```%````H!````X`
M``"F$```"````+40```&````OA```"0```#%$```$P```.H0```+````_A``
M``H````*$0``'P```!41```.````-1$```\```!$$0``"````%01```R````
M71$```(```"0$0``"P```),1```9````GQ$``!8```"Y$0``+P```-`1```8
M`````!(``"L````9$@``$@```$42```.````6!(```0```!G$@``#P```&P2
M```0````?!(```X```"-$@``%0```)P2```/````LA(```L```#"$@``$P``
M`,X2```C````XA(``",````&$P```P```"H3```%````+A,``!,````T$P``
M$P```$@3```%````7!,``!,```!B$P``$@```'83```&````B1,``!@```"0
M$P``!@```*D3```/````L!,```(```#`$P``!@```,,3```6````RA,```<`
M``#A$P``#````.D3```$````]A,```4```#[$P``!0````$4```'````!Q0`
M`!$````/%```#P```"$4```A````,10```@```!3%```'@```%P4```O````
M>Q0``!8```"K%```"P```,(4```3````SA0```<```#B%```$0```.H4```A
M````_!0``!T````>%0``'0```#P5```E````6A4``!0```"`%0``'0```)45
M```3````LQ4``!\```#'%0``#0```.<5```'````]14``"(```#]%0``&P``
M`"`6```&````/!8```,```!#%@``*@```$<6```O````<A8``!,```"B%@``
M$@```+86```'````R18```4```#1%@``#````-<6```,````Y!8```T```#Q
M%@``%````/\6```4````%!<```(````I%P``"@```"P7```N````-Q<``#P`
M``!F%P``$0```*,7```?````M1<``!4```#5%P``#P```.L7```9````^Q<`
M``$````D`````````$X````=````3P```!<```!%````!P```"(`````````
M30```"$`````````2P```&(````*````$0`````````,````,@```%,````Q
M`````````"4```!&````70````````!2````0@```%4`````````1P```"P`
M```O````5@```%$````U````$`````@````^````00```%\````K````#P``
M`#D```!*````(P```!@````S````0````"@```!@````"P``````````````
M5```````````````/0````D`````````+@```$@```!<````.@`````````.
M`````````%D`````````-@`````````;````/P```!P````:````#0```#L`
M````````!`````4`````````$@`````````3`````````%<````M````````
M`"8``````````````!4````&`````````%L````W````&0````````!>````
M`````#@````T`````````$D````?````6@```$0`````````'@``````````
M````8P````````!8````*0`````````P```````````````\````9````%``
M````````%@```"```````````P```&$```!#````*@```"<```!,`````@``
M```````4`````"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M
M871I;VX`,C0@:&]U<G,`04TO4$T`061D('!A:7(`061D<F5S<P!!;&EA<P!!
M;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%V86EL86)L92!F:65L
M9',Z`$)I<G1H9&%Y`$-A;&5N9&%R`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#
M96QL(%!H;VYE`$-L;W-E(%=I;F1O=P!#;VUP86YY`$-O=6QD(&YO="!O<&5N
M($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$1$`$1A:6QY`$1E9F%U;'0@
M261E;G1I='D`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5T86EL<R!H879E(&)E
M96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&ES<&QA>2!/<'1I
M;VYS`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$5M
M86EL`$5M<'1Y(')E<W5L="X`17)R;W(`179E<GD@,34@;6EN=71E<P!%=F5R
M>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R
M>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!&86EL
M960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@
M=&\@3$1!4"!S97)V97(N`$9A>`!(96QP`$AO;64@061D<F5S<P!(;VUE(%!H
M;VYE`$AO<F1E`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z
M`$QA;F=U86=E`$QI<W0@2&5L<"!4;W!I8W,`3&]G(&EN`$QO9R!O=70`34T`
M36%I;`!-871C:&EN9R!F:65L9',`365S<V%G90!-;VYT:&QY`$YA;64`3F5V
M97(`3F]T97,`3W!T:6]N<P!/=&AE<B!);F9O<FUA=&EO;@!087-S=V]R9`!0
M97)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&AO;F4`4&QE87-E('!R
M;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED
M92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0<F]B;&5M($1E<V-R:7!T
M:6]N`%)E;6]V92!P86ER`%)E='5R;B!T;R!/<'1I;VYS`%)O;&4`4V%V92!/
M<'1I;VYS`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@
M9&%T92!F;W)M870Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T
M=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N
M9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4VMI<"!-86EN=&5N86YC90!3
M<&5C:6%L($-H87)A8W1E<B!);G!U=`!3=6-C97-S`%1A<VMS`%1H:7,@;G5M
M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('9A;'5E(&UU<W0@8F4@
M82!N=6UB97(N`%1I=&QE`%523`!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@
M<V5R=F5R+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N
M=`!5;F1O($-H86YG97,`57-E<B!/<'1I;VYS`%5S97)N86UE`%=A<FYI;F<`
M5V5E:VQY`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V]R:R!!9&1R97-S
M`%=O<FL@4&AO;F4`65D`665A<FQY`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P
M<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T
M+@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A
M9V%I;BX`66]U<B!);F9O<FUA=&EO;@!9;W5R(&]P=&EO;G,@:&%V92!B965N
M('5P9&%T960N`%M0<F]B;&5M(%)E<&]R=%T`6VQI;F4@)7,@;V8@)7-=`'9#
M87)D`%!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@,BXQ"E)E<&]R="U-<V=I
M9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$
M871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@
M,C`P,RTP."TQ.2`Q,SHS-4=-5"LQ"DQA<W0M5')A;G-L871O<CH@4V5R=FEC
M:6\@9&4@3F]R;6%L:7IA8VEO;B!,:6YG=6ES=&EC82`\<VYL=7-C0'5S8RYE
M<SX*3&%N9W5A9V4M5&5A;3H@1V%L96=O"DU)344M5F5R<VEO;CH@,2XP"D-O
M;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ"D-O
M;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*6"U'96YE<F%T;W(Z($M"
M86)E;"`P+CDN-0H`3W!E<F%C:?-N<R!D92!M86YT96UE;G1O("5S("T@0V]N
M9FER;6%C:?-N`#(T(&AO<F%S`$%-+U!-`$5N9V%D:7(@=6X@<&%R`$5N9&5R
M97IO`$%L8W5M90!/('9A;&]R('%U92!E<W!E8VEF:6-O=2!N;VX@Z2!VX6QI
M9&\`0V%M<&]S(&1I<W!O\6EB;&5S.@!!;FEV97)S87)I;P!#86QE;F1A<FEO
M`$-A;F-E;&%R(&\@:6YF;W)M92!D92!P<F]B;&5M87,`5&5LZ69O;F\@;?-B
M:6P`4&5C:&%R(&$@>&%N96QA`$-O;7!A\>UA`$9A;&QO(/,@86)R:7(@;R!M
M\V1U;&\@9&4@=&%R969A<R!D92!M86YT96UE;G1O("5S`$1$`$1I87)I86UE
M;G1E`$ED96YT:61A9&4@<')E9&5T97)M:6YA9&$`1&5S8W)I8VGS;B!D;R!P
M<F]B;&5M80!297AI<W1RX7)O;G-E(&]S(&1E=&%L;&5S('!A<F$@;R!A9&UI
M;FES=')A9&]R+@!/<&-I\VYS(&1E('9I<W5A;&EZ86-I\VX`3F]N(&%C8V5D
M82!D:7)E8W1A;65N=&4@82`B;6%I;G1E;F%N8V4N<&AP(@!#;W)R96\@96QE
M8W1R\VYI8V\`4V5N(')E<W5L=&%D;RX`17)R;P!#861A(#$U(&UI;G5T;W,`
M0V%D82`S,"!S96=U;F1O<P!#861A(#4@;6EN=71O<P!#861A(&EN:6-I;R!D
M92!S97-I\VX`0V%D82!M961I82!H;W)A`$-A9&$@;6EN=71O`$5X96UP;&\@
M9&4@=F%L;W)E<SH`1F%L;&]U(/,@<F5C=7!E<F%R(&%S('!R969E<F5N8VEA
M<RX`1F%L;&]U(/,@8V]N96-T87(@8V\@<V5R=FED;W(@3$1!4"X`1F%X`$%X
M=61A`$5N9&5R97IO('!A<G1I8W5L87(`5&5LZ69O;F\@<&%R=&EC=6QA<@!(
M;W)D90!#86UP;R!I;7!O<G1A9&\Z("5S`$-A;7!O<R!I;7!O<G1A9&]S.@!,
M:6YG=6$`3&ES=&%R(&]S('1E;6%S(&1E(&%X=61A`$5N=')A<@!096-H87(@
M82!S97-I\VX`34T`0V]R<F5O`$-A;7!O<R!C;W)R97-P;VYD96YT97,`365N
M<V%X90!-96YS=6%L;65N=&4`3F]M90!.=6YC80!.;W1A<P!/<&-I\VYS`$]U
M=')A(&EN9F]R;6%C:?-N`$-H879E(&1E(&%C8V5S;P!296%L:7IA<B!O<&5R
M86-I\VYS(&1E(&UA;G1E;65N=&\`5&5LZ69O;F\`06-H96=U92!U;B!R97-U
M;6\@9&\@<')O8FQE;6$N`$%C:&5G=64@;R!S974@;F]M92!D92!U<W5A<FEO
M(&4@8VAA=F4@9&4@86-C97-O`$1E<V-R:6-I\VX@9&\@<')O8FQE;6$`4V%C
M87(@;R!P87(`4F5G<F5S87(@X7,@;W!C:?-N<P!&=6YC:?-N`$=A<F1A<B!A
M<R!O<&-I\VYS`%-E;&5C8VEO;F4@;R!D96QI;6ET861O<B!D82!D871A.@!3
M96QE8V-I;VYE(&\@9F]R;6%T;R!D82!D871A.@!396QE8V-I;VYE(&\@9F]R
M;6%T;R!D82!H;W)A.@!396QE8V-I;VYE(&1O=7,@8V%M<&]S('%U92!C;VEN
M8VED86XN`%-E;&5C8VEO;F4@82!L:6YG=6$Z`$5N=FEA<B!O(&EN9F]R;64@
M9&4@<')O8FQE;6%S`$]M:71I<B!O(&UA;G1E;65N=&\`16YT<F%D82!D92!C
M87)A8W1E<F5S(&5S<&5C:6%I<P!#;W)R96-T86UE;G1E`%1A<F5F87,`3R!N
M^FUE<F\@9&5B92!S97(@<&]L;R!M96YO<R!U;B`Q+@!/('9A;&]R(&1E8F4@
M<V5R('5N(&[Z;65R;RX`5.UT=6QO`%523`!.;VX@9F]I('!O<VEB;&4@8V]N
M96-T87)S92#S('-E<G9I9&]R(%-13"X`3F]N(&9O:2!P;W-I8FQE('1R861U
M8VER(&5S=&4@9&]C=6UE;G1O(&1E(%=O<F0`1&5S9F%C97(@;W,@8V%M8FEO
M<P!/<&-I\VYS(&1O('5S=6%R:6\`57-U87)I;P!!=FES;P!396UA;F%L;65N
M=&4`0F5N=FED82!A("5S`$)E;G9I9&\O82P@)7,`16YD97)E>F\@9&\@=')A
M8F%L;&\`5&5LZ69O;F\@9&\@=')A8F%L;&\`04$`06YU86QM96YT90!$97-C
M<FEB82!O('!R;V)L96UA(&%N=&5S(&1E(&5N=FEA<B!O(&EN9F]R;64N`$-A
M9'5C;W4@82!S^F$@<V5S:?-N(&5N("5S(&5X<&ER;W4N($EN:6-I92!U;FAA
M(&YO=F$@<V5S:?-N+@!!('/Z82!I;F9O<FUA8VGS;@!!8W1U86QI>N%R;VYS
M92!A<R!S^F%S(&]P8VGS;G,N`%M);F9O<FUE(&1O(%!R;V)L96UA70!;;&GQ
M82`E<R!D92`E<UT`5&%R>&5T82!D92!V:7-I=&$@*'9#87)D*0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQO8V%L92]H95])3```````````````````````````
M```````````````````````````````````````````````````````````P
M,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<T
M,2`P,3<V-S8`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VAE7TE,+TQ#
M7TU%4U-!1T53````````````````````````````````````````````````
M`````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P,#`P(#$P-3$U-#,S-S0Q(#`R,30V,P`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L;V-A;&4O:&5?24PO3$-?34534T%'15,O:&]R9&4N;6\`````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,3<S,#(@,3`U,34T,S,W-#$@,#(S,C`S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````-X2!)4`
M````J0```!P```!D!0``XP```*P*````````.`X```P````Y#@``"P```$8.
M```'````4@X```<```!:#@``"@```&(.```)````;0X```<```!W#@``"0``
M`'\.```'````B0X```<```"1#@``!P```)D.```*````H0X```<```"L#@``
M!@```+0.```'````NPX```@```###@``!@```,P.```1````TPX```<```#E
M#@``"````.T.```(````]@X```8```#_#@``!@````8/```*````#0\``!@`
M```8#P``!````#$/```%````-@\```4````\#P``!0```$(/```&````2`\`
M``@```!/#P``!0```%@/```*````7@\```0```!I#P``!@```&X/```.````
M=0\```<```"$#P``$@```(P/```'````GP\```4```"G#P``"P```*T/```(
M````N0\```0```#"#P``!P```,</```#````SP\```8```#3#P``!0```-H/
M```&````X`\```<```#G#P``!P```.\/```%````]P\```(```#]#P``!@``
M```0```'````!Q````D````/$```!@```!D0```&````(!````4````G$```
M#0```"T0```$````.Q```!T```!`$```"````%X0```(````9Q````H```!P
M$```!P```'L0```'````@Q````4```"+$```"0```)$0```9````FQ````0`
M``"U$```!P```+H0```&````PA````4```#)$```!P```,\0```%````UQ``
M``8```#=$```!0```.00```&````ZA````<```#Q$```!P```/D0```6````
M`1$```H````8$0``"@```",1```&````+A$```@````U$0``"````#X1```$
M````1Q$```4```!,$0``"@```%(1```)````71$```8```!G$0``!@```&X1
M```(````=1$```<```!^$0``"@```(81```$````D1$```4```"6$0``"P``
M`)P1```+````J!$```D```"T$0``!0```+X1```'````Q!$```8```#,$0``
M!````-,1```'````V!$```4```#@$0``"````.81```&````[Q$```@```#V
M$0``"````/\1```)````"!(```H````2$@``!````!T2```+````(A(```8`
M```N$@``"````#42```%````/A(```<```!$$@``$@```$P2```&````7Q(`
M``P```!F$@``!@```',2```'````>A(```H```""$@``#````(T2```)````
MFA(```<```"D$@``#````*P2```%````N1(```D```"_$@``!0```,D2```(
M````SQ(```D```#8$@``!@```.(2```+````Z1(``!0```#U$@``'`````H3
M```(````)Q,```4````P$P``$P```#83```'````2A,```8```!2$P```P``
M`%D3```$````71,```8```!B$P``!P```&D3```4````<1,```X```"&$P``
M#0```)43```&````HQ,```<```"J$P``"````+(3```'````NQ,```D```##
M$P``!P```,T3```(````U1,```0```#>$P``!0```.,3```&````Z1,```4`
M``#P$P``"@```/83```&`````10```@````(%```!0```!$4```(````%Q0`
M``@````@%```#````"D4```$````-A0``$X!```[%```$P```(H5```0````
MGA4```P```"O%0``#````+P5```?````R14``!````#I%0``#````/H5```0
M````!Q8```X````8%@``$0```"<6```,````.18```P```!&%@``"@```%,6
M```(````7A8```X```!G%@``#@```'86```*````A18```P```"0%@``#@``
M`)T6```.````K!8```H```"[%@``"````,86```&````SQ8```\```#6%@``
M+@```.86```$````%1<```@````:%P``!@```",7```3````*A<``!<````^
M%P``$````%87```*````9Q<``!,```!R%P``"````(87```.````CQ<```@`
M``">%P``"````*<7```I````L!<```X```#:%P``"@```.D7```5````]!<`
M``X````*&```"````!D8```,````(A@```@````O&```"````#@8```(````
M01@```H```!*&```#````%48```,````8A@```8```!O&```!````'88```(
M````>Q@```H```"$&```#@```(\8```*````GA@```H```"I&```"@```+08
M```<````OQ@```@```#<&```"@```.48```.````\!@```@```#_&```"0``
M``@9```.````$AD```P````A&0``"````"X9```2````-QD```@```!*&0``
M"````%,9```,````7!D```P```!I&0``#````'89```,````@QD```8```"0
M&0``"````)<9```(````H!D```P```"I&0``"@```+89```,````P1D```8`
M``#.&0``$@```-49```,````Z!D```H```#U&0``#@`````:```?````#QH`
M``8````O&@``"````#8:```2````/QH``!(```!2&@``#````&4:```*````
M<AH``!````!]&@``"@```(X:```.````F1H```0```"H&@``!@```*T:```*
M````M!H``!,```"_&@``$````-,:```(````Y!H```P```#M&@``$````/H:
M```*````"QL``!`````6&P``!@```"<;```,````+AL```@````[&P``#@``
M`$0;```*````4QL```L```!>&P``#````&H;```&````=QL``!0```!^&P``
M"@```),;```.````GAL```8```"M&P``#````+0;```*````P1L```P```#,
M&P``%0```-D;```*````[QL```@```#Z&P``$P````,<```5````%QP```X`
M```M'```#````#P<```7````21P```@```!A'```#P```&H<```(````>AP`
M``P```"#'```$````)`<```,````H1P```H```"N'```"@```+D<```,````
MQ!P```P```#1'```(````-X<```;````_QP```X````;'0``#@```"H=```&
M````.1T```<```!`'0``#````$@=```0````51T``",```!F'0``&P```(H=
M```7````IAT```H```"^'0``$````,D=```<````VAT```P```#W'0``#@``
M``0>```*````$QX```\````>'@``!@```"X>```'````-1X```@````]'@``
M"````$8>```2````3QX```P```!B'@``$````&\>```(````@!X```X```")
M'@``$````)@>```3````J1X```0```"]'@```0```*````!`````````````
M````````I@```*,````I````$P````````!B````&````!````!,````````
M``<````Z````,@```&,```"-````&@````````!*````6@```%X```!'````
M:@````P```!?````)````!4````H````,````((```!U````0@```)(```!;
M````D0```)@````]````,0````H````&````&0```',`````````````````
M```N````'@`````````C`````@``````````````````````````````.0``
M`%<`````````'````&D``````````````&0```!Q````*P```"8```!=````
M=P```$X```!)````-````($```!X`````````&<```!O````@P````0```"I
M````C@```!8````M````9@````T```":````(@```!T````2````2P```*4`
M````````B@`````````L````>0```)X``````````````#\`````````E@``
M`&$```!\````90```&@`````````A0```#4```![````@````"<````?````
M&P````````!6````+P```(<```"7`````````'\```!^`````````%(```"D
M````;`````4````\````G0`````````#````````````````````.P``````
M`````````````%````````````````````"A````7`````````!%````1@``
M`#,``````````````!<`````````H@```$,`````````:P```!0````W````
M00`````````/````(````)D```"(````50```"4````1````A```````````
M````"0```&X``````````````'0```!Z```````````````^````4P```*@`
M`````````````)P```!/````-@```(P```"/````8````)4`````````6```
M`(L`````````B0```$@```"?````=@````````!-````E````$0````J````
M`````"$```!M````DP````L```"G````<````%$```!9````FP````@`````
M````?0```%0```"0````<@```#@`````````A@````X`````061D<F5S<R!"
M;V]K`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;G1A<F-T:6-A`$%R
M9V5N=&EN80!!<FUE;FEA`$%U<W1R86QI80!!=7-T<FEA`$)A:&%M87,`0F%H
M<F%I;@!"86YG;&%D97-H`$)E;&=I=6T`0F5L:7IE`$)O;&EV:6$`0F]T<W=A
M;F$`0G)A>FEL`$)R=6YE:2!$87)U<W-A;&%M`$)U<G5N9&D`0V%M8F]D:6$`
M0V%M97)O;VX`0V%N861A`$-A;F-E;`!#87!E(%9E<F1E`$-E;G1R86P@069R
M:6-A;B!297!U8FQI8P!#:&%D`$-H:6QE`$-H:6YA`$-L96%R`$-L;W5D>0!#
M;VQO;6)I80!#;VYG;P!#;W-T82!2:6-A`$-U8F$`0WEP<G5S`$-Z96-H(%)E
M<'5B;&EC`$1E;FUA<FL`1&]M:6YI8V%N(%)E<'5B;&EC`$5C=6%D;W(`16=Y
M<'0`16P@4V%L=F%D;W(`171H:6]P:6$`1FEJ:0!&:6YL86YD`$9O9P!&<F%N
M8V4`1V%B;VX`1V%M8FEA`$=E;W)G:6$`1V5R;6%N>0!':&%N80!';P!'<F5E
M8V4`1W)E;F%D80!'=6%T96UA;&$`1W5I;F5A`$=U>6%N80!(86ET:0!(96%V
M>2!4+5-T;W)M`$AE;'``2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`
M2&]N9'5R87,`2'5M:61I='D`2'5M:61I='DZ(`!(=6YG87)Y`$EC96QA;F0`
M26YD:6$`26YD;VYE<VEA`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A
M<0!)<F5L86YD`$ES<F%E;`!)=&%L>0!*86UA:6-A`$IA<&%N`$IO<F1A;@!+
M96YY80!+=7=A:70`3&5B86YO;@!,:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H
M:7)I>6$`3'5X96UB;W5R9P!-861A9V%S8V%R`$UA;&%W:0!-86QA>7-I80!-
M86QD:79E<P!-86QI`$UA;'1A`$UA=7)I=&%N:6$`36%U<FET:75S`$UE>&EC
M;P!-;VYA8V\`36]N9V]L:6$`36]R;V-C;P!-;WIA;6)I<75E`$YA;64`3F5P
M86P`3F5T:&5R;&%N9',`3F5W(%IE86QA;F0`3FEC87)A9W5A`$YI9V5R`$YI
M9V5R:6$`3F]R=V%Y`$]M86X`3W!T:6]N<P!/=&AE<@!086MI<W1A;@!086YA
M;6$`4&%R86=U87D`4&%S<W=O<F0`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&5R
M=0!0:&EL:7!P:6YE<P!0;VQA;F0`4&]R='5G86P`46%T87(`4F]M86YI80!2
M=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%-A=61I($%R86)I80!396%R8V@`
M4V5N96=A;`!397EC:&5L;&5S`%-I97)R82!,96]N90!3:6YG87!O<F4`4V]M
M86QI80!3;W5T:"!!9G)I8V$`4W!A:6X`4W)I($QA;FMA`%-U9&%N`%-U<FEN
M86UE`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`4WER:6%N($%R86(@
M4F5P=6)L:6,`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!4:&%I;&%N
M9`!4;VYG80!4<FEN:61A9"!A;F0@5&]B86=O`%1U;FES:6$`5'5R:V5Y`%52
M3`!54DPZ`%5G86YD80!5:W)A:6YE`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N
M:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`57!L;V%D`%5R=6=U87D`57-E
M<FYA;64`5F%N=6%T=0!696YE>G5E;&$`5F5R<VEO;@!6:65T($YA;0!7:6YD
M`%=I;F0Z`%=I;F0Z(`!996UE;@!9=6=O<VQA=FEA`%IA;6)I80!::6UB86)W
M90!?2&5L<`!?3&]G(&]U=`!?3W!T:6]N<P!A9&1R97-S(&)O;VL`;F%M90!0
M<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,BUC=G,*4F5P;W)T+4US9VED
M+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A
M=&4Z(#(P,#8M,#(M,#<@,#0Z,#@M,#4P,`I03RU2979I<VEO;BU$871E.B`R
M,#`V+3`R+3`W(#`T.C`X+3`U,#`*3&%S="U4<F%N<VQA=&]R.B!-871T(%-E
M;'-K>2`\<V5L<VMY0&-O;'5M8FEA+F5D=3X*3&%N9W5A9V4M5&5A;3H@:3$X
M;D!L:7-T<RYH;W)D92YO<F<*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4
M>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/5541BTX"D-O;G1E;G0M5')A;G-F
M97(M16YC;V1I;F<Z(#AB:70*`->AUZ37J"#7F]>JUY77D=>5UZH`UY#7I->2
MUZ#7F=>AUZK7GP#7D-><UY'7H->9UY0`UY#7G->2UZC7F=>4`->9UY'7J=>J
MXH"3UY#7H->8UY#7J->GUYC7F=>GUY0`UY#7J->2UZ#7F->9UZ#7E`#7D->H
MUY[7H->9UY0`UY#7E=>AUYC7J-><UYG7E`#7D->5UZ'7F->HUYG7E`#7D->9
MUYGB@)/7D=>4UY[7E`#7D=>7UZC7F=>9UY\`UY'7H->2UYS7D]>I`->1UYS7
MDM>9UY0`UY'7G->9UY8`UY'7E=><UYG7D=>9UY0`UY'7E=>FUY77E=>@UY0`
MUY'7J->6UYG7G`#7D=>HUY77H->9UYD`UY'7E=>HUY77H->3UYD`UZ?7GM>1
MUY77D]>9UY0`UZ?7GM>HUY77GP#7I]>@UY/7E`#7J=>@UY0`UZ?7I->4(->5
MUZC7D]>4`->4UZ?7E->9UYS7F=>9UY0@UY37GM>HUYO7EN*`D]>0UZ37J->9
MUZ?7H->9UZH`UZ;7DP#7IM>9UYS7F0#7H=>9UY\`UZG7GM>9UYT@UY'7E->9
MUZC7G0#7J=>>UYG7G2#7GM>BUY77H->@UYG7G0#7I]>5UYS7E=>>UY'7F=>4
M`->GUY77H->2UY4`UZ?7E=>AUYC7E"#7J->9UZ?7E`#7I]>5UY'7E`#7I]>D
MUZC7F=>AUYG7GP#7IM>;UYG7E`#7D]>@UYG7E`#7E->HUZ37E=>1UYS7F=>G
MUY0@UY37D]>5UY[7F=>@UYG7I]>@UYG7J@#7D->GUY77E=>3UY77J`#7GM>F
MUZC7F=>=`->0UYSB@)/7H=><UY77E=>3UY77J`#7D->JUYG7E=>DUYG7E`#7
MI->9UY+7F0#7I->9UZ#7G->@UY,`UZ+7J->DUYP`UZ;7J->DUZH`UY+7D=>5
MUY\`UY+7GM>1UYG7E`#7DM>5UZC7DM>9UY0`UY+7J->>UZ#7F=>4`->2UZ#7
ME`#7G->:`->9UY77E=>?`->2UZC7H->3UY0`UY+7E=>0UYC7GM><UY0`UY+7
MF=>@UY#7E`#7DM>9UY#7H->4`->4UY#7F=>8UYD`UZ'7E=>DUZKB@)/7J->B
MUY[7F=>=(->BUY;7E`#7HM>6UZC7E`#7E=>8UYG7I]>?`->4UY77H->3UY77
MJ->A`-><UY?7E=>J`#K7G->7UYG7J@#7E->5UZ#7DM>HUYG7E`#7D->9UZ'7
MG->@UY,`UY37E=>3UY4`UY#7F=>@UY/7E=>@UY;7F=>4`->0UYG7J->?`->B
MUYG7J->G`->0UYG7J-><UZ#7DP#7F=>IUX'7J->0UYP`UY#7F=>8UYS7F=>4
M`->2UY[7F=>9UZ?7E`#7F=>DUY\`UYG7J->3UY\`UZ?7H->9UY0`UYO7E=>5
MUYG7F=>J`-><UY'7H->5UY\`UYS7F=>1UZC7F=>4`-><UY77D0#7G->5UYO7
MH=>>UY'7E=>HUY(`UY[7D]>2UZ'7I]>H`->>UYS7E=>5UYD`UY[7G->9UYG7
MEM>9UY0`UY37D->9UYG7G2#7E->>UYS7D]>9UY77E=>9UYG7G0#7GM><UYD`
MUY[7G->8UY0`UY[7D->5UZC7F=>8UZ#7F=>4`->>UY#7E=>HUYG7IM>9UY77
MH0#7GM>;UZ'7F=>GUY4`UY[7E=>@UZ?7E0#7GM>5UZ#7DM>5UYS7F=>4`->>
MUZC7E=>GUY4`UY[7E=>6UY[7D=>9UZ<`UZG7G0#7H->DUYP`UY37E=><UZ#7
MDP#7H->9UY7B@)/7EM>9UYS7H->3`->@UYG7I]>HUY+7E=>0UY0`UZ#7F=>6
MUZ@`UZ#7F=>2UZC7F=>4`->@UY77J->5UY77DM>9UY0`UZ+7E=>>UY#7GP#7
MD->DUZG7J->5UYG7E=>J`->0UY?7J`#7I->GUYG7H=>JUY\`UZ37H->>UY0`
MUZ37J->2UY77D->9UYD`UZ'7F=>AUY[7D`#7H=>9UZ'7GM>0.@#7H=>9UZ'7
MGM>0.B``UZ37J->5`->DUYG7G->9UZ37F=>@UYG7F=>=`->DUY77G->9UY\`
MUZ37E=>HUYC7E=>2UYP`UZ?7F->H`->HUY77GM>@UYG7E`#7J->5UZ'7F=>4
M`->HUY77D->@UY/7E`#7HM>HUY$@UY37H=>BUY77D]>9UZH`UY?7F=>DUY77
MJ0#7H=>@UY+7G`#7D->9UYGB@)/7H=>9UYG7J=><`->GUYG7F=>HUY0@UYS7
MF=>0UY77GP#7H=>9UZ#7DM>DUY77J`#7H=>5UY[7G->9UY0`UY/7J->5UYWB
M@)/7D->DUZC7F=>GUY0`UZ'7I->HUY,`UZ'7J->9(-><UZ#7I]>4`->AUY77
MD]>?`->AUY77J->9UZ#7G0#7H=>5UY77EM>9UYS7H->3`->IUY77E=>3UYG7
ME`#7J=>5UY77F=>E`->AUY77J->9UY0`UYC7H->6UZ#7F=>4`->JUY#7F=><
MUZ#7DP#7I]>1UY77IM>JXH"3UY#7F=>9XH"3UYC7E=>@UY+7E`#7F->HUYG7
MH->9UY/7DR#7E=>8UY77D=>2UY4`UYC7E=>@UYG7H=>9UY0`UYC7E=>HUZ?7
MF=>9UY0`UY#7JM>H`->0UZK7J#H`UY#7E=>2UZ#7D]>4`->0UY77I]>HUYG7
MF=>@UY0`UY37D->>UYG7J->5UYG7E=>J(->4UY[7D->5UY?7D]>5UZH`UY37
MGM>>UYS7F]>4(->4UY[7D->5UY?7D]>J`->0UZC7IM>5UZKB@)/7E->1UZC7
MF=>J`->4UZ+7G->0UY0`UY#7E=>HUY77DM>5UY77F0#7I]>5UY,@UY;7F=>4
MUY77F2#7GM>IUZK7GM>I`->5UZ#7E=>0UYC7E0#7E=>@UY;7E=>0UYS7E`#7
MDM>9UZC7H=>4`->5UYG7F=>8XH"3UZ#7G0#7J->5UY<`UZC7E=>7.@#7J->5
MUY<Z(`#7JM>9UY[7GP#7F=>5UY+7E=>AUYS7D=>9UY0`UY;7GM>1UYG7F=>4
M`->6UYG7GM>1UY'7E=>5UY0`UZ+7EM>HUY0`UY37JM>@UZK7I]>5UZH`UY#7
MI->IUZC7E=>9UY77J@#7H=>DUZ@@UYO7JM>5UY'7E=>J`->IUYT`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VED7TE$````````````````
M````````````````````````````````````````````````````````````
M`````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P
M-3$U-#,S-S0Q(#`Q-S8V-@`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O
M:61?240O3$-?34534T%'15,`````````````````````````````````````
M````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W-#$@,#(Q-#4S`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQO8V%L92]I9%])1"],0U]-15-304=%4R]H;W)D92YM;P``
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#$V-#`Q-B`Q,#4Q-30S,S<T,2`P
M,C,R,#``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````WA($E0````!U`P``'````,0;``"=!```;#<```````#@20``!````.%)
M```D````YDD``"D````+2@``&0```#5*```F````3TH```P```!V2@``)```
M`(-*```/````J$H```L```"X2@``*````,1*```(````[4H``!4```#V2@``
M"P````Q+``"%````&$L```H```">2P``#@```*E+```/````N$L``!@```#(
M2P``#@```.%+```.````\$L```@```#_2P``+@````A,```)````-TP```T`
M``!!3```!P```$],```*````5TP```\```!B3```!0```'),```1````>$P`
M``@```"*3```"0```)-,```)````G4P``!,```"G3```$````+M,```*````
MS$P```,```#73```#P```-M,```)````ZTP```T```#U3```#P````--```/
M````$TT```@````C30``)````"Q-```(````44T``!D```!:30``#````'1-
M```.````@4T```,```"030``!0```)1-```*````FDT```,```"E30``%P``
M`*E-```*````P4T```X```#,30``(P```-M-```4````_TT``!<````43@``
M%P```"Q.```7````1$X``!,```!<3@``#P```'!.```&````@$X```L```"'
M3@``$````)-.```5````I$X``!4```"Z3@``!P```-!.```%````V$X``!4`
M``#>3@``.P```/1.```4````,$\```,```!%3P``"0```$E/```Y````4T\`
M`"<```"-3P``+````+5/```J````XD\``"4````-4```!@```#-0```1````
M.E````P```!,4```"@```%E0```0````9%```!0```!U4```"````(I0```.
M````DU````H```"B4```!````*U0```)````LE````8```"\4```$0```,-0
M```'````U5````0```#=4```!@```.)0```-````Z5````,```#W4```$P``
M`/M0```(````#U$```0````840``00```!U1```&````7U$``!4```!F40``
M!P```'Q1```5````A%$```\```":40``#0```*I1```/````N%$```T```#(
M40``%````-91```&````ZU$``!T```#R40``!@```!!2```4````%U(``%0`
M```L4@``9````(%2```$````YE(```X```#K4@``&P```/I2```:````%E,`
M`!P````Q4P``*@```$Y3```%````>5,``!,```!_4P``$@```)-3```*````
MIE,```\```"Q4P``#0```,%3```1````SU,```P```#A4P``!@```.Y3```,
M````]5,```8````"5```$`````E4```1````&E0```4````L5```#````#)4
M```%````/U0```8```!%5```!P```$Q4```-````5%0```D```!B5```"0``
M`&Q4```*````=E0``!D```"!5```'0```)M4```,````N50``!````#&5```
M"````-=4```(````X%0```8```#I5```!````/!4```.````]50``!T````$
M50``(````")5``"B````0U4``!\```#F50``(`````96```P````)U8``)(`
M``!85@``00```.M6```'````+5<```8````U5P``#0```#Q7```0````2E<`
M``P```!;5P``#@```&A7```/````=U<``!,```"'5P``#0```)M7```H````
MJ5<```,```#25P``#0```-97```1````Y%<``!<```#V5P``&P````Y8```"
M````*E@``!`````M6```#0```#Y8```#````3%@```X```!06```"````%]8
M```/````:%@```\```!X6```!P```(A8```-````D%@```T```">6```"P``
M`*Q8```&````N%@```L```"_6```#````,M8```+````V%@```T```#D6```
M(@```/)8```*````%5D``!@````@60``&0```#E9```6````4UD``!0```!J
M60``"P```']9```+````BUD```D```"760``&0```*%9```+````NUD``!<`
M``#'60``%P```-]9```)````]UD``!8````!6@``#P```!A:```9````*%H`
M`!8```!"6@``)@```%E:``!#````@%H``!\```#$6@``+P```.1:```%````
M%%L```0````:6P``"@```!];```*````*EL``!`````U6P``%P```$9;```1
M````7EL``!<```!P6P``"0```(A;```*````DEL```(```"=6P``#0```*!;
M```X````KEL``"````#G6P``#@````A<``![````%UP``!@```"37```!0``
M`*Q<```;````LEP```8```#.7```$````-5<```/````YEP``!````#V7```
M#P````==```/````%UT```P````G70``#P```#1=```'````1%T```X```!,
M70``"````%M=```3````9%T```0```!X70``!0```'U=```(````@UT```H`
M``",70``#````)==```+````I%T``!````"P70``#````,%=```'````SET`
M``H```#670``#0```.%=```%````[UT```,```#U70``"@```/E=```$````
M!%X``"8````)7@``#@```#!>``!\````/UX``!4```"\7@``!0```-)>```'
M````V%X```P```#@7@``"````.U>```*````]EX```8````!7P``"`````A?
M```"````$5\```8````47P``"0```!M?```0````)5\```D````V7P``"0``
M`$!?```:````2E\```@```!E7P``&0```&Y?```.````B%\```(```"77P``
M!@```)I?```-````H5\``!(```"O7P``%````,)?```&````UU\``!$```#>
M7P``"0```/!?```Y````^E\``#T````T8```.@```')@```$````K6```!4`
M``"R8```!@```,A@```$````SV```!$```#48```"@```.9@```B````\6``
M``0````480``!0```!EA```.````'V$```4````N80``#P```#1A```2````
M1&$```L```!780``)@```&-A```I````BF$``"0```"T80``)@```-EA```(
M`````&(```H````)8@``"0```!1B```2````'F(```H````Q8@``#````#QB
M```/````26(``!````!98@``<````&IB```.````VV(```D```#J8@``"@``
M`/1B```2````_V(``!,````28P``!@```"9C```/````+6,``!(````]8P``
M$````%!C```1````86,``&H```!S8P``#P```-YC```0````[F,```L```#_
M8P``(`````MD```4````+&0```P```!!9```#````$YD```/````6V0``!4`
M``!K9```*0```(%D```J````JV0``"8```#69```)P```/UD```I````)64`
M`"H```!/90``&0```'IE``!"````E&4``!$```#790``$@```.EE```3````
M_&4``!0````09@``%@```"5F```7````/&8``!````!49@``$0```&5F```T
M````=V8``!,```"L9@``$@```,!F```4````TV8``!H```#H9@``"0````-G
M```1````#6<```8````?9P``!P```"9G```6````+F<```0```!%9P``!```
M`$IG```'````3V<```X```!79P``#````&9G```,````<V<```T```"`9P``
M#@```(YG```$````G6<```\```"B9P``!P```+)G```(````NF<```D```##
M9P``%````,UG```,````XF<```T```#O9P```P```/UG```&`````6@``!D`
M```(:```!````")H```-````)V@```H````U:```$````$!H```/````46@`
M`!$```!A:```%P```'-H```*````BV@``!$```"6:```"````*AH```/````
ML6@```P```#!:```#@```,YH```0````W6@```L```#N:```&@```/IH```*
M````%6D```P````@:0``#P```"UI```(````/6D```8```!&:0``!P```$UI
M```%````56D```L```!;:0``!````&=I```#````;&D``!,```!P:0``$P``
M`(1I```3````F&D```(```"L:0``!````*]I```%````M&D```0```"Z:0``
M"@```+]I```-````RFD``&@```#8:0``!0```$%J```&````1VH```\```!.
M:@``&````%YJ```7````=VH``!\```"/:@```P```*]J```(````LVH```<`
M``"\:@``"@```,1J```+````SVH```T```#;:@``&@```.EJ``!*````!&L`
M``8```!/:P``!@```%9K```8````76L``!<```!V:P``#0```(YK``!7````
MG&L```(```#T:P``"P```/=K```(`````VP```H````,;```"P```!=L```,
M````(VP```T````P;```#````#YL```*````2VP``!8```!6;```"0```&UL
M```0````=VP``!(```"(;```!P```)ML```%````HVP```P```"I;```"```
M`+9L```7````OVP```P```#7;```&@```.1L```3````_VP```0````3;0``
M"@```!AM```$````(VT```4````H;0``.````"YM```*````9VT```\```!R
M;0``$P```()M```5````EFT``!,```"L;0``"````,!M```(````R6T``"L`
M``#2;0``10```/YM``!!````1&X```0```"&;@``$P```(MN```4````GVX`
M`!,```"T;@``!P```,AN```%````T&X``!L```#6;@``"````/)N```1````
M^VX```X````-;P```@```!QO```.````'V\```<````N;P``#@```#9O```&
M````16\``"@```!,;P``#````'5O```<````@F\``!<```"?;P``7````+=O
M```4````%'```!\````I<```$````$EP```'````6G````X```!B<```#```
M`'%P```*````?G```!T```")<```&0```*=P```%````P7```!$```#'<```
M$0```-EP```(````ZW````D```#T<```#0```/YP```*````#'$```<````7
M<0``#P```!]Q```&````+W$```L````V<0``&@```$)Q```*````77$```<`
M``!H<0``#0```'!Q```(````?G$``!X```"'<0``"0```*9Q```*````L'$`
M`!4```"[<0``!0```-%Q```4````UW$```0```#L<0``$````/%Q```&````
M`G(```<````)<@``'@```!%R```H````,'(``!P```!9<@``&@```'9R```4
M````D7(```0```"F<@``!@```*MR```&````LG(```H```"Y<@``&P```,1R
M```T````X'(``#0````5<P``*0```$IS```H````=',``"D```"=<P``4```
M`,=S```(````&'0```4````A=```&0```"=T```9````070``",```!;=```
M&0```']T```(````F70``!<```"B=```"@```+IT```'````Q70``"$```#-
M=```#@```.]T```3````_G0```@````2=0``!0```!MU```%````(74```0`
M```G=0``"@```"QU```)````-W4```L```!!=0``#0```$UU```,````6W4`
M``X```!H=0``!````'=U```R````?'4``$4```"O=0``%P```/5U```>````
M#78``!0````L=@``!P```$%V```.````278``"H```!8=@``!@```(-V```,
M````BG8``!$```"7=@``"P```*EV```V````M78```H```#L=@``(@```/=V
M```+````&G<```\````F=P``!0```#9W```.````/'<``!,```!+=P``!P``
M`%]W```1````9W<``!,```!Y=P``%````(UW```8````HG<```<```"[=P``
M!0```,-W```2````R7<```X```#<=P``#@```.MW```%````^G<```4`````
M>```+@````9X```F````-7@``",```!<>````P```(!X```-````A'@```D`
M``"2>````P```)QX```*````H'@```(```"K>```$@```*YX```$````P7@`
M``<```#&>```#````,YX``!2````VW@``!<````N>0``$@```$9Y```'````
M67D```8```!A>0``#@```&AY```5````=WD``!(```"->0``#P```*!Y```4
M````L'D``&D```#%>0``&@```"]Z```7````2GH``"<```!B>@``&@```(IZ
M```7````I7H``!L```"]>@``&0```-EZ```?````\WH``!,````3>P``"```
M`"=[```)````,'L``$8````Z>P``/P```(%[```W````P7L``%<```#Y>P``
M!0```%%\```?````5WP``"\```!W?```"````*=\```-````L'P``"T```"^
M?```!````.Q\``!/````\7P``"4```!!?0``'P```&=]```=````AWT``"4`
M``"E?0``(````,M]```D````['T``"`````1?@``!P```#)^```-````.GX`
M``P```!(?@``%P```%5^```0````;7X```0```!^?@``"P```(-^```,````
MCWX``!(```"<?@``$0```*]^```,````P7X``!H```#.?@``#0```.E^```;
M````]WX``!,````3?P``'````"=_```H````1'\```<```!M?P``$P```'5_
M```$````B7\``!<```".?P``"@```*9_```,````L7\```D```"^?P``!@``
M`,A_```(````SW\```D```#8?P``!@```.)_```-````Z7\```L```#W?P``
M`@````.````)````!H````<````0@```&@```!B````[````,X```"@```!O
M@```-````)B````5````S8````<```#C@```"````.N````'````](````4`
M``#\@```!P````*!```.````"H$```D````9@0``!@```".!```(````*H$`
M``L````S@0``!P```#^!```'````1X$``!$```!/@0``"````&&!```0````
M:H$``!````![@0``!P```(R!```%````E($``!0```":@0``"P```*^!```-
M````NX$``"@```#)@0``%P```/*!```)````"H(```H````4@@``!P```!^"
M```"````)X(```X````J@@``,0```#F"```G````:X(``!0```"3@@``J0$`
M`*B"```C````4H0``!<```!VA```'0```(Z$```8````K(0``"$```#%A```
M'P```.>$```K````!X4``!T````SA0``$0```%&%```G````8X4``%0```"+
MA0``"P```."%```Q````[(4```<````>A@``!P```":&```-````+H8```L`
M```\A@``!0```$B&```0````3H8```4```!?A@``$@```&6&```(````>(8`
M``,```"!A@``$````(6&```,````EH8```(```"CA@``%````*:&```,````
MNX8```,```#(A@``!````,R&```:````T88```D```#LA@``#````/:&```7
M`````X<```<````;AP``#P```".'```%````,X<``!H````YAP``QP```%2'
M```+````'(@```8````HB```"0```"^(```+````.8@```T```!%B```%P``
M`%.(```&````:X@``#,```!RB```$P```*:(```3````NH@``#(```#.B```
M$P````&)```1````%8D``#(````GB0``%@```%J)```(````<8D```D```!Z
MB0``"@```(2)```4````CXD```@```"DB0``"````*V)```/````MHD```X`
M``#&B0``$````-6)```)````YHD```D```#PB0``$P```/J)```9````#HH`
M``H````HB@``#````#.*```J````0(H```<```!KB@```@```'.*```0````
M=HH``!@```"'B@```P```*"*```(````I(H```<```"MB@``#0```+6*```+
M````PXH``!0```#/B@``%0```.2*```O````^HH``"`````JBP``'````$N+
M```,````:(L``#$```!UBP``!0```*>+```_````K8L``!(```#MBP``"@``
M``",```&````"XP```0````2C```!````!>,```*````'(P``!,````GC```
M!0```#N,```&````08P```8```!(C```"````$^,```$````6(P```4```!=
MC````@```&.,```,````9HP``$4```!SC```,@```+F,``!%````[(P``#``
M```RC0``*````&.-```I````C(T``"8```"VC0``)0```-V-```H`````XX`
M`!(````LC@``$P```#^.```0````4XX```D```!DC@``<P```&Z.```K````
MXHX``!<````.CP``)P```":/```6````3H\```\```!ECP``'P```'6/```<
M````E8\``%$```"RCP``%`````20```%````&9```!(````?D```$````#*0
M```3````0Y````\```!7D```!````&>0```)````;)````L```!VD```!P``
M`(*0```4````BI````\```"?D```#````*^0```/````O)````8```#,D```
M%````-.0```&````Z)````0```#OD```!P```/20```9````_)````<````6
MD0``!@```!Z1```&````)9$```0````LD0``!P```#&1```&````.9$```8`
M``!`D0``$````$>1```&````6)$``"(```!?D0``!P```(*1```+````BI$`
M`$8!``"6D0``!@```-V2```L````Y)(``"P````1DP``%@```#Z3``!`````
M59,```P```"6DP``,````*.3```5````U),``!(```#JDP``)````/V3```(
M````(I0``!L````KE```#0```$>4``"_````590```@````5E0``#@```!Z5
M```5````+94``!@```!#E0``#0```%R5```-````:I4```8```!XE0``*P``
M`'^5```*````JY4```H```"VE0``"````,&5```*````RI4``!````#5E0``
M!0```.:5```2````[)4```L```#_E0``.@````N6```\````1I8``!$```"#
ME@``#0```)66```)````HY8```8```"ME@``$````+26```.````Q98``!``
M``#4E@``%0```.66```3````^Y8```\````/EP``+0```!^7```/````39<`
M`"4```!=EP``#````(.7```,````D)<```4```"=EP``!````*.7```(````
MJ)<```4```"QEP``$P```+>7```*````RY<``!````#6EP``,@```.>7```4
M````&I@``!0````OF```'````$28```6````89@``!(```!XF```#P```(N8
M```'````FY@```@```"CF```#P```*R8```4````O)@``!L```#1F```"0``
M`.V8```%````]Y@``!,```#]F```20```!&9```3````6YD```0```!OF0``
M"@```'29```]````?YD``"P```"]F0``+````.J9```K````%YH``"T```!#
MF@``!P```'&:```4````>9H```L```".F@``#@```)J:```4````J9H``!0`
M``"^F@``.0```-.:```/````#9L```D````=FP``"P```">;```4````,YL`
M``8```!(FP``$````$^;```&````8)L```@```!GFP``!0```'";```-````
M=IL```,```"$FP``#0```(B;```(````EIL```8```"?FP``50```*:;```%
M````_)L``!@````"G```"P```!N<```2````)YP```P````ZG```,0```$><
M```,````>9P``!8```"&G```%````)V<```&````LIP``!D```"YG```!```
M`-.<```/````V)P``&8```#HG```:````$^=```(````N)T```\```#!G0``
M%P```-&=```7````Z9T``"4````!G@``,P```">>```)````6YX``!8```!E
MG@``%@```'R>```2````DYX``!<```"FG@``&````+Z>```1````UYX```T`
M``#IG@``!P```/>>```4````_YX```<````4GP``&````!R?```/````-9\`
M``4```!%GP``#0```$N?```%````69\```8```!?GP``!P```&:?```-````
M;I\```@```!\GP``!P```(6?```'````C9\``!4```"5GP``*````*N?```+
M````U)\``!````#@GP``!@```/&?```&````^)\```8```#_GP``!0````:@
M```-````#*```"8````:H```)````$&@``"[````9J```",````BH0``)0``
M`$:A```Q````;*$``+T```">H0``5````%RB```&````L:(```0```"XH@``
M"0```+VB```)````QZ(```X```#1H@``$P```."B```.````]*(``!$````#
MHP``#0```!6C```W````(Z,```4```!;HP``#0```&&C```1````;Z,``!<`
M``"!HP``&P```)FC```"````M:,``!````"XHP``$````,FC```$````VJ,`
M``L```#?HP``"````.NC```-````]*,``!`````"I```!P```!.D```-````
M&Z0```T````II```"````#>D```%````0*0```D```!&I```"@```%"D```)
M````6Z0```L```!EI```)P```'&D```+````F:0``!T```"EI```&0```,.D
M```9````W:0``!````#WI```"0````BE```,````$J4```L````?I0``'P``
M`"NE```+````2Z4``!(```!7I0``$@```&JE```)````?:4``!<```"'I0``
M$0```)^E```=````L:4``!T```#/I0``*0```.VE``!6````%Z8``"H```!N
MI@``.````)FF```+````TJ8```0```#>I@``"P```..F```)````[Z8```D`
M``#YI@``$@````.G```3````%J<``!(````JIP``"@```#VG```)````2*<`
M``(```!2IP``#````%6G``!!````8J<``"$```"DIP``#P```,:G``"=````
MUJ<``!H```!TJ```"0```(^H```F````F:@```0```#`J```#P```,6H```.
M````U:@```\```#DJ```#@```/2H```3`````ZD```P````7J0``$P```"2I
M```(````.*D``!<```!!J0``"````%FI```6````8JD```4```!YJ0```P``
M`'^I```(````@ZD```<```",J0``"````)2I```0````G:D``!8```"NJ0``
M#````,6I```&````TJD``!\```#9J0``'P```/FI```%````&:H```@````?
MJ@``#0```"BJ```'````-JH``"\````^J@``$P```&ZJ``"?````@JH``!<`
M```BJP``"````#JK```'````0ZL```P```!+JP``!P```%BK```)````8*L`
M``4```!JJP``"@```'"K```#````>ZL```4```!_JP``!````(6K```1````
MBJL```T```"<JP``#````*JK```B````MZL```8```#:JP``'````.&K```4
M````_JL```@````3K```!@```!RL```0````(ZP``!,````TK```$0```$BL
M```$````6JP```D```!?K```"0```&FL``!.````<ZP``%````#"K```4```
M`!.M```(````9*T``!4```!MK0``!@```(.M```'````BJT``!H```"2K0``
M#````*VM```?````NJT```8```#:K0``!0```.&M```.````YZT```4```#V
MK0``'@```/RM```[````&ZX```L```!7K@``.@```&.N```N````GJX``"0`
M``#-K@``+@```/*N```*````(:\```L````LKP``!P```#BO```9````0*\`
M``H```!:KP``#0```&6O```0````<Z\```\```"$KP``F@```)2O```-````
M+[````H````]L```"P```$BP```2````5+```!,```!GL```#0```'NP```1
M````B;```!8```";L```$P```+*P```9````QK```),```#@L```#@```'2Q
M```0````@[$```D```"4L0``(0```)ZQ```9````P+$```\```#:L0``#@``
M`.JQ```1````^;$``!D````+L@``-````"6R```T````6K(``#0```"/L@``
M-````,2R```P````^;(``#`````JLP``&P```%NS``!!````=[,``!<```"Y
MLP``%P```-&S```9````Z;,``!D````#M```'````!VT```<````.K0``!D`
M``!7M```&0```'&T```\````B[0``!0```#(M```$@```-VT```5````\+0`
M`!<````&M0``"@```!ZU```Y````*;4```P```!CM0``!P```'"U```4````
M>+4```0```"-M0``!````)*U```$````E[4```L```"<M0``$P```*BU```)
M````O+4```H```#&M0``#@```-&U```)````X+4```X```#JM0``"````/FU
M```&`````K8``"`````)M@``&````"JV```@````0[8``!(```!DM@``!0``
M`'>V```(````?;8``!X```"&M@``!````*6V```'````JK8```<```"RM@``
M%````+JV```:````S[8```<```#JM@``%@```/*V```(````";<```T````2
MMP``#0```""W```1````+K<```P```!`MP``#P```$VW```4````7;<```P`
M``!RMP``'P```'^W```-````G[<```P```"MMP``&@```+JW```&````U;<`
M``4```#<MP``!P```.*W```%````ZK<```L```#PMP``!0```/RW```&````
M`K@``!D````)N```&````".X```9````/+@```(```!6N```!````%FX```%
M````7K@```4```!DN```"P```&JX```,````=K@``&P```"#N```!0```/"X
M```&````]K@``!$```#]N```+@````^Y```L````/KD``"D```!KN0```P``
M`)6Y```+````F;D```<```"EN0``"@```*VY```-````N+D```P```#&N0``
M'````-.Y``!%````\+D```8````VN@``!@```#VZ```L````1+H``"L```!Q
MN@``"0```)VZ``!R````I[H```,````:NP``"P```!Z[```&````*KL```@`
M```QNP``"@```#J[```4````1;L``!8```!:NP``%````'&[```*````AKL`
M`!0```"1NP``"````*:[```1````K[L``!@```#!NP``!P```-J[```,````
MXKL```T```#ONP``"@```/V[```<````"+P```H````EO```%P```#"\```4
M````2+P```8```!=O```"P```&2\```*````<+P```4```![O```2P```(&\
M```4````S;P``!X```#BO```'0````&]```B````'[T``",```!"O0``$```
M`&:]```.````=[T``#<```"&O0``8````+Z]``!;````'[X```D```![O@``
M(@```(6^```9````J+X``!(```#"O@``#````-6^```'````XKX``"\```#J
MO@``"````!J_```,````([\```P````POP```@```#V_```.````0+\```<`
M``!/OP``$@```%>_```&````:K\``"(```!QOP``"@```)2_```7````G[\`
M`!X```"WOP``:P```-:_```9````0L```"(```!<P```#@```'_````'````
MCL```!````"6P```%````*?````(````O,```!8```#%P```&@```-S````)
M````]\````X````!P0``#````!#!```(````'<$```D````FP0``"@```##!
M```*````.\$```L```!&P0``$````%+!```(````8\$``"H```!LP0``'@``
M`)?!```)````ML$``!<```#`P0``$````-C!```%````Z<$``!8```#OP0``
M!@````;"```&````#<(``!(````4P@``!0```"?"```7````+<(```0```!%
MP@``&0```$K"```%````9,(```8```!JP@``(0```''"```S````D\(``"0`
M``#'P@``$0```.S"```1````_L(``!,````0PP``!````"3#```%````*<,`
M``\````OPP``(@```#_#```[````8L,``$0```">PP``+P```./#```I````
M$\0``"T````]Q```8@```&O$```'````SL0```<```#6Q```%P```-[$```6
M````]L0``"(````-Q0``'````##%```'````3<4``!P```!5Q0``"````'+%
M```%````>\4``"<```"!Q0``#0```*G%```1````M\4```8```#)Q0``!0``
M`-#%```%````UL4```4```#<Q0``$@```.+%```8````]<4```<````.Q@``
M$@```!;&```<````*<8```P```!&Q@``!````%/&```]````6,8``%P```"6
MQ@``&0```//&```<````#<<``!4````JQP``"````$#'```-````2<<``"D`
M``!7QP``"0```(''```0````B\<``!4```"<QP``$@```++'``!%````Q<<`
M``D````+R```'P```!7(```2````-<@``!8```!(R```#0```%_(```2````
M;<@``!<```"`R```!0```)C(```2````GL@``!8```"QR```%@```,C(```8
M````W\@```D```#XR```!0````+)```1````",D```X````:R0``#@```"G)
M```&````.,D```8````_R0``-@```$;)```L````?<D``"P```"JR0``"```
M`-?)```)````X,D```D```#JR0```P```/3)```*````^,D```,````#R@``
M%P````?*```&````'\H```D````FR@``#@```##*``!?````/\H``!X```"?
MR@``*0```+[*```0````Z,H```D```#YR@``#P````/+```9````$\L``!(`
M```MRP``#````$#+```=````3<L``'D```!KRP``%````.7+```5````^LL`
M`"P````0S```$@```#W,```3````4,P``!L```!DS```&````(#,```@````
MF<P``!4```"ZS```!P```-#,```)````V,P``%X```#BS```.@```$'-``!`
M````?,T``%0```"]S0``!0```!+.```=````&,X``"X````VS@``!P```&7.
M```0````;<X``#D```!^S@``"0```+C.``!5````PLX``#$````8SP``(P``
M`$K/```B````;L\``",```"1SP``'P```+7/```E````U<\``"````#[SP``
M!P```!S0```4````)-```!H````YT```&0```%30```3````;M````4```""
MT```#0```(C0```-````EM```!H```"DT```(````+_0```0````X-```"(`
M``#QT```#````!31```:````(=$``!0````\T0``(````%'1```H````<M$`
M``L```";T0``)P```*?1```$````S]$``!D```#4T0``#````.[1```.````
M^]$```X````*T@``"````!G2```'````(M(``!(````JT@``!@```#W2```J
M````1-(```H```!OT@```P```'K2```X````?M(```@```"WT@``&P```,#2
M``!)````W-(``"L````FTP``,P```%+3```;````AM,```D```"BTP``#P``
M`*S3```1````O-,```4```#.TP``#P```-33```A````Y-,``!`````&U```
M$0```!?4```2````*=0``#$````\U```"````&[4```G````=]0``"T```"?
MU```)P```,W4```.````]=0```X````$U0``!P```!/5```%````&]4``!@`
M```AU0``!````#K5```%````/]4``"$```!%U0``%0```&?5```*````?=4`
M``T```"(U0``$````);5```#````I]4```X```"KU0``+0```+K5```L````
MZ-4``!<````5U@``'0(``"W6```=````2]@``!8```!IV```(````(#8```7
M````H=@``",```"YV```)````-W8```[`````MD``"`````^V0``%@```%_9
M```E````=MD``%X```"<V0``#@```/O9```N````"MH```4````YV@``!0``
M`#_:```/````1=H```P```!5V@``!0```&+:```8````:-H```@```"!V@``
M$0```(K:```%````G-H```0```"BV@``$0```*?:```)````N=H```,```##
MV@``$@```,?:```+````VMH```,```#FV@``!````.K:```E````[]H```L`
M```5VP``$@```"';```;````--L``!````!0VP``#P```&';```$````<=L`
M`"<```!VVP``&0$``)[;```2````N-P```H```#+W```#0```-;<```3````
MY-P``!@```#XW```'0```!'=```&````+]T``#,````VW0``&````&K=```9
M````@]T``#H```"=W0``%0```-C=```4````[MT``#D````#W@``(````#W>
M```-````7MX```X```!LW@``#@```'O>```9````BMX```<```"DW@``"```
M`*S>```-````M=X``#8```##W@``,0```/K>```)````+-\```T````VWP``
M$````$3?```8````5=\```T```!NWP``#@```'S?```Y````B]\```H```#%
MWP``!````-#?```-````U=\``!H```#CWP```P```/[?```(`````N````X`
M```+X```%````!K@```2````+^```!0```!"X```%0```%?@```S````;>``
M`"4```"AX```*0```,?@```.````\>```#P`````X0``!0```#WA``!'````
M0^$```L```"+X0``"@```)?A```&````HN$```0```"IX0``!0```*[A```2
M````M.$``!T```#'X0``!@```.7A```&````[.$```X```#SX0``$`````+B
M```)````$^(```4````=X@```@```"/B```/````)N(``&(````VX@``-@``
M`)GB``!.````T.(``#4````?XP``+@```%7C```[````A.,``#L```#`XP``
M,P```/SC```W````,.0``!$```!HY```$@```'KD```.````C>0```D```"<
MY```?````*;D```M````(^4``!D```!1Y0``)````&OE```7````D.4``!(`
M``"HY0``(P```+OE```=````W^4``&$```#]Y0``$P```%_F```%````<^8`
M`!P```!YY@``$0```);F```:````J.8```T```##Y@``!````-'F```)````
MUN8```L```#@Y@``!0```.SF```2````\N8```P````%YP``!````!+G```1
M````%^<```8````IYP``$0```##G```(````0N<```8```!+YP``!0```%+G
M```7````6.<```T```!PYP``%@```'[G```&````E><```0```"<YP``!@``
M`*'G```%````J.<```0```"NYP``$P```+/G```%````Q^<``"D```#-YP``
M"@```/?G```+`````N@```$```#/````7`(``!P"``#1`@```````),````4
M````0`(``#H#``!L`0``L````$@#``#<`@```````(H"```H`P``$@```&X#
M`````````````%\#````````X0````````#D`@``&@(```````!Y````1P(`
M````````````X@```$X"``"_`@``/`$```````#7`0``\@```)(!``"``0``
M+P(``'`````T`P``:P```$L``````````````)P!``#N````<@,``/$!``!5
M`@``$`$```,`````````:P$```````!\````)P```*8!```'`@``?0(``)@`
M``"\`@```````!L!``!H````#``````````.`0``/P(```````!T`0``````
M``````"7`@```````!\``````````````````````````````#8```!S`0``
MA@(``/L```"+`@``]P(``"4#``!B`@``O`$``)L!```U````GP```!L`````
M````F0(``.8````E````!0,``(<!``"/`0```````#T"````````"0```$T"
M``!=````9@(``($"``!C````DP$``',#````````7`,````````W`P``4P``
M`!<`````````\`$``*L````"`@``!P```%8#``"L`0``GP$```````#_`@``
M`````/X"```.`P``CP(```8"``#S`0``AP```'`"``!9`P```````)H```!/
M````Q@(``",```"S`````````-4"````````H0$``$,```#J````=@(`````
M``#,`0``%@$``+H```!/`0``#`$``&0!```R`P``,````+H!``"M`0``,P,`
M`!$!``#1`0````````<#````````(0```)4!```1`@``.P(``$H!````````
M[`$```````#%`@``)`$`````````````)@````````#O`0``M````/0!``"'
M`@``*`(``-X!``#*````?0````````"#`0``,@$``,X```"Q`0``:@$``/\`
M``#]`0``<`,``%\```"0`0```````&@#``"[`0``-P(``/$```!H`@``8P(`
M`+@"``#@`0``S`(```````!O````M@````````#J`@```````)4"````````
M`````!P`````````^P$```````#8`@``:P,``!,"``!$`P``>P$``&$"``!C
M`P``<@$``.0!```Z`@```````&D!`````````````&<#````````[0(`````
M``"L````=P(``'<!``"^`0``50,``-P!``!#`0```````%\!``!/`@``10(`
M``````!3`@``O0$``&T#```.`@``80,``!0!``"+````(@,``!`"```A`P``
MK`(``-,"``````````````````!_`@``LP(```````````````````````#K
M````U`$```````#B`0``J0```+<"````````"`$```````"H`@```0,`````
M````````&@,``-X```"4`0``<@```"P```#.`0```````$("```^`@``@`(`
M```````M`P``CP````````!]`0``@@```)$"``#4`````````)@!``!X`0``
M9P$``"`#``#``0``K@$```````#E`````````),"``#H`0```````',```!)
M`0``3@```$$"````````-0$````````R`@``F0$``,<"``"[`@``9`(`````
M````````<0(``$0!``!Q`````````"4"``!_````RP```(T````]`P``UP(`
M``````!B````%0,```<!`````````````(,```"C`@``I`(``/H"````````
M`````(4```!9`0``A0$```````!U`P```````$P#````````9@$``)<!````
M````"````&<````!`@``G0$``(D!```5`@``V@$```````#Q`@``-@$``'<`
M```K`0```````/<````&````?`$````````6`@``=0``````````````````
M```````:`0``F@$``&,!````````^````&`````Q`@``,`(```````!2`@``
M3`(``+D```!^`0``'@,````````A`0``*0```$8#``#+`@``*````#0"```%
M````M`$``%(!``#0`0``;@$``$<!``"?`@`````````````G`0``!`$``#X`
M````````70(````````X`0``]0```-\```!A`0```````%(```"%`@``@0``
M`(X"```=````%0$``!@"```I`P``T@$``-H`````````H`$``/,```"E`0``
M#P(``)@"````````4`(``*8````4`P``B0(```````#L`@``6```````````
M````_0```#`#`````````````%`!```D````\````(``````````U0``````
M```U`@``/`,``#P```#(`0``T0``````````````TP```+\`````````N```
M``(#`````````````(@"```X`P``2@,``/<!````````V@(```````!Z````
M90(``'4"``!Z`@``Q0$`````````````*`$``,(```"O`0``W0$``!T!````
M````T@````4!``!+`P```````,4````3`P``Z````,L!```Q`P``X0(``$0"
M``"J`0``HP`````````$`@``P0$``)("``!0````/0```'X"```1````1P``
M`/D```#5`0``QP```'@"``"U`````````)8```````````````\#``!@`@``
ML@(``#,!``#G````(P(``"X"``!Z`0``30```",!``!'`P``````````````
M````J0(```````!7````J`$```````!S`@````````````!J`P``G0```#H!
M````````[@$``"L#````````(`(``!8````F`0``7@,````````"`0``W0``
M`*T"``#I`````````&T!``"A`@``[P(``&H"`````````````/H```!#`P``
M(````$8```!I````````````````````M0(``/\!``````````````T```!I
M`P``VP$```4"```3`````````/@!``#9````E@$``*D!``!L`````````"X`
M````````[@(``%D````Y`P```````.4!``!8`@``+`$``+0"````````'P(`
M`)H"``"!`0``10,``&8```"V`0``:@```$@!``"^`@``*@$``$H"```B````
M:0(``"P#``!1````#0$``'0```!O`@````````````">`@``8@$````````-
M`P`````````````Q````@@(``/D!``#F`@``````````````````,P```+<`
M`````````````+P`````````:P(``$\#``"9```````````````*`@``H```
M`*X`````````6@$``'0"``#O````>P(``.,"```^`P``;@(``%$#````````
M#@`````````[````20(``"X!``"G`0```````%L!``">`0``BP$``)L```!,
M`````````"H"````````.@````````!`````Z0(`````````````%P$``!(!
M``!P`0``50````````#?`@``6@(``/8````X`@`````````````P`0``S0``
M`#8"```I`@``40(``"\!``#U`@``0@$``(D```#V`0```````'D!``!M`@``
ME0```%D"`````````@```!````!\`@``&`,``!,!``"$`````````"8#```1
M`P```````+X``````P````````````!-`0``B@$``&4```"Y`0``=@```%X`
M```T`0``U`(``(P!````````)0$``*8"```X````K@(```````#`````6P``
M````````````80```.T!``".`0``N`$````````+`0``:`$```H#``!4`P``
M-````!T"``!%````-P```,0````_`0``"@``````````````&0(``#D"``#)
M`0``(@(``-D"```&`0``&@```.<"```,`@``5P$```````"7`````````+<!
M```N`P```````*H````M````0`$``.@"```6`P````````````#'`0``````
M`*4"```M`@``'@```+$"``#T````PP$`````````````H`(``%\"``"1````
M'@$``+H"````````JP$``%L#````````V````#P"```$````2P$```P#```<
M`P```````&\#`````````````$0```#[`@``"@$``#4#````````,P(``$8!
M```)`P```````+T"``"1`0``R@$``"$"`````````````,,```#P`@``@P(`
M`,$"```/``````(``+T```#U`0```````,("````````6P(```````!V`0``
M`````+`!```C`P``7`$``$X#```;`@``0@````````#R`0``V0$``-`"``#B
M`@```````,T!``!)````N0(``!@!``#Y`@``]`(``.4"```9`0``Q@```#D!
M```G`@``0P(``"L"``!%`0````````````",````B`$```````!L`@``````
M`)(```#G`0``SP$``)`"``#]`@````````````!O`0``;0````````"R`0``
M&0```-@!```2`P``7@(``%@!``"&````4P$```,!`````````````#L#``!E
M`P``A@$``/X````;`P``ZP(``*L"``!R`@``SP(``-,!````````$`,``'X`
M``#``@``[0```"0"``"S`0``00````````"O`@````````````#6`0``````
M````````````H0`````````&`P``90$``)T"```I`0``A`$``+4!```+`@``
M,@````````"P`@``````````````````1@(```````"G````"`(``)0```#,
M````S@(``'\!```B`0``.P$```````"<`@``)P,``%<#````````H@``````
M``#^`0``20,``-("````````G````&P#`````````````/,"``!"`P``/P,`
M`.L!``#D````C@````````#@`@```````#D`````````)@(``%4!``!T`P``
MC0$``'L```!:`P``Q`$````````O````&0,```````#V`@```````,D```!1
M`0```````%0"````````I````#T!````````W``````````K````;@```%T#
M```4`@``%P,```````"B`0``/P```$`#``",`@``PP(```````#\`0``````
M`-`````$`P```````-8"``#\`````````+(```#?`0``4P,``$@"````````
M`````'D"```+`P``8`$``%8"``#(`@``Q@$``#X!```V`P``"0$``%T!``!G
M`@``00,``!<"````````Q`(``*H"``#6````3@$``,@```#=`@``````````
M``!>`0``>````*\```````````$``"`!````````'`$``*,!````````%0``
M`"\#``#;````E@(``)0"```J`P``````````````````"P```'$!``"*````
MNP``````````````#P$``/("``#7```````````````W`0```````$L"``#-
M`@``P0```!X"``#;`@``FP(``*("````````5P(``/P"``"0````8@,``!T#
M```2`@``IP(``.$!``!-`P```````.P```#Z`0```P(```````"_`0``````
M`,D"``"-`@``5`$``.,``````````````$P!`````````````(@```!@`P``
M"0(``(0"``!*````Y@$``'$#```D`P``9````%0```!!`0``7````"T!``#C
M`0```````((!``#*`@``6`,``%(#```!`0``*@```*0!``#@`````````'4!
M````````#0(``.H!````````6@```&8#`````````````%8```!(````+`(`
M`*4```"Q````&````````````````````&0#``#X`@``5@$``#$!``"V`@``
MG@```!\#``!0`P``'P$```@#```#`P``P@$``.D!`````````````*T`````
M`````````*@```#>`@```"!A="``(B5S(B!W87,@861D960@=&\@=&AE(&=R
M;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N
M<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`)2XR9DU"('5S
M960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2D`)60@)7,@86YD("5S`"5D
M(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+@`E9"UD87D@9F]R
M96-A<W0`)7,@+2!.;W1I8V4`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M
M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!497)M<R!O9B!!9W)E96UE;G0`
M)7,@870@)7,@)7,`)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@8F]X
M(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@
M=&AI<R!T:6UE+@`E<R!M:6YU=&5S`"5S('1O("5S(&]F("5S`"P@9W5S=&EN
M9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`,3(@2&]U<B!&;W)M
M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`02!D871A8F%S92!B86-K96YD
M(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!32!#;&]U9',`04T@3&EG
M:'0@4F%I;@!!32!286EN`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W97)S`$%-
M+U!-`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B<V)O='1O;0!!8G-M
M:61D;&4`06-C;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A<W-W;W)D`$%C
M8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@2&5R93H`061D($YE
M=R!'<F]U<`!!9&0@82!N97<@=7-E<CH`061D(&YE=R!M96UB97)S`$%D9"!P
M86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@
M=7-E<@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,@0F]O:P!!
M9&UI;FES=')A=&EO;@!!9',`06QI9VX`06QI9VYM96YT.@!!;&P`06QL($%U
M=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@9F]U<B!S:61E<P!!
M;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;'1E<FYA=&4@
M24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@
M24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA
M=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;G-W97(`07!P;&EC871I
M;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P
M;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!R:6P`07)A8FEC("A7:6YD
M;W=S+3$R-38I`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE
M('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R;65N:6%N("A!4DU30TE)+3@I
M`$%R=`!!<V-I:2!!<G0`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O
M:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%T=&5M<'0@=&\@9&5L971E
M(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO
M;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM
M97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X
M:7-T96YT('-H87)E+@!!=6=U<W0`079A:6QA8FQE(&9I96QD<SH`0D]&2"!%
M>&-U<V5S`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"86QT:6,@*$E3
M3RTX.#4Y+3$S*0!"87-E;&EN90!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E
M`$)O;&0`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!";W)D
M97)S`$)O=&@`0F]T=&]M`$)U;&QE=&5D($QI<W0`0TU3`$-?96QL(%!R;W!E
M<G1I97,N+BX`0V%L96YD87(`0V%L;0!#86X@;F]T(')E<V5T('!A<W-W;W)D
M(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#
M86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A<'1I;VX`0V%T96=O<FEE
M<R!A;F0@3&%B96QS`$-E;&P@4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E
M;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;'1I8R`H25-/+3@X-3DM
M,30I`$-E;G1E<@!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*0!#:&%N
M9V4`0VAA;F=E(%EO=7(@4&%S<W=O<F0`0VAA;F=E('1H92!N86UE(&%N9"!A
M9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P
M;'D@=&\@>6]U<B!E;6%I;',N`$-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@
M;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN
M("!#;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0VAA<@!#:&5C7VL@3&EN
M:RXN+@!#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D
M:71I;VYA;"`H0FEG-2D`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#
M:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VQE
M87(`0VQE87(@35-/9F9I8V4@=&%G<P!#;&5A<B!O=70@=7-E<CH@)7,`0VQE
M87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQE87)I;F<@3&%T90!#;&EC:R!T
M;R!#;VYT:6YU90!#;&]S92!7:6YD;W<`0VQO=61S`$-L;W5D<R!%87)L>0!#
M;&]U9'D`0V]L;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO
M<@!#;VQO<B!0:6-K97(`0V]L<SH`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3
M:&5L;`!#;VUP=71E<G,`0V]N9&ET:6]N`$-O;F1I=&EO;G,`0V]N9FEG=7)A
M=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E
M+@!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYT86-T<P!#;VYT
M:6YU90!#;V]K:64`0V]P>0!#;W!Y('-E;&5C=&EO;@!#;W5L9"!N;W0@8FEN
M9"!T;R!L9&%P('-E<G9E<@!#;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E
M<G9E<@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q
M=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS(&%R92!N
M;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES
M=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T(')E
M=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U
M<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I
M;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@
M9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N
M<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL
M>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&1N)W0@9FEN9"!T:&4@36]Z
M:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`
M0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@;VYE
M`$-U<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT(%=E871H97(`
M0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T
M87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I
M;VX`0WER:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`
M0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I`$1$`$1A=&%4<F5E($)R;W=S
M97(`1&%T92!296-E:79E9`!$87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`
M1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U
M;'0@0V]L;W(`1&5F875L="!3:&5L;`!$969I;FET:6]N<P!$96QE=&4`1&5L
M971E($-E;&P`1&5L971E($=R;W5P`$1E;&5T92!C96QL`$1E;&5T92!C;VQU
M;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@
M<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E
M;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5S8W)I8F4@=&AE
M(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E
M=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N
M(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T
M;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I
M<W!L87D@9&5T86EL960@9F]R96-A<W0`1&ES<&QA>2!F;W)E8V%S="`H5$%&
M*0!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;V5S
M('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE
M<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG
M;B!U<"X`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0
M('-C<FEP="X`1')U9W,`161I=`!%9&ET($)L;V-K`$5D:70@1W)O=7``161I
M="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P
M=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9'5C871I;VX`
M16QE;65N="XN+@!%;0!%;6%I;"!!9&1R97-S`$5N86)L92!I;G-E<G1I;VX@
M;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N86)L
M92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N;&%R9V4@161I=&]R`$5N
M=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K
M960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G
M=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA
M9V4@55),(&AE<F4`17)R;W(`17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S
M`$5T:&YI8P!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R
M>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!H86QF(&AO=7(`
M179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9"!3
M:61E8F%R`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I<@!&87AE
M<P!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R
M<P!&97<@4VYO=R!3:&]W97)S`$9I;&4@36%N86=E<@!&:6QT97)S`$9I<G-T
M($AA;&8`1FER<W0@475A<G1E<@!&;&]A=`!&;V<`1F]N="!#;VQO<@!&;V]D
M`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C
M87-T("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N
M960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R
M9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`
M1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T
M>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S`$9R`$9R
M86UE<P!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L
M;"!.86UE`$=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=E
M;F5R871E("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`1V\`1V]E
M9&5L`$=O;V=L92!396%R8V@`1W)E96L@*$E33RTX.#4Y+3<I`$=R;W5P($%D
M;6EN:7-T<F%T:6]N`$=R;W5P<P!'=65S="!097)M:7-S:6]N<P!'=65S=&)O
M;VL`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA
M<W0@8V5L;"!I;B!R;W<N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@
M9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R96$@8V]W
M87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE
M+@!(87IE`$AE8G)E=R`H25-/+3@X-3DM."U)*0!(96EG:'0`2&5L<`!(96QP
M('5S:6YG(&5D:71O<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN
M9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VUE($1I<F5C=&]R>0!(;W)D
M90!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT
M86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO
M=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M
M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S
M('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@
M`$AU;6]R:7-T<P!)7VYS97)T(%)O=R!"969O<F4`26-O;G,@3VYL>0!)8V]N
M<R!F;W(@)7,`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M93H`268@
M>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R
M97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F
M9B!03D<@=')A;G-P87)E;F-Y+@!);6%G92!0<F5V:65W.@!);6%G92!54DP`
M26UA9V4@55),.@!);6%G92!F<F]M(&=A;&QE<GD`26UA9V4@9G)O;2!G86QL
M97)Y.@!);6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E
M<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C
M="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R
M(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H
M97(@:&5L<"X`26YC<F5A<V4@26YD96YT`$EN9&EV:61U86P@57-E<G,`26YF
M;W)M871I;VX`26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92X`26YS
M97)T($-?;VQU;6X@069T97(`26YS97)T($EM86=E`$EN<V5R="!486)L90!)
M;G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R="!A
M(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE
M=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@
M<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&)E
M9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R87!H(&%F=&5R
M('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T
M:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS
M97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E
M('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R="!C
M96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU;6X@
M8F5F;W)E`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P
M:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!)
M;G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E
M<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK
M`$EN=F%L:60@87!P;&EC871I;VXN`$EN=F%L:60@<&%R96YT('!E<FUI<W-I
M;VXN`$EN=F5N=&]R>0!)<V]L871E9"!4+5-T;W)M<P!)=&%L:6,`2F%N=6%R
M>0!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IU;'D`2G5N90!*=7-T:69Y`$IU
M<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF
M>2!2:6=H=`!+97)N96P@3F5W8FEE<P!+:61S`$MO<F5A;B`H155#+4M2*0!,
M85]Y;W5T`$QA;F=U86=E`$QA<W0@2&%L9@!,87-T(%!A<W-W;W)D($-H86YG
M90!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87<`3&%Y;W5T`$QE879E
M(&5M<'1Y(&9O<B!N;R!B;W)D97(`3&5F=`!,:6=H="!$<FEZ>FQE`$QI9VAT
M(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN($QA=&4`3&EG:'0@
M4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG:'0@4VYO
M=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6YK('!O:6YT<R!T;SH`
M3&EN=7@@0V]O:VEE`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`
M3&ES="!486)L97,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A
M='5R90!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO
M9R!I;@!,;V<@;W5T`$QO9VEN`$QO9VEN(%1A<VMS`$QO=F4`3&]W`$QO=V5R
M(&=R965K(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA
M;B!N=6UB97)S`$U-`$U/5$0`36%G:6,`36%I;`!-86EL($%D;6EN`$UA:V4@
M;&EN7VLN+BX`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA
M=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D
M('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%R8V@`36%R9VEN`$UA=&-H:6YG
M(&9I96QD<P!-87@@=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S
M="`V(&AO=7)S.B``36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<P!-
M87D`365D:6-I;F4`365M8F5R<P!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE
M=&%R(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X`365T87(@
M8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D
M(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T<FEC`$UI9&1L90!-:6X@=&5M
M<"!L87-T(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36ES
M8V5L;&%N96]U<P!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O
M(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L
M:6-A=&EO;BX`36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D:69Y(%523`!-
M;V]N(%!H87-E<P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D>0!-;W-T;'D@
M4W5N;GD`37D@06-C;W5N=`!->2!!8V-O=6YT($EN9F]R;6%T:6]N`$UY(%!O
M<G1A;`!->2!0;W)T86P@3&%Y;W5T`$Y/+"!)($1O($Y/5"!!9W)E90!.971W
M;W)K`$YE=F5R`$YE=R!#871E9V]R>0!.97<@36]O;@!.97<@57-E<FYA;64@
M*&]P=&EO;F%L*0!.97<@<&%S<W=O<F0`3F5W('!A<W-W;W)D<R!D;VXG="!M
M871C:"X`3F5W('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X
M=`!.:6=H=`!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H
M;W<@9&EF9F5R96YC97,@9F]R+@!.;R!C:&%N9V4N`$YO(&EC;VYS(&9O=6YD
M+@!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.
M;R!P96YD:6YG('-I9VYU<',N`$YO(')U;&5S`$YO('-I9&5S`$YO('1E;7!O
M<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@=F5R<VEO
M;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E
M(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF
M:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;F4`3F]N
M92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W)T:&5R
M;B!(96UI<W!H97)E`$YO="!S970`3F]T97,`3F]T:&EN9R!T;R!B<F]W<V4L
M(&=O(&)A8VLN`$YO=F5M8F5R`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O
M9B!R;W=S`$]+`$]B:F5C="!#<F5A=&]R`$]C=&]B97(`3V9F96YS92!F:6QT
M97(`3V9F:6-E`$]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E
M<F5N="X`3VQD('!A<W-W;W)D`$]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C
M="X`3VYL>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!T:&4@;W=N97(@;W(@
M<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@
M;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W
M:6YD;W<`3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I
M;F<@4WES=&5M`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T
M`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I
M9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO
M;@!/=VYE<B!097)M:7-S:6]N<P!02%`@0V]D90!02%`@4VAE;&P`4$T@3&EG
M:'0@4F%I;@!032!3:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S`%!-
M(%-U;@!032!4+5-T;W)M<P!03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9P!0
M7TA0(%-H96QL`%!A9&1I;F<`4&%R=&QY($-L;W5D>0!087-S=V]R9`!087-S
M=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2X`4&%S<W=O<F0Z`%!A<W-W;W)D
M.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI
M<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N=`!0
M97)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N
M86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N("(E<R(@;F]T
M(&1E;&5T960N`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L
M($EN9F]R;6%T:6]N`%!E=',`4&AO=&]S`%!I>&5L<P!0;&%T:71U9&5S`%!L
M96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T
M('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF
M:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="X`4&QE
M87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE87-E
M('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O
M=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A<V4@<F5A9"!T
M:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E
M<FUS('1O('5S92!T:&4@<WES=&5M+@!0;VQI=&EC<P!0;VQL<P!0;W-I=&EO
M;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4`
M4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E8VEP:71A
M=&EO;CQB<B`O/F-H86YC90!0<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V
M96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@
M82!N97<@=VEN9&]W`%!R:6YT(&1O8W5M96YT`%!R;V)L96T@1&5S8W)I<'1I
M;VX`4')O:F5C=',`475E<GD`475O=&$`4F%I;@!286EN($5A<FQY`%)A:6X@
M3&%T90!286EN(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!2
M86YD;VT@1F]R='5N90!296%D`%)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E
M<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E86QL>2!R96UO=F4@=7-E<B!D
M871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD
M;VYE+@!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H($1Y;F%M:6,@
M365N=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5M87)K<P!2
M96UO=&4@4V5R=F5R<P!296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N
M8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!";&]C:P!296UO=F4@9F]R;6%T
M=&EN9P!296UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R
M=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@
M=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V
M92!U<V5R.B`E<P!297-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A
M<W-W;W)D`%)E<W5L=',`4F5T=7)N('1O($]P=&EO;G,`4F5T>7!E(&YE=R!P
M87-S=V]R9`!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R
M($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2;U]W(%!R;W!E<G1I97,N+BX`4F]W
M(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L97,@
M=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE
M<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL
M(&%P<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4TU3($UE<W-A9VEN9P!3
M44P@4VAE;&P`4U-(`%-?44P@4VAE;&P`4V$`4V%M92!F<F%M92`H7W-E;&8I
M`%-A=F4`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G96YE<F%T960@8V]N
M9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T
M96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3
M8V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!396%R8V@`4V5A<F-H($5N9VEN
M97,`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!3
M96QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T('1H
M92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9
M;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT
M(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@
M9&%T92!F;W)M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@
M8VAA;F=E.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE
M('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L
M96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@
M;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N<V]R.B``4V5P=&5M
M8F5R`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A
M<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T('5P(')E;6]T92!S
M97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T
M86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD
M(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@
M8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P
M;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I
M;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R
M86UE=&5R.B``4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S
M(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W(&1I
M9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W
M;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T
M:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!T86)L92!O<&5R871I;VYS(&UE
M;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W('1H
M92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE
M(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T
M:65S(&1I86QO9P!3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9P!3
M:&]W97)S`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@
M=&AE(%9I8VEN:71Y`%-K:7`@36%I;G1E;F%N8V4`4VYO=P!3;F]W(%-H;W=E
M<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO=V5R
M<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z
M(`!3;VYG<R`F(%!O96US`%-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0!3
M;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@861J86-E;G0@8V5L
M;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3
M<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!A;0!3<&5C:6%L($-H87)A
M8W1E<B!);G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`
M4W!O<G1S`%-T86YD87)D`%-T87(@5')E:P!3=&%T=7,`4W1R:6ME=&AR;W5G
M:`!3='EL92!;0U-370!3=0!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L
M;'D@9&5L971E9"`B)7,B+@!3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG
M=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3=6-C97-S9G5L;'D@
M<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL>2!S879E
M9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`4W5C8V5S<V9U
M;&QY('=R;W1E("5S`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3
M=6YR:7-E`%-U;G)I<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T
M.B``4W5P97)S8W)I<'0`4W5P<&]R=`!4+5-T;W)M`%0M4W1O<FT@86YD(%=I
M;F1Y`%0M4W1O<FUS`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@<')O<&5R=&EE
M<P!487)G970Z`%1A<VMS`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E;7!E<F%T
M=7)E`%1E;7!E<F%T=7)E.B``5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S
M3&\E<RD@)F1E9SLE<P!496UP;&%T92!!9&UI;FES=')A=&EO;@!497AT($]N
M;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@*%1)4RTV,C`I`%1H92!-
M86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`
M5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!B
M;W1T;VT@<VED92!O;FQY`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N
M('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U
M92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R
M:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA
M>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O
M=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I
M="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L(%!R
M;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<;EQN66]U(&AA
M=F4@8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@3TL@:68@>6]U('-T:6QL
M('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N
M=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!L969T+6AA;F0@<VED
M92!O;FQY`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY`%1H92!R:6=H
M="UH86YD('-I9&4@;VYL>0!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L
M971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG
M;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H92!T;W`@
M86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!W
M96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5R92!W87,@
M86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y
M;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AI<R!I<R`E<RX`5&AI
M<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O
M=P!4:'5N9&5R`%1I8VME=',`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4
M:71L90!4:71L92`H=&]O;'1I<"DZ`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C
M90!4;VUO<G)O=P!4;W``5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA=&EO;G,`
M5'4`5'5R:VES:"`H25-/+3@X-3DM.2D`52Y6+B!I;F1E>#H@`%523`!54DPZ
M`%5N86)L92!T;R!D96QE=&4@(B5S(CH@)7,N`%5N9&5R;&EN90!5;F1O($-H
M86YG97,`56YD;V5S('EO=7(@;&%S="!A8W1I;VX`56YF:6QE9`!5;FEC;V1E
M("A55$8M."D`56YI=',`56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YP
M<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T
M92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC
M:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W
M:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S
M<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5<&1A=&4`57!D871E("5S
M`%5P9&%T92!U<V5R`%5P9&%T960@(B5S(BX`57!G<F%D92!S8W)I<'0@9&5L
M971E9"X`57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F
M:6QE<R!T;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R
M(')O;6%N(&YU;6)E<G,`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R
M96YT(&9O<B!)35-0('-E<G9E<BX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R
M(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A
M8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R(&%C8V]U;G0@;F]T(&9O=6YD`%5S
M97)N86UE`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S>7-T
M96TZ`%9A8V%T:6]N`%9A<FEA8FQE`%9E<G-I;VX@0V]N=')O;`!697)T:6-A
M;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E<G1I8V%L.@!697)Y($AI9V@`
M5FEE=&YA;65S92`H5DE30TE)*0!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E
M`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%=!4DY)3D<A(2$@4D5-3U9%(%-#
M4DE05"!-04Y504Q,62!&4D]-("5S+@!787)N:6YG`%=E`%=E871H97(@1F]R
M96-A<W0`5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E8@!796(@4VET90!7
M96QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/
M+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I`%=H870@87!P;&EC871I
M;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE
M(&1E;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A
M8W1E<C\`5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O
M<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@`5VED=&@@;V8@=&AE("5S
M(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI
M;BDZ`%=I9'1H(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7:6MI
M`%=I;F0`5VEN9"!%87)L>0!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I
M;F0Z(`!7:7-D;VT`5VES:&QI<W0`5V]R:P!8+5)E9@!960!997,L($D@06=R
M964`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N
M('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%L;&]W
M960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!M=7-T(&1E
M<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R
M;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H
M:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T
M;R!B92!D96QE=&5D+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@
M8VQE87(@;W5T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M
M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO
M=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`66]U<B!%
M;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA
M=&EO;@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O
M97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@
M:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R
M(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N`%EO=7(@
M8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET>2!H87,@
M8F5E;B!C:&%N9V5D+@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L
M;"!N86UE.@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@
M<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E
M;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U
M<B!N97<@<&%S<W=O<F0N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%II<'!Y`%M(
M:61E(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E
M9"!497AT("T`7T%D;6EN:7-T<F%T:6]N`%]#3$D`7T1A=&%4<F5E`%]$96QE
M=&4@4F]W`%]'<F]U<',`7TEM86=E(%!R;W!E<G1I97,N+BX`7TUO9&EF>2!,
M:6YK+BXN`%]097)M:7-S:6]N<P!?4F5M;W9E($QI;FLN+BX`7U-E='5P`%]4
M86)L92!0<F]P97)T:65S+BXN`%]5<V5R<P!C86QM`&9A;&QI;F<`9G)O;2!T
M:&4@)7,@*"5S*2!A="`E<R`E<P!G=7-T:6YG`&EN;&EN90!L:6YE<UT`;F%M
M90!P97)C96YT`'!I>&5L<P!R:7-I;F<`<VAO=R!D:69F97)E;F-E<P!S=&5A
M9'D`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D
M`'=E871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@,C`P-2TP."TP,PI2
M97!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M
M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/+5)E=FES
M:6]N+41A=&4Z(#(P,#4M,#@M,#0@,#DZ,3`K,#(P,`I,87-T+51R86YS;&%T
M;W(Z($IA;65S(#QJ86UE<T!A8W1I;VYM97-S86=E+F-O;3X*3&%N9W5A9V4M
M5&5A;3H@:60@/&ED0&QI+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N
M="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/553+4%30TE)"D-O;G1E;G0M
M5')A;G-F97(M16YC;V1I;F<Z(#=B:70*`"!P861A(``B)7,B('-U9&%H(&1I
M=&%M8F%H:V%N(&ME(&1A;&%M('-I<W1E;2!G<G5P+@`B)7,B('-U9&%H(&1I
M=&%M8F%H:V%N(&ME(&1A;&%M(&EZ:6X@<VES=&5M+@`B)7,B(&)E;'5M(&1I
M8G5A=#H@)7,N`"4N,F9-0B!S=61A:"!D:6=U;F%K86X@9&%R:2`E+C)F34(@
M>6%N9R!S=61A:"!D:6EJ:6YK86X@*"4N,F8E)2D`)60@)7,@9&%N("5S`"5D
M(&AA<FD@<V%M<&%I('-A;F1I(&%N9&$@:&%B:7,@;6%S82!B97)L86MU;GEA
M+@`E9"UH87)I(')A;6%L86X@8W5A8V$`)7,@+2!096UB97)I=&%H=6%N`$MO
M;F9I<FUA<VD@+2!/<&5R87-I(%!E;65L:6AA<F%A;B`E<P`E<R!3971U<``E
M<R!3>6%R870M<WEA<F%T(%!E<FIA;FII86X`)7,@<&%D82`E<R`E<P`E<R!S
M:6%P('5N='5K(&UE;&%K<V%N86MA;B!O<&5R87-I('!E;65L:6AA<F%A;B!Y
M86YG('-U9&%H(&1I=&%N9&%I(&1I(&)A=V%H(&EN:2X@0F5R:6QA:"!T86YD
M82!P861A(&MO=&%K('1E<G-E8G5T('5N='5K(&]P97)A<VD@;6%N87!U;B!Y
M86YG(&%N9&$@:6YG:6YK86X@=6YT=6L@9&EL86MS86YA:V%N('!A9&$@=V%K
M='4@:6YI+@`E<R!M96YI=``E<R!U;G1U:R`E<R`E<P`L(&%N9VEN(&ME;F-A
M;F<@)7,@)7,`+"!V87)I86)L92!D87)I("5S(&ME("5S`$9O<FUA="`Q,B!*
M86T`1F]R;6%T(#(T($IA;0`R-"!J86T`1&%T86)A<V4@8F%C:V5N9"!D:7!E
M<FQU:V%N('5N='5K(&%R96$@:6YI+@!!32!-96YD=6YG`$%-($=E<FEM:7,`
M04T@2'5J86X`04T@1V5R:6UI<P!!32!'97)I;6ES(%-A;&IU`$%-+U!-`%1E
M;G1A;F<@961I=&]R(&EN:0!496YT86YG+BXN(`!*87)A:R!A;G1A<F$@8F%G
M:6%N(&)A=V%H(&)A<FES(&1E;F=A;B!B86=I86X@8F%W86@@9V%M8F%R`$IA
M<F%K(&%N=&%R82!B86=I86X@=&5N9V%H(&)A<FES(&1E;F=A;B!B86=I86X@
M=&5N9V%H(&=A;6)A<@!);F9O<FUA<VD@06-C;W5N=`!386YD:2!!8V-O=6YT
M`$%K=6YT86YS:0!486UB86@`5&%M8F%H($=R=7`@06YA:P!486UB86@@1&ES
M:6YI.@!486UB86@@1W)U<"!"87)U`%1A;6)A:"!P96YG9W5N82!B87)U.@!4
M86UB86@@86YG9V]T82!B87)U`%1A;6)A:"!P87-A;F=A;@!486UB86@@365N
M=2`E<R!S96)A9V%I(%!A;F5L(&YA=FEG87-I($UO>FEL;&$`5&%M8F%H('!E
M;F=G=6YA`%!E;F%M8F%H86X@<&5N9V=U;F$@=&ED86L@9&EA:W1I9FMA;BX`
M0G5K=2!!;&%M870@`$%D;6EN:7-T<F%S:0!):VQA;@!2871A`%!E<F%T86%N
M`%-E;75A`%-E;75A(%!E;F=G=6YA($%S;&D`4V5M=6$@1W)U<`!396UU82!E
M;7!A="!S:7-I`$EZ:6YK86X@<&5N9V%T=7)A;B!D87)I('1I<&4@9&%F=&%R
M(&YO;6]R(&)E<G5R=70_`%!E;F=G86YT:2!,;V=I;B!)35-0`%!E;F=G86YT
M:2!386YD:2!)35-0`%!E;F=G86YT:2!.86UA(%!E;F=G=6YA($E-4U``4&5N
M9V=A;G1I(&%L86UA="!E;6%I;`!096YG9V%N=&D@=&5M<&QA=&4`4&5N9V=A
M;G1I('1E:W,Z`$IA=V%B86X`07!L:6MA<VD`1&%F=&%R($%P;&EK87-I`$%P
M;&EK87-I('-U9&%H('-I87`N`$1I9W5N86MA;B!U;G1U:R!"86=I86X@06YA
M:P!$:7-E='5J=6D`07!R:6P`07)A8B`H5VEN9&]W<RTQ,C4V*0!!<&%K86@@
M86YD82!Y86MI;B!A;F1A(&EN9VEN(&UE;6EN9&%H:V%N('!E<FUO:&]N86X@
M<&5N9&%F=&%R86X@=6YT=6L@)7,_`$%R;65N:6$@*$%235-#24DM."D`4V5N
M:0!+;V1E($%S8VEI`$UE;6EN=&$@:V]N9FER;6%S:2!S96)E;'5M(&UE;&%K
M<V%N86MA;B!O<&5R87-I('!E;65L:6AA<F%A;C\`365N8V]B82!U;G1U:R!M
M96YG:&%P=7,@9W)U<"!Y86YG('1I9&%K(&%D82X`365N8V]B82!U;G1U:R!M
M96YG:&%P=7,@:7II;B!Y86YG('1I9&%K(&%D82X`365N8V]B82!U;G1U:R!M
M96YG=6)A:"!I>FEN('EA;F<@=&ED86L@861A+@!-96YC;V)A('5N='5K(&UE
M;F=U8F%H(&)A9VEA;B!Y86YG('1I9&%K(&%D82X`06=U<W1U<P!+;VQO;2!Y
M86YG('1E<G-E9&EA.@!!;&%S86X@0D]&2`!,871A<B!"96QA:V%N9P!787)N
M82!,871A<B!"96QA:V%N9P!"86QT:6,@*$E33RTX.#4Y+3$S*0!*87)A:R!A
M;G1A<F$@8F%G:6%N(&)A=V%H(&=A;6)A<B!D96YG86X@9V%R:7,@9&%S87(@
M8F%R:7,`4&5N9V%T=7)A;B!!<F5A`%1I<&4@07)E80!(=7)U9B!496)A;`!0
M971U;FIU:R!H86QA;6%N('=E8@!";W)D97(`2V5T96)A;&%N($)O<F1E<@!"
M;W)D97(`2V5D=6%N>6$`0F%W86@`1&%F=&%R($)U;&QE=`!#35,`4')O<&5R
M=&D@4U]E;`!+86QE;F1E<@!496YA;F<`5&ED86L@9&%P870@;65N9V%T=7(@
M=6QA;F<@<V%N9&D@<V5C87)A(&]T;VUA=&ES+"!S:6QA:V%N(&AU8G5N9VD@
M861M:6YI<W1R871O<B!A;F1A+@!"871A;`!"871A;&MA;B!,87!O<F%N($UA
M<V%L86@`2G5D=6P@5&%B96P`2V%T96=O<FD@9&%N($QA8F5L`%!R;W!E<G1I
M(%-E;`!*87)A:R!S<&%S:2!D87)I(&)O<F1E<B!D96YG86X@=&5K<R!D:2!D
M86QA;2!S96PZ`'!R;W!E<G1I('-E;`!*87)A:R!S<&%S:2!A;G1A<B!S96PN
M`$-E;'1I8R`H25-/+3@X-3DM,30I`%1E;F=A:`!%<F]P82!496YG86@@*$E3
M3RTX.#4Y+3(I`%5B86@`56)A:"!386YD:2!!;F1A`%5B86@@;F%M82!D86X@
M86QA;6%T('-E:&EN9V=A(&]R86YG(&1A<&%T(&UE;&EH871N>6$@:V5T:6MA
M(&UE<F5K82!M96UB86-A(&1A;B!M96UB86QA<R!K92!E;6%I;"!A;F1A+@!-
M96YG=6)A:"!S86YD:2!A;F1A('1I9&%K(&1I9'5K=6YG(&1E;F=A;B!K;VYF
M:6=U<F%S:2!Y86YG('-E:V%R86YG+B!3:6QA:V%N(&AU8G5N9VD@861M:6YI
M<W1R871O<B!A;F1A+@!+87)A:W1E<@!097)I:W-A($QI;FLN+BX`0VEN82!3
M961E<FAA;F$@*$=",C,Q,BD`0VEN82!4<F%D:7-I;VYI;"`H0FEG-2D`4&EL
M:6@@8V%R82!U;G1U:R!M96YA;7!I;&MA;B!T86YG9V%L.@!0:6QI:"!D869T
M87(@=&EP92!G87EA("AU;G1U:R!D869T87(@;F]M;W(@8F5R=7)U="D`0F5R
M<VEH:V%N`$)E<G-I:&MA;B!T86<@35-/9F9I8V4`0F5R<VEH:V%N('!E;F=G
M=6YA.B`E<P!"97)S:6AK86X@<&5N9V=U;F$`0F5R<VEH:V%N(&1A=&$@<&5N
M9V=U;F$`0V5R86@@8F5B97)A<&$@<V%A="!L86=I`$ML:6L@=6YT=6L@3&%N
M:G5T`%1U='5P($IE;F1E;&$`365N9'5N9P!-96YD=6YG(&1I('!A9VD@:&%R
M:0!"97)A=V%N`%!E<F)E<V%R(%!A;F5L($YA=FEG87-I(`!097)B97-A<B!B
M;W)D97(`5V%R;F$`4&5M:6QI:"!787)N80!+;VQO;0!#;VUI8W,`0V]M;6%N
M9`!#;VUM86YD(%-H96QL`$MO;7!U=&5R`$MO;F1I<VD`2V]N9&ES:0!097)B
M961A86X@2V]N9FEG=7)A<VD`2V]N9FEG=7)A<VD@<W5D86@@:&%B:7,@;6%S
M82!B97)L86MU;GEA+@!-96YG871U<B`E<P!+;VYF:7)M87-I(%-A;F1I`$MO
M;G1A:P!,86YJ=70`0V]O:VEE`%-A;&EN`%-A;&EN(%!I;&EH86X`5&ED86L@
M9&%P870@=&5R:6MA="!D96YG86X@<V5R=F5R(&QD87``5&ED86L@9&%P870@
M=&5R:'5B=6YG(&ME('-E<G9E<B!L9&%P`%1I9&%K(&1A<&%T(&UE;F=A='5R
M('5L86YG('5N='5K('!E;F=G=6YA('EA;F<@9&EM:6YT82X@0F5B97)A<&$@
M871A=2!S96UU82!D971I;"!T:61A:R!B96YA<BX@0V]B82!L86=I(&%T874@
M<VEL86MA;B!H=6)U;F=I(&%D;6EN:7-T<F%T;W(@86YD82!J:6MA(&%N9&$@
M;65M97)L=6MA;B!B86YT=6%N(&QE8FEH(&QA;FIU="X`5&ED86L@9&%P870@
M:V5M8F%L:2!K92!K;VYF:6=U<F%S:2X`5&ED86L@9&%P870@;65N>6EM<&%N
M(&MO;F9I9W5R87-I("5S+@!4:61A:R!D87!A="!M96YY:6UP86X@9FEL92!K
M;VYF:6=U<F%S:2!B86-K=7`@)7,N`%1I9&%K(&1A<&%T(&UE;GEI;7!A;B!F
M:6QE(&MO;F9I9W5R87-I("5S+B!!;F1A(&1A<&%T(&UE;F=G=6YA:V%N('-A
M;&%H('-A='4@9&%R:2!P:6QI:&%N('5N='5K(&UE;GEI;7!A;B!K;V1E('1E
M<G-E8G5T(&ME;6)A;&D@:V4@)7,@871A=7!U;B!M96YY86QI;B!K;V1E(&1I
M(&)A=V%H(&EN:2!S96-A<F$@;6%N=6%L(&ME("5S+@!4:61A:R!D87!A="!M
M96YE;75K86X@4&%N96P@3F%V:6=A<VD@36]Z:6QL82X@4&%S=&EK86X@<&%N
M96P@;F%V:6=A<VD@<W5D86@@=&5R8G5K82X`2W5R<W5S`$)U870`0G5A="!L
M:6YK`$)U870@8F%R=0!786MT=2!396MA<F%N9P!54DP@4V5K87)A;F<@861A
M;&%H`$-U86-A(%-E:V%R86YG`$MO;F1I<VD@4V5K87)A;F<Z`$=A>6$@4V5K
M87)A;F<`2V]S='5M:7-A<VD@='5G87,@=6YT=6L@9&EJ86QA;FMA;B!S96)E
M;'5M(&QO9V]N(&ME("5S+@!(87!U<P!(87!U<R!P:6QI:&%N`$-Y<FEL;&EC
M("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K
M<F%I;FEA;B`H2T])."U5*0!$1`!$871A5')E92!"<F]W<V5R`%1A;F=G86P@
M1&ET97)I;6$`2&%R:0!(87!U<R!+;VQO;0!$97-E;6)E<@!!;F=K82!$97-I
M;6%L`$UE;F=U<F%N9VD@26YD96X`1&5F875L=`!$969A=6QT(%=A<FYA`$1E
M9F%U;'0@4VAE;&P`1&5F:6YI<VD`2&%P=7,`2&%P=7,@4V5L`$AA<'5S($=R
M=7``2&%P=7,@<V5L`$AA<'5S(&MO;&]M`$AA<'5S('!E;F=G86YT:2!T96UP
M;&%T92!Y86YG('-U9&%H(&%D80!(87!U<R!B87)I<P!(87!U<R!I9&5N=&ET
M87,@>6%N9R!T97)P:6QI:`!(87!U<R!K;VQO;2!Y86YG('-E:V%R86YG`$AA
M<'5S(&)A<FES('EA;F<@<V5K87)A;F<`2F5L87-K86X@36%S86QA:`!$97-K
M<FEP<VD`4&5R:V5M8F%N9V%N`%1I=&EK($5M8G5N`%1I=&EK($5M8G5N('5N
M='5K(&IA;2!T97)A:VAI<CH`5&ET:6L@16UB=6X`07)A:"!K:7)I(&ME(&MA
M;F%N`$%R86@@:V%N86X@:V4@:VER:0!$:7)E:W1O<FD`5&%M<&EL:V%N('=A
M:W1U(#(T(&IA;3\`5&%M<&EL:V%N(%!I;&EH86X`5&%M<&EL:V%N(&1E=&EL
M(')A;6%L86X@8W5A8V$`5&%M<&EL:V%N(')A;6%L86X@8W5A8V$@*%1!1BD`
M2F%N9V%N(&QA;F=S=6YG(&UE;F=A:W-E<R!M86EN=&5N86YC92YP:'``07!A
M:V%H(&)A<FES('EA;F<@<&5R=&%M82!T97)D:7)I(&1A<FD@:V]L;VT@;F%M
M83\@:FEK82!Y82P@8F5R:2!T86YD82!P861A(&MO=&%K(&EN:3H`5&ED86L@
M;65M:6QI:VD@86-C;W5N=#\@4VEL86MA;B!M96YD869T87(N`$1O=VYL;V%D
M(&MO;F9I9W5R87-I('EA;F<@9&EH87-I;&MA;B!S96)A9V%I('-C<FEP="!0
M2%`N`$]B870M;V)A=&%N`%5B86@`56)A:"!";&]K:7(`56)A:"!'<G5P`%5B
M86@@27II;@!58F%H($EZ:6X@=6YT=6L@)7,`56)A:"!P:6QI:&%N('5N='5K
M.@!58F%H(&EZ:6X@=6YT=6L@)7,`4&5N9&ED:6MA;@!%;&5M96XN+BX`16T`
M06QA;6%T($5M86EL`$%K=&EF:V%N('!E;GEI<VEP86X@9V%M8F%R+6=A;6)A
M<B!D87)I($=A;&5R:2!&;W1O(&1I(&1A;&%M('1E:W,_`$%K=&EF:V%N(&ML
M:6L@:V%N86X@;65N=2!K;VYT96MS/P!097)B97-A<B!%9&ET;W(`36%S=6MK
M86X@<&5R=&%N>6%A;B!K96%M86YA;B!D:6UA;F$@86YD82!A:V%N(&1I=&%N
M>6%K86X@87!A8FEL82!A;F1A('!E<FQU('5N='5K(&UE;F=A='5R('5L86YG
M('-A;F1I(&%N9&$L("!C;VYT;V@@)V%P86MA:"!N86UA(&)I;F%T86YG(&ME
M<V%Y86YG86X@86YD83\G.@!-87-U:VMA;B!54DP@9V%M8F%R(&1I<VEN:0!+
M97-A;&%H86X`2V5S86QA:&%N('-A870@;65M<&5R8F%H87)U:2!S86YD:3H@
M)7,`4W5K=0!3971I87`@,34@;65N:70`4V5T:6%P(#(@;65N:70`4V5T:6%P
M(#,P(&1E=&EK`%-E=&EA<"`U(&UE;FET`%-E=&EA<"!S971E;F=A:"!J86T`
M4V5T:6%P(&UE;FET`$-O;G1O:"!N:6QA:2UN:6QA:3H`2F%L86YK86X`4&5R
M8F5S87(@4&%N96P@3F%V:6=A<VD`5V%R;F$@1D<`1E10('5P;&]A9"!U;G1U
M:R!S971U<`!#97)A:`!&87@`1F5B<G5A<FD`4V5P97)T:0!397!E<G1I.@!'
M97)I;6ES(%-E8F%G:6%N`$=E<FEM:7,@4V%L:G4@4V5B86=I86X`1FEL92!-
M86YA9V5R`$9I;'1E<@!&87-E('!E<G1A;6$@9&%R:2!397!A<G5H($)U;&%N
M`$9A<V4@<&5R=&%M82!D87)I(%-E<&%R=6@@0G5L86X`1FQO870`0F5R:V%B
M=70`5V%R;F$@5'5L:7-A;@!-86MA;F%N`%5N='5K(&)R;W=S97(@>6%N9R!T
M:61A:R!D87!A="!M96YD=6MU;F<@9V%M8F%R`%)A;6%L86X@8W5A8V$@*%1!
M1BD`2&%R:2!286UA;&%N($-U86-A("AC871A=&%N(&)A:'=A(')A;6%L86X@
M8W5A8V$@>6%N9R!D:6ME;6)A;&EK86X@86MA;B!M96YG96UB86QI:V%N(&)A
M:6L@<VEA;F<@871A=2!M86QA;2!H87)I+"!S96IU;6QA:"!A;F=K82!D87!A
M="!D:6AA<VEL:V%N('!A9&$@87)E82!I;FDI`$QU<&$@9&5N9V%N('-A;F1I
M(&%N9&$_`$9O<FUU;&ER`%)A;6%L86X`5&EP92!286UA;&%N`%)A;6%L86X`
M4F%M86QA;B`R`$9O<G5M`$1I=&5R=7-K86X`2FUT`$9R86UE`$1A<FD`1&5S
M:W)I<'-I($QE;F=K87``0G5L86X@4'5R;F%M80!.86UA($QE;F=K87``1V%L
M97)I('5N='5K(&UE;F=A;6)I;"!G86UB87(@9&%R:0!'86QE<FD`365N9VAA
M<VEL:V%N("5S($MO;F9I9W5R87-I(`!+;V1E('EA;F<@9&EH87-I;&MA;@!*
M86QA;FMA;@!';V5D96P`4&5N8V%R:6%N($=O;V=L90!9=6YA;FD@*$E33RTX
M.#4Y+3<I`$%D;6EN:7-T<F%S:2!'<G5P`$=R=7``27II;B!T86UU`$)U:W4@
M=&%M=0!(5$U,07)E82!D96YG86X@<F%G=2!M96YO;&%K('5N='5K(&UE;F=H
M87!U<R!S96P@>6%N9R!T97)A:VAI<B!D:2!D86QA;2!B87)I<RX`2%1-3$%R
M96$@9&5N9V%N(')A9W4@;65N;VQA:R!U;G1U:R!M96YG:&%P=7,@:V]L;VT@
M>6%N9R!T97)A:VAI<B!D:2!D86QA;2!T86)E;"X`2%1-3$%R96$@9&5N9V%N
M(')A9W4@;65N;VQA:R!U;G1U:R!M96YG:&%P=7,@8F%R:7,@>6%N9R!T97)A
M:VAI<B!D:2!D86QA;2!T86)E;"X`0F5R:V%B=70`66%H=61I("A)4T\M.#@U
M.2TX+4DI`%1I;F=G:0!"86YT=6%N`$)A;G1U86X@;65N9V=U;F%K86X@961I
M=&]R`$)E;&%H86X@0G5M:0!);FD@861A;&%H('!E<FUU;&%A;B!D87)I(&9I
M;&4Z`%1I;F=G:0!(;U]M90!$:7)E:W1O<FD@2&]M90!(;W)D90!'87)I<R!(
M;W)I<V]N=&%L(&1I(&1A;&%M($A434P`2F%R86L@9V%R:7,@:&]R:7IO;G1A
M;"!D87)I(&)O<F1E<B!D96YG86X@=&5K<R!D:2!D86QA;2!S96P`2&]R:7IO
M;G1A;#H`0F%G86EM86YA(&-A<F$@86YD82!B:7-A('-A;7!A:2!D:7-I;FD_
M("A3:6QA:V%N(&UE;&%P;W(A*0!"97)A<&$@8F%N>6%K(&MO;&]M('EA;F<@
M:6YG:6X@86YD82!G86)U;F=K86X_`$)E<F%P82!B86YY86L@:V]L;VT@>6%N
M9R!A9&$@9&ES86YA/P!"97)A<&$@8F%N>6%K(&)A<FES('EA;F<@:6YG:6X@
M86YD82!G86)U;F=K86X_`$ME;&5M8F%B86X`2V5L96UB86)A;CH`4&5L87=A
M:P!-87-U:VMA;B!"87)I<R!396)E;'5M;GEA`$AA;GEA(&EK;VX`26MO;B!U
M;G1U:R`E<P!):V]N(&1E;F=A;B!T96MS`$YA;6$@261E;G1I=&%S.@!*:6MA
M(&%N9&$@=&ED86L@;65L:6AA="!I:V]N(&UA;F%P=6X@9&5N9V%N(&UE;F=G
M=6YA:V%N($EN=&5R;F5T($5X<&QO<F5R+"!A;F1A(&UU;F=K:6X@<&5R;'4@
M=6YT=6L@;65N86YD86D@:V]T86L@:6YI('5N='5K(&UE;F]N+6%K=&EF:V%N
M(&ME;&5M86AA;B!03D<N`$QI:&%T($=A;6)A<CH`55),($=A;6)A<@!54DP@
M1V%M8F%R.@!'86UB87(@9&%R:2!G86QE<FD`1V%M8F%R(&1A<FD@9V%L97)I
M.@!'86UB87(M9V%M8F%R`$EM<&]R+"!,86YG:V%H("5D`$MO;&]M('EA;F<@
M9&EI;7!O<CH@)7,`2V]L;VT@>6%N9R!D:6EM<&]R.@!-87-U:VMA;B!"87)I
M<R!"97)I:W5T;GEA`$YA;6$@<&5N9V=U;F$@871A=2!A;&%M870@96UA:6P@
M<&5N9V=A;G1I('1I9&%K(&)E;F%R+B!#;V)A(&QA9VD@871A=2!S:6QA:V%N
M(&AU8G5N9VD@861M:6YI<W1R871O<B!A;F1A(&II:V$@86YD82!M96UE<FQU
M:V%N(&)A;G1U86X@;&5B:6@@;&%N:G5T+@!-96YA;6)A:"!);F1E;@!096YG
M9W5N82!0<FEB861I`$EN9F]R;6%S:0!);F9O<FUA<VD@<W5D86@@=&ED86L@
M9&ES961I86MA;BX`36%S=6MK86X@2V]L;VT@0F5R:6MU=&YY80!-87-U:VMA
M;B!'86UB87(`36%S=6MK86X@5&%B96P`36%S=6MK86X@5V5B($QI;FL`36%S
M=6MK86X@2V]L;VT@4V5B96QU;6YY80!-87-U:VMA;B!K;VQO;2!Y86YG(&)A
M<G4@<V5T96QA:"!K;VQO;2!Y86YG('-E:V%R86YG`$UA<W5K:V%N(&MO;&]M
M('EA;F<@8F%R=2!S96)E;'5M(&MO;&]M('EA;F<@<V5K87)A;F<`36%S=6MK
M86X@8F%R:7,@>6%N9R!B87)U('-E=&5L86@@8F%R:7,@>6%N9R!S96MA<F%N
M9P!-87-U:VMA;B!B87)I<R!Y86YG(&)A<G4@<V5B96QU;2!K;VQO;2!Y86YG
M('-E:V%R86YG`$UA<W5K:V%N('!A<F%G<F%F('-E=&5L86@@<&%R86=R868@
M>6%N9R!S96MA<F%N9P!-87-U:VMA;B!P87)A9W)A9B!S96)E;'5M('!A<F%G
M<F%F('EA;F<@<V5K87)A;F<`36%S=6MK86X@=&5M<&QA=&4@<&5N9V=A;G1I
M`$UA<W5K:V%N(&%L86UA="!E;6%I;"!D:6UA;F$@86YD82!D87!A="!M96YE
M<FEM82!S86YD:2!Y86YG(&)A<G4Z`$UA<W5K:V%N('-E;"!B97)I:W5T;GEA
M`$UA<W5K:V%N('-E;"!S96)E;'5M;GEA`$UA<W5K:V%N(&MO;&]M(&)E<FEK
M=71N>6$`36%S=6MK86X@:V]L;VT@<V5B96QU;6YY80!-87-U:VMA;B!P87)A
M9W)A9B!B97)I:W5T;GEA`$UA<W5K:V%N('!A<F%G<F%F('-E8F5L=6UN>6$`
M36%S=6MK86X@8F%R:7,@8F5R:6MU=&YY80!-87-U:VMA;B!B87)I<R!S96)E
M;'5M;GEA`$UA<W5K:V%N(&IA=V%B86X@>6%N9R!D:7!E<FQU:V%N('5N='5K
M('!E<G1A;GEA86%N(&ME86UA;F%N.@!-87-U:VMA;B]58F%H($=A;6)A<@!-
M87-U:VMA;B]58F%H($QI;FL`07!L:6MA<VD@=&ED86L@=F%L:60N`$EZ:6X@
M:6YD=6L@=&ED86L@=F%L:60N`$EN=F5N=&]R:7,`2'5J86X@<&5T:7(@9&ES
M97)T86D@86YG:6X@<FEB=70@9&D@9&%E<F%H('EA;F<@=&5R<&5N8VEL`$AU
M<G5F($UI<FEN9P!*86YU87)I`$IE<&%N9R`H25-/+3(P,C(M2E`I`$IU;&D`
M2G5N:0!2871A`%)A=&$@5&5N9V%H`%)A=&$@2VER:2!D86X@2V%N86X`4F%T
M82!+:7)I`%)A=&$@2V%N86X`2V5R;F5L($YE=V)I97,`06YA:RUA;F%K`$MO
M<F5A("A%54,M2U(I`%1A;7!I;&%N`$)A:&%S80!&87-E('1E<F%K:&ER(&1A
M<FD@4V5P87)U:"!"=6QA;@!097)U8F%H86X@4V%N9&D@5&5R86MH:7(`1F%S
M92!T97)A:VAI<B!D87)I(%-E<&%R=6@@0G5L86X`4&5R=6)A:&%N(%1E<F%K
M:7(Z`$AU:W5M`%1A;7!I;&%N`%1I;F=G86QK86X@:V]S;VYG('1A;G!A(&)O
M<F1E<@!+:7)I`$=E<FEM:7,`1V5R:6UI<P!'97)I;6ES(&1I('!A9VD@:&%R
M:0!'97)I;6ES(&)E8F5R87!A('-A870@;&%G:0!'97)I;6ES`$=E<FEM:7,@
M9&ES97)T86D@<&5T:7(`0F5R<V%L:G4`1V5R:6UI<R!386QJ=0!086YT=6X@
M2F5N86MA`$QI;FL@;65N=6YJ=6L@:V4Z`$QI;G5X($-O;VMI90!$869T87(@
M1&%T86)A<V4`1&%F=&%R(%1O<&EK($)A;G1U86X`1&%F=&%R(%1A8F5L`$1A
M9G1A<B!P96YG9W5N82!D:6YO;BUA:W1I9FMA;BX`1&%F=&%R($)A8V%A;@!7
M86MT=2!L;V-A;#H`5&5M<&%T(%!E<FES=&EW82!D86X@5V%K='4`3&]K87-I
M`$QO9VEN`$QO9R!O=70`3&]G:6X`5'5G87,@3&]G:6X`0VEN=&$`4F5N9&%H
M`%-I;6)O;"!(=7)U9B!K96-I;"!Y=6YA;FD`4VEM8F]L($AU<G5F(&ME8VEL
M(&QA=&EN`%-I;6)O;"!(=7)U9B!K96-I;"!R;VUA=VD`34T`34]41`!3=6QA
M<`!3=7)A=`!3=7)A="!!9&UI;@!"=6%T(&QI;FLN+BX`365N9V%T=7(@9&%F
M=&%R(&MA=&5G;W)I('EA;F<@:&%R=7,@9&EB97)I(&QA8F5L(&ET96TL(&1A
M;B!W87)N82!Y86YG(&)E<FAU8G5N9V%N("!D96YG86X@:V%T96=O<FD@=&5R
M<V5B=70N`$UA<F5T`$UA<F=I;@!-96YC;V-O:VMA;B!K;VQO;0`@4W5H=2!M
M86MS:6UU;2!Y86YG(&)E<FQA;F=S=6YG('-E;&%M82`R-"!J86TZ`%-U:'4@
M;6%K<VEM=6T@>6%N9R!B97)L86YG<W5N9R!S96QA;6$@-B!J86TZ`$IU;6QA
M:"!M86MS:6UU;2!D87)I('!O<G1A;"!Y86YG(&1I8FQO:VER`$UE:0!/8F%T
M+6]B871A;@!!;F=G;W1A`$UE;G4@;6]D93H`1V%B=6YG:V%N('-E;``@0W5A
M8V$@365T87(`07)E82!-971A<B!T:61A:R!D:7-E9&EA:V%N+@!!<F5A($UE
M=&%R('1I9&%K(&1I<V5D:6%K86XN($1E=&EL('1E;&%H(&1I8V%T870@=6YT
M=6L@861M:6YI<W1R871O<BX`365T<FEK`%1E;F=A:`!3=6AU(&UI;FEM=6T@
M>6%N9R!B97)L86YG<W5N9R!S96QA;6$@,C0@:F%M.@!3=6AU(&UI;FEM=6T@
M>6%N9R!B97)L86YG<W5N9R!S96QA;6$@-B!J86TZ`$QA:6XM;&%I;@!+;VYF
M:6=U<F%S:2!T:61A:R!D:71E;75K86XN($%N9&$@:&%R=7,@;65N9VAA<VEK
M86X@:V]N9FEG=7)A<VD@<V5K87)A;F<@:FEK82!A;F1A(&EN9VEN(&UE;F=G
M=6YA:V%N(&%P;&EK87-I(&EN:2X`4V5N`$UO8FEL92!-86EL`%-E9&%N9P!5
M8F%H(%523`!&87-E($)U;&%N`%-E8F%G:6%N(&)E<V%R($-E<F%H`%-E8F%G
M:6%N(&)E<V%R($)E<F%W86X`4V5B86=I86X@8F5S87(@0V5R86@`06-C;W5N
M="UK=0!);F9O<FUA<VD@06-C;W5N="UK=0!0;W)T86QK=0!486UP:6QA;B!0
M;W)T86QK=0!4241!2RP@4V%Y82!4241!2R!3971U:G4`3F5T=V]R:P!4:61A
M:R!P97)N86@`2V%T96=O<FD@0F%R=0!"=6QA;B!"87)U`$YA;6$@4&5N9V=U
M;F$@0F%R=2`H<&EL:6AA;BD`4V%N9&D@0F%R=0!386YD:2!B87)U('1I9&%K
M(&-O8V]K+@!7:6YD;W<@0F%R=2`H7V)L86YK*0!"97)I=&$`1W)U<"!"97)I
M=&$`0F5R:6MU=&YY80!-86QA;0!4:61A:R!A9&$@9&%T82!K;VYF:6=U<F%S
M:2!Y86YG('1E<G-E9&EA('5N='5K(&UE;G5N:G5K:V%N('!E<F)E9&%A;B!U
M;G1U:RX`5&ED86L@861A('!E<G5B86AA;BX`5&ED86L@861A(&EK;VX@>6%N
M9R!D:71E;75K86XN`%1I9&%K(&%D82!L;VMA<VD@>6%N9R!D:6%T=7(N`%1I
M9&%K(&%D82!R86UA;&%N('EA;F<@=&ED86L@<V]P86X`5&ED86L@861A('!E
M;F1A9G1A<F%N('EA;F<@9&ET=6YD82X`5&ED86L@861A(&%T=7)A;@!4:61A
M:R!A9&$@<VES:0!4:61A:R!A9&$@9&ER96MT;W)I('-E;65N=&%R82!Y86YG
M('1E<G-E9&EA('5N='5K(&-A8VAE`%1I9&%K(&%D82!V97)S:2!Y86YG(&1I
M=&5M=6MA;B!D:2!D86QA;2!K;VYF:6=U<F%S:2!Y86YG(&%S;&DN($UE;F=H
M87-I;&MA;B!K;VYF:6=U<F%S:2!K96UB86QI+@!4:61A:R!A9&$@=F5R<VD@
M>6%N9R!D:71E;75K86X@9&D@9&%L86T@:V]N9FEG=7)A<VD@86YD82X@365N
M9VAA<VEL:V%N(&MO;F9I9W5R87-I(&ME;6)A;&DN`%1I9&%K(&%D80!4:61A
M:R!A9&$@*&1I9W5N86MA;B!S96QE;F=K87!N>6$I`%-C86YD:6YA=FEA("A)
M4T\M.#@U.2TQ,"D`0F5L86AA;B!"=6UI(%5T87)A`$)E;'5M(&1I871U<@!#
M871A=&%N`%1I9&%K(&%D82!Y86YG(&1A<&%T(&1I8G)O=W-E+"!S:6QA:V%N
M(&ME;6)A;&DN`$YO=F5M8F5R`$IU;6QA:"!K;VQO;0!*=6UL86@@8F%R:7,`
M3TL`4&5N8VEP=&$@3V)J96L`3VMT;V)E<@!&:6QT97(@4&5L86YG9V%R86X`
M2V%N=&]R`%-A;F1I(&QA;6$@9&%N(&)A<G4@:&%R=7,@8F5R8F5D82X`4V%N
M9&D@;&%M80!386YD:2!L86UA('1I9&%K(&)E;F%R+@!(86YY82!R86UA;&%N
M('EA;F<@=&ED86L@<V]P86X`2&%N>6$@<&5M:6QI:R!A=&%U('-I<W1E;2!A
M9&UI;FES=')A=&]R('-A:F$@>6%N9R!D87!A="!M96YG=6)A:"!K97!E;6EL
M:6MA;B!A=&%U('!E;6EL:6L@:7II;B!U;G1U:R!B86=I86X`0G5K82!D:2!J
M96YD96QA('EA;F<@8F%R=0!"=6MA(&QI;FL@:6YI(&1I(&IE;F1E;&$@>6%N
M9R!B87)U`%-I<W1E;2!/<&5R87-I`%!I;&EH86X`4&EL:6AA;B!U;G1U:R`E
M<P!$869T87(@3F]M;W(@0F5R=7)U=`!-96YG871U<@!!<&QI:V%S:2!T96UP
M;&%T92!A<VQI`%1E;7!L871E(&%S;&D@9&D@9&%L86T@)7,Z`$QA:6XM;&%I
M;@!);F9O<FUA<VD@3&%I;@!)>FEN(%!E;6EL:6L`2V]D92!02%``4$A0(%-H
M96QL`%!-($=E<FEM:7,`4$T@1V5R:6UI<P!032!"97)S86QJ=0!032!'97)I
M;6ES(%-A;&IU`%!-($-E<F%H`%!-($AU:F%N('!E=&ER(&1I<V5R=&%I(&1E
M;F=A;B!A;F=I;B!R:6)U=`!%:W-T96YS:2!03U-)6"!T:61A:R!D:71E;75K
M86X`4$A0(%-H96QL`$IA<F%K('-P87-I(&1A<FD@8F]R9&5R`%-E8F%G:6%N
M($)E<F%W86X`4V%N9&D`4V%N9&D@8F5R:&%S:6P@9&EU8F%H+@!386YD:3H`
M4V%N9&DZ`%-A;F1I(&AA<G5S(&-O8V]K+@!386QI;@!,96MA=&MA;B!D87)I
M(&-L:7!B;V%R9`!0871H`%!E;F1A9G1A<F%N('EA;F<@9&ET=6YD83H`3W)A
M;F<`4&5R<V5N`$UE;&%K<V%N86MA;B!/<&5R87-I(%!E;65L:6AA<F%A;@!-
M96QA:W-A;F%K86X@;W!E<F%S:2!P96UE;&EH87)A86X@<&%D82!W86MT=2!L
M;V=I;C\`27II;B!U;G1U:R`B)7,B('1I9&%K(&1A<&%T(&1I:&%P=7,N`$EZ
M:6X@061M:6YI<W1R87-I`$EN9F]R;6%S:2!0<FEB861I`$)I;F%T86YG($ME
M<V%Y86YG86X`1F]T;P!0:7AE;`!+871A+6MA=&$@:VQI<V4`4VEL86MA;B!K
M;&EK(&ME(&1A;&%M(&)E8F5R87!A('-E;`!3:6QA:V%N(&MO;F9I<FUA<VD@
M8F%H=V$@86YD82!I;F=I;B!M96UI;F1A:&MA;B!E;&5M96X@:6YI.@!3:6QA
M:V%N(&MO;F9I<FUA<VD@8F%H=V$@86YD82!I;F=I;B!M96YG:&%P=7,@;&EN
M:R!U;G1U:R!E;&5M96X@:6YI+@!3:6QA:V%N(&UA<W5K:V%N(&YA;6$@=6YT
M=6L@:V%T96=O<FD@>6%N9R!B87)U.@!3:6QA:V%N(&UA<W5K:V%N(')I;F=K
M87-A;B!U;G1U:R!M87-A;&%H+@!3:6QA:V%N(&UA<W5K:V%N(&YA;6$@<&5N
M9V=U;F$@9&%N('-A;F1I(&%N9&$`4VEL86MA;B!M96UB86-A('1E:W,@8F5R
M:6MU="!I;FDN($%N9&$@2$%255,@<V5T=6IU(&1E;F=A;B!S>6%R870M<WEA
M<F%T('5N='5K(&UE;F=G=6YA:V%N('-I<W1E;2X`4&]L:71I:P!0;VQL:6YG
M`%!O<VES:2!U;G1U:R!G86UB87(@:6YI`%!O<VES:2!U;G1U:R!T86)E;"!I
M;FD`2'5J86X@<V%L:G4@=6YT=6L@)7,@:F%M('1E<F%K:&ER.@!+96UU;F=K
M:6YA;B`\8G(O/DAU:F%N('-A;&IU`%1E:V%N86X`5&5K86YA;B!P861A('!E
M<FUU:V%A;B!L875T.@!496MA;F%N.@!,:6AA=`!,:6AA="!G86UB87(@9&D@
M9&%L86T@:F5N9&5L82!Y86YG(&)A<G4`0V5T86L@9&]K=6UE;@!$97-K<FEP
M<VD@36%S86QA:`!0<F]J96L`475E<GD`2W5O=&$`2'5J86X`2'5J86X@9&D@
M<&%G:2!H87)I`$AU:F%N(&)E8F5R87!A('-A870@;&%G:0!'97)I;6ES`$AU
M:F%N(&1A;B!"97)S86QJ=0!(=6IA;B!B97)C86UP=7(@9&5N9V%N('-A;&IU
M`%)A;6%L86X@06-A:P!"86-A`%EA:VEN('5N='5K(&UE;F=H87!U<R`E<S\@
M3W!E<F%S:2!I;FD@=&ED86L@9&%P870@9&EB871A;&MA;BX`66%K:6X@=6YT
M=6L@;65M:6YD86AK86X@9&%T82!P96YG9W5N82!U;G1U:R!P96YG9W5N82`E
M<S\@3W!E<F%S:2!I;FD@=&ED86L@9&%P870@9&EB871A;&MA;BX`56QA;F=I
M(&%K<VD@=&5R86MH:7(@86YD80!2969R97-H($5L96UE;B!-96YU($1I;F%M
M:7,Z`%)E9G)E<V@@3&EH870@4&]R=&%L.@!$:71A;F1A:0!296UO=&4@4V5R
M=F5R`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I
M`%!I;F1A:&MA;@!0:6YD86AK86X@0FQO:VER`%!I;F1A:&MA;B!#87)A($9O
M<FUA=`!0:6YD86AK86X@<&%S86YG86X`4&EN9&%H:V%N('-C<FEP="!Y86YG
M('-U9&%H(&1I<VEM<&%N(&1A<FD@9&ER96MT;W)I('-E<G9E<B!S96UE;G1A
M<F$N`%!I;F1A:&MA;@!0:6YD86AK86X@;F]D92!I;FD@9&%R:2!D;VMU;65N
M`%!I;F1A:&MA;B!P96YG9W5N80!0:6YD86AK86X@<&5N9V=U;F$Z("5S`$%T
M=7(@:V5M8F%L:2``071U<B!K96UB86QI(%-A;F1I`$%T=7(@:V5M8F%L:2!3
M86YD:2!!;F1A`$AA<VEL`$ME;6)A;&D@:V4@4&EL:6AA;@!+971I:R!U;&%N
M9R!S86YD:2!B87)U`$ME;6)A;&D@:V4@2V]N9FEG=7)A<VD`4&EL:6AA;B!%
M9&ET;W(@4FEC:"!497AT`%1E:V$M=&5K:0!+86YA;@!0<F]P97)T:2!"87)I
M<RXN+@!0<F]P97)T:2!"87)I<P!0<F]P97)T:2!B87)I<P!"87)I<SH`071U
M<F%N`$%T=7)A;B!A:V%N(&1I=&%M<&EL:V%N(&1I86YT87)A('-E;75A(&)A
M<FES(&1A;B!K;VQO;0!!='5R86X@86MA;B!D:71A;7!I;&MA;B!H86YY82!D
M:6%N=&%R82!K;VQO;0!!='5R86X@86MA;B!D:71A;7!I;&MA;B!H86YY82!D
M:6%N=&%R82!B87)I<P!*86QA;FMA;@!097-A;B!335,`4U%,(%-H96QL`%-3
M2`!37U%,(%-H96QL`%-B=`!&<F%M92!Y86YG('-A;6$@*%]S96QF*0!3:6UP
M86X`4VEM<&%N("5S`%-I;7!A;B!0:6QI:&%N`%-I;7!A;B!K;VYF:6=U<F%S
M:2!Y86YG(&1I:&%S:6QK86X@<V5B86=A:2!S8W)I<'0@4$A0(&ME(&1A;&%M
M(&1I<F5K=&]R:2!S97)V97(@<V5M96YT87)A(&%N9&$N`$MO;F9I9W5R87-I
M("5S('-U9&%H(&1I<VEM<&%N+@!396)A9VEA;B!(=6IA;B!P971I<B!D:7-E
M<G1A:2!A;F=I;B!R:6)U=`!);&UU(%!E;F=E=&%H=6%N`%!E;F-A<FEA;@!-
M97-I;B!096YC87)I86X`4&EL:6@@9W)U<"!U;G1U:R!D:71A;6)A:`!0:6QI
M:"!P96UI;&EK(&)A<G4`4&EL:6@@<V5R=F5R`%!I;&EH('!E;F=G=6YA('5N
M='5K(&1I=&%M8F%H`%!I;&EH(&MA<F%K=&5R('EA;F<@86YD82!P97)L=6MA
M;B!D87)I(&MO=&%K+6MO=&%K(&1I8F%W86@@:6YI+B!!;F1A(&1A<&%T(&UE
M;GEA;&EN(&1A;B!M96QE:V%T:V%N;GEA(&ME(&1A;&%M(&%R96$@=&5K<RX`
M4&EL:6@@8F%T87,@=&%N9V=A;#H`4&EL:6@@9F]R;6%T('1A;F=G86PZ`%!I
M;&EH(&ED96YT:71A<R!Y86YG(&EN9VEN(&1I=6)A:"!O;&5H(&%N9&$Z`%!I
M;&EH(&)A=&%S('=A:W1U.@!0:6QI:"!F;W)M870@=V%K='4Z`%!I;&EH(&1U
M82!K;VQO;2!Y86YG(&-O8V]K+@!0:6QI:"!W87)N82!S8VAE;64@86YD82X`
M4&EL:6@@8F%H87-A('EA;F<@86YD82!I;F=I;FMA;CH`2VER:6T@3&%P;W)A
M;B!-87-A;&%H`%-E;G-O<CH`4V5P=&5M8F5R`$%T=7(@<&EL:6AA;B!U;G1U
M:R!M96YG:7II;FMA;B!A;F1A(&1A<&%T(&UE;F=A='5R('5L86YG(&ME;6)A
M;&D@<V%N9&D@86YD82!A<&%B:6QA(&%N9&$@;'5P82X`071U<B!R96UO=&4@
M<V5R=F5R('EA;F<@:6YG:6X@86YD82!A:W-E<R!D87)I('!O<G1A;"!A;F1A
M+@!!='5R(&)A:&%S82P@>F]N82!W86MT=2!D86X@<&EL:6AA;B!T86YG9V%L
M+"!Y86YG(&%N9&$@:6YG:6YK86XN`$%T=7(@87!L:6MA<VD@87=A;"!A;F1A
M+"!W87)N82!S8VAE;64L(&AA;&%M86X@<F5F<F5S:"!D86X@<&EL:6AA;B!T
M86UP:6QA;B!L86EN;GEA+@!3971U<`!38W)I<'0@<V5T=7`@=7!G<F%D92!T
M97)S961I80!"96)E<F%P82!L;VMA<VD@>6%N9R!M=6YG:VEN(&1E;F=A;B!P
M87)A;65T97(Z`$)E;&%N:F$`4FEN9VMA<V%N(%!E;F1E:P!097)L=6MA:"!K
M=6YC:2!A:W-E<R!D:61E9FEN:7-I:V%N('5N='5K(&ME8F%N>6%K86X@;&EN
M:S\`5&%M<&EL:V%N`%1A;7!I;&MA;B!P97)B961A86X@9&EA;G1A<F$@:V]N
M9FEG=7)A<VD@>6%N9R!B87)U(&1I<VEM<&%N(&1A;B!Y86YG(&)A<G4@9&EH
M87-I;&MA;BX`5&%M<&EL:V%N('=A:W1U(&QO9VEN('1E<F%K:&ER(&ME=&EK
M82!A;F1A(&QO9VEN/P!486UP:6QK86X@<&%N96P@;65N=2!T86)E;"!O<&5R
M87-I/P!486UP:6QK86X@365N=2`E<R!D:2!S96)E;&%H(&MI<FD_`%1A;7!I
M;&MA;B!D:6%L;V<@4')O<&5R=&D@4V5L(%1A8F5L`%1A;7!I;&MA;B!D:6%L
M;V<@4')O<&5R=&D@5&%B96P`5&%M<&EL:V%N(&1I86QO9R!0<F]P97)T:2!"
M87)I<R!486)E;`!486UP:6QK86X@9&EA;&]G('!R;W!E<G1I(&=A;6)A<@!'
M97)I;6ES`$=E<FEM:7,@9&D@<&%G:2!H87)I`$=E<FEM:7,@8F5B97)A<&$@
M<V%A="!L86=I`$=E<FEM:7,@9&D@<V5K:71A<B!D865R86@`3&5W871I(%!E
M;65L:6AA<F%A;@!386QJ=0!'97)I;6ES(%-A;&IU`$=E<FEM:7,@4V%L:G4`
M1V5R:6UI<R!386QJ=2!D:2!P86=I(&AA<FD`1V5R:6UI<R!386QJ=2!B96)E
M<F%P82!S86%T(&QA9VD`2V5D86QA;6%N(%-A;&IU.@!097)B86YD:6YG86X@
M<V%L:G4@9&D@*&1A;&%M*2!A:7(Z`$QA9W4@)B!386IA:P!%<F]P82!396QA
M=&%N("A)4T\M.#@U.2TS*0!"96QA:&%N($)U;6D@4V5L871A;@!*87)A:R!A
M;G1A<F$@<V5L('EA;F<@8F5R9&5K871A;@!*87)A:R!A;G1A<F$@:7-I(&1A
M;B!B;W)D97(@9&D@9&%L86T@<V5L`$IA<F%K('-P87-I`$IA<F%K('-P87-I
M(&1A;B!J87)A:R!S<&%S:2!D87)I(&)O<F1E<@!3<&%M`$UA<W5K:V%N($MA
M<F%K=&5R(%-P97-I86P`4&ES86AK86X@4V5L`%!I<V%H:V%N(&MO;&]M`%!I
M<V%H:V%N(&)A<FES`$]L86AR86=A`%-T86YD87(`4&5R:F%L86YA;B!":6YT
M86YG`%-T871U<P!!;F=K82]H=7)U9B]S:6UB;VP@>6%N9R!D:6)E<FD@=&%N
M9&$@9V%R:7,`1V%Y82!;0U-370!-:6X`06YG:V$O:'5R=68O<VEM8F]L('EA
M;F<@9&ET=6QI<R!D:6)A=V%H(&=A<FES(&)A<FES('1E:W,`0F5R:&%S:6P`
M(B5S(G-U9&%H(&)E<FAA<VEL(&1I:&%P=7,N`$MO;F9I9W5R87-I('-U9&%H
M(&)E<FAA<VEL(&1I:V5M8F%L:6MA;BX@56QA;F=I('5N='5K(&UE;&EH870@
M<&5R=6)A:&%N+B``0F%C:W5P(&MO;F9I9W5R87-I('-U9&%H(&)E<FAA<VEL
M(&1I<VEM<&%N+@!&:6QE($)A8VMU<"!+;VYF:6=U<F%S:2`E<R!S=61A:"!B
M97)H87-I;"!D:7-I;7!A;BX`)R5S)R!S=61A:"!B97)H87-I;"!D:71U;&ES
M`%)I;F=K87-A;@!-871A:&%R:2!497)B:70`36%T86AA<FD@5&5R8F5N86T`
M0V5R86@`36%T86AA<FD@5&5R8FET`$UA=&%H87)I(%1E<F)I="]-871A:&%R
M:2!497)B96YA;0!-871A:&%R:2!497)B:70Z`$UA=&%H87)I(%1E<F)E;F%M
M`$UA=&%H87)I(%1E<F)E;F%M.@!!;F=K82]H=7)U9B]S:6UB;VP@>6%N9R!D
M:71U;&ES(&1I871A<R!B87)I<R!T96MS`$1U:W5N9V%N`$AU:F%N('!E=&ER
M(&1I<V5R=&%I(&1E;F=A;B!A;F=I;B!R:6)U=`!(=6IA;B!P971I<B!D:7-E
M<G1A:2!D96YG86X@8F%D86D@86YG:6X@<FEB=70`2'5J86X@<&5T:7(@9&ES
M97)T86D@9&5N9V%N(&%N9VEN(')I8G5T`%!R;W!E<G1I(%1A8F5L`%!R;W!E
M<G1I('1A8F5L`%1A<F=E=#H`5'5G87,`4W5H=2!U;G1U:R!J86T@=&5R86MH
M:7(Z`%-U:'4`4W5H=3H`4W5H=3QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G
M.R5S`%1E;7!L871E($%D;6EN:7-T<F%S:0!(86YY82!496MS`%!E<F%T86%N
M(%1E:W,`5&5K<R!"86=I86X@071A<P!+;7,`5&AA:2`H5$E3+38R,"D`4&5M
M96QI:&%R86%N.CH@8VQA<W,@=&ED86L@8F5R:&%S:6P@9&EP86YG9VEL`%=I
M;F1O=R!0:6QI:&%N('-U9&%H(&1I='5T=7`N(%-I;&%K86X@2V5L=6%R`$AA
M;GEA('-I<VD@8F%G:6%N(&)A=V%H`$UO9&4@3&%Y87(@4&5N=6@@9&EK96YA
M;"!D87!A="!M96YY96)A8FMA;B!M87-A;&%H(&1E;F=A;B!);G1E<FYE="!%
M>'!L;W)E<BP@:G5G82!U;G1U:R!M96YC87)I(&ME<V%L86AA;B!Y86YG(&UE
M;GEE8F%B:V%N(&%N9&$@=&ED86L@;6%M<'4@8F5K97)J82!D96YG86X@8F%I
M:RX@06YD82!M=6YG:VEN('!E<FYA:"!M96YG86QA;6D@=&%M<&EL86X@>6%N
M9R!B=7)U:RP@:V5K=7)A;F=A;B!D87)I(&9U;F=S:2!E9&ET;W(@9&%N+V%T
M874@8G)O=W-E<B!Y86YG('-E<FEN9R!K86QI(')U<V%K(&1A;B!H87)U<R!D
M:75L86YG(&ME;6)A;&DN($II:V$@<VES=&5M(&%N9&$@861A;&%H(%=I;F1O
M=W,@.7@@861A(&ME;75N9VMI;F%N(&%N9&$@86MA;B!M96YD87!A=&MA;B`G
M2V5S86QA:&%N(%!E<FQI;F1U;F=A;B!5;75M)R!D86X@<&5R;'4@=6YT=6L@
M;64M<F5S=&%R="!K;VUP=71E<B!A;F1A+EQN7&X@06YD82!S=61A:"!D:7!E
M<FEN9V%T:2X@4VEL86MA;B!K;&EK($]+(&II:V$@86YD82!I;F=I;B!M96YC
M;V)A(&5D:71O<B!L87EA<B!P96YU:"X`261E;G1I=&%S("(E<R(@<W5D86@@
M9&EH87!U<RX`2&%N>6$@<VES:2!B86=I86X@:VER:0!(86YY82!S:7-I(&)A
M9VEA;B!K86YA;B!D86X@:VER:0!(86YY82!S:7-I(&)A9VEA;B!K86YA;@!3
M97)V97(@(B5S(B!S=61A:"!B97)H87-I;"!D:6AA<'5S+@!397)V97(@(B5S
M(B!S=61A:"!B97)H87-I;"!D:7-I;7!A;BX`4&5R;6EN=&%A;B!P96YD869T
M87)A;B!U;G1U:R`E<R!S=61A:"!B97)H87-I;"!D:7!I;F1A:&MA;BX`2&%N
M>6$@<VES:2!B86=I86X@871A<R!D86X@8F%W86@`2&%N>6$@<VES:2!B86=I
M86X@871A<P!!<F5A(&ME('=E871H97(N8V]M('1I9&%K(&1I<V5D:6%K86XN
M`$%D82!K97-A;&%H86X@9&D@9&%L86T@9F]R;75L:7(@:V]N9FEG=7)A<VDN
M($UU;F=K:6X@86YD82!T:61A:R!M96YG:7-I(&MO;&]M('EA;F<@9&EP97)L
M=6MA;BX`26YI(&%D86QA:"`E<RX`5VEN9&]W(&EN:2!H87)U<R!D:7!A;F=G
M:6P@9&%R:2!0:6QI:&%N(%=I;F1O=P!0971I<@!4:6ME=`!-96YG:6MU=&D@
M5V%K='4`1F]R;6%T(%=A:W1U`$IU9'5L`$IU9'5L("A#871A=&%N('!E='5N
M:G5K*0!(87)I($EN:0!'86YT:2!3;W5R8V4@2%1-3`!"97-O:P!!=&%S`$9R
M86UE($%T87,@*%]T;W`I`%1R86YS;&%S:0!396P`5'5R:VD@*$E33RTX.#4Y
M+3DI`$EN9&5K<R!5+E8Z`%523`!54DPZ`%1I9&%K(&1A<&%T('5N='5K(&UE
M;F=H87!U<R`B)7,B.B`E<RX`1V%R:7,@8F%W86@`0F%T86QK86X@4&5R=6)A
M:&%N`$)A=&%L:V%N(&%K<VD@=&5R86MH:7(@86YD80!4:61A:R!D:6%R<VEP
M:V%N`%5N:6-O9&4@*%541BTX*0!5;FET`$)A=&%L:V%N(&QI;FL@<&%D82!E
M;&5M96X@>6%N9R!S96MA<F%N9P!38W)I<'0@>6%N9R!T:61A:R!M96UP=6YY
M86D@:&%K(&ES=&EM97=A('1I9&%K(&1A<&%T(&UE;F=A:W-E<R!(87!U<R]3
M86QI;B],96MA=&MA;B!S97-U86D@<F5N8V%N82!U;G1U:R!A;&%S86X@:V5A
M;6%N86XN2VQI:R!/2R!U;G1U:R!M96QI:&%T(&-A=&%T86X@=&5K;FES('!A
M9&$@;6]Z:6QL82YO<F<@9&EM86YA(&%N9&$@86MA;B!D:7!E<FQI:&%T:V%N
M(&-A<F$@8F%G86EM86YA('5N='5K(&UE;F=I>FEN:V%N('-C<FEP="!U;G1U
M:R!D87!A="!M96YG86MS97,@:V4@8VQI<&)O87)D+@!787)N82!B96QU;2!D
M:6%T=7(`4&5R8F%H87)U:0!097)B86AA<G5I("5S`%!E<F)A:&%R=6D@<&5N
M9V=U;F$`(B5S(B!S=61A:"!D:7!E<F)A:&%R=6DN`%-C<FEP="!U<&=R861E
M('-U9&%H(&1I:&%P=7,N`%5P;&]A9`!396UU82!F:6QE('-E='5P(&%P;&EK
M87-I('-U9&%H(&1I=7!L;V%D(&ME('-E<G9E<BX`4VEM8F]L(&AU<G5F(&)E
M<V%R(&QA=&EN`%-I;6)O;"!H=7)U9B!B97-A<B!R;VUA=VD`1W5N86MA;FQA
M:"!J:6MA(&YA;6$O<V%N9&D@86YD82!B97)B961A('5N='5K('-E<G9E<B!)
M35-0+@!!9&UI;FES=')A<VD@4&5N9V=U;F$`4&5N9&%F=&%R86X@4&5N9V=U
M;F$`4&5N9&%F=&%R86X@4&5N9V=U;F$@<W5D86@@9&EN;VXM86MT:69K86X@
M=6YT=6L@<VET92!I;FDN`$%C8V]U;G0@4&5N9V=U;F$@=&ED86L@9&ET96UU
M:V%N`$YA;6$@4&5N9V=U;F$`3F%M82!096YG9W5N83H`3F%M82!096YG9W5N
M83H`4&5N9V=U;F$@9&D@9&%L86T@<VES=&5M.@!,:6)U<F%N`%9A<FEA8FQE
M`%9E<G-I($MO;G1R;VP`2F%R86L@<&]S:7-I('9E<G1I:V%L(&%N=&%R82!G
M87)I<R!D87-A<B!D96YG86X@9V%M8F%R`$IA<F%K('!O<VES:2!V97)T:6MA
M;"!A;G1A<F$@8F]R9&5R(&1E;F=A;B!G86UB87(`5F5R=&EK86PZ`%-A;F=A
M="!4:6YG9VD`5FEE=&YA;2`H5DE30TE)*0!,:6AA="!W96(@<&%G92!E:W-T
M97)N86P`2F%R86L@4&%N9&%N9P!*87)A:R!086YD86YG.@!015))3D=!5$%.
M(2$A(%!)3D1!2$M!3B!30U))4%0@24Y)(%-%0T%202!-04Y504P@1$%222`E
M<RX`4&5R:6YG871A;@!286)U`%)A;6%L86X@0W5A8V$`1&%T82!#=6%C82!D
M:7-E9&EA:V%N(&]L96@`5V5B`%=E8B!3:71E`%-E;&%M870@1&%T86YG`%-E
M;&%M870@9&%T86YG(&ME("5S`%-E;&%M870@9&%T86YG+"`E<P!797-T97)N
M("A)4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ-2D`07!A:V%H(&%P
M;&EK87-I("5S('!E<FQU(&1I=&%M<&EL:V%N('-E=&5L86@@;&]G:6X_`$%P
M86MA:"!Y86YG(&UE<G5P86MA;B!B871A<R!K87)A:W1E<C\`07!A:V%H('EA
M;F<@;65R=7!A:V%N(&MA<F%K=&5R(&EN9&5N=&%S:3\`1F%S92!Y86YG(&UA
M;F$`4&QU9VEN(&UA;F%K86@@>6%N9R!D87!A="!D:6%K=&EF:V%N('5N='5K
M(&5D:71O<B!2:6-H(%1E>'0N`$QE8F%R`$QE8F%R(&UE;G4@)7,@<&%D82!B
M86=I86X@:VER:2`H86MA;B!B97)P96YG87)U:"!P861A(&QO9VEN(&)E<FEK
M=71N>6$I`$QE8F%R('1A8F5L`$QE8F%R('5N:70`3&5B87(Z`%=I:VD`06YG
M:6X`06YG:6X@9&D@<&%G:2!H87)I`$ME8V5P871A;B!A;F=I;B!D:2!D86QA
M;2!K;F]T`$%N9VEN.@!!;F=I;CH`2V%T82!":6IA:W-A;F$`1&%F=&%R($ME
M:6YG:6YA;@!096ME<FIA86X`6"U2968`65D`66$L(%-!64$@4T5454I5`$%N
M9&$@8F5R861A(&1I(&1A;&%M($U/1$4@5$5+4RX@1W5N86MA;B!T;VUB;VP@
M6SP^72!U;G1U:R!M96YG9V%N=&D@:V5M8F%L:2!K92!D86QA;2!M;V1E(%=9
M4TE764<N`$%N9&$@=&ED86L@9&EI>FEN:V%N('5N='5K(&UE;6)U870@;&5B
M:6@@9&%R:2`E9"!A<F5A+@!!;F1A(&AA<G5S(&UE;FIE;&%S:V%N(&UA<V%L
M86@@<V5B96QU;2!A;F1A(&1A<&%T(&UE;F=I<FEM:V%N(&QA<&]R86X@;6%S
M86QA:"X`06YD82!H87)U<R!M96UA<W5K:V%N(%523"!D:6UA;F$@;&EN:R!I
M;FD@;65N=6YJ=6L@:V4`06YD82!H87)U<R!M96UI;&EH('-E<G9E<B!U;G1U
M:R!D87!A="!D:6AA<'5S+@!!;F1A(&AA<G5S(&UE;F5T87!K86X@;F%M82!P
M96YG9W5N82!Y86YG(&EN9VEN(&1I8F5R<VEH:V%N+@!!;F1A(&AA<G5S(&UE
M;F5T87!K86X@;F%M82!P96YG9W5N82!Y86YG(&EN9VEN(&1I<&EN9&%H:V%N
M+@!!;F1A(&AA<G5S(&UE;F5T87!K86X@;F%M82!P96YG9W5N82!U;G1U:R!D
M:71A;6)A:"X`06YD82!H87)U<R!M96YE=&%P:V%N(&YA;6$@<&5N9V=U;F$@
M=6YT=6L@9&EP97)B86AA<G5I+@!!;&%M870@16UA:6P@06YD80!!;F1A($1A
M<FDZ(&%L86UA=#H`26YF;W)M87-I($%N9&$`3F%M82!!;F1A`$)A8VME;F0@
M87-L:2!A;F1A('1I9&%K(&1A<&%T(&UE;F1U:W5N9R!P96YD869T87)A;B!P
M96YG9W5N82P@871A=2!F:71U<B!I;FD@<W5D86@@9&EN;VXM86MT:69K86X@
M=6YT=6L@8F5B97)A<&$@86QA<V%N(&QA:6X`0G)O=W-E<B!A;F1A('1I9&%K
M(&UE;F1U:W5N9R!U;G1U:R!F:71U<B!I;FDN`%IO;F$@5V%K='4@06YD82!3
M96MA<F%N9SH`1&5F875L="!I9&5N=&ET87,@86YD82!S=61A:"!D:75B86@N
M`$1E9F%U;'0@:61E;G1I=&%S(&%N9&$Z`$YA;6$@;&5N9VMA<"!A;F1A.@!3
M86YD:2!B87)U(&%N9&$@=6YT=6L@)7,@861A;&%H.B`E<P!386YD:2!A;F1A
M('-U9&%H(&1I871U<B!U;&%N9P!386YD:2!A;F1A('-U9&%H(&1I871U<B!U
M;&%N9RP@<&5R:6MS86QA:"!E;6%I;"!A;F1A(&1A;B!L;V=I;B!D96YG86X@
M;65N9V=U;F%K86X@<V%N9&D@8F%R=2!A;F1A`%)E;6]T92!S97)V97(@86YD
M83H`0V5R:6$`6U-E;6)U;GEI:V%N($EN9&5N=&%S:2!496MS70!;3&%P;W)A
M;B!-87-A;&%H70!;5&%M<&EL86X@26YD96YT87-I(%1E:W,@+0!?061M:6YI
M<W1R87-I`%]#3$D`7T1A=&%4<F5E`$AA<'5S($)A<FES`%]'<G5P`%!R;W!E
M<G1I($=A;6)A<BXN+@!58F%H($QI;FLN+BX`27II;@!0:6YD86AK86X@3&EN
M:RXN+@!?4V5T=7``4')O<&5R=&D@5&%B96PN+BX`4&5N9V=U;F$`5&5N86YG
M`&IA='5H`$1A<FD@)7,@*"5S*2!P861A("5S("5S`&%N9VEN(&ME;F-A;F<`
M;6%S:6@@9&D@9&%L86T@86YT<FEA;@!B87)I<UT`;F%M80!P97)S96X`<&EX
M96P`;F%I:P!T86UP:6QK86X@<&5R8F5D86%N`'1E=&%P`$ME=&EK('-A;F1I
M(&1U82!K86QI('5N='5K(&UE;F=K;VYF:7)M87-I`&UE;GEA='5K86X`=V5A
M=&AE<BYC;VT`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VAU
M7TA5````````````````````````````````````````````````````````
M`````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S0Q(#`Q-S<R-@`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L;V-A;&4O:'5?2%4O3$-?34534T%'15,`````````````````
M````````````````````````````````````````````````````,#`P-S4U
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W-#$@,#(Q
M-3$S`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]H=5](52],0U]-15-3
M04=%4R]H;W)D92YM;P``````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#0R,S$P
M-2`Q,#4Q-30S,S<T,2`P,C,R,S4`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````WA($E0````!S!P``'````+0[``#O"0``3'<`
M```````(GP``#@````F?```/````&)\```T````HGP``"````#:?```+````
M/Y\```P```!+GP``!````%B?```8````79\``!L```!VGP``+0```)*?```=
M````P)\``"0```#>GP``*0````.@```9````+:```"8```!'H```#````&Z@
M```D````>Z````\```"@H```"P```+"@```.````O*```"@```#+H```"```
M`/2@```*````_:```!4````(H0``$@```!ZA```+````,:$``(4````]H0``
M#@```,.A```*````TJ$```T```#=H0``#@```.NA```1````^J$```T````,
MH@``#````!JB```-````)Z(``)0````UH@``"@```,JB```/````U:(``!@`
M``#EH@``#````/ZB```.````"Z,```X````:HP``"````"FC```)````,J,`
M`"X````\HP``&@```&NC```R````AJ,``#@```"YHP``5````/*C``!1````
M1Z0``%H```"9I```5P```/2D```T````3*4```D```"!I0``#0```(NE```'
M````F:4```H```"AI0``#P```*RE```%````O*4```8```#"I0``$0```,FE
M```(````VZ4```D```#DI0``"0```.ZE```E````^*4``"`````>I@``$P``
M`#^F```0````4Z8```\```!DI@``"@```'2F```#````?Z8```\```"#I@``
M%````).F```)````J*8```T```"RI@``$@```,"F```9````TZ8``!X```#M
MI@``#P````RG```*````'*<```\````GIP``"````#>G```D````0*<``!0`
M``!EIP``%@```'JG```(````D:<``$X```":IP``+0```.FG```9````%Z@`
M``<````QJ```#````#FH```L````1J@```X```!SJ````P```(*H```+````
MAJ@```<```"2J```!P```)JH```%````HJ@```4```"HJ```"@```*ZH```#
M````N:@``!<```"]J```"@```-6H```/````X*@```X```#PJ```&````/^H
M```C````&*D```X````\J0``%````$NI```7````8*D``!<```!XJ0``%P``
M`)"I```3````J*D```\```"\J0``#@```,RI```?````VZD``!T```#[J0``
M!P```!FJ```&````(:H```@````HJ@``#P```#&J```&````0:H```H```!(
MJ@``$P```%.J```+````9ZH``!````!SJ@``%0```(2J```5````FJH```<`
M``"PJ@``$````+BJ```%````R:H``!4```#/J@``$0```.6J```,````]ZH`
M`#L````$JP``.````$"K```)````>:L```<```"#JP``%````(NK```#````
MH*L```4```"DJP``$````*JK```)````NZL``!,```#%JP``.0```-FK```2
M````$ZP``"<````FK```+````$ZL```J````>ZP``"4```"FK```"@```,RL
M```&````UZP```D```#>K```!P```.BL```O````\*P``#<````@K0``+@``
M`%BM``!5````AZT``"T```#=K0``+0````NN```]````.:X``#\```!WK@``
M+0```+>N``!`````Y:X``",````FKP``(P```$JO``!`````;J\``"T```"O
MKP``,P```-VO```E````$;```!4````WL```&0```$VP```I````9[```"0`
M``"1L```*````+:P```1````W[````H```#QL```#````/RP```*````";$`
M`!`````4L0``%@```"6Q```6````/+$```<```!3L0``!P```%NQ```4````
M8[$```H```!XL0``"````(.Q```G````C+$```@```"TL0``!P```+VQ```'
M````Q;$```8```#-L0``!0```-2Q```'````VK$```8```#BL0``"````.FQ
M```I````\K$```X````<L@``"@```"NR```$````-K(```<````[L@``"0``
M`$.R```&````3;(``!$```!4L@``!P```&:R```6````;K(```0```"%L@``
M"````(JR```&````D[(```T```":L@``!@```*BR```>````K[(``!$```#.
ML@``"````."R```-````Z;(```P```#WL@``!P````2S```#````#+,```,`
M```0LP``%P```!2S```3````++,``!T```!`LP``"````%ZS```$````9[,`
M``@```!LLP``"````'6S``!!````?K,``!H```#`LP``*P```-NS```@````
M![0``!4````HM```!@```#ZT```&````1;0``!4```!,M```&````&*T```B
M````>[0``"X```">M```'0```,VT```A````Z[0``%0````-M0``*0```&*U
M```*````C+4```<```"7M0``!P```)^U```5````I[4```X```"]M0``"@``
M`,RU```/````U[4```T```#GM0``#P```/6U```-````!;8```D````3M@``
M%````!VV```&````,K8``!@````YM@``'0```%*V```3````<+8``!$```"$
MM@``%````):V```$````J[8```8```"PM@``%````+>V``!4````S+8``&0`
M```AMP``!````(:W```.````B[<```4```":MP``!0```*"W```;````IK<`
M`!H```#"MP``$P```-VW```1````\;<``!$````#N```'````!6X```J````
M,K@``!````!=N```(0```&ZX```%````D+@``!,```"6N```"P```*JX```2
M````MK@```H```#)N```#P```-2X```-````Y+@``!$```#RN```$P````2Y
M```,````&+D```8````EN0``#````"RY```&````.;D``!<```!`N0``$```
M`%BY```1````:;D```@```![N0``!0```(2Y```,````BKD``!````"7N0``
M!0```*BY```-````KKD```8```"\N0``!P```,.Y```-````R[D```<```#9
MN0``"P```.&Y```'````[;D```<```#UN0``"0```/VY```)````![H```H`
M```1N@``&0```!RZ```]````-KH``!T```!TN@``#````)*Z```0````G[H`
M``4```"PN@``)0```+:Z```2````W+H``!,```#ON@``*P````.[```[````
M+[L``"````!KNP``"````(R[```V````E;L``"$```#,NP``$````.Z[```(
M````_[L```P````(O```!@```!6\```$````'+P```\````AO```#@```#&\
M```'````0+P```H```!(O```#0```%.\```?````8;P``!P```"!O```(0``
M`)Z\```>````P+P``!D```#?O```'@```/F\```;````&+T``"$````TO0``
M+@```%:]```F````A;T``!P```"LO0``'@```,F]```<````Z+T``"8````%
MO@``*P```"R^```S````6+X``"8```",O@``*P```+.^```X````W[X``!T`
M```8OP``%0```#:_```O````3+\``"````!\OP``$@```)V_```I````L+\`
M`!X```#:OP``(````/F_```2````&L```*(````MP```%@```-#````C````
MY\```"@````+P0``*0```#3!```H````7L$``!\```"'P0``%0```*?!```@
M````O<$``"4```#>P0``*`````3"```M````+<(``#````!;P@``D@```(S"
M```A````'\,``!8```!!PP``'````%C#```F````=<,``"H```"<PP``00``
M`,?#``!$````"<0```P```!.Q```!P```%O$```'````8\0```8```!KQ```
M#0```'+$```0````@,0``!(```"1Q```$P```*3$```2````N,0```<```#+
MQ```!````-/$```0````V,0``!````#IQ```#````/K$```.````!\4```T`
M```6Q0``#P```"3%```3````-,4```T```!(Q0``*````%;%```#````?\4`
M``T```"#Q0``!@```)'%```1````F,4``!<```"JQ0``&P```,+%```.````
MWL4```(```#MQ0``20```/#%```%````.L8``!````!`Q@``#P```%'&```$
M````8<8```T```!FQ@``#@```'3&```#````@\8```X```"'Q@``"````);&
M```/````G\8```\```"OQ@``!P```+_&```-````Q\8``!````#5Q@``#0``
M`.;&```+````],8```8`````QP``"P````?'```,````$\<```H````@QP``
M$0```"O'```9````/<<```L```!7QP``#0```&/'```B````<<<```\```"4
MQP``&P```*3'```T````P,<```H```#UQP``&`````#(```2````&<@``!D`
M```LR```%@```$;(```B````7<@```T```"`R```!P```([(```4````EL@`
M``L```"KR```(@```+?(```O````VL@```L````*R0``"0```!;)```9````
M(,D```L````ZR0``%P```$;)```7````7LD```D```!VR0``%@```(#)```/
M````E\D``!D```"GR0``%@```,')```.````V,D``!@```#GR0``"`````#*
M```-````"<H``"8````7R@``0P```#[*```(````@LH``!(```"+R@``'P``
M`)[*```(````OLH```L```#'R@``+P```-/*```.`````\L```4````2RP``
M!@```!C+``!%````'\L```,```!ERP``!P```&G+```$````<<L```H```!V
MRP``"@```('+```/````C,L``!````"<RP``%P```*W+```1````Q<L``!D`
M``#7RP``%P```/'+```)````"<P```4````3S```"P```!G,```*````)<P`
M``(````PS```!0```#/,```-````.<P``!L```!'S```%P```&/,```4````
M>\P```D```"0S```#@```)K,```-````J<P``!(```"WS```.````,K,```@
M`````\T```@````DS0``#@```"W-``![````/,T``!@```"XS0``&````-'-
M```1````ZLT```<```#\S0``!0````3.```8````"LX``!X````CS@``&P``
M`$+.```9````7LX``!L```!XS@``&0```)3.```3````KLX```<```#"S@``
M"````,K.```&````T\X```8```#:S@``$````.'.```/````\LX``!`````"
MSP``#P```!//```+````(\\```\````OSP``#````#_/```/````3,\```<`
M``!<SP``!@```&3/```.````:\\```P```!ZSP``*````(?/```/````L,\`
M``@```#`SP``"````,G/```3````TL\``!X```#FSP``(0````70```@````
M)]```!D```!(T```%P```&+0```E````>M```!<```"@T```%@```+C0```$
M````S]```!L```#4T```#0```/#0```,````_M````,````+T0``!0````_1
M```(````%=$```H````>T0``#````"G1```+````-M$``!````!"T0``#```
M`%/1```.````8-$```0```!OT0``!````'31```3````>=$``!0```"-T0``
M#````*+1```)````K]$```X```"YT0``"P```,C1```;````U-$```<```#P
MT0``!P```/C1```*`````-(```T````+T@``"0```!G2```$````(](```,`
M```HT@``&````"S2```*````1=(```0```!0T@``)@```%72```.````?-(`
M`'P```"+T@``%0````C3```%````'M,```<````DTP``#````"S3```(````
M.=,```H```!"TP``!@```$W3```(````5-,```(```!=TP``!@```&#3```&
M````9],``!0```!NTP``#0```(/3```0````D=,``!L```"BTP``!````+[3
M```)````P],``!````#-TP``"0```-[3```)````Z-,```4```#RTP``&@``
M`/C3```(````$]0```8````<U```&0```"/4```.````/=0```<```!,U```
M!P```%34```%````7-0```D```!BU```"@```&S4```.````=]0```(```"&
MU```!@```(G4```+````D-0```T```"<U```"0```*K4```&````M-0``!(`
M``"[U```"0```,[4```'````V-0``!0```#@U```'0```/74``!"````$]4`
M`"4```!6U0``)0```'S5```&````HM4```H```"IU0``!````+35```)````
MN=4```@```##U0``$0```,S5```)````WM4```8```#HU0``#0```._5```&
M````_=4``#D````$U@``/0```#[6```Z````?-8``!X```"WU@``!0```-;6
M```.````W-8```0```#KU@``!@```/#6```'````]]8``"$```#_U@``#0``
M`"'7```5````+]<```8```!%UP``!````$S7```1````4=<```8```!CUP``
M"@```&K7```B````==<```0```"8UP``!0```)W7```=````H]<```0```#!
MUP``#````,;7```.````T]<```H```#BUP``"````.W7```)````]M<```4`
M````V```.@````;8```P````0=@``#4```!RV```*0```*C8``!'````TM@`
M`#@````:V0``*0```%/9```_````?=D``"X```"]V0``+0```.S9```?````
M&MH```\````ZV@``$@```$K:```+````7=H``"8```!IV@``*0```)#:```D
M````NMH``"8```#?V@``"`````;;```*````#]L```D````:VP``!P```"3;
M```@````+-L``"````!-VP``)@```&[;```*````E=L``!D```"@VP``*0``
M`+K;```6````Y-L``!(```#[VP``!P````[<```*````%MP```P````AW```
M#P```"[<```0````/MP``$````!/W```<````)#<``!F`````=T```X```!H
MW0``"0```'?=```*````@=T``!(```",W0``$P```)_=```,````L]T```8`
M``#`W0``#P```,?=```2````U]T``!````#JW0``$0```/O=```<````#=X`
M`",````JW@``:@```$[>```/````N=X```4```#)W@``$````,_>```)````
MX-X```0```#JW@``"P```._>```@````^]X``!0````<WP``#````#'?```,
M````/M\```\```!+WP``%0```%O?```I````<=\``"H```";WP``)@```,;?
M```G````[=\``"D````5X```*@```#_@```9````:N```$(```"$X```$0``
M`,?@```2````V>```!,```#LX```%`````#A```/````%>$``!8````EX0``
M%P```#SA```0````5.$``!$```!EX0``-````'?A```3````K.$``!(```#`
MX0``-0```-/A```4````">(```<````>X@``#````";B```@````,^(``!``
M``!4X@``%````&7B```1````>N(``!<```",X@``'````*3B```3````P>(`
M`!0```#5X@``&@```.KB```1````!>,``!H````7XP``'@```#+C```:````
M4>,``!,```!LXP``%0```(#C```1````EN,``!<```"HXP``%````,#C```7
M````U>,``!4```#MXP``"0````/D```0````#>0``!D````>Y```!````#CD
M```'````/>0```L```!%Y```$0```%'D```&````8^0```8```!JY```!@``
M`''D```%````>.0```<```!^Y```!P```(;D```%````CN0``!8```"4Y```
M!@```*OD```&````LN0```0```"YY```!````+[D```'````P^0```X```#+
MY```#````-KD```,````Y^0```T```#TY```"@````+E```.````#>4```4`
M```<Y0``*````"+E```.````2^4```P```!:Y0``#P```&?E```*````=^4`
M``@```""Y0``"0```(OE```K````E>4```0```#!Y0``"````,;E```F````
MS^4``!(```#VY0``#P````GF```&````&>8```H````@Y@``!P```"OF```(
M````,^8``"`````\Y@``"0```%WF```4````9^8```P```!\Y@``#0```(GF
M```.````E^8``!8```"FY@``$0```+WF```&````S^8```,```#6Y@``!@``
M`-KF```9````X>8```<```#[Y@``!`````/G```+````".<```L````4YP``
M!P```"#G```%````*.<```<````NYP``%@```#;G```-````3><```T```!;
MYP``"@```&GG```0````=.<```\```"%YP``$0```)7G```7````I^<```H`
M``"_YP``$0```,KG```$````W.<```\```#AYP``.@```/'G```%````+.@`
M``P````RZ```'@```#_H```.````7N@``!````!MZ```"P```'[H```,````
MBN@```D```"7Z```!P```*'H```*````J>@```D```"TZ```#@```+[H```0
M````S>@``!L```#>Z```&````/KH```:````$^D```H````NZ0``"0```#GI
M```*````0^D```P```!.Z0``#P```%OI```(````:^D```8```!TZ0``'```
M`'OI```'````F.D```4```"@Z0``"P```*;I``!'````LND```T```#ZZ0``
M"0````CJ```$````$NH```,````7Z@``$P```!OJ```3````+^H``!,```!#
MZ@``"@```%?J```"````8NH```0```!EZ@``)0```&KJ```#````D.H```4`
M``"4Z@``*@```)KJ```*````Q>H```4```#0Z@``!````-;J```*````V^H`
M``T```#FZ@``!@```/3J```(````^^H```@````$ZP``!`````WK```%````
M$NL``&@````8ZP``"0```('K```,````B^L``!````"8ZP``!0```*GK```&
M````K^L``!L```"VZP``+P```-+K```0`````NP```H````3[```#P```![L
M```*````+NP```D````Y[```$P```$/L```;````5^P``!@```!S[```%P``
M`(SL```?````I.P```X```#$[````P```-/L```'````U^P```@```#?[```
M!P```.CL```*````\.P```L```#[[```!P````?M``!1````#^T``!````!A
M[0``#````'+M```-````?^T``!H```"-[0``2@```*CM```9````\^T```8`
M```-[@``&@```!3N```E````+^X```8```!5[@``!@```%SN```?````8^X`
M``8```"#[@``"0```(KN```8````E.X``!<```"M[@``*````,7N```&````
M[NX```T```#U[@``(@````/O``!7````)N\``!,```!^[P``(P```)+O```3
M````MN\```(```#*[P``"P```,WO```(````V>\```T```#B[P``"@```/#O
M```'````^^\``!0````#\```!@```!CP```(````'_````X````H\```!P``
M`#?P```*````/_````L```!*\```,@```%;P```'````B?````P```"1\```
M#0```)[P```,````K/````D```"Y\```"0```,/P```*````S?````<```#8
M\```"0```.#P```'````ZO````H```#R\```&P```/WP```/````&?$``!(`
M```I\0``"@```#SQ```6````1_$```D```!>\0``$````&CQ```'````>?$`
M`!(```"!\0``!````)3Q```'````F?$```4```"A\0``!0```*?Q```+````
MK?$``!0```"Y\0``$0```,[Q```:````X/$``!8```#[\0``%````!+R```7
M````)_(``!@````_\@``'````%CR```9````=?(```<```"/\@``!0```)?R
M```-````G?(```P```"K\@``$0```+CR```(````RO(``!<```#3\@``"P``
M`.OR```,````]_(``!\````$\P``&@```"3S```3````/_,```0```!3\P``
M"@```%CS```$````8_,```T```!H\P``#````';S```%````@_,```D```")
M\P``!0```)/S```'````F?,```4```"A\P``!````*?S```"````K/,``#@`
M``"O\P``+````.CS```2````%?0``"D````H]```,@```%+T```*````A?0`
M`"P```"0]```+@```+WT```S````[/0``#,````@]0``.````%3U```/````
MC?4``!@```"=]0``$````+;U```/````Q_4``!,```#7]0``%0```.OU```4
M`````?8``!(````6]@``%````"GV```5````/O8``"T```!4]@``+0```(+V
M```Q````L/8``"X```#B]@``+P```!'W```L````0?<``&(```!N]P``$P``
M`-'W```-````Y?<```@```#S]P``%P```/SW```(````%/@```P````=^```
M*P```"KX```A````5O@``!H```!X^```"0```)/X``!%````G?@``$$```#C
M^```!````"7Y```3````*OD``!0````^^0``#@```%/Y```3````8OD``!@`
M``!V^0``!@```(_Y```)````EOD```H```"@^0``#P```*OY```0````N_D`
M``<```#,^0``#@```-3Y```%````X_D``!L```#I^0``"`````7Z```&````
M#OH``!0````5^@``$0```"KZ```.````//H``#@```!+^@```@```(3Z```&
M````A_H```X```".^@``!0```)WZ```'````H_H```X```"K^@``!@```+KZ
M```H````P?H```P```#J^@``'````/?Z```$````%/L``"D````9^P``%P``
M`$/[```?````6_L``%P```![^P``%````-C[```^````[?L``!\````L_```
M$````$S\```'````7?P```X```!E_```#````'3\```,````@?P``!,```".
M_```"@```*+\```=````K?P``!D```#+_```!0```.7\```1````Z_P``!$`
M``#]_```)`````_]```2````-/T``!4```!'_0``$@```%W]```.````</T`
M`!D```!__0``"````)G]```-````HOT```<```"P_0``"@```+C]```'````
MP_T```\```#+_0``!@```-O]```+````XOT``!H```#N_0``!P````G^```(
M````$?X```4````:_@``'P```"#^```&````0/X``!````!'_@``"````%C^
M```-````8?X```@```!O_@``'@```'C^```2````E_X``"P```"J_@``&@``
M`-?^```)````\OX```H```#\_@``%0````?_```%````'?\``!0````C_P``
M!````#C_```0````/?\```8```!._P``!P```%7_```>````7?\``"@```!\
M_P``"@```*7_```<````L/\``!$```#-_P``"P```-__```:````Z_\``!0`
M```&``$`!````!L``0`$````(``!``L````E``$`!0```#$``0`&````-P`!
M``@````^``$`!@```$<``0`*````3@`!`!L```!9``$`-````'4``0`T````
MJ@`!`"````#?``$`*0`````!`0`@````*@$!`$$```!+`0$`&@```(T!`0`H
M````J`$!`"D```#1`0$`4````/L!`0`B````3`(!``8```!O`@$`"````'8"
M`0`%````?P(!``@```"%`@$`&0```(X"`0`9````J`(!`"H```#"`@$`(P``
M`.T"`0`9````$0,!`"X````K`P$`-````%H#`0`(````CP,!`!<```"8`P$`
M"@```+`#`0`'````NP,!`"$```##`P$`$````.4#`0`.````]@,!``L````%
M!`$`!P```!$$`0`3````&00!``@````M!`$`"P```#8$`0`*````0@0!`!0`
M``!-!`$`#P```&($`0`R````<@0!``L```"E!`$`#@```+$$`0`%````P`0!
M``4```#&!`$`!0```,P$`0`7````T@0!``\```#J!`$`!````/H$`0`*````
M_P0!``D````*!0$`"P```!0%`0`-````(`4!``P````N!0$`#@```#L%`0`%
M````2@4!``0```!0!0$`#0```%4%`0`R````8P4!`$4```"6!0$`%P```-P%
M`0`'````]`4!`!X```#\!0$`%````!L&`0`4````,`8!``8```!%!@$`!P``
M`$P&`0`.````5`8!`"H```!C!@$`!@```(X&`0`,````E08!``T```"B!@$`
M$0```+`&`0`+````P@8!`#8```#.!@$`"@````4'`0`B````$`<!``L````S
M!P$`#P```#\'`0`R````3P<!`"4```""!P$`,````*@'`0`Q````V0<!`"T`
M```+"`$`#@```#D(`0`%````2`@!``X```!."`$`$P```%T(`0`2````<0@!
M``<```"$"`$`$0```(P(`0`3````G@@!``<```"R"`$`%````+H(`0`8````
MSP@!``<```#H"`$`!0```/`(`0`,````]@@!``P````#"0$`$@```!`)`0`$
M````(PD!``<````H"0$`"@```#`)`0`+````.PD!``P```!'"0$`#@```%0)
M`0`.````8PD!``4```!R"0$`!0```'@)`0`N````?@D!`"8```"M"0$`(P``
M`-0)`0`#````^`D!`!(```#\"0$`!@````\*`0`>````%@H!`!@````U"@$`
M)0```$X*`0`-````=`H!`!\```"""@$``P```*(*`0`'````I@H!``(```"N
M"@$`#````+$*`0`5````O@H!``L```#4"@$`&0```.`*`0`@````^@H!`!(`
M```;"P$`!0```"X+`0`*````-`L!`!4````_"P$`$@```%4+`0`,````:`L!
M``0```!U"P$`"0```'H+`0`'````A`L!``P```","P$`4@```)D+`0`7````
M[`L!`"0````$#`$`$@```"D,`0`'````/`P!``8```!$#`$`#@```$L,`0`,
M````6@P!``T```!G#`$`%0```'4,`0`2````BPP!``\```">#`$`%````*X,
M`0`*````PPP!`!L```#.#`$`$````.H,`0`+````^PP!`&D````'#0$`&@``
M`'$-`0`7````C`T!`"<```"D#0$`&@```,P-`0`7````YPT!`!L```#_#0$`
M&0```!L.`0`?````-0X!`!,```!5#@$`"````&D.`0`'````<@X!``@```!Z
M#@$`"0```(,.`0`5````C0X!``T```"C#@$`(P```+$.`0`-````U0X!`!,`
M``#C#@$`"````/<.`0`#``````\!`$8````$#P$`/P```$L/`0`W````BP\!
M`%<```###P$`!0```!L0`0`?````(1`!`"\```!!$`$`"@```'$0`0`(````
M?!`!``T```"%$`$`+0```),0`0`$````P1`!`$\```#&$`$`)0```!81`0`<
M````/!$!``L```!9$0$`'P```&41`0`=````A1$!`"4```"C$0$`(````,D1
M`0`D````ZA$!`"`````/$@$`"P```#`2`0`'````/!(!``T```!$$@$`#```
M`%(2`0`7````7Q(!``8```!W$@$`.0```'X2`0`,````N!(!``<```#%$@$`
M"0```,T2`0`3````UQ(!``D```#K$@$`!````/42`0`0````^A(!``@````+
M$P$`"````!03`0`$````'1,!``L````B$P$`#````"X3`0`2````.Q,!`!$`
M``!.$P$`#````&`3`0`:````;1,!``\```"($P$`!P```)@3`0`-````H!,!
M`!0```"N$P$`#@```,,3`0`,````TA,!`!L```#?$P$`+````/L3`0`3````
M*!0!`!P````\%`$`*````%D4`0`&````@A0!``<```")%`$`$P```)$4`0`%
M````I10!``0```"K%`$`%P```+`4`0`*````R!0!``P```#3%`$`"0```.`4
M`0`&````ZA0!``D```#Q%`$`"````/L4`0`)````!!4!``H````.%0$`$0``
M`!D5`0`&````*Q4!``X````R%0$`#@```$$5`0`-````4!4!``L```!>%0$`
M'0```&H5`0`+````B!4!``(```"4%0$`'````)<5`0`'````M!4!``8```"\
M%0$`9````,,5`0`)````*!8!``<````R%@$`)@```#H6`0`X````818!`!H`
M``":%@$`*@```+46`0`[````X!8!`"@````<%P$`-````$47`0`9````>A<!
M`!4```"4%P$`!0```*H7`0`'````L!<!``@```"X%P$`!P```,$7`0`%````
MR1<!``<```#/%P$`#@```-<7`0`)````YA<!``8```#P%P$`"````/<7`0`+
M`````!@!``<````,&`$`"````!08`0`'````'1@!`!8````E&`$`"0```#P8
M`0`&````1A@!``L```!-&`$`$````%D8`0`<````:A@!`!0```"'&`$`!P``
M`)P8`0`1````I!@!``@```"V&`$`#@```+\8`0`(````SA@!``4```#7&`$`
M$````-T8`0`0````[A@!``8```#_&`$`&0````89`0`*````(!D!`!P````K
M&0$`!P```$@9`0`%````4!D!`!````!6&0$`%````&<9`0`+````?!D!``T`
M``"(&0$`*````)89`0`8````OQD!`!<```#8&0$`!````/`9`0`)````]1D!
M``H```#_&0$`!P````H:`0`"````$AH!``X````5&@$`"````"0:`0`C````
M+1H!`!\```!1&@$`.````'$:`0`F````JAH!`#$```#1&@$`)P````,;`0!D
M````*QL!`!0```"0&P$`50```*4;`0`X````^QL!`$H````T'`$`6P```'\<
M`0`H````VQP!`#@````$'0$`*````#T=`0`L````9AT!`"8```"3'0$`&P``
M`+H=`0`^````UAT!`*D!```5'@$`(P```+\?`0`7````XQ\!`$@```#['P$`
MA0```$0@`0`P````RB`!`"4```#[(`$`00```"$A`0!;````8R$!`$D```"_
M(0$`,0````DB`0`=````.R(!`!@```!9(@$`*P```'(B`0`A````GB(!`!\`
M``#`(@$`*P```.`B`0`F````#",!`"<````S(P$`.@```%LC`0`=````EB,!
M`!$```"T(P$`,P```,8C`0`E````^B,!`"<````@)`$`(````$@D`0`?````
M:20!`#````"))`$`:0```+HD`0`Q````)"4!`$$```!6)0$`,P```)@E`0`E
M````S"4!`#T```#R)0$`90```#`F`0!-````EB8!`"\```#D)@$`+@```!0G
M`0`P````0R<!`%0```!T)P$`6@```,DG`0!(````)"@!`$H```!M*`$`,@``
M`+@H`0`O````ZR@!`"P````;*0$`+0```$@I`0!Q````=BD!`&8```#H*0$`
M;P```$\J`0"S````ORH!`!<```!S*P$`)0```(LK`0`R````L2L!`"D```#D
M*P$`/@````XL`0`B````32P!`%(```!P+`$`)0```,,L`0`+````Z2P!`+$`
M``#U+`$`10```*<M`0`A````[2T!`#`````/+@$`)0```$`N`0`<````9BX!
M`#$```"#+@$`!P```+4N`0`'````O2X!``0```#%+@$`#0```,HN`0`+````
MV"X!``X```#D+@$`"P```/,N`0`%````_RX!`!`````%+P$``@```!8O`0!9
M````&2\!``4```!S+P$`$@```'DO`0`$````C"\!``<```"1+P$`"````)DO
M`0`%````HB\!``,```"H+P$`$````*PO`0`,````O2\!`!,```#*+P$`#0``
M`-XO`0`"````["\!``<```#O+P$`!@```/<O`0`4````_B\!``P````3,`$`
M&````"`P`0`&````.3`!`!(```!`,`$`#````%,P`0`#````8#`!`"H```!D
M,`$`!````(\P`0`&````E#`!``<```";,`$`'P```*,P`0`U````PS`!`"X`
M``#Y,`$`+P```"@Q`0`7````6#$!`"(```!P,0$`)0```),Q`0`@````N3$!
M`!L```#:,0$`&````/8Q`0`D````#S(!`!\````T,@$`&@```%0R`0`A````
M;S(!`"````"1,@$`&@```+(R`0`R````S3(!`!H`````,P$`+P```!LS`0`K
M````2S,!`!\```!W,P$`(P```)<S`0`?````NS,!`!H```#;,P$`(0```/8S
M`0`E````&#0!`"8````^-`$`)0```&4T`0`D````BS0!`!@```"P-`$`'0``
M`,DT`0`D````YS0!`!@````,-0$`(@```"4U`0`L````2#4!`"\```!U-0$`
M%0```*4U`0`E````NS4!`#P```#A-0$`'P```!XV`0`C````/C8!`!\```!B
M-@$`(````((V`0`:````HS8!`!@```"^-@$`)@```-<V`0`>````_C8!`"D`
M```=-P$`'@```$<W`0`Q````9C<!``D```"8-P$`#````*(W`0`7````KS<!
M`"\```#'-P$`)````/<W`0`'````'#@!``\````D.`$`%````#0X`0`.````
M23@!``T```!8.`$`)````&8X`0`%````BS@!``<```"1.`$`(@```)DX`0`E
M````O#@!`!H```#B.`$`'0```/TX`0`:````&SD!``<````V.0$`QP```#XY
M`0`+````!CH!`!4````2.@$`!@```"@Z`0`)````+SH!``L````Y.@$`#0``
M`$4Z`0`7````4SH!``8```!K.@$`,P```'(Z`0`3````ICH!`!,```"Z.@$`
M!P```,XZ`0`/````UCH!``<```#F.@$`,@```.XZ`0`$````(3L!`"$````F
M.P$`$P```$@[`0`,````7#L!`!$```!I.P$`,@```'L[`0`6````KCL!``@`
M``#%.P$`'0```,X[`0`)````[#L!``H```#V.P$`%`````$\`0`*````%CP!
M`!T````A/`$`"````#\\`0`?````2#P!``@```!H/`$`&@```'$\`0`G````
MC#P!``8```"T/`$`%0```+L\`0`'````T3P!``@```#9/`$`"0```.(\`0`_
M````[#P!``<````L/0$`#P```#0]`0`.````1#T!`!````!3/0$`"0```&0]
M`0`)````;CT!``@```!X/0$`$P```($]`0`'````E3T!`!D```"=/0$`"@``
M`+<]`0`7````PCT!`!0```#:/0$`"@```.\]`0`,````^CT!`!<````'/@$`
M!````!\^`0`J````)#X!``P```!//@$`$0```%P^`0`'````;CX!``(```!V
M/@$`$````'D^`0`8````BCX!``,```"C/@$`"````*<^`0`&````L#X!``<`
M``"W/@$`#0```+\^`0`+````S3X!`!0```#9/@$`%0```.X^`0`.````!#\!
M`"\````3/P$`(````$,_`0`<````9#\!`!4```"!/P$`#````)<_`0`Q````
MI#\!``4```#6/P$`$@```-P_`0`_````[S\!`!(````O0`$`"@```$)``0`&
M````34`!``0```!40`$`!````%E``0`*````7D`!`!,```!I0`$`!0```'U`
M`0`&````@T`!``8```"*0`$`"````)%``0`$````FD`!``P```"?0`$`"@``
M`*Q``0`Y````MT`!`"X```#Q0`$`*0```"!!`0`%````2D$!`!@```!000$`
M&0```&E!`0`?````@T$!`!T```"C00$`$0```,%!`0`"````TT$!``0```#6
M00$`"@```-M!`0`&````YD$!``4```#M00$``P```/-!`0`,````]T$!`$4`
M```$0@$`,@```$I"`0`:````?4(!`#0```"80@$`*````,U"`0!3````]D(!
M`!D```!*0P$`<@```&1#`0`@````UT,!`#4```#X0P$`(0```"Y$`0!%````
M4$0!`#````"61`$`*````,=$`0`I````\$0!`"8````:10$`)0```$%%`0`H
M````9T4!`"@```"010$`(@```+E%`0`K````W$4!`#`````(1@$`$@```#E&
M`0`3````3$8!`!````!@1@$`>0```'%&`0`)````ZT8!`*$```#U1@$`<P``
M`)='`0!\````"T@!`"L```"(2`$`5````+1(`0`7````"4D!`"<````A20$`
M%@```$E)`0`/````8$D!`!<```!P20$`'P```(A)`0!`````J$D!`!\```#I
M20$`'`````E*`0!1````)DH!`!H```!X2@$`%````)-*`0`*````J$H!``4`
M``"S2@$`!@```+E*`0`(````P$H!`!(```#)2@$`$````-Q*`0`3````[4H!
M`!T````!2P$`#P```!]+`0`/````+TL!``0````_2P$`"P```$1+`0`'````
M4$L!``4```!82P$`%````%Y+`0`'````<TL!``@```![2P$`#P```(1+`0`(
M````E$L!``P```"=2P$`#P```*I+`0`&````NDL!`!0```#!2P$`!@```-9+
M`0`,````W4L!`!$```#J2P$`"````/Q+`0`$````!4P!`!D````*3`$`$0``
M`"1,`0`*````-DP!`!@```!!3`$`$P```%I,`0`<````;DP!`!$```"+3`$`
M!````)U,`0`/````HDP!``<```"R3`$`!````+I,`0`9````OTP!``<```#9
M3`$``@```.%,`0`1````Y$P!``D```#V3`$`$@````!-`0`7````$TT!``8`
M```K30$`)P```#)-`0`$````6DT!``\```!?30$`$P```&]-`0`'````@TT!
M``<```"+30$`$0```)--`0`&````I4T!`!@```"L30$`!@```,5-`0`3````
MS$T!`!````#@30$`$@```/%-`0`&````!$X!``P````+3@$`"0```!A.`0`1
M````(DX!`"(````T3@$`!P```%=.`0`+````7TX!``4```!K3@$``@```'%.
M`0!C`0``=$X!`!0```#83P$`$P```.U/`0`/`````5`!``4````14`$`"0``
M`!=0`0`)````(5`!``,````K4`$`%````"]0`0`<````1%`!`"P```!A4`$`
M*P```(Y0`0`A````NE`!`"T```#<4`$`'`````I1`0`S````)U$!``L```!;
M40$`+````&=1`0`4````E%$!`!,```"I40$`"P```+U1`0`H````R5$!``P`
M``#R40$`%0```/]1`0`;````%5(!`"$````Q4@$`"@```%-2`0"#````7E(!
M`!8```#B4@$`!P```/E2`0`1`````5,!`!4````34P$`#@```"E3`0`*````
M.%,!``\```!#4P$`$0```%-3`0":````95,!``T`````5`$`%0````Y4`0`9
M````)%0!``\````^5`$`$````$Y4`0`0````7U0!``8```!P5`$`!@```'=4
M`0`\````?E0!`!X```"[5`$`.0```-I4`0!,````%%4!`&L```!A50$`9P``
M`,U5`0!Q````-58!`&T```"G5@$`/````!57`0`2````4E<!`!,```!E5P$`
M#````'E7`0`1````AE<!`!(```"85P$`!0```*M7`0`K````L5<!`!(```#=
M5P$`"@```/!7`0`)````^U<!``H````%6`$`,P```!!8`0`M````1%@!`!D`
M``!R6`$`!@```(Q8`0`A````DU@!``D```"U6`$`!P```+]8`0`5````QU@!
M`"(```#=6`$`$0````!9`0`6````$ED!`!H````I60$`'0```$19`0`J````
M8ED!`!L```"-60$`%````*E9`0`2````OED!`!$```#160$`+@```.-9`0`<
M````$EH!`!T````O6@$`&0```$U:`0!E````9UH!`$(```#-6@$`,````!!;
M`0`#````05L!``H```!%6P$`/````%!;`0`.````C5L!``H```"<6P$`"P``
M`*=;`0`'````LUL!``<```"[6P$`!0```,-;`0`*````R5L!``D```#46P$`
M"P```-Y;`0`=````ZEL!``X````(7`$`$@```!=<`0`@````*EP!`!L```!+
M7`$`,P```&=<`0`+````FUP!`!\```"G7`$`$@```,=<`0`>````VEP!``\`
M``#Y7`$`$P````E=`0`2````'5T!``\````P70$`(@```$!=`0`8````8UT!
M``<```!\70$`!@```(1=`0`(````BUT!`"@```"470$`!@```+U=`0`*````
MQ%T!`!(```#/70$`"@```.)=`0`4````[5T!`!,````"7@$`+0```!9>`0`*
M````1%X!`!$```!/7@$`!P```&%>`0`3````:5X!`!P```!]7@$`&@```)I>
M`0`]````M5X!`#H```#S7@$`"0```"Y?`0`,````.%\!`!(```!%7P$`"```
M`%A?`0`%````85\!``<```!G7P$`#````&]?`0`:````?%\!`$D```"77P$`
M%P```.%?`0`I````^5\!`"T````C8`$`-````%%@`0`Y````AF`!``T```#`
M8`$`"0```,Y@`0`*````V&`!``@```#C8`$`-````.Q@`0!(````(6$!`#,`
M``!J80$`7@```)YA`0`R````_6$!`#(````P8@$`10```&-B`0`^````J6(!
M`#(```#H8@$`1@```!MC`0`N````8F,!`#L```"18P$`0@```,UC`0`R````
M$&0!`#@```!#9`$`.@```'QD`0`E````MV0!`"@```#=9`$`.0````9E`0`Z
M````0&4!`#D```![90$`&P```+5E`0`,````T64!`"````#>90$`!@```/]E
M`0`+````!F8!`!X````29@$`)@```#%F`0`'````6&8!``<```!@9@$`$P``
M`&AF`0`)````?&8!``@```"&9@$`-0```(]F`0`+````Q68!`!````#19@$`
M!P```.)F`0`&````ZF8!``4```#Q9@$`!P```/=F`0`&````_V8!``L````&
M9P$`+0```!)G`0`6````0&<!`!(```!79P$`"````&IG`0`'````<V<!`!``
M``![9P$`!0```(QG`0`/````DF<!``<```"B9P$`$P```*IG`0`)````OF<!
M``@```#(9P$`!````-%G`0`-````UF<!``@```#D9P$`&@```.UG`0`1````
M"&@!``@````::`$`"@```"-H`0`,````+F@!``<````[:`$`%0```$-H`0`#
M````66@!`"P```!=:`$`$P```(IH`0`I````GF@!``8```#(:`$`!P```,]H
M`0`)````UV@!``<```#A:`$`0````.EH`0`>````*FD!`#L```!):0$`*@``
M`(5I`0`D````L&D!``8```#5:0$`!0```-QI`0`:````XFD!`"$```#]:0$`
M/P```!]J`0`[````7VH!`",```";:@$`(@```+]J`0!7````XFH!`"P````Z
M:P$`$@```&=K`0`*````>FL!``L```"%:P$`%P```)%K`0`/````J6L!``T`
M``"Y:P$`$@```,=K`0`2````VFL!`!(```#M:P$`$P````!L`0`-````%&P!
M`!,````B;`$`!0```#9L`0`9````/&P!`!H```!6;`$`%P```'%L`0`9````
MB6P!`"0```"C;`$`!````,AL`0`+````S6P!`!,```#9;`$`1````.UL`0!<
M````,FT!``@```"/;0$`$@```)AM`0`%````JVT!``0```"Q;0$`'@```+9M
M`0`9````U6T!`!T```#O;0$`$0````UN`0`>````'VX!`"T````^;@$`-@``
M`&QN`0`2````HVX!`"@```"V;@$`!@```-]N`0`9````YFX!`!0`````;P$`
M%@```!5O`0`5````+&\!`!\```!";P$`$````&)O`0`D````<V\!`"@```"8
M;P$`$0```,%O`0`)````TV\!`!$```#=;P$`"@```.]O`0`/````^F\!`!T`
M```*<`$`$0```"AP`0`(````.G`!``0```!#<`$`#````$AP`0`-````57`!
M``D```!C<`$`$0```&UP`0`&````?W`!``<```"&<`$`$````(YP`0`*````
MGW`!``X```"J<`$`#P```+EP`0`#````R7`!``P```#-<`$`$0```-IP`0`1
M````['`!`!T```#^<`$`6````!QQ`0`@````=7$!`!$```"6<0$`%0```*AQ
M`0`%````OG$!`!\```#$<0$`%P```.1Q`0`8````_'$!`#8````5<@$`0P``
M`$QR`0`L````D'(!``D```"]<@$`-````,=R`0`>````_'(!``T````;<P$`
M"0```"ES`0`-````,W,!``0```!!<P$`"P```$9S`0`:````4G,!`!@```!M
M<P$`%````(9S`0`*````FW,!`!````"F<P$`+````+=S`0`O````Y',!`#X`
M```4=`$`,0```%-T`0`L````A70!`!X```"R=`$`1````-%T`0`L````%G4!
M`#X```!#=0$`+````()U`0`]````KW4!`#\```#M=0$`(@```"UV`0`H````
M4'8!`#<```!Y=@$`,0```+%V`0`M````XW8!`"\````1=P$`/````$%W`0`B
M````?G<!`"<```"A=P$`/P```,EW`0`K````"7@!`!P````U>`$`*0```%)X
M`0`F````?'@!`!X```"C>`$`$0```,)X`0#$````U'@!`#H```"9>0$`*0``
M`-1Y`0`K````_GD!`"T````J>@$`+P```%AZ`0`U````B'H!`",```"^>@$`
M*````.)Z`0`N````"WL!`#$````Z>P$`.0```&Q[`0`T````IGL!`)````#;
M>P$`-````&Q\`0`8````H7P!`"T```"Z?`$`*P```.A\`0`O````%'T!`$0`
M``!$?0$`2@```(E]`0`/````U'T!``8```#D?0$`"@```.M]`0`*````]GT!
M`!`````!?@$`#@```!)^`0`4````(7X!`"@````V?@$`#P```%]^`0`,````
M;WX!``0```!\?@$`$0```(%^`0`B````DWX!``H```"V?@$`#P```,%^`0`6
M````T7X!`!(```#H?@$`'@```/M^`0`0````&G\!`$L````K?P$`!P```'=_
M`0`8````?W\!``8```"8?P$`#P```)]_`0`5````KW\!`!4```#%?P$`$```
M`-M_`0`"````['\!`%T```#O?P$`!P```$V``0`1````58`!`!D```!G@`$`
M!0```(&``0`1````AX`!`!(```"9@`$`!@```*R``0`.````LX`!``@```#"
M@`$`!@```,N``0`0````TH`!``\```#C@`$`'P```/.``0`A````$X$!`!4`
M```U@0$`"@```$N!`0`&````5H$!``\```!=@0$`$0```&V!`0`7````?X$!
M`!4```"7@0$`#P```*V!`0`/````O8$!`!$```#-@0$`*````-^!`0`1````
M"((!`!T````:@@$`/@```#B"`0`-````=X(!`"````"%@@$`$P```*:"`0`:
M````NH(!`!<```#5@@$`*P```.V"`0`2````&8,!``4````L@P$`&P```#*#
M`0`&````3H,!`"\```!5@P$`00```(6#`0`*````QX,!``H```#2@P$`%0``
M`-V#`0`,````\X,!`!(`````A`$`$@```!.$`0`&````)H0!`#(````MA`$`
M&0```&"$`0`E````>H0!`"8```"@A`$`%@```,>$`0`F````WH0!``@````%
MA0$`"P````Z%`0`L````&H4!`$````!'A0$`"````(B%`0`5````D84!`"<`
M``"GA0$`"````,^%`0`/````V(4!`#T```#HA0$`#P```":&`0`,````-H8!
M``4```!#A@$`40```$F&`0`$````FX8!``<```"@A@$`"0```*B&`0`/````
MLH8!`!$```#"A@$`%0```-2&`0`8````ZH8!`!X````#AP$`'0```"*'`0`@
M````0(<!`!X```!AAP$`!P```("'`0`(````B(<!``@```"1AP$`!P```)J'
M`0`6````HH<!``4```"YAP$`"0```+^'`0`A````R8<!`!<```#KAP$`$```
M``.(`0`.````%(@!``P````CB`$`#````#"(`0`9````/8@!`$,```!7B`$`
M-@```)N(`0`,````TH@!`!8```#?B`$`>@```/:(`0`:````<8D!`!H```",
MB0$`$0```*>)`0`'````N8D!``0```#!B0$`)P```,:)`0`V````[HD!`#T`
M```EB@$`(@```&.*`0`L````AHH!`!@```"SB@$`)P```,R*`0`*````](H!
M``<```#_B@$`#`````>+`0`&````%(L!``T````;BP$`#````"F+`0`2````
M-HL!``P```!)BP$`%P```%:+`0`+````;HL!``H```!ZBP$`#@```(6+`0`+
M````E(L!``P```"@BP$`'P```*V+`0`;````S8L!`$T```#IBP$`%P```#>,
M`0`&````3XP!``0```!6C`$`)P```%N,`0`Q````@XP!`!X```"UC`$`'0``
M`-2,`0`K````\HP!`"H````>C0$`+````$F-`0`M````=HT!`!P```"DC0$`
M!@```,&-`0`<````R(T!``X```#EC0$`%P```/2-`0`#````#(X!``,````0
MC@$`!P```!2.`0`0````'(X!`!(````MC@$`#0```$".`0`6````3HX!``L`
M``!EC@$`)@```'&.`0`&````F(X!``0```"?C@$`$@```*2.`0`2````MXX!
M``X```#*C@$`!P```-F.`0`.````X8X!``\```#PC@$`(0````"/`0`&````
M(H\!``H````ICP$`"````#2/`0`+````/8\!`!8```!)CP$`$0```&"/`0`#
M````<H\!`!0```!VCP$`"````(N/`0`&````E(\!`#D```";CP$`&````-6/
M`0",````[H\!`!D```![D`$`#````)60`0`&````HI`!``X```"ID`$`"```
M`+B0`0`*````P9`!``<```#,D`$`#````-20`0`"````X9`!``@```#DD`$`
M#0```.V0`0`-````^Y`!``X````)D0$`$0```!B1`0`6````*I$!``8```!!
MD0$`!P```$B1`0`0````4)$!``@```!AD0$`"@```&J1`0`%````=9$!`"``
M``![D0$`"P```)R1`0`&````J)$!`"0```"OD0$`$0```-21`0`&````YI$!
M``L```#MD0$`!0```/F1`0`)````_Y$!``H````)D@$`%````!22`0`%````
M*9(!``4````OD@$`#0```#62`0`.````0Y(!``P```!2D@$`"P```%^2`0`2
M````:Y(!``@```!^D@$`!P```(>2`0`6````CY(!`!P```"FD@$`0P```,.2
M`0`K````!Y,!`#@````SDP$`"0```&R3`0`*````=I,!``0```"!DP$`"0``
M`(:3`0`(````D),!`!0```"9DP$`"P```*Z3`0`&````NI,!``T```#!DP$`
M!@```,^3`0!`````UI,!`$4````7E`$`0@```%V4`0`K````H)0!``4```#,
ME`$`#P```-*4`0`#````XI0!``8```#FE`$`!@```.V4`0`;````])0!``P`
M```0E0$`%````!V5`0`(````,I4!``@````[E0$`(P```$25`0`(````:)4!
M``<```!QE0$`$````'F5`0`$````BI4!``@```"/E0$`#````)B5`0`(````
MI94!``L```"NE0$`%````+J5`0`/````SY4!``@```#?E0$`"````.B5`0`%
M````\94!`#0```#WE0$`-P```"R6`0`W````9)8!`"P```"<E@$`10```,F6
M`0!#````#Y<!`"\```!3EP$`6````(.7`0`T````W)<!`$H````1F`$`+0``
M`%R8`0`0````BI@!`!````";F`$`"P```*R8`0`C````N)@!`"0```#<F`$`
M%P````&9`0`@````&9D!``P````ZF0$`#@```$>9`0`*````5ID!``P```!A
MF0$`+@```&Z9`0`J````G9D!`#\```#(F0$`!@````B:`0`>````#YH!`#``
M```NF@$`'````%^:`0`6````?)H!``8```"3F@$`"P```)J:`0`*````IIH!
M`!````"QF@$`)0```,*:`0!&````Z)H!`)$````OFP$`=````,&;`0`/````
M-IP!``P```!&G`$`#0```%.<`0`;````89P!`!<```!]G`$`#@```)6<`0`%
M````I)P!`!4```"JG`$`%0```,"<`0`3````UIP!`!8```#JG`$`%P````&=
M`0`T````&9T!`(T```!.G0$`$````-R=`0`%````[9T!`!(```#SG0$`"0``
M``:>`0`*````$)X!``H````;G@$`*````":>`0`7````3YX!`!````!GG@$`
M%0```'B>`0`0````CIX!`!8```"?G@$`%P```+:>`0`6````SIX!`!,```#E
MG@$`$P```/F>`0`<````#9\!`!L````JGP$`(````$:?`0`_````9Y\!`!D`
M``"GGP$`&````,&?`0`7````VI\!`!8```#RGP$`$@````F@`0`<````'*`!
M`!L````YH`$`$P```%6@`0`3````::`!`#````!]H`$`&P```*Z@`0`<````
MRJ`!`$(```#GH`$`'P```"JA`0`%````2J$!`!0```!0H0$`+0```&6A`0`C
M````DZ$!`"$```"WH0$`)@```-FA`0`E`````*(!`!T````FH@$`(P```$2B
M`0`C````:*(!`!P```",H@$`(@```*FB`0!!````S*(!`"(````.HP$`)P``
M`#&C`0`G````6:,!`"````"!HP$`(````**C`0`C````PZ,!`"D```#GHP$`
M(@```!&D`0`C````-*0!``T```!8I`$`%P```&:D`0`8````?J0!``0```"7
MI`$`"````)RD`0`*````I:0!`!0```"PI`$`!@```,6D`0`5````S*0!``0`
M``#BI`$`"P```.>D`0`'````\Z0!``8```#[I`$`!0````*E`0`3````"*4!
M``8````<I0$`"````".E`0`&````+*4!``8````SI0$`"@```#JE`0`0````
M1:4!`!H```!6I0$`$````'&E`0`1````@J4!``H```"4I0$`&````)^E`0`%
M````N*4!`#D```"^I0$`%@```/BE`0`1````#Z8!`!$````AI@$`#@```#.F
M`0`+````0J8!`!(```!.I@$`+P```&&F`0`(````D:8!``@```":I@$`)```
M`*.F`0`2````R*8!``\```#;I@$`!@```.NF`0`,````\J8!``D```#_I@$`
M!0````FG`0`D````#Z<!``H````TIP$`%@```#^G`0`-````5J<!`!,```!D
MIP$`&````'BG`0`C````D:<!`"<```"UIP$`"@```-VG`0`#````Z*<!``H`
M``#LIP$`(@```/>G`0`'````&J@!``,````BJ`$`$0```":H`0`2````.*@!
M``<```!+J`$`!0```%.H`0`'````6:@!`"H```!AJ`$`#0```(RH`0`2````
MFJ@!``H```"MJ`$`$P```+BH`0`7````S*@!``P```#DJ`$`#@```/&H`0`.
M`````*D!``X````/J0$`!````!ZI`0`1````(ZD!`$,````UJ0$`!@```'FI
M`0`%````@*D!`"<```"&J0$`%@```*ZI`0`T````Q:D!`!4```#ZJ0$`#@``
M`!"J`0`3````'ZH!``\````SJ@$`$````$.J`0`/````5*H!`!X```!DJ@$`
M'P```(.J`0`U````HZH!`"L```#9J@$`)@````6K`0`(````+*L!``@````U
MJP$`"P```#ZK`0`+````2JL!`!$```!6JP$`!````&BK`0`-````;:L!`"H`
M``![JP$`#0```*:K`0`-````M*L!`"8```#"JP$`40```.FK`0`=````.ZP!
M``T```!9K`$`"````&>L`0`(````<*P!``X```!YK`$`#@```(BL`0`5````
MEZP!``D```"MK`$``@```+>L`0`-````NJP!`",```#(K`$`!@```.RL`0`%
M````\ZP!``D```#YK`$`"P````.M`0`)````#ZT!``D````9K0$`%````".M
M`0`.````.*T!``8```!'K0$`"````$ZM`0`/````5ZT!``0```!GK0$`!0``
M`&RM`0!K````<JT!``P```#>K0$`#P```.NM`0`@````^ZT!``<````<K@$`
M!0```"2N`0`J````*JX!`#$```!5K@$`$0```(>N`0`*````F:X!`!D```"D
MK@$`"@```+ZN`0`)````R:X!`"H```#3K@$`'@```/ZN`0`I````':\!`"@`
M``!'KP$`*P```'"O`0`/````G*\!``4```"LKP$`!P```+*O`0`-````NJ\!
M``4```#(KP$`$P```,ZO`0`6````XJ\!``8```#YKP$`60````"P`0`>````
M6K`!`!````!YL`$`%@```(JP`0`D````H;`!`&8```#&L`$`&````"VQ`0`'
M````1K$!`!\```!.L0$`,````&ZQ`0`(````G[$!``8```"HL0$`'@```*^Q
M`0`%````SK$!``H```#4L0$`+@```-^Q`0`M````#K(!`#L````\L@$`$P``
M`'BR`0`&````C+(!`"0```"3L@$`5@```+BR`0`?````#[,!`!P````OLP$`
M.0```$RS`0`"````AK,!`!D```")LP$`!P```*.S`0`2````J[,!`!$```"^
MLP$`!P```-"S`0`4````V+,!``8```#MLP$`"````/2S`0`+````_;,!``<`
M```)M`$`"@```!&T`0`+````'+0!`"P````HM`$`!P```%6T`0`0````7;0!
M`!````!NM`$`#P```'^T`0`)````C[0!``P```"9M`$`#0```*:T`0`*````
MM+0!``D```"_M`$`"@```,FT`0`(````U+0!`!L```#=M`$`'@```/FT`0`4
M````&+4!`!H````MM0$`%@```$BU`0`6````7[4!`"````!VM0$`!P```)>U
M`0`6````G[4!``,```"VM0$`!P```+JU`0`%````PK4!``4```#(M0$`"0``
M`,ZU`0`0````V+4!`!(```#IM0$`,P```/RU`0`N````,+8!`"(```!?M@$`
M)````(*V`0`7````I[8!`!\```"_M@$`&0```-^V`0`'````^;8!``0````!
MMP$`#`````:W`0`,````$[<!`!$````@MP$`!@```#*W`0`>````.;<!``D`
M``!8MP$`"0```&*W`0`K````;+<!`"4```"8MP$`#P```+ZW`0`%````SK<!
M``P```#4MP$`"0```.&W`0`1````Z[<!`!````#]MP$`"@````ZX`0`)````
M&;@!``4````CN`$`!P```"FX`0`'````,;@!``0````YN`$``P```#ZX`0!9
M````0K@!`"T```"<N`$`1````,JX`0`;````#[D!`#T````KN0$`#P```&FY
M`0!`````>;D!`"D```"ZN0$`'@```.2Y`0`>`````[H!`",````BN@$`-@``
M`$:Z`0`-````?;H!`#````"+N@$`&0```+RZ`0`5````UKH!`!4```#LN@$`
M#P````*[`0`4````$KL!`!4````GNP$`(0```#V[`0`]````7[L!`#X```"=
MNP$`00```-R[`0`^````'KP!`#\```!=O`$`/0```)V\`0!M````V[P!`!X`
M``!)O0$`%@```&B]`0`:````?[T!`"4```":O0$`#P```,"]`0`0````T+T!
M`#L```#AO0$`*P```!V^`0`M````2;X!``H```!WO@$`*0```(*^`0`K````
MK+X!``4```#8O@$`)@```-Z^`0`6````!;\!``X````<OP$`#@```"N_`0`7
M````.K\!``@```!2OP$`"@```%N_`0`,````9K\!``X```!SOP$`+P```(*_
M`0`/````LK\!``\```#"OP$`#````-*_`0`F````W[\!``@````&P`$`!```
M``_``0`0````%,`!``X````EP`$`"P```#3``0`U````0,`!``(```!VP`$`
M"````'G``0`7````@L`!``P```":P`$`!P```*?``0`&````K\`!`!$```"V
MP`$`*P```,C``0`-````],`!`!P````"P0$`!````!_!`0`W````),$!`",`
M``!<P0$`'@```(#!`0!W````G\$!`!<````7P@$`2````"_"`0`G````>,(!
M`!(```"@P@$`!@```+/"`0`.````NL(!`!0```#)P@$`"0```-["`0`1````
MZ,(!``X```#ZP@$`'@````G#`0`5````*,,!``4````^PP$`$````$3#`0`:
M````5<,!`#(```!PPP$`%0```*/#`0`5````N<,!`!@```#/PP$`$P```.C#
M`0`?````_,,!``<````<Q`$`%P```"3$`0`+````/,0!`!0```!(Q`$`%```
M`%W$`0`6````<L0!`!````")Q`$`%@```)K$`0`8````L<0!``L```#*Q`$`
M"0```-;$`0`%````X,0!`!T```#FQ`$`!@````3%`0`/````"\4!``@````;
MQ0$`$@```"3%`0`&````-\4!`"0````^Q0$`%````&/%`0`S````>,4!`!4`
M``"LQ0$`!P```,+%`0`(````RL4!`!X```#3Q0$`"P```/+%`0`;````_L4!
M``<````:Q@$`(P```"+&`0`'````1L8!``@```!.Q@$`)````%?&`0`[````
M?,8!``L```"XQ@$`)0```,3&`0`G````ZL8!``T````2QP$`&@```"#'`0`0
M````.\<!``0```!,QP$`#@```%''`0`.````8,<!``<```!OQP$`#@```'?'
M`0`(````AL<!``4```"/QP$`"0```)7'`0`=````G\<!`"8```"]QP$`/P``
M`.3'`0`H````),@!`"4```!-R`$`'P```'/(`0`[````D\@!`!X```#/R`$`
M*@```.[(`0`R````&<D!`%T```!,R0$`)0```*K)`0`-````T,D!``@```#>
MR0$`"@```.?)`0`*````\LD!`!$```#]R0$`%@````_*`0!'````)LH!`"4`
M``!NR@$`&@```)3*`0`X````K\H!`$````#HR@$`"0```"G+`0`F````,\L!
M``L```!:RP$`%````&;+`0`G````>\L!``P```"CRP$`&0```+#+`0`,````
MRLL!``X```#7RP$`#@```.;+`0`/````]<L!`!`````%S`$`#P```!;,`0`;
M````)LP!`!H```!"S`$`-0```%W,`0`+````D\P!`!H```"?S`$`!0```+K,
M`0`5````P,P!``4```#6S`$`'@```-S,`0`7````^\P!``,````3S0$`#```
M`!?-`0`0````),T!``4````US0$`#@```#O-`0`(````2LT!``\```!3S0$`
M!0```&/-`0`'````:<T!`!````!QS0$`20```(+-`0!0````S,T!`"<````=
MS@$`"0```$7.`0`R````3\X!`"L```""S@$`$0```*[.`0`)````P,X!``P`
M``#*S@$`$````-?.`0`R````Z,X!``8````;SP$`#0```"+/`0`.````,,\!
M`!4````_SP$`#0```%7/`0!<````8\\!``H```#`SP$`)0```,O/`0`5````
M\<\!`!8````'T`$`+````![0`0`F````2]`!`#X```!RT`$`00```+'0`0`[
M````\]`!``X````OT0$`!0```#[1`0`3````1-$!`!P```!8T0$`(````'71
M`0`(````EM$!`!,```"?T0$`&P```+/1`0`'````S]$!`!\```#7T0$`%P``
M`/?1`0`0````#](!``0````@T@$`$@```"72`0`3````.-(!`!0```!,T@$`
M!@```&'2`0`'````:-(!`!,```!PT@$`#@```(32`0`/````D](!`!$```"C
MT@$`$0```+72`0`&````Q](!``<```#.T@$`*````-;2`0`D````_](!`"``
M```DTP$`"````$73`0`/````3M,!``8```!>TP$`&````&73`0`I````?M,!
M`"D```"HTP$`"@```-+3`0`8````W=,!``,```#VTP$`"````/K3`0`#````
M`]0!`!(````'U`$`%````!K4`0`+````+]0!`!@````[U`$`(P```%34`0`7
M````>-0!``8```"0U`$`"@```)?4`0`4````HM0!`!<```"WU`$`#````,_4
M`0`&````W-0!``P```#CU`$`"@```/#4`0`5````^]0!`'D````1U0$`'P``
M`(O5`0`O````J]4!`!0```#;U0$`"````/#5`0`'````^=4!`!<````!U@$`
M%P```!G6`0`8````,=8!`"(```!*U@$`'0```&W6`0`2````B]8!`"4```">
MU@$`$0```,36`0`F````UM8!`!@```#]U@$`%P```!;7`0"#````+M<!`"@`
M``"RUP$`'P```-O7`0`X````^]<!`"<````TV`$`'@```%S8`0`K````>]@!
M`",```"GV`$`)P```,O8`0`4````\]@!``L````(V0$`"````!39`0`)````
M'=D!``H````GV0$`%0```#+9`0`+````2-D!`#L```!4V0$`*0```)#9`0`W
M````NMD!`!8```#RV0$`!@````G:`0!%````$-H!`%4```!6V@$`-````*S:
M`0"<````X=H!``L```!^VP$`-P```(K;`0`O````PML!`!(```#RVP$`"```
M``7<`0`3````#MP!`$0````BW`$`#````&?<`0!8````=-P!`$@```#-W`$`
M*````!;=`0`4````/]T!`"(```!4W0$`(@```'?=`0`L````FMT!`"(```#'
MW0$`*P```.K=`0`?````%MX!`!4````VW@$`!P```$S>`0`0````5-X!`!0`
M``!EW@$`#0```'K>`0`+````B-X!`%$```"4W@$`#````.;>`0`>````\]X!
M`!$````2WP$`'P```"3?`0`)````1-\!``4```!.WP$`&````%3?`0`)````
M;=\!``D```!WWP$`!P```('?`0`'````B=\!``D```"1WP$`$@```)O?`0`<
M````KM\!``\```#+WP$`'P```-O?`0`0````^]\!``@````,X`$`#0```!7@
M`0`F````(^`!``L```!*X`$`"@```%;@`0`8````8>`!`"8```!ZX`$`#```
M`*'@`0`B````KN`!`"L```#1X`$`"P```/W@`0`(````">$!`"$````2X0$`
M#0```#3A`0`9````0N$!`!L```!<X0$`%````'CA`0`6````C>$!`!(```"D
MX0$`!0```+?A`0`)````O>$!``@```#'X0$`"0```-#A`0`*````VN$!`!0`
M``#EX0$`!P```/KA`0`0`````N(!``H````3X@$`"````![B`0`,````)^(!
M`"$````TX@$`#````%;B`0`"````8^(!`",```!FX@$`!0```(KB`0`*````
MD.(!`'H```";X@$`"@```!;C`0`(````(>,!`"H````JXP$`.@```%7C`0`:
M````D.,!`"X```"KXP$`70```-KC`0`C````..0!`#,```!<Y`$`+P```)#D
M`0`E````P.0!``8```#FY`$`#0```.WD`0`(````^^0!``D````$Y0$`!0``
M``[E`0`(````%.4!`!(````=Y0$`"@```##E`0`)````.^4!``L```!%Y0$`
M"P```%'E`0`:````7>4!``@```!XY0$`"0```('E`0`5````B^4!``H```"A
MY0$`"@```*SE`0`%````M^4!`"X```"]Y0$`)@```.SE`0`8````$^8!``<`
M```LY@$`$@```#3F`0`)````1^8!``\```!1Y@$`,P```&'F`0`(````E>8!
M`!@```">Y@$`&````+?F`0`&````T.8!``8```#7Y@$`#0```-[F`0`<````
M[.8!``8````)YP$`"0```!#G`0`+````&N<!`!P````FYP$`"P```$/G`0`-
M````3^<!`"H```!=YP$`'P```(CG`0`8````J.<!``8```#!YP$`"P```,CG
M`0`0````U.<!``T```#EYP$``P```//G`0`.````]^<!``@````&Z`$`'0``
M``_H`0`O````+>@!`#````!=Z`$`*@```([H`0`N````N>@!`"X```#HZ`$`
MC@```!?I`0`6````IND!`&,```"]Z0$`.````"'J`0!A````6NH!`&D```"\
MZ@$`(0```";K`0!-````2.L!`#P```"6ZP$`1P```-/K`0`>````&^P!`!@`
M```Z[`$`(P```%/L`0#]`0``=^P!`!T```!U[@$`'0```)/N`0!)````L>X!
M`*````#[[@$`-````)SO`0`I````T>\!`$<```#[[P$`6@```$/P`0!D````
MGO`!`#(````#\0$`(````#;Q`0`>````5_$!`#0```!V\0$`'````*OQ`0`?
M````R/$!`"0```#H\0$`(`````WR`0`F````+O(!`"\```!5\@$`&@```(7R
M`0`6````H/(!`#$```"W\@$`*@```.GR`0`D````%/,!`#P````Y\P$`&@``
M`';S`0`R````D?,!`'$```#$\P$`.P```#;T`0`Z````<O0!`#(```"M]`$`
M*0```.#T`0!'````"O4!`&T```!2]0$`7P```,#U`0`P````(/8!`#````!1
M]@$`,P```(+V`0!.````MO8!`&8````%]P$`30```&SW`0!3````NO<!`$D`
M```.^`$`)P```%CX`0`G````@/@!`"0```"H^`$`>````,WX`0!M````1OD!
M`'<```"T^0$`S@```"SZ`0`<````^_H!`"P````8^P$`-@```$7[`0`N````
M?/L!`%````"K^P$`'````/S[`0!`````&?P!`#\```!:_`$`!0```)K\`0#(
M````H/P!`$8```!I_0$`(@```+#]`0`^````T_T!`"<````2_@$`'````#K^
M`0`L````5_X!``D```"$_@$`%@```([^`0`#````I?X!`!8```"I_@$`#```
M`,#^`0`-````S?X!``L```#;_@$`!P```.?^`0`-````[_X!``<```#]_@$`
M=0````7_`0`"````>_\!`!8```!^_P$`!````)7_`0`'````FO\!``8```"B
M_P$`!0```*G_`0`%````K_\!`!4```"U_P$`"@```,O_`0`2````UO\!``\`
M``#I_P$``@```/G_`0`'````_/\!``L````$``(`$@```!```@`-````(P`"
M`!D````Q``(`!@```$L``@`9````4@`"``H```!L``(``P```'<``@!;````
M>P`"``0```#7``(`!@```-P``@`'````XP`"`"<```#K``(`3````!,!`@!&
M````8`$"`$<```"G`0(`*@```.\!`@`N````&@("`#$```!)`@(`'0```'L"
M`@`B````F0("`!P```"\`@(`,@```-D"`@`J````#`,"`"0````W`P(`)@``
M`%P#`@`G````@P,"`"X```"K`P(`*P```-H#`@`>````!@0"`"D````E!`(`
M*@```$\$`@`?````>@0"`",```":!`(`(0```+X$`@`9````X`0"`"(```#Z
M!`(`+````!T%`@`R````2@4"`#,```!]!0(`)P```+$%`@`=````V04"`"0`
M``#W!0(`*0```!P&`@`=````1@8"`"<```!D!@(`.````(P&`@`[````Q08"
M`!D````!!P(`(P```!L'`@`Z````/P<"`"(```!Z!P(`)@```)T'`@`D````
MQ`<"`"4```#I!P(`'`````\(`@`D````+`@"`#````!1"`(`'@```(((`@`Q
M````H0@"`"$```#3"`(`-@```/4(`@`)````+`D"`!`````V"0(`(@```$<)
M`@!'````:@D"`"P```"R"0(`#````-\)`@`/````[`D"`!<```#\"0(`$@``
M`!0*`@`0````)PH"`"<````X"@(`!@```&`*`@`*````9PH"`"4```!R"@(`
M*````)@*`@`;````P0H"`"@```#="@(`'`````8+`@`/````(PL"`/0````S
M"P(`%0```"@,`@`7````/@P"``D```!6#`(`%P```&`,`@`B````>`P"`!T`
M``";#`(`'@```+D,`@`)````V`P"`#X```#B#`(`#P```"$-`@`6````,0T"
M``<```!(#0(`&P```%`-`@`1````;`T"`$X```!^#0(`$````,T-`@`B````
MW@T"`!P````!#@(`&````!X.`@`C````-PX"`&$```!;#@(`)P```+T.`@`0
M````Y0X"`"<```#V#@(`$0```!X/`@`2````,`\"`!@```!##P(`"P```%P/
M`@`=````:`\"`"D```"&#P(`'P```+`/`@`+````T`\"`#,```#<#P(`/0``
M`!`0`@`'````3A`"`!,```!6$`(`!P```&H0`@`'````<A`"``D```!Z$`(`
M20```(00`@`&````SA`"``T```#5$`(`$````.,0`@`6````]!`"``L````+
M$0(`#````!<1`@`'````)!$"`!$````L$0(`#P```#X1`@`<````3A$"`!<`
M``!K$0(`%````(,1`@`8````F!$"``P```"Q$0(`#@```+X1`@`L````S1$"
M``X```#Z$0(`-@````D2`@`:````0!("`!````!;$@(`#@```&P2`@`#````
M>Q("`!0```!_$@(`&P```)02`@`#````L!("``D```"T$@(`!P```+X2`@`*
M````QA("``X```#1$@(`#@```.`2`@`;````[Q("`!P````+$P(`#@```"@3
M`@`T````-Q,"`!H```!L$P(`%0```(<3`@`9````G1,"``T```"W$P(`,@``
M`,43`@`)````^!,"`!<````"%`(`5@```!H4`@`5````<10"`!D```"'%`(`
M"@```*$4`@`$````K!0"``0```"Q%`(`%@```+84`@`5````S10"``4```#C
M%`(`!@```.D4`@`*````\!0"``T```#[%`(`!0````D5`@`.````#Q4"`!(`
M```>%0(`/P```#$5`@`R````<14"`"D```"D%0(`(````,X5`@`<````[Q4"
M`",````,%@(`*````#`6`@`@````618"`!4```!Z%@(``@```)`6`@`$````
MDQ8"``T```"8%@(`!@```*86`@`%````K18"``0```"S%@(`$0```+@6`@!X
M````RA8"`"0```!#%P(`+0```&@7`@`O````EA<"`",```#&%P(`2````.H7
M`@`9````,Q@"`(X```!-&`(`(@```-P8`@!4````_Q@"`"$```!4&0(`5P``
M`'89`@`N````SAD"`"D```#]&0(`0````"<:`@`S````:!H"`"\```"<&@(`
M/P```,P:`@`=````#!L"`"4````J&P(`*````%`;`@!-````>1L"`!````#'
M&P(`&P```-@;`@`4````]!L"`'4````)'`(`"@```'\<`@#6````BAP"`(4`
M``!A'0(`?@```.<=`@`X````9AX"`'H```"?'@(`'````!H?`@`W````-Q\"
M`"H```!O'P(`$@```)H?`@`E````K1\"`"0```#3'P(`1@```/@?`@`B````
M/R`"`!P```!B(`(`60```'\@`@`O````V2`"`"8````)(0(`"P```#`A`@`%
M````/"$"``8```!"(0(`"````$DA`@`B````4B$"``X```!U(0(`(````(0A
M`@`H````I2$"``L```#.(0(`#P```-HA`@`+````ZB$"``D```#V(0(`"@``
M```B`@`)````"R("`!8````5(@(`#0```"PB`@`.````.B("`!0```!)(@(`
M!P```%XB`@`.````9B("`!$```!U(@(`#````(<B`@`6````E"("``T```"K
M(@(`"@```+DB`@`4````Q"("``8```#9(@(`!P```.`B`@`E````Z"("`"(`
M```.(P(`#@```#$C`@`0````0","`!(```!1(P(`)````&0C`@`1````B2,"
M``D```";(P(`%0```*4C`@`'````NR,"``0```##(P(`(P```,@C`@`+````
M[","``(```#X(P(`%0```/LC`@`(````$20"`!$````:)`(`$0```"PD`@`$
M````/B0"`$D```!#)`(``P```(TD`@`O````D20"`"\```#!)`(`"P```/$D
M`@`(````_20"`!P````&)0(`!0```",E`@`=````*24"``D```!')0(`)```
M`%$E`@`:````=B4"`"````"1)0(`"P```+(E`@`,````OB4"``P```#+)0(`
M#0```-@E`@`I````YB4"``H````0)@(`'P```!LF`@`%````.R8"``,```!!
M)@(``0```,4%``#"`@``UP4``),"``#Z`P``9`8```````!*!@``V@4``"$$
M``"?````6@,``.(&````````GP$``'$%````````'@,```````!.`0``;P0`
M`/<%``!F`0``\@$``-$#```,!@```````"("``#+`````````%H%``!W!0``
M*P8```````!(`@``M`0``&`#``#=````W`0`````````````K04```````#8
M!@```````*(&``"R`0``H`4``$````#W`0```````/4$``#(````Z`4``&4'
M````````N`$```D&````````````````````````A`8``+8`````````7P0`
M`$L`````````K`$``(`!``#?!@``RP(``+$````@!0``1P```$H#``#,!0``
M9`(``+,$```-`@``MP0``&P"``#H`0```````+T&``!8`@``-0```(8%````
M````/0,```4!``!\````0P4``'H!``!"`0``$@,``#8"```H!P``/0(``)T&
M``!Q````QP4``,0#````````"@$``*H```"[!@```````,$&``!5````90``
M``````````````````````!4`0``>@8``-`!```N`P```P(`````````````
MT0(``!8!``"Z!@``"`````````#L!```EP4```\'`````0`````````````A
M````Y@,``$0```#R!`````````$!``!Y!```,0$``"8"```D`P``$P,``,4!
M``"%`P```````)$%```M`0``6@<``-\```!P`0``QP$``'X$``"X`P``````
M`*$!```,!```<P4``.0#`````````````*0"`````````````&8%``#:`0``
M`04````````,`@``Z0```.T#````````R@0``"@!``#,`@```````*`$``#*
M`P``40```$X$``"E````!P$```````"O`0``S@8``+L#``"V`P``EP,``!X%
M``",``````````0%``"`!0``4@```&8'``#_``````````````"4`0``0P8`
M``````!=!P```````%P#`````````````%P"```&`@``#08``+,%``"5!0``
M`````,T```!@!P``E@0``'P$``!,`P````````````!Z!0``<P<```````!+
M!```LP,``+4"`````````````+`#``#;`0```````'\#``"^`````````/8%
M````````8@$```T%````````XP8`````````````#@(```````"J`P``N@$`
M`&4&```R````X0(```````#4`@```````%X!```R!0``J@4``(<"```S!P``
M(04``/,$``"*````>@```,4"```>!P``"@4``+4`````````X08``#H"``#6
M`@``:`0``+D&``#I`@``0P0````````&!0``.`````````!M!```?0```/L!
M``"O````&0,``*H&``#K`@``\P,```````#5!@```````,D#````````````
M`'D#```3!0``Z00``#L`````````_P(```D%```B!0```````+0```"@`P``
M/`<``((&````````KP(```````#=`@```````-8#```E`@``"P8```````!-
M`P``)04``(D#``#@`P``70```,4$``!N`@``I@```&4!``!-!0``.P$``-X$
M``#C!0``ZP```!L'``#"!@``JP4```\$``#.`P```````$$!``")!@``````
M```````&`P``YP8```````!*`````````/<#``##!```M04```````#$`0``
M10<``,`$````````10$``%P```#]`0``?0$````````&!`````````````#Z
M!@``:P,```````!(!0``%`$``(X!``"V!```@P4``)("```,`P``Q@0`````
M````````TP$```````!0!0``]@0```@'``#.`0``900``.4&```[`@``````
M```$``!V!0``8`(```````!I`0``-0(``#\%``!%`@``A0(``%D'``!L!P``
M:@```"X%```F!P``1@0``)$"````````)00``$X"``!6````^P0```````#L
M!@``<`4```````"-`P``!P4``(X#````````:P0```P'``"G!@``[P$``!<#
M````````/@```)`%``#I!0``VP8```````!:!@``K00``(`&````````Z@4`
M`'L$``#F`````````````````````````.4```!V`0``K`0``-@!``"Q!0``
M$@8``%4'``!)`0``T04```````"Z````'@0````````6!@``T@```(X```#L
M`P``AP$``+`&``!M!P`````````````G`0``%`8`````````````[P```"$!
M`````````````'("``!V!```108``",!``"``P``A`(`````````````I04`
M`````````````````,@#``".!@```````-X```#6`0``&`0```````!?`0``
M$`0``#@#```2`@``'P,``!P%``!B````!@8``(<```#J`P``GP8`````````
M````6````-L$````````#P```%,&`````````````$$&`````````````!<$
M``#)````X`4``)0$``"%``````````4%````````0@4``+@%````````?@4`
M``````#$!```B@,``-$$```[!0``@@````````#3````A0$```,#````````
M'@(``,T#``#Y!0```````"P$```A`@``H@4````````?`0``100``.,"``!(
M````^0(``'D%``!9!````````&0%``">!0``]`8```````"@`0``KP,`````
M``!'!0``U0```"<#``!?````V````#P!```H`@``<0(``*,"``"3`0``;P8`
M`"T$``"T`@```````*D!``!%`P``UP(``-<!``"E`0````````````#N!@``
M`````!D"```_`@``-P$``+L!``!]`P``Y00``!H!````````704``)4"``!=
M`0``&`,``,L&``!I!```-`0``)(```#J!@``*P```'\```!L!0``,@(``/(`
M````````&@4``)X```"G!```>0(```````"W!@``10`````%````````,@<`
M``````!-`@```````+4&``!5`P``3P8``%\&````````N@(``/$!``#-`0``
M`````%<```#T`P``Q0,``/(#````````&00``!$$````````(``````````P
M!0``)@,``,P!````````H`8``#4#``!&````/@$````````E`````````%X'
M``"R!0``'00```H#``">!@```````'``````````[@$``)````"D`P``-`4`
M`-X"``#J!```KP8``(@%``#Y!@``IP,``*,```#/````LP8``.L&```K!```
M20,``"8%``!\`@``VP`````````$!@``]04```0"``!S`0``D@,`````````
M````9@```%T"```G````@04``$H'``#-!0``1`,```````#(`0``BP(``!@&
M```=`@``C00````````P`0```````+`!``#M``````````````"=`P``"P<`
M````````````V@,``!`&```!`@``H08``#P#``"'!0```````#P%````````
M`````+,!``#J``````````````!^`@``GP(```````"\`@```````&H&``#,
M````40$``````````````````(@```![!@``/P0```````![!0```````-P`
M```T!@``&P0``!$!````````LP```(<$``":!0``I08``-L%``!E`@``$`(`
M``````#'!@``/`8``.0``````````````#L$``#.`````````#`&``"9!@``
M:`,``%<&````````[P(``(\%``#/!0``$@4``'\!```+`P```````+``````
M````Q````&T#``!^`P``````````````````>@(``"H%``!1`P``&04``&,`
M````````@`0``',```"-````Q@```'\"``#P!0``0`,``,0%``!G!@``````
M`/D!```````````````````+!0``-@```$P'```0`P``+````(,"``!O````
M-`````````!Y!@``'````.`&``"0!@``;P$``&T%``#(!0```````"<&```]
M!P``#@``````````````G`4````````Q`@``4P````````!7!P``>`0``*(`
M``!@`0```````-X#````````"0```!8$``#8`P``0P(`````````````````
M`,(#``!/`@``*0(``/H"``",!@``E0```"\!``!6`@``5P4``%P%``!A!@``
M(P4``'<!````````F@,```$#``"A!````````.,````<!@``P@4```H"``"[
M!0```````#D%```*!@``1P,``````````````````*L&``!#`P``JP````4'
M``!D````O0```(,&````````FP,``*L#````````H0(``+$!``#"!```F`0`
M`"@``````````````!$"``#X!@``,P````,&```X!0``7`<``-H$```V!```
MO@8``(L!````````A@,``!H$``````````````````!!`P``P@`````````)
M!P``I00```````#=`P```````)(&``"1`P```````.4!```_!P``=P0``&P!
M``!(!P````8``````````````````(8&````````<@```$`'```/!@``````
M`#0"```C`````````.T%``"L!@``4P,``&0#``#&!0``2@0``,H"``!9````
M,0<``!0%`````````````/\%````````=0,```````"H!`````````````#B
M`@```````#D#`````````````/\!``",!0``/`(``+P&```B!@``QP0``%`&
M`````````````'H$``"$`P``U@```.\&``!9`0``FP0``+D$``"F!0``_@$`
M`"P%````````!08``,H````Y!@```````,\"````````O````&\#``!?`P``
M*P,``-0&```S!@``"@```%T$````````R@8``&X$```I!```[P,``"4#``"Q
M!```'`$```````!Q!```-@$```````"M`````````(0%``![`0``]@8``&<'
M````````'@8```````#5!````````+L$``!V`P``204`````````````40(`
M`!4"``#Q!```A00```````"M`0``>0```-`$``!#````(`,``$P$```$````
M#0,``%D&``!W`P``0`8``.$````J````V0$````````L`P``H0```",#```2
M!```=`(``.\$``"9!`````````````#U!@``8P(``%4%``````````````('
M```!!```J`(``+\"```\```````````````2````[@0``#$$````````Z`8`
M`!4$````````5P(``+\!``".!0``^0````````#0!0```````($!```-!P``
M:````.0!``#4`0``%`<``+`"``"!!```N04``#0'````````-@4``/\&``#:
M`@``B04``/0$````````CP(```<#``#&`0``,`0``"L'``!D!```,@0`````
M``#R`@``B`(```H'``#?`@``508``'`"`````````````-,&``#!`P``3```
M````````````[0(``%P&``"U`0``.`8``(H$```@`0``2P<``%<$``#0`@``
MT@,````````?!P``.@0``#(#``!@!@```````&,#````````T@4``%($``"_
M`P``````````````````2@(``!<!``#.`@``-@8``(L```#!`@``O0$`````
M```F!```3`4```````"(`P```````*<```!;!P``)`<``/$```#X!0``^@$`
M```````V`P``NP````,`````````H@(``%('``#W`@``G@(``&````!^````
M7`$`````````````3P```'($````````4@,``!H&```4`@``G`(``,T$````
M````AP8```````!F!```D@0```````"=`@``PP8``/``````````O`4``,`&
M``#@`0``+@(``%L"````````F04``'`#``!`!0``F@```'0%```,`0``-P4`
M``0#````````:@(```````#T`0``IP(`````````````````````````````
M`````%0"``"9`P``/P$``)X$```M!0``&@````````"5!```-@<``/`!````
M`````````-0%````````#0$```````#)!@```````$$'``"W`@``````````
M````````S`8``!T````Z`P````````````"+`P``K`4``%,"```N!```:P$`
M``````#/!```+`<``%@!```C!```E@$`````````````O0(```X'``!K`@``
M80````````!A`@``E@```!$```"0`0``5@0`````````````&````.$!````
M````:`$``#`#``#E`@``'P```'P!````````\P4``"4'``#)!0``*`4``!8'
M````````_@(``+0#``#D!````````&0'```]`0``2P,``"@$``"D`0``````
M`,,"````````$````,,#``"&`@```````+X!`````````````$D'``#[`P``
M&`(``((%``!E`P``:`8``-8$`````````````-P!`````````````+\&``#1
M!@``E`8```L````T`0``Y04``'L#``"V`@```````*X&```H!@``Y`8``!4'
M````````H@$`````````````Q`8``-H````(`@``=`0``!8#````````5P,`
M`"4&```B!P````````````#P`P``!0,````````9````;`,``.<$``#+`0``
M^@0``)4!``!S!```WP$``-(!``#>`0```````/H```"B`P``4P4```````"T
M`0```````/0```!\`P``U0$``)`#````````GP4````````;!@``!00``.D&
M```#!````````&H'``!C`0``J`8``,````#!````5`0``%D%``!R`P``QP(`
M````````````C0(``)P#```6!0``\04``#4!``")`@``CP```/X```#Z!0``
M``````````##`0``9`$```````"7!```E@,``/X$``#A!```T`,``*T#``#+
M!0``W0$```````!M!@``MP``````````````2`0```````!/!P``400``,8&
M````````%P(```````"I`````````%`"``"]!```.@$``%4"```C`@``T@(`
M``P```"5!@``KP0``+<!```B`0```````$,!``!R!P``#@4```````!T`0``
M/@8``.P"```J`P```````%L$``#2!```Q@(`````````````H@0``'X!``")
M!````````+4$``!6!P```````$$%``"2!0``Z@$``%0'``"8!0``!P<`````
M``#G`P``J0,``)4#``#\!@``0@,``!L"```J!````````&L'``!G`0``/P8`
M`)L"```O!P``?P4``+P!````````"P0````````Z````*P(```T$``!>!```
M\@8```````!A`P``O0,``$0&``#(`@```````'@#````````7P4``$<&``!_
M!```U@4``(T&``#I`P``O@,``,`"```2!P```````(T%```3````,`<`````
M``#1````*P4````````J!P``5@,```````!8!0``F@(```(&```\!```````
M``("``!H!P````````````#@````:@0``-````!?`@``NP(```````"=````
MIP4``&@"``"I!```E@(``"`$```Q!0``X@0``-\#``#W!```>``````````3
M!P``_0,``'(%``#\`P````````````#+`P``1@,``+,"````````U`0```D$
M``!L!```'08````````/!0``20(``($"```]!@``B`8`````````````(0,`
M`"$&```Z!@``5@8``#``````````CP$``"H!````````L@(`````````````
M*@8``-P"```(`0``7@(``/,"``#9!@```````.X%````````DP````````!:
M!`````````````#(!@````````````"7`0``6P4``!X```!/`P``[0$``!X!
M``!A!P``````````````````Q08``!4#``"-`0```````'T$```D!0``````
M`*D%``"L`@``)P<````````&!P````````````"V!0``'`(``-D"````````
MG0$``%<!```"`0``1@(``$\$``#K!0``2@4```````!N!P````````H$``#'
M`````````"($``!X!@``@@$``$D$``#M!@``:P````````!V!@```````.L#
M``#/`0``TP(``!0```"7`@````````````#7`P````````X$``"3!0``````
M`#<'```G`@``:P8```````"%!0``OP0``#D```!.`P``QP,``&\"``";````
MI0(```````#\`@``FP8``%X```!`!```?04``"L!``"I`@```````)D```#9
M`P``$04``/<````X`@``L@```,H%````````V04`````````````\`0`````
M````````YP4`````````````1P(``"\%````````L0(```````!I`P``````
M`/\#```#!0``(`8``$8&```1`P```````)P$``#T!0``=@```%\'``"?!```
M`````*X#``!!`@``FP4```D#`````````````$P&````````5@4`````````
M````XP0``+<%```N!@``V0```!`'``!S!@```````.D!```U!```;`8``#X'
M``"C!```9P````````!]!@``I0,````'```=!0``N0,```````!4!0``:`4`
M`'L"`````````````'@"``".!```B0```((#``"3`P``:@$``&X#``#Y!```
MP`$``%("``"#`P``Z`0``(`````^`@``-08``$0%```T`P``"0$``*@%````
M`````````)H$````````;P<``.$#```[`P````````````#6!@```````)$!
M````````N`8``'$&```<!```]@(``+T%``![````@08``*H!````````<0,`
M``L!``#F`@``.P8``#4'`````````````(0````=`P``&P4``#,!```M````
MEP8``,D$````````+`(``)<````:!P``"`,```````"/!````````,\#````
M````BP0``"4!````````4`````````!8!P``4P<``%H```!I`@````````X#
M``!$`0``6P,``#X$````````&@(```````"N````N```````````````8@8`
M`-4%```?!@``5`,``'P&``!&`0``O@0``#@'``````````````````#:!@``
MA`0``$$````I`P``40<``+8!``#=!```9P,```````#%````F@$````````5
M````5````.<!``#Q!@``G00``"@#``#7!```^`0``)$$````````F0$``#D!
M``!@!````````#,#``"_````#`4``.@#``#;`@``D@$``/$#``"P!```SP8`
M`'X&``!"````&0$```````"/!@``8P8``(8$``!I!0```````.L!``!B!P``
MBP8``&T"```"`P````````````#!`0``L08``.X"````````+08``)L!````
M````X@````````!0!P```````!0$```Q!@``I@,``$<'``#_!```0@<``/@!
M```"````1P$``',#```G!0```````!<%``!/`0``&`$``(<#````````6P8`
M`(D!`````````````````````````````'0&````````CP,```````#N`P``
MI@(``.,#```(!@``$P0``$L%``!G`@``!`<````````-`````P$``/<&``"F
M!```8@4``-,#````````T`8``,T"``"C`0``2`8``$P!``#7````/@4`````
M``!)````<@8``"H"````````@`(``/P!``#\!0````````````!W````!P8`
M`-0````;`0``S@4````````&````_04``!<&``"M!@``V`(``%,!``"N`0``
M;P4``-X%``"A`P``_`0`````````````:0<``.T$``",`0``@P0````"``!-
M`````````$("``"^`@``B`$``.(!````````V`4``"0````S!0``.`$``(0!
M``````````````````"Z`P``,0```)0```"0!```1`(````````O````````
M`'\&```O!@``F@8``````````````````!H#``#7!@``IP$``/4`````````
M`````*@```!"!@``M`8``(P"```U!0````````````!<!```4@4```````#B
M!0``GP,```,'````````'P(``-,$```O!```.0(```````"R!@```````/`&
M``"X!```R@$``#<#``"O!0```````'4````^`P``=P(```````"(!```P@$`
M`````````````````+`%``!>!0``,@$``*0%``!!!```4`0````````_````
M)`0``/X%`````````````),$`````````````*L$``!U!0``]0(``-,%````
M````=`,``*X%``#E`P``N0$``!\%````````R0$`````````````2P$`````
M```I!P``N@0``+X%``!L````8`4```````!N`0``(P8```<$````````500`
M`+$#```6`@``3@4```````#K!```@@(``!`%``">`P``X04```````!X`0``
M:0```($#``#F!0```````.<```!``0``#@$`````````````=@(``(H&``#!
M!0``+P(`````````````````````````````1@<```````!U!```1P0``'H#
M``#P`@```````$($``#T`@````````````!#!P``WP4``!D'```D`@``F`(`
M`%$&``!1!0``4`,``/$"``````````````````!*`0``2`,``#D'``!=`P``
MHP4`````````````@P$``"$'``!B`P```````$`"````````)@$``$X```"K
M`0```````(H%``!-!@``<`8``%T&```S`@``300``,8#``#+!````````+0%
M```7!P``&`4``%H!``!U`0``!@$``,$$```S!`````````````#-!@``1`0`
M`(L%``#$`@````````````#`!0``Z`(``.`"```3!@``D`(``.H"```N`0``
M,@8``)D"`````````````&T```!6`0``800``+(#````````<0$``&D&``#<
M`P```````/,```!;`0``%08``.<"``"Y`@``F`8``&T!````````8P<``%,$
M``"N`@```````)$````5`0```````*,&````````VP,``&<%```N````Y@$`
M````````````L@0``*P````@`@``<@$``/,!`````````````$D&``#L`0``
M`````)8%````````Y@8``+8&````````A@```"D!````````T0$``+@"``!$
M!P``.@4```````#[`@``!P````````"Y````$08```0!```<!P```````.0%
M````````C`0```4"``!>`P``$@$``/T$````````$P(``(($````````]0,`
M`*D&``"=!0``S`0``!L```!B!```WP0``/(%``"F`0``)@8``'T"````````
M'`,```@$````````8P0``+P$``!.!P``R`0``-X&````````_@,``,P#```X
M!```)P0````#````````^`(``````````````````%@#```?!```"0(``*,#
M````````K0(````````Q`P``2`$``+P#``"4`P``G`$```````!5`0``[P4`
M`.,!``"K`@``4@$``&4%````````1@4```4```!Q!P``.@<````````W`@``
M"`4``*@!``#D`@```````&$!``!N!@```````/@```"%!@``_````*H"``#X
M`P``%P```#\#``"8`P``/04``.`$````````I`0`````````````6P```.8$
M``##````.00``&,%``#9!```,`(```(%``"A!0```````.(#```'`@``E@8`
M`!$'``"D````+`8``!8````M`P````````\"``#V````"P(``$X&``!N!0``
MF`$``/T&```W!@``<`0``)0%`````````0<``,D"``!/!0````````````!2
M!@``W`4```($``!0`0``W04````````D`0``:P4`````````````8@(`````
M``#[!@``*08``*8&````````\P8``&X``````````````"0&```!!@``'0<`
M``````!G!```]@,```````!S`@``%`,``"8`````````9@,``*H$```I````
M5`8``!4%``#U`0``-P0``"T'``#]````+P,``.@```"U`P`````````````0
M`0````````````#2!@```````%@&````````'0$``'4"```/`0``@P```$L"
M``#[````W`8``%X&```]````&P,``*X$````````U0,``'<&``#8!```OP4`
M`(8!``"4`@``(@```"X'``#.!```6@(```````"H`P``6`0`````````````
M804```````"D!@``9@8```````"*`0``MP,``'`'``".`@``G@$``-0#``"L
M`P``G`8``)@```!,`@``P`,``$T!``#[!0``/00``)P```#Y`P``>0$``'4&
M``!J`P``+0(``/8!``#N`````````-4"````````!`0```````!X!0``?`4`
M```````L`0``&08```````#]`@``D08``/X&``"*`@``=````",'``!+!@``
M``````X&``!%!0```````&8"``!9`@``.P<```````"3!@``N@4``&H%```I
M!0``H````-T&``````````````````!-!P``C`,```\#```@!P``$P$``%D#
M``#L````(@,``#<```"@`@```````````````````````,,%``"!````[`4`
M`!@'````("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I`"`H:6X@)7,@
M9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T97)D87DI`"!A="``
M(B5S(B!I<R!N;W0@82!D:7)E8W1O<GDN`"(E<R(@:7,@;F]T(&$@=F%L:60@
M8VAO:6-E+@`B)7,B(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!2
M96=I<W1R>2X`(B5S(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"X`(B5S(B!W
M87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D
M('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A
M=&5D.B`E<RX`)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E
M)2D`)60@)7,@86YD("5S`"5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E
M>'!I<F5S+@`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R
M<')I;G0`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO
M;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E
M<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@:7,@<F5A9'D@=&\@
M<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E
M;&]W+B!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W
M86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@`E<R!I<R!R97%U:7)E9``E
M<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!
M9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!4
M87-K;&ES=``E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M
M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R!A;GD@;&EN
M:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@
M<&5R<V]N86P@:6YF;W)M871I;VXN`"P@9W5S=&EN9R``+"!G=7-T:6YG("5S
M("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S96QE8W0@+2T`,3(@
M2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`/%!R979I;W5S
M`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C
M:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@4$=0(&ME
M>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@
M4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G
M92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S
M<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@
M<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3
M+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@
M4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--
M24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04T@
M0VQO=61S`$%-($QI9VAT(%)A:6X`04T@4F%I;@!!32!3:&]W97)S`$%-(%-N
M;W<@4VAO=V5R<P!!32]030!!4$D@240`06)O=70@=&AI<R!E9&ET;W(`06)O
M=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E<W,@9&5N:65D(&-R96%T
M:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93
M(&9I;&4N`$%C8V]U;G0@26YF;W)M871I;VX`06-C;W5N="!087-S=V]R9`!!
M8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`061D($-H:6QD($=R;W5P
M`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P
M`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!G<F]U<"!T;R`B)7,B
M`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@(B5S(@!!9&0@82!N97<@=7-E
M<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D('!A:7(`061D('1H
M92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!T;R!A9&1R97-S
M(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D('5S97(`061D960@
M(B5S(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO
M;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N`$%D9&5D("(E<R(@=&\@=&AE
M('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+@!!9&1I;F<@=7-E<G,@:7,@
M9&ES86)L960N`$%D9')E<W,`061D<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S
M970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N
M`$%D<P!!9F=H86YI<W1A;@!!;&)A;FEA`$%L9V5R:6$`06QI87,`06QI9VX`
M06QI9VYM96YT.@!!;&P`06QL($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R
M;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@<VED97,`06QL;W<@;75L
M=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T
M('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)35-0($QO9VEN`$%L
M=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S97)N86UE
M`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T96UP;&%T97,`
M06QT97)N871E('1E>'0Z`$%M97)I8V%N(%-A;6]A`$%N(&EL;&5G86P@=F%L
M=64@=V%S('-P96-I9FEE9"X`06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E
M9"X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM;W5S(%!R;WAY`$%N
M<W=E<@!!;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U9&$`07!P;&EC871I
M;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P
M;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P<F]X:6UA=&4@4VEZ90!!
M<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`
M07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@
M=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@
M=VES:"!T;R!D96QE=&4@(B5S(B!A;F0@86YY('-U8BUG<F]U<',_`$%R9V5N
M=&EN80!!<FUE;FEA`$%R;65N:6%N("A!4DU30TE)+3@I`$%R=`!!<G5B80!!
M<V-E;G-I;VX@27-L86YD`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N
M`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC
M92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`071T96UP="!T;R!D
M96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E
M(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A
M(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N
M;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I8G5T97,`075G=7-T`$%U<W1R86QI
M80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V
M92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@
M:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@
M1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE
M("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR
M8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!!9&1I;F<@=7-E
M<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H
M7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C
M=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R
M("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P
M.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@
M=&\@=7!D871E('5S97(@)7,`075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I
M<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+@!!=71H7VUC
M86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]S
M;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"X`075T:&5N
M=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T
M:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`075T:&5N
M=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%U=&AE;G1I8V%T:6]N
M('1O('1H92!334(@<V5R=F5R(&9A:6QE9"X`079A:6QA8FQE(&9I96QD<SH`
M07IE<F)A:6IA;@!"3T9(($5X8W5S97,`0F%C:V=R;W5N9`!"86-K9W)O=6YD
M($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S
M97)N86UE+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`
M0F%N9VQA9&5S:`!"87)B861O<P!"87-E(&=R87!H:6-S(&1I<F5C=&]R>2`B
M)7,B(&YO="!F;W5N9"X`0F%S96QI;F4`0F5L87)U<P!"96QG:75M`$)E;&EZ
M90!"96YI;@!"97)M=61A`$)H=71A;@!":7)T:&1A>0!";&]C:R`B)7,B(&]F
M(&%P<&QI8V%T:6]N("(E<R(@;F]T(&9O=6YD+@!";&]C:R!3971T:6YG<P!"
M;&]C:R!4>7!E`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E
M<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN80!"
M;W1H`$)O='-W86YA`$)O='1O;0!";W5V970@27-L86YD`$)R87II;`!"<FET
M:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GD`0G)U;F5I($1A<G5S<V%L86T`
M0G5L9V%R:6$`0G5L;&5T960@3&ES=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!#
M35,`0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S`$-?96QL(%!R;W!E<G1I
M97,N+BX`0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"X`0V%L96YD87(`
M0V%L;0!#86UB;V1I80!#86UE<F]O;@!#86X@;F]T(')E<V5T('!A<W-W;W)D
M(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#
M86X@;F]T('=R:71E('1O(&9I;&4@(B5S(@!#86XG="!A9&UI;FES=&5R(&5X
M=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N`$-A;B=T(&-O;FYE8W0@=&\@24U!
M4"!S97)V97(Z("5S`$-A;B=T(&]P96X@9FEL92`B)7,B+@!#86YA9&$`0V%N
M8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN;W0@9&5L971E(&9I;&4@
M(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#86YN
M;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N`$-A
M;FYO="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D
M(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N
M=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M
M8F5R('-T;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D
M(&YU;6)E<BX`0V%P92!697)D90!#87!T:6]N`$-A<G)I97(`0V%T96=O<FEE
M<R!A;F0@3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0
M<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@
M<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E
M<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H
M25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!/
M=VYE<@!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H86YG90!#:&%N9V4@
M66]U<B!087-S=V]R9`!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA
M="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R
M(&5M86EL<RX`0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R
M=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@($-O;G1A8W0@
M>6]U<B!A9&UI;FES=')A=&]R+@!#:&%R`$-H96-?:R!,:6YK+BXN`$-H:6QE
M`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R
M861I=&EO;F%L("A":6<U*0!#:&]O<V4@07!P;&EC871I;VXZ`$-H;V]S92!A
M('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!H;W<@=&\@9&ES
M<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R
M960@;&ES=',I`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O
M9B`E<R!N;W0@9F]U;F0N`$-L96%R`$-L96%R($U33V9F:6-E('1A9W,`0VQE
M87(@475E<GD`0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S97(`0VQE87(@
M=7-E<B!D871A`$-L96%R:6YG($QA=&4`0VQI8VL@=&\@0V]N=&EN=64`0VQI
M8VMA=&5L;"!V:6$@2%144`!#;&]S92!7:6YD;W<`0VQO=61S`$-L;W5D<R!%
M87)L>0!#;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`0V]L;&%P<V4@
M4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO;6)I80!#;VQO<@!#;VQO
M<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#;VQU;6X@=&ET;&5S
M`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@
M3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M<'5T97)S`$-O;F1I=&EO;@!#;VYD
M:71I;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R96YC97,`0V]N9FEG=7)A=&EO
M;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L
M;V]K+@!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+@!#;VYF:6=U<F4@
M)7,`0V]N9FER;2!087-S=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C<F%T
M:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T
M:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC
M(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@
M<V5R=F5R(&9A:6QE9"X`0V]N=&%C=',`0V]N=&%C=',@=V5R92!S=6-C97-S
M9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O;G1E;G0@='EP
M92!O9B!C;VUP<F5S<V5D(&9I;&4Z(`!#;VYT96YT<R!O9B`B)7,B`$-O;G1I
M;G5E`$-O;VL@27-L86YD<P!#;V]K:64`0V]P>0!#;W!Y(&9A:6QE9#H@)7,`
M0V]P>2!S96QE8W1I;VX`0V]S="!)1`!#;W-T82!2:6-A`$-O=&4@9"=)=F]I
M<F4`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z(`!#;W5L9"!N;W0@
M4$=0('-I9VX@;65S<V%G93H@`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M
M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@
M;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E
M<G9E<BX`0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C
M;VYN96-T('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8V]N;F5C="!T;R!S
M97)V97(@(B5S(B!U<VEN9R!&5%`Z("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A
M.B``0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D
M96QE=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I
M;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C
M<FEP="`B)7,B+@!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G
M<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D
M9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U
M=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@
M;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@;&]A9"!S=')A=&5G
M>2`B)7,B+@!#;W5L9"!N;W0@;6MD:7(@(B5S(BX`0V]U;&0@;F]T(&]B=&%I
M;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P
M96X@(B5S(B!F;W(@=W)I=&EN9RX`0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD
M(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO
M="!O<&5N(&1I<F5C=&]R>2`B)7,B+@!#;W5L9"!N;W0@<F5A8V@@=&AE($Q$
M05`@<V5R=F5R+@!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T(')E<V5T
M('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R
M(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I
M;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F
M=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R971R:65V92!!0TP`0V]U;&0@;F]T
M(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E=')I979E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES
M=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R
M)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO
M;BX`0V]U;&0@;F]T(')M9&ER("(E<R(N`$-O=6QD(&YO="!S879E("5S(&-O
M;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A
M=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E
M<P!#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S
M(BX`0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I
M;&4@)7,N`$-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@
M<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE
M(&-O9&4@8F5L;W<@=&\@)7,N`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@
M<V5R=F5R+@!#;W5L9"!N;W0@=6YL:6YK("(E<R(N`$-O=6QD(&YO="!U<&1A
M=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,`0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R("(E
M<R(Z("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K
M92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN`$-O=6QD;B=T(&=I=F4@=7-E
M<B`B)7,B('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R("(E
M<R(Z("5S`$-O=6YT960@=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E871E`$-R
M96%T92!A(&QI;FL`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@<W5B(&9O;&1E
M<G,`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`0W)O
M871I80!#=6)A`$-U<G)E;G0@-"!0:&%S97,`0W5R<F5N="!397-S:6]N<P!#
M=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!5<V5R<P!#=7)R
M96YT(%=E871H97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE
M`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T
M`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL
M;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5
M*0!#>F5C:"!297!U8FQI8P!$1`!$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N
M;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP
M:'`I`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T86)A<V4@3&]O:W5P`$1A
M=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5?;&5T92!#
M;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E($EN9&5N
M=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969A
M=6QT(%-H96QL`$1E9FEN:71I;VYS`$1E;&5T90!$96QE=&4@0V5L;`!$96QE
M=&4@1W)O=7``1&5L971E($QO9P!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@
M86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`
M1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@;65S
M<V%G97,`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T92!P97)M
M:7-S:6]N<R!F;W(@(B5S(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L
M971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('-U8B!F
M;VQD97)S`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L971E('1H92!C
M=7)R96YT(')O=P!$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N
M`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$97-C<FEB92!T:&4@4')O8FQE;0!$
M97-C<FEP=&EO;@!$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ
M`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T
M;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@
M:&]U<CH@`$1E=R!P;VEN=#H@`$1I<F5C=&EO;B!L969T('1O(')I9VAT`$1I
M<F5C=&EO;B!R:6=H="!T;R!L969T`$1I<F5C=&]R>0!$:7-P;&%Y(#(T+6AO
M=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&1E=&%I;&5D(&9O
M<F5C87-T`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`
M1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N`$1J:6)O=71I`$1O(&YO="!D96QE
M=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``1&]E
M<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y
M97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L
M:6,`1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+@!$;W=N;&]A9`!$
M;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A
M<R!02%`@<V-R:7!T+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA:6P`14UA
M:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@
M<')O=FED92!T:&ES('-E<G9I8V4N`$524@!%8W5A9&]R`$5D:70`161I="!"
M;&]C:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I
M;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z
M`$5D:70@<&5R;6ES<VEO;G,@9F]R("(E<R(`161I="!P97)M:7-S:6]N<R!F
M;W(@)7,`161U8V%T:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`
M16T`16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M
M871C:"X`16UA:6P@=VET:"!C;VYF:7)M871I;VX`16UA:6PM=&\M4TU3($=A
M=&5W87D`16UO=&EC;VYS`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`
M16UP='D@<V5A<F-H('1E<FUS`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S
M(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N86)L92!R:6=H="!C
M;&EC:R!C;VYT97AT(&UE;G4_`$5N9"!Y96%R`$5N;&%R9V4@161I=&]R`$5N
M=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K
M960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G
M=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA
M9V4@55),(&AE<F4`16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z`$5Q=6%T;W)I
M86P@1W5I;F5A`$5R:71R96$`17)R;W(`17)R;W(@8W)E871I;F<@8FQO8VLZ
M("5S`$5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<P!%<G)O<B!D96QE
M=&EN9R!S>6YC(&QO9SH@)7,`17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<P!%
M<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,`17)R;W(@=VET:"!E;6%I;"!M
M97-S86=E+@!%<G)O<B!W<FET:6YG("(E<R(N`$5S=&]N:6$`171H:6]P:6$`
M171H;FEC`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E
M<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I
M;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S
M.@!%>&5C=71E`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%>'!E8W1E9"`G*2<`
M17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;0!%>'!I
M<F%T:6]N($1A=&4`17AP;VYE;G0`1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S
M971U<`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O
M(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T('1O
M(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D
M('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C
M;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&86EL960@=&\@
M<F5T<FEE=F4Z("5S`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I
M`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&87AE<P!&96)R=6%R
M>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R<P!&97<@4VYO
M=R!3:&]W97)S`$9I96QD(&UA=')I>`!&:6=L970@0T%05$-(00!&:6II`$9I
M;&4`1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&
M:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L
M;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QT97)S`$9I;FQA
M;F0`1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&EP`$9O
M9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]N="!#;VQO<@!&;V]D`$9O
M<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T
M("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@
M9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@
M;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R
M9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E
M`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S`$9R`$9R86UE
M<P!&<F%N8V4`1G)A;F-E+"!-971R;W!O;&ET86X`1G)E;F-H($=U:6%N80!&
M<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&
M<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL
M($YA;64`1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R
M>3H`1V%M8FEA`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D
M($-O9&4`1V5O<F=I80!'97)M86YY`$=H86YA`$=I8G)A;'1A<@!':79E;B!.
M86UE`$=L;V)A;"!/<'1I;VYS`$=O`$=O961E;`!';V]G;&4@36%P<P!';V]G
M;&4@4V5A<F-H`$=R87ES8V%L90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I
M`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P
M(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P7VQD87`Z(%5N86)L92!T
M;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z
M(`!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S`$=R;W5P
M7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,`1W)O=7!S`$=U861E
M;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO
M;G,`1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,
M07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL
M(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@
M=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R
M969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@
M075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R:71H
M;0!(87IE`$AE861E<@!(96%D97)S`$AE87)D($ES;&%N9"!A;F0@36-$;VYA
M;&0@27-L86YD<P!(96%V>2!4+5-T;W)M`$AE8G)E=R`H25-/+3@X-3DM."U)
M*0!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP97(`2&5M:7-P
M:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AI9V@`
M2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M90!(;VUE
M($%D9')E<W,`2&]M92!$:7)E8W1O<GD`2&]M92!0:&]N90!(;VYD=7)A<P!(
M;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A
M=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@3F\@
M;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z
M($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,`2&]R
M9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`2&]R9&4O
M2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D
M;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C
M<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E
M("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S
M(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R
M97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E<R(`2&]R:7IO
M;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W<@
M9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@;6%N>2!C
M;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L
M9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y
M;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ(`!(=6UO<FES
M=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)
M34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@
M<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S`$E0($%D9')E
M<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W
M960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)7VYS97)T
M(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS(&9O<B`E<P!)
M8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I<R!N;W0@
M9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W
M:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R
M;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@
M=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U('-E92!T:&ES
M(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@
M=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EM
M86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E(&9R;VT@
M9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G
M97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E
M9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C="!A8W1I;VX@
M8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R
M9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4
M<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U
M(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD
M:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA=&EO;@!);F9O
M<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+@!);G-E<G0@0U]O;'5M;B!!
M9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN
M:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A
M9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O
M<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE
M(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R
M96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@
M;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO
M9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@
M861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S
M=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN
M<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T
M(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G
M<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R
M90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@
M<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,
M:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I
M8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT
M96=E<B!L:7-T`$EN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN
M=F%L:60@6DE0(&1A=&$`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B
M871C:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T
M:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@
M;&EC96YS92!K97DN`$EN=F%L:60@;&]C871I;VX@<')O=FED960N`$EN=F%L
M:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L
M:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M
M:7-S:6]N+@!);G9A;&ED('!A<G1N97(@:60N`$EN=F%L:60@<')O9'5C="!C
M;V1E+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED(')E8VEP:65N=#H@(B5S
M(@!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S
M+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$EN=F5R="!S96QE
M8W1I;VX`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`
M27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)
M=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)
M4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*
M=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I
M9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY80!+97)B
M97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME<FYE;"!.
M97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T
M:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I`$MO<F5A+"!$96UO
M8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O
M9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U=`!,
M86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T
M($AA;&8`3&%S="!087-S=V]R9"!#:&%N9V4`3&%S="!1=6%R=&5R`$QA<W0@
M57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E
M<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`3&%W`$QA>6]U=`!,96%V92!E
M;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N;VX`3&5F=`!,969T(&AE861E<@!,
M969T('9A;'5E<P!,97-O=&AO`$QE=F5L`$QI8F5R:6$`3&EB>6%N($%R86(@
M2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI9VAT($1R:7IZ;&4`3&EG:'0@
M4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H="!2
M86EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W
M`$QI9VAT(%-N;W<@4VAO=V5R`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@
M=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I
M<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S
M964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S
M`$QI<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,
M:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B
M<V-R:6)E`$QI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S
M97)S(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET
M97)A='5R90!,:71H=6%N:6$`3&]A9&EN9RXN+@!,;V-A;"!T:6UE.B``3&]C
M86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@;V8@<')E=FEO=7,@
M<WEN8R!S97-S:6]N`$QO9R!O=70`3&]G:6X`3&]G:6X@5&%S:W,`3&]G:6X@
M9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@
M96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`
M3&]V90!,;W<`3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T
M97)S`$QO=V5R(')O;6%N(&YU;6)E<G,`3'5X96UB;W5R9P!-30!-3U1$`$U3
M+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA8V%O
M`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-
M861A9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!9&UI;@!-86ME(&QI;E]K+BXN
M`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA;F%G92!T
M:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US
M('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G
M;W)I97,N`$UA<#(T(&UA<`!-87!1=65S="!M87``36%P<&EN9W,@<W1O<F5D
M+@!-87)C:`!-87)G:6X`36%R:R!W:71H(%-E96XO56YS965N(&9L86=S`$UA
M<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I
M`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-871C:&EN9R!F:65L9',`
M36%U<FET86YI80!-875R:71I=7,`36%X(&%L;&]W960@8W)E9&ET+@!-87@@
M;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S="`R-"!H;W5R
M<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@3G5M8F5R(&]F
M(%!O<G1A;"!";&]C:W,`36%X:6UU;2!L96YG=&@`36%Y`$UA>6]T=&4`365D
M:6-I;F4`365M8F5R<P!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`
M365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G
M<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I960N`$UE<W-A9V4@
M97AP:7)E9"X`365S<V%G92!T>7!E`$UE=&%R(%=E871H97(`365T87(@8FQO
M8VL@;F]T(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@
M1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O
M<BX`365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+@!-971H;V0`365T:&]D("(E
M<R(@:7,@;F]T(&1E9FEN960`365T:&]D(&YO="!D969I;F5D+B!#86QL960@
M;65T:&]D.B`E<P!-971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E
M9"!3=&%T97,@;V8`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T
M(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36EN:6UU;2!P87-S
M=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9`!-:7)R;W(`36ES8V5L;&%N
M96]U<P!-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N`$UI<W-I
M;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W
M(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG
M(&UE<W-A9V4@240N`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA
M:6PN`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE($UA:6P`36]D97)A
M=&4`36]D:69I960@1&%T90!-;V1I9GD@55),`$UO9'5L=7,`36]L9&]V82P@
M4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO
M;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)E(&9I96QD<R!F;W5N
M9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+@!-;W)O8V-O`$UO
M<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!3=6YN>0!-;W9E($1O
M=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V
M92!U<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-
M=6QT:6UA<"!52R!M87``375L=&EP;&4@<V5L96-T:6]N`$UY($%C8V]U;G0`
M37D@06-C;W5N="!);F9O<FUA=&EO;@!->2!0;W)T86P`37D@4&]R=&%L($QA
M>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YA;6EB:6$`
M3F%U<G4`3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N9',@06YT:6QL97,`
M3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`
M3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!296YE=V%L(%523`!.
M971S8V%P92!2979O8V%T:6]N(%523`!.971S8V%P92!34TP@<V5R=F5R(&YA
M;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.971S8V%P92!C97)T
M:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`3F5W($-A;&5D;VYI80!.97<@
M0V%T96=O<GD`3F5W($UE<W-A9V4@=&\@)7,`3F5W($UO;VX`3F5W(%5S97)N
M86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W('!A<W-W;W)D`$YE=R!P
M87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"X`3F5W('!A<W-W;W)D<R!D;VXG
M="!M871C:"X`3F5W('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U<',`
M3F5X=`!.97AT(#0@4&AA<V5S`$YE>'0@;W!T:6]N<P!.97AT/@!.:6-A<F%G
M=6$`3FEG97(`3FEG97)I80!.:6=H=`!.:75E`$YO`$YO(&%V86EL86)L92!C
M;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO
M(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO
M(&)A=&-H('1E;7!L871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E
M<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-
M0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A
M;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93
M+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M4U%,+49I;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I;VX@
M<W5P<&QI960N`$YO(&9I;&4@=7!L;V%D960`3F\@:6-O;G,@9F]U;F0N`$YO
M(&QO8V%T:6]N(&ES('-E="X`3F\@;&]C871I;VX@<')O=FED960N`$YO(&UE
M<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N=6UB97(@
M<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`
M3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/
M<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H(%!+0U,@
M,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!Q=6]T82!S970N`$YO
M(')U;&5S`$YO('-E<&%R871O<B!S<&5C:69I960N`$YO('-I9&5S`$YO('-U
M8V@@9FEL90!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@
M8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V
M86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F
M;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O
M;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U
M<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;F4`3F]N92`H
M=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK($ES
M;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA;F$@27-L
M86YD<P!.;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER96-T
M;W)Y`$YO="!I;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.
M;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V96UB97(`3G5M
M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU
M;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I
M;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@0W)E
M871O<@!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/;&0@
M86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N`$]L9"!P87-S
M=V]R9`!/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N`$]M86X`3VYL>2!)
M34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!O9F9E
M;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D
M+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@
M8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S
M:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R.B!#;W5L
M9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+@!/
M<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T
M96T`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI
M<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA
M;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@
M)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E<FUI<W-I;VYS
M`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!014%2.CI-
M86EL(&)A8VME;F0`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T
M960@1&%T80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$
M871A`%!(4"!#;V1E`%!-($QI9VAT(%)A:6X`4$T@4F%I;@!032!3:&]W97)S
M`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S`%!-(%-U;@!032!4+5-T;W)M<P!0
M3U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9P!0861D:6YG`%!A:VES=&%N`%!A
M;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N86UA`%!A
M<'5A($YE=R!'=6EN96$`4&%R86=U87D`4&%R=&QY($-L;W5D>0!087-S=V]R
M9`!087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2X`4&%S<W=O<F0@:6YC
M;W)R96-T`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC
M871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!0
M87-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F
M<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E
M<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!0
M97)M:7-S:6]N("(E<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I;VX@1&5N:65D
M`%!E<FUI<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O
M;F%L($EN9F]R;6%T:6]N`%!E<G4`4&5T<P!0:&EL:7!P:6YE<P!0:&]N90!0
M:&]T;W,`4&ET8V%I<FX`4&EX96QS`%!L871I='5D97,`4&QE87-E(&-L:6-K
M(&EN=&\@<V]M92!C96QL`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@
M=&\@<F5M;W9E('1H:7,@96QE;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y
M;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@
M82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T
M:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R
M97-S+@!0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M
M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI
M9"!T:6UE+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L
M96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D
M`%!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R
M964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!L96%S92!T
M>7!E('1H92!N97<@8V%T96=O<GD@;F%M93H`4&]L86YD`%!O;&ET:6-S`%!O
M;&QS`%!O<G1U9V%L`%!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4`4&]S:71I
M;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@
M96YF;W)C960@8GD@24U!4"D`4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H
M;W5R*',I.B``4')E8VEP:71A=&EO;CQB<B`O/F-H86YC90!0<F5F<U]L9&%P
M.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E
M<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"X`
M4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0
M<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V
M:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@2V5Y`%!R;V)L
M96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0
M=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R!+97D@26YF
M;P!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S
M<V9U;&QY+@!0=65R=&\@4FEC;P!0=7)G92!M97-S86=E<P!1871A<@!1=65R
M>0!1=6]T80!24T$@4'5B;&EC($ME>2`H)60@8FET*0!2861I;R!S96QE8W1I
M;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T90!286EN(%-H;W=E<@!286EN
M(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!286YD;VT@1F]R='5N90!2871I;P!2
M96%D`%)E860@;65S<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R
M871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A
M=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O
M;F4N`%)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@`4F5F<F5S:"!$
M>6YA;6EC($UE;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E
M;&%T:6]N<VAI<"!"<F]W<V5R`%)E;&]A9`!296UA<FMS`%)E;6]T92!397)V
M97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I
M.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O
M<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M
M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M
M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!2
M96UO=F4@=7-E<CH@)7,`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@
M4F5T=7)N960@97)R;W)C;V1E.B``4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@
M;F]T(&)E(&9O=6YD+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@
M)7,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D
M(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C
M:69I960@:6X@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@1FEE;&0`4F5S970`
M4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R9`!297-T;W)E($QA
M<W0@475E<GD`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2971Y<&4@;F5W
M('!A<W-W;W)D`%)E=6YI;VX`4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!4
M97AT($5D:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R
M`%)I9VAT('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA
M`%)O=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P
M97)T:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@
M87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E
M87(@8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2
M=V%N9&$`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%
M;F-R>7!T960@365S<V%G90!305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A
M=F%I;&%B;&4N`%--4R!-97-S86=I;F<`4U%,('-T871E;65N="!F;W(@=F%L
M=64@;&]O:W5P<P!34T@`4U5#0T534P!380!386EN="!(96QE;F$`4V%I;G0@
M2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A;F0@
M36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,`4V%M
M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD
M(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3875D:2!!<F%B:6$`4V%V
M90!3879E("(E<R(`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G96YE<F%T
M960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V
M97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T
M:6]N+@!3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`4V-A
M='1E<F5D(%0M4W1O<FUS`%-C:65N8V4`4V5A<F-H`%-E87)C:"!%;F=I;F5S
M`%-E;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&=R;W5P('1O
M(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C
M="!A('5S97(@=&\@861D`%-E;&5C="!A;&P`4V5L96-T(&%L;"!D871E(&-O
M;7!O;F5N=',N`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T(&YO;F4`4V5L96-T
M('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W
M+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T
M97AT(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T
M:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@
M=&\@8VAA;F=E.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@
M=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`
M4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R
M960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`4V5N
M96=A;`!396YS;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE9W)O
M`%-E<FEA;"!.=6UB97(`4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL
M86)L92X`4V5S<VEO;B!!9&UI;@!397-S:6]N($E$(&5X<&ER960N`%-E<W-I
M;VYS`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U
M<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R96UO
M=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@
M<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE
M(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I
M;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@
M9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C<FEP=',@
M879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE
M('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAO<'!I;F<`4VAO<G0@4W5M;6%R
M>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK
M<S\`4VAO=P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A
M=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H
M;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O<'1I
M;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('1A8FQE(&]P
M97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE
M9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO
M=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@
M4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E<G1I
M97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R<R!%87)L>0!3
M:&]W97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@5FEC:6YI='D`4VAR:6YK`%-H
M<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE
M('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N871U<F4`4VEG
M;F%T=7)E($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ90!3:VEP($UA:6YT96YA
M;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<`4VYO=R!3:&]W97(`4VYO=R!3
M:&]W97)S`%-N;W<@4VAO=V5R<R!%87)L>0!3;F]W(%-H;W=E<G,@3&%T90!3
M;F]W(&1E<'1H.B``4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B``4V]L;VUO
M;B!)<VQA;F1S`%-O;6%L:6$`4V]N9W,@)B!0;V5M<P!3;W)T(&]R9&5R('-E
M;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@175R
M;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T
M:"!386YD=VEC:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@
M8F5T=V5E;B!A9&IA8V5N="!C96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@
M86YD(&)O<F1E<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@86YD
M('!A9&1I;F<`4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3
M<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-R:2!,
M86YK80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0@>65A<@!3=&%T92!O<B!0
M<F]V:6YC90!3=&%T=7,`4W1O<F%G92!F;W)M870`4W1R965T($%D9')E<W,`
M4W1R:6ME=&AR;W5G:`!3=')I;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T
M:&4@861D<F5S<P!3='EL92!;0U-370!3=0!3=6)D:7)E8W1O<GD@(B5S(B!N
M;W0@9F]U;F0N`%-U8FIE8W0`4W5B;6ET`%-U8FUI='1E9"!R97%U97-T('1O
M(&%D9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N
M=&EL('EO=7(@<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"X`4W5B<V-R:7!T
M`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E
M;2X`4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R
M;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C
M8V5S<V9U;&QY(')E;6]V960@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E
M<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E
M(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A
M=&EO;BX`4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A
M=&EO;B!F:6QE("5S+@!3=6-C97-S9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E
M<W-F=6QL>2!W<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3
M970`4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N
M<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R
M;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`
M4W=I='IE<FQA;F0`4WEN8R!L;V<@9&5L971E9`!3>6YT87@@97)R;W(@:6X@
M<V5A<F-H('1E<FUS`%-Y<FEA;B!!<F%B(%)E<'5B;&EC`%0M4W1O<FT`5"U3
M=&]R;2!A;F0@5VEN9'D`5"U3=&]R;7,`5"U3=&]R;7,@16%R;'D`5%-6(&9I
M;&4`5&%B;&4`5&%B;&4@4')O<&5R=&EE<P!486)L92!P<F]P97)T:65S`%1A
M:7=A;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A:FEK:7-T86X`5&%N
M>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!487)G970Z`%1A<VMS`%1E;&5P
M:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R871U<F4`
M5&5M<&5R871U<F4Z(`!496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S
M*2`F9&5G.R5S`%1E;7!L871E("(E<R(@;F]T(&9O=6YD+@!496UP;&%T92!!
M9&UI;FES=')A=&EO;@!497AT`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T
M;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AE($944"!E>'1E;G-I
M;VX@:7,@;F]T(&%V86EL86)L92X`5&AE($AI<W1O<GD@<WES=&5M(&ES(&1I
M<V%B;&5D+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O
M97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E
M(&EN:71I86QI>F5D+@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T
M(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO
M<V5D+B!%>&ET:6YG+@!4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF
M:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@
M=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED92!O;FQY
M`%1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F
M="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE
M(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E
M<W,@8F]O:RX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@
M<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I
M<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@
M;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@
M9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R
M>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I
M;VXN`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`
M5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`
M5&AE(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I
M;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H
M96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F
M=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I
M=&@@26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA
M="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E
M>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N
M8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U
M<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@
M>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N
M965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A
M<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL
M('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E
M;&5T960N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H92!L;V-A=&EO;B!O
M9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T
M7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I
M=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N
M;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R
M('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@
M=&AE(&-O;7!O<V4@<&%G90!4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E
M(&YU;65R:6,N`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@
M=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E
M("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC
M965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@
M=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N
M9"!O;B!T:&4@<WES=&5M+@!4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@
M;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!R:6=H="!A;F0@;&5F="!S:61E
M<R!O;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5P87)A=&]R
M(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!S97)V97(@(B5S
M(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@
M<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M
M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES="X`
M5&AE('1E;7!O<F%R>2!F:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H92!T
M97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE
M('-C<F5E;BX`5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`5&AE('1O
M<"!S:61E(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@
M=&AE('!R979I;W5S('-T97`N`%1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO
M="!B92!S879E9"X`5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I
M;&%B;&4N`%1H96UE<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%1H97)E
M(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@87)E(&YO('!A<G1S
M('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@
M;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R
M960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S
M+@!4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`B)7,B('1O('1H92!S>7-T
M96TZ("5S`%1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@
M=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L
M96T@<F5M;W9I;F<@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@
M82!P<F]B;&5M('5P9&%T:6YG("(E<R(Z("5S`%1H97)E('=A<R!A('!R;V)L
M96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`
M5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE
M("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@
M*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE
M('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`
M5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A
M<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D
M871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD
M87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T
M:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE
M;&0N`%1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I
M960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA
M=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@
M9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N
M(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E
M('1R>2!A9V%I;B!L871E<BX`5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S
M=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@
M=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E
M87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M
M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@
M*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A4
M5%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI(&=A=&5W87DL
M('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN
M9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R]S
M;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@
M=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@9V%T97=A>2P@;VYL>2!T;R!6
M;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT
M('=I=&@@5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI
M<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT
M86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M
M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O
M<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD
M(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT
M86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E
M>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@
M<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES(&ES(&$@2V]L86(@1W)O=7!W
M87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D
M(&%N(&5M86EL(&-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'
M<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@8VQI
M96YT<R!P;&5A<V4@=FES:70@)7,`5&AI<R!M97-S86=E('=A<R!W<FET=&5N
M(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN
M`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E
M<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S
M>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+@!4:&ES('9A;'5E(&UU
M<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R
M;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AU;F1E<@!4:6-K971S`%1I;64`5&EM
M92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,
M97-T90!4:71L90!4:71L92`H=&]O;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT
M:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M
M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(
M5$U,(%-O=7)C90!4;V=O`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`5&]P`%1O
M<"!F<F%M92`H7W1O<"D`5')A;G-L871I;VYS`%1R:6YI9&%D(&%N9"!4;V)A
M9V\`5')U92!O<B!F86QS90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)
M4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA
M;F1S`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%52
M3`!54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0`
M55),.@!59V%N9&$`56MR86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E
M8W1O<GDN`%5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W
M:&5N('-I9VYI;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F
M;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N
M(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`
M56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,B+@!5;F%B;&4@=&\@
M8VAE8VL@9FEL92!S:7IE(&]F("(E<R\E<R(N`%5N86)L92!T;R!C;VYN96-T
M('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5
M;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@
M9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R
M>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T
M92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93
M(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D
M96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L
M92!T;R!D96QE=&4@(B5S(CH@)7,N`%5N86)L92!T;R!D96QE=&4@)7,L('1H
M92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T92!61E,@
M9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S
M+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!D
M96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B`B
M)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N`%5N
M86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N86)L92!T
M;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',`56YA8FQE('1O(&QO860@
M=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!M;W9E(%9&4R!F:6QE
M+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@;W!E
M;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`56YA8FQE('1O(&]P96X@5D93(&9I
M;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`56YA8FQE
M('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2X`56YA8FQE
M('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2X`56YA
M8FQE('1O(')E860@9FEL93H@`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T
M(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN
M871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA;64@
M5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y
M.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@
M=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O('1R
M86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I
M(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F%B
M;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N
M`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S="!A8W1I
M;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T
M:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@`%5N
M9FEL960`56YI8V]D92`H551&+3@I`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N
M:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YI=&5D(%-T871E<R!-:6YO
M<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N:VYO=VX`56YK;F]W;B!A<&EM
M<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN;W=N(&-L:6US9VED("A#;&EE
M;G0@365S<V%G92!)1"DN`%5N:VYO=VX@;&]C871I;VX@<')O=FED960N`%5N
M:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N
M="!E;&5M96YT`%5N;F%M960`56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T
M(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R('-E
M8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@
M;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L
M;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C
M;VQO<@!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D871E`%5P9&%T92`E<P!5
M<&1A=&4@=7-E<@!5<&1A=&5D("(E<R(N`%5P9W)A9&4@<V-R:7!T(&1E;&5T
M960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL
M97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R
M;VUA;B!N=6UB97)S`%5R=6=U87D`57-E($-U<G)E;G0Z("5S`%5S92!34TP`
M57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E
M<G9E<BX`57-E<@!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`
M57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R
M871I;VX`57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R
M('1H:7,@<VET92X`57-E<B!A8V-O=6YT(&YO="!F;W5N9`!5<V5R;F%M90!5
M<V5R;F%M92`B)7,B(&%L<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`57-E<FYA
M;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E
M8W1O<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N
M<R!F;W5N9"!I;F-L=61E.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F
M<F]M(&YO=RX`5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@
M)7,N`%9A;'5E<P!686QU97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T=0!687)I
M86)L90!696YE>G5E;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S
M<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R
M<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`
M5F5R=&EC86PZ`%9E<GD@2&EG:`!6:65T($YA;0!6:65T;F%M97-E("A625-#
M24DI`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6:65W(&%S
M("5S`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5
M+E,N`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET86QY('9I
M82!33510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9
M($923TT@)7,N`%=)3B!V:6$@2%144`!786QL:7,@86YD($9U='5N80!787)N
M:6YG`%=E`%=E871H97(@1F]R96-A<W0`5V5A=&AE<B!D871A('!R;W9I9&5D
M(&)Y`%=E8@!796(@4VET90!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S
M`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E3
M3RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H
M;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI
M;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_
M`%=H97)E:7,@075S=')A;&EA(&UA<`!7:&EC:"!P:&%S97,`5VAI8V@@<&QU
M9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+@!7:61T
M:`!7:61T:"!I;B!#4U,@=6YI=',`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@
M=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H
M(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I;F0`5VEN
M9"!%87)L>0!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D
M;VT`5VES:&QI<W0`5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!7<F]N
M9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F
M;W5N9"`E9"X`5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L
M(&9O=6YD("5D+@!7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&
M4R!F:6QE+@!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S
M($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV
M92!.86UE`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E
M>'1E;G-I;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S
M`%EE<RP@22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@
M6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R
M92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RX`
M66]U(&%R92!N;W0@875T:&5N=&EC871E9"X`66]U(&-A;FYO="!H879E('1H
M92`G7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO
M="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P
M(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R
M<F5S<&]N9&EN9R!F:65L9',@:6X@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D
M(&]U="X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M
M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE
M(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N
M=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4
M<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R
M92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE
M;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U
M(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O
M`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U
M(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU
M<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E
M8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H
M92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A
M8W1I;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R
M>2!N86UE+@!9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@
M;G5M8F5R`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO
M9VEN(&%G86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R
M97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@061D<F5S<R!H
M87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S
M<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I
M;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N
M9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@
M=&\@=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U
M(&UU<W0@=7-E(&$@9&EF9F5R96YT(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0N
M`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T
M(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B
M;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!B<F]W<V5R(&%P<&5A
M<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U
M<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M
M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R
M="!T:&ES(&9E871U<F4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T
M('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0
M('1O('!R:6YT+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U
M;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"X`66]U<B!D969A=6QT(&ED
M96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!L;V=I;B!H87,@97AP:7)E
M9"X`66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO
M;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES
M('-E<W-I;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U
M<B!P87-S=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B
M965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y
M;W5R(&YE=R!P87-S=V]R9"X`66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"X`
M66]U<B!R96UO=&4@<V5R=F5R<SH`675G;W-L879I80!:86ER90!:86UB:6$`
M6FEM8F%B=V4`6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`
M6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI
M;F5S70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]#3$D`7T1E
M;&5T92!2;W<`7T=R;W5P<P!?2&5L<`!?26UA9V4@4')O<&5R=&EE<RXN+@!?
M3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN:RXN+@!?3W!T:6]N<P!?4&5R
M;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]3971U<`!?5&%B;&4@4')O<&5R
M=&EE<RXN+@!?57-E<G,`861D<F5S<R!B;V]K`&%D9')E<W-E92!U;FMN;W=N
M`&-A;&5N9&%R`&-A;&T`8V%N;F]T(&-R96%T92!O=71P=70@9FEL90!C86YN
M;W0@;W!E;B!I;G!U=`!C;&EC:R!H97)E`&-O;6UA;F0@;&EN92!U<V%G92!E
M<G)O<@!C;VYF:6=U<F%T:6]N(&5R<F]R`&-R:71I8V%L('-Y<W1E;2!F:6QE
M(&UI<W-I;F<`9&%T82!F;W)M870@97)R;W(`961I=`!E;G1R>2!N;W0@9F]U
M;F0`9F%L;&EN9P!F:6QE`&9R;VT@=&AE("5S("@E<RD@870@)7,@)7,`9W5S
M=&EN9P!H.@!H;W-T(&YA;64@=6YK;F]W;@!I;6UE9&EA=&4`:6YP=70O;W5T
M<'5T(&5R<F]R`&EN=&5R;F%L('-O9G1W87)E(&5R<F]R`&QI;F5S70!M:VES
M;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RX`;F%M90!N;W0@
M:6UP;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D`'!E<F-E
M;G0`<&5R;6ES<VEO;B!D96YI960`<&EX96QS`')E;6]T92!E<G)O<B!I;B!P
M<F]T;V-O;`!R:7-I;F<`<V5R=FEC92!U;F%V86EL86)L90!S:&]W(&1I9F9E
M<F5N8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S=&5A9'D`<WES=&5M(&5R<F]R
M`'1A<VL@;&ES=`!T96UP;W)A<GD@9F%I;'5R90!T>7!E('1H92!P87-S=V]R
M9"!T=VEC92!T;R!C;VYF:7)M`'5N;F%M960`=7-E<B!S96QE8W0`=D-A<F0`
M=SH`4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C$*4F5P;W)T+4US9VED
M+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A
M=&4Z(#(P,#8M,#(M,3<@,3`Z,#`K,#$P,`I03RU2979I<VEO;BU$871E.B`R
M,#`V+3`R+3$W(#$P.C,X*S`Q,#`*3&%S="U4<F%N<VQA=&]R.B!,87-Z;&\@
M3"X@5&]R;F]C:2`\=&]R;&%S>D!X96YI82YS;W1E+FAU/@I,86YG=6%G92U4
M96%M.B!(=6YG87)I86X@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/@I-24U%+59E
M<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]
M:7-O+3@X-3DM,@I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"@`@
M*"5S(&YA<'!A;"!E>F5L]71T*0`@*$%L="UB:6QL96YT>?L@)7,I`"`H)7,@
M;F%P(&WZ;'9A*0`@*&UA*0`@*&AO;&YA<"D`("AT96=N87`I`"`Z(``B)7,B
M(&YE;2!A;&OV;GEV=.%R+@`B)7,B(&YE;2#I<G;I;GEE<R!VX6QA<WITX7,N
M`"(E<R(@;FEN8W,@:V]N9FEG=7+A;'9A(&$@2&]R9&4@4F5G:7-T<GEB96XN
M`"(E<R(@9F%S=')U:W3Z<F$M;65G:F5L96[M=/4@;F5M('1A;.%L:&%T\RX`
M(B5S(BUT(&AO>GKA861T=6L@82!C<V]P;W)T;VMH;WHN`"(E<R(M="!H;WIZ
MX6%D='5K(&$@:F]G;W-U;'1SX6=I(')E;F1S>F5R:&5Z+@`B)7,B+70@;F5M
M(&AO>G1U:R!LZ71R93H@)7,N`"4N,F9-0B!F96QH87-Z;N%L="!A("4N,F9-
M0B!M96=E;F=E9&5T=&+U;"`H)2XR9B4E*0`E9"`E<R#I<R`E<P`E9"!N87`@
M;?IL=F$@;&5JX7(@:F5L<WIA=N%N86L@Z7)VZ6YY97-SZ6=E+@`E9"!N87!O
M<R!E;/5R96IE;'KI<P`E<R`M($9I9WEE;&UE>G1E=.ES`"5S(&QE;GEO;6%T
M`"5S(&MA<F)A;G1A<G3A<VD@9F5L861A=&]K("T@;65G97+U<^UTZ7,`)7,@
M8F7A;&SM=.%S`"5S(&QO9VEN(&[I=B!I9^EN>6SI<P`E<R!S>F]L9^%L=&%T
MX7-I(&9E;'3I=&5L96L`02`B)7,B(&YE=OL@X6QL;VWA;GD@;>%R(&SI=&5Z
M:6LN`"5S(#H@)7,@)7,`02AZ*2`E<R!KZ7-Z96X@X6QL(&%Z(&%LX6)B:2!K
M87)B86YT87)TX7-I(&9E;&%D871O:R!E;';I9WKI<^ER92Y*96SV;&IE(&MI
M(&%Z;VMA="!A(&9E;&%D871O*&MA*70L(&%M:2AK92ET(&UO<W0@96P@:^UV
MX6X@=NEG97IN:2X`)7,@:VET]FQTZ7-E('-Z_&MSZ6=E<P`E<R!P97)C`"5S
M(&YE;2!T86SA;&AA=/,N`"5S("T@)7,@*/9S<WIE<V5N("5S*0`E<R!C[6UJ
M96=Y>NEK90`E<R!N87!TX7)A`"5S(&9E;&IE9WEZZ7-E:0`E<R!F96QA9&%T
M;&ES=.%J80`E<SH@3&5H971SZ6=E<RP@:&]G>2!E>B!A(&QE=NEL('9A;/-J
MX6)A;B!N96T@82!M96=A9&]T="!F96QA9/-T\VP@<WKA<FUA>FEK+B!';VYD
M;VQJ82!M96<L(&UI96SU='0@<N%K871T:6YT('9A;&%M:7)E+"!V86=Y('-Z
M96WI;'EE<R!I;F9O<FWA8VGS="!A9"!M96<N`"P@<WKI;&SV:^ES96L`+"`E
M<R`E<RUS('-ZZ6QL]FOI<V5K`"P@=N%L=&]Z\R`E<R#I<R`E<R!K]GKV='0`
M+2T@=N%L87-S>F]N("TM`#$R(/-RX7,@9F]R;>%T=6T`,C0@\W+A<R!F;W)M
MX71U;0`R-"#S<F$`/$5L]7KU`$5Z96X@8FQO:VL@:&%S>F[A;&%TX6AO>B!E
M9WD@861A=&+A>FES(&%L<F5N9'-Z97(@<WK\:W/I9V5S+@!(96QY<F5H;WIH
M871A=&QA;B!H:6)A('3V<G3I;G0`02!L97;I;"!T:71K;W/M=.%SX6AO>B!E
M9WD@;GEI;';A;F]S(%!'4"!K=6QC<R!S>OQK<^EG97,N`$$@9&EG:73A;&ES
M86X@86SA[7)T(&QE=NEL(&5L;&5N]7)ZZ7/I:&5Z(&5G>2!N>6EL=N%N;W,@
M4$=0(&MU;&-S('-Z_&MSZ6=E<RX`02!T:71K;W/M=&]T="!L97;I;"!D96OS
M9&]LX7/A:&]Z(&5G>2!N>6EL=N%N;W,@4$=0(&MU;&-S+"!E9WD@=&ET:V]S
M(%!'4"!K=6QC<R#I<R!E9WD@:F5L;6]N9&%T('-Z_&MSZ6=E<RX`02!L97;I
M;"!D:6=I=.%L:7,@86SA[7+A<^%H;WH@96=Y(&YY:6QVX6YO<R!01U`@:W5L
M8W,L(&5G>2!T:71K;W,@4$=0(&MU;&-S(.ES(&5G>2!J96QM;VYD870@<WK\
M:W/I9V5S+@!!('1I=&MO<^UT;W1T(&QE=NEL(&1E:_-D;VSA<^%H;WH@96=Y
M(&YY:6QVX6YO<R!3+TU)344@:W5L8W,L(&5G>2!T:71K;W,@4R]-24U%(&MU
M;&-S(.ES(&5G>2!J96QM;VYD870@<WK\:W/I9V5S+@!!(&QE=NEL(&1I9VET
MX6QI<R!A;.'M<N%SX6AO>B!E9WD@;GEI;';A;F]S(%,O34E-12!K=6QC<RP@
M96=Y('1I=&MO<R!3+TU)344@:W5L8W,@Z7,@96=Y(&IE;&UO;F1A="!S>OQK
M<^EG97,N`$$@;&5VZ6P@=&ET:V]S[73A<^%H;WH@96=Y(&YY:6QVX6YO<R!3
M+TU)344@:W5L8W,@<WK\:W/I9V5S+@!$Z6QE;/5T="!B;W)U;'0@Z6<`1.EL
M96SU='0@9WEE;F=E(&5S]0!$Z6QE;/5T="!E<_4`1.EL96SU='1I('KA<&]R
M;VL`1.EL96SU='0@:/-ZX7!O<F]K`&1E+V1U`$%022!)1"`H82!P<F]G<F%M
M;WKA<VD@9F5L_&QE="!A>F]N;W/M=/-J82D`17)R]6P@87H@961I=&]R<O-L
M`$[I=FIE9WDN+BX`86)S>B!A;'5L`&%B<WH@:_9ZZ7``3FEN8W,@:F]G;W-U
M;'1SX6=A(&$@5D93(&%L:_9N>79TX7(@;.ET<F5H;WKA<^%H;WHN`$YI;F-S
M(&IO9V]S=6QT<^%G82!A(%9&4R!FX6IL(&SI=')E:&]ZX7/A:&]Z+@!"96IE
M;&5N=&ME>NES:2!I;F9O<FWA8VGS`$IE;'-Z\P!!(&IO9V]S=6QT<^%G(&9E
M;"!V86X@9OQG9V5S>G1V92X`4.EN>OQG>65K`$)E=FET96P`06QC<V]P;W)T
M(&SI=')E:&]ZX7-A`$IO9V]S=6QT<^%G:2!A;&-S;W!O<G0@;.ET<F5H;WKA
M<V$`061D:G5K(&AO>GKA(&ET=#H`VFH@8W-O<&]R="!LZ71R96AO>N%S80#:
M:B!J;V=O<W5L='/A9R!LZ71R96AO>N%S80!!;&-S;W!O<G0@:&]Z>N%A9.%S
M82`B)7,B+6AE>@!*;V=O<W5L='/A9VD@86QC<V]P;W)T(&AO>GKA863A<V$@
M(B5S(BUH97H`VFH@9F5L:&%S>F[A;/,@;.ET<F5H;WKA<V$Z`-IJ(&]S>FQO
M<"!H;WIZX6%DX7-A`-IJ('1A9V]K(&9E;';I=&5L90#::B!PX7(@:&]Z>N%A
M9.%S80!!*'HI("5S(&UE;OQT(&%D:G5K(&AO>GKA(&$@36]Z:6QL82!M96[\
M<V]R:&]Z`$%D:G5K(&AO>GKA(&$@8^UM:F5G>7KI:VAE>CH`061J=6L@:&]Z
M>N$@82!C[6UJ96=Y>NEK96UH97H`VFH@9F5L:&%S>F[A;/,@:&]Z>N%A9.%S
M80`B)7,B(&9E;&AA<WINX6SS="!H;WIZX6%D='5K(&$@<F5N9'-Z97)H97HL
M(&1E(&YE;2!S:6ME<OQL="!A('3V8F)I(&)E:F5L96YT:V5ZZ7-I(&%D870@
M=.%R;VSA<V$Z("5S+@`B)7,B(&9E;&AA<WINX6SS="!F96QV971TZ6L@82!R
M96YD<WIE<F)E+B!-;W-T(&WA<B!B96IE;&5N=&ME>FAE="X`02!R96YD<WIE
M<FAE>B!N96T@861H873S:R!H;WIZX2#Z:B!F96QH87-Z;N%L\VLN`$/M;0!#
M[6UJ96=Y>NEK`$%D;6EN:7-Z='+A8VGS("T@:F]G;W-U;'1SX6=O:R!A9.%S
M82!T;W;A8F)I(&9E;&AA<WINX6SS:VYA:P!!9&UI;FES>G1RX6-I\P!(:7)D
M973I<V5K`$%F9V%N:7-Z=.%N`$%L8N%N:6$`06QGZ7)I80!!;&EA<P!%;&AE
M;'EE>NES`%)E;F1E>NES.@!A>B#V<W-Z97-E=`!-:6YD96X@;F5M('9E;F3I
M9R!F96QH87-Z;N%L\P!-:6YD96X@8W-O<&]R=`!-:6YD96X@:F]G;W-U;'1S
MX6<`36EN9"!A(&[I9WD@;VQD86QO;B!L96=Y96X@:V5R970`16YG961J_&YK
M(&UE9R!T]F)B(&/M;65T(&ES`$$@<V]R<WKA;6]S(&9E;'-O<F]LX7,@=.UP
M=7-A(';A;'1O>G1A=&AA=/,@;&5G>65N/P!-X7(@;.ET97II:P!)35-0(&)E
M:F5L96YT:V5ZZ7-I('!A<F%MZ71E<F5K`$WA<VEK+"!)35-0(&IE;'-Z\P!-
MX7-I:RP@24U34"!B96IE;&5N=&ME>NES:2!NZ78`3>%S:6L@96UA:6P@8^UM
M`$%L=&5R;F%T[78@<V%B;&]N;VL`06QT97)N873M=B!S>O9V96<Z`$%M97)I
M:V%I(%-Z86UO80!!(&UE9V%D;W1T(.ER=.EK(&YE;2!F;V=A9&AA=/,@96PN
M`$ES;65R971L96X@:&EB82!T]G)TZ6YT+@!!;F1O<G)A`$%N9V]L80!!;F=U
M:6QL80!!;F]N:6T@<')O>'EN(&ME<F5S>G3\;&D@:6YT97)N970@96SI<NES
M`%;A;&%S>@!!;G1A<FMT:7-Z`$%N=&EG=6$@Z7,@0F%R8G5D80!!;&MA;&UA
M>N%S`$%L:V%L;6%ZX7-O:R!L:7-TX6IA`$%Z(&%L:V%L;6%ZX7,@:^ES>BX`
M02!K]GKV<R!TX7)T97+\;&5T(&%L8W-O<&]R=&IA:7)A(&ES(.ER=NEN>65S
M`$KS=N%H86=YX7,`2_9R_&QB96S\;&D@;>ER970`X7!R:6QI<P!A<F%B("A7
M:6YD;W=S+3$R-38I`$$@=/9M]G+M=&5T="#A;&QO;>%N>2!MZ7)E=&4`02!T
M]FWV<NUT971T(.%L;&]MX6YY(&YE=F4`0FEZ=&]S(&)E;FYE+"!H;V=Y('3V
M<O9L;FD@:^UVX6YJ82`E<R!B96IE;&5N=&ME>NES:2!I9^EN>>ET/P!":7IT
M;W,L(&AO9WD@=/9R]FQN:2!A:V%R:F$@(B5S(BUT(&%L8W-O<&]R=&IA:79A
M;"!E9WG\='0_`$%R9V5N=.UN80#6<FWI;GEO<G-ZX6<`]G)MZ6YY("A!4DU3
M0TE)+3@I`$W[=NES>F5T`$%R=6)A`%!O:&YP96D`07-C:6D@<F%J>F]K`,%Z
M<VEA+T-S96YD97,M\V-EX6YI('+I9VGS`$OI<FIE;B!A(')E;F1S>F5R(&UE
M9V5R]7/M=.ES="!A(&MA<F)A;G1A<G3A<VD@9F5L861A=&]K(&5L=NEG>NES
M92!E;/5T=#\`2&]Z>N%R96YD96SI<VD@;W-Z;&]P;VL`3F5M;.ET97KU(&-S
M;W!O<G1O="!K[7/I<F5L="!M96<@=/9R]FQN:2X`3F5M;.ET97KU(&IO9V]S
M=6QT<^%G;W0@:^USZ7)E;'0@;65G('3V<O9L;FDN`$YE;6SI=&5Z]2!J;V=O
M<W5L='/A9V]T(&OM<^ER96QT(&UE9R!M96=VX6QT;WIT871N:2X`3F5M;.ET
M97KU(&OV>O9S('3A<G1E<OQL971E="!K[7/I<F5L="!M96<@;65G=N%L=&]Z
M=&%T;FDN`%1U;&%J9&]N<^%G;VL`875G=7-Z='5S`$%U<WIT<N%L:6$`075S
M>G1R:6$`075T:%]C>7)S<6PZ(&$@<WK\:W/I9V5S(&EM87`@8O5V[73I<R!N
M96T@=&%LX6QH873S+@!!=71H7V-Y<G5S.B!A(&CA='3I<G-Z;VQGX6QT873A
M<R!N96T@<F5N9&5L:V5Z:6L@82!K[7;A;G0@:^EP97-SZ6=E:VME;"X`075T
M:%]C>7)U<SH@82!S>OQK<^EG97,@:6UA<"!B]7;M=.ES(&YE;2!T86SA;&AA
M=/,N`$%U=&A?9G1P.B!A('-Z_&MSZ6=E<R!F='`@8O5V[73I<R!N96T@=&%L
MX6QH873S+B!&;W)D[71S82!L92!A(%!(4"UT(&%Z("TM96YA8FQE+69T<"!O
M<&-I\W9A;"X`075T:%]I;6%P.B!A('-Z_&MSZ6=E<R!I;6%P(&+U=NUTZ7,@
M;F5M('1A;.%L:&%T\RX`075T:%]K<F(U.B!A('-Z_&MSZ6=E<R!K<F(U(&+U
M=NUTZ7,@;F5M('1A;.%L:&%T\RX`075T:%]L9&%P.B!N96T@:&]Z:&%T\VL@
M;.ET<F4@^FH@9F5L:&%S>F[A;/-K($%C=&EV92!$:7)E8W1O<GD@97-E=.EN
M`$%U=&A?;&1A<#H@9F5L:&%S>F[A;/-K(&YE;2!T]G+V;&AE=/5K($%C=&EV
M92!$:7)E8W1O<GD@97-E=.EN`$%U=&A?;&1A<#H@82!S>OQK<^EG97,@3$1!
M4"!B]7;M=.ES(&YE;2!T86SA;&AA=/,N`$%U=&A?;&1A<#H@)7,@9F5L:&%S
M>F[A;/,@:&]Z>N%A9.%S82!N96T@<VEK97+\;'0N($$@<WIE<G9E<B!VX6QA
M<WIA.B``075T:%]L9&%P.B`E<R!F96QH87-Z;N%L\R!T]G)LZ7-E(&YE;2!S
M:6ME<OQL=`!!=71H7VQD87`Z("5S(&9E;&AA<WINX6SS(&%D871A:6YA:R!M
M96?Z:NUTX7-A(&YE;2!S:6ME<OQL=`!!=71H7VQD87`Z(&$@9F5L:&%S>F[A
M;/-K(&YE;2!M\V1O<^UT:&%T\VL@06-T:79E($1I<F5C=&]R>2!E<V5TZ6X`
M075T:%]M8V%L.B!A('-Z_&MSZ6=E<R!-0T%,(&+U=NUTZ7,@;F5M('1A;.%L
M:&%T\RX`075T:%]S;6)A=71H.B!A('-Z_&MSZ6=E<R!S;6)A=71H(&+U=NUT
MZ7,@;F5M('1A;.%L:&%T\RX`3F5M('-I:V5R_&QT(&%Z($E-05`@<WIE<G9E
M<F5N('9A;/,@9F5L:&%S>F[A;/-A>F]N;W/M=.%S+@!!(&9E;&AA<WINX6SS
M87IO;F]S[73A<R!N96T@<VEK97+\;'0N`$$@9F5L:&%S>F[A;/-A>F]N;W/M
M=.%S(&YE;2!S:6ME<OQL="X@)7,`02!F96QH87-Z;N%L\R!A>F]N;W/M=.%S
MX70@82!2041)55,@<WIE<G9E<B!E;'5T87/M=&]T=&$N`$YE;2!S:6ME<OQL
M="!A>B!&5%`@<WIE<G9E<FAE>B!V86SS(&9E;&AA<WINX6SS87IO;F]S[73A
M<RX`3F5M('-I:V5R_&QT(&%Z(%--0B!S>F5R=F5R96X@=F%L\R!F96QH87-Z
M;N%L\V%Z;VYO<^UTX7,N`$$@<F5N9&5L:V5ZZ7-R92#A;&SS(&UE>O5K.@!!
M>F5R8F%J9'ISX6X`02!G;VYO<WH@<F5N9'-Z97)G87ID82!M96YT<^EG96D`
M2.%T=.ER`$CA='3I<B!S>NUN`$YE;2!M96=F96QE;/4@:V5R8F5R;W,@:F5L
M<WKS+@!.96T@;65G9F5L96SU(&ME<F)E<F]S(&9E;&AA<WINX6SS;NEV+@!"
M86AA;>%K`$)A:')E:6X`8F%L=&D@*$E33RTX.#4Y+3$S*0!"86YG;&%D97,`
M0F%R8F%D;W,`02!G<F%F:6MU<R#A;&QO;>%N>6]K("(E<R(@86QK]FYY=G3A
M<F$@;F5M('1A;.%L:&%T\RX`86QA<'9O;F%L;VX`1F5HZ7)O<F]S>F]R<WKA
M9P!"96QG:75M`$)E;&EZ90!"96YI;@!"97)M=61A`$)H=73A;@!3>OQL973I
M<VYA<`!!("(E<R(@8FQO:VL@82`B)7,B('!R;V=R86UM86P@;F5M('1A;.%L
M:&%T\RX`2^EP97)N>?5RZ7-Z(&)EX6QL[73A<P!+Z7!E<FYY]7+I<WH@=.UP
M=7,`9NEL:_9VZ7(`0F]L[79I80!+961V96YC('=E8F/M;65K`$ME<F5T`$ME
M<F5T=F%S=&%G<^%G.@!+97)E=&5K`$)O<WIN:6$M2&5R8V5G;W9I;F$`36EN
M9&ME='3U`$)O='-W86YA`&%L=6P`0F]U=F5T+7-Z:6=E=`!"<F%Z[6QI80!"
M<FET($EN9&EA:2WS8V7A;FD@5&5R_&QE=`!"<G5N96D@1&%R=7-S86QA;0!"
M=6QGX7)I80!&96QS;W)O;.%S`$)U<FMI;F$@1F%S;P!"=7)U;F1I`%=E8F]L
M9&%L(&MA<F)A;G1A<G3A<P!#4D,`02!T86[Z<^UT=N%N>79I<W-Z879O;N%S
M:2!L:7-TX6L@*$-23"D@8^UM96D`0V5L;&$@='5L86ID;VYSX6=O:P!!(&-A
M8VAE(&EN:6-I86QI>N%LX7-A(&YE;2!F96IE>O5D]G1T(&)E+@!.87!TX7(`
M3GEU9V]D=`!+86UB;V1Z<V$`2V%M97)U;@!.96T@<VEK97+\;'0@82!J96QS
M>O-T(.%TX6QL[71A;FDL(&9O<F1U;&IO;B!A(')E;F1S>F5R9V%Z9.%H;WHN
M`$$H>BD@(B5S(B#A;&QO;>%N>2!N96T@[7)H873S+@!!(&O\;'/U(&9E;&AA
M<WINX6SS:V%P8W-O;&%T+6ME>F5L]6L@;F5M(&%D;6EN:7-Z='+A;&AA=/-K
M+@!!(&OV=F5T:V5Z]2!)34%0('-Z97)V97(@;F5M(.ER:&5T]2!E;#H@)7,`
M02AZ*2`B)7,B(.%L;&]MX6YY(&YE;2!N>6ET:&%T\R!M96<N`$MA;F%D80!-
MZ6=S90!-Z6=S92!K_&QD]FL@:&EB86IE;&5N=.ES=`!!*'HI("(E<R(@X6QL
M;VWA;GD@;F5M('3V<O9L:&5T]2X`3F5M('1A;.%L:&%T\R!A>B!I9&5I9VQE
M;F5S(.%L;&]MX6YY;VMA="!T87)T86QM87KS(&%L:_9N>79TX7(N`$$@)W1A
M<F=E=$9I;&4G('!A<F%MZ71E<B!M96=A9.%S82!NZ6QK_&P@;F5M(&9O;'ET
M871H871J=6LN`$$H>BD@(B5S(B!A;&OV;GEV=.%R(&YE;2!T]G+V;&AE=/4N
M`$YE;2!T]G+V;&AE=/4L("5D(&%L8W-O<&]R=&IA('9A;BX`07H@^FH@<V]R
M8F%R96YD97KI<R!N96T@;&5H971SZ6=E<RP@82!M96=A9&]T="!A9&%T;VL@
M<WKA;6$@;F5M(&5G>65Z:6L@82!TX7)O;'1A:^EV86PN`$$@;65G861O='0@
M<WKA;7)A(&YE;2!K_&QD:&5T]2!E;"!A>B#\>F5N970N`%KV;&0M9F]K:2US
M>FEG971E:P#!8G)A<WKV=F5G`%-Z;VQGX6QT873S`$MA=&5G\W)IX6L@Z7,@
M:F5L]FSI<_QK`$MA:FWA;BUS>FEG971E:P!-;V)I;"!T96QE9F]N`$-E;&QA
M='5L86ID;VYSX6=O:P!#96QL82!B96QS]2!M87)G\SH`0V5L;&%T=6QA:F1O
M;G/A9V]K`$-E;&SA:R!K]GKV='1I('+I<SH`36]B:6P@=&5L969O;@!K96QT
M82`H25-/+3@X-3DM,30I`&OV>NEP`$OV>NEP+6%F<FEK86D@2_9Z=.%R<V%S
MX6<`:V5L970M975R\W!A:2`H25-/+3@X-3DM,BD`02!T86[Z<^UT=N%N>2!R
MZ7-Z;&5T96D`02!T86[Z<^UT=N%N>2!T=6QA:F1O;F]S80!486[Z<^UT=N%N
M>2!F96QH87-Z;N%LX7-I(&ERX6YY96QV96L`0W/A9`!6X6QT;WIT873A<P!!
M(&IE;'-Z\R#A=.%L;.UTX7-A`$%Z(-9N(.%L=&%L(&5L:_QL9/9T="!L979E
M;&5K96X@<WIE<F5P;/4@;NEV(.ES(&/M;2!M96=VX6QT;WIT873A<V$N`$$@
M:F5L96X@:V]N9FEG=7+A8VGS8F%N(&YE;2!L96AE='/I9V5S(&$@:F5L<WIA
M=F%K(&WS9&]S[73A<V$N($9O<F1U;&IO;B!A(')E;F1S>F5R9V%Z9.%H;WHN
M`$MA<F%K=&5R`$QI;E]K96QL96[U<GKI<RXN+@!#:&EL90!+[6YA`&OM;F%I
M+"!E9WES>F5R^W/M=&5T="`H1T(R,S$R*0!K[6YA:2P@:&%G>6]MX6YY;W,@
M*$)I9S4I`%;A;&%S<WIO;B!K:2!E9WD@86QK86QM87KA<W0Z`%;A;&%S<WIO
M;B!J96QS>O-T`%;A;&%S<WIO;B!E9WD@9F5L:&%S>F[A;/-N979E=`!6X6QA
M<W-Z82!K:2!A(&3A='5M;VL@;65G:F5L96[M=.ES:2!F;W)MX6KA=#H`5N%L
M87-S>F$@:VD@82!F96QS;W)O;.%S('3M<'5SX70@*'-ZX6UO>F]T="!L:7-T
MX6MNX6PI`$MA<N%C<V]N>2US>FEG971E:P!!*'HI("5S(&-L87-S(&1E9FEN
M[6-I\VIA(&YE;2!T86SA;&AA=/,N`$1E<OQL=`!4]G)L:2!A>B!-4T]F9FEC
M92!T86=E:V5T`$$@;&5KZ7)D97KI<R!T]G)LZ7-E`"5S(&9E;&AA<WINX6SS
M('3V<FSI<V4`02!F96QH87-Z;N%L\R!T]G)LZ7-E`$$@9F5L:&%S>F[A;/,@
M861A=&%I;F%K('3V<FSI<V4`17-TZ7)E(&1E<OQL="#I9P!!(&9O;'ET873A
M<VAO>B!K871T:6YT<V]N(&%Z(&5GZ7)R96P`0VQI8VMA=&5L;"!S>F]L9^%L
M=&%TX7,@2%144"UN(&ME<F5S>G3\;`!!>B!A8FQA:R!B97KA<N%S80!";W)U
M;'0@Z6<`4F5G9V5L(&9E;&CU<R!I9/4`1F5L:/5S(&ED]0!+\VMU<WHM<WII
M9V5T96L`5/QN=&5S<_QK(&5L(&%Z(&]L9&%L<_,@;65N_'0`UG-S>F5ZX7)T
M(&ME<F5T96L`2V]L=6UB:6$`4WKM;@!3>NUN=N%L87-Z=/,`4WKM;G;A;&%S
M>G3A<P!/<WIL;W!O:SH`07H@;W-Z;&]P;VL@8^UM96D`5FEC8V5K`%!A<F%N
M8W,`4&%R86YC<^ER=&5L;65Z]0!-96=J96=Y>NES`$[I=BP@96QN979E>NES
M`$-O;6]R92US>FEG971E:P!#Z6<`4WKA;>UT\V?I<&5K`$ED]6KA<N%S:2!H
M96QY>F5T`$ED]6KA<N%S:2!H96QY>F5T`$O\;/9N8G/I9V5K(&$@:V]N9FEG
M=7+A8VGS8F%N`$OI>FES>N%M[73S9^EP96MK96PL(&]K;W-T96QE9F]N;VMK
M86PL($]U=&QO;VMK86P@=F%L\R!A9&%T<WII;FMR;VYI>N%LX7,@:V]N9FEG
M=7+A8VGS:F$`02!K;VYF:6=U<N%C:?,@;>%R(&YE;2#I<G;I;GEE<RX`)7,@
M:V]N9FEG=7+A8VGS:F$`02!J96QS>O,@;65G97+U<^UTZ7-E`$MO;F?S`$MO
M;F?S:2!$96UO:W)A=&EK=7,@2_9Z=.%R<V%SX6<`4VEK97)T96QE;B!A(&MA
M<&-S;VQA="X`4VEK97)T96QE;B!A(&MA<&-S;VQA=#H@`$$@;GEI;';A;F]S
M(&MU;&-S;VL@<WIE<G9E<F4@96QU=&%S[71J82!A(&MA<&-S;VQA=&]T+@!!
M(&YY:6QVX6YO<R!K=6QC<V]K('-Z97)V97)E(&5L=71A<^UT:F$@82!K87!C
M<V]L871O="X@3VMA.B`E<R`H)7,I`%-I:V5R=&5L96X@87H@1E10('-Z97)V
M97)R96P@=F%L\R!K87!C<V]L870N`%!A<G1N97)E:P!!('!A<G1N97)E:V5T
M('-I:V5R97-E;B!H;WIZX6%D='5K(&$@8^UM:F5G>7KI:^EH97HN`$$@=/9M
M]G+M=&5T="#A;&QO;>%N>2!T[7!U<V$Z(``B)7,B('1A<G1A;&UA`$9O;'ET
M873A<P!#;V]K+7-Z:6=E=&5K`%/\=&D`3>%S;VQJ=6L@X70`02!MX7-O;.%S
M(&YE;2!S:6ME<OQL=#H@)7,`02!K:6IE;/9L="!RZ7-Z(&WA<V]LX7-A`%-Z
MX6ULX7KA<VD@87IO;F]S[73S`$-O<W1A(%)I8V$`16QE9N%N=&-S;VYT<&%R
M=`!.96T@<VEK97+\;'0@4$=0+79E;"!T:71K;W/M=&%N:2!A(&QE=F5L970Z
M(`!!(&QE=F5L970@;F5M('-I:V5R_&QT(%!'4"!A;.'M<N%S<V%L(&5L;.%T
M;FDZ(`!!(&QE=F5L970@;F5M('-I:V5R_&QT(&%Z(%,O34E-12!S>F%B=N%N
M>2!S>F5R:6YT('1I=&MO<^UT86YI+@!!(&QE=F5L970@;F5M('-I:V5R_&QT
M(%,O34E-12!A;.'M<N%S<V%L(&5L;.%T;FDN`$$@<&%R=&YE<B!A9&%T86ET
M(&YE;2!S:6ME<OQL="!E;'3A<F]L;FDN("5S`$%Z($Q$05`@<WIE<G9E<B!N
M96T@Z7)H973U(&5L+@!.96T@<VEK97+\;'0@96QL96[U<FEZ;FD@82!S>N%M
M;.%JX6X@<F5N9&5L:V5ZZ7-R92#A;&SS(/9S<WIE9V5T+B`E<P!.96T@<VEK
M97+\;'0@87H@3$1!4"!S>F5R=F5R:&5Z(&MA<&-S;VSS9&YI+@!.96T@<VEK
M97+\;'0@82AZ*2`B)7,B('-Z97)V97)R96P@1E10(&MA<&-S;VQA=&]T(&9E
M;'9E;FYI.B`E<P!.96T@<VEK97+\;'0@;.ET<F5H;WIN:2!A(&OV<FQE=NEL
M;&ES=.%T+B`E<P!!>B!A9&%T;VL@4$=0('1I=&MO<^UTX7-B\VP@=/9R=.EN
M]2!D96OS9&]LX7-A(&YE;2!S:6ME<OQL=#H@`$%Z(&%D871O:R!3+TU)344@
M=&ET:V]S[73A<V+S;"!T]G)TZ6[U(&1E:_-D;VSA<V$@;F5M('-I:V5R_&QT
M+@!!('!A<G1N97(@=/9R;.ES92!N96T@<VEK97+\;'0N("5S`$$@:_9R;&5V
MZ6QL:7-T82!T]G)LZ7-E(&YE;2!S:6ME<OQL="X@)7,`3F5M('-I:V5R_&QT
M('3V<O9L;FD@82AZ*2`B)7,B('-E='5P('5P9W)A9&4@<')O9W)A;6]T+@!.
M96T@<VEK97+\;'0@;65GX6QL87#M=&%N:2!A(&/M;7IE='0@96UA:6P@8^UM
MZ70N`$YE;2!S:6ME<OQL="!B96]L=F%S;FD@82!T96QJ97,@8^UM:F5G>7KI
M:V5T+@!.96T@<VEK97+\;'0@8F5O;'9A<VYI(&$@=&5L:F5S(&OV<FQE=NEL
M;&ES=.%T+@!.96T@<VEK97+\;'0@8F5O;'9A<VYI(&$@:_9R;&5VZ6QL:7-T
MX6L@=&5L:F5S(&9E;'-O<F]LX7/A="X`02AZ*2`B)7,B('-T<F%TZ6=I82!N
M96T@=&%LX6QH873S+@!!*'HI("(E<R(@86QK]FYY=G3A<B!N96T@:&]Z:&%T
M\R!LZ71R92X`02!N>6EL=N%N;W,@:W5L8W-O="!N96T@<VEK97+\;'0@;65G
M<WIE<F5Z;FD@82!K=6QC<W-Z97)V97)R]6PN`$YE;2!S:6ME<OQL="`B)7,B
M+70@[7+A<VD@8^EL;&%L(&UE9VYY:71N:2X`3F5M('-I:V5R_&QT("5S+70@
M;65G;GEI=&YI+@!!("5S(&MA<F)A;G1A<G3A<VD@;6]D=6P@;F5M(&YY:71H
M873S(&UE9P!!*'HI("(E<R(@86QK]FYY=G3A<B!N96T@;GEI=&AA=/,@;65G
M+@!!>B!,1$%0('-Z97)V97(@;F5M(.ER:&5T]2!E;"X`)7,@;F5M(&]L=F%S
M:&%T\RX`3F5M('-I:V5R_&QT(&$@:^UVX6YT(&9E;&AA<WINX6SS(&IE;'-Z
M87;A="#A=.%L;.UT86YI+B!!>B!M96=A9&]T="!A9&%T;VL@;F5M('9A9WD@
M;F5M('1E;&IE<V5N(&9E;&5L;F5K(&UE9RX@4'+S8N%L:F$@^FIR82P@=F%G
M>2!H82!T;W;A8F)I('-E9^UT<^EG<F4@=F%N('-Z_&MSZ6=E+"!F;W)D=6QJ
M;VX@82!R96YD<WIE<F=A>F3A:&]Z+@!.96T@<VEK97+\;'0@;65G:&%TX7)O
M>FYI(&%Z(&5LZ7+I<VD@:F]G;W-U;'1SX6=O:V%T("A!0TPI`$YE;2!S:6ME
M<OQL="!B96]L=F%S;FD@82!C[6UJ96=Y>NEK970N("5S`$YE;2!S:6ME<OQL
M="!B96]L=F%S;FD@82!K]G)L97;I;&QI<W3A="X@)7,`3F5M('-I:V5R_&QT
M(&)E;VQV87-N:2!A(&OV<FQE=NEL;&ES=.%K870N("5S`$YE;2!S:6ME<OQL
M="!M96=H873A<F]Z;FD@82!S>F5R=F5R(&OI<&5S<^EG96ET`$YE;2!S:6ME
M<OQL="!V:7-S>F'A;&SM=&%N:2!E>B!E<F5D971I(&MO;F9I9W5RX6-I\W0N
M`$$H>BD@(B5S(B!A;&OV;GEV=.%R(&YE;2!T]G+V;&AE=/4N`$YE;2!S:6ME
M<OQL="!E;&UE;G1E;FD@)7,@:V]N9FEG=7+A8VGS="X`3F5M('-I:V5R_&QT
M(&5L;65N=&5N:2!A(&)A8VMU<"!K;VYF:6=U<N%C:?-T+@!.96T@<VEK97+\
M;'0@96QM96YT96YI(&$@8F%C:W5P(&MO;F9I9W5RX6-I\W0Z("5S`$YE;2!S
M:6ME<OQL="!E;&UE;G1E;FD@82AZ*2`B)7,B('-E='5P('5P9W)A9&4@<')O
M9W)A;6]T+@!.96T@<VEK97+\;'0@96QM96YT96YI(&$H>BD@)7,@8F%C:W5P
M(&MO;F9I9W5RX6-I\W0N`$$H>BD@)7,@:V]N9FEG=7+A8VGS<R#A;&QO;>%N
M>70@;F5M('-I:V5R_&QT(&5L;65N=&5N:2X@5F%G>2!H87-Z;N%L:F$@82`E
M<R!O;&1A;&]N(&QE=O4@;&5H973U<^EG96ME="P@=F%G>2!MX7-O;&IA(.%T
M(&%Z(&%LX6)B:2!K\V1O="!I9&4Z("5S+@!!>B!,1$%0('-Z97)V97)E;B!N
M96T@<VEK97+\;'0@96QVZ6=E>FYI(&$@:V5R97/I<W0N`"(E<R(@;F5M('9O
M;'0@=/9R]FQH973U+@!!('!A<G1N97(@861A=&%I="!N96T@<VEK97+\;'0@
M;?-D;W/M=&%N:2X@)7,`3F5M('-I:V5R_&QT(&$@:_9R;&5VZ6QL:7-T82!M
M\V1O<^UTX7-A+B`E<P!.96T@<VEK97+\;'0@96QM96YT96YI("(E<R(@:V]N
M9FEG=7+A8VGS:N%T.B`E<P!!($UO>FEL;&$@;65N_'-O<B!N96T@=&%LX6QH
M873S+B!%;&QE;O5R:7IZ92P@:&]G>2!M96<@=F%N+64@;GEI='9A+@!.96T@
M<VEK97+\;'0@(B5S(B!F96QH87-Z;N%L\VYA:R!J;V=O<W5L='/A9V]T(&%D
M;FD@82AZ*2`B)7,B(&UA<'#A:&]Z.B`E<P!+;W)LX71O<R!S>O9V96<`3W)S
M>N%G`%3A=F]K=&%TX7,`3.ET<F5H;WKA<P!,:6YK(&SI=')E:&]ZX7-A`-IJ
M(&SI=')E:&]ZX7-A`$%L;6%P<.%K(&SI=')E:&]ZX7-A`$%Z(&]B:F5K='5M
M(&SI=')E:&]Z\VKA;F%K(&IO9V]S=6QT<^%G86D`2&ET96QKX7)T>6%S>N%M
M`$AO<G;A=&]R<WKA9P!+=6)A`$IE;&5N;&5G:2`T(&;A>FES`$$@:F5L96YL
M96=I(&9E;&AA<WINX6SS:V%P8W-O;&%T;VL`4&]N=&]S(&ED]0!!(&IE;&5N
M;&5G:2!54DP`2F5L96YL96=I(&9E;&AA<WINX6SS:P!*96QE;FQE9VD@:63U
M:N%RX7,`02!J96QE;FQE9VD@:63U:N%RX7-I(&AE;'EZ970Z`$IE;&5N;&5G
M:2!S=.UL=7,`36EL>65N('!A<F%N8W-O:R!F=7-S86YA:R!L92!A=71O;6%T
M:6MU<V%N(&$@)7-B92!T]G)TZ6[U(&)E:F5L96YT:V5ZZ7-K;W(N`$MI=N%G
MX7,`02!K:6IE;/9L="!RZ7-Z(&MI=N%GX7-A`$-I<')U<P!C:7)I;&P@*$M/
M23@M4BD`8VER:6QL("A7:6YD;W=S+3$R-3$I`&-I<FEL;"UU:W+A;B`H2T])
M."U5*0!#<V5H($OV>G3A<G-A<^%G`$1$`$133B`H861A=&9O<G+A<VQE[7+S
M("T@;.%S9#H@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G
M92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!N87!O;G1A`$1A=&%4<F5E
M(&+V;F?I<WKU`$%D871BX7II<V)A;B!V86SS(&ME<F5SZ7,`1.%T=6T`02!B
M9>ER:V5ZZ7,@;F%P:F$`1.%T=6T@:VEVX6QA<WITX7-A`&YA<'!A;`!/<WIL
M;W`@=/9R;.ES90!D96-E;6)E<@!S>N%M;VL`0F5K97IDZ7,@:VEJ:F5B8@!!
M;&%PZ7)T96QM97IE='0`07H@86QA<.ER=&5L;65ZZ7,@<WIE<FEN=&D@<WKM
M;@!!;&%PZ7)T96QM97KI<R!S>F5R:6YT:2!A>F]N;W/M=/,`06QA<.ER=&5L
M;65Z971T('-H96QL`$1E9FEN[6-I\VL`5/9R;.ES`$$@8V5L;&$@=/9R;.ES
M90!!(&-S;W!O<G0@=/9R;.ES90!!(&YA<&SSX6QL;VWA;GD@=/9R;.ES90!!
M(&IO9V]S=6QT<^%G('3V<FSI<V4`3&5V96QE:R!T]G)LZ7-E`$$@8V5L;&$@
M=/9R;.ES90!!>B!O<WIL;W`@=/9R;.ES90!4]G+V;&K\:R!K:2!A(&UE9VSI
M=O4@86QT97)N873M=B!S86)L;VYT`$$@;&5V96QE:R!T]G)LZ7-E`"(E<R(@
M:F]G;W-U;'1SX6=A:6YA:R!T]G)LZ7-E`%3V<O9L:OQK("(E<R(@:F]G;W-U
M;'1SX6=A:70@Z7,@96YN96L@97-E=&QE9V5S(&%L8W-O<&]R=&IA:70_`$$@
M<V]R('3V<FSI<V4`02!K:7;A;&%S>G1O='0@87IO;F]S[73S('3V<FSI<V4`
M07H@86QM87!PX6L@=/9R;.ES90!!(&IE;&5N;&5G:2!O<WIL;W`@=/9R;.ES
M90!!(&IE;&5N;&5G:2!S;W(@=/9R;.ES90!4]G+V;'3\:R!A*'HI("(E<R(@
M<V5T=7`@=7!G<F%D92!P<F]G<F%M;W0N`$$@:^EZ8F5S[73I<R!I9&5J90!$
MX6YI80!!9&IO;B!L9>URX7-T(&$@<')O8FSI;>%R\VP`3&7M<N%S`%+I<WIL
M971E:R`H82!(;W)D92!L;V=FX6IL8F%N(&ES(&UE9W1A;.%L:&%T\RDZ`$$@
M<NES>FQE=&5K(&$@<F5N9'-Z97)G87ID82!S>N%MX7)A(&OI<WK\;/4@;F%P
M;/-FX6IL8F$@:V5R_&QT96LN`$9E:FQE<WITZ7,`2&%R;6%T<&]N=`!(87)M
M871P;VYT(&IE;&5N;&5G.B``2&%R;6%T<&]N=#H@`&)A;'+S;"!J;V)B<F$@
M[7+A<P!J;V)B<O-L(&)A;')A(.URX7,`0^UM=.%R`$%Z(&ED]7!O;G1O:V%T
M(#(T(/-RX7,@9F]R;>%T=6UB86X@:F5L96[M='/\:R!M96<_`$UE9VIE;&5N
M[73I<VD@8F7A;&SM=.%S;VL`02!RZ7-Z;&5T97,@96SU<F5J96QZZ7,@;65G
M:F5L96[M=.ES90!%;/5R96IE;'KI<R!M96=J96QE;NUTZ7-E("AR97#\;/5T
MZ7)I*0!-96=J96QE;NUTZ7-I(&9O<FWA='5M`,ER=&5S[73I<R!A(&OI>F)E
M<^UT971T(&QE=NEL('-O<G/A<O-L`$1Z<VEB=71I`$YE('3V<O9L:OQK`$$@
M;6%I;G1E;F%N8V4N<&AP(&YE;2#I<FAE=/4@96P@:_9Z=F5T;&5N_&PN`$%Z
M(&5L<_4@<V]R(&$@;65Z]6L@;F5V96ET('1A<G1A;&UA>GIA/R!(82!I9V5N
M+"!J96SV;&IE(&MI(&5Z=#H`1&]M:6YI:V$`1&]M:6YI:V%I($OV>G3A<G-A
M<^%G`$YI;F-S(&WI9R!L;V=I;B!N979E/R!)9^EN>65L:F5N(&5G>65T+@!,
M973V;'3I<P!4]FQT<_QK(&QE("5S+70`5/9L='/\:R!L92!02%`@<')O9W)A
M;2!F;W)MX6KA8F%N(&%Z(&5L:^ES>OQL="!K;VYF:6=U<N%C:?-T+@!,96?V
M<F3\;/4@;&ES=&$`2^%B[73S<WIE<F5K`&5M86EL`$5M86EL8O5L(%--4RUK
M_&QD]2!M96=H86IT\RP@:&$@82!T96QE9F]N=.%R<V%SX6<@8FEZ=&]S[71J
M82!E>G0@82!S>F]L9^%L=&%TX7-T+@!(24)!`$5C=6%D;W(`3?-D;W/M=.%S
M`$)L;VMK(&WS9&]S[73A<P!#<V]P;W)T(&WS9&]S[73A<P!*;V=O<W5L='/A
M9R!M\V1O<^UTX7,`2F]G;W-U;'1SX6=O:R!M\V1O<^UTX7-A`"5S(&IO9V]S
M=6QT<^%G86EN86L@;?-D;W/M=.%S80!-96QY:6L@;W!C:?-K870@=N%L=&]Z
M=&%S<W5K.@`B)7,B(&IO9V]S=6QT<^%G86EN86L@;?-D;W/M=.%S80`E<R!J
M;V=O<W5L='/A9V%I;F%K(&WS9&]S[73A<V$`3VMT873A<P!%9WEI<'1O;0!3
M86QV861O<@!%;&5M+BXN`&%Z("=M)R!B973[('-ZZ6QE<W/I9V4`16UA:6P`
M16UA:6P@8^UM`$%Z(&5M86EL(&/M;65K;F5K(&5G>65Z;FG\:R!K96QL+@!%
M;6%I;"!V:7-S>F%I9V%Z;VSA<W-A;`!%;6%I;"U335,@X71JX7+S`$AA;F=U
M;&%T:6MO;F]K`-QR97,@_'IE;F5T+@!.:6YC<R!I;'EE;BX`5/9R]FQJ_&L@
M:VD@82!K97)E<^ES96ME=`!%;F=E9&K\:R!M96<L(&AO9WD@:^EP96ME="!I
M;&QE<W-Z_&YK(&$@<WKV=F5G8F4@82!&;W3S9V%LZ7)IX6MB\VP_`$QE9WEE
M;B!J;V)B(&5GZ7)G;VUB8F%L(&5LZ7)H973U+"!K;VYT97AT=7-F_&=G]2!M
M96[\/P!!>B!U=&]L<_,@Z78`P71VX6QTX7,@:_QL]FX@86)L86MR80!!9&IA
M(&UE9R!A>G0@82!B:7IT;VYSX6=I(&OI<F3I<W0L(&%M96QY<F4@;6%J9"!V
MX6QA<WIO;&YI82!K96QL(&IE;'-Z87;A;F%K(.%TX6QL[73A<^%H;WHL('!L
M+B`G:&]G>2!H[79JX6L@82!K=71YX6KA=#\G.@!!9&IA(&UE9R!A(&OI<"!5
M4DPM:NET(&ET=`#-<FIA(&)E(&%Z(&%LX6)B:2!B973[:V5T.@!%9WEE;FSM
M=/5I+4=U:6YE80!%<FET<F5A`$AI8F$`2&EB82!T]G)TZ6YT(&$@8FQO:VL@
M;.ET<F5H;WKA<V%K;W(Z("5S`$AI8F$@=/9R=.EN="!A>B!A9&%T<WII;FMR
M;VYI>N%C:?-S(&IE;"!T]G)LZ7-E:V]R.B`E<P!!>B!A9&%T<WII;FMR;VYI
M>N%C:?-S(&YA<&SSX6QL;VWA;GD@=/9R;.ES92!N96T@<VEK97+\;'0Z("5S
M`$AI8F$@=/9R=.EN="!A>B!A9&%T;&5KZ7+I<V)E;CH@)7,`2&EB82!T]G)T
MZ6YT(&$@:F5L<WKS(&UE9W;A;'1O>G1A=.%S86MO<CH@)7,`2&EB82!A>B!E
M;6%I;"#\>F5N971B96XN`$$H>BD@(B5S(B#A;&QO;>%N>7)A(&YE;2!S:6ME
M<OQL="#M<FYI+@#)<WIT;W)S>N%G`$5T:?-P:6$`3F5M>F5T:7/I9V5K`$5U
M<O-P80`Q-2!P97)C96YKZ6YT`#(@<&5R8V5N:^EN=``S,"!MX7-O9'!E<F-E
M;FOI;G0`-2!P97)C96YKZ6YT`&UI;F1E;B!B96IE;&5N=&ME>NES:V]R`&;I
M;/-RX6YKZ6YT`'!E<F-E;FOI;G0`4.EL9&$@Z7)TZ6ME:SH`5NEG<F5H86IT
MX7,`3GEI<W-U:R!S>NET`$IE;&5N[71S_&L@;65G(&%Z(&]L9&%L<_,@;65N
M_'0`271T("<I)R!K96QL96YE(&OV=F5T:V5Z>F5N`$ET="!C<W5P87-Z('-Z
M\VYA:R!V86=Y(&EDZ7KU:F5L8F5N(&QE=O4@:V5R97/I<VD@:VEF96IE>NES
M;F5K(&ME;&QE;F4@;&5N;FEE`$%Z(.ER=NEN>65S<^EG(&QE:N%R871A`$MI
M=&5V]0!3>NUN`$$@:V]N9FEG=7+A8VGS($944"UN(.%T('9A;/,@9F5L=/9L
M=.ES90!!('-Z96WI;'EE<R!B9>%L;.UTX7-O:V%T(&YE;2!S:6ME<OQL="!B
M96]L=F%S;FDN`$%Z($Q$05`@<WIE<G9E<B!N96T@Z7)H973U(&5L+@!!>B!3
M34(@<WIE<G9E<B!N96T@Z7)H973U(&5L+@!.96T@<VEK97+\;'0@82AZ*2`B
M)7,B+6+U;"!T]G)TZ6[U(&WA<V]LX7,N`$YE;2!S:6ME<OQL="!A*'HI("(E
M<R(M8F4@=/9R=.EN]2!MX7-O;.%S+@!.96T@<VEK97+\;'0@^FH@4T%33"!K
M87!C<V]L871O="!LZ71R96AO>FYI+@!.96T@<VEK97+\;'0@82AZ*2`B)7,B
M+6)E('3V<G3I;O4@X71H96QY97KI<RX`P6QL;VWA;GEH;WIZX6;I<NES:2!H
M:6)A.B`E<P!4:7-Z=&$`1F%L:VQA;F0M<WII9V5T96L@*$UA;'9I;F%S*0!&
M87)O92US>FEG971E:P!(96QY<F5H;WIH871A=&QA;B!H:6)A.@!&87@`1F%X
M`&9E8G)UX7(`2/5MZ7)SZ6ML973I<GIE=`!(]6WI<G/I:VQE=.ER>F5T.B``
M16=Y+65G>2!ZX7!O<@!3>O-R=N%N>6]S86X@:/-ZX7!O<F]K`$UE>O4@;>%T
M<FEX`$9I9VQE="!#05!40TA!("AB973[:VER86OS(&AU;>%N=&5S>G0I`$9I
M9'IS:0!&X6IL`$$@9N%J;&]K('-ZX6UA.B`E<P!!(&;A:FQO:R!S>N%M83H@
M)7,`1N%J;"!M96YE9'IS97(`1N%J;&[I=@!&X6IL(&MI:F5L]FSI<P!&X6IL
M(&9E;'3V;'3I<V4`1N%J;&]K(&9E;'3V;'3I<V4@;F5M(&QE:&5T<^EG97,N
M`%-Z^W+U:P!&:6YN;W)S>N%G`&5L<_4@9NEL`&5L<_4@;F5G>65D`%;A;'1O
M>F%T;&%N(&WI<F5T87+A;GD`5/QK<O9ZZ7,@*&;V;"]L92D`2_9D`"5S(&UA
M<'!A(&YE;2!LZ71E>FEK`$)E=/MS>NUN`,ET96QE:P!/;'EA;B!B]FYGZ7-Z
M]6L@<WKA;>%R82P@86UI:R!N96T@:F5L96[M=&EK(&UE9R!A(&OI<&5K970`
M16SU<F5J96QZZ7,@*')E</QL]73I<FDI`$%Z(&5L]7)E:F5L>NES(&ED]71A
M<G1A;6$@;F%P;VMB86X@*&%Z(&5L]7)E:F5L>NES(&YA<'!A;&D@Z7,@Z6IS
M>F%K86D@861A=&]K870@=&%R=&%L;6%Z+"!E>NER="!A(&YA9WD@<WKA;6]K
M('-ZZ6QE<R!B;&]K:V]T(&5R961MZ6YY97IN96LI`$5L9F5L96IT971T92!A
M(&IE;'-Z87;A=#\`VW)L87!K97IE;.ES`$EDZ7IE=`!)9.EZ970@9F%J=.%J
M80!)9.EZ971E:P!)9.EZ971E:R`R`$;S<G5M;VL`5&]VX6)B[73A<V]K`%#I
M`$9R86UE+65K`$9R86YC:6%O<G-ZX6<`1G)A;F-I86]R<WKA9P!&<F%N8VEA
M($=U>6%N80!&<F%N8VEA(%!O;&ENZ7II80!&<F%N8VEA($3I;&D@5&5R_&QE
M=&5K`$9E;&%D\P!)<N%N>3H@`%+I<WIL971E<R!L9>URX7,`=&5L:6AO;&0`
M5&5L:F5S(&[I=@!'86)O;@!-96QY:6L@9V%LZ7)IX6+S;"!V96=Y_&L@82!K
MZ7!E=`!+Z7!G86SI<FEA.@!'86UB:6$`2&]Z>G5K(&SI=')E(&$H>BD@)7,@
M:V]N9FEG=7+A8VGS:N%T`$$@:V5L971K97IE='0@:_-D`$=R^GII80!.Z6UE
M=&]R<WKA9P!':.%N80!':6)R86QTX7(`2V5R97-Z=&[I=@!';&]BX6QI<R!B
M9>%L;.UTX7-O:P!-96AE=`!']F1E;`!';V]G;&4@=.ER:^EP`$=O;V=L92!K
M97)E<^ES`$9E:V5T92]F96CI<@!']G+V9V]R<WKA9P!G]G+V9R`H25-/+3@X
M-3DM-RD`1W+V;FQA;F0`1W)E;F%D80!#<V]P;W)T(&%D;6EN:7-Z='+A8VGS
M`$$@8W-O<&]R=&[I=B!M87)A9&AA="#\<F5S96X`1W)O=7!?;&1A<#H@)7,@
M8W-O<&]R="!H;WIZX6%DX7-A(&YE;2!S:6ME<OQL="X@02!S>F5R=F5R(';A
M;&%S>F$Z(`!'<F]U<%]L9&%P.B`E<R!C<V]P;W)T('3V<FSI<V4@;F5M('-I
M:V5R_&QT`$=R;W5P7VQD87`Z("5S(&-S;W!O<G0@861A=&%I;F%K(&UE9_IJ
M[73A<V$@;F5M('-I:V5R_&QT`$-S;W!O<G1O:P!'=6%D96QO=7!E`$=U86T`
M1W5A=&5M86QA`$=U97)N<V5Y`%9E;F3I9R!J;V=O<W5L='/A9V]K`%9E;F3I
M9VOV;GEV`$=U:6YE80!":7-S874M1W5I;F5A`$=U>6%N80!(5$U,07)E82!G
M>>%V87/A9V+S;"!N96T@:&%J;&%N9/,@82!S;W(@=71O;'/S(&-E;&SA:N%T
M('3V<O9L;FDN`$A434Q!<F5A(&=YX79A<^%G8O-L(&YE;2!H86IL86YD\R!A
M('3A8FSA>F%T('5T;VQS\R!O<WIL;W#A="!T]G+V;&YI+@!(5$U,07)E82!G
M>>%V87/A9V+S;"!N96T@:&%J;&%N9/,@82!TX6)LX7IA="!U=&]L<_,@<V]R
MX70@=/9R]FQN:2X`02!(5%10(&9E;&AA<WINX6SS87IO;F]S[73A<R!N96T@
M=&%LX6QH873S+@!(86ET:0!(87-H(&%L9V]R:71M=7,`2_9D`$9E:FSI8P!&
M96ILZ6,`2&5A<F0M(.ES($UC1&]N86QD+7-Z:6=E=&5K`$5R]7,@>FEV871A
M<@!HZ6)E<B`H25-/+3@X-3DM."U)*0!-86=A<W/A9P!396?M='/I9P!396?M
M='/I9R!A('-Z97)K97-Z=/4@:&%S>F[A;&%TX6AO>@!396?M='/I9P!&Z6QT
M96ME`$5Z(&$@9N%J;"!E;&5J93H`;F%G>0!+97ID]6QA<`!6871I:^%N=N%R
M;W,`2V5Z9/5L87``3W1T:&]N:2!C[6T`4WIE;>EL>65S(&%L:_9N>79TX7(`
M3W1T:&]N:2!T96QE9F]N`$AO;F1U<F%S`$AO;F=K;VYG`$AO<F1E`$AO<F1E
M+TMO;&%B.B!H:6+A<R`E<R!834P@861A="!V86X@82AZ*2`E<R#\>F5N971B
M96X`2&]R9&4O2V]L86(Z(&YI;F-S(&$H>BD@)7,@;V)J96MT=6UN86L@;65G
M9F5L96SU(/QZ96YE=`!(;W)D92]+;VQA8CH@;FEN8W,@)7,@=.UP=7/Z(&]B
M:F5K='5M(&$H>BD@)7,@_'IE;F5T8F5N`$AO<F1E+TMO;&%B.B!3:6ME<F5S
M96X@=/9R]FQT_&L@97IT.B`E<R`B)7,B`$AO<F1E+TMO;&%B.B!A>B!I;G1E
M9W+A;/,@<')O9W)A;6AO>B!S>OQK<^EG97,@82`G9&]M>&UL)R!02%`@8O5V
M[73I<P!(;W)D92]+;VQA8CH@;F5M('-I:V5R_&QT(/IJ(%A-3"!FX70@;.ET
M<F5H;WIN:2!A*'HI("5S(&]B:F5K='5M:&]Z`$AO<F1E+TMO;&%B.B!.96T@
M<VEK97+\;'0@=/9R]FQN:2`E<RUT("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!N
M96T@<VEK97+\;'0@;65G:&%TX7)O>FYI(&$@34E-12!)1"UJX70@82!K]G9E
M=&ME>O4@=.UP=7/Z(&UE;&SI:VQE=&YE:SH@)7,`2&]R9&4O2V]L86(Z($YE
M;2!S:6ME<OQL="!S>FEN:W)O;FEZX6QN:2`E<R`B)7,B.B`E<P!(;W)D92]+
M;VQA8CH@3F5M('-I:V5R_&QT(&$@:_9V971K97KU(&OV>O9S('3A<G1E<OQL
M970@<WII;FMR;VYI>N%LX7-A.B`E<P!(;W)D92]+;VQA8CH@:7-M97)E=&QE
M;B!K]GKV<R!TX7)T97+\;&5T("(E<R(`5NUZ<WII;G1E<R!V;VYA;`!6[7IS
M>FEN=&5S(&UA<F?S`%;M>G-Z:6YT97,Z`$AO9WD@:G5T;W1T(&ED93\@*$OI
M<FK\:R#M<FIA(&UE9R$I`$CA;GD@;W-Z;&]P;W0@:^UVX6X@]G-S>F5O;'9A
M<WIT86YI/P!(X6YY(&UE>O4@*&]S>FQO<"D@=F%N/P!(X6YY('-O<G0@:^UV
MX6X@]G-S>F5O;'9A<WIT86YI/P!0X7)A=&%R=&%L;VT`4.%R871A<G1A;&]M
M.B``2'5M;W)I<W3A:P!-86=Y87)O<G-ZX6<`07H@24U!4"!L97;I;&SA9&$@
M;.ET<F5H;WKA<V$@;F5M('-I:V5R_&QT.B`E<P!!>B!)34%0(&QE=NEL;.%D
M82!T]G)LZ7-E(&YE;2!S:6ME<OQL=#H@)7,`07H@24U!4"!L97;I;&SA9.%H
M;WH@=&%R=&]Z\R!K=O-T82!LZ71R96AO>N%S82!N96T@<VEK97+\;'0Z("5S
M`$E0(&/M;0!!>B!)4"!C[6T@;F5M(&AA=.%R;WIH873S(&UE9RX`07H@25`@
M8^UM(&YI;F-S(&$@;65G96YG961E='0@0TE$4B!T87)T;VWA;GEB86XN`%1I
M;'1O='0O;65G=N%L=&]Z;W1T($E0(&/M;2X`4V]R(&)E:6QL97-Z=.ES92!E
M9O9LZ0!)>FQA;F0`8W-A:R!I:V]N;VL`)7,@:6MO;FIA:0!I:V]N;VL@Z7,@
M<WKV=F5G`$%Z(&%Z;VYO<^UT\VAO>B!VX6QA<WIT;W1T(&5L;F5V97KI<SH`
M2&$@82!M96=J96QE;NUTZ7,@;F5M(&UE9V9E;&5L]2P@)7,@96=Y(/IJ(&%B
M;&%K8F%N('9A;/,@;65G;GEI=.%S:&]Z+@!(82#6;B!);G1E<FYE="!%>'!L
M;W)E<G0@:&%S>F[A;"P@Z7,@;F5M(&IE;&5N;F5K(&UE9R!A>B!I:V]N;VLL
M(&%K:V]R(';A;&%S<WIA(&5Z="!A>B!O<&-I\W0L(&UE;&QY96P@:VEK87!C
M<V]L:F$@82!03D<@:^EP96L@=')A;G-Z<&%R96YC:>%JX70N`$AA(&SA=&IA
M(&5Z="!A('-Z]G9E9V5T+"!D92!A(&OI<&5T(&YE;2P@86MK;W(@8O9N9^ES
M>O5P<F]G<F%M:F$@;F5M(&OI<&5S(&UE9VIE;&5N[71E;FD@82!S>F5R=F5R
M<F4@:_QL9&5N9/4@:^EP970N`$5L]7IE=&5S(&[I>F5T.@!!(&OI<"!54DPM
M:F4`02!KZ7`@55),+6IE.@!-96QY:6L@9V%LZ7)IX6+S;"!V86X@82!KZ7``
M2^EP(&5B8O5L(&$@9V%LZ7)IX6+S;#H`2^EP(&9E;'3V;'3I<V4`2^EP96L`
M26UP;W)TX6SA<RP@)60N(&SI<.ES`$%Z(&EM<&]R=.%L="!M97KU.B`E<P!!
M>B!I;7!O<G3A;'0@;65Z]6LZ`%-O<B!B96EL;&5S>G3I<V4@97IA;.$`2&EB
MX7,@<&%R86YC<W!A<F%MZ71E<BX`3F5M(&UE9V9E;&5L]2!A(&)E:F5L96YT
M:V5ZZ7-I(&[I=B#I<R]V86=Y(&$@:F5L<WKS+@!.96T@;65G9F5L96SU(&$@
M9F5L:&%S>F[A;/-I(&[I=B!V86=Y(&%Z(&%L=&5R;F%T[78@8^UM+B!0<O-B
MX6QJ82#Z:G)A('9A9WD@9F]R9'5L:F]N(&$@<F5N9'-Z97)G87IDX6AO>BP@
M:&$@=&]VX6)B:2!S96?M='/I9W)E('9A;B!S>OQK<^EG92X`0F5K97IDZ7,@
M8F5L:F5B8@!);F1I80!%9WEE<R!F96QH87-Z;N%L\VL`26YD;V[I>FEA`$EN
M9F]R;>%C:?,`26YF;W)MX6-I\P!!>B!I;F9O<FWA8VGS(&WA<B!N96T@X6QL
M(')E;F1E;&ME>NES<F4N`$]S>FQO<"!B97-Z^G+A<V$@97IU=.%N`$OI<"!B
M96EL;&5S>G3I<V4`5.%B;.%Z870@8F5I;&QE<WITZ7-E`$QI;FL@;.ET<F5H
M;WKA<V$`3W-Z;&]P(&)E<WKZ<N%S82!E>F5LZ0!/<WIL;W`@8F5S>OIRX7-A
M(&5Z=73A;@!/<WIL;W`@8F5S>OIRX7-A(&5Z96SI`%-O<B!B97-Z^G+A<V$@
M97IA;.$`4V]R(&)E<WKZ<N%S82!E9O9LZ0!"96ME>F3I<R!B96EL;&5S>G3I
M<V4@97IU=.%N`$)E:V5Z9.ES(&)E:6QL97-Z=.ES92!E>F5LZ0!(;WIZ=6YK
M(&SI=')E(&%L=&5R;F%T[78@<V%B;&]N=`!!9&IO;B!M96<@96=Y(&5M86EL
M(&/M;65T+"!M96QY<F4@96QK_&QD:&5T]2!A>B#6;B#Z:B!J96QS>F%V83H`
M0V5L;&$@8F5I;&QE<WITZ7-E(&5Z=73A;@!#96QL82!B96EL;&5S>G3I<V4@
M97IE;.D`3W-Z;&]P(&)E<WKZ<N%S82!E>G5TX6X`3W-Z;&]P(&)E<WKZ<N%S
M82!E>F5LZ0!,979E;&5K(&)E;>%S;VSA<V$`0F5K97IDZ7,@8F5I;&QE<WIT
MZ7-E(&5Z=73A;@!"96ME>F3I<R!B96EL;&5S>G3I<V4@97IE;.D`4V]R(&)E
M<WKZ<N%S82!E>F%LX0!3;W(@8F5S>OIRX7-A(&5F]FSI`$%D:F$@;65G(&$@
M:^UVX6YT(';A;&%S>G0@82!B:7IT;VYSX6=I(&OI<F3I<W)E.@!+Z7`@8F5I
M;&QE<WITZ7-E+VWS9&]S[73A<V$`3&EN:R!B96EL;&5S>G3I<V4O;?-D;W/M
M=.%S80!!('-ZX6ULX6KA;B!N:6YC<R!E;.EG(&9E9&5Z970@_'IE;F5T970@
M:_QL9&5N:2!A(&OV<FQE=NEL;&ES=.%R82X`02!S>N%M;.%JX6X@;FEN8W,@
M96SI9R!F961E>F5T+@!%9^ES>@!%9^ES>B!S>N%M;VL@;&ES=.%J80!(:6+A
M<R]E;&9O9V%D:&%T871L86X@541(("A5<V5R($1A=&$@2&5A9&5R*2X`2&EB
MX7,O96QF;V=A9&AA=&%T;&%N(%I)4"!T]FWV<NUTZ7,`2&EBX7,O96QF;V=A
M9&AA=&%T;&%N(&%L:V%L;6%ZX7,N`$AI8N%S+V5L9F]G861H871A=&QA;B!B
M871C:"!A>F]N;W/M=/,N`$$@:_QL9/9T="!A9&%T(&AI8N%S+V5L9F]G861H
M871A=&QA;BX`2&EBX7,O96QF;V=A9&AA=&%T;&%N(&/M;7KI<RX`2&EBX7,O
M96QF;V=A9&AA=&%T;&%N(&;A:FP@9F]R;>%T=6T`2&EBX7,O96QF;V=A9&AA
M=&%T;&%N(&QI8V5N<WIK=6QC<RX`2&EBX7,O96QF;V=A9&AA=&%T;&%N(';A
M<F]S+@!(:6+A<R]E;&9O9V%D:&%T871L86X@_'IE;F5T=.UP=7,N`$AI8N%S
M+V5L9F]G861H871A=&QA;B!V86=Y(&AIX6YY>O,@<')O9W)A;6]ZX7-I9F5L
M_&QE="UA>F]N;W/M=/,N`$AI8N%S+V5L9F]G861H871A=&QA;B!P87)A;>ET
M97)E:RX`2&EBX7,@87H@;V)J96MT=6T@96SI<NES:2!J;V=O<W5L='/A9V$N
M`$AI8N%S+V5L9F]G861H871A=&QA;B!P87)T;F5R87IO;F]S[73S+@!(:6+A
M<R]E;&9O9V%D:&%T871L86X@=&5R;>EK:_-D+@!(:6+A<R]E;&9O9V%D:&%T
M871L86X@<')O=&]K;VQL+@!(:6+A<R]E;&9O9V%D:&%T871L86X@8^UM>F5T
M=#H@(B5S(@!(:6+A<R]E;&9O9V%D:&%T871L86X@;65G;W-Z=&]T="!O8FIE
M:W1U;0!(:6+A<R]E;&9O9V%D:&%T871L86X@9F5L863S:2!C[6TN`$AI8N%S
M+V5L9F]G861H871A=&QA;B!U;FEC;V1E(&%D870N`$YY:6QVX6YT87)TX7,`
M02!K:6IE;/9LZ7,@:6YV97)TX6SA<V$`27+A;FD@27-Z;.%M($OV>G3A<G-A
M<^%G`$ER86L`S7)O<G-ZX6<`36%N+7-Z:6=E=`!3>O-R=N%N>6]S('II=F%T
M87)O:P!)>G)A96P`02!T86[Z<^UT=N%N>2!K:6%D\VIA`&3U;'0`3VQA<WIO
M<G-ZX6<`2F%M86EC80!J86YUX7(`2F%PX6X`:F%PX6X@*$E33RTR,#(R+4I0
M*0!*97)S97D`2F]R9.%N:6$`:OIL:75S`&KZ;FEU<P!3;W)K:7KA<N%S`&OV
M>NEP<F4@<F5N9&5ZZ7,`<V]R:VEZX7+A<R!M:6YD:^ET(&]L9&%L<F$`<V]R
M:VEZX7+A<R!B86QR80!S;W)K:7KA<N%S(&IO8F)R80!+87IA:'-Z=.%N`%1A
M<G1S=6L@;65G(&%Z(&5R961E=&ET/P!+96YY80!!(&ME<F)E<F]S('-Z97)V
M97(@96QU=&%S[71O='1A(&$@9F5L:&%S>F[A;/-A>F]N;W/M=.%S="X`2V5Z
M9/4@:V5R;F5L9F5J;&5S>G3U:P!+=6QC<R!LZ71R96AO>N%S80!!(&MU;&-S
M(&QE;GEO;6%T80!+=6QC<VAO<W-Z^G/A9P!+=6QC<R!T[7!U<P!!(&MU;&-S
M(&AA<WINX6QA=&$`02!K=6QC<R!MX7(@;.ET97II:R!A(&YY:6QVX6YO<R!K
M=6QC<W-Z97)V97)E;BX`1WEE<F5K96L`2VER:6)A=&D`2V]R96%I($[I<&D@
M1&5M;VMR871I:W5S($OV>G3A<G-A<^%G`$MO<F5A:2!+]GITX7)S87/A9P!K
M;W)E86D@*$550RU+4BD`2W5V86ET`$MI<F=I>FES>G3A;@!?5&5R=F5ZZ7,`
M3GEE;'8`3&%O<WII($[I<&D@1&5M;VMR871I:W5S($OV>G3A<G-A<^%G`'5T
M;VQS\R!FZ6P`07H@=71O;'/S(&IE;'-Z\W;A;'3A<P!U=&]L<_,@;F5G>65D
M`%5T;VQS\R!VX6QT;WIT873A<SH`571O;'/S(&)E:F5L96YT:V5ZZ7,Z("5S
M`%5T;VQS\R!B96IE;&5N=&ME>NES.B`E<RP@)7,@8^UM<O5L`%5T;VQS\R!B
M96IE;&5N=&ME>NES.B!MZ6<@<V]H82!N96T@=F]L=`!,971T;W)S>N%G`$IO
M9P!%;&AE;'EE>NES`$AA9WEJ82#\<F5S96XL(&AA(&YE;2!A:V%R(&ME<F5T
M970`3&EB86YO;@!B86P`0F%L(&]L9&%L:2!F96ILZ6,`0F%L(&]L9&%L:2#I
M<G3I:V5K`$QE<V]T:&\`4WII;G0`3&EBZ7)I80!,[6)I86D@07)A8B!3>F]C
M:6%L:7-T82!.86=Y($[I<&D@2_9Z]G-SZ6<`3&EE8VAT96YS=&5I;@!'>65N
M9V4@<WII=.%L\R!E<_4`1WEE;F=E(&5S]0!$Z6QE;/5T="!G>65N9V4@97/U
M`$3I;'5TX6XO97-T92!G>65N9V4@97/U`$=Y96YG92!ZX7!O<@!'>65N9V4@
M>FEV871A<@!'>65N9V4@:&%V87KA<P!'>65N9V4@:/-ZX7!O<@!,:6YK`$$@
M;&EN:R!I9&4@;75T870Z`$UE9VIE;&5N[73I<VMO<B!M=71A<W-O;B!E9WD@
M;&EN:R!A(&QE=NEL8^UM<O5L(&$@;&5VZ6SM<O,@86)L86MH;WH`3&EN:V5K
M`$QI;G5X`$QI<W3A>N%S("T@82!F96QH87-Z;N%L\R!LX71J82!A(&UA<'#A
M=`!!>B!A9&%T8N%Z:7-O:R!L:7-TX6IA`$%Z;VMN86L@82!TZ6WA:VYA:R!A
M(&QI<W3A:F$@86UI<O5L('-E9^UT<^EG(&MA<&AA=/,`07H@861A='3A8FSA
M:R!L:7-TX6IA`$QI<W1A(&%R8VCM=G5M`$QI<W1A('-E9^UT<^EG:^ERZ7,`
M3&ES=&$@87IO;F]S[73S`$QI<W1A('1U;&%J9&]N;W,`3&ES=&$@;&5VZ6SM
M<N%S`$QI<W1A(&9E;&ER871K;WKA<R`H<W5B<V-R:6)E*0!,:7-T82!L96ER
M871K;WKA<R`H=6YS=6)S8W)I8F4I`$$@9F5L:&%S>F[A;/-K87!C<V]L871O
M:R!K:6QI<W3A>N%S82!N96T@<VEK97+\;'0Z("5S`$$@9F5L:&%S>F[A;/-K
M(&MI;&ES=.%ZX7-A(&YE;2!S:6ME<OQL=#H@)7,`02!F96QH87-Z;N%L\VL@
M:VEL:7-TX7KA<V$@=&EL='9A('9A;BX`27)O9&%L;VT`3&ET=N%N:6$`3&5T
M]FQTZ7,N+BX`2&5L>6D@:63U.B``3GEE;'8L(&3A='5M+"!I9/4`2&5L>0!"
M96IE;&5N=&ME>NES`$%Z(&5L]7KU(&%D871S>FEN:W)O;FEZX6-I\R!N87!L
M\^%L;&]MX6YY80!+:6IE;&5N=&ME>NES`$)E:F5L96YT:V5ZZ7,`0F5J96QE
M;G1K97KI<W-E;"!K87!C<V]L871O<R!F96QA9&%T;VL`02!B96IE;&5N=&ME
M>NES(&YE;2!S:6ME<OQL="P@;65R="!R;W-S>B!F96QH87-Z;N%L\VYE=F5T
M('9A9WD@:F5L<WKS="!A9&]T="!M96<N`$$@8F5J96QE;G1K97KI<R!N96T@
M<VEK97+\;'0N`$AO<W-Z^B!S>O9V96<`4WIE<F5L96T`86QA8W-O;GD`9_9R
M]F<@:VES8F5T^VL`;&%T:6X@:VES8F5T^VL`:VES8F5T^W,@<O-M86D@<WKA
M;6]K`$QU>&5M8G5R9P!-30!.87!I(/QZ96YE=&5K`$%Z($U3+51.148@;65L
M;.EK;&5T8F5N(&YI;F-S(&%D870N`-Q:14Y%5`!-86MA\P!-86ME9/-N:6$`
M36%D86=A<WIKX7(`5F%RX7IS;&%T`$QE=F5L97KI<P!%;6%I;"!D;VUA:6X@
M:V5Z96SI<P!,:6YK(&OI<WKM=.ES90!-86QA=VD`36%L86IZ:6$`36%L9.UV
M+7-Z:6=E=&5K`$UA;&D`3>%L=&$`061A=&%I="!K871E9_-R:>%K8F$@<V]R
M;VQH871J82X@17IE:R!I='0@9&5F:6YIX6QH873S:RP@;?-D;W/M=&AA=/-K
M+"!T;W;A8F+A('-Z[6YE:R!R96YD96QH973U:R!H;WIZX6IU:RX`36%P,C0@
M=.ER:^EP`$UA<%%U97-T('3I<FOI<`!!(&AO>GKA<F5N9&5LZ7-E:V5T(&5L
M;65N=&5T=/QK+@!MX7)C:75S`$UA<F?S`$%Z($]L=F%S;W1T+T]L=F%S871L
M86X@:F5L>F5T96L@:&%S>F[A;&%T80!-X7,@:F5L>F5T96L@*'!L+B!&;VYT
M;W,O365G=N%L87-Z;VQT*2!H87-Z;N%L871A`$UA<G-H86QL+7-Z:6=E=&5K
M`$UA<G1I;FEQ=64`16=Y;>%S;F%K(&UE9V9E;&5L]2!M97KU:P!-875R:73A
M;FEA`$UA=7)I=&EU<P!-87AI;>%L:7,@<F5N9&5L:V5ZZ7-R92#A;&SS('-Z
MX6UL8?9S<WIE9RX`07H@_'IE;F5T('3Z;"!S;VL@<NES>F+U;"#A;&PN`$%Z
M(&5L;?IL="`R-"#S<F$@;6%X:6WA;&ES(&CU;>ER<^EK;&5T93H@`$%Z(&5L
M;?IL="`V(/-R82!M87AI;>%L:7,@:/5MZ7)SZ6ML971E.B``07H@]G-S>F5G
M]6]L9&%L(&)L;VMK:F%I;F%K(&UA>&EMX6QI<R!S>N%M80!-87AI;>%L:7,@
M:&]S<WH`;>%J=7,`36%Y;W1T90!/<G9O<W1U9&]MX6YY`%1A9V]K`$$@;65N
M_"!M96=J96QE;NES93H`0V5L;.%K(&5G>6)E;VQV87-Z=.%S80#<>F5N970`
M02!D:6=I=.%L:7-A;B!A;.'M<G0@_'IE;F5T(&AI=&5L97,L(&1E(&%Z(&%L
MX>UR\R!T86[Z<^UT=N%N>>%T(&YE;2!S:6ME<OQL="!E;&QE;O5R:7IN:2X`
M3&5JX7)T(&%Z(/QZ96YE="#I<G;I;GEE<W/I9V4N`$%Z(/QZ96YE="!T[7!U
M<V$`365T87(@:63U:N%RX7-J96QE;G3I<P!!($UE=&%R(&)L;VMK(&YE;2#A
M;&P@<F5N9&5L:V5ZZ7-R92X`02!-971A<B!B;&]K:R!N96T@X6QL(')E;F1E
M;&ME>NES<F4N($$@<NES>FQE=&5K(&$@<F5N9'-Z97)G87ID82!S>N%MX7)A
M(&OI<WK\;/4@;F%P;/-FX6IL8F$@:V5R_&QT96LN`$$@365T87)$0B!N96T@
MZ7)H973U(&5L+@!-\V1S>F5R`$$H>BD@(B5S(B!M\V1S>F5R(&1E9FEN:>%L
M871L86X`02!M\V1S>F5R(&1E9FEN:>%L871L86XN($$@;65G:.UV;W1T(&WS
M9'-Z97(Z("5S`$UE=')I:W5S`$UE>&EK\P!-:6MR;V[I>FEA:2!3>O9V971S
MZ6=I(,%L;&%M;VL`:_9ZZ7``34E-12!T[7!U<P!!>B!E;&WZ;'0@,C0@\W)A
M(&QE9V%L86-S;VYY86)B(&CU;>ER<^EK;&5T93H@`$%Z(&5L;?IL="`V(/-R
M82!L96=A;&%C<V]N>6%B8B!H]6WI<G/I:VQE=&4Z(`!-Z6<@;F5M('1E;'0@
M96P@82!M:6YI;>%L:7,@:63U(&$@:F5L<WKS(&UE9W;A;'1O>G1A=.%SX6AO
M>@!4_&MR]GKI<R`H:F]B8B]B86PI`%9E9WEE<P!(:>%N>7II:R!A($A45%!?
M4F5Q=65S="!014%2(&-S;VUA9RX`2V]N9FEG=7+A8VGS('-Z_&MSZ6=E<RX@
M17IT(&UO<W0@:V5L;"!LZ71R96AO>FYI82P@:&$@:&%S>F[A;&YI(&%K87)J
M82!A>B!A;&MA;&UA>N%S="X`2&GA;GEZ:6L@87H@_'IE;F5T(&%Z;VYO<^UT
M\VIA+@!(:>%N>7II:R!A($UA:6P@4$5!4B!C<V]M86<N`$AIX6YY>FEK(&$@
M9F5L:&%S>F[A;/-K87!C<V]L870@87IO;F]S[73S:F$@*'-E<W-I;VX@240I
M+@!(Z0!,979E;&5ZZ7,@;6]B:6QT96QE9F]N<O-L`$OV>F5P97,`02!M\V1O
M<^UTX7,@9.%T=6UA`$%Z(%523"!M\V1O<^UTX7-A`$UO9'5L=7,`36]L9&]V
M86D@2_9Z=.%R<V%SX6<`36]N86-O`$UO;F?S;&EA`$CS;F%P(.ES(.EV`&AA
M=F]N=&$`36]N='-E<G)A=`!(;VQD9N%Z:7-O:P!!("5D+B!S;W)B86X@=/9B
M8B!M97KU('9O;'0L(&UI;G0@82!VX7)T("5D+@!-87)O:VOS`%3V8F)N>6ER
M92!D97+\;'0`5/9B8FYY:7)E(&)O<G5L=`!4]F)B;GEI<F4@;F%P;W,`=FEG
M>?QK(&QE`'9I9WG\:R!B86QR80!V:6=Y_&L@:F]B8G)A`'9I9WG\:R!F]FP`
M=FEG>?QK(&QE`'9I9WG\:R!F]FP`36]Z86UB:6L`5/9B8G-Z:6YT^R!L96?V
M<F3\;/4@;&ES=.%K`$UU;'1I;6%P($YA9WDM0G)I=&%N;FEA('3I<FOI<`!4
M]F)B<WKV<O9S(';A;&%S>G3A<P!"96IE;&5N=&ME>NES:2!B9>%L;.UTX7-O
M:P!"96IE;&5N=&ME>NES:2!A9&%T86EM`%-A:N%T(/9S<WIE9WKU(&]L9&%L
M86T`4V%JX70@]G-S>F5G>O4@;VQD86QA;2!T97)V97KI<V4`36EA;FUA<@!.
M14TL(&YE;2!E9WEE>F5M(&)E;&4N`$[I=@!.86WM8FEA`$YA=7)U`$YE<.%L
M`$AO;&QA;F1I80!(;VQL86YD($%N=&EL;.%K`$YE='-C87!E(&+A>FES+552
M3`!.971S8V%P92!T86[Z<^UT=N%N>6MI863A<VEJ;V<H0T$I+79I<W-Z879O
M;N%S:2!54DP`3F5T<V-A<&4@=&%N^G/M=';A;GEF96QH87-Z;N%LX7-I(&ER
MX6YY96QV(%523`!.971S8V%P92!T86[Z<^UT=N%N>6UE9_IJ[73A<VD@55),
M`$YE='-C87!E('1A;OIS[71VX6YY=FES<WIA=F]NX7-I(%523`!.971S8V%P
M92!34TP@<WIE<G9E<F[I=@!.971S8V%P92!T86[Z<^UT=N%N>2!M96=J96=Y
M>NES`$YE='-C87!E('1A;OIS[71VX6YY=.UP=7,`2.%L\WIA=`!S;VAA`-IJ
M+4MA;&5D\VYI80#::B!K871E9_-R:6$`VFH@;&5VZ6P@)7,@8^UM<F4`^FIH
M;VQD`-IJ(&9E;&AA<WINX6SS;NEV("AO<&-I;V[A;&ES*0#::BU:Z6QA;F0`
MVFH@:F5L<WKS`$%Z(/IJ(&IE;'-Z\R#I<G;I;GEE<W/I9V4@96MK;W(@:N%R
M(&QE.B`E>"X`02!M96=A9&]T="#Z:B!J96QS>F%V86L@;F5M(&5G>65Z;F5K
M+@#::B!A8FQA:R`H_')E<RD`2.UR96L`2.UR8W-O<&]R=&]K`$OV=F5T:V5Z
M]0!+]G9E=&ME>O4@-"!FX7II<P!+]G9E=&ME>O4@;W!C:?-K`$OV=F5T:V5Z
M]3X`3FEC87)A9W5A`$YI9V5R`$YI9^ER:6$`Z6IS>F%K80!.:75E`$YE;0!.
M:6YC<R!R96YD96QK97KI<W)E(.%L;/,@:V]N9FEG=7+A8VGS+"!A;6EH97H@
M:^EP97-T(&$@:_QL]FYB<^EG96ME="!M96<@;&5H971N92!M=71A=&YI+@!.
M:6YC<R!L96AE=/5SZ6<@25-/(.%L;&]MX6YY;VL@;.ET<F5H;WKA<^%R82X`
M2&GA;GEZ:6L@82!K]G1E9V5L="!F96QD;VQG;WKA<VAO>B!S>OQK<^EG97,@
M;6EN=&$@*&)A=&-H('1E;7!L871E*2X`02!K[7;A;G0@:&5L>65N(&YI;F-S
M(&)L;VMK`$%Z($U#04P@9F5L:&%S>F[A;/-A>F]N;W/M=.%S:&]Z(&YI;F-S
M(&UE9V%D=F$@82!N87!TX7(@;F5V92X`3FEN8W,@=N%L=&]ZX7,N`$5H:&5Z
M(&$@:F]G;W-U;'1SX6=H;WH@;F5M(&AO>FAA=/,@;.ET<F4@:F]G;W-U;'1S
MX6=I(&%L8W-O<&]R="X`2&GA;GEO>FYA:R!A(&MO;F9I9W5RX6-I\W,@861A
M=&]K("5S+6AE>BX`07H@1E10(%9&4R!N:6YC<R!K;VYF:6=U<N%L=F$N`$%Z
M(%-13"!61E,@;FEN8W,@:V]N9FEG=7+A;'9A+@!!>B!344PM1FEL92!61E,@
M;FEN8W,@:V]N9FEG=7+A;'9A+@!!>B#6;B!S>N%M;.%JX6X@96QF;V=Y;W1T
M(&$@<F5N9&5L:V5ZZ7-R92#A;&SS(/9S<WIE9RX`3FEN8W,@8^UM>NES+@!!
M('-Z97)V97)R92!N96T@=/9L=/5D]G1T(&9E;"!S96UM:6QY96X@X6QL;VWA
M;GD`07H@:6MO;F]K(&YE;2!T86SA;&AA=/-K+@!.:6YC<R!M96=A9'9A(&$@
M:&5L>2X`3FEN8W,@;65G861V82!A(&AE;'DN`$%Z(/QZ96YE="#\<F5S+@!.
M:6YC<R!M96=A9'9A(&$@;NEV+@!.:6YC<R!M96=A9'9A(&$@<WKA;2X`3F4@
M;&5G>65N(&UE9V)O='+A;FMO>G1A=/,@:63I>F5T`$YI;F-S(&IE;'-Z\R!M
M96=A9'9A(&$@2%144"!A;&%P^B!F96QH87-Z;N%L\VD@87IO;F]S[73A<VAO
M>BX`3FEN8W,@:F5L<WKS(&UE9V%D=F$@87H@24U!4"!A;&%P^B!F96QH87-Z
M;N%L\VD@87IO;F]S[73A<VAO>BX`3FEN8W,@:F5L<WKS(&UE9V%D=F$@82!+
M97)B97)O<R!A;&%P^B!F96QH87-Z;N%L\VD@87IO;F]S[73A<VAO>BX`3FEN
M8W,@:F5L<WKS(&UE9V%D=F$@82!,;V=I;B!A;&%P^B!F96QH87-Z;N%L\VD@
M87IO;F]S[73A<VAO>BX`3FEN8W,@:F5L<WKS(&UE9V%D=F$@82!005-35T0@
M86QA</H@9F5L:&%S>F[A;/-I(&%Z;VYO<^UTX7-H;WHN`$YI;F-S(&IE;'-Z
M\R!M96=A9'9A(&%Z(%--0B!A;&%P^B!F96QH87-Z;N%L\VD@87IO;F]S[73A
M<VAO>BX`3FEN8W,@;65G861V82!A>B!/<&5N4U-,('!R;V=R86T@96SI<NES
M:2#Z='9O;F%L82X@07H@3W!E;E-33"!P<F]G<F%M('-Z_&MSZ6=E<R!A(%!+
M0U,@,3(@861A=&]K(&ME>F5LZ7/I:&5Z+@!.:6YC<R#Z:B!B96IE;&5N=&ME
M>NES:2!I9^EN>2X`3FEN8W,@:W;S=&$@8F7A;&SM='9A+@!.92!L96=Y96YE
M:R!V;VYA;&%K('-E:&]L+@!.:6YC<R!D969I;FGA;'9A(&5L=N%L87-Z=/,@
M:V%R86MT97(N`$YE(&QE9WEE;B!K97)E=`!.:6YC<R!I;'EE;B!FX6IL`$YI
M;F-S(&ED96EG;&5N97,@X6QL;VWA;GEO:R!TX7)O;.%SX7)A('-Z;VQGX6SS
M(&%L:_9N>79TX7(N`$AIX6YY>FEK(&$@9F5L:&%S>F[A;/-NZ78@Z7,O=F%G
M>2!A(&IE;'-Z\RX`02!V:7-S>F%K87!O='0@861A=&]K(&YE;2#I<G;I;GEE
M<R!834P@861A=&]K`$YI;F-S(&%D870`3FEN8W,@;>EG(&MO;F9I9W5RX6-I
M\RP@9V5N97+A;&IO;B!E9WEE="X`3FEN8W,@;>EG(&MO;F9I9W5RX6-I\VIA
M+"!G96YE<N%L:F]N(&5G>65T+@!N:6YC<P!N:6YC<R!M96=A9'9A("AL96=Y
M96X@86QA<.ER=&5L;65Z971T*0!N;W)D:6MU<R`H25-/+3@X-3DM,3`I`$YO
M<F9O;&LM<WII9V5T`,ES>F%K:2!FZ6QT96ME`,ES>F%K:2U-87)I86YA+7-Z
M:6=E=&5K`$YO<G;I9VEA`$YE;2!KZ7/U8F(`3F5M(&MO<N%B8F%N`$YE;2!A
M;&OV;GEV=.%R`$$@<')O9W)A;6YA:R!E>B!A('+I<WIE(&WI9R!N:6YC<R!M
M96=V86SS<^UT=F$N`$YI;F-S(&)EX6QL[71V80!.96T@=.%M;V=A=&]T="X`
M1F5L:F5G>7KI<V5K`$YI;F-S(&+V;F?I<WIH973U(&%D870L('3I<FIE;B!V
M:7-S>F$N`&YO=F5M8F5R`%-ZX6T`2V%R86MT97)E:R!S>N%M80!/<WIL;W!O
M:R!S>N%M80!3;W)O:R!S>N%M80!!(&OV<FQE=NEL;&ES=&$@;?-D;W/M=.%S
MX6AO>B!N96T@861O='0@;65G('-ZX6UO:V%T+@!/2P!/8FIE:W1U;0!!>B!O
M8FIE:W1U;2!LZ71R96AO>O-J80!/:W3A;&ES('-ZX6T`;VMT\V)E<@!3>OMR
MZ7,`2&EV871A;"]M=6YK86AE;'D`02!RZ6=I(.ES(&%Z(/IJ(&IE;'-Z\VYA
M:R!K_&SV;F+V>FYI92!K96QL+@!!('+I9VD@:F5L<WKS`$$@<NEG:2!J96QS
M>O,@;F5M(&UE9V9E;&5L]2X`3VWA;@!#<V%K(&%Z($E-05`@<WIE<G9E<F5K
M('3A;6]G871JX6L@82!M87!PX6L@;65G;W-Z=.%SX70N`$-S86L@;65G8F]T
M<N%N:V]Z=&%T\R!I9.EZ970@;&5G>65N`$-S86L@96=Y(&5M86EL(&/M;2!A
M9&AA=/,@;65G+@!#<V%K(&$@='5L86ID;VYO<R!V86=Y(&$@<F5N9'-Z97)G
M87ID82!VX6QT;WIT871H871J82!M96<@96=Y(&OV>O9S('3A<G1E<OQL970@
M='5L86ID;VYO<^%T('9A9WD@96SI<NES:2!J;V=O<W5L='/A9V%I=`!.>6ES
M<W5K(&UE9R#Z:B!A8FQA:V)A;@!/<&5N4U-,(&AI8F$Z($YE;2!S:6ME<OQL
M="!K:6YY97)N:2!A>B!A9&%T;VMA="!A>B!A;.'M<G0@4R]-24U%('+I<WIB
M]6P`3GEI<W-U:R!M96<@97IT(&$@8^UM970@96=Y(/IJ(&%B;&%K8F%N`$]P
M97+A8VGS<R!R96YD<WIE<@!/<&-I\VL`)7,@8F7A;&SM=.%S86D`4V]R<WKA
M;6]S(&9E;'-O<F]LX7,`4WIE<G9E>F5T`%-Z97)V97IE=&D@96=Y<^EG`$UU
M;FMA<WIE<G9E>NES`$%Z(&%L:V%L;6%ZX7,@97)E9&5T:2!S86)L;VYJ80`E
M<R!E<F5D971I('-A8FQO;FIA:3H`16=YZ6(`16=YZ6(@:6YF;W)MX6-I\P!!
M('1U;&%J9&]N;W,@:F]G;W-U;'1SX6=A:0!!(%!!32!F96QH87-Z;N%L\V%Z
M;VYO<^UTX7,@;F5M(.%L;"!R96YD96QK97KI<W)E+@!014%2.CI-86EL(&%L
M<F5N9'-Z97(`4$=0(&1I9VETX6QI<R!A;.'M<N%S`%!'4"UV96P@=&ET:V]S
M[71O='0@861A=`!01U`@;GEI;';A;F]S(&MU;&-S`%!'4"UV96P@86SA[7)T
M+W1I=&MO<^UT;W1T(&%D870`4$A0(&OS9`!$Z6QU=.%N+V5S=&4@9WEE;F=E
M(&5S]0!$Z6QU=.%N(&5S]0!$Z6QU=.%N+V5S=&4@>N%P;W)O:P!$Z6QU=.%N
M+V5S=&4@:&%V87KA<P!$Z6QU=.%N+V5S=&4@:/-ZX7!O<F]K`$3I;'5TX6X@
M;F%P<_QTZ7,`1.EL=73A;B]E<W1E('II=F%T87)O:P!(:>%N>7II:R!A(%!/
M4TE8(&+U=NUTZ7,`8F5L<_4@;6%R9_,`4&%K:7-Z=.%N`%!A;&%U`%!A;&5S
M>G1I;B!497+\;&5T("AM96=S>N%L;'0I`%!A;F%M80!0X7!U82#::BU'=6EN
M96$`4&%R86=U87D`3>ER<^EK96QT96X@8F]R=6QT`$IE;'-Z\P!!(&IE;'-Z
M\W0@<VEK97)E<V5N(&UE9W;A;'1O>G1A='1U:RX`3F5M(&UE9V9E;&5L]2!J
M96QS>O,`02!2041)55,@9F5L:&%S>F[A;/-A>F]N;W/M=.%S:&]Z(&IE;'-Z
M\R!S>OQK<^EG97,N`$IE;'-Z\R!M96=E<O5S[73I<W-E;`!*96QS>O,Z`$IE
M;'-Z\SH@`$$@:F5L<WIA=F%K;F%K(&5G>65Z;FG\:R!K96QL+@!"96EL;&5S
M>G3I<P!"96EL;&5S>G3A<R!A(';A9_-A<WIT86QR\VP`VG1V;VYA;`#::B!F
M96QH87-Z;N%L\VYA:R!B96IE;&5N=&ME>F5T=&5K.@!%;6)E<F5K`'-ZX7IA
M;.EK`$MA<F)A;G1A<G3A<VD@9F5L861A=&]K(';I9W)E:&%J=.%S80!"96IE
M;&5N=&ME>NES:V]R(&AA:G1S=6L@=NEG<F4@82!K87)B86YT87)TX7-I(&9E
M;&%D871O:V%T/P!*;V=O<W5L='/A9P!!*'HI("(E<R(@:F]G;W-U;'1SX6=O
M="!N96T@=/9R]FQT_&LN`-9N;F5K(&YI;F-S(&5H:&5Z(&5L96=E;F3U(&IO
M9V]S=6QT<^%G80!*;V=O<W5L='/A9V]K`$IO9V]S=6QT<^%G(&%D;6EN:7-Z
M='+A8VGS`%-Z96WI;'EE<R!A9&%T;VL`4&5R=0#!;&QA=&ME9'9E;F-E:P!&
M_&SV<"US>FEG971E:P!496QE9F]N`$;I;GEKZ7!G86SI<FEA`%!I=&-A:7)N
M`'!I>&5L`$OV>FAE;'EE:P!+871T:6YT<V]N('9A;&%M96QY:6L@8V5L;.%R
M80!":7IT;W-A;B!T]G+V;&YI(&%K87)J82!E>G0@87H@96QE;65T.@!+Z7)E
M;2!E<O5S[71S92!M96<L(&AO9WD@=F%L\V)A;B!T]G+V;&YI(&OM=N%N:F$@
M97IT(&%Z(&5L96UE="X`2^ER96T@861J;VX@;65G(&5G>2!H\VYA<&]T(.ES
M(&5G>2#I=F5T+@!+Z7)E;2!A9&IA(&UE9R!A>B#Z:B!K871E9_-R:6$@;F5V
MZ70Z`$OI<F5M('9A;/-S($E0(&/M;65T(&%D:F]N(&UE9RX`2^ER96T@=F%L
M\W,@9.%T=6UO="!A9&IO;B!M96<L(&5L;&5N]7)I>GIE(&$@:/-N87`@;F%P
M:F%I="X`2^ER96T@=F%L\W,@9.%T=6UO="!A9&IO;B!M96<N`$OI<F5M('+V
M=FED96X@[7)J82!L92!A('!R;V)LZ6UA(&SI;GEE9^ET+@!+Z7)E;2!A9&IA
M(&UE9R!A(&)E:F5L96YT:V5ZZ7-I(&YE=NET(.ES(&IE;'-Z87;A=`!+Z7)E
M;2!O;'9A<W-A(&5L(&$@:_9V971K97KU('-Z]G9E9V5T+B!!(')E;F1S>F5R
M(&AA<WINX6QA=.%N86L@9F5L=.ET96QE:70@96P@2T5,3"!F;V=A9&YI82X`
M2^ER96T@861J82!M96<@87H@^FH@:V%T96?S<FEA(&YE=NET.@!,96YG>65L
M;W)S>N%G`%!O;&ET:6MA`%-Z879A>N%S;VL`4&]R='5GX6QI80!!(&OI<"!E
M;&AE;'EE>NES90!!('3A8FSA>F%T(&5L:&5L>65ZZ7-E`$OV>G9E=&QE;B!L
M97;I;&O\;&3I<R!E8F)E(&$@;6%P<.%B82`H24U!4"!N96T@;6EN9&EG('9E
M<WII(&9I9WEE;&5M8F4I`$%Z(&5L;?IL="`E<R#S<F$@8W-A<&%DZ6MM96YN
M>6ESZ6=E.B``0W-A<&%DZ6L\8G(@+SYV86SS<WKM;OMSZ6<`4')E9G-?;&1A
M<#H@;F5M('1A;.%L:&%T\R!A('-Z_&MSZ6=E<R!,1$%0(&MI=&5R:F5S>G3I
M<RX`4')E9G-?<V5S<VEO;CH@;F5M('1A;.%L:&%T\R!A('-Z_&MSZ6=E<R`H
M<V5S<VEO;BD@:VET97)J97-Z=.ES+@!,Z6=N>6]MX7,`02!T96YG97)S>FEN
M=&YE:R!M96=F96QE;/4@;.EG;GEO;>%S.B``3.EG;GEO;>%S.B``16SU>F5T
M97,@;65G=&5K:6YTZ7,`02!KZ7`@96SU>F5T97,@;65G=&5K:6YTZ7-E(/IJ
M(&%B;&%K8F%N`$5L]7KU(&]P8VGS:P!!(&1O:W5M96YT=6T@:VEN>6]M=&%T
MX7-A`%1I=&MO<R!K=6QC<P!(:6)A8F5J96QE;G3I<P!!(&AI8F$@;&7M<N%S
M80!0<F]J96MT(&ME>F5LZ7,`02!P<F]M<'0@<WKV=F5G90!.>6EL=N%N;W,@
M:W5L8W,`3GEI;';A;F]S(&MU;&-S^B!A;&=O<FET;75S`$YY:6QVX6YO<R!K
M=6QC<R!I;F9O<FWA8VGS`$$@;GEI;';A;F]S+W1I=&MO<R!K=6QC<W#A<G0@
M;F5M('-I:V5R_&QT(&SI=')E:&]Z;FDN`%!U97)T;R!2:6-O`$$@;&5V96QE
M:R!VZ6=L96=E<R!T]G)LZ7-E`$MA=&%R`$ME<F5S]2]P87)A;F-S('-T<FEN
M9P!+=O-T80!24T$@;GEI;';A;F]S(&MU;&-S("@E9"!B:71E<RD`4N%D:?-G
M;VUB;W,@:VEVX6QA<WITX7,`17/U`$5S]2!DZ6QE;/5T=`!%<_4@9.EL=73A
M;B]E<W1E`%KA<&]R`$5S]2#I<R!H879A>N%S`$AA=F%S97/U`%;I;&5T;&5N
M(&EDZ7IE=`!!<N%N>0!/;'9A<^%S`$QE=F5L96L@;VQV87/A<V$`5.EN>6QE
M9R!T]G+V;&K\:R`E<R!F96QH87-Z;N%L\W0_($5Z(&$@=N%L=&]Z=&%TX7,@
M;F5M(&9O<F3M=&AA=/,@=FES<WIA+@!4Z6YY;&5G('3V<O9L:OQK("5S(&9E
M;&AA<WINX6SS(&%D871A:70_($5Z(&$@=N%L=&]Z=&%TX7,@;F5M(&9O<F3M
M=&AA=/,@=FES<WIA+@#::G)A(';I9W)E:&%J=&IA(&%Z('5T;VQS\R!VX6QT
M;WIT873A<W0`1G)I<W/M=.ES`$$@;65N_"!D:6YA;6EK=7,@96QE;65I;F5K
M(&9R:7-S[73I<VD@9WEA:V]R:7/A9V$Z`$%Z(/9S<WIE9WKU;VQD86P@9G)I
M<W/M=.ESZ6YE:R!G>6%K;W)I<^%G83H`3V)J96MT=6T@8O9N9^ES>O4`1G)I
M<W/M=.ES`$UE9VIE9WEZZ7-E:P!4X79O;&D@<WIE<G9E<F5K`$$@=.%V;VQI
M(%523"`H<&PN(&AT='`Z+R]W=W<N=F%L86UI+FAU+VUE9W9A;&%M:2DZ`%3V
M<FSI<P!";&]K:R!T]G)LZ7-E`$]S>FQO<"!T]G)LZ7-E`$$@9F]R;6%T=.%L
MX7,@=/9R;.ES90!!('#A<B!T]G)LZ7-E`%3V<O9L:OQK(&%Z(&5L;65N=&5T
M="!P<F]G<F%M;W0@82!S>F5R=F5R(&ED96EG;&5N97,@X6QL;VWA;GEO:V%T
M('1A<G1A;&UA>O,@86QK]FYY=G3A<N%B\VPN`%9E9WG\:R!K:2``5F5G>?QK
M(&MI(&5Z="!A('+I<WIT(&$@9&]K=6UE;G1U;6+S;`!!(&9E;&AA<WINX6SS
M('3V<FSI<V4`)7,@9F5L:&%S>F[A;/,@=/9R;.ES90!!(&OI<NES(&YE;2!T
M96QJ97/M=&AE=/4N($$@:V%P;W1T(&AI8F%K\V0Z(`!!(&ME<F5S971T('-Z
M;VQGX6QT873A<R!N96T@=&%LX6QH873S+@!!(&OV=&5L97KU96X@;65G861A
M;F3S("(E<R(@;F5M('-Z97)E<&5L("5S(&MO;F9I9W5RX6-I\VKA8F%N+@!!
M(&OV=&5L97KU96X@;65G861A;F3S("(E<R(@;F5M('-Z97)E<&5L(&$@5D93
M(&MO;F9I9W5RX6-I\VKA8F%N+@!!(&OV=&5L97KU96X@;65G861A;F3S("(E
M<R(@;F5M('-Z97)E<&5L(&$@:V]N9FEG=7+A8VGS8F%N+@!3>OQK<^EG97,@
M;65Z]0!297-E=`!!(&IE;'-Z\R#A=.%L;.UTX7-A`$%Z(-9N(&IE;'-Z87;A
M;F%K(.%TX6QL[73A<V$`07H@=71O;'/S(&ME<F5SZ7,@=FES<WIAX6QL[73A
M<V$`17)E9&WI;GD`5FES<WIA(&%Z(&]P8VGS:VAO>@!!>B#Z:B!J96QS>O-T
M(.UR:F$@8F4@:7-MZ70`4NEU;FEO;@#!;&SM='-U:R!V:7-S>F$@82!K;VYF
M:6=U<N%C:?-T`%)I8V@@5&5X="!%9&ET;W(@;W!C:?-K`%1A;.%L\W,@:^ER
M9.ES96L`:F]B8@!*;V)B(&]L9&%L:2!F96ILZ6,`2F]B8B!O;&1A;&D@Z7)T
MZ6ME:P!3;W(@='5L86ID;VYSX6=O:RXN+@!3>F5R97``4F]MX6YI80!&;W)G
M873A<R`Q.#`@9F]K:V%L`$)A;')A(&9O<F=A=.%S`$IO8F)R82!F;W)G873A
M<P!3;W(@='5L86ID;VYSX6=O:P!3;W(@='5L86ID;VYSX6=O:P!3;W)O:SH`
M5F]N86QA:P!-:6YD96X@<V]R(.ES(&]S>FQO<"!K]GKV='0@;&5G>65N('9O
M;F%L`$-S86L@87H@;W-Z;&]P;VL@:_9Z]G1T(&QE9WEE;B!V;VYA;`!#<V%K
M(&$@<V]R;VL@:_9Z]G1T(&QE9WEE;B!V;VYA;`!&=71T873A<P!/<F]S>B!&
M]F1E<N%C:?,`4G5A;F1A`%,O34E-12!D:6=I=.%L:7,@86SA[7+A<P!3+TU)
M344@<WIA8G;A;GD@<WIE<FEN="!T:71K;W/M=&]T="!L97;I;`!305-,(&9E
M;&AA<WINX6SS87IO;F]S[73A<R!N96T@=&%LX6QH873S+@!335,@:_QL9.ES
M`%-13"!P87)A;F-S(&$@:V5R97/I<VAE>@!34T@`4TE+15+<3%0`4WIO`%-Z
M96YT($EL;VYA+7-Z:6=E=`!386EN="!+:71T<R#I<R!.979I<P!386EN="!,
M=6-I80!386EN="!0:65R<F4@Z7,@36EQ=65L;VX`4V%I;G0@5FEN8V5N="#I
M<R!'<F5N861I;F4M<WII9V5T96L`56=Y86YA>B!A(&9R86UE("A?<V5L9BD`
M4WIA;6]A`%-A;B!-87)I;F\`4V%O(%1O;>D@Z7,@4'+M;F-I<&4`3?MH;VQD
M87,@:6YT97)N971E;.ERZ7,`4WIA^F0M07+A8FEA`$UE;G3I<P`B)7,B(&UE
M;G3I<V4`)7,@;65N=.ES90!!(&)EX6QL[73A<V]K(&UE;G3I<V4`365N='/\
M:R!E;"!A>B!E;&OI<WK\;'0@:V]N9FEG=7+A8VGS="!02%`@<')O9W)A;2!F
M;W)MX6KA8F%N(&$@<WIE<G9E<B!I9&5I9VQE;F5S(.%L;&]MX6YY;VMA="!T
M87)T86QM87KS(&%L:_9N>79TX7+A8F%N+@`E<R!K;VYF:6=U<N%C:?-JX70@
M96QM96YT971T_&LN`$5L;65N=&5T=/QK(&$@<V5T=7`@=7!G<F%D92!P<F]G
M<F%M;W0@:61E.B`B)7,B`%-Z\W)VX6YY;W,@>FEV871A<F]K`%1U9&]MX6YY
M`$ME<F5SZ7,`2V5R97/I<VD@<WIO;&?A;'1A=.%S;VL`P6QL;VWA;GEO:R!K
M:7;A;&%S>G3A<V$`5N%L87-S>F]N(&MI(&5G>2!DX71U;6]T`$UE;'EI:R!C
M<V]P;W)T;W0@:^UVX6YJ82!H;WIZX6%D;FD`5N%L87-S>F$@:VD@87H@^FH@
M='5L86ID;VYO<W0`5N%L87-S>F]N('-Z97)V97)T`$UE;'EI:R!F96QH87-Z
M;N%L\W0@:^UVX6YJ82!H;WIZX6%D;FD`36EN9&5T(&MI:F5L]FQJ_&L`5N%L
M87-S>F$@:VD@87H@]G-S>F5S(&3A='5M]G-S>F5T97;U="X`5N%L87-S>F]N
M(&5G>2!O8FIE:W1U;6]T`$5G>2!S92!L96=Y96X@:VEJ96SV;'9E`%;A;&%S
M<WIA(&MI(&$@:^UVX6YT(&MA<F%K=&5R*&5K92ET(&%Z(&%LX6)B:2!L96AE
M=/5SZ6=E:R!K]GK\;"X@17IU=.%N(")C;W!Y+W!A<W1E(B!M\V1S>F5R<F5L
M(&$@;65G9F5L96SU(&AE;'ER92!MX7-O;&AA=&IA(/5K970N`%;A;&%S<WIA
M(&MI(&$@9.%T=6UE;';A;&%S>G3S(&MA<F%K=&5R=#H`5N%L87-S>F$@:VD@
M82!DX71U;2!F;W)MX71U;>%T.@!6X6QA<W-Z82!K:2P@;65L>6EK(&%Z;VYO
M<^UT\VKA="!K[7;A;FIA(&UE9W;A;'1O>G1A=&YI.@!6X6QA<W-Z82!K:2!A
M>B!I9/5E;';A;&%S>G3S(&MA<F%K=&5R=#H`5N%L87-S>F$@:VD@87H@:63U
M(&9O<FWA='5MX70Z`%;A;&%S<WIO;B!K:2!KZ70@96=Y;>%S;F%K(&UE9V9E
M;&5L]2!M97KU="X`5N%L87-S>F$@:VD@82!K[7;A;G0@<WKM;F5G>?QT=&5S
M="X`5N%L87-S>F$@:VD@87H@UFYN96L@;65G9F5L96SU(&YY96QV970Z`$AI
M8F%J96QE;G3I<R!K_&QDZ7-E`%--4R!K_&QDZ7-E`%-Z96YE9^%L`%-Z96YZ
M;W(Z(`!S>F5P=&5M8F5R`%-Z97)B:6$@Z7,@36]N=&5N96=R\P!3;W)O>F%T
M<WKA;0!!('-Z97)V97)T]6P@:V%P;W1T(&%D870@:&EBX7,L('9A9WD@;F5M
M(.%L;"!R96YD96QK97KI<W)E+@!!(&9E;&AA<WINX6SS:V%P8W-O;&%T;VL@
M861M:6YI<WIT<N%C:?-J80!,96KA<G0@82!F96QH87-Z;N%L\VMA<&-S;VQA
M="!A>F]N;W/M=/-J82`H<V5S<VEO;B!)1"DN`$9E;&AA<WINX6SS:V%P8W-O
M;&%T;VL`2&%L;6%Z`$QE:&5T]7/I9R!J96QS>F%VX6YA:R#A=.%L;.UTX7/A
M<F$L(&%B8F%N(&%Z(&5S971B96XL(&AA(&5L9F5L96IT96[I+@!4X79O;&D@
M<WIE<G9E<F5K(&5LZ7+I<V4@X6QL[71H873S(&)E+"!M96QY96ME="!A>B!I
M;F1U;/-O;&1A;.%N(&OM=N%N(&UE9VIE;&5N[71E;FDN`$$@:^UVX6YT(&YY
M96QV+"!I9/5Z\VYA(.ES(&3A='5M9F]R;>%T=6T@8F7A;&SM=.%S82X`0F7A
M;&SM=&AA=/,L(&AO9WD@;65L>6EK(&%L:V%L;6%ZX7,@:F5L96YJ96X@;65G
M(&$@8F5J96QE;G1K97KI<R!U=.%N+"!M:6QY96X@<WKM;F5G>?QT=&5S="P@
M;VQD86QF<FES<^UTZ7-I(&=Y86MO<FESX6=O="!I;&PN(&5G>>EB(&)EX6QL
M[73A<V]K870@<WIE<F5T;F4N`$)EX6QL[73A<V]K`$$@8F7A;&SM=.%S;VMA
M="!M96?Z:NUT\R!P<F]G<F%M;VL@X6QL;F%K(')E;F1E;&ME>NES<F4`02!M
M96=A9&]T="!P87)A;>ET97(@=/9B8B!H96QY970@:7,@:F5L96YT:&5T.B``
M4V5Y8VAE;&QE+7-Z:6=E=&5K`%;A<^%R;.%S`%+V=FED(/9S<WIE9F]G;&%L
MX7,`16P@:^UVX6YJ82#I<FYI(&%Z(&5G>65S(&9U;FMC:?-K870@06QT+6)I
M;&QE;G1Y^RUK;VUB:6[A8VGS:VMA;"!I<S\`365G:F5L96[M=.ES`$UU=&%S
M<W5K(&UE9R!A(&O\;/9N8G/I9V5K970@87H@96QM96YT971T(.ES(&%Z(/IJ
M;VYN86X@;.ET<F5H;WIO='0@:V]N9FEG=7+A8VGS(&OV>O9T="X`36EN9&5N
M(&)E:F5L96YT:V5ZZ7-K;W(@[7+S9&KI:R!K:2!A(&MO<N%B8FD@=71O;'/S
M(&)E:F5L96YT:V5ZZ7,@:61E:F4_`%;A;&%S>G1H873S(&QE9WEE;B!A>B!E
M<F5D971I(&UE9W1A<G3A<V$`3&5G>65N(&3A='5M=N%L87-Z=/,`3&5G>65N
M(&5G>2!TX6)LX7IA=&ME>F5L]2!M96[\<V]R/P!-=71A<W-U:R!A("5S(&UE
M;OQT(&$@8F%L(&]L9&%L;VX_`$[I>GK\:R!M96<@=.%B;.%Z870@8V5L;.%I
M;F%K('1U;&%J9&]N<^%G86ET`$[I>GK\:R!M96<@=.%B;.%Z870@='5L86ID
M;VYSX6=A:70`3NEZ>OQK(&UE9R!TX6)LX7IA="!S;W)A:6YA:R!T=6QA:F1O
M;G/A9V%I=`!.Z7IZ_&L@;65G(&$@:^EP('1U;&%J9&]N<^%G86ET`$UU=&%S
M<W5K(&$@9F5L=/9L=.ES=`!:X7!O<F]K`%KA<&]R;VL@9.EL96SU='0`6N%P
M;W)O:R!DZ6QU=.%N+V5S=&4`2&5L>6D@>N%P;W)O:P!+:6-S:6YY[73I<P!%
M;/5S>O9R(&MI8W-I;GGM=&5N:64@:V5L;"P@=F%G>2!E;"!K96QL(&UO>F3M
M=&%N:6$@82!H96QY970@96QF;V=L86SS(&)L;VMK;VMA="X`4VEE<G)A($QE
M;VYE`-IJ(&9E;&AA<WINX6SS:R!B96IE;&5N=&ME>NES90!$:6=I=.%L:7,@
M86SA[7+A<P!!(&1I9VETX6QI<R!A;.'M<N%S(&%L9V]R:71M=7-A`%-Z:6YG
M87#Z<@!-Z7)E=`!!(&MA<F)A;G1A<G3A<R!K:6AA9WGA<V$`4WIL;W;A:VEA
M`%-Z;&]VZ6YI80!(879A>N%S`$CS>N%P;W(`2/-ZX7!O<F]K`$CS>N%P;W)O
M:R!DZ6QE;/5T=`!+Z7/U(&3I;'5TX6YI+V5S=&D@:/-ZX7!O<F]K`$$@:/,@
M;>EL>7/I9V4Z(`!(\R!V[7IM96YN>6ESZ6=E8F5N(&MI9F5J97IV93H@`%-A
M;&%M;VXM<WII9V5T96L`4WIO;>%L:6$`1&%L;VLL('9E<G-E:P!!('-O<F)A
M<F5N9&5ZZ7,@:7+A;GGA;F%K(&MI=N%L87-Z=.%S80!&96QA9/-I(&/M;0!$
MZ6PM069R:6MA`&3I;"UE=7+S<&%I("A)4T\M.#@U.2TS*0!$Z6QI+4=E;W)G
M:6$@Z7,@1.EL:2!386YD=VEC:"US>FEG971E:P!$Z6QI(&;I;'1E:V4`4WIO
M;7-ZZ61O<R!C96QLX6L@:_9Z]G1T:2!TX79O;'/A9P!!(&-E;&QA('1A<G1A
M;&UA(.ES(&ME<F5T92!K]GKV='1I('3A=F]L<^%G`$AE;'EK:73V;'3U`%3A
M=F]L<^%G`%3A=F]L<^%G(.ES(&)E;'/U(&UA<F?S(&)EX6QL[73A<P!3<&%N
M>6]L;W)S>N%G`%-P86UA<W-A<W-I;F4@8F7A;&SM=.%S;VL`4W!E8VGA;&ES
M(&MA<F%K=&5R(&)E=FET96QE`$$@8V5L;&$@:V5T=.EB;VYTX7-A`$%Z(&]S
M>FQO<"!K971TZ6)O;G3A<V$`02!S;W(@:V5T=.EB;VYTX7-A`%-P;W)T`%-R
M[2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`07H@96QS]2#I=@#!;&QA;2!V
M86=Y('1A<G1O;>%N>0#!;&QA<&]T`$UE;G3I<VD@9F]R;>%T=6T`0^UM("AU
M=&-A*0#A=&CZ>F]T=`!3=')I;F<@;&ES=&$`5/9R]FQJ_&L@82!C[6UB]6P@
M82!`('5TX6YI('+I<WIT`%-T[6QU<R!;0U-370!680!!*'HI("(E<R(@86QK
M]FYY=G3A<B!N96T@=&%LX6QH873S+@!4X7)G>0!+_&QD:OQK(&5L`"(E<R(@
M^FH@9F5L:&%S>F[A;/,@8F5J96QE;G1K97KI<VD@:^ER96QMZ70@=&]VX6)B
M[71O='1U:RX@UFX@8W-A:R!KZ7)E;&WI;F5K(&5L9F]G863A<^%T(&OV=F5T
M]65N('1U9"!M86ID(&)E:F5L96YT:V5Z;FDN`&%L<_,@:6YD97@`4VEK97+\
M;'0`4VEK97)E<V5N(&AO>GKA861T=6L@(B5S(BUT(&$@<F5N9'-Z97)H97HN
M`"(E<R(@9F5L:&%S>F[A;/,@861A=&%I="!S:6ME<F5S96X@=/9R]FQT_&L@
M82!R96YD<WIE<F+U;"X`4VEK97)E<V5N('3V<O9L=/QK("(E<R(M="X`4VEK
M97)E<V5N(&5L=.%V;VSM=&]T='5K("(E<R(M="!A(')E;F1S>F5R8O5L+@!!
M(&MO;F9I9W5RX6-I\W0@<VEK97)E<V5N('9I<W-Z8>%L;.UT;W1T=6LN($$@
M=N%L=&]ZX7-O:R!M96=T96MI;G3I<^EH97H@9G)I<W/M='-E(&%Z(&]L9&%L
M="X`02!B86-K=7`@:V]N9FEG=7+A8VGS="!E;&UE;G1E='3\:RX`4VEK97)E
M<V5N(&5L;65N=&5T=/QK(&$H>BD@)7,@8F%C:W5P(&MO;F9I9W5RX6-I\W0N
M`"(E<R(@861A=&%I;F%K(&WS9&]S[73A<V$@<VEK97)E<V5N(&UE9W3V<G3I
M;G0N`%-I:V5R97-E;B!E;&UE;G1E='3\:R!A("5S(.%L;&]MX6YY="X`4WIU
M9.%N`-9S<WIE9F]G;&%LX7,`3F%P:V5L=&4`3F%P;GEU9W1A`&YA<&]S`$YA
M<&ME;'1E`$YA<&ME;'1E+VYA<&YY=6=T80!.87!K96QT93H@`$YA<&YY=6=T
M80!.87!N>75G=&$Z(`!F96QS]2!I;F1E>`!/;FQI;F4@:V]M;75N:6OA8VGS
M("AC:&%T*0!3=7)I;F%M90!#<V%LX61NZ78`4W9A;&)A<F0@Z7,@2F%N($UA
M>65N`%-Z=N%Z:6;V;&0`4W;I9&]R<WKA9P!3=N%J8P!!>B!A9&%T<WII;FMR
M;VYI>N%C:?-S(&YA<&SSX6QL;VWA;GET('3V<O9L=/QK`%-Z:6YT86MT:6MA
M:2!H:6)A(&$@:V5R97/U:VEF96IE>NES8F5N`%-Z[7)I86D@07)A8B!+]GIT
MX7)S87/A9P!::79A=&%R`%II=F%T87(L(&5R]7,@<WKI;`!::79A=&%R;VL`
M2V]R86D@>FEV871A<F]K`%135B`H5$%"(&MA<F%K=&5R<F5L(&5L=N%L87-Z
M=&]T="#I<G3I:V5K*2#A;&QO;>%N>0!4X6)LX7IA=`!!('3A8FSA>F%T('1U
M;&%J9&]N<^%G86D`02!TX6)LX7IA="!T=6QA:F1O;G/A9V%I`%1A:G9A;@!4
M86IV86X`5&%D>G-I:VES>G3A;@!486YZX6YI86D@16=Y97/\;'0@2VERX6QY
M<^%G`$$@8^EL.@!&96QA9&%T;VL`5&5L969O;G-ZX6T`07H@96QM^FQT(/-R
M82!H]6WI<G/I:VQE=&4Z(`!(]6WI<G/I:VQE=`!(]6WI<G/I:VQE=#H@`$CU
M;>ER<^EK;&5T/&)R("\^*"5S36%X)7,O)7--:6XE<RD@)F1E9SLE<P!!*'HI
M("(E<R(@<V%B;&]N(&YE;2!T86SA;&AA=/,N`%-A8FQO;F]K(&%D;6EN:7-Z
M=.%C:?-J80!3>O9V96<`8W-A:R!S>O9V96<`4WKV=F5G96QH96QY97KI<P!S
M>O9V96<@=&5T96IE`$-S_`!T:&%I("A425,M-C(P*0!4:&%I9O9L9`!!>B!F
M='`@8O5V[73I<R!N96T@=&%LX6QH873S+@!!($AI<W1O<GD@<F5N9'-Z97(@
M;?MK]F3I<V4@;FEN8W,@96YG963I;'EE>G9E+@!!($AO<F1E+TMO;&%B(&EN
M=&5G<N%C:?,@97IT(&YE;2!TX6UO9V%T:F$Z("(E<R(`07H@24U34"!N87!L
M\WKA<W0@;F5M('-I:V5R_&QT(&UE9VME>F1E;FDN`$$@36%I;G1E;F%N8V4Z
M.B!O<WITX6QY(&)E=/9L=.ES92!N96T@<VEK97+\;'0`07H@3W!C:?,@86)L
M86L@8F5ZX7)O9&]T="X@2VELZ7#I<R!K]G9E=&ME>FEK+@!!($IO9V]S=6QT
M<^%G;VL@:&%S>F[A;&%TX6YA:R!E;/5F96QTZ71E;&4L(&AO9WD@82!R96YD
M<WIE<F=A>F1A(&MO;F9I9W5RX6QJ;VX@96=Y(&$@:F]G;W-U;'1SX6=I(&%D
M871O:V%T('1A<G3S<V%N('3A<F]L;FD@:^EP97,@86QR96YD<WIE<G0N`$-S
M86L@86QU;"!L96=Y96X@:V5R970`02!P87)T;F5R(&%Z;VYO<^UT\W-ZX6UA
M(&YE;2!V;VQT(&UE9V%D=F$O_')E<V5N(&UA<F%D="!V86=Y(&%Z(&%D871B
MX7II<V)A;B!N96T@=F]L="!M96=T86SA;&AA=/,N`$$@<&%R=&YE<B!A9&%T
M86ET('-I:V5R97-E;B!H;WIZX6%D='5K(&$@8^UM:F5G>7KI:^EH97HN`$O\
M;/9NX6QL\R!01U`@86SA[7+A<VD@8FQO:VL@<WK\:W/I9V5S(&$@9&EG:73A
M;&ES86X@86SA[7)T(/QZ96YE="!H:71E;&5S<^EGZ6YE:R!E;&QE;O5R>NES
MZ6AE>BX`02!K]G)L97;I;&QI<W1A(&%Z;VYO<^UT\W-ZX6UA(&YE;2!V;VQT
M(&UE9V%D=F$O_')E<V5N(&UA<F%D="!V86=Y(&%Z(&%D871BX7II<V)A;B!N
M96T@=F]L="!M96=T86SA;&AA=/,N`$$@:_9R;&5VZ6QL:7-T82!N96T@=F]L
M="!M96=A9'9A+@!!('1I=&MO<^UTX7-I('-Z;VQGX6QT873A<V]K:&]Z(&)I
M>G1O;G/A9V]S("AT:71K;W/M=&]T="D@=V5B(&MA<&-S;VQA="!K96QL+@!!
M*'HI("5S(.%L;&]MX6YY8F%N('-Z97)E<&5L;FEE(&ME;&QE;F4@96=Y("5S
M(&)EX6QL[73A<VYA:RX`02AZ*2`E<R#A;&QO;>%N>6)A;B!S>F5R97!E;&YI
M92!K96QL96YE('9A;&%M:6QY96X@)7,@8F7A;&SM=.%S*&]K*6YA:RX`02!F
MX6IL(&YE;2!MX7-O;&AA=/,@]FYM86?A<F$N`$$@9N%J;&)A;B!N96T@=F]L
M="!A9&%T+@!!>B#\>F5N970@9F5J;.EC<V]R86D@82!K]G9E=&ME>O5K+@!!
M('1E;&IE<R!KZ7!E<FYY]7,@_'IE;6WS9"!P<F]B;.EMX6MA="!O:V]Z:&%T
M(&%Z($EN=&5R;F5T($5X<&QO<F5R(&AA<WINX6QA=&$@97-E=.EN+"!M97)T
M(&5B8F5N(&]L>6%N('!R;V=R86UH:6+A:R!V86YN86LL(&%M:6ME="!N96T@
M='5D='5N:R!M96=K97+\;&YI+B!!(&OI<&5R;GGU:F4@;VQV87-H871A=&QA
M;F[A(';A;&AA="P@8FEZ;VYY;W,@961I=&]R(&9U;FMC:?-K(&AIX6YY;WIH
M871N86L@Z7,O=F%G>2!VX7)A=&QA;G5L(&QE9F%G>6AA="!A(&+V;F?I<WKU
M<')O9W)A;2X@5VEN9&]W<R`Y>"!H87-Z;N%L871A(&5S973I;B!N86=Y;VX@
M=F%L\W-Z[6[[+"!H;V=Y("='96YE<F%L('!R;W1E8W1I;VX@9F%U;'0G(&AI
M8F$@;6EA='0@^FIR82!K96QL(&EN9.UT86YI82!M86ID(&$@9^EPZ70N7&Y<
M;D9I9WEE;&UE>G1E='3\:R$@2V%T=&EN='-O;B!A>B!/2R!G;VUB<F$L(&AA
M(&WI9VES(&UE9R!K[7;A;FIA(&OM<^ER96QN:2!A('1E;&IE<R!KZ7!E<FYY
M]7,@_'IE;6WS9&]T+@!!("(E<R(@87IO;F]S[73S="!K:73V<O9L=/QK+@!#
M<V%K(&)A;"!O;&1A;&]N(&QE9WEE;B!K97)E=`!!($=N=5!'('!R;V=R86T@
M:&5L>>ET(&UE9R!K96QL(&%D;FD@82!#<GEP=%]P9W`Z.B!O<WITX6QY(&AA
M<WINX6QA=.%H;WHN`$$@;&5VZ6PL(&UE;'EE="`E<R!N87!JX6X@:_QL9/9T
M="`E<R!C[6UZ971T;F5K("(E<R(@=.%R9WEB86XL(&$@8^UM>F5T="!S>N%M
M[73S9^EPZ6X@;65G:F5L96YT+B!!<G)A(&YI;F-S(&=A<F%N8VEA+"!H;V=Y
M(&5L(&ES(&]L=F%S=.%K(&EL;"X@:&]G>2!M96?I<G1E='3I:RX`36D@;&5G
M>65N(&$@;&5VZ6SM<O,@86)L86MH;WH@;75T873S(&QI;FL@96QN979E>NES
M90!!(&UE>O5K('-ZX6UA(&-S86L@;G5M97)I:W5S(.ER=.EK(&QE:&5T+@!!
M>B!O<&5N<W-L(&UO9'5L('-Z_&MSZ6=E<R!A($AO<F1E7T-R>7!T7W-M:6UE
M.CH@;W-Z=.%L>2!H87-Z;N%L873A:&]Z+@!!("(E<R(@<WIE;>EL>65S(&)E
MX6QL[73A<R!N96T@;65N=&AE=/4@96PL(&UE<G0@;>ER971E(&UE9VAA;&%D
M:F$@82!M96=E;F=E9&5T="!M87AI;75M;W0`3F5M('1A;.%L:&%T\R!A>B!A
M('!R;V=R86T@82!S>F5R=F5R96XL(&%M:2!S>OQK<^EG97,@96YN96L@87H@
M861A='3M<'5S;F%K("@E<RD@82!M96=J96QE;NUTZ7/I:&5Z+@!!>B!I9.EZ
M]6IE;"!K87)A:W1E<B!C<V%K(&5G>65T;&5N(&MA<F%K=&5R(&QE:&5T+@!*
M;V)B(.ES(&)A;"!O;&1A;&]N(&QE9WEE;B!K97)E=`!#<V%K(&IO8F(@;VQD
M86QO;B!L96=Y96X@:V5R970`07H@96QVX6QA<WIT\R!K87)A:W1E<B!C<V%K
M(&5G>65T;&5N(&MA<F%K=&5R(&QE:&5T+@!!*'HI("(E<R(@<WIE<G9E<G0@
M=/9R]FQT_&LN`$$H>BD@(B5S(B!S>F5R=F5R="!E;&UE;G1E='3\:RX`)7,@
M8F5J96QE;G1K97KI<VD@:^ER96QMZ70@=/9R]FQT_&LN`$$@;65G861O='0@
M<V]R("@E9"D@;F5M(&SI=&5Z:6LN`$$H>BD@(B5S(B!I9&5I9VQE;F5S(&;A
M:FP@;F5M(&SI=&5Z:6LN`$$@8F7M<G0@<WKV=F5G(&YE;2!E9WEE>FEK(&$@
M:^EP97)N>?5N(&QE=O5V96PN`$%L=6P@Z7,@9O9L_&P@;&5G>65N(&ME<F5T
M`$-S86L@9F5N="!L96=Y96X@:V5R970`02!F96QT]FQT]G1T(&%D871O:R!A
M>B!E;/5Z]2!LZ7#I<R#S=&$@96QV97-Z=&5K+@!!(&9E;'3V;'3V='0@9N%J
M;'0@;F5M('-I:V5R_&QT(&5L;65N=&5N:2X`02!W96%T:&5R+F-O;2!B;&]K
M:R!N96T@:&%S>F[A;&AA=/,N`$$@;65G:F5L96[I<VD@<W3M;'5S("AT:&5M
M97,I(&%L:_9N>79TX7(@(B5S(B!N96T@=&%LX6QH873S+@!.:6YC<V5N(';A
M;&%S>G1H873S(&]P8VGS+@!.:6YC<R!A(&QE=NEL(&)E;'-E:NEB96X@;65G
M:F5L96[M=&AE=/4@;65L;.EK;&5T+@!4^FP@<V]K(&MA<F%K=&5R('9A;B!E
M8F)E;B!A(&UE>O5B96XN(-9N("5S(&MA<F%K=&5R="!A9&]T="!M96<[(&$@
M;6%X:6WA;&ES86X@;65G861H873S('!E9&EG(&ME=F5S96)B+"!M:6YT("5S
M+@`B)7,B(&9E;&AA<WINX6SS;F%K(&$@<F5N9'-Z97)H97H@863A<V%K;W(@
M:&EB82!T]G)TZ6YT+B`E<P`B)7,B(&9E;&AA<WINX6SS(&%D871A:6YA:R!T
M]G)LZ7-E('-O<N%N(&AI8F$@;.EP971T(&9E;#H@`"(E<R(@<F5N9'-Z97)B
M]6P@=F%L\R!T]G)LZ7-E:V]R(&AI8F$@;.EP971T(&9E;#H@`"(E<R(@;?-D
M;W/M=.%S82!S;W+A;B!H:6)A(&SI<&5T="!F96PZ("5S`$%Z(.%L;&]MX6YY
M="!N96T@<VEK97+\;'0@82!S>F5R=F5R<F4@9F5L=/9L=&5N:2X@)7,@;F5M
M('3V;'3U9/9T="!F96PN`$%Z(.%L;&]MX6YY="!N96T@<VEK97+\;'0@82!S
M>F5R=F5R<F4@9F5L=/9L=&5N:2X@)7,@;F%G>6]B8BP@;6EN="!A(&UA>&EM
MX6QI<V%N(&UE9V5N9V5D971T(&WI<F5T("@E9"!BX6IT*2X`07H@X6QL;VWA
M;GET(&YE;2!S:6ME<OQL="!A('-Z97)V97)R92!F96QT]FQT96YI+B!!*'HI
M("5S(&;A:FQN86L@8W-A:R!E9WD@<NES>F4@=/9L=/5D]G1T(&;V;"X`02!L
M97;I;"!E('+I<WKI;F5K(&UE9VIE;&5N[73I<V5K;W(@:&EB82!T]G)TZ6YT
M`$$@<&%R=&YE<B!A9&%T;VL@:6UP;W)TX6SA<V$@<V]RX6X@:&EB82!T]G)T
MZ6YT+@!!>B!I0V%L96YD87(@861A=&]K(&EM<&]R=.%LX7-A('-O<N%N(&AI
M8F$@=/9R=.EN="X`2&EBX7,@82!M96=A9&]T="!K;VYF:6=U<N%C:?,N($QE
M:&5T+"!H;V=Y(&YE;2!T]FQT]G1T(&MI(&5G>2!S>OQK<^EG97,@;65Z]70N
M`$$@<&%R=&YE<FIE9WEZZ6MK96P@:V%P8W-O;&%T;W,@9F5L861A="!VZ6=R
M96AA:G3A<V$@<V]RX6X@:&EB82!LZ7!E='0@9F5L+B!+Z7)E;2!P<O-BX6QJ
M82!M96<@:^ES]6)B+@!(:6)A('3V<G3I;G0@82!P87)T;F5R(&%D871A:6YA
M:R!F<FES<^UTZ7-E('-O<N%N+B!+Z7)E;2!P<O-BX6QJ82!M96<@:^ES]6)B
M+@!!(&OV<FQE=NEL;&ES=&$@861A=&%I;F%K(&9R:7-S[73I<V4@<V]RX6X@
M:&EB82!T]G)TZ6YT+B!+Z7)E;2!P<O-BX6QJ82!M96<@:^ES]6)B+@!%>B!A
M>B!)34%0('-Z97)V97(@;F5M('3A;6]G871J82!A(&UA<'#A:VAO>B!V86SS
M(&AO>GKA9NERZ7,@;65G;W-Z=.%SX70N`$5Z(&YE;2!T^VYI:R!S>F%BX6QY
M;W,@<F%R(.%L;&]MX6YY;F%K+@!%>B!N96T@=/MN:6L@<WIA8N%L>6]S('II
M<"#A;&QO;>%N>6YA:RX`17H@;F5M('3[;FEK(.ER=NEN>65S(&OA<G1Y87-Z
MX6UN86LN`$5Z(&$@;65G:&%J=/,@;&5H973U=ND@=&5S>FDL(&AO9WD@2%14
M4"UK87!C<V]L871O;B!335,M="!K_&QD:OQN:R!A($-L:6-K871E;&P@*&AT
M='`Z+R]C;&EC:V%T96QL+F-O;2D@<WIO;&?A;'1A=/-N(.%T+@!%>B!A(&UE
M9VAA:G3S(&QE:&5T]7;I('1E<WII+"!H;V=Y($A45%`M:V%P8W-O;&%T;VX@
M4TU3+70@:_QL9&K\;FL@82!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2!S>F]L
M9^%L=&%T\VX@X70N`$5Z(&$@;65G:&%J=/,@;&5H973U=ND@=&5S>FDL(&AO
M9WD@2%144"UK87!C<V]L871O;B!335,M="!K_&QD:OQN:R!A>B!S;7,R96UA
M:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!S>F]L9^%L=&%T\VX@X70N`$5Z
M(&$@;65G:&%J=/,@;&5H973U=ND@=&5S>FDL(&AO9WD@4TU44"UK87!C<V]L
M871O;B!335,M="!K_&QD:OQN:R!6;V1A9F]N92!S>N%M;VMR82!A(%9O9&%F
M;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="D@<WIO;&?A;'1A=/-N(.%T
M+B!!('-Z;VQGX6QT873A<R!I9^EN>6)E=NET96SI:&5Z(%9O9&%F;VYE($ET
M86QY(&5M86EL(&/M;2!S>OQK<^EG97,N`$5Z(&$@;65Z]2!N96T@;6%R861H
M870@_')E<RX`16)B96X@82!M97KU8F5N(&-S86L@96?I<WH@<WKA;6]K(.%L
M;&AA=&YA:RX`16)B96X@82!M97KU8F5N(&-S86L@96?I<WH@<WKA;6]K(.ES
M(&ME='3U<W!O;G0@;&5H970N`$5B8F5N(&$@;65Z]6)E;B!C<V%K(&]K=.%L
M:7,@<WKA;6]K(.%L;&AA=&YA:RX`17H@82!M97KU(&-S86L@=F5S<WKU=F5L
M('9A9WD@<WKS:_9Z>F5L(&5L=N%L87-Z=&]T="!E9^ES>B!S>N%M;VMA="!T
M87)T86QM87IH870`17H@87H@Z7)TZ6L@8W-A:R!S>N%M(&QE:&5T+@!%8F)E
M;B!A(&UE>O5B96X@:&5X861E8VEMX6QI<R!21T(@<WKM;FOS9"#A;&QH870L
M('!L+B`G(S$R,S1A9B<N`$5Z96X@861A=&]K:V%L(&MA<&-S;VQA=&]S(&9E
M;&%D871O:V%T(&$@<WIE<G9E<B!MX7(@96QVZ6=E>G1E+@!%>B`E<P!%>B!E
M9WD@2V]L86(@1W)O=7!W87)E(&]B:F5K='5M+B!!>B!I;'EE;B!O8FIE:W1U
M;2!M96=J96QE;NUTZ7/I:&5Z(&]L>6%N(&5M86EL(&ML:65N<W!R;V=R86T@
M<WK\:W/I9V5S+"!A;65L>2!KZ7!E<R!A($MO;&%B($=R;W5P=V%R92!F;W)M
MX71U;2!K97IE;.ESZ7)E+B!);'EE;B!E;6%I;"!K;&EE;G-E:R!L:7-TX6IA
M(&SA=&AA=/,@:71T.B`E<P!%>G0@82!L979E;&5T(&WA<R!K87)A:W1E<FOI
M<WIL971T96P@*"5S*2#M<G3A:RP@;6EN="!A;6ET(-9N(&AA<WINX6PN`$5Z
M(&$@<WKA;2!N96T@;&5H970@96=Y;NEL(&MI<V5B8BX`17H@82!S>F5R=F5R
M(&YE;2!KZ7!E<R!K:6)O;G1A;FD@82!Z:7`@:6QL+B!G>FEP(.%L;&]MX6YY
M;VMA="X`17H@82!R96YD<WIE<B!J96QE;FQE9R!I;F%K=&EVX6QV82!V86XN
M`$5Z(&%Z(.ER=.EK(&-S86L@<WKA;2!L96AE="X`17IT(&%Z(&%B;&%K(&-S
M86L@87H@3W!C:?-K(&%B;&%K8O-L(&CM=FAA=/,`5FEL;.%M;.%S`$AI8F%B
M96IE;&5N=.ES+6ME>F5LZ7,`263U`$UU;FMA:63U+6YY:6QVX6YT87)TX7,`
M263U(&9O<FWA='5M`$ED]2!VX6QA<WITX7,`2V5L970M5&EM;W(`5&ET=6QU
M<P!#[6T@*'1O;VQT:7`I`$/M;7IE='0`2&$@=/9B8B!E;&5M970@:7,@:VD@
M86MA<B!J96SV;&YI+"!T87)T<V$@;&5N>6]M=F$@82!#;VYT<F]L("A00RD@
M=F%G>2!A($-O;6UA;F0@*$UA8RD@8FEL;&5N='G[="!A(&MA='1I;G3A<R!K
M]GIB96XN`$UA`$A434P@9F]R<N%S;NEZ970@:VDO8F4`5&]G;P!4;VME;&%U
M`$AO;&YA<`!4;VYG80!F]FS\;`!,96=F96QS]2!F<F%M92`H7W1O<"D`1F]R
M9.UTX7-O:P!4<FEN:61A9"#I<R!4;V)A9V\`26=A>B!V86=Y(&AA;6ES`$ME
M`%1U;NEZ:6$`5/9R]FMO<G-ZX6<`=/9R]FL@*$E33RTX.#4Y+3DI`%3\<FMM
M96YI<WITX6X`5'5R:W,M(.ES($-A:6-O<RUS>FEG971E:P!4=79A;'4`S7)J
M82!B92P@;6ET(';A;&%S>G1O='0Z(`!55B!I;F1E>#H@`%523`!54DPL(&UE
M;'EE;B!E9WD@<')O9W)A;2!E;&9O9V%D:F$@82!S>F]L9^%L=&%T\R#A;'1A
M;"!K_&QD]G1T(&O\;&3V='0@:^EZ8F5S[73I<VD@:F5L96YTZ7-T`%523#H`
M56=A;F1A`%5K<F%J;F$`3F5M('-I:V5R_&QT(&$@5D93(&%L:_9N>73A<F)A
M(&)E;.EP;FDN`$$@8F5J96QE;G1K97KI<VD@:F]G;W-U;'1SX6<@:6?I;GEL
MZ7-E:V]R(&YE;2!S:6ME<OQL="!A>B!A9&%T;VL@96QTX7)O;.%S82X`3F5M
M('-I:V5R_&QT(&$H>BD@(B5S(B!61E,@9N%J;"!E;.ERZ7-I(&IO9V]S=6QT
M<^%G86ET(&UE9W;A;'1O>G1A=&YI+@!.96T@<VEK97+\;'0@82AZ*2`E<R\E
M<R!61E,@9N%J;"!E;.ERZ7-I(&IO9V]S=6QT<^%G86ET(&UE9W;A;'1O>G1A
M=&YI+@!.96T@<VEK97+\;'0@82AZ*2`E<R!A;&OV;GEV=.%R8F$@8F5LZ7!N
M:2X`02AZ*2`B)7,B(.%L;&]MX6YY(&WI<F5T92!N96T@X6QL87#M=&AA=/,@
M;65G+@!!*'HI("(E<R\E<R(@X6QL;VWA;GD@;>ER971E(&YE;2#A;&QA<.UT
M:&%T\R!M96<N`$%Z(%-13"!S>F5R=F5R(&YE;2#I<FAE=/4@96PN`$%Z(%-3
M3"!K87!C<V]L870@;F5M(.EP[71H973U(&9E;"X`02!61E,@9N%J;"!N96T@
M;>%S;VQH873S(.%T+@!.96T@<VEK97+\;'0@82AZ*2`B)7,B(%9&4R!A;&OV
M;GEV=.%R="!LZ71R96AO>FYI+@!.96T@<VEK97+\;'0@;.ET<F5H;WIN:2!A
M(%9&4R!A;&OV;GEV=.%R="X`3F5M('-I:V5R_&QT(&SI=')E:&]Z;FD@82!6
M1E,@9N%J;'0N`$$H>BD@(B5S(B!61E,@;6%P<&$@;F5M(&AO>FAA=/,@;.ET
M<F4N`$YE;2!S:6ME<OQL="!LZ71R96AO>FYI(/QR97,@5D93(&;A:FQT+@!!
M('3V;?9R[71E='0@X6QL;VWA;GET(&YE;2!S:6ME<OQL="!K:6)O;G1A;FDN
M`"(E<R(@;F5M('3V<O9L:&5T]2P@87H@86QK]FYY=G3A<B!N96T@_')E<RX`
M(B5S(B!T]G)LZ7-E(&YE;2!S:6ME<OQL=#H@)7,N`"5S(&YE;2!T]G+V;&AE
M=/4L(&%Z(&%L:_9N>79TX7(@;F5M(/QR97,N`$$@5D93(&%L:_9N>79TX7(@
M;F5M('3V<O9L:&5T]2!R96MU<GKM=F%N+@!!(%9&4R!A;&OV;GEV=.%R(&YE
M;2!T]G+V;&AE=/4N`$$@5D93(&%L:_9N>79TX7(@;F5M('3V<O9L:&5T]3H@
M)7,N`$$H>BD@(B5S(B!61E,@9N%J;"!N96T@=/9R]FQH973U+@!!(%9&4R!F
MX6IL(&YE;2!T]G+V;&AE=/4N`$$H>BD@(B5S(B!61E,@;6%P<&$@;F5M('3V
M<O9L:&5T]2X`3F5M(';I9V5Z:&5T\R!R96MU<GKM=B!T]G)LZ7,@82!61E,M
M8F5N.B`E<RX`3F5M(&AA=.%R;WIH873S(&UE9R!A(&IE;&5N;&5G(.ER=NEN
M>65S(&%L:_9N>73A<BX`02!T86[Z<^UT=N%N>2!RZ7-Z;&5T97,@861A=&%I
M(&YE;2!H873A<F]Z:&%T\VL@;65G`$YE;2!S:6ME<OQL="!B96]L=F%S;FD@
M)7,@9&5F:6[M8VGS:N%T+@!!(%9&4R!FX6IL(&YE;2!H96QY97IH973S(.%T
M+@!!*'HI("(E<R(@5D93(&;A:FP@;F5M(&YY:71H873S(&UE9RX`02!61E,@
M9N%J;"!N96T@;GEI=&AA=/,@;65G(.URX7-I(&/I;&QA;"X`02!61E,@9N%J
M;"!N96T@;GEI=&AA=/,@;65G("X`02!T]FWV<NUT971T(.%L;&]MX6YY(&YE
M;2!N>6ET:&%T\R!M96<N`$$@5D93(&;A:FP@;F5M(&]L=F%S:&%T\R`H82!F
M:6QE<VEZ92@I('-I:V5R=&5L96X@=F]L="DN`$$@5D93(&;A:FP@;F5M(&]L
M=F%S:&%T\R`H82!G971&:6QE4VEZ92@I('-I:V5R=&5L96X@=F]L="DN`$5Z
M(&$@9N%J;"!N96T@;VQV87-H873S.B``02!V9G-R;V]T(&%L:_9N>79TX7(@
M;F5M(&]L=F%S:&%T\RX`)7,@;F5M(&YE=F5Z:&5T]2#A="`E<R!NZ79R93H@
M;>%R(&SI=&5Z:6L@:6QY96X@;F5V^R!M87!P80!!(%9&4R!A;&OV;GEV=.%R
M(&YE;2!N979E>FAE=/4@X70N`$$@5D93(&%L:_9N>79TX7(@;F5M(&YE=F5Z
M:&5T]2#A=#H@)7,N`$$H>BD@(B5S(B!61E,@9N%J;"!N96T@;F5V97IH973U
M(.%T+@!!*'HI("5S+R5S(%9&4R!FX6IL(&YE;2!N979E>FAE=/4@X70N`$$@
M5D93(&;A:FP@;F5M(&YE=F5Z:&5T]2#A="X`07H@)VUK:7-O9G,G('!R;V=R
M86T@;F5M(&9U='1A=&AA=/,N`$YE;2!S:6ME<OQL="!L969O<F3M=&%N:2!E
M>G0@82!7;W)D(&1O:W5M96YT=6UO=`!!*'HI("(E<R(@5D93(&;A:FP@;F5M
M(.UR:&%T\RX`02!61E,@9N%J;"!N96T@[7)H873S("AA(&-O<'DH*2!S:6ME
M<G1E;&5N('9O;'0I+@!!(%9&4R!FX6IL(&%D871A:2!N96T@[7)H873S:R!K
M:2X`02!61E,@9N%J;"#M<N%S82!K=O-T873Z;&SI<.ES(&UI871T(&YE;2!F
M96IE>FAE=/4@8F4N`&%LX6CZ>F]T=`!-Z6=S92!M96YT<_QK(&5L`%9I<W-Z
M879O;FIA(&%Z('5T;VQS\R!VX6QT;WIT873A<W0`02!K87!C<V]L870@9F5L
M=NET96SI="!K]G9E=/5E;B!VX7)A=&QA;B!VX6QA<WH@Z7)K97IE='0@82!S
M>F5R=F5R=/5L.B``5N%R871L86X@=N%L87-Z(.ER:V5Z971T(&$@<WIE<G9E
M<G3U;"!E<G)E.B``0F5S;W)O;&%T;&%N`%5N:6-O9&4@*%541BTX*0!%9WEE
M<_QL="!!<F%B($5M[7)SZ6=E:P!%9WEE<_QL="!+:7+A;'ESX6<`16=Y97/\
M;'0@P6QL86UO:P!%9WEE<_QL="#!;&QA;6]K+"!K:7-E8F(@:_QL<_4@<WII
M9V5T96L`96=Y<^EG`$ES;65R971L96X`27-M97)E=&QE;B!A<&EM<V=I9"`H
M05!)($UE<W-A9V4@240I+@!)<VUE<F5T;&5N(&-L:6US9VED("A#;&EE;G0@
M365S<V%G92!)1"DN`$$@;65G861O='0@:&5L>2!I<VUE<F5T;&5N+@!)<VUE
M<F5T;&5N(&9E;&AA<WINX6SS:2!NZ78@=F%G>2!J96QS>O,N`%3A=F]L[71S
M=6L@96P@:6YN96X@82!L:6YK970`3FEN8W,@96QN979E>G9E`$)I>G1O;G/A
M9VD@;VMO:V+S;"!A(&9E;&AA<WINX6SS:2!P<F]G<F%M;VL@;F5M(&AA<WIN
MX6QH871JX6L@82!+:7;A9^%S+TWA<V]LX7,O0F5I;&QE<WITZ7,@;?-D<WIE
M<G0N($MA='1I;G1S;VX@87H@3TL@9V]M8G)A+"!H82!A(&UO>FEL;&$N;W)G
M('=E8F]L9&%L;VX@96P@:^UVX6YJ82!O;'9A<VYI(&$@=&5C:&YI:V%I(&QE
M[7+A<W0@;65L>2!M96=A9&IA+"!H;V=Y86X@;&5H970@97IT(&WI9VES(&5N
M9V5DZ6QY97IN:2X`02!S>NUN('9I<W-Z8>%L;.UTX7-A`$YE;2!TX6UO9V%T
M;W1T(&5X=&5N>FGS`$WS9&]S[73A<P`E<R!A9&%T86EN86L@;?-D;W/M=.%S
M80!!(&9E;&AA<WINX6SS(&%D871A:6YA:R!M\V1O<^UTX7-A`"(E<R(@=N%L
M=&]ZX7-A:70@96QM96YT971T_&LN`$%Z('5P9W)A9&4@<')O9W)A;6]T('3V
M<O9L=/QK+@!&96QT]FQTZ7,`07H@]G-S>F5S(&%L:V%L;6%ZX7,@:V]N9FEG
M=7+A8VGS:N%T(&9E;'3V;'3V='3\:R!A('-Z97)V97)R92X`;&%T:6X@;F%G
M>6)E=/MK`&YA9WEB973[<R!R\VUA:2!S>N%M;VL`57)U9W5A>0!(87-Z;N%L
M:G5K(&$@:F5L96YL96=I=#H@)7,`2&%S>F[A;&IU;FL@4U-,+70`06MK;W(@
M:&%S>F[A;&IU:RP@:&$@87H@24U34"!S>F5R=F5R96X@;>%S(&$@8F5J96QE
M;G1K97KI<VD@;F5V_&YK+VIE;'-Z879U;FLN`$9E;&AA<WINX6SS:2!NZ78`
M)7,@9F5L:&%S>F[A;/,@;F5M(&IO9V]S=6QT("5S+7)E+@!&96QH87-Z;N%L
M\VL@861M:6YI<WIT<N%LX7-A`$9E;&AA<WINX6SS:2!B9>%L;.UTX7-O:P!"
M96IE;&5N=&ME>NES(&IO9V]S=6QT<^%G(&EGZ6YY;.ES90!%>F5N(&$@<F5N
M9'-Z97)E;B!N:6YC<R!E;F=E9.EL>65Z=F4@87H@^FH@9F5L:&%S>F[A;/-K
M(&)E:F5L96YT:V5ZZ7-I(&IO9V]S=6QT<^%GX6YA:R!I9^EN>6SI<V4N`$%Z
M(&9E;&AA<WINX6SS:2!A>F]N;W/M=/,@;F5M('1A;.%L:&%T\P!&96QH87-Z
M;N%L\VD@;NEV`$$H>BD@(B5S(B!F96QH87-Z;N%L\VD@;NEV(&WA<B!LZ71E
M>FEK+@!&96QH87-Z;N%L\VD@;NEV.@!&96QH87-Z;N%L\VD@;NEV.B``02!R
M96YD<WIE<B!F96QH87-Z;N%L\VDZ`-QZ8F5G:7-Z=.%N`$$@5D93(&%L:_9N
M>79TX7(@;F5M(&SI=&5Z:6LN`%-Z86)A9'/A9R!A;&%T=&D@875T;VUA=&EK
M=7,@96UA:6PM=N%L87-Z`$$@:_9V971K97KU(&AE;'EE:V5T('1A;.%L='5K
M.B``R7)VZ6YY97-SZ6<`07H@Z7)TZ6ME:V5T('!E<F-B96X@861J=6L@;65G
M+"!M;W-T86YT\VP@<WKA;>UT=F$N`$$@Z7)TZ6L@;F%G>6]B8BP@;6EN="!A
M(&QE9VYA9WEO8F(@;65G96YG961E='0@:&]S<WKZ<^%G.B`E<RX`R7)TZ6ME
M:P!6X6QA<WIT:&%T\R#I<G3I:V5K`%9A;G5A='4`=N%L=&]Z\P!696YE>G5E
M;&$`02!H:71E;&5S[73I<R!N96T@<VEK97+\;'0@+2!L96AE="P@:&]G>2!A
M(&QE=F5L970@=F%L86MI(&UE9W;A;'1O>G1A='1A+@!697)Z:?,`5F5R>FGS
M:_9V973I<P!&_&=G+B!E;&AE;'EE>NES`$;\9V?U;&5G97,@8F5L<_4@;6%R
M9_,`9OQG9_5L96=E<SH`;F%G>6]N(&UA9V%S`%9I971N86T`=FEE=&YA;6D@
M*%9)4T-)22D`)7,@;65G=&5K:6YTZ7-E`$O\;'/U('=E8F]L9&%L(&UE9VIE
M;&5N[73I<V4`2F5L96[M='/\:R!M96<L(&UI;G0@)7,`0G)I="!6:7)G:6XM
M<WII9V5T96L`06UE<FEK86D@5FER9VEN+7-Z:6=E=&5K`$SA=/-TX79O;'/A
M9P!,X73S=.%V;VQSX6<Z(`!6;V1A9F]N92!)=&%L>2!S>F]L9^%L=&%TX7,@
M4TU44"UN(&ME<F5S>G3\;`!&24=914Q-15I4153)4P!&24=914Q-15I4153)
M4R$@2\E:6D5,(%3!5D],S51302!%3"!!(%-#4DE05$54("5S+5+53"X`5TE.
M('-Z;VQGX6QT873A<R!(5%10+6X@X70`5V%L;&ES(.ES($9U='5N80!&:6=Y
M96QM97IT973I<P!3>F4`263U:N%RX7,@96SU<F5J96QZZ7,`07H@:63U:N%R
MX7-I(&%D871O:R!F;W)RX7-A`%=E8@!796)H96QY96L`:&5T96YT90#<9';V
M>O9L:OQK`-QD=O9Z]FQJ_&LZ("5S`-QD=O9Z]FQJ_&LL("5S`&YY=6=A="UE
M=7+S<&%I("A)4T\M.#@U.2TQ*0!N>75G870M975R\W!A:2`H25-/+3@X-3DM
M,34I`$YY=6=A="U3>F%H87)A`$UI;'EE;B!A;&MA;&UA>N%S="!M=71A<W-O
M;B`E<R!A(&)E:F5L96YT:V5ZZ7,@=73A;C\`36D@87H@96QVX6QA<WIT\R!K
M87)A:W1E<C\`36D@87H@:63I>F5T:V%R86MT97(_`%=H97)E:7,@075S>G1R
MX6QI82!TZ7)KZ7``365L>6EK(&-I:VQU<P!-96QY:6L@;6]D=6QO:V%T(&%K
M=&EVX6QJ=6L@82!2:6-H(%1E>'0@961I=&]R8F%N/P!3>NEL97-SZ6<`4WKI
M;&5S<^EG($-34R!E9WESZ6=B96X`02`E<R!M96[\('-ZZ6QE<W/I9V4@82!B
M86P@;VQD86QO;B`H82!K]G9E=&ME>O4@8F5J96QE;G1K97KI<W0@:_9V973U
M96X@;&5S>B#I<G;I;GEE<RD`02!TX6)LX7IA="!S>NEL97-SZ6=E`$$@<WKI
M;&5S<^EG(&WI<G3I:V5G>7/I9V4`4WKI;&5S<^EG.@!7:6MI`%-ZZ6P`4WKI
M;"!A(')E9V=E;&D@\W+A:V)A;@!3>NEL<V5B97-SZ6<@8W-O;?-B86X`4WKI
M;#H`4WKI;#H@`$+V;&-S97-SZ6<`2^UVX6YSX6=L:7-T80!-=6YK80!-=6YK
M86AE;'EI(&/M;0!-=6YK86AE;'EI('1E;&5F;VX`02`E9"X@<V]R8F%N(&YE
M;2!M96=F96QE;/4@82!M97KU:R!S>N%M82X@5N%R=#H@)60L('1A;.%L=#H@
M)60N`$YE;2!M96=F96QE;/4@82!M97KU:R!S>N%M82X@5N%R=#H@)60L('1A
M;.%L=#H@)60N`$AI8N%S(&]F9G-E="`H)60I(&$@5D93(&;A:FP@;VQV87/A
M<V%K;W(N`$QI;G5X(&9O<G+A<VOS9"!K97)E<WIR969E<F5N8VEA`%@U,#EV
M,R!A;&%P=F5T]2!K;W)LX71O>N%S;VL`6#4P.78S(&MI=&5R:F5S>G1E='0@
M:W5L8W-H87-Z;N%L870`6#4P.78S('1U;&%J9&]N;W,@86QT97)N873M=B!M
M96=N979E>NES90!8-3`Y=C,@='5L86ID;VYO<R!K=6QC<V%Z;VYO<^UT\P!8
M-3`Y=C,@:VET97)J97-Z=.ES96L`65D`65E960!986AO;R$@=.ER:^EP`.EV
M96YT90!*96UE;@!)9V5N`$EG96XL(&)E;&5G>65Z96TN`$UO<W0@2%1-3"!4
M15A4(&WS9&)A;B!V86XN($AA<WINX6QJ82!A(%L\/ET@9V]M8F]T+"!H82!V
M:7-S>F$@86MA<B!VX6QT86YI(&$@<WIO:^%S;W,@9W)A9FEK=7,@*%=94TE7
M64<I(&UE9VIE;&5N[73I<W)E+@!.96T@:&]Z:&%T(&SI=')E("5D(&)L;VMK
M;N%L('3V8F)E="X`07H@UFX@9F5L:&%S>F[A;/-A>F]N;W/M=.%S82!N96T@
M=/9R=.EN="!M96<N`$$@=&5L:F5S(&[I=F)E;B!N96T@<WIE<F5P96QH970@
M82`G7"<@:V%R86MT97(N`$YE;2!A9&]T="!M96<@Z7)VZ6YY97,@96UA:6P@
M8^UM970N`$YE;2!A9'1A(&UE9R!A(&UE9V9E;&5L=&5TZ7-T(&%Z(&EM<&]R
M=.%L="!FX6IL(.ES(&$H>BD@)7,@;65Z]6D@:_9Z]G1T+@!3:6ME<F5S96X@
M:VEJ96QE;G1K97IE='0N`$5G>2!M;V)I;'1E;&5F;VYS>N%M;W0@:V5L;"!M
M96=A9&YI82P@8W-A:R!A('-ZX6UJ96=Y96ME="P@97-E=&QE9R!E9WD@)RLG
M(&MA<F%K=&5R<F5L(&ME>F1V92P@:&$@;F5M>F5T:_9Z:2!TX7)C<^%ZX7-I
M(&WS9&]T(&OM=N%N(&AA<WINX6QN:2X`16QF;V=A9&AA=/,@Z7)TZ6ME="!K
M96QL(&UE9V%D;FEA+@!!($1A=&%4<F5E(&%L<F5N9'-Z97)T(&)E(&ME;&P@
MX6QL[71A;FD@82!B96IE;&5N=&ME>NES:2!J;V=O<W5L='/A9V]K(&EGZ6YY
M;.ESZ6AE>BX`02!61E,@86QR96YD<WIE<B!N:6YC<R!B9>%L;.UT=F$N`$5L
M]6)B(&QE(&ME;&P@[7)N:6$L(&AO9WD@;6EL>65N('!R;V)LZ6WA="!T87!A
M<WIT86QT+"!M:65L]71T(&5L:_QL9&D@82!H:6)A:F5L96YTZ7-T+@!-96<@
M:V5L;"!A9&YI(&5G>2!54DPM="P@86AO=F$@97H@82!L:6YK(&UU=&%T`$MI
M(&ME;&P@=N%L87-Z=&%N:2!E9WD@=/9R;&5N9/4@<WIE<G9E<G0N`$UE9R!K
M96QL(&%D;FEA+"!H;V=Y(&UE;'EI:R!F96QH87-Z;N%L\R!A9&%T86ET(&OM
M=N%N:F$@=/9R]FQN:2X`365G(&ME;&P@861N:6$@87H@96QTX79O;.UT86YD
M\R!F96QH87-Z;N%L\VD@;F5V970N`$UE9R!K96QL(&%D;FEA(&$@:&]Z>N%A
M9&%N9/,@9F5L:&%S>F[A;/,@;F5VZ70N`$UE9R!K96QL(&%D;FEA+"!H;V=Y
M(&UE;'EI:R!F96QH87-Z;N%L\R!A9&%T86ET(&OM=N%N:F$@X73M<FYI+@!-
M96<@:V5L;"!A9&YI82!E9WD@<&%R86YC<V]T+@!-96<@:V5L;"!A9&YI82!A
M>B#Z:B!K871E9_-R:6$@;F5VZ70N`$]L87-Z;W)S>N%G:2!T96QE9F]N<WKA
M;6]T(&ME;&P@;65G861N:6$`07H@UFX@)7,@:V%P8W-O;&%T82!I9/5T^FQL
MZ7#I<R!M:6%T="!M96=S>F%K861T+B!+Z7)E;2!J96QE;G1K97IZ96X@8F4@
M^FIR82X`07H@UFX@96UA:6P@8^UM90!!>B#6;B!F96QA9/-I("A&<F]M.BD@
M8^UM93H`4WIE;>EL>65S(&EN9F]R;>%C:?,`07H@UFX@)7,@:V%P8W-O;&%T
MX6YA:R!K97ID971E(/-T82!M96=VX6QT;WIO='0@87H@:6YT97)N970@8^UM
M92X@0FEZ=&]N<^%GX6YA:R#I<F1E:^EB96X@:7-MZ70@8F4@:V5L;"!J96QE
M;G1K97IN:64N`$%Z(-9N(&YE=F4`07H@UFX@9F5L:&%S>F[A;/-A>F]N;W/M
M=/,@86QR96YD<WIE<F4@;F5M('1E<WII(&QE:&5T]7;I(&%Z(/IJ(&9E;&AA
M<WINX6SS:R!LZ71R96AO>N%SX70N($AA(&$@2&]R9&4@<F5N9'-Z97)R96P@
M:^UVX6YJ82!K97IE;&YI(&$@9F5L:&%S>F[A;/-I(&%D871O:V%T+"!A:VMO
M<B!MX7-I:R!F96QH87-Z;N%L\V%Z;VYO<^UT\R!A;')E;F1S>F5R<F4@=F%N
M('-Z_&MSZ6=E+@!!>B#6;B!F96QH87-Z;N%L\V%Z;VYO<^UT\R!A;')E;F1S
M>F5R92!N96T@=&5S>FD@;&5H973U=ND@82!F96QH87-Z;N%L\VL@;&ES=.%Z
MX7/A="P@=F%G>2!V86QA;6D@;VMB\VP@;&5T:6QT;W1TX6L@97IT(&$@;&5H
M973U<^EG970N`$%Z(-9N(&+V;F?I<WKU<')O9W)A;6IA(&UE9W;A;'1O>F]T
M="!A>B#6;B`E<R!M=6YK86MA<&-S;VQA=.%N86L@:V5Z9&5T92#S=&$N($)I
M>G1O;G/A9V$@Z7)D96OI8F5N(&ES;>ET(&)E(&ME;&P@:F5L96YT:V5Z;FEE
M+@!!>B#6;B!B]FYGZ7-Z]7!R;V=R86UJ82!N96T@=.%M;V=A=&IA(&5Z="!A
M(&QE:&5T]7/I9V5T+@!!>B#6;B!B]FYGZ7-Z]7!R;V=R86UJ82!N96T@=.%M
M;V=A=&IA(&5Z="!A(&YY;VUT873A<VD@;W!C:?-T+B!0<O-BX6QJ;VX@82!#
M=')L+5`@*'9A9WD@0V]M;6%N9"U0*2!L96YY;VWA<^%V86P@;GEO;71A=&YI
M+@!!(&IE;&5N;&5G(.ER=NEN>65S(&ED]7KS;F$Z`$%Z(-9N(&%L87#I<G1E
M;&UE>NES('-Z97)I;G1I(&%Z;VYO<^UT\VIA(&UE9W;A;'1O>F]T="X`07H@
MUFX@86QA<.ER=&5L;65ZZ7,@<WIE<FEN=&D@87IO;F]S[73S:F$Z`$%Z(-9N
M('1E;&IE<R!N979E.@!,96KA<G0@82!B96IE;&5N=&ME>NES:2!J;V=O<W5L
M='/A9V$N`$%Z(-9N("5S+7)E(&AA<WINX6QT(/IJ(&IE;'-Z879A.B`E<P!!
M>B#6;B#Z:B!B9>%L;.UTX7-A:70@Z7)VZ6YY97/M=&5T=/QK(&$@;6]S=&%N
M:2!B96IE;&5N=&ME>NES(&ED96KI<F4N`$%Z(-9N(/IJ(&)EX6QL[73A<V%I
M="!E;&UE;G1E='3\:RX`07H@UFX@:F5L<WIA=N%T(.%TX6QL[71O='1U:P!!
M>B#6;B!J96QS>F%VX70@X73A;&SM=&]T='5K+"!NZ7IZ92!M96<@82!L979E
M;&5I="P@;6%J9"!J96QE;G1K97IZ96X@8F4@87H@^FH@:F5L<WKS=F%L+@!!
M>B#6;B!J96QS>F%VX6YA:R!L96KA<G0@87H@Z7)VZ6YY97-SZ6=I(&ED96IE
M+@!!>B#6;B#A;'1A;"!H87-Z;N%L="!TX79O;&D@<WIE<G9E<F5K.@!*=6=O
M<WILX79I80!:86ER90!:86UB:6$`6FEM8F%B=V4`6TYE(&UU=&%S<W5K(&$@
M8F5I9.EZ971T('-Z]G9E9V5T70!;2&EB86IE;&5N=.ES70!;375T87-S=6L@
M82!B96EDZ7IE='0@<WKV=F5G970@+0!;375T87-S=6L@82!B96EDZ7IE='0@
M<WKV=F5G970@+2`E<R!S;W)=`%LE<R\E<R!S;W)=`%]!9&UI;FES>G1RX6-I
M\P!?4&%R86YC<W-O<@!3;W)T]G)LZ7,`7T-S;W!O<G1O:P!395]G[71SZ6<`
M02!KZ7`@='5L86ID;VYSX6=A:2XN+@!"96IE;&5N=&ME>NES`%]+:6IE;&5N
M=&ME>NES`$$@;&EN:R!M\V1O<^UTX7-A+BXN`%]/<&-I\VL`7TIO9V]S=6QT
M<^%G;VL`02!L:6YK('3V<FSI<V4N+BX`7T)EX6QL[73A<V]K`%3A8FSA>F%T
M('1U;&%J9&]N<^%G;VL`7T9E;&AA<WINX6SS:P!C[6UJ96=Y>NEK`&$@8^UM
M>F5T="!I<VUE<F5T;&5N`&YA<'3A<@!N>75G;V1T`&$@:VEM96YE=&D@X6QL
M;VWA;GD@;F5M(&AO>FAA=/,@;.ET<F4`82!B96UE;O4@X6QL;VWA;GD@;F5M
M(&YY:71H873S(&UE9P!K871T:6YT<V]N(&ED90!P87)A;F-S<V]R:2!H:6)A
M`&MO;F9I9W5RX6-I\W,@:&EB80!H:>%N>7II:R!E9WD@9F]N=&]S(')E;F1S
M>F5RX6QL;VWA;GD`861A=&9O<FWA='5M(&AI8F$`;?-D;W/M=.%S`&%Z(&%D
M870@;F5M('1A;.%L:&%T\P!C<_9K:V5N`&;A:FP`)7,@*"5S*2!I<N%N>6+S
M;"P@)7,@)7,@<V5B97-SZ6=G96P`<WKI;&SV:^ES96L`;3H`82!GZ7`@;F5V
M92!N96T@:7-M97)T`&%Z;VYN86QI`&EN<'5T+V]U='!U="!H:6)A`&)E;'/U
M('!R;V=R86UH:6)A`'-O<ET`07H@;6MS:6]F<R!P<F]G<F%M("5D(&AI8F%K
M\V1D86P@;&7A;&QT(&%Z($E33R#A;&QO;>%N>2!KZ7-Z[73I<V4@:_9Z8F5N
M+@!NZ78`02!P<F]G<F%M;F%K(&5Z(&$@<NES>F4@;>EG(&YI;F-S(&UE9W9A
M;/-S[71V82X`02!P<F]G<F%M;F%K(&5Z(&$@<NES>F4@;>EG(&YI;F-S(&UE
M9W9A;/-S[71V82X`:F5G>7IE='3V;6(`<WKA>F%LZ6L`;FEN8W,@;65G9F5L
M96SU(&IO9V]S=6QT<^%G80!P:7AE;`!A9&%TX71V:71E;&D@*'!R;W1O:V]L
M;"D@:&EB80!E;65L:V5D:6L`82!S>F]L9^%L=&%TX7,@;F5M(.%L;"!R96YD
M96QK97KI<W)E`&[I>GK\:R!M96<@82!K_&SV;F)SZ6=E:V5T`'-M<S)E;6%I
M;"!S>F]L9^%L=&%TX7,@2%144"UN(.%T`';A;'1O>F%T;&%N`')E;F1S>F5R
M:&EB80!F96QA9&%T;&ES=&$`X71M96YE=&D@:&EB80!M96=E<O5S[73I<VOI
M;G0@:^ET<WIE<B#M<FIA(&)E(&$@:F5L<WKS=`!NZ78@;NEL:_QL`&$@9F5L
M:&%S>F[A;/,@X6QT86P@=N%L87-Z=&AA=/,`=D-A<F0`<WHZ````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&]C86QE+VAU7TA5+VAE;'`N>&UL````````````````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`T,#<V(#$P-3$U-#,S-S0Q(#`R
M,30V-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/WAM;"!V97)S:6]N/2(Q+C`B(&5N8V]D:6YG/2)I<V\M.#@U.2TR(C\^
M"CPA+2T@2&]R9&4@,RXQ(&AE;'`Z(&AU7TA5("1(;W)D93H@:&]R9&4O;&]C
M86QE+VAU7TA5+VAE;'`N>&UL+'8@,2XR+C$P+C,@,C`P-B\P,R\P,R`Q,SHT
M-#HQ,"!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB<W5M;6%R
M>2(@<W1A=&4](G5P=&]D871E(B!M9#4](C8X8V$S,V8W9C!C.6%A931C,3`S
M96(T-S0Y,F-D8S$U(CX*/'1I=&QE/D$@<WIE;>EL>65S(/9S<WIE9WKU("AP
M;W)TX6PI(&]L9&%L/"]T:71L93X*(#QP87)A/@H@($5Z(&%Z(&]L9&%L(&=Y
M;W)S(/9S<WIE9WKI<W0@860@87H@UFX@<WKA;>%R82!F;VYT;W,@:6YF;W)M
MX6-I\VMR\VPN"B`@4&PN(&IE;&5Z:&5T:2P@:&]G>2!HX6YY(/IJ(&QE=F5L
M92!V86X@87H@24Y"3U@@;6%P<.%B86XL(&UI;'EE;B`*("!E;&9O9VQA;'1S
MX6=A:2!V86YN86L@8F7M<G9A(&$@:_9Z96QJ]G;U8F5N(&$@;F%P=.%R8F%N
M+"!M:6QY96X*("!E;&EN=.EZ96YD]2!D;VQG;VL@=F%N;F%K(&$@9F5L861A
M=&QI<W3A:N%B86XL(&1E(&UE9VIE;&5N[71H973U"B`@96=YZ6(@:_QL<_4@
M<WIO;&?A;'1A=.%S;VL@=&%R=&%L;6$@:7,L('-T8BX@17IE:V+U;"!A>B#V
M<W-Z96=ZZ7-E:V+U;`H@('-O:W-Z;W(@:_9Z=F5T;&5N_&P@:6YD[71H873S
M:R!A(&=Y86MR86X@:&%S>F[A;'0@9G5N:V-I\VLL('!L+@H@(/IJ(&QE=NEL
M(.URX7-A+"#Z:B!B96IE9WEZZ7,@:^ES>NUTZ7-E(&$@;F%P=.%R8F$@=F%G
M>2!A(&9E;&%D871L:7-TX6)A+"`*("!S=&(N"B`@/"]P87)A/@H@/'!A<F$^
M"B`@12!S>F5MZ6QY97,@]G-S>F5G>O4@;VQD86P@=&%R=&%L;>%T(&$@5&5R
M=F5ZZ7,@9V]M8F)A;"!M\V1O<^UT:&%T:F$N"B`@365G861H871J82!P;"XL
M(&AO9WD@;6EL>65N(&EN9F]R;>%C:?-K870@:^UVX6X@;65G:F5L96[M=&5N
M:2P@Z7,*("!M:6QY96X@96QR96YD97KI<V)E;BX*(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](FYA=F)A<B(@<W1A=&4](G5P=&]D871E(B!M9#4]
M(F(X8V8P864Q.64U-V1F83!C,F(Y-C)E-3$V-S@R9C0W(CX*/'1I=&QE/D%Z
M(&%L:V%L;6%ZX7-VX6QA<WIT\R!M96[\/"]T:71L93X*(#QP87)A/@H@($$@
M=V5B;VQD86P@8F%L(&]L9&%LX6X@96=Y(&%L:V%L;6%ZX7-VX6QA<WIT\R!M
M96[\('1A;.%L:&%T\RX*("!!(&UE9V9E;&5L]2!F96QI<F%T;VMR82!K871T
M:6YT=F$@9WEO<G-A;B#I<R!K]FYN>65N(.%T=6=O<FAA="!E9WEI:PH@(&%L
M:V%L;6%ZX7-B\VP@82!MX7-I:V)A+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<')E9G,M9&]?;6%I;G1E;F%N8V4B('-T871E/2)U<'1O9&%T
M92(@;60U/2)D9#DU9&8P-V$P,S`S,3(S,F)A96$Y,3DR.#AB,F0P,"(^"B`@
M("`\=&ET;&4^3W!C:?-K.B!"96IE;&5N=&ME>NES<V5L(&MA<&-S;VQA=&]S
M(&9E;&%D871O:SH@=NEG<F5H86ITX7,\+W1I=&QE/@H@("`@/'!A<F$^"B`@
M("!(82!A>G0@<WIE<F5T;NDL(&AO9WD@8F5J96QE;G1K97KI<VMO<B!F=7-S
M86YA:PH@("`@;&4@82!K87)B86YT87)TX7-I(&9E;&%D871O:RP@:F5L]FQJ
M92!B92!A(&[I9WEZ971E="X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](G!R969S+6-O;F9I<FU?;6%I;G1E;F%N8V4B('-T871E/2)U<'1O
M9&%T92(@;60U/2)A,C$Q-C)C9&9F,V(Q9#AF865A9&(W,CDV,C0P,#,V92(^
M"B`@("`\=&ET;&4^3W!C:?-K.B!"96IE;&5N=&ME>NES<V5L(&MA<&-S;VQA
M=&]S(&9E;&%D871O:SH@;65G97+U<^UTZ7,\+W1I=&QE/@H@("`@/'!A<F$^
M"B`@("!(82!A>G0@<WIE<F5T;NDL(&AO9WD@82!R96YD<WIE<B!M96=E<O5S
M[73I<W0@:^ER:F5N(-9N=/5L(&UI96SU='0*("`@(';I9W)E:&%J=&%NX2!A
M(&MA<F)A;G1A<G3A<VD@9F5L861A=&]K870L(&IE;/9L:F4@8F4@97IT(&$@
M;NEG>7IE=&5T+@H@("`@2&$@;F5M(&IE;/9L:2!B92P@82!K87)B86YT87)T
MX7-I(&9E;&%D871O:R!B96IE;&5N=&ME>NES:V]R(&%U=&]M871I:W5S86X@
M"B`@("!L92!F;V=N86L@9G5T;FDL(&%NZ6QK_&PL(&AO9WD@8F5F;VQYX7-O
M;&AA=&[A(/5K970N"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L<#X*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VIA7TI0````````````````
M````````````````````````````````````````````````````````````
M`````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P
M-3$U-#,S-S0Q(#`Q-S<P,0`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O
M:F%?2E`O3$-?34534T%'15,`````````````````````````````````````
M````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W-#$@,#(Q-#8V`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQO8V%L92]J85]*4"],0U]-15-304=%4R]H;W)D92YM;P``
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#,Q,#$W-R`Q,#4Q-30S,S<T,2`P
M,C,R,30`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````WA($E0````"I!0``'````&0M``"-!P``K%H```````#@>```#@```.%X
M```/````\'@```T`````>0``"`````YY```+````%WD```P````C>0``&```
M`#!Y```;````27D``"T```!E>0``'0```)-Y```D````L7D``"D```#6>0``
M&0````!Z```F````&GH```P```!!>@``)````$YZ```+````<WH```X```!_
M>@``!0```(YZ```H````E'H```@```"]>@``"@```,9Z```5````T7H``!(`
M``#G>@``A0```/IZ```.````@'L```H```"/>P``#0```)I[```.````J'L`
M`!$```"W>P``#0```,E[```,````UWL```T```#D>P``!@```/)[``"4````
M^7L```P```".?```#@```)M\```.````JGP```@```"Y?```"0```,)\```N
M````S'P``!H```#[?```,@```!9]```X````27T``%0```""?0``40```-=]
M``!:````*7X``%<```"$?@``-````-Q^```%````$7\``!$````7?P``)0``
M`"E_```@````3W\``!,```!P?P``$````(1_```/````E7\```H```"E?P``
M`P```+!_```/````M'\``!0```#$?P``"0```-E_```-````XW\``!(```#Q
M?P``&0````2````>````'H````\````]@```"@```$V````/````6(````@`
M``!H@```)````'&````4````EH```!8```"K@```"````,*```!.````RX``
M`"T````:@0``&0```$B!```'````8H$```P```!J@0``+````'>!```.````
MI($```,```"S@0``"P```+>!```'````PX$```<```#+@0``!0```-.!```*
M````V8$```,```#D@0``%P```.B!```*`````((```\````+@@``&````!N"
M```C````-((```X```!8@@``%````&>"```7````?((``!<```"4@@``%P``
M`*R"```3````Q((```\```#8@@``#@```.B"```?````]X(``!T````7@P``
M!P```#6#```&````/8,```@```!$@P``#P```$V#```&````78,```H```!D
M@P``$P```&^#```+````@X,``!````"/@P``%0```*"#```5````MH,```<`
M``#,@P``$````-2#```%````Y8,``!$```#K@P``#````/V#```[````"H0`
M`#@```!&A```"0```'^$```'````B80```4```"1A```$````)>$```3````
MJ(0``#D```"\A```)P```/:$```L````'H4``"H```!+A0``)0```':%```*
M````G(4```8```"GA0``"0```*Z%```'````N(4``"\```#`A0``-P```/"%
M```N````*(8``%4```!7A@``+0```*V&```M````VX8``#T````)AP``/P``
M`$>'```M````AX<``$````"UAP``(P```/:'```C````&H@``$`````^B```
M+0```'^(```S````K8@``"4```#AB```%0````>)```9````'8D``"D````W
MB0``)````&&)```H````AHD``!$```"OB0``"@```,&)```*````S(D``!``
M``#7B0``%@```.B)```6````_XD```<````6B@``!P```!Z*```*````)HH`
M``@````QB@``)P```#J*```(````8HH```<```!KB@``!P```'.*```&````
M>XH```4```""B@``!P```(B*```&````D(H```@```"7B@``*0```*"*```.
M````RHH```H```#9B@``!````.2*```'````Z8H```D```#QB@``!@```/N*
M```1`````HL```<````4BP``%@```!R+```(````,XL```T````\BP``!@``
M`$J+```>````48L``!$```!PBP``"````(*+```-````BXL```P```"9BP``
M!P```*:+```#````KHL```,```"RBP``%P```+:+```3````SHL``!T```#B
MBP``"`````",```(````"8P```@````2C```00```!N,```:````78P``"L`
M``!XC```(````*2,```5````Q8P```8```#;C```!@```.*,```5````Z8P`
M`!@```#_C```(@```!B-```N````.XT``!T```!JC0``(0```(B-``!4````
MJHT``"D```#_C0``"@```"F.```'````-(X```<````\C@``%0```$2.```.
M````6HX```H```!IC@``#P```'2.```-````A(X```\```"2C@``#0```**.
M```)````L(X```8```"ZC@``&````,&.```3````VHX``!$```#NC@``%```
M``"/```$````%8\```8````:CP``%````"&/``!4````-H\``&0```"+CP``
M#@```/"/```%````_X\```4````%D```$P````N0```1````'Y```!$````Q
MD```'````$.0```0````8)```"$```!QD```$P```).0```+````IY```!(`
M``"SD```"@```,:0```/````T9```!$```#AD```#````/.0```7`````)$`
M`!`````8D0``"````"F1```%````,I$```P````XD0``$````$61```%````
M5I$```T```!<D0``!@```&J1```'````<9$```T```!YD0``!P```(>1```+
M````CY$```<```";D0``!P```*.1```9````JY$``#T```#%D0``'0````.2
M```,````(9(``!`````ND@``!0```#^2```E````19(``!(```!KD@``$P``
M`'Z2```K````DI(``#L```"^D@``(````/J2```(````&Y,``#8````DDP``
M(0```%N3```0````?9,```@```".DP``#````)>3```$````I),```\```"I
MDP``#@```+F3```*````R),```T```#3DP``'P```.&3```<`````90``"$`
M```>E```'@```$"4```9````7Y0``!X```!YE```&P```)B4```A````M)0`
M`"X```#6E```)@````65```<````+)4``!X```!)E0``'````&B5```F````
MA94``"L```"LE0``,P```-B5```F````#)8``"L````SE@``.````%^6```=
M````F)8``!4```"VE@``+P```,R6```@````_)8``!(````=EP``*0```#"7
M```>````6I<``"````!YEP``$@```)J7``"B````K9<``!8```!0F```(P``
M`&>8```H````BY@``"D```"TF```*````-Z8```?````!YD``!4````GF0``
M(````#V9```E````7ID``"@```"$F0``+0```*V9```P````VYD``)(````,
MF@``(0```)^:```6````P9H``!P```#8F@``)@```/6:```J````')L``$$`
M``!'FP``!P```(F;```&````D9L``!````"8FP``$@```*F;```3````O)L`
M`!(```#0FP``!P```..;```$````ZYL``!````#PFP``#`````&<```.````
M#IP```T````=G```*````"N<```#````5)P```T```!8G```!@```&:<```.
M````;9P```(```!\G```!0```'^<```0````A9P```\```"6G```!````*:<
M```-````JYP```X```"YG```#@```,B<```(````UYP```\```#@G```#P``
M`/"<```'`````)T```T````(G0``$````!:=```-````)YT```8````UG0``
M"P```#R=```,````2)T```H```!5G0``$0```&"=```+````<IT```T```!^
MG0``(@```(R=```/````KYT``!L```"_G0``-````-N=```*````$)X``!@`
M```;G@``$@```#2>```9````1YX``!8```!AG@``(@```'B>```-````FYX`
M``<```"IG@``%````+&>```+````QIX``"(```#2G@``+P```/6>```+````
M)9\``!<````QGP``%P```$F?```6````89\```\```!XGP``"````(B?```-
M````D9\``"8```"?GP``0P```,:?```(````"J```!(````3H```'P```":@
M```(````1J````L```!/H```+P```%N@```&````BZ````<```"2H```!```
M`)J@```*````GZ````H```"JH```#P```+6@```0````Q:```!<```#6H```
M$0```.Z@```9`````*$``!<````:H0``!0```#*A```+````.*$```4```!$
MH0``#0```$JA```;````6*$``!<```!TH0``#@```(RA```-````FZ$``!(`
M``"IH0``.````+RA```@````]:$```X````6H@``>P```"6B```8````H:(`
M`!$```"ZH@``!P```,RB```%````U*(``!@```#:H@``&P```/.B```9````
M#Z,``!L````IHP``&0```$6C```3````7Z,```<```!SHP``"````'NC```&
M````A*,``!````"+HP``#P```)RC```0````K*,```\```"]HP``"P```,VC
M```/````V:,```P```#IHP``#P```/:C```'````!J0```8````.I```#@``
M`!6D```,````)*0```\````QI```"````$&D```(````2J0``!,```!3I```
M'@```&>D```A````AJ0``"````"HI```&0```,FD```7````XZ0``"4```#[
MI```%P```"&E```6````.:4``!L```!0I0``#0```&RE```,````>J4```,`
M``"'I0``!0```(NE```(````D:4```0```":I0``!````)^E```3````I*4`
M`!0```"XI0``#````,VE```)````VJ4```X```#DI0``"P```/.E```;````
M_Z4```<````;I@``!P```".F```-````*Z8``!@````YI@``"@```%*F```F
M````7:8``!4```"$I@``!0```)JF```&````H*8```(```"GI@``!@```*JF
M```&````L:8``!0```"XI@``#0```,VF```0````VZ8``!L```#LI@``$```
M``BG```)````&:<```D````CIP``!0```"VG```:````,Z<```@```!.IP``
M!@```%>G```9````7J<```X```!XIP``!P```(>G```'````CZ<```4```"7
MIP``"0```)VG```*````IZ<```X```"RIP``"P```,&G```-````S:<```8`
M``#;IP``"0```.*G```'````[*<``!0```#TIP``'0````FH``!"````)Z@`
M`"4```!JJ```)0```)"H```&````MJ@```H```"]J```!````,BH```)````
MS:@```@```#7J```$0```."H```)````\J@```8```#\J```#0````.I```&
M````$:D``!X````8J0``!0```#>I```.````/:D```8```!,J0``!P```%.I
M```A````6ZD```8```!]J0``!````(2I```*````B:D```4```"4J0``'0``
M`)JI```$````N*D```P```"]J0``#@```,JI```*````V:D```@```#DJ0``
M"0```.VI```%````]ZD``#H```#]J0``,````#BJ```U````::H``"D```"?
MJ@``1P```,FJ```X````$:L``"D```!*JP``/P```'2K```N````M*L``"T`
M``#CJP``'P```!&L```/````,:P``"D```!!K```)````&NL```F````D*P`
M``<```"WK```(````+^L```@````X*P``"8````!K0``"@```"BM```9````
M,ZT``"D```!-K0``%@```'>M```'````CJT```H```"6K0``#````*&M```/
M````KJT``!````"^K0``0````,^M``!P````$*X```X```"!K@``"0```)"N
M```*````FJX```8```"EK@``#P```*RN```2````O*X``!````#/K@``'```
M`."N```C````_:X``&H````AKP``#P```(RO```%````G*\``!````"BKP``
M"0```+.O```$````O:\```L```#"KP``%````,ZO```,````XZ\```P```#P
MKP``#P```/VO```5````#;```"D````CL```*@```$VP```F````>+```"<`
M``"?L```*0```,>P```J````\;```!D````<L0``0@```#:Q```1````>;$`
M`!(```"+L0``$P```)ZQ```4````LK$```\```#'L0``%@```->Q```7````
M[K$``!`````&L@``$0```!>R```T````*;(``!,```!>L@``$@```'*R```U
M````A;(``!0```"[L@``$````-"R```4````X;(``!<```#VL@``'`````ZS
M```4````*[,``!H```!`LP``&@```%NS```3````=K,``!4```"*LP``$0``
M`*"S```7````LK,``!0```#*LP``%P```-^S```5````][,``!`````-M```
M&0```!ZT```$````.+0```<````]M```"P```$6T```&````4;0```8```!8
MM```!@```%^T```%````9K0```<```!LM```!P```'2T```%````?+0```8`
M``""M```!@```(FT```$````D+0```0```"5M```!P```)JT```.````HK0`
M``P```"QM```#````+ZT```-````R[0```H```#9M```#@```.2T```%````
M\[0``"@```#YM```#````"*U```/````+[4```H````_M0``"````$JU```K
M````4[4```@```!_M0``)@```(BU```2````K[4```8```#"M0``"@```,FU
M```'````U+4```@```#<M0``(````.6U```,````!K8```X````3M@``%@``
M`"*V```1````.;8```8```!+M@``!@```%*V```'````6;8```0```!AM@``
M!P```&:V```'````;K8``!8```!VM@``#0```(VV```$````F[8``#H```"@
MM@``#@```-NV```0````ZK8```L```#[M@``&P````>W```8````([<``!H`
M```\MP``"0```%>W```*````8;<```P```!LMP``#P```'FW```(````B;<`
M``8```"2MP``!P```)FW```%````H;<```L```"GMP``1P```+.W```-````
M^[<``!,````)N```$P```!VX```3````,;@```H```!%N````@```%"X```E
M````4[@```4```!YN```*@```'^X```*````JK@```0```"UN```!@```+JX
M```(````P;@```@```#*N```!````-.X```%````V+@``&@```#>N```!0``
M`$>Y```0````3;D```H```!>N0``#P```&FY```*````>;D```D```"$N0``
M`P```(ZY```'````DKD```<```":N0``"@```**Y```+````K;D```<```"Y
MN0``40```,&Y```&````$[H``!H````:N@``!@```#6Z```?````/+H```D`
M``!<N@``(@```&:Z``!7````B;H``!,```#AN@``(P```/6Z```3````&;L`
M``(````MNP``"P```#"[```-````/+L``!0```!*NP``!@```%^[```(````
M9KL```<```!ONP``"@```'>[```+````@KL```<```".NP``"0```):[```)
M````H+L```H```"JNP``!P```+6[```)````O;L```<```#'NP``"@```,^[
M```*````VKL``!8```#ENP``!P```/R[```2````!+P```0````7O```!P``
M`!R\```%````)+P```4````JO```"P```#"\```4````/+P```<```!1O```
M!0```%F\```-````7[P```P```!MO```"````'J\```7````@[P```L```";
MO```#````*>\```?````M+P``!H```#4O```!````.^\```*````]+P```0`
M``#_O```#`````2]```%````$;T```D````7O0``!0```"&]```'````)[T`
M``0````OO0``.````#2]```*````;;T``"P```!XO0``+@```*6]```S````
MU+T``#,````(O@``.````#R^```/````=;X``!@```"%O@``$````)Z^```/
M````K[X``!4```"_O@``%````-6^```2````ZKX``!0```#]O@``+0```!*_
M```M````0+\``#$```!NOP``+@```*"_```O````S[\``"P```#_OP``8@``
M`"S````3````C\````T```"CP```%P```+'````,````R<```"$```#6P```
M&@```/C````)````$\$``$4````=P0``00```&/!```$````I<$```X```"J
MP0``$P```+G!```8````S<$```8```#FP0``"0```.W!```*````]\$```\`
M```"P@``$````!+"```.````(\(```4````RP@``"````#C"```&````0<(`
M`!0```!(P@``$0```%W"```.````;\(``#@```!^P@```@```+?"```&````
MNL(```X```#!P@``!P```-#"```&````V,(```P```#?P@``'````.S"```$
M````"<,``"D````.PP``'P```#C#``!<````6,,``!0```"UPP``/@```,K#
M```'````"<0```X````1Q```#````"#$```,````+<0``!,````ZQ```"@``
M`$[$```=````6<0``!$```!WQ```$0```(G$```D````F\0``!4```#`Q```
M$@```-;$```.````Z<0``!D```#XQ```"````!+%```)````&\4``!H````E
MQ0``!P```$#%```(````2,4```4```!1Q0``'P```%?%```&````=\4``!``
M``!^Q0``"````(_%```(````F,4``!X```"AQ0``$@```,#%```L````T\4`
M`!H`````Q@``"0```!O&```*````)<8``!4````PQ@``!0```$;&```4````
M3,8```0```!AQ@``$````&;&```'````=\8``!X```!_Q@``*````)[&```*
M````Q\8``!P```#2Q@``$0```._&```+`````<<``!H````-QP``%````"C'
M```$````/<<```L```!"QP``!0```$['```(````5,<```8```!=QP``(```
M`&3'```I````A<<``$$```"OQP``*````/''```I````&L@``%````!$R```
M!@```)7(```%````G,@```@```"BR```+@```*O(```T````VL@```<````/
MR0``(0```!?)```0````.<D```X```!*R0``"P```%G)```'````9<D``!,`
M``!MR0``"@```(')```4````C,D```\```"AR0``,@```+')```+````Y,D`
M``X```#PR0``!0```/_)```%````!<H```4````+R@``%P```!'*```%````
M*<H```0````OR@``,@```#3*``!%````9\H``!<```"MR@``'@```,7*```4
M````Y,H```8```#YR@``#@````#+```J````#\L```8````ZRP``#````$'+
M```1````3LL```L```!@RP``-@```&S+```*````H\L``"(```"NRP``"P``
M`-'+```/````W<L``#(```#MRP``,````"#,```Q````4<P``"T```"#S```
M!0```+',```.````M\P``!,```#&S```!P```-K,```1````XLP``!,```#T
MS```%`````C-```8````'<T```4````VS0``!````#S-```'````0<T```H`
M``!)S0``"P```%3-```,````8,T```X```!MS0``#@```'S-```%````B\T`
M``4```"1S0``+@```)?-```F````QLT``",```#MS0```P```!'.```2````
M%<X```8````HS@``'@```"_.```8````3LX``"4```!GS@``"0```(W.```#
M````E\X```<```";S@```@```*/.```,````ILX``!4```"SS@``"P```,G.
M```9````U<X``"````#OS@``!0```!#/```*````%L\``!4````ASP``#```
M`#?/```$````1,\```D```!)SP``!P```%//```,````6\\``%(```!HSP``
M%P```+O/```D````T\\```8```#XSP``#@```/_/```,````#M````T````;
MT```%0```"G0```2````/]````\```!2T```%````&+0```*````=]```&D`
M``""T```&@```.S0```7````!]$``"<````?T0``&@```$?1```7````8M$`
M`!L```!ZT0``&0```);1```?````L-$``!,```#0T0``"````.31```'````
M[=$```D```#UT0``%0```/_1```-````%=(```T````CT@``"````#'2``!&
M````.M(``#\```"!T@``-P```,'2``!7````^=(```4```!1TP``'P```%?3
M```*````=],```T```""TP``+0```)#3```$````OM,``$\```##TP``)0``
M`!/4```?````.=0``!T```!9U```)0```'?4```@````G=0``"0```"^U```
M(````./4```&````!-4``#D````+U0``#````$75```'````4M4```D```!:
MU0``$P```&35```)````>-4```0```""U0``$````(?5```(````F-4```@`
M``"AU0``#P```*K5```'````NM4``!0```#"U0``#@```-?5```,````YM4`
M`"P```#SU0``$P```"#6```<````--8``"@```!1U@``!P```'K6```3````
M@M8```4```"6U@``%P```)S6```*````M-8```P```"_U@``"0```,S6```)
M````UM8``!$```#@U@``!@```/+6```.````^=8```T````(UP``"P```!;7
M```"````(M<``!P````EUP``!@```$+7```)````2=<```<```!3UP``)@``
M`%O7```X````@M<``!H```"[UP``*@```-;7```[`````=@``"@````]V```
M-````&;8```9````F]@``!4```"UV```!0```,O8```'````T=@```@```#9
MV```!P```.+8```.````ZM@```D```#YV```!@````/9```(````"MD```L`
M```3V0``!P```!_9```(````)]D```<````PV0``%@```#C9```)````3]D`
M``8```!9V0``"P```&#9```4````;-D```@```"!V0``$````(K9```0````
MF]D```8```"LV0``&0```+/9```*````S=D``!P```#8V0``!0```/79```0
M````^]D``!@````,V@``%P```"7:```)````/=H```H```!'V@``!P```%+:
M```"````6MH```@```!=V@``(P```&;:```?````BMH``#$```"JV@``)P``
M`-S:``!D````!-L``%4```!IVP``.````+_;``!*````^-L``%L```!#W```
M*````)_<```X````R-P``"@````!W0``+````"K=```F````5]T``!L```!^
MW0``/@```)K=``"I`0``V=T``",```"#WP``2````*??```E````\-\``$$`
M```6X```6P```%C@``!)````M.```#$```#^X```*P```##A```A````7.$`
M`!\```!^X0``)@```)[A```G````Q>$``#,```#MX0``)0```"'B```@````
M1^(``!\```!HX@``,````(CB``!I````N>(``#$````CXP``00```%7C```S
M````E^,``"4```#+XP``/0```/'C``!E````+^0``$T```"5Y```+P```./D
M```N````$^4``#````!"Y0``5````'/E``!:````R.4``$@````CY@``2@``
M`&SF```R````M^8``"\```#JY@``+````!KG```M````1^<``!<```!UYP``
M)0```(WG```R````L^<``"D```#FYP``/@```!#H```B````3^@``%(```!R
MZ```)0```,7H``!%````Z^@``"$````QZ0``,````%/I```E````A.D``!P`
M``"JZ0``,0```,?I```$````^>D```T```#^Z0``"P````SJ```+````&.H`
M``4````DZ@``60```"KJ```2````A.H```0```"7Z@``!P```)SJ```%````
MI.H``#````"JZ@``$P```-OJ```"````[^H```<```#RZ@``!@```/KJ```,
M`````>L``!@````.ZP``!@```"?K```2````+NL```,```!!ZP``!@```$7K
M```'````3.L``!\```!4ZP``+@```'3K```O````H^L``!<```#3ZP``(@``
M`.OK```E````#NP``"`````T[```&P```%7L```8````<>P``"0```"*[```
M'P```*_L```:````S^P``"$```#J[```(`````SM```:````+>T``#(```!(
M[0``&@```'OM```O````ENT``"L```#&[0``'P```/+M```C````$NX``!\`
M```V[@``&@```%;N```A````<>X``"4```"3[@``)@```+GN```E````X.X`
M`"0````&[P``&````"OO```=````1.\``"0```!B[P``&````(?O```B````
MH.\``"P```##[P``+P```/#O```5````(/```"4````V\```/````%SP```?
M````F?```",```"Y\```'P```-WP```@````_?```!H````>\0``)@```#GQ
M```>````8/$``"D```!_\0``'@```*GQ```Q````R/$```D```#Z\0``#```
M``3R```7````$?(``"\````I\@``)````%GR```'````?O(``!0```"&\@``
M#@```)OR```-````JO(``"0```"X\@``!P```-WR```=````Y?(```<````#
M\P``QP````OS```5````T_,```8```#I\P``"0```/#S```+````^O,```T`
M```&]```%P```!3T```&````+/0``#,````S]```$P```&?T```3````>_0`
M``<```"/]```#P```)?T```'````I_0``#(```"O]```!````.+T```A````
MY_0``!,````)]0``#````!WU```1````*O4``#(````\]0``%@```&_U```(
M````AO4``!T```"/]0``"0```*WU```*````M_4``!0```#"]0``"@```-?U
M```(````XO4```@```#K]0``!P```/3U```)````_/4``#\````&]@``!P``
M`$;V```/````3O8```X```!>]@``"````&WV```'````=O8``!D```!^]@``
M%P```)CV```4````L/8``!$```#%]@``!P```-?V```"````W_8```8```#B
M]@``!P```.GV```-````\?8```L```#_]@``#@````OW```O````&O<``"``
M``!*]P``'````&OW```Q````B/<```4```"Z]P``/P```,#W```2`````/@`
M``H````3^```!@```![X```(````)?@```P````N^```"@```#OX```Y````
M1O@``"X```"`^```*0```*_X```8````V?@``!D```#R^```'P````SY```=
M````+/D``!$```!*^0```@```%SY```$````7_D```8```!D^0``!0```&OY
M```#````<?D```P```!U^0``10```(+Y```R````R/D``!H```#[^0``-```
M`!;Z```H````2_H``%,```!T^@``&0```,CZ``!R````XOH``"````!5^P``
M-0```';[```A````K/L``$4```#.^P``,````!3\```H````1?P``"D```!N
M_```)@```)C\```E````O_P``"@```#E_```*`````[]```B````-_T``#``
M``!:_0``$@```(O]```3````GOT``!````"R_0``>0```,/]```)````/?X`
M`*$```!'_@``<P```.G^``!\````7?\``"L```#:_P``5`````8``0`7````
M6P`!`"<```!S``$`%@```)L``0`/````L@`!`!<```#"``$`'P```-H``0!`
M````^@`!`!\````[`0$`'````%L!`0!1````>`$!`!H```#*`0$`%````.4!
M`0`*````^@$!``4````%`@$`!@````L"`0`(````$@(!`!`````;`@$`#P``
M`"P"`0`/````/`(!``L```!,`@$`!P```%@"`0`%````8`(!`!0```!F`@$`
M!P```'L"`0`(````@P(!``\```",`@$`"````)P"`0`,````I0(!``\```"R
M`@$`!@```,("`0`4````R0(!``8```#>`@$`#````.4"`0`1````\@(!``@`
M```$`P$`&0````T#`0`1````)P,!``H````Y`P$`&````$0#`0`3````70,!
M`!P```!Q`P$`$0```(X#`0`$````H`,!``\```"E`P$`!````+4#`0`1````
MN@,!`!(```#,`P$`%P```-\#`0`$````]P,!``\```#\`P$`$P````P$`0`'
M````(`0!``<````H!`$`$0```#`$`0`&````0@0!`!@```!)!`$`$P```&($
M`0`0````=@0!``P```"'!`$`"0```)0$`0`1````G@0!`"(```"P!`$`!P``
M`-,$`0`%````VP0!`#H!``#A!`$`"@```!P&`0`/````)P8!``\````W!@$`
M!P```$<&`0`(````3P8!``<```!8!@$`)0```&`&`0`A````A@8!`"T```"H
M!@$`)0```-8&`0`I````_`8!`"H````F!P$`(````%$'`0`J````<@<!``L`
M``"=!P$`(````*D'`0`)````R@<!``L```#4!P$`!0```.`'`0`1````Y@<!
M``D```#X!P$`#P````((`0`+````$@@!`!4````>"`$`:P```#0(`0`-````
MH`@!``4```"N"`$`$0```+0(`0`3````Q@@!``\```#:"`$`"P```.H(`0`+
M````]@@!`!$````""0$`!@```!0)`0"2````&PD!``H```"N"0$`"@```+D)
M`0`*````Q`D!``<```#/"0$`"P```-<)`0`H````XPD!`!P````,"@$`*0``
M`"D*`0`Q````4PH!`$H```"%"@$`1````-`*`0!0````%0L!`$H```!F"P$`
M+````+$+`0`%````W@L!`!8```#D"P$`+P```/L+`0`K````*PP!``X```!7
M#`$`%@```&8,`0`>````?0P!``H```"<#`$`!````*<,`0`2````K`P!`!0`
M``"_#`$`"P```-0,`0`4````X`P!`!@```#U#`$`&@````X-`0`<````*0T!
M`!(```!&#0$`"````%D-`0`2````8@T!``H```!U#0$`+````(`-`0`1````
MK0T!`!8```"_#0$`#````-8-`0!.````XPT!`#8````R#@$`)@```&D.`0`$
M````D`X!``H```"5#@$`'0```*`.`0`$````O@X!``,```###@$`#@```,<.
M`0`*````U@X!``P```#A#@$`!````.X.`0`*````\PX!``0```#^#@$`#```
M``,/`0`.````$`\!`!`````?#P$`%````#`/`0`J````10\!``X```!P#P$`
M%````'\/`0`6````E`\!`!0```"K#P$`%````,`/`0`2````U0\!``X```#H
M#P$`$````/</`0`:````"!`!`!X````C$`$`"````$(0`0`.````2Q`!``H`
M``!:$`$`#@```&40`0`$````=!`!``P```!Y$`$`&````(80`0`0````GQ`!
M`!0```"P$`$`%@```,40`0`0````W!`!``0```#M$`$`$````/(0`0`$````
M`Q$!`!@````($0$`#````"$1`0`Q````+A$!`#,```!@$0$`$@```)01`0`0
M````IQ$!``8```"X$0$`#@```+\1`0`2````SA$!`"X```#A$0$`*@```!`2
M`0`L````.Q(!`"P```!H$@$`)@```)42`0`$````O!(!``0```#!$@$`#@``
M`,82`0`2````U1(!`#$```#H$@$`-@```!H3`0`N````41,!`&H```"`$P$`
M*0```.L3`0`I````%10!`$(````_%`$`0@```((4`0`I````Q10!`#4```#O
M%`$`)0```"45`0`E````2Q4!`$(```!Q%0$`*0```+05`0`O````WA4!`"(`
M```.%@$`$@```#$6`0`6````1!8!`"@```!;%@$`'P```(06`0`?````I!8!
M`!8```#$%@$`%@```-L6`0`$````\A8!``8```#W%@$`(````/X6`0`>````
M'Q<!``8````^%P$`"@```$47`0`8````4!<!``H```!I%P$`-````'07`0`&
M````J1<!`!````"P%P$`"````,$7`0`(````RA<!``P```#3%P$`$@```.`7
M`0`,````\Q<!``8`````&`$`-`````<8`0`,````/!@!``X```!)&`$`!```
M`%@8`0`.````71@!``P```!L&`$``@```'D8`0`*````?!@!``(```"'&`$`
M&````(H8`0`.````HQ@!``@```"R&`$`"````+L8`0`.````Q!@!`!8```#3
M&`$`"@```.H8`0`(````]1@!``X```#^&`$`#@````T9`0`#````'!D!``,`
M```@&0$`$````"09`0`-````-1D!`"@```!#&0$`!@```&P9`0`*````<QD!
M`!````!^&0$`0````(\9`0`<````T!D!`"P```#M&0$`)0```!H:`0`<````
M0!H!``8```!=&@$`"@```&0:`0`8````;QH!`"````"(&@$`(@```*D:`0`O
M````S!H!`"8```#\&@$`)@```",;`0!(````2AL!`#(```"3&P$`$@```,8;
M`0`$````V1L!``@```#>&P$`#````.<;`0`,````]!L!``@````!'`$`"```
M``H<`0`*````$QP!``@````>'`$`"@```"<<`0`(````,AP!``0````['`$`
M$@```$`<`0`,````4QP!``X```!@'`$`#@```&\<`0`,````?AP!``0```"+
M'`$`$````)`<`0`P````H1P!`$X```#2'`$`%0```"$=`0`*````-QT!``X`
M``!"'0$`%@```%$=`0`0````:!T!``X```!Y'0$`#@```(@=`0`,````EQT!
M`"````"D'0$`&0```,4=`0`(````WQT!`!````#H'0$`"@```/D=`0`0````
M!!X!`!(````5'@$`$@```"@>`0`*````.QX!`!````!&'@$`$````%<>`0`"
M````:!X!``8```!K'@$`!@```'(>`0`$````>1X!``H```!^'@$`"@```(D>
M`0`(````E!X!``X```"='@$`"````*P>`0`&````M1X!``H```"\'@$`!```
M`,<>`0`*````S!X!`#(```#7'@$`&`````H?`0`-````(Q\!`!`````Q'P$`
M#````$(?`0`0````3Q\!``H```!@'P$`"@```&L?`0`F````=A\!`#,```"=
M'P$`(0```-$?`0`&````\Q\!`"0```#Z'P$`(````!\@`0`+````0"`!``0`
M``!,(`$`"@```%$@`0`&````7"`!``X```!C(`$`$````'(@`0`0````@R`!
M`!8```"4(`$`*P```*L@`0`I````UR`!`"X````!(0$`+````#`A`0`@````
M72$!`"<```!^(0$`'@```*8A`0`C````Q2$!`"P```#I(0$`)@```!8B`0`E
M````/2(!`"D```!C(@$`(````(TB`0`F````KB(!`#(```#5(@$`,@````@C
M`0`J````.R,!`"P```!F(P$`+````),C`0`L````P",!`!L```#M(P$`*@``
M``DD`0`M````-"0!`!\```!B)`$`*@```((D`0`H````K20!`!T```#6)`$`
M%0```/0D`0",````"B4!`!H```"7)0$`)````+(E`0`F````UR4!`"8```#^
M)0$`)@```"4F`0`<````3"8!`"4```!I)@$`'P```(\F`0`J````KR8!`"P`
M``#:)@$`-`````<G`0`V````/"<!`'T```!S)P$`'0```/$G`0`E````#R@!
M`"`````U*`$`)@```%8H`0`?````?2@!`$````"=*`$``@```-XH`0`$````
MX2@!``@```#F*`$`$@```.\H`0`2`````BD!`!0````5*0$`$````"HI`0`.
M````.RD!`!````!**0$`"@```%LI`0`-````9BD!``X```!T*0$`+P```(,I
M`0`(````LRD!`!(```"\*0$`#@```,\I`0`,````WBD!``(```#K*0$`!```
M`.XI`0`-````\RD!`!`````!*@$`!````!(J`0`*````%RH!``@````B*@$`
M"@```"LJ`0`$````-BH!``8````[*@$`#````$(J`0`*````3RH!``P```!:
M*@$`#0```&<J`0`0````=2H!``0```"&*@$`"````(LJ`0`.````E"H!``H`
M``"C*@$`$````*XJ`0`(````ORH!``@```#(*@$`%@```-$J`0`0````Z"H!
M`!<```#Y*@$`.0```!$K`0`(````2RL!`!````!4*P$`$@```&4K`0`2````
M>"L!`!(```"+*P$`*@```)XK`0`(````R2L!``H```#2*P$`#@```-TK`0`$
M````["L!`",```#Q*P$`)````!4L`0`$````.BP!``H````_+`$`"@```$HL
M`0`*````52P!``X```!@+`$`#````&\L`0`*````?"P!`"X```"'+`$`1@``
M`+8L`0`(````_2P!``X````&+0$`(@```!4M`0`,````."T!`!$```!%+0$`
M.0```%<M`0`*````D2T!`!````"<+0$`!````*TM`0`.````LBT!``X```#!
M+0$`$````-`M`0`0````X2T!`!4```#R+0$`$@````@N`0`7````&RX!`!4`
M```S+@$`%@```$DN`0`4````8"X!``H```!U+@$`#P```(`N`0`K````D"X!
M`!,```"\+@$`$@```-`N`0`4````XRX!``H```#X+@$`+@````,O`0`D````
M,B\!`!8```!7+P$`6@```&XO`0`/````R2\!`!````#9+P$`"@```.HO`0`&
M````]2\!`!<```#\+P$`&0```!0P`0`3````+C`!`!D```!",`$`'````%PP
M`0`;````>3`!`!````"5,`$`"@```*8P`0`*````L3`!``8```"\,`$`!0``
M`,,P`0`&````R3`!``4```#0,`$`"@```-8P`0`&````X3`!``4```#H,`$`
M"@```.XP`0`$````^3`!``0```#^,`$`$`````,Q`0`*````%#$!``@````?
M,0$`!````"@Q`0`&````+3$!`!T````T,0$`)````%(Q`0`C````=S$!`"(`
M``";,0$`(0```+XQ`0`?````X#$!`"``````,@$`'0```"$R`0`6````/S(!
M`"0```!6,@$`#````'LR`0`.````B#(!``,```"7,@$``P```)LR`0`$````
MGS(!`!(```"D,@$`"````+<R`0`7````P#(!`!<```#8,@$`$@```/`R`0`*
M`````S,!``P````.,P$`%````!LS`0`N````,#,!``@```!?,P$`$@```&@S
M`0`(````>S,!`!H```"$,P$`!@```)\S`0`>````IC,!`"(```#%,P$`"```
M`.@S`0`*````\3,!``(```#\,P$``@```/\S`0`.`````C0!`!`````1-`$`
M$````"(T`0`4````,S0!`!(```!(-`$`"@```%LT`0`$````9C0!``0```!K
M-`$`#````'`T`0`8````?30!``P```"6-`$`#@```*,T`0`5````LC0!`!``
M``#(-`$`#@```-DT`0`0````Z#0!``P```#Y-`$`#`````8U`0`"````$S4!
M``X````6-0$`#0```"4U`0`+````,S4!``X````_-0$`#@```$XU`0`(````
M734!``P```!F-0$`'````',U`0`X````D#4!`"@```#)-0$`*````/(U`0`(
M````&S8!``X````D-@$`"````#,V`0`0````/#8!``P```!--@$`$````%HV
M`0`,````:S8!``P```!X-@$`$@```(4V`0`2````F#8!`!L```"K-@$`#```
M`,<V`0`4````U#8!``8```#I-@$`!@```/`V`0`8````]S8!``0````0-P$`
M!@```!4W`0`$````'#<!``8````A-P$`'````"@W`0`&````13<!``H```!,
M-P$`%````%<W`0`.````;#<!`!(```![-P$`!````(XW`0`%````DS<!`$(`
M``"9-P$`/0```-PW`0`]````&C@!`"4```!8.`$`*0```'XX`0`Z````J#@!
M`"D```#C.`$`*P````TY`0`I````.3D!`!\```!C.0$`(@```(,Y`0`&````
MICD!`!H```"M.0$`(@```,@Y`0`:````ZSD!`!`````&.@$`*P```!<Z`0`K
M````0SH!`#,```!O.@$`"P```*,Z`0`9````KSH!`#(```#).@$`$````/PZ
M`0`2````#3L!``P````@.P$`#0```"T[`0`2````.SL!``@```!..P$`10``
M`%<[`0!9````G3L!``X```#W.P$`"`````8\`0`)````#SP!``0````9/`$`
M%P```!X\`0`?````-CP!`!P```!6/`$`+````',\`0`H````H#P!`%0```#)
M/`$`#````!X]`0`&````*ST!``H````R/0$`$@```#T]`0`$````4#T!`!(`
M``!5/0$`$````&@]`0`*````>3T!``@```"$/0$`#````(T]`0`.````FCT!
M`!@```"I/0$`%@```,(]`0`8````V3T!`!8```#R/0$`&@````D^`0`8````
M)#X!`!8````]/@$`,````%0^`0`0````A3X!``X```"6/@$`#@```*4^`0`.
M````M#X!`!````##/@$`$````-0^`0`.````Y3X!``X```#T/@$`#`````,_
M`0`>````$#\!`!`````O/P$`$@```$`_`0`H````4S\!`!````!\/P$`%P``
M`(T_`0`<````I3\!`!T```#"/P$`'````.`_`0`:````_3\!`!P````80`$`
M'````#5``0`8````4D`!`!8```!K0`$`%@```()``0`6````F4`!`!8```"P
M0`$`&@```,=``0`9````XD`!``H```#\0`$`%@````=!`0`,````'D$!``P`
M```K00$`!@```#A!`0`*````/T$!``8```!*00$`!````%%!`0`.````5D$!
M``H```!E00$`!````'!!`0`$````=4$!``P```!Z00$`"````(=!`0`$````
MD$$!``0```"500$`!@```)I!`0`(````H4$!``@```"J00$`!@```+-!`0`&
M````ND$!`!(```#!00$`$@```-1!`0`,````YT$!`",```#T00$`"````!A"
M`0`&````(4(!``0````H0@$`!@```"U"`0`H````-$(!``X```!=0@$`%@``
M`&Q"`0`(````@T(!``H```",0@$`#@```)="`0`,````ID(!``0```"S0@$`
M%````+A"`0`(````S4(!`!(```#60@$`'@```.E"`0`4````"$,!``X````=
M0P$`!````"Q#`0`.````,4,!``(```!`0P$`"@```$-#`0`.````3D,!`"P`
M``!=0P$`%@```(I#`0`&````H4,!`"@```"H0P$`$````-%#`0`4````XD,!
M``@```#W0P$`'@````!$`0`:````'T0!`"0````Z1`$`$````%]$`0`+````
M<$0!``H```!\1`$`"@```(=$`0`$````DD0!``@```"71`$`"@```*!$`0`(
M````JT0!``\```"T1`$`/@```,1$`0`8`````T4!`!8````<10$`%````#-%
M`0`4````2$4!`!0```!=10$``@```')%`0`M````=44!``8```"C10$`(```
M`*I%`0`2````RT4!``H```#>10$`#@```.E%`0`*````^$4!`!`````#1@$`
M"@```!1&`0`,````'T8!`#`````L1@$`!````%U&`0`4````8D8!``X```!W
M1@$`'````(9&`0`<````HT8!`!(```#`1@$`!````--&`0`,````V$8!``8`
M``#E1@$`#@```.Q&`0`(````^T8!``0````$1P$`0@````E'`0`(````3$<!
M`"````!51P$`#@```'9'`0`0````A4<!``D```"61P$`,0```*!'`0!8````
MTD<!`"`````K2`$`*0```$Q(`0`@````=D@!``(```"72`$`"@```)I(`0`&
M````I4@!``X```"L2`$`"@```+M(`0`(````QD@!``0```#/2`$`#@```-1(
M`0`$````XT@!``P```#H2`$`!````/5(`0`$````^D@!``0```#_2`$`!```
M``1)`0`$````"4D!``0````.20$`$@```!-)`0`*````)DD!``X````Q20$`
M#@```$!)`0`,````3TD!``0```!<20$`#@```&%)`0`,````<$D!``P```!]
M20$`#````(I)`0`8````ETD!``P```"P20$`!````+U)`0`:````PDD!``@`
M``#=20$`!````.9)`0`4````ZTD!`!``````2@$`$````!%*`0`L````(DH!
M`"````!/2@$`"````'!*`0`0````>4H!``(```"*2@$`#@```(U*`0`+````
MG$H!`!````"H2@$`$````+E*`0`6````RDH!``@```#A2@$`)@```.I*`0`*
M````$4L!`#(````<2P$`(P```$]+`0`H````<TL!`"@```"<2P$`+````,5+
M`0`2````\DL!`!P````%3`$`)````"),`0`6````1TP!`!H```!>3`$`(```
M`'E,`0`:````FDP!`!H```"U3`$`(P```-!,`0`C````]$P!`"<````830$`
M)P```$!-`0`E````:$T!`"@```".30$`70```+=-`0`8````%4X!`!X````N
M3@$`(````$U.`0`0````;DX!`"H```!_3@$`&P```*I.`0`&````QDX!`$8`
M``#-3@$`1@```!1/`0`$````6T\!``X```!@3P$`!@```&]/`0`.````=D\!
M``X```"%3P$`"@```)1/`0`*````GT\!`!H```"J3P$`%````,5/`0`8````
MVD\!``0```#S3P$`!````/A/`0`"````_4\!``8`````4`$`!`````=0`0`$
M````#%`!`#0````14`$``@```$90`0`,````25`!`!(```!64`$`!````&E0
M`0`(````;E`!``X```!W4`$`(````(90`0`(````IU`!`#(```"P4`$`*0``
M`.-0`0!"````#5$!`!0```!040$`20```&51`0`*````KU$!``T```"Z40$`
M#@```,A1`0`$````UU$!``0```#<40$`!````.%1`0`@````YE$!`!8````'
M4@$`$@```!Y2`0`:````,5(!``P```!,4@$`"@```%E2`0`*````9%(!`!<`
M``!O4@$`"0```(=2`0`)````D5(!`!H```";4@$`!````+92`0`:````NU(!
M``P```#64@$`$````.-2`0`,````]%(!`!@````!4P$`$````!I3`0`*````
M*U,!`"(````V4P$`'````%E3`0`C````=E,!`!````":4P$`"P```*M3`0`,
M````MU,!`!H```#$4P$`"````-]3`0`:````Z%,!``0````#5`$`%@````A4
M`0`*````'U0!`!(````J5`$`)````#U4`0`*````8E0!`"@```!M5`$`&```
M`)94`0`*````KU0!`!````"Z5`$`"````,M4`0`,````U%0!`!````#A5`$`
M!````/)4`0`,````]U0!``@````$50$`&@````U5`0`A````*%4!`#X```!*
M50$`(@```(E5`0`H````K%4!`%@```#550$`$````"Y6`0`&````/U8!`!``
M``!&5@$`,````%=6`0`S````B%8!``H```"\5@$`'````,=6`0`.````Y%8!
M``0```#S5@$`!@```/A6`0`$````_U8!``X````$5P$`!@```!-7`0`2````
M&E<!``H````M5P$`)0```#A7`0`,````7E<!`!(```!K5P$`"````'Y7`0`(
M````AU<!``@```"05P$`$P```)E7`0`"````K5<!``0```"P5P$`-````+57
M`0!#````ZE<!`!0````N6`$`&0```$-8`0`0````75@!``@```!N6`$`$```
M`'=8`0`L````B%@!``0```"U6`$`#@```+I8`0`*````R5@!``H```#46`$`
M,@```-]8`0`&````$ED!`"`````960$`#````#I9`0`0````1UD!`!8```!8
M60$`,@```&]9`0`Q````HED!`"P```#460$`"`````%:`0`4````"EH!`!P`
M```?6@$`!````#Q:`0`0````05H!`!(```!26@$`#@```&5:`0`>````=%H!
M``(```"36@$`!````)9:`0`*````FUH!``D```"F6@$`"````+!:`0`(````
MN5H!``8```#"6@$`!@```,E:`0`$````T%H!``0```#56@$`'````-I:`0`2
M````]UH!`!(````*6P$`!````!U;`0`*````(EL!``@````M6P$`#P```#9;
M`0`-````1EL!`!L```!46P$`"@```'!;`0`#````>UL!``0```!_6P$``@``
M`(1;`0`.````AUL!`!@```"66P$`#````*];`0`8````O%L!`"@```#56P$`
M#````/Y;`0`0````"UP!`!X````<7`$`$@```#M<`0`$````3EP!``L```!3
M7`$`"0```%]<`0`0````:5P!`$D```!Z7`$`%P```,1<`0`J````W%P!``0`
M```'70$`#`````Q=`0`.````&5T!`!@````H70$`(@```$%=`0`>````9%T!
M`!@```"#70$`(````)Q=`0`(````O5T!`%(```#&70$`)````!E>`0`>````
M/EX!`!,```!=7@$`)````'%>`0`>````EEX!`"H```"U7@$`%P```.!>`0`7
M````^%X!`!8````07P$`"````"=?`0`.````,%\!``0````_7P$`%@```$1?
M`0`$````6U\!``X```!@7P$`"@```&]?`0`V````>E\!`#(```"Q7P$`(```
M`.1?`0!7````!6`!``0```!=8`$`$@```&)@`0`0````=6`!``P```"&8`$`
M/````)-@`0`$````T&`!`#0```#58`$`+@````IA`0`>````.6$!`"0```!8
M80$`'````'UA`0`6````FF$!`!H```"Q80$`&@```,QA`0`$````YV$!`#(`
M``#L80$`$@```!]B`0`,````,F(!``@````_8@$`%````$AB`0`2````76(!
M``8```!P8@$`$@```'=B`0`0````BF(!`!````";8@$`#````*QB`0`2````
MN6(!``P```#,8@$`#@```-EB`0`0````Z&(!`"(```#Y8@$`!@```!QC`0`0
M````(V,!`!(````T8P$`!````$=C`0`*````3&,!``@```!78P$`#@```&!C
M`0`(````;V,!``8```!X8P$`!@```']C`0`<````AF,!``H```"C8P$`!```
M`*YC`0`(````LV,!``@```"\8P$`#@```,5C`0`"````U&,!`"0```#78P$`
M!````/QC`0`&`````60!``0````(9`$`(0````UD`0`C````+V0!`!<```!3
M9`$`(P```&MD`0`T````CV0!`"H```#$9`$`-@```.]D`0`;````)F4!`!L`
M``!"90$`#@```%YE`0`$````;64!``8```!R90$`"````'EE`0`/````@F4!
M``@```"290$`!````)ME`0`&````H&4!``8```"G90$`"````*YE`0`.````
MMV4!``(```#&90$`(````,EE`0`0````ZF4!`!````#[90$`"@````QF`0`4
M````%V8!``L````L9@$`!@```#AF`0`&````/V8!``0```!&9@$`$@```$MF
M`0`2````7F8!`!0```!Q9@$`!@```(9F`0`(````C68!`"````"69@$`$@``
M`+=F`0`,````RF8!``@```#79@$`"````.!F`0`"````Z68!``@```#L9@$`
M%@```/5F`0`B````#&<!`#(````O9P$`+@```&)G`0!,````D6<!`%P```#>
M9P$`+````#MH`0`\````:&@!`%P```"E:`$`)`````)I`0`F````)VD!`"8`
M``!.:0$`)@```'5I`0`F````G&D!`"(```##:0$`+````.9I`0#C````$VH!
M`!H```#W:@$`1P```!)K`0`J````6FL!`#@```"%:P$`1P```+YK`0!*````
M!FP!`"0```!1;`$`)@```'9L`0`>````G6P!`!X```"\;`$`'@```-ML`0`@
M````^FP!`#(````;;0$`*@```$YM`0`H````>6T!`"(```"B;0$`)@```,5M
M`0!>````[&T!`"\```!+;@$`/0```'MN`0`N````N6X!`"4```#H;@$`2P``
M``YO`0!?````6F\!`$\```"Z;P$`*`````IP`0`R````,W`!`"\```!F<`$`
M3````)9P`0!.````XW`!`$8````R<0$`1@```'EQ`0`V````P'$!`"T```#W
M<0$`*P```"5R`0`H````47(!`!H```!Z<@$`*@```)5R`0`R````P'(!`"L`
M``#S<@$`3@```!]S`0`J````;G,!`$8```"9<P$`)````.!S`0!,````!70!
M`"D```!2=`$`,0```'QT`0`J````KG0!`"(```#9=`$`0@```/QT`0`$````
M/W4!``P```!$=0$`"````%%U`0`6````6G4!``@```!Q=0$`6P```'IU`0`2
M````UG4!``P```#I=0$`#````/9U`0`*`````W8!`"P````.=@$`&@```#MV
M`0`"````5G8!`!````!9=@$`#````&IV`0`0````=W8!`!8```"(=@$`!@``
M`)]V`0`&````IG8!``,```"M=@$`#@```+%V`0`*````P'8!`"8```#+=@$`
M,````/)V`0`Q````(W<!`!4```!5=P$`*@```&MW`0`O````EG<!`!P```#&
M=P$`%@```.-W`0`@````^G<!`"@````;>`$`(@```$1X`0`>````9W@!`"@`
M``"&>`$`(P```*]X`0`8````TW@!`#8```#L>`$`&0```"-Y`0`T````/7D!
M`"H```!R>0$`(@```)UY`0`D````P'D!`"0```#E>0$`'@````IZ`0`H````
M*7H!`"````!2>@$`)@```'-Z`0`<````FGH!`!T```"W>@$`'@```-5Z`0`@
M````]'H!`"8````5>P$`&@```#Q[`0`>````5WL!`"\```!V>P$`,@```*9[
M`0`:````V7L!`"(```#T>P$`.@```!=\`0`J````4GP!`"P```!]?`$`*@``
M`*I\`0`K````U7P!`"0````!?0$`(````"9]`0`@````1WT!`"@```!H?0$`
M&@```)%]`0`T````K'T!``0```#A?0$`#@```.9]`0`4````]7T!`"8````*
M?@$`'@```#%^`0`&````4'X!`!````!7?@$`!````&A^`0`$````;7X!``X`
M``!R?@$`!````(%^`0`@````AGX!``0```"G?@$`O````*Q^`0`<````:7\!
M``0```"&?P$`#P```(M_`0`0````FW\!`!4```"L?P$`'@```,)_`0`,````
MX7\!`$0```#N?P$`%````#.``0`4````2(`!`!0```!=@`$`$@```'*``0`*
M````A8`!`#L```"0@`$`!@```,R``0`F````TX`!``H```#Z@`$`$`````6!
M`0`*````%H$!`"X````A@0$`(@```%"!`0`(````<X$!`!X```!\@0$`"0``
M`)N!`0`*````I8$!`!0```"P@0$`%````,6!`0`$````VH$!``8```#?@0$`
M#@```.:!`0`:````]8$!`#,````0@@$``@```$2"`0`.````1X(!``8```!6
M@@$`%@```%V"`0`)````=((!`!<```!^@@$`$````):"`0`0````IX(!`!@`
M``"X@@$`!````-&"`0`"````UH(!``0```#9@@$`"````-Z"`0`-````YX(!
M`!$```#U@@$`"`````>#`0`P````$(,!`!8```!!@P$`%````%B#`0`L````
M;8,!``(```":@P$`,0```)V#`0`&````SX,!``@```#6@P$`!````-^#`0`.
M````Y(,!``P```#S@P$`$`````"$`0`Y````$80!`#````!+A`$`/P```'R$
M`0`/````O(0!``\```#,A`$`$P```-R$`0`7````\(0!``\````(A0$``@``
M`!B%`0`"````&X4!``0````>A0$`#@```".%`0`$````,H4!``H````WA0$`
M/0```$*%`0`U````@(4!`!P```"VA0$`)P```-.%`0`H````^X4!`%$````D
MA@$`$P```':&`0!H````BH8!`!H```#SA@$`3@````Z'`0`J````78<!`#H`
M``"(AP$`(P```,.'`0`B````YX<!`"0````*B`$`)````"^(`0`D````5(@!
M`"0```!YB`$`)@```)Z(`0`>````Q8@!`$$```#DB`$`$@```":)`0`7````
M.8D!`!H```!1B0$`:````&R)`0`,````U8D!`)4```#BB0$`=@```'B*`0!N
M````[XH!`#(```!>BP$`8@```)&+`0`.````](L!`"8````#C`$`%0```"J,
M`0`,````0(P!`!@```!-C`$`'````&:,`0`X````@XP!`!@```"\C`$`(```
M`-6,`0!.````]HP!`!H```!%C0$`#P```&"-`0`.````<(T!`"(```!_C0$`
M#@```**-`0`0````L8T!``P```#"C0$`"@```,^-`0`&````VHT!``H```#A
MC0$`"@```.R-`0`(````]XT!`!,`````C@$`"@```!2.`0`,````'XX!``P`
M```LC@$`#````#F.`0`,````1HX!``P```!3C@$`#@```&".`0`(````;XX!
M``@```!XC@$`"@```(&.`0`.````C(X!``8```";C@$`'````**.`0`8````
MOXX!``X```#8C@$`%@```.>.`0`*````_HX!`!P````)CP$`$````":/`0`$
M````-X\!`!`````\CP$`"````$V/`0`.````5H\!``P```!ECP$`&````'*/
M`0`$````BX\!`!(```"0CP$`%@```*./`0`&````NH\!``H```#!CP$`&```
M`,R/`0`(````Y8\!`!P```#NCP$`#`````N0`0`*````&)`!``X````CD`$`
M#````#*0`0`.````/Y`!`"4```!.D`$`!````'20`0`%````>9`!``$```"V
M`0``4@`````````*`0``-0$``,@#``#D````)0$``````````````````/<"
M``#8!```[P0``+P!````````XP$``.X#````````'@```,$!```O!```D0``
M``\"````````0`(``*<#```Y!0``[@0``)P%```4```````````````J`P``
M`````#4```"/!````````%$$```4`0``S0(``'<"``!:!````````(4!````
M````I`$``+D$``!]!0``````````````````>@0```````"``P``V0(`````
M````````[`0``.X!```4`@``M0$``!H#``#^!````P(``)P$``#U````^P,`
M`"<"``"P````=P$``%4$``!T!0``P@```'\$```Q`@``R````/L"``!K````
M`@$```````"\````E00``````````````````(T"```%`0``(````+8#``!L
M`P``"P,``$\%``##`0``^@$```````!6`P``P0,``+L$````````?@(```8`
M``#*`@````````````"$`@``"P(``/H"``!,!```,@````````#/!```80$`
M`,8```!&`````````"D"``#W`````````-8#````````W@(``*H```"&!0``
MM@```*0#```Z`P``/`0```````"?````F0(```````!'!````````*(`````
M````;P(``)D!``"@!0``3@0``$@%```````````````````%!0```````#4"
M``#X`P``X````#\!``""!0``]P,``$T#``!D`````````$P%````````!`,`
M`!P!``"L`0``C0```,8"``"#`@``K@,``,P#````````]`$```````!N!```
MRP0`````````````)0,```````#9!```Y0,``-P"````````]````)\%``#.
M`````````'4``````````````/L!``#5`@`````````````H`0``LP$``)X%
M``#B!```F04``&X"``"H`0``9P(``-D!```-!```V`(``*4"````````<P0`
M`%L#````````CP$``*<```!M`P````````````"U`@``4`,```````!G````
M?0$``$(#```P````I@0``#$%``".`@``U`(``&4``````````````%$"``!3
M`0```````"P#``#^````20````````````````````````"5````+@$``#D`
M````````#P4``-P```!'`0```````.8```!8!0``#P$``(D#````````BP$`
M``````"G`@``#0(``#@$````````'@(``,$"```P`P``\0$``#,$``!D!0``
ML@0``,\```#;`0```````&@%``!R!```=00``#4%```H`@```````,X"```D
M`P``]0$``'P"````````C@0``#<"```^`P``&00``'0````*`@``#````+<!
M``"]`P``]00```````!!````)P$``#0#``#$`P``F`0``(("``!P`P``!`4`
M`%$#``!/`P``_P(```````"J`0``$@$```````!8`@```````'D!````````
M`````(4$````````O@(``&(````&`0``K````%H#```I`P``CP4``*@$````
M````;0$```````!(`0``$`4```````"M`0```````#T`````````?P(``($$
M```&!0``%P````````#T`P``E@```/@"````````VP,```````"8`P``````
M`)8$```N`@```````),"``!J`0```````+T$``!Q`0```````"L#```$````
MWP$``.,```"X````^00``%4```!'````0@``````````````4`0```````"@
M`P``=`$`````````````T`$``!\$``#_````@@0``'8$```#!0```````"H%
M`````````````%0%````````T`0`````````````0@$``'8`````````MP,`
M``````#R`````````"@$``!-`@```````%(#````````40````````"8`@``
M5`(``'`"``#3!```J0$``*4$``#3`0``)@$``*(%``!-`0``2@(```````#>
M!```+P,``,,$````````)@,``-T#``#L`@``#`,```$"``#@`P```````(X`
M``!&`@``IP0``$("``#H`0``5`$``*P"``"X`@``[@(```````#@`0``UP``
M`"4"```6!```.@```.8$``#]`0``5@4```\#``"K`````````#P"``!5`@``
M0@0```@%``#J`P```````-`#``#+`@``NP,```````!N````PP,```````"'
M`0``2`,``$$$```B`P``A0,`````````````:@0``!H!``!7````$P$``,X$
M``",`0```````,,"``"1!```\@$``.(!``#B`P``:0```"\%``!T`P``RP$`
M`!X#`````````````%(%````````9P4``.L#``!@!```'0````````!C`P``
M8`$``-0```"*`0``'P4``$,%``"_`P``"0(``",$````````0P0```````#=
M`0``*P(``(0```!:````_P$```````![`P``G@```&$$``!Q`@``=04``(`%
M``#S````)@4```````!I`0```````'<#``#5!```%@$``"X```!N`P``UP$`
M`%@#```Y`0```````.,#``#*`0```````%L`````````20(``,\!````````
M`````$<"``!0`@``/P,``#$!``!C`@````````(%````````+0```)T"````
M````Y0(``)P"````````^0$``$`!``"#`````````$0$````````````````
M``#\`0``+P```)X$``!9````_0,``*0%``!<`````````(\#``!K`@``;P``
M`)X#``!:`@``YP0```````"\!```\`,``%`!````````F0,``"L```!3!0``
M`P````````"P`0``R0,``#`%```D`@```````!8"````````.`(``*`!```5
M````D@4``&T$``"@````)00``/,!````````F`4``*($``!V!0``&`4``(0!
M``"0`````````"0$``!^!0``P````,0!`````````````%P!``",`@``?@0`
M`````````````````*\$````````N0,``"L%``!L`@`````````````*!```
M$0$``"@```#5`0````````````"P`@``FP0```````!%`P``F@4```````#"
M!````````-````#X!```&0$```,!```F`@``X00````````.!0``10$`````
M````````1`,``#T"``#=!`````````````"]````C`,`````````````>@,`
M`(L#`````````````(,!``!X!0```````*$$```1`@``VP0```````"Y`0``
M+P(``(@"``#,!````````#("````````.P4``",#````````KP$``!$#```"
M`@```````)T#````````'0,```````"\`@``W`0``+H$``";`@``S`(``+D`
M```1````C0$``*D$``!P`0````````````!N!0``HP(``*,%``"3````````
M``````#.`0``.@(```````#0`@``5@`````````;!```Q@$``%D"```^`0``
M!00``.<!``!8`0```````$D#``"X`P````````````!,`P```````)L!```&
M!````````(8#````````X`0``*(#````````V`$``)\!``!)!0``````````
M``!3`@``%P(``'\#``!<`@``1`(````````A````G0$````$``!O`P``````
M``<#```2!```U0```+X#``"-!```-P,```````#U`P``[`$``%8"``#O`@``
M`````$$#```H`P``<@$``&,!``!'`P``K0(``"T!`````````````*T#``!2
M!```&`,````````'!```V@(````````P!```M@0``````````````````$0`
M`````````````%D!````````&@(```T#`````````````!,%``"6`P``````
M`",!``"P!```4@$``!`"```?````'P,``'(`````````;@$```````#_!```
M/P(``-(!``!B!0``I`0``/T"``````````````````!S````"P```)<!``!I
M!```.`$``)H"``!O!0```````,4!`````````````/<!``!4!```````````
M``#?!````````!4%```+`0``]`(``/P```!E!````````'<$```)!0``````
M`'(#``"%````0P,``#P!``"Q`@``>```````````````"P4`````````````
M`````$`````D!0``>P(``($"``!5`0```````#,"``"-`P``KP,``)H#``!%
M!````````%,`````````@0,``$4```#6`@``"0````````#&`P``F@0`````
M```&`@```````)`"``!*!0``>P$``!T"````````_00`````````````ZP$`
M`&\!``#'`P``M````!$$``!:!0``*00``+T!``"K`0```````-($``!:`0``
MY`,```````#$`@``)P``````````````5`,```@!````````````````````
M````@@```*8"``#6!```;P0``%X#``!5!0``OP(```````!*`P``0`4``)($
M````````N@```&`#``#:`P```````",```#+````Y0```#L"``"J`P``T@``
M`*X"``"I```````````````Q`P``9P,````"````````CP(``.T#``#T!```
MB@,``/$#``#Z`````````$@"``"<````\@0``"`"```[`````````'$%``#:
M`0```````$<%``!>`@``_0```"D%```V!```2P```#@#``#7!````@0``',%
M```;````G@$``"$!``!.`0``?0(``!4"``!H!```LP```"`%```2!0``````
M```%```V!0``W@$``!`#``!B`P``E@$``!H%``#G````X0$``(0$``#(`@``
ME0,```H#`````````````'H%``"E`P``V@0``'H"``#/`@``I0$``!D```#B
M`@``HP0``"("`````````````$\$``"I!0``FP4``(@#``#'````5P,`````
M``"\`P``J0(``!T%````````U@```'D$``"N!```#0```!<!``!P!0```@``
M`*X```!6!````````$@```!F!```QP$``#8```!-````Z0(``#T!```I`0``
M!`0``&0$``!#`0``Q`0``#P%``!Y!0```````!L"``#Y`P````````8#````
M````(0,``+H!``"4`0``;04```````"7`@``V0```&<$```8`0``'`4``-\"
M``!W`````````!,#````````;`$```````#``P``(@````````#M`0``````
M`'$````N`P``#04``+\!``!X`0````````````#7`P``L00```$#``"A`P``
MPP```!<%`````````````)P#`````````````',"``!>!```6`````````#G
M`@``H0$``+4``````````````"<%````````7`,``)D$````````G0```'L$
M``"]`@``6P(``$0%```R!```5P4```````#R`@``7@$```````#O`0``````
M`!<#``#J`@``2P$``-@#``#?````?@```#X$``#C!```.`4```````"L`P``
MR00``)0```"*!0``O@$``#<!``!&`0``B`````````"+`@``8@0``+,$``!7
M`0``>0,``/,"``!/`@``<0,``.8"``!U`@``C@,``,0```"C`0``'@$``+<"
M``"7`P``90$````````?`0``=`0``-,#`````````````.<#````````W`$`
M`.0!``!F````X0(``&8#``#D!```L@(```````!F`0``40$``,@$``"F!0``
MZ@```(L%````````'`,`````````````R@`````````>!````````$X"```]
M!0``T0````````#,`0``_P,``'(%```,!0``````````````````6`0`````
M```.!```:`,``.\#````````(@4```````#X`````````!,"```M!```E`4`
M`(P```!^`P``B0(``-4#```W!0``%`4``$L%```<!```1@0```````#V!```
M70```($%``!]!`````````````#2`P``Y`(``+L```!_`0``I@$``)0"``"0
M!```,`(````````_!0``"0$```````!?````M`0```````!-!0``,P,``,T!
M``#;````$P```!D"``!=!0``>@````````#P`0``IP4```H```!=`P``D04`
M`+L"``!\!````````*T`````````?0,``!H$``#\`@``A0(``!T!````````
MI0```&0"````````+`$``*H"``"U`P``KP(``,X#``#-````````````````
M`0``?@$``!(```#H`@```````"`#```^````80(````````T`@``9`$``,\#
M``!4````````````````````E`,``%X```!%`@``(`$``)D```#Q`@``````
M`(D!```+!```U@$``%D$```0`````````-L"`````````````)`#``#3````
M[`,``(0#``#<`P``2@0``%T$```]`P``E@4````````7!```P`$`````````
M````R0(``+`#``"Y`@```````-,"```%````@P,``&`%``""`0``"````&P`
M```A!0``2P,```H%```3!```90(``(<"``#I`P``Y@,``'L%``#(`0``````
M`*`$```.`P``.@$```D#``````````````````"D````'@4``/,$``"1`@``
M&P,``!`$``!@`@``CP```+0"````````:`(``!(#``!.`P``U`$``%L!``!%
M!0``FP,``(H$``!=`0```````!0#```H!0``<P,``#P```````````````(#
M``"2`@``L@$``(@%``!X`@``UP(```@$```#!````````#X%````````%@,`
M`$@$```Z!```200``#0````[`P``#P```!4#``"O````?`$``&$```"S`@``
M]@$``$\```#M!```^P```!P"```'`@``:P$``"8```"2`P```````"H!```D
M`0``JP,``&@``````````````)$#``!#````X0,``(L````)!```1`$``&D#
M``"3!```-P````````#C`@``]@,``,("````````-`$````````M`@``7P$`
M`$D!````````L@,``/(#``!L!0``(P4``!@"````````K@$```````#&!```
M`````-D#``"Q`P``^P0``$$"```(`P```````'8!``#-!````````(H"```X
M````^0``````````````.P0``(D$``!F!0``$`$``(X%``#Z`P``70(``($`
M``"&`0``*0````````#H````?P4``(P$```Z!0``5@$``-X```"8`0``````
M`&H#``#%!```Q0(``%$%```M`P``>`0`````````````7P0``(P%````````
M`````(8$````````!P4``-0$````````DP,``%<"`````````````$H!``!J
M````J`4``)\#```;!0``<`0``+8"``!.````'P(``````````````````%L$
M```_````E@(```````````````````````"B`0``MP```"P%``#P````````
M`'$$``!_`````````&L#```8!```=P4``#\$````````I@```"H$``"?!```
MP@$``+@!``"7!```M00``(8`````````!0,``(D```!#`@``<P$``)4"``"*
M````)P,``)0$``"Q`0``\0````````";````L0```-@```#:`````````.D`
M````````IP$``+\````$`0``:@4```````#W!```^@0``!("``"H`@``````
M`.L"````````MP0``/P#```1!0``````````````````D@$```````#*`P``
M+04``$P````9`P```````$P!``#M````QP0``/$$``!!!0``90,``#8#```C
M`@```````-$$```@!````````'0"``#P!```00$``,(#```K!````````!4!
M``"'!```M`$```````#V`@```````(L$````````9`,``&$#````````D0$`
M`&8"``!-!```804```````!U`0``JP0`````````````@P0```T!````````
MN`0``$`#```S````X0```'("``!2`@``P0```(8"``!Y`@``1@4``*8#``![
M````6P4``#D$````````S``````#``!I`@``WP,``#D"````````X@````<`
M`````````00````````J`@``C04```````#E`0```````(<%```J````````
M```````B!```5P0```````"H````S0,``)@```":`0``7`4``-("``#K````
MT0,``)(```"A`````````&T```!`!```&P$```````"J!```9P$````````=
M!```,@$````````R`P```````'4#```D````@`(``),!````````-`4``$\!
M``!Y````#P0``%\%```%`@```````/X#````````[@`````````<````)04`
M`````````````````(D%``````````````````"=!````````'T```"C````
M#@````````".`0``W0(```````!C!```?````&4%``!3`P```04``#$```#4
M`P``\P,``.D!```8````B`0``)P!``"(`0``,00``%`%```6````7P(``*("
M````````=@,``#,%```6!0``RP,``%D%````````(0(``/`"```4!```0@4`
M`!H````9!0``NP$``#4$``"'`P``/@(`````````````:@(``&(!```,`@``
M8P4```````#%`````````(0%```B`0`````````````W!````````*L"```$
M`@```````/X"````````K00``%D#``"Z`@``A04`````````````K`0`````
M``!,`@``[0(``(`````.`@``+`0``/8```!5`P``D`4``*,#````````````
M``````"?`@``Z00```<!`````````````-$!``#X`0``-@$``#(%````````
M:P4``)<%```G!```(00```````#H`P```````((#````````[````%,$````
M`````````$L$``#1`@``*P$``"8$````````Y@$``'H!````````````````
M````````O@0``*0"`````````````*@#``!C`````````#0$````````````
M`),%```\`P``ZP0```````#J`0`````````````V`@``3@4``'P#``#)````
M`````)H```"E!0``EP```&D%``#``@```````'P%``!X`P```````(`$``"A
M!0```````,D!``!V`@``AP```%P$```L`@``+@0``#L!```O`0``1@,``*`"
M``#^`0``Z`0``&("``"``0```````+X````Y`P```````%````"!`0``````
M`&P$``#\!```)0```,4#````````#`$``)T%````````[P```%\#``"R````
MD`$``+0#``#'`@``#@$```,#``#`!```W0```)X"`````````````)4%``!H
M`0``X`(``/4"``#J!```2P(``#4#```L`````````#T$````````,`$``'``
M``"A`@``R@0``!4$```(`@```````#,!``"I`P``;0(``+,#``#E!```````
M`,$$`````````````&L$``"5`0```0$```P$``#>`P```````+H#```N!0``
M^0(`````````````OP0``&````!*````@P4``%X%````("@E<R!D87ES(&%G
M;RD`("A!8V-E<W-K97D@)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT
M;VUO<G)O=RD`("AY97-T97)D87DI`"(E<R(@:7,@;F]T(&$@9&ER96-T;W)Y
M+@`B)7,B(&ES(&YO="!A('9A;&ED(&-H;VEC92X`(B5S(B!I<R!N;W0@8V]N
M9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN`"(E<R(@=')E92!R96YD
M97)E<B!N;W0@9F]U;F0N`"(E<R(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@
M<WES=&5M+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES
M=&5M+@`B)7,B('=A<R!N;W0@8W)E871E9#H@)7,N`"4N,F9-0B!U<V5D(&]F
M("4N,F9-0B!A;&QO=V5D("@E+C)F)24I`"5D("5S(&%N9"`E<P`E9"!D87ES
M('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RX`)7,@+2!.;W1I8V4`)7,@
M1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M
M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F
M($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@:7,@<F5A9'D@=&\@
M<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E
M;&]W+B!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W
M86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@`E<R!I<R!R97%U:7)E9``E
M<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!
M9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!4
M87-K;&ES=``E<SH@)7,`)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R
M;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@
M86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I
M=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+@`M+2!S96QE8W0@+2T`,3(@
M2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`/%!R979I;W5S
M`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C
M:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@4$=0(&ME
M>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@
M4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G
M92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S
M<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@
M<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3
M+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@
M4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--
M24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04TO
M4$T`06)O=70@=&AI<R!E9&ET;W(`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!6
M1E,@9&ER96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE
M+@!!8V-O=6YT($EN9F]R;6%T:6]N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N
M="!F<F]Z96XN`$%C8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@
M0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@
M3F5W(%!E<FUI<W-I;VX`061D(&$@8VAI;&0@9W)O=7`@=&\@(B5S(@!!9&0@
M82!C:&EL9"!P97)M:7-S:6]N('1O("(E<R(`061D(&$@;F5W('5S97(Z`$%D
M9"!C;VQU;6X`061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@
M365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=&\@861D<F5S<R!B;V]K
M.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&5D("(E<R(@
M=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S
M:6=N=7`@:6YF;W)M871I;VXZ("5S+@!!9&1E9"`B)7,B('1O('1H92!S>7-T
M96TN(%EO=2!C86X@;&]G(&EN(&YO=RX`061D:6YG('5S97)S(&ES(&1I<V%B
M;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E
M<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`
M069G:&%N:7-T86X`06QB86YI80!!;&=E<FEA`$%L:6%S`$%L:6=N;65N=#H`
M06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E
M<FUI<W-I;VYS`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T
M:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E
M<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E
M<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!
M;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;65R:6-A;B!3
M86UO80!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N('5N:VYO
M=VX@97)R;W(@:&%S(&]C8W5R960N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA
M`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YT87)C=&EC80!!;G1I9W5A(&%N
M9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N($QI<W0`07!P;&EC
M871I;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H:6QD(%-H87)E<P!!<'!R;W9E
M`$%P<')O>&EM871E(%-I>F4`07!R:6P`07)C:&EV92!&:6QE(%-I>F4`07)C
M:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE
M('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES
M:"!T;R!D96QE=&4@(B5S(B!A;F0@86YY('-U8BUG<F]U<',_`$%R9V5N=&EN
M80!!<FUE;FEA`$%R=6)A`$%S8V5N<VEO;B!)<VQA;F0`07-I82]086-I9FEC
M(%)E9VEO;@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<S\`071T96UP="!T;R!D96QE=&4@82!N;VXM
M97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T
M96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N
M="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@
M<VAA<F4N`$%T=')I8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U
M=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C
M87!A8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T
M<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N
M(&YO="!F;W5N9"X`075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U
M<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E;6]V
M:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O
M<GD`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES
M('=H870@=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@
M<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S
M97(@)7,`075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R
M=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+@!!=71H7VUC86PZ(%)E<75I<F5D
M($U#04P@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]S;6)A=71H.B!297%U
M:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T
M:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@9F%I
M;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@
M<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@
M1E10('-E<G9E<B!F86EL960N`$%U=&AE;G1I8V%T:6]N('1O('1H92!334(@
M<V5R=F5R(&9A:6QE9"X`079A:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"
M86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W
M;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A:&%M87,`0F%H<F%I;@!"
M86YG;&%D97-H`$)A<F)A9&]S`$)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y("(E
M<R(@;F]T(&9O=6YD+@!"87-E;&EN90!"96QA<G5S`$)E;&=I=6T`0F5L:7IE
M`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@
M87!P;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L
M;V-K(%1Y<&4`0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R
M('1H:6-K;F5S<SH`0F]R9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O
M='-W86YA`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N($]C
M96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I80!"=6QL
M971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`0U),($1I
M<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#86-H92!I
M;FET('=A<R!N;W0@8V]M<&QE=&5D+@!#86QE;F1A<@!#86UB;V1I80!#86UE
M<F]O;@!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O
M;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86X@;F]T('=R:71E('1O(&9I
M;&4@(B5S(@!#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N
M9&QE<G,N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;B=T
M(&]P96X@9FEL92`B)7,B+@!#86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B;&5M
M(%)E<&]R=`!#86YN;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@
M82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@<')O8V5E9"!W:71H;W5T
M("=T87)G971&:6QE)R!P87)A;65T97(N`$-A;FYO="!R96UO=F4@9&ER96-T
M;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+@!#
M86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R
M(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R('-T;W)E9"X`0V%N;F]T
M(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BX`0V%P92!697)D
M90!#87!T:6]N`$-A<G)I97(`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA
M;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D
M9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE
M`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5R=&EF:6-A=&4@
M1&5T86EL<P!#97)T:69I8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE
M<P!#:&%D`$-H86YG90!#:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@=&AE
M(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R
M96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=I;F<@>6]U<B!P
M87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N
M9FEG=7)A=&EO;BX@($-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#:&5C
M7VL@3&EN:RXN+@!#:&EL90!#:&EN80!#:&]O<V4@07!P;&EC871I;VXZ`$-H
M;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!H;W<@
M=&\@9&ES<&QA>2!D871E<SH`0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D969I
M;FET:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE87(@35-/9F9I8V4@=&%G<P!#
M;&5A<B!1=65R>0!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A
M<B!U<V5R(&1A=&$`0VQI8VL@=&\@0V]N=&EN=64`0VQO<V4@5VEN9&]W`$-O
M8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L;VUB
M:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L<SH`
M0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O
M;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY`$-O;F9I9W5R871I
M;VX@1&EF9F5R96YC97,`0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H
M(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+@!#;VYF:6=U<F%T:6]N
M(&ES(&]U="!O9B!D871E+@!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R
M9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE
M`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE
M8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C
M=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ
M("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N
M=&%C=',`0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U
M<B!A9&1R97-S(&)O;VLN`$-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I
M;&4Z(`!#;VYT96YT<R!O9B`B)7,B`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#
M;W!Y`$-O<'D@9F%I;&5D.B`E<P!#;W!Y('-E;&5C=&EO;@!#;W-T82!2:6-A
M`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z
M(`!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G93H@`$-O=6QD(&YO="!3+TU)
M344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S
M<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN
M9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S
M`$-O=6QD(&YO="!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@
M8V]N;F5C="!T;R!S97)V97(@(B5S(B!U<VEN9R!&5%`Z("5S`$-O=6QD(&YO
M="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96-R
M>7!T(%!'4"!D871A.B``0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N
M`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&1E;&5T
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E;&5T92!S971U
M<"!U<&=R861E('-C<FEP="`B)7,B+@!#;W5L9"!N;W0@9&5T97)M:6YE('1H
M92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E=&-H
M(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L
M971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O
M;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@
M;&]A9"!S=')A=&5G>2`B)7,B+@!#;W5L9"!N;W0@;6MD:7(@(B5S(BX`0V]U
M;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BX`
M0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN9RX`0V]U;&0@;F]T(&]P
M96X@)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE
M("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B)7,B+@!#;W5L9"!N;W0@
M<F5A8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U
M;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U
M<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@;F]T(&-O<G)E
M8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I
M9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R971R:65V92!!
M0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@
M;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@
M<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5T
M<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO="!R979E<G0@
M8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T(')M9&ER("(E<R(N`$-O=6QD(&YO
M="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C
M:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N
M9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C
M<FEP="!T;SH@(B5S(BX`0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF
M:6=U<F%T:6]N(&9I;&4@)7,N`$-O=6QD(&YO="!S879E('1H92!C;VYF:6=U
M<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE
M(&]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@
M;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N`$-O=6QD(&YO="!S96%R
M8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@=6YL:6YK("(E<R(N`$-O
M=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D
M:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R
M871I;VX@9F]R("(E<R(Z("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@
M4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN`$-O=6YT
M<GD`0W)E871E`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S
M`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T
M:6$`0W5B80!#=7)R96YT(%-E<W-I;VYS`$-U<G)E;G0@5&EM90!#=7)R96YT
M(%523"!I<P!#=7)R96YT(%5S97)S`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@
M=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Z
M96-H(%)E<'5B;&EC`$1$`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T86)A
M<V4@3&]O:W5P`$1A=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$
M95]L971E($-O;'5M;@!$96-E;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C<F5A
M<V4@26YD96YT`$1E9F%U;'0`1&5F875L="!#;VQO<@!$969A=6QT($ED96YT
M:71Y`$1E9F%U;'0@4VAE;&P`1&5L971E`$1E;&5T92!#96QL`$1E;&5T92!'
M<F]U<`!$96QE=&4@3&]G`$1E;&5T92!097)M:7-S:6]N`$1E;&5T92!C96QL
M`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP
M;&%T90!$96QE=&4@;65S<V%G97,`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B
M)7,B`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(B!A;F0@86YY('-U8BUP
M97)M:7-S:6]N<S\`1&5L971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I
M='D`1&5L971E('-U8B!F;VQD97)S`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU
M;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$96QE=&5D('-E='5P('5P9W)A
M9&4@<V-R:7!T("(E<R(N`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$97-C<FEB
M92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS("AA;'-O(&EN($AO
M<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@
M=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1I<F5C=&EO;B!L969T
M('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T`$1I<W!L87D@,C0M
M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1J:6)O=71I`$1O(&YO="!D
M96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``
M1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)
M9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P
M=6)L:6,`1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+@!$;W=N;&]A
M9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO
M;B!A<R!02%`@<V-R:7!T+@!%+4UA:6P`16-U861O<@!%9&ET`$5D:70@0FQO
M8VL`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N
M<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%
M9&ET('!E<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO;G,@9F]R
M("5S`$5G>7!T`$5L(%-A;'9A9&]R`$5M86EL`$5M86EL($%D9')E<W,`16UA
M:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T
M:6]N`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H
M('1E<FUS`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@
M1V%L;&5R:65S(&EN('1E>'0_`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT
M(&UE;G4_`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I='D@<75E<W1I
M;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S
M970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y
M;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`17%U871O<FEA
M;"!'=6EN96$`17)I=')E80!%<G)O<@!%<G)O<B!C<F5A=&EN9R!B;&]C:SH@
M)7,`17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S`$5R<F]R(&=E='1I;F<@
M8V]N=&5N=#H@)7,`17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S`$5R<F]R
M('=I=&@@96UA:6P@;65S<V%G92X`17)R;W(@=W)I=&EN9R`B)7,B+@!%<W1O
M;FEA`$5T:&EO<&EA`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@
M;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R
M>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@
M=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%>'!E8W1E
M9"`G*2<`17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$9'($-O;&]R`$944"!U
M<&QO860@;V8@<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N
M`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@
M8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E
M<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@
M;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`
M1F%I;&5D('1O(')E=')I979E.B`E<P!&86QK;&%N9"!)<VQA;F1S("A-86QV
M:6YA<RD`1F%R;V4@27-L86YD<P!&871A;"!%<G)O<CH`1F%X`$9A>&5S`$9E
M8G)U87)Y`$9I:FD`1FEL90!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U
M;G0Z("5S(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE
M8W1I;VX`1FEL92!U<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N
M`$9I;'1E<G,`1FEN;&%N9`!&:7)S="!1=6%R=&5R`$9O;&1E<B`E<R!D;V5S
M(&YO="!E>&ES=`!&;VYT($-O;&]R`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T
M('-U<'!O<G0@:6UA9V5S`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&
M;W)U;7,`1G(`1G)A;65S`$9R86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&
M<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N
M(%1E<G)I=&]R:65S`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@
M3F%M90!'86)O;@!'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;0!'86QL97)Y
M.@!'86UB:6$`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@
M0V]D90!'96]R9VEA`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R`$=I=F5N($YA
M;64`1VQO8F%L($]P=&EO;G,`1V]O9VQE($UA<',`1V]O9VQE(%-E87)C:`!'
M<F5E8V4`1W)E96YL86YD`$=R96YA9&$`1W)O=7`@061M:6YI<W1R871I;VX`
M1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O=7!?;&1A<#H@56YA
M8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9#H@`$=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,`
M1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<P!'<F]U<',`
M1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'=65S="!097)M
M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA
M`$A45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L
M9V]R:71H;0!(96%D97(`2&5A9&5R<P!(96%R9"!)<VQA;F0@86YD($UC1&]N
M86QD($ES;&%N9',`2&5I9VAT`$AE;'``2&5M:7-P:&5R90!(;U]M90!(;VQY
M(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@061D<F5S<P!(
M;VUE($1I<F5C=&]R>0!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(
M;W)D90!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT
M97)E9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O
M<G)E<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T
M(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@
M4W5C8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE
M(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0
M(&5X=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@
M6$U,('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O
M(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E
M=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D
M92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R
M9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`
M2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W
M(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY(')O
M=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AU;F=A<GD`24U!4"!M86EL
M8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N
M(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE
M9#H@)7,`25`@061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0
M($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO
M8VMD;W=N('9I;VQA=&EO;BX`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS(&9O
M<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I
M<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A
M(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG
M($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI
M<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`26UA9V4@4')E
M=FEE=SH`26UA9V4@55),`$EM86=E(%523#H`26UA9V5S`$EM<&]R="P@4W1E
M<"`E9`!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);F-O
M<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M92!A
M;F0O;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA
M=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES
M=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@26YD
M96YT`$EN9&EA`$EN9&EV:61U86P@57-E<G,`26YD;VYE<VEA`$EN9F\`26YF
M;W)M871I;VX`26YS97)T($-?;VQU;6X@069T97(`26YS97)T($EM86=E`$EN
M<V5R="!486)L90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F
M;W)E`$EN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE
M`$EN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!)
M;G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@
M82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R
M86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R
M87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@
M=&5M<&QA=&4`26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U
M(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F
M=&5R`$EN<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN
M<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R="!M97-S86=E<P!);G-E<G0@<&%R
M86=R87!H(&%F=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R
M;W<@869T97(`26YS97)T(')O=R!B969O<F4`26YS97)T('1H92!R97%U:7)E
M9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.@!);G-E<G0O36]D
M:69Y($EM86=E`$EN<V5R="]-;V1I9GD@3&EN:P!);G-U9F9I8VEE;G0@8W)E
M9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I
M8VEE;G0@8W)E9&ET+@!);G9A;&ED(%I)4"!D871A`$EN=F%L:60@87!P;&EC
M871I;VXN`$EN=F%L:60@9&%T82!S=6)M:71T960N`$EN=F%L:60@9&5S=&EN
M871I;VX@861D<F5S<RX`26YV86QI9"!L:6-E;G-E(&ME>2X`26YV86QI9"!L
M;V-A=&EO;B!P<F]V:61E9"X`26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`
M26YV86QI9"!P87)T;F5R(&ED+@!);G9A;&ED('!R;V1U8W0@8V]D92X`26YV
M86QI9"!P<F]T;V-O;"X`26YV86QI9"!R96-I<&EE;G0Z("(E<R(`26YV86QI
M9"!S:&%R92!O8FIE8W0`26YV86QI9"!S;W5R8V4@861D<F5S<RX`26YV86QI
M9"!U;FEC;V1E(&1A=&$N`$EN=F5R="!S96QE8W1I;VX`27)A;BP@27-L86UI
M8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`27-R865L
M`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IE
M<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`
M2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MA>F%K
M:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R;W,@<V5R=F5R(')E
M:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97D@0W)E871I;VX`2V5Y($9I;F=E
M<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(&%L<F5A9'D@97AI<W1S
M(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:7)I8F%T:0!+;W)E82P@1&5M
M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@
M;V8`2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U=`!,86YG=6%G90!,86\@4&5O
M<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T(%%U87)T97(`3&%S="!L
M;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.
M979E<@!,871V:6$`3&%Y;W5T`$QE8F%N;VX`3&5F=`!,97-O=&AO`$QI8F5R
M:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI;FL`
M3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H
M96X@9&ES<&QA>6EN9P!,:7-T($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S
M`$QI<W0@5&%B;&5S`$QI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<P!,:7-T
M:6YG('5S97)S(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE
M9"X`3&ET:'5A;FEA`$QO861I;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A
M;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]U=`!,;V=I;@!,;V=I;B!4
M87-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A
M<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N
M`$QO=V5R(&=R965K(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E
M<B!R;VUA;B!N=6UB97)S`$QU>&5M8F]U<F<`34T`35,M5$Y%1B!!='1A8VAM
M96YT(&-O;G1A:6YE9"!N;R!D871A+@!-86-A;P!-86-E9&]N:6$L(%1H92!&
M;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86EL`$UA
M;&%W:0!-86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA;F%G92!T:&4@
M;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I
M=&@L(&%N9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I
M97,N`$UA<F-H`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-871C:&EN
M9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`36%Y`$UA>6]T=&4`365M
M8F5R<P!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G92!6
M97)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I
M8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I960N`$UE=&AO9`!-971H;V0@(B5S
M(B!I<R!N;W0@9&5F:6YE9`!-97AI8V\`36EC<F]N97-I82P@1F5D97)A=&5D
M(%-T871E<R!O9@!-:6UE(%1Y<&4`36ES<VEN9R!014%2('!A8VMA9V4@2%14
M4%]297%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O
M(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L
M:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG(')E<75I<F5D
M(%!%05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@240N`$UO`$UO
M8FEL92!-86EL`$UO9&EF:65D($1A=&4`36]L9&]V82P@4F5P=6)L:6,@;V8`
M36]N86-O`$UO;F=O;&EA`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E
M<P!-;W)O8V-O`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E
M(%5P`$UO=F4@9&]W;@!-;W9E('5P`$UO>F%M8FEQ=64`37D@06-C;W5N=`!-
M>2!!8V-O=6YT($EN9F]R;6%T:6]N`$UY86YM87(`3D\L($D@1&\@3D]4($%G
M<F5E`$YA;64`3F%M:6)I80!.875R=0!.97!A;`!.971H97)L86YD<P!.971H
M97)L86YD<R!!;G1I;&QE<P!.971W;W)K`$YE=F5R`$YE=R!#86QE9&]N:6$`
M3F5W($-A=&5G;W)Y`$YE=R!-;V]N`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI
M`$YE=R!:96%L86YD`$YE=R!P87-S=V]R9`!.97<@<&%S<W=O<F0@=VEL;"!E
M>'!I<F4@;VX@)7@N`$YE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N`$YE=W,`
M3F5W<V=R;W5P<P!.97AT`$YE>'0@;W!T:6]N<P!.97AT/@!.:6-A<F%G=6$`
M3FEG97(`3FEG97)I80!.:75E`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N
M(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&-H86YG92X`3F\@
M8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10
M(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-R961I="!L969T+@!.;R!D
M97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.;R!I8V]N
M<R!F;W5N9"X`3F\@;&]C871I;VX@<')O=FED960N`$YO(&UE<W-A9V4@<W5P
M<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF:65D
M+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO
M;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I
M;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT
M:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U
M=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U
M=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P
M<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R!W
M;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I9VYU<',N`$YO
M('%U;W1A('-E="X`3F\@<V5P87)A=&]R('-P96-I9FEE9"X`3F\@<W5C:"!F
M:6QE`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V86QI
M9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N
M9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I
M9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T
M:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;F4`3F]R9F]L:R!)
M<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R;B!-87)I86YA($ES
M;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E`$YO="!A(&1I<F5C
M=&]R>0!.;W0@:6UP;&5M96YT960N`$YO="!S=7!P;W)T960N`$YO=&5S`$YO
M=F5M8F5R`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@
M8V]L=6UN<P!.=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C:69I960@
M9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/8FIE8W0`
M3V)J96-T($-R96%T;W(`3V-T;V)E<@!/9F9I8V4`3VQD('!A<W-W;W)D`$]L
M9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="X`3VUA;@!/;FQY($E-05`@<V5R
M=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&]N92!E;6%I;"!A
M9&1R97-S(&%L;&]W960N`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI
M;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI
M<W-I;VYS(&9O<B!A('-H87)E`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96Y3
M4TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@
M4R]-24U%('!A<G0N`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,
M:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R9V%N:7II
M;F<`3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W1H97(@26YF;W)M
M871I;VX`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES
M(&YO="!A=F%I;&%B;&4N`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC
M<GEP=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T
M960@1&%T80!02%`@0V]D90!02%`@4VAE;&P`4$]325@@97AT96YS:6]N(&ES
M(&UI<W-I;F<`4&%D9&EN9P!086MI<W1A;@!086QA=0!086QE<W1I;FEA;B!4
M97)R:71O<GDL($]C8W5P:65D`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A
M<F%G=6%Y`%!A<W-W;W)D`%!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY
M+@!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!
M1$E54R!A=71H96YT:6-A=&EO;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I
M;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N
M`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N
M=7!S.@!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!0
M97)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI
M<W-I;VX`4&5R;6ES<VEO;B`B)7,B(&YO="!D96QE=&5D+@!097)M:7-S:6]N
M($1E;FEE9`!097)M:7-S:6]N<P!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO
M;@!097)S;VYA;"!);F9O<FUA=&EO;@!097)U`%!H:6QI<'!I;F5S`%!H;VYE
M`%!I=&-A:7)N`%!I>&5L<P!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y
M96%R+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y
M.@!0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R
M(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@<')O=FED92!A('-U;6UA
M<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA
M;64@86YD('!A<W-W;W)D`%!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X
M="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S
M>7-T96TN`%!O;&%N9`!0;VQL<P!0;W)T=6=A;`!0<F5F<U]L9&%P.B!297%U
M:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ
M(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"X`4')E=FEE
M=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E=FEO=7,@
M;W!T:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV871E($ME>0!0<F]B;&5M`%!R
M;V)L96T@1&5S8W)I<'1I;VX`4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R
M:71H;0!0=6)L:6,@2V5Y($EN9F\`4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N
M;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`4'5E<G1O(%)I8V\`4'5R9V4@
M;65S<V%G97,`46%T87(`475E<GD`475O=&$`4E-!(%!U8FQI8R!+97D@*"5D
M(&)I="D`4F%T:6\`4F5A9`!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A
M=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T
M82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N
M92X`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:"!$>6YA;6EC($UE
M;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E;&]A9`!296UO
M=&4@4V5R=F5R<P!296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M
M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!";&]C:P!296UO=F4@9F]R;6%T=&EN
M9P!296UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R
M)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@=&AI
M<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U
M<V5R.B`E<P!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE
M9"!E<G)O<F-O9&4Z(`!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@
M)7,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D
M(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C
M:69I960@:6X@8V]N9FEG=7)A=&EO;BX`4F5S970`4F5S970@4&%S<W=O<F0`
M4F5S970@66]U<B!087-S=V]R9`!297-U;'1S`%)E='5R;B!T;R!/<'1I;VYS
M`%)E='EP92!N97<@<&%S<W=O<F0`4F5V97)T($-O;F9I9W5R871I;VX`4FEC
M:"!497AT($5D:71O<B!/<'1I;VYS`%)I9VAT`%)O;&4`4F]M86YI80!2;W1A
M=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE
M<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P
M96%R(&)E='=E96X@8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E
M='=E96X@<F]W<R!O;FQY`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A
M`%,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP
M=&5D($UE<W-A9V4`4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA
M8FQE+@!344P@4VAE;&P`4U-(`%-50T-%4U,`4V$`4V%I;G0@2&5L96YA`%-A
M:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@
M86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S
M`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=61I
M($%R86)I80!3879E`%-A=F4@(B5S(@!3879E("5S`%-A=F4@3W!T:6]N<P!3
M879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T
M;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S
M(&-O;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O
M.B`B)7,B+@!396%R8V@`4V5A<F-H($5N9VEN97,`4V5L96-T($9I;&5S`%-E
M;&5C="!A(&1A=&4`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE
M=R!O=VYE<@!396QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`
M4V5L96-T(&%L;`!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O
M;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T
M92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E
M;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I
M9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D
M96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@
M;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E
M;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E
M<&]R=`!396YD(%--4P!396YE9V%L`%-E<'1E;6)E<@!397)B:6$@86YD($UO
M;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397-S:6]N($%D;6EN`%-E<W-I;VYS
M`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W
M;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T('5P(')E;6]T92!S97)V
M97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN
M`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A
M=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L
M;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y
M(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B
M;&4`4V5Y8VAE;&QE<P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y
M<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R
M96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I;64@
M=VAE;B!L;V=G:6YG(&EN/P!3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B
M87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@=&AE(%1A
M8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O
M<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@
M9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G`%-H<FEN
M:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F
M('1H92!W87D@9FER<W0`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E
M`%-I9VYA='5R92!!;&=O<FET:&T`4VEN9V%P;W)E`%-I>F4`4VMI<"!-86EN
M=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3;VQO;6]N($ES;&%N9',`4V]M
M86QI80!3;W)T(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T
M:"!!9G)I8V$`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H
M($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N(&%D
M:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R
M(&EN(&-E;&P`4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P86EN`%-P
M96-I86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN
M`%-P;&ET(')O=P!3<FD@3&%N:V$`4W1A=&4@;W(@4')O=FEN8V4`4W1A='5S
M`%-T<F5E="!!9&1R97-S`%-T<FEK971H<F]U9V@`4W1Y;&4@6T-34UT`4W4`
M4W5B9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!3=6)M:70`4W5B<V-R:7!T
M`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E
M;2X`4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R
M;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C
M8V5S<V9U;&QY(')E;6]V960@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E
M<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E
M(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A
M=&EO;BX`4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A
M=&EO;B!F:6QE("5S+@!3=6-C97-S9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E
M<W-F=6QL>2!W<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3
M970`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3
M=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@
M86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y
M<FEA;B!!<F%B(%)E<'5B;&EC`%135B!F:6QE`%1A8FQE(%!R;W!E<G1I97,`
M5&%B;&4@<')O<&5R=&EE<P!486EW86X`5&%I=V%N+"!0<F]V:6YC92!O9B!#
M:&EN80!486II:VES=&%N`%1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8`
M5&%S:W,`5&5L97!H;VYE($YU;6)E<@!496UP;&%T92`B)7,B(&YO="!F;W5N
M9"X`5&5M<&QA=&4@061M:6YI<W1R871I;VX`5&5X="!/;FQY`%1E>'0@86QI
M9VX`5&5X='1O<`!4:`!4:&%I;&%N9`!4:&4@1E10(&5X=&5N<VEO;B!I<R!N
M;W0@879A:6QA8FQE+@!4:&4@2&ES=&]R>2!S>7-T96T@:7,@9&ES86)L960N
M`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S
M9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N
M`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA
M;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!0
M97)M:7-S:6]N<RX`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E
M8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A
M=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O
M('EO=7(@861D<F5S<R!B;V]K+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R
M92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S
M86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@
M<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T
M86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE
M9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W
M96(@8V]N;F5C=&EO;BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E
M<R!S971T:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S
M('-E='1I;F=S+@!4:&4@9FEL92!C86YN;W0@8F4@8V]P:65D(&]N=&\@:71S
M96QF+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82X`5&AE(&9O;&QO=VEN
M9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S
M<V%G92X`5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@
M<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E('1O(&)R;W=S
M97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@
M66]U(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F
M(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H
M97,N("!)9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L
M:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@4')O=&5C=&EO;B!&
M875L="<@86YD(&YE960@=&\@<F5B;V]T+EQN7&Y9;W4@:&%V92!B965N('=A
M<FYE9"X@(%!L96%S92!P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T
M<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BX`5&AE(&ED96YT:71Y("(E<R(@
M:&%S(&)E96X@9&5L971E9"X`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B
M:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N
M`%1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RX`5&AE(&]P
M96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?
M<VUI;64Z.B!C;&%S<RX`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@
M8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU
M;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI
M<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN
M`%1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A
M8W1E<BX`5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C
M=&5R+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E
M<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<W!E8VEF:65D(')O=R`H
M)60I(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5M<&]R87)Y(&9I;&4@(B5S(B!D
M;V5S(&YO="!E>&ES="X`5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN
M8V4@=&AE('!R979I;W5S('-T97`N`%1H92!U<&QO861E9"!F:6QE(&-O=6QD
M(&YO="!B92!S879E9"X`5&AE;65S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N
M9"X`5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@
M;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@
M87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA
M=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S
M('1H86X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@861D:6YG("(E<R(@=&\@
M=&AE('-Y<W1E;3H@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D
M871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S
M(&$@<')O8FQE;2!R96UO=FEN9R`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H
M97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@(B5S(CH@)7,`5&AE<F4@=V%S
M(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P
M;&]A9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L
M;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W
M960@<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P
M;&]A9&5D+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE
M<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C
M;VYT86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE
M(&E#86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O
M;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R97%U
M:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE
M('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@
M86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@
M8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R
M92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T
M+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&ES($E-05`@<V5R=F5R(&1O
M97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O97,@
M;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!F:65L
M9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN
M=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A
M;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T
M86P@=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C
M92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@
M8F4@82!V86QI9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@
M8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE
M("<C,3(S-&%F)RX`5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S
M<V5D+@!4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@
M<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S
M="!B92!A="!L96%S="!O;F4N`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E
M<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT
M;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`
M5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I
M;F1O=P!4:6UE`%1I;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM;W(M3&5S
M=&4`5&ET;&4`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@
M=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C
M;&EC:VEN9RX`5&]G9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VYG
M80!4;V\@;6%N>2!I;G9A;&ED(&QO9VEN<R!D=7)I;F<@=&AE(&QA<W0@;6EN
M=71E<RX`5')I;FED860@86YD(%1O8F%G;P!4=0!4=6YI<VEA`%1U<FME>0!4
M=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4
M>7!E('EO=7(@8VAO:6-E.B``55),`%5G86YD80!5:W)A:6YE`%5N86)L92!T
M;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&-H86YG92!P97)M
M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E
M<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E
M('1O("5S+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R(N`%5N
M86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S+R5S(BX`56YA8FQE('1O
M(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET
M:"!34TPN`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E
M871E(%9&4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@
M9&ER96-T;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@
M=&\@8W)E871E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&-R96%T92!E
M;7!T>2!61E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA
M8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T
M>2X`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<RX`56YA8FQE('1O(&1E;&5T
M92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA
M8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@
M9F]L9&5R("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY
M.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`
M56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@
M=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@
M5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E
M;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E
M+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I
M+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL
M960I+@!5;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE('1O(')E860@=&AE
M('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE("5S('1O("5S
M.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`56YA8FQE('1O
M(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!D
M:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("(E<R(N
M`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D
M(&1O8W5M96YT`%5N86)L92!T;R!W<FET92!61E,@9FEL92`B)7,B+@!5;F%B
M;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+@!5;F%B;&4@
M=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`56YA8FQE('1O('=R:71E(%9&4R!F
M:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+@!5;F1E<FQI;F4`56YD;R!#
M:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T960@<F5S
M<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP96-T960@
M<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N:71E9"!!<F%B
M($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YI=&5D
M(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:VYO=VX`56YK;F]W
M;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YN86UE9`!5;G!R:79I;&5G960@
M<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA
M=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E
M92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S
M('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP
M8F]A<F0N`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D871E("5S
M`%5P9&%T92!U<V5R`%5P9&%T960@(B5S(BX`57!G<F%D92!S8W)I<'0@9&5L
M971E9"X`57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F
M:6QE<R!T;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R
M(')O;6%N(&YU;6)E<G,`57)U9W5A>0!5<V4@0W5R<F5N=#H@)7,`57-E(%-3
M3`!5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@
M<V5R=F5R+@!5<V5R`%5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S
M+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES
M=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F
M;W(@=&AI<R!S:71E+@!5<V5R(&%C8V]U;G0@;F]T(&9O=6YD`%5S97)N86UE
M`%5S97)N86UE("(E<R(@86QR96%D>2!E>&ES=',N`%5S97)N86UE.@!5<V5R
M;F%M93H@`%5S97)S(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5F%C871I
M;VX`5F%L:61I='D`5F%N=6%T=0!696YE>G5E;&$`5F5R:69I8V%T:6]N(&9A
M:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I
M=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9I
M970@3F%M`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6:7)G
M:6X@27-L86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!786QL
M:7,@86YD($9U='5N80!787)N:6YG`%=E`%=E96ML>0!796QC;VUE`%=E;&-O
M;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B!386AA<F$`5VAA="!A<'!L
M:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I
M<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@
M8VAA<F%C=&5R/P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I
M8V@@5&5X="!E9&ET;W(N`%=I9'1H`%=I9'1H(&]F('1H92`E<R!M96YU(&]N
M('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T
M:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`5VES:&QI<W0`5V]R
M:R!!9&1R97-S`%=O<FL@4&AO;F4`5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I
M;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG(&YU;6)E
M<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@;V9F
M<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92X`6#4P.78S($)A<VEC
M($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4`6#4P.78S
M(%-U8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y=C,@4W5B:F5C="!+97D@
M261E;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!960!965E9`%EE87)L>0!9
M96UE;@!997,`665S+"!)($%G<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@
M57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'
M+@!9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@
M8FQO8VMS+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N;F]T
M(&AA=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO
M=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I
M9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O
M('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&AA=F4@8F5E
M;B!L;V=G960@;W5T+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP
M:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG
M(&9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"X`66]U(&AA
M=F4@=&\@96YT97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E
M(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@
M8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N`%EO=2!M=7-T(&1E<V-R:6)E('1H
M92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P
M;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P
M;VEN=',@=&\`66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE
M=&5D+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T
M+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@
M;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P
M96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF
M>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W
M(&-A=&5G;W)Y(&YA;64N`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@
M4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&
M<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@
M061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO
M=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@
M;75S="!L;V=I;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@875T:&5N=&EC871I
M;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@
M>6]U('=I<V@@=&\@=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O
M=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT(&%U=&AE;G1I8V%T:6]N
M(&)A8VME;F0N`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO
M="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B
M965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!B<F]W
M<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI
M;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I
M='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R;W=S97(@9&]E<R!N
M;W0@<W5P<&]R="!T:&ES(&9E871U<F4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO
M="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O
M;6UA;F0@*R!0('1O('!R:6YT+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9
M;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"X`66]U<B!D
M969A=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!L;V=I;B!H
M87,@97AP:7)E9"X`66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9
M;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO
M;B!O9B!T:&ES('-E<W-I;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D
M871E9"X`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W
M;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@
M:6X@=VET:"!Y;W5R(&YE=R!P87-S=V]R9"X`66]U<B!P87-S=V]R9"!H87,@
M97AP:7)E9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`675G;W-L879I80!:86ER
M90!:86UB:6$`6FEM8F%B=V4`6U!R;V)L96T@4F5P;W)T70!;;&EN92`E<R!O
M9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]$96QE=&4@4F]W`%]'<F]U<',`7TAE
M;'``7TEM86=E(%!R;W!E<G1I97,N+BX`7TQO9R!I;@!?3&]G(&]U=`!?36]D
M:69Y($QI;FLN+BX`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN
M:RXN+@!?4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`7U5S97)S`&%D9')E
M<W,@8F]O:P!A9&1R97-S964@=6YK;F]W;@!C86QE;F1A<@!C86YN;W0@8W)E
M871E(&]U='!U="!F:6QE`&-A;FYO="!O<&5N(&EN<'5T`&-L:6-K(&AE<F4`
M8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R`&-O;F9I9W5R871I;VX@97)R;W(`
M8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9P!D871A(&9O<FUA="!E<G)O
M<@!E9&ET`&5N=')Y(&YO="!F;W5N9`!F:6QE`&AO<W0@;F%M92!U;FMN;W=N
M`&EN<'5T+V]U='!U="!E<G)O<@!I;G1E<FYA;"!S;V9T=V%R92!E<G)O<@!N
M86UE`&YO="!I;7!L96UE;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P
M860`<&5R8V5N=`!P97)M:7-S:6]N(&1E;FEE9`!P:7AE;',`<F5M;W1E(&5R
M<F]R(&EN('!R;W1O8V]L`'-E<G9I8V4@=6YA=F%I;&%B;&4`<VAO=R!D:69F
M97)E;F-E<P!S>7-T96T@97)R;W(`=&%S:R!L:7-T`'1E;7!O<F%R>2!F86EL
M=7)E`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YN86UE
M9`!V0V%R9`!0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,2XP"E!/5"U#
M<F5A=&EO;BU$871E.B`R,#`V+3`S+3`V(#$R.C0W*S`Q,#`*4$\M4F5V:7-I
M;VXM1&%T93H@,C`P-BTP,RTR,B`Q,CHP,"LP.3`P"DQA<W0M5')A;G-L871O
M<CH@2&ER;VUI($MI;75R82`\:&ER;VUI0'1A8RYT<W5K=6)A+F%C+FIP/@I,
M86YG=6%G92U496%M.B!*87!A;F5S92`\=6YK;F]W;D!U;FMN;W=N+F1O;6%I
M;CX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN
M.R!C:&%R<V5T/5-(24947TI)4PI#;VYT96YT+51R86YS9F5R+45N8V]D:6YG
M.B`X8FET"@`@*"5S()/ZD4\I`(-!@TZ#6H-8@TR#0R`E<P"!:25S()/Z@LR3
MX(+)@6H`("B-H9/Z*0"!:9:^D_J!:@`@*(WPD_HI`"<E<R<@@LV#9H-"@XR#
M3H-G@XJ!6X+%@LV"H(+H@MR"N8+Q@4(`(B5S(B""S9"S@K6"HI%)D?""Q8+-
M@J""Z(+<@KF"\8%"`"(E<R(@@LT@2&]R9&4@@XR#5X-8@V>#BH+)D-V2Z(*S
M@NJ"Q(*B@MR"N8+Q+@`B)7,B((-C@XJ!6Y5<CJ:+0)1<@JJ,J95T@JF"Z(+<
M@KF"\8%"`"(E<R(@@JJ#3X.+@5N#=H-6@UB#98.`@LF2QXG!@K."ZH+<@K6"
MO8%"`"(E<R(@@JJ#08-.@UJ#6(R@@U:#6(-E@X""R9+'B<&"LX+J@MR"M8*]
M+@`B)7,B((+-C>R0K(*S@NJ"W(*Y@O&"Q8*U@KTZ("5S+@"799?*("4R)"XR
M9DU"()*&@LP@)3$D+C)F34(@CF>7<"@E,R0N,F8E)2D`)60@)7,@@L8@)7,`
M@W"#6(./@5N#:(+-@J""QB`E9""3^I=,C/B"Q8*W@4(`DLJ2;2`M("5S`"5S
M()-DCG&.=Y;D`"5S($M"`"5S()7;CN>1@(WL@LR*;91&`"5S((+,D-V2Z``E
M<R"#5(-#@Y.#08-B@W8`)7,@DZ^(TX_PC8``)7,@@LV*^8+)D;:-W8*U@MR"
MMX%"`"5S((+-CI^"R8YWDNB"LX+J@L2"HH+IE=N.YY&`C>R"\([`C7."MX+I
MCX"4]8*JD*Z"HH+<@K6"O8%"CL"-<X*U@KV"HI&`C>R"S(-[@V*#3H-8@O"#
M8(-&@V*#3H*U@L2"K8*^@K."HH%"`"5S((*JE4N7=H+%@K<`)7,@E:H`)7,@
M@JJ"H(+H@MR"N8+Q@4(`)7,@@JF"YR`E<X%!C8>,=B`E<P`E<R""S(-!@VB#
MC(-8DJ``)7,@@LR77)+HE5P`)7,@@LR#@8."DJ``)7,@@LR#7H-8@TZ#BH-8
M@V<`)7,Z("5S`"5S.B""L8+,@X&#8H-:@5N#5X+-CJ:"LX+J@L2"HH+ID9>0
M38[2@JF"YX+,@N""S(+%@LV"R(*B@L:.=H+M@NJ"W(*W@4*"NX+,DH:"S(.*
M@Y.#3H+P@TZ#BH-B@TZ"M8*]@NB!08S"D&R/[I7Q@O"1EY!-@K>"Z8+,@LV/
M7)6J@LF2C8C3@K6"Q(FZ@K."HH%"`"TM()%)D?`@+2T`,3*.GHK4C&".K@`R
M-(Z>BM2,8(ZN`#(T((Z>BM0`/)%/@LR#>8%;@U<`@K&"S(-U@XV#8H-.@LF"
MS8-F@5N#7H-X@5N#6(*JE4N7=H+%@K>!0@"2=I:]DTF"R(-'@XF!6X*JE*V0
MMH*U@MR"M8*]`%!'4(SVBDJ,KH*J@X&#8H-:@5N#5X+,B,.-AHF[@LF52Y=V
M@L6"MX%"`%!'4(SVBDJ,KH*JCY"6O(*S@NJ"O8.!@V*#6H%;@U>"S(R?C]B"
MR95+EW:"Q8*W@4(`4$=0C/:*2HRN@4%01U"4Z9:GC*Z"J(+F@M&#<(-8@W2#
MC(%;@UF"JHC#C8:)NX.!@V*#6H%;@U>"S)6<C8:"R95+EW:"Q8*W@4(`4$=0
MC/:*2HRN@4%01U"4Z9:GC*Z"J(+F@M&#<(-8@W2#C(%;@UF"JH.!@V*#6H%;
M@U>"S(^0EKR"R95+EW:"Q8*W@4(`4R]-24U%C/:*2HRN@4%3+TU)3464Z9:G
MC*Z"J(+F@M&#<(-8@W2#C(%;@UF"JHC#C8:)NX.!@V*#6H%;@U>"S)6<C8:"
MR95+EW:"Q8*W@4(`4R]-24U%C/:*2HRN@4%3+TU)3464Z9:GC*Z"J(+F@M&#
M<(-8@W2#C(%;@UF"JH.!@V*#6H%;@U>"S(^0EKR"R95+EW:"Q8*W@4(`4R]-
M24U%C/:*2HRN@JJ#@8-B@UJ!6X-7@LR(PXV&B;N"R95+EW:"Q8*W@4(`04TO
M4$T`@K&"S(-'@V:#0H->@5N"R8+"@J*"Q`!61E.#9H-"@XR#3H-G@XJ"S(WL
MD*R"S8-!@TZ#6H-8BY&4VX*S@NJ"W(*U@KV!0@!61E.#=(-`@T.#BX+,C>R0
MK(+-@T&#3H-:@UB+D93;@K."ZH+<@K6"O8%"`(-!@TJ#18.3@V>/[I7Q`(-!
M@TJ#18.3@V>"S(-P@UB#CX%;@V@`@T&#2H-%@Y.#9X+-DX",BX*S@NJ"Q(*B
M@MR"MX%"`(-!@TJ#18.3@V<`DL>)P0"#5(-U@T^#BX%;@W:"\)+'B<$`@U2#
M=8-!@TZ#6H-8C*""\)+'B<$`@K&"L8+)DL>)P3H`D%:"M8*B@T^#BX%;@W:"
M\)+'B<$`D%:"M8*B@O"#08-.@UJ#6(R@@O"2QXG!`(-4@W6#3X.+@5N#=H+P
M("(E<R(@@LF2QXG!`(-4@W6#08-.@UJ#6(R@@O`@(B5S(B""R9+'B<$`D%:+
M2X.&@5N#58+PDL>)P8%&`)?Q@O"2QXG!`)!6BTN#@8.3@V^"\)+'B<&!1@"#
M>8-!@O"2QXG!`"5S((.!@VJ#A8%;@O`@36]Z:6QL82""S(-4@T.#:(-O@5N"
MR9+'B<&"MX+I`(-!@VB#C(-8DJ""R9+'B<$Z`(Z$@LR"S(-!@VB#C(-8DJ""
MR9+'B<$`@X:!6X-5@O"2QXG!`(-6@UB#98.`@LD@(B5S(B""\)+'B<&"M8+<
M@K6"O8*J@4&#5(-#@Y.#08-B@W:"S(_NE?&"JI+'B<&"Q8*K@MR"N8+Q@L6"
MM8*]@48E<P"#5H-8@V6#@(+)("(E<R(@@O"2QXG!@K6"W(*U@KV"S(+%@4&#
MC8-/@T.#DX+%@JN"W(*W@4(`@X:!6X-5@LR2QXG!CXB7G8+-EK.,^(+)@LB"
MP8+$@J*"W(*W@4(`CUJ/B@"#08-H@XR#6)*@`(K'EYT@+2"1O(+,@X:!6X-5
M@LR#08-.@UJ#6(R@`(K'EYT`061S`(-!@W2#2X-J@UB#7H.3`(-!@XN#;X-J
M@T$`@T&#BX-7@T:#BH-!`)7*EKP`B,J2=9&U@J:!1@"14Y64`)%3E$:/V(.&
M@5N#50"14X+$@LR#3X.+@5N#=@"14X+$@LR#08-.@UJ#6(R@`)6AD)2"S(-!
M@VB#C(-8@O"+EHG"`)34C8:5=(*K@XJ#6(-G@O"0W9+H@L6"JX+I@N:"I(+)
M@K6"W(*W@JF!2`"*^8+)D;:-W8*U@MR"MP"1XY'6@LP@24U34""#C8-/@T.#
MDP"1XY'6@LP@24U34""#<(-8@X^!6X-H`)'CD=:"S"!)35-0((.&@5N#59:\
M`)'CD=:"S(.!@5N#BX-!@VB#C(-8`)'CD=:"S(-E@Y.#=H.,@5N#9P"1XY'6
M@V6#3(-8@V>!1@"#08.!@XJ#2I?,@U2#@H-!`)5SD+."R))L@JJ.=Y+H@K."
MZH+$@J*"W(*W`)=<BOJ"M8+(@J*#1X.)@5N"JI2MD+:"M8+<@K6"O0"#08.3
M@VB#B0"#08.3@U.#B8NDF&&-D0"#08.3@T^#0H.)`).]EKR#=H.-@TR#5H%;
M`).:@J8`D^R+R8%ID>67I(%J`(-!@Y.#98-"@T^#08%%@V^!6X-U@5N#7P"#
M08-V@XJ#4(%;@U:#AX.3`(-!@W:#BH-0@5N#5H.'@Y.(ZI>7`(-!@W:#BH-0
M@5N#5H.'@Y..9Y=PB<(`B;J(RH+,BZ273(+)DTN7<`"/LY1&`(*H@JB"YH*[
M@LR#5(-#@UD`@E.,C@"#08%;@TJ#0X-U@W2#0(-#@XN#5(-#@UD`@T&!6X-*
M@T.#=9:\`"5S((+,@U2#0X.3@T&#8H-VEW:+@8+PEGN3EH+)C>V/G(*U@L2"
MHH*B@L6"MX*I@4@`EGN3EH+)("(E<R(@@L:#5(-U@T^#BX%;@W:14X+$@O"-
M[8^<@K6"Q(*B@J*"Q8*W@JD_`(-!@XN#6X.3@V"#DXNDF&&-D0"#08.+@X&#
M:H-!BZ2888V1`(-!@XN#;P"#08-:@Y.#5H.'@Y.3AP"#08-7@T&!7I&^E;V7
M;9)NB.8`E=N.YXWLB\:"S([`C7.13X+)BFV41H+PBX&"WX+I@N:"I(+)@K6"
MW(*W@JF!2`"1MHW=@K6"R(*B@T^#BX%;@W:"\(WMCYR"M8+F@J2"QH*U@MR"
MM8*]@4(`D;:-W8*U@LB"HH-!@TZ#6H-8C*""\(WMCYR"M8+F@J2"QH*U@MR"
MM8*]@4(`D;:-W8*U@LB"HH-!@TZ#6H-8C*""\)72CU>"M8+F@J2"QH*U@MR"
MM8*]@4(`D;:-W8*U@LB"HHNDETR"\)72CU>"M8+F@J2"QH*U@MR"M8*]@4(`
MD:Z0JP""5XR.`(-)@5N#6(-G@XF#BH-!`(-)@5N#6(-G@XJ#08NDF&&-D0!!
M=71H7V-Y<G-Q;#H@E4N7=H+(24U!4(IGDJ.+0)1<@JJ,J8+"@JF"Z(+<@KF"
M\8%"`$%U=&A?8WER=7,Z((-O@V*#3H-'@Y.#:(+-E4N7=H+(E%R7S8+PETR"
MM8+$@J*"W(*Y@O&!0@!!=71H7V-Y<G5S.B"7=HN!@K>"Z6EM87"*9Y*C@JJ,
MJ8+"@JF"Z(+<@KF"\8%"`$%U=&A?9G1P.B!&5%"*9Y*CBT"47(*J@MV"PH*I
M@NB"W(*Y@O$N(%!(4(+P("TM96YA8FQE+69T<""#28-V@U:#AX.3@O""PH*O
M@L2#4H.3@W"#0X.+@K6"R(*H@K6"Q(*M@KZ"LX*B@4(`075T:%]I;6%P.B!)
M34%0BF>2HXM`E%R"JHRI@L*"J8+H@MR"N8+Q@4(`075T:%]K<F(U.B!K<F(U
MBF>2HXM`E%R"JHRI@L*"J8+H@MR"N8+Q@4(`075T:%]L9&%P.B!!8W1I=F4@
M1&ER96-T;W)Y((+%@LR#AH%;@U62QXG!@LV#5(-\@5N#9X*S@NJ"Q(*B@MR"
MN8+Q`$%U=&A?;&1A<#H@06-T:79E($1I<F5C=&]R>2""Q8+,@X:!6X-5C>V/
MG(+-@U2#?(%;@V>"LX+J@L2"HH+<@KF"\0!!=71H7VQD87`Z($Q$05"*9Y*C
MBT"47(*JC*F"PH*I@NB"W(*Y@O&!0@!!=71H7VQD87`Z((.&@5N#52`E<R""
M\)+'B<&"Q8*K@MR"N8+Q@4*#5(%;@V^"S(F>DYHZ(`!!=71H7VQD87`Z((.&
M@5N#52`E<R""\(WMCYR"Q8*K@MR"N8+Q`$%U=&A?;&1A<#H@@X:!6X-5("5S
M((+PC5B05H+%@JN"W(*Y@O$`075T:%]L9&%P.B!!8W1I=F4@1&ER96-T;W)Y
M((+%@LR#AH%;@U6-6)!6@LV#5(-\@5N#9X*S@NJ"Q(*B@MR"N8+Q`$%U=&A?
M;6-A;#H@34-!4(IGDJ.+0)1<@JJ,J8+"@JF"Z(+<@KF"\8%"`$%U=&A?<VUB
M875T:#H@<VUB875T:(IGDJ.+0)1<@JJ,J8+"@JF"Z(+<@KF"\8%"`$E-05"#
M5(%;@V^"Q8+,E$:/V(+)CKB4<X*U@MR"M8*]@4(`E$:/V(+)CKB4<X*U@MR"
MM8*]`)1&C]B"R8ZXE'."M8+<@K6"O8%")7,`4D%$2553@U2!6X-O@LF"YH+H
ME$:/V(*JBY&4VX*S@NJ"W(*U@KV!0@!&5%"#5(%;@V^"S)1&C]B"R8ZXE'."
MM8+<@K6"O8%"`%--0H-4@5N#;X+,E$:/V(+)CKB4<X*U@MR"M8*]@4(`CF>7
M<(G"E%R"R(-T@T*!6X.+@VB!1@"#08-;@XN#;X-#@U>#@X.3BZ2888V1`)1W
MC&D`E'>,:9!&`$ME<F]B97)O<R"#<(-8@X^!6X-H@JJ6LXSX@L6"MX%"`$ME
M<F]B97)O<R"#AH%;@U66O(*JEK.,^(+%@K>!0@"#;X-N@WT`@V^!6X.,@5N#
MDP"#;X.3@T^#B8-F@U:#A9!LEJ^+I)AAC9$`@V^#BX-O@VB#6`"*[I9[@T^#
MB8-T@T*#3H-8@LR#9H-"@XR#3H-G@XJ!6R`B)7,B((*J@J""Z(+<@KF"\8%"
M`(KNCX"0_`"#>(.)@XN!6X-6BZ2888V1`(-X@XN#38%;`(-X@XJ!6X-9`(-X
M@VF#DXNDF&&-D0"#;X-^@X6!6X-?@6F/E).'@6H`@W6!6X->@Y.)I(V1`))A
MD+:3^@"#=8.-@V*#3B`B)7,B((+,@T&#=H.*@U"!6X-6@X>#DR`B)7,B((*J
M@J""Z(+<@KF"\8%"`(-U@XV#8H-.D-V2Z`"#=8.-@V*#3H->@T.#=@"1OHZ:
M`(-[@XJ#<H-!BZ2888V1`(-U@V*#3H-]@5N#3@")CP")CX+,D;Z"LX%&`(F/
M`(-[@UB#:H-!@46#=X.+@V.#1H-3@W*#:0"#>X-C@X^#:8NDF&&-D0"#=8%;
M@WB3AP"#=8.)@U>#BP")<)?,@T.#DX-HCY23AP"#=8.+@VR#0X%%@U^#BX-4
M@XF!6X.``(-U@XN#2X.*@T$`B=./\(^1@JL`@W6#BX-,@VF#=(-`@UP`@W6#
MBX.3@U>+I)AAC9$`0TU3`$-20P!#4DP@E'J5>H-\@T.#DX-G`%]%@UJ#BY&N
MD*LN+BX`@TR#@X-B@U:#A8+,CXF*^HF[@JJ*KI>Y@K6"W(*Y@O&"Q8*U@KV!
M0@"77)+HE5P`@TJ#DX-[@U>#00"#2H.!@XN!6X.3BZ2888V1`(-P@UB#CX%;
M@VB"S8ZIDZZ"Q8+-@XJ#6H-B@V>"Q8*K@MR"N8+Q@4**QY>=CM*"R9A!EXV"
MM8+$B;J"LX*B@4(`@W2#0(-#@XL@(B5S(B""R8^1@J^"W(*Y@O&!0@"*3Y64
M@LR#6H-B@U:#AX.3@VZ#DX-H@XF!6X+-BL>7G8+%@JN"W(*Y@O&!0@!)34%0
M((-4@5N#;X+)D-J1L8+%@JN"W(*Y@O&"Q8*U@KTZ("5S`(-T@T"#0X.+("(E
M<R(@@JJ*2H*O@MR"N8+Q@4(`@TJ#:8-?`(-,@X.#DX-:@XL`C^&*497QC9""
M\(-,@X.#DX-:@XN"MX+I`(-T@T"#0X.+("(E<R(@@O"-[8^<@L6"JX+<@KF"
M\8%"`(WLB\:#9H-"@XR#3H-G@XJ"JHRIE72"J8+H@MR"N8+Q@4(`)W1A<F=E
M=$9I;&4G((-P@XF#@8%;@UZ"R(*U@L6"S9&QC7."Q8*K@MR"N8+Q@4(`@V:#
M0H.,@TZ#9X.*@5L@(B5S(B""\(WMCYR"Q8*K@MR"N8+Q@4(`C>V/G(+%@JN"
MW(*Y@O&!0HYQD;>"JB`E9""1MHW=@K6"W(*W@4(`E<""UY'6@J:"S)'.C]N"
MS)"4@JJ5VY&V@K."ZH+$@J*"Z9"4@L:-AX+M@LB"HH+,@L65P(+7D=:"IH*J
M@L6"JX+<@KF"\8%"`(YWDNB"LX+J@KV4U(V&@LF#@8-B@UJ!6X-7@O"4>I&7
M@L6"JX+<@KF"\8+%@K6"O8%"`(-*@5N#?(-X@XN#9HNDF&&-D0"57)'H`(-,
M@X.#BH-!`)6JE]Z"QH.)@WB#BP"#4(-#@WV#DX^4DX<`C&>1T9-DF&(`@UJ#
MBY&ND*L`@UJ#BY:$D9"!1@"#6H.+D:Z0JP"#6H.+EUV4DH%&`(QGD=&39)AB
M`)*&B9L`DH:)FX-!@W2#BH-*BZ2888V1`(_8EKZ/D8+,C]J-UP"/V):^CY&"
MS(^*ETR.T@"/V):^CY&#?(.*@U:!6P"#8(.#@VB+I)AAC9$`E<^-6`"#<(-8
M@X^!6X-H@O"5SXU8`)-DCG&#@8-#@XN"R8YGEW""MX+IEKR13X+&@T&#:(.,
M@UB"\)7/C5B"M8+<@K>!0@",NXW=@LR0W9+H@L6"S8-P@UB#CX%;@VB"S)7/
MC5B"\(-4@WR!6X-G@K6"Q(*B@MR"N8+Q@4**QY>=CM*"R9A!EXV"M8+$B;J"
MLX*B@4(`7TN#BH.3@TZ"\(-@@T:#8H-.+BXN`(-@@XJ+I)AAC9$`DH:)V)!L
MEJ^+I)AAC9$`@T&#=H.*@U"!6X-6@X>#DY%)D?"!1@"#<(-8@X^!6X-H@O"1
M29'P`(.&@5N#59:\@O"129'P`)/ZE7257(ZFC&".KH%&`(-.@XJ#6(-]@UB3
MAP"#3H.)@UB2Z(M@("5S((*JC*F5=(*I@NB"W(*Y@O&!0@!-4RU/9F9I8V6"
MS(->@T^"\([F@NB/G(*M`(R?C?6/P8N.`(.&@5N#58+,D=Z+CH%&)7,`@X:!
M6X-5C\&+C@"#AH%;@U6#9H%;@UZ/P8N.`(-.@XJ#8H-.@K>"Z8+&CI^"U@"#
M18-"@Y.#:(-%@O"5PH*V@ND`@U*#4H-8CY23AP"#5(-#@VB#;X%;@O"/](+>
M`(-2@XV#DX-R@T&+I)AAC9$`D$8`D$:129'P`)!&D4F1\`"7\8%&`)?Q@UZ#
M0X-G@XL`@U*#?H-B@TZ#6`"#4H-]@Y.#:`"#4H-]@Y.#:(-6@T:#BP"#4H.!
M@Y.#9P"+I)+*EKP`@U*#@H.-F$&-AP")[X[0`)#=DNB"S(VWE:H`4$1!@4&#
M6(-]@5N#9X-T@TB#DX%!3W5T;&]O:X+&@LR3KXKZ@O"0W9+H@K6"W(*W@4(`
MD-V2Z(+-C]R6H8KZC,"0V(+J@L6"MX%"`"5S((+PD-V2Z(*W@ND`@W"#6(./
M@5N#:(+PBFV41@"#4H.3@U.+I)AAC9$`@U*#DX-3EJ^.Y8NDF&&-D0"0VI&Q
MCKB4<X%"`)#:D;&.N)1S@48`C/:/3XRN@U2!6X-O@M:"S)#:D;&"JHN1E-N"
MLX+J@MR"M8*]@4(`C/:*2HRN@U2!6X-O@M:"S)#:D;&"JHN1E-N"LX+J@MR"
MM8*]@4*7G9=2@48E<R`H)7,I`$944(-4@5N#;X+6@LR0VI&Q@LF.N)1S@K6"
MW(*U@KV!0@"809>-D.8`F$&7C9#F@LV#08-H@XR#6)*@@LF2QXG!@K."ZH+<
M@K6"O8%"`(BSCVN#=(-`@T.#BX+,@U*#DX-E@Y.#8X->@T.#=H%&`"(E<R(@
M@LR3X)=E`)&Q@JT`@TZ#8H-.CY23AP"#4H-S@5L`@U*#<X%;CKB4<X%&)7,`
MD4F1\)3-B,V"\(-2@W.!6P"#4H-8@UZ#BH-*BZ2888V1`(-2@5N#9X-7@WN#
MCX%;@XN+I)AAC9$`@X&#8H-:@5N#5X+,(%!'4""(PXV&B;N"JH+%@JN"W(*Y
M@O&"Q8*U@KV!0@"#@8-B@UJ!6X-7@LP@4$=0((^0EKR"JH+%@JN"W(*Y@O&"
MQ8*U@KV!0@"#@8-B@UJ!6X-7@LP@4R]-24U%((C#C8:)NX*J@L6"JX+<@KF"
M\8+%@K6"O8%"`(.!@V*#6H%;@U>"S"!3+TU)344@CY"6O(*J@L6"JX+<@KF"
M\8+%@K6"O8%"`)A!EXV0YH+PDL>)P8+%@JN"W(*Y@O&"Q8*U@KV!0B5S`$Q$
M05`@@U2!6X-O@LF#;X-#@Y.#:(+%@JN"W(*Y@O&"Q8*U@KV!0@".8XV"@JJ*
M;91&@L6"JX+<@KF"\8+%@K6"O8%")7,`3$1!4""#5(%;@V^"R9#:D;&"Q8*K
M@MR"N8+Q@L6"M8*]@4(`1E10((+%@U2!6X-O("(E<R(@@LF0VI&Q@L6"JX+<
M@KF"\8+%@K6"O3H@)7,`D9>039#F@XJ#6(-G@JJ-[)"L@L6"JX+<@KF"\8+%
M@K6"O8%")7,`4$=0((-F@5N#7H+,E9R-AHF[@JJ"Q8*K@MR"N8+Q@L6"M8*]
M.@!3+TU)344@@V:!6X->@LR5G(V&B;N"JH+%@JN"W(*Y@O&"Q8*U@KV!0@"8
M09>-D.:"JHWMCYR"Q8*K@MR"N8+Q@L6"M8*]@4(E<P"1EY!-D.:#BH-8@V>"
MJHWMCYR"Q8*K@MR"N8+Q@L6"M8*]@4(E<P"0W9+HC5B05I=P@UB#3H.*@W:#
M9R`B)7,B((+PC>V/G(+%@JN"W(*Y@O&"Q8*U@KV!0@".\Y!-CM*"S)-DCG&#
M@8%;@XN#08-H@XR#6(*JBFV2Z(+%@JN"W(*Y@O&"Q8*U@KV!0@"#08-H@XR#
M6)*@@JJ*KI%3@LF"S8[FD[Z"Q8*K@MR"N8+Q@L6"M8*]@4(`D9>039#F@XJ#
M6(-G@JJ*KI%3@LF"S8[FD[Z"Q8*K@MR"N8+Q@L6"M8*]@4(`D9>039#F@XJ#
M6(-G@JJ*KI%3@LF"S8[FD[Z"Q8*K@MR"N8+Q@L6"M8*]@4(`@UB#9X.)@V6#
M5X%;("(E<R(@@O"#C8%;@VB"Q8*K@MR"N8+Q@L6"M8*]@4(`36MD:7(@(B5S
M(B""R8ZXE'."M8+<@K6"O8%"`(SVBDJ,KH+PC*Z#5(%;@V^"J8+GCN:3OH+%
M@JN"W(*Y@O&"Q8*U@KV!0@`B)7,B((+PCY&"JXV>@MV7<(+)@TF!6X-V@Y."
MQ8*K@MR"N8+Q@L6"M8*]@4(`)7,@@O"#28%;@W:#DX+%@JN"W(*Y@O&"Q8*U
M@KV!0@"5VX[GC>R+QH."@U>#A8%;@XL@)7,@@O"*2H*O@MR"N8+Q@L6"M8*]
M@4(`@V:#0H.,@TZ#9X.*@5L@(B5S(B""JHI*@J^"W(*Y@O&"Q8*U@KV!0@!,
M1$%0((-4@5N#;X+)D-J1L8+%@JN"W(*Y@O&!0@`E<R""JI/'@MV/;X*Y@MR"
MN8+Q@4(`EW:+@8*S@NJ"O8.&@5N#58+,@W"#6(./@5N#:(+P@XJ#6H-B@V>"
MQ8*K@MR"N8+Q@L6"M8*]@4*"HH*M@L*"J8*@@NF"HH+-D5."Q(+,C^Z5\8+-
MBM2(X8+!@L2"HH+<@K>!0HW$DWB.CH*U@L2"W8+I@JF*QY>=CM*"R9A!EXV"
MM8+$B;J"LX*B@4(`04-,((+PCN:3OH+%@JN"W(*Y@O&"Q8*U@KT`@T&#:(.,
M@UB2H(+PCN:3OH+%@JN"W(*Y@O&"Q8*U@KV!0B5S`)&7D$V0YH.*@UB#9X+P
MCN:3OH+%@JN"W(*Y@O&"Q8*U@KV!0B5S`)&7D$V0YH.*@UB#9X+PCN:3OH+%
M@JN"W(*Y@O&"Q8*U@KV!0B5S`(-4@5N#;X+,BT"47(CJEY>"\([FD[Z"Q8*K
M@MR"N8+Q@L6"M8*]`)#=DNB"\(RS@LF6WX*Y@MR"N8+Q@L6"M8*]@4(`(B5S
M(B"#9H-"@XR#3H-G@XJ!6X*JC>V/G(+%@JN"W(*Y@O&!0@`E<R"0W9+H@O"5
MVY&V@L6"JX+<@KF"\8+%@K6"O8%"`)#=DNB"S(-O@V*#3H-!@V*#=H+PE=N1
MMH+%@JN"W(*Y@O&"Q8*U@KV!0@"0W9+H@LR#;X-B@TZ#08-B@W:"\)7;D;:"
MQ8*K@MR"N8+Q@L6"M8*]@48E<P"0W9+HC5B05I=P@UB#3H.*@W:#9X+P("(E
M<R(@@LF5VY&V@L6"JX+<@KF"\8+%@K6"O8%"`)#=DNB"S(-O@V*#3H-!@V*#
M=H-T@T"#0X.+("5S((+PE=N1MH+%@JN"W(*Y@O&"Q8*U@KV!0@"0W9+H@W2#
M0(-#@XL@)7,@@LF5VY&V@L6"JX+<@KF"\8+%@K6"O8%")7,@@LF6WX+!@L25
MVY&V@TF#=H-6@X>#DX+PCL"-<X*W@NF"J8%!CNB"Q8*Q@LR)YI;*@LR#4H%;
M@VB"\"`E<R""R8-2@W.!6X*U@L2)NH*S@J*!0@!,1$%0((-4@5N#;X*JC)^-
M]8+%@JN"W(*Y@O&!0@`B)7,B((+PC>V/G"AU;FQI;FLI@L6"JX+<@KF"\8+%
M@K6"O8%"`)A!EXV0YH+PC5B05H+%@JN"W(*Y@O&"Q8*U@KV!0B5S`)&7D$V0
MYH.*@UB#9X+PC5B05H+%@JN"W(*Y@O&"Q8*U@KV!0B5S`"(E<R(@@LR0W9+H
M@JJ/D8*KC9Z"WX+<@KF"\8%&)7,`36]Z:6QL82""S(-4@T.#:(-O@5N"JHRI
ME72"J8+H@MR"N8+Q@4*#5(-#@VB#;X%;@O"*2H*B@L2)NH*S@J*!0@"-D0"-
M[)"L`)!6BTN-[)"L`(-4@W6#=(-(@XN#7X+PC>R0K`"-[)"LCM*"S(-!@TZ#
M6H-8C*``@TZ#C(-7@V*#9X-*@5N#:)34C88`@TZ#C8-!@V"#08NDF&&-D0"#
M3(.%@5N#;XNDF&&-D0",NXW=@LR#6H-B@U:#AX.3`(R[C=V"S(Z>BM0`C+N-
MW8+,(%523"""S0",NXW=@LR#AH%;@U6!6P`E<R""UH+,@XV#3X-)@Y..GH+)
MCL"-<X*W@NF#7H-8@TZ"\)#=DNB"M8+<@K>!0@"0V(+HCN:"Z`"129'PE,V(
MS8+PD-B"Z([F@N@`@TR#=H.-@UB+I)AAC9$`@V"#1H-2BZ2888V1`)/Z`):(
MD_H`1&%T851R964@B7N7EP"#9H%;@UZ#>(%;@UB.48_&`)/ZE70`@V:!6X->
MCO.030"3^I5TD4F1\`!?3)?Q@LR-[8^<`#$RC(X`CUR0:9"4`))IB;J"L(+P
MD/."K0"#9H-T@TB#BX-G`(-F@W2#2(.+@V>01@"#9H-T@TB#BX-G($E$`(-F
M@W2#2(.+@V<@<VAE;&P`C>V/G`"#6H.+C>V/G`"#3X.+@5N#=H+PC>V/G`"#
MC8-/@LR-[8^<`(-!@TZ#6H-8C*""\(WMCYP`@UJ#BXWMCYP`E_&"S(WMCYP`
MD>.1UH-E@Y.#=H.,@5N#9X+,C>V/G`"#@8-B@UJ!6X-7@O"-[8^<`"(E<R(@
M@LR#08-.@UJ#6(R@@O"-[8^<`"(E<R(@@LR#08-.@UJ#6(R@@L:"NX+,@U2#
M=8-!@TZ#6H-8C*""\)%3@L2-[8^<@K6"W(*W@JF!2`"-<X+,C>V/G`"129'P
M@K6"O4E$@O"-[8^<`(-4@W6#=(-(@XN#7X+PC>V/G`",NXW=B,J2=8+,E_&"
M\(WMCYP`C+N-W8C*DG6"S(US@O"-[8^<`)#=DNB-6)!6EW"#6(-.@XJ#=H-G
M("(E<R(@@O"-[8^<@K6"W(*U@KV!0@"4>I&7CIZ*U`"#9H.3@WV!6X-.`(_A
MBE&3X)=E@LR0X):^`)#@EKX`C]J-UX%I2&]R9&6"S(.-@T^#=(-`@T.#BX+@
MCE&/QH%J@48`C]J-UX+-BL>7G8[2@LR"O8+?@LF+3)A>@K."ZH+<@K6"O8%"
M`(I*E*T`C;:"J8+GB46"U@")18*I@N>-MH+6`#(TCIZ*U)5<CJ8`E5R.IH-)
M@W:#5H.'@Y,`@U>#=8-@BZ2888V1`(WMCYR"M8+(@J(`;6%I;G1E;F%N8V4N
M<&AP((+)DKR0VH-!@TZ#6H-8@K6"R(*B@L6"K8*^@K."H@"-Q8^)@LR7\8*J
M@W2#0H%;@XN#:):\@O"*W(+Q@L6"HH+<@K>"J3\@@KN"I(+(@N>#8(-&@V*#
M3H*U@L2"K8*^@K."HH%&`(-H@WZ#:H-*`(-H@WZ#:H-*BZ2888V1`(-!@TJ#
M18.3@V>"JI5+EW:"R(+G@U2#0X.3@T&#8H-V@4(`@U^#18.3@XV!6X-H`"5S
M((+,@U^#18.3@XV!6X-H`)"VD*R"LX+J@KV0W9+H@O`@4$A0((-8@TZ#BH-V
M@V>"\(+&@K6"Q(-?@T6#DX.-@5N#:(*W@NF!0@"39(YQ@X&!6X.+`(-'@TZ#
M08-H@XN+I)AAC9$`E=*/5P"#=8.-@V*#3H+,E=*/5P"#3X.+@5N#=H+,E=*/
M5P"#08-.@UJ#6(R@@LR5TH]7`(-!@TZ#6H-8C*""S)72CU<`)7,@@LR#08-.
M@UJ#6(R@@LR5TH]7`(-)@W:#5H.'@Y."S)72CU>!1@`B)7,B((+,@T&#3H-:
M@UB,H(+,E=*/5P`E<R""S(-!@TZ#6H-8C*""S)72CU<`@T>#5X-V@V>!18-!
M@XF#=8NDF&&-D0"#1X.+@U2#BX-O@VB#BXNDF&&-D0"39(YQ@X&!6X.+`$6#
M@8%;@XN#08-H@XR#6`!%@X&!6X.+@T&#:(.,@UB"JHCJDG:"M8+(@J^"ZH+.
M@J*"KX+<@KF"\8%"`$6#@8%;@XN#08-H@XR#6(IME$8`B_.#@8-B@UJ!6X-7
M@L6"MX%"`(F]@N",J8+"@JF"Z(+<@KF"\8%"`(OS@LR,GXWUC.H`@TV#@X.)
M@XJ!6X*I@N>)YI&<@O"1?9/\@L6"JX+I@N:"I(+)@K6"W(*W@JF!2`")18-.
M@XJ#8H-.@L6#@8-J@X6!6X+PE5R.IH*U@MR"MX*I@4@`@T>#9H-"@UZ!6XGF
MELJ"\)'E@JN"K0""H(+(@KV"S(-P@UB#CX%;@VB"\(.*@UJ#8H-G@K>"Z8Z>
M@LR7<)!3@LR"O8+?@LR.OY;B@O"3_)?-@4*7X8*F@LZ!08%U@WF#8H-G@LR6
MO)%/@LV!2(%V@48`B>:1G(+,55),@O"3_)?-`)#4D[F#38-J@T&+I)AAC9$`
M@T>#BH-G@XJ#00"#1X.)@5L`@W6#C8-B@TZ-[)"L@T>#B8%;.B`E<RX`DZ^*
M^H.-@T^"S(WMCYR#1X.)@5LZ("5S+@"3X)=ECN:3OH-'@XF!6SH@)7,N`(-P
M@UB#CX%;@VB-6)!6@T>#B8%;.B`E<RX`@X&!6X.+@T&#:(.,@UB"S(-'@XF!
M6X+%@K>!0@`B)7,B((+,CY&"JXV>@MV#1X.)@5N"Q8*W@4(`@T>#6(-G@VJ#
M08NDF&&-D0"#1X-@@TF#<X-!`(.(@5N#C8-B@W``,365JI:(`#*5JI:(`#,P
ME:J6B``UE:J6B`"#C8-/@T.#DY:(`#,PE:J6B``QE:J6B`".=Y+HDFR"S)?A
M`([`C7,`DU>*2@"#5(-#@VB#;X%;@O"35XI*`"<I)R""\)-7BDH`ETR,^(KZ
MC,``CG>0E`"13XQID$8`D-V2Z(+P($944"""Q8-!@V*#=H.-@5N#:(*W@ND`
M@W:#C(-T@T"#C(.3@UB0W9+H@O".YI.^@L6"JX+<@KF"\8%"`$Q$05`@@U2!
M6X-O@LF0VI&Q@L6"JX+<@KF"\8+%@K6"O8%"`%--0B"#5(%;@V^"R9#:D;&"
MQ8*K@MR"N8+Q@L6"M8*]@4(`(B5S(B""J8+G@LR#4H-S@5N"R8ZXE'."M8+<
M@K6"O8%"`"(E<R(@@M:"S(-2@W.!6X+)CKB4<X*U@MR"M8*]@4(`D%:+2X+,
M(%-!4TP@D-J1L8+)CKB4<X*U@MR"M8*]@4(`(B5S(B""UH+,B-J3KH+)CKB4
M<X*U@MR"M8*]@4(`CN:3OH+)CKB4<X*U@MR"M8*]@48E<P"#=(-(@5N#3H.)
M@Y.#:(^4DX>!:8-]@XN#<H-I@UB/E).'@6H`@W2#1H.-@5N/E).'`))VEKV3
M28-'@XF!6X%&`$9!6`!&05@`@E&,C@"#=(-"@U>!6X^4DX>+I)AAC9$`@W2#
M0(-#@XL`@W2#0(-#@XN0E#H@)7,@@W2#0(-#@XL`@W2#0(-#@XN0E#H@)7,@
M@W2#0(-#@XL`@W2#0(-#@XN#?8-L@5N#5X.#`(-T@T"#0X.+EKP`@W2#0(-#
M@XN129'P`(-T@T"#0X.+@T&#8H-V@XV!6X-H`(-T@T"#0X.+@T&#8H-V@XV!
M6X-H@LV#5(-\@5N#9X*S@NJ"Q(*B@MR"N8+Q@4(`@W2#0H.+@UX`@W2#0H.3
M@XF#DX-HBZ2888V1`(_CC+>"S(R.`(-T@TB#BX-?@5L@)7,@@JJ"H(+H@MR"
MN8+Q`)6VCIJ01@")YI&<@O"#5(-\@5N#9X*U@LB"HH-U@XF#18-5EW``@W"#
M6(./@5N#:(+PEEF"ZH+$@K6"W(*B@MR"M8*]@JF!2`"#=(-(@5N#@`"#=(-(
M@5N#B8.``(O@`)AG`(-T@XF#DX-8BZ2888V1`(-T@XF#DX-8@6F6>XV1@6H`
M@W2#B8.3@UB7S(--@T&#:0"#=(.)@Y.#6)?,@WR#BH-L@U:#00"#=(.)@Y.#
M6)?,B\F3[(^4DX<`C]J"M8*BD."6O@"6GHR.`(Z!EKP`@TN#>X.3BZ2888V1
M`(GFD9R"\([F@NB/;X*W@TV#@X.)@XJ!6P"#38.#@XF#BH%;@48`@TN#DX-R
M@T&+I)AAC9$`)7,@C5R0K(_NE?&"\)"VD*R"MX+I`)"VD*R"LX+J@KV#4H%;
M@V@`@T^#BX-7@T&+I)AAC9$`@VB#0X-CF$&638NDF&&-D0"#2X%;@VF+I)AA
MC9$`@U>#=8.)@XN#7H.+`)"I`(NDDLJ#28-V@U:#AX.3`$=O;V=L92"#?8-B
M@W8`1V]O9VQE((R?C?4`@TV#BH-6@X.+I)AAC9$`@T^#BH%;@Y.#B8.3@V@`
M@T^#C(-I@U\`@T^#BX%;@W:*QY>=`(-/@XN!6X-VEKR"S8OSE)*"Q8+-@LB"
MHH*Q@L8`1W)O=7!?;&1A<#H@@T^#BX%;@W8@)7,@@O"2QXG!@L6"JX+<@KF"
M\8%"@U2!6X-O@LR)GI.:.B``1W)O=7!?;&1A<#H@@T^#BX%;@W8@)7,@@O"-
M[8^<@L6"JX+<@KF"\0!'<F]U<%]L9&%P.B"#3X.+@5N#=B`E<R""\(U8D%:"
MQ8*K@MR"N8+Q`(-/@XN!6X-V`(-/@T&#:(.+@5N#=I.'`(-/@T&#@).'`(-/
M@T&#98-]@XF+I)AAC9$`@TN!6X.3@U>!6Y.'`(-1@UB#9X-!@TZ#6H-8C*``
M@U&#6(-G@W6#8H-.`(--@VJ#08NDF&&-D0"#38-J@T&#<H-4@T6+I)AAC9$`
M@TN#0X-!@VF+I).OBZ2888V1`$A45%`@E$:/V(*J@MV"PH*I@NB"W(*Y@O&!
M0@"#;H-#@V"+I)AAC9$`@VZ#8H-6@X6#08.+@U.#BH-9@X``@W>#8H-?`(-W
M@V*#7P"#;H%;@VB!18-]@TZ#:(-I@XN#:(^4DX<`C8*"LP"#=X.+@W8`E+R+
MA0"#>H%;@X``@XV!6X-]ED")I)*A@6F#;X-@@TJ#DXYSC9&!:@"#>H%;@X``
MCJF1[H+,CUJ/B@"#>H%;@X"#9H-"@XR#3H-G@XJ!6P".J9'N@LR39)ABE-2-
MA@"#>H.3@U>#A8.)@UB+I)AAC9$`C8&-8`!(;W)D90!(;W)D92]+;VQA8CH@
ME7.0LX+((%A-3""#9H%;@UX@)7,@@JJ#@8-B@UJ!6X-7("5S((+%C)^/;X*S
M@NJ"W(*U@KT`2&]R9&4O2V]L86(Z((-)@W6#5X-&@TZ#9R`E<R""R9'.B9Z"
MMX+I@X&#8H-:@5N#5X+-@J""Z(+<@KF"\0!(;W)D92]+;VQA8CH@@TF#=8-7
M@T:#3H-GC%X@)7,@@LV#@8-B@UJ!6X-7("5S((+)@LV"H(+H@MR"N8+Q`$AO
M<F1E+TMO;&%B.B`E<R""S8WMCYR"LX+J@MR"M8*]("(E<R(`2&]R9&4O2V]L
M86(Z(%!(4""*9Y*C("=D;VUX;6PG((*JE4N7=H+%@K<`2&]R9&4O2V]L86(Z
M((-)@W6#5X-&@TZ#9R`E<R""S"!834P@@V.#BH%;@JJ-[)"L@L6"JX+<@KF"
M\0!(;W)D92]+;VQA8CH@)7,@@JJ-[8^<@L6"JX+<@KF"\2`B)7,B.B`E<P!(
M;W)D92]+;VQA8CH@)7,@@LP@34E-12!)1"""JH[FD[Z"Q8*K@MR"N8+Q`$AO
M<F1E+TMO;&%B.B`E<R""QI.OBOJ"Q8*K@MR"N8+Q("(E<R(Z("5S`$AO<F1E
M+TMO;&%B.B"3KXKZ@L6"JX+<@KF"\8%&)7,`2&]R9&4O2V]L86(Z("(E<R(@
M@LV5<Y:^@LB+I)=,@L6"MP"0A96]D/P`@J*"K8+"@LR7\8+PC(N-AX*U@MR"
MMX*I@4@`@W2#0H%;@XN#:"B-<RF"S)"4@LV"HH*M@L*"Q8*W@JF!2`""HH*M
M@L*"S(US@O",BXV'@K6"W(*W@JF!2`"#;H.3@TN#BH%;BZ2888V1`$E-05`@
M@X&!6X.+@WN#8H-.@UB"S(WLD*R"R8ZXE'."M8+<@K6"O3H@)7,`24U!4""#
M@8%;@XN#>X-B@TZ#6(+,C>V/G(+)CKB4<X*U@MR"M8*].B`E<P!)34%0((.!
M@5N#BX-[@V*#3H-8@TZ#2(%;@UZ"S(WLD*R"R8ZXE'."M8+<@K6"O3H@)7,`
M25`@@T&#:(.,@U@`25`@@T&#:(.,@UB"JH*@@NB"W(*Y@O&!0@!)4(-!@VB#
MC(-8@JJ+EHG"@K."ZH*]0TE$4H-U@XV#8H-.D^""R8*@@NB"W(*Y@O&!0@!)
M4)65C;V(X92]@L6"MX%"`(-!@T.#6(.)@Y.#:(NDF&&-D0"#08-#@U*#DX+,
M@MT`)7,@@LR#08-#@U*#DP"#08-#@U*#DX+&@V6#3(-8@V<`242"S):\D4\`
M@N""M8+@D+."M8*ME5R.IH*S@NJ"R(*B@LB"YX%!)7,@@K6"Q)!6@K6"HH-%
M@T.#DX-H@5N"\(I*@J*"Q(FZ@K."HH%"`(+@@K6"X"!);G1E<FYE="!%>'!L
M;W)E<B""\(YG@L&"Q(*B@L2!08-!@T.#4H.3@JJ57(ZF@K."ZH+(@J*"R(+G
M@4&"L8*Q@O"129'P@K6"Q(FZ@K."HH%"`(GFD9R#=H.,@W*#A8%;`(GFD9P@
M55),`(GFD9P@55),.@")YI&<`(-#@Y.#?(%;@V>!08-8@V6#8H-V("5D`(-#
M@Y.#?(%;@V>"LX+J@KV#=(-"@5N#BX-H@48@)7,`@T.#DX-\@5N#9X*S@NJ"
MO8-T@T*!6X.+@VB!1@"*U(CA@L&"O8-!@TZ#5H.'@Y.#4H%;@VB"JI=>@J:"
MYX+J@L2"HH+<@K>!0@"#AH%;@U66O(*I@W"#6(./@5N#:(*JD+."M8*M@J""
MZ(+<@KF"\8%"`(.&@5N#59:\@JF1XY'6@T&#:(.,@UB"JI"S@K6"K8*@@NB"
MW(*Y@O&!0HW$DWB.CH*U@L2"W8+I@JF!08K'EYV.TH+)F$&7C8*U@L2)NH*S
M@J*!0@"2:8FZ@K""\)!;@JT`@T.#DX-H`(S"E<J#AH%;@U4`@T.#DX-H@VR#
M5H-!BZ2888V1`(_NE?$`@T.#DX-T@TB#@8%;@U:#AX.3`%]/C.."ZX+)E_&"
M\)%]D_P`B>:1G(+PD7V3_`"57(+PD7V3_`"#BH.3@TZ"\)%]D_P`7T.13X+)
ME_&"\)%]D_P`C+N-W8C*DG6"S(SC@NN"R9?Q@O"1?9/\`(R[C=V(RI)U@LR1
M3X+)E_&"\)%]D_P`C+N-W8C*DG6"S(SC@NN"R8US@O"1?9/\`(R[C=V(RI)U
M@LR13X+)C7."\)%]D_P`C+N-W8C*DG6"S(SC@NN"R9)IEXZ"\)%]D_P`C+N-
MW8C*DG6"S)%/@LF2:9>.@O"1?9/\`)'CD=:#98.3@W:#C(%;@V>"S)%]D_P`
MD%:"M8*B@W"#6(./@5N#:(+PCO."KX[F@NF#@8%;@XN#08-H@XR#6(+PD_R7
MS8%&`(SC@NN"R8-:@XN"\)%]D_P`D4^"R8-:@XN"\)%]D_P`C.."ZX+)E_&"
M\)%]D_P`D4^"R8-:@XN"\)%]D_P`@X&#8H-:@5N#5X+PD7V3_`",XX+K@LF2
M:9>.@O"1?9/\`)%/@LF2:9>.@O"1?9/\`(SC@NN"R8US@O"1?9/\`)%/@LF-
M<X+PD7V3_`"7<)!3@LR"O8+?@LR.OY;B@LR3FH*F@O"3_)?-@48`B>:1G(+,
MD7V3_(%>E<^-6`"#BH.3@TZ"S)%]D_R!7I7/C5@`D9>039#F@LF1EX+I@KV"
MWX+,CF.-@H*JE7.1JX*U@L2"HH+<@K>!0@".8XV"@JJ5<Y&K@L6"MX%"`)5S
MD+."R"!::7`@@V:!6X->@L6"MX%"`)5SD+."R(-!@W:#BH-0@5N#5H.'@Y."
MQ8*W@4(`EK.,^(+(@V:!6X->@JJ2\8]O@K."ZH+<@K6"O2X`D9>"Z)#F@LR#
M08-H@XR#6(*JE7.0LX+%@K>!0@"5<Y"S@LB#B8-#@UJ#DX-8@TR#0X+%@K>!
M0@"5<Y"S@LB/ZH^*@JJ.=Y+H@K."ZH+<@K6"O8%"`(_CB,J"S(-!@TZ#6H-8
MC*""JI5SD+."Q8*W@4(`E7.0LX+(@W"!6X-G@VF!6TE$@L6"MX%"`)5SD+."
MR)"[E6F#4H%;@VB"Q8*W@4(`E7.0LX+(@W:#C8-G@U*#BX+%@K>!0@"5<Y"S
M@LB.\Y!-CM*"Q8*W@48B)7,B`)5SD+."R(NDETR#28-U@U>#1H-.@V<`E7.0
MLX+(E*V038RS@T&#:(.,@UB"Q8*W@4(`E7.0LX+(=6YI8V]D98-F@5N#7H+%
M@K>!0@"129'P@O"4O9-=`(-#@XF#DX%%@T.#6(.)@X"+I)AAC9$`@T.#B8-.
MBZ2888V1`(-!@T.#BX.)@Y.#:`"#?8.3DX<`@T.#6(.)@T>#BP"4K8USCM(`
MCLZ1S`"#0X->@XJ#08NDF&&-D0"#5X.#@WV#0X-*`()0C(X`D_J6>P"#5X.#
M@5N#5X%;DX<`@XB#BX-?@Y,`@E:,C@""58R.`)&U@J:"Z0"2AHF;D;6"I@"7
MO));D;6"I@"-MI&U@J8`B461M8*F`(-*@U6#=(-8@UZ#DXNDF&&-D0"#28.*
M@U>#:8.+@O"5VY&V@4@`@U"#:H-!BZ2888V1`$ME<F)E<F]S((-4@5N#;X*J
ME$:/V(N1E-N"M8+<@K6"O8%"`(RNC>R0K)/Z`(RNCG>6Y`",KI*W`(RNCNV7
MW@"39(YQC*Z"JH*W@L6"R8SVCT^,KH-4@5N#;X+)D;:-W8*U@MR"MX%"`(-,
M@XJ#;X-8BZ2888V1`)*ID4Z6KX[ECN6+8)!LEJ^+I)AAC9$`D>6*V):OC9$`
M@TZ#18-&@5N#9P"#3(.+@TV#6(NDF&&-D0!?68.,@T.#08-%@V<`C+Z,Z@"#
MB8-)@UB0;):OEJ^.Y8NDF&&-D0")NHRW@LR,C@"13XGQ@LR#C8-/@T.#DSH@
M)7,`D4^)\8+,@XV#3X-#@Y,Z("4R)',@@JF"YR`E,21S`)%/B?&"S(.-@T^#
M0X.3.B""R(*U`(.)@V>#<H-!BZ2888V1`)1ZDG4`@XR#;X-M@Y.+I)AAC9$`
MC;8`@XR#7(-GB:2-D0"#BH-X@XJ#08NDF&&-D0"1Y8.*@W*#08%%@T&#B8-U
MCM")[X[EBV"0;):O@U>#@X-]@5N#<8.*@5N#A`"#BH-Q@V6#DX-6@X6#7H-#
M@Y.,]HV1`(.*@Y.#3@"#@8%;@XN-[)"LEW""R8.!@5N#BX-!@VB#C(-8@LF#
MBH.3@TZ"MX+I`(-F@5N#7H-X@5N#6(CJEY<`@W>#BX-VC8"6VH+PE5R.IH*W
M@ND`E5R"S(CJEY<`@UJ#8H-6@X>#DX+,B.J7EXWLD*R"R8ZXE'.!1B5S`(.&
M@5N#58+,B.J7EXWLD*R"R8ZXE'.!1B5S`(.&@5N#58+,@XJ#6(-G@LV6LXSX
M@LF"R(+!@L2"HH+<@K>!0@"#BH-G@T&#:H-!BZ2888V1`(.-@5N#:)*&+BXN
M`(R[DFZ.GHK4@48`DFZ(YH+&CIZ*U`"/ZH^*`(.-@T^#0X.3`(.-@T^#08-%
M@V<`@XV#3X-#@Y,`@XV#3X-#@Y,@@UZ#6(-.`(.&@5N#59:\@JF#<(-8@X^!
M6X-H@JJ0LX*U@JV"R(*B@KV"WX+)@XV#3X-#@Y."R8ZXE'."M8+<@K6"O8%"
M`(.-@T^#0X.3@LF.N)1S@K6"W(*U@KV!0@"#38.*@U:#@Y6VCIJ!:8^LE;:.
MFH%J`(.)@V6#DY6VCIJ!:8^LE;:.FH%J`(.-@5N#?9"4CIJ!:8^LE;:.FH%J
M`(.+@TZ#6H.3@W6#BX-.D>6,]HV1`(R.`)-9E72"LX+J@KT@35,M5$Y%1B""
MS8-F@5N#7H+PBMR"\8+%@J*"W(*Y@O&!0@"#?8-*@TD`@WV#4(-H@VJ#08N,
M@X:!6X-3@UB#B8-R@T&+I)AAC9$`@WV#7X-+@UB#2H.+BZ2888V1`)-DCG&#
M@8%;@XL`@WV#B8-%@T.+I)AAC9$`@WV#C(%;@U:#00"#@H.+@V:#0H-UBZ28
M88V1`)-DCG&#@8%;@XL`@WV#BX->BZ2888V1`)!&E72"KX*S@NJ"O8.)@WB#
MBX+PD<Z)GH*S@KF"Q)6JE]Z"\(K'EYV"M8+<@K>!0@""4HR.`(-]@5N#5H.#
M@XN/E).'BZ2888V1`(-]@XN#98-"@VJ#3I.'`(-T@T*!6X.+@VB"\(CJDG:"
MLX*Y@L2"HH+<@K<`@X*!6X.*@UZ#:H-!@46#0X-8@XF#@(NDF&&-D0"#@H%;
M@XJ#5H.#@UB+I)AAC9$`@E2,C@"#?8-#@XB#8H-GDX<`@X&#DX-O`(.!@VJ#
MA8%;@X*!6X-H`(-:@XN,BXV'`)9[E;8`@X&#8H-:@5N#5X+-C)^/V(+%@JN"
MW(*U@KV"JH%!CY"6O([2@LR09XRS@LV,GX_8@L6"JX+<@KF"\8+%@K6"O8%"
M`(.!@UR#8H-H`(.!@UR#8H-H("(E<R(@@LV2Z(M@@K."ZH+$@MR"N8+Q`(.!
M@TR#5H-2C8>/3XV1`(-^@TZ#C8-L@U:#09A!EDT`36EM92!4>7!E`%!%05(@
M@W"#8H-0@5N#5X+,($A45%!?4F5Q=65S="""JHRIDY:"O8+H@MR"N8+Q@4(`
MEJ*0W9+H@L6"MX%"@K&"S(-!@W:#BH-0@5N#5H.'@Y."\(YGEW""MX+I@KV"
MWX+)@LV0W9+H@W2#0(-#@XN"\(WLD*R"MX+IE4N7=H*J@J""Z(+<@K>!0@"#
M@8-B@UJ!6X-7($E$((*JC*F3EH*]@NB"W(*Y@O&!0@!014%2((-P@V*#4(%;
M@U>"S"!-86EL((*JC*F3EH*]@NB"W(*Y@O&!0@"#6H-B@U:#AX.3($E$((*J
MC*F3EH*]@NB"W(*Y@O&!0@",C@",9Y'1@X&!6X.+`(]#D+.3^@"#@H.+@VB#
M;XNDF&&-D0"#@H-I@U*,]HV1`(."@Y.#4X.+`):(C(X`@X*#DX-G@UJ#B8-G
MDX<`C(Z7[@"#@H.-@V*#4HFDC9$`B;J"U@"-MH+6`(E%@M8`C^."U@")NH+6
M`(_C@M8`@X*#58.3@W*!6X-.BZ2888V1`(-!@TJ#18.3@V<`@T&#2H-%@Y.#
M9X_NE?$`@WZ#@X.3@WV!6YA!EDT`DZ^(TX*U@MR"N8+Q`):\D4\`@VF#?H-R
M@T&+I)AAC9$`@VF#18.+BZ2888V1`(-L@W"!6X.+B:2-D0"#28.)@Y.#7XFD
MC9$`@TF#B8.3@U^7S(-!@Y.#98-"@XN/E).'`(-L@V*#9X./@5N#3@""R(*U
M`(-T@XF#DX-8E\R#:H.%@5N#2H.,@VB#:H-!`)!6BTN5JI?>`)!6C(X`D%:"
MM8*B@X:!6X-5EKPHE$.(TRD`@VJ#A8%;@U>!6X.)@Y.#:`"05H*U@J*#<(-8
M@X^!6X-H`)!6@K6"HH-P@UB#CX%;@VB"S2`E>"""R8KZC,"0V(+J@LF"R(+H
M@MR"MX%"`)!6@K6"HH-P@UB#CX%;@VB"JHCJDG:"M8+<@KF"\8%"`(-J@X6!
M6X-8`(-J@X6!6X-8@T^#BX%;@W8`CI\`CI^"S(-)@W:#5H.'@Y,`CI^"S(-Y
M@5N#5SX`@VJ#2H.)@T^#08NDF&&-D0"#:H-7@T:!6X.+BZ2888V1`(-I@T.#
M5X-&@XJ#09A!EDV+I)AAC9$`@VJ#18-'DX<`C;>5JH+PE5R.IH*W@NF"O8+?
M@LR0W9+H@JJ"H(+H@MR"N8+Q@4(`E<^-6(+(@K6!0@""L8+,@T&#3H-:@UB,
MH(+)@LV#5(-U@T&#3H-:@UB,H(+-DL>)P8+%@JN"W(*Y@O&!0@`E<R""S)#=
MDNB/[I7Q@JJ.=Y+H@K."ZH+$@J*"W(*Y@O&!0@!&5%`@5D93((+,C5R0K(_N
ME?&"JHYWDNB"LX+J@L2"HH+<@KF"\8%"`%-13"!61E,@@LR-7)"LC^Z5\8*J
MCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(`4U%,((-*@V6#4X.*@LR-7)"LC^Z5\8*J
MCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(`CF.-@H*J@J""Z(+<@KF"\8%"`)&7D$V0
MYH*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(`@W2#0(-#@XN"JH-!@V*#=H.-@5N#
M:(*S@NJ"Q(*B@MR"N8+Q`(-!@T.#4H.3@JJ"H(+H@MR"N8+Q@4(`C^J/BH*J
MCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(`@X&#8H-:@5N#5X*JCG>2Z(*S@NJ"Q(*B
M@MR"N8+Q@4(`EKR13X*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(`E-2-AH*JCG>2
MZ(*S@NJ"Q(*B@MR"N8+Q@4(`2%144""41H_8@LR#<(-8@X^!6X-H@JJ"H(+H
M@MR"N8+Q@4(`24U!4""41H_8@LR#<(-8@X^!6X-H@JJ"H(+H@MR"N8+Q@4(`
M2V5R8F5R;W,@E$:/V(+,@W"#6(./@5N#:(*J@J""Z(+<@KF"\8%"`(.-@T^#
M0X.3()1&C]B"S(-P@UB#CX%;@VB"JH*@@NB"W(*Y@O&!0@!005-35T0@E$:/
MV(+,@W"#6(./@5N#:(*J@J""Z(+<@KF"\8%"`%--0B"41H_8@LR-7)"LC^Z5
M\8*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(`3W!E;E-33""#=H.-@T^#B8.`@LR#
M<(-8@JJ.=Y+H@K."ZH+$@J*"W(*Y@O&!0D]P96Y34TP@@LT@4$M#4R`Q,B""
MS(-F@5N#7H+PB+6"I(+,@LF52Y=V@L6"MX%"`)7;EZ^"S(-4@T.#DX-!@V*#
M=H+(@K6!0@"#3H-(@5N#7H*JD-V2Z(*S@NJ"Q(*B@MR"N8+Q@4(`@UJ#<(.,
M@5N#7H*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(`BEF3EH-T@T"#0X.+@LB"M0"#
MAH%;@U66O(*I@W"#6(./@5N#:(*JD9>"YX+J@MR"N8+Q@L6"M8*]@4(`EK.,
M^(+,6$U,@V:!6X->@JJ5U(+H@MR"M8*]`))L@LB"M0"#28.*@U>#:8.+@LR0
MW9+H@W2#0(-#@XN"R8-O@5N#5X.'@Y."JH*@@NB"W(*Y@O&!0I#=DNB"\(W$
MD+:0K(*U@MR"MX%"`)#=DNB#=(-`@T.#BX+)@V^!6X-7@X>#DX*J@J""Z(+<
M@KF"\8%"D-V2Z(-T@T"#0X.+@O"-[(+HDKR"M8+$B;J"LX*B@4(`@LB"M0"#
M;8%;@W2#2(%;@TZ3AP"6:Y2\BX4`EFN#?8.*@T&#:8^4DX<`@VV#BX-%@T:!
M6XFDC9$`@K&"ZH+F@NB13P""L8+J@N:"Z(SC`(-F@T*#C(-.@V>#BH+%@LV"
MH(+H@MR"N8+Q`([`D96"LX+J@L2"HH+<@KF"\8%"`(-4@WR!6X-G@K."ZH+$
M@J*"W(*Y@O&!0@"#@8."`#$QC(X`D)0`E;:.FI"4`)?QD)0`C7.0E`"1EY!-
MD.:#BH-8@V>"\(U8D%:"O8+?@LR4U(V&@JJ.=Y+H@K."ZH+<@KF"\8+%@K6"
MO8%"`$]+`(-)@W6#5X-&@TZ#9P"#28-U@U>#1H-.@V>-[)"LCM(`,3",C@"#
M28-T@T*#6`",PX*B@W"#6(./@5N#:`",PX*B@W"#6(./@5N#:(*JD+."M8*M
M@J""Z(+<@KF"\0"#28-]@5N#DP"+I)=,@W2#2(.+@U^"S2!)34%0((-4@5N#
M;X*^@J^"JH-4@WR!6X-G@L6"JX+<@K>!0@"39(YQ@X&!6X.+@T&#:(.,@UB"
MS3&"PH*^@J^.=Y+H@L6"JX+<@K>!0@"/BI=,CM*"J8-6@UB#98.`BL>7G8[2
M@KZ"KX*JBZ273(+,CXJ73(R@@L:#08-.@UJ#6(R@@O"5SXU8@L6"JX+<@K<`
MD%:+2X-%@T.#DX-H@5N"R95<CJ8`3W!E;E-33""#1X.)@5N!1E,O34E-12"/
MD):\@K."ZH*]@W"!6X-G@JF"YX-F@5N#7H+PCN:"Z(]O@KF"W(*Y@O&"Q8*U
M@KV!0@"#28-V@U:#AX.3`"5S((-)@W:#5H.'@Y,`E-2-AI5TB=./\(^1@JL`
MD6>01`"5E(^0`)"NEYT`C+."S(-!@W:#BH-0@5N#5H.'@Y.#98.3@W:#C(%;
M@V<`D;R"S(-#@Y.#=(-(@X&!6X-6@X>#DP"/BI=,CM*"S(-!@TZ#6H-8C*``
M4$%-()1&C]B"S8YGEW""Q8*K@MR"N8+Q@4(`4$=0()-DCG&/D):\`%!'4""(
MPXV&E;8`4$=0((SVBDJ,K@!01U`@CY"6O(W/+XC#C8:)NX-F@5N#7@!02%"#
M4H%;@V@`4$A0@U:#1H.+`%!/4TE8((IGDJ."JHRIDY:"O8+H@MR"N8+Q`):$
MD9``@W"#3(-8@UZ#DX%%@T.#6(.)@X"+I)AAC9$`@W"#B8-)BZ2888V1`(-P
M@XR#6(-@@VF.J8ZAB^8`@W"#:8-]BZ2888V1`(-P@W:#08-J@X6!6X--@VJ#
M09/&EZ>-D0"#<(.)@T^#08-#BZ2888V1`(-P@UB#CX%;@V@`@W"#6(./@5N#
M:(+-D+./[8+)E<^-6(*S@NJ"W(*U@KV!0@"#<(-8@X^!6X-H@JJ0LX*U@JV"
MH(+H@MR"N8+Q`%)!1$E54R"41H_8@LR#<(-8@X^!6X-H@JJ52Y=V@L6"MX%"
M`(-P@UB#CX%;@VB"S(IME$8`@W"#6(./@5N#:#H`@W"#6(./@5N#:#H@`(-P
M@UB#CX%;@VB"JHCJDG:"M8+<@KF"\8%"`)-<@NB5=(*O`(-.@XJ#8H-V@WN!
M6X-H@JF"YY-<@NB5=(*O`(-P@U@`E=N7KY*&@LR#5(-#@Y.#08-B@W:!1@"#
M<(%;@UJ#DX-G`)7;CN>1@(WL@O".P(US@K>"Z0"#C8-/@T.#DXZ>@LF5VX[G
MD8"-[(+PCL"-<X*U@MR"MX*I@4@`@T&#3H-:@UB,H`"#08-.@UJ#6(R@("(E
M<R(@@LV-[8^<@K."ZH+<@KF"\8+%@K6"O8%"`(-!@TZ#6H-8@LV+D93;@K."
MZH+<@K6"O0"#08-.@UJ#6(R@`(-!@TZ#6H-8C*""S(K'EYT`C,*0;(_NE?$`
M@WF#BX%;BZ2888V1`(-T@T*#BH-S@Y.+I)AAC9$`DV288@"#<X-G@U"#08.3
MDX<`@W.#3H-:@XL`C(Z"QI1.@O"3_)?-@K6"Q(*M@KZ"LX*B@4(`D%:"M8*B
ME:J7WH+,EKR13X+PD_R7S8*U@L2)NH*S@J(Z`)"S@K6"HI/ZE72"\)/\E\V"
MM8+$@JV"OH*S@J(N((R.@LR3^I"4@O"#8(-&@V*#3H*U@L2"K8*^@K."HH%"
M`(_ABE&3X)=E@O"7=I;Q@K6"Q(*RBTR3_(*M@KZ"LX*B@4(`@X:!6X-5EKR"
MQH-P@UB#CX%;@VB"\)/\E\V"M8+$@JV"OH*S@J*!0@".GX+,E;:/D8+PD\>"
M\8+%@JV"OH*S@J(N((*Q@LR#5H-8@V6#@(+PCF>7<(*W@NF"O8+?@LR+2Y+H
MCI:-@(+)DZ^(TX*W@NF52Y=V@JJ"H(+H@MR"MX%"`(-\@5N#B8.3@VB+I)AA
MC9$`DXJ56Y"4`(-\@XN#9X-+@XN+I)AAC9$`4')E9G-?;&1A<#H@E4N7=H+(
M3$1!4(IGDJ.+0)1<@JJ,J8+"@JF"Z(+<@KF"\8%"`%!R969S7VQD87`Z()5+
MEW:"R'-E<W-I;VZ*9Y*CBT"47(*JC*F"PH*I@NB"W(*Y@O&!0@"#=H.,@W*#
MA8%;`)!6@K6"HH-%@T.#DX-H@5N"R8GFD9R"\)5<CJ8`D4^"S(-)@W:#5H.'
M@Y,`B/.-_`"4Z9:GC*X`C^&*40"/X8I1D^"798+,D."6O@",]HI*C*X`C/:/
M3XRN@T&#BX-3@XJ#68.``(SVBDJ,KH_NE?$`C/:/3XRN+Y3IEJ>,KH*JD+:0
MK(+%@JN"W(*Y@O&"Q8*U@KV!0@"#=H-'@XN#9X.*@U(`@X&#8H-:@5N#5X+P
M@W"!6X-7`(-*@UZ!6X.+`(-.@T>#BH%;`(-*@UZ!6X.+`%)308SVCT^,KB@E
M9(-R@V*#9RD`E.0`D\>"W@"6>Y.6@LD@)7,@@O"-[8^<@K6"W(*W@JD_((*Q
M@LR1@(WL@LV,LX+)EM^"N8+<@KF"\8%"`)9[DY:"R8.&@5N#52`E<R""S(-F
M@5N#7H+PC>V/G(*U@MR"MX*I@4@@@K&"S)&`C>R"S8[F@NB/P8*Y@MR"N8+Q
M@4(`C<6,XX+,D8"-[(+P@N*"Z)*\@K<`DZZ328.!@VJ#A8%;@LR-Q)5<CJ:*
MU(IU.@"#?(%;@UZ#BX+,C<257(ZF`(.*@XV!6X-H`(.*@X*!6X-G@U2!6X-R
M@U@`@XJ#@H%;@V=54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I
M.B``C>V/G`"#=8.-@V*#3H+PC>V/G`"/D8ZN@O"-[8^<`(-Y@T&"\(WMCYP`
ME=N1MH*U@KV#6(-.@XJ#=H-G@O"-[(O&@V:#0H.,@TZ#9X.*@JF"YXWMCYR"
MMX+I@4(`C>V/G(%&`(*Q@LR#;8%;@VB"\(-H@TR#A8.!@Y.#9X*I@N>-[8^<
M`(.&@5N#58+PC>V/G`"#AH%;@U6"\(WMCYPZ("5S`)=VBX&"R974DYJ"Q8*K
M@MR"N8+Q.B``EW:+@8*S@NJ"O2`B)7,B((+-("5S((+,D-V2Z(+)CG>2Z(*S
M@NJ"Q(*B@MR"N8+Q@4(`EW:+@8*S@NJ"O2`B)7,B((+-(%9&4R"0W9+H@LF.
M=Y+H@K."ZH+$@J*"W(*Y@O&!0@"7=HN!@K."ZH*]("(E<R(@@LV0W9+H@LF.
M=Y+H@K."ZH+$@J*"W(*Y@O&!0@"#BH-:@V*#9P"#<(-8@X^!6X-H@O"#BH-:
M@V*#9P""H(+(@KV"S(-P@UB#CX%;@VB"\(.*@UJ#8H-G`(R+B<H`@TF#=H-6
M@X>#DX+)EM^"Z0"#<(-8@X^!6X-H@O"-Q)/\E\T`C+."S(U<D*R"R9;?@K<`
M@V6#3(-8@V>#1X-F@T*#7H%;@LR#28-V@U:#AX.3`(E%`);PBH0`@XN!6X-]
M@VJ#00`Q.#"3>(GQDUT`C;:"R8GQDUT`B46"R8GQDUT`C7.1KI"K`(USD:Z0
MJP"-<X%&`(QRD/P`D5."Q(+,C7."QI?Q@LR*U(+)C'*0_(+PB/B"K0"-<X+,
MBM2"R8QRD/R"\(CX@JT`E_&"S(K4@LF,<I#\@O"(^(*M`([`C7,`@XV#5H-!
MF$&630"#BX./@Y.#7P!3+TU)344@B,.-AH^0EKP`4R]-24U%((C#C8:5M@!3
M05-,()1&C]B"S8YGEW""Q8*K@MR"N8+Q@4(`4U%,((-6@T:#BP!34T@`D*R,
M]P"3>0"#6H.3@V>#=X.,@VF3AP"#6H.3@V>#3(-B@V.!E8-L@5N#E(-"@U@`
M@UJ#DX-G@XN#5H-!`(-4@Y.#<X-'@5N#BX%%@WZ#3H.-@Y.3AP"#6H.3@V>#
M<X.3@UJ#DX-G@JB"YH+1@T^#C(-I@V:#0H%;@Y./E).'`(-4@X*#09/&EZ>-
MD0"#5(.3@WV#BH-MBZ2888V1`(-4@Y.#9X.!@46#=H.*@Y.#5H-YEJ^.Y8ND
MF&&-D0"#5(-%@U>#08.)@W*#08FDC9$`E=N1M@`B)7,B((+PE=N1M@`E<R""
M\)7;D;8`@TF#=H-6@X>#DX+PE=N1M@"0MI"L@K."ZH*]D-V2Z(+P(%!(4""#
M6(-.@XJ#=H-G@L:"M8+$@U2!6X-O@LR-[(O&@V:#0H.,@TZ#9X.*@LF5VY&V
M@K>"Z8%"`"5S()#=DNB"\)7;D;:"M8+<@K6"O8%"`)#=DNB-6)!6EW"#6(-.
M@XJ#=H-G("(E<R(@@O"5VY&V@K6"W(*U@KV!0@",GXWU`(R?C?6#1X.3@U>#
MDP"#=(-`@T.#BX+PD4F1\`"3^I5T@O".=Y+H@K6"Q(*M@KZ"LX*B@48`DL>)
MP8*W@NF#3X.+@5N#=H+PD4F1\(*U@L2"K8*^@K."H@"05H*U@J*/BHZ=CM*"
M\)%)D?""M8+$@JV"OH*S@J(`@U2!6X-O@O"129'P@K6"Q(*M@KZ"LX*B`)+'
MB<&"MX+I@X:!6X-5@O"129'P@K6"Q(*M@KZ"LX*B`)%3@L2129'P`)5+EW:"
MR)6VCIJ"\(FZ@LR#>X-B@TZ#6(*I@N>128+Q@L6#4H-S@5N"MX+I@L:!08-E
M@TR#6(-G@T>#BH-!@M:#>8%;@UB#9X+%@JN"W(*W@4(`D_J5=(+,B^:0V(+H
ME;:.FH+PCG>2Z(*U@L2"K8*^@K."HH%&`)/ZE72"S(Q@CJZ"\(YWDNB"M8+$
M@JV"OH*S@J*!1@"5SXU8@K6"O8*B242"\)%)D?`Z`(Z>C8^"S(OFD-B"Z)6V
MCIJ"\(YWDNB"M8+$@JV"OH*S@J*!1@".GHV/@LR,8(ZN@O".=Y+H@K6"Q(*M
M@KZ"LX*B@48`B.J2=H*W@NF"48+"@LR#=(-"@5N#BX-H@O"128+Q@L6"K8*^
M@K."HH%"`)!&DK*"\)%)D?""M8+$@JV"OH*S@J(N`(R^C.J"\)%)D?""M8+$
M@JV"OH*S@J(Z`(_ABE&#C(-\@5N#9X+PD9>038*W@ND`4TU3()&7D$T`@UJ#
M;(-+@XN+I)AAC9$`@EB,C@"#6H.+@W*#08%%@X*#DX-E@VR#3X.-`)+*E-0`
M@UJ#8H-6@X>#DXK'EYT`@UJ#8H-6@X>#DP"668+J@L2"M8+<@L&"O8-P@UB#
MCX%;@VB"\(.*@UJ#8H-G@L6"JX+I@N:"I(+)@K6"W(*W@4(`@WR!6X->@XN"
MQ8-!@TZ#6H-8@K>"Z8.*@X*!6X-G@U2!6X-O@O"0W9+H@K6"W(*W@4(`C+Z,
MZH%!CIZ*U)'1@4&3^I5T@O"0W9+H@K6"W(*W@4(`BDJ.;HZ>@LR#08-V@XJ#
M4(%;@U:#AX.3@4&01I*R@4&#>8%;@U>-Q)5<CJ:!08*[@LR1O(+,E5R.IH-)
M@W:#5H.'@Y."\)%)D?""M8+$@JV"OH*S@J(N`)#=DN@`D-V2Z(U8D%:#6(-.
M@XJ#=H-G`(-:@5N#5H-&@XN+I)AAC9$`BLB24(+(EW:6\8%&`(%I@X&#:H.%
M@5N"R(+'@L6!:H-6@X>!6X-G@TJ#8H-G@TR!6X*JCF>"IH+I@N:"I(+)@K6"
MW(*W@JF!2`"57(ZF`(R[C=V"S)#=DNB"QI!6@K6"K9"VD*R"LX+J@KV0W9+H
M@L:"S(VWE:J"\)5<CJ:"MX+I@4(`@XV#3X-#@Y..GH+)D4^)\8+,@XV#3X-#
M@Y..GHK4@O"57(ZF@K6"W(*W@JF!2`"57)&`C>R#@8-J@X6!6X+PE5R.IH*U
M@MR"MX*I@4@`B>:6RHVV@LD@)7,@@X&#:H.%@5N"\)5<CJ:"M8+<@K>"J8%(
M`)5<@LR#6H.+D:Z0JX-?@T.#08.-@T^"\)5<CJ8`E5R1KI"K@U^#0X-!@XV#
M3X+PE5R.I@"57(+,E_&1KI"K@U^#0X-!@XV#3X+PE5R.I@"57(+,C7.1KI"K
M@U^#0X-!@XV#3X+PE5R.I@"/:X^L`(+<@KB7UX+H@LR#=8.-@V*#3H+PCVN/
MK(+<@KV"S8C:DZZ"LX*Y@L2"K8*^@K."HH%"`(-6@T>#B8.,@TF#;(NDF&&-
MD0"#5(-#@Y.#08-B@W8`DV2.<8^0EKP`DV2.<8^0EKR#08.+@U.#BH-9@X``
M@U:#DX-+@WR!6X.+BZ2888V1`(-4@T.#60"5VX[G@O"#6(-,@V*#=H*W@ND`
M@UB#C8-O@TR#08NDF&&-D0"#6(.-@WB#:H-!BZ2888V1`(-<@XV#@H.3CY23
MAP"#7(-]@XJ#09:OCN6+I)AAC9$`E<""T8^'@LR129'P`)&7D$V,LX-!@VB#
MC(-8`)/L@T&#=(.*@TJ+I)AAC9$`D^R#5X.'@5N#5X-!DX>!19/L@U2#DX-H
M@T.#8H-@CY23AP"3[)2\BX4`E]>"S(-:@XN"QH+,EUV4D@"#6H.+@L:+JXI%
M@L:"S)==E)(`EUV4D@"77922@L:6A)&0`(-8@WF#0X.3`)/!CNJ5MHZ:@LR3
M_)?-`(-:@XN5JHJ$`)?QE:J*A`"-<Y6JBH0`@UB#BH.)@Y.#2I:OCN6.T(GO
MCN6+8(NDF&&-D0"/0H+<@KV"S8RG`(_SD=0`CUJ/BI34DFX`CN:/P8*UD/P`
M@UB#7H-#@XL@6T-34UT`D_H`@U2#=8-F@T*#C(-.@V>#BB`B)7,B((*J@J""
MZ(+<@KF"\8%"`([`C7,`B;J5=(*K`)"LC/<`(B5S(B""S8-6@UB#98.`@LF2
MQXG!@K."ZH+<@K6"O8%"`"(E<R(@@JJ#5H-8@V6#@(*I@N>-[8^<@K."ZH+<
M@K6"O8%"`"(E<R(@@JJ-[8^<@K."ZH+<@K6"O8%"`"(E<R(@@JJ#5H-8@V6#
M@(*I@N>-[8^<@K."ZH+<@K6"O8%"`)#=DNB"S9"SC^V"R9;?@K."ZH+<@K6"
MO8%"@XJ#C8%;@VB"M8+$BFV41H+%@JN"W(*W@4(`D-V2Z(+,@V^#8H-.@T&#
M8H-V@LV0LX_M@LF5VY&V@K."ZH+<@K6"O8%"`)#=DNB#=(-`@T.#BX+,@V^#
M8H-.@T&#8H-V("5S((+-D+./[8+)E=N1MH*S@NJ"W(*U@KV!0@`B)7,B((+-
MD+./[8+)C5B05H*S@NJ"W(*U@KT`)7,@@LV0LX_M@LF/D8*KC9Z"W(+J@MR"
MM8*]`(-8@5N#7X.3BZ2888V1`(I4EW8`D_J"S(]O`)/Z@LR3_(+H`)/Z@LR/
M;R^3^H+,D_R"Z`"3^H+,CV^!1@"3^I9V`)/ZEG:!1@"/XY5T@JL`@U2#?(%;
M@V<`@UB#BH-I@X"+I)AAC9$`D*D`@UB#E(-`@5N#BX-O@XN!08.$@Y.#?8-#
M@T>#DX^4DX<`@UB#CX-7@XF#DX-HB:2-D0"#6(-%@T:!6X-F@Y.)I(V1`(-8
M@T.#6)A!EDT`@U:#BH-!@46#08.)@W6+I)AAC9$`5%-6@W2#0(-#@XL`E5R1
MKI"K`)5<D:Z0JP"1Y)AP`)'DF'"!:9*&C9&"S(CJE92!:@"#7H-7@TR#6(->
M@Y.+I)AAC9$`@UZ#DX-5@VJ#09A!EDV+I)AAC9$`@UZ#6(-.`)-DF&*4U(V&
M`(-E@Y.#=H.,@5N#9R`B)7,B((*J@J""Z(+<@KF"\8%"`(-E@Y.#=H.,@5N#
M9X+,BL>7G0"#98-,@UB#9X+,@MT`E;:.FI1ZDG4`E;:.FH+,C^,`EM@`@UZ#
M0XFDC9$`1E10((IGDJ."JH*@@NB"W(*Y@O&!0@"7FI?P@U:#6(-E@X""S9:S
MC/B"R8+(@L&"Q(*B@MR"MX%"`$UA:6YT96YA;F-E((-.@XF#6(+,D\>-GH+=
M@JJ0LX_M@LF-<X*F@MR"N8+Q@L6"M8*]`(-)@W:#5H.'@Y.#18-"@Y.#:(-%
M@O"5PH*V@MR"M8*]@4*/29>Y@K6"W(*W@4(`@T&#3H-:@UB,H(+PETR,^(+)
M@K>"Z8+)@LV*QY>=CM*"JH*[@LR#;X-B@TZ#1X.3@VB"\)#=DNB"MX+I@K&"
MQH*JE4N7=H+%@K>!0@"809>-D.9)1)34C8:"JHYWDNB"LX+J@LB"J8+!@KV"
MJ8%!B_."OH+!@KV"J8%!@J""Z8*B@LV#9H%;@UZ#>(%;@UB2AH+)C*F5=(*I
M@NB"W(*Y@O&"Q8*U@KV!0@"809>-D.:"S8*@@LB"O8+,@T&#:(.,@UB2H(+)
MDL>)P8*S@NJ"W(*U@KV!0@"39(YQCY"6O(*S@NJ"O8.!@V*#6H%;@U>"\(R?
MC]B"MX+I@LF"S8%!4$=0((^0EKR"JI5+EW:"Q8*W@4(`D9>039#F2424U(V&
M@JJ.=Y+H@K."ZH+(@JF"P8*]@JF!08OS@KZ"P8*]@JF!08*@@NF"HH+-@V:!
M6X->@WB!6X-8DH:"R8RIE72"J8+H@MR"N8+Q@L6"M8*]@4(`D9>039#F2424
MU(V&@JJ.=Y+H@K."ZH+<@KF"\8+%@K6"O8%"`(C#C8:)NX+)@LV(P)%3@LB#
M18-&@W60VI&Q@JJ52Y=V@L6"MX%"`(-T@T"#0X.+("5S((+)@LT@)7,@@LR0
MW9+H@JJ52Y![@L6"MX%"`(-T@T"#0X.+("5S((+)@LT@)7,@@LR0W9+H@JJ5
M2Y![@L6"MX%"`(-T@T"#0X.+@LV.J96JCJF09X+)@U*#<X%;@L6"JX+<@KF"
M\8%"`(-T@T"#0X.+@JJ#9H%;@UZ"\(K<@O&"Q8*B@MR"N8+Q@4(`B,B)NH+-
M@K&"S(.!@V*#6H%;@U>!:5)&0S@R,H%J@LR#=X-B@U^"Q8*W@4(`DHV(TX%)
M((-T@XN#6(-.@XJ!6X.3@X*!6X-H@LT@26YT97)N970@17AP;&]R97(@@L6"
MS9;BD>B"JI2MD+:"MX+I@K&"QH*J@J""Z(+<@K>!:8-U@XF#18-5@LR#;X-/
M@L6"MX%J@4*)YI;*@LF#4X-^@JJ57(ZF@K."ZH*]@NB!05=I;F1O=W,@@JJ#
M3H.)@V*#5H.%@K6"O8+H@K>"Z8*I@N""M8+J@MR"N8+Q@4(*@W2#BX-8@TZ#
MBH%;@Y.#@H%;@VB"R8*W@NF"R(+G($]+((+PB9^"M8+$B;J"LX*B@4(`240@
M(B5S(B""S8WMCYR"LX+J@MR"M8*]@4(`1VYU4$<@@V^#0X-I@XJ"S(-P@UB"
MJB!#<GEP=%]P9W`@@TZ#B8-8@LF0W9+H@K."ZH+$@J*"Z95+EW:"JH*@@NB"
MW(*W@4(`@K&"S(-T@T*!6X.+@VB"S9"4CIJ"Q8+(@J^"ZH+.@LB"Z(+<@KF"
M\8%"`$AO<F1E7T-R>7!T7W-M:6UE@TZ#B8-8@LF"S6]P96YS<VR#@H-7@X6!
M6X.+@JJ52Y=V@L6"MX%"`(-V@XR#=(-`@XR#DX-8(B5S(H+-@V:!6X->@JJ#
M5(-#@UF0IXS`@O")>H*F@KV"O8+?E=N1MH+%@JN"W(*Y@O&"Q8*U@KTN`(*Q
M@LR#9H%;@UZ,7B@E<RF"\)5<CJ:"MX+I@KV"WX+,@W:#C8-/@XF#@(*J@K&"
MS(-6@UB#98.`@LF"W8+"@JF"Z(+<@KF"\8%"`(CXEW"5A(+-@E"5MHZ:@L6"
MR(*O@NJ"SH+(@NB"W(*Y@O&!0@"+YI#8@NB5A(+-@E"5MHZ:@L6"R(*O@NJ"
MSH+(@NB"W(*Y@O&!0@"#5(%;@V\@(B5S(B""S8WMCYR"LX+J@MR"M8*]@4(`
M@U2!6X-O("(E<R(@@LV5VY&V@K."ZH+<@K6"O8%"`(YWDNB"M8*]E_&!:25D
M@6J"JH*@@NB"W(*Y@O&!0@"(ZHZ>@W2#0(-#@XL@(B5S(B""JH*@@NB"W(*Y
M@O&!0@"#08-B@W:#C8%;@VB#9H%;@UZ"JI*\D4^"S(-8@V6#8H-V@L6/P8ZX
M@K6"W(*U@KV!0@"#08-B@W:#C8%;@VB#9H%;@UZ"\)7;D;:"Q8*K@MR"N8+Q
M@L6"M8*]@4(`@V6!6X-]@V:#0H.,@TZ#9X.*@5L@(B5S(B""JH*@@NB"W(*Y
M@O&!0@".=Y+H@L6"JX+I@TF#=H-6@X>#DX+-@J""Z(+<@KF"\8%"`(-#@Y.#
MB8-#@Y.57(ZF@L6"JX+IE925JH+-@J""Z(+<@KF"\8%"`)6VCIJ0E(*J@K&"
MS(-T@T*!6X.+@VB"R9&]B=^"K(+<@K<N("5S((+,E;:.FH*JD_R7S8*S@NJ"
MQ(*B@MR"MRX@)7,@B,B)NH+%@LB"K8+$@LV"HH*O@MR"N8+Q@4(`(B5S(B""
M\(-6@UB#98.`@M:2QXG!DH:"R9;BD>B"JI2MD+:"M8+<@K6"O3H@)7,`@X:!
M6X-5("(E<R(@@LR#9H%;@UZ"\(-6@UB#98.`@JF"YX_!BXZ2AH+)EN*1Z(*J
ME*V0MH*U@MR"M8*].@`B)7,B((+P@U:#6(-E@X""J8+GC>V/G)*&@LF6XI'H
M@JJ4K9"V@K6"W(*U@KTZ`"(E<R(@@O"-6)!6DH:"R9;BD>B"JI2MD+:"M8+<
M@K6"O3H@)7,`@W2#0(-#@XN#08-B@W:#C8%;@VB"R9;BD>B"JI2MD+:"M8+<
M@K6"O3H@)7,@@LV#08-B@W:#C8%;@VB"LX+J@L2"HH+<@KF"\8%"`(-T@T"#
M0X.+@T&#8H-V@XV!6X-H@LF6XI'H@JJ4K9"V@K6"W(*U@KTZ("5S((+-@W2#
M0(-#@XN"S(-4@T.#69"GC,"2;"@E9(-O@T.#9RF"\(EZ@J:"Q(*B@MR"MX%"
M`(-T@T"#0X.+@T&#8H-V@XV!6X-H@LF6XI'H@JJ4K9"V@K6"W(*U@KTZ("5S
M((+-B.J5E(+,@MV#08-B@W:#C8%;@VB"LX+J@MR"M8*]@4(`@K&"S(-P@5N#
M9X+PE5R.II*&@LF#1X.)@5N"JI2MD+:"M8+<@K6"O0"809>-D.:#9H%;@UZ"
MS(-#@Y.#?(%;@V>2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KV!0@!I0V%L96YD
M87(@@LR#0X.3@WR!6X-GDH:"R8-'@XF!6X*JE*V0MH*U@MR"M8*]+@"0W9+H
M@W2#2(%;@X"2AH+)@T>#B8%;@JJ"H(+H@MR"M8*]@4*"O8+4@O&!095+D'N-
M@);:@JJ+\Y22@KZ"P8*]@LR"Q8*U@N6"I(%"`(YWDNB"LX+J@KV#08-H@XR#
M6)*@@LR1@(WLDH:"R8-'@XF!6X*JE*V0MH*U@MR"M8*]@4*,XX+%C<23>([`
MC7."M8+$@JV"OH*S@J*!0@"809>-D.:"S(_:C=>"\(U8D%:2AH+)@T>#B8%;
M@JJ4K9"V@K6"W(*U@KV!0HSC@L6-Q)-XCL"-<X*U@L2"K8*^@K."HH%"`)&7
MD$V0YH.*@UB#9X+,C5B05I*&@LF#1X.)@5N"JI2MD+:"M8+<@K6"O8%"C.."
MQ8W$DWB.P(US@K6"Q(*M@KZ"LX*B@4(`@K&"S"!)34%0((-4@5N#;X+-BZ27
M3(-T@TB#BX-?@O"#5(-\@5N#9X*U@L2"HH+<@KF"\8%"`(*Q@NJ"S9=,C/B"
MR"!R87(@@T&!6X-*@T.#=8+%@LV"R(*B@N:"I(+%@K>!0@""L8+J@LV73(SX
M@L@@>FEP((-T@T"#0X.+@L6"S8+(@J*"YH*D@L6"MX%"`(*Q@NJ"S9=,C/B"
MR(-*@5N#:)34C8:"Q8+-@LB"HH+F@J2"Q8*W@4(`@K&"S(-T@T*!6X.+@VB"
MS95+D'N"Q8*W@4(`@K&"S(-T@T*!6X.+@VB"S9"ND)2"Q8+(@JV"Q(+-@J*"
MKX+<@KF"\8%"`(*Q@LR#=(-"@5N#BX-H@LV0E(Z:@L:#4H.-@Y."Q8+(@JV"
MQ(+-@J*"KX+<@KF"\8%"`(*Q@LR#=(-"@5N#BX-H@LTXD&F0E(+%@LB"K8+$
M@LV"HH*O@MR"N8+Q@4(`@K&"S(-T@T*!6X.+@VB"S8-2@Y.#?8+<@KV"S8OS
ME)*"Q8OFD-B"YX+J@KV0KI"4@LR#BH-8@V>"Q8+(@JV"Q(+-@J*"KX+<@KF"
M\8%"`(*Q@LR#=(-"@5N#BX-H@LV0E(Z:@L6"R(*O@NJ"SH+(@NB"W(*Y@O&!
M0@""L8+,@W2#0H%;@XN#:(+-,3:0:5)'0I5<BTR"S)!&@U*!6X-H@LB"K8+$
M@LV"HH*O@MR"N8+Q@4*7X3HG(S$R,S1A9B<N`(*Q@LR#=(-(@5N#@(+-BOF"
MR8^(EYV"LX+J@L2"HH+<@K>!0@""L8+,@X&#8H-:@5N#5X+-@J""R(*]@JJ.
M9Y=P@K>"Z8+,@L:(V8+(@NF5MHZ:@UJ#8H-G@6DE<X%J@L6/D8*I@NJ"Q(*B
M@MR"MX%"`(*Q@LR4U(V&@LV-Q8^L@L6"X#&"Q8+(@JV"Q(+-@J*"KX+<@KF"
M\8%"`(*Q@LR#5(%;@V^"Q8+->FEP@L9G>FEP@W2#0(-#@XN"\)-7BDJ"Q8*K
M@MR"N8+Q@4(`@K&"S(-6@UB#98.`@LV(ZHZ>DTF"R9:SC/B"R8+(@L&"Q(*B
M@MR"MX%"`(*Q@LR2;(+-D)2.FH+%@LB"KX+J@LZ"R(+H@MR"N8+Q@4(`@K&"
MS(-%@T*#DX-H@T6"S8-)@W:#5H.'@Y.#18-"@Y.#:(-%@JF"YXS$CV^"LX+J
M@NF52Y=V@JJ"H(+H@MR"MX%"`(Z>BM0`@UZ#0X.`@U:!6X-G`(Z>BM2/D8ZN
M`).,@V6#0H."@5N#BY:OCN6+I)AAC9$`@UZ#0X-G@XL`E:&0E(+,C8"6VH+P
MD4F1\(*W@NF"R8+-@4%00X+%@LU#;VYT<F]L@TR#0X%!36%C@LB"YT-O;6UA
M;F2#3(-#@O")GX*U@LB"JH+G@TZ#BH-B@TZ"M8+<@K>!0@!(5$U,@UR!6X-8
ME5R.II#8D=8`@V>!6X-3BZ2888V1`(-G@U"#B8-%CY23AP"#9X.3@TN)I(V1
M`(*Q@LR0E)6JBM2"R8F]DWB"X(.-@T^#0X.3@JJ.CHUS@K."ZH+<@K6"O8%"
M`(-G@XJ#:H-?@5N#:(%%@V>#;X-3BZ2888V1`(G.`(-@@X6#:H-7@T&+I)AA
MC9$`@V>#BX-2BZ2888V1`(-G@XN#3H.!@VJ#6(->@Y,`@UZ!6X-.@UB!18-*
M@T.#4H-8CY23AP"#8X-O@XL`D4F1\(%&`%523`"#18-+@Y.#7XNDF&&-D0"#
M18-.@XF#0X-I`%9&4R"#9H-"@XR#3H-G@XJ"R8-!@TZ#6H-8@L6"JX+<@KF"
M\8%"`%9&4R"#=(-`@T.#BR`B)7,B((+,@T&#3H-:@UB,H(+-E<^-6(+%@JN"
MW(*Y@O&!0@!61E,@@W2#0(-#@XL@)7,O)7,@@LR#08-.@UJ#6(R@@LV5SXU8
M@L6"JX+<@KF"\8%"`"5S((+)E<^-6(+%@JN"W(*Y@O&!0@"#=(-`@T.#BR`B
M)7,B((+,@U2#0X-9@JJ#8(-&@V*#3H*K@MR"N8+Q@4(`@W2#0(-#@XL@(B5S
M+R5S(B""S(-4@T.#68*J@V"#1H-B@TZ"Q8*K@MR"N8+Q@4(`4U%,((-4@5N#
M;X+)D-J1L8+%@JN"W(*Y@O&!0@!34TP@@L60VI&Q@L6"JX+<@KF"\8%"`%9&
M4R"#=(-`@T.#BX+P@U*#<X%;@L6"JX+<@KF"\8%"`%9&4R"#9H-"@XR#3H-G
M@XH@(B5S(B""\(WLD*R"Q8*K@MR"N8+Q@4(`5D93((-F@T*#C(-.@V>#BH+P
MC>R0K(+%@JN"W(*Y@O&!0@!61E,@@W2#0(-#@XN"\(WLD*R"Q8*K@MR"N8+Q
M@4(`5D93((-F@T*#C(-.@V>#BB`B)7,B((+PC>R0K(+%@JN"W(*Y@O&!0@"+
M\X+,(%9&4R"#=(-`@T.#BX+PC>R0K(+%@JN"W(*Y@O&!0@"#9H%;@UZ"\(BS
MCVN"Q8*K@MR"N8+Q@4(`(B5S(H+PC>V/G(+%@JN"W(*Y@O$N((-F@T*#C(-.
M@V>#BH*JB_."Q8+-@J""Z(+<@KF"\8%"`"(E<R*"\(WMCYR"Q8*K@MR"N8+Q
M.B`E<RX`)7."\(WMCYR"Q8*K@MR"N8+Q+B"#9H-"@XR#3H-G@XJ"JHOS@L6"
MS8*@@NB"W(*Y@O&!0@!61E,@@V:#0H.,@TZ#9X.*@O"-Q(M!DTF"R8WMCYR"
MQ8*K@MR"N8+Q@4(`5D93((-F@T*#C(-.@V>#BH+PC>V/G(+%@JN"W(*Y@O&!
M0@!61E,@@V:#0H.,@TZ#9X.*@O"-[8^<@L6"JX+<@KF"\8%&)7,`5D93((-T
M@T"#0X.+("(E<R(@@O"-[8^<@L6"JX+<@KF"\8%"`%9&4R"#=(-`@T.#BX+P
MC>V/G(+%@JN"W(*Y@O&!0@!61E,@@V:#0H.,@TZ#9X.*("(E<R(@@O"-[8^<
M@L6"JX+<@KF"\8%"`%9&4R""\(W$BT&328+)C>V/G(+%@JN"W(*Y@O&!1B5S
M`(R[C=V"S(-F@T*#C(-.@V>#BH%;@JJ3P9+H@L6"JX+<@KF"\8%"`(_8EKZ/
MD8+,C]J-UX*JCN:"Z(]O@KF"W(*Y@O$`)7,@@LR2Z(M@@JJ#C8%;@VB"Q8*K
M@MR"N8+Q@4(`5D93((-T@T"#0X.+@JJ(VI.N@L6"JX+<@KF"\8%"`%9&4R"#
M=(-`@T.#BR`B)7,B((*JBDJ"KX+<@KF"\8%"`%9&4R"#=(-`@T.#BX+PCY&"
MJXV>@MV7<(+)BDJ"KX+<@KF"\8%"`%9&4R"#=(-`@T.#BX*JBDJ"KX+<@KF"
M\8%"`(BSCVN/D8S)@W2#0(-#@XN"\(I*@J^"W(*Y@O&!0@!61E,@@W2#0(-#
M@XN"JI/'@M^"W(*Y@O&!:69I;&5S:7IE*"D@@T>#B8%;@6J!0@!61E,@@W2#
M0(-#@XN"JI/'@M^"W(*Y@O&!:6=E=$9I;&53:7IE*"D@@T>#B8%;@6J!0@!6
M1E,@@W2#0(-#@XN"JI/'@M^"W(*Y@O&!0@!V9G-R;V]T((-F@T*#C(-.@V>#
MBH+PD\>"WX+<@KF"\8%"`):\D4\@)7,@@O`@)7,@@LF5SXU8@L6"JX+<@KF"
M\8%&@W2#2(.+@U^!6X+-BOF"R9&VC=V"M8+<@K<`5D93((-F@T*#C(-.@V>#
MBH%;@LR6O)%/@O"5SXU8@L6"JX+<@KF"\8%"`%9&4R"#9H-"@XR#3H-G@XJ!
M6X+,EKR13X+PE<^-6(+%@JN"W(*Y@O&!1B5S`%9&4R"#=(-`@T.#BR`B)7,B
M((+,EKR13X+PE<^-6(+%@JN"W(*Y@O&!0@!61E,@@W2#0(-#@XL@)7,O)7,@
M@LR6O)%/@O"5SXU8@L6"JX+<@KF"\8%"`%9&4R"#=(-`@T.#BX+,EKR13X+P
ME<^-6(+%@JN"W(*Y@O&!0@""L8+,(%=O<F0@E;:/D8+PEGR6\X+%@JN"W(*Y
M@O&!0@!61E,@@W2#0(-#@XL@(B5S(B""R8^1@J^"W(*Y@O&!0@!61E,@@W2#
M0(-#@XN"R8^1@J^"W(*Y@O&!:6-O<'DH*8ZXE'.!:H%"`%9&4R"#=(-`@T.#
MBX+)CY&"KX+<@KF"\8%"`%9&4R"#=(-`@T.#BX+)CY&"KX+<@KF"\8%"<75O
M=&$@@O"2M(G?@K6"O8+F@J2"Q8*W@4(`B;J0_`"5SXU8@O".YH+HC\&"MP"-
MQ8SC@LR1@(WL@O",LX+)EM^"MP"0VI&QCIZ"S(-4@5N#;X%;@JF"YX+,EUR*
M^H*U@LB"HHF>DYJ!1@"#5(%;@V^!6X*I@N>"S)=<BOJ"M8+(@J*)GI.:@48`
MEJ*0KI>=`(-!@XF#=8[QDK>-D9A!EDT`B7"-D0"5Q(V1`)7$E\R1OI6]EVV/
ME).'`)5SEKX`@X:!6X-5EKR"J8-P@UB#CX%;@VB"JI5SEKZ"Q8*W@4(`EK.6
MO`"#6H-,@X6#BH-E@T*!6X_C@LR7G9=2@JF"YY/!C*""S):S@J*#6(-.@XJ#
M=H-G@LT@0W5T+T-O<'DO4&%S=&4@@L6"JX+<@KF"\8%"3TL@@O"#3H.*@V*#
M3H*W@NF"QH%!@L>"I(+B@L&"Q(-.@XJ#8H-V@WN!6X-H@LF#08-.@UJ#6(*W
M@NF"J8+&@J*"I"!M;WII;&QA+F]R9R""S(M:CW"5MH^1@O",J8+I@K&"QH*J
M@L6"JX+<@K>!0@"#5(-\@5N#9X*U@L2"HH+(@J**9Y*CCG&"Q8*W`(U8D%8`
M)7,@@O"-6)!6@K>"Z8%"`(.&@5N#58+PC5B05H*W@ND`(B5S(B""\(U8D%:"
MM8+<@K6"O8%"`(U8D%:#6(-.@XJ#=H-G@O"-[8^<@K6"W(*U@KV!0@"#08-B
M@W:#C8%;@V@`D5."Q(+,@T&#=H.*@U"!6X-6@X>#DX+,D-V2Z(-T@T"#0X.+
M@O"#5(%;@V^"R8-!@V*#=H.-@5N#:(*U@MR"M8*]@4(`@XF#98.3E;:.FH%I
MD>65MHZ:@6H`@XV!6X-]D)2.FH%ID>65MHZ:@6H`@T6#BX-/@T&#0Y.,E?N+
MI)AAC9$`C+N-W8+,DFR"\(YGEW"!1B5S`%-33"""\(YGEW``24U34""#5(%;
M@V^"S(.&@5N#59:\@5Z#<(-8@X^!6X-H@JJ(V8+(@NF/ZHV'@LF.9Y=P@K6"
MW(*W@4(`@X:!6X-5`(.&@5N#52`E<R""S2`E<R""Q91&C]B"LX+J@L2"HH+<
M@KF"\8%"`(.&@5N#58K'EYT`@X:!6X-5@TF#=H-6@X>#DP"#AH%;@U63;YA>
M`(.&@5N#58+,DV^87H+-@K&"S(-4@T.#9X+%@LV+UHY^@K."ZH+$@J*"W(*W
M@4(`@X:!6X-5@5N#08-*@T6#DX-G@JJ"H(+H@MR"N8+Q@4*!0@"#AH%;@U66
MO`"#AH%;@U66O"`B)7,B((+-BOF"R8*@@NB"W(*W@4(`@X:!6X-5EKPZ`(.&
M@5N#59:\.B``@U:#6(-E@X"2AH+,@X:!6X-5@48`@T6#68-X@TR#6(->@Y.+
MI)AAC9$`BWB)R0"73(SXD*L`@V^#:X-!@V.+I)AAC9$`@WB#;(-9@T>#B8%%
M@WN#BH-O@XN+I)AAC9$`C)^/V(ZXE',@+2""L8+,@X&#8H-:@5N#5X+-B?SB
M@H*S@NJ"Q(*B@NF"YH*D@L6"MX%"`)3%`(-O@5N#5X.'@Y.*QY>=`(]CB,J2
M=0"#>(-G@VF#@([0B>^.Y8M@BZ2888V1`"5S((+PC*F"Z0"*3Y64@LP@=V5B
M((-Y@5N#5X+PE5R.I@")<)?,@V^!6X-7@Y./E).'`)7$E\R#;X%;@U>#DX^4
MDX<`@T6#2(.*@UB!18-T@V>#1(%;@VF/E).'`(QXC9``D(4`EHB/5`""YH*D
M@K&"NP`E<R""R8+F@J2"L8*[`"5S((*S@O&!08+F@J2"L8*[`)"\@U2#;H.)
M`"5S@XV#3X-#@Y.,XX+'@LR#08-V@XJ#4(%;@U:#AX.3@O"57(ZF@K6"W(*W
M@JF!2`"+YI#8@NB5MHZ:@LV)O8+%@K>"J8%(`(CXEW"5MHZ:@LV)O8+%@K>"
MJ8%(`(-E@TR#6(-G@T>#9H-"@UZ!6X+,@W:#B8-/@T.#DX+PD4F1\(*U@MR"
MMX%"`)6=`(VV@LF2=8*M)7.#@8-J@X6!6X+,E9V!:8Z?B?&"S(.-@T^#0X.3
M@JF"YY=,C/B!:CH`E5R"S)6=`)6=@LR24(C*`)6=@48`EWZ"M8*B@N""S(CJ
MEY<`B\Z6L9#F@LR/6H^*`(O.EK&0YH+,DV288I34C88`)60@C7.6VH+%BM2(
MX8+!@KV-@);:D)2!0I"S@K6"K8+-("5D@4&.=Y+H@K."ZH*]@LR"S2`E9(%"
M`(K4B.&"P8*]C8"6VI"4@4*0LX*U@JV"S2`E9(%!CG>2Z(*S@NJ"O8+,@LT@
M)62!0@!61E.#=(-`@T.#BX+,D\>"W8]O@K62AH+)E7.0LX+(@TF#=(-:@V*#
M9R`E9"""JHYWDNB"LX+J@MR"M8*]@4(`6#4P.78S((KNEGN0IXS``%@U,#EV
M,R",KHYGEW"60`!8-3`Y=C,@CN61S([2@LR5RI:\`%@U,#EV,R".Y9',CM*"
MS(RNCJ^5RHYQ`%@U,#EV,R"*9Y*CBT"47`"43@"43@"6B)1.`(-#@T>#@8.3
MBZ2888V1`(+-@J(`DZ^(TX*U@MR"MP"-H8+-@V6#3(-8@V>#@H%;@VB"Q8*W
M@4);/#Y=@WN#7H.3@L5765-)5UE'@X*!6X-H@LF6WX+H@MR"MX%"`"5D((C(
MC^."S(-U@XV#8H-.@O"-[)"L@K>"Z8*Q@L:"S8N6B<*"LX+J@L2"HH+<@KF"
M\8%"`(*@@LB"O8+-E$:/V(*S@NJ"Q(*B@MR"N8+Q@4(`EKR13X+,DH:"R2`G
M7"<@@L:"HH*DE;:.FH+-CF>"IH+<@KF"\8%"`)=,C/B"R)-DCG&#@8%;@XN#
M08-H@XR#6(+%@LV"H(+H@MR"N8+Q@4(`@T.#DX-\@5N#9X*S@NJ"O8-T@T"#
M0X.+@LR#=(-"@5N#BX-H@O`E<Y/@@LR1SHF>@K>"Z8-T@T*!6X.+@VB"R8-]
M@V*#=H*U@L2"W(*Y@O$N`(.-@T^#08-%@V>"M8+<@K6"O2X`D+."M8*BDV28
M8I34C8:"\)/\E\V"MX+I@N:"I(+)DHV(TX*U@L2)NH*S@J*!0I"4CIJ"OH*O
M@JJ.9Y=P@L6"JX+<@K>"JH%!C9&-VY-DF&*"R(+GD.:3JH+)@7N"\)5T@J^"
MW(*W@4(`D+."M8*BDFR"\)/\E\V"M8+$B;J"LX*B@4(`@U2#0X.3@T&#8H-V
M@O"7F)=P@K>"Z8*]@M^"R8+-($1A=&%4<F5E((-O@V*#3H-'@Y.#:(+PD-V2
MZ(*W@NF52Y=V@JJ"H(+H@MR"MX%"`%9&4R"#;X-B@TZ#1X.3@VB"\)#=DNB"
MMX+IE4N7=H*J@J""Z(+<@K>!0@"/X8I1@LR3X)=E@O"+3(]Q@K6"Q(*I@N>!
M08_ABE&#C(-\@5N#9X+PD9>038*U@L2"K8*^@K."HH%"`(*Q@K&"R8.*@Y.#
M3H*W@NE54DR"\)/\E\V"M8+$B;J"LX*B`(WMCYR"MX+I@U2!6X-O@O".=Y+H
M@K6"Q(*M@KZ"LX*B@4(`C\&+CH*W@NF#AH%;@U66O(+PCG>2Z(*U@L2"K8*^
M@K."HH%"`(WMCYR"MX+I@X:!6X-5EKR"\(YWDNB"M8+$@JV"OH*S@J*!0@"2
MQXG!@K>"Z8.&@5N#59:\@O".=Y+H@K6"Q(*M@KZ"LX*B@4(`C5B05H*W@NF#
MAH%;@U66O(+PCG>2Z(*U@L2"K8*^@K."HH%"`([`C7."MX+I@T&#3H-6@X>#
MDX+PCG>2Z(*U@L2"K8*^@K."HH%"`)!6@K6"HI6JE]Z6O(+PD_R7S8*U@L2)
MNH*S@J*!0@`E<R"#6H-B@U:#AX.3@LR73(SXBOJ,P(*JD-B"ZH+$@J*"W(*W
M@4*#C8-/@T.#DX*UDKR"M8+$@JV"OH*S@J*!0@"39(YQ@X&!6X.+@T&#:(.,
M@U@`@J""R(*]@LP@1G)O;3H@@T&#:(.,@U@`@J""R(*]@LR#0X.3@W2#2(.!
M@5N#5H.'@Y,`@UJ#8H-6@X>#DR`E<R""S(K4@LF"H(+(@KV"S(-!@VB#C(-8
M@JJ5SXU8@K."ZH+<@K6"O8%"@UJ#3(.%@XJ#98-"@5N5VXSL@LR"O8+?@LF#
MC8-/@T.#DX*UDKR"MX+7@JN"Q8*W@4(`@J""R(*]@LR6O)%/`(*Q@LR41H_8
M@V^#8H-.@T>#DX-H@L6"S8%!@X:!6X-5@LR2QXG!@JJ#5(-\@5N#9X*S@NJ"
MQ(*B@MR"N8+Q@4*"X(*U($AO<F1E((+%@X:!6X-5@T&#2H-%@Y.#9X+PBL>7
MG8*U@KV"HH+,@LB"YX%!D;R"S)1&C]B#;X-B@TZ#1X.3@VB"\(YG@J2"UX*K
M@L6"MX%"`(*Q@LR41H_8@V^#8H-.@T>#DX-H@L6"S8%!@X:!6X-5@LR#BH-8
M@V>"JH-4@WR!6X-G@K."ZH+$@J*"R(*B@JF!08*@@NF"HH+-B;V"YX*I@LR7
MG9=2@L6"L8+,BT"47(*JEK.,^(+)@LB"P8+$@J*"W(*W@4(`@UJ#8H-6@X>#
MDR`E<R""S(K4@LF"H(+(@KV"S(-U@XF#18-5@JJ5SXU8@K."ZH*]@N:"I(+(
M@LR"Q8%!@UJ#3(.%@XJ#98-"@5N5VXSL@LR"O8+?@LF#C8-/@T.#DX*UDKR"
MMX+7@JN"Q8*W@4(`@JB.9X*B@LR#=8.)@T6#58+-@K&"S(M`E%R"\(-4@WR!
M6X-G@K6"Q(*B@MR"N8+Q@4(`@JB.9X*B@LR#=8.)@T6#58+-@K&"S(CSC?R#
M28-V@U:#AX.3@O"#5(-\@5N#9X*U@L2"HH+<@KF"\8%"0V]N=')O;"]#;VUM
M86YD("L@4"""Q8CSC?R"M8+$B;J"LX*B@4(`@UZ#0X.`@UV!6X.3@48`@J""
MR(*]@LR#9H-T@TB#BX-G242"S97/C5B"LX+J@MR"M8*]@4(`@J""R(*]@LR#
M9H-T@TB#BX-G240Z`(*@@LB"O8+,CH&6O`"#C8-/@T.#DX+-BOJ,P)#8@NJ"
MQ8*W@4(`D%:"M8*B("5S()=P@LR#<(-8@X^!6X-H@48E<P""H(+(@KV"S(-)
M@W:#5H.'@Y."S8R[C=V"S(-:@V*#5H.'@Y.2AH+)E<^-6(*S@NJ"W(*U@KV!
M0@"#28-V@U:#AX.3@O"-6)!6@K6"W(*U@KT`@W"#6(./@5N#:(+-@XJ#6H-B
M@V>"LX+J@MR"M8*]@4(`@W"#6(./@5N#:(+-@XJ#6H-B@V>"LX+J@MR"M8*]
M@LR"Q8%!D%:"M8*B@W"#6(./@5N#:(+%@XV#3X-#@Y."M8+$@MV"Q(FZ@K."
MHH%"`(-P@UB#CX%;@VB"JHKZC,"0V(+J@L6"MX%"`(.*@X*!6X-G@U2!6X-O
M.@"#AH%;@U.#6(.)@W*#00"#58-#@5N#BXNDF&&-D8%I@U*#DX-3EJ^.Y8ND
MF&&-D8%J`(-5@Y.#<H-!BZ2888V1`(-7@Y.#;X-U@T>+I)AAC9$`@6V/X8I1
ME?&-D(%N`%N-<SHE<R\E<UT`7T&*QY>=`%]$C7."\(WMCYP`7T>#3X.+@5N#
M=@!?2(-W@XN#=@!?28GFD9R#=H.-@W"#98-"+BXN`%],@XV#3X-#@Y,`7TR#
MC8-/@T&#18-G`%]-@XJ#DX-.E<^-6`!?3X-)@W:#5H.'@Y,`7U"#08-.@UJ#
M6(R@`%]2@XJ#DX-.C>V/G`!?4X-:@V*#9X-!@V*#=@!?5)5<D:Z0JP!?58.&
M@5N#50"#08-H@XR#6)*@`)5SEKZ"R(-!@VB#C(-8`)=<DNB57`"/;Y?-@W2#
M0(-#@XN"JHWLD*R"Q8*K@MR"N8+Q`)/\E\V#=(-`@T.#BX*JBDJ"KX+<@KF"
M\0""L8*Q@O"#3H.*@V*#3@"#4H-]@Y.#:(USCF>7<(+,@T>#B8%;`)#=DNB#
M1X.)@5L`CV27=H+(@U:#6(-E@X"#=(-`@T.#BX+,C(>7C@"#9H%;@UZ,8(ZN
M@T>#B8%;`)72CU<`C8"6VH*J@J""Z(+<@KF"\0"#=(-`@T.#BP"#>H-8@V>6
MO(*JE7.6O@"3_(]OE\V#1X.)@5L`@UR#=(-G@T6#1H-!D^"5E(+,@T>#B8%;
M`):\D4\`CL"1E8*S@NJ"Q(*B@MR"N8+Q`(+<@KZ.P)&5@K."ZH+$@J*"W(*Y
M@O$`@X&#@I*@`(-P@5N#6H.3@V<`@T&#3H-:@UB"S8N1E-N"LX+J@MR"M8*]
M`(-S@TZ#6H.+`(.*@X*!6X-G@L6"S(-V@XV#9X-2@XN#1X.)@5L`@U2!6X-R
M@UB5<Y1<`(VWE:J"\)5<CJ8`@U:#6(-E@X"#1X.)@5L`@UZ#6(-.@XJ#6(-G
M`(CJCIZ328+(@T>#B8%;`(IME$:"S(*]@M^#<(-8@X^!6X-H,I-XD_R7S8*U
M@L2)NH*S@J(`EK.6O`!V0V%R9```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VIA7TI0+VAE;'`N>&UL
M````````````````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S,S(P
M(#$P-3$U-#,S-S0Q(#`R,30S,``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/WAM;"!V97)S:6]N/2(Q+C`B/SX*/"$M+2`D
M2&]R9&4Z(&AO<F1E+VQO8V%L92]J85]*4"]H96QP+GAM;"QV(#$N,B`R,#`T
M+S`U+S(W(#(P.C(R.C$T(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y
M(&ED/2)S=6UM87)Y(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H92!0;W)T86P@
M4&%G93PO=&ET;&4^"B`\<&%R83X*("!4:&ES('!O<G1A;"!P86=E('!R;W9I
M9&5S(&$@<75I8VL@<W5M;6%R>2!O9B!A;&P@>6]U<B!I;7!O<G1A;G0*("!I
M;F9O<FUA=&EO;BX@1F]R(&5X86UP;&4L(&ET(&UI9VAT('-H;W<@:&]W(&UA
M;GD@;F5W(&4M;6%I;"!M97-S86=E<R!Y;W4*("!H879E(&EN('EO=7(@24Y"
M3U@L('5P8V]M:6YG(&5V96YT<R!O;B!Y;W5R(&-A;&5N9&%R+"!T87-K<R!O
M;B!Y;W5R('1O+61O"B`@;&ES="P@:&5A9&QI;F5S(&9R;VT@<V5L96-T960@
M;F5W<R!S97)V:6-E<RP@86YD('-O(&]N+B`@36%N>2!O9B!T:&5S90H@('-U
M;6UA<FEE<R!W:6QL(&-O;G1A:6X@<75I8VL@<VAO<G1C=71S('1O(&-O;6UO
M;B!F=6YC=&EO;G,L('-U8V@@87,*("!C;VUP;W-I;F<@82!N97<@;6%I;"!M
M97-S86=E+"!C<F5A=&EN9R!A(&YE=R!C86QE;F1A<B!E=F5N="!O<B!T87-K
M+"!E=&,N"B`\+W!A<F$^"B`\<&%R83X*("!4:&4@8V]N=&5N=',@;V8@=&AI
M<R!P;W)T86P@<&%G92!A<F4@8W5S=&]M:7IA8FQE('9I82!T:&4@3&%Y;W5T
M(&)U='1O;BX*("!&;W(@97AA;7!L92P@>6]U(&-A;B!C:&]O<V4@=VAI8V@@
M:71E;7,@=&\@:6YC;'5D92!O;B!T:&ES('!O<G1A;"!P86=E(&%S"B`@=V5L
M;"!A<R!I;B!W:&EC:"!O<F1E<B!T:&5Y(&%R92!S:&]W;BX*(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](FYA=F)A<B(@<W1A=&4](FYE=R(^"CQT
M:71L93Y4:&4@07!P;&EC871I;VX@3F%V:6=A=&EO;B!"87(\+W1I=&QE/@H@
M/'!A<F$^"B`@070@=&AE(&QE9G0@:&%N9"!S:61E(&]F('1H92!W96(@<&%G
M92!I<R!T:&4@87!P;&EC871I;VX@;F%V:6=A=&EO;B!B87(N"B`@0VQI8VL@
M;VX@=&AE(&EC;VYS(&]N('1H:7,@;F%V:6=A=&EO;B!B87(@=&\@<75I8VML
M>2!A;F0@96%S:6QY('-W:71C:`H@(&)E='=E96X@=&AE(&%V86EL86)L92!A
M<'!L:6-A=&EO;G,N"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P
M<F5F<RUD;U]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^
M4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!$;R!-86EN=&5N86YC93PO=&ET
M;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O('!E<F9O
M<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;BP@8VAE8VL@=&AI
M<R!B;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F
M<RUC;VYF:7)M7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L
M93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($-O;F9I<FT@36%I;G1E;F%N
M8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T
M;R!C;VYF:7)M(&%L;"!M86EN=&5N86YC92!T87-K<R!B969O<F4@=&AE>2!A
M<F4@<G5N+"!C:&5C:R!T:&ES(&)O>"X@268@;&5F="!U;F-H96-K960L(&%L
M;"!M86EN=&5N86YC92!O<&5R871I;VYS('1H870@;F5E9"!T;R!B92!R=6X@
M=VEL;"!B92!P97)F;W)M960@875T;VUA=&EC86QL>2!W:71H(&YO(&-H86YC
M92!T;R!C86YC96P@;VX@;&]G:6XN"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO
M:&5L<#X*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]I<U])4P``````````````````
M````````````````````````````````````````````````````````````
M```````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q
M-30S,S<T,2`P,3<W,C0`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VES
M7TE3+TQ#7TU%4U-!1T53````````````````````````````````````````
M`````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S0Q(#`R,34Q,0`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L;V-A;&4O:7-?25,O3$-?34534T%'15,O:&]R9&4N;6\`````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3,W-3$@,3`U,34T,S,W-#$@,#(S
M,C,U`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`-X2!)4`````=P```!P```#4`P``HP```(P'````````&`H```P````9"@``
M`P```"8*```?````*@H```4```!*"@``!@```%`*```$````5PH``!8```!<
M"@``!@```',*```&````>@H``!D```"!"@``%````)L*```$````L`H```8`
M``"U"@``*````+P*```$````Y0H```@```#J"@``$````/,*```&````!`L`
M``\````+"P``"````!L+```+````)`L```0````P"P``#0```#4+```%````
M0PL``!````!)"P``$````%H+```/````:PL```\```!["P``#````(L+```(
M````F`L```<```"A"P``!````*D+```$````K@L``!````"S"P``!P```,0+
M```$````S`L```0```#1"P``"````-8+```-````WPL```X```#M"P``%@``
M`/P+```1````$PP```8````E#```!@```"P,```'````,PP```0````[#```
M!P```$`,```)````2`P```8```!2#```!P```%D,```+````80P```0```!M
M#```!@```'(,```(````>0P```@```""#```!````(L,```%````D`P```8`
M``"6#```$````)T,```*````K@P```,```"Y#```)````+T,```'````X@P`
M``8```#J#```'P```/$,```&````$0T```T````8#0```@```"8-```*````
M*0T```8````T#0``!@```#L-```)````0@T```<```!,#0``!````%0-```%
M````60T```0```!?#0```@```&0-```$````9PT```@```!L#0```@```'4-
M```'````>`T```<```"`#0``"````(@-```4````D0T``"D```"F#0``!0``
M`-`-```&````U@T``!\```#=#0``"0```/T-```$````!PX```<````,#@``
M!P```!0.```$````'`X``",````A#@``+P```$4.```A````=0X``!P```"7
M#@```@```+0.```'````MPX```P```"_#@``"````,P.```'````U0X```<`
M``#=#@``#0```.4.```#````\PX``#````#W#@``$P```"@/```0````/`\`
M`%,```!-#P``%P```*$/```6````N0\```\```#0#P``'P```.`/```%````
M`!````@````&$```"`````\0```$````&!````8````=$```6P$``"00```+
M````@!$```H```",$0``%@```)<1```%````KA$```4```"T$0``!````+H1
M```6````OQ$```D```#6$0``!@```.`1```;````YQ$``!$````#$@``!0``
M`!42```'````&Q(``#@````C$@``!````%P2```(````81(``!0```!J$@``
M!````'\2```0````A!(``!8```"5$@``&0```*P2```&````QA(```<```#-
M$@``!0```-42```0````VQ(``!````#L$@``%0```/T2```1````$Q,```\`
M```E$P``!P```#43```$````/1,```,```!"$P``!0```$83```*````3!,`
M``8```!7$P``!````%X3```$````8Q,```@```!H$P``#P```'$3```1````
M@1,``!@```"3$P``%0```*P3```(````PA,```L```#+$P``!P```-<3```'
M````WQ,```<```#G$P``!P```.\3```(````]Q,```8`````%```%0````<4
M```)````'10```8````G%```"````"X4```.````-Q0```0```!&%```!```
M`$L4```'````4!0```T```!8%```"0```&84```#````<!0``"8```!T%```
M!@```)L4```&````HA0```H```"I%```!@```+04```(````NQ0```(```#$
M%```"P```,<4```&````TQ0```8```#:%```#````.$4```*````[A0```0`
M``#Y%```!@```/X4```%````!14```,````+%0``!0````\5```(````%14`
M``8````>%0``!P```"45```-````+14```@````[%0``%@```$05```A````
M6Q4```H```!]%0``!0```(@5```:````CA4```D```"I%0``!0```+,5```$
M````N14```D```"^%0``!0```,@5```>````SA4``#$```#M%0``(P```!\6
M```@````0Q8```,```!D%@``!@```&@6```1````;Q8```L```"!%@``!P``
M`(T6```'````E18``!````"=%@```@```*X6```O````L18``!L```#A%@``
M"P```/T6``!5````"1<``!0```!?%P``%@```'07```0````BQ<``"8```"<
M%P``!0```,,7```&````R1<```D```#0%P``!0```-H7```(````X!<```$`
M```&`````````%<```!A````*`````````!D```````````````]````*0``
M``````!-````2@```&X`````````+P```!`````V````#@```&<````*````
M+@```#\````"`````````!$```!1````7````#0````B````/@```$L```!J
M````0@```#`````>````"````$4`````````-P``````````````=@``````
M```+````=`````P`````````2````#$`````````;`````````!.````````
M``,```!@````:``````````8````;0```$0`````````0P````````!F````
M60`````````%`````````!4```!0`````````&4````A`````````$`````C
M````$P````````!U````.0```%X```!3````50```#4`````````00``````
M```9````6````',```!)````%@```````````````````&L`````````.@``
M`!T````D`````````````````````````"L````M````5@`````````2````
M4@````T````;````'``````````L`````````$P`````````=P```"H```!;
M````1@```&(```!I````(````"4```!/````!````#,````\````1P```'``
M````````7P```%H````/````!P``````````````&@```&\````G````````
M`%T````X````%````#(```!C`````````"8```!R````"0```!\````7````
M.P````````!Q````5```````````061D<F5S<R!";V]K`$%L;`!!;B!I;&QE
M9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%P<FEL`$%U9W5S=`!";W1H`$)U
M:6QD:6YG(&QO8V%L92`E<RXN+B``0V%N8V5L`$-H86YG90!#;&5A;FEN9R!U
M<"!L;V-A;&4@)7,N+BX@`$-O;7!O<V4@365S<V%G92`H)7,I`$-O<'D`0W)E
M871E`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`
M1&%T90!$96-E;6)E<@!$969A=6QT($ED96YT:71Y`$1E;&5T90!$:7-P;&%Y
M($]P=&EO;G,`1&]W;FQO860`1&]W;FQO860@)7,`161I=`!%;6%I;"!!9&1R
M97-S`$5R<F]R`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%
M=F5R>2`U(&UI;G5T97,`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!&
M96)R=6%R>0!&:6QT97)S`$9R;VT`2&5L<`!)9&5N=&ET>2=S(&YA;64Z`$IA
M;G5A<GD`2G5L>0!*=6YE`$QA;F=U86=E`$QA<W0@57!D871E9#H`3&%S="!L
M;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.
M979E<@!,871V:6$`3&%Y;W5T`$QE8F%N;VX`3&5F=`!,:6)E<FEA`$QI=&AU
M86YI80!,;V<@:6X`3&]G(&]U=`!,;V=I;B!487-K<P!-86EL`$UA;&%W:0!-
M86QA>7-I80!-86QD:79E<P!-86QI`$UA<F-H`$UA<F=I;@!-87)S:&%L;"!)
M<VQA;F1S`$UA=7)I=&%N:6$`36%Y`$UE<F=I;F<@=')A;G-L871I;VX@9F]R
M(&UO9'5L92`E<RXN+@!-97-S86=E`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E
M<F%T960@4W1A=&5S(&]F`$UI<G)O<@!-:7-C96QL86YE;W5S`$UO`$UO9&EF
M>2!54DP`36]D=6QE`$UO;F%C;P!-;W9E($1O=VX`36]V92!5<`!.86UE`$YE
M=F5R`$YE>'0`3F\`3F]N90!.;W9E;6)E<@!/2P!/8W1O8F5R`$]P=&EO;G,`
M4&%S<W=O<F0`4&5R<V]N86P@26YF;W)M871I;VX`4&QE87-E('!R;W9I9&4@
M>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4F5S970`4V5A<F-H`%-E;&5C
M="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5P=&5M8F5R`%-I>F4`4W5B
M:F5C=`!3=6-C97-S`%1E>'0`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@
M9&5L971E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M
M97-S86=E('!A<G0`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N
M`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&\`56YN86UE9`!5<V5R
M($]P=&EO;G,`57-E<FYA;64`5FEE=R`E<P!787)N:6YG`%=E;&-O;64@=&\@
M)7,`665S`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO
M9VEN(&%G86EN+@!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I
M;VX`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O
M<'1I;VXN(%!R97-S($-O;G1R;VPO3W!T:6]N("L@4"!T;R!P<FEN="X`66]U
M<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&ED96YT:71Y.@!9
M;W5R(&9U;&P@;F%M93H`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D
M+@!?2&5L<`!?3&]G(&]U=`!?3W!T:6]N<P!D;VYE`&9A:6QE9`!0<F]J96-T
M+4ED+59E<G-I;VXZ($AO<F1E(#,N,"XU"E)E<&]R="U-<V=I9"U"=6=S+51O
M.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`R
M+3`Q+3$P(#$Y.C`P*S`Q,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-2TQ,2TQ
M.2`R,#HS,RLP,#`P"DQA<W0M5')A;G-L871O<CH@0FIO<FX@1&%V:61S<V]N
M(#QB:F]S<VE`<VYE<G!A+FES/@I,86YG=6%G92U496%M.B!)8V5L86YD:6,@
M/'-U<'!O<G1`<VYE<G!A+FES/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT
M+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,0I#;VYT96YT
M+51R86YS9F5R+45N8V]D:6YG.B`X8FET"@!.971F86YG86+S:P#6;&P@<VME
M>71I`--TYFMT(&=I;&1I('1I;&=R96EN="X`87!R[6P`X6?Z<W0`0N;P:0!"
M>6=G:2!N^B!L;V-A;&4@)7,@+BXN`$CF='1A('9I\`!"<F5Y=&$`2')E:6YS
M82!T:6P@[2!L;V-A;&4@)7,@+BXN`%-E;6IA('-K97ET:2`H)7,I`$%F<FET
M`$+Z82!T:6P`4W1I;&QA(&'P9V5R\&ER('-E;2!E<G4@9G)A;6MVYFUD87(@
M_F5G87(@_OH@=&5N9VES="`E<RX`1&%G<P!D97-E;6)E<@!3:N%L9F=E9FGP
M(&ME;FYI;6%R:P!%>?!A`-IT;&ET<W-T:6QL:6YG87(`4^9K:F$@>69I<B#A
M('9I;FYU<W3V\`!3YFMJ82`E<R!Y9FER(.$@=FEN;G5S=/;P`$)R97ET80!.
M971F86YG`%9I;&QA`,$@:V]R=&5R<R!F<F5S=&D`P2`S,"!S96LN(&9R97-T
M:0#!(&9I;6T@;>UN^G1N82!F<F5S=&D`P2!HX6QF=.UM82!F<F5S=&D`P2!M
M[6[Z='4@9G)E<W1I`&9E8G+Z87(`4^UU<@!&<N$`2&KA;'``2V5N;FEN869N
M.@!J86[Z87(`:OIL[0!J^F[M`%1U;F=U;>%L`'/M\&%S="!U<'!FYG)T.@!3
M[?!A<W0@=&5N9W-T.B`E<P!3[?!A<W0@=&5N9W-T.B`E<R!F<N$@)7,`4^WP
M87-T('1E;F=S=#H@06QD<F5I`$QE='1L86YD`$9R86US971N:6YG`$SM8F%N
M;VX`5FEN<W1R:0!,[6)E<NUA`$QI=&CA96X`5&5N9VIA<W0`VG1S:W+A`%9E
M<FME9FYI('9I\"!T96YG:6YG=0!6969P\W-T=7(`36%L87;M`$UA;&'M<^UA
M`$=RYFYH]F;P865Y:F%R`$UA;.T`;6%R<P!3<.%S<^UA`$UA<G-H86QL97EJ
M87(`3>%R[71A;NUA`&UA[0!386UE:6YA(/[]\&EN9V%R(&9Y<FER("5S(&5I
M;FEN9W5N82XN+@!3:V5Y=&D`365X[6OS`$WM:W+S;F5S[6$`4W!E9VQA`-UM
M:7-L96=T`$WA`$)R97ET82!S;//P`$5I;FEN9P!-\VYA:_,`1FQY=&IA(&YI
M\'5R`$9L>71J82!U<'``3F%F;@!!;&1R96D`3N9S=&$`3F5I`$5N9VEN`&[S
M=F5M8F5R`,T@;&%G:0!O:W3S8F5R`%9A;'-T:6QL:6YG87(`3'EK:6QO<O``
M57!P;/US:6YG87(@=6T@;F]T86YD80!3;.'P=2!I;FX@;F]T86YD86YA9FX@
M;V<@;'EK;&EO<O``16YD=7)S971J80!,96ET80!696QD=2!S:N%L9F=E9FGP
M('1U;F=U;>%L.@!S97!T96UB97(`4W3F<O``169N:0!&<F%M:W;F;70`5&5X
M=&D`2V5N;FEN=2`B)7,B(&AE9G5R('9E<FGP(&5Y='0N`%9I;&QA(&MO;2!U
M<'`@=FGP(&)I<G1I;F=U(/YE<W-A(&AL=71A('-K97ET:7-I;G,`5&%L86X@
M=F5R\'5R(&'P('9E<F$@8?`@;.%G;6%R:VD@,2X`WF5T=&$@9VEL9&D@=F5R
M\'5R(&'P('9E<F$@=&%L82X`5&EL`--N969N=`!686QK;W-T:7(@;F]T86YD
M80!.;W1A;F1A;F%F;@!3_6YA("5S`$'P=O9R=6X`5F5L:V]M:6XH;BD@[2`E
M<P!*X0!,;W1A;B`E<R!E<B!R=6YN:6X@^G0@X2!T[6UA+B!496YG9'4@_FEG
M(&%F='5R+@!&=6QL="!N971F86YG(/YI='0@*$9RX3HI(#H`57!P;/US:6YG
M87(`5F5F<VMO\&%R:2#^:6YN('-T>?!U<B!E:VMI(/YE<W-A('!R96YT8?!G
M97+P+B!.;W1A\'4@0U123"]/<'1I;VX@;V<@4"!T:6P@8?`@<')E;G1A+@!.
M^G9E<F%N9&D@=.UM86)E;'1I.@!3:N%L9F=E9FGP(&ME;FYI(/YI='0Z`$9U
M;&QT(&YA9FX@_FET=#H`4W1I;&QI;F=A<B#^[6YA<B!H869A('9E<FGP('5P
M<&;F<O!A<BX`2&KA;'``VG1S:W+A`%9A;&MO<W1I<@!L;VMI\`!K;&EK:V'P
M:0```````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQO8V%L92]I=%])5```````````````````````````````````````
M```````````````````````````````````````````````P,#`W-34@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<T,2`P,3<W,C8`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VET7TE4+TQ#7TU%4U-!1T53
M````````````````````````````````````````````````````````````
M`````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P
M-3$U-#,S-S0Q(#`R,34Q,P`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O
M:71?250O3$-?34534T%'15,O:&]R9&4N;6\`````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`S,C4Q,C<@,3`U,34T,S,W-#$@,#(S,C0R`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````-X2!)4`````AP4``!P`
M``!4+```80<``(Q8````````$'8```X````1=@``#P```"!V```-````,'8`
M``@````^=@``"P```$=V```,````4W8```0```!@=@``&````&5V```;````
M?G8``"T```":=@``'0```,AV```D````YG8``"D````+=P``&0```#5W```F
M````3W<```P```!V=P``)````(-W```/````J'<```L```"X=P``#@```,1W
M```%````TW<``"@```#9=P``"`````)X```*````"W@``!4````6>```$@``
M`"QX```+````/W@``(4```!+>```#@```-%X```*````X'@```T```#K>```
M#@```/EX```1````"'D```T````:>0``#````"AY```-````-7D```8```!#
M>0``E````$IY```*````WWD```\```#J>0``&````/IY```,````$WH```X`
M```@>@``#@```"]Z```(````/GH```D```!'>@``+@```%%Z```:````@'H`
M`#(```";>@``.````,YZ``!4````!WL``%$```!<>P``6@```*Y[``!7````
M"7P``#0```!A?```"0```)9\```-````H'P```<```"N?```"@```+9\```/
M````P7P```4```#1?```!@```-=\```1````WGP```@```#P?```)0```/E\
M```@````'WT``!,```!`?0``$````%1]```/````97T```H```!U?0```P``
M`(!]```/````A'T``!0```"4?0``"0```*E]```-````LWT``!(```#!?0``
M&0```-1]```>````[GT```\````-?@``"@```!U^```/````*'X```@````X
M?@``)````$%^```4````9GX``!8```![?@``"````))^``!.````FWX``"T`
M``#J?@``&0```!A_```'````,G\```P````Z?P``+````$=_```.````='\`
M``4```"#?P``"@```(E_```#````E'\``!<```"8?P``"@```+!_```/````
MNW\```X```#+?P``&````-I_```C````\W\```X````7@```%````":````7
M````.X```!<```!3@```%P```&N````3````@X````\```"7@```'P```*>`
M```=````QX````8```#E@```"P```.R````0````^(```!4````)@0``%0``
M`!^!```'````-8$``!`````]@0``!0```$Z!```1````5($```P```!F@0``
M.P```'.!```X````KX$``#D```#H@0``$@```"*"```G````-8(``"P```!=
M@@``*@```(J"```E````M8(```H```#;@@``!@```.:"```O````[8(``#<`
M```=@P``+@```%6#``!5````A(,``"T```#:@P``+0````B$```]````-H0`
M`#\```!TA```+0```+2$``!`````XH0``",````CA0``(P```$>%``!`````
M:X4``"T```"LA0``,P```-J%```E````#H8``!4````TA@``&0```$J&```I
M````9(8``"0```".A@``*````+.&```1````W(8```H```#NA@``$````/F&
M```6````"H<``!8````AAP``)P```#B'```(````8(<``"D```!IAP``#@``
M`).'```*````HH<```0```"MAP``"0```+*'```&````O(<``!$```##AP``
M!P```-6'```6````W8<```0```#TAP``!@```/F'```&`````(@```T````'
MB````P```!6(```#````&8@``!<````=B```$P```#6(```=````28@```@`
M``!GB```!````'"(```(````=8@``#L```!^B```-````+J(``!!````[X@`
M`!H````QB0``*P```$R)```@````>(D``!4```"9B0``!@```*^)```5````
MMHD``!@```#,B0``(@```.6)```N````"(H``!T````WB@``(0```%6*``!4
M````=XH``"D```#,B@``!P```/:*```5````_HH```X````4BP``"@```".+
M```/````+HL```T````^BP``#P```$R+```-````7(L```D```!JBP``!@``
M`'2+```=````>XL``!,```"9BP``$0```*V+```4````OXL```8```#4BP``
M%````-N+``!4````\(L``&0```!%C```!````*J,```.````KXP```4```"^
MC```!0```,2,```3````RHP``!$```#>C```$0```/",```<`````HT``"H`
M```?C0``(0```$J-```%````;(T```L```!RC0``$@```'Z-```*````D8T`
M``\```"<C0``#0```*R-```1````NHT```P```#,C0``!@```-F-```,````
MX(T```8```#MC0``$````/2-```1````!8X```4````7C@``#````!V.```0
M````*HX```4````[C@``#0```$&.```&````3XX```<```!6C@``#0```%Z.
M```'````;(X```L```!TC@``!P```(".```)````B(X```D```"2C@``"@``
M`)R.```9````IXX``#T```#!C@``'0```/^.```,````'8\``!`````JCP``
M$@```#N/```3````3H\``"L```!BCP``.P```(Z/```@````RH\```@```#K
MCP``-@```/2/```A````*Y```!````!-D```"````%Z0```$````9Y````\`
M``!LD```#@```'R0```?````BY```!P```"KD```(0```,B0```>````ZI``
M`!D````)D0``'@```".1```;````0I$``"$```!>D0``+@```("1```F````
MKY$``!P```#6D0``'@```/.1```<````$I(``"8````OD@``*P```%:2```S
M````@I(``"8```"VD@``*P```-V2```X````"9,``!T```!"DP``%0```&"3
M```O````=I,``"````"FDP``$@```,>3```I````VI,``!X````$E```(```
M`".4```2````1)0``*(```!7E```%@```/J4```C````$94``"@````UE0``
M*0```%Z5```H````B)4``!\```"QE0``%0```-&5```@````YY4``"4````(
ME@``*````"Z6```M````5Y8``#````"%E@``D@```+:6```A````29<``!P`
M``!KEP``)@```(B7```J````KY<``$$```#:EP``1````!R8```,````89@`
M``<```!NF```!P```':8```&````?I@```T```"%F```$````).8```2````
MI)@``!,```"WF```$@```,N8```0````WI@``!````#OF```#`````"9```.
M````#9D```T````<F0``#P```"J9```3````.ID```T```!.F0``*````%R9
M```#````A9D```T```")F0``!@```)>9```%````GID```0```"DF0``#0``
M`*F9```.````MYD```,```#&F0``#@```,J9```(````V9D```\```#BF0``
M#P```/*9```-`````IH``!`````0F@``#0```"&:```+````+YH```8````[
MF@``"P```$*:```,````3IH```H```!;F@``$0```&::```9````>)H```L`
M``"2F@``#0```)Z:```B````K)H```\```#/F@``&P```-^:```T````^YH`
M``H````PFP``&````#N;```2````5)L``!D```!GFP``%@```(&;```B````
MF)L```T```"[FP``!P```,F;```4````T9L```L```#FFP``(@```/*;```O
M````%9P```L```!%G```"0```%&<```9````6YP```L```!UG```%P```(&<
M```7````F9P``!8```"QG```#P```,B<```9````V)P```X```#RG```&```
M``&=```-````&IT``"8````HG0``0P```$^=```?````DYT```@```"SG0``
M"P```+R=```O````R)T```4```#XG0``!````/Z=```*`````YX```H````.
MG@``#P```!F>```0````*9X``!<````ZG@``$0```%*>```9````9)X``!<`
M``!^G@``!0```):>```*````G)X```T```"GG@``&P```+6>```7````T9X`
M``X```#IG@``#0```/B>```2````!I\``#@````9GP``(````%*?```(````
M<Y\```X```!\GP``>P```(N?```8````!Z```!@````@H```!0```#F@```8
M````/Z```!X```!8H```&P```'>@```9````DZ```!L```"MH```&0```,F@
M```3````XZ```!````#WH```#P````BA```0````&*$```\````IH0``"P``
M`#FA```/````1:$```P```!5H0``#P```&*A```'````<J$```8```!ZH0``
M#@```(&A```,````D*$``"@```"=H0``#P```,:A```(````UJ$```@```#?
MH0``$P```.BA```>````_*$``"$````;H@``(````#VB```9````7J(``!<`
M``!XH@``)0```)"B```7````MJ(``!8```#.H@``!````.6B```,````ZJ(`
M``@```#WH@``"@````"C```,````"Z,``!,````8HP``%````"RC```,````
M0:,```D```!.HP``#@```%BC```+````9Z,``!L```!SHP``!P```(^C```'
M````EZ,```H```"?HP``#0```*JC```)````N*,```,```#"HP``&````,:C
M```*````WZ,```0```#JHP``)@```.^C```.````%J0``!4````EI```"```
M`#ND```"````1*0```8```!'I```!````$ZD```)````4Z0``!````!=I```
M"0```&ZD```)````>*0``!H```""I```"````)VD```9````IJ0```X```#`
MI```!P```,^D```)````UZ0```H```#AI```#@```.RD```"````^Z0```L`
M``#^I```"0````JE```&````%*4``!0````;I0``'0```#"E``!"````3J4`
M`"4```"1I0``)0```+>E```&````W:4``!$```#DI0``"0```/:E```&````
M`*8```<````'I@``!@````^F```$````%J8``!$````;I@``!@```"VF```*
M````-*8``"(````_I@``!````&*F```%````9Z8``!T```!MI@``!````(NF
M```,````D*8```X```"=I@``"@```*RF```/````MZ8``!(```#'I@``"P``
M`-JF```F````YJ8``"D````-IP``)````#>G```F````7*<```@```"#IP``
M"@```(RG```'````EZ<``"````"?IP``(````,"G```F````X:<```H````(
MJ```&0```!.H```I````+:@``!(```!7J```!P```&JH```*````<J@```P`
M``!]J```#P```(JH```0````FJ@``$````"KJ```<````.RH``!F````7:D`
M``X```#$J0``"0```-.I```*````W:D``!(```#HJ0``$P```/NI```,````
M#ZH```8````<J@``#P```".J```2````,ZH``!````!&J@``$0```%>J```<
M````::H``",```"&J@``:@```*JJ```/````%:L``!`````EJP``"P```#:K
M```@````0JL``!0```!CJP``#````'BK```,````A:L```\```"2JP``%0``
M`**K```I````N*L``"H```#BJP``)@````VL```G````-*P``"D```!<K```
M*@```(:L```9````L:P``$(```#+K```$0````ZM```2````(*T``!,````S
MK0``%````$>M```/````7*T``!8```!LK0``%P```(.M```0````FZT``!$`
M``"LK0``-````+ZM```3````\ZT``!(````'K@``-0```!JN```4````4*X`
M``<```!EK@``#````&VN```@````>JX``!````";K@``%````*RN```1````
MP:X``!<```#3K@``'````.NN```3````"*\``!0````<KP``&@```#&O```1
M````3*\``!H```!>KP``'@```'FO```:````F*\``!,```"SKP``%0```,>O
M```1````W:\``!<```#OKP``%`````>P```7````'+````D````TL```$```
M`#ZP```&````3[````4```!6L```!P```%RP```%````9+````0```!JL```
M!````&^P```'````=+````X```!\L```#````(NP```,````F+````T```"E
ML```#@```+.P```H````PK````P```#KL```#P```/BP```*````"+$```@`
M```3L0``"0```!RQ```K````)K$```0```!2L0``!P```%>Q```(````7[$`
M``D```!HL0``%````'*Q```,````A[$```T```"4L0``#@```**Q```6````
ML;$``!$```#(L0```P```-JQ```&````WK$``!D```#EL0``!P```/^Q```$
M````![(```L````,L@``"P```!BR```%````)+(```H````JL@``!````#6R
M```/````.K(``#H```!*L@``!0```(6R```>````B[(```X```"JL@``$```
M`+FR```+````RK(```P```#6L@``"0```..R```'````[;(```H```#UL@``
M#@````"S```0````#[,``!L````@LP``&````#RS```:````5;,```H```!P
MLP``"@```'NS```,````AK,```\```"3LP``"````*.S```&````K+,```<`
M``"SLP``!0```+NS```+````P;,``$<```#-LP``#0```!6T```)````([0`
M``0````MM````P```#*T```3````-K0``!,```!*M```$P```%ZT```*````
M<K0``"4```!]M```!0```*.T```$````J;0```H```"NM```#0```+FT``!H
M````Q[0```4````PM0``!@```#:U```;````/;4``"\```!9M0``#P```(FU
M```3````F;4``!L```"MM0``&````,FU```7````XK4``!\```#ZM0``#@``
M`!JV```#````*;8```@````MM@``!P```#:V```+````/K8```<```!*M@``
M40```%*V```0````I+8```P```"UM@``!@```,*V```:````R;8``"4```#D
MM@``!@````JW```&````$;<```8````8MP``&````!^W```7````.+<``"@`
M``!0MP``!@```'FW```-````@+<``"(```".MP``5P```+&W```3````";@`
M`",````=N```$P```$&X```"````5;@```@```!8N```#0```&&X```*````
M;[@```<```!ZN```#@```(*X```'````D;@```L```"9N```,@```*6X```)
M````V+@```D```#BN```"@```.RX```'````][@```D```#_N```!P````FY
M```2````$;D```H````DN0``%@```"^Y```)````1KD``!````!0N0``$@``
M`&&Y```$````=+D```<```!YN0``!0```(&Y```,````A[D```@```"4N0``
M%P```)VY```,````M;D``!\```#"N0``&@```.*Y```3````_;D```0````1
MN@``"@```!:Z```$````(;H```T````FN@``#````#2Z```%````0;H```4`
M``!'N@``.````$VZ```L````AKH``"D```"SN@``,@```-VZ```*````$+L`
M`"P````;NP``+@```$B[```S````=[L``#,```"KNP``.````-^[```/````
M&+P``!@````HO```$````$&\```/````4KP``!,```!BO```%0```':\```4
M````C+P``!(```"AO```%````+2\```M````R;P``"T```#WO```,0```"6]
M```N````5[T``"\```"&O0``+````+:]``!B````X[T```T```!&O@``"```
M`%2^```7````7;X```@```!UO@``#````'Z^```K````B[X``"$```"WO@``
M&@```-F^```)````]+X``$4```#^O@``00```$2_```$````AK\``!,```"+
MOP``$P```)^_```&````L[\```D```"ZOP``"@```,2_```/````S[\``!``
M``#?OP``!P```/"_```.````^+\```4````'P```&P````W````(````*<``
M``8````RP```%````#G````1````3L````X```!@P```.````&_````&````
MJ,````X```"OP```!0```+[````'````Q,````8```#,P```*````-/````,
M````_,```!P````)P0``*0```";!```?````4,$``%P```!PP0``%````,W!
M```^````XL$``!\````AP@``$````$'"```'````4L(```X```!:P@``#```
M`&G"```,````=L(``!,```"#P@``"@```)?"```=````HL(``!D```#`P@``
M!0```-K"```1````X,(``!$```#RP@``)`````3#```2````*<,```X````\
MPP``&0```$O#```(````9<,```D```!NPP``&@```'C#```'````D\,```T`
M``";PP``'@```*G#```2````R,,``"P```#;PP``&@````C$```5````(\0`
M``4````YQ```%````#_$```$````5,0```8```!9Q```!P```&#$```>````
M:,0``"@```"'Q```"@```+#$```<````N\0``!$```#8Q```"P```.K$```:
M````]L0``!0````1Q0``!0```";%```&````+,4``!L````SQ0``-````$_%
M```T````A,4``"````"YQ0``*0```-K%```@````!,8``$$````EQ@``&@``
M`&?&```H````@L8``"D```"KQ@``4````-7&```B````)L<```8```!)QP``
M"````%#'```%````6<<```@```!?QP``&0```&C'```9````@L<``"H```"<
MQP``(P```,?'```N````Z\<``#0````:R```"````$_(```7````6,@```H`
M``!PR```!P```'O(```A````@\@``!````"ER```#@```+;(```+````Q<@`
M``<```#1R```$P```-G(```(````[<@```H```#VR```%`````')```/````
M%LD``#(````FR0``#@```%G)```%````:,D```\```!NR0``!````'[)```%
M````@\D```0```")R0``#0```([)```R````G,D``$4```#/R0``%P```!7*
M```'````+<H``!X````UR@``%````%3*```&````:<H```<```!PR@``#@``
M`'C*```J````A\H```8```"RR@``#````+G*```-````QLH``!$```#4R@``
M"P```.;*```V````\LH```H````IRP``(@```#3+```+````5\L```\```!C
MRP``,@```'/+```E````ILL``#````#,RP``,0```/W+```M````+\P```X`
M``!=S```!0```&S,```.````<LP``!,```"!S```$@```)7,```'````J,P`
M`!$```"PS```$P```,+,```'````ULP``!0```#>S```&````//,```'````
M#,T```4````4S0``#````!K-```,````)\T``!(````TS0``!````$?-```*
M````3,T```L```!7S0``#````&/-```.````<,T```X```!_S0``!0```([-
M```%````E,T``"X```":S0``)@```,G-```C````\,T```,````4S@``'@``
M`!C.```8````-\X``"4```!0S@``#0```';.```?````A,X``!(```"DS@``
M$@```+?.```$````RLX```D```#/S@``!P```-G.```,````X<X``%(```#N
MS@``%P```$'/```D````6<\```<```!^SP``!@```(;/```.````C<\```P`
M``"<SP``#0```*G/```5````M\\``!(```#-SP``#P```.#/```4````\,\`
M``H````%T```&P```!#0```0````+-````L````]T```:0```$G0```:````
ML]```!<```#.T```)P```.;0```:````#M$``!<````IT0``&P```$'1```9
M````7=$``!\```!WT0``$P```)?1```(````J]$```@```"TT0``"0```+W1
M```-````Q]$``",```#5T0``#0```/G1```3````!](```@````;T@```P``
M`"32``!&````*-(``#\```!OT@``-P```*_2``!7````Y](```4````_TP``
M'P```$73```O````9=,```T```"5TP``+0```*/3```$````T=,``$\```#6
MTP``)0```";4```<````3-0```L```!IU```'P```'74```=````E=0```L`
M``"SU```!P```+_4```)````Q]0``!,```#1U```!````.74```0````ZM0`
M``0```#[U```%`````#5```.````%=4```P````DU0``$P```#'5```<````
M1=4``"@```!BU0``!@```(O5```'````DM4``!,```":U0``!0```*[5```7
M````M-4```H```#,U0``#````-?5```)````Y-4```H```#NU0``$0```/G5
M```.````"]8```X````:U@``'0```"G6```+````1]8```(```!3U@``'```
M`%;6```'````<]8```8```![U@``9````(+6```F````Y]8``#@````.UP``
M&@```$?7```J````8M<``#L```"-UP``*````,G7```T````\M<``!D````G
MV```%0```$'8```'````5]@```<```!?V```!P```&?8```&````;]@```L`
M``!VV```'````(+8```0````G]@```D```"PV```$````+K8```'````R]@`
M``4```#3V```$````-G8```4````ZM@```L```#_V```#0````O9```8````
M&=D``!<````RV0``!````$K9```)````3]D```H```!9V0```@```&39```C
M````9]D``!\```"+V0``.````*O9```F````Y-D``#$````+V@``)P```#W:
M```4````9=H``#@```!ZV@``*````+/:```X````W-H``"@````5VP``+```
M`#[;```;````:]L``#X```"'VP``(P```,;;```E````ZML``$$````0W```
M6P```%+<``!)````KMP``"$```#XW```'P```!K=```K````.MT``"8```!F
MW0``)P```(W=```Z````M=T``#,```#PW0``)0```"3>```@````2MX``!\`
M``!KW@``,````(O>``!I````O-X``#$````FWP``00```%C?```S````FM\`
M`"4```#.WP``/0```/3?``!E````,N```$T```"8X```+P```.;@```N````
M%N$``#````!%X0``5````';A``!:````R^$``$@````FX@``2@```&_B```R
M````NN(``"\```#MX@``+````!WC```M````2N,``"4```!XXP``,@```)[C
M```^````T>,``"(````0Y```4@```#/D```E````AN0```L```"LY```10``
M`+CD```A````_N0``#`````@Y0``)0```%'E```<````=^4``#$```"4Y0``
M!P```,;E```'````SN4```0```#6Y0``"P```-OE```.````Y^4```4```#V
MY0```@```/SE``!9````_^4```4```!9Y@``"````%_F```P````:.8```,`
M``"9Y@``#````)WF```-````JN8```(```"XY@``!@```+OF```2````PN8`
M`!\```#5Y@``-0```/7F```N````*^<``"\```!:YP``%P```(KG```B````
MHN<``"4```#%YP``(````.OG```;````#.@``!@````HZ```)````$'H```?
M````9N@``!H```"&Z```(0```*'H```@````P^@``!H```#DZ```,@```/_H
M```:````,ND``"\```!-Z0``*P```'WI```?````J>D``",```#)Z0``'P``
M`.WI```:````#>H``"$````HZ@``)0```$KJ```F````<.H``"4```"7Z@``
M)````+WJ```8````XNH``!T```#[Z@``)````!GK```8````/NL``"(```!7
MZP``+````'KK```O````I^L``!4```#7ZP``)0```.WK```\````$^P``!\`
M``!0[```(P```'#L```?````E.P``"````"T[```&@```-7L```8````\.P`
M`"8````)[0``*0```##M```>````6NT``"D```!Y[0``'@```*/M```Q````
MPNT```D```#T[0``#````/[M```7````"^X``"\````C[@``)````%/N```'
M````>.X``!T```"`[@``&@```)[N```'````N>X``!4```#![@``!@```-?N
M```)````WNX```L```#H[@``#0```/3N```7`````N\```8````:[P``,P``
M`"'O```3````5>\``!,```!I[P``#P```'WO```'````C>\``#(```"5[P``
M!````,CO```A````S>\``!,```#O[P``#`````/P```1````$/```#(````B
M\```%@```%7P```(````;/```!T```!U\```"0```)/P```*````G?```!0`
M``"H\```'0```+WP```(````V_```!\```#D\```"`````3Q```:````#?$`
M`"<````H\0``!@```%#Q```5````5_$```@```!M\0``/P```';Q```'````
MMO$```\```"^\0``#@```,[Q```0````W?$```D```#N\0``"0```/CQ```'
M`````O(``!D````*\@``"@```"3R```*````+_(```P````Z\@``!````$?R
M```J````3/(```<```!W\@```@```'_R```0````@O(``!@```"3\@``!@``
M`*SR```'````L_(```T```"[\@``"P```,GR```O````U?(``"`````%\P``
M,0```";S```%````6/,``!(```!>\P``/P```''S```2````L?,```H```#$
M\P``!@```,_S```$````UO,``!,```#;\P``!0```._S```&````]?,```8`
M``#\\P``!`````/T```,````"/0```H````5]```.0```"#T```N````6O0`
M`"D```")]```!@```+/T```#````NO0```P```"^]```10```,OT```R````
M$?4``!H```!$]0``-````%_U```H````E/4``%,```"]]0``&0```!'V``!R
M````*_8``"````">]@``-0```+_V```A````]?8``$4````7]P``,````%WW
M```H````CO<``"D```"W]P``)@```.'W```E````"/@``"@````N^```*```
M`%?X```B````@/@``"L```"C^```,````,_X```2`````/D``!,````3^0``
M$````"?Y``!Y````./D```D```"R^0``H0```+SY``!S````7OH``'P```#2
M^@``*P```$_[``!4````>_L``!<```#0^P``)P```.C[```6````$/P```\`
M```G_```%P```#?\```?````3_P``$````!O_```'P```+#\```<````T/P`
M`%$```#M_```&@```#_]```4````6OT``!(```!O_0``$````(+]```3````
MD_T``!T```"G_0``#P```,7]```/````U?T```L```#E_0``!P```/']```%
M````^?T``!0```#__0``!P```!3^```(````'/X```\````E_@``"````#7^
M```,````/OX```\```!+_@``!@```%O^```4````8OX```8```!W_@``#```
M`'[^```1````B_X```@```"=_@``!````*;^```9````J_X``!$```#%_@``
M"@```-?^```8````XOX``!,```#[_@``$0````__```6````(?\```0````X
M_P``#P```#W_```9````3?\``!$```!G_P``"0```'G_```2````@_\``!<`
M``"6_P``!@```*[_```G````M?\```0```#=_P``#P```.+_```3````\O\`
M``<````&``$`!P````X``0`1````%@`!`!@````H``$`$P```$$``0`0````
M50`!``8```!F``$`#````&T``0`)````>@`!`!$```"$``$`(@```)8``0`'
M````N0`!``<```#!``$`"P```,D``0`"````U0`!``L```#8``$`B`$``.0`
M`0`3````;0(!`!<```"!`@$`#P```)D"`0`'````J0(!``D```"Q`@$`!P``
M`+L"`0`$````PP(!`!D```#(`@$`'0```.("`0`M``````,!`"$````N`P$`
M*P```%`#`0`M````?`,!`!P```"J`P$`*P```,<#`0`*````\P,!`"H```#^
M`P$`$P```"D$`0`,````/00!`!$```!*!`$`!0```%P$`0`H````8@0!``\`
M``"+!`$`"````)L$`0`5````I`0!`!$```"Z!`$`"@```,P$`0",````UP0!
M``X```!D!0$`"0```',%`0`/````?04!``T```"-!0$`#0```)L%`0`0````
MJ04!``H```"Z!0$`%````,4%`0`&````V@4!`)$```#A!0$`#````',&`0`1
M````@`8!`!8```"2!@$`#P```*D&`0`.````N08!``X```#(!@$`!@```-<&
M`0`+````W@8!`#4```#J!@$`'````"`'`0`]````/0<!`$@```![!P$`:0``
M`,0'`0!G````+@@!`'````"6"`$`;0````<)`0!`````=0D!``<```"V"0$`
M$@```+X)`0`*````T0D!``T```#<"0$`"P```.H)`0`%````]@D!``8```#\
M"0$`%@````,*`0`+````&@H!`"@````F"@$`(````$\*`0`4````<`H!`!``
M``"%"@$`$@```)8*`0`*````J0H!``@```"T"@$`%@```+T*`0`8````U`H!
M``T```#M"@$`%0```/L*`0`7````$0L!`"`````I"P$`(@```$H+`0`9````
M;0L!`!````"'"P$`%0```)@+`0`2````K@L!`"P```#!"P$`%@```.X+`0`>
M````!0P!``\````D#`$`4@```#0,`0`L````APP!`"0```"T#`$`"0```-D,
M`0`'````XPP!`#0```#K#`$`#P```"`-`0`'````,`T!``T````X#0$`!0``
M`$8-`0`<````3`T!``X```!I#0$`$````'@-`0`6````B0T!`!P```"@#0$`
M-@```+T-`0`*````]`T!`!8```#_#0$`&0```!8.`0`7````,`X!`!L```!(
M#@$`%````&0.`0`2````>0X!`"H```",#@$`$P```+<.`0`(````RPX!``P`
M``#4#@$`$@```.$.`0`8````]`X!`!H````-#P$`!P```"@/`0`9````,`\!
M``8```!*#P$`&P```%$/`0`-````;0\!`#L```![#P$`.````+</`0!'````
M\`\!`!0````X$`$`,@```$T0`0`T````@!`!`#4```"U$`$`.@```.L0`0`)
M````)A$!``8````P$0$`,P```#<1`0`T````:Q$!`#(```"@$0$`5P```-,1
M`0`R````*Q(!`#$```!>$@$`10```)`2`0!+````UA(!`#$````B$P$`3P``
M`%03`0`M````I!,!`"T```#2$P$`3@`````4`0`Q````3Q0!`#<```"!%`$`
M*@```+D4`0`6````Y!0!`!H```#[%`$`*P```!85`0`E````0A4!`"4```!H
M%0$`$@```(X5`0`&````H14!``T```"H%0$`'0```+85`0`;````U!4!`"L`
M``#P%0$`"@```!P6`0`O````)Q8!`!,```!7%@$`"P```&L6`0`)````=Q8!
M``H```"!%@$`!0```(P6`0`3````DA8!``4```"F%@$`%````*P6`0`(````
MP18!``4```#*%@$`!P```-`6`0`.````V!8!``,```#G%@$``P```.L6`0`7
M````[Q8!`!,````'%P$`*0```!L7`0`*````11<!``4```!0%P$`"````%87
M`0!(````7Q<!`$\```"H%P$`3P```/@7`0`A````2!@!`"4```!J&`$`*0``
M`)`8`0`@````NA@!``@```#;&`$`&P```.08`0`C`````!D!`"T````D&0$`
M-@```%(9`0`I````B1D!`"D```"S&0$`4@```-T9`0`Z````,!H!``@```!K
M&@$`%0```'0:`0`,````BAH!``D```"7&@$`#P```*$:`0`2````L1H!``\`
M``#$&@$`#0```-0:`0`)````XAH!``8```#L&@$`&P```/,:`0`8````#QL!
M`!P````H&P$`&0```$4;`0`&````7QL!`!8```!F&P$`7@```'T;`0!I````
MW!L!``<```!&'`$`#@```$X<`0`$````71P!``0```!B'`$`%@```&<<`0`3
M````?AP!`!4```"2'`$`(0```*@<`0`X````RAP!`#,````#'0$`!@```#<=
M`0`/````/AT!`!0```!.'0$`#@```&,=`0`;````<AT!``\```".'0$`%```
M`)X=`0`/````LQT!``0```##'0$`"P```,@=`0`(````U!T!``X```#='0$`
M#@```.P=`0`&````^QT!``P````"'@$`$`````\>`0`(````(!X!``X````I
M'@$`!P```#@>`0`'````0!X!`!````!('@$`"````%D>`0`+````8AX!``<`
M``!N'@$`"0```'8>`0`*````@!X!``H```"+'@$`'P```)8>`0!'````MAX!
M`!P```#^'@$`#````!L?`0`4````*!\!`!4````]'P$`%@```%,?`0`L````
M:A\!`#P```"7'P$`(@```-0?`0`(````]Q\!`#T`````(`$`)@```#X@`0`1
M````92`!``@```!W(`$`!0```(`@`0`1````AB`!``\```"8(`$`)@```*@@
M`0`F````SR`!`"H```#V(`$`*0```"$A`0`E````2R$!`"8```!Q(0$`)@``
M`)@A`0`F````OR$!`#0```#F(0$`,0```!LB`0`N````32(!`#````!\(@$`
M)0```*TB`0`S````TR(!`$<````'(P$`/````$\C`0`S````C",!`$$```#`
M(P$`30````(D`0`G````4"0!`"4```!X)`$`,P```)XD`0`K````TB0!`!8`
M``#^)`$`,````!4E`0`E````1B4!`"8```!L)0$`%P```),E`0"Q````JR4!
M`!H```!=)@$`)0```'@F`0`T````GB8!`#0```#3)@$`,`````@G`0`H````
M.2<!`"D```!B)P$`+````(PG`0`S````N2<!`#8```#M)P$`2P```"0H`0!&
M````<"@!`)D```"W*`$`+0```%$I`0`F````?RD!`#0```"F*0$`,P```-LI
M`0!%````#RH!`$P```!5*@$`#0```*(J`0`'````L"H!``4```"X*@$`!```
M`+XJ`0`,````PRH!``X```#0*@$`%0```-\J`0`4````]2H!`!<````**P$`
M#P```"(K`0`1````,BL!``T```!$*P$`$````%(K`0`.````8RL!``T```!R
M*P$`%0```(`K`0`.````EBL!`#8```"E*P$`!@```-PK`0`3````XRL!``4`
M``#W*P$`#````/TK`0`$````"BP!``T````/+`$`$0```!TL`0`&````+RP!
M`!`````V+`$`"````$<L`0`/````4"P!`!@```!@+`$`#P```'DL`0`3````
MB2P!`!````"=+`$`"P```*XL`0`'````NBP!``T```#"+`$`#@```-`L`0`+
M````WRP!`!````#K+`$`'@```/PL`0`-````&RT!``\````I+0$`*0```#DM
M`0`2````8RT!`!L```!V+0$`,@```)(M`0`,````Q2T!`!X```#2+0$`&0``
M`/$M`0`;````"RX!`!@````G+@$`/@```$`N`0`-````?RX!``D```"-+@$`
M%````)<N`0`+````K"X!`"H```"X+@$`0P```.,N`0`(````)R\!`!`````P
M+P$`(P```$$O`0`2````92\!`!X```!X+P$`'@```)<O`0`G````MB\!`!H`
M``#>+P$`(0```/DO`0`:````&S`!`!@````V,`$`#0```$\P`0`I````73`!
M`$D```"',`$`'0```-$P`0`'````[S`!``H```#W,`$`/0````(Q`0`&````
M0#$!``@```!',0$`$0```%`Q`0`1````8C$!`!,```!T,0$`$P```(@Q`0`:
M````G#$!`!H```"W,0$`'0```-(Q`0`<````\#$!``8````-,@$`"P```!0R
M`0`/````(#(!`"4````P,@$`$@```%8R`0`0````:3(!`!````!Z,@$`&0``
M`(LR`0!,````I3(!`$(```#R,@$`"0```#4S`0`3````/S,!`(@```!3,P$`
M(0```-PS`0`E````_C,!``8````D-`$`'````"LT`0`K````2#0!`"D```!T
M-`$`(0```)XT`0`B````P#0!`!X```#C-`$`%@````(U`0`.````&34!``T`
M```H-0$`#P```#8U`0`-````1C4!``\```!4-0$`#0```&0U`0`+````<C4!
M`!$```!^-0$`!@```)`U`0`'````ES4!``\```"?-0$`#````*\U`0`L````
MO#4!`!````#I-0$`"0```/HU`0`)````!#8!`"0````.-@$`,````#,V`0`D
M````9#8!`",```")-@$`(0```*TV`0`@````SS8!`#,```#P-@$`(0```"0W
M`0`?````1C<!``8```!F-P$`#@```&TW`0`(````?#<!``@```"%-P$`"0``
M`(XW`0`7````F#<!`!@```"P-P$`#0```,DW`0`)````US<!``X```#A-P$`
M"P```/`W`0`?````_#<!``8````<.`$`"0```",X`0`+````+3@!``P````Y
M.`$`#@```$8X`0`&````53@!`!D```!<.`$`$@```'8X`0`$````B3@!`"H`
M``"..`$`$````+DX`0`<````RC@!``<```#G.`$``@```.\X`0`'````\C@!
M``(```#Z.`$`!@```/TX`0`4````!#D!``D````9.0$`#0```",Y`0`I````
M,3D!``D```!;.0$`&````&4Y`0`/````?CD!``@```"..0$`"@```)<Y`0`)
M````HCD!``\```"L.0$``P```+PY`0`,````P#D!``X```#-.0$`!@```-PY
M`0`6````XSD!`"H```#Z.0$`4@```"4Z`0`N````>#H!`"\```"G.@$`!@``
M`-<Z`0`5````WCH!`!(```#T.@$`#`````<[`0`,````%#L!``<````A.P$`
M!0```"D[`0`5````+SL!``@```!%.P$`"````$X[`0`;````5SL!``0```!S
M.P$`!@```'@[`0`@````?SL!``4```"@.P$`$0```*8[`0`1````N#L!`!``
M``#*.P$`$@```-L[`0`7````[CL!``P````&/`$`.0```!,\`0`:````33P!
M`"````!H/`$`&````(D\`0`'````HCP!``D```"J/`$`"````+0\`0`H````
MO3P!`"P```#F/`$`-````!,]`0`,````2#T!`!T```!5/0$`/````',]`0`8
M````L#T!``<```#)/0$`"@```-$]`0`,````W#T!``\```#I/0$`$@```/D]
M`0!+````##X!`(X```!8/@$`=````.<^`0`B````7#\!``P```!_/P$`#0``
M`(P_`0`7````FC\!`!@```"R/P$`%````,L_`0`(````X#\!`!$```#I/P$`
M$P```/L_`0`0````#T`!`!0````@0`$`'0```#5``0`F````4T`!`'L```!Z
M0`$`%0```/9``0`2````#$$!``P````?00$`(0```"Q!`0`7````3D$!`!(`
M``!F00$`$0```'E!`0`2````BT$!`!@```">00$`,````+=!`0`T````Z$$!
M`"T````=0@$`,0```$M"`0`L````?4(!`"X```"J0@$`(@```-E"`0!(````
M_$(!`!@```!%0P$`&0```%Y#`0`:````>$,!`!L```"30P$`$0```*]#`0`;
M````P4,!`!P```#=0P$`%P```/I#`0`8````$D0!`#H````K1`$`'0```&9$
M`0`:````A$0!`#X```"?1`$`%@```-Y$`0`&````]40!``P```#\1`$`(@``
M``E%`0`3````+$4!`!@```!`10$`$P```%E%`0`H````;44!`"H```"610$`
M(````,%%`0`E````XD4!`!T````(1@$`%````"9&`0`=````.T8!`"````!9
M1@$`(0```'I&`0`:````G$8!`!L```"W1@$`%@```--&`0`=````ZD8!`!P`
M```(1P$`'@```"5'`0`*````1$<!`!0```!/1P$`"0```&1'`0`&````;D<!
M``<```!U1P$`"````'U'`0`&````AD<!``8```"-1P$`"@```)1'`0`4````
MGT<!`!````"T1P$`%0```,5'`0`3````VT<!`!8```#O1P$`,0````9(`0`0
M````.$@!`!X```!)2`$`%@```&A(`0`1````?T@!`!````"12`$`,````*)(
M`0`(````TT@!``T```#<2`$`"@```.I(`0`,````]4@!`"\````"20$`#0``
M`#))`0`5````0$D!`!8```!620$`'0```&U)`0`7````BTD!``4```"C20$`
M#````*E)`0`E````MDD!``8```#<20$`"````.-)`0`8````[$D!`!(````%
M2@$`!P```!A*`0`/````($H!``P````P2@$`&````#U*`0!/````5DH!``P`
M``"F2@$`*````+-*`0`3````W$H!`!X```#P2@$`#@````]+`0`4````'DL!
M`!$````S2P$`&@```$5+`0`8````8$L!`!4```!Y2P$`'P```(]+`0`E````
MKTL!`",```#52P$`)0```/E+`0`+````'TP!``X````K3`$`#````#I,`0`,
M````1TP!``4```!43`$`!0```%I,`0`$````8$P!``4```!E3`$`%0```&M,
M`0!3````@4P!`!````#53`$`"P```.9,`0`%````\DP!``4```#X3`$`&```
M`/Y,`0`8````%TT!`!<````P30$`"P```$A-`0`M````5$T!``8```""30$`
M!0```(E-`0`8````CTT!`!4```"H30$`90```+Y-`0`%````)$X!``<````J
M3@$`*0```#).`0`X````7$X!`!0```"53@$`&0```*I.`0`H````Q$X!`!T`
M``#M3@$`'`````M/`0`?````*$\!`!$```!(3P$`!@```%I/`0`(````84\!
M``8```!J3P$`#P```'%/`0`)````@4\!`&D```"+3P$`$@```/5/`0`.````
M"%`!``8````74`$`'@```!Y0`0`H````/5`!``<```!F4`$`!P```&Y0`0`%
M````=E`!`!P```!\4`$`&P```)E0`0`U````M5`!``@```#K4`$`!0```/10
M`0`J````^E`!`%0````E40$`&@```'I1`0`L````E5$!`!L```#"40$``@``
M`-Y1`0`(````X5$!`!,```#J40$`#````/Y1`0`&````"U(!``L````24@$`
M"P```!Y2`0`+````*E(!`$L````V4@$`#````()2`0`1````CU(!``\```"A
M4@$`#````+%2`0`,````OE(!``P```#+4@$`$@```-A2`0`+````ZU(!`!P`
M``#W4@$`"P```!13`0`<````(%,!`!8````]4P$`!````%13`0`$````65,!
M``,```!>4P$`#P```&)3`0`*````<E,!`!T```!]4P$`#@```)M3`0`?````
MJE,!`"(```#*4P$`%P```.U3`0`'````!50!`!$````-5`$`"````!]4`0`/
M````*%0!`!`````X5`$`"0```$E4`0`%````4U0!`%@```!95`$`.````+)4
M`0`M````ZU0!`$4````950$`$0```%]5`0`T````<54!`$@```"F50$`30``
M`.]5`0!-````/58!`%(```"+5@$`'0```-Y6`0`D````_%8!`!P````A5P$`
M(````#Y7`0`C````7U<!`"(```"#5P$`(0```*97`0`@````R%<!`"(```#I
M5P$`.@````Q8`0`Z````1U@!`#X```""6`$`.P```,%8`0`\````_5@!`#D`
M```Z60$`E0```'19`0`?````"EH!``X````J6@$`)@```#E:`0`,````8%H!
M`!,```!M6@$`.````(%:`0`P````NEH!`"H```#K6@$`#0```!9;`0!;````
M)%L!`%4```"`6P$`!P```-9;`0`7````WEL!`!<```#V6P$`"`````Y<`0`(
M````%UP!``D````@7`$`$0```"I<`0`0````/%P!``T```!-7`$`#P```%M<
M`0`'````:UP!`"8```!S7`$`"````)I<`0`&````HUP!`!,```"J7`$`$0``
M`+Y<`0`/````T%P!`%4```#@7`$`!P```#9=`0`5````/ET!``8```!470$`
M!P```%M=`0`'````8UT!`#0```!K70$`$````*!=`0`C````L5T!`#0```#5
M70$`)`````I>`0!_````+UX!`!H```"O7@$`4P```,I>`0`N````'E\!`!$`
M``!-7P$`!P```%]?`0`.````9U\!``\```!V7P$`#@```(9?`0`3````E5\!
M``8```"I7P$`(P```+!?`0`9````U%\!``4```#N7P$`$@```/1?`0`9````
M!V`!`"<````A8`$`&````$E@`0`3````8F`!`"````!V8`$`"@```)=@`0`)
M````HF`!`!D```"L8`$`"P```,9@`0`5````TF`!`!\```#H8`$`%0````AA
M`0`U````'F$!`!4```!480$`(0```&IA`0`'````C&$!`!<```"480$`"```
M`*QA`0`'````M6$!``L```"]80$`)````,EA`0`T````[F$!``@````C8@$`
M'0```"QB`0`/````2F(!``@```!:8@$`$0```&-B`0`6````=6(!``@```",
M8@$`"@```)5B`0`D````H&(!`#X```#%8@$`/P````1C`0`G````1&,!`#0`
M``!L8P$`+````*%C`0!-````SF,!`",````<9`$`+@```$!D`0`U````;V0!
M`%T```"E9`$`,@````-E`0`'````-F4!``@````^90$`"0```$=E`0`*````
M464!`"$```!<90$`(````'YE`0`Q````GV4!`"4```#190$`,@```/=E`0`_
M````*F8!``D```!J9@$`'P```'1F`0`+````E&8!``D```"@9@$`+0```*IF
M`0`1````V&8!`!````#J9@$`#@```/MF`0`(````"F<!`!@````39P$`"```
M`"QG`0`/````-6<!`!\```!%9P$`(@```&5G`0!$````B&<!`!(```#-9P$`
M!P```.!G`0`/````Z&<!``<```#X9P$`"`````!H`0`%````"6@!`!(````/
M:`$`/P```")H`0!C````8F@!`!T```#&:`$`"````.1H`0`H````[6@!`"``
M```6:0$`"````#=I`0`,````0&D!``T```!-:0$`*@```%MI`0`'````AFD!
M`!$```".:0$`$@```*!I`0`8````LVD!`!$```#,:0$`0````-YI`0`*````
M'VH!`"$````J:@$`$````$QJ`0`4````76H!`$````!R:@$`+````+-J`0`\
M````X&H!`#T````=:P$`-@```%MK`0`/````DFL!``8```"B:P$`$@```*EK
M`0`6````O&L!`!L```#3:P$`"0```.]K`0`4````^6L!`!H````.;`$`"```
M`"EL`0`9````,FP!`!\```!,;`$`"P```&QL`0`&````>&P!`!8```!_;`$`
M$````)9L`0`8````IVP!``8```#`;`$`#````,=L`0`0````U&P!``X```#E
M;`$`%````/1L`0`4````"6T!``8````>;0$`!@```"5M`0`U````+&T!`"D`
M``!B;0$`)P```(QM`0`(````M&T!`!0```"];0$`&````-)M`0`H````ZVT!
M``T````4;@$`*@```")N`0`8````36X!`!0```!F;@$`!0```'MN`0`*````
M@6X!``@```",;@$`$````)5N`0!E````IFX!`!H````,;P$`/P```"=O`0`'
M````9V\!``<```!O;P$`$0```'=O`0`0````B6\!`!(```":;P$`(0```*UO
M`0`?````SV\!`!,```#O;P$`(0````-P`0`/````)7`!`"@````U<`$`%```
M`%YP`0`1````<W`!`'8```"%<`$`(````/QP`0`@````'7$!`"D````^<0$`
M'0```&AQ`0`>````AG$!`"8```"E<0$`'P```,QQ`0`>````['$!`!P````+
M<@$`"0```"AR`0`)````,G(!``D````\<@$`#P```$9R`0`T````5G(!`!H`
M``"+<@$`&````*9R`0`(````OW(!``<```#(<@$`6P```-!R`0!`````+',!
M`#T```!M<P$`@@```*MS`0`,````+G0!`#8````[=`$`,````')T`0`.````
MHW0!`#\```"R=`$`!@```/)T`0!3````^70!`"X```!-=0$`+P```'QU`0`6
M````K'4!`#(```##=0$`)````/9U`0`5````&W8!``P````Q=@$`!0```#YV
M`0`2````1'8!``H```!7=@$`(P```&)V`0`$````AG8!`"$```"+=@$`$@``
M`*UV`0`*````P'8!`!0```#+=@$`&@```.!V`0`O````^W8!``T````K=P$`
M"@```#EW`0`8````1'<!``8```!==P$`'@```&1W`0`/````@W<!`!$```"3
M=P$`#P```*5W`0`0````M7<!`!$```#&=P$`&0```-AW`0`)````\G<!`!\`
M``#\=P$`"P```!QX`0`"````*'@!`"`````K>`$`!P```$QX`0`*````5'@!
M`'\```!?>`$`+@```-]X`0!8````#GD!`!P```!G>0$`)@```(1Y`0!)````
MJWD!`#````#U>0$`/````"9Z`0`<````8WH!`!<```"`>@$`"````)AZ`0`(
M````H7H!``H```"J>@$`!@```+5Z`0`(````O'H!`"D```#%>@$`%P```.]Z
M`0`:````!WL!`!<````B>P$`"@```#I[`0`(````17L!`!(```!.>P$`'@``
M`&%[`0`+````@'L!``T```",>P$`&@```)I[`0`1````M7L!``4```#'>P$`
M"@```,U[`0`2````V'L!``(```#K>P$`(P```.Y[`0`J````$GP!`#<````]
M?`$`+````'5\`0`Y````HGP!`"X```#<?`$`&P````M]`0`[````)WT!`#(`
M``!C?0$`/0```)9]`0`R````U'T!`#4````'?@$`(@```#U^`0!'````8'X!
M`",```"H?@$`,0```,Q^`0!`````_GX!`'(````_?P$`90```+)_`0`A````
M&(`!`!\````Z@`$`,@```%J``0`D````C8`!`",```"R@`$`.0```-:``0`\
M````$($!`"@```!-@0$`+P```':!`0`@````IH$!`#D```#'@0$`=P````&"
M`0`[````>8(!`%0```"U@@$`-@````J#`0`T````08,!`$X```!V@P$`=```
M`,6#`0!<````.H0!`$<```"7A`$`0````-^$`0!`````((4!`&(```!AA0$`
M9P```,2%`0!@````+(8!`&,```"-A@$`/````/&&`0`X````+H<!`#0```!G
MAP$`,P```)R'`0`H````T(<!`#0```#YAP$`30```"Z(`0`J````?(@!`%<`
M``"GB`$`(P```/^(`0`,````(XD!`$T````PB0$`(````'Z)`0`^````GXD!
M`"<```#>B0$`)`````:*`0!"````*XH!``4```!NB@$`"0```'2*`0`#````
M?HH!`!````""B@$`$@```).*`0`&````IHH!``$```"MB@$`9````*^*`0`$
M````%(L!``8````9BP$`-````""+`0`$````58L!``H```!:BP$`#````&6+
M`0`"````<HL!``<```!UBP$`%@```'V+`0`H````E(L!`%@```"]BP$`-0``
M`!:,`0`V````3(P!`!H```"#C`$`+0```)Z,`0`P````S(P!`"8```#]C`$`
M(````"2-`0`@````18T!`"D```!FC0$`)````)"-`0`?````M8T!`"@```#5
MC0$`)0```/Z-`0`I````)(X!`#4```!.C@$`'P```(2.`0`R````I(X!`#D`
M``#7C@$`)P```!&/`0`K````.8\!`"<```!ECP$`(@```(V/`0`K````L(\!
M`#````#<CP$`+0````V0`0`N````.Y`!`"H```!JD`$`(0```)60`0`D````
MMY`!`#````#<D`$`'P````V1`0`G````+9$!`#@```!5D0$`-P```(Z1`0`=
M````QI$!`"D```#DD0$`2P````Z2`0`H````6I(!`"P```"#D@$`*````+"2
M`0`I````V9(!`",````#DP$`'P```">3`0`J````1Y,!`#L```!RDP$`)@``
M`*Z3`0`Q````U9,!`#(````'E`$`10```#J4`0`,````@)0!`!$```"-E`$`
M'0```)^4`0`U````O90!`"````#SE`$`"P```!25`0`B````()4!`"$```!#
ME0$`"@```&65`0`9````<)4!``@```"*E0$`"P```).5`0`/````GY4!``X`
M``"OE0$`(````+Z5`0`&````WY4!`$0```#FE0$`&@```"N6`0`7````1I8!
M`!,```!>E@$`!P```'*6`0!&````>I8!``8```#!E@$`)````,B6`0`/````
M[98!``X```#]E@$`%`````R7`0!"````(9<!`!<```!DEP$`"P```'R7`0`@
M````B)<!``P```"IEP$`#0```+:7`0`3````Q)<!`!P```#8EP$`!P```/67
M`0`D````_9<!``@````BF`$`&````"N8`0`R````1)@!``8```!WF`$`'```
M`'Z8`0`)````FY@!`$(```"EF`$`"````.B8`0`5````\9@!`!8````'F0$`
M%0```!Z9`0`*````-)D!``H````_F0$`#0```$J9`0`A````6)D!`!(```!Z
MF0$`"@```(V9`0`,````F)D!``H```"EF0$`,@```+"9`0`*````XYD!``(`
M``#NF0$`&````/&9`0`C````"IH!``\````NF@$`"0```#Z:`0`.````2)H!
M``T```!7F@$`.````&6:`0`E````GIH!`#````#$F@$`"0```/6:`0`6````
M_YH!`$P````6FP$`%P```&.;`0`2````>YL!``H```".FP$`!0```)F;`0`:
M````GYL!``8```"ZFP$`!P```,&;`0`(````R9L!``8```#2FP$`%````-F;
M`0`3````[IL!`#T````"G`$`+@```$"<`0`]````;YP!``L```"MG`$``@``
M`+F<`0`2````O)P!`$D```#/G`$`,````!F=`0`7````2IT!`#8```!BG0$`
M*P```)F=`0!7````Q9T!`!8````=G@$`>````#2>`0`?````K9X!`#X```#-
MG@$`(`````R?`0!`````+9\!`#@```!NGP$`*````*>?`0`G````T)\!`"@`
M``#XGP$`*0```"&@`0`I````2Z`!`"<```!UH`$`+P```)V@`0`L````S:`!
M`$````#ZH`$`%@```#NA`0`?````4J$!`!,```!RH0$`A0```(:A`0`+````
M#*(!`*@````8H@$`>@```,&B`0"%````/*,!`"P```#"HP$`70```.^C`0`3
M````3:0!`"X```!AI`$`&P```)"D`0`5````K*0!`!<```#"I`$`(@```-JD
M`0!&````_:0!`"4```!$I0$`(````&JE`0!<````BZ4!`!H```#HI0$`%0``
M``.F`0`:````&:8!`!4````TI@$`&0```$JF`0`C````9*8!`!````"(I@$`
M$````)FF`0`.````JJ8!``<```"YI@$`!@```,&F`0`;````R*8!``8```#D
MI@$`!0```.NF`0`9````\:8!``@````+IP$`"0```!2G`0`8````'J<!``T`
M```WIP$`&P```$6G`0`&````8:<!``<```!HIP$`%0```'"G`0`*````AJ<!
M``4```"1IP$`(0```)>G`0`8````N:<!``D```#2IP$`)@```-RG`0`8````
M`Z@!`!T````<J`$`&P```#JH`0`(````5J@!`!$```!?J`$`%````'&H`0`5
M````AJ@!``D```"<J`$`%@```*:H`0`;````O:@!``8```#9J`$`.````."H
M`0`$````&:D!`!`````>J0$`%P```"^I`0`+````1ZD!``@```!3J0$`#P``
M`%RI`0`<````;*D!`!@```")J0$`%````**I`0`(````MZD!`!$```#`J0$`
M#P```-*I`0`1````XJD!`"L```#TJ0$`"0```""J`0`*````*JH!`!(````U
MJ@$``@```$BJ`0`+````2ZH!``$`````````?P```/<"```6`@``R`,`````
M``!9`0``#P,````````%`0```````%T%`````````P4``#0!````````````
M`%`!````````U0,``#$"``"%`@``BP(``/4$````````;P,``$P````)`0``
M@P(``(8$``!<````D0$```````!A!````````#H````N`P``\P$``+T!````
M````5@0``$\"``#,`P``J0```)(!`````````````!8```#W`P```````&0%
M``!'!0``\@0```````````````````$#```_!```K@0``$$!````````#P0`
M`,(!```G`P``Q`(``","``#'`@``0@(````````K`P``&P4``*X#``"&!0``
M/0$``&`#``!X!0``N@(``'P#`````````````'`"``````````$``'4$````
M````(@$``/X"```[`0```````.P!```D!`````````````!3!0``\00``!<`
M````````'`,``%L#``"5`@``C@$``!$"``"P`@````````X!```N`@``9`$`
M`/<$``#Z`P``$P,``'`%``#T!```,0```)`!```C`P```````#T$``#"````
MC`,``!<"```!`0``H````%X%````````=0$``*P!`````````````(4$``!!
M!0````````,$``!T!```L`$``$H"``!2````#`0``)8```#U`P``````````
M````````]`$``/D$````````X`(``&0#``!,`P``2`,``/@"``"`````?`4`
M`!H#`````````````#X%``"3`@``6P0``'4%``#)````\`0```8!````````
M!0,``&,%````````````````````````F@0``!0%`````````````.,```#J
M`P``^@````P%````````;P0``"X%``#`````&0,``"(%```P`0``F`(`````
M````````%@$```````"T`P``6`$``-T!````````F@,```````!7`0``````
M`$X"````````D@```/\$````````````````````````XP$```````#I````
MA`4``*P$``!#!0```````(X$``"E`0``/P$``!\```#'`P``404```````#2
M!```-P0```T!```U`P``C`$````````5`@``#`````````"D````<@4``)X#
M``"6`@``"@,```````!P`````````,,"````````_0$``#X````N!```R@,`
M`$<"``";```````````````R`P```````*L!``!1`0``````````````````
M&P(``&@`````````J`(``(T#``!S`P``BP$``````````````````/P#``#H
M`0``W`$``````````````````%L!``!3`P```````)D"``"/````=@$``/`#
M``"8`P````````X`````````%`(``-L$```9`@``[@```+P"``"7!```/P,`
M``````!P`P``>@```&`!``"?`0````````````"A`0``:@0``/0#``!;!0``
M=P(``"(#`````````````,($``#Q`````````&`"``#8`P```````,D!``"`
M`@```````'L!```8`0```````#`$```````````````````8`@``V@``````
M``"Q`@``TP,``)P"``#A!```*@(``$8$````````Z`````````#8`@``"04`
M`,\"```1!0``NP$````````W!0``M@0``)`"```````````````````G````
M+`(``'L%````````S0,``-L`````````D@(```(#``"M`P``R````&L`````
M````=@```&$#``!I!0````````$%``"J````M@(``$$$````````Y@0``$X#
M```2`P``F`````````!J`P``[0(``(\!``!#````J@(``!P%``"(`P``````
M`"$%````````/@,```````"C`0``CP,``%T#`````````````!X"``"O!```
MG00``(0$``"L`@``L0````````!W!```:P,``(8`````````LP,``#4!````
M````:@```&P#``#M!```2P(``.(```"_````OP0```````";`0``?@4``'8%
M``#=````G0,``$8#``!-`@```````-$#```=````D0(``/$"````````````
M```````Z`P`````````````8!0````````````"B`@``MP0``$P%``#X`0``
M#0(``'L```!#!```6@$```````#E`@```````)P#``!)`@``2`4``-$````B
M`@```````.,$``"'`P``B0(``-D#```;!```)P$``.0!``#X````3P```%``
M```9!```V`0```````#N`@``2P4````````]`P```````$4`````````````
M`,T$``!B!0``I0,``+("```V!0``Y@,``(T$````````-@,```````#L`@``
M`````,8````H`0``V````(X"`````````````/P"````````'P(````````:
M`0``_P```$D%``!N`P``!@(``&<!``"R`0``[P,```````#_`P``````````
M```F!```.P4````````G!0``I`,``-@!`````@``^`,``"\"```=!0``]0``
M`",%``"J`P``>0`````````P`@``20,``"@%```)`P``SP$``&<"``!F`@``
M``````$"``!9!```=0```*@!```A`0``\0$```X$``#$`P``;@0``$T%``!7
M`P``T`,``/$#``!F`P``3@```-,"````````$P(```````#&!```=0,``)T"
M```>````G@(``-8$`````````````&D"``#H!```2P0``"`"```$`0``````
M`/T"```E!```H`(````````J`````````&H"``!8!0``Z@$`````````````
M1P```($%```E`0``J0(````````4`P``"`0```````!Z`0``L0$``!($``#>
M`0``"@```#8"``!2`0````````````!``@``@0```"@$```=`0``0P,``*H$
M``!6`@``LP(````%````````2@,``#P#``"``P``\P```(X```!+`0``````
M`#(`````````.`(``",`````````+@```"P!``!]!```:`$``'4"``"Z!```
M+````",!````````KP(``'@```!5`P```````%@"`````````````%,"``!A
M!0```````+<!``"7`@``_@,``'P"``#<`P``#`$``.,#``"?`````````&T"
M``"'`0``M@$``!H$````````;0$``%("``#D!`````````````"H````Q0(`
M`(D```#Y`P``"@$```(```"7````.@0``.H$``#\````B`0````````V!```
M7P$``&D!``#G````!P0```D```#R`0``^@0``-4$```T`@``Q00``"D"``#M
M`P``1`(``&<%``#,!```M`(```````!8!```LP```$T#``#>````30$``%\"
M````````?P$``,P`````````B@$``!`%````````>`0``',!``#E````E0,`
M`%@#``"1````-P,```D"```M!```J0$``/T```"Q`P```````$4$```$!0``
M4P```"H$``!_!0```````.4$``#2`@``'0(```````!R`P```````-8#``!R
M`0``V0(```````!,`@``@@(``"`#``#%````YP(```````"-````8`4```8`
M``!T`@````````,!``"=`0``HP(``"L%``!D````,@0``/L```">````````
M``````#0`@``9P0```````"9`0``<P4``&(```!=`0``O0,```````!2!```
M?P(``+0```#<`@``[`,``#X"``"%````+0```,$!``````````````````#+
M````K0```)<#````````````````````````%P,``&L"``"&`@```````!4#
M``!"````U`(````````Z`@```````%L```#4`P``]@$```0````1````D`,`
M`)P````L`P`````````````X!````````#D$``!?````.04```````#I`P``
M*`,``/L$````````5`````````"8`0``M@```*\!``![!```<`0``%4"``!)
M````J0,``!D````[`@``4`,``"@"``!<`P``:`,``#0$``"(`@``R@0``-$!
M```M`0``@`$````#`````````````'\$``"E!````````$(#````````YP,`
M`#``````````_0,````````Y````U`0```````"V`P```````/`!``!$!0``
MF00``!`#``!:`P``9P,``/0"``"9````9@```'@#```?`P``NP(``/\!```%
M!0```````.0#``"E`@``I@(```L!````````]@```#P%``#H`@```````!@$
M``#7!````````$H```"3!```"@4```8$````````KP,``'T```#-````````
M`.T```!A`0``!`(```````"]!`````````````"8!```.0$``&T#``"7`0``
M300```("``!N````E@,````````Q`P``;@(```````"G!```'@,``"8"``#0
M`0``+04```````!6`0``H`$```````!5````]0(``(L$```\````90,``$@$
M``!5!0``N0(``-8!```X````/`0``'D"``!5!```60(``#P"````````IP(`
M`/\"````````E````&4$```V`0``PP,`````````````1P,``-(#``#O`@``
M8`````````#'`0```````'D!````````B00``*X!``````````````````!?
M!```6````#,"``!/`P```````!\!````````=P4``+@"``##````L@0``%X!
M````````@P0```````"A!```X@0````````%!```:00````````]````'`(`
M`+```````````````#,!```I`0``RP,``,H!``"X!```8P,``(,%````````
M'@0``-L"``"*````)0```.<$``#[`0````````\"``"%!0``,@4``%L"``!&
M`@``+0(``.D"```<!````````($#```4!```;P```-D$````````0@4``$`$
M``!L!0``H@,``)H"```6!````````/("```3!0``#`(```@```"D`@``-00`
M`$<$``!:````/P4``+T``````````@$``%T$``#:!```40````<"``#%`P``
M``````````!?`P``>00``$@"```K````*0```"8%````````,`4``(`$``"*
M`P``N0$``%<$```O`0``JP```#L$``"'`@``S`(``,$$``!I````%@4``$``
M``#P`@``D@0``(L#``"0!````````,L!``#D`@``M0,``'($```%`@``_`0`
M``($``#(!````00``+,!``#'````B`````````!4!0``1@4``*X```!M!```
MS@$```````#C`@``O@$``$4#````````-@```+,$````````40,```T#````
M````+P0``"@`````````'0,```````!H!0``P0,````````*!```#04`````
M````````$@4``,`$```"!0``'`$``)0!```C!```PP$````````X`0``````
M`$4!```S`P```````+@!``#+!```M0```*8$``#I!```8P$``)$#``!:!0``
M@P```'L#````````$````,`"````````*@,``$8```#3`0``9P```'("````
M``````````````!]`P``N@,```````#B`@```````(0```#)`@``E0$`````
M``"_`0```````(H"``!&`0``8`0``+(#````````@0(``(0!````````JP0`
M`,D#```>!0```````$\!``!0!0```P,````````1`P``>@(````````^!```
M-0(``!0````:`@``=`````````!H!```X`,```````"/!```)P0``,\`````
M````00```(<$````````O@(``$X!``"*!```ZP,``.4#````````"`(`````
M``"A`P``G0```#D#```0`@```````!@```#N!```200``&,"``#?`P``;`$`
M`%4!```Q!0``O0(``(P`````````>@,```````!4!```%P$``+4"```+!0``
M``````````!.!0``5P`````````%`````````!D%``#;`0```````*L"``"<
M`0``X`$``'`!`````````````$H!```2`0``.P,``'0!````````K```````
M``!4`@``$@````````!^`P``8@$``#D"``"W`@``7@,```````#>!```````
M`.H"``#5`0``OP(``,0!```E`P``U`$```````"Y`P```P```/T$``"K`P``
M]@,`````````````[0$``"0!````````0@$``-<!````````[@$``%H"``">
M`0```````+H`````````_@0``%H$``#;`P``$P```*@#```:````#`,``.\!
M``````````````````#0!```WP````````"?`@``"P,``$`!````````O@,`
M`*,``````````````"(```!6!0``)`4``'T"````````00,````````W`@``
M!P,```````"C!```Q@,```````"N`@``;`0``"4%````````K`,``%,!``!2
M!0``?`0```````#F``````````````!^!```S@0``$L```!1`@``AP4``(8!
M```-````5`$``)(#``!V!````````*0$``""`0``!P$`````````````(0(`
M`%(#```*`@``2@0```````![`@`````````````]`@``W`0``-0```!H`@``
M9@$```````````````````````!(````,00```````"A````UP(```````!9
M````CP(``(D!``!\`0``NP```%`$``"\`0```````!4```!R`````````/L#
M```]!0``;P$````````U!0``UP```*(```!#`0``[P0``%P%``#-`0``QP0`
M```````&!0``]P$``-X#```O!0``"`,``!0!````````@@0``-H#``#/`P``
M2@4``+@```!%`@``S@````````!'`0````````D$``!)`0``Y@$``%T"````
M`````````'H%``!.!```'P0``!L!```=!```1`,```````#3!```!@,``-\$
M`````````````,0```"0````AP```$T```#\`0``]@0``$($````````@@,`
M`+H!``#+`@``P`$``&L%````````\P(``'$%``"(`0``?@(```````#E`0``
M`````&\"``#:`0``904```````#A`P```````+4$``#&`@``;````!<$``!>
M`@```````"8!```$!````````#,%``!9!0``>`(``&L$```E`@``ZP``````
M``#!````Z@```&(#```5`0```````$$"````````[````(P$``#(`@``)@``
M``````#^`0``H@0``)0$``#3````+P,``&$"```7!0``'````!("``!Y`P``
M;04``&8$``!O!0```````#$!````````80``````````````?@$``&X!````
M````$P0``),```!$`````````#`#``#O````^0````````#Z`@``NP0``"<"
M```A````L00``/(`````````E`(```````#Z`0``\````&T```!,!```ZP0`
M``X#``!Y!0``S@,``*4```"T`0``E00``#(!````````+P```*0!````````
M<0,``"`$``"+````(`````````!(`0``E@0```````#2`````````-<#``"Y
M!```F0,```````":````(@0``*\```!/!```^0(``)4`````````!`,`````
M```;`````````+4!``#``P``.@$``.(!`````````````.``````````:@$`
M``````#9`0``T@$``&,```#W````<P(````````T!0```````*H!````````
MY@(``'8#```````````````````-!```70`````````0`0``<0(```````"M
M`@``````````````````.`,``,P!``!+`P``104``%<"````````L`0``*(!
M``"[`P``F@$``.L"``#A`0``````````````````^0$``.$"````````````
M``````!0`@```````+\#``#^````S@(``````````````````"T#``!S!```
M`````"L"````````GP0``````````````````#0```!9`P```````"0```!W
M`0``&0$```@%``"-`0``.`4```<`````````O@0``"H!``#S!```J00```<%
M``"H!`````````````!/!0``\@,``/L"````````+`0```L"``!I`P``````
M````````````=P```'$$``!E`0``W0,``!4%````````W````(4#``!]`0``
M`````+P#````````%00``!@#``#T````T0(``*8!``!E`@``?@```-8"``!$
M`0``Q0$``.`$``!#`@``N0```((%```/!0```````*$"``!7!0``FP(`````
M``!D`@``8@(``%8`````````]@(``-D```#:`@``A`(``"0"``"3`0``````
M`/4!````````(`$``"0#````````IP$```````!4`P``X@,``)\#```/`0``
MPP0``),#````````@`4``-````!6`P``[`0```````!\````,P```-4"``""
M`````P(``*`#``!K`0```````*T$``#!`@``1`0``,T"``"C`P````0``(X#
M``#&`0``0`,``+P````W````WP$``,("```Z!0``<0$``"P%``";`P``<0``
M`"H%```F`P`````````````K`0````````````#G`0``R`$``(P"````````
MQ`0````````A!```@P$``,(#```(`0``Z0$``%X```#D`````````'H$````
M````G`0```````#A````^`0`````````````@0$```````!S````8P0``(,#
M```.!0`````````````;`P``O@````````"\!````````"D#``!<`@``````
M`#4`````````\P,``#<!``!`!0```````%P!`````````````-T$````````
M4P0``#X!``!L`@``,@(``-T"`````````````-8```#1!```9`0``.X#```S
M!```;@4``"L$``!]!0```````(0#``!E````=P,``%P$```>`0``MP,``,D$
M````````?P,``(8#```.`@```````%\%```N`0``I@```+(````\`0``U0``
M`&($``">!```-`,``-\"``!,`0``L`,``#\"```[`````````!$!````````
M``````L$``"1!```M`0``'@!``"G`P``'P4``!,!````````B0,````````0
M!```:@4``,H```!>!```"P```(4!``!V`@``(`4``,H"``"M`0``I@,``'0%
M``````````````````"G`````````)8!```1!```E`,``(T"``"!!```9@4`
M`'0#````````/P```.L!````````H`0``````````````````+@#````````
M`````!8#``#/!```(0,````````:!0``W@(``"D$``#H`P``FP0``%$$``"W
M````*04```\``````````"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S
M*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S=&5R
M9&%Y*0`@870@`"(E<R(@:7,@;F]T(&$@9&ER96-T;W)Y+@`B)7,B(&ES(&YO
M="!A('9A;&ED(&-H;VEC92X`(B5S(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T
M:&4@2&]R9&4@4F5G:7-T<GDN`"(E<R(@=')E92!R96YD97)E<B!N;W0@9F]U
M;F0N`"(E<R(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+@`B)7,B
M('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+@`B)7,B('=A
M<R!N;W0@8W)E871E9#H@)7,N`"4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO
M=V5D("@E+C)F)24I`"5D("5S(&%N9"`E<P`E9"!D87ES('5N=&EL('EO=7(@
M<&%S<W=O<F0@97AP:7)E<RX`)60M9&%Y(&9O<F5C87-T`"5S("T@3F]T:6-E
M`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A=&EO
M;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T=7``)7,@4VEG;B!5<``E<R!497)M
M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D>2!E>&ES=',N`"5S(&%T("5S("5S
M`"5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P
M97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92X`
M)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S('1O
M("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L96YD87(`)7,G
M<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"5S.B!4:&ES(&UE<W-A
M9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A
M<F4@;V8@9F]L;&]W:6YG(&%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I
M;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BX`
M+"!G=7-T:6YG(``L(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M("5S
M('1O("5S`"TM('-E;&5C="`M+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O
M<FUA=``R-"!H;W5R<P`\4')E=FEO=7,`02!D871A8F%S92!B86-K96YD(&ES
M(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA<R!O
M8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y
M<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O
M('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P
M<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T
M92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG
M;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-
M24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y
M<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O
M34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N
M(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O
M(&5N8W)Y<'0@82!M97-S86=E+@!!32!#;&]U9',`04T@3&EG:'0@4F%I;@!!
M32!286EN`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W97)S`$%-+U!-`$%022!)
M1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8V-E<W,@9&5N:65D(&-R
M96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@
M5D93(&9I;&4N`$%C8V]U;G0@26YF;W)M871I;VX`06-C;W5N="!087-S=V]R
M9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`061D($-H:6QD($=R
M;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@3F5W($=R
M;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!G<F]U<"!T;R`B
M)7,B`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@(B5S(@!!9&0@82!N97<@
M=7-E<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D('!A:7(`061D
M('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!T;R!A9&1R
M97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D('5S97(`061D
M960@(B5S(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I
M=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N`$%D9&5D("(E<R(@=&\@
M=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+@!!9&1I;F<@=7-E<G,@
M:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S<R!";V]K`$%D;6EN:7-T97(@
M+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T
M:6]N`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S
M97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S
M`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R
M9&5R960@;&ES="!T>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U3
M4"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U3
M4"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@
M=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;B!I;&QE9V%L('9A;'5E('=A
M<R!S<&5C:69I960N`$%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N`$%N
M<W=E<@!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N
M(&ES(')E861Y+@!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<'!R
M;WAI;6%T92!3:7IE`$%P<FEL`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@
M3F%M90!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N
M=7`@<F5Q=65S="!F;W(@)7,@/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@
M9&5L971E("(E<R(@86YD(&%N>2!S=6(M9W)O=7!S/P!!<VL@9F]R(&-O;F9I
M<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`
M07-S:6=N;65N="!C;VQU;6YS`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X
M:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N
M="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@
M<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H
M87)E+@!!='1R:6)U=&5S`$%U9W5S=`!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@
M:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y<G5S.B!"86-K96YD
M(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N`$%U=&A?8WER
M=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]F
M='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE
M(%!(4"!W:71H('1H92`M+65N86)L92UF='`@<W=I=&-H+@!!=71H7VEM87`Z
M(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]K<F(U
M.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A
M<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$
M:7)E8W1O<GD`075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P
M<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5Q=6ER
M960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L
M92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S`$%U=&A?
M;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S`$%U=&A?;&1A<#H@57!D
M871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C
M=&]R>2X`075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F
M86EL960N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F
M86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S
M97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!!
M=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N`$%V86EL
M86)L92!F:65L9',Z`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@
M:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`0F%S
M92!G<F%P:&EC<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`$)I<G1H9&%Y
M`$)L;V-K("(E<R(@;V8@87!P;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L
M;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0F]L9`!";V]K;6%R:W,`0F]R9&5R
M`$)O<F1E<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]S;FEA(&%N9"!(97)Z96=O
M=FEN80!";W1H`$)O='1O;0!"<F%Z:6P`0G5L;&5T960@3&ES=`!#35,`0U)#
M`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S`$-?96QL(%!R;W!E<G1I97,N+BX`
M0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"X`0V%L96YD87(`0V%L;0!#
M86UB;V1I80!#86X@;F]T(&-O<'D@9FEL92AS*2`M('-O=7)C92!A;F0@9&5S
M=&EN871I;VX@87)E('1H92!S86UE+@!#86X@;F]T(&UO=F4@9FEL92AS*2`M
M(&1E<W1I;F%T:6]N(&ES('=I=&AI;B!S;W5R8V4N`$-A;B!N;W0@<F5S970@
M<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T
M<F%T;W(N`$-A;B!N;W0@=W)I=&4@=&\@9FEL92`B)7,B`$-A;B=T(&%D;6EN
M:7-T97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RX`0V%N)W0@8V]N;F5C
M="!T;R!)34%0('-E<G9E<CH@)7,`0V%N)W0@;W!E;B!F:6QE("(E<R(N`$-A
M;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE
M("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N
M;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#
M86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E
M9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E
M;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU
M;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE
M9"!N=6UB97(N`$-A<G)I97(`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA
M;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D
M9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE
M`$-E;G1E<@!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*0!#97)T:69I
M8V%T92!$971A:6QS`$-E<G1I9FEC871E($]W;F5R`$-E<G1I9FEC871E(%!O
M;&EC:65S`$-H86YG90!#:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@=&AE
M(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R
M96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=I;F<@>6]U<B!P
M87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N
M9FEG=7)A=&EO;BX@($-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#:&%R
M`$-H96-?:R!,:6YK+BXN`$-H:6QE`$-H:6YA`$-H;V]S92!!<'!L:6-A=&EO
M;CH`0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E
M(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E
M("AF;W(@;W)D97)E9"!L:7-T<RD`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N
M;W0@9F]U;F0N`$-L96%R`$-L96%R(%%U97)Y`$-L96%R(&]U="!U<V5R.B`E
M<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&5A<FEN9R!,871E`$-L
M:6-K('1O($-O;G1I;G5E`$-L;W-E(%=I;F1O=P!#;&]U9',`0VQO=61S($5A
M<FQY`$-L;W5D>0!#;VQL87!S92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S
M`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O
M;'5M;B!T:71L97,`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM
M96YT`$-O;6UO;B!.86UE`$-O;7!A;GD`0V]M<'5T97)S`$-O;F1I=&EO;@!#
M;VYD:71I;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R96YC97,`0V]N9FEG=7)A
M=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/
M=71L;V]K+@!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+@!#;VYF:6=U
M<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYN96-T:6]N(&9A:6QE9"X`0V]N
M;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U
M8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B
M;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@
M1E10('-E<G9E<B!F86EL960N`$-O;G1A8W1S`$-O;G1A8W1S('=E<F4@<W5C
M8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT96YT
M('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B``0V]N=&5N=',@;V8@(B5S(@!#
M;VYT:6YU90!#;W!Y`$-O<'D@9F%I;&5D.B`E<P!#;W!Y('-E;&5C=&EO;@!#
M;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@`$-O=6QD(&YO="!01U`@
M<VEG;B!M97-S86=E.B``0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A
M9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@
M861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R
M+@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-O;FYE
M8W0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E
M<B`B)7,B('5S:6YG($944#H@)7,`0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z(`!#
M;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T
M92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<P!#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T
M("(E<R(N`$-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M
M;6%I;"!A9&1R97-S+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S
M<R!B;V]K+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N
M(&QI<W0N`$-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D
M:7-T<FEB=71I;VX@;&ES=',N`$-O=6QD(&YO="!L;V%D('-T<F%T96=Y("(E
M<R(N`$-O=6QD(&YO="!M:V1I<B`B)7,B+@!#;W5L9"!N;W0@;V)T86EN('!U
M8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`B
M)7,B(&9O<B!W<FET:6YG+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T
M(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T(&]P
M96X@9&ER96-T;W)Y("(E<R(N`$-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S
M97)V97(N`$-O=6QD(&YO="!R96%D("5S+@!#;W5L9"!N;W0@<F5S970@=&AE
M('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL
M(&]F('1H92!D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R
M(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H
M97(@:&5L<"X`0V]U;&0@;F]T(')E=')I979E($%#3`!#;W5L9"!N;W0@<F5T
M<FEE=F4@861D<F5S<R!B;V]K+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB
M=71I;VX@;&ES=',N("5S`$-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C
M87!A8FEL:71I97,`0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#
M;W5L9"!N;W0@<FUD:7(@(B5S(BX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG
M=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N
M+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S`$-O
M=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!#
M;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E
M<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@
M66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T;R!S879E
M('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D
M92!B96QO=R!T;R`E<RX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V
M97(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P
M9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T('=R:71E(&-O
M;F9I9W5R871I;VX@9F]R("(E<R(Z("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO
M>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN
M`$-O=6QD;B=T(&=I=F4@=7-E<B`B)7,B('1H92!F;VQL;W=I;F<@<FEG:'1S
M(&9O<B!T:&4@9F]L9&5R("(E<R(Z("5S`$-O=6YT960@=&5X=`!#;W5N=')Y
M`$-O=7)S97,`0W)E871E`$-R96%T92!A(&QI;FL`0W)E871E(&$@;F5W(&]N
M90!#<F5A=&4@<W5B(&9O;&1E<G,`0W)E871O<B!097)M:7-S:6]N<P!#<F5D
M:70@8V%R9"!N=6UB97(`0W5R<F5N="`T(%!H87-E<P!#=7)R96YT(%-E<W-I
M;VYS`$-U<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT(%5S97)S
M`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E;G0@
M<W1Y;&4`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S
M+@!#=70`0W5T('-E;&5C=&EO;@!#>7!R=7,`1&%I;'D`1&%T90!$871E(%)E
M8V5I=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$95]L971E($-O;'5M;@!$96-E
M;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C<F5A<V4@26YD96YT`$1E9F%U;'0@
M0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969A=6QT(%-H96QL`$1E9FEN:71I
M;VYS`$1E;&5T90!$96QE=&4@0V5L;`!$96QE=&4@1W)O=7``1&5L971E($QO
M9P!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S
M`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L
M=&5R;F%T92!T96UP;&%T90!$96QE=&4@;65S<V%G97,`1&5L971E('!E<FUI
M<W-I;VYS(&9O<B`B)7,B`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(B!A
M;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E(')O=P!$96QE=&4@<V5L
M96-T960@:61E;G1I='D`1&5L971E('-U8B!F;VQD97)S`$1E;&5T92!T:&4@
M8W5R<F5N="!C;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$96QE=&5D
M('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$1E;&EV97)Y('1I;64`1&5N
M;6%R:P!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS
M("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N
M(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E
M=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@
M`$1I<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L
M969T`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I
M<W!L87D@9&5T86EL960@9F]R96-A<W0`1&ES<&QA>2!F;W)M870`1&ES<&]S
M:71I;VX@3F]T:69I8V%T:6]N`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C
M=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``1&]E<R!T:&4@9FER<W0@<F]W
M(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@
M8F]X.@!$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N`$1O=VYL;V%D
M`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N
M(&%S(%!(4"!S8W)I<'0N`$1R=6=S`$5D:70`161I="!";&]C:P!%9&ET($=R
M;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R
M;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES
M<VEO;G,@9F]R("(E<R(`161I="!P97)M:7-S:6]N<R!F;W(@)7,`16=Y<'0`
M16QE;65N="XN+@!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T
M(&UA=&-H+@!%;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%;7!T>2!M97-S86=E
M+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B;&4@:6YS
M97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT
M/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%;F0@>65A<@!%
M;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H
M('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@
M<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_
M)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5N=&5R('1H92!L971T97)S
M(&)E;&]W.@!%<G)O<@!%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,`17)R;W(@
M9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S`$5R<F]R(&1E;&5T:6YG('-Y;F,@
M;&]G.B`E<P!%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S`$5R<F]R('5P9&%T
M:6YG('!A<W-W;W)D.B`E<P!%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N`$5R
M<F]R('=R:71I;F<@(B5S(BX`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI
M;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@
M3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A
M;'5E<SH`17AE8W5T90!%>'!A;F0`17AP86YD(%-I9&5B87(`17AP96-T960@
M)RDG`$5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`
M17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$9'($-O;&]R`$944"!U<&QO860@
M;V8@<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE
M9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C
M="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A
M:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!
M4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I;&5D
M('1O(')E=')I979E.B`E<P!&86ER`$9A=&%L($5R<F]R.@!&96)R=6%R>0!&
M965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&:6QE($-O=6YT.B`E<R!F:6QE`$9I
M;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL
M92!S96QE8W1I;VX`1FEL92!U<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P
M;W)T960N`$9I;'1E<G,`1FEN;&%N9`!&:7)S="!(86QF`$9I<G-T(%%U87)T
M97(`1FEX(')A=&EO`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]N
M="!#;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@
M:6UA9V5S`$9O<F5C87-T("A4048I`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&
M;W)W87)D<P!&<@!&<F%N8V4`1G)O;0!&<F]M('1H92``1G5L;"!$97-C<FEP
M=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$=A;&QE<GD@=&\@=&%K92!I;6%G
M92!F<F]M`$=A;&QE<GDZ`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`1V5N
M97)A=&5D($-O9&4`1V5R;6%N>0!':6)R86QT87(`1VEV96X@3F%M90!';&]B
M86P@3W!T:6]N<P!';P!';V]G;&4@36%P<P!'<F%Y<V-A;&4`1W)E96-E`$=R
M;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M
M<'1Y`$=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!'<F]U<%]L9&%P.B!5;F%B;&4@
M=&\@9&5L971E(&=R;W5P("5S`$=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A
M=&4@9W)O=7`@)7,`1W)O=7!S`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T8F]O
M:P!(96%D97(`2&5A9&5R<P!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O
M<@!(96QP97(`2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@
M=&AE(&9I;&4Z`$AI9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3
M=&%T92D`2&]M90!(;VUE($%D9')E<W,`2&]M92!$:7)E8W1O<GD`2&]M92!0
M:&]N90!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ
M;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I
M`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO
M=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R
M;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET
M>3H@`$AU;F=A<GD`24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,`
M24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X
M('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`25`@061D<F5S<P!)4"!!9&1R
M97-S(&YO="!A=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO
M=V5D($-)1%(@8FQO8VLN`$E?;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC
M;VYS($]N;'D`26-O;G,@9F]R("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET
M>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E
M<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@>6]U(&1O;B=T('-E
M92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@
M;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P
M87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L
M('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA
M>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE=SH`26UA9V4@55),
M`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@9V%L
M;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0L(%-T97`@)60`26UP
M;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2;W<@
M069T97(`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E8W0@
M=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA;64@
M;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO
M=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$EN
M8W)E87-E($EN9&5N=`!);F1I=FED=6%L(%5S97)S`$EN9F]R;6%T:6]N`$EN
M9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N`$EN<V5R="!#7V]L=6UN
M($%F=&5R`$EN<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,
M:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN
M(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E
M9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T
M:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U
M<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N
M="!N;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@
M;F]D90!);G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I
M;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A
M<W-W;W)D.@!);G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`
M26YS97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E
M<G0@;65S<V%G97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R
M86=R87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F
M;W)E`$EN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET
M>2!Q=65S=&EO;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y
M($QI;FL`26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T
M<FEB=71I;VX@;&ES="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!)
M;G1E9V5R(&QI<W0`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`
M26YV86QI9"!:25`@9&%T80!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED
M(&)A=&-H($E$+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E
M<W1I;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI
M9"!L:6-E;G-E(&ME>2X`26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"X`26YV
M86QI9"!M<V=?='EP92X`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV
M86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E
M<FUI<W-I;VXN`$EN=F%L:60@<&%R=&YE<B!I9"X`26YV86QI9"!P<F]D=6-T
M(&-O9&4N`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<F5C:7!I96YT.B`B
M)7,B`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D9')E
M<W,N`$EN=F5N=&]R>0!);G9E<G0@<V5L96-T:6]N`$ES<W5E<@!)=&%L>0!*
M86YU87)Y`$IA<&%N`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I9GD@0V5N=&5R
M`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+965P
M(&]R:6=I;F%L/P!+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC
M871I;VXN`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T
M:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$QA7WEO=70`3&%N9W5A9V4`3&%S
M="!(86QF`$QA<W0@4&%S<W=O<F0@0VAA;F=E`$QA<W0@475A<G1E<@!,87-T
M(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@
M)7,`3&%S="!L;V=I;CH@3F5V97(`3&%W`$QA>6]U=`!,96%V92!E;7!T>2!F
M;W(@;F\@8F]R9&5R`$QE8F%N;VX`3&5F=`!,969T(&AE861E<@!,969T('9A
M;'5E<P!,979E;`!,:6=H="!286EN`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI
M;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N
M(&1I<W!L87EI;F<`3&EN:W,`3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L
M9&5R`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!486)L
M97,`3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`
M3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG('-E<W-I
M;VYS(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!F86EL960Z("5S`$QI<W1I
M;F<@=7-E<G,@:7,@9&ES86)L960N`$QI=&5R871U<F4`3&]A9&EN9RXN+@!,
M;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,
M;V<@;W5T`$QO9VEN`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E
M('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R
M96-T;'DN`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R
M(&=R965K(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA
M;B!N=6UB97)S`$QU>&5M8F]U<F<`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A
M:6YE9"!N;R!D871A+@!-86=I8P!-86EL`$UA:6P@061M:6X`36%K92!L:6Y?
M:RXN+@!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T
M;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET
M:"!T:&]S92!C871E9V]R:65S+@!-87)C:`!-87)G:6X`36%R:R!W:71H(%-E
M96XO56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!)
M;7!O<G1A;G0O06YS=V5R960I`$UA=&-H:6YG(&9I96QD<P!-87@@86QL;W=E
M9"!C<F5D:70N`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M
M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``36%X
M:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<P!-87AI;75M(&QE;F=T:`!-
M87D`365D:6-I;F4`365M8F5R<P!-97)G92!C96QL<P!-97-S86=E`$UE<W-A
M9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R
M=&EF:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER
M960N`$UE<W-A9V4@='EP90!-971H;V0`365T:&]D("(E<R(@:7,@;F]T(&1E
M9FEN960`365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D.B`E<P!-
M971R:6,`365X:6-O`$UI9&1L90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``
M36EN('1E;7`@;&%S="`V(&AO=7)S.B``36EN:6UU;2!P87-S=V]R9"!A9V4@
M:&%S(&YO="!Y970@97AP:7)E9`!-:7)R;W(`36ES8V5L;&%N96]U<P!-:7-S
M:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N`$UI<W-I;F<@8V]N9FEG
M=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W
M86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@
M240N`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN`$UI<W-I
M;F<@<V5S<VEO;B!)1"X`36\`36]D97)A=&4`36]D:69I960@1&%T90!-;V1I
M9GD@55),`$UO9'5L=7,`36]N=&@@86YD('EE87(`36]N=&AL>0!-;V]N(%!H
M87-E<P!-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X
M<&5C=&5D("5D+@!-;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V
M92!5<`!-;W9E(&1O=VX`36]V92!U<`!-=6QT:7!L92!S96QE8W1I;VX`37D@
M06-C;W5N=`!->2!!8V-O=6YT($EN9F]R;6%T:6]N`$UY(%!O<G1A;`!->2!0
M;W)T86P@3&%Y;W5T`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YE='=O<FL`
M3F5V97(`3F5W($-A=&5G;W)Y`$YE=R!-;V]N`$YE=R!5<V5R;F%M92`H;W!T
M:6]N86PI`$YE=R!P87-S=V]R9`!.97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@
M;VX@)7@N`$YE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N`$YE=R!W:6YD;W<@
M*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="`T(%!H87-E<P!.
M97AT(&]P=&EO;G,`3F5X=#X`3FEG:'0`3F\@879A:6QA8FQE(&-O;F9I9W5R
M871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@879A:6QA
M8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RX`3F\@8FQO8VL@
M97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VX`3F\@8V%L96YD87(@
M;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BX`3F\@8VAA
M;F=E+@!.;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S
M:6]N+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`3F\@8W)E9&ET(&QE
M9G0N`$YO(&1E<W1I;F%T:6]N('-U<'!L:65D+@!.;R!F:6QE('5P;&]A9&5D
M`$YO(&EC;VYS(&9O=6YD+@!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&QO8V%T
M:6]N('!R;W9I9&5D+@!.;R!M97-S86=E('-U<'!L:65D+@!.;R!N86UE('-P
M96-I9FEE9"X`3F\@;G5M8F5R('-P96-I9FEE9"X`3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@
M<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N
M4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@
M9&%T82X`3F\@<75O=&$@<V5T+@!.;R!R=6QE<P!.;R!S97!A<F%T;W(@<W!E
M8VEF:65D+@!.;R!S:61E<P!.;R!S=6-H(&9I;&4`3F\@=&5M<&]R87)Y(&1I
M<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!U<V5R;F%M92!A;F0O
M;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960`
M3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG
M=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;R!V97)S:6]N
M(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF
M:6=U<F%T:6]N+@!.;VYE`$YO;F4@*'5S92!I;7!L:6-I="D`3F]R=&AE<FX@
M2&5M:7-P:&5R90!.;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@
M9&ER96-T;W)Y`$YO="!I;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R
M=&5D+@!.;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V96UB
M97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU
M;6YS`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@
M=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]B:F5C=`!/8FIE8W0@
M0W)E871O<@!/8W1A;`!/8W1O8F5R`$]F9FEC90!/;&0@86YD(&YE=R!P87-S
M=V]R9',@;75S="!B92!D:69F97)E;G0N`$]L9"!P87-S=V]R9`!/;&0@<&%S
M<W=O<F0@:7,@;F]T(&-O<G)E8W0N`$]N;'D@24U!4"!S97)V97)S('-U<'!O
M<G0@<VAA<F5D(&9O;&1E<G,N`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL
M;W=E9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@
M;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R
M(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-33"!E<G)O<CH@
M0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R
M="X`3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@
M4WES=&5M`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R
M9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I
M9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S
M(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=VYE<B!097)M:7-S
M:6]N<P!004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4$=0
M($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC
M<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H96QL`%!/4TE8(&5X=&5N<VEO
M;B!I<R!M:7-S:6YG`%!A9&1I;F<`4&%R=&QY($-L;W5D>0!087-S=V]R9"!C
M:&%N9V5D('-U8V-E<W-F=6QL>2X`4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W
M;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN`%!A<W-W
M;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!0
M87-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;W!L90!097)C96YT
M`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES
M<VEO;B`B)7,B(&YO="!D96QE=&5D+@!097)M:7-S:6]N($1E;FEE9`!097)M
M:7-S:6]N<P!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!097)S;VYA;"!)
M;F9O<FUA=&EO;@!0:&]N90!0:&]T;W,`4&QE87-E(&-L:6-K(&EN=&\@<V]M
M92!C96QL`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E
M('1H:7,@96QE;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T
M;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!M;VYT:"!A
M;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A
M=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0;&5A
M<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A
M>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+@!0
M;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S
M92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!R
M96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T
M:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!L96%S92!T>7!E('1H92!N
M97<@8V%T96=O<GD@;F%M93H`4&]L86YD`%!O;&ET:6-S`%!O;&QS`%!O<G1U
M9V%L`%!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@
M=&AI<R!T86)L90!0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@
M8GD@24U!4"D`4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``
M4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`%!R97-S=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R
M97-S=7)E.B``4')E=FEE=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W
M:6YD;W<`4')E=FEO=7,@;W!T:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV871E
M($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C=',`4'5B
M;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,@2V5Y($EN9F\`
M4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F
M=6QL>2X`4'5R9V4@;65S<V%G97,`475E<GD`4F%D:6\@<V5L96-T:6]N`%)A
M:6X`4F%T:6\`4F5A9`!296%D(&UE<W-A9V5S`%)E86QL>2!D96QE=&4@)7,_
M(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E86QL>2!R96UO
M=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN
M;W0@8F4@=6YD;VYE+@!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H
M`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.@!2969R97-H(%!O<G1A
M;"!6:65W.@!296QO860`4F5M87)K<P!296UO=&4@4V5R=F5R<P!296UO=&4@
M55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E
M;6]V92!";&]C:P!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E
M;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T
M96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T:&ES(&YO
M9&4@9G)O;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z
M("5S`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R
M<F]R8V]D93H@`%)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N
M9"X`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R
M871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N
M9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(&-O
M;F9I9W5R871I;VXN`%)E<75I<F5D($9I96QD`%)E<V5T`%)E<V5T(%!A<W-W
M;W)D`%)E<V5T(%EO=7(@4&%S<W=O<F0`4F5S=&]R92!,87-T(%%U97)Y`%)E
M<W5L=',`4F5T=7)N('1O($]P=&EO;G,`4F5T>7!E(&YE=R!P87-S=V]R9`!2
M975N:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@
M3W!T:6]N<P!2:61D;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU
M97,`4F]?=R!0<F]P97)T:65S+BXN`%)O;&4`4F]T871E(#$X,`!2;W1A=&4@
M3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I
M97,`4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@
M<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O
M;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL
M>0!2=6X`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%
M;F-R>7!T960@365S<V%G90!305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A
M=F%I;&%B;&4N`%--4R!-97-S86=I;F<`4U%,('-T871E;65N="!F;W(@=F%L
M=64@;&]O:W5P<P!386UE(&9R86UE("A?<V5L9BD`4V%T96QL:71E(%!R;W9I
M9&5R`%-A=F4`4V%V92`B)7,B`%-A=F4@)7,`4V%V92!/<'1I;VYS`%-A=F4@
M9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO
M=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4V%V960@)7,@8V]N
M9FEG=7)A=&EO;BX`4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E
M<R(N`%-C:65N8V4`4V5A<F-H`%-E87)C:"!%;F=I;F5S`%-E;&5C="!&:6QE
M<P!396QE8W0@82!D871E`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@
M82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@
M861D`%-E;&5C="!A;&P`4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N`%-E
M;&5C="!A;B!O8FIE8W0`4V5L96-T(&YO;F4`4V5L96-T('1H92!C:&%R86-T
M97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H
M96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E
M;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M
M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!3
M96QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R
M;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@
M8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z
M`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`4V5N<V]R.B``4V5P=&5M
M8F5R`%-E<FEA;"!.=6UB97(`4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V
M86EL86)L92X`4V5S<VEO;B!!9&UI;@!397-S:6]N($E$(&5X<&ER960N`%-E
M<W-I;VYS`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@
M>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R
M96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO
M=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z
M;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC
M871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H
M97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C<FEP
M=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@
M=&AE('!A<F%M971E<CH@`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K
M97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R!D:69F
M97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY
M(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@!3:&]W(&QA<W0@;&]G:6X@=&EM
M92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN
M86P`4VAO=R!P:6-K97(`4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R
M/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W('5P;&]A9`!3
M:6=N('5P`%-I9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I>F4`4VMI
M<"!-86EN=&5N86YC90!3;F]W`%-O<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C
M92!A9&1R97-S`%-O=71H($%F<FEC80!3;W5T:&5R;B!(96UI<W!H97)E`%-P
M86-E(&)E='=E96X@861J86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT
M96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG
M(&%N9"!P861D:6YG`%-P86EN`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P
M;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3=&%R="!Y96%R`%-T
M871E(&]R(%!R;W9I;F-E`%-T;W)A9V4@9F]R;6%T`%-T<F5E="!!9&1R97-S
M`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=`%-U
M`%-U8F1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`4W5B:F5C=`!3=6)M:70`
M4W5B;6ET=&5D(')E<75E<W0@=&\@861D("(E<R(@=&\@=&AE('-Y<W1E;2X@
M66]U(&-A;FYO="!L;V<@:6X@=6YT:6P@>6]U<B!R97%U97-T(&AA<R!B965N
M(&%P<')O=F5D+@!3=6-C97-S9G5L;'D@861D960@(B5S(B!T;R!T:&4@<WES
M=&5M+@!3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R("(E<R(@
M9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@9&5L971E9"`B)7,B+@!3
M=6-C97-S9G5L;'D@<F5M;W9E9"`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C
M8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S
M964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U
M<F%T:6]N+@!3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U
M<F%T:6]N(&9I;&4@)7,N`%-U8V-E<W-F=6QL>2!U<&1A=&5D("(E<R(`4W5C
M8V5S<V9U;&QY('=R;W1E("5S`%-U;6UA<GD`4W5P<&]R=`!3=7)N86UE`%-W
M961E;@!3=VET>F5R;&%N9`!3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS
M`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@4V5T`%1A8FQE('!R;W!E<G1I97,`
M5&%R9V5T.@!487-K<P!496QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R(&QA<W0@
M:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&QA=&4@(B5S
M(B!N;W0@9F]U;F0N`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X
M="!/;FQY`%1E>'0@86QI9VX`5&@`5&AE($944"!E>'1E;G-I;VX@:7,@;F]T
M(&%V86EL86)L92X`5&AE($AI<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D+@!4
M:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U
M<'!O<G0@(B5S(@!4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI
M>F5D+@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C
M8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET
M:6YG+@!4:&4@8F]T=&]M('-I9&4@;VYL>0!4:&4@8V]N=&%C="!W87,@<W5C
M8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@9&ES
M=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T
M:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN
M`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE
M(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H
M92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H
M92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!N=6UB97(@
M;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RX`5&AE(&]P96YS<VP@;6]D=6QE
M(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S
M<RX`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C
M875S92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@
M<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@
M*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!S97)V97(@
M(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E
M96X@<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@
M<F5M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES
M="X`5&AE('1E;7!O<F%R>2!F:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H
M92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@
M=&AE('-C<F5E;BX`5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@
M=&AE('!R979I;W5S('-T97`N`%1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO
M="!B92!S879E9"X`5&AE;65S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`
M5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@
M<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E
M('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@
M96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H
M86X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@861D:6YG("(E<R(@=&\@=&AE
M('-Y<W1E;3H@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A
M(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@
M<')O8FQE;2!R96UO=FEN9R`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E
M('=A<R!A('!R;V)L96T@=7!D871I;F<@(B5S(CH@)7,`5&AE<F4@=V%S(&$@
M<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A
M9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D
M.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W960@
M<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE
M(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A
M9&5D+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A
M9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT
M86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#
M86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I
M9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R97%U:7)E
M9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P
M96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@86=A
M:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N
M=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W
M87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0
M;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&ES($E-05`@<V5R=F5R(&1O97,@
M;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(&1O97,@;F]T(&%P
M<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O97,@;F]T
M('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!F:65L9"!M
M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UU
M<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E
M9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H:7,@
M9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE
M>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F;W)M(&AA
M<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES(&UE
M<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H
M97(@=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S
M="!O;F4N`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G
M>FEP(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T
M960N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@
M;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R
M`%1I8VME=',`5&EM90!4:6UE(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4:71L
M90!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@
M0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K
M:6YG+@!4;V1A>0!4;VUO<G)O=P!4;V\@;6%N>2!I;G9A;&ED(&QO9VEN<R!D
M=7)I;F<@=&AE(&QA<W0@;6EN=71E<RX`5&]P`%1R86YS;&%T:6]N<P!4<G5E
M(&]R(&9A;'-E`%1U`%1U<FME>0!4>7!E('EO=7(@8VAO:6-E.B``56YA8FQE
M('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A
M('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@
M8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T
M;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L
M92!T;R!C:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@
M;V8@(B5S(BX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,O)7,B
M+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@
M8V]N;F5C="!W:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N
M86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@
M8W)E871E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I
M;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@
M=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S
M<R!D871A+@!5;F%B;&4@=&\@9&5L971E("(E<R(L('1H92!D:7)E8W1O<GD@
M:7,@;F]T(&5M<'1Y+@!5;F%B;&4@=&\@9&5L971E("(E<R(Z("5S+@!5;F%B
M;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>0!5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N
M86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T
M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL
M92`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@
M9&5L971E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@
M<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@
M9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A
M:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B
M;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@
M(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S
M<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ
M92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE
M4VEZ92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D(&9I;&4Z(`!5;F%B;&4@
M=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA
M;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T
M<P!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R
M96YA;64@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R96YA;64@5D93
M(&9I;&4@(B5S(BX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`
M56YA8FQE('1O(')E;F%M92!61E,@9FEL92X`56YA8FQE('1O(')U;B`G;6MI
M<V]F<R<N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT
M`%5N86)L92!T;R!T<FEG9V5R(&9R964O8G5S>2!U<&1A=&4@9F]R("5S`%5N
M86)L92!T;R!W<FET92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4@*&-O<'DH*2!F86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4@9&%T82X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W
M:6QL(&)E(&5X8V5E9&5D+@!5;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E
M<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S
M97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O
M;2!S97)V97(@=&\Z(`!5;FMN;W=N`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S
M<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M960`56YS
M=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`57!D871E('5S
M97(`57!D871E9"`B)7,B+@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO
M860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H
M92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@;G5M
M8F5R<P!5<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@:68@;F%M92]P87-S
M=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R`%5S97(@
M)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T
M:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES
M=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R
M(&%C8V]U;G0@;F]T(&9O=6YD`%5S97)N86UE`%5S97)N86UE("(E<R(@86QR
M96%D>2!E>&ES=',N`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H
M92!S>7-T96TZ`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T
M:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``5F%L:61I='D`
M5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L=64@:7,@;W9E<B!T:&4@
M;6%X:6UU;2!L96YG=&@@;V8@)7,N`%9A;'5E<P!686QU97,@=&\@<V5L96-T
M(&9R;VT`5F%R:6%B;&4`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S
M<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R
M<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`
M5F5R=&EC86PZ`%9E<GD@2&EG:`!6:65W("5S`%9I97<@86X@97AT97)N86P@
M=V5B('!A9V4`5FEE=R!A<R`E<P!6:7-I8FEL:71Y`%9I<VEB:6QI='DZ(`!7
M05).`%=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S
M+@!787)N:6YG`%=E`%=E871H97(@1F]R96-A<W0`5V5A=&AE<B!D871A('!R
M;W9I9&5D(&)Y`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M
M92P@)7,`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E
M<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAI
M8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R
M+@!7:61T:`!7:61T:"!I;B!#4U,@=6YI=',`5VED=&@@;V8@=&AE("5S(&UE
M;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ
M`%=I9'1H(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7:6YD`%=I
M;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O;0!7;W)K`%=O
M<FL@061D<F5S<P!7;W)K(%!H;VYE`%=R;VYG(&YU;6)E<B!O9B!F:65L9',@
M:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D+@!7<F]N9R!N=6UB
M97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG(&]F
M9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N`%EE87)L>0!997,`
M665S+"!)($%G<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;
M/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E
M(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+@!9
M;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N;F]T(&AA=F4@=&AE
M("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!D:60@;F]T
M(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I9&XG="!M87`@
M86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R
M97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&AA=F4@8F5E;B!L;V=G960@
M;W5T+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB
M97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG(&9O<B!T:&4@
M:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"X`66]U(&AA=F4@=&\@96YT
M97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R
M964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@8V]N9FEG=7)E
M(&$@5D93(&)A8VME;F0N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M
M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@
M;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\`
M66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+@!9;W4@
M;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@;75S
M="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C
M:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE
M('5S97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C
M=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y
M(&YA;64N`%EO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N
M=6UB97(`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G
M:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E
M<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA
M<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S
M:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN
M(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD
M(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T
M;R!U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@
M;75S="!U<V4@82!D:69F97)E;G0@875T:&5N=&EC871I;VX@8F%C:V5N9"X`
M66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@
M;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L
M960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R
M<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R
M("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU
M<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T
M('1H:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@
M=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@
M=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L
M="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E9F%U;'0@:61E
M;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&QO9VEN(&AA<R!E>'!I<F5D
M+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N
M<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@
M<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R
M('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E
M96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO
M=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+@!9
M;W5R(')E;6]T92!S97)V97)S.@!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L
M96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!4
M97AT("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I
M;VX`7T1E;&5T92!2;W<`7T=R;W5P<P!?2&5L<`!?26UA9V4@4')O<&5R=&EE
M<RXN+@!?3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN:RXN+@!?3W!T:6]N
M<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]3971U<`!?5&%B;&4@
M4')O<&5R=&EE<RXN+@!?57-E<G,`861D<F5S<R!B;V]K`&%D9')E<W-E92!U
M;FMN;W=N`&-A;&5N9&%R`&-A;&T`8V%N;F]T(&-R96%T92!O=71P=70@9FEL
M90!C86YN;W0@;W!E;B!I;G!U=`!C;&EC:R!H97)E`&-O;6UA;F0@;&EN92!U
M<V%G92!E<G)O<@!C;VYF:6=U<F%T:6]N(&5R<F]R`&1A=&$@9F]R;6%T(&5R
M<F]R`&1I<W!L87D@9F]R96-A<W0@*'1A9BD`961I=`!E;G1R>2!N;W0@9F]U
M;F0`9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!H;W-T(&YA;64@=6YK;F]W
M;@!I;6UE9&EA=&4`:6YP=70O;W5T<'5T(&5R<F]R`&EN=&5R;F%L('-O9G1W
M87)E(&5R<F]R`&QI;F5S70!M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@
M;6%K:6YG($E33RX`;F%M90!N;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L
M96UE;G1E9`!N;W1E<&%D`'!E<F-E;G0`<&5R;6ES<VEO;B!D96YI960`<F5M
M;W1E(&5R<F]R(&EN('!R;W1O8V]L`'-E<G9I8V4@=6YA=F%I;&%B;&4`<VAO
M=R!D:69F97)E;F-E<P!S=&5A9'D`<WES=&5M(&5R<F]R`'1A<VL@;&ES=`!T
M96UP;W)A<GD@9F%I;'5R90!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C
M;VYF:7)M`'5N:69I960`=6YN86UE9`!U<V5R('-E;&5C=`!W.@!W96%T:&5R
M+F-O;0!0<F]J96-T+4ED+59E<G-I;VXZ(&AO<F1E(#,N,2XQ"E)E<&]R="U-
M<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO
M;BU$871E.B`R,#`V+3`T+3$S(#$T.C$V*S`R,#`*4$\M4F5V:7-I;VXM1&%T
M93H@,C`P-BTP-"TQ,R`Q-#HQ-BLP,C`P"DQA<W0M5')A;G-L871O<CH@36%R
M8V\@4&ER;W9A;F\@/&UA<F-O+G!I<F]V86YO0'5N:6)O8V-O;FDN:70^"DQA
M;F=U86=E+51E86TZ(&DQ.&Y`;&ES=',N:&]R9&4N;W)G"DU)344M5F5R<VEO
M;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M
M.#@U.2TQ"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*4&QU<F%L
M+49O<FUS.B!N<&QU<F%L<STR.R!P;'5R86P]*&X@(3T@,2D["@`@*"5S(&=I
M;W)N:2!S8V]R<VDI`"`H0VAI879E(&1I(&%C8V5S<V\@)7,I`"`H:6X@)7,@
M9VEO<FYI*0`@*&]G9VDI`"`H9&]M86YI*0`@*&EE<FDI`"!A(&$`(B5S(B!N
M;VX@Z"!U;F$@9&ER96-T;W)Y+@`B)7,B(&YO;B#H('5N82!S8V5L=&$@=F%L
M:61A+@`B)7,B(&YO;B#H(&-O;F9I9W5R871O(&YE:2!296=I<W1R:2!D:2!(
M;W)D92X`(B5S(B!A;&)E<F\@<F5N9&5R97(@;F]N('1R;W9A=&\N`"(E<R(@
MZ"!S=&%T;R!A9V=I=6YT;R!A:2!G<G5P<&D@9&D@<VES=&5M82X`(B5S(B#H
M('-T871O(&%G9VEU;G1O(&%I('!E<FUE<W-I(&1I('-I<W1E;6$N`"(E<R(@
M;F]N(.@@<W1A=&\@8W)E871O.B`E<RX`)2XR9DU"('5S871I(&1I("4N,F9-
M0B!D:7-P;VYI8FEL:2`H)2XR9B4E*0`E9"`E<R!E("5S`"5D(&=I;W)N:2!A
M;&QO('-C861E<F4@9&5L;&$@='5A('!A<W-W;W)D+@`E9"UG:6]N;R!P<F5V
M:7-I;VYE`"5S("T@3F]T:7II80`E<R!&:7)M82!$:6=I=&%L90`E<R!+0@`E
M<R!/<&5R87II;VYI(&1I($UA;G5T96YZ:6]N92`M($-O;F9E<FUA`"5S($EM
M<&]S=&%Z:6]N90`E<R!&:7)M80`E<R!497)M:6YI(&1I($%C8V]R9&\`)7,@
M9VG@(&5S:7-T96YT92X`)7,@82`E<R`E<P`E<R#H('!R;VYT;R!P97(@97-E
M9W5I<F4@;&4@;W!E<F%Z:6]N:2!D:2!M86YU=&5N>FEO;F4@<V]T=&\@<V5L
M97II;VYA=&4N(%-E;&5Z:6]N82!L82!C87-E;&QA('!E<B!O9VYI(&]P97)A
M>FEO;F4H:2D@8VAE('9U;VD@97-E9W5I<F4@;W)A+@`E<R#H(')I8VAI97-T
M;P`E<R!M:6YU=&D`)7,@;F]N('1R;W9A=&\N`"5S(&$@)7,@9&D@)7,`4G5B
M<FEC82!D:2`E<P!#86QE;F1A<FEO(&1I("5S`$YO=&4@9&D@)7,`3&ES=&$@
M071T:79I=.`@9&D@)7,`)7,Z("5S`"5S.B!1=65S=&\@;65S<V%G9VEO('!O
M=')E8F)E(&YO;B!A<G)I=F4@9&$@8VAI(&1I8VAI87)A(&1I(&5S<V5R92X@
M071T96YZ:6]N92!A:2!L:6YK('!R97-E;G1I(&EN(&5S<V\@;R!F;W)N:7-C
M:2!O9VYI(&EN9F]R;6%Z:6]N92!A;"!M:71T96YT92X`+"!S;V9F:6%N9&\@
M`"P@<V]F9FEA;F1O("5S("5S`"P@=F%R:6%B:6QE(&1A("5S(&$@)7,`+2T@
M<V5L97II;VYA("TM`$9O<FUA=&\@,3(@;W)E`$9O<FUA=&\@,C0@;W)E`#(T
M(&]R90`\4')E8V5D96YT90!5;B!D871A8F%S92!D:2!B86-K96YD(.@@<FEC
M:&EE<W1O('!E<B!Q=65S=&\@8FQO8V-O+@!%)R!A8V-A9'5T;R!U;B!E<G)O
M<F4@9F%T86QE`%5N82!C:&EA=F4@<'5B8FQI8V$@4$=0(.@@<FEC:&EE<W1A
M('!E<B!C:69R87)E(&EL(&UE<W-A9V=I;RX`56YA(&-H:6%V82!P=6)B;&EC
M82!01U`@Z"!R:6-H:65S=&$@<&5R('9E<FEF:6-A<F4@:6P@;65S<V%G9VEO
M(&9I<FUA=&\N`%5N82!C:&EA=F4@<'5B8FQI8V$@4$=0+"!U;F$@8VAI879E
M('!R:79A=&$@4$=0+"!E('5N82!P87-S=V]R9"!S;VYO(')I8VAI97-T92!P
M97(@9&5C:69R87)E('5N(&UE<W-A9V=I;P!5;F$@8VAI879E('!U8F)L:6-A
M(%!'4"P@=6YA(&-H:6%V92!P<FEV871A(%!'4"P@92!U;F$@<&%S<W=O<F0@
M<V]N;R!R:6-H:65S=&4@<&5R(&9I<FUA<F4@=6X@;65S<V%G9VEO`%5N82!C
M:&EA=F4@<'5B8FQI8V$@4R]-24U%+"!U;F$@8VAI879E('!R:79A=&$@4R]-
M24U%(&4@=6YA('!A<W-W;W)D('-O;F\@<FEC:&EE<W1E('!E<B!D96-I9G)A
M<F4@=6YA(&UE<W-A9V=I;RX`56YA(&-H:6%V92!P=6)B;&EC82!3+TU)344L
M('5N82!C:&EA=F4@<')I=F%T82!3+TU)344@92!U;F$@<&%S<W=O<F0@<V]N
M;R!R:6-H:65S=&4@<&5R(&9I<FUA<F4@=6X@;65S<V%G9VEO+@!5;F$@8VAI
M879E('!U8F)L:6-A(%,O34E-12#H(')I8VAI97-T82!P97(@8VEF<F%R92!U
M;B!M97-S86=G:6\N`$%-($YU8FD`04T@4&EO9V=I82!,96=G97)A`$%-(%!I
M;V=G:6$`04T@06-Q=6%Z>F]N:0!!32!.979I8V%T90!!32]030!!4$D@240`
M4FEG=6%R9&\@<75E<W1O(&5D:71O<@!2:6=U87)D;RXN+@!!8V-E<W-O(&YE
M9V%T;R!C<F5A;F1O(&QA(&1I<F5C=&]R>2!61E,N`$%C8V5S<V\@;F5G871O
M(&-R96%N9&\@5D93(&9I;&4N`$EN9F]R;6%Z:6]N:2!!8V-O=6YT`%!A<W-O
M=W)D($%C8V]U;G0`06-C;W5N="!C;VYG96QA=&\N`$%C8V]U;G1I;F<`06=G
M:75N9VD`06=G:75N9VD@1W)U<'!O($9I9VQI;P!!9V=I=6YG:2!097)M97-S
M:2!&:6=L:6\`06=G:75N9VD@<75I.@!!9V=I=6YG:2!.=6]V;R!'<G5P<&\`
M06=G:75N9VD@3G5O=F\@4&5R;65S<V\`06=G:75N9VD@=6X@9W)U<'!O(&9I
M9VQI;R!A("(E<R(`06=G:75N9VD@=6X@<&5R;65S<V\@9FEG;&EO(&$@(B5S
M(@!!9V=I=6YG:2!U;B!N=6]V;R!U=&5N=&4Z`$%G9VEU;F=I(&-O;&]N;F$`
M06=G:75N9VD@;G5O=FD@;65M8G)I`$%G9VEU;F=I(&QA(&-O<'!I80!!9V=I
M=6YG:2!I;"`E<R!-96YU(&-O;64@=6YA($UO>FEL;&$@4VED96)A<@!!9V=I
M=6YG:2!A;&QA(')U8G)I8V$Z`$%G:75N9VD@86QL82!R=6)R:6-A('!E<G-O
M;F%L90!!9V=I=6YG:2!U=&5N=&4`06=G:75N=&D@(B5S(B!A;"!S:7-T96UA
M+"!M82!N;VX@<VD@<&]S<V]N;R!A9V=I=6YG97)E('5L=&5R:6]R:2!I;F9O
M<FUA>FEO;FDZ("5S+@!!9V=I=6YT;R`B)7,B(&%L('-I<W1E;6$N($]R82!P
M=6]I(&%C8V5D97)E+@!,)V%G9VEU;G1A(&1I('5T96YT:2#H(&1I<V%B:6QI
M=&%T82X`26YD:7)I>GIO`%)U8G)I8V$`06UM:6YI<W1R871O<F4@+2!I;7!O
M<W1A(&D@<&5R;65S<VD@<&5R(&%L=')I('5T96YT:0!!;6UI;FES=')A>FEO
M;F4`06QL:6YE80!!;&QI;F5A;65N=&\Z`%1U='1I`%1U='1I(&=L:2!U=&5N
M=&D@875T96YT:6-A=&D`5'5T=&D@:2!G<G5P<&D`5'5T=&D@:2!P97)M97-S
M:0!4=71T:2!E('%U871T<F\@:2!L871I`%1U='1I(&=L:2!I;F1I<FEZ>FD@
M;75L=&EP;&D`4&5R;65T=&5R92!L92!I;7!O<W1A>FEO;FD@9&D@;&ES=&4@
M;W)D:6YA=&4@<&5R('1I<&\_`$5S:7-T92!G:>``3&]G:6X@24U34"!A;'1E
M<FYA=&EV80!087-S=V]R9"!)35-0(&%L=&5R;F%T:79A`%5T96YT92!)35!3
M(&%L=&5R;F%T:79O`$EN9&ER:7IZ;R!E;6%I;"!A;'1E<FYA=&EV;P!-87-C
M:&5R92!A;'1E<FYA=&EV90!497-T;R!A;'1E<FYA=&EV;SH`12<@<W1A=&\@
M<W!E8VEF:6-A=&\@=6X@=F%L;W)E(&YO;B!V86QI9&\N`$5R<F]R92!S8V]N
M;W-C:75T;RX`4FES<&]S=&$`07!P;&EC87II;VYE`$QI<W1A($%P<&QI8V%Z
M:6]N:0!,)V%P<&QI8V%Z:6]N92#H('!R;VYT82X`07!P;&EC82!A:2!F:6=L
M:2!C;VYD:79I<VD`07!P<F]V80!$:6UE;G-I;VYE($%P<')O<W-I;6%T:79A
M`$%P<FEL90!$:6UE;G-I;VYE(&9I;&4@:6X@87)C:&EV:6\`3F]M92!!<F-H
M:79I;P!396D@<VEC=7)O(&1I('9O;&5R(')I;75O=F5R92!L92!R:6-H:65S
M=&4@9FER;6%T92!P97(@)7,@/P!!<V5I('-I8W5R;R!D:2!V;VQE<B!E;&EM
M:6YA<F4@(B5S(B!E(&]G;FD@<V]T=&\M9W)U<'!O/P!2:6-H:65D97)E(&QA
M(&-O;F9E<FUA('!R:6UA(&1I(&5S96=U:7)E(&QE(&]P97)A>FEO;FD@9&D@
M;6%N=71E;GII;VYE/P!!<W-E9VYA;65N=&\@8V]L;VYN90!3:2#H(&-E<F-A
M=&\@9&D@96QI;6EN87)E('5N(&=R=7!P;R!N;VX@97-I<W1E;G1E+@!3:2#H
M(&-E<F-A=&\@9&D@96QI;6EN87)E('5N('!E<FUE<W-O(&YO;B!E<VES=&5N
M=&4N`%-I(.@@8V5R8V%T;R!D:2!P=6)B;&EC87)E('5N('!E<FUE<W-O(&YO
M;B!E<VES=&5N=&4N`%-I(.@@8V5R8V%T;R!D:2!P=6)B;&EC87)E('5N82!C
M;VYD:79I<VEO;F4@;F]N(&5S:7-T96YT92X`071T<FEB=71I`$%G;W-T;P!!
M=71H7V-Y<G-Q;#H@97-T96YS:6]N92!I;6%P(')I8VAI97-T82!N;VX@=')O
M=F%T82X`075T:%]C>7)U<SH@:6P@8F%C:V5N9"!N;VX@:&$@;&4@8V%P86-I
M=.`@<FEC:&EE<W1E+@!!=71H7V-Y<G5S.B!E<W1E;G-I;VYE(&EM87`@<FEC
M:&EE<W1A(&YO;B!T<F]V871A+@!!=71H7V9T<#H@17-T96YS:6]N92!&5%`@
M<FEC:&EE<W1A(&YO;B!T<F]V871A+B!#;VUP:6QA(%!(4"!C;VX@;"=O<'II
M;VYE("TM96YA8FQE+69T<"X`075T:%]I;6%P.B`@17-T96YS:6]N92!)34%0
M(')I8VAI97-T82!N;VX@=')O=F%T82X`075T:%]K<F(U.B!%<W1E;G-I;VYE
M(&MR8C4@<FEC:&EE<W1A(&YO;B!T<F]V871A+@!!=71H7VQD87`Z(&PG86=G
M:75N=&$@9&D@=71E;G1I(&YO;B#H('-U<'!O<G1A=&$@<&5R($%C=&EV92!$
M:7)E8W1O<GD`075T:%]L9&%P.B!L82!C86YC96QL87II;VYE(&1I('5T96YT
M:2!N;VX@Z"!S=7!P;W)T871A('!E<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?
M;&1A<#H@17-T96YS:6]N92!,1$%0(')I8VAI97-T82!N;VX@=')O=F%T82X`
M075T:%]L9&%P.B!);7!O<W-I8FEL92!A9V=I=6YG97)E(&PG=71E;G1E("5S
M+B!1=65S=&$@Z"!L82!R:7-P;W-T82!D96P@<V5R=F5R.@!!=71H7VQD87`Z
M($EM<&]S<VEB:6QE(&-A;F-E;&QA<F4@;"=U=&5N=&4@)7,`075T:%]L9&%P
M.B!);7!O<W-I8FEL92!A9V=I;W)N87)E(&PG=71E;G1E("5S`$%U=&A?;&1A
M<#H@;"=A9V=I;W)N86UE;G1O(&1E9VQI('5T96YT:2!N;VX@Z"!S=7!P;W)T
M871O('!E<B!!8W1I=F4@1&ER96-T;W)Y+@!!=71H7VUC86PZ(&5S=&5N<VEO
M;F4@34-!3"!R:6-H:65S=&$@;F]N('1R;W9A=&$N`$%U=&A?<VUB875T:#H@
M97-T96YS:6]N92!S;6)A=71H(')I8VAI97-T82!N;VX@=')O=F%T82X`3"=A
M=71E;G1I8V%Z:6]N92!A;"!S97)V97(@24U!4"#H(&9A;&QI=&$N`$%U=&5N
M=&EC87II;VYE(&9A;&QI=&$`075T96YT:6-A>FEO;F4@9F%L;&ET82X@)7,`
M075T96YT:6-A>FEO;F4@<FEF:75T871A(&1A;"!S97)V97(@4D%$2553+@!!
M=71E;G1I8V%Z:6]N92!A;"!S97)V97(@1E10(&9A;&QI=&$N`$%U=&5N=&EC
M87II;VYE(&%L('-E<G9E<B!334(@9F%L;&ET82X`0V%M<&D@9&ES<&]N:6)I
M;&DZ`%-F;VYD;P!#;VQO<F4@<V9O;F1O`%!A<W-W;W)D(&ME<F)E<F]S(&YO
M;B!V86QI9&$N`%5T96YT92!K97)B97)O<R!N;VX@=F%L:61O+@!$:7)E8W1O
M<GD@9W)A9FEC82!D:2!B87-E("(E<R(@;F]N('1R;W9A=&$N`$-O;7!L96%N
M;F\`0FQO8V-O("(E<R(@9&5L;"=A<'!L:6-A>FEO;F4@(B5S(B!N;VX@=')O
M=F%T;RX`26UP;W-T87II;VYI($)L;V-C;P!4:7!O($)L;V-C;P!'<F%S<V5T
M=&\`4V5G;F%L:6)R:0!";W)D;P!3<&5S<V]R92!D96P@8F]R9&\Z`$)O<F1I
M`$)O<VYI82!E($AE<GIE9V]V:6YA`$5N=')A;6)E`$)A<W-O`$)R87-I;&4`
M16QE;F-O('!U;G1A=&\`0TU3`$-20P!0=6YT:2!$:7-T<FEB=7II;VYE($-2
M3`!0<F]P<FEE=.`@0U]E;&QE+BXN`$QA(&-A8VAE(&EN:7II86QE(&YO;B#H
M('-T871A(&-O;7!L971A=&$N`$-A;&5N9&%R:6\`0V%L;6\`0V%M8F]G:6$`
M26UP;W-S:6)I;&4@8V]P:6%R92!F:6QE*',I("T@;&$@<V]R9V5N=&4@92!L
M82!D97-T:6YA>FEO;F4@<V]N;R!U9W5A;&DN`$EM<&]S<VEB:6QE('-P;W-T
M87)E(&EL(&9I;&4H<RD@+2!L82!D97-T:6YA>FEO;F4@Z"!A;&PG:6YT97)N
M;R!D96QL82!S;W)G96YT92X`26UP;W-S:6)I;&4@<F5I;7!O<W1A<F4@;&$@
M<&%S<W=O<F0@875T;VUA=&EC86UE;G1E+"!C;VYT871T82!L)V%M;6EN:7-T
M<F%T;W)E+@!);7!O<W-I8FEL92!S8VEV97)E(&YE;"!F:6QE("(E<R(`26UP
M;W-S:6)I;&4@9V5S=&ER92!S97-S:6]N:2!E<W1E<FYE+@!);7!O<W-I8FEL
M92!C;VQL96=A<G-I(&%L('-E<G9E<B!)34%0.B`E<P!);7!O<W-I8FEL92!A
M<')I<F4@:6P@9FEL92`B)7,B+@!#86YC96QL80!#86YC96QL82!I;"!297!O
M<G0@<')O8FQE;6$`26UP;W-S:6)I;&4@96QI;6EN87)E(&EL(&9I;&4@(B5S
M(BX`26UP;W-S:6)I;&4@=')O=F%R92!U;F$@9&ER96-T;W)Y('1E;7!O<F%N
M96$N`$EM<&]S<VEB:6QE('!R;V-E9&5R92!S96YZ82!I;"!P87)A;65T<F\@
M)W1A<F=E=$9I;&4G+@!);7!O<W-I8FEL92!R:6UU;W9E<F4@;&$@9&ER96-T
M;W)Y("`B)7,B+@!);7!O<W-I8FEL92!R:6UU;W9E<F4L(&5S:7-T;VYO("5D
M(&9I9VQI+@!);7!O<W-I8FEL92!R:6]R9&EN87)E+"!L)V5L96YC;R!F;W)N
M:71O(&YO;B!C;W)R:7-P;VYD92!C;VX@;"=E;&5N8V\@;65M;W)I>GIA=&\N
M`$EM<&]S<VEB:6QE(&EN<W1R861A<F4@:6P@;65S<V%G9VEO(&%L(&YU;65R
M;R!S<&5C:69I8V%T;RX`0V%R<FEE<F$`0V%T96=O<FEE(&4@171I8VAE='1E
M`$ES;VQE($-A>6UA;@!#96QL=6QA<F4`4')O<')I973@($-E;&QE`%)I96UP
M:6UE;G1O(&-E;&QE.@!0<F]P<FEE=.`@8V5L;&4`4W!A>FEO(&-E;&QE.@!#
M96QL=6QA<F4`0V5N=')O`$5U<F]P82!#971R86QE("A)4T\M.#@U.2TR*0!$
M971T86=L:2!D96P@0V5R=&EF:6-A=&\`4')O<')I971A<FEO(&1E;"!#97)T
M:69I8V%T;P!0;VQI=&EC:&4@9&5L($-E<G1I9FEC871O`$-A;6)I80!#86UB
M:6$@;&$@='5A(%!A<W-W;W)D`$-A;6)I82!I;"!N;VUE(&4@;"=I;F1I<FEZ
M>F\@8VAE(&QE('!E<G-O;F4@=F5D;VYO('%U86YD;R!L96=G;VYO(&4@<FES
M<&]N9&]N;R!A;&QE('1U92!E;6%I;"X`26P@8V%M8FEO(&1E;&QA('1U82!P
M87-S=V]R9"!N;VX@Z"!S=7!P;W)T871O(&-O;B!L82!C;VYF:6=U<F%Z:6]N
M92!C;W)R96YT92X@($-O;G1A='1A(&PG86UM:6YI<W1R871O<F4N`$-A<F)O
M;F4`0VAE8U]K($QI;FLN+BX`0VEL90!#:6YA`%-C96=L:2!L)V%P<&QI8V%Z
M:6]N93H`4V-E9VQI('5N82!P87-S=V]R9`!38V5G;&D@=6X@;F]M92!U=&5N
M=&4`4V-E9VQI(&-O;64@=FES=6%L:7IZ87)E(&QA(&1A=&$Z`%-C96=L:2!I
M;"!T:7!O(&1I('-T:6QE(&1E;&QA(&QI<W1A("AP97(@;&ES=&4@;W)D:6YA
M=&4I`$QA(&1E9FEN:7II;VYE(&1I(&-L87-S92!D:2`E<R!N;VX@Z"!S=&%T
M82!T<F]V871A+@!#:&EA<F\`06YN=6QL82!$;VUA;F1A`$5L:6UI;F$@;"=U
M=&5N=&4Z("5S`$5L:6UI;F$@=71E;G1E`$5L:6UI;F$@:6YF;W)M87II;VYI
M('5T96YT90!%;&EM:6YA<F4@1&]P;R``0VQI8VL@<&5R($-O;G1I;G5A<F4`
M0VAI=61I($9I;F5S=')A`$YU8FD`3G5B:2!P<F5S=&\`3G5V;VQO<V\`0VAI
M=61I(%-I9&5B87(`0VAI=61I(&D@8F]R9&D`0V]L;W)E`$UA<'!A($-O;&]R
M:0!396QE>FEO;F4@8V]L;W)I`$-O;&]N;F4Z`%1I=&]L;R!C;VQO;FYE`$-O
M;6EC:&4`0V]M86YD;P!,:6YE82!D:2!C;VUA;F1O`$-O;6UE;G1O`$YO;64@
M0V]M=6YE`$%Z:65N9&$`0V]M<'5T97)S`$-O;F1I>FEO;F4`0V]N9&EZ:6]N
M:0!$:69F97)E;GIE(&YE;&QA(&-O;F9I9W5R87II;VYE`$-O;F9I9W5R87II
M;VYE('!E<B!L82!S:6YC<F]N:7IZ87II;VYE(&-O;B!01$%S+"!3;6%R='!H
M;VYE<R!E($]U=&QO;VLN`$QA(&-O;F9I9W5R87II;VYE(.@@=F5C8VAI82X`
M0V]N9FEG=7)A("5S`$-O;F9E<FUA(&QA(%!A<W-W;W)D`$-O;&QE9V%M96YT
M;R!F86QL:71O+@!#;VQL96=A;65N=&\@9F%L;&ET;SH@`$-O;FYE<W-I;VYE
M(&%L(&ME>7-E<G9E<B!O=6)B;&EC;R!R:69I=71A=&$N`$-O;FYE<W-I;VYE
M(&%L(&ME>7-E<G9E<B!P=6)B;&EC;R!R:69I=71A=&$N($UO=&EV;SH@)7,@
M*"5S*0!#;VYN97-S:6]N92!A;"!S97)V97(@1E10(&9A;&QI=&$N`$-O;G1A
M='1I`$D@8V]N=&%T=&D@<V]N;R!S=&%T:2!A9V=I=6YT:2!C;VX@<W5C8V5S
M<V\@86QL82!T=6$@<G5B<FEC82X`5&EP;R!D:2!C;VYT96YU=&\@9&5L(&9I
M;&4@8V]M<')E<W-O.B``0V]N=&5N=71I(&1I("(E<R(`0V]N=&EN=6$`0V]P
M:6$`0V]P:6$@9F%L;&ET83H@)7,`0V]P:6$@<V5L97II;VYE`$YO;B!S:2!P
M=?(@8VEF<F%R92!I;B!01U`@:6P@;65S<V%G9VEO`$YO;B!S:2!P=?(@9FER
M;6%R92!I;B!01U`@:6P@;65S<V%G9VEO`$YO;B!S:2!P=?(@8W)I9G)A<F4@
M:6X@4R]-24U%(&EL(&UE<W-A9V=I;P!.;VX@<VD@<'7R(&9I<FUA<F4@:6X@
M4R]-24U%(&EL(&UE<W-A9V=I;P!.;VX@<VD@<'7R(&%G9VEU;F=E<F4@:6P@
M8V]N=&%T=&\N("5S`$YO;B!S:2!P=?(@:6YT97)R;V=A<F4@:6P@<V5R=F5R
M($Q$05`N`$YO;B!S:2!P=?(@=F5R:69I8V%R92!L)V5Q=6EL:6)R:6\N("5S
M`$EM<&]S<VEB:6QE(&-O;&QE9V%R<VD@86P@<V5R=F5R($Q$05`N`$EM<&]S
M<VEB:6QE(&-O;&QE9V%R<VD@86P@<V5R=F5R("(E<R(@=7-A;F1O($944#H@
M)7,`26UP;W-S:6)I;&4@8W)E87)E('5N82!L:7-T82!D:2!D:7-T<FEB=7II
M;VYE+B`E<P!);7!O<W-I8FEL92!D96-I9G)A<F4@:6P@9&%T;R!I;B!F;W)M
M871O(%!'4#H@`$EM<&]S<VEB:6QE(&1E8VEF<F%R92!I;"!D871O(&EN(&9O
M<FUA=&\@4R]-24U%+@!);7!O<W-I8FEL92!E;&EM:6YA<F4@:6P@8V]N=&%T
M=&\N("5S`$EM<&]S<VEB:6QE(&5L:6UI;F%R92!L92!L:7-T82!D:2!D:7-T
M<FEB=7II;VYE+B`E<P!);7!O<VEB:6QE(&5L:6UI;F%R92!L;R!S8W)I<'0@
M9&D@86=G:6]R;F%M96YT;R!D96QL)VEM<&]S=&%Z:6]N92`B)7,B+@!);7!O
M<W-I8FEL92!D971E<FUI;F%R92!G;&D@:6YD:7)I>GII(&5M86EL(&1E:2!D
M97-T:6YA=&%R:2X`:4EM<&]S<VEB:6QE('-C87)I8V%R92!I;B!M;V1O(&-O
M;7!L971O(&QA(')U8G)I8V$N`$EM<&]S<VEB:6QE('-C87)I8V%R92!I;B!M
M;V1O(&-O;7!L971O(&QA(&QI<W1A(&1I(&1I<W1R:6)U>FEO;F4N`$EM<&]S
M<VEB:6QE('-C87)I8V%R92!I;B!M;V1O(&-O;7!L971O(&QA(&QI<W1A(&1E
M;&QE(&QI<W1E(&1I(&1I<W1R:6)U>FEO;F4N`$EM<&]S<VEB:6QE(&-A<FEC
M87)E(&QA('-T<F%T96=I82`B)7,B+@!);7!O<W-I8FEL92!C<F5A<F4@;&$@
M9&ER96-T;W)Y("(E<R(N`$EM<&]S<VEB:6QE(&]T=&5N97)E(&QA(&-H:6%V
M92!P=6)B;&EC82!D86P@<V5R=F5R+@!);7!O<W-I8FEL92!A<')I<F4@(B5S
M(B!P97(@;&$@<FES8W)I='1U<F$N`$EM<&]S<VEB:6QE(&%P<FER92`E<RX`
M26UP;W-S:6)I;&4@87!R:7)E(&EL(&UO9'5L;R!-86EN=&5N86YC95]487-K
M("5S`$EM<&]S<VEB:6QE(&%P<FER92!L82!D:7)E8W1O<GD@(B5S(BX`26UP
M;W-S:6)I;&4@8V]N=&%T=&%R92!I;"!S97)V97(@3$1!4"X`26UP;W-S:6)I
M;&4@;&5G9V5R92`E<RX`26UP;W-S:6)I;&4@87IZ97)A<F4@;&$@<&%S<W=O
M<F0@<&5R(&PG=71E;G1E(')I8VAI97-T;RX@06QC=6YI(&\@='5T=&D@:2!D
M971T86=L:2!N;VX@<V]N;R!C;W)R971T:2X@4FEP<F]V82!A;F-O<F$@;R!C
M;VYT871T82!L)V%M;6EN:7-T<F%T;W)E('-E(&YE8V5S<VET:2!D:2!U;'1E
M<FEO<F4@86EU=&\N`$EM<&]S<VEB:6QE(')E8W5P97)A<F4@04-,`$EM<&]S
M<VEB:6QE(')E8W5P97)A<F4@;&$@<G5B<FEC82X@)7,`26UP;W-S:6)I;&4@
M<F5C=7!E<F%R92!L82!L:7-T82!D:2!D:7-T<FEB=7II;VYE+B`E<P!);7!O
M<W-I8FEL92!R96-U<&5R87)E(&QE(&QI<W1E(&1I(&1I<W1R:6)U>FEO;F4N
M("5S`$EM<&]S<VEB:6QE(')E8W5P97)A<F4@;&4@<&]S<VEB:6QI=.`@9&5L
M('-E<G9E<@!);7!O<W-I8FEL92!I;G9E<G1I<F4@;&$@8V]N9FEG=7)A>FEO
M;F4N`$EM<&]S<VEB:6QE(&-A;F-E;&QA<F4@;&$@9&ER96-T;W)Y("(E<R(N
M`$EM<&]S<VEB:6QE('-A;'9A<F4@;&$@8V]N9FEG=7)A>FEO;F4@9&D@)7,N
M`$EM<&]S<VEB:6QE('-A;'9A<F4@=6YA(&-O<&EA(&1E;&QA(&-O;F9I9W5R
M87II;VYE+@!);7!O<W-I8FEL92!S86QV87)E('5N82!C;W!I82!D96QL82!C
M;VYF:6=U<F%Z:6]N93H@)7,`26UP;W-S:6)I;&4@<V%L=F%R92!L;R!S8W)I
M<'0@9&D@86=G:6]R;F%M96YT;R!D96QL92!I;7!O<W1A>FEO;FD@<W4Z("(E
M<R(N`$EM<&]S<VEB:6QE('-A;'9A<F4@:6P@9FEL92!D:2!S86QV871A9V=I
M;R!D96QL82!C;VYF:6=U<F%Z:6]N92!D:2`E<RX`26UP;W-S:6)I;&4@<V%L
M=F%R92!I;"!F:6QE(&1I(&-O;F9I9W5R87II;VYE(&1I("5S+B!0=6]I('5S
M87)E(&YA(&1E;&QE(&]P>FEO;FD@<&5R('-A;'9A<F4@:6P@8V]D:6-E('-U
M("5S(&\@8V]P:6%R92!M86YU86QM96YT92!I;"!C;V1I8V4@<V]T=&\@<W4@
M)7,N`$EM<&]S<VEB:6QE(&9A<F4@=6YA(')U8V5R8V$@;F5L('-E<G9E<B!,
M1$%0+@!);7!O<W-I8FEL92!A9V=I;W)N87)E(&EL(&-O;G1A='1O+B`E<P!)
M;7!O<W-I8FEL92!A9V=I;W)N87)E(&QA(&QI<W1A(&1I(&1I<W1R:6)U>FEO
M;F4N("5S`$EM<&]S<VEB:6QE('-C<FEV97)E(&QA(&-O;F9I9W5R87II;VYE
M('!E<B`B)7,B.B`E<P!);7!O<W-I8FEL92!T<F]V87)E(&QA(%-I9&5B87(@
M9&D@36]Z:6QL82X@07-S:6-U<F%T:2!C:&4@<VEA(&%P97)T82X`26UP;W-S
M:6)I;&4@9&%R92!A;&PG=71E;G1E("(E<R(@:2!S96=U96YT:2!D:7)I='1I
M('!E<B!L82!C87)T96QL82`B)7,B.B`E<P!497-T;R!C;VYT871O`$YA>FEO
M;F4`0V]R<VD`0W)E80!#<F5A('5N(&QI;FL`0W)E82!U;F\@;G5O=F\`0W)E
M87)E('-O='1O(&-A<G1E;&QE`$-R96%T;W)E(&1I('!E<FUE<W-I`$YU;65R
M;R!C87)T82!D:2!C<F5D:71O`$-O<G)E;G1E(#0@1F%S:0!397-S:6]N:2!C
M;W)R96YT:0!496UP;R!!='1U86QE`$QA(%523"!A='1U86QE(.@`571E;G1I
M($%T='5A;&D`5&5M<&\@071T=6%L90!#;VYD:7II;VYE(&-O<G)E;G1E.B``
M4W1I;&4@8V]R<F5N=&4`4&5R<V]N86QI>GIA(&QE(&]P97)A>FEO;FD@9&$@
M97-E9W5I<F4@86QL)V%V=FEO(&1I("5S`%1A9VQI80!486=L:6$@;&$@<V5L
M97II;VYE`$-I<')O`$=I;W)N86QM96YT90!$871A`$1A=&$@4FEC979U=&$`
M4V5L97II;VYA(&QA(&1A=&$`1VEO<FYO`$5?;&EM:6YA($-O;&]N;F$`1&EC
M96UB<F4`3G5M97)I(&1E8VEM86QI`$1I;6EN=6ES8VD@;&$@<FEE;G1R86YZ
M80!#;VQO<F4@<W1A;F1A<F0`261E;G1I=.`@9&D@9&5F875L=`!3:&5L;"!D
M:2!D969A=6QT`$1E9FEN:7II;VYI`$5L:6UI;F$`16QI;6EN82!#96QL80!%
M;&EM:6YA($=R=7!P;P!%;&EM:6YA($QO9P!%;&EM:6YA(%!E<FUE<W-O`$5L
M:6UI;F%R92!E('-V=6]T87)E(&D@;65S86=G:0!%;&EM:6YA(&-E;&QA`$5L
M:6UI;F$@8V]L;VYN80!%;&EM:6YA(&QA(&UA<V-H97)A(&%L=&5R;F%T:79A
M(&5S:7-T96YT90!%;&EM:6YA(&D@;65S<V%G9VD`16QI;6EN82!I('!E<FUE
M<W-I('!E<B`B)7,B`$5L:6UI;F$@:2!P97)M97-S:2!P97(@(B5S(B!E(&]G
M;FD@<V]T=&\M<&5R;65S<V\_`$5L:6UI;F$@<FEG80!%;&EM:6YA(&PG:61E
M;G1I=.`@<V5L97II;VYA=&$`16QI;6EN82!L92!S;W1T;R!C87)T96QL90!%
M;&EM:6YA(&QA(&-O;&]N;F$@8V]R<F5N=&4`16QI;6EN82!L82!R:6=A(&-O
M<G)E;G1E`$5L:6UI;F$@;&\@<V-R:7!T(&1I(&%G9VEO<FYA;65N=&\@9&5L
M;&4@:6UP;W-T87II;VYI(&1I("(E<R(N`%1E;7!O(&0G:6YV:6\`1&%N:6UA
M<F-A`$1E<V-R:79I(&EL('!R;V)L96UA`$1E<V-R:7II;VYE`$1E='1A9VQI
M("AA;F-H92!N96P@9FEL92!D:2!L;V<@9&D@2&]R9&4I.@!)(&1E='1A9VQI
M('-O;F\@<W1A=&D@<V-R:71T:2!N96P@9FEL92!D:2!L;V<@<&5R(&PG86UM
M:6YI<W1R871O<F4N`%-V:6QU<'!O`%!U;G1O(&1I(')U9VEA9&$`4'5N=&\@
M9&D@<G5G:6%D82!P97(@;"=U;'1I;6$@;W)A.B``4'5N=&\@9&D@<G5G:6%D
M83H@`$1I<F5Z:6]N92!D82!S:6YI<W1R82!A(&1E<W1R80!$:7)E>FEO;F4@
M9&$@9&5S=')A(&$@<VEN:7-T<F$`5FES=6%L:7IZ82!I;"!T96UP;R!N96P@
M9F]R;6%T;R`R-"!O<F4_`$]P>FEO;FD@9&D@=FES=6%L:7IZ87II;VYE`%9I
M<W5A;&EZ>F$@<')E=FES:6]N92!D971T86=L:6%T80!&;W)M871O(&1I('9I
M<W5A;&EZ>F%Z:6]N90!.;W1I9FEC82!D:2!D:7-P;W-I>FEO;F4`3F]N(&5L
M:6UI;F%R90!.;VX@86-C961E<F4@9&ER971T86UE;G1E(&UA:6YT96YA;F-E
M+G!H<`!,87!R:6UA(')I9V$@8V]N=&EE;F4@:6P@8V%M<&\@9&5I(&YO;6D_
M(%-E('-I+"!S96QE>FEO;F$@<75E<W1A(&-A<V5L;&$Z`$YO;B!H86D@=6XG
M=71E;GIA/R!I<V-R:79I=&DN`%-C87)I8V$`4V-A<FEC82`E<P!,82!C;VYF
M:6=U<F%Z:6]N92!G96YE<F%T82#H('-T871A('-C87)I8V%T82!C;VUE('-C
M<FEP="!02%`N`$1R;V=H90!0=6)B;&EC80!6:7-U86QI>GIA(&)L;V-C;P!6
M:7-U86QI>GIA($=R=7!P;P!6:7-U86QI>GIA(%!E<FUE<W-O`%9I<W5A;&EZ
M>F$@4&5R;65S<VD`5FES=6%L:7IZ82!097)M97-S:2!P97(@)7,`5FES=6%L
M:7IZ82!L92!O<'II;VYI('!E<CH`5FES=6%L:7IZ82!I('!E<FUE<VD@<&5R
M("(E<R(`5FES=6%L:7IZ82!I('!E<FUE<W-I('!E<B`E<P!%9VET=&\`16QE
M;65N=&\N+BX`26YD:7)I>GIO($5M86EL`$PG:6YD:7)I>GIO($5M86EL(&1E
M=F4@8V]R<FES<&]N9&5R92X`16UA:6P@8V]N(&-O;F9E<FUA`$UE<W-A9V=I
M;R!V=6]T;RX`4FES=6QT871O('9U;W1O+@!2:6-E<F-A(&1E:2!T97)M:6YI
M('9U;W1A`$%B:6QI=&$@;"=I;G-E<FEM96YT;R!D:2!I;6UA9VEN:2!N96P@
M=&5S=&\@9&%L;&$@1V%L;&5R:6$@9&5L;&4@1F]T;V=R869I93\`06)I;&ET
M87)E(&EL(&UE;G4@9&D@8V]N=&5S=&\@8VQI8V-A;F1O(&EL('1A<W1O(&1E
M<W1R;R!D96P@;6]U<V4_`$9I;F4@86YN;P!);F=R861I<V-I(&PG961I=&]R
M`$EN<V5R:7-C:2!U;F$@9&]M86YD82!S:6-U<F$@8VAE('1I('9E<G+@(&-H
M:65S=&$@<V4@879R86D@;F5C97-S:73@(&1I(&%Z>F5R87)E(&QA('1U82!P
M87-S=V]R9"P@97,@)W%U86PGZ"!I;"!N;VUE(&1E;"!T=6\@8W5C8VEO;&\_
M)SH`26YS97)I<V-I(&PG55),(&1E;&PG:6UM86=I;F4@<75I`$EN<V5R:7-C
M:2!L92!L971T97)E('-O='1O(')I<&]R=&%T93H`17)R;W)E`$5R<F]R92!C
M<F5A;F1O(&EL(&)L;V-C;SH@)7,`17)R;W)E(&5L:6UI;F%N9&\@;"=A;F-O
M<F$@9&D@<VEN8W)O;FEA.B`E<P!%<G)O<F4@96QI;6EN86YD;R!I;"!L;V<@
M9&D@<VEN8W)O;FEA.B`E<P!%<G)O<F4@;W1T96YE;F1O(&EL(&-O;G1E;G5T
M;SH@)7,`17)R;W)E(&%G9VEO<FYA;F1O(&QA('!A<W-W;W)D.B`E<P!%<G)O
M<F4@8V]N(&EL(&UE<W-A9V=I;R!E;6%I;"X`17)R;W)E('-C<FEV96YD;R`B
M)7,B+@!/9VYI(#$U(&UI;G5T:0!/9VYI(#(@;6EN=71I`$]G;FD@,S`@<V5C
M;VYD:0!/9VYI(#4@;6EN=71I`$%D(&]G;FD@86-C97-S;P!/9VYI(&UE>GHG
M;W)A`$]G;FD@;6EN=71O`%9A;&]R:2!D)V5S96UP:6\Z`$5S96=U:0!%<W!A
M;F1I`$5S<&%N9&D@4VED96)A<@!0<F5V:7-T;R`G*2<`:5!A<F]L82!P<F5V
M:7-T82!O('1E<FUI;F4@8VET871O(&1I(')I8V5R8V$`1&%T82!D:2!S8V%D
M96YZ80!%<W!O;F5N=&4`0V]L;W)E($9'`$%G9VEO<FYA;65N=&\@1E10(&1E
M;&QE(&EM<&]S=&%Z:6]N:0!496YT871I=F\@9F%L;&ET;R!N96P@<F5C=7!E
M<F\@9&5L;&4@<')E9F5R96YZ92X`0V]L;&5G86UE;G1O(&%L('-E<G9E<B!,
M1$%0(&9A;&QI=&\N`$-O;&QE9V%M96YT;R!A;"!S97)V97(@4TU"(&9A;&QI
M=&\N`$YO;B#H(')I=7-C:71O(&$@8V]P:6%R92!D82`B)7,B+@!.;VX@Z"!R
M:75S8VET;R!A(&-O<&EA<F4@82`B)7,B+@!.;VX@Z"!R:75S8VET;R!A(&-R
M96%R92!U;F$@;G5O=F$@8V]N;F5S<VEO;F4@4T%33"X`3F]N(.@@<FEU<V-I
M=&\@82!S<&]S=&%R92!A("(E<R(N`$YO;B#H(')I=7-C:71O(&$@<F5C=7!E
M<F%R93H@)7,`1VEU<W1O`$5R<F]R92!&871A;&4Z`$9E8F)R86EO`%-I;6EL
M92!A`%-I;6EL92!A.@!#;VYT96=G:6\@9FEL93H@)7,@9FEL90!#;VYT96=G
M:6\@9FEL93H@)7,@9FEL97,`1V5S=&EO;F4@1FEL90!.;VUE($9I;&4`4V5L
M97II;VYE(&9I;&4`0V%R:6-A($9I;&4`0V%R:6-A;65N=&\@9FEL92!N;VX@
M<W5P<&]R=&%T;P!&:6QT<FD`1FEN;&%N9&EA`%!R:6UO($UE>GIO`%!R:6UO
M(%%U87)T;P!287!P;W)T;R!F:7-S;P!.96)B:6$`3&$@0V%R=&5L;&$@)7,@
M;F]N(&5S:7-T90!#;VQO<F4@9&5L;&$@9F]N=&4`0VEB;P!097(@8G)O=W-E
M<B!C:&4@;F]N('-U<'!O<G1A;F\@;&4@:6UM86=I;FD`4')E=FES:6]N92`H
M5$%&*0!(86D@9&EM96YT:6-A=&\@;&$@<&%S<W=O<F0_`$EN;VQT<FD`5F4`
M1G)A;F-I80!$80!$82!I;"``1&5S8W)I>FEO;F4@0V]M<&QE=&$`3&YA(%!I
M96YA`$YO;64@0V]M<&QE=&\`1V%L;&5R:6$@9&%L;&$@<75A;&4@<')E;F1E
M<F4@;&4@:6UM86=I;FD`1V%L;&5R:6$Z`$=E;F5R82`E<R!#;VYF:6=U<F%Z
M:6]N90!#;V1I8V4@1V5N97)A=&\`1V5R;6%N:6$`1VEB:6QT97)R80!.;VUE
M($1A=&\`3W!Z:6]N:2!';&]B86QI`%9A:0!-87!P92!';V]G;&4`4V-A;&4@
M9&D@9W)I9VD`1W)E8VEA`$%M;6EN:7-T<F%Z:6]N92!'<G5P<&D`22!N;VUI
M(&1E;"!G<G5P<&\@;F]N(&1E=F]N;R!E<W-E<G)E('9U;W1I`$=R;W5P7VQD
M87`Z($EM<&]S<VEB:6QE(&%G9VEU;F=E<F4@:6P@9W)U<'!O("5S+B!1=65S
M=&$@Z"!L82!R:7-P;W-T82!D96P@<V5R=F5R.B``1W)O=7!?;&1A<#H@26UP
M;W-S:61I;&4@96QI;6EN87)E(&EL(&=R=7!P;R`E<P!'<F]U<%]L9&%P.B!)
M;7!O<W-I8FEL92!A9V=I;W)N87)E(&EL(&=R=7!P;R`E<P!'<G5P<&D`4&5R
M;65S<VD@9&5G;&D@;W-P:71I`$QI8G)O(&1E9VQI(&]S<&ET:0!);G1E<W1A
M>FEO;F4`26YT97-T87II;VYI`$%L=&5Z>F$`06EU=&\`06EU=&\@=7-A;F1O
M(&PG961I=&]R`$%I=71A;G1E`$5M:7-F97)O`%%U97-T;R#H(&PG:6YI>FEO
M(&1E;"!F:6QE.@!!;'1O`$AO7W)D90!386YT82!3961E("A#:71T82<@9&5L
M(%9A=&EC86YO*0!(;W)D90!);F1I<FEZ>F\@9&D@8V%S80!$:7)E8W1O<GD@
M9&D@8V%S80!496QE9F]N;R!D:2!C87-A`%)E9V]L82!O<FEZ>F]N=&%L90!2
M:65M<&EM96YT;R!O<FEZ>F]N=&%L90!/<FEZ>F]N=&%L93H`0V]M92!S96D@
M87)R:79A=&\@<75I/R`H4V5I('!R96=A=&\@9&D@9F%R92!U;B!R87!P;W)T
M;R$I`%%U86YT92!C;VQO;FYE('9U;VD@=6YI<F4_`%%U86YT:2!C86UP:2`H
M8V]L;VYN92D@8VD@<V]N;R`_`%%U86YT92!R:6=H92!V=6]I('5N:7)E/P!5
M;6ED:73@`%5M:61I=.`Z(`!5;F=H97)I80!#<F5A>FEO;F4@9&5L;&$@8V%S
M96QL82!)34%0(&9A;&QI=&$Z("5S`$-A;F-E;&QA>FEO;F4@9&5L;&$@8V%S
M96QL82!)34%0(&9A;&QI=&$Z("5S`$-R96%Z:6]N92!D96QL82!Q=6]T82!D
M96QL82!C87-E;&QA($E-05`@9F%L;&ET83H@)7,`26YD:7)I>GIO($E0`$EN
M9&ER:7IZ;R!)4"!N;VX@9&ES<&]N:6)I;&4N`$PG:6YD:7)I>GIO($E0(&YO
M;B#H(&%L;"=I;G1E<FYO(&1E;"!B;&]C8V\@0TE$4B!C;VYS96YT:71O+@!)
M7VYS97)I<V-I(&QA(%))9V$@<')I;6$`27-L86YD80!3;VQO($EC;VYE`$EC
M;VYE('!E<B`E<P!)8V]N92!C;VX@=&5S=&\`3F]M92!D96QL)TED96YT:73@
M`%-E(&YO;B#H('-T871O('9I<W5A;&EZ>F%T;R!C;W)R971T86UE;G1E+"`E
M<R!A<')I<F4@:6X@=6YA(&YU;W9A(&9I;F5S=')A+@!392!N;VX@=F5D:2!N
M97-S=6YA(&EC;VYA('5S86YD;R!);G1E<FYE="!%>'!L;W)E<BP@<&]T<F5S
M=&D@9&]V97(@<V5L97II;VYA<F4@<75E<W1A(&-A<V5L;&$@<&5R(&%N;G5L
M;&%R92!L82!T<F%S<&%R96YZ82!D96QL92!I;6UA9VEN:2!03D<N`%-E('9E
M9&D@<75E<W1O(&UE<W-A9V=I;R!M82!N;VX@;"=I;6UA9VEN92P@;"=I;6%G
M:6YE(&-H92!V=6]I(&-A<FEC87)E(&YO;B!P=?(@97-S97)E('9I<W5A;&EZ
M>F%T82!D86P@='5O(&)R;W=S97(N`%!R92U6:7-U86QI>GIA>FEO;F4@9&5L
M;"=);6UA9VEN93H`55),($EM;6%G:6YE`%523"!);6UA9VEN93H`26UM86=I
M;F4@9&%L;&$@9V%L;&5R:6$`26UM86=I;F4@9&%L;&$@9V%L;&5R:6$Z`$-A
M<FEC86UE;G1O($EM;6%G:6YE`$EM;6%G:6YI`$EM<&]R=&$L(%!A<W-O("5D
M`$-A;7!I(&EM<&]R=&%T:3H@)7,`0V%M<&D@:6UP;W)T871I.@!);E]S97)I
M<V-I(')I9V$@9&]P;P!#;V1I8V4@9&D@87II;VYE(&5R<F%T;R!D871O+@!.
M;VUE('5T96YT92!E+V\@<&%S<W=O<F0@;F]N(&-O<G)E='1O+@!.;VUE('5T
M96YT92!O(&EN9&ER:7IZ;R!A;'1E<FYA=&EV;R!N;VX@=F%L:61O+B!2:7!R
M;W9A(&%N8V]R82!O(&-O;G1A='1A(&PG86UM:6YI<W1R871O<F4@<V4@;F5C
M97-S:71I(&1I('5L=&5R:6]R92!A:75T;RX`075M96YT82!L82!R:65N=')A
M;GIA`%5T96YT:2!);F1I=FED=6%L:0!);F9O<FUA>FEO;F4`26YF;W)M87II
M;VYE(&YO;B!P:?D@9&ES<&]N:6)I;&4N`$EN<V5R:7-C:2!#7V]L;VYN82!$
M;W!O`$EN<V5R:7-C:2!);6UA9VEN90!);G-E<FES8VD@5&%B96QL80!);G-E
M<FES8VD@;&EN:R!W96(`26YS97)I<V-I(%]#;VQO;FYA(%!R:6UA`$EN<V5R
M:7-C:2!U;F$@;G5O=F$@8V]L;VYN82!D;W!O('%U96QL82!C;W)R96YT90!)
M;G-E<FES8VD@=6YA(&YU;W9A(&-O;&]N;F$@<')I;6$@9&D@<75E;&QA(&-O
M<G)E;G1E`$EN<V5R:7-C:2!U;F$@;G5O=F$@<FEG82!D;W!O('%U96QL82!C
M;W)R96YT90!);G-E<FES8VD@=6YA(&YU;W9A(')I9V$@<')I;6$@9&D@<75E
M;&QA(&-O<G)E;G1E`$EN<V5R:7-C:2!U;B!P87)A9W)A9F\@9&]P;R!I;"!N
M;V1O(&-O<G)E;G1E`$EN<V5R:7-C:2!U;B!P87)A9W)A9F\@<')I;6$@9&5L
M(&YO9&\@8V]R<F5N=&4`26YS97)I<V-I('5N82!M87-C:&5R82!A;'1E<FYA
M=&EV80!);G-E<FES8VD@=6X@:6YD:7)I>GIO(&5M86EL(&%L('%U86QE('!O
M=')A:2!R:6-E=F5R92!L82!N=6]V82!P87-S=V]R9#H`26YS97)I<V-I('5N
M82!C96QL82!D;W!O`$EN<V5R:7-C:2!U;F$@8V5L;&$@<')I;6$`26YS97)I
M<V-I('5N82!C;VQO;FYA(&1O<&\`26YS97)I<V-I('5N82!C;VQO;FYA('!R
M:6UA`$EN<V5R:7)E(&UE<W-A9V=I`$EN<V5R:7-C:2!U;B!P87)A9W)A9F\@
M9&]P;P!);G-E<FES8VD@=6X@<&%R86=R869O('!R:6UA`$EN<V5R:7-C:2!U
M;F$@<FEG82!D;W!O`$EN<V5R:7-C:2!U;F$@<FEG82!P<FEM80!);G-E<FES
M8VD@;&$@<FES<&]S=&$@<FEC:&EE<W1A(&%L;&$@9&]M86YD82!D:2!S:6-U
M<F5Z>F$Z`$EN<V5R:7-C:2]-3V1I9FEC82!L)VEM;6%G:6YE`$EN<V5R:7-C
M:2]-3V1I9FEC82!I;"!L:6YK`$-R961I=&D@:6YS=69F:6-I96YT:2!P97(@
M<W!E9&ER92!A;&QA(&QI<W1A(&1I(&1I<W1R:6)U>FEO;F4N`$-R961I=&D@
M:6YS=69F:6-I96YT:2X`26YT97)O`$QI<W1A(&EN=&5R80!51$@@;F]N('9A
M;&ED82`H57-E<B!$871A($AE861E<BDN`$1A=&$@6DE0(&YO;B!V86QI9&$`
M07!P;&EC87II;VYE(&YO;B!V86QI9&$N`$)A=&-H($E$(&YO;B!V86QI9&\`
M:4PG:6YF;W)M87II;VYE('-O='1O;65S<V$@;F]N(.@@=F%L:61A+@!,)VEN
M9&ER:7IZ;R!D:2!D9&5S=&EN87II;VYE(&YO;B#H('9A;&ED;RX`26P@9F]R
M;6%T;R!D96P@9FEL92!N;VX@Z"!V86QI9&\`3&$@8VAI879E(&1E;&QA(&QI
M8V5N>F$@;F]N(.@@=F%L:61A+@!);"!L;V=O(&9O<FYI=&\@;F]N(.@@=F%L
M:61O+@!M<V=?='EP92!N;VX@=F%L:61O+@!A<&E?:60@;F]N('9A;&ED;R!O
M(&UA;F-A;G1E+@!087)A;65T<F\@;F]N('9A;&ED;R!O(&UA;F-A;G1E+@!0
M97)M97-S;R!D96P@9V5N:71O<F4@;F]N('9A;&ED;RX`:60@9&5L('!A<G1N
M97(@;F]N('9A;&ED;RX`0V]D:6-E('!R;V1O='1O(&YO;B!V86QI9&\N`%!R
M;W1O8V]L;&\@;F]N('9A;&ED;RX`1&5S=&EN871A<FEO(&YO;B!V86QI9&\Z
M("(E<R(`3V=G971T;R!C;VYD:79I<V\@;F]N('9A;&ED;P!);F1I<FEZ>F\@
M<V]R9V5N=&4@;F]N('9A;&ED;RX`26YV96YT87)I;P!);G9E<G1I(&QA('-E
M;&5Z:6]N90!%;6ET=&5N=&4`271A;&EA`$=E;FYA:6\`1VEA<'!O;F4`3'5G
M;&EO`$=I=6=N;P!':75S=&EF:6-A`$=I=7-T:69I8V$@86P@8V5N=')O`$=I
M=7-T:69I8V$@='5T=&\`1VEU<W1I9FEC82!A('-I;FES=')A`$=I=7-T:69I
M8V$@82!D97-T<F$`36%N=&5N97)E(&PG;W)I9VEN86QE/P!);"!S97)V97(@
M2V5R8F5R;W,@:&$@<FEF:75T871O(&PG875T96YT:6-A>FEO;F4N`$-R96%Z
M:6]N92!C:&EA=F4`26UP<F]N=&$@9&EG:71A;&4@9&5L;&$@8VAI879E`$QU
M;F=H97IZ82!D96QL82!C:&EA=F4`5&EP;R!D96QL82!C:&EA=F4`57-O(&1E
M;&QA(&-H:6%V90!,82!C:&EA=F4@Z"!G:>`@<')E<V5N=&4@<W5L(&ME>7-E
M<G9E<B!P=6)B;&EC;RX`0F%M:6)I;FD`1&E?<W!O<VEZ:6]N90!,:6YG=6%G
M9VEO`%5L=&EM;R!M97IZ;P!5;'1I;6$@<&]S<VEB:6QI=.`@<&5R(&EL(&-A
M;6)I;R!D96QL82!P87-S=V]R9`!5;'1I;6\@<75A<G1O`%5L=&EM;R!A9V=I
M;W)N86UE;G1O.@!5;'1I;6$@8V]N;F5S<VEO;F4Z("5S`%5L=&EM82!C;VYN
M;F5S<VEO;F4Z("5S(&1A("5S`%5L=&EM82!C;VYN97-S:6]N93H@36%I`$QE
M9V=E`$1I<W!O<VEZ:6]N90!,87-C:6%L;R!V=6]T;R!P97(@879E<FQO('-E
M;GIA(&)O<F1I`$QI8F%N;P!3:6YI<W1R80!);G1E<W1A>FEO;F4@9&D@<VEN
M:7-T<F$`5F%L;W)I(&1I('-I;FES=')A`$QI=F5L;&\`4&EO9V=I82!L96=G
M97)A`$-O;&QE9V%M96YT;P!);"!C;VQL96=A;65N=&\@<'5N=&$@83H`0V]L
M;&5G82!L)VEN9&ER:7IZ;R!E;6%I;"!A;&QA('!A9VEN82!D:2!C;VUP;W-I
M>FEO;F4@<75A;F1O('9I96YE('9I<W5A;&EZ>F%T;P!#;VQL96=A;65N=&D`
M16QE;F-O("T@;"=U=&5N=&4@<'7R('9E9&5R92!L92!C87)T96QL90!%;&5N
M8V\@9&5I(&1A=&%B87-E`$5L96YC;R!D96D@<V]G9V5T=&D@9&5L;"=A:75T
M;P!%;&5N8V\@5&%B96QL90!!<F-H:79I;R!D96QL82!,:7-T80!!:75T;R!D
M96QL82!,:7-T80!)9&5N=&EF:6-A=&EV;R!D96QL82!,:7-T80!0<F]P<FEE
M=&%R:6\@9&5L;&$@;&ES=&$`27-C<FEZ:6]N92!A;&QA($QI<W1A`$%N;G5L
M;&$@;"=I<V-R:7II;VYE(&%L;&$@3&ES=&$`3"=E;&5N8V\@9&5L;&4@<V5S
M<VEO;F4@Z"!F86QL:71O.B`E<P!,)V5L96YC;R!D96=L:2!U=&5N=&D@Z"!F
M86QL:71O.B`E<P!,)V5L96YC;R!D96=L:2!U=&5N=&D@Z"!D:7-A8FEL:71A
M=&\N`$QE='1E<F%T=7)A`$-A<FEC86UE;G1O+BXN`$]R82!L;V-A;&4Z(`!,
M:6YG=6$@92!/<F$`3'5O9V\`16YT<F$`17-C:0!%;G1R80!/<&5R87II;VYI
M(&1I($%C8V5S<V\`3"=A8V-E<W-O(.@@9F%L;&ET;R!P97)C:.@@:6P@;F]M
M92!U=&5N=&4@;R!L82!P87-S=V]R9"!I;G-E<FET:2!N;VX@<V]N;R!C;W)R
M971T:2X`06-C97-S;R!F86QL:71O+@!497-T;R!L=6YG;P!!;6]R90!"87-S
M;P!,971T97)E(&=R96-H92!M:6YU<V-O;&4`3&5T=&5R92!L871I;F4@;6EN
M=7-C;VQE`$YU;65R:2!R;VUA;FD@;6EN=7-C;VQI`$QU<W-E;6)U<F=O`$U3
M+51.148@;"=A;&QE9V%T;R!N;VX@8V]N=&EE;F4@:6YF;W)M87II;VYI+@!-
M86=I8V\`4&]S=&$`26YD:7)I>GIO(&%M;6EN:7-T<F%T;W)E`$-R96$@8V]L
M;&5G86UE;E]T;RXN+@!'97-T:7-C:2!L)V5L96YC;R!D96QL92!C871E9V]R
M:64@971I8VAE='1A;F1O(&=L:2!A<G1I8V]L:2P@92!C;VX@:2!C;VQO<FD@
M87-S;V-I871I(&%L;&4@8V%T96=O<FEE+@!-87)Z;P!-87)G:6YE`$-O;G1R
M87-S96=N87)E(&-O;B!I(&9L86=S(%9I<W1O+TYO;E9I<W1O`$-O;G1R87-S
M96=N87)E(&-O;B!A;'1R:2!F;&%G<R`H97,Z($EM<&]R=&%N=&4O4FES<&]S
M=&\I`$-A;7!I(&-O<G)I<W!O;F1E;G1I`$-R961I=&\@;6%S<VEM;R!P97)M
M97-S;RX`16-C961U=&4@;&$@<&%R=&D@;6%S<VEM92!D96P@;65S<V%G9VEO
M+@!496UP;R!M87-S:6UO('5L=&EM92`R-"!O<F4Z(`!496UP;R!M87-S:6UO
M('5L=&EM92`V(&]R93H@`$YU;65R;R!M87-S:6UO(&1E;"!0;W)T82!";&]C
M:W,`3'5N9VAE>GIA(&UA<W-I;6$`36%G9VEO`$UE9&EC:6YA`$UE;6)R:0!5
M;FES8VD@;&4@8V5L;&4`365S<V%G9VEO`$EL(&UE<W-A9VEO(.@@<W1A=&\@
M=F5R:69I8V%T;R!C;W)R971T86UE;G1E+"!M82!I;"!F:7)M871A<FEO(&1E
M;"!C97)T:69I8V%T;R!N;VX@<'7R(&5S<V5R92!V97)I9FEC871O+@!-97-S
M86=G:6\@<V-A9'5T;RX`5&EP;R!M97-S86=G:6\`365T;V1O`$EL(&UE=&]D
M;R`@(B5S(B!N;VX@Z"!D969I;FET;P!-971O9&\@;F]N(&1E9FEN:71O+B!-
M971O9&\@8VAI86UA=&$Z("5S`$UE=')I8V$`365S<VEC;P!-97IZ;P!496UP
M;R!M:6YI;6\@=6QT:6UE(#(T(&]R93H@`%1E;7!O(&UI;FEM;R!U;'1I;64@
M-B!O<F4Z(`!);"!T96UP;R!D:2!D=7)A=&$@;6EN:6UO(&1E;&QA('!A<W=O
M<F0@;F]N(.@@<V-A9'5T;P!3<&5C8VAI;P!687)I;P!);"!P86-C:&5T=&\@
M4$5!4B!(5%107U)E<75E<W0@Z"!M86YC86YT92X`0V]N9FEG=7)A>FEO;F4@
M;6%N8V%N=&4N($1E=FD@9V5N97)A<FYE('5N82!N=6]V82!S92!V=6]I('5S
M87)E('%U97-T82!A<'!L:6-A>FEO;F4N`$E$(&1E;"!M97-S86=G:6\@;6%N
M8V%N=&4N`$EL('!A8V-H971T;R!014%2($UA:6P@<FEC:&EE<W1O(.@@;6%N
M8V%N=&4N`$E$(&1E;&QA('-E<W-I;VYE(&UA;F-A;G1E+@!,=0!-;V1E<F%T
M;P!$871A(&1E;&QA(&UO9&EF:6-A`$UO9&EF:6-A(%523`!-;V1U;&\`365S
M92!E(&%N;F\`365N<VEL;65N=&4`1F%S:2!L=6YA<FD`4V]N;R!S=&%T:2!T
M<F]V871I('!I^2!C86UP:2!N96QL82!L:6YE82`E9"!R:7-P971T;R!A('%U
M96QL:2!I<')E=FES=&D@)60N`%-P;W-T82!3;W1T;P!3<&]S=&$@82!3:6YI
M<W1R80!3<&]S=&$@82!$97-T<F$`4W!O<W1A(%-O<')A`%-P;W-T82!S;W1T
M;P!3<&]S=&$@<V]P<F$`4V5L97II;VYE(&UU;'1I<&QA`$UI;R!!8V-O=6YT
M`$EN9F]R;6%Z:6]N:2!D96P@36EO($%C8V]U;G0`36EO(%!O<G1A;&4`1&ES
M<&]S:7II;VYE(&1E;"!-:6\@4&]R=&%L90!.3RP@;F]N('-O;F\@9"=A8V-O
M<F1O`$YO;64`4F5T90!-86D`3G5O=F$@0V%T96=O<FEA`$QU;F$@3G5O=F$`
M3G5O=F\@3F]M92!5=&5N=&4@*&]P>FEO;F%L92D`3G5O=F$@<&%S<W=O<F0`
M3&$@;G5O=F$@<&%S<W=O<F0@<V-A9'+@(&EN("5X+@!,82!N=6]V82!P87-S
M=V]R9"!N;VX@8V]R<FES<&]N9&4N`$YU;W9A(&9I;FES=')A("A?=G5O=&$I
M`$YO=&EZ:64`1W)U<'!I(&1I($YO=&EZ:64`4')O<W-I;6\`4')O<W-I;64@
M-"!&87-I`%!R;W-S:6UE(&]P>FEO;FD`4')O<W-I;6\^`$YO='1E`$YO;B!S
M;VYO(&1I<W!O;FEB:6QI(&EN9F]R;6%Z:6]N:2!R:6=U87)D;R!L82!C;VYF
M:6=U<F%Z:6]N92!P97(@;6]S=')A<F4@;&4@9&EF9F5R96YZ92X`3F]N(.@@
M9&ES<&]N:6)I;&4@=6YA('-T<F%T96=I82!P97(@8W)E87)E(&EM;6%G:6YI
M($E33RX`3F]N(&5S:7-T92!U;B!B;&]C8V\@86QL82!P;W-I>FEO;F4@<FEC
M:&EE<W1A`$YO;B#H('-T871O(&9O<FYI=&\@:6P@;F]M92!D96P@8V%L96YD
M87)I;R!P97(@;"=A=71E;G1I8V%Z:6]N92!-0T%,+@!.97-S=6YA(&UO9&EF
M:6-A+@!.97-S=6X@9FEG;&EO('!U\B!E<W-E<F4@86=G:75N=&\@82!Q=65S
M=&\@<&5R;65S<V\N`$YO;B#H('-T871A('-P96-I9FEC871A(&%L8W5N82!I
M;F9O<FUA>FEO;F4@<W5L;&$@8V]N9FEG=7)A>FEO;F4@<&5R("5S+@!.;VX@
MZ"!S=&%T82!S<&5C:69I8V%T82!A;&-U;F$@:6YF;W)M87II;VYE('-U;&QA
M(&-O;F9I9W5R87II;VYE('!E<B!&5%`@5D93+@!.;VX@Z"!S=&%T82!S<&5C
M:69I8V%T82!A;&-U;F$@:6YF;W)M87II;VYE('-U;&QA(&-O;F9I9W5R87II
M;VYE('!E<B!344P@5D93+@!.;VX@Z"!S=&%T82!S<&5C:69I8V%T82!A;&-U
M;F$@:6YF;W)M87II;VYE('-U;&QA(&-O;F9I9W5R87II;VYE('!E<B!344PM
M1FEL92!61E,N`$YO;B#H(')I;6%S=&\@;F5S<W5N(&-R961I=&\N`$YO;B#H
M('-T871A(&9O<FYI=&$@;&$@9&5S=&EN87II;VYE+@!);"!F:6QE(&YO;B#H
M('-T871O(&-A<FEC871O`$YO;B!S;VYO('-T871E('1R;W9A=&4@;&4@:6-O
M;F4N`$YO;B#H('-T871O(&EM<&]S=&%T;R!L82!P;W-I>FEO;F4N`$YO;B#H
M('-T871O(&EN9&EC871O(&QA('!O<VEZ:6]N92X`3F]N(.@@<W1A=&\@9F]R
M;FET;R!I;"!M97-S86=G:6\N`$YO;B#H('-T871O('-P96-I9FEC871O(&EL
M(&YO;64N`$YO;B#H('-T871O('-P96-I9FEC871O(&EL(&YU;65R;RX`3F]N
M(.@@<W1A=&$@9F]R;FET82!L82!P87-S=V]R9"!P97(@;"=A=71E;G1I8V%Z
M:6]N92!(5%10+@!.;VX@Z"!S=&%T82!F;W)N:71A(&QA('!A<W-W;W)D('!E
M<B!L)V%U=&5N=&EC87II;VYE($E-05`N`$YO;B#H('-T871A(&9O<FYI=&$@
M;&$@<&%S<W=O<F0@<&5R(&PG875T96YT:6-A>FEO;F4@2V5R8F5R;W,N`$YO
M;B#H('-T871A(&9O<FYI=&$@;&$@<&%S<W=O<F0@<&5R(&PG875T96YT:6-A
M>FEO;F4@3&]G:6XN`$YO;B#H('-T871A(&9O<FYI=&$@;&$@<&%S<W=O<F0@
M<&5R(&PG875T96YT:6-A>FEO;F4@4$%34U=$+@!.;VX@Z"!S=&%T82!F;W)N
M:71A(&QA('!A<W-W;W)D('!E<B!L)V%U=&5N=&EC87II;VYE(%--0BX`3F]N
M(.@@9&ES<&]N:6)I;&4@86QC=6YA('!A=&-H('!E<B!L82!V97)S:6]N92!B
M:6YA<FEA(&1I($]P96Y34TPN($QA('9E<G-I;VYE(&)I;F%R:6$@9&D@3W!E
M;E-33"#H(&YE8V5S<V%R:6\@8VAE(&]P97)I(&-O;B!L92!I;F9O<FUA>FEO
M;FD@4$M#4R`Q,BX`3F]N(.@@<W1A=&$@:6UP;W-T871A(&QA('%U;W1A+@!.
M97-S=6YA(')E9V]L80!.;VX@Z"!S=&%T;R!S<&5C:69I8V%T;R!I;"!S97!A
M<F%T;W)E+@!.97-S=6YA(&QA=&\`3F5S<W5N('1I<&\@9&D@9FEL90!.;VX@
MZ"!D:7-P;VYI8FEL92!U;F$@9&ER96-T;W)Y('1E;7!O<F%N96$@<&5R(&QA
M(&-A8VAE+@!.;VX@Z"!S=&%T82!I;G9I871O(&EL(&YO;64@=71E;G1E(&4O
M;R!P87-S=V]R9"X`3F]N('-O;F\@<FET;W)N871E(&EN9F]R;6%Z:6]N:2!8
M34P@=F%L:61E`$YE<W-U;B!V86QO<F4`3F]N(.@@<W1A=&$@=')O=F%T82!L
M82!V97)S:6]N92!N96QL82!C;VYF:6=U<F%Z:6]N92!O<FEG:6YA;&4N(%)I
M9V5N97)A(&QA(&-O;F9I9W5R87II;VYE+@!.;VX@Z"!S=&%T82!T<F]V871A
M(&QA('9E<G-I;VYE(&YE;&QA('1U82!C;VYF:6=U<F%Z:6]N92X@4FEG96YE
M<F$@;&$@8V]N9FEG=7)A>FEO;F4N`$YE<W-U;F\`3F5S<W5N;R`O=7-O(&EM
M<&QI8VET;RD`16UI<V9E<F\@4V5T=&5N=')I;VYA;&4`3F]R=F5G:6$`3F]N
M($1O<&\`3F]N(%!R:6UA`$YO;B!U;F$@9&ER96-T;W)Y`$YO;B!I;7!L96UE
M;G1A=&\`3F]N(&EM<&]S=&%T;P!.;VX@<W5P<&]R=&%T;RX`07!P=6YT:0!.
M=6QL82!D82!V:7-U86QI>GIA<F4L('1O<FYA(&EN9&EE=')O+@!.;W9E;6)R
M90!.=6UE<F\`3G5M97)O(&1I(&-A<F%T=&5R:0!.=6UE<F\@9&D@8V]L;VYN
M90!.=6UE<F\@9&D@<FEG:&4`22!N=6UE<FD@;F]N('-O;F\@<W1A=&D@<W!E
M8VEF:6-A=&D@<&5R(&PG86=G:6]R;F%M96YT;R!N96QL82!L:7-T82!D:2!D
M:7-T<FEB=7II;VYE+@!/9V=E='1O`$-R96%T;W)E(&1E;&PG3V=G971T;P!/
M='1A;&4`3W1T;V)R90!59F9I8VEO`$QE('!A<W-W;W)D('9E8V-H:64@92!N
M=6]V92!D979O;F\@97-S97)E(&1I9F9E<F5N=&D`5F5C8VAI82!P87-S=V]R
M9`!,82!V96-C:&EA('!A<W-W;W)D(&YO;B#H(&-O<G)E='1A+@!3;VQO(&D@
M<V5R=F5R($E-05`@<W5P<&]R=&%N;R!L92!C87)T96QL92!C;VYD:79I<V4N
M`$4G('!E<FUE<W-O('-O;&\@=6X@:6YD:7)I>GIO(&5M86EL+@!3;VQO(&EL
M('!R;W!R:65T87)I;R!O(&PG86UM:6YI<W1R871O<F4@9&D@<VES=&5M82!P
M=?(@8V%M8FEA<F4@;&$@<')O<')I973@(&\@:2!P97)M97-S:2!D96P@<')O
M<')I971A<FEO('!E<B!U;F$@8V]N9&EV:7-I;VYE`$%P<F4@:6X@=6YA(&YU
M;W9A(&9I;FES=')A`$5R<F]R92!/<&5N4U-,.B!N;VX@<VD@<&]S<V]N;R!E
M<W1R87)R92!L92!I;F9O<FUA>FEO;FD@9&%L;&$@<&%R=&4@9FER;6%T82!3
M+TU)344N`$%P<F4@<75E<W1O(&-O;&QE9V%M96YT;R!I;B!U;F$@;G5O=F$@
M9FEN97-T<F$`4VES=&5M82!/<&5R871I=F\`3W!Z:6]N:0!/<'II;VYI('!E
M<B`E<P!%;&5N8V\@;W)D:6YA=&\`3W)G86YI>GIA>FEO;F4`56YI=.`@3W)G
M86YI>GIA=&EV80!!9V5N9&$`36%S8VAE<F$@;W)I9VEN86QE(&1E;&PG87!L
M:6-A>FEO;F4`36%S8VAE<F$@;W)I9VEN86QE(&EN("5S.@!!;'1R;P!!;'1R
M92!);F9O<FUA>FEO;F4`4&5R;65S<VD@9&5L('!R;W!R:65T87)I;P!,)V%U
M=&5N=&EC87II;VYE(%!!32!N;VX@Z"!D:7-P;VYI8FEL92X`26YF;W)M87II
M;VYE($-I9G)A=&$@4$=0`$-H:6%V92!0=6)B;&EC82!01U``26YF;W)M87II
M;VYE($9I<FUA=&$O0VEF<F%T82!01U``0V]D:6-E(%!(4`!3:&5L;"!02%``
M17-T96YS:6]N92!03U-)6"!M86YC86YT90!2:65M<&EM96YT;P!087)Z:6%L
M;65N=&4@3G5V;VQO<V\`4&%S<W=O<F0@8V%M8FEA=&$@8V]N('-U8V-E<W-O
M+@!087-S;W=R9"!N;VX@8V]R<F5T=&$`12<@<FEC:&EE<W1A(&QA('!A<W-W
M;W)D('!E<B!L)V%U=&5N=&EC87II;VYE(%)!1$E54RX`4&%S<W=O<F0@8V]N
M(&-O;F9E<FUA`$QE('!A<W-W;W)D(&1E=F]N;R!C;W)R:7-P;VYD97)E+@!)
M;F-O;&QA`$EN8V]L;&$@9&%L;&$@8VQI<&)O87)D`%!E<F-O<G-O`%!E<G-O
M;F4`4&5R8V5N='5A;&4`17-E9W5I(&QE($]P97)A>FEO;FD@9&D@36%N=71E
M;GII;VYE`$5S96=U:7)E(&QE(&]P97)A>FEO;FD@9&D@;6%N='5T96YZ:6]N
M92!A;&PG86-C97-S;S\`4&5R;65S<V\`4&5R;65S<V\@(B5S(B!N;VX@8V%N
M8V5L;&%T;RX`4&5R;65S<V\@3F5G871O`%!E<FUE<W-I`$=E<W1I;VYE(%!E
M<FUE<W-I`$EN9F]R;6%Z:6]N:2!097)S;VYA;&D`5&5L969O;F\`1F]T;V=R
M869I90!3:2!P<F5G82!D:2!C;&EC8V%R92!I;B!A;&-U;F4@8V5L;&4`4VD@
M<')E9V$@9&D@8V]N9F5R;6%R92!C:&4@<VD@=G5O;&4@<FEM=6]V97)E('%U
M97-T;R!E;&5M96YT;SH`4VD@<')E9V$@9&D@8V]N9F5R;6%R92!C:&4@<VD@
M=G5O;&4@<V-O;&QE9V%R92!Q=65S=&\@96QE;65N=&\Z`%-I('!R96=A(&1I
M(&EN<V5R:7)E('5N(&UE<V4@92!U;B!A;FYO+@!3:2!P<F5G82!D:2!I;G-E
M<FER92!U;B!N;VUE('!E<B!L82!N=6]V82!G871E9V]R:6$Z`%-I('!R96=A
M(&1I(&EN<V5R:7)E('5N(&EN9&ER:7IZ;R!)4"!V86QI9&\N`%-I('!R96=A
M(&1I(&EN<V5R:7)E('5N82!D871A('9A;&ED82P@8V]N=')O;&QA(&EL(&YU
M;65R;R!D:2!G:6]R;FD@;F5L(&UE<V4N`%-I('!R96=A(&1I(&EN<V5R:7)E
M('5N)V]R82!V86QI9&$N`%-I('!R96=A(&1I(&9O<FYI<F4@=6X@<FEA<W-U
M;G1O(&1E;"!P<F]B;&5M82X`4VD@<')E9V$@9&D@9F]R;FER92!I;"!P<F]P
M<FEO(&YO;64@=71E;G1E(&4@<&%S<W=O<F0`4VD@<')E9V$@9&D@;&5G9V5R
M92!I;"!S96=U96YT92!T97-T;RX@1$5622!E<W-E<F4@9"=A8V-O<F1O(&-O
M;B!I('1E<FUI;FD@9"=U<V\@9&5L('-I<W1E;6$N`%-I('!R96=A(&1I('-C
M<FEV97)E(&EL;F]M92!D96QL82!N=6]V82!C871E9V]R:6$Z`%!O;&]N:6$`
M4&]L:71I8V$`4V-R=71I;FEO`%!O<G1O9V%L;&\`4&]S:7II;VYA;65N=&\@
M9&D@<75E<W1A(&EM;6%G:6YE`%!O<VEZ:6]N86UE;G1O(&1I('%U97-T82!T
M86)E;&QA`%!O<W1A<F4@82!Q=65S=&$@8V%R=&5L;&$@*&YO;B!A<'!L:6-A
M=&\@9&$@24U!4"D`4')E8VEP:71A>FEO;F4@<&5R(&PG=6QT:6UA("5S(&]R
M82AE*0!0<F5F<U]L9&%P.B!%<W1E;G-I;VYE($Q$05`@<FEC:&EE<W1A(&YO
M;B!T<F]V871A+@!0<F5F<U]S97-S:6]N.B!E<W1E;G-I;VYE(&1E;&QA('-E
M<W-I;VYE(')I8VAI97-T82!N;VX@=')O=F%T82X`4')E<W-I;VYE`%!R97-S
M:6]N92!A;"!L:79E;&QO(&1E;"!M87)E.B``4')E<W-I;VYE.B``06YT97!R
M:6UA`$%N=&5P<FEM82!D96QL)VEM;6%G:6YE(&EN('5N82!N=6]V82!F:6YE
M<W1R80!/<'II;VYI('!R96-D96YT:0!3=&%M<&$@9&]C=6UE;G1O`$-H:6%V
M92!0<FEV871A`%!R;V)L96UA`$1E<V-R:7II;VYE(&1E;"!P<F]B;&5M80!0
M<F]G971T:0!#:&EA=F4@4'5B8FQI8V$`06QG;W)I=&UO(&1E;&QA($-H:6%V
M92!0=6)B;&EC80!);F9O<FUA>FEO;FD@<W5L;&$@0VAI879E(%!U8F)L:6-A
M`$QA(&-O<'!I82!C:&EA=F4@4'5B8FQI8V$O4')I=F%T82!N;VX@Z"!S=&%T
M82!G96YE<F%T82!C;VX@<W5C8V5S<V\N`$5L:6UI;F$@:2!M97-S86=G:0!$
M;VUA;F1A`%-E;&5Z:6]N92!R861I;P!0:6]G9VEA`%)A<'!O<G1O`$QE9V=I
M`$QE9V=E<F4@:2!M97-S86=G:0!%;&EM:6YA<F4@<F5A;&UE;G1E("5S/R!,
M)V]P97)A>FEO;F4@;F]N('!U\B!E<W-E<F4@<F5C=7!E<F%T82X`16QI;6EN
M87)E(')E86QM96YT92!L92!I;F9O<FUA>FEO;FD@<F5L871I=F4@86QL)W5T
M96YT92`E<S\@3"=O<&5R87II;VYE(&YO;B!P=?(@97-S97)E(')E8W5P97)A
M=&$N`%)I97-E9W5E(&QA('1U82!U;'1I;6$@87II;VYE`$%G9VEO<FYA`$%G
M9VEO<FYA(&=L:2!E;&5M96YT:2!D:6YA;6EC:2!D96P@;65N=3H`06=G:6]R
M;F%R92!L82!V:7-T82!D96P@<&]R=&%L93H`4FEC87)I8V$`3W-S97)V87II
M;VYI`%-E<G9E<B!R96UO=&D`55),(')E;6]T82`H:'1T<#HO+W=W=RYE>&%M
M<&QE+F-O;2]H;W)D92DZ`%)I;75O=FD`4FEM=6]V:2!I;"!B;&]C8V\`4FEM
M=6]V:2!L82!C;VQO;FYA`%)I;75O=FD@;&$@9F]R;6%T=&%Z:6]N90!2:6UU
M;W9I(&QA(&-O<'!I80!2:6UU;W9I(&QO('-C<FEP="!S86QV871O(&1A;&QA
M(&1I<F5C=&]R>2!T96UP;W)A;F5A(&1E;"!S97)V97(N`%)I;75O=FD@:6P`
M4FEM=6]V:2!Q=65S=&\@;F]D;R!D86P@9&]C=6UE;G1O`%)I;75O=FD@;"=U
M=&5N=&4`4FEM=6]V:2!L)W5T96YT93H@)7,`3&$@<FEC:&EE<W1A(&YO;B!P
M=?(@97-S97)E(&5V87-A+B!#;V1I8V4@9&D@97)R;W)E(&1I(')I=&]R;F\Z
M(`!);"!S97)V:7II;R!R:6-H:65S=&\@;VX@<'7R(&5S<V5R92!T<F]V871O
M+@`B)7,B(')I8VAI97-T;R!N;VX@Z"!S<&5C:69I8V%T;R!N96QL82!C;VYF
M:6=U<F%Z:6]N92!D:2`E<RX`(B5S(B!R:6-H:65S=&\@;F]N(.@@<W!E8VEF
M:6-A=&\@;F5L;&$@8V]N9FEG=7)A>FEO;F4@9&D@5D93+@`B)7,B(')I8VAI
M97-T;R!N;VX@Z"!S<&5C:69I8V%T;R!N96QL82!C;VYF:6=U<F%Z:6]N92X`
M0V%M<&\@4FEC:&EE<W1O`$%Z>F5R80!!>GIE<F$@;&$@<&%S<W=O<F0`07IZ
M97)A(&QA('1U82!P87-S=V]R9`!2:7!R:7-T:6YA(&PG=6QT:6UA(&1O;6%N
M9&$`4FES=6QT871I`%)I=&]R;F$@86QL92!/<'II;VYI`%)I<V-R:79I(&QA
M(&YU;W9A('!A<W-W;W)D`%)I=6YI;VYE`$EN=F5R=&D@;&$@0V]N9FEG=7)A
M>FEO;F4`3W!Z:6]N:2!P97(@:6P@4FEC:"!497AT($5D:71O<@!);F1O=FEN
M96QL:0!$97-T<F$`26YT97-T87II;VYI(&1I(&1E<W1R80!686QO<FD@9&D@
M9&5S=')A`%!R;W!R:65TX"!D96QL82!2:5]G82XN+@!296=O;&$`4F]U=&$@
M9&D@,3@P`%)O=71A(&$@<VEN:7-T<F$`4F]U=&$@82!$97-T<F$`4')O<')I
M973@(&1E;&QA(%)I9V$`4')O<')I973@(&1E;&QA(')I9V$`4FEG:&4Z`%)E
M9V]L90!,92!R96=O;&4@87!P87)I<F%N;F\@=')A('1U='1E(&QE(')I9VAE
M(&4@;&4@8V]L;VYN90!,92!R96=O;&4@87!P87)I<F%N;F\@<V]L;R!T<F$@
M;&4@8V]L;VYN90!,92!R96=O;&4@87!P87)I<F%N;F\@<V]L;R!T<F$@;&4@
M<FEG:&4`17-E9W5I<F4`1FER;6$@8VEF<F%T82!3+TU)344`365S<V%G9VEO
M(&-I9G)A=&\@4R]-24U%`$PG875T96YT:6-A>FEO;F4@4T%33"!N;VX@Z"!D
M:7-P;VYI8FEL92X`365S<V%G9VEO(%--4P!$:6-H:6%R87II;VYE(%-13"!P
M97(@:6P@=F%L;W)E(&1I(&QO;VMS=7``4W1E<W-A('-T<G5T='5R82`H7V%U
M=&\I`'!R;W9I9&5R('-A=&5L;&ET87)E`%-A;'9A`%-A;'9A("(E<R(`4V%L
M=F$@)7,`4V%L=F$@;&4@3W!Z:6]N:0!,82!C;VYF:6=U<F%Z:6]N92!G96YE
M<F%T82#H('-T871A('-A;'9A=&$@8V]M92!S8W)I<'0@4$A0(&YE;&QA(&1I
M<F5C=&]R>2!T96UP;W)A;F5A(&1E;"!T=6\@<V5R=F5R+@!S86QV871E("5S
M(&-O;F9I9W5R87II;VYI+@!386QV871O(&QO('-C<FEP="!D:2!A9V=I;W)N
M86UE;G1O(&1E;&QE(&EM<&]S=&%Z:6]N:2!I;CH@(B5S(BX`4V-I96YZ80!2
M:6-E<F-A`$UO=&]R:2!D:2!2:6-E<F-A`$9I;&4@<V5L97II;VYA=&D`4V5L
M97II;VYA('5N82!D871A`%-E;&5Z:6]N82!U;B!G<G5P<&\@9&$@86=G:75N
M9V5R90!396QE>FEO;F$@=6X@;G5O=F\@<')O<')I971A<FEO`%-E;&5Z:6]N
M82!U;B!S97)V97(`4V5L97II;VYA('5N('5T96YT92!D82!A9V=I=6YG97)E
M`%-E;&5Z:6]N82!T=71T;P!396QE>FEO;F$@='5T=&D@:2!C;VUP;VYE;G1I
M(&1E;&QA(&1A=&$N`'-E;&5Z:6]N82!U;B!O9V=E='1O`$YE<W-U;F$@<V5L
M97II;VYE`%-E;&5Z:6]N82!I(&-A<F%T=&5R:2!D:2!C=6D@:&%I(&)I<V]G
M;F\@9&%L;&4@8V%S96QL92!S;W1T;R!R:7!O<G1A=&4N(%!U;VD@8V]P:6%R
M;&D@92!I;F-O;&QA<FQI(&1A;&PG87)E82!D:2!T97-T;RX`4V5L97II;VYA
M(&EL('1E<FUI;F4@9&5L;&$@9&%T83H`4V5L97II;VYA(&EL(&9O<FUA=&\@
M9&5L;&$@9&%T83H`4V5L97II;VYA(&PG:61E;G1I=.`@8VAE('9U;VD@;6]D
M:69I8V%R93H`4V5L97II;VYA(&EL(&QI;6ET92!D96QL)V]R83H`4V5L97II
M;VYA(&EL(&9O<FUA=&\@9&5L;"=O<F$Z`%-E;&5Z:6]N82!D=64@8V%M<&D@
M8VAE(&-O<G)I<W!O;F1O;F\N`%-E;&5Z:6]N82!L;R!S8VAE;6$@9&5I(&-O
M;&]R:2X`4V5L97II;VYA(&QA(&QI;F=U82!P<F5F97)I=&$Z`$EN=FEA(&EL
M(%)E<&]R="!D96P@<')O8FQE;6$`26YV:6$@4TU3`%-E;G-O<F4Z(`!3971T
M96UB<F4`3G5M97)O(&1I(%-E<FEE`$EN9F]R;6%Z:6]N92!D96P@<V5R=F5R
M('-B86=L:6%T82!O(&YO;B!D:7-P;VYI8FEL92X`06UM:6YI<W1R871O<F4@
M9&D@<V5S<VEO;F4`3&$@<V5S<VEO;F4@240@Z"!S8V%D=71A`%-E<W-I;VYI
M`$EM<&]S=&$`26UP;W-T82!L92!O<'II;VYI('!E<B!P97)M971T97)T:2!D
M:2!A>GIE<F%R92!L82!P87-S=V]R9"!N96P@8V%S;R!D;W9E<W-I(&1I;65N
M=&EC87)T96QA+@!);7!O<W1A(&EL('-E<G9E<B!R96UO=&\@86P@<75A;&4@
M=G5O:2!A8V-E9&5R92!D86P@='5O('!O<G1A;&4N`$EM<&]S=&$@;&$@;&EN
M9W5A('!R969E<FET82!E(&QE(&]P>FEO;FD@<&5R(&PG;W)A(&4@;&$@9&%T
M82X`26UP;W-T82!L92!A<'!L:6-A>FEO;FD@9&D@879V:6\L(&QO('-C:&5M
M82!D96D@8V]L;W)I+"!I;"!T96UP;R!D:2!A9V=I;W)N86UE;G1O(&1E;&QA
M('!A9VEN82!E(&%L=')E(&]P>FEO;FD@9&D@=FES=6%L:7IZ87II;VYE+@!)
M;7!O<W1A>FEO;F4`4V-R:7!T(&1I(&%G9VEO<FYA;65N=&\@9&5L;&4@:6UP
M;W-T87II;VYI(&1I<W!O;FEB:6QI`$1I=F5R<V4@<&]S:7II;VYI(&1I<W!O
M;FEB:6QI(&-O;B!I;"!P87)A;65T<F\Z(`!"<F5V92!3;VUM87)I;P!,82!C
M:&EA=F4@9"=A8V-E<W-O(&1O=G+@(&5S<V5R92!D969I;FET82!P97(@<&GY
M(&-O;&QE9V%M96YT:3\`36]S=')A`$UO<W1R82!L92!D:69F97)E;GIE('1R
M82!L82!C;VYF:6=U<F%Z:6]N92!A='1U86QM96YT92!S86QV871A(&4@;&$@
M;G5O=F$@9V5N97)A=&$N`$UO<W1R82!L)V]R82!D96QL)W5L=&EM;R!A8V-E
M<W-O('%U86YD;R!E;G1R:3\`36]S=')A(&PG;W!Z:6]N92!P97(@;6%N=&5N
M97)E('%U96QL82!O<FEG:6YA;&4`36]S=')A(&EL(')A8V-O9VQI=&]R90!-
M;W-T<F%R92!L82!T86)E;&QA(&1E;&QE(&]P97)A>FEO;FD@9&5L(&UE;G4@
M8F%R/P!-;W-T<F$@:6P@;65N=2!D:2`E<R!S=6QL82!S:6YI<W1R83\`36]S
M=')A(&EL(&-A<FEC86UE;G1O`$-O;G1R87-S96=N80!&:7)M80!!;&=O<FET
M;6\@9&D@9FER;6$`1&EM96YS:6]N90!386QT82!L92!O<&5R87II;VYI(&1I
M(&UA;G5T96YZ:6]N90!.979E`$]R9&EN82!L)V]R9&EN86UE;G1O(&1I('-E
M;&5Z:6]N90!);F1I<FEZ>F\@<V]R9V5N=&4`4W5D($%F<FEC80!E;6ES9F5R
M;R!-97)I9&EO;F%L90!3<&%Z:6\@=')A(&-E;&QE(&%I9&%C96YT:0!3<&%Z
M:6\@=')A(&EL(&-O;G1E;G5T;R!E(&EL(&)O<F1O(&EN('5N82!C96QL80!$
M:7-T86YZ:6%T;W)E`%-P87II871U<F$`4W!A>FEA='5R82!E(')I96UP:6UE
M;G1O`%-P86=N80!);G-E<FEM96YT;R!#87)A='1E<FD@4W!E8VEA;&D`4V5P
M87)A(&QA(&-E;&QA`%-E<&%R82!L82!C;VQO;FYA`%-E<&%R82!L82!R:6=H
M80!!;FYO(&1I('!A<G1E;GIA`%-T871O(&\@4')O=FEN8VEA`$9O<FUA=&\@
M9&D@;65M;W)I>GIA>FEO;F4`26YD:7)I>GIO`%1O9VQI(&EL(&1O;6EN:6\@
M9&%L;"=I;F1I<FEZ>F\`4W1I;&4@6T-34UT`1&\`4V]T=&]D:7)E8W1O<GD@
M(B5S(B!N;VX@=')O=F%T82X`3V=G971T;P!3;W1T;VUE='1I`$4G('-T871A
M(&EN=FEA=&$@;&$@<FEC:&EE<W1A('!E<B!A9V=I=6YG97)E("(E<R(@86P@
M<VES=&5M82X@3F]N('!U;VD@86-C961E<F4@9FEN=&%N=&\@(&-H92!L82!R
M:6-H:65S=&$@;F]N('9I96YE(&%P<')O=F%T82X`(B5S(B#H('-T871O(&%G
M9VEU;G1O(&-O;B!S=6-C97-S;R!A;"!S:7-T96UA+@!,92!I;F9O<FUA>FEO
M;FD@<F5L871I=F4@86QL)W5T96YT92`B)7,B('-O;F\@<W1A=&4@8V%N8V5L
M;&%T92!C;VX@<W5S<V5S<V\@9&%L('-I<W1E;6$N`"(E<R(@96QI;6EN871A
M(&-O;B!S=6-C97-S;RX`(B5S(B!R:6UO<W-O(&-O;B!S=6-C97-S;R!D86P@
M<VES=&5M82X`0V]N9FEG=7)A>FEO;F4@:6YV97)T:71A(&-O;B!S=6-C97-S
M;RX@4FEC87)I8V$@<&5R('9E9&5R92!I(&-A;6)I86UE;G1I+@!#;W!I82!D
M96QL82!C;VYF:6=U<F%Z:6]N92!S86QV871A(&-O;B!S=6-C97-S;RX`0V]P
M:6$@9&5L(&9I;&4@9&D@8V]N9FEG=7)A>FEO;F4@9&D@)7,@<V%L=F%T82!C
M;VX@<W5C8V5S<V\N`$%G9VEO<FYA=&\@8V]N('-U8V-E<W-O("(E<R(`4V-R
M:71T;R!C;VX@<W5C8V5S<V\@)7,`4V]M;6%R:6\`4W5P<&]R=&\`4V]P<F%N
M;F]M90!3=F5Z:6$`4W9I>GIE<F$`17)R;W)E(&1I('-I;G1A<W-I(&YE:2!T
M97)M:6YI(&1I(')I8V5R8V$`4')O<')I973@(&1E;&QA(%1A8F5L;&$`26UP
M;W-T87II;VYE(&1E;&QA(%1A8F5L;&$`4')O<')I973@(&1E;&QA('1A8F5L
M;&$`3V)I971T:79O.@!!='1I=FETX`!.=6UE<F\@9&D@=&5L969O;F\`5&5M
M<&5R871U<F$@<&5R(&PG=6QT:6UA(&]R83H@`%1E;7!E<F%T=7)A`%1E;7!E
M<F%T=7)A.B``36%S8VAE<F$@(B5S(B!N;VX@=')O=F%T82X`1V5S=&EO;F4@
M36%S8VAE<F$`5&5S=&\`4V]L;R!497-T;P!!;&QI;F5A;65N=&\@=&5S=&\`
M1VD`3"=E<W1E;G-I;VYE($944"!N;VX@Z"!D:7-P;VYI8FEL92X`3&$@8W)O
M;FES=&]R:6$@9&5L('-I<W1E;6$@Z"!D:7-A8FEL:71A=&$N`$EL(&UO=&]R
M92!D:2!I;G1E9W)A>FEO;F4@2&]R9&4O2V]L86(@;F]N('-U<'!O<G1A("(E
M<R(`26P@;&]G(&1I($E-4U`@;F]N('!U\B!E<W-E<F4@:6YI>FEA;&EZ>F%T
M;RX`3&$@8VQA<W-E($UA:6YT96YA;F-E.CH@;F]N(.@@<W1A=&$@8V%R:6-A
M=&$@8V]N('-U8V-E<W-O`$QA(&9I;FES=')A(&1E;&QE($]P>FEO;FD@<VD@
MZ"!C:&EU<V$N(%5S8VER92X`4V]L86UE;G1E(&EL(&QA=&\@:6YF97)I;W)E
M`$EL(&-O;G1A='1O(.@@<W1A=&\@86=G:75N=&\@8V]N('-U8V-E<W-O(&%L
M;&$@='5A(')U8G)I8V$N`$YO;B#H('-T871A('-P96-I9FEC871A(&QA(&QI
M<W1A(&1I(&1I<W1R:6)U>FEO;F4N`$QA(&9U;GII;VYE(&1I(&-I9G)A='5R
M82!R:6-H:65D92!U;F$@8V]N;F5S<VEO;F4@=V5B('-I8W5R82X`26P@9FEL
M92`E<R!D;W9R96)B92!C;VYT96YE<F4@=6YA("5S(&EM<&]S=&%Z:6]N92X`
M26P@9FEL92`E<R!D;W9R96)B92!C;VYT96YE<F4@86QC=6YE("5S(&EM<&]S
M=&%Z:6]N:2X`26P@9FEL92!N;VX@8V]N=&EE;F4@:6YF;W)M87II;VYI+@!,
M92!S96=U96YT:2!S;VYO(&QE(&EN=&5S=&%Z:6]N:2!P97(@<75E<W1O(&UE
M<W-A9V=I;R]R9F,X,C(@;65S<V%G9VEO+@!,)VED96YT:73@("(E<R(@Z"!S
M=&%T82!C86UC96QL871A+@!);"!N=6UE<F\@9&5I(&-A;7!I(&1E=F4@97-S
M97)E(&1I('1I<&\@;G5M97)I8V\N`$EL(&UO9'5L;R!O<&5N<W-L(.@@<FEC
M:&EE<W1O('!E<B!L82!C;&%S<V4@2&]R9&5?0W)Y<'1?<VUI;64Z.BX`3&$@
M<')E9F5R96YZ82`B)7,B(&YO;B!P=?(@97-S97)E('-A;'9A=&$@<&5R8VCH
M(&PG:6YF;W)M87II;VYE(&-O;G1E;G5T82!E8V-E9&4@;&$@;6%S<VEM82!D
M:6UE;G-I;VYE(&1I<W!O;FEB:6QE`$EL('!R;V=R86UM82!U<V%T;R!P97(@
M=FES=6%L:7IZ87)E('%U97-T;R!T:7!O(&1I(&EN9F]R;6%Z:6]N92`H)7,I
M(&YO;B#H('-T871O('1R;W9A=&\@;F5L('-I<W1E;6$N`$EL('-E<G9E<B`B
M)7,B(.@@<W1A=&\@96QI;6EN871O+@!);"!S97)V97(@(B5S(B#H('-T871O
M('-A;'9A=&\N`$QA(')I8VAI97-T82!D:2!I<V-R:7II;VYE('!E<B`E<R#H
M('-T871A(')I;6]S<V$N`$QA(')I9V$@<W!E8VEF:6-A=&$@*"5D*2!N;VX@
M97-I<W1E+@!);"!F:6QE('1E;7!O<F%N96\@(B5S(B!N;VX@97-I<W1E+@!)
M;"!T97-T;R!D:6=I=&%T;R!N;VX@8V]R<FES<&]N9&4@86P@=&5S=&\@<W5L
M;&\@<V-H97)M;RX`3"=I;F9O<FUA>FEO;F4@8V%R:6-A=&$@Z"!S=&%T82!P
M97)S82!S:6X@9&%L;"=U;'1I;6\@<&%S<V\N`$EL(&9I;&4@8V%R:6-A=&\@
M;F]N('!U\B!E<W-E<F4@<V%L=F%T;RX`3&$@9&ER96-T;W)Y(&1E:2!T96UI
M("(E<R(@;F]N(.@@<W1A=&$@=')O=F%T82X`3F]N(&-I('-O;F\@;W!Z:6]N
M:2!D:7-P;VYI8FEL:2X`3F]N(&-I('-O;F\@<&%R=&D@8VAE('!O<W-O;F\@
M97-S97)E('9I<W5A;&EZ>F%T92!I;FQI;F4N`$-I('-O;F\@=')O<'!I(&-A
M<F%T=&5R:2!I;B!Q=65S=&\@8V%M<&\N($AA:2!D:6=I=&%T;R`E<R!C87)A
M='1E<FD[(&1E=FD@9&EG:71A<F4@=6X@;G5M97)O(&1I(&-A<F%T=&5R:2!M
M:6YO<F4@9&D@)7,N`$-I('-O;F\@86QC=6YI('!R;V)L96UI(&YE;&PG86=G
M:75N9V5R92`B)7,B(&%L('-I<W1E;6$Z("5S`$,GZ"!S=&%T;R!U;B!P<F]B
M;&5M82!N96P@8V%N8V5L;&%R92!L92!I;F9O<FUA>FEO;FD@<&5R(&PG=71E
M;G1E("(E<R(@9&%L('-I<W1E;6$Z(`!#)^@@<W1A=&\@=6X@<')O8FQE;6$@
M;F5L(')I;75O=F5R92`B)7,B(&1A;"!S:7-T96UA.B``0R?H('-T871O('5N
M('!R;V)L96UA(&YE;&PG86=G:6]R;F%M96YT;R!D:2`B)7,B.B`E<P!#)^@@
M<W1A=&\@=6X@<')O8FQE;6$@8V]N(&EL(&-A<FEC86UE;G1O(&1E;"!F:6QE
M.B!.97-S=6X@)7,@Z"!S=&%T;R!C87)I8V%T;RX`0R?H('-T871O('5N('!R
M;V)L96UA(&-O;B!I;"!C87)I8V%M96YT;R!D96P@9FEL93H@26P@)7,@97)A
M('!I^2!L=6YG;R!D96QL82!M87-S:6UA(&1I;65N<VEO;F4@<&5R;65S<V$@
M*"5D(&)Y=&5S*2X`0R?H('-T871O('5N('!R;V)L96UA(&-O;B!I;"!C87)I
M8V%M96YT;R!D96P@9FEL93H@26P@)7,@Z"!S=&%T;R!C87)I8V%T;R!S;VQO
M('!A<GII86QM96YT92X`0R?H('-T871O('5N(&5R<F]R92!N96QL82!V:7-U
M86QI>GIA>FEO;F4@9&D@<75E<W1A('!A<G1E(&1E;"!M97-S86=G:6\`0R?H
M('-T871O('5N(&5R<F]R92!N96QL)VEM<&]R=&%R92!L92!I;F9O<FUA>FEO
M;FD@9&5L(&-O;G1A='1O+@!#)^@@<W1A=&\@=6X@97)R;W)E(&YE;&PG:6UP
M;W)T87)E(&QE(&EN9F]R;6%Z:6]N:2!D:2!I0V%L96YD87(N`$,GZ"!S=&%T
M;R!U;B!E<F]R92!N96QL82!F;W)M(&1I(&-O;F9I9W5R87II;VYE+B!0<F]B
M86)I;&UE;G1E(&AA:2!D:6UE;G1I8V%T;R!U;B!C86UP;R!R:6-H:65S=&\N
M`$,GZ"!S=&%T;R!U;B!E<G)O<F4@;F5L;"=E<V5G=6ER92!L82!S<&5C:69I
M8V$@9G5N>FEO;F4@9&5L;&$@<G5B<FEC82X@4VD@<')E9V$@9&D@<FEP<F]V
M87)E('!I^2!T87)D:2X`0R?H('-T871O('5N(&5R<F]R92!N96QL)V%G9VEO
M<FYA;65N=&\@9&5I(&1E='1A9VQI(&1E;"!C;VYT871T;RX@4VD@<')E9V$@
M9&D@<')O=F%R92!P:?D@=&%R9&DN`$,GZ"!S=&%T;R!U;B!E<G)O<F4@;F5L
M;"=A9V=I;W)N86UE;G1O(&1E;&QA(&QI<W1A(&1I(&1I<W1R:6)U>FEO;F4N
M(%-I('!R96=A(&1I('!R;W9A<F4@<&GY('1A<F1I+@!1=65S=&\@<V5R=F5R
M($E-05`@;F]N('-U<'!O<G1A(&QA(&-O;F1I=FES:6]N92!D:2!C87)T96QL
M92X`475E<W1O('-E;6)R82!N;VX@97-S97)E('5N(&%R8VAI=FEO(&1I('1I
M<&\@<F%R('9A;&ED;RX`475E<W1O('-E;6)R82!N;VX@97-S97)E('5N(&9I
M;&4@9&D@=&EP;R!Z:7`@=F%L:61O+@!1=65S=&\@;F]N('-E;6)R82!E<W-E
M<F4@=6X@;G5M97)O(&1I(&-A<G1A('9A;&ED;RX`(%%U97-T;R!C86UP;R!P
M=?(@8V]N=&5N97)E('-O;&\@:6YT97)I+@`@475E<W1O(&-A;7!O('!U\B!C
M;VYT96YE<F4@<V]L;R!N=6UE<FD@92!D=64@<'5N=&DN`%%U97-T;R!C86UP
M;R!P=?(@97-S97)E('-O;&\@=6YA(&QI<W1A(&1I(&EN=&5R:2!S87!A<F%T
M:2!D82!V:7)G;VQA(&\@<W!A>FEO`%%U97-T;R!C86UP;R!D979E(&5S<V5R
M92!U;B!N=6UE<F\@=F%L:61O+@!1=65S=&\@8V%M<&\@9&5V92!C;VYT96YE
M<F4@=6X@8V]L;W)O(&EN(&9O<FUA=&\@4D="(&5S861E8VEM86QE+"!A9"!E
M<V5M<&EO("<C,3(S-&%F)RX`475E<W1A(&9O<FT@Z"!G:6$@<W1A=&$@<')O
M8V5S<V%T82X`475E<W1O(.@@)7,N`%%U97-T;R!M97-S86=G:6\@Z"!S=&%T
M;R!S8W)I='1O(&EN('5N('-E="!D:2!C87)A='1E<FD@*"5S*2!D:79E<G-O
M(&1A;"!T=6\N`%%U97-T;R!N=6UE<F\@9&5V92!E<W-E<F4@=6YI8V\N`%%U
M97-T;R!S97)V97(@;F]N('!U\B!D96-O;7!R:6UE<F4@9FEL92!I;B!F;W)M
M871O('II<"!E(&=Z:7`N`$%L(&UO;65N=&\@<75E<W1O('-I<W1E;6$@;F]N
M(.@@871T:79O+@!1=65S=&\@=F%L;W)E(&1E=F4@97-S97)E('5N(&YU;65R
M;RX`475E<W1A(&9I;F5S=')A(&1E=F4@97-S97)E(&-H:6%M871A(&1A('5N
M82!F:6YE<W1R82!D96QL92!/<'II;VYI`%1U;VYO`$)I9VQI971T:0!/<F$`
M1F]R;6%T;R!D96QL)V]R80!396QE>FEO;F4@9&5L;"=O<F$`5&ET;VQO`$$`
M4&5R('-E;&5Z:6]N97)E('!I^2!V;V-I+"!T:65N:2!P<F5M=71O(&EL('1A
M<W1O($-O;G1R;VP@*%!#*2!O($-O;6UA;F0@*$UA8RD@;65N=')I('-T86D@
M8VQI8V-A;F1O+@!/9V=I`$1O;6%N:0!4<F]P<&4@86-C97-S:2!N;VX@=F%L
M:61I(&1U<F5N=&4@9VQI('5L=&EM:2!M:6YU=&DN`$%L=&\`5')A9'5Z:6]N
M:0!697)O(&\@9F%L<V\`36$`5'5R8VAI80!$:6=I=&$@;&$@='5A('-C96QT
M83H@`$EM<&]S<VEB:6QE(&%C8V5D97)E(&%L;&$@9&ER96-T;W)Y(%9&4RX`
M26UP;W-S:6)I;&4@86=G:75N9V5R92!A;'1R92!I;F9O<FUA>FEO;FD@<W5G
M;&D@=71E;G1I(&UE;G1R92!D=7)A;G1E(&QA('-O='1O<V-R:7II;VYE+@!)
M;7!O<W-I8FEL92!C86UB:6%R92!I('!E<FUE<W-I('!E<B!I;"!F:6QE(%9&
M4R`B)7,B+@!);7!O<W-I8FEL92!C86UB:6%R92!I('!E<FUE<W-I('!E<B!I
M;"!F:6QE(%9&4R`E<R\E<RX`26UP;W-S:6)I;&4@8V%M8FEA<F4@82`E<RX`
M26UP;W-S:6)I;&4@=F5R:69I8V%R92!L82!D:6UE;G-I;VYE(&1I("(E<R(N
M`$EM<&]S<VEB:6QE('9E<FEF:6-A<F4@;&$@9&EM96YS:6]N92!D:2`B)7,O
M)7,B+@!);7!O<W-I8FEL92!C;VYN971T97)S:2!A;"!S97)V97(@4U%,+@!)
M;7!O<W-I8FEL92!C;VYN971T97)S:2!C;VX@4U-,+@!);7!O<W-I8FEL92!C
M;W!I87)E(&EL(&9I;&4@5D93+@!);7!O<W-I8FEL92!C<F5A<F4@;&$@9&ER
M96-T;W)Y(%9&4R`B)7,B+@!);7!O<W-I8FEL92!C<F5A<F4@;&$@9&ER96-T
M;W)Y(%9&4RX`26UP;W-S:6)I;&4@8W)E87)E(&EL(&9I;&4@5D93+@!);7!O
M<W-I8FEL92!C<F5A<F4@;&$@8V%R=&5L;&$@5D93("(E<R(N`$EM<&]S<VEB
M:6QE(&-R96%R92!I;"!F:6QE(%9&4R!V=6]T;RX`26UP;W-S:6)I;&4@9&5C
M;VUP<FEM97)E(&QE(&EN9F]R;6%Z:6]N:2X`26UP;W-S:6)I;&4@96QI;6EN
M87)E("(E<R(L(&QA(&1I<F5C=&]R>2!N;VX@Z"!V=6]T82X`26UP;W-S:6)I
M;&4@96QI;6EN87)E("(E<R(Z("5S+@!);7!O<W-I8FEL92!E;&EM:6YA<F4@
M)7,L(&QA(&1I<F5C=&]R>2!N;VX@Z"!V=6]T80!);7!O<W-I8FEL92!E;&EM
M:6YA<F4@;&$@9&ER96-T;W)Y(%9&4R!I;B!M;V1O(')I8V]R<VEV;RX`26UP
M;W-S:6)I;&4@96QI;6EN87)E(&QA(&1I<F5C=&]R>2!61E,N`$EM<&]S<VEB
M:6QE(&5L:6UI;F%R92!L82!D:7)E8W1O<GD@5D93.B`E<RX`24UP;W-S:6)I
M;&4@96QI;6EN87)E(&EL(&9I;&4@5D93("(E<R(N`$EM<&]S<VEB:6QE(&5L
M:6UI;F%R92!I;"!F:6QE(%9&4RX`26UP;W-S:6)I;&4@96QI;6EN87)E(&QA
M(&-A<G1E;&QA(%9&4R`B)7,B+@!);7!O<W-I8FEL92!E;&EM:6YA<F4@5D93
M(&EN(&UO9&\@<FEC;W)S:79O.B`E<RX`26UP;W-S:6)I;&4@9&5T97)M:6YA
M<F4@;&$@9&ER96-T;W)Y(&%T='5A;&4N`$EM<&]S<VEB:6QE(&5S=&%R<F4@
M:2!D971T86=L:2!D96P@8V5R=&EF:6-A=&\`26UP;W-S:6)I;&4@8V%R:6-A
M<F4@;&$@9&5F:6YI>FEO;F4@9&D@)7,N`$EM<&]S<VEB:6QE('-P;W-T87)E
M(&EL(&9I;&4@5D93+@!);7!O<W-I8FEL92!A<')I<F4@:6P@9FEL92!61E,@
M(B5S(BX`26UP;W-S:6)I;&4@87!R:7)E(&EL(&9I;&4@5D93('!E<B!L82!S
M8W)I='1U<F$N`$EM<&]S<VEB:6QE(&%P<FER92!I;"!F:6QE(%9&4RX`26UP
M;W-S:6)I;&4@87!R:64@;"=A<F-H:79I;R!C;VUP<F5S<V\N`$EM<&]S:6)I
M;&4@;&5G9V5R92!I;"!F:6QE(%9&4R`H9FEL97-I>F4@9FEL92@I(&9A:6QE
M9"DN`$EM<&]S<VEB:6QE(&QE9V=E<F4@:6P@9FEL92!61E,@*&=E=$9I;&53
M:7IE*"D@9F%I;&5D*2X`26UP;W-S:6)I;&4@;&5G9V5R92!I;"!F:6QE.B``
M26UP;W-S:6)I;&4@;&5G9V5R92!L82!D:7)E8W1O<GD@=F9S<F]O="X`26UP
M;W-S:6)I;&4@<FEN;VUI;F%R92`E<R!I;B`E<SH@;&$@8V%R=&5L;&$@9&D@
M9&5S=&EN87II;VYE(.@@9VEA('!R97-E;G1E`$EM<&]S<VEB:6QE(')I;F]M
M:6YA<F4@;&$@9&ER96-T;W)Y(%9&4RX`26UP;W-S:6)I;&4@<FEN;VUI;F%R
M92!L82!D:7)E8W1O<GD@5D93.B`E<RX`26UP;W-S:6)I;&4@<FEN;VUI;F%R
M92!I;"!F:6QE(%9&4R`B)7,B+@!);7!O<W-I8FEL92!R:6YO;6EN87)E(&EL
M(&9I;&4@5D93("5S+R5S+@!);7!O<W-I8FEL92!R:6YO;6EN87)E(&EL(&9I
M;&4@5D93+@!);7!O<W-I8FEL92!E<V5G=6ER92`G;6MI<V]F<R<N`$EM<&]S
M<VEB:6QE('1R861U<G)E('%U97-T;R!D;V-U;65N=&\@5V]R9`!);7!O<W-I
M8FEL92!D87)E(&PG879V:6\@86QL)V%G9VEO<FYA;65N=&\@9G)E92]B=7-Y
M('!E<B`E<P!);7!O<W-I8FEL92!S8W)I=F5R92!I;"!F:6QE(%9&4R`B)7,B
M+@!);7!O<W-I8FEL92!S8W)I=F5R92!I;"!F:6QE(%9&4R`H8V]P>2@I(&9A
M:6QE9"DN`$EM<&]S<VEB:6QE('-C<FEV97)E(&QE(&EN9F]R;6%Z:6]N:2!N
M96P@9FEL92!61E,N`$EM<&]S<VEB:6QE('-C<FEV97)E(&EL(&9I;&4@5D93
M+"!L82!Q=6]T82!C;VYS96YT:71A('9E<G+@(&5C8V5D=71A+@!3;W1T;VQI
M;F5A=&\`06YN=6QL82!-;V1I9FEC:&4`3F]N(&9A<F4@;&$@='5A('5L=&EM
M82!A>FEO;F4`4FES<&]S=&$@:6YA='1E<V$@9&%L('-E<G9E<B!D=7)A;G1E
M(&QA(&-O;FYE<W-I;VYE.B``4FES<&]S=&$@:6YA='1E<V$@9&%L('-E<G9E
M<B!A.B``4V-O;F]S8VEU=&\`3F]M92!U=&5N=&4@92!P87-S=V]R9"!S8V]N
M;W-C:75T:0!.;VX@8V]L;&5G87)E(&PG96QE;65N=&\@8V]R<F5N=&4`4V5N
M>F$@;F]M90!%<W1E;G-I;VYE(&YO;B!S=7!P;W)T871A`$%G9VEO<FYA`$%G
M9VEO<FYA("5S`$%G9VEO<FYA('5T96YT90!!9V=I;W)N82`B)7,B+@!38W)I
M<'0@9&D@8V%R:6-A;65N=&4@96QI;6EN871A+@!#87)I8V$`8V%R:6-A=&D@
M='5T=&D@:2!F:6QE(&1I(&EM<&]S=&%Z:6]N92!D96QL92!A<'!L:6-A>FEO
M;FD@<W5L('-E<G9E<BX`8V%R871T97)I(&QA=&EN:2!M86EU<V-O;&D`3G5M
M97)I(')O;6%N:2!M86EU<V-O;&D`=7-A(&EL(&-O<G)E;G1E.B`E<P!5<V$@
M4U-,`%5S82!S92!I;"!N;VUE('5T96YT92]P87-S=V]R9"#H(&1I9F9E<F5N
M=&4@9&$@<75E;&QA(&1E;"!S97)V97(@24U34"X`571E;G1E`$QU=&5N=&4@
M)7,@;F]N(.@@875T;W)I>GIA=&\@<&5R("5S+@!'97-T:6]N92!5=&5N=&D`
M3W!Z:6]N:2!5=&5N=&D`4F5G:7-T<F%Z:6]N92!5=&5N=&D`3&%R96=I<W1R
M87II;VYE(&1E9VQI('5T96YT:2#H('-T871A(&1I<V%B:6QI=&%T82!P97(@
M<75E<W1O('-I=&\N`$YO;64@=71E;G1E(&YO;B!T<F]V871O`$YO;64@571E
M;G1E`$YO;64@571E;G1E("(E<R(@Z"!G:6$@<')E<V5N=&4N`$YO;64@571E
M;G1E.@!.;VUE(%5T96YT93H@`%5T96YT:2!N96P@<VES=&5M83H`3&$@9&ER
M96-T;W)Y(%9&4R!N;VX@97-I<W1E+@!!<W-E;GIA`%!O<VEZ:6]N:2!V86QI
M9&4@=')O=F%T92!I;F-L=61O;F\Z(`!686QI9&ETX`!686QO<F4@:6X@;6EN
M=71I(&1A(&]R82X`26P@=F%L;W)E(.@@;6%G9VEO<F4@9&QL82!M87-S:6UA
M(&QU;F=H97IZ82!D:2`E<RX`5F%L;W)I`%9A;&]R:2!D86D@<75A;&D@<V5L
M97II;VYA<F4`5F%R:6%B:6QE`%9E<FEF:6-A(&9A;&QI=&$@+2!Q=65S=&\@
M;65S<V%G9VEO('!U\B!E<W-E<F4@<W1A=&\@86QT97)A=&\@8V]N+@!697)S
M:6]N90!697)S:6]N92!D:2!#;VYT<F]L;&\`06QL:6YE86UE;G1O('9E<G1I
M8V%L90!2:65M<&EM96YT;R!V97)T:6-A;&4`5F5R=&EC86QE.@!-;VQT;R!!
M;'1O`%9I<W5A;&EZ>F$@)7,`5FES=6%L:7IZ82!U;F$@<&%G:6YA('=E8B!E
M<W1E<FYA`%9I<W5A;&EZ>F$@8V]M92`E<P!6:7-I8FEL:73@`%9I<VEB:6QI
M=.`Z(`!!5%1%3EI)3TY%`$%45$5.6DE/3D4A(2$@4DE-54]622!,3R!30U))
M4%0@34%.54%,345.5$4@1$$@)7,N`$%T=&5N>FEO;F4`364`0F]L;&5T=&EN
M;R!M971E;W)O;&]G:6-O`$)O;&QE='1I;F\@;65T96]R;VQO9VEC;R!F;W)N
M:71O(&1A`%-E='1I;6%N86QM96YT90!"96YV96YU=&\`0F5N=F5N=71O(&$@
M)7,`0F5N=F5N=71O+"`E<P!1=6%L92!A<'!L:6-A>FEO;F4@9&]V<N`@=FES
M=6%L:7IZ87)E("5S(&1O<&\@;"=A8V-E<W-O/P!1=6%L)^@@:6P@8V%R871T
M97)E(&1I(&1E;&EM:71A>FEO;F4_`%%U86QE('!L=6=I;G,@86)I;&ET87)E
M('!E<B!I;"!2:6-H(%1E>'0@961I=&]R+@!,87)G:&5Z>F$`3&%R9VAE>GIA
M(&EN('5N:73@($-34P!,87)G:&5Z>F$@9&5L(&UE;G4@9&D@)7,@<W5L;&$@
M<VEN:7-T<F$@*&%V<N`@969F971T;R!C;VP@<')O<W-I;6\@86-C97-S;RDZ
M`$QA<F=H97IZ82!D96QL82!T86)E;&QA`%5N:73@(&1I(&QA<F=H97IZ80!,
M87)G:&5Z>F$Z`%9E;G1O`%9E;&]C:73@(&1E;"!V96YT;R!I;B!N;V1I`%9E
M;G1O.@!696YT;SH@`%-A9V=E>GIA`$QA=F]R;P!);F1I<FEZ>F\@9&5L(&QA
M=F]R;P!496QE9F]N;R!D96P@;&%V;W)O`$YU;65R;R!D:2!C86UP:2!E<G)A
M=&\@;F5L;&$@;&EN96$@)60N($%T=&5S:2`E9"P@=')O=F%T:2`E9"X`3G5M
M97)O(&1I(&-A;7!I(&5R<F%T;RX@071T97-I("5D+"!T<F]V871I("5D+@!#
M;VUP96YS87II;VYE('-B86=L:6%T82`E9"!D=7)A;G1E(&QA(&QE='1U<F$@
M9&D@=6X@9FEL92!61E,N`$%N;G5A;&UE;G1E`%-I`%-I+"!S;VYO(&0G86-C
M;W)D;P!396D@:6X@9F]R;6%T;R!T97-T;RX@57-A(&EL(&)O='1O;F4@6SP^
M72!P97(@=&]R;F%R92!A;"!F;W)M871O(%=94TE764<N`$YO;B!H86D@:6P@
M<&5R;65S<V\@9&D@8W)E87)E('!I^2!D:2`E9"!B;&]C8VAI+@!.;VX@=&D@
M<V5I(&%U=&5N=&EC871O+@!.;VX@<'5O:2!A=F5R92!I;"!C87)A='1E<F4@
M)UPG(&YE;"!T=6\@;F]M92!C;VUP;&5T;RX`3F]N(&AA:2!I;G-E<FET;R!U
M;B!I;F1I<FEZ>F\@96UA:6P@=F%L:61O+@!.;VX@:&%I(&%S<V]C:6%T;R!N
M97-S=6X@9&5I(&-A;7!I(&1A;"!F:6QE(&EM<&]R=&%T;R!C;VX@:2!C86UP
M:2!C;W)R:7-P;VYD96YT:2!I;B`E<RX`4V5I('-T871O(&1I<V-O;FYE<W-O
M+@!$979I(&EN<V5R:7)E('5N(&YU;65R;R!D:2!C96QL=6QA<F4@=F%L:61O
M+"!C;VYT96YE;G1E('-O;&\@;G5M97)I(&-O;B!L)V]P>FEO;F4@9&5L("<K
M)R!P97(@:2!P<F5F:7-S:2!I;G1E<FYA>FEO;F%L:2X`1&5V:2!I;G-E<FER
M92!U;B!V86QO<F4@=F%L:61O+@!$979I(&-O;F9I9W5R87)E('5N(&)A8VME
M;F0@<&5R(&EL($1A=&%4<F5E('!E<B!U<V%R92!3:6=N=7!S+@!$979I(&-O
M;F9I9W5R87)E('5N(&)A8VME;F0@5D93+@!$979I('!R:6UA(&1E<V-R:79E
M<F4@:6P@<')O8FQE;6$@<')I;6$@9&D@;6%N9&%R;&\@8V]M92!R97!O<G0N
M`$1E=FD@:6YS97)I<F4@;"=54DP@86QL82!Q=6%L92!P=6YT82!Q=65S=&\@
M8V]L;&5G86UE;G1O`$1E=FD@<V5L97II;VYA<F4@=6X@<V5R=F5R(&1A(&5L
M:6UI;F%R92X`1&5V:2!S<&5C:69I8V%R92!U;B!U=&5N=&4@9&$@87IZ97)A
M<F4N`$1E=FD@<W!E8VEF:6-A<F4@=6X@=71E;G1E(&1A(')I;75O=F5R92X`
M1&5V:2!S<&5C:69I8V%R92!U;B!U=&5N=&4@9&$@86=G:75N9V5R92X`1&5V
M:2!S<&5C:69I8V%R92!U;B!U=&5N=&4@9&$@86=G:6]R;F%R92X`1&5V:2!S
M<&5C:69I8V%R92!U;B=A>FEO;F4@9&$@97-E9W5I<F4N`$1E=FD@<W!E8VEF
M:6-A<F4@:6P@;F]M92!D96QL82!N=6]V82!C871E9V]R:6$N`$1E=FD@:6YS
M97)I<F4@=6X@;G5M97)O(&1I('1E;&5F;VYO(&ET86QI86YO`$QA('1U82!S
M97-S:6]N92`E<R#H('-C861U=&$N(%-I('!R96=A(&1I(&-O;&QE9V%R<VD@
M;G5O=F%M96YT92X`26P@='5O(&EN9&ER:7IZ;R!%;6%I;`!);"!C86UP;R!$
M83H@9&5L('1U;R!I;F1I<FEZ>F\Z`$QE('1U92!I;F9O<FUA>FEO;FD`26P@
M='5O(&EN9&ER:7IZ;R!);G1E<FYE="#H(&-A;6)I871O(&1A;&PG:6YI>FEO
M(&1E;&QA('1U82!S97-S:6]N92`E<RX@4&5R('!R;W1E9V=E<F4@;&$@='5A
M('-I8W5R97IZ82P@9&5V:2!R:6-O;&5G87)T:2!N=6]V86UE;G1E+@!);"!T
M=6\@3F]M90!);"!T=6\@8F%C:V5N9"!D:2!A=71E;G1I8V%Z:6]N92!N;VX@
M<W5P<&]R=&$@;"=A9V=I=6YT82!D:2!N=6]V:2!U=&5N=&DN(%-E('9U;VD@
M=7-A<F4@2&]R9&4@<&5R(&=E<W1I<F4@9VQI('5T96YT:2P@9&5V:2!U<V%R
M92!U;B!B86-K96YD(&1I(&%U=&5N=&EC87II;VYE(&1I9F9E<F5N=&4`26P@
M='5O(&)A8VME;F0@9&D@875T96YT:6-A>FEO;F4@;F]N('-U<'!O<G1A(&PG
M96QE;F-O(&1E9VQI('5T96YT:2P@;R!L82!F=6YZ:6]N92#H('-T871A(&1I
M<V%B:6QI=&%T82!P97(@86QT<F4@<F%G:6]N:2X`4V5M8F9R82!C:&4@:6P@
M='5O(&)R;W=S97(@<VEA(&-A;6)I871A(&1A;&PG:6YI>FEO(&1E;&QA('1U
M82!S97-S:6]N92`E<RX@4&5R('!R;W1E9V=E<F4@;&$@='5A('-I8W5R97IZ
M82P@9&5V:2!A8V-E9&5R92!N=6]V86UE;G1E+@!);"!T=6\@8G)O=W-E<B!N
M;VX@<W5P<&]R=&$@<75E<W1A(&9U;GII;VYE+@!);"!T=6\@8G)O=W-E<B!N
M;VX@<W5P<&]R=&$@<75E<W1A(&]P>FEO;F4@9&D@<W1A;7!A+B!0<F5M:2!#
M;VYT<F]L+T-O;6UA;F0@*R!0('!E<B!S=&%M<&%R92X`26P@='5O(&9U<V\@
M;W)A<FEO.@!,82!T=6$@:61E;G1I=.`@9&D@9&5F875L="#H('-T871A(&UO
M9&EF:6-A=&$N`$QA('1U82!I9&5N=&ETX"!D:2!D969A=6QT.@!);"!T=6\@
M;F]M92!C;VUP;&5T;SH`3&$@='5A(&QO9VEN(.@@<V-A9'5T82X`3&$@='5A
M(&YU;W9A('!A<W-W;W)D('!E<B`E<R#H.B`E<P!,92!T=64@;W!Z:6]N:2!S
M;VYO('-T871E(&%G9VEO<FYA=&4@<&5R(&QA(&1U<F%T82!D:2!Q=65S=&$@
M<V5S<VEO;F4N`$QE('1U92!O<'II;VYI('-O;F\@<W1A=&4@86=G:6]R;F%T
M92X`3&$@='5A('!A<W-W;W)D(.@@<W1A=&$@87IZ97)A=&$`3&$@='5A('!A
M<W-W;W)D(.@@<W1A=&$@87IZ97)A=&$L(&-O;G1R;VQL82!L82!T=6$@96UA
M:6P@92!A8V-E9&D@8V]N(&QA('1U82!N=6]V82!P87-S=V]R9"X`3&$@='5A
M('!A<W-W;W)D(.@@<V-A9'5T82X`22!T=6]I('-E<G9E<B!R96UO=&DZ`%M.
M87-C;VYD:2!I;"!T97-T;R!C:71A=&]=`%M297!O<G0@9&5L('!R;V)L96UA
M70!;36]S=')A(&EL('1E<W1O(&-I=&%T;R`M`%M-;W-T<F$@:6P@=&5S=&\@
M8VET871O("T@)7,@;&EN965=`%ML:6YE82`E<R!D:2`E<UT`7T%M;6EN:7-T
M<F%Z:6]N90!?0V%N8V5L;&$@4FEG80!?1W)U<'!I`%]!:75T;P!P<F]P<FEE
M=.`@9&5L;"=?26UM86=I;F4N+BX`7T5N=')A`%]%<V-I`%]-;V1I9FEC82!#
M;VQL96=A;65N=&\N+BX`7T]P>FEO;FD`7U!E<FUE<W-I`%]%;&EM:6YA($-O
M;&QE9V%M96YT;RXN+@!?26UP;W-T87II;VYE`%!R;W!R:65TX"!D96QL82!?
M5&%B96QL82XN+@!5=&5N=&D`<G5B<FEC80!I;F1I<FEZ>FD@<V-O;F]S8VEU
M=&D`8V%L96YD87)I;P!C86QM;P!N;VX@<&]S<V\@8W)E87)E(&EL(&9I;&4@
M9&D@;W5P=70`;F]N('!O<W-O(&%P<FER92!L)VEN<'5T`'!R96UI('%U:0!E
M<G)O<F4@;F5L;"=U<V\@9&5L;&$@;&EN96$@9&D@8V]M86YD;P!E<G)O<F4@
M9&D@8V]N9FEG=7)A>FEO;F4`97)R;W)E(&YE;"!F;W)M871O(&1E;&QA(&1A
M=&$`=FES=6%L:7IZ82!P<F5V:7-I;VYE("AT868I`'!U8F)L:6-A`&5N=')Y
M(&YO;B!T<F]V871A`&1A;"`E<R`H)7,I(&%L("5S("5S`&YO;64@:&]S="!S
M8V]N;W-C:75T;P!I;6UE9&EA=&\`97)R;W)E(&1I(&EN<'5T+V]U='!U=`!E
M<G)O<F4@:6YT97)N;R!D96P@<V]F='=A<F4`;&EN965=`&5R<F]R92!D:2!C
M;V1I8V4@)60@9&D@;6MI<V]F<R!D=7)A;G1E(&QA('-C<FET=&]R82!)4T\N
M`&YO;64`;F]N(&EM<&QE;65N=&%T;P!N;VX@86YC;W)A(&EM<&QE;65N=&%D
M;P!B;&]C8V\@;F]T90!P97)C96YT;P!P97)M97-S;R!N96=A=&\`97)R;W)E
M(')E;6]T;R!N96P@<')O=&]C;VQL;P!S97)V:7II;R!N;VX@9&ES<&]N:6)I
M;&4`;6]S=')A(&QE(&1I9F9E<F5N>F4`8V]S=&%N=&4`97)R;W)E(&1I('-I
M<W1E;6$`96QE;F-O(&%T=&EV:73@`&=U87-T;R!T96UP;W)A;F5O`'-C<FEV
M:2!L82!P87-S=V]R9"!D=64@=F]L=&4@<&5R(&-O;F9E<FUA<F4`=6YI9FEC
M871O`'-E;GIA(&YO;64`=71E;G1E('-E;&5Z:6]N871O`'<Z`'=E871H97(N
M8V]M````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&]C86QE+VET7TE4+VAE;'`N>&UL````````````````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`T-#(W(#$P-3$U-#,S-S0Q(#`R,30V-@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/WAM
M;"!V97)S:6]N/2(Q+C`B(&5N8V]D:6YG/2)I<V\M.#@U.2TQ(C\^"CPA+2T@
M)$AO<F1E.B!H;W)D92]L;V-A;&4O:71?250O:&5L<"YX;6PL=B`Q+C(N,3`N
M,B`R,#`U+S$P+S$X(#$Q.C,S.C0S(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@
M/&5N=')Y(&ED/2)S=6UM87)Y(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB-CAC
M83,S9C=F,&,Y86%E-&,Q,#-E8C0W-#DR8V1C,34B/@H\=&ET;&4^4&%G:6YA
M(&1I(&EN9W)E<W-O(&1E;"!P;W)T86QE/"]T:71L93X*(#QP87)A/@H@(%%U
M97-T82!P86=I;F$@9&D@:6YG<F5S<V\@9&5L('!O<G1A;&4@9F]R;FES8V4@
M=6X@8G)E=F4@<V]M;6%R:6\@9&D@='5T=&4@;&4@='5E"B`@:6YF;W)M87II
M;VYI(&EM<&]R=&%N=&DN($%D(&5S96UP:6\L('1I('!U\B!M;W-T<F%R92!Q
M=6%N=&D@;G5O=FD@;65S<V%G9VD@8VD*("!S;VYO(&YE;&QA('1U82!)3D)/
M6"P@:2!P<F]S<VEM:2!E=F5N=&D@;F5L('1U;R!C86QE;F1A<FEO+"!L92!A
M='1I=FETX"!N96QL80H@('1U82!L:7-T82P@;&4@=6QT:6UE(&YO=&EZ:64@
M9&$@<V5R=FEZ:2!S96QE>FEO;F%T:2!E(&-O<^P@=FEA+B!-;VQT:2!D:2!Q
M=65S=&D*("!S;VUM87)I(&-O;G1E<G)A;FYO(&1E:2!C;VQL96=A;65N=&D@
M82!F=6YZ:6]N:2!C;VUU;FDL('%U86QI(&%D(&5S96UP:6\@;&$@8V]M<&]S
M:7II;VYE"B`@9&D@=6YA(&YU;W9O(&UE<W-A9V=I;RP@;&$@8W)E87II;VYE
M(&1I('5N;R!N=6]V;R!E=F5N=&\@9&$@:6YS97)I<F4@;F5L(&-A;&5N9&%R
M:6\*("!O(&QA(&-R96%Z:6]N92!D:2!U;F$@;G5O=F$@871T:79I=.`@9&$@
M:6YS97)I<F4@;F5L;&$@;&ES=&$L(&5C8RX*(#PO<&%R83X*(#QP87)A/@H@
M($D@8V]N=&5N=71I(&1I('%U97-T82!P86=I;F$@9&5L('!O<G1A;&4@<V]N
M;R!P97)S;VYA;&EZ>F%B:6QI('1R86UI=&4@:6P@8F]T=&]N92!&;W)M871O
M+@H@($%D(&5S96UP:6\L('!U;VD@<V-E9VQI97)E('%U86QI(&EN9F]R;6%Z
M:6]N:2!I;G-E<FER92!N96QL82!P86=I;F$@8V]M92!A;F-H92!I;@H@('%U
M86QE(&]R9&EN92!V97)R86YN;R!M;W-T<F%T92X*(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](FYA=F)A<B(@<W1A=&4](G5P=&]D871E(B!M9#4]
M(F(X8V8P864Q.64U-V1F83!C,F(Y-C)E-3$V-S@R9C0W(CX*/'1I=&QE/DQA
M(&)A<G)A(&1I(&YA=FEG87II;VYE(&1E;&QE(&%P<&QI8V%Z:6]N:3PO=&ET
M;&4^"B`\<&%R83X*("!3=6QL82!S:6YI<W1R82!D96QL82!P86=I;F$@=V5B
M(.@@<')E<V5N=&4@;&$@8F%R<F$@9&D@;F%V:6=A>FEO;F4@9&5L;&4@87!P
M;&EC87II;VYI+@H@($-L:6-C82!S=6QL)VEC;VYA('!R97-E;G1E(&YE;&QA
M(&)A<G)A(&1I(&YA=FEG87II;VYE('!E<B!P87-S87)E(')A<&ED86UE;G1E
M(&4*("!V96QO8V5M96YT92!T<F$@;&4@=F%R:64@87!P;&EC87II;VYI(&1I
M<W!O;FEB:6QI+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E
M9G,M9&]?;6%I;G1E;F%N8V4B('-T871E/2)U<'1O9&%T92(@;60U/2)D9#DU
M9&8P-V$P,S`S,3(S,F)A96$Y,3DR.#AB,F0P,"(^"B`@("`\=&ET;&4^4')E
M9F5R96YZ93H@36%N=71E;GII;VYE.B!%<V5G=6D@;&$@;6%N=71E;GII;VYE
M/"]T:71L93X*("`@(#QP87)A/@H@("`@4V4@=G5O:2!E<V5G=6ER92!L92!O
M<&5R87II;VYI(&1I(&UA;G5T96YZ:6]N92!A<'!E;F$@96YT<F%T;R!N96P@
M<&]R=&%L92P*("`@('-E;&5Z:6]N92!Q=65S=&$@8V%S96QL82X*("`@(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6-O;F9I<FU?;6%I
M;G1E;F%N8V4B('-T871E/2)U<'1O9&%T92(@;60U/2)A,C$Q-C)C9&9F,V(Q
M9#AF865A9&(W,CDV,C0P,#,V92(^"B`@("`\=&ET;&4^4')E9F5R96YZ93H@
M36%N=71E;GII;VYE.B!#;VYF97)M82!L82!M86YU=&5N>FEO;F4\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("!392!D97-I9&5R:2!C:&4@=F5N9V$@8VAI97-T
M82!L82!C;VYF97)M82!P<FEM82!C:&4@='5T=&4@;&4@;W!E<F%Z:6]N:2!D
M:2!M86YU=&5N>FEO;F4@"B`@("!V96YG86YO(&5S96=U:71E+"!S96QE>FEO
M;F$@<75E<W1A(&-A<V5L;&$N"B`@("!392!L82!C87-E;&QA(&YO;B!V:65N
M92!S96QE>FEO;F%T82P@='5T=&4@;&4@;W!E<F%Z:6]N:2!D:2!M86YU=&5N
M>FEO;F4@8VAE('-O;F\*("`@('!R;V=R86UM871E('9E<G)A;FYO(&5S96=U
M:71E(&%U=&]M871I8V%M96YT92!S96YZ82!L82!P;W-S:6)I;&ETX"!D:2!C
M86YC96QL87)L90H@("`@<75A;F1O('-I(&5N=')A(&YE;"!P;W)T86QE+@H@
M("`@/"]P87)A/@H\+V5N=')Y/@H\+VAE;'`^"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&]C86QE+V)G7T)'````````````````````````
M````````````````````````````````````````````````````````````
M`#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S
M-S0Q(#`Q-S8U-@`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O8F=?0D<O
M3$-?34534T%'15,`````````````````````````````````````````````
M````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`P,#`@,3`U,34T,S,W-#$@,#(Q-#0S`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQO8V%L92]B9U]"1R],0U]-15-304=%4R]H;W)D92YM;P``````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`T,C8Q,2`Q,#4Q-30S,S<T,2`P,C,Q-C0`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````WA($
ME0````#Z````'````.P'``!1`0``O`\`````````%0``#@````$5```(````
M$!4```P````9%0``"P```"85```H````,A4``!4```!;%0``#@```'$5```(
M````@!4``#(```")%0``.````+P5``!4````]14``%$```!*%@``-````)P6
M```%````T18```T```#7%@``$@```.46```/````^!8``!D````(%P``!P``
M`"(7```,````*A<```X````W%P```P```$87```%````2A<```H```!0%P``
M#P```%L7```?````:Q<``!$```"+%P``#````)T7```Y````JA<``"<```#D
M%P``+`````P8```J````.1@```H```!D&```%0```&\8```I````A1@``!$`
M``"O&```%@```,$8```6````V!@```@```#O&```!````/@8```)````_1@`
M``,````'&0```P````L9```(````#QD``"`````8&0``!@```#D9```*````
M0!D```P```!+&0``!@```%@9```'````7QD``!````!G&0``*P```'@9```$
M````I!D``!X```"I&0``&P```,@9```;````Y!D``#,`````&@``+P```#0:
M```I````9!H```,```".&@```@```)(:```%````E1H``!````";&@``!@``
M`*P:```O````LQH```\```#C&@``!````/,:```%````^!H```T```#^&@``
M&P````P;```-````*!L```4````V&P``$````#P;```0````31L```\```!>
M&P``"P```&X;```/````>AL```P```"*&P``#P```)<;```>````IQL``"$`
M``#&&P``(````.@;```#````"1P``!,````-'```%````"$<```,````-AP`
M``D```!#'```&P```$T<```'````:1P```8```!Q'```"0```'@<```4````
M@AP```8```"7'```$0```)X<```>````L!P```0```#/'```!````-0<```,
M````V1P```H```#F'```!0```/$<```@````]QP``"`````8'0``)@```#D=
M```I````8!T```H```"*'0``#P```)4=```2````I1T``!````"X'0``%P``
M`,D=```&````X1T```P```#H'0``#````/4=```-`````AX``"@````0'@``
M*P```#D>```(````91X``!````!N'@``&@```'\>```&````FAX```<```"A
M'@```@```*D>```E````K!X```0```#2'@``#P```-<>```'````YQX```H`
M``#O'@``!P```/H>```&`````A\```D````)'P``#0```!,?```'````(1\`
M``H````I'P``!````#0?```'````.1\```4```!!'P``%P```$<?```"````
M7Q\``#,```!B'P``,P```)8?```X````RA\``"T````#(```,0```#$@```L
M````8R```!H```"0(```"0```*L@```%````M2````(```"[(```!P```+X@
M```,````QB```!$```#3(```$0```.4@```)````]R````@````!(0``"0``
M``HA```*````%"$``!4````?(0``!0```#4A```H````.R$```L```!D(0``
M&@```'`A```%````BR$``"````"1(0``,@```+(A```%````Y2$```0```#K
M(0``,@```/`A```J````(R(```8```!.(@``#P```%4B```$````92(```D`
M``!J(@```P```'0B```5````>"(``!(```".(@``#P```*$B```4````L2(`
M`!H```#&(@``%P```.$B```7````^2(``!L````1(P``&0```"TC```?````
M1R,``%<```!G(P``!````+\C```$````Q",``!<```#)(P``!@```.$C```'
M````Z",```4```#P(P``"0```/8C``!*`````"0``#@```!+)```2````(0D
M``!)````S20``#`````7)0``:0```$@E```]````LB4``&4```#P)0``30``
M`%8F```N````I"8``"\```#3)@``+`````,G```7````,"<``"4```!()P``
M,@```&XG```^````H2<``"4```#@)P``(0````8H```P````*"@``!P```!9
M*```#0```'8H```%````A"@```,```"**```(````(XH```B````KR@``"4`
M``#2*```)@```/@H```)````'RD```8````I*0``"0```#`I```3````.BD`
M``@```!.*0``"0```%<I```*````82D``!0```!L*0``"````($I```_````
MBBD```<```#**0``!@```-(I```-````V2D```L```#G*0``+P```/,I```,
M````(RH```H````P*@```@```#LJ```&````/BH```,```!%*@``*````$DJ
M```F````<BH``"4```"9*@``*````+\J```0````Z"H``',```#Y*@``'P``
M`&TK```4````C2L```\```"B*P``!````+(K```'````MRL```4```"_*P``
M4@$``,4K```/````&"T```<````H+0``"````#`M```.````.2T``"4```!(
M+0``'````&XM```,````BRT```<```"8+0``-0```*`M```U````UBT``%(`
M```,+@``3P```%\N```W````KRX```4```#G+@``%@```.TN```6````!"\`
M`!8````;+P``)@```#(O```%````62\``!````!?+P``#@```'`O```'````
M?R\```D```"'+P``#````)$O```,````GB\``",```"K+P``%P```,\O```-
M````YR\``#<```#U+P``+0```"TP```M````6S```"\```"),```"````+DP
M```8````PC```#(```#;,```#P````XQ```;````'C$``"4````Z,0``"@``
M`&`Q```)````:S$```<```!U,0```P```'TQ```#````@3$```@```"%,0``
M)@```(XQ```&````M3$```\```"\,0``$````,PQ```'````W3$```@```#E
M,0``$P```.XQ```I`````C(```<````L,@``)0```#0R```E````6C(``"<`
M``"`,@``)0```*@R```Z````SC(``#4````),P``!@```#\S```"````1C,`
M``D```!),P``&P```%,S```&````;S,``"X```!V,P``#0```*4S```(````
MLS,```4```"\,P``"P```,(S```B````SC,``!````#Q,P``!@````(T```/
M````"30``!`````9-```#@```"HT```-````.30``!0```!'-```#````%PT
M```3````:30``"D```!]-```,@```*<T```D````VC0```0```#_-```%0``
M``0U```6````&C4```P````Q-0``"P```#XU```F````2C4```8```!Q-0``
M!@```'@U```+````?S4``!<```"+-0``!0```*,U```.````J34``"$```"X
M-0``!0```-HU```&````X#4```T```#G-0``#P```/4U```%````!38``"\`
M```+-@``+P```#LV```\````:S8``"8```"H-@``"@```,\V```-````VC8`
M`!0```#H-@``$P```/TV```?````$3<```D````Q-P``$@```#LW```1````
M3C<``!(```!@-P``*@```',W```M````GC<```0```#,-P``"@```-$W```A
M````W#<```0```#^-P``!0````,X```"````"3@``"T````,.```!````#HX
M```0````/S@```<```!0.```#@```%@X```%````9S@```4```!M.```"```
M`',X```1````?#@```<```"..```"@```)8X```#````H3@```4```"E.```
M!@```*LX```C````LC@```(```#6.```)@```-DX```F`````#D``"L````G
M.0``*P```%,Y```O````?SD``#4```"O.0``&0```.4Y```.````_SD```<`
M```..@```@```!8Z```%````&3H```\````?.@``$````"\Z```4````0#H`
M``D```!5.@``!@```%\Z```'````9CH```@```!N.@``$@```'<Z```&````
MBCH``#(```"1.@``!0```,0Z```9````RCH```<```#D.@``'@```.PZ```W
M````"SL```H```!#.P``!@```$X[``!"````53L``"D```"8.P``"````,([
M```7````RSL```0```#C.P``"0```.@[```#````\CL``!H```#V.P``(```
M`!$\```/````,CP``!T```!"/```&0```&`\```:````>CP``!@```"5/```
M'@```*X\```C````S3P``"0```#Q/```:````!8]```)````?ST```8```")
M/0``'@```)`]```'````KST```4```"W/0``!@```+T]```*````Q#T``$<`
M``#//0``*P```!<^``!)````0SX``%<```"-/@``+P```.4^``!?````%3\`
M`#4```!U/P``80```*L_```_````#4```"<```!-0```'````'5````;````
MDD```!<```"N0```*@```,9````Q````\4```$4````C00``(````&E!```D
M````BD$``#<```"O00``(````.=!```5````"$(```@````>0@```P```"="
M```D````*T(``"L```!00@``)0```'Q"```H````HD(```H```#+0@``!P``
M`-9"```*````WD(``!\```#I0@```P````E#```$````#4,```4````20P``
M&````!A#```(````,4,``#T````Z0P``"````'A#```(````@4,``!````"*
M0P``#P```)M#```T````JT,```P```#@0P``#@```.U#```"````_$,```<`
M``#_0P```@````=$```A````"D0``"L````L1```*@```%A$```M````@T0`
M`!$```"Q1```90```,-$```K````*44```\```!510``$````&5%```$````
M=D4```<```![10``!0```(-%```!`````````+<```":````/````.4```"G
M````=````````````````````(H`````````E@```%````!W`````````%$`
M``".````9P```!(```!S```````````````H````KP```)`````=````"0``
M``\```!_```````````````_````;@```!L```!+````9@````````#V````
M`````"H````M`````````%L`````````5````/4`````````B0```$D```!]
M`````````*H```!%````K````'L```#S`````````,X```!M````-0```.\`
M````````K@```.<```"&````,P```),```"M````6@````````#R````8```
M`$,```!V`````````$P``````````````$<`````````(````#H````Y````
MV@`````````X````&@```#(```"+````30``````````````8P```&\```"K
M````[@```.````!A````````````````````9`````````#,````7@```-``
M```N````<@```.@``````````````#8```#=````HP```-L```",````````
M``````#3````5P```!0```#)````U`````(```"9````!````!`````>````
MW@```+4``````````````*(```!*````SP```"$```"5`````````%@````F
M````"@```"\````E````/@```+D```"!`````````!D```!H````^@```&H`
M``#5````M`````````"Q````%P```.8`````````D@````````!3````1@``
M`-\```"E`````````%P`````````60```)P```#+``````````````"I````
MR````.P````B`````````&4```"R````[0```'X```!L`````````.(```#$
M````$P``````````````````````````````M@````````""````Z@```/$`
M``#K````D0```'$```"=``````````````#<````L````!4```"@````T@``
M`!8```#-`````````+X```"X````]````(<```">````Q0````````!!````
M`````)<`````````,0```(T```!X````OP````````#C``````````X```!=
M````T0```$(`````````.P```.$```!U``````````````!(````4@```$\`
M``"/``````````````!P````"`````T````T````5@```",`````````````
M``````!5````V0```/D```#X````V`````````"?````$0```-<```"\````
MQP```-8```"A````/0```"L```"H````'`````4````#````"P```,8```"S
M`````````+T`````````P0````````#*`````````/````"`````&````)@`
M``"Z`````````&L```````````````````!\````>0```$``````````>@``
M`"0```#D````@P```.D`````````A0```&(````P````'P```/<`````````
M``````P```"(````*0```+L```";`````````$0`````````PP```(0````W
M````I````,`````G`````````)0```!I````!@````<```!.````````````
M```L````P@```*8```!?`````"`H)7,@9&%Y<R!A9V\I`"`H=&]D87DI`"`H
M>65S=&5R9&%Y*0`E<R`M($YO=&EC90`E<R!-86EN=&5N86YC92!/<&5R871I
M;VYS("T@0V]N9FER;6%T:6]N`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!I
M<R!R97%U:7)E9``R-"!H;W5R<P!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES
M(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI
M8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0
M(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I
M<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04TO4$T`061D($YE
M=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@;F5W('5S97(Z`$%D
M9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`
M061M:6YI<W1R871I;VX`061S`$%L:6%S`$%L;"!'<F]U<',`06QL(%!E<FUI
M<W-I;VYS`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`07)C:&EV
M92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%S:R!F;W(@8V]N9FER;6%T:6]N
M(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!='1E;7!T
M('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D
M96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E
M9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=')I8G5T97,`075T
M:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y
M(%)!1$E54R!S97)V97(N`$%V86EL86)L92!F:65L9',Z`$)A9"!K97)B97)O
M<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!":7)T:&1A>0!"
M;VQD`$)O;VMM87)K<P!#35,`0U)#`$-A;&5N9&%R`$-A;B=T(&-O;FYE8W0@
M=&\@24U!4"!S97)V97(Z("5S`$-A;F-E;`!#96QL(%!H;VYE`$-O;&]R(%!I
M8VME<@!#;VUI8W,`0V]M<&%N>0!#;VYF:7)M(%!A<W-W;W)D`$-O;FYE8W1I
M;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]P>0!#;W5L
M9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%!'4"!S:6=N
M(&UE<W-A9V4N`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+@!#;W5L9"!N
M;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`
M0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E
M<BX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`
M0W5T`$1$`$1A:6QY`$1E9F%U;'0@261E;G1I='D`1&5L971E`$1E=&%I;',@
M:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1I<W!L
M87D@3W!T:6]N<P!%9&ET`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D
M<F5S<V5S(&UU<W0@;6%T8V@N`$5M<'1Y(')E<W5L="X`17)R;W(`179E<GD@
M,34@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%
M=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP
M;&4@=F%L=65S.@!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I
M;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN
M96-T('1O(%--0B!S97)V97(N`$9A>`!&:6QE($-O=6YT.B`E<R!F:6QE`$9I
M;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL
M92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<G,`1F]R=6US`$9U;&P@
M3F%M90!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<',`1W5E<W0@4&5R;6ES
M<VEO;G,`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AE;'``2&]M
M90!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;W)D90!)34%0(&UA:6QB;W@@
M8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I
M;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E
M<P!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)
M8V]N<R!/;FQY`$EC;VYS('=I=&@@=&5X=`!);7!O<G1E9"!F:65L9#H@)7,`
M26UP;W)T960@9FEE;&1S.@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!)=&%L
M:6,`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$ME
M<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5Y(&%L
M<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!,86YG=6%G
M90!,:7-T($AE;'`@5&]P:6-S`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N
M`$QO9R!I;@!,;V<@;W5T`$U-`$U3+51.148@071T86-H;65N="!C;VYT86EN
M960@;F\@9&%T82X`36%I;`!-871C:&EN9R!F:65L9',`365M8F5R<P!-96YU
M(&UO9&4Z`$UE<W-A9V4`365T:&]D`$UI;64@5'EP90!-;V1I9FEE9"!$871E
M`$UO;G1H;'D`37D@06-C;W5N=`!.86UE`$YE='=O<FL`3F5V97(`3F5W(%5S
M97)N86UE("AO<'1I;VYA;"D`3F\`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93
M+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO
M;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I
M8V%T:6]N+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`
M3F]T97,`3TL`3W!T:6]N<P!/<F1E<F5D($QI<W0`3W1H97(@26YF;W)M871I
M;VX`3W=N97(@4&5R;6ES<VEO;G,`4$A0(%-H96QL`%!A<W-W;W)D`%!A<W-W
M;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!0
M97)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI
M<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!H;VYE`%!L96%S
M92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!U8FQI8R]0<FEV871E(&ME
M>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%)A=&EO`%)E860`
M4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N
M9&]N92X`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D
M92DZ`%)E;6]V90!296UO=F4@=7-E<CH@)7,`4F]L90!344P@4VAE;&P`4U-(
M`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L
M96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!T:&4@
M9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C
M="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S
M+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E
M<G)E9"!L86YG=6%G93H`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@
M8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P
M;&%Y(&]P=&EO;G,N`%-H;W<`4VEZ90!3<&5C:6%L($-H87)A8W1E<B!);G!U
M=`!3=6)M:70`4W5C8V5S<P!487-K<P!497AT($]N;'D`5&AE(&1E=&%C:&5D
M(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H
M92!S:6=N960@;65S<V%G92X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q
M=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&QO8V%T:6]N(&]F
M('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?
M<&=P.CH@8VQA<W,N`%1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A
M=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE
M<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N
M`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N
M(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT
M97(@;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE
M(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A
M('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R
M9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN
M`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H
M92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AI<R!D;V5S
M(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D
M;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!F
M:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN
M(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R
M<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O
M<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9O<FT@
M:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@;G5M8F5R(&UU<W0@
M8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S
M('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M
M8F5R+@!4:6UE(%1R86-K:6YG`%1I=&QE`%523`!5;F%B;&4@=&\@8V]N;F5C
M="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R
M8VAI=F4N`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`
M56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YD97)L
M:6YE`%5P9&%T90!5<&1A=&4@)7,`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R
M;F%M90!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M
M.@!686-A=&EO;@!697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E
M(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"X`5V%R;FEN9P!7965K;'D`
M5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!7:&%T(&%P<&QI8V%T:6]N('-H
M;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7;W)K($%D9')E<W,`5V]R
M:R!0:&]N90!960!996%R;'D`665S`%EO=2!D:60@;F]T(&5N=&5R(&$@=F%L
M:60@96UA:6P@861D<F5S<RX`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE
M('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@
M861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N
M`%EO=7(@26YF;W)M871I;VX`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD
M(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U
M<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9
M;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<F5M;W1E('-E
M<G9E<G,Z`%ML:6YE("5S(&]F("5S70!F:6QE`'5N;F%M960`=D-A<F0`4')O
M:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C`M8W9S"E)E<&]R="U-<V=I9"U"
M=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E
M.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P
M,BTQ,2TQ.2`R,#HT-"TP-3`P"DQA<W0M5')A;G-L871O<CH@36ER;W-L878@
M4&5N9&5V(#QM:7)O0&-Y8F5R<VAA9&4N=7,^"DQA;F=U86=E+51E86TZ(&DQ
M.&Y`;&ES=',N:&]R9&4N;W)G"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M
M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U#4#$R-3$*0V]N=&5N="U4<F%N
M<V9E<BU%;F-O9&EN9SH@.&)I=`H`("@E<R#D[>@@[>#GX.0I`"`HY.WE\2D`
M("CB]^7PX"D`)7,@+2#'X.'EZ^7FZN``)7,@SN'QZ_/FXN#YZ"#N[^7PX/;H
MZ"`M(,_N\N+Z\.;DY>WHY0`E<R#3\>ONXNC_(._N(-'O[O#@Y_/LY>WHY?+N
M`"5S(.WE[N'U[N3H[``R-"#WX/'@`,?@(.3@(.KPZ._RZ/#@\N4@[^CQ[.X@
MY2#MY>[A]>[DZ.P@[_/AZ^CWY>T@4$=0(.KK_O<N`,?@(.3@(._P[N+E\.CR
MY2#O[N3OZ/'@[>X@[^CQ[.X@Y2#MY>[A]>[DZ.P@4$=0(.KK_O<N`,?@(.3@
M(.3EZO#H[_+H\.#RY2#OZ/'L[B#QX"#MY>[A]>[DZ.SH.B#O\^'KZ/?E[2#J
MZ_[W+"#KZ/?E[2#JZ_[W(.@@ZNO^]^[BX"#T\.#GX"X`Q^`@Y.`@[^[D[^CX
MY?+E(._H\>SN(/'@(.WE[N'U[N3H[.@Z(._SX>OH]^7M(.KK_O<L(.OH]^7M
M(.KK_O<@Z"#JZ_[W[N+@(/3PX.?@+@#'X"#DX"#J\.CO\NCPX/+E(._H\>SN
M(.4@[>7NX?7NY.CL(._SX>OH]^7M(%--24U%(.KK_O<N`$%-+U!-`,3NX>#B
M_^WE(.W@(.WNXN`@X_#S[^``Q.[AX.+_[>4@[>`@[>[BZ"#O\.#BX`#$[N'@
MXN@@[>[B(._N\O#EX>CRY>LZ`,3NX>#B_^WE\NX@[>`@[^[R\.7AZ/+EZ^@@
MY2#GX.'PX.WE[>XN`,#D\.7Q`,#D\.7QY>T@X>7KY>;MZ.H`P.3LZ.WH\?+P
MZ/#@[>4`Q.[AX.+JZ`#/\>7BY.[MZ.P`PO'H]^KH(./P\^_H`,+QZ/?JZ"#O
M\.#BX`#"^N+EY.7MX/+@(/'R[NGM[O'R(.WE(.4@Y.[O\_'RZ.S@+@#0X.?L
MY?`@[>`@X/#UZ.+MZ/\@].#IZP#([.4@[>`@X/#UZ.+@`,3@(/'E(.CQZN`@
MZ^@@[^[RXOKPYN3E[>CE(._PY>3H(.[A\>OSYN+@^>CRY2#N[^7PX/;HZ#\`
MP_#E^.K@(._PZ"#HY_+PZ.+@[>4@[>`@[>7Q^OGE\?+B\^+@^>`@X_#S[^`N
M`,/PY?CJX"#O\.@@Z.?R\.CBX.WE(.WE(.WE\?KYY?'RXO/BX/GH(._PX.+@
M+@##\.7XZN`@[_#H(/#EY.#J\NCPX.WE(.W@(.WE\?KYY?'RXO/BX/GH(._P
MX.+@+@#`\O#HX?/RZ`##\.7XZN`@[_#H(.CDY>WRZ/3HZN#VZ/\`R.3E[?+H
M].CJX/;H__+@(.'E^.4@[O+UXOKPZ^7MX"#N\B!2041)55,@\?KPXOKPX"X`
MS>#KZ/?MZ"#O[NOE\N`Z`,WEXN#KZ.3MX"!K97)B97)O<R`@[^#P[NO@+@#-
MY>+@Z^CD[>X@:V5R8F5R;W,@[^[R\.7AZ/+EZ_'J[B#H[.4N`-#NYN3E[2#D
MY>T`T^3EX>7KY>WH`,[R[.7RZN@`0TU3`$-20P#*X.OE[>3@\`##\.7XZN`@
M[_#H(/'B^O#GXN#MY2#Q(.SEZ>L@\?KPXOKP.B`E<P#.\NK@YN@`S.[AZ.OE
M[2#RY>OE].[M`,CGX>CPX.WE(.W@(/;B__(`RN[LZ.KQZ`#*[NSOX.WH_P#/
M[O+B^O#DY?+E(._@\.[KX/+@`,3N\?+Z[^`@Y.X@[_/AZ^CW[>C_(/'Z\.+Z
M\"#AY?CE(.[RZN#GX.TN`,KN[^CPX.D`P_#E^.K@(._PZ"!01U`@ZO#H[_+H
M\.#MY?+N(.W@(._H\>SN+@##\.7XZN`@[_#H(%!'4"#O[N3OZ/'BX.WE\NX@
M[>`@[^CQ[.XN`,/PY?CJX"#O\.@@Y.7J\.CO\NCPX.WE\NX@[>`@4$=0(.3@
M[>WH+@#-Y>KN\.7J\N7M(&5M86EL(.#D\.7Q(.W@(._NZ_/WX/+EZ_\N`,/P
MY?CJX"#O\.@@[^[K\_?@XN#MY?+N(.W@(._SX>OH]^WH_R#JZ_[W(.[R(.KK
M_O<M\?KPXOKPX"X`S>7B^N?L[N;M[O'R(.3@(/'E(.[RXN[PZ"#.X?'K\^;B
MX/GH7^?@Y.#WZ"#L[N3SZR`E<R``Z.?PY>;H`,3$`,7FY>3MY>+M[@#(Y.7M
M\NCW[>[Q\B#O[B#O[N3PX.?AZ/#@[>4`R.?R\.CI`,3E\N#IZ^CRY2#A__7@
M(/#EX^CQ\O#H\.#MZ"#GX"#@Y.SH[>CQ\O#@\N[PX"X`Q.CQ[^OEZ2#.[_;H
MZ`#0Y>3@ZO;H_P#/Z/'L[@#%;6%I;"#@Y/#E\0!%;6%I;"#@Y/#E\>CRY2#R
M\/_AXN`@Y.`@\?KB[^#DX/(N`,_PX.?E[2#PY>?SZ_+@\BX`P_#E^.K@`,+Q
MY>KH(#$U(.SH[?/RZ`#"\>7JZ"`S,"#QY>KS[>3H`,+QY>KH(#4@[.CM\_+H
M`,+Q_^KN(.ONX^+@[>4`S>`@XO'EZN@@[^[K[N+H[2#WX/$`PO'_ZN`@[.CM
M\_+@`,_PZ.SE\.WH(/'R[NGM[O'RZ#H`S>7B^N?L[N;M[O'R(.3@(/'E(.?@
M\.7D__(@[_#E].7PY>WVZ.CRY2X`S>7B^N?L[N;M[O'R(.3@(/'E(.[Q^OGE
M\?+BZ"#B\/KGZN`@\2!,1$%0(/'Z\.+Z\"X`P_#E^.K@(._PZ"#QXOKPY^+@
M[>4@\?KQ(%--0B#Q^O#B^O`N`-3@ZO$`P?#NZ2#TX.GK[N+E.B`E<R#TX.GK
M`,'P[ND@].#IZ^[BY3H@)7,@].#IZ^``U.#IZR#LY>W@YN7P`,CLY2#MX"#T
MX.GK`,CG[_#@^>#MY?+N(.W@(/3@Z>ONXN4@[>4@\>4@[^[DY/KPYN`N`-3H
MZ_+Z\`#4[O#S[.@`R.SE(.W@(/3@Z>L`P.3LZ.WH\?+PZ/#@[>4@[>`@X_#S
M[^@`P_#S[^@`S_#@XN`@Y^`@X^[Q\N@`2%144"#HY.7M\NCTZ.K@]NC_(.WE
M(.4@[>#LY?#E[>`N`,_N[.[Y`,W@]^#K[@#$[NS@^.7M(.#D\.7Q`,3N[.#X
MY>T@\N7KY?3N[0!(;W)D90##\.7XZN`@[_#H(/'ZY^3@XN#MY2#MX"!)34%0
M(._N^>7M\>K@(.KS\NC_.B`E<P##\.7XZN`@[_#H(.CG\O#HXN#MY2#MX"!)
M34%0(._N^>7M\>K@(.KS\NC_.B`E<P##\.7XZN`@[^[PX.3H(.KB[O+@(._P
MZ"#Q^N?DX.+@[>4@[>`@24U!4"#O[OGE[?'JX"#J\_+H_SH@)7,`25`@X.3P
MY?'@(.WE(.4@XB#O[N?B[NOE[>C_($-)1%(@X>ONZBX`T>#L[B#HZN[MZ`#(
MZN[MZ"#Q(/+EZO'R`,CL[^[P\NCPX.WN(._NZ^4Z("5S`,CL[^[P\NCPX.WH
M(._NZ^7RX#H`R.?O\.#RY>WH\N4@Y.#M[>@@\>`@[>7BX.OHY.WH+@#-X.KK
M[NWE[>@`[_KK[>X@[^[D\.#B[?_BX.WE`.O_XNX@[^[D\.#B[?_BX.WE`.3_
M\>WN(._NY/#@XNW_XN#MY0!+97)B97)O<R#Q^O#B^O#@(.[R]>+Z\.OH(.CD
MY>WRZ/3HZN#VZ/_RX"X`RNO^]^`@XN7WY2#Q^OGE\?+B\^+@(.(@[_/AZ^CW
M[>C_(.KK_O?Q^O#B^O`N`,7GZ.H`S^[L[OD@\N7LZ`#1[^CQ^NK@(/$@[^[R
M\.7AZ/+EZ^@@Y2#GX.'PX.WE[2X`PO7NY`#(Y_7NY`#,S`!-4RU43D5&(._P
MZ.KPY>_E[>C_\B#TX.GK(.WE(/'ZY/KPYN#XY2#DX.WMZ"X`S^[YX`#1^N+O
MX.3@^>@@[^[KY?+@`-?KY>WNXN4`PNCD(.W@(.SE[?[R[CH`S^CQ[.X`S.7R
M[N0`36EM92#RZ.\`Q.#RX"#MX"#O\.[LY>W_[>4`S.7QY??M[@#,[O_RX"#/
M[OG@`,CLY0#,\.7FX`#-Z.KNX^``S>[B[B#O[O+PY>'H\N7K\>KN(.CLY2`H
M[N_VZ.[MX.OM[BD`S>4`S?_LX"#GX.3@Y.7MX"#J[NWTZ./S\.#VZ/\@Y^`@
M1E10(%9&4RX`S?_LX"#GX.3@Y.7MX"#J[NWTZ./S\.#VZ/\@Y^`@4U%,(%9&
M4RX`S?_LX"#GX.3@Y.7MX"#J[NWTZ./S\.#VZ/\@Y^`@4U%,+49I;&4@5D93
M+@#-_^S@(.?@Y.#DY>W@(._@\.[KX"#GX"!)34%0(.CDY>WRZ/3HZN#VZ/\N
M`,W_[.`@Y^#DX.3E[>`@[^#P[NO@(.?@($ME<F)E<F]S(.CDY>WRZ/3HZN#V
MZ/\N`,W_[.`@ZN[M].CC\_#@]NCN[>W@(.CM].[P[.#VZ/\@Y^`@4TU"(.CD
MY>WRZ/3HZN#VZ/\N`,+Z\.W@\NCRY2#DX.WMZ"#MY2#QX"!834P`S?_LX"#Q
M\N[I[>[Q\N@`P>7KY>;JZ`#.R@#.[_;HZ`#/[N3PY>3E[2#Q[^CQ^NH`Q/#S
MX^`@Z.WT[O#LX/;H_P#/\.#BX"#MX"#O\.CRY>;@\N7K_P!01U`@4VAE;&P`
MS^#P[NO@`,_@\.[KX#H`S^#P[NO@.B``S>7J[O#EZO+MX"#OX/#NZ^`N`,+L
M^NKMZ`#$X"#QY2#HY^+Z\/CBX/(@Z^@@[N'QZ_/FXN#YZ/+E(.[OY?#@]NCH
M(._PZ"#"]>[D/P#/\.#BX`#`Y.SH[>CQ\O#H\.#MY2#MX"#O\.#BX/+@`-+E
MZ^7T[NT`S.[K_RP@XOKBY>3E\N4@[.7QY?8@Z"#C[N3H[>`N`,KK_O?NXN`@
MY.+NZ>K@(._SX>OH]^7M+_?@\?+E[2#JZ_[W(.WE(.'E^.4@X^7MY?#H\.#M
MX"X`RN[E].CVZ.7M\@#7Y?+E[>4`R/'JX/+E(.3@(.CG\O#HY?+E("5S(.OH
M/R#2X.?H(.[OY?#@]NC_(.WE(.SNYN4@Y.`@\>4@XOKP[>4@[>#GX.0N`,#D
M\.7Q(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`,_PY>S@
M]>WH`,_PY>S@]>WH(._N\O#EX>CRY>LZ("5S`-#NZ_\`4U%,(%-H96QL`%-3
M2`#(Y^'E\.7RY2#C\//OX"#GX"#D[N'@XO_MY0#(Y^'E\.7RY2#M[N(@[_#H
M\N7FX/+EZR#MX"#C\//OX`#(Y^'E\.7RY2#Q^O#B^O``R.?AY?#H(._N\O#E
MX>CRY>L@Y^`@Y.[AX.+_[>4`R.?AY?#E\N4@Q.#RX"#PX.?DY>OH\N7K.@#(
MY^'E\.7RY2#T[O#LX/(@Y^`@Q.#RX/+@.@#(Y^'E\.7RY2#T[O#LX/(@Y^`@
MU^#QX#H`R.?AY?#E\N4@Y.+E(/'ZXN_@Y.#YZ"#O[NOE\N`Z`,CGX>7PY?+E
M(.+@^.#RX"#Q]>7LX"#GX"#VXN7R[N+E\N4N`,CGX>7PY?+E(._PY>3O[O?H
M\N#MZ/_R(.[R(,+@\2#EY^CJ.@#'X.3@Z?+E(,+@^.7R[B#MX/?@Z^WN(._P
MZ.ONYN7MZ.4L(/'UY>S@(.?@(/;BY?+NXN4L(.[O\.7Q[?_BX.WE(.W@(/'R
M\.#MZ/;@\N`@Z"#D\//CZ"#N[_;HZ"#GX"#DZ/'OZ^7_+@#/[NK@Y^+@[>4`
MT.#G[.7P`,+ZXN7FY.#MY2#MX"#Q[^7VZ.#K[>@@\>CLXN[KZ`#(Y^_PX/+H
M`-/Q[^7U`,?@Y.#WZ`#1X.SN(/+EZO'R`,_PZ.KPY>_E[>C_\B!01U`@[^[D
M[^CQ(.4@[>7NX?7NY.CL(.?@(.3@(/'E(._P[N+E\.@@[^[D[^CQX.WN\NX@
M[^CQ[.XN`,KPZ._RZ/#@[>7R[B#HY^CQZN+@(.KPZ._RZ/#@[>`@=V5B(.+P
M^N?JX"X`S.7Q\N[O[NONYN7MZ.7R[B#MX"!';G501R#TX.GKX"#R\/_AXN`@
MY.`@X?KDY2#DX.3E[6\@[>`@0W)Y<'1?<&=P.CH@8VQA<P#/\.[C\.#LX/+@
M+"#J[O_R[B#QZ_/FZ"#GX"#O[NK@Y^+@[>4@[>`@\N[GZ"#RZ.\@Y.#M[>@@
M*"5S*2#MY2#AY?CE(.[RZO#H\N`@XB#QZ/'RY>S@\N``S?_LX"#DXN[IZN@L
M(.KNZ/+N(.3@(.'ZY.#R(._NZN#GX.WH(.(@Z^CMZ/_RX"X`R.S@(/+B^O#D
MY2#L[>[C[B#QZ.SB[NOH(.(@\N[BX"#O[NOE+B#"^N+EZ^@@\?+E("5S(/'H
M[.+NZ^`[(/+P_^'BX"#DX"#B^N+EY.7RY2#O[BWLX.OJ[B#N\B`E<RX`P_#E
M^.K@(._PZ"#HY^_PX/G@[>7R[B#MX"#TX.GKX#H@)7,@[>4@X>7XY2#HY^_P
MX/+E[2X`R.S@^.4@[_#NX>OE["#O\.@@Z.?O\.#YX.WE\NX@[>`@].#IZ^`N
M("5S(.4@[^XMX^[K_^P@[O(@[.#J\>CLX.OM[B#D[N_S\?+H[.C_(/#@Y^SE
M\"`H)60@X>#I\N`I+@##\.7XZN`@[_#H(.CG[_#@^>#MY?+N(.W@(/3@Z>O@
M+B`E<R#AY?CE(/'@[.X@[O+WX/'RZ"#HY^_PX/+E[2X`P_#E^.K@(._PZ"#H
M[._N\/(@[>`@Y.#M[>@@Y^`@ZN[M\N#J\N@N`-+NXN`@[>4@Y2#BX.OHY.7M
M(')A<B#@\/7HXBX`TN[BX"#MY2#E(.+@Z^CDY>T@>FEP(/3@Z>LN`-+NXN`@
M[^[KY2#E(.WE[N'U[N3H[.XN`-+NXN`@[^[KY2#L[N;E(.3@(/'ZY/KPYN`@
M\>#L[B#VY>OH(/?H\>O@+@#2[N+@(._NZ^4@[.[FY2#DX"#Q^N3Z\.;@(/'@
M[.X@]^CQZ^`@Z"#DXN[E\N[WZ.4N`-+NXN`@[^[KY2#R\/_AXN`@Y.`@Y2#G
MX._E\N#_(.CKZ"#H[?+E\.+@ZR#PX.?DY>OE[2#Q[^CQ^NH@[_#N[.7MZ^CB
MZ`#2X.?H(/3N\.S@(.+E]^4@X>7XY2#NX?#@X>[RY>W@+@#2[N+@(/?H\>ON
M(/+P_^'BX"#DX"#E(._N[>4@Y>3H[>CVX"X`TN[GZ"#Q^O#B^O`@[>4@[.[F
MY2#DX"#DY>KN[._PY?'H\.`@>FEP(.@@9WII<"#TX.GK[N+E+@#2X.?H(/'R
M[NGM[O'R(/+P_^'BX"#DX"#E(/?H\>ON+@#/\.[QZ^7D_^+@[>4@[>4@XO#E
M[.4`Q.OZYNWN\?(`55),`,WEXOKG[.[F[>[Q\B#GX"#B\/KGZN`@\2!344P@
M\?KPXOKP+@##\.7XZN`@[_#H(.[RXN#P_^WE\NX@[>`@ZN[L[_#E\>CPX.T@
MX/#UZ.(N`,/PY?CJX"#O\.@@]^7RY>WE\NX@[>`@=F9S<F]O="#OX._JX"X`
MP_#E^.K@(._PZ"#O\.7B[N3@(.W@(/+NY^@@5V]R9"#D[NKS[.7M\@#/[N3W
MY?#RX.WH`,[O\.7Q[>@`SN_PY?'MZ"`E<P#`Y.SH[>CQ\O#H\.#MY2#MX"#O
M[O+PY>'H\N7KZ/+E`,CLY0#([.4Z`,CLY3H@`,_N\O#EX>CRY>OH(.(@\>CQ
M\N7LX/+@.@#"X.K@[?;H_P##\.7XZN`@[_#H(._P[N+E\.K@\N`@+2#R[N+@
M(._H\>SN(.SNYN4@Y.`@Y2#AZ.ON(._NY._PX.+E[>XN`,+MZ.S@[>CE`-'E
MY.SH]^WN`,3NX?#E(,3N^.OH(.(@)7,`Q.[A\.4@Y.[XZ^@L("5S`,CGX>7P
MY?+E(._PZ.ONYN7MZ.7R[BP@ZN[E\NX@)7,@Y.`@[^[JX.;E(/'KY>0@XO7N
MY"X`P>CG[>7Q(.#D\.7Q`,'HY^WE\2#RY>OE].[M`,/#`,/NY.CX[>X`Q.``
MS>4@XOKBY>3N]?+E(.+@Z^CDY>T@96UA:6P@X.3PY?$N`-+P_^'BX"#DX"#G
MX.3@Y.7RY2#O[O+PY>'H\N7K(.?@(.CG\O#HXN#MY2X`TO#_X>+@(.3@(.?@
MY.#DY?+E(._N\O#EX>CRY>L@Y^`@Y.[AX.+_[>4N`-+P_^'BX"#DX"#GX.3@
MY.7RY2#O[O+PY>'H\N7K(.?@(.[O\.7Q[?_BX.WE+@#([?3N\.S@]NC_(.?@
M(,+@\0#"X/CH__(@Z.3E[?+H].CJX/;H[NWE[2#D\.#IXN7P(.WE(._NY.3Z
M\.;@(/'OZ/'ZZB#MX"#O[O+PY>'H\N7KZ/+E+"#HZ^@@\N#GZ"#B^N?L[N;M
M[O'R(.4@Y^#A\.#MY>W@+@#"X/CH\N4@ZN[M].CC\_#@]NCN[>WH(.[O]NCH
M(.'_]>`@[N'M[N+E[>@N`,+@^.CRY2#Q^O#B^O#H.@!;Z^CMZ/\@)7,@[O(@
M)7-=`/3@Z>L`X>7G(.CLY0!V0V%R9```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]B9U]"1R]H
M96QP+GAM;```````````````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,S,R,"`Q,#4Q-30S,S<T,2`P,C$T,#4`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]X;6P@=F5R<VEO;CTB,2XP(C\^
M"CPA+2T@)$AO<F1E.B!H;W)D92]L;V-A;&4O8F=?0D<O:&5L<"YX;6PL=B`Q
M+C(@,C`P-"\P-2\R-R`R,#HR,CHQ-B!J86X@17AP("0@+2T^"CQH96QP/@H@
M(#QE;G1R>2!I9#TB<W5M;6%R>2(@<W1A=&4](FYE=R(^"CQT:71L93Y4:&4@
M4&]R=&%L(%!A9V4\+W1I=&QE/@H@/'!A<F$^"B`@5&AI<R!P;W)T86P@<&%G
M92!P<F]V:61E<R!A('%U:6-K('-U;6UA<GD@;V8@86QL('EO=7(@:6UP;W)T
M86YT"B`@:6YF;W)M871I;VXN($9O<B!E>&%M<&QE+"!I="!M:6=H="!S:&]W
M(&AO=R!M86YY(&YE=R!E+6UA:6P@;65S<V%G97,@>6]U"B`@:&%V92!I;B!Y
M;W5R($E.0D]8+"!U<&-O;6EN9R!E=F5N=',@;VX@>6]U<B!C86QE;F1A<BP@
M=&%S:W,@;VX@>6]U<B!T;RUD;PH@(&QI<W0L(&AE861L:6YE<R!F<F]M('-E
M;&5C=&5D(&YE=W,@<V5R=FEC97,L(&%N9"!S;R!O;BX@($UA;GD@;V8@=&AE
M<V4*("!S=6UM87)I97,@=VEL;"!C;VYT86EN('%U:6-K('-H;W)T8W5T<R!T
M;R!C;VUM;VX@9G5N8W1I;VYS+"!S=6-H(&%S"B`@8V]M<&]S:6YG(&$@;F5W
M(&UA:6P@;65S<V%G92P@8W)E871I;F<@82!N97<@8V%L96YD87(@979E;G0@
M;W(@=&%S:RP@971C+@H@/"]P87)A/@H@/'!A<F$^"B`@5&AE(&-O;G1E;G1S
M(&]F('1H:7,@<&]R=&%L('!A9V4@87)E(&-U<W1O;6EZ86)L92!V:6$@=&AE
M($QA>6]U="!B=71T;VXN"B`@1F]R(&5X86UP;&4L('EO=2!C86X@8VAO;W-E
M('=H:6-H(&ET96US('1O(&EN8VQU9&4@;VX@=&AI<R!P;W)T86P@<&%G92!A
M<PH@('=E;&P@87,@:6X@=VAI8V@@;W)D97(@=&AE>2!A<F4@<VAO=VXN"B`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)N879B87(B('-T871E/2)N
M97<B/@H\=&ET;&4^5&AE($%P<&QI8V%T:6]N($YA=FEG871I;VX@0F%R/"]T
M:71L93X*(#QP87)A/@H@($%T('1H92!L969T(&AA;F0@<VED92!O9B!T:&4@
M=V5B('!A9V4@:7,@=&AE(&%P<&QI8V%T:6]N(&YA=FEG871I;VX@8F%R+@H@
M($-L:6-K(&]N('1H92!I8V]N<R!O;B!T:&ES(&YA=FEG871I;VX@8F%R('1O
M('%U:6-K;'D@86YD(&5A<VEL>2!S=VET8V@*("!B971W965N('1H92!A=F%I
M;&%B;&4@87!P;&EC871I;VYS+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<')E9G,M9&]?;6%I;G1E;F%N8V4B('-T871E/2)N97<B/@H@("`@
M/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@1&\@36%I;G1E;F%N
M8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T
M;R!P97)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6XL(&-H
M96-K('1H:7,@8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<')E9G,M8V]N9FER;5]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!#;VYF:7)M($UA
M:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U('=O=6QD
M(&QI:V4@=&\@8V]N9FER;2!A;&P@;6%I;G1E;F%N8V4@=&%S:W,@8F5F;W)E
M('1H97D@87)E(')U;BP@8VAE8VL@=&AI<R!B;W@N($EF(&QE9G0@=6YC:&5C
M:V5D+"!A;&P@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!T:&%T(&YE960@=&\@
M8F4@<G5N('=I;&P@8F4@<&5R9F]R;65D(&%U=&]M871I8V%L;'D@=VET:"!N
M;R!C:&%N8V4@=&\@8V%N8V5L(&]N(&QO9VEN+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H\+VAE;'`^"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O:V]?2U(`````````
M````````````````````````````````````````````````````````````
M````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P
M,#`@,3`U,34T,S,W-#$@,#$W-S(S`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO
M8V%L92]K;U]+4B],0U]-15-304=%4P``````````````````````````````
M```````````````````````````````````````P,#`W-34@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<T,2`P,C$U,3``(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&]C86QE+VMO7TM2+TQ#7TU%4U-!1T53+VAO<F1E
M+FUO````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#4Q,#4U(#$P-3$U-#,S
M-S0Q(#`R,S(S,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#>$@25`````(L!```<````=`P``!T"``#,&````````$`A```/
M````02$```@```!1(0``"P```%HA```,````9B$``"@```!S(0``$@```)PA
M```(````KR$```4```"X(0``$0```+XA```#````T"$```\```#4(0``"```
M`.0A```(````[2$``!D```#V(0``!P```!`B```,````&"(```X````E(@``
M!0```#0B```%````.B(```H```!`(@```P```$LB```.````3R(```\```!>
M(@``'P```&XB```%````CB(``#D```"4(@``!@```,XB```1````U2(```H`
M``#G(@``$````/(B```(`````R,```0````,(P``!@```!$C```1````&",`
M``<````J(P``!````#(C```&````-R,```T````^(P``$P```$PC```(````
M8",```8```!I(P``%0```'`C```'````AB,```H```".(P``#P```)DC```-
M````J2,```\```"W(P``#0```,<C```)````U2,```8```#?(P``!@```.8C
M```.````[2,```4```#\(P``*@````(D```3````+20```P```!!)```$```
M`$XD```1````7R0```4```!Q)```!0```'<D```&````?20```<```"$)```
M$````(PD```$````G20```X```"B)```*0```+$D```&````VR0```T```#B
M)```#@```/`D```-````_R0```,````-)0``#0```!$E```"````'R4```4`
M```B)0``!````"@E```.````+24```@````\)0``#P```$4E```/````524`
M``<```!E)0``$````&TE```&````?B4```L```"%)0``#0```)$E```*````
MGR4``!D```"J)0``%@```,0E```4````VR4```L```#P)0``+P```/PE```)
M````+"8```\````V)@``)@```$8F``!#````;28```@```"Q)@``"P```+HF
M```$````QB8``!<```#+)@``$0```.,F```*````]28```(`````)P``!0``
M``,G```)````"2<```T````3)P``#@```"$G```8````,"<```4```!))P``
M$````$\G```0````8"<```\```!Q)P``"P```($G```/````C2<```P```"=
M)P``#P```*HG```.````NB<```@```#))P``'@```-(G```A````\2<```,`
M```3*```"````!<H```,````("@```<````M*```"@```#4H```&````0"@`
M``0```!'*```!P```$PH```"````5"@```8```!7*```!````%XH```1````
M8R@``"(```!U*```#````)@H```*````I2@```4```"P*```#P```+8H```2
M````QB@```L```#9*```*0```.4H```D````#RD``"8````T*0``$@```%LI
M```*````;BD```\```!Y*0``$````(DI```.````FBD```D```"I*0``"@``
M`+,I```2````OBD``!````#1*0``$0```.(I```/````]"D``!0````$*@``
M#````!DJ```,````)BH```\````S*@``%0```$,J```I````62H``"H```"#
M*@``)@```*XJ```G````U2H``"D```#]*@``*@```"<K```1````4BL``!(`
M``!D*P``$P```'<K```4````BRL``!8```"@*P``%P```+<K```0````SRL`
M`!$```#@*P``$P```/(K```2````!BP```8````9+```!P```"`L```%````
M*"P``!8````N+```!````$4L```$````2BP```<```!/+```#@```%<L```,
M````9BP```P```!S+```#0```(`L```2````CBP```\```"A+```"````+$L
M```.````NBP``!8```#)+```$0```.`L```&````\BP```0```#Y+```$```
M`/XL```:````#RT```8````J+0``!P```#$M```+````.2T``!,```!%+0``
M$P```%DM```3````;2T```(```"!+0``!````(0M```-````B2T```4```"7
M+0``!@```)TM```/````I"T```,```"T+0``"@```+@M```+````PRT```<`
M``#/+0``!@```-<M```*````WBT```<```#I+0``"0```/$M```'````^RT`
M``0````#+@``!P````@N```%````$"X``!,````6+@``!````"HN```"````
M+RX``#,````R+@``,P```&8N```X````FBX```0```#3+@``!0```-@N```(
M````WBX``!$```#G+@``#@```/DN```'````""\``!\````0+P``!P```#`O
M```.````."\```P```!'+P``#````%0O```%````82\``!$```!G+P``!P``
M`'DO```(````@2\``!4```"*+P``!0```*`O```4````IB\```0```"[+P``
M!P```,`O```>````R"\``!0```#G+P``!0```/PO```&`````C```"@````)
M,```*0```#(P```'````7#```"$```!D,```#@```(8P```3````E3```!<`
M``"I,```"P```,$P```%````S3```!$```#3,```!0```.4P```2````ZS``
M``0```#^,```#@````,Q```.````$C$```4````A,0``$@```"<Q```$````
M.C$```P````_,0``!@```$PQ``!I````4S$``!H```"],0``%P```-@Q```7
M````\#$``!L````(,@``'P```"0R```3````1#(```D```!8,@``)0```&(R
M```@````B#(``"0```"I,@``(````,XR```$````[S(``!````#T,@``'```
M``4S```H````(C,```<```!+,P``$P```%,S```7````9S,```H```!_,P``
M#````(HS```)````ES,```T```"A,P``"P```*\S```'````NS,```8```##
M,P``"0```,HS```'````U#,```<```#<,P``"P```.0S```0````\#,``!``
M```!-```!0```!(T```$````&#0```D````=-```"@```"<T```?````,C0`
M`!L```!2-```/@```&XT```C````K30``!\```#1-```/0```/$T```A````
M+S4``!P```!1-0``!0```&XU```0````=#4```(```"%-0``$@```(@U```#
M````FS4``!````"?-0```P```+`U```O````M#4``"````#D-0``)`````4V
M```E````*C8``"````!0-@``)@```'$V```)````F#8```P```"B-@``%P``
M`*\V```.````QS8```T```#6-@``&@```.0V```'````_S8```L````'-P``
M$P```!,W```3````)S<```P````[-P``"````$@W```4````43<```X```!F
M-P``$````'4W```'````AC<```<```".-P``!@```)8W```'````G3<```T`
M``"E-P``"P```+,W```@````OS<``!P```#@-P``!0```/TW```2`````S@`
M``H````6.```!@```"$X```,````*#@```H````U.````@```$`X```&````
M0S@```,```!*.```10```$XX```9````E#@``$4```"N.```,````/0X```F
M````)3D``"4```!,.0``,````'(Y```2````HSD``!,```"V.0``$````,HY
M```)````VSD``',```#E.0``*P```%DZ```7````A3H``!8```"=.@``#P``
M`+0Z``!`````Q#H``!\````%.P``$@```"4[```0````.#L``!,```!).P``
M'0```%T[```/````>SL```\```"+.P``"P```)L[```%````ISL``!0```"M
M.P``"````,([```/````RSL```@```#;.P``#P```.0[```4````]#L```8`
M```)/```!````!`\```'````%3P```8````=/```!P```"0\```%````+#P`
M`%(!```R/```#````(4]```'````DCT```<```":/0``!P```*(]```7````
MJCT``!4```#"/0``!P```-@]```)````X#T```L```#J/0``!````/8]```3
M````^ST```\````//@``"P```!\^```4````*SX```0```!`/@``!@```$4^
M```$````3#X```H```!1/@``!````%P^```%````83X```D```!G/@``"```
M`'$^```'````>CX``!<```""/@```P```)H^```7````GCX```,```"V/@``
M#````+H^```$````QSX```D```#,/@``!````-8^```$````VSX```0```#@
M/@``"0```.4^```$````[SX```0```#T/@``!````/D^```+````_CX```P`
M```*/P``!````!<_```$````'#\``!(````A/P``!````#0_```&````.3\`
M``<```!`/P``!P```$@_```'````4#\```<```!8/P``!@```&`_```&````
M9S\```0```!N/P``#@```',_```$````@C\``!4```"'/P``%````)T_```'
M````LC\```T```"Z/P``"P```,@_```$````U#\```,```#9/P``!@```-T_
M```$````Y#\```D```#I/P``!````/,_```$````^#\``"L```#]/P``!@``
M`"E````+````,$````H````\0```"P```$=````&````4T````8```!:0```
M`@```&%````$````9$````0```!I0```"0```&Y````$````>$````0```!]
M0```"````()````$````BT````L```"00```!````)Q````'````H4````<`
M``"I0```!P```+%````,````N4````P```#&0```"0```--````%````W4``
M`"H```#C0```"`````Y!```)````%T$``"<````A00``0P```$E!```(````
MC4$```L```"600``!````*)!```,````IT$```X```"T00``!P```,-!```"
M````RT$```8```#.00``"````-5!```)````WD$```L```#H00``#0```/1!
M```$`````D(```D````'0@``"0```!%"```(````&T(```L````D0@``"0``
M`#!"```$````.D(```,````_0@``#0```$-"```&````44(``!,```!80@``
M$P```&Q"```$````@$(```,```"%0@``"P```(E"```$````E4(```D```":
M0@``!@```*1"```$````JT(```0```"P0@``!````+5"```$````ND(```8`
M``"_0@``!@```,9"```>````S4(```<```#L0@``"P```/1"```%`````$,`
M``8````&0P``"0````U#```%````%T,``!,````=0P``#@```#%#```3````
M0$,```X```!40P``!@```&-#```-````:D,```P```!X0P``#@```(5#```(
M````E$,```D```"=0P``#P```*=#```,````MT,``!````#$0P``"````-5#
M```0````WD,```D```#O0P``!P```/E#```,`````40```X````.1```%P``
M`!U$```7````-40``!<```!-1```%P```&5$```8````?40``!@```"61```
M#````*]$```,````O$0```P```#)1```#````-9$```.````XT0```X```#R
M1```#`````%%```,````#D4```X````;10``#@```"I%```(````.44```,`
M``!"10``!````$9%```4````2T4```,```!@10```P```&1%```$````:$4`
M``L```!M10``"0```'E%```)````@T4```L```"-10``"````)E%```/````
MHD4```0```"R10``$0```+=%```@````R44``!,```#J10``"````/Y%```$
M````!T8```L````,1@``&P```!A&```&````-$8```@````[1@``#P```$1&
M```-````5$8```L```!B1@``$````&Y&```"````?T8```0```""1@``$```
M`(=&```#````F$8```@```"<1@``#0```*5&```#````LT8```D```"W1@``
M"0```,%&```&````RT8```8```#21@``"````-E&```$````XD8```L```#G
M1@``"0```/-&```$````_48```@````"1P``"`````M'```-````%$<```0`
M```B1P``!@```"='```C````+D<``!P```!21P``(0```&]'```-````D4<`
M``0```"?1P``!````*1'```'````J4<```<```"Q1P``!````+E'```1````
MOD<```@```#01P``"P```-E'```)````Y4<```0```#O1P``!````/1'```)
M````^4<```0````#2```!`````A(```9````#4@```8````G2```$P```"Y(
M```$````0D@```8```!'2```$P```$Y(```)````8D@```@```!L2```!```
M`'5(```A````>D@``!X```"<2```"````+M(```0````Q$@```D```#52```
M"0```-](```0````Z4@```\```#Z2```"0````I)```1````%$D```8````F
M20``#````"U)```$````.DD```<````_20``!P```$=)```#````3TD``!(`
M``!320``!````&9)```-````:TD```0```!Y20``.P```'Y)```3````NDD`
M``X```#.20``#@```-U)```9````[$D``!\````&2@``&````"9*```#````
M/TH```X```!#2@``#@```%)*```.````84H``!````!P2@``!````(%*```-
M````ADH```8```"42@``&@```)M*```$````MDH```T```"[2@``#@```,E*
M```'````V$H```<```#@2@``!P```.A*```(````\$H```L```#Y2@``!```
M``5+```$````"DL```@````/2P``!````!A+```$````'4L```8````B2P``
M!P```"E+```'````,4L```0````Y2P``!@```#Y+```$````14L```D```!*
M2P``&````%1+```>````;4L``"T```",2P``'@```+I+```?````V4L``#\`
M``#Y2P``*0```#E,```8````8TP```0```!\3```#0```(%,```)````CTP`
M``X```"93````@```*A,```1````JTP```,```"]3```+0```,%,```>````
M[TP``!L````.30``)````"I-```H````3TT``"$```!X30``!````)I-```1
M````GTT``!````"Q30``!````,)-```$````QTT``!4```#,30``"0```.)-
M```)````[$T```T```#V30``$`````1.```/````%4X```@````E3@``$```
M`"Y.```)````/TX```D```!)3@``!P```%-.```$````6TX```0```!@3@``
M!````&5.```6````:DX```X```"!3@``%P```)!.```7````J$X```0```#`
M3@``"0```,5.```)````STX```4```#93@``"@```-].```-````ZDX```(`
M``#X3@``!````/M.```"`````$\``#T````#3P``%````$%/```^````5D\`
M`"D```"53P``)0```+]/```E````Y4\``"P````+4```#````#A0```*````
M15````0```!04```!0```%50``!S````6U```"<```#/4```#````/=0```,
M````!%$```H````140``'P```!Q1```6````/%$```T```!340``#P```&%1
M```,````<5$``!,```!^40``#@```))1```&````H5$```D```"H40``!@``
M`+)1```.````N5$```H```#(40``#@```--1```*````XE$```T```#M40``
M#````/M1```#````"%(```0````,4@``!@```!%2```$````&%(```D````=
M4@``!0```"=2```!````]P```&\!````````4P$```````!:````K````!<!
M```@`````````#\````*````RP```(T```!G````Y````"P!``#=````````
M`&D```"Q````>@```*0`````````^0```(8```!B````6`$``!,!```X````
M````````````````'P$``#,!``#F````^P```+,`````````O`````````"C
M````W@`````````U````/@`````````2`0``@@$``"\```!;`0``1`$``%\`
M``!\`0``C@``````````````W````````````````````'X!``!=````````
M````````````````````````````I@```,@```!:`0``J0```$H```#U````
M`````,P`````````&P```!T!``">````%@````@!``"X````UP````(`````
M````F0```/(````#````TP```-0```#2````=`$``%<```#N``````$``&T!
M``!'`0``R@```````````````````!`!``#J````BP```.P```!Q````)0$`
M`,\`````````!P```"8!````````"````"L```"K````````````````````
MB@```$\!``"4````>`$``!H`````````$@```&T````]`0``5````&8`````
M````3P```#<!``!;````,@$``'T``````````````/P`````````J@``````
M``!5`0``%P```(4```!`````BP$``/H`````````H````%8````8`0``F```
M`#P```!+`0``=@```$8```#$`````````#X!````````/0```.(```"`````
M:@$``&4`````````(0$``&4!````````@@```%P!````````[P````````"&
M`0``00```$H!```4`0``OP```(@```!K`````````-D`````````S@```&0`
M````````!@```.4```#C````3````$`!``"Y````&@$```````!?`0``YP``
M``,!````````:P$``(<!````````2`````````"#````:`$````````[`0``
M'`$``.@```"R````U@```$<``````````````,T```"``0``_P```#H```!^
M`````````"(`````````0@$``,D`````````40```%D!``"3`````````!$`
M``#``````````'<!``!P````_@```+T`````````2`$```````!\````````
M`&D!``!>`0``B0``````````````+````!,``````````````(<```#"````
M``````````!]`0``+P$```0!```*`0``=@$```X!``!_`0```````/0`````
M````40$`````````````1@$``%(``````````````-L```#S````#@```'0`
M``#A`````````#H!``!0`0``Q0```)8`````````8P```.L````S````+@``
M`-H````$````9@$`````````````80```",````"`0``H0```'D!``"#`0``
MM````%(!``"V````#````'@`````````&`````````"^````#`$```T!``"2
M````/`$````````/`0```````',```!.````'@$``!P`````````T```````
M``"1````(0````````#I````)````'4```#1````%@$`````````````E0``
M```````N`0``1````",!```P`0``$0$``"D!```4`````````#(`````````
M`````%````"Z````)P```(D!````````G````,<`````````-@$````````T
M`0```````&P`````````!P$``%D```!>````A`$```$!``"%`0``&0```&X!
M````````9P$`````````````M0````````!-`0```````'L```"(`0``3`$`
M`&(!``!Z`0``7`````T```!.`0```````"T```!7`0```````#0`````````
M#P```'D````;`0````````````"P````%0$````````%````"0````4!```K
M`0``^`````8!````````9`$``#L```!W``````````````!A`0``````````
M```=````NP```&P!```5````20```"H!``"!````?P````````!Q`0``;P``
M`*(````_`0````````````!"`````````&,!``!S`0``K@```!``````````
MK0```#8`````````,````"@!````````6````&H```"0``````````````#&
M`````````'`!````````*````%4```#]`````````'(````M`0``)0````D!
M```G`0``I0````````#!````X```````````````V````"8`````````CP``
M`/``````````>P$``)T`````````KP````````"W````=0$````````9`0``
M.0$``"`!```D`0```````#D`````````"P``````````````(@$``*<```"$
M````F@```&`````>````,0$``(P```!@`0``*@```$,!``!-````20$``%,`
M``##````2P````L!`````````````$,```!6`0``J````#4!````````GP``
M`#@!````````;@```/$```!4`0``*0```&@```#5`````````!\````Q````
M-P```)<```!=`0``@0$``'(!````````]@```$$!``#M````FP```$4!````
M````WP```$4```"*`0```"`H06-C97-S:V5Y("5S*0`@*'1O9&%Y*0`@*'1O
M;6]R<F]W*0`@*'EE<W1E<F1A>2D`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<R`M($-O;F9I<FUA=&EO;@`E<R!A;')E861Y(&5X:7-T<RX`,C0@:&]U<G,`
M04TO4$T`06)O=70@=&AI<R!E9&ET;W(`061D`$%D9"!A(&YE=R!U<V5R.@!!
M9&0@<&%I<@!!9&0@=7-E<@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D
M9')E<W,`061D<F5S<R!";V]K`$%D;6EN:7-T<F%T:6]N`$%L:6%S`$%L:6=N
M`$%L:6=N;65N=#H`06QL`$%L;"!F;W5R('-I9&5S`$%L=&5R;F%T92!T97AT
M.@!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%P<FEL`$%S:R!F
M;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R
M871I;VYS/P!!=6=U<W0`079A:6QA8FQE(&9I96QD<SH`0F%C:V=R;W5N9`!"
M86-K9W)O=6YD($-O;&]R`$)I<G1H9&%Y`$)O;&0`0F]R9&5R`$)O<F1E<B!T
M:&EC:VYE<W,Z`$)O<F1E<G,`0F]T:`!";W1T;VT`0G5L;&5T960@3&ES=`!#
M7V5L;"!0<F]P97)T:65S+BXN`$-A;&5N9&%R`$-A;F-E;`!#86YC96P@4')O
M8FQE;2!297!O<G0`0V%P=&EO;@!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE
M<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z
M`$-E;&QP:&]N90!#96YT97(`0VAA;F=E`$-H96-?:R!,:6YK+BXN`$-H:6YA
M`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#
M;&5A<B!-4T]F9FEC92!T86=S`$-L;W-E(%=I;F1O=P!#;VQL87!S92!3:61E
M8F%R`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]R`$-O;',Z`$-O;6EC<P!#;VUP
M86YY`$-O;F9I<FT@4&%S<W=O<F0`0V]P>0!#;W!Y('-E;&5C=&EO;@!#;W5L
M9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#<F5A=&4`
M0W)E871E(&$@;&EN:P!#=7)R96YT(%523"!I<P!#=7)R96YT('-T>6QE`$-U
M=`!#=70@<V5L96-T:6]N`$1$`$1A:6QY`$1A=&4`1&5?;&5T92!#;VQU;6X`
M1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E($EN9&5N=`!$969A
M=6QT`$1E9F%U;'0@261E;G1I='D`1&5L971E`$1E;&5T92!C96QL`$1E;&5T
M92!C;VQU;6X`1&5L971E(')O=P!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN
M`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5S8W)I8F4@=&AE(%!R;V)L96T`
M1&5S8W)I<'1I;VX`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@
M861M:6YI<W1R871O<BX`1&ER96-T;W)Y`$1I<W!L87D@3W!T:6]N<P!$;R!N
M;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H92!F
M:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE
M8VL@=&AI<R!B;W@Z`$1O=VYL;V%D`$1O=VYL;V%D("5S`$5D:70`161I="!0
M97)M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`16QE;65N="XN
M+@!%;0!%;6%I;`!%;6]T:6-O;G,`16UP='D@<F5S=6QT+@!%;FQA<F=E($5D
M:71O<@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`17)R;W(`179E<GD@,34@
M;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R
M>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@
M=F%L=65S.@!%>'!A;F0@4VED96)A<@!&1R!#;VQO<@!&86EL960@<F5T<FEE
M=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S
M97)V97(N`$9A>`!&96)R=6%R>0!&:6QE($UA;F%G97(`1FEL=&5R<P!&;VYT
M($-O;&]R`$9R86UE<P!&<F]M`$=E<FUA;GD`1V\`2&5I9VAT`$AE;'``2&5L
M<"!U<VEN9R!E9&ET;W(`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F
M:6QE.@!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;W)D90!(;W)I>F]N=&%L
M(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!M86YY
M(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I
M96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD
M('EO=2!L:6ME('1O(&UE<F=E/P!)7VYS97)T(%)O=R!"969O<F4`26-O;G,@
M3VYL>0!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!);6%G92!0
M<F5V:65W.@!);6%G92!54DP`26UA9V4@55),.@!);7!O<G1E9"!F:65L9#H@
M)7,`26UP;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E<@!);F-R96%S
M92!);F1E;G0`26YS97)T($-?;VQU;6X@069T97(`26YS97)T($EM86=E`$EN
M<V5R="!486)L90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F
M;W)E`$EN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE
M`$EN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!)
M;G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@
M82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R
M86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R
M87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!C96QL(&%F=&5R
M`$EN<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R
M="!C;VQU;6X@8F5F;W)E`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T
M('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W
M(&)E9F]R90!);G-E<G0O36]D:69Y($EM86=E`$EN<V5R="]-;V1I9GD@3&EN
M:P!)=&%L:6,`2F%N=6%R>0!*87!A;@!*87!A;F5S92`H25-/+3(P,C(M2E`I
M`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L
M;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+;W)E82P@4F5P=6)L:6,@
M;V8`2V]R96%N("A%54,M2U(I`$QA;F=U86=E`$QA<W0@;&]G:6XZ("5S`$QA
M<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%Y;W5T
M`$QE9G0`3&ES="!(96QP(%1O<&EC<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B
M;&5D+@!,;V<@:6X`3&]G(&]U=`!,;V=I;B!487-K<P!,;W=E<B!G<F5E:R!L
M971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M8F5R
M<P!-30!-86EL`$UA:V4@;&EN7VLN+BX`36%R8V@`36%R9VEN`$UA=&-H:6YG
M(&9I96QD<P!-87D`365N=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UI
M9&1L90!-;V1I9GD@55),`$UO;G1H;'D`36]V92!$;W=N`$UO=F4@57``3F%M
M90!.971W;W)K`$YE=F5R`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5X=`!.;P!.
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10
M(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO;F4`3F]T97,`3F]V96UB97(`
M3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3V-T;V)E<@!/<&5N
M<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P=&EO;G,`3W!T:6]N<R!F
M;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/=&AE<@!/=&AE<B!)
M;F9O<FUA=&EO;@!0861D:6YG`%!A<W-W;W)D`%!A<W-W;W)D<R!M=7-T(&UA
M=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E<F-E;G0`
M4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<G-O;F%L($EN9F]R
M;6%T:6]N`%!H;VYE`%!I>&5L<P!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@
M;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@
M86YD('!A<W-W;W)D`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N
M97<@=VEN9&]W`%!R:6YT(&1O8W5M96YT`%!R;V)L96T@1&5S8W)I<'1I;VX`
M4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5M;W9E('!A:7(`4F5S970`4F5T
M=7)N('1O($]P=&EO;G,`4FEG:'0`4F]?=R!0<F]P97)T:65S+BXN`%)O;&4`
M4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4V%M92!F<F%M
M92`H7W-E;&8I`%-A=F4`4V%V92!/<'1I;VYS`%-E87)C:`!396QE8W0@=&AE
M(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO
M=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@
M87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D
M871E(&9O<FUA=#H`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W
M;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG
M=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!397!T96UB97(`4VAO=R!T:&4@
M5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!0
M<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE
M<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VEZ
M90!3:VEP($UA:6YT96YA;F-E`%-P86-E(&)E='=E96X@861J86-E;G0@8V5L
M;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3
M<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!E8VEA;"!#:&%R86-T97(@
M26YP=70`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W`%-T<FEK
M971H<F]U9V@`4W1Y;&4@6T-34UT`4W5B:F5C=`!3=6)M:70`4W5B<V-R:7!T
M`%-U8V-E<W,`4W5M;6%R>0!3=7!E<G-C<FEP=`!486)L92!0<F]P97)T:65S
M`%1A8FQE('!R;W!E<G1I97,`5&%S:W,`5&5X=`!497AT($]N;'D`5&5X="!A
M;&EG;@!4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN`%1H92!F:6QE
M(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A
M9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@:61E
M;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&5R92!A<F4@;F\@;W!T
M:6]N<R!A=F%I;&%B;&4N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@
M9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`5&AI<R!N=6UB97(@
M;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@=F%L=64@;75S="!B92!A(&YU
M;6)E<BX`5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4;P!4;V=G;&4@2%1-3"!3
M;W5R8V4`5&]P`%1O<"!F<F%M92`H7W1O<"D`55),`%5N86)L92!T;R!C:&%N
M9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C
M;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!L;V%D('1H92!D969I
M;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E
M8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N86)L
M92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N9&5R;&EN90!5
M;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S="!A8W1I;VX`56YI=&5D($MI
M;F=D;VT`56YI=&5D(%-T871E<P!5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N
M=`!5;FYA;65D`%5N<V5T(&-O;&]R`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P
M97(@<F]M86X@;G5M8F5R<P!5<V5R($]P=&EO;G,`57-E<FYA;64`57-E<G,@
M:6X@=&AE('-Y<W1E;3H`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D9&EN
M9P!6:65W("5S`%=A<FYI;F<`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E
M<P!796QC;VUE+"`E<P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R
M/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=I9'1H`%=I9'1H(&]F
M('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7;W)K($%D9')E<W,`5V]R
M:R!0:&]N90!960!996%R;'D`665S`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@
M57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'
M+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!M=7-T(&1E<V-R:6)E
M('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@
M<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN
M:R!P;VEN=',@=&\`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E
M;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9
M;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I
M;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U
M<B!);F9O<FUA=&EO;@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B
M86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE
M(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A
M<V]N+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U
M<F4N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!I9&5N
M=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;W!T:6]N<R!H879E(&)E96X@
M=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BX`66]U
M<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!;2&ED92!1=6]T960@5&5X
M=%T`6U!R;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W
M(%%U;W1E9"!497AT("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?061M
M:6YI<W1R871I;VX`7T1E;&5T92!2;W<`7TAE;'``7TEM86=E(%!R;W!E<G1I
M97,N+BX`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]296UO
M=F4@3&EN:RXN+@!?5&%B;&4@4')O<&5R=&EE<RXN+@!L:6YE<UT`;F%M90!P
M97)C96YT`'!I>&5L<P!U;FYA;65D`'9#87)D`%!R;VIE8W0M260M5F5R<VEO
M;CH@2&]R9&4@,RXP+6-V<PI297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI
M<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q
M-3HQ,BLP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#$M,3$M,#D@,38Z,CDK
M,#DP,`I,87-T+51R86YS;&%T;W(Z($II;FAY;VL@2&5O(#QN;W9E;6)R94!O
M=7)N871U<F4N;W)G/@I,86YG=6%G92U496%M.B!I,3AN0&QI<W1S+FAO<F1E
M+F]R9PI-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA
M:6X[(&-H87)S970]155#+4M2"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z
M(#AB:70*`"`HM-S#X,6P("5S*0`@*+_`M,,I`"`HL[O`SRD`("B^[L&F*0`E
M<R#`K\'VL/RXKB#`V[[W("T@R*[`S@`B)7,BM,(@P,RYS"#`UKW`M,^TV2X`
M,C0@O<.PHP"_P,#\+[_`R,0`P,P@OZ&U\,7-M,(`P]^PH0"[];?.O^X@N^>_
MZ\#:(,/?L*$Z`,;DONXH<&%I<BD@P]^PH0"[Y[_KP-H@P]^PH0"[Y[_KP-H@
MP]^PH2"[Y[_KOLC'U`#!UKS2`,'6O-*WSP"P_+BN`+[SMO/`S+[NO;H`P:2W
MQ`#!I+?$.@"X\+7.(+RQQ<,`N/"UYR`TN.D`M.O#O""QVP#`W[CXM<@@N:[`
MVK"A(,#6O<"TS[39+@`TO_D`P*_!]K#\N*Z]Q\?@P/P@R*[`SL?/L>(`.+_Y
M`+"AM,G'T2#'RK7E.@"YZ+#F`+GHL.8@N_:Q\@"[_<#/`+&]L-0`L.:PZ`"P
MYK#H(+7.LK(`L.:PZ`"X\+7.`+[&MZ$`L>+(HR"XKKVZQJX`7V6\OR"\T[RZ
M+BXN`+3>M\(`P^N\T@"_P+?Y(+JXL.W'S['B(,/KO-(`Q+B\QP#(WK3KQOD`
MO+\@O-.\N@"\OR#&Y+7Y`+R_(+S3O+H`O+\@L*.PW0#(WK3KQOD`L*&_[K6E
M`+JOL.8`7VNXM<6I(+#+N^<N+BX`P=^QN0"\^+RM(+BNO;K&KB#!OK?Y(+RQ
MQ<,`35._P,?'O;H@Q=>QUR#!]K_LL>(`PZ(@M-VQX@"_WL+*N+>TZR"TW;'B
M`,?5P\3!^""PYK#H`+OVL?(`OZTZ`$-O;6EC<P#(N+OG`+[/R*,@R*[`S@"Z
MN;OG`+JYN^<`36%I;G1E;F%N8V5?5&%S:R"X\+7B("5S(+BF(+^M(+SV(+[X
MO<"TS[39+@"XN+7IL>(`N+7%J2"XN+7IL>(`Q_;`YR!54DS`N@#']L#G(+VZ
MQ;C`SP#`VKBCL>(`P-JXH['B`$1$`,#/NK``LZ_"I0!?;+^M(+OHP:8`,3*_
M^0"\_<#:`+.[ONZ^LK'B`+'BNKL`L>*ZNR"]Q+JPP-H`N^C!I@"\OR"[Z,&F
M`+^M(+OHP:8`Q^`@N^C!I@#']L#G(+^M(,'VO_(`Q_;`YR#'X"#!]K_R`+_`
MM_D@O+.X[0"\L[CM.@"\O+K.P:2ZN+"A(+#\N*[`VKBF(,"GQ]@@L>*WS[7'
MON[!L[W`M,^TV2X`M?"WNL7DN*X`R*VXZ2"\L\&D`&UA:6YT96YA;F-E+G!H
M<+^A(,'WP:(@P:*QV<?/P?8@N+:\O+_D+@##N;GXPK`@Q^#`NB#'U[CQ(,#,
MN*?`NR"PKK#M(,#6O<"TS['N/R"QU[>XM-FXZ2P@OZFQXKBF(,.\Q:G'S[R\
MO^0Z`+.[M\&YWK'B`"5S(+.[M\&YWK'B`+SVP:0`)7,@L<?'T2"\]L&D`+RQ
MQ<.[Y\?7(+SVP:0Z`+_DO-(N+BX`96T`P,RXWL#/`,#,N/#&O,3<`+#AL/H@
MOOC`O0#&[<']L>(@R*ZTZP"QU[BR(%523"#`U+?"`+_`M_D`,36ZT""XMK39
M`#,PP\H@N+:TV0`UNM`@N+:TV0"X\+7G(+?.L=?`S@`S,+K0(+BVM-D`N,6Z
MT`"_N3H`O]["RKBWM.L@R*[`Y0#`_+#FN_8`R*^PYKRSP:0@P-"QXB"_P+?Y
M+@!,1$%0(+RMN?8@P:*\TR"]Q\;0`,;1O;H`,K_Y`,;$P,\@L/RXKL#:`,?*
MQ<T`L=O`VB"[]K'R`,?!M[G`TP#`I\2A`+6VP,\`L*&QX@"S],#,`+6UO_*X
MNP"UM;_RN+L`QL3`S\#'(+W#P-O`S""TV<"]L/H@L+"]P+3/M-DZ`,'](,'6
MO-(`P?T@P/S(K;GXR*,`2&]R9&4`O/;&\KRQ`+"AM\X@PZ2_\@"PH;?..@#'
MU<2AL.T@O<W`NB"_K<#'(+SV`,?7N/$HOZTIP,<@O/8_`,?5Q*&P[2"]S<"Z
M(,?@P,<@O/8`7VZ^U;^A(,?@(,/?L*$`OL;`S,3<`+[&P,S$W+#Z(+FNP-H`
MO<2ZL,#:(,#,N*<Z`+'7N+(@N<RXKKJXL>(Z`+'7N+(@55),`+'7N+(@55),
M.@"PH<&NO\(@Q]>X\3H@)7,`L*'!KK_"(,?7N/$Z`%]SM-G`O;^A(,?@(,/?
ML*$`M>F_J;ZRL>(`7V^TV<"]OZ$@OZT@P]^PH0"QU[BR(,/?L*$`QZ4@P]^P
MH0#`I2"XM<6I(,/?L*$`7V.^U;^A(+^M(,/?L*$`Q_;`YR"_K2"UVK^A(+OU
M(+^M(,/?L*$`Q_;`YR"_K2"^U;^A(+OU(+^M(,/?L*$`Q_;`YR#'X""UVK^A
M(+OU(,?@(,/?L*$`Q_;`YR#'X""^U;^A(+OU(,?@(,/?L*$`Q_;`YR#!]L&A
M(+7:OZ$@M-RV]"##W["A`,?VP.<@P?;!H2"^U;^A(+3<MO0@P]^PH0"UVK^A
M(+R_(,/?L*$`OM6_H2"\OR##W["A`+7:OZ$@OZT@P]^PH0"^U;^A(+^M(,/?
ML*$`M=J_H2"TW+;T(,/?L*$`OM6_H2"TW+;T(,/?L*$`M=J_H2#'X"##W["A
M`+[5OZ$@Q^`@P]^PH0"QU[BR(,/?L*$OO/;!I`"XM<6I(,/?L*$OO/;!I`"Q
MXK_OP,RQX@`QO_D`P,^ZNP#`S[J[ONX@*$E33RTR,#(R+4I0*0`WO_D`-K_Y
M`,&DM\0`L*&_[K6E(,&DM\0`ON?"RB#!I+?$`+_>PLH@P:2WQ`"_P+BEPLH@
MP:2WQ`"TZ\?1N<ZQN0#'T;&YONX@*$550RU+4BD`OO"^[@"XML'VN+<@M\ZQ
MU\#..B`E<P"XML'VN+<@M\ZQU\#..B`E<RP@P:*\TR#`I\2A.B`E<P"XML'V
MN+<@M\ZQU\#..B"^^,"]`+>YP,R^QK_T`+_>PLH`M;6_\K[+(+CQPO<`N^>_
MZ\?2(+SV(+[XM,(@N^>_Z\#:(+CQM\\N`+?.L=?`S@"WSK'7OL:_]`"WSK'7
MP,X@O</`V\#;OO<`L=>XKKVZ(+S2N:[`V@"V\\:^(+S2N:[`V@"WSKBV(+S2
MN:[`VB"\_<#:`$U-`+C>P,\`7VNXM<6I(+BXM>FQXBXN+@`SO_D`L*'`Y<#:
MN*X`P,_$H<?/M,(@Q]>X\0`UO_D`N-ZTNB"X\+7E`+R_(,?5Q*&QX@"XWKW#
MP?8`L*&_[K6E`%523""\]L&D`+C%O_D`OL:WH;?.(,#,M;\`P*>WSB#`S+6_
M`,#,N*<`L]?&KK_VQ:D`N^>_Z[[(Q]0`N_4@PZ(H7V)L86YK*0"TV<"]`+[&
MM,^_P`!&5%`@5D93N*8@P*?'T2"\L\&DP:2ZN+"A(+[XO<"TS[39+@!344P@
M5D93(+RSP:3!I+JXL*$@OOB]P+3/M-DN`%-13"U&:6QE(%9&4R"\L\&DP:2Z
MN+"A(+[XO<"TS[39+@"\L<7#Q\_!]B"^RL"]`,+\P;8`,3&_^0"_K<#'(+SV
M`,?@P,<@O/8`,3"_^0"[]2##HK^A(+BUQ:D@OZVQX@"\L<7#N^?'UP`E<R"\
ML<7#N^?'UP"\_<#:(+CQM\\`M-S#O`"QXL6X`+'BQ;@@P:2ZN`#&Y+7Y`+[/
MR*,`OL_(H["A(,#/Q*''S\'V(+[*O<"TS[39+@"ZV<#,L>(`Q:RXL[JXM>6_
MH;RM(+K9P,RQX@"PYK?.`,;;O+[&K@#`K\'V(+#\N*X@P-N^]R"]Q\?@`+"S
MP,X@P:2ZN`#`_,BMN?C(HP#'R+R_`+FNP::_H2"TZ\?1(+_DON#`NR#`U+?"
MQ]@@P=:\O+_D+@"[Y[_KP-K`S+BGL/H@OL_(H[BF(,#4M\+'S[R\O^0`N<RX
MKKJXL>(`N_4@PZ*_H2"YS+BNNKBQX@"YKKRM(,#.O.(`N:[!IB"\L[CM`+BV
MP?:XMR"X[;?)(+G=NKD`QN2^[BAP86ER*2"[Z,&F`,#4M\(@P^N\T@"_R;S'
MP+BWSB"UN;[&L*&QX@"_P+BEPLH`7W?'X""\T[RZ+BXN`+^JQ](`Q^`@O-.\
MN@#'X""\T[RZ`,?@.@"PL,"Z(,?!M[G`TRA?<V5L9BD`P/K`Y0"\L<7#N^?'
MUR#`^L#E`+#+N_8`OL:WH2"[\\#:OZ&\K2#'RK_DQ]$@N:[`VKBF(+RQQ</'
MS[#M(+JYN^?'S[^I(+K9OZFSUL"XO+R_Y"X`LZ_`VB"QN+K0QZ6]PR"\L<7#
M.@"SK\#:(,?\O<0@O+'%PP"]P["C(,?\O<0@O+'%PP"USK"SP,<@P,_$H<?/
MM,(@Q]>X\2"\L<7#`,#:P=:[Y[_KQ\^TPB"^\+[NN*8@O+'%P\?/O+R_Y"X`
MN:[!IKG?N_T@NKBP[;RM(,#\O-O'S['B`#F_^0"\OR"\T[RZPZ(@NKBQX@#'
MI2"\T[RZPZ(@NKBQX@"_K2"\T[RZPZ(@NKBQX@"QU[BR(+S3O+K#HB"ZN+'B
M`,6IL>(`P*_!]K#\N*X@N_VWJP"\O["CL-T`O+\@L.:PZ+_-(+.[O^L@N^?`
MS,#'(+"CL-T`L,6XK@"PQ;BNO\T@PZ2_[+'B`,:OO/8@N:[`VB#`U+?"`+R_
M(+K0Q](`OZT@NM#'T@#'X""ZT,?2`+"AO^ZUI<'9`+VZQ;C`SUM#4U-=`,&F
MN/$`P:;#X@"^QK>AP[?`V@"\NK#X`+_DON``P*W#M\#:`,>E(+S3O+H`QZ4@
MO-.\N@#`V[[W`+FNP-J_K0"YKL#:`+FNP-H@P:2WQ`"[Y[_KQ]C!UKS%O*T@
ML*B[Y\?5M,^TV2X`QL3`S[^A(+[&N:NWL2#`VK?AL*$@OOB]P+3/M-DN`+[&
MMZ&TPB#`S"!M97-S86=E+W)F8S@R,B#&[<'VP,<@N-.XM+B[P-2TS[39+@"]
MQ+JPP-H@(B5S(B"PH2"[Z,&FM<>^^KW`M,^TV2X`P,R_Z["AM,G'T2"\L<7#
MN^?'U\#,(+[XO<"TS[39+@#&Q,#/(+_#N*ZQXK^A(+FNP::PH2#`UKW`M,^T
MV2X@)7,@QL3`S\#,(+[WM\ZUY;7'P?8@OLJ^TKW`M,^TV2X`P,P@O/W`VK3"
M(,/6O-+'T2`QP-JXKB#`S+OSP,R^[K[?(,?5M,^TV2X`P,P@L*K`NB"\_<#:
MOZF^WR#'U;3/M-DN`,&FN/$`Q;C`S,:R*,7XQL$I.@"YWK3"(+OGMO<`2%1-
M3""\TKVZ(+JXL>(`P*<`N_/`IR#'P;>YP-,H7W1O<"D`55),`%9&4R#&Q,#/
M("5S+R5SP,<@QMNYS+S'P+L@NJ^PYL?2(+SV(+[XO<"TS[39+@!344P@O*VY
M]K^A(,&BO-/'TB"\]B"^^+W`M,^TV2X`)7,@P:3`Q[BF(,#0P+L@O/8@OOB]
MP+3/M-DN`'9F<W)O;W0@M?"WNL7DN*ZXIB#`T,"[(+SV(+[XO<"TS[39+@!6
M1E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN`,#,(+_V
MM>6YKKRMN*8@NJ^PYL?2(+SV(+[XO<"TS[39+@"YV,'9`+JOL.:[Y\?7(+7'
MM;FXKK'B`+BVP?:XMR"X[;?)(,/KO-(`O[6QN0"YS+&Y`,?VP.<@O^2\TK^A
M(+BUQ:D@P::PQ0#`S+BG(+[XP+T`N_:Q\B#!IK#%`+;SQKZ^[B"TZ[FNP-H`
MM\ZXMB"TZ[FNP-H@O/W`V@"[Y[_KP-H@O+'%P[OGQ]<`N^>_Z\#:N.T`O<.]
MNL7;P,<@N^>_Z\#:.@"\]L'W(,&DM\0`O/;!]R##I+_R`"5S(+JXL>(`L.:P
M[0"XQ<'6`,BOO[4`R*^_M<?5M,^TV2$@)7,@P-2TS[39+@#(K[^UQ]6TS[39
M+"`E<P"QN+K0(+FNP-JTPB"YJ[[YP-2TS['N/P#`SK_K(+K.R*.TPB"YJ[[Y
MP-2TS['N/P"SRKKQ`,>EP,<@L\JZ\0"SRKKQ(+3<P*<`L\JZ\3H`P??`Y2#!
MUKS2.@#!]\#E(,#\R*VY^,BC`%E9`+C%L^(`O[D`5$585+CPM>7`U+3/M-DN
M(%L\/ET@N?;&L,"[(+2IN*.XZ2!765-)5UE'(+CPM>6WSB"UN;[&L*FTS[39
M+@"WSK'7OL:_]"#'S[^TO<"TS[39+@"YKL&F(+JXL.V\K;BF(+JXL[NQXL#\
MOZ$@P,RYKL&FOZ$@M.O'T2"\L[CMP+L@P-2WPL?8OM\@Q]6TS[39+@#`S""X
MM<6IL*$@L*&XKL2AM,(@55),P+L@P-2WPL?8OM\@Q]6TS[39+@"[Z,&FQ](@
MN^>_Z\#:(,#,N*?`NR#`U+?"Q]B^WR#'U;3/M-DN`,/?L*''TB"[Y[_KP-H@
MP,RXI\"[(,#4M\+'V+[?(,?5M,^TV2X`)7,@O+R\Q\#,(+BXM^&UQ[[ZO<"T
MS[39+B"TV;W#(+?.L=?`SL?/O+R_Y"X`P,RXWL#/(,'6O-(Z`+C>P,\@P=:\
MTCH`P:2ZN`#`S+BG.@"TY[W%P,<@P,[!]<6LMO/`S+[PQJZPH2"[Y[_KP-H@
MN/&WS[JXL>*XIB#!]K_XQ\_!]B"^RKW`M,^TV2X@ML>TPB"TV;BE(,#,P*^W
MSB"[Y[_KP-H@N/&WS[JXL>*XIB"[Y[_KQ](@O/8@OOB]P+3/M-DN`+KJMO._
M[,#ZL*$@P,P@L>*TR<"[(,'VO_C'S\'V(+[*O<"TS[39+@#']L#G(+W#L*.T
MZSH`L>*ZNR"]Q+JPP-HZ`,#\P[P@P,RXISH`P,P@O+R\QR"UO[[((+_)O,?`
MS"#`^L#EM<NTS[39+@"_R;S'P,P@P/K`Y;7'OOJ]P+3/M-DN`%O`SK_K(+S[
ML>*QXET`6[_`M_D@NKBP[<?/L>)=`%O`SK_K(+JXL>(@+0!;P,Z_ZR"ZN+'B
M("T@)7,@P=E=`%NV\\#.("5S("\@)7-=`%]!L/RXK@!?1,?@(,'VO_(`M;6_
M\KB[`%])L=>XLB"\T[RZ+BXN`%],M\ZQU[[&O_0`7VVXM<6I(+SVP:0N+BX`
M7T^\L<7#N^?'UP!?<KBUQ:D@N^C!IBXN`%]TQZ4@O-.\NBXN+@#!V5T`P,RX
MIP#&V[R^QJX`Q\B\OP#`S+BG(+[XP+T`=D-A<F0`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O:V]?2U(O:&5L<"YX
M;6P`````````````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,S
M,C`@,3`U,34T,S,W-#$@,#(Q-#4R`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_>&UL('9E<G-I;VX](C$N,"(_/@H\(2TM
M("1(;W)D93H@:&]R9&4O;&]C86QE+VMO7TM2+VAE;'`N>&UL+'8@,2XR(#(P
M,#0O,#4O,C<@,C`Z,C(Z,30@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT
M<GD@:60](G-U;6UA<GDB('-T871E/2)N97<B/@H\=&ET;&4^5&AE(%!O<G1A
M;"!086=E/"]T:71L93X*(#QP87)A/@H@(%1H:7,@<&]R=&%L('!A9V4@<')O
M=FED97,@82!Q=6EC:R!S=6UM87)Y(&]F(&%L;"!Y;W5R(&EM<&]R=&%N=`H@
M(&EN9F]R;6%T:6]N+B!&;W(@97AA;7!L92P@:70@;6EG:'0@<VAO=R!H;W<@
M;6%N>2!N97<@92UM86EL(&UE<W-A9V5S('EO=0H@(&AA=F4@:6X@>6]U<B!)
M3D)/6"P@=7!C;VUI;F<@979E;G1S(&]N('EO=7(@8V%L96YD87(L('1A<VMS
M(&]N('EO=7(@=&\M9&\*("!L:7-T+"!H96%D;&EN97,@9G)O;2!S96QE8W1E
M9"!N97=S('-E<G9I8V5S+"!A;F0@<V\@;VXN("!-86YY(&]F('1H97-E"B`@
M<W5M;6%R:65S('=I;&P@8V]N=&%I;B!Q=6EC:R!S:&]R=&-U=',@=&\@8V]M
M;6]N(&9U;F-T:6]N<RP@<W5C:"!A<PH@(&-O;7!O<VEN9R!A(&YE=R!M86EL
M(&UE<W-A9V4L(&-R96%T:6YG(&$@;F5W(&-A;&5N9&%R(&5V96YT(&]R('1A
M<VLL(&5T8RX*(#PO<&%R83X*(#QP87)A/@H@(%1H92!C;VYT96YT<R!O9B!T
M:&ES('!O<G1A;"!P86=E(&%R92!C=7-T;VUI>F%B;&4@=FEA('1H92!,87EO
M=70@8G5T=&]N+@H@($9O<B!E>&%M<&QE+"!Y;W4@8V%N(&-H;V]S92!W:&EC
M:"!I=&5M<R!T;R!I;F-L=61E(&]N('1H:7,@<&]R=&%L('!A9V4@87,*("!W
M96QL(&%S(&EN('=H:6-H(&]R9&5R('1H97D@87)E('-H;W=N+@H@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB;F%V8F%R(B!S=&%T93TB;F5W(CX*
M/'1I=&QE/E1H92!!<'!L:6-A=&EO;B!.879I9V%T:6]N($)A<CPO=&ET;&4^
M"B`\<&%R83X*("!!="!T:&4@;&5F="!H86YD('-I9&4@;V8@=&AE('=E8B!P
M86=E(&ES('1H92!A<'!L:6-A=&EO;B!N879I9V%T:6]N(&)A<BX*("!#;&EC
M:R!O;B!T:&4@:6-O;G,@;VX@=&AI<R!N879I9V%T:6]N(&)A<B!T;R!Q=6EC
M:VQY(&%N9"!E87-I;'D@<W=I=&-H"B`@8F5T=V5E;B!T:&4@879A:6QA8FQE
M(&%P<&QI8V%T:6]N<RX*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(G!R969S+61O7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L
M93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($1O($UA:6YT96YA;F-E/"]T
M:71L93X*("`@(#QP87)A/@H@("`@268@>6]U('=O=6QD(&QI:V4@=&\@<&5R
M9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN+"!C:&5C:R!T
M:&ES(&)O>"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R
M969S+6-O;F9I<FU?;6%I;G1E;F%N8V4B('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@0V]N9FER;2!-86EN=&5N
M86YC93PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME
M('1O(&-O;F9I<FT@86QL(&UA:6YT96YA;F-E('1A<VMS(&)E9F]R92!T:&5Y
M(&%R92!R=6XL(&-H96-K('1H:7,@8F]X+B!)9B!L969T('5N8VAE8VME9"P@
M86QL(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@=&AA="!N965D('1O(&)E(')U
M;B!W:6QL(&)E('!E<F9O<FUE9"!A=71O;6%T:6-A;&QY('=I=&@@;F\@8VAA
M;F-E('1O(&-A;F-E;"!O;B!L;V=I;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*
M/"]H96QP/@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VQT7TQ4````````````````
M````````````````````````````````````````````````````````````
M`````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P
M-3$U-#,S-S0Q(#`Q-S<S-``@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O
M;'1?3%0O3$-?34534T%'15,`````````````````````````````````````
M````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W-#$@,#(Q-3(Q`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQO8V%L92]L=%],5"],0U]-15-304=%4R]H;W)D92YM;P``
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#,S,C(T,B`Q,#4Q-30S,S<T,2`P
M,C,R-#0`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````WA($E0````!T!@``'````+PS``";"```7&<```````#(B0``#@```,F)
M```/````V(D```@```#HB0``#````/&)```$````_HD```P````#B@``#P``
M`!"*```+````((H```X````LB@``!0```#N*```H````08H```H```!JB@``
M%0```'6*```2````BXH```L```">B@``#@```*J*```*````N8H```T```#$
MB@``#@```-**```1````X8H```T```#SB@``#`````&+```-````#HL```8`
M```<BP``#P```".+```8````,XL```P```!,BP``#@```%F+```.````:(L`
M``@```!WBP``+@```("+```:````KXL``#(```#*BP``.````/V+``!4````
M-HP``%$```"+C```6@```-V,``!7````.(T``#0```"0C0``"@```,6-```%
M````T(T```8```#6C0``$0```-V-```(````[XT```D```#XC0``"0````*.
M```E````#(X``"`````RC@``$````%..```/````9(X```H```!TC@```P``
M`'^.```/````@XX``!0```"3C@``"0```*B.```-````LHX``!(```#`C@``
M#P```-..```*````XXX```\```#NC@``"````/Z.```D````!X\``!0````L
MCP``%@```$&/```(````6(\``!D```!ACP``!P```'N/```,````@X\``"P`
M``"0CP``#@```+V/```#````S(\```L```#0CP``!P```-R/```'````Y(\`
M``4```#LCP``!0```/*/```*````^(\```,````#D```%P````>0```*````
M'Y````\````JD```#@```#J0```8````29```",```!BD```#@```(:0```4
M````E9```!<```"JD```%P```,*0```7````VI```!,```#RD```#P````:1
M```.````%I$``!\````ED0``!P```$61```&````39$```@```!4D0``#P``
M`%V1```&````;9$```H```!TD0``$P```'^1```+````DY$``!4```"?D0``
M%0```+61```'````RY$```4```#3D0``%0```-F1```1````[Y$```P````!
MD@``.P````Z2```)````2I(```<```!4D@``%````%R2```#````<9(```4`
M``!UD@``$````'N2```)````C)(``!,```"6D@``.0```*J2```2````Y)(`
M`"<```#WD@``+````!^3```J````3),``"4```!WDP``"@```)V3```&````
MJ),```D```"ODP``!P```+F3```O````P9,``#<```#QDP``+@```"F4``!5
M````6)0``"T```"NE```+0```-R4```M````"I4``$`````XE0``(P```'F5
M```C````G94``"T```#!E0``,P```.^5```5````(Y8``!D````YE@``*0``
M`%.6```D````?98``!$```"BE@``"@```+26```,````OY8```H```#,E@``
M$````->6```6````Z)8``!8```#_E@``!P```!:7```'````'I<``!0````F
MEP``"@```#N7```(````1I<```@```!/EP``!P```%B7```'````8)<```8`
M``!HEP``!0```&^7```'````=9<```8```!]EP``"````(27```.````C9<`
M``H```"<EP``!````*>7```'````K)<```D```"TEP``!@```+Z7```1````
MQ9<```<```#7EP``%@```-^7```$````]I<```@```#[EP``!@````28```-
M````"Y@```8````9F```'@```""8```1````/Y@```@```!1F```#0```%J8
M```,````:)@```<```!UF````P```'V8```#````@9@``!<```"%F```$P``
M`)V8```(````L9@```0```"ZF```"````+^8```(````R)@``$$```#1F```
M(````!.9```&````-)D```8````[F0``%0```$*9```8````6)D``"(```!Q
MF0``+@```)29```=````PYD``"$```#AF0``5`````.:```I````6)H```H`
M``""F@``!P```(V:```5````E9H```X```"KF@``"@```+J:```/````Q9H`
M``T```#5F@``#P```..:```-````\YH```D````!FP``%`````N;```&````
M()L``!@````GFP``'0```$";```3````7IL``!0```!RFP``!````(>;```&
M````C)L``%0```"3FP``!````.B;```.````[9L```4```#\FP``!0````*<
M```;````")P``!H````DG```$0```#^<```1````49P``!P```!CG```*@``
M`("<```0````JYP``"$```"\G```!0```-Z<```3````Y)P``!(```#XG```
M"@````N=```/````%IT``!$````FG0``$P```#B=```,````3)T```8```!9
MG0``!@```&"=```7````9YT``!$```!_G0``"````)&=```%````FIT```P`
M``"@G0``$````*V=```%````OIT```T```#$G0``!@```-*=```'````V9T`
M``T```#AG0``!P```.^=```+````]YT```<````#G@``!P````N>```)````
M$YX```H````=G@``&0```"B>```,````0IX``!````!/G@``!0```&">```E
M````9IX``!(```",G@``$P```)^>```K````LYX``#L```#?G@``(````!N?
M```V````/)\```@```!SGP``#````'R?```&````B9\```0```"0GP``#@``
M`)6?```*````I)\```T```"OGP``'@```+V?```;````W)\``"$```#XGP``
M'@```!J@```9````.:```!X```!3H```&P```'*@```F````CJ```!L```"U
MH```'@```-&@```<````\*```"8````-H0``,P```#2A```F````:*$``"L`
M``"/H0``.````+NA```O````]*$``!(````DH@``*0```#>B```2````8:(`
M`*(```!TH@``%@```!>C```C````+J,``"@```!2HP``*0```'NC```H````
MI:,``!\```#.HP``(````.ZC```E````#Z0``"$````UI```'````%>D```F
M````=*0``$$```";I```#````-VD```'````ZJ0```<```#RI```!@```/JD
M```-`````:4``!`````/I0``$@```""E```3````,Z4``!(```!'I0``!P``
M`%JE```$````8J4```P```!GI0``#@```'2E```/````@Z4``!,```"3I0``
M#0```*>E```H````M:4```,```#>I0``#0```.*E```&````\*4``!$```#W
MI0``%P````FF```;````(:8```X````]I@```@```$RF```%````3Z8``!``
M``!5I@``!````&:F```-````:Z8```X```!YI@```P```(BF```.````C*8`
M``@```";I@``#P```*2F```/````M*8```T```#$I@``$````-*F```+````
MXZ8```8```#OI@``#````/:F```1`````Z<``!D````5IP``"P```"^G```-
M````.Z<``"(```!)IP``"@```&RG```8````=Z<``!D```"0IP``%@```*JG
M```-````P:<```<```#/IP``%````->G```+````[*<``"(```#XIP``+P``
M`!NH```+````2Z@```D```!7J```&0```&&H```+````>Z@``!<```"'J```
M%P```)^H```)````MZ@``!8```#!J```#P```-BH```6````Z*@```X```#_
MJ```&`````ZI```(````)ZD```T````PJ0``)@```#ZI``!#````9:D```@`
M``"IJ0``$@```+*I```(````Q:D```L```#.J0``+P```-JI```.````"JH`
M``4````9J@``!@```!^J```#````)JH```<````JJ@``!````#*J```*````
M-ZH```H```!"J@``#P```$VJ```0````7:H``!<```!NJ@``$0```(:J```7
M````F*H```D```"PJ@``!0```+JJ```+````P*H```H```#,J@```@```->J
M```%````VJH```T```#@J@``&P```.ZJ```7````"JL```D````BJP``#@``
M`"RK```-````.ZL``!(```!)JP``.````%RK```@````E:L```@```"VJP``
M#@```+^K``![````SJL``!@```!*K```$0```&.L```'````=:P```4```!]
MK```&0```(.L```'````G:P```@```"EK```!@```*ZL```&````M:P``!``
M``"\K```#P```,VL```0````W:P```\```#NK```"P```/ZL```/````"JT`
M``P````:K0``#P```">M```'````-ZT```8````_K0``#````$:M```H````
M4ZT```\```!\K0``"````(RM```(````E:T``!,```">K0``'@```+*M```A
M````T:T``"````#SK0``&0```!2N```7````+JX``"4```!&K@``%P```&RN
M```$````A*X``!L```")K@``#0```*6N```#````LZX```@```"WK@``"@``
M`,"N```,````RZX```L```#8K@``!````.2N```3````Z:X``!0```#]K@``
M#````!*O```)````'Z\```X````IKP``"P```#BO```;````1*\```<```!@
MKP``!P```&BO```*````<*\```T```![KP``"0```(FO```$````DZ\```4`
M``"8KP```P```)ZO```8````HJ\```H```"[KP``!````,:O```F````RZ\`
M``X```#RKP``?`````&P```5````?K````4```"4L```!P```)JP```,````
MHK````@```"OL```"@```+BP```&````P[````@```#*L````@```-.P```&
M````UK````8```#=L```%````.2P```-````^;```!`````'L0``&P```!BQ
M```$````-+$```D````YL0``$````$.Q```)````5+$```D```!>L0``!0``
M`&BQ```:````;K$```@```")L0``!@```)*Q```9````F;$```X```"SL0``
M!P```,*Q```'````RK$```4```#2L0``"0```-BQ```*````XK$```(```#M
ML0``!@```/"Q```-````][$```D````%L@``!@````^R```2````%K(```D`
M```IL@``!P```#.R```4````.[(``!T```!0L@``!@```&ZR```*````=;(`
M``0```"`L@``"0```(6R```(````C[(``!$```"8L@``"0```*JR```&````
MM+(```T```"[L@``!@```,FR```$````T+(``#D```#5L@``/0````^S```Z
M````3;,``!X```"(LP``!0```*>S```.````K;,```0```"\LP``!@```,&S
M```A````R+,``!4```#JLP``!@````"T```$````![0``!$````,M```!@``
M`!ZT```*````);0``"(````PM```!````%.T```%````6+0``!T```!>M```
M!````'RT```,````@;0```H```".M```"````)FT```)````HK0```4```"L
MM```.@```+*T```P````[;0``#4````>M0``*0```%2U``!'````?K4``#@`
M``#&M0``*0```/^U```_````*;8``"X```!IM@``+0```)BV```?````QK8`
M``\```#FM@``$@```/:V```+````";<``"8````5MP``*0```#RW```D````
M9K<``"8```"+MP``"````+*W```*````N[<```D```#&MP``!P```-"W```@
M````V+<``"````#YMP``)@```!JX```*````0;@``!D```!,N```*0```&:X
M```6````D+@``!(```"GN```!P```+JX```*````PK@```\```#-N```$```
M`-VX``!`````[K@``&8````ON0``#@```):Y```)````I;D```H```"ON0``
M$@```+JY```3````S;D```P```#AN0``!@```.ZY```/````];D``!(````%
MN@``$````!BZ```1````*;H``!P````[N@``(P```%BZ``!J````?+H```\`
M``#GN@``!0```/>Z```0````_;H```D````.NP``!````!B[```+````';L`
M`!0````INP``#````#Z[```,````2[L```\```!8NP``%0```&B[```I````
M?KL``"H```"HNP``)@```-.[```G````^KL``"D````BO```*@```$R\```9
M````=[P``$(```"1O```$0```-2\```2````YKP``!,```#YO```%`````V]
M```/````(KT``!8````RO0``%P```$F]```0````8;T``!$```!RO0``-```
M`(2]```3````N;T``!(```#-O0``-0```."]```4````%KX```<````KO@``
M#````#.^```@````0+X``!0```!AO@``$0```':^```7````B+X``!P```"@
MO@``$P```+V^```1````T;X``!H```#CO@``'@```/Z^```:````';\``!$`
M```XOP``%````$J_```7````7[\``!4```!WOP``"0```(V_```9````E[\`
M``0```"QOP``!P```+:_```+````OK\``!$```#*OP``!@```-R_```&````
MX[\```8```#JOP``!0```/&_```'````][\```<```#_OP``!0````?````6
M````#<````8````DP```!@```"O````$````,L````0````WP```!P```#S`
M```.````1,````P```!3P```#````&#````-````;<````H```![P```#@``
M`(;````%````E<```"@```";P```#@```,3````,````T\````\```#@P```
M"@```/#````(````^\````D````$P0``*P````[!```$````.L$```@````_
MP0``)@```$C!```2````;\$```\```""P0``!@```)+!```*````F<$```<`
M``"DP0``"````*S!```@````M<$```D```#6P0``#````.#!```-````[<$`
M``X```#[P0``%@````K"```1````(<(```8````SP@```P```#K"```&````
M/L(``!D```!%P@``!P```%_"```$````9\(```L```!LP@``"P```'C"```'
M````A,(```<```",P@``%@```)3"```-````J\(```T```"YP@``"@```,?"
M```0````TL(```\```#CP@``$0```//"```7````!<,```H````=PP``$0``
M`"C#```(````.L,```0```!#PP``#P```$C#```Z````6,,```4```"3PP``
M#````)G#```>````IL,```X```#%PP``$````-3#```+````Y<,```P```#Q
MPP``"0```/[#```'````",0```H````0Q```"0```!O$```.````)<0``!``
M```TQ```&@```$7$```*````8,0```D```!KQ```"@```'7$```,````@,0`
M``\```"-Q```"````)W$```&````IL0```<```"MQ```"P```+7$``!'````
MP<0```T````)Q0``"0```!?%```$````(<4```,````FQ0``$P```"K%```3
M````/L4``!,```!2Q0``"@```&;%```"````<<4```0```!TQ0``)0```'G%
M```#````G\4```4```"CQ0``*@```*G%```*````U,4```4```#?Q0``!```
M`.7%```*````ZL4```T```#UQ0``!@````/&```(````"L8```@````3Q@``
M!````!S&```%````(<8``&@````GQ@``"0```)#&```,````FL8```4```"G
MQ@``!@```*W&```;````M,8``"\```#0Q@``$`````#'```*````$<<```\`
M```<QP``"@```"S'```)````-\<``!,```!!QP``&P```%7'```8````<<<`
M`!<```"*QP``#@```*+'```#````L<<```<```"UQP``"````+W'```'````
MQL<```H```#.QP``"P```-G'```'````Y<<``%$```#MQP``$````#_(```,
M````4,@```T```!=R```&@```&O(``!*````AL@```8```#1R```!@```-C(
M```&````W\@``!\```#FR```!@````;)```)````#<D``!@````7R0``%P``
M`##)```&````2,D```T```!/R0``(@```%W)``!7````@,D``!,```#8R0``
M(P```.S)```3````$,H```(````DR@``"P```"?*```(````,\H```T````\
MR@``"@```$K*```'````5<H``!0```!=R@``!@```'+*```(````><H```X`
M``""R@``!P```)'*```*````F<H```L```"DR@``!P```+#*```,````N,H`
M``T```#%R@``#````-/*```)````X,H```D```#JR@``"@```/3*```'````
M_\H```D````'RP``!P```!'+```*````&<L``!L````DRP``$@```$#+```*
M````4\L```D```!>RP``$````&C+```'````><L``!(```"!RP``!````)3+
M```'````F<L```4```"ARP``!0```*?+```+````K<L``!0```"YRP``$0``
M`,[+```:````X,L``!8```#[RP``%````!+,```7````)\P``!@````_S```
M'````%C,```9````=<P```<```"/S```!0```)?,```-````G<P```P```"K
MS```"````+C,```7````P<P```L```#9S```$P```.7,```$````^<P```H`
M``#^S```!`````G-```,````#LT```D````;S0``!0```"7-```'````*\T`
M``4````SS0``!````#G-```"````/LT``#@```!!S0``+````'K-```2````
MI\T``"D```"ZS0``,@```.3-```*````%\X``"P````BS@``+@```$_.```S
M````?LX``#,```"RS@``.````.;.```/````'\\``!@````OSP``$````$C/
M```3````6<\``!0```!MSP``$@```(+/```4````E<\``!4```"JSP``+0``
M`,#/```M````[L\``#$````<T```+@```$[0```O````?=```"P```"MT```
M8@```-K0```3````/=$```@```!1T0``"````%K1```K````8]$``"$```"/
MT0``&@```+'1```)````S-$``$4```#6T0``00```!S2```$````7M(``!,`
M``!CT@``%````'?2```.````C-(``!,```";T@``&````*_2```&````R-(`
M``D```#/T@``"@```-G2```/````Y-(``!````#TT@``!P````73```.````
M#=,```4````<TP``&P```"+3```(````/M,```8```!'TP``%````$[3```1
M````8],```X```!UTP``.````(33```"````O=,```8```#`TP``#@```,?3
M```%````UM,```<```#<TP``#@```.33```&````\],```0```#ZTP``*0``
M`/_3```7````*=0``!\```!!U```7````&'4```4````OM0``!\```#3U```
M$````//4```'````!-4```X````,U0``#````!O5```,````*-4``!,````U
MU0``"@```$G5```=````5-4``!D```!RU0``!0```(S5```1````DM4``!$`
M``"DU0``)````+;5```5````V]4``!(```#QU0``#@````36```9````$]8`
M``@````MU@``"0```#;6```-````0-8```H```!.U@``"P```%G6```*````
M9=8```<```!PU@``"````'C6```%````@=8``!\```"'U@``!@```*?6```0
M````KM8```@```"_U@``#0```,C6```(````UM8``!(```#?U@``+````/+6
M```:````']<```D````ZUP``"@```$37```5````3]<```4```!EUP``%```
M`&O7```$````@-<``!````"%UP``!@```);7```'````G=<``!X```"EUP``
M*````,37```*````[=<``!H```#XUP``%````!/8```$````*-@```0````M
MV```"P```#+8```%````/M@```8```!$V```"````$O8```&````5-@```H`
M``!;V```&P```&;8```T````@M@``#0```"WV```(````.S8```I````#=D`
M`"`````WV0``00```%C9```:````FMD``"@```"UV0``*0```-[9```B````
M"-H```8````KV@``"````#+:```%````.]H```@```!!V@``&0```$K:```9
M````9-H``"H```!^V@``(P```*G:```N````S=H``#0```#\V@``"````#';
M```7````.ML```H```!2VP``!P```%W;```A````9=L``!````"'VP``#@``
M`)C;```+````I]L```<```"SVP``$P```+O;```(````S]L```L```#8VP``
M"@```.3;```4````[]L``#(````$W```"P```#?<```%````0]P```4```!)
MW```%P```$_<```/````9]P```0```!WW```"@```'S<```)````A]P```L`
M``"1W```#@```)W<```%````K-P```0```"RW```#0```+?<```R````Q=P`
M`$4```#XW```%P```#[=```>````5MT``!0```!UW0``!0```(K=```4````
MD-T```<```"EW0``#@```*W=```J````O-T```8```#GW0``#````.[=```-
M````^]T``!$````)W@``"P```!O>```V````)]X```H```!>W@``(@```&G>
M```+````C-X```\```"8W@``,@```*C>```%````V]X```X```#AW@``$P``
M`/#>```'````!-\``!$````,WP``!P```![?```4````)M\``!@````[WP``
M!P```%3?```%````7-\```P```!BWP``#````&_?```2````?-\```0```"/
MWP``!P```)3?```*````G-\```L```"GWP``#````+/?```.````P-\```X`
M``#/WP``!0```-[?```%````Y-\``"X```#JWP``)@```!G@```C````0.``
M``,```!DX```$@```&C@```&````>^```!X```""X```&````*'@```E````
MNN````T```#@X```"0```.[@```#````^.````<```#\X```"@````3A```"
M````#^$```P````2X0``%0```!_A```+````->$``!D```!!X0``(````%OA
M```2````?.$```4```"/X0``"@```)7A```5````H.$``!(```"VX0``#```
M`,GA```$````UN$```<```#;X0``#````./A``!2````\.$``!<```!#X@``
M!P```%OB```&````8^(```X```!JX@``#````'GB```-````AN(``!4```"4
MX@``$@```*KB```/````O>(``!0```#-X@``&P```.+B```0````_N(``&D`
M```/XP``&@```'GC```7````E.,``"<```"LXP``&@```-3C```7````[^,`
M`!L````'Y```&0```"/D```?````/>0``!,```!=Y```"````''D```'````
M>N0```@```""Y```"0```(OD```5````E>0```T```"KY```$P```+GD```#
M````S>0``$8```#1Y```/P```!CE```W````6.4``%<```"0Y0``'P```.CE
M```O````".8```H````XY@``"````$/F```-````3.8``"T```!:Y@``!```
M`(CF``!/````C>8``"4```#=Y@``'`````/G```+````(.<``!\````LYP``
M'0```$SG```E````:N<``"````"0YP``)````+'G```@````UN<```L```#W
MYP``!P````/H```-````"^@```P````9Z```!@```";H```Y````+>@```P`
M``!GZ```!P```'3H```)````?.@``!,```"&Z```"0```)KH```$````I.@`
M`!````"IZ```"````+KH```(````P^@```L```#,Z```#````-CH```:````
MY>@```\`````Z0``!P```!#I```-````&.D``!0````FZ0``#@```#OI```,
M````2ND``!L```!7Z0``+````'/I```3````H.D``!P```"TZ0``*````-'I
M```&````^ND```<````!Z@``$P````GJ```%````'>H```0````CZ@``%P``
M`"CJ```*````0.H```P```!+Z@``"0```%CJ```&````8NH```D```!IZ@``
M"````'/J```)````?.H```H```"&Z@``$0```)'J```&````H^H```X```"J
MZ@``#@```+GJ```-````R.H```L```#6Z@``'0```.+J```+`````.L```(`
M```,ZP``!P````_K```&````%^L```D````>ZP``!P```"CK```[````,.L`
M`"@```!LZP``%0```)7K```%````J^L```<```"QZP``"````+GK```'````
MPNL```4```#*ZP``!P```-#K```.````V.L```D```#GZP``!@```/'K```(
M````^.L```L````![```!P````WL```(````%>P```<````>[```%@```";L
M```)````/>P```8```!'[```"P```$[L```<````6NP``!0```!W[```!P``
M`(SL```(````E.P```@```"=[```!0```*;L```0````K.P``!````"][```
M!@```,[L```9````U>P```H```#O[```'````/KL```'````%^T```4````?
M[0``$````"7M```4````-NT```L```!+[0``#0```%?M```7````9>T```0`
M``!][0``"0```(+M```*````C.T```<```"7[0```@```)_M```.````HNT`
M``@```"Q[0``'P```+KM```C````VNT``#@```#^[0``,0```#?N```G````
M:>X``&0```"1[@``%````/;N``!5````"^\``#@```!A[P``2@```)KO``!;
M````Y>\``"@```!!\```.````&KP```H````H_```"P```#,\```)P```/GP
M```;````(?$``#X````]\0``J0$``'SQ```C````)O,``!<```!*\P``2```
M`&+S``"%````J_,``#`````Q]```00```&+T``!;````I/0``$D`````]0``
M'0```$KU```8````:/4``"$```"!]0``'P```*/U```K````P_4``"$```#O
M]0``'0```!'V```1````+_8``#,```!!]@``)0```'7V```G````F_8``!\`
M``##]@``,````./V``!I````%/<``#T```!^]P``90```+SW``!-````(O@`
M`"\```!P^```+@```*#X```P````S_@``%0`````^0``6@```%7Y``!(````
ML/D``$H```#Y^0``,@```$3Z```O````=_H``"P```"G^@``+0```-3Z``!Q
M`````OL``&\```!T^P``LP```.3[```7````F/P``"4```"P_```,@```-;\
M```I````"?T``#X````S_0``(@```'+]``!2````E?T``"4```#H_0``"P``
M``[^``"Q````&OX``$4```#,_@``(0```!+_```P````-/\``"4```!E_P``
M'````(O_```Q````J/\```<```#:_P``!P```.+_```$````ZO\```T```#O
M_P``"P```/W_```.````"0`!``L````8``$`!0```"0``0`0````*@`!``(`
M```[``$`60```#X``0`%````F``!`!(```">``$`!````+$``0`'````M@`!
M``@```"^``$`!0```,<``0`#````S0`!`!````#1``$`#````.(``0`3````
M[P`!``T````#`0$``@```!$!`0`'````%`$!``8````<`0$`%````",!`0`,
M````.`$!`!@```!%`0$`!@```%X!`0`2````90$!``P```!X`0$``P```(4!
M`0`J````B0$!``0```"T`0$`!@```+D!`0`'````P`$!`!\```#(`0$`-0``
M`.@!`0`N````'@(!`"\```!-`@$`%P```'T"`0`@````E0(!`!L```"V`@$`
M&````-("`0`D````ZP(!`!\````0`P$`&@```#`#`0`@````2P,!`!H```!L
M`P$`,@```(<#`0`O````N@,!`"L```#J`P$`'P```!8$`0`C````-@0!`!\`
M``!:!`$`&@```'H$`0`E````E00!`"8```"[!`$`)0```.($`0`D````"`4!
M`!@````M!0$`'0```$8%`0`D````9`4!`!@```")!0$`(@```*(%`0`E````
MQ04!`#P```#K!0$`'P```"@&`0`C````2`8!`!\```!L!@$`(````(P&`0`:
M````K08!`!@```#(!@$`)@```.$&`0`>````"`<!`"D````G!P$`'@```%$'
M`0`)````<`<!``P```!Z!P$`%P```(<'`0`O````GP<!`"0```#/!P$`!P``
M`/0'`0`/````_`<!`!0````,"`$`#@```"$(`0`-````,`@!`"0````^"`$`
M!0```&,(`0`'````:0@!`"(```!Q"`$`)0```)0(`0`=````N@@!`!H```#8
M"`$`!P```/,(`0#'````^P@!``L```##"0$`%0```,\)`0`&````Y0D!``D`
M``#L"0$`"P```/8)`0`7`````@H!``8````:"@$`,P```"$*`0`3````50H!
M`!,```!I"@$`!P```'T*`0`/````A0H!``<```"5"@$`,@```)T*`0`A````
MT`H!`!,```#R"@$`#`````8+`0`1````$PL!`#(````E"P$`"````%@+`0`)
M````80L!``H```!K"P$`%````'8+`0`*````BPL!`!T```"6"P$`"````+0+
M`0`?````O0L!``@```#="P$`&@```.8+`0`&`````0P!`!4````(#`$`!P``
M`!X,`0`(````)@P!``D````O#`$`/P```#D,`0`'````>0P!``\```"!#`$`
M#@```)$,`0`0````H`P!``D```"Q#`$`"0```+L,`0`(````Q0P!`!,```#.
M#`$`!P```.(,`0`9````Z@P!``H````$#0$`%P````\-`0`4````)PT!``H`
M```\#0$`#````$<-`0`7````5`T!``0```!L#0$`*@```'$-`0`1````G`T!
M``<```"N#0$``@```+8-`0`0````N0T!`!@```#*#0$`"P```.,-`0`#````
M[PT!``@```#S#0$`!@```/P-`0`'`````PX!``T````+#@$`"P```!D.`0`4
M````)0X!`!4````Z#@$`#@```%`.`0`O````7PX!`"````"/#@$`'````+`.
M`0`,````S0X!`#$```#:#@$`!0````P/`0`2````$@\!`#\````E#P$`$@``
M`&4/`0`*````>`\!``8```"##P$`!````(H/`0`3````CP\!``4```"C#P$`
M!@```*D/`0`&````L`\!``0```"W#P$`#````+P/`0`*````R0\!``4```#4
M#P$`&````-H/`0`9````\P\!`!\````-$`$`'0```"T0`0`1````2Q`!``(`
M``!=$`$`!````&`0`0`*````91`!``8```!P$`$`!0```'<0`0`#````?1`!
M``P```"!$`$`10```(X0`0`:````U!`!`#4```#O$`$`*````"41`0!3````
M3A$!`!D```"B$0$`<@```+P1`0`@````+Q(!`#4```!0$@$`10```(82`0`P
M````S!(!`"@```#]$@$`*0```"83`0`F````4!,!`"4```!W$P$`*````)T3
M`0`H````QA,!`"(```#O$P$`,````!(4`0`2````0Q0!`!,```!6%`$`$```
M`&H4`0!Y````>Q0!``D```#U%`$`<P```/\4`0!\````<Q4!`"L```#P%0$`
M%P```!P6`0`6````-!8!``\```!+%@$`'P```%L6`0`?````>Q8!`!P```";
M%@$`40```+@6`0`4````"A<!``H````?%P$`!0```"H7`0`&````,!<!``@`
M```W%P$`!0```$`7`0`2````1A<!`!````!9%P$`$P```&H7`0`=````?A<!
M``\```"<%P$`#P```*P7`0`$````O!<!``D```#!%P$`"P```,L7`0`'````
MUQ<!``4```#?%P$`%````.47`0`'````^A<!``@````"&`$`#P````L8`0`(
M````&Q@!``P````D&`$`#P```#$8`0`&````01@!`!0```!(&`$`!@```%T8
M`0`,````9!@!``@```!Q&`$`!````'H8`0`*````?Q@!``<```"*&`$`!```
M`)(8`0`9````EQ@!``(```"Q&`$`"0```+08`0`&````OA@!``8```#%&`$`
M)P```,P8`0`$````]!@!``\```#Y&`$`$P````D9`0`'````'1D!``<````E
M&0$`!@```"T9`0`&````-!D!`!`````[&0$`$@```$P9`0`&````7QD!``D`
M``!F&0$`(@```'`9`0`'````DQD!``<```";&0$`"P```*,9`0`%````KQD!
M``(```"U&0$`"P```+@9`0!7`0``Q!D!`!(````<&P$`#@```"\;`0`+````
M/AL!``@```!*&P$``0```%,;`0`+````51L!`!$```!A&P$`#````',;`0`-
M````@!L!``4```".&P$`*0```)0;`0`/````OAL!``P```#.&P$`$@```-L;
M`0`(````[AL!`!$```#W&P$`"@````D<`0`,````%!P!`!,````A'`$`$0``
M`#4<`0`.````1QP!`!$```!6'`$`$````&@<`0`&````>1P!``X```"`'`$`
M%0```(\<`0`1````I1P!`!,```"W'`$`$P```,L<`0`+````WQP!`"P```#K
M'`$`$@```!@=`0`]````*QT!`$D```!I'0$`90```+,=`0!F````&1X!`&@`
M``"`'@$`:0```.D>`0!`````4Q\!``H```"4'P$`!0```)\?`0`&````I1\!
M`!(```"L'P$`!P```+\?`0`1````QQ\!`!,```#9'P$`*P```.T?`0`H````
M&2`!``L```!"(`$`$P```$X@`0`(````8B`!``<```!K(`$`#P```',@`0`0
M````@R`!`!````"4(`$`$P```*4@`0`5````N2`!`!H```#/(`$`$````.H@
M`0`6````^R`!``P````2(0$`+0```!\A`0`:````32$!`!\```!H(0$`$0``
M`(@A`0`<````FB$!``<```"W(0$`!P```+\A`0`Y````QR$!``@````!(@$`
M"`````HB`0`,````$R(!``@````@(@$`!P```"DB`0`(````,2(!``@````Z
M(@$`"P```$,B`0`%````3R(!`!H```!5(@$`#````'`B`0`,````?2(!`!0`
M``"*(@$`%````)\B`0`A````M"(!``X```#6(@$`'P```.4B`0`=````!2,!
M`"(````C(P$`'@```$8C`0`5````92,!`!0```![(P$`#@```)`C`0`;````
MGR,!``8```"[(P$`!@```,(C`0`'````R2,!`!D```#1(P$`"0```.LC`0`*
M````]2,!`!(`````)`$`!P```!,D`0`5````&R0!`!<````Q)`$`"P```$DD
M`0`(````520!`!<```!>)`$`$P```'8D`0`9````BB0!`#,```"D)`$`"0``
M`-@D`0`(````XB0!`!4```#K)`$`!0````$E`0`%````!R4!`!T````-)0$`
M"P```"LE`0`@````-R4!`"X```!8)0$`%0```(<E`0`H````G24!`"H```#&
M)0$`*P```/$E`0`K````'28!``D```!))@$`"0```%,F`0`*````728!``@`
M``!H)@$`+P```'$F`0`L````H28!`"X```#.)@$`4````/TF`0`M````3B<!
M`"T```!\)P$`+0```*HG`0`_````V"<!`"D````8*`$`*P```$(H`0`M````
M;B@!`#,```"<*`$`%````-`H`0`8````Y2@!`"H```#^*`$`)P```"DI`0`.
M````42D!``T```!@*0$`$0```&XI`0`%````@"D!``L```"&*0$`(0```)(I
M`0`F````M"D!``<```#;*0$`"0```.,I`0`6````[2D!``H````$*@$`"@``
M``\J`0`.````&BH!``L````I*@$`!P```#4J`0`'````/2H!``<```!%*@$`
M"````$TJ`0`'````5BH!``L```!>*@$`$````&HJ`0`+````>RH!``H```"'
M*@$`"````)(J`0`'````FRH!``<```"C*@$`$````*LJ`0`'````O"H!`!8`
M``#$*@$`!0```-LJ`0`(````X2H!``@```#J*@$`"@```/,J`0`)````_BH!
M`"`````(*P$`%0```"DK`0`)````/RL!`!$```!)*P$`#@```%LK`0`)````
M:BL!``,```!T*P$``P```'@K`0`7````?"L!`!0```"4*P$`"P```*DK`0`$
M````M2L!``@```"Z*P$`"0```,,K`0!/````S2L!`"H````=+`$`!@```$@L
M`0`(````3RP!`!P```!8+`$`'````'4L`0`A````DBP!`"@```"T+`$`'P``
M`-TL`0`I````_2P!`%@````G+0$`+````(`M`0`*````K2T!``L```"X+0$`
M"P```,0M`0`-````T"T!`!$```#>+0$`$````/`M`0`.`````2X!`!`````0
M+@$`$@```"$N`0`3````-"X!`!,```!(+@$`!@```%PN`0`<````8RX!`!X`
M``"`+@$`$P```)\N`0`2````LRX!``4```#&+@$`"````,PN`0!B````U2X!
M``@````X+P$`%@```$$O`0`$````6"\!``8```!=+P$`'````&0O`0`;````
M@2\!`!8```"=+P$`&P```+0O`0`A````T"\!`"0```#R+P$`"P```!<P`0`/
M````(S`!``8````S,`$`&````#HP`0`=````4S`!`!L```!Q,`$`&P```(TP
M`0`%````J3`!`!,```"O,`$`#@```,,P`0`)````TC`!``D```#<,`$`%@``
M`.8P`0`;````_3`!``D````9,0$`!@```",Q`0`2````*C$!`!0````],0$`
M"P```%(Q`0`5````7C$!``@```!T,0$`!P```'TQ`0`0````A3$!``H```"6
M,0$`#@```*$Q`0`'````L#$!``D```"X,0$`#````,(Q`0`'````SS$!`!0`
M``#7,0$`#P```.PQ`0`5````_#$!``8````2,@$`'````!DR`0`5````-C(!
M`!8```!,,@$`,0```&,R`0`^````E3(!`"<```#4,@$`,@```/PR`0`%````
M+S,!``H````U,P$`#@```$`S`0`)````3S,!`!4```!9,P$`"@```&\S`0`6
M````>C,!`!X```"1,P$`'P```+`S`0`A````T#,!`"(```#R,P$`'0```!4T
M`0`H````,S0!`!\```!<-`$`*0```'PT`0`?````IC0!`"(```#&-`$`'@``
M`.DT`0`J````"#4!`"L````S-0$`(P```%\U`0`I````@S4!`#````"M-0$`
M+P```-XU`0`6````#C8!`"X````E-@$`%0```%0V`0"W````:C8!`!(````B
M-P$`(@```#4W`0`G````6#<!`"<```"`-P$`)0```*@W`0`<````SC<!`"``
M``#K-P$`+P````PX`0`@````/#@!`"````!=.`$`+````'XX`0!'````JS@!
M``\```#S.`$`"`````,Y`0`&````##D!``<````3.0$`#P```!LY`0`4````
M*SD!`!0```!`.0$`$````%4Y`0`;````9CD!``@```"".0$`!````(LY`0`1
M````D#D!`!$```"B.0$`%@```+0Y`0`4````RSD!`!(```#@.0$`,P```/,Y
M`0`(````)SH!`!0````P.@$`!@```$4Z`0`1````3#H!`!<```!>.@$`'P``
M`'8Z`0`2````ECH!``(```"I.@$`!P```*PZ`0`7````M#H!``0```#,.@$`
M!0```-$Z`0`2````USH!``4```#J.@$`$@```/`Z`0`'`````SL!`!4````+
M.P$`%0```"$[`0`2````-SL!`!0```!*.P$`"P```%\[`0`(````:SL!``X`
M``!T.P$`#@```(,[`0`9````DCL!``T```"L.P$`$0```+H[`0`J````S#L!
M``\```#W.P$`&@````<\`0`4````(CP!`!,````W/`$`$0```$L\`0`&````
M73P!`!,```!D/`$`"0```'@\`0`N````@CP!`"T```"Q/`$`"````-\\`0`)
M````Z#P!`!T```#R/`$`"P```!`]`0`:````'#T!`!H````W/0$`"0```%(]
M`0`:````7#T!`!4```!W/0$`%0```(T]`0`3````HST!`!P```"W/0$`"```
M`-0]`0`(````W3T!`"H```#F/0$`(@```!$^`0`(````-#X!`!0````]/@$`
M"@```%(^`0`-````73X!`#0```!K/@$`&0```*`^`0`'````NCX!`!$```#"
M/@$``P```-0^`0`)````V#X!``8```#B/@$`%P```.D^`0`/`````3\!`!``
M```1/P$`$````"(_`0`5````,S\!`!(```!)/P$`%0```%P_`0`'````<C\!
M``<```!Z/P$`"@```((_`0`,````C3\!``(```":/P$`"@```)T_`0`1````
MJ#\!`!\```"Z/P$`(0```-H_`0`*````_#\!``X````'0`$`$P```!9``0`;
M````*D`!`#L```!&0`$`)@```()``0`.````J4`!`!,```"X0`$`<@```,Q`
M`0`9````/T$!`!(```!900$`"````&Q!`0`&````=4$!``X```!\00$`!@``
M`(M!`0`(````DD$!``<```";00$`!@```*-!`0`.````JD$!``T```"Y00$`
M$````,=!`0`-````V$$!`!L```#F00$`#@````)"`0`*````$4(!``L````<
M0@$`!P```"A"`0`*````,$(!``\````[0@$`/````$M"`0`.````B$(!``H`
M``"70@$`#0```*)"`0`<````L$(!`!T```#-0@$`*````.M"`0`G````%$,!
M`!T````\0P$`'````%I#`0`B````=T,!`!D```":0P$`!P```+1#`0`:````
MO$,!``P```#70P$`!@```.1#`0`'````ZT,!``H```#S0P$`#````/Y#`0`3
M````"T0!``8````?1`$`&0```"9$`0`<````0$0!``\```!=1`$`$0```&U$
M`0`2````?T0!``\```"21`$`(@```*)$`0`'````Q40!``<```#-1`$`#```
M`-5$`0`2````XD0!`!<```#U1`$`"P````U%`0`*````&44!``4````D10$`
M&0```"I%`0`-````1$4!``<```!210$`*0```%I%`0`2````A$4!`(<```"7
M10$`&@```!]&`0`&````.D8!``4```!!1@$`#````$=&`0`&````5$8!``@`
M``!;1@$`"@```&1&`0`,````;T8!``4```!\1@$`"0```()&`0`*````C$8!
M`!8```"71@$`$@```*Y&`0`6````P48!`"````#81@$``P```/E&`0`$````
M_48!`!`````"1P$`"````!-'`0`-````'$<!``<````J1P$`-0```#)'`0`)
M````:$<!``<```!R1P$`%P```'I'`0`2````DD<!``<```"E1P$`"0```*U'
M`0`$````MT<!``L```"\1P$`!@```,A'`0`&````ST<!``<```#61P$`#@``
M`-Y'`0`+````[4<!``@```#Y1P$`%@````)(`0`+````&4@!``<````E2`$`
M%@```"U(`0`A````1$@!``8```!F2`$`"0```&U(`0`%````=T@!``D```!]
M2`$`!P```(=(`0`-````CT@!``P```"=2`$`!P```*I(`0`.````LD@!``8`
M``#!2`$`!````,A(`0`S````S4@!`#<````!20$`-@```#E)`0`@````<$D!
M``8```"120$`#P```)A)`0`%````J$D!``@```"N20$`'@```+=)`0`6````
MUDD!``<```#M20$`!P```/5)`0`@````_4D!``T````>2@$`"0```"Q*`0`;
M````-DH!``8```!22@$`"0```%E*`0`D````8TH!``@```"(2@$`#````)%*
M`0`.````GDH!``@```"M2@$`"0```+9*`0`(````P$H!`#,```#)2@$`+P``
M`/U*`0`R````+4L!`"8```!@2P$`1@```(=+`0`Z````SDL!`"H````)3`$`
M,@```#1,`0`R````9TP!`#,```":3`$`)0```,Y,`0`2````]$P!`!,````'
M30$`#@```!M-`0`@````*DT!`!\```!+30$`'P```&M-`0`=````BTT!``D`
M``"I30$`"P```+--`0`*````OTT!``@```#*30$`)P```---`0`H````^TT!
M`#`````D3@$`"@```%5.`0`9````8$X!`",```!Z3@$`#@```)Y.`0`7````
MK4X!``D```#%3@$`#P```,].`0`5````WTX!`!,```#U3@$`*`````E/`0!I
M````,D\!`!4```"<3P$`$````+)/`0`1````PT\!`!D```#53P$`&@```.]/
M`0`5````"E`!``<````@4`$`%0```"A0`0`2````/E`!``X```!14`$`&```
M`&!0`0`:````>5`!`#$```"44`$`HP```,90`0`5````:E$!``8```"`40$`
M%P```(=1`0`*````GU$!``L```"J40$`"P```+91`0`;````PE$!`!,```#>
M40$`#P```/)1`0`/`````E(!`!D````24@$`+P```"Q2`0`N````7%(!`"P`
M``"+4@$`*P```+A2`0`C````Y%(!`"(````(4P$`&P```"M3`0!!````1U,!
M`!(```")4P$`%@```)Q3`0`9````LU,!`!@```#-4P$`#P```.93`0`7````
M]E,!`!L````.5`$`%````"I4`0`8````/U0!`"\```!85`$`'0```(A4`0`9
M````IE0!`#$```#`5`$`$@```/)4`0`(````!54!``\````.50$`)````!Y5
M`0`4````0U4!``\```!850$`&P```&A5`0`4````A%4!`!H```"950$`%0``
M`+15`0`=````RE4!`",```#H50$`'@````Q6`0`7````*U8!`!0```!#5@$`
M'0```%A6`0`<````=E8!``L```"35@$`&@```)]6`0`&````NE8!``8```#!
M5@$`"0```,A6`0`3````TE8!``@```#F5@$`"0```.]6`0`(````^58!``<`
M```"5P$`!P````I7`0`&````$E<!``@````95P$`%P```")7`0`'````.E<!
M``D```!"5P$`!0```$Q7`0`(````4E<!``8```!;5P$`#P```&)7`0`.````
M<E<!`!````"!5P$`$0```))7`0`+````I%<!`!0```"P5P$`!@```,57`0`L
M````S%<!`!,```#Y5P$`#0````U8`0`/````&U@!``L````K6`$`"P```#=8
M`0`2````0U@!`"<```!66`$`!@```'Y8`0`)````A5@!`"<```"/6`$`$@``
M`+=8`0`5````RE@!``@```#@6`$`"0```.E8`0`+````\U@!``4```#_6`$`
M)0````59`0`*````*UD!`!0````V60$`"P```$M9`0`<````5UD!`"D```!T
M60$`&````)Y9`0`'````MUD!``4```"_60$`"@```,59`0`P````T%D!``<`
M```!6@$`!P````E:`0`1````$5H!`!,````C6@$`!P```#=:`0`(````/UH!
M`!8```!(6@$`#@```%]:`0`.````;EH!`!````!]6@$`%0```(Y:`0`7````
MI%H!``\```"\6@$`'0```,Q:`0`1````ZEH!`!(```#\6@$`"0````];`0`'
M````&5L!``H````A6P$`.0```"Q;`0`(````9EL!`!0```!O6P$`+P```(1;
M`0`;````M%L!`!4```#06P$`%@```.9;`0`6````_5L!`!4````47`$`$```
M`"I<`0`8````.UP!`!4```!47`$`'@```&I<`0`<````B5P!`!T```"F7`$`
M"@```,1<`0`'````SUP!``D```#77`$`$0```.%<`0`0````\UP!``4````$
M70$`"P````I=`0`*````%ET!`!,````A70$`5````#5=`0`5````BET!``T`
M``"@70$`!0```*Y=`0`(````M%T!`!H```"]70$`&@```-A=`0`:````\UT!
M``T````.7@$``@```!Q>`0`$````'UX!`"@````D7@$``P```$U>`0`%````
M45X!``H```!77@$`#````&)>`0`&````;UX!``8```!V7@$`#@```'U>`0`3
M````C%X!``<```"@7@$`"0```*A>`0`(````LEX!``4```"[7@$`!0```,%>
M`0!7````QUX!``\````?7P$`$@```"]?`0`%````0E\!``<```!(7P$`(P``
M`%!?`0`Q````=%\!``T```"F7P$`"0```+1?`0`/````OE\!``L```#.7P$`
M"@```-I?`0`4````Y5\!`"L```#Z7P$`&@```"9@`0`9````06`!`!````!;
M8`$`!@```&Q@`0`&````<V`!``@```!Z8`$`!@```(-@`0`.````BF`!``X`
M``"98`$`!@```*A@`0!,````KV`!`!(```#\8`$`#0````]A`0`+````'6$!
M`!8````I80$`1````$!A`0`'````A6$!``4```"-80$`!P```)-A`0`B````
MFV$!``@```"^80$`"@```,=A`0`9````TF$!`!H```#L80$`"0````=B`0`%
M````$6(!`",````78@$`20```#MB`0`0````A6(!`"<```"68@$`$````+YB
M`0`%````SV(!``X```#58@$`"0```.1B`0`/````[F(!``H```#^8@$`!P``
M``EC`0`3````$6,!``<````E8P$`"0```"UC`0`1````-V,!``H```!)8P$`
M"@```%1C`0`-````7V,!``<```!M8P$`$0```'5C`0`4````AV,!`!(```"<
M8P$`#P```*]C`0`0````OV,!`!$```#08P$`$0```.)C`0`0````]&,!`!(`
M```%9`$`"@```!AD`0`F````(V0!`!,```!*9`$`#0```%YD`0`-````;&0!
M`!<```!Z9`$`"0```))D`0`-````G&0!``8```"J9`$`"````+%D`0`&````
MNF0!``<```#!9`$`"P```,ED`0`2````U60!`!4```#H9`$`(0```/YD`0`?
M````(&4!`!@```!`90$`%@```%EE`0`<````<&4!`!X```"-90$`&@```*QE
M`0`'````QV4!``<```#/90$`$@```-=E`0`0````ZF4!``X```#[90$`(P``
M``IF`0`1````+F8!`!8```!`9@$`"0```%=F`0`/````868!``@```!Q9@$`
M$P```'IF`0`)````CF8!``<```"89@$`"````*!F`0`&````J68!``4```"P
M9@$``@```+9F`0`E````N68!`"(```#?9@$`%P````)G`0`@````&F<!`#0`
M```[9P$`#@```'!G`0`C````?V<!`"@```"C9P$`+0```,QG`0`M````^F<!
M`#(````H:`$`%````%MH`0`2````<&@!`!(```"#:`$`%````)9H`0`2````
MJV@!`!````"^:`$`$@```,]H`0`<````XF@!`"T```#_:`$`+0```"UI`0`Q
M````6VD!`"X```"-:0$`+P```+QI`0`L````[&D!`&`````9:@$`(````'IJ
M`0`2````FVH!`!$```"N:@$`)````,!J`0`Q````Y6H!`!D````7:P$`#0``
M`#%K`0!`````/VL!`$````"`:P$`"@```,%K`0`$````S&L!`!4```#1:P$`
M#@```.=K`0`2````]FL!`!@````);`$`"0```")L`0`(````+&P!``P````U
M;`$`#````$)L`0`-````3VP!``H```!=;`$`#0```&AL`0`'````=FP!`"$`
M``!^;`$`"0```*!L`0`'````JFP!`!$```"R;`$`$@```,1L`0`0````UVP!
M`#,```#H;`$``@```!QM`0`(````'VT!`!(````H;0$`"P```#MM`0`&````
M1VT!`!````!.;0$`!@```%]M`0`&````9FT!`"\```!M;0$`&````)UM`0`H
M````MFT!`%8```#?;0$`%P```#9N`0`C````3FX!`!(```!R;@$`"@```(5N
M`0`-````D&X!`!,```">;@$`#````+)N`0`)````OVX!``P```#);@$`'P``
M`-9N`0`7````]FX!``0````.;P$`$````!-O`0`1````)&\!`"4````V;P$`
M&````%QO`0`9````=6\!`!,```"/;P$`(0```*-O`0`)````Q6\!``<```#/
M;P$`$0```-=O`0`)````Z6\!``H```#S;P$`"````/YO`0`-````!W`!``H`
M```5<`$`!0```"!P`0`>````)G`!``8```!%<`$`%0```$QP`0`*````8G`!
M`!$```!M<`$`"P```']P`0`7````BW`!`"P```"C<`$`&P```-!P`0`,````
M['`!``T```#Y<`$`&P````=Q`0`&````(W$!`"L````J<0$`!@```%9Q`0`=
M````77$!``8```![<0$`"0```()Q`0`?````C'$!`#4```"L<0$`!@```.)Q
M`0`6````Z7$!`!0`````<@$`!````!5R`0`'````&G(!``D````B<@$`"0``
M`"QR`0`*````-G(!``D```!!<@$`"0```$MR`0`)````57(!`!L```!?<@$`
M-0```'MR`0`^````L7(!`!D```#P<@$`)P````IS`0`<````,G,!`#P```!/
M<P$`&````(QS`0`4````I7,!`"X```"Z<P$`)@```.ES`0`'````$'0!``D`
M```8=`$`"@```")T`0`+````+70!`!4````Y=`$`$0```$]T`0`I````870!
M`"````"+=`$`+@```*QT`0`S````VW0!``8````/=0$`%0```!9U`0`(````
M+'4!``@````U=0$`)````#YU`0`4````8W4!`!8```!X=0$`$````(]U`0`(
M````H'4!`!,```"I=0$`"0```+UU`0`0````QW4!``\```#8=0$`&````.AU
M`0`J`````78!``P````L=@$`!P```#EV`0`'````078!`!X```!)=@$`%```
M`&AV`0`&````?78!``L```"$=@$`#0```)!V`0`&````GG8!`!$```"E=@$`
M"````+=V`0`(````P'8!`!,```#)=@$`,````-UV`0!#````#G<!`!L```!2
M=P$`)````&YW`0`:````DW<!``4```"N=P$`$````+1W`0`(````Q7<!`!``
M``#.=P$`+````-]W`0`(````#'@!``\````5>`$`$P```"5X`0`6````.7@!
M``T```!0>`$`/````%YX`0`)````FW@!`"(```"E>`$`$@```,AX`0`6````
MVW@!`"P```#R>`$`"````!]Y`0`3````*'D!`!4````\>0$`"@```%)Y`0`3
M````77D!``@```!Q>0$`%P```'IY`0`<````DGD!``8```"O>0$`"````+9Y
M`0`2````OWD!`!0```#2>0$`%@```.=Y`0`$````_GD!``@````#>@$`"P``
M``QZ`0`.````&'H!``\````G>@$`$@```#=Z`0`2````2GH!``@```!=>@$`
M"0```&9Z`0`H````<'H!`!P```"9>@$`&@```+9Z`0`'````T7H!`!(```#9
M>@$`!@```.QZ`0`.````\WH!`!D````">P$`)@```!Q[`0`+````0WL!``<`
M``!/>P$``P```%=[`0`&````6WL!``@```!B>P$`!0```&M[`0`/````<7L!
M`!<```"!>P$`#0```)E[`0`=````IWL!`!T```#%>P$`&@```.-[`0`%````
M_GL!``L````$?`$`%````!!\`0`)````)7P!``T````O?`$`"0```#U\`0`,
M````1WP!`!0```!4?`$`5@```&E\`0`8````P'P!``<```#9?`$`!P```.%\
M`0`'````Z7P!`!(```#Q?`$`$`````1]`0`1````%7T!`!L````G?0$`$P``
M`$-]`0`5````5WT!`"0```!M?0$`$P```))]`0!B````IGT!`!L````)?@$`
M&@```"5^`0`I````0'X!`!L```!J?@$`&@```(9^`0`D````H7X!`!H```#&
M?@$`&0```.%^`0`:````^WX!``H````6?P$`"0```"%_`0`+````*W\!``@`
M```W?P$`%@```$!_`0`/````5W\!`!4```!G?P$`"````'U_`0!0````AG\!
M`$$```#7?P$`*````!F``0!/````0H`!`!L```"2@`$`*P```*Z``0`(````
MVH`!``H```#C@`$`$0```.Z``0`I`````($!``8````J@0$`30```#&!`0`E
M````?X$!`"$```"E@0$`$@```,>!`0`@````VH$!`!@```#[@0$`'````!2"
M`0`?````,8(!`!X```!1@@$`(P```'""`0`4````E((!``8```"I@@$`"P``
M`+""`0`-````O((!``D```#*@@$`*@```-2"`0`+````_X(!``P````+@P$`
M!P```!B#`0`1````((,!``H````R@P$`!0```#V#`0`6````0X,!``D```!:
M@P$`"0```&2#`0`$````;H,!``X```!S@P$`&````(*#`0`.````FX,!``<`
M``"J@P$`%0```+*#`0`>````R(,!`!````#G@P$`#````/B#`0`:````!80!
M`"@````@A`$`$0```$F$`0`1````6X0!`"8```!MA`$`!@```)2$`0`1````
MFX0!``8```"MA`$`"````+2$`0`&````O80!`!T```#$A`$`#@```.*$`0`2
M````\80!`!`````$A0$`!P```!6%`0`)````'84!``H````GA0$`#````#*%
M`0`/````/X4!`!<```!/A0$`!@```&>%`0`2````;H4!``X```"!A0$`"0``
M`)"%`0`.````FH4!`!@```"IA0$`#0```,*%`0`%````T(4!``0```#6A0$`
M!@```-N%`0`(````XH4!``@```#KA0$`5````/2%`0`T````288!`!D```!^
MA@$`!P```)B&`0`'````H(8!``H```"HA@$`"@```+.&`0`'````OH8!``H`
M``#&A@$`%0```-&&`0`,````YX8!``H```#TA@$`#````/^&`0`(````#(<!
M``P````5AP$`"0```"*'`0`'````+(<!`!@````TAP$`"P```$V'`0`'````
M68<!``H```!AAP$`)0```&R'`0`8````DH<!``<```"KAP$`"````+.'`0`*
M````O(<!``<```#'AP$`$P```,^'`0`3````XX<!``@```#WAP$`'`````"(
M`0`-````'8@!`!X````KB`$`"0```$J(`0`&````5(@!`!````!;B`$`%0``
M`&R(`0`+````@H@!``T```".B`$`%P```)R(`0`'````M(@!``L```"\B`$`
M#P```,B(`0`.````V(@!``4```#GB`$`&````.V(`0`)````!HD!`!P````0
MB0$`$0```"V)`0`S````/XD!`"8```!SB0$`(P```)J)`0![````OHD!`!0`
M```ZB@$`/P```$^*`0`T````CXH!`$4```#$B@$`0P````J+`0`?````3HL!
M`&0```!NBP$`)@```-.+`0`S````^HL!`"H````NC`$`$P```%F,`0`8````
M;8P!`'T!``"&C`$`%P````2.`0`2````'(X!`#@````OC@$`@0```&B.`0`\
M````ZHX!`#<````GCP$`20```%^/`0!$````J8\!`!X```#NCP$`$P````V0
M`0`8````(9`!`!D````ZD`$`)````%20`0`=````>9`!`",```"7D`$`%```
M`+N0`0`;````T)`!`"$```#LD`$`%P````Z1`0`/````)I$!`#`````VD0$`
M6P```&>1`0`L````PY$!`%(```#PD0$`.0```$.2`0`C````?9(!`"8```"A
MD@$`(P```,B2`0!'````[)(!`$<````TDP$`/0```'R3`0`\````NI,!`#``
M``#WDP$`*@```"B4`0`J````4Y0!`"T```!^E`$`9P```*R4`0!E````%)4!
M`*L```!ZE0$`%@```":6`0`M````/98!`#$```!KE@$`,````)V6`0!)````
MSI8!`!X````8EP$`3@```#>7`0`6````AI<!``<```"=EP$`L0```*67`0!%
M````5Y@!`"@```"=F`$`,P```,:8`0`:````^I@!`!X````5F0$`+@```#29
M`0`)````8YD!``@```!MF0$`!@```':9`0`.````?9D!``X```",F0$`$@``
M`)N9`0`*````KID!``@```"YF0$`#````,*9`0`#````SYD!`&P```#3F0$`
M"````$":`0`0````29H!``4```!:F@$`!P```&":`0`%````:)H!``4```!N
MF@$`!P```'2:`0`9````?)H!``@```"6F@$`%0```)^:`0`,````M9H!``4`
M``#"F@$`!P```,B:`0`'````T)H!`!4```#8F@$`"@```.Z:`0`7````^9H!
M``8````1FP$`&P```!B;`0`/````-)L!``,```!$FP$`)@```$B;`0`$````
M;YL!``8```!TFP$`!P```'N;`0`B````@YL!`$$```"FFP$`*````.B;`0`J
M````$9P!`!8````\G`$`)P```%.<`0`@````>YP!`!\```"<G`$`(P```+R<
M`0`>````X)P!`!L```#_G`$`(@```!N=`0`>````/IT!`"L```!=G0$`*0``
M`(F=`0`K````LYT!`!\```#?G0$`(P```/^=`0`A````(YX!`!P```!%G@$`
M)@```&*>`0`G````B9X!`",```"QG@$`'@```-6>`0`<````])X!`"(````1
MGP$`)0```#2?`0`=````6I\!`"4```!XGP$`)@```)Z?`0`Z````Q9\!`"$`
M````H`$`)0```"*@`0`C````2*`!`"0```!LH`$`'@```)&@`0`<````L*`!
M`"0```#-H`$`(````/*@`0`K````$Z$!`",````_H0$`"0```&.A`0`3````
M;:$!`!H```"!H0$`&@```)RA`0`:````MZ$!``H```#2H0$`$````-VA`0`9
M````[J$!`!(````(H@$`$P```!NB`0`B````+Z(!``@```!2H@$`"0```%NB
M`0`D````9:(!`"<```"*H@$`+P```+*B`0`A````XJ(!``P````$HP$`^@``
M`!&C`0`1````#*0!`!4````>I`$`"@```#2D`0`-````/Z0!`!0```!-I`$`
M'P```&*D`0`(````@J0!`#$```"+I`$`'````+VD`0`:````VJ0!``D```#U
MI`$`%0```/^D`0`+````%:4!`$4````AI0$`+P```&>E`0`9````EZ4!`!0`
M``"QI0$`%@```,:E`0`@````W:4!`!````#^I0$`$0````^F`0`2````(:8!
M`!L````TI@$`#````%"F`0`;````7:8!``D```!YI@$`&P```(.F`0`*````
MGZ8!`!P```"JI@$`"````,>F`0`C````T*8!``<```#TI@$`"0```/RF`0`)
M````!J<!`#$````0IP$`!P```$*G`0`0````2J<!`!0```!;IP$`$0```'"G
M`0`+````@J<!``T```".IP$`"0```)RG`0`7````IJ<!``T```"^IP$`%@``
M`,RG`0`2````XZ<!`!<```#VIP$`%0````ZH`0`)````)*@!``L````NJ`$`
M&0```#JH`0`$````5*@!`"H```!9J`$`#P```(2H`0`'````E*@!``4```"<
MJ`$`#````**H`0`2````KZ@!``L```#"J`$``P```,ZH`0`,````TJ@!``L`
M``#?J`$`!@```.NH`0`2````\J@!``D````%J0$`$P````^I`0`4````(ZD!
M``X````XJ0$`*P```$>I`0`7````<ZD!`!8```"+J0$`#````**I`0`D````
MKZD!``8```#4J0$`$0```-NI`0!&````[:D!``\````TJ@$`#````$2J`0`'
M````4:H!``0```!9J@$`%````%ZJ`0`&````<ZH!``<```!ZJ@$`"````(*J
M`0`&````BZH!``T```"2J@$`#P```*"J`0`%````L*H!`!X```"VJ@$`(@``
M`-6J`0`:````^*H!`!T````3JP$`#P```#&K`0`"````0:L!``0```!$JP$`
M$````$FK`0`&````6JL!``<```!AJP$`!````&FK`0`0````;JL!`$<```!_
MJP$`$0```,>K`0`I````V:L!`"0````#K`$`1````"BL`0`0````;:P!`&4`
M``!^K`$`&P```.2L`0!8`````*T!`"X```!9K0$`%@```(BM`0`P````GZT!
M`#,```#0K0$`)`````2N`0`C````*:X!`"<```!-K@$`$P```'6N`0`P````
MB:X!`#````"ZK@$`%P```.NN`0`2`````Z\!`!0````6KP$`3P```"NO`0`3
M````>Z\!`&T```"/KP$`5````/VO`0`G````4K`!`!(```!ZL`$`&@```(VP
M`0`4````J+`!`"(```"]L`$`&P```."P`0`:````_+`!`%P````7L0$`%@``
M`'2Q`0`+````B[$!``8```"7L0$`!P```)ZQ`0`(````IK$!``H```"OL0$`
M&P```+JQ`0`6````UK$!`!H```#ML0$`)@````BR`0`1````+[(!``D```!!
ML@$`!````$NR`0`.````4+(!`!````!?L@$`!P```'"R`0`(````>+(!`!L`
M``"!L@$`#````)VR`0`+````JK(!`!$```"VL@$`"P```,BR`0`'````U+(!
M`!0```#<L@$`#@```/&R`0`7`````+,!``L````8LP$`#@```"2S`0`+````
M,[,!``4````_LP$`#0```$6S`0`&````4[,!``8```!:LP$`$0```&&S`0`"
M````<[,!``H```!VLP$`"````(&S`0`(````BK,!`"8```"3LP$`!@```+JS
M`0`,````P;,!`!````#.LP$`#@```-^S`0`)````[K,!``D```#XLP$`!```
M``*T`0`0````![0!`!(````8M`$`!P```"NT`0`-````,[0!`",```!!M`$`
M"@```&6T`0`%````<+0!`!8```!VM`$`!0```(VT`0`"````D[0!``L```"6
MM`$``0```!`#``"'`@``&@,``*L%````````'P(``$X!```U!```J`4``$H"
M`````````````.<#````````D`0``*`!``"J`0```````,4"````````104`
M``````"?!0```````&@$`````````````"D"```H`P``1P8``/0````O!@``
M,0(```,#`````````````/4````O!0``508``&4#````````;@,``!H!````
M````7`$```````"[````)@(``,P!````````9P0``'$$```\`0``NP$`````
M``#9`@``60(``",#``">`@``B@0``&$````````````````````S`P``````
M``````"I`P``OP0`````````````/@0``'X````^`0``^P``````````````
M*P,``.(%````````8````&$#``"F`0``JP(``.`$`````````````#H!```H
M!```T@(``-\%```2`P``600```````!R!@```````+,$```;`P``H04`````
M````````]@$```````",!````````$T$``!-!0``O`$`````````````E`4`
M`.<%``````````````@"````````1P```%L$```R!``````````````I````
M`````+,!`````````0$``!T#````````6@8``*,```!)!0``D`(`````````
M````$P8``'\!````````_@$``)\#``!N!@``````````````````J0$``(X`
M````````DP```&\$``#?!```&`0`````````````-@$``)L%````````S`(`
M`($#````````'0(``"X!``""!```,P4``&,&````````SP4``.<!````````
M`````#<```!:````^00``*<"``!D`P``N0(```````"F`P````````````"4
M`0``/P$``(D$``#'!```L@,``+P"````````X0```!D`````````6```````
M````````C@$``#,!````````O````#\$``"I`@``HP$```H"``"M````)08`
M```````K!```E0````0"````````4@`````````M`````````$,&``!D`@``
MW`0``"T&````````MP,`````````````<@4``.X#``#"`P``````````````
M````````````````````?00```(!```,`P``/0(``)T#``"-!````````)4!
M``#W`@``P0```$X%````````)@,``'P#``#M````A0$``/P"``#^`@``$@4`
M```````*`0``L@``````````````LP4``,,"``!B!0``$P$``*X$``!(`@``
M3`0``,X````J!`````````@&```O````'@```%L&```F!0``=P,```````#O
M`P``F04``-(!``#Z!0``1@4``-$!```0`@``.`8``%`"``"A`P``X04``#(%
M```4`0``&`8``&D&```S!```C@,```($``!/!```6@0``(@"```V!0``1@,`
M``("``!F!0``60,``%$&``!'`0``"P(``%,"```O!````````)(```#/`P``
M00$``/4$`````````````/X```"$````308``+<"```[`@```````,\!```&
M!````````-4#```%`0``VP0```````#1!0``P`$``'<%````````$0```$X`
M````````S00``+H"````````1`8```D#````````*`(``'D%``"*`0``_P0`
M`"T$```:!```704``.\"``!$`@```````*P!``!N`@``+P,``+P#```-!@``
M\P0``/P!``"C!0``O0(``(T!``"3!```8@(``#4#``!6`@``F`0``"($``"1
M`0``^````%8```#2!0``[0,``.4```#J````'@$``'8```![`P``5@,`````
M```R````>0```(4#``#X!```L`(``/(%````````G0$``&0````$`0``M@,`
M`&4```#1````4`0``%D&```_````,@(``$L%``````````````````#3!```
MH`4````````&`P``J````'4#``#W!0``808``!P$``"3`@``4@0``!$"``"$
M`P```````"4```#_`P``````````````````(0,````````]!@``O04``#<#
M```````````````````C`@``B04```L&````````W@```)L```!T````````
M`*0"```U`@``/@8```````!K!@``%08``$,"``"/`P``5P8``)X$````````
M`````&4&```?`P```````*X"```=`0``VP(``,`%```^`P``NP4``)````#[
M`P``'@8```````#*`0``S``````````S`````````/,%``"N`0```````-T%
M``!6`0````````````#4````+@8``)H`````````6P,``+@!````````A@(`
M`)<$`````````````!P%``!4````#`0``.@```"O`@```````)($``!#`P``
MJ04``+8"```\!```A00``'L`````````]@(``*4"``"$!```%@(``&P"``!"
M````Q`$```H&`````````````)8!````````700``#0"```@!0```````!``
M``!2`P```````*<%``!M`@``M`(``.D%``!_`P``.P0``%8$``!)`@``````
M`&,```!Q````20```,4!````````7````)L!``!T`@``;````/D!````````
MP`,``'<`````````\@0``&8!``"N!0``J@4``)X#````````>``````````\
M`@````````X%```!`P``4`$``$X$```Z!0``.@0```4#``!.!@```````*(`
M`````````````%,$``"-`P````````````#R`0```````/\%``"'`0``D`$`
M`+$%``"+`P``(`````````#)`0``NP0``+0$``#+!0```````!\&``"=!0``
M7P(```````!O`@``9P$```````#>`@``C`````````#8`@``=`$``(P#``#R
M`@```````)H$``!G`P``1`0``/@!``#8!0````````(#``")````I0$`````
M``!K```````````````1!```+`,``!`$``#A`0``&`4```````"F`@``-P4`
M`'X%``"^`P`````````$`````````````(X%``!@!```10```*L!``"+!```
M?````-<#``"V`````````&P!``"W````$`4`````````````OP,```````!T
M!@``30(``.\$``"$`0``+`$````````T````Q`,``-$#````````,0,``$@%
M``!3`0```````.X$``!O!0``W0$```,!```O`@``+````$<"````````ZP(`
M`!\!``#@`P``2@,``'("````````J@(``*T%``">!0````````H$``"_`@``
M%P8``&8"``!F`````````!8```"(`0``4P4``"4#``"T````0@0`````````
M````R`(``+4$```]````Y0,`````````````#`8``+`#``"2`P``U@```$@$
M```9`@```````.0#````````*P(``)\!``#D!```%@8```````!L`P``#```
M`+L"````````8@,``````````````````"P$```A````4@8``(D#````````
M"@,``&X!``"(`````````!<"``!1!0``#@`````````U````A0(```````#D
M`@``;`4``'L$``!H````\0````````!X`0``\0(```````!<!0``E`0``)P%
M``!(````W`4``-L````]!0```````/$$````````]P0````````8`@``6`,`
M`%@%``"?````FP0```L$````````2@`````````O`0``DP$``"H%````````
M``````````"U!0```````*,"``"A!````````(T%````````7@8``'(!```\
M`P``V@,``.8%``!T`P``^P(``(,%``#C!````````"4"``!+`@``````````
M`````````````$4#````````_04``+@"```K````,0$``.T%``"7`@``I`4`
M``````#.!```K`0````````.`@``B@(``"H#``#3`@```````/D%````````
M`````.,!``#$`@```````$L#```?!```WP```#8&``"]`0``4P8`````````
M```````````````1!@```````*@#```-`0``C`4``),#````````X`$`````
M``!@`P``7@$``,0%``"O`P``!P4``%T#``!5!```F@,```````!$`P``````
M`#H&``!D!@```````$T!````````#P$```\%``!'!```N@4``/,```#1`@``
MN0```!@#``#7`@``>@,``'P!```9`P``E`,``*\!``!=`0``3P```/(#``!X
M`@``8@8````````R`0``YP``````````````&P0```````"A`0````8`````
M``"S````F`$``/8#```````````````````9!```@P(```````!?`0``.`,`
M`,L$```D!````````"<%``#V````^@```'8%``#R````M0,``,<#````````
M``````8&``#!`@``%00``%0$```Q!```8P,```````!<`P``7P```.D#````
M``````````````#+`@``U0```#,"``!``0``.`4``+H```!>````0`,``,L`
M``#@````[`0``-$$```H````\0,``(<#``!1`@``I04`````````````9@8`
M`-@#``#5`0``*P$``.P%``!\!0``30,``!`!```@!@``.0(``,,%```>`P``
M8`$``&T%``"``P``8P$``(D"````````M0(``"<&``"]!````````)<%``!7
M!```````````````````G`(``&8#```T`P``%P```'@%````````$04`````
M``!R````(@,``,D"````````M`,``(@%``!Q`0``#0,``$<%``!:`P``````
M`!("``!&`@``)@$``"("``!0!0``IP````````"@`P``90$``.<$``#F`0``
MD0````````!J!```604``!0#```.`P``[````*<!```W`@``=0(`````````
M````<P$`````````````E@(```````#%!```R@,``(`"``!M`P```````+`$
M````````<P8``/H"``!)!```30```.`"``!3````6P4``-(#```(`P``%@,`
M``````"6!```W@4``,D```"C!````````.@"``"V`0````````````"\!```
MM0```(,```!G````5`8`````````````Y`4```````#-`0``50,``/P%````
M````.`0``%@"````````+@(``-X#``!^!``````````````@!```Q@$``,`$
M``"L`@``U@0``+8$``#&````I`,``,T%``#S`0``(0$``,<%````````?0$`
M```````M!0```````.(#```4`@``[`$``'4```#6`0``!P0``,D$``!4`0``
M0@$```````!;`0``J`(``!0`````````#`4`````````````+@`````````Z
M`@`````````````<`0``.@``````````````50(``'8"``"H`0``CP4``$$#
M``!N!````````-T$```L!@``J@,``&\#```,`@``0P4``%X#``"2`0``20,`
M`"8&```]`P``K@```&<%``#4`P````````````#T!0``S`4``"0"````````
M%`8``)$"````````J0```%<!``!A!```K0(```````#K`P``````````````
M````GP(`````````````I0````````"?!```V@$```0$```V`P``\`4``+4!
M``#"!```]04``-8#``!6!0``K00``,$#``#8``````````X!``!Z!```````
M`$D!``#<`@````````````````````````````#&!0``D0,``%(!```_!0``
M`````&`"````````X@$``%X$````````;`0``'`&```1`P``-@(``#````"L
M````%@$````"``"Q````:@,``.$$````````,@,``",!````````<`,``-,%
M`````````04````````C!````````````````````````!$!``!O`0``L```
M`%P&``!U!0``%P,```````#3`0``X0(``+$"``!I`````P8``+P%```A!```
M`````'@$``#0`0```````#P&``#B````IP,``.($````````MP$``)<!````
M````O@0``"@&``!`!```[00``!(```#E!`````````````#K!````````)H"
M``````````````@$``#>`0````````````##!````````.L!``"N`P``XP``
M`'`"``!,!@``'08````````6!0``D00``$H!``!S!```A`(``%4```#J`0``
M``````````!R!```-P8``)D$``#J`P``+@0```,%``!'`P``7P0```````"L
M`P``?@(``'L!``"Q!```?P```#D%``#&!```2`$``$("````````*08``#8$
M``"*````[0$```````````````````````#H!0```````.8#```0!@``Y04`
M`($```#*!0````,``',#`````````P(``)`#``#_````2@0````````G````
M^P0``$$```"&`P``CP$``"0```"/````-@```,8"``!C`@``3`(``%4!``!Y
M`0``.`(``*L```![!0```````/T"````````3@,``),%``!M````]P,``&\`
M``#.`P``@0(``)@"`````````````#<!```-````SP```(4`````!0``H@0`
M`%P$````````R0,``.P"``"8````*@(```\#`````````````%\&``#^!```
M&P8``+$#``"X````K0,``#D$```Z`P``VP4``+,#```%!@``S`0``+\```#-
M````!P(``%$```#V!0``.P4```````"[`P``[P````````#N`@``>`,`````
M````````&0$```H%````````AP0``!,#``!_`@````````````"C`P``-`4`
M`%4%```U!0``H@4```````!H`@``?`0``/\!```&````#@8``&4%``!R`P``
M````````````````ZP4``!H"````````&``````````M`@``:`,``%H!``!S
M!0```````%8&``#D`````@8`````````````2P8``,$$````````9P8``+D$
M````````F`,``)P`````````)P$``$4$```'`0``PP$``$`&```$````@```
M`'D"``!7````2`,```````"+`@``@@``````````````8@0```````#G`@``
MR````/4!```%!```40,``-4$````````B0$```8%``"6`P``@00``*\$````
M````C@0```````!M`0``QP$```D$``"^`0``+@4````````)!0``'@(``&L"
M``"(!```70(``+0%````````!0````````!8`0``.0``````````````TP,`
M`-0!`````````````*T!``#9`````````"D%``"4````=00``#$```#8`0``
M=P0````````;!0``:@(``,(`````````400``-<!``!!!@``H@(``"`#``!W
M`0``Z@(``/,#````````60$``-D$```D`P``]`,``(L```"^``````````L#
M``#/!```Z`0``"4%```;`0``R`,``$H&```Y`P``MP4``#0$``"6````.0$`
M``````"+!0``<0,````````K!@``$P(``(\"``!(!@``60```$L!````````
MTP```",%``"O`````````"D#``!A`0``^`(``$D&```8`0``0@8``-T#````
M````10$```````"7`P````````````!1`0`````````````]`0```````,$!
M``"D`0``A@```&0!``!`!0````````````!4`@``4`8``*D$``"*`P``````
M``````#9!0``C0````````!,`0```@4``#P`````````8`8``,,#``#.`@``
M`````)H!````````JP0``%<%``!B`0```````/P#``"P`0``T@```+H!``#(
M!0``OP4``%T&``#I`````````!T$``!M!`````````````!4`P````````\&
M``"4`@``I`0``&L%````````(08``+H$````````>@```/D"``!J!0``W0(`
M`/4#````````1````(L!``"5!0``;08``(,$``"S`@```````)<```!!!```
M`````)T$``"5`@``C`(``((%``#Z!`````````````!4!0``T`,```````#H
M`P``"P4```````"#`P``UP```#L!````````F0,``"(&`````````````/<!
M``#O!0``:@$``,(%``"_`0``:@8``&$%```7!`````````````#F````;P8`
M``4"``!Q!0``1@$``#@!````````[@4``+("``````````````````!U`0``
M`````#<$````````@`4``#0&````````<`$``%@&``"X`P```````$X"```X
M````"0$``,4%`````````````+<$``!Y`P```````(`!``!,!0``!P,``($%
M``!S`@``P04```````````````````````#]`0``Y@0```````!A`@``+@,`
M`$\"``"Q`0``^P4```````"<`P```````%@$``#M`@``V@4``'8$``#0!```
M004``&@&``#-`P```````````````````````.,"``!Q`@``%`0``&X%``"A
M`@``3P8``,<"``"F!````````'T"``#9`P``:`$```````#6!0```````&@%
M``!,````%0```)("```!!```I@4````!```P`@``[@$``-`"``"A````QP``
M`!X$``!7`@``*`$``/H!``````````````@!```2!@```````)@%```:````
MH@,``'H%``#<`P``/@4``-D!``#+`0``&P(``.P#```P!@```````.,%````
M`````````,0$```B`0``R@0``-\"``!^`0``*P4```````!=````_0```-<$
M``!]!0``O@(```X$```Q!@``?P4``!4!``"X!0``A@$```0#``#*````"P``
M`)(%``"-`@``'P```/@#``#P`@```````'D$````````!P```,H"````````
MA@4``(<%``#@!0``4@4``!P```";`@``U@(``+D%``"9````.P8``%P"``!T
M!```1@```````````````````#D&``!W`@``J`0```````!P!```J@0`````
M````````(`(``!T%``!&!@```````/4"```_`P``E00`````````````````
M``````"P!0``-08``'\$``#D`0``V@```/0!```:!0``>@$``+0!``#;`P``
MZ0$```````"`!```Q````((!````````/P8```D&``!K`0``U04```````"L
M!0```````(("```!!@``#P0````````;``````````4%```+`0```````*4#
M````````.P,``/T$``#H`0``,`,``$,$``#4`@``'`,``-\#```*````JP,`
M`/`!``!K`P```````&D!``#:`@``U`0```$"```9!@``S0(``"D!````````
M`````"`!````````)@0``&<"``#]`P``VP$``(H%``!/`0``S@$```````#N
M````V@0````````)`@``=@,``$8$````````L@0``$\#```&`@``9@0``!($
M``">`0```````%<#``"Z`P``/00``"<"````````(@4``/X%````````\`,`
M`!T```!P````900``,8#````````0P$```T%```$!@```````(\$``!B````
M2P0```````"R`0``Z0(``/0"``!$!0``4````-($````````#0(```D```!;
M`@``$P```+(%````````:0,``#0!```<`@``F0(```<&``!N`````````#X"
M``#Y`P``$P0``"4$``"@`@``3`,``!D%````````Z@0`````````````\04`
M``````#E`0``ZP````(`````````%P4``'L"``#B`@``)P,``*H```"5`P``
MR`$```````"^!0``]P```$\%```5!0``4`,``"H```"]`P```````(8$````
M``````````````#0````WP$``"0&````````.P````````"=`@``(P```"$"
M````````4P,``"H&``#"`@``N`0``!<!``"$!0``(@```'8!``#Z`P``N0,`
M`&D"``":!0``<`4``/8$``#P!````````,4#````````)0$``$(%```P!```
M`````````````````P````````";`P``P`(``"$%```R!@``)@```'T#``!D
M!``````````````(!0``B`,``````````````````*8```#_`@```````$0!
M``!>!0``>@(``/@%```C!@``U`4``)P!```S!@```````&,$``!!`@``````
M`(,!``"G!`````````T$``!:!0`````````````6!```,04`````````````
M%`4``,L#``!``@``0````)$%```(````F0$``!4#``!?`P``\`````,$``#=
M````^0```$4&``!C!0``I````,X%``",`0``*00``*\%``#\````N0$``,\"
M```3!0``Q0`````````/````=`4``+8%``#0!0``)P0`````````````````
M`,````!D!0``!`4``)T```#)!0``:04``#4!``!J````Y@(````````&`0``
MW@0``.,#``#\!````````"H!``!E`@``,`4``#`!```>!0``4@(``.D$``!Q
M!@``Y0(``)P$``!]```````````````<!@``]`0``,(!``">````<P```%L`
M``!?!0``_@,```````#5`@``W````.\!```/`@``/`4``-@$```_`@``C@(`
M`!\%````````?`(``%H"```L`@``\P(```````#A`P``)`$```````##````
M+`4``!(!``!*!0``7@(``$(#``""`P``#`$`````````````H`````````#(
M!```S`,``$4"`````````````"T!``"0!0``Z@4``$L``````````````"T#
M````````O0```)8%````````W`$``'X#``"%!0```````&P&```5`@``*`4`
M`"0%``"B`0``\0$```````"@!```UP4``(<````^````8`4``&D$``"E!```
M`````!H&``!#``````````````#[`0``:P0``($!```````````````@*"5S
M(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`("AT;V1A>2D`("AY97-T97)D
M87DI`"!A="``)60@)7,@86YD("5S`"5D+61A>2!F;W)E8V%S=``E<R`M($YO
M=&EC90`E<R!&:6YG97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R
M871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@
M06=R965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!I
M<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@)7,@
M;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO
M=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`+"!G=7-T:6YG("5S("5S`"P@
M=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S96QE8W0@+2T`,3(@2&]U<B!&
M;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`02!D871A8F%S92!B86-K
M96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R
M(&AA<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O
M(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@
M:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@
M<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A
M=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV
M871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I
M<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!32!3:&]W97)S`$%-+U!-`$%0
M22!)1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B;W1T;VT`06)S
M;6ED9&QE`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2X`
M06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`06-C;W5N="!087-S
M=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`061D($-H:6QD
M($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@3F5W
M($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!N97<@=7-E<CH`061D
M(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D('!A:7(`061D('1H92`E<R!-
M96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!T;R!A9&1R97-S(&)O;VLZ
M`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D('5S97(`061D:6YG('5S97)S
M(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R
M("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A
M=&EO;@!!9',`069G:&%N:7-T86X`06QB86YI80!!;&=E<FEA`$%L:6%S`$%L
M:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L
M;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L;&]W
M(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@
M;&ES="!T>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I
M;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R
M;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA
M=&5S`$%L=&5R;F%T92!T97AT.@!!;65R:6-A;B!386UO80!!;B!I;&QE9V%L
M('9A;'5E('=A<R!S<&5C:69I960N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA
M`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YT87)C=&EC80!!;G1I9W5A(&%N
M9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!
M<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<')I;`!!<F%B:6,@*%=I
M;F1O=W,M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R
M92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U
M97-T(&9O<B`E<R`_`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!4DU3
M0TE)+3@I`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L86YD`$%S8VEI($%R=`!!
M<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R
M92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O
M;'5M;G,`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N
M`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN
M`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!
M='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I8G5T
M97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U
M:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A
M8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T
M:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O
M;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?
M:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T
M:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@
M=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E
M('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`
M075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@
M9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@
M<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`
M079A:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"3T9(($5X8W5S97,`0F%C
M:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R
M9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`0F%L
M=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!"87-E;&EN
M90!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N
M`$)I<G1H9&%Y`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0F]L9`!";VQI
M=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R
M<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A;F$`0F]T=&]M
M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N($]C96%N(%1E
M<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I80!"=6QL971E9"!,
M:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`0U),($1I<W1R:6)U
M=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#86QE;F1A<@!#86QM
M`$-A;6)O9&EA`$-A;65R;V]N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T
M;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B=T
M(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;F%D80!#86YC96P`0V%N
M8V5L(%!R;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#
M86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C
M965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E
M;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R
M96X@97AI<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S
M=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O
M<F5D+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R
M+@!#87!E(%9E<F1E`$-A<'1I;VX`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A
M>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@
M<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H
M;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#96YT<F%L($%F<FEC
M86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R
M=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H
M86YG90!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@
M<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`
M0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&EL90!#:&EN80!#:&EN97-E(%-I;7!L
M:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`0VAO
M;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO=R!T
M;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@
M;W)D97)E9"!L:7-T<RD`0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D969I;FET
M:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE87(`0VQE87(@35-/9F9I8V4@=&%G
M<P!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A
M=&$`0VQI8VL@=&\@0V]N=&EN=64`0VQI8VMA=&5L;"!V:6$@2%144`!#;&]S
M92!7:6YD;W<`0VQO=61S`$-L;W5D>0!#;V-O<R`H2V5E;&EN9RD@27-L86YD
M<P!#;VQL87!S960@8F]R9&5R<P!#;VQO;6)I80!#;VQO<@!#;VQO<B!0:6-K
M97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#;VQU;6X@=&ET;&5S`$-O;6EC
M<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#
M;VUO<F]S`$-O;7!A;GD`0V]M<'5T97)S`$-O;F1I=&EO;G,`0V]N9FEG=7)A
M=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R
M9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE
M`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE
M8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C
M=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ
M("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N
M=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S
M(&)O;VLN`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#;V]K:64`0V]P>0!#;W!Y
M('-E;&5C=&EO;@!#;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T
M(%!'4"!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!01U`@<VEG;B!M97-S
M86=E+@!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@
M;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C
M="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO
M="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82X`0V]U
M;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@
M8V]N=&%C="X@)7,`0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM
M86EL(&%D9')E<W,N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S
M(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@
M;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I
M<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y
M(&9R;VT@=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD
M(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO
M="!R96%D("5S+@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T
M:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS
M(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`0V]U;&0@
M;F]T(')E=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B
M;V]K+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S
M`$-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,`0V]U
M;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92`E
M<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF
M:6=U871I;VXN`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#
M;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL
M;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN`$-O
M=6YT960@=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E871E`$-R96%T92!A(&QI
M;FL`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@<W5B(&9O;&1E<G,`0W)E871O
M<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`0W)O871I80!#=6)A
M`$-U<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT(%=E871H97(`
M0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T
M87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I
M;VX`0WEP<G5S`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S
M+3$R-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*0!#>F5C:"!297!U
M8FQI8P!$1`!$86EL>0!$871A5')E92!"<F]W<V5R`$1A=&4`1&%T92!296-E
M:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU;6X`1&5C96UB
M97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E($EN9&5N=`!$969A=6QT($-O
M;&]R`$1E9F%U;'0@261E;G1I='D`1&5F:6YI=&EO;G,`1&5L971E`$1E;&5T
M92!'<F]U<`!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E(&UE
M<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T
M:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@<F]W`$1E;&5T92!S96QE
M8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T
M92!T:&4@8W5R<F5N="!R;W<`1&5L:79E<GD@=&EM90!$96YM87)K`$1E<V-R
M:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@*&%L<V\@:6X@
M2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O
M<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E
M=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N
M(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T
M;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I
M<W!L87D@9F]R96-A<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES<&]S:71I
M;VX@3F]T:69I8V%T:6]N`$1J:6)O=71I`$1O(&YO="!D96QE=&4`1&\@;F]T
M(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``1&]E<R!T:&4@9FER
M<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K
M('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]W;FQO
M860`1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I
M;VX@87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-86EL
M`$524@!%8W5A9&]R`$5D:70`161I="!";&]C:P!%9&ET($=R;W5P`$5D:70@
M4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@
M9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R
M("5S`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN`$5M
M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T
M8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M;W1I8V]N<P!%;7!T>2!M
M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B
M;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I
M;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%;F0@
M>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N
M('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T
M('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U
M<B!P970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5Q=6%T;W)I86P@
M1W5I;F5A`$5R:71R96$`17)R;W(`17)R;W(@=VET:"!E;6%I;"!M97-S86=E
M+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@,34@;6EN
M=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U
M(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI
M;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A;F0`17AP96-T960@
M)RDG`$5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`
M17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$9'($-O;&]R`$944"!U<&QO860@
M;V8@<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE
M9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C
M="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A
M:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!
M4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I<@!&
M86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@27-L86YD<P!&87@`
M1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME.B``1F5W(%-H;W=E<G,`
M1FEJ:0!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S
M`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`1FEL92!U
M<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<G,`1FEN
M;&%N9`!&:7)S="!(86QF`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L:7``
M1FQO870`1F]G`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R
M`$9O;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`
M1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R
M971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@
M82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L
M;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T
M=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9',`
M1G(`1G)A;65S`$9R86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&<F5N8V@@
M1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N(%1E<G)I
M=&]R:65S`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!-
M;V]N`$9U;&P@3F%M90!'86)O;@!'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O
M;0!'86QL97)Y.@!'86UB:6$`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'
M96YE<F%T960@0V]D90!'96]R9VEA`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R
M`$=I=F5N($YA;64`1V\`1V]E9&5L`$=O;V=L92!396%R8V@`1W)A>7-C86QE
M`$=R965C90!'<F5E:R`H25-/+3@X-3DM-RD`1W)E96YL86YD`$=R96YA9&$`
M1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM
M96UP='D`1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS
M97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M
M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@
M=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+@!(5$U,07)E82!C;W=A
M<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B
M;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L
M87-T(')O=R!I;B!T86)L92X`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U
M;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE87)D($ES
M;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<P!(96)R97<@*$E33RTX.#4Y+3@M
M22D`2&5I9VAT`$AE;'``2&5L<"!U<VEN9R!E9&ET;W(`2&5L<&5R`$AE;6ES
M<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(:6=H
M`$AO7VUE`$AO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I`$AO;64`2&]M
M92!!9&1R97-S`$AO;64@4&AO;F4`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E
M`$AO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D
M(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S
M<&]N9',@=&\@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@
M='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C
M97-S9G5L;'D@<F5M;W9E9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT
M96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT
M96YS:6]N`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@
M=')E92!F;W(@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M
M;W9E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE
M=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<P!(;W)D92]+;VQA
M8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+
M;VQA8CH@56YK;F]W;B!S:&%R92`B)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I
M>F]N=&%L('!A9&1I;F<`2&]R:7IO;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE
M<F4_("A0;&5A<V4@<F5P;W)T(2D`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y
M;W4@;&EK92!T;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A
M<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R
M9V4_`$AU;6ED:71Y`$AU;6ED:71Y.B``2'5M;W)I<W1S`$AU;F=A<GD`24U!
M4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E
M;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N
M(&9A:6QE9#H@)7,`25`@061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B
M;&4N`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN
M`$E0(&QO8VMD;W=N('9I;VQA=&EO;BX`25]N<V5R="!2;W<@0F5F;W)E`$EC
M96QA;F0`26-O;G,@3VYL>0!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N
M86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@
M;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!S964@=&AI<R!M97-S
M86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A
M9"!C86XG="!B92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+@!);6%G92!0
M<F5V:65W.@!);6%G92!54DP`26UA9V4@55),.@!);6%G92!F<F]M(&=A;&QE
M<GD`26UA9V4@9G)O;2!G86QL97)Y.@!);6%G92!U<&QO860`26UA9V5S`$EM
M<&]R="P@4W1E<"`E9`!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE
M;&1S.@!);E]S97)T(%)O=R!!9G1E<@!);F-O<G)E8W0@86-T:6]N(&-O9&4@
M9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN
M8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G
M86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D
M(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT`$EN9&EA`$EN9&EV:61U
M86P@57-E<G,`26YD;VYE<VEA`$EN9F\`26YF;W)M871I;VX`26YS97)T($-?
M;VQU;6X@069T97(`26YS97)T($EM86=E`$EN<V5R="!486)L90!);G-E<G0@
M5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R="!A(&YE=R!C
M;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!C;VQU
M;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&%F
M=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&)E9F]R92!T
M:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C
M=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R
M<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS97)T(&%N
M(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N
M97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R="!C96QL(&)E
M9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU;6X@8F5F;W)E
M`$EN<V5R="!M97-S86=E<P!);G-E<G0@<&%R86=R87!H(&%F=&5R`$EN<V5R
M="!P87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R;W<@869T97(`26YS97)T(')O
M=R!B969O<F4`26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E
M8W5R:71Y('%U97-T:6]N.@!);G-E<G0O36]D:69Y($EM86=E`$EN<V5R="]-
M;V1I9GD@3&EN:P!);G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE
M(&1I<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@8W)E9&ET+@!);G1E
M9V5R`$EN=&5G97(@;&ES=`!);G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D
M97(I+@!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$+@!)
M;G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T:6]N(&%D
M9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI9"!M<V=?='EP92X`
M26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O<B!M:7-S:6YG
M('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN`$EN=F%L
M:60@<')O=&]C;VPN`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U
M<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D92!D871A+@!);G9E;G1O<GD`
M27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O
M9B!-86X`27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)=&%L:6,`
M271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R
M,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y
M($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG
M:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY80!+97)B97)O<R!S
M97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME<FYE;"!.97=B:65S
M`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@
M5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I`$MO<F5A+"!$96UO8W)A=&EC
M(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O9@!+;W)E
M86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U=`!,86YG=6%G
M90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T($AA;&8`
M3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S
M="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`
M3&%W`$QA>6]U=`!,96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N;VX`
M3&5F=`!,969T(&AE861E<@!,969T('9A;'5E<P!,97-O=&AO`$QI8F5R:6$`
M3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI9VAT($1R
M:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A:6X@
M3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU;F1E
M<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K`$QI;FL`
M3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE
M(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O
M:VEE`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A=&%B
M87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C:&EV
M90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T
M+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@=7-E<G,@:7,@
M9&ES86)L960N`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO861I;F<N+BX`3&]C
M86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G
M(&]U=`!,;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S
M97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,
M;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E:R!L
M971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M8F5R
M<P!,=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A
M:6YE9"!N;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R;65R
M(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%G:6,`36%I;`!-
M86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA;&1I
M=F5S`$UA;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@
M>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O
M8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U
M97-T(&UA<`!-87)C:`!-87)G:6X`36%R:R!W:71H(%-E96XO56YS965N(&9L
M86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS
M=V5R960I`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-871C:&EN9R!F
M:65L9',`36%U<FET86YI80!-875R:71I=7,`36%X(&%L;&]W960@8W)E9&ET
M+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S="`R
M-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@;&5N
M9W1H`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365N=2!M;V1E.@!-
M97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U
M;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E
M('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@='EP90!-971A
M<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE=&%R(&)L
M;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F
M;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&AO9`!-971R:6,`365X:6-O`$UI
M8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8`36ED9&QE`$UI;64@5'EP
M90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO
M=7)S.B``36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!014%2('!A8VMA
M9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H
M879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI
M<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG(')E
M<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@240N
M`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF:65D($1A=&4`36]D:69Y
M(%523`!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYG
M;VQI80!-;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1S97)R870`36]O;B!0
M:&%S97,`36]R;V-C;P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D>0!-;W-T
M;'D@4W5N;GD`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@
M57``36]V92!D;W=N`$UO=F4@=7``36]Z86UB:7%U90!-=6QT:2UL979E;"!D
M<F]P(&1O=VX@;&ES=',`375L=&EP;&4@<V5L96-T:6]N`$UY($%C8V]U;G0`
M37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`37EA;FUA<@!.3RP@22!$;R!.
M3U0@06=R964`3F%M90!.86UI8FEA`$YA=7)U`$YE<&%L`$YE=&AE<FQA;F1S
M`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C
M87!E($-!(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`
M3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`
M3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E
M(&-O;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE
M=F5R`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!-;V]N`$YE=R!5
M<V5R;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!W:6YD;W<@*%]B
M;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="!O<'1I;VYS`$YI8V%R
M86=U80!.:6=E<@!.:6=E<FEA`$YI9VAT`$YI=64`3F\`3F\@879A:6QA8FQE
M(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`
M3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RX`
M3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q
M=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R
M($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@8VAI;&1R96X@
M8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!6
M1E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B!344PM1FEL92!61E,N`$YO(&-R961I="!L969T+@!.;R!D97-T:6YA=&EO
M;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.;R!L;V-A=&EO;B!I<R!S
M970N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.
M;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I
M;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A
M=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT
M:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT
M:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED
M960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R:R!W
M:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!R=6QE
M<P!.;R!S:61E<P!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F
M;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.
M;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO
M;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E
M(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF
M:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;F4`3F]N
M92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK
M($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA;F$@
M27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER
M96-T;W)Y`$YO="!I;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D
M+@!.;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V96UB97(`
M3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS
M`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D
M871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@
M0W)E871O<@!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/
M;6%N`$]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N
M`$]N;'D@;V9F96YS:79E(&9O<G1U;F5S`$]N;'D@;VYE(&5M86EL(&%D9')E
M<W,@86QL;W=E9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T
M<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO
M;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;G,@=&AI
M<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M`$]P=&EO
M;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/
M<F=A;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC
M871I;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE
M<@!/=&AE<B!);F9O<FUA=&EO;@!/=VYE<B!097)M:7-S:6]N<P!004T@875T
M:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4$=0($1I9VET86P@4VEG
M;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T80!01U`@4'5B;&EC($ME>0!01U`@
M4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!(4"!3:&5L;`!032!,
M:6=H="!286EN`%!-(%-H;W=E<G,`4$T@5"U3=&]R;7,`4%](4"!3:&5L;`!0
M861D:6YG`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@
M3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`4&%R
M=&QY($-L;W5D>0!087-S=V]R9`!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O
M<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BX`4&%S<W=O
M<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S
M<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D
M`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N=`!097)F;W)M
M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O
M<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VYS($%D
M;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G4`4&5T<P!0
M:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`4&ET8V%I<FX`4&EX96QS`%!L871I
M='5D97,`4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L96%S92!C;VYF
M:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#H`4&QE
M87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M
M96YT+@!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@
M96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT
M97(@82!V86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT97(@82!V86QI9"!D
M871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0
M;&5A<V4@96YT97(@82!V86QI9"!T:6UE+@!0;&5A<V4@<')O=FED92!A('-U
M;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E
M<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!T>7!E('1H92!N97<@8V%T96=O
M<GD@;F%M93H`4&]L86YD`%!O;&ET:6-S`%!O;&QS`%!O<G1U9V%L`%!O<VET
M:6]N:6YG(&]F('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L
M90!0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`
M4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E9G-?;&1A
M<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5F<U]S
M97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`%!R97-S=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R97-S=7)E.B``
M4')E=FEE=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E
M=FEO=7,@;W!T:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV871E($ME>0!0<F]B
M;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C=',`4')O;7!T('1E>'0`
M4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,O4')I=F%T
M92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@
M4FEC;P!1871A<@!1=65R>0!24T$@4'5B;&EC($ME>2`H)60@8FET*0!2861I
M;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T90!286EN(%-H
M;W=E<@!286YD;VT@1F]R='5N90!2871I;P!296%D`%)E860@;65S<V%G97,`
M4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N
M9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H
M:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E9&]E<R!Y;W5R(&QA
M<W0@86-T:6]N`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.@!2969R
M97-H(%!O<G1A;"!6:65W.@!296=E>`!296QA=&EO;G-H:7`@0G)O=W-E<@!2
M96UA<FMS`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N
M97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V
M92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E
M('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O
M<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U
M;65N=`!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5Q=65S="!C;W5L
M9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``4F5S970`
M4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R9`!297-U;'1S`%)E
M='5R;B!T;R!/<'1I;VYS`%)E=6YI;VX`4F5V97)T($-O;F9I9W5R871I;VX`
M4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@
M:&5A9&5R`%)I9VAT('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2
M;VUA;FEA`%)O=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O
M=R!0<F]P97)T:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A
M=&EO;@!2=V%N9&$`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O
M34E-12!%;F-R>7!T960@365S<V%G90!305-,(&%U=&AE;G1I8V%T:6]N(&ES
M(&YO="!A=F%I;&%B;&4N`%--4R!-97-S86=I;F<`4U%,(%-H96QL`%-32`!3
M54-#15-3`%-?44P@4VAE;&P`4V$`4V%I;G0@2&5L96YA`%-A:6YT($MI='1S
M(&%N9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@86YD($UI<75E
M;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S`%-A;64@9G)A
M;64@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE(&%N9"!0<FEN
M8VEP90!3871E;&QI=&4@4')O=FED97(`4V%U9&D@07)A8FEA`%-A=F4`4V%V
M92`E<P!3879E($]P=&EO;G,`4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO
M;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@
M9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!38VEE;F-E`%-E
M87)C:`!396%R8V@@16YG:6YE<P!396QE8W0@1FEL97,`4V5L96-T(&$@9&%T
M90!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E
M;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@86QL
M(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C=`!396QE8W0@=&AE
M(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO
M=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@
M87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D
M871E(&9O<FUA=#H`4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C
M:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@
M=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE
M8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L
M86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD(%--4P!396YE9V%L
M`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:6$@86YD($UO;G1E;F5G<F\`4V5R
M:6%L($YU;6)E<@!397-S:6]N($E$(&5X<&ER960N`%-E=`!3970@;W!T:6]N
M<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@
M979E<B!F;W)G970@:70N`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO
M=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P
M<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N
M`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@
M<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3
M971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I
M;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`
M4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@
M9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W(&1I9F9E<F5N8V5S
M(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A
M=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@
M;&]G9VEN9R!I;C\`4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W
M('!I8VME<@!3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@
M=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@
M4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D
M:6%L;V<`4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H
M;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H
M;W=E<G,`4VAO=V5R<R!%87)L>0!3:&]W97)S($QA=&4`4VAR:6YK`%-H<FEN
M:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A
M>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N871U<F4`4VEG;F%T
M=7)E($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ90!3:VEP($UA:6YT96YA;F-E
M`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<@4VAO=V5R`%-N;W<@9&5P=&@Z(`!3
M;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N($ES;&%N9',`4V]M
M86QI80!3;VYG<R`F(%!O96US`%-O<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C
M92!A9&1R97-S`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H25-/+3@X
M-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES
M;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N(&%D:F%C
M96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN
M(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I
M;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L
M:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I($QA;FMA`%-T86YD87)D
M`%-T87(@5')E:P!3=&%R="!Y96%R`%-T871E(&]R(%!R;W9I;F-E`%-T871U
M<P!3=&]R86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T:')O=6=H
M`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T
M>6QE(%M#4U-=`%-U`%-U8FIE8W0`4W5B;6ET`%-U8G-C<FEP=`!3=6-C97-S
M`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@
M=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N
M9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U9&%N`%-U;6UA
M<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U;G)I<V4O4W5N
M<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I<'0`4W5P
M<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V86QB87)D(&%N9"!*86X@36%Y96X`
M4W=A>FEL86YD`%-W961E;@!3=VET>F5R;&%N9`!3>6YT87@@97)R;W(@:6X@
M<V5A<F-H('1E<FUS`%-Y<FEA;B!!<F%B(%)E<'5B;&EC`%0M4W1O<FT`5"U3
M=&]R;7,`5%-6(&9I;&4`5&%B;&4`5&%B;&4@4')O<&5R=&EE<P!486)L92!P
M<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A
M:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!487)G970Z
M`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``
M5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP;&%T92!!9&UI;FES=')A
M=&EO;@!497AT`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``5&@`5&AA
M:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@
M<WES=&5M+@!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4
M:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U
M<'!O<G0@(B5S(@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO
M860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D
M+B!%>&ET:6YG+@!4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U
M<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N
M="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H
M92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B
M;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O
M;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@
M8F]O:RX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R
M:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F
M="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES
M=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T
M:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN
M`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE
M(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N`%1H92!F:6QE
M(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A
M9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@9G5L
M;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H
M($EN=&5R;F5T($5X<&QO<F5R+"!D=64@=&\@8G)O=W-E<B!B=6=S('1H870@
M=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP
M97)I96YC92!G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T
M:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO=7(@
M<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO
M=2=L;"!G970@82`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E
M9"!T;R!R96)O;W0N7&Y<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E
M('!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S
M8W)E96X@961I=&]R+@!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE
M=&5D+@!4:&4@;&5F="UH86YD('-I9&4@;VYL>0!4:&4@;&]C871I;VX@;V8@
M=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P
M9W`Z.B!C;&%S<RX`5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H
M('-U8FIE8W0@(B5S(B!H87,@8F5E;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@
M9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U
M;F1E<G-T;V]D+@!4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H
M92!C;VUP;W-E('!A9V4`5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D
M(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R969E
M<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T
M82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O
M9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T
M(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!R:6=H="!A;F0@;&5F="!S:61E
M<R!O;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5R=F5R("(E
M<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N
M('-A=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E
M;6]V960N`%1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+@!4:&4@
M=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4
M:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@
M<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4
M:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE<F4@
M87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@
M=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M
M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E
M9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N
M`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO
M("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H
M92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X
M:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A
M<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI
M;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R
M(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@
M;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!P97)F
M;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0
M;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D
M871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L
M871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB
M=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AI<R!)34%0
M('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI
M<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`
M5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`
M5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N
M`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U
M9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T
M97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T
M<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%0
M20!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@
M4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2!G871E=V%Y+"!O;FQY
M('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C
M8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I
M+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I
M;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N;'D@
M8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@;75S="!B92!A(&-O
M;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S`%1H:7,@
M9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M=7-T
M(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@
M9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@
M8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+;VQA8B!'
M<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL
M(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO
M;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I
M;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UE<W-A9V4@=V%S('=R
M:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R
M(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@
M<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4
M:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L
M=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL
M960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R`%1I8VME=',`5&EM
M90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L96-T:6]N`%1I
M;6]R+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`5&\`5&\@<V5L96-T
M(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O
M<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D87D`5&]G
M9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO<G)O=P!4;VYG80!4
M;W``5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA=&EO;G,`5')I;FED860@86YD
M(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U;FES:6$`5'5R:V5Y`%1U<FMI
M<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S
M($ES;&%N9',`5'5V86QU`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X
M.B``55),`%523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E
M<&]R=`!54DPZ`%5G86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@5D93
M(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T
M:6]N('=H96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M:7-S
M:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI
M<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O
M("5S+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@
M=&\@8V]N;F5C="!W:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N
M`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@
M=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93
M(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L
M92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@
M=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@
M)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T
M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O
M<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L
M92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93(')E
M8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I
M<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL
M<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE
M('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E
M<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B
M;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E
M9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O
M<GDN`%5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O
M;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E
M8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N`%5N
M86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92X`
M56YA8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N86)L92!T;R!T<F%N<VQA=&4@
M=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET92!61E,@9FEL92`B
M)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I
M+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`56YD97)L:6YE`%5N
M9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D
M(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C
M=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B``56YF:6QE9`!5;FEC;V1E
M("A55$8M."D`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`
M56YI=&5D(%-T871E<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES
M;&%N9',`56YI=',`56YK;F]W;@!5;FMN;W=N(&%P:6US9VED("A!4$D@365S
M<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$
M*2X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YL:6YK('1H92!C
M=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R:79I;&5G960@<V-R:7!T<R!C
M86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F
M;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN
M:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO=2!H;W<@
M=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N`%5N
M<V5T(&-O;&]R`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D871E
M("5S`%5P9&%T92!U<V5R`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A
M9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE
M('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB
M97)S`%5R=6=U87D`57-E($-U<G)E;G0Z("5S`%5S92!34TP`57-E(&EF(&YA
M;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E
M<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@061M:6YI<W1R
M871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S97(@4F5G
M:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N`%5S
M97)N86UE`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S>7-T
M96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="X`
M5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI
M9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU97,`5F%L=65S
M('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B;&4`5F5N97IU96QA`%9E
M<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E
M;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9E<G-I;VX@0V]N=')O;`!697)T
M:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E<G1I8V%L.@!697)Y($AI
M9V@`5FEE="!.86T`5FEE=&YA;65S92`H5DE30TE)*0!6:65W("5S`%9I97<@
M86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:7)G:6X@27-L86YD
M<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6:7-I8FEL:71Y`%9I
M<VEB:6QI='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU44`!705).`%=!4DY)
M3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+@!786QL:7,@
M86YD($9U='5N80!787)N:6YG`%=E`%=E871H97(@1F]R96-A<W0`5V5A=&AE
M<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!796(@4VET90!7
M965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=E<W1E
M<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T97)N
M(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F
M=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7
M:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H:6-H('!H87-E<P!7:&EC
M:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N
M`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N
M=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`
M5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN
M9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES9&]M`%=O<FL`5V]R
M:R!!9&1R97-S`%=O<FL@4&AO;F4`6"U2968`6#4P.78S($)A<VEC($-O;G-T
M<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4`6#4P.78S(%-U8FIE
M8W0@06QT97)N871I=F4@3F%M90!8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I
M9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!960!965E9`%EA:&]O(2!M87``665A
M<FQY`%EE;65N`%EE<P!997,L($D@06=R964`66]U(&%R92!I;B!415A4($U/
M1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=9
M4TE764<N`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO=2!C86X@;F]T
M(&AA=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO
M=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I
M9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O
M('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&AA=F4@8F5E
M;B!L;V=G960@;W5T+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP
M:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG
M(&9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"X`66]U(&AA
M=F4@=&\@96YT97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E
M(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@
M9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@
M<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@
M=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R
M('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T
M;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R
M96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`
M66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@
M;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T
M('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U<B`E<R!S97-S:6]N(&AA
M<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D
M<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U
M<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I
M;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C
M=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A
M=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN
M9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R
M('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H
M879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E
M<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G
M:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@
M9F5A='5R92X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT
M(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!N97<@<&%S<W=O<F0@
M9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N
M`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H
M87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I
M=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%EU
M9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M(:61E(%%U
M;W1E9"!497AT70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!497AT
M("T`6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI;F4@)7,@;V8@
M)7-=`%]!9&UI;FES=')A=&EO;@!?0TQ)`%]$871A5')E90!?1&5L971E(%)O
M=P!?1W)O=7!S`%](96QP`%]);6%G92!0<F]P97)T:65S+BXN`%],;V<@:6X`
M7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]097)M:7-S:6]N
M<P!?4F5M;W9E($QI;FLN+BX`7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN
M`%]5<V5R<P!A9&1R97-S(&)O;VL`8V%L96YD87(`8V%L;0!C;&EC:R!H97)E
M`&9A;&QI;F<`9FEL90!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&@Z`&EM
M;65D:6%T90!I;FQI;F4`;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W
M:&EL92!M86MI;F<@25-/+@!N86UE`&YO="!I;7!L96UE;G1E9`!N;W0@>65T
M(&EM<&QE;65N=&5D`&YO=&5P860`<&5R8V5N=`!P:7AE;',`<FES:6YG`'-H
M;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10`'-T96%D>0!T87-K
M(&QI<W0`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF
M:65D`'5N;F%M960`=7-E<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE<BYC;VT`
M4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C`M8W9S"E)E<&]R="U-<V=I
M9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$
M871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@
M,C`P-"TQ,2TR.2`Q,CHU,BLP,C`P"DQA<W0M5')A;G-L871O<CH@5FEL:75S
M(%-U;7-K87,@/'9I;&EU<T!L;FLN;'0^"DQA;F=U86=E+51E86TZ($QI=&AU
M86YI86X@/'9I;&EU<T!L;FLN;'0^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E
M;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ,PI#;VYT
M96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"@`@*'!R:67P("5S(&1I96YA
M<RD`("AM>6=T=6MA<R`E<RD`("CP:6%N9&EE;BD`("AV86MA<BD`(``E9"`E
M<R!I<B`E<P`E9"UD:65N^"!P<F]G;F]ZZP`E<R`M('!A<W1A8F$`)7,@86YT
M<W!A=61A<P`E<R!+0@`E<R!P<F]F:6QA:W1I:V]S('9E:6MS;6%I("T@<&%T
M=FER=&EN:6UA<P`E<R!R96=I<W1R86-I:F$`)7,@;G5O<W1A=&]S`"5S(&IA
M=2!E9WII<W1U;VIA+@`E<R`E<R`E<P`E<R!Y<F$@<')I=F%L;VUA<P`E<R!M
M:6YU=.MS`"5S(&YE<F%S=&%S+@!N=6\@)7,@:6MI("5S(&GP("5S`"5S(&%D
M<F5S^"!K;GEG96SK`"5S(&MA;&5N9&]R:75S`"5S('7^<F'P^"!K;GEG96SK
M`"5S(&1A<F+X('/@<F'P87,`)7,Z("5S`"P@9_MS:6%I("5S("5S`"P@:VEN
M=&$@;G5O("5S(&EK:2`E<P`M+2!P87-I<FEN:VET92`M+0`Q,B!V86QA;F3X
M(&9O<FUA=&%S`#(T('9A;&%N9/@@9F]R;6%T87,`,C0@=F%L86YD;W,`T&EA
M;2!B;&]K=6D@<F5I:V%L:6YG82!V:65T82!D=6]M96[X(&)A>NMJ92X`P79Y
M:V\@<FEM=&$@:VQA:61A`$YO<NMD86UI('7^:V]D=6]T:2!L86GP:^`@<')I
M=F%L;W1E('1U<NMT:2!V:67PX&KA(%!'4"!R86MTX"X`3F]RZV1A;6D@<&%T
M:6MR:6YT:2!P87-I<F'P>73@(&QA:?!KX"!P<FEV86QO=&4@='5RZW1I('9I
M9?#@:N$@4$=0(')A:W3@+@!.;W+K9&%M:2!A=&MO9'5O=&D@;&%I\&O@('!R
M:79A;&]T92!T=7+K=&D@=FEE\.!JX2!I<B!S;&%P=.!JX2!01U`@<F%K='5S
M+"!B96D@_FEN;W1I('-L87!TX&K@(&9R87KF+@!.;W+K9&%M:2!P87-I<F'P
M>71I(&QA:?!KX"!P<FEV86QO=&4@='5RZW1I('9I9?#@:N$@:7(@<VQA<'3@
M:N$@4$=0(')A:W1U<RP@8F5I(/YI;F]T:2!S;&%P=.!JX"!F<F%ZYBX`3F]R
MZV1A;6D@871K;V1U;W1I(&QA:?!KX"!P<FEV86QO=&4@='5RZW1I('9I9?#@
M:N$@:7(@<VQA<'3@:N$@4R]-24U%(')A:W1U<RP@8F5I(/YI;F]T:2!S;&%P
M=.!JX"!F<F%ZYBX`3F]RZV1A;6D@<&%S:7)A\'ET:2!L86GP:^`@<')I=F%L
M;W1E('1U<NMT:2!V:67PX&KA(&ER('-L87!TX&KA(%,O34E-12!R86MT=7,L
M(&)E:2#^:6YO=&D@<VQA<'3@:N`@9G)A>N8N`$YO<NMD86UI('7^:V]D=6]T
M:2!L86GP:^`@<')I=F%L;W1E('1U<NMT:2!V:67PX&KA(%,O34E-12!R86MT
MX"X`04T@<F]D>6UA<P!!32]030!!4$D@240`07!I92#PX2!R961A:W1O<FGX
M`$%P:64N+BX`5FES:?!K86D@87!AZ&EO:F4`5FES:?!K86D@<&5R('9I9'5R
MX0!3:7-T96UA(&YE='5R:2!T96ES:?@@<W5K=7)T:2!61E,@:V%T86QO9^`N
M`%-I<W1E;6$@;F5T=7)I('1E:7-I^"!S=6MU<G1I(%9&4R!F86ELX"X`4VQA
M<'1A_F]D:7,`4^!S:V%I=&$@=?[P86QD>71A+@!!<'-K86ET80!3=6MU<G1I
M`%-U:W5R=&D@<&]G<G5PX0!3=6MU<G1I('!O=&5I<V5S`$)L;VMO(.%T97)P
M:6UA<SH`4W5K=7)T:2!N875JX"!G<G5PY@!3=6MU<G1I(&YA=6IA<R!T96ES
M97,`3F%U:F\@=F%R=&]T;VIO('-U:_MR:6UA<SH`4')I9.MT:2!S='5L<&5L
MX0!.875J^"!N87)I^"!P<FEDZVII;6%S`%-U:W5R=&D@<&]RX`!0<FEDZW1I
M("5S(&UE;FEU('!R:64@36]Z:6QO<R#A<F%N:VGX(&IU;W-T;W,`P71R875K
M=&D@X2!A9')E<_@@:VYY9V5LYCH`P71R875K=&D@X2!M86YO(&%D<F5S^"!K
M;GEG96SF.@!3=6MU<G1I('9A<G1O=&]JX`!687)T;W1O:O@@:_MR:6UA<R!I
M\&IU;F=T87,N`$%D<F5S87,`061R97-A:0!!9&UI;FES=')U;W1I("T@9V%L
M:2!N=7-T871Y=&D@=&5I<V5S(&MI=&EE;7,@=F%R=&]T;VIA;7,`5F%L9'EM
M87,`0F%N97)I86D`069G86YI<W1A;F%S`$%L8F%N:6IA`$%L_GER87,`4')A
M=F%R9.L`3'EG:75O=&D`3'EG:6%V:6UA<SH`5FES;W,`5FES:2!P<FES:6IU
M;F?F('9A<G1O=&]J86D`5FES;W,@9W)U<.MS`%9I<V]S('1E:7/K<P!6:7-O
M<R!K971U<FEO<R!P=7/K<P!,96ES=&D@:V5L973@(&%D<F5S^`!,96ES=&D@
M;F%U9&]T:2!S=7+[\&EU;W3@('/@<F'PX#\`2F%U(&5G>FES='5O:F$`06QT
M97)N871Y=G5S($E-4U`@<')I<VEJ=6YG:6UA<P!!;'1E<FYA='EV=7,@24U3
M4"!S;&%P=&'^;V1I<P!!;'1E<FYA='EV=7,@24U34"!V87)T;W1O:F\@=F%R
M9&%S`$%L=&5R;F%T>79U<R!E;"X@<&'P=&\@861R97-A<P!!;'1E<FYA='EV
M^W,@\&%B;&]N86D`06QT97)N871Y=G5S('1E:W-T87,`06UE<FEK;W,@4V%M
M;V$`P79E9.MT92!N96QE:7-T:6[@(')E:6OP;>8N`$%N9&]R80!!;F=O;&$`
M06YG:6QA:0!!;F]N:6UI;FES('!R;WAY('-E<G9E<FES`$%T<V%K>6UA<P!!
M;G1A<FMT:61A`$%N=&EG=6$@:7(@0F%R8G5D80!-;V1U;&ES`$UO9'5L:7,@
M=F5I:VEA(&=E<F%I+@!0<FET86EK>71I(&ER('!O\&%K:6%M<P!0871V:7)T
M:6YT:0!"86QA;F1I<P!!<F%B:?!K82`H5VEN9&]W<RTQ,C4V*0!!<F-H>79O
M(&9A:6QO(&1Y9&ES`$%R8VAY=F\@9F%I;&\@<&%V861I;FEM87,`07(@=&EK
M<F%I(&YO<FET92!I\'1R:6YT:2`E<R!R96=I<W1R86-I:F]S('!R8?!Y;>`_
M`$%R9V5N=&EN80!!<FWK;FEJ80!!<FWK;FGP:V$@*$%235-#24DM."D`365N
M87,`07)U8F$`2W)I<W1A=7,@_F5N9VEM;R#A(&1A;F?X('-A;&$`06-S:6D@
M;65N87,`07II:F$O4F%M:6]J;R!V86YD96YY;F\@<F5G:6]N87,`07(@<')A
M\'ET:2!P871V:7)T:6YT:2!P<F]F:6QA:W1I:V]S('9E:6MS;75S/P!0<FES
M:WER:6UO('-T=6QP96QI86D`0F%N9&]T92!I\'1R:6YT:2!N965G>FES='5O
M:F%NZ&G@(&=R=7#F+@!"86YD;W1E(&GP=')I;G1I(&YE96=Z:7-T=6]J86[H
M:6%S('1E:7-E<RX`0F%N9&]T92!R961A9W5O=&D@;F5E9WII<W1U;VIA;NAI
M87,@=&5I<V5S+@!"86YD;W1E(')E9&%G=6]T:2!N965G>FES='5O:F%N=.$@
M96QE;65N=.`N`$%T<FEB=71A:0!2=6=P:OMT:7,`075S=')A;&EJ80!!=7-T
M<FEJ80!!=71H7V-Y<G-Q;#H@;F5R87-T87,@<F5I:V%L:6YG87,@24U!4"!M
M;V1U;&ES+@!!=71H7V-Y<G5S.B!C>7)U<R!N971U<FD@<F5I:VEA;?@@9V%L
M:6UY8FGX+@!!=71H7V-Y<G5S.B!N97)A<W1A<R!R96EK86QI;F=A<R!)34%0
M(&UO9'5L:7,N`$%U=&A?9G1P.B!N97)A<W1A<R!R96EK86QI;F=A<R!&5%`@
M;6]D=6QI<RX@4W5K;VUP:6QI=6]K:71E(%!(4"!S=2`M+65N86)L92UF='`N
M`$%U=&A?:6UA<#H@;F5R87-T87,@<F5I:V%L:6YG87,@24U!4"!M;V1U;&ES
M+@!!=71H7VMR8C4Z(&YE<F%S=&%S(')E:6MA;&EN9V%S(&MR8C4@;6]D=6QI
M<RX`075T:%]L9&%P.B!N97)A<W1A<R!R96EK86QI;F=A<R!,1$%0(&UO9'5L
M:7,N`$%U=&A?;&1A<#H@<W5K=7)T:2!V87)T;W1O:N`@)7,@;F5P879Y:V\N
M(%-E<G9E<FEO('!R86YE\&EM87,Z(`!!=71H7VQD87`Z(&GP=')I;G1I('9A
M<G1O=&]JX"`E<R!N97!A=GEK;P!!=71H7VQD87`Z(&%T;F%U:FEN=&D@=F%R
M=&]T;VK@("5S(&YE<&%V>6MO`$%U=&A?;6-A;#H@;F5R87-T87,@<F5I:V%L
M:6YG87,@34-!3"!M;V1U;&ES+@!!=71H7W-M8F%U=&@Z(&YE<F%S=&%S(')E
M:6MA;&EN9V%S('-M8F%U=&@@;6]D=6QI<RX`4')I<VEJ=6YG=&D@;F5P879Y
M:V\`4')I<VEJ=6YG=&D@;F5P879Y:V\N("5S`%)!1$E54R!S97)V97)I<R!N
M96QE:63^:6$@875T96YT:69I:W5O=&ES+@!0<FES:6IU;F=T:2!P<FEE($94
M4"!S97)V97)I;R!N97!A=GEK;RX`1V%L:6UI(&QA=6MA:3H`07IE<F)A:63^
M86YA<P!"3T9((&%T<VEP<F'P>6UA:0!&;VYA<P!&;VYO('-P86QV80!.971E
M:7-I;F=A<R!K97)B97)O<R!S;&%P=&'^;V1I<RX`3F5T96ES:6YG87,@:V5R
M8F5R;W,@=F%R=&]T;VIO('9A<F1A<RX`0F%H86UA:0!"86AR96EN87,`0F%L
M=&GP:V$@*$E33RTX.#4Y+3$S*0!"86=L861E\&%S`$)A<F)A9&]S87,`4&%G
M<BX@;&EN:6IO:F4`0F%L=&%R=7-I:F$`0F5L9VEJ80!"96QI>F%S`$)E;FEN
M87,`0F5R;75D86D`0G5T86YA<P!':6UT861I96YI<P!";&]K;R!P87)A;65T
M<F%I`$)L;VMO('1I<&%S`%!A<W1O<FEN=&D`0F]L:79I:F$`073^>6UO<P!+
M<F'P=&%S`$MR8?!T;R!S=&]R=6UA<SH`2W)A\'1A:0!";W-N:6IA(&ER($AE
M<F-E9V]V:6YA`%9I<V]S`$)O='-V86YA`$%P8>AI;VIE`$)U=F5T('-A;&$`
M0G)A>FEL:6IA`$)R:73X($EN9&EJ;W,@=F%N9&5N>6YO('1E<FET;VIA`$)R
M=6[K:F%U<R!D87)U<V%L96UA<P!"=6QG87)I:F$`4W7^>6WK=&%S('/@<F'P
M87,`0G5R:VEN87,@1F%S87,`0G5R=6YD:6IA`%164P!#4D,`0U),('!A<VMI
M<G-T>6UO('!U;FMT86D`7T-E;.MS(&YU<W1A='EM86DN+BX`2V%L96YD;W)I
M=7,`4F%M=0!+86UB;V3^80!+86UE<OMN87,`3F5V96EK:6$@875T;VUA=&EN
M:7,@<VQA<'1A_F]D_FEO('!A:V5I=&EM87,L('-U<VES:65K:71E('-U(&%D
M;6EN:7-T<F%T;W)I=6UI+@!.96=A;&EU('!R:7-I:G5N9W1I('!R:64@24U!
M4"!S97)V97)I;SH@)7,`2V%N861A`$%T\&%U:W1I`$%T\&%U:W1I('!R;V)L
M96UO<R!P<F%N9?!I;>``3F5G86QI=2!I\'1R:6YT:2!F86EL;R`B)7,B+@!.
M96=A;&EU(')A<W1I(&QA:6MI;F]J;R!K871A;&]G;RX`3F5G86QI=2!A<&1O
M<F]T:2`G=&%R9V5T1FEL92<@<&%R86UE=')O+@!.96=A;&EU(&GP=')I;G1I
M(&MA=&%L;V=O("(E<R(N`$YE9V%L:74@:?!T<FEN=&DN($5G>FES='5O:F$@
M)60@<&_P86MI86DN`$YE9V%L:74@<&5R<OOP:75O=&DN(,%V97-T87,@X7)A
M\/@@<VMA:>AI=7,@;F5S=71A;7!A('-U(.%R8?#X('-K86GH:75M:2!D=6]M
M96[X(&)A>NMJ92X`3F5G86QI=2!N=6MR96EP=&D@_FEN=73K<R#A(&YU<F]D
M>73@(&YU;65RX2X`2V5I<'9E<F1I<P!0879A9&EN:6UA<P!+871E9V]R:6IO
M<P!+86EM86[X('-A;&]S`$UO8FEL=7,@=&5L969O;F%S`$-E;.MS(&YU<W1A
M='EM86D`5&%R<&%I(&-E;.MS93H`0V5LZW,@;G5S=&%T>6UA:0!487)P86D@
M=&%R<"!C96QI^#H`36]B:6QU<VES('1E;&5F;VYA<P!+96QT^"`H25-/+3@X
M-3DM,30I`$-E;G1R90!#96YT<FENZW,@069R:6MO<R!297-P=6)L:6MA`$-E
M;G1R:6[K<R!%=7)O<&]S("A)4T\M.#@U.2TR*0!397)T:69I:V%T;R!D971A
M;.MS`%-E<G1I9FEK871O('1E:7/K<P#(861A<P!086ME:7-T:0!*^W/X('9A
M<F1O(&ER(&%D<F5S;RP@:W5R:75O<R!M871Y<R#^;6]NZW,L('-K86ET86YT
M>7,@:7(@871S86MI;NMJ86YT>7,@X2!*^W/X(&QA:?!K=7,L(&ME:71I;6%S
M+@!3:6UB;VQI<P!085]T:6MR:6YT:2!N=6]R;V3@+BXN`,AI;.L`2VEN:6IA
M`$MI;FEE=&GP:V$@<&%P<F%S=&$@*$=",C,Q,BD`2VEN:65T:?!K82!T<F%D
M:6-I;NL@*$)I9S4I`%!A<VER:6YK:71E('-L87!T8?YO9.$`4&%S:7)I;FMI
M=&4@=F%R=&]T;VIO('9A<F3@`%!A<VER:6YK:71E(&MA:7`@=F%I>F1U;W1I
M(&1A=&%S.@!087-I<FEN:VET92!S=7+[\&EU;W1O('/@<F'P;R!S=&EL:?@`
M2V%LZV3X('-A;&$`2VQA<^MS("5S(&[K<F$N`$=I961R80!)\'1R:6YT:2!-
M4R!/9F9I8V4@_GEM97,`5F%R=&]T;VIO(&1U;VUE;O@@=F%L>6UA<SH@)7,`
M2?!V86QY=&D@=F%R=&]T;VIO(&1U;VUE;FES`$GP=F%L>71I('9A<G1O=&]J
M;R!D=6]M96YI<P!4YG-T:0!#;&EC:V%T96QL('!E<B!(5%10`%7^9&%R>71I
M(&QA;F?@`$1E8F5S=6]T80!$96)E<W5O=&$`2V]K;W-O("A+>6QI;F=O*2!S
M86QO<P!4=?#H:?@@8V5L:?@@:W)A\'3X(')O9'EM87,`2V]L=6UB:6IA`%-P
M86QV80!087-I<FEN:VET92!S<&%L=N``4W!A;'9O<R!P87-I<FEN:VEM87,`
M4W1U;'!E;&EA:3H`4W1U;'!E;&GX('!A=F%D:6YI;6%I`$MO;6EK<V%I`$MO
M;6%N9&$`2V]M86YD:6[K(&5I;'5TZP!+;VUE;G1A<F%S`%9A<F1A<R]P879A
M<F3K`$MO;6]R86D`2V]M<&%N:6IA`$MO;7!I=71E<FEA:0!3X&QY9V]S`$YU
M<W1A='EM^"!P86ME:71I;6%I`$MO;F9I9_MR=6]T:2`E<P!3;&%P=&'^;V1I
M<R!D87(@:V%R=.``2V]N9V%S`$1E;6]K<F%T:6[K($MO;F=O(%)E<W!U8FQI
M:V$`4')I<VEJ=6YG=&D@;F5P879Y:V\N`%!R:7-I:G5N9W1I(&YE<&%V>6MO
M.B``4')I<VEJ=6YG=&D@<')I92!V:67P^&KX(')A:W3X('-E<G9E<FEO(&YE
M<&%V>6MO+@!0<FES:6IU;F=T:2!P<FEE('9I9?#X:O@@<F%K=/@@<V5R=F5R
M:6\@;F5P879Y:V\L(&YE<SH@)7,@*"5S*0!0<FES:6IU;F=T:2!P<FEE($94
M4"!S97)V97)I;R!N97!A=GEK;RX`2V]N:V%K=&%I('/K:VUI;F=A:2#A=')A
M=6MT:2#A($K[<_@@861R97/X(&MN>6=E;.8`5.9S=&D`2W5K;R!S86QO<P!,
M86EMZW,@_FEN=73K<P!+;W!I:G5O=&D`2V]P:6IU;W1I('!A<VER:6YK:6W@
M`$MO<W1A(%)I:V$`1')A;6)L:6\@2V%U;&\@2W)A;G1A<P!.97!A=GEK;R!U
M_FMO9'5O=&D@4$=0(&QA:?!K;RX`3F5P879Y:V\@<&%S:7)A\'ET:2!01U`@
M;&%I\&MO+@!.97!A=GEK;R!U_FMO9'5O=&D@4R]-24U%(&QA:?!K;RX`3F5P
M879Y:V\@<&%S:7)A\'ET:2!3+TU)344@;&%I\&MO+@!.97!A=GEK;R!P<FED
MZW1I(&MO;G1A:W1O+B`E<P!.97!A=GEK;R!A=71E;G1I9FEK=6]T:7,@X2!,
M1$%0('-E<G9E<N$N`$YE<&%V>6MO('!A=&EK<FEN=&D@8F%L86YS;RX@)7,`
M3F5P879Y:V\@<W5K=7)T:2!D:7-T<FEB=6-I:F]S('/@<F'P;RX@)7,`3F5P
M879Y:V\@871K;V1U;W1I(%!'4"!D=6]M96[X+@!.97!A=GEK;R!A=&MO9'5O
M=&D@4R]-24U%(&1U;VUE;O@N`$YE<&%V>6MO(&GP=')I;G1I(&MO;G1A:W1O
M+B`E<P!.97!A=GEK;R!I\'1R:6YT:2!D:7-T<FEB=6-I:F]S('/@<F'P;RX@
M)7,`3F5P879Y:V\@;G5S=&%T>71I(&=A=NMJ;R!E;"X@<&'P=&\@861R97-O
M+@!0879Y:V\@9V%U=&D@=FES;W,@861R97/X(&MN>6=E;.MS+@!.97!A=GEK
M;R!G875T:2!V:7-O(&1I<W1R:6)U8VEJ;W,@<^!R8?!O+@!.97!A=GEK;R!G
M875T:2!V:7-O(&1I<W1R:6)U8VEJ;W,@<^!R8?#X('/@<F'P;RX`3F5P879Y
M:V\@9V%U=&D@=FEE\&]J;R!R86MT;R!I\"!R86MT^"!S97)V97)I;RX`3F5P
M879Y:V\@871I9&%R>71I("5S+@!.97!A=GEK;R!A=&ED87)Y=&D@36%I;G1E
M;F%N8V5?5&%S:R!M;V1U;&EO("5S`$YE<&%V>6MO('-K86ET>71I("5S+@!.
M97!A=GEK;R!P86ME:7-T:2!S;&%P=&'^;V3^:6\@\&EA;2!V87)T;W1O:G5I
M+B!+86D@:W5R:2!A<F)A('9I<V$@:6YF;W)M86-I:F$@>7)A(&YE=&EK<VQI
M+B!086)A;F1Y:VET92!D87(@:V%R=.`@87)B82!S=7-I<VEE:VET92!S=2!S
M879O(&%D;6EN:7-T<F%T;W)I=6UI(&IE:6=U(')E:6MA;&EN9V$@<&%G86QB
M82X`3F5P879Y:V\@9V%U=&D@04-,`$YE<&%V>6MO(&=A=71I(&%D<F5S^"!K
M;GEG96SK<RX@)7,`3F5P879Y:V\@9V%U=&D@9&ES=')I8G5C:6IO<R!SX')A
M\&\N("5S`$YE<&%V>6MO(&=A=71I(&1I<W1R:6)U8VEJ;W,@<^!R8?#X+B`E
M<P!.97!A=GEK;R!N=7-T871Y=&D@<V5R=F5R:6\@9V%L:6UY8FGX`$YE<&%V
M>6MO(&%T:V5I<W1I(&YU<W1A='EM^"X`3F5P879Y:V\@:?!S875G;W1I("5S
M(&YU<W1A='EM^"X`3F5P879Y:V\@<&%D87)Y=&D@871S87)G:6[K<R!N=7-T
M871Y;?@@:V]P:6IO<RX`3F5P879Y:V\@<&%I9?!K82!,1$%0('-E<G9E<GEJ
M92X`3F5P879Y:V\@871N875J:6YT:2!K;VYT86MT;RX@)7,`3F5P879Y:V\@
M871N875J:6YT:2!D:7-T<FEB=6-I:F]S('/@<F'P;RX@)7,`3F5P879Y:V\@
M<F%S=&D@36]Z:6QO<R#A<F%N:VGX(&IU;W-T;W,N(,%S:71I:VEN:VET92P@
M:V%D(&II(&%T:61A<GET82X`4FEB;W1A<R!T96MS=&%S`%9A;'-T>6+K`$MU
M<G-A:0!3=6MU<G1I`%-U:W5R=&D@;G5O<F]DX`!3=6MU<G1I(&YA=6K@(&%P
M<F'PX`!3=6MU<G1I('!A:V%T86QO9VEU<P!3879I;FEN:V\@=&5I<^MS`$MR
M961I=&ENZW,@:V]R=&5LZW,@;G5M97)I<P!+<F]A=&EJ80!+=6)A`$1A8F%R
M=&EN:7,@;&%I:V%S`-!I=6\@;65T=2!54DP@>7)A`$1A8F%R=&ENZW,@;W)O
M('/@;'EG;W,`1&%B87)T:6[K<R!SX&QY9V]S.B``1&%B87)T:6YI<R!S=&EL
M:75S`%9E:6MS;?@L(&%T;&EE:V%M^"!P<FES:6IU;F=U<R!P<FEE("5S+"!N
M=7-T871Y;6%S+@!097)K96QT:0!097)K96QT:2!P87-I<FEN:VEMX`!+:7!R
M87,`2VER:6QI8V$@*$M/23@M4BD`2VER:6QI8V$@*%=I;F1O=W,M,3(U,2D`
M2VER:6QI8V$O56MR86EN:65T:?!K82`H2T])."U5*0#(96MI:F]S(%)E<W!U
M8FQI:V$`1$0`2V%S9&EE;@!$=6]M96[X(&UE9/YI;R!N87+P>6MLZP!$871A
M`$=A=71A`$1A=&]S('!A<VER:6YK:6UA<P!$:65N80!)\'1R:6YT:2!?<W1U
M;'!E;.$`1W)U;V1I<P!$9?!I;71A:6YI86D@<VMA:>AI86D`4W5M8?YI;G1I
M(&%T:71R875K:6W@`%-T86YD87)T:6[K('-P86QV80!3=&%N9&%R=&EN:7,@
M87!R8?!A<P!!<&EB<NO^:6UA:0!)\'1R:6YT:0!)\'1R:6YT:2!G<G5PY@!)
M\'1R:6YT:2!T96ESY@!6:7-I\&MA:2!I\'1R:6YT:2!L86GP:W5S`$GP=')I
M;G1I(&-E;.8`2?!T<FEN=&D@<W1U;'!E;.$`2?!T<FEN=&D@96=Z:7-T=6]J
M86YTX2!A;'1E<FYA='EV^"#P86)L;V[@`$GP=')I;G1I(&5I;'5TY@!)\'1R
M:6YT:2!P87-I<FEN:W3@(&%P<F'PX`!)\'1R:6YT:2#PX2!S='5L<&5LX0!)
M\'1R:6YT:2#P:>`@96EL=73F`%!R:7-T871Y;6\@;&%I:V%S`$1A;FEJ80!0
M<F]B;&5M;W,@87!R8?!Y;6%S`$%P<F'P>6UA<P!$971A;&EA=2`H=&%I<"!P
M870@_FG[<NMK:71E($AO<F1E(&QO9R!F86EL92DZ`$%D;6EN:7-T<F%T;W)I
M=6D@:?!S:?AS=&%S(&1E=&%L=7,@87!R8?!Y;6%S+@!6>7-T>6UA<P!$<NMG
M;G5M87,`1'+K9VYU;6%S('!A<VMU=&ENYB!V86QA;F3@.B``1'+K9VYU;6%S
M.B``2W)Y<'1I<R!I\"!K86ERZW,@X2!D9?!I;N8`2W)Y<'1I<R!I\"!D9?!I
M;NMS(.$@:V%I<N8`2V%T86QO9V%S`%)O9'ET:2`R-"UI^"!V86PN(&9O<FUA
M=.`_`%9A:7ID879I;6\@;G5S=&%T>6UA:0!2;V1Y=&D@<')O9W)O;N8@*%1!
M1BD`5F%I>F1A=FEM;R!F;W)M871A<P!,86GP:V\@<')I<W1A='EM;R!P<F%N
M9?!I;6%I`$3^:6)U=&ES`$YE=')I;G1I`$YE<VEK<F5I<&MI=&4@=&EE<VEO
M9VEA:2#A(&UA:6YT96YA;F-E+G!H<`!!<B!P:7)M87,@X7)A\&%S('ER82!L
M875K;R!V87)D86D_`$1O;6EN:6MA`$1O;6EN:6MO<R!297-P=6)L:6MA`$%T
M<VES:?AS=&D`071S:7-I^'-T:2`E<P!!='-I<VGX<W1I('-U9V5N97)U;W1U
M<R!N=7-T871Y;75S(&MA:7`@4$A0('-K<FEP=.`N`$GP<VES:VQE:63^:6%N
M=&ES('/@<F'P87,`5F%I<W1A:0!%;"X@<&'P=&\@861R97-A<P!%4E(`16MV
M861O<F%S`$ME:7-T:0!+96ES=&D@8FQO:V\@<&%R86UE=')U<P!2961A9W5O
M=&D@9W)U<.8`4F5D86=U;W1I('1E:7-E<P!2961A9W5O=&D@=&5I<V5S`"5S
M('1E:7-I^"!R961A9V%V:6UA<P!+96ES=&D@;G5S=&%T>6UU<SH`)7,@=&5I
M<VGX(')E9&%G879I;6%S`%5G9'EM87,`16=I<'1A<P!386QV861O<F%S`$5L
M96UE;G1A<RXN+@!%;0!%;"X@<&'P=&%S`$5L+B!P8?!T;R!A9')E<V%S`$5L
M+B!P8?!T;R!A9')E<V%I('1U<FD@<W5T87!T:2X`16PN('!A\'1O(&%D<F5S
M87,@<W4@<&%T=FER=&EN:6UU`-!Y<'-E;NMLZW,`WFEN=73K('1U\.AI82X`
M4F5Z=6QT871A<R!T=?#H:6%S+@!.96YU<F]DZW1E('!A:67P:V]S('1E<FUI
M;O@`3&5I<W1I('1E:W-T92#A=&5R<'1I('!A=F5I:W-LZVQI=7,@:?`@3G5O
M=')A=6OX(&=A;&5R:6IO<S\`P6IU;F=T:2!D9?!I;FEO:F\@<&5LZW,@;7EG
M='5K;R!M96YI=3\`1V%L:6YI86D@;65T86D`2?!P;.MS=&D@<F5D86MT;W)I
M^`#!<F'P>6MI=&4@:VQA=7-I;>`L(&MU<FES(&IU;7,@8G5S('7^9'5O=&%S
M(&IE:6=U('!A;6ER\&ET92!S879O('-L87!T8?YO9.$L('!V>BXZ("=K;VMS
M('ER82!*^W/X(&=Y=OMN;R!V87)D87,_)SH`P79E<VMI=&4@<&%V96EK<VSK
M;&EO(%523`!%:W9A=&]R:6[K($=V:6[K:F$`17)I='+K:F$`2VQA:61A`$ML
M86ED82!L86GP:V4N`$5S=&EJ80!%=&EO<&EJ80!%=&YI;NMS`$5U<F]P80!+
M87,@,34@;6EN=>AI^`!+87,@,B!M:6YU=&5S`$MA<R`S,"!S96MU;F3^:?@`
M2V%S(#4@;6EN=71E<P!+:65K=FEE;F\@<')I<VEJ=6YG:6UO(&UE='4`2V%S
M('!U<W9A;&%N9.$`2V%S(&UI;G5TY@!0879Y>F3^:75I.@!6>6MD>71I`$GP
M<VML96ES=&D`4F5I:V%L:6YG87,@)RDG`%)E:6MA;&EN9V%S(/YO9&ES(&%R
M8F$@:V%B=73K<V4@X7)A\'ET87,@<&%I9?!K;W,@:W)I=&5R:6IU<P!'86QI
M;VII;6\@9&%T80!%:W-P;VYE;G3K`%1E:W-T;R!S<&%L=F$`3G5S=&%T>6WX
M('-I=6YT:6UA<R!P97(@1E10+@!+;&%I9&$@;G5S:V%I=&%N="!N=7-T871Y
M;75S+@!.97!A=GEK;R!P<FES:6IU;F=T:2!P<FEE($Q$05`@<V5R=F5R:6\N
M`$YE<&%V>6MO('!R:7-I:G5N9W1I('!R:64@4TU"('-E<G9E<FEO+@!.97!A
M=GEK;R!N=6MO<&EJ=6]T:2!I\"`B)7,B+@!.97!A=GEK;R!N=6MO<&EJ=6]T
M:2#A("(E<R(N`$YE<&%V>6MO('-U:W5R=&D@;F%U:F\@4T%33"!R>?!I;RX`
M3F5P879Y:V\@<&5R:V5L=&D@X2`B)7,B+@#0=F5L;G5S`$9O;&ML86YD^"!S
M86QO<R`H36%L=FEN86DI`$9A<F5R^"!S86QO<P!&86MS87,`5F%S87)I<P!!
M=')O9&\@;'EG`$%T<F]D;R!L>6<Z(`!4<G5M<&%L86EK:7,@;&EE='5S`$9I
M9/YI<P!&86EL^"!S:V%IZ&EU<SH@)7,@9F%I;&%S`$9A:6SX('-K86GH:75S
M.B`E<R!F86EL86DH^"D`1F%I;/@@='9A<FMY;6%S`$9A:6QO('!A=F%D:6YI
M;6%S`$9A:6QO('!A<VER:6YK:6UA<P!&86EL;R!S:75N=&EM87,`3F%R\'EK
M;.L@;F5P86QA:6MO(&9A:6SX('-I=6YT:6UO+@!&:6QT<F%I`%-U;VUI:F$`
M4&ER;6]J:2!P=7/K`%!I<FUA<VES(&ME='9I<G1I<P!.=7-T871Y=&%S(&MO
M969I8VEE;G1A<P!!='9I<FOPZ&EA<P!)\&3K<W1Y;6%S`%+[:V%S`$MA=&%L
M;V=A<R`E<R!N965G>FES='5O:F$`5&5K<W1O('-P86QV80!-86ES=&%S`$YA
M<O!Y:VSK;7,L(&MU<FEO<R!N97!A;&%I:V\@<&%V96EK<VSK;&GX`$]R^"!P
M<F]G;F]ZZR`H5$%&*0!/<O@@<')O9VYO>NMS(&%P:6UT:7,@*.%S:63K;>MK
M:71E+"!K860@\&D@9G5N:V-I:F$@9W)A_FEN82!I<B!D:65N;W,@:7(@;F%K
M=&EE<R!P<F]G;F]ZYCL@<&5R(&1I9&5L:7,@<VMA:>AI=7,@9V%L:2!S=61A
M<FMY=&D@9&EZ86ENX"D`4&%M:7+P;W1E('-A=F\@<VQA<'1A_F]DX3\`1F]R
M;6]S`$9R87KK`$9R87II^"!T:7!A<P!&<F%ZZW,`1G)A>NMS(#(`1&ES:W5S
M:6IO<P!097)S:75N=&EM86D`4&5N:RX`2W)A\'1I;NMS`%!R86YC^WII:F$`
M4')A;F/[>FEJ82P@365T<F]P;VQI<P!0<F%N8_MZ:6IO<R!'=FEA;F$`4')A
M;F/[>FEJ;W,@4&]L:6YE>FEJ80!0<F%N8_MZ:6IO<R!P:65T:6[K<R!T97)I
M=&]R:6IO<P!.=6\`3G5O(`!0:6QN87,@87!R8?!Y;6%S`%!I;&YA=&ES`%!I
M;&YA<R!V87)D87,`1V%B;VYA<P!'86QE<FEJ82!I\"!K=7)I;W,@:?`@:W5R
M:6]S(&)U<R!R;V1O;6%S('!A=F5I:W-LZVQI<P!'86QE<FEJ83H`1V%M8FEJ
M80!'96YE<G5O=&D@)7,@;G5S=&%T>6UU<P!3=6=E;F5R=6]T87,@:V]D87,`
M1W)U>FEJ80!6;VMI971I:F$`1V%N80!':6)R86QT87)A<P!687)D87,`4F]D
M>71I`$=A9&5L:7,`1V]O9VQE('!A:67P:V$`3F5S<&%L=F]T87,`1W)A:6MI
M:F$`1W)A:6MI\&MA("A)4T\M.#@U.2TW*0!'<F5N;&%N9&EJ80!'<F5N861A
M`$=R=7!I^"!A9&UI;FES=')A=FEM87,`1W)U<.MS('9A<F1A<R!T=7)I(&+[
M=&D@;F5T=?#H:6%S`$=R=7#K<P!'=F%D96QU<.L`1W5A;6$`1W9A=&5M86QA
M`$=E<FYS:7,`4W9EZ&GX('1E:7/K<P!3=F7H:?@@:VYY9V$`1W9I;NMJ80!"
M:7-S874M1W9I;NMJ80!'86IA;F$`2%1-3`!(5$U,07)E82!N96=A;&D@:?!T
M<FEN=&D@<&%S:W5T:6[K<R!C96SK<R!E:6QU=.MJ92X`2%1-3$%R96$@;F5G
M86QI(&GP<FEN=&D@<&%S:W5T:6YI;R!S='5L<&5L:6\@;&5N=&5LZVIE+@!(
M5$U,07)E82!N96=A;&D@:?!T<FEN=&D@<&%S:W5T:6[K<R!E:6QU=.MS(&QE
M;G1E;.MJ92X`4F5I:V%L:6YG82!(5%10(&%U=&5N=&EF:6MA8VEJ82X`2&%I
M=&ES`$AA<V@M06QG;W)I=&UA<P!-:6=L80!!;G1R8?!TZP!(97)D;R!S86QA
M(&ER($UA:V1O;F%L9&\@<V%L;W,`2&5B<F%J^"`H25-/+3@X-3DM."U)*0!!
M=6OP=&ES`%!A9V%L8F$`4F5D86MT;W)I875S(&YA=61O:FEM;W-I('!A9V%L
M8F$`4&%G86QB:6YI;FMA<P!(96UI<V9E<F$`T'1A:2#H:6$@>7)A(&9A:6QO
M('!R863^:6$Z`%-V87)B=0!?4&]R=&%L87,`T'9E;G1A<VES(%-O<W1A<R`H
M5F%T:6MA;F\@=F%L<W1I:F$I`%!O<G1A;&%S`$YA;?@@861R97-A<P!.86WX
M('1E;&5F;VYA<P!(;VYD^W)A<P!(;VYK;VYG87,`4&]R=&%L87,`2&]R9&4O
M2V]L86(Z(&YE=&5I<VEN9VD@)7,@6$U,(&1U;VUE;GES(/YI;G5TZVIE("5S
M`$AO<F1E+TMO;&%B.B!O8FIE:W1O("5S(&YE871I=&EN:V$@:F]K:6$@_FEN
M=73K`$AO<F1E+TMO;&%B.B!O8FIE:W1O('1I<&%S("5S(&YE<F%S=&%S(/YI
M;G5TZVIE("5S`$AO<F1E+TMO;&%B.B`E<R`B)7,B('/K:VUI;F%I(&GP=')I
M;G1A`$AO<F1E+TMO;&%B.B!I;G1E9W)A8VEJ;W,@=F%R:6ML:75K=6D@<F5I
M:V%L:6YG87,@)V1O;7AM;"<@4$A0(&UO9'5L:7,`2&]R9&4O2V]L86(Z(&YE
M<&%V>6MO('-U:W5R=&D@;F%U:F\@6$U,(&UE9/YI;R!O8FIE:W1U:2`E<P!(
M;W)D92]+;VQA8CH@;F5P879Y:V\@:?!T<FEN=&D@)7,@(B5S(CH@)7,`2&]R
M9&4O2V]L86(Z(&YE<&%V>6MO(&=A=71I($U)344@240@9&%L:6%I("5S('1I
M<&\`2&]R9&4O2V]L86(Z(&YE<&%V>6MO('-U<VEN8VAR;VYI>G5O=&D@)7,@
M(B5S(CH@)7,`2&]R9&4O2V]L86(Z(&YE<&%V>6MO('-U<VEN8VAR;VYI>G5O
M=&D@96QE;65N=/@Z("5S`$AO<F1E+TMO;&%B.B!N9?YI;F]M87,@96QE;65N
M=&%S("(E<R(`2&]R:7IO;G1A;&D@;&EN:6IA`$AO<FEZ;VYT86QU<R!T87)P
M87,`2&]R:7IO;G1A;&EA:3H`2V%I<"#H:6$@<&%T96MO=&4_("A0<F%N9?!K
M:71E(2D`2VEE:R!S='5L<&5L:?@@;F]R:71E('-U:G5N9W1I/P!+:65K(&QA
M=6OX("AS='5L<&5L:?@I('1E;B!Y<F$_`$MI96L@96EL=>AI^"!N;W)I=&4@
M<W5J=6YG=&D_`$1RZV=N=6UA<P!$<NMG;G5M87,Z(`!*=6UO<F5S:V]S`%9E
M;F=R:6IA`$YE<&%V>6MO('-U:W5R=&D@24U!4"!P8?!T;R!DZ_YU=.MS.B`E
M<P!.97!A=GEK;R!I\'1R:6YT:2!)34%0('!A\'1O(&3K_G5TZW,Z("5S`$YE
M<&%V>6MO(&YU<W1A='ET:2!)34%0('!A\'1O(&3K_G5TZW,@9'ED_FEO.B`E
M<P!)4"!A9')E<V%S`$YE<&%V>6MO(&=A=71I($E0(&%D<F5S;RX`25`@861R
M97-A<R!N971E:7-I;F=A;64@0TE$4B!B;&]K92X`25`@=?YR86MI;G1A<RX`
M7\%T97)P=&D@96EL=73F('9I<O!U:F4`27-L86YD:6IA`%1I:R!P:6MT;V=R
M86UO<P!0:6MT;V=R86UO<R!S=2!T96MS='4`07!R8?!O('!A=F%D:6YI;6%S
M.@!*96D@;F5G86QI=&4@<&5R<VMA:71Y=&D@\&EO(&QA:?!K;RP@)7,N`$IE
M:6=U(&UA=&]T92#P:>`@_FEN=73F('9I971O:B!P879E:6MS;.ML:6\L(&MU
M<N$@;F]R:71E(.%K96QT:2P@=&%I($K[<_@@;F%R\'EK;.L@;F5G86QI(&IO
M(&%T=F%I>F1U;W1I+@!0879E:6MS;.ML:6\@<&5R_FG[<F$`4&%V96EK<VSK
M;&EO(%523`!0879E:6MS;.ML:6\@55),.@!0879E:6MS;.ML:7,@:?`@9V%L
M97)I:F]S`%!A=F5I:W-LZVQI<R!I\"!G86QE<FEJ;W,Z`%!A=F5I:W-LZVQI
M;R#A:^ML:6UA<P!686EZ9&%I`,%KZVQI;6%S+"`E9"#^:6YG<VYI<P!,875K
M87,@X6ME;'1A<SH@)7,`P6ME;'1I(&QA=6MA:3H`P5]T97)P=&D@96EL=73F
M(&%P8>AI;VIE`$YE=&5I<VEN9V%S('9E:6MS;6\@:V]D87,N`$YE=&5I<VEN
M9V%S('9A<G1O=&]J;R!V87)D87,@:7(O87)B82!S;&%P=&'^;V1I<RX`3F5I
M=&5I<VEN9V%S('9A<G1O=&]J;R!V87)D87,@87)B82!A;'1E<FYA='EV=7,@
M96PN('!A\'1O(&%D<F5S87,N($)A;F1Y:VET92!D87(@:V%R=.`@87)B82!S
M=7-I<VEE:VET92!S=2!S879O(&%D;6EN:7-T<F%T;W)I=6UI(&IE:6=U(')E
M:6MA;&EN9V$@=&]L97-NZR!P86=A;&)A+@!0861I9&EN=&D@871I=')A=6MI
M;>``26YD:6IA`$EN9&EV:61U86S[<R!V87)T;W1O:F%I`$EN9&]N97II:F$`
M26YF;W)M86-I:F$`26YF;W)M86-I:F$`P71R875K=&D@<W1U;'!E;.$@7V1E
M\&ENZVIE`,%T97)P=&D@<&%V96EK<VSK;.$`P71E<G!T:2!L96YT96SF`,%T
M97)P=&D@;G5O<F]DX`#!=&5R<'1I('-T=6QP96SA(%]K86ERZVIE`,%T97)P
M=&D@;F%U:N`@<W1U;'!E;.$@97-A;6\@<W1U;'!E;&EO(&1E\&ENZVIE`,%T
M97)P=&D@;F%U:N`@<W1U;'!E;.$@97-A;6\@<W1U;'!E;&EO(&MA:7+K:F4`
MP71E<G!T:2!N875JX"!E:6QU=.8@97-A;6]S(&5I;'5TZW,@87!AZ&EO:F4`
MP71E<G!T:2!N875JX"!E:6QU=.8@97-A;6]S(&5I;'5TZW,@=FER\'5J90#!
M=&5R<'1I('!A<F%G<F%FX"!E;&5M96YT;R!A<&'H:6]J90#!=&5R<'1I('!A
M<F%G<F%GX"!E;&5M96YT;R!V:7+P=6IE`,%T97)P=&D@86QT97)N871Y=O@@
M\&%B;&]NX`#!<F'P>6MI=&4@96PN('!A\'1O(&%D<F5SX"P@X2!K=7+A(&YO
M<FET92!G875T:2!N875JX"!S;&%P=&'^;V3A.@#!=&5R<'1I(&-E;.8@<&\@
M=&\`P71E<G!T:2!C96SF('!R:67P('1A:0#!=&5R<'1I('-T=6QP96SA(&1E
M\&ENZVIE`,%T97)P=&D@<W1U;'!E;.$@:V%I<NMJ90#!=&5R<'1I(&QA:?!K
M=7,`P71E<G!T:2!P87)A9W)A9N`@<&\@=&\`P71E<G!T:2!P87)A9W)A9N`@
M<')I9?`@=&%I`,%T97)P=&D@96EL=73F('!O('1O`,%T97)P=&D@96EL=73F
M('!R:67P('1A:0#!<F'P>6MI=&4@<F5I:VEA;>`@871S86MY;>`@X2!K;&%U
M<VEMX"!V:7+P=6IE.@#!=&5R<'1I+W)E9&%G=6]T:2!P879E:6MS;.MLX0#!
M=&5R<'1I+U)E9&%G=6]T:2!N=6]R;V3@`$1I<W1R:6)U8VEJ;W,@<^!R8?!U
M:2!N=7-I^'-T:2!N977^=&5N:V$@:W)E9&ET;RX`3F5U_G1E;FMA(&MR961I
M=&\N`%-K86GH:75S`%-K86GH:?@@<^!R8?!A<P!.971E:7-I;F=A<R!51$@N
M("A5<V5R($1A=&$@2&5A9&5R*2X`3F5T96ES:6YG87,@;6]D=6QI<RX`3F5T
M96ES:6YG87,@240N`,%V97-T:2!N971E:7-I;F=I(&1U;VUE;GES+@!.971E
M:7-I;F=A<R!A9')E<V%S+@!.971E:7-I;F=A<R!F86EL;R!F;W)M871A<P!.
M971E:7-I;F=A<R!M<V=?='EP92X`3F5T96ES:6YG87,@87)B82!NZW)A(&%P
M:5]I9"X`4&%R86UE=')A:2!N971E:7-I;F=I(&%R8F$@:O@@;NMR82X`3F5T
M96ES:6YG;W,@<&%V96QD:6UO<R!T96ESZW,N`$YE=&5I<VEN9V%S('!R;W1O
M:V]L87,N`$YE=&5I<VEN9V%S(&]B:F5K=&%S`$YE=&5I<VEN9V%S('-I=6YT
MZVIO(&%D<F5S87,N`$YE=&5I<VEN9VD@=6YI:V]D;R!D=6]M96YY<RX`26YV
M96YT;W)I=7,`27-L86UI\&MA($ER86YO(%)E<W!U8FQI:V$`27)A:V%S`$%I
M<FEJ80!-96YO('-A;&$`27IO;&EU;W1O<R!4+6%U9')O<P!)>G)A96QI<P!)
M\&1A=NMJ87,`2W5R<WEV87,`271A;&EJ80!*86UA:6MA`%-A=7-I<P!*87!O
M;FEJ80!*87!O;FGP:V$@*$E33RTR,#(R+4I0*0!$_F5R<VES`$IO<F1A;FEJ
M80!,:65P80!":7+^96QI<P!0:6QN86D`3'EG:75O=&D@8V5N=')E`$QY9W5O
M=&D@<&EL;F%I`$QY9VEU;W1I(&MA:7+K:F4`3'EG:75O=&D@9&7P:6[K:F4`
M2V%Z86MS=&%N87,`2?!S875G;W1I(&]R:6=I;F%LX#\`2V5N:6IA`$YE<&%V
M>6MO('!R:7-I:G5N9W1I('!R:64@2V5R8F5R;W,@<V5R=F5R:6\N`$)R86YD
M=6]L:6\@;F%U:F]K86D`4F%K=&\@:_MR:6UA<P!286MT;R!A='-P875D87,`
M4F%K=&\@:6QG:7,`4F%K=&\@=&EP87,`4F%K=&\@<&%N875D;VII;6%S`%)A
M:W1A<R!J874@>7)A('9I9?#X:O@@<F%K=/@@<V5R=F5R>6IE+@!686EK86D`
M2VER:6)A=&ES`$1E;6]K<F%T:6[K($MO<NMJ;W,@3&EA=61I97,@4F5S<'5B
M;&EK80!+;W+K:F]S(%)E<W!U8FQI:V$`2V]RZVII971I\&MA("A%54,M2U(I
M`$MU=F5I=&%S`$MI<F=I>FEJ80!?2?!DZW-T>6UA<P!+86QB80!,86]S;R!$
M96UO:W)A=&ENZR!,:6%U9&EE<R!297-P=6)L:6MA`$%N=')A('!U<^L`4&%S
M:W5T:6YI<R!K971V:7)T:7,`071N875J:6YT83H`4&%S:W5T:6YI<R!P<FES
M:6IU;F=I;6%S.B`E<P!087-K=71I;FES('!R:7-I:G5N9VEM87,Z("5S(&GP
M(&%D<F5S;R`E<P!0<FES:6IU;F?K=&4@<&ER;>`@:V%R=.``3&%T=FEJ80!4
M96ESZP!)\&3K<W1Y;6%S`$IE:6=U(&YE;F]R:71E(&YE;F%U9&]T:2!K<F'P
M=/@L('!A;&EK:71E('1U\.AIX`!,:6)A;F%S`$MA:7+K:F4`2V%I<FEO:FD@
M86YT<F'P=.L`2V%I<FEO<VEO<R!R96EK\&WK<P!,97-O=&%S`$QI8F5R:6IA
M`$QI8FEJ;W,@07)A8O@@16UY<F%T86D`3&EC:'1E;O!T96EN87,`4VUU;&MU
M<R!L:65T=7,`3F5D:61E;&ES(&QI971U<P!.961I9&5L:7,@;&EE='5S(')Y
M=&4`3F5D:61E;&ES(&QI971U<R!V86MA<F4`3F5D:61E;.L@;&G[=&ES`$YE
M9&ED96QI<R!L:65T=7,@<W4@<&5R:_MN:6IA`$YE9&ED96QI<R!S;FEE9V%S
M`$YE9&ED96SK(/!L87!D<FEB80!,:6UE<FEK87,`3G5O<F]D80!.=6]R;V1A
M(.$Z`%!A9&%R>71I(&5L+B!P8?!T;R!A9')E<^`@;G5O<F]D82#A(&QA:?!K
M;R!R8?!Y;6\@<'5S;&%PX0!.=6]R;V1O<P!,:6YU>"!L86EMZW,@_FEN=73K
M<P!2;V1Y=&D@+2!V87)T;W1O:F%S(&=A;&D@;6%T>71I(&MA=&%L;V=O('1U
M<FENX0!2;V1Y=&D@9'5O;65N^"!B87II^"!SX')A\.``4F]D>71I('!A9V%L
M8F]S('1E;6%S`%)O9'ET:2!L96YT96QI^"!SX')A\.``2V]N9F5R96YC:6IO
M<R!A<F-H>79A<P!+;VYF97)E;F-I:F]S('!A9V%L8F$`2V]N9F5R96YC:6IO
M<R!)1`!+;VYF97)E;F-I:F]S('-A=FEN:6YK87,`4F'P>71I(.$@:V]N9F5R
M96YC:6K@`%!R:7-I:G5N9W1I('!R:64@:V]N9F5R96YC:6IO<P!!='-I:G5N
M9W1I(&YU;R!K;VYF97)E;F-I:F]S`%9A<G1O=&]J^"!SX')A\&%S('7^9')A
M=7-T87,N`$QI=&5R873[<F$`3&EE='5V80!+<F%U;F$N+BX`5FEE=&EN:7,@
M;&%I:V%S.B``3&]K86SK(&ER(&QA:6MA<P!6:65T80!0<FES:6IU;F=T:0!!
M='-I:G5N9W1I`%!R:7-I:G5N9VEM;R!D87)B86D`4')I<VEJ=6YG=&D@;F5P
M879Y:V\N($YE=&5I<VEN9V%S($K[<_@@;G5R;V1Y=&%S('9A<G1O=&]J;R!V
M87)D87,@:7(O87(@<VQA<'1A_F]D:7,N`%!R:7-I:G5N9W1I(&YE<&%V>6MO
M+@!);&=A<R!T96MS=&%S`$UE:6SK`$YE<W9A<F)U`$UA_F]S:6]S(&=R86EK
M:?!K;W,@<F%I9.MS`$UA_F]S:6]S(&QO='EN:?!K;W,@<F%I9.MS`$UA_FEE
M:FD@<F]MZVYI\&MI('-K86GH:6%I`$QI=6MS96UB=7)G87,`34T`34]41`!0
M<FEK86)I;G1A;64@35,M5$Y%1B!F86EL92!NZW)A(&1U;VWK;O@N`$U31P!-
M86MA;P!-86ME9&]N:6IA`$UA9&%G87-K87)A<P!-86=I:F$`4&'P=&%S`%!A
M\'1O('9A;&1Y;6%S`%-U:W5R=&D@7VYU;W)O9.`N+BX`36%L879I<P!-86QA
M:7II:F$`36%L9'EV86D`36%L:7,`36%L=&$`2V%T96=O<FEJ^"!SX')A\&\L
M(&MU<FEO;7,@<')I<VMI<FEA;6D@;V)J96MT86DL(&ER('-U(&IO;6ES('-U
M<VEJ=7-I^"!S<&%L=O@@:V5I=&EM87,N`$UA<#(T(/YE;>ML87!I<P!-87!1
M=65S="#^96WK;&%P:7,`2V]V87,`4&%R8?!TZP!08?YY;>MT:2!K86EP('-K
M86ET>71U<R]N97-K86ET>71U<P!08?YY;>MT:2!K:71A:7,@871R:6)U=&%I
M<R`H<'9Z+B!S=F%R8G4O871S86MY=&$I`$UA<O!A;&\@<V%L;W,`36%R=&EN
M:6MA`%-U:G5N9W1I(&QA=6MA:0!-875R:71A;FEJ80!-875R:6-I:G5S`$UA
M:W-I;6%L=7,@:W)E9&ET87,N`$UA:W-I;6%L=7,@_FEN=>AI^"!D86QI^"!K
M:65K:7,@:?!E:6MV;W1A<RX`36%K<RX@=&5M<"X@<&%S:RX@,C0@=F%L.B``
M36%K<RX@=&5M<"X@<&%S:RX@-B!V86PZ(`!-86MS:6UA;'5S(&EL9VES`$=E
M9W7^ZP!-;VIO=.L`365D:6-I;F$`3F%R:6%I`$UE;FEU(')E_FEM87,Z`%-U
M:G5N9W1I(&-E;&5S`-YI;G5TZP!,86GP:V%S('!A=FER=&EN=&%S+"!T8>AI
M874@;F5P871V:7)T:6YT87,@<&%S:7)A\&EU<VEO(&%S;65N<R!S97)T:69I
M:V%T87,N`-YI;G5TZR!N96GP<VGX<W1A+@#>:6YU=.MS('1I<&%S`$]R;R!S
M86QY9V]S`$]R;R!SX&QY9_@@8FQO:V\@;NMR82X`3W)O('/@;'EG^"!B;&]K
M;R!NZW)A+B!!9&UI;FES=')A=&]R:75I(&GP<VGX<W1A<R!D971A;'5S(&%P
M<F'P>6UA<RX`365T;V1A<P!-871A:0!-96MS:6MA`$UI:W)O;F5Z:6IO<R!&
M961E<F%C:6[K<R!686QS=&EJ;W,`5FED=7)Y:F4`34E-12!T:7!A<P!-:6XN
M('1E;7`N('!A<VLN(#(T('9A;#H@`$UI;BX@=&5M<"X@<&%S:RX@-B!H;W5R
M<SH@`$%T<W!I;F1Y<P!+:71O<P!.97)A<W1A<R!014%2($A45%!?4F5Q=65S
M="!P86ME=&%S+@!.=7-T871Y;?@@;NMR82X@2F5I9W4@;F]R:71E(&YA=61O
M=&D@\.$@;6]D=6SA+"!T=7)I=&4@:N$@<W5K;VYF:6?[<G5O=&DN`$[K<F$@
M_FEN=73K<R!)1"X`3F5R87-T87,@<F5I:V%L:6YG87,@4$5!4B!-86EL('!A
M:V5T87,N`$[K<F$@<V5S:6IO<R!)1"X`4&ER;2X`36]B:6QU<R!P8?!T87,`
M5FED=71I;FES`%)E9&%G879I;6\@9&%T80!+96ES=&D@55),`$UO9'5L:7,`
M36]L9&]V;W,@4F5S<'5B;&EK80!-;VYA:V%S`$UO;F=O;&EJ80!-ZVYE<VEA
M:2!I<B!M971A:0!+87,@;>MN97/A`$UO;G-E<F%T87,`3>MN=6QI;R!F87KK
M<P!-87)O:V%S`$1A=6=I875S:6$@9VEE9')A`$1A=6=I875S:6$@87!S:6YA
M=6OF`$1A=6=I875S:6$@<V%U;.MT80!097)K96QT:2#^96UI874`4&5R:V5L
M=&D@:V%I<FEA=0!097)K96QT:2!D9?!I;FEA=0!097)K96QT:2!A=6OPZ&EA
M=0!097)KZVQI;6%S(/YE;7EN`%!E<FOK;&EM87,@875K\'1Y;@!-;WIA;6)I
M:V%S`$ME;&5T;R!L>6=I^"!I\'-I<VML96ED_FEA;G1I<R!SX')A\&%S`$ME
M;&5T87,@<&%S:7)I;FMI;?@`36%N;R!SX'-K86ET80!-86YO('!O<G1A;&%S
M`$UA;F\@<&]R=&%L;R!I\&3K<W1Y;6%S`$UA:6YM87)A<P!.12P@3D53551)
M3DM5`%9A<F1A<P!.86UI8FEJ80!.875R87,`3F5P86QA<P!.>61E<FQA;F1A
M:0!.>61E<FQA;F3X($%N=&EL86D`3F5T<V-P87!E(&)A>FEN:7,@55),`$YE
M='-C<&%E('-E<FEF:6MA=&\@873P875K:6UO(%523`!.971S8W!A92!S97)T
M:69I:V%T;R!T96ES:?@@55),`$YE='-C87!E(&%T;F%U:FEN;VUO(%523`!.
M971S8V%P92!A=/!A=6MI;6\@55),`$YE='-C87!E(%-33"!S97)V97)I;R!V
M87)D87,`3F5T<V-A<&4@<V5R=&EF:6MA=&\@87!R8?!Y;6%S`$YE='-C87!E
M('-E<G1I9FEK871O('1I<&%S`%1I;FML87,`3FEE:V%D80!.875J;VII($MA
M;&5D;VYI:F$`3F%U:F$@:V%T96=O<FEJ80!.875J87,@;>MN=6QI<P!.875J
M87,@=F%R=&]T;VIO('9A<F1A<R`H;F5B^W1I;F%S*0!.875J;VII(%IE;&%N
M9&EJ80!.875J86UE(&QA;F=E("A?8FQA;FLI`$YA=6II96YO<P!.875J:65N
M^"!G<G5PZW,`4V5K86YT:7,`4V5K86YT>7,@;G5S=&%T>6UA:0!.:6MA<F%G
M=F$`3FEG97)I<P!.:6=E<FEJ80!.86MT:7,`3FEU:NL`3F4`3F5U_G1E;FMA
M(&1U;VUE;O@@<VMI<G1U;?@@<&%R;V1Y;75I+@!.96YU<F]D>71A('-T<F%T
M96=I:F$@25-/(')A\'EM=6DN`$[K<F$@<W5DZW1I;FEO(/!A8FQO;F\N`$YU
M<F]D>71O:F4@<&]Z:6-I:F]J92!B;&]K;R!NZW)A`$YEX79E9.MT92!K86QE
M;F1O<FEA=7,@=F%R9&\@34-!3"!A=71E;G1I9FEK86-I:F]J92X`4VMI<G1U
M;?@@;NMR82X`T&EO<R!T96ESZW,@;F5G86QI('1U<NMT:2!P;W1E:7-I^"X`
M3NMR82!I;F9O<FUA8VEJ;W,@87!I92`E<R!K;VYF:6?[<F%C:6K@+@!.ZW)A
M(&EN9F]R;6%C:6IO<R!A<&EE($944"!61E,@:V]N9FEG^W)A8VEJX"X`3NMR
M82!I;F9O<FUA8VEJ;W,@87!I92!344P@5D93(&MO;F9I9_MR86-I:N`N`$[K
M<F$@:6YF;W)M86-I:F]S(&%P:64@4U%,+49I;&4@5D93(&MO;F9I9_MR86-I
M:N`N`$MR961I=&%S(&GP96EK=F]T87,N`$YEX79E<W1A<R!G87;K:F%S+@!&
M86EL87,@;F5N=7-I^'-T87,`3F5N=7-T871Y=&$@=FEE=&]VZRX`3F7A<F'P
MZW1E(/YI;G5TZW,N`$YEX7)A\.MT92!V87)D;RX`3F7A<F'PZW1E(&YU;65R
M:6\N`$YE<F]D>71I(.'^96ED_FEA;NAI^"!F<F%Z:?@`3F7A=F5DZW1E('-L
M87!T8?YO9/YI;R!(5%10(&%U=&5N=&EF:6MA8VEJ86DN`$YEX79E9.MT92!S
M;&%P=&'^;V3^:6\@24U!4"!A=71E;G1I9FEK86-I:F%I+@!.9>%V963K=&4@
M<VQA<'1A_F]D_FEO($ME<F)E<F]S(&%U=&5N=&EF:6MA8VEJ86DN`$YEX79E
M9.MT92!S;&%P=&'^;V3^:6\@3&]G:6X@875T96YT:69I:V%C:6IA:2X`3F7A
M=F5DZW1E('-L87!T8?YO9/YI;R!005-35T0@875T96YT:69I:V%C:6IA:2X`
M3F7A=F5DZW1E('-L87!T8?YO9/YI;R!334(@875T96YT:69I:V%C:6IA:2X`
M3F7A=F5S=&%S(&ME;&EA<R!I:VD@3W!E;E-33"!P86=R:6YD:6YI^"!F86EL
M^"X@3W!E;E-33"!R96EK86QI;F=A(&1A<F)U:2!S=2!02T-3(#$R(&1U;VUE
M;FEM:7,N`$YE<&%T=FER=&EN=/@@<F5G:7-T<F%C:6KX(&[K<F$N`$YE;F%U
M9&]T:2!S:VER='5K^`!.ZR!V:65N;VIE('!U<^MJ90!3<&%R=&EN:6UU:2!N
MZW)A(&QA:6MI;F]J;R!K871A;&]G;RX`5F%R=&]T;VIO('9A<F1A<R!I<B]A
M<F)A('-L87!T8?YO9&ES(&YE;G5S:?AS=&%S+@!496ES:6YG^"!834P@9'5O
M;65N^"!NZW)A`$[K<F$@<F5I:_!M:?@`2V]N9FEG^W)A8VEN:6%M92!F86EL
M92!NZW)A('9E<G-I:F]S+B!097)G96YE<G5O:VET92!N=7-T871Y;75S+@!+
M;VYF:6?[<F%C:6YI86UE(&9A:6QE(&[K<F$@=F5R<VEJ;W,N(%!E<F=E;F5R
M=6]K:71E(&YU<W1A='EM=7,N`$YE;G5R;V1Y=&$`3NMR80#0:6%U<NMS("A)
M4T\M.#@U.2TQ,"D`3F]R9F]L:V\@<V%L;W,`T&EA=7)I;NL@:&5M:7-F97)A
M`-!I875R:6[K<R!-87)I:F%N^"!S86QO<P!.;W)V96=I:F$`3F4@<&\@=&\`
M3F4@<')I9?`@=&%I`$YE(&MA=&%L;V=A<P!.97)E86QI>G5O=&$N`$YE;G5R
M;V1Y=&$`3F5P86QA:6MO;6%S+@!5_G)A\&%I`$[K<F$@:^`@<&5R_FG[<NMT
M:2P@96EK:71E(&%T9V%L+@!,87!K<FET:7,`3G5M97)I<P!3:6UB;VQI^"!S
M:V%IZ&EU<P!3='5L<&5L:?@@<VMA:>AI=7,`16EL=>AI^"!S:V%IZ&EU<P!.
M9>%V97-T:2!D:7-T<FEB=6-I:F]S('/@<F'P;R!A=&YA=6II;FEM;R!S:V%I
MZ&EA:2X`3TL`3V)J96MT87,`3V)J96MT;R!S879I;FEN:V%S`$'P='5N=&%I
M;FES`%-P86QI<P#>:6%U<G5M;R!F:6QT<F%S`$]F:7-A<P!/;6%N87,`2V%T
M86QO9_@@9&%L:6II;>!S:2!P86QA:6MO('1I:R!)34%0('-E<G9E<FEA:2X`
M5&EK(.'^96ED_FEA;NAI;W,@9G)A>NMS`$QE:63^:6%M87,@=&EK('9I96YA
M<R!E;"X@<&'P=&\@861R97-A<RX`16QE;65N=&\@<V%V:6YI;FMO('1E:7-E
M<R!G86QI(&ME:7-T:2!T:6L@:F\@<V%V:6YI;FMA<R!A<F)A('-I<W1E;6]S
M(&%D;6EN:7-T<F%T;W)I=7,`071I9&%R>71I(&YA=6IA;64@;&%N9V4`071I
M9&%R>71I(/!IX"!N=6]R;V3@(&YA=6IA;64@;&%N9V4`3W!R86-I;NMS('-I
M<W1E;6]S`$YU<W1A='EM86D`)7,@;G5S=&%T>6UA:0!3=7+[\&EU;W1A<R!S
MX')A\&%S`$]R9V%N:7IA8VEJ80!0861A;&EN>7,`4VES=&5M:6YI;6%S`$]R
M:6=I;F%L=7,@87!L:6MA8VEJ;W,@\&%B;&]N87,`3W)I9VEN86SX<R#P86)L
M;VYA:2`E<SH`2VET80!+:71A(&EN9F]R;6%C:6IA`%-A=FEN:6YI:V\@=&5I
M<^MS`$[K<F$@4$%-(&%U=&5N=&EF:6MA8VEJ;W,@;65C:&%N:7IM;RX`4$=0
M('-K86ET;65N:6YI<R!P87)A\&%S`%!'4"!U_FMO9'5O=&$@:6YF;W)M86-I
M:F$`4$=0('9I9?!A<VES(')A:W1A<P!01U`@<&%S:7)A\'ET:2]U_FMO9'5O
M=&D@9'5O;65N>7,`4$A0(&MO9&%S`%!(4"!#3$D`4$T@;&5N9W9A<R!L:65T
M=7,`4$T@;&G[=&ES`%!-(%0M875D<F$`4%](4"!#3$D`5&%R<&%I(&-E;.MS
M90!086MI<W1A;F%S`%!A;&%U`%7^:6UT;VII(%!A;&5S=&EN;W,@=&5R:71O
M<FEJ80!086YA;6$`4&%P=6$@3F%U:F]J:2!'=FENZVIA`%!A<F%G=F%J=7,`
M1&%L:6YA:2!D96)E<W5O=&$`4VQA<'1A_F]D:7,`4VQA<'1A_F]D:7,@;F5T
M96ES:6YG87,`4D%$2553(&%U=&5N=&EF:6MA8VEJ86D@<F5I:VEA('-L87!T
M8?YO9/YI;RX`4VQA<'1A_F]D:7,@<W4@<&%T=FER=&EN:6UU`%-L87!T8?YO
M9&ES.@!3;&%P=&'^;V1I<SH@`%-L87!T8?YO9/YI86D@='5R:2!S=71A<'1I
M+@#!:V5L=&D`P6ME;'1I(&GP(&QA:6MI;F]S:6]S('-A=6=Y:VQO<R`H8VQI
M<&)O87)D*0!+96QI87,`3F5P871V:7)T:6YT;W,@<F5G:7-T<F%C:6IO<SH`
MWFUO;NMS`%!R;V-E;G1A:0!!=&QI:W1I('!R;V9I;&%K=&EN:75S('9E:6MS
M;75S`$%R(&%T;&EK=&D@<')O9FEL86MT:6YI=7,@=F5I:W-M=7,@<')I<VEJ
M=6YG:6UO(&UE='4_`%1E:7/K<P!496ES:?@@861M:6YI<W1R879I;6%S`$%S
M;65N:6[K(&EN9F]R;6%C:6IA`%!E<G4`1WEV^VYA:0!&:6QI<&EN86D`5&5L
M969O;F%S`$YU;W1R875K;W,`4&ET:W)A;F%S`%!I:W-E;&EA:0!"86YA;'EB
MZW,`2?!S:7)I;FMI=&4@:W5R:>`@;F]R<R!C96SF`%!A='9I<G1I;FMI=&4L
M(&%R('1I:W)A:2!N;W)I=&4@:?!T<FEN=&D@\.$@96QE;65N=.`Z`%!A='9I
M<G1I;FMI=&4L(&%R('1I:W)A:2!N;W)I=&4@:?!T<FEN=&D@\&EO(&5L96UE
M;G1O(&YU;W)O9.`N`,%V97-K:71E(&WK;F5SX2!I<B!M971U<RX`P79E<VMI
M=&4@;F%U:F]S(&MA=&5G;W)I:F]S('!A=F%D:6YI;>`Z`,%V97-K:71E('1E
M:7-I;F?@($E0(&%D<F5SX"X`P79E<VMI=&4@=&5I<VEN9^`@9&%TX"P@<&%T
M:6MR:6YK:71E(&1I96[X('-K86GH:?@@;>MN97-Y:F4N`,%V97-K:71E('1E
M:7-I;F?@(&QA:6O@+@!!<')A\'EK:71E('!R;V)L96W@+@!.=7)O9'EK:71E
M('-A=F\@=F%R=&]T;VIO('9A<F3@(&)E:2!S;&%P=&'^;V3A`,%V97-K:71E
M(&YA=6K@(&MA=&5G;W)I:F]S('!A=F%D:6YI;>`Z`$QE;FMI:F$`4&]L:71I
M:V%I`$)A;'-A=FEM86D`4&]R='5G86QI:F$`4&%V96EK<VSK;&EO('!O>FEC
M:6IA`$QE;G1E;.MS('!O>FEC:6IA`$GP<V%U9V]T:2#P:6%M92!K871A;&]G
M92`H;F5G86QI;VIA($E-05`I`$MR:71U;&EA:2!P87-K+B`E<R!V86QA;F3@
M*&%S*3H@`%!R969S7VQD87`Z(&YE<F%S=&%S(')E:6MA;&EN9V%S($Q$05`@
M;6]D=6QI<RX`4')E9G-?<V5S<VEO;CH@;F5R87-T87,@<F5I:V%L:6YG87,@
M<V5S:6KX(&UO9'5L:7,N`%-LZV=I<P!3;.MG:7,@:OMR;W,@;'EG>6IE.B``
M4VSK9VES.B``4&5R_FG[<F$`4&5R_FG[<NMT:2!P879E:6MS;.MLX2!N875J
M86UE(&QA;F=E`$%N:W-T97-N:2!N=7-T871Y;6%I`$%T<W!A=7-D:6YT:2!D
M;VMU;65N=.``4VQA<'1A<VES(')A:W1A<P!0<F]B;&5M80!0<F]B;&5M;W,@
M87!R8?!Y;6%S`%!R;VIE:W1A:0!0<F'P>6UA<R!T96MS='5I`%9I9?!A<VES
M(')A:W1A<P!6:67P;VIO(')A:W1O(&%L9V]R:71M87,`5FEE\&]J;R]S;&%P
M=&]J;R!R86MT^"!P;W)A(&YE<W5G96YE<G5O=&$N`%!U97)T;R!2:6MA<P!+
M871A<F%S`%-A:VEN>7,`4E-!('9I9?!A<VES(')A:W1A<R`H)60@8FET86DI
M`"=2861I;R<@<&%S:7)I;FMI;6%S`$QI971U<P!,:65T=7,@<GET90!,:65T
M=7,@=F%K87)E`$QI^W1I<P!!='-I=&EK=&ENZR!F<F%ZZP!386YT>6MI<P!3
M:V%I='ET:0!097)S:V%I='ET:2!L86GP:V%I`%1I:W)A:2!I\'1R:6YT:2`E
M<S\@1W)A_FEN=&D@871G86P@;F5B96=A;.MS:71E+@!4:6MR86D@:?!T<FEN
M=&D@=F%R=&]T;VIO("5S(&1U;VUE;FES/R!'<F'^:6YT:2!A=&=A;"!N96)E
M9V%LZW-I=&4N`%!A:V%R=&]T:2!A;FMS=&5S;N$@=F5I:W-MX`!!=&YA=6II
M;G1I(&MA:7)I;VIO(&UE;FEU(&5L96UE;G1U<SH`071N875J:6YT:2!P;W)T
M86QO('9A:7IDX#H`4F5G97@`4^!R>?!I^"!N87+P>6MLZP!087-T86)O<P!.
M=71O;.8@<V5R=F5R:6%I`$YU=&]LYG,@55),("AH='1P.B\O=W=W+G!A=GEZ
M9'ES+F-O;2]H;W)D92DZ`$GP=')I;G1I`%!A\&%L:6YT:2!B;&]KX`!086YA
M:6MI;G1I('-T=6QP96SA`%!A;F%I:VEN=&D@9F]R;6%T879I;>``2?!T<FEN
M=&D@<&]RX`!)\'1R:6YT:2!A=&YA=6II;FEM;R!S:W)I<'3@(&GP('-E<G9E
M<FEO(&QA:6MI;F]J;R!K871A;&]G;RX`4&'P86QI;G1I`%!A\&%L:6YT:2#P
MX2!E;&5M96YTX"!I\"!D;VMU;65N=&\`2?!T<FEN=&D@=F%R=&]T;VK@`%9A
M<G1O=&]J;R!T<GEN:6UA<SH@)7,`3F5G86QI=2!A='-A:WET:2#A('7^:VQA
M=7/@+B!+;&%I9&]S(&MO9&%S.B``2?`@;F%U:F\`4&%K96ES=&D@<VQA<'1A
M_F]DX0!3;&%P=&'^;V3^:6\@:V5I=&EM87,`4F5Z=6QT871A:0!'<N'^=&D@
MX2!N=7-T871Y;75S`%)E:OMN:6IA`$%T<W1A='ET:2!K;VYF:6?[<F%C:6K@
M`$A434P@<F5D86MT;W)I875S(&YU<W1A='EM86D`3>%S;.MS`$1E\&ENZVIE
M`$1E\&EN:6]J:2!A;G1R8?!TZP!$9?!I;FEO<VEO<R!R96EK\&WK<P!?16EL
M=73K<R!N=7-T871Y;6%I+BXN`%)O;.L`4G5M=6YI:F$`4&%S=6MT:2`Q.#``
M4&%S=6MT:2!K86ERZVX`4&%S=6MT:2!D9?!I;NMN`$5I;'5TZW,@;G5S=&%T
M>6UA:0!%:6QU=.MS(&YU<W1A='EM86D`16EL=73K<SH`4VMI<G1U:V%I`%-K
M:7)T=6MA:2!T87)P('9I<_@@96EL=>AI^"!I<B!S='5L<&5L:?@`4VMI<G1U
M:V%I('1I:R!T87)P('-T=6QP96QI^`!3:VER='5K86D@=&EK('1A<G`@96EL
M=>AI^`!6>6MD>71I`%)U<VEJ;W,@1F5D97)A8VEJ80!2=6%N9&$`4R]-24U%
M('!A<F'P87,`4R]-24U%('7^:V]D=6]T87,@;&%I\&MA<P!.ZW)A(%-!4TP@
M875T96YT:69I:V%C:6IO<R!M96-H86YI>FUO+@!335,@_FEN=73K<P!344P@
M0TQ)`%-32`!005992T\`4U]13"!#3$D`T&7P="X`T'9E;G1O:FD@2&5L96YA
M`%-A:6YT($MI='-A<R!I<B!.979I<V%S`%-A:6YT($QI=6-I:F$`T'9E;G1A
M<VES(%!E=')A<R!I<B!-:6=E;&]N87,`4V%I;G0@5FEN8V5N=&%S(&ER($=R
M96YA9&EN86D`5&%M92!P8>AI86UE(&QA;F=E("A?<V5L9BD`4V%M;V$`4V%N
M($UA<FEN87,`4V%O(%1O;64@:7(@4')I;F-I<.L`4&%L>61O=F%S`%-A=61O
M($%R86)I:F$`2?!S875G;W1I`$GP<V%U9V]T:2`E<P!)\'-A=6=O=&D@;G5S
M=&%T>6UU<P!)\'-A=6=O=&D@<W5G96YE<G5O='5S(&YU<W1A='EM=7,@:V%I
M<"!02%`@<VMR:7!TX"!J^W/X('-E<G9E<FEO(&QA:6MI;F%J86UE(&MA=&%L
M;V=E+@`E<R!N=7-T871Y;6%I(&GP<V%U9V]T:2X`36]K<VQA<P!)9?!K;W1I
M`%!A:67P:V$`4&%S:7)I;FMI=&4@9F%I;'5S`%!A<VER:6YK:71E(&1A=.``
M4&%S:7)I;FMI=&4@9W)U<.8`4&%S:7)I;FMI=&4@;F%U:N`@<V%V:6YI;FO@
M`%!A<VER:6YK:71E('-E<G9E<N$`4&%S:7)I;FMI=&4@=F%R=&]T;VK@`%!A
M<VER:6YK:71E('9I<W5S(&1A=&]S(&MO;7!O;F5N='5S+@!087-I<FEN:VET
M92!O8FIE:W3@`$GP(/YE;6EA=2!E<V%NZ&GX('/@<F'P^"!P87-I<FEN:VET
M92!R96EK:6%M=7,@<VEM8F]L:75S+B!6ZVQI874@9V%L:71E(&IU;W,@;G5K
M;W!I:G5O=&D@X2!L86GP:^`N`%!A<VER:6YK:71E(&1A=&]S('-K:7)T=6O@
M.@!087-I<FEN:VET92!D871O<R!F;W)M873@.@!087-I<FEN:VET92!A<')A
M\.`@:W5RX2!N;W)I=&4@<F5D86=U;W1I.@!087-I<FEN:VET92!L86EK;R!S
M:VER='5KX#H`4&%S:7)I;FMI=&4@;&%I:V\@9F]R;6%TX#H`4&%S:7)I;FMI
M=&4@9'4@871I=&EN:V%NZ&EU<R!L875K=7,N`%!A<VER:6YK:71E('-P86QV
M^"!D97)I;N$N`%!A<VER:6YK:71E(&YO<FEMX"!K86QBX#H`4VGX<W1I('!R
M;V)L96UO<R!P<F%N9?!I;>``4VGX<W1I(%--4P!396YE9V%L87,`4V5N<V]R
M:75S.B``4G5G<^MJ:7,`4V5R8FEJ82!I<B!-;VYT96YE9W)A<P!397)I:F]S
M(&YU;65R:7,`4V5S:6IO<R!)1"!P87-I8F%I9^LN`%)I;FMI;GES`$YU<W1A
M='EM86D@;&5I9/YI86YT>7,@2G5M<R!P87-I:V5I<W1I('-L87!T8?YO9.$L
M(&IE:6=U(&KA(&MA9&$@;F]R<R!P86UI<O!I=&4N`$YU=&]L=7-I^"!S97)V
M97)I^"P@:W5R:75O<R!N;W)I=&4@;6%T>71I(&GP('!O<G1A;&\L(&YU<W1A
M='EM86DN`$MA;&)O<RP@;&%I:V\@>F]N;W,@:7(@9&%T;W,@;G5S=&%T>6UA
M:2X`4'5S;&%P:6\@<W!A;';X+"!A='-I;F%U:FEN:6UO(&1A_FYU;6\@:7(@
M:VET^"!V86EZ9&%V:6UO('!A<F%M971R^"!N=7-T871Y;6%I+@!287-T87,@
M871N875J:6YI;6\@<VMR:7!T87,`4W4@\&EU;R!P87)A;65T<G4@9V%L:6UO
M<R!K96QI;W,@=FEE=&]VZW,Z(`!396GP96QA:0!087)D=6]T=7;K`%1R=6UP
M87,@87!R8?!Y;6%S`$%R(&YA=61O=&D@:VQA=FEA=/MR;W,@;7EG='5K=7,@
M=F%L9'EM=6D_`%)O9'ET:0!087)O9'ET:2!S:VER='5M=7,@=&%R<"!I\'-A
M=6=O=&\@:7(@:^`@=&EK('-U9V5N97)U;W1O(&MO;F9I9_MR86-I;FEO(&9A
M:6QO+@!2;V1Y=&D@<&%S:W5T:6YI;R!P<FES:6IU;F=I;6\@;&%I:^`_`%)O
M9'ET:2!G86QI;7EBYB!P86QI:W1I(&]R:6=I;F%LX`!2;V1Y=&D@<&%R:7-I
M;FMI;>``4F]D>71I(&QE;G1E;.MS(&]P97)A8VEJ^"!M96YI=3\`4F]D>71I
M("5S(&UE;FEU(&MA:7+K:F4_`%)O9'ET:2!C96SK<R!N=7-T871Y;?@@;&%N
M9^``4F]D>71I(&QE;G1E;.MS(&YU<W1A='EM^"!L86YGX`!2;V1Y=&D@96EL
M=73K<R!N=7-T871Y;?@@;&%N9^``4F]D>71I('!A=F5I:W-LZVQI;R!N=7-T
M871Y;?@@;&%N9^``4F]D>71I(&9A:6SX(.%KZVQI;>``3&G[=&ES`$QI^W1I
M<R!R>71E`$QI^W1I<R!V86MA<F4`4W5M8?YI;G1I`%-U;6'^:6YT:2!A<F)A
M('!A<W1U;71I(&MA:6UY;FEN:75S(&)L;VMU<P!3:65R82!,96]NZP!296=I
M<W1R86-I:F$`4&%R8?!A<P!087)A\&\@86QG;W)I=&UA<P!3:6YG87#[<F%S
M`$1Y9&ES`%!R86QE:7-T:2!P<F]F:6QA:W1I:^``4VQO=F%K:6IA`%-L;W;K
M;FEJ80!0^V=A`%-N:65G;R!G>6QI<SH@`%-N:65G;R!K:65K:7,@=F%N9&5N
M:74Z(`!3;VQO;6]N;R!S86QO<P!3;VUA;&EA`$1A:6YO<R!I<B!%:6SK<F'P
MZ&EA:0!2^_!I879I;6\@='9A<FMO<R!P87-I<FEN:VEM87,`4VEU;G3K:F\@
M861R97-A<P!0:65T^"!!9G)I:V$`4&EE=/@@175R;W!O<R`H25-/+3@X-3DM
M,RD`4&EE=/@@1/YO<F3^:6IO<R!I<B!0:65T^"!386YD=FGH;R!S86QO<P!0
M:65T:6[K(&AE;6ES9F5R80!487)P87,@=&%R<"!C96QI^`!487)P87,@=&%R
M<"!C96SK<R!T=7)I;FEO(&ER(&MR8?!T:6[K<P!487)P87,`5&%R<&%I('1A
M<G`@8V5L:?@`5&%R<&%I`$ES<&%N:6IA`%-P86UA<P!3<&5C:69I;FGX('-I
M;6)O;&GX(.%T97)P:6UA<P!097)S:V5L=&D@8V5LY@!097)S:V5L=&D@<W1U
M;'!E;.$`4&5R<VME;'1I(&5I;'5TY@!3<&]R=&%S`-!R:2!,86YK80!3=&%N
M9&%R=&%S`%-T87(@5')E:R=A<P!0<F%D:6YI86D@;65T86D`4F%J;VYA<R!A
M<F)A('!R;W9I;F-I:F$`0OMS96YA`%-A=6=O:FEM;R!F;W)M871A<P!'871V
MZW,@861R97-A<P!5_F)R875K=&D`WF]D_FGX('/@<F'P87,`3G5I;71I(&1O
M;65NX"!N=6\@861R97-O`%-T:6QI=7,@6T-34UT`4V5K;2X`5&5M80#!=F5S
M=&D`26YD96MS87,`4^MK;6EN9V$`2V]N9FEG^W)A8VEJ82!A='-T871Y=&$@
M<^MK;6EN9V%I+B!097)K<F%U:VET92!P=7-L87#A+"!K860@<&%M871Y='5M
MZW1E('!A:V5I='5M=7,N`$%T<V%R9VENZR!K;VYF:6?[<F%C:6IO<R!K;W!I
M:F$@<^MK;6EN9V%I(&GP<V%U9V]T82X`)R5S)R!SZVMM:6YG86D@=?YR8?!Y
M=&%S+@!3=61A;F%S`%1U<FEN>7,`4V%U;.MT96MI<P!3875LZVQY9VES`%-A
M=6SK=&$`4V%U;.MT96MI<P!3875LZW1E:VES+U-A=6SK;'ED:7,`4V%U;.MT
M96MI<SH@`%-A=6SK;'EG:7,`4V%U;.ML>6=I<SH@`$QA:7!S;FES`$%P=&%R
M;F%V:6UA<P!3=7)I;F%M87,`4&%V87)DZP!3=F%L8F%R9&%S(&ER($3^86YM
M86EN87,`4W9A>FEL86YD87,`T'9E9&EJ80#0=F5I8V%R:6IA`%-I;G1A:W/K
M<R!K;&%I9&$@<&%I9?!K;W,@:W)I=&5R:6IU:F4`4VER:6IO<R!!<F%B^"!2
M97-P=6)L:6MA`%0M875D<F$`5"UA=61R;W,`5%-6(&9A:6QA<P!,96YT96SK
M`$QE;G1E;.MS(&YU<W1A='EM86D`3&5N=&5LZW,@;G5S=&%T>6UA:0!486EV
M86YA<P!486EV86YA<RP@2VEN:6IO<R!P<F]V:6YC:6IA`%1A9/YI:VES=&%N
M87,`2G5N9W1I;NL@5&%N>F%N:6IO<R!297-P=6)L:6MA`%1A:6MI;GES.@!$
M87)B86D`5&5L969O;F\@;G5M97)I<P!496UP+B!P87-K+B!V86QA;F3@.B``
M5&5M<&5R873[<F$`5&5M<&5R873[<F$Z(`#086)L;V[X(&%D;6EN:7-T<F%V
M:6UA<P!496MS=&%S`%1I:R!T96MS=&%S`$QY9VEU;W1I('1E:W-TX`!496MS
M=&\@=FER\'5J90!+971V+@!486EL86YD:65T:?!K82`H5$E3+38R,"D`5&%I
M;&%N9&%S`$'H:?L@:V%D(&YA=61O:F%TZW,@<VES=&5M82X`3NMR82!&5%`@
M;6]D=6QI;RX`2&]R9&4O2V]L86(@:6YT96=R86-I:F]S('9A<FEK;&EU:V%S
M(&YE<&%L86EK;R`B)7,B`$YE<&%V>6MO('7^:W)A=71I($UA:6YT96YA;F-E
M.CH@:VQA<^MS`$YU<W1A='EM^"!L86YG87,@=?YD87)Y=&%S+B!)\&5I;G4N
M`$IE:6=U(&YO<FET92!N875D;W1I(&YU<W1A='EM=7,L('!A<')A\'EK:71E
M(&MA9"!A9&UI;FES=')A=&]R:75S('-U:V]N9FEG^W)U;W3X('!A<W1O=FG@
M(&1U;VUE;O@@8F%ZYB!N=7-T871Y;6%M<R!S875G;W1I+@!4:6L@87!A=&EN
MZVIE('!U<^MJ90!.9>%R8?#K=&4@8V]N=&%K=&\@240@;G5M97)I;R!A<F)A
M(&II<R!N97)A<W1A<R!D=6]M96[X(&)A>NMJ92X`2V]N=&%K=&%S('/K:VUI
M;F=A:2#A=')A=6MT87,@X2!*^W/X(&%D<F5S^"!K;GEG96SF+@!.;W+K9&%M
M:2!P871I:W)I;G1I(&QA:?!KX"!P<FEV86QO=&4@='5RZW1I(&%T<VMI<N`@
M4$=0('!A<F'P;R!B;&]KX"X`3F7A<F'PZW1E(&1I<W1R:6)U8VEJ;W,@<^!R
M8?!O($E$(&%R8F$@:FES(&YE<F%S=&%S(&1U;VUE;O@@8F%ZZVIE+@!.9>%R
M8?#K=&4@9&ES=')I8G5C:6IO<R!SX')A\&\N`%!'4"!U_FMO9&%V:6UO(&=A
M;&EM>6+K(')E:6MA;&%U:F$@<V%U9V%U<R!P<FES:6IU;F=I;6\N($)A;F1Y
M:VET92!R8?!Y=&D@:'1T<',Z+R\@861R97-O('!R863^:6]J92X`1F%I;&%S
M("5S('!R:79A;&\@='5RZW1I("5S('!A<F%M971RX"X`1F%I;&%S("5S('!R
M:79A;&\@='5RZW1I(&MA:2!K=7)I=6]S("5S('!A<F%M971R=7,N`$9A:6QA
M<R!N96=A;&D@8OMT:2!N=6MO<&EJ=6]T87,@86YT('-A=N9S+@!&86EL92!N
MZW)A(&1U;VUE;O@N`%)&0S@X,B!L86GP:V\@86YT<F'P=.MS+@!*96EG=2!D
M:7)B871E($EN=&5R;F5T($5X<&QO<F5R(&YA<O!Y:VQE+"!P:6QN865K<F%N
M:7,@<F5D86MT;W)I875S(')E_FEM87,@9V%L:2!S=6ME;'1I('!R;V)L96WX
M+"!DZVP@\&EO<R!N87+P>6MLZW,@:VQA:63X+B!'86QI=&4@;F5M871Y=&D@
M:V%I(&MU<FGX(')E9&%K=&]R:6%U<R!E;&5M96YT^"X@2F5I9W4@;F%U9&]J
M871E(%=I;F1O=W,@.7@@3U,@9W)E:>AI875S:6%I(&K[<_@@:V]M<&EU=&5R
M:7,@<&%P<F'PZ&EA=7-I86D@;G5L=?`@<&%S:V5L8F1A;6%S(&%P:64@<&%G
M<FEN9&ENYB!K;&%I9.`N7&Y<;DK[<R!B=79O=&4@<&5R<W#K=&%S+B!*96EG
M=2!V:7-T:65K(&YO<FET92!I\&)A;F1Y=&D@<&EL;F%E:W)A;N$@<F7^:6W@
M('-P875S:VET92!/2RX`07!R8?!A<R`B)7,B(&GP=')I;G1A<RX`5&EK(&MA
M:7+K:F4@<'5SZVIE`$-R>7!T7W!Q<#HZ(&ML87-E:2!R96EK:6$@;G5R;V1Y
M=&D@:W5R('ER82!';G501R!F86EL86DN`$QA:?!K87,@:?!S:?AS=&%S("5S
M(&%D<F5S871U:2`E<R!T96UA("(E<R(@8G5V;R!P87)O9'ET87,N"E1AZ&EA
M=2!T86D@;F5G87)A;G1U;VIA(&MA9"!L86GP:V%S(&)U=F\@<&5R<VMA:71Y
M=&%S(&%R8F$@<W5P<F%S=&%S+@!0879A9&EN:6UA<R!K=7+A(&YA=61O<VET
M92!N=6]R;V1O:F4@X2!L86GP:V\@<F'P>6UO('!U<VQA<.$`2&]R9&5?0W)Y
M<'1?<VUI;64Z.B!K;&%S96D@<F5I:V%L:6YG87,@3W!E;E-33"!M;V1U;&ES
M+@!.96=A;&EU(&GP<V%U9V]T:2!N=7-T871Y;6\@(B5S(BP@;F5S(&1U;VUE
M;O@@9'ED:7,@=FER\'EJ82!L96ES=&ENX"!R:6+@`%!R;V=R86UA+"!S:VER
M=&$@<&5R_FG[<NMT:2#PX2!D=6]M96[X('1I<.`@*"5S*2P@;F5R87-T82!S
M:7-T96UO:F4N`%1I:R!K86ERZVIE(&ER(&1E\&ENZVIE('!U<^MS90!4:6L@
M9&7P:6[K:F4@<'5SZVIE`%-E<G9E<FES("(E<R(@:?!T<FEN=&%S+@!397)V
M97)I<R`B)7,B(&GP<V%U9V]T87,N`"5S(')E9VES=')A8VEJ;W,@<')A\'EM
M87,@:?!T<FEN=&%S+@!.=7)O9'ET82!E:6QU=.L@;F5E9WII<W1U;VIA+@!4
M:6L@=FER\'5T:6[K:F4@:7(@87!A=&ENZVIE('!U<^MS90!4:6L@87!A=&EN
MZVIE('!U<^MJ90!.=7-I^'-T:2!D=6]M96YY<R!P<F%R87-T:2X`3F5G86QI
M=2!I\'-A=6=O=&D@;G5S:?AS=&\@9F%I;&\N`%=E871H97(N8V]M(&)L;VMO
M(&[K<F$N`$YU<W1A='EM^"!NZW)A+@!$86QI^"P@:W5R:6%S(&=A;&EM82!R
M;V1Y=&D@;&%I\&MO('1E:W-T92P@;NMR82X`T&EA;64@;&%U:V4@X79E<W1A
M('!E<B!D875G('-I;6)O;&GX+B!*^W,@X79E9.MT92`E<RP@;R!M86MS:6UA
M;'5S('-K86GH:75S("T@)7,@<VEM8F]L:6%I+@!0<F]B;&5M;W,@<W4@9F%I
M;/@@<VEU;G1I;74Z("5S(&YE;G5S:?AS=&%S+@!.=7-I^'-T:2!F86EL;R!N
M97!A=GEK;RX@1F%I;&%S("5S('ER82!D:61E<VYI<R!N96=U(&QE:63^:6%M
M87,@9'ED:7,@*"5D(&)A:71A:2DN`$YU<VGX<W1I(&9A:6QO(&YE<&%V>6MO
M+B!&86EL87,@)7,@=&EK(&1A;&EN86D@;G5S:?AS=&%S+@!.96=A;&EU('!A
M<F]D>71I(/!I;W,@;&%I\&MO(&1A;&EE<P!+;&%I9&$@X6ME;&EA;G0@:V]N
M=&%K=&EN:75S(&1U;VUE;FES+@!+;&%I9&$@X6ME;&EA;G0@:4-A;&5N9&%R
M(&1U;VUE;FES+@!+;&%I9&$@:V]N9FEG^W)A8VEJ;W,@9F]R;6]J92X@1W)E
M:>AI875S:6%I(&YE=?YP:6QDZW1E(')E:6MI86WX(&QA=6OX+@!+;&%I9&$@
M871L:65K86YT(&YU<F]D>73@(&%D<F5S^"!K;GEG96SK<R!F=6YK8VEJX"X@
M4&%B86YD>6MI=&4@=NML:6%U+@!+;&%I9&$@871N875J:6YA;G0@:V]N=&%K
M=&EN:75S(&1U;VUE;FES+B!086)A;F1Y:VET92!VZVQI874N`$ML86ED82!A
M=&YA=6II;F%N="!D:7-T<FEB=6-I:F]S('/@<F'PX"X@4&%B86YD>6MI=&4@
M=NML:6%U+@#0:7,@24U!4"!S97)V97)I<R!N97!A;&%I:V\@:V%T86QO9_@@
M9&%L:6II;6]S:2X`071R;V1O+"!K860@=&%I(&YE='9A<FMI;F=A<R!205(@
M87)C:'EV87,N`$%T<F]D;RP@:V%D('1A:2!N971V87)K:6YG87,@6DE0(&%R
M8VAY=F%S+@!!=')O9&\L(&MA9"!T86D@;F5T96ES:6YG87,@:V]R=&5LZW,@
M;G5M97)I<RX`T&D@='9A<FMY:VSK(&QE:63^:6$@<VGX<W1I(/YI;G5T97,@
M<&5R($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@<&%S:6YA
M=61O:F%N="!(5%10('!R;W1O:V]L=0#0:2!T=F%R:WEK;.L@;&5I9/YI82!S
M:?AS=&D@_FEN=71E<R!P97(@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL
M+F-O;2D@<&%S:6YA=61O:F%N="!(5%10('!R;W1O:V]L=0#0:2!T=F%R:WEK
M;.L@;&5I9/YI82!S:?AS=&D@_FEN=71E<R!33510('!R;W1O:V]L=2!P97(@
M5F]D869O;F4@271A;&EJ;W,@=F%R='5S+"!T:6L@5F]D869O;F4@;G5M97)I
M86US+B!*:2!R96EK86QA=6IA(&5L+B!P8?!T;R!A9')E<V\@5F]D869O;F4@
M271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`T&ES(&QA=6MA<R!P<FEV86QO
M;6%S+@#0:6%M92!L875K92!G86QI(&+[=&D@=&EK('-V96EK:65J:2!S:V%I
MZ&EA:2X`T&EA;64@;&%U:V4@9V%L:2!B^W1I('1I:R!S:V%IZ&EA:2!I<B!D
M=FET8?!K:6%I+@#0:6%M92!L875K92!G86QI(&+[=&D@=&EK(&'P='5N=&%I
M;FEA:2!S:V%IZ&EA:2X`T&EA;64@;&%U:V4@='5R:2!B^W1I(&MA8FQE;&EA
M:7,@87)B82!T87)P86ES(&%T<VMI<G1I('-V96EK:65J:2!S:V%IZ&EA:0#0
M:2!R96EK\&WK('1U<FD@8OMT:2!S:V%IZ&EU<RX`T&EA;64@;&%U:V4@9V%L
M:2!B^W1I('1I:R!S<&%L=F]S(&MO9&%S(%)'0B!(97@@9F]R;6%T92P@<&%V
M>7ID_FEU:2`G(S$R,S1!1B<N`-!I(&9O<FUA(&IA=2!A<&1O<F]T82X`5&%I
M("5S+@!486D@2V]L86(@1W)O=7!W87)E(&]B:F5K=&%S+B!.;W+K9&%M:2!P
M97+^:?MRZW1I(&]B:F5K=.`@<')I=F%L;W1E('1U<NMT:2!E;"X@<&'P=&\@
M:VQI96YTX"P@:W5R:7,@<W5P<F%N=.`@\.$@9F]R;6%TX"X@5&]K:?@@96PN
M('!A\'1O(&ML:65N=/@@<^!R8?#@(&=A;&ET92!R87-T:2!A<'-I;&%N:^8@
M)7,`T&ES(&QA:?!K87,@8G5V;R!P87)A\'ET87,@)7,@:V]D=6]T92X@2OMS
M(&YA=61O:F%T92!K:71O:VG@(&MO9'5O=.8N`-!I<R!S:V%IZ&EU<R!T=7)I
M(&+[=&D@9&ED97-N:7,@=?X@;G5LX2X`T&ES('-E<G9E<FES(&YE9V%L:2!I
M\&%R8VAY=G5O=&D@>FEP(&ER(&=Z:7`@9F%I;/@N`-!I('-I<W1E;6$@9&%B
M87(@:?!J=6YG=&$N`-!I(')E:6OP;>L@='5R:2!B^W1I('-K86GH:75S+@#0
MX2!L86YGX"!R96EK:6$@871I9&%R:6[K=&D@:?`@;G5S=&%T>6WX(&QA;F=O
M`%!E<FO[;FEJ80!":6QI971A:0!,86EK87,`3&%I:V\@87!S:V%I=&$`3&%I
M:V\@9F]R;6%T87,`3&%I:V\@<&%S:7)I;FMI;6%S`%1I;6]R;&5S=.L`4&%R
M96EG;W,`4&%V861I;FEM87,Z`$MA;0!.;W+K9&%M:2!P87-I<FEN:W1I(&ME
M;&5TX"!E;&5M96YT^"P@;&%I:WEK:71E($-O;G1R;VP@*%!#*2!A<F)A($-O
M;6UN860@*$UA8RD@:VQA=FGPX"P@:7(@<&%S:7)I;FMI=&4@<&5L92X`T&EA
M;F1I96X`4F]D>71I($A434P@:V]DX`!4;V=A<P!4;VME;&%U`%)Y=&]J`%1O
M;F=A`%9I<O!U:F4`5FER\'5T:6YI86UE(&QA;F=E("A?=&]P*0!697)T:6UA
M:0!4<FEN:61A9&%S(&ER(%1O8F%G87,`5&%I<"!A<F)A(&YE`$%N='(N`%1U
M;FES87,`5'5R:VEJ80!4=7)K:?!K82`H25-/+3@X-3DM.2D`5'5R:VWK;FEJ
M80!4=7)K<V\@:7(@2V%I:V]S;R!S86QO<P!4=79A;'4`P79E<VMI=&4@<V%V
M;R!P87-I<FEN:VEMX#H@`%4N5BX@:6YD96MS87,Z(`!54DP`4VMR:7!T;R!P
M<FES=&%T>6UO('-T871U<V\@<F%P;W)T;R!54DP`55),.@!59V%N9&$`56MR
M86EN80!.97!A=GEK;R!P97)S:V%I='ET:2!61E,@:V%T86QO9V\N`$YE<&%V
M>6MO('!R:63K=&D@<&%P:6QD;VUO<R!V87)T;W1O:F\@<F5G:7-T<F%C:6IO
M<R!I;F9O<FUA8VEJ;W,N`$YE<&%V>6MO('!A:V5I<W1I(%9&4R!F86EL;R`B
M)7,B('1E:7-I^"X`3F5P879Y:V\@<&%K96ES=&D@=&5I<VGX(%9&4R!F86EL
M=6D@)7,O)7,N`$YE<&%V>6MO('!E<F5I=&D@X2`E<RX`3F5P879Y:V\@<')I
M<VEJ=6YG=&D@<')I92!344P@<V5R=F5R:6\N`$YE<&%V>6MO('!R:7-I:G5N
M9W1I(%-33"!R9?YI;74N`$YE<&%V>6MO(&YU:V]P:6IU;W1I(%9&4R!F86EL
M;RX`3F5P879Y:V\@<W5K=7)T:2!61E,@:V%T86QO9V\@(B5S(BX`3F5P879Y
M:V\@<W5K=7)T:2!61E,@:V%T86QO9V\N`$YE<&%V>6MO('-U:W5R=&D@5D93
M(&9A:6QO+@!.97!A=GEK;R!S=6MU<G1I('1U\.AI;R!61E,@9F%I;&\N`$YE
M<&%V>6MO(&GP87)C:'EV=6]T:2!D=6]M96[X+@!.97!A=GEK;R!I\'1R:6YT
M:2`B)7,B+"!K871A;&]G87,@;F5T=?#H:6%S`$YE<&%V>6MO(&GP=')I;G1I
M("5S+"!K871A;&]G87,@;F5T=?#H:6%S`$YE<&%V>6MO(')E:W5R<VGP:V%I
M(&GP=')I;G1I(%9&4R!K871A;&]G;RX`3F5P879Y:V\@:?!T<FEN=&D@5D93
M(&MA=&%L;V=O+@!.97!A=GEK;R!I\'1R:6YT:2!61E,@:V%T86QO9V\Z("5S
M+@!.97!A=GEK;R!I\'1R:6YT:2!61E,@9F%I;&\@(B5S(BX`3F5P879Y:V\@
M:?!T<FEN=&D@5D93(&9A:6QO+@!.97!A=GEK;R!R96MU<G-I\&MA:2!I\'1R
M:6YT:2!61E,Z("5S+@!.97!A=GEK;R!N=7-T871Y=&D@9&%B87)T:6YI;R!K
M871A;&]G;RX`3F5P879Y:V\@9V%U=&D@<V5R=&EF:6MA=&\@87!R8?!Y;6\`
M3F5P879Y:V\@=?YK<F%U=&D@)7,@87!R8?!Y;6\N`$YE<&%V>6MO('!E<FME
M;'1I(%9&4R!F86EL;RX`3F5P879Y:V\@871I9&%R>71I(%9&4R!F86EL;R`B
M)7,B+@!.97!A=GEK;R!A=&ED87)Y=&D@5D93(&9A:6QO(')A\'EM=6DN`$YE
M<&%V>6MO(&%T:61A<GET:2!61E,@9F%I;&\N`$YE<&%V>6MO(&%T:61A<GET
M:2!S=7-P875S=&\@87)C:'EV;RX`3F5P879Y:V\@<&5R<VMA:71Y=&D@=F9S
M<F]O="!K871A;&]G;RX`3F5P879Y:V\@<&5R=F%D:6YT:2`E<R#A("5S.B!T
M;VMS(&MA=&%L;V=A<R!J874@96=Z:7-T=6]J80!.97!A=GEK;R!P97)V861I
M;G1I(%9&4R!K871A;&]G;RX`3F5P879Y:V\@<&5R=F%D:6YT:2!61E,@:V%T
M86QO9V\Z("5S+@!.97!A=GEK;R!P97)V861I;G1I(%9&4R!F86EL;R`B)7,B
M+@!.97!A=GEK;R!P97)V861I;G1I(%9&4R!F86EL;R`E<R\E<RX`3F5P879Y
M:V\@<&5R=F%D:6YT:2!61E,@9F%I;&\N`$YE<&%V>6MO('!A;&5I<W1I("=M
M:VES;V9S)RX`3F5P879Y:V\@:?!V97)S=&D@\&EO(%=O<F0@9&]K=6UE;G1O
M`$YE<&%V>6MO(.%R8?!Y=&D@5D93(&9A:6QO("(E<R(N`$YE<&%V>6MO(.%R
M8?!Y=&D@5D93(&9A:6QO("AC;W!Y*"D@:VQA:61A*2X`3F5P879Y:V\@X7)A
M\'ET:2!61E,@9F%I;&\@9'5O;65N^"X`4&%B<F%U:W1I`$%T\&%U:W1I('!A
M:V5I=&EM=7,`073P875K=&D@86YK<W1E<V[A('9E:6MS;>``3F5T:6OK=&$@
M<V5R=F5R:6\@:VQA:61A.B``3F5T:6OK=&$@<V5R=F5R:6\@:VQA:61A.B``
M3F5N=7)O9'ET80!5;FEK;V1A<R`H551&+3@I`$IU;F=T:6YI86D@07)A8O@@
M16UY<F%T86D`2G5N9W1I;NL@2V%R86QY<W3K`$IU;F=T:6[K<R!686QS=&EJ
M;W,`2G5N9W1I;FGX(%9A;'-T>6KX($%T;VME<V[K<R!S86QO<P!6:65N971A
M:0!.9?YI;F]M87,`3F7^:6YO;6%S(&%P:6US9VED("A!4$D@365S<V%G92!)
M1"DN`$YE_FEN;VUA<R!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!.
M9?YI;F]M87,@=F%R=&]T;VIO('9A<F1A<R!I<B]A<F)A('-L87!T8?YO9&ES
M+@!086YA:6MI;G1I(&YU;W)O9.`@\&EA;2!E;&5M96YT=6D`3F7A=F%R9&EN
M=&%S`%-A=6=U;6\@<W5M971I;6%I<R!N97!R:79I;&5G:6IU;W1I('-K<FEP
M=&%I(&YE9V%L:2!A=&QI:W1I(%!E<FOK;&EM;R]+;W!I:F%V:6UO+\%KZVQI
M;6\@<')O9W)A;6GP:V%I+B!.;W+K9&%M:2!P97+^:?MRZW1I('1E8VAN:6YE
M<R!D971A;&5S(&UO>FEL;&$N;W)G('1I;FML87!Y:F4L(&ER('-U_FEN;W1I
M(&MA:7`@<VMR:7!T86US(&QE:7-T:2!P<FEE:71I('!R:64@;&%I:VEN;W-I
M;W,@<V%U9WEK;&]S+"!P87-P875S:VET92!/2RX`3F5N875D;W1I('-P86QV
M;W,`4&SK=&EN>7,@;F5P86QA:6MO;6%S`$%T;F%U:FEN=&D`071N875J:6YT
M:2`E<P!!=&YA=6II;G1I('9A<G1O=&]JX`!!=&YA=6II;FEM;R!S:W)I<'1A
M<R!I\'1R:6YT87,N`$YU<VGX<W1I`%9I<VD@;6]D=6QI^"!A=&YA=6II;FEM
M;R!F86EL86D@X6ME;'1I(.$@<V5R=F5RX2X`1&ED_FEO<VEO<R!L;W1I;FGP
M:V]S(')A:63K<P!$:61I96II(')O;>MN:?!K:2!S:V%IZ&EA:0!5<G5G=F%J
M=7,`3F%U9&]T:2!D86)A<G1I;N8Z("5S`$YA=61O=&D@4U-,`$YA=61O=&D@
M:F5I9W4@=F%R=&]T;VIO('9A<F1A<R]S;&%P=&'^;V1I<R!)35-0('-E<G9E
M<FEU:2!Y<F$@:VET;VMS+@!687)T;W1O:F%S("5S(&YE875T;W)I>G5O=&%S
M('!R:>MJ:6UU:2!P<FEE("5S+@!687)T;W1O:O@@861M:6YI<W1R879I;6%S
M`%9A<G1O=&]J;R!N=7-T871Y;6%I`%9A<G1O=&]J^"!R96=I<W1R86-I:F$`
M5F%R=&]T;VKX(')E9VES=')A8VEJ82!I\&IU;F=T82X`5F%R=&]T;VIO('9A
M<F1A<P!687)T;W1O:F\@=F%R9&%S.@!687)T;W1O:F\@=F%R9&%S.B``5F%R
M=&]T;VIA:2#P:6]J92!S:7-T96UO:F4Z`%5Z8F5K:7-T86YA<P!61E,@:V%T
M86QO9V%S(&YE96=Z:7-T=6]J82X`071O<W1O9V]S`%)A<W1O<R!T96ES:6YG
M;W,@=FEE=&]VZW,Z(`!'86QI;VII;6%S`%)E:6OP;>L@;6EN=73K;6ES(&YU
M;R!D86)A<BX`4F5I:_!MZW,`4F5I:_!MZW,@:?`@:W5R:?@@9V%L:6UA('!A
M<VER:6YK=&D`5F%N=6%T=0!+:6YT86YT:7,`5F5N97-U96QA`%!A='9I<G1I
M;FEM87,@;F5B86EG=&%S("T@\&ES(&QA:?!K87,@<W5G861I;G1A<RX`5F5R
M<VEJ80!697)S:6KX(&MO;G1R;VSK`$QY9VEU;W1I('9E<G1I:V%L:6%I`%9E
M<G1I:V%L=7,@=&%R<&%S`%9E<G1I:V%L=7,Z`$QA8F%I(&1I9&5L:7,`5FEE
M=&YA;6%S`%9I971N86UI971I\&MA("A625-#24DI`%!E<OYI^W+K=&D@)7,`
M4F]D>71I(&GP;W)I;N$@<'5S;&%PX0!097+^:?MRZW1I(&MA:7`@)7,`0G)I
M=/@@5FER9/YI;FEJ;W,@<V%L;W,`2D%6(%9I<F3^:6YI:F]S('-A;&]S`$UA
M=&]M=6UA<P!-871O;75M87,Z(`!6;V1A9F]N92!)=&%L:6IA('!E<B!33510
M`%=!4DX`1,M-15-)3R$A(2!005194R!)T%1224Y+251%(%-+4DE05,`@2=`@
M)7,N`%9A;&ES(&ER($9U='5N80!$ZVUE<VEO`%1R9>@N`$]R^"!P<F]G;F]Z
MZP!/<O@@<')O9VYO>NL@<&%G86P`5V5A=&AE<BYC;VT`5U=7`%=75R!P=7-L
M87!I<P!+87,@<V%V86ETY@!3=F5I:VD`4W9E:6MI(&%T=GEKYB#A("5S`$QA
M8F%S+"`E<P!686MA<O@@*$E33RTX.#4Y+3$I`%9A:V%R^"`H25-/+3@X-3DM
M,34I`%9A:V%R^"!386-H87)A`$MO:^$@;6]D=6SA("5S('1U<FD@<F]D>71I
M('!O('!R:7-I:G5N9VEM;S\`2V]K<R!S:VER='5K;R!S:6UB;VQI<S\`2V]K
M<R!K86)UZ&GX('-I;6)O;&ES/P!+=7)I;W,@9F%ZZW,`2%1-3"!R961A:W1O
M<FEA=7,@;6]D=6QI^"#A:G5N9VEM87,N`%!L;W1I<P!0;&]T:7,@0U-3(&UA
M=&%I<P`E<R!K86ER:6]J;R!M96YI=2!P;&]T:7,@*'!A:V5I=&EM86D@8G5S
M(&UA='ET:2!P;R!K:71O('!R:7-I:G5N9VEM;RDZ`$QE;G1E;.MS('!L;W1I
M<P!0;&_H:6\@;6%T87,`4&QO=&ES.@!7:6MI`%;K:F\@9W)E:71I<R!M87IG
M86ES`%;K:F%S.@!6ZVIA<SH@`$GP;6EN=&ES`$1A<F)A<P!$87)B;R!A9')E
M<V%S`$1A<F)O('1E;&5F;VYA<P!8+5)E9@!8-3`Y=C,@<&%G<FEN9&EN:6%I
M(&YU<W1A='EM86D`6#4P.78S(&GP<&SK<W1O(')A:W1O('!A;F%U9&]J:6UA
M<P!8-3`Y=C,@86QT97)N871Y=G5S('9A<F1A<P!8-3`Y=C,@<F%K=&\@:61E
M;G1I9FEK871O<FEU<P!8-3`Y=C,@;6]D=6QI86D`65D`65E960!986AO;R$@
M_F5MZVQA<&ES`$MA<VUE=`!*96UE;F%S`%1A:7``5&%I<"P@8?`@<W5T:6YK
M=0!*^W,@97-A=&4@5$5+4U1)3DE!344@4D7>24U%+B!.;W+K9&%M:2!G<N'^
M=&D@X2!765-)5UE'('-P875S:VET92!;/#Y=+@!*^W,@;F5P<FES:6IU;F?F
M+@!3879O('9A<F1E(&YE9V%L:71E(&YA=61O=&D@<VEM8F]L:6\@)UPG+@#!
M=F5DZW1E(&YE=&5I<VEN9^`@96PN('!A\'1O(&%D<F5SX"X`3F5P<FEJ=6YG
MZW1E(&IO:VGX(&QA=6OX(&GP(.%K96QI86UO(&9A:6QO('!R:64@)7,@871I
M=&EN:V%M^"!L875K^"X`2OMS(&%T<VEJ=6YGZW1E+@!4=7)I=&4@X79E<W1I
M('1E:7-I;F?@('1E;&5F;VYO(&YU;65RX2`H=&EK('-K86GH:75S(&ER("<K
M)RP@:F5I9W4@;F]R:71E(&YU<F]D>71I('1A<G!T875T:6[A(&MO9.`I+@#!
M=F5DZW1E(&YE=&5I<VEN9^`@<F5I:_!MYBX`3F]RZV1A;6D@;F%U9V]T:7,@
M<F5G:7-T<F%C:6IO<R!S:7-T96UA+"!T=7)I=&4@<W5K;VYF:6?[<G5O=&D@
M9'5O;65N^"!M963^:6\@<&]S:7-T96WF+@!0<FEE\"!S:?AS9&%M:2!P<F%N
M9?!I;>`L(&%P<F'P>6MI=&4@<')O8FQE;>`N`,%R8?!Y:VET92!N=6]R;V1O
M<R!54DP`5'5R:71E('!A<VER:6YK=&D@<V5R=F5RX2P@:W5RX2!N;W)I=&4@
M:?!T<FEN=&DN`$YU<F]D>6MI=&4@=F%R=&]T;VIO('9A<F3@+"!K=7)I;R!D
M=6]M96YI<R!T<FEN871E+@!.=7)O9'EK:71E('9A<G1O=&]J;R!V87)DX"!T
M<GEN:6UU:2X`3G5R;V1Y:VET92!K=7)I86UO('9A<G1O=&]J;R!V87)DX"X`
M3G5R;V1Y:VET92!A=&YA=6II;F%M;R!V87)T;W1O:F\@=F%R9.`N`$YU<F]D
M>6MI=&4@=F5I:W-MX"X`2OMS('1U<FET92#A=F5S=&D@;F%U:F]S(&MA=&5G
M;W)I:F]S('!A=F%D:6YI;>`N`"5S('-E<VEJ82!B86EGZW-I+B!0<F'P;VUE
M('!R:7-I:G5N9W1I(&GP(&YA=6IO+@!*^W/X(&5L+B!P8?!T;R!A9')E<V%S
M.@!%;"X@<&'P=&\@861R97-A<SH`26YF;W)M86-I:F$@87!I92!*=7,`3G5O
M("5S('-E<VEJ;W,@<')A9/YI;W,@:OMS^"!)4"!A9')E<V%S('!A<VEK96ET
MZRX@5'5R:71E('!R:7-I:G5N9W1I(&GP(&YA=6IO+@!*^W/X('9A<F1A<R]P
M879A<F3K`$K[<_@@875T96YT:69I:V%V:6UO('-I<W1E;6$@;F5P86QA:6MO
M('9A<G1O=&]J^"!SX')A\&\L(&%R8F$@\&D@9G5N:V-I:F$@=?YD<F%U<W1A
M(&3K;"!T86T@=&EK<O@@<')I9?YA<^AI^"X`3G5O("5S('-E<VEJ;W,@<')A
M9/YI;W,@:OMS^"!N87+P>6MLZW,@=&EP87,@<&%S:6ME:73K+B!4=7)I=&4@
M<')I<VEJ=6YG=&D@:?`@;F%U:F\N`$K[<_@@;F%R\'EK;.L@;F5P86QA:6MO
M(/!I;W,@9V%L:6UY8NMS+@!*^W/X(&QA:6MO(&IU;W-T83H`2OMS^"!S=&%N
M9&%R=&EN:7,@87!R8?!A<SH`2OMS^"!V87)D87,O<&%V87)DZSH`2OMS^"!N
M875J87,@)7,@<VQA<'1A_F]D:7,@>7)A.B`E<P!*^W/X(&YU<W1A='EM86D@
M871N875J:6YT:2X`2OMS^"!S;&%P=&'^;V1I<R!P86ME:7-T87,`2OMS^"!S
M;&%P=&'^;V1I<R!P86ME:7-T87,N(%!A<VET:6MR:6YK:71E('-A=F\@<&'P
M=.`@:7(@<')I<VEJ=6YK:71E('-U(&YA=6IU('-L87!T8?YO9/YI=2X`2OMS
M^"!N=71O;.8@<V5R=F5R:6%I.@!*=6=O<VQA=FEJ80!:86ER87,`6F%M8FEJ
M80!::6UB86)VZP!%;F5R9VEN9V]S`%M087-LZW!T:2!C:71U;VIA;>`@=&5K
M<W3@70!;4')O8FQE;6]S('!R86YE\&EM87-=`%M2;V1Y=&D@8VET=6]J86W@
M('1E:W-TX"`M`%M2;V1Y=&D@8VET=6]J86W@('1E:W-TX"`M("5S(&5I;'5T
M97-=`%ME:6QU=.L@)7,@:?`@)7-=`%]686QD>6UA<P!?0TQ)`%]$=6]M96[X
M(&UE9&ES`%])\'1R:6YT:2!E:6QU=.8`1U]R=7#K<P!085]G86QB80!?4&%V
M96EK<VSK;&EO(&YU<W1A='EM86DN+BX`4')I<VE?:G5N9W1I`$%T<VE?:G5N
M9W1I`%]+96ES=&D@;G5O<F]DX"XN`%].=7-T871Y;6%I`%]496ESZW,`7TGP
M=')I;G1I(&YU;W)O9.`N+BX`7TMO;F9I9_MR86-I:F$`7TQE;G1E;.MS(&YU
M<W1A='EM86DN+BX`5E]A<G1O=&]J86D`861R97/X(&MN>6=E;.L`2V%L96YD
M;W)I=7,`<F%M=7,`<W!A=7-K:71E(.AI80!K<F5N=&$`9F%I;&%S`&YU;R`E
M<R`H)7,I("5S("5S`&$Z`'1U;VIA=2!P870`<&%P<F%S=&D`96EL=71E<UT`
M;6MI<V]F<R!K;&%I9&]S(&MO9&%S("5D(&)E9&%R86YT($E33RX`=F%R9&%S
M`&YE<F5A;&EZ=6]T80!D87(@;F5R96%L:7IU;W1A`'7^<F'P^"!K;GEG96SK
M`'!R;V-E;G1A:0!P:6MS96QI86D`:WEL80!R;V1Y=&D@<VMI<G1U;75S`'-M
M<S)E;6%I;"!P97(@2%144`!S=&%B:6QI`&1A<F+X('/@<F'P87,`<VQA<'1A
M_F]DX2!T=7)I=&4@X7)A\'ET:2!D=2!K87)T=7,`=6YI9FEK=6]T:0!D86QI
M<P!V87)T;W1O:F\@<&%S:7)I;FMI;6%S`'9#87)D`'`Z`'=E871H97(N8V]M
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&]C86QE+VQT7TQ4+VAE;'`N>&UL````````````
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S,S(P(#$P-3$U-#,S
M-S0Q(#`R,30V,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/WAM;"!V97)S:6]N/2(Q+C`B/SX*/"$M+2`D2&]R9&4Z(&AO
M<F1E+VQO8V%L92]L=%],5"]H96QP+GAM;"QV(#$N,B`R,#`T+S`U+S(W(#(P
M.C(R.C$T(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED/2)S=6UM
M87)Y(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H92!0;W)T86P@4&%G93PO=&ET
M;&4^"B`\<&%R83X*("!4:&ES('!O<G1A;"!P86=E('!R;W9I9&5S(&$@<75I
M8VL@<W5M;6%R>2!O9B!A;&P@>6]U<B!I;7!O<G1A;G0*("!I;F9O<FUA=&EO
M;BX@1F]R(&5X86UP;&4L(&ET(&UI9VAT('-H;W<@:&]W(&UA;GD@;F5W(&4M
M;6%I;"!M97-S86=E<R!Y;W4*("!H879E(&EN('EO=7(@24Y"3U@L('5P8V]M
M:6YG(&5V96YT<R!O;B!Y;W5R(&-A;&5N9&%R+"!T87-K<R!O;B!Y;W5R('1O
M+61O"B`@;&ES="P@:&5A9&QI;F5S(&9R;VT@<V5L96-T960@;F5W<R!S97)V
M:6-E<RP@86YD('-O(&]N+B`@36%N>2!O9B!T:&5S90H@('-U;6UA<FEE<R!W
M:6QL(&-O;G1A:6X@<75I8VL@<VAO<G1C=71S('1O(&-O;6UO;B!F=6YC=&EO
M;G,L('-U8V@@87,*("!C;VUP;W-I;F<@82!N97<@;6%I;"!M97-S86=E+"!C
M<F5A=&EN9R!A(&YE=R!C86QE;F1A<B!E=F5N="!O<B!T87-K+"!E=&,N"B`\
M+W!A<F$^"B`\<&%R83X*("!4:&4@8V]N=&5N=',@;V8@=&AI<R!P;W)T86P@
M<&%G92!A<F4@8W5S=&]M:7IA8FQE('9I82!T:&4@3&%Y;W5T(&)U='1O;BX*
M("!&;W(@97AA;7!L92P@>6]U(&-A;B!C:&]O<V4@=VAI8V@@:71E;7,@=&\@
M:6YC;'5D92!O;B!T:&ES('!O<G1A;"!P86=E(&%S"B`@=V5L;"!A<R!I;B!W
M:&EC:"!O<F1E<B!T:&5Y(&%R92!S:&]W;BX*(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](FYA=F)A<B(@<W1A=&4](FYE=R(^"CQT:71L93Y4:&4@
M07!P;&EC871I;VX@3F%V:6=A=&EO;B!"87(\+W1I=&QE/@H@/'!A<F$^"B`@
M070@=&AE(&QE9G0@:&%N9"!S:61E(&]F('1H92!W96(@<&%G92!I<R!T:&4@
M87!P;&EC871I;VX@;F%V:6=A=&EO;B!B87(N"B`@0VQI8VL@;VX@=&AE(&EC
M;VYS(&]N('1H:7,@;F%V:6=A=&EO;B!B87(@=&\@<75I8VML>2!A;F0@96%S
M:6QY('-W:71C:`H@(&)E='=E96X@=&AE(&%V86EL86)L92!A<'!L:6-A=&EO
M;G,N"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD;U]M
M86EN=&5N86YC92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC
M97,Z($UA:6YT96YA;F-E.B!$;R!-86EN=&5N86YC93PO=&ET;&4^"B`@("`\
M<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O('!E<F9O<FT@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;BP@8VAE8VL@=&AI<R!B;W@N"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUC;VYF:7)M
M7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E
M;F-E<SH@36%I;G1E;F%N8V4Z($-O;F9I<FT@36%I;G1E;F%N8V4\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!C;VYF:7)M
M(&%L;"!M86EN=&5N86YC92!T87-K<R!B969O<F4@=&AE>2!A<F4@<G5N+"!C
M:&5C:R!T:&ES(&)O>"X@268@;&5F="!U;F-H96-K960L(&%L;"!M86EN=&5N
M86YC92!O<&5R871I;VYS('1H870@;F5E9"!T;R!B92!R=6X@=VEL;"!B92!P
M97)F;W)M960@875T;VUA=&EC86QL>2!W:71H(&YO(&-H86YC92!T;R!C86YC
M96P@;VX@;&]G:6XN"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L<#X*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQO8V%L92]M:U]-2P``````````````````````````````
M```````````````````````````````````````````````````````P,#`W
M-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<T,2`P
M,3<W,30`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VUK7TU++TQ#7TU%
M4U-!1T53````````````````````````````````````````````````````
M`````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M,#`P(#$P-3$U-#,S-S0Q(#`R,34P,0`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M;V-A;&4O;6M?34LO3$-?34534T%'15,O:&]R9&4N;6\`````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,3(V,3`@,3`U,34T,S,W-#$@,#(S,C$V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````-X2!)4`````
M6````!P```#<`@``?P```)P%````````F`<``"@```"9!P``"````,('```%
M````RP<```\```#1!P``"````.$'```(````Z@<``!D```#S!P``!P````T(
M```.````%0@```4````D"```$0```"H(```(````/`@``!4```!%"```"@``
M`%L(```,````9@@```<```!S"```$````'L(```I````C`@```(```"V"```
M!0```+D(```0````OP@```8```#0"```%````-<(```F````[`@```4````3
M"0``#0```!D)```%````)PD```L````M"0``#P```#D)```A````20D```,`
M``!K"0``!````&\)```,````=`D```H```"!"0``!0```(P)```2````D@D`
M`!````"E"0``$````+8)```:````QPD```8```#B"0``!P```.D)```"````
M\0D```0```#T"0``#P```/D)```'````"0H```<````1"@``!````!D*```%
M````'@H```@````D"@``%0```"T*```>````0PH```4```!B"@``*````&@*
M```I````D0H``!,```"["@``"P```,\*```%````VPH``!$```#A"@``!```
M`/,*```,````^`H``!H````%"P``%P```"`+```7````.`L``!L```!0"P``
M$P```&P+```0````@`L``!<```"1"P``!P```*D+```%````L0L```,```"W
M"P``(````+L+```F````W`L```P````##```"````!`,```4````&0P```<`
M```N#```!@```#8,```+````/0P```P```!)#```"@```%8,```"````80P`
M``8```!D#```10```&L,```F````L0P``"4```#8#```<P```/X,```0````
M<@T``'$!``"##0``(@```/4.```'````&`\```4````@#P``%````"8/```*
M````.P\```\```!&#P``)P```%8/```&````?@\```X```"%#P``!0```)0/
M```0````F@\```@```"K#P``%0```+0/```'````R@\``!4```#2#P``!0``
M`.@/```/````[@\``#L```#^#P```@```#H0```&````/1```!0```!$$```
M!P```%D0```1````81```"H```!S$```!P```)X0```0````IA````8```"W
M$```$0```+X0```'````T!```"4```#8$```!````/X0```%`````Q$```\`
M```)$0``#P```!D1```%````*1$``!0````O$0``$P```$01```6````6!$`
M`"8```!O$0``"````)81```%````GQ$```(```"E$0``!0```*@1```6````
MKA$```8```#%$0``!P```,P1```#````U!$```D```#8$0``!P```.(1```=
M````ZA$``!P````($@``!P```"42```@````+1(``#````!.$@``$0```'\2
M```,````D1(```4```">$@``$0```*02```%````MA(```T```"\$@``'```
M`,H2```9````YQ(``!D````!$P``'@```!L3```;````.A,``!,```!6$P``
M'0```&H3```'````B!,```8```"0$P```P```)<3```J````FQ,``"L```#&
M$P``$P```/(3```.````!A0``!8````5%```"````"P4```'````-10```X`
M```]%```$````$P4```1````710```(```!O%```!P```'(4```P````>A0`
M`"L```"K%```*0```-<4``!N`````14``!<```!P%0```0```"P````J````
M`````%8````+`````````!@``````````````$0````H`````````!0`````
M`````````#4````%````2@````(````#````.P```$@````2`````````%$`
M```^````,P```"$````R````3````!H`````````+P```"``````````````
M`%<````6````*P```!,`````````1@```!\````&````.0``````````````
M``````H```!"````)P``````````````)`````\````,````30```$<````V
M`````````#H````I````2P````<````C````````````````````4P```$``
M```>````-````!P`````````'0`````````B````$0``````````````/P``
M````````````%P```$,```!4````3P```"4````5````,````$X`````````
M#@```#P````0````6```````````````10`````````-`````````!L````)
M````"`````````!0````&0`````````F````!````#$````X````/0```%4`
M``!2````+0``````````````20```$$````W`````````"X`````````````
M```E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`#(T
M(&AO=7)S`$%-+U!-`$%D9"!A(&YE=R!U<V5R.@!!9&0@<&%I<@!!9&0@=7-E
M<@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`061M:6YI<W1R
M871I;VX`06QI87,`079A:6QA8FQE(&9I96QD<SH`0FER=&AD87D`0V%N8V5L
M(%!R;V)L96T@4F5P;W)T`$-E;&P@4&AO;F4`0VQO<V4@5VEN9&]W`$-O;7!A
M;GD`0V]N9FER;2!087-S=V]R9`!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC
M95]487-K(&UO9'5L92`E<P!$1`!$86EL>0!$969A=6QT($ED96YT:71Y`$1E
M;&5T90!$97-C<FEB92!T:&4@4')O8FQE;0!$;R!N;W0@9&ER96-T;'D@86-C
M97-S(&UA:6YT96YA;F-E+G!H<`!%;6%I;`!%;7!T>2!R97-U;'0N`$5R<F]R
M`$5V97)Y($QO9VEN`$5X86UP;&4@=F%L=65S.@!&86EL960@=&\@8V]N;F5C
M="!T;R!,1$%0('-E<G9E<BX`1F%X`$AE;'``2&]M92!!9&1R97-S`$AO;64@
M4&AO;F4`2&]R9&4`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD
M<SH`3&ES="!(96QP(%1O<&EC<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D
M+@!,;V<@:6X`3&]G(&]U=`!-30!-86EL`$UA=&-H:6YG(&9I96QD<P!-97-S
M86=E`$UO;G1H;'D`3F%M90!.;W1E<P!087-S=V]R9`!087-S=V]R9',@;75S
M="!M871C:"X`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!H;VYE
M`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE
M87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4')O8FQE
M;2!$97-C<FEP=&EO;@!296UO=F4@<&%I<@!297-E=`!2971U<FX@=&\@3W!T
M:6]N<P!2;VQE`%-A=F4@3W!T:6]N<P!396QE8W0@=&AE(&1A=&4@9&5L:6UI
M=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE('1I;64@
M9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5N9"!0<F]B
M;&5M(%)E<&]R=`!3:VEP($UA:6YT96YA;F-E`%-P96-I86P@0VAA<F%C=&5R
M($EN<'5T`%-U8V-E<W,`5&ET;&4`55),`%5N86)L92!T;R!C;VYN96-T('1O
M(%-13"!S97)V97(N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O
M8W5M96YT`%5N9&\@0VAA;F=E<P!5<V5R;F%M90!5<V5R<R!I;B!T:&4@<WES
M=&5M.@!787)N:6YG`%=E96ML>0!796QC;VUE+"`E<P!7;W)K($%D9')E<W,`
M5V]R:R!0:&]N90!960!996%R;'D`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R
M;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N
M`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M
M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U<B!A=71H96YT
M:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R
M<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@
M;W1H97(@<F5A<V]N+@!;4')O8FQE;2!297!O<G1=`%!R;VIE8W0M260M5F5R
M<VEO;CH@;6M?34L*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH
M;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K
M,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`S+3`V+3(V(#$U.C$X*S`R,#`*
M3&%S="U4<F%N<VQA=&]R.B!3=&]J86X@4&5S;W8@/'-S<$!E=7)E:V$N8V]M
M+FUK/@I,86YG=6%G92U496%M.B!-86-E9&]N:6%N(#QI,3AN0&QI<W1S+FAO
M<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT
M+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+34*0V]N=&5N="U4<F%N<V9E<BU%
M;F-O9&EN9SH@.&)I=`I8+4=E;F5R871O<CH@2T)A8F5L(#$N,"XQ"@`E<R"^
MW]7@T.;8V"#7T"#>U.#6X]+0^M4@+2"_WN+2X-30`#(T(.?0X=``04TO4$T`
MM-[4T-38(-W>TB#:WN#8X=W8VCH`M-[4T-38(-_0X`"TWM30U-@@VM[@V.'=
MV-H`M-[4T-+0^M7BWB#=T"#:WN#8X=W8YM@@U2#>W=72WM?<WM;5W=XN`+#4
MX-7AT`"PU-S8W=CAXN#0YMCXT`!!;&EA<P"TWN'BT-_=V"#?WMO8^M`Z`,#>
MU-7=U-7=`+[BVM#6V""_X-[1V]7<(,#5W][@X@"\WM'8V]7=`+?0XM+>X-@@
MT]X@W^#>U][@U>;>X@#$V.#<T`"_WN+2X-38(-O>U]C=VM``O-[4X]O>XB#=
MT"#7T-30Y]#BT"#7T"#>U.#6X]+0^M4@)7,@W=4@W-[6U2#4T"#1V-35(-[B
MTM[@U=T`1$0`M-W5TMW>`,'BT-W4T.#4U=T@V-35W>+8XM7B`+C7T>#8Z-@`
MOM_8X2#=T"#?X-[1V]7<WN(`O=4@W^#8X>+0W^/2T/@@U-C@U=KBW=X@U-X@
M;6%I;G1E;F%N8V4N<&AP`-4MW][HXM``O^#0U]7=(.#5U^/;XM#B+@"SX-7H
MVM``P=7:WM4@W^#8^-#2X]+0^M4`O^#8W-7@.@"]U>/AW]7HW=`@VM[=U=KF
MV/C0(.'>($Q$05`@X=7@TM7@WN(N`,30VN$`O][<WN@`M-[<T.C=T"#0U.#5
MX=`Z`+3>W-#HU=T@XM7;U>3>W0!(;W)D90"XW-_>X.+8X-#=WB#?WMO5.B`E
M<P"XW-_>X.+8X-#=V"#?WMO8^M`Z`+C7V]CAXM#X(.+5W-@@U]`@W][<WN@`
MN]CAXM#ZU>+>(-W0(-K>X-CAW=CFV"#5(-[=U=+>U]S>UM7=WBX`N][3V.#0
M^M4`N-?;U=<`34T`O][HXM``NM[@U>'?WMW4V.#0Y]K8(-_>V]CZT`"_WN#0
MVM``O-7AU>?=W@"XW-4`M]#1U=O5Z-K8`+O>U]C=VM``N][7V-W:V.+5(-S>
MX-`@U-`@T=C4T.(@V.'BV"X`N-?2X.C8(-[?U>#0YMC8(-?0(-[4X-;CTM#Z
MU0#"U=O5Y-[=`++5(-S>V]C<U2#=T-+5U-7BU2#3WB#?X-[1V]7<WN(N`++5
M(-S>V]C<U2#=T-+5U-7BU2#2T.C5(-K>X-CAW=CGVMX@V-S5(-@@V][7V-W:
MT`"^W]CA(-W0(-_@WM';U=S>X@"^U.'BX-#=V"#?T.``4F5S970`O=#7T-0@
MVM[=(-[?YMC8XM4`P]O>T]``M]#GX]+0^"#>W^;8V`"XU]'5X-@@X=7?T.#0
MXM[@(-?0(-30XN/<WN(Z`+C7T=7@V"#DWN#<T.(@U]`@U-#BX]S>XCH`N-?1
MU>#8(.3>X-S0XB#7T"#2X-7<U>+>.@"XU]'5X-@@U-+5(-[4T][2T.#0Y]K8
M(-_>V]CZT"X`O^#0XM@@V-?2U>CBT/@@U]`@W^#>T=O5W-[B`+_@U>':WMK=
MV"#>U.#6X]+0^M4`LMW5X>/2T/K5(-W0(.'?U>;8^-#;W=@@U]W0YM@`P^'?
MU>C=W@"]T.';WM(`55),`+W5(-S>UM72(-30(.'5(-K>W=7:XMC@T-P@X=X@
M4U%,(.'5X-+5X-[B+@"]U2#<WM;5TB#4T"#3WB#?X-72U=30W"#>TM[X(%=O
M<F0@U-[:X]S5W>(N`+[BVM#6V"#3V"#?X-[<U=W8XM4`NM[@V.'=V.?:WB#8
MW-4`NM[@V.'=V.;8(-+>(.'8X>+5W-[B.@"RW=C<T-W8U0"]U=35V]W>`+3>
MT>#5U-[XU-4L("5S`+#4X-7AT"#=T"#@T-'>XM``PM7;U>3>W2#=T"#@T-'>
MXM``L[,`L][4V.C=W@"^W]CHU>+5(-/>(-_@WM';U=S>XB#?X-74(-30(-CA
MW^#0XM7BU2#8U]+5Z.+0^"X`O=#2U=35XM4@VM[5(-K>X-CAW=CGVMX@V-S5
M(-30(.'5(-[BX>+@T-W8+@"]T-+5U-7BU2#:WM4@VM[@V.'=V.?:WB#8W-4@
MU-`@X=4@U-[4T-35+@"RT.C8WN(@T-+BWN#8U]#FV-[=U=T@W^#>XM[:WML@
MW=4@W][4X-;CTM`@V]CAXM#ZU2#:WN#8X=W8YM@L(-C;V"#BT-`@W-[6W=[A
MXB#5(-[=U=+>U]S>UM7=T"#>U"#4X./3V"#?X-CGV-W8+@!;N-?2U>CBT/@@
MU]`@W^#>T=O5W-[B70``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O;'9?3%8`````````````
M````````````````````````````````````````````````````````````
M````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@
M,3`U,34T,S,W-#$@,#$W-S0P`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L
M92]L=E],5B],0U]-15-304=%4P``````````````````````````````````
M```````````````````````````````````P,#`W-34@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<T,2`P,C$U,C4`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&]C86QE+VQV7TQ6+TQ#7TU%4U-!1T53+VAO<F1E+FUO
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$S-3<Q(#$P-3$U-#,S-S0Q
M(#`R,S(U,0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#>$@25`````&0````<````/`,``(D```!<!@```````(`(```H````
M@0@```@```"J"```!0```+,(```(````N0@```<```#""```!0```,H(```?
M````T`@``!$```#P"```"`````()```(````"PD``!4````4"0``"@```"H)
M```,````-0D```<```!""0``*0```$H)```"````=`D```4```!W"0``$```
M`'T)```4````C@D``"\```"C"0``#P```-,)```F````XPD```4````*"@``
M#0```!`*```%````'@H``!`````D"@``$````#4*```/````1@H```L```!6
M"@``#P```&(*```,````<@H```\```!_"@``'@```(\*```A````K@H```,`
M``#0"@``!````-0*```,````V0H```H```#F"@``!0```/$*```2````]PH`
M`!`````*"P``"````!L+```0````)`L```8````U"P``!P```#P+```"````
M1`L```0```!'"P``#P```$P+```'````7`L```<```!D"P``!````&P+```%
M````<0L```4```!W"P``!P```'T+```1````A0L```@```"7"P``'@```*`+
M```%````OPL``"@```#%"P``*0```.X+```3````&`P```L````L#```$0``
M`#@,```$````2@P```P```!/#```&@```%P,```7````=PP``!<```"/#```
M&P```*<,```?````PPP``!,```#C#```$````/<,```7````"`T```<````@
M#0``!0```"@-```A````+@T``!P```!0#0``!0```&T-```#````<PT``"``
M``!W#0``)@```)@-```,````OPT```P```#,#0``"````-D-```'````X@T`
M``8```#J#0``#0```/$-```+````_PT```P````+#@``"@```!@.```"````
M(PX```8````F#@``10```"T.```P````<PX``!````"D#@``'P```+4.```0
M````U0X```\```#F#@``!0```/8.``!7`0``_`X``"H```!4$```"@```'\0
M```%````BA````X```"0$```!@```)\0```,````IA```!D```"S$```$```
M`,T0```/````WA````D```#N$```&P```/@0```1````%!$```P````F$0``
M"````#,1```K````/!$```(```!H$0``"````&L1```2````=!$``!,```"'
M$0``+P```)L1```2````RQ$``"(```#>$0``!P````$2```0````"1(```4`
M```:$@``$0```"`2```2````,A(``!````!%$@``&````%82```/````;Q(`
M``P```!_$@``#@```(P2```>````FQ(``"0```"Z$@``!0```-\2```)````
MY1(```P```#O$@``#@```/P2```%````"Q,``!0````1$P``$````"83```&
M````-Q,``!H````^$P``"P```%D3```%````91,```(```!K$P``!0```&X3
M```0````=!,```0```"%$P``#````(H3```%````EQ,```4```"=$P``"```
M`*,3```'````K!,``!````"T$P``!@```,43```?````S!,```@```#L$P``
M(P```/43```M````&10``!(```!'%```#````%H4```7````9Q0```0```!_
M%```$````(04```>````E10``!L```"T%```&@```-`4```C````ZQ0``!,`
M```/%0``'````",5```2````0!4``!0```!3%0``!P```&@5```(````<!4`
M`!\```!Y%0``'P```)D5```*````N14```,```#$%0``)P```,@5```K````
M\!4```\````<%@``$0```"P6```/````/A8```L```!.%@``#````%H6```0
M````9Q8``!````!X%@``#````(D6```.````EA8```(```"E%@``"@```*@6
M```O````LQ8``#P```#C%@``$````"`7```;````,1<``!0```!-%P``$```
M`&(7```%````<Q<```$````D`````````$X````=````3P```!<```!%````
M!P```"(`````````30```"$`````````2P```&(````*````$0`````````,
M````,@```%,````Q`````````"4```!&````70````````!2````0@```%4`
M````````1P```"P````O````5@```%$````U````$`````@````^````00``
M`%\````K````#P```#D```!*````(P```!@````S````0````"@```!@````
M"P``````````````5```````````````/0````D`````````+@```$@```!<
M````.@`````````.`````````%D`````````-@`````````;````/P```!P`
M```:````#0```#L`````````!`````4`````````$@`````````3````````
M`%<````M`````````"8``````````````!4````&`````````%L````W````
M&0````````!>`````````#@````T`````````$D````?````6@```$0`````
M````'@``````````````8P````````!8````*0`````````P````````````
M```\````9````%``````````%@```"```````````P```&$```!#````*@``
M`"<```!,`````@`````````4`````"5S($UA:6YT96YA;F-E($]P97)A=&EO
M;G,@+2!#;VYF:7)M871I;VX`,C0@:&]U<G,`04TO4$T`061D('!A:7(`061D
M<F5S<P!!;&EA<P!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%V
M86EL86)L92!F:65L9',Z`$)I<G1H9&%Y`$-A;&5N9&%R`$-A;F-E;"!0<F]B
M;&5M(%)E<&]R=`!#96QL(%!H;VYE`$-L;W-E(%=I;F1O=P!#;VUP86YY`$-O
M=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$1$`$1A
M:6QY`$1E9F%U;'0@261E;G1I='D`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5T
M86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`
M1&ES<&QA>2!/<'1I;VYS`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E
M;F%N8V4N<&AP`$5M86EL`$5M<'1Y(')E<W5L="X`17)R;W(`179E<GD@,34@
M;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R
M>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@
M=F%L=65S.@!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D
M('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A>`!(96QP`$AO;64@061D
M<F5S<P!(;VUE(%!H;VYE`$AO<F1E`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O
M<G1E9"!F:65L9',Z`$QA;F=U86=E`$QI<W0@2&5L<"!4;W!I8W,`3&]G(&EN
M`$QO9R!O=70`34T`36%I;`!-871C:&EN9R!F:65L9',`365S<V%G90!-;VYT
M:&QY`$YA;64`3F5V97(`3F]T97,`3W!T:6]N<P!/=&AE<B!);F9O<FUA=&EO
M;@!087-S=V]R9`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&AO
M;F4`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0
M;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0<F]B
M;&5M($1E<V-R:7!T:6]N`%)E;6]V92!P86ER`%)E='5R;B!T;R!/<'1I;VYS
M`%)O;&4`4V%V92!/<'1I;VYS`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z
M`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@=&EM92!F;W)M
M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!P
M<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4VMI<"!-
M86EN=&5N86YC90!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3=6-C97-S`%1A
M<VMS`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('9A
M;'5E(&UU<W0@8F4@82!N=6UB97(N`%1I=&QE`%523`!5;F%B;&4@=&\@8V]N
M;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@
M5V]R9"!D;V-U;65N=`!5;F1O($-H86YG97,`57-E<B!/<'1I;VYS`%5S97)N
M86UE`%=A<FYI;F<`5V5E:VQY`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`
M5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`65D`665A<FQY`%EO=2!M=7-T(&1E
M<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R
M;V)L96T@<F5P;W)T+@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L
M96%S92!L;V=I;B!A9V%I;BX`66]U<B!);F9O<FUA=&EO;@!9;W5R(&]P=&EO
M;G,@:&%V92!B965N('5P9&%T960N`%M0<F]B;&5M(%)E<&]R=%T`6VQI;F4@
M)7,@;V8@)7-=`'9#87)D`%!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@,BXQ
M"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/
M5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V
M:7-I;VXM1&%T93H@,C`P,BTQ,2TR."`Q-#HP,"LP,C`P"DQA<W0M5')A;G-L
M871O<CH@2V%S<&%R<R!+87!E;FEE:W,@/&MA<W!A<G-`<F-C+FQV/@I,86YG
M=6%G92U496%M.B!,871V:6%N(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-
M12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R
M<V5T/4-0,3(U-PI#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X+6)I=`H`
M)7,@57IT=7+G\&%N87,@;W!E<N)C:6IA<R`M(&%P<W1I<')I;N)J=6US`#(T
M('-T=6YD87,`04TO4$T`4&EE=FEE;F]T('#B<FD`061R97-E`$%I>G-TXFIV
MXG)D<P!.;W+B9.YT82!N961E<NYG82!VYW)T[F)A`%!I965J86UI92!L875K
M:3H`1'II;?!A;F%S(&1I96YA`$MA;&5N9.)R<P!!=&-E;'0@<')O8FSG;6%S
M('!I971E:6MU;74`36]B:6QA:7,@=.)L<G5N:7,`06EZ=N=R="!L;V=U`%5Z
M\N=M=6US`$YE:7ID97;B<R!A=';G<G0@36%I;G1E;F%N8V5?5&%S:R!M;V1U
M;&D@)7,`1$0`26MD:65N87,`4&%R87-TXB!I9&5N=&ETXG1E`$%P<F%K<W1I
M970@<')O8FSG;74`4^YKXFMA(&EN9F]R;>)C:6IA(&ER(&YO<_MT[G1A(&%D
M;6EN:7-T<F%T;W)A;2X`16MRXFYA(&EE<W1A=.YJ=6UI`$YA=B!T:67P87,@
M<&EE96IA<R!M86EN=&5N86YC92YP:'``12UP87-T<P!4=6OP<R!R97IU;'3B
M=',N`$OO^V1A`$MA=')A<R`Q-2!M:6[[=&5S`$MA=')A<R`S,"!S96MU;F1E
M<P!+871R87,@-2!M:6[[=&5S`$MA='+B('!I97-LYV?P86[B<R!R96EZYP!+
M871R=2!P=7-S='5N9'4`2V%T<G4@;6EN^W1I`%!A<F%U9W;G<G3N8F%S`$YE
M:7ID97;B<R!S8?)E;70@:65S=&%T[FIU;75S+@!.96EZ9&5VXG,@<&EE<VSG
M9W1I97,@3$1!4"!S97)V97)I;2X`1F%K<W,`4&%L[F1Z[F)A`$WB:F%S(&%D
M<F5S90!-XFIA<R!T96QE9F]N<P!(;W)D90!)96SB9.=T86ES(&QA=6MS.B`E
M<P!)96SB9.=T:64@;&%U:VDZ`%9A;&]D80!087+B9.YT('!A;.YD>NYB87,@
M=&5M871U<P!0:65S;.=G=&EE<P!)>FEE=`!-30!087-T<P!387-K86YO\&EE
M(&QA=6MI`%II\F$`2V%T<G4@;>=N97-I`%;B<F1S`$YE:V%D`%!I97KN;65S
M`$]P8VEJ87,`0VET82!I;F9O<FWB8VEJ80!087)O;&4`27IP:6QD[G0@=7IT
M=7+G\&%N87,@;W!E<N)C:6IA<P!4XFQR=6YI<P!,^V1Z=2!N;W+B9&EE="!P
M<F]B;.=M87,@86YO=.)C:6IU+@!,^V1Z=2!N;W+B9&EE="!S879U(&QI971O
M=.)J82!VXG)D=2!U;B!P87)O;&D`4')O8FSG;6%S(&%P<F%K<W1S`$EZ9'KG
M<W0@<.)R:0!!=&=R:65Z=&EE<R!P:64@;W!C:6KB;0!,;VUA`%-A9VQA8N)T
M(&]P8VEJ87,`27IVYVQI971I97,@9&%T=6UA(&%T9&%L[G3B:G4Z`$EZ=N=L
M:65T:65S(&1A='5M82!F;W)MXG1U.@!)>G;G;&EE=&EE<R!L86EK82!F;W)M
MXG1U.@!)>G;G;&EE=&EE<R!D:79U<R!S861E<NYG=7,@;&%U:W5S+@!)>G;G
M;&EE=&EE<R!V86QO9'4Z`$YO<_MT[G0@<')O8FSG;6%S('!I971E:6MU;74`
M27IL86ES="!U>G1U<N?P86YU`,YP8?!O('-I;6)O;'4@:65V861E`%9E:6MS
M;64`57ID979U;6D`T&EM('-K86ET;&EM(&ER(&KB8OMT('9I<VUA>B`Q+@#0
M86D@=N=R=.YB86D@:7(@:N)B^W0@<VMA:71L:6TN`%9I<G-R86MS=',`55),
M`$YA=B!I97-PYVIA;7,@<&EE<VSG9W1I97,@4U%,('-E<G9E<FEM+@!.878@
M:65S<.=J86US(&EN=&5R<')E=.=T(/!O(%=O<F0@9&]K=6UE;G1U`$%T8V5L
M="!I>FUA:?)A<P!,:65T;W3B:F$@;W!C:6IA<P!,:65T;W3B:F$@=N)R9',`
M0G+N9&ENXFIU;7,`2V%T<G4@;F5DY^]U`$QA:7!N:2!L^V1Z86T@)7,`3&%I
M<&YI(&S[9'IM+"`E<P!$87)B82!A9')E<V4`1&%R8F$@=.)L<G5N:7,`1T<`
M2V%T<G4@9V%D=0!!<')A:W-T:65T('!R;V)LYVUU('!I<FUS('!I971E:6MU
M;6$@<_MT[O!A;F%S+@!*^W-U("5S('-E<VEJ82!I<B!B96EG=7-I97,N($S[
M9'IU('!I97-LYV1Z:65T:65S(&%T:^)R=&]T:2X`2OMS=2!I;F9O<FWB8VEJ
M80!*^W-U(&]P8VEJ87,@:7(@<V%G;&%BXG1A<RX`6U!R;V)LYVUA<R!Z:?)O
M:G5M<UT`6W)I;F1A("5S(&YO("5S70!V0V%R9```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L;V-A;&4O;F)?3D\`````````````````````````````````
M````````````````````````````````````````````````````,#`P-S4U
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W-#$@,#$W
M-S$Q`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]N8E].3R],0U]-15-3
M04=%4P``````````````````````````````````````````````````````
M```````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P
M,"`Q,#4Q-30S,S<T,2`P,C$T-S8`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C
M86QE+VYB7TY/+TQ#7TU%4U-!1T53+VAO<F1E+FUO````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,38Q,#0S(#$P-3$U-#,S-S0Q(#`R,S(R,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#>$@25`````%$#
M```<````I!H``'\$```L-0```````"A'``!(````*4<```X```!R1P``#P``
M`(%'```-````D4<```@```"?1P``"P```*A'```,````M$<```0```#!1P``
M#````,9'```1````TT<``"4```#E1P``#P````M(```+````&T@``!$````G
M2```#@```#E(```%````2$@``"@```!.2```"````'=(```*````@$@``!4`
M``"+2```$@```*%(```+````M$@``!0```#`2```)@```-5(```G````_$@`
M`"8````D20``$P```$M)```.````7TD```H```!N20``#0```'E)```G````
MATD``"````"O20``#@```-!)```7````WTD``"(```#W20``-0```!I*```1
M````4$H```T```!B2@``#````'!*```-````?4H```8```"+2@``&P```))*
M```M````KDH``"0```#<2@``*0````%+```9````*TL``!@```!%2P``#```
M`%Y+```.````:TL```X```!Z2P``"````(E+```N````DDL``!H```#!2P``
M,@```-Q+```X````#TP``%0```!(3```40```)U,``!:````[TP``%<```!*
M30``-````*)-```%````UTT``!$```#=30``"````.]-```)````^$T```D`
M```"3@``#@````Q.```(````&TX``"4````D3@``(````$I.```0````:TX`
M``\```!\3@``"@```(Q.```'````ETX```,```"?3@``#P```*-.```4````
MLTX```D```#(3@``#0```-).```2````X$X``!D```#S3@``'@````U/```/
M````+$\```H````\3P``#P```$=/```(````5T\``"0```!@3P``%P```(5/
M```4````G4\``!8```"R3P``"````,E/``!.````TD\``"T````A4```'P``
M`$]0```9````;U````<```")4```#````)%0```L````GE````X```#+4```
M`P```-I0```%````WE````4```#D4```"@```.I0```#````]5```!<```#Y
M4```"@```!%1```/````'%$```X````L40``&````#M1```C````5%$```X`
M``!X40``%````(=1```7````G%$``!<```"T40``%P```,Q1```3````Y%$`
M``\```#X40``'P````A2```/````*%(```8````X4@``"P```#]2```0````
M2U(``!4```!<4@``%0```')2```'````B%(``!````"04@``$0```*%2```,
M````LU(``#L```#`4@``.````/Q2```#````-5,```D````Y4P``.0```$-3
M```2````?5,``#D```"04P``)P```,I3```L````\E,``"H````?5```)0``
M`$I4```)````<%0```H```!Z5```!P```(54```O````C50``#<```"]5```
M+@```/54``!5````)%4``"T```!Z50``+0```*A5```M````UE4``$`````$
M5@``(P```$56```C````:58``"T```"-5@``,P```+M6```5````[U8``!D`
M```%5P``*0```!]7```D````25<``!$```!N5P``$0```(!7```,````DE<`
M``H```"?5P``$````*I7```6````NU<``!8```#25P``!````.E7```G````
M[E<```@````66```!P```!]8```(````)U@``"D````P6```#@```%I8```*
M````:5@```0```!T6```"0```'E8```&````@U@``!$```"*6```!P```)Q8
M```$````I%@```8```"I6```#0```+!8```#````OE@```,```#"6```%P``
M`,98```3````WE@```@```#R6```!````/M8``!!`````%D``"````!"60``
M!@```&-9```&````:ED``!4```!Q60``&````(=9```B````H%D``"X```##
M60``'0```/)9```A````$%H``%0````R6@``*0```(=:```'````L5H``!4`
M``"Y6@``"@```,]:```/````VEH```T```#J6@``#P```/A:```-````"%L`
M``D````66P``!@```"!;```3````)UL``!0````[6P``#````%!;```&````
M75L``%0```!D6P``!````+E;```.````OEL``$0```#-6P``$0```!)<```1
M````)%P``!$````V7```'````$A<```J````95P``"$```"07```!0```+)<
M```3````N%P``!(```#,7```"@```-]<```/````ZEP``!$```#Z7```$P``
M``Q=```,````(%T```8````M70``!@```#1=```0````.UT``!$```!,70``
M!0```%Y=```,````9%T``!````!Q70``#0```()=```&````D%T```<```"7
M70``#0```)]=```0````K5T```D```"^70``!P```,A=```+````T%T```L`
M``#<70``!P```.A=```)````\%T``!0```#Z70``"0````]>```*````&5X`
M`!D````D7@``'0```#Y>```,````7%X``!````!I7@``$@```'I>```3````
MC5X``"L```"A7@``.P```,U>```@````"5\``#8````J7P``$````&%?```(
M````<E\```8```![7P``!````()?```.````AU\``!````"67P``'@```*=?
M```;````QE\``"$```#B7P``'@````1@```9````(V```!X````]8```&P``
M`%Q@```N````>&```!<```"G8```)@```+]@```P````YF```!L````780``
M'@```#-A```<````4F$``"8```!O80``*P```)9A```S````PF$``"8```#V
M80``*P```!UB```X````26(``!T```""8@``%0```*!B```O````MF(``!(`
M``#F8@``(````/EB```I````&F,``!X```!$8P``$@```&-C``"B````=F,`
M`!8````99```(P```#!D```H````5&0``"D```!]9```*````*=D```?````
MT&0``!4```#P9```(`````9E```E````)V4``"@```!-90``+0```'9E```P
M````I&4``)(```#590``(0```&AF```6````BF8``!P```"A9@``)@```+YF
M```J````Y68``$$````09P``1````%)G```,````EV<```<```"D9P``!P``
M`*QG```&````M&<```T```"[9P``$````,EG```2````VF<``!,```#M9P``
M$@````%H```-````%&@```P````B:```#P```"]H```3````/V@```T```!3
M:```*````&%H```#````BF@```T```".:```!@```)QH```"````HV@```4`
M``"F:```!````*QH```0````L6@```0```#":```#0```,=H```.````U6@`
M``,```#D:```#@```.AH```(````]V@```\`````:0``"````!!I```/````
M&6D```<````I:0``#0```#%I```0````/VD``!,```!0:0``$P```&1I```+
M````>&D``!$```"$:0``"0```)9I```&````H&D```P```"G:0``$0```+1I
M```9````QFD```L```#@:0``#0```.QI```B````^FD``!L````=:@``-```
M`#EJ```*````;FH``!@```!Y:@``&0```))J```6````K&H``"\```##:@``
M(@```/-J```-````%FL```<````D:P``#````"QK```F````.6L``!0```!@
M:P``"P```'5K```B````@6L``"\```"D:P``"P```-1K```)````X&L``!D`
M``#J:P``"P````1L```7````$&P``!<````H;```"0```$!L```6````2FP`
M``\```!A;```%@```'%L```.````B&P``!@```"7;```#0```+!L```F````
MOFP``$,```#E;```"````"EM```O````,FT```X```!B;0``!0```'%M```&
M````=VT```,```!^;0``!````()M```*````AVT```H```"2;0``#P```)UM
M```0````K6T``!<```"^;0``$0```-9M```7````Z&T``!D`````;@``"0``
M`!IN```*````)&X```(````O;@``!0```#)N```-````.&X``!L```!&;@``
M%P```&)N```)````>FX```X```"$;@``#0```)-N```2````H6X``#@```"T
M;@``(````.UN```#````#F\```@````2;P``#@```!MO``![````*F\``!@`
M``"F;P``!0```+]O```8````Q6\``!D```#>;P``$P```/AO```'````#'``
M``8````4<```$````!MP```/````+'```!`````\<```#P```$UP```+````
M77````\```!I<```#````'EP```/````AG````<```"6<```"@```)YP```&
M````J7````X```"P<```#````+]P```H````S'````\```#U<```"`````5Q
M```(````#G$``!,````7<0``'@```"MQ```A````2G$``"````!L<0``&0``
M`(UQ```7````IW$``"4```"_<0``%P```.5Q```$````_7$```P````"<@``
M`P````]R```(````$W(```H````<<@``#````"=R```+````-'(``!````!`
M<@``#````%%R```3````7G(``!0```!R<@``#````(=R```)````E'(```X`
M``"><@``"P```*UR```;````N7(```<```#5<@``"@```-UR```-````Z'(`
M``D```#V<@``!`````!S```%````!7,```,````+<P``&`````]S```*````
M*',```0````S<P``)@```#AS```.````7W,``'P```!N<P``%0```.MS```%
M`````70```<````'=```#`````]T```(````''0```H````E=```!@```#!T
M```(````-W0``!8```!`=```$@```%=T```"````:G0```8```!M=```%0``
M`'1T```/````BG0``!$```":=```&@```*QT```$````QW0```D```#,=```
M$````-9T```)````YW0```D```#Q=```&@```/MT```(````%G4``!D````?
M=0``#@```#EU```.````2'4```H```!7=0```@```&)U```-````974```D`
M``!S=0``!@```'UU```)````A'4``!0```".=0``'0```*-U```1````P74`
M``8```#3=0``$0```-IU```1````['4```D```#^=0```@````AV```$````
M"W8``#D````0=@``/0```$IV```Z````B'8``!X```##=@``#@```.)V```$
M````\78```8```#V=@``!@```/UV```$````!'<``!$````)=P``!@```!MW
M```*````(G<``"(````M=P``!````%!W```E````57<```4```![=P``!```
M`(%W```,````AG<```H```"3=P``!0```)YW```Z````I'<``#````#?=P``
M-0```!!X```I````1G@``"X```!P>```1P```)]X```X````YW@``"D````@
M>0``/P```$IY```N````BGD``"T```"Y>0``'P```.=Y```/````!WH``!(`
M```7>@``"P```"IZ```F````-GH``"D```!=>@``)````(=Z```F````K'H`
M``@```#3>@``"@```-QZ```)````YWH``"````#Q>@``(````!)[```F````
M,WL```H```!:>P``&0```&5[```I````?WL``!8```"I>P``$@```,![```*
M````TWL```P```#>>P``#P```.M[```0````^WL``$`````,?```<````$U\
M``!F````OGP```X````E?0``"0```#1]```*````/GT``!(```!)?0``$P``
M`%Q]```,````<'T```8```!]?0``#P```(1]```2````E'T``!````"G?0``
M"@```+A]```1````PWT``!P```#5?0``(P```/)]``!J````%GX```\```"!
M?@``$````)%^```$````HGX```L```"G?@``%````+-^```,````R'X```P`
M``#5?@``#P```.)^```5````\GX``"D````(?P``*@```#)_```F````77\`
M`"<```"$?P``*0```*Q_```J````UG\``!D````!@```0@```!N````1````
M7H```!(```!P@```$P```(.````4````EX````\```"L@```%@```+R````7
M````TX```!````#K@```$0```/R````T````#H$``!,```!#@0``$@```%>!
M```U````:H$``!0```"@@0``!P```+6!```K````O8$``"````#I@0``%```
M``J"```1````'X(``!<````Q@@``'````$F"```3````9H(``!$```!Z@@``
M&@```(R"```>````IX(``!H```#&@@``$0```.&"```7````\X(``!0````+
M@P``%P```""#```5````.(,```D```!.@P``$0```%B#```&````:H,```8`
M``!Q@P``!P```'B#```$````@(,```0```"%@P``!P```(J#```.````DH,`
M``X```"A@P``*````+"#```.````V8,```P```#H@P``#P```/6#```*````
M!80```@````0A```"0```!F$```K````(X0```0```!/A```!P```%2$```(
M````7(0```D```!EA```#````&^$```-````?(0```X```"*A```%@```)F$
M```1````L(0```,```#"A```!@```,:$```9````S80```0```#GA```"P``
M`.R$```+````^(0```T````$A0``"@```!*%```0````'84```\````NA0``
M$0```#Z%```7````4(4```H```!HA0``$0```'.%```(````A84```0```".
MA0``#P```).%```Z````HX4```4```#>A0``#````.2%```>````\84```X`
M```0A@``$````!^&```+````,(8```P````\A@``"0```$F&```'````4X8`
M``H```!;A@``"0```&:&```.````<(8``!````!_A@``&@```)"&```*````
MJX8``!0```"VA@``"@```,N&```,````UH8```\```#CA@``"````/.&```&
M````_(8```<````#AP``"P````N'``!'````%X<```T```!?AP``"0```&V'
M```$````=X<```,```!\AP``$P```("'```3````E(<```(```"HAP``!```
M`*N'```/````L(<``!0```#`AP``$P```-6'```0````Z8<```T```#ZAP``
M#@````B(```6````%X@```H````NB```!P```#F(```'````08@```D```!)
MB```!P```%.(```$````6X@```P```!@B```!0```&V(```$````<X@```0`
M``!XB```"0```'V(```"````AX@```\```"*B```!````)J(```%````GX@`
M``8```"EB````@```*R(```&````KX@``!0```"VB```!P```,N(```*````
MTX@``!$```#>B```"````/"(```>````^8@``"@````8B0``%````$&)```%
M````5HD``"@```!<B0``*0```(6)``!7````KXD``"P````'B@``!P```#2*
M```-````/(H``!,```!*B@``(P```%Z*```+````@HH```L```".B@``(```
M`)J*```G````NXH``"L```#CB@``%`````^+```%````)(L``!$````JBP``
M!````#R+```$````08L```P```!&BP``!@```%.+```-````6HL``!H```!H
MBP``%P```(.+```7````FXL``!L```"SBP``'P```,^+```7````[XL``!,`
M```'C```&0```!N,```$````-8P``!`````ZC```%P```$N,```%````8XP`
M``8```!IC```!P```'",```&````>(P```<```!_C```!P```(>,```%````
MCXP``!H```"5C```%````+",```)````Q8P``!P```#/C```*0```.R,```X
M````%HT``"\```!/C0``*P```'^-```J````JXT``#X```#6C0``'0```!6.
M```C````,XX``"$```!7C@``'````'F.```%````EHX```(```"<C@```P``
M`)^.```@````HXX``"8```#$C@``#````.N.```?````^(X```<````8CP``
M&````""/```&````.8\```P```!`CP``"````$V/```)````5H\```<```!@
MCP``"@```&B/```)````<X\```<```!]CP``!@```(6/```-````C(\```L`
M``":CP``#````*:/```*````LX\```(```"^CP``!@```,&/```#````R(\`
M`$4```#,CP``,````!*0```0````0Y````D```!4D```4P```%Z0```?````
MLI```!````#2D```#P```..0```%````\Y````@```#YD```"`````*1```$
M````"Y$```4````0D0``:`$``!:1``!/````?Y(``!$```#/D@``$````.&2
M```1````\I(```@````$DP``"P````V3```(````&9,```4````BDP``"P``
M`"B3```1````-),``"D```!&DP``$````'"3```-````@9,``!$```"/DP``
M#@```*&3```%````L),``"@```"VDP``#P```-^3```/````[Y,```\```#_
MDP``$P````^4```+````(Y0``!4````OE```1````$64```D````BI0``"X`
M``"OE```%@```-Z4```-````]90```L````#E0``#P````^5```S````'Y4`
M`"$```!3E0``#0```'65```9````@Y4``"<```"=E0``.@```,65```2````
M`)8```\````3E@``$0```".6```3````-98```8```!)E@``'````%"6```L
M````;98``!\```":E@``)0```+J6```:````X)8``!H```#[E@``"@```!:7
M```0````(9<``!`````REP``"````$.7```P````3)<``!H```!]EP``/```
M`)B7``!$````U9<``&`````:F```70```'N8``!G````V9@``&0```!!F0``
M0````*:9```%````YYD``!$```#MF0``!0```/^9```0````!9H```T````6
MF@``%````"2:```'````.9H``"X```!!F@``*@```'":```-````FYH```T`
M``"IF@``%0```+>:```*````S9H```@```#8F@``%````.&:```9````]IH`
M``T````0FP``$@```!Z;```5````,9L``"````!'FP``(````&B;```3````
MB9L``!````"=FP``%@```*Z;```,````Q9L``"8```#2FP``%P```/F;```7
M````$9P``!H````IG```#P```$2<``!.````5)P``"H```"CG```'@```,Z<
M```S````[9P```<````AG0``"P```"F=```P````-9T```X```!FG0``"```
M`'6=```%````?IT```<```"$G0``"@```(R=```$````EYT``!D```"<G0``
M#````+:=```0````PYT```\```#4G0``%@```.2=```Q````^YT``!,````M
MG@``%0```$&>```8````5YX``!L```!PG@``&0```(R>```1````IIX``!$`
M``"XG@``'0```,J>```,````Z)X```0```#UG@``!P```/J>```,`````I\`
M`!0````/GP``-0```"2?```(````6I\``!0```!CGP``%P```'B?```)````
MD)\``$,```":GP``.P```-Z?```%````&J````L````@H```/@```"R@```0
M````:Z```$$```!\H```,````+Z@```S````[Z```#4````CH0``.````%FA
M```)````DJ$```@```"<H0``"0```*6A```[````KZ$``#H```#KH0``.@``
M`":B``!6````8:(``#D```"XH@``.0```/*B```Y````+*,``#@```!FHP``
M*````)^C```I````R*,``#D```#RHP``/P```"RD```4````;*0``!@```"!
MI```)@```)JD```F````P:0``!,```#HI```#@```/RD```,````"Z4```@`
M```8I0``#@```"&E```6````,*4``!D```!'I0``!0```&&E```M````9Z4`
M``H```"5I0``!@```*"E```'````IZ4``"X```"OI0``$P```-ZE```*````
M\J4```,```#]I0``"0````&F```%````"Z8```X````1I@``!@```""F```%
M````)Z8```0````MI@``"@```#*F```#````/:8```,```!!I@``&````$6F
M```8````7J8```@```!WI@``!@```("F``!"````AZ8``"0```#*I@``!@``
M`.^F```&````]J8``!4```#]I@``&P```!.G```?````+Z<``"\```!/IP``
M'P```'^G```D````GZ<``'4```#$IP``-P```#JH```&````<J@``!<```!Y
MJ```#````)&H```4````GJ@``!P```"SJ```%````-"H```2````Y:@```P`
M``#XJ```!@````6I```7````#*D``!X````DJ0``"0```$.I```%````3:D`
M`$T```!3J0``!````*&I```.````IJD``"8```"UJ0``$````-RI```3````
M[:D```X````!J@``(````!"J```N````,:H``"@```!@J@``!0```(FJ```3
M````CZH``!````"CJ@``#````+2J```0````P:H``!4```#2J@``$P```.BJ
M```*````_*H```4````'JP``!0````VK```5````$ZL``!$````IJP``!0``
M`#NK```+````0:L```D```!-JP``#@```%>K```+````9JL```@```!RJP``
M#0```'NK```2````B:L```L```"<JP``"0```*BK```*````LJL```L```"]
MJP``!0```,FK```&````SZL``!(```#6JP``#````.FK```&````]JL``!P`
M``#]JP``(@```!JL```-````/:P```\```!+K```%0```%NL```6````<:P`
M`#,```"(K```0@```+RL```E````_ZP``"0````EK0``#@```$JM```(````
M6:T```8```!BK0``!@```&FM```3````<*T``!(```"$K0``'P```)>M```>
M````MZT``"D```#6K0``*`````"N```@````*:X``"(```!*K@``*@```&VN
M```Y````F*X``!P```#2K@``)@```.^N```Q````%J\``"(```!(KP``)0``
M`&NO```@````D:\``"L```"RKP``,0```-ZO```J````$+```"8````[L```
M)P```&*P```X````BK```",```##L```(P```.>P```X````"[$``!,```!$
ML0``(@```%BQ```I````>[$``!\```"EL0``$@```,6Q``"Q````V+$``!<`
M``"*L@``(@```**R```J````Q;(``"H```#PL@``/0```!NS```F````6;,`
M`"$```"`LP``(@```**S```I````Q;,``"P```#OLP``.````!RT```O````
M5;0``*````"%M```)P```":U```7````3K4``"````!FM0``+````(>U```L
M````M+4``#<```#AM0``/P```!FV```*````6;8```0```!DM@``!@```&FV
M```'````<+8```\```!XM@``#0```(BV```3````EK8``!0```"JM@``$0``
M`+^V```.````T;8```T```#@M@``#0```.ZV```4````_+8```X````1MP``
M,@```""W```(````4[<``!4```!<MP``!@```'*W```"````>;<```8```!\
MMP``!````(.W```1````B+<```0```":MP``#````)^W```)````K+<```,`
M``"VMP``#0```+JW```(````R+<```L```#1MP``!P```-VW```/````Y;<`
M``@```#UMP``#@```/ZW```1````#;@``!0````?N```%````#2X```,````
M2;@``!````!6N```"````&>X```%````<+@```P```!VN```#P```(.X```8
M````D[@```L```"LN```#0```+BX```A````QK@``!L```#HN```-@````2Y
M```)````.[D``!4```!%N0``%P```%NY```3````<[D``#,```"'N0``)@``
M`+NY```,````XKD```<```#ON0``$0```/>Y```O````";H``!$````YN@``
M"P```$NZ```B````5[H``"X```!ZN@``"0```*FZ```)````L[H``!\```"]
MN@``"P```-VZ```=````Z;H``!T````'NP``!P```"6[```4````+;L```P`
M``!"NP``$P```$^[```.````8[L``!(```!RNP``"@```(6[```@````D+L`
M`#H```"QNP``"````.R[```O````];L```X````EO```"0```#2\```&````
M/KP```,```!%O```!P```$F\```.````4;P```X```!@O```$P```&^\```2
M````@[P``!H```"6O```$0```+&\```:````P[P``!H```#>O```"0```/F\
M```*`````[T```(````.O0``!@```!&]```-````&+T``!@````FO0``%@``
M`#^]```(````5KT```P```!?O0``#@```&R]```1````>[T``$````"-O0``
M&0```,Z]```%````Z+T```@```#NO0``%````/>]``"0````#+X``"$```"=
MO@``!````+^^```<````Q+X``!H```#AO@``&P```/R^```&````&+\```8`
M```?OP``$````":_```/````-[\``!````!'OP``#P```%B_```/````:+\`
M``T```!XOP``#````(:_```0````D[\```0```"DOP``!P```*F_```%````
ML;\```T```"WOP``#0```,6_```N````T[\```H````"P```"0````W````.
M````%\```!L````FP```(0```$+````B````9,```"$```"'P```'@```*G`
M```>````R,```"H```#GP```'0```!+!```(````,,$```P````YP0```P``
M`$;!```'````2L$```D```!2P0``"P```%S!```(````:,$```L```!QP0``
M"P```'W!```6````B<$``!8```"@P0``#````+?!```'````Q,$```<```#,
MP0``#@```-3!```A````X\$```8````%P@``#P````S"```0````',(```P`
M```MP@```P```#K"```$````/L(```0```!#P@``&0```$C"```)````8L(`
M``,```!LP@``)@```'#"```/````E\(``(X```"GP@``$````#;#```(````
M1\,```T```!0PP``$@```%[#```.````<<,``!````"`PP``!P```)'#```,
M````F<,``!0```"FPP``$````+O#```"````S,,```8```#/PP``&0```-;#
M```2````\,,``!D````#Q```(0```!W$```#````/\0```0```!#Q```$```
M`$C$```(````6<0```H```!BQ```(P```&W$```(````D<0``!@```":Q```
M#0```+/$```-````P<0```D```#/Q````@```-G$```-````W,0```<```#J
MQ```!@```/+$```(````^<0``!4````"Q0``'@```!C%```1````-\4```<`
M``!)Q0``%0```%'%```5````9\4```D```!]Q0```@```(?%```$````BL4`
M`#,```"/Q0``-P```,/%```T````^\4``!\````PQ@``#@```%#&```#````
M7\8```0```!CQ@``!0```&C&```%````;L8``!@```!TQ@``!P```(W&```(
M````E<8``!P```">Q@```P```+O&```P````O\8```4```#PQ@``!````/;&
M```-````^\8```X````)QP``!0```!C'```T````'L<``#$```!3QP``.0``
M`(7'```<````O\<``"(```#<QP``/@```/_'```]````/L@``"H```!\R```
M.@```*?(```P````XL@``#@````3R0``)0```$S)```0````<LD``!(```"#
MR0``"P```);)```J````HLD``"L```#-R0``)````/G)```H````'LH```D`
M``!'R@``"P```%'*```*````7<H``"<```!HR@``)@```)#*```P````M\H`
M``H```#HR@``'0```//*```L````$<L``!4````^RP``%````%3+```*````
M:<L```T```!TRP``$````(++```2````D\L``#<```"FRP``D````-[+``!U
M````;\P``!D```#ES```#````/_,```-````#,T``!$````:S0``$@```"S-
M```3````/\T```8```!3S0``%````%K-```3````;\T``!````"#S0``#```
M`)3-```3````H<T``!@```"US0``)````,[-``"!````\\T```H```!US@``
M%````(#.```$````E<X```L```":S@``%P```*;.```.````OLX```\```#-
MS@``$````-W.```5````[LX``"H````$SP``*````"_/```F````6,\``"0`
M``!_SP``+0```*3/```K````TL\``!<```#^SP``0@```!;0```4````6=``
M`!0```!NT```%@```(/0```4````FM```!(```"OT```&0```,+0```7````
MW-```!(```#TT```$`````?1```]````&-$``!<```!6T0``%@```&[1```[
M````A=$``!$```#!T0``!P```-/1```M````V]$``"`````)T@``$````"K2
M```0````.](``!,```!,T@``&0```&#2```1````>M(``!0```",T@``'P``
M`*'2```C````P=(``!4```#ET@``$@```/O2```6````#M,``!,````ETP``
M%````#G3```5````3M,```<```!DTP``%P```&S3```'````A-,```8```",
MTP``!@```)/3```$````FM,```0```"?TP``!@```*33```)````J],``!``
M``"UTP``*@```,;3```2````\=,``!`````$U```$@```!74```-````*-0`
M``L````VU```"@```$+4```\````3=0```0```"*U```"0```(_4```%````
MF=0```T```"?U```#0```*W4```2````N]0``!0```#.U```&P```./4```7
M````_]0```,````7U0``"````!O5```K````)-4```<```!0U0``#````%C5
M```/````9=4```T```!UU0``"0```(/5```3````C=4``!4```"AU0``#P``
M`+?5```4````Q]4```P```#<U0``#@```.G5```(````^-4```0````!U@``
M#P````;6```T````%M8```8```!+U@``#````%+6```=````7]8```X```!]
MU@``#0```(S6```-````FM8```L```"HU@``"@```+36```(````O]8```T`
M``#(U@``"@```-;6```0````X=8``!H```#RU@``*P````W7```*````.=<`
M`!4```!$UP``"0```%K7```*````9-<```P```!OUP``"````'S7```(````
MA=<```<```".UP``$P```);7``!&````JM<```T```#QUP``"@```/_7```*
M````"M@```,````5V```%````!G8```6````+M@```(```!%V```!P```$C8
M```0````4-@```T```!AV```#P```&_8```/````?]@```@```"/V```#P``
M`)C8```=````J-@```H```#&V```!P```-'8```)````V=@```D```#CV```
M"0```.W8```$````]]@``!````#\V```!0````W9```'````$]D```4````;
MV0``"@```"'9```#````+-D```T````PV0``!0```#[9```'````1-D```0`
M``!,V0```@```%'9```&````5-D``!````!;V0``!````&S9```,````<=D`
M`!$```!^V0``!P```)#9```=````F-D``"T```"VV0``%0```.39```'````
M^MD``"@````"V@``*````"O:``!8````5-H``#$```"MV@``#P```-_:```,
M````[]H``!(```#\V@``'P````_;```)````+]L```L````YVP``'@```$7;
M```P````9-L``#0```"5VP``%0```,K;```)````X-L``!````#JVP``!0``
M`/O;```)`````=P```H````+W````P```!;<```,````&MP``!0````GW```
M#P```#S<```0````3-P``!D```!=W```$@```'?<```6````BMP``!,```"A
MW```(````+7<```)````UMP``!4```#@W```%0```/;<```%````#-T```8`
M```2W0``!````!G=```$````'MT```<````CW0``"@```"O=```(````-MT`
M`!L````_W0``#P```%O=```)````:]T``!<```!UW0``.````(W=```O````
MQMT``#X```#VW0``-P```#7>```U````;=X``$X```"CW@``*````/+>```M
M````&]\``!T```!)WP``%@```&??```&````?M\```,```"%WP```P```(G?
M```?````C=\``"@```"MWP``#P```-;?```@````YM\```D````'X```'```
M`!'@```(````+N````H````WX```"@```$+@```+````3>````8```!9X```
M#````&#@```.````;>````@```!\X```"````(7@```0````CN````T```"?
MX```#````*W@```,````NN````(```#'X```!0```,K@```"````T.```#P`
M``#3X```-@```!#A```/````1^$```H```!7X0``8@```&+A```=````Q>$`
M`!````#CX0``$````/3A```%````!>(```<````+X@``!````!/B```$````
M&.(```4````=X@```0```,H"``#-````J````%L"``!/`0```````!`#````
M````U@```)L```#.````3@,``$0"``!$`0``````````````````````````
M```Q`P``'P```%0```#=`0``-@```,P!``"U`@``A0$```````"C`0``````
M`,\!```A`P```````(0!````````ZP(`````````````\P(``%$"```(`@``
M`````#H#```G`0````````````""`@``#P(``(P!```6`@``M@```(T!``"2
M`@``/0$```````#V````]`(```````!&`0``:````&D"``#N````%P$``*0`
M``"Z`````P```(@!``!.`0``V`$```0!``````````````X"``#H`@``````
M`````````````````$4!``#W`````````+X!``!6````.P,```````"!`@``
M%`,````````E`@```````&L"``!#`P```````)P!```-`````@(``%````#_
M````!P,``$`#```8`0```````-,````2````"0```%T"`````````````$D"
M``"9````4P```&8"``#W`0```````+<```!8`0``&@$``!8#``!S`0``````
M````````````Q`````L!```N`0``A@```*P```!4`0``WP``````````````
M```````````.`0``I@```!`"````````T0$```````````````````@````Q
M`@``RP```&4```"L`0`````````````H`0``E0$``#,#``#D````)@,``/X`
M````````\@```!T!``!E`0````````````#E`@``L0(```````"#````U`(`
M`````````````````*X```!9````+P$````````E`P```0$``*@"```3`0``
M9`$``+T```!^````,P````````"Q`````````),!``#U`@``$@,``.4```#L
M`@```P$``+`!```V`@``FP$``)T!````````#0,``,T"````````.@(`````
M```3`P``0P(```````#_`0``BP```!L"```1`````````#4"```0````````
M`%8"``````````````````!+`0```````!L```````````(``'`````:````
M#`$``(H!``#<````#`(``%4"``#3`0```````!<``````````````.`!``!(
M`````@$``"P```!F`````````!$#``!2``````````L#``!!`P``_`$`````
M```/`0``H`(``'P"``#'`0``/@```$(#````````.@$``*T!``!-`@``P@$`
M```````A````UP```````````````````+(!```=`````````*P"``#^`@``
M,`$```````!<`@````````````!&`@```````,H!```M`0``D````$L"``##
M`0```````-`!```%`@``_`(``$4"``!@````;0`````````-`@```````!0!
M``#%`````````+0```!R`0``NP$``%H!``"4`0``$P```%$!````````````
M`#0```!*````*0(``"T#``#_`@``;P(``#H```!!`@``>`(````````;`0``
ML@(`````````````"@,``/H"````````>````&H````Q`0``]`````````#G
M`@``3@```$D!``!5````'P$``(@```".````+@```$@!``!?````80(`````
M``!"`````````*<`````````V@$``$$```#Q`0``J0$``)@```"O````-0$`
M`!\"``!P`0``AP$``(L!``"_`@````````````!2`0```````%D!```<`@``
M``````````#]````Q@````$"``!H`@````$``*<"``#P`0``>P``````````
M````^0(``%X````W`0```````&`!``#:```````````````]`@```````'H"
M````````E`(``!D#``"A`@``,P$``.H!``!5`0``D0$``$H"``!B````*0$`
M``````"U`````````(8"``````````````````#[`0``0`````,"``"0`0``
M``````````"C`````````*<!``"6`@``]@$``&0"```*````#0$``-D!``#G
M`0``XP(``)D!```X`0``@@$``*$```#.`@```````$D```!%````````````
M``!*`0``B0```-\!``"``````````!@`````````\````/@"```9`@``````
M`'8"``"<``````````@!``"J`@`````````````"````````````````````
M[0$``+X`````````;P$``'4"``#$`@``<0(``)`"``!T`0``40,``(0`````
M`````````)X!``"<`@``(P(``(H``````````````),```#8````8@(``#@#
M``#,````5P```.L!``"%`@``R`$``*T"``!8````_0$``!H#```<`P``+@(`
M`'T!```\`0``Z0$```8#````````F@```.,!``!,`@``30,```````"K`0``
M```````````````````````````M`@``X@````8"```@`0````````````!T
M`@````````P```"F`@```````+@```##`@``L````(,!````````2@,``,\`
M``#&`0``1````!@#``#7`@``ZP````````"Y````;````',```#X````BP(`
M`*H```!L`@``Q`$``)D"``"Y`0``D@``````````````9P```(X"```)`@``
M;`$``#@"````````Z@(```$#```R`0```@,``$4#```'`@```````!X#````
M````O@(``$<!``#5`0``-P,``"@```!;````````````````````4P(``,$`
M``"5````/`(``/X!``"E`0``K@(```````#W`@``D0```-4"```D`0``````
M`(`!``#I`````````%<"```E````70$``/P```"N`0````````0"```\````
MM@(``"````!/`P``OP$``!D````B`@``<`(``(D"````````(`(``%T`````
M````.0$``,L"``"@`0``&@(`````````````*@````````!9`@``V0(``.8`
M``!G`0```````+P!```[`0``N`(``"P"``"K````?`$``'@!````````````
M`+T!````````Y0$``,P"``!``0``%0```)T"````````8@$``,D!````````
M`````)\!```D`P``J@$```````#U`0``T`(``-L```#Z`````````!`!````
M````B0$``*(!``#3`@``CP$``*\"`````````````(\`````````8P$`````
M``!A````H````#\!```_`P``[P$````````C`P``'@(`````````````L`(`
M`$X"```3`@``?`````````!6`0``MP(```````!;`0``&P,```H"``",````
ML0$````````K`0```````(X!``!"`0``"0,````````\`P``+P(``"H#```%
M````%0,``*0!``"5`@``$0$``+P"``"!`0``NP````````#;`@``&`(`````
M``"$`@``0@(``$<"``!H`0``1@,`````````````5`(``/,```!W`@``!`,`
M`,$!``!-````````````````````W@(``(T```!<````[0```"L`````````
MX@$``"8"``#L````\`(```````"*`@``E@$``"D```"!`````````-0`````
M`````````)X``````P``3````(`"````````#P```*\!``!^`0``,````,H`
M```2`@``*P,``'("``"1`@``]@(````````5`@``XP````````!E`@``W`$`
M`#L"``#/`@```````*$!```U`P``AP```/L"````````=@$``",!````````
M=P```'(``````````````"@"``!K`0``T0(``!X!````````"`,``'D`````
M````+P````````"U`0``F`(``+@!``"B`@``(0(``"H!``#]`@```````%$`
M``"H`0``W@$```````"(`@``'0(```````"%````^P```#T`````````Z@``
M``````#6`0`````````````%`P``Z0(``(<"``!-`0``+@,``&X"``!_````
M'````-<!``"7`0``[P(``,`"``#.`0``0`(``````````````````-H"```A
M`0``^0````````"7````-P(``"<"``!7`0``J0(``-8"```D`@``O0(``,@`
M``!M`@``.0,``"L"``!J`@```````#(```"S`0``7`$``,("``!?`0``$0(`
M`)X"```]`P``M@$``.<```!@`@``:0``````````````F@$``.@`````````
M`````/D!``"I````HP(````````.`P``\0(```````#-`0``[P``````````
M````2`,``.$"```G`P``+`,```````!_`@``M`(```````"?`@``:@$`````
M````````6@(``$,!``!8`@``7@$``.`"````````;@`````````6`0``````
M`.X"``#``0``WP(``"8```#>````,`(``((`````````VP$```````#0````
M"0$`````````````FP(```L````P`P``!P```,8"```2`0``+P,``"0`````
M````CP(``.X!```^`@``Y`(````````+`@``R`(``*4````7`P``1@```#(#
M``"E`@`````````````Q````<0```#D"```B````?0```-D```!Y`@``````
M`!4!``!!`0````````````#)``````````````!,`P``\@$``.P!```B`P``
M'P,``#0"```&`0``%P(``+<!``"T`0`````````````#`P``X`````````##
M````K0```,(``````````````"@#````````NP(``&,````$````T@$``.0!
M```T`P``7P(````````@`P``T0```````````````````#\"````````'`$`
M`"4!``"D`@``/@,``/0!```^`0``@P(``*L"```,`P``=@```%X"```F`0``
MOP```.8!``!Z````-@,``&\```"6````Y@(``&,"``!'````W0(```````!Y
M`0``\@(``.("``!_`0``:P```+D"````````-`$``-("````````#@```,<`
M````````!P$``,<"````````````````````````;0$``+H!``"3`@``;@$`
M`$D#``#4`0``1P,``#<``````````````#("``"=````'@```(P"``!U`0``
M/P```#8!```/`P``^@$``+(````9`0``'0,```````"4````Q0(``'H!```&
M````(@$``-(```#%`0```````/,!```U````=0`````````4````X0```#D`
M````````[0(``"D#```S`@``9P(```````!^`@``P0(``&D!````````%`(`
M`.$!```M````6@```%`"``!/```````````````%`0``.P```$L`````````
M3P(```````!Q`0``R0(``"<```"Z`@````````````"\````.````$P!````
M````>P$``&0`````````9@$```````#=````(P```*(```!(`@``4`$``$L#
M```J`@``=P$``,````"&`0``V`(``!8`````````80$``*8!````````=```
M`)@!``````````````H!``"-`@```````'T"``!$`P``\0``````````````
M>P(``"P!``#5````LP```%`#``"2`0``````````````````````````````
M````]0```%,!``!#````EP(``/@!``"S`@``4@(```````":`@``````````
M``#<`@``<P(``.@!````````RP$``)\`````("8C,34Q.R`E<R!I<R!R96%D
M>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K
M960@8F5L;W<N`"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*&EN
M("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S=&5R9&%Y*0`@
M870@`"5D("5S(&%N9"`E<P`E9"!B>71E<R!W<FET=&5N+@`E9"!O9B`E9"!E
M;G1R:65S(&UA<FME9"!A<R!U<"UT;RUD871E`"5D+61A>2!F;W)E8V%S=``E
M<R`M($YO=&EC90`E<R!!9&UI;FES=')A=&EO;@`E<R!&:6YG97)P<FEN=``E
M<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N
M`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M96YT`"5S
M(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!H87,@8V%N8V5L;&5D
M("5S+@`E<R!H87,@<F5P;&EE9"!T;R!A(&9R964O8G5S>2!R97%U97-T+@`E
M<R!H87,@<F5P;&EE9"!T;R!T:&4@:6YV:71A=&EO;B!T;R`E<RX`)7,@:&%S
M('-E;G0@>6]U(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`)7,@:7,@;F]T('=R
M:71A8FQE+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N
M9"X`)7,@<F5Q=65S=',@>6]U<B!F<F5E+V)U<WD@:6YF;W)M871I;VXN`"5S
M(')E<75E<W1S('EO=7(@<')E<V5N8V4@870@)7,N`"5S('1O("5S(&]F("5S
M`"5S('=I<VAE<R!T;R!A9&0@=&\@)7,N`"5S('=I<VAE<R!T;R!M86ME('EO
M=2!A=V%R92!O9B`E<RX`)7,@=VES:&5S('1O(')E8V5I=F4@=&AE(&QA=&5S
M="!I;F9O<FUA=&EO;B!A8F]U="`E<RX`)7,G<R!!9&1R97-S($)O;VL`)7,G
M<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`
M)R5S)R!I<R!N;W0@82!V86QI9"!C:&]I8V4N`"<E<R<@:7,@;F]T(&-O;F9I
M9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+@`G)7,G('=A<R!A9&1E9"!T
M;R!T:&4@9W)O=7!S('-Y<W1E;2X`)R5S)R!W87,@861D960@=&\@=&AE('!E
M<FUI<W-I;VYS('-Y<W1E;2X`)R5S)R!W87,@;F]T(&-R96%T960Z("5S+@`L
M('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`#$R($AO=7(@
M1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`$$@9&%T86)A<V4@8F%C
M:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O
M<B!H87,@;V-C=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T
M;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U
M:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0
M(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL
M('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV
M871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I
M=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U
M:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04TO4$T`06)O=70@=&AI<R!E
M9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E<'0@<F5Q
M=65S=`!!8V-E<'1E9`!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E
M8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V]U
M;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`06-T:6]N
M<P!!9&0`061D($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D
M9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@
M82!C:&EL9"!G<F]U<"!T;R`G)7,G`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@
M=&\@)R5S)P!!9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE
M;6)E<G,`061D('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3
M:61E8F%R`$%D9"!T:&ES('1O(&UY(&-A;&5N9&%R`$%D9"!T;R!A9&1R97-S
M(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D('5S97(`061D960@
M)R5S)R!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO
M;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N`$%D9&5D("<E<R<@=&\@=&AE
M('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+@!!9&1I;F<@;F5W(&9I;&5S
M('1O(')E<&]S:71O<GDZ`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D
M<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N
M<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S`$%L:6%S`$%L
M:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L
M;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L;&]W
M(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@
M;&ES="!T>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I
M;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R
M;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA
M=&5S`$%L=&5R;F%T92!T97AT.@!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C
M:69I960N`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`07!P;&EC871I;VX`07!P
M;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P;'D@=&\@
M0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P<F]X:6UA=&4@4VEZ90!!<F-H:79E
M($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT
M('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)E('EO
M=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92`G)7,G(&%N9"!A;GD@<W5B+6=R
M;W5P<S\`07)T`$%S8VEI($%R=`!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O
M<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`07-S:6=N;65N="!C
M;VQU;6YS`$%T=&%C:&5D(&ES(&%N(&E#86QE;F1A<B!F:6QE(')E<&QY('1O
M(&$@<F5Q=65S="!Y;W4@<V5N=`!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE
M>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E
M;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT
M('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S
M:&%R92X`071T96YD965S`$%T=')I8G5T97,`075S=')I80!!=71H7V-Y<G-Q
M;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y
M<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET
M97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF='`@<W=I=&-H
M+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I
M<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O
M(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U
M<V5R("5S`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I
M8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@
M4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F
M86EL960N`$%V86EL86)L92!F:65L9',Z`$%W86ET:6YG(%)E<W!O;G-E`$)/
M1D@@17AC=7-E<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D(&ME
M<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A<F4`
M0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@)R5S)R!N;W0@9F]U;F0N`$)A<V5L
M:6YE`$)E;&=I=6T`0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO
M;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!"
M;VQD`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R
M<P!";W1H`$)O='1O;0!"=6QL971E9"!,:7-T`$--4P!#4D,`0U),($1I<W1R
M:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#86QE;F1A<@!#
M86QM`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N
M=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B=T(&-O;FYE8W0@=&\@24U!
M4"!S97)V97(Z("5S`$-A;F%D80!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P
M;W)T`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A('1E
M;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D('=I=&AO=70@)W1A
M<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@
M(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N`$-A;FYO
M="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O
M<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#86YN;W0@<F]U
M=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#87!T:6]N`$-A=&5G
M;W)I97,@86YD($QA8F5L<P!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE<P!#
M96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E
M;&QP:&]N90!#96YT97(`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T
M92!0;VQI8VEE<P!#:&%I<B!097)S;VX`0VAA;F=E`$-H86YG92!T:&4@;F%M
M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@
M86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%R`$-H96-?:R!,:6YK+BXN
M`$-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@
M=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`$-H;V]S92!A('!A<W-W;W)D`$-H
M;V]S92!A('5S97)N86UE`$-H;V]S92!A;B!A8W1I;VXZ`$-H;V]S92!H;W<@
M=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R
M(&]R9&5R960@;&ES=',I`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O
M=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R(&]U="!U<V5R
M.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&EC:R!T;R!#;VYT
M:6YU90!#;&EC:V%T96QL('9I82!(5%10`$-L;W-E(%=I;F1O=P!#;&]U9',`
M0VQO=61Y`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E<G,`0V]L
M;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L=6UN('1I=&QE
M<P!#;VUI8W,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UA;F0@;W!T:6]N
M<SH`0V]M;6%N9',Z`$-O;6UE;G0`0V]M;6ET=&EN9SH`0V]M;6]N($YA;64`
M0V]M<&%N>0!#;VUP;&5T960`0V]M<&]S92!-97-S86=E("@E<RD`0V]M<'5T
M97)S`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF
M:6=U<F%T:6]N(&YE961S('5P9&%T:6YG+@!#;VYF:6=U<F4@)7,`0V]N9FER
M;2!087-S=V]R9`!#;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL
M960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V
M97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E
M<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F
M86EL960N`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO
M=7(@861D<F5S<R!B;V]K+@!#;VYT96YT<R!O9B`G)7,G`$-O;G1I;G5E`$-O
M;VMI90!#;W!Y`$-O<'D@<V5L96-T:6]N`$-O<'EI;F<@)7,@=&\@)7,`0V]U
M;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!01U`@<VEG
M;B!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`
M0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@
M8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O
M=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T
M;R!S97)V97(@)R5S)R!U<VEN9R!&5%`Z("5S`$-O=6QD(&YO="!C;W!Y("5S
M('1O("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S
M`$-O=6QD(&YO="!C<F5A=&4@;&]C86QE(&1I<F5C=&]R>2!F;W(@;&]C86QE
M("5S.@!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82X`0V]U;&0@;F]T(&1E
M8W)Y<'0@4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@
M)7,`0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U
M;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="`G)7,G+@!#;W5L
M9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S
M<RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U
M;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L
M9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N
M(&QI<W1S+@!#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2`G)7,G+@!#;W5L9"!N
M;W0@;6MD:7(@)R5S)RX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R
M;VT@=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO
M="!O<&5N("<E<R<@9F]R('=R:71I;F<N`$-O=6QD(&YO="!O<&5N($UA:6YT
M96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R
M>2`G)7,G+@!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H
M92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L
M;"!O9B!T:&4@9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O
M<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T
M:&5R(&AE;'`N`$-O=6QD(&YO="!R971R:65V92!!0TP`0V]U;&0@;F]T(')E
M=')I979E(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E=')I979E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I
M8G5T:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@
M8V%P86)I;&ET:65S`$-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BX`
M0V]U;&0@;F]T(')M9&ER("<E<R<N`$-O=6QD(&YO="!S879E("5S(&-O;F9I
M9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO
M;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#
M;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@)R5S)RX`
M0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N`$-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N
M(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V
M92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O
M9&4@8F5L;W<@=&\@)7,N`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R
M=F5R+@!#;W5L9"!N;W0@=6YL:6YK("<E<R<N`$-O=6QD(&YO="!U<&1A=&4@
M8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,`0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R("<E<R<Z
M("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S
M=7)E('1H92!S:61E8F%R(&ES(&]P96XN`$-O=6QD;B=T(&=I=F4@=7-E<B`G
M)7,G('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R("<E<R<Z
M("5S`$-O=6YT960@=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E871E`$-R96%T
M92!A(&QI;FL`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@<W5B(&9O;&1E<G,`
M0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`0W5R<F5N
M="!0:&%S90!#=7)R96YT(%1I;64`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@
M8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@
M<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U
M<P!$1`!$86EL>0!$871A`$1A=&%4<F5E($)R;W=S97(`1&%T90!$871E(%)E
M8V5I=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$95]L971E($-O;'5M;@!$96-E
M;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C;&EN960`1&5C<F5A<V4@26YD96YT
M`$1E9F%U;'0`1&5F875L="!#;VQO<@!$969A=6QT($ED96YT:71Y`$1E9F%U
M;'0@4&5R;6ES<VEO;G,`1&5F875L="!P97)M:7-S:6]N<P!$969I;FET:6]N
M<P!$96QE9V%T92!P;W-I=&EO;@!$96QE9V%T960`1&5L971E`$1E;&5T92!'
M<F]U<`!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A
M9V5S`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG
M(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("<E
M<R<`1&5L971E('!E<FUI<W-I;VYS(&9O<B`G)7,G(&%N9"!A;GD@<W5B+7!E
M<FUI<W-I;VYS/P!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET
M>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N
M="!R;W<`1&5L971E('1H:7,@<&5R;6ES<VEO;B!A;F0@86YY('-U8BUP97)M
M:7-S:6]N<S\`1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="`G)7,G+@!$
M96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5N>2!R97%U97-T`$1E;GD@<F5Q=65S
M="!F;W(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N`$1E<V-R:6)E('1H92!0<F]B
M;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F
M:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI
M<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@
M;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG
M:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D@
M,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9F]R96-A
M<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES<&]S:71I;VX@3F]T:69I8V%T
M:6]N`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN
M=&5N86YC92YP:'``1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I
M96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;W=N;&]A9`!$
M;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T
M+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA:6P`15)2`$5D:70`161I="!"
M;&]C:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I
M;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z
M`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D:70@<&5R;6ES<VEO;G,@9F]R
M("<E<R<`161U8V%T:6]N`$5L96UE;G0N+BX`16T`16UA:6P`16UA:6P@061D
M<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UA:6P@=VET:"!C
M;VYF:7)M871I;VX`16UO=&EC;VYS`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E
M<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N86)L92!I;G-E<G1I;VX@;V8@
M:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N86)L92!R
M:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N9`!%;F0@>65A<@!%;FQA<F=E
M($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W
M:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@<&%S<W=O
M<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SH`16YT
M97(@=&AE(&EM86=E(%523"!H97)E`$5R<F]R`$5R<F]R('-E;F1I;F<@<F5P
M;'DZ("5S+@!%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N`$5R<F]R('=R:71I
M;F<@)R5S)RX`17)R;W(Z(`!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R
M>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`
M179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M
M<&QE('9A;'5E<SH`17AE8W5T90!%>&5C=71I;F<Z`$5X<&%N9`!%>'!A;F0@
M4VED96)A<@!%>'!E8W1E9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R('%U
M;W1E9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`1D<@
M0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN9R!P
M<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N
M`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C
M;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D
M('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V
M92!T;R`B)7,B+@!&86ER`$9A=&%L($5R<F]R.@!&87@`1F5B<G5A<GD`1F5E
M;',@3&EK90!&965L<R!L:6ME.B``1F5W(%-H;W=E<G,`1F5W(%-N;W<@4VAO
M=V5R<P!&:65L9"!M871R:7@`1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O
M=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@<V5L
M96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D
M+@!&:6QT97)S`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&:7@@<F%T:6\`
M1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@
M0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM
M86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN;W1E('1H870@
M=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI
M9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I
M9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&;W)T=6YE
M`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M<P!&;W)W
M87)D<P!&;W5N9"!A<'!L:6-A=&EO;G,Z("5S`$9O=6YD(&1I<F5C=&]R:65S
M.@!&<@!&<F%M97,`1G)E92]"=7-Y($EN9F]R;6%T:6]N`$9R964O0G5S>2!2
M97!L>0!&<F5E+T)U<WD@4F5Q=65S=`!&<F5E+T)U<WD@4F5Q=65S="!297-P
M;VYS90!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O
M;@!&=6QL($YA;64`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R
M>3H`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'
M971O<'0@17)R;W(Z(`!':79E;B!.86UE`$=O`$=O;V=L92!396%R8V@`1W)A
M>7-C86QE`$=R965C90!'<F5E;FQA;F0`1W)O=7`@061M:6YI<W1R871I;VX`
M1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O=7`@<&5R;6ES<VEO
M;G,`1W)O=7!S`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T('!E<FUI<W-I;VYS
M`$=U97-T8F]O:P!(2`!(5$U,`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@
M=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+@!(5$U,07)E82!C;W=A
M<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B
M;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L
M87-T(')O=R!I;B!T86)L92X`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U
M;F0N`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE:6=H=`!(96QP`$AE
M;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE
M(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(:7-T;W)Y(&5N=')Y(&YA
M;65S(&UU<W0@8F4@;F]N+65M<'1Y`$AO7VUE`$AO;64`2&]M92!!9&1R97-S
M`$AO;64@4&AO;F4`2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,
M(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@
M3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O2V]L
M86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,`
M2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`2&]R
M9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!S>6YC:')O;FES960@)7,@(B5S(@!(
M;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T
M:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA8FQE
M('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+
M;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA
M8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F
M('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E
M<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E
M('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(
M;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ
M`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!M
M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY
M(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O
M=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU
M;6]R:7-T<P!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0
M(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O
M=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S`$E0($%D9')E<W,@
M;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@
M0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)7VYS97)T(%)O
M=R!"969O<F4`26-O;G,@3VYL>0!)8V]N<R!F;W(@)7,`26-O;G,@=VET:"!T
M97AT`$ED96YT:71Y)W,@;F%M93H`268@:70@:7,@;F]T(&1I<W!L87EE9"!C
M;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+@!)9B!Y
M;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E
M<BP@>6]U(&UA>2!N965D('1O(&-H96-K('1H:7,@8F]X('1O('1U<FX@;V9F
M(%!.1R!T<F%N<W!A<F5N8WDN`$EF('EO=2!S964@=&AI<R!M97-S86=E(&)U
M="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG
M="!B92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+@!);6%G92!0<F5V:65W
M.@!);6%G92!54DP`26UA9V4@55),.@!);6%G92!F<F]M(&=A;&QE<GD`26UA
M9V4@9G)O;2!G86QL97)Y.@!);6%G92!U<&QO860`26UA9V5S`$EM<&]R="P@
M4W1E<"`E9`!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!)
M;B!0<F]C97-S`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C="!A8W1I;VX@
M8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R
M9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4
M<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U
M(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD:79I9'5A
M;"!5<V5R<P!);F9O`$EN9F]R;6%T:6]N`$EN<V5R="!#7V]L=6UN($%F=&5R
M`$EN<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN
M<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R
M('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T
M:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R
M<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@
M;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E
M`$EN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!)
M;G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R
M97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D
M.@!);G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T
M(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S
M<V%G97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H
M(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN
M<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S
M=&EO;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`
M26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I
M;VX@;&ES="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!);G9A;&ED
M($%C=&EO;B!S96QE8W1E9"!F;W(@=&AI<R!C;VUP;VYE;G0N`$EN=F%L:60@
M541(+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L:60@87!P;&EC871I;VXN
M`$EN=F%L:60@8F%T8V@@240N`$EN=F%L:60@9&%T82!S=6)M:71T960N`$EN
M=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI9"!F:6QE(&9O<FUA
M=`!);G9A;&ED(&US9U]T>7!E+@!);G9A;&ED(&]R(&UI<W-I;F<@87!I7VED
M+@!);G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV86QI9"!P87)E
M;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P<F]T;V-O;"X`26YV86QI9"!R96-I
M<&EE;G0Z("<E<R<`26YV86QI9"!S:&%R92!O8FIE8W0`26YV86QI9"!S;W5R
M8V4@861D<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN=F5N=&]R>0!)
M<V]L871E9"!4+5-T;W)M<P!)<W-U97(`271A;&EC`$IA;G5A<GD`2G5L>0!*
M=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`2V5E<"!O<FEG:6YA;#\`2V5R
M8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N96P@
M3F5W8FEE<P!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG
M=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!,85]Y;W5T`$QA;F=U86=E`$QA
M<W0@2&%L9@!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN
M.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R
M`$QA=P!,87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,969T`$QE
M9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I
M;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H="!286EN
M(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI
M9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K`$QI;FL`3&EN:R!P;VEN=',@=&\Z
M`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W
M:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O:VEE`$QI<W0@+2!U<V5R
M(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T($AE;'`@
M5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES
M="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T
M+55N<W5B<V-R:6)E`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QI=&5R
M871U<F4`3&]A9&EN9R!L:6)R87)I97,N+BX`3&]A9&EN9RXN+@!,;V-A;"!T
M:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@;W5T
M`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA
M;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN
M(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE='1E
M<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!-30!-86EL`$UA=&-H:6YG(&9I96QD
M<P!-965T:6YG($-A;F-E;&QA=&EO;@!-965T:6YG($EN9F]R;6%T:6]N`$UE
M971I;F<@4')O<&]S86P`365E=&EN9R!297!L>0!-965T:6YG(%5P9&%T90!-
M965T:6YG(%5P9&%T92!297%U97-T`$UE;G4@;6]D93H`365S<V%G90!-;VYT
M:&QY`$UO=F4@9&]W;@!-;W9E('5P`$YA;64`3F5E9',@06-T:6]N`$YE=F5R
M`$YE=W,`3F5X=`!.97AT(%!A9V4`3F\`3F]N(%!A<G1I8VEP86YT`$YO;F4`
M3F]T97,`3F]T:6-E`$]+`$]F9FEC90!/<'1I;VYA;"!087)T:6-I<&%N=`!/
M<'1I;VYS`$]R9V%N:7II;F<`3W1H97(@26YF;W)M871I;VX`4&%S<W=O<F0`
M4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R<V]N86P@26YF;W)M871I
M;VX`4&AO;F4`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B
M;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R
M9`!0;&5A<V4@<F5V:65W('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VXL(&%N
M9"!T:&5N('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@;65N=2!B96QO=RX`
M4&QE87-E('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@;65N=2!B96QO=RX`
M4')E=FEE=P!0<F5V:6]U<R!086=E`%!R;V)L96T@1&5S8W)I<'1I;VX`4F5M
M96UB97(@=&AE(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`4F5M;W9E('!A:7(`
M4F5P;'D@4V5N="X`4F5P;'D@=VET:"!.;W0@4W5P<&]R=&5D($UE<W-A9V4`
M4F5P;'D@=VET:"!F<F5E+V)U<WD@9F]R(&YE>'0@,B!M;VYT:',N`%)E<&QY
M('=I=&@@<F5Q=65S=&5D(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`4F5Q=6ER
M960@4&%R=&EC:7!A;G0`4F5S970`4F5T=7)N('1O($]P=&EO;G,`4F]L90!3
M879E`%-A=F4@3W!T:6]N<P!396%R8V@`4V5L96-T(&$@9&%T90!396QE8W0@
M=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!3
M96QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I
M96QD<RX`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD($QA
M=&5S="!);F9O<FUA=&EO;@!396YD(%!R;V)L96T@4F5P;W)T`%-I9VX@=7`@
M:68@;F]T(')E9VES=&5R960`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-P96-I
M86P@0VAA<F%C=&5R($EN<'5T`%-T87)T`%-T871U<P!3=6)J96-T`%-U8FUI
M=`!3=6-C97-S`%-U;6UA<GD`5&%S:W,`5&5N=&%T:79E;'D@06-C97!T(')E
M<75E<W0`5&5N=&%T:79E;'D@06-C97!T960`5&5X="!/;FQY`%1H92!C86QE
M;F1A<B!D871A(&ES(&EN=F%L:60`5&AE('1A<VL@:&%S(&)E96X@861D960@
M=&\@>6]U<B!T87-K;&ES="X`5&AE('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M
M871I;VX@=V%S('-U8V5S<V9U;&QY('-T;W)E9"X`5&AE<F4@=V%S(&%N(&5R
M<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@979E;G0Z("5S+@!4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!T87-K.B`E<RX`5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N.B`E
M<RX`5&AI<R!A8W1I;VX@:7,@;F]T('-U<'!O<G1E9"X`5&AI<R!A8W1I;VX@
M:7,@;F]T('EE="!I;7!L96UE;G1E9"X`5&AI<R!N=6UB97(@;75S="!B92!A
M="!L96%S="!O;F4N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&ET
M;&4`5&\`55),`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N
M86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N9&\@0VAA
M;F=E<P!5;FAA;F1L960@8V]M<&]N96YT(&]F('1Y<&4Z("5S`%5N;F%M960`
M57!D871E(')E<W!O;F1E;G0@<W1A='5S`%5P;&]A9`!5<V5R($]P=&EO;G,`
M57-E<FYA;64`57-E<FYA;64Z`%9I97<@)7,`5FEE=R!E=F5N=`!6:65W('1A
M<VL`5V%R;FEN9P!7965K;'D`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!7
M;W)K($%D9')E<W,`5V]R:R!0:&]N90!960!996%R;'D`665S`%EO=2!M=7-T
M(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE
M('!R;V)L96T@<F5P;W)T+@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N
M(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!);F9O<FUA=&EO;@!9;W5R($YA
M;64`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O
M<'1I;VXN(%!R97-S($-O;G1R;VPO3W!T:6]N("L@4"!T;R!P<FEN="X`66]U
M<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!;4')O8FQE;2!297!O<G1=
M`%ML:6YE("5S(&]F("5S70!?2&5L<`!?3&]G(&]U=`!?3W!T:6]N<P!N86UE
M`'9#87)D`%!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@,RXP+C0*4F5P;W)T
M+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T
M:6]N+41A=&4Z(#(P,#4M,#4M,3@@,3(Z-#,K,#(P,`I03RU2979I<VEO;BU$
M871E.B`R,#`U+3`U+3$X(#$T.C,W*S`R,#`*3&%S="U4<F%N<VQA=&]R.B!'
M96ER($\N($AO9V)E<F<@/&AO<F1E0'-K>61I=F5R+FYO/@I,86YG=6%G92U4
M96%M.B!.;W)W96=I86X@*$)O:VUA;"D@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G
M/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[
M(&-H87)S970]:7-O+3@X-3DM,0I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG
M.B`X8FET"@`@)B,Q-3$[("5S(&5R(&ML87(@9F]R(.4@=71F^')E('9E9&QI
M:V5H;VQD<V]P97)A<VIO;F5N92!S;VT@97(@=F%L9W0@;F5D96YF;W(N`"`H
M)7,@9&%G97(@<VED96XI`"`H:'5R=&EG=&%S="`E<RD`("AI;FYE;B`E<R!D
M86=E<BD`("AI(&1A9RD`("AI(&UO<F=E;BD`("AI(&?E<BD`(&1E;B``)60@
M)7,@;V<@)7,`)60@8GET97,@<VMR979E="X`)60@878@)60@;W!P9OAR:6YG
M97(@;6%R:V5T('-O;2!O<'!D871E<G0`)60M9&%G97)S('9A<G-E;``E<R`M
M(%1I;"!I;F9O`"5S(&%D;6EN:7-T<F%S:F]N`"5S($9I;F=E<G!R:6YT`"5S
M($M"`"5S('9E9&QI:V5H;VQD<V]P97)A<VIO;F5R("T@0F5K<F5F=&5L<V4`
M)7,@:6YS=&EL;&EN9V5R`"5S(')E9VES=')E<FEN9P`E<R!A=G1A;&5V:6QK
MY7(`)7,@9FEN;F5S(&%L;&5R961E+@`E<R!PY2`E<R`E<P`E<R!H87(@:V%N
M<V5L;&5R="`E<RX`)7,@:&%R(&)E<W9A<G0@96X@9F]R97-P^')S96P@;VT@
M:6YF;W)M87-J;VX@86YGY65N9&4@;&5D:6<O;W!P=&%T="X`)7,@:&%R('-V
M87)T('#E(&EN=FET87-J;VYE;B!T:6P@)7,N`"5S(&AA<B!S96YD="!D96<@
M:6YF;W)M87-J;VX@;VT@;&5D:6<O;W!P=&%T="X`)7,@97(@<VMR:79E8F5S
M:WET=&5T+@`E<R!E<B!PY6MR979D`"5S(&UI;G5T=&5R`"5S(&EK:V4@9G5N
M;F5T+@`E<R!F;W)E<W#X<B!I;F9O<FUA<VIO;B!O;2!NY7(@9'4@97(@;&5D
M:6<O;W!T=&%T="X`)7,@9F]R97-P^'(@9&EN(&1E;'1A9V5L<V4@<.4@)7,N
M`"5S("T@)7,@878@)7,`)7,@^&YS:V5R(.4@;&5G9V4@=&EL("5S+@`E<R#X
M;G-K97(@Y2!G:OAR92!D96<@;W!P;65R:W-O;2!PY2`E<RX`)7,@^&YS:V5R
M(.4@;6]T=&$@9&5N('-I<W0@;W!P9&%T97)T92!I;F9O<FUA<VIO;F5N(&]M
M("5S+@!!9&1R97-S96)O:R!F;W(@)7,`2V%L96YD97(@9F]R("5S`$YO=&%T
M8FQO:VL@9F]R("5S`$]P<&=A=F5L:7-T92!F;W(@)7,`)7,Z("5S`"<E<R<@
M97(@:6MK92!E="!G>6QD:6<@=F%L9RX`)R5S)R!E<B!I:VME(&-O;F9I9W5R
M97)T(&D@2&]R9&4@4F5G:7-T97)E="X`)7,@8FQE(&QA9W0@=&EL(&=R=7!P
M97-Y<W1E;65T+@`G)7,G(&)L92!L86=T('1I;"!R971T:6=H971S<WES=&5M
M970N`"5S(&)L92!I:VME(&]P<')E='1E=#H@)7,N`"P@=F%R:6%B96P@;65L
M;&]M("5S(&]G("5S`"TM('9E;&<@+2T`,3(@5&EM97)S(&9O<FUA=``R-"!4
M:6UE<G,@9F]R;6%T`#(T('1I;65R`$5N(&1A=&%B87-E:V]B;&EN9R!E<B!P
MY6MR979D(&9O<B!D96YN92!B;&]K:V5N+@!%;B!F871A;"!F96EL(&AA<B!O
M<'!S=.5T=`!%;B!O9F9E;G1L:6<@4$=0+6[X:VME;"!E<B!PY6MR979D(&9O
M<B#E(&MR>7!T97)E(&UE;&1I;F=E;BX`16X@;V9F96YT;&EG(%!'4"UN^&MK
M96P@97(@<.5K<F5V9"!F;W(@Y2!V97)I9FES97)E('-I9VYE<G0@;65L9&EN
M9RX`16X@;V9F96YT;&EG(%!'4"UN^&MK96PL('!R:79A="!01U`M;OAK:V5L
M(&]G('!A<W-P:')A<V4@97(@<.5K<F5V9"!F;W(@Y2!D96MR>7!T97)E(&5N
M(&UE;&1I;F<N`$5N(&]F9F5N=&QI9R!01U`M;OAK:V5L+"!P<FEV870@4$=0
M+6[X:VME;"!O9R!P87-S<&AR87-E(&5R('#E:W)E=F0@9F]R(.4@<VEG;F5R
M92!E;B!M96QD:6YG+@!%;B!O9F9E;G1L:6<@4R]-24U%+6[X:VME;"P@<')I
M=F%T(%,O34E-12UN^&MK96PL(&]G('!A<W-P:')A<V4@97(@<.5K<F5V9"!F
M;W(@Y2!D96MR>7!T97)E(&5N(&UE;&1I;F<N`$5N(&]F9F5N=&QI9R!3+TU)
M344M;OAK:V5L+"!P<FEV870@4R]-24U%+6[X:VME;"P@;V<@<&%S<W!H<F%S
M92!E<B!PY6MR979D(&9O<B#E('-I9VYE<F4@96X@;65L9&EN9RX`16X@;V9F
M96YT;&EG(%,O34E-12UN^&MK96P@97(@<.5K<F5V9"!F;W(@Y2!K<GEP=&5R
M92!E;B!M96QD:6YG+@!!32]030!/;2!D96YN92!E9&ET;W)E;@!/;2XN+@!!
M8G-O;'5T="!N961E<G-T`$%B<V]L=71T(&UI9'0`1V]D:VIE;FX@9F]R97-P
M^')S96P`1V]D=&%T=`!4:6QG86YG(&YE:W1E="!V960@;W!P<F5T=&5L<V4@
M878@5D93(&MA=&%L;V<N`%1I;&=A;F<@;F5K=&5T('9E9"!O<'!R971T96QS
M92!A=B!61E,@9FEL+@!+;VYT;R!087-S;W)D`$MO;G1O(&9R^'-E="X`0F]K
M:&]L9&EN9R]!8V-O=6YT:6YG`$AA;F1L:6YG97(`3&5G9R!T:6P`3&5G9R!T
M:6P@=6YD97)G<G5P<&4`3&5G9R!T:6P@=6YD97)R971T:6=H971E<@!,96=G
M('1I;"!H97(Z`$QE9V<@=&EL(&YY(&=R=7!P90!,96=G('1I;"!N>2!R971T
M:6=H970`3&5G9R!T:6P@96X@=6YD97)G<G5P<&4@=&EL("<E<R<`3&5G9R!T
M:6P@=6YD97)R971T:6=H970@=&EL("<E<R<`3&5G9R!T:6P@;GD@8G)U:V5R
M.@!,96=G('1I;"!K;VQO;FYE`$QE9V<@=&EL(&YY92!M961L96UM97(`3&5G
M9R!T:6P@<&%R`$QE9V<@=&EL("5S(&UE;GEE;B!S;VT@36]Z:6QL82!3:61E
M8F%R`$QE9V<@=&EL(&D@;6EN(&MA;&5N9&5R`$QE9V<@=&EL(&D@861D<F5S
M<V5B;VLZ`$QE9V<@=&EL(&D@;6EN(&%D9')E<W-E8F]K`$QE9V<@=&EL(&)R
M=6ME<@!,82!T:6P@)R5S)R!I('-Y<W1E;65T+"!M96X@:W5N;F4@:6MK92!L
M96=G92!T:6P@96MS=')A(')E9VES=')E<FEN9W-I;F9O.B`E<RX`3&$@)R5S
M)R!T:6P@<WES=&5M970N($1U(&MA;B!L;V=G92!I;FX@;N4N`$QA('1I;"!N
M>64@9FEL97(@:2!R97!O<VET;W)Y.@!-=6QI9VAE="!F;W(@Y2!L96=G92!T
M:6P@;GEE(&)R=6ME<F4@97(@9&5A:W1I=F5R="X`061R97-S90!!9')E<W-E
M($)O:P!!9&UI;FES=')E<B`M('-E='0@<F5T=&EG:&5T97(@9F]R(&%N9')E
M(&)R=6ME<F4`061M:6YI<W1R87-J;VX`4F5K;&%M97(`06QI87,`2G5S=&5R
M90!*=7-T97)I;F<Z`$%L;&4`06QL92!A=71E;G1I<V5R=&4@8G)U:V5R90!!
M;&QE($=R=7!P97(`06QL92!R961D:6=H971E<@!!;&QE(&9I<F4@<VED97(`
M5&EL;&%T="!F;&5R92!A9')E<W-E<@!4:6QL871T(&5N9')I;F<@878@9F]R
M;6%T970@<.4@;G5M;65R97)T92!L:7-T97(_`$5K<VES=&5R97(@86QL97)E
M9&4`06QT97)N871I=B!)35-0($QO9VEN`$%L=&5R;F%T:79T($E-4U`@<&%S
M<V]R9`!!;'1E<FYA=&EV="!)35-0(&)R=6ME<FYA=FX`06QT97)N871I=B!E
M+7!O<W0@861R97-S90!!;'1E<FYA=&EV92!M86QE<@!!;'1E<FYA=&EV('1E
M:W-T.@!%;B!U;&]V;&EG('9E<F1I('9A<B!O<'!G:71T+@!!;F]N>6T@4')O
M>'D`4W9A<@!0<F]G<F%M`%!R;V=R86UL:7-T90!0<F]G<F%M;65T(&5R(&ML
M87)T+@!/<'!D871E<B!O9W/E(')E:W5R<VEV="!N961O=F5R(&9O<B!U;F1E
M<FUA<'!E<B]F:6QE<@!';V1K:F5N;@!/;71R96YT;&EG('-T^')R96QS90!&
M:6QS=/AR<F5L<V4@<.4@87)K:79E=`!!<FMI=FYA=FX`17(@9'4@4TE+2T52
M('#E(&%T(&1U('9I;"!F:F5R;F4@<F5G:7-T<F5R:6YG<V9O<F5S</AR<V5L
M96X@9F]R("5S/P!%<B!D=2!S:6MK97(@<.4@870@9'4@=FEL('-L971T92`G
M)7,G(&]G(&1E;G,@=6YD97)G<G5P<&5R/P!+=6YS=`!!<V-I:2!K=6YS=`!"
M92!O;2!B96MR969T96QS92!F^'(@9VIE;FYO;6;X<FEN9R!A=B!V961L:6ME
M:&]L9'-O<&5R87-J;VYE<@!+;VQO;FYE86YV:7-N:6YG`%9E9&QA9W0@:2!S
M=F%R970@97(@96X@:4-A;&5N9&%R(&9I;"!F;W(@96X@9F]R97-P^')S96P@
M9'4@<V5N9'1E`$9O<G/X:W1E(.4@<VQE='1E(&5N(&=R=7!P92!S;VT@:6MK
M92!E:W-I<W1E<F5R+@!&;W)S^&MT92#E('-L971T92!E;B!R971T:6=H970@
M<V]M(&EK:V4@96MS:7-T97)E<BX`1F]R<_AK=&4@Y2!R961I9V5R92!E;B!R
M971T:6=H970@<V]M(&EK:V4@96MS:7-T97)E<BX`1F]R<_AK=&4@Y2!R961I
M9V5R92!E;B!D96QT(')E<W-U<G,@<V]M(&EK:V4@96MS:7-T97)E<BX`1&5L
M=&%G97)E`$%T=')I8G5T`-AS=&5R<FEK90!!=71H7V-Y<G-Q;#H@2V%N(&EK
M:V4@9FEN;F4@9&5N(&[X9'9E;F1I9V4@24U!4"!U='9I9&5L<V5N+@!!=71H
M7V-Y<G5S.B!"86-K96YD(&EN;F5H87(@:6MK92!N^&1V96YD:6<@9G5N:W-J
M;VYA;&ET970N`$%U=&A?8WER=7,Z($MA;B!I:VME(&9I;FYE(&1E;B!N^&1V
M96YD:6=E($E-05`@=71V:61E;'-E;BX`075T:%]F='`Z($MA;B!I:VME(&9I
M;FYE(&1E;B!N^&1V96YD:6=E($944"!U='9I9&5L<V5N+B!+;VUP:6QE<B!0
M2%`@;65D("TM96YA8FQE+69T<"X`075T:%]I;6%P.B!+86X@:6MK92!F:6YN
M92!D96X@;OAD=F5N9&EG92!)34%0('5T=FED96QS96XN`$%U=&A?:W)B-3H@
M2V%N(&EK:V4@9FEN;F4@9&5N(&[X9'9E;F1I9V4@:W)B-2!U='9I9&5L<V5N
M+@!!=71H7VQD87`Z($MA;B!I:VME(&9I;FYE(&1E;B!N^&1V96YD:6=E($Q$
M05`@=71V:61E;'-E;BX`075T:%]L9&%P.B!+=6YN92!I:VME(&QE9V=E('1I
M;"!B<G5K97(@)7,N(%-E<G9E<F5N('-A.B``075T:%]L9&%P.B!+=6YN92!I
M:VME(&9J97)N92!B<G5K97)E;B`E<P!!=71H7VQD87`Z($MU;FYE(&EK:V4@
M;W!P9&%T97)E(&)R=6ME<B`E<P!!=71H7VUC86PZ($MA;B!I:VME(&9I;FYE
M(&1E;B!N^&1V96YD:6=E($U#04P@=71V:61E;'-E;BX`075T:%]S;6)A=71H
M.B!+86X@:6MK92!F:6YN92!D96X@;OAD=F5N9&EG92!S;6)A=71H('5T=FED
M96QS96XN`$%U=&5N=&ES97)I;F<@9F5I;&5T`$%U=&5N=&ES97)I;F<@9F5I
M;&5T+B`E<P!!=71E;G1I<V5R:6YG(&YE:W1E="!A=B!2041)55,@=&IE;F5R
M+@!!=71E;G1I<V5R:6YG(&UO="!&5%`@=&IE;F5R96X@9F5I;&5T+@!4:6QG
M:F5N9V5L:6=E(&9E;'0Z`%9E;G1E<B!PY2!S=F%R`$)/1D@@17AC=7-E<P!"
M86MG<G5N;@!"86MG<G5N;G-F87)G90!&96EL(&ME<F)E<F]S('!A<W-O<F0N
M`$9E:6P@:V5R8F5R;W,@8G)U:V5R;F%V;BX`0FQA;FL`0F%S96MA=&%L;V<@
M9F]R(&=R869I:VL@)R5S)R!B;&4@:6MK92!F=6YN970N`$=R=6YN;&EN:F4`
M0F5L:6=A`$)U<G-D86<`0FQO:VL@(B5S(B!A=B!P<F]G<F%M;65T("(E<R(@
M8FQE(&EK:V4@9G5N;F5T+@!";&]K:R!I;FYS=&EL;&EN9V5R`$)L;VMK('1Y
M<&4`1F5T`$)O:VUE<FME<@!286UM90!286UM971Y:VME;'-E.@!286UM97(`
M0F5G9V4`0G5N;@!0=6YK=&QI<W1E`$--4P!#4D,`0U),($1I<W1R:6)U<VIO
M;G-P=6YK=&5R`$5G96YS:V%P97(@9F]R(&-?96QL92XN+@!+86QE;F1E<@!3
M=&EL;&4`2V%N(&EK:V4@;G5L;'-T:6QL92!P87-S;W)D(&%U=&]M871I<VLL
M(&MO;G1A:W0@9&EN(&%D;6EN:7-T<F%T;W(N`$MA;B!I:VME(&MO8FQE('1I
M;"!)34%0('1J96YE<F5N.B`E<P!+86YA9&$`079B<GET`$%V8G)Y="!P<F]B
M;&5M<F%P<&]R=`!+86X@:6MK92!S;&5T=&4@9FEL96X@(B5S(BX`2V%N(&EK
M:V4@9FEN;F4@96X@=&5M<"UK871A;&]G+@!+86X@:6MK92!F;W)T<V5T=&4@
M=71E;B`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!+86X@:6MK92!S;&5T=&4@
M:V%T86QO9V5N("(E<R(N`$MA;B!I:VME('-L971T92P@)60@8F%R;B!E:W-I
M<W1E<F5R+@!+86X@:6MK92!E;F1R92!R96MK96;X;&=E;BP@86YT86QL970@
M;W!P9OAR:6YG97(@=F%L9W0@9F]R(&]M<V]R=&5R:6YG('-T96UM97(@:6MK
M92!M960@86YT86QL970@;&%G<F5D92!O<'!F^')I;F=E<BX`2V%N(&EK:V4@
M<V5N9&4@;65L9&EN9V5N('1I;"!D970@<W!E<VEF:7-E<G1E(&YU;6UE<F5T
M+@!5=&1R86<`2V%T96=O<FEE<B!O9R!E=&EK971T97(`36]B:6QT96QE9F]N
M`$5G96YS:V%P97(@9F]R(&-E;&QE`$QU9G0@<G5N9'0@:6YN:&]L9"!A=B!C
M96QL93H`16=E;G-K87!E<B!F;W(@8V5L;&4`3'5F="!R=6YD="!C96QL96XZ
M`$UO8FEL=&5L969O;@!396YT97(`1&5T86QJ97(@9F]R('-E<G1I9FEK870`
M4F5T=&YI;F=S;&EN:F5R(&9O<B!S97)T:69I:V%T`$]R9'-T>7)E<@!%;F1R
M90!%;F1R92!N879N(&]G(&%D<F5S<V4@<V]M(&UO='1A:V5R92!S97(@;N5R
M(&1E(&QE<V5R(&]G('-V87)E<B!PY2!P;W-T96X@9&EN+@!496=N`%-J96M?
M:R!L:6YK+BXN`%9E;&<@9&4@;W!E<F%S:F]N96YE(&1U('9I;"!U=&;X<F4@
M;N4N`%9E;&<@971T('!A<W-O<F0`5F5L9R!E='0@8G)U:V5R;F%V;@!696QG
M(&AA;F1L:6YG.@!696QG(&AV;W)D86X@9'4@=FEL('9I<V4@9&%T;V5R.@!6
M96QG('-T:6P@<.4@;&ES=&5T>7!E("AF;W(@;G5M;65R97)T92!L:7-T97(I
M`$ML87-S961E9FEN:7-J;VX@9F]R("5S(&)L92!I:VME(&9U;FYE="X`2VQA
M<G0`1FIE<FX@35-/9F9I8V4@=&%G<P!&:F5R;B!B<G5K97(Z("5S`$9J97)N
M(&)R=6ME<@!&:F5R;B!B<G5K97)D871A`$ML:6MK(&9O<B#E(&9O<G1S971T
M90!#;&EC:V%T96QL('9I82!(5%10`$QU:VL@=FEN9'4`4VMY97(`4VMY970`
M4VSE('-A;6UE;B!S:61E;&EN:F5N`%-A;6UE;G-LY71T(')A;6UE`$9A<F=E
M`$9A<F=E=F5L9V5R`$9A<F=E=F%L9P!+;VQO;FYE+71I=&QE<@!496=N97-E
M<FEE<@!+;VUM86YD;P!+;VUM86YD;W9I;F1U`%9A;&<@9F]R(&MO;6UA;F1O
M.@!+;VUM86YD;V5R.@!+;VUM96YT87(`4VIE:VL@:6YN.@!686YL:6<@;F%V
M;@!&:7)M80!&97)D:6<`4VMR:78@;65L9&EN9R`H)7,I`$1A=&%M87-K:6YE
M<@!6:6QKY7(`1F]R<VMJ96QL97(@:2!I;FYS=&EL;&EN9V5N90!);FYS=&EL
M;&EN9V5R(&)E:/AV97(@;W!P9&%T97)I;F<N`$MO;F9I9W5R97(@)7,`0F5K
M<F5F="!P87-S;W)D`%1I;&MO8FQI;F<@;6ES;'EK=&5S+@!4:6QK;V)L:6YG
M(&UI<VQY:W1E<SH@`$MO8FQI;F=E;B!T:6P@9&5N(&]F9F5N=&QI9V4@;OAK
M:V5L=&IE;F5R96X@9F5I;&5T+@!+;V)L:6YG96X@=&EL(&1E;B!O9F9E;G1L
M:6=E(&[X:VME;'1J96YE<F5N(&9E:6QE="X@Q7)S86LZ("5S("@E<RD`2V]B
M;&EN9V5N('1I;"!&5%`@=&IE;F5R96X@;6ES;'EK=&5S+@!+;VYT86MT96YE
M(&)L92!L86=T('1I;"!A9')E<W-E8F]K96X`26YN:&]L9"!I("<E<R<`1F]R
M='-E='0`0V]O:VEE`$MO<&EE<@!+;W!I97(@=F%L9W0@;VURY61E`$MO<&EE
M<F5R("5S('1I;"`E<P!+=6YN92!I:VME(%!'4"UK<GEP=&5R92!M96QD:6YG
M`$MU;FYE(&EK:V4@4$=0+7-I9VYE<F4@;65L9&EN9P!+=6YN92!I:VME(&MR
M>7!T97)E(&UE;&1I;F=E;B!M960@4R]-24U%+@!+=6YN92!I:VME('-I9VYE
M<F4@;65L9&EN9V5N(&UE9"!3+TU)344N`$MU;FYE(&EK:V4@;&5G9V4@=&EL
M(&MO;G1A:W0Z("5S`%1I;&MO8FQI;F<@=&EL($Q$05`M<V5R=F5R(&9E:6QE
M="X`2W5N;F4@:6MK92!S:F5K:V4@=&EL9VIE;F=E;&EG(&MR961I='0N("5S
M`$ML87)T92!I:VME(.4@:V]B;&4@=&EL('1J96YE<F5N("<E<R<@=F5D(&)R
M=6L@878@1E10.B`E<P!+=6YN92!I:VME(&MO<&EE<F4@)7,@=&EL("5S`$MU
M;FYE(&EK:V4@;&%G92!D:7-T<FEB=7-J;VYS;&ES=&4N("5S`$MU;FYE(&EK
M:V4@;W!P<F5T=&4@;&]C86QE(&MA=&%L;V<@9F]R(&QO8V%L92`E<SH`2W5N
M;F4@:6MK92!D96MR>7!T97)E(%!'4"!M96QD:6YG+@!+=6YN92!I:VME(&1E
M:W)Y<'1E<F4@4R]-24U%(&UE;&1I;F<N`$ML87)T92!I:VME(.4@<VQE='1E
M(&MO;G1A:W0N("5S`$ML87)T92!I:VME(.4@<VQE='1E(&1I<W1R:6)U<VIO
M;G-L:7-T92X@)7,`2W5N;F4@:6MK92!S;&5T=&4@<V5T=7`@;W!P9W)A9&5R
M:6YG<W-C<FEP="`G)7,G+@!+=6YN92!I:VME(&9I;FYE(&UO='1A:V5R<R!E
M+7!O<W0@861R97-S92X`2W5N;F4@:6MK92!H96YT92!U="!H96QE(&%D<F5S
M<V5B;VME;BX`2W5N;F4@:6MK92!U="!H96QE(&1I<W1R:6)U<VIO;G-L:7-T
M96XN`$MU;FYE(&EK:V4@:&5N=&4@=70@:&5L92!L:7-T96X@;65D(&1I<W1R
M:6)U<VIO;G-L:7-T97(N`$MU;FYE(&EK:V4@;&%S=&4@:6YN('-T<F%T96=I
M("<E<R<N`$MU;FYE(&EK:V4@;W!P<F5T=&4@:V%T86QO9V5N("<E<R<N`$MU
M;FYE(&EK:V4@:&5N=&4@=70@;V9F96YT;&EG(&[X:VME;"!F<F$@;OAK:V5L
M=&IE;F5R96XN`$MU;FYE(&EK:V4@Y7!N92`E<RX`2W5N;F4@:6MK92#E<&YE
M("<E<R<@9F]R('-K<FEV:6YG+@!+86X@:6MK92#E<&YE($UA:6YT96YA;F-E
M7U1A<VLM;6]D=6QE;B`E<P!+=6YN92!I:VME(.5P;F4@:V%T86QO9V5N("<E
M<R<N`$MU;FYE(&EK:V4@;&5S92`E<P!+=6YN92!I:VME(&YU;&QS=&EL;&4@
M<&%S<V]R9&5T(&9O<B!D96X@9F]R97-P=7)T92!B<G5K97)E;BX@3F]E;B!E
M;&QE<B!A;&QE(&1E=&%L:F5N92!E<B!U<FEK=&EG92X@1F]R<_AK(&EG:F5N
M(&5L;&5R(&MO;G1A:W0@861M:6YI<W1R871O<F5N(&AV:7,@9'4@=')E;F=E
M<B!Y='1E<FQI9V5R92!H:F5L<"X`2W5N;F4@:6MK92!H96YT92!U="!!0TP`
M2W5N;F4@:6MK92!H96YT92!U="!A9')E<W-E8F]K+B`E<P!+=6YN92!I:VME
M(&AE;G1E('5T(&1I<W1R:6)U<VIO;G-L:7-T92X@)7,`2W5N;F4@:6MK92!H
M96YT92!U="!D:7-T<FEB=7-J;VYS;&ES=&4N("5S`$MU;FYE(&EK:V4@:&5N
M=&4@=70@:6YF;W)M87-J;VX@;VT@=&IE;F5R96YS(&9U;FMS:F]N86QI=&5T
M97(`2W5N;F4@:6MK92!R979E<G1E<F4@:V]N9FEG=7)A<VIO;F5N92X`2W5N
M;F4@:6MK92!F:F5R;F4@:V%T86QO9V5N("<E<R<N`$MU;FYE(&EK:V4@;&%G
M<F4@)7,@:V]N9FEG=7)A<VIO;BX`2W5N;F4@:6MK92!L86=R92!E;B!B86-K
M=7`@:V]N9FEG=7)A<VIO;BX`2W5N;F4@:6MK92!L86=R92!E;B!B86-K=7`@
M8V]N9FEG=7)A<VIO;CH@)7,`2W5N;F4@:6MK92!L86=R92!S971U<"!O<'!G
M<F%D97)I;F=S+7-C<FEP=&5T('1I;#H@)R5S)RX`2W5N;F4@:6MK92!L86=R
M92!B86-K=7`@:V]N9FEG=7)A<VIO;G-F:6QE;B`E<RX`2W5N;F4@:6MK92!L
M86=R92!K;VYF:6=U<F%S:F]N<V9I;&5N("5S+B!$=2!K86X@96YT96X@8F5N
M>71T92!D96<@878@96X@878@;75L:6=H971E;F4@9F]R(.4@;&%G<F4@9&%T
M82!T:6QB86ME('1I;"`E<R!E;&QE<B!K;W!I97)E(&MO9&5N('5N9&5R(&UA
M;G5E;'0@=&EL("5S+@!+=6YN92!I:VME('5T9OAR92!S^&L@<.4@3$1!4"!T
M:F5N97)E;BX`2W5N;F4@:6MK92!F:F5R;F4@)R5S)RX`2W5N;F4@:6MK92!O
M<'!D871E<F4@:V]N=&%K="X@)7,`2W5N;F4@:6MK92!O<'!D871E<F4@9&ES
M=')I8G5S:F]N<VQI<W1E;BX@)7,`2W5N;F4@:6MK92!S:W)I=F4@:V]N9FEG
M=7)A<VIO;B!F;W(@)R5S)SH@)7,`2W5N;F4@:6MK92!F:6YN92!-;WII;&QA
M(%-I9&5B87(N(%-J96MK(&%T(&1E;B!E<B#E<&5N+@!"<G5K97)E;B`G)7,G
M(&)L92!G:71T(&;X;&=E;F1E(')E='1I9VAE=&5R('1I;"!M87!P96X@)R5S
M)SH@)7,`5&%L="!T96MS=`!,86YD`$MU<G-E<@!/<'!R971T`$]P<')E='0@
M96X@;&EN:P!/<'!R971T(&5N(&YY`$]P<')E='0@=6YD97)M87!P97(`4F5T
M=&EG:&5T97(@9F]R(&5I97(`2W)E9&ET=&MO<G1N=6UM97(`1VIE;&1E;F1E
M(&9A<V4`1VIE;&1E;F1E('1I9`!':F5L9&5N9&4@=N9R`$=J96QD96YD92!U
M='-I:W1E<CH@`$=J96QD96YD92!S=&EL`%1I;'!A<W,@;W!P9V%V97(@<V]M
M(&MJ^')E<R!V960@:6YN;&]G9VEN9R!T:6P@)7,N`$ML:7!P('5T`$ML:7!P
M('5T('9A;&=T(&]M<N5D90!+>7!R;W,`1$0`1&%G;&EG`$1A=&$`1&%T851R
M92!U=&9O<G-K97(`1&%T;P!$871O($UO='1A='0`1&%T;R!V86QG`$1A9P!3
M;&5T="!K;VQO;FYE`$1E<V5M8F5R`$1E<VEM86QT86QL`$%V<VSE='0`4F5D
M=7-E<B!I;FYR>6MK`%-T86YD87)D`%-T86YD87)D(&9A<F=E`%-T86YD87)D
M:61E;G1I=&5T`%-T86YD87)D(')E='1I9VAE=&5R`%-T86YD87)D(')E='1I
M9VAE=&5R`$1E9FEN:7-J;VYE<@!$96QE9V5R('!O<VES:F]N`$1E;&5G97)T
M`%-L971T`%-L971T(&=R=7!P90!3;&5T="!R971T:6=H970`4VQE='0@;V<@
M9FIE<FX@;65L9&EN9V5R`%-L971T(&-E;&QE`%-L971T(&MO;&]N;F4`4VQE
M='0@96MS:7-T97)E;F1E(&%L=&5R;F%T:78@;6%L`$9J97)N(')E='1I9VAE
M=&5N92!T:6P@)R5S)P!&:F5R;B!R971T:6=H971E;F4@=&EL("<E<R<@;V<@
M86QL92!U;F1E<BUR971T:6=H971E<C\`4VQE='0@<F%D`%-L971T('9A;&=T
M(&ED96YT:71E=`!3;&5T="!G:F5L9&5N9&4@:V]L;VYN90!3;&5T="!G:F5L
M9&5N9&4@<F%D`%-L971T92!D96YN92!R971T:6=H971E;B!O9R!A;&QE('5N
M9&5R+7)E='1I9VAE=&5R/P!3;&5T="!S971U<"!O<'!G<F%D97)I;F=S+7-C
M<FEP="`G)7,G+@!,979E<FEN9W-T:60`1&%N;6%R:P!!=G-LY2!F;W)E<W#X
M<G-E;`!!=G-LY2!F;W)E<W#X<G-E;"!F;W(@;&5D:6<O;W!P=&%T="UI;F9O
M<FUA<VIO;@!"97-K<FEV('!R;V)L96UE=`!"97-K<FEV96QS90!$971A;&IE
M<B`H;V=SY2!I($AO<F1E)W,@;&]G9V9I;"DZ`$1E=&%L:F5R(&AA<B!B;&ET
M="!L;V=G970@9F]R(&%D;6EN:7-T<F%T;W)E;BX`571V:6ML:6YG`$1O9V=P
M=6YK=`!$;V=G<'5N:W0@9F]R(&1E;B!S:7-T92!T:6UE;CH@`$1O9V=P=6YK
M=#H@`%)E=&YI;F<@9G)A('9E;G-T<F4@;6]T(&CX>7)E`%)E=&YI;F<@9G)A
M(&CX>7)E(&UO="!V96YS=')E`$MA=&%L;V<`5FES(#(T+71I;65R<R!T:61E
M<C\`5FES;FEN9W-V86QG`%9I<R!F;W)V87)S96P@*%1!1BD`5FES;FEN9W-F
M;W)M870`365L9&EN9R!O;2!O<F1N:6YG`$EK:V4@<VQE='0`26MK92#E<&YE
M(&UA:6YE;F%N8V4N<&AP(&1I<F5K=&4`2W)Y<W,@878@:&5R(&AV:7,@9&5N
M(&;X<G-T92!R861E;B!I;FYE:&]L9&5R(&9E;'0M;F%V;F5T.@!,87-T(&YE
M9`!,87-T(&YE9"!G96YE<F5R="!K;VYF:6=U<F%S:F]N('-O;2!02%`@<V-R
M:7!T+@!.961T<F5K:W-L:7-T90!-961I<VEN97(`12UP;W-T`$524@!2961I
M9V5R`%)E9&EG97)E(&)L;VMK`%)E9&EG97(@1W)U<'!E`%)E9&EG97(@<F5T
M=&EG:&5T97(`4F5D:6=E<B!R971T:6=H=&5R`%)E9&EG97(@<F5T=&EG:&5T
M97(@9F]R("5S`%)E9&EG97(@=F%L9R!F;W(Z`%)E9&EG97(@<F5T=&EG:&5T
M97(@9F]R("5S`%)E9&EG97(@<F5T=&EG:&5T97(@9F]R("5S`$]P<&SF<FEN
M9P!%;&5M96YT+BXN`$5M`$4M<&]S=`!%+7!O<W1A9')E<W-E`$4M<&]S=&%D
M<F5S<V4@;>4@<W1E;6UE+@!%+7!O<W0@;65D(&)E:W)E9G1E;'-E`$;X;&5L
M<V5R`%1O;2!M96QD:6YG+@!4;VUT(')E<W5L=&%T+@!4^&T@<_AK96MR:71E
M<FEE<@!!:W1I=F5R(&UU;&EG:&5T(&9O<B#E('-E='1E(&EN;B!B:6QD97(@
M9G)A(&=A;&QE<FEE<B!I('1E:W-T96X_`$%K=&EV97)E(&CX>7)E:VQI:VL@
M;65N>3\`4VQU='0`Q7)S<VQU='0`1VKX<B!E9&ET;W)E;B!S=/AR<F4`4VMR
M:78@:6YN(&5T="!S:6MK97)H971S<W#X<G-MY6P@<V]M(&1U('9I;"!B;&D@
M<W!U<G0@;VT@:'9I<R!D=2#X;G-K97(@Y2!N=6QL<W1I;&QE('!A<W-O<F1E
M="!D:71T+"!F+F5K<RX@)VAV82!E<B!N879N970@<.4@:VKF;&5D>7)E="!D
M:71T/R<Z`%-K<FEV(&EN;B!A9')E<W-E;B!T:6P@8FEL9&5T(&AE<@!&96EL
M`$9E:6P@=F5D('-E;F1I;F<@878@<W9A<CH@)7,`1F5I;"!M960@92UP;W-T
M(&UE;&1I;F=E;BX`1F5I;"!V960@<VMR:79I;F<@=&EL("<E<R<N`$9E:6PZ
M(`!%=7)O<&$`2'9E<G0@,34N(&UI;G5T=`!(=F5R="`R+B!M:6YU='0`2'9E
M<G0@,S`N('-E:W5N9`!(=F5R="`U+B!M:6YU='0`2'9E<B!I;FYL;V=G:6YG
M`$AV97(@:&%L=G1I;64`2'9E<G0@;6EN=71T`$5K<V5M<&5L=F5R9&EE<CH`
M2VKX<@!+:OAR97(Z`%5T=FED`%5T=FED(%-I9&5B87(`1F]R=F5N=&5T("<I
M)P!&;W)V96YT970@8FQA;FMT(&]R9"!E;&QE<B!Q=6]T970@<_AK96MR:71E
M<FEE`%5T;/AP<V1A=&\`16MS<&]N96YT`$9O<F=R=6YN<V9A<F=E`$]P<&QA
M<W1I;F<@878@<V5T=7`@=FEA($944`!5=&AE;G1I;F<@878@:6YS=&EL;&EN
M9V5R(&9E:6QE="X`5&EL:V]B;&EN9R!T:6P@3$1!4"UT:F5N97(@9F5I;&5T
M+@!4:6QK;V)L:6YG('1I;"!334(M=&IE;F5R(&9E:6QE="X`1F5I;&5T('9E
M9"!K;W!I97)I;F<@9G)A("(E<R(N`$9E:6QE="!V960@:V]P:65R:6YG('1I
M;"`B)7,B+@!&96EL970@=F5D(&]P<')E='1E;'-E(&%V(&YY(%-!4TP@:V]B
M;&EN9RX`1F5I;&5T('9E9"!F;'ET=&EN9R!T:6P@(B5S(BX`4&5N="!VYG(`
M1F%T86P@1F5I;#H@`$9A>`!&96)R=6%R`$;X;&5S('-O;0!&^&QE<R!S;VTZ
M(`!&Y2!B>6=E<@!&Y2!S;OAB>6=E<@!&96QT;6%T<FES90!!;G1A;&P@9FEL
M97(Z("5S(&9I;&5R`$%N=&%L;"!F:6QE<CH@)7,@9FEL97(`1FEL8F5H86YD
M;&5R`$9I;&YA=FX`1FEL=F%L9P!,87-T(&]P<"!F:6QE<@!/<'!L87-T:6YG
M(&%V(&9I;&5R('-T^'1T97,@:6MK92X`1FEL=&5R`$;X<G-T92!H86QV;>5N
M90!&^')S=&4@:W9A<G1MY6YE`$9A<W0@9F]R:&]L9`!3;G4`1FQY=`!4Y6ME
M`$UA<'!E;B`E<R!E:W-I<W1E<F5R(&EK:V4`1F]N=&9A<F=E`$UA=`!&;W(@
M;F5T=&QE<V5R92!S;VT@:6MK92!S=/AT=&5R(&)I;&1E<@!&;W)V87)S96P@
M*%1!1BD`06YT86QL(&1A9V5R<R!F;W)V87)S96P@*';F<B!O8G,@<.4@870@
M9&5T(')E='5R;F5R=&4@9F]R=F%R<VQE="!I;FYE:&]L9&5R(&+E9&4@9&%G
M(&]G(&YA='0[(&5N('-T;W(@=F5R9&D@:&5R(&MA;B!R97-U;'1E<F4@:2!E
M;B!S=&]R(&)L;VMK*0!';&5M="!P87-S;W)D970_`%-K:F5M865R`%-K:F5B
M;F4O;'EK:V4`5'EP92!S:VIE8FYE+VQY:VME`%-K:F5B;F5R+VQY:VME`%-K
M:F5B;F5R+VQY:VME(#(`1F]R=6UE<@!6:61E<F5S96YD=&4`1F%N="!P<F]G
M<F%M;65N93H@)7,`1F%N="!K871A;&]G96YE.@!&<@!286UM97(`3&5D:6<O
M;W!P=&%T="UI;F9O<FUA<VIO;@!,961I9R]O<'!T871T('-V87(`3&5D:6<O
M;W!P=&%T="!F;W)E<W#X<G-E;`!3=F%R('#E(&QE9&EG+V]P<'1A='0@9F]R
M97-P^')S96P`1G)A`$9R82``1G5L;"!B97-K<FEV96QS90!&=6QL;>5N90!&
M=6QL="!N879N`$=A;&QE<FD@9'4@^&YS:V5R(.4@:&5N=&4@8FEL9&4@9G)A
M`$=A;&QE<FDZ`$=E;F5R97(@)7,@:V]N9FEG=7)A<VIO;@!'96YE<F5R="!K
M;V1E`$=E=&]P="!&96EL.B``1VET="!.879N`$=O`%/X:R!PY2!';V]G;&4`
M1W+E=&]N90!(96QL87,`1W+X;FQA;F0`1W)U<'!E(&%D;6EN:7-T<F%S:F]N
M`$=R=7!P96YA=FX@:V%N(&EK:V4@=N9R92!T;VUM90!'<G5P<&5R971T:6=H
M971E<@!'<G5P<&5R`%)E='1I9VAE=&5R(&9O<B!G:F5S=`!2971T:6=H971E
M<B!F;W(@9VIE<W0`1VIE<W1E8F]K`$A(`$A434P`2%1-3$%R96$@;F5K=&5R
M(.4@<VQE='1E(&1E;B!S:7-T92!C96QL96X@:2!E;B!R860N`$A434Q!<F5A
M(&YE:W1E<B#E('-L971T92!D96X@<VES=&4@:V]L;VYN96X@:2!T86)E;&QE
M;BX`2%1-3$%R96$@;F5K=&5R(.4@<VQE='1E(&1E;B!S:7-T92!R861E;B!I
M('1A8F5L;&5N+@!(5%10(&%U=&5N=&ES97)I;F<@:6MK92!F=6YN970N`$AA
M<V@M86QG;W)I=&UE`$1I<P!(;V1E`$CX>61E`$AJ96QP`$AJ96QP('1I;"!B
M<G5K(&%V(&5D:71O<@!(:F5L<&5R`$AA;'9K=6QE`$AE<B!E<B!B96=Y;FYE
M;'-E;B!PY2!F:6QE;CH`2/AY`$AI<W1O<FEE;W!P9OAR:6YG97(@<.4@:&$@
M;F%V;B!S;VT@:6MK92!E<B!T;VUM90!(:F5?;0!(:F5M`$AJ96UM96%D<F5S
M<V4`5&5L969O;B!H:F5M;64`2&]R9&4`2&]R9&4O2V]L86(Z(%5G>6QD:6<@
M)7,@6$U,(&1A=&$@9G5N;F5T(&D@;65L9&EN9R`E<P!(;W)D92]+;VQA8CH@
M26YG96X@;65L9&EN9R!P87-S97(@;65D(&]B:F5K=&5T("5S`$AO<F1E+TMO
M;&%B.B!);G1E="!O8FIE:W0@878@='EP96X@)7,@9G5N;F5T(&D@;65L9&EN
M9R`E<P!(;W)D92]+;VQA8CH@1FIE<FYE="`E<R`B)7,B`$AO<F1E+TMO;&%B
M.B!3>6YK<F]N:7-E<G1E("5S("(E<R(`2&]R9&4O2V]L86(Z($EN=&5G<F%S
M:F]N<VUO=&]R96X@:W)E=F5R(%!(4"`G9&]M>&UL)R!U='9I9&5L<V4`2&]R
M9&4O2V]L86(Z($MU;FYE(&EK:V4@;W!P<F5T=&4@;GET="!834P@=')E(&9O
M<B!O8FIE:W1E="`E<P!(;W)D92]+;VQA8CH@2W5N;F4@:6MK92!F:F5R;F4@
M)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z($MU;FYE(&EK:V4@:&5N=&4@34E-
M12!)1"!F;W(@9&5L96X@878@='EP92`E<P!(;W)D92]+;VQA8CH@2W5N;F4@
M:6MK92!S>6YK<F]N:7-E<F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z($MU
M;FYE(&EK:V4@<WEN:W)O;FES97)E(&1E;'1E(')E<W-U<G-E<CH@)7,`2&]R
M9&4O2V]L86(Z(%5K:F5N="!D96QT(')E<W-U<G,@(B5S(@!(;W)I<V]N=&%L
M(&QI;FIE`$AO<FES;VYT86P@<&%D9&EN9P!(;W)I<V]N=&%L.@!(=F]R9&%N
M(&MO;2!D=2!H:70_("A696YN;&EG<W0@<F%P<&]R=&5R(2D`2'9O<B!M86YG
M92!K;VQO;FYE<B#X;G-K97(@9'4@Y2!S;.4@<V%M;65N/P!(=F]R(&UA;F=E
M(&9E;'1E<B`H:V]L;VYN97(I(&5R(&1E=#\`2'9O<B!M86YG92!R861E<B#X
M;G-K97(@9'4@Y2!S;.4@<V%M;65N/P!&=6MT:6=H970`1G5K=&EG:&5T.B``
M2'5M;W)I<W1E<@!/<'!R971T96QS92!A=B!)34%0('!O<W1B;VMS(&9E:6QE
M=#H@)7,`4VQE='1I;F<@878@24U!4"!P;W-T8F]K<V5N(&9E:6QE=#H@)7,`
M3W!P<F5T=&5L<V4@878@:W9O=&4@<.4@24U!4"!P;W-T8F]K<R!F96EL970Z
M("5S`$E0($%D<F5S<V4`25`@061R97-S92!I:VME('1I;&=J96YG96QI9RX`
M25`@061R97-S92!I:VME(&EN;F5N9F]R('1I;&%T=&4@0TE$4B!B;&]K:RX`
M0G)U9&0@<.4@25`@;&]C:V1O=VXN`%-?971T(&EN;B!N>2!R860@9OAR`$MU
M;B!I:V]N97(`26MO;F5R(&9O<B`E<P!):V]N97(@;65D('1E:W-T`$ED96YT
M:71E=&5N<R!N879N.@!(=FES(&1E;B!I:VME('9I<V5S(')I:W1I9RP@)7,@
M9F]R(.4@Y7!N92!I(&YY='0@=FEN9'4N`$AV:7,@9'4@:6MK92!S97(@;F]E
M;B!I:V]N97(@;N5R(&1U(&)E;GET=&5R($EN=&5R;F5T($5X<&QO<F5R+"!K
M86X@9&5T(&AE;F1E(&1U('1R96YG97(@Y2!K<GES<V4@878@9&5N;F4@8F]K
M<V5N(&9O<B#E('-K<G4@878@=')A;G-P87)E;G0@4$Y'+@!(=FES(&1U('-E
M<B!D96YN92!M96QD:6YG96X@;65N(&EN=&5T(&)I;&1E+"!K86X@9&5T(&AE
M;F1E(&%T(&)I;&1E="!D=2!V:6P@;&%S=&4@;W!P(&EK:V4@:V%N('9I<V5S
M(&D@9&EN(&YE='1L97-E<BX`1F]R:.5N9'-V:7-N:6YG(&%V(&)I;&1E.@!"
M:6QD96%D<F5S<V4`0FEL9&5A9')E<W-E.@!":6QD92!F<F$@9V%L;&5R:0!"
M:6QD92!F<F$@9V%L;&5R:3H`3W!P;&%S=&EN9R!A=B!B:6QD90!":6QD97(`
M26UP;W)T97)I;F<L('-T96<@)60`26UP;W)T97)T92!F96QT.B`E<P!);7!O
M<G1E<G1E(&9E;'0Z`%5N9&5R(&%R8F5I9`!?4V5T="!I;FX@<F%D(&5T=&5R
M`$9E:6P@:&%N9&QI;F=S:V]D92!G:71T+@!59WEL9&EG(&)R=6ME<FYA=FX@
M;V<O96QL97(@<&%S<V]R9"X`1F5I;"!B<G5K97)N879N(&5L;&5R(&%L=&5R
M;F%T:78@861R97-S92X@5F5N;FQI9W-T(&9O<G/X:R!I9VIE;B!E;&QE<B!K
M;VYT86MT('-Y<W1E;6%D;6EN:7-T<F%T;W)E;B!D:6X@9F]R('ET=&5R;&EG
M97)E<F4@:&IE;'`N`-AK(&EN;G)Y:VL`26YD:79I9'5E;&QE(&)R=6ME<F4`
M26YF;P!);F9O<FUA<VIO;@!3971T(&EN;B!K7V]L;VYN92!E='1E<@!3971T
M(&EN;B!B:6QD90!3971T(&EN;B!T86)E;&P`4V5T="!I;FX@=V5B;&EN:P!3
M971T(&EN;B!?:V]L;VYN92!F^'(`4V5T="!I;FX@96X@;GD@:V]L;VYN92!E
M='1E<B!D96X@9VIE;&1E;F1E`%-E='0@:6YN(&5N(&YY(&MO;&]N;F4@9OAR
M(&1E;B!G:F5L9&5N9&4`4V5T="!I;FX@96X@;GD@<F%D(&5T=&5R(&1E;B!G
M:F5L9&5N9&4`4V5T="!I;FX@96X@;GD@<F%D(&;X<B!D96X@9VIE;&1E;F1E
M`%-E='0@:6YN(&QI;FIE<VMI9G0@971T97(@9&5N(&=J96QD96YD92!N;V1E
M;@!3971T(&EN;B!L:6YJ97-K:69T(&;X<B!D96X@9VIE;&1E;F1E(&YO9&5N
M`%-E='0@:6YN(&%L=&5R;F%T:78@;6%L`%-E='0@:6YN(&5N(&4M<&]S="!A
M9')E<W-E(&1U(/AN<VME<B#E(&UO='1A(&1E="!N>64@<&%S<V]R9&5T('#E
M.@!3971T(&EN;B!C96QL92!E='1E<@!3971T(&EN;B!C96QL92!E='1E<@!3
M971T(&EN;B!K;VQO;FYE(&5T=&5R`%-E='0@:6YN(&MO;&]N;F4@9OAR`%-E
M='0@:6YN(&UE;&1I;F=E<@!3971T(&EN;B!L:6YJ97-K:69T(&5T=&5R`%-E
M='0@:6YN(&QI;FIE<VMI9G0@9OAR`%-E='0@:6YN(')A9"!E='1E<@!3971T
M(&EN;B!R860@9OAR`%-E='0@:6YN(&1E="!PY6MR979D92!S=F%R970@=&EL
M(&;X;&=E;F1E('-I:VME<FAE='-S</AR<VWE;#H`4V5T="!I;FXO<F5D:6=E
M<F4@8FEL9&4`4V5T="!I;FXO<F5D:6=E<F4@;&EN:P!):VME(&YO:R!K<F5D
M:71T(&9O<B#E(&MU;FYE('-E;F1E('1I;"!D:7-T<FEB=7-J;VYS;&ES=&5N
M+@!):VME(&YO:R!K<F5D:71T+@!);G1E9V5R`%5G>6QD:6<@:&%N9&QI;F<@
M=F%L9W0@9F]R(&1E;FYE(&MO;7!O;F5N=&5N+@!59WEL9&EG(%5$2"X@*%5S
M97(@1&%T82!(96%D97(I+@!59WEL9&EG('!R;V=R86TN`%5G>6QD:6<@8F%T
M8V@@240`56=Y;&1I9R!D871A('-E;F1T+@!59WEL9&EG(&UO='1A:V5R(&%D
M<F5S<V4N`%5G>6QD:6<@9FEL9F]R;6%T`%5G>6QD:6<@;65L9&EN9W-T>7!E
M`%5G>6QD:6<@96QL97(@;6%N9VQE;F1E(&%P:5]I9"X`56=Y;&1I9R!E;&QE
M<B!M86YG;&5N9&4@<&%R86UE=&5R92X`56=Y;&1I9V4@<F5T=&EG:&5T97(N
M`%5G>6QD:6<@<')O=&]K;VQL+@!59WEL9&EG(&UO='1A:V5R.B`G)7,G`%5G
M>6QD:6<@9&5L="!O8FIE:W0`56=Y;&1I9R!K:6QD96%D<F5S<V4`56=Y;&1I
M9R!U;FEC;V1E(&1A=&$N`$EN;FAO;&0`27-O;&5R=&4@=&]R9&5N+7-T;W)M
M97(`571G:79E<@!+=7)S:78`2F%N=6%R`$IU;&D`2G5N:0!*=7-T97(`36ED
M='-T:6QL`$)E:&]L9&4@;W)G:6YA;#\`2V5R8F5R;W,@=&IE;F5R96X@879V
M:7-T92!A=71E;G1I<V5R:6YG96XN`$ME<FYE;"!.>6)E9WEN;F5R90!.^&MK
M96QG96YE<F5R:6YG`$[X:VME;"!F:6YG97)P<FEN=`!.^&MK96P@;&5N9V1E
M`$[X:VME;"!T>7!E`$[X:VME;&)R=6L`3OAK:V5L(&5K<VES=&5R97(@86QL
M97)E9&4@<.4@9&5N(&]F9F5N=&QI9V4@;OAK:V5L=&IE;F5R96XN`$)A<FX`
M571?<V5E;F1E`%-P<N5K`%-I<W1E(&AA;'1I;64`4VES=&4@:W9A<G1E<@!3
M:7-T92!O<'!D871E<FEN9SH`4VES=&4@:6YN;&]G9VEN9SH@)7,`4VES=&4@
M:6YN;&]G9VEN9SH@)7,@9G)A("5S`%-I<W1E(&EN;FQO9V=I;F<Z($%L9')I
M`$QO=@!5='-E96YD90#8;G-K97,@:6YG96X@<F%M;65R(&QA<B!D=2!F96QT
M970@=N9R92!T;VUT`%9E;G-T<F4`5F5N<W1R92!H;V1E`%9E;G-T<F4@=F5R
M9&EE<@!,971T(&1U<VMR96=N`$QE='0@<F5G;@!,971T(&9O<FUI9&1A9W-R
M96=N`$QE='0@971T97)M:61D86=S<F5G;@!,971T92!R96=N8GEG97(`3&5T
M="!R96=N(&UE9"!T;W)D96X`3&5T="!S;OAF86QL`$QE='1E('-N^&)Y9V5R
M`$QI;65R:6-K`$QI;FL`3&EN:R!P96ME<B!T:6PZ`$QI;FL@92UP;W-T(&%D
M<F5S<V5N('1I;"`G<VMR:78@;GDG+7-I9&4@=F5D('9I<VYI;F<`3&EN:V5R
M`$QI;G5X($-O;VMI90!,:7-T("T@8G)U:V5R96X@:V%N('-E(&UA<'!E;@!,
M:7-T(&1A=&%B87-E<@!%;6YE<B!I($AJ96QP`$QI<W0@=&%B96QL97(`3&ES
M=&4M87)K:78`3&ES=&5H:F5L<`!,:7-T92U)9`!%:65R(&%V(&QI<W1E`$QI
M<W1E+7!O<W0`06)B;VYE<B!PY2!L:7-T90!3=&]P<"!A8F)O;FYE;65N="!P
MY2!L:7-T90!-=6QI9VAE="!F;W(@Y2!L:7-T92!B<G5K97)E(&5R(&1E86MT
M:79E<G0N`$QI='1E<F%T=7(`3&%S=&5R(&)I8FQI;W1E:V5R+BXN`$QA<W1E
M<BXN+@!,;VMA;"!T:60Z`%-P<N5K(&]G('1I9`!,;VMA<VIO;@!,;V=G(&EN
M;@!,;V=G('5T`$EN;FQO9V=I;F=S;W!P9V%V97(`3&]G:6X@9F5I;&5T(&9O
M<F1I(&)R=6ME<FYA=FYE="!E;&QE<B!P87-S;W)D970@9'4@<VMR978@:6YN
M('9A<B!F96EL+@!,;V=I;B!F96EL970N`$QA;F<@=&5K<W0`2VKF<FQI9VAE
M=`!,878`4VWE(&=R97-K92!B;VMS=&%V97(`4VWE(&QA=&EN<VME(&)O:W-T
M879E<@!-30!);FYB;VMS`%-A;7-V87)E;F1E(&9E;'0`3?AT96%V;'ES;FEN
M9P!-^'1E:6YF;W)M87-J;VX`3?AT96EN;FMA;&QE;'-E`$WX=&5S=F%R`$WX
M=&5O<'!D871E<FEN9P!&;W)E<_AR<V5L(&]M(&WX=&5O<'!D871E<FEN9P!-
M96YY;6]D=7,Z`$UE;&1I;F<`3>5N961T;&EG`&9L>71T(&YE9`!F;'ET="!O
M<'``3F%V;@!4<F5N9V5R(&AA;F1L:6YG`$%L9')I`$YY:&5T97(`3F5S=&4`
M3F5S=&4@<VED90!.96D`26MK92!D96QT86=E<@!);F=E;@!.;W1A=&5R`$]B
M<R$`3TL`2V]N=&]R`%9A;&=F<FD@9&5L=&%G97(`5F%L9P!/<F=A;FES97)I
M;F<`06YN96X@:6YF;W)M87-J;VX`4&%S<V]R9`!5=&;X<B!V961L:6ME:&]L
M9'-O<&5R87-J;VYE<@!5=&;X<B!V961L:6ME:&]L9'-O<&5R87-J;VYE<B!V
M960@:6YN;&]G9VEN9S\`4&5R<V]N;&EG(&EN9F]R;6%S:F]N`%1E;&5F;VX`
M5F5N;FQI9W-T(&=I(&5T('-A;6UE;F1R86<@878@<')O8FQE;65T+@!696YN
M;&ES="!S:W)I=B!I;FX@8G)U:V5R;F%V;B!O9R!P87-S;W)D`%9E;FYL:6=S
M="!S92!O=F5R(&1E;B!F^&QG96YD92!I;F9O<FUA<VIO;F5N+"!V96QG('/E
M(&5N(&AA;F1L:6YG(&9R82!M96YY96X@;F5D96YU;F1E<BX`5F5N;FQI9W-T
M('9E;&<@96X@:&%N9&QI;F<@9G)A(&UE;GEE;B!N961E;G5N9&5R+@!&;W)H
MY6YD<W9I<VYI;F<`1F]R<FEG92!S:61E`%!R;V)L96UB97-K<FEV96QS90!(
M=7-K(&QE9&EG+V]P<'1A='0M:6YF;W)M87-J;VXN`$9J97)N('!A<@!3=F%R
M('-E;F1T+@!3=F%R(&%T(&UE;&1I;F=E;B!I:VME('-T^'1T97,`4W9A<B!M
M960@;&5D:6<O;W!P=&%T="!F;W(@9&4@;F5S=&4@=&\@;>5N961E;F4N`%-V
M87(@;65D(&1E;B!F;W)E<W!U<G1E(&QE9&EG+V]P<'1A='0M:6YF;W)M87-J
M;VYE;BX`3V)L:6=A=&]R:7-K(&1E;'1A9V5R`$YU;&QS=&EL;`!4:6QB86ME
M('1I;"!686QG`%)O;&QE`$QA9W)E('-O;0!,86=R92!686QG`%/X:P!696QG
M(&5N(&1A=&\`5F5L9R!D871O<VMI;&QE=&5G;CH`5F5L9R!D871O9F]R;6%T
M`%9E;&<@=&ED<V9O<FUA=#H`5F5L9R!T;R!S86US=F%R96YD92!F96QT+@!6
M96QG(/AN<VME="!S<'+E:SH`4V5N9"!S:7-T92!I;F9O<FUA<VIO;@!396YD
M('!R;V)L96UR87!P;W)T`%)E9VES=')E<B!D96<@;VT@:6MK92!R96=I<W1R
M97)T`%-T^')R96QS90!(;W!P(&]V97(@=F5D;&EK96AO;&0`4W!E<VEA;'1E
M9VYI;FYT87-T:6YG`%-T87)T`%-T871U<P!%;6YE`%-E;F0`4W5K<V5S<P!3
M86UM96YD<F%G`$]P<&=A=F5R`$=O9'1A(&9O<F5S</AR<V5L(&9O<F5L^'!I
M9P!';V1T82!F;W)E;/AP:6<`2W5N('1E:W-T`$MA;&5N9&5R9&%T82!E<B!U
M9WEL9&EG`$AA;F1L:6YG96X@:&%R(&)L:71T(&QA9W0@=&EL(&1I;B!L:7-T
M92!O=F5R(&AA;F1L:6YG97(N`$)R=6ME<F5N<R!L961I9R]O<'!T871T(&EN
M9F]R;6%S:F]N(&)L92!L86=R970N`$1E="!O<'!S=&]D(&5N(&9E:6P@=6YD
M97(@9F]R<_AK('#E(.4@=FES92!D96YN92!M96QD:6YG<V1E;&5N`$1E="!O
M<'!S=&]D(&5N(&9E:6P@=6YD97(@:6UP;W)T97)I;F<@878@:&5N9&5L<V5N
M.B`E<RX`1&5T(&]P<'-T;V0@96X@9F5I;"!V960@:6UP;W)T97)I;F<@878@
M:&5N9&5L<V5N.B`E<RX`1&5T(&]P<'-T;V0@96X@9F5I;"!V960@:6UP;W)T
M97)I;F<@878@8G)U:V5R96YS(&QE9&EG+V]P<'1A='0M:6YF;W)M87-J;VXZ
M("5S`$1E;B!F;W)E<W!U<G1E(&]P<&=A=F5N(&5R(&EK:V4@<W1O='1E="X`
M1&5N(&9O<F5S<'5R=&4@;W!P9V%V96X@97(@:6MK92!I;7!L96UE;G1E<G0N
M`$1E='1E('1A;&QE="!MY2!VYG)E(&UI;G-T(#$N`$1E='1E(&WE(';F<F4@
M970@=&%L;"X`5&ET=&5L`%1I;`!54DP`2V%N(&EK:V4@:V]B;&4@=&EL(%-1
M3'-E<G9E<F5N+@!+86X@:6MK92!O=F5R<V5T=&4@9&5T=&4@5V]R9"UD;VMU
M;65N=&5T`$%N9W)E(&5N9')I;F=E<@!5:.5N9'1E<G0@:V]M<&]N96YT(&%V
M('1Y<&5N.B`E<P!5=&5N(&YA=FX`3W!P9&%T97(@<W1A='5S('#E(&%V<V5N
M9&5R90!,87-T(&]P<`!,86=R92!686QG`$)R=6ME<FYA=FX`0G)U:V5R;F%V
M;CH`5FES("5S`%9I<R!H96YD96QS90!6:7,@:&%N9&QI;F=E<@!!9'9A<G-E
M;`!5:V5N=&QI9P!696QK;VUM96X@=&EL("5S`%9E;&MO;6UE;BP@)7,`1FER
M;6%A9')E<W-E`$9I<FUA=&5L969O;@#EY0#E<FQI9P!*80!$=2!MY2!B97-K
M<FEV92!P<F]B;&5M970@9OAR(&1U(&MA;B!S96YD92!E;B!P<F]B;&5M<F%P
M<&]R="X`1&EN("5S('1I;&MO8FEN9R!H87(@9^5T="!U="X@5F5N;FQI9W-T
M(&QO9R!I;FX@:6=J96XN`$1I;B!I;F9O<FUA<VIO;@!&=6QL="!N879N`$YE
M='1L97-E<F5N(&1I;B!S=/AT=&5R(&EK:V4@9&5N;F4@=71S:VEF='-O<&5R
M87-J;VYE;BX@5')Y:VL@2V]N=')O;&PO3W!S:F]N("L@4"!F;W(@Y2!S:W)I
M=F4@=70N`$1I;F4@=F%L9R!H87(@8FQI='0@;W!P9&%T97)T`%M0<F]B;&5M
M<F%P<&]R=%T`6VQI;FIE("5S(&%V("5S70!(:F5L<`!,;V=G('5T`%9A;&<`
M;F%V;@!V0V%R9```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L;V-A;&4O;F)?3D\O:&5L<"YX;6P`````````
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,S,C`@,3`U,34T
M,S,W-#$@,#(Q-#0P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_>&UL('9E<G-I;VX](C$N,"(_/@H\(2TM("1(;W)D93H@
M:&]R9&4O;&]C86QE+VYB7TY/+VAE;'`N>&UL+'8@,2XR(#(P,#0O,#4O,C<@
M,C`Z,C(Z,30@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT<GD@:60](G-U
M;6UA<GDB('-T871E/2)N97<B/@H\=&ET;&4^5&AE(%!O<G1A;"!086=E/"]T
M:71L93X*(#QP87)A/@H@(%1H:7,@<&]R=&%L('!A9V4@<')O=FED97,@82!Q
M=6EC:R!S=6UM87)Y(&]F(&%L;"!Y;W5R(&EM<&]R=&%N=`H@(&EN9F]R;6%T
M:6]N+B!&;W(@97AA;7!L92P@:70@;6EG:'0@<VAO=R!H;W<@;6%N>2!N97<@
M92UM86EL(&UE<W-A9V5S('EO=0H@(&AA=F4@:6X@>6]U<B!)3D)/6"P@=7!C
M;VUI;F<@979E;G1S(&]N('EO=7(@8V%L96YD87(L('1A<VMS(&]N('EO=7(@
M=&\M9&\*("!L:7-T+"!H96%D;&EN97,@9G)O;2!S96QE8W1E9"!N97=S('-E
M<G9I8V5S+"!A;F0@<V\@;VXN("!-86YY(&]F('1H97-E"B`@<W5M;6%R:65S
M('=I;&P@8V]N=&%I;B!Q=6EC:R!S:&]R=&-U=',@=&\@8V]M;6]N(&9U;F-T
M:6]N<RP@<W5C:"!A<PH@(&-O;7!O<VEN9R!A(&YE=R!M86EL(&UE<W-A9V4L
M(&-R96%T:6YG(&$@;F5W(&-A;&5N9&%R(&5V96YT(&]R('1A<VLL(&5T8RX*
M(#PO<&%R83X*(#QP87)A/@H@(%1H92!C;VYT96YT<R!O9B!T:&ES('!O<G1A
M;"!P86=E(&%R92!C=7-T;VUI>F%B;&4@=FEA('1H92!,87EO=70@8G5T=&]N
M+@H@($9O<B!E>&%M<&QE+"!Y;W4@8V%N(&-H;V]S92!W:&EC:"!I=&5M<R!T
M;R!I;F-L=61E(&]N('1H:7,@<&]R=&%L('!A9V4@87,*("!W96QL(&%S(&EN
M('=H:6-H(&]R9&5R('1H97D@87)E('-H;W=N+@H@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB;F%V8F%R(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H
M92!!<'!L:6-A=&EO;B!.879I9V%T:6]N($)A<CPO=&ET;&4^"B`\<&%R83X*
M("!!="!T:&4@;&5F="!H86YD('-I9&4@;V8@=&AE('=E8B!P86=E(&ES('1H
M92!A<'!L:6-A=&EO;B!N879I9V%T:6]N(&)A<BX*("!#;&EC:R!O;B!T:&4@
M:6-O;G,@;VX@=&AI<R!N879I9V%T:6]N(&)A<B!T;R!Q=6EC:VQY(&%N9"!E
M87-I;'D@<W=I=&-H"B`@8F5T=V5E;B!T:&4@879A:6QA8FQE(&%P<&QI8V%T
M:6]N<RX*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61O
M7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E
M;F-E<SH@36%I;G1E;F%N8V4Z($1O($UA:6YT96YA;F-E/"]T:71L93X*("`@
M(#QP87)A/@H@("`@268@>6]U('=O=6QD(&QI:V4@=&\@<&5R9F]R;2!M86EN
M=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN+"!C:&5C:R!T:&ES(&)O>"X*
M("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6-O;F9I
M<FU?;6%I;G1E;F%N8V4B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E
M<F5N8V5S.B!-86EN=&5N86YC93H@0V]N9FER;2!-86EN=&5N86YC93PO=&ET
M;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O(&-O;F9I
M<FT@86QL(&UA:6YT96YA;F-E('1A<VMS(&)E9F]R92!T:&5Y(&%R92!R=6XL
M(&-H96-K('1H:7,@8F]X+B!)9B!L969T('5N8VAE8VME9"P@86QL(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,@=&AA="!N965D('1O(&)E(')U;B!W:6QL(&)E
M('!E<F9O<FUE9"!A=71O;6%T:6-A;&QY('=I=&@@;F\@8VAA;F-E('1O(&-A
M;F-E;"!O;B!L;V=I;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*/"]H96QP/@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&]C86QE+VYL7TY,````````````````````````````
M`````````````````````````````````````````````````````````#`P
M,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S0Q
M(#`Q-S<R,``@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O;FQ?3DPO3$-?
M34534T%'15,`````````````````````````````````````````````````
M````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#`P,#`@,3`U,34T,S,W-#$@,#(Q-3`U`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQO8V%L92]N;%].3"],0U]-15-304=%4R]H;W)D92YM;P``````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#0Q-3`P-R`Q,#4Q-30S,S<T,2`P,C,R,S$`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````WA($E0``
M``")!P``'````&0\```3"@``K'@```````#XH```#@```/F@```/````"*$`
M``T````8H0``"````":A```+````+Z$```P````[H0``!````$BA```8````
M3:$``!L```!FH0``+0```(*A```=````L*$``"0```#.H0``*0```/.A```9
M````':(``"8````WH@``#````%ZB```D````:Z(```\```"0H@``"P```*"B
M```.````K*(```4```"[H@``*````,&B```(````ZJ(```H```#SH@``%0``
M`/ZB```2````%*,```L````GHP``A0```#.C```.````N:,```H```#(HP``
M#0```-.C```.````X:,``!$```#PHP``#0````*D```,````$*0```T````=
MI```!@```"ND``"4````,J0```H```#'I```#P```-*D```8````XJ0```P`
M``#[I```#@````BE```.````%Z4```@````FI0``"0```"^E```N````.:4`
M`!H```!HI0``,@```(.E```X````MJ4``%0```#OI0``40```$2F``!:````
MEJ8``%<```#QI@``-````$FG```)````?J<```T```"(IP``!P```):G```*
M````GJ<```\```"IIP``!0```+FG```&````OZ<``!$```#&IP``"````-BG
M```)````X:<```D```#KIP``)0```/6G```@````&Z@``!,````\J```$```
M`%"H```/````8:@```H```!QJ````P```'RH```/````@*@``!0```"0J```
M"0```*6H```-````KZ@``!(```"]J```&0```-"H```>````ZJ@```\````)
MJ0``"@```!FI```/````)*D```@````TJ0``)````#VI```4````8JD``!8`
M``!WJ0``"````(ZI``!.````EZD``"T```#FJ0``&0```!2J```'````+JH`
M``P````VJ@``+````$.J```.````<*H```,```!_J@``"P```(.J```'````
MCZH```<```"7J@``!0```)^J```%````I:H```H```"KJ@```P```+:J```7
M````NJH```H```#2J@``#P```-VJ```.````[:H``!@```#\J@``(P```!6K
M```.````.:L``!0```!(JP``%P```%VK```7````=:L``!<```"-JP``$P``
M`*6K```/````N:L```X```#)JP``'P```-BK```=````^*L```<````6K```
M!@```!ZL```(````):P```\````NK```!@```#ZL```*````1:P``!,```!0
MK```"P```&2L```0````<*P``!4```"!K```%0```)>L```'````K:P``!``
M``"UK```!0```,:L```5````S*P``!$```#BK```#````/2L```[`````:T`
M`#@````]K0``"0```':M```'````@*T``!0```"(K0```P```)VM```%````
MH:T``!````"GK0``"0```+BM```3````PJT``#D```#6K0``$@```!"N```G
M````(ZX``"P```!+K@``*@```'BN```E````HZX```H```#)K@``!@```-2N
M```)````VZX```<```#EK@``+P```.VN```W````':\``"X```!5KP``50``
M`(2O```M````VJ\``"T````(L```/0```#:P```_````=+```"T```"TL```
M0````.*P```C````([$``",```!'L0``0````&NQ```M````K+$``#,```#:
ML0``)0````ZR```5````-+(``!D```!*L@``*0```&2R```D````CK(``"@`
M``"SL@``$0```-RR```*````[K(```P```#YL@``"@````:S```0````$;,`
M`!8````BLP``%@```#FS```'````4+,```<```!8LP``%````&"S```*````
M=;,```@```"`LP``)P```(FS```(````L;,```<```"ZLP``!P```,*S```&
M````RK,```4```#1LP``!P```->S```&````W[,```@```#FLP``*0```.^S
M```.````&;0```H````HM```!````#.T```'````.+0```D```!`M```!@``
M`$JT```1````4;0```<```!CM```%@```&NT```$````@K0```@```"'M```
M!@```)"T```-````E[0```8```"EM```'@```*RT```1````R[0```@```#=
MM```#0```.:T```,````]+0```<````!M0```P````FU```#````#;4``!<`
M```1M0``$P```"FU```=````/;4```@```!;M0``!````&2U```(````:;4`
M``@```!RM0``00```'NU```:````O;4``"L```#8M0``(`````2V```5````
M);8```8````[M@``!@```$*V```5````2;8``!@```!?M@``(@```'BV```N
M````F[8``!T```#*M@``(0```.BV``!4````"K<``"D```!?MP``"@```(FW
M```'````E+<```<```"<MP``%0```*2W```.````NK<```H```#)MP``#P``
M`-2W```-````Y+<```\```#RMP``#0````*X```)````$+@``!0````:N```
M!@```"^X```8````-K@``!T```!/N```$P```&VX```1````@;@``!0```"3
MN```!````*BX```&````K;@``!0```"TN```5````,FX``!D````'KD```0`
M``"#N0``#@```(BY```%````E[D```4```"=N0``&P```*.Y```:````O[D`
M`!,```#:N0``$0```.ZY```1`````+H``!P````2N@``*@```"^Z```0````
M6KH``"$```!KN@``!0```(VZ```3````D[H```L```"GN@``$@```+.Z```*
M````QKH```\```#1N@``#0```.&Z```1````[[H``!,````!NP``#````!6[
M```&````(KL```P````INP``!@```#:[```7````/;L``!````!5NP``$0``
M`&:[```(````>+L```4```"!NP``#````(>[```0````E+L```4```"ENP``
M#0```*N[```&````N;L```<```#`NP``#0```,B[```'````UKL```L```#>
MNP``!P```.J[```'````\KL```D```#ZNP``"0````2\```*````#KP``!D`
M```9O```/0```#.\```=````<;P```P```"/O```$````)R\```%````K;P`
M`"4```"SO```$@```-F\```3````[+P``"L`````O0``.P```"R]```@````
M:+T```@```")O0``-@```)*]```A````R;T``!````#KO0``"````/R]```,
M````!;X```8````2O@``!````!F^```/````'KX```X````NO@``!P```#V^
M```*````1;X```T```!0O@``'P```%Z^```<````?KX``"$```";O@``'@``
M`+V^```9````W+X``!X```#VO@``&P```!6_```A````,;\``"X```!3OP``
M)@```(*_```<````J;\``!X```#&OP``'````.6_```F`````L```"L````I
MP```,P```%7````F````B<```"L```"PP```.````-S````=````%<$``!4`
M```SP0``+P```$G!```@````><$``!(```":P0``*0```*W!```>````U\$`
M`"````#VP0``$@```!?"``"B````*L(``!8```#-P@``(P```.3"```H````
M",,``"D````QPP``*````%O#```?````A,,``!4```"DPP``(````+K#```E
M````V\,``"@````!Q```+0```"K$```P````6,0``)(```")Q```(0```!S%
M```6````/L4``!P```!5Q0``)@```'+%```J````F<4``$$```#$Q0``1```
M``;&```,````2\8```<```!8Q@``!P```&#&```&````:,8```T```!OQ@``
M$````'W&```2````CL8``!,```"AQ@``$@```+7&```'````R,8```0```#0
MQ@``$````-7&```0````YL8```P```#WQ@``#@````3'```-````$\<```\`
M```AQP``$P```#''```-````1<<``"@```!3QP```P```'S'```-````@,<`
M``8```".QP``$0```)7'```7````I\<``!L```"_QP``#@```-O'```"````
MZL<``$D```#MQP``!0```#?(```0````/<@```\```!.R```!````%[(```-
M````8\@```X```!QR````P```(#(```.````A,@```@```"3R```#P```)S(
M```/````K,@```<```"\R```#0```,3(```0````TL@```T```#CR```"P``
M`/'(```&````_<@```L````$R0``#````!#)```*````'<D``!$````HR0``
M&0```#K)```+````5,D```T```!@R0``(@```&[)```/````D<D``!L```"A
MR0``-````+W)```*````\LD``!@```#]R0``$@```!;*```9````*<H``!8`
M``!#R@``(@```%K*```-````?<H```<```"+R@``%````)/*```+````J,H`
M`"(```"TR@``+P```-?*```+````!\L```D````3RP``&0```!W+```+````
M-\L``!<```!#RP``%P```%O+```)````<\L``!8```!]RP``#P```)3+```9
M````I,L``!8```"^RP``#@```-7+```8````Y,L```@```#]RP``#0````;,
M```F````%,P``$,````[S```"````'_,```2````B,P``!\```";S```"```
M`+O,```+````Q,P``"\```#0S```#@````#-```%````#\T```8````5S0``
M10```!S-```#````8LT```<```!FS0``!````&[-```*````<\T```H```!^
MS0``#P```(G-```0````F<T``!<```"JS0``$0```,+-```9````U,T``!<`
M``#NS0``"0````;.```%````$,X```L````6S@``"@```"+.```"````+<X`
M``4````PS@``#0```#;.```;````1,X``!<```!@S@``%````'C.```)````
MC<X```X```"7S@``#0```*;.```2````M,X``#@```#'S@``(`````#/```(
M````(<\```X````JSP``>P```#G/```8````M<\``!@```#.SP``$0```.?/
M```'````^<\```4````!T```&`````?0```>````(-```!L````_T```&0``
M`%O0```;````==```!D```"1T```$P```*O0```'````O]````@```#'T```
M!@```-#0```&````U]```!````#>T```#P```._0```0````_]````\````0
MT0``"P```"#1```/````+-$```P````\T0``#P```$G1```'````6=$```8`
M``!AT0``#@```&C1```,````=]$``"@```"$T0``#P```*W1```(````O=$`
M``@```#&T0``$P```,_1```>````X]$``"$````"T@``(````"32```9````
M1=(``!<```!?T@``)0```'?2```7````G=(``!8```"UT@``!````,S2```;
M````T=(```T```#MT@``#````/O2```#````"-,```4````,TP``"````!+3
M```*````&],```P````FTP``"P```#/3```0````/],```P```!0TP``#@``
M`%W3```+````;-,```0```!XTP``!````'W3```3````@M,``!0```"6TP``
M#````*O3```)````N-,```X```#"TP``"P```-'3```;````W=,```<```#Y
MTP``!P````'4```*````"=0```T````4U```"0```"+4```$````+-0```4`
M```QU````P```#?4```8````.]0```H```!4U```!````%_4```F````9-0`
M``X```"+U```?````)K4```5````%]4```4````MU0``!P```#/5```,````
M.]4```@```!(U0``"@```%'5```&````7-4```@```!CU0```@```&S5```&
M````;]4```8```!VU0``%````'W5```-````DM4``!````"@U0``&P```+'5
M```$````S=4```D```#2U0``$````-S5```)````[=4```D```#WU0``!0``
M``'6```:````!]8```@````BU@``!@```"O6```9````,M8```X```!,U@``
M!P```%O6```'````8]8```4```!KU@``"0```''6```*````>]8```X```"&
MU@```@```)76```&````F-8```L```"?U@``#0```*O6```)````N=8```8`
M``##U@``$@```,K6```)````W=8```<```#GU@``%````._6```=````!-<`
M`$(````BUP``)0```&77```E````B]<```8```"QUP``"@```+C7```$````
MP]<```D```#(UP``"````-+7```1````V]<```D```#MUP``!@```/?7```-
M````_M<```8````,V```!````!/8```Y````&-@``#T```!2V```.@```)#8
M```>````R]@```4```#JV```#@```/#8```$````_]@```8````$V0``!P``
M``O9```A````$]D```T````UV0``%0```$/9```&````6=D```0```!@V0``
M$0```&79```&````=]D```H```!^V0``(@```(G9```$````K-D```4```"Q
MV0``'0```+?9```$````U=D```P```#:V0``#@```.?9```*````]MD```@`
M```!V@``"0````K:```%````%-H``#H````:V@``,````%7:```U````AMH`
M`"D```"\V@``1P```.;:```X````+ML``"D```!GVP``/P```)';```N````
MT=L``"T`````W```'P```"[<```/````3MP``!(```!>W```"P```''<```F
M````?=P``"D```"DW```)````,[<```F````\]P```@````:W0``"@```"/=
M```)````+MT```<````XW0``(````$#=```@````8=T``"8```""W0``"@``
M`*G=```9````M-T``"D```#.W0``%@```/C=```2````#]X```<````BW@``
M"@```"K>```,````-=X```\```!"W@``$````%+>``!`````8]X``'````"D
MW@``9@```!7?```.````?-\```D```"+WP``"@```)7?```2````H-\``!,`
M``"SWP``#````,??```&````U-\```\```#;WP``$@```.O?```0````_M\`
M`!$````/X```'````"'@```C````/N```&H```!BX```#P```,W@```%````
MW>```!````#CX```"0```/3@```$````_N````L````#X0``(`````_A```4
M````,.$```P```!%X0``#````%+A```/````7^$``!4```!OX0``*0```(7A
M```J````K^$``"8```#:X0``)P````'B```I````*>(``"H```!3X@``&0``
M`'[B``!"````F.(``!$```#;X@``$@```.WB```3`````.,``!0````4XP``
M#P```"GC```6````.>,``!<```!0XP``$````&CC```1````>>,``#0```"+
MXP``$P```,#C```2````U.,``#4```#GXP``%````!WD```'````,N0```P`
M```ZY```(````$?D```0````:.0``!0```!YY```$0```([D```7````H.0`
M`!P```"XY```$P```-7D```4````Z>0``!H```#^Y```$0```!GE```:````
M*^4``!X```!&Y0``&@```&7E```3````@.4``!4```"4Y0``$0```*KE```7
M````O.4``!0```#4Y0``%P```.GE```5`````>8```D````7Y@``$````"'F
M```9````,N8```0```!,Y@``!P```%'F```+````6>8``!$```!EY@``!@``
M`'?F```&````?N8```8```"%Y@``!0```(SF```'````DN8```<```":Y@``
M!0```*+F```6````J.8```8```"_Y@``!@```,;F```$````S>8```0```#2
MY@``!P```-?F```.````W^8```P```#NY@``#````/OF```-````".<```H`
M```6YP``#@```"'G```%````,.<``"@````VYP``#@```%_G```,````;N<`
M``\```![YP``"@```(OG```(````EN<```D```"?YP``*P```*GG```$````
MU><```@```#:YP``)@```./G```2````"N@```\````=Z```!@```"WH```*
M````-.@```<````_Z```"````$?H```@````4.@```D```!QZ```%````'OH
M```,````D.@```T```"=Z```#@```*OH```6````NN@``!$```#1Z```!@``
M`./H```#````ZN@```8```#NZ```&0```/7H```'````#^D```0````7Z0``
M"P```!SI```+````*.D```<````TZ0``!0```#SI```'````0ND``!8```!*
MZ0``#0```&'I```-````;^D```H```!]Z0``$````(CI```/````F>D``!$`
M``"IZ0``%P```+OI```*````T^D``!$```#>Z0``"````/#I```$````^>D`
M``\```#^Z0``.@````[J```%````2>H```P```!/Z@``'@```%SJ```.````
M>^H``!````"*Z@``"P```)OJ```,````I^H```D```"TZ@``!P```+[J```*
M````QNH```D```#1Z@``#@```-OJ```0````ZNH``!L```#[Z@``&````!?K
M```:````,.L```H```!+ZP``"0```%;K```*````8.L```P```!KZP``#P``
M`'CK```(````B.L```8```"1ZP``'````)CK```'````M>L```4```"]ZP``
M"P```,/K``!'````S^L```T````7[```"0```"7L```$````+^P```,````T
M[```$P```#CL```3````3.P``!,```!@[```"@```'3L```"````?^P```0`
M``""[```)0```(?L```#````K>P```4```"Q[```*@```+?L```*````XNP`
M``4```#M[```!````//L```*````^.P```T````#[0``!@```!'M```(````
M&.T```@````A[0``!````"KM```%````+^T``&@````U[0``"0```)[M```,
M````J.T``!````"U[0``!0```,;M```&````S.T``!L```#3[0``+P```._M
M```0````'^X```H````P[@``#P```#ON```*````2^X```D```!6[@``$P``
M`&#N```;````=.X``!@```"0[@``%P```*GN```?````P>X```X```#A[@``
M`P```/#N```'````].X```@```#\[@``!P````7O```*````#>\```L````8
M[P``!P```"3O``!1````+.\``!````!^[P``#````(_O```-````G.\``!H`
M``"J[P``2@```,7O```9````$/````8````J\```&@```#'P```E````3/``
M``8```!R\```!@```'GP```?````@/````8```"@\```"0```*?P```8````
ML?```!<```#*\```*````.+P```&````"_$```T````2\0``(@```"#Q``!7
M````0_$``!,```";\0``(P```*_Q```3````T_$```(```#G\0``"P```.KQ
M```(````]O$```T```#_\0``"@````WR```'````&/(``!0````@\@``!@``
M`#7R```(````//(```X```!%\@``!P```%3R```*````7/(```L```!G\@``
M,@```'/R```'````IO(```P```"N\@``#0```+OR```7````R?(```P```#A
M\@``"0```.[R```)````^/(```H````"\P``!P````WS```)````%?,```<`
M```?\P``"@```"?S```;````,O,```\```!.\P``$@```%[S```*````<?,`
M`!8```!\\P``"0```)/S```0````G?,```<```"N\P``$@```+;S```$````
MR?,```<```#.\P``!0```-;S```%````W/,```L```#B\P``%````.[S```1
M`````_0``!H````5]```%@```##T```4````1_0``!<```!<]```&````'3T
M```<````C?0``!D```"J]```!P```,3T```%````S/0```T```#2]```#```
M`.#T```(````[?0``!<```#V]```"P````[U```,````&O4``!\````G]0``
M&@```$?U```3````8O4```0```!V]0``"@```'OU```$````AO4```T```"+
M]0``#````)GU```%````IO4```D```"L]0``!0```+;U```'````O/4```4`
M``#$]0``!````,KU```"````S_4``#@```#2]0``+`````OV```2````./8`
M`"D```!+]@``,@```'7V```*````J/8``"P```"S]@``+@```.#V```S````
M#_<``#,```!#]P``.````'?W```/````L/<``!@```#`]P``$````-GW```/
M````ZO<``!,```#Z]P``%0````[X```4````)/@``!(````Y^```%````$SX
M```5````8?@``"T```!W^```+0```*7X```Q````T_@``"X````%^0``+P``
M`#3Y```L````9/D``&(```"1^0``$P```/3Y```-````"/H```@````6^@``
M%P```!_Z```(````-_H```P```!`^@``*P```$WZ```A````>?H``!H```";
M^@``"0```+;Z``!%````P/H``$$````&^P``!````$C[```3````3?L``!0`
M``!A^P``#@```';[```3````A?L``!@```"9^P``!@```++[```)````N?L`
M``H```##^P``#P```,[[```0````WOL```<```#O^P``#@```/?[```%````
M!OP``!L````,_```"````"C\```&````,?P``!0````X_```$0```$W\```.
M````7_P``#@```!N_````@```*?\```&````JOP```X```"Q_```!0```,#\
M```'````QOP```X```#._```!@```-W\```H````Y/P```P````-_0``'```
M`!K]```$````-_T``"D````\_0``%P```&;]```?````?OT``%P```">_0``
M%````/O]```^````$/X``!\```!/_@``$````&_^```'````@/X```X```"(
M_@``#````)?^```,````I/X``!,```"Q_@``"@```,7^```=````T/X``!D`
M``#N_@``!0````C_```1````#O\``!$````@_P``)````#+_```2````5_\`
M`!4```!J_P``$@```(#_```.````D_\``!D```"B_P``"````+S_```)````
MQ?\```T```#/_P``!P```-W_```*````Y?\```<```#P_P``#P```/C_```&
M````"``!``L````/``$`&@```!L``0`*````-@`!``<```!!``$`"````$D`
M`0`%````4@`!`!\```!8``$`!@```'@``0`0````?P`!``@```"0``$`#0``
M`)D``0`(````IP`!`!X```"P``$`$@```,\``0`L````X@`!`!H````/`0$`
M"0```"H!`0`*````-`$!`!4````_`0$`!0```%4!`0`4````6P$!``0```!P
M`0$`$````'4!`0`&````A@$!``<```"-`0$`'@```)4!`0`H````M`$!``H`
M``#=`0$`'````.@!`0`1````!0(!``L````7`@$`&@```","`0`4````/@(!
M``0```!3`@$`!````%@"`0`+````70(!``4```!I`@$`!@```&\"`0`(````
M=@(!``8```!_`@$`"@```(8"`0`;````D0(!`#0```"M`@$`-````.("`0`@
M````%P,!`"D````X`P$`(````&(#`0!!````@P,!`!H```#%`P$`*````.`#
M`0`I````"00!`%`````S!`$`(@```(0$`0`&````IP0!``@```"N!`$`!0``
M`+<$`0`(````O00!`!D```#&!`$`&0```.`$`0`J````^@0!`",````E!0$`
M&0```$D%`0`N````8P4!`#0```"2!0$`"````,<%`0`7````T`4!``H```#H
M!0$`!P```/,%`0`A````^P4!`!`````=!@$`#@```"X&`0`+````/08!``<`
M``!)!@$`$P```%$&`0`(````908!``L```!N!@$`"@```'H&`0`4````A08!
M``\```":!@$`,@```*H&`0`+````W08!``X```#I!@$`!0```/@&`0`%````
M_@8!``4````$!P$`%P````H'`0`/````(@<!``0````R!P$`"@```#<'`0`)
M````0@<!``L```!,!P$`#0```%@'`0`,````9@<!``X```!S!P$`!0```(('
M`0`$````B`<!``T```"-!P$`,@```)L'`0!%````S@<!`!<````4"`$`!P``
M`"P(`0`>````-`@!`!0```!3"`$`!0```&@(`0`4````;@@!``8```"#"`$`
M!P```(H(`0`.````D@@!`"H```"A"`$`!@```,P(`0`,````TP@!``T```#@
M"`$`$0```.X(`0`+``````D!`#8````,"0$`"@```$,)`0`B````3@D!``L`
M``!Q"0$`#P```'T)`0`R````C0D!`"4```#`"0$`,````.8)`0`Q````%PH!
M`"T```!)"@$`#@```'<*`0`%````A@H!``X```","@$`$P```)L*`0`2````
MKPH!``<```#""@$`$0```,H*`0`3````W`H!``<```#P"@$`%````/@*`0`8
M````#0L!``<````F"P$`!0```"X+`0`,````-`L!``P```!!"P$`$@```$X+
M`0`$````80L!``<```!F"P$`"@```&X+`0`+````>0L!``P```"%"P$`#@``
M`)(+`0`.````H0L!``4```"P"P$`!0```+8+`0`N````O`L!`"8```#K"P$`
M(P```!(,`0`#````-@P!`!(````Z#`$`!@```$T,`0`>````5`P!`!@```!S
M#`$`)0```(P,`0`-````L@P!``D```#`#`$`'P```,H,`0`#````Z@P!``<`
M``#N#`$`"@```/8,`0`"`````0T!``P````$#0$`%0```!$-`0`+````)PT!
M`!D````S#0$`(````$T-`0`2````;@T!``4```"!#0$`"@```(<-`0`5````
MD@T!`!(```"H#0$`#````+L-`0`$````R`T!``D```#-#0$`!P```-<-`0`,
M````WPT!`%(```#L#0$`%P```#\.`0`D````5PX!`!(```!\#@$`!P```(\.
M`0`&````EPX!``X```">#@$`#````*T.`0`-````N@X!`!4```#(#@$`$@``
M`-X.`0`/````\0X!`!0````!#P$`"@```!8/`0`;````(0\!`!`````]#P$`
M"P```$X/`0!I````6@\!`!H```#$#P$`%P```-\/`0`G````]P\!`!H````?
M$`$`%P```#H0`0`;````4A`!`!D```!N$`$`'P```(@0`0`3````J!`!``@`
M``"\$`$`!P```,40`0`(````S1`!``D```#6$`$`%0```.`0`0`-````]A`!
M`",````$$0$`#0```"@1`0`3````-A$!``@```!*$0$``P```%,1`0!&````
M5Q$!`#\```">$0$`-P```-X1`0!7````%A(!``4```!N$@$`'P```'02`0`O
M````E!(!``H```#$$@$`"````,\2`0`-````V!(!`"T```#F$@$`!````!03
M`0!/````&1,!`"4```!I$P$`'````(\3`0`+````K!,!`!\```"X$P$`'0``
M`-@3`0`E````]A,!`"`````<%`$`)````#T4`0`@````8A0!``L```"#%`$`
M!P```(\4`0`-````EQ0!``P```"E%`$`%P```+(4`0`&````RA0!`#D```#1
M%`$`#`````L5`0`'````&!4!``D````@%0$`$P```"H5`0`)````/A4!``0`
M``!(%0$`$````$T5`0`(````7A4!``@```!G%0$`!````'`5`0`+````=14!
M``P```"!%0$`$@```(X5`0`1````H14!``P```"S%0$`&@```,`5`0`/````
MVQ4!``<```#K%0$`#0```/,5`0`4`````18!``X````6%@$`#````"46`0`;
M````,A8!`"P```!.%@$`$P```'L6`0`<````CQ8!`"@```"L%@$`!@```-46
M`0`'````W!8!`!,```#D%@$`!0```/@6`0`$````_A8!`!<````#%P$`"@``
M`!L7`0`,````)A<!``D````S%P$`!@```#T7`0`)````1!<!``@```!.%P$`
M"0```%<7`0`*````81<!`!$```!L%P$`!@```'X7`0`.````A1<!``X```"4
M%P$`#0```*,7`0`+````L1<!`!T```"]%P$`"P```-L7`0`"````YQ<!`!P`
M``#J%P$`!P````<8`0`&````#Q@!`&0````6&`$`"0```'L8`0`'````A1@!
M`"8```"-&`$`.````+08`0`:````[1@!`"H````(&0$`.P```#,9`0`H````
M;QD!`#0```"8&0$`&0```,T9`0`5````YQD!``4```#]&0$`!P````,:`0`(
M````"QH!``<````4&@$`!0```!P:`0`'````(AH!``X````J&@$`"0```#D:
M`0`&````0QH!``@```!*&@$`"P```%,:`0`'````7QH!``@```!G&@$`!P``
M`'`:`0`6````>!H!``D```"/&@$`!@```)D:`0`+````H!H!`!````"L&@$`
M!@```+T:`0`<````Q!H!`!0```#A&@$`!P```/8:`0`1````_AH!``@````0
M&P$`#@```!D;`0`(````*!L!`!`````Q&P$`"0```$(;`0`0````3!L!``8`
M``!=&P$`&0```&0;`0`*````?AL!`!P```")&P$`!P```*8;`0`%````KAL!
M`!````"T&P$`%````,4;`0`+````VAL!``T```#F&P$`*````/0;`0`8````
M'1P!`!<````V'`$`!````$X<`0`)````4QP!``H```!='`$`!P```&@<`0`"
M````<!P!``X```!S'`$`"````((<`0`C````BQP!`!\```"O'`$`.````,\<
M`0`F````"!T!`#$````O'0$`)P```&$=`0!D````B1T!`!0```#N'0$`50``
M``,>`0`X````61X!`$H```"2'@$`6P```-T>`0`H````.1\!`#@```!B'P$`
M*````)L?`0`L````Q!\!`"8```#Q'P$`&P```!@@`0`^````-"`!`*D!``!S
M(`$`(P```!TB`0`7````02(!`$@```!9(@$`A0```*(B`0`P````*",!`"4`
M``!9(P$`00```'\C`0!;````P2,!`$D````=)`$`,0```&<D`0`=````F20!
M`!@```"W)`$`*P```-`D`0`A````_"0!`!\````>)0$`*P```#XE`0`F````
M:B4!`"<```"1)0$`.@```+DE`0`=````]"4!`!$````2)@$`,P```"0F`0`E
M````6"8!`"<```!^)@$`(````*8F`0`?````QR8!`#````#G)@$`:0```!@G
M`0`Q````@B<!`$$```"T)P$`,P```/8G`0`E````*B@!`#T```!0*`$`90``
M`(XH`0!-````]"@!`"\```!"*0$`+@```'(I`0`P````H2D!`%0```#2*0$`
M6@```"<J`0!(````@BH!`$H```#+*@$`,@```!8K`0`O````22L!`"P```!Y
M*P$`+0```*8K`0!Q````U"L!`&8```!&+`$`;P```*TL`0"S````'2T!`!<`
M``#1+0$`)0```.DM`0`R````#RX!`"D```!"+@$`/@```&PN`0`B````JRX!
M`%(```#.+@$`)0```"$O`0`+````1R\!`+$```!3+P$`10````4P`0`A````
M2S`!`#````!M,`$`)0```)XP`0`<````Q#`!`#$```#A,`$`!P```!,Q`0`'
M````&S$!``0````C,0$`#0```"@Q`0`+````-C$!``X```!",0$`"P```%$Q
M`0`%````73$!`!````!C,0$``@```'0Q`0!9````=S$!``4```#1,0$`$@``
M`-<Q`0`$````ZC$!``<```#O,0$`"````/<Q`0`%`````#(!`#`````&,@$`
M`P```#<R`0`0````.S(!``P```!,,@$`$P```%DR`0`-````;3(!``(```![
M,@$`!P```'XR`0`&````AC(!`!0```"-,@$`#````*(R`0`8````KS(!``8`
M``#(,@$`$@```,\R`0`,````XC(!``,```#O,@$`*@```/,R`0`$````'C,!
M``8````C,P$`!P```"HS`0`?````,C,!`#4```!2,P$`+@```(@S`0`O````
MMS,!`!<```#G,P$`(@```/\S`0`E````(C0!`"````!(-`$`&P```&DT`0`8
M````A30!`"0```">-`$`'P```,,T`0`:````XS0!`"$```#^-`$`(````"`U
M`0`:````034!`#(```!<-0$`&@```(\U`0`O````JC4!`"L```#:-0$`'P``
M``8V`0`C````)C8!`!\```!*-@$`&@```&HV`0`A````A38!`"4```"G-@$`
M)@```,TV`0`E````]#8!`"0````:-P$`&````#\W`0`=````6#<!`"0```!V
M-P$`&````)LW`0`B````M#<!`"P```#7-P$`+P````0X`0`5````-#@!`"4`
M``!*.`$`/````'`X`0`?````K3@!`",```#-.`$`'P```/$X`0`@````$3D!
M`!H````R.0$`&````$TY`0`F````9CD!`!X```"-.0$`*0```*PY`0`>````
MUCD!`#$```#U.0$`"0```"<Z`0`,````,3H!`!<````^.@$`+P```%8Z`0`D
M````ACH!``<```"K.@$`#P```+,Z`0`4````PSH!``X```#8.@$`#0```.<Z
M`0`D````]3H!``4````:.P$`!P```"`[`0`B````*#L!`"4```!+.P$`&@``
M`'$[`0`=````C#L!`!H```"J.P$`!P```,4[`0#'````S3L!``L```"5/`$`
M%0```*$\`0`&````MSP!``D```"^/`$`"P```,@\`0`-````U#P!`!<```#B
M/`$`!@```/H\`0`S`````3T!`!,````U/0$`$P```$D]`0`'````73T!``\`
M``!E/0$`!P```'4]`0`R````?3T!``0```"P/0$`(0```+4]`0`3````UST!
M``P```#K/0$`$0```/@]`0`R````"CX!`!8````]/@$`"````%0^`0`=````
M73X!``D```![/@$`"@```(4^`0`4````D#X!``H```"E/@$`'0```+`^`0`(
M````SCX!`!\```#7/@$`"````/<^`0`:`````#\!`"<````;/P$`!@```$,_
M`0`5````2C\!``<```!@/P$`"````&@_`0`)````<3\!`#\```![/P$`!P``
M`+L_`0`/````PS\!``X```#3/P$`$````.(_`0`)````\S\!``D```#]/P$`
M"`````=``0`3````$$`!``<````D0`$`&0```"Q``0`*````1D`!`!<```!1
M0`$`%````&E``0`*````?D`!``P```")0`$`%P```)9``0`$````KD`!`"H`
M``"S0`$`#````-Y``0`1````ZT`!``<```#]0`$``@````5!`0`0````"$$!
M`!@````900$`"P```#)!`0`#````/D$!``@```!"00$`!@```$M!`0`'````
M4D$!``T```!:00$`"P```&A!`0`4````=$$!`!4```")00$`#@```)]!`0`O
M````KD$!`"````#>00$`'````/]!`0`5````'$(!``P````R0@$`,0```#]"
M`0`%````<4(!`!(```!W0@$`/P```(I"`0`2````RD(!``H```#=0@$`!@``
M`.A"`0`$````[T(!``0```#T0@$`"@```/E"`0`3````!$,!``4````80P$`
M!@```!Y#`0`&````)4,!``@````L0P$`!````#5#`0`,````.D,!``H```!'
M0P$`.0```%)#`0`N````C$,!`"D```"[0P$`!0```.5#`0`8````ZT,!`!D`
M```$1`$`'P```!Y$`0`=````/D0!`!$```!<1`$``@```&Y$`0`$````<40!
M``H```!V1`$`!@```(%$`0`%````B$0!``,```".1`$`#````))$`0!%````
MGT0!`#(```#E1`$`&@```!A%`0`T````,T4!`"@```!H10$`4P```)%%`0`9
M````Y44!`'(```#_10$`(````')&`0`U````DT8!`"$```#)1@$`10```.M&
M`0`P````,4<!`"@```!B1P$`*0```(M'`0`F````M4<!`"4```#<1P$`*```
M``)(`0`H````*T@!`"(```!42`$`*P```'=(`0`P````HT@!`!(```#42`$`
M$P```.=(`0`0````^T@!`'D````,20$`"0```(9)`0"A````D$D!`',````R
M2@$`?````*9*`0`K````(TL!`%0```!/2P$`%P```*1+`0`G````O$L!`!8`
M``#D2P$`#P```/M+`0`7````"TP!`!\````C3`$`0````$-,`0`?````A$P!
M`!P```"D3`$`40```,%,`0`:````$TT!`!0````N30$`"@```$--`0`%````
M3DT!``8```!430$`"````%M-`0`%````9$T!`!(```!J30$`$````'U-`0`3
M````CDT!`!T```"B30$`#P```,!-`0`/````T$T!``0```#@30$`"0```.5-
M`0`+````[TT!``<```#[30$`!0````-.`0`4````"4X!``<````>3@$`"```
M`"9.`0`/````+TX!``@````_3@$`#````$A.`0`/````54X!``8```!E3@$`
M%````&Q.`0`&````@4X!``P```"(3@$`$0```)5.`0`(````ITX!``0```"P
M3@$`&0```+5.`0`1````STX!``H```#A3@$`&````.Q.`0`3````!4\!`!P`
M```93P$`$0```#9/`0`$````2$\!``\```!-3P$`!P```%U/`0`$````94\!
M`!D```!J3P$`!P```(1/`0`"````C$\!``(```"/3P$`$0```))/`0`)````
MI$\!``8```"N3P$`$@```+5/`0`7````R$\!``8```#@3P$`)P```.=/`0`"
M````#U`!``0````24`$`#P```!=0`0`3````)U`!``<````[4`$`!P```$-0
M`0`1````2U`!``8```!=4`$`&````&10`0`&````?5`!`!,```"$4`$`$```
M`)A0`0`2````J5`!``(```"\4`$`!@```+]0`0`,````QE`!``D```#34`$`
M$0```-U0`0`B````[U`!``<````240$`!P```!I1`0`+````(E$!``4````N
M40$``@```#11`0`+````-U$!`&4!``!#40$`$P```*E2`0`/````O5(!`!(`
M``#-4@$`"@```.!2`0`)````ZU(!``L```#U4@$`!`````%3`0`7````!E,!
M`!L````>4P$`,@```#I3`0`B````;5,!`"<```"04P$`)P```+A3`0`<````
MX%,!`"X```#]4P$`"P```"Q4`0`C````.%0!`!,```!<5`$`#@```'!4`0`/
M````?U0!``4```"/5`$`*````)54`0`,````OE0!``X```#+5`$`&0```-I4
M`0`.````]%0!``L````#50$`CP````]5`0`-````GU4!``H```"M50$`$0``
M`+A5`0`0````RE4!``X```#;50$`"P```.I5`0`0````]E4!``\````'5@$`
M!@```!=6`0"R````'E8!``T```#15@$`$@```-]6`0`8````\E8!`!`````+
M5P$`#P```!Q7`0`/````+%<!``<````\5P$`!P```$17`0`N````3%<!`"@`
M``![5P$`/@```*17`0!-````XU<!`&@````Q6`$`:P```)I8`0!N````!ED!
M`'$```!U60$`0````.=9`0`8````*%H!`!L```!!6@$`%````%U:`0`4````
M<EH!`!H```"'6@$`!0```*):`0`&````J%H!`!````"O6@$`!P```,!:`0`)
M````R%H!``D```#26@$`,@```-Q:`0`P````#UL!`!$```!`6P$`$0```%);
M`0`1````9%L!``X```!V6P$`"0```(5;`0`5````CUL!`!4```"E6P$`#P``
M`+M;`0`6````RUL!`!4```#B6P$`(P```/A;`0`C````'%P!`!L```!`7`$`
M#P```%Q<`0`6````;%P!``X```"#7`$`+0```))<`0`7````P%P!`!L```#8
M7`$`$P```/1<`0!;````"%T!`#4```!D70$`*@```)I=`0`%````Q5T!``D`
M``#+70$`,0```-5=`0`&````!UX!``P````.7@$`"@```!M>`0`'````)EX!
M``@````N7@$`!0```#=>`0`)````/5X!``L```!'7@$`!````%->`0`@````
M6%X!``P```!Y7@$`#````(9>`0`0````DUX!`!H```"D7@$`+````+]>`0`*
M````[%X!`!P```#W7@$`&P```!1?`0`@````,%\!`!<```!17P$`%@```&E?
M`0`3````@%\!`!````"47P$`'P```*5?`0`K````Q5\!``<```#Q7P$`!@``
M`/E?`0`(`````&`!``X````)8`$`"````!A@`0`*````(6`!`!(````L8`$`
M"@```#]@`0`1````2F`!`!4```!<8`$`&````')@`0`*````BV`!`!$```"6
M8`$`!0```*A@`0`7````KF`!`!8```#&8`$`"P```-U@`0!"````Z6`!`#P`
M```L80$`"@```&EA`0`'````=&$!`!,```!\80$`!0```)!A`0`%````EF$!
M`!````"<80$`"P```*UA`0`5````N6$!`$4```#/80$`$0```!5B`0`R````
M)V(!`#$```!:8@$`+@```(QB`0`O````NV(!``H```#K8@$`"````/9B`0`)
M````_V(!``H````)8P$`,@```!1C`0`X````1V,!`#$```"`8P$`5P```+)C
M`0`P````"F0!`#`````[9`$`4````&QD`0!2````O60!`#`````090$`1@``
M`$%E`0`T````B&4!`#,```"]90$`40```/%E`0`P````0V8!`#8```!T9@$`
M)0```*MF`0`5````T68!`!D```#G9@$`+@````%G`0`D````,&<!`"<```!5
M9P$`$P```'UG`0`,````D6<!``P```">9P$`"P```*MG`0`0````MV<!`!@`
M``#(9P$`'0```.%G`0`'````_V<!``<````':`$`%@````]H`0`*````)F@!
M``@````Q:`$`+P```#IH`0`)````:F@!``L```!T:`$`!@```(!H`0`&````
MAV@!``4```".:`$`!P```)1H`0`&````G&@!``H```"C:`$`+````*YH`0`0
M````VV@!``@```#L:`$``P```/5H`0`'````^6@!``D````!:0$`!`````MI
M`0`*````$&D!``8````;:0$`%0```")I`0`&````.&D!``@````_:0$`"0``
M`$AI`0`-````4FD!``@```!@:0$`(0```&EI`0`1````BVD!``D```"=:0$`
M$0```*=I`0`,````N6D!``<```#&:0$``P```,YI`0`#````TFD!`!4```#6
M:0$`%````.QI`0`E`````6H!``8````G:@$`!````"YJ`0`(````,VH!``@`
M```\:@$`4@```$5J`0`D````F&H!`"<```"]:@$`)@```.5J`0`=````#&L!
M``8````J:P$`"````#%K`0`8````.FL!`"(```!3:P$`)0```'9K`0`P````
MG&L!`"0```#-:P$`*@```/)K`0!Z````'6P!`#4```"8;`$`"@```,YL`0`)
M````V6P!``8```#C;`$`%0```.IL`0`/`````&T!``T````0;0$`$````!YM
M`0`1````+VT!`!````!!;0$`#@```%)M`0`-````86T!`!8```!O;0$`!@``
M`(9M`0`=````C6T!`!X```"K;0$`$@```,IM`0`3````W6T!`!$```#Q;0$`
M!@````-N`0`(````"FX!`!0````3;@$`80```"AN`0!X````BFX!``@````#
M;P$`$P````QO`0`%````(&\!``4````F;P$`'@```"QO`0`;````2V\!`!``
M``!G;P$`$P```'AO`0`7````C&\!`!,```"D;P$`+````+AO`0`0````Y6\!
M`"0```#V;P$`!@```!MP`0`4````(G`!``D````W<`$`$0```$%P`0`-````
M4W`!`!(```!A<`$`$````'1P`0`6````A7`!`!,```"<<`$`#````+!P`0`&
M````O7`!`!````#$<`$`!P```-5P`0`8````W7`!`!$```#V<`$`$0````AQ
M`0`(````&G$!``4````C<0$`#0```"EQ`0`-````-W$!``D```!%<0$`"P``
M`$]Q`0`&````6W$!``@```!B<0$`#0```&MQ`0`)````>7$!``T```"#<0$`
M!P```)%Q`0`'````F7$!``D```"A<0$`"````*MQ`0`)````M'$!`!L```"^
M<0$`1P```-IQ`0`:````(G(!``\````]<@$`$P```$UR`0`%````87(!`"@`
M``!G<@$`$P```)!R`0`4````I'(!`#@```"Y<@$`1P```/)R`0`B````.G,!
M``@```!=<P$`-0```&9S`0`H````G',!``\```#%<P$`"````-5S`0`-````
MWG,!``8```#L<P$`"````/-S`0`4````_',!`!`````1=`$`"0```")T`0`*
M````+'0!``D````W=`$`'@```$%T`0`C````8'0!`"````"$=`$`)0```*5T
M`0`<````RW0!`"T```#H=`$`'P```!9U`0`C````-G4!`"X```!:=0$`(P``
M`(EU`0`=````K74!`!\```#+=0$`'@```.MU`0`I````"G8!`"\````T=@$`
M,@```&1V`0`D````EW8!`"L```"\=@$`-P```.AV`0`>````('<!`!X````_
M=P$`/0```%YW`0`D````G'<!`!,```#!=P$`*````-5W`0`?````_G<!`"$`
M```>>`$`$@```$!X`0#$````4W@!`!0````8>0$`'@```"UY`0`E````3'D!
M`"<```!R>0$`(P```)IY`0`B````OGD!`"0```#A>0$`(0````9Z`0`D````
M*'H!`"<```!->@$`,````'5Z`0`R````IGH!`*8```#9>@$`(P```(![`0`:
M````I'L!`!P```"_>P$`)P```-Q[`0`P````!'P!`$<````U?`$`1````'U\
M`0`-````PGP!``0```#0?`$`"0```-5\`0`%````WWP!``T```#E?`$`#P``
M`/-\`0`.`````WT!``\````2?0$`$````")]`0`'````,WT!``0````[?0$`
M#P```$!]`0`/````4'T!``P```!@?0$`#@```&U]`0`2````?'T!``L```"/
M?0$`$@```)M]`0`-````KGT!`"X```"\?0$`!P```.M]`0`0````\WT!``8`
M```$?@$`$P````M^`0`9````'WX!`!L````Y?@$`%0```%5^`0`"````:WX!
M`$D```!N?@$`"0```+A^`0`0````PGX!`!,```#3?@$`!0```.=^`0`/````
M[7X!``X```#]?@$``P````Q_`0`0````$'\!``@````A?P$`$0```"I_`0`5
M````/'\!``D```!2?P$`#P```%Q_`0`4````;'\!``\```"!?P$`"@```)%_
M`0`+````G'\!``T```"H?P$`$0```+9_`0`-````R'\!`!$```#6?P$`&@``
M`.A_`0`-`````X`!``\````1@`$`*0```"&``0`3````2X`!`!P```!?@`$`
M-@```'R``0`-````LX`!`"0```#!@`$`$P```.:``0`:````^H`!`!@````5
M@0$`)0```"Z!`0`+````5($!``H```!@@0$`%@```&N!`0`,````@H$!`"0`
M``"/@0$`+0```+2!`0`,````XH$!``@```#O@0$`(0```/B!`0`*````&H(!
M`!D````E@@$`&@```#^"`0`)````6H(!`!4```!D@@$`#@```'J"`0`F````
MB8(!`!T```"P@@$`#P```,Z"`0`9````WH(!``@```#X@@$`$`````&#`0`F
M````$H,!`#T````Y@P$`"````'>#`0`6````@(,!`!L```"7@P$`"@```+.#
M`0`-````OH,!`#(```#,@P$`#P```/^#`0`%````#X0!``8````5A`$`4P``
M`!R$`0`#````<(0!``<```!TA`$`"````'R$`0`-````A80!``X```"3A`$`
M#@```**$`0`0````L80!`!D```#"A`$`%0```-R$`0`9````\H0!`!<````,
MA0$`"0```"2%`0`&````+H4!``L````UA0$`"@```$&%`0`"````3(4!``8`
M``!/A0$`"P```%:%`0`C````8H4!`!8```"&A0$`%P```)V%`0`)````M84!
M``T```"_A0$`#P```,V%`0`/````W84!`#X```#MA0$`)@```"R&`0`(````
M4X8!``\```!<A@$`BP```&R&`0`>````^(8!`!T````7AP$`$@```#6'`0`'
M````2(<!``0```!0AP$`&P```%6'`0`G````<8<!`"4```"9AP$`'P```+^'
M`0`E````WX<!`!<````%B`$`'````!V(`0`'````.H@!``@```!"B`$`!P``
M`$N(`0`&````4X@!``\```!:B`$`#@```&J(`0`0````>8@!``X```"*B`$`
M#P```)F(`0`,````J8@!``L```"VB`$`$0```,*(`0`)````U(@!``H```#>
MB`$`$@```.F(`0`.````_(@!`"X````+B0$`"P```#J)`0`(````1HD!``X`
M``!/B0$`%````%Z)`0`F````<XD!`"D```":B0$`*````,2)`0`=````[8D!
M`!X````+B@$`+````"J*`0`A````5XH!`!D```!YB@$`!````).*`0`<````
MF(H!``\```"UB@$`#````,6*`0`#````THH!``4```#6B@$`"````-R*`0`)
M````Y8H!``L```#OB@$`#````/N*`0`1````"(L!``H````:BP$`#@```"6+
M`0`+````-(L!``0```!`BP$`!P```$6+`0`<````38L!`!X```!JBP$`#0``
M`(F+`0`,````EXL!``X```"DBP$`#0```+.+`0`G````P8L!``<```#IBP$`
M!P```/&+`0`,````^8L!``\````&C`$`%0```!:,`0`'````+(P!``<````T
MC`$`!````#R,`0`3````08P!``D```!5C`$`!P```%^,`0`P````9XP!`!<`
M``"8C`$`@@```+",`0`7````,XT!``L```!+C0$`!P```%>-`0`+````7XT!
M``@```!KC0$`"@```'2-`0`&````?XT!``H```"&C0$``@```)&-`0`&````
ME(T!``D```";C0$`&0```*6-`0`,````OXT!``\```#,C0$`'````-R-`0`#
M````^8T!``<```#]C0$`%@````6.`0`*````'(X!``X````GC@$`!0```#:.
M`0`S````/(X!``8```!PC@$`!@```'>.`0`8````?HX!`!$```"7C@$`!P``
M`*F.`0`)````L8X!``4```"[C@$`"0```,&.`0`(````RXX!``X```#4C@$`
M`@```...`0`&````YHX!``X```#MC@$`#0```/R.`0`+````"H\!``L````6
MCP$`$P```"*/`0`)````-H\!``<```!`CP$`#````$B/`0`?````58\!`$,`
M``!UCP$`,0```+F/`0`P````ZX\!``<````<D`$`"@```"20`0`$````+Y`!
M``D````TD`$`"````#Z0`0`,````1Y`!``H```!4D`$`!@```%^0`0`-````
M9I`!``8```!TD`$`!````'N0`0!`````@)`!`$0```#!D`$`0@````:1`0`A
M````29$!``4```!KD0$`#P```'&1`0`%````@9$!``,```"'D0$`!@```(N1
M`0`A````DI$!`!````"TD0$`&````,61`0`&````WI$!``0```#ED0$`&P``
M`.J1`0`&````!I(!``@````-D@$`(@```!:2`0`$````.9(!``4````^D@$`
M%P```$22`0`$````7)(!``T```!AD@$`#0```&^2`0`/````?9(!``@```"-
MD@$`"0```):2`0`%````H)(!`#T```"FD@$`-@```.22`0`[````&Y,!`"H`
M``!7DP$`.````(*3`0`Z````NY,!`"T```#VDP$`4@```"24`0`P````=Y0!
M`#D```"HE`$`*0```.*4`0`0````#)4!`!@````=E0$`#````#:5`0`D````
M0Y4!`"0```!HE0$`(@```(V5`0`A````L)4!``L```#2E0$`#0```-Z5`0`*
M````[)4!``D```#WE0$`(@````&6`0`H````))8!`"@```!-E@$`"````':6
M`0`:````?Y8!`#,```":E@$`&````,Z6`0`2````YY8!``<```#ZE@$`$P``
M``*7`0`4````%I<!`!8````KEP$`$````$*7`0!1````4Y<!`)$```"EEP$`
MA````#>8`0`7````O)@!``X```#4F`$`#P```..8`0`4````\Y@!`!4````(
MF0$`$0```!Z9`0`,````,)D!`!,````]F0$`%0```%&9`0`5````9YD!``\`
M``!]F0$`(@```(V9`0`I````L)D!`(T```#:F0$`%````&B:`0`%````?9H!
M`!8```"#F@$`"0```)J:`0`$````I)H!``H```"IF@$`(P```+2:`0`1````
MV)H!`!,```#JF@$`#@```/Z:`0`0````#9L!`!0````>FP$`)P```#.;`0`I
M````6YL!`"4```"%FP$`)0```*N;`0`P````T9L!`#`````"G`$`'0```#.<
M`0!%````49P!``\```"7G`$`$0```*><`0`1````N9P!`!,```#+G`$`$@``
M`-^<`0`5````\IP!`!<````(G0$`#P```""=`0`1````,)T!`#D```!"G0$`
M'0```'R=`0`7````FIT!`#H```"RG0$`$P```.V=`0`'`````9X!``T````)
MG@$`(@```!>>`0`2````.IX!`!4```!-G@$`$@```&.>`0`9````=IX!`!D`
M``"0G@$`%````*J>`0`:````OYX!`!P```#:G@$`$@```/>>`0`>````"I\!
M`"0````IGP$`%@```$Z?`0`4````99\!`!@```!ZGP$`$@```).?`0`9````
MII\!`!<```#`GP$`$P```-B?`0`7````[)\!``H````$H`$`$`````^@`0`@
M````(*`!``0```!!H`$`!P```$:@`0`*````3J`!`!@```!9H`$`!@```'*@
M`0`(````>:`!``<```""H`$`!@```(J@`0`'````D:`!``<```"9H`$`!0``
M`*&@`0`4````IZ`!``8```"\H`$`"````,.@`0`$````S*`!``0```#1H`$`
M"0```-:@`0`5````X*`!`!(```#VH`$`#P````FA`0`0````&:$!``H````J
MH0$`$P```#6A`0`%````2:$!`"<```!/H0$`#@```'>A`0`-````AJ$!`!,`
M``"4H0$`#0```*BA`0`+````MJ$!``X```#"H0$`,P```-&A`0`(````!:(!
M``@````.H@$`)P```!>B`0`4````/Z(!`!$```!4H@$`!P```&:B`0`)````
M;J(!``<```!XH@$`!````("B`0`@````A:(!``T```"FH@$`&P```+2B`0`0
M````T*(!`!(```#AH@$`%@```/2B`0`=````"Z,!`!D````IHP$`!P```$.C
M`0`'````2Z,!``8```!3HP$`&````%JC`0`'````<Z,!``4```![HP$`"@``
M`(&C`0`.````C*,!``<```";HP$`!@```*.C`0`'````JJ,!`!T```"RHP$`
M#0```-"C`0`,````WJ,!``P```#KHP$`$@```/BC`0`,````"Z0!``\````8
MI`$`%P```"BD`0`-````0*0!`!````!.I`$`"````%^D`0`$````:*0!`!``
M``!MI`$`00```'ZD`0`%````P*0!``P```#&I`$`(0```-.D`0`-````]:0!
M`!D````#I0$`"@```!VE`0`-````**4!``H````VI0$`"````$&E`0`.````
M2J4!``H```!9I0$`$0```&2E`0`2````=J4!`"@```")I0$`+````+*E`0`O
M````WZ4!``H````/I@$`"````!JF`0`(````(Z8!``P````LI@$`%@```#FF
M`0`'````4*8!``D```!8I@$`'@```&*F`0`(````@:8!``D```"*I@$`#```
M`)2F`0!.````H:8!`!,```#PI@$`"P````2G`0`&````$*<!``0````7IP$`
M%@```!RG`0`7````,Z<!`!@```!+IP$`"0```&2G`0`"````;J<!``0```!Q
MIP$`(@```':G`0`#````F:<!``4```"=IP$`,P```*.G`0`*````UZ<!``4`
M``#BIP$`!@```.BG`0`-````[Z<!``T```#]IP$`!@````NH`0`(````$J@!
M``D````;J`$`!````"6H`0`%````*J@!`&(````PJ`$`"P```).H`0`-````
MGZ@!`!<```"MJ`$`!0```,6H`0`%````RZ@!`"8```#1J`$`-P```/BH`0`1
M````,*D!``H```!"J0$`%0```$VI`0`*````8ZD!``D```!NJ0$`'````'BI
M`0`G````E:D!`"T```"]J0$`+````.NI`0`=````&*H!``X````VJ@$``P``
M`$6J`0`'````2:H!``L```!1J@$`!0```%VJ`0`*````8ZH!`!(```!NJ@$`
M!P```(&J`0!I````B:H!`!$```#SJ@$`"P````6K`0`*````$:L!`!\````<
MJP$`30```#RK`0`:````BJL!``<```"EJP$`(0```*VK`0`U````SZL!``@`
M```%K`$`!@````ZL`0`?````%:P!``8````UK`$`"0```#RL`0`M````1JP!
M`"P```!TK`$`+P```*&L`0`&````T:P!``H```#8K`$`)0```..L`0!A````
M":T!`!8```!KK0$`*````(*M`0`5````JZT!``(```#!K0$`#@```,2M`0`)
M````TZT!``\```#=K0$`"@```.VM`0`'````^*T!`!<`````K@$`!@```!BN
M`0`(````'ZX!``T````HK@$`"P```#:N`0`*````0JX!``D```!-K@$`-P``
M`%>N`0`'````CZX!`!8```"7K@$`%````*ZN`0`@````PZX!`!,```#DK@$`
M#````/BN`0`*````!:\!``L````0KP$`"@```!RO`0`,````)Z\!``H````T
MKP$`"@```#^O`0`=````2J\!`!$```!HKP$`%````'JO`0`,````CZ\!`!0`
M``"<KP$`#````+&O`0`2````OJ\!``4```#1KP$`)0```->O`0`$````_:\!
M``<````"L`$`!0````JP`0`%````$+`!``D````6L`$`$P```""P`0`2````
M-+`!`!H```!'L`$`%@```&*P`0`8````>;`!`!<```"2L`$`%P```*JP`0`>
M````PK`!`!@```#AL`$`!P```/JP`0`%`````K$!``\````(L0$`$````!BQ
M`0`+````*;$!`"$````UL0$`#0```%>Q`0`0````9;$!`"0```!VL0$`)P``
M`)NQ`0`5````P[$!``8```#9L0$`#0```."Q`0`(````[K$!`!````#WL0$`
M#P````BR`0`)````&+(!``D````BL@$`!0```"RR`0`'````,K(!``4````Z
ML@$`!````$"R`0`#````1;(!`#\```!)L@$`.0```(FR`0`3````P[(!`"P`
M``#7L@$`,@````2S`0`1````-[,!`#H```!)LP$`+@```(2S`0`S````L[,!
M`#,```#GLP$`.P```!NT`0`2````5[0!`!H```!JM`$`%0```(6T`0`;````
MF[0!`!T```"WM`$`%P```-6T`0`6````[;0!`!0````$M0$`%0```!FU`0`9
M````+[4!`#(```!)M0$`,@```'RU`0`U````K[4!`#,```#EM0$`-````!FV
M`0`Q````3K8!`&L```"`M@$`'0```.RV`0`5````"K<!``X````@MP$`'P``
M`"^W`0`+````3[<!`!8```!;MP$`,````'*W`0`O````H[<!`",```#3MP$`
M#````/>W`0!)````!+@!`$(```!.N`$`!````)&X`0`0````EK@!`!P```"G
MN`$`#@```,2X`0`3````T[@!``@```#GN`$`"0```/"X`0`'````^K@!``D`
M```"N0$`#@````RY`0`5````&[D!``X````QN0$`$0```$"Y`0`(````4KD!
M`!P```!;N0$`"````'BY`0`%````@;D!`!````"'N0$`#P```)BY`0`,````
MJ+D!`#\```"UN0$``@```/6Y`0`&````^+D!``X```#_N0$`!@````ZZ`0`'
M````%;H!`!`````=N@$`!P```"ZZ`0`X````-KH!``\```!ON@$`'0```'^Z
M`0`$````G;H!`#$```"BN@$`&P```-2Z`0`B````\+H!`%@````3NP$`&```
M`&R[`0!(````A;L!`",```#.NP$`$````/*[`0`&`````[P!``X````*O`$`
M#P```!F\`0`,````*;P!`!,````VO`$`"P```$J\`0`=````5KP!`!H```!T
MO`$`!@```(^\`0`1````EKP!``\```"HO`$`)@```+B\`0`2````W[P!`!D`
M``#RO`$`$P````R]`0`4````(+T!`"`````UO0$`"````%:]`0`)````7[T!
M`!D```!IO0$`$@```(.]`0`2````EKT!`!,```"IO0$`&````+V]`0`0````
MUKT!`!D```#GO0$`&`````&^`0`*````&KX!``P````EO@$`"````#*^`0`%
M````.[X!`!T```!!O@$`!@```%^^`0`2````9KX!``@```!YO@$`%````(*^
M`0`*````E[X!`"````"BO@$`$@```,.^`0`P````UKX!`!H````'OP$`"P``
M`"*_`0`,````+K\!`"$````[OP$`!P```%V_`0`6````9;\!``,```!\OP$`
M&````("_`0`&````F;\!``<```"@OP$`(0```*B_`0`Q````RK\!``4```#\
MOP$`&P````+``0`/````'L`!``<````NP`$`#0```#;``0`7````1,`!``0`
M``!<P`$`"@```&'``0`,````;,`!``@```!YP`$`!@```(+``0`(````B<`!
M``8```"2P`$`"@```)G``0`7````I,`!`#0```"\P`$`-````/'``0`B````
M)L$!`#,```!)P0$`(````'W!`0!'````GL$!`!T```#FP0$`+@````3"`0`L
M````,\(!`&8```!@P@$`)0```,?"`0`%````[<(!``@```#SP@$`"0```/S"
M`0`(````!L,!`"$````/PP$`'````#'#`0`P````3L,!`",```!_PP$`$@``
M`*/#`0`Q````ML,!`#8```#HPP$`"0```!_$`0`8````*<0!``L```!"Q`$`
M"@```$[$`0`K````6<0!``T```"%Q`$`$@```)/$`0`-````IL0!``@```"T
MQ`$`%````+W$`0`)````TL0!``P```#<Q`$`$````.G$`0`;````^L0!`!H`
M```6Q0$`+````#'%`0`+````7L4!``T```!JQ0$`!@```'C%`0`%````?\4!
M``4```"%Q0$`'0```(O%`0`4````J<4!``4```"^Q0$`"P```,3%`0`*````
MT,4!``@```#;Q0$`#P```.3%`0`1````],4!``X````&Q@$`"@```!7&`0`%
M````(,8!``X````FQ@$`10```#7&`0!B````>\8!`!P```#>Q@$`"0```/O&
M`0`C````!<<!`!D````IQP$`!0```$/'`0`4````2<<!``@```!>QP$`"P``
M`&?'`0`2````<\<!`"X```"&QP$`"P```+7'`0`0````P<<!`!$```#2QP$`
M$@```.3'`0`0````]\<!`$D````(R`$`#````%+(`0`D````7\@!`!4```"$
MR`$`%P```)K(`0`]````LL@!`"X```#PR`$`,````!_)`0`Q````4,D!`"T`
M``""R0$`#````+#)`0`*````O<D!`!````#(R0$`$P```-G)`0`;````[<D!
M``H````)R@$`$0```!3*`0`<````)LH!``<```!#R@$`&````$O*`0`7````
M9,H!``@```!\R@$`!@```(7*`0`+````C,H!``\```"8R@$`%````*C*`0`#
M````O<H!``@```#!R@$`"P```,K*`0`2````ULH!`!,```#IR@$`$0```/W*
M`0`1````#\L!``8````ARP$`"0```"C+`0`W````,LL!`#````!JRP$`+0``
M`)O+`0`'````R<L!`!,```#1RP$`!@```.7+`0`C````[,L!`!@````0S`$`
M)P```"G,`0`-````4<P!``D```!?S`$`)P```&G,`0`#````D<P!``8```"5
MS`$`"@```)S,`0`"````I\P!``D```"JS`$`$0```+3,`0`(````QLP!`!4`
M``#/S`$`&P```.7,`0`4`````<T!``4````6S0$`"@```!S-`0`4````)\T!
M`!$````\S0$`#````$[-`0`'````6\T!``P```!CS0$`"@```'#-`0`.````
M>\T!`%T```"*S0$`&@```.C-`0`K`````\X!`!8````OS@$`"@```$;.`0`&
M````4<X!``P```!8S@$`#@```&7.`0`3````=,X!`"0```"(S@$`'0```*W.
M`0`4````R\X!`"@```#@S@$`$`````G/`0`@````&L\!`!0````[SP$`$```
M`%#/`0!T````8<\!`",```#6SP$`&P```/K/`0`L````%M`!`"(```!#T`$`
M&P```&;0`0`E````@M`!`!D```"HT`$`&P```,+0`0`9````WM`!``L```#X
MT`$`!P````31`0`(````#-$!``D````5T0$`%````!_1`0`+````--$!`"0`
M``!`T0$`#P```&71`0`3````==$!``<```")T0$`"0```)'1`0!>````F]$!
M`$<```#ZT0$`.````$+2`0!;````>](!``D```#7T@$`(0```.'2`0`R````
M`],!``H````VTP$`"````$'3`0`2````2M,!`#\```!=TP$`"0```)W3`0!H
M````I],!`#`````0U`$`)P```$'4`0`0````:=0!`"(```!ZU`$`)````)W4
M`0`N````PM0!`"L```#QU`$`+@```!W5`0`Q````3-4!`!````!^U0$`!0``
M`(_5`0`+````E=4!``H```"AU0$`%0```*S5`0`*````PM4!`"P```#-U0$`
M#````/K5`0`)````!]8!``P````1U@$`%P```![6`0`)````-M8!``<```!`
MU@$`$P```$C6`0`)````7-8!``@```!FU@$`!@```&_6`0`+````=M8!``L`
M``""U@$`$0```([6`0`0````H-8!``X```"QU@$`&P```,#6`0`0````W-8!
M``<```#MU@$`%0```/76`0`8````"]<!``D````DUP$`"P```"[7`0`:````
M.M<!`"D```!5UP$`$@```'_7`0`E````DM<!`"<```"XUP$`#P```.#7`0`*
M````\-<!`!H```#[UP$`!@```!;8`0`$````'=@!`!@````BV`$`#@```#O8
M`0`0````2M@!``X```!;V`$`!0```&K8`0`)````<-@!``D```!ZV`$`"0``
M`(38`0`)````CM@!`!(```"8V`$`!@```*O8`0`-````LM@!``4```#`V`$`
M"0```,;8`0`+````T-@!`!H```#<V`$`"P```/?8`0`"`````]D!`"`````&
MV0$`"0```"?9`0`*````,=D!`&T````\V0$`"0```*K9`0`&````M-D!`"L`
M``"[V0$`/@```.?9`0`;````)MH!`"L```!"V@$`1````&[:`0`J````L]H!
M`#0```#>V@$`&@```!/;`0`8````+ML!``8```!'VP$`#````$[;`0`*````
M6]L!``T```!FVP$`!@```'3;`0`*````>]L!`!@```"&VP$`#````)_;`0`-
M````K-L!``\```"ZVP$`"P```,K;`0`-````UML!``@```#DVP$`"@```.W;
M`0`8````^-L!``D````1W`$`!@```!O<`0`+````(MP!`!,````NW`$`!@``
M`$+<`0`8````2=P!`!P```!BW`$`"@```'_<`0`8````BMP!``P```"CW`$`
M$@```+#<`0`+````P]P!`!(```#/W`$`"````.+<`0`2````Z]P!``8```#^
MW`$`&P````7=`0`,````(=T!`"$````NW0$`!0```%#=`0`%````5MT!``X`
M``!<W0$`(P```&O=`0`+````C]T!``T```";W0$`+````*G=`0`<````UMT!
M``X```#SW0$`!0````+>`0`,````"-X!``\````5W@$`#@```"7>`0`"````
M--X!``\````WW@$`"````$?>`0`D````4-X!`"D```!UW@$`+P```)_>`0`M
M````S]X!`"@```#]W@$`*````";?`0!=````3]\!`!,```"MWP$`60```,'?
M`0`T````&^`!`%X```!0X`$`6P```*_@`0`F````"^$!`#T````RX0$`,P``
M`'#A`0`W````I.$!`#4```#<X0$`'@```!+B`0`[````,>(!`.0!``!MX@$`
M(0```%+D`0`4````=.0!`%0```")Y`$`@@```-[D`0!"````8>4!`"D```"D
MY0$`/P```,[E`0!R````#N8!`%(```"!Y@$`,@```-3F`0`@````!^<!`!4`
M```HYP$`,@```#[G`0`=````<><!`!T```"/YP$`+0```*WG`0`C````V^<!
M`"@```#_YP$`00```"CH`0`=````:N@!`!,```"(Z`$`.@```)SH`0`H````
MU^@!`"D`````Z0$`(@```"KI`0`8````3>D!`$````!FZ0$`:0```*?I`0`[
M````$>H!`$X```!-Z@$`.P```)SJ`0`K````V.H!`#H````$ZP$`8P```#_K
M`0!,````H^L!`#(```#PZP$`+0```"/L`0`Q````4>P!`%0```"#[`$`6P``
M`-CL`0!-````-.T!`%$```""[0$`-````-3M`0`N````">X!`"X````X[@$`
M+@```&?N`0"(````ENX!`'T````?[P$`A@```)WO`0#0````)/`!`!,```#U
M\`$`)@````GQ`0`Y````,/$!`"P```!J\0$`2````)?Q`0`K````X/$!`$P`
M```,\@$`(````%GR`0`*````>O(!`,$```"%\@$`1P```$?S`0`F````C_,!
M`#4```"V\P$`)P```.SS`0`D````%/0!`#X````Y]`$`!@```'CT`0`'````
M?_0!``0```"']`$`#````(ST`0`+````F?0!``P```"E]`$`"P```++T`0`%
M````OO0!`!````#$]`$``P```-7T`0!G````V?0!``<```!!]0$`%0```$GU
M`0`$````7_4!``<```!D]0$`!@```&SU`0`%````<_4!`#X```!Y]0$`"0``
M`+CU`0`5````PO4!``L```#8]0$`$@```.3U`0`-````]_4!``(````%]@$`
M!P````CV`0`'````$/8!`!(````8]@$`#````"OV`0`8````./8!``8```!1
M]@$`#@```%CV`0`,````9_8!``,```!T]@$`*P```'CV`0`$````I/8!``<`
M``"I]@$`"````+'V`0`K````NO8!`$<```#F]@$`.@```"[W`0`[````:?<!
M`"(```"E]P$`-@```,CW`0`Y````__<!`"T````Y^`$`(P```&?X`0`F````
MB_@!`"H```"R^`$`)0```-WX`0`C`````_D!`"0````G^0$`+````$SY`0`A
M````>?D!`#P```";^0$`)@```-CY`0`Z````__D!`#4````Z^@$`*P```'#Z
M`0`N````G/H!`"X```#+^@$`*0```/KZ`0`J````)/L!`"X```!/^P$`*P``
M`'[[`0`P````JOL!`"X```#;^P$`*0````K\`0`I````-/P!`#,```!>_`$`
M)````)+\`0`N````M_P!`#@```#F_`$`.P```!_]`0`@````6_T!`"H```!\
M_0$`0P```*?]`0`I````Z_T!`"P````5_@$`+````$+^`0`M````;_X!`"<`
M``"=_@$`'0```,7^`0`K````X_X!`"P````/_P$`-P```#S_`0`L````=/\!
M`$$```"A_P$`#````./_`0`3````\/\!`"`````$``(`,0```"4``@`D````
M5P`"``D```!\``(`#P```(8``@`<````E@`"`!0```"S``(`$````,@``@`Q
M````V0`"``@````+`0(`"````!0!`@`C````'0$"`"8```!!`0(`'````&@!
M`@`G````A0$"`!\```"M`0(`"0```,T!`@#A````UP$"`!(```"Y`@(`&@``
M`,P"`@`)````YP("``P```#Q`@(`%````/X"`@`0````$P,"`!H````D`P(`
M!@```#\#`@`W````1@,"`!4```!^`P(`%P```)0#`@`'````K`,"`!,```"T
M`P(`"P```,@#`@`\````U`,"``D````1!`(`*P```!L$`@`0````1P0"`!``
M``!8!`(`%0```&D$`@`T````?P0"`"````"T!`(`#@```-4$`@`?````Y`0"
M``\````$!0(`$````!0%`@`:````)04"``L```!`!0(`&P```$P%`@`+````
M:`4"`"0```!T!0(`"@```)D%`@`;````I`4"`"L```#`!0(`!P```.P%`@`G
M````]`4"``<````<!@(`"0```"0&`@`)````+@8"`#L````X!@(`!@```'0&
M`@`.````>P8"`!,```"*!@(`%@```)X&`@`*````M08"``@```#`!@(`!P``
M`,D&`@`3````T08"``L```#E!@(`'````/$&`@`/````#@<"`!@````>!P(`
M%@```#<'`@`%````3@<"``<```!4!P(`%P```%P'`@`$````=`<"`#,```!Y
M!P(`#````*T'`@`0````N@<"``P```#+!P(``@```-@'`@`1````VP<"`"(`
M``#M!P(`"P```!`(`@`#````'`@"``<````@"`(`"0```"@(`@`&````,@@"
M``T````Y"`(`"@```$<(`@`4````4@@"`!4```!G"`(`$0```'T(`@`V````
MCP@"`!X```#&"`(`&@```.4(`@`7``````D"``L````8"0(`,P```"0)`@`'
M````6`D"`!<```!@"0(`2P```'@)`@`4````Q`D"``\```#9"0(`"````.D)
M`@`$````\@D"``0```#W"0(`"@```/P)`@`6````!PH"``4````>"@(`!@``
M`"0*`@`(````*PH"``D````T"@(`!````#X*`@`)````0PH"``X```!-"@(`
M/0```%P*`@`Q````F@H"`"X```#,"@(`!0```/L*`@`7`````0L"`"`````9
M"P(`(0```#H+`@`E````7`L"`!````"""P(``@```),+`@`$````E@L"``H`
M``";"P(`"0```*8+`@`%````L`L"``(```"V"P(`'P```+D+`@!.````V0L"
M`#D````H#`(`'@```&(,`@`S````@0P"`"H```"U#`(`8````.`,`@`0````
M00T"`'P```!2#0(`)P```,\-`@!3````]PT"`"@```!+#@(`4@```'0.`@`X
M````QPX"`#,`````#P(`-````#0/`@`Y````:0\"`#@```"C#P(`/P```-P/
M`@`_````'!`"`"T```!<$`(`,````(H0`@`S````NQ`"``X```#O$`(`#@``
M`/X0`@`-````#1$"`(,````;$0(`"````)\1`@"Q````J!$"`(T```!:$@(`
MB````.@2`@`N````<1,"`%H```"@$P(`%````/L3`@`E````$!0"`!@````V
M%`(`$@```$\4`@`:````8A0"`",```!]%`(`-P```*$4`@`:````V10"`!@`
M``#T%`(`5@````T5`@`:````9!4"`!8```!_%0(`"P```)85`@`%````HA4"
M``8```"H%0(`"````*\5`@`%````N!4"`!L```"^%0(`$0```-H5`@`>````
M[!4"`!\````+%@(`$0```"L6`@`'````/18"``0```!%%@(`"0```$H6`@`.
M````5!8"``@```!C%@(`!0```&P6`@`<````<A8"``H```"/%@(`"0```)H6
M`@`/````I!8"``<```"T%@(`"````+P6`@`2````Q18"``H```#8%@(`%@``
M`.,6`@`+````^A8"``D````&%P(`%@```!`7`@`(````)Q<"``0````P%P(`
M'````#47`@`5````4A<"``D```!H%P(`&@```'(7`@`0````C1<"`"$```">
M%P(`#P```,`7`@`(````T!<"`!0```#9%P(`!@```.X7`@`'````]1<"`!<`
M``#]%P(`"````!48`@`"````'A@"``(````A&`(`$0```"08`@`+````-A@"
M``8```!"&`(`$0```$D8`@`4````6Q@"``<```!P&`(`+0```'@8`@`"````
MIA@"``0```"I&`(`$P```*X8`@`7````PA@"``L```#:&`(`!P```.88`@`/
M````[A@"``8```#^&`(`%P````49`@`(````'1D"`!@````F&0(`$````#\9
M`@`2````4!D"``(```!C&0(`!P```&89`@`+````;AD"``H```!Z&0(`%0``
M`(49`@`R````FQD"``<```#.&0(`"0```-89`@`1````X!D"``4```#R&0(`
M`@```/@9`@`+````^QD"``$```#3!```'`0``#$%``!?`P```````)P!``!M
M`@``H`0```````"4`P``QP$``/L&``!\``````````````"&`@``*0<```L!
M````````@0<``,$```!W!0``%00``/`%```L````VP,``,$&```C!P``"`(`
M``$$``"\!0```@<``#$#````````I@(``.\%``!D`@``L@(```\$``"!`P``
M`````````````````````-8$``!1!0``A00`````````````]@$``'`"````
M`````````'\"```N!````````",!``"D!0```````&('``#C!0``CP8``"4!
M``!P!@``]00``&X"``!P`0``,P<``,(!``#1`@``+P0``&\#``!.!P``6@``
M`*(!```S`0``B0<```````![`0``ZP```)8&``#`!0``7`<``$H%``#,!@``
M`````)0$``!B`@``\@```"D"``!F`@```````-L$``"$!@``W04`````````
M````I0```````````````````)@#````````0````.0&````````S0$`````
M``"=!```2`(``+\%````````_0(``(@'````````#`4```````!/!```RP4`
M`.P"```F!0``%P`````````T````6````+P!`````````````+4"``!:!```
M90,``&H#``!?`0``@@<``````````````````/H!``!D`P``;P```-8!````
M````?08````````(!P``D`````````!-`P``FP(````````<`P``708``/0!
M``#?````*`,``-P!``#0`0``M@,``$<#````````&P<``!$'```E`P``\0``
M`+`%``#2!`````````````"K`P``I`````````#*!0``80,``'D#``"5!```
M"@0```````"*!@``P`$```````#A!```>`<``-D#``#G`0```````/X%``!*
M!P``J0$``%@$``#D`0```````$\```"^`0``````````````````+P,``&P'
M````````L@````````"8!0``9P0``*0&``#B`0``1@8````````J````^P$`
M`&@!``!4!P``V@,``"@&``"C!```5`8``%8$``"O!@```````)T"``!;````
MD@8``(L#``"I`````````*P%``#3````H`,``'H!``!G`@``P@,``"@'``![
M`P``*P`````````V```````````````Q`@``@P```.0$````````]@0``'D$
M``!$!P```````/<``````````````),"``"Z!0```````!<%``"J`P``*P(`
M`'H'````````=`0``#L"`````````````)`"``".`0``B@0``-P```!\!P``
M5P4``)H#```#`@``.P<``%X#```&`0```````$4$````````+0<``)\#``"E
M`0````````````!G!0``<0$`````````````0@8``-L````]!P``2@``````
M```"`@```````"D!````````5@,```````"<!````````,P!``!A!```%@,`
M```````G!```80``````````````)00``'<```#N`P``9@8```````"<!@``
M_P4``'L`````````&`8``+$$```#`````P<``-P%``"W!@``R0,``'P"```6
M!P``[```````````````8P$```````#N`@``F@```)(```">`P```````)L!
M```K!0``<0(``/,#``!&`P``O@(``+H!``#=!```U@8``+0#``#C!```R@0`
M`*H$````````&`<``!<"``"_!```&`$``+$"`````````````.(#``"/`@``
M`````'X!``#]!0``:0$``!8&``#X`0``*@,``$L#``!R`P``1P0``)8!``!'
M````R`$``'$#``!.!@``.@```&`&``!3````U08``'8"````````+@4``"8"
M``!S!@``[0````H&```$````Y`(``'X#``"#!0``B0$``),$``#^`@``9`<`
M`.8%```7`0```````)\!```-!P``>P(``'X````%!```"0<``"T&```T!@``
M`````%("``"_`````````'<#``#_`P````````L````S!0````````````!F
M!P``)P8``-T`````````]`(``#\'````````V`,``-H$`````````````&@`
M```-`@``<@8```````#3!@``Q08``'$```"@````_`8``$("````````FP0`
M`+D#``#`````!`0```X&``!,`0``E`(``+D%``"@`0``P0$````````%````
M`````$P'``#6`@``8P````````#$````````````````````\@0```````!`
M!0``;P<```````#-!@```````!<#``"!!@````````````!2!0``````````
M``#S!```=P0``*,&``!O!```"````%X```!(!P``N@,``'8%``#>````A`,`
M`"0$```[!0``]P8``)P#``!W`@```````&H!```^`@``O@8``.T%``"^!```
M`````&\&````````B0```*4"````````,P8````````<!P```````%4!```B
M!```.`$```````!M!````````(<"``!Y!0``@`4``-8`````````(0(``$\&
M```W!```,P(`````````````EP,``/\$````!P``!P,``&D&````````\0$`
M`,8```#P`P``CP```%L'`````````````.<&``"%`P````````````#=`@``
M+@,``%<!``#T!@```````.4!``#^````30```,T$```0!0```````#8!``"0
M`P``?0$``)<```!9!```?P0``',```"G!0``6`(``(("````````008``'8!
M``#^`0```````.<$````````)`````````#X!```:P0``,8$``!9`0``(00`
M``8```"?`@``7@(``````````````P8``)0%````````X08``(X#```^````
M*P$``!0"``#7`P``D08``$`'````````;`,```````".!```HP````````#%
M`P``40```+T"```L!```(`0``.D$````````+`8``/8"```N!@``6`4`````
M`````````````*D"```D`P````````````"S`0```````'T````G`P``````
M`'('````````D00```````#.`0``\`8```@!`````````````````````0``
M3`4``#@&````````R`4``!$!``!?!```^@,``)P```"P`P``Q`$```````!U
M!```<00``-<"``#)!0``?`$``(P!``````````````````#\!0``-00`````
M```^!P``I08``-`#``"H!@``[0$``*8`````````[P(`````````````````
M`*T$``#K`0``^00``-\#```H!````````&8$``"?````#P8``+D$``#J`P``
M`````,D$``!;`@``C`0```````#$`@``O@4``$(%``!T!P``U04``),&````
M````8P<`````````````&P0```````#T`P``5````-D`````````2````)8`
M````````5@(``#<````?!@``/`(``',"````````\P(````````(!```MP(`
M`*4$``!W!P```````-H&```5`````````-D$````````_``````````?!0``
MBP4``/<!``#V!0``?`,``-@&``"T!0``E04```,%````````````````````
M````@P0``+\"``#.`@``#`<``)D#``#_`@```````/0$```_`@``4P$`````
M``#%!```,@$```````#+`@``C```````````````2P$`````````````N@8`
M``D!``#>`0``)@0``*0#``#,!0``<P$``#,$```0!@``BP0``&(`````````
M+P```*`&```X`@``60(``'\'``!'!P``C04``!D`````````K0```.\#``#1
M!@``?`4``#(```"]!0``R@(```````#V!@``M@8``%L%``!$`0``````````
M```=`@``'@<``-L&````````#@4```````!@`0``.0(``$,"``"[`0``@`,`
M```````J`0``1@```-`"```3!@```````'\```!"`P``-0<``"T!```Q!```
MX0$```````#1!0``M`(``.@!``!4`P``^`,``'T$````````H@,``-0"``!B
M`P``Z@4`````````````7P```!\"```R`P``_`(```````!S!````````(`&
M```W!0``.@4``!@$````````=@```*,#````````EP4``&(%```2`@``;`$`
M`"(!````````C@````````!J!0```````,4%```:`0``X`$```````"3`P``
MF`````````"%!0``&``````````L!0``A@0````````<````F08``&@&``#[
M`@``A0$```````!,`P``:`<``'H$```0!```90```%0%``#$!@``=`(``.``
M`````````````+<#``!U`P````````````````````````````!<`0``````
M`#@'``!^`@``;```````````````B`(```````#.!@``"P(```\%``!M`0``
M+0(``-\%``#G`@``3P,```T!``!@````9P````````"_!@``V0(``+D&````
M``````````````#J````L@0``"@`````````+P<```````#S````J@4``/T!
M``#5!```&@```````````````````&($````````R`8``%\&``!.````````
M`!,"`````````````$H$```5!@``(P```#\```""!0``J`0``+@"``"1!0``
MY````$($````````N`4``$$%```?`0``N`$```````";!0```````+4````!
M!P``*P<`````````````L`0```````!I!P``>P4``&8`````````````````
M``#.!```!P$``%<&`````````````-\&``!@!P``.P$``#L$``!U`@``ZP8`
M`#D$```?!P``_08``'$&```,`0```````$<&``"=!@``O`0``&4&```)!0``
M10<``````````````````',#``"+````>0<``-(#```!`@``HP$``"P#````
M````LP0````````D!P```0,``.L"``!P````;08``-@````1!@``10,``%T'
M``#R!0``Z`8``-$$```_`P```````/H%``!E!P``GP8``-("````````:P$`
M`-$```")!@``,````,@"``"A!```[`$``.(```!J`@``I@$``%P"````````
M.`,```````!;!@``*P0``&`#``#@!0```````,\```"6!0``UP8``$4"````
M`````````)4!``````````````8&``!&!0``_@8```````!)`P``;`4``%,'
M``#3`0``@`$`````````````````````````````_00``&P$```&!```/@,`
M`!\$``#?!````````%P#``!^!```$0(``"L&``#+!```&P,```````!^!@``
M=0````4#``"1`0```````*P`````````!`(``'D!```I!```-`<```````!Z
M````=```````````````8@$``%0!```-````/P$``-X#``"T!@``-P<`````
M````````)@```````````````````(@%``"/!````````$8$````!@``````
M`+,```!0`0``D`8``+(!```6`@``4`(``(<#``!N!P``]0(``+8```#R!@``
M\0,``%$!``#B!```[P0```````#/!@```````"\"````````"P<``%``````
M````5`(```````!+!@``@0(````````;!@```````/,&``"+!@``NP```%P&
M````````^0$``(0```!%!@```````'4!`````````````$0"``!(`0``%0,`
M```````D`0``60,``/4```":!0``4P4``-P&```Y`0``&0<```````"(`0``
M7`4``%<$``!!!P``F@(``#T#```1`P``K@4``$D!````````GP0````````^
M`0``:@```'X%``"G`P``IP8``"``````````K@```$L````2````I@0```$!
M``!X!@```````-4!``"Z````Y`,``+8!`````````````&@$````````````
M`+X```"Y````<@0````````1````7P4``.8$```@`P``JP$``.8````B`@``
MG@8``+T!``#R`0``.08``((&````````@0```!($``"[`@``/00``'\!```;
M````LP(```````"]`P``=04``&4"``"%`````````,T"``##!@``?P4`````
M``!7`@``GP4``/`!``"M`P```````(H%``!R`0``L0```($$````````[P8`
M```````0!P``;P(```````#M`P```````!`"```4`0``+0,``$0$````````
MU0,``-\"````````>P8``$D%````````V@4``(<$````````L08``/<"``"O
M!```!0(````````A````^P4``'<!```\`P``"08``/,%``#P`@``<04``+@#
M````````U`,``.@"``!8!@```````'L$``!!`P```````"H"``"<!0``Q@4`
M`-D%``!A!0````````````#_!@``>@4``$<"```\````O```````````````
M#P,`````````````#P<``#8&```4!`````````````!A`@``!P<``#,#````
M````0`$``#T%````````F@8`````````````AP$``,D```#I`P``XP8``+T`
M``"+`0``O00````````V`P``-0(``!T%````````A@8``*X$```'`@``ZP0`
M`+\#``````````````````!)!```4`8``+4$``!S!0``Q`,```````!K`P``
MV@$``+`!````````DP4```````#)!@``H@4````````)`P``?0,``!,````-
M!```Q0$```L$````````00(``%4```#B!0```````*P#```#`P``&00```4&
M`````````````.H$``#K!0``"@,``*@%``"W!```%@```%0$```W`0``504`
M`*0"``#Y`@```````(`"```C!0``^P,``$,!``!J!``````````````_!0``
M$P$```````#R`P``QP0``+T&````````2`,```````#-`P``704``'P$```\
M!@``^0```!X%``!&`0```````*L```!6`0``Z`0``(T`````````S@,``#<&
M`````````````,L```"'````W0,`````````````S`0```````!1!P``````
M`!D%````````YP,``#$```#,`P``B04``!`!```.````:@<``*<```#/!```
M80<``!<&``#:````(0$``*("``"8`@``7@0``"T$```B!P``90$``'@"```3
M!P``'00``-@%``"<`@``70````````#@!```9@4``#X&``#F`@```````+(%
M````````!`,``!X$```````````````````$!0```````),!``"%!@``=`,`
M`*\#``#Y!@```````)($``"%`@``'08```````#<`P```````%L!``!:!P``
M%`,``/$"```R!P``=`4``*@#``!=`0``*@8``````````````````*X&``#@
M`P``3@,``/P$```Y!P``>`0````````O!0``9P8``-0```"@`@``^0,`````
M```H!0``A0<``.P%``!R`@```````"D`````````!@(````````*!P``Y00`
M``````!1!@`````````````F!P```08```````!&`@``````````````````
MUP$``,T````W`P``!`$````````J!P``<0<``&(&````````@04``&X!``"O
M`@``Q`0``"X"``!5!```````````````````A`4``!,$``"1`@``5@8``-(`
M``"N`P``2`8``#8'``![!P```````-`$```;!0```````+H$````````````
M`((!`````````````","``!:`0```````!H'```Q!P``(`(``*@"```E!P``
M`````#H$``")`@``:P```/$&```Y!0``/`$``!$%````````Y`4``(H````<
M`0``JP0``(D#```&!0```````"(%``!=`@```````.H!````````^@0`````
M``#?`0``1P4````````2!@``B````.D"```T!```Y0,``*L%``#-!0``QP,`
M```````_!```````````````````Z@(``*$#``#^`P``&`4``#,```#U!0``
M=@<```````!N!@```````,L#``!O`0``'@,``%D%````````A@```(,!````
M````M````(\#``"$!```,`0``+<!``"9`@``H`4``+8"``#E`@```````#($
M``"A````+`(``,@#```+`P```````(P%````````&@8``*P$````````````
M``````!K!0```````-@!````````#@0```<&````````)0```.$#``">````
M``````````!R!0``'@8````````5`0``/@4``!T```#,`@``G@4``(@&``".
M`@``(04``)8"````````/P8``$`&``"A`0``H04``"<"`````````````"T`
M``!)!P``E0(``%($`````````````#0"``#W!0``=`$``%T#```U`0``````
M`$X$``!6!0``H@0```D```##!0``@P,```````!8`0``:0(``.P#```9`@``
M`````,("``!9!P``0P,``#P$``"0`0``Y@$``.,#``!1!`````````````"L
M`@``#@(``!P"``!.`0``2`0```H`````````3`8``/P!```N````C0$`````
M```L!P``[0(``.D!``#/`0``;`(`````````````V@(``,,"```G````LP,`
M`)(%````````;@```!``````````C00``!L!``!P!```=0<````#``#>!0``
M4@<``+(#```&!P``C0,```````"-`@``9P$``((#``"_`0``=@8``&X$``"J
M````3@(``&0%````````C`,``"X'``""!````````+P#```^!```&`(`````
M```W`@``D@,``((`````!```````````````````#P(``!4"``#"````NP,`
M``````#0!@``,`4``.X```#!!0```````$@%```2!P``6`<```($``!>`0``
M``````````#9`0``208``/$$``!L!@``.`4``#H'``":`0``X0```+P"``"^
M`P``%@0`````````````F04``.D%``#U`P```````$('```9`P``[`0``)4#
M```"`P``"`8``(T&````````:P8``%\'```N`0``)08```````!D!@``:0,`
M``````!>!@``M0,```H"``!)`@``'P````L&``!D`0````````````!/`@``
M``````````"F!0``,`8``+$!```,!@``T@$``#4%``"&`0``7``````````Z
M!@``Y@,``!H%``"[!```K0(```````"`````>@,``(<&````````@P8``-T!
M```U`P``[P$`````````````#````)8#``!C`@``G@(``/$%````````````
M``````!D!`````````````#I````M@4``*$&````````'@$``,$#```[!@``
M<`4``(0!``!K`@```````$T$``#F!@```````,8&``"/`0```````,,````=
M!P```````&,$``!S!P````````T%```]`0``3P<``&T#```A!@``1````!4'
M`````````````-@"``!)````.P,``!<$````````[P```&H&````````"@4`
M`%,#```'!0``)`4``+4&``"I!```!P0``$<!``!#!@``````````````````
M(`4```````"P````KP```"\&``#N!@``XP`````````B!@``$@,``,$$``#9
M!@````````````!_`P``#`0``!@#``"L`0```````+D!``#B!@``S@``````
M``"2`0``?@<``,4"```"!0```````#0!````````J````"P!```.`P``````
M`)`$```9`0``H@```%`%````````Z08``-4"```````````````````)!```
MF0$``)L#``"J`0``#`(``-0%``#T!0``]0$```T#````````G0$``,4`````
M````Q@(``%<````X````*`(`````````````_0,``*<$``"[!0```````,(%
M````````3P$``!T!``#L!@``^`8``)8$``!0!````````*T!````````````
M`*0!``"I!0``L`(``&,&````````U@,``!8%``"F`P```````!H"````!0``
M`````(8'``"`!P``T`4``.,!``"L!@``XP(``,`&``"K`@``<`,``)`%``"O
M`0```````-(%``"B!@```````+4%````````S@4``&T%````````^`(`````
M``#=!@`````````````?`P``?0<``+0$``"F!@```````,0%``"G`0``0P``
M`)T#```;`@```````$P$`````````@$``)<"``!/!0``0`,``'D&``#<`@``
M`````$8'``!C!0``?P8``$0#``#E````304``,(&````````````````````
M````T````%L#``"W````>0(``$,%````````4@8``-8%``!*`@``/0```"T%
M````````>@8``.`"``!@!```&@,``````````````````,,$````````TP,`
M`.("``!X`P``E````(<'```:!````````````````````````$$$```9!@``
M``````````!0!P```````"D#``#]````5P,`````````````(0<``%$#```Z
M`@``DP```/,!``!5`@`````````````-!@```````)D$````````0@$``%\"
M``!+!```2P<``&X%``"Q`P```````(0"``!-!@```````"8!````````VP$`
M``````"Q!0``<`<``-P$``!I!0``LP8``"<%```\!P``0P<``$H#``!I!```
MSP,```````!H`@``KP4``(`$``!V`P``T0,``%`#``"8`0``X0(``$P"``#"
M!````````(@$``!K!P``<@```````````````````/H"````````,@4``&@#
M```%!P``(P,``'P&````````Z`,``)<$``"U`0``R@8``,\"```H`0``EP$`
M`,L!````````5@<``%,"``!:`P``A@4````````P`@``^````)D`````````
MS````*X"```T!0```````-<`````````I04``````````````````"0&``"8
M!@``[@$``"$#```[````EP8``$$!``#&`P``C`(```0'```5!0``904`````
M`````````````"(#``"*`@``'@```(,'``!5!P``K04``$4```!U!@``.`0`
M`,,!``#4`0``0@```&4$```G!P``;P4``/4&``!6````#@$``/D%``!-`@``
M_@0``%H"``"C!0``!`8``.@%```B````104```````!*!@``F`0``)L&``#!
M`@```P0`````````````O`8``&X#```4!@``[08```````!]!0``Z````#0#
M``!:!0``$@4```\!```>`@```````&@%````````+P$``#T"``!-`0``,`$`
M`"4"``#5`````````"4%``!F`P``]@```'H"``".!@````````````"C`@``
M`````*X!``#\`P``80$``+@```"1````````````````````E0```"8#```/
M``````````````"*`P```````'T"``#'!0``Q@$```````"&`P``(`<``)X!
M````````VP(``,D!```*`0``50,``'D```#4!```PP,```````#*`0``$P,`
M`````````````````&T'``#P!```=@0```@#````````/08``-@$````````
MH0(``&T```"/!0``%P<```````!7!P``*@0```(```!@`@``'`4```````#X
M!0``3@4```````#(````#`,``(L"````````I0,```@%````````.0,``/\!
M```.!P``700```D"````````3````)H$``#1`0``*04``.<%````````>```
M``````!F`0``\````.X%``!+`@``MP4```4%````````4@```.L#``!+!0``
MU`8``#D```#(!```G04``,`"``!>!P```P$``'<&``!$!0``W@8`````````
M````!P```#8%```K`P``^@```,<&```4!P```@8``,H```!X`0``$@$``/<#
M``#E!0``J@8``%,$``!2`0````````8#``"Y`@``30<``!0```"1`P``J@(`
M`%P$``#7!```.@,``#`#``#T````0`0```````#>`@``L`8`````````````
MVP4``&$&``#``P``R@,``.T$``!;!```E`$``(@#``!G!P``A`<`````````
M````$P4``(P&``"D!```,`<``(H!``!#!```FP```"`&``#R`@``=`8`````
M````````M@0````````0`P``Z@8``&`%````````^P0``)0&``#A!0``*08`
M````````````]P0```````"Z`@```````+0!``!$!@```````*T&``!5!@``
M/`4```````!!````-@0````````R`@````````$%````````C@4``!T#``"G
M`@````````````!2`P``)@8``-,%``#Z!@```````*@!``!C`P``$00`````
M````````4P8``"<!``"S!0```````.4&``#3`@```````(<%``"#`@``N`8`
M`%@#``"!`0```````.X$```D`@``T@8````````U````NP8``,D"``"I`P``
M60`````````Q`0```````.`&``"R!@``"P4``$4!``!:!@``N`0``#4&````
M````608```````!D````(P8``,<"````````G0```/\````%`0``0`(``(D$
M``!I````UP4``"`!``">!````````)("```4!0```````#H!``#/!0``````
M`!8!````````>`4``,<```#+!@````````````!>!0``(P0``/8#```J!0``
MYP```,`$``"I!@``'`8``$H!```Q!@````(``&<#``#>!```-@(`````````
M````^P```*L&``"5!@``40(````````R!@```"`H)7,@9&%Y<R!A9V\I`"`H
M06-C97-S:V5Y("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R
M;W<I`"`H>65S=&5R9&%Y*0`@870@`"(E<R(@:7,@;F]T(&$@9&ER96-T;W)Y
M+@`B)7,B(&ES(&YO="!A('9A;&ED(&-H;VEC92X`(B5S(B!I<R!N;W0@8V]N
M9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN`"(E<R(@=')E92!R96YD
M97)E<B!N;W0@9F]U;F0N`"(E<R(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@
M<WES=&5M+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES
M=&5M+@`B)7,B('=A<R!N;W0@8W)E871E9#H@)7,N`"4N,F9-0B!U<V5D(&]F
M("4N,F9-0B!A;&QO=V5D("@E+C)F)24I`"5D("5S(&%N9"`E<P`E9"!D87ES
M('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RX`)60M9&%Y(&9O<F5C87-T
M`"5S("T@3F]T:6-E`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT96YA
M;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T=7``)7,@4VEG
M;B!5<``E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D>2!E>&ES=',N
M`"5S(&%T("5S("5S`"5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE(&)O
M>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T
M('1H:7,@=&EM92X`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@
M9F]U;F0N`"5S('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K`"5S)W,@
M0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"5S
M.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US
M('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG(&%N>2!L:6YK<R!I;B!I="!O
M<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I
M;F9O<FUA=&EO;BX`+"!G=7-T:6YG(``L(&=U<W1I;F<@)7,@)7,`+"!V87)I
M86)L92!F<F]M("5S('1O("5S`"TM('-E;&5C="`M+0`Q,B!(;W5R($9O<FUA
M=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P`\4')E=FEO=7,`02!D871A8F%S
M92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L
M(&5R<F]R(&AA<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES
M(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI
M8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0
M(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL
M('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y
M+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES
M(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!32!#;&]U9',`04T@
M3&EG:'0@4F%I;@!!32!286EN`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W97)S
M`$%-+U!-`$%022!)1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B
M;W1T;VT`06)S;6ED9&QE`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I
M<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`06-C
M;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@9G)O
M>F5N+@!!8V-O=6YT:6YG`$%D9`!!9&0@0VAI;&0@1W)O=7``061D($-H:6QD
M(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D($YE=R!0
M97)M:7-S:6]N`$%D9"!A(&-H:6QD(&=R;W5P('1O("(E<R(`061D(&$@8VAI
M;&0@<&5R;6ES<VEO;B!T;R`B)7,B`$%D9"!A(&YE=R!U<V5R.@!!9&0@8V]L
M=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@
M87,@82!-;WII;&QA(%-I9&5B87(`061D('1O(&%D9')E<W,@8F]O:SH`061D
M('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1E9"`B)7,B('1O('1H
M92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P
M(&EN9F]R;6%T:6]N.B`E<RX`061D960@(B5S(B!T;R!T:&4@<WES=&5M+B!9
M;W4@8V%N(&QO9R!I;B!N;W<N`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`
M061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E="!P97)M:7-S
M:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S`$%F9VAA
M;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&EG;FUE;G0Z
M`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!0
M97)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT:7!L92!A9&1R
M97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR
M96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E($E-
M4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N871E
M(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E<FYA=&4@
M=&5X=#H`06UE<FEC86X@4V%M;V$`06X@:6QL96=A;"!V86QU92!W87,@<W!E
M8VEF:65D+@!!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+@!!;F1O<G)A
M`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`06YS=V5R`$%N=&%R
M8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D80!!<'!L:6-A=&EO;@!!<'!L:6-A
M=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L>2!T;R!#:&EL
M9"!3:&%R97,`07!P<F]V90!!<'!R;WAI;6%T92!3:7IE`$%P<FEL`$%R86)I
M8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA
M;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P
M(')E<75E<W0@9F]R("5S(#\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E
M;&5T92`B)7,B(&%N9"!A;GD@<W5B+6=R;W5P<S\`07)G96YT:6YA`$%R;65N
M:6$`07)M96YI86X@*$%235-#24DM."D`07)T`$%R=6)A`$%S8V5N<VEO;B!)
M<VQA;F0`07-C:6D@07)T`$%S:6$O4&%C:69I8R!296=I;VX`07-K(&9O<B!C
M;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1E;7!T('1O(&1E;&5T92!A(&YO
M;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI
M<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T
M96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N
M="!S:&%R92X`071T<FEB=71E<P!!=6=U<W0`075S=')A;&EA`$%U<W1R:6$`
M075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D
M(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS
M:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M
M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@
M<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5M
M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C
M=&]R>0!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L92!T
M;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@
M=7-E<B`E<P!!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P
M;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN`$%U=&A?;6-A;#H@4F5Q=6ER
M960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E
M<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"X`075T:&5N=&EC
M871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO;B!F
M86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO
M;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T
M;R!&5%`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@=&\@=&AE(%--
M0B!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I:F%N
M`$)/1D@@17AC=7-E<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D
M(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A
M:&%M87,`0F%H<F%I;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H
M`$)A<F)A9&]S`$)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y("(E<R(@;F]T(&9O
M=6YD+@!"87-E;&EN90!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E
M<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@87!P;&EC871I
M;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`
M0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S
M<SH`0F]R9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A
M;F$`0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N
M($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I80!"
M=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`0U),
M($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#86-H
M92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+@!#86QE;F1A<@!#86QM`$-A;6)O
M9&EA`$-A;65R;V]N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC
M86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B!N;W0@=W)I
M=&4@=&\@9FEL92`B)7,B`$-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S
M<VEO;B!H86YD;&5R<RX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@
M)7,`0V%N)W0@;W!E;B!F:6QE("(E<R(N`$-A;F%D80!#86YC96P`0V%N8V5L
M(%!R;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN
M;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D
M('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V
M92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@
M97AI<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P
M;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D
M+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#
M87!E(%9E<F1E`$-A<'1I;VX`0V%R<FEE<@!#871E9V]R:65S(&%N9"!,86)E
M;',`0V%Y;6%N($ES;&%N9',`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`
M0V5L;"!P861D:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#
M96QL<&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R86P@
M069R:6-A;B!297!U8FQI8P!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR
M*0!#97)T:69I8V%T92!$971A:6QS`$-E<G1I9FEC871E($]W;F5R`$-E<G1I
M9FEC871E(%!O;&EC:65S`$-H860`0VAA;F=E`$-H86YG92!9;W5R(%!A<W-W
M;W)D`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S
M964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#
M:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T
M:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@0V]N=&%C="!Y;W5R(&%D;6EN
M:7-T<F%T;W(N`$-H87(`0VAE8U]K($QI;FLN+BX`0VAI;&4`0VAI;F$`0VAI
M;F5S92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@
M*$)I9S4I`$-H;V]S92!!<'!L:6-A=&EO;CH`0VAO;W-E(&$@<&%S<W=O<F0`
M0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S
M.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`
M0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F
M;W5N9"X`0VQE87(`0VQE87(@35-/9F9I8V4@=&%G<P!#;&5A<B!1=65R>0!#
M;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`
M0VQE87)I;F<@3&%T90!#;&EC:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL('9I
M82!(5%10`$-L;W-E(%=I;F1O=P!#;&]U9',`0VQO=61S($5A<FQY`$-L;W5D
M>0!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#;VQL87!S92!3:61E8F%R`$-O
M;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME<@!#
M;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S`$-O
M;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O;6]R
M;W,`0V]M<&%N>0!#;VUP=71E<G,`0V]N9&ET:6]N`$-O;F1I=&EO;G,`0V]N
M9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F%T:6]N(&9O<B!S>6YC
M:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN`$-O;F9I
M9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N`$-O;F9I9W5R92`E<P!#;VYF:7)M
M(%!A<W-W;W)D`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI
M8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I;&5D
M.B``0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R
M+@!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N
M(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I
M;&5D+@!#;VYT86-T<P!#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E
M9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&5N="!T>7!E(&]F(&-O;7!R
M97-S960@9FEL93H@`$-O;G1E;G1S(&]F("(E<R(`0V]N=&EN=64`0V]O:R!)
M<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@9F%I;&5D.B`E<P!#;W!Y('-E;&5C
M=&EO;@!#;W-T($E$`$-O<W1A(%)I8V$`0V]T92!D)TEV;VER90!#;W5L9"!N
M;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@`$-O=6QD(&YO="!01U`@<VEG;B!M
M97-S86=E.B``0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O
M=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@861D(&-O
M;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L
M9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-O;FYE8W0@=&\@
M3$1!4"!S97)V97(N`$-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B`B)7,B
M('5S:6YG($944#H@)7,`0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z(`!#;W5L9"!N
M;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT
M86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<P!#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N
M`$-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A
M9&1R97-S+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K
M+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N
M`$-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB
M=71I;VX@;&ES=',N`$-O=6QD(&YO="!L;V%D('-T<F%T96=Y("(E<R(N`$-O
M=6QD(&YO="!M:V1I<B`B)7,B+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K
M97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`B)7,B(&9O
M<B!W<FET:6YG+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@
M36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T(&]P96X@9&ER
M96-T;W)Y("(E<R(N`$-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N
M`$-O=6QD(&YO="!R96%D("5S+@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W
M;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H
M92!D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A
M8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L
M<"X`0V]U;&0@;F]T(')E=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@
M861D<F5S<R!B;V]K+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@
M;&ES=',N("5S`$-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL
M:71I97,`0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N
M;W0@<FUD:7(@(B5S(BX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO
M;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L
M9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD(&YO
M="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!#;W5L9"!N
M;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`0V]U
M;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A
M;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T;R!S879E('1H92!C
M;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO
M=R!T;R`E<RX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O
M=6QD(&YO="!U;FQI;FL@(B5S(BX`0V]U;&0@;F]T('5P9&%T92!C;VYT86-T
M+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#
M;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@(B5S(CH@)7,`0V]U
M;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE
M('-I9&5B87(@:7,@;W!E;BX`0V]U;&1N)W0@9VEV92!U<V5R("(E<R(@=&AE
M(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@(B5S(CH@)7,`0V]U
M;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@;&EN
M:P!#<F5A=&4@82!N97<@;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&]R
M(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`
M0W5R<F5N="`T(%!H87-E<P!#=7)R96YT(%-E<W-I;VYS`$-U<G)E;G0@5&EM
M90!#=7)R96YT(%523"!I<P!#=7)R96YT(%5S97)S`$-U<G)E;G0@5V5A=&AE
M<@!#=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE
M('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C
M=&EO;@!#>7!R=7,`0WER:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O
M=W,M,3(U,2D`0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I`$-Z96-H(%)E
M<'5B;&EC`$1$`$133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L
M+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"D`1&%I;'D`
M1&%T851R964@0G)O=W-E<@!$871A8F%S92!,;V]K=7``1&%T90!$871E(%)E
M8V5I=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$95]L971E($-O;'5M;@!$96-E
M;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C<F5A<V4@26YD96YT`$1E9F%U;'0`
M1&5F875L="!#;VQO<@!$969A=6QT($ED96YT:71Y`$1E9F%U;'0@4VAE;&P`
M1&5F:6YI=&EO;G,`1&5L971E`$1E;&5T92!#96QL`$1E;&5T92!'<F]U<`!$
M96QE=&4@3&]G`$1E;&5T92!097)M:7-S:6]N`$1E;&5T92!A;F0@<'5R9V4@
M;65S<V%G97,`1&5L971E(&-E;&P`1&5L971E(&-O;'5M;@!$96QE=&4@97AI
M<W1I;F<@86QT97)N871E('1E;7!L871E`$1E;&5T92!M97-S86=E<P!$96QE
M=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(`1&5L971E('!E<FUI<W-I;VYS(&9O
M<B`B)7,B(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@<F]W`$1E
M;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@<W5B(&9O;&1E<G,`1&5L
M971E('1H92!C=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W
M`$1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`1&5L:79E<GD@
M=&EM90!$96YM87)K`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N
M`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H
M879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO
M<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W
M('!O:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I
M9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`
M1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9&5T86EL960@9F]R96-A<W0`1&ES
M<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA=`!$:7-P;W-I=&EO
M;B!.;W1I9FEC871I;VX`1&II8F]U=&D`1&\@;F]T(&1E;&5T90!$;R!N;W0@
M9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H92!F:7)S
M="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@
M=&AI<R!B;W@Z`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$;VXG="!H
M879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N`$1O=VYL;V%D`$1O=VYL;V%D("5S
M`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I
M<'0N`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$4M36%I;`!%36%I;"UT;RU335,@
M9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H
M:7,@<V5R=FEC92X`15)2`$5C=6%D;W(`161I=`!%9&ET($)L;V-K`$5D:70@
M1W)O=7``161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I="!0
M97)M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I="!P97)M
M:7-S:6]N<R!F;W(@(B5S(@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9'5C
M871I;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%;6%I;`!%
M;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I
M;"!W:71H(&-O;F9I<FUA=&EO;@!%;6%I;"UT;RU335,@1V%T97=A>0!%;6]T
M:6-O;G,`16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;7!T>2!S96%R
M8V@@=&5R;7,`16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T
M;R!'86QL97)I97,@:6X@=&5X=#\`16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E
M>'0@;65N=3\`16YD('EE87(`16YL87)G92!%9&ET;W(`16YT97(@82!S96-U
M<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@
M;F5E9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H
M92!N86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R
M90!%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SH`17%U871O<FEA;"!'=6EN96$`
M17)I=')E80!%<G)O<@!%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,`17)R;W(@
M9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S`$5R<F]R(&1E;&5T:6YG('-Y;F,@
M;&]G.B`E<P!%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S`$5R<F]R('5P9&%T
M:6YG('!A<W-W;W)D.B`E<P!%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N`$5R
M<F]R('=R:71I;F<@(B5S(BX`17-T;VYI80!%=&AI;W!I80!%=&AN:6,`175R
M;W!E`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P
M('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA
M;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X96-U=&4`
M17AP86YD`$5X<&%N9"!3:61E8F%R`$5X<&5C=&5D("<I)P!%>'!E8W1E9"!B
M87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M`$5X<&ER871I;VX@1&%T
M90!%>'!O;F5N=`!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE
M9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T
M;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E
M<BX`1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T
M;R`B)7,B+@!&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN
M`$9A:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A:6QE9"!T;R!R971R:65V93H@
M)7,`1F%I<@!&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@27-L
M86YD<P!&871A;"!%<G)O<CH`1F%X`$9A>&5S`$9E8G)U87)Y`$9E96QS($QI
M:V4`1F5E;',@;&EK93H@`$9E=R!3:&]W97)S`$9E=R!3;F]W(%-H;W=E<G,`
M1FEE;&0@;6%T<FEX`$9I9VQE="!#05!40TA!`$9I9VQE="!F;VYT`$9I:FD`
M1FEL90!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S
M`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`1FEL92!U
M<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<G,`1FEN
M;&%N9`!&:7)S="!(86QF`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L:7``
M1FQO870`1F]G`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R
M`$9O;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`
M1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R
M971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@
M82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L
M;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T
M=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9',`
M1G(`1G)A;65S`$9R86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&<F5N8V@@
M1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N(%1E<G)I
M=&]R:65S`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!-
M;V]N`$9U;&P@3F%M90!'86)O;@!'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O
M;0!'86QL97)Y.@!'86UB:6$`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'
M96YE<F%T960@0V]D90!'96]R9VEA`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R
M`$=I=F5N($YA;64`1VQO8F%L($]P=&EO;G,`1V\`1V]E9&5L`$=O;V=L92!-
M87!S`$=O;V=L92!396%R8V@`1W)A>7-C86QE`$=R965C90!'<F5E:R`H25-/
M+3@X-3DM-RD`1W)E96YL86YD`$=R96YA9&$`1W)O=7`@061M:6YI<W1R871I
M;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O=7!?;&1A<#H@
M56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9#H@`$=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@
M)7,`1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<P!'<F]U
M<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'=65S="!0
M97)M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y
M86YA`$A434P`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@
M=&AE(&QA<W0@8V5L;"!I;B!R;W<N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S
M97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R
M96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN
M('1A8FQE+@!(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%I=&D`
M2&%S:"U!;&=O<FET:&T`2&%Z90!(96%D97(`2&5A9&5R<P!(96%R9"!)<VQA
M;F0@86YD($UC1&]N86QD($ES;&%N9',`2&5A=GD@5"U3=&]R;0!(96)R97<@
M*$E33RTX.#4Y+3@M22D`2&5I9VAT`$AE;'``2&5L<"!U<VEN9R!E9&ET;W(`
M2&5L<&5R`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H
M92!F:6QE.@!(:6=H`$AO7VUE`$AO;'D@4V5E("A6871I8V%N($-I='D@4W1A
M=&4I`$AO;64`2&]M92!!9&1R97-S`$AO;64@1&ER96-T;W)Y`$AO;64@4&AO
M;F4`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!);G9A
M;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,`2&]R
M9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S
M`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M
M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E
M<R`B)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E
M<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N`$AO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S
M`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z("5S`$AO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE
M('!A<G0@;V8@='EP92`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H
M<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN
M8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R
M92`B)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`2&]R
M:7IO;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T
M(2D`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`
M2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY
M(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AU;6ED:71Y`$AU;6ED
M:71Y.B``2'5M;W)I<W1S`$AU;F=A<GD`24U!4"!M86EL8F]X(&-R96%T:6]N
M(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,`
M24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`25`@061D
M<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T
M('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO8VMD;W=N('9I;VQA
M=&EO;BX`25]N<V5R="!2;W<@0F5F;W)E`$EC96QA;F0`26-O;G,@3VYL>0!)
M8V]N<R!F;W(@)7,`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M93H`
M268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@
M:70@:6X@82!N97<@=VEN9&]W+@!)9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N
M<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H
M96-K('1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN`$EF
M('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E
M('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92!D:7-P;&%Y960@8GD@>6]U
M<B!B<F]W<V5R+@!);6%G92!0<F5V:65W.@!);6%G92!54DP`26UA9V4@55),
M.@!);6%G92!F<F]M(&=A;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y.@!);6%G
M92!U<&QO860`26UA9V5S`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E9"!F:65L
M9#H@)7,`26UP;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E<@!);F-O
M<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M92!A
M;F0O;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA
M=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES
M=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@26YD
M96YT`$EN9&EA`$EN9&EV:61U86P@57-E<G,`26YD;VYE<VEA`$EN9F\`26YF
M;W)M871I;VX`26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92X`26YS
M97)T($-?;VQU;6X@069T97(`26YS97)T($EM86=E`$EN<V5R="!486)L90!)
M;G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R="!A
M(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE
M=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@
M<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&)E
M9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R87!H(&%F=&5R
M('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T
M:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS
M97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E
M('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R="!C
M96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU;6X@
M8F5F;W)E`$EN<V5R="!M97-S86=E<P!);G-E<G0@<&%R86=R87!H(&%F=&5R
M`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R;W<@869T97(`26YS
M97)T(')O=R!B969O<F4`26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@
M=&AE('-E8W5R:71Y('%U97-T:6]N.@!);G-E<G0O36]D:69Y($EM86=E`$EN
M<V5R="]-;V1I9GD@3&EN:P!);G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@
M=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@8W)E9&ET
M+@!);G1E9V5R`$EN=&5G97(@;&ES=`!);G9A;&ED(%5$2"X@*%5S97(@1&%T
M82!(96%D97(I+@!);G9A;&ED(%I)4"!D871A`$EN=F%L:60@87!P;&EC871I
M;VXN`$EN=F%L:60@8F%T8V@@240N`$EN=F%L:60@9&%T82!S=6)M:71T960N
M`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI9"!F:6QE(&9O
M<FUA=`!);G9A;&ED(&QI8V5N<V4@:V5Y+@!);G9A;&ED(&QO8V%T:6]N('!R
M;W9I9&5D+@!);G9A;&ED(&US9U]T>7!E+@!);G9A;&ED(&]R(&UI<W-I;F<@
M87!I7VED+@!);G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV86QI
M9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P87)T;F5R(&ED+@!);G9A
M;&ED('!R;V1U8W0@8V]D92X`26YV86QI9"!P<F]T;V-O;"X`26YV86QI9"!R
M96-I<&EE;G0Z("(E<R(`26YV86QI9"!S:&%R92!O8FIE8W0`26YV86QI9"!S
M;W5R8V4@861D<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN=F5N=&]R
M>0!);G9E<G0@<V5L96-T:6]N`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`
M27)A<0!)<F5L86YD`$ES;&4@;V8@36%N`$ES;VQA=&5D(%0M4W1O<FUS`$ES
M<F%E;`!)<W-U97(`271A;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A
M;@!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86X`2G5L>0!*
M=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I
M9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA
M;#\`2V5N>6$`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T
M:6]N+@!+97)N96P@3F5W8FEE<P!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R
M:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y
M(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+:7)I8F%T
M:0!+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+;W)E
M82P@4F5P=6)L:6,@;V8`2V]R96%N("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS
M=&%N`$QA7WEO=70`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@
M4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@4&%S<W=O<F0@0VAA;F=E`$QA<W0@
M475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G
M:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA`$QA=P!,
M87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`
M3&5F="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,979E;`!,:6)E<FEA
M`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H="!$
M<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN
M($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD
M97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6YK
M`$QI;FL@<&]I;G1S('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H
M92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X($-O
M;VMI90!,:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!$871A
M8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI
M=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES
M="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG('-E<W-I;VYS
M(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!F86EL960Z("5S`$QI<W1I;F<@
M=7-E<G,@:7,@9&ES86)L960N`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO861I
M;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,
M;V<@:6X`3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;@!,;V<@;W5T`$QO
M9VEN`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E
M<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO
M9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE
M='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S
M`$QU>&5M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I
M;F5D(&YO(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@
M675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I8P!-86EL`$UA
M:6P@061M:6X`36%K92!L:6Y?:RXN+@!-86QA=VD`36%L87ES:6$`36%L9&EV
M97,`36%L:0!-86QT80!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y
M;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C
M:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87`R-"!M87``36%P475E
M<W0@;6%P`$UA<'!I;F=S('-T;W)E9"X`36%R8V@`36%R9VEN`$UA<FL@=VET
M:"!3965N+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N
M9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I
M;FEQ=64`36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET:75S`$UA
M>"!A;&QO=V5D(&-R961I="X`36%X(&UE<W-A9V4@<&%R=',@97AC965D960N
M`$UA>"!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U
M<G,Z(`!-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS`$UA>&EM=6T@
M;&5N9W1H`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365N=2!M;V1E
M.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@5F5R:69I960@4W5C8V5S
M<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T
M(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@='EP90!-
M971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE=&%R
M(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E
M9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&%R1$(@:7,@;F]T(&-O;FYE
M8W1E9"X`365T:&]D`$UE=&AO9"`B)7,B(&ES(&YO="!D969I;F5D`$UE=&AO
M9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,`365T<FEC`$UE>&EC
M;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F`$UI9&1L90!-:6UE
M(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA<W0@
M-B!H;W5R<SH@`$UI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X
M<&ER960`36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!014%2('!A8VMA
M9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H
M879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI
M<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG(')E
M<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@240N
M`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF:65D($1A=&4`36]D:69Y
M(%523`!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYG
M;VQI80!-;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1S97)R870`36]O;B!0
M:&%S97,`36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E
M>'!E8W1E9"`E9"X`36]R;V-C;P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D
M>0!-;W-T;'D@0VQO=61Y(&%N9"!7:6YD>0!-;W-T;'D@4W5N;GD`36]V92!$
M;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V92!D;W=N`$UO
M=F4@=7``36]Z86UB:7%U90!-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',`
M375L=&EM87`@54L@;6%P`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT
M`$UY($%C8V]U;G0@26YF;W)M871I;VX`37D@4&]R=&%L`$UY(%!O<G1A;"!,
M87EO=70`37EA;FUA<@!.3RP@22!$;R!.3U0@06=R964`3F%M90!.86UI8FEA
M`$YA=7)U`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S
M`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!(%)E=F]C871I;VX@55),
M`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A;"!54DP`
M3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@4U-,('-E<G9E<B!N
M86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A<&4@8V5R
M=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R`$YE=R!#86QE9&]N:6$`3F5W
M($-A=&5G;W)Y`$YE=R!-;V]N`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE
M=R!:96%L86YD`$YE=R!P87-S=V]R9`!.97<@<&%S<W=O<F0@=VEL;"!E>'!I
M<F4@;VX@)7@N`$YE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N`$YE=R!W:6YD
M;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="`T(%!H87-E
M<P!.97AT(&]P=&EO;G,`3F5X=#X`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`
M3FEG:'0`3FEU90!.;P!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A
M('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@<W1R871E
M9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T96UP;&%T92X`
M3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VX`3F\@
M8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO
M;BX`3F\@8VAA;F=E+@!.;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI
M<R!P97)M:7-S:6]N+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`3F\@
M8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T:6]N('-U<'!L:65D+@!.;R!F:6QE
M('5P;&]A9&5D`$YO(&EC;VYS(&9O=6YD+@!.;R!L;V-A=&EO;B!I<R!S970N
M`$YO(&QO8V%T:6]N('!R;W9I9&5D+@!.;R!M97-S86=E('-U<'!L:65D+@!.
M;R!N86UE('-P96-I9FEE9"X`3F\@;G5M8F5R('-P96-I9FEE9"X`3F\@;V9F
M96YS:79E(&9O<G1U;F5S`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10
M(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!
M4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME
M<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@3&]G:6X@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!005-35T0@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN`$YO('!A=&@@=&\@=&AE($]P
M96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@
M;F5C97-S87)Y('1O('=O<FL@=VET:"!02T-3(#$R(&1A=&$N`$YO('!E;F1I
M;F<@<VEG;G5P<RX`3F\@<75O=&$@<V5T+@!.;R!R=6QE<P!.;R!S97!A<F%T
M;W(@<W!E8VEF:65D+@!.;R!S:61E<P!.;R!S=6-H(&9I;&4`3F\@=&5M<&]R
M87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!U<V5R;F%M
M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L:60@6$U,(&1A=&$@<F5T
M=7)N960`3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@
M8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;R!V
M97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T
M92!C;VYF:6=U<F%T:6]N+@!.;VYE`$YO;F4@*'5S92!I;7!L:6-I="D`3F]R
M9&EC("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!)<VQA;F0`3F]R=&AE<FX@2&5M
M:7-P:&5R90!.;W)T:&5R;B!-87)I86YA($ES;&%N9',`3F]R=V%Y`$YO="!!
M9G1E<@!.;W0@0F5F;W)E`$YO="!A(&1I<F5C=&]R>0!.;W0@:6UP;&5M96YT
M960N`$YO="!S970`3F]T('-U<'!O<G1E9"X`3F]T97,`3F]T:&EN9R!T;R!B
M<F]W<V4L(&=O(&)A8VLN`$YO=F5M8F5R`$YU;6)E<@!.=6UB97(@;V8@8VAA
M<F%C=&5R<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@<F]W<P!.=6UB
M97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO
M;B!L:7-T+@!/2P!/8FIE8W0`3V)J96-T($-R96%T;W(`3V-T86P`3V-T;V)E
M<@!/9F9E;G-E(&9I;'1E<@!/9F9I8V4`3VQD(&%N9"!N97<@<&%S<W=O<F1S
M(&UU<W0@8F4@9&EF9F5R96YT+@!/;&0@<&%S<W=O<F0`3VQD('!A<W-W;W)D
M(&ES(&YO="!C;W)R96-T+@!/;6%N`$]N;'D@24U!4"!S97)V97)S('-U<'!O
M<G0@<VAA<F5D(&9O;&1E<G,N`$]N;'D@;V9F96YS:79E(&9O<G1U;F5S`$]N
M;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"X`3VYL>2!T:&4@;W=N97(@
M;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@
M;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE
M=R!W:6YD;W<`3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T
M82!F<F]M('-I9VYE9"!3+TU)344@<&%R="X`3W!E;G,@=&AI<R!L:6YK(&EN
M(&$@;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M`$]P=&EO;G,`3W!T:6]N
M<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES871I
M;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC871I;VX@=&5M
M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/=&AE<B!)
M;F9O<FUA=&EO;@!/=VYE<B!097)M:7-S:6]N<P!004T@875T:&5N=&EC871I
M;VX@:7,@;F]T(&%V86EL86)L92X`4$5!4CHZ36%I;"!B86-K96YD`%!'4"!$
M:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D($1A=&$`4$=0(%!U8FQI
M8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`@0V]D90!02%`@
M4VAE;&P`4$T@3&EG:'0@4F%I;@!032!286EN`%!-(%-H;W=E<G,`4$T@4VYO
M=P!032!3;F]W(%-H;W=E<G,`4$T@4W5N`%!-(%0M4W1O<FUS`%!/4TE8(&5X
M=&5N<VEO;B!I<R!M:7-S:6YG`%!?2%`@4VAE;&P`4&%D9&EN9P!086MI<W1A
M;@!086QA=0!086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D`%!A;F%M
M80!087!U82!.97<@1W5I;F5A`%!A<F%G=6%Y`%!A<G1L>2!#;&]U9'D`4&%S
M<W=O<F0`4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN`%!A<W-W;W)D
M(&EN8V]R<F5C=`!087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE
M;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!087-S=V]R
M9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%S
M=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z`%!E;W!L
M90!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F
M;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I
M;VX`4&5R;6ES<VEO;B`B)7,B(&YO="!D96QE=&5D+@!097)M:7-S:6]N($1E
M;FEE9`!097)M:7-S:6]N<P!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!0
M97)S;VYA;"!);F9O<FUA=&EO;@!097)U`%!E=',`4&AI;&EP<&EN97,`4&AO
M;F4`4&AO=&]S`%!I=&-A:7)N`%!I>&5L<P!0;&%T:71U9&5S`%!L96%S92!C
M;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W
M86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF:7)M('1H
M870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="X`4&QE87-E(&5N
M=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`4&QE87-E(&5N=&5R(&$@;F%M92!F
M;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE87-E(&5N=&5R(&$@=F%L:60@25`@
M861D<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE
M(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@
M=F%L:60@=&EM92X`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P
M<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S
M=V]R9`!0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4
M(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@<WES=&5M+@!0;&5A
M<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0;VQI=&EC
M<P!0;VQL<P!0;W)T=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O
M<VET:6]N:6YG(&]F('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H
M;F]T(&5N9F]R8V5D(&)Y($E-05`I`%!R96-I<&ET871I;VX@9F]R(&QA<W0@
M)7,@:&]U<BAS*3H@`%!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4`4')E9G-?
M;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5F
M<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`%!R97-S=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R97-S=7)E
M.B``4')E=FEE=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`
M4')E=FEO=7,@;W!T:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV871E($ME>0!0
M<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C=',`4')O;7!T('1E
M>'0`4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,@2V5Y
M($EN9F\`4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U
M8V-E<W-F=6QL>2X`4'5E<G1O(%)I8V\`4'5R9V4@;65S<V%G97,`46%T87(`
M475E<GD`475O=&$`4E-!(%!U8FQI8R!+97D@*"5D(&)I="D`4F%D:6\@<V5L
M96-T:6]N`%)A:6X`4F%I;B!%87)L>0!286EN($QA=&4`4F%I;B!3:&]W97(`
M4F%I;B!A;F0@4VYO=P!286EN('1O(%-N;W<`4F%N9&]M($9O<G1U;F4`4F%T
M:6\`4F5A9`!296%D(&UE<W-A9V5S`%)E86QL>2!D96QE=&4@)7,_(%1H:7,@
M;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E86QL>2!R96UO=F4@=7-E
M<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@
M=6YD;VYE+@!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H`%)E9G)E
M<V@@1'EN86UI8R!-96YU($5L96UE;G1S.@!2969R97-H(%!O<G1A;"!6:65W
M.@!296=E>`!296QA=&EO;G-H:7`@0G)O=W-E<@!296QO860`4F5M87)K<P!2
M96UO=&4@4V5R=F5R<P!296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N
M8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!";&]C:P!296UO=F4@8V]L=6UN
M`%)E;6]V92!F;W)M871T:6YG`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S
M8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO
M=F4@=&AE`%)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0`4F5M
M;W9E('5S97(`4F5M;W9E('5S97(Z("5S`%)E<75E<W0@8V]U;&1N)W0@8F4@
M86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@`%)E<75E<W1E9"!S97)V
M:6-E(&-O=6QD(&YO="!B92!F;W5N9"X`4F5Q=6ER960@(B5S(B!N;W0@<W!E
M8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T
M('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S
M(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN`%)E<75I<F5D($9I
M96QD`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T(%EO=7(@4&%S<W=O<F0`
M4F5S=&]R92!,87-T(%%U97)Y`%)E<W5L=',`4F5T=7)N('1O($]P=&EO;G,`
M4F5T>7!E(&YE=R!P87-S=V]R9`!2975N:6]N`%)E=F5R="!#;VYF:6=U<F%T
M:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT`%)I
M9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?=R!0<F]P97)T:65S+BXN`%)O
M;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H
M=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE<P!2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS
M`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY`%)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY`%)U;@!2=7-S:6%N($9E
M9&5R871I;VX`4G=A;F1A`%,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R
M90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`4T%33"!A=71H96YT:6-A=&EO
M;B!I<R!N;W0@879A:6QA8FQE+@!335,@365S<V%G:6YG`%-13"!3:&5L;`!3
M44P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S`%-32`!354-#15-3`%-?
M44P@4VAE;&P`4V$`4V%I;G0@2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I
M<P!386EN="!,=6-I80!386EN="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT
M(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S`%-A;64@9G)A;64@*%]S96QF
M*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!3871E
M;&QI=&4@4')O=FED97(`4V%U9&D@07)A8FEA`%-A=F4`4V%V92`B)7,B`%-A
M=F4@)7,`4V%V92!/<'1I;VYS`%-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I
M;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y
M(&1I<F5C=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V%V960@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`%-C871T97)E9"!4+5-T;W)M
M<P!38VEE;F-E`%-E87)C:`!396%R8V@@16YG:6YE<P!396QE8W0@1FEL97,`
M4V5L96-T(&$@9&%T90!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@
M;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D
M9`!396QE8W0@86QL`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+@!396QE
M8W0@86X@;V)J96-T`%-E;&5C="!N;VYE`%-E;&5C="!T:&4@8VAA<F%C=&5R
M<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N
M(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+@!396QE
M8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T
M.@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93H`4V5L
M96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L96-T('1H92!T:6UE(&9O<FUA
M=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O
M;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!3
M96YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;F5G86P`4V5N<V]R.B``
M4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I86P@3G5M8F5R
M`%-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N`%-E<W-I;VX@
M061M:6X`4V5S<VEO;B!)1"!E>'!I<F5D+@!397-S:6]N<P!3970`4V5T(&]P
M=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@
M>6]U(&5V97(@9F]R9V5T(&ET+@!3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA
M="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"X`4V5T('EO
M=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I
M;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE
M;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L87D@;W!T:6]N
M<RX`4V5T=7``4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L90!3979E
M<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z(`!3
M97EC:&5L;&5S`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S
M<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R!D
M:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE
M=VQY(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@!3:&]W(&QA<W0@;&]G:6X@
M=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@;W!T:6]N('1O(&ME97`@;W)I
M9VEN86P`4VAO=R!P:6-K97(`4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@
M8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W('1H92!4
M86)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R
M;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S
M(&1I86QO9P!3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9P!3:&]W
M('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,871E`%-H
M;W=E<G,@:6X@=&AE(%9I8VEN:71Y`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N
M96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0`4VEE
M<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET
M:&T`4VEN9V%P;W)E`%-I>F4`4VMI<"!-86EN=&5N86YC90!3;&]V86MI80!3
M;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R`%-N;W<@4VAO=V5R<P!3;F]W(%-H
M;W=E<G,@16%R;'D`4VYO=R!3:&]W97)S($QA=&4`4VYO=R!D97!T:#H@`%-N
M;W<@97%U:79A;&5N="!I;B!W871E<CH@`%-O;&]M;VX@27-L86YD<P!3;VUA
M;&EA`%-O;F=S("8@4&]E;7,`4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E
M(&%D9')E<W,`4V]U=&@@069R:6-A`%-O=71H($5U<F]P96%N("A)4T\M.#@U
M.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L
M86YD<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@861J86-E
M;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@
M8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P86EN
M`%-P86T`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!L:70@8V5L;`!3<&QI
M="!C;VQU;6X`4W!L:70@<F]W`%-P;W)T<P!3<FD@3&%N:V$`4W1A;F1A<F0`
M4W1A<B!4<F5K`%-T87)T('EE87(`4W1A=&4@;W(@4')O=FEN8V4`4W1A='5S
M`%-T;W)A9V4@9F]R;6%T`%-T<F5E="!!9&1R97-S`%-T<FEK971H<F]U9V@`
M4W1R:6YG(&QI<W0`4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,`4W1Y
M;&4@6T-34UT`4W4`4W5B9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!3=6)J
M96-T`%-U8FUI=`!3=6)M:71T960@<F5Q=65S="!T;R!A9&0@(B5S(B!T;R!T
M:&4@<WES=&5M+B!9;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R(')E<75E
M<W0@:&%S(&)E96X@87!P<F]V960N`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E
M<W-F=6QL>2!A9&1E9"`B)7,B('1O('1H92!S>7-T96TN`%-U8V-E<W-F=6QL
M>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TN
M`%-U8V-E<W-F=6QL>2!D96QE=&5D("(E<R(N`%-U8V-E<W-F=6QL>2!R96UO
M=F5D("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@<F5V97)T
M960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3=6-C
M97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F
M=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`
M4W5C8V5S<V9U;&QY('5P9&%T960@(B5S(@!3=6-C97-S9G5L;'D@=W)O=&4@
M)7,`4W5D86X`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U;G)I
M<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3
M=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@
M86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y
M;F,@;&]G(&1E;&5T960`4WEN8TU,`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@
M=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M(&%N
M9"!7:6YD>0!4+5-T;W)M<P!4+5-T;W)M<R!%87)L>0!44U8@9FEL90!486)L
M92!0<F]P97)T:65S`%1A8FQE(%-E=`!486)L92!P<F]P97)T:65S`%1A:7=A
M;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N
M:6$L(%5N:71E9"!297!U8FQI8R!O9@!487)G970Z`%1A<VMS`%1E;&5P:&]N
M92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R871U<F4`5&5M
M<&5R871U<F4Z(`!496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F
M9&5G.R5S`%1E;7!L871E("(E<R(@;F]T(&9O=6YD+@!496UP;&%T92!!9&UI
M;FES=')A=&EO;@!497AT`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``
M5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AE($944"!E>'1E;G-I;VX@
M:7,@;F]T(&%V86EL86)L92X`5&AE($AI<W1O<GD@<WES=&5M(&ES(&1I<V%B
M;&5D+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@
M;F]T('-U<'!O<G0@(B5S(@!4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN
M:71I86QI>F5D+@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO
M860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D
M+B!%>&ET:6YG+@!4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U
M<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N
M="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H
M92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B
M;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O
M;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@
M8F]O:RX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R
M:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F
M="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES
M=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T
M:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN
M`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE
M(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@
M8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D
M97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F=6QL
M('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@
M26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W
M92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E
M<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I
M;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S
M>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U
M)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D
M('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@
M<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C
M<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T
M960N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H92!L;V-A=&EO;B!O9B!T
M:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G
M<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@
M<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G
M=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N
M9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE
M(&-O;7!O<V4@<&%G90!4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU
M;65R:6,N`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE
M($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E
M<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D
M960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E
M9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O
M;B!T:&4@<WES=&5M+@!4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE
M('-I;F=L92!C:&%R86-T97(N`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O
M;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5P87)A=&]R(&UU
M<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!S97)V97(@(B5S(B!H
M87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V
M960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E
M9"X`5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES="X`5&AE
M('1E;7!O<F%R>2!F:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H92!T97AT
M('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C
M<F5E;BX`5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`5&AE('1O<"!S
M:61E(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE
M('!R979I;W5S('-T97`N`%1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B
M92!S879E9"X`5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B
M;&4N`%1H96UE<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%1H97)E(&%R
M92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@87)E(&YO('!A<G1S('1H
M870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N
M>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@
M)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+@!4
M:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`B)7,B('1O('1H92!S>7-T96TZ
M("5S`%1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E
M<B`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@
M<F5M;W9I;F<@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P
M<F]B;&5M('5P9&%T:6YG("(E<R(Z("5S`%1H97)E('=A<R!A('!R;V)L96T@
M=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`5&AE
M<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S
M('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D
M(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P
M;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`5&AE
M<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A
M+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@
M9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N
M(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N
M`%1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@
M861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R
M+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T
M86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R
M<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R
M>2!A9V%I;B!L871E<BX`5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P
M;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@
M8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@
M=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O
M(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT
M='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@
M05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H
M<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI(&=A=&5W87DL('5S
M:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R
M96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D
M<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR
M;W5G:"!T:&4@5F]D869O;F4@271A;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A
M9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I
M=&@@5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F
M:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN
M(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R
M<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@
M;V-T86P@=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S
M<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU
M<W0@8F4@82!V86QI9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN
M(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M
M<&QE("<C,3(S-&%F)RX`5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O
M8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E
M(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N
M(&5M86EL(&-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U
M<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@8VQI96YT
M<R!P;&5A<V4@=FES:70@)7,`5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN
M(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H
M:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C
M86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T
M96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@
M8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@
M86X@3W!T:6]N<R!W:6YD;W<`5&AU;F1E<@!4:6-K971S`%1I;64`5&EM92!4
M<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T
M90!4:71L90!4:71L92`H=&]O;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT:7!L
M92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N
M9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(5$U,
M(%-O=7)C90!4;V=O`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`5&]O(&UA;GD@
M:6YV86QI9"!L;V=I;G,@9'5R:6YG('1H92!L87-T(&UI;G5T97,N`%1O<`!4
M;W`@9G)A;64@*%]T;W`I`%1R86YS;&%T:6]N<P!4<FEN:61A9"!A;F0@5&]B
M86=O`%1R=64@;W(@9F%L<V4`5'4`5'5N:7-I80!4=7)K97D`5'5R:VES:"`H
M25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L
M86YD<P!4=79A;'4`5'EP92!Y;W5R(&-H;VEC93H@`%4N5BX@:6YD97@Z(`!5
M4DP`55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T
M`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C8V5S<R!61E,@9&ER
M96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@
M=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@
M9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO
M;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N9V4@=&\@)7,N
M`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S(BX`56YA8FQE('1O
M(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,O)7,B+@!5;F%B;&4@=&\@8V]N;F5C
M="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"X`
M56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93
M(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O
M<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A
M=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&
M4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B;&4@=&\@
M9&5L971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+@!5;F%B
M;&4@=&\@9&5L971E("(E<R(Z("5S+@!5;F%B;&4@=&\@9&5L971E("5S+"!T
M:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E
M<RX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@
M(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+@!5
M;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@
M=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N86)L92!T;R!L;V%D
M('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL
M92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P
M96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F
M:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L
M92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN`%5N86)L
M92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN`%5N
M86)L92!T;R!R96%D(&9I;&4Z(`!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O
M="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I
M;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@<F5N86UE
M(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R
M>3H@)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`56YA8FQE
M('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E;F%M92!6
M1E,@9FEL92X`56YA8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N86)L92!T;R!T
M<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET92!6
M1E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH
M*2!F86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D
M+@!5;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T
M:6]N`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C
M=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5
M;F9I;&5D`%5N:6-O9&4@*%541BTX*0!5;FET960@07)A8B!%;6ER871E<P!5
M;FET960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N:71E9"!3=&%T97,@36EN
M;W(@3W5T;'EI;F<@27-L86YD<P!5;FET<P!5;FMN;W=N`%5N:VYO=VX@87!I
M;7-G:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I9"`H0VQI
M96YT($UE<W-A9V4@240I+@!5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+@!5
M;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE(&-U<G)E
M;G0@96QE;65N=`!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO
M="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S
M96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L
M(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A
M;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`56YS970@
M8V]L;W(`56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`
M57!D871E('5S97(`57!D871E9"`B)7,B+@!5<&=R861E('-C<FEP="!D96QE
M=&5D+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I
M;&5S('1O('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@
M<F]M86X@;G5M8F5R<P!5<G5G=6%Y`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,
M`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S
M97)V97(N`%5S97(`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N
M`%5S97(@061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T
M<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O
M<B!T:&ES('-I=&4N`%5S97(@86-C;W5N="!N;W0@9F]U;F0`57-E<FYA;64`
M57-E<FYA;64@(B5S(B!A;')E861Y(&5X:7-T<RX`57-E<FYA;64Z`%5S97)N
M86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@9&ER
M96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A=&EO
M;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@
M9G)O;2!N;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F
M("5S+@!686QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R
M:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE
M<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9E
M<G-I;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG
M`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE=&YA;65S92`H5DE3
M0TE)*0!6:65W("5S`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A
M<R`E<P!6:7)G:6X@27-L86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@
M52Y3+@!6:7-I8FEL:71Y`%9I<VEB:6QI='DZ(`!6;V1A9F]N92!)=&%L>2!V
M:6$@4TU44`!705).`%=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,
M62!&4D]-("5S+@!724X@=FEA($A45%``5V%L;&ES(&%N9"!&=71U;F$`5V%R
M;FEN9P!790!796%T:&5R($9O<F5C87-T`%=E871H97(@9&%T82!P<F]V:61E
M9"!B>0!796%T:&5R+F-O;0!796(`5V5B(%-I=&4`5V5E:VQY`%=E;&-O;64`
M5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!797-T97)N("A)4T\M.#@U.2TQ
M*0!797-T97)N("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!386AA<F$`5VAA="!A
M<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA
M="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@<75O
M=&4@8VAA<F%C=&5R/P!7:&5R96ES($%U<W1R86QI82!M87``5VAI8V@@<&AA
M<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT
M(&5D:71O<BX`5VED=&@`5VED=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F('1H
M92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L
M;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`
M5VEK:0!7:6YD`%=I;F0@16%R;'D`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD
M.@!7:6YD.B``5VES9&]M`%=I<VAL:7-T`%=O<FL`5V]R:R!!9&1R97-S`%=O
M<FL@4&AO;F4`5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%
M>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG(&YU;6)E<B!O9B!F:65L9',N
M($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@;V9F<V5T("5D('=H:6QE
M(')E861I;F<@82!61E,@9FEL92X`6"U2968`6#4P.78S($)A<VEC($-O;G-T
M<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4`6#4P.78S(%-U8FIE
M8W0@06QT97)N871I=F4@3F%M90!8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I
M9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!960!965E9`%EA:&]O(2!M87``665A
M<FQY`%EE;65N`%EE<P!997,L($D@06=R964`66]U(&%R92!I;B!415A4($U/
M1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=9
M4TE764<N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA
M;B`E9"!B;&]C:W,N`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO=2!C
M86YN;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M
M92X`66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9
M;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I
M;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@:&%V
M92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@
M8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA
M;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+@!9
M;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@;75S="!C;VYF
M:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+@!9;W4@
M;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"X`66]U(&UU<W0@9&5S8W)I
M8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE
M;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L
M:6YK('!O:6YT<R!T;P!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E
M(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A
M<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N
M`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U(&UU
M<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@;75S="!S
M<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T('1Y<&4@
M82!N97<@8V%T96=O<GD@;F%M92X`66]U(&YE960@=&\@<')O=FED92!A;B!)
M=&%L:6%N('!H;VYE(&YU;6)E<@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER
M960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO
M=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R
M;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O
M9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@
M>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I
M8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N
M($EF('EO=2!W:7-H('1O('5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@
M86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="!A=71H96YT:6-A
M=&EO;B!B86-K96YD+@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E
M<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H
M87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@
M8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G
M:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E
M8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O
M97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&)R;W=S97(@9&]E
M<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O
M;"]#;VUM86YD("L@4"!T;R!P<FEN="X`66]U<B!C=7)R96YT('1I;64@>F]N
M93H`66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N`%EO
M=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;&]G
M:6X@:&%S(&5X<&ER960N`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@
M)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R
M871I;VX@;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B965N
M('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P
M87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@
M;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@<&%S<W=O<F0@
M:&%S(&5X<&ER960N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`
M6F%I<F4`6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M(:61E(%%U;W1E9"!497AT
M70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!497AT("T`6U-H;W<@
M475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI;F4@)7,@;V8@)7-=`%]!9&UI
M;FES=')A=&EO;@!?0TQ)`%]$871A5')E90!?1&5L971E(%)O=P!?1W)O=7!S
M`%](96QP`%]);6%G92!0<F]P97)T:65S+BXN`%],;V<@:6X`7TQO9R!O=70`
M7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4F5M;W9E
M($QI;FLN+BX`7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN`%]5<V5R<P!A
M9&1R97-S(&)O;VL`861D<F5S<V5E('5N:VYO=VX`8V%L96YD87(`8V%L;0!C
M86YN;W0@8W)E871E(&]U='!U="!F:6QE`&-A;FYO="!O<&5N(&EN<'5T`&-L
M:6-K(&AE<F4`8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R`&-O;F9I9W5R871I
M;VX@97)R;W(`8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9P!D871A(&9O
M<FUA="!E<G)O<@!E9&ET`&5N=')Y(&YO="!F;W5N9`!F86QL:6YG`&9I;&4`
M9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!G=7-T:6YG`&@Z`&AH`&AO<W0@
M;F%M92!U;FMN;W=N`&EM;65D:6%T90!I;FQI;F4`:6YP=70O;W5T<'5T(&5R
M<F]R`&EN=&5R;F%L('-O9G1W87)E(&5R<F]R`&QI;F5S70!M:VES;V9S(&5R
M<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RX`;6T`;F%M90!N;W0@:6UP
M;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D`'!E<F-E;G0`
M<&5R;6ES<VEO;B!D96YI960`<&EX96QS`')E;6]T92!E<G)O<B!I;B!P<F]T
M;V-O;`!R:7-I;F<`<V5R=FEC92!U;F%V86EL86)L90!S:&]W(&1I9F9E<F5N
M8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S<P!S=&5A9'D`<WES=&5M(&5R<F]R
M`'1A<VL@;&ES=`!T96UP;W)A<GD@9F%I;'5R90!T>7!E('1H92!P87-S=V]R
M9"!T=VEC92!T;R!C;VYF:7)M`'5N:69I960`=6YN86UE9`!U<V5R('-E;&5C
M=`!V0V%R9`!W.@!W96%T:&5R+F-O;0!0<F]J96-T+4ED+59E<G-I;VXZ($AO
M<F1E(#,N,2XQ+6-V<PI297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S
M+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-BTP,RTQ,B`P,#HS
M,2LP,3`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#,M,3,@,C(Z-#`K,#$P
M,`I,87-T+51R86YS;&%T;W(Z($IA;B!+=6EP97)S(#QJ<FMU:7!E<G-`;&%U
M=V5R<V-O;&QE9V4N;FP^"DQA;F=U86=E+51E86TZ($1U=&-H(#QI,3AN0&QI
M<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E
M.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3$*0V]N=&5N="U4<F%N
M<V9E<BU%;F-O9&EN9SH@.&)I=`H`("@E<R!D86=E;B!G96QE9&5N*0`@*%-N
M96QT;V5T<R`E<RD`("AB:6YN96X@)7,@9&%G96XI`"`H=F%N9&%A9RD`("AM
M;W)G96XI`"`H9VES=&5R96XI`"!O<"``(B5S(B!I<R!G965N(&1I<F5C=&]R
M>2X`(B5S(B!I<R!G965N(&=E;&1I9V4@:V5U>F4N`"(E<R(@:7,@;FEE="!G
M96-O;F9I9W5R965R9"!I;B!H970@2&]R9&4@<F5G:7-T97(N`"(E<R(@=')E
M92!W965R9V5V97(@;FEE="!G979O;F1E;BX`(B5S(B!A86X@:&5T(&=R;V5P
M96YS>7-T965M('1O96=E=F]E9V0N`"(E<R(@86%N(&AE="!R96-H=&5N<WES
M=&5E;2!T;V5G979O96=D+@`B)7,B(&ES(&YI970@86%N9V5M86%K=#H@)7,N
M`"4N,F9-0B!G96)R=6EK="!V86X@)2XR9DU"('1O96=E<W1A86X@*"4N,F8E
M)2D`)60@)7,@96X@)7,`)60@9&%G96X@=&]T('5W('=A8VAT=V]O<F0@=F5R
M=F%L="X`)60M9&%G('9O;W)U:71Z:6-H=``E<R`M($]P;65R:VEN9P`E<R!V
M:6YG97)A9F1R=6L`)7,@2T(`)7,@3VYD97)H;W5D<W=E<FMZ86%M:&5D96X@
M+2!"979E<W1I9VEN9P`E<R!);G-T96QL96X`)7,@:6YS8VAR:6IV96X`)7,@
M9V5B<G5I:V5R<V]V97)E96YK;VUS=``E<R!B97-T86%T(&%L+@`E<R!O<"`E
M<R`E<P`E<R!I<R!G97)E960@;VT@;VYD97)S=&%A;F1E(&=E<V5L96-T965R
M9&4@;VYD97)H;W5D<W=E<FMZ86%M:&5D96X@=6ET('1E('9O97)E;BX@5FEN
M:R!D92!B97=E<FMI;F<H96XI(&%A;B!D:64@=2!O<"!D:70@;6]M96YT('=I
M;'0@=6ET=F]E<F5N+@`E<R!I<R!V97)E:7-T`"5S(&UI;G5T96X`)7,@;FEE
M="!G979O;F1E;BX`)7,@=&]T("5S('9A;B`E<P`E<R=S(&%D<F5S8F]E:P`E
M<R=S(&%G96YD80`E<R=S(&YO=&ET:65B;V5K`"5S)W,@=&%K96YL:6IS=``E
M<SH@)7,`)7,Z($1I="!B97)I8VAT(&MO;70@;6ES<V-H:65N(&YI970@=F%N
M(&1E9V5N92!D:64@:&5T(&)E=V5E<G0@=&4@>FEJ;BX@5V5E<R!V;V]R>FEC
M:'1I9R!B:6H@:&5T(&ML:6MK96X@;W`@;&EN:W,@:6X@:&5T(&)E<FEC:'0@
M;V8@9&4@869Z96YD97(@<&5R<V]O;FQI:FME(&EN9F]R;6%T:64@=&4@<W1U
M<F5N+@`L('=I;F1V;&%G96X@`"P@=VEN9'9L86=E;B`E<R`E<P`L('9A<FEA
M8F5L('9A;B`E<R!T;W0@)7,`+2T@<V5L96-T97)E;B`M+0`Q,B!U=7)S=V5E
M<F=A=F4`,C0@=75R<W=E97)G879E`#(T('5U<G,`/%9O<FEG90!%96X@9&%T
M86)A<V4@8F%C:V5N9"!I<R!V97)E:7-T('9O;W(@9&ET(&)L;VLN`$5R(&AE
M969T('II8V@@965N(&9A=&%L92!F;W5T('9O;W)G961A86X`165N(&]P96YB
M87)E(%!'4"!S;&5U=&5L(&ES('9E<F5I<W0@;VT@965N(&)E<FEC:'0@=&4@
M8V]D97)E;BX`165N(&]P96YB87)E(%!'4"!S;&5U=&5L(&ES('9E<F5I<W0@
M;VT@965N(&]N9&5R=&5K96YD(&)E<FEC:'0@=&4@=F5R:69IZW)E;BX`165N
M(&]P96YB87)E(%!'4"!S;&5U=&5L+"!P<FEVZ2!01U`@<VQE=71E;"!E;B!W
M86-H='=O;W)D<F5G96P@>FEJ;B!V97)E:7-T(&]M(&5E;B!B97)I8VAT('1E
M(&1E8V]D97)E;BX`165N(&]P96YB87)E(%!'4"!S;&5U=&5L+"!P<FEVZ2!0
M1U`@<VQE=71E;"!E;B!W86-H='=O;W)D<F5G96P@>FEJ;B!V97)E:7-T(&]M
M(&5E;B!B97)I8VAT('1E(&]N9&5R=&5K96YE;BX`165N(&]P96YB87)E(%,O
M34E-12!S;&5U=&5L+"!P<FEVZ2!3+TU)344@<VQE=71E;"!E;B!W86-H='=O
M;W)D<F5G96P@>FEJ;B!V97)E:7-T(&]M(&5E;B!B97)I8VAT('1E(&1E8V]D
M97)E;BX`165N(&]P96YB87)E(%,O34E-12!S;&5U=&5L+"!P<FEVZ2!3+TU)
M344@<VQE=71E;"!E;B!W86-H='=O;W)D<F5G96P@>FEJ;B!V97)E:7-T(&]M
M(&5E;B!B97)I8VAT('1E(&]N9&5R=&5K96YE;BX`165N(&]P96YB87)E(%--
M24U%('-L975T96P@:7,@=F5R96ES="!O;2!E96X@8F5R:6-H="!T92!C;V1E
M<F5N+@!"97=O;&MI;F<@=F]O<B`Q,BXP,"!U=7(`3&EC:'1E(')E9V5N('9O
M;W(@,3(N,#`@=75R`%)E9V5N('9O;W(@,3(N,#`@=75R`$)U:65N('9O;W(@
M,3(N,#`@=75R`%-N965U=V)U:65N('9O;W(@,3(N,#`@=75R`$%-+U!-`$%0
M22!)1`!/=F5R(&1E>F4@961I=&]R`$]V97(N+BX`06)S8F]T=&]M`$%B<VUI
M9&1L90!4;V5G86YG(&=E=V5I9V5R9"!B:6H@:&5T(&UA:V5N('9A;B!61E,@
M9&ER96-T;W)Y+@!4;V5G86YG(&=E=V5I9V5R9"!B:6H@:&5T(&UA:V5N('9A
M;B!61E,@8F5S=&%N9"X`06-C;W5N=&EN9F]R;6%T:64`06-C;W5N='=A8VAT
M=V]O<F0`06-C;W5N="!B979R;W)E;BX`5F5R86YT=V]O<F1I;F<`5&]E=F]E
M9V5N`$-H:6QD(&=R;V5P('1O979O96=E;@!#:&EL9"!R96-H="!T;V5V;V5G
M96X`2&EE<B!T;V5V;V5G96XZ`$YI975W92!G<F]E<"!T;V5V;V5G96X`3FEE
M=7<@<F5C:'0@=&]E=F]E9V5N`$5E;B`B8VAI;&1G<F]E<"(@86%N("(E<R(@
M=&]E=F]E9V5N`$5E;B`B8VAI;&1R96-H="(@86%N("(E<R(@=&]E=F]E9V5N
M`$YI975W92!G96)R=6EK97(@=&]E=F]E9V5N.@!+;VQO;2!T;V5V;V5G96X`
M3FEE=7=E(&QE9&5N('1O979O96=E;@!086%R('1O979O96=E;@!(970@)7,@
M;65N=2!T;V5V;V5G96X@86QS(&5E;B!-;WII;&QA(%-I9&5B87(`5F]E9R!T
M;V4@86%N(&%D<F5S8F]E:SH`5F]E9R!T;V4@86%N(&UI:FX@861R97-B;V5K
M`$=E8G)U:6ME<B!T;V5V;V5G96X`(B5S(B!A86X@:&5T('-Y<W1E96T@=&]E
M9V5V;V5G9"P@;6%A<B!K;VX@9V5E;B!E>'1R82!I;G-C:')I:G9I;F=S:6YF
M;W)M871I92!T;V5V;V5G96XZ("5S+@`B)7,B(&%A;B!H970@<WES=&5E;2!T
M;V5G979O96=D+B!5(&MU;G0@;G4@86%N;65L9&5N+@!4;V5V;V5G96X@=F%N
M(&=E8G)U:6ME<G,@:7,@=6ET9V5S8VAA:V5L9"X`061R97,`061R97-B;V5K
M`$)E:&5E<B`M(')E8VAT96X@=F]O<B!A;F1E<F4@9V5B<G5I:V5R<R!I;G-T
M96QL96X`0F5H965R`$%D=F5R=&5N=&EE<P!!9F=A;FES=&%N`$%L8F%N:>L`
M06QG97)I:F4`06QI87,`56ET;&EJ;F5N`%5I=&QI:FYI;F<Z`$%L;&4`06QL
M92!G96%U=&AE;G1I8V5E<F1E(&=E8G)U:6ME<G,`06QL92!G<F]E<&5N`$%L
M;&4@<F5C:'1E;@!!;&QE('9I97(@>FEJ9&5N`$UE97)D97)E(&%D<F5S<V5N
M('1O97-T86%N`$EN<W1E;&QE;B!V86X@9V5O<F1E;F1E(&QI:G-T('1Y<&4@
M=&]E<W1A86X_`$)E<W1A870@86P`06QT97)N871I979E($E-4U`@86%N;65L
M9&EN9P!!;'1E<FYA=&EE9B!)35-0('=A8VAT=V]O<F0`06QT97)N871I979E
M($E-4U`@9V5B<G5I:V5R<VYA86T`06QT97)N871I968@92UM86EL861R97,`
M06QT97)N871I979E('-J86)L;VYE;@!!;'1E<FYA=&EE=F4@=&5K<W0Z`$%M
M97)I:V%A;G,@4V%M;V$`165N(&]N9V5L9&EG92!W86%R9&4@;W!G96=E=F5N
M+@!%<B!H965F="!Z:6-H(&5E;B!O;F)E:V5N9&5F;W5T('9O;W)G961A86XN
M`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYI96UE('!R;WAY`$%N='=O
M;W)D`$%N=&%R8W1I8V$`06YT:6=U82!E;B!"87)B=61A`%1O97!A<W-I;F<`
M5&]E<&%S<VEN9V5N;&EJ<W0`5&]E<&%S<VEN9R!I<R!G97)E960N`$]P(&-H
M:6QD<VAA<F5S('1O97!A<W-E;@!';V5D:V5U<F5N`$=E<V-H871T92!G<F]O
M='1E`$%P<FEL`$%R86)I<V-H("A7:6YD;W=S+3$R-38I`$%R8VAI969B97-T
M86YD<V=R;V]T=&4`07)C:&EE9FYA86T`5V5E="!U('IE:V5R(&1A="!U(&AE
M="!A86YM96QD:6YG<W9E<GIO96L@=F%N("5S('=I;'0@=F5R=VEJ9&5R96X_
M`%=E970@=2!Z96ME<B!D870@=2`B)7,B(&5N(&%L;&4@<W5B9W)O97!E;B!W
M:6QT('9E<G=I:F1E<F5N/P!!<F=E;G1I;FGK`$%R;65N:>L`07)M965N<R`H
M05)-4T-)22TX*0!+=6YS=`!!<G5B80!!<V-E;G-I;VX@96EL86YD`$%S8VEI
M(&MU;G-T`$%Z:>LO4&%C:69I<V-H92!296=I;P!/;2!B979E<W1I9VEN9R!V
M<F%G96X@=F]O<B!H970@=6ET=F]E<F5N('9A;B!O;F1E<FAO=61S=V5R:WIA
M86UH961E;C\`3W!D<F%C:'0@:V]L;VUM96X`4&]G:6YG(&]M(&5E;B!N:65T
M(&)E<W1A86YD92!G<F]E<"!T92!V97)W:6ID97)E;BX`4&]G:6YG(&]M(&5E
M;B!N:65T(&)E<W1A86YD(')E8VAT('1E('9E<G=I:F1E<F5N+@!0;V=I;F<@
M;VT@965N(&YI970@8F5S=&%A;F0@<F5C:'0@=&4@8F5W97)K96XN`%!O9VEN
M9R!O;2!E96X@;FEE="!B97-T86%N9&4@<VAA<F4@=&4@8F5W97)K96XN`$%T
M=')I8G5T96X`075G=7-T=7,`075S=')A;&GK`$]O<W1E;G)I:FL`075T:%]C
M>7)S<6PZ('9E<F5I<W1E(&EM87`@97AT96YT:64@;FEE="!G979O;F1E;BX`
M075T:%]C>7)U<SH@8F%C:V5N9"!H965F="!N:65T(&1E('9E<F5I<W1E(&)E
M:W=A86UH961E;BX`075T:%]C>7)U<SH@=F5R96ES=&4@:6UA<"!E>'1E;G1I
M92!N:65T(&=E=F]N9&5N+@!!=71H7V9T<#H@=F5R96ES=&4@1E10(&5X=&5N
M=&EE(&YI970@9V5V;VYD96XN($-O;7!I;&5E<B!02%`@;65T(&1E("TM96YA
M8FQE+69T<"!O<'1I92X`075T:%]I;6%P.B!V97)E:7-T92!)34%0(&5X=&5N
M=&EE(&YI970@9V5V;VYD96XN`$%U=&A?:W)B-3H@=F5R96ES=&4@:W)B-2!E
M>'1E;G1I92!N:65T(&=E=F]N9&5N+@!!=71H7VQD87`Z('1O979O96=E;B!V
M86X@9V5B<G5I:V5R<R!W;W)D="!N:65T(&]N9&5R<W1E=6YD('9O;W(@06-T
M:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%9E<G=I:F1E<F5N('9A;B!G96)R
M=6EK97)S('=O<F1T(&YI970@;VYD97)S=&5U;F0@=F]O<B!!8W1I=F4@1&ER
M96-T;W)Y`$%U=&A?;&1A<#H@=F5R96ES=&4@3$1!4"!E>'1E;G1I92!N:65T
M(&=E=F]N9&5N+@!!=71H7VQD87`Z($YI970@:6X@<W1A870@9V5B<G5I:V5R
M("5S('1O92!T92!V;V5G96XN($1E('-E<G9E<B!M96QD=#H@`$%U=&A?;&1A
M<#H@3FEE="!I;B!S=&%A="!G96)R=6EK97(@)7,@=&4@=F5R=VEJ9&5R96X`
M075T:%]L9&%P.B!.:65T(&EN('-T86%T(&=E8G)U:6ME<B`E<R!B:6H@=&4@
M=V5R:V5N`$%U=&A?;&1A<#H@0FEJ=V5R:V5N('9A;B!G96)R=6EK97)S('=O
M<F1T(&YI970@;VYD97)S=&5U;F0@=F]O<B!!8W1I=F4@1&ER96-T;W)Y+@!!
M=71H7VUC86PZ('9E<F5I<W1E($U#04P@97AT96YT:64@;FEE="!G979O;F1E
M;BX`075T:%]S;6)A=71H.B!V97)E:7-T92!S;6)A=71H(&5X=&5N=&EE(&YI
M970@9V5V;VYD96XN`$%U=&AE;G1I8V%T:64@;W`@24U!4"!S97)V97(@;6ES
M;'5K="X`075T:&5N=&EC871I92!M:7-L=6MT`$%U=&AE;G1I8V%T:64@;6ES
M;'5K="X@)7,`075T:&5N=&EC871I92!G97=E:6=E<F0@9&]O<B!D92!2041)
M55,@<V5R=F5R+@!!=71H96YT:6-A=&EE(&]P($944"!S97)V97(@;6ES;'5K
M="X`075T:&5N=&EC871I92!O<"!D92!334(@<V5R=F5R(&UI<VQU:W0N`$)E
M<V-H:6MB87)E('9E;&1E;CH`07IE<F)A:61Z:F%N`$)/1D@@17AC=7-E<P!!
M8VAT97)G<F]N9`!!8VAT97)G<F]N9&ML975R`$9O=70@:V5R8F5R;W-W86-H
M='=O;W)D+@!&;W5T92!K97)B97)O<V=E8G)U:6ME<G-N86%M+@!"86AA;6%S
M`$)A:')E:6X`0F%L=&ES8V@@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H`$)A
M<F)A9&]S`$)A<VES(&%F8F5E;&1I;F=E;F1I<F5C=&]R>2`B)7,B(&YI970@
M9V5V;VYD96XN`$)A<VES;&EJ;@!7:70@<G5S;&%N9`!"96QG:>L`0F5L:7IE
M`$)E;FEN`$)E<FUU9&$`0FAU=&%N`%9E<FIA87)D86<`0FQO:R`B)7,B('9A
M;B!T;V5P87-S:6YG("(E<R(@;FEE="!G979O;F1E;BX`0FQO:VEN<W1E;&QI
M;F=E;@!";&]K='EP90!6970`0F]L:79I80!";V]K;6%R:W,`4F%N9`!286YD
M9&EK=&4Z`%)A;F1E;@!";W-N:>L@96X@2&5R>F5G;W9I;F$`0F5I9&5N`$)O
M='-W86YA`$]N9&5R:V%N=`!";W5V970@96EL86YD`$)R87II;&GK`$)R:71S
M($EN9&ES8VAE($]C96%A;B!497)R:71O<FEU;0!"<G5N96D@1&%R=7-S86QA
M;0!"=6QG87)I:F4`3VYG96]R9&5N9&4@;&EJ<W0`0G5R:VEN82!&87-O`$)U
M<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:65P=6YT96X`0U]E;&5I9V5N
M<V-H87!P96XN+BX`0V%C:&4@:6YI=&EA;&ES871I92!I<R!N:65T(&%F9V5R
M;VYD+@!!9V5N9&$`2V%L;0!#86UB;V1J80!+86UE<F]E;@!+86X@=V%C:'1W
M;V]R9"!N:65T(&%U=&]M871I<V-H(')E<V5T=&5N+"!N965M(&-O;G1A8W0@
M;W`@;65T(&1E('-Y<W1E96UB96AE97)D97(N`$MA;B!N:65T(&YA87(@8F5S
M=&%N9"`B)7,B('-C:')I:G9E;@!+86X@9V5E;B!E>'1E<FYE('-E<W-I96AA
M;F1L97(@8F5H97)E;BX`2V%N(&YI970@=F5R8FEN9&5N(&UE="!)34%0('-E
M<G9E<CH@)7,`2V%N(&)E<W1A;F0@(B5S(B!N:65T(&]P96YE;BX`0V%N861A
M`$%F8G)E:V5N`%!R;V)L965M<F%P<&]R="!A9F)R96ME;@!+86X@8F5S=&%N
M9"`B)7,B(&YI970@=F5R=VEJ9&5R96XN`$MA;B!G965N('1I:F1E;&EJ:V4@
M9&ER96-T;W)Y('9I;F1E;BX`2V%N(&YI970@9&]O<F=A86X@>F]N9&5R("=T
M87)G971&:6QE)R!P87)A;65T97(N`$MA;B!D:7)E8W1O<GD@(B5S(B!N:65T
M('9E<G=I:F1E<F5N+@!+86X@;FEE="!V97)W:6ID97)E;CL@)60@8VAI;&1R
M96X@8F5S=&%A;BX`2V%N(&YI970@;W!N:65U=R!R86YG<V-H:6MK96XL(&AE
M="!A86YT86P@:6YV;V5R96X@;VT@;W!N:65U=R!T92!R86YG<V-H:6MK96X@
M:V]M="!N:65T(&]V97)E96X@;65T(&AE="!O<&=E<VQA9V5N(&%A;G1A;"X`
M2V%N(&)E<FEC:'0@;FEE="!N86%R(&AE="!O<&=E9V5V96X@;G5M;65R('9E
M<G-T=7)E;BX`2V%A<"!697)D90!/<'-C:')I9G0`1')A9V5R`$-A=&5G;W)I
M9>MN(&5N(&QA8F5L<P!#87EM86X@96EL86YD96X`5&5L+FYR+FUO8FEE;`!#
M96QE:6=E;G-C:&%P<&5N`$-E;"!V<FEJ92!R=6EM=&4Z`$-E;&5I9V5N<V-H
M87!P96X`0V5L<W!A=&GK<FEN9SH`5&5L+FYR+FUO8FEE;`!+96QT:7-C:"`H
M25-/+3@X-3DM,30I`$UI9&1E;@!#96YT<F%A;"!!9G)I:V%A;G-E(%)E<'5B
M;&EE:P!#96YT<F%A;"!%=7)O<&5E<R`H25-/+3@X-3DM,BD`0V5R=&EF:6-A
M871D971A:6QS`$-E<G1I9FEC86%T96EG96YA87(`0V5R=&EF:6-A871B96QE
M:60`5'-J86%D`%=I:GII9V5N`%=I:GII9R!U=R!W86-H='=O;W)D`%=I:GII
M9R!D92!N86%M+"!A9')E<R!E;B!O;F1E<G1E:V5N:6YG(&1I92!M96X@>FEE
M="!B:6H@:&5T(&QE>F5N(&5N(&)E86YT=V]O<F1E;B!V86X@=7<@92UM86EL
M<RX`5VEJ>FEG96X@=F%N('5W('=A8VAT=V]O<F0@=V]R9'0@;FEE="!O;F1E
M<G-T975N9"!D;V]R(&1E(&AU:61I9V4@8V]N9FEG=7)A=&EE+B!.965M(&-O
M;G1A8W0@;W`@;65T('5W('-Y<W1E96UB96AE97)D97(N`$MA<F%K=&5R`$-O
M;G1?<F]L965R(&QI;FLN+BX`0VAI;&D`0VAI;F$`0VAI;F5E<R!V97)E96YV
M;W5D:6=D("A'0C(S,3(I`$-H:6YE97,@=')A9&ET:6]N965L("A":6<U*0!+
M:65S('1O97!A<W-I;F<Z`$MI97,@965N('=A8VAT=V]O<F0`2VEE<R!E96X@
M9V5B<G5I:V5R<VYA86T`2VEE<R!D871U;7=E97)G879E.@!+:65S(&QI:G-T
M<W1I:FQT>7!E("AV;V]R(&=E;W)D96YD92!L:6IS=&5N*0!#:')I<W1M87,@
M96EL86YD`$-L87-S9&5F:6YI=&EE('9A;B`E<R!N:65T(&=E=F]N9&5N+@!(
M96QD97(`35-/9F9I8V4@=&%G<R!W:7-S96X`5VES('%U97)Y`%=I<R!G96)R
M=6EK97(Z("5S`%=I<R!G96)R=6EK97(`5VES(&=E8G)U:6ME<G-D871A`$QA
M=&4@;W!K;&%R:6YG96X`2VQI:R!O;2!V97)D97(@=&4@9V%A;@!#;&EC:V%T
M96QL('9I82!(5%10`%-L=6ET('-C:&5R;0!7;VQK96X`5G)O96=E(&)E=V]L
M:VEN9P!"97=O;&MT`$-O8V]S("A+965L:6YG*2!E:6QA;F1E;@!::6IB86QK
M(&EN:VQA<'!E;@!);F=E:VQA<'1E(')A;F1E;@!#;VQO;6)I80!+;&5U<@!+
M;&5U<F5N:VEE>F5R`$ML975R<V5L96-T:64`2V]L;VUM96XZ`$MO;&]M=&ET
M96QS`%-T<FEP<P!/<&1R86-H=`!/<&1R86-H='-H96QL`$]P;65R:VEN9P!!
M;&=E;65N92!N86%M`$-O;6]R96X`0F5D<FEJ9@!#;VUP=71E<G,`0V]N9&ET
M:64`0V]N9&ET:65S`%9E<G-C:&EL;&5N(&EN(&-O;F9I9W5R871I90!#;VYF
M:6=U<F%T:64@=F]O<B!H970@<WEN8VAR;VYI<V5R96X@;65T(%!$02=S+"!3
M;6%R='!H;VYE<R!E;B!/=71L;V]K+@!#;VYF:6=U<F%T:64@:7,@=F5R;W5D
M97)D+@`E<R!C;VYF:6=U<F5R96X`0F5V97-T:6<@=V%C:'1W;V]R9`!+;VYG
M;P!+;VYG;RP@1&4@1&5M;V-R871I<V-H92!297!U8FQI96L@=F%N(&1E`%9E
M<F)I;F1I;F<@;6ES;'5K="X`5F5R8FEN9&EN9R!M:7-L=6MT.B``5F5R8FEN
M9&EN9RP@;65T(&1E(&]P96YB87)E('-L975T96QS97)V97(L(&ES(&=E=V5I
M9V5R9"X`5F5R8FEN9&EN9RP@;65T(&1E(&]P96YB87)E('-L975T96QS97)V
M97(L(&ES(&=E=V5I9V5R9"X@4F5D96XZ("5S("@E<RD`5F5R8FEN9&EN9R!M
M970@1E10('-E<G9E<B!M:7-L=6MT+@!!9')E<W-E;@!!9')E<W-E;B!Z:6IN
M(&UE="!S=6-C97,@86%N('5W(&%D<F5S8F]E:R!T;V5G979O96=D+@!#;VYT
M96YT('1Y<&4@=F%N(&=E8V]M<')I;65E<F0@8F5S=&%N9#H@`$EN:&]U9"!V
M86X@(B5S(@!$;V]R9V%A;@!#;V]K(&5I;&%N9&5N`$-O;VMI90!+;W!IZW)E
M;@!+;W!IZW)E;B!M:7-L=6MT.B`E<P!+;W!I965R('-E;&5C=&EE`$MO<W1E
M;B!)1`!#;W-T82!2:6-A`$EV;V]R:W5S=`!+;VX@4$=0(&)E<FEC:'0@;FEE
M="!C;V1E<F5N.B``2V]N(%!'4"!B97)I8VAT(&YI970@;VYD97)T96ME;F5N
M.B``2V]N(&)E<FEC:'0@;FEE="!3+TU)344@8V]D97)E;BX`2V]N(&)E<FEC
M:'0@;FEE="!3+TU)344@;VYD97)T96ME;F5N+@!+;VX@861R97,@)7,@;FEE
M="!T;V5V;V5G96XN`$MO;B!G965N('9E<F)I;F1I;F<@;65T(&1E($Q$05`M
M<V5R=F5R(&UA:V5N+@!+;VX@=&5G;V5D("5S(&YI970@8V]N=')O;&5R96XN
M`$MO;B!N:65T('9E<F)I;F1E;B!M970@3$1!4"!S97)V97(N`$MO;B!N:65T
M('9E<F)I;F1E;B!M970@<V5R=F5R("(E<R(@;65T($944#H@)7,`2V]N(&=E
M96X@9&ES=')I8G5T:65L:6IS="`E<R!M86ME;BX`2V]N(%!'4"!D871A(&YI
M970@9&5C;V1E<F5N.B``2V]N(%,O34E-12!D871A(&YI970@9&5C;V1E<F5N
M+@!+;VX@861R97,@)7,@;FEE="!V97)W:6ID97)E;BX`2V]N(&1I<W1R:6)U
M=&EE;&EJ<W0@)7,@;FEE="!V97)W:6ID97)E;BX`2V]N('-E='5P('5P9W)A
M9&4@<V-R:7!T("(E<R(@;FEE="!V97)W:6ID97)E;BX`2V]N(&AE="!E+6UA
M:6QA9')E<R!V86X@9&4@;VYT=F%N9V5R(&YI970@8F5P86QE;BX`2V]N(&-O
M;7!L971E(&%D<F5S8F]E:R!N:65T(&]P:&%L96XN`$MO;B!C;VUP;&5T92!D
M:7-T<FEB=71I96QI:G-T(&YI970@;W!H86QE;BX`2V]N(&-O;7!L971E(&QI
M:G-T('9A;B!D:7-T<FEB=71I96QI:G-T96X@;FEE="!O<&AA;&5N+@!+;VX@
M<W1R871E9VEE("(E<R(@;FEE="!L861E;BX`2V]N(&1I<F5C=&]R>2`B)7,B
M(&YI970@;6%K96XN`$MO;B!D92!O<&5N8F%R92!S;&5U=&5L(&YI970@=F5R
M:W)I:F=E;B!V86X@9&4@<VQE=71E;'-E<G9E<BX`2V]N("(E<R(@;FEE="!O
M<&5N96X@=F]O<B!S8VAR:6IV96XN`$MO;B`E<R!N:65T(&]P96YE;BX`2V]N
M(&]N9&5R:&]U9'-T86ME;FUO9'5L92`E<R!N:65T(&]P96YE;@!+;VX@9&ER
M96-T;W)Y("(E<R(@;FEE="!O<&5N96XN`$MO;B!D92!,1$%0+7-E<G9E<B!N
M:65T(&)E<F5I:V5N+@!+;VX@)7,@;FEE="!L97IE;BX`2V]N(&AE="!W86-H
M='=O;W)D('9A;B!D92!G97=E;G-T92!G96)R=6EK97(@;FEE="!R97-E='1E
M;BX@4V]M;6EG92!O9B!A;&QE(&1E=&%I;',@>FEJ;B!N:65T(&IU:7-T+B!0
M<F]B965R(&]P;FEE=7<@;V8@;F5E;2!C;VYT86-T(&]P(&UE="!D92!S>7-T
M965M8F5H965R9&5R+"!W86YN965R('4@=F5R9&5R92!H=6QP(&YO9&EG(&AE
M969T+@!+;VX@04-,(&YI970@;W!H86QE;@!+;VX@861R97-B;V5K("5S(&YI
M970@;W!H86QE;BX`2V]N(&1I<W1R:6)U=&EE;&EJ<W0@)7,@;FEE="!O<&AA
M;&5N+@!+;VX@9&ES=')I8G5T:65L:6IS=&5N("5S(&YI970@;W!H86QE;BX`
M2V]N('-E<G9E<F)E:W=A86UH961E;B!N:65T(&]P:&%L96X`2V]N(&-O;F9I
M9W5R871I92!N:65T('1E<G5G>F5T=&5N+@!+;VX@9&ER96-T;W)Y("(E<R(@
M;FEE="!V97)W:6ID97)E;BX`2V]N(&-O;F9I9W5R871I92`E<R!N:65T(&]P
M<VQA86XN`$MO;B!G965N(&)A8VMU<&-O;F9I9W5R871I92!O<'-L86%N+@!+
M;VX@9V5E;B!B86-K=7!C;VYF:6=U<F%T:64@;W!S;&%A;CH@)7,`2V]N('-E
M='5P('5P9W)A9&4@<V-R:7!T(&YI970@;W!S;&%A;B!A;',Z("(E<R(N`$MO
M;B!H970@8F%C:W5P8V]N9FEG=7)A=&EE8F5S=&%N9"!N:65T(&]P<VQA86X@
M)7,N`$MO;B!H970@8V]N9FEG=7)A=&EE8F5S=&%N9"`E<R!N:65T(&]P<VQA
M86XN(%4@:W5N="!O9B#KZVX@=F%N(&1E(&]P=&EE<R!G96)R=6EK96X@;VT@
M9&4@8V]D92!T97)U9R!O<"!T92!S;&%A;B!O<"`E<R!O9B!O;F1E<G-T86%N
M9&4@8V]D92!H86YD;6%T:6<@;F%A<B`E<R!K;W!IZW)E;BX`2V]N(&1E($Q$
M05`M<V5R=F5R(&YI970@9&]O<GIO96ME;BX`2V]N("(E<R(@;FEE="!L;W-K
M;W!P96QE;BX`2V]N(&%D<F5S("5S(&YI970@8FEJ=V5R:V5N+@!+;VX@9&ES
M=')I8G5T:65L:6IS="`E<R!N:65T(&)I:G=E<FME;BX`2V]N(&-O;F9I9W5R
M871I92!V;V]R("(E<R(@;FEE="!W96=S8VAR:6IV96XZ("5S`$MO;B!D92!-
M;WII;&QA(%-I9&5B87(@;FEE="!V:6YD96XN(%IO<F<@97)V;V]R(&1A="!D
M92!S:61E8F%R(&]P96X@:7,N`$MO;B!G96)R=6EK97(@(B5S(B!D92!V;VQG
M96YD92!R96-H=&5N(&]P(&1E(&UA<"`B)7,B(&YI970@9V5V96XZ("5S`$=E
M=&5L9&4@=&5K<W0`3&%N9`!#=7)S=7-S96X`36%K96X`36%A:R!E96X@;&EN
M:P!-86%K(&5E;B!N:65U=V4`36%A:R!S=6)M87!P96X`16EG96YA87)R96-H
M=&5N`$-R961I=&-A<F1N=6UM97(`2W)O871IZP!#=6)A`$AU:61I9V4@-"!F
M87-E;@!(=6ED:6=E('-E<W-I97,`2'5I9&EG92!T:6ID`$AU:61I9V4@55),
M(&ES`$AU:61I9V4@9V5B<G5I:V5R<P!(=6ED:6<@=V5E<@!(=6ED:6=E(&-O
M;F1I=&EE.B``2'5I9&EG92!S=&EJ;`!!86YP87-S96X@=F%N('1A:V5N('1I
M:F1E;G,@86%N;65L9&EN9R!B:6H@)7,N`$MN:7!P96X`4V5L96-T:64@:VYI
M<'!E;@!#>7!R=7,`0WER:6QL:7-C:"`H2T])."U2*0!#>7)I;&QI<V-H("A7
M:6YD;W=S+3$R-3$I`$-Y<FEL;&ES8V@O56MR86EN<R`H2T])."U5*0!4<VIE
M8VAI<V-H92!297!U8FQI96L`1$0`1%-.("AZ:64@:'1T<#HO+W!E87(N<&AP
M+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN
M<&AP*0!$86=E;&EJ:W,`1&%T851R964@8G)O=W-E<@!$871A8F%S92!D;V]R
M>F]E:V5N`$1A='5M`$1A='5M($]N='9A;F=E;@!$871U;2!S96QE8W1I90!$
M86<`5F5R7W=I:F1E<B!K;VQO;0!$96-E;6)E<@!$96-I;6%L92!G971A;&QE
M;@!);G-P<FEN9V5N('9E<FML96EN96X`4W1A;F1A87)D`%-T86YD86%R9"!K
M;&5U<@!3=&%N9&%A<F0@:61E;G1I=&5I=`!3=&%N9&%A<F0@<VAE;&P`1&5F
M:6YI=&EE<P!697)W:6ID97)E;@!697)W:6ID97(@8V5L`$=R;V5P('9E<G=I
M:F1E<F5N`%9E<G=I:F1E<B!L;V<`4F5C:'0@=F5R=VEJ9&5R96X`5F5R=VEJ
M9&5R(&5N('=I<R!B97)I8VAT96X`5F5R=VEJ9&5R(&-E;`!697)W:6ID97(@
M:V]L;VT`0F5S=&%A;F0@86QT97)N871I968@<VIA8FQO;VX@=F5R=VEJ9&5R
M96X`5F5R=VEJ9&5R(&)E<FEC:'1E;@!296-H=&5N('9A;B`B)7,B('9E<G=I
M:F1E<F5N`%)E8VAT96X@96X@979E;G1U96QE('-U8G)E8VAT96X@=F]O<B`B
M)7,B('9E<G=I:F1E<F5N/P!697)W:6ID97(@<FEJ`$=E<V5L96-T965R9&4@
M:61E;G1I=&5I="!V97)W:6ID97)E;@!697)W:6ID97(@<W5B;6%P<&5N`%9E
M<G=I:F1E<B!D92!H=6ED:6=E(&MO;&]M`%9E<G=I:F1E<B!D92!H=6ED:6=E
M(')I:@!3971U<"!U<&=R861E('-C<FEP="`B)7,B('9E<G=I:F1E<F0N`$%F
M;&5V97)T:6ID`$1E;F5M87)K96X`0F5S8VAR:6IF(&AE="!P<F]B;&5E;0!"
M97-C:')I:G9I;F<`1&5T86EL<R`H;V]K(&EN($AO<F1E)W,@;&]G8F5S=&%N
M9"DZ`$1E=&%I;',@>FEJ;B!G96QO9V0@=F]O<B!D92!S>7-T965M8F5H965R
M9&5R+@!/;G1W:6MK96QI;F<`1&%U=W!U;G0`1&%U=W!U;G0@=F]O<B!H970@
M869G96QO<&5N('5U<CH@`$1A=7=P=6YT.B``4FEC:'1I;F<@;&EN:W,@;F%A
M<B!R96-H=`!2:6-H=&EN9R!R96-H=',@;F%A<B!L:6YK<P!$:7)E8W1O<GD`
M,C0M=75R<R!T:6ID=V5E<F=A=F4_`%=E97)G879E;W!T:65S`$=E9&5T86EL
M;&5E<F1E('=E97)S=F]O<G-P96QL:6YG('1O;F5N`%=E97)S=F]O<G-P96QL
M:6YG('1O;F5N("A4048I`%=E97)G879E9F]R;6%A=`!6;V]R8F5R96ED:6YG
M<VYO=&EF:6-A=&EE`$1J:6)O=71I`$YI970@=F5R=VEJ9&5R96X`;6%I;G1E
M;F%N8V4N<&AP(&YI970@9&ER96-T(&%A;G-P<F5K96X`0F5V870@9&4@965R
M<W1E(')I:B!D92!V96QD;F%M96X_(%IO(&IA+"!D:70@:&]K:F4@86%N=FEN
M:V5N.@!$;VUI;FEC80!$;VUI;FEC86%N<V4@4F5P=6)L:65K`$=E96X@86-C
M;W5N=#\@4V-H<FEJ9B!U(&EN+@!$;W=N;&]A9&5N`"5S(&1O=VYL;V%D96X`
M1&]W;FQO860@9V5G96YE<F5E<F1E(&-O;F9I9W5R871I92!A;',@4$A0('-C
M<FEP="X`1')O<"!D;W=N(&QI:G-T`$1R=6=S`$4M36%I;`!%+6UA:6P@;F%A
M<B!335,@9V%T97=A>2!S='5U<G!R;V=R86UM82P@=F]O<B!D<F%G97)S(&1I
M92!D97IE('-E<G9I8V4@;VYD97)S=&5U;F5N+@!%4E(`16-U861O<@!"97=E
M<FME;@!";&]K(&)E=V5R:V5N`$=R;V5P(&)E=V5R:V5N`%)E8VAT(&)E=V5R
M:V5N`%)E8VAT96X@8F5W97)K96X`4F5C:'1E;B!V86X@)R5S)R!B97=E<FME
M;@!/<'1I97,@8F5W97)K96X@=F]O<CH`4F5C:'1E;B!V86X@(B5S(B!B97=E
M<FME;@!296-H=&5N('9A;B`E<R!B97=E<FME;@!/;F1E<G=I:G,`16=Y<'1E
M`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`12UM86EL`$4M;6%I;&%D<F5S
M`$4M;6%I;&%D<F5S<V5N(&UO971E;B!O=F5R965N:V]M96XN`$4M;6%I;"!M
M970@8F5V97-T:6=I;F<`12UM86EL(&YA87(@4TU3(&=A=&5W87D`16UO=&EC
M;VYS`$QE96<@8F5R:6-H="X`1V5E;B!R97-U;'1A870N`$QE9V4@>F]E:W1E
M<FUE;@!);G9O96=E;B!V86X@869B965L9&EN9V5N('5I="!F;W1O86QB=6US
M(&EN('1E:W-T(&EN<V-H86ME;&5N/P!296-H=&ML:6MK96X@8V]N=&5X="!M
M96YU(&EN<V-H86ME;&5N/P!%:6YD:F%A<@!697)G<F]O="!E9&ET;W(`1V5E
M9B!E96X@8F5V96EL:6=I;F=S=G)A86<@9&EE('4@9V5V<F%A9V0@=V]R9'0L
M('=A;FYE97(@:&5T(&YO9&EG(&ES(&]M('5W('=A8VAT=V]O<F0@=&4@<F5S
M971T96XL(&(N=BX@)W=A="!I<R!D92!N86%M('9A;B!U=R!H=6ES9&EE<C\G
M.@!6;V5R(&1E(&%F8F5E;&1I;F<@55),(&AI97(@:6X`5F]E<B!O;F1E<G-T
M86%N9&4@;&5T=&5R<R!I;CH`17%U871O<FEA86P@1W5I;F5E`$5R:71R96$`
M1F]U=`!&;W5T(&)I:B!M86ME;B!V86X@8FQO:SH@)7,`1F]U="!B:6H@=F5R
M=VEJ9&5R96X@=F%N('-Y;F,@86YK97(Z("5S`$9O=70@8FEJ('9E<G=I:F1E
M<F5N('9A;B!S>6YC(&QO9SH@)7,`1F]U="!B:6H@;W!H86QE;B!V86X@:6YH
M;W5D.B`E<P!&;W5T(&)I:B!B:6IW97)K96X@=F%N('=A8VAT=V]O<F0Z("5S
M`$9O=70@;65T(&4M;6%I;&)E<FEC:'0N`$9O=70@8FEJ('-C:')I:G9E;B!V
M86X@(B5S(BX`17-T;&%N9`!%=&AI;W!IZP!%=&YI<V-H`$5U<F]P80!%;&ME
M(#$U(&UI;G5T96X`16QK92`R(&UI;G5T96X`16QK92`S,"!S96-O;F1E;@!%
M;&ME(#4@;6EN=71E;@!%;&ME(&%A;FUE;&1I;F<`16QK(&AA;&8@=75R`$5L
M:V4@;6EN=75T`%9O;W)B965L9'=A87)D96XZ`%5I='9O97)E;@!5:71K;&%P
M<&5N`%II:F)A;&L@=6ET:VQA<'!E;@!697)W86-H='1E("<I)P!697)W86-H
M='1E(&5N:V5L('=O;W)D(&]F(&%A;F=E:&%A;&1E('IO96MT97)M`%9E<G9A
M;&1A='5M`$5X<&]N96YT`%9O;W)G<F]N9&ML975R`$944"!U<&QO860@=F%N
M('-E='5P`$]P:&%L96X@=F]O<FME=7)S:6YS=&5L;&EN9V5N(&UI<VQU:W0N
M`%9E<F)I;F1I;F<@;65T(&1E($Q$05`M<V5R=F5R(&ES(&UI<VQU:W0N`%9E
M<F)I;F1I;F<@;65T(&1E(%--0BUS97)V97(@:7,@;6ES;'5K="X`2V]P:>MR
M96X@=6ET("(E<R(@:7,@;6ES;'5K="X`2V]P:>MR96X@;F%A<B`B)7,B(&ES
M(&UI<VQU:W0N`$UA:V5N('9A;B!N:65U=V4@4T%33"!V97)B:6YD:6YG(&ES
M(&UI<VQU:W0N`%9E<G!L86%T<V5N(&YA87(@(B5S(B!I<R!M:7-L=6MT+@!/
M<&AA;&5N('9A;B`E<R!I<R!M:7-L=6MT`$UO;VD`1F%L:VQA;F0@96EL86YD
M96X@*$UA;'9I;F%S*0!&87)OZW(@96EL86YD96X`1F%T86QE(&9O=70Z`$9A
M>`!&87AE;@!&96)R=6%R:0!6;V5L="!A;',`5F]E;'0@86QS.B``16YK96QE
M(&)U:65N`$5N:6=E('-N965U=V)U:65N`%9E;&1M871R:7@`1FEG;&5T($-!
M4%1#2$$`1FEG;&5T(&9O;G0`1FEJ:0!"97-T86YD`$%A;G1A;"!B97-T86YD
M96XZ("5S(&)E<W1A;F0`06%N=&%L(&)E<W1A;F1E;CH@)7,@8F5S=&%N9&5N
M`$)E<W1A;F1B96AE97(`0F5S=&%N9'-N86%M`$)E<W1A;F0@:VEE>F5N`$)E
M<W1A;F1U<&QO860`0F5S=&%N9'5P;&]A9',@=V]R9&5N(&YI970@;VYD97)S
M=&5U;F0N`$9I;'1E<G,`1FEN;&%N9`!%97)S=&4@:&5L9G0`165R<W1E(&MW
M87)T86%L`%9E<FAO=61I;F<@:&5R<W1E;&QE;@!/;6ME<F5N`$1R:6IV96X`
M36ES=`!-87`@)7,@8F5S=&%A="!N:65T`$9O;G1K;&5U<@!6;V5D<V5L`%9O
M;W(@8G)O=W-E<G,@9&EE(&=E96X@869B965L9&EN9V5N(&]N9&5R<W1E=6YE
M;@!7965R<W9O;W)S<&5L;&EN9R`H5$%&*0!6;V]R=6ET>FEC:'1D86=E;B`H
M;65R:R!O<"!D870@:&5T(&=E9V5V96X@=F]O<G5I='II8VAT(&1A9V5N(&5N
M(&YA8VAT96X@9V5E9G0[(&5E;B!G<F]O="!A86YT86P@:V%N(')E<W5L=&5R
M96X@:6X@965N(&)R965D(&)L;VLI`%5W('=A8VAT=V]O<F0@=F5R9V5T96X_
M`$9O<FUU;&EE<F5N`$9O<G1U;F4`1F]R='5N971Y<&4`1F]R='5N97,`1F]R
M='5N97,@,@!&;W)U;7,`1&]O<G-T=7)E;@!6<@!&<F%M97,`1G)A;FMR:6IK
M`$9R86YK<FEJ:RP@2&]O9F1S=&5D96QI:FL`1G)A;G,@1W5Y86YA`$9R86YS
M(%!O;'EN97-IZP!&<F%N<V4@6G5I9&5L:6IK92!497)R:71O<FEA`%9A;@!6
M86X@9&4@`%9O;&QE9&EG92!B97-C:')I:G9I;F<`5F]L;&4@;6%A;@!6;VQL
M961I9V4@;F%A;0!'86)O;@!!;&)U;2!W86%R=6ET(&1E(&%F8F5E;&1I;F<@
M9V5H86%L9"!D:65N="!T92!W;W)D96X`06QB=6TZ`$=A;6)I80!'96YE<F5E
M<B`E<R!C;VYF:6=U<F%T:64`1V5G96YE<F5E<F1E(&-O9&4`1V5O<F=IZP!$
M=6ET<VQA;F0`1VAA;F$`1VEB<F%L=&%R`%9O;W)N86%M`$=L;V)A;&4@;W!T
M:65S`$=A`$=O961E;`!';V]G;&4@:V%A<G1E;@!';V]G;&4@>F]E:V5N`$=R
M:6IS<V-H86%L`$=R:65K96YL86YD`$=R:65K<R`H25-/+3@X-3DM-RD`1W)O
M96YL86YD`$=R96YA9&$`1W)O97!S8F5H965R`$=R;V5P;F%M96X@;6]G96X@
M;FEE="!L965G('II:FX`1W)O=7!?;&1A<#H@3FEE="!I;B!S=&%A="!G<F]E
M<"`E<R!T;V4@=&4@=F]E9V5N+B!$92!S97)V97(@;65L9'0Z(`!'<F]U<%]L
M9&%P.B!.:65T(&EN('-T86%T(&=R;V5P("5S('1E('9E<G=I:F1E<F5N`$=R
M;W5P7VQD87`Z($YI970@:6X@<W1A870@9W)O97`@)7,@8FEJ('1E('=E<FME
M;@!'<F]E<&5N`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`
M1V%S="!R96-H=&5N`$=A<W1E;F)O96L`1W5I;F5E`$=U:6YE92U":7-S874`
M1W5Y86YA`$A434P`2%1-3$%R96$@=V5I9V5R="!L868@;VT@9&4@;&%A='-T
M92!C96P@:6X@9&4@<FEJ('1E('9E<G=I:F1E<F5N+@!(5$U,07)E82!W96EG
M97)T(&QA9B!O;2!D92!L86%T<W1E(&MO;&]M(&EN(&1E('1A8F5L('1E('9E
M<G=I:F1E<F5N+@!(5$U,07)E82!W96EG97)T(&QA9B!O;2!D92!L86%T<W1E
M(')I:B!I;B!D92!T86)E;"!T92!V97)W:6ID97)E;BX`2%144"!A=71H96YT
M:6-A=&EE(&YI970@9V5V;VYD96XN`$AA:71I`$AA<V@M86QG;W)I=&AM90!.
M979E;`!+;W``2V]P<&5N`$AE87)D(&5I;&%N9"!E;B!-8T1O;F%L9"!E:6QA
M;F1E;@!:=V%R92!O;G=E97)S8G5I`$AE8G)E975W<R`H25-/+3@X-3DM."U)
M*0!(;V]G=&4`2&5L<`!(96QP(&)I:B!G96)R=6EK('9A;B!E9&ET;W(`2&5L
M<&5R`$AA;&9R;VYD`$AI97(@:7,@:&5T(&)E9VEN('9A;B!H970@8F5S=&%N
M9#H`2&]O9P!(;U]M90!(;VQY(%-E92`H5F%T:6-A86YS=&%D*0!(;VUE`$%D
M<F5S("AP<FEVZ2D`2&]M961I<F5C=&]R>0!496PN;G(N("AP<FEVZ2D`2&]N
M9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!/;F=E;&1I9V4@
M)7,@6$U,(&1A=&$@=&5G96YG96MO;65N(&EN(&)E<FEC:'0@)7,`2&]R9&4O
M2V]L86(Z($=E96X@8F5R:6-H="!C;W)R97-P;VYD965R="!M970@;V)J96-T
M("5S`$AO<F1E+TMO;&%B.B!'965N(&]B:F5C="!V86X@='EP92`E<R!G979O
M;F1E;B!I;B!B97)I8VAT("5S`$AO<F1E+TMO;&%B.B`E<R!M970@<W5C8V5S
M('9E<G=I:F1E<F0@(B5S(@!(;W)D92]+;VQA8CH@1&4@:6YT97)G<F%T:64@
M=F5R96ES="!D92`G9&]M>&UL)R!E>'1E;G-I90!(;W)D92]+;VQA8CH@2V%N
M(&=E96X@;FEE=7=E(%A-3"!B;V]M(&UA:V5N('9O;W(@;V)J96-T("5S`$AO
M<F1E+TMO;&%B.B!+86X@)7,@(B5S(B!N:65T('9E<G=I:F1E<F5N.B`E<P!(
M;W)D92]+;VQA8CH@3FEE="!I;B!S=&%A="!H970@34E-12!)1"P@=F]O<B!H
M970@9V5D965L=&4@;65T('1Y<&4@)7,L(&]P('1E(&AA;&5N`$AO<F1E+TMO
M;&%B.B!+86X@)7,@(B5S(B!N:65T('-Y;F-H<F]N:7-E<F5N.B`E<P!(;W)D
M92]+;VQA8CH@2V%N(&=E9&5E;&1E(&)R;VYN96X@;FEE="!S>6YC:')O;FES
M97)E;CH@)7,`2&]R9&4O2V]L86(Z($]N8F5K96YD92!G961E96QD92!B<F]N
M("(E<R(`2&]R:7IO;G1A;&4@;&EJ;@!(;W)I>F]N=&%L92!V<FEJ92!R=6EM
M=&4`2&]R:7IO;G1A86PZ`$AO92!K=V%M('4@:&EE<C\@*$=R86%G(')A<'!O
M<G1A9V4A*0!(;V5V965L(&MO;&]M;65N('=I;'0@=2!S86UE;G9O96=E;C\`
M2&]E=F5E;"!V96QD96X@*&MO;&]M;65N*2!Z:6IN(&5R/P!(;V5V965L(')I
M:F5N('=I;'0@=2!S86UE;G9O96=E;C\`5F]C:'1I9VAE:60`5F]C:'1I9VAE
M:60Z(`!(=6UO<FES=&5N`$AO;F=A<FEJ90!-86ME;B!V86X@24U!4"!M86EL
M8F]X(&UI<VQU:W0Z("5S`%9E<G=I:F1E<F5N('9A;B!)34%0(&UA:6QB;W@@
M;6ES;'5K=#H@)7,`36%K96X@=F%N($E-05`@;6%I;&)O>"!Q=6]T82!M:7-L
M=6MT.B`E<P!)4"!!9')E<P!)4"!A9')E<R!N:65T(&)E<V-H:6MB86%R+@!)
M4"!A9')E<R!V86QT(&YI970@8FEN;F5N(&AE="!T;V5G97-T86YE($-)1%(@
M8FQO:RX`25`@;&]C:V1O=VX@;W9E<G1R961I;F<N`%)I:B!I7VYV;V5G96X@
M=F]O<@!)2G-L86YD`$%L;&5E;B!P:6-T;V=R86UM96X`4&EC=&]G<F%M;65N
M('9O;W(@)7,`4&EC=&]G<F%M;65N(&UE="!T96MS=`!)9&5N=&ET96ET<VYA
M86TZ`%=A;FYE97(@:&5T(&YI970@9V]E9"!W;W)D="!W965R9V5G979E;BP@
M)7,@;VT@:&5T(&EN(&5E;B!N:65U=R!S8VAE<FT@=&4@;W!E;F5N+@!!;',@
M=2!G965N('!I8W1O9W)A;6UE;B!Z:65T+"!B:6H@9V5B<G5I:R!V86X@26YT
M97)N970@17AP;&]R97(L(&MA;B!H970@;F]D:6<@>FEJ;B!D:70@=F%K:F4@
M86%N('1E('9I;FME;B!O;2!03D<@=')A;G-P87)A=&EE('5I="!T92!S8VAA
M:V5L96XN`%=A;FYE97(@=2!D:70@8F5R:6-H="!Z:65T+"!M86%R(&=E96X@
M869B965L9&EN9RP@9&%N(&MA;B!D92!A9F)E96QD:6YG(&1I92!U('=I;'0@
M=7!L;V%D96X@;FEE="!D;V]R('5W(&)R;W=S97(@=V]R9&5N('=E97)G96=E
M=F5N+@!!9F)E96QD:6YG<V)E;V]R9&5L:6YG.@!!9F)E96QD:6YG(%523`!!
M9F)E96QD:6YG(%523#H`069B965L9&EN9R!U:70@86QB=6T`069B965L9&EN
M9R!U:70@86QB=6TZ`$%F8F5E;&1I;F=S=7!L;V%D`$%F8F5E;&1I;F=E;@!)
M;7!O<G1E<F5N+"!S=&%P("5D`$=E:6UP;W)T965R9"!V96QD.B`E<P!'96EM
M<&]R=&5E<F1E('9E;&1E;CH`4FEJ(&EN=F]E9V5N(&YA`$]N:G5I<W1E(&)E
M=V5R:VEN9W-C;V1E(&]P9V5G979E;BX`3VYJ=6ES=&4@9V5B<G5I:V5R<VYA
M86T@96XO;V8@=V%C:'1W;V]R9"X`3VYJ=6ES=&4@9V5B<G5I:V5R<VYA86T@
M;V8@86QT97)N871I968@861R97,N(%!R;V)E97(@;W!N:65U=R!O9B!N965M
M(&-O;G1A8W0@;W`@;65T(&1E('-Y<W1E96UB96AE97)D97(L('=A;FYE97(@
M=2!V97)D97)E(&AU;'`@;F]D:6<@:&5E9G0N`%9E<F=R;V]T(&EN<W!R:6YG
M:6YG`$EN9&EA`$EN9&EV:61U96QE(&=E8G)U:6ME<G,`26YD;VYE<VGK`$EN
M9F\`26YF;W)M871I90!);F9O<FUA=&EE(&YI970@;&%N9V5R(&)E<V-H:6MB
M86%R+@!+;VQO;2!I;G9O96=E;B!N80!!9F)E96QD:6YG(&EN=F]E9V5N`%1A
M8F5L(&EN=F]E9V5N`%=E8FQI;FL@:6YV;V5G96X`7TMO;&]M(&EN=F]E9V5N
M('9O;W(`165N(&YI975W92!K;VQO;2!I;G9O96=E;B!N82!D92!H=6ED:6=E
M`$5E;B!N:65U=V4@:V]L;VT@:6YV;V5G96X@=F]O<B!D92!H=6ED:6=E`$5E
M;B!N:65U=V4@<FEJ(&EN=F]E9V5N(&YA(&1E(&AU:61I9V4`165N(&YI975W
M92!R:6H@:6YV;V5G96X@;F$@9&4@:'5I9&EG90!%96X@;FEE=7=E('!A<F%G
M<F%A9B!I;G9O96=E;B!N82!D92!H=6ED:6=E(&YO9&4`165N(&YI975W92!P
M87)A9W)A868@:6YV;V5G96X@;F$@9&4@:'5I9&EG92!N;V1E`$%L=&5R;F%T
M:65F('-J86)L;V]N(&EN=F]E9V5N`$5E;B!E+6UA:6QA9')E<R!I;G9O96=E
M;BP@=V%A<B!U(&AE="!N:65U=V4@=V%C:'1W;V]R9"!K86X@;VYT=F%N9V5N
M.@!#96P@:6YV;V5G96X@;F$`0V5L(&EN=F]E9V5N('9O;W(`2V]L;VT@:6YV
M;V5G96X@;F$`2V]L;VT@:6YV;V5G96X@=F]O<@!"97)I8VAT96X@:6YV;V5G
M96X`4&%R86=R86%F(&EN=F]E9V5N(&YA`%!A<F%G<F%A9B!I;G9O96=E;B!V
M;V]R`%)I:B!I;G9O96=E;B!N80!2:6H@:6YV;V5G96X@=F]O<@!(970@9V5W
M96YS=&4@86YT=V]O<F0@=F]O<B!D92!B979E:6QI9VEN9W-V<F%A9R!I;G9O
M96=E;CH`069B965L9&EN9R!I;G9O96=E;B]A86YP87-S96X`3&EN:R!I;G9O
M96=E;B]A86YP87-S96X`3VYV;VQD;V5N9&4@:W)E9&EE="!O;2!N86%R(&1E
M(&1I<W1R:6)U=&EE;&EJ<W0@=&4@>F5N9&5N+@!/;G9O;&1O96YD92!K<F5D
M:65T`$EN=&5G97(`26YT96=E<B!L:6IS=`!/;F=E;&1I9V4@541(+B`H57-E
M<B!$871A($AE861E<BDN`$]N9V5L9&EG92!:25`@9&%T80!/;F=E;&1I9V4@
M=&]E<&%S<VEN9RX`3VYG96QD:6<@8F%T8V@@240N`$]N9V5L9&EG92!D871A
M(&]P9V5G979E;BX`3VYG96QD:6<@8F5S=&5M;6EN9V%D<F5S+@!/;F=E;&1I
M9R!T:6ID9F]R;6%A=`!/;F=E;&1I9V4@;&EC96YT:65S;&5U=&5L+@!/;F=E
M;&1I9V4@;&]C871I92!O<&=E9V5V96XN`$]N9V5L9&EG(&US9U]T>7!E+@!/
M;F=E;&1I9R!O9B!O;G1B<F5K96YD(&%P:5]I9"X`3VYG96QD:6=E(&]F(&]N
M=&)R96ME;F1E('!A<F%M971E<G,N`$]N9V5L9&EG('!A<F5N="!R96-H="X`
M3VYG96QD:6<@<&%R=&YE<B!I9"X`3VYG96QD:6=E('!R;V1U8W1I96-O9&4N
M`$]N9V5L9&EG('!R;W1O8V]L+@!/;F=E;&1I9V4@;VYT=F%N9V5R.B`B)7,B
M`$]N9V5L9&EG92!G961E96QD92!B<F]N`$]N9V5L9&EG(&)R;VYA9')E<RX`
M3VYG96QD:6=E('5N:6-O9&4@9&%T82X`26YV96YT87)I<P!396QE8W1I92!O
M;6ME<F5N`$ER86XL($ES;&%M:71I<V-H92!297!U8FQI96L@=F%N`$ER86L`
M265R;&%N9`!%:6QA;F0@36%N`$=E:7-O;&5E<F1E(&]N=V5E<G-B=6EE;@!)
M<W)AZVP`56ET9V5V97(`0W5R<VEE9@!)=&%L:>L`2F%M86EC80!*86YU87)I
M`$IA<&%N`$IA<&%N<R`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86YIZP!*
M=6QI`$IU;FD`=6ET;&EJ;F5N`$=E8V5N=')E97)D('5I=&QI:FYE;@!6;VQL
M961I9R!U:71L:6IN96X`3&EN:W,@=6ET;&EJ;F5N`%)E8VAT<R!U:71L:6IN
M96X`2V%Z86-H<W1A;@!/<FEG:6YE96P@8F5H;W5D96X_`$ME;FEA`$ME<F)E
M<F]S('-E<G9E<B!W96EG97)D92!A=71H96YT:6-A=&EE+@!+97)N96P@3F5W
M8FEE<P!3;&5U=&5L(&UA:V5N`%-L975T96QV:6YG97)A9F1R=6L`4VQE=71E
M;&QE;F=T90!3;&5U=&5L='EP90!3;&5U=&5L9V5B<G5I:P!$92!S;&5U=&5L
M(&)E<W1A870@86P@;W`@9&4@;W!E;F)A<F4@<VQE=71E;'-E<G9E<BX`2VEN
M9&5R96X`2VER:6)A=&D`2V]R96$L($1E;6]C<F%T:7-C:&4@5F]L:W-R97!U
M8FQI96L@=F%N`$MO<F5A+"!297!U8FQI96L@=F%N`$MO<F5A86YS("A%54,M
M2U(I`$MO97=E:70`2WER9VEE<VGK`$]?<&UA86L`5&%A;`!$96UO8W)A=&ES
M8VAE(%9O;&MS<F5P=6)L:65K($QA;P!,86%T<W1E(&AE;&9T`$QA871S=&4@
M=V%C:'1W;V]R9'=I:GII9VEN9P!,86%T<W1E(&MW87)T:65R`$QA871S="!B
M:6IG97=E<FMT.@!,86%T<W1E(&%A;FUE;&1I;F<Z("5S`$QA871S=&4@86%N
M;65L9&EN9SH@)7,@=F%N("5S`$QA871S=&4@86%N;65L9&EN9SH@3F]O:70`
M3&5T;&%N9`!296-H=&5N`$]P;6%A:P!,86%T(&QE96<@=F]O<B!G965N(')A
M;F0`3&EB86YO;@!,:6YK<P!,:6YK<V4@:V]P`$QI;FMS92!W86%R9&5N`$QE
M<V]T:&\`3FEV96%U`$QI8F5R:6$`3&EB:7-C:&4@07)A8FES8VAE($IA;6%H
M:7)I>6$`3&EE8VAT96YS=&5I;@!:86-H="!B=6ET:F4`3&EC:'1E(')E9V5N
M`%9R;V5G(&QI8VAT92!R96=E;@!,:6-H=&4@<F5G96X`3&EC:'1E(')E9V5N
M8G5I`$QI8VAT92!R96=E;B!M970@;VYW965R`$QI8VAT92!S;F5E=7<`3&EC
M:'1E('-N965U=V)U:0!,:6UE<FEC:P!,:6YK`$QI;FL@=VEJ<W0@;F%A<CH`
M3&EN:R!H970@92UM86EL861R97,@86%N(&1E(&YI975W(&)E<FEC:'0@<&%G
M:6YA('1I:F1E;G,@=V5E<F=A=F4`3&EN:W,`3&EN=7@@0V]O:VEE`$QI:G-T
M("T@9V5B<G5I:V5R(&MA;B!D92!M87`@>FEE;@!$871A8F%S96QI:G-T`$QI
M:G-T('9A;B!H96QP(&]N9&5R9&5L96X`5&%B96QL:6IS=`!,:6IS="U!<F-H
M:65F`$QI:G-T+4AE;'``3&EJ<W0M260`3&EJ<W0M16EG96YA87(`3&EJ<W0M
M4&]S=`!,:6IS="U);G-C:')I:G9E;@!,:6IS="U5:71S8VAR:6IV96X`5V5E
M<F=E=F5N('9A;B!S97-S:65L:6IS="!I<R!M:7-L=6MT.B`E<P!7965R9V5V
M96X@=F%N(&=E8G)U:6ME<G-L:6IS="!I<R!M:7-L=6MT.B`E<P!7965R9V5V
M96X@=F%N(&=E8G)U:6ME<G-L:6IS="!I<R!U:71G97-C:&%K96QD+@!,:71E
M<F%T=75R`$QI=&]U=V5N`$QA9&5N+BXN`$QO:V%L92!T:6ID.@!,86YD:6YS
M=&5L;&EN9R!E;B!T:6ID`$QO8V%T:64`06%N;65L9&5N`$QO9R!V86X@=F]O
M<F=A86YD92!S>6YC('-E<W-I90!!9FUE;&1E;@!!86YM96QD96X`06%N;65L
M9'1A:V5N`$%A;FUE;&1I;F<@;6ES;'5K="!O;61A="!U=R!G96)R=6EK97)S
M;F%A;2!O9B!W86-H='=O;W)D(&]N:G5I<W0@:7,@:6YG979O97)D+@!!86YM
M96QD:6YG(&UI<VQU:W0N`$QA;F=E('1E:W-T`$QI969D90!,86%G`$=R:65K
M<V4@:VQE:6YE(&QE='1E<G,`3&%T:6IN<V4@:VQE:6YE(&QE='1E<G,`2VQE
M:6YE(%)O;65I;G-E(&=E=&%L;&5N`$QU>&5M8G5R9P!-30!-3U1$`$U3+51.
M148@8FEJ;&%G92!B979A='1E(&=E96X@9&%T82X`35-'`$UA8V%O`$UA8V5D
M;VYIZRP@1&4@=G)O96=E<F4@2F]E9V]S;&%V:7-C:&4@4F5P=6)L:65K('9A
M;@!-861A9V%S8V%R`$UA9VEE`$4M;6%I;`!-86EL8F5H965R9&5R`$UA86L@
M;&EN7VLN+BX`36%L87=I`$UA;&5I<VGK`$UA;&%D:79E;@!-86QI`$UA;'1A
M`$)E:&5E<B!U=R!L:6IS="!M970@8V%T96=O<FEEZVX@96X@9&4@8V]R<F5S
M<&]N9&5R96YD92!K;&5U<F5N+"!W86%R;65E(&]N9&5R9&5L96X@=V]R9&5N
M(&=E;&%B96QD`$UA<#(T(&MA87)T`$UA<%%U97-T:V%A<G0`2V]P<&5L:6YG
M96X@;W!G97-L86=E;BX`36%A<G0`36%R9V4`36%R:V5E<B!M970@1V5Z:65N
M+TYI970@1V5Z:65N('9L86=G96X`36%R:V5E<B!M970@86YD97)E('9L86=G
M96X@*&(N=BX@0F5L86YG<FEJ:R]"96%N='=O;W)D*0!-87)C:&%L;"!E:6QA
M;F1E;@!-87)T:6YI<75E`$]V97)E96YK;VUE;F1E('9E;&1E;@!-875R971A
M;FGK`$UA=7)I=&EU<P!-87AI;6%A;"!T;V5G97-T86%N(&MR961I970N`$UA
M>&EM=6T@8F5R:6-H=&]N9&5R9&5L96X@;W9E<G-C:')E9&5N+@!-87AI;75M
M('1E;7!E<F%T=75R('9A;B!D92!A9F=E;&]P96X@,C0@=75R.B``36%X:6UU
M;2!T96UP97)A='5U<B!V86X@9&4@869G96QO<&5N(#8@=75R.B``36%X:6UU
M;2!A86YT86P@<&]R=&%A;&)L;VMK96X`36%X:6UU;2!L96YG=&4`365I`$UA
M>6]T=&4`1V5N965S:W5N9&4`3&5D96X`365N=2!M;V1E.@!#96QL96X@<V%M
M96YV;V5G96X`0F5R:6-H=`!"97)I8VAT(&UE="!S=6-C97,@9V5V97)I9FEE
M97)D+"!M86%R(&AE="!C97)T:69I8V%A="!V86X@9&4@;VYD97)G971E:V5N
M9&4@:V]N(&YI970@=V]R9&5N(&=E=F5R:69I965R9"X`0F5R:6-H="!V97)L
M;W!E;BX`0F5R:6-H='1Y<&4`365T87(@5V5E<@!-151!4B!B;&]K(&ES(&YI
M970@8F5S8VAI:V)A87(N`$U%5$%2(&)L;VL@:7,@;FEE="!B97-C:&EK8F%A
M<BX@1&5T86EL<R!Z:6IN(&=E;&]G9"!V;V]R(&1E('-Y<W1E96UB96AE97)D
M97(N`$UE=&%R1$(@:7,@;FEE="!V97)B;VYD96XN`$UE=&AO9&4`365T:&]D
M92`B)7,B(&ES(&YI970@9V5D969I;FEE97)D`$UE=&AO9&4@:7,@;FEE="!G
M961E9FEN:65E<F0N($%A;F=E<F]E<&5N(&UE=&AO9&4Z("5S`$UE=')I<V-H
M`$UE>&EC;P!-:6-R;VYE<VGK+"!&961E<F%L92!3=&%T96X@=F%N`$UI9&1E
M;@!-:6UE('1Y<&4`36EN:6UU;2!T96UP97)A='5U<B!V86X@9&4@869G96QO
M<&5N(#(T('5U<CH@`$UI;FEM=6T@=&5M<&5R871U=7(@=F%N(&1E(&%F9V5L
M;W!E;B`V('5U<CH@`$UI;FEM=6T@=V%C:'1W;V]R9&QE969T:6ID(&ES(&YO
M9R!N:65T('9E<FQO<&5N`$UI<G)O<@!!;&QE<FAA;F1E`$]N=&)R96ME;F1E
M(%!%05(@;6]D=6QE($A45%!?4F5Q=65S="X`3VYT8G)E:V5N9&4@8V]N9FEG
M=7)A=&EE+B!5(&1I96YT(&1E>F4@;G4@=&4@9V5N97)E<F5N+"!W86YN965R
M('4@9&5Z92!T;V5P87-S:6YG('=I;'0@9V5B<G5I:V5N+@!/;G1B<F5K96YD
M(&)E<FEC:'0@240N`$]N=&)R96ME;F1E+"!V97)E:7-T92P@4$5!4B!M;V1U
M;&4@36%I;"X`3VYT8G)E:V5N9"!S97-S:64@240N`$UA`$UO8FEE;&4@92UM
M86EL`$=E;6ED9&5L9`!7:6IZ:6=I;F=S9&%T=6T`5VEJ>FEG(%523`!-;V1U
M;'5S`$UO;&1A=FGK+"!297!U8FQI96L@=F%N`$UO;F%C;P!-;VYG;VQIZP!-
M86%N9"!E;B!J86%R`$UA86YD96QI:FMS`$UO;G1S97)R870`36%A;F9A<V5N
M`$UE97(@=F5L9&5N(&EN(')E9V5L("5D(&=E=F]N9&5N+"!D86X@9&4@=F5R
M=V%C:'1T92`E9"X`36%R;VMK;P!6;V]R;F%M96QI:FL@;VYB97=O;&MT`%9O
M;W)N86UE;&EJ:R!B97=O;&MT`%9O;W)N86UE;&EJ:R!B97=O;&MT(&5N('=I
M;F1E<FEG`%9O;W)N86UE;&EJ:R!Z;VYN:6<`3F%A<B!B96YE9&5N`$YA87(@
M;&EN:W,`3F%A<B!R96-H=',`3F%A<B!B;W9E;@!.86%R(&)E;F5D96X`3F%A
M<B!B;W9E;@!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:6IS
M=&5N`$UU;'1I;6%P(%9+(&MA87)T`$UE97)V;W5D:6=E('-E;&5C=&EE`$UI
M:FX@86-C;W5N=`!5=R!A8V-O=6YT:6YF;W)M871I90!-:6IN('!O<G1A86P`
M36EJ;B!P;W)T86%L;&%Y;W5T`$)I<FUA`$YE92P@:6L@86-C97!T965R(&1E
M('9O;W)W86%R9&5N($Y)150`3F%A;0!.86UI8FGK`$YA=7)U`$YE<&%L`$YE
M9&5R;&%N9`!.961E<FQA;F1S($%N=&EL;&5N`$YE='-C87!E($)A<VES(%52
M3`!.971S8V%P92!#02!I;G1R96MK:6YG(%523`!.971S8V%P92!#02!B96QE
M:60@55),`$YE='-C87!E('9E<FYI975W:6YG(%523`!.971S8V%P92!I;G1R
M96MK:6YG(%523`!.971S8V%P92!34TP@<V5R=F5R;F%A;0!.971S8V%P92!C
M97)T:69I8V%A=&-O;6UE;G1A87(`3F5T<V-A<&4@8V5R=&EF:6-A871T>7!E
M`$YE='=E<FL`3F]O:70`3FEE=7<@0V%L961O;FGK`$YI975W92!C871E9V]R
M:64`3FEE=7=E(&UA86X`3FEE=7=E(&=E8G)U:6ME<G-N86%M("AO<'1I;VYE
M96PI`$YI975W(%IE96QA;F0`3FEE=7<@=V%C:'1W;V]R9`!.:65U=R!W86-H
M='=O;W)D('IA;"!V97)L;W!E;B!O<"`E>"X`3FEE=7=E(%=A8VAT=V]O<F1E
M;B!K;VUE;B!N:65T(&]V97)E96XN`$YI975W('-C:&5R;2`H7V)L86YK*0!.
M:65U=W,`3FEE=7=S9W)O97!E;@!6;VQG96YD90!6;VQG96YD92`T(&9A<V5N
M`%9O;&=E;F1E(&]P=&EE<P!6;VQG96YD93X`3FEC87)A9W5A`$YI9V5R`$YI
M9V5R:6$`3F%C:'0`3FEU90!.964`1V5E;B!B97-C:&EK8F%R92!C;VYF:6=U
M<F%T:65D871A(&]M('9E<G-C:&EL;&5N('1E(&QA=&5N('II96XN`$=E96X@
M8F5S8VAI:V)A<F4@<W1R871E9VEE('9O;W(@:&5T(&UA:V5N('9A;B!)4T\@
M:6UA9V5S+@!'965N(&)A=&-H<VIA8FQO;VXN`$5R(&)E<W1A870@9V5E;B!B
M;&]K(&]P(&1E(&=E=G)A86=D92!P;W-I=&EE`$=E96X@86=E;F1A;F%A;2!O
M<&=E9V5V96X@=F]O<B!-0T%,(&%U=&AE;G1I8V%T:64N`$=E96X@=VEJ>FEG
M:6YG96XN`$%A;B!D:70@<F5C:'0@:W5N;F5N(&=E96X@8VAI;&0@<F5C:'1E
M;B!W;W)D96X@=&]E9V5V;V5G9"X`1V5E;B!C;VYF:6=U<F%T:65I;F9O<FUA
M=&EE(&]P9V5G979E;B!V;V]R("5S+@!'965N(&-O;F9I9W5R871I96EN9F]R
M;6%T:64@;W!G96=E=F5N('9O;W(@1E10(%9&4RX`1V5E;B!C;VYF:6=U<F%T
M:65I;F9O<FUA=&EE(&]P9V5G979E;B!V;V]R(%-13"!61E,N`$=E96X@8V]N
M9FEG=7)A=&EE:6YF;W)M871I92!O<&=E9V5V96X@=F]O<B!344PM8F5S=&%N
M9"!61E,N`$=E96X@:W)E9&EE="!M965R+@!'965N(&)E<W1E;6UI;F<@;W!G
M96=E=F5N+@!'965N(&)E<W1A;F0@=7!L;V%D960`1V5E;B!P:6-T;V=R86UM
M96X@9V5V;VYD96XN`$5R(&ES(&=E96X@;&]C871I92!I;F=E<W1E;&0N`$=E
M96X@;&]C871I92!O<&=E9V5V96XN`$=E96X@8F5R:6-H="!G96QE=F5R9"X`
M1V5E;B!N86%M(&]P9V5G979E;BX`1V5E;B!G971A;"!O<&=E9V5V96XN`$=E
M96X@8F5L961I9V5N9&4@9F]R='5N97,`1V5E;B!W86-H='=O;W)D(&]P9V5G
M979E;B!V;V]R($A45%`@875T:&5N=&EC871I92X`1V5E;B!W86-H='=O;W)D
M(&]P9V5G979E;B!V;V]R($E-05`@875T:&5N=&EC871I92X`1V5E;B!W86-H
M='=O;W)D(&]P9V5G979E;B!V86X@2V5R8F5R;W,@875T:&5N=&EC871I92X`
M1V5E;B!W86-H='=O;W)D(&]P9V5G979E;B!V;V]R($QO9VEN(&%U=&AE;G1I
M8V%T:64N`$=E96X@=V%C:'1W;V]R9"!O<&=E9V5V96X@=F]O<B!005-35T0@
M875T:&5N=&EC871I92X`1V5E;B!W86-H='=O;W)D(&]P9V5G979E;B!V;V]R
M(%--0B!A=71H96YT:6-A=&EE+@!'965N('!A9"!N86%R(&1E($]P96Y34TP@
M8FEN87)Y(&]P9V5G979E;BX@1&4@3W!E;E-33"!B:6YA<GD@:7,@;F]D:6<@
M;VT@=&4@:W5N;F5N('=E<FME;B!M970@4$M#4R`Q,B!D871A+@!'965N(&AA
M;F=E;F1E(&EN<V-H<FEJ=FEN9V5N+@!'965N('%U;W1A(&EN9V5S=&5L9"X`
M1V5E;B!L:6YIZW)I;F<`1V5E;B!S8VAE:61I;F=S=&5K96X@;W!G96=E=F5N
M+@!'965N('II:F1E;@!'965N(&1E<F=E;&EJ:R!B97-T86YD`$=E96X@=&EJ
M9&5L:6IK(&1I<F5C=&]R>2!B97-C:&EK8F%A<B!V;V]R(&-A8VAE+@!'965N
M(&=E8G)U:6ME<G-N86%M(&5N+V]F('=A8VAT=V]O<F0@=F5R>F]N9&5N+@!'
M965N(&=E;&1I9V4@6$U,(&1A=&$@=&5R=6=G97-T=75R9`!'965N('=A87)D
M96X`1V5E;B!V97)S:64@9V5V;VYD96X@:6X@;W)I9VEN96QE(&-O;F9I9W5R
M871I92X@2&5R9V5N97)E97(@8V]N9FEG=7)A=&EE+@!'965N('9E<G-I92!G
M979O;F1E;B!I;B!U=R!C;VYF:6=U<F%T:64N($AE<F=E;F5R965R(&-O;F9I
M9W5R871I92X`1V5E;@!'965N("AV97)P;&EC:'0I`$YO;W)D($5U<F]P965S
M("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!E:6QA;F0`3F]O<F1E;&EJ:R!H86QF
M<F]N9`!-87)I86YE;@!.;V]R=V5G96X`3FEE="!N80!.:65T('9O;W(`1V5E
M;B!D:7)E8W1O<GD`3FEE="!G96EM<&QE;65N=&5E<F0N`$YI970@:6YG97-T
M96QD`$YI970@;VYD97)S=&5U;F0N`$YO=&ET:65S`$YI971S('1E(&)L861E
M<F5N+"!G82!T97)U9RX`3F]V96UB97(`1V5T86P`06%N=&%L(&MA<F%K=&5R
M<P!!86YT86P@:V]L;VUM96X`06%N=&%L(')I:F5N`$=E=&%L;&5N(&YI970@
M;W!G96=E=F5N('9O;W(@8FEJ=V5R:V5N(&EN(&5E;B!D:7-T<FEB=71I96QI
M:G-T+@!/2P!/8FIE8W0`3V)J96-T96EG96YA87(`3V-T86%L`$]K=&]B97(`
M0F5L961I9VEN9V9I;'1E<@!+86YT;V]R`$]U9&4@96X@;FEE=7=E('=A8VAT
M=V]O<F1E;B!D:65N96X@=F5R<V-H:6QL96YD('1E('II:FXN`$]U9&4@=V%C
M:'1W;V]R9`!/=61E('=A8VAT=V]O<F0@:7,@;FEE="!J=6ES=`!/;6%N`$%L
M;&5E;B!)34%0('-E<G9E<G,@;VYD97)S=&5U;F5N(&=E9&5E;&1E(&UA<'!E
M;BX`06QL965N(&)E;&5D:6=E;F1E(&9O<G1U;F5S`%-L96-H="#IZ6X@92UM
M86EL861R97,@=&]E9V5S=&%A;BX`06QL965N(&1E(&5I9V5N86%R(&]F(&5E
M;B!S>7-T965M8F5H965R9&5R(&UA9R!D92!E:6=E;F%A<G)E8VAT96X@=F%N
M(&5E;B!S:&%R92!W:6IZ:6=E;@!/<&5N(&EN(&5E;B!N:65U=R!S8VAE<FT`
M3W!E;E-33"!F;W5T.B!K;VX@9V5E;B!D871A('5I="!H970@;VYD97)T96ME
M;F1E(%,O34E-12!O;F1E<F1E96P@:&%L96XN`$]P96YT(&1E>F4@;&EN:R!I
M;B!E96X@;FEE=7<@<V-H97)M`$)E<W1U<FEN9W-S>71E96T`3W!T:65S`$]P
M=&EE<R!V;V]R("5S`$=E;W)D96YD92!L:6IS=`!/<F=A;FES=&%T:64`3W)G
M86YI<V%T:64@965N:&5I9`!/<F=A;FES97)E;@!/<FEG:6YE96P@=&]E<&%S
M<VEN9W-S:F%B;&]O;@!/<FEG:6YE;&4@<VIA8FQO;F5N(&EN("5S.@!!;F1E
M<F4`06YD97)E(&EN9F]R;6%T:64`16EG96YA87)R96-H=&5N`%!!32!A=71H
M96YT:6-A=&EE(&ES(&YI970@8F5S8VAI:V)A87(N`%!%05(Z.DUA:6P@8F%C
M:V5N9`!$:6=I=&%L92!01U`@:&%N9'1E:V5N:6YG`$=E8V]D965R9&4@4$=0
M(&1A=&$`3W!E;F)A<F4@4$=0('-L975T96P`3VYD97)T96ME;F1E+V=E8V]D
M965R9&4@4$=0(&1A=&$`4$A0(&-O9&4`4$A0('-H96QL`$QI8VAT92!R96=E
M;B!N82`Q,BXP,"!U=7(`4F5G96X@;F$@,3(N,#`@=75R`$)U:65N(&YA(#$R
M+C`P('5U<@!3;F5E=7<@;F$@,3(N,#`@=75R`%-N965U=V)U:65N(&YA(#$R
M+C`P('5U<@!:;VX@;F$@,3(N,#`@=75R`$]N=V5E<G-B=6EE;B!N82`Q,BXP
M,"!U=7(`4$]325@@97AT96YS:64@;VYT8G)E96MT`%!(4"!?4VAE;&P`5G)I
M:F4@<G5I;71E`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EJ;G,@5&5R<FET;W)I
M=6TL($)E>F5T`%!A;F%M80!087!U82!.:65U=R!'=6EN96$`4&%R86=U87D`
M1V5D965L=&5L:6IK(&)E=V]L:W0`5V%C:'1W;V]R9`!786-H='=O;W)D(&UE
M="!S=6-C97,@9V5W:6IZ:6=D+@!786-H='=O;W)D(&]N:G5I<W0`5V%C:'1W
M;V]R9"!I<R!V97)E:7-T('9O;W(@4D%$2553(&%U=&AE;G1I8V%T:64N`%=A
M8VAT=V]O<F0@;65T(&)E=F5S=&EG:6YG`%=A8VAT=V]O<F0Z`%=A8VAT=V]O
M<F0Z(`!786-H='=O;W)D96X@;6]E=&5N(&]V97)E96YK;VUE;BX`4&QA:VME
M;@!0;&%K:V5N('9A;F%F('!R:6MB;W)D`%!A9`!(86YG96YD92!I;G-C:')I
M:G9I;F=E;CH`365N<V5N`%!R;V-E;G0`3VYD97)H;W5D<W=E<FMZ86%M:&5D
M96X@=6ET=F]E<F5N`$]N9&5R:&]U9'-W97)K>F%A;6AE9&5N('5I='9O97)E
M;B!B:6H@86%N;65L9&EN9S\`4F5C:'0`4F5C:'0@(B5S(B!N:65T('9E<G=I
M:F1E<F0N`%)E8VAT(&=E=V5I9V5R9`!296-H=&5N`%)E8VAT96YB96AE97(`
M4&5R<V]O;FQI:FME(&EN9F]R;6%T:64`4&5R=0!(=6ES9&EE<F5N`%!H:6QI
M<'!I:FYE;@!496QE9F]O;@!&;W1O)W,`4&ET8V%I<FX`4&EX96QS`%!L871I
M='5D97,`2VQI:R!I;B!E96X@8V5L+"!A+G4N8BX`0F5V97-T:6<L(&1A="!U
M(&1I="!E;&5M96YT('=I;'0@=F5R=VEJ9&5R96XL(&$N=2YB.@!"979E<W1I
M9RP@9&%T('4@9&ET(&5L96UE;G0@=VEL="!L;W-K;W!P96QE;BP@82YU+F(N
M`$=E968@965N(&UA86YD(&5N(&5E;B!J86%R+"!A+G4N8BX`165N(&YA86T@
M=F]O<B!D92!N:65U=V4@8V%T96=O<FEE(&EN=F]E<F5N+"!A+G4N8BXZ`$=E
M968@965N(&=E;&1I9R!)4"!A9')E<RP@82YU+F(N`$=E968@965N(&=E;&1I
M9V4@9&%T=6T@82YU+F(N+"!C;VYT<F]L965R(&AE="!A86YT86P@9&%G96X@
M:6X@9&4@;6%A;F0N`$=E968@965N(&=E;&1I9V4@=&EJ9"P@82YU+F(N`$=E
M968@965N('-A;65N=F%T=&EN9R!V86X@:&5T('!R;V)L965M+"!A+G4N8BX`
M1V5E9B!U=R!G96)R=6EK97)S;F%A;2!E;B!W86-H='=O;W)D+"!A+G4N8BX`
M3&5E<R!D92!V;VQG96YD92!T96MS="P@82YU+F(N(%4@34]%5"!D92!V;V]R
M=V%A<F1E;B!T92!A8V-E<'1E<F5N(&]M(&AE="!S>7-T965M('1E(&MU;FYE
M;B!G96)R=6EK96XN`$=E968@9&4@;FEE=7=E(&-A=&5G;W)I96YA86TL(&$N
M=2YB+CH`4&]L96X`4&]L:71I96L`4&5I;&EN9V5N`%!O<G1U9V%L`%!O<VET
M:6]N97)I;F<@=F%N(&1E>F4@869B965L9&EN9P!0;W-I=&EO;F5R:6YG('9A
M;B!D97IE('1A8F5L`%-T=75R(&YA87(@9&5Z92!M87`@*&YI970@869G961W
M;VYG96X@9&]O<B!)34%0*0!.965R<VQA9R!V86X@9&4@869G96QO<&5N("5S
M('5R96XZ(`!.965R<VQA9SQB<B`O/FMA;G,`4')E9G-?;&1A<#H@=F5R96ES
M=&4@3$1!4"!E>'1E;G1I92!N:65T(&=E=F]N9&5N+@!0<F5F<U]S97-S:6]N
M.B!V97)E:7-T92!S97-S:64@97AT96YT:64@;FEE="!G979O;F1E;BX`3'5C
M:'1D<G5K`$QU8VAT9')U:R!O<"!Z965N:79E874Z(`!,=6-H=&1R=6LZ(`!"
M96]O<F1E;&5N`$)E;V]R9&5E;"!D92!A9F)E96QD:6YG(&EN(&5E;B!N:65U
M=R!S8VAE<FT`5F]R:6=E(&]P=&EE<P!$;V-U;65N="!A9F1R=6MK96X`4')I
M=F4@<VQE=71E;`!0<F]B;&5E;0!0<F]B;&5E;6)E<V-H<FEJ=FEN9P!0<F]J
M96-T96X`4')O;7!T('1E:W-T`$]P96YB87)E('-L975T96P`3W!E;F)A<F4@
M<VQE=71E;"!A;&=O<FET:&UE`$]P96YB87)E('-L975T96QI;F9O<FUA=&EE
M`$]P96YB86%R+U!R:79E('-L975T96QP86%R(&YI970@9V5G96YE<F5E<F0N
M`%!U97)T;R!2:6-O`%=I<R!B97)I8VAT96X`475A=&%R`%%U97)Y`%%U;W1A
M`%)302!O<&5N8F%R92!S;&5U=&5L("@E9"!B:70I`$ME=7IE<F]N9&IE('-E
M;&5C=&EE`%)E9V5N`%9R;V5G(')E9V5N`$QA870@<F5G96X`4F5G96YB=6D`
M4F5G96X@96X@<VYE975W`%)E9V5N(&YA87(@<VYE975W`%)A;F1O;2!&;W)T
M=6YE`%9E<FAO=61I;F<`3&5Z96X`3&5E<R!B97)I8VAT96X`)7,@96-H="!V
M97)W:6ID97)E;C\@1&5Z92!B97=E<FMI;F<@:V%N(&YI970@;VYG961A86X@
M9V5M86%K="!W;W)D96XN`$=E8G)U:6ME<G-D871A('9A;B!G96)R=6EK97(@
M)7,@96-H="!V97)W:6ID97)E;C\@1&5Z92!B97=E<FMI;F<@:V%N(&YI970@
M;VYG961A86X@9V5M86%K="!W;W)D96XN`$AE<FAA86QT('5W('9O<FEG92!B
M97=E<FMI;F<`5F5R=F5R<V5N`%9E<G9E<G,@9'EN86UI<V-H92!M96YU(&]N
M9&5R9&5L96XZ`%!O<G1A;'=E97)G879E('9E<G9E<G-E;CH`4F5G97@`0F5T
M<F5K:VEN9V5N(&)R;W=S97(`2&5R;&%D96X`3W!M97)K:6YG96X`4V5R=F5R
M<R!O<"!A9G-T86YD`%523"!O<"!A9G-T86YD("AH='1P.B\O=W=W+F5X86UP
M;&4N8V]M+VAO<F1E*3H`5F5R=VEJ9&5R96X`0FQO:R!V97)W:6ID97)E;@!+
M;VQO;2!V97)W:6ID97)E;@!/<&UA86L@=F5R=VEJ9&5R96X`4&%A<B!V97)W
M:6ID97)E;@!697)W:6ID97(@:&5T(&]P9V5S;&%G96X@<V-R:7!T('5I="!D
M92!T:6ID96QI:FME(&1I<F5C=&]R>2!O<"!D92!S97)V97(N`%9E<G=I:F1E
M<B!D90!697)W:6ID97(@9&5Z92!N;V1E('5I="!H970@9&]C=6UE;G0`1V5B
M<G5I:V5R('9E<G=I:F1E<F5N`%9E<G=I:F1E<B!G96)R=6EK97(Z("5S`%9E
M<GIO96L@:V]N(&YI970@=V]R9&5N(&)E86YT=V]O<F0N($=E<F5T;W5R;F5E
M<F1E(&9O=71C;V1E.B``1&4@9V5V<F%A9V1E('-E<G9I8V4@:V]N(&YI970@
M=V]R9&5N(&=E=F]N9&5N+@!697)E:7-T92`B)7,B(&YI970@;W!G96=E=F5N
M(&EN("5S(&-O;F9I9W5R871I92X`5F5R96ES=&4@(B5S(B!N:65T(&]P9V5G
M979E;B!I;B!61E,@8V]N9FEG=7)A=&EE+@!697)E:7-T92`B)7,B(&YI970@
M;W!G96=E=F5N(&EN(&-O;F9I9W5R871I92X`5F5R96ES="!V96QD`$AE<G-T
M96QL96X`4F5S970@=V%C:'1W;V]R9`!297-E="!U=R!W86-H='=O;W)D`%9O
M;W)G86%N9&4@<75E<GD@:&5R<W1E;&QE;@!297-U;'1A=&5N`%1E<G5G(&YA
M87(@;W!T:65S`%1Y<"!N:65U=R!W86-H='=O;W)D(&]P;FEE=7<`4F5U;FEO
M;@!#;VYF:6=U<F%T:64@=&5R=6=Z971T96X`4FEC:"!497AT($5D:71O<B!O
M<'1I97,`4F%A9'-E;',`4F5C:'1S`%)E8VAT<V4@:V]P`%)E8VAT<V4@=V%A
M<F1E;@!2:5]J96EG96YS8VAA<'!E;BXN+@!2;VP`4F]E;65N:>L`,3@P(&1R
M86%I96X`3F%A<B!L:6YK<R!D<F%A:65N`$YA87(@<F5C:'1S(&1R86%I96X`
M4FEJ(&5I9V5N<V-H87!P96X`4FEJ(&5I9V5N<V-H87!P96X`4FEJ96XZ`$QI
M;FGK<FEN9P!,:6YIZW)I;F<@>F%L('9E<G-C:&EJ;F5N('1U<W-E;B!A;&QE
M(')I:F5N(&5N(&MO;&]M;65N`$QI;FGK<FEN9R!Z86P@86QL965N('1U<W-E
M;B!K;VQO;6UE;B!V97)S8VAI:FYE;@!,:6YIZW)I;F<@>F%L(&%L;&5E;B!T
M=7-S96X@<FEJ96X@=F5R<V-H:6IN96X`4W1A<G1E;@!2=7-S:7-C:&4@1F5D
M97)A=&EE`%)W86YD80!#<GEP=&]G<F%F:7-C:&4@4R]-24U%(&AA;F1T96ME
M;FEN9P!3+TU)344@9V5C;V1E97)D(&)E<FEC:'0`4T%33"!A=71H96YT:6-A
M=&EE(&ES(&YI970@8F5S8VAI:V)A87(N`%--4R!V97)S='5R96X`4U%,('-H
M96QL`%-13"!S=&%T96UE;G0@=F]O<B!W86%R9&5Z;V5K;W!D<F%C:'1E;@!3
M4T@`4U5#0T53`%-?44P@<VAE;&P`6F$`4W0@2&5L96YA`%-T($MI='1S(&5N
M($YE=FES`%-T($QU8VEA`%-T(%!I97)R92!E;B!-:7%U96QO;@!3="!6:6YC
M96YT(&5N(&1E($=R96YA9&EN97,`6F5L9F1E(&9R86UE("A?<V5L9BD`4V%M
M;V$`4V%N($UA<FEN;P!386\@5&]M92!E;B!0<FEN8VEP90!3871E;&QI971P
M<F]V:61E<@!3875D:2!!<F%B:>L`3W!S;&%A;@`B)7,B(&]P<VQA86X`)7,@
M;W!S;&%A;@!/<'1I97,@;W!S;&%A;@!'96=E;F5R965R9&4@8V]N9FEG=7)A
M=&EE(&%L<R!02%`@<V-R:7!T(&]P9V5S;&%G96X@:6X@9&4@=&EJ9&5L:6IK
M92!D:7)E8W1O<GD@=F%N('5W('-E<G9E<BX`)7,@8V]N9FEG=7)A=&EE(&]P
M9V5S;&%G96X`4V5T=7`@=7!G<F%D92!S8W)I<'0@;W!G97-L86=E;B!N86%R
M.B`B)7,B+@!'97-P<F5I9&4@;VYW965R<V)U:65N`%=E=&5N<V-H87``6F]E
M:V5N`%IO96MM86-H:6YE<P!+:65S(&)E<W1A;F1E;@!396QE8W1E97(@965N
M(&1A='5M`%-E;&5C=&5E<B!E96X@9W)O97`@;VT@=&]E('1E('9O96=E;@!3
M96QE8W1E97(@965N(&YI975W92!E:6=E;F%A<@!396QE8W1E97(@965N('-E
M<G9E<@!396QE8W1E97(@965N(&=E8G)U:6ME<B!O;2!T;V4@=&4@=F]E9V5N
M`$%L;&5S('-E;&5C=&5R96X`4V5L96-T965R(&%L;&4@9&%T=6UC;VUP;VYE
M;G1E;BX`4V5L96-T965R(&5E;B!O8FIE8W0`3FEE=',@<V5L96-T97)E;@!3
M96QE8W1E97(@9&4@8F5N;V1I9V1E(&MA<F%K=&5R<R!U:70@9&4@;VYD97)S
M=&%A;F1E('9A:VIE<RX@52!K=6YT(&1E>F4@9&%N(&MO<&GK<F5N(&5N('!L
M86MK96X@:6X@:&5T('1E:W-T9V5B:65D+@!396QE8W1E97(@:&5T(&1A='5M
M<V-H96ED:6YG<W1E:V5N.@!396QE8W1E97(@:&5T(&1A='5M9F]R;6%A=#H`
M4V5L96-T965R(&1E(&ED96YT:71E:70@9&EE('4@=VEL="!W:6IZ:6=E;CH`
M4V5L96-T965R(&AE="!T:6ID<V-H96ED:6YG<W1E:V5N.@!396QE8W1E97(@
M:&5T('1I:F1S9F]R;6%A=#H`4V5L96-T965R('1W964@;W9E<F5E;FMO;65N
M9&4@=F5L9&5N+@!396QE8W1E97(@=7<@:VQE=7)S8VAE;6$N`%-E;&5C=&5E
M<B!U=R!G97=E;G-T92!T86%L.@!0<F]B;&5E;7)A<'!O<G0@=F5R>F5N9&5N
M`%9E<GIE;F0@4TU3`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E<G9I
MZR!E;B!-;VYT96YE9W)O`%-E<FEE;G5M;65R`%-E<G9E<F1A=&$@9F]U="!O
M9B!N:65T(&)E<V-H:6MB86%R+@!397-S:65B96AE97)D97(`4V5S<VEE($E$
M('9E<FQO<&5N+@!397-S:65S`$EN<W1E;&QE;@!);G-T96QL96X@=F%N(&]P
M=&EE<R!O;2!U('1O92!T92!S=&%A;B!U=R!W86-H='=O;W)D('1E(')E<V5T
M=&5N+"!W86YN965R('4@9&ET(&)E;G0@=F5R9V5T96XN`$EN<W1E;&QE;B!V
M86X@<V5R=F5R<R!O<"!A9G-T86YD(&1I92!U('=I;'0@8F5N861E<F5N('9A
M;G5I="!U=R!P;W)T86PN`$EN<W1E;&QE;B!V86X@=7<@9V5W96YS=&4@=&%A
M;"P@=&EJ9'IO;F4@96X@9&%T=6UO<'1I97,N`$EN<W1E;&QE;B!V86X@=7<@
M;W!S=&%R='1O97!A<W-I;F<L(&ML975R<V-H96UA+"!P86=I;F%V97)V97)S
M:6YG(&5N(&%N9&5R92!W965R9V%V96]P=&EE<RX`26YS=&5L;&5N`%-E='5P
M('5P9W)A9&4@<V-R:7!T<R!B97-C:&EK8F%A<@!697)S8VAI;&QE;F1E(&QO
M8V%T:65S(&UO9V5L:6IK(&UE="!D92!P87)A;6%T97(Z(`!397EC:&5L;&5N
M`%=I;FME;&5N`$MO<G1E('-A;65N=F%T=&EN9P!$:65N96X@<VYE;'1O971S
M96X@=F]O<B!D92!M965S=&4@;&EN:W,@9V5D969I;FEE97)D('1E('=O<F1E
M;C\`5V5E<F=E=F5N`%9E<G-C:&EL;&5N(&QA=&5N('II96X@='5S<V5N(&1E
M(&AU:61I9V4@;W!G97-L86=E;B!C;VYF:6=U<F%T:64@96X@9&4@;FEE=7=E
M(&=E9V5N97)E97)D92!C;VYF:6=U<F%T:64N`$QA871S=&4@86%N;65L9&EN
M9W-T:6ID('=E97)G979E;B!B:6H@86%N;65L9&5N/P!/<'1I92!W965R9V5V
M96X@;VT@;W)I9VEN965L('1E(&)E=V%R96X`2VEE>F5R('=E97)G979E;@!4
M86)E;&)E=V5R:VEN9W-T86%K8F%L:R!W965R9V5V96X_`"5S(&UE;G4@86%N
M(&1E(&QI;FME<FMA;G0@=V5E<F=E=F5N/P!486)E;&-E;&5I9V5N<V-H87!P
M96X@9&EA;&]O9W9E;G-T97(@=V5E<F=E=F5N`%1A8F5L96EG96YS8VAA<'!E
M;B!D:6%L;V]G=F5N<W1E<B!W965R9V5V96X`5&%B96QR:6IE:6=E;G-C:&%P
M<&5N(&1I86QO;V=V96YS=&5R('=E97)G979E;@!!9F)E96QD:6YG<V5I9V5N
M<V-H87!P96X@9&EA;&]O9W9E;G-T97(@=V5E<F=E=F5N`%5P;&]A9"!W965R
M9V5V96X`0G5I96X`0G5I96X@=G)O96<`0G5I96X@;&%A=`!"=6EE;B!I;B!D
M92!N86)I:FAE:60`5F5R:VQE:6YE;@!697)K;&5I;B!O9B!V97)P;&%A=',@
M;F%B=7)I9V4@8FQO:VME;B!E97)S=`!3:65R<F$@3&5O;F4`26YT96ME;F5N
M`$AA;F1T96ME;FEN9P!(86YD=&5K96YI;F<@86QG;W)I=&AM90!3:6YG87!O
M<F4`1W)O;W1T90!/;F1E<FAO=60@;W9E<G-L86%N`%-L;W=A:VEJ90!3;&]V
M96YIZP!3;F5E=7<`4VYE975W=FQA86<`4VYE975W8G5I96X`<VYE975W8G5I
M96X@=G)O96<`4VYE975W8G5I96X@;&%A=`!3;F5E=7=D:65P=&4Z(`!3;F5E
M=7=E<75I=F%L96YT(&EN('=A=&5R.B``4V]L;VUO;B!E:6QA;F1E;@!3;VUA
M;&GK`$QI961E<F5N(&5N(&=E9&EC:'1E;@!3;W)T965R=F]L9V]R9&4@<V5L
M96-T:64`0G)O;F%D<F5S`%IU:60@069R:6MA`%IU:60@175R;W!E97,@*$E3
M3RTX.#4Y+3,I`%IU:60@1V5O<F=IZR!E;B!D92!:=6ED(%-A;F1W:6-H(&5I
M;&%N9&5N`%IU:61E;&EJ:R!H86QF<F]N9`!3<&%T:>MR:6YG('1U<W-E;B!A
M86YG<F5N>F5N9&4@8V5L;&5N`%-P871IZW)I;F<@='5S<V5N(&EN:&]U9"!E
M;B!R86YD(&EN(&-E;`!38VAE:61I;F=S=&5K96X`4W!A=&GK<FEN9P!3<&%T
M:>MR:6YG(&5N('9R:6IE(')U:6UT90!3<&%N:F4`4W!A;0!3<&5C:6%A;"!K
M87)A:W1E<B!I;G9O97(`0V5L(&]P<W!L:71S96X`2V]L;VT@;W!S<&QI='-E
M;@!2:6H@;W!S<&QI='-E;@!3<&]R=`!3<FD@3&%N:V$`4W1A;F1A87)D`%-T
M87(@5')E:P!3=&%R=&IA87(`4W1A870@;V8@<')O=FEN8VEE`%-T871U<P!/
M<'-L86=F;W)M86%T`$%D<F5S`$1O;W)H86QE;@!3=')I;F=L:6IS=`!3=')I
M<"!D;VUE:6X@=F%N(&AE="!A9')E<P!3=&EJ;"!;0U-370!:;P!3=6)D:7)E
M8W1O<GD@(B5S(B!N:65T(&=E=F]N9&5N+@!/;F1E<G=E<G``0F5V97-T:6=E
M;@!697)Z;V5K('9E<G-T=75R9"!O;2`B)7,B(&%A;B!H970@<WES=&5E;2!T
M;V4@=&4@=F]E9V5N+B!5(&MU;G0@;FEE="!A86YM96QD96X@=&]T('5W('9E
M<GIO96L@:7,@9V]E9&=E:V5U<F0N`%-U8G-C<FEP=`!3=6-C97,`(B5S(B!M
M970@<W5C8V5S(&%A;B!H970@<WES=&5E;2!T;V5G979O96=D+@!$871A('9A
M;B!G96)R=6EK97(@(B5S(B!M970@<W5C8V5S('5I="!H970@<WES=&5E;2!V
M97)W:6ID97)D+@`B)7,B(&UE="!S=6-C97,@=F5R=VEJ9&5R9"X`(B5S(B!M
M970@<W5C8V5S('5I="!H970@<WES=&5E;2!V97)W:6ID97)D+@!#;VYF:6=U
M<F%T:64@;65T('-U8V-E<R!T97)U9V=E>F5T+B!697)N:65U=R!O;2!W:6IZ
M:6=I;F=E;B!T92!Z:65N+@!"86-K=7!C;VYF:6=U<F%T:64@;65T('-U8V-E
M<W,@;W!G97-L86=E;BX`0F%C:W5P8V]N9FEG=7)A=&EE8F5S=&%N9"`E<R!M
M970@<W5C8V5S<R!O<&=E<VQA9V5N+@`B)7,B(&UE="!S=6-C97,@8FEJ9V5W
M97)K=``E<R!M970@<W5C8V5S(&=E<V-H<F5V96X`4V]E9&%N`%-A;65N=F%T
M=&EN9P!:;VYS;W!G86YG`%IO;G-O;F1E<F=A;F<`6F]N;FEG`%IO;G-O<&=A
M;F<`6F]N<V]P9V%N9R]:;VYS;VYD97)G86YG`%IO;G-O<&=A;F<Z(`!:;VYS
M;VYD97)G86YG`%IO;G-O;F1E<F=A;F<Z(`!3=7!E<G-C<FEP=`!/;F1E<G-T
M975N:6YG`%-U<FEN86UE`$%C:'1E<FYA86T`4W!I='-B97)G96X@96X@2F%N
M($UA>65N`%-W87II;&%N9`!:=V5D96X`6G=I='-E<FQA;F0`4WEN8R!L;V<@
M=F5R=VEJ9&5R9`!3>6YC34P`4WEN=&%X9F]U="!I;B!Z;V5K=&5R;65N`%-Y
M<FES8VAE($%R86)I<V-H92!297!U8FQI96L`3VYW965R<V)U:0!/;G=E97)S
M8G5I96X@96X@=VEN9&5R:6<`3VYW965R<V)U:65N`$]N=V5E<G-B=6EE;B!V
M<F]E9P!44U8@8F5S=&%N9`!486)E;&5I9V5N<V-H87!P96X`5&%B96QS970`
M5&%B96QE:6=E;G-C:&%P<&5N`%1A:7=A;@!486EW86XL(%!R;W9I;F-I92!V
M86X@0VAI;F$`5&%D>FII:VES=&%N`%1A;GIA;FEA+"!697)E;FEG9&4@4F5P
M=6)L:65K('9A;@!$;V5L.@!486ME;@!496QE9F]O;FYU;6UE<@!496UP97)A
M='5U<B!V86X@:&5T(&%F9V5L;W!E;B!U=7(Z(`!496UP97)A='5U<@!496UP
M97)A='5U<CH@`%1E;7!E<F%T=75R/&)R("\^*"5S2&]O9R5S+R5S3&%A9R5S
M*2`F9W)D.R5S`%-J86)L;V]N("(E<R(@;FEE="!G979O;F1E;BX`4VIA8FQO
M;VYB96AE97(`5&5K<W0`06QL965N('1E:W-T`%1E:W-T('5I=&QI:FYE;@!4
M96MS=&)O=F5N:V%N=`!$;P!4:&%I<R`H5$E3+38R,"D`5&AA:6QA;F0`1&4@
M1E10(&5X=&5N=&EE(&ES(&YI970@8F5S8VAI:V)A87(N`$AE="!G97-C:&EE
M9&5N:7-S>7-T965M(&ES('5I=&=E<V-H86ME;&0N`$1E($AO<F1E+TMO;&%B
M(&EN=&5G<F%T:64@;VYD97)S=&5U;G0@(B5S(B!N:65T`$AE="!)35-0(&QO
M9R!K;VX@;FEE="!W;W)D96X@9V5I;FET:6%L:7-E97)D+@!$92!-86EN=&5N
M86YC93HZ(&-L87-S('=E<F0@;FEE="!G96QA9&5N`$AE="!/<'1I97-S8VAE
M<FT@:7,@9V5S;&]T96XN($%F<VQU:71E;BX`1&4@8F5H965R9&5R(&1I96YT
M(&5E;B!P97)M86YE;G0@<F5C:'1E;F)A8VME;F0@=&4@8V]N9FEG=7)E<F5N
M(&%L<R!U(')E8VAT96X@=VEL="!G96)R=6EK96XN`$%L;&5E;B!D92!O;F1E
M<FMA;G0`2&5T(&-O;G1A8W0@240@;G5M;65R(&ES(&YI970@;W!G96=E=F5N
M+"!L965G(&=E;&%T96X@;V8@:7,@;FEE="!G979O;F1E;B!I;B!D92!D871A
M8F%S92X`2&5T(&%D<F5S(&ES(&UE="!S=6-C97,@86%N('5W(&%D<F5S8F]E
M:R!T;V5G979O96=D+@!(970@;&]S9V5K;W!P96QD92!01U`@;VYD97)T96ME
M;FEN9W-B;&]K(&ES('9E<F5I<W0@;VT@:&5T(&]N9&5R=&5K96YD92!B97)I
M8VAT('1E('9E<FEF:>MR96XN`$AE="!D:7-T<G5B=71I96QI:G-T($E$(&ES
M(&YI970@;W!G96=E=F5N+"!L965G(&=E;&%T96X@;V8@:7,@;FEE="!G979O
M;F1E;B!I;B!D92!D871A8F%S92X`1&4@9&ES=')I8G5T:65L:6IS="!I<R!N
M:65T(&]P9V5G979E;BX`1&4@8V]D965R;6]G96QI:FMH961E;B!V97)E:7-E
M;B!E96X@8F5V96EL:6=D92!W96)V97)B:6YD:6YG+@!(970@8F5S=&%N9"`E
M<R!D:65N="!E96X@)7,@:6YS=&5L;&EN9R!T92!B979A='1E;BX`2&5T(&)E
M<W1A;F0@)7,@9&EE;G0@96YI9V4@)7,@:6YS=&5L;&EN9V5N('1E(&)E=F%T
M=&5N+@!(970@8F5S=&%N9"!K86X@;FEE="!N86%R('II8VAZ96QF(&=E:V]P
M:65E<F0@=V]R9&5N+@!(970@8F5S=&%N9"!B979A='1E(&=E96X@9&%T82X`
M2&5T('9O;&=E;F1E('II:FX@9&4@:V]P<&5N('9A;B!D:70@;65S<V%G92]R
M9F,X,C(@8F5R:6-H="X`5F%N(&1E('9O;&QE9&EG('-C:&5R;2!M;V1E(&ES
M(&)E:V5N9"P@9&%T(&1I="!P<F]B;&5M96X@:V%N('9E<F]O<GIA:V5N(&UE
M="!);G1E<FYE="!%>'!L;W)E<BP@=F%N=V5G92!B<F]W<V5R8G5G<R!W86%R
M('=I:B!N:65T(&]M:&5E;B!K=6YN96XN($AE="!I<R!M;V=E;&EJ:R!D870@
M=2!R;VUM96P@:6X@:&5T(&)E96QD<V-H97)M+"!G96)R96L@86%N(&5D:71O
M<F9U;F-T:65S(&5N+V]F(')A;F1O;2!B<F]W<V5R+2!C<F%S:&5S(&5R=F%A
M<G0N(%=A;FYE97(@=7<@<WES=&5E;2!7:6YD;W=S(#EX(&ES+"!I<R!H970@
M=V%A<G-C:&EJ;FQI:FL@9&%T('4@965N("=!;&=E;65N92!"979E:6QI9VEN
M9W,@1F]U="<@:W)I:F=T+"!E;B!O<&YI975W(&1I96YT('1E(&AE<G-T87)T
M96XN7&Y<;E4@8F5N="!G97=A87)S8VAU=V0N($1R=6L@;W`@3TL@=V%N;F5E
M<B!U('1O8V@@9&4@=F]L;&5D:6<@<V-H97)M(&5D:71O<B!W:6QT('!R;V)E
M<F5N+@!$92!I9&5N=&ET96ET("(E<R(@:7,@=F5R=VEJ9&5R9"X`06QL965N
M(&1E(&QI;FME<FMA;G0`1&4@<&QA871S('9A;B!H970@1VYU4$<@<')O9W)A
M;6UA(&1I96YT(&]P9V5G979E;B!T92!W;W)D96X@:6X@9&4@0W)Y<'1?<&=P
M.CH@8VQA<W,N`$AE="!B97)I8VAT('9E<G-T=75R9"!O<"`E<R!A86X@)7,@
M;65T(&]N9&5R=V5R<"`B)7,B(&ES('=E97)G96=E=F5N+@I$:70@:7,@9V5E
M;B!G87)A;G1I92!D870@:&5T(&)E<FEC:'0@:7,@9V5L97IE;B!O9B!B96=R
M97!E;BX`1&4@;F%A;2!D:64@9V5B<G5I:W0@=V]R9'0@8FEJ(&QI;FME;B!N
M86%R(&1E(&YI975W(&)E<FEC:'0@<&%G:6YA`$AE="!A86YT86P@=F5L9&5N
M(&1I96YT(&YU;65R:65K('1E('II:FXN`$1E(&]P96YS<VP@;6]D=6QE(&ES
M('9E<F5I<W0@=F]O<B!D92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+@!$
M92!V;V]R:V5U<G-I;G-T96QL:6YG("(E<R(@:V]N(&YI970@=V]R9&5N(&]P
M9V5S;&%G96XL(&]M9&%T(&1E(&1A=&$@9&4@;6%X:6UU;2!T;V5L86%T8F%R
M92!G<F]O='1E(&]V97)S8VAR:6ID="X`2&5T('!R;V=R86UM82!O;2!D:70@
M9&%T871Y<&4@*"5S*2!T92!B96MI:FME;BP@=V5R9"!N:65T(&]P(&AE="!S
M>7-T965M(&=E=F]N9&5N+@!(970@86%N:&%L:6YG<W1E:V5N(&1I96YT(.OK
M;B!E;FME;"!T96ME;B!T92!Z:6IN+@!!;&QE96X@9&4@<F5C:'1E<BT@96X@
M;&EN:V5R:V%N=`!!;&QE96X@9&4@<F5C:'1E<FMA;G0`2&5T('-C:&5I9&EN
M9W-T96ME;B!D:65N="#KZVX@96YK96P@=&5K96X@=&4@>FEJ;BX`1&4@<V5R
M=F5R("(E<R(@:7,@=F5R=VEJ9&5R9"X`1&4@<V5R=F5R("(E<R(@:7,@;W!G
M97-L86=E;BX`2&5T(&%A;FUE;&1I;F=S=F5R>F]E:R!V;V]R("5S(&ES('9E
M<G=I:F1E<F0N`$1E(&]P9V5G979E;B!R:6H@*"5D*2!B97-T86%T(&YI970N
M`$AE="!T:6ID96QI:FL@8F5S=&%N9"`B)7,B(&)E<W1A870@;FEE="X`1&4@
M:6YG979O97)D92!T96MS="!K;VUT(&YI970@;W9E<F5E;B!M970@9&4@=&5K
M<W0@;W`@:&5T('-C:&5R;2X`06QL965N(&1E(&)O=F5N+2!E;B!O;F1E<FMA
M;G0`06QL965N(&1E(&)O=F5N:V%N=`!$92!U<&QO861E9"!D871A(&ES(&YA
M(&1E('9O;W)G86%N9&4@<W1A<"!V97)L;W)E;B!G96=A86XN`$AE="!U<&QO
M861E9"!B97-T86YD(&ES(&YI970@;W!G97-L86=E;BX`2&5T('=E871H97(N
M8V]M(&)L;VL@:7,@;FEE="!B97-C:&EK8F%A<BX`5&AE;6%D:7)E8W1O<GD@
M(B5S(B!N:65T(&=E=F]N9&5N+@!'965N(&]P=&EE<R!B97-C:&EK8F%A<BX`
M17(@>FEJ;B!G965N(&]N9&5R9&5L96XL('=E;&ME(&EN;&EN92!W965R9V5G
M979E;B!K=6YN96X@=V]R9&5N+@!%<B!Z:6IN('1E('9E96P@:V%R86MT97)S
M(&EN(&1I="!V96QD+B!5(&AE969T("5S(&MA<F%K=&5R<R!O<&=E9V5V96X[
M('4@9&EE;G0@;6EN9&5R(&1A;B`E<R!O<"!T92!G979E;BX`165N('!R;V)L
M965M(&UE="!H970@=&]E=F]E9V5N('9A;B`B)7,B(&%A;B!H970@<WES=&5E
M;3H@)7,`165N('!R;V)L965M(&UE="!H970@=F5R=VEJ9&5R96X@=F%N(&1A
M=&$@=F%N(&=E8G)U:6ME<B`B)7,B('5I="!H970@<WES=&5E;3H@`$5E;B!P
M<F]B;&5E;2!M970@:&5T('9E<G=I:F1E<F5N('9A;B`B)7,B('5I="!H970@
M<WES=&5E;3H@`$5E;B!P<F]B;&5E;2!M970@:&5T(&)I:G=E<FME;B!V86X@
M(B5S(CH@)7,`165N('!R;V)L965M(&UE="!D92!B97-T86YD<W5P;&]A9#H@
M1V5E;B`E<R!W97)D(&=E=7!L;V%D+@!%96X@<')O8FQE96T@;65T(&1E(&)E
M<W1A;F1S=7!L;V%D.B!(970@)7,@:7,@9W)O=&5R(&1A;B!D92!M87AI;75M
M('1O96QA871B87)E(&=R;V]T=&4@*"5D(&)Y=&5S*2X`165N('!R;V)L965M
M(&UE="!D92!B97-T86YD<W5P;&]A9#H@2&5T("5S(&ES('-L96-H=',@9V5D
M965L=&5L:6IK(&=E=7!L;V%D+@!%96X@9F]U="!B:6H@:&5T(&)E:VEJ:V5N
M('9A;B!D:70@8F5R:6-H=&]N9&5R9&5E;`!%96X@9F]U="!B:6H@:&5T(&EM
M<&]R=&5R96X@=F%N(&1E(&%D<F5S9&%T82X`165N(&9O=70@8FEJ(&AE="!I
M;7!O<G1E<F5N('9A;B!D92!I0V%L96YD87)D871A+@!%96X@9F]U="!I;B!H
M970@8V]N9FEG=7)A=&EE9F]R;75L:65R+B!-:7-S8VAI96X@8F5N="!U(&5E
M;B!V97)P;&EC:'0@=F5L9"!V97)G971E;BX`165N(&9O=70@8FEJ(&AE="!U
M:71V;V5R96X@=F%N(&1E(&]P9V5G979E;B!A9')E<V)O96MF=6YC=&EE+B!0
M<F]B965R(&QA=&5R(&]P;FEE=7<L(&$N=2YB+@!%96X@9F]U="!M970@:&5T
M(&)I:G=E<FME;B!V86X@9&4@861R97-D971A:6QS+B!0<F]B965R(&QA=&5R
M(&]P;FEE=7<L(&$N=2YB+@!%96X@9F]U="!M970@:&5T(&)I:G=E<FME;B!V
M86X@9&4@9&ES=')I8G5T:65L:6IS="X@4')O8F5E<B!L871E<B!O<&YI975W
M+"!A+G4N8BX`1&5Z92!)34%0('-E<G9E<B!O;F1E<G-T975N="!G965N(&1E
M;&EN9R!V86X@;6%P<&5N+@!$:70@;&EJ:W0@;FEE="!E96X@9V5L9&EG(')A
M<B!B97-T86YD('1E('II:FXN`$1I="!L:6IK="!N:65T(&5E;B!G96QD:6<@
M>FEP(&)E<W1A;F0@=&4@>FEJ;BX`1&ET(&QI:FMT(&YI970@965N(&=E;&1I
M9R!K86%R=&YU;6UE<B!T92!Z:6IN+@!$:70@<W1U=7)P<F]G<F%M;6$@9V5E
M9G0@9&4@;6]G96QI:FMH96ED(&]M(&)E<FEC:'1E;B!V:6$@9&4@0VQI8VMA
M=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G871E=V%Y('1E('9E<GIE
M;F1E;BP@9"YM+G8N(&1E($A45%`@05!)`$1I="!S='5U<G!R;V=R86UM82!G
M965F="!D92!M;V=E;&EJ:VAE:60@;VT@8F5R:6-H=&5N('9I82!D92!724X@
M*&AT='`Z+R]W:6YP;&,N8V]M*2!G871E=V%Y('1E('9E<GIE;F1E;BP@9"YM
M+G8N(&1E($A45%`@05!)`$1I="!S='5U<G!R;V=R86UM82!G965F="!D92!M
M;V=E;&EJ:VAE:60@;VT@8F5R:6-H=&5N('9I82!D92!S;7,R96UA:6P@*&AT
M='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y('1E('9E<GIE;F1E;BP@9"YM
M+G8N(&1E($A45%`@05!)`$1I="!S='5U<G!R;V=R86UM82!G965F="!D92!M
M;V=E;&EJ:VAE:60@;VT@8F5R:6-H=&5N('9I82!33510(&0N;2YV+B!D92!6
M;V1A9F]N92!)=&%L>2!G871E=V%Y('1E('9E<GIE;F1E;B!N86%R(%9O9&%F
M;VYE(&YU;6UE<G,N($AI97)V;V]R(&ES(&5E;B!6;V1A9F]N92!)=&%L>2!E
M+6UA:6QA9')E<R`H:'1T<#HO+W=W=RXQ.3`N:70I(&YO;V1Z86ME;&EJ:RX`
M1&ET('9E;&0@:7,@=F5R96ES=`!$:70@=F5L9"!M86<@86QL965N(&EN=&5G
M97)S(&)E=F%T=&5N+@!$:70@=F5L9"!M86<@86QL965N(&=E=&%L;&5N(&5N
M(&1E(&1U8F)E;&4@<'5N="!B979A='1E;BX`1&ET('9E;&0@;6%G(&%L;&5E
M;B!O8W1A86P@=V%A<F1E;B!B979A='1E;BX`1&ET('9E;&0@9&EE;G0@965N
M(&MO;6UA(&]F('-P871I92!G97-C:&5I9&5N(&QI:G-T(&UE="!I;G1E9V5R
M<R!T92!Z:6IN`$1E>F4@=V%A<F1E(&1I96YT(&5E;B!G96QD:6<@9V5T86P@
M=&4@>FEJ;BX`1&ET('9E;&0@9&EE;G0@965N(&ML975R8V]D92!I;B!21T(@
M2$58+69O<FUA870@=&4@8F5V871T96XL(&(N=BX@)R,Q,C,T868G+@!$:70@
M9F]R;75L:65R(&ES(')E961S('9E<G=E<FMT+@!$:70@:7,@)7,N`$1I="!I
M<R!E96X@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@3VT@9&ET(&]B:F5C="!W
M965R('1E(&=E=F5N(&AE969T('4@965N(&4M;6%I;"!C;&EE;G0@;F]D:6<@
M9&EE(&AE="!+;VQA8B!'<F]U<'=A<F4@9F]R;6%A="!B96=R:6IP="X@5F]O
M<B!E96X@;&EJ<W0@;65T(&1E>F4@92UM86EL8VQI96YT<RP@8F5Z;V5K("5S
M+"!A+G4N8BX`1&ET(&)E<FEC:'0@:7,@:6X@965N(&%N9&5R92!K87)A:W1E
M<G-E="`H)7,I(&=E<V-H<F5V96XL(&1A;B!U=R!E:6=E;BX`1&ET(&=E=&%L
M(&1I96YT('1E;FUI;G-T92#IZ6X@=&4@>FEJ;BX`1&5Z92!S97)V97(@:V%N
M(&=E96X@>FEP(&5N(&=Z:7`@8F5S=&%N9&5N('5I='!A:VME;BX`2&5T('-Y
M<W1E96T@:7,@;6]M96YT965L('5I=&=E<V-H86ME;&0N`$1E>F4@=V%A<F1E
M(&1I96YT(&5E;B!G971A;"!T92!Z:6IN+@!$:70@<V-H97)M(&1I96YT(&%A
M;F=E<F]E<&5N('1E('=O<F1E;B!V86YU:70@965N($]P=&EE<W-C:&5R;0!/
M;G=E97(`5&EC:V5T<P!4:6ID`%1I:F1P;&%N;FEN9P!4:6ID9F]R;6%A=`!4
M:6ID<V5L96-T:64`5&EM;W(M3&5S=&4`5&ET96P`5&ET96P@*'1O;VQT:7`I
M.@!!86X`3VT@;65E<F1E<F4@;VYD97)D96QE;B!T92!S96QE8W1E<F5N+"!H
M;W5D(&1E($-O;G1R;VP@*%!#*2!O9B!#;VUM86YD("A-86,I('1O971S('9A
M<W0@=&EJ9&5N<R!K;&EK:V5N+@!686YD86%G`$A434P@8G)O;B!O;7-C:&%K
M96QE;@!4;V=O`%1O:V5L874`36]R9V5N`%1O;F=A`%1E('9E96P@;VYG96QD
M:6=E(&%A;FUE;&1I;F=E;B!G961U<F5N9&4@9&4@869G96QO<&5N(&UI;G5T
M96XN`$)O=F5N:V%N=`!";W9E;G-T92!F<F%M92`H7W1O<"D`5F5R=&%L:6YG
M96X`5')I;FED860@96X@5&]B86=O`%1R=64@;V8@9F%L<V4`1&D`5'5N97-I
MZP!4=7)K:6IE`%1U<FMS("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R
M:W,@96X@0V%I8V]S(&5I;&%N9&5N`%1U=F%L=0!4>7`@=7<@:V5U>F4Z(`!5
M+E8N(&EN9&5X.B``55),`%523"!V;V]R('5W(&%F;&5V97)I;F=S<W1A='5S
M<F%P<&]R="!S8W)I<'0`55),.@!/96=A;F1A`$]E:W)A[VYE`$YI970@:6X@
M<W1A870@5D93(&1I<F5C=&]R>2!A86X@=&4@<W!R96ME;BX`3FEE="!I;B!S
M=&%A="!E>'1R82!G96)R=6EK97)S:6YF;W)M871I92!T;V4@=&4@=F]E9V5N
M(&)I:B!I;G-C:')I:G9E;BX`3FEE="!I;B!S=&%A="!D92!R96-H=&5N('9A
M;B!61E,@8F5S=&%N9"`B)7,B('1E('=I:GII9V5N+@!.:65T(&EN('-T86%T
M(&1E(')E8VAT96X@=F%N(%9&4R!B97-T86YD("5S+R5S('1E('=I:GII9V5N
M+@!.:65T(&EN('-T86%T('1E('=I:GII9V5N(&YA87(@)7,N`$YI970@:6X@
M<W1A870@8F5S=&%N9'-G<F]O='1E('9A;B`B)7,B('1E(&-O;G1R;VQE<F5N
M+@!.:65T(&EN('-T86%T(&)E<W1A;F1S9W)O;W1T92!V86X@(B5S+R5S(B!T
M92!C;VYT<F]L97)E;BX`3FEE="!I;B!S=&%A="!M970@9&4@4U%,('-E<G9E
M<B!T92!V97)B:6YD96XN`$YI970@:6X@<W1A870@;65T(%-33"!T92!V97)B
M:6YD96XN`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@=&4@:V]P:>MR96XN
M`$YI970@:6X@<W1A870@5D93(&1I<F5C=&]R>2`B)7,B('1E(&UA:V5N+@!.
M:65T(&EN('-T86%T(%9&4R!D:7)E8W1O<GD@=&4@;6%K96XN`$YI970@:6X@
M<W1A870@5D93(&)E<W1A;F0@=&4@;6%K96XN`$YI970@:6X@<W1A870@5D93
M(&UA<"`B)7,B('1E(&UA:V5N+@!.:65T(&EN('-T86%T(&5E;B!L965G(%9&
M4R!B97-T86YD('1E(&UA:V5N+@!.:65T(&EN('-T86%T(&1A=&$@=6ET('1E
M('!A:VME;BX`3FEE="!I;B!S=&%A="`B)7,B('1E('9E<G=I:F1E<F5N+"!D
M92!D:7)E8W1O<GD@:7,@;FEE="!L965G`$YI970@:6X@<W1A870@(B5S(CH@
M)7,@=&4@=F5R=VEJ9&5R96XN`$YI970@:6X@<W1A870@)7,@=&4@=F5R=VEJ
M9&5R96XL(&1E(&1I<F5C=&]R>2!I<R!N:65T(&QE96<`3FEE="!I;B!S=&%A
M="!61E,@9&ER96-T;W)Y(')E8W5R<VEE9B!T92!V97)W:6ID97)E;BX`3FEE
M="!I;B!S=&%A="!61E,@9&ER96-T;W)Y('1E('9E<G=I:F1E<F5N+@!.:65T
M(&EN('-T86%T(%9&4R!D:7)E8W1O<GD@)7,@=&4@=F5R=VEJ9&5R96XN`$YI
M970@:6X@<W1A870@5D93(&)E<W1A;F0@(B5S(B!T92!V97)W:6ID97)E;BX`
M3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"!T92!V97)W:6ID97)E;BX`3FEE
M="!I;B!S=&%A="!61E,@;6%P("(E<R(@=&4@=F5R=VEJ9&5R96XN`$YI970@
M:6X@<W1A870@5D93("5S(')E8W5R<VEE9B!T92!V97)W:6ID97)E;BX`3FEE
M="!I;B!S=&%A="!H=6ED:6=E(&1I<F5C=&]R>2!T92!B97!A;&5N+@!.:65T
M(&EN('-T86%T(&-E<G1I9FEC86%T9&5T86EL<R!U:70@=&4@9FEL=&5R96X`
M3FEE="!I;B!S=&%A="!O;2!D92!D969I;FET:64@=F%N("5S('1E(&QA9&5N
M+@!.:65T(&EN('-T86%T(%9&4R!B97-T86YD('1E('9E<G!L86%T<V5N+@!.
M:65T(&EN('-T86%T(%9&4R!B97-T86YD("(E<R(@=&4@;W!E;F5N+@!.:65T
M(&EN('-T86%T(%9&4R!B97-T86YD('1E(&]P96YE;B!V;V]R('-C:')I:G9E
M;BX`3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"!T92!O<&5N96XN`$YI970@
M:6X@<W1A870@:&5T(&EN9V5P86MT92!B97-T86YD('1E(&]P96YE;BX`3FEE
M="!I;B!S=&%A="!61E,@8F5S=&%N9"!T92!L97IE;B`H9FEL97-I>F4H*2!M
M:7-L=6MT*2X`3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"!T92!L97IE;B`H
M9V5T1FEL95-I>F4H*2!M:7-L=6MT*2X`3FEE="!I;B!S=&%A="!B97-T86YD
M('1E(&QE>F5N.B``3FEE="!I;B!S=&%A="!V9G-R;V]T(&1I<F5C=&]R>2!T
M92!O<&5N96XN`$YI970@:6X@<W1A870@;VT@)7,@=&4@:&5R;F]E;65N(&YA
M87(@)7,Z(&)E<W1E;6UI;F=S;6%P(&)E<W1A870@86P`3FEE="!I;B!S=&%A
M="!61E,@9&ER96-T;W)Y('1E(&AE<FYO96UE;BX`3FEE="!I;B!S=&%A="!6
M1E,@9&ER96-T;W)Y("5S('1E(&AE<FYO96UE;BX`3FEE="!I;B!S=&%A="!6
M1E,@8F5S=&%N9"`B)7,B('1E(&AE<FYO96UE;BX`3FEE="!I;B!S=&%A="!6
M1E,@8F5S=&%N9"`E<R\E<R!T92!H97)N;V5M96XN`$YI970@:6X@<W1A870@
M5D93(&)E<W1A;F0@=&4@:&5R;F]E;65N+@!+86X@)VUK:7-O9G,G(&YI970@
M=6ET=F]E<F5N+@!.:65T(&EN('-T86%T(&1I="!7;W)D(&1O8W5M96YT('1E
M('9E<G1A;&5N`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@(B5S(B!T92!S
M8VAR:6IV96XN`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@=&4@<V-H<FEJ
M=F5N("AC;W!Y*"D@9F%I;&5D*2X`3FEE="!I;B!S=&%A="!61E,@8F5S=&%N
M9'-D871A('1E('-C:')I:G9E;BX`3FEE="!I;B!S=&%A="!61E,@8F5S=&%N
M9"!T92!S8VAR:6IV96XL('%U;W1A('=O<F1T(&]V97)S8VAR961E;BX`3VYD
M97)S=')E<&5N`$AE<G-T96P@=VEJ>FEG:6YG96X`1&]E="!U=R!L86%T<W1E
M(&)E=V5R:VEN9R!T96YI970`3VYV97)W86-H="!A;G1W;V]R9"!V86X@9&4@
M<V5R=F5R(&]P('9E<F)I;F1I;F<Z(`!/;G9E<G=A8VAT(&%N='=O;W)D('9A
M;B!S97)V97(@86%N.B``3VYB96YO96UD`%5N:6-O9&4@*%541BTX*0!697)E
M;FEG9&4@07)A8FES8VAE($5M:7)A=&5N`%9E<F5N:6=D($MO;FEN9VMR:6IK
M`%9E<F5N:6=D92!3=&%T96X`5F5R96YI9V1E(%-T871E;BP@:VQE:6YE(&)U
M:71E;B!L:6=G96YD92!E:6QA;F1E;@!%96YH961E;@!/;F)E:V5N9`!/;F)E
M:V5N9"!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!/;F)E:V5N9"!C;&EM
M<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!/;F)E:V5N9&4@;&]C871I92!O
M<&=E9V5V96XN`$]N8F5K96YD92!G96)R=6EK97)S;F%A;2!O9B!W86-H='=O
M;W)D+@!(970@:'5I9&EG92!E;&5M96YT(&QO<VMO<'!E;&5N`$]N8F5N;V5M
M9`!.:65T(&=E<F5C:'1I9V1E('-C<FEP=',@:W5N;F5N('!R;V=R86UM86UA
M=&EG(&YI970@2VYI<'!E;B]+;W!IZW)E;B]0;&%K:V5N+"!V86YW96=E(&)E
M=F5I;&EG:6YG<W)E9&5N96XN($ML:6L@;W`@3TL@;VT@965N('1E8VAN:7-C
M:&4@;W!M97)K:6YG(&]P(&UO>FEL;&$N;W)G('1E(&)E:VEJ:V5N(&AO92!U
M(&5E;B!S8W)I<'0@=&]E<W1A870@:&5T('!R:6MB;W)D('1E(&)E;F%D97)E
M;BX`2VQE=7(@=&5R=6=S=&5L;&5N`$YI970@;VYD97)S=&5U;F1E(&5X=&5N
M=&EE`$)I:G=E<FME;@`E<R!B:6IW97)K96X`1V5B<G5I:V5R(&)I:G=E<FME
M;BX`(B5S(B!B:6IG97=E<FMT+@!5<&=R861E('-C<FEP="!V97)W:6ID97)D
M+@!5<&QO860`06QL92!T;V5P87-S:6YG('-E='5P8F5S=&%N9&5N(&YA87(@
M9&4@<V5R=F5R(&=E=7!L;V%D+@!,871I:FYS92!H;V]F9&QE='1E<G,`1W)O
M=&4@4F]M96EN<V4@9V5T86QL96X`57)U9W5A>0!'96)R=6EK(&AU:61I9V4Z
M("5S`$=E8G)U:6L@4U-,`$=E8G)U:6ME;B!W86YN965R(&YA86TO=V%C:'1W
M;V]R9"!V97)S8VAI;'0@;65T($E-4U`@<V5R=F5R+@!'96)R=6EK97(`1V5B
M<G5I:V5R("5S(&ES(&YI970@9V5A=71O<FES965R9"!V;V]R("5S+@!'96)R
M=6EK97)S8F5H965R`$=E8G)U:6ME<G-O<'1I97,`1V5B<G5I:V5R<W)E9VES
M=')A=&EE`$=E8G)U:6ME<G-R96=I<W1R871I92!I<R!U:71G97-C:&%K96QD
M(&]P(&1E>F4@<VET92X`1V5B<G5I:V5R<V%C8V]U;G0@;FEE="!G979O;F1E
M;BX`1V5B<G5I:V5R<VYA86T`1V5B<G5I:V5R<VYA86T@(B5S(B!B97-T86%T
M(&%L+@!'96)R=6EK97)S;F%A;3H`1V5B<G5I:V5R<VYA86TZ(`!'96)R=6EK
M97)S(&EN(&AE="!S>7-T965M.@!/97IB96MI<W1A;@!61E,@9&ER96-T;W)Y
M(&)E<W1A870@;FEE="X`069W97II9VAE:60`1V5V;VYD96X@9V5L9&EG92!L
M;V-A=&EE<R!B979A='1E;CH@`$=E;&1I9VAE:60`5V%A<F1E(&EN(&UI;G5T
M96X@=F%N868@;G4N`%=A87)D92!L:6=T(&)O=F5N(&1E(&UA>&EM=6T@;&5N
M9W1E('9A;B`E<RX`5V%A<F1E;@!786%R9&5N('=A87)U:70@9V5S96QE8W1E
M97)D(&MA;B!W;W)D96X`5F%N=6%T=0!687)I86)E;&4`5F5N97IU96QA`%9E
M<FEF:6-A=&EE(&UI<VQU:W0@+2!E<B!K86X@;65T(&1I="!B97)I8VAT(&=E
M:VYO96ED('II:FXN`%9E<G-I90!697)S:65C;VYT<F]L90!697)T:6MA86P@
M=6ET;&EJ;F5N`%9E<G1I:V%L92!V<FEJ92!R=6EM=&4`5F5R=&EK86%L.@!%
M<F<@:&]O9P!6:65T;F%M`%9I971N86UE97,@*%9)4T-)22D`)7,@8F5K:6IK
M96X`0F5K:6IK(&5E;B!E>'1E<FYE('=E8G!A9VEN80!"96MI:FME;B!A;',@
M)7,`36%A9V1E;B!E:6QA;F1E;BP@0G)I='-E`$UA86=D96X@96EL86YD96XL
M(%8N4RX`6FEC:'0`6FEC:'0Z(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU44`!7
M05).`%=!05)30TA55TE.1R$A(2`@5D525TE*1$52(%-#4DE05"!(04Y$34%4
M24<@54E4("5S+@!724X@=FEA($A45%``5V%L;&ES(&5N($9U='5N80!786%R
M<V-H=7=I;F<`5V\`5V5E<G-V;V]R=6ET>FEC:'0`5V5E<F)E<FEC:'0@9V5G
M979E;G,@9V5L979E<F0@9&]O<@!796%T:&5R+F-O;0!796(`5V5B<VET90!7
M96ME;&EJ:W,`5V5L:V]M`%=E;&MO;2!B:6H@)7,`5V5L:V]M+"`E<P!797-T
M97)S("A)4T\M.#@U.2TQ*0!797-T97)S("A)4T\M.#@U.2TQ-2D`5V5S=&5L
M:6IK92!386AA<F$`5V5L:V4@=&]E<&%S<VEN9R!D:65N="`E<R!W965R('1E
M(&=E=F5N(&YA(&%A;FUE;&1I;F<_`%=A="!I<R!H970@<V-H96ED:6YG<VMA
M<F%K=&5R/P!7870@:7,@:&5T(&-I=&%A=&MA<F%K=&5R/P!7:&5R96ES($%U
M<W1R86QIZR!K86%R=`!796QK92!F87-E;@!796QK92!P;'5G:6YS('9O;W(@
M9&4@4FEC:"!497AT(&5D:71O<B!I;G-C:&%K96QE;BX`0G)E961T90!"<F5E
M9'1E(&EN($-34R!E96YH961E;@!"<F5E9'1E('9A;B!H970@)7,@;65N=2!A
M86X@9&4@;&EN:V5R:V%N="`H86MT:65F(&)I:B!V;VQG96YD92!A86YM96QD
M:6YG*3H`0G)E961T92!V86X@9&4@=&%B96P`0G)E961T92!E96YH96ED`$)R
M965D=&4Z`%=I:VD`5VEN9`!7:6YD('9R;V5G`%=I;F1S;F5L:&5I9"!I;B!K
M;F]P96X`5VEN9#H`5VEN9#H@`%=I:G-H96ED`%=E;G-L:6IS=`!797)K`%=E
M<FMA9')E<P!496PN;G(N("AW97)K*0!697)K965R9"!A86YT86P@=F5L9&5N
M(&EN(')E9V5L("5D+B!697)W86-H="`E9"P@9V5V;VYD96X@)60N`%9E<FME
M97)D(&%A;G1A;"!V96QD96XN(%9E<G=A8VAT("5D+"!G979O;F1E;B`E9"X`
M5F5R:V5E<F1E(&]F9G-E="`E9"!B:6H@;&5Z96X@=F%N(%9&4R!B97-T86YD
M+@!8+5)E9@!8-3`Y=C,@8F%S:7-B97!E<FMI;F=E;@!8-3`Y=C,@=6ET9V5B
M<F5I9"!S;&5U=&5L9V5B<G5I:P!8-3`Y=C,@86QT97)N871I979E(&]N9&5R
M=V5R<&YA86T`6#4P.78S(&]N9&5R=V5R<"!S;&5U=&5L:61E;G1I9FEC871O
M<@!8-3`Y=C,@97AT96YT:65S`$I*`$I*2DH`66%H;V\A(&UA<`!*86%R;&EJ
M:W,`2F5M96X`2F$`2F$L(&EK(&%C8V5P=&5E<B!D92!V;V]R=V%A<F1E;@!5
M(&)E;G0@:6X@5$5+4U0@34]$12X@1V5B<G5I:R!D92!;/#Y=(&MN;W`@;VT@
M;F%A<B!765-)5UE'('1E<G5G('1E('-C:&%K96QE;BX`2&5T(&ES('4@;FEE
M="!T;V5G97-T86%N(&]M(&UE97(@9&%N("5D(&)L;VMK96X@=&4@;6%K96XN
M`%4@8F5N="!N:65T(&=E875T:&5N=&EF:6-E97)D+@!5(&MU;G0@9V5E;B`G
M7"<@:V%R86MT97(@:6X@=7<@=F]L;&5G92!N86%M(&AE8F)E;BX`52!H965F
M="!G965N(&=E;&1I9R!E+6UA:6QA9')E<R!O<&=E9V5V96XN`%4@:&5E9G0@
M9V5E;B!V96QD96X@=6ET(&AE="!G96EM<&]R=&5E<F1E(&)E<W1A;F0@9V5K
M;W!P96QD(&UE="!D92!O=F5R965N:V]M<W1I9V4@=F5L9&5N(&EN("5S+@!5
M(&)E;G0@869G96UE;&0N`%4@9&EE;G0@965N(&=E;&1I9R!M;V)I96P@;G5M
M;65R(&EN('1E('9O97)E;BP@86QL965N(&-I:F9E<G,@;65T(&5E;B!O<'1I
M;VYE;&4@)RLG('9O;W(@:&5T(&EN=&5R;F%T:6]N86QE(&MI97-V;V]R=F]E
M9W-E;"X`52!D:65N="!E96X@9V5L9&EG92!W86%R9&4@;W`@=&4@9V5V96XN
M`%4@9&EE;G0@965N($1A=&%4<F5E(&)A8VME;F0@=&4@8V]N9FEG=7)E<F5N
M(&]M(&EN<V-H<FEJ=FEN9V5N('1E(&MU;FYE;B!G96)R=6EK96XN`%4@9&EE
M;G0@965N(%9&4R!B86-K96YD('1E(&-O;F9I9W5R97)E;BX`52!D:65N="!H
M970@<')O8FQE96T@=&4@8F5S8VAR:6IV96XL('9O;W)D870@=2!H970@<')O
M8FQE96UR87!P;W)T(&MU;G0@=F5R>F5N9&5N+@!5(&1I96YT(&5E;B!54DP@
M:6X@=&4@=F]E<F5N('=A87)N86%R(&1E>F4@;&EN:R!V97)W:6IS=`!5(&1I
M96YT(&5E;B!S97)V97(@=&4@<V5L96-T97)E;B!O;2!T92!V97)W:6ID97)E
M;BX`52!D:65N="!E96X@9V5B<G5I:V5R<VYA86T@;W`@=&4@9V5V96X@;VT@
M=&4@=VES<V5N+@!5(&1I96YT(&5E;B!G96)R=6EK97)S;F%A;2!O<"!T92!G
M979E;B!O;2!T92!V97)W:6ID97)E;BX`52!D:65N="!E96X@9V5B<G5I:V5R
M<VYA86T@;W`@=&4@9V5V96X@;VT@=&]E('1E('9O96=E;BX`52!D:65N="!E
M96X@9V5B<G5I:V5R<VYA86T@;W`@=&4@9V5V96X@;VT@8FEJ('1E(&MU;FYE
M;B!W97)K96XN`%4@9&EE;G0@965N(&)E=V5R:VEN9R!O<"!T92!G979E;B!W
M96QK92!U:71G979O97)D(&UO970@=V]R9&5N+@!5(&1I96YT(&5E;B!N:65U
M=V4@8V%T96=O<FEE;F%A;2!O<"!T92!G979E;BX`52!D:65N="!E96X@271A
M;&EA86YS('1E;&5F;V]N;G5M;65R(&]P('1E(&=E=F5N`%5W("5S('-E<W-I
M92!I<R!V97)L;W!E;BX@3W!N:65U=R!A86YM96QD96XL(&$N=2YB+@!5=R!E
M+6UA:6QA9')E<P!5=R!686XZ(&%D<F5S.@!5=R!I;F9O<FUA=&EE`%5W(&EN
M=&5R;F5T861R97,@:7,@9V5W:6IZ:6=D('-I;F1S(&AE="!B96=I;B!V86X@
M=7<@)7,@<V5S<VEE+B!/;2!U=R!V96EL:6=H96ED('1E(&)E<V-H97)M96XL
M(&1I96YT('4@>FEC:"!O<&YI975W(&%A;B!T92!M96QD96XN`%5W(&YA86TZ
M`$AE="!T;V5V;V5G96X@=F%N(&=E8G)U:6ME<G,@=V]R9'0@;FEE="!O;F1E
M<G-T975N9"!D;V]R('5W(&%U=&AE;G1I8V%T:64@8F%C:V5N9"X@5V%N;F5E
M<B!U($AO<F1E(&=E8G)U:6ME<G,@=VEL="!B96AE<F5N+"!D:65N="!U(&5E
M;B!A;F1E<B!A=71H96YT:6-A=&EE(&)A8VME;F0@=&4@9V5B<G5I:V5N+@!(
M970@=V5E<F=E=F5N('9A;B!E96X@9V5B<G5I:V5R<VQI:G-T('=O<F1T(&YI
M970@;VYD97)S=&5U;F0@9&]O<B!U=R!A=71H96YT:6-A=&EE(&)A8VME;F0L
M(&]F(&1E>F4@;W!T:64@:7,@;VT@86YD97)E(')E9&5N96X@=6ET9V5S8VAA
M:V5L9"X`57<@8G)O=W-E<B!L:6IK="!T92!Z:6IN(&=E=VEJ>FEG9"!S:6YD
M<R!H970@8F5G:6X@=F%N('5W("5S('-E<W-I92X@3VT@=7<@=F5I;&EG:&5I
M9"!T92!B97-C:&5R;65N+"!D:65N="!U('II8V@@;W!N:65U=R!A86X@=&4@
M;65L9&5N+@!5=R!B<F]W<V5R(&]N9&5R<W1E=6YT(&1E>F4@;6]G96QI:FMH
M96ED(&YI970N`%5W(&)R;W=S97(@;VYD97)S=&5U;G0@9&5Z92!P<FEN=&]P
M=&EE(&YI970N($1R=6L@;W`@0V]N=')O;"]#;VUM86YD("L@4"!O;2!A9B!T
M92!D<G5K:V5N+@!5=R!H=6ED:6=E('1I:F1Z;VYE.@!5=R!S=&%N9&%A<F0@
M:61E;G1I=&5I="!I<R!G97=I:GII9V0N`%5W('-T86YD86%R9"!I9&5N=&ET
M96ET.@!5=R!V;VQL961I9V4@;F%A;3H`57<@86%N;65L9&EN9R!I<R!V97)L
M;W!E;BX`57<@;FEE=7=E('=A8VAT=V]O<F0@=F]O<B`E<R!I<SH@)7,`57<@
M;W!T:65S('II:FX@8FEJ9V5W97)K="!V;V]R(&1E(&1U=7(@=F%N(&1E>F4@
M<V5S<VEE+@!5=R!O<'1I97,@>FEJ;B!B:6IG97=E<FMT+@!5=R!W86-H='=O
M;W)D(&ES(&=E<F5S970`57<@=V%C:'1W;V]R9"!I<R!V97)N:65U=V0L(&-O
M;G1R;VQE97(@=7<@92UM86EL(&5N(&UE;&0@86%N(&UE="!U=R!N:65U=V4@
M=V%C:'1W;V]R9"X`57<@=V%C:'1W;V]R9"!I<R!V97)L;W!E;BX`57<@<V5R
M=F5R<R!O<"!A9G-T86YD.@!*;V5G;W-L879IZP!:8>]R90!:86UB:6$`6FEM
M8F%B=V4`6FEP<'D`6U9E<F)E<F<@86%N9V5H86%L9&4@=&5K<W1=`%M0<F]B
M;&5E;7)A<'!O<G1=`%M!86YG96AA86QD92!T96MS="!W965R9V5V96X@+0!;
M06%N9V5H86%L9&4@=&5K<W0@+2`E<R!R96=E;'-=`%MR96=E;"`E<R!V86X@
M)7-=`$)?96AE97(`7T-,20!?1&%T851R964`5F5R7W=I:F1E<B!R:6H`7T=R
M;V5P96X`7TAE;'``7T%F8F5E;&1I;F=S96EG96YS8VAA<'!E;BXN+@!?06%N
M;65L9&5N`%]!9FUE;&1E;@!?5VEJ>FEG(&QI;FLN+BX`7T]P=&EE<P!?4F5C
M:'1E;@!?5F5R=VEJ9&5R(&QI;FLN+BX`7TEN<W1E;&QE;@!?5&%B96QE:6=E
M;G-C:&%P<&5N+BXN`$=E7V)R=6EK97)S`$%D<F5S8F]E:P!'96%D<F5S<V5E
M<F1E(&]N8F5K96YD`$MA;&5N9&5R`$MA;&T`2V%N(&]U='!U=&)E<W1A;F0@
M;FEE="!M86ME;@!+86X@:6YP=70@;FEE="!O<&5N96X`2VQI:R!H:65R`$-O
M;6UA;F1O<F5G96P@9V5B<G5I:W-F;W5T`$-O;F9I9W5R871I969O=70`2W)I
M=&ES8V@@<WES=&5E;6)E<W1A;F0@;VYT8G)E96MT`$1A=&%F;W)M86%T9F]U
M=`!B97=E<FME;@!I;G9O97(@;FEE="!G979O;F1E;@!D86QE;F0`8F5S=&%N
M9`!V86X@9&4@)7,@*"5S*2!O<"`E<R`E<P!V;&%G97)I9P!H.@!H:`!H;W-T
M;F%A;2!O;F)E:V5N9`!O;FUI9&1E;&EJ:P!I;FQI;F4`:6YP=70O;W5T<'5T
M(&9O=70`:6YT97)N92!S;V9T=V%R969O=70`<F5G96QS70!M:VES;V9S(&9O
M=71C;V1E("5D(&)I:B!H970@86%N;6%K96X@=F%N($E33RX`;6T`;F%A;0!N
M:65T('9A;B!T;V5P87-S:6YG`$YO9R!N:65T('9A;B!T;V5P87-S:6YG`&YO
M=&ET:65B;V5K`'!R;V-E;G0`4F5C:'0@9V5W96EG97)D`'!I>&5L<P!296UO
M=&4@9F]U="!I;B!P<F]T;V-O;`!S=&EJ9V5N9`!397)V:6-E(&YI970@8F5S
M8VAI:V)A87(`=&]O;B!V97)S8VAI;&QE;@!S;7,R96UA:6P@=FEA($A45%``
M<W,`<W1A8FEE;`!S>7-T965M9F]U=`!T86ME;FQI:G-T`'1I:F1E;&EJ:V4@
M;6ES;'5K:VEN9P!6;V5R+"!T97(@8F5V97-T:6=I;F<L(&AE="!W86-H='=O
M;W)D('1W964@;6%A;"!I;@!U;FEF:65D`&]N8F5N;V5M9`!'96)R=6EK97)S
M96QE8W1I90!V0V%R9`!W.@!W96%T:&5R+F-O;0``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VYL7TY,+VAE;'`N>&UL````````
M````````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S,S(P(#$P-3$U
M-#,S-S0Q(#`R,30T-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/WAM;"!V97)S:6]N/2(Q+C`B/SX*/"$M+2`D2&]R9&4Z
M(&AO<F1E+VQO8V%L92]N;%].3"]H96QP+GAM;"QV(#$N,B`R,#`T+S`U+S(W
M(#(P.C(R.C$T(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED/2)S
M=6UM87)Y(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H92!0;W)T86P@4&%G93PO
M=&ET;&4^"B`\<&%R83X*("!4:&ES('!O<G1A;"!P86=E('!R;W9I9&5S(&$@
M<75I8VL@<W5M;6%R>2!O9B!A;&P@>6]U<B!I;7!O<G1A;G0*("!I;F9O<FUA
M=&EO;BX@1F]R(&5X86UP;&4L(&ET(&UI9VAT('-H;W<@:&]W(&UA;GD@;F5W
M(&4M;6%I;"!M97-S86=E<R!Y;W4*("!H879E(&EN('EO=7(@24Y"3U@L('5P
M8V]M:6YG(&5V96YT<R!O;B!Y;W5R(&-A;&5N9&%R+"!T87-K<R!O;B!Y;W5R
M('1O+61O"B`@;&ES="P@:&5A9&QI;F5S(&9R;VT@<V5L96-T960@;F5W<R!S
M97)V:6-E<RP@86YD('-O(&]N+B`@36%N>2!O9B!T:&5S90H@('-U;6UA<FEE
M<R!W:6QL(&-O;G1A:6X@<75I8VL@<VAO<G1C=71S('1O(&-O;6UO;B!F=6YC
M=&EO;G,L('-U8V@@87,*("!C;VUP;W-I;F<@82!N97<@;6%I;"!M97-S86=E
M+"!C<F5A=&EN9R!A(&YE=R!C86QE;F1A<B!E=F5N="!O<B!T87-K+"!E=&,N
M"B`\+W!A<F$^"B`\<&%R83X*("!4:&4@8V]N=&5N=',@;V8@=&AI<R!P;W)T
M86P@<&%G92!A<F4@8W5S=&]M:7IA8FQE('9I82!T:&4@3&%Y;W5T(&)U='1O
M;BX*("!&;W(@97AA;7!L92P@>6]U(&-A;B!C:&]O<V4@=VAI8V@@:71E;7,@
M=&\@:6YC;'5D92!O;B!T:&ES('!O<G1A;"!P86=E(&%S"B`@=V5L;"!A<R!I
M;B!W:&EC:"!O<F1E<B!T:&5Y(&%R92!S:&]W;BX*(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](FYA=F)A<B(@<W1A=&4](FYE=R(^"CQT:71L93Y4
M:&4@07!P;&EC871I;VX@3F%V:6=A=&EO;B!"87(\+W1I=&QE/@H@/'!A<F$^
M"B`@070@=&AE(&QE9G0@:&%N9"!S:61E(&]F('1H92!W96(@<&%G92!I<R!T
M:&4@87!P;&EC871I;VX@;F%V:6=A=&EO;B!B87(N"B`@0VQI8VL@;VX@=&AE
M(&EC;VYS(&]N('1H:7,@;F%V:6=A=&EO;B!B87(@=&\@<75I8VML>2!A;F0@
M96%S:6QY('-W:71C:`H@(&)E='=E96X@=&AE(&%V86EL86)L92!A<'!L:6-A
M=&EO;G,N"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD
M;U]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R
M96YC97,Z($UA:6YT96YA;F-E.B!$;R!-86EN=&5N86YC93PO=&ET;&4^"B`@
M("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O('!E<F9O<FT@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;BP@8VAE8VL@=&AI<R!B;W@N
M"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUC;VYF
M:7)M7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F
M97)E;F-E<SH@36%I;G1E;F%N8V4Z($-O;F9I<FT@36%I;G1E;F%N8V4\+W1I
M=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!C;VYF
M:7)M(&%L;"!M86EN=&5N86YC92!T87-K<R!B969O<F4@=&AE>2!A<F4@<G5N
M+"!C:&5C:R!T:&ES(&)O>"X@268@;&5F="!U;F-H96-K960L(&%L;"!M86EN
M=&5N86YC92!O<&5R871I;VYS('1H870@;F5E9"!T;R!B92!R=6X@=VEL;"!B
M92!P97)F;W)M960@875T;VUA=&EC86QL>2!W:71H(&YO(&-H86YC92!T;R!C
M86YC96P@;VX@;&]G:6XN"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L<#X*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQO8V%L92]N;E].3P``````````````````````````
M```````````````````````````````````````````````````````````P
M,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<T
M,2`P,3<W,C4`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VYN7TY/+TQ#
M7TU%4U-!1T53````````````````````````````````````````````````
M`````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P,#`P(#$P-3$U-#,S-S0Q(#`R,34Q,@`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L;V-A;&4O;FY?3D\O3$-?34534T%'15,O:&]R9&4N;6\`````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,C,R,#$@,3`U,34T,S,W-#$@,#(S,C(U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````-X2!)4`
M````F0```!P```#D!```TP```*P)````````^`P```L```#Y#```*`````4-
M```5````+@T```@```!$#0``!0```$T-```#````4PT```\```!7#0``"```
M`&<-```(````<`T``!D```!Y#0``!P```),-```,````FPT```X```"H#0``
M!0```+<-```?````O0T``#D```#=#0``)P```!<.```L````/PX``"H```!L
M#@``$0```)<.```(````J0X```@```"R#@``!@```+L.```5````P@X```H`
M``#8#@``$0```.,.```,````]0X```<````"#P``$`````H/```K````&P\`
M`!X```!'#P``&P```&8/```;````@@\``#,```">#P``+P```-(/```I````
M`A````(````L$```!0```"\0```0````-1````8```!&$```%````$T0```O
M````8A````\```"2$```)@```*(0```$````R1````4```#.$```#0```-00
M```%````XA```!````#H$```$````/D0```/````"A$```L````:$0``#P``
M`"81```,````-A$```\```!#$0``'@```%,1```A````<A$```,```"4$0``
M#````)@1```4````I1$```8```"Z$0``!````,$1```,````QA$```H```#3
M$0``!0```-X1```2````Y!$``!````#W$0``"`````@2```0````$1(``!H`
M```B$@``!@```#T2```'````1!(```(```!,$@``)0```$\2```$````=1(`
M``\```!Z$@``!P```(H2```'````DA(```D```":$@``!P```*02```2````
MK!(```0```"_$@``!P```,02```%````S!(``#,```#2$@``&@````83```%
M````(1,```<````G$P``$0```"\3```(````01,``!4```!*$P``'@```&`3
M```H````?Q,```L```"H$P``&@```+03```%````SQ,``"@```#5$P``*0``
M`/X3```3````*!0``#(````\%```!````&\4```&````=!0```L```![%```
M!0```(<4```1````C10```0```"?%```#````*04```:````L10``!<```#,
M%```%P```.04```;````_!0``!D````8%0``'P```#(5```3````4A4```0`
M``!F%0``$````&L5```7````?!4```<```"4%0``!0```)P5```Q````HA4`
M`#@```#4%0``(0````T6```<````+Q8```4```!,%@```P```%(6```@````
M5A8``"8```!W%@``#````)X6```&````JQ8``!,```"R%@``#````,86```(
M````TQ8``!0```#<%@``!P```/$6```&````^18```T`````%P``"P````X7
M```,````&A<```H````G%P```@```#(7```&````-1<```P````\%P``10``
M`$D7```F````CQ<``"4```"V%P``,````-P7```0````#1@``',````>&```
M'P```)(8```0````LA@```\```##&```!0```-,8``!B`0``V1@```H````\
M&@``*````$<:```4````<!H```@```"%&@``!0```(X:```(````E!H``!,`
M``"=&@``#````+$:```/````OAH``!X```#.&@``!P```.T:```*````]1H`
M``X`````&P``!0````\;```C````%1L``#L````Y&P``+0```'4;```O````
MHQL``"X```#3&P``$P````(<```'````%AP```@````>'```!@```"<<```5
M````+AP```P```!$'```%@```%$<```.````:!P```4```!W'```$````'T<
M```K````CAP``!T```"Z'```(````-@<```<````^1P``#`````6'0``-@``
M`$<=```L````?AT```(```"K'0``!@```*X=```1````M1T```8```#''0``
M$0```,X=```F````X!T``!$````''@``(P```!D>```%````/1X```8```!#
M'@``#@```$H>```$````61X``!````!>'@``$````&\>```/````@!X```\`
M``"0'@``#P```*`>```,````L!X``!````"]'@``'P```,X>```C````[AX`
M``0````2'P``#0```!<?```4````)1\```<````Z'P``!0```$(?```/````
M2!\```\```!8'P``!0```&@?```3````;A\``!````""'P``!0```),?```2
M````F1\``"````"L'P``"````,T?```'````UA\```(```#>'P``)0```.$?
M```&````!R```!`````.(```"0```!\@```'````*2````D````Q(```"```
M`#L@```5````1"````0```!:(```"````%\@```%````:"```#@```!N(```
M(````*<@```'````R"````H```#0(```$0```-L@```'````[2```!4```#U
M(```'`````LA```L````*"$```<```!5(0``%@```%TA```'````="$``"4`
M``!\(0``)````*(A```6````QR$``"\```#>(0```P````XB```%````$B(`
M``D````8(@``"0```"(B```6````+"(```4```!#(@``$````$DB```9````
M6B(```\```!T(@``#P```(0B```8````E"(``!````"M(@``$````+XB```3
M````SR(```,```#C(@``%0```.<B```:````_2(```<````8(P``"````"`C
M```I````*2,``#4```!3(P``'@```(DC```>````J",```8```#'(P```P``
M`,XC```>````TB,``"@```#Q(P``#P```!HD```(````*B0``!0````S)```
M$````$@D```*````620``!0```!D)```"````'DD```)````@B0```\```",
M)```#````)PD```/````J20```\```"Y)````@```,DD```%````S"0```X`
M``#2)```.@```.$D```J````'"4``"T```!')0``,@```'4E```/````J"4`
M`'D```"X)0``)@```#(F```0````628``!````!J)@``!0```'LF```!````
M;@````````"+````!@```````````````````&,````3````#0``````````
M````A@```(`````9````3P```!(````:````=0````D```!V````!````"@`
M```%`````````&T```!(````.````$(`````````80````P`````````````
M`($```"-````0P```&8````L````"``````````W````/@```((```!H````
M`````&H````\````9`````````!$````<0```#````!0````>0```%H```"0
M````5P```!4`````````$0```)D`````````'`````,`````````AP```#T`
M``!]``````````````!X````:0```"L```")`````````"D`````````<```
M```````+````A0```````````````````(,```"*````````````````````
M>@``````````````)`````````!'````6````!````!*````*@```"8````4
M``````````````!E````70```)<``````````````',```"4````C@```(\`
M`````````````#4```![````,@```'<``````````````"4```!-````50``
M`"T```"$````(@```$8`````````-````%$`````````'P```%(````/````
M``````(````>``````````````"5````DP```$4```!T````C````'\`````
M````,P```'X`````````&````%8``````````````!T``````````````#8`
M````````)P``````````````B````&\````Q````7P````H`````````5```
M`%X````@`````````'(```!G````D@```$D````6````3@````X````[````
M0````$L```!B````&P```&P```"6````4P```#H```!\`````````&L```!,
M````D0````<````A`````````%D````Y````F````#\````C````8```````
M``!<````%P```$$`````````6P```"X````O`````"5S("T@3F]T:6-E`"5S
M($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@5&5R
M;7,@;V8@06=R965M96YT`#(T(&AO=7)S`$%-+U!-`$%D9`!!9&0@82!N97<@
M=7-E<CH`061D('!A:7(`061D('5S97(`061D:6YG('5S97)S(&ES(&1I<V%B
M;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=')A=&EO;@!!;&EA
M<P!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%S:R!F;W(@8V]N
M9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS
M/P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T
M96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T
M96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%V86EL
M86)L92!F:65L9',Z`$)I<G1H9&%Y`$-A;&5N9&%R`$-A;F-E;`!#86YC96P@
M4')O8FQE;2!297!O<G0`0V5L;"!0:&]N90!#;&EC:R!T;R!#;VYT:6YU90!#
M;&]S92!7:6YD;W<`0V]M<&%N>0!#;VYF:7)M(%!A<W-W;W)D`$-O;FYE8W1I
M;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]U;&0@;F]T
M(%!'4"!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!01U`@<VEG;B!M97-S
M86=E+@!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82X`0V]U;&0@;F]T(&1E
M=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD
M(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O
M=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$1$`$1A
M:6QY`$1E9F%U;'0@261E;G1I='D`1&5L971E`$1E<V-R:6)E('1H92!0<F]B
M;&5M`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T
M<F%T;W(N`$1I<W!L87D@3W!T:6]N<P!$;R!N;W0@9&ER96-T;'D@86-C97-S
M(&UA:6YT96YA;F-E+G!H<`!%9&ET`$5M86EL`$5M<'1Y(')E<W5L="X`17)R
M;W(`179E<GD@,34@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@
M;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN
M=71E`$5X86UP;&4@=F%L=65S.@!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E
M;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A>`!&
M:6QE($UA;F%G97(`1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7!S`$AE;'``
M2&]M92!!9&1R97-S`$AO;64@4&AO;F4`2&]R9&4`26UP;W)T960@9FEE;&0Z
M("5S`$EM<&]R=&5D(&9I96QD<SH`3&%N9W5A9V4`3&ES="!(96QP(%1O<&EC
M<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,;V<@:6X`3&]G(&]U=`!-
M30!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$UA:6P`
M36%T8VAI;F<@9FEE;&1S`$UE;6)E<G,`365S<V%G90!-:6UE(%1Y<&4`36]N
M=&AL>0!.3RP@22!$;R!.3U0@06=R964`3F%M90!.971W;W)K`$YE=F5R`$YO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@
M5D93+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;W1E<P!/<'1I;VYS
M`$]T:&5R($EN9F]R;6%T:6]N`%!A<W-W;W)D`%!A<W-W;W)D<R!M=7-T(&UA
M=&-H+@!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M
M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N<P!0
M97)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!0:&]N90!0;&5A<V4@<')O=FED
M92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO
M=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!R;V)L96T@1&5S8W)I<'1I;VX`
M4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F
M=6QL>2X`4F5A9`!296UO=F4`4F5M;W9E('!A:7(`4F5S970`4F5T=7)N('1O
M($]P=&EO;G,`4F]L90!3879E($]P=&EO;G,`4V5L96-T('1H92!D871E(&1E
M;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!T
M:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C
M="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA
M;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-H;W<`4VMI<"!-86EN=&5N
M86YC90!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3=6-C97-S`%1A<VMS`%1H
M92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L
M;'D`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W
M96(@8V]N;F5C=&EO;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O
M;F4N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&ET;&4`55),`%5N
M86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!T<F%N
M<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N9&\@0VAA;F=E<P!5<&1A=&4`
M57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<FYA;64`57-E
M<G,@:6X@=&AE('-Y<W1E;3H`5V%R;FEN9P!7965K;'D`5V5L8V]M92!T;R`E
M<P!796QC;VUE+"`E<P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!960!996%R
M;'D`665S+"!)($%G<F5E`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M
M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@
M;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S
M<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=7(@)7,@<V5S<VEO;B!H
M87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($EN9F]R;6%T
M:6]N`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P
M;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I
M<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!O<'1I;VYS(&AA
M=F4@8F5E;B!U<&1A=&5D+@!;4')O8FQE;2!297!O<G1=`%ML:6YE("5S(&]F
M("5S70!V0V%R9`!0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,"UC=G,*
M4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4
M+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I
M<VEO;BU$871E.B`R,#`R+3`V+3`X(#(R.C,P*S`Q,#`*3&%S="U4<F%N<VQA
M=&]R.B!097(M4W1I86X@5F%T;F4@/'!S=D!O<G-T82YO<F<^"DQA;F=U86=E
M+51E86TZ($YO<G=E9VEA;B!.>6YO<G-K(#QN>6YO<G-K0&]R<W1A+F]R9SX*
M34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C
M:&%R<V5T/6ES;RTX.#4Y+3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@
M.&)I=`H`)7,@+2!.;W1I<P`E<R!V961L:6ME:&%L9'-O<&5R87-J;VYA<B`M
M(%-T861F97-T:6YG`"5S(%9I;&OE<B!F;W(@879T86QE`#(T('1I;6%R`$%-
M+U!-`$QE9V<@=&EL`$QE9V<@=&EL(&YY(&)R=6MA<CH`3&5G9R!T:6P@<&%R
M`$QE9V<@=&EL(&)R=6MA<@!,96=G('1I;"!B<G5K87)A<B!E<B!S;.5T="!A
M=BX`061R97-S90!!9')E<W-E8F]K`$%D;6EN:7-T<F5R:6YG`$%L:6%S`$5I
M;B!U;&]V;&5G('9E<F1I('9A<G0@<W!E<VEF:7-E<G0N`%-P^'(@;VT@<W1A
M9&9E<W1I;F<@9OAR(&OX>7)I;F<@878@=F5D;&EK96AA;&1S;W!E<F%S:F]N
M87(_`%!R^'9D92#E('-L971T92!E:2!I:VMJ92UE:W-I<W1E<F%N9&4@9W)U
M<'!E+@!0<OAV9&4@Y2!S;&5T=&4@96EN(&EK:VIE+65K<VES=&5R86YD92!T
M:6QG86YG+@!0<OAV9&4@Y2!E;F1R92!E:6X@:6MK:F4M96MS:7-T97)A;F1E
M('1I;&=A;F<N`%1I;&=J96YG96QE9V4@9F5L=#H`0G5R<V1A9P!+86QE;F1E
M<@!!=F)R>70`079B<GET('!R;V)L96UR87!P;W)T`$UO8FEL=&5L969O;@!+
M;&EK:R!F;W(@Y2!H86QD92!F<F%M`$QU:VL@=FEN9&%U9V5T`$9I<FUA`%-T
M861F97-T('!A<W-O<F0`3W!P:V]P;&EN9R!M;W0@;V9F96YT;&5G(&[X:VME
M;'1E;F%R(&YE:W1A+@!+=6YN92!I:VMJ92!01U`M:V]D92!M96QD:6YG+@!+
M=6YN92!I:VMJ92!01U`M<VEG;F5R92!M96QD:6YG+@!+=6YN92!I:VMJ92!D
M96MO9&4@4$=0+61A=&$N`$MU;FYE(&EK:VIE(&%V9VIE<F4@;6]T=&%K87)E
M;B!S:2!E+7!O<W1A9')E<W-E+@!+=6YN92!I:VMJ92!S:V%F9F4@;V9F96YT
M;&5G(&[X:VME;"!F<N4@;OAK:V5L=&5N87)E;BX`2W5N;F4@:6MK:F4@;W!N
M92!-86EN=&5N86YC95]487-K+6UO9'5L96X@)7,`1$0`1&%G;&5G`%-T86YD
M87)D:61E;G1I=&5T`%-L971T90!3:VEL9')E('!R;V)L96UE=`!$971A;&IA
M<B!E<B!L;V=G82!F;W(@861M:6YI<W1R871O<F5N+@!6:7-I;F=S86QT97)N
M871I=@!):VMJ92!B<G5K(&UA:6YT96YA;F-E+G!H<"!D:7)E:W1E+@!%;F1R
M90!%+7!O<W0`5&]M="!R97-U;'1A="X`1F5I;`!+=F%R="`Q-2X@;6EN=71T
M`$MV87)T(#,P+B!S96MU;F0`2W9A<G0@-2X@;6EN=71T`$MV87(@:6YN;&]G
M9VEN9P!+=F%R(&AA;'9E('1I;64`2W9A<G0@;6EN=71T`$5K<V5M<&5L=F5R
M9&EA<CH`2W5N;F4@:6MK:F4@:&5N=&4@:6YN<W1I;&QI;F=A<@!+=6YN92!I
M:VMJ92!K;W!L92!T:6P@3$1!4"UT96YA<F5N+@!&86MS`$9I;&AA;F1S86UI
M;F<`1W)U<'!E861M:6YI<W1R97)I;F<`1W)U<'!E<@!(:F5L<`!!9')E<W-E
M+"!P<FEV870`5&5L969O;BP@<')I=F%T`$AO<F1E`$EM<&]R=&5R=&4@9F5L
M=#H@)7,`26UP;W)T97)T92!F96QT.@!3<'+E:P!6:7,@96UN92!F<N4@2&IE
M;'``3&ES=&EN9R!A=B!B<G5K87)A<B!E<B!S;.5T="!A=BX`3&]G9R!I;FX`
M3&]G9R!U=`!-30!-4RU43D5&+79E9&QE9V<@:6YN96AE;&1T(&EN9V5N(&1A
M=&$N`$4M<&]S=`!386US=F%R86YD92!F96QT`$UE9&QE;6UA<@!-96QD:6YG
M`$U)344M='EP90!-Y6YA9&QE9P!.14DL(&5G(&5R($E+2TI%('-A;60`3F%M
M;@!.971T=F5R:P!!;&1R:0!);F=E;B!K;VYF:6=U<F%S:F]N<VEN9F]R;6%S
M:F]N('-P97-I9FES97)T(&9O<B!344P@5D93+@!);F=E;B!G>6QD:6=E(%A-
M3"UD871A(')E='5R;F5R=`!.;W1A=&%R`$%L=&5R;F%T:78`06YN86X@:6YF
M;W)M87-J;VX`4&%S<V]R9`!087-S;W)D82!MY2!S86US=F%R92X`2_AY<B!V
M961L:6ME:&%L9'-O<&5R87-J;VYA<@!+^'ER('9E9&QI:V5H86QD<V]P97)A
M<VIO;F%R('9E9"!I;FYL;V=G:6YG/P!4:6QG86YG`%1I;&=A;F=S861M:6YI
M<W1R97)I;F<`5&5L969O;@!3:W)I=B!I;FX@96ET('-A;6%N9')A9R!A=B!P
M<F]B;&5M970N`%-K<FEV(&EN;B!D:71T(&)R=6MA<FYA;6X@;V<@<&%S<V]R
M9`!3:VEL9')I;F<@878@<')O8FQE;65T`$]F9F5N=&QE9R]P<FEV870@;OAK
M:V5L<&%R('9A<G0@:6MK:F4@9V5N97)E<G0N`$QE<P!&:F5R;@!&:F5R;B!P
M87(`3G5L;'-T:6QL`%1I;&)A:V4@=&EL(&%L=&5R;F%T:78`4F]L;&4`3&%G
M<F4@86QT97)N871I=@!696P@<VMI;&IE=&5I:VX@9F]R(&1A=&\Z`%9E;"!D
M871O9F]R;6%T.@!696P@=&ED<V9O<FUA=#H`5F5L('1O('-A;7-V87)A;F1E
M(&9E;'0N`%9E;"!F87)G97-K:F5M82X`5F5L(/AN<VMA('-P<N5K.@!396YD
M('!R;V)L96UR87!P;W)T`%9I<P!(;W!P(&]V97(@=F5D;&EK96AA;&0`26YN
M=&%S=&EN9R!A=B!S<&5S:6%L=&5I:VX`4W5K<V5S<P!/<'!GY79E<@!+;&%S
M<V$@36%I;G1E;F%N8V4Z.B!V87)T(&EK:VIE(&QA<W1A(&EN;@!+<GEP=&5R
M:6YG<V9U;FMS:F]N86YE(&MR978@96D@<VEK:V5R(&YE='1O<'!K;W!L:6YG
M+@!$971T92!T86QE="!MY2!V97)E(&UI;G-T(&5I;BX`1&5N;F4@=F5R9&EE
M;B!MY2!V97)E(&5I="!T86PN`%1I='1E;`!54DP`2V%N(&EK:VIE(&MO<&QE
M('1I;"!344PM=&5N87(N`$MA;B!I:VMJ92!O;7-E=&IE(&1E='1E(%=O<F0M
M9&]K=6UE;G1E="X`06YG<F4@96YD<FEN9V%R`$]P<&1A=&5R`$)R=6MA<F%D
M;6EN:7-T<F5R:6YG`$)R=6MA<F%L=&5R;F%T:78`0G)U:V%R;F%M;@!"<G5K
M87)A<B!I('-Y<W1E;65T.@#%='9A<FEN9P!+=F%R('9E:V4`5F5L:V]M96X@
M=&EL("5S`%9E;&MO;65N+"`E<P!!9')E<W-E+"!A<F)E:60`5&5L969O;BP@
M87)B96ED`,7%`,5R;&5G`$IA+"!E9R!E<B!S86UD`$1U(&WE('-K:6QD<F4@
M<')O8FQE;65T(&;X<B!D=2!K86X@<V5N9&4@<')O8FQE;7)A<'!O<G1E;BX`
M1'4@;>4@<W!E<VEF:7-E<F4@96ET(&)R=6MA<FYA;6X@Y2!F:F5R;F4N`$1U
M(&WE('-P97-I9FES97)E(&5I="!B<G5K87)N86UN(.4@;&5G9V4@=&EL+@#8
M:W1A(&1I("@E<RD@:&%R(&?E='0@=70@<.4@=&ED+B!,;V=G(&EN;B!PY2!N
M>71T+@!$:6X@:6YF;W)M87-J;VX`3&ES=&EN9R!A=B!B<G5K87)A<B!E<B!I
M:VMJ92!S=/AT=&$@878@8F%K<F4@875T96YT:7-E<FEN9RP@96QL97(@9G5N
M:W-J;VYE;B!H87(@878@96EN(&5L;&5R(&%N;F%N(&=R=6YN(&)L:71T('-L
MY71T(&%V+@!!;'1E<FYA=&EV82!D:6YE(&AA<B!B;&ET="!O<'!D871E<G1E
M+@!;4')O8FQE;7)A<'!O<G1=`%ML:6YJ92`E<R!A=B`E<UT`=D-A<F0`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M;V-A;&4O;FY?3D\O:&5L<"YX;6P`````````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#,S,C`@,3`U,34T,S,W-#$@,#(Q-#4T`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_>&UL('9E
M<G-I;VX](C$N,"(_/@H\(2TM("1(;W)D93H@:&]R9&4O;&]C86QE+VYN7TY/
M+VAE;'`N>&UL+'8@,2XR(#(P,#0O,#4O,C<@,C`Z,C(Z,3,@:F%N($5X<"`D
M("TM/@H\:&5L<#X*("`\96YT<GD@:60](G-U;6UA<GDB('-T871E/2)N97<B
M/@H\=&ET;&4^5&AE(%!O<G1A;"!086=E/"]T:71L93X*(#QP87)A/@H@(%1H
M:7,@<&]R=&%L('!A9V4@<')O=FED97,@82!Q=6EC:R!S=6UM87)Y(&]F(&%L
M;"!Y;W5R(&EM<&]R=&%N=`H@(&EN9F]R;6%T:6]N+B!&;W(@97AA;7!L92P@
M:70@;6EG:'0@<VAO=R!H;W<@;6%N>2!N97<@92UM86EL(&UE<W-A9V5S('EO
M=0H@(&AA=F4@:6X@>6]U<B!)3D)/6"P@=7!C;VUI;F<@979E;G1S(&]N('EO
M=7(@8V%L96YD87(L('1A<VMS(&]N('EO=7(@=&\M9&\*("!L:7-T+"!H96%D
M;&EN97,@9G)O;2!S96QE8W1E9"!N97=S('-E<G9I8V5S+"!A;F0@<V\@;VXN
M("!-86YY(&]F('1H97-E"B`@<W5M;6%R:65S('=I;&P@8V]N=&%I;B!Q=6EC
M:R!S:&]R=&-U=',@=&\@8V]M;6]N(&9U;F-T:6]N<RP@<W5C:"!A<PH@(&-O
M;7!O<VEN9R!A(&YE=R!M86EL(&UE<W-A9V4L(&-R96%T:6YG(&$@;F5W(&-A
M;&5N9&%R(&5V96YT(&]R('1A<VLL(&5T8RX*(#PO<&%R83X*(#QP87)A/@H@
M(%1H92!C;VYT96YT<R!O9B!T:&ES('!O<G1A;"!P86=E(&%R92!C=7-T;VUI
M>F%B;&4@=FEA('1H92!,87EO=70@8G5T=&]N+@H@($9O<B!E>&%M<&QE+"!Y
M;W4@8V%N(&-H;V]S92!W:&EC:"!I=&5M<R!T;R!I;F-L=61E(&]N('1H:7,@
M<&]R=&%L('!A9V4@87,*("!W96QL(&%S(&EN('=H:6-H(&]R9&5R('1H97D@
M87)E('-H;W=N+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB;F%V
M8F%R(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H92!!<'!L:6-A=&EO;B!.879I
M9V%T:6]N($)A<CPO=&ET;&4^"B`\<&%R83X*("!!="!T:&4@;&5F="!H86YD
M('-I9&4@;V8@=&AE('=E8B!P86=E(&ES('1H92!A<'!L:6-A=&EO;B!N879I
M9V%T:6]N(&)A<BX*("!#;&EC:R!O;B!T:&4@:6-O;G,@;VX@=&AI<R!N879I
M9V%T:6]N(&)A<B!T;R!Q=6EC:VQY(&%N9"!E87-I;'D@<W=I=&-H"B`@8F5T
M=V5E;B!T:&4@879A:6QA8FQE(&%P<&QI8V%T:6]N<RX*(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G!R969S+61O7VUA:6YT96YA;F-E(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z
M($1O($UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U
M('=O=6QD(&QI:V4@=&\@<&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS
M(&]N(&QO9VEN+"!C:&5C:R!T:&ES(&)O>"X*("`@(#PO<&%R83X*/"]E;G1R
M>3X*("`\96YT<GD@:60](G!R969S+6-O;F9I<FU?;6%I;G1E;F%N8V4B('-T
M871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC
M93H@0V]N9FER;2!-86EN=&5N86YC93PO=&ET;&4^"B`@("`\<&%R83X*("`@
M($EF('EO=2!W;W5L9"!L:6ME('1O(&-O;F9I<FT@86QL(&UA:6YT96YA;F-E
M('1A<VMS(&)E9F]R92!T:&5Y(&%R92!R=6XL(&-H96-K('1H:7,@8F]X+B!)
M9B!L969T('5N8VAE8VME9"P@86QL(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@
M=&AA="!N965D('1O(&)E(')U;B!W:6QL(&)E('!E<F9O<FUE9"!A=71O;6%T
M:6-A;&QY('=I=&@@;F\@8VAA;F-E('1O(&-A;F-E;"!O;B!L;V=I;BX*("`@
M(#PO<&%R83X*/"]E;G1R>3X*/"]H96QP/@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE
M+W!L7U!,````````````````````````````````````````````````````
M`````````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S0Q(#`Q-S<R-``@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L;V-A;&4O<&Q?4$PO3$-?34534T%'15,`````````````
M````````````````````````````````````````````````````````,#`P
M-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W-#$@
M,#(Q-3$Q`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]P;%]03"],0U]-
M15-304=%4R]H;W)D92YM;P``````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#$T
M,3`Q-2`Q,#4Q-30S,S<T,2`P,C,R,S``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````WA($E0````!!`P``'````"0:``!=!```
M+#0```````"@10``2````*%%```.````ZD4```\```#Y10``#0````E&```(
M````%T8```L````@1@``#````"Q&```;````.48``"T```!51@``)````(-&
M```I````J$8``!D```#21@``#````.Q&```+````^48``!$````%1P``#@``
M`!='```%````)D<``"@````L1P``"````%5'```*````7D<``!(```!I1P``
M#@```'Q'```*````BT<```T```"61P``#@```*1'```1````LT<```T```#%
M1P``#````--'```-````X$<```8```#N1P``#````/5'```.`````D@```X`
M```12```"````"!(```)````*4@``!H````S2```,@```$Y(```X````@4@`
M`%0```"Z2```40````])``!:````84D``%<```"\20``-````!1*```%````
M24H``!$```!/2@``"````&%*```0````:DH```\```![2@``"@```(M*```#
M````EDH```D```":2@``#0```*1*```2````LDH```\```#%2@``"@```-5*
M```/````X$H```@```#P2@``)````/E*```4````'DL``!8````S2P``"```
M`$I+```M````4TL``!D```"!2P``!P```)M+```,````HTL```X```"P2P``
M`P```+]+```+````PTL```<```#/2P``!P```-=+```%````WTL```,```#E
M2P``%P```.E+```*`````4P```\````,3```&````!Q,```.````-4P``!0`
M``!$3```%P```%E,```7````<4P``!<```")3```#P```*%,```?````L4P`
M``<```#13```!@```-E,```(````X$P```\```#I3```!@```/E,```*````
M`$T```L````+30``%0```!=-```'````+4T```4````U30``$0```#M-```,
M````34T```D```!:30``!P```&1-```%````;$T``#D```!R30``"@```*Q-
M```&````MTT```D```"^30``!P```,A-```O````T$T``"X`````3@``50``
M`"].```M````A4X``"T```"S3@``+0```.%.```C````#T\``",````S3P``
M+0```%=/```S````A4\``!4```"Y3P``&0```,]/```I````Z4\``"0````3
M4```$0```#A0```*````2E````P```!54```"@```&)0```0````;5```!8`
M``!^4```%@```)50```'````K%````<```"T4```%````+Q0```*````T5``
M``<```#<4```!P```.10```&````[%````4```#S4```!P```/E0```&````
M`5$```@````(40``#@```!%1```*````(%$```<````K40``"0```#-1```6
M````/5$```0```!440``!@```%E1```(````8%$```,```!I40```P```&U1
M```3````<5$```@```"%40``"````(Y1```(````EU$``$$```"@40``(```
M`.)1```&`````U(```8````*4@``%0```!%2```8````)U(``"(```!`4@``
M'0```&-2```*````@5(``!4```",4@``"@```*)2```/````K5(```\```"]
M4@``"0```,U2```4````UU(``!@```#L4@``'0````53```3````(U,``!$`
M```W4P``!````$E3```&````3E,``%0```!54P``#@```*I3``!$````N5,`
M``4```#^4P``!0````14```1````"E0``!$````<5```'````"Y4```0````
M2U0``!$```!<5```#````&Y4```7````>U0``!````"35```"````*14```%
M````K50```P```"S5```$````,!4```-````T50```<```#?5```#0```.=4
M```'````]50```<```#]5```!P````55```4````#54```D````B50``"@``
M`"Q5```,````-U4``!````!$50``!0```%55```E````6U4``!(```"!50``
M$P```)15```K````J%4``#L```#450``(````!!6```V````,58``!````!H
M5@``"````'E6```,````@E8```0```"/5@``#@```)16```>````HU8``!L`
M``#"5@``(0```-Y6```>`````%<``!X````?5P``+@```#Y7```;````;5<`
M`!X```")5P``,P```*A7```O````W%<``"`````,6```$@```"U8```I````
M0%@``!X```!J6```%@```(E8``!!````H%@```<```#B6```!@```.I8```-
M````\5@``!````#_6```$@```!!9```'````(UD```0````K60``#````#!9
M```H````/5D```,```!F60``!@```&I9```.````<5D```(```"`60``!0``
M`(-9```$````B5D```X```".60``"````)U9```-````IED``!````"T60``
M$P```,59```3````V5D```8```#M60``#````/19```1`````5H``!D````3
M6@``"P```"U:```-````.5H``!L```!'6@``-````&-:```*````F%H``!@`
M``"C6@``&0```+Q:```6````UEH``"\```#M6@``!P```!U;```4````)5L`
M`"\````Z6P``"0```&I;```6````=%L```\```"+6P``"````)M;```-````
MI%L``"8```"R6P``"````-E;```2````XEL```@```#U6P``"P```/Y;```%
M````"EP```8````07```!P```!=<```$````'UP```H````D7```#P```"]<
M```0````/UP``!<```!07```$0```&A<```7````>EP```4```"27```"P``
M`)A<```%````I%P```T```"J7```&P```+A<```)````U%P```X```#>7```
M#0```.U<```@````^UP``!$````<70``!P```"Y=```%````-ET``!,````\
M70``!P```%!=```(````6%T```8```!A70``$````&A=```/````>5T``!``
M``")70``#P```)I=```+````JET```\```"V70``#````,9=```/````TUT`
M``<```#C70``!@```.M=```.````\ET``"$````!7@``&0```"->```7````
M/5X``!<```!57@``&P```&U>```-````B5X```P```"77@```P```*1>```(
M````J%X```0```"Q7@``#````+9>```)````PUX```X```#-7@``"P```-Q>
M```;````Z%X```<````$7P``!P````Q?```$````%%\``!4````97P``!@``
M`"]?```-````-E\``!````!$7P``&P```%5?```$````<5\```4```!V7P``
M!@```'Q?```'````@U\```4```"+7P``"0```)%?```"````FU\```T```">
M7P``!@```*Q?```)````LU\```<```"]7P``!@```,5?```*````S%\```0`
M``#77P``"0```-Q?```(````YE\```8```#O7P``#0```/9?```&````!&``
M``0````+8```!0```!!@```A````%F````0````X8```!````#U@```%````
M0F```!T```!(8```!````&9@```,````:V````H```!X8```"````(-@```)
M````C&````4```"68```*0```)Q@```'````QF````<```#.8```"@```-9@
M```/````X6```!````#Q8```!@````)A```2````"6$``!`````<80``!0``
M`"UA```)````,V$```0````]80``#````$)A```7````3V$``!P```!G80``
M$P```(1A```4````F&$``!D```"M80``!````,=A```'````S&$```8```#4
M80``!@```-MA```%````XF$```<```#H80``!P```/!A```%````^&$```8`
M``#^80``!`````5B```$````"F(```H````/8@``!0```!IB```,````(&(`
M``\````M8@``"@```#UB```(````2&(``"L```!18@``!````'UB```(````
M@F(``"8```"+8@``$@```+)B```&````Q6(```H```#,8@``!P```-=B```(
M````WV(``"````#H8@``#@````EC```6````&&,``!$````O8P``!@```$%C
M```'````2&,```<```!08P``%@```%AC```-````;V,``!````!]8P``&@``
M`(YC```)````J6,```H```"S8P``#````+YC```/````RV,```8```#;8P``
M!P```.)C```+````ZF,``$<```#V8P``#0```#YD```#````3&0```H```!0
M9````@```%MD```$````7F0```,```!C9```!0```&=D```J````;60```H`
M``"89```!````*-D```&````J&0```@```"O9```"````+AD```$````P60`
M``4```#&9```:````,QD```%````-64```8````[90``$````$)E```*````
M4V4```\```!>90``"@```&YE```)````>64```,```"#90``!P```(=E```*
M````CV4```L```":90``!P```*9E```:````KF4``$H```#)90``!@```!1F
M```)````&V8```T````E9@``"@```#-F```'````/F8``!0```!&9@``!@``
M`%MF```(````8F8```<```!K9@``"@```'-F```+````?F8```<```"*9@``
M"0```))F```)````G&8```H```"F9@``!P```+%F```)````N68```<```##
M9@``"@```,MF```*````UF8```D```#A9@``!P```.MF```$````\V8```<`
M``#X9@``!0````!G```%````!F<```L````,9P``%````!AG```'````+6<`
M``4````U9P``#0```#MG```,````26<```L```!69P``!````&)G```$````
M9V<```P```!L9P``"0```'EG```%````@V<```<```")9P``!````)%G```*
M````EF<``"X```"A9P``$````-!G```M````X6<``"T````/:```,0```#UH
M```M````;V@``"X```"=:```+P```,QH```L````_&@```0````I:0``#@``
M`"YI```&````/6D``!````!$:0``!P```%5I```.````76D```4```!L:0``
M!@```')I```(````>6D``!$```"":0``#@```)1I```"````HVD```<```"F
M:0``!@```*YI```$````M6D``!\```"Z:0``%````-II```'````[VD```X`
M``#W:0``#`````9J```3````$VH```H````G:@``!0```#)J```1````.&H`
M`!$```!*:@``)````%QJ```5````@6H``!(```"7:@``#@```*IJ```9````
MN6H```@```#3:@``"0```-QJ```*````YFH```@```#Q:@``!0```/IJ```&
M`````&L``!`````':P``"````!AK```(````(6L``!(````J:P``&@```#UK
M```)````6&L```H```!B:P``%0```&UK```%````@VL``!0```"):P``'@``
M`)YK```H````O6L```H```#F:P``#P```/%K```4`````6P```0````6;```
M"P```!ML```%````)VP```@````M;```-````#9L```T````:VP``"````"@
M;```&@```,%L```H````W&P``"D````%;0``!@```"]M```(````-FT```<`
M```_;0``"P```$=M```'````4VT``!,```!;;0``"@```&]M```4````>FT`
M``\```"/;0``,@```)]M```+````TFT```4```#>;0``!0```.1M```7````
MZFT``!X````";@``%````"%N```.````-FX```8```!%;@``#````$QN```-
M````66X```L```!G;@``"@```'-N```+````?FX```\```"*;@``!0```)IN
M```.````H&X``!,```"O;@``!P```,-N```1````RVX```<```#=;@``&```
M`.5N```$````_FX```<````#;P``"@````MO```+````%F\```P````B;P``
M#@```"]O```2````/F\```8```!1;P``&````%AO```E````<6\```D```"7
M;P```P```*%O```*````I6\```P```"P;P``%0```+UO```+````TV\``!D`
M``#?;P``(````/EO```%````&G````H````@<```#````"MP```$````.'``
M``D````]<```!P```$=P```,````3W````8```!<<```#````&-P```:````
M<'```!<```"+<```)P```*-P```:````RW```!<```#F<```&P```/YP```9
M````&G$``!\````T<0``$P```%1Q```'````:'$```D```!P<0``#0```'IQ
M```#````B'$``#\```",<0``-P```,QQ``!7````!'(```4```!<<@``"@``
M`&)R```-````;7(```0```![<@``)0```(!R```=````IG(```P```#$<@``
M&0```-%R```)````ZW(``!,```#U<@``"0````ES```$````$W,``!`````8
M<P``"````"ES```(````,G,```\````[<P``!P```$MS```,````4W,``!L`
M``!@<P``+````'QS```%````J7,```0```"O<P``%P```+1S```*````S',`
M``P```#7<P``"0```.1S```)````[G,``!$```#X<P``!@````IT```.````
M$70```<````@=```!@```"AT```'````+W0``"8````W=```.````%YT```:
M````EW0``"H```"R=```&0```-UT```%````]W0```X```#]=```"`````QU
M```)````%74```8````?=0``"P```"9U```4````,G4```8```!'=0``&0``
M`$YU```*````:'4``!P```!S=0``!0```)!U```0````EG4```D```"G=0``
M"````+%U```?````NG4``",```#:=0``(0```/YU```?````('8``"<```!`
M=@``'P```&AV```Q````B'8``$$```"Z=@``,P```/QV```E````,'<``"\`
M``!6=P``,````(9W```O````MW<``"P```#G=P``%P```!1X```B````+'@`
M`$4```!/>```,````)5X```$````QG@```L```#+>```!0```-=X```"````
MW7@``%D```#@>```!0```#IY```$````0'D```<```!%>0``"````$UY```%
M````5GD``!,```!<>0``#0```'!Y```'````?GD```8```"&>0``%````(UY
M```,````HGD```8```"O>0```P```+9Y```$````NGD```8```"_>0``!P``
M`,9Y```7````SGD``"````#F>0``&@````=Z```F````(GH```P```!)>@``
M%````%9Z```.````:WH```T```!Z>@``!P```(AZ```'````D'H``!4```"8
M>@``!@```*YZ```&````M7H```<```"\>@``#````,1Z```1````T7H```@`
M``#C>@``'0```.QZ```)````"GL```H````4>P``%````!][```*````-'L`
M``@````_>P``!P```$A[```)````4'L```<```!:>P``"````&)[```'````
M:WL``!D```!S>P``"@```(U[```7````F'L``!0```"P>P``$0```,5[```'
M````UWL```,```#?>P``!@```.-[```'````ZGL```T```#R>P``"P````!\
M```4````#'P``!4````A?```#@```#=\```O````1GP``#$```!V?```/P``
M`*A\```,````Z'P```H```#U?````@````!]```$`````WT```8````(?0``
M!0````]]```#````%7T```P````9?0``&0```"9]``!%````0'T``"8```"&
M?0``)0```*U]```2````TWT``!,```#F?0``$````/I]``!Y````"WX```D`
M``"%?@``<@```(]^``!S`````G\``!<```!V?P``%@```(Y_```/````I7\`
M`!\```"U?P``0````-5_```?````%H```!0````V@```"@```$N````%````
M5H````8```!<@```"````&.````0````;(````\```!]@```!````(V````+
M````DH````<```">@```!0```*:````'````K(````@```"T@```#P```+V`
M```(````S8````P```#6@```#P```..````&````\X````8```#Z@```#```
M``&!```(````#H$```0````7@0``!````!R!```'````(8$```<````I@0``
M!0```#&!``!3`0``-X$``$,```"+@@``#@```,^"```2````WH(``!$```#Q
M@@``!P````.#```(````"X,```H````4@P``(@```!^#```O````0H,``!T`
M``!R@P``(@```)"#```>````LX,```H```#2@P``"@```-V#```0````Z(,`
M``\```#Y@P``!0````F$```G````#X0```\````WA```#@```$>$```0````
M5H0``!````!GA```"````'B$```1````@80```T```"3A```$P```*&$```,
M````M80```L```#"A```#@```,Z$```&````W80```T```#DA```$@```/*$
M```2````!84```@````8A0``"@```"&%```7````+(4``#\```!$A0``2```
M`(2%``!<````S84``%D````JA@``8@```(2&``!?````YX8``$$```!'AP``
M!0```(F'```.````CX<```X```">AP``#@```*V'```2````O(<```4```#/
MAP``!0```-6'```,````VX<``!````#HAP``%@```/F'```9````$(@```T`
M```JB```%0```#B(```*````3H@``!X```!9B```&P```'B(```@````E(@`
M`!$```"UB```+0```,>(```F````]8@```4````<B0``$````"*)```-````
M,XD```<```!!B0``"@```$F)```'````5(D```@```!<B0``!0```&6)```(
M````:XD``",```!TB0``#P```)B)```5````J(D``!<```"^B0``#````-:)
M```7````XXD``!<```#[B0``(P```!.*```8````-XH``!,```!0B@``)0``
M`&2*```&````BHH```8```"1B@``"````)B*```/````H8H```D```"QB@``
M"@```+N*```)````QHH``!````#0B@``"0```.&*```(````ZXH``!$```#T
MB@``#@````:+```)````%8L```<````?BP``!0```">+```]````+8L```@`
M``!KBP``"````'2+```)````?8L```<```"'BP``.````(^+```X````R(L`
M`%L````!C```-P```%V,```W````E8P``#<```#-C```+@````6-```R````
M-(T``#<```!GC0``/0```)^-```A````W8T``"4```#_C0``+P```"6.```Q
M````58X```X```"'C@``"P```):.```,````HHX```,```"OC@``"0```+..
M```4````O8X``!\```#2C@``#````/*.```'````_XX``!8````'CP``"@``
M`!Z/```(````*8\```8````RCP``!@```#F/```%````0(\```<```!&CP``
M!@```$Z/```.````58\``!````!DCP``"0```'6/```'````?X\```@```"'
MCP``%````)"/```#````I8\```@```"ICP``"````+*/```#````NX\```,`
M``"_CP``&P```,./```)````WX\```@```#ICP``!P```/*/``!/````^H\`
M`"T```!*D```!@```'B0```&````?Y```!D```"&D```'0```*"0```L````
MOI```"````#KD```&0````R1```6````)I$```D````]D0``$P```$>1```3
M````6Y$```D```!OD0``%@```'F1```:````D)$``!\```"KD0``%0```,N1
M```6````X9$```0```#XD0``!0```/V1``!&`````Y(```\```!*D@``,P``
M`%J2```%````CI(```4```"4D@``"P```)J2```7````II(``"````"^D@``
M%P```-^2```6````]Y(```P````.DP``&0```!N3```-````-9,```@```!#
MDP``!0```$R3```-````4I,```P```!@DP``#0```&V3```'````>Y,```<`
M``"#DP``"0```(N3```&````E9,```4```"<DP``%0```**3```)````N),`
M``<```#"DP``#@```,J3```/````V9,```4```#IDP``'0```.^3```<````
M#90``!T````JE```+````$B4```[````=90``"D```"QE```/@```-N4```.
M````&I4```@````IE0``"P```#*5```'````/I4```T```!&E0``*P```%25
M```H````@)4``"X```"IE0``*P```-B5```J````!)8``#D````OE@``)0``
M`&F6```H````CY8``"T```"XE@``,P```.:6```F````&I<``!8```!!EP``
M+0```%B7```@````AI<``"(```"GEP``10```,J7```$````$)@```8````5
MF```"P```!R8```+````*)@``!8````TF```"0```$N8```$````59@```L`
M``!:F```-P```&:8```&````GI@```0```"EF```#P```*J8```"````NI@`
M``H```"]F```!````,B8```-````S9@```@```#;F```#@```.28```2````
M\Y@``!0````&F0``%````!N9```$````,)D```H````UF0``$````$"9```9
M````49D```P```!KF0``#````'B9```;````A9D``#H```"AF0``"P```-R9
M```8````Z)D``!4````!F@``%````!>:```T````+)H```4```!AF@``#0``
M`&>:```P````=9H```<```"FF@``)@```*Z:```2````U9H```<```#HF@``
M"0```/":```N````^IH``!T````IFP``(P```$>;```(````:YL```L```!T
MFP``"0```(";```&````BIL```<```"1FP``!@```)F;```*````H)L``!$`
M``"KFP``$0```+V;```8````SYL``!4```#HFP``&````/Z;```%````%YP`
M``@````=G```!0```":<```+````+)P``"4````XG```"0```%Z<```0````
M:)P``!````!YG```-@```(J<```0````P9P```<```#2G```!````-J<```7
M````WYP```<```#WG```!P```/^<```&````!YT``!$````.G0``$0```""=
M```2````,IT``!````!%G0``%````%:=```4````:YT```\```"`G0``%0``
M`)"=```'````IIT```8```"NG0``#````+6=```J````PIT``!\```#MG0``
M(`````V>```B````+IX``!,```!1G@``"P```&6>```0````<9X```0```""
MG@``!````(>>```%````C)X```\```"2G@``"P```**>```+````KIX```\`
M``"ZG@``)@```,J>```&````\9X```D```#XG@``"`````*?```2````"Y\`
M``<````>GP``$````":?```3````-Y\``"X```!+GP```@```'J?```%````
M?9\```8```"#GP``!@```(J?```%````D9\```D```"7GP```P```*&?```3
M````I9\```8```"YGP``"@```,"?```'````RY\``!````#3GP``"0```.2?
M```$````[I\```D```#SGP``"````/V?```&````!J````T````-H```!@``
M`!N@```$````(J````4````GH```%P```"V@```%````1:````8```!+H```
M!@```%*@```<````6:````@```!VH```#````'^@```)````C*````@```"6
MH```"````)^@```%````J*```"4```"NH```!0```-2@```(````VJ````L`
M``#CH```#P```.^@```1````_Z````<````1H0``%````!FA```1````+J$`
M``4```!`H0``"0```$:A```$````4*$```T```!5H0``&P```&.A```=````
M?Z$``!H```"=H0``'0```+BA```$````UJ$```0```#;H0``"````."A```&
M````Z:$```<```#PH0``!@```/BA```'````_Z$```<````'H@``!P````^B
M```&````%Z(```8````>H@``"````"6B```*````+J(```4````YH@``$```
M`#^B```-````4*(```X```!>H@``"@```&VB```Q````>*(```8```"JH@``
M"````+&B```H````NJ(```\```#CH@``!@```/.B```)````^J(```L````$
MHP``!0```!"C```$````%J,``!8````;HP``&P```#*C```9````3J,```4`
M``!HHP``!P```&ZC```'````=J,```4```!^HP``#0```(2C```6````DJ,`
M`"<```"IHP``!0```-&C```,````UZ,```X```#DHP``&0```/.C```'````
M#:0```<````5I```%@```!VD``!7````-*0``!L```",I```!0```*BD```*
M````KJ0```(```"YI```!````+RD```#````P:0```4```#%I```"0```,ND
M```*````U:0```8```#@I```!@```.>D```'````[J0```@```#VI```!```
M`/^D```%````!*4``%L````*I0``!@```&:E```(````;:4```\```!VI0``
M"0```(:E```-````D*4```H```">I0``"0```*FE```#````LZ4```<```"W
MI0``"@```+^E```.````RJ4```D```#9I0``'P```..E``!:`````Z8```8`
M``!>I@``"````&6F```4````;J8```H```"#I@``"````(ZF```2````EZ8`
M``8```"JI@``"````+&F```*````NJ8```H```#%I@``#0```-"F```&````
MWJ8```T```#EI@``#@```/.F```/`````J<```X````2IP``#@```"&G```.
M````,*<```@````_IP``!0```$BG```*````3J<```4```!9IP``"````%^G
M```'````:*<```4```!PIP``!0```':G```(````?*<``!,```"%IP``!```
M`)FG```%````GJ<```X```"DIP``#@```+.G```-````PJ<```H```#0IP``
M"````-NG```.````Y*<```D```#SIP``!0```/VG```'`````Z@```0````+
MJ```"@```!"H```9````&Z@``!`````UJ```*P```$:H```K````<J@``"\`
M``">J```*P```,ZH```L````^J@``"T````GJ0``*@```%6I```%````@*D`
M``<```"&J0``"````(ZI```5````EZD```P```"MJ0``#@```+JI```%````
MR:D```4```#/J0``"````-6I```-````WJD```X```#LJ0```@```/NI```+
M````_JD```4````*J@``!````!"J```G````%:H``!0````]J@``!0```%*J
M```(````6*H```L```!AJ@``%P```&VJ```+````A:H```0```"1J@``#P``
M`):J```0````IJH``"<```"WJ@``$@```-^J```:````\JH``!,````-JP``
M+````"&K```'````3JL```L```!6JP``#````&*K```(````;ZL```4```!X
MJP``!@```'ZK```1````A:L```@```"7JP``!0```*"K```3````IJL``!8`
M``"ZJP``!@```-&K```'````V*L``!,```#@JP``!0```/2K```0````^JL`
M`!H````+K```+0```":L```+````5*P```\```!@K```$P```'"L```$````
MA*P```@```")K```!P```)*L```(````FJP``"0```"CK```(````,BL```?
M````Z:P``!L````)K0``%@```"6M```F````/*T```8```!CK0``"@```&JM
M```'````=:T```X```!]K0``!P```(RM```-````E*T```\```"BK0``&P``
M`+*M```>````SJT``#H```#MK0``"0```"BN```%````,JX```D````XK@``
M'@```$*N```A````8:X``!8```"#K@``#@```)JN```$````J:X```D```"N
MK@``#````+BN```)````Q:X```0```#/K@``$````-2N```6````Y:X```4`
M``#\K@``#0````*O```3````$*\```8````DKP``#P```"NO```'````.Z\`
M`!D```!#KP``"@```%VO```'````:*\``!(```!PKP``#````(.O```-````
MD*\``!P```">KP``!0```+NO```&````P:\``!T```#(KP``*````.:O```+
M````#[````,````;L```#````!^P```-````++```!,````ZL```"P```$ZP
M```7````6K```!D```!RL```!0```(RP```*````DK```!````"=L```!@``
M`*ZP```+````M;````D```#!L```#````,NP```&````V+````T```#?L```
M&P```.VP```4````";$``!P````>L0``&P```#NQ```5````5[$``!H```!M
ML0``&````(BQ```?````H;$``!D```#!L0``!P```-NQ```(````X[$```T`
M``#LL0``!0```/JQ```^`````+(``#4````_L@``5@```'6R```,````S+(`
M``@```#9L@``"P```.*R```%````[K(``#,```#TL@``%P```"BS```,````
M0+,``#````!-LP``!@```'ZS```0````A;,```@```"6LP``"````)^S```8
M````J+,```@```#!LP``"````,JS```.````T[,```<```#BLP``$0```.JS
M```A````_+,``!(````>M```"0```#&T```$````.[0``!D```!`M```#P``
M`%JT```/````:K0```X```!ZM```"0```(FT```4````D[0```8```"HM```
M#````*^T```%````O+0```8```#"M```"@```,FT```@````U+0``"````#U
MM```%@```!:U```@````+;4``!D```!.M0``!0```&BU```4````;K4```<`
M``"#M0``!0```(NU```'````D;4```H```"9M0``!0```*2U```&````JK4`
M``8```"QM0``"P```+BU```(````Q+4```<```#-M0``#@```-6U```+````
MY+4```D```#PM0``)````/JU```@````'[8``!P```!`M@``'````%VV```C
M````>K8``"````">M@``,P```+^V``!'````\[8``"X````[MP``+````&JW
M```X````E[<``#,```#0MP``*@````2X```J````+[@``!8```!:N```(0``
M`'&X``!"````D[@``#@```#6N```!`````^Y```,````%+D```4````AN0``
M`@```">Y``!>````*KD```0```")N0``!````(ZY```'````D[D```4```";
MN0``!0```*&Y```1````I[D``!````"YN0``!P```,JY```&````TKD``!0`
M``#9N0``#````.ZY```&````^[D```,````"N@``!`````:Z```&````"[H`
M``<````2N@``&@```!JZ```I````-;H``",```!?N@``+0```(.Z```-````
ML;H``!P```"_N@``#P```-RZ```#````[+H```@```#PN@``"0```/FZ```;
M`````[L```H````?NP``!P```"J[```'````,KL``!$````ZNP``%P```$R[
M```1````9+L``"8```!VNP``$@```)V[```3````L+L``!<```#$NP``"@``
M`-R[```'````Y[L```<```#ONP``"0```/>[```&`````;P```<````(O```
M"````!"\```0````&;P```T````JO```&@```#B\```D````4[P```\```!X
MO```"P```(B\```#````E+P```H```"8O```!@```*.\```+````JKP```H`
M``"VO```%0```,&\```6````U[P``!````#NO```,P```/^\```W````,[T`
M`$\```!KO0``#@```+N]```-````RKT```(```#8O0``!````-N]```&````
MX+T```4```#GO0```P```.V]```0````\;T``!`````"O@``)P```!.^```S
M````.[X``#(```!OO@``$0```**^```.````M+X``!````##O@``@0```-2^
M```*````5K\``%T```!AOP``7@```+^_```<````'L```!,````[P```'```
M`$_````@````;,```$````"-P```)@```,[````5````]<````H````+P0``
M!````!;!```&````&\$```@````BP0``%````"O!```.````0,$```0```!/
MP0``#````%3!```&````8<$```8```!HP0``"````&_!```(````>,$```T`
M``"!P0``!@```(_!```,````EL$```P```"CP0``#0```+#!```,````OL$`
M`!````#+P0``"0```-S!```$````YL$```@```#KP0``"````/3!```)````
M_<$```4````'P@```0```*H``````````````%@`````````O`$```````#:
M````"@```&@````T`P``G`(``!(````^`@``PP$``)4```"5`0```````$<!
M``!-`0````````````"R`@``P0(``!4```!#`@``R@$``,8```!P````;P$`
M`%T"```*`P``EP(```````"9``````````````!?````\0```$8"````````
M,`$``&4!``#3`@```````,L!````````I0```)8```!<````A0(```T!``"V
M`@````````````!V````!`(```````"O````_`(```````"0````S0```'(!
M``#5`````````+L````"`@``N`(````````1`````````,P"``!T````=0(`
M`(H````Z````X0$```4"``!>`````````#4````F`@```````"<#``"F`@``
M`@```"$#```#`P``Y````#8!````````=0`````````,`0``J`$``*L```#:
M`@``MP(``%\!``"V````8`$``"`#```C`P``J0```/0!````````'`$```\"
M````````]0$``!T#``!@`@``B0```*\!````````0@$``!("```U`P``$`,`
M`-\!````````T````$`!``!0`@``:@$```````#%````]P```%8!````````
M`````%$`````````9@`````````J`P``&0,``)`"````````6@```/L````4
M`0``^@$``,$``````````````*4"```[`0```````.X```#[`@``````````
M``"C`0``=P$`````````````Z@(``-@"````````Q@$``$\```!Z`0``````
M`%\"``!/`0````````````!O`@``10(``"@"``"?`@``P@$``#@#````````
M90````T"`````````````#8```!7`@```````%(````Z`P``4P(```````!`
M````_@$``#$```"L`@``:P$``/\"````````80````````!9`0``*@(`````
M``!D````!P$```````#[`0``*0$```````#I````-`(``/X"``"#`0``N`$`
M```````B`P``/@```!<"``#+````W0(``'H"`````````````,<"``#=`0``
M"@(``,<`````````?`````P#``#C`@``P@(``.(`````````:@````````"E
M`0``M@$```````#<`0``*0,``#T"``".`````````$L"````````QP$`````
M``"^`0``SP$``/4"``"A``````````````">`0``G@(``,D!``#6`````0$`
M``````#+`@``-0(``,X"``!(````&P(``'$``````````````"8!``"'`0``
M)0,````````M`@``H`(``*<!``````````````````!+`0``Z`$``$P````^
M`P```````$,!```%````OP```!H#``!.`0``````````````````8@(``+0`
M``"8````%@(``#\"```_`0``F@(``+`!``!M`````````$T```"$`0``:0(`
M`!0```#)`@`````````````Y`0```````'\!``#Z````H@$``'P!``#;````
MF0(`````````````=@$``'$"``#B`0``.P(``)D!````````'`(````````:
M`@``ZP$```````#S`@````````$"``"`````O0(``.L"``#S`0``UP(``!`"
M````````'0(``!$!``!%````[P(``*0````V`P``@@$``#("````````-P``
M`&X"``!(`@``&P,``.X"```P````_`$```8!````````\````#@`````````
MHP(``)T"``!8`0``1P```#D```#Q`@``+`(```````"[`@``*P```$$`````
M``````````D"````````D@$``````````````````/,```#T`@``UP$``(T`
M````````:P(``"T```#W`0``&@$``/D"``!4`@``)P$``$(```"+`@``$P$`
M`%("``!]````[0(`````````````$0,```````",````````````````````
M'P``````````````]0````0```#=````2P```&P"````````XP$```````!P
M`@``+`,``(D"````````4P$``#X!````````^0````@"``!.````G`$`````
M``!&`````````(L````7`P````````````#G`0```````'T"````````````
M`($```#(`@``O0``````````````N````"(```#G````8P$````````\````
MM0(``,@!``""`@``L`(``#(```"@`0``D@(```````"Y`0```````)T!``#>
M````&0(``"$`````````00,``+<```"Y`````````#$"``"8`0``,P``````
M``"M`0``SP```'8"``!6`@``%@,```````"(`@``````````````````!@(`
M``````![`@``1````%D"`````P``#P```"`"```N`@```````&<```!:`@``
M-P$```T```!/`@``,@,``"\```!8`@``K@`````````C`@``/`$```````#;
M`@````````<````*`0``)`$``(8"``#E`````````&D!``!*````>P$``.$`
M``"H````A@````````"Z````N@(``%P!```>`0``?@(```````#)````````
M`-0!````````'@```-X!````````ZP```),```"A`@``(P````````#1`0``
MT@`````````C`0```````(H"````````)0(``$`"``"4`@``"````$X"````
M````A0```$,```#$`0``V@$``'\````9````Y`$```0#``!,`0``$@$`````
M````````4`$``+P"````````UP````<#```S`0``DP(``#P#``#_`0``70``
M``,!```9`0``HP```)H```#&`@```````%$!```T````)P```"L"``"W`0``
MJ@$``!H````E````A0$``!`!``!F`@``,@$``*0!```.`@```````#T#````
M````1P(``)$`````````-P,``/("````````G@```/T!```.`0``+`$``$D`
M``!Z````.P,``-P```"$`@````````````##````E`````0!````````*0``
M`'D"``#L`0``B0$``+P```!O````&P``````````````\@$````````+`@``
M*P$``(T"``",`@``N@$```````#D`@``#@```.`!``!E`@``"P$``)<!``#;
M`0``(````-4!````````M0$``/X```!J`@``?@$``"8```"5`@``:0```/<"
M``#J`0```````!(#``!Q`0````````D!``!M`@``P`$``'P"``"2````L@``
M```````7`0``.@$````````,`@``S@```````````````````"T#````````
MK`$``*L!```+`````0,``#$!````````,`(``-`"``#Q`0```````#@"``#Z
M`@``V0(``"@#``#X`@``U``````!``#*``````````````"M````Y0$``(<"
M```6````"`$``',`````````*@$````````&`P``[`(```````"7````'`,`
M`*``````````]@````````#O````;`$```\!````````)`,``-@!````````
MZ0(``.```````````````````````````````!0#``!Y`````````-D```"(
M`0``\`$``+````!G`0``SP(``%T!```A`@````````````#``@```````#,#
M```3`P``S@$``*<"``!G`@``-`$````````>`P``J0(``)$"````````'P,`
M`'0!``!]`0``%0$```````#F````.`$``'<```"6`@``!0,``%D```!U`0``
MT`$``-$`````````.@(``',!`````````````,P!````````7@$``&$"``!5
M`0``[0```.<"```G`@``L@$``&X```!1`@``,0,``+\"````````9`(``!T!
M``#F`0``1`(``)P```"^````C0$``%4``````@```````*T"``!!`@``Y@(`
M`#4!```5`@``@0$``/T``````````````%4"`````````````.H```#C````
M=`(``-X"``!M`0``S0$``+,!``!*`@``0`,`````````````$0(``$P"``#!
M`0``+P(``````````````````!<````[````U0(``"D"```+`P``*`$``)T`
M````````X`(``,0```"#`@````````````!>`@``````````````````C@$`
M``````"O`@``!0$``"L#`````````````.D!````````>`(``.$"``!L````
MZ````(X"``!7````'@(``!\"``!@````6P(``%<!```J````<P(```````"!
M`@```````,4!``"T`@``DP$``'("``"6`0``'0```-("```8`@```````,T"
M``":`0``A@$```,`````````T0(``/8"`````````````"0```"G````A```
M``````!R````:P````,"```A`0``>P````````!)`@```````*(```"/`0``
MP````+,"``#(`````````$H!``!N`0``$P````\#````````4````)L!``"_
M`0``)0$``&@"```6`0``9@$``)$!```<````]@$``*X!``"?````FP``````
M``#3`0``(@(``(L!```4`@``/0````(#`````````````#\#````````M`$`
M`$8!```O`0``_0(``(P!``##`@``)@,``-,````8`0``6P```)L"``"J`@``
MCP```*X"````````I`(``-\"```N``````````````!A`0``D`$``&,"````
M````&````-D!``#6`@``6P$``+,```"H`@``9`$``"`!````````@`$``-(!
M````````=P(```T#``#8````L0(``#T!``#H`@``7`(``"\#``"U````[0$`
M`*$!````````X@(``````````````````+X"``!X`0````````X#````````
M-@(``+$!`````````````((```!!`0```````/@```!Y`0``P@```&(`````
M``````````````!4````O0$```````"B`@``\@```-\`````````[````#P"
M``!P`0``1`$``*P```"?`0``)`(```````!X`````````'X```!B`0``Q0(`
M``````#X`0``NP$`````````````$P(```````"8`@``6@$``!\!```B`0``
M&P$````````Y`@````````````!6````"`,``%0!```L````I@$``!4#````
M````^0$``(,````_``````````````"Y`@``30(``$4!`````````````(`"
M``"/`@```````)0!``#<`@``_````"X#``#T````,P(``$D!``!H`0``Q`(`
M`%,`````````4@$``(H!```0````?P(`````````````Y0(```````!"`@``
M!@```-8!``"K`@```````#D#```N`0```````(@`````````R@(``/\````H
M````U`(``````````````````.X!```)````AP````<"````````8P```/`"
M```)`P``2`$```P```"I`0```````#<"``"Q`````````,P````"`0``[P$`
M`#`#`````````````!@#```M`0``I@`````@)B,Q-3$[("5S(&ES(')E861Y
M('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME
M9"!B96QO=RX`("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I`"`H:6X@
M)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T97)D87DI`"(E
M<R(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO="!C;VYF:6=U
M<F5D(&EN('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!W87,@861D960@=&\@
M=&AE(&=R;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M
M:7-S:6]N<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`)60@
M)7,@86YD("5S`"5S("T@3F]T:6-E`"5S($%D;6EN:7-T<F%T:6]N`"5S($9I
M;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#
M;VYF:7)M871I;VX`)7,@4V5T=7``)7,@4VEG;B!5<``E<R!A;')E861Y(&5X
M:7-T<RX`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@9F]U;F0N
M`"5S('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L96YD
M87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"TM('-E;&5C
M="`M+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P`\
M4')E=FEO=7,`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@
M4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P
M=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@
M;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A
M9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U
M8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P
M=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S
M<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G
M92X`04TO4$T`06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06-C;W5N="!0
M87-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`061D($AE
M<F4Z`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&YE
M=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!
M9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1O(&%D
M9')E<W,@8F]O:SH`061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!
M9&1E9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RX`
M061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O
M:P!!9&UI;FES=')A=&EO;@!!9',`069G:&%N:7-T86X`06QB86YI80!!;&=E
M<FEA`$%L:6%S`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O
M=7!S`$%L;"!097)M:7-S:6]N<P!!;&QO=R!M=6QT:7!L92!A9&1R97-S97,`
M06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E
M($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N
M871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E>'0Z`$%N(&EL;&5G86P@
M=F%L=64@=V%S('-P96-I9FEE9"X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`
M06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%P<&QI8V%T:6]N
M`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!R;W9E`$%P<FEL`$%R8VAI=F4@
M1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!<F=E;G1I;F$`07)M96YI80!!<G5B
M80!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<S\`071T<FEB=71E<P!!=6=U<W0`075S=')A;&EA`$%U
M<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S
M=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S
M`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S`$%U=&A?;6-A
M;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M
M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"X`
M075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@
M)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`
M075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%V86EL86)L
M92!F:65L9',Z`$%Z97)B86EJ86X`0D]&2"!%>&-U<V5S`$)A8VMG<F]U;F0`
M0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K
M97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"86AR86EN`$)A;'1I8R`H25-/
M+3@X-3DM,3,I`$)A;F=L861E<V@`0F5L87)U<P!"96QG:75M`$)E;&EZ90!"
M96YI;@!"97)M=61A`$)H=71A;@!":7)T:&1A>0!";&]C:R!3971T:6YG<P!"
M;&]C:R!4>7!E`$)O;&EV:6$`0F]O:VUA<FMS`$)O<VYI82!A;F0@2&5R>F5G
M;W9I;F$`0F]T:`!"<F%Z:6P`0G5L9V%R:6$`0TU3`$-20P!#7V5L;"!0<F]P
M97)T:65S+BXN`$-A;&5N9&%R`$-A;6)O9&EA`$-A;65R;V]N`$-A;B!N;W0@
M<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S
M`$-A;F%D80!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;FYO="!D
M96QE=&4@9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E
M8W1O<GDN`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A<&4@5F5R
M9&4`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-E;&P@4&AO;F4`0V5L;"!0<F]P
M97)T:65S`$-E;&P@<')O<&5R=&EE<P!#96QL<&AO;F4`0V5L=&EC("A)4T\M
M.#@U.2TQ-"D`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@175R
M;W!E86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I;',`0V5R=&EF
M:6-A=&4@3W=N97(`0VAA9`!#:&%N9V4`0VAA;F=E('1H92!N86UE(&%N9"!A
M9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P
M;'D@=&\@>6]U<B!E;6%I;',N`$-H96-?:R!,:6YK+BXN`$-H96-K('1H92!B
M;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A
M="!T:&ES('1I;64N`$-H:6QE`$-H:6YA`$-H;V]S92!A('!A<W-W;W)D`$-H
M;V]S92!A('5S97)N86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`
M0VAR:7-T;6%S($ES;&%N9`!#;&EC:R!T;R!#;VYT:6YU90!#;&]S92!7:6YD
M;W<`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`0V]L;&%P<V4@4VED96)A<@!#
M;VQO;6)I80!#;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#
M;VQU;6X@=&ET;&5S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O
M;6]R;W,`0V]M<&%N>0!#;VUP;W-E($UE<W-A9V4@*"5S*0!#;VUP=71E<G,`
M0V]N9&ET:6]N<P!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYG
M;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE
M8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@
M<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R
M969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E
M<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C=',@
M=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN
M`$-O;G1E;G1S(&]F("(E<R(`0V]N=&EN=64`0V]O:R!)<VQA;F1S`$-O<'D`
M0V]P>2!S96QE8W1I;VX`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N
M`$-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%
M(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A
M9V4N`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@
M8V]N;F5C="!T;R!S97)V97(@(B5S(B!U<VEN9R!&5%`Z("5S`$-O=6QD(&YO
M="!D96-R>7!T(%!'4"!D871A+@!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@
M9&%T82X`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM
M86EL(&%D9')E<W,N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M
M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("(E<R(@9F]R('=R:71I
M;F<N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N
M86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@
M(B5S(BX`0V]U;&0@;F]T('5N;&EN:R`B)7,B+@!#;W5L9&XG="!F:6YD('1H
M92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O
M<&5N+@!#;W5N=')Y`$-R96%T90!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE
M=R!O;F4`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT
M(%1I;64`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S
M+@!#=70`0WEP<G5S`$-Z96-H(%)E<'5B;&EC`$1$`$1A:6QY`$1A=&4`1&5?
M;&5T92!#;VQU;6X`1&5C96UB97(`1&5F875L="!#;VQO<@!$969A=6QT($ED
M96YT:71Y`$1E9F%U;'0@4&5R;6ES<VEO;G,`1&5F875L="!P97)M:7-S:6]N
M<P!$96QE=&4`1&5L971E($=R;W5P`$1E;&5T92!097)M:7-S:6]N`$1E;&5T
M92!A;F0@<'5R9V4@;65S<V%G97,`1&5L971E(&-E;&P`1&5L971E(&-O;'5M
M;@!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(`1&5L971E('!E<FUI<W-I
M;VYS(&9O<B`B)7,B(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@
M<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E
M;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L971E('1H:7,@
M<&5R;6ES<VEO;B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5N;6%R:P!$
M97-C<FEB92!T:&4@4')O8FQE;0!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@
M9F]R('1H92!A9&UI;FES=')A=&]R+@!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH
M;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&II8F]U=&D`1&\@;F]T(&1E
M;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$
M;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]W;FQO860`1&]W;FQO860@
M)7,`1')U9W,`12U-86EL`$5C=6%D;W(`161I=`!%9&ET($=R;W5P`$5D:70@
M4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@
M9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R
M("5S`$5G>7!T`$5L(%-A;'9A9&]R`$5M86EL`$5M86EL($%D9')E<W,`16UA
M:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M;W1I8V]N<P!%;7!T>2!M97-S
M86=E+@!%;7!T>2!R97-U;'0N`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT
M(&UE;G4_`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R96$`17)R;W(`17)R;W(@
M=W)I=&EN9R`B)7,B+@!%<W1O;FEA`$5T:&EO<&EA`$5U<F]P90!%=F5R>2`Q
M-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V
M97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E
M<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A
M;F0@4VED96)A<@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`
M1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B
M)7,B+@!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&86QK;&%N9"!)<VQA;F1S
M("A-86QV:6YA<RD`1F%R;V4@27-L86YD<P!&871A;"!%<G)O<CH`1F%X`$9E
M8G)U87)Y`$9I:FD`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C
M=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`
M1FEL=&5R<P!&:6YL86YD`$9O;V0`1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9R
M86YC90!&<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O
M=71H97)N(%1E<G)I=&]R:65S`$9R;VT`1V%B;VX`1V%M8FEA`$=E<FUA;GD`
M1VAA;F$`1VEB<F%L=&%R`$=O`$=O;V=L92!396%R8V@`1W)E96-E`$=R965N
M;&%N9`!'<F5N861A`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA
M`$=U97)N<V5Y`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$AA
M:71I`$AE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<P!(96QP`$AI
M9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M90!(
M;VUE($%D9')E<W,`2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`2&]R
M9&4`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`
M2'5N9V%R>0!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@=VET:"!T97AT`$ED
M96YT:71Y)W,@;F%M93H`26UA9V5S`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O
M<G1E9"!F:65L9',Z`$EN9&EA`$EN9&]N97-I80!);F9O`$EN<V5R="!);6%G
M90!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T:6]N
M(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI9"!L:6-E;G-E
M(&ME>2X`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`
M27-R865L`$ES<W5E<@!)=&%L>0!*86UA:6-A`$IA;G5A<GD`2F%P86X`2F]R
M9&%N`$IU;'D`2G5N90!+87IA:VAS=&%N`$ME;GEA`$ME>2!#<F5A=&EO;@!+
M97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+97D@86QR96%D
M>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$MI9',`2VER:6)A
M=&D`2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R
M96$L(%)E<'5B;&EC(&]F`$MU=V%I=`!+>7)G>7IS=&%N`$QA7WEO=70`3&%N
M9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!L
M;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.
M979E<@!,871V:6$`3&5S;W1H;P!,:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H
M:7)I>6$`3&EE8VAT96YS=&5I;@!,:7-T($AE;'`@5&]P:6-S`$QI<W1I;F<@
M=7-E<G,@:7,@9&ES86)L960N`$QI=&AU86YI80!,;V%D:6YG+BXN`$QO8V%L
M('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]G(&EN`$QO9R!O=70`3&]G:6X@
M5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P
M87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D
M+@!,;W<`3'5X96UB;W5R9P!-30!-3U1$`$U31P!-86-A;P!-86-E9&]N:6$L
M(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-
M86EL`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA;F%G
M92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET
M96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A
M=&5G;W)I97,N`$UA<F-H`$UA<F=I;@!-87)S:&%L;"!)<VQA;F1S`$UA<G1I
M;FEQ=64`36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET:75S`$UA
M>0!-87EO='1E`$UE;G4@;6]D93H`365R9V4@8V5L;',`365S<V%G90!-971A
M<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA
M8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES
M=')A=&]R+@!-97AI8V\`36EM92!4>7!E`$UO9&EF:65D($1A=&4`36]D:69Y
M(%523`!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYG
M;VQI80!-;VYT:&QY`$UO;G1S97)R870`36]O;B!0:&%S97,`36]R;V-C;P!-
M;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O
M=VX`36]V92!U<`!-;WIA;6)I<75E`$UY($%C8V]U;G0`37D@4&]R=&%L`$UY
M86YM87(`3F%M90!.86UI8FEA`$YA=7)U`$YE<&%L`$YE=&AE<FQA;F1S`$YE
M=&AE<FQA;F1S($%N=&EL;&5S`$YE='=O<FL`3F5V97(`3F5W($-A;&5D;VYI
M80!.97<@0V%T96=O<GD`3F5W(%IE86QA;F0`3F5W<P!.97AT`$YE>'0@;W!T
M:6]N<P!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:75E`$YO(&-H86YG92X`
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S
M+@!.;R!F:6QE('5P;&]A9&5D`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(
M5%10(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M24U!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@3$1!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;VYE`$YO<F9O;&L@
M27-L86YD`$YO<G=A>0!.;W0@:6UP;&5M96YT960N`$YO="!S970`3F]T('-U
M<'!O<G1E9"X`3F]T97,`3F]T:6-E`$YO=F5M8F5R`$YU;6)E<B!O9B!C;VQU
M;6YS`$YU;6)E<B!O9B!R;W=S`$]+`$]C=&]B97(`3V9F:6-E`$]M86X`3VYL
M>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+@!/<&5N(&EN(&$@;F5W('=I
M;F1O=P!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R9V%N:7-A=&EO;@!/<F=A
M;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W1H97(`3W1H97(@26YF;W)M
M871I;VX`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES
M(&YO="!A=F%I;&%B;&4N`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC
M<GEP=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T
M960@1&%T80!02%`@0V]D90!02%`@4VAE;&P`4%](4"!3:&5L;`!086MI<W1A
M;@!086QA=0!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A>0!087-S
M=V]R9`!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@=VET:"!C;VYF:7)M
M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T
M8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!E<F9O<FT@36%I;G1E
M;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;G,@9F]R`%!E<G-O
M;F%L($EN9F]R;6%T:6]N`%!E<G4`4&AI;&EP<&EN97,`4&AO;F4`4&ET8V%I
M<FX`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI
M<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N
M;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D
M9')E<W,N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!P<F]V
M:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@
M>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&]L86YD`%!O<G1U9V%L`%!R
M979I97<`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N
M`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC($ME>2!)
M;F9O`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C
M97-S9G5L;'DN`%!U97)T;R!2:6-O`%%A=&%R`%%U97)Y`%)302!0=6)L:6,@
M2V5Y("@E9"!B:70I`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.@!2
M969R97-H(%!O<G1A;"!6:65W.@!296UO=&4@4V5R=F5R<P!296UO=F4`4F5M
M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E('!A:7(`4F5M;W9E('1H
M90!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5S970`4F5S970@4&%S
M<W=O<F0`4F5S970@66]U<B!087-S=V]R9`!297-U;'1S`%)E='5R;B!T;R!/
M<'1I;VYS`%)E=6YI;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)O;&4`
M4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H=`!2
M;W<@<')O<&5R=&EE<P!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O34E-
M12!%;F-R>7!T960@365S<V%G90!305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO
M="!A=F%I;&%B;&4N`%-13"!3:&5L;`!34T@`4U]13"!3:&5L;`!386EN="!(
M96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT
M(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R
M96YA9&EN97,`4V%M;V$`4V%N($UA<FEN;P!3875D:2!!<F%B:6$`4V%V90!3
M879E("(E<R(`4V%V92`E<P!3879E($]P=&EO;G,`4V5A<F-H`%-E;&5C="!&
M:6QE<P!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A
M=&4@9F]R;6%T.@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H
M86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L96-T('1H92!T
M:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C
M="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA
M;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F5G86P`4V5P=&5M8F5R
M`%-E<FEA;"!.=6UB97(`4V5T`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T
M('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U
M<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO
M;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M
M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS
M+@!3971U<`!397EC:&5L;&5S`%-H;W)T(%-U;6UA<GD`4VAO=P!3:&]W(&QA
M<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@=&AE("5S($UE
M;G4@;VX@=&AE(&QE9G0_`%-I97)R82!,96]N90!3:6=N('5P(&EF(&YO="!R
M96=I<W1E<F5D`%-I9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I;F=A
M<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`
M4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]U=&@@069R:6-A`%-O=71H($5U
M<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U
M=&@@4V%N9'=I8V@@27-L86YD<P!3<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C
M=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3
M<FD@3&%N:V$`4W1A=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T<F5E="!!9&1R
M97-S`%-U8FIE8W0`4W5B;6ET`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D
M("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-L96%R960@9&%T
M82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY
M(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY(')E;6]V960@(B5S(B!F<F]M
M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!U<&1A=&5D("(E<R(`4W5D86X`
M4W5N<FES92]3=6YS970`4W5R:6YA;64`4W=A>FEL86YD`%-W961E;@!3=VET
M>F5R;&%N9`!3>7)I86X@07)A8B!297!U8FQI8P!486EW86X`5&%I=V%N+"!0
M<F]V:6YC92!O9B!#:&EN80!486II:VES=&%N`%1A;GIA;FEA+"!5;FET960@
M4F5P=6)L:6,@;V8`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!497AT($]N;'D`
M5&AA:6QA;F0`5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+@!4:&4@
M:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E
M<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N
M('-A=F5D+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L
M92X`5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!W87,@
M82!P<F]B;&5M(&%D9&EN9R`B)7,B('1O('1H92!S>7-T96TZ("5S`%1H97)E
M('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B`B)7,B(&9R
M;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@
M(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M('5P
M9&%T:6YG("(E<R(Z("5S`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG
M('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I
M;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T
M;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A
M<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&9I96QD(&ES(')E<75I
M<F5D+@!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H:7,@
M;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O
M=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R
M97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&EM90!4:6UE(&9O<FUA=`!4:71L
M90!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@
M0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K
M:6YG+@!4;V1A>0!4;V=O`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`5')I;FED
M860@86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U;FES:6$`5'5R:V5Y`%1U
M<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=79A;'4`55),`%52
M3#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA
M8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&1E8V]M
M<')E<W,@9&%T82X`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C
M=6UE;G0`56YD;R!#:&%N9V5S`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N:71E
M9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YK;F]W;@!5;FYA;65D`%5N<W5P
M<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!L;V%D`%5R=6=U87D`57-E<B!/
M<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S97)N86UE`%5S97)N86UE("(E
M<R(@86QR96%D>2!E>&ES=',N`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S
M(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5F%C871I;VX`5F%N=6%T=0!6
M96YE>G5E;&$`5F5R<VEO;@!6:65T($YA;0!6:65W("5S`%9I97<@86X@97AT
M97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:7)G:6X@27-L86YD<RP@0G)I
M=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!786QL:7,@86YD($9U='5N80!7
M87)N:6YG`%=E8@!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O
M;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y
M+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E
M<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&EC:"!P;'5G:6YS('1O(&5N86)L
M92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H(&]F('1H92`E<R!M
M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI
M.@!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!960!965E9`%EE87)L>0!996UE
M;@!997,`665S+"!)($%G<F5E`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`
M66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@
M<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T('-P96-I9GD@82!U
M<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N
M86UE('1O(&%D9"X`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D
M<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D9')E<W,@
M:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E
M<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G
M:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME
M;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,L(&]R('1H92!F96%T
M=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`
M66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@
M;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L
M960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&-U<G)E;G0@=&EM92!Z
M;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9
M;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N<R!H
M879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S
M<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R(')E
M;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!::6UB86)W
M90!;4')O8FQE;2!297!O<G1=`%]!9&UI;FES=')A=&EO;@!?0TQ)`%]$96QE
M=&4@4F]W`%]'<F]U<',`7TAE;'``7TQO9R!I;@!?3&]G(&]U=`!?36]D:69Y
M($QI;FLN+BX`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN:RXN
M+@!?4V5T=7``7U5S97)S`&%D9')E<W,@8F]O:P!C86QE;F1A<@!F:6QE`&YA
M;64`;F]T97!A9`!U;FYA;65D`'9#87)D`%!R;VIE8W0M260M5F5R<VEO;CH@
M2&]R9&4@,RXP+6-V<PI297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S
M+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,2TR-"`R,#HU
M-BLP,3`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#4M,3$M,C0@,C$Z-#8K,#$P
M,`I,87-T+51R86YS;&%T;W(Z($MR>GES>G1O9B!+;WIL;W=S:VD@/&MO>FEK
M,4!O,BYP;#X*3&%N9W5A9V4M5&5A;3H@4&]L:7-H(#QP;$!L:2YO<F<^"DU)
M344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA
M<G-E=#UI<V\M.#@U.2TR"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M
M8FET"@`E<R`M(&=O=&]W>2!D;R!W>6MO;F%N:6$@8WEK;&EC>FYY8V@@;W!E
M<F%C:FD@>F%Z;F%C>F]N>6-H('!O;FF_96HN`"`H)7,@9&YI('1E;74I`"AK
M;'5C>B!D;W-TZG!U("5S*0`@*'<@8VFQ9W4@)7,@9&YI*0`@*&1Z:;8I`"`H
M:G5T<F\I`"`H=V-Z;W)A:BD`(B5S(B!N:64@:F5S="!P<F%W:62S;W=Y;2!W
M>6)O<F5M+@`B)7,B(&YI92!J97-T('-K;VYF:6=U<F]W86YY('<@<F5J97-T
M<GIE($AO<F1E+@!59&&S;R!S:>H@9&]D8>8@(B5S(B!D;R!G<G5P+@!59&&S
M;R!S:>H@9&]D8>8@(B5S(B!D;R!U<')A=VYI9?$N`"(E<R(@;FEE('IO<W1A
MLR!U='=O<GIO;GDZ("5S+@`E9"`E<R!I("5S`"5S("T@57=A9V$`061M:6YI
M<W1R86-J82`E<P`E<R!O9&-I<VL@<&%L8V$`)7,@:T(`)7,@+2!O<&5R86-J
M92!C>6ML:6-Z;F4@+2!P;W1W:65R9'IE;FEE`$MO;F9I9W5R86-J82`E<P!2
M96IE<W1R86-J82`E<P`E<R!J=;\@:7-T;FEE:F4N`"5S(&IE<W0@=WEM86=A
M;GD`)7,@;6EN=70`)7,@;FEE>FYA;&5Z:6]N>2X`)7,@9&\@)7,@>B`E<P!+
M<VFQOVMA(&%D<F5S;W=A("5S`$MA;&5N9&%R>B`E<P!.;W1A=&YI:R`E<P!,
M:7-T82!Z861A\2`E<P`E<SH@)7,`+2T@=WEB:65R>B`M+0`Q,BUG;V1Z:6YN
M>2!F;W)M870`,C0M9V]D>FEN;GD@9F]R;6%T`#(T(&=O9'HN`#Q0;W!R>F5D
M;FD`3F%S=+%P:;,@8K.Q9"!K<GET>6-Z;GD`4&]T<GIE8FYY(&IE<W0@:VQU
M8WH@<'5B;&EC>FYY(%!'4"!D;R!Z87-Z>69R;W=A;FEA('=I861O;6^V8VDN
M`%!O=')Z96)N>2!J97-T(&ML=6-Z('!U8FQI8WIN>2!01U`@9&\@<W!R87=D
M>F5N:6$@<&]D<&ES86YE:B!W:6%D;VUOMF-I+@!0;W1R>F5B;F4@<[$@:VQU
M8WH@<'5B;&EC>FYY(%!'4"P@:VQU8WH@<')Y=V%T;GD@4$=0(&]R87H@:&%S
MLV\@9&\@;V1S>GEF<F]W86YI82!W:6%D;VUOMF-I+@!0;W1R>F5B;F4@<[$@
M:VQU8WH@<'5B;&EC>FYY(%!'4"P@:VQU8WH@<')Y=V%T;GD@4$=0(&]R87H@
M:&%SLV\@9&\@<&]D<&ES86YI82!W:6%D;VUOMF-I+@!0;W1R>F5B;F4@<[$@
M:VQU8WH@<'5B;&EC>FYY(%,O34E-12P@:VQU8WH@<')Y=V%T;GD@4R]-24U%
M(&]R87H@:&%SLV\@9&\@;V1S>GEF<F]W86YI82!W:6%D;VUOMF-I+@!0;W1R
M>F5B;F4@<[$@:VQU8WH@<'5B;&EC>FYY(%,O34E-12P@:VQU8WH@<')Y=V%T
M;GD@4R]-24U%(&]R87H@:&%SLV\@9&\@<&]D<&ES86YI82!W:6%D;VUOMF-I
M+@!0;W1R>F5B;GD@:F5S="!K;'5C>B!P=6)L:6-Z;GD@4TU)344@9&\@>F%S
M>GEF<F]W86YI82!W:6%D;VUOMF-I+@!!32]030!/('1Y;2!E9'ET;W)Z90!/
M('!R;V=R86UI92XN+@!(87.S;R!D;R!K;VYT80!+;VYT;R!Z86)L;VMO=V%N
M92X`2V]N=&$`1&]D86H`1&]D86H@='5T86HZ`$1O9&%J(&YO=[$@9W)U<.H`
M1&]D86H@;F]W92!U<')A=VYI96YI90!$;V1A:B!N;W=E9V\@=;]Y=&MO=VYI
M:V$Z`$1O9&%J(&MO;'5M;NH`1&]D86H@;F]W>6-H(&-ZLV]N:_-W`$1O9&%J
M('!A<NH`1&]D86H@;65N=2`E<R!D;R!P87-K82!-;WII;&QI`$1O9&%J(&1O
M(&MS:;&_:VD@861R97-O=V5J.@!$;V1A:B!D;R!M;VIE:B!K<VFQ>FMI(&%D
M<F5S;W=E:@!$;V1A:B!UOWET:V]W;FEK80!$;V1A;F\@(B5S(B!D;R!S>7-T
M96UU+B!-;[]E<WH@<VGJ('IA;&]G;W=AYBX`1&]D87=A;FEE('6_>71K;W=N
M:6OS=R!J97-T('=YLV%C>F]N92X`061R97,`2W-IL;]K82!A9')E<V]W80!!
M9&UI;FES=')A8VIA`%)E:VQA;7D`069G86YI<W1A;@!!;&)A;FEA`$%L9VEE
M<FEA`$%L:6%S`%=S>GES=&MO`%=S>GES8WD@=7=I97)Z>71E;&YI96YI('6_
M>71K;W=N:6-Y`%=S>GES=&MI92!G<G5P>0!7<WIY<W1K:64@=7!R87=N:65N
M:6$`4&]Z=_-L(&YA('=I96QE(&%D<F5S\W<`2G6_(&ES=&YI96IE`$%L=&5R
M;F%T>7=N>2!L;V=I;B!)35-0`$%L=&5R;F%T>7=N>2!H87.S;R!)35-0`$%L
M=&5R;F%T>7=N82!N87IW82!UOWET:V]W;FEK82!)35-0`$%L=&5R;F%T>7=N
M>2!A9')E<R!E;6%I;`!!;'1E<FYA='EW;GD@=&5K<W0Z`%IO<W1ALV$@<&]D
M86YA(&YI97!R87=I9+-O=V$@=V%R=&^VYBX`06YD;W)A`$%N9V]L80!!;F=U
M:6QL80!!;F]N:6UO=V4@4')O>'D`3V1P;W=I962\`$%N=&%R:W1Y9&$`07!L
M:6MA8VIA`$%P;&EK86-J82!G;W1O=V$`6F%T=VEE<F2\`$MW:65C:67Q`%=I
M96QK;[;F(&%R8VAI=W5M`$YA>G=A(&%R8VAI=W5M`$%R9V5N='EN80!!<FUE
M;FEA`$%R=6)A`%!O<')OMB!O('!O='=I97)D>F5N:64@<')Z960@=WEK;VYA
M;FEE;2!O<&5R86-J:2!C>6ML:6-Z;GEC:#\`071R>6)U='D`4VEE<G!I9?$`
M075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)U<SH@3FEE('IN86QE>FEO;F\@
M=WEM86=A;F5G;R!R;WIS>F5R>F5N:6$@:6UA<"X`075T:%]C>7)U<SH@3FEE
M('IN86QE>FEO;F\@=WEM86=A;F5G;R!R;WIS>F5R>F5N:6$@:6UA<"X`075T
M:%]F='`Z($YI92!Z;F%L97II;VYO('=Y;6%G86YE9V\@<F]Z<WIE<GIE;FEA
M($944"X@4VMO;7!I;'5J(%!(4"!Z('!A<F%M971R96T@+2UE;F%B;&4@+@!!
M=71H7VEM87`Z($YI92!Z;F%L97II;VYO('=Y;6%G86YE9V\@<F]Z<WIE<GIE
M;FEA($E-05`N`$%U=&A?:W)B-3H@3FEE('IN86QE>FEO;F\@=WEM86=A;F5G
M;R!R;WIS>F5R>F5N:6$@:W)B-2X`075T:%]L9&%P.B!.:64@>FYA;&5Z:6]N
M;R!W>6UA9V%N96=O(')O>G-Z97)Z96YI82!,1$%0+@!!=71H7VQD87`Z($YI
M92!U9&&S;R!S:>H@=7-U;K'F('6_>71K;W=N:6MA("5S`$%U=&A?;&1A<#H@
M3FEE('5D8;-O('-IZB!U86MT=6%L;FGF('6_>71K;W=N:6MA("5S`$%U=&A?
M;6-A;#H@3FEE('IN86QE>FEO;F\@=WEM86=A;F5G;R!R;WIS>F5R>F5N:6$@
M34-!3"X`075T:%]S;6)A=71H.B!.:64@>FYA;&5Z:6]N;R!W>6UA9V%N96=O
M(')O>G-Z97)Z96YI82!S;6)A=71H+@!5=VEE<GIY=&5L;FEE;FEE(&YI92!P
M;W=I;V2S;R!S:>H`57=I97)Z>71E;&YI96YI92!N:64@<&]W:6]DLV\@<VGJ
M+B`E<P!5=VEE<GIY=&5L;FEE;FEE(&]D<GIU8V]N92!P<GIE>B!S97)W97(@
M4D%$2553+@!5=VEE<GIY=&5L;FEE;FEE(&1O('-E<G=E<F$@1E10(&YI92!P
M;W=I;V2S;R!S:>HN`$1O<W3J<&YE('!O;&$Z`$%Z97)B96IDOV%N`%=Y;?-W
M:VD@0D]&2`!4LV\`2V]L;W(@=+-A`%JS92!H87.S;R!+97)B97)O<V$N`%JS
M82!N87IW82!UOWET:V]W;FEK82!+97)B97)O<V$`5WES<'D@0F%H86UA`$)A
M:')A:FX`0F&S='EC:VD@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-Z`$)I8;-O
M<G6V`$)E;&=I80!"96QI>F4`0F5N:6X`0F5R;75D>0!":'5T86X`1&%T82!U
M<F]D>F5N:6$`57-T87=I96YI82!B;&]K=0!4>7`@8FQO:W4`0F]L:7=I80!:
M86NS861K:0!";[9N:6$@:2!(97)C96=O=VEN80!/8F$`0G)A>GEL:6$`0G6S
M9V%R:6$`0TU3`$-20P!7LV&V8VEW;[9C:2!K;VWS<FMI+BXN("A?8RD`2V%L
M96YD87)Z`$MA;6)O9+]A`$MA;65R=6X`3FEE('5D8;-O('-IZB!Z<F5S971O
M=V'F(&AA<[-A(&%U=&]M871Y8WIN:64L('-K;VYT86MT=6H@<VGJ('H@861M
M:6YI<W1R871O<F5M+@!"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R
M=V5R96T@24U!4#H@)7,`2V%N861A`$%N=6QU:@!!;G5L=6H@<F%P;W)T(&\@
M<')O8FQE;6EE`$YI92!M;[]N82!S:V%S;W=AYB!P;&EK=2`B)7,B`$YI92!U
M9&&S;R!S:>H@>FYA;&6\YB!K871A;&]G=2!T>6UC>F%S;W=E9V\N`$YI92!M
M;[]N82!S:V%S;W=AYB!K871A;&]G=2`B)7,B`%=Y<W!Y(%II96QO;F5G;R!0
M<GIY;+%D:V$`2V%T96=O<FEE(&D@;WIN86-Z96YI80!496PN(&MO;2X`5[-A
MMF-I=V^V8VD@:V]M\W)K:0!7LV&V8VEW;[9C:2!K;VWS<FMI`%1E;"X@:V]M
M+@!#96QT>6-K:2`H25-/+3@X-3DM,30I`%)E<'5B;&EK82"F<F]D:V]W96H@
M069R>6MI`*9R;V1K;W=O975R;W!E:G-K:2`H25-/+3@X-3DM,BD`4WIC>F5G
M\[-Y(&-E<G1Y9FEK871U`%>S8;9C:6-I96P@8V5R='EF:6MA='4`0WIA9`!:
M;6EE\0!:;6EE\2!I;6GJ+"!N87IW:7-K;R!I(&%D<F5S+"!K=/-R>2!I;FYI
M('=I9'JQ('<@5'=O:6-H(&QI<W1A8V@@96UA:6PN`%-P<F%W9+P@;&EN:RXN
M+@!:87IN86-Z('!O>GEC:NH@9&QA(&MT\W)E:B!C:&-E<WH@=WEK;VYAYB!O
M<&5R86-JZBX`0VAI;&4`0VAI;GD`4&]D86H@:&%SLV\`4&]D86H@;F%Z=^H@
M=;]Y=&MO=VYI:V$`5WEB:65R>B!S<&]S\V(@=WFV=VEE=&QA;FEA(&1A=#H`
M5WES<&$@0F^_96=O($YA<F]D>F5N:6$`2VQI:VYI:B!B>2!K;VYT>6YU;W=A
MY@!:86UK;FEJ(&]K;F\`5WES<'D@2V]K;W-O=V4@*$ME96QI;F=A*0!38VAO
M=V%J('!A<V5K`$MO;'5M8FEA`$MO;&]R`%=Y8FEE<GH@:V]L;W(`5WEB\W(@
M:V]L;W)U`%1Y='6S>2!K;VQU;6X`2V]M96YD80!0;W>S;VMA`$MO;65N=&%R
M>@!+;VUO<GD`1FER;6$`4W1W\W)Z('=I861O;6^VYB`H)7,I`$MO;7!U=&5R
M>0!787)U;FMI`%-K;VYF:6=U<G5J("5S`%!O='=I97)DO"!H87.S;P!+;VYG
M;P!$96UO:W)A='EC>FYA(%)E<'5B;&EK82!+;VYG;P!0;[.Q8WIE;FEE(&YI
M92!P;W=I;V2S;R!S:>HN`%!OL[%C>F5N:64@;FEE('!O=VEO9+-O('-IZCH@
M`$]D;?-W:6]N;R!P;[.Q8WIE;FEA(&1O('!U8FQI8WIN96=O('-E<G=E<F$N
M`$]D;?-W:6]N;R!P;[.Q8WIE;FEA(&1O('!U8FQI8WIN96=O('-E<G=E<F$N
M(%!O=_-D.B`E<R`H)7,I`$*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S
M97)W97)E;2!&5%`N`$MO;G1A:W1Y('IO<W1ALWD@<&]M>;9L;FEE(&1O9&%N
M92!D;R!4=V]J96H@:W-IL;]K:2!A9')E<V]W96HN`%IA=V%R=&^VYB`B)7,B
M`$MO;GEN=75J`%=Y<W!Y($-O;VMA`%-K;W!I=6H`4VMO<&EU:B!W>6+S<@!.
M:64@=61ALV\@<VGJ('IA<WIY9G)O=V'F("A01U`I('=I861O;6^V8VDN`$YI
M92!U9&&S;R!S:>H@<&]D<&ES8>8@*%!'4"D@=VEA9&]M;[9C:2X`3FEE('5D
M8;-O('-IZB!Z87-Z>69R;W=AYB`H4R]-24U%*2!W:6%D;VUOMF-I+@!.:64@
M=61ALV\@<VGJ('!O9'!I<V'F("A3+TU)344I('=I861O;6^V8VDN`$*SL60@
M<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!,1$%0+@!"L[%D('!O
M9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@(B5S(B!P;W!R>F5Z($94
M4#H@)7,`3FEE('5D8;-O('-IZB!O9'-Z>69R;W=AYB!D86YY8V@@4$=0+@!.
M:64@=61ALV\@<VGJ(&]D<WIY9G)O=V'F(&1A;GEC:"!3+TU)344N`$YI92!U
M9&&S;R!S:>H@=7-T86QIYB!A9')E<W4@92UM86EL(&]D8FEO<F-Y+@!.:64@
M=61ALV\@<VGJ('5Z>7-K8>8@>B!S97)W97)A(&ML=6-Z82!P8G5L:6-Z;F5G
M;RX`3FEE('5D8;-O('-IZB!O='=O<GIYYB`B)7,B(&1O('IA<&ES=2X`3FEE
M(&UOOVYA(&]T=V]R>GGF("5S+@!.:64@;6^_;F$@;W1W;W)Z>>8@;6]D=;-U
M($UA:6YT96YA;F-E7U1A<VL@)7,`3FEE(&UOOVYA(&]T=V]R>GGF(&MA=&%L
M;V=U("(E<R(`3FEE('5D8;-O('-IZB!S:V%S;W=AYB!P;&EK=2`B)7,B+@!.
M:64@=61ALV\@<VGJ('IN86QEO.8@<&%S:V$@36]Z:6QL:2X@57!E=VYI:B!S
M:>HL(+]E(&IE<W0@;VX@;W1W87)T>2X`2W)A:@!3='?S<GH`4W1W\W)Z(&QI
M;FL`4W1W\W)Z(&YO=[$`3G5M97(@:V%R='D@:W)E9'ET;W=E:@!#:&]R=V%C
M:F$`2W5B80!/8F5C;GD@8WIA<P!3<&5R<V]N86QI>G5J('IA9&%N:6$@=7)U
M8VAA;6EA;F4@<')Z>2!L;V=O=V%N:74@9&\@)7,N`%=Y=&YI:@!#>7!R`%)E
M<'5B;&EK82!#>F5C:`!$1`!#;V1Z:65N;FEE`$1A=&$`7U5S=?$@:V]L=6UN
MZ@!'<G5D>FEE\0!$;VUYMFQN>2!K;VQO<@!$;VUYMFQN82!T;[]S86UOMN8`
M1&]M>;9L;F4@=7!R87=N:65N:6$`1&]M>;9L;F4@=7!R87=N:65N:6$`57-U
M\0!5<W7Q($=R=7#J`%5S=?$@=7!R87=N:65N:6$`57-U\2!I('=Y8WIYMN8@
M=VEA9&]M;[9C:0!5<W7Q(&MO;?-R:^H`57-U\2!K;VQU;6[J`%-K87-U:B!U
M<')A=VYI96YI82!D;&$@(B5S(@!3:V%S;W=AYB!U<')A=VYI96YI82!D;&$@
M(B5S(B!I('=S>GES=&MI92!P;V0M=7!R87=N:65N:6$_`%5S=?$@=VEE<G-Z
M`%-K87-U:B!W>6)R86ZQ('1OOW-A;6^VY@!5<W7Q(&%K='5A;&ZQ(&MO;'5M
M;NH`57-U\2!A:W1U86QN>2!W:65R<WH`4VMA<V]W8>8@=&\@=7!R87=N:65N
M:64@:2!W<WIY<W1K:64@<&]D+75P<F%W;FEE;FEA/P!$86YI80!/<&ES>B!P
M<F]B;&5M`%-Z8WIE9_.S>2!Z;W-T8;-Y('IA;&]G;W=A;F4@9&QA(&%D;6EN
M:7-T<F%T;W)A+@!+871A;&]G`%=YMG=I971L(&-Z87,@=R!F;W)M86-I92`R
M-"UG;V1Z:6YN>6T_`%5S=&%W:65N:6$@=WEG;+%D=0!$OVEB=71I`$YI92!K
M87-U:@!"<F%K(&)E>G!OMG)E9&YI96=O(&1O<W3J<'4@9&\@;6%I;G1E;F%N
M8V4N<&AP`$1O;6EN:6MA("A7<W#S;&YO=&$@1&]M:6YI:VDI`$1O;6EN:6MA
M;F$@*%)E<'5B;&EK82!$;VUI;FEK8?%S:V$I`*9C:;%G;FEJ`*9C:;%G;FEJ
M("5S`$YA<FMO='EK:0!%+6UA:6P`16MW861O<@!%9'EC:F$`57-U\2!'<G5P
MZ@!:;6EE\2!U<')A=VYI96YI90!:;6EE\2!U<')A=VYI96YI80!:;6EE\2!U
M<')A=VYI96YI82!D;&$@)7,`6FUI9?$@=7-T87=I96YI82!D;&$Z`%IM:67Q
M('5P<F%W;FEE;FEA(&1L82`E<P!%9VEP=`!386QW861O<@!%;6%I;`!!9')E
M<R!E;6%I;`!!9')E<WD@96UA:6P@;75S>K$@9&\@<VEE8FEE('!A<V]W8>8N
M`$5M;W1I:V]N>0!0=7-T82!W:6%D;VUOMN8N`$)R86L@<F5Z=6QT873S=RX`
M5[.Q8WIYYB!M96YU(&MO;G1E:W-T;W=E('!O9"!P<F%W>6T@<')Z>6-I<VMI
M96T@;7ES>GD_`$=W:6YE82!2\W=N:6MO=V$`17)Y=')E80!"L[%D`$*SL60@
M<')Z>2!Z87!I<VEE("(E<R(N`$5S=&]N:6$`171I;W!I80!%=7)O<&$`0V\@
M:V&_9&4@,34@;6EN=70`0V\@:V&_9&4@,B!M:6YU='D`0V\@:V&_9&4@,S`@
M<V5K=6YD`$-O(&MAOV1E(#4@;6EN=70`0V\@:V&_9&4@>F%L;V=O=V%N:64`
M0V\@:V&_9&4@</.S(&=O9'II;GD`0V\@:V&_9+$@;6EN=73J`%!R>GEKLV%D
M;W=E('=A<G1OMF-I.@!7>6MO;F%J`%)O>G=I\0!2;WIW:?$@<&%S96L`0K.Q
M9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M($Q$05`N`$*SL60@
M<&]D8WIA<R!K;W!I;W=A;FEA('H@(B5S(BX`0K.Q9"!P;V1C>F%S(&MO<&EO
M=V%N:6$@9&\@(B5S(BX`0K.Q9"!P;V1C>F%S('!R>F5N;W-Z96YI82!D;R`B
M)7,B+@!&86QK;&%N9'D@*$UA;'=I;GDI`%=Y<W!Y($]W8WIE`$*SL60@:W)Y
M='EC>FYY.B``1F%K<P!,=71Y`$9I9+]I`$UE;F5DOV5R('!L:6OS=P!.87IW
M82!P;&EK=0!7>6+S<B!P;&EK=0!79W)Y=V%N:64@<&QI:W4`5V=R>7=A;FEE
M('!L:6OS=R!N:64@:F5S="!O8G.S=6=I=V%N92X`1FEL=')Y`$9I;FQA;F1I
M80!*961Z96YI90!:87!O;6YI8;-EMB!H87.S83\`1G)A;F-J80!'=6IA;F$@
M1G)A;F-U<VMA`%!O;&EN97IJ82!&<F%N8W5S:V$`1G)A;F-U<VMI92!497)Y
M=&]R:6$@4&^S=61N:6]W92!I($%N=&%R:W1Y8WIN90!/9`!'86)O;@!'86UB
M:6$`3FEE;6-Y`$=H86YA`$=I8G)A;'1A<@!)9+P`5WES>G5K:7=A<FMA($=O
M;V=L90!'<F5C:F$`1W)E;FQA;F1I80!'<F5N861A`$=R=7!Y(&1Y<VMU<WEJ
M;F4`1W=A9&5L=7!A`$=U86T`1W=A=&5M86QA`$=U97)N<V5Y`$=W:6YE80!'
M=VEN96$@0FES<V%U`$=U:F%N80!(5$U,`$AA:71I`%=Y<W!Y($AE87)D(&D@
M36-$;VYA;&1A`%!O;6]C`%=Y<V]K:0!?4W1A<G0`5V%T>6MA;B`H4W1O;&EC
M82!!<&]S=&]L<VMA*0!0;V-ZL71E:P!!9')E<R!D;VUO=WD`5&5L+B!D;VTN
M`$AO;F1U<F%S`$AO;F=+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!59&&S;R!S
M:>H@=7-U;K'F("5S("(E<R(`5^IG<GD`27-L86YD:6$`5'EL:V\@:6MO;GD`
M26MO;GD@>B!T96MS=&5M`$YA>G=A('1OOW-A;6^V8VDZ`$=R869I:V$`26UP
M;W)T;W=A;F4@<&]L93H@)7,`26UP;W)T;W=A;F4@<&]L83H`26YD:64`26YD
M;VYE>FIA`$EN9F\`5VML96H@;V)R87IE:P!7>7.S86YE(&YI97!R87=I9+-O
M=V4@9&%N92X`3FEE<')A=VEDLV]W>2!A9')E<R!D;V-E;&]W>2X`3FEE<')A
M=VEDLV]W>2!F;W)M870@<&QI:W4`3FEE<')A=VEDLV]W>2!K;'5C>B!L:6-E
M;F-J:2X`27)A;@!)<F%K`$ER;&%N9&EA`$EZ<F%E;`!7>61A=V-A`%>S;V-H
M>0!*86UA:FMA`%-T>6-Z9?$`2F%P;VYI80!*;W)D86X`3&EP:65C`$-Z97)W
M:65C`$MA>F%C:'-T86X`2V5N:6$`5'=O<GIE;FEE(&ML=6-Z80!/9&-I<VL@
M:VQU8WIA`$2S=6=OMN8@:VQU8WIA`%1Y<"!K;'5C>F$`2VQU8WH@:G6_(&ES
M=&YI96IE(&YA('!U8FQI8WIN>6T@<V5R=V5R>F4@:VQU8WIY+@!$>FEE8VD`
M2VER:6)A=&D`2V]R96'Q<VMA(%)E<'5B;&EK82!,=61O=V\M1&5M;VMR871Y
M8WIN80!297!U8FQI:V$@2V]R96D`2W5W96IT`$MI<F=I<W1A;@!7>6=LL60@
M*%]Y*0!*ZGIY:P!,86]S`$]S=&%T;FEE(&QO9V]W86YI93H@)7,`3W-T871N
M:64@;&]G;W=A;FEE.B`E<R!Z("5S`$]S=&%T;FEE(&QO9V]W86YI93H@;FEG
M9'D`HV]T=V$`3&5S;W1H;P!,:6)E<FEA`$QI8FEA`$QI96-H=&5N<W1E:6X`
M5WFV=VEE=&P@=&5M871Y('!O;6]C>0!,:7-T;W=A;FEE('6_>71K;W=N:6OS
M=R!J97-T('=YL[%C>F]N92X`3&ET=V$`HV%D;W=A;FEE+BXN`$-Z87,@;&]K
M86QN>3H@`%5S=&%W:65N:6$@;&]K86QN92!I(&-Z87,`6F%L;V=U:@!7>6QO
M9W5J`%IA9&%N:6$@<')Z>2!L;V=O=V%N:74`3&]G;W=A;FEE(&YI92!P;W=I
M;V2S;R!S:>HL('!O;FEE=V&_('!O9&&S9;8@;FEE<')A=VEDLV]W92!H87.S
M;R!L=6(@;F%Z=^H@=;]Y=&MO=VYI:V$N`$QO9V]W86YI92!N:64@<&]W:6]D
MLV\@<VGJ+@!.:7-K:0!,=6MS96UB=7)G`$U-`$U/5$0`35-'`$UA:V%U`$UA
M8V5D;VYI80!-861A9V%S:V%R`%!O8WIT80!-86QA=VD`36%L97IJ80!-86QE
M9&EW>0!-86QI`$UA;'1A`%IA<GJQ9'IA:B!L:7-TL2!K871E9V]R:6DL(&MT
M\W)Y;6D@8NID>FEE<WH@;WIN86-Z8;,@<&]Z>6-J92P@:2!K;VQO<F%M:2!Z
M(&YI;6D@>G=IL7IA;GEM:2X`36%R>F5C`$UA<F=I;F5S`%=Y<W!Y($UA<G-H
M86QL80!-87)T>6YI:V$`4&%S=6JQ8V4@<&]L80!-875R971A;FEA`$UA=7)I
M=&EU<P!-86H`36%J;W1T80!4<GEB(&UE;G4Z`%!OL[%C>B!K;VWS<FMI`%=I
M861O;6^VY@!";&]K(")-971A<B(@;FEE(&IE<W0@9&]S=.IP;GDN`$)L;VL@
M(DUE=&%R(B!N:64@:F5S="!D;W-TZG!N>2X@4WIC>F5G\[-Y('ID87)Z96YI
M82!Z;W-T8;-Y('IA;&]G;W=A;F4@9&QA(&%D;6EN:7-T<F%T;W)A+@!-96MS
M>6L`5'EP($UI;64`3W-T871N:6$@;6]D>69I:V%C:F$`6FUI9?$@;&EN:P!-
M;[-D87=I80!297!U8FQI:V$@36^S9&%W:6D`36]N86MO`$UO;F=O;&EA`$-O
M(&UI97-IL6,`36]N='-E<G)A=`!&87IY(&MS:>J_>6-A`$UA<F]K;P!0<GIE
M<W7Q('<@9/.S`%!R>F5S=?$@=R!L97=O`%!R>F5S=?$@=R!P<F%W;P!0<GIE
M<W7Q('<@9_-RZ@!0<GIE;FEEMB!W(&3SLP!0<GIE<W7Q('<@9_-RZ@!-;WIA
M;6)I:P!+;VYT;P!-\VH@<&]R=&%L`$)I<FUA`$YA>G=I<VMO`$YA;6EB:6$`
M3F%U<G4`3F5P86P`2&]L86YD:6$`06YT>6QE($AO;&5N9&5R<VMI90!3:67F
M`$YI9V1Y`$YO=V$@2V%L961O;FEA`$YO=V$@:V%T96=O<FEA`$YO=V$@6F5L
M86YD:6$`5VEA9&]M;[9C:0!.87-TZG!N90!.87-TZG!N92!O<&-J90!.:6MA
M<F%G=6$`3FEG97(`3FEG97)I80!.:75E`$)E>B!Z;6EA;BX`0G)A:R!K;VYF
M:6=U<F%C:FD@9&QA("5S+@!.:64@=V=R86YO('!L:6MU`$YI92!P;V1A;F\@
M:&%SLV$@9&QA('5W:65R>GET96QN:65N:6$@2%144"X`3FEE('!O9&%N;R!H
M87.S82!D;&$@=7=I97)Z>71E;&YI96YI82!)34%0+@!.:64@<&]D86YO(&AA
M<[-A(&1L82!U=VEE<GIY=&5L;FEE;FEA($ME<F)E<F]S+@!.:64@<&]D86YO
M(&AA<[-A(&1L82!U=VEE<GIY=&5L;FEE;FEA($Q$05`N`$YI92!P;V1A;F\@
M:&%SLV$@9&QA('5W:65R>GET96QN:65N:6$@3$]'24XN`$YI92!P;V1A;F\@
M:&%SLV$@9&QA('5W:65R>GET96QN:65N:6$@4$%34U=$+@!.:64@<&]D86YO
M(&AA<[-A(&1L82!U=VEE<GIY=&5L;FEE;FEA(%--0BX`KV%D;F$`3F]R9F]L
M:P!.;W)W96=I80!.:64@>F%I;7!L96UE;G1O=V%N;RX`3FEE=7-T87=I;VYE
M`$YI96]B<[-U9VEW86YE`%5W86=I`%5W86=A`$QI<W1O<&%D`$QI8WIB82!K
M;VQU;6X`3&EC>F)A('=I97)S>GD`3TL`4&&\9'II97)N:6L`0FEU<F\`3VUA
M;@!4=_-J(&IE9&5N(&%D<F5S(&4M;6%I;"!J97-T(&1O>G=O;&]N>2X`3W1W
M\W)Z('<@;F]W>6T@;VMN:64`3W!C:F4`3W!C:F4@)7,`3W)G86YI>F%C:F$`
M2F5D;F]S=&MA(&]R9V%N:7IA8WEJ;F$`3W)G86YI>F%T;W(`26YN90!);FYE
M(&EN9F]R;6%C:F4`26YN92!U<')A=VYI96YI80!5=VEE<GIY=&5L;FEE;FEE
M(%!!32!N:64@:F5S="!D;W-TZG!N92X`0WEF<F]W>2!P;V1P:7,@4$=0`%=I
M861O;6^VYB!Z87-Z>69R;W=A;F$@4$=0`$ML=6-Z('!U8FQI8WIN>2!01U``
M5VEA9&]M;[;F('IA<WIY9G)O=V%N82]P;V1P:7-A;F$@:VQU8WIE;2!01U``
M2V]D(%!(4`!0;W>S;VMA(%!(4`!0;W>S;VMA(%!?2%``4&%K:7-T86X`4&%L
M874`4&%N86UA`%!A<'5A+4YO=V$@1W=I;F5A`%!A<F%G=V%J`$AA<[-O`$AA
M<[-O(&YI97!R87=I9+-O=V4`2&%SLV\@>B!P;W1W:65R9'IE;FEE;0!(87.S
M;SH`2&%SLV\Z(`!(87.S;R!M=7-I('!A<V]W8>8N`%=K;&5J`%=K;&5J('IE
M('-C:&]W:V$`5WEK;VYA:B!C>6ML:6-Z;F4@;W!E<F%C:F4`5WEK;VYA:B!C
M>6ML:6-Z;F4@;W!E<F%C:F4@<&]D8WIA<R!L;V=O=V%N:6$_`%5P<F%W;FEE
M;FEE`%5P<F%W;FEE;FEA(&1L80!);F9O<FUA8VIE(&]S;V)I<W1E`%!E<G4`
M1FEL:7!I;GD`5&5L969O;@!0:71C86ER;@!.82!P97=N;R!U<W5NL>8@=&5N
M('=Y8G)A;GD@96QE;65N=#H`3F$@<&5W;F\@=7-U;K'F('=Y8G)A;GD@96QE
M;65N=#H`4')O<WKJ('!O9&'F('!O<')A=VYY(&%D<F5S($E0+@!0<F]S>NH@
M<&]D8>8@<&]P<F%W;GD@8WIA<RX`4')O<WKJ(&]P:7-AYB!P<F]B;&5M+@!0
M<F]S>NH@<&]D8>8@;F%Z=^H@=;]Y=&MO=VYI:V$@:2!H87.S;P!0;VQS:V$`
M4&]R='5G86QI80!0;V1G;+%D`$ML=6-Z('!R>7=A=&YY`%!R;V)L96T`3W!I
M<R!P<F]B;&5M=0!+;'5C>B!P=6)L:6-Z;GD`06QG;W)Y=&T@:VQU8WIA('!U
M8FQI8WIN96=O`$EN9F]R;6%C:F4@;R!K;'5C>G4@<'5B;&EC>FYY;0!087)A
M(&ML=6-Z>2!O<V]B:7-T>6-H(&YI92!Z;W-T8;-A('=Y9V5N97)O=V%N82!P
M;VUYMFQN:64N`%!O<G1O<GEK;P!+871A<@!:87!Y=&%N:64`2VQU8WH@<'5B
M;&EC>FYY(%)302`H)60@8FET\W<I`$]DMG=I9;\@9'EN86UI8WIN92!E;&5M
M96YT>2!M96YU.@!/9+9W:66_('=I9&]K('-E<G=I<W4Z`%ID86QN92!S97)W
M97)Y`%5S=?$`57-U\2!B;&]K`%5S=?$@:V]L=6UNZ@!5<W7Q('!A<NH`57-U
M\0!5<W7Q('6_>71K;W=N:6MA`%ID86QN92!UOWET:V]W;FEK83H@)7,`2V%S
M=6H`5WEC>GFVYB!H87.S;P!7>6-Z>;;F(%1W;VIE(&AA<[-O`%=Y;FEK:0!0
M;W=R\W0@9&\@;W!C:FD`4F5U;FEO;@!2;WIB=61O=V%N>2!E9'ET;W(@=&5K
M<W1U`%-T86YO=VES:V\`4G5M=6YI80!/8G+SYB!O(#$X,"!S=&]P;FD`3V)R
M\^8@=R!L97=O`$]B<O/F('<@<')A=V\`5[-AMF-I=V^V8VD@<GKJ9'4@4')O
M<&5R=&EE<P!2;W-J80!2=6%N9&$`5VEA9&]M;[;F('IA<WIY9G)O=V%N82!3
M+TU)344`57=I97)Z>71E;&YI96YI92!305-,(&YI92!J97-T(&1O<W3J<&YE
M+@!0;W=L;VMA(%-13`!34T@`4&]WLV]K82!37U%,`*9W:>IT82!(96QE;F$`
M4V%I;G0@2VET=',@:2!.979I<P!386EN="!,=6-I80!386EN="U0:65R<F4@
M:2!-:7%U96QO;@!386EN="!6:6YC96YT(&D@1W)E;F%D>6YY`%-A;6]A`%-A
M;B!-87)I;F\`07)A8FEA(%-A=61Y:G-K80!:87!I<WH`6F%P:7-Z("(E<R(`
M6F%P:7-Z("5S`%IA<&ES>B!O<&-J90!3>G5K86H`5WEB:65R>B!P;&EK:0!7
M>6)I97)Z('IN86L@<&]D>FEALW4@9&%T>3H`5WEB:65R>B!F;W)M870@9&%T
M>3H`5WEB:65R>B!T;[]S86UOMN8@9&\@>FUI86YY.@!7>6)I97)Z('IN86L@
M<&]D>FEALW4@9&%T>3H`5WEB:65R>B!F;W)M870@8WIA<W4Z`%=Y8FEE<GH@
M9'=A('!A<W5JL6-E('!O;&$N`%=Y8FEE<GH@<V-H96UA="!K;VQO<O-W+@!7
M>6)I97)Z('1W\VH@<')E9F5R;W=A;GD@:NIZ>6LZ`%=YMFQI:B!R87!O<G0@
M;R!P<F]B;&5M:64`4V5N96=A;`!7<GIE<VEE\0!.=6UE<B!S97)Y:FYY`%5S
M=&%W`%5S=&%W('ID86QN92!S97)W97)Y+"!D;R!K=/-R>6-H(&-H8V5S>B!M
M:67F(&1O<W3J<"!Z('-E<G=I<W4N`%5S=&%W('!R969E<F]W86YY(&KJ>GEK
M+"!S=')E9NH@8WIA<V]WL2!I(&]P8VIE(&1A='DN`%5S=&%W('5SLW5GZB!P
M;V-ZL71K;W>Q+"!S8VAE;6%T(&MO;&]R\W<L(&]DMG=I9;]A;FEE('-T<F]N
M>2!I(&EN;F4@;W!C:F4@=WFV=VEE=&QA;FEA`$MO;F9I9W5R86-J80!3>F5S
M>F5L90!+<O-T:VD@;W!I<P!0;VMAOP!0;VMA>GEW8>8@8WIA<R!O<W1A=&YI
M96=O('IA;&]G;W=A;FEA('!O(&QO9V]W86YI=3\`4&]K8;\@;65N=2`E<R!P
M;R!L97=E:C\`4VEE<G)A($QE;VYE`%IA<F5J97-T<G5J('-IZBP@:F6V;&D@
M:F5S>F-Z92!T96=O(&YI92!Z<F]B:;-EM@!0;V1P:7,`06QG;W)Y=&T@<&]D
M<&ES=0!3:6YG87!U<@!7:65L:V^VY@!0;VUI\2!O<&5R86-J92!C>6ML:6-Z
M;F4`4[-O=V%C:F$`4[-O=V5N:6$`5WES<'D@4V%L;VUO;F$`4V]M86QI80!0
M;[-U9&YI;W=A($%F<GEK80!0;[-U9&YI;W=O975R;W!E:G-K:2`H25-/+3@X
M-3DM,RD`1V5O<F=I82!0;[-U9&YI;W=A`$AI<WIP86YI80!3<&%M`$5D>6-J
M82!Z;F%K\W<@<W!E8VIA;&YY8V@`4&]D>FEE;"!K;VWS<FOJ`%!O9'II96P@
M:V]L=6UNZ@!0;V1Z:65L('=I97)S>@!3<FD@3&%N:V$`5V]J97?S9+QT=V\@
M;'5B('-T86X`4W1A='5S`$%D<F5S(&1O;6]W>0!496UA=`!7>;9L:6H`4&]W
M;V1Z96YI90!59&&S;R!S:>H@9&]D8>8@(B5S(B!D;R!S>7-T96UU+@!59&&S
M;R!S:>H@=7-U;K'F("(E<R(@>B!S>7-T96UU+@!59&&S;R!S:>H@=7-U;K'F
M("(E<R(N`%5D8;-O('-IZB!U<W5NL>8@(B5S(B!Z('-Y<W1E;74N`%5D8;-O
M('-IZB!U86MT=6%L;FGF("(E<R(`4W5D86X`5W-C:/-D+WIA8VCS9"!SLV_Q
M8V$`4W5R:6YA;0!3=6%Z:0!3>G=E8VIA`%-Z=V%J8V%R:6$`4WER:6$`5&%J
M=V%N`%1A:G=A;@!4862_>6MI<W1A;@!486YZ86YI80!:861A;FEA`$YU;65R
M('1E;&5F;VYU`%1Y;&MO('1E:W-T`%1A:FQA;F1I80!$>FGJ:W5J96UY('IA
M(&MO<GIY<W1A;FEE('H@<V5R=VES=2X`5&^_<V%M;[;F("(E<R(@>F]S=&&S
M82!U<W5N:>IT82X`4V5R=V5R("(E<R(@>F]S=&&S('5S=6YIZG1Y+@!397)W
M97(@(B5S(B!Z;W-T8;,@>F%P:7-A;GDN`$)L;VL@=V5A=&AE<BYC;VT@;FEE
M(&IE<W0@9&]S=.IP;GDN`$YI92!M82"_861N>6-H(&1O<W3J<&YY8V@@;W!C
M:FDN`%=Y<W2Q<&FS('!R;V)L96T@<')Z>2!D;V1A=V%N:74@(B5S(B!D;R!S
M>7-T96UU.B`E<P!7>7-TL7!ILR!P<F]B;&5M('!R>GD@=7-U=V%N:74@9&%N
M>6-H(&1L82!UOWET:V]W;FEK82`B)7,B('<@<WES=&5M:64Z(`!7>7-TL7!I
MLR!P<F]B;&5M('!R>GD@=7-U=V%N:74@(B5S(B!Z('-Y<W1E;74N`%=Y<W2Q
M<&FS('!R;V)L96T@<')Z>2!U86MT=6%L;FEA;FEU("(E<R(Z("5S`%=Y<W2Q
M<&FS(&*SL60@<&]D8WIA<R!W>;9W:65T;&%N:6$@=&5J(&-ZZK9C:2!W:6%D
M;VUOMF-I`%=Y<W2Q<&FS(&*SL60@<&]C>F%S(&EM<&]R=&]W86YI82!D86YY
M8V@@:4-A;&5N9&%R+@!0;&EK(&YI92!W>6=LL61A(&YA('!O<')A=VYE(&%R
M8VAI=W5M(%)!4BX`4&QI:R!N:64@=WEG;+%D82!N82!P;W!R87=N92!A<F-H
M:7=U;2!:25`N`%1O('!O;&4@:F5S="!W>6UA9V%N92X`5&\@<&]L92!M=7-I
M(&)YYB!P;W!R87=NL2!L:6-Z8K$N`%=I861O;6^VYB!Z;W-T8;-A(&YA<&ES
M86YA('<@:6YN96H@;FF_('1W;VIA('-T<F]N:64@:V]D;W=E:B`H)7,I+@!4
M96X@<V5R=V5R(&YI92!P;W1R869I(')O>G!A:V]W>7=AYB!A<F-H:7?S=R!Z
M:7`@:2!G>FEP+@!#>F%S`$9O<FUA="!C>F%S=0!4>71ULP!$;P!!8GD@=WEB
M<F'F('=I96QO:W)O=&YE('!O;&$@<')Z>71R>GEM86H@<')Z>6-I<VL@0W1R
M;"`H4$,I(&QU8B!#;VUM86YD("A-86,I('!O9&-Z87,@:VQI:V%N:6$N`$1Z
M:;8`5&]G;P!4;VME;&%U`$IU=')O`%1O;F=A`%1R>6YI9&%D(&D@5&]B86=O
M`%!R87=D82!L=6(@9F&S<WH`5'5N97IJ80!4=7)C:F$`5'5R96-K:2`H25-/
M+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U=F%L=0!54DP`55),.@!59V%N9&$`
M56MR86EN80!"L[%D('!O9&-Z87,@>FUI86YY(&1O("5S+@!"L[%D('!O9&-Z
M87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,+@!"L[%D('!O9&-Z87,@
M<F]Z<&%K;W=Y=V%N:6$@9&%N>6-H+@!.:64@;6^_;F$@<')Z972S=6UA8WIY
MYB!T96=O(&1O:W5M96YT=2!7;W)D+6$`0V]F;FEJ('IM:6%N>0!::F5D;F]C
M>F]N92!%;6ER871Y($%R86)S:VEE`%=I96QK82!"<GET86YI80!54T$`3FEE
M>FYA;F4`0F5Z(&YA>G=Y`$YI96]B<[-U9VEW86YE(')O>G-Z97)Z96YI90!5
M86MT=6%L;FEJ`%IALV%D=6H`57)U9W=A:@!/<&-J92!UOWET:V]W;FEK80!2
M96IE<W1R86-J82!UOWET:V]W;FEK80!.87IW82!UOWET:V]W;FEK80!5OWET
M:V]W;FEK(&\@;F%Z=VEE("(E<R(@:G6_(&ES=&YI96IE+@!.87IW82!UOWET
M:V]W;FEK83H`3F%Z=V$@=;]Y=&MO=VYI:V$Z(`!5OWET:V]W;FEC>2!W('-Y
M<W1E;6EE.@!5>F)E:VES=&%N`%=A:V%C:F4`5F%N=6%T=0!796YE>G5E;&$`
M5V5R<VIA`%=I971N86T`5VED;VL@)7,`4&]K8;\@<W1R;V[J(%=75P!0;VMA
MOR!J86MO("5S`$)R>71Y:G-K:64@5WES<'D@1'II97=I8WIE`%=Y<W!Y($1Z
M:65W:6-Z92!3=&%N\W<@6FIE9&YO8WIO;GEC:`!786QL:7,@:2!&=71U;F$`
M3W-T<GIEOV5N:64`5U=7`$-O('1Y9'II9?$`5VET86UY`%=I=&%M>2!W("5S
M`%=I=&%M>2P@)7,`6F%C:&]D;FD@*$E33RTX.#4Y+3$I`%IA8VAO9&YI("A)
M4T\M.#@U.2TQ-2D`4V%H87)A(%IA8VAO9&YI80!*86NQ(&%P;&EK86-JZB!M
M82`E<R!W>;9W:65T;&'F('!O('IA;&]G;W=A;FEU('-IZC\`2F%K:64@=W1Y
M8WIK:2!A:W1Y=V]W8>8@=R!2;WIB=61O=V%N>6T@961Y=&]R>F4@=&5K<W1U
M+@!3>F5R;VMOMN8@;&5W96=O(&UE;G4@)7,@*'IM:6%N82!Z86-Z;FEE(&]B
M;W=IL7IY=V'F('!R>GD@;F%S=.IP;GEM(&QO9V]W86YI=2DZ`$%D<F5S(&1O
M('!R86-Y`%1E;"X@9&\@<')A8WD`4E(`4E)24@!#;R!R;VL`2F5M96X`5&%K
M`%1A:RP@>F=A9'IA;2!S:>H`5WEL;V=O=V&S9;8@<VGJ+@!-=7-I<WH@;W!I
M<V'F('!R;V)L96T@>F%N:6T@9V\@=WFV;&5S>BX`375S:7-Z(&]K<F6V;&GF
M('6_>71K;W=N:6MA+"!K=/-R96=O(&-H8V5S>B!U<W5NL>8N`$UU<VES>B!O
M:W)EMFQIYB!UOWET:V]W;FEK82P@:W3S<F5G;R!C:&-E<WH@9&]D8>8N`%1W
M\VH@861R97,@92UM86EL`%1W\VH@861R97,@3V0Z`%1W;VIE(&EN9F]R;6%C
M:F4`5'?S:B!A9')E<R!I;G1E<FYE=&]W>2!S:>H@>FUI96YILR!O9"!P;V-Z
ML71K=2!S97-J:2`E<RX@5R!Z=VFQ>FMU('H@8F5Z<&EE8WIE\7-T=V5M(%1W
M;VIE9V\@:V]N=&$@;75S:7-Z('IA;&]G;W=AYB!S:>H@<&]N;W=N:64N`%1W
M;VIE(&EM:>H`5&5N('-Y<W1E;2!A=71E;G1Y:V%C:FD@;FEE(&]B<[-U9W5J
M92!D;V1A=V%N:6$@=;]Y=&MO=VYI:_-W+"!L=6(@=&$@;W!C:F$@>F]S=&&S
M82!W>;.Q8WIO;F$N`%1E;B!S>7-T96T@875T96YT>6MA8VII(&YI92!O8G.S
M=6=U:F4@;&ES=&]W86YI82!UOWET:V]W;FEK\W<L(&QU8B!T82!O<&-J82!Z
M;W-T8;-A('=YL[%C>F]N82X`5'=O:F$@;V)E8VYA('-T<F5F82!C>F%S;W=A
M.@!$;VUYMFQN82!T;[]S86UOMN8Z`%1W;VIE('!ELVYE(&EM:>H@:2!N87IW
M:7-K;SH`5'=O:6T@;F]W>6T@:&%SLV5M('<@)7,@:F5S=#H@)7,`5'=O:F4@
M=7-T87=I96YI82!Z;W-T8;-Y('5A:W1U86QN:6]N92!N82!C>F%S('1R=V%N
M:6$@=&5J('-E<VII+@!4=V]J92!U<W1A=VEE;FEA('IO<W1ALWD@=6%K='5A
M;&YI;VYE+@!4=V]J92!Z9&%L;F4@<V5R=V5R>3H`2G5G;W.S87=I80!:86ER
M`%IA;6)I80!::6UB86)W90!;4F%P;W)T(&\@<')O8FQE;6EE70!?061M:6YI
M<W1R86-J80!?0TQ)`%]5<W7Q('=I97)S>@!?1W)U<'D`7U!O;6]C`%]:86QO
M9W5J`%]7>6QO9W5J`%IM:67Q(&QI;FLN+BX`7T]P8VIE`%]5<')A=VYI96YI
M80!5<W7Q(&QI;FLN+BX`7TMO;F9I9W5R86-J80!?5;]Y=&MO=VYI8WD`:W-I
ML;]K82!A9')E<V]W80!K86QE;F1A<GH`<&QI:P!.87IW:7-K;P!N;W1A=&YI
M:P!B97H@;F%Z=WD`=D-A<F0`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQO8V%L92]P;%]03"]H96QP+GAM;```````````````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,S,R,"`Q,#4Q-30S,S<T,2`P,C$T-3,`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]X;6P@
M=F5R<VEO;CTB,2XP(C\^"CPA+2T@)$AO<F1E.B!H;W)D92]L;V-A;&4O<&Q?
M4$PO:&5L<"YX;6PL=B`Q+C(@,C`P-"\P-2\R-R`R,#HR,CHQ,R!J86X@17AP
M("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB<W5M;6%R>2(@<W1A=&4](FYE
M=R(^"CQT:71L93Y4:&4@4&]R=&%L(%!A9V4\+W1I=&QE/@H@/'!A<F$^"B`@
M5&AI<R!P;W)T86P@<&%G92!P<F]V:61E<R!A('%U:6-K('-U;6UA<GD@;V8@
M86QL('EO=7(@:6UP;W)T86YT"B`@:6YF;W)M871I;VXN($9O<B!E>&%M<&QE
M+"!I="!M:6=H="!S:&]W(&AO=R!M86YY(&YE=R!E+6UA:6P@;65S<V%G97,@
M>6]U"B`@:&%V92!I;B!Y;W5R($E.0D]8+"!U<&-O;6EN9R!E=F5N=',@;VX@
M>6]U<B!C86QE;F1A<BP@=&%S:W,@;VX@>6]U<B!T;RUD;PH@(&QI<W0L(&AE
M861L:6YE<R!F<F]M('-E;&5C=&5D(&YE=W,@<V5R=FEC97,L(&%N9"!S;R!O
M;BX@($UA;GD@;V8@=&AE<V4*("!S=6UM87)I97,@=VEL;"!C;VYT86EN('%U
M:6-K('-H;W)T8W5T<R!T;R!C;VUM;VX@9G5N8W1I;VYS+"!S=6-H(&%S"B`@
M8V]M<&]S:6YG(&$@;F5W(&UA:6P@;65S<V%G92P@8W)E871I;F<@82!N97<@
M8V%L96YD87(@979E;G0@;W(@=&%S:RP@971C+@H@/"]P87)A/@H@/'!A<F$^
M"B`@5&AE(&-O;G1E;G1S(&]F('1H:7,@<&]R=&%L('!A9V4@87)E(&-U<W1O
M;6EZ86)L92!V:6$@=&AE($QA>6]U="!B=71T;VXN"B`@1F]R(&5X86UP;&4L
M('EO=2!C86X@8VAO;W-E('=H:6-H(&ET96US('1O(&EN8VQU9&4@;VX@=&AI
M<R!P;W)T86P@<&%G92!A<PH@('=E;&P@87,@:6X@=VAI8V@@;W)D97(@=&AE
M>2!A<F4@<VAO=VXN"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)N
M879B87(B('-T871E/2)N97<B/@H\=&ET;&4^5&AE($%P<&QI8V%T:6]N($YA
M=FEG871I;VX@0F%R/"]T:71L93X*(#QP87)A/@H@($%T('1H92!L969T(&AA
M;F0@<VED92!O9B!T:&4@=V5B('!A9V4@:7,@=&AE(&%P<&QI8V%T:6]N(&YA
M=FEG871I;VX@8F%R+@H@($-L:6-K(&]N('1H92!I8V]N<R!O;B!T:&ES(&YA
M=FEG871I;VX@8F%R('1O('%U:6-K;'D@86YD(&5A<VEL>2!S=VET8V@*("!B
M971W965N('1H92!A=F%I;&%B;&4@87!P;&EC871I;VYS+@H@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&]?;6%I;G1E;F%N8V4B('-T
M871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC
M93H@1&\@36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y
M;W4@=V]U;&0@;&EK92!T;R!P97)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@;VX@;&]G:6XL(&-H96-K('1H:7,@8F]X+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M8V]N9FER;5]M86EN=&5N86YC92(@
M<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA
M;F-E.B!#;VYF:7)M($UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A/@H@
M("`@268@>6]U('=O=6QD(&QI:V4@=&\@8V]N9FER;2!A;&P@;6%I;G1E;F%N
M8V4@=&%S:W,@8F5F;W)E('1H97D@87)E(')U;BP@8VAE8VL@=&AI<R!B;W@N
M($EF(&QE9G0@=6YC:&5C:V5D+"!A;&P@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<R!T:&%T(&YE960@=&\@8F4@<G5N('=I;&P@8F4@<&5R9F]R;65D(&%U=&]M
M871I8V%L;'D@=VET:"!N;R!C:&%N8V4@=&\@8V%N8V5L(&]N(&QO9VEN+@H@
M("`@/"]P87)A/@H\+V5N=')Y/@H\+VAE;'`^"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A
M;&4O<'1?0E(`````````````````````````````````````````````````
M````````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W-#$@,#$W-S(T`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQO8V%L92]P=%]"4B],0U]-15-304=%4P``````````
M```````````````````````````````````````````````````````````P
M,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<T
M,2`P,C$U,3$`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+W!T7T)2+TQ#
M7TU%4U-!1T53+VAO<F1E+FUO````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M-#$U,34Q(#$P-3$U-#,S-S0Q(#`R,S(S-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#>$@25`````(8'```<````3#P``!,*
M``!\>````````,B@```.````R:````\```#8H```#0```.B@```(````]J``
M``L```#_H```#`````NA```$````&*$``!@````=H0``&P```#:A```M````
M4J$``!T```"`H0``)````)ZA```I````PZ$``!D```#MH0``)@````>B```,
M````+J(``"0````[H@``#P```&"B```+````<*(```X```!\H@``!0```(NB
M```H````D:(```@```"ZH@``"@```,.B```5````SJ(``!(```#DH@``"P``
M`/>B``"%`````Z,```X```")HP``"@```)BC```-````HZ,```X```"QHP``
M$0```,"C```-````TJ,```P```#@HP``#0```.VC```&````^Z,``)0````"
MI```"@```)>D```/````HJ0``!@```"RI```#````,ND```.````V*0```X`
M``#GI```"````/:D```)````_Z0``"X````)I0``&@```#BE```R````4Z4`
M`#@```"&I0``5````+^E``!1````%*8``%H```!FI@``5P```,&F```T````
M&:<```D```!.IP``#0```%BG```'````9J<```H```!NIP``#P```'FG```%
M````B:<```8```"/IP``$0```):G```(````J*<```D```"QIP``"0```+NG
M```E````Q:<``"````#KIP``$P````RH```0````(*@```\````QJ```"@``
M`$&H```#````3*@```\```!0J```%````&"H```)````=:@```T```!_J```
M$@```(VH```9````H*@``!X```"ZJ```#P```-FH```*````Z:@```\```#T
MJ```"`````2I```D````#:D``!0````RJ0``%@```$>I```(````7JD``$X`
M``!GJ0``+0```+:I```9````Y*D```<```#^J0``#`````:J```L````$ZH`
M``X```!`J@```P```$^J```+````4ZH```<```!?J@``!P```&>J```%````
M;ZH```4```!UJ@``"@```'NJ```#````AJH``!<```"*J@``"@```**J```/
M````K:H```X```"]J@``&````,RJ```C````Y:H```X````)JP``%````!BK
M```7````+:L``!<```!%JP``%P```%VK```3````=:L```\```")JP``#@``
M`)FK```?````J*L``!T```#(JP``!P```.:K```&````[JL```@```#UJP``
M#P```/ZK```&````#JP```H````5K```$P```""L```+````-*P``!````!`
MK```%0```%&L```5````9ZP```<```!]K```$````(6L```%````EJP``!4`
M``"<K```$0```+*L```,````Q*P``#L```#1K```.`````VM```)````1JT`
M``<```!0K0``%````%BM```#````;:T```4```!QK0``$````'>M```)````
MB*T``!,```"2K0``.0```*:M```2````X*T``"<```#SK0``+````!NN```J
M````2*X``"4```!SK@``"@```)FN```&````I*X```D```"KK@``!P```+6N
M```O````O:X``#<```#MK@``+@```"6O``!5````5*\``"T```"JKP``+0``
M`-BO```]````!K```#\```!$L```+0```(2P``!`````LK```",```#SL```
M(P```!>Q``!`````.[$``"T```!\L0``,P```*JQ```E````WK$``!4````$
ML@``&0```!JR```I````-+(``"0```!>L@``*````(.R```1````K+(```H`
M``"^L@``#````,FR```*````UK(``!````#AL@``%@```/*R```6````";,`
M``<````@LP``!P```"BS```4````,+,```H```!%LP``"````%"S```G````
M6;,```@```"!LP``!P```(JS```'````DK,```8```":LP``!0```*&S```'
M````I[,```8```"OLP``"````+:S```I````O[,```X```#ILP``"@```/BS
M```$`````[0```<````(M```"0```!"T```&````&K0``!$````AM```!P``
M`#.T```6````.[0```0```!2M```"````%>T```&````8+0```T```!GM```
M!@```'6T```>````?+0``!$```";M```"````*VT```-````MK0```P```#$
MM```!P```-&T```#````V;0```,```#=M```%P```.&T```3````^;0``!T`
M```-M0``"````"NU```$````-+4```@````YM0``"````$*U``!!````2[4`
M`!H```"-M0``*P```*BU```@````U+4``!4```#UM0``!@````NV```&````
M$K8``!4````9M@``&````"^V```B````2+8``"X```!KM@``'0```)JV```A
M````N+8``%0```#:M@``*0```"^W```*````6;<```<```!DMP``!P```&RW
M```5````=+<```X```"*MP``"@```)FW```/````I+<```T```"TMP``#P``
M`,*W```-````TK<```D```#@MP``%````.JW```&````_[<``!@````&N```
M'0```!^X```3````/;@``!$```!1N```%````&.X```$````>+@```8```!]
MN```%````(2X``!4````F;@``&0```#NN```!````%.Y```.````6+D```4`
M``!GN0``!0```&VY```;````<[D``!H```"/N0``$P```*JY```1````OKD`
M`!$```#0N0``'````.*Y```J````_[D``!`````JN@``(0```#NZ```%````
M7;H``!,```!CN@``"P```'>Z```2````@[H```H```"6N@``#P```*&Z```-
M````L;H``!$```"_N@``$P```-&Z```,````Y;H```8```#RN@``#````/FZ
M```&````!KL``!<````-NP``$````"6[```1````-KL```@```!(NP``!0``
M`%&[```,````5[L``!````!DNP``!0```'6[```-````>[L```8```")NP``
M!P```)"[```-````F+L```<```"FNP``"P```*Z[```'````NKL```<```#"
MNP``"0```,J[```)````U+L```H```#>NP``&0```.F[```]`````[P``!T`
M``!!O```#````%^\```0````;+P```4```!]O```)0```(.\```2````J;P`
M`!,```"\O```*P```-"\```[````_+P``"`````XO0``"````%F]```V````
M8KT``"$```"9O0``$````+N]```(````S+T```P```#5O0``!@```.*]```$
M````Z;T```\```#NO0``#@```/Z]```'````#;X```H````5O@``#0```""^
M```?````+KX``!P```!.O@``(0```&N^```>````C;X``!D```"LO@``'@``
M`,:^```;````Y;X``"$````!OP``+@```"._```F````4K\``!P```!YOP``
M'@```):_```<````M;\``"8```#2OP``*P```/F_```S````)<```"8```!9
MP```*P```(#````X````K,```!T```#EP```%0````/!```O````&<$``"``
M``!)P0``$@```&K!```I````?<$``!X```"GP0``(````,;!```2````Y\$`
M`*(```#ZP0``%@```)W"```C````M,(``"@```#8P@``*0````'#```H````
M*\,``!\```!4PP``%0```'3#```@````BL,``"4```"KPP``*````-'#```M
M````^L,``#`````HQ```D@```%G$```A````[,0``!8````.Q0``'````"7%
M```F````0L4``"H```!IQ0``00```)3%``!$````UL4```P````;Q@``!P``
M`"C&```'````,,8```8````XQ@``#0```#_&```0````3<8``!(```!>Q@``
M$P```''&```2````A<8```<```"8Q@``!````*#&```0````I<8``!````"V
MQ@``#````,?&```.````U,8```T```#CQ@``#P```/'&```3`````<<```T`
M```5QP``*````"/'```#````3,<```T```!0QP``!@```%['```1````9<<`
M`!<```!WQP``&P```(_'```.````J\<```(```"ZQP``20```+W'```%````
M!\@``!`````-R```#P```![(```$````+L@```T````SR```#@```$'(```#
M````4,@```X```!4R```"````&/(```/````;,@```\```!\R```!P```(S(
M```-````E,@``!````"BR```#0```+/(```+````P<@```8```#-R```"P``
M`-3(```,````X,@```H```#MR```$0```/C(```9````"LD```L````DR0``
M#0```##)```B````/LD``!L```!AR0``-````'W)```*````LLD``!@```"]
MR0``&0```-;)```6````\,D``"(````'R@``#0```"K*```'````.,H``!0`
M``!`R@``"P```%7*```B````8<H``"\```"$R@``"P```+3*```)````P,H`
M`!D```#*R@``"P```.3*```7````\,H``!<````(RP``"0```"#+```6````
M*LL```\```!!RP``&0```%'+```6````:\L```X```""RP``&````)'+```(
M````JLL```T```"SRP``)@```,'+``!#````Z,L```@````LS```$@```#7,
M```?````2,P```@```!HS```"P```'',```O````?<P```X```"MS```!0``
M`+S,```&````PLP``$4```#)S````P````_-```'````$\T```0````;S0``
M"@```"#-```*````*\T```\````VS0``$````$;-```7````5\T``!$```!O
MS0``&0```('-```7````F\T```D```"SS0``!0```+W-```+````P\T```H`
M``#/S0```@```-K-```%````W<T```T```#CS0``&P```/'-```7````#<X`
M`!0````ES@``"0```#K.```.````1,X```T```!3S@``$@```&'.```X````
M=,X``"````"MS@``"````,[.```.````U\X``'L```#FS@``&````&+/```8
M````>\\``!$```"4SP``!P```*;/```%````KL\``!@```"TSP``'@```,W/
M```;````[,\``!D````(T```&P```"+0```9````/M```!,```!8T```!P``
M`&S0```(````=-````8```!]T```!@```(30```0````B]````\```"<T```
M$````*S0```/````O=````L```#-T```#P```-G0```,````Z=````\```#V
MT```!P````;1```&````#M$```X````5T0``#````"31```H````,=$```\`
M``!:T0``"````&K1```(````<]$``!,```!\T0``'@```)#1```A````K]$`
M`"````#1T0``&0```/+1```7````#-(``"4````DT@``%P```$K2```6````
M8M(```0```!YT@``&P```'[2```-````FM(```P```"HT@```P```+72```%
M````N=(```@```"_T@``"@```,C2```,````T](```L```#@T@``$````.S2
M```,````_=(```X````*TP``"P```!G3```$````)=,```0````JTP``$P``
M`"_3```4````0],```P```!8TP``"0```&73```.````;],```L```!^TP``
M&P```(K3```'````IM,```<```"NTP``"@```+;3```-````P=,```D```#/
MTP``!````-G3```%````WM,```,```#DTP``&````.C3```*`````=0```0`
M```,U```)@```!'4```.````.-0``'P```!'U```%0```,34```%````VM0`
M``<```#@U```#````.C4```(````]=0```H```#^U```!@````G5```(````
M$-4```(````9U0``!@```!S5```&````(]4``!0````JU0``#0```#_5```0
M````3=4``!L```!>U0``!````'K5```)````?]4``!````")U0``"0```)K5
M```)````I-4```4```"NU0``&@```+35```(````S]4```8```#8U0``&0``
M`-_5```.````^=4```<````(U@``!P```!#6```%````&-8```D````>U@``
M"@```"C6```.````,]8```(```!"U@``!@```$76```+````3-8```T```!8
MU@``"0```&;6```&````<-8``!(```!WU@``"0```(K6```'````E-8``!0`
M``"<U@``'0```+'6``!"````S]8``"4````2UP``)0```#C7```&````7M<`
M``H```!EUP``!````'#7```)````==<```@```!_UP``$0```(C7```)````
MFM<```8```"DUP``#0```*O7```&````N=<```0```#`UP``.0```,77```]
M````_]<``#H````]V```'@```'C8```%````E]@```X```"=V```!````*S8
M```&````L=@```<```"XV```(0```,#8```-````XM@``!4```#PV```!@``
M``;9```$````#=D``!$````2V0``!@```"39```*````*]D``"(````VV0``
M!````%G9```%````7MD``!T```!DV0``!````(+9```,````A]D```X```"4
MV0``"@```*/9```(````KMD```D```"WV0``!0```,'9```Z````Q]D``#``
M```"V@``-0```#/:```I````:=H``$<```"3V@``.````-O:```I````%-L`
M`#\````^VP``+@```'[;```M````K=L``!\```#;VP``#P```/O;```2````
M"]P```L````>W```)@```"K<```I````4=P``"0```![W```)@```*#<```(
M````Q]P```H```#0W```"0```-O<```'````Y=P``"````#MW```(`````[=
M```F````+]T```H```!6W0``&0```&'=```I````>]T``!8```"EW0``$@``
M`+S=```'````S]T```H```#7W0``#````.+=```/````[]T``!````#_W0``
M0````!#>``!P````4=X``&8```#"W@``#@```"G?```)````.-\```H```!"
MWP``$@```$W?```3````8-\```P```!TWP``!@```('?```/````B-\``!(`
M``"8WP``$````*O?```1````O-\``!P```#.WP``(P```.O?``!J````#^``
M``\```!ZX```!0```(K@```0````D.````D```"AX```!````*O@```+````
ML.```"````"\X```%````-W@```,````\N````P```#_X```#P````SA```5
M````'.$``"D````RX0``*@```%SA```F````A^$``"<```"NX0``*0```-;A
M```J`````.(``!D````KX@``0@```$7B```1````B.(``!(```":X@``$P``
M`*WB```4````P>(```\```#6X@``%@```.;B```7````_>(``!`````5XP``
M$0```";C```T````..,``!,```!MXP``$@```('C```U````E.,``!0```#*
MXP``!P```-_C```,````Y^,``"````#TXP``$````!7D```4````)N0``!$`
M```[Y```%P```$WD```<````9>0``!,```""Y```%````);D```:````J^0`
M`!$```#&Y```&@```-CD```>````\^0``!H````2Y0``$P```"WE```5````
M0>4``!$```!7Y0``%P```&GE```4````@>4``!<```"6Y0``%0```*[E```)
M````Q.4``!````#.Y0``&0```-_E```$````^>4```<```#^Y0``"P````;F
M```1````$N8```8````DY@``!@```"OF```&````,N8```4````YY@``!P``
M`#_F```'````1^8```4```!/Y@``%@```%7F```&````;.8```8```!SY@``
M!````'KF```$````?^8```<```"$Y@``#@```(SF```,````F^8```P```"H
MY@``#0```+7F```*````P^8```X```#.Y@``!0```-WF```H````X^8```X`
M```,YP``#````!OG```/````*.<```H````XYP``"````$/G```)````3.<`
M`"L```!6YP``!````(+G```(````A^<``"8```"0YP``$@```+?G```/````
MRN<```8```#:YP``"@```.'G```'````[.<```@```#TYP``(````/WG```)
M````'N@``!0````HZ```#````#WH```-````2N@```X```!8Z```%@```&?H
M```1````?N@```8```"0Z````P```)?H```&````F^@``!D```"BZ```!P``
M`+SH```$````Q.@```L```#)Z```"P```-7H```'````X>@```4```#IZ```
M!P```._H```6````]^@```T````.Z0``#0```!SI```*````*ND``!`````U
MZ0``#P```$;I```1````5ND``!<```!HZ0``"@```(#I```1````B^D```@`
M``"=Z0``!````*;I```/````J^D``#H```"[Z0``!0```/;I```,````_.D`
M`!X````)Z@``#@```"CJ```0````-^H```L```!(Z@``#````%3J```)````
M8>H```<```!KZ@``"@```'/J```)````?NH```X```"(Z@``$````)?J```;
M````J.H``!@```#$Z@``&@```-WJ```*````^.H```D````#ZP``"@````WK
M```,````&.L```\````EZP``"````#7K```&````/NL``!P```!%ZP``!P``
M`&+K```%````:NL```L```!PZP``1P```'SK```-````Q.L```D```#2ZP``
M!````-SK```#````X>L``!,```#EZP``$P```/GK```3````#>P```H````A
M[````@```"SL```$````+^P``"4````T[````P```%KL```%````7NP``"H`
M``!D[```"@```(_L```%````FNP```0```"@[```"@```*7L```-````L.P`
M``8```"^[```"````,7L```(````SNP```0```#7[```!0```-SL``!H````
MXNP```D```!+[0``#````%7M```0````8NT```4```!S[0``!@```'GM```;
M````@.T``"\```"<[0``$````,SM```*````W>T```\```#H[0``"@```/CM
M```)`````^X``!,````-[@``&P```"'N```8````/>X``!<```!6[@``'P``
M`&[N```.````CNX```,```"=[@``!P```*'N```(````J>X```<```"R[@``
M"@```+KN```+````Q>X```<```#1[@``40```-GN```0````*^\```P````\
M[P``#0```$GO```:````5^\``$H```!R[P``&0```+WO```&````U^\``!H`
M``#>[P``)0```/GO```&````'_````8````F\```'P```"WP```&````3?``
M``D```!4\```&````%[P```7````=_```"@```"/\```!@```+CP```-````
MO_```"(```#-\```5P```/#P```3````2/$``",```!<\0``$P```(#Q```"
M````E/$```L```"7\0``"````*/Q```-````K/$```H```"Z\0``!P```,7Q
M```4````S?$```8```#B\0``"````.GQ```.````\O$```<````!\@``"@``
M``GR```+````%/(``#(````@\@``!P```%/R```,````6_(```T```!H\@``
M#````';R```)````@_(```D```"-\@``"@```)?R```'````HO(```D```"J
M\@``!P```+3R```*````O/(``!L```#'\@``#P```./R```2````\_(```H`
M```&\P``%@```!'S```)````*/,``!`````R\P``!P```$/S```2````2_,`
M``0```!>\P``!P```&/S```%````:_,```4```!Q\P``"P```'?S```4````
M@_,``!$```"8\P``&@```*KS```6````Q?,``!0```#<\P``%P```/'S```8
M````"?0``!P````B]```&0```#_T```'````6?0```4```!A]```#0```&?T
M```,````=?0``!$```""]```"````)3T```7````G?0```L```"U]```#```
M`,'T```?````SO0``!H```#N]```$P````GU```$````'?4```H````B]0``
M!````"WU```-````,O4```P```!`]0``!0```$WU```)````4_4```4```!=
M]0``!P```&/U```%````:_4```0```!Q]0```@```';U```X````>?4``"P`
M``"R]0``$@```-_U```I````\O4``#(````<]@``"@```$_V```L````6O8`
M`"X```"']@``,P```+;V```S````ZO8``#@````>]P``#P```%?W```8````
M9_<``!````"`]P``#P```)'W```3````H?<``!4```"U]P``%````,OW```2
M````X/<``!0```#S]P``%0````CX```M````'O@``"T```!,^```,0```'KX
M```N````K/@``"\```#;^```+`````OY``!B````./D``!,```";^0``#0``
M`*_Y```(````O?D``!<```#&^0``"````-[Y```,````Y_D``"L```#T^0``
M(0```"#Z```:````0OH```D```!=^@``10```&?Z``!!````K?H```0```#O
M^@``$P```/3Z```4````"/L```X````=^P``$P```"S[```8````0/L```8`
M``!9^P``"0```&#[```*````:OL```\```!U^P``$````(7[```'````EOL`
M``X```">^P``!0```*W[```;````L_L```@```#/^P``!@```-C[```4````
MW_L``!$```#T^P``#@````;\```X````%?P```(```!._```!@```%'\```.
M````6/P```4```!G_```!P```&W\```.````=?P```8```"$_```*````(O\
M```,````M/P``!P```#!_```!````-[\```I````X_P``!<````-_0``'P``
M`"7]``!<````1?T``!0```"B_0``/@```+?]```?````]OT``!`````6_@``
M!P```"?^```.````+_X```P````^_@``#````$O^```3````6/X```H```!L
M_@``'0```'?^```9````E?X```4```"O_@``$0```+7^```1````Q_X``"0`
M``#9_@``$@```/[^```5````$?\``!(````G_P``#@```#K_```9````2?\`
M``@```!C_P``"0```&S_```-````=O\```<```"$_P``"@```(S_```'````
ME_\```\```"?_P``!@```*__```+````MO\``!H```#"_P``"@```-W_```'
M````Z/\```@```#P_P``!0```/G_```?````__\```8````?``$`$````"8`
M`0`(````-P`!``T```!```$`"````$X``0`>````5P`!`!(```!V``$`+```
M`(D``0`:````M@`!``D```#1``$`"@```-L``0`5````Y@`!``4```#\``$`
M%`````(!`0`$````%P$!`!`````<`0$`!@```"T!`0`'````-`$!`!X````\
M`0$`*````%L!`0`*````A`$!`!P```"/`0$`$0```*P!`0`+````O@$!`!H`
M``#*`0$`%````.4!`0`$````^@$!``0```#_`0$`"P````0"`0`%````$`(!
M``8````6`@$`"````!T"`0`&````)@(!``H````M`@$`&P```#@"`0`T````
M5`(!`#0```")`@$`(````+X"`0`I````WP(!`"`````)`P$`00```"H#`0`:
M````;`,!`"@```"'`P$`*0```+`#`0!0````V@,!`"(````K!`$`!@```$X$
M`0`(````500!``4```!>!`$`"````&0$`0`9````;00!`!D```"'!`$`*@``
M`*$$`0`C````S`0!`!D```#P!`$`+@````H%`0`T````.04!``@```!N!0$`
M%P```'<%`0`*````CP4!``<```":!0$`(0```*(%`0`0````Q`4!``X```#5
M!0$`"P```.0%`0`'````\`4!`!,```#X!0$`"`````P&`0`+````%08!``H`
M```A!@$`%````"P&`0`/````008!`#(```!1!@$`"P```(0&`0`%````D`8!
M``4```"6!@$`!0```)P&`0`7````H@8!``\```"Z!@$`!````,H&`0`*````
MSP8!``D```#:!@$`"P```.0&`0`-````\`8!``P```#^!@$`#@````L'`0`%
M````&@<!``0````@!P$`#0```"4'`0`R````,P<!`$4```!F!P$`%P```*P'
M`0`'````Q`<!`!X```#,!P$`%````.L'`0`%``````@!`!0````&"`$`!@``
M`!L(`0`'````(@@!``X````J"`$`*@```#D(`0`&````9`@!``P```!K"`$`
M#0```'@(`0`1````A@@!``L```"8"`$`-@```*0(`0`*````VP@!`"(```#F
M"`$`"P````D)`0`/````%0D!`#(````E"0$`)0```%@)`0`P````?@D!`#$`
M``"O"0$`+0```.$)`0`.````#PH!``4````>"@$`#@```"0*`0`3````,PH!
M`!(```!'"@$`!P```%H*`0`1````8@H!`!,```!T"@$`!P```(@*`0`4````
MD`H!`!@```"E"@$`!P```+X*`0`%````Q@H!``P```#,"@$`#````-D*`0`2
M````Y@H!``0```#Y"@$`!P```/X*`0`*````!@L!``L````1"P$`#````!T+
M`0`.````*@L!``X````Y"P$`!0```$@+`0`%````3@L!`"X```!4"P$`)@``
M`(,+`0`C````J@L!``,```#."P$`$@```-(+`0`&````Y0L!`!X```#L"P$`
M&`````L,`0`E````)`P!``T```!*#`$`"0```%@,`0`?````8@P!``,```""
M#`$`!P```(8,`0`*````C@P!``(```"9#`$`#````)P,`0`5````J0P!``L`
M``"_#`$`&0```,L,`0`@````Y0P!`!(````&#0$`!0```!D-`0`*````'PT!
M`!4````J#0$`$@```$`-`0`,````4PT!``0```!@#0$`"0```&4-`0`'````
M;PT!``P```!W#0$`4@```(0-`0`7````UPT!`"0```#O#0$`$@```!0.`0`'
M````)PX!``8````O#@$`#@```#8.`0`,````10X!``T```!2#@$`%0```&`.
M`0`2````=@X!``\```")#@$`%````)D.`0`*````K@X!`!L```"Y#@$`$```
M`-4.`0`+````Y@X!`&D```#R#@$`&@```%P/`0`7````=P\!`"<```"/#P$`
M&@```+</`0`7````T@\!`!L```#J#P$`&0````80`0`?````(!`!`!,```!`
M$`$`"````%00`0`'````71`!``@```!E$`$`"0```&X0`0`5````>!`!``T`
M``".$`$`(P```)P0`0`-````P!`!`!,```#.$`$`"````.(0`0`#````ZQ`!
M`$8```#O$`$`/P```#81`0`W````=A$!`%<```"N$0$`!0````82`0`?````
M#!(!`"\````L$@$`"@```%P2`0`(````9Q(!``T```!P$@$`+0```'X2`0`$
M````K!(!`$\```"Q$@$`)0````$3`0`<````)Q,!``L```!$$P$`'P```%`3
M`0`=````<!,!`"4```".$P$`(````+03`0`D````U1,!`"````#Z$P$`"P``
M`!L4`0`'````)Q0!``T````O%`$`#````#T4`0`7````2A0!``8```!B%`$`
M.0```&D4`0`,````HQ0!``<```"P%`$`"0```+@4`0`3````PA0!``D```#6
M%`$`!````.`4`0`0````Y10!``@```#V%`$`"````/\4`0`$````"!4!``L`
M```-%0$`#````!D5`0`2````)A4!`!$````Y%0$`#````$L5`0`:````6!4!
M``\```!S%0$`!P```(,5`0`-````BQ4!`!0```"9%0$`#@```*X5`0`,````
MO14!`!L```#*%0$`+````.85`0`3````$Q8!`!P````G%@$`*````$06`0`&
M````;18!``<```!T%@$`$P```'P6`0`%````D!8!``0```"6%@$`%P```)L6
M`0`*````LQ8!``P```"^%@$`"0```,L6`0`&````U18!``D```#<%@$`"```
M`.86`0`)````[Q8!``H```#Y%@$`$0````07`0`&````%A<!``X````=%P$`
M#@```"P7`0`-````.Q<!``L```!)%P$`'0```%47`0`+````<Q<!``(```!_
M%P$`'````((7`0`'````GQ<!``8```"G%P$`9````*X7`0`)````$Q@!``<`
M```=&`$`)@```"48`0`X````3!@!`!H```"%&`$`*@```*`8`0`[````RQ@!
M`"@````'&0$`-````#`9`0`9````91D!`!4```!_&0$`!0```)49`0`'````
MFQD!``@```"C&0$`!P```*P9`0`%````M!D!``<```"Z&0$`#@```,(9`0`)
M````T1D!``8```#;&0$`"````.(9`0`+````ZQD!``<```#W&0$`"````/\9
M`0`'````"!H!`!8````0&@$`"0```"<:`0`&````,1H!``L````X&@$`$```
M`$0:`0`&````51H!`!P```!<&@$`%````'D:`0`'````CAH!`!$```"6&@$`
M"````*@:`0`.````L1H!``@```#`&@$`!0```,D:`0`0````SQH!``D```#@
M&@$`$````.H:`0`&````^QH!`!D````"&P$`"@```!P;`0`<````)QL!``<`
M``!$&P$`!0```$P;`0`0````4AL!`!0```!C&P$`"P```'@;`0`-````A!L!
M`"@```"2&P$`&````+L;`0`7````U!L!``0```#L&P$`"0```/$;`0`*````
M^QL!``<````&'`$``@````X<`0`.````$1P!``@````@'`$`(P```"D<`0`?
M````31P!`#@```!M'`$`)@```*8<`0`Q````S1P!`"<```#_'`$`9````"<=
M`0`4````C!T!`%4```"A'0$`.````/<=`0!*````,!X!`%L```!['@$`*```
M`-<>`0`X`````!\!`"@````Y'P$`+````&(?`0`F````CQ\!`!L```"V'P$`
M/@```-(?`0"I`0``$2`!`",```"[(0$`%P```-\A`0!(````]R$!`(4```!`
M(@$`,````,8B`0`E````]R(!`$$````=(P$`6P```%\C`0!)````NR,!`#$`
M```%)`$`'0```#<D`0`8````520!`"L```!N)`$`(0```)HD`0`?````O"0!
M`"L```#<)`$`)@````@E`0`G````+R4!`#H```!7)0$`'0```)(E`0`1````
ML"4!`#,```#")0$`)0```/8E`0`G````'"8!`"````!$)@$`'P```&4F`0`P
M````A28!`&D```"V)@$`,0```"`G`0!!````4B<!`#,```"4)P$`)0```,@G
M`0`]````[B<!`&4````L*`$`30```)(H`0`O````X"@!`"X````0*0$`,```
M`#\I`0!4````<"D!`%H```#%*0$`2````"`J`0!*````:2H!`#(```"T*@$`
M+P```.<J`0`L````%RL!`"T```!$*P$`<0```'(K`0!F````Y"L!`&\```!+
M+`$`LP```+LL`0`7````;RT!`"4```"'+0$`,@```*TM`0`I````X"T!`#X`
M```*+@$`(@```$DN`0!2````;"X!`"4```"_+@$`"P```.4N`0"Q````\2X!
M`$4```"C+P$`(0```.DO`0`P````"S`!`"4````\,`$`'````&(P`0`Q````
M?S`!``<```"Q,`$`!P```+DP`0`$````P3`!``T```#&,`$`"P```-0P`0`.
M````X#`!``L```#O,`$`!0```/LP`0`0`````3$!``(````2,0$`60```!4Q
M`0`%````;S$!`!(```!U,0$`!````(@Q`0`'````C3$!``@```"5,0$`!0``
M`)XQ`0`#````I#$!`!````"H,0$`#````+DQ`0`3````QC$!``T```#:,0$`
M`@```.@Q`0`'````ZS$!``8```#S,0$`%````/HQ`0`,````#S(!`!@````<
M,@$`!@```#4R`0`2````/#(!``P```!/,@$``P```%PR`0`J````8#(!``0`
M``"+,@$`!@```)`R`0`'````ES(!`!\```"?,@$`-0```+\R`0`N````]3(!
M`"\````D,P$`%P```%0S`0`B````;#,!`"4```"/,P$`(````+4S`0`;````
MUC,!`!@```#R,P$`)`````LT`0`?````,#0!`!H```!0-`$`(0```&LT`0`@
M````C30!`!H```"N-`$`,@```,DT`0`:````_#0!`"\````7-0$`*P```$<U
M`0`?````<S4!`",```"3-0$`'P```+<U`0`:````US4!`"$```#R-0$`)0``
M`!0V`0`F````.C8!`"4```!A-@$`)````(<V`0`8````K#8!`!T```#%-@$`
M)````.,V`0`8````"#<!`"(````A-P$`+````$0W`0`O````<3<!`!4```"A
M-P$`)0```+<W`0`\````W3<!`!\````:.`$`(P```#HX`0`?````7C@!`"``
M``!^.`$`&@```)\X`0`8````NC@!`"8```#3.`$`'@```/HX`0`I````&3D!
M`!X```!#.0$`,0```&(Y`0`)````E#D!``P```">.0$`%P```*LY`0`O````
MPSD!`"0```#S.0$`!P```!@Z`0`/````(#H!`!0````P.@$`#@```$4Z`0`-
M````5#H!`"0```!B.@$`!0```(<Z`0`'````C3H!`"(```"5.@$`)0```+@Z
M`0`:````WCH!`!T```#Y.@$`&@```!<[`0`'````,CL!`,<````Z.P$`"P``
M``(\`0`5````#CP!``8````D/`$`"0```"L\`0`+````-3P!``T```!!/`$`
M%P```$\\`0`&````9SP!`#,```!N/`$`$P```*(\`0`3````MCP!``<```#*
M/`$`#P```-(\`0`'````XCP!`#(```#J/`$`!````!T]`0`A````(CT!`!,`
M``!$/0$`#````%@]`0`1````93T!`#(```!W/0$`%@```*H]`0`(````P3T!
M`!T```#*/0$`"0```.@]`0`*````\CT!`!0```#]/0$`"@```!(^`0`=````
M'3X!``@````[/@$`'P```$0^`0`(````9#X!`!H```!M/@$`)P```(@^`0`&
M````L#X!`!4```"W/@$`!P```,T^`0`(````U3X!``D```#>/@$`/P```.@^
M`0`'````*#\!``\````P/P$`#@```$`_`0`0````3S\!``D```!@/P$`"0``
M`&H_`0`(````=#\!`!,```!]/P$`!P```)$_`0`9````F3\!``H```"S/P$`
M%P```+X_`0`4````UC\!``H```#K/P$`#````/8_`0`7`````T`!``0````;
M0`$`*@```"!``0`,````2T`!`!$```!80`$`!P```&I``0`"````<D`!`!``
M``!U0`$`&````(9``0`+````GT`!``,```"K0`$`"````*]``0`&````N$`!
M``<```"_0`$`#0```,=``0`+````U4`!`!0```#A0`$`%0```/9``0`.````
M#$$!`"\````;00$`(````$M!`0`<````;$$!`!4```")00$`#````)]!`0`Q
M````K$$!``4```#>00$`$@```.1!`0`_````]T$!`!(````W0@$`"@```$I"
M`0`&````54(!``0```!<0@$`!````&%"`0`*````9D(!`!,```!Q0@$`!0``
M`(5"`0`&````BT(!``8```"20@$`"````)E"`0`$````HD(!``P```"G0@$`
M"@```+1"`0`Y````OT(!`"X```#Y0@$`*0```"A#`0`%````4D,!`!@```!8
M0P$`&0```'%#`0`?````BT,!`!T```"K0P$`$0```,E#`0`"````VT,!``0`
M``#>0P$`"@```.-#`0`&````[D,!``4```#U0P$``P```/M#`0`,````_T,!
M`$4````,1`$`,@```%)$`0`:````A40!`#0```"@1`$`*````-5$`0!3````
M_D0!`!D```!210$`<@```&Q%`0`@````WT4!`#4`````1@$`(0```#9&`0!%
M````6$8!`#````">1@$`*````,]&`0`I````^$8!`"8````B1P$`)0```$E'
M`0`H````;T<!`"@```"81P$`(@```,%'`0`K````Y$<!`#`````02`$`$@``
M`$%(`0`3````5$@!`!````!H2`$`>0```'E(`0`)````\T@!`*$```#]2`$`
M<P```)])`0!\````$TH!`"L```"02@$`5````+Q*`0`7````$4L!`"<````I
M2P$`%@```%%+`0`/````:$L!`!<```!X2P$`'P```)!+`0!`````L$L!`!\`
M``#Q2P$`'````!%,`0!1````+DP!`!H```"`3`$`%````)M,`0`*````L$P!
M``4```"[3`$`!@```,%,`0`(````R$P!``4```#13`$`$@```-=,`0`0````
MZDP!`!,```#[3`$`'0````]-`0`/````+4T!``\````]30$`!````$U-`0`)
M````4DT!``L```!<30$`!P```&A-`0`%````<$T!`!0```!V30$`!P```(M-
M`0`(````DTT!``\```"<30$`"````*Q-`0`,````M4T!``\```#"30$`!@``
M`-)-`0`4````V4T!``8```#N30$`#````/5-`0`1`````DX!``@````43@$`
M!````!U.`0`9````(DX!`!$````\3@$`"@```$Y.`0`8````64X!`!,```!R
M3@$`'````(9.`0`1````HTX!``0```"U3@$`#P```+I.`0`'````RDX!``0`
M``#23@$`&0```-=.`0`'````\4X!``(```#Y3@$``@```/Q.`0`1````_TX!
M``D````13P$`!@```!M/`0`2````(D\!`!<````U3P$`!@```$U/`0`G````
M5$\!``(```!\3P$`!````']/`0`/````A$\!`!,```"43P$`!P```*A/`0`'
M````L$\!`!$```"X3P$`!@```,I/`0`8````T4\!``8```#J3P$`$P```/%/
M`0`0````!5`!`!(````64`$``@```"E0`0`&````+%`!``P````S4`$`"0``
M`$!0`0`1````2E`!`"(```!<4`$`!P```']0`0`'````AU`!``L```"/4`$`
M!0```)M0`0`"````H5`!``L```"D4`$`I0$``+!0`0`0````5E(!`!4```!G
M4@$`#0```'U2`0`'````BU(!``D```"34@$`"````)U2`0`#````IE(!`!@`
M``"J4@$`'@```,-2`0`O````XE(!`"L````24P$`*0```#Y3`0`M````:%,!
M`!D```"64P$`*@```+!3`0`*````VU,!`!X```#F4P$`$@````54`0`*````
M&%0!`!<````C5`$`!0```#M4`0`H````050!`!(```!J5`$`#@```'U4`0`3
M````C%0!``T```"@5`$`"@```*Y4`0"2````N50!`!````!,50$`"@```%U5
M`0`2````:%4!``T```![50$`&P```(E5`0`,````I54!``\```"R50$`%@``
M`,)5`0`&````V54!`)D```#@50$`"````'I6`0`-````@U8!`!@```"15@$`
M#P```*I6`0`0````NE8!`!````#+5@$`"````-Q6`0`0````Y58!`#P```#V
M5@$`%0```#-7`0!#````25<!`$D```"-5P$`50```-=7`0!-````+5@!`'(`
M``![6`$`:@```.Y8`0!&````65D!`!````"@60$`%@```+%9`0`.````R%D!
M`!````#760$`$@```.A9`0`%````^UD!``8````!6@$`$0````A:`0`(````
M&EH!``D````C6@$`"0```"U:`0`E````-UH!`",```!=6@$`$````(%:`0`.
M````DEH!`!$```"A6@$`!@```+-:`0`)````NEH!`!L```#$6@$`(0```.!:
M`0`.`````EL!`!0````16P$`&````"9;`0`E````/UL!`"H```!E6P$`&@``
M`)!;`0`0````JUL!`!<```"\6P$`#0```-1;`0`U````XEL!`",````87`$`
M)@```#Q<`0`1````8UP!`%@```!U7`$`-@```,Y<`0`E````!5T!``@````K
M70$`%0```#1=`0`W````2ET!``T```""70$`"````)!=`0`+````F5T!``<`
M``"E70$`!P```*U=`0`'````M5T!``<```"]70$`#````,5=`0`%````TET!
M`!L```#870$`#````/1=`0`0`````5X!`!(````27@$`'````"5>`0`O````
M0EX!``D```!R7@$`%@```'Q>`0`6````DUX!`!@```"J7@$`'@```,->`0`4
M````XEX!`!(```#W7@$`#P````I?`0`A````&E\!`!T````\7P$`!P```%I?
M`0`&````8E\!``@```!I7P$`#0```')?`0`(````@%\!``D```")7P$`$@``
M`)-?`0`)````IE\!`!,```"P7P$`&````,1?`0`J````W5\!``<````(8`$`
M$@```!!@`0`%````(V`!`!8````I8`$`$@```$!@`0`/````4V`!`$(```!C
M8`$`.@```*9@`0`)````X6`!``<```#K8`$`$P```/-@`0`$````!V$!``4`
M```,80$`#0```!)A`0`*````(&$!`!<````K80$`0P```$-A`0`5````AV$!
M`"0```"=80$`*P```,)A`0`J````[F$!`#`````98@$`"0```$IB`0`&````
M5&(!``D```!;8@$`!P```&5B`0`[````;6(!`#T```"I8@$`.@```.=B`0!?
M````(F,!`#D```""8P$`.0```+QC`0!%````]F,!`$4````\9`$`.0```()D
M`0!2````O&0!`"H````/90$`+````#IE`0!)````9V4!`#D```"Q90$`/P``
M`.ME`0`E````*V8!`!4```!19@$`&0```&=F`0`L````@68!`"8```"N9@$`
M)@```-5F`0`3````_&8!``H````09P$`$0```!MG`0`%````+6<!``P````S
M9P$`&0```$!G`0`;````6F<!``<```!V9P$`!P```'YG`0`5````AF<!``H`
M``"<9P$`"````*=G`0`T````L&<!`!````#E9P$`"@```/9G`0`'`````6@!
M``8````):`$`!0```!!H`0`(````%F@!``4````?:`$`"P```"5H`0`R````
M,6@!`!8```!D:`$`#0```'MH`0`'````B6@!``<```"1:`$`"0```)EH`0`%
M````HV@!`!$```"I:`$`!@```+MH`0`4````PF@!``4```#7:`$`"````-UH
M`0`&````YF@!``L```#M:`$`!@```/EH`0`B`````&D!``8````C:0$`"```
M`"II`0`4````,VD!``P```!(:0$`!P```%5I`0`#````76D!``,```!A:0$`
M&@```&5I`0`:````@&D!`"T```";:0$`!@```,EI`0`%````T&D!``@```#6
M:0$`"````-]I`0!:````Z&D!`"$```!#:@$`/````&5J`0`L````HFH!`"$`
M``#/:@$`!@```/%J`0`(````^&H!`!X````!:P$`)@```"!K`0`Q````1VL!
M`#8```!Y:P$`*````+!K`0`O````V6L!`&T````);`$`.@```'=L`0`*````
MLFP!``8```"];`$`"0```,1L`0`2````SFP!``P```#A;`$`$````.YL`0`6
M````_VP!`!$````6;0$`%@```"AM`0`6````/VT!`!````!6;0$`%0```&=M
M`0`&````?6T!`!L```"$;0$`&P```*!M`0`7````O&T!`!L```#4;0$`&```
M`/!M`0`&````"6X!``<````0;@$`$````!AN`0!<````*6X!`&````"&;@$`
M!````.=N`0`2````[&X!``4```#_;@$`!0````5O`0`<````"V\!`!D````H
M;P$`%````$)O`0`1````5V\!`!(```!I;P$`&@```'QO`0`Z````EV\!``\`
M``#2;P$`+P```.)O`0`&````$G`!`!0````9<`$`#P```"YP`0`3````/G`!
M``\```!2<`$`&````&)P`0`2````>W`!`!4```".<`$`$P```*1P`0`-````
MN'`!``8```#&<`$`$@```,UP`0`'````X'`!``X```#H<`$`%@```/=P`0`/
M````#G$!``@````><0$``P```"=Q`0`0````*W$!``X````\<0$`!0```$MQ
M`0`3````47$!``H```!E<0$`!P```'!Q`0`0````>'$!``@```")<0$`!```
M`))Q`0`'````EW$!``<```"?<0$`#````*=Q`0`(````M'$!``D```"]<0$`
M&@```,=Q`0`^````XG$!`"8````A<@$`#0```$AR`0`0````5G(!``4```!G
M<@$`'P```&UR`0`1````C7(!`!(```"?<@$`,@```+)R`0!"````Y7(!`"$`
M```H<P$`"````$IS`0!'````4W,!`"@```";<P$`$````,1S`0`)````U7,!
M``H```#?<P$`!@```.IS`0`&````\7,!`!(```#X<P$`#@````MT`0`+````
M&G0!``H````F=`$`#P```#%T`0`L````070!`"<```!N=`$`-````)9T`0`O
M````RW0!`"8```#[=`$`*P```")U`0`F````3G4!`"4```!U=0$`/0```)MU
M`0`R````V74!`"D````,=@$`+P```#9V`0`F````9G8!`#0```"-=@$`1@``
M`,)V`0!!````"7<!`#T```!+=P$`/0```(EW`0!'````QW<!`"P````/>`$`
M*````#QX`0!&````97@!`"H```"L>`$`&@```-=X`0`U````\G@!`"@````H
M>0$`+````%%Y`0`8````?GD!`,D```"7>0$`'````&%Z`0`R````?GH!`#(`
M``"Q>@$`-````.1Z`0`Q````&7L!`"D```!+>P$`*@```'5[`0`J````H'L!
M`#(```#+>P$`-0```/Y[`0!)````-'P!`#L```!^?`$`J0```+I\`0`L````
M9'T!`"4```"1?0$`*````+=]`0`V````X'T!`#(````7?@$`60```$I^`0!.
M````I'X!``T```#S?@$`!`````%_`0`&````!G\!``4````-?P$`#0```!-_
M`0`.````(7\!`!`````P?P$`%0```$%_`0`;````5W\!``<```!S?P$`!```
M`'M_`0`.````@'\!``X```"/?P$`"@```)Y_`0`-````J7\!`!,```"W?P$`
M"P```,M_`0`0````UW\!``P```#H?P$`-@```/5_`0`&````+(`!``X````S
M@`$`!@```$*``0`1````28`!`!<```!;@`$`&P```'.``0`0````CX`!``(`
M``"@@`$`2@```*.``0`+````[H`!`!4```#Z@`$`&@```!"!`0`$````*X$!
M`!,````P@0$`#P```$2!`0`#````5($!``\```!8@0$`"````&B!`0`0````
M<8$!`!````""@0$`!@```).!`0`*````FH$!`!$```"E@0$`#````+>!`0`*
M````Q($!``<```#/@0$`#@```->!`0`-````YH$!``L```#T@0$`$0````""
M`0`:````$H(!``X````M@@$`#@```#R"`0`C````2X(!`!P```!O@@$`/```
M`(R"`0`-````R8(!`!X```#7@@$`%@```/:"`0`5````#8,!`#0````C@P$`
M#P```%B#`0`)````:(,!`!,```!R@P$`"0```(:#`0`U````D(,!`#<```#&
M@P$`#P```/Z#`0`0````#H0!`"4````?A`$`$@```$6$`0`@````6(0!`"``
M``!YA`$`"0```)J$`0`;````I(0!`!(```#`A`$`&0```-.$`0`5````[80!
M``X````#A0$`&0```!*%`0`'````+(4!``L````TA0$`)@```$"%`0!(````
M9X4!``H```"PA0$`%````+N%`0`?````T(4!``8```#PA0$`"0```/>%`0`P
M`````88!`!`````RA@$`!@```$.&`0`'````2H8!`%0```!2A@$``P```*>&
M`0`'````JX8!``8```"SA@$`#````+J&`0`,````QX8!`!````#4A@$`$0``
M`.6&`0`9````]X8!`!$````1AP$`&0```".'`0`9````/8<!``@```!7AP$`
M!0```&"'`0`+````9H<!``L```!RAP$``@```'Z'`0`&````@8<!`!(```"(
MAP$`)P```)N'`0`8````PX<!`!D```#<AP$`"0```/:'`0`3`````(@!`!0`
M```4B`$`'````"F(`0!&````1H@!`"\```"-B`$`#````+V(`0`/````RH@!
M`(H```#:B`$`'````&6)`0`8````@HD!`!````";B0$`"````*R)`0`$````
MM8D!`!<```"ZB0$`*P```-*)`0`H````_HD!`!H````GB@$`'0```$**`0`1
M````8(H!`!,```!RB@$`!P```(:*`0`'````CHH!``8```"6B@$`!@```)V*
M`0`/````I(H!``X```"TB@$`$````,.*`0`.````U(H!``P```#CB@$`#@``
M`/"*`0`+````_XH!`!,````+BP$`"````!^+`0`(````*(L!`!8````QBP$`
M#````$B+`0`U````58L!`!$```"+BP$`"````)V+`0`5````IHL!`"4```"\
MBP$`&P```.*+`0`C````_HL!`"(````BC`$`&````$6,`0`:````7HP!`"4`
M``!YC`$`&0```)^,`0`2````N8P!``4```#,C`$`&0```-*,`0`+````[(P!
M``L```#XC`$``P````2-`0`%````"(T!``D````.C0$`$````!B-`0`2````
M*8T!`!$````\C0$`"@```$Z-`0`/````68T!``X```!IC0$`#````'B-`0`$
M````A8T!``<```"*C0$`(````)*-`0`A````LXT!`!<```#5C0$`#P```.V-
M`0`2````_8T!`!`````0C@$`(@```"&.`0`'````1(X!``D```!,C@$`#P``
M`%:.`0`/````9HX!``D```!VC@$`!0```(".`0`*````AHX!``4```"1C@$`
M$P```)>.`0`,````JXX!``8```"XC@$`*0```+^.`0`.````Z8X!`(,```#X
MC@$`$0```'R/`0`+````CH\!``4```":CP$`#0```*"/`0`&````KH\!``@`
M``"UCP$`!@```+Z/`0`1````Q8\!``,```#7CP$`!P```-N/`0`&````XX\!
M`!0```#JCP$`#P```/^/`0`2````#Y`!`!P````BD`$``@```#^0`0`%````
M0I`!`!(```!(D`$`"0```%N0`0`-````99`!``4```!SD`$`(````'F0`0`(
M````FI`!``8```"CD`$`&@```*J0`0`-````Q9`!``<```#3D`$`"````-N0
M`0`$````Y)`!``D```#ID`$`#0```/.0`0`.`````9$!``(````0D0$`!@``
M`!.1`0`,````&I$!`!,````GD0$`$````#N1`0`&````3)$!`!(```!3D0$`
M"@```&:1`0`'````<9$!`!<```!YD0$`*0```)&1`0!*````NY$!`"<````&
MD@$`*0```"Z2`0`&````6)(!``D```!?D@$`!````&F2`0`)````;I(!``@`
M``!XD@$`%P```(&2`0`0````F9(!``4```"JD@$`#````+"2`0`&````O9(!
M``0```#$D@$`00```,F2`0!"````"Y,!`$$```!.DP$`(0```)"3`0`%````
MLI,!``X```"XDP$`!P```,>3`0`)````SY,!``D```#9DP$`&P```..3`0`0
M````_Y,!`!4````0E`$`!@```":4`0`%````+90!``\````SE`$`"@```$.4
M`0`*````3I0!`!X```!9E`$`!````'B4`0`'````?90!`"0```"%E`$`!@``
M`*J4`0`4````L90!`!$```#&E`$`$````-B4`0`(````Z90!``D```#RE`$`
M!0```/R4`0`[`````I4!`#8````^E0$`0P```'65`0`I````N94!`$(```#C
ME0$`0@```":6`0`K````:98!`$H```"5E@$`+P```."6`0`Y````$)<!`"\`
M``!*EP$`$````'J7`0`1````BY<!``L```"=EP$`+0```*F7`0`I````UY<!
M`"$````!F`$`*````".8`0`'````3)@!``D```!4F`$`"@```%Z8`0`'````
M:9@!`"0```!QF`$`)@```):8`0`M````O9@!``L```#KF`$`&P```/>8`0`M
M````$YD!`!@```!!F0$`$P```%J9`0`(````;ID!``X```!WF0$`#@```(:9
M`0`.````E9D!`!,```"DF0$`1````+B9`0!^````_9D!`'$```!\F@$`&P``
M`.Z:`0`-````"IL!``X````8FP$`$0```">;`0`2````.9L!``\```!,FP$`
M!P```%R;`0`2````9)L!`!,```!WFP$`$@```(N;`0`3````GIL!`"@```"R
MFP$`'@```-N;`0"$````^IL!`!(```!_G`$`!0```)*<`0`4````F)P!``D`
M``"MG`$`"@```+><`0`*````PIP!`!\```#-G`$`%````.V<`0`.`````IT!
M``X````1G0$`$P```""=`0`5````-)T!`"0```!*G0$`)@```&^=`0`C````
MEIT!`"4```"ZG0$`(0```."=`0`C`````IX!`!T````FG@$`10```$2>`0`3
M````BIX!`!0```">G@$`$P```+.>`0`4````QYX!`!$```#<G@$`%@```.Z>
M`0`7````!9\!`!(````=GP$`$P```#"?`0`\````1)\!`!8```"!GP$`%```
M`)B?`0`^````K9\!`!4```#LGP$`#@````*@`0`1````$:`!`"T````CH`$`
M$P```%&@`0`3````9:`!`"````!YH`$`'0```)J@`0`?````N*`!`!T```#8
MH`$`&P```/:@`0`A````$J$!`!P````TH0$`(P```%&A`0`A````=:$!`"``
M``"7H0$`(````+BA`0`=````V:$!`!,```#WH0$`&P````NB`0`=````)Z(!
M`!L```!%H@$`&````&&B`0`*````>J(!`!````"%H@$`&@```):B`0`&````
ML:(!``<```"XH@$`#0```,"B`0`4````SJ(!``8```#CH@$`!P```.JB`0`'
M````\J(!``8```#ZH@$`!P````&C`0`'````":,!``4````1HP$`%0```!>C
M`0`&````+:,!``@````THP$`!0```#VC`0`%````0Z,!``H```!)HP$`$0``
M`%2C`0`*````9J,!`!(```!QHP$`$0```(2C`0`+````EJ,!`!(```"BHP$`
M!@```+6C`0`J````O*,!`!$```#GHP$`$````/FC`0`:````"J0!`!`````E
MI`$`#0```#:D`0`,````1*0!`"\```!1I`$`"````(&D`0`(````BJ0!`"@`
M``"3I`$`%````+RD`0`0````T:0!``8```#BI`$`"P```.FD`0`'````]:0!
M``8```#]I`$`(0````2E`0`-````)J4!`!`````TI0$`#0```$6E`0`3````
M4Z4!`!````!GI0$`'P```'BE`0`3````F*4!``<```"LI0$``P```+2E`0`&
M````N*4!`!\```"_I0$`!@```-^E`0`(````YJ4!`!(```#OI0$`$P````*F
M`0`&````%J8!``0````=I@$`!P```"*F`0`6````*J8!``T```!!I@$`#0``
M`$^F`0`+````7:8!`!0```!II@$`%@```'ZF`0`7````E:8!`!D```"MI@$`
M"@```,>F`0`-````TJ8!``8```#@I@$`!````.>F`0`1````[*8!`#L```#^
MI@$`!0```#JG`0`/````0*<!`"$```!0IP$`%@```'*G`0`7````B:<!``X`
M``"AIP$`#````+"G`0`)````O:<!``<```#'IP$`"@```,^G`0`)````VJ<!
M``X```#DIP$`$````/.G`0`@````!*@!`"$````EJ`$`)P```$>H`0`*````
M;Z@!``@```!ZJ`$`#0```(.H`0`,````D:@!`!(```">J`$`!@```+&H`0`(
M````N*@!`"<```#!J`$`"P```.FH`0`(````]:@!`!(```#^J`$`/````!&I
M`0`/````3JD!``L```!>J0$`!````&JI`0`%````;ZD!`!L```!UJ0$`'```
M`)&I`0`<````KJD!``H```#+J0$``@```-:I`0`$````V:D!`"$```#>J0$`
M`P````"J`0`%````!*H!`"D````*J@$`"@```#2J`0`&````/ZH!``<```!&
MJ@$`&````$ZJ`0`.````9ZH!``8```!VJ@$`!P```'VJ`0`(````A:H!``0`
M``".J@$`!0```).J`0`\````F:H!`!````#6J@$`$P```.>J`0`5````^ZH!
M``4````1JP$`!@```!>K`0`>````'JL!`#,````]JP$`#@```'&K`0`)````
M@*L!`!8```"*JP$`"@```*&K`0`(````K*L!`!D```"UJP$`+````,^K`0`I
M````_*L!`"@````FK`$`(0```$^L`0`.````<:P!``0```"`K`$`!P```(6L
M`0`(````C:P!``<```"6K`$`#0```)ZL`0`/````K*P!``@```"\K`$`5P``
M`,6L`0`2````':T!`!`````PK0$`"P```$&M`0`;````3:T!`%````!IK0$`
M'0```+JM`0`&````V*T!`!T```#?K0$`)P```/VM`0`'````):X!``8````M
MK@$`(````#2N`0`$````5:X!``D```!:K@$`*0```&2N`0`H````CJX!`"<`
M``"WK@$`!P```-^N`0`(````YZX!`"(```#PK@$`60```!.O`0`8````;:\!
M`"8```"&KP$`%@```*VO`0`#````Q*\!``T```#(KP$`!P```-:O`0`/````
MWJ\!``L```#NKP$`!@```/JO`0`5`````;`!``8````7L`$`"````!ZP`0`)
M````)[`!``L````QL`$`"@```#VP`0`,````2+`!`#T```!5L`$`"````).P
M`0`2````G+`!`!0```"OL`$`%P```,2P`0`,````W+`!`!````#IL`$`#P``
M`/JP`0`+````"K$!``8````6L0$`!0```!VQ`0`*````([$!`"4````NL0$`
M%P```%2Q`0`0````;+$!``L```!]L0$`$````(FQ`0`*````FK$!`!0```"E
ML0$`"````+JQ`0`4````P[$!``0```#8L0$`!P```-VQ`0`%````Y;$!``4`
M``#KL0$`!P```/&Q`0`3````^;$!`!0````-L@$`(@```"*R`0`B````1;(!
M`!P```!HL@$`'````(6R`0`@````HK(!`"4```##L@$`'P```.FR`0`$````
M";,!``4````.LP$`#@```!2S`0`.````([,!`!4````RLP$`"````$BS`0`7
M````4;,!``T```!ILP$`"@```'>S`0`:````@K,!`!\```"=LP$`%````+VS
M`0`(````TK,!`!(```#;LP$`!P```.ZS`0`0````]K,!``\````'M`$`"```
M`!>T`0`)````(+0!``4````JM`$`!P```#"T`0`%````.+0!``0````^M`$`
M`P```$.T`0!!````1[0!`#4```")M`$`%P```+^T`0`I````U[0!`#D````!
MM0$`$@```#NU`0`X````3K4!`#@```"'M0$`/0```,"U`0`]````_K4!`$(`
M```\M@$`&````'^V`0`9````F+8!`!8```"RM@$`&````,FV`0`@````XK8!
M`"`````#MP$`&P```"2W`0`9````0+<!`!L```!:MP$`%````':W`0`Q````
MB[<!`#$```"]MP$`-0```.^W`0`R````);@!`#,```!8N`$`,````(RX`0!W
M````O;@!`!D````UN0$`%@```$^Y`0`*````9KD!`"(```!QN0$`"0```)2Y
M`0`3````GKD!`#0```"RN0$`)0```.>Y`0`@````#;H!``L````NN@$`40``
M`#JZ`0!-````C+H!``<```#:N@$`%P```.*Z`0`5````^KH!``P````0NP$`
M$````!V[`0`6````+KL!``<```!%NP$`"````$V[`0`)````5KL!`!(```!@
MNP$`$0```'.[`0`/````A;L!``X```"5NP$`"0```*2[`0`8````KKL!``@`
M``#'NP$`!@```-"[`0`4````U[L!`!$```#LNP$`$````/Z[`0!"````#[P!
M``(```!2O`$`!@```%6\`0`1````7+P!``4```!NO`$`!P```'2\`0`/````
M?+P!``H```",O`$`*@```)>\`0`,````PKP!`!X```#/O`$``P```.Z\`0`W
M````\KP!`!@````JO0$`*````$.]`0"&````;+T!`!@```#SO0$`00````R^
M`0`A````3KX!`!,```!PO@$`!@```(2^`0`,````B[X!``X```"8O@$`"P``
M`*>^`0`6````L[X!``L```#*O@$`'````-:^`0`6````\[X!``4````*OP$`
M$@```!"_`0`:````([\!`"4````^OP$`$P```&2_`0`6````>+\!`!P```"/
MOP$`$0```*R_`0`F````OK\!``H```#EOP$`%````/"_`0`6````!<`!`!``
M```<P`$`$@```"W``0`/````0,`!`!(```!0P`$`#P```&/``0`5````<\`!
M`!X```")P`$`%0```*C``0`&````OL`!``D```#%P`$`!0```,_``0`=````
MU<`!``8```#SP`$`$````/K``0`(````"\$!`!0````4P0$`!0```"G!`0`;
M````+\$!``\```!+P0$`+0```%O!`0`5````B<$!``8```"?P0$`!P```*;!
M`0`8````KL$!``4```#'P0$`'@```,W!`0`$````[,$!`!0```#QP0$`!P``
M``;"`0`+````#L(!`"`````:P@$`+0```#O"`0`)````:<(!`!P```!SP@$`
M$````)#"`0`*````H<(!`!L```"LP@$`%````,C"`0`$````W<(!`!0```#B
MP@$`"0```/?"`0`(`````<,!``4````*PP$`"````!##`0`&````&<,!``8`
M```@PP$`(0```"?#`0`W````2<,!`#\```"!PP$`(@```,'#`0`P````Y,,!
M`"@````5Q`$`10```#[$`0`B````A,0!`"@```"GQ`$`)0```-#$`0!5````
M]L0!`"H```!,Q0$`!P```'?%`0`(````?\4!``<```"(Q0$`"````)#%`0`4
M````F<4!`!0```"NQ0$`,````,/%`0`M````],4!`!@````BQ@$`-0```#O&
M`0`]````<<8!``<```"OQ@$`&0```+?&`0`)````T<8!`!````#;Q@$`(@``
M`.S&`0`1````#\<!`!(````AQP$`#0```#3'`0`(````0L<!`!4```!+QP$`
M"````&''`0`+````:L<!``T```!VQP$`&@```(3'`0`-````G\<!`#P```"M
MQP$`"@```.K'`0`%````]<<!``D```#[QP$`!0````7(`0`:````"\@!`!$`
M```FR`$`!0```#C(`0`.````/L@!`!````!-R`$`$0```%[(`0`,````<,@!
M``\```!]R`$`#P```(W(`0`'````G<@!``,```"ER`$`#0```*G(`0`Z````
MM\@!`$X```#RR`$`%0```$')`0`)````5\D!`"8```!AR0$`'0```(C)`0`%
M````ILD!`!4```"LR0$``P```,+)`0`+````QLD!`!(```#2R0$`*@```.7)
M`0`'````$,H!``T````8R@$`#@```";*`0`2````-<H!``L```!(R@$`.P``
M`%3*`0`)````D,H!`!P```":R@$`#P```+?*`0`3````Q\H!`#\```#;R@$`
M+@```!O+`0`Y````2LL!`#H```"$RP$`-@```+_+`0`1````]LL!``8````(
MS`$`$`````_,`0`0````(,P!``T````QS`$`"@```#_,`0`1````2LP!`!T`
M``!<S`$`!P```'K,`0`5````@LP!`!H```"8S`$`"````+/,`0`'````O,P!
M`!$```#$S`$`$@```-;,`0`9````Z<P!``8````#S0$`!P````K-`0`/````
M$LT!`!4````BS0$`%````#C-`0`5````3<T!`!4```!CS0$`!P```'G-`0`&
M````@<T!`#$```"(S0$`)P```+K-`0`F````XLT!``@````)S@$`#P```!+.
M`0`&````(LX!`!\````IS@$`(0```$G.`0`F````:\X!``L```"2S@$`%```
M`)[.`0`F````L\X!``,```#:S@$`!P```-[.`0`5````YLX!``,```#\S@$`
M#`````#/`0`1````#<\!``L````?SP$`%````"O/`0`8````0,\!`!0```!9
MSP$`!0```&[/`0`*````=,\!`!,```!_SP$`%````)//`0`.````J,\!``8`
M``"WSP$`"0```+[/`0`)````R,\!``T```#2SP$`6@```.#/`0`6````.]`!
M`#4```!2T`$`%````(C0`0`'````G=`!``D```"ET`$`%````*_0`0`5````
MQ-`!`!(```#:T`$`(0```.W0`0`8````#]$!`!4````HT0$`(P```#[1`0`0
M````8M$!`"<```!ST0$`$P```)O1`0`5````K]$!`'````#%T0$`(0```#;2
M`0`<````6-(!`"T```!UT@$`(0```*/2`0`<````Q=(!`"8```#BT@$`'P``
M``G3`0`?````*=,!`!P```!)TP$`"@```&;3`0`'````<=,!``@```!YTP$`
M"````(+3`0`3````B],!``\```"?TP$`+0```*_3`0`7````W=,!`!4```#U
MTP$`!P````O4`0`'````$]0!`$\````;U`$`20```&O4`0`^````M=0!`&8`
M``#TU`$`#````%O5`0`R````:-4!`#````";U0$`"0```,S5`0`'````UM4!
M``8```#>U0$`0````.75`0`&````)M8!`$`````MU@$`-````&[6`0`C````
MH]8!``X```#'U@$`+0```-;6`0`<````!-<!`#,````AUP$`*````%77`0`R
M````?M<!`"@```"QUP$`#0```-K7`0`&````Z-<!``\```#OUP$`$@```/_7
M`0`5````$M@!``<````HV`$`0@```##8`0`*````<]@!``D```!^V`$`"@``
M`(C8`0`7````D]@!``D```"KV`$`!P```+78`0`2````O=@!``H```#0V`$`
M"0```-O8`0`$````Y=@!``<```#JV`$`"````/+8`0`/````^]@!`!0````+
MV0$`%@```"#9`0`=````-]D!``T```!5V0$`!P```&/9`0`0````:]D!``\`
M``!\V0$`$@```(S9`0`-````G]D!`!@```"MV0$`*````,;9`0`.````[]D!
M`!\```#^V0$`*0```![:`0`)````2-H!``L```!2V@$`%````%[:`0`'````
M<]H!``0```![V@$`'P```(#:`0`.````H-H!``X```"OV@$`#0```+[:`0`(
M````S-H!``D```#5V@$`!@```-_:`0`)````YMH!``L```#PV@$`$P```/S:
M`0`(````$-L!`!@````9VP$`"P```#+;`0`'````/ML!`!X```!&VP$`)@``
M`&7;`0`,````C-L!``,```"9VP$`(0```)W;`0`'````O]L!``8```#'VP$`
M=````,[;`0`*````0]P!``<```!.W`$`)P```%;<`0!`````?MP!`!H```"_
MW`$`)0```-K<`0!$`````-T!`"D```!%W0$`/0```&_=`0`;````K=T!`!8`
M``#)W0$`!0```.#=`0`&````YMT!``D```#MW0$`"@```/?=`0`*`````MX!
M``D````-W@$`%````!?>`0`+````+-X!``H````XW@$`#````$/>`0`,````
M4-X!``<```!=W@$`"````&7>`0`)````;MX!`!0```!XW@$`"P```(W>`0`&
M````F=X!``4```"@W@$`"P```*;>`0`&````LMX!`"8```"YW@$`&````.#>
M`0`*````^=X!`!8````$WP$`"P```!O?`0`4````)]\!``L````\WP$`!@``
M`$C?`0`6````3]\!``8```!FWP$`%@```&W?`0`&````A-\!`!H```"+WP$`
M"P```*;?`0`6````LM\!``4```#)WP$`!P```,_?`0`2````U]\!`"````#J
MWP$`"P````O@`0`-````%^`!`"T````EX`$`&P```%/@`0`8````;^`!``4`
M``"(X`$`#0```([@`0`4````G.`!`!<```"QX`$``P```,G@`0`3````S>`!
M``D```#AX`$`(P```.O@`0`I````#^$!`#,````YX0$`)0```&WA`0`T````
MD^$!`"<```#(X0$`:0```/#A`0`7````6N(!`&<```!RX@$`0@```-KB`0!4
M````'>,!`&X```!RXP$`+0```.'C`0`[````#^0!`#,```!+Y`$`.````'_D
M`0`N````N.0!`!L```#GY`$`-`````/E`0#7`0``..4!`!\````0YP$`%P``
M`##G`0!*````2.<!`'<```"3YP$`,P````OH`0`E````/^@!`$$```!EZ`$`
M7````*?H`0!:````!.D!`"H```!?Z0$`(P```(KI`0`6````KND!`"@```#%
MZ0$`'0```.[I`0`:````#.H!`"T````GZ@$`)0```%7J`0`E````>^H!`#H`
M``"AZ@$`(P```-SJ`0`6`````.L!`#@````7ZP$`)0```%#K`0`J````=NL!
M`"T```"AZP$`'P```,_K`0`X````[^L!`&T````H[`$`,0```);L`0!"````
MR.P!`"X````+[0$`)P```#KM`0!`````8NT!`&,```"C[0$`2`````?N`0`N
M````4.X!`"X```!_[@$`,````*[N`0!?````W^X!`&\````_[P$`6````*_O
M`0!9````"/`!`#4```!B\`$`*@```)CP`0`J````P_`!`"\```#N\`$`:P``
M`![Q`0!Q````BO$!`'$```#\\0$`N0```&[R`0`9````*/,!`"\```!"\P$`
M,````'+S`0`M````H_,!`%(```#1\P$`)0```"3T`0!3````2O0!`"(```">
M]`$`"@```,'T`0#8````S/0!`%@```"E]0$`(P```/[U`0`X````(O8!`"@`
M``!;]@$`'@```(3V`0`Y````H_8!``0```#=]@$`"````.+V`0`$````Z_8!
M`!D```#P]@$`#P````KW`0`/````&O<!``L````J]P$`!@```#;W`0`/````
M/?<!``0```!-]P$`6````%+W`0`$````J_<!`!<```"P]P$`!````,CW`0`'
M````S?<!``8```#5]P$`!0```-SW`0`$````XO<!`!4```#G]P$`"0```/WW
M`0`1````!_@!`!,````9^`$``P```"WX`0`'````,?@!``<````Y^`$`$@``
M`$'X`0`-````5/@!`!0```!B^`$`!@```'?X`0`:````?O@!``T```"9^`$`
M`P```*?X`0`K````J_@!``0```#7^`$`!@```-SX`0`'````X_@!`"$```#K
M^`$`0`````WY`0`Q````3OD!`#(```"`^0$`&P```+/Y`0`R````S_D!`#4`
M```"^@$`)````#CZ`0`C````7?H!`!X```"!^@$`)````*#Z`0`?````Q?H!
M`!T```#E^@$`)0````/[`0`C````*?L!`!X```!-^P$`-````&S[`0`<````
MH?L!`#$```"^^P$`,@```/#[`0`A````(_P!`"4```!%_`$`)````&O\`0`?
M````D/P!`"0```"P_`$`*@```-7\`0`H`````/T!`"H````I_0$`)@```%3]
M`0`?````>_T!`"(```";_0$`*P```+[]`0`=````ZOT!`"0````(_@$`+P``
M`"W^`0`R````7?X!`!H```"0_@$`)P```*O^`0`\````T_X!`"0````0_P$`
M)@```#7_`0`E````7/\!`"8```""_P$`(````*G_`0`>````RO\!`"<```#I
M_P$`(P```!$``@`N````-0`"`"<```!D``(`+@```(P``@`*````NP`"`!,`
M``#&``(`%@```-H``@`S````\0`"`"8````E`0(`#0```$P!`@`/````6@$"
M`!8```!J`0(`"P```($!`@`.````C0$"`"P```"<`0(`"````,D!`@`,````
MT@$"`"<```#?`0(`*@````<"`@`@````,@("`!\```!3`@(`'````',"`@`(
M````D`("`-0```"9`@(`#0```&X#`@`6````?`,"``D```"3`P(`#0```)T#
M`@`1````JP,"`!````"]`P(`'P```,X#`@`&````[@,"`$L```#U`P(`'```
M`$$$`@`<````7@0"``<```![!`(`$@```(,$`@`,````E@0"`#8```"C!`(`
M"````-H$`@`G````XP0"`!D````+!0(`$@```"4%`@`4````.`4"`#(```!-
M!0(`'P```(`%`@`'````H`4"`!<```"H!0(`"````,`%`@`)````R04"`!0`
M``#3!0(`"P```.@%`@`;````]`4"``8````0!@(`*@```!<&`@`(````0@8"
M`",```!+!@(`*P```&\&`@`'````FP8"`!<```"C!@(`!P```+L&`@`(````
MPP8"``D```#,!@(`/@```-8&`@`&````%0<"`!(````<!P(`%````"\'`@`/
M````1`<"``D```!4!P(`"@```%X'`@`&````:0<"`!,```!P!P(`!@```(0'
M`@`A````BP<"`!(```"M!P(`&0```,`'`@`5````V@<"``P```#P!P(`#@``
M`/T'`@`:````#`@"``<````G"`(`+0```"\(`@`,````70@"``\```!J"`(`
M!P```'H(`@`#````@@@"`!$```"&"`(`'````)@(`@`+````M0@"``,```#!
M"`(`"````,4(`@`,````S@@"``D```#;"`(`#P```.4(`@`-````]0@"`!8`
M```#"0(`%P```!H)`@`0````,@D"`"\```!#"0(`'0```',)`@`<````D0D"
M`!H```"N"0(`"P```,D)`@`P````U0D"``<````&"@(`%P````X*`@!%````
M)@H"`!$```!L"@(`$@```'X*`@`(````D0H"``0```":"@(`!0```)\*`@`1
M````I0H"`!H```"W"@(`!@```-(*`@`'````V0H"``D```#A"@(`$````.L*
M`@`(````_`H"`!(````%"P(`#@```!@+`@!%````)PL"`#8```!M"P(`*0``
M`*0+`@`%````S@L"`!D```#4"P(`)````.X+`@`B````$PP"`"@````V#`(`
M$````%\,`@`"````<`P"``0```!S#`(`"P```'@,`@`*````A`P"``4```"/
M#`(``P```)4,`@`0````F0P"`$\```"J#`(`,P```/H,`@`:````+@T"`"L`
M``!)#0(`+P```'4-`@!3````I0T"`!8```#Y#0(`A0```!`.`@`D````E@X"
M`$(```"[#@(`)0```/X.`@!'````)`\"`"L```!L#P(`,P```)@/`@`N````
MS`\"`"X```#[#P(`,````"H0`@`P````6Q`"`"T```",$`(`,@```+H0`@`T
M````[1`"`#<````B$0(`%@```%H1`@`@````<1$"`!````"2$0(`?````*,1
M`@`(````(!("`'`````I$@(`<@```)H2`@"`````#1,"`"8```".$P(`7@``
M`+43`@`7````%!0"`",````L%`(`%@```%`4`@`2````9Q0"`!0```!Z%`(`
M'````(\4`@!`````K!0"`!X```#M%`(`&0````P5`@!0````)A4"`!(```!W
M%0(`&````(H5`@`*````HQ4"``4```"N%0(`!@```+05`@`(````NQ4"``4`
M``#$%0(`%@```,H5`@`7````X14"`!8```#Y%0(`(0```!`6`@`0````,A8"
M``X```!#%@(`!````%(6`@`)````5Q8"``\```!A%@(`!P```'$6`@`&````
M>18"`!H```"`%@(`"0```)L6`@`,````I18"`!````"R%@(`!P```,,6`@`+
M````RQ8"`!````#7%@(`"P```.@6`@`:````]!8"``D````/%P(`%0```!D7
M`@`5````+Q<"``8```!%%P(`!0```$P7`@`C````4A<"`!D```!V%P(`"P``
M`)`7`@`C````G!<"`!0```#`%P(`*P```-47`@`9`````1@"``8````;&`(`
M%P```"(8`@`%````.A@"``<```!`&`(`&P```$@8`@`%````9!@"``(```!J
M&`(``@```&T8`@`;````<!@"``@```",&`(`"P```)48`@`5````H1@"`!@`
M``"W&`(`!P```-`8`@`S````V!@"``(````,&0(`!`````\9`@`0````%!D"
M`!8````E&0(`#@```#P9`@`+````2QD"``D```!7&0(`!@```&$9`@`8````
M:!D"``@```"!&0(`%````(H9`@`1````GQD"`!(```"Q&0(``@```,09`@`'
M````QQD"``\```#/&0(`$````-\9`@`0````\!D"`"P````!&@(`"0```"X:
M`@`(````.!H"`!(```!!&@(`!0```%0:`@`"````6AH"``L```!=&@(``0``
M`-`$```:!```+@4``%T#````````G`$``&L"``">!````````)(#``#%`0``
M^`8``'P``````````````(0"```F!P``"P$```````!^!P``P0```'0%```3
M!```[@4``"P```#8`P``O@8``"`'```&`@``_P,``+D%``#_!@``+P,`````
M``"D`@``[04``&("``"P`@``#00``'\#````````````````````````TP0`
M`$X%``"#!`````````````#T`0``;@(`````````````?0(``"P$````````
M(P$``*$%````````7P<``.$%``",!@``)0$``&T&``#R!```;`(``'`!```P
M!P``P`$``,\"```M!```;0,``$L'``!:````H@$``#,!``"&!P```````'L!
M``#K````DP8``+T%``!9!P``1P4``,D&````````D@0``&`"``#R````)P(`
M`&0"````````V`0``($&``#;!0````````````"E````````````````````
ME@,```````!`````X08```````#+`0```````,L%``!&`@``O`4```````#[
M`@``A0<````````)!0```````$T$``#)!0``Z@(``",%```7`````````#0`
M``!8````NP$`````````````LP(``%@$``!C`P``:`,``%\!````````````
M````````````^`$``&(#``!O````U`$```````!Z!@````````4'``"0````
M`````$L#``"9`@```````!H#``!:!@``\@$``-\````F`P``V@$``,X!``"T
M`P``10,````````8!P``#@<``",#``#Q````K04``,\$`````````````*D#
M``"D`````````,@%``!?`P``=P,``),$```(!````````(<&``"^`0``````
M`-X$``!U!P``U@,``.4!````````_`4``$<'``"I`0``5@0``.(!````````
M3P```)L$```````````````````M`P``:0<```````"R`````````)4%``!E
M!```H08``.`!``"N!@```````"H```#Y`0``:`$``%$'``#7`P``)@8``*$$
M``!1!@``5`0``*P&````````FP(``%L```"/!@``B0,``*D`````````J04`
M`-,```">`P``>@$``&4"``#``P``)0<``'D#```K`````````#8`````````
M`````"\"``"#````X00```````#S!```=P0``$$'````````]P``````````
M````D0(``+<%````````%`4``*@#```I`@``=P<```````!R!```.0(`````
M````````C@(``(X!``"(!```W````'D'``!4!0``F`,```$"```X!P``7`,`
M``8!````````0P0````````J!P``G0,``*4!`````````````&0%``!Q`0``
M``````````!`!@``VP```#H'``!*```````````"````````*0$```````!4
M`P```````)H$````````R@$``%\$```4`P```````"4$``!A````````````
M```C!```=P```.L#``!C!@```````)D&``#]!0``>P`````````6!@``KP0`
M``,`````!P``V@4``+0&``#'`P``>@(``!,'``#L``````````````!C`0``
M`````.P"``":````D@```)P#````````FP$``"@%``!O`@``\`,``$0#``"\
M`@``N0$``-H$``#3!@``L@,``.`$``#'!```J`0````````5!P``%0(``+T$
M```8`0``KP(`````````````WP,``(T"````````?@$``/L%``!I`0``%`8`
M`/8!```H`P``20,``'`#``!%!```E@$``$<```#&`0``;P,``$L&```Z````
M708``%,```#2!@``=`(````````K!0``)`(``'`&``#M````"`8```0```#B
M`@``?`,``(`%``")`0``D00``/P"``!A!P``Y`4``!<!````````GP$```H'
M``!Y`@``?@````,$```&!P``*P8``#(&````````4`(``+\`````````=0,`
M`/T#````````"P```#`%`````````````&,'```E!@``W0````````#R`@``
M/`<```````#5`P``UP0`````````````:`````L"``!O!@```````-`&``#"
M!@``<0```*````#Y!@``0`(```````"9!```MP,``,`````"!```#`8``$P!
M``"2`@``M@4``*`!``"_`0````````4`````````20<``-0"``!C````````
M`,0```````````````````#O!````````#T%``!L!P```````,H&````````
M%0,``'X&`````````````$\%`````````````/`$``!U!```H`8``&T$```(
M````7@```$4'``"X`P``<P4``-X```""`P``(@0``#@%``#T!@``F@,``'4"
M````````:@$``#P"``"[!@``ZP4``+P$````````;`8```````")````HP(`
M```````Q!@```````!D'````````50$``"`$```X`0```````&L$````````
MA0(``'8%``!]!0``U@`````````?`@``3`8``#4$```Q`@````````````"5
M`P``_`0``/T&```%`P``9@8```````#O`0``Q@```.T#``"/````6`<`````
M````````Y`8``(,#`````````````-L"```L`P``5P$``/$&````````XP$`
M`/X```!-````R@0```T%````````-@$``(X#``!]`0``EP```%<$``!]!```
M<P```*0%``!6`@``@`(````````_!@``=@$``/P!````````Y`0````````D
M`````````/4$``!I!````````%D!```?!```!@```)T"``!<`@``````````
M```!!@``D04```````#>!@``C`,``#X````K`0``$@(``-0#``".!@``/0<`
M``````!J`P```````(P$``"C`````````,,#``!1````NP(``"H$```>!```
MY@0````````J!@``]`(``"P&``!5!0``````````````````IP(``"(#````
M`````````+,!````````?0```"4#````````;P<```````"/!````````,P!
M``#M!@``"`$````````````````````!``!)!0``-@8```````#&!0``$0$`
M`%T$``#X`P``G````*X#``#"`0```````',$``!O!```U0(``,<%``!\`0``
MC`$``````````````````/H%```S!````````#L'``"B!@``S@,``*4&``#K
M`0``I@````````#M`@``````````````````JP0``.D!``#V!```W`,``"8$
M````````9`0``)\````-!@``MP0``.<#````````Q@0``%D"``"*!```````
M`,("``"[!0``/P4``'$'``#3!0``D`8```````!@!P`````````````9!```
M`````/$#``!4````V0````````!(````E@````````!4`@``-P```!T&```Z
M`@``<0(```````#Q`@````````8$``"U`@``HP0``'0'````````UP8``!4`
M````````U@0```````#\`````````!P%``"(!0``]0$``/0%``!Z`P``U08`
M`+$%``"2!0````4```````````````````````"!!```O0(``,P"```)!P``
MEP,``/T"````````\00``#T"``!3`0```````,,$```R`0```````,D"``",
M``````````````!+`0````````````"W!@``"0$``-P!```D!```H@,``,H%
M``!S`0``,00```X&``")!```8@`````````O````G08``#8"``!7`@``?`<`
M`$0'``"*!0``&0````````"M````[`,``,X&``!Y!0``,@```+H%``#(`@``
M`````/,&``"S!@``6`4``$0!`````````````!L"```;!P``V`8````````+
M!0```````&`!```W`@``00(``+H!``!^`P```````"H!``!&````S@(``!$&
M````````?P```$`#```R!P``+0$``"\$``#?`0```````,\%``"R`@``Y@$`
M`%(#``#U`P``>P0```````"@`P``T@(``&`#``#H!0````````````!?````
M'0(``#`#``#Z`@```````'$$````````?08``#0%```W!0``%@0```````!V
M````H0,```````"4!0``7P4``!`"``!L`0``(@$```````".`````````&<%
M````````P@4``!H!``#>`0```````)$#``"8`````````((%```8````````
M`"D%``"$!````````!P```"6!@``908``/D"``"%`0```````$H#``!E!P``
M>`0```X$``!E````404``,$&``!R`@``X```````````````M0,``',#````
M`````````````````````````%P!````````-0<``'P"``!L````````````
M``"&`@```````,L&```)`@``#`4``&T!```K`@``W04``.4"``!-`P``#0$`
M`&````!G`````````+P&``#7`@``M@8``````````````````.H```"P!```
M*``````````L!P```````/,```"G!0``^P$``-($```:````````````````
M````8`0```````#%!@``7`8``$X`````````$0(`````````````2`0``!,&
M```C````/P```'\%``"F!```M@(``(X%``#D````0`0```````"U!0``/@4`
M`!\!``"X`0```````)@%````````M0```/X&```H!P````````````"N!```
M`````&8'``!X!0``9@```````````````````,L$```'`0``5`8`````````
M````W`8``%T'```[`0``.00``',"``#H!@``-P0``!P'``#Z!@``;@8```P!
M````````1`8``)H&``"Z!```8@8```8%``!"!P``````````````````<0,`
M`(L```!V!P``T`,``/\!``"C`0``*@,```````"Q!````````"$'``#_`@``
MZ0(``'````!J!@``V`````\&``!#`P``6@<``/`%``#E!@``S@0``#T#````
M````^`4``&('``"<!@``T`(```````!K`0``T0```(8&```P````Q@(``)\$
M``#J`0``X@```&@"``"F`0``6@(````````V`P```````%@&```I!```7@,`
M`-X%````````SP```),%``#4!@``0P(`````````````E0$`````````````
M!`8``$,%``#[!@```````$<#``!I!0``4`<``-$!``"``0``````````````
M``````````````#Z!```:@0```0$```\`P``'00``-P$````````6@,``'P$
M```/`@``*08``,@$```9`P```````'L&``!U`````P,``)$!````````K```
M```````"`@``>0$``"<$```Q!P```````'H```!T``````````````!B`0``
M5`$```T````_`0``VP,``+$&```T!P`````````````F````````````````
M````A04``(T$````````1`0``/X%````````LP```%`!``"-!@``L@$``!0"
M``!.`@``A0,``&L'``#S`@``M@```.\&``#N`P``40$``-\$``#L!```````
M`,P&````````+0(````````(!P``4`````````!2`@```````$@&``!_`@``
M`````!D&````````\`8``(@&``"[````608```````#W`0``A````$,&````
M````=0$`````````````0@(``$@!```3`P```````"0!``!7`P``]0```)<%
M``!0!0``V08``#D!```6!P```````(@!``!9!0``500``#X'``"8`@``.P,`
M``\#``"K!0``20$```````"=!````````#X!``!J````>P4``*4#``"D!@``
M(`````````"N````2P```!(```"D!````0$``'4&````````TP$``+H```#A
M`P``M@$`````````````9@0`````````````O@```+D```!P!````````!$`
M``!<!0``XP0``!X#``"K`0``Y@```"`"``";!@``O`$``/`!```W!@``?P8`
M``````"!````$`0``+D"```[!```?P$``!L```"Q`@```````+L#``!R!0``
M8P(``(4`````````RP(``,`&``!\!0```````%4"``"<!0``[@$``*L#````
M````AP4``'(!``"Q````?P0```````#L!@````````T'``!M`@```````.H#
M````````#@(``!0!```K`P``0@0```````!_!P``W0(```````!X!@``1@4`
M``````#8!0``A00```````!;!P``]0(``*T$```#`@```````"$```#Y!0``
M=P$``#H#```'!@``\04``.X"``!N!0``M@,```````#2`P``Y@(``%4&````
M````>00``#\#````````*`(``)D%``##!0``UP4``%X%`````````````/P&
M``!W!0``10(``#P```"\```````````````-`P`````````````,!P``-`8`
M`!($`````````````%\"```$!P``,0,```````!``0``.@4```````"7!@``
M``````````"'`0``R0```.8#``#@!@``O0```(L!``"[!````````#0#```S
M`@``&@4```````"#!@``K`0```4"``#H!```O0,``````````````````$<$
M``!-!@``LP0``'`%``#"`P```````&D#``#8`0``L`$```````"0!0``````
M`,8&``"?!0````````<#``![`P``$P````L$``##`0``"00````````_`@``
M50```.`%````````J@,```$#```7!````P8`````````````YP0``.D%```(
M`P``I04``+4$```6````4@0``#<!``!2!0``H@(``/<"````````?@(``"`%
M``#Y`P``0P$``&@$`````````````#P%```3`0```````.\#``#$!```N@8`
M``````!&`P```````,L#``!:!0``>@0``#H&``#Y````&P4``$8!````````
MJP```%8!``#E!```C0````````#,`P``-08`````````````RP```(<```#:
M`P````````````#)!````````$X'````````%@4```````#D`P``,0```,H#
M``"&!0``$`$```X```!G!P``IP```,P$``!>!P``%08``-H````A`0``H`(`
M`)8"``!<!```*P0``!\'``!E`0``=@(``!`'```;!```U@4``)H"``!=````
M`````-T$``!C!0``/`8``.0"````````KP4````````"`P``'`0`````````
M``````````$%````````DP$``((&``!R`P``K0,``/8&````````D`0``(,"
M```;!@```````-D#````````6P$``%<'```2`P``[P(``"\'``!Q!0``I@,`
M`%T!```H!@``````````````````JP8``-T#``!,`P``^00``#8'``!V!```
M`````"P%``!D!@``U````)X"``#W`P```````"4%``""!P``Z@4``'`"````
M````*0`````````$`@````````<'``#B!````````$X&`````````````",'
M``#_!0```````$0"``````````````````#5`0``S0```#4#```$`0``````
M`"<'``!N!P``7P8```````!^!0``;@$``*T"``#"!```+`(``%,$````````
M``````````"!!0``$00``(\"``!3!@``T@```*P#``!%!@``,P<``'@'````
M````S00``!@%````````N`0`````````````@@$`````````````(0(``%H!
M````````%P<``"X'```>`@``I@(``"('````````.`0``(<"``!K````[@8`
M`#8%```\`0``#@4```````#B!0``B@```!P!``"I!```AP,```,%````````
M'P4``%L"````````Z`$```````#W!````````-T!``!$!0```````!`&``"(
M````YP(``#($``#B`P``J`4```H&``#%`P```````#T$````````````````
M``#H`@``GP,``/P#```5!0``,P```/,%``!S!P```````&L&````````R0,`
M`&\!```<`P``5@4```````"&````@P$```````"T````C0,``(($```N!```
MMP$``)<"``"=!0``M`(``.,"````````,`0``*$````J`@``Q@,```D#````
M````B04````````8!@``J@0``````````````````&@%````````U@$`````
M```,!```!08````````E````W@,``)X``````````````&\%```<!@``````
M`!4!```[!0``'0```,H"``";!0``A08``(P"```>!0``E`(````````]!@``
M/@8``*$!``">!0``)0(`````````````+0```$8'``"3`@``4`0`````````
M````,@(``/4%``!T`0``6P,``#4!````````3`0``%,%``"@!```"0```,`%
M``"!`P```````%@!``!G`@``Z0,``!<"````````P`(``%8'``!!`P``.@0`
M`)`!``#D`0``X`,``$\$`````````````*H"```,`@``&@(``$X!``!&!```
M"@````````!)!@``^@$``"X```"-`0```````"D'``#K`@``YP$``,T!``!J
M`@````````````#8`@``P0(``"<```"Q`P``CP4```````!N````$```````
M``"+!```&P$``&X$``!R!P``_@(``-P%``!/!P``L`,```,'``"+`P``````
M`(L"``!G`0``@`,``+T!``!S!@``;`0``*H```!,`@``804```````"*`P``
M*P<``(`$````````N@,``#P$```6`@```````#4"``"0`P``@@```/X#````
M```````````````-`@``$P(``,(```"Y`P```````,T&```M!0``[@```+X%
M````````104```\'``!5!P````0``%X!`````````````-<!``!&!@``[@0`
M`&D&```U!0``-P<``)H!``#A````N@(``+P#```4!`````````````"6!0``
MYP4``/(#````````/P<``!<#``#I!```DP,````#```&!@``B@8```````!H
M!@``7`<``"X!```C!@```````&$&``!G`P```````%L&``"S`P``"`(``$<"
M```?````"08``&0!`````````````$T"`````````````*,%```N!@``L0$`
M``````#0`0``,@4``(8!``!<`````````#@&``#C`P``%P4``+D$``"K`@``
M`````(````!X`P``A`8``,4%``"`!@``VP$``#,#``#M`0`````````````,
M````E`,``&$"``"<`@``[P4``````````````````&($`````````````.D`
M``"S!0``G@8````````>`0``OP,``#D&``!M!0``A`$``&D"````````2P0`
M`.,&````````PP8``(\!````````PP```!H'````````800``'`'````````
M"@4``#T!``!,!P``:P,``!\&``!$````$@<`````````````U@(``$D````Y
M`P``%00```````#O````9P8````````'!0``40,```0%```A!0``L@8``*<$
M```%!```1P$``$$&```````````````````=!0```````+````"O````+08`
M`.L&``#C`````````"`&```0`P``OP0``-8&`````````````'T#```*!```
M%@,``*P!`````````````-\&``#.`````````)(!``![!P``PP(``/\$````
M````-`$```````"H````+`$```P#````````C@0``!D!``"B````304`````
M``#F!@``TP(```````````````````<$``"9`0``F0,``*H!```*`@``T@4`
M`/(%``#S`0``"P,```````"=`0``Q0````````#$`@``5P```#@````F`@``
M``````````#[`P``I00``+@%````````OP4```````!/`0``'0$``.D&``#U
M!@``E`0``$X$````````K0$`````````````I`$``*8%``"N`@``8`8`````
M``#3`P``$P4``*0#````````&`(``/T$````````@P<``'T'``#.!0``X0$`
M`*D&``#A`@``O08``*D"``!N`P``C04``*\!````````T`4``)\&````````
ML@4```````#,!0``:@4```````#V`@```````-H&`````````````!T#``!Z
M!P``L@0``*,&````````P04``*<!``!#````FP,``!D"````````2@0`````
M```"`0``E0(``$P%```^`P``=@8``-H"````````0P<``&`%``!\!@``0@,`
M`.4```!*!0``OP8```````````````````````#0````60,``+<```!W`@``
M0`4```````!/!@``U`4``$@"```]````*@4```````!W!@``W@(``%X$```8
M`P``````````````````P00```````#1`P``X`(``'8#``"4````A`<``!@$
M````````````````````````/P0``!<&`````````````$T'````````)P,`
M`/T```!5`P`````````````>!P``3P,``#@"``"3````\0$``%,"````````
M]@,```L&````````EP0```````!"`0``70(``$D$``!(!P``:P4``*\#````
M````@@(``$H&````````)@$```````#9`0```````*X%``!M!P``V00``&8%
M``"P!@``)`4``#D'``!`!P``2`,``&<$``#-`P```````&8"``"L!0``?@0`
M`'0#``#/`P``3@,``)@!``#?`@``2@(``,`$````````A@0``&@'``!R````
M````````````````^`(````````O!0``9@,```('```A`P``>08```````#E
M`P``E00``+4!``#'!@``S0(``"@!``"7`0``R0$```````!3!P``40(``%@#
M``"#!0```````"X"``#X````F0````````#,````K`(``#$%````````UP``
M``````"B!0``````````````````(@8``)4&``#L`0``'P,``#L```"4!@``
M00$``,0#``"*`@```0<``!(%``!B!0``````````````````(`,``(@"```>
M````@`<``%('``"J!0``10```'(&```V!```P0$``-(!``!"````8P0``"0'
M``!L!0``\@8``%8````.`0``]P4``$L"``#[!```6`(``*`%```"!@``Y@4`
M`"(```!"!0```````$<&``"6!```F`8``+\"```!!`````````````"Y!@``
M;`,``!(&``#J!@```````'H%``#H````,@,``%<%```/!0``#P$``!P"````
M````904````````O`0``.P(``$T!```P`0``(P(``-4`````````(@4``&0#
M``#V````>`(``(L&`````````````*$"````````K@$``/H#``!A`0``N```
M`)$```````````````````"5````)`,```\``````````````(@#````````
M>P(``,0%``#$`0```````(0#```=!P``G@$```````#9`@``QP$```H!``!3
M`P``>0```-$$``#!`P```````,@!```1`P``````````````````:@<``.T$
M``!T!```!@,````````[!@``U00```````"?`@``;0```(P%```4!P``````
M`%0'```H!````@```%X"```9!0```````/8%``!+!0```````,@````*`P``
MB0(```````"C`P``!04````````W`P``_0$```L'``!;!```!P(```````!,
M````F`0``,\!```F!0``Y04```````!X`````````&8!``#P````[`4``$D"
M``"T!0```@4```````!2````Z`,``$@%``#1!@``.0```,4$``":!0``O@(`
M```````#`0``=`8``$$%``#;!@`````````````'````,P4``"D#``#Z````
MQ`8``!$'````!@``R@```'@!```2`0``]`,``.,%``"G!@``400``%(!````
M````!`,``+<"``!*!P``%````(\#``"H`@``6@0``-0$```X`P``+@,``/0`
M```^!````````-P"``"M!@````````````#9!0``7@8``+X#``#(`P``Z@0`
M`%D$``"4`0``A@,``&0'``"!!P`````````````0!0``B08``*($```M!P``
MB@$``$$$``";````'@8``/`"``!Q!@````````````"T!`````````X#``#G
M!@``704```````#X!```D08``-\%```G!@````````````#T!````````+@"
M````````M`$``$(&````````J@8``%(&```Y!0```````$$````T!```````
M`#`"````````_@0```````"+!0``&P,``*4"`````````````%`#```D!@``
MT04``/<&````````J`$``&$#```/!`````````````!0!@``)P$``+`%````
M````X@8``-$"````````A`4``($"``"U!@``5@,``($!````````ZP0``"("
M``#/!@```````#4```"X!@``QP(``*<#``!9`````````#$!````````W08`
M`*\&```(!0``10$``%<&``"V!```,P8```````!6!@```````&0````A!@``
MQ0(```````"=````_P````4!```^`@``AP0``&D```#5!0``(`$``)P$````
M````D`(``!$%````````.@$``,T%````````%@$```````!U!0``QP```,@&
M`````````````%L%```A!```\P,``"<%``#G````O@0``*8&```:!@``2@$`
M`"\&``#^`0``90,``-L$```T`@````````````#[````J`8``)(&``!/`@``
M`````#`&````("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I`"`H:6X@
M)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T97)D87DI`"!A
M="``(B5S(B!I<R!N;W0@82!D:7)E8W1O<GDN`"(E<R(@:7,@;F]T(&$@=F%L
M:60@8VAO:6-E+@`B)7,B(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D
M92!296=I<W1R>2X`(B5S(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"X`(B5S
M(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D
M9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C
M<F5A=&5D.B`E<RX`)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N
M,F8E)2D`)60@)7,@86YD("5S`"5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R
M9"!E>'!I<F5S+@`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN
M9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O
M;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G
M<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@:7,@
M<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C
M:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N
M*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@`E<R!I<R!R
M97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@)7,@;V8@
M)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P
M860`)7,G<R!487-K;&ES=``E<SH@)7,`)7,Z(%1H:7,@;65S<V%G92!M87D@
M;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F
M;VQL;W=I;F<@86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@
M<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+@`L(&=U<W1I
M;F<@`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`
M+2T@<V5L96-T("TM`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T
M(&AO=7)S`#Q0<F5V:6]U<P!!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER
M960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D
M`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE
M<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y
M(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@
M4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y
M<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K
M97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S
M<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE
M<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S
M86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP
M="!A(&UE<W-A9V4N`$%-($-L;W5D<P!!32!,:6=H="!286EN`$%-(%)A:6X`
M04T@4VAO=V5R<P!!32!3;F]W(%-H;W=E<G,`04TO4$T`05!)($E$`$%B;W5T
M('1H:7,@961I=&]R`$%B;W5T+BXN`$%B<V)O='1O;0!!8G-M:61D;&4`06-C
M97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E<W,@9&5N
M:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-O=6YT($EN9F]R;6%T:6]N`$%C
M8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`061D
M`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R
M93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@8VAI
M;&0@9W)O=7`@=&\@(B5S(@!!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O("(E
M<R(`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`061D(&YE=R!M96UB97)S
M`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A
M<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K
M`$%D9"!U<V5R`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD
M(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("5S+@!!
M9&1E9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RX`
M061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O
M:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R
M<P!!9&UI;FES=')A=&EO;@!!9',`069G:&%N:7-T86X`06QB86YI80!!;&=E
M<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!=71H96YT:6-A
M=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R
M('-I9&5S`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T:6YG
M(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA
M=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA
M=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E
M<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;65R:6-A;B!386UO
M80!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N('5N:VYO=VX@
M97)R;W(@:&%S(&]C8W5R960N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N
M;VYY;6]U<R!0<F]X>0!!;G-W97(`06YT87)C=&EC80!!;G1I9W5A(&%N9"!"
M87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N($QI<W0`07!P;&EC871I
M;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P
M<')O>&EM871E(%-I>F4`07!R:6P`07)A8FEC("A7:6YD;W=S+3$R-38I`$%R
M8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!<F4@>6]U('-U<F4@>6]U
M('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!
M<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E("(E<R(@86YD(&%N>2!S
M=6(M9W)O=7!S/P!!<F=E;G1I;F$`07)M96YI80!!<FUE;FEA;B`H05)-4T-)
M22TX*0!!<G0`07)U8F$`07-C96YS:6]N($ES;&%N9`!!<V-I:2!!<G0`07-I
M82]086-I9FEC(%)E9VEO;@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@
M9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`07-S:6=N;65N="!C;VQU
M;6YS`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!
M='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!
M='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T
M96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+@!!='1R:6)U=&5S
M`$%U9W5S=`!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y<G-Q;#H@4F5Q=6ER
M960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y<G5S.B!"86-K
M96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N`$%U=&A?
M8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T
M:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP
M:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF='`@<W=I=&-H+@!!=71H7VEM
M87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]K
M<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?
M;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV
M92!$:7)E8W1O<GD`075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@
M<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5Q
M=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N
M86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S`$%U
M=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S`$%U=&A?;&1A<#H@
M57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I
M<F5C=&]R>2X`075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E
M<B!F86EL960N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO
M;B!F86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E5
M4R!S97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D
M+@!!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N`$%V
M86EL86)L92!F:65L9',Z`$%Z97)B86EJ86X`0D]&2"!%>&-U<V5S`$)A8VMG
M<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N
M`$)A9"!K97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"86AR86EN`$)A;'1I
M8R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`0F%S92!G<F%P
M:&EC<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`$)A<V5L:6YE`$)E;&%R
M=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R;75D80!":'5T86X`0FER=&AD
M87D`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`
M0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";VQD`$)O;&EV:6$`0F]O:VUA
M<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!";W)D97)S`$)O<VYI82!A
M;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1S=V%N80!";W1T;VT`0F]U=F5T($ES
M;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R
M=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN
M82!&87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT
M<P!#7V5L;"!0<F]P97)T:65S+BXN`$-A8VAE(&EN:70@=V%S(&YO="!C;VUP
M;&5T960N`$-A;&5N9&%R`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`0V%N(&YO
M="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@
M861M:6YI<W1R871O<BX`0V%N(&YO="!W<FET92!T;R!F:6QE("(E<R(`0V%N
M)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+@!#86XG
M="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<P!#86XG="!O<&5N(&9I;&4@
M(B5S(BX`0V%N861A`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N
M;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y
M(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL
M92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#
M86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D
M97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O
M97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S
M86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#
M87)R:65R`$-A=&5G;W)I97,@86YD($QA8F5L<P!#87EM86X@27-L86YD<P!#
M96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@
M<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;&QP:&]N90!#96QT:6,@*$E3
M3RTX.#4Y+3$T*0!#96YT97(`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E
M;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I
M;',`0V5R=&EF:6-A=&4@3W=N97(`0V5R=&EF:6-A=&4@4&]L:6-I97,`0VAA
M9`!#:&%N9V4`0VAA;F=E(%EO=7(@4&%S<W=O<F0`0VAA;F=E('1H92!N86UE
M(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A
M;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H86YG:6YG('EO=7(@<&%S<W=O
M<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R
M871I;VXN("!#;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0VAA<@!#:&5C
M7VL@3&EN:RXN+@!#:&EL90!#:&EN80!#:&EN97-E(%-I;7!L:69I960@*$="
M,C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`0VAO;W-E($%P<&QI
M8V%T:6]N.@!#:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#
M:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE
M('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#:')I<W1M87,@27-L86YD`$-L
M87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A<B!-
M4T]F9FEC92!T86=S`$-L96%R(%%U97)Y`$-L96%R(&]U="!U<V5R.B`E<P!#
M;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&5A<FEN9R!,871E`$-L:6-K
M('1O($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A45%``0VQO<V4@5VEN9&]W
M`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O8V]S("A+965L:6YG*2!)
M<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E<G,`0V]L
M;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L
M<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM86YD(%-H96QL
M`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY`$-O;7!U=&5R
M<P!#;VYD:71I;VX`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N
M8V5S`$-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R
M='!H;VYE<R!A;F0@3W5T;&]O:RX`0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@
M9&%T92X`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N
M9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T:6]N
M(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E9G5S
M960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E
M9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O
M;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A8W1S`$-O;G1A
M8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B
M;V]K+@!#;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B``0V]N=&5N
M=',@;V8@(B5S(@!#;VYT:6YU90!#;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`
M0V]P>2!F86EL960Z("5S`$-O<'D@<V5L96-T:6]N`$-O<W0@240`0V]S=&$@
M4FEC80!#;W1E(&0G279O:7)E`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S
M86=E.B``0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z(`!#;W5L9"!N;W0@
M4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S:6=N
M(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T
M(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C:&5C:R!B86QA;F-E
M+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`0V]U;&0@
M;F]T(&-O;FYE8W0@=&\@<V5R=F5R("(E<R(@=7-I;F<@1E10.B`E<P!#;W5L
M9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@
M9&5C<GEP="!01U`@9&%T83H@`$-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D
M871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D
M96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96QE=&4@
M<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`0V]U;&0@;F]T(&1E=&5R;6EN
M92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!F
M971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F971C:"!C
M;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H
M92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@
M;F]T(&QO860@<W1R871E9WD@(B5S(BX`0V]U;&0@;F]T(&UK9&ER("(E<R(N
M`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V
M97(N`$-O=6QD(&YO="!O<&5N("(E<R(@9F]R('=R:71I;F<N`$-O=6QD(&YO
M="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO
M9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@(B5S(BX`0V]U;&0@
M;F]T(')E86-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(')E860@)7,N
M`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T
M960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C
M;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE
M=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O
M=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@
M;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T
M(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V
M97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!R;61I<B`B)7,B+@!#;W5L
M9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A
M(&)A8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P
M(&-O;F9I9W5A=&EO;CH@)7,`0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D
M92!S8W)I<'0@=&\Z("(E<R(N`$-O=6QD(&YO="!S879E('1H92!B86-K=7`@
M8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N
M9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F
M('1H92!O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C
M;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+@!#;W5L9"!N;W0@
M<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5N;&EN:R`B)7,B
M+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A
M=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!W<FET92!C;VYF
M:6=U<F%T:6]N(&9O<B`B)7,B.B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII
M;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#
M;W5L9&XG="!G:79E('5S97(@(B5S(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F
M;W(@=&AE(&9O;&1E<B`B)7,B.B`E<P!#;W5N=&5D('1E>'0`0V]U;G1R>0!#
M;W5R<V5S`$-R96%T90!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!O;F4`
M0W)E871E('-U8B!F;VQD97)S`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET
M(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT(#0@4&AA<V5S`$-U
M<G)E;G0@4V5S<VEO;G,`0W5R<F5N="!4:6UE`$-U<G)E;G0@55),(&ES`$-U
M<G)E;G0@57-E<G,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N
M.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@
M;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI
M8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5
M:W)A:6YI86X@*$M/23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`1%-.("AS964@
M:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S
M92YD8BYI;G1R;RUD<VXN<&AP*0!$86EL>0!$871A5')E92!"<F]W<V5R`$1A
M=&%B87-E($QO;VMU<`!$871E`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I
M;VX`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R
M<P!$96-R96%S92!);F1E;G0`1&5F875L=`!$969A=6QT($-O;&]R`$1E9F%U
M;'0@261E;G1I='D`1&5F875L="!3:&5L;`!$969I;FET:6]N<P!$96QE=&4`
M1&5L971E($-E;&P`1&5L971E($=R;W5P`$1E;&5T92!,;V<`1&5L971E(%!E
M<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L
M;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M
M<&QA=&4`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T92!P97)M
M:7-S:6]N<R!F;W(@(B5S(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L
M971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('1H92!C
M=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T960@
M<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`1&5L:79E<GD@=&EM90!$96YM
M87)K`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@
M*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@
M;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W
M(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``
M1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE
M9G0`1&ER96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/
M<'1I;VYS`$1I<W!L87D@9&5T86EL960@9F]R96-A<W0`1&ES<&QA>2!F;W)E
M8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA=`!$:7-P;W-I=&EO;B!.;W1I9FEC
M871I;VX`1&II8F]U=&D`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@
M86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H92!F:7)S="!R;W<@8V]N
M=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z
M`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$;VXG="!H879E(&%N(&%C
M8V]U;G0_(%-I9VX@=7`N`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D
M(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1R;W`@
M9&]W;B!L:7-T`$1R=6=S`$4M36%I;`!%36%I;"UT;RU335,@9V%T97=A>2!D
M<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC
M92X`15)2`$5C=6%D;W(`161I=`!%9&ET($)L;V-K`$5D:70@1W)O=7``161I
M="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N
M<R!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I="!P97)M:7-S:6]N<R!F
M;W(@(B5S(@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9'5C871I;VX`16=Y
M<'0`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%;6%I;`!%;6%I;"!!9&1R
M97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I;"!W:71H(&-O
M;F9I<FUA=&EO;@!%;6%I;"UT;RU335,@1V%T97=A>0!%;6]T:6-O;G,`16UP
M='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;7!T>2!S96%R8V@@=&5R;7,`
M16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I
M97,@:6X@=&5X=#\`16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`
M16YD('EE87(`16YL87)G92!%9&ET;W(`16YT97(@82!S96-U<FET>2!Q=65S
M=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R
M97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F
M('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%;G1E<B!T
M:&4@;&5T=&5R<R!B96QO=SH`17%U871O<FEA;"!'=6EN96$`17)I=')E80!%
M<G)O<@!%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,`17)R;W(@9&5L971I;F<@
M<WEN8R!A;F-H;W(Z("5S`$5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<P!%
M<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S`$5R<F]R('5P9&%T:6YG('!A<W-W
M;W)D.B`E<P!%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N`$5R<F]R('=R:71I
M;F<@(B5S(BX`17-T;VYI80!%=&AI;W!I80!%=&AN:6,`175R;W!E`$5V97)Y
M(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`
M179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%
M=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X96-U=&4`17AP86YD`$5X
M<&%N9"!3:61E8F%R`$5X<&5C=&5D("<I)P!%>'!E8W1E9"!B87)E('=O<F0@
M;W(@<75O=&5D('-E87)C:"!T97)M`$5X<&ER871I;VX@1&%T90!%>'!O;F5N
M=`!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE9"!R971R:65V
M:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E
M<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D
M('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B)7,B+@!&
M86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T
M;R!M;W9E('1O("(E<R(N`$9A:6QE9"!T;R!R971R:65V93H@)7,`1F%I<@!&
M86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@27-L86YD<P!&871A
M;"!%<G)O<CH`1F%X`$9A>&5S`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E;',@
M;&EK93H@`$9E=R!3:&]W97)S`$9E=R!3;F]W(%-H;W=E<G,`1FEE;&0@;6%T
M<FEX`$9I9VQE="!#05!40TA!`$9I9VQE="!F;VYT`$9I:FD`1FEL90!&:6QE
M($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@36%N
M86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`1FEL92!U<&QO860`1FEL
M92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<G,`1FEN;&%N9`!&:7)S
M="!(86QF`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L:7``1FQO870`1F]G
M`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R`$9O;V0`1F]R
M(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`1F]R96-A<W0@
M*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F
M;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82!L87)G92!N
M=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*0!&;W)G
M;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y<&4`
M1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9',`1G(`1G)A;65S
M`$9R86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&<F5N8V@@1W5I86YA`$9R
M96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S`$9R
M;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@
M3F%M90!'86)O;@!'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;0!'86QL97)Y
M.@!'86UB:6$`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@
M0V]D90!'96]R9VEA`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R`$=I=F5N($YA
M;64`1VQO8F%L($]P=&EO;G,`1V\`1V]E9&5L`$=O;V=L92!-87!S`$=O;V=L
M92!396%R8V@`1W)A>7-C86QE`$=R965C90!'<F5E:R`H25-/+3@X-3DM-RD`
M1W)E96YL86YD`$=R96YA9&$`1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7`@
M;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O=7!?;&1A<#H@56YA8FQE('1O
M(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@
M`$=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,`1W)O=7!?
M;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<P!'<F]U<',`1W5A9&5L
M;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'=65S="!097)M:7-S:6]N
M<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA`$A434P`
M2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@
M8V5L;"!I;B!R;W<N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L
M971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R96$@8V]W87)D
M;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+@!(
M5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O
M<FET:&T`2&%Z90!(96%D97(`2&5A9&5R<P!(96%R9"!)<VQA;F0@86YD($UC
M1&]N86QD($ES;&%N9',`2&5A=GD@5"U3=&]R;0!(96)R97<@*$E33RTX.#4Y
M+3@M22D`2&5I9VAT`$AE;'``2&5L<"!U<VEN9R!E9&ET;W(`2&5L<&5R`$AE
M;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(
M:6=H`$AO7VUE`$AO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I`$AO;64`
M2&]M92!!9&1R97-S`$AO;64@1&ER96-T;W)Y`$AO;64@4&AO;F4`2&]N9'5R
M87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-
M3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z
M($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S`$AO<F1E+TMO
M;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S
M`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R`B)7,B`$AO
M<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H
M92`G9&]M>&UL)R!02%`@97AT96YS:6]N`$AO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S`$AO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@
M='EP92`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S
M("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@
M<VAA<F5S.B`E<P!(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92`B)7,B`$AO
M<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`2&]R:7IO;G1A;#H`
M2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2D`2&]W(&UA
M;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W(&UA;GD@
M9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U
M;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AU;6ED:71Y`$AU;6ED:71Y.B``2'5M
M;W)I<W1S`$AU;F=A<GD`24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@
M)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL
M8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`25`@061D<F5S<P!)4"!!
M9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T('=I=&AI;B!A
M;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO8VMD;W=N('9I;VQA=&EO;BX`25]N
M<V5R="!2;W<@0F5F;W)E`$EC96QA;F0`26-O;G,@3VYL>0!)8V]N<R!F;W(@
M)7,`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M93H`268@:70@:7,@
M;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N
M97<@=VEN9&]W+@!)9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!)
M;G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K('1H:7,@
M8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN`$EF('EO=2!S964@
M=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT
M('1O('5P;&]A9"!C86XG="!B92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R
M+@!);6%G92!0<F5V:65W.@!);6%G92!54DP`26UA9V4@55),.@!);6%G92!F
M<F]M(&=A;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y.@!);6%G92!U<&QO860`
M26UA9V5S`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E9"!F:65L9#H@)7,`26UP
M;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E<@!);F-O<G)E8W0@86-T
M:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S
M<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S
M<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF
M('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT`$EN9&EA
M`$EN9&EV:61U86P@57-E<G,`26YD;VYE<VEA`$EN9F\`26YF;W)M871I;VX`
M26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92X`26YS97)T($-?;VQU
M;6X@069T97(`26YS97)T($EM86=E`$EN<V5R="!486)L90!);G-E<G0@5V5B
M($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R="!A(&YE=R!C;VQU
M;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!C;VQU;6X@
M8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&%F=&5R
M('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@
M8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R
M96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N
M="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS97)T(&%N(&5M
M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@
M<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R="!C96QL(&)E9F]R
M90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU;6X@8F5F;W)E`$EN
M<V5R="!M97-S86=E<P!);G-E<G0@<&%R86=R87!H(&%F=&5R`$EN<V5R="!P
M87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R;W<@869T97(`26YS97)T(')O=R!B
M969O<F4`26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R
M:71Y('%U97-T:6]N.@!);G-E<G0O36]D:69Y($EM86=E`$EN<V5R="]-;V1I
M9GD@3&EN:P!);G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I
M<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@8W)E9&ET+@!);G1E9V5R
M`$EN=&5G97(@;&ES=`!);G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I
M+@!);G9A;&ED(%I)4"!D871A`$EN=F%L:60@87!P;&EC871I;VXN`$EN=F%L
M:60@8F%T8V@@240N`$EN=F%L:60@9&%T82!S=6)M:71T960N`$EN=F%L:60@
M9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI9"!F:6QE(&9O<FUA=`!);G9A
M;&ED(&QI8V5N<V4@:V5Y+@!);G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+@!)
M;G9A;&ED(&US9U]T>7!E+@!);G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+@!)
M;G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV86QI9"!P87)E;G0@
M<&5R;6ES<VEO;BX`26YV86QI9"!P87)T;F5R(&ED+@!);G9A;&ED('!R;V1U
M8W0@8V]D92X`26YV86QI9"!P<F]T;V-O;"X`26YV86QI9"!R96-I<&EE;G0Z
M("(E<R(`26YV86QI9"!S:&%R92!O8FIE8W0`26YV86QI9"!S;W5R8V4@861D
M<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN=F5N=&]R>0!);G9E<G0@
M<V5L96-T:6]N`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L
M86YD`$ES;&4@;V8@36%N`$ES;VQA=&5D(%0M4W1O<FUS`$ES<F%E;`!)<W-U
M97(`271A;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A;F5S
M92`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I
M9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*
M=7-T:69Y(%)I9VAT`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`
M2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N
M96P@3F5W8FEE<P!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,
M96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O
M;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E82P@
M1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L
M:6,@;V8`2V]R96%N("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$QA7WEO
M=70`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`
M3&%S="!(86QF`$QA<W0@4&%S<W=O<F0@0VAA;F=E`$QA<W0@475A<G1E<@!,
M87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R
M;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA`$QA=P!,87EO=70`3&5A
M=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`3&5F="!H96%D
M97(`3&5F="!V86QU97,`3&5S;W1H;P!,979E;`!,:6)E<FEA`$QI8GEA;B!!
M<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H="!$<FEZ>FQE`$QI
M9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN($QA=&4`3&EG
M:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG:'0@
M4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6YK`$QI;FL@<&]I
M;G1S('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E
M('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X($-O;VMI90!,:7-T
M("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES
M="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES="U(
M96QP`$QI<W0M260`3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I
M8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@
M)7,`3&ES=&EN9R!U<V5R<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@:7,@
M9&ES86)L960N`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO861I;F<N+BX`3&]C
M86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G
M(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;@!,;V<@;W5T`$QO9VEN`$QO9VEN
M(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@
M<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN(&9A:6QE
M9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE='1E<G,`3&]W
M97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$QU>&5M8F]U
M<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A
M=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@
M4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I8P!-86EL`$UA:6P@061M:6X`
M36%K92!L:6Y?:RXN+@!-86QA=VD`36%L87ES:6$`36%L9&EV97,`36%L:0!-
M86QT80!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T
M;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET
M:"!T:&]S92!C871E9V]R:65S+@!-87`R-"!M87``36%P475E<W0@;6%P`$UA
M<'!I;F=S('-T;W)E9"X`36%R8V@`36%R9VEN`$UA<FL@=VET:"!3965N+U5N
M<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T
M86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T
M8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET:75S`$UA>"!A;&QO=V5D
M(&-R961I="X`36%X(&UE<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T96UP
M(&QA<W0@,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI
M;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS`$UA>&EM=6T@;&5N9W1H`$UA
M>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365N=2!M;V1E.@!-97)G92!C
M96QL<P!-97-S86=E`$UE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U
M="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF
M:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@='EP90!-971A<B!796%T
M:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO
M="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE
M(&%D;6EN:7-T<F%T;W(N`$UE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"X`365T
M:&]D`$UE=&AO9"`B)7,B(&ES(&YO="!D969I;F5D`$UE=&AO9"!N;W0@9&5F
M:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,`365T<FEC`$UE>&EC;P!-:6-R;VYE
M<VEA+"!&961E<F%T960@4W1A=&5S(&]F`$UI9&1L90!-:6UE(%1Y<&4`36EN
M('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA<W0@-B!H;W5R<SH@
M`$UI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960`36ER
M<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!014%2('!A8VMA9V4@2%144%]2
M97%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E
M;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A
M=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG(')E<75I<F5D(%!%
M05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@240N`$UO`$UO8FEL
M92!-86EL`$UO9&5R871E`$UO9&EF:65D($1A=&4`36]D:69Y(%523`!-;V1U
M;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYG;VQI80!-;VYT
M:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1S97)R870`36]O;B!0:&%S97,`36]R
M92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E
M9"X`36]R;V-C;P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D>0!-;W-T;'D@
M4W5N;GD`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``
M36]V92!D;W=N`$UO=F4@=7``36]Z86UB:7%U90!-=6QT:2UL979E;"!D<F]P
M(&1O=VX@;&ES=',`375L=&EM87`@54L@;6%P`$UU;'1I<&QE('-E;&5C=&EO
M;@!->2!!8V-O=6YT`$UY($%C8V]U;G0@26YF;W)M871I;VX`37D@4&]R=&%L
M`$UY(%!O<G1A;"!,87EO=70`37EA;FUA<@!.3RP@22!$;R!.3U0@06=R964`
M3F%M90!.86UI8FEA`$YA=7)U`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA
M;F1S($%N=&EL;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!(%)E
M=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@
M4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@
M4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0`
M3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R`$YE=R!#
M86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!-97-S86=E('1O("5S`$YE=R!-
M;V]N`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!P
M87-S=V]R9`!.97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N`$YE=R!P
M87-S=V]R9',@9&]N)W0@;6%T8V@N`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W
M<P!.97=S9W)O=7!S`$YE>'0`3F5X="`T(%!H87-E<P!.97AT(&]P=&EO;G,`
M3F5X=#X`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.
M;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R
M96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)
M4T\@:6UA9V5S+@!.;R!B871C:"!T96UP;&%T92X`3F\@8FQO8VL@97AI<W1S
M(&%T('1H92!R97%U97-T960@<&]S:71I;VX`3F\@8V%L96YD87(@;F%M92!P
M<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BX`3F\@8VAA;F=E+@!.
M;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+@!.
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N
M`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&
M5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N`$YO
M(&1E<W1I;F%T:6]N('-U<'!L:65D+@!.;R!F:6QE('5P;&]A9&5D`$YO(&EC
M;VYS(&9O=6YD+@!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&QO8V%T:6]N('!R
M;W9I9&5D+@!.;R!M97-S86=E('-U<'!L:65D+@!.;R!N86UE('-P96-I9FEE
M9"X`3F\@;G5M8F5R('-P96-I9FEE9"X`3F\@;V9F96YS:79E(&9O<G1U;F5S
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO
M;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N
M=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T
M:&5N=&EC871I;VXN`$YO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R
M;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O('=O
M<FL@=VET:"!02T-3(#$R(&1A=&$N`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@
M<75O=&$@<V5T+@!.;R!R=6QE<P!.;R!S97!A<F%T;W(@<W!E8VEF:65D+@!.
M;R!S:61E<P!.;R!S=6-H(&9I;&4`3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A
M=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O
M<F0@<V5N="X`3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960`3F\@=F%L=65S
M`$YO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@
M4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN
M('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N
M+@!.;VYE`$YO;F4@*'5S92!I;7!L:6-I="D`3F]R9&EC("A)4T\M.#@U.2TQ
M,"D`3F]R9F]L:R!)<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R
M;B!-87)I86YA($ES;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E
M`$YO="!A(&1I<F5C=&]R>0!.;W0@:6UP;&5M96YT960N`$YO="!S970`3F]T
M('-U<'!O<G1E9"X`3F]T97,`3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN
M`$YO=F5M8F5R`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@
M;V8@8V]L=6UN<P!.=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C:69I
M960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/8FIE
M8W0`3V)J96-T($-R96%T;W(`3V-T86P`3V-T;V)E<@!/9F9E;G-E(&9I;'1E
M<@!/9F9I8V4`3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R
M96YT+@!/;&0@<&%S<W=O<F0`3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T
M+@!/;6%N`$]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E
M<G,N`$]N;'D@;V9F96YS:79E(&9O<G1U;F5S`$]N;'D@;VYE(&5M86EL(&%D
M9')E<W,@86QL;W=E9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN
M:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES
M<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-3
M3"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3
M+TU)344@<&%R="X`3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/
M<&5R871I;F<@4WES=&5M`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E
M9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R9V%N
M:7II;F<`3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN86P@
M=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=VYE
M<B!097)M:7-S:6]N<P!004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL
M86)L92X`4$5!4CHZ36%I;"!B86-K96YD`%!'4"!$:6=I=&%L(%-I9VYA='5R
M90!01U`@16YC<GEP=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE
M9"]%;F-R>7!T960@1&%T80!02%`@0V]D90!02%`@4VAE;&P`4$T@3&EG:'0@
M4F%I;@!032!286EN`%!-(%-H;W=E<G,`4$T@4VYO=P!032!3;F]W(%-H;W=E
M<G,`4$T@4W5N`%!-(%0M4W1O<FUS`%!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S
M:6YG`%!?2%`@4VAE;&P`4&%D9&EN9P!086MI<W1A;@!086QA=0!086QE<W1I
M;FEA;B!497)R:71O<GDL($]C8W5P:65D`%!A;F%M80!087!U82!.97<@1W5I
M;F5A`%!A<F%G=6%Y`%!A<G1L>2!#;&]U9'D`4&%S<W=O<F0`4&%S<W=O<F0@
M8VAA;F=E9"!S=6-C97-S9G5L;'DN`%!A<W-W;W)D(&EN8V]R<F5C=`!087-S
M=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!087-S
M=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z(`!0
M87-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A
M<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z`%!E;W!L90!097)C96YT`%!E<F9O
M<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B`B
M)7,B(&YO="!D96QE=&5D+@!097)M:7-S:6]N($1E;FEE9`!097)M:7-S:6]N
M<P!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!097)S;VYA;"!);F9O<FUA
M=&EO;@!097)U`%!E=',`4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I=&-A
M:7)N`%!I>&5L<P!0;&%T:71U9&5S`%!L96%S92!C;&EC:R!I;G1O('-O;64@
M8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T
M:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@
M=6YL:6YK('1H:7,@96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD
M(&$@>65A<BX`4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E
M9V]R>3H`4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RX`4&QE87-E
M(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES
M(&EN('1H92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE
M87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@
M<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A<V4@<F5A
M9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE
M('1E<FUS('1O('5S92!T:&4@<WES=&5M+@!0;&5A<V4@='EP92!T:&4@;F5W
M(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0;VQI=&EC<P!0;VQL<P!0;W)T=6=A
M;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F('1H
M:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y
M($E-05`I`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@`%!R
M96-I<&ET871I;VX\8G(@+SYC:&%N8V4`4')E9G-?;&1A<#H@4F5Q=6ER960@
M3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5F<U]S97-S:6]N.B!297%U
M:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R97-S=7)E`%!R
M97-S=7)E(&%T('-E82!L979E;#H@`%!R97-S=7)E.B``4')E=FEE=P!0<F5V
M:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E=FEO=7,@;W!T:6]N
M<P!0<FEN="!D;V-U;65N=`!0<FEV871E($ME>0!0<F]B;&5M`%!R;V)L96T@
M1&5S8W)I<'1I;VX`4')O:F5C=',`4')O;7!T('1E>'0`4'5B;&EC($ME>0!0
M=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,@2V5Y($EN9F\`4'5B;&EC+U!R
M:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`4'5E
M<G1O(%)I8V\`46%T87(`475E<GD`475O=&$`4E-!(%!U8FQI8R!+97D@*"5D
M(&)I="D`4F%D:6\@<V5L96-T:6]N`%)A:6X`4F%I;B!%87)L>0!286EN($QA
M=&4`4F%I;B!3:&]W97(`4F%I;B!A;F0@4VYO=P!286EN('1O(%-N;W<`4F%N
M9&]M($9O<G1U;F4`4F%T:6\`4F5A9`!296%D(&UE<W-A9V5S`%)E86QL>2!D
M96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E
M86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A
M=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!2961O97,@>6]U<B!L87-T(&%C=&EO
M;@!2969R97-H`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.@!2969R
M97-H(%!O<G1A;"!6:65W.@!296=E>`!296QA=&EO;G-H:7`@0G)O=W-E<@!2
M96QO860`4F5M87)K<P!296UO=&4@4V5R=F5R<P!296UO=&4@55),("AH='1P
M.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!";&]C
M:P!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E;6]V92!P86ER
M`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@
M9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T:&ES(&YO9&4@9G)O;2!T
M:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z("5S`%)E<75E
M<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@
M`%)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"X`4F5Q=6ER
M960@(B5S(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN`%)E
M<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO
M;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I
M;VXN`%)E<75I<F5D($9I96QD`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T
M(%EO=7(@4&%S<W=O<F0`4F5S=&]R92!,87-T(%%U97)Y`%)E<W5L=',`4F5T
M=7)N('1O($]P=&EO;G,`4F5T>7!E(&YE=R!P87-S=V]R9`!2975N:6]N`%)E
M=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2
M:61D;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?=R!0
M<F]P97)T:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,
M969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE
M<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R
M;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L
M=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY
M`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O34E-12!#<GEP=&]G
M<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`4T%3
M3"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@365S<V%G
M:6YG`%-13"!3:&5L;`!344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S
M`%-32`!354-#15-3`%-?44P@4VAE;&P`4V$`4V%I;G0@2&5L96YA`%-A:6YT
M($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@86YD
M($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S`%-A
M;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE(&%N
M9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`4V%U9&D@07)A8FEA`%-A
M=F4`4V%V92`B)7,B`%-A=F4@)7,`4V%V92!/<'1I;VYS`%-A=F4@9V5N97)A
M=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R
M=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A
M=&EO;BX`4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`%-C
M871T97)E9"!4+5-T;W)M<P!38VEE;F-E`%-E87)C:`!396%R8V@@16YG:6YE
M<P!396QE8W0@1FEL97,`4V5L96-T(&$@9&%T90!396QE8W0@82!G<F]U<"!T
M;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E<@!396QE
M8W0@82!U<V5R('1O(&%D9`!396QE8W0@86QL`%-E;&5C="!A;&P@9&%T92!C
M;VUP;VYE;G1S+@!396QE8W0@86X@;V)J96-T`%-E;&5C="!N;VYE`%-E;&5C
M="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO
M=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T:&4@
M=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@
M=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT
M('1O(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L96-T
M('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N
M`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R
M<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E
M;F5G86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R
M;P!397)I86P@3G5M8F5R`%-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I
M;&%B;&4N`%-E<W-I;VX@061M:6X`4V5S<VEO;B!)1"!E>'!I<F5D+@!397-S
M:6]N<P!3970`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO
M=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@=7`@<F5M
M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R
M('!O<G1A;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N
M92!A;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T
M:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R
M(&1I<W!L87D@;W!T:6]N<RX`4V5T=7``4V5T=7`@=7!G<F%D92!S8W)I<'1S
M(&%V86EL86)L90!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H
M92!P87)A;65T97(Z(`!397EC:&5L;&5S`%-H;W!P:6YG`%-H;W)T(%-U;6UA
M<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN
M:W,_`%-H;W<`4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S
M879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@!3
M:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@;W!T
M:6]N('1O(&ME97`@;W)I9VEN86P`4VAO=R!P:6-K97(`4VAO=R!T86)L92!O
M<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L
M969T/P!3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H
M;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE
M(%)O=R!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!I;6%G92!P<F]P97)T
M:65S(&1I86QO9P!3:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@16%R;'D`
M4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y`%-H<FEN:P!3
M:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H
M92!W87D@9FER<W0`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E`%-I
M9VYA='5R92!!;&=O<FET:&T`4VEN9V%P;W)E`%-I>F4`4VMI<"!-86EN=&5N
M86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R`%-N;W<@
M4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W97)S($QA=&4`
M4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I;B!W871E<CH@`%-O;&]M
M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R="!O<F1E<B!S
M96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@069R:6-A`%-O=71H($5U
M<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U
M=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E
M(&)E='=E96X@861J86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT
M(&%N9"!B;W)D97(@:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG(&%N
M9"!P861D:6YG`%-P86EN`%-P86T`4W!E8VEA;"!#:&%R86-T97(@26YP=70`
M4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W`%-P;W)T<P!3<FD@
M3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K`%-T87)T('EE87(`4W1A=&4@;W(@
M4')O=FEN8V4`4W1A='5S`%-T;W)A9V4@9F]R;6%T`%-T<F5E="!!9&1R97-S
M`%-T<FEK971H<F]U9V@`4W1R:6YG(&QI<W0`4W1R:7`@9&]M86EN(&9R;VT@
M=&AE(&%D9')E<W,`4W1Y;&4@6T-34UT`4W4`4W5B9&ER96-T;W)Y("(E<R(@
M;F]T(&9O=6YD+@!3=6)J96-T`%-U8FUI=`!3=6)M:71T960@<F5Q=65S="!T
M;R!A9&0@(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N;F]T(&QO9R!I;B!U
M;G1I;"!Y;W5R(')E<75E<W0@:&%S(&)E96X@87!P<F]V960N`%-U8G-C<FEP
M=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!A9&1E9"`B)7,B('1O('1H92!S>7-T
M96TN`%-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@(B5S(B!F
M<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!D96QE=&5D("(E<R(N`%-U
M8V-E<W-F=6QL>2!R96UO=F5D("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C
M97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E
M92!C:&%N9V5S+@!3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R
M871I;VXN`%-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R
M871I;VX@9FEL92`E<RX`4W5C8V5S<V9U;&QY('5P9&%T960@(B5S(@!3=6-C
M97-S9G5L;'D@=W)O=&4@)7,`4W5D86X`4W5M;6%R>0!3=6X@4FES90!3=6X@
M4V5T`%-U;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U
M;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U
M<FYA;64`4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N
M`%-W:71Z97)L86YD`%-Y;F,@;&]G(&1E;&5T960`4WEN8TU,`%-Y;G1A>"!E
M<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`5"U3
M=&]R;0!4+5-T;W)M(&%N9"!7:6YD>0!4+5-T;W)M<P!4+5-T;W)M<R!%87)L
M>0!44U8@9FEL90!486)L90!486)L92!0<F]P97)T:65S`%1A8FQE(%-E=`!4
M86)L92!P<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F($-H
M:6YA`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!4
M87)G970Z`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H
M;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP97)A='5R93QB
M<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S`%1E;7!L871E("(E<R(@;F]T
M(&9O=6YD+@!496UP;&%T92!!9&UI;FES=')A=&EO;@!497AT`%1E>'0@3VYL
M>0!497AT(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA
M;F0`5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`5&AE($AI
M<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D+@!4:&4@2&]R9&4O2V]L86(@:6YT
M96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@24U3
M4"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+@!4:&4@36%I;G1E;F%N
M8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I
M;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@861M:6YI<W1R
M871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO
M;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H
M92!B;W1T;VT@<VED92!O;FQY`%1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@
M;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN
M('1H92!D871A8F%S92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A
M9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`5&AE(&1E=&%C:&5D(%!'4"!S
M:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N
M960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H
M97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@
M=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S
M<&5C:69I960N`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S
M96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!F:6QE("5S('-H;W5L9"!C;VYT
M86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@
M<V]M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O
M;G1O(&ET<V5L9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F
M;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C
M.#(R(&UE<W-A9V4N`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O
M(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92!T
M;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R
M;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@
M;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E
M<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S
M('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E
M8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@
M8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A
M;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET
M>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!L969T+6AA;F0@<VED92!O
M;FQY`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@
M9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S
M96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I
M<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G
M92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S
M92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;G5M8F5R
M(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N`%1H92!O<&5N<W-L(&UO9'5L
M92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA
M<W,N`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E
M8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE
M('-I>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E
M("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<75O=&4@
M8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!R
M:6=H="!A;F0@;&5F="!S:61E<R!O;FQY`%1H92!R:6=H="UH86YD('-I9&4@
M;VYL>0!4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T
M97(N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R
M=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F
M;W(@)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@*"5D
M*2!D;V5S(&YO="!E>&ES="X`5&AE('1E;7!O<F%R>2!F:6QE("(E<R(@9&]E
M<R!N;W0@97AI<W0N`%1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T
M8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BX`5&AE('1O<"!A;F0@8F]T=&]M
M('-I9&5S(&]N;'D`5&AE('1O<"!S:61E(&]N;'D`5&AE('5P;&]A9&5D(&1A
M=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N`%1H92!U<&QO
M861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE('=E871H97(N8V]M
M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H96UE<R!D:7)E8W1O<GD@(B5S
M(B!N;W0@9F]U;F0N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`
M5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI
M;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE
M;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@
M96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN
M9R`B)7,B('1O('1H92!S>7-T96TZ("5S`%1H97)E('=A<R!A('!R;V)L96T@
M8VQE87)I;F<@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@
M`%1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@(B5S(B!F<F]M('1H92!S
M>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG("(E<R(Z("5S
M`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO
M("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H
M92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X
M:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A
M<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI
M;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R
M(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@
M;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!P97)F
M;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0
M;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D
M871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L
M871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB
M=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AI<R!)34%0
M('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI
M<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`
M5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`
M5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N
M`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U
M9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T
M97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I
M;G!L8RYC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R
M:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S
M;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN
M9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@
M9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E
M<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@271A;'D@*&AT='`Z
M+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F
M:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA
M>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I96QD
M(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I
M;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H
M:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="
M($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F;W)M
M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES
M(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B
M:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N="!T:&%T('5N9&5R
M<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T
M(&]F('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES:70@)7,`5&AI<R!M
M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T
M:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A
M<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@
M9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A
M=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W
M(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AU;F1E
M<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE
M('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L92`H=&]O;'1I<"DZ
M`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#
M;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI
M;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O:V5L874`5&]M
M;W)R;W<`5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`5')A;G-L871I;VYS
M`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS90!4=0!4=6YI<VEA
M`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R
M:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E
M.B``52Y6+B!I;F1E>#H@`%523`!54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV
M97)Y('-T871U<R!R97!O<G0`55),.@!59V%N9&$`56MR86EN90!5;F%B;&4@
M=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@97AT<F$@
M=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L92!T;R!C
M:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O
M(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE
M('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O
M9B`B)7,B+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R\E<R(N
M`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C
M;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA
M8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C
M<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL
M92X`56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T
M;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S
M(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I
M<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@(B5S(CH@)7,N`%5N86)L
M92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N
M86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA
M8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E
M(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE
M("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D
M96QE=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R
M96-U<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D
M:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I
M;',`56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L
M92!T;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B
M)7,B+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`56YA
M8FQE('1O(&]P96X@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S
M960@87)C:&EV92X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE
M*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53
M:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@9FEL93H@`%5N86)L92!T
M;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M
M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S
M`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E
M;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@
M9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5
M;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES
M;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET
M92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!6
M1E,@9FEL92!D871A+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A
M('=I;&P@8F4@97AC965D960N`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD
M;V5S('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M
M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F
M<F]M('-E<G9E<B!T;SH@`%5N9FEL960`56YI8V]D92`H551&+3@I`%5N:71E
M9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`
M56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N
M:VYO=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN
M;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@;&]C
M871I;VX@<')O=FED960N`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N
M`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M960`56YP<FEV:6QE
M9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G
M<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T
M;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"!S
M:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@
M8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`
M57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&1A=&5D("(E<R(N`%5P
M9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P
M;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T
M:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`57-E($-U
M<G)E;G0Z("5S`%5S92!34TP`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF
M9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E<@!5<V5R("5S(&ES(&YO="!A
M=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P
M=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<B!296=I<W1R871I;VX@:&%S
M(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`57-E<B!A8V-O=6YT(&YO
M="!F;W5N9`!5<V5R;F%M90!5<V5R;F%M92`B)7,B(&%L<F5A9'D@97AI<W1S
M+@!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!5
M>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T
M:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``5F%L:61I='D`
M5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L=64@:7,@;W9E<B!T:&4@
M;6%X:6UU;2!L96YG=&@@;V8@)7,N`%9A;'5E<P!686QU97,@=&\@<V5L96-T
M(&9R;VT`5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`5F5R:69I8V%T:6]N
M(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D
M('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N
M`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6:65T($YA
M;0!6:65T;F%M97-E("A625-#24DI`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA
M;"!W96(@<&%G90!6:65W(&%S("5S`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H
M`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@
M`%9O9&%F;VYE($ET86QY('9I82!33510`%=!4DX`5T%23DE.1R$A(2!214U/
M5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=)3B!V:6$@2%144`!786QL
M:7,@86YD($9U='5N80!787)N:6YG`%=E`%=E871H97(@1F]R96-A<W0`5V5A
M=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!796(@4VET
M90!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=E
M<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T
M97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y
M(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R
M/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H97)E:7,@075S=')A
M;&EA(&UA<`!7:&EC:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@
M9F]R('1H92!2:6-H(%1E>'0@961I=&]R+@!7:61T:`!7:61T:"!I;B!#4U,@
M=6YI=',`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S
M(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T86)L90!7
M:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I;F0`5VEN9"!%87)L>0!7:6YD('-P
M965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`5VES:&QI<W0`5V]R
M:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!7<F]N9R!N=6UB97(@;V8@9FEE
M;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@
M;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+@!7<F]N
M9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+@!8+5)E9@!8
M-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S($5X=&5N9&5D($ME>2!5
M<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE`%@U,#EV,R!3
M=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E9
M65D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S`%EE<RP@22!!9W)E90!9
M;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@
M<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@86QL;W=E9"!T
M;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RX`66]U(&%R92!N;W0@875T
M:&5N=&EC871E9"X`66]U(&-A;FYO="!H879E('1H92`G7"<@8VAA<F%C=&5R
M(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED
M(&5M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O
M;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L
M9',@:6X@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@
M=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL
M>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@
M9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L
M=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@
M=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD
M+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A
M;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@=&AE
M(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C
M="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<W!E8VEF>2!A
M('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A('5S
M97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA
M;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U
M<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R
M;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+@!9;W4@;F5E
M9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R`%EO=7(@)7,@
M<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R
M($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R
M;6%T:6]N`%EO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC
M92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C
M="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!.
M86UE`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P
M;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@=7-E($AO<F1E('1O
M(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF
M9F5R96YT(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0N`%EO=7(@875T:&5N=&EC
M871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L
M(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T
M:&5R(')E87-O;BX`66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N
M9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4
M;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN
M+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N
M`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T
M:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0('1O('!R:6YT+@!9;W5R
M(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S
M(&)E96X@8VAA;F=E9"X`66]U<B!D969A=6QT(&ED96YT:71Y.@!9;W5R(&9U
M;&P@;F%M93H`66]U<B!L;V=I;B!H87,@97AP:7)E9"X`66]U<B!N97<@<&%S
M<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P
M9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN`%EO=7(@
M;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P87-S=V]R9"!H87,@
M8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C
M:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S=V]R
M9"X`66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"X`66]U<B!R96UO=&4@<V5R
M=F5R<SH`675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`
M6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O
M=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S70!;;&EN
M92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]#3$D`7T1A=&%4<F5E`%]$
M96QE=&4@4F]W`%]'<F]U<',`7TAE;'``7TEM86=E(%!R;W!E<G1I97,N+BX`
M7TQO9R!I;@!?3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`7T]P=&EO;G,`7U!E
M<FUI<W-I;VYS`%]296UO=F4@3&EN:RXN+@!?4V5T=7``7U1A8FQE(%!R;W!E
M<G1I97,N+BX`7U5S97)S`&%D9')E<W,@8F]O:P!A9&1R97-S964@=6YK;F]W
M;@!C86QE;F1A<@!C86QM`&-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4`8V%N
M;F]T(&]P96X@:6YP=70`8VQI8VL@:&5R90!C;VUM86YD(&QI;F4@=7-A9V4@
M97)R;W(`8V]N9FEG=7)A=&EO;B!E<G)O<@!C<FET:6-A;"!S>7-T96T@9FEL
M92!M:7-S:6YG`&1A=&$@9F]R;6%T(&5R<F]R`&5D:70`96YT<GD@;F]T(&9O
M=6YD`&9A;&QI;F<`9FEL90!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&=U
M<W1I;F<`:#H`:&@`:&]S="!N86UE('5N:VYO=VX`:6UM961I871E`&EN;&EN
M90!I;G!U="]O=71P=70@97)R;W(`:6YT97)N86P@<V]F='=A<F4@97)R;W(`
M;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/
M+@!M;0!N86UE`&YO="!I;7!L96UE;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D
M`&YO=&5P860`<&5R8V5N=`!P97)M:7-S:6]N(&1E;FEE9`!P:7AE;',`<F5M
M;W1E(&5R<F]R(&EN('!R;W1O8V]L`')I<VEN9P!S97)V:6-E('5N879A:6QA
M8FQE`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10`'-S`'-T
M96%D>0!S>7-T96T@97)R;W(`=&%S:R!L:7-T`'1E;7!O<F%R>2!F86EL=7)E
M`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U
M;FYA;65D`'5S97(@<V5L96-T`'9#87)D`'<Z`'=E871H97(N8V]M`%!R;VIE
M8W0M260M5F5R<VEO;CH@2&]R9&4*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E
M=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M
M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`V+3`R+3$U(#$V
M.C4P+3`R,#`*3&%S="U4<F%N<VQA=&]R.B!&86)I;R!';VUE<R`\9FQG;VUS
M0'5O;"YC;VTN8G(^"DQA;F=U86=E+51E86TZ($)R87II;&EA;B!0;W)T=6=U
M97-E(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*
M0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3$*
M0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`I8+4=E;F5R871O<CH@
M2T)A8F5L(#$N,RXQ"E!L=7)A;"U&;W)M<SH@(&YP;'5R86QS/3([('!L=7)A
M;#TH;B`^(#$I.PH`("@E<R!D:6%S(&%T<N%S*0`@*%1E8VQA(&1E($%T86QH
M;R`E<RD`("AE;2`E<R!D:6%S*0`@*&AO:F4I`"`H86UA;FCC*0`@*&]N=&5M
M*0`@82``(B5S(B!.XV\@Z2!U;2!D:7)E=/-R:6\N`"<E<R<@;N-O(.D@=6UA
M(&5S8V]L:&$@=N%L:61A+@`G)7,G(&[C;R!E<W3A(&-O;F9I9W5R861O(&YO
M(%)E9VES=')O(&1O($AO<F1E+@!R96YD97)I>F%D;W(@9&4@X7)V;W)E("(E
M<R(@;N-O(&5N8V]N=')A9&\N`"(E<R(@9F]I(&%D:6-I;VYA9&\@86\@<VES
M=&5M82!D92!G<G5P;W,N`"(E<R(@9F]I(&%D:6-I;VYA9&\@86\@<VES=&5M
M82!D92!P97)M:7-S]65S+@`B)R5S(B!NXV\@9F]I(&-R:6%D;SH@)7,N`"4N
M,F9-0B!U<V%D;W,@9&4E+C)F34(@<&5R;6ET:61O<R`H)2XR9B4E*0`E9"`E
M<R!E("5S`"5D(&1I87,@873I('-U82!S96YH82!E>'!I<F%R+@`E9"!P<F5V
M:7/C;R!D;R!D:6$`)7,@+2!!=FES;P!);7!R97-SXV\@1&EG:71A;"!D92`E
M<P`E<R!+0@`E<R!/<&5R8>?U97,@9&4@36%N=71E;N?C;R`M($-O;F9I<FUA
MY^-O`$-O;F9I9W5R8>?C;R!D92`E<P!#861A<W1R;R!D92`E<P`E<R!497)M
M;W,@9&\@06-O<F1O`"5S(&KA(&5X:7-T92X`)7,@82`E<R`E<P`E<R!E<W3A
M('!R;VYT;R!P87)A(&5X96-U=&%R(&%S(&]P97)AY_5E<R!D92!M86YU=&5N
MY^-O(&UA<F-A9&%S(&%B86EX;RX@36%R<75E(&$@8V%I>&$@<&%R82!Q=6%L
M<75E<B!O<&5R8>?C;R!Q=64@=F]CZB!Q=65I<F$@97AE8W5T87(@9&5S=&$@
M=F5Z+@`E<R#I(&]B<FEG873S<FEO`"5S(&UI;G5T;W,`)7,@;N-O(&5N8V]N
M=')A9&\N`"5S(&$@)7,@9&4@)7,`0V%TX6QO9V\@9&4@16YD97)EYV]S(&1E
M("5S`$%G96YD82!D92`E<P!!;F]T8>?U97,@9&4@)7,`3&ES=&$@9&4@5&%R
M969A<R!D92`E<P`E<SH@)7,`)7,Z($5S=&$@;65N<V%G96T@<&]D92!NXV\@
M<V5R(&1E('%U96T@96QA(&1I>B!S97(N(%1O;64@8W5I9&%D;R!C;VT@<75A
M;'%U97(@;&EN:R!P<F5S96YT92!N96QA(&]U(&5M(&9O<FYE8V5R(&%O(')E
M;65T96YT92!Q=6%L<75E<B!I;F9O<FUAY^-O('!E<W-O86PN`"P@8G)I<V$@
M`"P@8G)I<V$@)7,@)7,`+"!V87)IX79E;"!D92`E<R!P87)A("5S`"TM('-E
M;&5C:6]N92`M+0!&;W)M871O(#$R($AO<F%S`$9O<FUA=&\@,C0@2&]R87,`
M,C0@:&]R87,`/%#A9VEN82!!;G1E<FEO<@!5;2!C;VYE8W1O<B!D92!B86YC
M;R!D92!D861O<R#I(&]B<FEG873S<FEO('!A<F$@97-T92!B;&]C;RX`56T@
M97)R;R!F871A;"!O8V]R<F5U`%5M82!C:&%V92!P^F)L:6-A(%!'4"#I(&]B
M<FEG873S<FEA('!A<F$@8W)I<'1O9W)A9F%R('5M82!M96YS86=E;2X`56UA
M(&-H879E('#Z8FQI8V$@4$=0(.D@;V)R:6=A=/-R:6$@<&%R82!V97)I9FEC
M87(@=6UA(&UE;G-A9V5M(&%S<VEN861A+@!5;6$@8VAA=F4@<')I=F%D82!0
M1U`@92!U;6$@<V5N:&$@<^-O(&]B<FEG873S<FEA<R!P87)A(&1E<V-R:7!T
M;V=R869A<B!U;6$@;65N<V%G96TN`%5M82!C:&%V92!P<FEV861A(%!'4"!E
M('5M82!S96YH82!SXV\@;V)R:6=A=/-R:6%S('!A<F$@87-S:6YA<B!U;6$@
M;65N<V%G96TN`%5M82!C:&%V92!P^F)L:6-A(%,O34E-12P@=6UA(&-H879E
M('!R:79A9&$@4R]-24U%(&4@=6UA('-E;FAA('/C;R!O8G)I9V%T\W)I87,@
M<&%R82!D97-C<FEP=&]G<F%F87(@=6UA(&UE;G-A9V5M+@!5;6$@8VAA=F4@
M</IB;&EC82!3+TU)344L('5M82!C:&%V92!P<FEV861A(%,O34E-12!E('5M
M82!S96YH82!SXV\@;V)R:6=A=/-R:6%S('!A<F$@87-S:6YA<B!U;6$@;65N
M<V%G96TN`%5M82!C:&%V92!P^F)L:6-A(%,O34E-12#I(&]B<FEG873S<FEA
M('!A<F$@8W)I<'1O9W)A9F%R('5M82!M96YS86=E;2X`3G5V96YS(&UA='5T
M:6YA<P!#:'5V82!&<F%C82!697-P97)T:6YA`$-H=79A(&UA='5T:6YA`$-H
M=79A<R!M871U=&EN87,`3F5V87-C87,@36%T=71I;F%S`$%-+U!-`$%022!)
M1`!3;V)R92!E<W1E(&5D:71O<@!3;V)R92XN+@!!8G-B;W1T;VT`06)S;6ED
M9&QE`$%C97-S;R!N96=A9&\@86\@8W)I87(@9&ER973S<FEO(%9&4RX`06-E
M<W-O(&YE9V%D;R!A;R!C<FEA<B!A<G%U:79O(%9&4RX`4W5A<R!);F9O<FUA
MY_5E<P!396YH82!D82!#;VYT80!#;VYT82!D97-A=&EV861A+@!#;VYT87,`
M061I8VEO;F%R`$%D:6-I;VYA<B!'<G5P;R!3=6)O<F1I;F%D;P!!9&EC:6]N
M87(@4&5R;6ES<_5E<R!3=6)O<F1I;F%D87,`061I8VEO;F4@07%U:3H`061I
M8VEO;F%R($YO=F\@1W)U<&\`061I8VEO;F%R($YO=F$@4&5R;6ES<^-O`$%D
M:6-I;VYA<B!U;2!G<G5P;R!S=6)O<F1I;F%D;R!A("<E<R<`061I8VEO;F%R
M('5M82!P97)M:7-SXV\@<W5B;W)D:6YA9&$@82`G)7,G`$%D:6-I;VYA<B!U
M;2!N;W9O('5S=>%R:6\Z`$%D:6-I;VYA<B!C;VQU;F$`061I8VEO;F%R(&YO
M=F]S(&UE;6)R;W,`061I8VEO;F%R('!A<@!!9&EC:6]N87(@;R!-96YU("5S
M(&-O;6\@=6UA($)A<G)A($QA=&5R86P@9&\@36]Z:6QL80!!9&EC:6]N87(@
M86\@8V%TX6QO9V\@9&4@96YD97)EYV]S.@!!9&EC:6]N87(@86\@;65U(&-A
M=.%L;V=O(&1E(&5N9&5R9>=O<P!!9&EC:6]N87(@=7-UX7)I;P`G)7,G(&%D
M:6-I;VYA9&\@86\@<VES=&5M82P@;6%S(&[C;R!P=61E(&EN8VQU:7(@:6YF
M;W)M8>?U97,@861I8VEO;F%I<R!D;R!C861A<W1R;SH@)7,N`"5S(&%D:6-I
M;VYA9&\@86\@<VES=&5M82X@5F]CZB!P;V1E('-E(&-O;F5C=&%R(&%G;W)A
M+@!!9&GGXV\@9&4@=7-UX7)I;W,@97-TX2!D97-A8FEL:71A9&$N`$5N9&5R
M9>=O`$-A=.%L;V=O(&1E($5N9&5R9>=O<P!!9&UI;FES=')A<B`M(&-O;F9I
M9W5R82!P97)M:7-S]65S('!A<F$@;W5T<F]S('5S=>%R:6]S`$%D;6EN:7-T
M<F'GXV\`06[Z;F-I;W,`069E9V%N:7-TXV\`06QBXFYI80!!<F?I<FEA`$%P
M96QI9&\`06QI;FAA<@!!;&EN:&%M96YT;SH`5&]D;W,`5&]D;W,@57-UX7)I
M;W,@075T96YT:6-A9&]S`%1O9&]S($=R=7!O<P!4;V1A<R!097)M:7-S]65S
M`%1O9&]S('%U871R;R!L861O<P!097)M:71I<B!M^FQT:7!L;W,@96YD97)E
MYV]S`%!E<FUI=&ER(&-O;F9I9W5R87(@;R!T:7!O(&1E(&QI<W1A<R!O<F1E
M;F%D87,_`$KA(&5X:7-T90!,;V=I;B!)35-0($%L=&5R;F%T:79O`%-E;FAA
M($E-4U`@06QT97)N871I=F$`57-UX7)I;R!)35-0($%L=&5R;F%T:79O`$5N
M9&5R9>=O(&1E(&4M;6%I;"!A;'1E<FYA=&EV;P!-;V1E;&]S(&%L=&5R;F%T
M:79O<P!497AT;R!A;'1E<FYA=&EV;SH`4V%M;V$@06UE<FEC86YA`%5M('9A
M;&]R(&EL96=A;"!F;VD@97-P96-I9FEC861O+@!/8V]R<F5U('5M(&5R<F\@
M9&5S8V]N:&5C:61O+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!0<F]X>2!A
M;O1N:6UO`%)E<W!O<W1A`$%N=.%R=&ED80!!;G1I9W5A(&4@0F%R8F%D;W,`
M07!L:6-AY^-O`$QI<W1A(&1E($%P;&EC8>?U97,`02!A<&QI8V'GXV\@97-T
MX2!P<F]N=&$N`$%P;&EC87(@86]S($-O;7!A<G1I;&AA;65N=&]S(%-U8F]R
M9&EN861O<P!!<')O=F%R`%1A;6%N:&\@07!R;WAI;6%D;P!!8G)I;`!!<N%B
M:6-O("A7:6YD;W=S+3$R-38I`%1A;6%N:&\@9&\@07)Q=6EV;P!.;VUE(&1O
M($%R<75I=F\`5F]CZB!T96T@8V5R=&5Z82!Q=64@<75E<B!R96UO=F5R(&$@
M<V]L:6-I=&'GXV\@9&4@8V%D87-T<F\@9&4@)7,_`%9O8^H@=&5M(&-E<G1E
M>F$@<75E(&1E<V5J82!E>&-L=6ER("<E<R<@92!S975S('-U8F=R=7!O<S\`
M07)G96YT:6YA`$%R;>IN:6$`07)MZFYI;R`H05)-4T-)22TX*0!!<G1E`$%R
M=6)A`$EL:&$@07-C96YSXV\`07)T92!!<V-I:0#!<VEA+U)E9VGC;R!D;R!0
M86/M9FEC;P!3;VQI8VET87(@8V]N9FER;6'GXV\@86YT97,@9&4@97AE8W5T
M87(@87,@;W!E<F'G]65S(&1E(&UA;G5T96[GXV\_`$-O;'5N87,@9&4@9&5S
M:6=N8>?C;P!496YT;W4@97AC;'5I<B!U;2!G<G5P;R!I;F5X:7-T96YT92X`
M5&5N=&]U(&5X8VQU:7(@=6UA('!E<FUI<W/C;R!NXV\@97AI<W1E;G1E+@!4
M96YT;W4@961I=&%R('5M82!P97)M:7-SXV\@;N-O(&5X:7-T96YT92X`5&5N
M=&]U(&5D:71A<B!U;2!C;VUP87)T:6QH86UE;G1O(&[C;R!E>&ES=&5N=&4N
M`$%T<FEB=71O<P!!9V]S=&\`075S='+A;&EA`,%U<W1R:6$`075T:%]C>7)S
M<6PZ($[C;R!F;VD@96YC;VYT<F%D82!A(&5X=&5N<^-O(&EM87`@;F5C97-S
MX7)I82X`075T:%]C>7)U<SH@3R!C;VYE8W1O<B!NXV\@<&]S<W5I(&%S(&-A
M<&%C:61A9&5S(&YE8V5S<^%R:6%S+@!!=71H7V-Y<G5S.B!.XV\@9F]I(&5N
M8V]N=')A9&$@82!E>'1E;G/C;R!I;6%P(&YE8V5S<^%R:6$N`$%U=&A?9G1P
M.B!.XV\@9F]I(&5N8V]N=')A9&$@82!E>'1E;G/C;R!&5%`@;F5C97-SX7)I
M82X@0V]M<&EL92!O(%!(4"!C;VT@82!O<.?C;R`M+65N86)L92UF='`N`$%U
M=&A?:6UA<#H@3N-O(&9O:2!E;F-O;G1R861A(&$@97AT96YSXV\@:6UA<"!N
M96-E<W/A<FEA+@!!=71H7VMR8C4Z($[C;R!F;VD@96YC;VYT<F%D82!A(&5X
M=&5N<^-O(&MR8C4@;F5C97-SX7)I82X`075T:%]L9&%P.B!);F-L=7/C;R!D
M92!U<W7A<FEO<R!NXV\@Z2!S=7!O<G1A9&$@<&%R82!!8W1I=F4@1&ER96-T
M;W)Y`$%U=&A?;&1A<#H@17AC;'5SXV\@9&4@=7-UX7)I;W,@;N-O(.D@<W5P
M;W)T861A('!A<F$@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z($[C;R!F
M;VD@96YC;VYT<F%D82!A(&5X=&5N<^-O($Q$05`@;F5C97-SX7)I82X`075T
M:%]L9&%P.B!);7!O<W/M=F5L(&%D:6-I;VYA<B!O('5S=>%R:6\@)7,N($ES
M=&\@9F]I(&\@<75E(&\@<V5R=FED;W(@<F5P;W)T;W4Z(`!!=71H7VQD87`Z
M($EM<&]S<^UV96P@<F5M;W9E<B!O('5S=>%R:6\@)7,`075T:%]L9&%P.B!)
M;7!O<W/M=F5L(&%T=6%L:7IA<B!O('5S=>%R:6\@)7,`075T:%]L9&%P.B!!
M='5A;&EZ8>?C;R!D92!U<W7A<FEO<R!NXV\@Z2!S=7!O<G1A9&$@<&%R82!!
M8W1I=F4@1&ER96-T;W)Y+@!!=71H7VUC86PZ($[C;R!F;VD@96YC;VYT<F%D
M82!A(&5X=&5N<^-O($U#04P@;F5C97-SX7)I82X`075T:%]S;6)A=71H.B!.
MXV\@9F]I(&5N8V]N=')A9&$@82!E>'1E;G/C;R!S;6)A=71H(&YE8V5S<^%R
M:6$N`$%U=&5N=&EC8>?C;R!N;R!S97)V:61O<B!)34%0(&9A;&AO=2X`1F%L
M:&$@;F$@875T96YT:6-AY^-O`$9A;&AA(&YA(&%U=&5N=&EC8>?C;SH@)7,`
M075T96YT:6-AY^-O(')E:F5I=&%D82!P96QO('-E<G9I9&]R(%)!1$E54RX`
M02!A=71E;G1I8V'GXV\@;F\@<V5R=FED;W(@1E10(&9A;&AO=2X`02!A=71E
M;G1I8V'GXV\@;F\@<V5R=FED;W(@4TU"(&9A;&AO=2X`0V%M<&]S(&1I<W!O
M;NUV96ES.@!!>F5R8F%I:N-O`$1E<V-U;'!A<R!D;R!"3T9(`$9U;F1O`$-O
M<B!D92!&=6YD;P!396YH82!K97)B97)O<R!I;F-O<G)E=&$N`%5S=>%R:6\@
M:V5R8F5R;W,@:6YC;W)R971O+@!"86AA;6%S`$)A:')A:6X`0N%L=&EC;R`H
M25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`3N-O(&9O:2!E;F-O
M;G1R861O(&\@9&ER973S<FEO(&)A<V4@9&4@:6UA9V5N<R`G)7,G+@!,:6YH
M82!D92!087)T:61A`$)E;&]R^G-S:6$`0NEL9VEC80!"96QI>F4`0F5N:6X`
M0F5R;75D87,`0G5TXV\`06YI=F5R<^%R:6\`3N-O(&9O:2!E;F-O;G1R861O
M(&\@8FQO8V\@(B5S(B!D82!A<&QI8V'GXV\@(B5S(BX`0V]N9FEG=7)AY_5E
M<R!D;R!";&]C;P!4:7!O(&1E($)L;V-O`$YE9W)I=&\`0F]L[79I80!&879O
M<FET;W,`0F]R9&$`3&%R9W5R82!D82!B;W)D83H`0F]R9&%S`$+S<VYI82!E
M($AE<GIE9V]V:6YA`$%M8F]S`$)O='-U86YA`%)O9&%PZ0!);&AA($)O=79E
M=`!"<F%S:6P`5&5R<FET\W)I;R!D;R!/8V5A;F\@S6YD:6-O($EN9VSJ<P!"
M<G5N96D`0G5L9^%R:6$`3&ES=&$@8V]M($UA<F-A9&]R97,`0G5R:VEN82!&
M87-O`$)U<G5N9&D`0TU3`$-20P!0;VYT;W,@9&4@1&ES=')I8G5IY^-O($-2
M3`!0<F]P<FEE9&%D97,@9&$@0^E?;'5L82XN+@!!(&QI<W1A(&1E(&1I<W1R
M:6)U:>?C;R!NXV\@9F]I(&5S<&5C:69I8V%D82X`06=E;F1A`$-A;&UO`$-A
M;6)O9&IA`$-A;6%R]65S`$[C;R#I('!O<W/M=F5L(&=E<F%R('5M82!N;W9A
M('-E;FAA(&%U=&]M871I8V%M96YT92P@96YT<F4@96T@8V]N=&%T;R!C;VT@
M;R!A9&UI;FES=')A9&]R+@!.XV\@8V]N<VEG;R!G<F%V87(@;R!A<G%U:79O
M("(E<R(`3N-O(.D@<&]S<^UV96P@861M:6YI<W1R87(@9V5R96YC:6%D;W)E
M<R!E>'1E<FYO<R!D92!S97-SXV\N`$[C;R#I('!O<W/M=F5L(&-O;F5C=&%R
M(&%O('-E<G9I9&]R($E-05`Z("5S`$[C;R!C;VYS:6=O(&%B<FER(&\@87)Q
M=6EV;R`B)7,B+@!#86YA9.$`0V%N8V5L87(`0V%N8V5L87(@4F5L873S<FEO
M(&1E(%!R;V)L96UA`$[C;R#I('!O<W/M=F5L(&5X8VQU:7(@;R!A<G%U:79O
M("(E<R(N`$[C;R#I('!O<W/M=F5L(&5N8V]N=')A<B!U;2!D:7)E=/-R:6\@
M=&5M<&]RX7)I;RX`3N-O(.D@<&]S<^UV96P@8V]N=&EN=6%R('-E;2!O('!A
M<N)M971R;R`G=&%R9V5T1FEL92<N`$[C;R#I('!O<W/M=F5L(&5X8VQU:7(@
M;R!D:7)E=/-R:6\@(B5S(BX`3N-O(.D@<&]S<^UV96P@97AC;'5I<BP@)60@
M<&]S<W5I('-U8F]R9&EN861O<RX`3N-O(.D@<&]S<^UV96P@<F5O<F1E;F%R
M+"!N^FUE<F\@9&4@<F5G:7-T<F]S(&9O<FYE8VED;W,@<&%R82!R96]R9&5N
M87(@;N-O(&-O<G)E<W!O;F1E(&%O(&[Z;65R;R!A<FUA>F5N861O+@!.XV\@
MZ2!P;W-S[79E;"!R;W1E87(@;65N<V%G96T@<&%R82!O(&[Z;65R;R!E<W!E
M8VEF:6-A9&\N`$-A8F\@5F5R9&4`5.UT=6QO`$]P97)A9&]R80!#871E9V]R
M:6%S(&4@3F]M97,`26QH87,@0V%Y;6%N`%1E;&5F;VYE($-E;'5L87(`4')O
M<')I961A9&5S(&1A($/I;'5L80!-87)G96T@9&$@8^EL=6QA.@!0<F]P<FEE
M9&%D97,@9&$@0^EL=6QA`$5S<&'G86UE;G1O(&1A(&/I;'5L83H`5&5L969O
M;F4@8V5L=6QA<@!#Z6QT:6-O("A)4T\M.#@U.2TQ-"D`0V5N=')O`%)E</IB
M;&EC82!D82#!9G)I8V$@0V5N=')A;`!%=7)O<&$@0V5N=')A;"`H25-/+3@X
M-3DM,BD`1&5T86QH97,@9&\@0V5R=&EF:6-A9&\`4')O<')I973A<FEO(&1O
M($-E<G1I9FEC861O`%!O;.UT:6-A<R!D;R!#97)T:69I8V%D;P!48VAA9&4`
M06QT97)A<@!!;'1E<F4@4W5A(%-E;FAA`$%L=&5R87(@;R!N;VUE(&4@;R!E
M;F1E<F7G;R!Q=64@87,@<&5S<V]A<R!VZF5M('%U86YD;R!E;&%S(&SJ96T@
M92!R97-P;VYD96T@<W5A<R!M96YS86=E;G,N`$%L=&5R8>?C;R!D92!S96YH
M82!NXV\@Z2!S=7!O<G1A9&$@;F$@8V]N9FEG=7)AY^-O(&%T=6%L+B`@16YT
M<F4@96T@8V]N=&%T;R!C;VT@;R!A9&UI;FES=')A9&]R+@!#:&%R`%9E<FEF
M:6-A<B!,:6Y?:RXN+@!#:&EL90!#:&EN80!#:&ENZG,@4VEM<&QI9FEC861O
M("A'0C(S,3(I`$-H:6[J<R!4<F%D:6-I;VYA;"`H0FEG-2D`17-C;VQH82!A
M($%P;&EC8>?C;SH`17-C;VQH82!U;6$@<V5N:&$`17-C;VQH82!U;2!U<W7A
M<FEO`$5S8V]L:&$@8V]M;R!E>&EB:7(@9&%T87,Z`$5S8V]L:&$@;R!T:7!O
M(&1E(&5S=&EL;R!D92!L:7-T87,@*'!A<F$@;&ES=&%S(&]R9&5N861A<RD`
M26QH87,@0VAR:7-T;6%S`$[C;R!F;VD@96YC;VYT<F%D82!A(&1E9FEN:>?C
M;R!D92!C;&%S<V4@9&4@)7,N`$QI;7!A<@!,:6UP87(@=&%G<R!-4T]F9FEC
M90!%>&-L=6ER('5S=>%R:6\`17AC;'5I<B!U<W7A<FEO.B`E<P!%>&-L=6ER
M('5S=>%R:6\`17AC;'5I<B!D861O<R!D;R!U<W7A<FEO`$/I=2!A8F5R=&\@
M82!487)D90!#;&EQ=64@<&%R82!#;VYT:6YU87(`0VQI8VMA=&5L;"!V:6$@
M2%144`!&96-H87(@2F%N96QA`$YU=F5N<P!.=6)L861O('!E;&$@36%N:.,`
M3G5B;&%D;P!);&AA<R!D92!#;V-O<P!#;VYT<F%I<B!"87)R82!,871E<F%L
M`$-O;G1R86ER(&)O<F1A<P!#;VST;6)I80!#;W(`4&%L:&5T82!D92!#;W)E
M<P!396QEY^-O(&1E($-O<@!#;VQS.@!4[71U;&]S(&1A<R!#;VQU;F%S`%%U
M861R:6YH;W,`0V]M86YD;P!,:6YH82!D92!#;VUA;F1O`$-O;65N=&%R`$YO
M;64`0V]M;W)O<P!%;7!R97-A`$-O;7!U=&%D;W)E<P!#;VYD:>?C;P!#;VYD
M:>?U97,`1&EF97)E;N=A<R!D92!#;VYF:6=U<F'GXV\`0V]N9FEG=7)AY^-O
M(&1E('-I;F-R;VYI>F'GXV\@8V]M(%!$07,L(%-M87)T<&AO;F5S(&4@3W5T
M;&]O:RX`0V]N9FEG=7)AY^-O(&YE8V5S<VET82!D92!A='5A;&EZ8>?C;RX`
M0V]N9FEG=7)A<B`E<P!#;VYF:7)M92!A(%-E;FAA`$-O;F=O`$-O;F=O+"!2
M97#Z8FQI8V$@1&5M;V-RX71I8V$@9&\`1F%L:&$@;F$@8V]N97CC;RX`1F%L
M:&$@;F$@8V]N97CC;SH@`$-O;F5XXV\@<F5C=7-A9&$@<&5L;R!S97)V:61O
M<B!D92!C:&%V97,@</IB;&EC87,N`$-O;F5XXV\@<F5C=7-A9&$@<&5L;R!S
M97)V:61O<B!D92!C:&%V97,@</IB;&EC87,N($UO=&EV;SH@)7,@*"5S*0!!
M(&-O;F5XXV\@86\@<V5R=FED;W(@1E10(&9A;&AO=2X`0V]N=&%T;W,`3W,@
M8V]N=&%T;W,@9F]R86T@861I8VEO;F%D;W,@8V]M('-U8V5S<V\@86\@<V5U
M(&-A=.%L;V=O(&1E(&5N9&5R9>=O<RX`5&EP92!D92!C;VYT9?ID;R!D;R!A
M<G%U:79O(&-O;7!R:6UI9&\Z(`!#;VYT9?ID;R!D92`G)7,G`$-O;G1I;G5A
M<@!);&AA<R!#;V]K`$-O;VMI90!#;W!I87(`1F%L:&$@;F$@8_-P:6$Z("5S
M`$-O<&EA<B!S96QEY^-O`$E$(&1E($-U<W1O`$-O<W1A(%)I8V$`0V]S=&$@
M9&\@36%R9FEM`$EM<&]S<^UV96P@8W)I<'1O9W)A9F%R(&$@;65N<V%G96T@
M8V]M(%!'4#H@`$EM<&]S<^UV96P@87-S:6YA<B!A(&UE;G-A9V5M(&-O;2!0
M1U`Z(`!.XV\@9F]I('!O<W/M=F5L(&-R:7!T;V=R869A<B!A(&UE;G-A9V5M
M(&-O;2!3+TU)344N`$[C;R!F;VD@<&]S<^UV96P@87-S:6YA<B!A(&UE;G-A
M9V5M(&-O;2!3+TU)344N`$[C;R!F;VD@<&]S<^UV96P@861I8VEO;F%R(&-O
M;G1A=&\N("5S`$[C;R!F;VD@<&]S<^UV96P@8V]N96-T87(@86\@<V5R=FED
M;W(@3$1!4"X`3N-O(&9O:2!P;W-S[79E;"!V97)I9FEC87(@;R!S86QD;RX@
M)7,`26UP;W-S[79E;"!C;VYE8W1A<B!A;R!S97)V:61O<B!,1$%0+@!.XV\@
M9F]I('!O<W/M=F5L(&-O;F5C=&%R(&%O('-E<G9I9&]R("<E<R<@=71I;&EZ
M86YD;R!&5%`Z("5S`$[C;R!F;VD@<&]S<^UV96P@8W)I87(@82!L:7-T82!D
M92!D:7-T<FEB=6GGXV\N("5S`$EM<&]S<^UV96P@9&5S8W)I<'1O9W)A9F%R
M(&]S(&1A9&]S(%!'4#H@`$[C;R!F;VD@<&]S<^UV96P@9&5S8W)I<'1O9W)A
M9F%R(&\@9&%D;R!3+TU)344N`$[C;R!F;VD@<&]S<^UV96P@97AC;'5I<B!O
M(&-O;G1A=&\N("5S`$[C;R!F;VD@<&]S<^UV96P@97AC;'5I<B!A(&QI<W1A
M(&1E(&1I<W1R:6)U:>?C;RX@)7,`3N-O(&9O:2!P;W-S[79E;"!E>&-L=6ER
M(&\@<V-R:7!T(&1E(&%T=6%L:7IAY^-O(&1E(&-O;F9I9W5R8>?C;R`G)7,G
M+@!.XV\@9F]I('!O<W/M=F5L(&1E=&5R;6EN87(@;R!E;F1E<F7G;R!D92!E
M+6UA:6P@9&\@9&5S=&EN873A<FEO+@!.XV\@9F]I('!O<W/M=F5L(&]B=&5R
M(&-O;7!L971A;65N=&4@;R!C873A;&]G;R!D92!E;F1E<F7G;W,N`$[C;R!F
M;VD@<&]S<^UV96P@;V)T97(@8V]M<&QE=&%M96YT92!A(&QI<W1A(&1E(&1I
M<W1R:6)U:>?C;RX`3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!C;VUP;&5T86UE
M;G1E(&$@;&ES=&$@9&4@;&ES=&%S(&1E(&1I<W1R:6)U:>?C;RX`3N-O(&9O
M:2!P;W-S[79E;"!C87)R96=A<B!A(&5S=')A=.EG:6$@)R5S)RX`3N-O(&9O
M:2!P;W-S[79E;"!C<FEA<B!O(&1I<F5T\W)I;R`G)7,G+@!.XV\@9F]I('!O
M<W/M=F5L(&]B=&5R(&$@8VAA=F4@</IB;&EC82!A('!A<G1I<B!D;R!S97)V
M:61O<B!D92!C:&%V97,N`$[C;R!F;VD@<&]S<^UV96P@86)R:7(@)R5S)R!P
M87)A(&=R879AY^-O+@!.XV\@9F]I('!O<W/M=F5L(&%B<FER("5S+@!.XV\@
M9F]I('!O<W/M=F5L(&%B<FER(&\@;?-D=6QO("=-86EN=&5N86YC95]487-K
M)R`E<P!.XV\@9F]I('!O<W/M=F5L(&%B<FER(&\@9&ER973S<FEO("<E<R<N
M`$[C;R!F;VD@<&]S<^UV96P@<&5S<75I<V%R(&YO('-E<G9I9&]R($Q$05`N
M`$[C;R!F;VD@<&]S<^UV96P@;&5R("5S+@!.XV\@9F]I('!O<W/M=F5L(&=E
M<F%R('5M82!N;W9A('-E;FAA('!A<F$@;R!U<W7A<FEO('-O;&EC:71A9&\N
M($%L9W5N<R!O=2!T;V1O<R!O<R!D971A;&AE<R!NXV\@97-TXV\@8V]R<F5T
M;W,N(%1E;G1E(&YO=F%M96YT92!O=2!E;G1R92!E;2!C;VYT871O(&-O;2!O
M(&%D;6EN:7-T<F%D;W(@<V4@=F]CZB!N96-E<W-I=&$@9&4@;6%I<R!A:G5D
M82X`3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!A($%#3`!.XV\@9F]I('!O<W/M
M=F5L(&]B=&5R(&\@8V%TX6QO9V\@9&4@96YD97)EYV]S+B`E<P!.XV\@9F]I
M('!O<W/M=F5L(&]B=&5R(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O+B`E<P!.
MXV\@9F]I('!O<W/M=F5L(&]B=&5R(&%S(&QI<W1A<R!D92!D:7-T<FEB=6GG
MXV\N("5S`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@87,@8V%P86-I9&%D97,@
M9&\@<V5R=FED;W(`3N-O(&9O:2!P;W-S[79E;"!R979E<G1E<B!A(&-O;F9I
M9W5R8>?C;RX`3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(&\@9&ER973S<FEO
M("<E<R<N`$[C;R!F;VD@<&]S<^UV96P@<V%L=F%R(&$@8V]N9FEG=7)AY^-O
M("5S+@!.XV\@9F]I('!O<W/M=F5L('-A;'9A<B!U;2!B86-K=7`@9&$@8V]N
M9FEG=7)AY^-O+@!.XV\@9F]I('!O<W/M=F5L('-A;'9A<B!U;2!B86-K=7`@
M9&$@8V]N9FEG=7)AY^-O.B`E<P!.XV\@9F]I('!O<W/M=F5L('-A;'9A<B!O
M('-C<FEP="!D92!A='5A;&EZ8>?C;R!D92!C;VYF:6=U<F'GXV\@96TZ("<E
M<R<N`$[C;R!C;VYS96=U:2!S86QV87(@;R!B86-K=7`@9&\@87)Q=6EV;R!D
M92!C;VYF:6=U<F'GXV\@)7,N`$[C;R!C;VYS96=U:2!S86QV87(@;R!A<G%U
M:79O(&1E(&-O;F9I9W5R8>?C;R`E<RX@5F]CZB!P;V1E(&]U('5T:6QI>F%R
M('5M82!D87,@;W#G]65S('!A<F$@<V%L=F%R(&\@8_-D:6=O(&1E('9O;'1A
M(&5M("5S(&]U(&-O<&EA<B!M86YU86QM96YT92!O(&/S9&EG;R!A8F%I>&\@
M<&%R82`E<RX`3N-O(&9O:2!P;W-S[79E;"!P97-Q=6ES87(@;F\@<V5R=FED
M;W(@3$1!4"X`3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(&\@;&EN:R`G)7,G
M+@!.XV\@9F]I('!O<W/M=F5L(&%T=6%L:7IA<B!O(&-O;G1A=&\N("5S`$[C
M;R!F;VD@<&]S<^UV96P@871U86QI>F%R(&$@;&ES=&$@9&4@9&ES=')I8G5I
MY^-O+B`E<P!.XV\@9F]I('!O<W/M=F5L(&=R879A<B!A(&-O;F9I9W5R8>?C
M;R!D92`G)7,G.B`E<P!.XV\@9F]I('!O<W/M=F5L(&5N8V]N=')A<B!A($)A
M<G)A($QA=&5R86P@9&\@36]Z:6QL82X@0V5R=&EF:7%U92US92!Q=64@96QA
M(&5S=.$@86)E<G1A+@!.XV\@9F]I('!O<W/M=F5L(&1A<B!A;R!U<W7A<FEO
M("5S(&]S('-E9W5I;G1E<R!D:7)E:71O<R!P87)A(&$@<&%S=&$@)R5S)SH@
M)7,`5&5X=&\@8V]N=&%D;P!08>US`$-U<G-O<P!#<FEA<@!#<FEA<B!U;2!L
M:6YK`$-R:6%R('5M82!N;W9A`$-R:6%R('-U8B!P87-T87,`4&5R;6ES<_5E
M<R!D;R!C<FEA9&]R`$[Z;65R;R!D;R!C87)TXV\@9&4@8W+I9&ET;P!#<F_A
M8VEA`$-U8F$`-"!&87-E<R!!='5A:7,`4V5S<_5E<R!!='5A:7,`2&]R82!!
M='5A;`!!(%523"!A='5A;"#I`%5S=>%R:6]S(&YO(&UO;65N=&\`0VQI;6$@
M071U86P`0V]N9&GGXV\@871U86PZ(`!%<W1I;&\@871U86P`0W5S=&]M:7IA
M('1A<F5F87,@82!S97)E;2!E>&5C=71A9&%S(&%O(&-O;F5C=&%R(&$@)7,N
M`$-O<G1A<@!#;W)T87(@<V5L9>?C;P!#:&EP<F4`0VER[6QI8V\@*$M/23@M
M4BD`0VER[6QI8V\@*%=I;F1O=W,M,3(U,2D`0VER[6QI8V\O56-R86YI86YO
M("A+3TDX+54I`%)E</IB;&EC82!48VAE8V$`1$0`1%-.("AV96IA(&AT='`Z
M+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N
M:6YT<F\M9'-N+G!H<"D`1&EA<FEA;65N=&4`3F%V96=A9&]R(&1E($1A=&%4
M<F5E`%!E<W%U:7-A(&YO($)A;F-O(&1E($1A9&]S`$1A=&$`1&%T82!D92!2
M96-E8FEM96YT;P!396QEY^-O(&1E(&1A=&$`1&EA`$5?>&-L=6ER($-O;'5N
M80!$97IE;6)R;P!.^FUE<F]S(&1E8VEM86ES`%)E8W5A<B!)9&5N=&'GXV\`
M4&%D<N-O`$-O<B!0861RXV\`261E;G1I9&%D92!0861RXV\`4VAE;&P@4&%D
M<N-O`$1E9FEN:>?U97,`17AC;'5I<@!%>&-L=6ER(&/I;'5L80!%>&-L=6ER
M($=R=7!O`$5X8VQU:7(@3&]G`$5X8VQU:7(@4&5R;6ES<^-O`$5X8VQU:7(@
M92!P=7)G87(@;65N<V%G96YS`$5X8VQU:7(@8^EL=6QA`$5X8VQU:7(@8V]L
M=6YA`$5X8VQU:7(@;6]D96QO('-U8G-T:71U=&\@97AI<W1E;G1E`$5X8VQU
M:7(@<&5R;6ES<_5E<R!P87)A("<E<R<`17AC;'5I<B!P97)M:7-S]65S('!A
M<F$@)R5S)R!E('%U86QQ=65R(&]U=')A('-U8BUP97)M:7-SXV\_`$5X8VQU
M:7(@;&EN:&$`17AC;'5I<B!I9&5N=&ED861E('-E;&5C:6]N861A`$5X8VQU
M:7(@82!C;VQU;F$@871U86P`17AC;'5I<B!A(&QI;FAA(&%T=6%L`%-C<FEP
M="!D92!A='5A;&EZ8>?C;R!D92!C;VYF:6=U<F'GXV\@)R5S)R!E>&-L=>UD
M;RX`2&]R82!D92!E;G1R96=A`$1I;F%M87)C80!$97-C<F5V82!O('!R;V)L
M96UA`$1E<V-R:>?C;P!$971A;&AE<R`H=&%M8NEM(&YO(')E9VES=')O(&1E
M(&%T:79I9&%D97,@9&\@2&]R9&4I.@!/<R!D971A;&AE<R!F;W)A;2!G<F%V
M861O<R!E;2!L;V<@<&%R82!O(&%D;6EN:7-T<F%D;W(N`$1E<V5N=F]L=FEM
M96YT;P!0;VYT;R!D92!/<G9A;&AO`%!O;G1O(&1E($]R=F%L:&\@<&%R82!A
M(/IL=&EM82!H;W)A.B``4&]N=&\@9&4@3W)V86QH;SH@`$1I<F7GXV\@9&$@
M97-Q=65R9&$@<&%R82!D:7)E:71A`$1I<F7GXV\@9&$@9&ER96ET82!P87)A
M(&5S<75E<F1A`$1I<F5T\W)I;P!%>&EB:7(@96T@9F]R;6%T;R`R-"!H;W)A
M<S\`3W#G]65S(&1E($5X:6)IY^-O`$5X:6)I<B!P<F5V:7/C;R!D971A;&AA
M9&$`17AI8FER('!R979I<^-O("A4048I`$5X:6)I<B!F;W)M871O`$YO=&EF
M:6-AY^-O(&1E($1I<W!O<VGGXV\`1&II8G5T:0!.XV\@97AC;'5I<@!.XV\@
M86-E<W-E(&1I<F5T86UE;G1E(&UA:6YT96YA;F-E+G!H<`!!('!R:6UE:7)A
M(&QI;FAA(&-O;G3I;2!O<R!N;VUE<R!D;W,@8V%M<&]S/R!392!S:6TL(&-L
M:7%U92!N97-T82!C86EX83H`1&]M:6YI8V%N80!297#Z8FQI8V$@1&]M:6YI
M8V%N80!.XV\@=&5M('5M82!C;VYT83\@0V%D87-T<F4M<V4N`$)A:7AA<@!"
M86EX87(@)7,`0F%I>&%R(&$@8V]N9FEG=7)AY^-O(&=E<F%D82!C;VUO('5M
M('-C<FEP="!02%`N`$QI<W1A(&1E('-E;&7GXV\`1')O9V%S`$-O<G)E:6\`
M0V]N96-T;W(@9&\@9V%T97=A>2!%36%I;"UP87)A+5--4RP@<&%R82!O<&5R
M861O<F%S('%U92!D:7-P;VYI8FEL:7IA;2!E<W1E('-E<G9IYV\N`$524@!%
M<75A9&]R`$5D:71A<@!%9&ET87(@0FQO8V\`161I=&%R($=R=7!O`$5D:71A
M<B!097)M:7-SXV\`161I=&%R(%!E<FUI<W/U97,`161I=&%R(%!E<FUI<W/U
M97,@<&%R82`E<P!%9&ET87(@;W#G]65S(&1E.@!%9&ET87(@<&5R;6ES<_5E
M<R!P87)A("5S`$5D:71A<B!P97)M:7-S]65S('!A<F$@)7,`161U8V'GXV\`
M16=I=&\`16P@4V%L=F%D;W(`16QE;65N=&\N+BX`16T`12UM86EL`$5N9&5R
M9>=O(&1E($4M36%I;`!/(&5N9&5R9>=O(&1E(&4M;6%I;"!D979E(&-O<G)E
M<W!O;F1E<BX`365N<V%G96T@8V]M(&-O;F9I<FUAY^-O`$=A=&5W87D@9&4@
M14UA:6PM<&%R82U335,`16UO=&EC;VYS`$UE;G-A9V5M(&5M(&)R86YC;RX`
M4F5S=6QT861O(&5M(&)R86YC;RX`5&5R;6]S(&1E('!E<W%U:7-A(&5M(&)R
M86YC;P!(86)I;&ET87(@:6YS97+GXV\@9&4@:6UA9V5N<R!A('!A<G1I<B!D
M82!'86QE<FEA(&1E($EM86=E;G,@;F\@=&5X=&\_`$AA8FEL:71A<B!M96YU
M(&1E(&-O;G1E>'1O(&-O;2!O(&)O=.-O(&1I<F5I=&\_`$9I;F%L(&1O(&%N
M;P!!=6UE;G1A<B!%9&ET;W(`1F]R;F7G82!U;6$@<&5R9W5N=&$@9&4@<V5G
M=7)A;N=A(&$@<75A;"!V;V/J('-E<N$@<&5R9W5N=&%D;R!S92!V;V/J(&YE
M8V5S<VET87(@9V5R87(@=6UA(&YO=F$@<V5N:&$L(&5X+B`G<75A;"!O(&YO
M;64@9&\@<V5U(&-A8VAO<G)O/R<Z`$9O<FYEYV$@82!54DP@9&$@:6UA9V5M
M(&%Q=6D`1&EG:71E(&%S(&QE=')A<R!A8F%I>&\Z`$=U:6[I($5Q=6%T;W)I
M86P`17)I='+I:6$`17)R;P!%<G)O(&%O(&-R:6%R(&)L;V-O.B`E<P!%<G)O
M(&%O(&5X8VQU:7(@XFYC;W)A(&1E('-I;F-R;VYI>F'GXV\Z("5S`$5R<F\@
M86\@97AC;'5I<B!L;V<@9&4@<VEN8W)O;FEZ8>?C;SH@)7,`17)R;R!A;R!O
M8G1E<B!C;VYT9?ID;SH@)7,`17)R;R!A;R!A='5A;&EZ87(@82!S96YH83H@
M)7,`17)R;R!N82!M96YS86=E;2X`17)R;R!G<F%V86YD;R`G)7,G+@!%<W3T
M;FEA`$5T:?-P:6$`R71N:6-O`$5U<F]P80!#861A(#$U(&UI;G5T;W,`0V%D
M82`R(&UI;G5T;W,`0V%D82`S,"!S96=U;F1O<P!#861A(#4@;6EN=71O<P!#
M861A($-O;F5XXV\`0V%D82!M96EA(&AO<F$`0V%D82!M:6YU=&\`5F%L;W)E
M<R!D92!E>&5M<&QO.@!%>&5C=71A<@!%>'!A;F1I<@!%>'!A;F1I<B!"87)R
M82!,871E<F%L`$5S<&5R861O("<I)P!%<W!E<F%D;R!U;6$@<&%L879R82!O
M=2!T97)M;R!D92!P97-Q=6ES82!E;G1R92!A<W!A<P!$871A(&1E($5X<&ER
M8>?C;P!%>'!O96YT90!#;W(@9&\@<')I;65I<F\@<&QA;F\`0V]N9FEG=7)A
MY^-O(&1E(&5N=FEO(&1E(&%R<75I=F]S($944`!&86QH82!O8G1E;F1O('!R
M969E<NIN8VEA<RX`1F%L:&$@86\@8V]N96-T87(@86\@<V5R=FED;W(@3$1!
M4"X`1F%L:&$@86\@8V]N96-T87(@86\@<V5R=FED;W(@4TU"+@!&86QH82!A
M;R!C;W!I87(@9&4@(B5S(BX`1F%L:&$@86\@8V]P:6%R('!A<F$@(B5S(BX`
M1F%L:&$@86\@8W)I87(@=6UA(&YO=F$@8V]N97CC;R!305-,+@!&86QH82!A
M;R!M;W9E<B!P87)A("(E<R(N`$9A;&AA(&%O(&]B=&5R.B`E<P!*=7-T;P!)
M;&AA<R!&86QK;&%N9"`H36%L=FEN87,I`$EL:&%S($9A<F]E`$5R<F\@1F%T
M86PZ`$9A>`!&87AE<P!&979E<F5I<F\`4V5N<V'GXV\@5.ER;6EC80!396YS
M8>?C;R!TZ7)M:6-A.B``4&%N8V%D87,@9&4@0VAU=F$`3F5V92!&<F%C80!-
M871R:7H@9&\@8V%M<&\`1FEG;&5T($-!4%1#2$$`1F]N=&4@1FEG;&5T`$9I
M:FD`87)Q=6EV;P!#;VYT86=E;2!D92!!<G%U:79O<SH@)7,@87)Q=6EV;P!#
M;VYT86=E;2!D92!!<G%U:79O<SH@)7,@87)Q=6EV;W,`1V5R96YC:6%D;W(@
M9&4@07)Q=6EV;W,`3F]M92!D;R!!<G%U:79O`%-E;&7GXV\@9&4@87)Q=6EV
M;P!%;G9I;R!D92!A<G%U:79O`$5N=FEO(&1E(&%R<75I=F]S(&[C;R#I('-U
M<&]R=&%D;RX`1FEL=')O<P!&:6YLXFYD:6$`4')I;65I<F$@365T861E`%!R
M:6UE:7)O(%%U87)T;P!487AA(&9I>&$`1VER87(`1&ES<&]S:>?C;P!.Z79O
M80!087-T82`E<R!NXV\@97AI<W1E`$-O<B!D82!&;VYT90!#;VUI9&$`4&%R
M82!N879E9V%D;W)E<R!Q=64@;N-O('-U<&]R=&%M(&EM86=E;G,`4')E=FES
MXV\@*%1!1BD`1&EA<R!0<F5V:7-T;W,@*$YO=&4@<75E(&$@<')E=FESXV\@
M<F5T;W)N861A(&5X:6)E(&%M8F]S(&1I82!E(&YO:71E.R!U;2!N^FUE<F\@
M;75I=&\@86QT;R!A<75I('!O9&4@<F5S=6QT87(@96T@=6T@8FQO8V\@97AT
M96YS;RD`17-Q=65C974@82!S96YH83\`1F]R;75LX7)I;W,`4V]R=&4`5&EP
M;R!D92!3;W)T90!3;W)T97,`4V]R=&5S(#(`1O-R=6YS`%)E9&ER96-I;VYA
M;65N=&]S`%-E>`!1=6%D<F]S`$9R86[G80!&<F%NYV$@365T<F]P;VQI=&%N
M80!'=6EA;F$@1G)A;F-E<V$`4&]L:6[I<VEA($9R86YC97-A`%1E<G)I=/-R
M:6]S($9R86YC97-E<R!D;R!3=6P`1&4`1&\H82D`1&5S8W)IY^-O($-O;7!L
M971A`$QU82!#:&5I80!.;VUE($-O;7!L971O`$=A8N-O`$=A;&5R:6$@9&4@
M;VYD92!O8G1E<B!A<R!I;6%G96YS`$=A;&5R:6$Z`$?B;6)I80!'97)A<B!A
M($-O;F9I9W5R8>?C;R!D92`E<P!#\V1I9V\@1V5R861O`$=E\W)G:6$`06QE
M;6%N:&$`1V%N80!':6)R86QT87(`4')I;65I<F\@3F]M90!/<.?U97,@1VQO
M8F%I<P!)<@!';V5D96P`1V]O9VQE($UA<&%S`%!E<W%U:7-A<B!N;R!';V]G
M;&4`17-C86QA(&1E($-I;GIA<P!'<NEC:6$`1W)E9V\@*$E33RTX.#4Y+3<I
M`$=R;V5LXFYD:6$`1W)A;F%D80!!9&UI;FES=')AY^-O(&1E($=R=7!O<P!.
M;VUE<R!D92!G<G5P;W,@;N-O(&1E=F5M(&5S=&%R(&5M(&)R86YC;P!'<F]U
M<%]L9&%P.B!);7!O<W/M=F5L(&%D:6-I;VYA<B!G<G5P;R`E<RX@27-T;R#I
M(&\@<75E(&\@<V5R=FED;W(@9&ES<V4Z(`!'<F]U<%]L9&%P.B!);7!O<W/M
M=F5L(&5X8VQU:7(@9W)U<&\@)7,`1W)O=7!?;&1A<#H@26UP;W-S[79E;"!A
M='5A;&EZ87(@9W)U<&\@)7,`1W)U<&]S`$=U861A;'5P90!'=6%M`$=U871E
M;&%M80!'=65R;G-E>0!097)M:7-S]65S(&1E($-O;G9I9&%D;P!,:79R;R!D
M92!6:7-I=&%S`$=U:6[I`$=U:6[I+4)I<W-A=0!'=6EA;F$`2%1-3`!(5$U,
M07)E82!S92!N96=A(&-O=F%R9&5M96YT92!A(&5X8VQU:7(@82#Z;'1I;6$@
M8^EL=6QA(&1A(&QI;FAA+@!(5$U,07)E82!S92!N96=A(&-O=F%R9&5M96YT
M92!A(&5X8VQU:7(@82#Z;'1I;6$@8V]L=6YA(&1A('1A8F5L82X`2%1-3$%R
M96$@<V4@;F5G82!C;W9A<F1E;65N=&4@82!E>&-L=6ER(&$@^FQT:6UA(&QI
M;FAA(&1A('1A8F5L82X`075T96YT:6-AY^-O($A45%`@;N-O(&5N8V]N=')A
M9&$N`$AA:71I`$%L9V]R:71M;R!(87-H`$YE8FQI;F$`0V%B9>=A;&AO`$-A
M8F7G86QH;P!);&AA($AE87)D(&4@26QH87,@36-$;VYA;&0`5&5M<&5S=&%D
M92!&;W)T90!(96)R974@*$E33RTX.#4Y+3@M22D`06QT=7)A`$%J=61A`$%J
M=61A(&1O(&5D:71O<@!!<W-I<W1E;G1E`$AE;6ES9NER:6\`07%U:2!E<W3A
M(&\@:6[M8VEO(&1O(&%R<75I=F\Z`$%L=&$`25]N[6-I;P!386YT82!3Z2`H
M0VED861E+45S=&%D;R!D;R!6871I8V%N;RD`26[M8VEO`$5N9&5R9>=O(%)E
M<VED96YC:6%L`$1I<F5T\W)I;R!097-S;V%L`$9O;F4@4F5S:61E;F-I86P`
M2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!$861O(%A-
M3"`E<R!I;G;A;&ED;R!E;F-O;G1R861O(&YA(&UE;G-A9V5M("5S`$AO<F1E
M+TMO;&%B.B!.96YH=6UA(&UE;G-A9V5M(&-O<G)E<W!O;F1E(&%O(&]B:F5T
M;R`E<P!(;W)D92]+;VQA8CH@3F5N:'5M(&]B:F5T;R!D;R!T:7!O("5S(&9O
M:2!E;F-O;G1R861O(&YA(&UE;G-A9V5M("5S`$AO<F1E+TMO;&%B.B!296UO
M=FED;R!C;VT@<W5C97-S;R`E<R`B)7,B`$AO<F1E+TMO;&%B.B!!(&5N9VEN
M92!D92!I;G1E9W)AY^-O(')E<75E<B!A(&5X=&5N<^-O(%!(4"`G9&]M>&UL
M)P!(;W)D92]+;VQA8CH@26UP;W-S[79E;"!C<FEA<B!U;6$@;F]V82#A<G9O
M<F4@6$U,('!A<F$@;R!O8FIE=&\@)7,`2&]R9&4O2V]L86(Z($EM<&]S<^UV
M96P@<F5M;W9E<B`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@26UP;W-S[79E
M;"!O8G1E<B!A(&ED96YT:69I8V'GXV\@34E-12!P87)A(&$@<&%R=&4@9&\@
M=&EP;R`E<P!(;W)D92]+;VQA8CH@26UP;W-S[79E;"!S:6YC<F]N:7IA<B`E
M<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@26UP;W-S[79E;"!S:6YC<F]N:7IA
M<B!C;VUP87)T:6QH86UE;G1O<SH@)7,`2&]R9&4O2V]L86(Z($-O;7!A<G1I
M;&AA;65N=&\@9&5S8V]N:&5C:61O("(E<R(`3&EN:&$@2&]R:7IO;G1A;`!-
M87)G96T@:&]R:7IO;G1A;`!(;W)I>F]N=&%L.@!#;VUO('9O8^H@8VAE9V]U
M(&%Q=6D_("A0;W(@9F%V;W(@8V]M=6YI<75E(2D`475A;G1A<R!C;VQU;F%S
M('9O8^H@9V]S=&%R:6$@9&4@;65S8VQA<C\`475A;G1O<R!C86UP;W,@*&-O
M;'5N87,I(&5X:7-T96T_`%%U86YT87,@;&EN:&%S('9O8^H@9V]S=&%R:6$@
M9&4@;65S8VQA<C\`56UI9&%D90!5;6ED861E.B``2'5M;W)I<W1A<P!(=6YG
M<NUA`$9A;&AA(&%O(&-R:6%R(&-A:7AA('!O<W1A;"!)34%0.B`E<P!&86QH
M82!A;R!E>&-L=6ER(&-A:7AA('!O<W1A;"!)34%0.B`E<P!&86QH82!A;R!C
M<FEA<B!Q=6]T82!D82!C86EX82!P;W-T86P@24U!4#H@)7,`16YD97)EYV\@
M25``16YD97)EYV\@25`@;N-O(&1I<W!O;NUV96PN`$5N9&5R9>=O($E0(&[C
M;R!E<W3A(&YO(&)L;V-O('!E<FUI=&ED;R!#2412+@!6:6]L8>?C;R!D;R!B
M;&]Q=65I;R!)4"X`25]N<VER82!,:6YH82!!;G1E<P!)<VSB;F1I80!3;VUE
M;G1E(,UC;VYE<P#-8V]N97,@<&%R82`E<P#-8V]N97,@92!T97AT;P!.;VUE
M(&1A(&ED96YT:61A9&4Z`%-E(&[C;R!F;W(@97AI8FED;R!C;W)R971A;65N
M=&4L("5S('!A<F$@86)R[2UL;R!E;2!U;6$@;F]V82!J86YE;&$N`%-E('9O
M8^H@;N-O(';J(&YE;FAU;2#M8V]N92!A;R!U=&EL:7IA<B!O($EN=&5R;F5T
M($5X<&QO<F5R+"!V;V/J('!O9&4@8VAE8V%R(&5S=&$@8V%I>&$@<&%R82!D
M97-A8FEL:71A<B!A('1R86YS<&%RZFYC:6$@4$Y'+@!392!V;V/J(';J(&5S
M=&$@;65N<V%G96T@;6%S(&[C;R!A(&EM86=E;2P@82!I;6%G96T@<75E('9O
M8^H@<75E<B!E;G9I87(@;N-O('!O9&4@<V5R(&5X:6)I9&$@<&5L;R!S974@
M;F%V96=A9&]R+@!0<NDM=FES=6%L:7IAY^-O(&1A($EM86=E;3H`55),(&1A
M($EM86=E;0!54DP@9&$@26UA9V5M.@!);6%G96T@9&$@9V%L97)I80!);6%G
M96T@9&$@9V%L97)I83H`16YV:6\@9&4@26UA9V5M`$EM86=E;G,`26UP;W)T
M87(L(%!A<W-O("5D`$-A;7!O(&EM<&]R=&%D;SH@)7,`0V%M<&]S(&EM<&]R
M=&%D;W,Z`$EN7W-E<FER($QI;FAA($%P\W,`0_-D:6=O(&1E(&'GXV\@9F]R
M;F5C:61O(&5S=.$@:6YC;W)R971O+@!5<W7A<FEO(&4O;W4@<V5N:&$@:6YC
M;W)R971O<RX`57-UX7)I;R!O=2!E;F1E<F7G;R!A;'1E<FYA=&EV;R!I;F-O
M<G)E=&]S+B!496YT92!N;W9A;65N=&4@;W4@96YT<F4@96T@8V]N=&%T;R!C
M;VT@;R!A9&UI;FES=')A9&]R('-E('9O8^H@;F5C97-S:71A(&1E(&UA:7,@
M86IU9&$N`$%U;65N=&%R($ED96YT8>?C;P#-;F1I80!5<W7A<FEO<R!I;F1I
M=FED=6%I<P!);F1O;NES:6$`26YF;W)M8>?C;P!);F9O<FUAY^-O`$[C;R!E
M>&ES=&5M(&]PY_5E<R!D:7-P;V[M=F5I<RX`26YS97)I<B!#7V]L=6YA($%P
M\W,`26YS97)I<B!);6%G96T`26YS97)I<B!486)E;&$`26YS97)I<B!,:6YK
M(&1A(%=E8@!);G-E<FER(%]#;VQU;F$@06YT97,`26YS97)I<B!U;6$@;F]V
M82!C;VQU;F$@87#S<R!A(&%T=6%L`$EN<V5R:7(@=6UA(&YO=F$@8V]L=6YA
M(&%N=&5S(&1A(&%T=6%L`$EN<V5R:7(@=6UA(&YO=F$@;&EN:&$@87#S<R!A
M(&%T=6%L`$EN<V5R:7(@=6UA(&YO=F$@;&EN:&$@86YT97,@9&$@871U86P`
M26YS97)I<B!U;2!P87+A9W)A9F\@87#S<R!O(&%T=6%L`$EN<V5R:7(@=6T@
M<&%RX6=R869O(&%N=&5S(&1O(&%T=6%L`$EN<V5R:7(@=6T@;6]D96QO(&%L
M=&5R;F%T:79O`$9O<FYEYV$@=6T@96YD97)EYV\@9&4@92UM86EL(&YO('%U
M86P@=F]CZB!P;V1E(')E8V5B97(@82!N;W9A('-E;FAA.@!);G-E<FER(&/I
M;'5L82!A</-S`$EN<V5R:7(@8^EL=6QA(&%N=&5S`$EN<V5R:7(@8V]L=6YA
M(&%P\W,`26YS97)I<B!C;VQU;F$@86YT97,`26YS97)I<B!M96YS86=E;G,`
M26YS97)I<B!P87+A9W)A9F\@87#S<P!);G-E<FER('!A<N%G<F%F;R!A;G1E
M<P!);G-E<FER(&QI;FAA(&%P\W,`26YS97)I<B!L:6YH82!A;G1E<P!&;W)N
M9>=A(&$@<F5S<&]S=&$@;V)R:6=A=/-R:6$@<&%R82!A('!E<F=U;G1A(&1E
M('-E9W5R86[G83H`26YS97)I<B]!;'1E<F%R($EM86=E;0!);G-E<FER+T%L
M=&5R87(@3&EN:P!#<NED:71O(&EN<W5F:6-I96YT92!P87)A(&5N=FEA<B!P
M87)A(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O+@!#<NED:71O(&EN<W5F:6-I
M96YT92X`3OIM97)O($EN=&5I<F\`3&ES=&$@9&4@26YT96ER;W,`0T15("A#
M86)EYV%L:&\@9&4@1&%D;W,@9&4@57-UX7)I;RD@:6YVX6QI9&\N`$1A9&]S
M(%I)4"!I;G;A;&ED;W,`07!L:6-AY^-O(&EN=N%L:61A+@!)9&5N=&EF:6-A
MY^-O(&1O(&)A=&-H(&EN=N%L:61A+@!$861O<R!E;G9I861O<R!SXV\@:6YV
MX6QI9&]S+@!%;F1E<F7G;R!D92!D97-T:6YO(.D@:6YVX6QI9&\N`$9O<FUA
M=&\@9&\@87)Q=6EV;R#I(&EN=N%L:61O`$[Z;65R;R!D92!L:6-E;N=A(&EN
M=N%L:61O+@!,;V-A;&EZ8>?C;R!F;W)N96-I9&$@Z2!I;G;A;&ED82X`5&EP
M;R!D82!M96YS86=E;2#I(&EN=N%L:61O+@!!<&E?:60@Z2!I;G;A;&ED;R!O
M=2!E<W3A(&9A;'1A;F1O+@!087+B;65T<F]S(&EN=N%L:61O<R!O=2!F86QT
M86YD;RX`4&5R;6ES<_5E<R!D;R!P86D@<^-O(&EN=N%L:61A<RX`4&5R;6ES
M<_5E<R!D;R!P86D@<^-O(&EN=N%L:61A<RX`0_-D:6=O(&1O('!R;V1U=&\@
MZ2!I;G;A;&ED;RX`4')O=&]C;VQO(&EN=N%L:61O+@!$97-T:6YA=.%R:6\@
M:6YVX6QI9&\Z("<E<R<`3V)J971O(&-O;7!A<G1I;&AA9&\@:6YVX6QI9&\`
M1F]N=&4@9&\@96YD97)EYV\@:6YVX6QI9&$N`$1A9&]S('5N:6-O9&4@:6YV
MX6QI9&]S+@!);G9E;G3A<FEO`$EN=F5R=&5R('-E;&7GXV\`27+C+"!297#Z
M8FQI8V$@27-LXFUI8V$@9&\`27)A<75E`$ER;&%N9&$`26QH82!D;R!(;VUE
M;0!496UP97-T861E<R!)<V]L861A<P!)<W)A96P`16UI<W-O<@!)=.%L:6-O
M`$ETX6QI80!*86UA:6-A`$IA;F5I<F\`2F%PXV\`2F%P;V[J<R`H25-/+3(P
M,C(M2E`I`$IE<G-E>0!*;W)DXFYI80!*=6QH;P!*=6YH;P!*=7-T:69I8V%R
M`$%L:6YH87(@86\@0V5N=')O`$IU<W1I9FEC87(`06QI;FAA<B#@($5S<75E
M<F1A`$%L:6YH87(@X"!$:7)E:71A`$-A>F%Q=6ES=.-O`$UA;G1E<B!O(&]R
M:6=I;F%L/P!1=>IN:6$`4V5R=FED;W(@:V5R8F5R;W,@<F5J96ET;W4@82!A
M=71E;G1I8V'GXV\N`$YO=F%T;W,@9&4@2V5R;F5L`$-R:6'GXV\@9&4@0VAA
M=F4`26UP<F5S<^-O($1I9VET86P@9&$@0VAA=F4`5&%M86YH;R!D82!#:&%V
M90!4:7!O(&1A($-H879E`%5S;R!D82!#:&%V90!#:&%V92!JX2!E>&ES=&4@
M;F\@<V5R=FED;W(@9&4@8VAA=F5S('#Z8FQI8V%S+@!#<FEA;N=A<P!+:7)I
M8F%T:0!#;W+I:6$L(%)E</IB;&EC82!0;W!U;&%R($1E;6]C<N%T:6-A(&1A
M`$-O<NEI82P@4F5P^F)L:6-A(&1A`$-O<F5A;F\@*$550RU+4BD`2W5W86ET
M`%%U:7)G=6ES=.-O`$QA7WEO=70`261I;VUA`$QA;R!297#Z8FQI8V$@1&5M
M;V-RX71I8V$@4&]P=6QA<@#:;'1I;6$@365T861E`$=E<F%R($YO=F$@4V5N
M:&$`VFQT:6UO(%%U87)T;P#:;'1I;6$@071U86QI>F'GXV\Z`-IL=&EM;R!L
M;V=I;CH@)7,`VFQT:6UO(&QO9VEN.B`E<R#@('!A<G1I<B!D92`E<P#:;'1I
M;6\@;&]G:6XZ($YU;F-A`$QE=/1N:6$`3&5I`$QA>6]U=`!$96EX82!V87II
M;R!S92!Q=6ES97(@<V5M(&)O<F1A`$SM8F%N;P!%<W%U97)D80!#86)EYV%L
M:&\@97-Q=65R9&\`5F%L;W)E<R!D82!E<W%U97)D80!,97-O=&\`06UO<@!,
M:6+I<FEA`$SM8FEA(,%R86)E($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!#
M:&EV:7-C;T9R86-O`$-H=79A($9R86-A`$-H=79A($9R86-A($UA='5T:6YA
M`$-H=79A($9R86-A(%9E<W!E<G1I;F$`3&5V97,@4&%N8V%D87,@9&4@0VAU
M=F$`0VAU=F%S($9R86-A<R!C;VT@5')O=O5E<P!.979E($9R86-A`$)R979E
M($YE=F%S8V$`4&_J;6%S`$QI;FL`3&EN:R!A<&]N=&$@<&%R83H`3&EG87(@
M;R!E;F1E<F7G;R!D92!E+6UA:6P@X"!PX6=I;F$@9&4@8V]M<&]S:>?C;R!A
M;R!E>&EB:7(`3&EN:W,`0V]O:VEE(&1O($QI;G5X`$QI<W1A<B`M('5S=>%R
M:6\@<&]D92!V97(@82!P87-T80!,:7-T87(@0F%N8V]S(&1E($1A9&]S`$QI
M<W1A<B!4\W!I8V]S(&1E($%J=61A`$QI<W1A<B!486)E;&%S`$QI<W0M07)C
M:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,
M:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$$@;&ES=&%G96T@9&4@
M<V5S<_5E<R!F86QH;W4Z("5S`$$@;&ES=&%G96T@9&4@=7-UX7)I;W,@9F%L
M:&]U.B`E<P!,:7-T86=E;2!D92!U<W7A<FEO<R!E<W3A(&1E<V%B:6QI=&%D
M82X`3&ET97)A='5R80!,:71UXFYI80!#87)R96=A;F1O+BXN`$AO<F$@;&]C
M86PZ(`!,;V-A;&EZ8>?C;R!E($AO<F$`4F5G:>-O`$-O;F5C=&%R`$QO9R!D
M82!S97-SXV\@9&4@<VEN8W)O;FEZ8>?C;R!A;G1E<FEO<@!$97-C;VYE8W1A
M<@!#;VYE8W1A<@!487)E9F%S(&1E($-O;F5XXV\`3R!L;V=I;B!F86QH;W4@
M<&]R<75E('-E=2!U<W7A<FEO(&]U('-E;FAA(&5S=&%V82!I;F-O<G)E=&$N
M`$9A;&AA(&1E($QO9VEN+@!497AT;R!L;VYG;P!!;6]R`$)A:7AA`$%L9F%B
M971O(&=R96=O(&5M(&UI;OIS8W5L;P!!;&9A8F5T;R!L871I;F\@96T@;6EN
M^G-C=6QO`$[Z;65R;W,@<F]M86YO<R!E;2!M:6[Z<V-U;&\`3'5X96UB=7)G
M;P!-30!-3U1$`$\@86YE>&\@35,M5$Y%1B!NXV\@8V]N=.EM(&1A9&]S+@!-
M4T<`36%C86\`36%C961O;FEA+"!!;G1I9V$@4F5P^F)L:6-A($EU9V]S;.%V
M:6$@9&$`36%D86=A<V-A<@!-X6=I8V\`0V]R<F5I;P!!9&UI;FES=')A9&]R
M(&1O($-O<G)E:6\`0W)I87(@;&EN7VLN+BX`36%L87=I`$UA;.%S:6$`36%L
M9&EV87,`36%L:0!-86QT80!'97)E;F-I82!A(&QI<W1A(&1E(&-A=&5G;W)I
M87,@92!A<R!C;W)E<R!A<W-O8VEA9&%S(&$@96QA<RX`36%P96%M96YT;R!-
M87`R-`!-87!E86UE;G1O($UA<%%U97-T`$UA<&5A;65N=&]S(&=R879A9&]S
M+@!-87+G;P!-87)G96T`36%R8V%R(&-O;2!F;&%G<R!,:61A+T[C;R!,:61A
M`$UA<F-A<B!C;VT@;W5T<F]S(&9L86=S("AE>"X@26UP;W)T86YT92]297-P
M;VYD:61A*0!);&AA<R!-87)S:&%L;`!-87)T:6YI8V$`0V%M<&]S(&-O<G)E
M<W!O;F1E;G1E<P!-875R:73B;FEA`$UA=7+M8VEO`$-RZ61I=&\@;>%X:6UO
M('!E<FUI=&ED;RX`3OIM97)O(&WA>&EM;R!D92!P87)T97,@9&$@;65N<V%G
M96T@97AC961E=2X`5&5M<&5R871U<F$@;>%X:6UA(&YA<R#Z;'1I;6%S(#(T
M(&AO<F%S.B``5&5M<&5R871U<F$@;>%X:6UA(&YA<R#Z;'1I;6%S(#8@:&]R
M87,Z(`!.^FUE<F\@3>%X:6UO(&1E($)L;V-O<R!D92!0;W)T86P`5&%M86YH
M;R!MX7AI;6\`36%I;P!-87EO='1E`$UE9&EC:6YA`$UE;6)R;W,`36]D;R!D
M;R!M96YU.@!-97-C;&%R(&/I;'5L87,`365N<V%G96T`365N<V%G96T@5F5R
M:69I8V%D82!C;VT@4W5C97-S;R!M87,@;R!C97)T:69I8V%D;R!D;R!A<W-I
M;F%N=&4@;N-O('#T9&4@<V5R('9E<FEF:6-A9&\N`$UE;G-A9V5M(&5X<&ER
M861A+@!4:7!O(&1E(&UE;G-A9V5M`$-L:6UA($UE=&%R`$)L;V-O($UE=&%R
M(&[C;R!D:7-P;V[M=F5L+@!";&]C;R!-971A<B!NXV\@9&ES<&]N[79E;"X@
M1&5T86QH97,@9F]R86T@9W)A=F%D;W,@96T@;&]G('!A<F$@;R!A9&UI;FES
M=')A9&]R+@!/($UE=&%R1$(@;N-O(&5S=.$@8V]N96-T861O+@!-Z71O9&\`
M3>ET;V1O("<E<R<@;N-O(&5S=.$@9&5F:6YI9&\`3>ET;V1O(&[C;R!D969I
M;FED;RX@3>ET;V1O(&-H86UA9&\Z("5S`$WI=')I8V$`3>EX:6-O`$UI8W)O
M;NES:6$L($5S=&%D;W,@1F5D97)A9&]S(&1A`$UE:6\`5&EP;R!-:6UE`%1E
M;7!E<F%T=7)A(&WM;FEM82!N87,@^FQT:6UA<R`R-"!H;W)A<SH@`%1E;7!E
M<F%T=7)A(&WM;FEM82!N87,@^FQT:6UA<R`V(&AO<F%S.B``261A9&4@;>UN
M:6UA(&1A('-E;FAA(&%I;F1A(&[C;R!E>'!I<F]U`$5S<&5L:&\`1&EV97)S
M;W,`4&%C;W1E(%!%05(@2%144%]297%U97-T(&9A;'1A;F1O+@!#;VYF:6=U
M<F'GXV\@9F%L=&%N9&\N(%9O8^H@=&5M('%U92!G97)A<B!E;&$@86=O<F$@
M<V4@=F]CZB!Q=65R('5T:6QI>F%R(&5S=&$@87!L:6-AY^-O+@!)1"!D82!M
M96YS86=E;2!F86QT86YD;RX`4&%C;W1E(&]B<FEG873S<FEO(%!%05(@36%I
M;"!F86QT86YD;RX`240@9&$@<V5S<^-O(&9A;'1A;F1O+@!396<`0V]R<F5I
M;R!-\W9E;`!-;V1E<F%R`$1A=&$@36]D:69I8V%D80!!;'1E<F%R(%523`!-
M\V1U;&\`36]L9&]V82P@4F5P^F)L:6-A(&1A`$WT;F%C;P!-;VYG\VQI80!-
MZG,@92!A;F\`365N<V%L;65N=&4`36]N='-E<G)A=`!&87-E<R!D82!,=6$`
M36%I<R!C86UP;W,@96YC;VYT<F%D;W,@;F$@;&EN:&$@)60@<75E(&\@;OIM
M97)O(&5S<&5R861O("5D+@!-87)R;V-O<P!'<F%N9&4@4&%R=&4@3&EM<&$`
M1W)A;F1E(%!A<G1E($YU8FQA9&\`1W)A;F1E(%!A<G1E($5N<V]L87)A9&\`
M36]V97(@06)A:7AO`$UO=F5R(.`@17-Q=65R9&$`36]V97(@X"!$:7)E:71A
M`$UO=F5R($%C:6UA`$%B86EX;P!!8VEM80!-;^=A;6)I<75E`$QI<W1A<R!D
M92!S96QEY^-O(&1E(&WZ;'1I<&QO<R!N[79E:7,`36%P87,@26YG;&5S97,@
M375L=&EM87``4V5L9>?C;R!M^FQT:7!L80!-:6YH82!#;VYT80!3=6%S($EN
M9F]R;6'G]65S`$UE=2!0;W)T86P`365U($QA>6]U="!D92!0;W)T86P`0FER
M;>)N:6$`3L-/+"!%=2!.PT\@0V]N8V]R9&\`3F]M90!.86WM8FEA`$YA=7)U
M`$YE<&%L`$AO;&%N9&$`06YT:6QH87,@2&]L86YD97-A<P!54DP@0F%S92!D
M;R!.971S8V%P90!54DP@9&4@4F5V;V=AY^-O(&1E($-!(&1O($YE='-C87!E
M`%523"!D92!P;VSM=&EC87,@9&4@0T$@9&\@3F5T<V-A<&4`55),(&1E(%)E
M;F]V8>?C;R!D;R!.971S8V%P90!54DP@9&4@4F5V;V=AY^-O(&1O($YE='-C
M87!E`$YO;64@9&\@<V5R=FED;W(@4U-,(&1O($YE='-C87!E`$-O;65N=.%R
M:6\@9&\@8V5R=&EF:6-A9&\@9&\@3F5T<V-A<&4`5&EP;R!D92!C97)T:69I
M8V%D;R!D;R!.971S8V%P90!2961E`$YU;F-A`$YO=F$@0V%L963T;FEA`$YO
M=F$@0V%T96=O<FEA`$YO=F$@365N<V%G96T@<&%R82`E<P!,=6$@3F]V80!.
M;W9O(%5S=>%R:6\@*&]P8VEO;F%L*0!.;W9A(%IE;.)N9&EA`$YO=F$@<V5N
M:&$`3F]V82!S96YH82!E>'!I<F%RX2!E;2`E>"X`07,@;F]V87,@<V5N:&%S
M(&[C;R!SXV\@:6=U86ES+@!.;W9A(&IA;F5L82`H7V)L86YK*0!.;W3M8VEA
M<P!'<G5P;W,@9&4@3F]T[6-I87,`4'+S>&EM80!0<O-X:6UA<R`T($9A<V5S
M`%!R\WAI;6%S(&]PY_5E<P!0<O-X:6UA/@!.:6-A<N%G=6$`3FEG97(`3FEG
MZ7)I80!.;VET90!.:75E`$[C;P!.96YH=6T@9&%D;R!D92!C;VYF:6=U<F'G
MXV\@9&ES<&]N[79E;"!P87)A(&5X:6)I<B!A<R!D:69E<F5NYV%S+@!.96YH
M=6UA(&5S=')A=.EG:6$@9&ES<&]N[79E;"!P87)A(&-R:6%R(&EM86=E;G,@
M25-/+@!.96YH=6T@;6]D96QO(&1E(&)A=&-H+@!.96YH=6T@8FQO8V\@97AI
M<W1E(&YA('!O<VGGXV\@<V]L:6-I=&%D80!.96YH=6T@;F]M92!D92!A9V5N
M9&$@9F]R;F5C:61O('!A<F$@82!A=71E;G1I8V'GXV\@34-!3"X`3F5N:'5M
M82!A;'1E<F'GXV\N`$YE;FAU;2!S=6)O<F1I;F%D;R!P;V1E('-E<B!A9&EC
M:6]N861O(&$@97-T82!P97)M:7-SXV\N`$YE;FAU;6$@:6YF;W)M8>?C;R!D
M92!C;VYF:6=U<F'GXV\@97-P96-I9FEC861A('!A<F$@)7,N`$YE;FAU;6$@
M:6YF;W)M8>?C;R!D92!C;VYF:6=U<F'GXV\@97-P96-I9FEC861A('!A<F$@
M1E10(%9&4RX`3F5N:'5M82!I;F9O<FUAY^-O(&1E(&-O;F9I9W5R8>?C;R!E
M<W!E8VEF:6-A9&$@<&%R82!344P@5D93+@!.96YH=6UA(&EN9F]R;6'GXV\@
M9&4@8V]N9FEG=7)AY^-O(&5S<&5C:69I8V%D82!P87)A(%-13"U&:6QE(%9&
M4RX`3F5N:'5M(&-RZ61I=&\@<F5S=&%N=&4N`$YE;FAU;2!D97-T:6YO(&9O
M<FYE8VED;RX`3F5N:'5M(&%R<75I=F\@96YV:6%D;P!.96YH=6T@[6-O;F4@
M96YC;VYT<F%D;RX`3F5N:'5M82!L;V-A;&EZ8>?C;R!C;VYF:6=U<F%D82X`
M3F5N:'5M82!L;V-A;&EZ8>?C;R!C;VYF:6=U<F%D82X`3F5N:'5M82!M96YS
M86=E;2!F;W)N96-I9&$N`$YE;FAU;2!N;VUE(&5S<&5C:69I8V%D;RX`3F5N
M:'5M(&[Z;65R;R!E<W!E8VEF:6-A9&\N`%-E;2!S;W)T97,@;V9E;G-I=F%S
M`$YE;FAU;6$@<V5N:&$@9F]R;F5C:61A('!A<F$@82!A=71E;G1I8V'GXV\@
M2%144"X`3F5N:'5M82!S96YH82!F;W)N96-I9&$@<&%R82!A(&%U=&5N=&EC
M8>?C;R!)34%0+@!.96YH=6UA('-E;FAA(&9O<FYE8VED82!P87)A(&$@875T
M96YT:6-AY^-O($ME<F)E<F]S+@!.96YH=6UA('-E;FAA(&9O<FYE8VED82!P
M87)A(&$@875T96YT:6-AY^-O($QO9VEN+@!.96YH=6UA('-E;FAA(&9O<FYE
M8VED82!P87)A(&$@875T96YT:6-AY^-O(%!!4U-71"X`3F5N:'5M82!S96YH
M82!F;W)N96-I9&$@<&%R82!A(&%U=&5N=&EC8>?C;R!334(N`$YE;FAU;2!P
M871H('!A<F$@;R!B:6[A<FEO(&1O($]P96Y34TP@9F]I(&9O<FYE8VED;RX@
M3R!B:6[A<FEO(&1O($]P96Y34TP@Z2!N96-E<W/A<FEO('!A<F$@;6%N:7!U
M;&%R(&]S(&1A9&]S(%!+0U,@,3(N`$YE;FAU;2!C861A<W1R;R!P96YD96YT
M92X`475O=&$@;N-O(&-O;F9I9W5R861A+@!396T@;&EN:&%S`$YE;FAU;2!S
M97!A<F%D;W(@9F]I(&5S<&5C:69I8V%D;RX`4V5M(&QA9&]S`$%R<75I=F\@
M:6YE>&ES=&5N=&4`3F5N:'5M(&1I<F5T\W)I;R!T96UP;W+A<FEO(&1I<W!O
M;NUV96P@<&%R82!O(&-A8VAE+@!.96YH=6T@=7-UX7)I;R!E+V]U('-E;FAA
M(&9O<FYE8VED;W,N`$YE;FAU;2!D861O(%A-3"!VX6QI9&\@<F5T;W)N861O
M`%-E;2!V86QO<F5S`$YE;FAU;2!V97)SXV\@96YC;VYT<F%D82!N82!C;VYF
M:6=U<F'GXV\@;W)I9VEN86PN($=E<F4@;F]V86UE;G1E(&$@8V]N9FEG=7)A
MY^-O+@!.96YH=6UA('9E<G/C;R!E;F-O;G1R861A(&YA('-U82!C;VYF:6=U
M<F'GXV\N($=E<F4@;F]V86UE;G1E(&$@8V]N9FEG=7)AY^-O+@!.96YH=6UA
M`$YE;FAU;6$@*'5S;R!I;7!L[6-I=&\I`$[S<F1I8V\@*$E33RTX.#4Y+3$P
M*0!);&AA($YO<F9O;&L`2&5M:7-FZ7)I;R!.;W)T90!);&AA<R!-87)I86YA
M(&1O($YO<G1E`$YO<G5E9V$`3N-O($%P\W,`3N-O($%N=&5S`$[C;R#I('5M
M(&1I<F5T\W)I;P!.XV\@26UP;&5M96YT861O+@!.XV\@8V]N9FEG=7)A9&\`
M3N-O('-U<&]R=&%D;RX`06YO=&'G]65S`$YA9&$@<&%R82!E>&EB:7(L('9O
M;'1E+@!.;W9E;6)R;P!.^FUE<F\`3OIM97)O(&1E(&-A<F%C=&5R97,`3OIM
M97)O(&1E(&-O;'5N87,`3OIM97)O(&1E(&QI;FAA<P!.^FUE<F\@;N-O(&5S
M<&5C:69I8V%D;R!P87)A(&%T=6%L:7IAY^-O(&YA(&QI<W1A(&1E(&1I<W1R
M:6)U:>?C;RX`3TL`3V)J971O`$-R:6%D;W(@9&\@3V)J971O`$]C=&%L`$]U
M='5B<F\`1FEL=')O(&]F96YS:79O`$5S8W)I=/-R:6\`4V5N:&%S(&%N=&EG
M82!E(&YO=F$@9&5V96T@<V5R(&1I9F5R96YT97,N`%-E;FAA(&%N=&EG80!3
M96YH82!A;G1I9V$@;N-O(&5S=.$@8V]R<F5T82X`3VWC`%-O;65N=&4@<V5R
M=FED;W)E<R!)34%0('-U<&]R=&%M('!A<W1A<R!C;VUP87)T:6QH861A<RX`
M4V]M96YT92!S;W)T97,@;V9E;G-I=F%S`%-O;65N=&4@=6T@96YD97)EYV\@
M9&4@92UM86EL('!E<FUI=&ED;RX`4V]M96YT92!O('!R;W!R:65TX7)I;R!O
M=2!O(&%D;6EN:7-T<F%D;W(@9&\@<VES=&5M82!P;V1E;2!A;'1E<F%R(&%S
M('!E<FUI<W/U97,@9&4@<')O<')I961A9&4@;W4@<')O<')I973A<FEO(&1E
M('5M(&-O;7!A<G1I;&AA;65N=&\`06)R:7(@96T@=6UA(&YO=F$@:F%N96QA
M`$5R<F\@9&\@3W!E;E-33#H@3N-O('!U9&4@97AT<F%I<B!D861O<R!D82!P
M87)T92!A<W-I;F%D82!3+TU)344N`$%B<F4@97-T92!L:6YK(&5M('5M82!N
M;W9A(&IA;F5L80!3:7-T96UA($]P97)A8VEO;F%L`$]PY_5E<P!/<.?U97,@
M9&4@)7,`3&ES=&$@3W)D96YA9&$`3W)G86YI>F'GXV\`56YI9&%D92!/<F=A
M;FEZ86-I;VYA;`!/<F=A;FEZ86YD;P!-;V1E;&\@;W)I9VEN86P@9&4@87!L
M:6-AY^-O`$UO9&5L;R!O<FEG:6YA;"!E;2`E<SH`3W5T<F\`3W5T<F%S($EN
M9F]R;6'G]65S`%!E<FUI<W/U97,@9&\@4')O<')I973A<FEO`$%U=&5N=&EC
M8>?C;R!004T@;N-O(&5S=.$@9&ES<&]N[79E;"X`0V]N96-T;W(@4$5!4CHZ
M36%I;`!!<W-I;F%T=7)A($1I9VET86P@4$=0`$1A9&]S($-R:7!T;V=R869A
M9&]S(&-O;2!01U``0VAA=F4@4/IB;&EC82!01U``1&%D;W,@07-S:6YA9&]S
M+T-R:7!T;V=R869A9&]S(&-O;2!01U``0_-D:6=O(%!(4`!,:6YH82!D92!#
M;VUA;F1O(%!(4`!#:'5V82!&<F%C82!697-P97)T:6YA`$-H=79A(%9E<W!E
M<G1I;F$`0VAU=F%S(%9E<W!E<G1I;F%S`$YE=F4@5F5S<&5R=&EN80!.979A
M<V-A(%9E<W!E<G1I;F$`3F5V92!697-P97)T:6YA`%1R;W9O861A<R!697-P
M97)T:6YA<P!%<W3A(&9A;'1A;F1O(&$@97AT96YSXV\@4$]325@`3&EN:&$@
M9&4@0V]M86YD;R!07TA0`$UA<F=E;0!087%U:7-TXV\`4&%L874`4&%L97-T
M:6YO+"!497)R:73S<FEO($]C=7!A9&\`4&%N86WA`%#A<'5A($YO=F$@1W5I
M;ND`4&%R86=U86D`4&%R8VEA;&UE;G1E($YU8FQA9&\`4V5N:&$`4V5N:&$@
M86QT97)A9&$@8V]M('-U8V5S<V\N`%-E;FAA(&EN8V]R<F5T80!396YH82!O
M8G)I9V%T\W)I82!P87)A(&$@875T96YT:6-AY^-O(%)!1$E54RX`4V5N:&$@
M8V]M(&-O;F9I<FUAY^-O`%-E;FAA.@!396YH83H@`%-E;FAA<R!D979E;2!S
M97(@:6=U86ES+@!#;VQA<@!#;VQA<B!D82#A<F5A(&1E('1R86YS9F5RZFYC
M:6$`4&%T:`!#861A<W1R;W,@4&5N9&5N=&5S.@!097-S;V%S`%!O<F-E;G1A
M9V5M`$5X96-U=&%R($]P97)AY_5E<R!D92!-86YU=&5NY^-O`$5X96-U=&%R
M(&]P97)AY_5E<R!D92!M86YU=&5NY^-O(&%O(&-O;F5C=&%R/P!097)M:7-S
MXV\`4&5R;6ES<^-O("(E<R(@;N-O(&5X8VQU[61A+@!097)M:7-SXV\@3F5G
M861A`%!E<FUI<W/U97,`061M:6YI<W1R8>?C;R!D92!097)M:7-S]65S`$EN
M9F]R;6'G]65S(%!E<W-O86ES`%!E<G4`06YI;6%I<R!D92!%<W1I;6'GXV\`
M1FEL:7!I;F%S`%1E;&5F;VYE`$9O=&]S`%!I=&-A:7)N`%!I>&5L<P!#;&EC
M:.D`4&]R(&9A=F]R(&-L:7%U92!E;2!A;&=U;6$@8^EL=6QA`%!O<B!F879O
M<B!C;VYF:7)M92!Q=64@=F]CZB!Q=65R(')E;6]V97(@97-T92!E;&5M96YT
M;SH`4&]R(&9A=F]R(&-O;F9I<FUE('%U92!V;V/J('%U97(@<F5M;W9E<B!O
M(&QI;FL@9&5S=&4@96QE;65N=&\N`%!O<B!F879O<B!F;W)N9>=A('5M(&WJ
M<R!E('5M(&%N;RX`4&]R(&9A=F]R(&9O<FYEYV$@=6T@;F]M92!P87)A(&$@
M;F]V82!C871E9V]R:6$Z`%!O<B!F879O<B!F;W)N9>=A('5M(&5N9&5R9>=O
M($E0(';A;&ED;RX`4&]R(&9A=F]R(&9O<FYEYV$@=6UA(&1A=&$@=N%L:61A
M+"!V97)I9FEQ=64@;R!N^FUE<F\@9&4@9&EA<R!N;R!MZG,N`%!O<B!F879O
M<B!F;W)N9>=A('5M82!H;W)A(';A;&ED82X`4&]R(&9A=F]R(&9O<FYEYV$@
M=6T@<F5S=6UO(&1O('!R;V)L96UA+@!0;W(@9F%V;W(@9F]R;F7G82!S974@
M=7-UX7)I;R!E('-E;FAA`%!O<B!F879O<B!L96EA(&\@=&5X=&\@82!S96=U
M:7(N(%9O8^H@1$5612!C;VYC;W)D87(@8V]M(&]S('1E<FUO<R!D92!U<V\@
M9&\@<VES=&5M82X`4&]R(&9A=F]R(&1I9VET92!O(&YO;64@9&$@;F]V82!C
M871E9V]R:6$Z`%!O;/1N:6$`4&]L[71I8V$`16YQ=65T90!0;W)T=6=A;`!0
M;W-IY^-O(&1E<W1A(&EM86=E;0!0;W-IY^-O(&1E<W1A('1A8F5L80!%;G9I
M92!P87)A(&5S=&$@<&%S=&$@*&[C;R#I(&]B<FEG861O('!E;&\@24U!4"D`
M4')E8VEP:71AY^-O('!A<F$@82AS*2#Z;'1I;6$H<RD@)7,@:&]R82AS*3H@
M`%!R96-I<&ET8>?C;SQB<B`O/F-H86YC90!0<F5F<U]L9&%P.B!%>'1E;G/C
M;R!,1$%0(&]B<FEG873S<FEA(&[C;R!E;F-O;G1R861A+@!0<F5F<U]S97-S
M:6]N.B!%>'1E;G/C;R!D92!S97-SXV\@;V)R:6=A=/-R:6$@;N-O(&5N8V]N
M=')A9&$N`%!R97-SXV\`4')E<W/C;R!E;2!N[79E;"!D;R!M87(Z(`!0<F5S
M<^-O.B``4'+I+79I<W5A;&EZ8>?C;P!0<F5V97(@82!I;6%G96T@96T@=6UA
M(&YO=F$@:F%N96QA`$]PY_5E<R!A;G1E<FEO<F5S`$EM<')I;6ER(&1O8W5M
M96YT;P!#:&%V92!0<FEV861A`%!R;V)L96UA`$1E<V-R:>?C;R!D;R!0<F]B
M;&5M80!0<F]J971O<P!497AT;R!B<F5V90!#:&%V92!0^F)L:6-A`$%L9V]R
M:71M;R!D82!#:&%V92!0^F)L:6-A`$-H879E(%#Z8FQI8V$`4&%R(&1E(&-H
M879E<R!0^F)L:6-A+U!R:79A9&$@;N-O(&9O<F%M(&=E<F%D;W,@8V]M('-U
M8V5S<V\N`%!O<G1O(%)I8V\`46%T87(`0V]N<W5L=&%R`%%A=&%R`$-H879E
M(%#Z8FQI8V$@4E-!("@E9"!B:70I`$)O=/5E<R!D92!S96QEY^-O`$-H=79A
M`$-H=79A($UA='5T:6YA`$-H=79A(%9E<W!E<G1I;F$`4&%N8V%D87,@9&4@
M0VAU=F$`0VAU=F$@92!.979E`$-H=79A('!A<F$@3F5V90!3;W)T92!!;&5A
M=/-R:6$`4F5L8>?C;P!,97(`3&5R(&UE;G-A9V5N<P!%>&-L=6ER(')E86QM
M96YT92`E<S\@17-T82!O<&5R8>?C;R!NXV\@<&]D92!S97(@9&5S9F5I=&$N
M`%)E;6]V97(@<F5A;&UE;G1E(&]S(&1A9&]S(&1O('5S=>%R:6\@)7,_($5S
M=&$@;W!E<F'GXV\@;N-O('!O9&4@<V5R(&1E<V9E:71A+@!2969A>B!S=6$@
M^FQT:6UA(&'GXV\`071U86QI>F%R`$%T=6%L:7IA<B!-96YU(&1E($5L96UE
M;G1O<R!$:6[B;6EC;W,Z`$%T=6%L:7IA<B!%>&EB:>?C;R!D;R!0;W)T86PZ
M`%)E9V5X`$YA=F5G861O<B!D92!296QAY_5E<P!,97(`3V)S97)V8>?U97,`
M4V5R=FED;W)E<R!296UO=&]S`%523"!296UO=&$@*&AT='`Z+R]W=W<N97AA
M;7!L92YC;VTO:&]R9&4I.@!296UO=F5R`%)E;6]V97(@0FQO8V\`4F5M;W9E
M<B!C;VQU;F$`4F5M;W9E<B!F;W)M871AY^-O`%)E;6]V97(@<&%R`%)E;6]V
M97(@<V-R:7!T(&=R879A9&\@;F\@9&ER973S<FEO('1E;7!O<N%R:6\@9&\@
M<V5R=FED;W(N`%)E;6]V97(@;P!296UO=F5R(&5S=&4@;O,@9&\@9&]C=6UE
M;G1O`%)E;6]V97(@=7-UX7)I;P!296UO=F5R('5S=>%R:6\Z("5S`%-O;&EC
M:71AY^-O(&[C;R!P]&1E('-E<B!R97-P;VYD:61A+B!#\V1I9V\@9&4@97)R
M;R!R971O<FYA9&\Z(`!/('-E<G9IYV\@<F5Q=6ES:71A9&\@;N-O('!O9&4@
M<V5R(&5N8V]N=')A9&\N`"<E<R<@;V)R:6=A=/-R:6\@;N-O(&9O:2!E<W!E
M8VEF:6-A9&\@;F$@8V]N9FEG=7)AY^-O("5S+@`G)7,G(&]B<FEG873S<FEO
M(&[C;R!F;VD@97-P96-I9FEC861O(&YA(&-O;F9I9W5R8>?C;R!61E,N`"<E
M<R<@;V)R:6=A=/-R:6\@;N-O(&9O:2!E<W!E8VEF:6-A9&\@;F$@8V]N9FEG
M=7)AY^-O+@!#86UP;R!/8G)I9V%T\W)I;P!,:6UP87(`1V5R87(@3F]V82!3
M96YH80!'97)A<B!.;W9A(%-E;FAA`-IL=&EM;R!1=6%R=&\`4F5S=6QT861O
M<P!2971O<FYA<B#@($]PY_5E<P!$:6=I=&4@82!N;W9A('-E;FAA(&YO=F%M
M96YT90!2975N:>-O`%)E=F5R=&5R($-O;F9I9W5R8>?C;P!/<.?U97,@9&\@
M161I=&]R(%)I8V@@5&5X=`!#:&%R861A<P!$:7)E:71A`$-A8F7G86QH;R!D
M:7)E:71O`%9A;&]R97,@9&$@9&ER96ET80!0<F]P<FEE9&%D97,@9&$@7TQI
M;FAA+BXN`$9U;N?C;P!2;VWJ;FEA`$=I<F%R(#$X,"!G<F%U<P!':7)A<B!P
M87)A(&$@17-Q=65R9&$`1VER87(@<&%R82!A($1I<F5I=&$`4')O<')I961A
M9&5S(&1A($QI;FAA`%!R;W!R:65D861E<R!D82!L:6YH80!,:6YH87,Z`$QI
M;FAA<P!,:6YH87,@87!A<F5C97+C;R!E;G1R92!T;V1A<R!A<R!L:6YH87,@
M92!C;VQU;F%S`$QI;FAA<R!A<&%R96-E<N-O('-O;65N=&4@96YT<F4@8V]L
M=6YA<P!,:6YH87,@87!A<F5C97+C;R!S;VUE;G1E(&5N=')E(&QI;FAA<P!%
M>&5C=71A<@!&961E<F'GXV\@4G5S<V$`4G5A;F1A`$%S<VEN871U<F$@0W)I
M<'1O9W+A9FEC82!3+TU)344`365N<V%G96T@0W)I<'1O9W)A9F%D82!C;VT@
M4R]-24U%`$%U=&5N=&EC8>?C;R!305-,(&[C;R!E<W3A(&1I<W!O;NUV96PN
M`$-O<G)E:6\@4TU3`$QI;FAA(&1E(&-O;6%N9&\@4U%,`%-E;G1E;N=A(%-1
M3"!P87)A('!E<W%U:7-A<R!D92!V86QO<F5S`%-32`!354-%4U-/`$QI;FAA
M(&1E(&-O;6%N9&\@4U]13`!386(`4V%N=&$@2&5L96YA`%/C;R!+:71T<R!E
M($YE=FES`%-A;G1A($QU>FEA`%/C;R!0961R;R!E($UI<75E;&]N`%/C;R!6
M:6-E;G1E(&4@1W)A;F%D:6YA<P!-97-M;R!Q=6%D<F\@*%]S96QF*0!386UO
M80!386X@36%R:6YO`%/C;R!4;VWI(&4@4'+M;F-I<&4`4')O=F5D;W(@9&4@
M4V%TZ6QI=&4`07+A8FEA(%-A=61I=&$`4V%L=F%R`%-A;'9A<B`E<P!386QV
M87(@)7,`4V%L=F%R($]PY_5E<P!386QV87(@8V]N9FEG=7)AY^-O(&=E<F%D
M82!C;VUO('5M('-C<FEP="!02%`@<&%R82!O(&1I<F5T\W)I;R!T96UP;W+A
M<FEO(&1O('-E=2!S97)V:61O<BX`0V]N9FEG=7)AY^-O("5S('-A;'9A+@!3
M8W)I<'0@9&4@871U86QI>F'GXV\@9&4@8V]N9FEG=7)AY^-O('-A;'9O(&5M
M.B`G)7,G+@!496UP97-T861E<R!)<V]L861A<P!#:>IN8VEA`%!E<W%U:7-A
M<@!%;F=I;F5S(&1E(%!E<W%U:7-A(`!396QE8VEO;F4@;W,@07)Q=6EV;W,`
M4V5L96-I;VYE('5M82!D871A`%-E;&5C:6]N92!U;2!G<G5P;R!P87)A(&%D
M:6-I;VYA<@!396QE8VEO;F4@=6T@;F]V;R!M96UB<F\`4V5L96-I;VYE('5M
M('-E<G9I9&]R`%-E;&5C:6]N92!U;2!U<W7A<FEO('!A<F$@861I8VEO;F%R
M`%-E;&5C:6]N87(@=&]D;W,`4V5L96-I;VYE('1O9&]S(&]S(&-O;7!O;F5N
M=&5S(&1E(&1A=&$N`%-E;&5C:6]N92!U;2!O8FIE=&\`3N-O('-E;&5C:6]N
M87(@;F5N:'5M`%-E;&5C:6]N92!O<R!C87)A8W1E<F5S('%U92!V;V/J('!R
M96-I<V$@;F$@8V%I>&$@86)A:7AO+B!6;V/J('!O9&4@96YTXV\@8V]P:>$M
M;&]S(&4@8V]LX2UL;W,@;F$@X7)E82!D92!T97AT;RX`4V5L96-I;VYE('5M
M(&1E;&EM:71A9&]R(&1E(&1A=&$Z`%-E;&5C:6]N92!O(&9O<FUA=&\@9&4@
M9&%T83H`4V5L96-I;VYE(&$@:61E;G1I9&%D92!Q=64@=F]CZB!Q=65R(&%L
M=&5R87(Z`%-E;&5C:6]N92!U;2!D96QI;6ET861O<B!D92!H;W)A.@!396QE
M8VEO;F4@;R!F;W)M871O(&1E(&AO<F$Z`%-E;&5C:6]N92!D;VES(&-A;7!O
M<R!C;W)R97-P;VYD96YT97,N`%-E;&5C:6]N92!S974@97-Q=65M82!D92!C
M;W)E<RX`4V5L96-I;VYE('-E=2!I9&EO;6$@<')E9F5R:61O.@!%;G9I87(@
M4F5L873S<FEO(&1E(%!R;V)L96UA`$5N=FEA<B!335,`4V5N96=A;`!396YS
M;W(Z(`!3971E;6)R;P!397)V:6$@92!-;VYT96YE9W)O`$[Z;65R;R!D92!3
MZ7)I90!$861O<R!D;R!S97)V:61O<B!E<G)A9&]S(&]U(&[C;R!D:7-P;V[M
M=F5I<RX`061M:6YI<W1R861O<B!D92!397-SXV\`240@9&$@4V5S<^-O(&5X
M<&ER;W4N`%-E<W/U97,`06IU<W1A<@!#;VYF:6=U<F$@87,@;W#G]65S('!A
M<F$@<&5R;6ET:7(@=F]CZB!G97)A<B!U;6$@;F]V82!S96YH82!S92!V;V/J
M(&5S<75E8^HM;&$N`$-O;F9I9W5R82!O<R!S97)V:61O<F5S(')E;6]T;W,@
M<75E('9O8^H@<75E<B!A8V5S<V%R(.`@<&%R=&ER(&1O('!O<G1A;"X`0V]N
M9FEG=7)A('-E=2!I9&EO;6$@<')E9F5R:61O+"!F=7-O(&AO<N%R:6\@92!O
M<.?U97,@9&4@9&%T82X`0V]N9FEG=7)A('-U82!A<&QI8V'GXV\@:6YI8VEA
M;"P@97-Q=65M82!D92!C;W)E<RP@871U86QI>F'GXV\@9&4@<.%G:6YA<R!E
M(&]U=')A<R!O<.?U97,@9&4@97AI8FGGXV\N`$-O;F9I9W5R8>?C;P!38W)I
M<'1S(&1E(&%T=6%L:7IAY^-O(&1E(&-O;F9I9W5R8>?C;R!D:7-P;V[M=F5I
M<P!$:79E<G-A<R!L;V-A;&ED861E<R!P;W-S[79E:7,@8V]M(&\@<&%RXFUE
M=')O.B``4V5I8VAE;&5S`$-O;7!R87,`4F5S=6UO`%1E8VQA<R!D92!A=&%L
M:&\@9&5V97+C;R!S97(@9&5F:6YI9&%S('!A<F$@82!M86EO<FEA(&1O<R!L
M:6YK<S\`17AI8FER`$5X:6)I<B!A<R!D:69E<F5NYV%S(&5N=')E(&$@8V]N
M9FEG=7)AY^-O(&%T=6%L(&4@82!N;W9A(&=E<F%D82X`17AI8FER(&1A=&$@
M92!H;W)A(&1A(/IL=&EM82!C;VYE>.-O(&%O('-E(&-O;F5C=&%R/P!%>&EB
M:7(@82!O<.?C;R!D92!M86YT97(@;R!O<FEG:6YA;`!%>&EB:7(@<V5L971O
M<@!%>&EB:7(@8F%R<F$@9&4@;65N=2!C;VT@;W!E<F'G]65S(&1E('1A8F5L
M83\`17AI8FER(&\@365N=2`E<R#@(&5S<75E<F1A/P!%>&EB:7(@9&GA;&]G
M;R!D92!0<F]P<FEE9&%D97,@9&4@0^EL=6QA<R!D82!486)E;&$`17AI8FER
M(&1IX6QO9V\@9&4@4')O<')I961A9&5S(&1A(%1A8F5L80!%>&EB:7(@9&GA
M;&]G;R!D92!0<F]P<FEE9&%D97,@9&4@3&EN:&%S(&1A(%1A8F5L80!%>&EB
M:7(@9&GA;&]G;R!D92!P<F]P<FEE9&%D97,@9&4@:6UA9V5M`$5X:6)I<B!U
M<&QO860`0VAU=F%S`$-H=79A<R!M871I;F%I<P!#:'5V87,@5F5S<&5R=&EN
M87,`0VAU=F%S(&YA<R!R961O;F1E>F%S`%)E9'5Z:7(`4')I;65I<F%M96YT
M92!R961U>F$@;W4@=&ER92!D;R!C86UI;FAO(&\H<RD@8FQO8V\H<RD@861J
M86-E;G1E*',I`%-E<G)A($QE;V$`4F5G:7-T<F%R`$%S<VEN871U<F$`06QG
M;W)I=&UO(&1A($%S<VEN871U<F$`0VEN9V%P=7)A`%1A;6%N:&\`26=N;W)A
M<B!-86YU=&5NY^-O`$5S;&]VX7%U:6$`17-L;W9E;FEA`$YE=F4`3F5V87-C
M80!.979A<V-A<P!#:'5V87,@;6%T:6YA:7,`3F5V87-C87,@5F5S<&5R=&EN
M87,`4')O9G5N9&ED861E(&1A($YE=F4Z(`!%<75I=F%L96YT92!D92!N979E
M(&5M(.%G=6$Z(`!);&AA<R!386QO;>-O`%-O;>%L:6$`0V%NY_5E<R`F(%!O
M96UA<P!/<F1E;F%R('-E;&7GXV\`16YD97)EYV\@9&4@;W)I9V5M`,%F<FEC
M82!D;R!3=6P`4W5L($5U<F]P974@*$E33RTX.#4Y+3,I`%-U;"!D82!'96]R
M9VEA(&4@4W5L(&1A<R!);&AA<R!386YD=>UC:&4`2&5M:7-FZ7)I;R!3=6P`
M17-P8>=O(&5N=')E(&/I;'5L87,@861J86-E;G1E<P!%<W!AYV\@96YT<F4@
M;R!C;VYT9?ID;R!E(&)O<F1A(&1A(&/I;'5L80!%<W!AYV%D;W(`17-P8>=A
M;65N=&\`17-P8>=A;65N=&\@92!M87)G96T`17-P86YH80!3<&%M`$5N=')A
M9&$@9&4@0V%R86-T97)E<R!%<W!E8VEA:7,`1&EV:61I<B!CZ6QU;&$`1&EV
M:61I<B!C;VQU;F$`1&EV:61I<B!L:6YH80!%<W!O<G1E<P!3<FD@3&%N:V$`
M4&%D<N-O`%-T87(@5')E:P!!;F\@:6YI8VEA;`!%<W1A9&\@;W4@4')O=NUN
M8VEA`%-I='5AY^-O`$9O<FUA=&\@9&\@87)M87IE;F%M96YT;P!.;VUE(&1A
M(%)U80!4<F'G861O`$QI<W1A(&1E(&-A9&5I87,@9&4@8V%R86-T97)E<P!2
M971I<F%R(&$@<&%R=&4@9&\@9&]M[6YI;R!D;R!E;F1E<F7G;P!%<W1I;&\@
M6T-34UT`1&]M`%-U8F1I<F5T\W)I;R`G)7,G(&[C;R!E;F-O;G1R861O+@!!
M<W-U;G1O`$5N=FEA<@!%;G9I861A(&$@<V]L:6-I=&'GXV\@9&4@861I8VEO
M;F%R("(E<R(@86\@<VES=&5M82X@5F]CZB!NXV\@<&]D92!C;VYE8W1A<BUS
M92!A=.D@<75E('-U82!S;VQI8VET8>?C;R!S96IA(&%P<F]V861A+@!3=6)S
M8W)E=F5R`%-U8V5S<V\`)R5S)R!A9&EC:6]N861O(&-O;2!S=6-E<W-O(&%O
M('-I<W1E;6$N`$]S(&1A9&]S(&1O('5S=>%R:6\@)R5S)R!F;W)A;2!R96UO
M=FED;W,@9&\@<VES=&5M82!C;VT@<W5C97-S;RX`)R5S)R!E>&-L=>UD;R!C
M;VT@<W5C97-S;RX`17AC;'7M9&\@)R5S)R!D;R!S:7-T96UA(&-O;2!S=6-E
M<W-O+@!#;VYF:6=U<F'GXV\@<F5V97)T:61A(&-O;2!S=6-E<W-O+B!!='5A
M;&EZ92!P87)A('9E<B!A<R!A;'1E<F'G]65S+@!"86-K=7`@9&$@8V]N9FEG
M=7)AY^-O('-A;'9A(&-O;2!S=6-E<W-O+@!/(&)A8VMU<"!D;R!A<G%U:79O
M(&1E(&-O;F9I9W5R8>?C;R`E<R!F;VD@<V%L=F\@8V]M('-U8V5S<V\N`"<E
M<R<@871U86QI>F%D;R!C;VT@<W5C97-S;P`E<R!G<F%V861O(&-O;2!S=6-E
M<W-O`%-U9.-O`%)E<W5M;P!!;6%N:&5C97(`4/1R+61O+5-O;`!%;G-O;&%R
M861O`$%M86YH96-E<@!!;6%N:&5C97(O4/1R+61O+5-O;`!!;6%N:&5C97(Z
M(`!0]'(M9&\M4V]L`%#T<BUD;RU3;VPZ(`!3;V)R97-C<F5V97(`4W5P;W)T
M90!3=7)I;F%M90!3;V)R96YO;64`4W9A;&)A<F0@92!*86X@36%Y96X`4W5A
M>FELXFYD:6$`4W7I8VEA`%-U[>=A`$[C;R!E>&-L=6ER`%-Y;F--3`!%<G)O
M(&1E('-I;G1A>&4@;F]S('1E<FUO<R!D82!P97-Q=6ES80!297#Z8FQI8V$@
MP7)A8F4@9&$@4^UR:6$`5&5M<&5S=&%D90!496UP97-T861E<R!E(%9E;G1A
M;FEA`%1E;7!E<W1A9&5S`%1E;7!E<W1A9&5S($UA=&EN86ES`$%R<75I=F\@
M5%-6`%1A8F5L80!0<F]P<FEE9&%D97,@9&$@5&%B96QA`%1A8F5L80!0<F]P
M<FEE9&%D97,@9&$@=&%B96QA`%1A:7=A;@!486EW86XL(%!R;W;M;F-I82!D
M82!#:&EN80!486II<75I<W3C;P!486YZXFYI82P@4F5P^F)L:6-A(&1A`$%L
M=F\Z`%1A<F5F87,`3OIM97)O(&1E(%1E;&5F;VYE`%1E;7!E<F%T=7)A('!A
M<F$@82#Z;'1I;6$@:&]R83H@`%1E;7!E<F%T=7)A`%1E;7!E<F%T=7)A.B``
M5&5M<&5R871U<F$\8G(@+SXH)7-!;'1A)7,O)7-"86EX825S*2`F9&5G.R5S
M`$UO9&5L;R`G)7,G(&[C;R!E;F-O;G1R861O+@!!9&UI;FES=')AY^-O(&1E
M($UO9&5L;W,`5&5X=&\`4V]M96YT92!497AT;P!!;&EN:&%M96YT;R!D92!4
M97AT;P!";W)D82!S=7!E<FEO<B!D;R!497AT;P!1=6D`5&%I;&%N9.IS("A4
M25,M-C(P*0!486ELXFYD:6$`02!E>'1E;G/C;R!&5%`@;N-O(&5S=.$@9&ES
M<&]N[79E;"X`3R!H:7-T\W)I8V\@9&\@<VES=&5M82!E<W3A(&1E<V%B:6QI
M=&%D;RX`02!E;F=I;F4@9&4@:6YT96=R8>?C;R!(;W)D92]+;VQA8B!NXV\@
M<W5P;W)T82`B)7,B`$\@;&]G($E-4U`@;N-O('!O9&4@<V5R(&EN:6-I86QI
M>F%D;RX`02!C;&%S<V4@(DUA:6YT96YA;F-E(B!NXV\@9F]I(&-A<G)E9V%D
M82!C;VT@<W5C97-S;P!!(&IA;F5L82!D92!/<.?U97,@9F]I(&9E8VAA9&$N
M(%-A:6YD;RX`3R!A9&UI;FES=')A9&]R('!R96-I<V$@8V]N9FEG=7)A<B!U
M;2!C;VYE8W1O<B!P97)M86YE;G1E(&1E(%!E<FUI<W/U97,@<V4@=F]CZB!Q
M=65R('5T:6QI>F%R(%!E<FUI<W/U97,N`%-O;65N=&4@;R!L861O(&1E(&)A
M:7AO`$\@;OIM97)O($E$(&1O(&-O;G1A=&\@;N-O(&9O:2!E<W!E8VEF:6-A
M9&\L(&1E:7AA9&\@96T@8G)A;F-O(&]U(&[C;R!F;VD@96YC;VYT<F%D;R!N
M;R!B86YC;R!D92!D861O<RX`3R!C;VYT871O(&9O:2!A9&EC:6]N861O(&-O
M;2!S=6-E<W-O(&%O('-E=2!C873A;&]G;R!D92!E;F1E<F7G;W,N`%!A<F$@
M=F5R:69I8V%R(&$@;65N<V%G96T@87-S:6YA9&$@Z2!N96-E<W/A<FEO('5M
M(&)L;V-O('-E<&%R861O(&1A(&%S<VEN871U<F$@4$=0+@!/($E$(&1A(&QI
M<W1A(&1E(&1I<W1R:6)U:>?C;R!NXV\@9F]I(&5S<&5C:69I8V%D;RP@9&5I
M>&%D;R!E;2!B<F%N8V\@;W4@;N-O(&9O:2!E;F-O;G1R861O(&YO(&)A;F-O
M(&1E(&1A9&]S+@!!(&QI<W1A(&1E(&1I<W1R:6)U:>?C;R!NXV\@9F]I(&5S
M<&5C:69I8V%D82X`07,@9G5NY_5E<R!D92!C<FEP=&]G<F%F:6$@<F5Q=65R
M96T@=6UA(&-O;F5XXV\@=V5B('-E9W5R82X`3R!A<G%U:79O("5S(&1E=F5R
M:6$@8V]N=&5R('5M82!C;VYF:6=U<F'GXV\@9&4@)7,N`$\@87)Q=6EV;R`E
M<R!D979E<FEA(&-O;G1E<B!A;&=U;6%S(&-O;F9I9W5R8>?U97,@9&4@)7,N
M`$\@87)Q=6EV;R!NXV\@<&]D92!S97(@8V]P:6%D;R!P87)A(&5L92!M97-M
M;RX`3R!A<G%U:79O(&[C;R!C;VYTZ6T@9&%D;W,N`%-E9W5E;2!O<R!C86)E
MYV%L:&]S(&1E<W1A(&UE;G-A9V5M+VUE;G-A9V5M(')F8S@R,BX`R2!S86)I
M9&\@<75E(&\@;6]D;R!T96QA(&-H96EA(&-A=7-A('!R;V)L96UA<R!C;VT@
M;R!);G1E<FYE="!%>'!L;W)E<BP@96T@=FER='5D92!D92!B=6=S(&1O(&YA
M=F5G861O<B!Q=64@;O-S(&[C;R!E<W1A;6]S(&%P=&]S(&$@8V]N=&]R;F%R
M+B!6;V/J('!O9&4@;V)S97)V87(@97)R;W,@9&4@97AI8FGGXV\L(&9A;'1A
M(&1E(&9U;N?U97,@9&\@961I=&]R(&4O;W4@=')A=F%M96YT;W,@86QE873S
M<FEO<R!D;R!N879E9V%D;W(N(%-E('-E=2!S:7-T96UA(.D@5VEN9&]W<R`Y
M>"#I(&UU:71O('!R;W;A=F5L('%U92!V;V/J(')E8V5B82!U;2!E<G)O(&1E
M("=&86QH82!'97)A;"!D92!0<F]T9>?C;R<@92!P<F5C:7-A<N$@<F5I;FEC
M:6%R+B!<;EQN(%9O8^H@9F]I(&%V:7-A9&\N(%!O<B!F879O<B!P<F5S<VEO
M;F4@3TL@<V4@=F]CZB!A:6YD82!Q=65R('1E;G1A<B!U<V%R(&\@961I=&]R
M(&1E('1E;&$@8VAE:6$N`$$@:61E;G1I9&%D92`B)7,B(&9O:2!E>&-L=>UD
M82X`4V]M96YT92!O(&QA9&\@97-Q=65R9&\`02!L;V-A;&EZ8>?C;R!D;R!B
M:6[A<FEO(&1O($=N=5!'(&1E=F4@<V5R(&9O<FYE8VED82#@(&-L87-S92`B
M0W)Y<'1?<&=P(BX`02!M96YS86=E;2!E;G9I861A(&5M("5S('!A<F$@)7,@
M8V]M(&\@87-S=6YT;R`B)7,B(&9O:2!E>&EB:61A+@I)<W1O(&[C;R!G87)A
M;G1E('%U92!A(&UE;G-A9V5M(&9O:2!L:61A(&]U(&5N=&5N9&ED82X`3R!N
M;VUE('5T:6QI>F%D;R!A;R!V:6YC=6QA<B!A('#A9VEN82!D92!C;VUP;W-I
MY^-O`$\@;OIM97)O(&1E(&-A;7!O<R!D979E('-E<B!N=6WI<FEC;RX`3R!M
M\V1U;&\@;W!E;G-S;"#I(&]B<FEG873S<FEO('!A<F$@82!C;&%S<V4@(DAO
M<F1E7T-R>7!T7W-M:6UE(BX`02!P<F5F97+J;F-I82`B)7,B(&[C;R!P;V1E
M('-E<B!S86QV82!P;W)Q=64@<V5U<R!D861O<R!E>&-E9&5R86T@;R!T86UA
M;FAO(&WA>&EM;R!P97)M:71I9&\`3R!P<F]G<F%M82!U=&EL:7IA9&\@<&%R
M82!V:7-U86QI>F%R(&5S=&4@=&EP;R!D92!D861O("@E<RD@;N-O(&9O:2!E
M;F-O;G1R861O(&YO('-I<W1E;6$N`$\@8V%R86-T97)E('!A<F$@8VET8>?C
M;R!D92!S97(@87!E;F%S('5M+@!3;VUE;G1E(&]S(&QA9&]S(&1I<F5I=&\@
M92!E<W%U97)D;P!3;VUE;G1E(&\@;&%D;R!D:7)E:71O`$\@<V5P87)A9&]R
M(&1E=F4@<V5R('5M(/IN:6-O(&-A<F%C=&5R92X`3R!S97)V:61O<B`B)7,B
M(&9O:2!E>&-L=>UD;RX`3R!S97)V:61O<B`B)7,B(&9O:2!S86QV;RX`02!S
M;VQI8VET8>?C;R!D92!C861A<W1R;R!D92`E<R!F;VD@97AC;'7M9&$N`$$@
M;&EN:&$@97-P96-I9FEC861A("@E9"D@;N-O(&5X:7-T92X`3R!A<G%U:79O
M('1E;7!O<N%R:6\@(B5S(B!NXV\@97AI<W1E+@!/('1E>'1O('%U92!V;V/J
M(&1I9VET;W4@;N-O(&-O<G)E<W!O;F1E(&%O('1E>'1O(&YA('1E;&$N`%-O
M;65N=&4@;W,@;&%D;W,@9&4@8VEM82!E(&1E(&)A:7AO`%-O;65N=&4@;R!L
M861O(&1E(&-I;6$`3W,@9&%D;W,@96YV:6%D;W,@9F]R86T@<&5R9&ED;W,@
M9&5S9&4@;R!P87-S;R!A;G1E<FEO<BX`3R!A<G%U:79O(&5N=FEA9&\@;N-O
M('#T9&4@<V5R('-A;'9O+@!/(&)L;V-O(")W96%T:&5R+F-O;2(@;N-O(&5S
M=.$@9&ES<&]N[79E;"X`3R!D:7)E=/-R:6\@9&4@=&5M87,@)R5S)R!NXV\@
M9F]I(&5N8V]N=')A9&\N`$[C;R!E>&ES=&5M(&]PY_5E<R!D:7-P;V[M=F5I
M<RX`3N-O(&5X:7-T96T@<&%R=&5S('%U92!P;W-S86T@<V5R(&5X:6)I9&%S
M(&EN8V]R<&]R861A<RX`17AI<W1E;2!M=6ET;W,@8V%R86-T97)E<R!N97-T
M92!C86UP;RX@5F]CZB!P<F5E;F-H974@8V]M("5S(&-A<F%C=&5R97,[('9O
M8^H@9&5V92!P<F5E;F-H97(@8V]M("5S(&]U(&UE;F]S+@!(;W5V92!U;2!P
M<F]B;&5M82!A9&EC:6]N86YD;R`G)7,G(&%O('-I<W1E;6$Z("5S`$AO=79E
M('5M('!R;V)L96UA(&%O(&5X8VQU:7(@9&\@<VES=&5M82!O<R!D861O<R!D
M;R!U<W7A<FEO("<E<R<Z(`!(;W5V92!U;2!P<F]B;&5M82!A;R!E>&-L=6ER
M("<E<R<@9&\@<VES=&5M83H@`$AO=79E('5M('!R;V)L96UA(&%O(&%T=6%L
M:7IA<B`G)7,G.B`E<P!(;W5V92!U;2!P<F]B;&5M82!C;VT@;R!E;G9I;R!D
M;R!A<G%U:79O.B!.96YH=6T@)7,@9F]I(&5N=FEA9&\N`$AO=79E('5M('!R
M;V)L96UA(&-O;2!O(&5N=FEO(&1O(&%R<75I=F\N($\@)7,@97)A(&UA:6]R
M('%U92!O('1A;6%N:&\@;>%X:6UO('!E<FUI=&ED;R`H)60@8GET97,I+@!(
M;W5V92!U;2!P<F]B;&5M82!C;VT@;R!E;G9I;R!D;R!A<G%U:79O+B!/("5S
M(&9O:2!E;G9I861O('!A<F-I86QM96YT92X`2&]U=F4@=6T@97)R;R!A;R!E
M>&EB:7(@97-T82!P87)T92!D82!M96YS86=E;0!(;W5V92!U;2!E<G)O(&%O
M(&EM<&]R=&%R(&]S(&1A9&]S(&1O(&-O;G1A=&\N`$AO=79E('5M(&5R<F\@
M86\@:6UP;W)T87(@;W,@9&%D;W,@9&\@:4-A;&5N9&%R+@!(;W5V92!U;2!E
M<G)O(&YO(&9O<FUU;.%R:6\@9&4@8V]N9FEG=7)AY^-O+B!486QV97H@=F]C
MZB!D96EX;W4@=6T@8V%M<&\@;V)R:6=A=/-R:6\@96T@8G)A;F-O+@!(;W5V
M92!U;2!E<G)O(&%O(&5X96-U=&%R(&$@9G5NY^-O(&1E(&-A=.%L;V=O(&1E
M(&5N9&5R9>=O<R!E<W!E8VEF:6-A9&$N(%!O<B!F879O<B!T96YT92!N;W9A
M;65N=&4@;6%I<R!T87)D92X`2&]U=F4@=6T@97)R;R!A;R!A='5A;&EZ87(@
M;W,@9&5T86QH97,@9&\@8V]N=&%T;RX@4&]R(&9A=F]R('1E;G1E(&YO=F%M
M96YT92!M86ES('1A<F1E+@!(;W5V92!U;2!E<G)O(&%O(&%T=6%L:7IA<B!A
M(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@4&]R(&9A=F]R('1E;G1E(&YO=F%M
M96YT92!M86ES('1A<F1E+@!%<W1E('-E<G9I9&]R($E-05`@;N-O('-U<&]R
M=&$@<&%S=&%S(&-O;7!A<G1I;&AA9&%S+@!%<W1E(&[C;R!P87)E8V4@<V5R
M('5M(&%R<75I=F\@<F%R(';A;&ED;RX`17-T92!NXV\@<&%R96-E('-E<B!U
M;2!A<G%U:79O('II<"!VX6QI9&\N`$5S=&4@;N-O('!A<F5C92!S97(@=6T@
M;OIM97)O(&1E(&-A<G3C;R!VX6QI9&\N`$5S=&4@8V]N96-T;W(@<&5R;6ET
M92!E;G9I87(@;65N<V%G96YS(&%T<F%VZ7,@9&\@0VQI8VMA=&5L;"`H:'1T
M<#HO+V-L:6-K871E;&PN8V]M*2P@=71I;&EZ86YD;R!A($%022!(5%10`$5S
M=&4@8V]N96-T;W(@<&5R;6ET92!E;G9I87(@;65N<V%G96YS(&%T<F%VZ7,@
M9&\@9V%T97=A>2!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2P@
M=71I;&EZ86YD;R!O($%022!(5%10`$5S=&4@8V]N96-T;W(@<&5R;6ET92!E
M;G9I87(@;65N<V%G96YS(&%T<F%VZ7,@9&\@9V%T97=A>2!S;7,R96UA:6P@
M*&AT='`Z+R]S;7,R96UA:6PN8V]M*2P@=71I;&EZ86YD;R!O($%022!(5%10
M`$5S=&4@8V]N96-T;W(@<&5R;6ET92!E;G9I87(@=6UA(&UE;G-A9V5M('9I
M82!33510(&%T<F%VZ7,@9&\@5F]D869O;F4@271A;&EA;F\L('-O;65N=&4@
M<&%R82!N^FUE<F]S(%9O9&%F;VYE+B#)(&]B<FEG873S<FEO('!O<W-U:7(@
M=6UA(&-O;G1A(&YO(%9O9&%F;VYE($ET86QI86YO("AH='1P.B\O=W=W+C$Y
M,"YI="DN`$5S=&4@8V%M<&\@Z2!O8G)I9V%T\W)I;RX`17-T92!C86UP;R!P
M;V1E(&-O;G1E<B!A<&5N87,@;OIM97)O<R!I;G1E:7)O<RX`17-T92!C86UP
M;R!P;V1E(&-O;G1E<B!A<&5N87,@;OIM97)O<R!E(';M<F=U;&$N`$5S=&4@
M8V%M<&\@<&]D92!C;VYT97(@87!E;F%S('9A;&]R97,@;V-T86ES+@!%<W1E
M(&-A;7!O(&1E=F4@<V5R('5M82!L:7-T82!D92!N^FUE<F]S(&EN=&5I<F]S
M('-E<&%R861A('!O<B!V[7)G=6QA<R!O=2!E<W!AYV]S`$5S=&4@8V%M<&\@
M9&5V92!S97(@=6T@;OIM97)O(';A;&ED;RX`17-T92!C86UP;R!D979E(&-O
M;G1E<B!U;2!C\V1I9V\@9&4@8V]R(&5M(&9O<FUA=&\@4D="($AE>&$L('!O
M<B!E>&5M<&QO("<C,3(S-&%F)RX`17-T92!F;W)M=6SA<FEO(&KA(&9O:2!P
M<F]C97-S861O+@!)<W1O(.D@)7,N`$5S=&4@Z2!U;2!O8FIE=&\@2V]L86(@
M1W)O=7!W87)E+B!087)A('9I<W5A;&EZ87(@97-T92!O8FIE=&\@=F]CZB!P
M<F5C:7-A<N$@9&4@=6T@8VQI96YT92!D92!C;W)R96EO('%U92!E;G1E;F1A
M(&\@9F]R;6%T;R!+;VQA8B!'<F]U<'=A<F4N(%!A<F$@=6UA(&QI<W1A(&1E
M(&-L:65N=&5S(&1E(&-O<G)E:6\@8V]M(&5S=&%S(&9U;N?U97,@<&]R(&9A
M=F]R('9I<VET92`E<P!%<W1A(&UE;G-A9V5M(&9O:2!E<V-R:71A(&5M('5M
M(&-O;FIU;G1O(&1E(&-A<F%C=&5R97,@*"5S*2!Q=64@;N-O(.D@;R!M97-M
M;R!Q=64@;R!S974N`$5S=&4@;OIM97)O(&1E=F4@<V5R('!E;&\@;65N;W,@
M=6TN`$5S=&4@<V5R=FED;W(@;N-O('!O9&4@9&5S8V]M<')I;6ER(&%R<75I
M=F]S('II<"!E(&=Z:7`N`$5S=&4@<VES=&5M82!E<W3A(&%T=6%L;65N=&4@
M9&5S871I=F%D;RX`17-T92!V86QO<B!D979E('-E<B!U;2!N^FUE<F\N`$5S
M=&$@:F%N96QA(&1E=F4@<V5R(&-H86UA9&$@82!P87)T:7(@9&$@:F%N96QA
M(&1E($]PY_5E<P!286EO`$)I;&AE=&5S`$AO<F$`06-O;7!A;FAA;65N=&\@
M9&4@2&]RX7)I;P!&;W)M871O(&1E(&AO<F$`4V5L9>?C;R!D92!H;W)A`%1I
M;6]R($QE<W1E`%3M='5L;P!!<W-U;G1O("AD:6-A*3H`4&%R80!087)A('-E
M;&5C:6]N87(@;?IL=&EP;&]S(.UT96YS+"!S96=U<F4@82!T96-L82!#;VYT
M<F]L("A00RD@;W4@0V]M;6%N9"`H36%C*2!A;R!C;&EC87(N`$AO:F4`5')O
M8V%R('!A<F$@8_-D:6=O($A434P`5&]G;P!4;VME;&%U`$%M86YHXP!4;VYG
M80!4;W!O`%%U861R;R!D;R!4;W!O("A?=&]P*0!4<F%D=>?U97,`5')I;F1A
M9&4@92!4;V)A9V\`5F5R9&%D96ER;R!O=2!F86QS;P!497(`5'5N[7-I80!4
M=7)Q=6EA`%1U<F-O("A)4T\M.#@U.2TY*0!4=7)C;VUE;FES=.-O`$EL:&%S
M(%1U<FMS(&4@0V%I8V]S`%1U=F%L=0!0<F5E;F-H82!C;VT@<W5A(&5S8V]L
M:&$Z(`#-;F1I8V4@52Y6+CH@`%523`!54DP@9&\@<V5U(')E;&%T\W)I;R!D
M92!S:71U8>?C;R!D92!E;G1R96=A`%523#H`56=A;F1A`%5C<N)N:6$`26UP
M;W-S[79E;"!A8V5S<V%R(&1I<F5T\W)I;R!61E,N`$EM<&]S<^UV96P@861I
M8VEO;F%R(&EN9F]R;6'G]65S(&5X=')A<R!D92!U<W7A<FEO(&%O(')E9VES
M=')A<BX`26UP;W-S[79E;"!A;'1E<F%R('!E<FUI<W/C;R!D;R!A<G%U:79O
M(%9&4R`B)7,B+@!);7!O<W/M=F5L(&%L=&5R87(@<&5R;6ES<^-O(&1O(&%R
M<75I=F\@5D93("5S+R5S+@!);7!O<W/M=F5L(&%L=&5R87(@<&%R82`E<RX`
M26UP;W-S[79E;"!V97)I9FEC87(@;R!T86UA;FAO(&1O(&%R<75I=F\@9&4@
M(B5S(BX`26UP;W-S[79E;"!V97)I9FEC87(@;R!T86UA;FAO(&1O(&%R<75I
M=F\@9&4@(B5S+R5S(BX`26UP;W-S[79E;"!C;VYE8W1A<B!A;R!S97)V:61O
M<B!344PN`$EM<&]S<^UV96P@8V]N96-T87(@=71I;&EZ86YD;R!34TPN`$EM
M<&]S<^UV96P@8V]P:6%R(&%R<75I=F\@5D93+@!);7!O<W/M=F5L(&-R:6%R
M(&1I<F5T\W)I;R!61E,@(B5S(BX`26UP;W-S[79E;"!C<FEA<B!D:7)E=/-R
M:6\@5D93+@!);7!O<W/M=F5L(&-R:6%R(&%R<75I=F\@5D93+@!);7!O<W/M
M=F5L(')E;F]M96%R(&%R<75I=F\@5D93("(E<R(N`$EM<&]S<^UV96P@8W)I
M87(@87)Q=6EV;R!61E,@=F%Z:6\N`$EM<&]S<^UV96P@9&5S8V]M<')I;6ER
M(&1A9&]S+@!);7!O<W/M=F5L(&5X8VQU:7(@(B5S(BP@;R!D:7)E=/-R:6\@
M;N-O(&5S=.$@=F%Z:6\N`$EM<&]S<^UV96P@97AC;'5I<B`B)7,B.B`E<RX`
M26UP;W-S[79E;"!E>&-L=6ER("5S+"!O(&1I<F5T\W)I;R!NXV\@97-TX2!V
M87II;P!);7!O<W/M=F5L(&5X8VQU:7(@<F5C=7)S:79A;65N=&4@;R!D:7)E
M=/-R:6\@5D93+@!);7!O<W/M=F5L(&5X8VQU:7(@9&ER973S<FEO(%9&4RX`
M26UP;W-S[79E;"!E>&-L=6ER(&1I<F5T\W)I;R!61E,Z("5S+@!);7!O<W/M
M=F5L(&5X8VQU:7(@87)Q=6EV;R!61E,@(B5S(BX`26UP;W-S[79E;"!E>&-L
M=6ER(&%R<75I=F\@5D93+@!);7!O<W/M=F5L(&5X8VQU:7(@87)Q=6EV;R!6
M1E,@(B5S(BX`26UP;W-S[79E;"!E>&-L=6ER(%9&4R!R96-U<G-I=F%M96YT
M93H@)7,N`$EM<&]S<^UV96P@9&5T97)M:6YA<B!O(&1I<F5T\W)I;R!A='5A
M;"X`26UP;W-S[79E;"!E>'1R86ER(&1E=&%L:&5S(&1O(&-E<G1I9FEC861O
M`$EM<&]S<^UV96P@8V%R<F5G87(@82!D969I;FGGXV\@9&4@)7,N`$EM<&]S
M<^UV96P@;6]V97(@;R!A<G%U:79O(%9&4RX`26UP;W-S[79E;"!A8G)I<B!A
M<G%U:79O(%9&4R`B)7,B+@!);7!O<W/M=F5L(&%B<FER(&%R<75I=F\@5D93
M('!A<F$@9W)A=F'GXV\N`$EM<&]S<^UV96P@86)R:7(@87)Q=6EV;R!61E,N
M`$EM<&]S<^UV96P@86)R:7(@87)Q=6EV;R!C;VUP<FEM:61O+@!);7!O<W/M
M=F5L(&QE<B!A<G%U:79O(%9&4R`H9FEL97-I>F4H*2!F86QH;W4I+@!);7!O
M<W/M=F5L(&QE<B!A<G%U:79O(%9&4R`H9V5T1FEL95-I>F4H*2!F86QH;W4I
M+@!);7!O<W/M=F5L(&QE<B!O(&%R<75I=F\Z(`!);7!O<W/M=F5L(&QE<B!A
M(')A:7H@9&\@9&ER973S<FEO(%9&4RX`26UP;W-S[79E;"!R96YO;65A<B`E
M<R!P87)A("5S.B!A('!A<W1A(&1E(&1E<W1I;F\@:N$@97AI<W1E`$EM<&]S
M<^UV96P@<F5N;VUE87(@;R!D:7)E=/-R:6\@5D93+@!);7!O<W/M=F5L(')E
M;F]M96%R(&1I<F5T\W)I;R!61E,Z("5S+@!);7!O<W/M=F5L(')E;F]M96%R
M(&%R<75I=F\@5D93("(E<R(N`$EM<&]S<^UV96P@<F5N;VUE87(@87)Q=6EV
M;R!61E,@)7,O)7,N`$EM<&]S<^UV96P@<F5N;VUE87(@87)Q=6EV;R!61E,N
M`$EM<&]S<^UV96P@97AE8W5T87(@)VUK:7-O9G,G+@!);7!O<W/M=F5L('1R
M861U>FER(&5S=&4@9&]C=6UE;G1O(%=O<F0`26UP;W-S[79E;"!G<F%V87(@
M87)Q=6EV;R!61E,@(B5S(BX`26UP;W-S[79E;"!G<F%V87(@87)Q=6EV;R!6
M1E,@*&-O<'DH*2!F86QH;W4I+@!);7!O<W/M=F5L(&=R879A<B!D861O<R!D
M;R!A<G%U:79O(%9&4RX`26UP;W-S[79E;"!G<F%V87(@87)Q=6EV;R!61E,L
M('%U;W1A(&5X8V5D97+A+@!3=6)L:6YH861O`$1E<V9A>F5R($%L=&5R8>?U
M97,`1&5S9F%Z('-U82#Z;'1I;6$@8>?C;P!297-P;W-T82!I;F5S<&5R861A
M(&1O('-E<G9I9&]R(&1U<F%N=&4@82!C;VYE>.-O.B``4F5S<&]S=&$@:6YE
M<W!E<F%D82!D;R!S97)V:61O<B!P87)A.B``4V5M(&-A=&5G;W)I80!5;FEC
M;V1E("A55$8M."D`16UI<F%D;W,@P7)A8F5S(%5N:61O<P!296EN;R!5;FED
M;P!%<W1A9&]S(%5N:61O<P!);&AA<R!097)I9NER:6-A<R!-96YO<F5S(&1O
M<R!%<W1A9&]S(%5N:61O<P!5;FED861E<P!$97-C;VYH96-I9&\`87!I;7-G
M:60@9&5S8V]N:&5C:61O("A!4$D@365S<V%G92!)1"DN`&-L:6US9VED(&1E
M<V-O;FAE8VED;R`H0VQI96YT($UE<W-A9V4@240I+@!.96YH=6UA(&QO8V%L
M:7IAY^-O(&-O;F9I9W5R861A+@!5<W7A<FEO(&]U('-E;FAA(&1E<V-O;FAE
M8VED;W,N`$1E<W9I;F-U;&%R(&\@96QE;65N=&\@871U86P`4V5M($YO;64`
M4V-R:7!T<R!NXV\@<')I=FEL96=I861O<R!NXV\@<&]D96T@=71I;&EZ87(@
M0V]R=&%R+T-O<&EA<B]#;VQA<B!P;W(@<F%Z]65S(&1E('-E9W5R86[G82X@
M0VQI<75E(&5M($]+('!A<F$@=F5R(&$@;F]T82!TZ6-N:6-A(&5M(&UO>FEL
M;&$N;W)G(&$@<75A;"!E;G-I;F$@8V]M;R!P97)M:71I<B!S8W)I<'1S(&%C
M97-S87)E;2!A(.%R96$@9&4@=')A;G-F97+J;F-I82X`1&5S;6%R8V%R(&-O
M<@!%>'1E;G/C;R!.XV\@4W5P;W)T861A`$%T=6%L:7IA<@`E<R!A='5A;&EZ
M861O`$%T=6%L:7IA<B!U<W7A<FEO`"<E<R<@871U86QI>F%D;RX`4V-R:7!T
M(&1E(&%T=6%L:7IAY^-O(')E;6]V:61O+@!%;G9I87(`5&]D;W,@87)Q=6EV
M;W,@9&4@(&-O;F9I9W5R8>?U97,@9&%S(&%P;&EC8>?U97,@9F]R86T@96YV
M:6%D;W,@86\@<V5R=FED;W(N`$%L9F%B971O(&QA=&EN;R!E;2!M86GZ<V-U
M;&\`3OIM97)O<R!R;VUA;F]S(&5M(&UA:?IS8W5L;P!5<G5G=6%I`%5T:6QI
M>F%R($%T=6%L.B`E<P!5=&EL:7IA<B!34TP`571I;&EZ87(@<V4@;R!N;VUE
M+W-E;FAA(.D@9&EF97)E;G1E(&YO('-E<G9I9&]R($E-4U`N`%5S=>%R:6]S
M`%5S=>%R:6\@)7,@;N-O(&5S=.$@875T;W)I>F%D;R!P87)A("5S+@!!9&UI
M;FES=')AY^-O(&1E(%5S=>%R:6]S`$]PY_5E<R!D92!5<W7A<FEO<P!296=I
M<W1R;R!D92!5<W7A<FEO<P!296=I<W1R;R!D92!5<W7A<FEO<R!E<W3A(&1E
M<V%B:6QI=&%D;R!N97-T92!S:71E+@!#;VYT82!D92!U<W7A<FEO(&[C;R!E
M;F-O;G1R861A`%5S=>%R:6\`57-UX7)I;R`G)7,G(&KA(&5X:7-T92X`57-U
MX7)I;SH`57-UX7)I;SH@`%5S=>%R:6]S(&YO('-I<W1E;6$Z`%5Z8F5Q=6ES
M=.-O`$\@9&ER973S<FEO(%9&4R!NXV\@97AI<W1E+@!&Z7)I87,`3&]C86QI
M>F'G]65S(';A;&ED87,@96YC;VYT<F%D87,@:6YC;'5E;3H@`%9A;&ED861E
M`%9A;&]R(&5M(&UI;G5T;W,@82!P87)T:7(@9&4@86=O<F$N`$\@=F%L;W(@
M97-TX2!A8VEM82!D;R!T86UA;FAO(&WA>&EM;R!D92`E<RX`5F%L;W)E<P!6
M86QO<F5S('!A<F$@<V5L96-I;VYA<@!686YU871U`%9A<FGA=F5L`%9E;F5Z
M=65L80!&86QH82!N82!V97)I9FEC8>?C;R`M(&5S=&$@;65N<V%G96T@<&]D
M92!T97(@<VED;R!A9'5L=&5R861A+@!697)SXV\`0V]N=')O;&4@9&4@5F5R
M<^-O`$%L:6YH86UE;G1O('9E<G1I8V%L`$UA<F=E;2!V97)T:6-A;`!697)T
M:6-A;#H`375I=&\@06QT80!6:65T;N,`5FEE=&YA;6ET82`H5DE30TE)*0!6
M97(@)7,`5FES=6%L:7IA<B!U;6$@<.%G:6YA('=E8B!E>'1E<FYA`%9I<W5A
M;&EZ87(@8V]M;R`E<P!);&AA<R!6:7)G96YS+"!"<FETXFYI8V%S`$EL:&%S
M(%9I<F=E;G,L($4N52Y!+@!6:7-I8FEL:61A9&4`5FES:6)I;&ED861E.B``
M5F]D869O;F4@271A;&EA;F\@=FEA(%--5%``051%3L?#3P!!5$5.Q\-/(2$A
M(%)%34]602!/(%-#4DE05"!-04Y504Q-14Y412!$12`E<RX`5TE.('9I82!(
M5%10`%=A;&QI<R!E($9U='5N80!!=&5NY^-O`%%U80!0<F5V:7/C;R!D;R!4
M96UP;P!$861O<R!D;R!#;&EM82!F;W)N96-I9&\@<&]R`%=E871H97(N8V]M
M`%=E8@!3:71E(%=E8@!396UA;F%L;65N=&4`0F5M+79I;F1O`$)E;2UV:6YD
M;R!A;R`E<P!"96TM=FEN9&\L("5S`$]C:61E;G1A;"`H25-/+3@X-3DM,2D`
M3V-I9&5N=&%L("A)4T\M.#@U.2TQ-2D`4V%H87)A($]C:61E;G1A;`!1=64@
M87!L:6-AY^-O("5S(&1E=F5R:6$@97AI8FER(&%P\W,@82!C;VYE>.-O/P!1
M=6%L(&\@8V%R86-T97)E(&1E;&EM:71A9&]R/P!1=6%L(&\@8V%R86-T97)E
M(&1E(&-I=&'GXV\_`$UA<&%S($%U<W1R86QI86YO<R!7:&5R96ES`%%U86ES
M(&9A<V5S`%%U86ES('!L=6=I;G,@:&%B:6QI=&%R('!A<F$@;R!E9&ET;W(@
M4FEC:"!497AT+@!,87)G=7)A`$QA<F=U<F$@96T@=6YI9&%D97,@0U-3`$QA
M<F=U<F$@9&\@;65N=2`E<R!D;R!L861O(&5S<75E<F1O("AT97+A(&5F96ET
M;R!N82!P<O-X:6UA(&-O;F5XXV\I.@!,87)G=7)A(&1A('1A8F5L80!5;FED
M861E(&1E($QA<F=U<F$`3&%R9W5R83H`5VEK:0!696YT;P!696YT;W,@<&5L
M82!M86YHXP!696QO8VED861E(&1O('9E;G1O(&5M(&[S<P!696YT;SH`5F5N
M=&\Z(`!386)E9&]R:6$`3&ES=&$@9&4@<&5D:61O<P!4<F%B86QH;P!%;F1E
M<F7G;R!#;VUE<F-I86P`1F]N92!#;VUE<F-I86P`3OIM97)O(&EN8V]R<F5T
M;R!D92!C86UP;W,@;F$@;&EN:&$@)60N($5S<&5R861O<R`E9"P@96YC;VYT
M<F%D;W,@)60N`$[Z;65R;R!E<G)A9&\@9&4@8V%M<&]S+B!%<W!E<F%D;W,@
M)60L(&5N8V]N=')A9&]S("5D+@!/9F9S970@)60@:6YC;W)R971O(&%O(&QE
M<B!O(&%R<75I=F\@5D93+@!8+5)E9@!297-T<FGG]65S($+A<VEC87,@6#4P
M.78S`%5T:6QI>F'GXV\@9&4@0VAA=F4@17AT96YD:61A(%@U,#EV,P!.;VUE
M($%L=&5R;F%T:79O(&1E($%S<W5N=&\@6#4P.78S`$ED96YT:69I8V%D;W(@
M9&$@0VAA=F4@9&4@07-S=6YT;R!8-3`Y=C,`17AT96YS]65S(%@U,#EV,P!!
M00!!04%!`$UA<&$@66%H;V\A`$%N=6%L;65N=&4`3.IM96X`4VEM`%-I;2P@
M174@0V]N8V]R9&\`5F]CZB!E<W3A(&5M($U/1$\@5$585$\N("!5=&EL:7IA
M(&\@8F]TXV\@6SP^72!P87)A('9O;'1A<B!P87)A(&\@;6]D;R!765-)5UE'
M+@!6;V/J(&[C;R!E<W3A(&%U=&]R:7IA9&\@82!C<FEA<B!M86ES(&1E("5D
M(&)L;V-O<RX`5F]CZB!NXV\@97-TX2!A=71E;G1I8V%D;RX`5F]CZB!NXV\@
M<&]D92!T97(@;R!C87)A8W1E<B!<(&YO('-E=2!N;VUE+@!6;V/J(&[C;R!F
M;W)N96-E=2!U;2!E;F1E<F7G;R!D92!E+6UA:6P@=N%L:61O+@!6;V/J(&[C
M;R!M87!E;W4@;F5N:'5M(&-A;7!O(&1O(&%R<75I=F\@:6UP;W)T861O(&%O
M<R!C86UP;W,@8V]R<F5S<&]N9&5N=&5S(&5M("5S+@!6;V/J(&9O:2!D97-C
M;VYE8W1A9&\N`%9O8^H@9&5V92!P<F5E;F-H97(@=6T@;OIM97)O(&1E('1E
M;&5F;VYE(&-E;'5L87(@=N%L:61O+"!S;VUE;G1E(&3M9VET;W,@8V]M('5M
M(&]P8VEO;F%L("<K)R!P87)A(&1I<V-A9V5M(&1E('!R969I>&\@:6YT97)N
M86-I;VYA;"X`5F]CZB!D979E('!R965N8VAE<B!U;2!V86QO<B!VX6QI9&\N
M`%9O8^H@9&5V92!C;VYF:6=U<F%R('5M(&-O;F5C=&]R($1A=&%4<F5E('!A
M<F$@=71I;&EZ87(@0V%D87-T<F]S+@!6;V/J(&1E=F4@8V]N9FEG=7)A<B!U
M;2!C;VYE8W1O<B!61E,N`%9O8^H@9&5V92!D97-C<F5V97(@;R!P<F]B;&5M
M82!A;G1E<R!D92!E;G9I87(@;R!R96QA=/-R:6\@9&4@<')O8FQE;6$N`%9O
M8^H@9&5V92!F;W)N96-E<B!A(%523"!O;F1E(&\@;&EN:R!A<&]N=&$`5F]C
MZB!D979E('-E;&5C:6]N87(@=6T@<V5R=FED;W(@<&%R82!S97(@97AC;'7M
M9&\N`%9O8^H@9&5V92!E<W!E8VEF:6-A<B!U;2!U<W7A<FEO('!A<F$@97AC
M;'5I<BX`5F]CZB!D979E(&5S<&5C:69I8V%R('5M('5S=>%R:6\@<&%R82!R
M96UO=F5R+@!6;V/J(&1E=F4@97-P96-I9FEC87(@=6T@=7-UX7)I;R!P87)A
M(&%D:6-I;VYA<BX`5F]CZB!D979E(&5S<&5C:69I8V%R('5M('5S=>%R:6\@
M<&%R82!A='5A;&EZ87(N`%9O8^H@9&5V92!E<W!E8VEF:6-A<B!U;6$@8>?C
M;R!P87)A(&5X96-U=&%R+@!6;V/J(&1E=F4@<')E96YC:&5R('5M(&YO;64@
M<&%R82!A(&YO=F$@8V%T96=O<FEA+@!6;V/J('!R96-I<V$@9F]R;F5C97(@
M=6T@;OIM97)O(&1E('1E;&5F;VYE(&ET86QI86YO`%-U82!S97-SXV\@)7,@
M97AP:7)O=2X@4&]R(&9A=F]R+"!C;VYE8W1E+7-E(&YO=F%M96YT92X`4V5U
M($5N9&5R9>=O(&1E($4M;6%I;`!3974@16YD97)EYV\@9&4@4F5M971E;G1E
M("A$93HI.@!3=6%S($EN9F]R;6'G]65S`%-E=2!%;F1E<F7G;R!D92!);G1E
M<FYE="!M=61O=2!D97-D92!O(&EN[6-I;R!D92!S=6$@<V5S<^-O("5S+B!0
M87)A('!R;W1E9V5R('-U82!S96=U<F%NYV$@=F]CZB!D979E(&-O;F5C=&%R
M+7-E(&YO=F%M96YT92X`4V5U($YO;64`4V5U(&)A8VME;F0@9&4@875T96YT
M:6-AY^-O(&[C;R!S=7!O<G1A(&%D:>?C;R!D92!U<W7A<FEO<RP@;W4@82!F
M=6[GXV\@9F]I(&1E<V%B:6QI=&%D82!P;W(@86QG=6UA(&]U=')A(')A>N-O
M+@!3974@8F%C:V5N9"!D92!A=71E;G1I8V'GXV\@;N-O('-U<&]R=&$@;&ES
M=&%G96T@9&4@=7-UX7)I;W,L(&]U(&$@9G5NY^-O(&9O:2!D97-A8FEL:71A
M9&$@<&]R(&%L9W5M82!O=71R82!R87KC;RX`4V5U(&YA=F5G861O<B!P87)E
M8V4@=&5R(&%L=&5R861O(&1E<V1E(&\@:6[M8VEO(&1E('-U82!S97-SXV\@
M)7,N(%!A<F$@<')O=&5G97(@<W5A('-E9W5R86[G82P@=F]CZB!D979E(&-O
M;F5C=&%R+7-E(&YO=F%M96YT92X`4V5U(&YA=F5G861O<B!NXV\@<W5P;W)T
M82!E<W1A(&9U;N?C;RX`4V5U(&YA=F5G861O<B!NXV\@<W5P;W)T82!E<W1A
M(&]PY^-O(&1E(&EM<')E<W/C;RX@4')E<W-I;VYE($-O;G1R;VPO3W!T:6]N
M("L@4"!P87)A(&EM<')I;6ER+@!3974@9G5S;R!H;W+A<FEO(&%T=6%L.@!3
M=6$@:61E;G1I9&%D92!P861RXV\@9F]I(&%L=&5R861A+@!3=6$@:61E;G1I
M9&%D92!P861RXV\Z`%-E=2!N;VUE(&-O;7!L971O.@!3=6$@8V]N97CC;R!E
M>'!I<F]U+@!3=6$@;F]V82!S96YH82!P87)A("5S(.DZ("5S`%-U87,@;W#G
M]65S(&9O<F%M(&%T=6%L:7IA9&%S('!O<B!C875S82!D82!D=7)AY^-O(&1E
M<W1A('-E<W/C;RX`4W5A<R!O<.?U97,@9F]R86T@871U86QI>F%D87,N`%-U
M82!N;W9A('-E;FAA(&9O:2!G97)A9&$`4W5A(&YO=F$@<V5N:&$@9F]I(&=E
M<F%D82P@=F5R:69I<75E('-E=2!E+6UA:6P@92!C;VYE8W1E+7-E(&-O;2!S
M=6$@;F]V82!S96YH82X`4W5A('-E;FAA(&5X<&ER;W4N`%-E=7,@<V5R=FED
M;W)E<R!R96UO=&]S.@!)=6=O<VSA=FEA`%IA:7)E`%KB;6)I80!::6UB86)W
M90!::7!P>0!;3V-U;'1A<B!497AT;R!#:71A9&]=`%M296QA=/-R:6\@9&4@
M4')O8FQE;6%=`%M%>&EB:7(@5&5X=&\@0VET861O("T`6T5X:6)I<B!497AT
M;R!#:71A9&\@+2`E<R!L:6YH87-=`%ML:6YH82`E<R!D92`E<UT`7T%D;6EN
M:7-T<F'GXV\`7T-,20!$871A7U1R964`15]X8VQU:7(@0V]L=6YA`%]'<G5P
M;W,`05]J=61A`%!R;W!R:65D861E<R!D82!?26UA9V5M+BXN`%]#;VYE8W1A
M<@!?1&5S8V]N96-T87(`05]L=&5R87(@3&EN:RXN+@!?3W#G]65S`%]097)M
M:7-S]65S`%]296UO=F5R($QI;FLN+BX`0V]N9FEG=7)A7W(`4')O<')I961A
M9&5S(&1A(%]486)E;&$N+BX`7U5S=>%R:6]S`&-A=.%L;V=O(&1E(&5N9&5R
M9>=O<P!C873A;&]G;R!D92!E;F1E<F7G;W,`86=E;F1A`&-A;&UO`&EM<&]S
M<^UV96P@8W)I87(@87)Q=6EV;R!D92!D97-T:6YO`&EM<&]S<^UV96P@86)R
M:7(@82!O<FEG96T`8VQI<75E(&%Q=6D`97)R;R!D92!S:6YT87AE(&1A(&QI
M;FAA(&1E(&-O;6%N9&\`97)R;R!D92!C;VYF:6=U<F'GXV\`=6T@87)Q=6EV
M;R!C<NUT:6-O(&1O('-I<W1E;6$@97-TX2!F86QT86YD;P!E<G)O(&YO(&9O
M<FUA=&\@9&]S(&1A9&]S`&5D:71A<@!R96=I<W1R;R!NXV\@96YC;VYT<F%D
M;P!Q=65D80!A<G%U:79O`&$@<&%R=&ER(&1E("5S("@E<RD@X"`E<R`E<P!B
M<FES80!H.@!H:`!N;VUE(&1O(&AO<W0@Z2!D97-C;VYH96-I9&\`:6UE9&EA
M=&\`:6YC;W)P;W)A9&\`97)R;R!D92!E;G1R861A+W-A[61A`&5R<F\@:6YT
M97)N;R!D;R!P<F]G<F%M80!L:6YH87-=`&/S9&EG;R!D92!E<G)O("5D(&1O
M(&UK:7-O9G,@96YQ=6%N=&\@9V5R879A(&$@25-/+@!M;0!N;VUE`&[C;R!I
M;7!L96UE;G1A9&\`;N-O(&EM<&QE;65N=&%D;R!A:6YD80!B;&]C;R!D92!N
M;W1A<P!P;W)C96YT86=E;0!097)M:7-SXV\`<&EX96QS`&5R<F\@<F5M;W1O
M(&YO('!R;W1O8V]L;P!N87-C96YT90!S97)V:>=O(&EN9&ES<&]N[79E;`!E
M>&EB:7(@9&EF97)E;N=A<P!S;7,R96UA:6P@=FEA($A45%``<W,`97-TX79E
M;`!E<G)O(&1E('-I<W1E;6$`;&ES=&$@9&4@=&%R969A<P!F86QH82!T96UP
M;W+A<FEA`'!R965N8VAA('-U82!S96YH82!D=6%S('9E>F5S('!A<F$@8V]N
M9FER;6%R`'5N:69I8V%D;P!S96T@;F]M90!S96QEY^-O(&1E('5S=>%R:6\`
M=D-A<F0`=SH`=V5A=&AE<BYC;VT`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L;V-A;&4O<'1?0E(O:&5L<"YX;6P`````````````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#,S,C`@,3`U,34T,S,W-#$@,#(Q-#4S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_>&UL
M('9E<G-I;VX](C$N,"(_/@H\(2TM("1(;W)D93H@:&]R9&4O;&]C86QE+W!T
M7T)2+VAE;'`N>&UL+'8@,2XR(#(P,#0O,#4O,C<@,C`Z,C(Z,3,@:F%N($5X
M<"`D("TM/@H\:&5L<#X*("`\96YT<GD@:60](G-U;6UA<GDB('-T871E/2)N
M97<B/@H\=&ET;&4^5&AE(%!O<G1A;"!086=E/"]T:71L93X*(#QP87)A/@H@
M(%1H:7,@<&]R=&%L('!A9V4@<')O=FED97,@82!Q=6EC:R!S=6UM87)Y(&]F
M(&%L;"!Y;W5R(&EM<&]R=&%N=`H@(&EN9F]R;6%T:6]N+B!&;W(@97AA;7!L
M92P@:70@;6EG:'0@<VAO=R!H;W<@;6%N>2!N97<@92UM86EL(&UE<W-A9V5S
M('EO=0H@(&AA=F4@:6X@>6]U<B!)3D)/6"P@=7!C;VUI;F<@979E;G1S(&]N
M('EO=7(@8V%L96YD87(L('1A<VMS(&]N('EO=7(@=&\M9&\*("!L:7-T+"!H
M96%D;&EN97,@9G)O;2!S96QE8W1E9"!N97=S('-E<G9I8V5S+"!A;F0@<V\@
M;VXN("!-86YY(&]F('1H97-E"B`@<W5M;6%R:65S('=I;&P@8V]N=&%I;B!Q
M=6EC:R!S:&]R=&-U=',@=&\@8V]M;6]N(&9U;F-T:6]N<RP@<W5C:"!A<PH@
M(&-O;7!O<VEN9R!A(&YE=R!M86EL(&UE<W-A9V4L(&-R96%T:6YG(&$@;F5W
M(&-A;&5N9&%R(&5V96YT(&]R('1A<VLL(&5T8RX*(#PO<&%R83X*(#QP87)A
M/@H@(%1H92!C;VYT96YT<R!O9B!T:&ES('!O<G1A;"!P86=E(&%R92!C=7-T
M;VUI>F%B;&4@=FEA('1H92!,87EO=70@8G5T=&]N+@H@($9O<B!E>&%M<&QE
M+"!Y;W4@8V%N(&-H;V]S92!W:&EC:"!I=&5M<R!T;R!I;F-L=61E(&]N('1H
M:7,@<&]R=&%L('!A9V4@87,*("!W96QL(&%S(&EN('=H:6-H(&]R9&5R('1H
M97D@87)E('-H;W=N+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M;F%V8F%R(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H92!!<'!L:6-A=&EO;B!.
M879I9V%T:6]N($)A<CPO=&ET;&4^"B`\<&%R83X*("!!="!T:&4@;&5F="!H
M86YD('-I9&4@;V8@=&AE('=E8B!P86=E(&ES('1H92!A<'!L:6-A=&EO;B!N
M879I9V%T:6]N(&)A<BX*("!#;&EC:R!O;B!T:&4@:6-O;G,@;VX@=&AI<R!N
M879I9V%T:6]N(&)A<B!T;R!Q=6EC:VQY(&%N9"!E87-I;'D@<W=I=&-H"B`@
M8F5T=V5E;B!T:&4@879A:6QA8FQE(&%P<&QI8V%T:6]N<RX*(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61O7VUA:6YT96YA;F-E(B!S
M=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N
M8V4Z($1O($UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A/@H@("`@268@
M>6]U('=O=6QD(&QI:V4@=&\@<&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I
M;VYS(&]N(&QO9VEN+"!C:&5C:R!T:&ES(&)O>"X*("`@(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G!R969S+6-O;F9I<FU?;6%I;G1E;F%N8V4B
M('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N
M86YC93H@0V]N9FER;2!-86EN=&5N86YC93PO=&ET;&4^"B`@("`\<&%R83X*
M("`@($EF('EO=2!W;W5L9"!L:6ME('1O(&-O;F9I<FT@86QL(&UA:6YT96YA
M;F-E('1A<VMS(&)E9F]R92!T:&5Y(&%R92!R=6XL(&-H96-K('1H:7,@8F]X
M+B!)9B!L969T('5N8VAE8VME9"P@86QL(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@=&AA="!N965D('1O(&)E(')U;B!W:6QL(&)E('!E<F9O<FUE9"!A=71O
M;6%T:6-A;&QY('=I=&@@;F\@8VAA;F-E('1O(&-A;F-E;"!O;B!L;V=I;BX*
M("`@(#PO<&%R83X*/"]E;G1R>3X*/"]H96QP/@H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C
M86QE+W!T7U!4````````````````````````````````````````````````
M`````````````````````````````````````#`P,#<U-2``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S0Q(#`Q-S<T-``@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L;V-A;&4O<'1?4%0O3$-?34534T%'15,`````````
M````````````````````````````````````````````````````````````
M,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W
M-#$@,#(Q-3,Q`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]P=%]05"],
M0U]-15-304=%4R]H;W)D92YM;P``````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#0R-S,R-R`Q,#4Q-30S,S<T,2`P,C,R-C4`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````WA($E0````!S!P``'````+0[``#O
M"0``3'<````````(GP``30````F?``"_````5Y\``&0````7H```O@```'R@
M``"0````.Z$``$,```#,H0``/````!"B```K````3:(``"X```!YH@``*0``
M`*BB```H````TJ(``$4```#[H@``1P```$&C``!*````B:,``$<```#4HP``
M10```!RD``!(````8J0``#D```"KI```1@```.6D``!(````+*4``#````!U
MI0``10```*:E``!&````[*4``$P````SI@``-````("F```R````M:8``&D`
M``#HI@``,````%*G```E````@Z<``(@```"IIP``0````#*H``#V````<Z@`
M`$H```!JJ0``+````+6I``"%````XJD``$@```!HJ@``#@```+&J```/````
MP*H```T```#0J@``"````-ZJ```+````YZH```P```#SJ@``!`````"K```;
M````!:L``"T````AJP``'0```$^K```D````;:L``"D```"2JP``&0```+RK
M```,````UJL``!$```#CJP``)0```/6K```/````&ZP```L````KK```$0``
M`#>L```.````2:P```4```!8K```*````%ZL```(````AZP```H```"0K```
M%0```)NL```2````L:P```L```#$K```$P```-"L```.````Y*P```H```#S
MK```#0```/ZL```N````#*T```X````[K0``$0```$JM```-````7*T```P`
M``!JK0``#0```'>M```&````A:T```H```",K0``#P```)>M```8````IZT`
M``P```#`K0``&P```,VM```.````Z:T```X```#XK0``"`````>N```)````
M$*X``$(````:K@``+@```%VN```:````C*X``#(```"GK@``.````-JN``!4
M````$Z\``%$```!HKP``6@```+JO``!7````%;```#0```!ML```"0```**P
M```-````K+````<```"ZL```"@```,*P```/````S;````4```#=L```!@``
M`..P```1````ZK````@```#\L```"0````6Q```)````#[$``"4````9L0``
M(````#^Q```0````8+$```\```!QL0``"@```(&Q```#````C+$```\```"0
ML0``%````*"Q```)````M;$```T```"_L0``$@```,VQ```9````X+$``!X`
M``#ZL0``#P```!FR```*````*;(```\````TL@``"````$2R```D````3;(`
M`!0```!RL@``%@```(>R```(````GK(``$X```"GL@``+0```/:R```?````
M)+,``!D```!$LP``!P```%ZS```,````9K,``"P```!SLP``#@```*"S```#
M````K[,```L```"SLP``!P```+^S```'````Q[,```4```#/LP``!0```-6S
M```*````V[,```,```#FLP``%P```.JS```*`````K0```\````-M```#@``
M`!VT```8````++0``",```!%M```#@```&FT```4````>+0``!<```"-M```
M%P```*6T```7````O;0``!,```#5M```#P```.FT```.````^;0``!\````(
MM0``'0```"BU```'````1K4```8```!.M0``"````%6U```/````7K4```8`
M``!NM0``"@```'6U```3````@+4```L```"4M0``%0```*"U```5````MK4`
M``<```#,M0``$````-2U```%````Y;4``!4```#KM0``$0````&V```,````
M$[8``#L````@M@``.````%RV```)````E;8```<```"?M@``%````*>V```#
M````O+8```4```#`M@``$````,:V```)````U[8``!,```#AM@``.0```/6V
M```2````+[<``"<```!"MP``+````&JW```J````E[<``"4```#"MP``"@``
M`.BW```&````\[<```D```#ZMP``!P````2X```O````#+@``#<````\N```
M+@```'2X``!5````H[@``"T```#YN```+0```">Y```M````5;D``$````"#
MN0``(P```,2Y```C````Z+D``"T````,N@``,P```#JZ```5````;KH``!D`
M``"$N@``*0```)ZZ```D````R+H``!$```#MN@``"@```/^Z```,````"KL`
M``H````7NP``$````"*[```6````,[L``!8```!*NP``!P```&&[```'````
M:;L``!0```!QNP``"@```(:[```(````D;L```@```":NP``!P```*.[```'
M````J[L```8```"SNP``!0```+J[```'````P+L```8```#(NP``"````,^[
M```I````V+L```X````"O```"@```!&\```$````'+P```<````AO```"0``
M`"F\```&````,[P``!$````ZO```!P```$R\```6````5+P```0```!KO```
M"````'"\```&````>;P```T```"`O```!@```(Z\```>````E;P``!$```"T
MO```(@```,:\```6````Z;P```@`````O0``#0````F]```,````%[T```<`
M```DO0```P```"R]```#````,+T``!<````TO0``$P```$R]```=````8+T`
M``@```!^O0``!````(>]```(````C+T```@```"5O0``00```)Z]```@````
MX+T```8````!O@``!@````B^```5````#[X``!@````EO@``(@```#Z^```N
M````8;X``!T```"0O@``(0```*Z^``!4````T+X``"D````EOP``"@```$^_
M```'````6K\``!4```!BOP``#@```'B_```*````A[\```\```"2OP``#0``
M`**_```/````L+\```T```#`OP``"0```,Z_```4````V+\```8```#MOP``
M&````/2_```=````#<```!,````KP```$0```#_````4````4<````0```!F
MP```!@```&O```!4````<L````0```#'P```#@```,S```!$````V\````4`
M```@P0``!0```";!```;````+,$``!H```!(P0``$0```&/!```1````=<$`
M`!P```"'P0``*@```*3!```0````S\$``"$```#@P0``)0````+"```9````
M*,(```4```!"P@``$P```$C"```2````7,(```H```!OP@``#P```'K"```-
M````BL(``!$```"8P@``$P```*K"```,````OL(```8```#+P@``#````-+"
M```&````W\(``!<```#FP@``$````/["```1````#\,```@````APP``!0``
M`"K#```,````,,,``!`````]PP``!0```$[#```-````5,,```8```!BPP``
M!P```&G#```-````<<,``!````!_PP``"0```)##```'````FL,```L```"B
MPP``"P```*[#```'````NL,```<```#"PP``%````,K#```)````W\,```D`
M``#IPP``"@```//#```9````_L,``!T````8Q```#````#;$```0````0\0`
M``4```!4Q```)0```%K$```2````@,0``!,```"3Q```*P```*?$```[````
MT\0``"`````/Q0``-@```##%```A````9\4``!````")Q0``"````)K%```,
M````H\4```8```"PQ0``!````+?%```.````O,4``!````#+Q0``"@```-S%
M```-````Y\4``!X```#UQ0``&P```!3&```A````,,8``!X```!2Q@``&0``
M`''&```>````B\8``!L```"JQ@``+@```,;&```7````]<8``"8````-QP``
M,````#3'```;````9<<``!X```"!QP``'````*#'```F````O<<``"L```#D
MQP``,P```!#(```F````1,@``"L```!KR```.````)?(```=````T,@``!4`
M``#NR```+P````3)```@````-,D``!(```!5R0``*0```&C)```>````DLD`
M`!(```"QR0``H@```,3)```6````9\H``",```!^R@``*````*+*```I````
MR\H``"@```#UR@``'P```![+```5````/LL``"````!4RP``)0```'7+```H
M````F\L``"T```#$RP``,````/++``"2````(\P``"$```"VS```%@```-C,
M```<````[\P``"8````,S0``*@```#/-``!!````7LT``$0```"@S0``#```
M`.7-```'````\LT```<```#ZS0``!@````+.```-````"<X``!`````7S@``
M$@```"C.```3````.\X``!(```!/S@``!P```&+.```$````:LX``!````!O
MS@``#````(#.```.````C<X```\```"<S@``$P```*S.```-````P,X``"@`
M``#.S@```P```/?.```-````^\X```8````)SP``$0```!#/```7````(L\`
M`!L````ZSP``#@```%;/```"````9<\```4```!HSP``$````&[/```$````
M?\\```T```"$SP``#@```)+/```#````H<\```X```"ESP``"````+3/```/
M````O<\```\```#-SP``!P```-W/```-````Y<\``!````#SSP``$P````30
M```3````&-````L````LT```!@```#C0```,````/]```!$```!,T```&0``
M`%[0```+````>-````T```"$T```(@```)+0```;````M=```#0```#1T```
M"@````;1```8````$=$``!D````JT0``%@```$31```O````6]$``"(```"+
MT0``#0```*[1```'````O-$``!0```#$T0``"P```-G1```B````Y=$``"\`
M```(T@``"P```#C2```)````1-(``!D```!.T@``"P```&C2```7````=-(`
M`!<```",T@``"0```*32```6````KM(```\```#%T@``&0```-72```6````
M[](```X````&TP``&````!73```(````+M,```T````WTP``)@```$73``!#
M````;-,```@```"PTP``$@```+G3```(````S-,```L```#5TP``+P```.'3
M```.````$=0```4````@U```!@```";4```#````+=0```<````QU```!```
M`#G4```*````/M0```H```!)U```#P```%34```0````9-0``!<```!UU```
M$0```(W4```9````G]0``!<```"YU```"0```-'4```%````V]0```L```#A
MU```"@```.W4```"````^-0```4```#[U```#0````'5```;````#]4``!<`
M```KU0``"0```$/5```.````3=4```T```!<U0``$@```&K5```X````?=4`
M`"````"VU0``"````-?5```.````X-4``'L```#OU0``&````&O6``!`````
MA-8``!$```#%U@``!P```-?6```%````W]8``!D```#EU@``$P```/_6```'
M````$]<```<````;UP``"````"/7```&````+-<```8````SUP``$````#K7
M```/````2]<``!````!;UP``#P```&S7```+````?-<```\```"(UP``#```
M`)C7```/````I=<```<```"UUP``"@```+W7```&````R-<```X```#/UP``
M#````-[7```H````Z]<```\````4V```"````"38```6````+=@```@```!$
MV```$P```$W8```>````8=@``"$```"`V```(````*+8```9````P]@``!<`
M``#=V```)0```/78```7````&]D```0````SV0``&P```#C9```-````5-D`
M``P```!BV0```P```&_9```(````<]D```H```!\V0``#````(?9```+````
ME-D``!````"@V0``#````+'9```$````OMD``!,```##V0``%````-?9```,
M````[-D```D```#YV0``#@````/:```+````$MH``!L````>V@``!P```#K:
M```'````0MH```H```!*V@``#0```%7:```)````8]H```0```!MV@``!0``
M`'+:```#````>-H``!@```!\V@``"@```)7:```$````H-H``"8```"EV@``
M#@```,S:``!\````V]H``!4```!8VP``!0```&[;```'````=-L```P```!\
MVP``"````(G;```*````DML```8```"=VP``"````*3;```6````K=L``!(`
M``#$VP```@```-?;```&````VML```8```#AVP``%````.C;```-````_=L`
M`!`````+W```&P```!S<```$````.-P```D````]W```$````$?<```)````
M6-P```D```!BW```!0```&S<```%````<MP``!H```!XW```"````)/<```&
M````G-P``!D```"CW```#@```+W<```B````S-P```<```#OW```!P```/?<
M```.````_]P```4````.W0``"0```!3=```*````'MT```(````IW0``!@``
M`"S=```-````,]T```D```!!W0``!@```$O=```2````4MT```D```!EW0``
M!P```&_=```4````=]T``!T```",W0``$0```*K=```&````O-T```H```##
MW0``!````,[=```)````T]T```@```#=W0``$0```.;=```1````^-T```D`
M```*W@``!@```!3>```-````&]X```8````IW@``!````##>```Y````-=X`
M`#T```!OW@``.@```*W>```>````Z-X```4````'WP``#@````W?```$````
M'-\```8````AWP``(0```"C?```-````2M\``!4```!8WP``!@```&[?```$
M````==\``!$```!ZWP``!@```(S?``"@````D]\```H````TX```(@```#_@
M```$````8N```"4```!GX```!0```(W@```=````D^````0```"QX```#```
M`+;@```*````P^````@```#.X```"0```-?@```%````X>```!L```#GX```
M.@````/A```P````/N$``#4```!OX0``*0```*7A```N````S^$``$<```#^
MX0``.````$;B```I````?^(``#\```"IX@``+@```.GB```M````&.,``!\`
M``!&XP``#P```&;C```2````=N,```L```")XP``)@```)7C```I````O.,`
M`"0```#FXP``)@````OD```(````,N0```H````[Y```"0```$;D```'````
M4.0``"````!8Y```(````'GD```F````FN0```H```#!Y```&0```,SD```I
M````YN0``!8````0Y0``$@```"?E```'````.N4```H```!"Y0``#P```$WE
M```0````7>4``$````!NY0``<````*_E``!F````(.8```X```"'Y@``"0``
M`);F```*````H.8``!(```"KY@``$P```+[F```,````TN8```8```#?Y@``
M#P```.;F```2````]N8``!`````)YP``$0```!KG```<````+.<``",```!)
MYP``:@```&WG```/````V.<```4```#HYP``$````.[G```)````_^<```0`
M```)Z```"P````[H```@````&N@``!H````[Z```%````%;H```,````:^@`
M``P```!XZ```#P```(7H```5````E>@``"D```"KZ```*@```-7H```F````
M`.D``"<````GZ0``*0```$_I```J````>>D``!D```"DZ0``0@```+[I```1
M`````>H``!(````3Z@``$P```";J```4````.NH```\```!/Z@``%@```%_J
M```7````=NH``!````".Z@``$0```)_J```T````L>H``!,```#FZ@``$@``
M`/KJ```U````#>L``!0```!#ZP``!P```%CK```,````8.L``"````!MZP``
M$````([K```4````G^L``!$```"TZP``%P```,;K```<````WNL``!,```#[
MZP``%`````_L```:````).P``!$````_[```&@```%'L```>````;.P``!H`
M``"+[```$P```*;L```5````NNP``!$```#0[```%P```.+L```4````^NP`
M`!<````/[0``%0```"?M```)````/>T``!D```!'[0``!````&'M```'````
M9NT```L```!N[0``$0```'KM```&````C.T```8```"3[0``!@```)KM```%
M````H>T```<```"G[0``!P```*_M```%````M^T``!8```"][0``!@```-3M
M```&````V^T```0```#B[0``!````.?M```'````[.T```X```#T[0``#```
M``/N```,````$.X```T````=[@``"@```"ON```.````-NX```4```!%[@``
M*````$ON```.````=.X```P```"#[@``#P```)#N```*````H.X```@```"K
M[@``"0```+3N```K````ONX```0```#J[@``"````._N```F````^.X``!(`
M```?[P``#P```#+O```&````0N\```H```!)[P``!P```%3O```(````7.\`
M`"````!E[P``"0```(;O```,````D.\```T```"=[P``#@```*OO```6````
MNN\``!$```#1[P``!@```./O```#````ZN\```8```#N[P``&0```/7O```'
M````#_````0````7\```"P```!SP```+````*/````<````T\```!P```#SP
M```6````1/````T```!;\```#0```&GP```*````=_```!````""\```#P``
M`)/P```1````H_```!<```"U\```"@```,WP```1````V/````@```#J\```
M!````//P```/````^/```#H````(\0``!0```$/Q```,````2?$``!X```!6
M\0``#@```'7Q```0````A/$```L```"5\0``#````*'Q```)````KO$```<`
M``"X\0``"@```,#Q```)````R_$```X```#5\0``$````.3Q```:````]?$`
M``H````0\@``"0```!OR```4````)?(```H````Z\@``#````$7R```/````
M4O(```@```!B\@``!@```&OR```'````<O(```L```!Z\@``1P```(;R```-
M````SO(```D```#<\@``!````.;R```#````Z_(``!,```#O\@``$P````/S
M```3````%_,```H````K\P```@```#;S```$````.?,``"4````^\P```P``
M`&3S```%````:/,``"H```!N\P``"@```)GS```%````I/,```0```"J\P``
M"@```*_S```-````NO,``$````#(\P``$P````GT```&````'?0```@````D
M]```"````"WT```$````-O0```4````[]```:````$'T```)````JO0```P`
M``"T]```!0```,'T```&````Q_0``!L```#.]```+P```.KT```0````&O4`
M``H````K]0``#P```#;U```*````1O4```D```!1]0``$P```%OU```;````
M;_4``!@```"+]0``%P```*3U```.````O/4```,```#+]0``!P```,_U```(
M````U_4```<```#@]0``"@```.CU```+````\_4``"T```#_]0``%0```"WV
M```P````0_8``"0```!T]@``!P```)GV``!1````H?8``!````#S]@``#```
M``3W```-````$?<``!H````?]P``2@```#KW```9````A?<```8```"?]P``
M&@```*;W```&````P?<```8```#(]P``'P```,_W```&````[_<```D```#V
M]P``&`````#X```7````&?@```8````Q^```#0```#CX```B````1O@``%<`
M``!I^```$P```,'X```C````U?@``!,```#Y^````@````WY```+````$/D`
M``@````<^0``#0```"7Y```*````,_D```8````^^0``!P```$7Y```4````
M3?D```8```!B^0``"````&GY```.````<OD```<```"!^0``"@```(GY```+
M````E/D```<```"@^0``#````*CY```-````M?D```P```##^0``"0```-#Y
M```)````VOD```H```#D^0``!P```._Y```)````]_D```<````!^@``"@``
M``GZ```;````%/H``!(````P^@``"@```$/Z```)````3OH``!````!8^@``
M!P```&GZ```2````<?H```0```"$^@``!P```(GZ```%````D?H```4```"7
M^@``"P```)WZ```4````J?H``!$```"^^@``&@```-#Z```6````Z_H``!0`
M```"^P``%P```!?[```8````+_L``!P```!(^P``&0```&7[```'````?_L`
M``4```"'^P``#0```(W[```,````F_L```@```"H^P``%P```+'[```+````
MR?L``!,```#5^P``!````.G[```*````[OL```0```#Y^P``#0```/[[```,
M````#/P```4````9_```"0```!_\```%````*?P```<````O_```!0```#?\
M```$````/?P```(```!"_```.````$7\```L````?OP``!(```"K_```*0``
M`+[\```R````Z/P```H````;_0``-@```";]```L````7?T``!4```"*_0``
M+@```*#]```S````S_T``#,````#_@``.````#?^```/````</X``!@```"`
M_@``.P```)G^```0````U?X``!0```#F_@``$P```/O^```5````#_\``!0`
M```E_P``$@```#K_```4````3?\``!4```!B_P``+0```'C_```M````IO\`
M`#$```#4_P``+0````8``0`N````-``!`"\```!C``$`+````),``0!B````
MP``!`!,````C`0$`"````#<!`0`(````0`$!`"L```!)`0$`(0```'4!`0`:
M````EP$!``D```"R`0$`10```+P!`0!!`````@(!``0```!$`@$`$P```$D"
M`0`4````70(!``X```!R`@$`$P```($"`0`8````E0(!``8```"N`@$`"0``
M`+4"`0`*````OP(!``\```#*`@$`$````-H"`0`'````ZP(!``X```#S`@$`
M!0````(#`0`;````"`,!``8````D`P$`"````"L#`0`&````-`,!`!0````[
M`P$`$0```%`#`0`.````8@,!`#@```!Q`P$``@```*H#`0`&````K0,!``X`
M``"T`P$`&@```,,#`0`%````W@,!``<```#D`P$`#@```.P#`0`&````^P,!
M``0````"!`$`*0````<$`0`7````,00!`!\```!)!`$`7````&D$`0`4````
MQ@0!`#X```#;!`$`'P```!H%`0`0````.@4!``<```!+!0$`#@```%,%`0`(
M````8@4!``P```!K!0$`#````'@%`0`3````A04!``H```"9!0$`'0```*0%
M`0`9````P@4!``4```#<!0$`$0```.(%`0`1````]`4!`"0````&!@$`%0``
M`"L&`0`2````008!``X```!4!@$`&0```&,&`0`(````?08!``D```"&!@$`
M#0```)`&`0`*````G@8!``<```"I!@$`#P```+$&`0`&````P08!``L```#(
M!@$`"@```-0&`0`'````WP8!``@```#G!@$`!0```/`&`0`?````]@8!``8`
M```6!P$`$````!T'`0`(````+@<!``T````W!P$`"````$4'`0`2````3@<!
M`"P```!A!P$`&@```(X'`0`)````J0<!``H```"S!P$`%0```+X'`0`%````
MU`<!`!0```#:!P$`!````.\'`0`0````]`<!``8````%"`$`!P````P(`0`>
M````%`@!`"@````S"`$`"@```%P(`0`<````9P@!`!H```"$"`$`#P```)\(
M`0`4````KP@!``0```#$"`$`!````,D(`0`+````S@@!``4```#:"`$`!@``
M`.`(`0`(````YP@!``8```#P"`$`"@```/<(`0`;`````@D!`#0````>"0$`
M-````%,)`0`@````B`D!`"D```"I"0$`(````-,)`0!!````]`D!`!H````V
M"@$`*````%$*`0`I````>@H!`%$```"D"@$`+P```/8*`0`B````)@L!``8`
M``!)"P$`"````%`+`0`%````60L!``@```!?"P$`&0```&@+`0`9````@@L!
M`"H```"<"P$`(P```,<+`0`9````ZPL!`"X````%#`$`-````#0,`0`(````
M:0P!`!<```!R#`$`"@```(H,`0`'````E0P!`"$```"=#`$`$````+\,`0`.
M````T`P!``L```#?#`$`!P```.L,`0`3````\PP!``@````'#0$`"P```!`-
M`0`*````'`T!`!0````G#0$`#P```#P-`0`R````3`T!``L```!_#0$`!0``
M`(L-`0`%````D0T!`!<```"7#0$`#P```*\-`0`$````OPT!``H```#$#0$`
M"0```,\-`0`+````V0T!``T```#E#0$`#````/,-`0`.``````X!``4````/
M#@$`!````!4.`0`-````&@X!`#(````H#@$`10```%L.`0`7````H0X!`!X`
M``"Y#@$`%````-@.`0`%````[0X!`!0```#S#@$`!P````@/`0`.````$`\!
M`"H````?#P$`!@```$H/`0`,````40\!``T```!>#P$`$0```&P/`0`+````
M?@\!`#8```"*#P$`"@```,$/`0`B````S`\!``L```#O#P$`#P```/L/`0`R
M````"Q`!`"4````^$`$`,````&00`0`Q````E1`!`"T```#'$`$`#@```/40
M`0`%````!!$!``X````*$0$`$P```!D1`0`'````+1$!`!H````U$0$`"```
M`%`1`0`1````61$!``<```!K$0$`%````',1`0`8````B!$!``<```"A$0$`
M!0```*D1`0`,````KQ$!``P```"\$0$`$@```,D1`0`$````W!$!``<```#A
M$0$`"@```.D1`0`+````]!$!``P`````$@$`#@````T2`0`.````'!(!``4`
M```K$@$`!0```#$2`0`N````-Q(!`"8```!F$@$`(P```(T2`0`#````L1(!
M`!(```"U$@$`!@```,@2`0`>````SQ(!`!@```#N$@$`)0````<3`0`-````
M+1,!``D````[$P$``P```$43`0`'````21,!``H```!1$P$``@```%P3`0`,
M````7Q,!`!4```!L$P$`"P```((3`0`9````CA,!`"````"H$P$`$@```,D3
M`0`%````W!,!``H```#B$P$`%0```.T3`0`2`````Q0!``P````6%`$`!```
M`",4`0`'````*!0!``D````P%`$`#````#H4`0!2````1Q0!`!<```":%`$`
M)````+(4`0`2````UQ0!``<```#J%`$`!@```/(4`0`.````^10!`"(````(
M%0$`'0```"L5`0`,````214!``T```!6%0$`%0```&05`0`2````>A4!``\`
M``"-%0$`%````)T5`0`;````LA4!`!````#.%0$`:0```-\5`0`:````218!
M`!<```!D%@$`)P```'P6`0`:````I!8!`!<```"_%@$`&P```-<6`0`9````
M\Q8!`!\````-%P$`$P```"T7`0`(````01<!``<```!*%P$`"````%(7`0`)
M````6Q<!`!4```!E%P$`#0```'L7`0`C````B1<!`!,```"M%P$``P```,$7
M`0!&````Q1<!`#\````,&`$`-P```$P8`0!7````A!@!``4```#<&`$`'P``
M`.(8`0`O`````AD!``H````R&0$`"````#T9`0`-````1AD!`"T```!4&0$`
M!````((9`0!/````AQD!`"4```#7&0$`'````/T9`0`+````&AH!`!\````F
M&@$`'0```$8:`0`E````9!H!`"````"*&@$`)````*L:`0`@````T!H!``L`
M``#Q&@$`!P```/T:`0`-````!1L!``P````3&P$`%P```"`;`0`&````.!L!
M`#D````_&P$`#````'D;`0`'````AAL!`!D```".&P$`"0```*@;`0`3````
MLAL!``D```#&&P$`!````-`;`0`0````U1L!``H```#F&P$`"````/$;`0`(
M````^AL!``0````#'`$`"P````@<`0`,````%!P!`!(````A'`$`$0```#0<
M`0`,````1AP!`!H```!3'`$`#P```&X<`0`'````?AP!``T```"&'`$`%```
M`)0<`0`.````J1P!``P```"X'`$`&P```,4<`0`L````X1P!`!,````.'0$`
M'````"(=`0`H````/QT!``8```!H'0$`!P```&\=`0`3````=QT!``4```"+
M'0$`!````)$=`0`7````EAT!``H```"N'0$`#````+D=`0`)````QAT!``8`
M``#0'0$`"0```-<=`0`(````X1T!``D```#J'0$`"@```/0=`0`1````_QT!
M``8````1'@$`&````!@>`0`.````,1X!``X```!`'@$`#0```$\>`0`+````
M71X!`!T```!I'@$`"P```(<>`0`"````DQX!``<```"6'@$`!@```)X>`0!E
M````I1X!``D````+'P$`!P```!4?`0`F````'1\!`#@```!$'P$`&@```'T?
M`0`J````F!\!`#L```##'P$`*````/\?`0`T````*"`!`!D```!=(`$`%0``
M`'<@`0`%````C2`!``<```"3(`$`"````)L@`0`'````I"`!``4```"L(`$`
M!P```+(@`0`.````NB`!``D```#)(`$`!@```-,@`0`(````VB`!``L```#C
M(`$`!P```.\@`0`(````]R`!``<`````(0$`%@````@A`0`)````'R$!``8`
M```I(0$`"P```#`A`0`<````/"$!`!0```!9(0$`!P```&XA`0`1````=B$!
M``@```"((0$`#@```)$A`0`(````H"$!``4```"I(0$`$````*\A`0`0````
MP"$!``8```#1(0$`&0```-@A`0`*````\B$!`!P```#](0$`!P```!HB`0`%
M````(B(!`!`````H(@$`%````#DB`0`+````3B(!``T```!:(@$`*````&@B
M`0`8````D2(!`!<```"J(@$`!````,(B`0`)````QR(!``H```#1(@$`!P``
M`-PB`0`"````Y"(!``X```#G(@$`"````/8B`0`?````_R(!`#X````?(P$`
M(P```%XC`0`X````@B,!`"8```"[(P$`,0```.(C`0`G````%"0!`&0````\
M)`$`%````*$D`0!5````MB0!`#@````,)0$`2@```$4E`0!;````D"4!`"@`
M``#L)0$`.````!4F`0`H````3B8!`"P```!W)@$`)P```*0F`0`;````S"8!
M`#X```#H)@$`J0$``"<G`0`H````T2@!`",```#Z*`$`%P```!XI`0!(````
M-BD!`(4```!_*0$`,`````4J`0!!````-BH!`%L```!X*@$`20```-0J`0`=
M````'BL!`!@````\*P$`(0```%4K`0`?````=RL!`"L```"7*P$`(0```,,K
M`0`G````Y2L!`!T````-+`$`$0```"LL`0`S````/2P!`"4```!Q+`$`)P``
M`)<L`0`?````ORP!`#````#?+`$`:0```!`M`0`K````>BT!`#$```"F+0$`
M00```-@M`0`S````&BX!`"4```!.+@$`/0```'0N`0!E````LBX!`$T````8
M+P$`+P```&8O`0`N````EB\!`#````#%+P$`5````/8O`0"#````2S`!`%H`
M``#/,`$`2````"HQ`0!*````<S$!`#(```"^,0$`+P```/$Q`0`L````(3(!
M`"T```!.,@$`<0```'PR`0!O````[C(!`+,```!>,P$`%P```!(T`0`E````
M*C0!`#(```!0-`$`*0```(,T`0`^````K30!`"(```#L-`$`4@````\U`0`E
M````8C4!``L```"(-0$`L0```)0U`0!%````1C8!`"$```",-@$`+@```*XV
M`0`P````W38!`"4````.-P$`'````#0W`0`Q````43<!``<```"#-P$`!P``
M`(LW`0`$````DS<!``T```"8-P$`"P```*8W`0`.````LC<!``L```#!-P$`
M!0```,TW`0`0````TS<!``(```#D-P$`60```.<W`0`%````03@!`!(```!'
M.`$`!````%HX`0`'````7S@!``@```!G.`$`!0```'`X`0`#````=C@!`!``
M``!Z.`$`"@```(LX`0`,````EC@!`!,```"C.`$`#0```+<X`0`"````Q3@!
M``<```#(.`$`!@```-`X`0`4````US@!``P```#L.`$`&````/DX`0`&````
M$CD!`!(````9.0$`#````"PY`0`#````.3D!`"H````].0$`!````&@Y`0`&
M````;3D!``<```!T.0$`'P```'PY`0`U````G#D!`"X```#2.0$`+P````$Z
M`0`7````,3H!`"````!).@$`&P```&HZ`0`8````ACH!`"0```"?.@$`'P``
M`,0Z`0`:````Y#H!`"````#_.@$`&@```"`[`0`R````.SL!`!H```!N.P$`
M+P```(D[`0`K````N3L!`!\```#E.P$`(P````4\`0`?````*3P!`!H```!)
M/`$`)0```&0\`0`F````BCP!`"4```"Q/`$`)````-<\`0`8````_#P!`!T`
M```5/0$`)````#,]`0`8````6#T!`"(```!Q/0$`%0```)0]`0`E````JCT!
M`#P```#0/0$`'P````T^`0`C````+3X!`!\```!1/@$`(````'$^`0`:````
MDCX!`!@```"M/@$`)@```,8^`0`>````[3X!`"D````,/P$`'@```#8_`0`)
M````53\!``P```!?/P$`%P```&P_`0`O````A#\!`"0```"T/P$`!P```-D_
M`0`/````X3\!`!0```#Q/P$`#@````9``0`-````%4`!`"0````C0`$`!0``
M`$A``0`'````3D`!`"(```!60`$`)0```'E``0`3````GT`!`!H```"S0`$`
M'0```,Y``0`:````[$`!``<````'00$`QP````]!`0`+````UT$!`!4```#C
M00$`#````/E!`0`&````!D(!``D````-0@$`"P```!="`0`-````(T(!`!T`
M```Q0@$`%P```$]"`0`&````9T(!`#,```!N0@$`$P```*)"`0`3````MD(!
M``<```#*0@$`!@```-)"`0`/````V4(!``<```#I0@$`,@```/%"`0`A````
M)$,!`!,```!&0P$`#````%I#`0`1````9T,!`#(```!Y0P$`$````*Q#`0`(
M````O4,!`!T```#&0P$`"0```.1#`0`*````[D,!``4```#Y0P$`%````/]#
M`0`*````%$0!`!T````?1`$`"````#U$`0`?````1D0!``@```!F1`$`&@``
M`&]$`0`G````BD0!``8```"R1`$`%0```+E$`0`'````ST0!``@```#71`$`
M"0```.!$`0`_````ZD0!``<````J10$`#P```#)%`0`.````0D4!`!````!1
M10$`"0```&)%`0`)````;$4!``@```!V10$`$P```']%`0`'````DT4!`!D`
M``";10$`"@```+5%`0`7````P$4!`!0```#810$`"@```.U%`0`,````^$4!
M`!<````%1@$`!````!U&`0`J````(D8!`!$```!-1@$`!P```%]&`0`)````
M9T8!``(```!Q1@$`$````'1&`0`8````A48!``L```">1@$``P```*I&`0`(
M````KD8!``8```"W1@$`!P```+Y&`0`-````QD8!``L```#41@$`%````.!&
M`0`5````]48!``X````+1P$`+P```!I'`0`@````2D<!`!P```!K1P$`#```
M`(A'`0`Q````E4<!``4```#'1P$`$@```,U'`0`_````X$<!`!(````@2`$`
M"@```#-(`0`&````/D@!``0```!%2`$`!````$I(`0`*````3T@!`!,```!:
M2`$`!0```&Y(`0`&````=$@!``8```![2`$`"0```()(`0`$````C$@!``P`
M``"12`$`"@```)Y(`0`@````J4@!``4```#*2`$`&````-!(`0`9````Z4@!
M`!\````#20$`'0```"-)`0`1````04D!``(```!320$`!````%9)`0`*````
M6TD!``8```!F20$`!0```&U)`0`#````<TD!``P```!W20$`10```(1)`0`:
M````RDD!`#4```#E20$`*````!M*`0!3````1$H!`!D```"82@$`<@```+)*
M`0`@````)4L!`#4```!&2P$`(0```'Q+`0!%````GDL!`#````#D2P$`*```
M`!5,`0`I````/DP!`"8```!H3`$`)0```(],`0`H````M4P!`"@```#>3`$`
M(@````=-`0`K````*DT!`#````!630$`$@```(=-`0`3````FDT!`!````"N
M30$`>0```+]-`0`)````.4X!`'(```!#3@$`<P```+9.`0!\````*D\!`"L`
M``"G3P$`5````--/`0`7````*%`!`!8```!`4`$`#P```%=0`0!E````9U`!
M`!\```#-4`$`0````.U0`0`?````+E$!`!P```!.40$`40```&M1`0`4````
MO5$!``H```#240$`!0```-U1`0`&````XU$!``@```#J40$`!0```/-1`0`2
M````^5$!`!`````,4@$`$P```!U2`0`=````,5(!``\```!/4@$`#P```%]2
M`0`$````;U(!``D```!T4@$`"P```'Y2`0`'````BE(!``4```"24@$`%```
M`)A2`0`'````K5(!``@```"U4@$`#P```+Y2`0`(````SE(!``P```#74@$`
M#P```.12`0`&````]%(!`!0```#[4@$`!@```!!3`0`,````%U,!`!4````D
M4P$`"````#I3`0`$````0U,!``H```!(4P$`!````%-3`0`&````6%,!``<`
M``!?4P$`!````&=3`0`'````;%,!`!D```!T4P$`!P```(Y3`0`"````EE,!
M``(```"94P$`"0```)Q3`0`&````IE,!``8```"M4P$`)P```+13`0`"````
MW%,!``0```#?4P$`"P```.13`0`)````\%,!``\```#Z4P$`$P````I4`0`'
M````'E0!``<````F5`$`!@```"Y4`0`&````-50!`!`````\5`$`$@```$U4
M`0`"````8%0!``8```!C5`$`"0```&I4`0`S````=%0!`"(```"H5`$`!P``
M`,M4`0`'````TU0!``<```#;5`$`"P```.-4`0`%````[U0!``(```#U5`$`
M"P```/A4`0!B`0``!%4!`',```!G5@$`N````-M6`0!"````E%<!`,````#7
M5P$`D````)A8`0!&````*5D!`#<```!P60$`,P```*A9`0`V````W%D!`"\`
M```36@$`+@```$-:`0!H````<EH!`&4```#;6@$`9P```$%;`0!E````J5L!
M`&<````/7`$`;P```'=<`0`_````YUP!`&0````G70$`0P```(Q=`0`O````
MT%T!`$T`````7@$`1````$Y>`0!*````DUX!`#,```#>7@$`.````!)?`0!N
M````2U\!`"X```"Z7P$`+0```.E?`0"(````%V`!`&(```"@8`$`#P$```-A
M`0!.````$V(!`#0```!B8@$`BP```)=B`0!0````(V,!`!````!T8P$`%0``
M`(5C`0`4````FV,!``<```"P8P$`"0```+AC`0`(````PF,!``4```#+8P$`
M'@```-%C`0`N````\&,!`"P````?9`$`*0```$QD`0`N````=F0!`!@```"E
M9`$`"@```+YD`0`1````R60!`"L```#;9`$`$P````=E`0`0````&V4!`!``
M```L90$`%````#UE`0`%````4F4!`"@```!890$`#0```(%E`0`-````CV4!
M`!,```"=90$`#0```+%E`0`+````OV4!`!L```#+90$`$````.=E`0`*````
M^&4!`!8````#9@$`/P```!IF`0`-````6F8!``\```!H9@$`$````'AF`0`+
M````B68!``T```"59@$`!@```*-F`0`-````JF8!`!,```"X9@$`%0```,QF
M`0`-````XF8!`!L```#P9@$`&P````QG`0`3````*&<!``@````\9P$`"0``
M`$5G`0!8````3V<!`#0```"H9P$`%0```-UG`0`]````\V<!`$X````Q:`$`
M:@```(!H`0!I````ZV@!`'````!5:0$`;P```,9I`0!"````-FH!``\```!Y
M:@$`$@```(EJ`0`.````G&H!`!,```"K:@$`#P```+]J`0`%````SVH!``8`
M``#5:@$`$P```-QJ`0`)````\&H!``\```#Z:@$`$0````IK`0`A````'&L!
M`",````^:P$`%@```&)K`0`0````>6L!``T```"*:P$`"0```)AK`0`5````
MHFL!`!D```"X:P$`$0```-)K`0`5````Y&L!`!@```#Z:P$`'P```!-L`0`D
M````,VP!`!H```!8;`$`$````'-L`0`7````A&P!`!(```"<;`$`+@```*]L
M`0`8````WFP!`!P```#W;`$`%````!1M`0!9````*6T!`"H```"#;0$`*@``
M`*YM`0`J````V6T!``@````$;@$`"0````UN`0`W````%VX!``T```!/;@$`
M"````%UN`0`+````9FX!``<```!R;@$`!P```'IN`0`'````@FX!``<```"*
M;@$`#````))N`0`$````GVX!`"(```"D;@$`#P```,=N`0`3````UVX!`!<`
M``#K;@$`'`````-O`0`P````(&\!``D```!1;P$`&````%MO`0`>````=&\!
M`",```"3;P$`$0```+=O`0`4````R6\!`!(```#>;P$`#P```/%O`0`C````
M`7`!`!T````E<`$`!P```$-P`0`&````2W`!``<```!2<`$`&@```%IP`0`(
M````=7`!``H```!^<`$`$0```(EP`0`)````FW`!`!$```"E<`$`&@```+=P
M`0`'````TG`!`!(```#:<`$`!0```.UP`0`6````\W`!`!X````*<0$`#P``
M`"EQ`0`_````.7$!`#L```!Y<0$`"0```+5Q`0`'````OW$!`!,```#'<0$`
M!````-MQ`0`%````X'$!`!````#F<0$`"@```/=Q`0`4`````G(!`#P````7
M<@$`%0```%1R`0`M````:G(!`#(```"8<@$`,0```,MR`0`P````_7(!``D`
M```N<P$`!@```#AS`0`)````/W,!``<```!)<P$`.P```%%S`0`[````C7,!
M`#H```#)<P$`7P````1T`0`Y````9'0!`#D```">=`$`.0```-AT`0!+````
M$G4!`"T```!>=0$`,````(QU`0`Y````O74!`#\```#W=0$`%0```#=V`0`9
M````378!`#(```!G=@$`)@```)IV`0`3````P78!``H```#5=@$`$````.!V
M`0`%````\78!``P```#W=@$`'@````1W`0`C````(W<!``8```!'=P$`!0``
M`$YW`0`5````5'<!``L```!J=P$`"````'9W`0`*````?W<!``P```"*=P$`
M!P```)=W`0`&````GW<!``4```"F=P$`!P```*QW`0`%````M'<!``L```"Z
M=P$`,@```,9W`0`7````^7<!``T````1>`$`!P```!]X`0`'````)W@!``H`
M```O>`$`!0```#IX`0`3````0'@!``8```!4>`$`$@```%MX`0`%````;G@!
M``@```!T>`$`!````'UX`0`+````@G@!``8```".>`$`)0```)5X`0`1````
MNW@!`"L```#->`$`'@```/EX`0`(````&'D!``X````A>0$`#0```#!Y`0`'
M````/GD!``,```!&>0$``P```$IY`0`:````3GD!`"````!I>0$`*P```(IY
M`0`*````MGD!``4```#!>0$`"````,=Y`0`(````T'D!`%X```#9>0$`*```
M`#AZ`0`&````87H!``@```!H>@$`'P```'%Z`0`D````D7H!`"\```"V>@$`
M,@```.9Z`0`F````&7L!`"8```!`>P$`70```&=[`0`^````Q7L!`!<````$
M?`$`!P```!Q\`0`2````)'P!``P````W?`$`$````$1\`0`8````57P!`!<`
M``!N?`$`&````(9\`0`8````GWP!``D```"X?`$`%0```,)\`0`'````V'P!
M`!D```#@?`$`&P```/I\`0`9````%GT!`!,````P?0$`&````$1]`0`2````
M77T!``<```!P?0$`6P```'A]`0`)````U'T!`!4```#>?0$`-@```/1]`0`2
M````*WX!`!H````^?@$`'0```%E^`0`9````=WX!`!<```"1?@$`'0```*E^
M`0`>````QWX!`#(```#F?@$`#0```!E_`0`L````)W\!`"<```!4?P$`'0``
M`'Q_`0`&````FG\!`!P```"A?P$`'@```+Y_`0`:````W7\!`!H```#X?P$`
M"P```!.``0`5````'X`!`!,````U@`$`#0```$F``0`&````5X`!``\```!>
M@`$`"````&Z``0`5````=X`!`!8```"-@`$`$0```*2``0`5````MH`!``4`
M``#,@`$`!@```-*``0`1````V8`!``@```#K@`$`$P```/2``0`"````"($!
M``<````+@0$`$P```!.!`0`2````)X$!``D````Z@0$`"@```$2!`0`)````
M3X$!``H```!9@0$`!P```&2!`0`'````;($!``T```!T@0$`#````(*!`0`(
M````CX$!``D```"8@0$`&@```**!`0`B````O8$!``T```#@@0$`&````.Z!
M`0`>````!X(!`!X````F@@$`#P```$6"`0`0````58(!`#````!F@@$`/P``
M`)>"`0`A````UX(!`#P```#Y@@$`*````#:#`0`.````7X,!``D```!N@P$`
M"@```'B#`0`.````@X,!``8```"2@P$`#P```)F#`0`6````J8,!`!<```#`
M@P$`'````-B#`0`N````]8,!`"P````DA`$`,````%&$`0`O````@H0!`"D`
M``"RA`$`*0```-R$`0`F````!H4!`#D````MA0$`(@```&>%`0`P````BH4!
M`$(```"[A0$`,0```/Z%`0`R````,(8!`"4```!CA@$`,@```(F&`0`Y````
MO(8!`$X```#VA@$`-0```$6'`0`X````>X<!`$,```"TAP$`)````/B'`0`6
M````'8@!`$\````TB`$`*0```(2(`0`:````KH@!`#L```#)B`$`(@````6)
M`0`8````*(D!`-4```!!B0$`&@```!>*`0`M````,HH!`#````!@B@$`,0``
M`)&*`0`R````PXH!`"D```#VB@$`%@```""+`0`N````-XL!`#<```!FBP$`
M.@```)Z+`0`]````V8L!`#H````7C`$`F@```%*,`0`K````[8P!`!\````9
MC0$`*````#F-`0`W````8HT!`#8```":C0$`5@```-&-`0!9````*(X!``T`
M``""C@$`!````)".`0`&````E8X!``4```"<C@$`$0```**.`0`.````M(X!
M`!````##C@$`%0```-2.`0`;````ZHX!`!0````&CP$`$0```!N/`0`6````
M+8\!``D```!$CP$`#@```$Z/`0`/````78\!`!$```!MCP$`#0```'^/`0!#
M````C8\!``8```#1CP$`$0```-B/`0`3````ZH\!`!$```#^CP$`%P```!"0
M`0`;````*)`!``\```!$D`$``@```%20`0`+````5Y`!`!P```!CD`$`!```
M`("0`0`0````A9`!`!````"6D`$``P```*>0`0`/````JY`!``@```"[D`$`
M$````,20`0`2````U9`!``L```#HD`$`#P```/20`0`1````!)$!`!8````6
MD0$`%@```"V1`0`*````1)$!``<```!/D0$`#0```%>1`0`1````99$!`!H`
M``!WD0$`#@```)*1`0`.````H9$!`"0```"PD0$`&@```-61`0`X````\)$!
M``T````ID@$`'P```#>2`0`9````5Y(!`!@```!QD@$`-@```(J2`0`G````
MP9(!`!(```#ID@$`"0```/R2`0`3````!I,!``D````:DP$`,````"23`0`[
M````59,!``\```"1DP$`$````*&3`0`A````LI,!`!(```#4DP$`(P```.>3
M`0`C````"Y0!``H````OE`$`'````#J4`0`6````5Y0!`!X```!NE`$`%@``
M`(V4`0`7````I)0!`!D```"\E`$`!P```-:4`0`+````WI0!`"H```#JE`$`
M2@```!65`0`(````8)4!`!0```!IE0$`!P```'Z5`0`*````AI4!`#<```"1
ME0$`$P```,F5`0`&````W94!`!,```#DE0$``P```/B5`0`4````_)4!``8`
M```1E@$`#````!B6`0`,````)98!`!$````RE@$`$0```$26`0`7````5I8!
M`!$```!NE@$`&0```("6`0`7````FI8!``@```"RE@$`!@```+N6`0`8````
MPI8!``L```#;E@$``@```.>6`0`3````ZI8!`!\```#^E@$`'P```!Z7`0`8
M````/I<!`!(```!7EP$`#P```&J7`0`/````>I<!`!4```"*EP$`/@```*"7
M`0`R````WY<!``H````2F`$`#P```!V8`0"B````+9@!`!X```#0F`$`30``
M`.^8`0`0````/9D!`!(```!.F0$`!````&&9`0`H````9ID!`!8```"/F0$`
M!@```*:9`0`4````K9D!`"@```#"F0$`!0```.N9`0`&````\9D!``\```#X
MF0$`#@````B:`0`0````%YH!``X````HF@$`#````#>:`0`.````1)H!``L`
M``!3F@$`$````%^:`0`(````<)H!``L```!YF@$`"````(6:`0`5````CIH!
M``P```"DF@$`/P```+&:`0`1````\9H!``@````#FP$`$P````R;`0`5````
M()L!`"L````VFP$`)P```&*;`0`B````BIL!`"$```"MFP$`&````,^;`0`:
M````Z)L!`"4````#G`$`&0```"F<`0`#````0YP!`!D```!'G`$`"P```&&<
M`0`+````;9P!``,```!YG`$`"0```'V<`0`(````AYP!``H```"0G`$`$0``
M`)N<`0`-````K9P!`!````"[G`$`!````,R<`0`@````T9P!`"$```#RG`$`
M$P```!2=`0`/````*)T!`!,````XG0$`%P```$R=`0`N````9)T!``<```"3
MG0$`"0```)N=`0`0````I9T!`!````"VG0$`"P```,>=`0`(````TYT!``D`
M``#<G0$`"````.:=`0`6````[YT!``P````&G@$`!@```!.>`0`I````&IX!
M``X```!$G@$`B0```%.>`0`=````W9X!``<```#[G@$`!0````.?`0`-````
M"9\!``4````7GP$`!P```!V?`0`&````)9\!``@````LGP$`)````#6?`0`3
M````6I\!``(```!NGP$`"````'&?`0`2````>I\!`!4```"-GP$`#P```*.?
M`0`2````LY\!`"<```#&GP$``@```.Z?`0`#````\9\!`!(```#UGP$`"0``
M``B@`0`-````$J`!``<````@H`$`$@```"B@`0`@````.Z`!``@```!<H`$`
M$P```&6@`0`5````>:`!``T```"/H`$`(````)V@`0`'````OJ`!`!T```#&
MH`$`#P```.2@`0`1````]*`!``D````&H0$`#````!"A`0`"````':$!``4`
M```@H0$`#P```":A`0`2````-J$!``8```!)H0$`$@```%"A`0`+````8Z$!
M``<```!OH0$`%P```'>A`0`F````CZ$!`!,```"VH0$`!@```,JA`0`)````
MT:$!``0```#;H0$`%@```."A`0`(````]Z$!`!8`````H@$`%@```!>B`0`0
M````+J(!``4````_H@$`#````$6B`0`@````4J(!``0```!SH@$`10```'BB
M`0!&````OJ(!`$4````%HP$`)0```$NC`0`2````<:,!`!,```"$HP$`!P``
M`)BC`0`)````H*,!`!8```"JHP$`$````,&C`0`5````TJ,!``8```#HHP$`
M!0```.^C`0`4````]:,!``4````*I`$`G````!"D`0`*````K:0!`!X```"X
MI`$`!````->D`0`S````W*0!``4````0I0$`'````!:E`0`$````,Z4!`!``
M```XI0$`$````$FE`0`6````6J4!``P```!QI0$`!0```'ZE`0`:````A*4!
M`#(```"?I0$`-P```-*E`0!`````"J8!`"P```!+I@$`,@```'BF`0!!````
MJZ8!`$H```#MI@$`,0```#BG`0!%````:J<!`#4```"PIP$`-P```.:G`0`G
M````'J@!`!````!&J`$`%0```%>H`0`+````;:@!`"@```!YJ`$`(````**H
M`0`A````PZ@!`!\```#EJ`$`"`````6I`0`*````#JD!``H````9J0$`%```
M`"2I`0`I````.:D!`"<```!CJ0$`,````(NI`0`+````O*D!`!D```#(J0$`
M*0```.*I`0`:````#*H!`!0````GJ@$`%````#RJ`0`-````4:H!`!````!?
MJ@$`$P```'"J`0!$````A*H!`'T```#)J@$`@@```$>K`0`3````RJL!``T`
M``#>JP$`#@```.RK`0`1````^ZL!`!(````-K`$`%@```""L`0`'````-ZP!
M`!(````_K`$`$P```%*L`0`2````9JP!`!4```!YK`$`+````(^L`0`L````
MO*P!`&T```#IK`$`%0```%>M`0`2````;:T!`!@```"`K0$`%@```)FM`0`*
M````L*T!``H```"[K0$`(0```,:M`0`=````Z*T!`!8````&K@$`#@```!VN
M`0`.````+*X!`!4````[K@$`%0```%&N`0`J````9ZX!`"D```"2K@$`*0``
M`+RN`0`H````YJX!`"<````/KP$`*0```#>O`0`:````8:\!`%4```!\KP$`
M$P```-*O`0`5````YJ\!`!4```#\KP$`%````!*P`0`1````)[`!`!<````Y
ML`$`%P```%&P`0`4````:;`!`!,```!^L`$`.@```)*P`0`8````S;`!`!D`
M``#FL`$`/@````"Q`0`5````/[$!``<```!5L0$`$0```%VQ`0`@````;[$!
M`!,```"0L0$`$P```*2Q`0`>````N+$!`"(```#7L0$`'0```/JQ`0`;````
M&+(!`!H````TL@$`(@```$^R`0`2````<K(!`!P```"%L@$`(0```**R`0`<
M````Q+(!`!@```#AL@$`&P```/JR`0`3````%K,!`!L````JLP$`'````$:S
M`0`<````8[,!`!@```"`LP$`"@```)FS`0`:````I+,!`!,```"_LP$`%```
M`-.S`0`+````Z+,!`!0```#TLP$`$`````FT`0`'````&K0!``<````BM`$`
M$@```"JT`0`'````/;0!``<```!%M`$`!0```$VT`0`5````4[0!``8```!I
MM`$`&P```'"T`0`%````C+0!``4```"2M`$`"@```)BT`0`'````H[0!``H`
M``"KM`$`%0```+:T`0`4````S+0!`!@```#AM`$`%0```/JT`0`3````$+4!
M`"P````DM0$`$P```%&U`0`0````9;4!`!H```!VM0$`%````)&U`0`-````
MIK4!`!,```"TM0$`,0```,BU`0`&````^K4!``D````!M@$`)P````NV`0`3
M````,[8!`!````!'M@$`!@```%BV`0`3````7[8!``L```!SM@$`!@```'^V
M`0`A````AK8!`!(```"HM@$`$@```+NV`0`4````SK8!`!(```#CM@$`&```
M`/:V`0`5````#[<!`!0````EMP$``P```#JW`0`*````/K<!`"$```!)MP$`
M!@```&NW`0`(````<K<!`!4```![MP$`$@```)&W`0`&````I+<!``<```"K
MMP$`,P```+.W`0`,````Y[<!`!,```#TMP$`"0````BX`0`2````$K@!`!4`
M```EN`$`$0```#NX`0`5````3;@!``T```!CN`$`!````'&X`0`*````=K@!
M``<```"!N`$`%````(FX`0!)````GK@!``@```#HN`$`#P```/&X`0`E````
M`;D!`!4````GN0$`&````#VY`0`.````5KD!`!````!EN0$`#@```':Y`0`+
M````A;D!``T```"1N0$`$P```)^Y`0`3````L[D!`!<```#'N0$`+````-^Y
M`0`+````#+H!`!4````8N@$`&0```"ZZ`0`-````2+H!``P```!6N@$`&@``
M`&.Z`0`+````?KH!``8```"*N@$`!````)&Z`0`2````EKH!`%8```"IN@$`
M%@````"[`0`+````%[L!``0````CNP$`!0```"B[`0`8````+KL!`!D```!'
MNP$`&@```&&[`0`*````?+L!``(```"'NP$`!````(J[`0`C````C[L!``,`
M``"SNP$`!0```+>[`0`H````O;L!``H```#FNP$`!0```/&[`0`'````][L!
M`!@```#_NP$`$0```!B\`0!1````*KP!`!(```!\O`$`!@```(^\`0`'````
MEKP!``@```">O`$`!````*>\`0`%````K+P!`&0```"RO`$`"@```!>]`0`-
M````(KT!``4````PO0$`!@```#:]`0`9````/;T!`#@```!7O0$`#@```)"]
M`0`)````G[T!`!<```"IO0$`"@```,&]`0`(````S+T!`!D```#5O0$`+P``
M`.^]`0`I````'[X!`"@```!)O@$`$@```'*^`0`$````A;X!``<```"*O@$`
M"````)*^`0`'````F[X!``T```"CO@$`#````+&^`0`V````OKX!`!\```#U
MO@$`,0```!6_`0`E````1[\!``@```!MOP$`60```':_`0`1````T+\!`!``
M``#BOP$`$@```/._`0`9````!L`!`$X````@P`$`'0```&_``0`&````C<`!
M`!\```"4P`$`!P```+3``0`&````O,`!`"````##P`$`!@```.3``0`)````
MZ\`!`"<```#UP`$`)@```!W!`0`'````1,$!``H```!,P0$`)0```%?!`0!+
M````?<$!`!@```#)P0$`'0```.+!`0`6`````,(!``(````7P@$`#0```!K"
M`0`(````*,(!`!,````QP@$`#0```$7"`0`&````4\(!``8```!:P@$`%```
M`&'"`0`4````=L(!``@```"+P@$`"0```)3"`0`+````GL(!``H```"JP@$`
M"P```+7"`0`1````P<(!``\```#3P@$`$@```./"`0`3````]L(!``8````*
MPP$`%0```!'#`0`4````)\,!``4````\PP$`!@```$+#`0`%````2<,!`!<`
M``!/PP$`(````&?#`0`1````B,,!``T```":PP$`#````*C#`0`4````M<,!
M`!````#*PP$`$0```-O#`0`$````[<,!`!0```#RPP$`!0````?$`0`%````
M#<0!`!<````3Q`$`$P```"O$`0`4````/\0!`!P```!4Q`$`(0```''$`0`9
M````D\0!`!D```"MQ`$`'0```,?$`0`B````Y<0!`!P````(Q0$`!````"7%
M`0`%````*L4!``X````PQ0$`#@```#_%`0`(````3L4!`"(```!7Q0$`#0``
M`'K%`0`4````B,4!``@```"=Q0$`$@```*;%`0`'````N<4!`!````#!Q0$`
M#P```-+%`0`(````XL4!`!8```#KQ0$`$@````+&`0`<````%<8!``4````R
MQ@$`!````#C&`0`#````/<8!`%$```!!Q@$`/P```)/&`0`>````T\8!`"0`
M``#RQ@$`00```!?'`0`1````6<<!`#X```!KQP$`+@```*K'`0`<````V<<!
M`#H```#VQP$`2@```#'(`0!7````?,@!`%P```#4R`$`$````#')`0`B````
M0LD!`$<```!ER0$`%0```*W)`0`A````P\D!`!X```#ER0$`(P````3*`0`?
M````*,H!`!D```!(R@$`&P```&+*`0`3````?LH!`#D```"2R@$`.0```,S*
M`0`]````!LL!`#D```!$RP$`.@```'[+`0`[````N<L!`#@```#URP$`<0``
M`"[,`0`=````H,P!``H```"^S`$`"0```,G,`0`P````T\P!`#L````$S0$`
M*0```$#-`0`+````:LT!`$L```!VS0$`1@```,+-`0`'````"<X!`!<````1
MS@$`%0```"G.`0`/````/\X!`!````!/S@$`%P```&#.`0`0````>,X!``\`
M``")S@$`#@```)G.`0`3````J,X!`!$```"\S@$`#````,[.`0`.````V\X!
M``4```#JS@$`(P```/#.`0`$````%,\!``@````9SP$`!@```"+/`0`4````
M*<\!`!$````^SP$`$````%#/`0!2````8<\!``(```"TSP$`!P```+?/`0`2
M````O\\!`"````#2SP$`!0```///`0`'````^<\!`!L````!T`$`"````!W0
M`0`0````)M`!`#(````WT`$`%@```&K0`0`R````@=`!`'8```"TT`$`%0``
M`"O1`0!.````0=$!`"(```"0T0$`$0```+/1`0`&````Q=$!``P```#,T0$`
M!P```-G1`0`.````X=$!``L```#PT0$`%@```/S1`0`+````$](!`!P````?
MT@$`&````#S2`0`%````5=(!`!(```!;T@$`$@```&[2`0`E````@=(!`!8`
M``"GT@$`%0```+[2`0`1````U-(!`",```#FT@$`"@````K3`0`,````%=,!
M`!0````BTP$`$P```#?3`0`,````2],!``X```!8TP$`"P```&?3`0`3````
M<],!``T```"'TP$`"@```)73`0`?````H-,!`!(```#`TP$`%P```-/3`0`&
M````Z],!`!````#RTP$`%0````/4`0`6````&=0!``T````PU`$`&````#[4
M`0`Q````5]0!`!T```")U`$`#@```*?4`0`/````MM0!`"0```#&U`$`!0``
M`.O4`0`1````\=0!``<````#U0$`%@````O5`0`'````(M4!``L````JU0$`
M(````#;5`0`T````5]4!``D```",U0$`(@```);5`0`;````N=4!``T```#5
MU0$`%````./5`0`$````^-4!`!0```#]U0$`"0```!+6`0`(````'-8!``L`
M```EU@$`#@```#'6`0`&````0-8!``H```!'U@$`(0```%+6`0`_````=-8!
M`$````"TU@$`)````/76`0`M````&M<!`"H```!(UP$`1P```'/7`0`D````
MN]<!`#,```#@UP$`0P```!38`0!A````6-@!`#0```"ZV`$`+0```._8`0`'
M````'=D!``@````EV0$`"0```"[9`0`4````.-D!`!L```!-V0$`&P```&G9
M`0`P````A=D!`"4```"VV0$`(@```-S9`0`Z````_]D!`$(````ZV@$`!P``
M`'W:`0`9````A=H!``D```"?V@$`"````*G:`0`@````LMH!`!$```#3V@$`
M%````.7:`0`-````^MH!``@````(VP$`%0```!';`0`)````)]L!``\````Q
MVP$`#0```$';`0`:````3]L!`!@```!JVP$`.P```(/;`0`*````O]L!``\`
M``#*VP$`!@```-K;`0`:````X=L!`!````#\VP$`!0````W<`0`-````$]P!
M`!`````AW`$`"0```#+<`0`,````/-P!``P```!)W`$`#@```%;<`0`'````
M9=P!``,```!MW`$`#0```''<`0`V````?]P!`$@```"VW`$`&````/_<`0`E
M````&-T!`"$````^W0$`$0```&#=`0`5````<MT!``L```"(W0$`$@```)3=
M`0`I````I]T!``<```#1W0$`#0```-G=`0`.````Y]T!`!(```#VW0$`"P``
M``G>`0`\````%=X!``D```!2W@$`'````%S>`0`2````>=X!`!8```",W@$`
M0````*/>`0`D````Y-X!`#P````)WP$`.@```$;?`0`V````@=\!`!$```"X
MWP$`!@```,K?`0`7````T=\!`!P```#IWP$`"@````;@`0`=````$>`!``L`
M```OX`$`$````#O@`0`'````3.`!`!4```!4X`$`%0```&K@`0`)````@.`!
M``<```"*X`$`%````)+@`0`1````I^`!`!D```"YX`$`!0```-/@`0`'````
MV>`!``D```#AX`$`$````.O@`0`/````_.`!`!4````,X0$`%0```"+A`0`'
M````..$!``8```!`X0$`,0```$?A`0`I````>>$!`"4```"CX0$`"````,GA
M`0`/````TN$!`!,```#BX0$`'P```/;A`0`>````%N(!`!\````UX@$`#0``
M`%7B`0`,````8^(!``,```!PX@$`!P```'3B`0`-````?.(!``(```"*X@$`
M#````(WB`0`1````FN(!``L```"LX@$`%````+CB`0`8````S>(!`!4```#F
MX@$`'````/SB`0`C````&>,!`!,````]XP$`%@```%'C`0`.````:.,!``<`
M``!WXP$`"@```'_C`0`,````BN,!``X```"7XP$`6@```*;C`0`8`````>0!
M`"P````:Y`$`%0```$?D`0`'````7>0!``@```!EY`$`$@```&[D`0`K````
M@>0!`"0```"MY`$`%````-+D`0`3````Y^0!`"$```#[Y`$`&````!WE`0`6
M````-N4!`"0```!-Y0$`*````'+E`0`5````F^4!`%\```"QY0$`(0```!'F
M`0`=````,^8!`"T```!1Y@$`(P```'_F`0`=````H^8!`"0```#!Y@$`(```
M`.;F`0`B````!^<!`!T````JYP$`"@```$CG`0`4````4^<!``D```!HYP$`
M"````'+G`0`3````>^<!``\```"/YP$`*P```)_G`0`5````R^<!``@```#A
MYP$`8````.KG`0`_````2^@!`%````"+Z`$`<````-SH`0`*````3>D!`"4`
M``!8Z0$`+P```'[I`0`)````KND!``<```"XZ0$`#0```,#I`0`^````SND!
M``<````-Z@$`20```!7J`0`M````7^H!`"<```"-Z@$`#@```+7J`0`W````
MQ.H!`!T```#\Z@$`00```!KK`0`V````7.L!`#\```"3ZP$`-0```-/K`0`4
M````">P!``H````>[`$`$P```"GL`0`6````/>P!`!@```!4[`$`"````&WL
M`0`Q````=NP!``H```"H[`$`"@```+/L`0`F````ONP!``H```#E[`$`%P``
M`/#L`0`6````".T!``<````?[0$`$0```"?M`0`1````.>T!``H```!+[0$`
M%@```%;M`0`$````;>T!``4```!R[0$`!@```'CM`0`/````?^T!`!(```"/
M[0$`$````*+M`0`=````L^T!``T```#1[0$`!P```-_M`0`0````Y^T!`"``
M``#X[0$`$@```!GN`0`-````+.X!`!H````Z[@$`)@```%7N`0`.````?.X!
M`!\```"+[@$`+P```*ON`0`)````V^X!``L```#E[@$`&````/'N`0`0````
M"N\!`!8````;[P$`&0```#+O`0`.````3.\!`!````!;[P$`#0```&SO`0`)
M````>N\!`"T```"$[P$`!@```++O`0`)````N>\!``T```##[P$`$P```-'O
M`0`&````Y>\!`!P```#L[P$`&`````GP`0`/````(O`!``@````R\`$`'@``
M`#OP`0`;````6O`!``P```!V\`$``@```(/P`0`'````AO`!``@```".\`$`
M;@```)?P`0`0````!O$!``<````7\0$`)P```!_Q`0!&````1_$!`!P```".
M\0$`)P```*OQ`0!$````T_$!`#$````8\@$`0````$KR`0`<````B_(!`!8`
M``"H\@$`$@```+_R`0`&````TO(!``T```#9\@$`"@```.?R`0`)````\O(!
M``T```#\\@$`$0````KS`0`/````'/,!``H````L\P$`#````#?S`0`0````
M1/,!``<```!5\P$`"````%WS`0`'````9O,!`!0```!N\P$`%````(/S`0`/
M````F/,!``4```"H\P$`)0```*[S`0`5````U/,!``H```#J\P$`%````/7S
M`0`+````"O0!`!0````6]`$`"P```"OT`0`&````-_0!`!8````^]`$`%@``
M`%7T`0`'````;/0!``<```!T]`$`&0```'ST`0`(````EO0!``4```"?]`$`
M!P```*7T`0`2````K?0!`!L```#`]`$`"P```-ST`0`-````Z/0!`"T```#V
M]`$`(0```"3U`0`8````1O4!``4```!?]0$`#````&7U`0`4````<O4!``T`
M``"']0$``@```)7U`0`3````F/4!`!(```"L]0$`'P```+_U`0!`````W_4!
M`",````@]@$`-````$3V`0`Q````>?8!`#0```"K]@$`(@```.#V`0!B````
M`_<!`!8```!F]P$`;@```'WW`0`[````[/<!`%8````H^`$`<0```'_X`0`M
M````\?@!`#P````?^0$`*P```%SY`0`P````B/D!`#````"Y^0$`'````.KY
M`0`Z````!_H!`+\!``!"^@$`*P````+\`0`?````+OP!`!8```!._`$`5@``
M`&7\`0",````O/P!`#,```!)_0$`0````'W]`0!:````OOT!`%`````9_@$`
M(@```&K^`0`5````C?X!`!T```"C_@$`'0```,'^`0`J````W_X!`!P````*
M_P$`)0```"?_`0`C````3?\!`!8```!Q_P$`-P```(C_`0`J````P/\!`"@`
M``#K_P$`&@```!0``@`P````+P`"`&(```!@``(`+0```,,``@`T````\0`"
M`$4````F`0(`,@```&P!`@`K````GP$"`$<```#+`0(`90```!,"`@!:````
M>0("`#$```#4`@(`+@````8#`@`L````-0,"`%D```!B`P(`E0```+P#`@!L
M````4@0"`%P```"_!`(`6@```!P%`@`R````=P4"`"4```"J!0(`)0```-`%
M`@`K````]@4"`&X````B!@(`:P```)$&`@#`````_08"`!D```"^!P(`)P``
M`-@'`@`^``````@"`"T````_"`(`40```&T(`@`G````OP@"`%P```#G"`(`
M'@```$0)`@`*````8PD"`-X```!N"0(`.P```$T*`@`I````B0H"`$(```"S
M"@(`/0```/8*`@`E````-`L"`"````!:"P(`/P```'L+`@`(````NPL"``@`
M``#$"P(`"0```,T+`@`3````UPL"`!````#K"P(`$@```/P+`@`+````#PP"
M``8````;#`(`#@```"(,`@`$````,0P"`%P````V#`(`!````),,`@`1````
MF`P"`!(```"J#`(`"````+T,`@`&````Q@P"``X```#-#`(`!````-P,`@`6
M````X0P"``H```#X#`(`"0````,-`@`1````#0T"`!,````?#0(``@```#,-
M`@`4````-@T"`!0```!+#0(`$@```&`-`@`.````<PT"`!4```""#0(`!@``
M`)@-`@`6````GPT"``T```"V#0(``P```,0-`@`T````R`T"``0```#]#0(`
M$P````(.`@`'````%@X"`"0````>#@(`4````$,.`@`Y````E`X"`#H```#.
M#@(`'P````D/`@`G````*0\"`"(```!1#P(`)@```'0/`@`H````FP\"`",`
M``#$#P(`)0```.@/`@`L````#A`"`"<````[$`(`.P```&,0`@`B````GQ`"
M`#@```#"$`(`-````/L0`@`E````,!$"`"D```!6$0(`+````(`1`@`G````
MK1$"`"P```#5$0(`+0````(2`@`U````,!("`"$```!F$@(`)0```(@2`@`J
M````KA("`#(```#9$@(`)0````P3`@`L````,A,"`!L```!?$P(`)0```'L3
M`@!"````H1,"`"8```#D$P(`*@````L4`@`M````-A0"`"X```!D%`(`)@``
M`),4`@`D````NA0"`"X```#?%`(`*P````X5`@`X````.A4"`!T```!S%0(`
M"@```)$5`@`3````G!4"`!D```"P%0(`+````,H5`@`C````]Q4"``T````;
M%@(`#P```"D6`@`6````.18"``L```!0%@(`&0```%P6`@`J````=A8"``@`
M``"A%@(`#````*H6`@`A````MQ8"`#(```#9%@(`&`````P7`@`K````)1<"
M`"L```!1%P(`)````'T7`@`(````HA<"`.8```"K%P(`$0```)(8`@`6````
MI!@"``P```"[&`(`"0```,@8`@`-````TA@"`!4```#@&`(`$0```/88`@`I
M````"!D"`"(````R&0(`!@```%49`@!%````7!D"`!P```"B&0(`'0```+\9
M`@`=````W1D"``L```#[&0(`$P````<:`@`)````&QH"`%(````E&@(`*@``
M`'@:`@`=````HQH"`!0```#!&@(`%P```-8:`@`H````[AH"`!@````7&P(`
M$@```#`;`@`D````0QL"`!,```!H&P(`%````'P;`@`,````D1L"`!@```">
M&P(`&````+<;`@`7````T!L"``@```#H&P(`+````/$;`@`)````'AP"`"D`
M```H'`(`*````%(<`@`'````>QP"`!L```"#'`(`!P```)\<`@`(````IQP"
M``D```"P'`(`/````+H<`@`&````]QP"`!,```#^'`(`%````!(=`@`.````
M)QT"``D````V'0(`"@```$`=`@`@````2QT"`!,```!L'0(`#0```(`=`@`6
M````CAT"`!(```"E'0(`&````+@=`@`8````T1T"``P```#J'0(`#@```/<=
M`@`8````!AX"``0````?'@(`+P```"0>`@`/````5!X"``4```!D'@(`!P``
M`&H>`@`"````<AX"`!$```!U'@(`(P```(<>`@`+````JQX"``,```"W'@(`
M!@```+L>`@`,````PAX"``P```#/'@(`$0```-P>`@`0````[AX"`!8```#_
M'@(`%P```!8?`@`%````+A\"`"\````T'P(`'P```&0?`@`>````A!\"``D`
M``"C'P(`*0```*T?`@`'````UQ\"`!<```#?'P(`/@```/<?`@`1````-B`"
M`!(```!((`(`"````%L@`@`$````9"`"``4```!I(`(`#0```&\@`@`:````
M?2`"``8```"8(`(`!P```)\@`@`)````IR`"`!$```"Q(`(`"````,,@`@`2
M````S"`"`!(```#?(`(`,````/(@`@`4````(R$"`!D````X(0(`)````%(A
M`@`B````=R$"`"4```":(0(`$````,`A`@`"````T2$"``0```#4(0(`"P``
M`-DA`@`*````Y2$"``4```#P(0(``P```/8A`@`-````^B$"`$<````((@(`
M%0```%`B`@`R````9B("`#D```"9(@(`4@```-,B`@`/````)B,"`'8````V
M(P(`(@```*TC`@!.````T","`"\````?)`(`-@```$\D`@`]````AB0"`"D`
M``#$)`(`)P```.XD`@`P````%B4"`#0```!')0(`+0```'PE`@`I````JB4"
M`"P```#4)0(`+@````$F`@`Q````,"8"`"8```!B)@(`%````(DF`@`0````
MGB8"`'L```"O)@(`"@```"LG`@!X````-B<"`'H```"O)P(`>0```"HH`@`P
M````I"@"`&$```#5*`(`%````#<I`@`2````3"D"``T```!?*0(`@P```&TI
M`@`F````\2D"`#D````8*@(`(@```%(J`@`@````=2H"`&L```"6*@(`&P``
M``(K`@`*````'BL"``4````I*P(`!@```"\K`@`(````-BL"``4````_*P(`
M%P```$4K`@`9````72L"`!<```!W*P(`(@```(\K`@`0````LBL"``X```##
M*P(`"````-(K`@`'````VRL"``X```#C*P(`!P```/(K`@`&````^BL"`!<`
M```!+`(`!P```!DL`@`%````(2P"`!(````G+`(`!P```#HL`@`+````0BP"
M`!,```!.+`(`#0```&(L`@`7````<"P"``T```"(+`(`"0```)8L`@`0````
MH"P"``H```"Q+`(`!0```+PL`@`+````PBP"``4```#.+`(`!@```-0L`@`*
M````VRP"``@```#F+`(`#````.\L`@`3````_"P"``<````0+0(``@```!@M
M`@`"````&RT"``@````>+0(`"````"<M`@`'````,"T"`"P````X+0(``@``
M`&4M`@`$````:"T"``X```!M+0(`#@```'PM`@`0````BRT"`!4```"<+0(`
M$````+(M`@`+````PRT"``8```#/+0(`!P```-8M`@`2````WBT"`!(```#Q
M+0(``@````0N`@`'````!RX"`!`````/+@(`*@```"`N`@`V````2RX"``D`
M``""+@(`"````(PN`@`+````E2X"`!P```"A+@(`!0```+XN`@`&````Q"X"
M``L```#++@(``0```,X%``#7`@``X04``*<"```'!```:@8```````!3!@``
MY`4``#($``#&````;@,``+D&````````NP$``'L%````````,P,``#H&``!M
M`0``O`4```````"&`0``"0(``.0#```3!@```````#8"``#L`````````&(%
M``"!!0``,P8```````!9`@``P`0``'0#`````0``Y00```D````'````MP4`
M``````#?!@````````````#,`0``"````&@````-`@```````/X$``#I````
M\P4``/$%````````T0$``!`&````````````````````````;`$``-@`````
M````D@8``!,`````````1@(``)\!````````X`(``-,````J!0``;@``````
M``#5!0``>`(``+\$```?`@``PP0``($"``#_`0```````,,&``!K`@``70``
M`)`%````````40,``"0!``"D````2P4``)D!``!C`0``)P,````````L`P``
M30(``*(&``"9````T`4``-@#````````)P$``,X```#!!@```````,<&``!\
M````C0````````"E!`````````````!S`0``?08``.D!``!#`P``&0(`````
M``!+!```Y@(``#,!``#`!@``+`````````#4!@``H04````````?`0``````
M``P```!'````]P,``$X"``#[!````````"`!``"8!@``4@$``#H"```Y`P``
M*`,``-X!``"6`P```````)P%``!+`0````````(!``"/`0``X`$``(H$``#+
M`P```````+P!```:!```?04``/4#``">!@```````%T#````````[04``&\%
M``#R`0``"@4````````>`@``"0$``/X#``#)`0``U`0``$8!``#A`@``````
M``````#>`P``>````%L$``#*````20$`````````````TP8``,X#````````
MJ0,``"@%``"S``````````T%``"*!0``>0```&\!```>`0``&04```````"Q
M`0``3`8``````````````````'`#`````````````&\"``""!```%`8``+T%
M``"?!0```````.X```!@!P``X@0``(@$``!?`P``[P8```````"$!0``<@<`
M`$\'```Z!P``QP,``,L"`````````````,0#``#S`0```````)`#``#?````
M`````/X%````````@@$``!8%``"B!0``Z08`````````````(`(```````"_
M`P``TP$``.`&``!:````]P(```````#I`@```````'X!```\!0``M`4``)L"
M```U!P```````/P$``"Q````H@```-H"``!O!P``$P4``-<`````````YP8`
M`$H"``#K`@``=@0``+\&``#_`@``4@0``!8'``!!````8````','``!Z!```
MI0```!$"``#2````+@,``*\&```!`P```P0`````````````2P```-T#````
M`````````(H#```=!0``\@0``&,`````````%0,``!(%```L!0``M0,``-8`
M``"Q`P``/P<``(0&````````Q0(```````#S`@```````.D#```Y`@``JP0`
M``````!@`P``,04``!$&``#Q`P``A0```,\$``""`@``RP```(4!``!5!0``
M7`$``.<$```/!P``"P$```````!P`0``M04``!X$``#A`P```````&(!``"+
M!@`````````````<`@``[08```````!Q``````````````#-!```O@4`````
M``#=`0``2`<``,L$```P!0``90$``(0````3`@``G`$````````3!```````
M`,$#``#^!@``$0<```````!0!0``,0$``*P!``#"!```C04``*4"```E````
MT`0`````````````[`$```````!8!0``_P0``)`&``#G`0``<@0``.L&``!+
M`@````````T$``"`!0``=`(``(\#``")`0``^0```$D%``!6`@``F0(`````
M````````D@`````````H!P``5@0``*0"`````````````%\"``!]````!`4`
M````````````"P````````"@`P``"08``"L'````````>`0``!L&``"L!@``
M`@```+\"````````9@```)L%``#T!0``X@8`````````````N00```````"F
M`@``]04``(<$```````````````````I!P```````"T&``"5`0``N`0``/$!
M``"[!0``&@8```````!I`0``V@4```````#<````+P0``/4&````````-0``
M`+4```#]`P``I@$```````!J!P``U08```````!%`0``(P```#@"````````
M\P```#\!````````C08``(8"``"#!```3@8``$$!``"1`P``F`(`````````
M````KP4``````````````````-P#``"1!@``[@(```$!``#O`0``*`0`````
M``!_`0``'P0``$T#``!W`0``-`,``"4%``"*````#08``$<'``#[`P``I08`
M````````````?P```.0$````````,@```-X&````````3@$``$H&````````
M`````"<$``#J````Z@4``)\$``"L``````````X%`````````````,$%````
M````B`4``-8#``#.!```G0,```````!%!0``J0````````#T````I`$``!D#
M````````,@(``.`#`````````````#H$```U`@``K`4````````]`0``5`0`
M`/D"``!O````#P,``(,%``!G!````````&T%``"H!0``#@<`````````````
MPP,```````!/!0``]@```#P#``"'````^P```%T!```[`@``A0(``+D"``"P
M`0``T08``#L$``#*`@```````,0!``!9`P```04``/`!``#``0``````````
M``#T!@```````"P"``!/`@``60$``-0!``".`P``9P,``#@!````````904`
M`*D"``!]`0``+0,`````````````0@0``+D```#P!@``4@```%\!``!V!0``
M1`(``!(!````````)`4``,4```"S!```BP(```````"]!@``;`````D%````
M````,P<```````!>`@``8P8``+L&``!I`P``6`8``&4&````````T`(```@"
M``#F`0```````'X````U`0``V0,``"H$````````*00``"`$````````1@``
M```````Z!0``.P,``.4!````````I@8``$H#``!M``````````````"N````
M`````%L'``!8!P``+00``"`#``"C!@```````)@```!>`0``!0(``+<```"Y
M`P``/@4``/0"``#S!```M08``)(%````````O`,```````#P````W00``*T&
M```Y!```50$``#(%``".`@``_@`````````+!@``_04```````"2`0``I`,`
M`&4$```D````C@```'`"``!-````BP4``$T'``#6!0``6`,```````#A`0``
ML`4``!\&```P`@``F`0```````!0`0```````%$!```-`0````````````"N
M`P``````````````````[`,``!@&```7`@``IP8``%`#``"1!0```````$8%
M`````````````,T!```*`0````````````"0`@``M`(``-4#``#2`@``````
M`&\&``#M`````````````````````````*\````L!@``3@0```````"%!0``
M`````/\````\!@``*P0``"X!````````U0```),$``"D!0``J@8``.4%``!Z
M`@``(@(``#0```#-!@``108```<!````````?@8``$D$``#O`````````#@&
M``!R!0``>@,``&D'````````!0,``)H%``#8!0``'`4``)X!```A`P``````
M`'0$````````Y0```&0"```Q`@``````````````````C`(``!8```!D`P``
M(P4``(L`````````C`0``)L```"T````YP```)("``!Y!@``5`,``,T%``!L
M!@``]@4```\"````````````````````````7@```-(!```E`P``4P```)<"
M``"7````7`````````!\!@```````&4"``"3!@``C@$``'<%``#1!0``````
M`,("``!`!P``,0``````````````I@4``!4```!#`@``>@````````!5!P``
MA00``($```"``0```````%4`````````G@,``"8$````````*0$`````````
M`````````-<!``!@`@``/`(``!`#``".!@``O````$T!``!I`@``7P4``&0%
M``!G!@``+04``)8!````````K`,``!<#``"M!`````````8!```C!@``RP4`
M`!L"```@`````````$,%````````6P,``````````````````+`&``!7`P``
M[`(```@'``",````$`4``(4&````````1`0``,`#````````M@(```````#,
M!```HP0``$X``````````````","``#\!@``6P````H&``!"!0```````.,$
M````````Q`8``*H!````````F0,``#P'``````````````````!5`P``XP``
M```````,!P``L00``$@$``#N`P``#P$``)4&``"C`P```````/P!``!"!P``
MA`0``(L!````````!@8``!4&```V!0```````(@&``#.!@``F@```$,'```7
M!@```````",'``!)`````````/<%``"Q!@``9@,```````#/!0``M@8```X$
M```;````,@<``!X%````````[@0```<'````````A@,```````"T!```````
M``````#X`@``OP4`````````````4P<``!4"``"7!0``3`(``,(&```I!@``
MT00``%D&`````````````(8$``"5`P``]P````````!X`0``I@0``,4$````
M````%`(``(H"```V`P``#`8``.L```!!!@```````.0"````````W@```($#
M``!S`P``0`,``-L&```[!@``+0```&L$````````T`8``'L$```W!`````0`
M`#H#``"]!```.@$```````!^!```6`$``%<'``#0`````````(X%``":`0``
M^@8``&4'````````)08``````````````````,<$``"'`P``404`````````
M````8@(``"<"``#Z!```D00````````B````H0```-H$``!K````-0,``+<#
M```H````(@,``&`&``"(`P``208```0!``!1````H00```````!!`P``R```
M`#@#```A!```B`(``.D%``"D!```````````````````=P(``%T%```$!```
M``````8'```J`P``O@(``&T$``!D````````````````````^`0``#\$````
M````[@8``"4$````````:@(```````"9!0``&`$```````#9!0```````*`!
M```0!P``D````/L!``#M`0``%P<``,8"``"-!```P@4``#8'```J`@``0`4`
M``,'``#P`@``DP4``/T$````````H@(``!T#``#?`0``/@0``"T'``!Q!```
M0`0````````6`@``G`(```T'``#U`@``7`8``(0"``````````````,```#4
M`P``<P```````````````P,``&(&``#/`0``0`8````````^`0```````&0$
M``#E`@``Y0,````````B!P``'`,``$<#``!F!@```````'<#````````VP4`
M`%\$``#2`P``````````````````6P(``#8!``#C`@``/@8``+(```#6`@``
MU0$````````X````5`4```````";`P``EP0``,P`````````6@<``!$!````
M!@``$`(```````!+`P``W0```"<`````````MP(````````-`P``L@(``(@`
M``"F````?`$``.\#````````=@```'\$``#'`0``90,``"$&```F`@``L`(`
M`-<$````````B08```````!S!```G00```````"Q`@``R08``!`!````````
MQ04``,8&```U!@``0`(``&X"````````HP4``#,%```Y!P``P0```'X%```J
M`0``004``!H#````````?@,````````+`@``O0(`````````````````````
M`````````````&<"``"K`P``8`$``*D$```X!0``/P````````"@!```.`<`
M``<"``"``P``````````````````*P$```````#/!@```````$0'``#-`@``
M.@``````````````T@8``$(```!.`P````````````!V!@``M@4``&8"``#<
M!@``B@$```````#9!```D`0``'8!``!/!@``LP$`````````````TP(`````
M``"``@``B0````````!U`@``O0```#,```"5!```8P0``.8#````````/0``
M`/@!````````B`$``$4#``#[`@``1````)L!`````````````+@```#2!0``
M-`4``!D'``"&!@``%`,``,@#``"X`P```````%`'``"<````7@,``#8$``"_
M`0```````-@"`````````````-<#``":`@```````-8!`````````````$P'
M```(!```*P(``(P%``"<`P``;08``-\$`````````````/0!````````````
M`,4&``#7!@``EP8``"X```!6`0``[P4``(P#``#,`@```````+0&```P!@``
MZ@8``!@'````````O0$``*L%````````R@8``/T```!'!0``@00``"L#````
M````:P,``'D!```E!P`````````````!!```&P,````````^````?P,``/`$
M``#D`0```P4``+(!``"`!```]P$``.L!``#V`0```````!D!``"S`P``6P4`
M`/\%``#.`0```````!0!``"-`P``[@$``*(#```4````J04``!X````B!@``
M$@0``!\````0!````````&<'``"#`0```````.$```#B````800``&$%``"#
M`P``W`(`````````````H`(``"L%```@!0``^@4``%<!``"=`@``M@```!T!
M```!!@```````!P&``#<`0``A`$``"0$``"B!```J`,```<%``#J!```XP,`
M`,(#``"S!@``]0$```````!R!@``V0``````````````6`0```````!P!P``
M7@0``,P&``!W!@``*0(```````#-`````````&$"``#)!```6P$``&@"```W
M`@``YP(``"\```"9!@``NP0``,L&``!``0``-`$``,@"````````&`4`````
M``"3`0``1P8```(#```_`P```````&D$``#;!```VP(`````````````K@0`
M`)T!```1`````````,$$``!4!P````````````"=!0```0(``%$'``#M!```
M"@<```````#X`P``O@,``*<#````!P``5@,``"X"```X!`````````````"'
M`0``2`8``*\"```P!P``B04`````````````&`0```````!B````/@(``!P$
M``!L!```^`8```````!U`P``T`,``$T&``#=`@```````(D#````````9P4`
M`%`&``"+!```X`4``'$%``#Z`P``T0,``-4"```5!P```````)@%```V````
MH`4```````#R```````````````L!P``:@,``'P"``!@!0````````@&``!*
M!````````!@"`````````````#0'```#`0``=P0``/$```!S`@``T0(`````
M``#$````L04``'X"``"U!```JP(``#$$```[!0``ZP0``/`#````!0``H```
M``````"L!```"@0``'P%```)!````````&L'```R!@``6@,``,D"````````
MW@0```````!Y!```)`8```````#W!```6@(``)0"``!&!@``B@8``!D$````
M````10```"@&``!"!@``708``%@`````````K0$``$@!````````````````
M`````````````/("```F`0``<0(```D#`````````````/@%````````N@``
M``````!H!`````````````"8`P````````````"T`0``8P4``$,```!B`P``
M!`(``#P!``!A!P``````````````````%`4``!H````*`P```````(D$```N
M!0```````+,%```A````J@(``/@``````````````'L#```$````+P(``!D`
M```7!0```````$H%```A`0``5P(``%P$``!R`@``4@4`````````````9`<`
M`!H!``#H`````````#,$``![!@``H0$``%D$``#S!@``DP```.,%```%!P``
M`````/P#``#H`0``Z`(``#<```"L`@``-P4```````#J`P```````!T$``!<
M!P```````%P#```>!P``<`8```````"/!0``R@0``&$```!A`P``VP,``(,"
M``#"````NP(````````2`P``H`8``(8```!/!```+P4``(P&```8````'0(`
M`,````#K`P``&P4``!8!``!(`@``U````-,%````````?`0`````````````
M^00`````````````\@4`````````````6`(``#D%````````QP(```````!\
M`P````````P$```,!0``)P8``!('```F`P```````*<$``#\!0``G@```%T'
M``"J!`````````````!1`@``I04``!\#`````````````%4&````````7@4`
M````````````[`0``,`%```V!@``_````!,'```````````````"```U!```
M+P8``$$'``"O!```CP````````"`!@``N@,````````G!0``S`,```````!<
M!0``>0(```\&`````````````+H"``"9!```L````),#``"E`P``60<``+0#
M```"!0``V0$``&,"``"4`P``\00``*<```!Z!@``/08``$P%``!)`P``V`$`
M`"($`````````````)T```"D!@``;`<``/(#``!/`P`````````````(`P``
M+@0``*X!````````O@8``'0&```L!```#`,``,8%``"C````@P8``,4!``"'
M!0``@@,``"@!``#\`@``0P8``#<'`````````````*L````R`P``7@8``%0!
M``!4````FP8``-,$``#(`0``/P(``+X````=!P``'@,```````":!```L@8`
M`.(#`````````````$,!````````=P`````````N!P```````((```!_`@``
M`````",#``!D`0``;P,``$T$````````+0(```````#1````V@``````````
M````:`8``-\%```F!@``:`,``'\&``!F`0``'`````````"=!@``````````
M``#A!@``RP$``&D````^`P```````-`!``#F!```>0,```````#F````MP$`
M```````Y````>P```/X!``#W!@``J`0``#T#``#@!````````)P$```2````
MM@$``%H!``!N!````````$@#``#@````%04``/D#``#Q`@``KP$```($``"\
M!```"0<```````!J````&`,```````!2!P``:08``)($``!S!0``````````
M``!B!P``$````,0%```Q!P````````````#:`0``MP8```0#```/!0``>@4`
M`+@!````````!0$``````````````````+@"```Y!@``NP,``$H'```(!0``
M10<```X"```F````9P$``(0#````````4P(```````!N`0``-P$``)H#````
M````808``*@!``````````````````!?!P```````%`"````````H0,`````
M``#_`P``O`(``/0#```F!0``(P0``%,%``!]`@`````````````P````(@$`
M`/L&``"R!```:@4``.\"````````U@8``.("``"^`0``408``&L!``#Z````
M2`4``%0"``!P````=08``#T"``!M!P``DP(``!("```#!@````````````"?
M````#@8``/4````Y`0``UP4````````J````!`8``!X&````````[0(``'(!
M``#*`0``>04``.@%``"R`P``5@<`````````````9@<``/4$``"K`0``CP0`
M`*T#``!T`````````%("``#4`@``IP$``/D!````````X@4``$H````]!0``
M500``*,!``#H!@``7@<```````#-`P``60```+L```";!```50(```````!7
M`````````($&```W!@``GP8``````````````````"\#````````P@$``(T"
M``````````````````!+!@``N@8``)\"```_!0````````````!J!```6@4`
M``````#L!0``L`,`````````````,P(``-P$```]!```20(```````"X!@``
M`````/8&``#$!```XP$``$P#``"Y!0```````'(```!2`P``(04```````"4
M!```VP$``````````````````+H%``!F!0``4P$``*X%``!0!```700``-T%
M``!G````-`0```4&`````````````)X$``!#!```:P4```````!_!0``"P,`
M`-X%````````A0,``+@%``#V`P``@@8``"D%````````X@$`````````````
M````````````````Q@0``,<%``"4````:`4```````"-`0``*@8``!0$``"6
M!0``8@0``,4#```H`@``5@4```````#T!```E0(``!H%``"O`P``ZP4`````
M``"7`0``D0```)(#``#P!0````````@!``!A`0``+`$`````````````_08`
M`%````#*!0``00(`````````````!@(`````````````20<````````7````
M5P0``(L#```&`P```````%$$```\!```2P<``(\&``!&!P```````!P'```%
M````K0(``%H&``!9!0``8P,```<#`````````````"0"``!J`0``MP0``#L'
M``!Q`P``K04```````!H!P``H@$```````!V`P```````(``````````1`$`
M`'4```#&`0```````)0%``!6!@```````!<$``!%`@``6@0``-H#``#5!```
M`````,@&```:!P``(@4```("``"4`0``)0$``.8&``!!!```L@4`````````
M````4P0``)4%``#9`@````````````#)!0``_@(``/8"``#<!0``HP(````#
M``!,`0``LP(``*X"``#V!```(0<``)4```!U`0``;P0``,8#````````D`$`
M`&X&``#M`P```````!,!``![`0``'08``/T"``#/`@``G`8``(P!````````
M8P<``&`$``#$`@``V@8```\````R`0``>@$``"H'````````J08``'`%``!6
M````_0$```````#Q!@``O@0``,\````T`@``D0$```H"`````````````%(&
M```#`@```````'4$````````[`8``+P&````````K0```$<!````````Z@$`
M`,X"````````1`4````````1`P``*P````````#;````&08``",!```?!P``
M1`8``.X%````````E@0``!8$``!R`P``+P$```8%````````)0(``(X$````
M````!00``*X&``"G!0``U@0``$``````````Z`0``/L%``#!`0``+@8``(\"
M````````,0,``!4$````````<`0``,@$````````T@0``.4&````````"P0`
M`-\#``!&!```5P4``!8#````````#@,``````````````````&P#```P!```
M&@(```$'````````PP(```````!&`P``:`$``,\#``"F`P``N0$```````!T
M`0``^04``/H!``#!`@``<0$``&X%````````3@4``"D`````````/0<`````
M``!'`@``$04``,,!``#Z`@```````($!``!S!@```````!<!``"'!@``&P$`
M`,`"```T!@``/````%,#``"J`P```````.D$````````L`0``"<'````````
M@P```.\$``#D````1P0``&P%````````0@(```L%```*`````````/,#````
M````F@8``!0'``#)`````````#L```!"`P```````"$"```5`0``3P$``%<&
M``!X!0``M0$``/D&```_!@``?00``)X%`````````````-X"````````````
M``````#R!@``Y@4```\$```%!0``YP4```L'``!"`0``=04``)8"```2!@``
M=@(```````#_!@``,08``*L&````````<0<``)8``````````````"L&```'
M!@``(`<```````#4!0``)`<```````"'`@``*0,``$P`````````>`,``+8$
M``!/````6P8``!\%````````100````````<`0``1`,``*@&``#)`P``<08`
M``````````````````````#8!@``&P0``%\&``"V`P``.P$``(D"```M`0``
MJ@```%P"```-````XP8``&0&``!E````,`,``+H$````````Z`,```0'``#A
M!```R`4``*4!``"H`@``2````"\'``#8!```;0(```````"]`P``9@0`````
M``!N!P``:04``*H%``#9!@``:P8```````"I`0``R@,```8```"A`@``N@$`
M`.<#``"1`@``H08``+\```!=`@``TP,``!T````"!@``3`0``,,````&!```
MF`$``'@&``!]`P``WP(```P"```.`0```````.H"````````$00```````""
M!0``A@4```````!*`0``(`8````````3`P``E`8```('``">`@``#@```"8'
M``!4!@```````!8&``!-!0```````'L"``!L`@``/@<``-T&``"6!@``PP4`
M`'0%```U!0``QP```.0&``````````````````!.!P``GP,``"0#````````
M,`$``&T#```,`0``-P,``%\```"U`@```````)<#`````````````,P%``"H
M`````````!L'````("`M32P@+2UM97-S86=E/4U%4U-!1T4@(%5S92!T:&ES
M(&-O;6UI="!M97-S86=E(&EN<W1E860@;V8@=&AE(&1E9F%U;'0@;VYE<RX`
M("`M82P@+2UA9&0]1DE,12`@("`@("`@061D('1H:7,@4$\@9FEL92!T;R!T
M:&4@8V]M<&5N9&EU;2X@57-E9G5L('1O"B`@("`@("`@("`@("`@("`@("`@
M("`@(&EN8VQU9&4@82!C;VUP96YD:75M(&9R;VT@82!D:69F97)E;G0@8G)A
M;F-H('1O"B`@("`@("`@("`@("`@("`@("`@("`@('1H92!G96YE<F%T960@
M8V]M<&5N9&EU;2X`("`M8BP@+2UB87-E/2]0051(("!&=6QL('!A=&@@=&\@
M=&AE("A(;W)D92D@8F%S92!D:7)E8W1O<GD@=&AA="!S:&]U;&0@8F4*("`@
M("`@("`@("`@("`@("`@("!U<V5D+@`@("UC+"`M+6-O;7!E;F1I=6T]1DE,
M12`@365R9V4@;F5W('1R86YS;&%T:6]N<R!T;R!T:&ES(&-O;7!E;F1I=6T@
M9FEL90H@("`@("`@("`@("`@("`@("`@("`@("`@:6YS=&5A9"!O9B!T:&4@
M9&5F875L="!O;F4@*&-O;7!E;F1I=6TN<&\@:6X@=&AE"B`@("`@("`@("`@
M("`@("`@("`@("`@("!H;W)D92]P;R!D:7)E8W1O<GDN`"`@+6,L("TM8V]M
M<&5N9&EU;3U&24Q%("!5<V4@=&AI<R!C;VUP96YD:75M(&9I;&4@:6YS=&5A
M9"!O9B!T:&4@9&5F875L=`H@("`@("`@("`@("`@("`@("`@("`@("`@;VYE
M("AC;VUP96YD:75M+G!O(&EN('1H92!H;W)D92]P;R!D:7)E8W1O<GDI+@`@
M("UD+"`M+61E8G5G("`@("`@(%-H;W<@97)R;W(@;65S<V%G97,@9G)O;2!T
M:&4@97AE8W5T960@8FEN87)I97,N`"`@+60L("TM9&ER96-T;W)Y/41)4B`@
M($-R96%T92!C;VUP96YD:75M(&EN('1H:7,@9&ER96-T;W)Y+@`@("UH+"`M
M+6AE;'`@("`@("`@(%-H;W<@=&AI<R!H96QP(&UE<W-A9V4N`"`@+6PL("TM
M;&]C86QE/6QL7T-#("`@("!5<V4@;VYL>2!T:&ES(&QO8V%L92X`("`M;"P@
M+2UL;V-A;&4];&Q?0T,@("`@(%5S92!T:&ES(&QO8V%L92X`("`M;"P@+2UL
M;V-A;&4];&Q?0T,@("`@57-E('1H:7,@;&]C86QE+@`@("UM+"`M+6UO9'5L
M93U-3T153$4@("`@0G5I;&0@34\@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R
M9&4I(&UO9'5L92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($-L96%N=7`@
M4$\@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M;2P@
M+2UM;V1U;&4]34]$54Q%("`@($-O;6UI="!T<F%N<VQA=&EO;G,@;VYL>2!F
M;W(@=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM;V1U;&4]34]$54Q%
M("`@($-R96%T92!A(%!/(&9I;&4@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO
M9'5L92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($UE<F=E(%!/(&9I;&5S
M(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE
M/4U/1%5,12`@("!5<&1A=&4@:&5L<"!F:6QE<R!O;FQY(&9O<B!T:&ES("A(
M;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L93U-3T153$4@("`@57!D871E
M(&]N;'D@=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM;V1U;&4]34]$
M54Q%("!'96YE<F%T92!03U0@9FEL92!O;FQY(&9O<B!T:&ES("A(;W)D92D@
M;6]D=6QE+@`@("UN+"`M+6YO+6-O;7!E;F1I=6T@("`@1&]N)W0@;65R9V4@
M;F5W('1R86YS;&%T:6]N<R!T;R!T:&4@8V]M<&5N9&EU;2X`("`M;BP@+2UN
M;RUC;VUP96YD:75M("`@($1O;B=T('5S92!A(&-O;7!E;F1I=6TN`"`@+7,L
M("TM<W1A=&ES=&EC<R`@("`@("!3879E('1R86YS;&%T:6]N('-T871I<W1I
M8W,@:6X@82!L;V-A;"!F:6QE+@`@("UT+"`M+71E<W0@("`@("`@(%-H;W<@
M=&AE(&5X96-U=&5D(&-O;6UA;F1S(&)U="!D;VXG="!R=6X@86YY=&AI;F<N
M`"`@8VQE86YU<"`@("`@0VQE86YS('1H92!03R!F:6QE<R!U<"!F<F]M('5N
M=')A;G-L871E9"!A;F0@;V)S;VQE=&4@96YT<FEE<RX`("!C;VUM:70@("`@
M("!#;VUM:70@=')A;G-L871I;VYS('1O('1H92!#5E,@<V5R=F5R+@`@(&-O
M;6UI="UH96QP($-O;6UI="!H96QP(&9I;&5S('1O('1H92!#5E,@<V5R=F5R
M+@`@(&-O;7!E;F1I=6T@(%)E8G5I;&0@=&AE(&-O;7!E;F1I=6T@9FEL92X@
M5V%R;FEN9SH@5&AI<R!O=F5R=W)I=&5S('1H90H@("`@("`@("`@("`@(&-U
M<G)E;G0@8V]M<&5N9&EU;2X`("!E>'1R86-T("`@("!'96YE<F%T92!03R!T
M96UP;&%T92`H+G!O="D@9FEL97,N`"`@:&5L<"`@("`@("`@4VAO=R!T:&ES
M(&AE;'`@;65S<V%G92X`("!I;FET("`@("`@("!#<F5A=&4@;VYE(&]R(&UO
M<F4@4$\@9FEL97,@9F]R(&$@;F5W(&QO8V%L92X@5V%R;FEN9SH@5&AI<PH@
M("`@("`@("`@("`@(&]V97)W<FET97,@=&AE(&5X:7-T:6YG(%!/(&9I;&5S
M(&]F('1H:7,@;&]C86QE+@`@(&UA:V4@("`@("`@($)U:6QD(&)I;F%R>2!-
M3R!F:6QE<R!F<F]M('1H92!S<&5C:69I960@4$\@9FEL97,N`"`@;6%K92UH
M96QP("`@36%R:R!A;&P@96YT<FEE<R!I;B!T:&4@6$U,(&AE;'`@9FEL92!B
M96EN9R!U<"UT;RUD871E(&%N9`H@("`@("`@("`@("`@('!R97!A<F4@=&AE
M(&9I;&4@9F]R('1H92!N97AT(&5X96-U=&EO;B!O9B!U<&1A=&4M:&5L<"X@
M66]U"B`@("`@("`@("`@("`@<VAO=6QD(&]N;'D@<G5N(&UA:V4M:&5L<"!!
M1E1%4B!U<&1A=&4M:&5L<"!A;F0@<F5V:7-I;F<@=&AE"B`@("`@("`@("`@
M("`@:&5L<"!F:6QE+@`@(&UE<F=E("`@("`@($UE<F=E('1H92!C=7)R96YT
M(%!/(&9I;&4@=VET:"!T:&4@8W5R<F5N="!03R!T96UP;&%T92!F:6QE+@`@
M('5P9&%T92`@("`@(%)U;B!E>'1R86-T(&%N9"!M97)G92!S97%U96YT+@`@
M('5P9&%T92UH96QP($5X=')A8W0@86QL(&YE=R!A;F0@8VAA;F=E9"!E;G1R
M:65S(&9R;VT@=&AE($5N9VQI<V@@6$U,(&AE;'`*("`@("`@("`@("`@("!F
M:6QE(&%N9"!M97)G92!T:&5M('=I=&@@=&AE(&5X:7-T:6YG(&]N97,N`"`F
M(S$U,3L@)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+@`@*"5S(&1A>7,@86=O*0`@*$%C
M8V5S<VME>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W
M*0`@*'EE<W1E<F1A>2D`(&%T(``B)7,B(&ES(&YO="!A('9A;&ED(&-H;VEC
M92X`(B5S(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T
M<GDN`"(E<R(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N`"(E<R(@=V%S(&%D
M9&5D('1O('1H92!G<F]U<',@<WES=&5M+@`B)7,B('=A<R!A9&1E9"!T;R!T
M:&4@<&5R;6ES<VEO;G,@<WES=&5M+@`B)7,B('=A<R!N;W0@8W)E871E9#H@
M)7,N`"5D("5S(&%N9"`E<P`E9"!B>71E<R!W<FET=&5N+@`E9"!O9B`E9"!E
M;G1R:65S(&UA<FME9"!A<R!U<"UT;RUD871E`"5D+61A>2!F;W)E8V%S=``E
M<R`M($YO=&EC90`E<R!!9&UI;FES=')A=&EO;@`E<R!&:6YG97)P<FEN=``E
M<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N
M`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M96YT`"5S
M(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!I<R!N;W0@=W)I=&%B
M;&4N`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E
M<R!N;W0@9F]U;F0N(%)U;B`G=')A;G-L871I;VX@97AT<F%C="<@9FER<W0N
M`"5S('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L96YD
M87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"P@9W5S=&EN
M9R``+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M
M+2!S96QE8W0@+2T`+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM`#$R($AO
M=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#Q0<F5V:6]U<P`\
M9V5T=&5X=#X@=&%G(&YO="!C;&]S960@:6X@9FEL92`E<RX*3W!E;FEN9R!T
M86<@9F]U;F0@:6X@;&EN92`E9"X`02!D871A8F%S92!B86-K96YD(&ES(')E
M<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA<R!O8V-U
M<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@
M82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E
M<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV
M871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D
M96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!0
M1U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A
M(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@
M82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-
M12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@
M;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N
M8W)Y<'0@82!M97-S86=E+@!!32!#;&]U9',`04T@3&EG:'0@4F%I;@!!32!2
M86EN`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W97)S`$%-+U!-`$%022!)1`!!
M8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B;W1T;VT`06)S;6ED9&QE
M`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2X`06-C97-S
M(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`06-C;W5N="!087-S=V]R9`!!
M8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`061D($-H:6QD($=R;W5P
M`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P
M`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!G<F]U<"!T;R`B)7,B
M`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@(B5S(@!!9&0@82!N97<@=7-E
M<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D('!A:7(`061D('1H
M92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!T;R!A9&1R97-S
M(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D('5S97(`061D960@
M(B5S(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO
M;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N`$%D9&5D("(E<R(@=&\@=&AE
M('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+@!!9&1I;F<@;F5W(&9I;&5S
M('1O(')E<&]S:71O<GDZ`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D
M<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N
M<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S`$%F9VAA;FES
M=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&EG;FUE;G0Z`$%L
M;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M
M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT:7!L92!A9&1R97-S
M97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR96%D
M>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@
M4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N871E(&5M
M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E<FYA=&4@=&5X
M=#H`06UE<FEC86X@4V%M;V$`06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF
M:65D+@!!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+@!!;F1O<G)A`$%N
M9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`06YS=V5R`$%N=&%R8W1I
M8V$`06YT:6=U82!A;F0@0F%R8G5D80!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO
M;B!I<R!R96%D>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P
M<F]X:6UA=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C
M:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@
M=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R
M92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@(B5S(B!A;F0@86YY('-U
M8BUG<F]U<',_`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!4DU30TE)
M+3@I`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L86YD`$%S8VEI($%R=`!!<VEA
M+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D
M;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O;'5M
M;G,`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T
M=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T
M=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E
M;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I8G5T97,`
M075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E
M9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME
M;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C
M>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I
M;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA
M<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR
M8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L
M9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?
M;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE
M('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S
M97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T
M:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I
M;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R
M=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`079A
M:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"3T9(($5X8W5S97,`0F%C:V=R
M;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`
M0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC
M("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!"87-E;&EN90!"
M96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I
M<G1H9&%Y`$)L;V-K("(E<R(@;V8@87!P;&EC871I;VX@(B5S(B!N;W0@9F]U
M;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0F]L9`!";VQI=FEA`$)O
M;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!";W-N
M:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A;F$`0F]T=&]M`$)O=79E
M="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R
M>0!"<G5N96D@1&%R=7-S86QA;0!"=6EL9&EN9R!-3R!F:6QE<R!F;W(@;6]D
M=6QE("5S+BXN`$)U:6QD:6YG(&QO8V%L92`E<RXN+B``0G5L9V%R:6$`0G5L
M;&5T960@3&ES=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#`$-23"!$
M:7-T<FEB=71I;VX@4&]I;G1S`$-?96QL(%!R;W!E<G1I97,N+BX`0V%C:&4@
M:6YI="!W87,@;F]T(&-O;7!L971E9"X`0V%L96YD87(`0V%L;0!#86UB;V1I
M80!#86UE<F]O;@!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L
M;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86XG="!C;VYN96-T
M('1O($E-05`@<V5R=F5R.B`E<P!#86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B
M;&5M(%)E<&]R=`!#86YN;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I
M;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@<')O8V5E9"!W:71H
M;W5T("=T87)G971&:6QE)R!P87)A;65T97(N`$-A;FYO="!R96UO=F4@9&ER
M96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T
M+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@
M9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R('-T;W)E9"X`0V%N
M;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BX`0V%P92!6
M97)D90!#87!T:6]N`$-A=&5G;W)I97,@86YD($QA8F5L<P!#87EM86X@27-L
M86YD<P!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z
M`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;&QP:&]N90!#96QT
M:6,@*$E33RTX.#4Y+3$T*0!#96YT97(`0V5N=')A;"!!9G)I8V%N(%)E<'5B
M;&EC`$-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E
M($1E=&%I;',`0V5R=&EF:6-A=&4@3W=N97(`0V5R=&EF:6-A=&4@4&]L:6-I
M97,`0VAA9`!#:&%N9V4`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H
M870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U
M<B!E;6%I;',N`$-H87(`0VAE8U]K($QI;FLN+BX`0VAE8VL@=&AE(&)O>"!F
M;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H
M:7,@=&EM92X`0VAI;&4`0VAI;F$`0VAI;F5S92!3:6UP;&EF:65D("A'0C(S
M,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I`$-H;V]S92!A('!A<W-W
M;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D
M871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES
M=',I`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N
M;W0@9F]U;F0N`$-L96%N:6YG('5P(%!/(&9I;&5S(&9O<B!M;V1U;&4@)7,N
M+BX`0VQE86YI;F<@=7`@;&]C86QE("5S+BXN(`!#;&5A<@!#;&5A<B!-4T]F
M9FEC92!T86=S`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R
M('5S97(@9&%T80!#;&5A<FEN9R!,871E`$-L:6-K('1O($-O;G1I;G5E`$-L
M:6-K871E;&P@=FEA($A45%``0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U9',@
M16%R;'D`0VQO=61Y`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E
M(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E<G,`0V]L;VUB:6$`0V]L;W(`0V]L
M;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L<SH`0V]L=6UN('1I=&QE
M<P!#;VUI8W,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UA;F0@;W!T:6]N
M<SH`0V]M;6%N9',Z`$-O;6UE;G0`0V]M;6ET=&EN9SH`0V]M;6]N($YA;64`
M0V]M;W)O<P!#;VUP86YY`$-O;7!O<V4@365S<V%G92`H)7,I`$-O;7!U=&5R
M<P!#;VYD:71I;VX`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N
M8V5S`$-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N`$-O;F9I9W5R92`E
M<P!#;VYF:7)M(%!A<W-W;W)D`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I
M8R!297!U8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I
M;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K
M97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S
M97)V97(@9F%I;&5D+@!#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E
M9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&5N="!T>7!E(&]F(&-O;7!R
M97-S960@9FEL93H@`$-O;G1E;G1S(&]F("(E<R(`0V]N=&EN=64`0V]O:R!)
M<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@<V5L96-T:6]N`$-O<'EI;F<@)7,@
M=&\@)7,`0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O=6QD(&YO="!01U`@
M96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92X`
M0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3
M+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S
M`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8VAE
M8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("(E
M<R(@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@8V]P>2`E<R!T;R`E<P!#;W5L
M9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@
M8W)E871E(&QO8V%L92!D:7)E8W1O<GD@9F]R(&QO8V%L92`E<SH`0V]U;&0@
M;F]T(&1E8W)Y<'0@4$=0(&1A=&$N`$-O=6QD(&YO="!D96-R>7!T(%,O34E-
M12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO
M="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96QE
M=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`0V]U;&0@;F]T(&1E=&5R
M;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO
M="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F971C
M:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H
M('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U
M;&0@;F]T(&QO860@<W1R871E9WD@(B5S(BX`0V]U;&0@;F]T(&UK9&ER("(E
M<R(N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES
M97)V97(N`$-O=6QD(&YO="!O<&5N("(E<R(@9F]R('=R:71I;F<N`$-O=6QD
M(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K
M(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@(B5S(BX`0V]U
M;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@
M9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E
M=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#
M;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R
M97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T
M<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE
M<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!R
M;61I<B`B)7,B+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#
M;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO
M="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U;&0@;F]T('-A
M=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`$-O=6QD(&YO="!S
M879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N
M;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I
M=&AE<B!U<V4@;VYE(&]F('1H92!O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@
M8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O
M("5S+@!#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@
M;F]T('5N;&EN:R`B)7,B+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S
M`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD
M(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B`B)7,B.B`E<P!#;W5L9&XG
M="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED
M96)A<B!I<R!O<&5N+@!#;W5L9&XG="!G:79E('5S97(@(B5S(B!T:&4@9F]L
M;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B.B`E<P!#;W5N=&5D
M('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@82!L:6YK`$-R
M96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S`$-R96%T;W(@4&5R
M;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R
M96YT(#0@4&AA<V5S`$-U<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#=7)R
M96YT(%=E871H97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE
M`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T
M`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL
M;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5
M*0!#>F5C:"!297!U8FQI8P!$1`!$86EL>0!$871A5')E92!"<F]W<V5R`$1A
M=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5?;&5T92!#
M;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E($EN9&5N
M=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969A
M=6QT(%!E<FUI<W-I;VYS`$1E9F%U;'0@<&5R;6ES<VEO;G,`1&5F:6YI=&EO
M;G,`1&5L971E`$1E;&5T92!'<F]U<`!$96QE=&4@4&5R;6ES<VEO;@!$96QE
M=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C;VQU
M;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@
M<&5R;6ES<VEO;G,@9F]R("(E<R(`1&5L971E('!E<FUI<W-I;VYS(&9O<B`G
M)7,G(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@<F]W`$1E;&5T
M92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN
M`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L971E('1H:7,@<&5R;6ES<VEO
M;B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E9"!S971U<"!U<&=R
M861E('-C<FEP="`B)7,B+@!$96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5S8W)I
M8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(
M;W)D92=S(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R
M('1H92!A9&UI;FES=')A=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`1&5W
M(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@
M;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O
M<GD`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES
M<&QA>2!D971A:6QE9"!F;W)E8V%S=`!$:7-P;&%Y(&9O<F5C87-T("A4048I
M`$1I<W!L87D@9F]R;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB
M;W5T:0!$;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I
M;G1E;F%N8V4N<&AP`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F
M:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`
M1&]M:6YI8V%N(%)E<'5B;&EC`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL
M;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1R
M;W`@9&]W;B!L:7-T`$1R=6=S`$4M36%I;`!%4E(`16-U861O<@!%9&ET`$5D
M:70@0FQO8VL`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M
M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@
M9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO
M;G,@9F]R("5S`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT
M+BXN`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU
M<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M;W1I8V]N<P!%
M;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M
M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE
M<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU
M/P!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U
M97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O
M(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@
M;V8@>6]U<B!P970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5N=')I
M97,Z("5D('1O=&%L+"`E9"!U<"UT;RUD871E+"`E9"!N97<L("5D(&-H86YG
M960L("5D('5N:VYO=VX`17%U871O<FEA;"!'=6EN96$`17)I=')E80!%<G)O
M<@!%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N`$5R<F]R('=R:71I;F<@(B5S
M(BX`17)R;W(Z(`!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E
M<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD
M<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R
M`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>&5C=71I
M;F<Z`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%>'!E8W1E9"`G*2<`17AP96-T
M960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N
M($1A=&4`17AP;VYE;G0`17AT<F%C=&EN9R!F<F]M("5S+BXN(`!&1R!#;VQO
M<@!&5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE9"!R971R:65V:6YG('!R969E
M<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I
M;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D('1O(&-O<'D@
M9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B)7,B+@!&86EL960@=&\@
M8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T;R!M;W9E('1O
M("(E<R(N`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E
M($ES;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&96)R=6%R>0!&965L<R!,:6ME
M`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R<P!&97<@4VYO=R!3:&]W97)S`$9I
M96QD(&UA=')I>`!&:6II`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N
M=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C
M=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`
M1FEL=&5R<P!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&:7@@
M<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T
M`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P
M;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN;W1E
M('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@
M86YD(&YI9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I
M;B!A('=I9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&
M;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M
M<P!&;W)W87)D<P!&;W5N9"!A<'!L:6-A=&EO;G,Z("5S`$9O=6YD(&1I<F5C
M=&]R:65S.@!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI=&%N
M`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U=&AE
M<FX@5&5R<FET;W)I97,`1G)O;0!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO
M;@!&=6QL($UO;VX`1G5L;"!.86UE`$9U>GIY`$=A8F]N`$=A;&QE<GD@=&\@
M=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=A;6)I80!'96YE<F%T92`E<R!#
M;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E;F5R871I;F<@<W1A='5S
M(&9O<B!M;V1U;&4@)7,N+BX`1V5O<F=I80!'97)M86YY`$=E=&]P="!%<G)O
M<CH@`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=O`$=O961E;`!';V]G
M;&4@4V5A<F-H`$=R87ES8V%L90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I
M`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P
M(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P('!E<FUI<W-I;VYS`$=R
M;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T
M(%!E<FUI<W-I;VYS`$=U97-T('!E<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN
M96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!C;W=A<F1L
M>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RX`2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L
M=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E
M;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@075T:&5N=&EC871I
M;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R:71H;0!(87IE`$AE861E
M<@!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`2&5A=GD@5"U3
M=&]R;0!(96)R97<@*$E33RTX.#4Y+3@M22D`2&5I9VAT`$AE;'``2&5L<"!U
M<VEN9R!E9&ET;W(`2&5L<&5R`$AE;'!E<B!A<'!L:6-A=&EO;B!T;R!C<F5A
M=&4@86YD(&UA:6YT86EN('1R86YS;&%T:6]N<R!F;W(@=&AE($AO<F1E"F9R
M86UE=V]R:R!A;F0@:71S(&%P<&QI8V%T:6]N<RX*1F]R(&%N(&EN=')O9'5C
M=&EO;B!R96%D('1H92!F:6QE(%)%041-12!I;B!T:&ES(&1I<F5C=&]R>2X`
M2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z
M`$AI9V@`2&ES=&]R>2!E;G1R>2!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!(
M;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@
M061D<F5S<P!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(
M;W)D92!T<F%N<VQA=&EO;B!G96YE<F%T;W(`2&]R9&4O2V]L86(Z($EN=F%L
M:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D
M92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`
M2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE
M<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S
M("(E<R(`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!S>6YC:')O;FES960@
M)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R
M97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+;VQA
M8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E
M<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B)7,B.B`E<P!(
M;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H
M92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC
M:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y
M;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA
M<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO
M<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R
M="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_
M`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N
M>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI
M9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-05`@;6%I;&)O>"!C<F5A=&EO
M;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S
M`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S`$E0($%D
M9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO
M="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V:6]L
M871I;VXN`$E?;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC;VYS($]N;'D`
M26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M93H`268@:70@:7,@;F]T
M(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@
M=VEN9&]W+@!)9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E
M<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K('1H:7,@8F]X
M('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN`$EF('EO=2!S964@=&AI
M<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O
M('5P;&]A9"!C86XG="!B92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+@!)
M;6%G92!0<F5V:65W.@!);6%G92!54DP`26UA9V4@55),.@!);6%G92!F<F]M
M(&=A;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y.@!);6%G92!U<&QO860`26UA
M9V5S`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T
M960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E<@!);F-O<G)E8W0@86-T:6]N
M(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O
M<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@
M5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO
M=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT`$EN9&EA`$EN
M9&EV:61U86P@57-E<G,`26YD;VYE<VEA`$EN9F\`26YF;W)M871I;VX`26YF
M;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92X`26YI=&EA;&EZ:6YG(&UO
M9'5L92`E<RXN+B``26YS97)T($-?;VQU;6X@069T97(`26YS97)T($EM86=E
M`$EN<V5R="!486)L90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@
M0F5F;W)E`$EN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@
M;VYE`$EN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N
M90!);G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E
M<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@
M<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R
M86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA
M=&4@=&5M<&QA=&4`26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@
M>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL
M(&%F=&5R`$EN<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R
M`$EN<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R="!M97-S86=E<P!);G-E<G0@
M<&%R86=R87!H(&%F=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN<V5R
M="!R;W<@869T97(`26YS97)T(')O=R!B969O<F4`26YS97)T('1H92!R97%U
M:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.@!);G-E<G0O
M36]D:69Y($EM86=E`$EN<V5R="]-;V1I9GD@3&EN:P!);G-U9F9I8VEE;G0@
M8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!);G-U
M9F9I8VEE;G0@8W)E9&ET+@!);G1E9V5R`$EN=&5G97(@;&ES=`!);G9A;&ED
M(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!);G9A;&ED(%I)4"!D871A`$EN
M=F%L:60@87!P;&EC871I;VXN`$EN=F%L:60@8F%T8V@@240N`$EN=F%L:60@
M9&%T82!S=6)M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`
M26YV86QI9"!F:6QE(&9O<FUA=`!);G9A;&ED(&QI8V5N<V4@:V5Y+@!);G9A
M;&ED(&QO8V%T:6]N('!R;W9I9&5D+@!);G9A;&ED(&US9U]T>7!E+@!);G9A
M;&ED(&]R(&UI<W-I;F<@87!I7VED+@!);G9A;&ED(&]R(&UI<W-I;F<@<&%R
M86UE=&5R<RX`26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P
M87)T;F5R(&ED+@!);G9A;&ED('!R;V1U8W0@8V]D92X`26YV86QI9"!P<F]T
M;V-O;"X`26YV86QI9"!R96-I<&EE;G0Z("(E<R(`26YV86QI9"!S:&%R92!O
M8FIE8W0`26YV86QI9"!S;W5R8V4@861D<F5S<RX`26YV86QI9"!U;FEC;V1E
M(&1A=&$N`$EN=F5N=&]R>0!)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F`$ER
M87$`27)E;&%N9`!)<VQE(&]F($UA;@!)<V]L871E9"!4+5-T;W)M<P!)<W)A
M96P`27-S=65R`$ET86QI8P!)=&%L>0!*86UA:6-A`$IA;G5A<GD`2F%P86X`
M2F%P86YE<V4@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N`$IU;'D`2G5N
M90!*=7-T:69Y`$IU<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y
M($QE9G0`2G5S=&EF>2!2:6=H=`!+87IA:VAS=&%N`$ME97`@;W)I9VEN86P_
M`$ME;GEA`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO
M;BX`2V5R;F5L($YE=V)I97,`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN
M=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@86QR96%D>2!E
M>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$MI9',`2VER:6)A=&D`
M2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L
M(%)E<'5B;&EC(&]F`$MO<F5A;B`H155#+4M2*0!+=7=A:70`2WER9WEZ<W1A
M;@!,85]Y;W5T`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E
M<'5B;&EC`$QA<W0@2&%L9@!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,
M87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G
M:6XZ($YE=F5R`$QA='9I80!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N
M;R!B;W)D97(`3&5B86YO;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S
M`$QE<V]T:&\`3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI96-H
M=&5N<W1E:6X`3&EG:'0@1')I>GIL90!,:6=H="!286EN`$QI9VAT(%)A:6X@
M16%R;'D`3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A:6X@4VAO=V5R`$QI9VAT
M(%)A:6X@=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`3&EG:'0@4VYO=R!3:&]W
M97(`3&EM97)I8VL`3&EN:P!,:6YK('!O:6YT<R!T;SH`3&EN:R!T:&4@96UA
M:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN
M9P!,:6YK<P!,:6YU>"!#;V]K:64`3&ES="`M('5S97(@8V%N('-E92!T:&4@
M9F]L9&5R`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!4
M86)L97,`3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N
M97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`
M3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N
M:6$`3&]A9&EN9R!L:6)R87)I97,N+BX`3&]A9&EN9RXN+@!,;V-A;"!T:6UE
M.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@;W5T`$QO
M9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@
M;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN(&9A
M:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE='1E<G,`
M3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$QU>&5M
M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO
M(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L
M878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I8P!-86EL`$UA:6P@061M
M:6X`36%K92!L:6Y?:RXN+@!-86ME('-U<F4@=&AA="!Y;W4@:&%V92!014%2
M(&EN<W1A;&QE9"!A;F0@:6X@>6]U<B!I;F-L=61E('!A=&@N`$UA:VEN9R!D
M:7)E8W1O<GD@)7,`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%L
M=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@
M;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@
M=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-87)C
M:`!-87)G:6X`36%R:R!W:71H(%-E96XO56YS965N(&9L86=S`$UA<FL@=VET
M:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I`$UA<G-H
M86QL($ES;&%N9',`36%R=&EN:7%U90!-871C:&EN9R!F:65L9',`36%U<FET
M86YI80!-875R:71I=7,`36%X(&%L;&]W960@8W)E9&ET+@!-87@@;65S<V%G
M92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA
M>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@;&5N9W1H`$UA>0!-87EO
M='1E`$UE9&EC:6YE`$UE;6)E<G,`365N=2!M;V1E.@!-97)G92!C96QL<P!-
M97)G:6YG(&%L;"`E<RYP;R!F:6QE<R!T;R!T:&4@8V]M<&5N9&EU;2XN+B``
M365R9VEN9R!L;V-A;&4@)7,N+BX@`$UE<F=I;F<@=&AE(%!/(&9I;&4@9F]R
M("5S('1O('1H92!C;VUP96YD:75M+BXN(`!-97)G:6YG('1R86YS;&%T:6]N
M(&9O<B!M;V1U;&4@)7,N+BX`365S<V%G90!-97-S86=E(%9E<FEF:65D(%-U
M8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD
M(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E>'!I<F5D+@!-97-S86=E('1Y
M<&4`365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-
M971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L
M;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971A<D1"(&ES(&YO="!C
M;VYN96-T960N`$UE=&AO9`!-971H;V0@(B5S(B!I<R!N;W0@9&5F:6YE9`!-
M971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8`
M36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``36EN
M('1E;7`@;&%S="`V(&AO=7)S.B``36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES
M<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O;F9I
M9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@
M=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E
M($E$+@!-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S
M:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF
M:65D($1A=&4`36]D:69Y(%523`!-;V1U;&4`36]D=6QU<P!-;VQD;W9A+"!2
M97!U8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N=&@@86YD('EE87(`36]N
M=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO<F]C8V\`36]S=&QY($-L
M96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY(%-U;FYY`$UO=F4@1&]W;@!-;W9E
M($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E('5P`$UO
M>F%M8FEQ=64`375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S`$UU;'1I<&QE
M('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y
M;W5T`$UY86YM87(`3D\L($D@1&\@3D]4($%G<F5E`$YA;64`3F%M:6)I80!.
M875R=0!.97!A;`!.971H97)L86YD<P!.971H97)L86YD<R!!;G1I;&QE<P!.
M971S8V%P92!"87-E(%523`!.971S8V%P92!#02!2979O8V%T:6]N(%523`!.
M971S8V%P92!#02!P;VQI8WD@55),`$YE='-C87!E(%)E;F5W86P@55),`$YE
M='-C87!E(%)E=F]C871I;VX@55),`$YE='-C87!E(%-33"!S97)V97(@;F%M
M90!.971S8V%P92!C97)T:69I8V%T92!C;VUM96YT`$YE='-C87!E(&-E<G1I
M9FEC871E('1Y<&4`3F5T=V]R:P!.979E<@!.97<@0V%L961O;FEA`$YE=R!#
M871E9V]R>0!.97<@36]O;@!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@
M6F5A;&%N9`!.97<@=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5W<V=R;W5P<P!.
M97AT`$YE>'0@-"!0:&%S97,`3F5X="!O<'1I;VYS`$YE>'0^`$YI8V%R86=U
M80!.:6=E<@!.:6=E<FEA`$YI9VAT`$YI=64`3F\`3F\@879A:6QA8FQE(&-O
M;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@
M879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RX`3F\@
M8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S
M=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#
M04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@8VAI;&0@<&5R;6ES
M<VEO;G,@87)E('1O(&)E(&%D9&5D(&)E;&]W('1H:7,@;&5V96PN`$YO(&-H
M:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O
M;6UA;F0@<W!E8VEF:65D+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`
M3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T:6]N('-U<'!L:65D+@!.;R!E
M;G1R>2!W:71H('1H92!I9"`B)7,B(&5X:7-T<R!I;B!T:&4@;W)I9VEN86P@
M:&5L<"!F:6QE+@!.;R!F:6QE('5P;&]A9&5D`$YO(&QO8V%L92!S<&5C:69I
M960N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;&]C871I;VX@<')O=FED960N
M`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N
M=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,1$%0(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I
M;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC
M871I;VXN`$YO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D
M+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O('=O<FL@=VET
M:"!02T-3(#$R(&1A=&$N`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@<G5L97,`
M3F\@<VED97,`3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R
M(&-A8VAE+@!.;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@
M=F%L:60@6$U,(&1A=&$@<F5T=7)N960`3F\@=F%L=65S`$YO('9E<G-I;VX@
M9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C
M;VYF:6=U<F%T:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG
M=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;VYE`$YO;F4@
M*'5S92!I;7!L:6-I="D`3F]R9&EC("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!)
M<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R;B!-87)I86YA($ES
M;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E`$YO="!A(&1I<F5C
M=&]R>0!.;W0@:6UP;&5M96YT960N`$YO="!S970`3F]T('-U<'!O<G1E9"X`
M3F]T97,`3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO=&EC90!.;W9E
M;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O
M;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O
M<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J96-T`$]B
M:F5C="!#<F5A=&]R`$]B:F5C="!C<F5A=&]R('!E<FUI<W-I;VYS`$]C=&%L
M`$]C=&]B97(`3V9F96YS92!F:6QT97(`3V9F:6-E`$]M86X`3VYL>2!)34%0
M('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!O9F9E;G-I
M=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+@!/
M;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA
M;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R
M90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R.B!#;W5L9"!N
M;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+@!/<&5N
M<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T96T`
M3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<'1I;VYS.@!/<F1E<F5D($QI<W0`
M3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/
M<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T
M97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E<FUI
M<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!0
M1U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0
M=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D($1A=&$`4$A0($-O9&4`
M4$A0(%-H96QL`%!-($QI9VAT(%)A:6X`4$T@4VAO=V5R<P!032!3;F]W`%!-
M(%-N;W<@4VAO=V5R<P!032!3=6X`4$T@5"U3=&]R;7,`4%](4"!3:&5L;`!0
M861D:6YG`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@
M3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`4&%R
M=&QY($-L;W5D>0!087-S=V]R9`!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O
M<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BX`4&%S<W=O
M<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S
M<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D
M`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N=`!097)F;W)M
M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O
M<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VX@(B5S
M(B!N;W0@9&5L971E9"X`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R
M;6ES<VEO;G,@9F]R`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G4`4&5T<P!0
M:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`4&ET8V%I<FX`4&EX96QS`%!L871I
M='5D97,`4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L96%S92!C;VYF
M:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#H`4&QE
M87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M
M96YT+@!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@
M96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT
M97(@82!V86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT97(@82!V86QI9"!D
M871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0
M;&5A<V4@96YT97(@82!V86QI9"!T:6UE+@!0;&5A<V4@<')O=FED92!A('-U
M;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E
M<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!R96%D('1H92!F;VQL;W=I;F<@
M=&5X="X@(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T
M:&4@<WES=&5M+@!0;&5A<V4@<F5P;W)T(&%N>2!B=6=S('1O(&DQ.&Y`;&ES
M=',N:&]R9&4N;W)G+@!0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA
M;64Z`%!O;&%N9`!0;VQI=&EC<P!0;VQL<P!0;W)T=6=A;`!0;W-I=&EO;FEN
M9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4`4&]S
M="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I`%!R96-I
M<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@`%!R96-I<&ET871I;VX\
M8G(@+SYC:&%N8V4`4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R97-S=7)E`%!R97-S=7)E(&%T('-E
M82!L979E;#H@`%!R97-S=7)E.B``4')E=FEE=P!0<F5V:65W('1H92!I;6%G
M92!I;B!A(&YE=R!W:6YD;W<`4')E=FEO=7,@;W!T:6]N<P!0<FEN="!D;V-U
M;65N=`!0<FEV871E($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`
M4')O:F5C=',`4')O;7!T('1E>'0`4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L
M9V]R:71H;0!0=6)L:6,@2V5Y($EN9F\`4'5B;&EC+U!R:79A=&4@:V5Y<&%I
M<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`4'5E<G1O(%)I8V\`46%T
M87(`475E<GD`4E-!(%!U8FQI8R!+97D@*"5D(&)I="D`4F%D:6\@<V5L96-T
M:6]N`%)A:6X`4F%I;B!%87)L>0!286EN($QA=&4`4F%I;B!3:&]W97(`4F%I
M;B!A;F0@4VYO=P!286EN('1O(%-N;W<`4F%N9&]M($9O<G1U;F4`4F%T:6\`
M4F5A9`!296%D(&UE<W-A9V5S`%)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E
M<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E86QL>2!R96UO=F4@=7-E<B!D
M871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD
M;VYE+@!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H($1Y;F%M:6,@
M365N=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G97@`4F5L
M871I;VYS:&EP($)R;W=S97(`4F5M87)K<P!296UO=&4@4V5R=F5R<P!296UO
M=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E
M`%)E;6]V92!";&]C:P!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG
M`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G
M<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T:&ES
M(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S
M97(Z("5S`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D
M(&5R<F]R8V]D93H@`%)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F
M;W5N9"X`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I
M9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!61E,@
M8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN
M(&-O;F9I9W5R871I;VXN`%)E<75I<F5D($9I96QD`%)E<V5T`%)E<V5T(%!A
M<W-W;W)D`%)E<V5T(%EO=7(@4&%S<W=O<F0`4F5S=6QT<P!297-U;'1S("AI
M;F-L=61I;F<@2&]R9&4I.@!297-U;'1S.@!2971U<FX@=&\@3W!T:6]N<P!2
M975N:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@
M3W!T:6]N<P!2:61D;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU
M97,`4F]?=R!0<F]P97)T:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P
M`%)O=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@
M<')O<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W
M965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R(&)E
M='=E96X@8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@
M<F]W<R!O;FQY`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O34E-
M12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP=&5D($UE
M<W-A9V4`4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!3
M35,@365S<V%G:6YG`%-13"!3:&5L;`!34T@`4U5#0T534P!37U%,(%-H96QL
M`%-A`%-A:6YT($AE;&5N80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@
M3'5C:6$`4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT
M(&%N9"!T:&4@1W)E;F%D:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`
M4V%N($UA<FEN;P!386\@5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R
M;W9I9&5R`%-A=61I($%R86)I80!3879E`%-A=F4@)7,`4V%V92`G)7,G`%-A
M=F4@3W!T:6]N<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@
M4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O
M<GDN`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A
M9&4@<V-R:7!T('1O.B`B)7,B+@!38V%T=&5R960@5"U3=&]R;7,`4V-I96YC
M90!396%R8V@`4V5A<F-H($5N9VEN97,`4V5A<F-H:6YG($AO<F1E(&%P<&QI
M8V%T:6]N<R!I;B`E<P!396%R8VAI;F<@9V5T=&5X="!B:6YA<FEE<RXN+@!3
M96QE8W0@1FEL97,`4V5L96-T(&$@9&%T90!396QE8W0@82!G<F]U<"!T;R!A
M9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E<@!396QE8W0@
M82!U<V5R('1O(&%D9`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L
M96-T(&%N(&]B:F5C=`!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@
M9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P
M87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E
M(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H
M92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM
M92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T
M=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N
M`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M
M(%)E<&]R=`!396YD(%--4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!3
M97)B:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397)V97(@9&%T
M82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+@!397-S:6]N($E$(&5X<&ER960N
M`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P
M87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R96UO=&4@
M<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R
M=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N
M9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL
M(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES
M<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C<FEP=',@879A
M:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A
M<F%M971E<CH@`%-E>6-H96QL97,`4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3
M:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`
M4VAO=P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D
M(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@
M;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O<'1I;VX@
M=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('1A8FQE(&]P97)A
M=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_
M`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T
M:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4F]W
M(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@
M9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R<R!%87)L>0!3:&]W
M97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@5FEC:6YI='D`4VAR:6YK`%-H<FEN
M:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A
M>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N('5P(&EF(&YO="!R
M96=I<W1E<F5D`%-I9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I;F=A
M<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VMI<'!E9"XN+@!3;&]V86MI
M80!3;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R`%-N;W<@4VAO=V5R<P!3;F]W
M(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W97)S($QA=&4`4VYO=R!D97!T:#H@
M`%-N;W<@97%U:79A;&5N="!I;B!W871E<CH@`%-O;&]M;VX@27-L86YD<P!3
M;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U
M<F-E(&%D9')E<W,`4V]U=&@@069R:6-A`%-O=71H($5U<F]P96%N("A)4T\M
M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@
M27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@861J
M86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@
M:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P
M86EN`%-P86T`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!L:70@8V5L;`!3
M<&QI="!C;VQU;6X`4W!L:70@<F]W`%-P;W)T<P!3<FD@3&%N:V$`4W1A;F1A
M<F0`4W1A<B!4<F5K`%-T87)T('EE87(`4W1A=&4@;W(@4')O=FEN8V4`4W1A
M='5S`%-T871U<R!F;W(@;&]C86QE("5S+BXN(`!3=&]R86=E(&9O<FUA=`!3
M=')E970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP
M(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=`%-U`%-U8FIE
M8W0`4W5B;6ET`%-U8FUI='1E9"!R97%U97-T('1O(&%D9"`B)7,B('1O('1H
M92!S>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y;W5R(')E<75E
M<W0@:&%S(&)E96X@87!P<F]V960N`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E
M<W-F=6QL>2!A9&1E9"`B)7,B('1O('1H92!S>7-T96TN`%-U8V-E<W-F=6QL
M>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TN
M`%-U8V-E<W-F=6QL>2!D96QE=&5D("(E<R(N`%-U8V-E<W-F=6QL>2!R96UO
M=F5D("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@<F5V97)T
M960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3=6-C
M97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F
M=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`
M4W5C8V5S<V9U;&QY('5P9&%T960@(B5S(@!3=6-C97-S9G5L;'D@=W)O=&4@
M)7,`4W5D86X`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U;G)I
M<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3
M=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@
M86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y
M;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L
M:6,`5"U3=&]R;0!4+5-T;W)M(&%N9"!7:6YD>0!4+5-T;W)M<P!4+5-T;W)M
M<R!%87)L>0!44U8@9FEL90!486)L90!486)L92!0<F]P97)T:65S`%1A8FQE
M('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`
M5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E
M=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z
M(`!496UP97)A='5R90!496UP97)A='5R93H@`%1E;7!E<F%T=7)E/&)R("\^
M*"5S2&DE<R\E<TQO)7,I("9D96<[)7,`5&5M<&QA=&4@(B5S(B!N;W0@9F]U
M;F0N`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1E
M>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I("A425,M-C(P*0!4:&%I;&%N9`!4
M:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN`%1H92`E<R!H96QP(&9I
M;&4@9F]R("5S(&1O97-N)W0@>65T(&5X:7-T+B!#<F5A=&EN9R!A(&YE=R!O
M;F4N`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(
M;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R
M="`B)7,B`%1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N
M`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S
M9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N
M`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA
M;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!0
M97)M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&-O;G1A8W0@
M240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A
M<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@
M<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@
M9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V
M97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI
M<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R
M(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@
M;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R
M97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&9I;&4@
M)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL92`E<R!S
M:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL92!C86X@
M;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@8V]N=&%I;F5D
M(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T
M:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F=6QL('-C<F5E;B!M
M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@
M17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T
M(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A
M<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O
M<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T96T@:7,@
M5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A
M("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O
M="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@3TL@
M:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET
M;W(N`%1H92!H96QP(&9I;&4@)7,@9&ED;B=T('-T87)T('=I=&@@/#]X;6P`
M5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&QE9G0M
M:&%N9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA
M<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H
M92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T("(E<R(@
M:&%S(&)E96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T
M('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"X`5&AE
M(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E
M`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E
M7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E<R(@8V]U
M;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE
M(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V
M:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@
M<WES=&5M+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG
M:'0M:&%N9"!S:61E(&]N;'D`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E
M;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE('-I
M9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@<W!E
M8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="X`5&AE('1E;7!O<F%R>2!F:6QE
M("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H92!T;W`@86YD(&)O='1O;2!S:61E
M<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!U<&QO861E9"!D871A('=A
M<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4:&4@=7!L;V%D960@
M9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!W96%T:&5R+F-O;2!B;&]C
M:R!I<R!N;W0@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I
M;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y
M960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T
M:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[('EO
M=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@9&]E<VXG="!Y970@
M97AI<W0@82!H96QP(&9I;&4@9F]R("5S+@!4:&5R92!W87,@82!P<F]B;&5M
M(&%D9&EN9R`B)7,B('1O('1H92!S>7-T96TZ("5S`%1H97)E('=A<R!A('!R
M;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y
M<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@(B5S(B!F<F]M
M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG("(E
M<R(Z("5S`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO
M860Z($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W
M:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T
M:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S
M(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O
M;FQY('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I
M<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@97)R
M;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S(&%N
M(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U
M(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O
M<B!O<&5N:6YG('1H92!F:6QE("5S+B!4<GD@<G5N;FEN9R!T<F%N<VQA=&EO
M;BYP:'`@=VET:"!T:&4@9FQA9R`M9"!T;R!S964@86YY(&5R<F]R(&UE<W-A
M9V5S(&9R;VT@=&AE('AM;"!P87)S97(N`%1H97)E('=A<R!A;B!E<G)O<B!P
M97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N
M+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I
M;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T
M<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AI<R!)
M34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`
M5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV
M92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL
M92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB
M97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H
M<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H
M:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10
M($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V
M:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2!G871E=V%Y+"!O
M;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL
M(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N
M:70I+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N
M;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@;75S="!B92!A
M(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S`%1H
M:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M
M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA
M="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O<FT@:&%S(&%L<F5A
M9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+;VQA
M8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W
M:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE
M($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E
M;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UE<W-A9V4@=V%S
M('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y
M;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H
M:7,@<V-R:7!T(&UU<W0@8F4@<G5N(&9R;VT@=&AE(&-O;6UA;F0@;&EN92X`
M5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL
M97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"X`5&AI
M<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E
M(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H=6YD97(`5&EC:V5T
M<P!4:6UE`%1I;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM92!S96QE8W1I
M;VX`5&EM;W(M3&5S=&4`5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4;P!4;R!S
M96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H
M4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!4;V1A
M>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME;&%U`%1O;6]R<F]W`%1O
M;F=A`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1R86YS;&%T960`5')A;G-L871I
M;VYS`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS90!4=0!4=6YI
M<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`
M5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@8VAO
M:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DP@9F]R('EO=7(@<V-R:7!T(&1E
M;&EV97)Y('-T871U<R!R97!O<G0`55),.@!59V%N9&$`56MR86EN90!5;F%B
M;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@97AT
M<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L92!T
M;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE
M('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA
M8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,
M('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN`%5N86)L92!T
M;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O
M<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+@!5;F%B
M;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(&5M<'1Y
M(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B;&4@
M=&\@9&5L971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+@!5
M;F%B;&4@=&\@9&5L971E("(E<R(Z("5S+@!5;F%B;&4@=&\@9&5L971E("5S
M+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@9&5L971E
M(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L92!T;R!D96QE=&4@
M5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y
M.B`E<RX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92`B)7,B+@!5;F%B;&4@
M=&\@9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U
M<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E
M8W1O<GDN`%5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',`
M56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T
M;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B)7,B
M+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`56YA8FQE
M('1O(&]P96X@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S960@
M87)C:&EV92X`56YA8FQE('1O(')E860@9FEL93H@`%5N86)L92!T;R!R96%D
M('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92`E<R!T
M;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L
M92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!6
M1E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B
M)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@
M=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`
M56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET92!61E,@
M9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!61E,@9FEL
M92!D871A+@!5;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA
M<W0@86-T:6]N`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@
M8V]N;F5C=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@
M=&\Z(`!5;F9I;&5D`%5N:6-O9&4@*%541BTX*0!5;FET960@07)A8B!%;6ER
M871E<P!5;FET960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N:71E9"!3=&%T
M97,@36EN;W(@3W5T;'EI;F<@27-L86YD<P!5;FET<P!5;FMN;W=N`%5N:VYO
M=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I
M9"`H0VQI96YT($UE<W-A9V4@240I+@!5;FMN;W=N(&-O;6UA;F0Z("5S`%5N
M:VYO=VX@;&]C871I;VX@<')O=FED960N`%5N:VYO=VX@=7-E<FYA;64@;W(@
M<&%S<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M960`
M56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]0
M87-T92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#
M;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R
M9R!W:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C
M8V5S<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!%
M>'1E;G-I;VX`56YT<F%N<VQA=&5D`%5P9&%T90!5<&1A=&4@)7,`57!D871E
M('5S97(`57!D871E9"`B)7,B+@!5<&1A=&EN9R`E<R!H96QP(&9I;&4@9F]R
M("5S+@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO860`57!L;V%D960@
M86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N`%5P
M<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@;G5M8F5R<P!5<G5G=6%Y
M`%5S86=E.@!5<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@:68@;F%M92]P
M87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R("5S
M(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO
M;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<B!296=I<W1R
M871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`57-E<B!P
M97)M:7-S:6]N<P!5<V5R;F%M90!5<V5R;F%M92`B)7,B(&%L<F5A9'D@97AI
M<W1S+@!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<P!5<V5R<R!I;B!T:&4@
M<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI
M<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``
M5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L=64@:7,@
M;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N`%9A;'5E<P!686QU97,@
M=&\@<V5L96-T(&9R;VT`5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`5F5R
M:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N
M('1A;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I
M8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@2&EG
M:`!6:65T($YA;0!6:65T;F%M97-E("A625-#24DI`%9I97<@)7,`5FEE=R!A
M;B!E>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I<F=I;B!)<VQA;F1S
M+"!"<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES
M:6)I;&ET>3H@`%9O9&%F;VYE($ET86QY('9I82!33510`%=!4DX`5T%23DE.
M1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=A;&QI<R!A
M;F0@1G5T=6YA`%=A<FYI;F<`5V%R;FEN9SH@`%=E`%=E871H97(@1F]R96-A
M<W0`5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!7
M96(@4VET90!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L
M("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U
M*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D
M:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA
M<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H:6-H('!H
M87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X
M="!E9&ET;W(N`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T
M:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@
M;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z
M`%=I:VD`5VEN9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN
M9#H`5VEN9#H@`%=I<V1O;0!7:7-H;&ES=',`5V]R:P!7;W)K($%D9')E<W,`
M5V]R:R!0:&]N90!7<FET:6YG('5P9&%T960@:&5L<"!F:6QE('1O("5S+@!8
M+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S($5X=&5N9&5D
M($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE`%@U
M,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS
M`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S`%EE<RP@22!!
M9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T
M;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@875T
M:&5N=&EC871E9"X`66]U(&-A;B!N;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E
M<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&1I9"!N;W0@96YT97(@82!V86QI
M9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R
M;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE
M;&1S(&EN("5S+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E
M('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N
M;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L
M(&1I86QI;F<@<')E9FEX+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A
M;'5E+@!9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O
M('5S92!3:6=N=7!S+@!9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N
M9"X`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C
M86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H
M92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!S96QE
M8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@
M82!U<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U
M<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N
M86UE('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@
M=7!D871E+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O
M<FTN`%EO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U(&YE
M960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9;W5R("5S
M('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U
M<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O
M<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN
M8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E
M8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@
M3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P
M<&]R="!A9&1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I
M<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!A=71H96YT:6-A
M=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@
M;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H
M97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG
M960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O
M('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN
M`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92X`
M66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I
M;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@=&\@<')I;G0N`%EO=7(@
M8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U
M<B!F=6QL(&YA;64Z`%EO=7(@9V5T=&5X="!V97)S:6]N(&ES('1O;R!O;&0@
M86YD(&1O97,@;F]T('-U<'!O<G0@4$A0(&YA=&EV96QY+@I.;W0@86QL('-T
M<FEN9W,@=VEL;"!B92!E>'1R86-T960N`%EO=7(@;F5W('!A<W-W;W)D(&9O
M<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O
M<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@
M:&%V92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S
M970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E
M;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@
M<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A
M8G=E`%II<'!Y`%M(:61E(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O<G1=
M`%M3:&]W(%%U;W1E9"!497AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L
M:6YE<UT`6VQI;F4@)7,@;V8@)7-=`%]!9&UI;FES=')A=&EO;@!?0TQ)`%]$
M871A5')E90!?1&5L971E(%)O=P!?1W)O=7!S`%](96QP`%]);6%G92!0<F]P
M97)T:65S+BXN`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]/
M<'1I;VYS`%]097)M:7-S:6]N<P!?4F5M;W9E($QI;FLN+BX`7U-E='5P`%]4
M86)L92!0<F]P97)T:65S+BXN`%]5<V5R<P!A9&1R97-S(&)O;VL`86X@97)R
M;W(@:&%S(&]C8W5R960Z`&-A;&5N9&%R`&-A;&T`8VQI8VL@:&5R90!D;VYE
M`&9A:6QE9`!F86QL:6YG`&9I;&4`9F]U;F0Z(`!F<F]M('1H92`E<R`H)7,I
M(&%T("5S("5S`&=U<W1I;F<`:#H`:&@`:6UM961I871E`&EN;&EN90!L:6YE
M<UT`;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N`&UM
M`&YA;64`;F]T(&-H86YG960`;F]T(&9O=6YD`&YO="!I;7!L96UE;G1E9`!N
M;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`<&5R8V5N=`!P:7AE;',`<FES
M:6YG`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10`'-S`'-T
M96%D>0!T87-K(&QI<W0`=&AE($AO<F1E(%!/(&9I;&4@9F]R('1H92!L;V-A
M;&4@)7,@9&]E<R!N;W0@97AI<W0Z`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E
M('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5P9&%T960`=7-E<B!S96QE
M8W0`=D-A<F0`=SH`=V5A=&AE<BYC;VT`4')O:F5C="U)9"U697)S:6]N.B!(
M;W)D92`S+C`M8W9S"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N
M:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$Q+3(T(#`Q.C$X
M*S`P,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P,BTP,2TR,2`Q.#HR,BTP,#`P
M"DQA<W0M5')A;G-L871O<CH@3G5N;R!,;W5R96ER;R`\;G5N;T!E=&@N<'0^
M"DQA;F=U86=E+51E86TZ(%!O<G1U9V%L(%!O<G1U9W5E<V4@/&1E=D!L:7-T
M<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@
M=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ"D-O;G1E;G0M5')A;G-F
M97(M16YC;V1I;F<Z(#AB:70*`"`@+4TL("TM;65S<V%G93U-14Y304=%32!5
M<V%R(&5S=&$@;65N<V%G96T@9&4@8V]M971I;65N=&\@96T@=F5Z(&1A"B`@
M("`@("`@("`@("`@("`@("`@("`@("!M96YS86=E;2!P;W(@;VUI<W/C;RX`
M("`M82P@+2UA9&0]05)154E63R`@("`@061I8VEO;F%R(&5S=&4@87)Q=6EV
M;R!03R!A;R!C;VUPZFYD:6\N(%5T:6P@<&%R80H@("`@("`@("`@("`@("`@
M("`@("`@("!I;F-L=6ER('5M(&-O;7#J;F1I;R!D92!U;2!R86UO(&1I9F5R
M96YT92!N;PH@("`@("`@("`@("`@("`@("`@("`@("!C;VUPZFYD:6\@9V5R
M861O+@`@("UB+"`M+6)A<V4]+T-!34D@($-A;6EN:&\@<&%R82!O(&1I<F5C
M=/-R:6\@8F%S92`H2&]R9&4I(&$@=7-A<BX`("`M8RP@+2UC;VUP96YD:75M
M/4%2454@($EN=&5G<F%R(&YO=F%S('1R861UY_5E<R!A(&5S=&4@87)Q=6EV
M;R!D92!C;VUPZFYD:6\*("`@("`@("`@("`@("`@("`@("`@("`@(&4@;N-O
M(&%O(&-O;7#J;F1I;R!P;W(@;VUI<W/C;R`H8V]M<&5N9&EU;2YP;R!N80H@
M("`@("`@("`@("`@("`@("`@("`@("`@<&%S=&$@:&]R9&4O<&\N`"`@+6,L
M("TM8V]M<&5N9&EU;3U!4E%5("!5<V%R(&5S=&4@87)Q=6EV;R!D92!C;VUP
MZFYD:6\@96T@=F5Z(&1O(&%R<75I=F\*("`@("`@("`@("`@("`@("`@("`@
M("`@('!O<B!O;6ES<^-O("AC;VUP96YD:75M+G!O(&YA('!A<W1A(&AO<F1E
M+W!O+@`@("UD+"`M+61E8G5G("`@("`@($UO<W1R87(@;65N<V%G96YS(&1E
M(&5R<F\@9&]S(&)I;N%R:6]S(&5X96-U=&%D;W,N`"`@+60L("TM9&ER96-T
M;W)Y/5!!4U1!($-R:6%R('5M(&-O;7#J;F1I;R!N97-T82!P87-T82X`("`M
M:"P@+2UH96QP("`@("`@("!-;W-T<F%R(&5S=&$@;65N<V%G96T@9&4@86IU
M9&$N`"`@+6PL("TM;&]C86QE/6QL7T-#("`@("!5<V%R(&%P96YA<R!E<W1A
M(&QO8V%L:7IAY^-O+@`@("UL+"`M+6QO8V%L93UL;%]#0R`@("`@57-A<B!E
M<W1A(&QO8V%L:7IAY^-O+@`@("UL+"`M+6QO8V%L93UL;%]#0R`@("!5<V%R
M(&5S=&$@;&]C86QI>F'GXV\N`"`@+6TL("TM;6]D=6QE/4W31%5,3R`@("!#
M;VYS=')U:7(@87)Q=6EV;W,@34\@87!E;F%S('!A<F$@97-T92!M\V1U;&\*
M("`@("`@("`@("`@("`@("`@("`@("`@("A(;W)D92DN`"`@+6TL("TM;6]D
M=6QE/4W31%5,3R`@("!,:6UP87(@87)Q=6EV;W,@4$\@87!E;F%S('!A<F$@
M97-T92!M\V1U;&\*("`@("`@("`@("`@("`@("`@("`@("`@("A(;W)D92DN
M`"`@+6TL("TM;6]D=6QE/4W31%5,3R`@("!#;VUE=&5R(&%S('1R861UY_5E
M<R!A<&5N87,@<&%R82!E<W1E(&WS9'5L;PH@("`@("`@("`@("`@("`@("`@
M("`@("`@*$AO<F1E*2X`("`M;2P@+2UM;V1U;&4]3=-$54Q/("`@($-R:6%R
M(&\@87)Q=6EV;R!03R!A<&5N87,@<&%R82!E<W1E(&WS9'5L;PH@("`@("`@
M("`@("`@("`@("`@("`@("`@*$AO<F1E*2X`("`M;2P@+2UM;V1U;&4]3=-$
M54Q/("`@($EN=&5G<F%R(&%R<75I=F]S(%!/(&%P96YA<R!P87)A(&5S=&4@
M;?-D=6QO"B`@("`@("`@("`@("`@("`@("`@("`@("`H2&]R9&4I+@`@("UM
M+"`M+6UO9'5L93U-TT153$\@("`@06-T=6%L:7IA<B!A<G%U:79O<R!D92!A
M:G5D82!A<&5N87,@<&%R82!E<W1E"B`@("`@("`@("`@("`@("`@("`@("`@
M("!M\V1U;&\@*$AO<F1E*2X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($%C
M='5A;&EZ87(@87!E;F%S(&5S=&4@;?-D=6QO("A(;W)D92DN`"`@+6TL("TM
M;6]D=6QE/4U/1%5,12`@("!'97)A<B!A<F-H:79O(%!/5"!A<&5N87,@<&%R
M82!E<W1E(&WS9'5L;PH@("`@("`@("`@("`@("`@("`@("`@("`@*$AO<F1E
M*2X`("`M;BP@+2UN;RUC;VUP96YD:75M("`@($[C;R!I;G1E9W)A<B!N;W9A
M<R!T<F%D=>?U97,@;F\@8V]M<.IN9&EO+@`@("UN+"`M+6YO+6-O;7!E;F1I
M=6T@("`@3N-O('5S87(@=6T@8V]M<.IN9&EO+@`@("US+"`M+7-T871I<W1I
M8W,@("`@("`@1W5A<F1A<B!E<W1A=.US=&EC87,@9&4@=')A9'7GXV\@;G5M
M(&9I8VAE:7)O(&QO8V%L+@`@("UT+"`M+71E<W0@("`@("`@($UO<W1R87(@
M;W,@<')O9W)A;6%S(&$@97AE8W5T87(@;6%S(&[C;R!O(&9A>F5R+@`@(&-L
M96%N=7`@("`@($QI;7!A<B!O9B!A<G%U:79O<R!03R!D92!E;G1R861A<R!P
M;W(@=')A9'5Z:7(@;W4@;V)S;VQE=&%S+@`@(&-O;6UI="`@("`@($-O;65T
M97(@87,@=')A9'7G]65S(&YO('-E<G9I9&]R($-64RX`("!C;VUM:70M:&5L
M<"!#;VUE=&5R(&%R<75I=F]S(&1E(&%J=61A(&YO('-E<G9I9&]R($-64RX`
M("!C;VUP96YD:75M("!296-O;G-T<G5I<B!O(&%R<75I=F\@9&4@8V]M<.IN
M9&EO+B!!=&5NY^-O.B!/(&YO=F\@87)Q=6EV;PH@("`@("`@("`@("`@('-O
M8G)E</5E+7-E(&%O(&%N=&EG;RX`("!E>'1R86-T("`@("!'97)A<B!A<G%U
M:79O<R!M;V1E;&\@4$\@*"YP;W0I+@`@(&AE;'`@("`@("`@($UO<W1R87(@
M97-T82!M96YS86=E;2!D92!A:G5D82X`("!I;FET("`@("`@("!#<FEA<B!U
M;2!O=2!M86ES(&%R<75I=F]S(%!/('!A<F$@=6UA(&YO=F$@;&]C86QI>F'G
MXV\N"B`@("`@("`@("`@("`@071E;N?C;SH@3W,@;F]V;W,@87)Q=6EV;W,@
M<V]P<F5P]65M+7-E(&%O<R!A;G1I9V]S+@`@(&UA:V4@("`@("`@($-O;G-T
M<G5I<B!A<G%U:79O<R!B:6[A<FEO<R!-3R!A('!A<G1I<B!D;W,@87)Q=6EV
M;W,*("`@("`@("`@("`@("!03R!E<W!E8VEF:6-A9&]S+@`@(&UA:V4M:&5L
M<"`@($UA<F-A<B!T;V1A<R!A<R!E;G1R861A<R!N;R!A<G%U:79O(%A-3"!D
M92!A:G5D82!C;VUO(&5S=&%N9&\*("`@("`@("`@("`@("!A8W1U86QI>F%D
M87,@92!P<F5P87)A<B!O(&%R<75I=F\@<&%R82!A('!R\WAI;6$@97AE8W7G
MXV\*("`@("`@("`@("`@("!D92!U<&1A=&4M:&5L<"X@1&5V92US92!E>&5C
M=71A<B!M86ME+6AE;'`@1$503TE3(&1E"B`@("`@("`@("`@("`@=7!D871E
M+6AE;'`@92!D92!R979E<B!O(&%R<75I=F\@9&4@86IU9&$N`"`@;65R9V4@
M("`@("`@26YT96=R87(@;R!A<G%U:79O(%!/(&-O<G)E;G1E(&-O;2!O(&%R
M<75I=F\@;6]D96QO(%!/(&-O<G)E;G1E+@`@('5P9&%T92`@("`@($5X96-U
M=&%R(&5X=')A8W0@92!M97)G92!E;2!S97%UZFYC:6$N`"`@=7!D871E+6AE
M;'`@17AT<F%I<B!T;V1A<R!A<R!E;G1R861A<R!N;W9A<R!E(&UO9&EF:6-A
M9&%S(&1O(&%R<75I=F\@9&4*("`@("`@("`@("`@("!A:G5D82!834P@96T@
M:6YG;.IS(&4@:6YT96=RX2UL87,@8V]M(&%S(&5X:7-T96YT92X`("8C,34Q
M.R`E<R!E<W3A('!R;VYT;R!P87)A(&5F96-T=6%R(&%S(&]P97)AY_5E<R!D
M92!M86YU=&5NY^-O(&UA<F-A9&%S(&%B86EX;RX`("@E<R!D:6%S(&%T<N%S
M*0`@*$-H879E(&1E(&%C97-S;R`E<RD`("AD96YT<F\@9&4@)7,@9&EA<RD`
M("AH;VIE*0`@*&%M86YHXRD`("AO;G1E;2D`(&-O;2``(B5S(B!NXV\@Z2!U
M;6$@97-C;VQH82!VX6QI9&$N`"(E<R(@;N-O(&5S=.$@8V]N9FEG=7)A9&\@
M;F\@4F5G:7-T;R!D;R!(;W)D92X`(B5S(B!R97!R97-E;G1A9&]R(&1E(.%R
M=F]R92!NXV\@96YC;VYT<F%D;RX`(B5S(B!F;VD@861I8VEO;F%D;R!A;R!S
M:7-T96UA(&1E(&=R=7!O<RX`(B5S(B<@9F]I(&%D:6-I;VYA9&\@86\@<VES
M=&5M82!D92!P97)M:7-S]65S+@`B)7,B(&[C;R!F;VD@8W)I861O.B`E<RX`
M)60@)7,@92`E<P`E9"!B>71E<R!E<V-R:71O<P`E9"!D92`E9"!E;G1R861A
M(&UA<F-A9&%S(&-O;6\@86-T=6%L:7IA9&%S`'!R979I<^-O(&1E("5D(&1I
M87,`)7,@+2!.;W1I9FEC8>?C;P`E<R!!9&UI;FES=')AY^-O`"5S($EM<')E
M<W/C;R!$:6=I=&%L`"5S($M"`"5S($]P97)AY_5E<R!D92!-86YU=&5NY^-O
M("T@0V]N9FER;6'GXV\`0V]N9FEG=7)A<B`E<P`E<R!3=6)S8W)E=F5R`"5S
M(%1E<FUO<R!D;R!!8V]R9&\`)7,@:N$@97AI<W1E+@`E<R!E;2`E<R`E<P!N
MXV\@<V4@<&]D92!E<V-R979E<B!E;2`E<RX`)7,@Z2!O8G)I9V%T\W)I;P`E
M<R!M:6YU=&]S`"5S(&[C;R!F;VD@96YC;VYT<F%D;RX`)7,@;N-O(&9O:2!E
M;F-O;G1R861O+B!%>&5C=71A<B`G=')A;G-L871I;VX@97AT<F%C="<@<')I
M;65I<F\N`"5S(&$@)7,@9&4@)7,`0V]N=&%C=&]S(&1E("5S`$-A;&5N9.%R
M:6\@9&4@)7,`3F]T87,@9&4@)7,`5&%R969A<R!D92`E<P`E<SH@)7,`+"!C
M;VT@<F%J861A<P`L(&-O;2!R86IA9&%S("5S("5S`"P@=F%R:>%V96P@9&4@
M)7,@82`E<P`M+2!E<V-O;&AA("TM`"TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+0!&;W)M871O(&1E(#$R(&AO<F%S("A!32]032D`1F]R;6%T;R!D92`R
M-"!H;W)A<P`R-"!H;W)A<P`\06YT97)I;W(`971I<75E=&$@/&=E='1E>'0^
M('!O<B!F96-H87(@;F\@9FEC:&5I<F\@)7,N"D%B<FEN9&\@82!E=&EQ=65T
M82!E;F-O;G1R861A(&YA(&QI;FAA("5D+@!%<W1E(&)L;V-O(&5X:6=E('5M
M(&UE8V%N:7-M;R!U<V%N9&\@8F%S97,@9&4@9&%D;W,N`$]C;W)R974@=6T@
M97)R;R!F871A;`#)(&YE8V5S<^%R:6$@=6UA(&-H879E('#Z8FQI8V$@4$=0
M('!A<F$@96YC<FEP=&%R(&$@;65N<V%G96TN`,D@;F5C97-SX7)I82!U;6$@
M8VAA=F4@</IB;&EC82!01U`@<&%R82!V97)I9FEC87(@82!A<W-I;F%T=7)A
M(&1E('5M82!M96YS86=E;0!087)A(&1E8VEF<F%R('5M82!M96YS86=E;2!S
MXV\@;F5C97-SX7)I87,@=6UA(&-H879E('#Z8FQI8V$@4$=0+"!U;6$@8VAA
M=F4@<')I=F%D82!01U`@92!U;6$@9G)A<V4M<&%S<V4N`%!A<F$@87-S:6YA
M<B!U;6$@;65N<V%G96T@<^-O(&YE8V5S<^%R:6%S('5M82!C:&%V92!P^F)L
M:6-A(%!'4"P@=6UA(&-H879E('!R:79A9&$@4$=0(&4@=6UA(&9R87-E+7!A
M<W-E+@!087)A(&1E8VEF<F%R('5M82!M96YS86=E;2!SXV\@;F5C97-SX7)I
M87,@=6UA(&-H879E('#Z8FQI8V$@4R]-24U%+"!U;6$@8VAA=F4@<')I=F%D
M82!3+TU)344@92!U;6$@9G)A<V4M<&%S<V4N`%!A<F$@87-S:6YA<B!U;6$@
M;65N<V%G96T@<^-O(&YE8V5S<^%R:6%S('5M82!C:&%V92!P^F)L:6-A(%,O
M34E-12P@=6UA(&-H879E('!R:79A9&$@4R]-24U%(&4@=6UA(&9R87-E+7!A
M<W-E+@#)(&YE8V5S<^%R:6$@=6UA(&-H879E('#Z8FQI8V$@4R]-24U%('!A
M<F$@96YC<FEP=&%R('5M82!M96YS86=E;2X`3OIV96YS(&1E(&UA;FCC`$-H
M=79I<V-O<R!D92!-86YHXP!#:'5V82!D92!M86YHXP!!9W5A8V5I<F]S(&1E
M(&UA;FCC`$YE=O5E<R!D92!M86YHXP!!32]030!!4$D@240`06-E<F-A(&1E
M<W1E(&5D:71O<@!!8V5R8V$N+BX`0F%S97,@86QI;FAA9&%S`$-E;G1R;W,@
M86QI;FAA9&]S`$%C97-S;R!N96=A9&\@86\@8W)I87(@<&%S=&$@5D93+@!!
M8V5S<V\@;F5G861O(&%O(&-R:6%R(&%R<75I=F\@5D93+@!086QA=G)A+5!A
M<W-E(&1A($-O;G1A`$-O;G1A(&-O;F=E;&%D82X`0V]N=&%B:6QI9&%D90!!
M9&EC:6]N87(`061I8VEO;F%R($=R=7!O($9I;&AO`$%D:6-I;VYA<B!097)M
M:7-SXV\@1FEL:&$`06-R97-C96YT87(@07%U:3H`061D:6-I;VYA<B!.;W9O
M($=R=7!O`$%D:6-I;VYA<B!.;W9A(%!E<FUI<W/C;P!!9&EC:6]N87(@=6T@
M9W)U<&\@9FEL:&\@82`B)7,B`$%D:6-I;VYA<B!U;6$@<&5R;6ES<^-O(&9I
M;&AA(&$@(B5S(@!!9&EC:6]N87(@;F]V;R!U=&EL:7IA9&]R.@!!9&EC:6]N
M87(@8V]L=6YA`$%D:6-I;VYA<B!N;W9O<R!M96UB<F]S`$%D:6-I;VYA<B!P
M87)C96ER;P!!9&EC:6]N87(@;R!-96YU("5S(&-O;6\@0F%R<F$@3&%T97)A
M;"!-;WII;&QA`$%D:6-I;VYA<B!A;W,@0V]N=&%C=&]S.@!!9&EC:6]N87(@
M86]S(&UE=7,@8V]N=&%C=&]S`$%D:6-I;VYA<B!U=&EL:7IA9&]R`$%D:6-I
M;VYE:2`B)7,B(&%O('-I<W1E;6$L(&UA<R!NXV\@<'5D92!A9&EC:6]N87(@
M:6YF;W)M8>?C;R!D92!S=6)S8W)IY^-O(&%D:6-I;VYA;#H@)7,N`$%D:6-I
M;VYE:2`B)7,B(&%O('-I<W1E;6$N($KA('!O9&4@96YT<F%R+@!!9&EC:6]N
M86YD;R!N;W9O<R!A<G%U:79O<R!A;R!R97!O<VET\W)I;SH`02!A9&GGXV\@
M9&4@=71I;&EZ861O<F5S(&5S=.$@9&5S86-T:79A9&$N`$5N9&5R9>=O`$-O
M;G1A8W1O<P!!9&UI;FES=')A<B`M(&%T<FEB=6ER('!E<FUI<W/U97,@82!O
M=71R;W,@=71I;&EZ861O<F5S`$%D;6EN:7-T<F'GXV\`06[Z;F-I;W,`069E
M9V%N:7-TXV\`06QBXFYI80!!<F?I;&EA`$%L8W5N:&$`06QI;FAA<@!!;&EN
M:&%M96YT;SH`5'5D;P!4;V1O<R!O<R!5=&EL:7IA9&]R97,@075T96YT:6-A
M9&]S`%1O9&]S(&]S($=R=7!O<P!4;V1A<R!A<R!097)M:7-S]65S`%1O9&]S
M(&]S("AQ=6%T<F\I(&QA9&]S`%!E<FUI=&ER(&WZ;'1I<&QO<R!E;F1E<F7G
M;W,`4&5R;6ET:7(@871R:6)U:>?C;R!D;R!T:7!O(&1E(&QI<W1A<R!O<F1E
M;F%D87,_`$KA(&5X:7-T90!%;G1R861A($E-4U`@06QT97)N871I=F$`4&%L
M879R82U087-S92!)35-0($%L=&5R;F%T:79A`$YO;64@9&4@571I;&EZ861O
M<B!)35-0($%L=&5R;F%T:79O`$5N9&5R9>=O(&EN=N%L:61O`$UO9&5L;W,@
M86QT97)N871I=F]S`%1E>'1O(&%L=&5R;F%T:79O.@!386UO82!!;65R:6-A
M;F$`1F]I(&5S<&5C:69I8V%D;R!U;2!V86QO<B!I;G;A;&ED;RX`3V-O<G)E
M=2!U;2!E<G)O(&1E<V-O;FAE8VED;RX`06YD;W)R80!!;F=O;&$`06YG=6EL
M80!%;G1R97!O<W1O("AP<F]X>2D@06[S;FEM;P!297-P;W-T80!!;G3A<F-T
M:6-O`$%N=.UG=6$@92!"87)B=61A`$%P;&EC8>?C;P!!<&QI8V'GXV\@<')O
M;G1A+@!!<&QI8V%R(&$@4&%R=&EL:&%S($9I;&AA<P!!<')O=F%R`%1A;6%N
M:&\@07!R;WAI;6%D;P!!8G)I;`!!<N%B:6-O("A7:6YD;W=S+3$R-38I`%1A
M;6%N:&\@9&\@1FEC:&5I<F\@9&4@07)Q=6EV;P!.;VUE(&1O($%R<75I=F\`
M5&5M(&$@8V5R=&5Z82!Q=64@<75E<B!R96UO=F5R(&\@<&5D:61O(&1E('-U
M8G-C<FGGXV\@<&%R82`E<R`_`%1E;2!A(&-E<G1E>F$@<75E('%U97(@<F5M
M;W9E<B`B)7,B(&4@<75A:7-Q=65R('-U8BUG<G5P;W,_`$%R9V5N=&EN80!!
M<FWI;FEA`$%R;>EN:6\@*$%235-#24DM."D`07)T90!!<G5B80!);&AA(&1E
M($%S8V5N<^-O`$%R=&4@05-#24D`4F5G:>-O(,%S:6$O4&%C[69I8V\`4&5D
M:7(@8V]N9FER;6'GXV\@86YT97,@9&4@<F5A;&EZ87(@;W!E<F'G]65S(&1E
M(&UA;G5T96[GXV\_`$-O;'5N87,@9&4@871R:6)U:>?C;P!496YT871I=F$@
M9&4@<F5M;^?C;R!D92!U;2!G<G5P;R!I;F5X:7-T96YT92X`5&5N=&%T:79A
M(&1E(')E;6_GXV\@9&4@=6UA('!E<FUI<W/C;R!I;F5X:7-T96YT92X`5&5N
M=&%T:79A(&1E(&5D:>?C;R!D92!U;6$@<&5R;6ES<^-O(&EN97AI<W1E;G1E
M+@!496YT871I=F$@9&4@961IY^-O(&1E('5M82!P87)T:6QH82!I;F5X:7-T
M96YT92X`071R:6)U=&]S`$%G;W-T;P!!=7-T<N%L:6$`P75S=')I80!!=71H
M7V-Y<G-Q;#H@02!E>'1E;G/C;R!I;6%P(&YE8V5S<^%R:6$@;N-O(&9O:2!E
M;F-O;G1R861A+@!!=71H7V-Y<G5S.B!/(&UE8V%N:7-M;R!NXV\@=&5M(&%S
M(&-A<&%C:61A9&5S(&YE8V5S<^%R:6%S+@!!=71H7V-Y<G5S.B!!(&5X=&5N
M<^-O(&EM87`@;F5C97-SX7)I82!NXV\@9F]I(&5N8V]N=')A9&$N`$%U=&A?
M9G1P.B!!(&5X=&5N<^-O($944"!N96-E<W/A<FEA(&[C;R!F;VD@96YC;VYT
M<F%D82X@0V]M<&EL92!O(%!(4"!C;VT@82!O<.?C;R`M+65N86)L92UF='`N
M`$%U=&A?:6UA<#H@02!E>'1E;G/C;R!)34%0(&YE8V5S<^%R:6$@;N-O(&9O
M:2!E;F-O;G1R861A+@!!=71H7VMR8C4Z($$@97AT96YSXV\@:W)B-2!N96-E
M<W/A<FEA(&[C;R!F;VD@96YC;VYT<F%D82X`075T:%]L9&%P.B!!(&5X=&5N
M<^-O($Q$05`@;F5C97-SX7)I82!NXV\@9F]I(&5N8V]N=')A9&$N`$%U=&A?
M;&1A<#H@26UP;W-S[79E;"!A9&EC:6]N87(@=71I;&EZ861O<B`E<RX@16ES
M(&\@<75E(&\@<V5R=FED;W(@9&ES<V4Z(`!!=71H7VQD87`Z($EM<&]S<^UV
M96P@<F5M;W9E<B!O('5T:6QI>F%D;W(@)7,`075T:%]L9&%P.B!);7!O<W/M
M=F5L(&%C='5A;&EZ87(@;R!U=&EL:7IA9&]R("5S`$%U=&A?;6-A;#H@02!E
M>'1E;G/C;R!-0T%,(&YE8V5S<^%R:6$@;N-O(&9O:2!E;F-O;G1R861A+@!!
M=71H7W-M8F%U=&@Z($$@97AT96YSXV\@<VUB875T:"!N96-E<W/A<FEA(&[C
M;R!F;VD@96YC;VYT<F%D82X`02!A=71E;G1I8V'GXV\@9F%L:&]U`$$@875T
M96YT:6-AY^-O(&9A;&AO=2X@)7,`02!A=71E;G1I8V'GXV\@9F]I(')E:F5I
M=&%D82!P96QO('-E<G9I9&]R(%)!1$E54RX`02!A=71E;G1I8V'GXV\@;F\@
M<V5R=FED;W(@1E10(&9A;&AO=2X`0V%M<&]S(&1I<W!O;NUV96ES.@!!>F5R
M8F%I:N-O`$1E<V-U;'!A<R`B0D]&2"(`1G5N9&\`0V]R(&1O($9U;F1O`%!A
M;&%V<F$M4&%S<V4@:V5R8F5R;W,@97)R861A+@!.;VUE(&1E(%5T:6QI>F%D
M;W(@:V5R8F5R;W,@97)R861O+@!"86%M87,`0F%RZ6T`0N%L=&EC;R`H25-/
M+3@X-3DM,3,I`$)A;F=L861E8VAE`$)A<F)A9&]S`$QI;FAA(&)A<V4`0FEE
M;&]R<OIS<VEA`$+I;&=I8V$`0F5L:7IE`$)E;FEM`$)E<FUU9&$`0G5TXV\`
M06YI=F5R<^%R:6\`3R!B;&]C;R`B)7,B(&1A(&%P;&EC8>?C;R`B)7,B(&[C
M;R!F;VD@96YC;VYT<F%D;RX`0V]N9FEG=7)AY_5E<R!D92!";&]C;W,`5&EP
M;R!D92!";&]C;P!.96=R:71O`$)O;.UV:6$`36%R8V%D;W)E<P!";W)D80!%
M<W!E<W-U<F$@9&$@8F]R9&$Z`$)O<F1A<P!"\W-N:6$M2&5R>F5G;W9I;F$`
M06UB87,`0F]T<W5A;F$`0F%S90!);&AA($)O=79E=`!"<F%S:6P`5&5R<FET
M\W)I;R!"<FETXFYI8V\@9&\@3V-E86YO(,UN9&EC;P!"<G5N96D@1&%R=7-S
M86QA;0!#;VYS=')U:6YD;R!A<G%U:79O<R!-3R!P87)A(&\@;?-D=6QO("5S
M+BXN`$-O;G-T<G5I;F1O(&QO8V%L:7IAY^-O("5S+BXN(`!"=6QGX7)I80!,
M:7-T($ET96UI>F%D80!"=7)Q=6EN82!&87-O`$)U<OIN9&D`0TU3`$-20P!0
M;VYT;W,@9&4@1&ES=')I8G5IY^-O($-23`!0<F]P<FEE9&%D97,@9&$H<RD@
M0^E?;'5L82AS*2XN+@!);FEC:6%L:7IAY^-O(&1A(")C86-H92(@;N-O(&9O
M:2!C;VYC;'7M9&$N`$-A;&5N9.%R:6\`0V%L;6\`0V%M8F]D:F$`0V%M87+U
M97,`3N-O('!O<W-O(')E:6YI8VEA<B!A('!A;&%V<F$M<&%S<V4@875T;VUA
M=&EC86UE;G1E+"!C;VYT86-T92!O('-E=2!A9&UI;FES=')A9&]R(&1E('-I
M<W1E;6%S+@!);7!O<W/M=F5L(&-O;F5C=&%R(&%O('-E<G9I9&]R($E-05`Z
M("5S`$-A;F%DX0!#86YC96QA<@!#86YC96QA<B!296QA=/-R:6\@9&4@4')O
M8FQE;6%S`$[C;R!C;VYS:6=O(')E;6]V97(@;R!F:6-H96ER;R`B)7,B+@!.
MXV\@8V]N<VEG;R!E;F-O;G1R87(@=6T@9&ER96-T\W)I;R!T96UP;W+A<FEO
M+@!);7!O<W/M=F5L(&-O;G1I;G5A<B!S96T@;R!P87+B;65T<F\@)W1A<F=E
M=$9I;&4G+@!.XV\@9F]I('!O<W/M=F5L(')E;6]V97(@82!P87-T82`B)7,B
M+@!);7!O<W/M=F5L(')E;6]V97(L(&5X:7-T96T@)60@9FEL:&]S+@!.XV\@
MZ2!P;W-S[79E;"!R96]R9&5N87(Z(&\@;OIM97)O(&1E(&5N=')A9&%S(&9O
M<FYE8VED87,@;N-O(&-O<G)E<W!O;F1E(&%O(&[Z;65R;R!G=6%R9&%D;RX`
M3N-O(&9O:2!P;W-S[79E;"!E;F-A;6EN:&%R(&$@;65N<V%G96T@<&%R82!O
M(&[Z;65R;R!I;F1I8V%D;RX`4F5P^F)L:6-A(&1E($-A8F\@5F5R9&4`3&5G
M96YD80!#871E9V]R:6%S(&4@0V]R97,`26QH87,@0V%I;>-O`%1E;&5F;VYE
M($-E;'5L87(`4')O<')I961A9&5S(&1A<R!#Z6QU;&%S`$5N8VAI;65N=&\@
M9&%S($/I;'5L87,Z`%!R;W!R:65D861E<R!D87,@8^EL=6QA<P!%<W!AYV%M
M96YT;R!D87,@8^EL=6QA<SH`5&5L96WS=F5L`$/I;'1I8V\@*$E33RTX.#4Y
M+3$T*0!#96YT<F%R`%)E</IB;&EC82!#96YT<F\@069R:6-A;F$`175R;W!A
M($-E;G1R86P@*$E33RTX.#4Y+3(I`%!O<FUE;F]R97,@9&\@0V5R=&EF:6-A
M9&\`1&]N;R!D;R!#97)T:69I8V%D;P!0;VSM=&EC87,@9&4@0V5R=&EF:6-A
M9&\`4F5P^F)L:6-A(&1O($-H861E`$%L=&5R87(`06QT97)E(&\@;F]M92!E
M(&5N9&5R9>=O('%U92!A<R!P97-S;V%S('9E<N-O('%U86YD;R!L97)E;2!E
M(')E<W!O;F1E<F5M(.!S('-U87,@;65N<V%G96YS+@!#87)A8W1E<F4`5F5R
M:5]F:6-A<B!,:6=AY^-O+BXN`$UA<G%U92!A<R!O<&5R8>?U97,@<75E(&1E
M<V5J82!E>&5C=71A<B!N97-T92!M;VUE;G1O+@!297#Z8FQI8V$@9&\@0VAI
M;&4`4F5P^F)L:6-A(%!O<'5L87(@9&$@0VAI;F$`0VAI;NIS(%-I;7!L:69I
M8V%D;W,@*$=",C,Q,BD`0VAI;NIS(%1R861I8VEO;F%L("A":6<U*0!%<V-O
M;&AA(&$@<&%L879R82UP87-S90!%<V-O;&AA('5M($YO;64@9&4@571I;&EZ
M861O<@!%<V-O;&AA(&-O;6\@;6]S=')A<B!A<R!D871A<SH`17-C;VQH82!O
M(&5S=&EL;R!D87,@;&ES=&$@*'!A<F$@;&ES=&%S(&]R9&5N861A<RD`26QH
M82!D;R!.871A;`!.XV\@9F]I(&5N8V]N=')A9&$@82!D969I;FGGXV\@9&$@
M8VQA<W-E("5S+@!,:6UP86YD;R!O<R!A<G%U:79O<R!03R!D;R!M\V1U;&\@
M)7,N+BX`3&EM<&%N9&\@82!L;V-A;&EZ8>?C;R`E<RXN+B``3&EM<&%R`$QI
M;7!A<B!E=&EQ=65T87,@9&\@35-/9F9I8V4`3&EM<&%R(&1A9&]S(&1O('5T
M:6QI>F%D;W(Z("5S`$QI;7!A<B!D861O<R!D;R!U=&EL:7IA9&]R`$QI;7!A
M<B!D861O<R!D;R!U=&EL:7IA9&]R`$QI;7!A(%1A<F1E`$-L:7%U92!P87)A
M($-O;G1I;G5A<@!#;&EC:V%T96QL('9I82!(5%10`$9E8VAA<B!J86YE;&$`
M3OIV96YS`$[Z=F5N<R!-871I;F%I<P!%;F5V;V%D;P!);&AA<R!#;V-O<R`H
M2V5E;&EN9RD`0V]L87!S87(@0F%R<F$@3&%T97)A;`!";W)D87,@0V]L87!S
M861A<P!297#Z8FQI8V$@9&$@0V]L]&UB:6$`0V]R97,`4&%L971E`%-E;&5C
MY^-O(&1E(&-O<F5R`$-O;'5N87,Z`%3M='5L;W,@9&%S(&-O;'5N87,`0D0`
M0V]M86YD;P!#;VYS;VQA(&1E($-O;6%N9&]S`$]PY_5E<R!D;R!C;VUA;F1O
M.@!#;VUA;F1O<SH`0V]M96YTX7)I;P!#;VUE=&5N9&\`3F]M92!#;VUU;0!#
M;VUO<F]S`$5M<')E<V$`17-C<F5V97(@*"5S*0!#;VUP=71A9&]R97,`0V]N
M9&GGXV\`0V]N9&GG]65S`$1I9F5R96[G87,@9&4@0V]N9FEG=7)AY^-O`$$@
M8V]N9FEG=7)AY^-O(&5S=.$@9&5S86-T=6%L:7IA9&$`0V]N9FEG=7)A<B`E
M<P!#;VYF:7)M92!A(%!A;&%V<F$M4&%S<V4`4F5P^F)L:6-A($1E;6]C<N%T
M:6-A(&1O($-O;F=O`%)E</IB;&EC82!$96UO8W+A=&EC82!D;R!#;VYG;P!#
M;VYE>.-O(&9A;&AO=2X`0V]N97CC;R!F86QH;W4Z(`!#;VYE>.-O(&%O('-E
M<G9I9&]R(&1E(&-H879E<R!P^F)L:6-A<R!R96-U<V%D82X`0V]N97CC;R!A
M;R!S97)V:61O<B!D92!C:&%V97,@</IB;&EC87,@<F5C=7-A9&$N(%)A>N-O
M.B`E<R`H)7,I`$-O;F5XXV\@86\@<V5R=FED;W(@1E10(')E8W5S861A+@!#
M;VYT86-T;W,@861I8VEO;F%D;W,@8V]M('-U8V5S<V\@86\@<V5U(&QI=G)O
M(&1E(&5N9&5R9>=O<RX`5&EP;R!D92!C;VYT9?ID;R!D;R!A<G%U:79O(&-O
M;7!R:6UI9&\Z(`!#;VYT9?ID;R!D92`E<P!#;VYT:6YU87(`26QH87,@0V]O
M:P!";VQI;FAO(&-H:6[J<P!#;W!I87(`0V]P:6%R('-E;&5CY^-O`$-O<&EA
M;F1O(&1E("5S('!A<F$@)7,`4F5P^F)L:6-A(&1A($-O<W1A(%)I8V$`4F5P
M^F)L:6-A(&1A($-O<W1A(&1O($UA<F9I;0!.XV\@9F]I('!O<W/M=F5L(&5N
M8W)I<'1A<B!A(&UE;G-A9V5M(&-O;2!01U`N`$[C;R!F;VD@<&]S<^UV96P@
M87-S:6YA<B!A(&UE;G-A9V5M(&-O;2!01U`N`$[C;R!F;VD@<&]S<^UV96P@
M96YC<FEP87(@82!M96YS86=E;2!C;VT@4R]-24U%+@!.XV\@9F]I('!O<W/M
M=F5L(&%S<VEN87(@82!M96YS86=E;2!C;VT@4R]-24U%+@!.XV\@9F]I('!O
M<W/M=F5L(&%D:6-I;VYA<B!O(&-O;G1A8W1O+B`E<P!&86QH82!N82!L:6=A
MY^-O("AB:6YD*2!A;R!S97)V:61O<B!,1$%0+@!.XV\@9F]I('!O<W/M=F5L
M('9E<FEF:6-A<B!O('-A;&1O+B`E<P!.XV\@9F]I('!O<W/M=F5L(&-O;F5C
M=&%R(&%O('-E<G9I9&]R("(E<R(@=7-A;F1O($944#H@)7,`3N-O(&9O:2!P
M;W-S[79E;"!C;W!I87(@)7,@<&%R82`E<P!.XV\@9F]I('!O<W/M=F5L(&-R
M:6%R(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@)7,`3N-O(&9O:2!P;W-S[79E
M;"!C<FEA<B!P87-T82!D92!L;V-A;&EZ8>?C;R!P87)A(&$@;&]C86QI>F'G
MXV\@)7,Z`$[C;R!F;VD@<&]S<^UV96P@9&5S96YC<FEP=&%R(&]S(&1A9&]S
M(&-O;2!O(%!'4"X`3N-O(&9O:2!P;W-S[79E;"!D97-E;F-R:7!T87(@;W,@
M9&%D;W,@8V]M(%,O34E-12X`3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(&-O
M;G1A8W1O+B`E<P!.XV\@9F]I('!O<W/M=F5L(')E;6]V97(@;&ES=&$@9&4@
M9&ES=')I8G5IY^-O+B`E<P!.XV\@9F]I('!O<W/M=F5L(')E;6]V97(@;R`B
M<V-R:7!T(B!D92!A8W1U86QI>F'GXV\@(B5S(BX`3N-O(&9O:2!P;W-S[79E
M;"!D971E<FUI;F%R(&\@96YD97)EYV\@9&4@8V]R<F5I;R!E;&5C='+S;FEC
M;R!D;R!D97-T:6YA=.%R:6\N`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@;R!L
M:79R;R!D92!E;F1E<F7G;W,@8V]M<&QE=&\N`$[C;R!F;VD@<&]S<^UV96P@
M;V)T97(@82!L:7-T82!D92!D:7-T<FEB=6GGXV\@8V]M<&QE=&$N`$[C;R!F
M;VD@<&]S<^UV96P@;V)T97(@82!L:7-T82!C;VUP;&5T82!D87,@;&ES=&%S
M(&1E(&1I<W1R:6)U:>?C;RX`26UP;W-S[79E;"!C87)R96=A<B!E<W1R873I
M9VEA("(E<R(N`$EM<&]S<^UV96P@;6MD:7(@(B5S(BX`3N-O(&9O:2!P;W-S
M[79E;"!O8G1E<B!A(&-H879E('#Z8FQI8V$@82!P87)T:7(@9&\@<V5R=FED
M;W(@9&4@8VAA=F5S('#Z8FQI8V%S+@!.XV\@9F]I('!O<W/M=F5L(&%B<FER
M("(E<R(@<&%R82!E<V-R:71A+@!.XV\@9F]I('!O<W/M=F5L(&%B<FER("5S
M+@!.XV\@9F]I('!O<W/M=F5L(&%B<FER(&\@;?-D=6QO(&1E($UA;G5T96[G
MXV\@9&4@5&%R969A<R`E<P!.XV\@9F]I('!O<W/M=F5L(&%B<FER('!A<W1A
M("(E<R(N`$[C;R!F;VD@<&]S<^UV96P@;&5R("5S+@!.XV\@9F]I('!O<W/M
M=F5L(')E:6YI8VEA<B!A('!A;&%V<F$M<&%S<V4@9&\@=71I;&EZ861O<B!I
M;F1I8V%D;RX@06QG=6T@;W4@=&]D;W,@;W,@<&]R;65N;W)E<R!NXV\@97-T
M879A;2!C;W)R96-T;W,N(%!O<B!F879O<B!T96YT92!D92!N;W9O(&]U(&-O
M;G1A8W1E(&\@<V5U(&%D;6EN:7-T<F%D;W(@9&4@<VES=&5M87,@<V4@<')E
M8VES87(@9&4@;6%I<R!A:G5D82X`3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!!
M0TP`3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!L:79R;R!D92!E;F1E<F7G;W,N
M("5S`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@;&ES=&$@9&4@9&ES=')I8G5I
MY^-O+B`E<P!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&QI<W1A<R!D92!D:7-T
M<FEB=6GGXV\N("5S`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@87,@8V]M<&5T
MZFYC:6%S(&1O('-E<G9I9&]R`$[C;R!F;VD@<&]S<^UV96P@<F5V97)T97(@
M82!C;VYF:6=U<F'GXV\N`$EM<&]S<^UV96P@<FUD:7(@(B5S(BX`3N-O(&9O
M:2!P;W-S[79E;"!G=6%R9&%R(&$@8V]N9FEG=7)AY^-O(&1E("5S+@!.XV\@
M9F]I('!O<W/M=F5L(&=U87)D87(@82!C;VYF:6=U<F'GXV\@9&4@<V%L=F%G
M=6%R9&$N`$[C;R!F;VD@<&]S<^UV96P@9W5A<F1A<B!A(&-O;F9I9W5R8>?C
M;R!D92!S86QV86=U87)D83H@)7,`3N-O(&9O:2!P;W-S[79E;"!G=6%R9&%R
M(&\@(G-C<FEP="(@9&4@86-T=6%L:7IAY^-O(&5M.B`B)7,B+@!.XV\@9F]I
M('!O<W/M=F5L(&=U87)D87(@82!C;VYF:6=U<F'GXV\@9&4@<V%L=F%G=6%R
M9&$@)7,N`$[C;R!F;VD@<&]S<^UV96P@9W5A<F1A<B!O(&%R<75I=F\@9&4@
M8V]N9FEG=7)AY^-O("5S+B!0;V1E('5S87(@=6UA(&1A<R!O<.?U97,@<&%R
M82!G=6%R9&%R(&\@8_-D:6=O(&5M("5S(&]U(&-O<&EA<B!M86YU86QM96YT
M92!O(&/S9&EG;R!A8F%I>&\@<&%R82`E<RX`3N-O(&9O:2!P;W-S[79E;"!P
M<F]C=7)A<B!N;R!S97)V:61O<B!,1$%0+@!.XV\@9F]I('!O<W/M=F5L(&1E
M<VQI9V%R("(E<R(N`$[C;R!F;VD@<&]S<^UV96P@86-T=6%L:7IA<B!C;VYT
M86-T;RX@)7,`3N-O(&9O:2!P;W-S[79E;"!A8W1U86QI>F%R(&$@;&ES=&$@
M9&4@9&ES=')I8G5IY^-O+B`E<P!.XV\@9F]I('!O<W/M=F5L(&5S8W)E=F5R
M(&$@8V]N9FEG=7)AY^-O('!A<F$@(B5S(CH@)7,`3N-O(&5N8V]N=')E:2!A
M($)A<G)A($QA=&5R86P@9&\@36]Z:6QL82X@07-S96=U<F4M<V4@<75E(&$@
M8F%R<F$@;&%T97)A;"!E<W3A(&%B97)T82X`3N-O(&9O:2!P;W-S[79E;"!A
M=')I8G5I<B!A;R!U=&EL:7IA9&]R("(E<R(@;W,@<V5G=6EN=&5S(&1I<F5I
M=&]S('-O8G)E(&$@<&%S=&$@(B5S(CH@)7,`5&5X=&\@0V]N=&%D;P!08>US
M`$-U<G-O<P!#<FEA<@!#<FEA<B!U;6$@;&EG8>?C;P!#<FEA<B!U;6$@;F]V
M80!#<FEA<B!S=6(M<&%S=&%S`%!E<FUI<W/U97,@9&\@0W)I861O<@!.^FUE
M<F\@9&\@8V%R=.-O(&1E(&-RZ61I=&\`4F5P^F)L:6-A(&1A($-R;^%C:6$`
M4F5P^F)L:6-A(&1E($-U8F$`475A=')O(&9A<V5S(&-O<G)E;G1E<P!$871A
M+TAO<F$`55),(&-O<G)E;G1E(.D`17-T861O(&1O(%1E;7!O`%-I='5AY^-O
M(&%C='5A;#H@`$5S=&EL;R!A8W1U86P`4&5R<V]N86QI>F%R(&%S('1A<F5F
M87,@<75E('-E<N-O(&5X96-U=&%D87,@87%U86YD;R!O(&QO9VEN(&YO("5S
M+@!#;W)T87(`0V]R=&%R(&$@<V5L96/GXV\`4F5P^F)L:6-A(&1E($-H:7!R
M90!#:7+M;&EC;R`H2T])."U2*0!#:7+M;&EC;R`H5VEN9&]W<RTQ,C4V*0!#
M:7+M;&EC;R]58W)A;FEA;F\@*$M/23@M52D`4F5P^F)L:6-A($-H96-A`$1$
M`$1I87)I86UE;G1E`$YA=F5G861O<B!D92#!<G9O<F4@9&4@1&%D;W,`1&%T
M80!$871A(&1E(%)E8V5PY^-O`%-E;&5CY^-O(&1E(&1A=&$`1&EA`%)E;6]V
M97(@0V]?;'5N80!$97IE;6)R;P!.^FUE<F]S(&1E8VEM86ES`%)E9'5Z:7(@
M:6YD96YT8>?C;P!0;W(@3VUI<W/C;P!#;W(@4&]R($]M:7-SXV\`261E;G1I
M9&%D92!0861RXV\`4&5R;6ES<_5E<R!0;W(@3VUI<W/C;P!097)M:7-S]65S
M('!O<B!O;6ES<^-O`$1E9FEN:>?U97,`4F5M;W9E<@!296UO=F5R($=R=7!O
M`%)E;6]V97(@4&5R;6ES<^-O`%)E;6]V97(@92!P=7)G87(@;65N<V%G96YS
M`%)E;6]V97(@8^EL=6QA`%)E;6]V97(@8V]L=6YA`%)E;6]V97(@;6]D96QO
M(&%L=&5R;F%T:79O(&5X:7-T96YT90!296UO=F5R('!E<FUI<W/U97,@9&4@
M(B5S(@!296UO=F5R('!E<FUI<W/U97,@<&%R82`G)7,G(&4@<75A:7-Q=65R
M('-U8BUP97)M:7-S]65S/P!296UO=F5R(&QI;FAA`%)E;6]V97(@:61E;G1I
M9&%D92!S96QE8V-I;VYA9&$`4F5M;W9E<B!A(&-O;'5N82!C;W)R96YT90!2
M96UO=F5R(&$@;&EN:&$@8V]R<F5N=&4`4F5M;W9E<B!E<W1A('!E<FUI<W/C
M;R!E('1O9&%S(&%S('-U87,@<W5B+7!E<FUI<W/U97,_`")38W)I<'0B(&1E
M(&%C='5A;&EZ8>?C;R`B)7,B(')E;6]V:61O+@!-;VUE;G1O(&1E(&5N=')E
M9V$`1&EN86UA<F-A`$1E<V-R979A(&\@4')O8FQE;6$`1&5S8W)IY^-O`%!O
M<FUE;F]R97,@*'1A;6+I;2!N;R!R96=I<W1O+"`B;&]G(BP@9&\@2&]R9&4I
M.@!/<R!D971A;&AE<R!F;W)A;2!E;G9I861O<R!P87)A(&\@861M:6YI<W1R
M861O<B!D;R!S:7-T96UA+@!$97-E;G9O;'9I;65N=&\`4&]N=&\@9&4@3W)V
M86QH;P!0;VYT;R!D92!/<G9A;&AO(&YA(/IL=&EM82!H;W)A.B``4&]N=&\@
M9&4@;W)V86QH;SH@`$1I<F5CY^-O(&1A(&5S<75E<F1A('!A<F$@82!D:7)E
M:71A`$1I<F5CY^-O(&1A(&1I<F5I=&$@<&%R82!A(&5S<75E<F1A`$1I<F5C
M=/-R:6\`36]S=')A<B!T96UP;W,@8V]M(#(T(&AO<F%S/P!/<.?U97,@9&4@
M5FES=6%L:7IAY^-O`$UO<W1R87(@<')E=FESXV\@<&]R;65N;W)I>F%D80!-
M;W-T<F%R('!R979I<^-O("A4048I`$9O<FUA=&\@9&4@=FES=6%L:7IAY^-O
M`$YO=&EF:6-AY^-O(&1E($1I<W!O<VGGXV\`1&II8G5T:0!.XV\@<F5M;W9E
M<@!.XV\@=71I;&EZ92!O(&UA:6YT96YA;F-E+G!H<"!D:7)E8W1A;65N=&4`
M02!P<FEM96ER82!L:6YH82!C;VYTZ6T@;W,@;F]M97,@9&]S(&-A;7!O<S\@
M4V4@<VEM+"!A<W-I;F%L87(@97-T82!C86EX83H`1&]M:6YI8V$`4F5P^F)L
M:6-A($1O;6EN:6-A;F$`4F5C96)E<@!296-E8F5R("5S`$1E<V-A<G)E9V%R
M(&$@8V]N9FEG=7)AY^-O(&=E<F%D82!C;VUO('5M(")S8W)I<'0B(%!(4"X`
M3&ES=&$@9&4@9&5S96YR;VQA<@!$<F]G87,`0V]R<F5I;R!E;&5C='+S;FEC
M;P!%4E(`4F5P^F)L:6-A(&1O($5Q=6%D;W(`161I=&%R`$5D:71A<B!";&]C
M;P!%9&ET87(@1W)U<&\`161I=&%R(%!E<FUI<W/U97,`161I=&%R(%!E<FUI
M<W/U97,`161I=&%R('!E<FUI<W/U97,@9&4@)7,`161I=&%R(&]PY_5E<R!D
M93H`161I=&%R('!E<FUI<W/U97,@9&4@(B5S(@!%9&ET87(@<&5R;6ES<_5E
M<R!D92`E<P!%9'5C8>?C;P!%9VEP=&\`4F5P^F)L:6-A(&1E($5L(%-A;'9A
M9&]R`$5L96UE;G1O+BXN`$5M`$-O<G)E:6\@16QE8W1R\VYI8V\`16YD97)E
MYV\@9&4@0V]R<F5I;R!%;&5C='+S;FEC;P!/<R!E;F1E<F7G;W,@=.IM('%U
M92!C;VEN8VED:7(N`$UE;G-A9V5M(&-O;2!C;VYF:7)M8>?C;P!3[6UB;VQO
M<R!D92!%;6_GXV\`365N<V%G96T@=F%Z:6$N`%-E;2!R97-U;'1A9&]S+@!3
M96T@=&5R;6]S(&1E('!R;V-U<F$`06-T:79A<B!I;G-E<N?C;R!D92!I;6%G
M96YS(&1E($=A;&5R:6%S($9O=&]G<N%F:6-A<R!N;R!T97AT;S\`06-T:79A
M<B!M96YU(&1E(&-O;G1E>'1O(&YO(&)O=.-O(&1I<F5I=&\@9&\@<F%T;S\`
M06YO(&1E(&9I;0!!=6UE;G1A<B!%9&ET;W(`26YT<F]D=7IA('5M82!P97)G
M=6YT82!D92!S96=U<F%NYV$@<75E('-E<N$@8V]N=FED861O(&$@<F5S<&]N
M9&5R('-E('!R96-I<V%R(&1E(')E:6YI8VEA<B!A('-U82!P86QA=G)A+7!A
M<W-E+"!E+F<N+"`G8V]M;R!S92!C:&%M82!O('-E=2!A;FEM86P@9&4@97-T
M:6UAY^-O/R<Z`$EN=')O9'5Z82!O(%523"!D82!I;6%G96T@87%U:0!%;G1R
M861A<SH@)60@=&]T86PL("5D(&%C='5A;&EZ861A<RP@)60@;F]V87,L("5D
M(&%L=&5R861A<RP@)60@9&5S8V]N:&5C:61A<P!'=6ENZ2!%<75A=&]R:6%L
M`$5S=&%D;R!D82!%<FET<F5I80!%<G)O`$5R<F\@;F$@;65N<V%G96T@9&4@
M8V]R<F5I;R!E;&5C='+S;FEC;RX`17)R;R!A;R!E<V-R979E<B`B)7,B+@!%
M<G)O.B``4F5P^F)L:6-A(&1A($5S=/-N:6$`4F5P^F)L:6-A($1E;6]C<N%T
M:6-A($9E9&5R86P@9&$@171I\W!I80#)=&EC;P!%=7)O<&$`0V%D82`Q-2!M
M:6YU=&]S`$-A9&$@,B!M:6YU=&]S`$-A9&$@,S`@<V5G=6YD;W,`0V%D82`U
M(&UI;G5T;W,`0V%D82!%;G1R861A`$-A9&$@;65I82!H;W)A`$-A9&$@;6EN
M=71O`%9A;&]R97,@97AE;7!L;SH`17AE8W5T87(`17AE8W5T86YD;SH`17AP
M86YD:7(`36]S=')A<B!"87)R82!,871E<F%L`"<I)R!E<W!E<F%D;P!%<W!E
M<F%V82!U;6$@<VEM<&QE<R!P86QA=G)A(&]U('5M('1E<FUO(&1E('!R;V-U
M<F$@96YT<F4@87-P87,`1&%T82!D92!%>'!I<F'GXV\`17AP;V5N=&4`17AT
M<F%I;F1O(&1E("5S+BXN(`!#;W(@9&\@4')I;65I<F\@4&QA;F\`0V%R<F5G
M87(@8V]N9FEG=7)AY^-O(&1E(&EN<W1A;&'GXV\@<&]R($944`!.XV\@9F]I
M('!O<W/M=F5L('!U>&%R(&%S('!R969E<NIN8VEA<RX`1F%L:&$@;F$@;&EG
M8>?C;R!A;R!S97)V:61O<B!,1$%0+@!&86QH82!N82!L:6=AY^-O(&%O('-E
M<G9I9&]R(%--0BX`1F%L:&$@86\@8V]P:6%R(&1E("(E<R(N`$9A;&AA(&%O
M(&-O<&EA<B!P87)A("(E<R(N`$9A;&AA(&%O(&-R:6%R('5M82!N;W9A(&-O
M;F5XXV\@4T%33"X`1F%L:&$@86\@;6]V97(@<&%R82`B)7,B+@!";VT`26QH
M87,@1F%L:VQA;F0@*$UA;'9I;F%S*0!);&AA<R!&87)O90!%<G)O($9A=&%L
M.@!&87@`1F5V97)E:7)O`$%P87)E;G1A`$%P87)E;G1A.B``06QG=6YS($%G
M=6%C96ER;W,`06QG=6YS($YE=O5E<P!-871R:7H@9&4@8V%M<&]S`$9I:FD`
M0V]N=&%G96T@9&4@07)Q=6EV;W,Z("5S(&%R<75I=F\`0V]N=&%G96T@9&4@
M07)Q=6EV;W,Z("5S(&%R<75I=F]S`$=E<W3C;R!D92!&:6-H96ER;W,`3F]M
M92!D;R!!<G%U:79O`%-E;&5CY^-O(&1O(&%R<75I=F\`0V%R<F5G86UE;G1O
M(&1E(&%R<75I=F\`0V%R<F5G86UE;G1O<R!D92!F:6-H96ER;W,@;N-O('/C
M;R!S=7!O<G1A9&]S+@!&:6QT<F]S`$9I;FSB;F1I80!1=6%R=&\@0W)E<V-E
M;G1E`%%U87)T;R!#<F5S8V5N=&4`1FEX87(@<N%C:6\`26YV97)T97(`1FQU
M='5A;G1E`$YE=F]E:7)O`$$@<&%S=&$@)7,@;N-O(&5X:7-T92X`0V]R(&1O
M(%1E>'1O`$-O;6ED80!087)A(&YA=F5G861O<F5S('%U92!NXV\@<W5P;W)T
M86T@:6UA9V5N<P!0<F5V:7/C;R`H5$%&*0!$:6%S(&1E(%!R979I<^-O("AN
M;W1E+7-E('%U92!A<R!P<F5V:7/U97,@:6YC;'5E;2!T86YT;R!D:6%S(&-O
M;6\@;F]I=&5S.R!U;2!V86QO<B!D96UA<VEA9&\@9W)A;F1E('!O9&4@<F5S
M=6QT87(@;G5M(&)L;V-O(&UU:71O(&QA<F=O*0!%<W%U96-E=2US92!D82!P
M86QA=G)A+7!A<W-E/P!-;V1E;&]S`$1I=&]S`%1I<&\@9&4@9&ET;W,`1&ET
M;W,`1&ET;W,@,@!&\W)U;G,`4F5E;G9I;W,`07!L:6-AY_5E<R`H;?-D=6QO
M<RD@96YC;VYT<F%D87,Z("5S`%!A<W1A<R!E;F-O;G1R861A<SH`-JH`36]L
M9'5R87,`4F5P^F)L:6-A($9R86YC97-A`$9R86[G82P@365T<F]P;VQI=&%N
M80!'=6EA;F$@1G)A;F-E<V$`4&]L:6[I<VEA($9R86YC97-A`%1E<G)A<R!!
M=7-T<F%I<R!E($%N=.%R8W1I8V%S($9R86YC97-A<P!$90!$92``1&5S8W)I
MY^-O($-O;7!L971A`$QU82!#:&5I80!.;VUE($-O;7!L971O`$1I9G5S87,`
M4F5P^F)L:6-A($=A8F]N97-A`$=A;&5R:6$@9&4@;VYD92!R971I<F%R(&$@
M:6UA9V5M`$=A;&5R:6$Z`%)E</IB;&EC82!D82!'XFUB:6$`1V5R87(@0V]N
M9FEG=7)AY^-O("5S`$/S9&EG;R!'97)A9&\`1V5R86YD;R!O(&5S=&%D;R!D
M;R!M\V1U;&\@)7,N+BX`1V7S<F=I80!297#Z8FQI8V$@1F5D97)A;"!D82!!
M;&5M86YH80!%<G)O(&5M(&=E=&]P=#H`4F5P^F)L:6-A(&1O($=A;F$`1VEB
M<F%L=&%R`$YO;64@4'+S<')I;P!)<@!']F1E;`!097-Q=6ES82!';V]G;&4`
M3NUV96ES(&1E(&-I;GIE;G1O`$=RZ6-I80!'<F5G;R`H25-/+3@X-3DM-RD`
M1W)O;F5LXFYD:6$`1W)A;F%D80!!9&UI;FES=')AY^-O(&1E($=R=7!O<P!.
M;VUE<R!D92!G<G5P;W,@;N-O('!O9&5M(&5S=&%R('9A>FEO<P!097)M:7-S
M]65S(&1E(&=R=7!O`$=R=7!O<P!'=6%D86QU<&4`1W5A;0!297#Z8FQI8V$@
M9&$@1W5A=&5M86QA`$=U97)N<V5Y`%!E<FUI<W/U97,@9&%S(%9I<VET87,`
M4&5R;6ES<_5E<R!D87,@5FES:71A<P!,:79R;R!D92!6:7-I=&%S`$=U:6[I
M`$=U:6[I+4)I<W-A=0!297#Z8FQI8V$@0V\M;W!E<F%T:79A(&1A($=U:6%N
M80!(5$U,`$\@2%1-3$%R96$@<F5C=7-A+7-E(&-O8F%R9&5M96YT92!A(')E
M;6]V97(@82#Z;'1I;6$@8^EL=6QA(&1A(&QI;FAA+@!/($A434Q!<F5A(')E
M8W5S82US92!C;V)A<F1E;65N=&4@82!R96UO=F5R(&$@^FQT:6UA(&-O;'5N
M82!D82!T86)E;&$N`$\@2%1-3$%R96$@<F5C=7-A+7-E(&-O8F%R9&5M96YT
M92!A(')E;6]V97(@82#Z;'1I;6$@;&EN:&$@9&$@=&%B96QA+@!!=71E;G1I
M8V'GXV\@2%104"!NXV\@9F]I(&5N8V]N=')A9&$N`%)E</IB;&EC82!D;R!(
M86ET:0!!;&=O<FET;6\@9&4@(DAA<V@B`$YE8FQI;F$`0V%B9>=A;&AO`$EL
M:&%S($AE87)D(&4@36-$;VYA;&0`5&5M<&]R86PM5"!&;W)T90!(96)R974@
M*$E33RTX.#4Y+3@M22D`06QT=7)A`$%J=61A`$%J=61A('-O8G)E(&\@961I
M=&]R`$%J=61A`$%P;&EC8>?C;R!A=7AI;&EA<B!P87)A(&-R:6%R(&4@;6%N
M=&5R('1R861UY_5E<R!D82!P;&%T869O<FUA"DAO<F1E(&4@9&%S('-U87,@
M87!L:6-AY_5E<R`H;?-D=6QO<RDN"E!A<F$@=6UA(&EN=')O9'7GXV\@;&5R
M(&\@9FEC:&5I<F\@4D5!1$U%(&YE<W1A('!A<W1A+@!(96UI<V;I<FEO`$%Q
M=6D@97-TX2!O(&EN[6-I;R!D;R!A<G%U:79O.@!!;'1A`$YO;65S(&1A<R!E
M;G1R861A<R!H:7-T\W)I87,@;N-O('!O9&5M(&5S=&%R('9A>FEO<P!#85]S
M80!%<W1A9&\@9&$@0VED861E(&1O(%9A=&EC86YO`$-A<V$`16YD97)EYV\@
M9&4@0V%S80!496QE9F]N92!D92!#87-A`%)E</IB;&EC82!D87,@2&]N9'5R
M87,`2&]N9W5E8V]N9W5E`$AO<F1E`$=E<F%D;W(@9&4@=')A9'7G]65S($AO
M<F1E`$AO<F1E+TMO;&%B.B!$861O<R!834P@)7,@:6YVX6QI9&]S(&YA(&UE
M;G-A9V5M("5S`$AO<F1E+TMO;&%B.B!.96YH=6UA(&UE;G-A9V5M(&-O<G)E
M<W!O;F1E(&%O(&]B:F5C=&\@)7,`2&]R9&4O2V]L86(Z($YE;FAU;2!O8FIE
M8W1O(&1O('1I<&\@)7,@96YC;VYT<F%D;R!N82!M96YS86=E;2`E<P!(;W)D
M92]+;VQA8CH@4F5M;^?C;R!D92`E<R`B)7,B('1E=F4@<W5C97-S;P!(;W)D
M92]+;VQA8CH@4VEN8W)O;FEZ8>?C;R!D92`E<R`B)7,B('1E=F4@<W5C97-S
M;P!(;W)D92]+;VQA8CH@3R!M;W1O<B!D92!I;G1E9W)AY^-O(')E<75E<B!A
M(&5X=&5N<^-O(%!(4"`G9&]M>&UL)P!(;W)D92]+;VQA8CH@3N-O(&9O:2!P
M;W-S[79E;"!C<FEA<B!U;6$@;F]V82#A<G9O<F5S(%A-3"!P87)A(&\@;V)J
M96-T;R`E<P!(;W)D92]+;VQA8CH@3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R
M("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!.XV\@9F]I('!O<W/M=F5L(&]B
M=&5R(&\@240@34E-12!P87)A(&$@<&%R=&4@9&4@=&EP;R`E<P!(;W)D92]+
M;VQA8CH@3N-O(&9O:2!P;W-S[79E;"!S:6YC<F]N:7IA<B`E<R`B)7,B.B`E
M<P!(;W)D92]+;VQA8CH@3N-O(&9O:2!P;W-S[79E;"!S:6YC<F]N:7IA<B!P
M87)T:6QH87,Z("5S`$AO<F1E+TMO;&%B.B!087)T:6QH82`B)7,B(&1E<V-O
M;FAE8VED80!4<F'G;R!(;W)I>F]N=&%L`$5N8VAI;65N=&\@:&]R:7IO;G1A
M;`!(;W)I>F]N=&%L.@!#;VUO(&-H96=O=2!A<75I/R`H4&]R(&9A=F]R(')E
M<&]R=&4M;R$I`%%U86YT87,@8V]L=6YA<R!P<F5T96YD92!J=6YT87(_`%%U
M86YT;W,@8V%M<&]S("AC;VQU;F%S*2!E>&ES=&5M/P!1=6%N=&%S(&QI;FAA
M<R!P<F5T96YD92!J=6YT87(_`$AU;6ED861E`$AU;6ED861E.B``2'5M;W)I
M<W1A<P!297#Z8FQI8V$@9&$@2'5N9W)I80!!(&-R:6'GXV\@9&$@8V%I>&$@
M<&]S=&%L($E-05`@9F%L:&]U.B`E<P!296UOY^-O(&1A(&-A:7AA('!O<W1A
M;"!)34%0(&9A;&AO=3H@)7,`0W)I8>?C;R!D92!Q=6]T82!D92!C86EX82!P
M;W-T86P@24U!4"!F86QH;W4Z("5S`$5N9&5R9>=O($E0`$5N9&5R9>=O($E0
M(&EN9&ES<&]N[79E;"X`16YD97)EYV\@25`@9F]R82!D;R!B;&]C;R!#2412
M('!E<FUI=&ED;RX`5FEO;&'GXV\@9&4@8FQO<75E:6\@9&4@25``25]N<V5R
M:7(@3&EN:&$@06YT97,`4F5P^F)L:6-A(&1A($ES;.)N9&D`07!E;F%S(,UC
M;VYE<P#-8V]N97,@8V]M(%1E>'1O`$YO;64@9&$@:61E;G1I9&%D93H`4V4@
M;N-O(&9O<B!M;W-T<F%D;R!C;W)R96-T86UE;G1E+"`E<R!P87)A(&\@86)R
M:7(@;G5M82!N;W9A(&IA;F5L82X`4V4@;N-O('9I<B!Q=6%L<75E<B#M8V]N
M92!A;R!U<V%R(&\@26YT97)N970@17AP;&]R97(L('!O9&4@<')E8VES87(@
M9&4@<V5L96-C:6]N87(@97-T82!C86EX82!P87)A(&1E<VQI9V%R(&$@=')A
M;G-P87+J;F-I82X`4V4@=FER(&5S=&$@;65N<V%G96T@;FUA<R!NXV\@82!I
M;6%G96T@<')O<')I86UE;G1E(&1I=&$L(&$@:6UA9V5M('%U92!P<F5T96YD
M92!C87)R96=A<B!NXV\@<&]D92!S97(@;6]S=')A9&$@<&5L;R!S974@;F%V
M96=A9&]R+@!0<F5V:7/C;R!D82!);6%G96TZ`%523"!D82!I;6%G96T`55),
M(&1A(&EM86=E;3H`26UA9V5M(&1E(&=A;&5R:6$`26UA9V5M(&1E(&=A;&5R
M:6$Z`$-A<G)E9V%M96YT;R!D82!I;6%G96T`26UA9V5N<P!);7!O<G1A<BP@
M4&%S<V\@)60`0V%M<&\@:6UP;W)T861O.B`E<P!#86UP;W,@:6UP;W)T861O
M<SH`26Y?<V5R:7(@3&EN:&$@1&5P;VES`$/S9&EG;R!D92!A8^?C;R!I;G1R
M;V1U>FED;R!E<W3A(&EN8V]R<F5C=&\N`$YO;64@9&4@=71I;&EZ861O<B!O
M=2!P86QA=G)A+7!A<W-E(&5R<F%D;W,N`$YO;64@9&4@=71I;&EZ861O<B!O
M=2!E;F1E<F7G;R!A;'1E<FYA=&EV;R!E<G)A9&]S+B!#;VYT86-T92!O('-E
M=2!A9&UI;FES=')A9&]R(&1E('-I<W1E;6$@<&%R82!O8G1E<B!A:G5D82X`
M075M96YT87(@82!);F1E;G1AY^-O`%)E</IB;&EC82!D82#-;F1I80!5=&EL
M:7IA9&]R97,@26YD:79I9'5A:7,`4F5P^F)L:6-A(&1A($EN9&]NZ7-I80!)
M;F9O<FUAY^-O`$EN9F]R;6'GXV\`26YF;W)M8>?C;R!JX2!NXV\@97-TX2!D
M:7-P;V[M=F5L`$EN:6-I86QI>F%N9&\@;R!M\V1U;&\@)7,N+BX@`$EN<V5R
M:7(@0U]O;'5N82!$97!O:7,`26YS97)I<B!);6%G96T`26YS97)I<B!486)E
M;&$`26YS97)I<B!,:6=AY^-O(.`@5V5B`$EN<V5R:7(@7T-O;'5N82!!;G1E
M<P!);G-I<FER('5M82!N;W9A(&-O;'5N82!D97!O:7,@9&$@8V]R<F5N=&4`
M26YS:7)I<B!U;6$@;F]V82!C;VQU;F$@86YT97,@9&$@8V]R<F5N=&4`26YS
M:7)I<B!U;6$@;F]V82!L:6YH82!D97!O:7,@9&$@8V]R<F5N=&4`26YS:7)I
M<B!U;6$@;F]V82!L:6YH82!A;G1E<R!D82!C;W)R96YT90!);G-E<FER('5M
M('!A<N%G<F%F;R!A</-S(&\@;O,@8V]R<F5N=&4`26YS97)I<B!U;2!P87+A
M9W)A9F\@86YT97,@9&\@;O,@8V]R<F5N=&4`26YS:7)I<B!M;V1E;&\@86QT
M97)N871I=F\`26YT<F]D=7IA('5M(&5N9&5R9>=O(&1E(&-O<G)E:6\@96QE
M8W1R\VYI8V\@;VYD92!P;W-S82!R96-E8F5R(&$@;F]V82!P86QA=G)A+7!A
M<W-E.@!);G-I<FER(&/I;'5L82!A</-S`$EN<V5R:7(@8^EL=6QA<R!A;G1E
M<P!);G-E<FER(&/I;'5L82!D97!O:7,`26YS97)I<B!C;VQU;F$@86YT97,`
M26YS97)I<B!M96YS86=E;G,`26YS97)I<B!P87+A9W)A9F\@86YT97,`26YS
M97)I<B!P87+A9W)A9F\@86YT97,`26YS97)I<B!L:6YH82!D97!O:7,`26YS
M97)I<B!L:6YH82!A;G1E<P!);G1R;V1U>F$@82!R97-P;W-T82!E>&EG:61A
M('!A<F$@82!P97)G=6YT82!D92!S96=U<F%NYV$Z`$EN<V5R:7(O36]D:69I
M8V%R($EM86=E;0!);G-E<FER+TUO9&EF:6-A<B!,:6=AY^-O`$-RZ61I=&\@
M:6YS=69I8VEE;G1E('!A<F$@96YV:6%R('!A<F$@82!L:7-T82!D92!D:7-T
M<FEB=6GGXV\N`$-RZ61I=&\@:6YS=69I8VEE;G1E+@!);G1E:7)O`$QI<W1A
M(&1E(&EN=&5I<F]S`%5$2"`H57-E<B!$871A($AE861E<BD@:6YVX6QI9&\N
M`$1A9&]S(%I)4"!I;G;A;&ED;W,`07!L:6-AY^-O(&EN=N%L:61A+@!)1"!D
M92!L;W1E("@B8F%T8V@B*2!I;G;A;&ED;RX`3W,@9&%D;W,@<W5B;65T:61O
M<R!SXV\@:6YVX6QI9&]S+@!%;F1E<F7G;R!D92!D97-T:6YO(&EN=N%L:61O
M+@!&;W)M871O(&1O(&%R<75I=F\@:6YVX6QI9&\`0VAA=F4@9&$@;&EC96[G
M82!I;G;A;&ED82X`3&]C86QI>F'GXV\@:6YVX6QI9&$@97-P96-I9FEC861A
M+@!M<V=?='EP92!I;G;A;&ED;RX`87!I7VED(&EN=N%L:61O(&]U(&5M(&9A
M;'1A+@!087+B;65T<F]S(&EN=N%L:61O<R!O=2!E;2!F86QT82X`4&5R;6ES
M<^-O('!A<F5N=&%L(&EN=N%L:61A+@!)1"!D92!P87)C96ER;R!I;G;A;&ED
M;RX`0_-D:6=O(&1E('!R;V1U=&\@:6YVX6QI9&\N`%!R;W1O8V]L;R!I;G;A
M;&ED;RX`1&5S=&EN873A<FEO(&EN=N%L:61O.B`B)7,B`$]B:F5C=&\@9&4@
M<&%R=&EL:&$@:6YVX6QI9&\`16YD97)EYV\@9&$@;W)I9V5M(&EN=N%L:61O
M+@!$861O<R!U;FEC;V1E(&EN=N%L:61O<RX`26YV96YTX7)I;P!297#Z8FQI
M8V$@27-LXFUI8V$@9&\@27+C;P!297#Z8FQI8V$@9&\@27)A<75E`%)E</IB
M;&EC82!D82!)<FQA;F1A`$EL:&$@9&4@36%N`%1E;7!O<F%I<RU4($ES;VQA
M9&]S`$5S=&%D;R!D92!)<W)A96P`16UI<W-O<@!)=.%L:6-O`%)E</IB;&EC
M82!)=&%L:6%N80!*86UA:6-A`$IA;F5I<F\`2F%PXV\`2F%P;V[J<R`H25-/
M+3(P,C(M2E`I`$IE<G-E>0!296EN;R!(87-H96UI=&$@9&$@2F]R9.)N:6$`
M2G5L:&\`2G5N:&\`2G5S=&EF:6-A<@!#96YT<F%R`$IU<W1I9FEC87(`2G5S
M=&EF:6-A<B#@($5S<75E<F1A`$IU<W1I9FEC87(@X"!$:7)E:71A`%)E</IB
M;&EC82!D;R!#87IA<75I<W3C;P!0<F5S97)V87(@;R!O<FEG:6YA;#\`4F5P
M^F)L:6-A(&1O(%%UZ6YI80!/('-E<G9I9&]R($ME<F)E<F]S(')E:F5I=&]U
M(&$@875T96YT:6-AY^-O+@!.;W9A=&]S(&YO(")+97)N96PB`$-R:6'GXV\@
M9&$@0VAA=F4`26UP<F5S<^-O(&1I9VET86P@9&$@8VAA=F4`0V]M<')I;65N
M=&\@9&$@8VAA=F4`5&EP;R!D82!#:&%V90!5=&EL:7IAY^-O(&1A($-H879E
M`$$@8VAA=F4@:N$@97AI<W1E(&YO('-E<G9I9&]R(&1E(&-H879E<R!P^F)L
M:6-A<RX`36GZ9&]S`%%U:7)I8F%T:0!297#Z8FQI8V$@4&]P=6QA<B!$96UO
M8W+A=&EC82!D82!#;W)E:6$`4F5P^F)L:6-A(&1A($-O<F5I80!#;W)E86YO
M("A%54,M2U(I`$MU=V%I=`!297#Z8FQI8V$@475I<F=U:7IE`%]$:7-P;W-I
MY^-O`$ED:6]M80!297#Z8FQI8V$@4&]P=6QA<B!$96UO8W+A=&EC82!,86\`
M475A<G1O($1E8W)E<V-E;G1E`%%U87)T;R!$96-R97-C96YT90#:;'1I;6$@
M06-T=6%L:7IAY^-O.@#:;'1I;6$@96YT<F%D83H@)7,`VFQT:6UA(&5N=')A
M9&$Z("5S(&1E("5S`-IL=&EM82!E;G1R861A.B!.=6YC80!297#Z8FQI8V$@
M9&$@3&5T\VYI80!,96D`1&ES<&]S:>?C;P!$96EX87(@=F%Z:6\@<&%R82!F
M:6-A<B!S96T@8F]R9&$`3.UB86YO`$5S<75E<F1A`$-A8F7G86QH;R!D82!E
M<W%U97)D80!686QO<F5S(.`@97-Q=65R9&$`3&5S;W1O`$QI8NER:6$`1W)A
M;F1E($IA;6%H:7)I>6$@4V]C:6%L:7-T82!0;W!U;&%R(,%R86)E(&1A($SM
M8FEA`$QI<W1E;G-T86EN90!#:'5V82`B36]L:&$M5&]L;W,B`$-H=79I<V-O
M<P!#:'5V:7-C;W,@36%T:6YA:7,`0VAU=FES8V]S(%9E<W!E<G1I;F]S`%!E
M<75E;F\@06=U86-E:7)O`$-H=79I<V-O(&-O;2!4<F]V;V%D80!1=65D82!D
M92!.979E`$YE=F4`(DQI;65R:6-K(@!,:6=AY^-O`$QI9V'GXV\@87!O;G1A
M('!A<F$Z`$QI9V%R(&\@96YD97)EYV\@9&4@8V]R<F5I;R!E;&5C='+S;FEC
M;R#@('#A9VEN82!D92!C;VUP;W-IY^-O(&%O(&UO<W1R87(`3&EG8>?U97,`
M0F]L:6YH;R!L:6YU>.IS`$QI<W1A("T@;R!U=&EL:7IA9&]R('!O9&4@=F5R
M(&$@<&%S=&$`3&ES=&%R($)A<V5S(&1E($1A9&]S`$UO<W1R87(@5/-P:6-O
M<R!D92!!:G5D80!,:7-T87(@5&%B96QA<P!,:7-T86=E;2U!<G%U:79O`$QI
M<W1A9V5M+4%J=61A`$E$(&1A($QI<W1A`$QI<W1A9V5M+41O;F\`3&ES=&%G
M96TM4W5B;6ES<_5E<P!,:7-T86=E;2U3=6)S8W)I=&%S`$QI<W1A9V5M+4[C
M;R!S=6)S8W)I=&%S`$$@;&ES=&%G96T@9&4@=71I;&EZ861O<F5S(&5S=.$@
M9&5S86-T:79A9&$N`$QI=&5R871U<F$Z`%)E</IB;&EC82!D82!,:71UXFYI
M80!#87)R96=A;F1O(&)I8FQI;W1E8V%S+BXN`$-A<G)E9V%N9&\N+BX`5&5M
M<&\@;&]C86PZ`$QO8V%L:7IAY^-O(&4@1G5S;R!(;W+A<FEO`$QO8V%L:7IA
MY^-O`$5N=')A<@!386ER`%1A<F5F87,@9&4@16YT<F%D80!!(&%U=&5N=&EC
M8>?C;R!F86QH;W4@<&]R(&\@3F]M92!D92!5=&EL:7IA9&]R(&]U(&$@4&%L
M879R82U087-S92!E<W1A<F5M(&EN8V]R<F5C=&]S+@!!(&%U=&5N=&EC8>?C
M;R!F86QH;W4N`%1E>'1O(&QO;F=O`$%M;W(`0F%I>&\`3&5T<F%S(&=R96=A
M<R!M:6[Z<V-U;&%S`$QE=')A<R!L871I;F%S(&UI;OIS8W5L87,`3OIM97)O
M<R!R;VUA;F]S(&UI;OIS8W5L;W,`3'5X96UB=7)G;P!-30!-3U1$`$\@86YE
M>&\@35,M5$Y%1B!NXV\@8V]N=&EN:&$@9&%D;W,N`$U31P!-86-A=0!-86-E
M9/-N:6$L($%N=&EG82!297#Z8FQI8V$@2G5G;W-L879A(&1A`$UA9&%GX7-C
M87(`36%G:6$`0V]R<F5I;P!!9&UI;FES=')AY^-O(&1E($-O<G)E:6\`1F%Z
M97(@;&E?9V'GXV\N+BX`07-S96=U<F4M<V4@9&4@<75E('1E;2!O(%!%05(@
M:6YS=&%L861O(&4@;F\@8V%M:6YH;R!D92!I;F-L=7/U97,@*&EN8VQU9&4@
M<&%T:"DN`$-R:6%N9&\@82!P87-T82`E<P!-86QA=6D`36%LX7-I80!-86QD
M:79A<P!-86QI`$UA;'1A`$=I<F$@82!L:7-T82!D92!C871E9V]R:6%S('%U
M92!P;V1E(&%T<FEB=6ER(&%O<R!I=&5N<RP@8F5M(&-O;6\@87,@8V]R97,@
M<75E(&QH97,@97-TXV\@87-S;V-I861A<RX`36%P82!-87`R-`!-87!A($UA
M<%%U97-T`$UA<N=O`$UA<F=E;0!-87)C87(@8V]M;R!,:61A+T[C;R!L:61A
M`$UA<F-A<B!D92!O=71R87,@9F]R;6%S("AE+F<N+"!);7!O<G1A;G1E+U!O
M<B!R97-P;VYD97(I`$EL:&%S($UA<G-H86QL`$UA<G1I;FEC80!#86UP;W,@
M<75E(&-O<G)E<W!O;F1E;0!-875R:73B;FEA`$UA=7+M8VEO`$WA>&EM;R!C
M<NED:71O('!E<FUI=&ED;RX`3>%X:6UO(&[Z;65R;R!D92!P87)T97,@;G5M
M82!M96YS86=E;2!E>&-E9&ED;RX`5&5M<&5R871U<F$@;>%X:6UA(&YA<R#Z
M;'1I;6%S(#(T(&AO<F%S.B``5&5M<&5R871U<F$@;>%X:6UA(&YA<R#Z;'1I
M;6%S(#8@:&]R87,Z(`!#;VUP<FEM96YT;R!MX7AI;6\`36%I;P!-87EO='1E
M`$UE9&EC:6YA`$UE;6)R;W,`36]D;R!D;R!M96YU.@!5;FER(&/I;'5L87,`
M26YT96=R86YD;R!T;V1O<R!O<R!F:6-H96ER;W,@)7,N<&\@8V]M(&\@8V]M
M<.IN9&EO+BXN`$EN=&5G<F%N9&\@82!L;V-A;&EZ8>?C;R`E<RXN+B``26YT
M96=R86YD;R!O(&%R<75I=F\@4$\@9&4@)7,@8V]M(&\@8V]M<.IN9&EO+BXN
M(`!);G1E9W)A;F1O(&$@=')A9'7GXV\@9&\@;?-D=6QO("5S+BXN`$UE;G-A
M9V5M`$UE;G-A9V5N(%9E<FEF:6-A9&$@8V]M(%-U8V5S<V\L(&UA<R!O(&-E
M<G1I9FEC861O(&1O('-U8G-C<FET;W(@;N-O('#T9&4@<V5R('9E<FEF:6-A
M9&\N`$UE;G-A9V5M(&5X<&ER;W4N`%1I<&\@9&4@;65N<V%G96T`365T96]R
M;VQO9VEA($U%5$%2`$)L;V-O($U%5$%2(&EN9&ES<&]N[79E;"X`0FQO8V\@
M345405(@:6YD:7-P;V[M=F5L+B!/<R!P;W)M96YO<F5S(&9O<F%M(')E9VES
M=&%D;W,@<&%R82!O(&%D;6EN:7-T<F%D;W(N`$$@365T87)$0B!NXV\@97-T
MX2!C;VYE8W1A9&$N`$WI=&]D;P!/(&WI=&]D;R`B)7,B(&[C;R!E<W3A(&1E
M9FEN:61O`$WI=')I8V\`3>EX:6-O`$UI8W)O;NES:6$L($5S=&%D;W,@1F5D
M97)A9&]S(&1A`$-E;G1R;P!4:7!O($U)344`5&5M<&5R871U<F$@;>UN:6UA
M(&YA<R#Z;'1I;6%S(#(T(&AO<F%S`%1E;7!E<F%T=7)A(&WM;FEM82!N87,@
M^FQT:6UA<R`V(&AO<F%S`$5S<&5L:&\`36ES8V5LXFYE80!086-O=&4@2%14
M4%]297%U97-T(&1O(%!%05(@96T@9F%L=&$N`$-O;F9I9W5R8>?C;R!E;2!F
M86QT82X@5&5RX2!D92!A(&=E<F%R(&%G;W)A('-E('%U:7-E<B!U<V%R(&5S
M=&$@87!L:6-AY^-O+@!)1"!D82!M96YS86=E;2!E;2!F86QT82X`4&%C;W1E
M($UA:6P@9&\@4$5!4B!E;2!F86QT82X`240@9&$@<V5S<^-O(&5M(&9A;'1A
M+@`RJ@!#;W)R96EO($WS=F5L`$UO9&5R861O`$1A=&$@9&4@36]D:69I8V'G
MXV\`36]D:69I8V%R(%523`!-\V1U;&\`3?-D=6QO`%)E</IB;&EC82!D82!-
M;VQD;W9A`%!R:6YC:7!A9&\@9&\@3?-N86-O`$UO;F?S;&EA`$WJ<R!E(&%N
M;P!-96YS86QM96YT90!-;VYT<V5R<F%T`$9A<V4@9&$@3'5A`%)E:6YO(&1E
M($UA<G)O8V]S`%-O8G)E='5D;R!,:6UP;P!3;V)R971U9&\@16YE=F]A9&\`
M4V]B<F5T=61O(%-O;&%R96YG;P!$97-C97(`36]V97(@<&%R82!A($5S<75E
M<F1A`$UO=F5R('!A<F$@82!$:7)E:71A`%-U8FER`$1E<V-E<@!3=6)I<@!2
M97#Z8FQI8V$@9&4@36_G86UB:7%U90!,:7-T87,@9&4@9&5S96YR;VQA<B!M
M=6QT:2UN[79E;`!396QE8^?C;R!M^FQT:7!L80!!($UI;FAA($-O;G1A`$\@
M365U(%!O<G1A;`!$:7-P;W-IY^-O(&1O(%!O<G1A;`!5;FGC;R!D92!->6%N
M;6%R`$[C;RP@;N-O(&-O;F-O<F1O`$YO;64`4F5P^F)L:6-A(&1A($YA;>UB
M:6$`3F%U<G4`3F5P86P`4F5I;F\@9&]S(%!A[7-E<R!"86EX;W,`06YT:6QH
M87,@2&]L86YD97-A<P!54DP@9&4@0F%S92!.971S8V%P90!54DP@9&4@4F5V
M;V=AY^-O($-!($YE='-C87!E`%523"!C;VT@82!P;VSM=&EC82!D92!#02!.
M971S8V%P90!54DP@9&4@4F5N;W9AY^-O($YE='-C87!E`%523"!D92!2979O
M9V'GXV\@3F5T<V-A<&4`3F]M92!D;R!S97)V:61O<B!34TP@3F5T<V-A<&4`
M0V]M96YTX7)I;R!D92!C97)T:69I8V%D;R!.971S8V%P90!4:7!O(&1E(&-E
M<G1I9FEC861O($YE='-C87!E`%)E9&4`3G5N8V$`3F]V82!#86QE9/-N:6$`
M3F]V82!#871E9V]R:6$`3'5A($YO=F$`3F]V;R!.;VUE(&1E(%5T:6QI>F%D
M;W(@*&]P8VEO;F%L*0!.;W9A(%IE;.)N9&EA`$YO=F$@:F%N96QA("A?8FQA
M;FLI`$YO=.UC:6%S`$=R=7!O<R!D92!.;W3M8VEA<P!0<O-X:6UA`%!R\WAI
M;6%S(#0@1F%S97,`4'+S>&EM87,@;W#G]65S`%!R\WAI;6$^`%)E</IB;&EC
M82!D82!.:6-A<N%G=6$`4F5P^F)L:6-A(&1O($[M9V5R`%)E</IB;&EC82!&
M961E<F%L(&1A($YI9V5R:6$`3F]I=&4`3FEU90!.XV\`3N-O(&CA(&1A9&]S
M(&1E(&-O;F9I9W5R8>?C;R!D:7-P;V[M=F5I<R!E;2!R96QAY^-O(&%O<R!Q
M=6%I<R!M;W-T<F%R(&1I9F5R96[G87,N`$[C;R!HX2!N96YH=6UA(&5S=')A
M=.EG:6$@9&ES<&]N[79E;"!P87)A(')E86QI>F%R(&EM86=E;G,@25-/+@!.
MXV\@:.$@;6]D96QO(&1E(&QO=&4@(F)A=&-H(BX`3N-O(&5X:7-T92!B;&]C
M;R!N82!P;W-IY^-O(&EN9&EC861A`$[C;R!F;VD@9F]R;F5C:61O('5M(&YO
M;64@9&4@8V%L96YDX7)I;R!P87)A(&$@875T96YT:6-AY^-O($U#04PN`%-E
M;2!M;V1I9FEC8>?U97,N`$[C;R!S92!P;V1E(&%D:6-I;VYA<B!P97)M:7-S
M]65S(&1E(&9I;&AO<R!A8F%I>&\@9&5S=&4@;NUV96PN`$[C;R!S92!P;V1E
M(&%D:6-I;VYA<B!F:6QH;W,@82!E<W1A('!E<FUI<W/C;RX`3F5N:'5M(&-O
M;6%N9&\@97-P96-I9FEC861O+@!.XV\@9F]I(&5S<&5C:69I8V%D82!A(&EN
M9F]R;6'GXV\@9&4@8V]N9FEG=7)AY^-O('!A<F$@)7,N`$[C;R!F;VD@97-P
M96-I9FEC861A(&$@:6YF;W)M8>?C;R!D92!C;VYF:6=U<F'GXV\@<&%R82!6
M1E,@8F%S96%D;R!E;2!&5%`N`$[C;R!F;VD@97-P96-I9FEC861A(&$@:6YF
M;W)M8>?C;R!D92!C;VYF:6=U<F'GXV\@;F5C97-SX7)I82!P87)A(&\@5D93
M(&)A<V5A9&\@96T@4U%,+@!.XV\@9F]I(&5S<&5C:69I8V%D82!A(&EN9F]R
M;6'GXV\@9&4@8V]N9FEG=7)AY^-O(&YE8V5S<^%R:6$@<&%R82!O(%9&4R!B
M87-E861O(&5M(%-13"U&:6QE+@!#<NED:71O(&5S9V]T;W4N`$YE;FAU;2!D
M97-T:6YA=.%R:6\@9F]I(&9O<FYE8VED;RX`3N-O(&5X:7-T92!Q=6%L<75E
M<B!E;G1R861A(&-O;2!O(&ED("(E<R(@;F\@87)Q=6EV;R!D92!A:G5D82!O
M<FEG:6YA;"X`3N-O('-E(&-A<G)E9V]U(&YA9&$N`$YE;FAU;6$@;&]C86QI
M>F'GXV\@97-P96-I9FEC861A+@!&86QT82!I;F1I8V%R('5M82!L;V-A;&EZ
M8>?C;RX`02!L;V-A;&EZ8>?C;R!NXV\@9F]I(&5S<&5C:69I8V%D82X`3F5N
M:'5M82!M96YS86=E;2!F;VD@9F]R;F5C:61A+@!.96YH=6T@;F]M92!E<W!E
M8VEF:6-A9&\N`$YE;FAU;2!N^FUE<F\@97-P96-I9FEC861O+@!396T@9&ET
M;W,@;V9E;G-I=F]S`$[C;R!F;VD@9F]R;F5C:61A('!A;&%V<F$M<&%S<V4@
M<&%R82!A(&%U=&5N=&EC8>?C;R!(5%10+@!.XV\@9F]I(&9O<FYE8VED82!P
M86QA=G)A+7!A<W-E('!A<F$@82!A=71E;G1I8V'GXV\@24U!4"X`3N-O(&9O
M:2!F;W)N96-I9&$@<&%L879R82UP87-S92!P87)A(&$@875T96YT:6-AY^-O
M($ME<F)E<F]S+@!.XV\@9F]I(&9O<FYE8VED82!P86QA=G)A+7!A<W-E('!A
M<F$@82!A=71E;G1I8V'GXV\@3$1!4"X`3N-O(&9O:2!F;W)N96-I9&$@<&%L
M879R82UP87-S92!P87)A(&$@875T96YT:6-AY^-O($QO9VEN+@!.XV\@9F]I
M(&9O<FYE8VED82!P86QA=G)A+7!A<W-E('!A<F$@82!A=71E;G1I8V'GXV\@
M4$%34U=$+@!.XV\@9F]I(&9O<FYE8VED82!P86QA=G)A+7!A<W-E('!A<F$@
M82!A=71E;G1I8V'GXV\@4TU"+@!.XV\@9F]I(&EN9&EC861O(&-A;6EN:&\@
M<&%R82!O(&)I;N%R:6\@3W!E;E-33"X@3R!B:6[A<FEO($]P96Y34TP@Z2!N
M96-E<W/A<FEO('!A<F$@=')A8F%L:&%R(&-O;2!D861O<R!02T-3(#$R+@!.
MXV\@:.$@<W5B<V-R:>?U97,@<&5N9&5N=&5S+@!396T@=')AYV]S`%-E;2!L
M861O<P!.XV\@:.$@<&%S=&$@=&5M<&]RX7)I82!D:7-P;V[M=F5L('!A<F$@
M(F-A8VAE(BX`3N-O(&9O<F%M(&5N=FEA9&]S(&\@;F]M92!D;R!U=&EL:7IA
M9&]R(&]U(&$@<&%L879R82UP87-S92X`3N-O(&9O<F%M(')E=&]R;F%D;W,@
M9&%D;W,@96T@6$U,(';A;&ED;W,`4V5M('9A;&]R97,`3N-O(&9O:2!E;F-O
M;G1R861A('9E<G/C;R!N82!C;VYF:6=U<F'GXV\@;W)I9VEN86PN(%)E9V5N
M97)A<B!C;VYF:6=U<F'GXV\N`$[C;R!F;VD@96YC;VYT<F%D82!V97)SXV\@
M;F$@<W5A(&-O;F9I9W5R8>?C;RX@4F5G96YE<F%R(&-O;F9I9W5R8>?C;RX`
M3F5N:'5M80!.96YH=6T@*'5S87(@:6UP;.UC:71O*0!.\W)D:6-O("A)4T\M
M.#@U.2TQ,"D`26QH82!D92!.;W)F;VQK`$AE;6ES9NER:6\@3F]R=&4`26QH
M87,@36%R:6%N87,@9&\@3F]R=&4`4F5I;F\@9&$@3F]R=65G80!.=6YC82!$
M97!O:7,@9&4`3G5N8V$@06YT97,@9&4`3N-O(.D@=6T@9&ER96-T\W)I;P!.
MXV\@:6UP;&5M96YT861A+@!0;W(@871R:6)U:7(`3N-O('-U<&]R=&%D;RX`
M3F]T87,`3F%D82!P87)A(&YA=F5G87(L('9O;'1E('!A<F$@='+A<RX`3F]T
M80!.;W9E;6)R;P!.^FUE<F\`3OIM97)O(&1E(&-A<F%C=&5R97,`3OIM97)O
M(&1E(&-O;'5N87,`3OIM97)O(&1E(&QI;FAA<P!.82!L:7-T82!D92!D:7-T
M<FEB=6GGXV\@:.$@;OIM97)O<R!Q=64@;N-O(&9O<F%M(&5S<&5C:69I8V%D
M;W,@<&%R82!A8W1U86QI>F'GXV\N`$]+`$]B:F5C=&\`0W)I861O<B!D;R!/
M8FIE8W1O`%!E<FUI<W/U97,@9&\@8W)I861O<B!D;R!O8FIE8W1O`$]C=&%L
M`$]U='5B<F\`1FEL=')O(&1E(&UA=&5R:6%L(&]F96YS:79O`$=A8FEN971E
M`%-U;'1A;F%T;R!D;R!/;>,`4_,@;W,@<V5R=FED;W)E<R!)34%0('-U<&]R
M=&%M('!A<W1A<R!P87)T:6QH861A<RX`07!E;F%S(&1I=&]S(&]F96YS:79O
M<P!3\R#I('!E<FUI=&ED;R!U;2!E;F1E<F7G;R!D92!C;W)R96EO(&5L96-T
M<O-N:6-O+@!!<&5N87,@;R!D;VYO(&]U('5M(&%D;6EN:7-T<F%D;W(@9&4@
M<VES=&5M87,@<&]D92!A;'1E<F%R(&$@=&ET=6QA<FED861E(&1E('5M82!P
M87)T:6QH82!O=2!A<R!P97)M:7-S]65S(&1O('-E=2!D;VYO`$%B<F4@;G5M
M82!N;W9A(&IA;F5L80!%<G)O($]P96Y34TPZ($[C;R!F;VD@<&]S<^UV96P@
M97AT<F%I<B!D861O<R!D92!U;6$@<&%R=&4@87-S:6YA9&$@8V]M(%,O34E-
M12X`06)R92!E<W1A(&QI9V'GXV\@;G5M82!N;W9A(&IA;F5L80!3:7-T96UA
M($]P97)A=&EV;P!/<.?U97,`3W#G]65S(&1O("5S`$]PY_5E<SH`3&ES=&$@
M3W)D96YA9&$`3W)G86YI>F'GXV\`56YI9&%D92!/<F=A;FEZ86-I;VYA;`!/
M<F=A;FEZ8>?C;P!-;V1E;&\@;W)I9VEN86P@9&$@87!L:6-AY^-O`$UO9&5L
M;W,@;W)I9VEN86ES(&5M("5S.@!/=71R;P!/=71R87,@26YF;W)M8>?U97,`
M4&5R;6ES<_5E<R!D;R!$;VYO`$%U=&5N=&EC8>?C;R!004T@;N-O(&5S=.$@
M9&ES<&]N[79E;"X`07-S:6YA='5R82!$:6=I=&%L(%!'4`!$861O<R!E;F-R
M:7!T861O<R!01U``0VAA=F4@4/IB;&EC82!01U``1&%D;W,@07-S:6YA9&]S
M+T5N8W)I<'1A9&]S(&-O;2!01U``0_-D:6=O(%!(4`!#;VUA;F1O<R!02%``
M0VAU=FES8V]S('!E;&$@5&%R9&4`06=U86-E:7)O<R!D92!487)D90!.979E
M(.`@5&%R9&4`3F5V]65S(.`@5&%R9&4`4V]L(.`@5&%R9&4`5&5M<&]R86ES
M+50@X"!487)D90!#;VUA;F1O<R!07TA0`$5N8VAI;65N=&\`4F5P^F)L:6-A
M($ES;.)M:6-A(&1O(%!A<75I<W3C;P!297#Z8FQI8V$@9&4@4&%L874`5&5R
M<FET\W)I;R!086QE<W1I;FEA;F\`4&%N86WA`%!A<'5A($YO=F$@1W5I;ND`
M4F5P^F)L:6-A(&1O(%!A<F%G=6%I`%!A<F-I86QM96YT92!%;F-O8F5R=&\`
M4&%L879R82U087-S90!086QA=G)A+5!A<W-E(&EN8V]R<F5C=&$`4&%L879R
M82U087-S92!N96-E<W/A<FEA('!A<F$@875T96YT:6-AY^-O(%)!1$E54P!0
M86QA=G)A+5!A<W-E(&-O;2!C;VYF:7)M8>?C;P!086QA=G)A+5!A<W-E.@!0
M86QA=G)A+5!A<W-E.B``07,@<&%L879R87,M<&%S<V4@=.IM(&1E('-E<B!I
M9W5A:7,N`$-O;&%R`$-O;&%R(&1E(')E8V]R=&5S`$-A;6EN:&\`4W5B<V-R
M:>?U97,@4&5N9&5N=&5S.@!097-S;V%S`%!E<F-E;G1A9V5M`$5X96-U=&%R
M($]P97)AY_5E<R!D92!-86YU=&5NY^-O`$5X96-U=&%R(&]P97)AY_5E<R!D
M92!M86YU=&5NY^-O(&%Q=6%N9&\@9&$@96YT<F%D83\`4&5R;6ES<^-O`$$@
M<&5R;6ES<^-O("(E<R(@;N-O(&9O:2!R96UO=FED82X`061M:6YI<W1R8>?C
M;R!D92!097)M:7-S]65S`%!E<FUI<W/U97,@9&4`26YF;W)M8>?U97,@4&5S
M<V]A:7,`4&5R^@!!;FEM86ES(&1E($5S=&EM8>?C;P!&:6QI<&EN87,`5&5L
M969O;F4`1F]T;V=R869I87,`26QH87,@4&ET8V%I<FX`4.UX96ES`%!L871I
M='5D97,`4&]R(&9A=F]R(&-L:7%U92!S;V)R92!U;6$@8^EL=6QA`%!O<B!F
M879O<B!C;VYF:7)M92!S92!R96%L;65N=&4@<')E=&5N9&4@<F5M;W9E<B!E
M<W1E(&5L96UE;G1O.@!0;W(@9F%V;W(@8V]N9FER;64@<V4@<F5A;&UE;G1E
M('!R971E;F1E(&1E<VQI9V%R(&5S=&4@96QE;65N=&\N`%!O<B!F879O<B!I
M;G1R;V1U>F$@=6T@;>IS(&4@=6T@86YO+@!0;W(@9F%V;W(@:6YT<F]D=7IA
M(&\@;F]M92!D82!N;W9A(&-A=&5G;W)I83H`4&]R(&9A=F]R(&EN=')O9'5Z
M82!U;2!E;F1E<F7G;R!)4"!VX6QI9&\N`%!O<B!F879O<B!I;G1R;V1U>F$@
M=6UA(&1A=&$@=N%L:61A.R!V97)I9FEQ=64@;R!N^FUE<F\@9&4@9&EA<R!D
M;R!MZG,N`%!O<B!F879O<B!I;G1R;V1U>F$@=6UA(&AO<F$@=N%L:61A+@!0
M;W(@9F%V;W(L(&9O<FYEYV$@=6UA(&)R979E(&1E<V-R:>?C;R!D;R!P<F]B
M;&5M82X`4&]R(&9A=F]R+"!I;G1R;V1U>F$@;R!S974@3F]M92!D92!5=&EL
M:7IA9&]R(&4@82!S=6$@4&%L879R82U087-S90!0;W(@9F%V;W(@;&5I82!O
M('1E>'1O('-E9W5I;G1E+B!496T@9&4@0T].0T]21$%2(&-O;2!O<R!T97)M
M;W,@9&5S=&4@86-O<F1O('!A<F$@=7-A<B!O('-I<W1E;6$N`%!O<B!F879O
M<B!R97!O<G1E(&]S(&5R<F]S('!A<F$@:3$X;D!L:7-T<RYH;W)D92YO<F<`
M4&]R(&9A=F]R(&EN=')O9'5Z82!O(&YO;64@9&$@;F]V82!C871E9V]R:6$Z
M`%!O;/-N:6$`4&]L[71I8V$`4V]N9&%G96YS`%)E</IB;&EC82!0;W)T=6=U
M97-A`%!O<VEC:6]N86UE;G1O(&1E<W1A(&EM86=E;0!0;W-I8VEO;F%M96YT
M;R!D97-T82!T86)E;&$`(E!O<W0B('!A<F$@97-T82!P87-T82`H;N-O(.D@
M<F5Q=6ES:71O(&1O($E-05`I`%!R96-I<&ET8>?C;R!N87,@^FQT:6UA<R`E
M<R!H;W)A*',I.B``4')O8F%B:6QI9&%D92!D93QB<B`O/E!R96-I<&ET8>?C
M;P!0<F5F<U]L9&%P.B!!(&5X=&5N<^-O($Q$05`@;F5C97-SX7)I82!NXV\@
M9F]I(&5N8V]N=')A9&$N`%!R969S7W-E<W-I;VXZ($$@97AT96YSXV\@9&4@
M<V5S<^-O(&YE8V5S<^%R:6$@;N-O(&9O:2!E;F-O;G1R861A+@!0<F5S<^-O
M`%!R97-SXV\@86\@;NUV96P@9&\@;6%R.B``4')E<W/C;SH@`%!R979I<^-O
M`%!R979E<B!A(&EM86=E;2!N=6UA(&YO=F$@:F%N96QA`$]PY_5E<R!A;G1E
M<FEO<F5S`$EM<')I;6ER(&\@9&]C=6UE;G1O`$-H879E(%!R:79A9&$`4')O
M8FQE;6$`1&5S8W)IY^-O(&1O(%!R;V)L96UA`%!R;VIE8W1O<P!-96YS86=E
M;2UP<F]N=&\`0VAA=F4@4/IB;&EC80!!;&=O<FET;6\@9&4@0VAA=F4@4/IB
M;&EC80!);F9O<FUAY^-O(%-O8G)E(&$@0VAA=F4`3R!P87(@9&4@8VAA=F5S
M(%!U8FQI8V$O4')I=F%D82!NXV\@9F]I(&=E<F%D82!C;VT@<W5C97-S;RX`
M4&]R=&\@4FEC;P!%<W1A9&\@9&\@46%T87(`4&5D:61O`$-H879E(%#Z8FQI
M8V$@4E-!("@E9"!B:70I`%-E;&5CY^-O(")RX61I;R(`0VAU=F$`0VAU=F$@
M36%T:6YA;`!#:'5V82!697-P97)T:6YA`$%G=6%C96ER;P!#:'5V82!E($YE
M=F4`0VAU=F$@82!.979E`$1I=&\@06QE873S<FEO`%)E;&'GXV\`3&5R`$QE
M<B!M96YS86=E;G,`475E<B!M97-M;R!R96UO=F5R("5S/R!%<W1A(&]P97)A
MY^-O(&[C;R!T96T@<F5G<F5S<V\N`%)E;6]V97(@;65S;6\@;W,@9&%D;W,@
M9&\@=71I;&EZ861O<B`E<S\@17-T82!O<&5R8>?C;R!NXV\@=&5M(')E9W)E
M<W-O+@!2969A>B!A('-U82#Z;'1I;6$@86/GXV\`4F5F<F5S8V%R($5L96UE
M;G1O<R!D92!-96YU($1I;N)M:6-O.@!2969R97-C87(@5FES=6%L:7IAY^-O
M(&1O(%!O<G1A;#H`17AP<F5S<^-O(%)E9W5L87(`3F%V96=A9&]R(&1E(%)E
M;&'G]65S`$]B<V5R=F'G]65S`%-E<G9I9&]R97,@4F5M;W1O<P!54DP@4F5M
M;W1O("AH='1P.B\O=W=W+F5X96UP;&\N<'0O:&]R9&4I.@!296UO=F5R`%)E
M;6]V97(@0FQO8V\`4F5M;W9E<B!C;VQU;F$`4F5M;W9E<B!F;W)M871AY^-O
M`%)E;6]V97(@<&%R`%)E;6]V97(@;R`B<V-R:7!T(B!G=6%R9&%D;R!D82!P
M87-T82!T96UP;W+A<FEA(&1O('-E<G9I9&]R+@!296UO=F5R(&\`4F5M;W9E
M<B!E<W1E(&[S(&1O(&1O8W5M96YT;P!296UO=F5R(%5T:6QI>F%D;W(`4F5M
M;W9E<B!U=&EL:7IA9&]R.B`E<P!.XV\@9F]I('!O<W/M=F5L(')E<W!O;F1E
M<B!A;R!P961I9&\N($/S9&EG;R!D92!E<G)O(&1E=F]L=FED;SH@`$\@<V5R
M=FGG;R!P961I9&\@;N-O(&9O:2!E;F-O;G1R861A+@`B)7,B(&]B<FEG873S
M<FEO(&[C;R!F;VD@97-P96-I9FEC861O(&YA(&-O;F9I9W5R8>?C;R!D92`E
M<RX`(B5S(B!O8G)I9V%T\W)I;R!NXV\@9F]I(&5S<&5C:69I8V%D;R!N82!C
M;VYF:6=U<F'GXV\@5D93+@`B)7,B(&]B<FEG873S<FEO(&[C;R!F;VD@97-P
M96-I9FEC861O(&YA(&-O;F9I9W5R8>?C;RX`0V%M<&\@3V)R:6=A=/-R:6\`
M3&EM<&%R`%)E:6YI8VEA<B!086QA=G)A+5!A<W-E`%)E:6YI8VEE(&$@4W5A
M(%!A;&%V<F$M4&%S<V4`4F5S=6QT861O<P!297-U;'1A9&]S("AI;F-L=6EN
M9&\@2&]R9&4I.@!297-U;'1A9&]S.@!6;VQT87(@X',@3W#G]65S`%)E=6YI
MXV\`4D5V97)T97(@0V]N9FEG=7)AY^-O`$]PY_5E<R!D92!%9&GGXV\@4FEC
M80!!9&EV:6YH87,`1&ER96ET80!#86)EYV%L:&\@9&$@9&ER96ET80!686QO
M<F5S(.`@9&ER96ET80!0<F]P<FEE9&%D97,@9&$@3&EN7VAA+BXN`%)E9W)A
M`%)O;>EN:6$`4F]D87(@,3@P`%)O9&%R(.`@17-Q=65R9&$`4F]D87(@X"!D
M:7)E:71A`%!R;W!R:65D861E<R!D82!,:6YH80!0<F]P<FEE9&%D97,@9&$@
M;&EN:&$`3&EN:&%S.@!4<F'G;W,`5')AYV]S(&%P87)E8V5RXV\@96YT<F4@
M=&]D87,@87,@;&EN:&%S(&4@8V]L=6YA<P!4<F'G;W,@87!A<F5C97+C;R!A
M<&5N87,@96YT<F4@87,@8V]L=6YA<P!4<F'G;W,@87!A<F5C97+C;R!A<&5N
M87,@96YT<F4@;&EN:&%S`$5X96-U=&%R`$9E9&5R8>?C;R!2=7-S80!297#Z
M8FQI8V$@9&\@4G5A;F1A`$%S<VEN871U<F$@0W)I<'1O9W+A9FEC82!3+TU)
M344`365N<V%G96T@16YC<FEP=&%D82!C;VT@4R]-24U%`$%U=&5N=&EC8>?C
M;R!305-,(&EN9&ES<&]N[79E;"X`365N<V%G96YS(%--4P!#;VUA;F1O<R!3
M44P`4U-(`%-50T534T\`0V]M86YD;W,@4U]13`!SX0!386YT82!(96QE;F$`
M4^-O($MI='1S(&4@3F5V:7,`4V%N=&$@3/IC:6$`4^-O(%!E9')O(&4@36EQ
M=65L;VX`4^-O(%9I8V5N=&4@92!'<F5N861I;F5S`$UE<VUA(&UO;&1U<F$@
M*%]S96QF*0!%<W1A9&\@26YD97!E;F1E;G1E(&1A(%-A;6]A`%)E</IB;&EC
M82!397)E;NUS<VEM82!D92!3XV\@36%R:6YO`%/C;R!4;VWI(&4@4'+M;F-I
M<&4`1F]R;F5C961O<B!D;R!3873I;&ET90!!<N%B:6$@4V%U9&ET80!'=6%R
M9&%R`$=U87)D87(@)7,`1W5A<F1A<B`G)7,G`$=U87)D87(@3W#G]65S`$=U
M87)D87(@8V]N9FEG=7)AY^-O(&=E<F%D82!C;VUO('5M(")S8W)I<'0B(%!(
M4"!N;R!D:7)E8W3S<FEO('1E;7!O<N%R:6\@9&\@<V5U('-E<G9I9&]R+@!'
M=6%R9&5I(&-O;F9I9W5R8>?C;R`E<RX`1W5A<F1E:2!O(")S8W)I<'0B(&1E
M(&%C='5A;&EZ8>?C;R!E;3H@(B5S(BX`5&5M<&]R86ES+50@1&ES<&5R<V]S
M`$-IZFYC:6$`4')O8W5R87(`36]T;W)E<R!D92!0<F]C=7)A`%!R;V-U<F%N
M9&\@87!L:6-AY_5E<R`H;?-D=6QO<RD@2&]R9&4@96T@)7,`4')O8W5R86YD
M;R!O<R!B:6[A<FEO<R!D92!G971T97AT+BXN`%-E;&5C8VEO;F%R($%R<75I
M=F]S`%-E;&5C8VEO;F4@=6UA(&1A=&$`4V5L96-C:6]N92!U;2!G<G5P;R!A
M(&%C<F5S8V5N=&%R`%-E;&5C8VEO;F%R('5M(&YO=F\@9&]N;P!396QE8V-I
M;VYE('5M('-E<G9I9&]R`%-E;&5C8VEO;F4@=6T@=71I;&EZ861O<B!A(&%D
M:6-I;VYA<@!396QE8V-I;VYE('1O9&]S(&]S(&-O;7!O;F5N=&5S(&1A(&1A
M=&$N`%-E;&5C8VEO;F4@=6T@;V)J96-T;P!396QE8V-I;VYE(&]S(&-A<F%C
M=&5R97,@;F%S(&-A:7AA<R!A8F%I>&\N(%!O9&5RX2!E;G3C;R!C;W!IX2UL
M;W,@92!C;VSA+6QO<R!N82#A<F5A(&1E('1E>'1O+@!396QE8V-I;VYE(&\@
M9&5L:6UI=&%D;W(@9&$@9&%T83H`4V5L96-C:6]N92!O(&9O<FUA=&\@9&$@
M9&%T83H`4V5L96-C:6]N92!A(&ED96YT:61A9&4@<75E('!R971E;F1E(&%L
M=&5R87(Z`%-E;&5C8VEO;F4@;R!D96QI;6ET861O<B!D87,@:&]R87,Z`%-E
M;&5C8VEO;F4@;R!F;W)M871O(&1A(&AO<F$Z`%-E;&5C8VEO;F4@9&]I<R!C
M86UP;W,@<F5L86-I;VYA9&]S+@!%<V-O;&AA(&\@<V5U(&-O;FIU;G1O(&1E
M(&-O<F5S+@!396QE8V-I;VYE(&\@<V5U(&ED:6]M82!P<F5F97)I9&\Z`$5N
M=FEA<B!296QA=/-R:6\@9&4@4')O8FQE;6%S`$5N=FEA<B!335,`4F5P^F)L
M:6-A(&1O(%-E;F5G86P`(%-E;G-O<CH@`%-E=&5M8G)O`%/I<G9I82!E($UO
M;G1E;F5G<F\`3OIM97)O(&1E(%/I<FEE`$1A9&]S(&1O('-E<G9I9&]R(&5R
M<F%D;W,@;W4@:6YD:7-P;V[M=F5I<RX`240@9&4@<V5S<^-O(&5X<&ER;W4N
M`$%T<FEB=6ER`$5S=&%B96QEYV$@;W#G]65S('%U92!L:&4@<&5R;6ET86T@
M<F5I;FEC:6%R(&$@<W5A('!A;&%V<F$M<&%S<V4@<V4@86QG=6UA('9E>B!D
M96QA('-E(&5S<75E8V5R+@!%<W!E8VEF:6-A<B!S97)V:61O<F5S(')E;6]T
M;W,@<75E(&1E<V5J82!A8V5D97(@;F\@<V5U('!O<G1A;"X`4V5L96-C:6]N
M92!O('-E=2!I9&EO;6$@<')E9F5R:61O+"!O('-E=2!F=7-O(&AO<N%R:6\@
M92!A<R!S=6%S(&]PY_5E<R!D92!D871A<RX`17-C;VQH82!A('-U82!A<&QI
M8V'GXV\@:6YI8VEA;"P@;R!E<W%U96UA(&1E(&-O<F5S+"!O(')E9G)E<V-A
M;65N=&\@9&4@<.%G:6YA<R!E(&]U=')A<R!O<.?U97,@9&4@=FES=6%L:7IA
MY^-O+@!#;VYF:6=U<F%R`")38W)I<'1S(B!D92!A8W1U86QI>F'GXV\@9&ES
M<&]N[79E:7,`5N%R:6%S(&QO8V%L:7IAY_5E<R!P;W-S[79E:7,@8V]M(&\@
M<&%RXFUE=')O.B``4V5I8VAE;&5S`$-O;7!R87,`0G)E=F4@4W5MX7)I;P!$
M979E;2US92!D969I;FER('1E8VQA<R!D92!A8V5S<V\@<&%R82!A(&UA:6]R
M:6$@9&%S(&QI9V'G]65S/P!-;W-T<F%R`$UO<W1R87(@9&EF97)E;N=A<R!E
M;G1R92!A(&-O;F9I9W5R8>?C;R!G=6%R9&%D82!E(&%Q=64@9F]I(&%G;W)A
M(&=E<F%D82X`36]S=')A<B!M;VUE;G1O(&1A(/IL=&EM82!E;G1R861A(&YO
M('-I<W1E;6$_`$UO<W1R87(@;W#GXV\@<&%R82!P<F5S97)V87(@;R!O<FEG
M:6YA;`!-;W-T<F%R('!A;&5T90!-;W-T<F%R(&$@8F%R<F$@9&4@;65N=2!C
M;VT@87,@;W!E<F'G]65S('-O8G)E('1A8F5L87,_`$UO<W1R87(@;R!-96YU
M("5S(.`@97-Q=65R9&$_`$UO<W1R87(@82!C86EX82!D92!D:>%L;V=O(&1A
M<R!0<F]P<FEE9&%D97,@9&4@0^EL=6QA<R!D92!486)E;&$_`$UO<W1R87(@
M82!C86EX82!D92!D:>%L;V=O(&1A<R!0<F]P<FEE9&%D97,@9&4@5&%B96QA
M<P!-;W-T<F%R(&$@8V%I>&$@9&4@9&GA;&]G;R!D87,@4')O<')I961A9&5S
M(&1E($QI;FAA<R!D92!486)E;&$`36]S=')A<B!A(&-A:7AA(&1E(&1IX6QO
M9V\@9&%S(%!R;W!R:65D861E<R!D92!);6%G96T`36]S=')A<B!C87)R96=A
M;65N=&\`06=U86-E:7)O<P!!9W5A8V5I<F]S($UA=&EN86ES`$%G=6%C96ER
M;W,@5F5S<&5R=&EN;W,`06=U86-E:7)O<R!N82!6:7II;FAA;N=A`$5N8V]L
M:&5R`$5N8V]L:&$@;W4@;6]V82!O*',I(&)L;V-O*',I('9I>FEN:&\H<RD@
M<')I;65I<F\`4V5R<F$@3&7C;P!3=6)S8W)E=F5R`%-U8G-C<F5V82P@<V4@
M86EN9&$@;N-O(&5S=.$@<F5G:7-T861O`$%S<VEN871U<F$`06QG;W)I=&UO
M(&1E($%S<VEN871U<F$`4F5P^F)L:6-A(&1E(%-I;F=A<'5R80!486UA;FAO
M`%-A;'1A<B!-86YU=&5NY^-O`$[C;R!P<F]C97-S861O+BXN`$5S;&]VX7%U
M:6$`4F5P^F)L:6-A(&1A($5S;&]VZ6YI80!.979E`$YE=N-O`$YE=O5E<P!.
M97;U97,@36%T:6YA:7,`3F5V]65S(%9E<W!E<G1I;F]S`$%L='5R82!D92!N
M979E.B``36]S=')A<B!E<75I=F%L96YT92!N82#A9W5A.B``26QH87,@4V%L
M;VWC;P!3;VWA;&EA`$-A;N?U97,@92!0;V5M87,`4V5L96/GXV\@9&\@<V5N
M=&ED;R!D82!O<F1E;F'GXV\`16YD97)EYV\@9&4@;W)I9V5M`,%F<FEC82!D
M;R!3=6P`175R;W!A(&1O(%-U;"`H25-/+3@X-3DM,RD`1V7S<F=I82!D;R!3
M=6P@92!);&AA<R!386YD=VEC:"!D;R!3=6P`2&5M:7-FZ7)I;R!3=6P`17-P
M8>=O(&5N=')E(&/I;'5L87,@861J86-E;G1E<P!%<W!AYV\@96YT<F4@;R!C
M;VYT9?ID;R!E(&$@8F]R9&$@9&4@=6UA(&/I;'5L80!%<W!AYV%D;W(`17-P
M8>=A;65N=&\`17-P8>=A;65N=&\@92!E;F-H:6UE;G1O`%)E:6YO(&1E($5S
M<&%N:&$`0V]R<F5I;R!NXV\@<V]L:6-I=&%D;P!);G-E<FER($-A<F%C=&5R
M($5S<&5C:6%L`$1I=FED:7(@8^EL=6QA`$%D:6-I;VYA<B!C;VQU;F$`1&EV
M:61I<B!L:6YH80!$97-P;W)T;W,`4F5P^F)L:6-A($1E;6]C<N%T:6-A(%-O
M8VEA;&ES=&$@9&\@4W)I($QA;FMA`%!A9'+C;P!3=&%R(%1R96L`06YO(&1E
M(&EN[6-I;P!%<W1A9&\@;W4@4')O=NUN8VEA`%-T871U<P!%<W1A9&\@9&$@
M;&]C86QI>F'GXV\@)7,N+BX@`$9O<FUA=&\@9&4@87)M87IE;F%M96YT;P!%
M;F1E<F7G;R!D92!2=6$`4F%S=7)A9&\`3&ES=&$@9&4@8V%D96EA<R!D92!C
M87)A8W1E<F5S`%)E=&ER87(@9&]M[6YI;R!D;R!E;F1E<F7G;P!%<W1I;&\@
M6T-34UT`9&\`07-S=6YT;P!3=6)M971E<@!&;VD@<W5B;65T:61O('!E9&ED
M;R!P87)A(&%D:6-I;VYA<B`B)7,B(&%O('-I<W1E;6$N($[C;R!P;V1E<N$@
M96YT<F%R(&5N<75A;G1O(&\@<V5U('!E9&ED;R!NXV\@9F]R(&%P<F]V861O
M+@!);F9E<FEO<B#@(&QI;FAA`%-U8V5S<V\`(B5S(B!A9&EC:6]N861O(&-O
M;2!S=6-E<W-O(&%O('-I<W1E;6$N`$QI;7!E>F$@9&\@<VES=&5M82!D;W,@
M9&%D;W,@9&\@=71I;&EZ861O<B`B)7,B(')E86QI>F%D82!C;VT@<W5C97-S
M;RX`4F5M;^?C;R!D92`B)7,B(&-O;2!S=6-E<W-O+@!296UOY^-O(&1E("(E
M<R(@9&\@<VES=&5M82!C;VT@<W5C97-S;RX`0V]N9FEG=7)AY^-O(')E=F5R
M=&ED82!C;VT@<W5C97-S;RX@4F5C87)R96=U92!P87)A('9E<B!A<R!M=61A
M;N=A<RX`0V]N9FEG=7)AY^-O(&1E('-A;'9A9W5A<F1A(&=U87)D861A(&-O
M;2!S=6-E<W-O+@!&:6-H96ER;R!D92!C;VYF:6=U<F'GXV\@9&4@<V%L=F%G
M=6%R9&$@)7,@9W5A<F1A9&\@8V]M('-U8V5S<V\N`"(E<R(@86-T=6%L:7IA
M9&\@8V]M('-U8V5S<V\`)7,@97-C<FET;R!C;VT@<W5C97-S;P!297#Z8FQI
M8V$@9&\@4W5DXV\`4F5S=6UO`$YA<V-E<B!D;R!3;VP`4/1R(&1O(%-O;`!3
M;VQA<F5N9V\`3F%S8V5R(&1O(%-O;`!.87-C97(O4/1R(&1O(%-O;`!.87-C
M97(@9&\@4V]L.B``4/1R(&1O(%-O;`!0]'(@9&\@4V]L.B``4W5P97)I;W(@
MX"!L:6YH80!3=7!O<G1E`%-U<FEN86UE`$%P96QI9&\`4W9A;&)A<F0@92!*
M86X@36%Y96X`4F5I;F\@9&$@4W5A>FELXFYD:6$`4F5I;F\@9&$@4W7I8VEA
M`%-U[>=A`$5R<F\@9&4@<VEN=&%X92!N;W,@=&5R;6]S(&1E('!R;V-U<F$`
M4F5P^F)L:6-A(,%R86)E(%/M<FEA`%1E;7!O<F%L+50`5&5M<&]R86PM5"!E
M(%9E;G1O<V\`5&5M<&]R86ES+50`5&5M<&]R86ES+50@36%T:6YA:7,`07)Q
M=6EV;R!44U8`5&%B96QA`%!R;W!R:65D861E<R!D82!486)E;&$`4')O<')I
M961A9&5S(&1A('1A8F5L80!&;W)M;W-A`$9O<FUO<V$`4F5P^F)L:6-A(&1O
M(%1A9&II<75I<W3C;P!486YZXFYI80!!;'9O.@!487)E9F%S`$[Z;65R;R!D
M92!496QE9F]N90!496UP97)A='5R82!D82#Z;'1I;6$@:&]R83H`5&5M<&5R
M871U<F$`5&5M<&5R871U<F$Z(`!496UP97)A='5R83QB<B`O/B@E<T%L=&$E
M<R\E<T)A:7AA)7,I("9D96<[)7,`3R!M;V1E;&\@(B5S(B!NXV\@9F]I(&5N
M8V]N=')A9&\N`$%D;6EN:7-T<F'GXV\@9&4@36]D96QO<P!497AT;P!!<&5N
M87,@5&5X=&\`06QI;FAA;65N=&\@9&\@=&5X=&\`5&]P;R!D;R!T97AT;P`U
MJ@!486EL86YDZG,@*%1)4RTV,C`I`%)E:6YO(&1A(%1A:6SB;F1I80!/8G)I
M9V%D;R!P;W(@=7-A<B!E<W1E('-I<W1E;6$N`$\@87)Q=6EV;R!D92!A:G5D
M82`E<R!P87)A("5S(&[C;R!E>&ES=&4@86EN9&$N($-R:6%N9&\@=6T@;F]V
M;RX`02!E>'1E;G/C;R!&5%`@;N-O(&5S=.$@9&ES<&]N[79E;"X`3R!E;F=E
M;FAO(&1E(&EN=&5G<F'GXV\@2&]R9&4O2V]L86(@;N-O('-U<&]R=&$@(B5S
M(@!/(')E9VES=&\@*")L;V<B*2!)35-0(&[C;R!P]&1E('-E<B!I;FEC:6%L
M:7IA9&\N`$$@8VQA<W-E($UA:6YT96YA;F-E.CH@;N-O(&9O:2!C87)R96=A
M9&$@8V]M('-U8V5S<V\`02!J86YE;&$@9&4@3W#G]65S(&9E8VAO=2X@4V'M
M;F1O+@!/(&%D;6EN:7-T<F%D;W(@=&5M(&1E(&-O;F9I9W5R87(@=6T@;65C
M86YI<VUO(&1E('!E<FUI<W/U97,@<&5R;6%N96YT92!S92!Q=6ES97(@=7-A
M<B!097)M:7-S]65S+@!!<&5N87,@;R!L861O(&EN9F5R:6]R`$\@;OIM97)O
M(&1E($E$(&1O(&-O;G1A8W1O(&[C;R!F;VD@97-P96-I9FEC861O+"!F;VD@
M9&5I>&%D;R!E;2!B<F%N8V\@;W4@;N-O(&9O:2!E;F-O;G1R861O(&YA(&)A
M<V4@9&4@9&%D;W,N`$\@8V]N=&%C=&\@9F]I(&%D:6-I;VYA9&\@X"!L:7-T
M82!D92!C;VYT86-T;W,@8V]M('-U8V5S<V\N`$\@8FQO8V\@9&4@87-S:6YA
M='5R82!01U`@9&5S=&%C861O(.D@;F5C97-SX7)I;R!P87)A('9E<FEF:6-A
M<B!U;6$@;65N<V%G96T@87-S:6YA9&$N`$\@240@9&$@;&ES=&$@9&4@9&ES
M=')I8G5IY^-O(&[C;R!F;VD@97-P96-I9FEC861O+"!F;VD@9&5I>&%D;R!E
M;2!B<F%N8V\@;W4@;N-O(&9O:2!E;F-O;G1R861O(&YA(&)A<V4@9&4@9&%D
M;W,N`$$@;&ES=&$@9&4@9&ES=')I8G5IY^-O(&[C;R!F;VD@97-P96-I9FEC
M861A+@!!<R!F=6YC:6]N86QI9&%D97,@9&4@96YC<FEP=&'GXV\@97AI9V5M
M('5M82!L:6=AY^-O('-E9W5R82X`3R!A<G%U:79O("5S(&1E=F5R:6$@8V]N
M=&5R('5M(&%T<FEB=71O("5S+@!/(&%R<75I=F\@)7,@9&5V97)I82!C;VYT
M97(@86QG=6YS(&%T<FEB=71O<R`E<RX`3R!F:6-H96ER;R!NXV\@<&]D92!S
M97(@8V]P:6%D;R!P87)A('-I('!R\W!R:6\N`$\@9FEC:&5I<F\@;N-O(&-O
M;G3I;2!D861O<RX`06)A:7AO(&5S=.-O(&]S(&-A8F7G86QH;W,@9&5S=&$@
M;65N<V%G96TO;65N<V%G96T@<F9C.#(R+@!/(&UO9&\@9&4@96-RXR!I;G1E
M:7)O(&-A=7-A('!R;V)L96UA<R!N;R!);G1E<FYE="!%>'!L;W)E<BP@9&5V
M:61O(&$@97)R;W,@;F\@;F%V96=A9&]R('%U92!NXV\@8V]N<V5G=6EM;W,@
M=6QT<F%P87-S87(N("!0;V1E('-U<F=I<B!L:7AO+"!P;V1E;2!D97-A<&%R
M96-E<B!F=6YC:6]N86QI9&%D97,@9&\@961I=&]R(&4O;W4@;R!S974@;F%V
M96=A9&]R('!O9&4@86)O<G1A<BX@4V4@;R!S974@<VES=&5M82#I('5M(%=I
M;F1O=W,@.7@L(.D@;75I=&\@<')O=N%V96P@<75E(&]B=&5N:&$@=6T@)T=E
M;F5R86P@4')O=&5C=&EO;B!&875L="<@92!P<F5C:7-E(&1E(')E:6YI8VEA
M<B!O('-I<W1E;6$N7&Y<;D9O:2!A=FES861O+B`@4&]R(&9A=F]R('!R97-S
M:6]N92!/2R!S92!A:6YD82!A<W-I;2!Q=6ES97(@97AP97)I;65N=&%R(&\@
M961I=&]R(&1E(&5C<N,@:6YT96ER;RX`3R!F:6-H96ER;R!D92!A:G5D82`E
M<R!NXV\@8V]M9>=A(&-O;2`\/WAM;`!!(&ED96YT:61A9&4@(B5S(B!F;VD@
M<F5M;W9I9&$N`$%P96YA<R!O(&QA9&\@97-Q=65R9&\`02!L;V-A;&EZ8>?C
M;R!D;R!A<G%U:79O(&5X96-U=.%V96P@9&4@1VYU4$<@=&5M(&1E('-E<B!I
M;F1I8V%D82#@(&-L87-S92!#<GEP=%]P9W`Z.BX`02!M96YS86=E;2!E;G9I
M861A(&5M("5S('!A<F$@)7,@8V]M(&%S<W5N=&\@(B5S(B!F;VD@;6]S=')A
M9&$N"D[C;R!HX2!G87)A;G1I82!D92!Q=64@82!M96YS86=E;2!T96YH82!S
M:61O(')E86QM96YT92!L:61A(&]U(&-O;7!R965N9&ED82X`3R!N;VUE(&$@
M=7-A<B!Q=6%N9&\@;&EG86YD;R#@('#A9VEN82!D92!C;VUP;W-IY^-O`$\@
M;?-D=6QO(&]P96YS<VP@Z2!N96-E<W/A<FEO('!A<F$@82!C;&%S<V4@2&]R
M9&5?0W)Y<'1?<VUI;64Z.BX`02!O<.?C;R`B)7,B(&[C;R!P]&1E('-E<B!G
M=6%R9&%D82P@<&]I<R!O<R!S975S(&1A9&]S(&5X8V5D96T@82!D:6UE;G/C
M;R!MX7AI;6$@<&5R;6ET:61A`$\@<')O9W)A;6$@=7-A9&\@<&%R82!V97(@
M97-T92!T:7!O(&1E(&1A9&]S("@E<RD@;N-O(&9O:2!E;F-O;G1R861O(&YO
M('-I<W1E;6$N`$%P96YA<R!O<R!L861O<R!E<W%U97)D;R!E(&1I<F5I=&\`
M07!E;F%S(&\@;&%D;R!D:7)E:71O`$\@<V5R=FED;W(@(B5S(B!F;VD@<F5M
M;W9I9&\N`$\@<V5R=FED;W(@(B5S(B!F;VD@9W5A<F1A9&\N`$\@<&5D:61O
M(&1E('-U8G-C<FGGXV\@9&4@)7,@9F]I(')E;6]V:61O+@!!(&QI;FAA(&EN
M9&EC861A(&[C;R!E>&ES=&4N`$\@87)Q=6EV;R!T96UP;W+A<FEO("(E<R(@
M;N-O(&5X:7-T92X`07!E;F%S(&]S(&QA9&]S('-U<&5R:6]R(&4@:6YF97)I
M;W(`07!E;F%S(&\@;&%D;R!S=7!E<FEO<@!/<R!D861O<R!C87)R96=A9&]S
M('!E<F1E<F%M+7-E(&1E<V1E(&\@<&%S<V\@86YT97)I;W(N`$\@87)Q=6EV
M;R!C87)R96=A9&\@;N-O('#T9&4@<V5R(&=U87)D861O+@!/(&)L;V-O('=E
M871H97(N8V]M(&[C;R!E<W3A(&1I<W!O;NUV96PN`$[C;R!HX2!O<.?U97,@
M9&ES<&]N[79E:7,N`$[C;R!HX2!P87)T97,@<75E('!O<W-A;2!S97(@;6]S
M=')A9&%S(&5M(&QI;FAA+@!(X2!D96UA<VEA9&]S(&-A<F%C=&5R97,@;F5S
M=&4@8V%M<&\N($EN=')O9'5Z:74@)7,@8V%R86-T97)E<SL@=&5M(&1E(&EN
M=')O9'5Z:7(@;65N;W,@9&\@<75E("5S+@!.XV\@97AI<W1E(&%I;F1A('5M
M(&%R<75I=F\@9&4@86IU9&$@<&%R82`E<RX`3V-O<G)E=2!U;2!P<F]B;&5M
M82!N82!A9&GGXV\@9&4@(B5S(B!A;R!S:7-T96UA.B`E<P!/8V]R<F5U('5M
M('!R;V)L96UA(&%O(&QI;7!A<B!O<R!D861O<R!D;R!U=&EL:7IA9&]R("(E
M<R(@9&\@<VES=&5M82X`3V-O<G)E=2!U;2!P<F]B;&5M82!N82!R96UOY^-O
M(&1E("(E<R(@9&\@<VES=&5M82X`3V-O<G)E=2!U;2!P<F]B;&5M82!A;R!A
M8W1U86QI>F%R("(E<R(Z("5S+@!(;W5V92!U;2!P<F]B;&5M82!C;VT@;R!C
M87)R96=A;65N=&\@9&\@9FEC:&5I<F\Z("5S(&[C;R!F;VD@8V%R<F5G861O
M+@!/8V]R<F5U('5M('!R;V)L96UA(&-O;2!O(&-A<G)E9V%M96YT;R!D;R!A
M<G%U:79O.B!/("5S(&5X8V5D92!O('1A;6%N:&\@;>%X:6UO('!E<FUI=&ED
M;R`H)60@8GET97,I+@!/8V]R<F5U('5M('!R;V)L96UA(&-O;2!O(&-A<G)E
M9V%M96YT;R!D;R!A<G%U:79O.B!/("5S(&9O:2!A<&5N87,@<&%R8VEA;&UE
M;G1E(&-A<G)E9V%D;RX`3V-O<G)E=2!U;2!E<G)O(&%O(&UO<W1R87(@97-T
M82!P87)T92!D82!M96YS86=E;0!/8V]R<F5U('5M(&5R<F\@86\@:6UP;W)T
M87(@9&%D;W,@9&4@8V]N=&%C=&\N`$]C;W)R974@=6T@97)R;R!A;R!I;7!O
M<G1A<B!D861O<R!I0V%L96YD87(N`$]C;W)R974@=6T@97)R;R!N;R!F;W)M
M=6SA<FEO(&1E(&-O;F9I9W5R8>?C;RX@5&%L=F5Z('1E;FAA(&]M:71I9&\@
M=6T@8V%M<&\@;V)R:6=A=/-R:6\N`$]C;W)R974@=6T@97)R;R!A;R!A8G)I
M<B!O(&%R<75I=F\@)7,N($5X<&5R:6UE;G1E(&5X96-U=&%R('1R86YS;&%T
M:6]N+G!H<"!C;VT@82!O<.?C;R`M9"!P87)A(&-O;G-E9W5I<B!V97(@87,@
M;65N<V%G96YS(&1E(&5R<F\@9&\@86YA;&ES861O<B!834PN`$]C;W)R974@
M=6T@97)R;R!A;R!R96%L:7IA<B!A(&9U;N?C;R!D92!L:79R;R!D92!E;F1E
M<F7G;W,@97-P96-I9FEC861A+B!0;W(@9F%V;W(@=&5N=&4@9&4@;F]V;R!M
M86ES('1A<F1E+@!/8V]R<F5U('5M(&5R<F\@86\@86-T=6%L:7IA<B!O<R!P
M;W)M96YO<F5S(&1O(&-O;G1A8W1O+B!0;W(@9F%V;W(@=&5N=&4@9&4@;F]V
M;R!M86ES('1A<F1E+@!/8V]R<F5U('5M(&5R<F\@86\@86-T=6%L:7IA<B!A
M(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@4&]R(&9A=F]R('1E;G1E(&1E(&YO
M=F\@;6%I<R!T87)D92X`17-T92!S97)V:61O<B!)34%0(&[C;R!S=7!O<G1A
M('!A<G1I;&AA(&1E('!A<W1A<RX`3N-O('!A<F5C92!S97(@=6T@87)Q=6EV
M;R!R87(@=N%L:61O+@!.XV\@<&%R96-E('-E<B!U;2!A<G%U:79O('II<"!V
MX6QI9&\N`$[C;R!P87)E8V4@<V5R('5M82!N^FUE<F\@9&4@8V%R=.-O(';A
M;&ED;RX`17-T92!C;VYT<F]L861O<B!P97)M:71E(&\@96YV:6\@9&4@;65N
M<V%G96YS(&%T<F%VZ7,@9&\@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E
M;&PN8V]M*2P@=7-A;F1O(&$@05!)($A45%``17-T92!C;VYT<F]L861O<B!P
M97)M:71E(&\@96YV:6\@9&4@;65N<V%G96YS(&%T<F%VZ7,@9&\@<VUS,FUA
M:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2P@=7-A;F1O(&$@05!)($A45%``
M17-T92!C;VYT<F]L861O<B!P97)M:71E(&\@96YV:6\@9&4@;65N<V%G96YS
M('9I82!33510(&%T<F%VZ7,@9&$@5F]D869O;F4@273A;&EA(&4@87!E;F%S
M('!A<F$@;OIM97)O<R!6;V1A9F]N92X@17AI9V4@=6UA(&-O;G1A(&1E(&-O
M<G)E:6\@96QE8W1R\VYI8V\@;F$@5F]D869O;F4@273A;&EA("AH='1P.B\O
M=W=W+C$Y,"YI="DN`$5S=&4@8V%M<&\@Z2!O8G)I9V%T\W)I;RX`17-T92!C
M86UP;R!P;V1E(&-O;G1E<B!A<&5N87,@:6YT96ER;W,N`$5S=&4@8V%M<&\@
M<&]D92!A<&5N87,@8V]N=&5R(&[Z;65R;W,@92!O('/M;6)O;&\@9&]I<RUP
M;VYT;W,N`$5S=&4@8V%M<&\@<&]D92!C;VYT97(@87!E;F%S('9A;&]R97,@
M;V-T86ES+@!%<W1E(&-A;7!O('1E;2!D92!C;VYT97(@=6UA(&QI<W1A(&1E
M(&EN=&5I<F]S('-E<&%R861O<R!P;W(@97-P8>=O<R!O=2!V[7)G=6QA<RX`
M17-T92!C86UP;R!T96T@9&4@<V5R('5M(&[Z;65R;R!VX6QI9&\N`$5S=&4@
M8V%M<&\@=&5M(&1E(&-O;G1E<B!U;2!C\V1I9V\@9&4@8V]R(&YO(&9O<FUA
M=&\@4D="(&AE>&%D96-I;6%L+"!P;W(@97AE;7!L;R`G(S$R,S1A9B<N`$5S
M=&4@;6]D96QO(&KA(&9O:2!P<F]C97-S861O+@!)<W1O(.D@)7,N`$5S=&4@
MZ2!U;2!O8FIE8W1O($MO;&%B($=R;W5P=V%R92X@4&%R82!V97(@97-T92!O
M8FIE8W1O('!R96-I<V$@9&4@=6T@8VQI96YT92!D92!C;W)R96EO(&5L96-T
M<O-N:6-O('%U92!C;VYH9>=A(&\@9F]R;6%T;R!+;VQA8B!'<F]U<'=A<F4N
M(%!A<F$@=6UA(&QI<W1A(&1E(&-L:65N=&5S(&1E(&-O<G)E:6\@96QE8W1R
M\VYI8V\@;F5S<V%S(&-I<F-U;G-TXFYC:6%S('9I<VET92`E<P!%<W1A(&UE
M;G-A9V5M(&9O:2!E<V-R:71A(&YU;2!C\V1I9V\@*"5S*2!D:69E<F5N=&4@
M9&\@<V5U+@!%<W1E(&[Z;65R;R!P<F5C:7-A(&1E('-E<B!P96QO(&UE;F]S
M('5M+@!%<W1E(")S8W)I<'0B('1E;2!S97(@97AE8W5T861O(&$@<&%R=&ER
M(&1E('5M82!L:6YH82!D92!C;VUA;F1O<RX`17-T92!S97)V:61O<B!NXV\@
M8V]N<V5G=64@9&5S8V]M<')I;6ER(&%R<75I=F]S('II<"!O=2!G>FEP+@!%
M<W1E('-I<W1E;6$@96YC;VYT<F$M<V4@9&5S86-T:79A9&\N`$5S=&$@=F%L
M;W(@=&5M(&1E('-E<B!U;2!N^FUE<F\N`$5S=&$@:F%N96QA('1E;2!D92!S
M97(@8VAA;6%D82!A('!A<G1I<B!D92!U;6$@:F%N96QA(&1E($]PY_5E<P!4
M<F]V;V%D80!":6QH971E<P!$871A+TAO<F$`4V5G=6EM96YT;R!496UP;W)A
M;`!&;W)M871O(&1O('1E;7!O`%-E;&5CY^-O(&1A=&$O:&]R80!4:6UO<BU,
M97-T90!4[71U;&\`5.UT=6QO("AD:6-A*3H`4&%R80!087)A('-E;&5C8VEO
M;F%R(&WZ;'1I<&QO<R!I=&5N<RP@8V%R<F5G=64@96T@0V]N=')O;"`H4$,I
M(&]U($-O;6UA;F0@*$UA8RD@96YQ=6%N=&\@8VQI8V%R+@!(;VIE`%1R;V-A
M<B!&;VYT92!(5$U,`%)E</IB;&EC82!4;V=O;&5S80!4;W%U96QA=0!!;6%N
M:.,`4F5I;F\@9&\@5&]N9V$`5&]P;P!-;VQD=7)A(&1E('1O<&\@*%]T;W`I
M`%1R861U>FED87,`5')A9'7G]65S`%1R:6YD861E(&4@5&]B86=O`%9E<F1A
M9&5I<F\@;W4@9F%L<V\`,ZH`4F5P^F)L:6-A(&1A(%1U;NUS:6$`4F5P^F)L
M:6-A(&1A(%1U<G%U:6$`5'5R8V\@*$E33RTX.#4Y+3DI`%1U<G%U96UE;FES
M=.-O`$EL:&%S(%1U<F-A<R!E($-A:6-O<P!4=79A;'4`17-C<F5V82!A('-U
M82!E<V-O;&AA.@#-;F1I8V4@52Y6+CH@`%523`!54DP@9&\@<V5U(')E;&%T
M\W)I;R!D92!E<W1A9&\@9&\@96YV:6\@9&4@(G-C<FEP=',B`%523#H`4F5P
M^F)L:6-A(&1O(%5G86YD80!58W+B;FEA`$[C;R!F;VD@<&]S<^UV96P@86-E
M9&5R(.`@<&%S=&$@5D93+@!.XV\@9F]I('!O<W/M=F5L(&%D:6-I;VYA<B!I
M;F9O<FUAY^-O(&1E('5T:6QI>F%D;W(@97AT<F$@87%U86YD;R!D82!S=6)S
M8W)IY^-O+@!.XV\@9F]I('!O<W/M=F5L(&UU9&%R(&%S('!E<FUI<W/U97,@
M9&\@87)Q=6EV;R!61E,@(B5S(BX`3N-O(&9O:2!P;W-S[79E;"!M=61A<B!A
M<R!P97)M:7-S]65S(&1O(&%R<75I=F\@5D93("5S+R5S+@!.XV\@9F]I('!O
M<W/M=F5L(&UU9&%R('!A<F$@)7,N`$[C;R!F;VD@<&]S<^UV96P@;&EG87(@
M86\@<V5R=FED;W(@4U%,+@!.XV\@9F]I('!O<W/M=F5L(&QI9V%R('5S86YD
M;R!34TPN`$[C;R!F;VD@<&]S<^UV96P@8V]P:6%R(&\@87)Q=6EV;R!61E,N
M`$[C;R!F;VD@<&]S<^UV96P@8W)I87(@82!P87-T82!61E,@(B5S(BX`3N-O
M(&9O:2!P;W-S[79E;"!C<FEA<B!A('!A<W1A(%9&4RX`3N-O(&9O:2!P;W-S
M[79E;"!C<FEA<B!O(&%R<75I=F\@5D93+@!.XV\@9F]I('!O<W/M=F5L(&-R
M:6%R('5M(&%R<75I=F\@5D93('9A>FEO+@!.XV\@9F]I('!O<W/M=F5L(&1E
M<V-O;7!R:6UI<B!O<R!D861O<RX`3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R
M("(E<R(L('!O:7,@82!P87-T82!NXV\@97-TX2!V87II82X`3N-O(&9O:2!P
M;W-S[79E;"!R96UO=F5R("(E<R(Z("5S+@!.XV\@9F]I('!O<W/M=F5L(')E
M;6]V97(@)7,L('!O:7,@82!P87-T82!NXV\@97-TX2!V87II80!.XV\@9F]I
M('!O<W/M=F5L(')E;6]V97(@82!P87-T82!61E,@<F5C=7)S:79A;65N=&4N
M`$[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!A('!A<W1A(%9&4RX`3N-O(&9O
M:2!P;W-S[79E;"!R96UO=F5R(&$@<&%S=&$@5D93.B`E<RX`3N-O(&9O:2!P
M;W-S[79E;"!R96UO=F5R(&\@87)Q=6EV;R!61E,@(B5S(BX`3N-O(&9O:2!P
M;W-S[79E;"!R96UO=F5R(&\@87)Q=6EV;R!61E,N`$[C;R!F;VD@<&]S<^UV
M96P@<F5M;W9E<B!R96-U<G-I=F%M96YT93H@)7,N`$[C;R!F;VD@<&]S<^UV
M96P@9&5T97)M:6YA<B!A('!A<W1A(&-O<G)E;G1E+@!.XV\@9F]I('!O<W/M
M=F5L(&5X=')A:7(@;W,@<&]R;65N;W)E<R!D;R!C97)T:69I8V%D;P!);7!O
M<W/M=F5L(&QE<B!A(&1E9FEN:>?C;R!D92`E<RX`3N-O(&9O:2!P;W-S[79E
M;"!M;W9E<B!O(&%R<75I=F\@5D93+@!.XV\@9F]I('!O<W/M=F5L(&%B<FER
M(&\@87)Q=6EV;R!61E,@(B5S(BX`3N-O(&9O:2!P;W-S[79E;"!A8G)I<B!O
M(&%R<75I=F\@5D93('!A<F$@97-C<FET82X`3N-O(&9O:2!P;W-S[79E;"!A
M8G)I<B!O(&%R<75I=F\@5D93+@!.XV\@9F]I('!O<W/M=F5L(&%B<FER(&\@
M87)Q=6EV;R!C;VUP<FEM:61O+@!.XV\@8V]N<VEG;R!L97(@;R!A<G%U:79O
M.B``3N-O(&9O:2!P;W-S[79E;"!L97(@82!P87-T82!V9G-R;V]T+@!.XV\@
M9F]I('!O<W/M=F5L(')E;F]M96%R("5S(&-O;6\@)7,Z(&$@<&%S=&$@9&4@
M9&5S=&EN;R!JX2!E>&ES=&4`3N-O(&9O:2!P;W-S[79E;"!R96YO;65A<B!A
M('!A<W1A(%9&4RX`3N-O(&9O:2!P;W-S[79E;"!R96YO;65A<B!A('!A<W1A
M(%9&4SH@)7,N`$[C;R!F;VD@<&]S<^UV96P@<F5N;VUE87(@;R!A<G%U:79O
M(%9&4R`B)7,B+@!.XV\@9F]I('!O<W/M=F5L(')E;F]M96%R(&\@87)Q=6EV
M;R!61E,@)7,O)7,N`$[C;R!F;VD@<&]S<^UV96P@<F5N;VUE87(@87)Q=6EV
M;R!61E,N`$[C;R!F;VD@<&]S<^UV96P@97AE8W5T87(@)VUK:7-O9G,G+@!.
MXV\@9F]I('!O<W/M=F5L(&-O;G9E<G1E<B!E<W1E(&1O8W5M96YT;R!7;W)D
M`$[C;R!F;VD@<&]S<^UV96P@97-C<F5V97(@87)Q=6EV;R!61E,@(B5S(BX`
M3N-O(&9O:2!P;W-S[79E;"!E<V-R979E<B!O(&%R<75I=F\@5D93("AC;W!Y
M*"D@9F%L:&]U*2X`3N-O(&-O;G-I9V\@<F5M;W9E<B`G)7,G.B`E<RX`4W5B
M;&EN:&%D;P!$97-F87IE<B!!;'1E<F'G]65S`$1E<V9A>B!A('-U82#Z;'1I
M;6$@86/GXV\`4F5S<&]S=&$@:6YE<W!E<F%D82!D;R!S97)V:61O<B!N82!C
M;VYE>.-O.B``4F5S<&]S=&$@:6YE<W!E<F%D82!D;R!S97)V:61O<B!A.B``
M4V5M(&-A=&5G;W)I80!5;FEC;V1E("A55$8M."D`16UI<F%D;W,@P7)A8F5S
M(%5N:61O<P!296EN;R!5;FED;P!%<W1A9&]S(%5N:61O<R!D82!!;>ER:6-A
M`$EL:&%S($UE;F]R97,@1&ES=&%N=&5S(&1O<R!%<W1A9&]S(%5N:61O<P!5
M;FED861E<P!$97-C;VYH96-I9&\`87!I;7-G:60@*$E$(&1E($UE;G-A9V5M
M(&1E($%022DN`&-L:6US9VED(&1E<V-O;FAE8VED;R`H240@9&4@365N<V%G
M96T@9&4@0VQI96YT92DN`$-O;6%N9&\@9&5S8V]N:&5C:61O.B`E<P!&;VD@
M9F]R;F5C:61A('5M82!L;V-A;&EZ8>?C;R!D97-C;VYH96-I9&$N`$YO;64@
M9&4@=71I;&EZ861O<B!O=2!P86QA=G)A+7!A<W-E(&5R<F%D;W,`4F5M;W9E
M<B!L:6=AY^-O(&1O(&5L96UE;G1O(&-O<G)E;G1E`%-E;2!N;VUE`%!O<B!R
M87KU97,@9&4@<V5G=7)A;N=A+"`B<V-R:7!T<R(@<V5M('!R:79I;.EG:6\@
M;N-O('!O9&5M(&%C961E<B!A($-O<G1A<B]#;W!I87(O0V]L87(@<')O9W)A
M;6%T:6-A;65N=&4N($-A<G)E9W5E(&5M($]+('!A<F$@=F5R('5M82!N;W1A
M('3I8VYI8V$@96T@;6]Z:6QL82YO<F<@<75E(&QH92!M;W-T<F%RX2!C;VUO
M(&%U=&]R:7IA<B!U;2`B<V-R:7!T(B!A(&%C961E<B!A;W,@<F5C;W)T97,N
M`%)E;6]V97(@8V]L;W)AY^-O`$5X=&5N<^-O(&[C;R!3=7!O<G1A9&$`4&]R
M('1R861U>FER`$UO9&EF:6-A<@!!8W1U86QI>F%R("5S`$%C='5A;&EZ87(@
M=71I;&EZ861O<@`B)7,B(&%C='5A;&EZ861O+@!!8W1U86QI>F%N9&\@87)Q
M=6EV;R!D92!A:G5D82`E<R!P87)A("5S+@`B4V-R:7!T(B!D92!A8W1U86QI
M>F'GXV\@<F5M;W9I9&\N`%5P;&]A9`!#87)R96=A9&]S(&YO('-E<G9I9&]R
M('1O9&]S(&]S(&%R<75I=F]S(&1E(&EN<W1A;&'GXV\@9&4@87!L:6-AY_5E
M<RX`3&5T<F%S(&QA=&EN87,@96T@;6%I^G-C=6QA<P!.^FUE<F]S(')O;6%N
M;W,@96T@;6%I^G-C=6QA<P!297#Z8FQI8V$@3W)I96YT86P@9&\@57)U9W5A
M:0!5=&EL:7IAY^-O.@!5<V%R(&\@0V]R<F5N=&4Z("5S`%5S87(@4U-,+@!5
M<V%R('-E(&\@;F]M92!D92!U=&EL:7IA9&]R(&]U(&$@<&%L879R82UP87-S
M92!F;W)E;2!D:69E<F5N=&5S(&YO('-E<G9I9&]R($E-4U`N`%5T:6QI>F%D
M;W(@)7,@;N-O(&5S=.$@875T;W)I<V%D;R!P87)A("5S+@!!9&UI;FES=')A
MY^-O(&1E(%5T:6QI>F%D;W)E<P!/<.?U97,@9&\@571I;&EZ861O<@!296=I
M<W1O(&1E(%5T:6QI>F%D;W)E<P!/(%)E9VES=&\@9&4@571I;&EZ861O<F5S
M(&5S=.$@:6YA8W1I=F\N`%!E<FUI<W/U97,@9&\@=71I;&EZ861O<@!.;VUE
M(&1E(%5T:6QI>F%D;W(`3R!.;VUE(&1E(%5T:6QI>F%D;W(@(B5S(B!JX2!E
M>&ES=&4N`$YO;64@9&4@571I;&EZ861O<CH`3F]M92!D92!5=&EL:7IA9&]R
M.B``571I;&EZ861O<F5S`%5T:6QI>F%D;W)E<R!D;R!S:7-T96UA.@!297#Z
M8FQI8V$@9&\@57IB97%U:7-TXV\`02!P87-T82!61E,@;N-O(&5X:7-T92X`
M075SZFYC:6$`07,@;&]C86QI>F'G]65S(';A;&ED87,@96YC;VYT<F%D87,@
M:6YC;'5E;3H`5F%L:61A9&4N`%9A;&]R(&5M(&UI;G5T;W,@82!P87)T:7(@
M9&5S=&4@:6YS=&%N=&4N`%9A;&]R(&5X8V5D92!O(&-O;7!R:6UE;G1O(&WA
M>&EM;R!D92`E<RX`5F%L;W)E<P!0;W-S[79E;"!V86QO<F5S(&$@97-C;VQH
M97(`5F%N=6%T=0!687)IX79E;`!696YE>G5E;&$`5F5R:69I8V'GXV\@9F%L
M:&]U("T@97-T82!M96YS86=E;2!P;V1E('1E<B!S:61O(&%D=6QT97)A9&$N
M`%9E<G/C;P!#;VYT<F]L;R!D92!697)S]65S`$%L:6YH86UE;G1O(%9E<G1I
M8V%L`$-A;.=O(%9E<G1I8V%L`%9E<G1I8V%L.@!-=6ET;R!!;'1O`%)E</IB
M;&EC82!3;V-I86QI<W1A(&1O(%9I971N86UE`%9I971N86UI=&$@*%9)4T-)
M22D`5FES=6%L:7IA<B`E<P!697(@=6UA('#A9VEN82!E>'1E<FYA`%9I<W5A
M;&EZ87(@8V]M;R`E<P!);&AA<R!6:7)G96YS($)R:73B;FEC87,`26QH87,@
M5FER9V5N<R!!;65R:6-A;F%S`%9I<VEB:6QI9&%D90!6:7-I8FEL:61A9&4Z
M(`!6;V1A9F]N92!)=.%L:6$@=FEA(%--5%``059)4P!!5$5.Q\-/(2$A(%)%
M34]602!/(")30U))4%0B($U!3E5!3$U%3E1%($1%("5S+@!786QL:7,@92!&
M=71U;F$`079I<V\`079I<V\Z(``TJ@!0<F5V:7/C;R!D;R!496UP;P!$861O
M<R!M971E;W)O;/-G:6-O<R!F;W)N96-I9&]S('!O<@!796%T:&5R+F-O;0!7
M96(`4.%G:6YA`%-E;6%N86QM96YT90!"96TM=FEN9&$H;RD`0F5M+79I;F1A
M*&\I(&$@)7,`0F5M+79I;F1A*&\I+"`E<P!/8VED96YT86P@*$E33RTX.#4Y
M+3$I`$]C:61E;G1A;"`H25-/+3@X-3DM,34I`%-A87)A`%%U92!A<&QI8V'G
MXV\@9&5V92!O("5S(&UO<W1R87(@87#S<R!A(&5N=')A9&$_`%%U86P@Z2!O
M(&-A<F%C=&5R92!D96QI;6ET861O<C\`475A;"#I(&\@8V%R86-T97)E(&1E
M(&-I=&'GXV\_`%%U92!F87-E<P!1=64@(G!L=6=I;G,B(&%C=&EV87(@<&%R
M82!A($5D:>?C;R!2:6-A+@!,87)G=7)A`$QA<F=U<F$@96T@=6YI9&%D97,@
M0U-3`$QA<F=U<F$@9&\@365N=2`E<R#@(&5S<75E<F1A("AT96T@969E:71O
M(&YA('!R\WAI;6$@96YT<F%D82DZ`$QA<F=U<F$@9&$@=&%B96QA`%5N:61A
M9&4@9&4@;&%R9W5R80!,87)G=7)A.@!7:6MI`%9E;G1O`%9E;G1O($UA=&EN
M86P`5F5L;V-I9&%D92!D;R!V96YT;R!E;2!N\W,`5F5N=&\Z`%9E;G1O.B``
M4V%B961O<FEA`$QI<W1A<R!D92!$97-E:F]S`%1R86)A;&AO`$5N9&5R9>=O
M("A%;7!R96=O*0!496QE9F]N92`H16UP<F5G;RD`17-C<F5V96YD;R!A<G%U
M:79O(&1E(&%J=61A(&%C='5A;&EZ861O('!A<F$@)7,N`%)E9F5RZFYC:6%S
M(&-R=7IA9&%S`%)E<W1R:>?U97,@0N%S:6-A<R!8-3`Y=C,`571I;&EZ8>?C
M;R!D92!#:&%V92!%>'1E;F1I9&$@6#4P.78S`$YO;64@06QT97)N871I=F\@
M9&4@4W5J96ET;R!8-3`Y=C,`261E;G1I9FEC861O<B!#:&%V92!D92!3=6IE
M:71O(%@U,#EV,P!%>'1E;G/U97,@6#4P.78S`$%!`$%!04$`36%P82!986AO
M;R$`06YU86QM96YT90!)Z6UE;@!3:6T`4VEM+"!#;VYC;W)D;P!%<W3A(&5M
M($U/1$\@9&4@5$585"X@(%5S92!O(&)O=.-O(%L\/ET@<&%R82!T<F]C87(@
M<&%R82!O(&UO9&\@5DE354%,+@!.XV\@97-TX2!A=71E;G1I8V%D;RX`3N-O
M('!O9&4@=&5R(&\@8V%R86-T97)E("=<)R!N;R!S974@;F]M92!C;VUP;&5T
M;RX`3N-O(&EN=')O9'5Z:74@=6T@96YD97)EYV\@9&4@8V]R<F5I;R!E;&5C
M='+S;FEC;R!VX6QI9&\N`$[C;R!M87!E;W4@;F5N:'5M(&-A;7!O(&1O(&%R
M<75I=F\@:6UP;W)T861O('!A<F$@;W,@8V%M<&]S(&-O<G)E<W!O;F1E;G1E
M<R!E;2`E<RX`06-A8F]U(&1E('-A:7(N`%1E;2!D92!I;G1R;V1U>FER('5M
M(&[Z;65R;R!D92!T96QE;?-V96P@=N%L:61O+"!S\R!C;VT@9.UG:71O<RP@
M;6%S(&-O;2!U;2`G*R<@;W!C:6]N86P@<&%R82!O('!R969I>&\@:6YT97)N
M86-I;VYA;"X`5&5M(&1E(&EN=')O9'5Z:7(@=6T@=F%L;W(@=N%L:61O+@!4
M96T@9&4@8V]N9FEG=7)A<B!U;2!M96-A;FES;6\@8N%S:6-O('!A<F$@1&%T
M851R964@<V4@<75I<V5R('5S87(@4W5B<V-R:>?U97,`5&5M(&1E(&-O;F9I
M9W5R87(@=6T@;65C86YI<VUO(&)A<V4@<&%R82!O(%9&4RX`1&5V92!D97-C
M<F5V97(@;R!P<F]B;&5M82!A;G1E<R!D92!E;G9I87(@;R!R96QA=/-R:6\N
M`%1E;2!D92!I;G1R;V1U>FER(&\@55),(&1O(')E8W5R<V\@<75E(&5S=&$@
M;&EG8>?C;R!S92!R969E<F4`5&5M(&1E('-E;&5C8VEO;F%R('5M('-E<G9I
M9&]R(&$@<F5M;W9E<BX`1&5V92!E<W!E8VEF:6-A<B!O('5T:6QI>F%D;W(@
M82!L:6UP87(N`$1E=F4@97-P96-I9FEC87(@;R!N;VUE(&1O('5T:6QI>F%D
M;W(@82!R96UO=F5R+@!496T@9&4@97-P96-I9FEC87(@;R!N;VUE(&1O('5T
M:6QI>F%D;W(@82!A9&EC:6]N87(N`%1E;2!D92!E<W!E8VEF:6-A<B!O('5T
M:6QI>F%D;W(@82!A8W1U86QI>F%R+@!496T@9&4@97-P96-I9FEC87(@82!A
M8^?C;R!A(&1E<V5M<&5N:&%R+@!496T@9&4@:6YT<F]D=7II<B!U;2!N;W9O
M(&YO;64@9&4@8V%T96=O<FEA+@!496T@9&4@9F]R;F5C97(@=6T@;OIM97)O
M(&1E('1E;&5F;VYE(&ET86QI86YO`$$@<W5A('-E<W/C;R`E<R!E>'!I<F]U
M+B!0;W(@9F%V;W(@96YT<F4@9&4@;F]V;RX`3R!S974@16YD97)EYV\@9&4@
M0V]R<F5I;R!%;&5C='+S;FEC;SH`3R!S974@96YD97)EYV\@(D1E.B(`02!S
M=6$@26YF;W)M8>?C;P!/('-E=2!E;F1E<F7G;R!)4"!P87)E8V4@=&5R(&UU
M9&%D;R!D97-D92!O(&EN[6-I;R!D82!S97-SXV\@)7,N(%!A<F$@9V%R86YT
M:7(@82!S=6$@<V5G=7)A;N=A+"!D979E(&%U=&5N=&EC87(M<V4@9&4@;F]V
M;RX`3R!3974@3F]M90!/('-E=2!M96-A;FES;6\@9&4@875T96YT:6-AY^-O
M(&[C;R!S=7!O<G1A(&%D:>?C;R!D92!U=&EL:7IA9&]R97,@;W4@97-T82!O
M<.?C;R!F;VD@9&5S86-T:79A9&$@<&]R(&%L9W5M(&]U=')O(&UO=&EV;RX`
M3R!S974@;65C86YI<VUO(&1E(&%U=&5N=&EC8>?C;R!NXV\@<W5P;W)T82!L
M:7-T86=E;2!D92!U=&EL:7IA9&]R97,@;W4@97-T82!O<.?C;R!F;VD@9&5S
M86-T:79A9&$@<&]R(&%L9W5M(&]U=')O(&UO=&EV;RX`3R!S974@;F%V96=A
M9&]R('!A<F5C92!T97(@;75D861O(&1E<V1E(&\@:6[M8VEO(&1A('-E<W/C
M;R`E<RX@4&%R82!G87)A;G1I<B!A('-U82!S96=U<F%NYV$L(&1E=F4@875T
M96YT:6-A<BUS92!D92!N;W9O+@!/('-E=2!N879E9V%D;W(@;N-O('-U<&]R
M=&$@97-T82!F=6YC:6]N86QI9&%D92X`3R!S974@;F%V96=A9&]R(&[C;R!S
M=7!O<G1A(&5S=&$@;W#GXV\@9&4@:6UP<F5S<^-O+B!0<F5S<VEO;F4@0V]N
M=')O;"]#;VUM86YD("L@4"!P87)A(&EM<')I;6ER+@!&=7-O(&AO<N%R:6\@
M86-T=6%L.@!)9&5N=&ED861E('!A9'+C;SH`3F]M92!C;VUP;&5T;P!!('-U
M82!V97)SXV\@9&\@9V5T=&5X="#I(&1E;6%S:6%D;R!A;G1I9V$L(&[C;R!S
M=7!O<G1A;F1O(%!(4"!D92!F;W)M82!N871I=F$N($YE;2!T;V1A<R!A<R!C
M861E:6%S(&1E(&-A<F%C=&5R97,@<V5RXV\@97AT<F'M9&%S+@!!('-U82!N
M;W9A('!A;&%V<F$M<&%S<V4@<&%R82`E<R#I.B`E<P!!<R!S=6%S(&]PY_5E
M<R!F;W)A;2!A;'1E<F%D87,@873I(&%O(&9I;F%L(&1E<W1A('-E<W/C;RX`
M07,@<W5A<R!O<.?U97,@9F]R86T@86-T=6%L:7IA9&%S+@!!('-U82!P86QA
M=G)A+7!A<W-E(&9O:2!R96-R:6%D80!!('-U82!P86QA=G)A+7!A<W-E(&9O
M:2!R96-R:6%D82P@=F5R:69I<75E(&\@<V5U(&-O<G)E:6\@96QE8W1R\VYI
M8V\@92!E;G1R92!C;VT@82!S=6$@;F]V82!P86QA=G)A+7!A<W-E+@!/<R!S
M975S('-E<G9I9&]R97,@<F5M;W1O<SH`2G5G;W-LX79I80!:86ER90!:XFUB
M:6$`6FEM8F%B=>D`6FEP<'D`6T5S8V]N9&5R(%1E>'1O($-I=&%D;UT`6U)E
M;&%T\W)I;R!D92!0<F]B;&5M87-=(`!;36]S=')A<B!497AT;R!#:71A9&\@
M+0!;36]S=')A<B!497AT;R!#:71A9&\@+2`E<R!L:6YH87-=`%ML:6YH82`E
M<R!D92`E<UT`7T%D;6EN:7-T<F'GXV\`7T-O;G-O;&$`P7)?=F]R90!?4F5M
M;W9E<B!,:6YH80!?1W)U<&]S`$%?:G5D80!0<F]P<FEE9&%D97,@9&$@7TEM
M86=E;0!?16YT<F%R`%]386ER`%]-;V1I9FEC87(@3&EG8>?C;P!?3W#G]65S
M`%]097)M:7-S]65S`%]296UO=F5R($QI9V'GXV\N+BX`7T-O;F9I9W5R8>?C
M;P!0<F]P<FEE9&%D97,@9&$@7U1A8F5L80!?571I;&EZ861O<F5S`&-O;G1A
M8W1O<P!O8V]R<F5U('5M(&5R<F\Z`&-A;&5N9.%R:6\`8V%L;6\`8VQI<75E
M(&%Q=6D`9F5I=&\`9F%L:&]U`&1I;6EN=6EN9&\`9FEC:&5I<F\`96YC;VYT
M<F%D;SH@`&1O("5S("@E<RD@X',@)7,@)7,`<F%J861A<P!H.@!H:`!I;65D
M:6%T;P!E;2!L:6YH80!L:6YH87-=`$5R<F\@;6MI<V]F<R!C;VT@8_-D:6=O
M("5D(&%O(&-O;G-T<G5I<B!)4T\N`&UM`&YO;64`<V5M(&%L=&5R8>?U97,`
M;N-O(&5N8V]N=')A9&\`;N-O(&EM<&QE;65N=&%D80!A:6YD82!P;W(@:6UP
M;&5M96YT87(`8V%D97)N;R!D92!N;W1A<P!P97)C96YT86=E;0!P[7AE:7,`
M<W5B:6YD;P!M;W-T<F%R(&1I9F5R96[G87,`<VUS,F5M86EL('9I82!(5%10
M`'-S`&5S=.%V96P`;&ES=&$@9&4@=&%R969A<P!/(&9I8VAE:7)O(%!/('!A
M<F$@;R!L;V-A;&4@)7,@;N-O(&5X:7-T92X`:6YT<F]D=7IA(&$@<&%L879R
M82UP87-S92!D=6%S('9E>F5S+"!P87)A(&-O;F9I<FUAY^-O`'5N:69I8V%D
M;P!S96T@;F]M90!A8W1U86QI>F%D;P!S96QE8V-I;VYA9&$@<&5L;R!U=&EL
M:7IA9&]R`'9#87)D`%)E96YC.@!W96%T:&5R+F-O;0``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O
M<'1?4%0O:&5L<"YX;6P`````````````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#,V-#8@,3`U,34T,S,W-#$@,#(Q-3`V`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_>&UL('9E<G-I;VX]
M(C$N,"(@96YC;V1I;F<](FES;RTX.#4Y+3$B/SX*/"$M+2`D2&]R9&4Z(&AO
M<F1E+VQO8V%L92]P=%]05"]H96QP+GAM;"QV(#$N,BXQ,"XQ(#(P,#8O,#<O
M,C<@,3,Z-3$Z,#$@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT<GD@:60]
M(G-U;6UA<GDB('-T871E/2)U<'1O9&%T92(@;60U/2(V.&-A,S-F-V8P8SEA
M864T8S$P,V5B-#<T.3)C9&,Q-2(^"CQT:71L93Y!(%#A9VEN82!D;R!0;W)T
M86P\+W1I=&QE/@H@/'!A<F$^"D5S=&$@<.%G:6YA(&9O<FYE8V4@=6T@8G)E
M=F4@<W5MX7)I;R!D92!T;V1A(&$@<W5A(&EN9F]R;6'GXV\@:6UP;W)T86YT
M92X*4&]R(&5X96UP;&\L('!O9&4@;6]S=')A<B!Q=6%N=&%S(&UE;G-A9V5N
M<R!N;W9A<R!D92!E+6UA:6P@97AI<W1E;2!N82!S=6$@24Y"3U@L(`IO<R!E
M=F5N=&]S(&%G96YD861O<R!N;R!S974@8V%L96YDX7)I;RP@=&%R969A<R!N
M82!S=6$@;&ES=&$@9&4@869A>F5R97,L;W,@8V%B9>=A;&AO<R!D;W,@"G-E
M<G9IYV]S(&1E(&YO=.UC:6%S('-E;&5C8VEO;F%D;W,L(&4@;75I=&\@;6%I
M<RX*375I=&]S(&1E<W1E<R!S=6WA<FEO<R!C;VYTZFT@871A;&AO<R!RX7!I
M9&]S('!A<F$@87,@9G5NY_5E<R!M86ES(&-O;75N<RP@8V]M;R!C;VUP;W-I
MY^-O"F1E('5M82!N;W9A(&UE;G-A9V5M(&1E(&4M;6%I;"P@8W)I8>?C;R!D
M92!U;2!N;W9O(&-A;&5N9.%R:6\@9&4@979E;G1O<R!O=2!T87)E9F%S+"!E
M=&,N"B`@(#PO<&%R83X*(#QP87)A/@I/<R!C;VYT9?ID;W,@9&5S=&4@<&]R
M=&%L('/C;R!P97)S;VYA;&EZX79E:7,@871R87;I<R!D92!U;2!B;W3C;R!D
M92!,87EO=70N"E!O<B!E>&5M<&QO+"!P;V1E(&5S8V]L:&5R('%U86ES(&]S
M(&ET96US(&$@:6YC;'5I<B!N97-T92!P;W)T86P@92!A('-U82!O<F1E;2!D
M92!A<')E<V5N=&'GXV\*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(FYA=F)A<B(@<W1A=&4](G5P=&]D871E(B!M9#4](F(X8V8P864Q.64U-V1F
M83!C,F(Y-C)E-3$V-S@R9C0W(CX*/'1I=&QE/E1H92!!<'!L:6-A=&EO;B!.
M879I9V%T:6]N($)A<CPO=&ET;&4^"B`\<&%R83X*3F\@;&%D;R!E<W%U97)D
M;R!D82!PX6=I;F$@=V5B(&5S=.$@82!B87)R82!D92!N879E9V'GXV\N"D-L
M:7%U92!N;W,@[6-O;F5S(&1E<W1A(&)A<G)A(&1E(&YA=F5G8>?C;R!P87)A
M('+A<&ED82!E(&;A8VEL;65N=&4@97-C;VQH97(@"F%S(&%P;&EC8>?U97,@
M9&ES<&]N[79E:7,N(`H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M<')E9G,M9&]?;6%I;G1E;F%N8V4B('-T871E/2)U<'1O9&%T92(@;60U/2)D
M9#DU9&8P-V$P,S`S,3(S,F)A96$Y,3DR.#AB,F0P,"(^"B`@("`\=&ET;&4^
M4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!$;R!-86EN=&5N86YC93PO=&ET
M;&4^"B`@("`\<&%R83X*4V4@<')E=&5N9&5R(')E86QI>F%R(&]P97)AY_5E
M<R!D92!M86YU=&5NY^-O(&YO(&QO9VEN+"!S96QE8V-I;VYE(&5S=&$@8V%I
M>&$N"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUC;VYF
M:7)M7VUA:6YT96YA;F-E(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB83(Q,38R
M8V1F9C-B,60X9F%E861B-S(Y-C(T,#`S-F4B/@H@("`@/'1I=&QE/E!R969E
M<NIN8VEA<SH@36%N=71E;N?C;SH@0V]N9FER;6%R($UA;G5T96[GXV\\+W1I
M=&QE/@H@("`@/'!A<F$^"E-E('!R971E;F1E<B!C;VYF:7)M87(@=&]D87,@
M87,@=&%R969A<R!D92!M86YU=&5NY^-O(&%N=&5S(&1E('-E<F5M(&%P;&EC
M861A<RP@<V5L96-C:6]N92!E<W1A(&-A:7AA+@I392!NXV\@<V5L96-C:6]N
M87(@97-T82!C86EX82P@=&]D87,@87,@;W!E<F'G]65S(&1E(&UA;G5T96[G
MXV\@<V5RXV\@<F5A;&EZ861A<R!A=71O;>%T:6-A;65N=&4@<V5M(&$@;W#G
MXV\@9&4*8V%N8V5L87(@;F\@;&]G:6XN"B`@("`\+W!A<F$^"CPO96YT<GD^
M"CPO:&5L<#X*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+W)O7U)/
M````````````````````````````````````````````````````````````
M`````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,#`P(#$P-3$U-#,S-S0Q(#`Q-S<S-@`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L;V-A;&4O<F]?4D\O3$-?34534T%'15,`````````````````````
M````````````````````````````````````````````````,#`P-S4U(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W-#$@,#(Q-3(S
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]R;U]23R],0U]-15-304=%
M4R]H;W)D92YM;P``````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,S<Q-2`Q
M,#4Q-30S,S<T,2`P,C,R-#<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````WA($E0````!D````'````#P#``")````7`8`````
M``"`"```*````($(```(````J@@```4```"S"```"````+D(```'````P@@`
M``4```#*"```'P```-`(```1````\`@```@````""0``"`````L)```5````
M%`D```H````J"0``#````#4)```'````0@D``"D```!*"0```@```'0)```%
M````=PD``!````!]"0``%````(X)```O````HPD```\```#3"0``)@```.,)
M```%````"@H```T````0"@``!0```!X*```0````)`H``!`````U"@``#P``
M`$8*```+````5@H```\```!B"@``#````'(*```/````?PH``!X```"/"@``
M(0```*X*```#````T`H```0```#4"@``#````-D*```*````Y@H```4```#Q
M"@``$@```/<*```0````"@L```@````;"P``$````"0+```&````-0L```<`
M```\"P```@```$0+```$````1PL```\```!,"P``!P```%P+```'````9`L`
M``0```!L"P``!0```'$+```%````=PL```<```!]"P``$0```(4+```(````
MEPL``!X```"@"P``!0```+\+```H````Q0L``"D```#N"P``$P```!@,```+
M````+`P``!$````X#```!````$H,```,````3PP``!H```!<#```%P```'<,
M```7````CPP``!L```"G#```'P```,,,```3````XPP``!````#W#```%P``
M``@-```'````(`T```4````H#0``(0```"X-```<````4`T```4```!M#0``
M`P```',-```@````=PT``"8```"8#0``#````+\-```,````S`T```@```#9
M#0``!P```.(-```&````Z@T```T```#Q#0``"P```/\-```,````"PX```H`
M```8#@```@```",.```&````)@X``$4````M#@``,````',.```0````I`X`
M`!\```"U#@``$````-4.```/````Y@X```4```#V#@``6P$``/P.```H````
M6!````D```"!$```!0```(L0```/````D1````8```"A$```!0```*@0```C
M````KA```!0```#2$```#P```.<0```(````]Q```!$`````$0``#0```!(1
M```1````(!$```@````R$0``*````#L1```"````9!$```8```!G$0``%```
M`&X1```0````@Q$``#$```"4$0``$@```,81```G````V1$```4````!$@``
M&0````<2```&````(1(``!,````H$@``%````#P2```3````41(``!0```!E
M$@``$P```'H2```0````CA(``!(```"?$@``&0```+(2```F````S!(```,`
M``#S$@``!````/<2```/````_!(``!(````,$P``!0```!\3```1````)1,`
M`!(````W$P``!0```$H3```:````4!,```D```!K$P``"P```'43```"````
M@1,```T```"$$P``'0```)(3```%````L!,```4```"V$P``!````+P3```)
M````P1,```0```#+$P``!P```-`3```/````V!,```8```#H$P``(@```.\3
M```'````$A0``"<````:%```,````$(4```4````<Q0```\```"(%```$0``
M`)@4```0````JA0```\```"[%```%````,L4```<````X!0``!L```#]%```
M(@```!D5```;````/!4``!@```!8%0``%0```'$5```6````AQ4```8```">
M%0``!P```*45```6````K14``"@```#$%0``!0```.T5```#````\Q4``"(`
M``#W%0``+@```!H6```4````218``!(```!>%@``"@```'$6```'````?!8`
M``H```"$%@``'````(\6```1````K!8``!(```"^%@``$P```-$6```"````
MY18```4```#H%@``.@```.X6```[````*1<``!8```!E%P``&@```'P7```1
M````EQ<``!$```"I%P``$0```+L7```!````)`````````!.````'0```$\`
M```7````10````<````B`````````$T````A`````````$L```!B````"@``
M`!$`````````#````#(```!3````,0`````````E````1@```%T`````````
M4@```$(```!5`````````$<````L````+P```%8```!1````-0```!`````(
M````/@```$$```!?````*P````\````Y````2@```",````8````,P```$``
M```H````8`````L``````````````%0``````````````#T````)````````
M`"X```!(````7````#H`````````#@````````!9`````````#8`````````
M&P```#\````<````&@````T````[``````````0````%`````````!(`````
M````$P````````!7````+0`````````F```````````````5````!@``````
M``!;````-P```!D`````````7@`````````X````-`````````!)````'P``
M`%H```!$`````````!X``````````````&,`````````6````"D`````````
M,```````````````/````&0```!0`````````!8````@``````````,```!A
M````0P```"H````G````3`````(`````````%``````E<R!-86EN=&5N86YC
M92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`#(T(&AO=7)S`$%-+U!-`$%D
M9"!P86ER`$%D9')E<W,`06QI87,`06X@:6QL96=A;"!V86QU92!W87,@<W!E
M8VEF:65D+@!!=F%I;&%B;&4@9FEE;&1S.@!":7)T:&1A>0!#86QE;F1A<@!#
M86YC96P@4')O8FQE;2!297!O<G0`0V5L;"!0:&]N90!#;&]S92!7:6YD;W<`
M0V]M<&%N>0!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L
M92`E<P!$1`!$86EL>0!$969A=6QT($ED96YT:71Y`$1E<V-R:6)E('1H92!0
M<F]B;&5M`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN
M:7-T<F%T;W(N`$1I<W!L87D@3W!T:6]N<P!$;R!N;W0@9&ER96-T;'D@86-C
M97-S(&UA:6YT96YA;F-E+G!H<`!%;6%I;`!%;7!T>2!R97-U;'0N`$5R<F]R
M`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI
M;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T
M90!%>&%M<&QE('9A;'5E<SH`1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC
M97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&87@`2&5L
M<`!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;W)D90!);7!O<G1E9"!F:65L
M9#H@)7,`26UP;W)T960@9FEE;&1S.@!,86YG=6%G90!,:7-T($AE;'`@5&]P
M:6-S`$QO9R!I;@!,;V<@;W5T`$U-`$UA:6P`36%T8VAI;F<@9FEE;&1S`$UE
M<W-A9V4`36]N=&AL>0!.86UE`$YE=F5R`$YO=&5S`$]P=&EO;G,`3W1H97(@
M26YF;W)M871I;VX`4&%S<W=O<F0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R
M871I;VYS`%!H;VYE`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@
M<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S
M<W=O<F0`4')O8FQE;2!$97-C<FEP=&EO;@!296UO=F4@<&%I<@!2971U<FX@
M=&\@3W!T:6]N<P!2;VQE`%-A=F4@3W!T:6]N<P!396QE8W0@=&AE(&1A=&4@
M9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE
M('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L
M96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P
M;W)T`%-K:7`@36%I;G1E;F%N8V4`4W!E8VEA;"!#:&%R86-T97(@26YP=70`
M4W5C8V5S<P!487-K<P!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N
M92X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:71L90!54DP`56YA
M8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O('1R86YS
M;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YD;R!#:&%N9V5S`%5S97(@3W!T
M:6]N<P!5<V5R;F%M90!787)N:6YG`%=E96ML>0!796QC;VUE('1O("5S`%=E
M;&-O;64L("5S`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%E9`%EE87)L>0!9
M;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S
M96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U<B`E<R!S97-S:6]N(&AA<R!E
M>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@26YF;W)M871I;VX`
M66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!;4')O8FQE;2!297!O
M<G1=`%ML:6YE("5S(&]F("5S70!V0V%R9`!0<F]J96-T+4ED+59E<G-I;VXZ
M($A/4D1%(#(N,0I297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO
M<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP
M,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#(M,#@M,#$@,#DZ,S0K,#(Z,#`*
M3&%S="U4<F%N<VQA=&]R.B!#;W)N96QI=2!-55-!5"`\8VUU<V%T0&ME>7-Y
M<RYR;SX*3&%N9W5A9V4M5&5A;3H@4D]-04Y)04X@/&DQ.&Y`;&ES=',N:&]R
M9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O
M<&QA:6X[(&-H87)S970]25-/+3@X-3DM,0I#;VYT96YT+51R86YS9F5R+45N
M8V]D:6YG.B`X8FET"@`E<R!/<&5R871I=6YI(&1E(&UE;G1E;F%N=&$@+2!#
M;VYF:7)M87)E`#(T(&1E(&]R90!!32]030!!9&%U9V$@<&5R96-H96$`061R
M97-A`$%L:6%S`%,M82!S<&5C:69I8V%T(&\@=F%L;V%R92!I;F-O<F5C=&$N
M`$-I;7!U<FD@9&ES<&]N:6)I;&4Z`%II=6$@9&4@;F%S=&5R90!#86QE;F1A
M<@!296YU;G1A(&QA(%)A<&]R=`!496QE9F]N($UO8FEL`$EN8VAI9&4@9F5R
M96%S=')A`$-O;7!A;FEA`$YU('!O="!D97-C:&ED92!M;V1U;'5L(&1E($UE
M;G1E;F%N=&$@)7,`6EH`6FEL;FEC`$ED96YT:71A=&4@26UP;&EC:71A`$1E
M<V-R:64@<')O8FQE;6$`1&5T86QI:2!I;G)E9VES=')A=&4@:6X@3$]'('!E
M;G1R=2!A9&UI;FES=')A=&]R+@!/<'1I=6YI(&1E($%F:7-A<F4`5&4@<F]G
M(&YU(&%C8V5S82!D:7)E8W0@;6%I;G1E;F%N8V4N<&AP`$5M86EL`$5M<'1Y
M(')E<W5L="X@+2!D92!T<F%D=7,`17)O87)E`$\@9&%T82!L82`Q-2!M:6YU
M=&4`3R!D871A(&QA(#,P('-E8W5N9&4`3&$@9FEE8V%R92`U(&UI;G5T90!,
M82!F:65C87)E($-O;F5C=&%R90!/(&1A=&$@;&$@,S`@;6EN=71E`$EN(&9I
M96-A<F4@;6EN=70`17AE;7!L92!D92!V86QO<FDZ`$YU('!O="!C:71I('!R
M969E<FEN=&5L92X`3G4@;6$@<&]T(&-O;F5C=&$@;&$@<V5R=F5R=6P@9&4@
M3$1!4"X`1F%X`$AE;'``061R97-A(&1E(&%C87-A`%1E;&5F;VYU;"!D92!A
M8V%S80!(;W)D90!#:6UP(&EM<&]R=&%T.B`E<P!#:6UP=7)I(&EM<&]R=&%T
M93H`3&EM8F$`3&ES=&$@<W5B:65C=&5L;W(@9&EN($AE;'``0V]N96-T87)E
M`$1E8V]N96-T87)E`$Q,`$-O<F5S<&]N9&5N=&$`0VEM<'5R:2!P;W1R:79I
M=&4@+2!D92!T<F%D=7,`365S86H`3'5N87(`3G5M90!.:6-I;V1A=&$`3F]T
M90!/<'1I=6YI`$%L=&4@:6YF;W)M871I:0!087)O;&$`17AE8W5T82!/<&5R
M871I=6YI;&4@9&4@365N=&5N86YT80!496QE9F]N`%1E(')O9R!S<&5C:69I
M8V$@=6X@<W5M87(@86P@<')O8FQE;65I+@!492!R;V<@:6YT<F]D=2!U;B!N
M=6UE(&1E('5T:6QI>F%T;W(@<VD@;R!P87)O;&$`1&5S8W)I97)E82!P<F]B
M;&5M96D`4W1E<F=E('!E<F5C:&5A`$EN87!O:2!L82!O<'1I=6YI`%)O;&4@
M+2!D92!T<F%D=7,`4V%L=F%Z82!/<'1I=6YI`$1E;&EM:71A=&]R(&1E(&1A
M=&$Z`$9O<FUA='5L(&1E(&%F:7-A<F4@82!D871E:3H`1F]R;6%T=6P@9&4@
M869I<V%R92!A(&]R96DZ`%-E;&5C=&5A>F$@9&]U82!C:6UP=7)I('!O=')I
M=FET92X`4V5L96-T96%Z82!L:6UB82!P<F5F97)A=&$Z`%1R:6UI=&4@4F%P
M;W)T(&1E($5R;V%R90!387)I('!E<W1E($UE;G1E;F%N=&$`0V%R86-T97)E
M(%-P96-I86QE("XN+@!3=6-C97,`4V%R8VEN:0!686QO87)E82!M:6YI;6$@
M97-T92`Q`$%C96%S=&$@=F%L;V%R92!T<F5B=6EE('-A(&9I92!N=6UE<FEC
M82X`5&ET;'4`55),`$YU(&UA('!O="!C;VYE8W1A(&QA('-E<G9E<G5L(%-1
M3"X`3G4@<&]T('1R861U8V4@86-E<W0@9&]C=6UE;G0@5V]R9"`M(&1E('1R
M861U<P!!;G5L96%Z82!38VAI;6)A<FEL90!/<'1I=6YI(%5T:6QI>F%T;W(`
M571I;&EZ871O<@!!=&5N=&EE`%-A<'1A;6EN86P`0FEN92!A:2!V96YI="!I
M;B!S:7-T96UU;"`E<P!":6YE(&%I('9E;FET+"`E<P!!9')E<V$@;&$@4V5R
M=FEC:74`5&5L969O;B!L82!397)V:6-I=0!!00!!;G5A;`!4<F5B=6EE('-A
M(&1E<V-R:6D@<')O8FQE;6$@:6YA:6YT92!D92!A('1R:6UI=&4@<F%P;W)T
M=6PN`%-E<VEU;F5A('1A(&1E("5S(&$@97AP:7)A="X@5&4@<F]G('-A(&9A
M8VD@3&]G($EN(&1I;B!N;W4N`$EN9F]R;6%T:6D@9&5S<')E('1I;F4`3W!T
M:75N:6QE(&%U(&9O<W0@<V%L=F%T92X`6U)A<&]R="!0<F]B;&5M85T`6VQI
M;FEA("5S(&1I;B`E<UT`=D-A<F0@+2!D92!T<F%D=7,`````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+W)U7U)5````````````````````
M````````````````````````````````````````````````````````````
M`````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U
M-#,S-S0Q(#`Q-S<U,@`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O<G5?
M4E4O3$-?34534T%'15,`````````````````````````````````````````
M````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`P,#`@,3`U,34T,S,W-#$@,#(Q-3,W`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQO8V%L92]R=5]252],0U]-15-304=%4R]H;W)D92YM;P``````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`T,C,W-2`Q,#4Q-30S,S<T,2`P,C,R
M-C<`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MWA($E0`````C`0``'````#0)``"%`0``3!(```````!@&```*````&$8```.
M````BA@```X```"9&```"````*@8```%````L1@``!,```"W&````P```,L8
M```)````SQ@```@```#9&```)````.(8```'````!QD```P````/&0``+```
M`!P9```.````21D```4```!8&0``%P```%X9```*````=AD```\```"!&0``
M(P```)$9```4````M1D``!<```#*&0``%P```.(9```?````^AD```L````:
M&@``%0```"8:```Y````/!H``"P```!V&@``*@```*,:```1````SAH```@`
M``#@&@``#@```.D:```*````^!H```@````#&P``!@````P;```5````$QL`
M`!4````I&P``"@```#\;``!4````2AL``$0```"?&P``$P```.0;```<````
M^!L```P````5'```$````"(<```'````,QP``!T````['```*0```%D<```&
M````@QP``!````"*'```$P```)L<```,````KQP``"@```"\'````@```.4<
M```%````Z!P```0```#N'```#0```/,<```0`````1T```8````2'0``&```
M`!D=```4````,AT``"\```!''0``"0```'<=```6````@1T```\```"8'0``
M)@```*@=``!#````SQT```@````3'@``"P```!P>```$````*!X```H````M
M'@``%P```#@>```1````4!X```4```!B'@``#0```&@>```@````=AX```4`
M``"7'@``$````)T>```/````KAX``!````"^'@``#P```,\>```+````WQX`
M``\```#K'@``#````/L>```/````"!\```8````8'P``'@```!\?```A````
M/A\```,```!@'P``!````&0?```,````:1\```<```!V'P``$````'X?```.
M````CQ\```(```">'P``#0```*$?```&````KQ\``!$```"V'P``!P```,@?
M```$````T!\```H```#5'P``(@```.`?```%`````R````0````)(```#```
M``X@```*````&R````4````F(```"@```"P@```/````-R```!````!'(```
M!@```%@@```/````7R```!(```!O(```$````((@```0````DR````<```"D
M(```"````*P@```.````M2```!8```#$(```$0```-L@```&````[2```!``
M``#T(```#P````4A```(````%2$```8````>(0``!P```"4A```%````+2$`
M``L````S(0```@```#\A```$````0B$``&@```!'(0``#P```+`A```*````
MP"$```<```#+(0``!P```-,A```+````VR$```D```#G(0``"0```/$A```*
M````^R$```<````&(@``"0````XB```'````&"(```H````@(@``%@```"LB
M```$````0B(```4```!'(@``#````$TB```$````6B(```0```!?(@``#```
M`&0B```"````<2(```D```!T(@``!````'XB```3````@R(```4```"7(@``
M`@```)TB```'````H"(```X```"H(@``"@```+<B```1````PB(```@```#4
M(@``"0```-TB```*````YR(``!X```#R(@``*````!$C```*````.B,```L`
M``!%(P``%````%$C```%````9B,``"D```!L(P``*````)8C```I````OR,`
M`!````#I(P``!P```/HC```3`````B0```0````6)```!P```!LD```>````
M(R0``!0```!")```#@```%<D```J````9B0```8```"1)```#````)@D```+
M````I20```4```"Q)```$0```+<D```8````R20```0```#B)```!````.<D
M```,````["0```8```#Y)```#P`````E```*````$"4```L````;)0``&@``
M`"<E```7````0B4``"<```!:)0``%P```((E```;````FB4``!D```"V)0``
M'P```-`E```3````\"4``#\````$)@``-P```$0F``!7````?"8```4```#4
M)@``#0```-HF```M````Z"8```0````6)P``)0```!LG```?````02<``!T`
M``!A)P``!@```'\G```$````AB<``!````"+)P``$P```)PG```7````L"<`
M``8```#()P``!P```,\G```&````UR<```<```#>)P``-````.8G```5````
M&R@```X````Q*```!0```$`H```)````1B@``"$```!0*```'P```'(H```?
M````DB@``#````"R*```+P```.,H```A````$RD``!P````U*0``!P```%(I
M```+````6BD```4```!F*0```@```&PI``!9````;RD```,```#)*0``(```
M`,TI```D````[BD``"8````3*@``#````#HJ```'````1RH```8```!/*@``
M,@```%8J```$````B2H```P```".*@``"````)LJ```)````I"H```H```"N
M*@``!P```+DJ```9````P2H```<```#;*@```P```.,J```&````YRH```T`
M``#N*@``"P```/PJ```O````""L```P````X*P``,0```$4K```_````=RL`
M``P```"W*P``"@```,0K```"````SRL```8```#2*P```P```-DK```9````
MW2L``$4```#W*P``,````#TL```2````;BP``!,```"!+```$````)4L```)
M````IBP``!<```"P+```%@```,@L```/````WRP``!\```#O+```%`````\M
M```0````)"T```\````U+0``#P```$4M```'````52T```4```!=+0``"```
M`&,M```(````;"T```P```!U+0``!@```((M```&````B2T```0```"0+0``
M!P```)4M```%````G2T``%H!``"C+0``)0```/XN```*````)"\```H````O
M+P``!P```#HO```%````0B\```X```!(+P``"````%<O```)````8"\```T`
M``!J+P``&````'@O```%````D2\```X```"7+P``,P```*8O```*````VB\`
M``D```#E+P``#````.\O```*````_"\```D````',```'@```!$P```3````
M,#````<```!$,```%@```$PP```C````8S````H```"',```"0```)(P``!"
M````G#```"0```#?,```*@````0Q```/````+S$```T````_,0``"@```$TQ
M```*````6#$```D```!C,0``!@```&TQ```8````=#$``!$```"-,0``%```
M`)\Q```A````M#$``#X```#6,0``%````!4R```8````*C(```P```!#,@``
M"P```%`R```(````7#(``!4```!E,@``*@```'LR```'````IC(``!4```"N
M,@``"0```,0R```-````SC(``"(```#<,@```@```/\R```)`````C,```0`
M```,,P``$0```!$S```4````(S,```<````X,P``&0```$`S```0````6C,`
M`#8```!K,P``!P```*(S```F````JC,``!````#1,P``+````.(S``!!````
M#S0```D```!1-```#````%LT```.````:#0```T```!W-```%0```(4T```)
M````FS0```4```"E-```$@```*LT```N````OC0```8```#M-```#P```/0T
M```/````!#4``!`````4-0``#@```"4U```4````-#4```X```!)-0``#0``
M`%@U```0````9C4```D```!W-0``(P```($U```E````I34```0```#+-0``
M!````-`U```)````U34```<```#?-0``&0```.<U```&`````38```<````(
M-@``#@```!`V```&````'S8```4````F-@``"0```"PV```)````-C8```D`
M``!`-@``-````$HV```&````?S8```8```"&-@``#@```(TV```0````G#8`
M``8```"M-@``#0```+0V```0````PC8```P```#3-@``"````.`V```.````
MZ38``!8```#X-@``$P````\W```,````(S<```D````P-P``!````#HW```7
M````/S<``"<```!7-P``'P```'\W```%````GS<``!D```"E-P``"P```+\W
M```,````RS<```0```#8-P``!0```-TW```.````XS<```0```#R-P```@``
M`/<W```%````^C<``#(`````.```$````#,X```+````1#@```D```!0.```
M"@```%HX```)````93@``!````!O.```$0```(`X```2````DC@``!$```"E
M.```$````+<X```1````R#@```X```#:.```#P```.DX```#````^3@```<`
M``#].```#P````4Y```'````%3D```4````=.0``$@```",Y```#````-CD`
M``T````Z.0``"P```$@Y```2````5#D```<```!G.0```@```&\Y```)````
M<CD``!$```!\.0``"@```(XY```1````F3D```8```"K.0``!@```+(Y```&
M````N3D``"````#`.0``-````.$Y```%````%CH```T````<.@``!@```"HZ
M```'````,3H``"$````Y.@``(P```%LZ```R````?SH``!,```"R.@``"0``
M`,8Z```1````T#H```8```#B.@``"````.DZ```C````\CH``!4````6.P``
M$````"P[```G````/3L```<```!E.P``#````&T[```,````>CL```@```"'
M.P``%@```)`[```?````ISL```@```#'.P``"0```-`[```3````VCL```4`
M``#N.P``#P```/0[```+````!#P```X````0/```(````!\\```5````0#P`
M`!\```!6/```)````'8\```>````FSP``!,```"Z/```$````,X\```<````
MWSP``$T```#\/```10```$H]``!,````D#T```H```#=/0``$@```.@]```F
M````^ST```@````B/@``*0```"L^```B````53X``!D```!X/@``!@```)(^
M```&````F3X``!0```"@/@``#P```+4^```3````Q3X```8```#9/@``!```
M`.`^```&````Y3X```<```#L/@``*````/0^```B````'3\``!0```!`/P``
M!@```%4_```,````7#\``!0```!I/P``%````'X_```7````DS\``#<```"K
M/P``*P```.,_```G````#T```"`````W0```!P```%A````2````8$````D`
M``!S0```!````'U```!#````@D````,```#&0```)@```,I````D````\4``
M`"L````600``$@```$)!```&````54$```D```!<00``2````&9!```,````
MKT$``!8```"\00``$````--!```0````Y$$``!````#U00``"P````9"```5
M````$D(```@````H0@```P```#%"```+````-4(``!4```!!0@``%````%="
M```E````;$(```0```"20@``,0```)="```Z````R4(```T````$0P``#P``
M`!)#```"````(D,```@````E0P```@```"Y#```4````,4,``$@```!&0P``
M00```(]#```*````T4,``!8```#<0P``#P```/-#```)`````T0```P````-
M1```&0```!I$```)````-$0``!X````^1```$0```%U$```6````;T0``!$`
M``"&1```"@```)A$```&````HT0```8```"J1```!0```+%$```)````MT0`
M``4```#!1```"@```,=$```,````TD0```<```#?1```#P```.=$```%````
M]T0```$```!:`````````)0`````````7``````````-`0``"@$``.L```##
M````&P````````#5````=0``````````````/P````````#7`````````$4`
M``"C````"P```)<```"5````KP```!4`````````!P$``",!``#3````2P``
M`+$`````````2@```/0````R````.@```&8```"'````/````!H!````````
MT0```'X`````````A0```"8```"@````C0```(````!D`````````)@```#V
M``````````@`````````V0````````!/`````````&<```![````````````
M``",````7P````,!``"^````I````"``````````T@```((`````````````
M`&\```!V````7@```($````X`````````+L```!7````#P$```````!'````
MG@````P```!J````IP`````````=`0``M0```,8```#I````````````````
M````!`$``!L!````````T````+T```#:````'@$``+8````7``````$``.\`
M```9`0``,0```!X```!X````30```.T````3`0``5@```!0```!A````_```
M``````#N`````````!````!C`````````"@```#"`````````#`````8`0``
M``````````"2````/0``````````````40```)D```!8````(0````(!``#D
M````&@```*P````S````%0$``#8`````````W0````````"Y````#@$``&P`
M``!]````N`````X```!;````'`$`````````````70```$X```#8````````
M`'0```#U``````````````";`````````.4````0`0```````!<!``!R````
M*0```(D```":````$@```/````"=````Q````,H````)`0``D0`````````=
M````MP```)8```!P````4@```"<```#W````J0```.,````&`0``````````
M`````````````.@```#B````(`$``(,````?````SP```-0```"3````1@``
M```````#````S0```&(````E````I0```&D```!_`````````(8```#,````
M`````"H``````````````,<```"?````/@````4`````````=P```#D```"$
M````^````$,````N````R0```,4`````````+P````````#Z`````````&X`
M``"T````_@`````````?`0``%`$``!@````)````LP````````!4````C@``
M````````````JP```&````"H````<0```/T```"J````^0```/$```!K````
MWP```-P`````````$P````<````(`0``+0``````````````X0``````````
M````"@```!$!``!0````OP`````````6`0``^P```.P```#;``````````T`
M``#6```````````````D`````````.<```"P````_P````0```"(`````@``
M`"(!```C`````````.````!$````20```%,```!S````K0```)P```"B````
M#P````````"+`````````(H`````````$0```&T``````````````,$```#>
M````%@````L!``!"````2````!P```#.````CP```+(`````````````````
M```9````.P```%D`````````-P`````````%`0``D````'P```!,````>0``
M`.8`````````H0```+P```!E````:````"(````A`0```````/,```!5````
M>@````````"N`````````/(`````````0`````8````,`0``$@$``#0`````
M``````````````"F````P````"P````K````RP```#4`````````00```,@`
M``#J`````````````````````0$```````"Z`````"5S($UA:6YT96YA;F-E
M($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`,3(@2&]U<B!&;W)M870`,C0@
M2&]U<B!&;W)M870`,C0@:&]U<G,`04TO4$T`06-C;W5N="!);F9O<FUA=&EO
M;@!!9&0`061D($AE<F4Z`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A
M($UO>FEL;&$@4VED96)A<@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES
M=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES
M=')A=&EO;@!!;&EA<P!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O
M=7!S`$%L;"!097)M:7-S:6]N<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@
M;&ES="!T>7!E/P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U3
M4"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;B!I;&QE9V%L
M('9A;'5E('=A<R!S<&5C:69I960N`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N
M(&ES(')E861Y+@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`071T96UP="!T;R!D96QE=&4@82!N
M;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N
M+65X:7-T96YT('!E<FUI<W-I;VXN`$%V86EL86)L92!F:65L9',Z`$)I<G1H
M9&%Y`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0V%L96YD87(`0V%N8V5L
M`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#871E9V]R:65S(&%N9"!,86)E;',`
M0V5L;"!0:&]N90!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P
M96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M
M86EL<RX`0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@
M=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92X`0VAO;W-E($%P<&QI8V%T
M:6]N.@!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-L;W-E(%=I;F1O
M=P!#;VQL87!S92!3:61E8F%R`$-O;7!A;GD`0V]N9FEG=7)A=&EO;B!I<R!O
M=70@;V8@9&%T92X`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M
M;V1U;&4@)7,`0W)E871E`$-R96%T92!A(&YE=R!O;F4`0W)E871O<B!097)M
M:7-S:6]N<P!#=7)R96YT(%1I;64`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U
M<&]N(&QO9V]N('1O("5S+@!$1`!$86EL>0!$871E`$1E9F%U;'0@0V]L;W(`
M1&5F875L="!)9&5N=&ET>0!$96QE=&4`1&5L971E('-E;&5C=&5D(&ED96YT
M:71Y`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E=&%I;',@:&%V92!B965N(&QO
M9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1I<F5C=&]R>0!$:7-P;&%Y
M(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$;R!N;W0@9&ER96-T
M;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H92!F:7)S="!R;W<@
M8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B
M;W@Z`$1O=VYL;V%D`$1O=VYL;V%D("5S`$5D:70`161I="!";&]C:P!%9&ET
M(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%;6%I;`!%
M;7!T>2!R97-U;'0N`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_
M`$5R<F]R`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y
M(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y
M(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X<&%N
M9`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O
M;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A>`!&:6QE`$9I;&4@36%N86=E<@!&
M:6QT97)S`$9U;&P@1&5S8W)I<'1I;VX`1VQO8F%L($]P=&EO;G,`1V\`1V]O
M9VQE(%-E87)C:`!'<F]U<',`1W5E<W0@4&5R;6ES<VEO;G,`2&5A9&5R<P!(
M96QP`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F
M:6QE.@!(;U]M90!(;VUE`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO<F1E
M`$EC;VYS($]N;'D`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M93H`
M26UA9V5S`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E9"!F:65L9#H@)7,`26UP
M;W)T960@9FEE;&1S.@!);F1I=FED=6%L(%5S97)S`$QA7WEO=70`3&%N9W5A
M9V4`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T
M(&QO9VEN.B!.979E<@!,87EO=70`3&ES="!(96QP(%1O<&EC<P!,;V-A;&4@
M86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O=70`3&]G:6X`3&]G:6X@
M5&%S:W,`34T`36%I;`!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y
M;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C
M:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-871C:&EN9R!F:65L9',`
M365N=2!M;V1E.@!-97-S86=E`$UO;G1H;'D`36]O;B!0:&%S97,`36]V92!$
M;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V92!D;W=N`$UO
M=F4@=7``37D@06-C;W5N=`!->2!!8V-O=6YT($EN9F]R;6%T:6]N`$YA;64`
M3F5V97(`3F5W($-A=&5G;W)Y`$YE=W,`3F5X=`!.97AT(&]P=&EO;G,`3F\`
M3F\@=F%L=65S`$YO;F4`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W1E<P!/2P!/
M<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R9V%N:7II;F<`3W1H97(@26YF;W)M
M871I;VX`4&%S<W=O<F0`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&5R9F]R;2!-
M86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N<P!097)S
M;VYA;"!);F9O<FUA=&EO;@!0:&]N90!0;&5A<V4@96YT97(@82!N86UE(&9O
M<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@
M;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@
M86YD('!A<W-W;W)D`%!R979I;W5S(&]P=&EO;G,`4')O8FQE;0!0<F]B;&5M
M($1E<V-R:7!T:6]N`%)E860`4F5F<F5S:`!2969R97-H($1Y;F%M:6,@365N
M=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5M;W1E(%-E<G9E
M<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ
M`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E('!A:7(`4F5S970`4F5T=7)N
M('1O($]P=&EO;G,`4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)O;&4`4V%V
M90!3879E($]P=&EO;G,`4V5A<F-H`%-E;&5C="!A('-E<G9E<@!396QE8W0@
M86QL`%-E;&5C="!N;VYE`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E
M;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U
M('=A;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE
M8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H
M96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O
M8FQE;2!297!O<G0`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A
M;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E
M<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T
M('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E
M(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P
M`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@
M9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE
M;B!L;V=G:6YG(&EN/P!3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_
M`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H<FEN:P!3:7IE`%-K
M:7`@36%I;G1E;F%N8V4`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&5C:6%L($-H
M87)A8W1E<B!);G!U=`!3=&%T=7,`4W5B:F5C=`!3=6)M:70`4W5C8V5S<P!3
M=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I
M;&4@)7,N`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=6YR:7-E+U-U;G-E=`!4
M87-K<P!497AT($]N;'D`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T
M960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE<F4@87)E
M(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA
M="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@=V%S(&%N(&5R<F]R
M(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AI<R!N=6UB97(@;75S
M="!B92!A="!L96%S="!O;F4N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E
M<BX`5&EC:V5T<P!4:6UE(&9O<FUA=`!4:71L90!4;P!4;R!S96QE8W0@;75L
M=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O
M;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!54DP`56YA8FQE('1O
M(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&QO860@=&AE(&1E
M9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D
M(&1O8W5M96YT`%5N9&\@0VAA;F=E<P!5;F9I;&5D`%5P9&%T90!5<V4@:68@
M;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5
M<V5R`%5S97(@3W!T:6]N<P!5<V5R;F%M90!5<V5R;F%M93H`57-E<FYA;64Z
M(`!6:65W("5S`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5V%R;FEN9P!7
M96(`5V5E:VQY`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5VAA="!A<'!L
M:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAI8V@@
M<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!4
M97AT(&5D:71O<BX`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@
M*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=O<FL@061D<F5S<P!7
M;W)K(%!H;VYE`%E9`%EE87)L>0!997,`66]U(&AA=F4@8F5E;B!L;V=G960@
M;W5T+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U
M(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U<B`E<R!S97-S:6]N
M(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@
M061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`
M66]U<B!.86UE`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L
M="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;W!T:6]N<R!H879E
M(&)E96X@=7!D871E9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`6U!R;V)L96T@
M4F5P;W)T70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]'<F]U
M<',`7TAE;'``7TQO9R!O=70`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]3971U
M<`!?57-E<G,`961I=`!U;FYA;65D`'9#87)D`%!R;VIE8W0M260M5F5R<VEO
M;CH@2&]R9&4@=C,N,2U20S,*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L
M:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#8M,#(M,#<@
M,3$Z,3`K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`V+3`R+3$W(#$W.C`P
M*S`R,#`*3&%S="U4<F%N<VQA=&]R.B!!;&5X97D@6F%K:&%R;W8@/&)A8F5R
M0&UO<V=A+FYE=#X*3&%N9W5A9V4M5&5A;3H@4G5S<VEA;B`\:3$X;D!L:7-T
M<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@
M=&5X="]P;&%I;CL@8VAA<G-E=#U#4#$R-3$*0V]N=&5N="U4<F%N<V9E<BU%
M;F-O9&EN9SH@.&)I=`H`SN_E\.#VZ/\@[^[DY.7PYNKH("5S("T@S^[D\N+E
M\.;DY>WHY0`Q,BWWX/'NXN[I`#(T+??@\>[B[ND`,C0@]^#QX`!!32]030#3
M]^7R[>#_(.?@[^CQ_`#$[N'@XNCR_`#$[N'@XNCR_#H`Q.[AX.+H\OP@[^#P
M\P#$[N'@XNCR_"!-;WII;&QA(%-I9&5B87(`P.3PY?$`P.3PY?'MX/\@ZNWH
MX^``S>#Q\O#NZ>KH("T@\_'RX.WNXNK@(._PX.(@Y.O_(.3P\^/H]2#O[NO\
MY^[BX/+EZ^7I`-/O\.#BZ^7MZ.4`S_'EXN3N[>CL`,+QY2#B[OCEY/CHY0#"
M\>4@X_#S[^_[`,+QY2#O\.#BX`#0X.?PY?CH\OP@[N_E\.#VZ.@@\>X@\>_H
M\>K@[.@`P.O\\N7P[>#RZ.+M^^D@25--4`#/X/#NZ_PZ`,CL_R#O[NO\Y^[B
MX/+EZ_\@25--4#H`P?OK[B#SZN#GX.WN(.WEZN[P\.7J\NWNY2#G[>#WY>WH
MY2X`S_#HZ^[FY>WHY0#-X/'R\.[E[>X`Q^#O\.#XZ.+@\OP@[^[D\N+E\.;D
MY>WHY2#OY?#EY"#B^^_NZ^WE[>CE["#N[^7PX/;HZ2#NX?'K\^;HXN#MZ/\_
M`,_N[_ORZN`@\^3@Z^CR_"#MY?'S^>7Q\N+S_OGHY2#O\.#BX`#/[N_[\NK@
M(/#EY.#J\NCP[N+@\OP@[>7Q\_GE\?+B\_[YZ.4@[_#@XN``Q.[Q\O/O[?OE
M(._NZ_\Z`,3E[?P@\.[FY.7MZ/\`S>#Q\O#NZ>K@.@#0X/'XZ/#E[>CE`,K@
MZ^7MY.#P_`#.\NSE[>``SO+LY>W@(.[R]^7RX"#N(._P[N'KY>SE`,K@\N7C
M[O#HZ"#H(.SE\NKH`,KKY?+N]^W@_R#PX.3H[O'B_^?\`,W@\?+P[NGJZ"#H
M[.7MZ"P@X.3PY?'@+"#O[N3OZ/'H+@#.\NSE\OSRY2#TZ^#FZN#LZ"#N[^7P
MX/;H_BCHZ"DL(.KN\N[P^^4@POL@]>[RZ/+E(.[Q\_GE\?+BZ/+\+@#"^^'E
M\.CRY2#O\.CK[N;E[>CE.@#4[O#LX/(@[O+NX?#@YN7MZ/\@Y.#R^SH`Q^#J
M\/OR_"#NZNWN`-/A\.#R_"#LY>W^`,KN[._@[>C_`,KN[?3HX_/PX/;H_R#S
M\?+@\.7KX`#-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A
M<VL@)7,`T>[GY.#R_`#1[N?DX/+\(.WNXOOI(._P[O3HZ_P`T>[GY.#RY>O\
M`-+EZO/YY>4@XO#E[/\`Q^#DX/?H+"#GX._S\>K@Y>S[Y2#O\.@@XO7NY.4@
MXB`E<P#$Q`#%YN7D[>7B[>X`Q.#RX`#6XN7R(._N(//L[NOWX.WH_@#/\.[T
MZ.O\(._N(//L[NOWX.WH_@#3Y.#KZ/+\`-/DX.OH\OP@XOOA\.#M[?OI(._P
M[O3HZ_P`SN_H^.CRY2#O\.[AZ^7L\P#/[N3P[N'M[O'RZ"#A^^OH(.?@[^CQ
MX.W[(.(@YO/P[>#K(.3K_R#@Y.SH[>CQ\O#@\N[PX"X`RN#RX.ONXP#.\N[A
M\.#FX/+\(.+PY>S_(.(@,C0M]^#Q[N+N["#T[O#LX/+E/P#$\//CZ.4@[>#Q
M\O#NZ>KH`,WE(.+[Y_OBX.GRY2!M86EN=&5N86YC92YP:'`@[>7O[O'PY>3Q
M\N+E[>WN`,(@[^7PXN[I(/'R\.[JY2#SZN#GX.W[(.CLY>W@(._NZ^7I/R#%
M\>OH(.3@+"#O[O'RX.+\\N4@X^#K[O?J\SH@`,?@X_#SY^CR_`#'X./P\^?H
M\OP@)7,`T.7DX.KRZ/#NXN#MZ.4`T.7DX.KRZ/#NXN#R_`#3\?+@[>[BZN`@
M[_#@XB#DZ_\@)7,`S>#Q\O#NZ>KH`$5M86EL`,WSZ^7B[ND@\.7G\^O\\N#R
M+@#*[NWRY>KQ\NWNY2#LY>W^(._N(.W@YN#RZ.@@[_#@XN[I(.KM[N_JZ"#L
M^_CH`,[XZ.'JX`#*X.;D^^4@,34@[.CM\_(`RN#FY/OE(#(@[.CM\_+[`,K@
MYN3[Y2`S,"#QY>KS[>0`RN#FY/OE(#4@[.CM\_(`RN#FY/OI(/#@YR#O\.@@
MXO7NY.4`RN#FY/OE(._NZ_?@\>``RN#FY//^(.SH[?/R\P#/\.CLY?`@Y^W@
M]^7MZ.DZ`-#@\?CH\.CR_`#"[O'Q\N#M[N+KY>WHY2#MX/'R\.[EZB#MY2#S
MY.#K[O'\+@#-Y?/DX/?M[N4@\>[EY.CMY>WHY2#Q(/'E\.+E\.[L($Q$05`N
M`-3@ZO$`U.#IZP#5\.#MZ.OH^>``U.CK_/+P^P#/[NOM[N4@[N_H\>#MZ.4@
M[_#NX>OE[/LZ`,_N\/+@ZP#/Y?#EZ?+H`,_NZ/'J(.(@1V]O9VQE`,/P\^_O
M^P##[O'R_`#'X./NZ^[BZN@`S^[D\>K@Y^K@`,_NZ_/XX/#HY0#-Z.;E(._P
MY>3Q\N#BZ^7MX"#H[?3N\.S@]NC_(.CG(/'@[.[C[B#MX/?@Z^`@].#IZ^`Z
M`,_N\/+@ZP#/[O#RX.L`Q.[LX/CMZ.D@X.3PY?$`Q.[LX/CMZ.D@\N7KY?3N
M[0#/[O#RX.L`TN[K_.KN(.CJ[NWJZ`#(ZN[MZN@@\2#RY>KQ\N[L`,CL_R#O
M\.[TZ.O_.@#*X/#RZ.WJZ`#([._N\/(L(/C@XR`E9`#([._N\/+H\.[BX.WN
M(._NZ^4Z("5S`,CL[^[P\NCP[N+@[?L@[^[K_SH`S^[K_.?NXN#RY>OH`-#@
M\>KKX.3JX`#?Y_OJ`,_PY>3[Y//YZ.D@XO7NY"#A^^LZ("5S`,_PY>3[Y//Y
MZ.D@XO7NY"#A^^LZ("5S(/$@ZN[L[_S^\N7PX"`E<P#/\.7D^^3S^>CI(.+U
M[N0@[>4@Y^#TZ.KQZ/#NXN#M`,+[]>[D`-'OZ/'NZB#PX.?DY>ONXB#O[N3Q
MZN#GZN@`R^[JX.OHY^#VZ/\`T.#Q[^[K[N;E[>CE`,+U[N0`POOU[N0`T_?E
M\NW@_R#GX._H\?P`PO7NY`#,S`#/[O?RX`#-X/'R\.[IZN`@\>_H\>K@(.K@
M\N7C[O#HZ2#H(/;BY?+NXB#H]2#N\N[A\.#FY>WH_P#1[N+OX.3@_OGHY2#O
M[NO_`-#EYNCL(.SE[?XZ`-'N[N'YY>WHY0#%YN7LY?'_]^WN`-3@Y_L@R_/M
M^P#OY?#E[.7Q\NCR_"#B[>CG`._E\.7LY?'RZ/+\(.+KY>+N`._E\.7LY?'R
MZ/+\(.+O\.#B[@#OY?#E[.7Q\NCR_"#BXN7P]0#OY?#E[.7Q\NCR_"#B[>CG
M`._E\.7LY?'RZ/+\(.+BY?#U`-/WY?+MX/\@Y^#OZ/'\`,+@^.`@Z.WT[O#L
MX/;H_P#([/\`S>CJ[N/DX`#-[N+@_R#JX/+EX^[PZ/\`S>[B[O'RZ`#$X.OE
MY0#1Z^7D\_[YX/\@\?+PX.WH]N``S>7R`,WE(.[O\.7DY>OE[>X`+>WE(.+[
MX?#@[2T`T>7BY?#M[N4@[^[K\_C@\.CE`,?@[.7RZN@`3TL`S>#Q\O#NZ>KH
M`,W@\?+P[NGJZ"#DZ_\Z("5S`,[PX^#MX.GGY?``S_#N]^#_(.CM].[P[.#V
MZ/\`S^#P[NO\`,_@\.[K_`#/X/#NZ_P`SO'S^>7Q\N+KY>WHY2#N[^7PX/;H
MZ2#O[N3DY?#FZN@`POOO[NOMZ/+\(.[OY?#@]NCH(.[A\>OSYNCBX.WH_R#O
M\.@@XO7NY.4@XB#QZ/'RY>SS/P#/\.#BX`#/\.#BX"#D[O'R\^_@`,OH]^W[
MY0#2Y>OE].[M`,+BY>3H\N4@[>#GXN#MZ.4@[>[B[ND@ZN#RY>/N\.CH.@#/
M[N;@Z_/I\?+@+"#Q[N[A^>CRY2#Q\_+\(._P[N'KY>S[+@#/[N;@Z_/I\?+@
M+"#BXN7DZ/+E(,+@^.@@Z.S_(._NZ_SG[N+@\N7K_R#H(._@\.[K_`#/\.7D
M^^3S^>#_(/'R\.#MZ/;@`,_P[N'KY>S@/P#.[^CQX.WHY2#O\.[AZ^7L^P#7
MZ/+@\OP`SN'M[N+H\OP`SN'M[N+K__+\(.3H[>#LZ/?E\>KHY2#O\^WJ\OL@
M[.7M_CH`SN'M[N+K__+\(.CM].[P[.#VZ/XZ`,_N]_+NXOOE(/'E\.+E\.``
MP.3PY?$@\>7PXN7PX"`H[>#O\.CLY?`@:'1T<#HO+VUA:6PN<G4I`-/DX.OH
M\OP`T^3@Z^CR_"#AZ^[J`-/DX.OH\OP@[^#P\P#1X?#N\>CR_`#"Y?#M\_+\
M\?\@ZB#MX/'R\.[IZN#L`,W@\?+P[NGJZ"#BZ.?SX.O\[>[C[B#PY>3@ZO+N
M\.``T?;E[>#PZ.D`T>[U\.#MZ/+\`-'N]?#@[>CR_"#MX/'R\.[IZN@`S^[H
M\>H`POOAY?#H\N4@\>7PXN7P`,+[X?#@\OP@XO'E`,[R[.7MZ/+\(.+[X>[P
M`,+[X>7PZ/+E(/#@Y^3EZ^CRY>O\(._NZ^7I(.3@\OLZ`,+[X>7PZ/+E(/3N
M\.S@\B#DX/+[.@#"^^'E\.CRY2#O\.[TZ.O\(.3K_R#MX/'R\.[IZN@Z`,+[
MX>7PZ/+E(.[R[N'PX.;E[>C_(/3N\.S@\B#B\.7LY>WH.@#"^^'E\.CRY2#D
MXN`@\>[B[^#DX/[YZ/4@[^[K_RX`PN#XX"#VXN7R[N+@_R#Q]>7LX`#?Y_OJ
M(.[R[N'PX.;E[>C_`,_N\>O@\OP@\>[NX?GE[>CE(.X@[_#NX>OE[.4`Q.[O
M[NOMZ/+EZ_SM^^4@[^[W\N[B^^4@\>7PXN7PX"P@ZB#J[O+N\/OL(.+[(/7N
M\NCRY2#H[.7R_"#D[O'R\^\@Z.<@S^[P\N#KX"X`T_'RX.WNXNK@(/_G^^K@
M(.+[XN[DX"P@XO#E[.7M[>[I(.?N[?L@Z"#T[O#LX/+@(.[R[N'PX.;E[>C_
M(.+PY>SE[>@N`-/Q\N#M[N+JX"#O\.CK[N;E[>C_(._N(//L[NOWX.WH_BP@
M]N+E\N[B[ND@\?7E[/L@Z"#O\.[WZ/4@[N_VZ.D@[O+NX?#@YN7MZ/\`S_#H
MZ^[FY>WH_P#*\.#RZN[E(.[A[N'YY>WHY3H`SN_PY>3EZ^CR_"#A^_'R\/OE
M(.KKX.+H^.@@Y.O_(/'Q^^ONZC\`S^[JX.?@\OP`S^[JX.?[XN#R_"#H[?3N
M\.S@]NC^(.X@[_#EY/OD\_GE["#B]>[DY3\`S^[JX.?@\OP@[.7M_B#N[^7P
MX/;HZ2#Q(/+@X>OH]N#LZ`#.\N[A\.#FX/+\(.SE[?X@)7,@\>OEXN`_`-'S
MY^CR_`#0X.?LY?``S_#N[_/Q\NCR_"#O[N3DY?#FZO,`WN;M[N4@[^[K\_C@
M\.CE`-'OY?;HX.O\[?OE(/'H[.+NZ_L`T?+@\O/Q`-+E[.``R/'JX/+\`-/Q
M[^7X[>X`T?+@\.#_(.KN[?3HX_/PX/;H_R#Q[O7PX.WE[>`@XB#TX.GK.B`E
M<P#-[N+@_R#J[NWTZ./S\.#VZ/\@\>[U\.#MY>W@(.(Z("5S`,+PY>S_(.+N
M\?7NY.`OY^#JX/+@`,?@Y.#WZ`#2[NO\ZNX@\N7J\?(`T>7PXN7P("5S(.'[
MZR#SY.#KY>T`T>7PXN7P("5S(.'[ZR#Q[N?DX.T`S>7R(.3N\?+S[^W[]2#M
MX/'R\.[EZBX`T>[NX?GE[>CE(.(@[>7BY?#M[NP@].[P[.#RY2#H(.WE(.SN
MYN7R(.'[\OP@[O+NX?#@YN7M[@#.^.CAZN`@[_#H(.[R[N'PX.;E[>CH(/WR
M[ND@]^#Q\N@@\>[NX?GE[>C_`-WR[B#WZ/'K[B#MY2#L[N;E\B#A^_+\(.SE
M[?SXY2#EY.CMZ/;[+@#=\NX@Y^W@]^7MZ.4@Y.[KYNWN(.'[\OP@]^CQZ^[L
M+@#'X._P[O'[`-3N\.S@\B#N\N[A\.#FY>WH_P#'X./NZ^[B[NH`RN[L\P#7
M\N[A^R#B^^'PX/+\(.WE\>KNZ_SJ[B#]Z^7LY>WR[N(L(//DY?#FZ.+@Z?+E
M(.W@YN#R[ND@ZNO@XNCF\R!#=')L`%523`#-Y>+NY^SNYNWN(/'NY>3H[>CR
M_/'_(/$@4U%,(/'E\.+E\.[L+@#-Y>+NY^SNYNWN(.?@X_#SY^CR_"#N[_#E
MY.7KY>WHY2`E<RX`W?+N\B#D[NKS[.7M\B!7;W)D(.WE(.SNYN7R(.'[\OP@
M[^7PY>+EY.7M+@#.\NSE[>CR_"#HY^SE[>7MZ/\`S_/Q\N[I`,_PZ.SE[>CR
M_`#(\>_NZ_SG\^7R\?\@Y?'KZ"#BX/CH(.CL_R_OX/#NZ_P@Y.O_($E-4U`@
M\>7PXN7PX"#N\NOH]^#^\O'_(.[R(/+EZO/YZ/4`S^[K_.?NXN#RY>O\`,W@
M\?+P[NGJZ"#O[NO\Y^[BX/+EZ_\`R.S_(._NZ_SG[N+@\N7K_P#([/\@[^[K
M_.?NXN#RY>O_`,CL_R#O[NO\Y^[BX/+EZ_\`S_#N\>SN\O`@)7,`S^[JX.?@
M\OP@XN7A+?'R\.#MZ/;S`,+MZ.S@[>CE`,+EX0#%YN7MY>3EZ_SM[@#$[N'P
M[B#O[N;@Z^[BX/+\(.(@)7,`Q.[A\.X@[^[FX.ONXN#R_"P@)7,`U_+N(.[R
M[N'PX.;@\OP@[^[QZ^4@XO7NY.`@XB#QZ/'RY>SS.@#4X.?@`,K@ZNCE(.[O
M]NCH(.'SY//R(.3N\?+S[^W[(.(@XNCG\^#K_.WN["#PY>3@ZO+N\.4`V.CP
MZ.W@(.SE[?X@)7,@\>OEXN`@*.'SY.7R(._PZ.SE[>7MX"#O\.@@\>OEY//^
M^>7L(.+U[N3E*0#0X.'N]^CI(.#D\.7Q`-#@X>[WZ.D@\N7KY?3N[0##PP#%
MYN7C[N3M[@#$X`#"^R#B^_CKZ"#HYR#QZ/'RY>S[+@#"^R#D[NOF[?L@[N_H
M\>#R_"#O\.[AZ^7L^RP@[_#EYN3E(/?E["#Q[.[FY?+E(.[R[O'KX/+\(/'N
M[N'YY>WHY2#N(.WEZ2X`PN#XX"`E<R#QY?'QZ/\@Y^#J[NWWZ.O@\?PN(,_N
MYN#K\^GQ\N`L(.+NZ>3H\N4@XB#QZ/'RY>SS(.?@[>[B[BX`PN#X($5M86EL
M.@#"X/@@X.3PY?$@[O+O\.#BZ/+EZ_\Z`,+@^.`@Z.WT[O#LX/;H_P#"X/CE
M(.CL_SH`U^#Q[N+NZ2#O[O_Q`,+@^"#O\.[TZ.O\(._N(//L[NOWX.WH_CH`
MPN#XY2#H[/\Z`,+@^.@@[>#Q\O#NZ>KH(.'[Z^@@[N'M[N+KY>W[+@#1\N[P
M[NWMZ.D@\>7PXN7P.@!;T>[NX?GE[>CE(.X@[_#NX>OE[.5=`%OQ\O#NZN`@
M)7,@Z.<@)7-=`-/O\.#BZ^7MZ.4`P_#S[^_[`,_N[.[Y_`#"^_7NY`#-X/'R
M\.[IZN@`S_#@XN``S_#HZ^[FY>WH_P#/[NO\Y^[BX/+EZ^@`S_#@XNCR_`#R
MY>KQ\B#Q[N[A^>7MZ/\`=D-A<F0`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]R=5]2
M52]H96QP+GAM;```````````````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,S,R,"`Q,#4Q-30S,S<T,2`P,C$U,#$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]X;6P@=F5R<VEO;CTB,2XP
M(C\^"CPA+2T@)$AO<F1E.B!H;W)D92]L;V-A;&4O<G5?4E4O:&5L<"YX;6PL
M=B`Q+C(@,C`P-"\P-2\R-R`R,#HR,CHQ,R!J86X@17AP("0@+2T^"CQH96QP
M/@H@(#QE;G1R>2!I9#TB<W5M;6%R>2(@<W1A=&4](FYE=R(^"CQT:71L93Y4
M:&4@4&]R=&%L(%!A9V4\+W1I=&QE/@H@/'!A<F$^"B`@5&AI<R!P;W)T86P@
M<&%G92!P<F]V:61E<R!A('%U:6-K('-U;6UA<GD@;V8@86QL('EO=7(@:6UP
M;W)T86YT"B`@:6YF;W)M871I;VXN($9O<B!E>&%M<&QE+"!I="!M:6=H="!S
M:&]W(&AO=R!M86YY(&YE=R!E+6UA:6P@;65S<V%G97,@>6]U"B`@:&%V92!I
M;B!Y;W5R($E.0D]8+"!U<&-O;6EN9R!E=F5N=',@;VX@>6]U<B!C86QE;F1A
M<BP@=&%S:W,@;VX@>6]U<B!T;RUD;PH@(&QI<W0L(&AE861L:6YE<R!F<F]M
M('-E;&5C=&5D(&YE=W,@<V5R=FEC97,L(&%N9"!S;R!O;BX@($UA;GD@;V8@
M=&AE<V4*("!S=6UM87)I97,@=VEL;"!C;VYT86EN('%U:6-K('-H;W)T8W5T
M<R!T;R!C;VUM;VX@9G5N8W1I;VYS+"!S=6-H(&%S"B`@8V]M<&]S:6YG(&$@
M;F5W(&UA:6P@;65S<V%G92P@8W)E871I;F<@82!N97<@8V%L96YD87(@979E
M;G0@;W(@=&%S:RP@971C+@H@/"]P87)A/@H@/'!A<F$^"B`@5&AE(&-O;G1E
M;G1S(&]F('1H:7,@<&]R=&%L('!A9V4@87)E(&-U<W1O;6EZ86)L92!V:6$@
M=&AE($QA>6]U="!B=71T;VXN"B`@1F]R(&5X86UP;&4L('EO=2!C86X@8VAO
M;W-E('=H:6-H(&ET96US('1O(&EN8VQU9&4@;VX@=&AI<R!P;W)T86P@<&%G
M92!A<PH@('=E;&P@87,@:6X@=VAI8V@@;W)D97(@=&AE>2!A<F4@<VAO=VXN
M"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)N879B87(B('-T871E
M/2)N97<B/@H\=&ET;&4^5&AE($%P<&QI8V%T:6]N($YA=FEG871I;VX@0F%R
M/"]T:71L93X*(#QP87)A/@H@($%T('1H92!L969T(&AA;F0@<VED92!O9B!T
M:&4@=V5B('!A9V4@:7,@=&AE(&%P<&QI8V%T:6]N(&YA=FEG871I;VX@8F%R
M+@H@($-L:6-K(&]N('1H92!I8V]N<R!O;B!T:&ES(&YA=FEG871I;VX@8F%R
M('1O('%U:6-K;'D@86YD(&5A<VEL>2!S=VET8V@*("!B971W965N('1H92!A
M=F%I;&%B;&4@87!P;&EC871I;VYS+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<')E9G,M9&]?;6%I;G1E;F%N8V4B('-T871E/2)N97<B/@H@
M("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@1&\@36%I;G1E
M;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK
M92!T;R!P97)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6XL
M(&-H96-K('1H:7,@8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<')E9G,M8V]N9FER;5]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!#;VYF:7)M
M($UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U('=O
M=6QD(&QI:V4@=&\@8V]N9FER;2!A;&P@;6%I;G1E;F%N8V4@=&%S:W,@8F5F
M;W)E('1H97D@87)E(')U;BP@8VAE8VL@=&AI<R!B;W@N($EF(&QE9G0@=6YC
M:&5C:V5D+"!A;&P@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!T:&%T(&YE960@
M=&\@8F4@<G5N('=I;&P@8F4@<&5R9F]R;65D(&%U=&]M871I8V%L;'D@=VET
M:"!N;R!C:&%N8V4@=&\@8V%N8V5L(&]N(&QO9VEN+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H\+VAE;'`^"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O<VM?4TL`````
M````````````````````````````````````````````````````````````
M````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#`P,#`@,3`U,34T,S,W-#(@,#$W-S,Q`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQO8V%L92]S:U]32R],0U]-15-304=%4P``````````````````````````
M```````````````````````````````````````````P,#`W-34@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<T,2`P,C$U,34`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+W-K7U-++TQ#7TU%4U-!1T53+VAO
M<F1E+FUO````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P-#`T,3<S(#$P-3$U
M-#,S-S0Q(#`R,S(T,P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#>$@25`````&,'```<````-#L``-D)``!,=@```````+"=
M```.````L9T```\```#`G0``#0```-"=```(````WIT```L```#GG0``#```
M`/.=```$`````)X``!@````%G@``&P```!Z>```M````.IX``!T```!HG@``
M)````(:>```I````JYX``!D```#5G@``)@```.^>```,````%I\``"0````C
MGP``#P```$B?```+````6)\```X```!DGP``!0```'.?```H````>9\```@`
M``"BGP``"@```*N?```5````MI\``!(```#,GP``"P```-^?``"%````ZY\`
M``X```!QH```"@```("@```-````BZ````X```"9H```$0```*B@```-````
MNJ````P```#(H```#0```-6@```&````XZ```)0```#JH```"@```'^A```/
M````BJ$``!@```":H0``#````+.A```.````P*$```X```#/H0``"````-ZA
M```)````YZ$``"X```#QH0``&@```""B```R````.Z(``#@```!NH@``5```
M`*>B``!1````_*(``%H```!.HP``5P```*FC```T`````:0```D````VI```
M#0```$"D```'````3J0```H```!6I```#P```&&D```%````<:0```8```!W
MI```$0```'ZD```(````D*0```D```"9I```"0```*.D```E````K:0``"``
M``#3I```$P```/2D```0````"*4```\````9I0``"@```"FE```#````-*4`
M``\````XI0``%````$BE```)````7:4```T```!GI0``$@```'6E```9````
MB*4``!X```"BI0``#P```,&E```*````T:4```\```#<I0``"````.RE```D
M````]:4``!0````:I@``%@```"^F```(````1J8``$X```!/I@``+0```)ZF
M```9````S*8```<```#FI@``#````.ZF```L````^Z8```X````HIP```P``
M`#>G```+````.Z<```<```!'IP``!P```$^G```%````5Z<```4```!=IP``
M"@```&.G```#````;J<``!<```!RIP``"@```(JG```/````E:<```X```"E
MIP``&````+2G```C````S:<```X```#QIP``%`````"H```7````%:@``!<`
M```MJ```%P```$6H```3````7:@```\```!QJ```#@```(&H```?````D*@`
M`!T```"PJ```!P```,ZH```&````UJ@```@```#=J```#P```.:H```&````
M]J@```H```#]J```$P````BI```+````'*D``!`````HJ0``%0```#FI```5
M````3ZD```<```!EJ0``$````&VI```%````?JD``!$```"$J0``#````):I
M```[````HZD``#@```#?J0``"0```!BJ```'````(JH```,````JJ@``!0``
M`"ZJ```0````-*H```D```!%J@``$P```$^J```Y````8ZH``"<```"=J@``
M+````,6J```J````\JH``"4````=JP``"@```$.K```&````3JL```D```!5
MJP``!P```%^K```O````9ZL``#<```"7JP``+@```,^K``!5````_JL``"T`
M``!4K```+0```(*L```]````L*P``#\```#NK```+0```"ZM``!`````7*T`
M`",```"=K0``(P```,&M``!`````Y:T``"T````FK@``,P```%2N```E````
MB*X``!4```"NK@``&0```,2N```I````WJX``"0````(KP``*````"VO```1
M````5J\```H```!HKP``#````'.O```*````@*\``!````"+KP``%@```)RO
M```6````LZ\```<```#*KP``!P```-*O```*````VJ\```@```#EKP``)P``
M`.ZO```(````%K````<````?L```!P```">P```&````+[````4````VL```
M!P```#RP```&````1+````@```!+L```*0```%2P```.````?K````H```"-
ML```!````)BP```'````G;````D```"EL```!@```*^P```1````MK````<`
M``#(L```%@```-"P```$````Y[````@```#LL```!@```/6P```-````_+``
M``8````*L0``'@```!&Q```1````,+$```@```!"L0``#0```$NQ```,````
M6;$```<```!FL0```P```&ZQ```#````<K$``!<```!VL0``$P```(ZQ```=
M````HK$```@```#`L0``!````,FQ```(````SK$```@```#7L0``00```."Q
M```:````(K(``"L````]L@``(````&FR```5````BK(```8```"@L@``!@``
M`*>R```5````KK(``!@```#$L@``(@```-VR```N`````+,``!T````OLP``
M(0```$VS``!4````;[,``"D```#$LP``"@```.ZS```'````^;,``!4````!
MM```#@```!>T```*````)K0```\````QM```#0```$&T```/````3[0```T`
M``!?M```"0```&VT```&````=[0``!@```!^M```$P```)>T```1````J[0`
M`!0```"]M```!````-*T```&````U[0``!0```#>M```5````/.T``!D````
M2+4```0```"MM0``#@```+*U```%````P;4```4```#'M0``$P```,VU```1
M````X;4``!$```#SM0``'`````6V```J````(K8``!````!-M@``(0```%ZV
M```%````@+8``!,```"&M@``"P```)JV```2````IK8```H```"YM@``#P``
M`,2V```-````U+8``!$```#BM@``$P```/2V```,````"+<```8````5MP``
M#````!RW```&````*;<``!<````PMP``$````$BW```1````6;<```@```!K
MMP``!0```'2W```,````>K<``!````"'MP``!0```)BW```-````GK<```8`
M``"LMP``!P```+.W```-````N[<```<```#)MP``"P```-&W```'````W;<`
M``<```#EMP``"0```.VW```)````][<```H````!N```&0````RX```]````
M)K@``!T```!DN```#````(*X```0````C[@```4```"@N```)0```*:X```2
M````S+@``!,```#?N```*P```/.X```[````'[D``"````!;N0``"````'RY
M```V````A;D``"$```"\N0``$````-ZY```(````[[D```P```#XN0``!@``
M``6Z```$````#+H```\````1N@``#@```"&Z```*````,+H```T````[N@``
M'P```$FZ```<````:;H``"$```"&N@``'@```*BZ```9````Q[H``!X```#A
MN@``'0````"[```;````'KL``"`````ZNP``+@```%N[```F````BKL``!P`
M``"QNP``'@```,Z[```<````[;L``"8````*O```*P```#&\```S````7;P`
M`"8```"1O```*P```+B\```X````Y+P``!T````=O0``%0```#N]```O````
M4;T``"````"!O0``$@```**]```I````M;T``!X```#?O0``(````/Z]```2
M````'[X``*(````RO@``%@```-6^```C````[+X``"@````0OP``*0```#F_
M```H````8[\``!\```",OP``%0```*R_```@````PK\``"4```#COP``*```
M``G````M````,L```#````!@P```D@```)'````A````),$``!8```!&P0``
M'````%W!```F````>L$``"H```"AP0``00```,S!``!$````#L(```P```!3
MP@``!P```&#"```'````:,(```8```!PP@``#0```'?"```0````A<(``!(`
M``"6P@``$P```*G"```2````O<(```<```#0P@``!````-C"```0````W<(`
M`!````#NP@``#````/_"```.````#,,```T````;PP``#P```"G#```3````
M.<,```T```!-PP``*````%O#```#````A,,```T```"(PP``!@```);#```.
M````G<,```(```"LPP``20```*_#```%````^<,``!````#_PP``#P```!#$
M```$````(,0```T````EQ```#@```#/$```#````0L0```X```!&Q```"```
M`%7$```/````7L0```\```!NQ```!P```'[$```-````AL0``!````"4Q```
M#0```*7$```+````L\0```8```"_Q```"P```,;$```,````TL0```H```#?
MQ```$0```.K$```9````_,0```L````6Q0``#0```"+%```B````,,4``!L`
M``!3Q0``-````&_%```*````I,4``!@```"OQ0``&0```,C%```6````XL4`
M`"(```#YQ0``#0```!S&```'````*L8``!0````RQ@``"P```$?&```B````
M4\8``"\```!VQ@``"P```*;&```)````LL8``!D```"\Q@``"P```-;&```7
M````XL8``!<```#ZQ@``"0```!+'```6````',<```\````SQP``&0```$/'
M```6````7<<```X```!TQP``&````(/'```(````G,<```T```"EQP``)@``
M`+/'``!#````VL<```@````>R```$@```"?(```?````.L@```@```!:R```
M"P```&/(```O````;\@```X```"?R```!0```*[(```&````M,@```,```"[
MR```!P```+_(```$````Q\@```H```#,R```"@```-?(```/````XL@``!``
M``#RR```%P````/)```1````&\D``!D````MR0``%P```$?)```)````7\D`
M``4```!IR0``"P```&_)```*````>\D```(```"&R0``!0```(G)```-````
MC\D``!L```"=R0``%P```+G)```4````T<D```D```#FR0``#@```/#)```-
M````_\D``!(````-R@``.````"#*```@````6<H```@```!ZR@``#@```(/*
M``![````DLH``!@````.RP``&````"?+```1````0,L```<```!2RP``!0``
M`%K+```8````8,L``!X```!YRP``&P```)C+```9````M,L``!L```#.RP``
M&0```.K+```3````!,P```<````8S```"````"#,```&````*<P```8````P
MS```$````#?,```/````2,P``!````!8S```#P```&G,```+````><P```\`
M``"%S```#````)7,```/````HLP```<```"RS```!@```+K,```.````P<P`
M``P```#0S```*````-W,```/````!LT```@````6S0``"````!_-```3````
M*,T``!X````\S0``(0```%O-```@````?<T``!D```">S0``%P```+C-```E
M````T,T``!<```#VS0``%@````[.```$````)<X``!L````JS@``#0```$;.
M```,````5,X```,```!AS@``!0```&7.```(````:\X```H```!TS@``#```
M`'_.```+````C,X``!````"8S@``#````*G.```$````MLX```0```"[S@``
M$P```,#.```4````U,X```P```#IS@``"0```/;.```.`````,\```L````/
MSP``&P```!O/```'````-\\```<````_SP``"@```$?/```-````4L\```D`
M``!@SP``!````&K/```%````;\\```,```!USP``&````'G/```*````DL\`
M``0```"=SP``)@```*+/```.````R<\``'P```#8SP``%0```%70```%````
M:]````<```!QT```#````'G0```(````AM````H```"/T```!@```)K0```(
M````H=````(```"JT```!@```*W0```&````M-```!0```"[T```#0```-#0
M```0````WM```!L```#OT```!`````O1```)````$-$``!`````:T0``"0``
M`"O1```)````-=$```4````_T0``&@```$71```(````8-$```8```!IT0``
M&0```'#1```.````BM$```<```"9T0``!P```*'1```%````J=$```D```"O
MT0``"@```+G1```"````Q-$```8```#'T0``"P```,[1```-````VM$```D`
M``#HT0``!@```/+1```)````^=$```<````#T@``%`````O2```=````(-(`
M`$(````^T@``)0```('2```E````I](```8```#-T@``"@```-32```$````
MW](```D```#DT@``"````.[2```1````]](```D````)TP``!@```!/3```-
M````&M,```8````HTP``!````"_3```Y````--,``#T```!NTP``.@```*S3
M```>````Y],```4````&U```#@````S4```$````&]0```8````@U```!P``
M`"?4```A````+]0```T```!1U```!@```%_4```$````9M0``!$```!KU```
M!@```'W4```*````A-0``"(```"/U```!````++4```%````M]0``!T```"]
MU```!````-O4```,````X-0```X```#MU```"@```/S4```(````!]4```D`
M```0U0``!0```!K5```Z````(-4``#````!;U0``-0```(S5```I````PM4`
M`$<```#LU0``.````#36```I````;=8``#\```"7U@``+@```-?6```M````
M!M<``!\````TUP``#P```%37```2````9-<```L```!WUP``)@```(/7```I
M````JM<``"0```#4UP``)@```/G7```(````(-@```H````IV```"0```#38
M```'````/M@``"````!&V```(````&?8```F````B-@```H```"OV```&0``
M`+K8```I````U-@``!8```#^V```$@```!79```'````*-D```H````PV0``
M#````#O9```/````2-D``!````!8V0``0````&G9``!P````JMD``&8````;
MV@``#@```(+:```)````D=H```H```";V@``$@```*;:```3````N=H```P`
M``#-V@``!@```-K:```/````X=H``!(```#QV@``$`````3;```1````%=L`
M`!P````GVP``(P```$3;``!J````:-L```\```#3VP``!0```./;```0````
MZ=L```D```#ZVP``!`````3<```+````"=P``"`````5W```%````#;<```,
M````2]P```P```!8W```#P```&7<```5````==P``"D```"+W```*@```+7<
M```F````X-P``"<````'W0``*0```"_=```J````6=T``!D```"$W0``0@``
M`)[=```1````X=T``!(```#SW0``$P````;>```4````&MX```\````OW@``
M%@```#_>```7````5MX``!````!NW@``$0```'_>```T````D=X``!,```#&
MW@``$@```-K>```U````[=X``!0````CWP``!P```#C?```,````0-\``"``
M``!-WP``$````&[?```4````?]\``!$```"4WP``%P```*;?```<````OM\`
M`!,```#;WP``%````._?```:````!.```!$````?X```&@```#'@```>````
M3.```!H```!KX```$P```(;@```5````FN```!$```"PX```%P```,+@```4
M````VN```!<```#OX```%0````?A```)````'>$``!`````GX0``&0```#CA
M```$````4N$```<```!7X0``"P```%_A```1````:^$```8```!]X0``!@``
M`(3A```&````B^$```4```"2X0``!P```)CA```'````H.$```4```"HX0``
M!@```*[A```&````M>$```0```"\X0``!````,'A```'````QN$```X```#.
MX0``#````-WA```,````ZN$```T```#WX0``"@````7B```.````$.(```4`
M```?X@``*````"7B```.````3N(```P```!=X@``#P```&KB```*````>N(`
M``@```"%X@``"0```([B```K````F.(```0```#$X@``"````,GB```F````
MTN(``!(```#YX@``!@````SC```*````$^,```<````>XP``"````";C```@
M````+^,```D```!0XP``%````%KC```,````;^,```T```!\XP``#@```(KC
M```6````F>,``!$```"PXP``!@```,+C```#````R>,```8```#-XP``&0``
M`-3C```'````[N,```0```#VXP``"P```/OC```+````!^0```<````3Y```
M!0```!OD```'````(>0``!8````IY```#0```$#D```-````3N0```H```!<
MY```$````&?D```/````>.0``!$```"(Y```%P```)KD```*````LN0``!$`
M``"]Y```"````,_D```$````V.0```\```#=Y```.@```.WD```%````*.4`
M``P````NY0``'@```#OE```.````6N4``!````!IY0``"P```'KE```,````
MAN4```D```"3Y0``!P```)WE```*````I>4```D```"PY0``#@```+KE```0
M````R>4``!L```#:Y0``&````/;E```:````#^8```H````JY@``"0```#7F
M```*````/^8```P```!*Y@``#P```%?F```(````9^8```8```!PY@``'```
M`'?F```'````E.8```4```"<Y@``"P```*+F``!'````KN8```T```#VY@``
M"0````3G```$````#N<```,````3YP``$P```!?G```3````*^<``!,````_
MYP``"@```%/G```"````7N<```0```!AYP``)0```&;G```#````C.<```4`
M``"0YP``*@```);G```*````P><```4```#,YP``!````-+G```*````U^<`
M``T```#BYP``!@```/#G```(````]^<```@`````Z```!`````GH```%````
M#N@``&@````4Z```"0```'WH```,````A^@``!````"4Z```!0```*7H```&
M````J^@``!L```"RZ```+P```,[H```0````_N@```H````/Z0``#P```!KI
M```*````*ND```D````UZ0``$P```#_I```;````4^D``!@```!OZ0``%P``
M`(CI```?````H.D```X```#`Z0```P```,_I```'````T^D```@```#;Z0``
M!P```.3I```*````[.D```L```#WZ0``!P````/J``!1````"^H``!````!=
MZ@``#````&[J```-````>^H``!H```")Z@``2@```*3J```9````[^H```8`
M```)ZP``&@```!#K```E````*^L```8```!1ZP``!@```%CK```?````7^L`
M``8```!_ZP``"0```(;K```8````D.L``!<```"IZP``*````,'K```&````
MZNL```T```#QZP``(@```/_K``!7````(NP``!,```!Z[```(P```([L```3
M````LNP```(```#&[```"P```,GL```(````U>P```T```#>[```"@```.SL
M```'````]^P``!0```#_[```!@```!3M```(````&^T```X````D[0``!P``
M`#/M```*````.^T```L```!&[0``,@```%+M```'````A>T```P```"-[0``
M#0```)KM```,````J.T```D```"U[0``"0```+_M```*````R>T```<```#4
M[0``"0```-SM```'````YNT```H```#N[0``&P```/GM```2````%>X```H`
M```H[@``%@```#/N```)````2NX``!````!4[@``!P```&7N```2````;>X`
M``0```"`[@``!P```(7N```%````C>X```4```"3[@``"P```)GN```4````
MI>X``!$```"Z[@``&@```,SN```6````Y^X``!0```#^[@``%P```!/O```8
M````*^\``!P```!$[P``&0```&'O```'````>^\```4```"#[P``#0```(GO
M```,````E^\``!$```"D[P``"````+;O```7````O^\```L```#7[P``#```
M`./O```?````\.\``!H````0\```$P```"OP```$````/_````H```!$\```
M!````$_P```-````5/````P```!B\```!0```&_P```)````=?````4```!_
M\```!P```(7P```%````C?````0```"3\````@```)CP```X````F_```"P`
M``#4\```$@````'Q```I````%/$``#(````^\0``"@```''Q```L````?/$`
M`"X```"I\0``,P```-CQ```S````#/(``#@```!`\@``#P```'GR```8````
MB?(``!````"B\@``#P```+/R```3````P_(``!4```#7\@``%````.WR```2
M`````O,``!0````5\P``%0```"KS```M````0/,``"T```!N\P``,0```)SS
M```N````SO,``"\```#]\P``+````"WT``!B````6O0``!,```"]]```#0``
M`-'T```(````W_0``!<```#H]```"`````#U```,````"?4``"L````6]0``
M(0```$+U```:````9/4```D```!_]0``10```(GU``!!````S_4```0````1
M]@``$P```!;V```.````*O8``!,````Y]@``&````$WV```&````9O8```D`
M``!M]@``"@```'?V```/````@O8``!````"2]@``!P```*/V```.````J_8`
M``4```"Z]@``&P```,#V```(````W/8```8```#E]@``%````.SV```1````
M`?<```X````3]P``.````"+W```"````6_<```8```!>]P``#@```&7W```%
M````=/<```<```!Z]P``#@```(+W```&````D?<``"@```"8]P``#````,'W
M```<````SO<```0```#K]P``*0```/#W```7````&O@``!\````R^```7```
M`%+X```4````K_@``#X```#$^```'P````/Y```0````(_D```<````T^0``
M#@```#SY```,````2_D```P```!8^0``$P```&7Y```*````>?D``!T```"$
M^0``&0```*+Y```%````O/D``!$```#"^0``$0```-3Y```D````YOD``!(`
M```+^@``%0```![Z```2````-/H```X```!'^@``&0```%;Z```(````</H`
M``D```!Y^@``#0```(/Z```*````D?H```<```"<^@``#P```*3Z```&````
MM/H```L```"[^@``&@```,?Z```*````XOH```<```#M^@``"````/7Z```%
M````_OH``!\````$^P``!@```"3[```0````*_L```@````\^P``#0```$7[
M```(````4_L``!X```!<^P``$@```'O[```L````COL``!H```"[^P``"0``
M`-;[```*````X/L``!4```#K^P``!0````'\```4````!_P```0````<_```
M$````"'\```&````,OP```<````Y_```'@```$'\```H````8/P```H```")
M_```'````)3\```1````L?P```L```##_```&@```,_\```4````ZOP```0`
M``#__```!`````3]```+````"?T```4````5_0``!@```!O]```(````(OT`
M``8````K_0``&P```#+]```T````3OT``#0```"#_0``(````+C]```I````
MV?T``"`````#_@``00```"3^```:````9OX``"@```"!_@``*0```*K^``!0
M````U/X``"(````E_P``!@```$C_```(````3_\```4```!8_P``"````%[_
M```9````9_\``!D```"!_P``*@```)O_```C````QO\``!D```#J_P``+@``
M``0``0`T````,P`!``@```!H``$`%P```'$``0`*````B0`!``<```"4``$`
M(0```)P``0`0````O@`!``X```#/``$`"P```-X``0`'````Z@`!`!,```#R
M``$`"`````8!`0`+````#P$!``H````;`0$`%````"8!`0`/````.P$!`#(`
M``!+`0$`"P```'X!`0`%````B@$!``4```"0`0$`!0```)8!`0`7````G`$!
M``\```"T`0$`!````,0!`0`*````R0$!``D```#4`0$`"P```-X!`0`-````
MZ@$!``P```#X`0$`#@````4"`0`%````%`(!``0````:`@$`#0```!\"`0`R
M````+0(!`$4```!@`@$`%P```*8"`0`'````O@(!`!X```#&`@$`%````.4"
M`0`%````^@(!`!0``````P$`!@```!4#`0`'````'`,!``X````D`P$`*@``
M`#,#`0`&````7@,!``P```!E`P$`#0```'(#`0`1````@`,!``L```"2`P$`
M-@```)X#`0`*````U0,!`"(```#@`P$`"P````,$`0`/````#P0!`#(````?
M!`$`)0```%($`0`P````>`0!`#$```"I!`$`+0```-L$`0`.````"04!``4`
M```8!0$`#@```!X%`0`3````+04!`!(```!!!0$`!P```%0%`0`1````7`4!
M`!,```!N!0$`!P```((%`0`4````B@4!`!@```"?!0$`!P```+@%`0`%````
MP`4!``P```#&!0$`#````-,%`0`2````X`4!``0```#S!0$`!P```/@%`0`*
M``````8!``L````+!@$`#````!<&`0`.````)`8!``X````S!@$`!0```$(&
M`0`%````2`8!`"X```!.!@$`)@```'T&`0`C````I`8!``,```#(!@$`$@``
M`,P&`0`&````WP8!`!X```#F!@$`&`````4'`0`E````'@<!``T```!$!P$`
M"0```%('`0`?````7`<!``,```!\!P$`!P```(`'`0`*````B`<!``(```"3
M!P$`#````)8'`0`5````HP<!``L```"Y!P$`&0```,4'`0`@````WP<!`!(`
M````"`$`!0```!,(`0`*````&0@!`!4````D"`$`$@```#H(`0`,````30@!
M``0```!:"`$`"0```%\(`0`'````:0@!``P```!Q"`$`4@```'X(`0`7````
MT0@!`"0```#I"`$`$@````X)`0`'````(0D!``8````I"0$`#@```#`)`0`,
M````/PD!``T```!,"0$`%0```%H)`0`2````<`D!``\```"#"0$`%````),)
M`0`*````J`D!`!L```"S"0$`$````,\)`0`+````X`D!`&D```#L"0$`&@``
M`%8*`0`7````<0H!`"<```")"@$`&@```+$*`0`7````S`H!`!L```#D"@$`
M&0`````+`0`?````&@L!`!,````Z"P$`"````$X+`0`'````5PL!``@```!?
M"P$`"0```&@+`0`5````<@L!``T```"("P$`(P```)8+`0`-````N@L!`!,`
M``#("P$`"````-P+`0`#````Y0L!`$8```#I"P$`/P```#`,`0`W````<`P!
M`%<```"H#`$`!0`````-`0`?````!@T!`"\````F#0$`"@```%8-`0`(````
M80T!``T```!J#0$`+0```'@-`0`$````I@T!`$\```"K#0$`)0```/L-`0`<
M````(0X!``L````^#@$`'P```$H.`0`=````:@X!`"4```"(#@$`(````*X.
M`0`D````SPX!`"````#T#@$`"P```!4/`0`'````(0\!``T````I#P$`#```
M`#</`0`7````1`\!``8```!<#P$`.0```&,/`0`,````G0\!``<```"J#P$`
M"0```+(/`0`3````O`\!``D```#0#P$`!````-H/`0`0````WP\!``@```#P
M#P$`"````/D/`0`$`````A`!``L````'$`$`#````!,0`0`2````(!`!`!$`
M```S$`$`#````$40`0`:````4A`!``\```!M$`$`!P```'T0`0`-````A1`!
M`!0```"3$`$`#@```*@0`0`,````MQ`!`"P```#$$`$`$P```/$0`0`<````
M!1$!`"@````B$0$`!@```$L1`0`'````4A$!`!,```!:$0$`!0```&X1`0`$
M````=!$!`!<```!Y$0$`"@```)$1`0`,````G!$!``D```"I$0$`!@```+,1
M`0`)````NA$!``@```#$$0$`"0```,T1`0`*````UQ$!`!$```#B$0$`!@``
M`/01`0`.````^Q$!``X````*$@$`#0```!D2`0`+````)Q(!`!T````S$@$`
M"P```%$2`0`"````71(!`!P```!@$@$`!P```'T2`0`&````A1(!`&0```",
M$@$`"0```/$2`0`'````^Q(!`"8````#$P$`.````"H3`0`:````8Q,!`"H`
M``!^$P$`.P```*D3`0`H````Y1,!`#0````.%`$`&0```$,4`0`5````710!
M``4```!S%`$`!P```'D4`0`(````@10!``<```"*%`$`!0```)(4`0`'````
MF!0!``X```"@%`$`"0```*\4`0`&````N10!``@```#`%`$`"P```,D4`0`'
M````U10!``@```#=%`$`!P```.84`0`6````[A0!``D````%%0$`!@````\5
M`0`+````%A4!`!`````B%0$`!@```#,5`0`<````.A4!`!0```!7%0$`!P``
M`&P5`0`1````=!4!``@```"&%0$`#@```(\5`0`(````GA4!``4```"G%0$`
M$````*T5`0`0````OA4!``8```#/%0$`&0```-85`0`*````\!4!`!P```#[
M%0$`!P```!@6`0`%````(!8!`!`````F%@$`%````#<6`0`+````3!8!``T`
M``!8%@$`*````&86`0`8````CQ8!`!<```"H%@$`!````,`6`0`)````Q18!
M``H```#/%@$`!P```-H6`0`"````XA8!``@```#E%@$`(P```.X6`0`X````
M$A<!`"8```!+%P$`,0```'(7`0`G````I!<!`&0```#,%P$`%````#$8`0!5
M````1A@!`#@```"<&`$`2@```-48`0!;````(!D!`"@```!\&0$`.````*49
M`0`H````WAD!`"P````'&@$`)@```#0:`0`;````6QH!`#X```!W&@$`J0$`
M`+8:`0`C````8!P!`!<```"$'`$`2````)P<`0"%````Y1P!`#````!K'0$`
M)0```)P=`0!!````PAT!`%L````$'@$`20```&`>`0`Q````JAX!`!T```#<
M'@$`&````/H>`0`K````$Q\!`"$````_'P$`'P```&$?`0`K````@1\!`"$`
M``"M'P$`)P```,\?`0`Z````]Q\!`!T````R(`$`$0```%`@`0`S````8B`!
M`"4```"6(`$`)P```+P@`0`@````Y"`!`!\````%(0$`,````"4A`0!I````
M5B$!`#$```#`(0$`00```/(A`0`S````-"(!`"4```!H(@$`/0```(XB`0!E
M````S"(!`$T````R(P$`+P```(`C`0`N````L",!`#````#?(P$`5````!`D
M`0!:````920!`$@```#`)`$`2@````DE`0`R````5"4!`"\```"')0$`+```
M`+<E`0`M````Y"4!`'$````2)@$`9@```(0F`0!O````ZR8!`+,```!;)P$`
M%P````\H`0`E````)R@!`#(```!-*`$`*0```(`H`0`^````JB@!`"(```#I
M*`$`4@````PI`0`E````7RD!``L```"%*0$`L0```)$I`0!%````0RH!`"$`
M``")*@$`,````*LJ`0`E````W"H!`!P````"*P$`,0```!\K`0`'````42L!
M``<```!9*P$`!````&$K`0`-````9BL!``L```!T*P$`#@```(`K`0`+````
MCRL!``4```";*P$`$````*$K`0`"````LBL!`%D```"U*P$`!0````\L`0`2
M````%2P!``0````H+`$`!P```"TL`0`(````-2P!``4````^+`$``P```$0L
M`0`0````2"P!``P```!9+`$`$P```&8L`0`-````>BP!``(```"(+`$`!P``
M`(LL`0`&````DRP!``P```":+`$`&````*<L`0`&````P"P!`!(```#'+`$`
M#````-HL`0`#````YRP!`"H```#K+`$`!````!8M`0`&````&RT!``<````B
M+0$`'P```"HM`0`U````2BT!`"X```"`+0$`+P```*\M`0`7````WRT!`"(`
M``#W+0$`)0```!HN`0`@````0"X!`!L```!A+@$`&````'TN`0`D````EBX!
M`!\```"[+@$`&@```-LN`0`A````]BX!`"`````8+P$`&@```#DO`0`R````
M5"\!`!H```"'+P$`+P```*(O`0`K````TB\!`!\```#^+P$`(P```!XP`0`?
M````0C`!`!H```!B,`$`(0```'TP`0`E````GS`!`"8```#%,`$`)0```.PP
M`0`D````$C$!`!@````W,0$`'0```%`Q`0`D````;C$!`!@```"3,0$`(@``
M`*PQ`0`L````SS$!`"\```#\,0$`%0```"PR`0`E````0C(!`#P```!H,@$`
M'P```*4R`0`C````Q3(!`!\```#I,@$`(`````DS`0`:````*C,!`!@```!%
M,P$`)@```%XS`0`>````A3,!`"D```"D,P$`'@```,XS`0`Q````[3,!``D`
M```?-`$`#````"DT`0`7````-C0!`"\```!.-`$`)````'XT`0`'````HS0!
M`!0```"K-`$`#@```,`T`0`-````SS0!``4```#=-`$`!P```.,T`0`B````
MZS0!`"4````.-0$`&@```#0U`0`=````3S4!`!H```!M-0$`!P```(@U`0#'
M````D#4!``L```!8-@$`%0```&0V`0`&````>C8!``D```"!-@$`"P```(LV
M`0`-````ES8!`!<```"E-@$`!@```+TV`0`S````Q#8!`!,```#X-@$`$P``
M``PW`0`'````(#<!``\````H-P$`!P```#@W`0`R````0#<!``0```!S-P$`
M(0```'@W`0`3````FC<!``P```"N-P$`$0```+LW`0`R````S3<!`!8`````
M.`$`"````!<X`0`=````(#@!``D````^.`$`"@```$@X`0`4````4S@!``H`
M``!H.`$`'0```',X`0`(````D3@!`!\```":.`$`"````+HX`0`:````PS@!
M`"<```#>.`$`!@````8Y`0`5````#3D!``<````C.0$`"````"LY`0`)````
M-#D!`#\````^.0$`!P```'XY`0`/````ACD!``X```"6.0$`$````*4Y`0`)
M````MCD!``D```#`.0$`"````,HY`0`'````TSD!`!D```#;.0$`"@```/4Y
M`0`7`````#H!`!0````8.@$`"@```"TZ`0`,````.#H!`!<```!%.@$`!```
M`%TZ`0`J````8CH!``P```"-.@$`$0```)HZ`0`'````K#H!``(```"T.@$`
M$````+<Z`0`8````R#H!``L```#A.@$``P```.TZ`0`(````\3H!``8```#Z
M.@$`!P````$[`0`-````"3L!``L````7.P$`#@```",[`0`O````,CL!`"``
M``!B.P$`'````(,[`0`5````H#L!``P```"V.P$`,0```,,[`0`%````]3L!
M`!(```#[.P$`/P````X\`0`2````3CP!``H```!A/`$`!@```&P\`0`$````
M<SP!``0```!X/`$`"@```'T\`0`3````B#P!``4```"</`$`!@```*(\`0`&
M````J3P!``@```"P/`$`!````+D\`0`,````OCP!``H```#+/`$`.0```-8\
M`0`N````$#T!`"D````_/0$`!0```&D]`0`8````;ST!`!D```"(/0$`'P``
M`*(]`0`=````PCT!`!$```#@/0$``@```/(]`0`$````]3T!``H```#Z/0$`
M!@````4^`0`%````##X!``,````2/@$`#````!8^`0!%````(SX!`#(```!I
M/@$`&@```)P^`0`T````MSX!`"@```#L/@$`4P```!4_`0`9````:3\!`'(`
M``"#/P$`(````/8_`0`U````%T`!`"$```!-0`$`10```&]``0`P````M4`!
M`"@```#F0`$`*0````]!`0`F````.4$!`"4```!@00$`*````(9!`0`H````
MKT$!`"(```#800$`*P```/M!`0`P````)T(!`!(```!80@$`$P```&M"`0`0
M````?T(!`'D```"00@$`"0````I#`0"A````%$,!`',```"V0P$`?````"I$
M`0`K````IT0!`%0```#31`$`%P```"A%`0`G````0$4!`!8```!H10$`#P``
M`']%`0`7````CT4!`!\```"G10$`0````,=%`0`?````"$8!`!P````H1@$`
M40```$5&`0`:````ET8!`!0```"R1@$`"@```,=&`0`%````TD8!``8```#8
M1@$`"````-]&`0`%````Z$8!`!(```#N1@$`$`````%'`0`3````$D<!`!T`
M```F1P$`#P```$1'`0`/````5$<!``0```!D1P$`"0```&E'`0`+````<T<!
M``<```!_1P$`!0```(='`0`4````C4<!``<```"B1P$`"````*I'`0`/````
MLT<!``@```##1P$`#````,Q'`0`/````V4<!``8```#I1P$`%````/!'`0`&
M````!4@!``P````,2`$`$0```!E(`0`(````*T@!``0````T2`$`&0```#E(
M`0`1````4T@!``H```!E2`$`&````'!(`0`3````B4@!`!P```"=2`$`$0``
M`+I(`0`/````S$@!``<```#<2`$`!````.1(`0`9````Z4@!``<````#20$`
M`@````M)`0`"````#DD!`!$````120$`"0```"-)`0`&````+4D!`!(````T
M20$`%P```$=)`0`&````7TD!`"<```!F20$``@```(Y)`0`$````D4D!``\`
M``"620$`$P```*9)`0`'````NDD!``<```#"20$`$0```,I)`0`&````W$D!
M`!@```#C20$`!@```/Q)`0`3`````TH!`!`````72@$`$@```"A*`0`"````
M.TH!``8````^2@$`#````$5*`0`)````4DH!`!$```!<2@$`(@```&Y*`0`'
M````D4H!``<```"92@$`"P```*%*`0`%````K4H!``(```"S2@$`"P```+9*
M`0!)`0``PDH!`!`````,3`$`%P```!U,`0`+````-4P!``8```!!3`$`"0``
M`$A,`0`(````4DP!``H```!;3`$`%````&9,`0`9````>TP!`"T```"53`$`
M)0```,-,`0`E````Z4P!`",````/30$`'P```#--`0`M````4TT!``H```"!
M30$`*@```(Q-`0`3````MTT!``T```#+30$`"P```-E-`0`%````Y4T!`"T`
M``#K30$`#0```!E.`0`=````)TX!`!4```!%3@$`#P```%M.`0`1````:TX!
M`'0```!]3@$`#@```/).`0`(`````4\!`!$````*3P$`#0```!Q/`0`6````
M*D\!`!<```!!3P$`%P```%E/`0`:````<4\!``8```",3P$`OP```)-/`0`+
M````4U`!`!(```!?4`$`'0```')0`0`0````D%`!`!(```"A4`$`$@```+10
M`0`(````QU`!``\```#04`$`,````.!0`0`9````$5$!`#8````K40$`/0``
M`&)1`0!0````H%$!`$\```#Q40$`6````$%2`0!6````FE(!`#@```#Q4@$`
M%````"I3`0`7````/U,!`!$```!74P$`%0```&E3`0`=````?U,!``@```"=
M4P$`!@```*93`0`/````K5,!``0```"]4P$`$````,)3`0`/````TU,!`#(`
M``#C4P$`,````!94`0`1````1U0!``X```!95`$`$0```&A4`0`)````>E0!
M``8```"$5`$`&0```(M4`0`7````I50!``<```"]5`$`#@```,54`0`1````
MU%0!`!X```#F5`$`'`````55`0`3````(E4!``T````V50$`#0```$15`0`*
M````4E4!`"8```!=50$`$P```(15`0`8````F%4!`!(```"Q50$`5````,15
M`0`W````&58!`"0```!15@$`!@```'96`0`'````?58!`#8```"%5@$`#0``
M`+Q6`0`'````RE8!``H```#25@$`"````-U6`0`(````YE8!``4```#O5@$`
M"````/56`0`+````_E8!``8````*5P$`(P```!%7`0`.````-5<!``P```!$
M5P$`$P```%%7`0`6````95<!`"L```!\5P$`"P```*A7`0`D````M%<!`!<`
M``#95P$`)````/%7`0`=````%E@!`!0````T6`$`$@```$E8`0`.````7%@!
M`!P```!K6`$`%@```(A8`0`'````GU@!``8```"G6`$`"````*Y8`0`.````
MMU@!``<```#&6`$`"@```,Y8`0`1````V5@!``D```#K6`$`$````/58`0`8
M````!ED!`"H````?60$`"````$I9`0`1````4UD!``4```!E60$`#P```&M9
M`0`,````>UD!`#$```"(60$`+P```+I9`0`)````ZED!``@```#T60$`!@``
M`/U9`0`%````!%H!`!`````*6@$`#````!M:`0`5````*%H!`#0````^6@$`
M*````'-:`0`G````G%H!`"0```#$6@$`,0```.E:`0`(````&UL!``8````D
M6P$`"0```"M;`0`'````-5L!`#<````]6P$`+P```'5;`0`V````I5L!`%X`
M``#<6P$`-0```#M<`0`U````<5P!`$H```"G7`$`2P```/)<`0`U````/ET!
M`$(```!T70$`,0```+==`0`T````Z5T!`$P````>7@$`-0```&M>`0`[````
MH5X!`"P```#=7@$`%@````I?`0`:````(5\!`"8````\7P$`*P```&-?`0`K
M````CU\!`!$```"[7P$`"P```,U?`0`,````V5\!``<```#F7P$`#0```.Y?
M`0`7````_%\!`"0````48`$`!@```#E@`0`'````0&`!``D```!(8`$`"```
M`%)@`0`H````6V`!``\```"$8`$`"@```)1@`0`(````GV`!``8```"H8`$`
M!0```*]@`0`'````M6`!``4```"]8`$`"@```,-@`0`G````SF`!`!````#V
M8`$`"0````=A`0`%````$6$!``<````780$`!P```!]A`0`%````)V$!``T`
M```M80$`!@```#MA`0`3````0F$!``,```!680$`"````%IA`0`&````8V$!
M``T```!J80$`"````'AA`0`@````@6$!`!$```"B80$`"0```+1A`0`2````
MOF$!``P```#180$`!P```-YA`0`#````YF$!``,```#J80$`%````.YA`0`4
M`````V(!`#(````88@$`"````$MB`0`)````5&(!``@```!>8@$`!P```&=B
M`0!+````;V(!`"0```"[8@$`+0```.!B`0`H````#F,!`"$````W8P$`!@``
M`%EC`0`&````8&,!`!@```!G8P$`(0```(!C`0`D````HF,!`"X```#'8P$`
M)0```/9C`0`M````'&0!`&````!*9`$`+@```*MD`0`2````VF0!``<```#M
M9`$`$P```/5D`0`1````"64!``\````;90$`$````"ME`0`0````/&4!`!``
M``!-90$`$````%YE`0`/````;V4!``D```!_90$`%P```(EE`0`A````H64!
M`!0```##90$`&````-AE`0`#````\64!``8```#U90$`$0```/QE`0!5````
M#F8!`%P```!D9@$`!````,%F`0`6````QF8!``4```#=9@$`!````.-F`0`2
M````Z&8!``\```#[9@$`'`````MG`0`D````*&<!`#````!-9P$`#P```'YG
M`0`C````CF<!``4```"R9P$`&@```+AG`0`-````TV<!`!D```#A9P$`%0``
M`/MG`0`;````$6@!`!$````M:`$`&0```#]H`0`3````66@!``T```!M:`$`
M!@```'MH`0`,````@F@!``<```"/:`$`%P```)=H`0`2````KV@!``X```#"
M:`$`"````-%H`0`%````VF@!``L```#@:`$`"P```.QH`0`'````^&@!``\`
M````:0$`!@```!!I`0`&````%VD!`!4````>:0$`"````#1I`0`*````/6D!
M``8```!(:0$`"@```$]I`0`(````6FD!``0```!C:0$`!````&AI`0`7````
M;6D!`$P```"%:0$`)````-)I`0`/````]VD!``X````':@$`!0```!9J`0`<
M````'&H!`!$````Y:@$`$@```$MJ`0`N````7FH!`#T```"-:@$`(````,MJ
M`0`(````[&H!`#````#U:@$`&@```"9K`0`*````06L!``H```!,:P$`#P``
M`%=K`0`&````9VL!``D```!N:P$`%P```'AK`0`/````D&L!``D```"@:P$`
M$@```*IK`0`M````O6L!`"L```#K:P$`+P```!=L`0`M````1VP!`"$```!U
M;`$`)@```)=L`0`E````OFP!`"D```#D;`$`*0````YM`0`U````.&T!`"L`
M``!N;0$`)````)IM`0`F````OVT!`"$```#F;0$`*@````AN`0`Z````,VX!
M`"X```!N;@$`)````)UN`0`P````PFX!`#D```#S;@$`)0```"UO`0`A````
M4V\!`#0```!U;P$`)0```*IO`0`9````T&\!`"\```#J;P$`(P```!IP`0`F
M````/G`!`!H```!E<`$`L0```(!P`0`2````,G$!`"````!%<0$`*0```&9Q
M`0`I````D'$!`#$```"Z<0$`(@```.QQ`0`A````#W(!`"4````Q<@$`*0``
M`%=R`0`L````@7(!`#H```"N<@$`+````.ER`0"3````%G,!`"4```"J<P$`
M&P```-!S`0`F````[',!`"\````3=`$`+P```$-T`0!&````<W0!`$0```"Z
M=`$`#0```/]T`0`'````#74!``4````5=0$`"````!MU`0`.````)'4!``T`
M```S=0$`%0```$%U`0`,````5W4!`!4```!D=0$`"@```'IU`0`$````A74!
M``\```"*=0$`$````)IU`0`,````JW4!``\```"X=0$`%0```,AU`0`0````
MWG4!`!0```#O=0$`#0````1V`0!"````$G8!``H```!5=@$`$````&!V`0`&
M````<78!``\```!X=@$``@```(AV`0!+````BW8!``4```#7=@$`(P```-UV
M`0`7`````7<!``4````9=P$`#@```!]W`0`,````+G<!``,````[=P$`$0``
M`#]W`0`(````47<!`!````!:=P$`$0```&MW`0`-````?7<!`!,```"+=P$`
M&P```)]W`0`C````NW<!``D```#?=P$`!P```.EW`0`-````\7<!``\```#_
M=P$`#@````]X`0`-````'G@!`!H````L>`$`#0```$=X`0`.````57@!`"<`
M``!D>`$`%@```(QX`0`K````HW@!``X```#/>`$`&````-YX`0`7````]W@!
M`!<````/>0$`,0```"=Y`0`-````67D!``8```!G>0$`#P```&YY`0`%````
M?GD!`"L```"$>0$`+````+!Y`0`%````W7D!``D```#C>0$`'@```.UY`0`+
M````#'H!`!(````8>@$`$@```"MZ`0`'````/GH!`"8```!&>@$`%0```&UZ
M`0`;````@WH!`!@```"?>@$`$0```+AZ`0`5````RGH!``D```#@>@$`"0``
M`.IZ`0`C````]'H!`#T````8>P$`"````%9[`0`6````7WL!`!X```!V>P$`
M"````)5[`0`+````GGL!`#(```"J>P$`$````-U[`0`%````[GL!``8```#T
M>P$``P```/M[`0`'````_WL!``<````'?`$`#`````]\`0`/````''P!``T`
M```L?`$`#0```#I\`0`4````2'P!`!<```!=?`$`%@```'5\`0`4````C'P!
M``L```"A?`$`!0```*U\`0`(````LWP!``H```"\?`$``@```,=\`0`%````
MRGP!`!````#0?`$`(P```.%\`0`3````!7T!`!(````9?0$`"0```"Q]`0`/
M````-GT!`!$```!&?0$`&@```%A]`0`M````<WT!`"L```"A?0$`"P```,U]
M`0`.````V7T!`'8```#H?0$`$P```%]^`0`?````<WX!`!````"3?@$`!P``
M`*1^`0`%````K'X!`!T```"R?@$`,0```-!^`0`O`````G\!`!X````R?P$`
M(````%%_`0`:````<G\!`!H```"-?P$`"````*A_`0`'````L7\!``<```"Y
M?P$`!@```,%_`0`0````R'\!``X```#9?P$`$0```.A_`0`/````^G\!`!4`
M```*@`$`#P```""``0`,````,(`!``H````]@`$`!P```$B``0`(````4(`!
M`!0```!9@`$`#@```&Z``0`W````?8`!``\```"U@`$`"````,6``0`+````
MSH`!`!H```#:@`$`(````/6``0`J````%H$!`"D```!!@0$`'P```&N!`0`@
M````BX$!`"H```"L@0$`'P```->!`0`8````]X$!``4````0@@$`'0```!:"
M`0`/````-((!``X```!$@@$``P```%."`0`$````5X(!``<```!<@@$`#0``
M`&2"`0`/````<H(!``L```""@@$`%0```(Z"`0`+````I((!``4```"P@@$`
M!0```+:"`0`7````O((!`!D```#4@@$`#P```.Z"`0`+````_H(!``P````*
M@P$`#P```!>#`0`F````)X,!``8```!.@P$`!@```%6#`0`-````7(,!``H`
M``!J@P$`"P```'6#`0`&````@8,!``X```"(@P$`!````)>#`0`7````G(,!
M``L```"T@P$`!P```,"#`0`J````R(,!``\```#S@P$`@P````.$`0`2````
MAX0!``D```":A`$`!P```*2$`0`+````K(0!``<```"XA`$`"0```,"$`0`$
M````RH0!``T```#/A`$``P```-V$`0`%````X80!``H```#GA`$`$P```/*$
M`0`2````!H4!`!0````9A0$`&@```"Z%`0`"````284!``D```!,A0$`"P``
M`%:%`0`$````8H4!``H```!GA0$`!0```'*%`0`F````>(4!``@```"?A0$`
M!@```*B%`0`G````KX4!``X```#7A0$`!P```.:%`0`'````[H4!``4```#V
MA0$`"0```/R%`0`+````!H8!``<````2A@$`!@```!J&`0`+````(88!`!``
M```MA@$`#0```#Z&`0`&````3(8!``<```!3A@$`!P```%N&`0`4````8X8!
M`!T```!XA@$`/P```):&`0`L````UH8!`#$````#AP$`!P```#6'`0`*````
M/8<!``0```!(AP$`"0```$V'`0`(````5X<!`!T```!@AP$`"0```'Z'`0`&
M````B(<!``T```"/AP$`!@```)V'`0`$````I(<!`#(```"IAP$`-````-R'
M`0`T````$8@!`",```!&B`$`!0```&J(`0`=````<(@!``0```".B`$`"```
M`).(`0`(````G(@!`"0```"EB`$`"P```,J(`0`%````UH@!``@```#<B`$`
M'P```.6(`0`(````!8D!``@````.B0$`%@```!>)`0`&````+HD!``8````U
MB0$`!P```#R)`0`%````1(D!``T```!*B0$`$````%B)`0`-````:8D!``@`
M``!WB0$`"0```(")`0`%````BHD!`#L```"0B0$`.````,R)`0`\````!8H!
M`"<```!"B@$`.````&J*`0!`````HXH!`#````#DB@$`.@```!6+`0`U````
M4(L!`#X```"&BP$`*0```,6+`0`2````[XL!`!8````"C`$`#0```!F,`0`J
M````)XP!`!P```!2C`$`'0```&^,`0`<````C8P!``<```"JC`$`"0```+*,
M`0`)````O(P!``@```#&C`$`*````,^,`0`G````^(P!`"4````@C0$`"0``
M`$:-`0`:````4(T!`"\```!KC0$`)@```)N-`0`1````PHT!``8```#4C0$`
M"0```-N-`0`,````Y8T!``P```#RC0$`#P```/^-`0`V````#XX!`((```!&
MC@$`=@```,F.`0`/````0(\!``L```!0CP$`#````%R/`0`1````:8\!`!(`
M``![CP$`$````(Z/`0`'````GX\!``\```"GCP$`%````+>/`0`2````S(\!
M``\```#?CP$`'P```.^/`0`J````#Y`!`(8````ZD`$`$0```,&0`0`%````
MTY`!`!<```#9D`$`"0```/&0`0`$````^Y`!``H`````D0$`'@````N1`0`1
M````*I$!``X````\D0$`#@```$N1`0`,````6I$!`!,```!GD0$`'@```'N1
M`0`@````FI$!`!X```"[D0$`(````-J1`0`?````^Y$!`"$````;D@$`&P``
M`#V2`0`X````69(!``\```"2D@$`$0```**2`0`0````M)(!`!(```#%D@$`
M#0```-B2`0`2````YI(!`!0```#YD@$`$`````Z3`0`2````'Y,!`#(````R
MDP$`%@```&63`0`4````?),!`#T```"1DP$`%````,^3`0`*````Y),!`!,`
M``#ODP$`00````.4`0`;````190!`!,```!AE`$`$@```'64`0`=````B)0!
M`!@```"FE`$`%@```+^4`0`7````UI0!`!X```#NE`$`&@````V5`0`H````
M*)4!`",```!1E0$`&@```'65`0`5````D)4!`!8```"FE0$`$0```+V5`0`7
M````SY4!`!D```#GE0$`&0````&6`0`7````&Y8!``@````SE@$`$````#R6
M`0`$````398!``0```!2E@$`!0```%>6`0`+````798!``\```!IE@$`!@``
M`'F6`0`)````@)8!``<```"*E@$`"0```)*6`0`'````G)8!``8```"DE@$`
M"````*N6`0`&````M)8!``8```"[E@$``P```,*6`0`#````QI8!``@```#*
ME@$`$@```-.6`0`1````YI8!``X```#XE@$`#P````>7`0`*````%Y<!`!(`
M```BEP$`!````#67`0`H````.I<!`!(```!CEP$`$````':7`0`8````AY<!
M``L```"@EP$`"0```*R7`0`.````MI<!`"T```#%EP$`!````/.7`0`(````
M^)<!`"(````!F`$`$@```"28`0`&````-Y@!``D````^F`$`!P```$B8`0`%
M````4)@!``0```!6F`$`$0```%N8`0`4````;9@!``X```""F`$`%@```)&8
M`0`8````J)@!`!T```#!F`$`&P```-^8`0`(````^Y@!``4````$F0$`!@``
M``J9`0`A````$9D!``<````SF0$`!0```#N9`0`.````09D!``T```!0F0$`
M!P```%Z9`0`&````9ID!``<```!MF0$`!0```'69`0`/````>YD!``\```"+
MF0$`"@```)N9`0`/````IID!`!$```"VF0$`%@```,B9`0`4````WYD!``X`
M``#TF0$`%@````.:`0`(````&IH!``4````CF@$`$0```"F:`0`V````.YH!
M``4```!RF@$`#````'B:`0`C````A9H!`!8```"IF@$`%````,":`0`7````
MU9H!``P```#MF@$`"0```/J:`0`'````!)L!``H````,FP$`"0```!>;`0`.
M````(9L!`!`````PFP$`'0```$&;`0`C````7YL!`"X```"#FP$`"@```+*;
M`0`%````O9L!``X```##FP$`#0```-*;`0`1````X)L!``@```#RFP$`"P``
M`/N;`0`F````!YP!``@````NG`$`"P```#><`0`4````0YP!`%$```!8G`$`
M%````*J<`0`)````OYP!``4```#)G`$`!0```,^<`0`3````U9P!`!4```#I
MG`$`$P```/^<`0`+````$YT!``(````?G0$`"@```"*=`0`J````+9T!``,`
M``!8G0$`!0```%R=`0`*````8IT!``H```!MG0$`!0```'B=`0`%````?IT!
M`!X```"$G0$`$@```*.=`0`&````MIT!``@```"]G0$`"````,:=`0`$````
MSYT!``4```#4G0$`80```-J=`0`*````/)X!``T```!'G@$`$@```%6>`0`%
M````:)X!``4```!NG@$`)P```'2>`0`T````G)X!`!,```#1G@$`"````.6>
M`0`,````[IX!``H```#[G@$`"0````:?`0`:````$)\!`"P````KGP$`*@``
M`%B?`0`I````@Y\!`!X```"MGP$`#P```,R?`0`#````W)\!``<```#@GP$`
M"````.B?`0`(````\9\!`!````#ZGP$`#`````N@`0`&````&*`!`$D````?
MH`$`&0```&F@`0`*````@Z`!``T```".H`$`'````)R@`0!-````N:`!`"``
M```'H0$`!@```"BA`0`=````+Z$!`"@```!-H0$`"````':A`0`&````?Z$!
M`!T```"&H0$`!0```*2A`0`(````JJ$!`"H```"SH0$`*0```-ZA`0`N````
M"*(!`!$````WH@$`!0```$FB`0`>````3Z(!`%T```!NH@$`$````,RB`0`A
M````W:(!`!$```#_H@$``P```!&C`0`,````%:,!``8````BHP$`%0```"FC
M`0`+````/Z,!``<```!+HP$`"0```%.C`0`&````7:,!``D```!DHP$`#```
M`&ZC`0`'````>Z,!``H```"#HP$`#````(ZC`0`Y````FZ,!``8```#5HP$`
M#@```-RC`0`0````ZZ,!`!````#\HP$`#0````VD`0`.````&Z0!``\````J
MI`$`#0```#JD`0`-````2*0!``T```!6I`$`"````&2D`0`>````;:0!`!$`
M``",I`$`"@```)ZD`0`7````J:0!``H```#!I`$`%````,RD`0`'````X:0!
M`!````#II`$`!````/JD`0`'````_Z0!``4````'I0$`!0````VE`0`)````
M$Z4!`!`````=I0$`%0```"ZE`0`M````1*4!`!P```!RI0$`,0```(^E`0`J
M````P:4!`!D```#LI0$`'0````:F`0`8````)*8!``0````]I@$`!0```$*F
M`0`.````2*8!``X```!7I@$`$@```&:F`0`#````>:8!`",```!]I@$`"P``
M`*&F`0`*````K:8!`"````"XI@$`&@```-FF`0`2````]*8!``0````'IP$`
M$`````RG`0`%````':<!`!(````CIP$`$0```#:G`0`,````2*<!``D```!5
MIP$`!0```%^G`0`'````9:<!``,```!MIP$`!````'&G`0`#````=J<!`%(`
M``!ZIP$`0````,VG`0`=````#J@!`"X````LJ`$`-0```%NH`0`-````D:@!
M`#8```"?J`$`(@```-:H`0`G````^:@!`"<````AJ0$`+````$FI`0`.````
M=JD!`"0```"%J0$`%````*JI`0`<````OZD!`!H```#<J0$`%P```/>I`0`<
M````#ZH!`"$````LJ@$`&P```$ZJ`0`7````:JH!`"P```""J@$`+````*^J
M`0`P````W*H!`"T````-JP$`+@```#NK`0`K````:JL!`%X```"6JP$`(```
M`/6K`0`7````%JP!``@````NK`$`'@```#>L`0`)````5JP!``\```!@K`$`
M0````'"L`0`Q````L:P!`!\```#CK`$`#@````.M`0!5````$JT!`$P```!H
MK0$`!@```+6M`0`B````O*T!``X```#?K0$`$````.ZM`0`9````_ZT!``8`
M```9K@$`"@```""N`0`,````*ZX!``X````XK@$`%@```$>N`0`+````7JX!
M`!,```!JK@$`"````'ZN`0`B````AZX!``@```"JK@$`!0```+.N`0`,````
MN:X!``T```#&K@$`#0```-2N`0`^````XJX!``(````AKP$`!@```"2O`0`-
M````*Z\!``D````YKP$`!P```$.O`0`1````2Z\!``H```!=KP$`)0```&BO
M`0`+````CJ\!`"(```":KP$`!````+VO`0`N````PJ\!`!0```#QKP$`*```
M``:P`0!J````+[`!`!0```":L`$`1````*^P`0`?````]+`!``\````4L0$`
M"@```"2Q`0`-````+[$!``\````]L0$`"P```$VQ`0`4````6;$!``T```!N
ML0$`&0```'RQ`0`5````EK$!``,```"LL0$`$0```+"Q`0`/````PK$!`",`
M``#2L0$`$0```/:Q`0`4````"+(!`!T````=L@$`$````#NR`0`G````3+(!
M``<```!TL@$`"0```'RR`0`4````AK(!`!(```";L@$`$@```*ZR`0`:````
MP;(!`!(```#<L@$`#P```.^R`0`6````_[(!``H````6LP$`"0```"&S`0`(
M````*[,!`!`````TLP$`$@```$6S`0`&````6+,!`!$```!?LP$`"````'&S
M`0`1````>K,!``4```",LP$`&P```)*S`0`/````KK,!`"X```"^LP$`$@``
M`.VS`0`&`````+0!``<````'M`$`&`````^T`0`&````*+0!`!(````OM`$`
M!0```$*T`0`9````2+0!``4```!BM`$`!P```&BT`0`7````<+0!`"<```"(
MM`$`!0```+"T`0`;````MK0!`!(```#2M`$`!0```.6T`0`2````Z[0!`!$`
M``#^M`$`!````!"U`0`/````%;4!``@````EM0$`!P```"ZU`0`*````-K4!
M``@```!!M0$`!0```$JU`0`@````4+4!`#,```!QM0$`/````*6U`0`<````
MXK4!`"<```#_M0$`(````">V`0`^````2+8!`!H```"'M@$`(````**V`0`O
M````P[8!`%@```#SM@$`)P```$RW`0`&````=+<!``@```![MP$`!@```(2W
M`0`+````B[<!`!D```"7MP$`&0```+&W`0`L````R[<!`!\```#XMP$`&P``
M`!BX`0`V````-+@!`#P```!KN`$`!````*BX`0`5````K;@!``8```##N`$`
M!@```,JX`0`D````T;@!`!D```#VN`$`$0```!"Y`0`-````(KD!``<````P
MN0$`#@```#BY`0`(````1[D!`!8```!0N0$`#````&>Y`0`:````=+D!`!L`
M``"/N0$`.````*NY`0`)````Y+D!``4```#NN0$`!0```/2Y`0`%````^KD!
M`!L`````N@$`$@```!RZ`0`$````+[H!``D````TN@$`"P```#ZZ`0`0````
M2KH!``X```!;N@$`'0```&JZ`0`/````B+H!``4```"8N@$`!0```)ZZ`0`,
M````I+H!`#4```"QN@$`60```.>Z`0`>````0;L!``<```!@NP$`(@```&B[
M`0`;````B[L!``\```"GNP$`$@```+>[`0`-````RKL!``@```#8NP$`$0``
M`.&[`0`M````\[L!``D````AO`$`#@```"N\`0`0````.KP!`!8```!+O`$`
M#0```&*\`0`Z````<+P!``D```"KO`$`'P```+6\`0`5````U;P!`!D```#K
MO`$`.P````6]`0`F````0;T!`#X```!HO0$`/P```*>]`0`[````Y[T!``P`
M```CO@$`$````#"^`0`-````0;X!`!(```!/O@$`%@```&*^`0`(````>;X!
M`!0```""O@$`$@```)>^`0`'````JKX!`!,```"RO@$`*````,:^`0`'````
M[[X!``8```#WO@$`#P```/Z^`0`.````#K\!`!4````=OP$`!````#._`0`(
M````.+\!``P```!!OP$`#````$Z_`0`-````6[\!`!$```!IOP$`$0```'N_
M`0`'````C;\!``4```"5OP$`-````)N_`0`D````T+\!`"0```#UOP$`!P``
M`!K``0`/````(L`!``8````RP`$`'````#G``0`A````5L`!`"0```!XP`$`
M#@```)W``0`)````K,`!`!X```"VP`$``P```-7``0`&````V<`!``H```#@
MP`$``@```.O``0`,````[L`!`!,```#[P`$`"P````_!`0`5````&\$!`!D`
M```QP0$`%@```$O!`0`%````8L$!``H```!HP0$`$P```'/!`0`6````A\$!
M``X```">P0$`!@```*W!`0`+````M,$!``D```#`P0$`$0```,K!`0!5````
MW,$!`!T````RP@$`,0```%#"`0`/````@L(!``0```"2P@$`!@```)?"`0`+
M````GL(!``X```"JP@$`#0```+G"`0`;````Q\(!`!@```#CP@$`#@```/S"
M`0`?````"\,!``X````KPP$`(````#K#`0`.````6\,!``P```!JPP$`:@``
M`'?#`0`D````XL,!`!8````'Q`$`)@```![$`0`B````1<0!`!0```!HQ`$`
M&0```'W$`0`9````E\0!``X```"QQ`$`&````,#$`0`*````V<0!``<```#D
MQ`$`"````.S$`0`)````]<0!`!0```#_Q`$`#0```!3%`0`T````(L4!`!0`
M``!7Q0$`'0```&S%`0`'````BL4!``X```"2Q0$`.P```*'%`0!.````W<4!
M`"\````LQ@$`>````%S&`0`*````U<8!`"@```#@Q@$`-P````G'`0`(````
M0<<!``@```!*QP$`#````%/'`0`V````8,<!``@```"7QP$`20```*#'`0`Y
M````ZL<!`"@````DR`$`(````$W(`0`G````;L@!`"$```"6R`$`+````+C(
M`0`F````Y<@!`"T````,R0$`)@```#K)`0`0````8<D!``@```!RR0$`#0``
M`'O)`0`/````B<D!``X```"9R0$`!P```*C)`0`T````L,D!``P```#ER0$`
M$````/+)`0`&`````\H!`!(````*R@$`"````!W*`0`'````)LH!`!`````N
MR@$`"0```#_*`0`)````2<H!``@```!3R@$`$````%S*`0`0````;<H!`!4`
M``!^R@$`%P```)3*`0`-````K,H!`"(```"ZR@$`$@```-W*`0`(````\,H!
M``X```#YR@$`%0````C+`0`/````'LL!``P````NRP$`)@```#O+`0`.````
M8LL!`!\```!QRP$`)0```)'+`0`)````M\L!``8```#!RP$`$@```,C+`0`*
M````V\L!``0```#FRP$`&P```.O+`0`.````!\P!``\````6S`$`#P```";,
M`0`&````-LP!``D````]S`$`"@```$?,`0`)````4LP!``X```!<S`$`%```
M`&O,`0`$````@,P!``\```"%S`$`"````)7,`0`+````GLP!``\```"JS`$`
M&0```+K,`0`*````U,P!``(```#?S`$`(````.+,`0`'`````\T!``<````+
MS0$`<@```!/-`0`+````ALT!``8```"2S0$`)@```)G-`0`^````P,T!`!P`
M``#_S0$`)P```!S.`0!1````1,X!`"$```"6S@$`,@```+C.`0`?````Z\X!
M`!0````+SP$`!0```"#/`0`%````)L\!``P````LSP$`"P```#G/`0`'````
M1<\!``P```!-SP$`$@```%K/`0`.````;<\!``L```!\SP$`#0```(C/`0`+
M````EL\!``<```"BSP$`!P```*K/`0`*````LL\!`!0```"]SP$`"0```-+/
M`0`'````W,\!``L```#DSP$`(0```/#/`0`&````$M`!`"@````9T`$`!0``
M`$+0`0`%````2-`!``\```!.T`$`!0```%[0`0`*````9-`!``D```!OT`$`
M!P```'G0`0`2````@=`!`!(```"4T`$`!@```*?0`0`6````KM`!``L```#%
MT`$`"````-'0`0`%````VM`!``4```#@T`$`#P```.;0`0`<````]M`!``<`
M```3T0$`"0```!O1`0`F````)=$!`!P```!,T0$`#0```&G1`0`$````=]$!
M``@```!\T0$`$````(71`0`)````EM$!``(```"@T0$`!P```*/1`0`?````
MJ]$!`"<```#+T0$`(0```//1`0`J````%=(!`"D```!`T@$`6@```&K2`0`1
M````Q=(!`%\```#7T@$`+@```#?3`0!)````9M,!`&P```"PTP$`'@```!W4
M`0`P````/-0!`"@```!MU`$`,0```);4`0`K````R-0!`!\```#TU`$`.@``
M`!35`0#+`0``3]4!`!P````;UP$`#P```#C7`0`_````2-<!`'P```"(UP$`
M0P````78`0`:````2=@!`#(```!DV`$`7@```)?8`0!(````]M@!`"$````_
MV0$`%P```&'9`0`0````>=D!`!X```"*V0$`&0```*G9`0`8````P]D!`"<`
M``#<V0$`(`````3:`0`>````)=H!`#$```!$V@$`&0```';:`0`0````D-H!
M`#0```"AV@$`(P```-;:`0`A````^MH!`"$````<VP$`(@```#[;`0`Y````
M8=L!`%0```";VP$`+P```/#;`0!'````(-P!`#````!HW`$`)P```)G<`0!!
M````P=P!`%X````#W0$`10```&+=`0`P````J-T!`"P```#9W0$`*P````;>
M`0!6````,MX!`$\```")W@$`2@```-G>`0!)````)-\!`#,```!NWP$`+```
M`*+?`0`L````S]\!`"T```#\WP$`90```"K@`0!:````D.`!`&,```#KX`$`
MG0```$_A`0`5````[>$!`",````#X@$`+P```"?B`0`O````5^(!`$$```"'
MX@$`(````,GB`0!4````ZN(!`"$````_XP$`"P```&'C`0"U````;>,!`$@`
M```CY`$`'P```&SD`0`V````C.0!`"(```##Y`$`'@```.;D`0`L````!>4!
M``<````RY0$`!P```#KE`0`#````0N4!``T```!&Y0$`"P```%3E`0`*````
M8.4!``L```!KY0$`!P```'?E`0`9````?^4!``,```"9Y0$`6P```)WE`0`$
M````^>4!`"<```#^Y0$`!````";F`0`'````*^8!``8````SY@$`!0```#KF
M`0`$````0.8!`!,```!%Y@$`"````%GF`0`1````8N8!`!4```!TY@$``@``
M`(KF`0`'````C>8!``<```"5Y@$`#````)WF`0`.````JN8!``8```"YY@$`
M%````,#F`0`,````U>8!``,```#BY@$`)P```.;F`0`$````#N<!``8````3
MYP$`"````!KG`0`P````(^<!`$<```!4YP$`+@```)SG`0`O````R^<!`!L`
M``#[YP$`+P```!?H`0`R````1^@!`"0```!ZZ`$`(0```)_H`0`C````P>@!
M`"@```#EZ`$`(P````[I`0`A````,ND!`"H```!4Z0$`*0```'_I`0`B````
MJ>D!`#,```#,Z0$`'P````#J`0`P````(.H!`"T```!1Z@$`(@```'_J`0`F
M````HNH!`"4```#)Z@$`(````._J`0`I````$.L!`"D````ZZP$`)0```&3K
M`0`O````BNL!`!P```"ZZP$`(0```-?K`0`E````^>L!`"D````?[`$`(```
M`$GL`0`J````:NP!`#X```"5[`$`00```-3L`0`=````%NT!`"0````T[0$`
M0````%GM`0`E````FNT!`"D```#`[0$`*````.KM`0`I````$^X!`",````]
M[@$`(````&'N`0`J````@NX!`"4```"M[@$`.0```-/N`0`G````#>\!`#4`
M```U[P$`#````&OO`0`,````>.\!`!0```"%[P$`+P```)KO`0`C````RN\!
M``L```#N[P$`%P```/KO`0`.````$O`!`!8````A\`$`"````#CP`0`'````
M0?`!`"(```!)\`$`)0```&SP`0`>````DO`!`"<```"Q\`$`)0```-GP`0`,
M````__`!`.L````,\0$`#P```/CQ`0`8````"/(!``P````A\@$`#P```"[R
M`0`8````/O(!`!\```!7\@$`'P```'?R`0`&````E_(!`#4```">\@$`%@``
M`-3R`0`4````Z_(!``<`````\P$`$P````CS`0`*````'/,!`#P````G\P$`
M"@```&3S`0`H````;_,!`!,```"8\P$`&````*SS`0`7````Q?,!`#@```#=
M\P$`(````!;T`0`2````-_0!`"0```!*]`$`$P```&_T`0`4````@_0!`!4`
M``"8]`$`"@```*[T`0`7````N?0!``D```#1]`$`'0```-OT`0`(````^?0!
M`!P````"]0$`)@```!_U`0`'````1O4!`",```!.]0$`!P```'+U`0`(````
M>O4!``D```"#]0$`-````(WU`0`&````PO4!`!````#)]0$`%0```-KU`0`4
M````\/4!``L````%]@$`#````!'V`0`'````'O8!``L````F]@$`'````#+V
M`0`/````3_8!`!@```!?]@$`&0```'CV`0`+````DO8!``T```">]@$`%P``
M`*SV`0`)````Q/8!`"L```#.]@$`#````/KV`0`/````!_<!``D````7]P$`
M`@```"'W`0`1````)/<!`!@````V]P$`"P```$_W`0`#````6_<!``L```!?
M]P$`"````&OW`0`'````=/<!``L```!\]P$`"P```(CW`0`.````E/<!`"T`
M``"C]P$`&@```-'W`0`:````[/<!`"$````'^`$`"@```"GX`0`Z````-/@!
M``4```!O^`$`%@```'7X`0`W````C/@!``T```#$^`$`#@```-+X`0`&````
MX?@!``0```#H^`$`!@```.WX`0`+````]/@!`!<`````^0$`!P```!CY`0`(
M````(/D!``<````I^0$`"````#'Y`0`%````.OD!``\```!`^0$`$````%#Y
M`0`^````8?D!`#$```"@^0$`)````-+Y`0`%````]_D!`!H```#]^0$`(0``
M`!CZ`0`A````.OH!`",```!<^@$`$0```(#Z`0`"````DOH!``0```"5^@$`
M"@```)KZ`0`%````I?H!``4```"K^@$``P```+'Z`0`)````M?H!`$P```"_
M^@$`)0````S[`0`8````,OL!`"T```!+^P$`)0```'G[`0!?````G_L!`!,`
M``#_^P$`>0```!/\`0`<````C?P!`%,```"J_`$`(@```/[\`0`_````(?T!
M`#0```!A_0$`+````);]`0`V````P_T!`#8```#Z_0$`-0```#'^`0`S````
M9_X!`"@```";_@$`(@```,3^`0`F````Y_X!`$P````._P$`%````%O_`0`T
M````</\!``\```"E_P$`;P```+7_`0`)````)0`"`*(````O``(`>P```-(`
M`@!P````3@$"`"@```"_`0(`5````.@!`@`:````/0("`"D```!8`@(`%P``
M`(("`@`*````F@("`!T```"E`@(`'0```,,"`@`T````X0("`",````6`P(`
M&````#H#`@!4````4P,"`!X```"H`P(`%P```,<#`@`*````WP,"``0```#J
M`P(`!@```.\#`@`(````]@,"``4```#_`P(`%0````4$`@`3````&P0"`!D`
M```O!`(`)0```$D$`@`0````;P0"``X```"`!`(`!````(\$`@`)````E`0"
M``\```">!`(`"````*X$`@`)````MP0"`!8```#!!`(`#0```-@$`@`,````
MY@0"`!$```#S!`(`"P````4%`@`&````$04"`!,````8!0(`"P```"P%`@`6
M````.`4"``T```!/!0(`!P```%T%`@`/````904"``@```!U!0(`"0```'X%
M`@`E````B`4"`!L```"N!0(`#````,H%`@`D````UP4"`!(```#\!0(`'@``
M``\&`@`4````+@8"`!$```!#!@(`!0```%4&`@`%````6P8"`"$```!A!@(`
M"````(,&`@`"````C`8"``(```"/!@(`%@```)(&`@`(````J08"``@```"R
M!@(`%````+L&`@`6````T`8"``@```#G!@(`+0```/`&`@`"````'@<"``0`
M```A!P(`$````"8'`@`7````-P<"``\```!/!P(`!P```%\'`@`2````9P<"
M``4```!Z!P(`&P```(`'`@`%````G`<"`!8```"B!P(`$0```+D'`@`2````
MRP<"``(```#>!P(`"````.$'`@`/````Z@<"``L```#Z!P(`#0````8(`@`D
M````%`@"``L````Y"`(`#````$4(`@`3````4@@"``4```!F"`(``@```&P(
M`@`+````;P@"``$```!_!```FP(```````!&`P``:0(``"\$```?!@``````
M`%,!``!3``````0```,!````````?`$``-@$``!]!```00<``$D%```V`P``
M)0,```X#``!W`P``,P0``*<!`````````````"T```````````````````#/
M!````````+L```#-`0``!04``-4#```-`@``````````````````W08``'D!
M``"M!@``N@$```````#J`0``I`0``%("```L`0``O@4``%\%````````-04`
M`-$%``!]`0``7`0``",'````````]0$``&D%```6`P``M@,````````9!0``
MYP$``"X&``!J`@``C04```````!A`@``N04``(```````````````+\"```[
M`@``JP4``'0"```U`P``'04``)P!``"_!0``V0$``#X%``"Q`@``D04`````
M``#G!0``+`````````!C`P``%0```)L!``!Z`P``TP$``$T!``!,!@``XP``
M`.T#``!F`0``QP(``,@"```Z!P``&0,`````````````1P4``$4&``"&`0``
M"P0``(T$````````"P```!<!```>`@```````'8&````````]`8```````#,
M`@``-P<````````S`````````+0"``#S!0```````#8%``"8!0``:@$``,X!
M````````$P<``%P```"Q`P``>P8```````!]````C08```````!9`0``30(`
M`/L!```&````T@``````````````V````!$&````````[P``````````````
M`````$,"``"B!@```````.,#``!J!```)P4``!`%``"L!0``1`````````!)
M````8@(``-L%```[!P```````%@%``"I!0``%`(``($!`````````````!X&
M``"]`````````&$'``"<!@```````!T"``!(!0``T`8``#8````F!0````$`
M`+@!``"Q`0```````.0&``!3!P```````&0``````````````/0#``!5`P``
MZ@4````````%`0``P@(``$,&````````>@8``.@%````````3@(``#L$``#2
M`@``$0`````````]`0``>P0``&(#``".!@```````````````````````&`%
M``#X!@``&`0``*L!``"&!0```````*D```"W`@``````````````````&`,`
M`)<&``#?`P``^@0```````#D````\00``*\$``!<!0``^0(```<!```!!P``
M4`4```````!'`P```````.0%``"T!```@0````8$``"E!@``'P4`````````
M````V00``&4!``!0!```]0,``!$"```'!```Z`(```````!\!```S@4``)T%
M````````\`$``&H%```(`0``:`4``*\#````````'P,``$<!``!C!@``E`,`
M````````````?`,``+T$``!6!```VP```/($````````M08```L'``#1!```
M:00``*`!``":!0``L@,``$H#``#R!0``7@8``'$````<!````````$@&``#/
M`0``X`$````````H`@``9@(``,0!````````Z0```-@"``":`P```````!X%
M````````$`$``"L!``#K````UP4```````!1`P``U08``#$!```<!P``;`$`
M`$4#```V`@``E``````````Q````FP8``+4$``!L!@``M`,```````"4!0``
M]04``$@$`````````````"P'``#U!@``.0<``$T````I!P``+04``"<!````
M````6@,```````#7!@``)@,```````#7!```0@````````#\`@``N00``',&
M``!F!0``>P,```\$```2!@``%`,```````!M`P```````*$&````````````
M`-4"``"!!0``308``!L#```/`@```````'X$```(`@``;0$```````#^!0``
M.@,```````````````````````#B````CP$``!D!``">`````````/`$````
M`````````$D$```1`0``N`````D$``"(!0``````````````````/@```"T&
M``!"!```P@0``````````````````$<$````````W`,``(8#````````Y`(`
M``````"X`@``)`,``'8!``"+`0```@(``'@$```_!0``#P,```````"6`@``
M_P8``#,&``!H`@``(`,``!0`````````KP(``+P$``"5````1`4``#T&``#6
M````%0$``-8$``#A!@````````````!!`P``\P,``-P"````````T@4``-0%
M````````!@$``),``````````````/$%```$````!0,``#`````T!@``*08`
M`#4&``!I`P``/`,``+<&``#-!```G@4``.$%```4!````````'<!``#+!@``
M&`<```````!E`@```````)P%````````"`<``)0$`````````````(X!``#L
M!0``*0```'L%``!C````F@(``,T#``!1````I`,```````"_!```;P8``)\%
M```@`@```````-X$``""`P``!P(``,L%``"@!@``S0```%8&```>`P``D@(`
M`#T$````````>@4``"H%``"S````=0```$X#``!``P``;@4````````*````
M[`,``````````````````"('````````F0$`````````````I`8``%<%``!%
M!P```````/(```"K`P``$@$````````C!```<P(```````#@!@``K@(``$D!
M``!I!@``+0<``'P```"$`@``T0$``&`#`````````````$4```#T`@``````
M`.X!``!Q`P``*@```+0!````````_`$``.D"``"C!```OP$```````"J````
M/`<``,T&````````,@(```P'``"V!```:@```&<"```Y!0````````@#````
M````0@$``(0&````````&@$``"\%``"R!@``%0(``/4"````````QP```&$&
M``"V!@``Q@```(@$```>!````````(4!``#Q!@``X````#,'``"'!@``XP(`
M````````````J`(``/T"``!?`@``*P4````````U!```/`0``%D"``"R!```
MF00``"H"``#F!@``2`,`````````````R`4`````````````N@4``%@&``"G
M`P`````````````-!0```````)@!``#L``````8``!H%````````?P4``/P#
M``"6`P``.P8```````#Y!0```````/0`````````@`4```H'``!M!```@@8`
M``````#F!``````````````W!@``@P4```````#N`@``N0$``)4$``#X`P``
MMP4``&X!``#^`````````)$&``"7!0```````&0&```A!@````````T````@
M!```@`8````````A!P```````*@#```=`P``GP````````!.!````````(P`
M```A!```SP4``*<&``#6!@``C`(``````````````````"P%``#-!0``1@0`
M`!L!`````````````%(!``"M`0``K@$``/L&``#V`0``K@8``$H````2!0``
M100```````!L`P``-@0``'X%```Z`0``/@(``&<!```H!@``6@(````````/
M````R@4``#P```````````````````#+`0``S@````````#Z!0``DP8``"`'
M``#G`P```````#(!`````````````*$#``#H`P``!0(```0#``"@!0``````
M`!4&``"S!````````/<$``"V`0```````$(#``";`P``9`,``,4"``"L`0``
M```````````;`@``,0<``!P%```W!0``3P```.0!``"A````&`4``"0$````
M````DP(```````"Q!@``5````,P$````````$P(``)$!``!1!0``1`0``'(%
M``!+!0``$@0``+(%``!<!@``6P8``%\$```!!@``/`8``+`!``"$!```G0``
M`&(```#R`@``\0,``&T`````````R`,``!8!```:`@``_P0``%8'````````
M+`,```````"X!@``SP,``(\"``!/!@``QP$``````````````````)<!````
M````F0,``'0&````````F`(``'D```#!`P``)P(``#(%```0!@``9`(``/T%
M``#+!````````"P$``##`0``&`(``'D%``"7`P``:P````P$````````60``
M`#T%``#9`````````%L!```-`0``<00`````````````"`8```````!H````
MB@```%0"````````O@(``*,&```3````FP4``&0!``#7`0``)`(``*L&``";
M!```!`8``````````````````&('``#"!0```````#`"```X!0``(P8``(,!
M```!`P``2@$``*@%``#%````'````#4```#O!@``(P(```````"E`@``"0,`
M`),!````````AP```!L$`````````````(\#````````+P```$8&````````
M`````%H'``"I!``````````````A`@``30<``+@#```K!```V@`````````>
M`0``G0,``!H$```\`0``#@8``%H$````````````````````````)04``)D%
M````````U`0```````!9`P``(`4````````X`P```````%L'````````U```
M`+\```"H````,P4```````"?`0``!P8``(8&``!!`````````!@!```_`@``
M`````'@&```7!```/P<``+H$``"X!0``'0`````````J!```5P0```````#0
M````!`$``(T```"D````C0(``(($`````````````*\&```Y!@``O@$```4`
M``!N`P``L@```"L"```6!```D00``%`"``#C!```YP(``-H"```Z`````@0`
M`"D#``!3`P```````.0#``#>`@``^@$``/X"````````R00``!8"````````
M^@(``+<!``#1````=@4````````V!@``V`,``-,$``"Y````%`8``.D$``"!
M!`````````````"Y!@```````.8```!]!@```````&P```"``0``(@4``,P!
M``#,!@```````!L&``!.!0```````+,&``!<!P```````$L```"I!@``*04`
M`&X````S`@````````0%``!Q!@```````$H%``!9!@``&0```(0!``#5!0``
M.P,```$"````````'@```'("``!H`P``P`0``'($``#E!0``H0$```````!,
M!```Y0```(P!```*`0```````"T"```_!```R04``.$$```2`@``$0,`````
M```Q`P```````+0`````````!@8````````.`0``(P````````!=`0``W0,`
M``````````````````````"J`P``\P```)X$``"8````604```````!!`@``
M`````)X#````````;P(``%8!``"A`@```````"X$``#'!````````+X$````
M````?P8``/@$````````[@0```````"V````K`(```,%```T!P``%@<``,0$
M```C`P``-`,``!<```!.!@``*0(``-<"``#[`P``UP,``#4"``#E!```J`8`
M```````<!@``[@````````#*``````````````!5!```)@(``!<"``#=````
M``````````#?``````````````"O`0``4@````H"````````]@4```````!&
M````C0$``'X&```Z!0````````````#;`0``(0,```````#6`P```````$X'
M``"F`@``+00``,@$``#B`0``,`,``%0%``##`P``,@<``"0&````````:`0`
M``````#O`0``6P(``#$%```6`````````'`&``!=!0``#`8``+H"``!/`P``
MRP,``$P#``!V````KP```!L```#J!@``908``.@!```5!```J0(```````"2
M`0``4@4``-X#```T`0``I04``'(#```T!```W`````````"[!0``````````
M````````@P0``*H%```$!P``]`$``#<```"?`P``\P$`````````````C`4`
M``````#\````E0$```````!F`P``!P<```````!O`P``A@0``)\$``!\`@``
MI0,````````K`P``*@<``'D#``"1`P``K@0``%$!``!``@```````-P!``#S
M`@``IP```$8%``"@!````````/@!``#M!@``1`(``!X'``#*!```;P$``.<$
M``#C`0``_0`````````0`@``C@,``!,&``!8`0``(@(```````"%!0``9P0`
M`.$"``"'!0``5P,``"8$``!<`0```````!T'``":!```G`,``((!``!0`0``
M+@4```````#(`0``0`4```H#````````*P```&X"``"C`P``>@(``)D&````
M````70(``,D````X````A@```!`'```P`0``?@,``/(&``!N!```PP(`````
M````````B@8```<```#I!@```````,P#````````N0(``!('``!K`@``T@8`
M`*(!````````*00``!\```"%`@``C@```#,#```N!P``20,````````R!@``
M`P```,`&````````V`$``%$$``#$!@```````(0%```_!@``T`4``/4`````
M``````````````")!```:@8``%(&``!I`0```````&`'````````HP4``#4'
M````````\`````````#G!@``[P,``)<```"'`@```````%T`````````#@4`
M`!0!`````````````*<"````````1P````````#)`@``0`8````````K!P``
M`````/8#``!"!0``2P8``$<"``#=!0``300``-$"``".!````````/<%````
M````6`,``'T%```Q!````````&`$``#2`0``K@,``"@'``"*`P``````````
M``!L!````````/L```#7````"0<``/<&``!A`0``50<``"@%````````EP(`
M`&4`````````Y0(``$4"````````&@,``.P"``!E`P``R0$``-T!``"\!0``
MD`0```````!X!0``2`(`````````````X0```)T$``!!`0``I`4`````````
M````2P(``/D&``!S`0``*0$``*P&``!/`0``/P,``(L"``!8!P```````,4$
M````````]`4```````!+`P```````&`!`````````````/<#````````D@4`
M`'0$``#K!@``,`<``(D```!K`P``Z04```````#4`0``>P```&@&````````
MA08``-L&````````@P(``%(#```"`````````.T$````````S@0``*X````O
M!@```````!T&``"G!```PP```&$`````````4`8``)H!``!0`P``)0```+`&
M``"'`P``/@<``$D&``"0`@``.`<````````-!P``&@```'`"``"D`@``BP0`
M`+4%``!F````WP$``%8#``#O!```E`(``"`&```P!```;P```(P#```B!```
MH@4``!P#``!"!@``XP4```X`````````=@(`````````````"`4``%X`````
M````3@$``(@&``!,`````````"<``````````````'(!````!0``<0$``/`"
M``"_`P``A`,`````````````P@8``)`#````````"````"<'``!8`@``7@$`
M`'`!``!S!```2`$```````#1!@``.`0``%`'``!K!0```````%0'````````
M`````'X```#Q`0``V@,``%8```!>!P``)08````````)`@``WP4```$$``!E
M!```20<```P#``"^!@``Y08```0$``!1!P``:P0``)`!```.`@```````/8"
M````````7P8```````!]`@``[P(```````!*!```YP```(4$``#Y````3P<`
M`-\$``"=!@```````&X&``#J`P``^@8``-@%`````````````+T%````````
M``````````!=`P``7@0`````````````Q08``*8#````````!08`````````
M````I@8````````N`0``Q`,``/<!````````Q@$``+L#```#!P```````$H'
M``"'!````````/`#``````````````````"O!0```````%X%``!P!```R0,`
M`',```#``P``$````-X```!2!```4P(```````#/`@``R@,``.X&```%!P``
M``````````!4`P``/0(``/X&```H!```E@8``"(`````````!@<``%4````W
M!```W00``-L"``"M`@```````!(#``#M`@``&0<``&T"``#.!@``.`8``+P#
M``!?`P```````%D'```L`@```````,P%``#*`@``XP8``"@````7!P``````
M`/\```![`@``"04````````V`0``HP(``+8"``!%`0``F0```*L"```<`@``
M``````,"`````````````+`%``!T````BP```````````````````)P$``!7
M!@``U0$``*8```!``0``Y@4``#8'````````W0(``````````````````%H`
M``!4!@```````"<$``"M!0``C`0```````!_`@``I@0``+,%```Q!@``,`8`
M`(H"``!6`@``B@4``',#``!0````T`,```,#``"`!```````````````````
M_@,```P```"5`@``3`<``)`%``"T!0```````(T#````````=P```.T!``!'
M!@``F`,``%8%````````````````````````C@(``,4%``#%`P``2P<``-P&
M```1!0``:`$``*,````F!@``W@4``$\"`````````````,H&`````@``=0$`
M``````!$!P``^0$``.T```#)!@``(P$```````#I`P``A0```%4!``!D!```
ML`(```\&```6!0``O`$````````T`@```@4``(0`````````P0$``(4#``#H
M!```EP0```````"4!@``E08``&4%``#V!```;`4``+,!```7!0``.00`````
M``#P!@``20(```````"P!``````````````+`0``>@$``-H$``!#!0``"P8`
M`)8!``#?!@```````!0%``!#!P``+0,```\%````````9P```-`"````````
M`````'`%```+`@``G`(```````#3````:P8``&`&````````````````````
M`````````(,&`````````````,X#``!T`P``"@4``*`#````````TP4``"(#
M``"<`````````)\"```\!0``N@,``.($```9`@``>`,```````#]`0``````
M`&(%``"H`0``P```````````````7P```*P$``!C!P``(0`````````"`0``
M#`(``+L$```6!@``Y@(```8"``#`!0``Q@,``'`````S`0``WP(``$T%````
M`````````)0!````````7`,``)($``!K`0````````````#P!0``````````
M````````.`(``'4"````````8`(``&H#``!"!P````````````"Z````"0``
M`"$%````````?`4``)T!``#N`P```````/@````^`0``2````/4$``"C`0``
M6@$``+<#```=!``````````````F`0``T`0``(("```,`0``600``'L!```^
M!@``\0```-H!``!?`0``]@```+L"``#;`P````````````#A`0``.0(``#H"
M```-!````````/P$````````,@,``$L!``#H!@``,@0````````;!P``JP0`
M`'`#``!!!```B`$``%4%```F!P```````'D"``!U`P``MP```,@```":!@``
M@08``/D$```T!0``8P$``,0%``"I`0``0`0```````#J`@``804``&T&``"J
M!@```````&8&````````W@8``&8$````````E@4```8#```^!```)```````
M``"/!```CP4``"\#``#T!```3P0```````"M`````````'4&````````$P0`
M```````?`@``````````````````$P$``$8'``#A`P``=P(```4$````````
MQ@(``*($``!:!0``-`````````"Z!@``&P4``)\&``!!!0``%0,``$L$``"U
M````SP````````"&`@``@@```,,&```)!@```````/D#``!Z````/@,``,$`
M``````````````````!O!```Q@4````````8!@``>08``,0```"#````O0,`
M``<#``"D`0``L00``+<$```E`@``6P```-`!``!S!0``Y@,``'\`````````
M`````-0"``"``@``ZP,``$P%``##!```ZP4``)4%````````0@(``'@!````
M`````````"$!````````(````&(&```!`0``$@````````"@`@``)`$``,8&
M``"M!```[@4``$4%``"\``````````````#J````L0````(&``"M`P``E@0`
M`,<%``!_`P````````````"[`0``5P<``*@$````````$`0``!\$```5!0``
M`````-L$``#_!0```````'$%```W`P``H04```````#B`@``*@,``'H$``#Z
M`P``+@````````#J!```508````````@`0``8P4``(\&````````Q@0``%L%
M````````9`4``%T$```3`P``(@$``-(#``#H`````````.8!``!;!```)`<`
M`&<%``"``P``E@```!D&``"+!0```````+$%``#4!@``_@0``'8$``#'!@``
M`````)T"``":````C@4``$H&``"U`0````````````"E`0``(@8``$$&``#6
M`@``1@$``&<#``!1!@``_`8``$,```#B`P````````````"B`P``M@4``)(&
M``!.`````````'<%``!4`0``B@$``*H!````````8P0``#H$```O!P``````
M`#$"``#_`P``0P,``/\"``!3!0``B@0``%$"```?!P``M`8``.P!```[`0``
MB04``+T&``"L`P``Y0,``'8#``!=!P``5P```/(!````````TP(```T#```D
M!0``.P4``.4!```L!@``8````.L!```W`@```````+P"``!_`0``V@8``.(&
M``#<!0````````````````````````````"@`````````$P"````````.@8`
M`/T$``"F!0``%0<``'0%``#S!```BP,```````"(`@``50(``)(#``#_`0``
MRP(```````!>`P``U00```@$``"0````%`<``(L&````````%P,``%@$``!]
M`P``>`(```X$````````[`0`````````````H@(``"\"````!P``*P8``!`#
M``#R`P``?`8``$````"J!```9P8``*D#````````/0```!$'``#3`P``````
M``H$``#K!```V04````````9!```DP0``),%``"R`@``V@4``!<&``#W`@``
M`````+L&`````````@<``$0#```'!0``O`8``+``````````#P$``&\%````
M````R@$`````````````^`4``$,!```J!@```````&,"``#``0``U0```-8%
M````````P@$`````````````=`$``.`$`````````````.`"````````8@0`
M`#T'```-!@``Y`0``&P"`````````````"T!```+`P``_08``",%``")`0``
M&@<``'D$````````0P0`````````````S0(``%T&``"S`P``/P```/L"````
M``````````````#>`0``1`8``,4!````````V`8``#`%``!8````4P8``+`#
M````````F`8```````!?!P``D0(``$H"``#9`@``80,``&$$``"J`@``G@8`
M````````````"@8``/$"``#@!0``D@```%0$```+!0```````"@!``"U`P``
MO@,``+T!``"8!`````````````#!!0``.0$``*4```#@`P````,``(D&``#!
M!```+@(```D!``"(`P``SP8``($#````````:0```+T"``#!!@``1P<``/@"
M```!!0``)P8``"H!````````'0$``(@```#9!@``L@$`````````````````
M`'4$`````````````%('``#"````Q`(`````````````C`8``/L%````````
MM0(``"\!````````G@$``-,&``">`@```````/P%``""!0````````P%``!W
M!````````$`'`````````````-$#````````OP8``)$````E!P``3P4``.L"
M``"B````#@<``-P$``"G!0``D`8`````````````````````````````````
M`#4!````````+@,``"4$```/!P``N`0``#T#``#L!@``_0,```0"``"^````
MT@0```````#V!@````````````#M!0```````,X"```[````K````#(```"#
M`P```````,$"``!U!0``K@4``#\!````````)@```'@`````````LP(``-0#
M``!:!@``<0(```````!R````;04``$P!````````[P4``'X!```1!```````
M`%P"````````@0(``,`"```<`0``I00``$@'``#^`0``R`8``(<!``"9`@``
M`````(\``````````````-D#```W`0``?@(``#@!``#6`0```````%<!````
M````JP```)4#``#'`P``<@8```8%````````/`(``$8"``#W````1`$``!@`
M``!7`@```````&(!``#+````Z0$``*8!```H`P``^P0``$T#``#Z````X@4`
M``````")`@``$P4```````#"`P````````````";```````````````Y````
M&@8```,&``!3!````````),#````````7@(`````````````H00```(#```Y
M`P``'P$````````#!```=P8``"<#```E`0```````/,&````````S````,,%
M``")`P``N0,``%L#````("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I
M`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T97)D
M87DI`"!A="``(B5S(B!I<R!N;W0@82!D:7)E8W1O<GDN`"(E<R(@:7,@;F]T
M(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H
M92!(;W)D92!296=I<W1R>2X`(B5S(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N
M9"X`(B5S(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN`"(E<R(@
M=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"(E<R(@=V%S
M(&YO="!C<F5A=&5D.B`E<RX`)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W
M960@*"4N,F8E)2D`)60@)7,@86YD("5S`"5D(&1A>7,@=6YT:6P@>6]U<B!P
M87-S=V]R9"!E>'!I<F5S+@`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`
M)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E<FUS
M(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@)7,`
M)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T
M:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E
M<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@`E
M<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@
M)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S
M($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`)7,Z(%1H:7,@;65S<V%G
M92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R
M92!O9B!F;VQL;W=I;F<@86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN
M9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+@`L
M(&=U<W1I;F<@`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@
M=&\@)7,`+2T@<V5L96-T("TM`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R
M;6%T`#(T(&AO=7)S`#Q0<F5V:6]U<P!!(&1A=&%B87-E(&)A8VME;F0@:7,@
M<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C
M8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP
M="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@
M=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R
M:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E
M(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N
M(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)
M344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP
M="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-
M24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@
M82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@
M96YC<GEP="!A(&UE<W-A9V4N`$%-($-L;W5D<P!!32!,:6=H="!286EN`$%-
M(%)A:6X`04T@4VAO=V5R<P!!32!3;F]W(%-H;W=E<G,`04TO4$T`05!)($E$
M`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B<V)O='1O;0!!8G-M:61D
M;&4`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E
M<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-O=6YT($EN9F]R;6%T
M:6]N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I
M;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!
M9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D
M(&$@8VAI;&0@9W)O=7`@=&\@(B5S(@!!9&0@82!C:&EL9"!P97)M:7-S:6]N
M('1O("(E<R(`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`061D(&YE=R!M
M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@
M4VED96)A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S
M<R!B;V]K`$%D9"!U<V5R`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2P@8G5T
M(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ
M("5S+@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN
M(&YO=RX`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E
M<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE
M<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`069G:&%N:7-T86X`06QB86YI
M80!!;&=E<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!=71H
M96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L
M;"!F;W5R('-I9&5S`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S
M971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y(&5X:7-T<P!!
M;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!
M;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S
M<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;65R:6-A
M;B!386UO80!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N('5N
M:VYO=VX@97)R;W(@:&%S(&]C8W5R960N`$%N9&]R<F$`06YG;VQA`$%N9W5I
M;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YT87)C=&EC80!!;G1I9W5A
M(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N($QI<W0`07!P
M;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H:6QD(%-H87)E<P!!<'!R
M;W9E`$%P<')O>&EM871E(%-I>F4`07!R:6P`07)C:&EV92!&:6QE(%-I>F4`
M07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@
M=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@
M=VES:"!T;R!D96QE=&4@(B5S(B!A;F0@86YY('-U8BUG<F]U<',_`$%R9V5N
M=&EN80!!<FUE;FEA`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L86YD`$%S8VEI
M($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N
M(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!='1E;7!T
M('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D
M96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E
M9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I
M="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T<FEB=71E<P!!=6=U<W0`075S
M=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO
M="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U
M:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U
M:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET
M:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E
M9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER
M960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z($%D9&EN
M9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y
M`$%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F
M;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@861D
M('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!=71H
M7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N
M86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!=71H7VQD87`Z(%5P9&%T:6YG('5S
M97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN`$%U
M=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:&5N=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+@!!
M=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E
M<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!
M=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC
M871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@9FEE
M;&1S.@!!>F5R8F%I:F%N`$)/1D@@17AC=7-E<P!"86-K9W)O=6YD`$)A8VMG
M<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R
M;W,@=7-E<FYA;64N`$)A:&%M87,`0F%H<F%I;@!"86YG;&%D97-H`$)A<F)A
M9&]S`$)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!"
M87-E;&EN90!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E<FUU9&$`
M0FAU=&%N`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@87!P;&EC871I;VX@(B5S
M(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0F]L9`!"
M;VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R
M9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A;F$`0F]T
M=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N($]C96%N
M(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I80!"=6QL971E
M9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`0U),($1I<W1R
M:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#86-H92!I;FET
M('=A<R!N;W0@8V]M<&QE=&5D+@!#86QE;F1A<@!#86QM`$-A;6)O9&EA`$-A
M;65R;V]N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@
M8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B!N;W0@=W)I=&4@=&\@
M9FEL92`B)7,B`$-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H
M86YD;&5R<RX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`0V%N
M)W0@;W!E;B!F:6QE("(E<R(N`$-A;F%D80!#86YC96P`0V%N8V5L(%!R;V)L
M96T@4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@9FEN
M9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D('=I=&AO
M=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D:7)E
M8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N
M`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F
M;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#86YN
M;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#87!E(%9E
M<F1E`$-A<'1I;VX`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA;B!)<VQA
M;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`
M0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;G1E
M<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5R=&EF:6-A=&4@1&5T86EL
M<P!#97)T:69I8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D
M`$-H86YG90!#:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@=&AE(&YA;64@
M86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N
M9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=I;F<@>6]U<B!P87-S=V]R
M9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A
M=&EO;BX@($-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#:&%R`$-H96-?
M:R!,:6YK+BXN`$-H:6QE`$-H:6YA`$-H;V]S92!!<'!L:6-A=&EO;CH`0VAO
M;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO=R!T
M;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@
M;W)D97)E9"!L:7-T<RD`0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D969I;FET
M:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE87(`0VQE87(@35-/9F9I8V4@=&%G
M<P!#;&5A<B!1=65R>0!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#
M;&5A<B!U<V5R(&1A=&$`0VQE87)I;F<@3&%T90!#;&EC:R!T;R!#;VYT:6YU
M90!#;&EC:V%T96QL('9I82!(5%10`$-L;W-E(%=I;F1O=P!#;&]U9',`0VQO
M=61S($5A<FQY`$-L;W5D>0!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#;VQL
M87!S92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O;&]R
M`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!T
M:71L97,`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O
M;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP=71E<G,`0V]N9&ET:6]N
M`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U
M<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD
M($]U=&QO;VLN`$-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N`$-O;F9I
M9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O;F=O`$-O;F=O+"!4:&4@1&5M
M;V-R871I8R!297!U8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL960N`$-O
M;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U
M8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O
M($944"!S97)V97(@9F%I;&5D+@!#;VYT86-T<P!#;VYT86-T<R!W97)E('-U
M8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&5N
M="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@`$-O;G1E;G1S(&]F("(E<R(`
M0V]N=&EN=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@9F%I;&5D
M.B`E<P!#;W!Y('-E;&5C=&EO;@!#;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`
M0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4$=0
M('-I9VX@;65S<V%G93H@`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S
M86=E+@!#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T
M(&%D9"!C;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E
M<BX`0V]U;&0@;F]T(&)I;F0@=&\@;&1A<"!S97)V97(`0V]U;&0@;F]T(&-H
M96-K(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C;VYN96-T('1O(&QD87`@<V5R
M=F5R`$-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B`B)7,B('5S:6YG($94
M4#H@)7,`0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`
M0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z(`!#;W5L9"!N;W0@9&5C<GEP
M="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#
M;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N
M;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$-O=6QD(&YO
M="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#
M;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N
M;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO
M="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES
M=',N`$-O=6QD(&YO="!L;V%D('-T<F%T96=Y("(E<R(N`$-O=6QD(&YO="!M
M:V1I<B`B)7,B+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T
M:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`B)7,B(&9O<B!W<FET:6YG
M+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N
M8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y("(E
M<R(N`$-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO
M="!R96%D("5S+@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T
M:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS
M(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`0V]U;&0@
M;F]T(')E=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B
M;V]K+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S
M`$-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,`0V]U
M;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<FUD:7(@
M(B5S(BX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@
M;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L9"!N;W0@<V%V
M92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD(&YO="!S879E('-E
M='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!#;W5L9"!N;W0@<V%V92!T
M:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A
M=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@
M=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@
M;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`
M0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U
M;FQI;FL@(B5S(BX`0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<P!#;W5L
M9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@
M=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@(B5S(CH@)7,`0V]U;&1N)W0@9FEN
M9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@
M:7,@;W!E;BX`0V]U;&1N)W0@9VEV92!U<V5R("(E<R(@=&AE(&9O;&QO=VEN
M9R!R:6=H=',@9F]R('1H92!F;VQD97(@(B5S(CH@)7,`0V]U;G1E9"!T97AT
M`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@;&EN:P!#<F5A=&4@
M82!N97<@;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&]R(%!E<FUI<W-I
M;VYS`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N="`T
M(%!H87-E<P!#=7)R96YT(%-E<W-I;VYS`$-U<G)E;G0@5&EM90!#=7)R96YT
M(%523"!I<P!#=7)R96YT(%5S97)S`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT
M(&-O;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE('1A<VMS('1O
M(')U;B!U<&]N(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C=&EO;@!#>7!R
M=7,`0WIE8V@@4F5P=6)L:6,`1$0`1%-.("AS964@:'1T<#HO+W!E87(N<&AP
M+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN
M<&AP*0!$86EL>0!$871A5')E92!"<F]W<V5R`$1A=&%B87-E($QO;VMU<`!$
M871E`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@
M0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!);F1E
M;G0`1&5F875L=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F
M875L="!3:&5L;`!$969I;FET:6]N<P!$96QE=&4`1&5L971E($-E;&P`1&5L
M971E($=R;W5P`$1E;&5T92!,;V<`1&5L971E(%!E<FUI<W-I;VX`1&5L971E
M(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN
M`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E('!E
M<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S
M(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E(')O=P!$96QE=&4@
M<V5L96-T960@:61E;G1I='D`1&5L971E('1H92!C=7)R96YT(&-O;'5M;@!$
M96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T960@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@(B5S(BX`1&5L:79E<GD@=&EM90!$96YM87)K`$1E<V-R:6)E('1H
M92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G
M<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@
M861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN
M="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE9G0@
M=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I
M<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@
M9&5T86EL960@9F]R96-A<W0`1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P
M;&%Y(&9O<FUA=`!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`1&II8F]U=&D`
M1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA
M;F-E+G!H<`!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@
M;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;6EN:6-A`$1O;6EN
M:6-A;B!297!U8FQI8P!$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N
M`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF
M:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R=6=S
M`$4M36%I;`!%4E(`16-U861O<@!%9&ET`$5D:70@0FQO8VL`161I="!'<F]U
M<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI
M<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I
M;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D=6-A=&EO
M;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN`$5M`$5M86EL`$5M86EL
M($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL('=I
M=&@@8V]N9FER;6%T:6]N`$5M86EL+71O+5--4R!'871E=V%Y`$5M;W1I8V]N
M<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T
M97)M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A
M;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M
M96YU/P!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y
M('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D
M('1O(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA
M;64@;V8@>6]U<B!P970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5N
M=&5R('1H92!L971T97)S(&)E;&]W.@!%<75A=&]R:6%L($=U:6YE80!%<FET
M<F5A`$5R<F]R`$5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<P!%<G)O<B!D96QE
M=&EN9R!S>6YC(&%N8VAO<CH@)7,`17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z
M("5S`$5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,`17)R;W(@=7!D871I;F<@
M<&%S<W=O<F0Z("5S`$5R<F]R('=I=&@@96UA:6P@;65S<V%G92X`17)R;W(@
M=W)I=&EN9R`B)7,B+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`
M179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C
M;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H
M;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A
M;F0`17AP86YD(%-I9&5B87(`17AP96-T960@)RDG`$5X<&5C=&5D(&)A<F4@
M=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`17AP:7)A=&EO;B!$871E`$5X
M<&]N96YT`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D(')E
M=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$
M05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&
M86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E
M<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I
M;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I;&5D('1O(')E=')I979E.B`E<P!&
M86ER`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S
M`$9A=&%L($5R<F]R.@!&87@`1F%X97,`1F5B<G5A<GD`1F5E;',@3&EK90!&
M965L<R!L:6ME.B``1F5W(%-H;W=E<G,`1F5W(%-N;W<@4VAO=V5R<P!&:65L
M9"!M871R:7@`1FEJ:0!&:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#
M;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E
M;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E
M9"X`1FEL=&5R<P!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&
M:7@@<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X
M:7-T`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S
M=7!P;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN
M;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D
M87D@86YD(&YI9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L
M="!I;B!A('=I9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M
M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O
M<G5M<P!&;W)W87)D<P!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P
M;VQI=&%N`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@
M4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O;0!&<F]M('1H92``1G5L;"!$97-C
M<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$=A8F]N`$=A;&QE<GD@=&\@
M=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=A;6)I80!'96YE<F%T92`E<R!#
M;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E;W)G:6$`1V5R;6%N>0!'
M:&%N80!':6)R86QT87(`1VEV96X@3F%M90!';P!';V5D96P`1V]O9VQE($UA
M<',`1V]O9VQE(%-E87)C:`!'<F%Y<V-A;&4`1W)E96-E`$=R965N;&%N9`!'
M<F5N861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@
M8F4@;F]N+65M<'1Y`$=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@
M)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!'<F]U<%]L9&%P
M.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S`$=R;W5P7VQD87`Z(%5N86)L
M92!T;R!U<&1A=&4@9W)O=7`@)7,`1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'
M=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W1B;V]K
M`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A(&-O
M=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W
M+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@
M=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92X`2%144"!!=71H96YT
M:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`
M2&5A9&5R`$AE861E<G,`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA
M;F1S`$AE879Y(%0M4W1O<FT`2&5I9VAT`$AE;'``2&5L<"!U<VEN9R!E9&ET
M;W(`2&5L<&5R`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F
M('1H92!F:6QE.@!(:6=H`$AO7VUE`$AO;'D@4V5E("A6871I8V%N($-I='D@
M4W1A=&4I`$AO;64`2&]M92!!9&1R97-S`$AO;64@1&ER96-T;W)Y`$AO;64@
M4&AO;F4`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!)
M;G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,`
M2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T
M("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I
M;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E
M9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE
M(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N`$AO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T
M("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z("5S
M`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@
M=&AE('!A<G0@;V8@='EP92`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y
M;F-H<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<WEN8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA8CH@56YK;F]W;B!S
M:&%R92`B)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`
M2&]R:7IO;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P
M;W)T(2D`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G
M93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M
M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AU;6ED:71Y`$AU
M;6ED:71Y.B``2'5M;W)I<W1S`$AU;F=A<GD`24U!4"!M86EL8F]X(&-R96%T
M:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@
M)7,`24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`25`@
M061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0($%D9')E<W,@
M;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO8VMD;W=N('9I
M;VQA=&EO;BX`25]N<V5R="!2;W<@0F5F;W)E`$EC96QA;F0`26-O;G,@3VYL
M>0!)8V]N<R!F;W(@)7,`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M
M93H`268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P
M96X@:70@:6X@82!N97<@=VEN9&]W+@!)9B!Y;W4@9&]N)W0@<V5E(&%N>2!I
M8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O
M(&-H96-K('1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN
M`$EF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM
M86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92!D:7-P;&%Y960@8GD@
M>6]U<B!B<F]W<V5R+@!);6%G92!0<F5V:65W.@!);6%G92!54DP`26UA9V4@
M55),.@!);6%G92!F<F]M(&=A;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y.@!)
M;6%G92!U<&QO860`26UA9V5S`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E9"!F
M:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E<@!)
M;F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M
M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E
M<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI
M;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@
M26YD96YT`$EN9&EA`$EN9&EV:61U86P@57-E<G,`26YD;VYE<VEA`$EN9F\`
M26YF;W)M871I;VX`26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92X`
M26YS97)T($-?;VQU;6X@069T97(`26YS97)T($EM86=E`$EN<V5R="!486)L
M90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R
M="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A
M(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N
M97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W
M(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R87!H(&%F
M=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H(&)E9F]R
M92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`
M26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E
M:79E('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R
M="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU
M;6X@8F5F;W)E`$EN<V5R="!M97-S86=E<P!);G-E<G0@<&%R86=R87!H(&%F
M=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R;W<@869T97(`
M26YS97)T(')O=R!B969O<F4`26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@
M=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.@!);G-E<G0O36]D:69Y($EM86=E
M`$EN<V5R="]-;V1I9GD@3&EN:P!);G-U9F9I8VEE;G0@8W)E9&ET('1O('-E
M;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@8W)E
M9&ET+@!);G1E9V5R`$EN=&5G97(@;&ES=`!);G9A;&ED(%5$2"X@*%5S97(@
M1&%T82!(96%D97(I+@!);G9A;&ED(%I)4"!D871A`$EN=F%L:60@87!P;&EC
M871I;VXN`$EN=F%L:60@8F%T8V@@240N`$EN=F%L:60@9&%T82!S=6)M:71T
M960N`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI9"!F:6QE
M(&9O<FUA=`!);G9A;&ED(&QI8V5N<V4@:V5Y+@!);G9A;&ED(&QO8V%T:6]N
M('!R;W9I9&5D+@!);G9A;&ED(&US9U]T>7!E+@!);G9A;&ED(&]R(&UI<W-I
M;F<@87!I7VED+@!);G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV
M86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P87)T;F5R(&ED+@!)
M;G9A;&ED('!R;V1U8W0@8V]D92X`26YV86QI9"!P<F]T;V-O;"X`26YV86QI
M9"!R96-I<&EE;G0Z("(E<R(`26YV86QI9"!S:&%R92!O8FIE8W0`26YV86QI
M9"!S;W5R8V4@861D<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN=F5N
M=&]R>0!);G9E<G0@<V5L96-T:6]N`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@
M;V8`27)A<0!)<F5L86YD`$ES;&4@;V8@36%N`$ES;VQA=&5D(%0M4W1O<FUS
M`$ES<F%E;`!)<W-U97(`271A;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*
M87!A;@!*97)S97D`2F]R9&%N`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I9GD@
M0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H
M=`!+87IA:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA`$ME<F)E<F]S('-E
M<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5R;F5L($YE=V)I97,`
M2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4
M>7!E`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI
M8R!K97ES97)V97(N`$MI9',`2VER:6)A=&D`2V]R96$L($1E;6]C<F%T:6,@
M4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F`$MU=V%I
M=`!+>7)G>7IS=&%N`$QA7WEO=70`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E
M;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@4&%S<W=O<F0@0VAA
M;F=E`$QA<W0@475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S
M`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T
M=FEA`$QA=P!,87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A
M;F]N`$QE9G0`3&5F="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,979E
M;`!,:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I
M;@!,:6=H="!$<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,
M:6=H="!286EN($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W
M:71H(%1H=6YD97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE
M<FEC:P!,:6YK`$QI;FL@<&]I;G1S('1O.@!,:6YK('1H92!E;6%I;"!A9&1R
M97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS
M`$QI;G5X($-O;VMI90!,:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(`
M3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,
M:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/=VYE<@!,:7-T
M+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG
M('-E<W-I;VYS(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!F86EL960Z("5S
M`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QI=&5R871U<F4`3&ET:'5A
M;FEA`$QO861I;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,
M;V-A=&EO;@!,;V<@:6X`3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;@!,
M;V<@;W5T`$QO9VEN`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E
M('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R
M96-T;'DN`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R
M(&=R965K(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA
M;B!N=6UB97)S`$QU>&5M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE
M;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H
M92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I
M8P!-86EL`$UA:6P@061M:6X`36%K92!L:6Y?:RXN+@!-86QA=VD`36%L87ES
M:6$`36%L9&EV97,`36%L:0!-86QT80!-86YA9V4@=&AE(&QI<W0@;V8@8V%T
M96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L
M;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87`R-"!M
M87``36%P475E<W0@;6%P`$UA<'!I;F=S('-T;W)E9"X`36%R8V@`36%R9VEN
M`$UA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H97(@
M9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA
M;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U
M<FET:75S`$UA>"!A;&QO=V5D(&-R961I="X`36%X(&UE<W-A9V4@<&%R=',@
M97AC965D960N`$UA>"!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-87@@=&5M<"!L
M87-T(#8@:&]U<G,Z(`!-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS
M`$UA>&EM=6T@;&5N9W1H`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`
M365N=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@5F5R:69I
M960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@
M8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A
M9V4@='EP90!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B
M;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B
M965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&%R1$(@:7,@
M;F]T(&-O;FYE8W1E9"X`365T:&]D`$UE=&AO9"`B)7,B(&ES(&YO="!D969I
M;F5D`$UE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,`365T
M<FEC`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F`$UI
M9&1L90!-:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T
M96UP(&QA<W0@-B!H;W5R<SH@`$UI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N
M;W0@>65T(&5X<&ER960`36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!0
M14%2('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I
M;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T
M;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-
M:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E
M<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF:65D($1A
M=&4`36]D:69Y(%523`!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO
M;F%C;P!-;VYG;VQI80!-;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1S97)R
M870`36]O;B!0:&%S97,`36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T
M:&%N('1H92!E>'!E8W1E9"`E9"X`36]R;V-C;P!-;W-T;'D@0VQE87(`36]S
M=&QY($-L;W5D>0!-;W-T;'D@4W5N;GD`36]V92!$;W=N`$UO=F4@3&5F=`!-
M;W9E(%)I9VAT`$UO=F4@57``36]V92!D;W=N`$UO=F4@=7``36]Z86UB:7%U
M90!-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',`375L=&EP;&4@<V5L96-T
M:6]N`$UY($%C8V]U;G0`37D@06-C;W5N="!);F9O<FUA=&EO;@!->2!0;W)T
M86P`37D@4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E
M90!.86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R
M;&%N9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@
M4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P
M92!296YE=V%L(%523`!.971S8V%P92!2979O8V%T:6]N(%523`!.971S8V%P
M92!34TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N
M=`!.971S8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`3F5W
M($-A;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($UE<W-A9V4@=&\@)7,`3F5W
M($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W
M('!A<W-W;W)D`$YE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"X`3F5W
M('!A<W-W;W)D<R!D;VXG="!M871C:"X`3F5W('=I;F1O=R`H7V)L86YK*0!.
M97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(#0@4&AA<V5S`$YE>'0@;W!T:6]N
M<P!.97AT/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:6=H=`!.:75E`$YO
M`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F
M97)E;F-E<R!F;W(N`$YO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG
M($E33R!I;6%G97,N`$YO(&)A=&-H('1E;7!L871E+@!.;R!B;&]C:R!E>&ES
M=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE
M('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N
M`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN
M`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E
M<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@;&5F="X`
M3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&9I;&4@=7!L;V%D960`3F\@
M:6-O;G,@9F]U;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;&]C871I;VX@
M<')O=FED960N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF
M:65D+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N
M97,`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I
M;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T
M:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N
M=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H
M96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A
M=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@
M<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@
M=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.
M;R!Q=6]T82!S970N`$YO(')U;&5S`$YO('-E<&%R871O<B!S<&5C:69I960N
M`$YO('-I9&5S`$YO('-U8V@@9FEL90!.;R!T96UP;W)A<GD@9&ER96-T;W)Y
M(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S
M=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU
M97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N
M+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@
M:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I
M;VXN`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)F;VQK($ES;&%N9`!.
M;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.
M;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO
M="!I;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.
M;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V96UB97(`3G5M8F5R`$YU
M;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O
M9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@
M9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@0W)E871O<@!/
M8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/;&0@86YD(&YE
M=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N`$]L9"!P87-S=V]R9`!/
M;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N`$]M86X`3VYL>2!)34%0('-E
M<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!O9F9E;G-I=F4@
M9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+@!/;FQY
M('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E
M(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R90!/
M<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@
M97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+@!/<&5N<R!T
M:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T
M:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N
M`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L
M:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T
M:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A
M=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!014%2.CI-86EL(&)A
M8VME;F0`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T
M80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(
M4"!#;V1E`%!(4"!3:&5L;`!032!,:6=H="!286EN`%!-(%-H;W=E<G,`4$T@
M4VYO=P!032!3;F]W(%-H;W=E<G,`4$T@4W5N`%!-(%0M4W1O<FUS`%!/4TE8
M(&5X=&5N<VEO;B!I<R!M:7-S:6YG`%!?2%`@4VAE;&P`4&%D9&EN9P!086MI
M<W1A;@!086QA=0!086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D`%!A
M;F%M80!087!U82!.97<@1W5I;F5A`%!A<F%G=6%Y`%!A<G1L>2!#;&]U9'D`
M4&%S<W=O<F0`4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN`%!A<W-W
M;W)D(&EN8V]R<F5C=`!087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U
M=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!087-S
M=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`4&%S=&4`
M4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z`%!E
M;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!0
M97)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI
M<W-I;VX`4&5R;6ES<VEO;B`B)7,B(&YO="!D96QE=&5D+@!097)M:7-S:6]N
M($1E;FEE9`!097)M:7-S:6]N<P!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO
M;@!097)S;VYA;"!);F9O<FUA=&EO;@!097)U`%!E=',`4&AI;&EP<&EN97,`
M4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!I>&5L<P!0;&5A<V4@8VQI8VL@:6YT
M;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R
M96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W
M86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO
M;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N
M97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N
M`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@
M;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I
M;64N`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`
M4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE
M87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W
M:71H('1H92!T97)M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E('1Y<&4@
M=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`
M4&]R='5G86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN
M9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O
M<F-E9"!B>2!)34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H
M<RDZ(`!0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E`%!R969S7VQD87`Z(%)E
M<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO
M;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S
M<W5R90!0<F5S<W5R92!A="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I
M97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S
M(&]P=&EO;G,`4')I;G0@9&]C=6UE;G0`4')I=F%T92!+97D`4')O8FQE;0!0
M<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI
M8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC($ME>2!);F9O`%!U
M8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L
M;'DN`%!U97)T;R!2:6-O`%%A=&%R`%%U97)Y`%%U;W1A`%)302!0=6)L:6,@
M2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`
M4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3
M;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E<P!2
M96%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD
M;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI
M<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5D;V5S('EO=7(@;&%S
M="!A8W1I;VX`4F5F<F5S:`!2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT
M<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G97@`4F5L871I;VYS:&EP($)R
M;W=S97(`4F5L;V%D`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%52
M3"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO
M=F4@0FQO8VL`4F5M;W9E(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO
M=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M
M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E
M(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E
M<P!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O
M<F-O9&4Z(`!297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N
M`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T
M:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I
M9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!C;VYF
M:6=U<F%T:6]N+@!297%U:7)E9"!&:65L9`!297-E=`!297-E="!087-S=V]R
M9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W1O<F4@3&%S="!1=65R>0!297-U
M;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E='EP92!N97<@<&%S<W=O<F0`4F5U
M;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R($]P
M=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG:'0@=F%L=65S
M`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N:6$`4F]T871E(#$X,`!2
M;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I97,`4F]W('!R
M;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E
M;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W
M965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O
M=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3+TU)344@
M0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E9"!-97-S
M86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3
M($UE<W-A9VEN9P!344P@4VAE;&P`4U%,('-T871E;65N="!F;W(@=F%L=64@
M;&]O:W5P<P!34T@`4U5#0T534P!37U%,(%-H96QL`%-A`%-A:6YT($AE;&5N
M80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE
M<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D
M:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@
M5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I9&5R`%-A=61I($%R
M86)I80!3879E`%-A=F4@(B5S(@!3879E("5S`%-A=F4@3W!T:6]N<P!3879E
M(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y
M;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O
M;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B
M)7,B+@!38V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!396%R8V@`4V5A<F-H
M($5N9VEN97,`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@
M9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!S97)V
M97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;`!396QE8W0@86QL
M(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C=`!396QE8W0@;F]N
M90!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X
M97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R
M;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`
M4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I9&5N=&ET>2!Y
M;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z
M`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@
M9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R
M('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD
M(%--4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:6$@86YD($UO
M;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397)V97(@9&%T82!W<F]N9R!O<B!N
M;W0@879A:6QA8FQE+@!397-S:6]N($%D;6EN`%-E<W-I;VX@240@97AP:7)E
M9"X`4V5S<VEO;G,`4V5T`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R
M97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T
M('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R
M;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@
M=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A
M<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N
M9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A9&4@
M<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@
M=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3:&]P<&EN9P!3:&]R
M="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M
M;W-T(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R
M96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A
M=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3
M:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H;W<@
M=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O
M;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I
M86QO9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H
M92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@
M<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W97)S
M($5A<FQY`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6:6-I;FET>0!3
M:')I;FL`4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U
M="!O9B!T:&4@=V%Y(&9I<G-T`%-I97)R82!,96]N90!3:6=N('5P`%-I9VYA
M='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@
M36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=P!3;F]W(%-H;W=E
M<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO=V5R
M<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z
M(`!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3;VYG<R`F(%!O96US`%-O<G0@
M;W)D97(@<V5L96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC80!3
M;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3
M;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@861J86-E;G0@8V5L
M;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3
M<&%C97(`4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P86EN`%-P86T`
M4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!L:70@8V5L;`!3<&QI="!C;VQU
M;6X`4W!L:70@<F]W`%-P;W)T<P!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4
M<F5K`%-T87)T('EE87(`4W1A=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T;W)A
M9V4@9F]R;6%T`%-T<F5E="!!9&1R97-S`%-T<FEK971H<F]U9V@`4W1R:6YG
M(&QI<W0`4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,`4W1Y;&4@6T-3
M4UT`4W4`4W5B9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!3=6)J96-T`%-U
M8FUI=`!3=6)M:71T960@<F5Q=65S="!T;R!A9&0@(B5S(B!T;R!T:&4@<WES
M=&5M+B!9;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R(')E<75E<W0@:&%S
M(&)E96X@87!P<F]V960N`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL
M>2!A9&1E9"`B)7,B('1O('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!C;&5A
M<F5D(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E
M<W-F=6QL>2!D96QE=&5D("(E<R(N`%-U8V-E<W-F=6QL>2!R96UO=F5D("(E
M<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@<F5V97)T960@8V]N
M9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3=6-C97-S9G5L
M;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL>2!S
M879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`4W5C8V5S
M<V9U;&QY('5P9&%T960@(B5S(@!3=6-C97-S9G5L;'D@=W)O=&4@)7,`4W5D
M86X`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U;G)I<V4`4W5N
M<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C
M<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@86YD($IA
M;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y;F,@;&]G
M(&1E;&5T960`4WEN8TU,`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`
M4WER:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M(&%N9"!7:6YD
M>0!4+5-T;W)M<P!4+5-T;W)M<R!%87)L>0!44U8@9FEL90!486)L90!486)L
M92!0<F]P97)T:65S`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@
M4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D
M(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!4
M96UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!496UP97)A='5R93H@
M`%1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,`5&5M
M<&QA=&4@(B5S(B!N;W0@9F]U;F0N`%1E;7!L871E($%D;6EN:7-T<F%T:6]N
M`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I;&%N
M9`!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@2&]R
M9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@
M(B5S(@!4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+@!4
M:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U
M;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4
M:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE
M;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R
M;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H92!C;VYT86-T($E$
M(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@
M;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A8W0@=V%S('-U
M8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`5&AE(&1E
M=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R
M:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T
M($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N
M;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI
M<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T:6]N(&9E871U<F5S
M(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!F:6QE("5S
M('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO
M=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N;F]T
M(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO
M(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES
M(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F=6QL('-C<F5E;B!M;V1E
M(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP
M;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B
M;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A
M9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R
M86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T96T@:7,@5VEN
M9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='
M96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<
M;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@3TL@:68@
M>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N
M`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!L969T
M+6AA;F0@<VED92!O;FQY`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN
M87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4
M:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B
M(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA
M="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H
M92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G
M90!4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N`%1H92!O
M<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T
M7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T
M(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM
M=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H
M:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M
M+@!4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R
M86-T97(N`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY`%1H92!R:6=H
M="UH86YD('-I9&4@;VYL>0!4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I
M;F=L92!C:&%R86-T97(N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D96QE
M=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S:6=N
M=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE('-P96-I
M9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N`%1H92!T96UP;W)A<GD@9FEL92`B
M)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@
M;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN`%1H92!T;W`@86YD
M(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!U<&QO
M861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4
M:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!W96%T
M:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5M97,@9&ER96-T
M;W)Y("(E<R(@;F]T(&9O=6YD+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I
M;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y
M960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T
M:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[('EO
M=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE
M;2!A9&1I;F<@(B5S(B!T;R!T:&4@<WES=&5M.B`E<P!4:&5R92!W87,@82!P
M<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S
M>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG("(E<R(@9G)O
M;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R`B
M)7,B.B`E<P!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L
M;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L96T@
M=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@
M=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E('=A
M<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@
M;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O<B!D
M:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N`%1H97)E('=A<R!A
M;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO
M=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W87,@86X@97)R
M;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC
M=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R
M<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@
M86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@
M9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H
M:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E
M<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R
M8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP
M(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@
M;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E
M<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC
M;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT
M='`Z+R]W:6YP;&,N8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`
M5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G
M:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A
M>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE
M($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@
M<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F;VYE($ET86QY
M("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N
M`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI<R!F
M:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BX`
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`5&AI
M<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI
M<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M
M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@
M=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N`%1H
M:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`5&AI<R!I<R`E
M<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@
M=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C;&EE;G0@=&AA
M="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R
M(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L:65N=',@<&QE87-E('9I<VET("5S
M`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@
M*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M=7-T(&)E
M(&%T(&QE87-T(&]N92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z
M:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D
M96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES
M('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W
M`%1H=6YD97(`5&EC:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`5&EM92!F;W)M
M870`5&EM92!S96QE8W1I;VX`5&EM;W(M3&5S=&4`5&ET;&4`5&ET;&4@*'1O
M;VQT:7`I.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W
M;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE
M(&-L:6-K:6YG+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME
M;&%U`%1O;6]R<F]W`%1O;F=A`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1R86YS
M;&%T:6]N<P!4<FEN:61A9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L<V4`5'4`
M5'5N:7-I80!4=7)K97D`5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#86EC;W,@
M27-L86YD<P!4=79A;'4`5'EP92!Y;W5R(&-H;VEC93H@`%4N5BX@:6YD97@Z
M(`!54DP`55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P
M;W)T`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C8V5S<R!61E,@
M9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I
M;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I
M;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES
M<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N9V4@=&\@
M)7,N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S(BX`56YA8FQE
M('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,O)7,B+@!5;F%B;&4@=&\@8V]N
M;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-3
M3"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@
M5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E
M8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T;R!C
M<F5A=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@8W)E871E(&5M<'1Y
M(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B;&4@
M=&\@9&5L971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+@!5
M;F%B;&4@=&\@9&5L971E("(E<R(Z("5S+@!5;F%B;&4@=&\@9&5L971E("5S
M+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@9&5L971E
M(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L92!T;R!D96QE=&4@
M5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y
M.B`E<RX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92`B)7,B+@!5;F%B;&4@
M=&\@9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD
M97(@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S
M+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5;F%B
M;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N86)L92!T;R!L
M;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V92!61E,@
M9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O
M(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T;R!O<&5N(%9&
M4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N
M86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN`%5N
M86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN
M`%5N86)L92!T;R!R96%D(&9I;&4Z(`!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S
M<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E
M<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@<F5N
M86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C
M=&]R>3H@)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`56YA
M8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92X`56YA8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N86)L92!T
M;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET
M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O
M<'DH*2!F86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E
M9&5D+@!5;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@
M86-T:6]N`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N
M;F5C=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z
M(`!5;F9I;&5D`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M
M`%5N:71E9"!3=&%T97,`56YI=',`56YK;F]W;@!5;FMN;W=N(&%P:6US9VED
M("A!4$D@365S<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-
M97-S86=E($E$*2X`56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"X`56YK;F]W
M;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YL:6YK('1H92!C=7)R96YT(&5L
M96UE;G0`56YN86UE9`!5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C
M97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I
M='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E
M(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@
M82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N`%5N<V5T(&-O;&]R
M`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D871E("5S`%5P9&%T
M92!U<V5R`%5P9&%T960@(B5S(BX`57!G<F%D92!S8W)I<'0@9&5L971E9"X`
M57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T
M;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R(')O;6%N
M(&YU;6)E<G,`57)U9W5A>0!5<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@
M:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R
M+@!5<V5R`%5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R
M($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO
M;@!5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI
M<R!S:71E+@!5<V5R(&%C8V]U;G0@;F]T(&9O=6YD`%5S97)N86UE`%5S97)N
M86UE("(E<R(@86QR96%D>2!E>&ES=',N`%5S97)N86UE.@!5<V5R;F%M93H@
M`%5S97)S(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R
M>2!D;V5S(&YO="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O
M=6YD(&EN8VQU9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@
M;F]W+@!686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RX`
M5F%L=65S`%9A;'5E<R!T;R!S96QE8W0@9G)O;0!686YU871U`%9A<FEA8FQE
M`%9E;F5Z=65L80!697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E
M(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO;@!697)S:6]N
M($-O;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T
M:6-A;#H`5F5R>2!(:6=H`%9I970@3F%M`%9I97<@)7,`5FEE=R!A;B!E>'1E
M<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I<F=I;B!)<VQA;F1S+"!"<FET
M:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I;&ET
M>3H@`%9O9&%F;VYE($ET86QY('9I82!33510`%=!4DX`5T%23DE.1R$A(2!2
M14U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=)3B!V:6$@2%144`!7
M86QL:7,@86YD($9U='5N80!787)N:6YG`%=E`%=E871H97(@1F]R96-A<W0`
M5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!796(@
M4VET90!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S
M`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I
M<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R
M86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAE<F5I<R!!
M=7-T<F%L:6$@;6%P`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N
M86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H`%=I9'1H(&EN
M($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H
M=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A
M8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN9`!7:6YD($5A<FQY`%=I
M;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O;0!7:7-H;&ES
M=`!7;W)K`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%=R;VYG(&YU;6)E<B!O
M9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D+@!7
M<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N
M`%=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N`%@M
M4F5F`%@U,#EV,R!"87-I8R!#;VYS=')A:6YT<P!8-3`Y=C,@17AT96YD960@
M2V5Y(%5S86=E`%@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64`6#4P
M.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(`6#4P.78S(&5X=&5N<VEO;G,`
M65D`65E960!986AO;R$@;6%P`%EE87)L>0!996UE;@!997,`665S+"!)($%G
M<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O
M;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E(&YO="!A;&QO
M=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+@!9;W4@87)E(&YO
M="!A=71H96YT:6-A=&5D+@!9;W4@8V%N;F]T(&AA=F4@=&AE("=<)R!C:&%R
M86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!D:60@;F]T(&5N=&5R(&$@
M=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I9&XG="!M87`@86YY(&9I96QD
M<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG
M(&9I96QD<R!I;B`E<RX`66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@
M:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET
M<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG(&9O<B!T:&4@:6YT97)N871I
M;VYA;"!D:6%L:6YG('!R969I>"X`66]U(&AA=F4@=&\@96YT97(@82!V86QI
M9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N
M9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A
M8VME;F0N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y
M;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E
M<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@
M<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+@!9;W4@;75S="!S<&5C
M:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@;75S="!S<&5C:69Y
M(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U
M<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE
M('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P
M97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N`%EO
M=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(`66]U
M<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN
M`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@
M26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D
M('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P
M<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9
M;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T
M('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R!U<V4@2&]R
M9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@
M82!D:69F97)E;G0@875T:&5N=&EC871I;VX@8F%C:V5N9"X`66]U<B!A=71H
M96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U
M<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O
M;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E
M(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I
M;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@
M86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A
M='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN
M="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@=&\@<')I;G0N
M`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET
M>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO
M=7(@9G5L;"!N86UE.@!9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+@!9;W5R(&YE
M=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N<R!H879E(&)E
M96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BX`
M66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D
M(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L
M(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W('!A
M<W-W;W)D+@!9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+@!9;W5R(')E;6]T
M92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!::6UB86)W90!:
M:7!P>0!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@4F5P;W)T70!;4VAO
M=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=
M`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I;VX`7T-,20!?1&%T851R
M964`7T1E;&5T92!2;W<`7T=R;W5P<P!?2&5L<`!?26UA9V4@4')O<&5R=&EE
M<RXN+@!?3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN:RXN+@!?3W!T:6]N
M<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]3971U<`!?5&%B;&4@
M4')O<&5R=&EE<RXN+@!?57-E<G,`861D<F5S<R!B;V]K`&%D9')E<W-E92!U
M;FMN;W=N`&-A;&5N9&%R`&-A;&T`8V%N;F]T(&-R96%T92!O=71P=70@9FEL
M90!C86YN;W0@;W!E;B!I;G!U=`!C;&EC:R!H97)E`&-O;6UA;F0@;&EN92!U
M<V%G92!E<G)O<@!C;VYF:6=U<F%T:6]N(&5R<F]R`&-R:71I8V%L('-Y<W1E
M;2!F:6QE(&UI<W-I;F<`9&%T82!F;W)M870@97)R;W(`96YT<GD@;F]T(&9O
M=6YD`&9A;&QI;F<`9FEL90!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&=U
M<W1I;F<`:#H`:&@`:&]S="!N86UE('5N:VYO=VX`:6UM961I871E`&EN;&EN
M90!I;G!U="]O=71P=70@97)R;W(`:6YT97)N86P@<V]F='=A<F4@97)R;W(`
M;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/
M+@!M;0!N86UE`&YO="!I;7!L96UE;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D
M`&YO=&5P860`<&5R8V5N=`!P97)M:7-S:6]N(&1E;FEE9`!P:7AE;',`<F5M
M;W1E(&5R<F]R(&EN('!R;W1O8V]L`')I<VEN9P!S97)V:6-E('5N879A:6QA
M8FQE`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10`'-S`'-T
M96%D>0!S>7-T96T@97)R;W(`=&%S:R!L:7-T`'1E;7!O<F%R>2!F86EL=7)E
M`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U
M;FYA;65D`'5S97(@<V5L96-T`'9#87)D`'<Z`'=E871H97(N8V]M`%!R;VIE
M8W0M260M5F5R<VEO;CH@2&]R9&4@,RXQ"E)E<&]R="U-<V=I9"U"=6=S+51O
M.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`V
M+3`Q+3`V(#$T.C$P*S`Q,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP,2TS
M,"`R,3HR-BLP,C`P"DQA<W0M5')A;G-L871O<CH@279A;B!.;W)I<R`\=FEX
M0'9A>FMA+G-K/@I,86YG=6%G92U496%M.B!3;&]V86L@/'9I>$!V87IK82YS
M:SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN
M.R!C:&%R<V5T/6ES;RTX.#4Y+3(*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN
M9SH@."UB:70*`"`H<')E9"`E<R!D\F%M:2D`("A+;.%V97-O=N$@<VMR871K
M82`E<RD`("AO("5S(&1N[2D`*&1N97,I`"`H>F%J=')A*0`@*';H97)A*0`@
M<OUC:&QO<[L@`"(E<R(@;FEE(&IE(&%D<F5SX7(N`"(E<R(@;FEE(&IE('!L
M871NX2!V;[5B82X`(B5S(B!N:64@:F4@;F%K;VYF:6=U<F]V86[I('8@<F5G
M:7-T<FD@2&]R9&4N`'IO8G)A>F]V8>@@<W1R;VUU("(E<R(@;F5B;VP@;N%J
M9&5N_2X`4VMU<&EN82`B)7,B(&)O;&$@<')I9&%NX2!D;R!S>7-TZ6UU+@!0
M<N%V;R`B)7,B(&)O;&\@<')I9&%NZ2!D;R!S>7-TZ6UU+@`B)7,B(&YE8F]L
M;R!M;[YNZ2!V>71V;W)INSH@)7,N`%!O=;YI=/UC:"`E+C)F34(@>B!D;W9O
M;&5N_6-H("4N,F9-0B`H)2XR9B4E*0`E9"`E<R!A("5S`"5D(&1N[2!D;R!V
M>7!RN6%N:6$@<&QA=&YO<W1I(%;AN6AO(&AE<VQA+@!P<F5D<&]V9>\@;F$@
M)60@9&[M`"5S("T@4&]Z;N%M:V$`3V1T;&'H;VL@)7,`)7,@2T(`3W!E<N%C
M:64@^F1ROF)Y('!R92!A<&QI:^%C:74@)7,@+2!0;W1V<F1E;FEE`$YA<W1A
M=F5N:64@)7,`4F5G:7-T<F]V86YI92!D;R!A<&QI:^%C:64@)7,`4&]D;6EE
M;FMY('!O=;YI=&EA("5S`"5S('6^(&5X:7-T=6IE+@`E<R!V;R!V_;EK92`E
M<R`E<P!!<&QI:^%C:6$@)7,@:F4@<')I<')A=F5NX2!N82!V>6MO;F%N:64@
M;W!E<N%C:>T@^F1ROF)Y+D]Z;F'H=&4@N71V;W+H96L@<')I(&]P97+A8VGA
M8V@L(&MT;W+I(&-H8V5T92!V>6MO;F&[('1E<F%Z+@!0;[YA9'5J92!S82`E
M<P`E<R!M:6[Z=``E<R!N96)O;"!NX6ID96[]+@`E<R!AOB`E<R!Z("5S`$%D
M<F5SX7(@<&]UONUV871EM6$@)7,`2V%L96YDX7(@<&]UONUV871EM6$@)7,`
M4&]Z;N%M:WD@<&]UONUV871EM6$@)7,`6F]Z;F%M(/IL;V@@<&]UONUV871E
MM6$@)7,`)7,Z("5S`"5S.B!4X71O('-P<N%V82!N96UU<^T@8GF[(&]D(&]D
M;W-I96QA=&6U82P@:W1O<OT@<V$@>F]B<F%Z=6IE(&%K;R!O9&]S:65L871E
MM2!S<'+A=GDN(%IA8VAO=F%J=&4@;W!A=')N;W.[('!R:2!K;&EK86[M(&YA
M(&QI;FMY('8@<W!RX79E(&%L96)O('!O<VMY=&]V86[M(&]S;V)N_6-H(&EN
M9F]R;>%C:>T@;V1O<VEE;&%T9;5O=FDN`"P@;N%R87IO=OT@`"P@=B!NX7)A
M>F]C:"`E<R`E<P`L('!R96UE;F[A('8@<F]Z<V%H=2`E<R!AOB`E<P`M+2!V
M>6)E<G1E('-I("TM`#$R+6AO9&EN;W;](&9O<FWA=``R-"UH;V1I;F]V_2!F
M;W)MX70`,C0@:&]D[6X`/%!R961C:.%D>F%J^F-A`%!R92!T96YT;R!B;&]K
M(&IE('!OOF%D;W9A;OT@9&%T86+A>F]V_2!B86-K96YD+@!6>7-K>71L82!S
M82!ZX79AOF[A(&-H>6)A`$YA('IAN6EF<F]V86YI92!S<'+A=GD@:F4@<&^^
M861O=F%N_2!V97)E:F[](%!(4"!KM?KH+@!.82!O=F5R96YI92!P;V1P[7-A
M;F5J('-P<N%V>2!J92!P;[YA9&]V86[]('9E<F5J;OT@4$=0(&NU^N@N`$YA
M(&1EN6EF<F]V86YI92!S<'+A=GD@<_H@<&]T<F5B;NDZ('9E<F5J;OT@4$=0
M(&NU^N@L('!R:7;A=&YY(%!'4"!KM?KH(&$@:&5S;&\N`$YA('!O9'#M<V%N
M:64@<W!RX79Y('/Z('!OOF%D;W9A;NDZ('9R96IN_2!01U`@:[7ZZ"P@<')I
M=N%T;GD@4$=0(&NU^N@@82!H97-L;RX`3F$@9&6Y:69R;W9A;FEE('-P<N%V
M>2!S^B!P;[YA9&]V86[I.B!V97)E:F[](%,O34E-12!KM?KH+"!P<FEVX71N
M>2!3+TU)344@:[7ZZ"!A(&AE<VQO+@!.82!P;V1P[7-A;FEE('-P<N%V>2!S
M^B!P;[YA9&]V86[I.B!V97)E:F[](%,O34E-12!KM?KH+"!P<FEVX71N>2!3
M+TU)344@:[7ZZ"!A(&AE<VQO+@!.82!Z8;EI9G)O=F%N:64@<W!RX79Y(&IE
M('!OOF%D;W9A;OT@=F5R96IN_2!334E-12!KM?KH+@!0<F5D<&]L=61N[6T@
M;V)L8>AN;P!0<F5D<&]L=61N[6T@M6%H:_T@9.&^[P!0<F5D<&]L=61N[6T@
M9.&^[P!0<F5D<&]L=61N[6T@<')E:.%N:WD`4')E9'!O;'5D;NUM('-N96AO
M=ND@<')E:.%N:WD`,3(@:&]D[6X`05!)($E$`$\@=&]M=&\@961I=&]R90!/
M+BXN`$%B<V]L^G1N>2!S<&]D;VL`06)S;VSZ=&YY('-T<F5D`%!R:2!V>71V
MX7)A;NT@5D93(&%D<F5SX7)A(&)O;"!Z86UI971N=73]('!R[7-T=7`N`%!R
M:2!V>71VX7)A;NT@5D93('/Z8F]R=2!B;VP@>F%M:65T;G5T_2!P<NUS='5P
M+@!);F9O<FWA8VEE(&\@^NAT90!(97-L;R!P<F4@^NAE=`#:Z&5T('IA8FQO
M:V]V86[]+@#:Z'1O=F%N:64`4')I9&&[`%!R:61ANR!P;V1R:6%D96[Z('-K
M=7!I;G4`4')I9&&[('!O9')I861E;ND@<'+A=F\`4')I9&&[.@!0<FED8;L@
M<VMU<&EN=0!0<FED8;L@;F]VZ2!P<N%V;P!0<FED8;L@9&/I<G-K=2!S:W5P
M:6YU(&1O("(E<R(`4')I9&&[(&1CZ7)S:V4@<'+A=F\@9&\@(B5S(@!0<FED
M8;L@<&]UONUV871EM6$Z`%!R:61ANR!S=.5P96,`4')I9&&[(.AL96YO=@!0
M<FED8;L@<.%R`%!R:61ANR!M96YU("5S(&%K;R!";^AN_2!P86YE;"!-;WII
M;&QY`%!R:61ANR!D;R!A9')E<^%R83H`4')I9&&[(&1O(&WT:FAO(&%D<F5S
MX7)A`%!R:61ANR!P;W6^[79A=&6U80`B)7,B(&)O;"!P<FED86[](&1O('-Y
M<W3I;74L(&%L92!N96UOOFYO('!R:61ANR#O86RY:64@<')I:&QA<V]V86-I
M92!I;F9O<FWA8VEE.B`E<RX`(B5S(B!B;VP@<')I9&%N_2!D;R!S>7-TZ6UU
M+B!497)A>B!S82!M]+YE=&4@<')I:&SA<VF[+@!0<FEDX79A;FEE('!O=;[M
M=F%T9;5O=B!J92!Z86OA>F%NZ2X`061R97-A`$%D<F5SX7(`061M:6YI<W1R
MX6-I82`M(&YA<W1A=F5N:64@<'+A=B!P<F4@:6[]8V@@<&]UONUV871EM6]V
M`$%D;6EN:7-T<N%C:6$`4F5K;&%M>0!!9F=A;FES=&%N`$%L8N%N<VMO`$%L
MONUR<VMO`$%L:6%S`%IA<F]V;F&[`%IA<F]V;F%N:64Z`%:Y971K>0!6N65T
M8VD@875T96YT:69I:V]V86[M('!O=;[M=F%T96QI80!6N65T:WD@<VMU<&EN
M>0!6N65T:WD@<'+A=F$`5KEE=&MY(+ET>7)I('-T<F%N>0!0;W9O;&F[('9I
M86-E<ND@861R97-Y`%!O=F]L:;L@;F%S=&%V96YI92!T>7!U('IO<F%D96[I
M:&\@>F]Z;F%M=3\`5;X@97AI<W1U:F4`06QT97)N873M=FYE('!R:6AL87-O
M=F%C:64@;65N;R!)35-0`$%L=&5R;F%T[79N92!H97-L;R!)35-0`$%L=&5R
M;F%T[79N92!P;W6^[79A=&6U<VOI(&UE;F\@24U34`!!;'1E<FYA=.UV;F$@
M92UM86EL;W;A(&%D<F5S80!!;'1E<FYA=.UV;F4@N6%B;/-N>0!!;'1E<FYA
M=.UV;GD@=&5X=#H`06UE<FEC:^$@4V%M;V$`0F]L82!Z861A;N$@;F5P;&%T
M;N$@:&]D;F]T80!.87-T86QA(&YE>F[A;6$@8VAY8F$N`$%N9&]R<F$`06YG
M;VQA`$%N9W5I;&QA`$%N;VYY;6[I('!R;WAY`$]D<&]V9>\`06YT87)K=&EK
M80!!;G1I9W5A(&$@0F%R8G5D80!!<&QI:^%C:6$`6F]Z;F%M(&%P;&EKX6-I
M[0!!<&QI:^%C:6$@:F4@<')I<')A=F5NX2X`07!L:6MO=F&[(&YA('!O9')I
M861E;ND@>F1I9;5A;ND@<')I9>AI;FMY`%-C:';A;&F[`%!R:6)L:;YNX2!V
M9;5K;W.[`$%P<NUL`%9EM6MO<[L@87)C:.UV=0!-96YO(&%R8VCM=G4`3F%O
M>F%J(&-H8V5T92!V>6UA>F&[(+YI861O<[L@;R!P<FEH;.%S96YI92`G)7,G
M/P!.86]Z86H@8VAC971E('9Y;6%Z8;L@(B5S(B!A(':Y971K>2!P;V1S:W5P
M:6YY/P!!<F=E;G3M;F$`07)MZ6YS:V\`56UE;FEE`$%R=6)A`$]S=')O=B!!
M<V-E;G-I;VX`07-C:6D@=6UE;FEE`,%Z:6$O4&%C:69I8VO](')E9VGS;@!6
M>;YA9&]V8;L@<&]T=G)D96YI92!P<F5D('9Y:V]N86[M;2!O<&5RX6-I[2#Z
M9'*^8GD_`%!O:W5S(&\@=GEM87IA;FEE(&YE97AI<W1U:OIC96H@<VMU<&EN
M>2X`4&]K=7,@;R!V>6UA>F%N:64@;F5E>&ES='5J^F-E:&\@<'+A=F$N`%!O
M:W5S(&\@^G!R879U(&YE97AI<W1U:OIC96AO('!RX79A+@!0;VMU<R!O(/IP
M<F%V=2!N965X:7-T=6KZ8V5H;R!Z9&EEM6%NZ6AO(&]B:F5K='4N`$%T<FEB
M^G1Y`$%U9W5S=`!!=7-T<N%L:6$`4F%K^G-K;P!!=71H7V-Y<G-Q;#H@4&^^
M861O=F%NZ2!R;WJY[7)E;FEE(&EM87`@;F5B;VQO(&[A:F1E;NDN`$%U=&A?
M8WER=7,Z(&)A8VME;F0@;F5MX2!P;[YA9&]V86[I('-C:&]P;F]S=&DN`$%U
M=&A?8WER=7,Z('!OOF%D;W9A;ND@<F]ZN>UR96YI92!I;6%P(&YE8F]L;R!N
MX6ID96[I+@!!=71H7V9T<#H@<&^^861O=F%NZ2!R;WJY[7)E;FEE($944"!N
M96)O;&\@;N%J9&5NZ2X@4VMO;7!I;'5J=&4@4$A0(',@<')E<.UN8>AO;2`M
M+65N86)L92UF='`N`$%U=&A?:6UA<#H@<&^^861O=F%NZ2!R;WJY[7)E;FEE
M($E-05`@;F5B;VQO(&[A:F1E;NDN`$%U=&A?:W)B-3H@<&^^861O=F%NZ2!R
M;WJY[7)E;FEE(&MR8C4@;F5B;VQO(&[A:F1E;NDN`$%U=&A?;&1A<#H@<')I
M9.%V86YI92!P;W6^[79A=&6U;W8@;FEE(&IE('!O9'!O<F]V86[I('!R92!!
M8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@=GEM87KA=F%N:64@<&]UONUV
M871EM6]V(&YI92!J92!P;V1P;W)O=F%NZ2!P<F4@06-T:79E($1I<F5C=&]R
M>0!!=71H7VQD87`Z('!OOF%D;W9A;ND@<F]ZN>UR96YI92!,1$%0(&YE8F]L
M;R!NX6ID96[I+@!!=71H7VQD87`Z($YE<&]D87)I;&\@<V$@<')I9&&[('!O
M=;[M=F%T9;5A("5S+B!397)V97(@;V1P;W9E9&%L.B``075T:%]L9&%P.B!N
M97!O9&%R:6QO('-A(&]D<W1RX6YINR!P;W6^[79A=&6U82`E<P!!=71H7VQD
M87`Z(&YE<&]D87)I;&\@<V$@86MT=6%L:7IO=F&[('!O=;[M=F%T9;5A("5S
M`$%U=&A?;&1A<#H@86MT=6%L:7KA8VEA('!O=;[M=F%T9;5O=B!N:64@:F4@
M<&]D<&]R;W9A;N$@<')E($%C=&EV92!$:7)E8W1O<GD`075T:%]M8V%L.B!P
M;[YA9&]V86[I(')O>KGM<F5N:64@34-!3"!N96)O;&\@;N%J9&5NZ2X`075T
M:%]S;6)A=71H.B!P;[YA9&]V86[I(')O>KGM<F5N:64@<VUB875T:"!N96)O
M;&\@;N%J9&5NZ2X`075T96YT:69I:^%C:6$@<&]M;V-O=2!)34%0('-E<G9E
M<F$@>FQY:&%L82X`075T96YT:69I:^%C:6$@>FQY:&%L80!!=71E;G1I9FEK
MX6-I82!Z;'EH86QA+B`E<P!397)V97(@4D%$2553('IA;6EE=&]L(&%U=&5N
M=&EF:6OA8VEU+@!!=71E;G1I9FEKX6-I82!P;VUO8V]U($944"!S97)V97)A
M('IL>6AA;&$N`$%U=&5N=&EF:6OA8VEA('!O;6]C;W4@4TU"('-E<G9E<F$@
M>FQY:&%L82X`1&]S='5P;ND@<&]L;[YK>3H`07IE<F)A:F2^86X`0D]&2"!%
M>&-U<V5S`%!O>F%D:64`1F%R8F$@<&]Z861I80!:;.D@:&5S;&\@<')E(&ME
M<F)E<F]S+@!:;.D@<&]UONUV871EM7-KZ2!M96YO('!R92!K97)B97)O<RX`
M0F%H86UY`$)A:')A:FX`0F%N9VQA9.FY`$)A<F)A9&]S`%!R:67H:6YO:R!S
M(&=R869I:V]U("(E<R(@;F5B;VP@;N%J9&5N_2X`6N%K;&%D;OT@<FEA9&]K
M`$)I96QO<G5S:V\`0F5L9VEC:V\`0F5L:7IE`$)E;FEN`$)E<FUU9'D`0G5T
MX6X`3F%R;V1E;FEN>0!";&]K("(E<R(@87!L:6OA8VEE("(E<R(@;F5B;VP@
M;N%J9&5N_2X`3F%S=&%V96YI82!B;&]K=0!4>7`@8FQO:W4`5'7H;ND`0F]L
M[79I80!:X6QOOFMY`$]K<F%J`*GM<FMA(&]K<F%J83H`3VMR86IE`$)O<VYA
M(&$@2&5R8V5G;W9I;F$`3V)E`$)O='-W86YA`$)O='1O;0!";W5V970@27-L
M86YD`$)R87KM;&EA`$)R:71S:^D@^GIE;6EE('8@26YD:6-K;VT@;V-EX6YE
M`$)R=6YE:2!$87)U<W-A;&%M`$)U;&AA<G-K;P!:;WIN86T@<R!O9'+AOFMA
M;6D`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!$:7-T<FEB=>ANZ2!B
M;V1Y($-23`!6;&%S=&YO<W1I(%]B=6YK>2XN+@!);F-I86QI>N%C:6$@=GER
M;W9NX79A8V5J('!A;>1T:2!N96)O;&$@9&]K;V[H96[A+@!+86QE;F3A<@!"
M97IV971R:64`2V%M8F]DOF$`2V%M97)U;@!.97!O9&%R:6QO('-A(&%U=&]M
M871I8VMY(&]B;F]V:;L@:&5S;&\L(&MO;G1A:W1U:G1E('-V;VIH;R!A9&UI
M;FES='+A=&]R82X`3F5P;V1A<FEL;R!S82!Z87#M<V&[(&1O('/Z8F]R=2`B
M)7,B`$YE;6^^;F\@861M:6ES=')O=F&[(&5X=&5R;ND@;W9LX61AZ&4@<V5D
M96[M+@!.97!O9&%R:6QO('-A('-P;VIINR!S($E-05`@<V5R=F5R;VTZ("5S
M`$YE<&]D87)I;&\@<V$@;W1V;W)INR!S^F)O<B`B)7,B+@!+86YA9&$`6G)U
MN6F[`%IR=;EINR!S<'+A=G4@;R!P<F]B;.EM90!.97!O9&%R:6QO('-A('9Y
M;6%Z8;L@<_IB;W(@(B5S(BX`3F5P;V1A<FEL;R!S82!NX6ISNR!D;^AA<V[]
M(&%D<F5SX7(N`$YE;6^^;F\@<&]K<F'H;W9ANR!B97H@<&%R86UE=')A("=T
M87)G971&:6QE)RX`3F5P;V1A<FEL;R!S82!O9'-T<N%N:;L@861R97/A<B`B
M)7,B+@!.96UOOFYO(&]D<W1RX6YINRP@97AI<W1U:F4@)60@;F%S;&5D;W9N
M[6MO=BX`3F5M;[YN;R!P<F5U<W!O<FEA9&&[+"!P;^AE="!P;VQOOFEE:R!P
M<F4@<')E=7-P;W)I861A;FEE(&YE<_IH;&%S[2!S('!OZ'1O;2!U;&^^96[]
M8V@@<&]L;[YI96LN`$YE<&]D87)I;&\@<V$@<VUE<F]V8;L@<W!RX79U(&YA
M('5RZ&5NZ2#H[7-L;RX`2V%P=F5R9'-KZ2!O<W1R;W9Y`%1I='5L;VL`2V%T
M96?S<FEE(&$@<&]P:7-K>0!+86IM86YS:^D@;W-T<F]V>0!-;V)I;&[]('1E
M;&5F\VX`5FQA<W1N;W-T:2!B=6YK>0!6>7!L;F5N:64@8G5N:WDZ`%9L87-T
M;F]S=&D@8G5N:WD`4F]Z;W-T=7`@8G5N:65K.@!-;V)I;&[]('1E;&5F\VX`
M1&\@<W1R961U`%-T<F5D;V%F<FEC:^$@<F5P=6)L:6MA`%!O9')O8F[I(&EN
M9F]R;>%C:64@;R!C97)T:69I:^%T90!6;&%S=&[M:R!C97)T:69I:^%T=0!0
M;VQI=&EK>2!P<F4@8V5R=&EF:6OA='D`R&%D`%IM96YINP!:;65N:;L@5F&Y
M92!H97-L;P!.87-T879E;FEE(&UE;F$@82!A9')I97,L(&MT;W+I('9I9&EA
M(+5U9&EA+"!K9>\@Z.UT86KZ(&$@;V1P;W9E9&%J^B!N82!68;EE(&4M;6%I
M;'DN`%IM96YA(&AE<VQA(&YI92!J92!V(&%K='7A;&YE:B!K;VYF:6=U<N%C
M:6D@<&]D<&]R;W9A;N$N("!+;VYT86MT=6IT92!S=F]J:&\@861M:6YI<W1R
MX71O<F$N`%IN86L`4U]K;VYT<F]L;W9ANR!L:6YK=2XN+@!#:&EL90#([6YA
M`%9Y8F5R=&4@87!L:6OA8VEU.@!:=F^U=&4@<VD@:&5S;&\`6G9OM71E('-I
M('!O=;[M=F%T9;5S:^D@;65N;P!6>6)E<G1E('-P]'-O8B!Z;V)R87IO=F%N
M:6$@9.%T=6UO=CH`5GEB97)T92!T>7`@N73];'4@>F]Z;F%M=2`H<')E('IO
M<F%D96[I('IO>FYA;7DI`%9I86YOZ&[](&]S=')O=@!$969I;NUC:6$@=')I
M961Y("5S(&YE8F]L82!NX6ID96[A+@!*87-N;P!/9'-T<N%N:;L@<'+M:V%Z
M>2!-4T]F9FEC90!6>6UA>F&[(&1O=&%Z`$]D<W1RX6YINR!P;W6^[79A=&6U
M83H@)7,`3V1S='+A;FF[('!O=;[M=F%T9;5A`%9Y;6%Z8;L@<&]UONUV871E
MM7-KZ2#Z9&%J90!.97-K]'(@=GEJ87-N96YI90!+;&EK;FET92!P<F4@<&]K
M<F'H;W9A;FEE`$-L:6-K871E;&P@8V5Z($A45%``6F%T=F]R:;L@;VMN;P!/
M8FQA:WD`4N%N;R!O8FQAZ&YO`$]B;&'H;F\`0V]C;W,@*$ME96QI;F<I($ES
M;&%N9',`6F)A;&F[($)OZ&[]('!A;F5L`%IB86QE;ND@;VMR86IE`$MO;'5M
M8FEA`$9A<F)A`%;]8F5R(&9A<F)Y`%;]8F5R(&9A<F)Y`%-TY7!C93H`3F%D
M<&ES>2!S=.5P8V]V`$MO;6EK<P!0<NUK87H`4'+M:V%Z;W;](&EN=&5R<')E
M=&5R`$MO;65N=.%R`$)EOF[I(&UE;F\`2V]M;W)Y`%-P;VQOZ&YO<[L`4&_H
M[71AZ&4`4W1A=@!3=&%V`%)O>F1I96QY('8@:V]N9FEG=7+A8VEI`$MO;F9I
M9W5RX6-I82!P<F4@<WEN8VAR;VYI>N%C:74@<R!01$$L(&EN=&5L:6=E;G1N
M_6UI('1E;&5F\VYM:2!A($]U=&QO;VMO;2X`2V]N9FEG=7+A8VEA('!O=')E
M8G5J92!A:W1U86QI>N%C:74N`$MO;F9I9W5R;W9ANR`E<P!0;W1V<N]T92!H
M97-L;P!+;VYG;P!$96UO:W)A=&EC:^$@<F5P=6)L:6MA($MO;F=O`%-P;VIE
M;FEE('IL>6AA;&\N`%-P;VIE;FEE('IL>6AA;&\Z(`!+M?KH(&)O;"!Z86UI
M971N=73]('-E<G9E<F]M('9E<F5J;OUC:"!KM?KH;W8N`$NU^N@@8F]L('IA
M;6EE=&YU=/T@<V5R=F5R;VT@=F5R96IN_6-H(&NU^NAO=BX@1/1V;V0Z("5S
M("@E<RD`4W!O:F5N:64@<R!&5%`@<V5R=F5R;VT@>FQY:&%L;RX`2V]N=&%K
M='D`2V]N=&%K='D@8F]L:2#Z<W!EN6YE('9L;[YE;N$@9&\@5N&Y:&\@861R
M97/A<F$N`%1Y<"!K;VUP<FEM;W9A;NEH;R!S^F)O<G4Z`$]B<V%H("(E<R(`
M4&]K<F'H;W9ANP!#;V]K;W9E(&]S=')O=GD`0V]O:VEE`$MO<.UR;W9ANP!+
M;W#M<F]V86YI92!Z;'EH86QO.B`E<P!+;W#M<F]V8;L@=OUB97(`2V]S=&%R
M:6MA`%!O8G)EOFEE('-L;VYO=FEN>0!.97!O9&%R:6QO('-A('IAN6EF<F]V
M8;L@<W!RX79U('!O;6]C;W4@4$=0.B``3F5P;V1A<FEL;R!S82!P;V1P[7-A
MNR!S<'+A=G4@<&]M;V-O=2!01U`Z(`!.97!O9&%R:6QO('-A('IAN6EF<F]V
M8;L@<W!RX79U('!O;6]C;W4@4R]-24U%+@!.97!O9&%R:6QO('-A('!O9'#M
M<V&[('-P<N%V=2!P;VUO8V]U(%,O34E-12X`3F5P;V1A<FEL;R!S82!P<FED
M8;L@:V]N=&%K="X@)7,N`$YE<&]D87)I;&\@<V$@<')I<&]J:;L@:R!,1$%0
M('-E<G9E<G4N`$YE<&]D87)I;&\@<V$@<')I<&]J:;L@:R!,1$%0('-E<G9E
M<G4`3F5P;V1A<FEL;R!S82!O=F5R:;L@>F]S=&%T;VL@;F$@^NAT92X@)7,`
M3F%S=&%L82!C:'EB82!P<FD@<'+M<W1U<&4@:R!,1$%0('-E<G9E<G4`3F5P
M;V1A<FEL;R!S82!P<FEP;VIINR!K('-E<G9E<G4@(B5S(B!P;VUO8V]U($94
M4#H@)7,`3F5P;V1A<FEL;R!S82!V>71V;W)INR!Z;WIN86T@<'+M:F5M8V]V
M+B`E<P!.97!O9&%R:6QO('-A(&1EN6EF<F]V8;L@4$=0(/ID86IE.B``3F5P
M;V1A<FEL;R!S82!D9;EI9G)O=F&[(%,O34E-12#Z9&%J92X`3F5P;V1A<FEL
M;R!S82!V>6UA>F&[(&MO;G1A:W0N("5S`$YE<&]D87)I;&\@<V$@=GEM87IA
MNR!Z;WIN86T@<'+M:F5M8V]V+B`E<P!.97!O9&%R:6QO('-A('9Y;6%Z8;L@
M<VMR:7!T(&YA('5P9W)A9&4@:V]N9FEG=7+A8VEE("(E<R(N`$YE<&]D87)I
M;&\@<V$@=7+H:;L@92UM86EL;W;Z(&%D<F5S=2!P<NUJ96UC=2X`3F5P;V1A
M<FEL;R!S82!S=&EA:&YUNR!C96S](&%D<F5SX7(N`$YE<&]D87)I;&\@<V$@
M>NUS:V&[(&MO;7!L971N_2!Z;WIN86T@<'+M:F5M8V]V+@!.97!O9&%R:6QO
M('-A('KM<VMANR!K;VUP;&5T;OT@>F]Z;F%M('IO>FYA;6]V('!R[6IE;6-O
M=BX`3F5P;V1A<FEL;R!S82!N8>CM=&&[('-T<F%TZ6=I=2`B)7,B+@!.97!O
M9&%R:6QO('-A('-P=7-T:;L@;6MD:7(@(B5S(BX`3F5P;V1A<FEL;R!S82!Z
M[7-K8;L@=F5R96IN_2!KM?KH('IO('-E<G9E<F$@:[7ZZ&]V+@!.97!O9&%R
M:6QO('-A(&]T=F]R:;L@(B5S(B!P<F4@>N%P:7,N`$YE<&]D87)I;&\@<V$@
M;W1V;W)INR`E<RX`3F5P;V1A<FEL;R!S82!O='9O<FF[(&UO9'5L($UA:6YT
M96YA;F-E7U1A<VL@)7,`3F5P;V1A<FEL;R!S82!O='9O<FF[(&%D<F5SX7(@
M(B5S(BX`3F5P;V1A<FEL;R!S82!P<FEP;VIINR!N82!,1$%0('-E<G9E<BX`
M3F5P;V1A<FEL;R!S82!P<F7H[71ANR`E<RX`3F5P;V1A<FEL;R!S82!O8FYO
M=FF[(&AE<VQO('IA9&%NZ6AO('!O=;[M=F%T9;5A+B!.:65K=&]RZ2!A;&5B
M;R!VN65T:WD@<&]D<F]B;F]S=&D@;FEE('/Z('-P<N%V;F4N(%-K^G-T92!T
M;R!Z;F]V=2!A;&5B;R!K;VYT86MT=6IT92!6X;EH;R!A9&UI;FES='+A=&]R
M82P@86L@<&]T<F5B=6IE=&4@<&]M;V,N`$YE;6^^;F\@>NUS:V&[($%#3`!.
M97!O9&%R:6QO('-A('KM<VMANR!A9')E<^%R+B`E<P!.97!O9&%R:6QO('-A
M('KM<VMANR!Z;WIN86T@<'+M:F5M8V]V+B`E<P!.97!O9&%R:6QO('-A('KM
M<VMANR!Z;WIN86UY('!R[6IE;6-O=B`E<P!.96UOOFYO('KM<VMANR!I;F9O
M<FWA8VEE(&\@=FQA<W1N;W-T:6%C:"!S97)V97)A`$YE<&]D87)I;&\@<V$@
M=G+A=&F[(&MO;F9I9W5RX6-I=2X`3F5P;V1A<FEL;R!S82!S<'5S=&F[(')M
M9&ER("(E<R(N`$YE<&]D87)I;&\@<V$@=6QOOFF[(&MO;F9I9W5RX6-I=2`E
M<RX`3F5P;V1A<FEL;R!S82!U;&^^:;L@>N%L;VAU(&MO;F9I9W5RX6-I92X`
M3F5P;V1A<FEL;R!S82!U;&^^:;L@>N%L;VAU(&MO;F9I9W5RX6-I93H@)7,`
M3F5P;V1A<FEL;R!S82!U;&^^:;L@<VMR:7!T(&YA('5P9W)A9&4@;F%S=&%V
M96[M(&1O.B`B)7,B+@!.97!O9&%R:6QO('-A('5L;[YINR!ZX6QO:'4@:V]N
M9FEG=7+A8VEE("5S+@!.97!O9&%R:6QO('-A('IA<.US8;L@:V]N9FEG=7)A
MZ&[]('/Z8F]R("5S+B!-]+YE=&4@<&]UOFF[(&YI96MT;W+Z('H@;6^^;F]S
M=.T@;F$@>N%P:7,@:_-D=2!N82`E<R!A;&5B;R!S:V]P[7)O=F&[(')UZ&YE
M(&OS9"!U=F5D96[](&YIOKEI92!D;R`E<RX`3F5P;V1A<FEL;R!S82!HM6%D
M8;L@;F$@3$1!4"!S97)V97)I+@!.97!O9&%R:6QO('-A('9Y;6%Z8;L@(B5S
M(BX`3F5P;V1A<FEL;R!S82!A:W1U86QI>F]V8;L@:V]N=&%K="X@)7,`3F5P
M;V1A<FEL;R!S82!A:W1U86QI>F]V8;L@>F]Z;F%M('!R[6IE;6-O=BX@)7,`
M3F5P;V1A<FEL;R!S82!Z87#M<V&[(&MO;F9I9W5RX6-I=2!P<F4@(B5S(CH@
M)7,`3F5M;[YN;R!NX6ISNR!";^AN_2!P86YE;"!-;WII;&QY+B!3:V]N=')O
M;'5J=&4L(+YE(&IE('!A;F5L(&]T=F]R96[]+@!0;W6^[79A=&6U;W9I("(E
M<R(@<V$@;F5P;V1A<FEL;R!P<FED8;L@<'+A=F$@<')E('!R:67H:6YO:R`B
M)7,B.B`E<P!0;^CM=&%N_2!T97AT`$MR86II;F$`2W5R>GD`5GET=F]R:;L`
M5GET=F]R:;L@;&EN:W4`5GET=F]R:;L@;F]V_0!6>71V;W)INR!P;V1P<FEE
MZ&EN;VL`4'+A=F$@='9O<F-U`,CM<VQO(&MR961I=&YE:B!K87)T>0!#:&]R
M=N%T<VMO`$MU8F$`06MT=>%L;F4@-"!FX7IY`$%K='7A;&YE('-E9&5N:6$`
M06MT=>%L;GD@Z&%S`$%K='7A;&YA(%523"!J90!!:W1UX6QN:2!P;W6^[79A
M=&5L:6$`06MT=>%L;F4@<&_H87-I90!!:W1UX6QN92!P;V1M:65N:WDZ(`!!
M:W1UX6QN>2"Y=/UL`$YA<W1A=F5N:64@^FQO:"P@:W1O<ND@<V$@<W#ZN;MA
M:OH@<')I('!R:6ALX7-E;NT@9&\@87!L:6OA8VEE("5S+@!6>7-T<FEH;OJ[
M`%9Y<W1R:6AN^KL@=OUB97(`0WEP<G5S`,AE<VOA(')E<'5B;&EK80!$1`!$
M4TX@*'!O>G)I(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA
M9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"D`1&5N;F4`4')E>F5R8>@@
M9.%T;W;I:&\@<W1R;VUU("A$871A5')E92D`5GEHM6%DX79A;FEE('8@9&%T
M86+A>F4`1.%T=6T`1.%T=6T@<')I:F%T:6$`5OUB97(@9.%T=6UU`$1E\@!/
M7V1S='+A;FF[('-TY7!E8P!$96-E;6)E<@!$97-I871K;W;I(.CM<VQA`%IM
M96ZY:;L@;V1S861E;FEE`%!R961N87-T879E;ND`4')E9&YA<W1A=F5NX2!F
M87)B80!68;EA('!R961N87-T879E;N$@:61E;G1I=&$`4')E9&YA<W1A=F5N
M_2!P<NUK87IO=OT@:6YT97)P<F5T97(`1&5F:6[M8VEE`%9Y;6%Z8;L`5GEM
M87IANR!B=6YK=0!6>6UA>F&[('-K=7!I;G4`5GEM87IANR!ZX7IN86T`5GEM
M87IANR!P<N%V;P!6>6UA>F&[(&$@;V1S='+A;FF[('-P<N%V>0!6>6UA>F&[
M(&)U;FMU`%9Y;6%Z8;L@<W3E<&5C`%9Y;6%Z8;L@97AI<W1U:OIC=2!A;'1E
M<FYA=.UV;G4@N6%B;/-N=0!6>6UA>F&[('!RX79A('!R92`B)7,B`$-H8V5T
M92!V>6UA>F&[("(E<R(@82!VN65T:WD@:F5H;R!P;V1P<N%V83\`5GEM87IA
MNR!R:6%D;VL`5GEM87IANR!V>6)R86[Z(&ED96YT:71U`%9Y;6%Z8;L@86MT
M=>%L;GD@<W3E<&5C`%9Y;6%Z8;L@86MT=>%L;GD@<FEA9&]K`%-K<FEP="!N
M82!U<&=R861E(&MO;F9I9W5RX6-I92`B)7,B(&)O;"!V>6UA>F%N_2X`R&%S
M(&1O<G7H96YI80!$X6YS:V\`4&]P[;ET92!P<F]B;.EM`%!O<&ES`%!O9')O
M8FYO<W1I("AT:66^('8@;&]G;W9A8V]M('/Z8F]R92!(;W)D92D`1&5T86EL
M>2!B;VQI('IA>FYA;65N86[I('!R92!A9&UI;FES='+A=&]R82X`5OUV;VH`
M4F]S;OT@8F]D`%)O<V[](&)O9"!Z82!P;W-L961N^B!H;V1I;G4Z(`!2;W-N
M_2!B;V0Z(`!3;65R('JU879A(&1O<')A=F$`4VUE<B!S<')A=F$@9&^U879A
M`$%D<F5SX7(`6F]B<F%Z;W9ANR#H87,@=B`R-"UH;V1I;F]V;VT@9F]R;>%T
M93\`3F%S=&%V96YI92!Z;V)R87IE;FEA`%IO8G)A>FF[('!O9')O8F[Z('!R
M961P;W9E[P!:;V)R87IINR!P<F5D<&]V9>\@*%1!1BD`1F]R;>%T('IO8G)A
M>F5N:6$`4&]T=G)D96YI92!O(&1O<G7H96[M`$2^:6)U='-K;P!.979Y;6%Z
M8;L`3F5P;W6^[79A:G1E('!R:6%M;R!M86EN=&5N86YC92YP:'``3V)S86AU
M:F4@<')V_2!R:6%D;VL@;N%Z=GD@<&]L[3\@06L@X6YO+"!Z8;EK<G1N:71E
M('!O;.WH:V\Z(`!$;VUI;FEC80!$;VUI;FEKX6YS:V$@<F5P=6)L:6MA`$YE
M;>%T92#ZZ&5T/R!:87)E9VES=')U:G1E('-A+@!3=&EA:&YUNP!3=&EA:&YU
MNR`E<P!3=&EA:&YUNR!V>6=E;F5R;W9A;OH@:V]N9FEG=7+A8VEU(&%K;R!0
M2%`@<VMR:7!T+@!:;WIN86T@<R!V_6)E<F]M`$1R;V=Y`$4M;6%I;`!%4E(`
M16MVX61O<@!5<')A=FF[`%5P<F%V:;L@8FQO:P!5<')A=FF[('-K=7!I;G4`
M57!R879INR!P<N%V;P!5<')A=FF[('!RX79A`%5P<F%V:;L@<'+A=F$@<')E
M("5S`%5P<F%V:;L@;F%S=&%V96YI82!P<F4Z`%5P<F%V:;L@<'+A=F$@<')E
M("(E<R(`57!R879INR!P<N%V82!P<F4@)7,`5GID96SA=F%N:64`16=Y<'0`
M4V%L=N%D;W(`16QE;65N="XN+@!%;0!%;6%I;`!%;6%I;&]VX2!A9')E<V$Z
M`$4M;6%I;&]VZ2!A9')E<WD@;75S:6$@8GF[(')O=FYA:^DN`$4M;6%I;"!S
M('!O='9R9&5N[6T`0G+A;F$@16UA:6PM;F$M4TU3`$5M;W1I:V]N>0!0<N%Z
M9&YA('-P<N%V82X`4'+A>F1N>2!V_7-L961O:RX`4'+A>F1N92!P;V1M:65N
M:WD@:+5A9&%N:6$`4&]V;VQINR!V;&^^96YI92!O8G+A>FMO=B!Z($=A;.ER
M:>T@9&\@=&5X='4_`%!O=F]L:;L@:V]N=&5X=&]VZ2!M96YU('!R92!P<F%V
MZ2!T;&'H:61L;S\`2V]N:65C(')O:V$`6G;DZ+EINR!E9&ET;W(`6F%D86IT
M92!B97IP9>AN;W-T;OH@;W3A>FMU+"!N82!K=&]R^B!B=61E=&4@;75S:66[
M(&]D<&]V961ANR!A:R!Z86)U9&YE=&4@:&5S;&\L(&YA<'(N("=A:V\@<V$@
M=F]LX2!M;VIE('IV:65R871K;S\G.@!:861A:G1E(%523"!O8G+A>FMA`%IA
M9&%J=&4@<.US;65NX2!U=F5D96[I(&YIOKEI93H`4F]V;NUK;W;A($=U:6YE
M80!%<FET<F5A`$-H>6)A`$-H>6)A('!R:2!V>71VX7)A;NT@8FQO:W4Z("5S
M`$-H>6)A('!R:2!V>6UA>N%V86[M('5K;W1V96YI82!S>6YC:')O;FEZX6-I
M93H@)7,`0VAY8F$@<')I('9Y;6%ZX79A;NT@>N%Z;F%M=2!S>6YC:')O;FEZ
MX6-I93H@)7,`0VAY8F$@<')I('KM<VMA=F%N[2!O8G-A:'4Z("5S`$-H>6)A
M('!R:2!A:W1U86QI>N%C:6D@:&5S;&$Z("5S`$-H>6)A('8@92UM86EL;W9E
M:B!S<'+A=F4N`$-H>6)A('!R:2!Z87!I<V]V86[M("(E<R(N`$5S=/-N<VMO
M`$5T:?-P:6$`171N:6-KZ0!%=7+S<&$`2V&^9/UC:"`Q-2!M:6[Z=`!+8;YD
MZ2`R(&UI;OIT>0!+8;YD_6-H(#,P('-E:_IN9`!+8;YD_6-H(#4@;6EN^G0`
M4')I(&MAOF1O;2!P<FEH;.%S96[M`$MAOF3Z('!O;&AO9&EN=0!+8;YD^B!M
M:6[Z='4`3F%P<NUK;&%D.@!3<'5S=&F[`%)O>F)A;&F[`%)O>F)A;&F[($)O
MZ&[]('!A;F5L`$_H86OA=F$@<V$@)RDG`$_H86OA=F$@<V$@<VQO=F\@86QE
M8F\@<&]D;6EE;FMA(&BU861A;FEA('8@^G9O9'IO=FOA8V@`1.%T=6T@97AP
M:7+A8VEE`$5X<&]N96YT`$9A<F)A('1E>'1U`$YA:')ANR!K;VYF:6=U<N%C
M:74@;F$@1E10`$YE<&]D87)I;&\@<V$@>NUS:V&[(&YA<W1A=F5N:6$N`$YA
M<W1A;&$@8VAY8F$@<')I('-P;VIE;NT@<R!,1$%0('-E<G9E<F]M+@!.87-T
M86QA(&-H>6)A('!R:2!P<NUS='5P92!K(%--0B!S97)V97)U+@!.97!O9&%R
M:6QO('-A(&MO<.UR;W9ANR!Z("(E<R(N`$YE<&]D87)I;&\@<V$@:V]P[7)O
M=F&[(&1O("(E<R(N`$YE<&]D87)I;&\@<V$@=GET=F]R:;L@;F]VZ2!305-,
M('-P;VIE;FEE+@!.97!O9&%R:6QO('-A('!R97-U;OJ[(&1O("(E<R(N`$YE
M<&]D87)I;&\@<V$@>NUS:V&[.B`E<P!$;V)RZ0!&86QK;&%N9'-KZ2!O<W1R
M;W9Y("A-86QV[6YY*0!&865R<VOI(&]S=')O=GD`6N%V8;YNX2!C:'EB83H`
M1F%X`$9A>'D`1F5B<G7A<@!0;V-I="!T97!L;W1Y`%!O8VET('1E<&QO='DZ
M(`!-86SI('IRX;YK>0!-86SI('-N96AO=ND@<')E:.%N:WD`36%T:6-A('!O
M;.T`1FEDOFD`4_IB;W(`4&_H970@<_IB;W)O=CH@)7,@<_IB;W(`4&_H970@
M<_IB;W)O=CH@)7,@<_IB;W)O=@!3<'+A=F-A('/Z8F]R;W8`365N;R!S^F)O
M<G4`5OUB97(@<_IB;W)U`$YA:')A=&EE('/Z8F]R=0!.86ARX79A;FEE('/Z
M8F]R;W8@;FEE(&IE('!O9'!O<F]V86[I+@!&:6QT<F4`1NUN<VMO`%!R=N$@
M<&]L;W9I8V$`4')VX2"Y='9RNP!0979N_2!P;VUE<@!/=&_H:;L`4&SA=F%J
M^F-I('1E>'0`2&UL80!0<FEEZ&EN;VL@)7,@;F5E>&ES='5J90!&87)B82!P
M[7-M80!0;W1R879A`%!R92!P<F5H;&EA9&'H92P@:W1O<ND@;F5P;V1P;W)U
M:OH@;V)RX7IK>0!0<F5D<&]V9>\@*%1!1BD`4')E9'!O=F7O(&YA('5V961E
M;OT@<&_H970@9&[M("AP86WD=&%J=&4@;F$@=&\L(+YE('!R961P;W9E[R!J
M92!P<F4@9&YI(&%J(&YO8VD@82!T86L@;?2^92!V9;5KZ2#H[7-L;R!V>71V
M;W)INR!V9;5M:2"Y:7)O:_T@8FQO:RD`6F%B=61L:2!S=&4@:&5S;&\_`$9O
M<FUU;.%R90!&;W)T=6YA`%1Y<"!F;W)T=6YY`$9O<G1U;GD`1F]R='5N>2`R
M`$;S<F$`4')E<VUE<F]V86YI80!0:6$`4N%M8V4`1G)A;F/Z>G-K;P!&<F%N
M8_IZ<VMO("A%=7+S<&$I`$9R86YC^GIS:V$@1W5A>6%N80!&<F%N8_IZ<VMA
M(%!O;'ENZ7II80!&<F%N8_IZ<VME(&IUOF[I('1E<FET\W)IX0!/9`!:;R!S
M;65R=2``VG!L;OT@<&]P:7,`4W!L;@!#96SI(&UE;F\Z`$=A8G5N`$=A;.ER
M:6$L('H@:W1O<F5J(&-H8V5T92!V>FEANR!O8G+A>F]K`$=A;.ER:6$Z`$=A
M;6)I80!'96YE<F]V8;L@:V]N9FEG=7+A8VEU('!R92!A<&QI:^%C:74@)7,`
M1V5N97)O=F%N_2!K\V0`1V5O<F=I80!.96UE8VMO`$=H86YA`$=I8G)A;'3A
M<@!+<G-T;ND@;65N;P!/9&]S;&&[`$=O961E;`!';V]G;&4@36%P<P!(M6%D
M8;L@;F$@1V]O9VQE`$]D=&EE;F4@N65D96H`1W+I8VMO`$=R\VYS:V\`1W)E
M;F%D80!!9&UI;FES='+A8VEA('-K=7#M;@!-96[A('-K=7#M;B!N97-M^B!B
M>;L@<'+A>F1N90!'<F]U<%]L9&%P.B!.97!O9&%R:6QO('-A('!R:61ANR!S
M:W5P:6YU("5S+B!397)V97(@;V1P;W9E9&%L.B``1W)O=7!?;&1A<#H@;F5P
M;V1A<FEL;R!S82!V>6UA>F&[('-K=7!I;G4@)7,`1W)O=7!?;&1A<#H@;F5P
M;V1A<FEL;R!S82!A:W1U86QI>F]V8;L@<VMU<&EN=2`E<P!3:W5P:6YY`$=U
M861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`4'+A=F$@86YO;GEM
M;OUC:"!P;W6^[79A=&6U;W8`1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M0FES
M<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A(&YE9&]V;VSM('9Y;6%Z8;L@<&]S
M;&5D;OH@8G5N:W4@=B!R:6%D:W4N`$A434Q!<F5A(&YE9&]V;VSM('9Y;6%Z
M8;L@<&]S;&5D;OT@<W3E<&5C('8@=&%B=;5K92X`2%1-3$%R96$@;F5D;W9O
M;.T@=GEM87IANR!P;W-L961N_2!R:6%D;VL@=B!T86)UM6ME+@!(5%10(&%U
M=&5N=&EF:6OA8VEA(&YE8F]L82!NX6ID96[A+@!(86ET:0!!;&=O<FET;75S
M(&AA<VAO=F%C96H@9G5N:V-I90!/<&%R`$AL879IZ&MA`$AL879IZ&MY`$AE
M87)D;W8@;W-T<F]V(&$@36-$;VYA;&1O=F4@;W-T<F]V>0!3:6QNX2!B^G)K
M80!6_;EK80!0;VUO8V[M:P!0;VUO8V[M:R!P<F4@<&]UONUV86YI92!E9&ET
M;W)A`%!O;6]C;NUK`%!O;&]G=;5A`%1U(&IE('IAZ&EA=&]K('/Z8F]R=3H`
M5GES;VOA`$1O7VUO=@!6871I:^%N`$1O;6]V`$1O;>%C82!A9')E<V$`1&]M
MX6-I('!R:67H:6YO:P!496QE9O-N(&1O;6]V`$AO;F1U<F%S`$AO;F<@2V]N
M9P!(;W)D90!(;W)D92]+;VQA8CH@=B!S<'+A=F4@)7,@8F]L:2!NX6ID96[I
M(&YE<&QA=&[I("5S(%A-3"#Z9&%J90!(;W)D92]+;VQA8CH@<R!O8FIE:W1O
M;2`E<R!N96MO<F6Y<&]N9'5J92"^:6%D;F$@<W!RX79A+@!(;W)D92]+;VQA
M8CH@=B!S<'+A=F4@)7,@;F5B;VP@;N%J9&5N_2"^:6%D96X@;V)J96MT('1Y
M<'4@)7,`2&]R9&4O2V]L86(Z(/IS<&6Y;F4@;V1S='+A;F5NZ2`E<R`B)7,B
M`$AO<F1E+TMO;&%B.B!I;G1E9W+A8VEA('9YOF%D=6IE(%!(4"!R;WJY[7)E
M;FEE("=D;VUX;6PG`$AO<F1E+TMO;&%B.B!N97!O9&%R:6QO('-A('9Y='9O
M<FF[(&YO=OT@6$U,('-T<F]M('!R92!O8FIE:W0@)7,`2&]R9&4O2V]L86(Z
M(&YE<&]D87)I;&\@<V$@;V1S='+A;FF[("5S("(E<R(Z("5S`$AO<F1E+TMO
M;&%B.B!N97!O9&%R:6QO('-A('KM<VMANR!-24U%($E$('!R92#H87.[('1Y
M<'4@)7,`2&]R9&4O2V]L86(Z(&YE<&]D87)I;&\@<V$@<WEN8VAR;VYI>F]V
M8;L@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(&YE<&]D87)I;&\@<V$@<WEN
M8VAR;VYI>F]V8;L@>F1I9;5A;ND@;V)J96MT>3H@)7,`2&]R9&4O2V]L86(Z
M(&YE>F[A;7D@>F1I9;5A;OT@;V)J96MT("(E<R(`2&]R:7IO;G3A;&YA(.AI
M87)A`$AO<FEZ;VYTX6QN92!V>7!L;F5N:64`2&]R:7IO;G3A;&YE.@!!:V\@
M<W1E('-A('-E;2!D;W-T86QI/R`H4')O<^UM(&YA:&SA<W1E(2D`2V^U:V\@
M<W3E<&-O=B!C:&-E=&4@>FSZZ&F[/P!:861A:G1E('!OZ&5T('!O;.T@*'-T
MY7!C;W8I/P!+;[5K;R!R:6%D:V]V(&-H8V5T92!Z;/KH:;L_`%9L:&MO<[L`
M5FQH:V]SNSH@`$AU;6]R:7-T:0!-8>]A<G-K;P!.97!O9&%R:6QO('-A('9Y
M='9O<FF[($E-05`@<V-H<N%N:W4Z("5S`$YE<&]D87)I;&\@<V$@=GEM87IA
MNR!)34%0('-C:'+A;FMU.B`E<P!.97!O9&%R:6QO('-A('9Y='9O<FF[($E-
M05`@:W;S='4Z("5S`$E0(&%D<F5S80!)4"!A9')E<V$@;FEE(&IE(&1O<W1U
M<&[A+@!)4"!A9')E<V$@;FEE(&IE('8@<N%M8VD@9&]V;VQE;NEH;R!#2412
M(&)L;VMU+@!0;W)UN65N:64@<')A=FED;&$@;R!P979N96H@25`@861R97-E
M+@!6;&^^:;L@:[7ZZ"!?<')E9`!)<VQA;F0`26)A(&EK;VYY`$EK;VYY('!R
M92`E<P!):V]N>2!A('1E>'0`3N%Z;W8@:61E;G1I='DZ`$%K('-A(&YE>F]B
M<F%Z[2!K;W)E:W1N92P@)7,@82!O='9O<NT@<V$@=B!N;W9O;2!O:VYE+@!!
M:R!N979I9.UT92!P<FD@<&]UOFET[2!);G1E<FYE="!%>'!L;W)E<F$@OFEA
M9&YE(&EK;VYY+"!P;W1R96)U:F5T92!Z8;EK<G1N^KL@=/IT;R!V;[5B=2!P
M<F4@=GEP;G5T:64@<')I97-V:71N;W-T:2!03D<@;V)RX7IK;W8N`$%K('9I
M9.UT92!T^G1O('-P<N%V=2!A(&YE=FED[71E(&]B<N%Z;VLL(&]B<N%Z;VLL
M(&MT;W+]('-T92!C:&-E;&D@;F%H<F&[+"!N96WTOF4@8GF[('IO8G)A>F5N
M_2!V;R!68;EO;2!P<F5H;&EA9&'H:2X`56OAOFMA(&]B<N%Z:V$Z`%523"!O
M8G+A>FMA`%523"!O8G+A>FMA.@!/8G+A>F]K('H@9V%LZ7)I90!/8G+A>F]K
M('H@9V%LZ7)I93H`3F%H<F%T:64@;V)RX7IK=0!/8G+A>FMY`$EM<&]R="P@
M:W)O:R`E9`!);7!O<G1O=F%NZ2!P;VQE.B`E<P!);7!O<G1O=F%NZ2!P;VQI
M83H`5FQOOFF[(&NU^N@@7WIA`$)O;"!Z861A;OT@;F5S<'+A=FYY(&OS9"!A
M:V-I92X`3F5S<'+A=FYE('!O=;[M=F%T9;5S:^D@;65N;R!A+V%L96)O(&AE
M<VQO`$YE<W!RX79N92!P;W6^[79A=&6U<VOI(&UE;F\@86QE8F\@86QT97)N
M873M=FYA(&%D<F5S82X@4VOZ<W1E('1O('IN;W9U(&%L96)O(&MO;G1A:W1U
M:G1E('-P<N%V8W4@5N&Y:&\@<WES=.EM=2P@86L@<&]T<F5B=6IE=&4@<&]M
M;V,N`%IVY.BY:;L@;V1S861E;FEE`$EN9&EA`$IE9&YO=&QI=NT@<&]UONUV
M871E;&EA`$EN9&]NZ7II80!);F9O`$EN9F]R;>%C:64`26YF;W)MX6-I92!U
MOB!N:64@<_H@9&]S='5P;NDN`%9L;[YINR!?<W3E<&5C('IA`%9L;[YINR!O
M8G+A>F]K`%9L;[YINR!T86)UM6MU`%9L;[YINR!L:6YK=0!6;&^^:;L@7W-T
MY7!E8R!P<F5D`%9L;[YINR!N;W;]('-TY7!E8R!Z82!A:W1UX6QN>0!6;&^^
M:;L@;F]V_2!S=.5P96,@<')E9"!A:W1UX6QN>0!6;&^^:;L@;F]V_2!R:6%D
M;VL@>F$@86MT=>%L;GD`5FQOOFF[(&YO=OT@<FEA9&]K('!R960@86MT=>%L
M;GD`5FQOOFF[(&]D<W1A=F5C('IA(&%K='7A;&YY(&)O9`!6;&^^:;L@;V1S
M=&%V96,@<')E9"!A:W1UX6QN>2!B;V0`5FQOOFF[(&%L=&5R;F%T[79N=2"Y
M86)L\VYU`%IA9&%J=&4@92UM86EL;W;Z(&%D<F5S=2P@;F$@:W1O<OH@9&]S
M=&%N971E(&YO=ND@:&5S;&\Z`%9L;[YINR!B=6YK=2!Z80!6;&^^:;L@8G5N
M:W4@<')E9`!6;&^^:;L@<W3E<&5C('IA`%9L;[YINR!S=.5P96,@<')E9`!6
M;&^^=&4@<W!RX79Y`%9L;[YINR!O9'-T879E8R!Z80!6;&^^:;L@;V1S=&%V
M96,@<')E9`!6;&^^:;L@<FEA9&]K('IA`%9L;[YINR!R:6%D;VL@<')E9`!:
M861A:G1E('!OOF%D;W9A;OH@;V1P;W9E[R!N82!B97IP9>AN;W-T;OH@;W3A
M>FMU.@!6;&^^:;LO=7!R879INR!O8G+A>F]K`%9L;[YINR]U<')A=FF[(&QI
M;FMU`$YA(&]D;W-I96QA;FEE('!R92!Z;WIN86T@<'+M:F5M8V]V(&YE;>%T
M92!D;W-T871OZ&[](&MR961I="X`3F5D;W-T871OZ&[](&MR961I="X`0V5L
MZ2#H[7-L;P!:;WIN86T@8V5L_6-H(.AI<V5L`$YE<&QA9&[I(%5$2"`H57-E
M<B!$871A($AE861E<BP@2&QA=FGH:V$@<&]UONUV871EM7-K_6-H(/ID86IO
M=BDN`$YE<&QA=&[I(/ID86IE(&9O<FWA='4@6DE0+@!.97!L871NX2!A<&QI
M:^%C:6$N`$YE<&QA=&[I($E$(&3A=FMY+@!";VQI(&]D;W-L86[I(&YE<&QA
M=&[I(/ID86IE+@!.97!L871NX2!C:66U;W;A(&%D<F5S82X`3F5P;&%T;OT@
M9F]R;>%T('/Z8F]R=0!.97!L871N_2!L:6-E;NAN_2!KM?KH+@!";VQA('IA
M9&%NX2!N97!L871NX2!L;VMA;&ET82X`3F5P;&%T;N$@:&]D;F]T82!M<V=?
M='EP92X`3F5P;&%T;N$@86QE8F\@8VC]8F%J^F-A(&AO9&YO=&$@87!I7VED
M+@!.97!L871NZ2!A;&5B;R!C:/UB86KZ8V4@<&%R86UE=')E+@!.97!L871N
MZ2!R;V1IZ&]V<VOI('!RX79O+@!.97!L871NZ2!I9"!P87)T;F5R82X`3F5P
M;&%T;OT@:_-D('!R;V1U:W1U+@!.97!L871N_2!P<F]T;VMO;`!.97!L871N
M_2!P<NUJ96UC83H@(B5S(@!.97!L871N_2!O8FIE:W0@>F1I9;5A;FEA`$YE
M<&QA=&[A('ID<F]J;W;A(&%D<F5S82X`3F5P;&%T;ND@^F1A:F4@=6YI8V]D
M92X`26YV96YTX7(`26YV97)T;W9ANR!V_6)E<@!)<N%N`$ER86L`S7)S:V\`
M27-L92!O9B!-86X`3VIE9&EN96SI(&+Z<FMY`$EZ<F%E;`!6>61A=F%T9;4`
M2W5R>NUV80!486QI86YS:V\`2F%M86IK80!*86YUX7(`2F%P;VYS:V\`2F5R
M<V5Y`$IO<F3A;@!*^FP`2OIN`%IA<F]V;F&[`%IA<F]V;F&[(&1O('-T<F5D
M=0!:87)O=FYANR!D;R!B;&]K=0!:87)O=FYANR!VM6%V;P!:87)O=FYANR!V
M<')A=F\`2V%Z86-H<W1A;@!0;VYE8VAANR!O<FEG:6[A;#\`2V7R80!+97)B
M97)O<R!S97)V97(@>F%M:65T;VP@875T96YT:69I:^%C:74N`$ME<FYE;"UN
M;W;AZ&EK;W9I80!6>71V;W)E;FEE(&NU^NAA`$1I9VETX6QN>2!O9'1L8>AO
M:R!KM?KH80!$Y;YK82!KM?KH80!4>7`@:[7ZZ&$`4&]UOFET:64@:[7ZZ&$`
M2[7ZZ"!UOB!E>&ES='5J92!N82!S97)V97)I('9E<F5J;OUC:"!KM?KH;W8N
M`$1E=&D`2VER:6)A=&D`I75D;W9O9&5M;VMR871I8VOA(')E<'5B;&EK82!+
M\W)E80!+\W)E:G-KX2!R97!U8FQI:V$`2W5V86IT`$MI<F=IN7-K;P!6>E]H
MM6%D`$IA>GEK`$QA;W,`4&]S;&5D;N$@<&]L;W9I8V$`4&]S;&5D;N$@>FUE
M;F$@:&5S;&$`4&]S;&5D;N$@N71V<KL`4&]S;&5D;N$@86MT=6%L:7KA8VEA
M.@!0;W-L961NZ2!P<FEH;.%S96YI93H@)7,`4&]S;&5D;ND@<')I:&SA<V5N
M:64Z("5S('H@)7,`4&]S;&5D;ND@<')I:&SA<V5N:64Z(&YI:V1Y`$QO='FY
M<VMO`%!RX79O`%9Z:+5A9`!.96-H86IT92!P<N%Z9&YE('!R92"^:6%D96X@
M;VMR86H`3&EB86YO;@!6M6%V;P!(;&%V:>AK82!VM6%V;P!(;V1N;W1Y(':U
M879O`$QE<V]T:&\`VG)O=F7R`$QI8NER:6$`3.UB>6$`3&EC:'1E;KET86IN
M<VMO`*5A:&OI(&UR:&]L96YI90"E86AK_2!DX;[O`%+A;F\@M6%H:_T@9.&^
M[P!.97-K]'(@M6%H:_T@9.&^[P"E86AKZ2!D8;[O;W;I('!R96CA;FMY`*5A
M:&O](&3AON\@<R!H<FUE;NUM`*5A:&OI('-N9;YE;FEE`*5A:&OI('-N96AO
M=ND@<')E:.%N:WD`3&EM97)I8VL`3&EN:V$`3&EN:V$@=6MA>G5J92!N83H`
M4')E<&]J:;L@92UM86EL;W;Z(&%D<F5S=2!S;R!S='+A;FMO=2!N82!P[7-A
M;FEE('!ON71Y`$QI;FMY`$QI;G5X($-O;VMI90!:;WIN86T@+2!P;W6^[79A
M=&6U('5V:63M('!R:67H:6YO:P!6>7#M<V&[('IO>FYA;2!D871A8N%Z`%IO
M>FYA;2!TZ6T@4&]M;V-N[6MA`%9Y<.US8;L@>F]Z;F%M('1A8G5L:65K`$QI
M<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M
M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`%IO8G)A>F5N
M:64@<V5D96[M('IL>6AA;&\Z("5S`%IO8G)A>F5N:64@<&]UONUV871EM6]V
M('IL>6AA;&\Z("5S`%IO8G)A>F]V86YI92!Z;WIN86UU('!O=;[M=F%T9;5O
M=B!J92!Z86OA>F%NZ2X`3&ET97)A=/IR80!,:71V80!.8>CM=&%V82!S82XN
M+@!-:65S=&YY(.AA<SH@`$QO:V%L:7KA8VEA(&$@Z&%S`$QO:V%L:71A`%!R
M:6ALX7-E;FEE`%KA>FYA;7D@<')E9&-HX61Z86KZ8V5J('-Y;F-H<F]N:7KA
M8VEE`$]D:&SA<VF[`%!R:6ALX7-E;FEE`-IL;VAY('!R:2!P<FEH;.%S96[M
M`%!R:6ALX7-E;FEE('IL>6AA;&\L('!R971OOF4@<W1E('IA9&%L:2!N97-P
M<N%V;F4@<&]UONUV871EM7-KZ2!M96YO(&%L96)O(&AE<VQO+@!0<FEH;.%S
M96YI92!Z;'EH86QO+@!$;&C]('1E>'0`3.%S:V$`3NUZ:V$`36%LZ2!G<NEC
M:V4@<.US;65NX0!-86SI(&QA=&EN<VOI('#M<VUE;N$`36%LZ2!R[6US:V4@
MZ.US;&EC90!,=7AE;6)U<G-K;P!-30!3<'+A=F$@9/)A`%!R[6QO:&$@35,M
M5$Y%1B!N96]B<V%H;W9A;&$@OFEA9&YE(/ID86IE+@!-4T<`36%C86\`36%C
M963S;G-K;P!-861A9V%S:V%R`$WA9VEA`%!ON71A`%!O<VQANR!E+6UA:6P@
M861M:6YI<W1RX71O<F]V:0!6>71V;W)INR!L:6Y?:W4N+BX`36%L87=I`$UA
M;&%J>FEA`$UA;&5D:79Y`$UA;&D`36%L=&$`4W!R879O=F&[('IO>FYA;2!K
M871E9_-R:>TL(',@:W1O<OUM:2!O>FYAZ'5J971E('!O;&^^:WD@82!F87)B
M>2!A<V]C:6]V86[I(',@=/UM:71O(&MA=&5G\W)I86UI+@!-87!A($UA<#(T
M`$UA<&$@36%P475E<W0`36%P;W9A;FEA('5L;[YE;NDN`$UA<F5C`$]K<F%J
M`$]Z;F'H:;L@<'+M>FYA:VUI(%!R9>CM=&%NZ2].97!R9>CM=&%NZ0!/>FYA
MZ&F[(&EN_6UI('!R[7IN86MM:2`H;F%P<BX@1/1L9;YI=.DO6F]D<&]V961A
M;NDI`$UA<G-H86QL;W9E(&]S=')O=GD`36%R=&EN:6L`6FAO9&[I('!O;&EA
M`$UA=7)E=.%N:6$`36%U<NUT:75S`$UA>&EMX6QN>2!P;W9O;&5N_2!K<F5D
M:70N`$)O;"!P<F5K<F_H96[](&UA>&EMX6QN>2!P;^AE="#H87-T[2!S<'+A
M=GDN`$YA:G9YN;EI82!T97!L;W1A('IA('!O<VQE9&[]8V@@,C0@:&]D[6XZ
M(`!.86IV>;FY:6$@=&5P;&]T82!Z82!P;W-L961N_6-H(#8@:&]D[6XZ(`!-
M87AI;>%L;GD@<&_H970@8FQO:V]V('!O<G3A;'4`36%X:6WA;&YA(&3EOFMA
M`$WA:@!-87EO='1E`$UE9&EC[6YA`,AL96YO=FEA`%IO8G)A>F5N:64@;65N
M=3H`6FSZZ&F[(&)U;FMY`%-P<N%V80!3<'+A=F$@8F]L82#Z<W!EN6YE(&]V
M97)E;N$L(&%L92!C97)T:69I:^%T('!O9'!I<W4@<V$@;F5P;V1A<FEL;R!O
M=F5R:;LN`%!L871N;W.[('-P<N%V>2!V>7!RN6%L82X`5'EP('-P<N%V>0!0
M;^AA<VEE($UE=&%R`-ID86IE($UE=&%R(&YI92!S^B!D;W-T=7!NZ2X`VF1A
M:F4@365T87(@;FEE('/Z(&L@9&ES<&]Z[6-I:2X@1&5T86EL>2!B;VQI('IA
M>FYA;65N86[I('!R92!A9&UI;FES='+A=&]R82X`4WES=.EM($UE=&%R1$(@
M;FEE(&IE('!R:7!O:F5N_2X`365T\V1A`$UE=/-D82`B)7,B(&YI92!J92!D
M969I;F]V86[A`$YE9&5F:6YO=F%NX2!M973S9&$N(%9O;&%NZ2!Z(&UE=/-D
M>3H@)7,`365T<FEC:^D`365X:6-O`$UI:W)O;NEZ<VME(&9E9&5R873M=FYE
M(+ETX71Y`%-T<F5D`%1Y<"!-:6UE`$YA:FYIOKEI82!T97!L;W1A('IA('!O
M<VQE9&[]8V@@,C0@:&]D[6XZ(`!.86IN:;ZY:6$@=&5P;&]T82!Z82!P;W-L
M961N_6-H(#8@:&]D[6XZ(`!-:6YI;>%L;F$@9&]B82!P;&%T;F]S=&D@:&5S
M;&$@9;ET92!N979Y<'*Y86QA`%IR:V%D;&]V;R!O8G+A=&F[`%+T>FYE`$-H
M_6)A(&)A;.UK(%!%05(@2%144%]297%U97-T+@!#:/UB82!K;VYF:6=U<N%C
M:6$N($%K(&-H8V5T92!P;W6^[79ANR!T^G1O(&%P;&EKX6-I=2P@;75S[71E
M('1E<F%Z('9Y9V5N97)O=F&[(&MO;F9I9W5RX6-I=2X`0VC]8F$@240@<W!R
MX79Y+@!#:/UB82!P;[YA9&]V86[](%!%05(@8F%L[6L@36%I;"X`0VC]8F$@
M240@<F5LX6-I92X`4&]N`$UO8FEL;OT@;6%I;`!-:65R;GD`1.%T=6T@<&]S
M;&5D;F5J('IM96YY`%5P<F%V:;L@55),`$UO9'5L=7,`36]L9&%V<VMO`$UO
M;F%K;P!-;VYG;VQS:V\`365S:6%C(&$@<F]K`$UE<V'H;F4`36]N='-E<G)A
M=`!-97-AZ&[I(&;A>GD`3F$@<FEA9&MU("5D(&)O;&\@;N%J9&5N_6-H('9I
M86,@<&]L[2!A:V\@;^AA:^%V86[]8V@@)60N`$UA<F]K;P!0<F5V8;YN92!J
M87-N;P!0<F5V8;YN92!O8FQAZ&YO`%!R979AOFYE('-L;F7H;F\`4')E<W5N
M^KL@9&]L=0!0<F5S=6[ZNR!VM6%V;P!0<F5S=6[ZNR!V<')A=F\`4')E<W5N
M^KL@:&]R90!0<F5S=6[ZNR!D;VQU`%!R97-U;OJ[(&AO<F4`36]Z86)M:6L`
M5FEA8_IR;W;R;W;I('9Y8F5R86-I92!Z;WIN86UY`%9I86-NX7-O8F[](';]
M8F5R`$UO:F4@:V]N=&\`26YF;W)MX6-I92!O(&UO:F]M(/KH=&4`3?1J('!O
M<G3A;`!6>FBU860@;?1J:&\@<&]R=.%L=0!->6%N;6%R`$YI92P@3D53VDA,
M05/-32X`365N;P!.86WM8FEA`$YA=7)U`$YE<.%L`$AO;&%N9'-K;P!(;VQA
M;F1S:^D@06YT:6QY`%KA:VQA9&[A(%523"!.971S8V%P90!54DP@<')E('IN
M97!L871N96YI92!C97)T:69I:^%T;W8@0T$@3F5T<V-A<&4`55),('!R92!P
M;VQI=&EK=2!#02!.971S8V%P90!54DP@<')E(&]B;F]V96YI92!P;&%T;F]S
M=&D@8V5R=&EF:6OA=&]V($YE='-C87!E`%523"!P<F4@>FYE<&QA=&YE;FEE
M(&-E<G1I9FEKX71O=B!.971S8V%P90!-96YO(%-33"!S97)V97)A($YE='-C
M87!E`$MO;65N=.%R(&-E<G1I9FEKX71U($YE='-C87!E`%1Y<"!C97)T:69I
M:^%T=2!.971S8V%P90!3:66[`$YI:V1Y`$YO=N$@2V%L963S;FEA`$YO=N$@
M:V%T96?S<FEA`$YO=N$@<W!RX79A('!R92`E<P!.;W8`3F]VZ2!P;W6^[79A
M=&6U<VOI(&UE;F\@*&YE<&]V:6YNZ2D`3F]V_2!:Z6QA;F0`3F]VZ2!H97-L
M;P!0;&%T;F]SNR!N;W;I:&\@:&5S;&$@=GEP<KGM("5X+@!.;W;I(&AE<VSA
M(&YI92!S^B!R;W9N86OI+@!.;W;I(&]K;F\@*%]B;&%N:RD`3F5W<P!$:7-K
M=7-NZ2!S:W5P:6YY`,]A;&5J`$YA<VQE9'5J^F-E(#0@9N%Z>0#/86RY:64@
M;F%S=&%V96YI80!.87-L961U:OIC83X`3FEK87)A9W5A`$YI9V5R`$YI9^ER
M:6$`3F]C`$YI=64`3FEE`$YI92!S^B!D;W-T=7!NZ2"^:6%D;F4@:V]N9FEG
M=7)AZ&[I(/ID86IE+"!P<F4@:W1O<ND@8GD@<V$@9&%L:2!Z;V)R87IINR!R
M;WID:65L>2X`4')E('9Y=';A<F%N:64@25-/(&]B<F%Z;W8@;FEE(&IE(&L@
M9&ES<&]Z[6-I:2"^:6%D;F$@<W1R873I9VEA+@!.965X:7-T=6IE(+EA8FSS
M;F$@<')E(&3A=FMU+@!.82!P;[YA9&]V86YE:B!P;WKM8VEI(&YE97AI<W1U
M:F4@OFEA9&5N(&)L;VLN`%!R92!-0T%,(&%U=&5N=&EF:6OA8VEU(&YE8F]L
M;R!Z861A;ND@;65N;R!K86QE;F3A<F$N`*YI861N82!Z;65N82X`2R!T;VUU
M=&\@<'+A=G4@;F5M;[YN;R!P<FED8;L@OFEA9&YE('!O9')I861E;ND@<'+A
M=F$N`%!R92`E<R!N96)O;&$@=7+H96[A(&MO;F9I9W5RX6-I82X`4')E($94
M4"!61E,@;F5B;VQA('5RZ&5NX2!K;VYF:6=U<N%C:6$N`%!R92!344P@5D93
M(&YE8F]L82!U<NAE;N$@:V]N9FEG=7+A8VEA+@!0<F4@4U%,+49I;&4@5D93
M(&YE8F]L82!U<NAE;N$@:V]N9FEG=7+A8VEA+@"N:6%D96X@:W)E9&ET+@!.
M96)O;&\@N7!E8VEF:6MO=F%NZ2!M:65S=&\@=7+H96YI82X`4_IB;W(@;F5B
M;VP@;F%H<F%N_2X`3F5B;VQI(&[A:F1E;ND@OFEA9&YE(&EK;VYY+@!.:64@
M:F4@;F%S=&%V96[A(&QO:V%L:71A+@!.96)O;&$@>F%D86[A(&QO:V%L:71A
M+@!.96)O;&$@>F%D86[A(+YI861N82!S<'+A=F$N`$YE8F]L;R"Y<&5C:69I
M:V]V86[I(+YI861N92!M96YO+@!.96)O;&\@N7!E8VEF:6MO=F%NZ2#H[7-L
M;RX`KFEA9&YE('5RX;YL:7;I(&9O<G1U;GD`4')E($A45%`@875T96YT:69I
M:^%C:74@;F5B;VQO('IA9&%NZ2!H97-L;RX`4')E($E-05`@875T96YT:69I
M:^%C:74@;F5B;VQO('IA9&%NZ2!H97-L;RX`4')E($ME<F)E<F]S(&%U=&5N
M=&EF:6OA8VEU(&YE8F]L;R!Z861A;ND@:&5S;&\N`%!R92!,;V=I;B!A=71E
M;G1I9FEKX6-I=2!N96)O;&\@>F%D86[I(&AE<VQO+@!0<F4@4$%34U=$(&%U
M=&5N=&EF:6OA8VEU(&YE8F]L;R!Z861A;ND@:&5S;&\N`%!R92!334(@875T
M96YT:69I:^%C:74@;F5B;VQO('IA9&%NZ2!H97-L;RX`3F5B;VQA('IA9&%N
MX2!C97-T82!K('!R;V=R86UU($]P96Y34TPN(%!R;V=R86T@3W!E;E-33"!J
M92!P;W1R96)N_2!N82!P<N%C=2!S(/ID86IM:2!02T-3(#$R+@"N:6%D;F4@
M<')E8FEE:&%J^F-E('!R:6ALX7-E;FEA+@!+=O-T82!N:64@:F4@;F%S=&%V
M96[A+@!"97H@Z&EA<@!.96)O;""Y<&5C:69I:V]V86[](&]D9&6U;W9AZ"X`
M0F5Z('-T<N%N`%/Z8F]R(&YE;N%J9&5N_0!0<F4@=GER;W9NX79A8VEU('!A
M;>2[(&YI92!J92!D;W-T=7!N_2"^:6%D96X@9&_H87-N_2!P<FEEZ&EN;VLN
M`$YE8F]L;R!O9&]S;&%NZ2!P;W6^[79A=&6U<VOI(&UE;F\@82]A;&5B;R!H
M97-L;RX`3F5B;VQI('9RX71E;ND@<&QA=&[I(%A-3"#Z9&%J90"N:6%D;F4@
M:&]D;F]T>0!6('#T=F]D;F5J(&MO;F9I9W5RX6-I:2!N96)O;&$@;N%J9&5N
MX2"^:6%D;F$@=F5R>FEA+B!6>6=E;F5R=6IT92!Z;F]V=2!K;VYF:6=U<N%C
M:74N`%8@:V]N9FEG=7+A8VEI(&YE8F]L82!NX6ID96[A(+YI861N82!V97)Z
M:6$N(%9Y9V5N97)U:G1E('IN;W9U(&MO;F9I9W5RX6-I=2X`KFEA9&5N`*YI
M861N92`H<&]UOFF[(&EM<&QI8VET;OH@:&]D;F]T=2D`3W-T<F]V($YO<F9O
M;&L`4V5V97)NX2!P;VQO9W6U80!3979E<F[I($UA<FGA;G-K92!O<W1R;W9Y
M`$[S<G-K;P!.97!L873M('!O`$YE<&QA=.T@<')E9`!.:64@:F4@861R97/A
M<@!.:64@:F4@:6UP;&5M96YT;W9A;NDN`$YE;F%S=&%V96[I`$YI92!J92!P
M;V1P;W)O=F%NZ2X`4&]Z;N%M:WD`3FGH(&YA('!R97IE<F%N:64L('9RX;MT
M92!S82!S<.2[+@!.;W9E;6)E<@#([7-L;P!0;^AE="!Z;F%K;W8`4&_H970@
M<W3E<&-O=@!0;^AE="!R:6%D:V]V`%!R92!A:W1U86QI>N%C:74@>F]Z;F%M
M=2!P<NUJ96UC;W8@;F5B;VQI(+EP96-I9FEK;W9A;ND@Z.US;&$N`$]+`$]B
M:F5K=`!!=71O<B!O8FIE:W1U`$]S;6GH:V]V_0!/:W3S8F5R`$9I;'1E<B!N
M82!N863A=FMY`%!R86-O=FES:V\`4W1A<ND@82!N;W;I(&AE<VQO(&UU<VEA
M(&)YNR!O9&QIN6[I+@!3=&%RZ2!H97-L;P!3=&%RZ2!H97-L;R!N96)O;&\@
M>F%D86[I('-P<N%V;F4N`$]MX6X`26)A($E-05`@<V5R=F5R>2!P;V1P;W)U
M:OH@>F1I9;5A;ND@<')I9>AI;FMY+@!)8F$@=7+AOFQI=ND@9F]R='5N>0!*
M92!P<NUP=7-T;N$@:6)A(&IE9&YA(&4M;6%I;&]VX2!A9')E<V$N`%9L87-T
M;NUK82!A;&5B;R!P<N%V82!V;&%S=&[M:V$@<')E('ID:66U86[](&]B:F5K
M="!M]+YE('IM96YINR!I8F$@=FQA<W1N[6L@86QE8F\@<WES=.EM;W;](&%D
M;6EN:7-T<N%T;W(`3W1V;W)INR!V(&YO=F]M(&]K;F4`0VAY8F$@3W!E;E-3
M3#H@;F5P;V1A<FEL;R!S82!Z[7-K8;L@^F1A:F4@>B!P;V1P[7-A;F5J(.AA
M<W1I(%,O34E-12X`3W1V;W)INR!T^G1O(&QI;FMU('8@;F]V;VT@;VMN90!/
M<&5R8>AN_2!S>7-TZ6T`3F%S=&%V96YI80!.87-T879E;FEA("5S`%IO<F%D
M96[]('IO>FYA;0!/<F=A;FEZX6-I80!/<F=A;FEZ8>ANX2!J961N;W1K80!/
M<F=A;FEZ;W9A;FEE`%#T=F]D;N$@N6%B;/-N82!A<&QI:^%C:64`4/1V;V1N
MZ2"Y86)L\VYY('8@)7,Z`$ENZ0#/86RY:64@:6YF;W)MX6-I90!0<N%V82!V
M;&%S=&[M:V$`4$%-(&%U=&5N=&EF:6OA8VEA(&YI92!J92!D;W-T=7!NX2X`
M4$5!4CI-86EL(&)A8VME;F0`1&EG:73A;&YY('!O9'!I<R!01U``VF1A:F4@
M>F&Y:69R;W9A;ND@<&]M;V-O=2!01U``4$=0('9E<F5J;OT@:[7ZZ`#:9&%J
M92!P;V1P[7-A;NDO>F&Y:69R;W9A;ND@<&]M;V-O=2!01U``4$A0(&OS9`!0
M2%`@4VAE;&P`4&]P;VQU9&[M(+5A:&O](&3AON\`4&]P;VQU9&[M('!R96CA
M;FMY`%!O<&]L=61N[2!S;F6^96YI90!0;W!O;'5D;NT@<VYE:&]VZ2!P<F5H
MX6YK>0!0;W!O;'5D;NT@<VYEOF5N:64`4&]P;VQU9&[M(&+Z<FMY`$-H_6)A
M(')O>KGM<F5N:64@4$]325@`4%](4"!3:&5L;`!6>7!L;F5N:64`4&%K:7-T
M86X`4&%L875S:^D@;W-T<F]V>0!086QE<W3M;G-K92#Z>F5M:64`4&%N86UA
M`%!A<'5A($YO=N$@1W5I;F5A`%!A<F%G=6%Y`,AI87-T;^AN92!O8FQAZ&YO
M`$AE<VQO`$AE<VQO(&)O;&\@^G-P9;EN92!Z;65N96[I+@!.97-P<N%V;F4@
M:&5S;&\`4')E(&%U=&5N=&EF:6OA8VEU(%)!1$E54R!J92!V>;YA9&]V86[I
M(&AE<VQO+@!(97-L;R!S('!O='9R9&5N[6T`2&5S;&\Z`$AE<VQO.B``2&5S
M;.$@;75S:6$@8GF[(')O=FYA:^DN`%9L;[YINP!6;&^^:;L@>F\@<V-H<N%N
M:WD`0V5S=&$`4')E8FEE:&%J^F-E(')E9VES='+A8VEE.@"E=61I80!097)C
M96YT`%9Y:V]N8;L@;W!E<N%C:64@^F1ROF)Y`%9Y:V]N8;L@;W!E<N%C:64@
M^F1ROF)Y('!R:2!P<FEH;.%S96[M/P!0<N%V;P!0<N%V;R`B)7,B(&YE8F]L
M;R!V>6UA>F%NZ2X`4'+M<W1U<"!Z86UI971N=73]`%!RX79A`$%D;6EN:7-T
M<N%C:6$@<'+A=@!/<V]B;ND@:6YF;W)MX6-I90!097)U`$1O;>%C92!Z=FEE
M<F%TX0!&:6QI<.UN>0!496QE9O-N`$9O=&]G<F%F:64`4&ET8V%I<FX`0F]D
M;W8`2VQI:VYI=&4@<')O<^UM(&1O(&YE:F%K96H@8G5N:WD`4&]T=G+O=&4@
M<')O<^UM+""^92!C:&-E=&4@;V1S='+A;FF[('1E;G1O(&5L96UE;G0Z`%!O
M='9R[W1E('!R;W/M;2P@OF4@8VAC971E(&]D<W1RX6YINR!L:6YK=2!Z('1O
M:'1O(&5L96UE;G1U+@!:861A:G1E('!R;W/M;2!M97-I86,@82!R;VLN`%IA
M9&%J=&4@<')O<^UM(&UE;F\@<')E(&YO=OH@:V%T96?S<FEU.@!:861A:G1E
M('!R;W/M;2!P;&%T;OH@25`@861R97-U+@!:861A:G1E('!R;W/M;2!P;&%T
M;OT@9.%T=6TL('-K;VYT<F]L=6IT92!P;^AE="!D;NT@=B!M97-I86-I+@!:
M861A:G1E('!R;W/M;2!P;&%T;OT@Z&%S+@!0<F]S[6T@=79E[W1E('IH<FYU
M=&EE('!R;V)LZ6UU+@!0<F]S[6T@>F%D86IT92!S=F]J92!P;W6^[79A=&6U
M<VOI(&UE;F\@82!H97-L;P!0<F7H[71A:G1E('-I('!R;W/M;2!N87-L961U
M:OIC:2!T97AT+B!-55/-5$4@<_IH;&%S:;L@<R!P;V1M:65N:V%M:2!P;W6^
M[79A;FEA('-Y<W3I;74N`%IA9&%J=&4@<')O<^UM(&UE;F\@<')E(&YO=OH@
M:V%T96?S<FEU.@!0;[5S:V\`4&]L:71I:V$`06YK971Y`%!O<G1U9V%L<VMO
M`%5M:65S=&YE;FEE('1O:'1O(&]B<N%Z:W4`56UI97-T;F5N:64@=&5J=&\@
M=&%B=;5K>0!/9&]S;&&[(&1O('1O:'1O('!R:67H:6YK82`H;F5V>6YU8W5J
M92!)34%0*0!:<N&^:WD@>F$@<&]S;&5D;OUC:"`E<R!H;V3M;CH@`%!R879D
M97!O9&]B;F]SNSQB<B`O/GIRX;YO:P!0<F5F<U]L9&%P.B!P;[YA9&]V86[I
M(')O>KGM<F5N:64@3$1!4"!N96)O;&\@;N%J9&5NZ2X`4')E9G-?<V5S<VEO
M;CH@<&^^861O=F%NZ2!R;WJY[7)E;FEE('-E<W-I;VX@;F5B;VQO(&[A:F1E
M;NDN`%1L86L`5&QA:R!N82#Z<F]V;FD@;6]R83H@`%1L86LZ(`!5:^&^:V$`
M6F]B<F%Z:;L@=6OAOFMU(&]B<N%Z:W4@=B!N;W9O;2!O:VYE`%!R961C:.%D
M>F%J^F-E(&YA<W1A=F5N:6$`5GET;&'H:;L@9&]K=6UE;G0`4')I=N%T;GD@
M:[7ZZ`!0<F]B;.EM`%!O<&ES('!R;V)LZ6UU`%!R;VIE:W1Y`%;]>G9A(&YA
M('IA9&%N:64@=&5X='4`5F5R96IN_2!KM?KH`$%L9V]R:71M=7,@=F5R96IN
MZ6AO(&NU^NAA`$EN9F]R;>%C:64@;R!V97)E:FYO;2!KM?KH:0!697)E:F[]
M+W!R:7;A=&YY(&NU^NAO=OT@<.%R(&YE8F]L(/IS<&6Y;F4@=GEG96YE<F]V
M86[]+@!0;W)T;W)I:V\`2V%T87(`1&]T87H`2W;S=&$`4E-!('9E<F5J;OT@
M:[7ZZ"`H)60@8FET;W8I`%!R97#M;F'H(',@=OUB97)O;0!$X;[O`%+A;F\@
M9.&^[P!.97-K]'(@9.&^[P!$8;[O;W;I('!R96CA;FMY`$3AON\@<V\@<VYE
M:&]M`$3AON\@<')E8VCA9'IA:OIC:2!V('-N9;YE;FEE`$[A:&]D;N$@9F]R
M='5N80!0;VUE<@#([71ANP#([71ANR!S<'+A=GD`3F%O>F%J('9Y;6%Z8;L@
M)7,_(%3Z=&\@;W!E<N%C:74@;F5M;[YN;R!V<N%T:;L@<W#DNRX`3F%O>F%J
M('9Y;6%Z8;L@<&]UONUV871EM7-KZ2#Z9&%J92!P<F4@<&]UONUV871EM6$@
M)7,_(%3Z=&\@;W!E<N%C:74@;F5M;[YN;R!V<N%T:;L@<W#DNRX`5G+A=&D@
M<W#DNR!68;EU('!O<VQE9&[Z(&%K8VEU`$]B;F]V:;L`3V)N;W9INR!E;&5M
M96YT>2!D>6YA;6EC:^EH;R!M96YU.@!/8FYO=FF[('IO8G)A>F5N:64@<&]R
M=.%L=3H`4F5G=6SA<FYY(';]<F%Z`%!R96AL:6%D8>@@=GJ[86AO=@!:;F]V
M=2!N8>CM=&&[`%!O<W1R96AY`%9Z9&EA;&5NZ2!S97)V97)Y`%9Z9&EA;&5N
MX2!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!/9'-T<N%N
M:;L`3V1S='+A;FF[(&)L;VL`3V1S='+A;FF[('-TY7!E8P!/9'-T<N%N:;L@
M9F]R;>%T;W9A;FEE`$]D<W1RX6YINR!PX7(`3V1S='+A;FF[('5L;[YE;OT@
M<VMR:7!T('H@9&_H87-NZ6AO('!R:67H:6YK82!N82!S97)V97)I+@!/9'-T
M<N%N:;L`3V1S='+A;FF[('1E;G1O(&)O9"!Z(&1O:W5M96YT=0!/9'-T<N%N
M:;L@<&]UONUV871EM6$`3V1S='+A;FF[('!O=;[M=F%T9;5A.B`E<P!.82!P
M;[YI861A=FMU(&YE8F]L;R!M;[YNZ2!O9'!O=F5D8;LN($[A=G)A=&]V_2!K
M\V0@8VAY8GDZ(`!0;[YA9&]V86[Z('-L=;YB=2!S82!N97!O9&%R:6QO(&[A
M:G.[+@!6(&MO;F9I9W5RX6-I:2`E<R!N:64@:F4@N7!E8VEF:6MO=F%NX2!P
M;[YA9&]V86[A('!O;&^^:V$@(B5S(@!6(&MO;F9I9W5RX6-I:2!61E,@;FEE
M(&IE(+EP96-I9FEK;W9A;N$@<&^^861O=F%NX2!P;VQOOFMA("(E<R(`5B!K
M;VYF:6=U<N%C:6D@;FEE(&IE(+EP96-I9FEK;W9A;N$@<&^^861O=F%NX2!P
M;VQOOFMA("(E<R(`4&]V:6YNZ2!P;VQE`%9Y;6%Z8;L@9F]R;75LX7(`3V)N
M;W9INR!H97-L;P!/8FYO=FF[(%9AN64@:&5S;&\`3V)N;W9INR!P;W-L961N
M_2!D;W1A>@!6_7-L961K>0!.X79R870@;F$@;F%S=&%V96YI80!:861A:G1E
M(&YO=ND@:&5S;&\`4F5U;FEO;@!6<N%T:;L@:V]N9FEG=7+A8VEU`$YA<W1A
M=F5N:6$@<F]ZN>UR96[I:&\@=&5X=&]VZ6AO(&5D:71O<G4`2.%D86YK>0!6
M<')A=F\`2&QA=FGH:V$@=G!R879O`$AO9&YO='D@=G!R879O`%9L87-T;F]S
M=&D@7W)I861K82XN+@!2;VQA`%)U;75N<VMO`$]T;^AINR!O(#$X,`!/=&_H
M:;L@=K5A=F\`3W1OZ&F[('9P<F%V;P!6;&%S=&YO<W1I(')I861K80!6;&%S
M=&YO<W1I(')I861K80!2:6%D:WDZ`,AI87)Y`,AI87)Y('-A('IO8G)A>FEA
M(&UE9'II(':Y971K_6UI(')I861K86UI(&$@<W3E<&-A;6D`R&EA<GD@<V$@
M>F]B<F%Z:6$@:6)A(&UE9'II('-TY7!C86UI`,AI87)Y('-A('IO8G)A>FEA
M(&EB82!M961Z:2!R:6%D:V%M:0!3<'5S=&F[`%)U<VOA(&9E9&5RX6-I80!2
M=V%N9&$`4R]-24U%(&MR>7!T;V=R869I8VO]('!O9'!I<P!3<'+A=F$@>F&Y
M:69R;W9A;N$@<&]M;V-O=2!3+TU)344`4T%33"!A=71E;G1I9FEKX6-I82!N
M:64@:F4@9&]S='5P;N$N`%!O<VEE;&%N:64@4TU3`%-13"!3:&5L;`!344P@
M<'+M:V%Z('!R92!HM6%D86YI92!H;V1N]'0`4U-(`-I34$5#2`!37U%,(%-H
M96QL`%-O`%-VY'3A($AE;&5N80!3=N1T_2!+:71T<R!A($YE=FES`%-VY'3A
M($QU8VEA`%-V+B!0:65R<F4@82!-:7%U96QO;@!3=N1T_2!6:6YC96YT(&$@
M1W)E;F%D:6YY`%1E;B!I<W3]('+A;65C("A?<V5L9BD`4V%M;V$`4V%N($UA
M<FEN;P!386\@5&]M92!A(%!R:6YC:7!E`%-A=&5L:71N_2!P;W-K>71O=F%T
M9;4`4V%U9'-KX2!!<N%B:6$`56QOOFF[`%5L;[YINR`B)7,B`%5L;[YINR`E
M<P!5;&^^:;L@;F%S=&%V96YI80!5;&^^:;L@=GEG96YE<F]V86[Z(&MO;F9I
M9W5RX6-I=2!A:V\@4$A0('-K<FEP="!D;R!D;^AA<V[I:&\@<')I9>AI;FMA
M(%;AN6AO('-E<G9E<F$N`$MO;F9I9W5RX6-I82`E<R!B;VQA('5L;[YE;N$N
M`%-K<FEP="!N82!U<&=R861E(&YA<W1A=F5N[2!B;VP@=6QOOF5N_2!D;SH@
M(B5S(BX`3VIE9&EN96SI(&+Z<FMY`%9E9&$`2+5A9&&[`%9Y:+5A9.%V8>AE
M`%9Y8F5R=&4@<_IB;W)Y`%9Y8F5R=&4@9.%T=6T`5GEB97)T92!S:W5P:6YU
M(&YA('!R:61A;FEE`%9Y8F5R=&4@;F]VZ6AO('9L87-T;NUK80!6>6)E<G1E
M('-E<G9E<@!6>6)E<G1E('!O=;[M=F%T9;5A(&YA('!R:61A;FEE`%9Y8F5R
M=&4@=KEE=&MY`%9Y8F5R=&4@=KEE=&MY(&MO;7!O;F5N='D@9.%T=6UU`%9Y
M8F5R=&4@;V)J96MT`%IR=;EINR!V_6)E<@!6>6)E<G1E('IN86MY+"!K=&]R
MZ2!P;W1R96)U:F5T92P@>B!O:VEE;F]K(&YIOKEI92X@4&]T;VT@:6-H(&WT
MOF5T92!S:V]P[7)O=F&[(&$@=FQOOFF[('H@=&5X=&]VZ6AO('!OM6$N`%9Y
M8F5R=&4@;V1D9;5O=F'H('9O(&9O<FWA=&4@9.%T=6UU.@!6>6)E<G1E(&9O
M<FWA="!DX71U;74Z`%9Y8F5R=&4@:61E;G1I='4L(&MT;W+Z(&-H8V5T92!Z
M;65N:;LZ`%9Y8F5R=&4@;V1D9;5O=F'H('9O(&9O<FWA=&4@Z&%S=3H`5GEB
M97)T92!F;W)MX70@Z&%S=3H`5GEB97)T92!D=F4@>FAO9&[I('!O;&EA+@!6
M>6)E<G1E('-I(&9A<F5B;OH@<V-HZ6UU`%9Y8F5R=&4@:F%Z>6LZ`%!O<VQA
MNR!S<'+A=G4@;R!P<F]B;.EM90!0;W-L8;L@4TU3`%-E;F5G86P`4V5N>F]R
M.B``4V5P=&5M8F5R`%-R8G-K;R!A(,AI97)N82!H;W)A`%/I<FEO=ND@Z.US
M;&\`VF1A:F4@>F\@<V5R=F5R82!S^B!N97-P<N%V;F4@86QE8F\@;FEE('/Z
M(&1O<W1U<&[I+@!!9&UI;FES='+A8VEA('-E9&5N[0!0;&%T;F]SNR!)1"!S
M961E;FEA('9Y<'*Y86QA+@!3961E;FEA`$UN;[YI;F$@:&]D;O1T`$YA<W1A
M=G1E(&UOOFYO<W1I(&YA(&]B;F]V96YI92!6X;EH;R!H97-L82!A:R!H;R!Z
M86)U9&YE=&4N`$YA<W1A=F5N:64@=GID:6%L96[]8V@@<V5R=F5R;W8L(&MU
M(&MT;W+];2!C:&-E=&4@<')I<W1U<&]V8;L@>B!6X;EH;R!P;W)TX6QU+@!6
M>6)E<G1E(&IA>GEK+"#H87-O=OH@>O-N=2!A(&YA<W1A=F5N:6$@9.%T=6UU
M+@!.87-T879E;FEE(&%P;&EKX6-I92!S</JYNV%N96H@<')I(+ET87)T92P@
M9F%R96)N96H@<V-HZ6UY+"!I;G1E<G9A;'4@;V)N;W9O=F%N:6$@<W1RX6YK
M>2!A(&EN_6-H('9L87-T;F]S=.T@>F]B<F%Z96YI82X`3F%S=&%V96YI90!3
M^B!D;W-T=7!NZ2!S:W)I<'1Y(&YA('5P9W)A9&4@;F%S=&%V96[M`$1O(/IV
M86AY('!R:6-HX61Z82!N:65K;[5K;R!L;VMA;.UT('!O;6]C;W4@<&%R86UE
M=')A.B``4V5Y8VAE;'D`4VAO<'!I;F<`2W+A=&MY('/Z:')N`$UA:OH@<V$@
M<')E(';DZ+EI;G4@;&EN:65K('9Y='9O<FF[('-K<F%T:V]VZ2!K;.%V97-Y
M/P!:;V)R87IINP!:;V)R87IINR!R;WID:65L>2!M961Z:2!P<N%V92!U;&^^
M96YO=2!A(&YO=F]V>6=E;F5R;W9A;F]U(&MO;F9I9W5RX6-I;W4N`$WA('-A
M('!R:2!P<FEH;.%S96[M('IO8G)A>FF[(.AA<R!P;W-L961NZ6AO('!R:6AL
MX7-E;FEA/P!:;V)R87IINR!M;[YN;W.[(&YA('!O;F5C:&%N:64@;W)I9VEN
MX6QU`%IO8G)A>FF[(&[A<W1R;VH@;F$@=OUB97(@9F%R:65B`%IO8G)A>FF[
M(&UE;G4@<')E(&]P97+A8VEE(',@=&%B=;5K86UI/P!:;V)R87IINR!M96YU
M("5S(&YA(+5A=F5J('-T<F%N93\`6F]B<F%Z:;L@9&EA;/-G(',@=FQA<W1N
M;W.[86UI(&)U;FMY('1A8G6U:WD`6F]B<F%Z:;L@9&EA;/-G(',@=FQA<W1N
M;W.[86UI('1A8G6U:WD`6F]B<F%Z:;L@9&EA;/-G(',@=FQA<W1N;W.[86UI
M(')I861K=2!T86)UM6MY`%IO8G)A>FF[(&1I86SS9R!S('9L87-T;F]SNV%M
M:2!O8G+A>FMU`%IO8G)A>FF[(&YA:')A;ND`4')E:.%N:WD`4N%N;R!P<F5H
MX6YK>0!.97-K]'(@<')E:.%N:WD`6G+AOFMY('8@;VMO;.T`6FUE;KEINP!.
M86IP<G8@;75S[71E('IM96ZY:;L@86QE8F\@<')E<W5N^KL@<W5S961N_2!B
M;&]K*'DI`%-I97)R82!,96]N90!:87)E9VES=')O=F&[('-A`%!O9'!I<P!!
M;&=O<FET;75S('!O9'!I<W4`4VEN9V%P=7(`5F6U:V]SNP!0<F5S:V_H:;L@
M^F1ROF)U`%-L;W9E;G-K;P!3;&]V:6YS:V\`4VYEOF5N:64`4VYE:&]VX2!P
M<F5HX6YK80!3;F5H;W;I('!R96CA;FMY`%+A;F\@<VYE:&]VZ2!P<F5HX6YK
M>0!.97-K]'(@<VYE:&]VZ2!P<F5HX6YK>0!(Y6)K82!S;F5H=3H@`$UN;[YS
M='9O('9O9'D@96MV:79A;&5N=&[I('-N96AU.B``J6%L86WZ;F]V92!O<W1R
M;W9Y`%-O;>%L<VMO`%!I97-N92!A(&+A<VYE`%;]8F5R('-M97)U('1R:65D
M96YI80!:9')O:F]VX2!A9')E<V$`2G6^;N$@069R:6MA`$IUOF[A($=E;W)G
M:6$@82!3;W5T:"!386YD=VEC:"!)<VQA;F1S`$IUOF[A('!O;&]G=;5A`$UE
M9'IE<F$@;65D>FD@<W5S961N_6UI(&)U;FMA;6D`365D>F5R82!M961Z:2!O
M8G-A:&]M(&$@;VMR86IO;2!B=6YK>0!/9&1EM6]V8>@`3V1S='5P`$]D<W1U
M<"!A('9Y<&QN96YI90"I<&%N:65L<VMO`%-P86T`5FQOOF5N:64@N7!E8VGA
M;&YY8V@@>FYA:V]V`%)O>F1E;&F[(&)U;FMU`%)O>F1E;&F[('-TY7!E8P!2
M;WID96QINR!R:6%D;VL`J7!O<G1Y`%-R[2!,86YK80"I=&%N9&%R9&[I`%-T
M87(@5')E:P!0;^AI871OZ&[](')O:P"I=.%T(&%L96)O('!R;W9I;F-I80!3
M=&%V`$9O<FWA="!U;&^^96YI80!">61L:7-K;P!0<F6Y:W)T;G5TZ0!:;WIN
M86T@<F6[87IC;W8`3V1S='+A;FF[(&1O;>EN=2!Z(&%D<F5S>0"I=/UL(%M#
M4U-=`$YE`%!O9'!R:67H:6YO:R`B)7,B(&YE8F]L(&[A:F1E;OTN`%!R961M
M970`3V1O<VQANP!0;[YI861A=FMA(&YA('!R:61A;FEE("(E<R(@9&\@<WES
M=.EM=2!B;VQA(&]D;W-L86[A+B!.96WTOF5T92!S82!P<FEH;.%S:;LL(&O]
M;2!N96)U9&4@5F&Y82!P;[YI861A=FMA('-C:';A;&5NX2X`1&]L;OT@:6YD
M97@`VG-P96-H`%!R:61A;FEE("(E<R(@9&\@<WES=.EM=2!B;VQO(/IS<&6Y
M;NDN`%9Y;6%Z86YI92#Z9&%J;W8@>F\@<WES=.EM=2!P<F4@<&]UONUV871E
MM6$@(B5S(B!B;VQO(/IS<&6Y;NDN`%9Y;6%Z86YI92`B)7,B(&)O;&\@^G-P
M9;ENZ2X`5GEM87IA;FEE("(E<R(@>F\@<WES=.EM=2!B;VQO(/IS<&6Y;NDN
M`$[A=G)A="!K=2!K;VYF:6=U<N%C:6D@8F]L(/IS<&6Y;OTN(%!R92!Z;V)R
M87IE;FEE('IM:65N('IN;W9U(&YAZ.UT86IT92!S='+A;FMU+@!:X6QO:&$@
M:V]N9FEG=7+A8VEE(&)O;&$@=6QOOF5NX2X`6N%L;[YN_2!K;VYF:6=U<F'H
M;OT@<_IB;W(@)7,@8F]L(/IS<&6Y;F4@=6QOOF5N_2X`06MT=6%L:7KA8VEA
M("(E<R(@8F]L82#Z<W!EN6[A+@!:X7!I<R`E<R!B;VP@^G-P9;EN_0!3=63A
M;@!3^FAR;@!6_6-H;V0@<VQN:V$`6N%P860@<VQN:V$`4VQN9>AN;P!6_6-H
M;V0@<VQN:V$`5OUC:&]D+WKA<&%D('-L;FMA`%;]8VAO9"!S;&YK83H@`%KA
M<&%D('-L;FMA`%KA<&%D('-L;FMA.B``2&]R;OT@:6YD97@`4&]D<&]R80!3
M=7)I;F%M`%!R:65Z=FES:V\`4W9A;&)A<F0@82!*86X@36%Y96X`4W9A>FEJ
M<VMO`*EVZ61S:V\`J79A:NAI87)S:V\`6N%Z;F%M>2!O('-Y;F-H<F]N:7KA
M8VEI('9Y;6%Z86[I`%-Y;F--3`!3>6YT86MT:6-KX2!C:'EB82!V('!O9&UI
M96YK86-H(&BU861A;FEA`%/]<FEA`$+Z<FMA`$+Z<FMA(&$@=F5T97)N;P!"
M^G)K>0!2X6YO(&+Z<FMY`%135B!S^F)O<@!486)UM6MA`%9L87-T;F]S=&D@
M=&%B=;5K>0!6;&%S=&YO<W1I('1A8G6U:WD`5&%I=V%N`%1A:7=A;BP@<')O
M=FEN8VEA(,CM;GD`5&%DOFEK:7-T86X`5&%N>N%N:6$`0VEEM3H`VFQO:'D`
M5&5L96;S;FYE(.CM<VQO`%1E<&QO=&$@>F$@<&]S;&5D;OH@:&]D:6YU.B``
M5&5P;&]T80!497!L;W1A.B``5&5P;&]T83QB<B`O/B@E<TUA>"5S+R5S36EN
M)7,I("9D96<[)7,`J6%B;/-N82`B)7,B(&YE8F]L82!NX6ID96[A+@!3<'+A
M=F$@N6%B;/-N`%1E>'0`26)A('1E>'0`6F%R;W9N86YI92!T97AT=0!497AT
M(&AO<F4`J70`5&AA:G-K;P!2;WJY[7)E;FEE($944"!N:64@:F4@9&]S='5P
M;NDN`$EN=&5G<N%C:6$@2&]R9&4O2V]L86(@;F5P;V1P;W)U:F4@(B5S(@!)
M35-0('KA>FYA;2!S82!N97!O9&%R:6QO('5L;[YINRX`5')I961A($UA:6YT
M96YA;F-E.CH@<V$@;F5N8>CM=&%L82#Z<W!EN6YE`$]K;F\@<R!N87-T879E
M;FEA;6D@<V$@>F%T=F]R:6QO+B!+;VYI96,N`$%D;6EN:7-T<N%T;W(@;75S
M[2!N86MO;F9I9W5R;W9ANR!P97)M86YE;G1N_2!B86-K96YD('!R92!0<N%V
M82P@86L@8VAC971E('!O=;[M=F&[(%!RX79A+@!)8F$@<W!O9&[A('-T<F%N
M80!)1"#H[7-L;R!K;VYT86MT=2!N96)O;&\@N7!E8VEF:6MO=F%NZ2P@8F]L
M;R!P;VYE8VAA;ND@<'+A>F1N92!A;&5B;R!N96)O;&\@;N%J9&5NZ2!V(&1A
M=&%BX7IE+@!+;VYT86MT(&)O;"#Z<W!EN6YE('9L;[YE;OT@9&\@5N&Y:&\@
M861R97/A<F$N`$YA(&]V97)E;FEE('!O9'#M<V%N96H@<W!RX79Y(&IE('!O
MOF%D;W9A;OT@;V1D96QE;OT@8FQO:R!S(%!'4"!P;V1P:7-O;2X`240@>F]Z
M;F%M=2!P<NUJ96UC;W8@8G7O(&YE8F]L;R"Y<&5C:69I:V]V86[I+"!A;&5B
M;R!B;VQO('!O;F5C:&%NZ2!P<N%Z9&YE(&%L96)O(&YE8F]L;R!NX6ID96[I
M('8@9&%T86+A>F4N`$YE8F]L('5RZ&5N_2!Z;WIN86T@<'+M:F5M8V]V+@"I
M:69R;W9A;FEE('9YOF%D=6IE(&)E>G!EZ&[I('!R:7!O:F5N:64@*&AT='!S
M*2X`4_IB;W(@)7,@8GD@;6%L(&]B<V%H;W9ANR!N87-T879E;FEE("5S+@!3
M^F)O<B`E<R!B>2!M86P@;V)S86AO=F&[(&YI96MT;W+I(&YA<W1A=F5N:6$@
M)7,N`%ID<F]J;W;](&$@8VEEM6]V_2!S^F)O<B!M=7-I82!B>;L@;V1L:;EN
MZ2X`4_IB;W(@;F5O8G-A:&]V86P@OFEA9&YE(/ID86IE+@!.87-L961U:OH@
M:&QA=FGH:WD@=&5J=&\@<W!RX79Y('9O(&9O<FWA=&4@;65S<V%G92]R9F,X
M,C(N`$-E;&]O8G)A>F]V:V]V_2!R9;YI;2!S</1S;V)U:F4@<')O8FSI;7D@
M=B!);G1E<FYE="!%>'!L;W)E<FD@:W;T;&D@8VAY8N%M('!R96AL:6%D8>AA
M+"!K=&]RZ2!S82!NX6T@;F5P;V1A<FEL;R!O8NUSNRX@3?2^=2!S82!P<F5J
M879INR!N97-P<N%V;GEM('IO8G)A>F5N[6TL(&-H_6)A:OIC:6UI(&9U;FMC
M:6%M:2!E9&ET;W)A(&$O86QE8F\@;N%H;V1N_6UI('#A9&UI('!R96AL:6%D
M8>AA+B!!:R!J92!6X;D@<WES=.EM(%=I;F1O=W,@.7@L(&IE('9EM6UI('!R
M879D97!O9&]B;NDL(+YE('-A('IO8G)A>NT@8VAY8F$@)T=E;F5R86P@4')O
M=&5C=&EO;B!&875L="<@82!B=61E=&4@;75S:66[(')EN71A<G1O=F&[('!O
MZ.UT8>@N7&Y<;E9A<F]V86QI('-M92!6X7,N(%-T;&'H=&4@<')O<^UM($]+
M(&%K(&YA;WIA:B!C:&-E=&4@<&]UOFF[(&5D:71O<B!V(&-E;&]O8G)A>F]V
M:V]V;VT@<F6^:6UE+@!)9&5N=&ET82`B)7,B(&)O;&$@=GEM87IA;N$N`$EB
M82"U87;A('-T<F%N80!4<FEE9&$@0W)Y<'1?<&=P.CH@<&]T<F5B=6IE('!O
M>FYANR!U;6EE<W1N96YI92!P<F]G<F%M=2!';G501RX`4W!RX79A(&]D;W-L
M86[A("5S('!R92`E<R!S('!R961M971O;2`B)7,B(&)O;&$@>F]B<F%Z96[A
M+@I.965X:7-T=6IE(':Y86L@>N%R=6MA+""^92!S<'+A=F$@8F]L82!P<F7H
M[71A;N$@86QE8F\@<&]C:&]P96[A+@!-96YO+"!K=&]RZ2!S82!MX2!P;W6^
M:;L@<')I(&QI;FMO=F%N[2!N82!S='+A;FMU(&YA('#M<V%N:64@<W!RX78@
M`%!OZ&5T('!O;.T@;75S[2!B>;L@Z.US;&\N`%1R:65D82!(;W)D95]#<GEP
M=%]S;6EM93HZ('9YOF%D=6IE(&UO9'5L(&]P96YS<VPN`$YA<W1A=F5N:64@
M(B5S(B!S82!N97!O9&%R:6QO('5L;[YINRP@<')E=&^^92!J96AO(/ID86IE
M('!R96MR8>AU:OH@;6%X:6WA;&YU('!O=F]L96[Z('9EM6MO<[L`4')O9W)A
M;2!P;W6^[79A;OT@;F$@>F]B<F%Z96YI92!T;VAT;R#Z9&%J;W;I:&\@='EP
M=2`H)7,I(&YE8F]L(&[A:F1E;OTN`%IN86L@8VETX6-I92!M=7/M(&)YNR!J
M961E;B!Z;F%K+@!)8F$@<')A=N$@82"U87;A('-T<F%N80!)8F$@<')A=N$@
M<W1R86YA`$]D9&6U;W9AZ"!M=7/M(&)YNR!J961E;B!Z;F%K+@!397)V97(@
M(B5S(B!B;VP@=GEM87IA;OTN`%-E<G9E<B`B)7,B(&)O;"!U;&^^96[]+@"N
M:6%D;W.[(&\@<')I:&SA<V5N:64@)7,@8F]L82!V>6UA>F%NX2X`J7!E8VEF
M:6MO=F%N_2!R:6%D;VL@;F5E>&ES='5J92X`1&_H87-N_2!S^F)O<B`B)7,B
M(&YE97AI<W1U:F4N`%IA9&%N_2!T97AT(&YI92!J92!R;W9N86O](&%K;R!T
M97AT(&YA(&]B<F%Z;W9K92X`26)A(&AO<F[A(&$@<W!O9&[A('-T<F%N80!)
M8F$@:&]R;N$@<W1R86YA`$YA:')A;ND@^F1A:F4@<V$@;V0@<')E9&-HX61Z
M86KZ8V5H;R!K<F]K=2!S=')A=&EL:2X`3F%H<F%N_2!S^F)O<B!S82!N97!O
M9&%R:6QO('5L;[YINRX`0FQO:R!W96%T:&5R+F-O;2!N:64@:F4@9&]S='5P
M;OTN`%!R:67H:6YO:R!TZ6T@(B5S(B!N96)O;"!NX6ID96[]+@"N:6%D;F4@
M;F%S=&%V96YI82!N:64@<_H@9&]S='5P;NDN`*YI861N92!A;'1E<FYA=.UV
M;F4@Z&%S=&D@;F5M;[YN;R!Z;V)R87IINR!V('1E;&4@<W!RX79Y+@!6('1O
M;71O('!O;&D@:F4@<'+M;&FY('9EM6$@>FYA:V]V+B!:861A;&D@<W1E("5S
M('IN86MO=CL@;75S[71E('IA9&&[(&UE;F5J(&%K;R`E<RX`3F%S=&%L82!C
M:'EB82!P<FD@<')I9.%V86[M("(E<R(@9&\@<WES=.EM=3H@)7,`3F%S=&%L
M82!C:'EB82!P<FD@;V1S=')A\F]V86[M('!O=;[M=F%T9;5S:_UC:"#Z9&%J
M;W8@(B5S(B!Z;R!S>7-TZ6UU.B``3F%S=&%L82!C:'EB82!P<FD@;V1S=')A
M\F]V86[M("(E<R(@>F\@<WES=.EM=3H@`$YA<W1A;&$@8VAY8F$@<')I(&%K
M='5A;&EZX6-I:2`B)7,B.B`E<P!6>7-K>71O;"!S82!P<F]B;.EM(',@;F%H
M<N%V86[M;2!S^F)O<G4Z(*YI861E;B`E<R!N96)O;"!N86AR86[]+@!6>7-K
M>71O;"!S82!P<F]B;.EM(',@;F%H<N%V86[M;2!S^F)O<G4Z("5S(&)O;"!V
MY.BY[2!A:V\@;F%J=N3HN>T@<&]V;VQE;OT@;&EM:70@*"5D(&)A:G1O=BDN
M`%9Y<VMY=&]L('-A('!R;V)LZ6T@<R!U:VQA9&%N[6T@<_IB;W)U.B`E<R!B
M;VP@;F%H<F%N_2!L96X@Z&EA<W1OZ&YE+@!.87-T86QA(&-H>6)A('!R:2!Z
M;V)R87IO=F%N[2!T96IT;R#H87-T:2!S<'+A=GD`3F%S=&%L82!C:'EB82!P
M<FD@:6UP;W)T92#Z9&%J;W8@;R!K;VYT86MT92X`3F%S=&%L82!C:'EB82!P
M<FD@:6UP;W)T92#Z9&%J;W8@:4-A;&5N9&%R+@!.87-T86QA(&-H>6)A('8@
M:V]N9FEG=7)AZ&YO;2!F;W)M=6SA<FDN(%!R879D97!O9&]B;F4@<W1E(&YE
M=GEP;&YI;&D@<&^^861O=F%NZ2!P;VQE+@!.87-T86QA(&-H>6)A('!R:2!V
M>6MO;N%V86[M('5RZ&5N96H@9G5N:V-I92!A9')E<^%R82X@4')O<^UM('-K
M^G-T92!T;R!N97-K]'(N`$YA<W1A;&$@8VAY8F$@<')I(&%K='5A;&EZX6-I
M:2!D971A:6QO=B!K;VYT86MT=2X@4')O<^UM('-K^G-T92!T;R!N97-K]'(N
M`$YA<W1A;&$@8VAY8F$@<')I(&%K='5A;&EZX6-I:2!Z;WIN86UU('!R[6IE
M;6-O=BX@4')O<^UM('-K^G-T92!T;R!Z;F]V=2X`5&5N=&\@24U!4"!S97)V
M97(@;F5P;V1P;W)U:F4@>F1I9;5A;FEE('!R:67H:6YK;W8N`%1O=&\@<')A
M=F1E<&]D;V)N92!N:64@:F4@<&QA=&[](&%R8VCM=B!R87(N`%1O=&\@<')A
M=F1E<&]D;V)N92!N:64@:F4@<&QA=&[](&%R8VCM=B!Z:7`N`%1O=&\@<')A
M=F1E<&]D;V)N92!N:64@:F4@<&QA=&[I(.CM<VQO(&MA<G1Y+@!496YT;R!O
M=FSA9&'H('5M;[[R=6IE('!O<VEE;&%N:64@<W!RX78@8V5Z(&)RX6YU($-L
M:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@<&]M;V-O=2!(5%10
M($%020!496YT;R!O=FSA9&'H('5M;[[R=6IE('!O<VEE;&%N:64@<W!RX78@
M8V5Z(&)RX6YU(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI('!O;6]C;W4@2%14
M4"!!4$D`5&5N=&\@;W9LX61AZ"!U;6^^\G5J92!P;W-I96QA;FEE('-P<N%V
M(&-E>B!B<N%N=2!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!P
M;VUO8V]U($A45%`@05!)`%1E;G1O(&]V;.%D8>@@=6UOOO)U:F4@<&]S:65L
M8;L@<W!RX79Y(&-E>B!33510(&-E>B!B<N%N=2!6;V1A9F]N92!)=&%L>2`H
M:6)A(&YA(.CM<VQA(%9O9&%F;VYE*2X@5GF^861U:F4@92UM86EL;W;](/KH
M970@5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&]T;R!P
M;VQE(&IE('!O=FEN;NDN`%1O=&\@<&]L92!M]+YE(&]B<V%H;W9ANR!I8F$@
MZ.US;&$N`%1O=&\@<&]L92!M]+YE(&]B<V%H;W9ANR!I8F$@Z.US;&$@82!D
M=F]J8F]D:W4N`%1O=&\@<&]L92!M]+YE(&]B<V%H;W9ANR!I8F$@;W-M:>AK
M;W;I(&AO9&YO='DN`%1O=&\@<&]L92!M=7/M(&)YNR!Z;WIN86T@Z.US96P@
M;V1D96QE;OUC:"#H:6%R:V]U(&%L96)O(&UE9'IE<F]U`%1O=&\@<&]L92!M
M=7/M(&)YNR!P;&%T;ND@Z.US;&\N`%1O=&\@<&]L92!M=7/M(&]B<V%H;W9A
MNR!K\V0@9F%R8GD@=B"Y97-T;N%S=&MO=F]M(&9O<FWA=&4@4D="+"!N87!R
M[6ML860@)R,Q,C,T868G+@!496YT;R!F;W)M=6SA<B!UOB!B;VP@<W!R86-O
M=F%N_2X`5&]T;R!J92`E<RX`5&]T;R!J92!O8FIE:W0@2V]L86(@1W)O=7!W
M87)E+B!0<F4@>F]B<F%Z96YI92!T;VAT;R!O8FIE:W1U('!O=')E8G5J971E
M(&4M;6%I;&]VZ6AO(&ML:65N=&$L(&MT;W+](')O>G5M:64@9F]R;>%T=2!+
M;VQA8B!'<F]U<'=A<F4N(%!R92!Z;WIN86T@=&%K_6-H=&\@:VQI96YT;W8@
M;F%VN73M=G1E('!R;W/M;2`E<P!4X71O('-P<N%V82!B;VQA(&YA<.US86[A
M('8@:6YE:B!A:V\@5F%M:2!P;W6^[79A;F5J('IN86MO=F5J('-A9&4@*"5S
M*2X`5&]T;R#H[7-L;R!M=7/M(&)YNR!N86IM96YE:B`Q+@!496YT;R!S97)V
M97(@;F5D;VOAOF4@9&5K;VUP<FEM;W9ANR!S^F)O<GD@>FEP(&$@9WII<"X`
M4WES=.EM(&IE(&UO;65N=.%L;F4@9&5A:W1I=F]V86[]+@!4X71O(&AO9&YO
M=&$@;75S[2!B>;L@Z.US96QNX2X`5&]T;R!O:VYO(&UU<^T@8GF[('IA=F]L
M86[I('H@;VMN82!.87-T879E;NT`2')M96YI90!4:6-K971S`,AA<P!4:6UE
M(%1R86-K:6YG`$9O<FWA="#H87-U`%;]8F5R(.AA<W4`5&EM;W(M3&5S=&4`
M5&ET=6QO:P!.861P:7,@*&)U8FQI;F]V_2!V_7!I<RDZ`%!R90!0<F4@=OUB
M97(@=FEA8V5R_6-H('!O;&^^:65K(&1ROG1E('!OZ&%S(&ML:6MA;FEA(&ML
MX79E<W4@0V]N=')O;"`H4$,I(&%L96)O($-O;6UA;F0@*$UA8RDN`$1N97,`
M4')E<&[ZNR!Z;V)R87IE;FEE('ID<F]J;W;I:&\@:_-D=2!(5$U,`%1O9V\`
M5&]K96QA=0!:86IT<F$`5&]N9V$`5G)C:`!6<F-H;OT@<N%M96,@*%]T;W`I
M`%!R96ML861Y`%1R:6YI9&%D(&$@5&]B86=O`%!R879D82!A;&5B;R!N97!R
M879D80!5=`!4=6YI<VMO`%1U<F5C:V\`5'5R:VUE;FES=&%N`%1U<FMS(&$@
M0V%I8V]S`%1U=F%L=0!:861A:G1E(%9AN74@=F^U8G4Z(`!5+E8N(&EN9&5X
M.B``55),`%523"!6X;EH;R!S:W)I<'1U('!R92!S<'+A=G4@;R!D;W)UZ&5N
M[0!54DPZ`%5G86YD80!5:W)A:FEN80!.97!O9&%R:6QO('-A('5S:W5T;^AN
M:;L@<'+M<W1U<"!K(%9&4R!A9')E<^%R=2X`3F5P;V1A<FEL;R!S82!P<FED
M8;L@[V%LN6EE(&EN9F]R;>%C:64@;R!P;W6^[79A=&6U;W9I('!R:2!R96=I
M<W1RX6-I:2X`3F5P;V1A<FEL;R!S82!Z;65N:;L@<'+A=F\@<')E(%9&4R!S
M^F)O<B`B)7,B+@!.97!O9&%R:6QO('-A('IM96YINR!P<N%V;R!P<F4@5D93
M('/Z8F]R("5S+R5S+@!.97!O9&%R:6QO('-A('IM96YINR!N82`E<RX`3F5P
M;V1A<FEL;R!S82!S:V]N=')O;&]V8;L@=F6U:V]SNR!S^F)O<G4@(B5S(BX`
M3F5P;V1A<FEL;R!S82!S:V]N=')O;&]V8;L@=F6U:V]SNR!S^F)O<G4@(B5S
M+R5S(BX`3F5P;V1A<FEL;R!S82!S<&]J:;L@<R!344P@<V5R=F5R;VTN`$YE
M<&]D87)I;&\@<V$@<W!O:FF[('!O;6]C;W4@4U-,+@!.97!O9&%R:6QO('-A
M('-K;W#M<F]V8;L@5D93('/Z8F]R+@!.97!O9&%R:6QO('-A('9Y='9O<FF[
M(%9&4R!A9')E<^%R("(E<R(N`$YE<&]D87)I;&\@<V$@=GET=F]R:;L@5D93
M(&%D<F5SX7(N`$YE<&]D87)I;&\@<V$@=GET=F]R:;L@5D93('/Z8F]R+@!.
M97!O9&%R:6QO('-A('9Y='9O<FF[(%9&4R!P<FEEZ&EN;VL@(B5S(BX`3F5P
M;V1A<FEL;R!S82!V>71V;W)INR!P<N%Z9&YY(%9&4R!S^F)O<BX`3F5P;V1A
M<FEL;R!S82!D96MO;7!R:6UO=F&[(/ID86IE+@!.97!O9&%R:6QO('-A('9Y
M;6%Z8;L@(B5S(BP@861R97/A<B!N:64@:F4@<'+A>F1N>2X`3F5P;V1A<FEL
M;R!S82!V>6UA>F&[("(E<R(Z("5S+@!.97!O9&%R:6QO('-A('9Y;6%Z8;L@
M)7,L(&%D<F5SX7(@;FEE(&IE('!RX7ID;GD`3F5P;V1A<FEL;R!S82!R96MU
M<GKM=FYE('9Y;6%Z8;L@5D93(&%D<F5SX7(N`$YE<&]D87)I;&\@<V$@=GEM
M87IANR!61E,@861R97/A<BX`3F5P;V1A<FEL;R!S82!V>6UA>F&[(%9&4R!A
M9')E<^%R.B`E<RX`3F5P;V1A<FEL;R!S82!V>6UA>F&[(%9&4R!S^F)O<B`B
M)7,B+@!.97!O9&%R:6QO('-A('9Y;6%Z8;L@5D93('/Z8F]R+@!.97!O9&%R
M:6QO('-A('9Y;6%Z8;L@5D93('!R:67H:6YO:R`B)7,B+@!.97!O9&%R:6QO
M('-A(')E:W5R>NUV;F4@=GEM87IANR!61E,Z("5S+@!.97!O9&%R:6QO('-A
M('5RZ&F[(&%K='7A;&YY(&%D<F5SX7(N`$YE<&]D87)I;&\@<V$@>FES=&F[
M('!O9')O8FYO<W1I(&\@8V5R=&EF:6OA=&4N`$YE;6^^;ND@;F%H<F&[(&1E
M9FEN[6-I=2`E<RX`3F5P;V1A<FEL;R!S82!P<F5S=6[ZNR!61E,@<_IB;W(N
M`$YE<&]D87)I;&\@<V$@;W1V;W)INR!61E,@<_IB;W(@(B5S(BX`3F5P;V1A
M<FEL;R!S82!O='9O<FF[(%9&4R!S^F)O<B!N82!ZX7!I<RX`3F5P;V1A<FEL
M;R!S82!O='9O<FF[(%9&4R!S^F)O<BX`3F5P;V1A<FEL;R!S82!O='9O<FF[
M(&MO;7!R:6UO=F%N_2!A<F-H[78N`$YE<&]D87)I;&\@<V$@<')EZ.UT8;L@
M5D93('/Z8F]R("AF=6YK8VEA(&9I;&5S:7IE*"D@>FQY:&%L82DN`$YE<&]D
M87)I;&\@<V$@<')EZ.UT8;L@5D93('/Z8F]R("AF=6YK8VEA(&=E=$9I;&53
M:7IE*"D@>FQY:&%L82DN`$YE<&]D87)I;&\@<V$@<')EZ.UT8;L@<_IB;W(Z
M`$YE<&]D87)I;&\@<V$@Z.UT8;L@861R97/A<B!V9G-R;V]T+@!.97!O9&%R
M:6QO('-A('!R96UE;F]V8;L@)7,@;F$@)7,Z(&-I9;5O=OT@<')I9>AI;F]K
M('6^(&5X:7-T=6IE`$YE<&]D87)I;&\@<V$@<')E;65N;W9ANR!61E,@861R
M97/A<BX`3F5P;V1A<FEL;R!S82!P<F5M96YO=F&[(%9&4R!A9')E<^%R.B`E
M<RX`3F5P;V1A<FEL;R!S82!P<F5M96YO=F&[(%9&4R!S^F)O<B`B)7,B+@!.
M97!O9&%R:6QO('-A('!R96UE;F]V8;L@5D93('/Z8F]R("5S+R5S+@!.97!O
M9&%R:6QO('-A('!R96UE;F]V8;L@5D93('/Z8F]R+@!.97!O9&%R:6QO('-A
M('-P=7-T:;L@)VUK:7-O9G,G+@!.97!O9&%R:6QO('-A('!R96QOOFF[('1E
M;G1O(&1O:W5M96YT(%=O<F0`3F5P;V1A<FEL;R!S82!Z87#M<V&[(%9&4R!S
M^F)O<B`B)7,B+@!.97!O9&%R:6QO('-A('IA<.US8;L@5D93('/Z8F]R("AF
M=6YK8VEA(&-O<'DH*2!Z;'EH86QA*2X`3F5P;V1A<FEL;R!S82!Z87#M<V&[
M(/ID86IE(%9&4R!S^F)O<G4N`$YE<&]D87)I;&\@<V$@>F%P[7-ANR!61E,@
M<_IB;W(L(&MV\W1A(&IE('!R96MR;^AE;N$N`%!O9.AI87)K;G5TZ0!:<G6Y
M:;L@>FUE;GD`6G)UN>T@<&]S;&5D;OH@86MC:74`3F5OZ&%KX79A;N$@;V1P
M;W9E[R!O9"!S97)V97)A('!OZ&%S('-P;VIE;FEA.B``3F5OZ&%KX79A;N$@
M;V1P;W9E[R!O9"!S97)V97)A(&YA.B``3F5N87-T879E;N$`4W!O:F5NZ2!A
M<F%B<VOI(&5M:7+A='D`5F6U:^$@0G)I=.%N:6$`4W!O:F5NZ2"Y=.%T>2!!
M;65R:6-KZ0!*961N;W1K>0!.97INX6UE`$YE>F[A;64@87!I;7-G:60@*$%0
M22!-97-S86=E($E$*2X`3F5Z;N%M92!C;&EM<V=I9"`H0VQI96YT($UE<W-A
M9V4@240I+@!";VQA('IA9&%NX2!N97!L871NX2!L;VMA;&ET82X`3F5Z;N%M
M92!P;W6^[79A=&6U<VOI(&UE;F\@86QE8F\@:&5S;&\N`$]D<W1RX6YINR!L
M:6YK=2!Z(&%K='7A;&YE:&\@96QE;65N='4`3F5P;VUE;F]V86[A`$YE<')I
M=FEL96=O=F%NZ2!S:W)I<'1Y(&YE;6%J^B!Z(&)E>G!EZ&YO<W1N_6-H(&3T
M=F]D;W8@<'+M<W1U<"!K('9OM6+A;2!6>7-T<FEH;OJ[+TMO<.UR;W9ANR]6
M;&^^:;LN($ML:6MN:71E(&YA($]+(&$@>F]B<F%Z[2!S82!T96-H;FEC:^$@
M:6YF;W)MX6-I82!N82!S='+A;FME(&UO>FEL;&$N;W)G+"!K=&]RX2!6X7,@
M:6YF;W)M=6IE+"!A:V\@=6UOOFYINR!S:W)I<'1U('!R[7-T=7`@:R!S8VAR
MX6YK92X`3V1S='+A;FF[(&9A<F)U`$YE<&]D<&]R;W9A;ND@<F]ZN>UR96YI
M90!!:W1U86QI>N%C:6$`06MT=6%L:7IO=F&[("5S`$%K='5A;&EZ;W9ANR!P
M;W6^[79A=&6U80!!:W1U86QI>N%C:6$@(B5S(B!B;VQA(/IS<&6Y;N$N`%-K
M<FEP="!N82!U<&=R861E(&)O;"!V>6UA>F%N_2X`3F%H<F&[`%:Y971K>2!S
M^F)O<GD@<R!K;VYF:6=U<N%C:6]U(&)O;&D@;F%H<F%NZ2!N82!S97)V97(N
M`%9EM6OI(&QA=&EN<VOI('#M<VUE;N$`5F6U:^D@<NUM<VME(.CM<VQI8V4`
M57)U9W5A>0!0;W6^:;L@86MT=>%L;F4Z("5S`%!O=;YINR!34TP`4&]UOFET
M92!V('!R[7!A9&4L(+YE(&IE(&UE;F\O:&5S;&\@;V1L:;ENZ2!P<F4@24U3
M4"!S97)V97(N`%!O=;[M=F%T9;4`4&]UONUV871EM2`E<R!N:64@:F4@875T
M;W)I>F]V86[](&YA("5S+@!3<'+A=F$@<&]UONUV871EM6]V`%!O=;[M=F%T
M9;5S:^D@;F%S=&%V96YI80!296=I<W1RX6-I82!P;W6^[79A=&6U80!296=I
M<W1RX6-I82!P;W6^[79A=&6U;W8@8F]L82!P<F4@=&5N=&\@<WES=.EM('IA
M:^%Z86[A+@!0;W6^[79A=&6U<VO](/KH970@;F5B;VP@;N%J9&5N_0!0;W6^
M[79A=&6U<VOI(&UE;F\`4&]UONUV871EM7-KZ2!M96YO("(E<R(@=;X@97AI
M<W1U:F4N`%!O=;[M=F%T9;5S:^D@;65N;SH`4&]UONUV871EM7-KZ2!M96YO
M.B``4&]UONUV871E;&EA('-Y<W3I;74Z`%5Z8F5K:7-T86X`5D93(&%D<F5S
MX7(@;F5E>&ES='5J92X`1&]V;VQE;FMA`%!L871NZ2!U;6EE<W1N96YI82!Z
M86C@\F%J^CH@`%!L871N;W.[`%!L871N;W.[('8@;6EN^G1A8V@@;V1T97)A
M>BX`2&]D;F]T82!P<F5K<F_H:6QA(&UA>&EMX6QN=2!DY;YK=2`E<RX`2&]D
M;F]T>0!(;V1N;W1Y+"!Z(&MT;W+]8V@@<VD@;?2^971E('9Y8G)ANP!686YU
M871U`%!R96UE;F[A`%9E;F5Z=65L80!/=F5R96YI92!Z;'EH86QO("T@=.%T
M;R!S<'+A=F$@;6]H;&$@8GF[('-F86RY;W9A;N$N`%9E<GII80!-86YAOFUE
M;G0@=F5R>FGM`%9E<G1I:^%L;F4@>F%R;W9N86YI90!697)T:6OA;&YE('9Y
M<&QN96YI90!697)T:6OA;&YE.@!69;5M:2!V>7-O:^$`5FEE=&YA;0!:;V)R
M87IINR`E<P!:;V)R87IINR!E>'1E<F[Z('=W=R!S='+A;FMU`%IO8G)A>FF[
M(&%K;R`E<P!"<FET<VOI(%!A;F5N<VOI(&]S=')O=GD`06UE<FEC:^D@4&%N
M96YS:^D@;W-T<F]V>0!6:61I=&6U;F]SNP!6:61I=&6U;F]SNSH@`%9O9&%F
M;VYE($ET86QY(&-E>B!33510`%9!4D]604Y)10!54$]:3U).14Y)12$A(2!/
M1%-44L'25$4@4TM225!4(%H@)7,@4E7(3D4N`%=)3B!C97H@2%144`!786QL
M:7,@82!&=71U;F$`5F%R;W9A;FEE`%-T`%!R961P;W9E[R!P;^AA<VEA`-ID
M86IE(&\@<&_H87/M('!O<VMY='5J90!796%T:&5R+F-O;0!796(`5U=7('-T
M<N%N:V$`5/V^9&5N;F4`5FET86IT90!6[71A(%;A<R`E<P!6:71A:G1E+"`E
M<P!:X7!A9&[A(%-A:&%R80!+=&]R^B!A<&QI:^%C:74@;>$@)7,@>F]B<F%Z
M:;L@<&\@<')I:&SA<V5N[3\`06O](&IE('IN86L@<')E(&]D9&6U;W9AZ#\`
M06O](&IE('IN86L@<')E(/IV;V1Z;W9K=3\`36%P82!!=7-T<N%L:64@<')E
M('-L=;YB=2!7:&5R96ES`$MT;W+I(&;A>GD`2W1O<ND@>N%S=79NZ2!M;V1U
M;'D@<&]V;VQINR!P<F4@<F]ZN>UR96[]('1E>'1O=OT@961I=&]R+@"I[7)K
M80"I[7)K82!V(&IE9&YO=&OA8V@@0U-3`*GM<FMA(&UE;G4@)7,@=K5A=F\@
M*'!R96IA=NT@<V$@<')I(.]A;+EO;2!P<FEH;.%S96[M*3H`J>UR:V$@=&%B
M=;5K>0!*961N;W1K82"Y[7)K>0"I[7)K83H`5VEK:0!6:65T;W(`4N%N;R!V
M:65T;W(`4OUC:&QO<[L@=F5T<F$@=B!U>FQO8V@`5FEE=&]R.@!6:65T;W(Z
M(`!-^F1R;W.[`%=I<VAL:7-T`%!RX6-A`$%D<F5S82!D;R!P<N%C90!496QE
M9O-N(&1O('!RX6-E`$YE<W!RX79N>2!P;^AE="!P;VSM(&YA(')I861K=2`E
M9"X@3^AA:^%V82!S82`E9"P@;F&Y;&\@<V$@)60N`$YE<W!RX79N>2!P;^AE
M="!P;VSM+B!/Z&%KX79A('-A("5D+"!N8;EL;R!S82`E9"X`6FS](&]F9G-E
M="`E9"!P<FD@Z.UT86[M(%9&4R!S^F)O<G4N`%@M4F5F`%KA:VQA9&[I(&]B
M;65D>F5N:6$@6#4P.78S`%!O=;YI=&EE(')O>KGM<F5NZ6AO(&NU^NAA(%@U
M,#EV,P!!;'1E<FYA=.UV;F4@;65N;R!S=6)J96MT=2!8-3`Y=C,`261E;G1I
M9FEKX71O<B!KM?KH82!S=6)J96MT=2!8-3`Y=C,`6#4P.78S(')O>KGM<F5N
M:6$`65D`65E960!986AO;R$@;6%P`%)OZ&YE`$IE;65N`$%N;P!3^FAL87/M
M;2X`4W1E('8@5$585$]63TT@4D6N24U%+B!0;W6^:71E('1L8>AI9&QO(%L\
M/ET@;F$@<')E<&YU=&EE(&YA<W#DNR!D;R!765-)5UE'+@!.96WTOF5T92!V
M>71V;W)INR!V:6%C(&%K;R`E9"!B;&]K;W8N`$YI92!S=&4@875T96YT:69I
M:V]V86[]+@!6;R!68;EO;2!P;&YO;2!M96YE(&YE;?2^971E('!O=;YINR!Z
M;F%K("=<)RX`3F5Z861A;&D@<W1E('!L871N^B!E+6UA:6QO=OH@861R97-U
M+@!.975RZ&EL:2!S=&4@=GJ[86@@;65D>FD@OFEA9&YY;6D@<&]L:6%M:2!Z
M(&EM<&]R=&]V86[I:&\@<_IB;W)U(&$@>F]D<&]V961A:OIC:6UI('!OM6%M
M:2!V("5S+@!";VQI('-T92!O9&ALX7-E;OTN`$UU<^UT92!Z861ANR!P;&%T
M;ND@Z.US;&\@;6]B:6QNZ6AO('1E;&5F\VYU+"!K=&]RZ2!O8G-A:'5J92!I
M8F$@Z.US;&$@<R!V;VQI=&6U;OUM('!R969I>&]M("<K)R!P<F4@;65D>FEN
MX7)O9&[](&9O<FWA="X`375S[71E('IA9&&[('!L871N^B!H;V1N;W1U+@!!
M8GD@<W1E(&UO:&QI('!O=;[M=F&[(%)E9VES='+A8VEE+"!M=7/M=&4@;F%J
M<VOT<B!N86MO;F9I9W5R;W9ANR!$871A5')E92!B86-K96YD+@!-=7/M=&4@
M;F%K;VYF:6=U<F]V8;L@5D93(&)A8VME;F0N`$UU<^UT92!P;W#M<V&[('!R
M;V)LZ6T@<')E9'3];2P@86MO(&]D;[EL971E('-P<N%V=2!O('!R;V)LZ6UE
M+@!-=7/M=&4@>F%D8;L@55),(&%D<F5S=2P@;F$@:W1O<OH@=.%T;R!L:6YK
M82!U:V%Z=6IE`$UU<^UT92!V>6)R8;L@<V5R=F5R+"!K=&]R_2!MX2!B>;L@
M=GEM87IA;OTN`$UU<^UT92!U<NAINR!M96YO('!O=;[M=F%T9;5A+"!K=&]R
MZ6AO(&-H8V5T92!V>6UA>F&[+@!-=7/M=&4@=7+H:;L@;65N;R!P;W6^[79A
M=&6U82P@:W1O<NEH;R!C:&-E=&4@=GEM87IANRX`375S[71E('5RZ&F[(&UE
M;F\@<&]UONUV871EM6$L(&MT;W+I:&\@8VAC971E('!R:61ANRX`375S[71E
M('5RZ&F[('!O=;[M=F%T9;5A+"!K=&]R_2!S82!MX2!A:W1U86QI>F]V8;LN
M`$UU<^UT92!U<NAINR!A:V-I=2P@:W1O<N$@<V$@;>$@=GEK;VYANRX`375S
M[71E('IA9&&[(&UE;F\@;F]V96H@:V%T96?S<FEE+@!-=7/M=&4@>F%D8;L@
M=&%L:6%N<VME('1E;&5F\VYN92#H[7-L;P!0;&%T;F]SNR!68;EE:B!R96SA
M8VEE('!R92!A<&QI:^%C:74@)7,@=GEP<KEA;&$N(%!R;W/M;2!P<FEH;.%S
M=&4@<V$@>FYO=G4N`%9AN6$@16UA:6QO=N$@861R97-A`%9AN6$@16UA:6QO
M=N$@861R97-A('!O=;YI=.$@<')E(&]D8VCA9'IA:OIC=2!P;[ET=3H`5F&Y
M92!I;F9O<FWA8VEE`%9AN6$@:6YT97)N971O=N$@861R97-A('-A('IM96YI
M;&$@;V0@>F'H:6%T:W4@5F&Y96H@<F5LX6-I92`E<RX@4')E(%9AN74@8F5Z
M<&7H;F]SNR!S82!M=7/M=&4@>FYO=G4@<')I:&SA<VF[+@!68;EE(&UE;F\`
M5N&Y(&%U=&5N=&EF:6MAZ&[](&UO9'5L(&YE<&]D<&]R=6IE('!R:63A=F%N
M:64@<&]UONUV871EM6]V+B!!:R!S:2"^96SA=&4@<&]UOFF[($AO<F1E(&YA
M('-P<N%V=2!P;W6^[79A=&6U<VO]8V@@^NAT;W8L(&UU<^UT92!P;W6^:;L@
M:6[](&%U=&5N=&EF:6MAZ&[](&)A8VME;F0N`%;AN2!A=71E;G1I9FEK8>AN
M_2!M;V1U;"!N97!O9'!O<G5J92!Z;V)R87IO=F%N:64@>F]Z;F%M=2!P;W6^
M[79A=&6U;W8L(&%L96)O(&)O;&$@=.%T;R!M;[YN;W.[('H@;F5J86OI:&\@
M9/1V;V1U('IA:^%Z86[A+@!:9.$@<V$L(+YE(%;AN2!P<F5H;&EA9&'H('-A
M('IM96YI;"!O9"!Z8>AI871K=2!68;EE:B!R96SA8VEE("5S+B!0<F4@5F&Y
M=2!B97IP9>AN;W.[('-A(&UU<^UT92!Z;F]V=2!P<FEH;.%S:;LN`%;AN2!P
M<F5H;&EA9&'H(&YE<&]D<&]R=6IE('3Z=&\@9G5N:V-I=2X`5N&Y('!R96AL
M:6%D8>@@;F5P;V1P;W)U:F4@=/IT;R!F=6YK8VEU('1L8>AE+B!3=&QAZ'1E
M($-O;G1R;VPO0V]M;6%N9"`K(%`@<')E('1L8>@N`%9AN6$@86MT=>%L;F$@
MZ&%S;W;A('KS;F$Z`%9AN6$@<')E9&YA<W1A=F5NX2!I9&5N=&ET82!B;VQA
M('IM96YE;N$N`%!R961N87-T879E;N$@:61E;G1I=&$Z`%9AN64@;65N;SH`
M4&QA=&YO<[L@5N&Y:&\@^NAT=2!V>7!RN6%L82X`5F&Y92!N;W;I(&AE<VQO
M('!R92`E<R!J93H@)7,`5F&Y92!N87-T879E;FEA(&)O;&D@86MT=6%L:7IO
M=F%NZ2!P<F4@=&]T;R!S961E;FEE+@!68;EE(&YA<W1A=F5N:6$@8F]L:2!A
M:W1U86QI>F]V86[I+@!68;EE(&AE<VQO(&)O;&\@;V)N;W9E;ND`5F&Y92!H
M97-L;R!B;VQO(&]B;F]V96[I+"!S:V]N=')O;'5J=&4@<VD@<&^Y='4@82!P
M<FEH;.%S=&4@<V$@<R!68;GM;2!N;W;];2!H97-L;VTN`%!L871N;W.[(%;A
MN6AO(&AE<VQA('9Y<'*Y86QA+@!68;EE('9Z9&EA;&5NZ2!S97)V97)Y.@!*
M=6AO<VSA=FEA`%IA:7(`6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M3:W)YNR!C
M:71O=F%N_2!T97AT70!;4W!RX79A(&\@<')O8FSI;65=`%M:;V)R87IINR!C
M:71O=F%N_2!T97AT("T`6UIO8G)A>FF[(&-I=&]V86[]('1E>'0@+2`E<R!R
M:6%D:V]V70!;<FEA9&]K("5S('H@)7-=`%]!9&UI;FES='+A8VEA`%]#3$D`
M7T1A=&%4<F5E`%]6>6UA>F&[(')I861O:P!?4VMU<&EN>0!?4&]M;V-N[6L`
M5FQA<W1N;W-T:2!?;V)RX7IK=2XN+@!?4')I:&SA<VF[('-A`%]/9&ALX7-I
MNR!S80!?57!R879INR!L:6YK=2XN+@!?3F%S=&%V96YI80!?4'+A=F$`3V1S
M=%]RX6YINR!L:6YK=2XN+@!.85]S=&%V96YI90!6;&%S=&YO<W1I(%]T86)U
MM6MY+BXN`%!O7W6^[79A=&5L:6$`861R97/A<@!A9')E<^%T(&YE>F[A;7D`
M:V%L96YDX7(`8F5Z=F5T<FEE`&YE<&]D87)I;&\@<V$@=GET=F]R:;L@=OUS
M='5P;OT@<_IB;W(`;F5P;V1A<FEL;R!S82!O='9O<FF[('9S='5P`&ML:6MN
M:71E('-E;0!C:'EB82!P<FD@<&]UOFET[2!P<NUK87IO=NEH;R!R:6%D:W4`
M8VAY8F$@:V]N9FEG=7+A8VEE`&-H_6)A(&3T;&6^:73]('-Y<W3I;6]V_2!S
M^F)O<@!C:'EB82!F;W)MX71U(/ID86IO=@!P;VQOOFMA(&YE;N%J9&5NX0!K
M;&5SX0!S^F)O<@!Z;R!S;65R=2`E<R`H)7,I('+]8VAL;W.[;W4@)7,@)7,`
M;N%R87IO=OT`=CH`:&@`;F5Z;N%M92!M96YO(&AO<W1I=&6U80!O:V%MOFET
M90!V('-P<N%V90!C:'EB82!V<W1U<'4O=OUS='5P=0!I;G1E<F[A(&-H>6)A
M('-O9G1VZ7)U`')I861K;W9=`'!OZ&%S('9Y=';A<F%N:6$@25-/(&YA<W1A
M;&$@8VAY8F$@;6MI<V]F<R`E9`!M;0!M96YO`&YE:6UP;&5M96YT;W9A;ND`
M>F%T:6&U(&YE:6UP;&5M96YT;W9A;ND`<&]Z;N%M:V]V_2!B;&]K`'!E<F-E
M;G0`<'+M<W1U<"!Z86UI971N=73]`&)O9&]V`'9Z9&EA;&5NX2!C:'EB82!V
M('!R;W1O:V]L90!S=/IP80!S;'6^8F$@;FEE(&IE(&1O<W1U<&[A`'IO8G)A
M>FF[(')O>F1I96QY`'-M<S)E;6%I;"!C97H@2%144`!S<P!U<W3A;&5N_0!S
M>7-TZ6UO=N$@8VAY8F$`>F]Z;F%M(/IL;V@`9&_H87-NX2!C:'EB80!P<F4@
M<&]T=G)D96YI92!Z861A:G1E(&AE<VQO(&1V86MRX70`=6YI9FEK;W9A;ND`
M;F5P;VUE;F]V86[A`&1E9FEN=6IE('!O=;[M=F%T9;4`=D-A<F0`N3H`=V5A
M=&AE<BYC;VT`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L;V-A;&4O<VM?4TLO:&5L<"YX;6P`````````
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,S,C`@,3`U,34T
M,S,W-#(@,#(Q-#8P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_>&UL('9E<G-I;VX](C$N,"(_/@H\(2TM("1(;W)D93H@
M:&]R9&4O;&]C86QE+W-K7U-++VAE;'`N>&UL+'8@,2XR(#(P,#0O,#4O,C<@
M,C`Z,C(Z,3,@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT<GD@:60](G-U
M;6UA<GDB('-T871E/2)N97<B/@H\=&ET;&4^5&AE(%!O<G1A;"!086=E/"]T
M:71L93X*(#QP87)A/@H@(%1H:7,@<&]R=&%L('!A9V4@<')O=FED97,@82!Q
M=6EC:R!S=6UM87)Y(&]F(&%L;"!Y;W5R(&EM<&]R=&%N=`H@(&EN9F]R;6%T
M:6]N+B!&;W(@97AA;7!L92P@:70@;6EG:'0@<VAO=R!H;W<@;6%N>2!N97<@
M92UM86EL(&UE<W-A9V5S('EO=0H@(&AA=F4@:6X@>6]U<B!)3D)/6"P@=7!C
M;VUI;F<@979E;G1S(&]N('EO=7(@8V%L96YD87(L('1A<VMS(&]N('EO=7(@
M=&\M9&\*("!L:7-T+"!H96%D;&EN97,@9G)O;2!S96QE8W1E9"!N97=S('-E
M<G9I8V5S+"!A;F0@<V\@;VXN("!-86YY(&]F('1H97-E"B`@<W5M;6%R:65S
M('=I;&P@8V]N=&%I;B!Q=6EC:R!S:&]R=&-U=',@=&\@8V]M;6]N(&9U;F-T
M:6]N<RP@<W5C:"!A<PH@(&-O;7!O<VEN9R!A(&YE=R!M86EL(&UE<W-A9V4L
M(&-R96%T:6YG(&$@;F5W(&-A;&5N9&%R(&5V96YT(&]R('1A<VLL(&5T8RX*
M(#PO<&%R83X*(#QP87)A/@H@(%1H92!C;VYT96YT<R!O9B!T:&ES('!O<G1A
M;"!P86=E(&%R92!C=7-T;VUI>F%B;&4@=FEA('1H92!,87EO=70@8G5T=&]N
M+@H@($9O<B!E>&%M<&QE+"!Y;W4@8V%N(&-H;V]S92!W:&EC:"!I=&5M<R!T
M;R!I;F-L=61E(&]N('1H:7,@<&]R=&%L('!A9V4@87,*("!W96QL(&%S(&EN
M('=H:6-H(&]R9&5R('1H97D@87)E('-H;W=N+@H@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB;F%V8F%R(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H
M92!!<'!L:6-A=&EO;B!.879I9V%T:6]N($)A<CPO=&ET;&4^"B`\<&%R83X*
M("!!="!T:&4@;&5F="!H86YD('-I9&4@;V8@=&AE('=E8B!P86=E(&ES('1H
M92!A<'!L:6-A=&EO;B!N879I9V%T:6]N(&)A<BX*("!#;&EC:R!O;B!T:&4@
M:6-O;G,@;VX@=&AI<R!N879I9V%T:6]N(&)A<B!T;R!Q=6EC:VQY(&%N9"!E
M87-I;'D@<W=I=&-H"B`@8F5T=V5E;B!T:&4@879A:6QA8FQE(&%P<&QI8V%T
M:6]N<RX*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61O
M7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E
M;F-E<SH@36%I;G1E;F%N8V4Z($1O($UA:6YT96YA;F-E/"]T:71L93X*("`@
M(#QP87)A/@H@("`@268@>6]U('=O=6QD(&QI:V4@=&\@<&5R9F]R;2!M86EN
M=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN+"!C:&5C:R!T:&ES(&)O>"X*
M("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6-O;F9I
M<FU?;6%I;G1E;F%N8V4B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E
M<F5N8V5S.B!-86EN=&5N86YC93H@0V]N9FER;2!-86EN=&5N86YC93PO=&ET
M;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O(&-O;F9I
M<FT@86QL(&UA:6YT96YA;F-E('1A<VMS(&)E9F]R92!T:&5Y(&%R92!R=6XL
M(&-H96-K('1H:7,@8F]X+B!)9B!L969T('5N8VAE8VME9"P@86QL(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,@=&AA="!N965D('1O(&)E(')U;B!W:6QL(&)E
M('!E<F9O<FUE9"!A=71O;6%T:6-A;&QY('=I=&@@;F\@8VAA;F-E('1O(&-A
M;F-E;"!O;B!L;V=I;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*/"]H96QP/@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&]C86QE+W-L7U-)````````````````````````````
M`````````````````````````````````````````````````````````#`P
M,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S0R
M(#`Q-S<S,``@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O<VQ?4TDO3$-?
M34534T%'15,`````````````````````````````````````````````````
M````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#`P,#`@,3`U,34T,S,W-#(@,#(Q-3$U`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQO8V%L92]S;%]322],0U]-15-304=%4R]H;W)D92YM;P``````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#,U,#`S,R`Q,#4Q-30S,S<T,B`P,C,R,S8`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````WA($E0``
M``"<!@``'````/PT``#;"```W&D```````!(C0``#@```$F-```/````6(T`
M``T```!HC0``"````':-```+````?XT```P```"+C0``!````)B-```8````
MG8T``!L```"VC0``+0```-*-```=`````(X``"0````>C@``*0```$..```9
M````;8X``"8```"'C@``#````*Z.```D````NXX```\```#@C@``"P```/".
M```.````_(X```4````+CP``*````!&/```(````.H\```H```!#CP``%0``
M`$Z/```2````9(\```L```!WCP``A0```(./```.````"9````H````8D```
M#0```".0```.````,9```!$```!`D```#0```%*0```,````8)````T```!M
MD```!@```'N0``"4````@I````H````7D0``#P```"*1```8````,I$```P`
M``!+D0``#@```%B1```.````9Y$```@```!VD0``"0```'^1```N````B9$`
M`!H```"XD0``,@```-.1```X````!I(``%0````_D@``40```)22``!:````
MYI(``%<```!!DP``-````)F3```)````SI,```T```#8DP``!P```.:3```*
M````[I,```\```#YDP``!0````F4```&````#Y0```@````6E```)0```!^4
M```@````190``!,```!FE```$````'J4```/````BY0```H```";E````P``
M`*:4```/````JI0``!0```"ZE```"0```,^4```-````V90``!(```#GE```
M&0```/J4```>````%)4```\````SE0``"@```$.5```/````3I4```@```!>
ME0``)````&>5```4````C)4``!8```"AE0``"````+B5``!.````P94``"T`
M```0E@``&0```#Z6```'````6)8```P```!@E@``+````&V6```.````FI8`
M``,```"IE@``"P```*V6```'````N98```<```#!E@``!0```,F6```#````
MSY8``!<```#3E@``"@```.N6```/````]I8``!@````&EP``(P```!^7```.
M````0Y<``!0```!2EP``%P```&>7```7````?Y<``!<```"7EP``$P```*^7
M```.````PY<``!\```#2EP``'0```/*7```'````$)@```8````8F```"```
M`!^8```/````*)@```8````XF```"@```#^8```3````2I@```L```!>F```
M$````&J8```5````>Y@``!4```"1F```!P```*>8```%````KY@``!4```"U
MF```$0```,N8```,````W9@``#L```#JF```.````":9```)````7YD```<`
M``!IF0``%````'&9```#````AID```4```"*F0``"0```)"9```3````FID`
M`#D```"NF0``$@```.B9```G````^YD``"P````CF@``*@```%":```E````
M>YH```H```"AF@``!@```*R:```)````LYH```<```"]F@``+P```,6:```W
M````]9H``"X````MFP``50```%R;```M````LIL``"T```#@FP``/0````Z<
M```_````3)P``"T```",G```0````+J<```C````^YP``",````?G0``0```
M`$.=```M````A)T``#,```"RG0``)0```.:=```5````#)X``!D````BG@``
M*0```#R>```D````9IX``"@```"+G@``$0```+2>```*````QIX```P```#1
MG@``%@```-Z>```6````]9X```<````,GP``!P```!2?```4````')\```H`
M```QGP``"````#R?```G````19\```<```!MGP``!P```'6?```&````?9\`
M``4```"$GP``!P```(J?```&````DI\```@```"9GP``*0```**?```.````
MS)\```H```#;GP``!P```.:?```)````[I\``!8```#XGP``!`````^@```(
M````%*````T````=H```!@```"N@```>````,J```!$```!1H```"````&.@
M```,````;*````<```!YH````P```(&@```#````A:```!<```")H```'0``
M`*&@```(````OZ````0```#(H```"````,V@```(````UJ```"L```#?H```
M(`````NA```5````+*$```8```!"H0``!@```$FA```5````4*$``#H```!F
MH0``&````*&A```B````NJ$``#,```#=H0``+@```!&B```=````0*(``"$`
M``!>H@``5````("B``!`````U:(``"D````6HP``&0```$"C```*````6J,`
M``<```!EHP``%0```&VC```.````@Z,```H```"2HP``"0```)VC```4````
MIZ,``!@```"\HP``'0```-6C```3````\Z,``!$````'I```%````!FD```$
M````+J0```8````SI```%````#JD``!4````3Z0``&0```"DI```!0````FE
M```%````#Z4``!L````5I0``&@```#&E```3````3*4``!$```!@I0``$0``
M`'*E```<````A*4``!````"AI0``(0```+*E```%````U*4```L```#:I0``
M$@```.:E```*````^:4```\````$I@``#0```!2F```1````(J8``!,````T
MI@``#````$BF```&````5:8```P```!<I@``!@```&FF```7````<*8``!``
M``"(I@``"````)FF```%````HJ8```P```"HI@``$````+6F```-````QJ8`
M``8```#4I@``!P```-NF```-````XZ8```<```#QI@``"P```/FF```'````
M!:<```<````-IP``"0```!6G```)````'Z<```H````IIP``&0```#2G```]
M````3J<``!T```",IP``#````*JG```0````MZ<```4```#(IP``)0```,ZG
M```2````]*<``!,````'J```*P```!NH```[````1Z@``"````"#J```"```
M`*2H```V````K:@``"$```#DJ```$`````:I```(````%ZD```P````@J0``
M!@```"VI```/````-*D```<```!$J0``"@```$RI```-````5ZD``!\```!E
MJ0``'````(6I```A````HJD``!X```#$J0``&0```..I```>````_:D``!L`
M```<J@``(0```#BJ```N````6JH``"8```")J@``'````+"J```>````S:H`
M`!P```#LJ@``)@````FK```K````,*L``#,```!<JP``)@```)"K```K````
MMZL``#@```#CJP``'0```!RL```5````.JP``"\```!0K```(````("L```2
M````H:P``"D```"TK```'@```-ZL```@````_:P``!(````>K0``H@```#&M
M```6````U*T``",```#KK0``*`````^N```I````.*X``"@```!BK@``'P``
M`(NN```5````JZX``"````#!K@``)0```.*N```H````"*\``"T````QKP``
M,````%^O``"2````D*\``"$````CL```%@```$6P```<````7+```"8```!Y
ML```*@```*"P``!!````R[```$0````-L0``#````%*Q```'````7[$```<`
M``!GL0``!@```&^Q```0````=K$``!(```"'L0``$P```)JQ```2````KK$`
M``<```#!L0``!````,FQ```0````SK$``!````#?L0``#````/"Q```-````
M_;$```\````+L@``$P```!NR```H````+[(```8```!8L@``$0```%^R```7
M````<;(``!L```")L@``#@```*6R```"````M+(``$D```"WL@``!0````&S
M```0````![,```\````8LP``!````"BS```-````+;,```X````[LP```P``
M`$JS```(````3K,```<```!7LP``#0```%^S```0````;;,```T```!^LP``
M"P```(RS```&````F+,```P```"?LP``"@```*RS```1````M[,``!D```#)
MLP``(@```..S```/````!K0``!L````6M```-````#*T```8````9[0``!(`
M``"`M```(@```).T```-````MK0```<```#$M```%````,RT```+````X;0`
M`"(```#MM```+P```!"U```+````0+4```D```!,M0``&0```%:U```+````
M<+4```D```!\M0``%@```(:U```/````G;4``!D```"MM0``%@```,>U```.
M````WK4``!@```#MM0``"`````:V```-````#[8``"8````=M@``0P```$2V
M```(````B+8``!(```"1M@``'P```*2V```+````Q+8``"\```#0M@``#@``
M``"W```%````#[<```8````5MP``10```!RW```#````8K<```<```!FMP``
M!````&ZW```*````<[<```H```!^MP``#P```(FW```0````F;<``!<```"J
MMP``$0```,*W```9````U+<``!<```#NMP``"0````:X```%````$+@```L`
M```6N```!0```"*X```-````*+@``!L````VN```%P```%*X```4````:K@`
M``D```!_N```#@```(FX```-````F+@``!(```"FN```.````+FX```@````
M\K@```@````3N0``>P```!RY```8````F+D``!$```"QN0``!P```,.Y```%
M````R[D``!@```#1N0``'@```.JY```;````";H``!D````EN@``&P```#^Z
M```9````6[H``!,```!UN@``!P```(FZ```(````D;H```8```":N@``!@``
M`*&Z```0````J+H```\```"YN@``$````,FZ```/````VKH```L```#JN@``
M#P```/:Z```,````!KL```\````3NP``!P```".[```&````*[L```P````R
MNP``*````#^[```/````:+L```@```!XNP``$P```(&[```>````E;L``"$`
M``"TNP``(````-:[```9````][L``!<````1O```)0```"F\```7````3[P`
M`!8```!GO```!````'Z\```;````@[P```T```"?O```#````*V\```#````
MNKP```4```"^O```"````,2\```*````S;P```P```#8O```"P```.6\```0
M````\;P```P````"O0``#@````^]```+````'KT```0````JO0``!````"^]
M```3````-+T``!0```!(O0``#````%V]```)````:KT```X```!TO0``"P``
M`(.]```;````C[T```<```"KO0``!P```+.]```*````N[T```T```#&O0``
M"0```-2]```$````WKT```,```#CO0``&````.>]```$`````+X```X````%
MO@``?````!2^```5````D;X```4```"GO@``!P```*V^```,````M;X```@`
M``#"O@``"@```,N^```&````UKX```@```#=O@```@```.:^```&````Z;X`
M`!0```#PO@``#0````6_```0````$[\``!L````DOP``!````$"_```)````
M1;\``!````!/OP``"0```&"_```)````:K\```4```!TOP``!@```'J_```9
M````@;\```X```";OP``!P```*J_```'````LK\```4```"ZOP``"0```,"_
M```*````RK\```X```#5OP```@```.2_```+````Y[\```T```#SOP``"0``
M``'````&````"\```!(````2P```"0```"7````'````+\```!0````WP```
M'0```$S```!"````:L```"4```"MP```)0```-/````&````^<````H`````
MP0``!`````O!```)````$,$```@````:P0``$0```"/!```)````-<$```8`
M```_P0``#0```$;!```&````5,$```0```!;P0``'@```&#!```%````?\$`
M``X```"%P0``!````)3!```&````F<$```<```"@P0``(0```*C!```-````
MRL$``!4```#8P0``!@```.[!```$````]<$```8```#ZP0``"@````'"```B
M````#,(```0````OP@``!0```#3"```=````.L(```P```!8P@``#@```&7"
M```*````=,(```@```!_P@``"0```(C"```%````DL(``#H```"8P@``,```
M`-/"```U````!,,``"D````ZPP``1P```&3#```X````K,,``"D```#EPP``
M/P````_$```N````3\0``"T```!^Q```'P```*S$```D````S,0```@```#Q
MQ```"@```/K$```)````!<4```<````/Q0``(````!?%```@````.,4``"8`
M``!9Q0``"@```(#%```9````B\4``"D```"EQ0``%@```,_%```'````YL4`
M``H```#NQ0``#````/G%```/````!L8``!`````6Q@``0````"?&``!F````
M:,8```P```#/Q@``!@```-S&```/````X\8``!(```#SQ@``$`````;'```<
M````%\<``",````TQP``:@```%C'```%````P\<``!````#)QP``"0```-K'
M```+````Y,<``"````#PQP``&0```!'(``!"````*\@```\```!NR```-```
M`'[(```U````L\@``!0```#IR```!P```/[(```,````!LD``"`````3R0``
M$````#3)```4````1<D``!$```!:R0``%P```&S)```<````A,D``!,```"A
MR0``%````+7)```:````RLD``!$```#ER0``&@```/?)```>````$LH``!H`
M```QR@``$P```$S*```5````8,H``!$```!VR@``%P```(C*```4````H,H`
M`!<```"UR@``%0```,W*```)````X\H``!````#MR@``&0```/[*```$````
M&,L```<````=RP``$0```"7+```&````-\L```8````^RP``!0```$7+```'
M````2\L```<```!3RP``!0```%O+```6````8<L```8```!XRP``!@```'_+
M```$````ALL```0```"+RP``"@```)#+```.````F\L```4```"JRP``*```
M`+#+```.````V<L```P```#HRP``#P```/7+```*````!<P```@````0S```
M"0```!G,```K````(\P```0```!/S```"````%3,```F````7<P``!(```"$
MS```#P```)?,```&````I\P```H```"NS```"````+G,```@````PLP```D`
M``#CS```%````.W,```,`````LT```T````/S0``#@```!W-```6````+,T`
M`!$```!#S0``!@```%7-```#````7,T```<```!@S0``"P```&C-```+````
M=,T```<```"`S0``!0```(C-```'````CLT``!8```"6S0``#0```*W-```-
M````N\T```H```#)S0``$````-3-```/````Y<T``!$```#US0``%P````?.
M```*````'\X``!$````JS@``!````#S.```Z````0<X```4```!\S@``#```
M`(+.```>````C\X```X```"NS@``$````+W.```+````SLX```P```#:S@``
M"0```.?.```'````\<X```H```#YS@``"0````3/```.````#L\``!`````=
MSP``&P```"[/```8````2L\``!H```!CSP``"@```'[/```)````B<\```H`
M``"3SP``#````)[/```/````J\\```@```"[SP``!@```,3/```<````R\\`
M``<```#HSP``!0```/#/```+````]L\``$<````"T```#0```$K0```)````
M6-````0```!BT````P```&?0```*````:]````(```!VT```!````'G0```E
M````?M````,```"DT```!0```*C0```J````KM````H```#9T```!0```.30
M```$````ZM````H```#OT```!@```/K0```(`````=$```@````*T0``!```
M`!/1```%````&-$``&@````>T0``"0```(?1```,````D=$``!````">T0``
M!0```*_1```;````M=$``"\```#1T0``$`````'2```*````$M(```\````=
MT@``"@```"W2```)````.-(``!,```!"T@``&P```%;2```8````<M(``!<`
M``"+T@``'P```*/2```.````P](```,```#2T@``!P```-;2```(````WM(`
M``<```#GT@``"@```._2```'````^M(``%$````"TP``$````%33```,````
M9=,```T```!RTP``&@```(#3``!*````F],``!D```#FTP``!@````#4```:
M````!]0``"4````BU```!@```$C4```&````3]0``!\```!6U```"0```';4
M```8````@-0``!<```"9U```*````+'4```&````VM0```T```#AU```(@``
M`._4```3````$M4``",````FU0``$P```$K5```"````7M4```L```!AU0``
M"````&W5```-````=M4```<```"$U0``%````(S5```&````H=4```@```"H
MU0``#@```+'5```'````P-4```H```#(U0``"P```-/5```R````W]4```<`
M```2U@``#````!K6```-````)]8``!<````UU@``#````$W6```)````6M8`
M``D```!DU@``"@```&[6```'````>=8```D```"!U@``!P```(O6```*````
MD]8``!L```">U@``#P```+K6```2````RM8```H```#=U@``%@```.C6```)
M````_]8``!`````)UP``!P```!K7```2````(M<```0````UUP``!P```#K7
M```%````0M<```4```!(UP``"P```$[7```4````6M<``!$```!OUP``&@``
M`('7```6````G-<``!0```"SUP``%P```,C7```8````X-<``!P```#YUP``
M&0```!;8```'````,-@```4````XV```#0```#[8```,````3-@```@```!9
MV```%P```&+8```+````>M@```P```"&V```'P```)/8```:````L]@```0`
M``#.V```"@```-/8```$````WM@```T```#CV```#````/'8```%````_M@`
M``D````$V0``!0````[9```'````%-D```4````<V0``!````"+9```"````
M)]D``#@````JV0``+````&/9```2````D-D``"D```"CV0``,@```,W9```*
M`````-H``"P````+V@``+@```#C:```S````9]H``#,```";V@``.````,_:
M```/````"-L``!@````8VP``$````#';```/````0ML``!,```!2VP``%0``
M`&;;```4````?-L``!(```"1VP``%````*3;```5````N=L``&(```#/VP``
M$P```#+<```-````1MP``!<```!4W```#````&S<```K````>=P``"$```"E
MW```&@```,?<```)````XMP``$4```#LW```00```#+=```$````=-T``!0`
M``!YW0``#@```([=```3````G=T``!@```"QW0``!@```,K=```)````T=T`
M``H```#;W0``#P```.;=```0````]MT```X````'W@``!0```!;>```;````
M'-X```@````XW@``!@```$'>```4````2-X``!$```!=W@``#@```&_>```X
M````?MX```8```"WW@``#@```+[>```%````S=X```<```#3W@``!@```-O>
M```H````XMX```P````+WP``'````!C?```$````-=\``"D````ZWP``%P``
M`&3?```?````?-\``%P```"<WP``%````/G?```^````#N```!````!-X```
M!P```%[@```.````9N````P```!UX```$P```(+@```*````EN```!T```"A
MX```&0```+_@```%````V>```!$```#?X```$0```/'@```D`````^$``!(`
M```HX0``%0```#OA```2````4>$```X```!DX0``&0```'/A```(````C>$`
M``D```"6X0``#0```*#A```'````KN$```H```"VX0``!P```,'A```/````
MR>$```8```#9X0``"P```.#A```:````[.$```H````'X@``"````!+B```%
M````&^(``!\````AX@``!@```$'B```0````2.(```@```!9X@``#0```&+B
M```(````<.(``!X```!YX@``$@```)CB```L````J^(``!H```#8X@``"0``
M`//B```*````_>(``!4````(XP``!0```![C```0````).,```8````UXP``
M'@```#SC```H````6^,```H```"$XP``'````(_C```1````K.,```L```"^
MXP``&@```,KC```4````Y>,```0```#ZXP``!````/_C```+````!.0```4`
M```0Y```!@```!;D```(````'>0``"`````FY```*0```$?D```@````<>0`
M`$$```"2Y```&@```-3D```H````[^0``"D````8Y0``4````$+E```B````
MD^4```8```"VY0``"````+WE```%````QN4```@```#,Y0``*@```-7E```C
M`````.8``!D````DY@``+@```#[F```(````;>8``!<```!VY@``"@```([F
M```'````F>8``!````"AY@``"P```++F```'````ON8``!,```#&Y@``"```
M`-KF```+````X^8```H```#OY@``%````/KF```/````#^<``#(````?YP``
M"P```%+G```.````7N<```4```!MYP``!0```'/G```%````>><``!<```!_
MYP``#P```)?G```$````I^<```H```"LYP``"0```+?G```+````P><```T`
M``#-YP``#````-OG```.````Z.<```4```#WYP``!````/WG```-`````N@`
M`#(````0Z```10```$/H```'````B>@``!X```"1Z```%````+#H```%````
MQ>@``!0```#+Z```!@```.#H```'````Y^@```X```#OZ```*@```/[H```&
M````*>D```T````PZ0``"P```#[I```V````2ND```L```"!Z0``#P```(WI
M```R````G>D``"4```#0Z0``,````/;I```Q````)^H``"T```!9Z@``#@``
M`(?J```%````ENH```X```"<Z@``$P```*OJ```2````O^H```<```#2Z@``
M$0```-KJ```3````[.H```<`````ZP``%`````CK```8````'>L```<````V
MZP``#````#[K```,````2^L```0```!8ZP``!P```%WK```*````9>L```L`
M``!PZP``#````'SK```#````B>L``!(```"-ZP``!@```*#K```>````I^L`
M`!@```#&ZP``)0```-_K```-````!>P```D````3[```'P```!WL```#````
M/>P```<```!![```"@```$GL```"````5.P```P```!7[```%0```&3L```+
M````>NP``!D```"&[```(````*#L```%````P>P```H```#'[```%0```-+L
M```2````Z.P```P```#[[```!`````CM```)````#>T```<````7[0``#```
M`!_M``!2````+.T``!<```!_[0``)````)?M```2````O.T```<```#/[0``
M!@```-?M```.````WNT```P```#M[0``#0```/KM```5````".X``!(````>
M[@``#P```#'N```4````0>X```H```!6[@``&P```&'N```0````?>X```L`
M``".[@``:0```)KN```:````!.\``!<````?[P``)P```#?O```:````7^\`
M`!<```!Z[P``&P```)+O```9````KN\``!\```#([P``$P```.CO```(````
M_.\```<````%\```"`````WP```)````%O```!4````@\```#0```#;P```C
M````1/````T```!H\```$P```';P```(````BO````,```"3\```1@```)?P
M```_````WO```#<````>\0``5P```%;Q```%````KO$``!\```"T\0``+P``
M`-3Q```*````!/(```@````/\@``#0```!CR```M````)O(```0```!4\@``
M3P```%GR```E````J?(``!P```#/\@``"P```.SR```?````^/(``!T````8
M\P``"P```#;S```'````0O,```T```!*\P``#````%CS```7````9?,```8`
M``!]\P``.0```(3S```,````OO,```<```#+\P``"0```-/S```3````W?,`
M``D```#Q\P``!````/OS```0`````/0```@````1]```"````!KT```$````
M(_0```L````H]```#````#3T```2````0?0``!$```!4]```#````&;T```:
M````<_0```\```".]```!P```)[T```-````IO0``!0```"T]```#@```,GT
M```,````V/0``!L```#E]```+`````'U```3````+O4```8```!"]0``!0``
M`$GU```$````3_4``!<```!4]0``!@```&SU```)````<_4```@```!]]0``
M"0```(;U```*````D/4``!$```";]0``!@```*WU```.````M/4```X```##
M]0``"P```-+U```=````WO4```(```#\]0``'````/_U```'````'/8```8`
M```D]@``9````"OV```'````D/8``"8```"8]@``.````+_V```:````^/8`
M`"H````3]P``.P```#[W```H````>O<``#0```"C]P``&0```-CW```5````
M\O<```4````(^```"`````[X```'````%_@```4````?^```!P```"7X```.
M````+?@```D````\^```!@```$;X```(````3?@```<```!6^```"````%[X
M```'````9_@``!8```!O^```"0```(;X```&````D/@```L```"7^```$```
M`*/X```&````M/@``!P```"[^```%````-CX```'````[?@``!$```#U^```
M"`````?Y```(````$/D```D````9^0``!@```"/Y```9````*OD```H```!$
M^0``'````$_Y```%````;/D``!````!R^0``%````(/Y```+````F/D```T`
M``"D^0``*````++Y```8````V_D``!<```#T^0``!`````SZ```)````$?H`
M``(````;^@``"````![Z```C````)_H``!\```!+^@``.````&OZ```F````
MI/H``#$```#+^@``)P```/WZ``!D````)?L``%4```"*^P``.````.#[``!*
M````&?P``%L```!D_```*````,#\```X````Z?P``"@````B_0``+````$O]
M```;````>/T``",```"4_0``2````+C]``"%`````?X``#````"'_@``)0``
M`+C^``!!````WOX``%L````@_P``20```'S_```Q````QO\``"L```#X_P``
M(0```"0``0`?````1@`!`"8```!F``$`.@```(T``0`S````R``!`"4```#\
M``$`)P```"(!`0`@````2@$!`!\```!K`0$`,````(L!`0!I````O`$!`#$`
M```F`@$`00```%@"`0`S````F@(!`"4```#.`@$`/0```/0"`0!E````,@,!
M`$T```"8`P$`+P```.8#`0`N````%@0!`#````!%!`$`5````'8$`0!:````
MRP0!`$@````F!0$`2@```&\%`0`R````N@4!`"\```#M!0$`+````!T&`0`M
M````2@8!`'$```!X!@$`9@```.H&`0!O````40<!`+,```#!!P$`%P```'4(
M`0`E````C0@!`#(```"S"`$`*0```.8(`0`^````$`D!`"(```!/"0$`4@``
M`'()`0`E````Q0D!``L```#K"0$`L0```/<)`0!%````J0H!`"$```#O"@$`
M,````!$+`0`E````0@L!`!P```!H"P$`,0```(4+`0`'````MPL!``<```"_
M"P$`!````,<+`0`-````S`L!``L```#:"P$`#@```.8+`0`%````]0L!``(`
M``#["P$`60```/X+`0`%````6`P!``0```!>#`$`!P```&,,`0`(````:PP!
M``4```!T#`$`,````'H,`0`,````JPP!`!,```"X#`$`#0```,P,`0`"````
MV@P!``<```#=#`$`!@```.4,`0`4````[`P!``P````!#0$`&`````X-`0`&
M````)PT!`!(````N#0$`#````$$-`0`#````3@T!`"H```!2#0$`!@```'T-
M`0`'````A`T!`!\```",#0$`+@```*P-`0`O````VPT!`!<````+#@$`(@``
M`",.`0`E````1@X!`!L```!L#@$`&````(@.`0`D````H0X!`!\```#&#@$`
M&@```.8.`0`A`````0\!`"`````C#P$`&@```$0/`0`R````7P\!`!H```"2
M#P$`+P```*T/`0`K````W0\!`!\````)$`$`(P```"D0`0`?````31`!`!H`
M``!M$`$`(0```(@0`0`E````JA`!`"8```#0$`$`)0```/<0`0`D````'1$!
M`!@```!"$0$`'0```%L1`0`D````>1$!`!@```">$0$`(@```+<1`0`L````
MVA$!`!4````'$@$`)0```!T2`0`\````0Q(!`!\```"`$@$`(P```*`2`0`?
M````Q!(!`"````#D$@$`&@````43`0`8````(!,!`"8````Y$P$`*0```&`3
M`0`>````BA,!`"D```"I$P$`'@```-,3`0`Q````\A,!``P````D%`$`+P``
M`#$4`0`D````810!``<```"&%`$`#P```(X4`0`4````GA0!``X```"S%`$`
M#0```,(4`0`D````T!0!``4```#U%`$`!P```/L4`0`B`````Q4!`"4````F
M%0$`&@```$P5`0`=````9Q4!``<```"%%0$`%0```(T5`0`&````HQ4!``D`
M``"J%0$`"P```+05`0`-````P!4!`!<```#.%0$`!@```.85`0`S````[14!
M``<````A%@$`#P```"D6`0`'````.18!`#(```!!%@$`!````'06`0`A````
M>18!`!,```";%@$`#````*\6`0`1````O!8!`#(```#.%@$`%@````$7`0`(
M````&!<!`!T````A%P$`"0```#\7`0`*````21<!`!0```!4%P$`"@```&D7
M`0`=````=!<!``@```"2%P$`'P```)L7`0`(````NQ<!`!H```#$%P$`)P``
M`-\7`0`&````!Q@!`!4````.&`$`!P```"08`0`(````+!@!``D````U&`$`
M/P```#\8`0`'````?Q@!``\```"'&`$`"0```)<8`0`(````H1@!`!,```"J
M&`$`!P```+X8`0`9````QA@!`!<```#@&`$`%````/@8`0`*````#1D!``P`
M```8&0$`%P```"49`0`$````/1D!`"H```!"&0$`#````&T9`0`1````>AD!
M``<```",&0$``@```)09`0`0````EQD!`!@```"H&0$`"P```,$9`0`#````
MS1D!``@```#1&0$`!@```-H9`0`'````X1D!``T```#I&0$`"P```/<9`0`4
M`````QH!`!4````8&@$`#@```"X:`0`O````/1H!`"````!M&@$`'````(X:
M`0`5````JQH!``P```#!&@$`,0```,X:`0`2`````!L!`#\````3&P$`!```
M`%,;`0`$````6!L!``H```!=&P$`$P```&@;`0`%````?!L!``8```""&P$`
M!@```(D;`0`(````D!L!``0```"9&P$`#````)X;`0`*````JQL!`#D```"V
M&P$`+@```/`;`0`I````'QP!``4```!)'`$`&````$\<`0`9````:!P!`!\`
M``""'`$`'0```*(<`0`1````P!P!``(```#2'`$`!````-4<`0`*````VAP!
M``8```#E'`$`!0```.P<`0`#````\AP!``P```#V'`$`,@````,=`0`:````
M-AT!`#0```!1'0$`*````(8=`0!3````KQT!`!D````#'@$`<@```!T>`0`@
M````D!X!`#4```"Q'@$`(0```.<>`0!%````"1\!`"@```!/'P$`*0```'@?
M`0`F````HA\!`"4```#)'P$`*````.\?`0`H````&"`!`"(```!!(`$`*P``
M`&0@`0`P````D"`!`!(```#!(`$`$P```-0@`0`0````Z"`!`'D```#Y(`$`
M"0```',A`0"A````?2$!`',````?(@$`?````),B`0`K````$",!`%0````\
M(P$`%P```)$C`0`G````J2,!`!8```#1(P$`#P```.@C`0`7````^",!`!\`
M```0)`$`0````#`D`0`?````<20!`!P```"1)`$`40```*XD`0`:`````"4!
M`!0````;)0$`"@```#`E`0`%````.R4!``8```!!)0$`"````$@E`0`2````
M424!`!````!D)0$`$P```'4E`0`=````B24!``\```"G)0$`!````+<E`0`)
M````O"4!``<```#&)0$`!0```,XE`0`'````U"4!``@```#<)0$`"````.4E
M`0`,````[B4!``8```#[)0$`!@````(F`0`,````"28!`!$````6)@$`"```
M`"@F`0`$````,28!`!D````V)@$`$0```%`F`0`*````8B8!`!@```!M)@$`
M$P```(8F`0`<````FB8!`!$```"W)@$`!````,DF`0`/````SB8!``<```#>
M)@$`!````.8F`0`9````ZR8!``<````%)P$``@````TG`0`"````$"<!`!$`
M```3)P$`"0```"4G`0`&````+R<!`!(````V)P$`%P```$DG`0`&````82<!
M`"<```!H)P$``@```)`G`0`$````DR<!``\```"8)P$`$P```*@G`0`'````
MO"<!`!$```#$)P$`&````-8G`0`&````[R<!`!,```#V)P$`$`````HH`0`2
M````&R@!``(````N*`$`!@```#$H`0`,````."@!``D```!%*`$`$0```$\H
M`0`B````82@!``<```"$*`$`!P```(PH`0`+````E"@!``4```"@*`$``@``
M`*8H`0`+````J2@!`#$!``"U*`$`$````.<I`0`4````^"D!``P````-*@$`
M!P```!HJ`0`&````(BH!``D````I*@$`!````#,J`0`.````."H!`!D```!'
M*@$`(P```&$J`0`@````A2H!`"4```"F*@$`)P```,PJ`0`6````]"H!`#$`
M```+*P$`"P```#TK`0`:````22L!`!$```!D*P$`%0```'8K`0`(````C"L!
M``4```"5*P$`(````)LK`0`(````O"L!``H```#%*P$`"0```-`K`0`/````
MVBL!``L```#J*P$`AP```/8K`0`.````?BP!``@```"-+`$`#````)8L`0`.
M````HRP!``D```"R+`$`"@```+PL`0`+````QRP!``L```#3+`$`!@```-\L
M`0"I````YBP!``D```"0+0$`#@```)HM`0`;````J2T!``P```#%+0$`#```
M`-(M`0`,````WRT!``4```#L+0$`$@```/(M`0`W````!2X!`!L````]+@$`
M,P```%DN`0`V````C2X!`%,```#$+@$`3P```!@O`0!5````:"\!`%4```"^
M+P$`.````!0P`0`(````33`!`!,```!6,`$`#0```&HP`0`.````>#`!`!<`
M``"',`$`!0```)\P`0`&````I3`!``<```"L,`$`*P```+0P`0`N````X#`!
M``T````/,0$`#````!TQ`0`'````*C$!``<````R,0$`!0```#HQ`0`3````
M0#$!`!<```!4,0$`"@```&PQ`0`2````=S$!`!4```"*,0$`&````*`Q`0`<
M````N3$!`!@```#6,0$`#0```.\Q`0`1````_3$!``D````/,@$`'P```!DR
M`0`/````.3(!`!,```!),@$`$````%TR`0!3````;C(!`"T```#",@$`)@``
M`/`R`0`&````%S,!``8````>,P$`)0```"4S`0`+````2S,!``<```!7,P$`
M"@```%\S`0`(````:C,!``D```!S,P$`!P```'TS`0`#````A3,!`!<```")
M,P$`"P```*$S`0`.````K3,!`!H```"\,P$`$P```-<S`0`-````ZS,!`"``
M``#Y,P$`%0```!HT`0`@````,#0!`!T```!1-`$`$0```&\T`0`1````@30!
M`"4```"3-`$`%0```+DT`0`&````SS0!``8```#6-`$`"````-TT`0`.````
MYC0!``<```#U-`$`"@```/TT`0`2````"#4!``H````;-0$`$````"8U`0`:
M````-S4!`!D```!2-0$`!@```&PU`0`%````<S4!`!8```!Y-0$`&````)`U
M`0`*````J34!`$(```"T-0$`0````/<U`0`)````.#8!``@```!"-@$`%```
M`$LV`0`(````8#8!``4```!I-@$`#@```&\V`0`6````?C8!`#(```"5-@$`
M$````,@V`0`D````V38!`"D```#^-@$`*@```"@W`0`E````4S<!``D```!Y
M-P$`!@```(,W`0`*````BC<!``@```"5-P$`,@```)XW`0`O````T3<!`#$`
M```!.`$`6P```#,X`0`G````CS@!`#````"W.`$`/0```.@X`0!"````)CD!
M`#````!I.0$`00```)HY`0`L````W#D!`"T````).@$`0````#<Z`0`P````
M>#H!`#L```"I.@$`)0```.4Z`0`4````"SL!`!<````@.P$`)@```#@[`0`E
M````7SL!`"4```"%.P$`$P```*L[`0`-````OSL!``\```#-.P$`&````-T[
M`0`C````]CL!``8````:/`$`!P```"$\`0`4````*3P!``H````^/`$`"```
M`$D\`0`P````4CP!``H```"#/`$`!P```(X\`0`&````ECP!``4```"=/`$`
M#P```*,\`0`%````LSP!``L```"Y/`$`*@```,4\`0`3````\#P!``P````$
M/0$`"````!$]`0`,````&CT!`!0````G/0$`!0```#P]`0`'````0CT!`!$`
M``!*/0$`"0```%P]`0`E````9CT!``8```",/0$`"0```),]`0`,````G3T!
M``<```"J/0$``P```+(]`0`#````MCT!`!D```"Z/0$`*@```-0]`0`'````
M_ST!``<````'/@$`"0````\^`0`'````&3X!`"@````A/@$`-0```$H^`0`A
M````@#X!``8```"B/@$`!P```*D^`0`@````L3X!`#8```#2/@$`(0````D_
M`0`;````*S\!`#<```!'/P$`-P```'\_`0`?````MS\!`"<```#7/P$`50``
M`/\_`0`]````54`!`#0```"30`$`&0```,A``0`0````XD`!``L```#S0`$`
M%````/]``0`/````%$$!``\````D00$`#P```#1!`0`5````1$$!`!P```!:
M00$`'````'=!`0`4````E$$!`!````"I00$`$````+I!`0`#````RT$!``@`
M``#/00$`%@```-A!`0!Y````[T$!`%0```!I0@$`!0```+Y"`0`(````Q$(!
M`",```#-0@$`(0```/%"`0`2````$T,!``P````F0P$`%P```#-#`0`6````
M2T,!``\```!B0P$`)````')#`0`%````ET,!`!,```"=0P$`(@```+%#`0`3
M````U$,!`!L```#H0P$`#@````1$`0`7````$T0!`!8````K1`$`"@```$)$
M`0`&````340!`!````!41`$`"````&5$`0`.````;D0!`!4```!]1`$`"0``
M`)-$`0`%````G40!``X```"C1`$`#@```+)$`0`/````P40!``8```#11`$`
M!````-A$`0`-````W40!``@```#K1`$`"@```/1$`0`'````_T0!``<````'
M10$`#`````]%`0`*````'$4!``H````G10$`$@```#)%`0`I````144!`"(`
M``!O10$`"@```))%`0`,````G44!``4```"J10$`'@```+!%`0`3````ST4!
M`!,```#C10$`,@```/=%`0!"````*D8!`"4```!M1@$`!0```)-&`0`M````
MF48!`!T```#'1@$`#@```.5&`0`(````]$8!``T```#]1@$`"0````M'`0`7
M````%4<!``L````M1P$`"0```#E'`0`6````0T<!`"(```!:1P$`'@```'U'
M`0`H````G$<!`"0```#%1P$`'0```.I'`0`G````"$@!`"(````P2`$`)P``
M`%-(`0!"````>T@!`"X```"^2`$`)0```.U(`0`G````$TD!`!T````[20$`
M+P```%E)`0`Y````B4D!`#8```##20$`)P```/I)`0`X````(DH!`#\```!;
M2@$`)0```)M*`0`;````P4H!`#L```#=2@$`(P```!E+`0`6````/4L!`#4`
M``!42P$`(````(I+`0`C````JTL!`!<```#/2P$`N0```.=+`0`:````H4P!
M`"(```"\3`$`,P```-],`0`S````$TT!`!H```!'30$`,0```&)-`0`=````
ME$T!`"4```"R30$`,P```-A-`0`V````#$X!`#T```!#3@$`0````(%.`0"5
M````PDX!`",```!83P$`)@```'Q/`0`?````HT\!`"\```##3P$`+0```/-/
M`0`P````(5`!`$,```!24`$`$P```)90`0`'````JE`!``<```"R4`$`!P``
M`+I0`0`,````PE`!``\```#/4`$`#P```-]0`0`;````[U`!``@````+40$`
M!````!11`0`:````&5$!``P````T40$`#````$%1`0`2````3E$!``T```!A
M40$`#P```&]1`0`\````?U$!``4```"\40$`$````,)1`0`7````TU$!`!P`
M``#K40$`$0````A2`0`"````&E(!`$P````=4@$`!@```&I2`0`A````<5(!
M`!<```"34@$`!0```*M2`0`-````L5(!``T```"_4@$``P```,U2`0`(````
MT5(!``@```#:4@$`#@```.-2`0`3````\E(!``\````&4P$`"P```!93`0`'
M````(E,!``\````J4P$`#P```#I3`0`2````2E,!`"````!=4P$`)P```'Y3
M`0`3````IE,!`!L```"Z4P$`,@```-93`0`;````"50!`!$````E5`$`.@``
M`#=4`0`,````<E0!``8```!_5`$`$````(94`0`$````EU0!`"H```"<5`$`
M+P```,=4`0`&````]U0!``D```#^5`$`&P````A5`0`*````)%4!``8````O
M50$`(P```#95`0`7````6E4!`!D```!R50$`%@```(Q5`0`1````HU4!`!X`
M``"U50$`"````-15`0`*````W54!`"D```#H50$`/P```!)6`0`(````4E8!
M`!8```!;5@$`)@```')6`0`*````F58!`#,```"D5@$`#@```-A6`0`(````
MYU8!`!(```#P5@$`1P````-7`0`#````2U<!``<```!/5P$`!0```%=7`0`-
M````75<!``T```!K5P$`$````'E7`0`0````BE<!`!<```";5P$`$P```+-7
M`0`8````QU<!`!8```#@5P$`#@```/=7`0`%````!E@!``@````,6`$`$@``
M`!58`0`2````*%@!`",````[6`$`(````%]8`0`0````@%@!``<```"16`$`
M$P```)E8`0`0````K5@!``\```"^6`$`,P```,Y8`0`>`````ED!``H````A
M60$`A@```"Q9`0`6````LUD!`!0```#*60$`"````-]9`0`&````Z%D!`"(`
M``#O60$`,````!):`0`P````0UH!`!L```!T6@$`(0```)!:`0`B````LEH!
M`!@```#56@$`"````.Y:`0`(````]UH!``@`````6P$`!@````E;`0`/````
M$%L!``X````@6P$`$````"];`0`.````0%L!``T```!/6P$`#0```%U;`0`,
M````:UL!`!$```!X6P$`!@```(I;`0`(````D5L!``\```":6P$`.@```*I;
M`0`0````Y5L!``D```#V6P$`&@````!<`0`A````&UP!`"8````]7`$`)0``
M`&1<`0`=````BEP!`!T```"H7`$`*0```,9<`0`;````\%P!`!<````,70$`
M"````"1=`0`1````+5T!``T````_70$`#````$U=`0`#````6ET!``0```!>
M70$`!P```&-=`0`0````:UT!`!$```!\70$`#0```(Y=`0`7````G%T!``T`
M``"T70$`#@```,)=`0`-````T5T!``8```#?70$`"````.9=`0`;````[UT!
M`!L````+7@$`$@```"=>`0`,````.EX!`!````!'7@$`$````%A>`0`;````
M:5X!``8```"%7@$`!@```(Q>`0`-````DUX!``X```"A7@$`$````+!>`0`%
M````P5X!``4```#'7@$`$P```,U>`0`%````X5X!``T```#G7@$`+@```/5>
M`0`9````)%\!``8````^7P$`!@```$5?`0`&````3%\!``8```!37P$`"```
M`%I?`0`/````8U\!``T```!S7P$``@```(%?`0`(````A%\!`!X```"-7P$`
M$@```*Q?`0`5````OU\!`!L```#57P$``@```/%?`0`#````]%\!``H```#X
M7P$`"@````-@`0`)````#F`!``4````88`$`!P```!Y@`0`5````)F`!``X`
M```\8`$`!P```$M@`0`(````4V`!``0```!<8`$`"0```&%@`0`(````:V`!
M`!(```!T8`$`!0```(=@`0`-````C6`!`!````";8`$`$````*Q@`0`'````
MO6`!`!,```#%8`$`"P```-E@`0`'````Y6`!`!@```#M8`$`(0````9A`0`^
M````*&$!`"@```!G80$`*0```)!A`0`'````NF$!``H```#"80$`!````,UA
M`0`)````TF$!``@```#<80$`$P```.5A`0`-````^6$!``<````'8@$`#@``
M``]B`0`'````'F(!``0````F8@$`'0```"MB`0`%````26(!``X```!/8@$`
M!P```%YB`0`%````9F(!``4```!L8@$`(0```')B`0`.````E&(!`!@```"C
M8@$`!P```+QB`0`&````Q&(!``H```#+8@$`!P```-9B`0`;````WF(!``8`
M``#Z8@$`!0````%C`0`'````!V,!``X````/8P$`!@```!YC`0`/````)6,!
M``@````U8P$`"0```#YC`0`%````2&,!`#T```!.8P$`.0```(QC`0`\````
MQF,!`"@````#9`$`0@```"QD`0`S````;V0!`"P```"C9`$`/@```-!D`0`P
M````#V4!`"T```!`90$`(0```&YE`0`=````D&4!``D```"N90$`"P```+AE
M`0`)````Q&4!``H```#.90$`*@```-EE`0`G````!&8!`#$````L9@$`"0``
M`%YF`0`:````:&8!`"8```"#9@$`#0```*IF`0`)````N&8!``H```#"9@$`
M"P```,UF`0`1````V68!`!4```#K9@$`-@````%G`0!U````.&<!``L```"N
M9P$`!0```+IG`0`.````P&<!`!(```#/9P$`#P```.)G`0`;````\F<!`"D`
M```.:`$`B@```#AH`0`&````PV@!`!4```#*:`$`"@```.!H`0`6````ZV@!
M`"$````":0$`&@```"1I`0!"````/VD!`!,```"":0$`,@```)9I`0!`````
MR6D!`!\````*:@$`#0```"IJ`0`4````.&H!`",```!-:@$`&````'%J`0`6
M````BFH!`!0```"A:@$`)0```+9J`0`=````W&H!`!P```#Z:@$`'````!=K
M`0`8````-&L!`!,```!-:P$`(0```&%K`0`E````@VL!`!\```"I:P$`&0``
M`,EK`0`8````XVL!`!0```#\:P$`&@```!%L`0`<````+&P!`!H```!);`$`
M&@```&1L`0`/````?VP!``L```"/;`$`&````)ML`0`$````M&P!``4```"Y
M;`$`$0```+]L`0`&````T6P!``H```#8;`$`!P```.-L`0`'````ZVP!``8`
M``#S;`$`"````/IL`0`6`````VT!``8````:;0$`"0```"%M`0`%````*VT!
M``4````Q;0$`"0```#=M`0`2````06T!``8```!4;0$`)````%MM`0`.````
M@&T!``\```"/;0$`#0```)]M`0`0````K6T!``P```"^;0$`$````,MM`0`R
M````W&T!``8````/;@$`"0```!9N`0`H````(&X!`!(```!);@$`$0```%QN
M`0`'````;FX!``H```!V;@$`!0```(%N`0`D````AVX!``\```"L;@$`&```
M`+QN`0`0````U6X!`!,```#F;@$`$P```/IN`0`8````#F\!`!8````G;P$`
M"````#YO`0`%````1V\!``<```!-;P$`#0```%5O`0`1````8V\!``8```!U
M;P$`!0```'QO`0`(````@F\!``<```"+;P$`#@```)-O`0`,````HF\!``H`
M``"O;P$`$0```+IO`0`0````S&\!``4```#=;P$`$````.-O`0`*````]&\!
M``X```#_;P$`"`````YP`0!#````%W`!``@```!;<`$`#P```&1P`0`B````
M='`!`!8```"7<`$`$P```*YP`0`,````PG`!``\```#/<`$`#P```-]P`0`1
M````[W`!`!$````!<0$`#@```!-Q`0`.````(G$!``T````Q<0$`(````#]Q
M`0`A````8'$!`!T```""<0$`"@```*!Q`0`&````JW$!``H```"R<0$`#0``
M`+UQ`0`,````RW$!``4```#8<0$`!P```-YQ`0`=````YG$!``8````$<@$`
M!P````MR`0`3````$W(!`$$````G<@$`$0```&ER`0`.````>W(!``@```"*
M<@$`!0```)-R`0`*````F7(!``(```"D<@$`$````*=R`0`G````N'(!``,`
M``#@<@$`!0```.1R`0`L````ZG(!``H````7<P$`"````")S`0`2````*W,!
M`!0````^<P$`!@```%-S`0`(````6G,!``<```!C<P$`!````&MS`0`%````
M<',!`&0```!V<P$`#P```-MS`0`2````ZW,!`!(```#^<P$`!0```!%T`0`E
M````%W0!`#D````]=`$`$P```'=T`0`*````BW0!``T```"6=`$`"P```*1T
M`0`)````L'0!`!@```"Z=`$`*````--T`0`E````_'0!`"0````B=0$`(@``
M`$=U`0`3````:G4!``,```!^=0$`!P```()U`0`3````BG4!``8```">=0$`
M"P```*5U`0`*````L74!`%\```"\=0$`%@```!QV`0`.````,W8!``L```!"
M=@$`&P```$YV`0`O````:G8!`!,```":=@$`"````*YV`0`:````MW8!`"D`
M``#2=@$`"0```/QV`0`&````!G<!`"`````-=P$`#````"YW`0`D````.W<!
M`",```!@=P$`)@```(1W`0`(````JW<!``T```"T=P$`)````,)W`0`9````
MYW<!`"\````!>`$`$P```#%X`0`"````17@!``X```!(>`$`!@```%=X`0`/
M````7G@!``8```!N>`$`%````'5X`0`&````BG@!``D```"1>`$`#0```)MX
M`0`(````J7@!``H```"R>`$`"P```+UX`0`S````R7@!``8```#]>`$`#P``
M``1Y`0`2````%'D!`!X````G>0$`$0```$9Y`0`.````6'D!`!$```!G>0$`
M$@```'EY`0`.````C'D!``X```";>0$`#@```*IY`0`(````N7D!`!T```#"
M>0$`%@```.!Y`0`1````]WD!``H````)>@$`%@```!1Z`0`*````*WH!`!<`
M```V>@$`!P```$YZ`0`2````5GH!``,```!I>@$`"````&UZ`0`%````=GH!
M``4```!\>@$`"@```()Z`0`1````C7H!`!0```"?>@$`&P```+1Z`0`;````
MT'H!`!D```#L>@$`&`````9[`0`;````'WL!`!@````[>P$`&````%1[`0`(
M````;7L!``8```!V>P$`#P```'U[`0`/````C7L!``D```"=>P$`%0```*=[
M`0`.````O7L!``H```#,>P$`&0```-=[`0`7````\7L!``8````)?`$`$P``
M`!!\`0`)````)'P!`!,````N?`$`$@```$)\`0`*````57P!``D```!@?`$`
M!0```&I\`0`(````<'P!``4```!Y?`$`!````']\`0`'````A'P!`#P```",
M?`$`+0```,E\`0`3````]WP!`"4````+?0$`)@```#%]`0`.````6'T!`"\`
M``!G?0$`-````)=]`0`B````S'T!`",```#O?0$`+````!-^`0`5````0'X!
M``X```!6?@$`%@```&5^`0`/````?'X!`!4```",?@$`%0```*)^`0`>````
MN'X!`!P```#7?@$`(0```/1^`0`9````%G\!`'0````P?P$`'@```*5_`0`?
M````Q'\!`!D```#D?P$`$````/Y_`0`I````#X`!`#4````Y@`$`(P```&^`
M`0`.````DX`!`$\```"B@`$`2@```/*``0`'````/8$!`!8```!%@0$`$```
M`%R!`0`/````;8$!`!<```!]@0$`"0```)6!`0`*````GX$!``<```"J@0$`
M"0```+*!`0`,````O($!``L```#)@0$`!P```-6!`0`N````W8$!``@````,
M@@$`"````!6"`0`/````'H(!`!$````N@@$`#P```$""`0!#````4((!``8`
M``"4@@$`%0```)N"`0`(````L8(!``<```"Z@@$`!P```,*"`0`J````RH(!
M``L```#U@@$`&`````&#`0`$````&H,!`#(````?@P$`%````%*#`0`E````
M9X,!`%X```"-@P$`$@```.R#`0!$````_X,!`!$```!$A`$`"0```%:$`0`/
M````8(0!``P```!PA`$`%````'V$`0`,````DH0!`!H```"?A`$`%@```+J$
M`0`%````T80!`!(```#7A`$`$P```.J$`0`3````_H0!`!8````2A0$`%```
M`"F%`0`4````/H4!``\```!3A0$`'@```&.%`0`(````@H4!``H```"+A0$`
M$P```):%`0`-````JH4!``\```"XA0$`#@```,B%`0`8````UX4!``X```#P
MA0$`$````/^%`0`;````$(8!``H````LA@$`"````#>&`0`%````0(8!`!X`
M``!&A@$`!@```&6&`0`2````;(8!``@```!_A@$`#@```(B&`0`%````EX8!
M`!H```"=A@$`$````+B&`0`F````R88!`!(```#PA@$`!@````.'`0`'````
M"H<!`!8````2AP$`!P```"F'`0`2````,8<!``8```!$AP$`&0```$N'`0`F
M````98<!``H```",AP$`'0```)>'`0`8````M8<!``H```#.AP$`%@```-F'
M`0`2````\(<!``0````#B`$`#`````B(`0`(````%8@!``<````>B`$`"P``
M`":(`0`(````,H@!`"(````[B`$`*````%Z(`0`G````AX@!`$0```"OB`$`
M(@```/2(`0`G````%XD!`#(````_B0$`9@```'*)`0`D````V8D!``<```#^
MB0$`"`````:*`0`&````#XH!``L````6B@$`)@```"**`0`;````28H!`!0`
M``!EB@$`,````'J*`0`$````JXH!`!<```"PB@$`!@```,B*`0`)````SXH!
M`!,```#9B@$`#@```.V*`0`'````_(H!`!4````$BP$`"````!J+`0`3````
M(XL!``P````WBP$`&0```$2+`0`;````7HL!`#4```!ZBP$`"0```+"+`0`4
M````NHL!``4```#/BP$`"0```-6+`0`%````WXL!`!L```#EBP$`#@````&,
M`0`$````$(P!``P````5C`$`#0```"*,`0`%````,(P!``P````VC`$`"P``
M`$.,`0`&````3XP!``@```!6C`$`!````%^,`0`/````9(P!`$<```!TC`$`
M:0```+R,`0`'````)HT!`"(````NC0$`#P```%&-`0`%````88T!`!$```!G
MC0$`#P```'F-`0`(````B8T!`!0```"2C0$`+````*>-`0`(````U(T!`!``
M``#=C0$`#````.Z-`0`X````^XT!`!,````TC@$`&````$B.`0`T````88X!
M`!X```"6C@$`.````+6.`0`Y````[HX!`"4````HCP$`$@```$Z/`0`)````
M88\!``\```!KCP$`%P```'N/`0`9````DX\!``<```"MCP$`%````+6/`0`;
M````RH\!``\```#FCP$`%````/:/`0`J````"Y`!``8````VD`$`#0```#V0
M`0`/````2Y`!``@```!;D`$`"````&20`0`,````;9`!``T```!ZD`$`#@``
M`(B0`0`'````EY`!``8```"?D`$`!@```*:0`0`<````K9`!`!H```#*D`$`
M&````.60`0`.````_I`!``H````-D0$`(0```!B1`0`#````.I$!``4````^
MD0$`"@```$21`0`"````3Y$!``P```!2D0$`%@```%^1`0`+````=I$!`!H`
M``""D0$`&@```)V1`0`%````N)$!``H```"^D0$`%````,F1`0`6````WI$!
M``\```#UD0$`!@````62`0`+````#)(!``H````8D@$`$````".2`0!>````
M-)(!`!H```"3D@$`,P```*Z2`0`=````XI(!``<`````DP$`!@````B3`0`)
M````#Y,!``\````9DP$`#````"F3`0`E````-I,!`!8```!<DP$`$````'.3
M`0`G````A),!``H```"LDP$`$P```+>3`0`.````RY,!``T```#:DP$`:@``
M`.B3`0`6````4Y0!`!4```!JE`$`+P```("4`0`4````L)0!`!(```#%E`$`
M'P```-B4`0`A````^)0!``\````:E0$`&P```"J5`0`+````1I4!``<```!2
ME0$`!P```%J5`0`)````8I4!`!0```!LE0$`$@```(&5`0`R````E)4!`!,`
M``#'E0$`$P```-N5`0`$````[Y4!``<```#TE0$`3P```/R5`0!*````3)8!
M`"P```"7E@$`/0```,26`0`'`````I<!`#$````*EP$`)0```#R7`0`(````
M8I<!``L```!KEP$`#P```'>7`0`H````AY<!``<```"PEP$`3````+B7`0`H
M````!9@!`"4````NF`$`'````%28`0`J````<9@!`"$```"<F`$`#P```+Z8
M`0`%````SI@!``T```#4F`$`#@```.*8`0`0````\9@!``8````"F0$`+@``
M``F9`0`,````.)D!``H```!%F0$`!@```%"9`0`4````5YD!``@```!LF0$`
M"````'69`0`6````?ID!``D```"5F0$`"0```)^9`0`$````J9D!``T```"N
MF0$`#0```+R9`0`5````RID!`!8```#@F0$`#@```/>9`0`B````!IH!`!``
M```IF@$`"````#J:`0`0````0YH!`!8```!4F@$`"P```&N:`0`-````=YH!
M`!P```"%F@$`)P```**:`0`.````RIH!``L```#9F@$`"````.6:`0`2````
M[IH!`!4````!FP$`!P```!>;`0`*````'YL!``H````JFP$`#0```#6;`0`-
M````0YL!`!0```!1FP$`!@```&:;`0`1````;9L!``P```!_FP$`%````(R;
M`0`;````H9L!``(```"]FP$`%@```,";`0`&````UYL!``D```#>FP$`7P``
M`.B;`0`%````2)P!`"(```!.G`$`)P```'&<`0`;````F9P!`"<```"UG`$`
M3P```-V<`0`R````+9T!`#T```!@G0$`(0```)Z=`0`8````P)T!``4```#9
MG0$`#0```-^=`0`-````[9T!``<```#[G0$`#0````.>`0`3````$9X!``T`
M```EG@$`#0```#.>`0`.````09X!``<```!0G@$`!P```%B>`0`'````8)X!
M`!4```!HG@$`!0```'Z>`0`(````A)X!``8```"-G@$`(0```)2>`0`.````
MMIX!`"(```#%G@$`&@```.B>`0`'`````Y\!`!P````+GP$`$@```"B?`0`,
M````.Y\!`!$```!(GP$`!@```%J?`0`8````89\!``P```!ZGP$`'@```(>?
M`0`(````II\!`!0```"OGP$`&0```,2?`0`+````WI\!``T```#JGP$`*```
M`/B?`0`6````(:`!`!,````XH`$`"````$R@`0`-````5:`!``(```!CH`$`
M!@```&:@`0`3````;:`!`!D```"!H`$`)P```)N@`0`G````PZ`!`"X```#K
MH`$`*P```!JA`0`W````1J$!`$$```!^H0$`1P```,"A`0!.````"*(!`#X`
M``!7H@$`&````):B`0`S````KZ(!`"X```#CH@$`+P```!*C`0`E````0J,!
M`!\```!HHP$`/0```(BC`0!Z````QJ,!`#0```!!I`$`(````':D`0`W````
MEZ0!`%\```#/I`$`/@```"^E`0`S````;J4!`#$```"BI0$`'P```-2E`0`;
M````]*4!`"`````0I@$`,````#&F`0`^````8J8!`"<```"AI@$`&````,FF
M`0`:````XJ8!`!H```#]I@$`'@```!BG`0!6````-Z<!`#4```".IP$`-@``
M`,2G`0`V````^Z<!`#`````RJ`$`2````&.H`0!P````K*@!`$8````=J0$`
M*@```&2I`0`N````CZD!`"X```"^J0$`6````.VI`0!@````1JH!`$\```"G
MJ@$`20```/>J`0`D````0:L!`!D```!FJP$`'````("K`0`C````G:L!`$0`
M``#!JP$`/0````:L`0!#````1*P!`(T```"(K`$`%````!:M`0`H````*ZT!
M`"X```!4K0$`(P```(.M`0!&````IZT!`"````#NK0$`2P````^N`0`?````
M6ZX!``D```![K@$`N@```(6N`0!#````0*\!`!\```"$KP$`,0```*2O`0`>
M````UJ\!`"````#UKP$`*````!:P`0`%````/[`!``<```!%L`$`!````$VP
M`0`-````4K`!``P```!@L`$`#````&VP`0`&````>K`!``(```"!L`$`;0``
M`(2P`0`#````\K`!``0```#VL`$`!P```/NP`0`'`````[$!``4````+L0$`
M+````!&Q`0`,````/K$!`!(```!+L0$`"0```%ZQ`0`#````:+$!``@```!L
ML0$`!P```'6Q`0`4````?;$!``P```"2L0$`%P```)^Q`0`&````M[$!`!@`
M``"^L0$`#````->Q`0`#````Y+$!`"\```#HL0$`!@```!BR`0`(````'[(!
M`!T````HL@$`,0```$:R`0`L````>+(!`!H```"EL@$`'````,"R`0`I````
MW;(!`!L````'LP$`'P```".S`0`@````0[,!`!\```!DLP$`(````(2S`0`@
M````I;,!`"````#&LP$`'````.>S`0`H````!+0!`!P````MM`$`*````$JT
M`0`;````<[0!`!L```"/M`$`(P```*NT`0`A````S[0!`"````#QM`$`(0``
M`!*U`0`;````-+4!`"4```!0M0$`*````':U`0`:````G[4!`"$```"ZM0$`
M'@```-RU`0`P````^[4!`!X````LM@$`)0```$NV`0`I````<;8!`",```";
MM@$`*````+^V`0`N````Z+8!`"(````7MP$`)@```#JW`0`H````8;<!`"D`
M``"*MP$`(P```+2W`0`:````V+<!`"L```#SMP$`,P```!^X`0`D````4[@!
M`"H```!XN`$`*@```*.X`0`T````SK@!`!0````#N0$`,0```!BY`0`R````
M2KD!``P```!]N0$`#@```(JY`0`9````F;D!`!0```"SN0$`$0```,BY`0`F
M````VKD!``4````!N@$`"0````>Z`0`G````$;H!`#$````YN@$`%0```&NZ
M`0`C````@;H!``H```"EN@$`%0```+"Z`0`(````QKH!``L```#/N@$`%0``
M`-NZ`0`1````\;H!`"`````#NP$`!P```"2[`0`Y````++L!``<```!FNP$`
M$P```&Z[`0`+````@KL!`$,```".NP$`"0```-*[`0`?````W+L!`!0```#\
MNP$`%P```!&\`0`7````*;P!`#@```!!O`$`'0```'J\`0`0````F+P!`"<`
M``"IO`$`$@```-&\`0`2````Y+P!`!P```#WO`$`"@```!2]`0`6````'[T!
M``D````VO0$`(0```$"]`0`*````8KT!`"(```!MO0$`*````)"]`0`)````
MN;T!`!L```##O0$`!P```-^]`0`*````Y[T!``D```#RO0$`0````/R]`0`*
M````/;X!``H```!(O@$`"P```%.^`0`'````7[X!`!,```!GO@$`"0```'N^
M`0`?````A;X!`!H```"EO@$`%````,"^`0`*````U;X!``L```#@O@$`&@``
M`.R^`0`)````![\!`"P````1OP$`#@```#Z_`0`0````3;\!``D```!>OP$`
M`@```&B_`0`1````:[\!`!H```!]OP$`"P```)B_`0`%````I+\!``T```"J
MOP$`"````+B_`0`+````P;\!`"L```#-OP$`#P```/F_`0`4````"<`!`!0`
M```>P`$`#@```#/``0`N````0L`!`!D```!QP`$`&0```(O``0`<````I<`!
M`!````#"P`$`,@```-/``0`4````!L$!`$`````;P0$`!````%S!`0`'````
M8<$!`!````!IP0$`%@```'K!`0`&````D<$!``<```"8P0$`!P```*#!`0`,
M````J,$!``<```"UP0$`$````+W!`0`1````SL$!`$$```#@P0$`-@```"+"
M`0`K````6<(!``4```"%P@$`%P```(O"`0`B````H\(!`!X```#&P@$`'@``
M`.7"`0`2````!,,!``(````7PP$`!````!K#`0`0````'\,!``4````PPP$`
M!0```#;#`0`#````/,,!`!````!`PP$`+P```%'#`0`1````@<,!`"(```"3
MPP$`,````+;#`0!2````Y\,!`!0````ZQ`$`;P```$_$`0`B````O\0!`$(`
M``#BQ`$`'@```"7%`0!*````1,4!`"D```"/Q0$`/@```+G%`0!`````^,4!
M`#P````YQ@$`0````';&`0`J````M\8!`!X```#BQ@$`+@````''`0!(````
M,,<!`!@```!YQP$`#````)+'`0`-````G\<!`&T```"MQP$`"@```!O(`0"K
M````)L@!`',```#2R`$`<0```$;)`0`F````N,D!`&P```#?R0$`&P```$S*
M`0`N````:,H!`!,```"7R@$`"@```*O*`0`9````MLH!`!T```#0R@$`-@``
M`.[*`0`F````)<L!`"(```!,RP$`90```&_+`0`7````U<L!`!H```#MRP$`
M"P````C,`0`$````%,P!``<````9S`$`"````"',`0`9````*LP!`!0```!$
MS`$`'````%G,`0`G````=LP!`!(```">S`$`!````+',`0`)````MLP!``@`
M``#`S`$`!@```,G,`0`'````T,P!``8```#8S`$`"0```-_,`0`*````Z<P!
M``@```#TS`$`"P```/W,`0`&````"<T!`!`````0S0$`!P```"'-`0`%````
M*<T!`",````OS0$`%@```%/-`0`)````:LT!`"````!TS0$`%@```)7-`0`F
M````K,T!`!8```#3S0$`!0```.K-`0`;````\,T!``@````,S@$`"````!7.
M`0`2````'LX!``8````QS@$``@```#C.`0`"````.\X!`!8````^S@$`!0``
M`%7.`0`-````6\X!`!4```!IS@$`&0```'_.`0`'````F<X!`"\```"AS@$`
M`@```-'.`0`#````U,X!``T```#8S@$`#@```.;.`0`(````]<X!`!@```#^
MS@$`'````!?/`0`+````-,\!`!,```!`SP$`#P```%3/`0`4````9,\!``(`
M``!YSP$`"````'S/`0`1````A<\!``\```"7SP$`$````*?/`0`D````N,\!
M``8```#=SP$`"@```.3/`0`2````[\\!``D````"T`$``@````S0`0`+````
M#]`!``$```#M````UP,``&D```!M`0```````/<%```H!@``1P$``$L#``#H
M!0```````-L#``#A!0``:@```*$$````````9P,``!D$``!#!0``K04``&<!
M```A!@````````````"1`0``DP4````````"`0``R`4``&L$````````U`0`
M`+4%``"_````)0$``#,$``#3!```00````H&``"?````8@$``"8!``"F`0``
M`````(P$``"S``````````````!(`0```````$X"`````````````(X!````
M`````````%D&`````````````````````````````$````!L!0``^04`````
M````````A0$``#8$```@!````````'<!``!C!0```````(H&``#>!0``5@8`
M`!D"`````````@,`````````````&P$``(D"``#B`0``:0,```````"J`@``
M`````!\%``#&!0``NP0``#T```#F!```30,``)X```!=!0`````````````H
M````-@(```````"@````7P$``#\&```<`@``````````````````;0(``'L%
M````````5`,``-H"``"!`@``2P8````````H`0``50,``(H#```G!@``[`$`
M`````````````````'<&```T````I`$````%``"@`@``:`$```````!F!```
MC`$```````"S`P```````#D!``#M!0``)P$``,D!```W!0``4@,``%,#``"[
M`P``KP0``"<%```7````LP0``%$&````````/@$``/D$``!N`0``.@8``"T#
M``!6````_0$``'8!```"!```7P```/$```!<!@``\0$```````#4`@``O@,`
M`!L%``!]`@``9`0``'<%`````````````.X"``#L!```OP,``#H"````````
M;P0```P%```E````7`0``#L```!T!0``P00``.\!```C!@``.04``,P"```V
M!@``R0``````````````Z`(`````````````G`0``/0$``!^`````````+P"
M``"H`````````$<```!J!@``<@```(4%````````A@4``%P%``#9````B`4`
M`#X```#O!```*00``)<`````````T@```%X````>!````````$0"````````
MGP4```````!!`@``O0$```````#&`0``+@(``,$"``!K!@``+0(`````````
M````\@4```````!W`@``N`,```````!.`P``!0```#8!``!4`0``B00``&8#
M``"I!0```````$L```"5!@``:@$``&$#````````400```4&````````````
M```````*!````````+4$``",`@```````*D#``!&`P``.@```%@!````````
MAP8``(T!``"M!```?08``)D!```O`P```````/0"``"6`@```````,4"``"M
M````208````````A`P``Q`````````"4!@``]P0```("```F`P``L@4``'T`
M````````IP0``$,&``"\!```(P```"H%````````O`,``$,"``!6`@``````
M`&@"``!E!````````*`#``!%!0``0`0``%4$``"E!```#0````$#``"D`@``
M7P,``+0%```#`@``=0,```````!V`P``#@,``,<"``!G!````P4``#<!``"9
M!@``C@4``*P%``!8!```?P8```````#+````K@```,<!````````Y0(`````
M`````````````-T!``!C````_@,``,`#````````2@(``#8%````````````
M`/X!````````E`4````````Z!0```````/\```#H`P``>`8``$\!``"(`@``
M;`8``)4#``#G`0`````````````2!```<P4``+0!``#R`0``$@`````````F
M````-`,```8"``"6!```(P4``````````````````.,"```T!@``PP,```0$
M````````6@8``/H!````````'`,````````/`P``I`0```````!I!```B@``
M`.$"``"I````S`````````!Y!```?P0```````#C````G``````````T`0``
M`````"\&```%`@``H`$``!@"```D`@``<@,``)T%``#Y`0``#`(````````K
M`@``T00``%(`````````BP,```````#)`@``?@,``#("```*!0``?00``(@$
M`````````````),"``!-!```K@(``,P%``"6!@``;@```*<"````````/@,`
M`*8$``#.!0``%@,````````<`0``T0,``(<````1````AP4``!,$````````
MC0`````````<!0``;00``'8"``"B`0```````%,````X````6P(``'("``!6
M!0```````+$%``#3````SP```&P#```J`@````````````!,!0``-`0``/,`
M````````)P```(X#````````$`$````````B`@``*04```````"Y````````
M``4%````````&@8``%,%````````>````.(```#N!0```````$T`````````
M!0,``````````````````/P#``!'!0``]`$``!X```#(!```C@8```````"#
M````508``/8#``#Z`P``W@0``'L$``"^!0``'P$`````````````G`$`````
M``!,`@``2@8``!P```#?!```/@4``*H$``"8`@``T`$``/<"``![`0``?@4`
M`"X````E`P``5P,``$@$````````LP$``!<$````````,P```,\$``"0`0``
MCP4```````#(````/0(``&P"```G`P```````/4#``!]`P```````$L%``!@
M!@``Z0(``'P#```3`P``EP4``.T"``#6!0``R`(```````!N`@```````/L$
M```)`0``&@,```T%````````108```````"W`````````.0"``#9`0``D`(`
M`'\%``!9`@```````%(&```$!@``\`4``!`````9`0``T`(``.P```#Q!```
M70```.L```!1`@```````)L"````````W`(```````#.`0``T@0``"X$````
M`````````*<%``"L````K`0````````=`@``%@8``,("``!O`@```````+@!
M````````Y@(``/@%``#E`P``\@```,4!``#[!0``A@8```````#7!```````
M`'X!```Z`P````````````!<````I@,``.<$````````U04```````!0`@``
M`````#X"``#`!0``/04```````#2`0```````,T$```E!0``F@```%("``"=
M`0``P`0``)X!``!K`0``B@$``!H"``"+!0``&`,``)T"``"1````;0``````
M``"`!```.0,`````````````%04``.0$```@!@``!`,``'L#``#J!0``^`$`
M``````!S`@```````.T!``!A!```5P(``"@"``"E`P``I04``,T#``!,`P``
M``````````!X!````````&<```!4!@``@@8``%$%````````.P$````````'
M`0``40$````````L!@``-`4```````"_`0``'`8``,`!``!5`@``#P4`````
M```.````*@8``.X#```?`P``W@(```````#]`P``B04``,$#``#0`P``(`4`
M``T#``!:!```Z`0``+P%``"/!````````#\!```)````3@$``#L&``!3`@``
M`````.4```"?!```Z@(``&@#``#6`@``;@4``+X```"4!```H@4`````````
M````>@,``(T&``!6!````````+D!````````A@(```0!``!/````3`8``"H#
M``#)!0``FP,```````!@````C0(``!4````N!@``2@$```````!'!```````
M`-0````W!@``<`(``-$"``"8`0``_P(``'H"``!"!```T@,``$8%``!#`0``
M`````/<`````````,@4``/\$``"7!@``N@0``.$$``!``0``T`4```````"R
M`P```````#4#``",!@```````-H$``#I````V0(``'(&```\!```J@``````
M``#G`P``700``!8"``!T!@``;P4``'\"``"*!0```````)$%``#/`@``90(`
M`*@!``"?`0````````$$``!P`P``$00``'($``"$`@``X`4``(X$``".`@``
M```````````+`````````",$````````%P8``#<$````````9`4``"0```#K
M!```"P(``````````````````!,&````````3`0````````,!```B`$``($&
M````````I0(```````"P!0``008```````#F!0``AP$``)@```"O````Y@$`
M```````[!0``(0```/X$````````V0,```````!8`@``R`$``$,$``#X`@``
MM@4``#(&``#;`@``5P$```L&````````-00``````````````````-$!```O
M`@````````(```#B!````````/,$``!F!0```````.P"````````,P8``)X$
M``"6````^P(``),!`````````````/X```"*!```@`4``'P"````````````
M`%@%``#\!0``#`$```````"V`@``0@`````````O!```<P8``$$$````````
M`````",#````````BP8``+8$``#8`@``G0````````#V`0``0`,```<`````
M`````````(\#```N`0``&0,``#P```"2`P````````````",`````````+($
M``!]`0``G`,``'@#``!U!0``E````)4```!Q!@``/0$``(<$``"K!```````
M`%,!```````````````$``#6`P````````0%`````````````(0```">`@``
MI0```((!```&`0``S`0```@#```#````OP(```,$``#:`0``J@,``%L```!@
M!````P,``(@&``">`P``8P0``($`````````3P,``+H``````````````-T#
M```W`P``'P8````````:`0``:`0``#0"``#C`0``!@8``&`%``#K`P``H@,`
M`/L!````````?@(``',````K`P``_P$``+8!``#Z!0``ZP(````````M!0``
M`````+L%``!N!@``R@0``+<%`````````````$0&````````8@0``!,!``!*
M`P``<P0``+$"````````W`,``#@#```L`@```````,$%``"#`0``)`4`````
M``#Y`@``7@0``%L&```!!@``9`````````#D`P``C00``%````!8!@``````
M`)`&``"'`@``0P,``/4```"I`0``]P,```````"A````E04``(4#``!7````
MW@```%`!````````U`4``.0```!O`P``7@8``*,%```/!```BP$``)X%``#=
M!0```````!`"``!/!@``X0$``)L&````````A08``(,%``#V````[00```X!
M````````2P0``)(!``"C!```,08````````*`````````$`"``#J`P``<P,`
M`$L!``#Y`````````+<#``"1`P``UP(``&`!````````9P8``&D"``#``@``
MRP,``#$!``````````````````#I!```#@4``$<"``#K!0``.@$``-(%``"!
M`0``Z0$``/H````/`@`````````````Q`@```````+0#`````````````&$&
M````````RP0``($#``"#`P````````````#`````6@4```````#'``````(`
M```````A`@``JP4```````"X!0``H04``"P$``#C!0``(@0``%D%``"Y!```
M%@4``'`%``!\````-P(`````````````:````,H"````````_0```)P"``!;
M`0``&`0``"D#````````B`,``!("``!(````K`(``,H``````````````$8`
M``!$!0``"`4``````````````P$``#`$````````F00```````!Z`0``)00`
M`,0#``!%`0``;P`````````;`````````#P%``#3`@```````'L&``";````
M]`4``!H```!)````100````````B!@``S@``````````````+@4``/$%````
M`````````%H"````````:P```%\%````````>P```/<!````````]0$``-D$
M``"H!``````````````2`0```````/````!(!0``D@````````!Q````9@``
M`)H$````````D@(``$T&`````````````````````````````(8$``#7!0``
M+P4``!,```"7!```]`````````"O`@``A`0``%D$``#R`P``,`,`````````
M````#@0``.("``#D!0``8`,``"(#````````W0(``+$$```>`@``+````"H$
M``"H!0```0$``+P```"K`0``8@4````````"!0``````````````````,P(`
M``````!A````JP(``(4$``!.!0``!@4`````````````<`0``/T$``#<````
MFP0``!0$```5`@``]00``((```"C````W@$```````"4`P``+00``*<#``!^
M!@``+`$``,($``#E`0``,````'@%``"``P``0@8``#\"``#E!```!P4``((%
M``!G!0````````````!)!```&`8```````!6`0``TP$```\&``"0!0``````
M`)(&``##!```WP(``,(!``"I!`````,``&D&``"P!```D0(``'4&```6````
M8@(``"4&`````````````#$````*`P``G`8```````!;!0``?`4```````!"
M`@```P8```````#T`P```````,<#`````````````#8#````````K0,``,H%
M``"7`0``Y04`````````````@@,``)``````````[@0````````Z!```````
M`*X%``"-!0``M`````````!(!@``2`,```````!F`@```````+H#``!B!@``
MX`(``/H$````````K@$``-H%```G!```%````)4"````````_````(T#``!"
M`P``CP8```````"O!0``3`$``(0#``#^`@``U`,``&$"```(`````````)H#
M````````L`(``"4"``!&`0```````#4&````````=0`````````\`0``8P,`
M`,D#````````A@````````#I!0``*@````````!K`P``H@```*0%``!%````
M.`(``*P!``!2!```A0(``%T"`````````````!L&```F!```F04``-P%``"/
M`@````````````"&`P``2@0``$0````4`P`````````````D`P```````%X!
M``"K`P``J@$```````!Y`0````````````!T`P``#0$``'$$````````&P0`
M``````#6!`````````````!E!@``'P```````````````````"$!``":!@``
M_`0``'(%`````````````&\&```^!```F0(``,0"``#+`@``'04``,4%````
M`````````&0!``"*`@``:`4``.L!``"R`0``T0```+`#``!Y`@``$0,``/H"
M``!?!@`````````````J`0``7`,```````#"`````````-T$``#Q`P``-P``
M`,$````1!@``,@```!8!````````3P4``%,&````````HP(```````!+`@``
M60,``!8$````````(@4``*`$``!J!0``C`,````````L!0``]@(```````"Q
M`P`````````````Y!````````#\$``"D````)`$``(L`````````O0(``-,%
M``"8!```904``/L`````````6`,```L#``!Z!0``6@``````````````````
M`-\!``"^!````````+@````/`0``L0`````````C`0```````#,!````````
M*0(``)`$``!5`0``````````````````H0(``)\"``!D`@``Y`$``'\!````
M````KP$``+L"``!K!0```````&D%````````!@```$,````I`0``S@0``-\#
M``!`!0``&P,``'D#``#-`0``AP,```````!.!@``?P```%(%``"9````]0(`
M`+8`````````````````````````,`(`````````````I@```!4#``#J`0``
M&````$0$`````````````(`!```4!0``X`,``&H#``"G`0``'08```L%``!:
M`P``3````"L&````````\P(``+4#``!&!```4`,``-@```!P`0``/`,`````
M``")````:@0```````````````````@$``"N`P``V04``-8`````````````
M`+(`````````(04``,$!`````````````)$$``#"!0``<0,``.@!```)!0``
MR`,``-L!``#8!```9@8``(("``!C`@```````),&``#?````5`(``-\%``!)
M`0```````&8!``!<`0``60```%(!``!1`P``-0(``'P!``"Y!0``K`,``&(#
M````````SP$``)8!````````_0(``,0$``"]````V`$``%X#```'`P```04`
M`+````#O!0```````+@"``#J````*`4``````````````````)0!```1`@``
M,@$``$$!``#=````^`,``+D"```1!0```````*T!``"2!```-0$``$T%``!$
M`P``````````````````S@(``#@%````````)@8``*T"````````N@(``&T#
M````````'00``$$#````````V@```.,$``!1````'P(``-0!```&!```DP,`
M`.,#``!'!@``E@,````````B`````````'@!```'!@``(`,```8#``"U`0``
MV@,``)H"``!Q`0``L`$``%T!````````90$``$X````Q!```_`$````````]
M!````````+<"````````7P0```@"``!_`P``,P4``,H#````````HP,`````
M``#'!0``I0$``%,$```3!0``TP,``$D%``"K````.P0```````!8````````
M`$D#````````N0,``&P!``"W`0``.08``)L%``!D`P``4`4```````#R`@``
MPP$````````'!```EP,``"L`````````?@0```@!`````````````*<```![
M`@``[P,```H!```Q!0``=P,``(8!```,!@``"P0``,,%`````````````)<"
M``"!!```Q0,````````)!@``A0```+H%``"+`@``=`(``#\````S`P``C@``
M`,8`````````\@0``#L#``"S!0``8@```!0"````````2@```"L$``!N`P``
M\0(``/`$````````?`0``'<````9!0``PP````````!.!```G0,``&4#``"_
M!0``90```&T%```Y`@```````+0$```M````"0(`````````````9`8``%<%
M``!X`@``/P,``/\#``!O`0``D@4``-L````*`@``U0(````````B`0``````
M``````"A`P`````````&``#<!```=````+4````C`@``R@$``-4!``!C!@``
M`````($%``"^`@```@8``'<$````````$`4``%8#``#[`P``X``````````$
M`@```````-````"V`P```````*($``!:`0``1`$``&L"```,````$0$``),`
M``!S`0``BP0````````X!@``NP```!D&```M`0```````'H```#]!0``Q`4`
M`!(&````````#@(``.D#``#X!```804``)H%```'`@``W@,`````````````
M`````'0$````````B0$```````";`0``504``*D"`````````````!,"````
M````PP(``#D````%!```5P8``&<"`````````````+4"``#G!0``QP0`````
M``!>`@``004``!X%``"X!```F0,````````=`P``'`0```````"]!0``80$`
M``\```#$`0``X@4``!0&``#L`P```````+H!````````?04``!<%```.!@``
M0@$``#T&``"$!@``W`$``-<!````````%P(``$T!```0`P```````!@%````
M````J`,``+,"```X`0``HP$``+P!```D!@``,`8````````2`P``D08``'8$
M````````(`$``(0%`````````````*("``#G````MP0```````!%`P``<`8`
M`*8%```5!@``^````"D&```0!@``&`$```````!9`0``/`8``/P"``#S`0``
M)@4``,T```````````````$"``!%`@``30(```````!L!````````),$````
M````;08``/X%```$````)P(`````````````VP4``)4!``#8`P``6P,``+0"
M``"8`P``=@8````````-`@``%`$``.@```#P`P``[0,``!X&``!R`0``````
M`"`"``#J!````````$8&```D!```X0,``````````````````-8!```-!```
M7@4``"`````>`0``"P$``+\$``!0!@``%00``#(#``!\!@``VP0``)4$``!=
M!@``&P(``,\#``"]!```%0$``.$```"[`0```````$`&``!V!0``J`(``.`!
M``!/`@`````````````7`P```````'H$````````\P,```````#N`0``````
M``````"=!```U0```#L"````````$@4```````!L`````````,L%``"#!```
M70,``!T!```)`P``U00``!H%``!U`@``X@,``.X````L`P``'P0``*8"````
M`0``R00``,P!`````````````$8"``"8!0``+P```(P%```F`@``@`8``.P%
M````````@P8``#@$``#2`@``B08``#`!``#&`@``'0```'$%``!7!```````
M`"@$````````J@4``+("```M!@```````````````````````/`"````````
M``````````!;!```=`$``#8```!(`@``CP```#X&``#U!0``RP$``'D```#-
M`@``-04``/,%``#V!0``\`$``&`"````````A`$``)\#```0!````````#($
M``"D`P``E@4````````(!@````````````"N!```UP```!H$````````````
M``````!U!```/`(``&D!``"``````````+$!``````````````````#.`P``
M#08```````!H!@``2@4``,8$``"/`0``U0,``%`$````````O@$``'H&```)
M!```T`0``#`%````````3P0``"D```!Q`@``D`,``)H!`````````````#T#
M`````````````"L%```N`P```````.`$```,`P``@@0``(`"````````E`(`
M`)P%`````````````````````````````&,!``"A`0``5`0``'D&```>`P``
MO0,``"$$``!4````````````````````[P(``-$%``!V````S`,``/\%``#F
M````/P4```````#F`P```````,(#`````````````$(%````````@P(``/D#
M````````7`(``$D"``#8!0```````)@&````````B0,``(@```!N!```7P(`
M`"L!```7`0``Q@,``,\%``!J`@``KP,````````U````Q00``!D```#%````
M5`4``*`%````````!0$``'``````````*`,``'D%``#-!0```````"\!``#G
M`@``,0,``.\```!'`P``50```'4!``#V!````"`H)7,@9&%Y<R!A9V\I`"`H
M06-C97-S:V5Y("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R
M;W<I`"`H>65S=&5R9&%Y*0`@870@`"(E<R(@:7,@;F]T(&$@9&ER96-T;W)Y
M+@`B)7,B(&ES(&YO="!A('9A;&ED(&-H;VEC92X`(B5S(B!I<R!N;W0@8V]N
M9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN`"(E<R(@=')E92!R96YD
M97)E<B!N;W0@9F]U;F0N`"(E<R(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@
M<WES=&5M+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES
M=&5M+@`B)7,B('=A<R!N;W0@8W)E871E9#H@)7,N`"4N,F9-0B!U<V5D(&]F
M("4N,F9-0B!A;&QO=V5D("@E+C)F)24I`"5D("5S(&%N9"`E<P`E9"!D87ES
M('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RX`)60M9&%Y(&9O<F5C87-T
M`"5S("T@3F]T:6-E`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT96YA
M;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T=7``)7,@4VEG
M;B!5<``E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D>2!E>&ES=',N
M`"5S(&%T("5S("5S`"5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE(&)O
M>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T
M('1H:7,@=&EM92X`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@
M9F]U;F0N`"5S('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K`"5S)W,@
M0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"5S
M.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US
M('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG(&%N>2!L:6YK<R!I;B!I="!O
M<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I
M;F9O<FUA=&EO;BX`+"!G=7-T:6YG(``L(&=U<W1I;F<@)7,@)7,`+"!V87)I
M86)L92!F<F]M("5S('1O("5S`"TM('-E;&5C="`M+0`Q,B!(;W5R($9O<FUA
M=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P`\4')E=FEO=7,`02!D871A8F%S
M92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L
M(&5R<F]R(&AA<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES
M(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI
M8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0
M(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL
M('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y
M+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES
M(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!32!#;&]U9',`04T@
M3&EG:'0@4F%I;@!!32!286EN`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W97)S
M`$%-+U!-`$%022!)1`!!8F]U="XN+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG
M(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I
M;&4N`$%C8V]U;G0@26YF;W)M871I;VX`06-C;W5N="!087-S=V]R9`!!8V-O
M=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`061D($-H:6QD($=R;W5P`$%D
M9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D
M9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!G<F]U<"!T;R`B)7,B`$%D
M9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@(B5S(@!!9&0@82!N97<@=7-E<CH`
M061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D('!A:7(`061D('1H92`E
M<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!T;R!A9&1R97-S(&)O
M;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D('5S97(`061D960@(B5S
M(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L
M('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N`$%D9&5D("(E<R(@=&\@=&AE('-Y
M<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+@!!9&1I;F<@=7-E<G,@:7,@9&ES
M86)L960N`$%D9')E<W,`061D<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S970@
M<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D
M<P!!9F=H86YI<W1A;@!!;&)A;FEA`$%L9V5R:6$`06QI87,`06QL`$%L;"!!
M=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS
M`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R
M9&5R960@;&ES="!T>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U3
M4"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U3
M4"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@
M=&5M<&QA=&5S`$%M97)I8V%N(%-A;6]A`$%N(&EL;&5G86P@=F%L=64@=V%S
M('-P96-I9FEE9"X`06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"X`06YD
M;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!
M;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U9&$`07!P;&EC871I;VX`07!P
M;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P;'D@=&\@
M0VAI;&0@4VAA<F5S`$%P<')O=F4`07!R:6P`07)A8FEC("A7:6YD;W=S+3$R
M-38I`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!<F4@>6]U('-U
M<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@
M)7,@/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E("(E<R(@86YD
M(&%N>2!S=6(M9W)O=7!S/P!!<F=E;G1I;F$`07)M96YI80!!<FUE;FEA;B`H
M05)-4T-)22TX*0!!<G0`07)U8F$`07-C:6D@07)T`$%S:6$O4&%C:69I8R!2
M96=I;VX`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1E;7!T
M('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D
M96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E
M9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I
M="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T<FEB=71E<P!!=6=U<W0`075S
M=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO
M="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U
M:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U
M:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET
M:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E
M9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER
M960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z($%D9&EN
M9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y
M`$%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F
M;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@861D
M('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!=71H
M7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N
M86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!=71H7VQD87`Z(%5P9&%T:6YG('5S
M97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN`$%U
M=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:&5N=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+@!!
M=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E
M<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!
M=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC
M871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@9FEE
M;&1S.@!!>F5R8F%I:F%N`$)/1D@@17AC=7-E<P!"860@:V5R8F5R;W,@<&%S
M<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"86AR86EN
M`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`0F%S
M92!G<F%P:&EC<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`$)E;&%R=7,`
M0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R;75D80!":'5T86X`0FER=&AD87D`
M0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO
M8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";VQI=FEA`$)O;VMM87)K<P!";W-N
M:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A;F$`0F]U=F5T($ES;&%N
M9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE
M:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--
M4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0V%C:&4@:6YI="!W87,@
M;F]T(&-O;7!L971E9"X`0V%L96YD87(`0V%L;0!#86UB;V1I80!#86UE<F]O
M;@!#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N
M`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;B=T(&]P96X@
M9FEL92`B)7,B+@!#86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R
M=`!#86YN;W0@8V]P>2!F:6QE*',I("T@<V]U<F-E(&%N9"!D97-T:6YA=&EO
M;B!A<F4@=&AE('-A;64N`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN
M;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!M;W9E(&9I
M;&4H<RD@+2!D97-T:6YA=&EO;B!I<R!W:71H:6X@<V]U<F-E+@!#86YN;W0@
M<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N`$-A;FYO
M="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D(&-H
M:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I
M97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R
M('-T;W)E9"X`0V%N;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL
M(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86YN;W0@<F]U=&4@;65S
M<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#86YN;W0@=W)I=&4@=&\@9FEL
M92`B)7,B`$-A<&4@5F5R9&4`0V%R<FEE<@!#871E9V]R:65S(&%N9"!,86)E
M;',`0V%Y;6%N($ES;&%N9',`0V5L;"!0:&]N90!#96QL<&AO;F4`0V5L=&EC
M("A)4T\M.#@U.2TQ-"D`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R
M86P@175R;W!E86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I;',`
M0V5R=&EF:6-A=&4@3W=N97(`0V5R=&EF:6-A=&4@4&]L:6-I97,`0VAA9`!#
M:&%N9V4`0VAA;F=E(%EO=7(@4&%S<W=O<F0`0VAA;F=E('1H92!N86UE(&%N
M9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@
M<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H86YG:6YG('EO=7(@<&%S<W=O<F0@
M:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I
M;VXN("!#;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0VAI;&4`0VAI;F$`
M0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N
M86P@*$)I9S4I`$-H;V]S92!!<'!L:6-A=&EO;CH`0VAO;W-E(&$@<&%S<W=O
M<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A
M=&5S.@!#:')I<W1M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@
M;F]T(&9O=6YD+@!#;&5A<@!#;&5A<B!1=65R>0!#;&5A<B!O=70@=7-E<CH@
M)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQE87)I;F<@3&%T90!#
M;&EC:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL('9I82!(5%10`$-L;W-E(%=I
M;F1O=P!#;&]U9',`0VQO=61S($5A<FQY`$-L;W5D>0!#;V-O<R`H2V5E;&EN
M9RD@27-L86YD<P!#;VQL87!S92!3:61E8F%R`$-O;&]M8FEA`$-O;&]R`$-O
M;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O;'5M;B!T:71L97,`0V]M
M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE
M`$-O;6]R;W,`0V]M<&%N>0!#;VUP=71E<G,`0V]N9&ET:6]N`$-O;F1I=&EO
M;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F%T:6]N(&9O
M<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN
M`$-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N`$-O;F9I9W5R92`E<P!#
M;VYF:7)M(%!A<W-W;W)D`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!2
M97!U8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@
M9F%I;&5D.B``0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y
M<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES
M97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V
M97(@9F%I;&5D+@!#;VYT86-T<P!#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL
M>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&5N="!T>7!E(&]F
M(&-O;7!R97-S960@9FEL93H@`$-O;G1E;G1S(&]F("(E<R(`0V]N=&EN=64`
M0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y(&9A:6QE9#H@)7,`0V]S="!)1`!#
M;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T(%!'4"!E;F-R>7!T
M(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G93H@`$-O=6QD
M(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%
M('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L
M9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H96-K(&)A
M;&%N8V4N("5S`$-O=6QD(&YO="!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!#
M;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@(B5S(B!U<VEN9R!&5%`Z("5S
M`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD
M(&YO="!D96-R>7!T(%!'4"!D871A.B``0V]U;&0@;F]T(&1E8W)Y<'0@4R]-
M24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,`0V]U;&0@
M;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E
M;&5T92!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!#;W5L9"!N;W0@9&5T
M97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@
M;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E
M=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T
M8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#
M;W5L9"!N;W0@;&]A9"!S=')A=&5G>2`B)7,B+@!#;W5L9"!N;W0@;6MD:7(@
M(B5S(BX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME
M>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN9RX`0V]U
M;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A
M<VL@;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B)7,B+@!#
M;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@<F5A
M9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E
M<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@
M;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI
M<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R
M971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@
M)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#
M;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L
M9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO
M="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T(')M9&ER("(E<R(N
M`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S
M879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B
M86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!S971U<"!U
M<&=R861E('-C<FEP="!T;SH@(B5S(BX`0V]U;&0@;F]T('-A=F4@=&AE(&)A
M8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`$-O=6QD(&YO="!S879E('1H
M92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O
M;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S
M(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N`$-O=6QD
M(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@=6YL:6YK
M("(E<R(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T
M('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T('=R:71E
M(&-O;F9I9W5R871I;VX@9F]R("(E<R(Z("5S`$-O=6QD;B=T(&9I;F0@=&AE
M($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P
M96XN`$-O=6QD;B=T(&=I=F4@=7-E<B`B)7,B('1H92!F;VQL;W=I;F<@<FEG
M:'1S(&9O<B!T:&4@9F]L9&5R("(E<R(Z("5S`$-O=6YT960@=&5X=`!#;W5N
M=')Y`$-O=7)S97,`0W)E871E`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U
M8B!F;VQD97)S`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M
M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT(#0@4&AA<V5S`$-U<G)E;G0@4V5S
M<VEO;G,`0W5R<F5N="!4:6UE`$-U<G)E;G0@57-E<G,`0W5R<F5N="!796%T
M:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5S=&]M:7IE('1A<VMS('1O(')U
M;B!U<&]N(&QO9V]N('1O("5S+@!#>7!R=7,`0WER:6QL:6,@*$M/23@M4BD`
M0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O56MR86EN:6%N("A+
M3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$`$133B`H<V5E(&AT='`Z+R]P96%R
M+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M
M9'-N+G!H<"D`1&%I;'D`1&%T851R964@0G)O=W-E<@!$871A8F%S92!,;V]K
M=7``1&%T90!$871E(%)E8V5I=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$96-E
M;6)E<@!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$
M969A=6QT(%-H96QL`$1E9FEN:71I;VYS`$1E;&5T90!$96QE=&4@1W)O=7``
M1&5L971E($QO9P!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E
M(&UE<W-A9V5S`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`
M1&5L971E(&UE<W-A9V5S`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(@!$
M96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(@86YD(&%N>2!S=6(M<&5R;6ES
M<VEO;G,_`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@<W5B(&9O
M;&1E<G,`1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!$96QI
M=F5R>2!T:6UE`$1E;FUA<FL`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I
M<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A
M:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$
M979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z
M(`!$97<@<&]I;G0Z(`!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I;65S
M/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S=`!$
M:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R;6%T`$1I<W!O<VET
M:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!N;W0@9&5L971E`$1O(&YO
M="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O97,@=&AE(&9I
M<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C
M:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B;&EC`$1O;B=T
M(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"X`1&]W;FQO860@)7,`1&]W;FQO
M860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`1')O
M<"!D;W=N(&QI<W0`1')U9W,`12U-86EL`$5-86EL+71O+5--4R!G871E=V%Y
M(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V
M:6-E+@!%4E(`16-U861O<@!%9&ET`$5D:70@0FQO8VL`161I="!'<F]U<`!%
M9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I
M;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS
M(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D=6-A=&EO;@!%
M9WEP=`!%;"!386QV861O<@!%;6%I;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D
M9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%
M;6%I;"UT;RU335,@1V%T97=A>0!%;6]T:6-O;G,`16UP='D@;65S<V%G92X`
M16UP='D@<F5S=6QT+@!%;7!T>2!S96%R8V@@=&5R;7,`16YA8FQE(&EN<V5R
M=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\`
M16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`16YD('EE87(`16YT
M97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME
M9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W
M:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H92!L971T
M97)S(&)E;&]W.@!%<75A=&]R:6%L($=U:6YE80!%<FET<F5A`$5R<F]R`$5R
M<F]R(&-R96%T:6YG(&)L;V-K.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&%N
M8VAO<CH@)7,`17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S`$5R<F]R(&=E
M='1I;F<@8V]N=&5N=#H@)7,`17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S
M`$5R<F]R('=I=&@@96UA:6P@;65S<V%G92X`17)R;W(@=W)I=&EN9R`B)7,B
M+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@,34@;6EN
M=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U
M(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI
M;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A;F0`17AP96-T960@
M)RDG`$5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`
M17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$944"!U<&QO860@;V8@<V5T=7``
M1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN
M96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@
M<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C
M;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C
M=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I;&5D('1O(')E=')I
M979E.B`E<P!&86ER`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O
M92!)<VQA;F1S`$9A=&%L($5R<F]R.@!&87@`1F%X97,`1F5B<G5A<GD`1F5E
M;',@3&EK90!&965L<R!L:6ME.B``1F5W(%-H;W=E<G,`1F5W(%-N;W<@4VAO
M=V5R<P!&:65L9"!M871R:7@`1FEG;&5T($-!4%1#2$$`1FEG;&5T(&9O;G0`
M1FEJ:0!&:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@)7,@
M9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO;@!&
M:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R
M<P!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&:7@@<F%T:6\`
M1FQI<`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;V0`1F]R96-A
M<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE
M9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82!L87)G
M92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*0!&
M;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y
M<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9',`1G(`1G)A
M;F-E`$9R86YC92P@365T<F]P;VQI=&%N`$9R96YC:"!'=6EA;F$`1G)E;F-H
M(%!O;'EN97-I80!&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O;0!&
M<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE
M`$=A8F]N`$=A;6)I80!'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R
M871E9"!#;V1E`$=E;W)G:6$`1V5R;6%N>0!':&%N80!':6)R86QT87(`1VEV
M96X@3F%M90!';&]B86P@3W!T:6]N<P!';P!';V]G;&4@36%P<P!';V]G;&4@
M4V5A<F-H`$=R87ES8V%L90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R
M965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA
M;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P7VQD87`Z(%5N86)L92!T;R!A
M9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!'
M<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S`$=R;W5P7VQD
M87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,`1W)O=7!S`$=U861E;&]U
M<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`
M1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$A4
M5%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R
M:71H;0!(87IE`$AE861E<@!(96%D97)S`$AE87)D($ES;&%N9"!A;F0@36-$
M;VYA;&0@27-L86YD<P!(96%V>2!4+5-T;W)M`$AE8G)E=R`H25-/+3@X-3DM
M."U)*0!(96EG:'0`2&5L<`!(96QP97(`2&5M:7-P:&5R90!(97)E(&ES('1H
M92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AI9V@`2&]?;64`2&]L>2!3964@
M*%9A=&EC86X@0VET>2!3=&%T92D`2&]M92!!9&1R97-S`$AO;64@1&ER96-T
M;W)Y`$AO;64@4&AO;F4`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E
M+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE
M<W-A9V4@)7,`2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@
M=&\@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E
M<R!F;W5N9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L
M;'D@<F5M;W9E9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I
M;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N
M`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F
M;W(@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S
M("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-
M12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<P!(;W)D92]+;VQA8CH@56YA
M8FQE('1O('-Y;F-H<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5
M;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA8CH@
M56YK;F]W;B!S:&%R92`B)7,B`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@
M87)E('1H97)E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG
M87)Y`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I
M;&)O>"!D96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C
M<F5A=&EO;B!F86EL960Z("5S`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@
M879A:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412
M(&)L;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$EC96QA;F0`26-O;G,@
M3VYL>0!)8V]N<R!F;W(@)7,`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@
M;F%M93H`268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O
M(&]P96X@:70@:6X@82!N97<@=VEN9&]W+@!)9B!Y;W4@<V5E('1H:7,@;65S
M<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO
M860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@
M=7!L;V%D`$EM86=E<P!);7!O<G0L(%-T97`@)60`26UP;W)T960@9FEE;&0Z
M("5S`$EM<&]R=&5D(&9I96QD<SH`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I
M=F5N+@!);F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O
M<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I
M;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F
M=7)T:&5R(&AE;'`N`$EN9&EA`$EN9&EV:61U86P@57-E<G,`26YD;VYE<VEA
M`$EN9F]R;6%T:6]N`$EN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N
M`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS97)T(&%N(&5M86EL(&%D
M9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O
M<F0Z`$EN<V5R="!M97-S86=E<P!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E
M<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN<W5F9FEC:65N="!C<F5D
M:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC
M:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN=F%L:60@541(
M+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L:60@6DE0(&1A=&$`26YV86QI
M9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D871A
M('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A
M;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;&EC96YS92!K97DN`$EN=F%L:60@
M;&]C871I;VX@<')O=FED960N`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@
M;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T
M97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!A<G1N
M97(@:60N`$EN=F%L:60@<')O9'5C="!C;V1E+@!);G9A;&ED('!R;W1O8V]L
M+@!);G9A;&ED(')E8VEP:65N=#H@(B5S(@!);G9A;&ED('-H87)E(&]B:F5C
M=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T
M82X`26YV96YT;W)Y`$EN=F5R="!S96QE8W1I;VX`27)A;BP@27-L86UI8R!2
M97!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-O;&%T960@5"U3=&]R;7,`27-R
M865L`$ES<W5E<@!)=&%L>0!*86UA:6-A`$IA;G5A<GD`2F%P86X`2F%P86YE
M<V4@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N`$IU;'D`2G5N90!+87IA
M:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA`$ME<F)E<F]S('-E<G9E<B!R
M96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5R;F5L($YE=V)I97,`2V5Y($-R
M96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME
M>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES
M97)V97(N`$MI9',`2VER:6)A=&D`2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE
M)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F`$MO<F5A;B`H155#
M+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,86YG=6%G90!,86\@4&5O<&QE)W,@
M1&5M;V-R871I8R!297!U8FQI8P!,87-T($AA;&8`3&%S="!087-S=V]R9"!#
M:&%N9V4`3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@
M)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,
M871V:6$`3&%W`$QE8F%N;VX`3&5F="!H96%D97(`3&5F="!V86QU97,`3&5S
M;W1H;P!,979E;`!,:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE
M8VAT96YS=&5I;@!,:6=H="!$<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I
M;B!%87)L>0!,:6=H="!286EN($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG
M:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H
M;W=E<@!,:6YK`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O
M<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O:VEE`$QI
M<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,
M:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,:7-T
M+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C
M<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@<V5S<VEO;G,@9F%I;&5D
M.B`E<P!,:7-T:6YG('5S97)S(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!I
M<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]A9&EN9RXN+@!,
M;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,
M;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N`$QO9R!O=70`3&]G:6X`3&]G
M:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O
M<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I
M;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`3'5X96UB;W5R9P!-30!-3U1$`$U3
M+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA8V%O
M`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-
M861A9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!9&UI;@!-86QA=VD`36%L87ES
M:6$`36%L9&EV97,`36%L:0!-86QT80!-86YA9V4@=&AE(&QI<W0@;V8@8V%T
M96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L
M;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87`R-"!M
M87``36%P475E<W0@;6%P`$UA<'!I;F=S('-T;W)E9"X`36%R8V@`36%R:R!W
M:71H(%-E96XO56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H
M92YG+B!);7!O<G1A;G0O06YS=V5R960I`$UA<G-H86QL($ES;&%N9',`36%R
M=&EN:7%U90!-871C:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`
M36%X(&%L;&]W960@8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E
M9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H
M;W5R<SH@`$UA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,`36%X:6UU
M;2!L96YG=&@`36%Y`$UA>6]T=&4`365D:6-I;F4`365M8F5R<P!-96YU(&UO
M9&4Z`$UE<W-A9V4`365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T
M('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I
M960N`$UE<W-A9V4@97AP:7)E9"X`365S<V%G92!T>7!E`$UE=&%R(%=E871H
M97(`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T
M(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@
M861M:6YI<W1R871O<BX`365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+@!-971H
M;V0`365T:&]D("(E<R(@:7,@;F]T(&1E9FEN960`365T:&]D(&YO="!D969I
M;F5D+B!#86QL960@;65T:&]D.B`E<P!-971R:6,`365X:6-O`$UI8W)O;F5S
M:6$L($9E9&5R871E9"!3=&%T97,@;V8`36EM92!4>7!E`$UI;B!T96UP(&QA
M<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-:6YI;75M
M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D`$UI<G)O<@!-:7-C
M96QL86YE;W5S`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="X`
M36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C
M:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-86EL
M`$UO9&5R871E`$UO9&EF:65D($1A=&4`36]D=6QU<P!-;VQD;W9A+"!297!U
M8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N=&@@86YD('EE87(`36]N=&AL
M>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO<F4@9FEE;&1S(&9O=6YD(&EN
M(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N`$UO<F]C8V\`36]S=&QY
M($-L96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY($-L;W5D>2!A;F0@5VEN9'D`
M36]S=&QY(%-U;FYY`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-
M;W9E(%5P`$UO=F4@9&]W;@!-;W9E('5P`$UO>F%M8FEQ=64`375L=&DM;&5V
M96P@9')O<"!D;W=N(&QI<W1S`$UU;'1I;6%P(%5+(&UA<`!-=6QT:7!L92!S
M96QE8W1I;VX`37D@06-C;W5N=`!->2!!8V-O=6YT($EN9F]R;6%T:6]N`$UY
M(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@3D]4
M($%G<F5E`$YA;64`3F%M:6)I80!.875R=0!.97!A;`!.971H97)L86YD<P!.
M971H97)L86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E(%523`!.971S8V%P
M92!#02!2979O8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@55),`$YE
M='-C87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C871I;VX@55),`$YE
M='-C87!E(%-33"!S97)V97(@;F%M90!.971S8V%P92!C97)T:69I8V%T92!C
M;VUM96YT`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.979E
M<@!.97<@0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@36]O;@!.97<@57-E
M<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@<&%S<W=O<F0`3F5W
M('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+@!.97<@<&%S<W=O<F1S(&1O
M;B=T(&UA=&-H+@!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(#0@4&AA<V5S
M`$YE>'0@;W!T:6]N<P!.97AT/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.
M:6=H=`!.:75E`$YO`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@
M=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V86EL86)L92!S=')A=&5G
M>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A=&-H('1E;7!L871E+@!.
M;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C
M86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N
M+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES
M('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C
M<F5D:70@;&5F="X`3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&9I;&4@
M=7!L;V%D960`3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`
M3F\@;&]C871I;VX@<')O=FED960N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO
M(&YA;64@<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E
M;G-I=F4@9F]R='5N97,`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@
M<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@
M=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.
M;R!Q=6]T82!S970N`$YO('-E<&%R871O<B!S<&5C:69I960N`$YO('-U8V@@
M9FEL90!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C
M:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V86QI
M9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N
M9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I
M9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T
M:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;F4`3F]R9&EC("A)
M4T\M.#@U.2TQ,"D`3F]R9F]L:R!)<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R
M90!.;W)T:&5R;B!-87)I86YA($ES;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.
M;W0@0F5F;W)E`$YO="!A(&1I<F5C=&]R>0!.;W0@:6UP;&5M96YT960N`$YO
M="!S=7!P;W)T960N`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K
M+@!.;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R
M(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF
M:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3V)J96-T
M`$]B:F5C="!#<F5A=&]R`$]C=&%L`$]C=&]B97(`3V9F:6-E`$]L9"!A;F0@
M;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="X`3VQD('!A<W-W;W)D
M`$]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="X`3VUA;@!/;FQY($E-05`@
M<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N<VEV
M92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N
M;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N
M9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E
M`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO
M="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N`$]P97)A
M=&EN9R!3>7-T96T`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F=A;FES871I
M;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L(&%P
M<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E<SH`
M3W1H97(`3W1H97(@26YF;W)M871I;VX`3W=N97(@4&5R;6ES<VEO;G,`4$%-
M(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!%05(Z.DUA:6P@
M8F%C:V5N9`!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$
M871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D($1A=&$`
M4$A0($-O9&4`4$A0(%-H96QL`%!-($QI9VAT(%)A:6X`4$T@4F%I;@!032!3
M:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S`%!-(%-U;@!032!4+5-T
M;W)M<P!03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9P!07TA0(%-H96QL`%!A
M:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`
M4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`4&%R=&QY($-L;W5D
M>0!087-S=V]R9`!087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2X`4&%S
M<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@
M875T:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A
M<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T
M90!096YD:6YG(%-I9VYU<',Z`%!E;W!L90!097)F;W)M($UA:6YT96YA;F-E
M($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N
M(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VX@(B5S(B!N;W0@9&5L971E
M9"X`4&5R;6ES<VEO;B!$96YI960`4&5R;6ES<VEO;G,`4&5R;6ES<VEO;G,@
M061M:6YI<W1R871I;VX`4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0971S
M`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0;&5A<V4@96YT
M97(@82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!N86UE(&9O
M<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A
M9&1R97-S+@!0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@
M;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V
M86QI9"!T:6UE+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R
M;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W
M;W)D`%!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@
M86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!L96%S
M92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93H`4&]L86YD`%!O;&ET:6-S
M`%!O;&QS`%!O<G1U9V%L`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O
M<F-E9"!B>2!)34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H
M<RDZ(`!0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E`%!R969S7VQD87`Z(%)E
M<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`4')E
M<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I
M;W5S(&]P=&EO;G,`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E<V-R
M:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`4'5B;&EC
M($ME>2!!;&=O<FET:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R]0<FEV871E
M(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2
M:6-O`%!U<F=E(&UE<W-A9V5S`%%A=&%R`%%U97)Y`%%U;W1A`%)302!0=6)L
M:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R
M;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T
M;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E
M<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@
M=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@
M5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5F<F5S:`!2969R
M97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE
M=SH`4F5G97@`4F5L871I;VYS:&EP($)R;W=S97(`4F5L;V%D`%)E;6%R:W,`
M4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE
M+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@8V]L=6UN`%)E;6]V92!P86ER
M`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@
M9&ER96-T;W)Y+@!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5Q=65S
M="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``
M4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+@!297%U:7)E
M9"`B)7,B(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BX`4F5Q
M=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N
M+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO
M;BX`4F5Q=6ER960@1FEE;&0`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@
M66]U<B!087-S=V]R9`!297-T;W)E($QA<W0@475E<GD`4F5S=6QT<P!2971U
M<FX@=&\@3W!T:6]N<P!2971Y<&4@;F5W('!A<W-W;W)D`%)E=6YI;VX`4F5V
M97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)I
M9&1L97,`4FEG:'0@:&5A9&5R`%)I9VAT('9A;'5E<P!2;VQE`%)O;6%N:6$`
M4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4G5N`%)U<W-I
M86X@1F5D97)A=&EO;@!2=V%N9&$`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG
M;F%T=7)E`%,O34E-12!%;F-R>7!T960@365S<V%G90!305-,(&%U=&AE;G1I
M8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S86=I;F<`4U%,(%-H
M96QL`%-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',`4U-(`%-50T-%
M4U,`4U]13"!3:&5L;`!380!386EN="!(96QE;F$`4V%I;G0@2VET=',@86YD
M($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`
M4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,`4V%M;V$`4V%N($UA
M<FEN;P!386\@5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I9&5R
M`%-A=61I($%R86)I80!3879E`%-A=F4@(B5S(@!3879E("5S`%-A=F4@3W!T
M:6]N<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C
M<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A
M=F5D("5S(&-O;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A9&4@<V-R
M:7!T('1O.B`B)7,B+@!38V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!396%R
M8V@`4V5A<F-H($5N9VEN97,`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A=&4`
M4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE
M8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;`!3
M96QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C=`!3
M96QE8W0@;F]N90!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O
M;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T
M92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E
M;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I
M9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D
M96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@
M;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E
M;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E
M<&]R=`!396YD(%--4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B
M:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397)V97(@9&%T82!W
M<F]N9R!O<B!N;W0@879A:6QA8FQE+@!397-S:6]N($%D;6EN`%-E<W-I;VX@
M240@97AP:7)E9"X`4V5S<VEO;G,`4V5T`%-E="!O<'1I;VYS('1O(&%L;&]W
M('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E
M="!I="X`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@
M86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L
M86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@
M<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E
M<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P
M('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@
M<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3:&]P
M<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I
M;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R96YC97,@8F5T
M=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@
M8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G
M:6YG(&EN/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC
M:V5R`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@
M)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W
M97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6:6-I;FET
M>0!3:')I;FL`4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I
M(&]U="!O9B!T:&4@=V%Y(&9I<G-T`%-I97)R82!,96]N90!3:6=N('5P`%-I
M9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K
M:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=P!3;F]W(%-H
M;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO
M=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T
M97(Z(`!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3;VYG<R`F(%!O96US`%-O
M<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC
M80!3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A
M;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P
M:&5R90!3<&%C97(`4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A8W1E<B!);G!U
M=`!3<&]R=',`4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R="!Y
M96%R`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R86=E(&9O<FUA=`!3
M=')E970@061D<F5S<P!3=')I;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T
M:&4@861D<F5S<P!3=0!3=6)D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%-U
M8FIE8W0`4W5B;6ET`%-U8FUI='1E9"!R97%U97-T('1O(&%D9"`B)7,B('1O
M('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@<F5Q
M=65S="!H87,@8F5E;B!A<'!R;W9E9"X`4W5C8V5S<P!3=6-C97-S9G5L;'D@
M861D960@(B5S(B!T;R!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@8VQE87)E
M9"!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S
M9G5L;'D@9&5L971E9"`B)7,B+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`B)7,B
M(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I
M9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY
M('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@<V%V
M960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E<W-F
M=6QL>2!U<&1A=&5D("(E<R(`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U9&%N
M`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E
M=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<'!O<G0`4W5R:6YA;64`
M4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D
M96X`4W=I='IE<FQA;F0`4WEN8R!L;V<@9&5L971E9`!3>6YC34P`4WEN=&%X
M(&5R<F]R(&EN('-E87)C:"!T97)M<P!3>7)I86X@07)A8B!297!U8FQI8P!4
M+5-T;W)M`%0M4W1O<FT@86YD(%=I;F1Y`%0M4W1O<FUS`%135B!F:6QE`%1A
M8FQE(%-E=`!486EW86X`5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN80!486II
M:VES=&%N`%1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8`5&%S:W,`5&5L
M97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R
M90!496UP97)A='5R93H@`%1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO
M)7,I("9D96<[)7,`5&5M<&QA=&4@(B5S(B!N;W0@9F]U;F0N`%1E;7!L871E
M($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1H`%1H86EL86YD`%1H
M92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(:7-T;W)Y
M('-Y<W1E;2!I<R!D:7-A8FQE9"X`5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T
M:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T("(E<R(`5&AE($E-4U`@;&]G
M(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"X`5&AE($UA:6YT96YA;F-E.CH@
M8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4:&4@3W!T:6]N<R!W
M:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE(&%D;6EN:7-T<F%T;W(@
M;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A
M8VME;F0@:68@>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+@!4:&4@8V]N
M=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@
M;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!C;VYT86-T
M('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN
M`%1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D
M('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N`%1H92!D:7-T<FEB=71I
M;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA
M;FL@;W(@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&1I<W1R:6)U
M=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+@!4:&4@96YC<GEP=&EO;B!F
M96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4:&4@
M9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE
M("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE
M(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E
M;B!D96QE=&5D+@!4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M
M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RX`5&AE(&UE
M<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@(B5S(B!H87,@
M8F5E;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE
M(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+@!4:&4@;F%M
M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4`5&AE
M(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+@!4:&4@;W!E;G-S
M;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM
M93HZ(&-L87-S+@!4:&4@<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B92!S
M879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M(&%L
M;&]W86)L92!S:7IE`%1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A
M=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE
M('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R
M+@!4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N
M`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R
M("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S<&5C:69I960@<F]W("@E9"D@
M9&]E<R!N;W0@97AI<W0N`%1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@
M;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BX`5&AE('5P;&]A9&5D(&1A
M=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N`%1H92!U<&QO
M861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE('=E871H97(N8V]M
M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H96UE<R!D:7)E8W1O<GD@(B5S
M(B!N;W0@9F]U;F0N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`
M5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI
M;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE
M;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@
M96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN
M9R`B)7,B('1O('1H92!S>7-T96TZ("5S`%1H97)E('=A<R!A('!R;V)L96T@
M8VQE87)I;F<@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@
M`%1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@(B5S(B!F<F]M('1H92!S
M>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG("(E<R(Z("5S
M`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO
M("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H
M92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X
M:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A
M<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI
M;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R
M(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@
M;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!P97)F
M;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0
M;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D
M871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L
M871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB
M=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AI<R!)34%0
M('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI
M<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`
M5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`
M5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N
M`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U
M9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T
M97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I
M;G!L8RYC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R
M:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S
M;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN
M9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@
M9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E
M<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@271A;'D@*&AT='`Z
M+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F
M:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA
M>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I96QD
M(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I
M;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H
M:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="
M($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F;W)M
M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES
M(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B
M:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N="!T:&%T('5N9&5R
M<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T
M(&]F('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES:70@)7,`5&AI<R!M
M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T
M:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A
M<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@
M9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A
M=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W
M(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AU;F1E
M<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE
M('-E;&5C=&EO;@!4:71L90!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L
M(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@
M:V5Y('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4;V=O`%1O:V5L874`5&]M;W)R
M;W<`5&]N9V$`5&]O(&UA;GD@:6YV86QI9"!L;V=I;G,@9'5R:6YG('1H92!L
M87-T(&UI;G5T97,N`%1R86YS;&%T:6]N<P!4<FEN:61A9"!A;F0@5&]B86=O
M`%1R=64@;W(@9F%L<V4`5'4`5'5N:7-I80!4=7)K97D`5'5R:VES:"`H25-/
M+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L86YD
M<P!4=79A;'4`5'EP92!Y;W5R(&-H;VEC93H@`%4N5BX@:6YD97@Z(`!54DP`
M55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T`%5G
M86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`
M56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B
M+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S
M+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8VAE8VL@
M9FEL92!S:7IE(&]F("(E<R(N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@
M;V8@(B5S+R5S(BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN`%5N86)L
M92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E
M8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+@!5
M;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&
M4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL
M92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E;&5T
M92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE('1O
M(&1E;&5T92`B)7,B.B`E<RX`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I
M<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E;&5T92!61E,@9&ER
M96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E
M8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N`%5N
M86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&1E;&5T
M92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R("(E<R(N
M`%5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RX`56YA8FQE
M('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X
M=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@
M9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!O<&5N(%9&
M4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`
M56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@
M<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+@!5;F%B;&4@=&\@
M<F5A9"!F:6QE.B``56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T
M;W)Y+@!5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F
M;VQD97(@86QR96%D>2!E>&ES=',`56YA8FQE('1O(')E;F%M92!61E,@9&ER
M96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5
M;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!R96YA
M;64@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4N
M`%5N86)L92!T;R!R=6X@)VUK:7-O9G,G+@!5;F%B;&4@=&\@=')A;G-L871E
M('1H:7,@5V]R9"!D;V-U;65N=`!5;F%B;&4@=&\@=')I9V=E<B!F<F5E+V)U
M<WD@=7!D871E(&9O<B`E<P!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S
M(BX`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2X`
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N`%5N86)L92!T;R!W<FET
M92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"X`56YD;R!#:&%N
M9V5S`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C
M=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5
M;F9I;&5D`%5N:6-O9&4@*%541BTX*0!5;FET960@07)A8B!%;6ER871E<P!5
M;FET960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N:71E9"!3=&%T97,@36EN
M;W(@3W5T;'EI;F<@27-L86YD<P!5;FET<P!5;FMN;W=N`%5N:VYO=VX@87!I
M;7-G:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I9"`H0VQI
M96YT($UE<W-A9V4@240I+@!5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+@!5
M;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FYA;65D`%5N<W5P<&]R
M=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D871E("5S`%5P9&%T92!U<V5R`%5P
M9&%T960@(B5S(BX`57!G<F%D92!S8W)I<'0@9&5L971E9"X`57!L;V%D`%5P
M;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R
M=F5R+@!5<G5G=6%Y`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,`%5S92!I9B!N
M86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N`%5S
M97(`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@061M
M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S
M97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I
M=&4N`%5S97(@86-C;W5N="!N;W0@9F]U;F0`57-E<FYA;64`57-E<FYA;64@
M(B5S(B!A;')E861Y(&5X:7-T<RX`57-E<FYA;64Z`%5S97)N86UE.B``57-E
M<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@9&ER96-T;W)Y(&1O
M97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A=&EO;G,@9F]U;F0@
M:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N
M`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+@!686QU
M97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B;&4`5F5N
M97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y
M(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9E<G-I;VX@0V]N
M=')O;`!697)Y($AI9V@`5FEE="!.86T`5FEE=&YA;65S92`H5DE30TE)*0!6
M:65W("5S`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FER9VEN($ES;&%N
M9',L($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES:6)I;&ET>0!6
M:7-I8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!705).
M24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5TE.('9I
M82!(5%10`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&
M;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC;VT`
M5V5B`%=E8B!3:71E`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L
M8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X
M-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO=6QD
M("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E
M<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAE
M<F5I<R!!=7-T<F%L:6$@;6%P`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS
M('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H(&EN
M($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H
M=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VEK:0!7:6YD`%=I;F0@
M16%R;'D`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES9&]M
M`%=I<VAL:7-T`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`5W)O;F<@
M;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U
M;F0@)60N`%=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F
M;W5N9"`E9"X`5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@
M9FEL92X`6"U2968`6#4P.78S($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%
M>'1E;F1E9"!+97D@57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@
M3F%M90!8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@97AT
M96YS:6]N<P!960!965E9`%EA:&]O(2!M87``665A<FQY`%EE;65N`%EE<P!9
M97,L($D@06=R964`66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R
M92!T:&%N("5D(&)L;V-K<RX`66]U(&%R92!N;W0@875T:&5N=&EC871E9"X`
M66]U(&-A;FYO="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L
M;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E
M<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T
M960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@)7,N`%EO
M=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@96YT97(@82!V
M86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P
M=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F
M:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T
M(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N
M`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D
M97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P
M<F]B;&5M(')E<&]R="X`66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B
M92!D96QE=&5D+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE
M87(@;W5T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E
M+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M
M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@
M<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E
M(&$@;F5W(&-A=&5G;W)Y(&YA;64N`%EO=2!N965D('1O('!R;W9I9&4@86X@
M271A;&EA;B!P:&]N92!N=6UB97(`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I
M<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9
M;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E
M<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@
M;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL
M('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT
M:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S
M+B!)9B!Y;W4@=VES:"!T;R!U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R
M(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@875T:&5N=&EC
M871I;VX@8F%C:V5N9"X`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O
M97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@
M:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R
M(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E
M9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S
M96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D
M;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O
M97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R
M;VPO0V]M;6%N9"`K(%`@=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO
M;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9
M;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&QO
M9VEN(&AA<R!E>'!I<F5D+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z
M("5S`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U
M<F%T:6]N(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E
M;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@
M<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD
M(&QO9R!I;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D
M(&AA<R!E>'!I<F5D+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA
M`%IA:7)E`%IA;6)I80!::6UB86)W90!;2&ED92!1=6]T960@5&5X=%T`6U!R
M;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E
M9"!497AT("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?0TQ)`%]$871A
M5')E90!?1W)O=7!S`%](96QP`%],;V<@:6X`7TQO9R!O=70`7T]P=&EO;G,`
M7U!E<FUI<W-I;VYS`%]3971U<`!?57-E<G,`861D<F5S<R!B;V]K`&%D9')E
M<W-E92!U;FMN;W=N`&-A;&5N9&%R`&-A;&T`8V%N;F]T(&-R96%T92!O=71P
M=70@9FEL90!C86YN;W0@;W!E;B!I;G!U=`!C;&EC:R!H97)E`&-O;6UA;F0@
M;&EN92!U<V%G92!E<G)O<@!C;VYF:6=U<F%T:6]N(&5R<F]R`&-R:71I8V%L
M('-Y<W1E;2!F:6QE(&UI<W-I;F<`9&%T82!F;W)M870@97)R;W(`961I=`!E
M;G1R>2!N;W0@9F]U;F0`9F%L;&EN9P!F:6QE`&9R;VT@=&AE("5S("@E<RD@
M870@)7,@)7,`9W5S=&EN9P!H.@!H:`!H;W-T(&YA;64@=6YK;F]W;@!I;6UE
M9&EA=&4`:6YL:6YE`&EN<'5T+V]U='!U="!E<G)O<@!I;G1E<FYA;"!S;V9T
M=V%R92!E<G)O<@!L:6YE<UT`;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE
M(&UA:VEN9R!)4T\N`&UM`&YA;64`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@
M:6UP;&5M96YT960`;F]T97!A9`!P97)M:7-S:6]N(&1E;FEE9`!R96UO=&4@
M97)R;W(@:6X@<')O=&]C;VP`<FES:6YG`'-E<G9I8V4@=6YA=F%I;&%B;&4`
M<VAO=R!D:69F97)E;F-E<P!S;7,R96UA:6P@=FEA($A45%``<W,`<W1E861Y
M`'-Y<W1E;2!E<G)O<@!T87-K(&QI<W0`=&5M<&]R87)Y(&9A:6QU<F4`='EP
M92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M
M960`=7-E<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE<BYC;VT`4')O:F5C="U)
M9"U697)S:6]N.B`N"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N
M:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`W+3(U(#$Q.C,P
M*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP-"TS,"`Q,#HS,BLP,3`P
M"DQA<W0M5')A;G-L871O<CH@9'5C:T!O8F%L82YN970*3&%N9W5A9V4M5&5A
M;3H@<VQ?4TD@/&1U8VM`;V)A;&$N;F5T/@I-24U%+59E<G-I;VXZ(#$N,`I#
M;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]=71F+3@*0V]N=&5N
M="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`("AP<F5D("5S(&1N979I*0`@
M*$1O<W1O<&YA('1I<&MA("5S*0`@*'8@)7,@9&YE:"D`*&1A;F5S*0!*=71R
M:2``*';$C65R86HI`"!O8B``(B5S(B!N:2!I;65N:6L`(B5S(B!J92!N979E
M;&IA=FYA(&EZ8FER80`B)7,B(&YE('IA>FYA;2!V($AO<F1O=F5M(')E9VES
M=')U(``G)7,G(&YE(&YA:F1E;2!D<F5V97-A('IA(&EZ<FES+@`G)7,G(&IE
M(&)I;"!D;V1A;B!S:W5P:6YS:V5M=2!S:7-T96UU`"<E<R<@:F4@8FEL(&1O
M9&%N(&L@9&]P=7-T;F5M=2!S:7-T96UU+@`G)7,G(&YI('5S='9A<FIE;CH@
M)7,@`%5P;W)A8FQJ96YI:"`E+C)F34(@;V0@)2XR9DU"(&1O=F]L:F5N:6@@
M*"4N,F8E)2D`)60@)7,@:6X@)7,`Q:!E("5D(&1N:2!D;R!P;W1E:V$@9V5S
M;&$`)60M9&YE=FYA(&YA<&]V960`)7,@XH"3($)O9&ET92!P;WIO<FYI`"5S
M($]D=&ES`"5S($M"`"5S(%9Z9'+%OF5V86QN82!D96QA("T@4&]T<F1I=&5V
M`"5S("`@("`@`"5S('!R:6IA=F$`)7,@4&]G;VII`"5S(,6^92!O8G-T86IA
M+@`E<R!O8B`E<R`E<P`E<R!J92!P<FEP<F%V;&IE;B!N82!I>G9A:F%N:F4@
M=GID<L6^979A;&YI:"!O<&5R86-I:BP@<')E=F5R:2!S<&]D86HN4')E=F5R
M:2!N86)I<F%L;FEK('IA('9S92!O<&5R86-I:F4L(&MI(&)I(&II:"!R860@
M;W!R879I;"!S961A:BX`4&]T<F5B=6IE;2`E<R``)7,@;6EN=70`)7,@;F4@
M;F%J9&5M`"5S(&]B("5S(&]D("5S`$EM96YI:R`E<P!+;VQE9&%R("5S`$)E
M;&7%OFMA("5S`"5S($]P<F%V:6QA`"5S.B`E<P`E<SH@=&\@<W!O<F_$C6EL
M;R!M;V=OQ(UE(&YI(&]D('!OQ:%I;&IA=&5L:F$L(&MA=&5R:2!P<F%V:2!D
M82!J92X@4&%Z:71E('-E(&MA=&5R:6AK;VQI('!O=F5Z878@=B!S<&]R;\2-
M:6QU(&%L:2!P;V1A:F%N:G4@:V%T97)I:"!K;VQI(&]S96)N:6@@:6YF;W)M
M86-I:B!N82!T82!N87-L;W8N`"P@9V]S=&EM(``L(&=O<W1I;2`E<R`E<P`L
M('-P<F5M96YL:FEV:V$@;V0@)7,@9&\@)7,`+2T@:7IB97)I("TM`#$R('5R
M(&9O<FUA=``R-"!U<B!F;W)M870`,C0@=7(`4')E:L6A;FIA(&UOQ;YN;W-T
M`%IA('1A(&)L;VL@:F4@<&]T<F5B;F$@<&]V97IA=F$@;F$@<&]D871K;W9N
M:2!S=')EQ;YN:6L`4&]J879I;&$@<V4@:F4@:'5D82!N87!A:V$N`%IA(&MO
M9&ER871I('-P;W)OQ(UI;&\@<&]T<F5B=6IE;2!J879N:2!01U`@:VQJ=<2-
M+@!*879N:2!01U`@:VQJ=<2-(&IE('!O=')E8F5N('IA(&]D:VQE<&%N:F4@
M<W!O<F_$C6EL82X`2F%V;FD@4$=0(&ML:G7$C2P@>F%S96)N:2!01U`@:VQJ
M=<2-(&EN(&=E<VQO('-O('!O=')E8FYI('IA(&]D:VQE<&%N:F4@<W!O<F_$
MC6EL82X`2F%V;FD@4$=0(&ML:G7$C2P@>F%S96)N:2!01U`@:VQJ=<2-(&EN
M(&=E<VQO('-O('!O=')E8FYI('IA('!O9'!I<R!S<&]R;\2-:6QA+@!*879N
M:2!3+TU)344@:VQJ=<2-+"!Z87-E8FYI(%,O34E-12!K;&IUQ(T@:6X@9V5S
M;&\@<V\@<&]T<F5B;FD@>F$@<&]D<&ES('-P;W)OQ(UI;&$N`$IA=FYI(%,O
M34E-12!K;&IUQ(TL('IA<V5B;FD@4R]-24U%(&ML:G7$C2!I;B!G97-L;R!S
M;R!P;W1R96)N:2!Z82!P;V1P:7,@<W!O<F_$C6EL82X`($IA=FYI(%--24U%
M(&ML:G5E(&IE('!O=')E8F5N('IA(&]D:VQE<&%N:F4@<W!O<F_$C6EL82``
M3V)L8<2-;F\`2G5T<F%N:FD@4F%H96P@9&7%O@!*=71R86YJ:2!D9<6^`$IU
M=')A;FII(&YA;&EV`$IU=')A;FII('-N9<6^;FD@;65T9<6^`$%-+U!-`$%0
M22!)1`!/<&ES+BXN`%!R97!O=F5D86X@9&]S=&]P('IA('5S='9A<FIA;FIE
M(&UA<&4@5D93+B``4')E<&]V961A;B!D;W-T;W`@>F$@=7-T=F%R:F%N:F4@
M9&%T;W1E:V4@5D93+@!68<6A:2!P;V1A=&MI`%!O=')D:2!G97-L;P!)>G9A
M:F%M`$EZ=F%J86T`1&]D86H`1&]D86H@<VMU<&EN;R!O=')O:P!$;V1A:B!D
M;W9O;&IE;FIA(&]T<F]K80!$961A:B!S96TZ`$1O9&%J(&YO=F\@<VMU<&EN
M;P!$;V1A:B!N;W9A(&1O=F]L:F5N:F$`1&]D86H@<VMU<&EN;R!O=')O:R`B
M)7,B`$1O9&%J(&1O=F]L:F5N:F4@;W1R;VMA("(E<R(`1&]D86H@;F]V96=A
M('5P;W)A8FYI:V$Z`$1O9&%J('-T;VQP96,`1&]D86H@;F]V92#$C6QA;F4`
M1&]D86H@<&%R`$1O9&%J("5S($UE;G4@=B!-;WII;&QA(%-I9&5B87(`1&]D
M86H@=B!I;65N:6LZ`$1O9&%J('8@;6]J(&EM96YI:SH`1&]D86H@=7!O<F%B
M;FEK80`@1&]D86P@)R5S)R!S:7-T96UU+"!V96YD87(@8F\@;F5M;V=OQ(UE
M(&1O9&%J86YJ92!D;V1A=&YI:"!V<&ES;FEH(&EN9F]R;6%C:6HZ("5S+@!$
M;V1A;B`G)7,G('-I<W1E;74N(%-E9&%J('-E(&QA:&MO('!R:6IA=FET92X`
M1&]D86IA;FIE('5P;W)A8FYI:V]V(&IE(&]N96UO9V_$C65N;RX`3F%S;&]V
M`$EM96YI:P!5<F5D:2!D;W9O;&IE;FIA('IA(&]S=&%L92!U<&]R86)N:6ME
M`%5P<F%V;&IA;FIE`%)E:VQA;64`069H86YI<W1A;@!!;&)A;FEJ80!!;,6^
M:7)I:F$`3WII<F]M80!6<V4`5G-I(&]V97)J96YI('5P;W)A8FYI:VD`5G-E
M('-K=7!I;F4`5G-A($1O=F]L:F5N:F$`1&]V;VQI(&UN;V=O:W)A=&YE(&YA
M<VQO=F4`1&]V;VQI(&YA<W1A=FET=F4@(`##@L6]92!O8G-T86IA`$YA9&]M
M97-T;F\@24U34"!U<&]R86)N:<6A:V\@:6UE`$YA9&]M97-T;F\@24U34"!G
M97-L;P!.861O;65S=&YO($E-4U`@=7!O<F%B;FG%H6MO(&EM90!.861O;65S
M=&YI(&5L96MT<F]N<VMI(&YA<VQO=@!.861O;65S=&YI('9Z;W)C:0`@06UE
M<FG%H6MA(%-A;6]A(`!.879E9&5N82!J92!B:6QA(&YE>F%K;VYI=&$@=G)E
M9&YO<W0N`'!O:F%V:6QA('-E(&IE(&YA<&%K80!!;F1O<F$`06YG;VQA`$%N
M9W5I;&QA`$%N;VYI;65N(%!R;WAY`$]D9V]V;W(`06YT87)K=&EC80!!;G1I
M9W5A(&EN($)A<F)U9&$`07!L:6MA8VEJ80!397IN86T@87!L:6MA8VEJ`$%P
M;&EK86-I:F$@:F4@<')I<')A=FQJ96YA`%!R:6IA=FD@;W1R;VMO=F4@9&5L
M;FEC92``4&]T<F1I`$%P<FEL`$%R86)S:VD@*%=I;F1O=W,M,3(U-BD`5F5L
M:6MO<W0@9&%T;W1E:V4@07)H:78@`$EM92!!<FAI=F$`4W1E('!R97!R:<2-
M86YI+"!D82#%OF5L:71E('!R96ML:6-A=&D@>F%H=&5V;R!Z82!P<FEJ879O
M('IA("5S(#\@`%-T92!P<F5P<FG$C6%N:2P@9&$@Q;YE;&ET92!I>F)R:7-A
M=&D@)R5S)R!I;B!O<W1A;&4@<&]D<VMU<&EN93\`07)G96YT:6YA`$%R;65N
M:6IA`$%R;65N<VMI("A!4DU30TE)+3@I`%5M971N;W-T`$%R=6)A`%5M971N
M;W-T:2#$C7)K`$%Z:6$O4&%C:69IQ:%K92!R96=I:F4`5G!R8<6A86H@>F$@
M<&]T<F1I=&5V('!R960@:7IV86IA;FIE;2!V>F1RQ;YE=F%N:F$`1&]D96QJ
M96YE(&MO;&]N90!0;W-K=7,@:7IB<FES82!N96]B<W1O:F7$C64@<VMU<&EN
M92X`4&]S:W5S(&EZ8G)I<V$@;F5O8G-T;VIEQ(UE9V$@9&]V;VQJ96YJ82X`
M4&]S:W5S('5R961I='9E(&YE;V)S=&]J9<2-96=A(&1O=F]L:F5N:F$N`%!O
M<VMU<R!U<F5D:71V92!N96]B<W1O:F7$C64@9&5L;FEC92X`3&%S=&YO<W1I
M`$%V9W5S=`!!=G-T<F%L:6IA`$%V<W1R:6IA`"!!=71H7V-Y<G5S.B!:86AT
M979A;F\@:6UA<"#%H6ER:71E=B!N:7-E;2!N8<6A96PN`$%U=&A?8WER=7,Z
M($)A8VME;F0@;FEM82!Z86AT979A;FEH('IM;\6^;F]S=&DN`$%U=&A?8WER
M=7,Z(%IA:'1E=F%N;R!I;6%P(,6A:7)I=&5V(&YI<V5M(&YAQ:%E;"X`075T
M:%]F='`Z(%IA:'1E=F%N;R!&5%`@Q:%I<FET978@;FES96T@;F'%H65L+B!)
M>G!O;&YI(%!(4"!Z("UO;F5M;V=OQ(UE;F\M(&9T<"!Z86UE;FIA=F\N(`!!
M=71H7VEM87!H=&5V86YO($E-05!I=&5V(&YI<V5M(&YAQ:%E;"X`075T:%]K
M<F(U.B!:86AT979A;F\@:W)B-2#%H6ER:71E=B!N:7-E;2!N8<6A96PN`$%U
M=&A?;&1A<#H@3FD@;6_%OFYO(&1O9&%J86YJ92!U<&]R86)N:6MO=B!V($%C
M=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!.:2!M;\6^;F\@;V1S=')A;FIE
M=F%N:F4@=7!O<F%B;FEK;W8@=B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A
M<#H@6F%H=&5V86YO($Q$05`@Q:%I<FET978@;FES96T@;F'%H65L+@!!=71H
M7VQD87`Z($YE(&UO<F5M(&1O9&%T:2!U<&]R86)N:6MA("5S+B!3<&]R;\2-
M:6QO('-T<F7%OFYI:V$Z(`!!=71H7VQD87`Z($YE(&UO<F5M(&]D<W1R86YI
M=&D@=7!O<F%B;FEK82`E<P!!=71H7VQD87`Z($YE(&UO<F5M(&YA9&=R861I
M=&D@=7!O<F%B;FEK82`E<R``075T:%]L9&%P.B!N92!M;W)E;2!N861G<F%J
M979A=&D@=7!O<F%B;FEK;W8@=B!!8W1I=F4@1&ER97-T;W)Y+@!!=71H7VUC
M86PZ(%IA:'1E=F%N;R!-0T%,(,6A:7)I=&5V(&YI<V5M(&YAQ:%E;"X`075T
M:%]S;6)A=71H.B!:86AT979A;F5G82!S;6)A=71H('IA(,6A:7)I=&5V(&YI
M<V5M(&YAQ:%E;"X`3W9E<FIA;FIE('IA($944"!S=')EQ;YN:6L@;FD@=7-P
M96QO+@!/=F5R:F%N:F4@;FD@=7-P96QO+@!/=F5R:F%N:F4@;FD@=7-P96QO
M+B`E<P!/=F5R:F%N:F4@:F4@>F%V<FYI;"!2041)55,@<W1R9<6^;FEK+@!/
M=F5R:F%N:F4@>F$@1E10('-T<F7%OFYI:R!N:2!U<W!E;&\N`$]V97)J86YJ
M92!Z82!334(@<W1R9<6^;FEK(&YI('5S<&5L;RX`4&]L:F$@;F$@<F%Z<&]L
M86=O.@!!>F5R8F%J9,6^86X@`$YE=6UN:2!I>F=O=F]R:0!.87!AQ(UN;R!K
M97)B97)O<R!G97-L;RX`3F%P8<2-;F\@:V5R8F5R;W,@=7!O<F%B;FG%H6MO
M(&EM92X`0F%H86UI`$)A:')A:6X`0F%L=&EK("A)4T\M.#@U.2TQ,RD`0F%N
M9VQA9&7%H0!"87)B861O<P!.:7-E;2!N8<6A96P@;W-N;W9N96=A(&=R869I
MQ(UN96=A(&EM96YI:V$@(B5S(BX`0F5L;W)U<VEJ80!"96QG:6IA`$)E;&EZ
M90!"96YI;@!"97)M=61S:VD@;W1O:VD`0G5T86X`4F]J<W1N:2!D86X`3FES
M96T@;F'%H65L(&)L;VMA("(E<R(L(&%P;&EK86-I:F4@(B5S(B`N`%IA=7-T
M879I($YA<W1A=FET=F4`6F%U<W1A=FD@5&EP`$)O;&EV:6IA`%!R:6QJ=6)L
M:F5N90!";W-N82!I;B!(97)C96=O=FEN80!/8F]J:0!";V-V86YA`$)O=79E
M=&]V;R!O=&_$C6IE`$)R87II;&EJ80`@0G)I=&%N<VMO(&]Z96UL:F4@26YD
M:6IS:V5G82!O8V5A;F$@`$)R=6YE:0!";VQG87)I:F$`0G5R:VEN82!&87-O
M`$)U<G5N9&D`35-'`$-20P`@0U),(')A>F1E;&ET=F5N92!T;\2-:V4@`$YA
M<W1A=FQJ86YJ92!P<F5D<&]M;FEL;FEK82!N:2!D;VMO;L2-86YO+@!+;VQE
M9&%R`%IB<FG%H6D`2V%M8F]DQ;YA`$MA;65R=6X`3F4@;6]R96IO('5P<F%V
M;&IA=&D@>G5N86YJ:2!U<')A=FQJ86QC:0!.92!M;W)E;2!V>G!O<W1A=FET
M:2!P;W9E>F%V92!Z($E-05`@<W1R9<6^;FEK;VTZ("5S(`!.:2!M;V=OQ(UE
M(&]D<')E=&D@(B5S(B!D871O=&5K92X`2V%N861A`%IB<FG%H6D`<&]R;\2-
M:6QO(&\@=&7%OF%V86@@>B!B<FES86YJ96T`3F4@;6]R96T@:V]P:7)A=&D@
M9&%T;W1E:R`H92D@+2!V:7(@:6X@8VEL:F$@<W1A(&ES=&$N`$YE(&UO<F5M
M(&EZ8G)I<V%T:2!D871O=&5K92`B)7,B+@!.92!N86ID96T@>F'$C6%S;F4@
M9&%T;W1E:RX`3F4@;6]R96T@<')E;6%K;FET:2!D871O=&5K("AE*2`M(&-I
M;&H@:F4@>FYO=')A:B!V:7)A+@!.92!M;W)E;2!N861A;&IE=F%T:2!B<F5Z
M('!A<F%M971R;W8@)V-I;&IN92!D871O=&5K92<N`"(E<R(@26UE;FEK82!N
M92!M;W)E;2!Z8G)I<V%T:2X`3F4@;6]R96T@;V1S=')A;FET:3L@;V)S=&%J
M82`E9"!P;V1V96QJ`$YE(&UO<F5M('!O;F]V;F\@=7)E9&ET:2P@Q:%T979I
M;&\@9&%N:6@@=FYO<V]V('-E(&YE('-K;&%D82!S(,6A=&5V:6QO;2`@<VAR
M86YJ96YI:"X`3F4@;6]R96T@879T;VUA='-K;R!P;VYA<W1A=FET:2!G97-L
M82P@;V)R;FET92!S92!N82!S:W)B;FEK80!.92!M;W)E;2!P<F5U<VUE<FET
M:2!S<&]R;\2-:6QA(&YA=F5D96YE;74@Q:%T979I;'4N`$-A;FYO="!W<FET
M92!T;R!F:6QE("(E<R(`2V%P=F5R9'-K:2!O=&]K:0!0<FEN8<6A86QE8P!+
M871E9V]R:6IE(&EN('IN86UK90!+87EM86YS:VD@;W1O:VD`36]B:6QN:2!T
M96QE9F]N`$UO8FEL;FD@=&5L969O;@!+96QT<VMI("A)4T\M.#@U.2TQ-"D`
M0V5N=')A;&YO($%F<FG%H6MA(%)E<'5B;&EK80!3<F5D;FIE979R;W!S:VD@
M*$E33RTX.#4Y+3(I`%!O9')O8FYO<W1I('!O=')D:6QA`$QA<W1N:6L@<&]T
M<F1I;&$`4')A=FEL82!P;W1R9&EL80!%860`4W!R96UE;FD`<W!R96UE;FET
M92!V8<6A92!G97-L;P!3<')E;65N:71E(&EM92!I;B!N87-L;W8@=F'%H65G
M82!E;&5K=')O;G-K96=A(&YA<VQO=F$L(&MI(&=A('9I9&EJ;W!R96IE;6YI
M:VD@;V(@8G)A;FIU(&EN(&]D9V]V87)J86YJ=2!N82!V8<6A;R!P;\6A=&\N
M`%8@=')E;G5T;FD@:V]N9FEG=7)A8VEJ92!N92!M;W)E=&4@<W!R96UE;FET
M:2!G97-L82X@2V]N=&%K=&ER86IT92!V8<6A96=A('-K<F)N:6MA+@#$C6EL
M90!+:71A:G-K80!0;V5N;W-T879L:F5N82!K:71A:L6AQ(UI;F$H1T(R,S$R
M*0!4<F%D:6-I;VYA;&YA(&MI=&%JQ:'$C6EN82`H0FEG-2D`27IB97)I(&%P
M;&EK86-I:F\Z`$EZ8F5R:2!G97-L;P!)>F)E<FD@=7!O<F%B;FG%H6MO(&EM
M90!+86MO('!R:6MA>F%T:2!D871U;64Z`$)OQ;YIQ(UN:2!O=&]K:0!.:7-E
M;2!N8<6A96P@9&5F:6YI8VEJ92!V<G-T92!Z82`E<RX`2F%S;F\`4')EQ(UI
M<W1I('!O:7IV961B90!/9'-T<F%N:2!Z=6YA;FIE9V$@=7!O<F%B;FEK83H@
M)7,@`$]D<W1R86YI('5P;W)A8FYI:V$`27IB<FG%H6D@<&]D871E:R!U<&]R
M86)N:6MA`&EZ8G)IQ:%I('!O=&5M`$ML:6MN:2!Z82!N861A;&IE=F%N:F4@
M`$-L:6-K871E;&P@<')O=&]M($A45%``6F%P<FD@;VMN;P!/8FQA:VD`6FIU
M=')A:B!/8FQAQ(UN;P!/8FQAQ(UN;P!+;VMO<V]V:2!O=&]K:0!:9')UQ;YI
M('-T<F%N<VMO(&]K;F\`2V]L=6UB:6IA`$)A<G9A`$EZ8FER86QE8R!B87)V
M`"!)>F)I<F$@0F%R=F4@`$YA<VQO=B!S=&]L<&EC80!3=')I<&D`56MA>@!5
M:V%Z;F$@;'5P:6YA`$MO;65N=&%R`%-K=7!N;R!I;64`2V]M;W)I(`!$<G7%
MOF)A`%)AQ(UU;F%L;FEK:0!.87-T879I=&5V`$YA<W1A=FET=F4`4F%Z;&EK
M92!N87-T879I='9E`$YA<W1A=FET=F4@>F$@<VEN:W)O;FEZ86-I:F%O(&1L
M86[$C6YI:V]V`$YA<W1A=FET=F4@<&]T<F5B=6IE:F\@8<6^=7)I<F%N:F4`
M3F%S=&%V:2`E<P!0;W1R9&D@9V5S;&\`2V]N9V\`2V]N9V\L($1E;6]K<F%T
M:<2-;F$@<F5P=6)L:6MA`%!O=F5Z879A(&YI('5S<&5L82X`4&]V97IA=F$@
M;FD@=7-P96QA.@!:879R;FIE;F$@<&]V97IA=F$@>B!J879N:6T@:VQJ=<2-
M;FEM('-T<F7%OFYI:V]M+@!:879R;FIE;F$@<&]V97IA=F$@>B!J879N:6T@
M:VQJ=<2-;FEM('-T<F7%OFYI:V]M+B!287IL;V<Z("5S("@E<RD`4&]V97IA
M=F$@<R!&5%`@<W1R9<6^;FEK;VT@;FD@=7-P96QA+@!3=&EK:0!3=&EK(&IE
M(&)I;"!U<W!EQ:%N;R!D;V1A;B!K('9AQ:%I;2!N87-L;W9O;2X`5&EP('-T
M:6MA('-T:7-N:F5N92!D871O=&5K93H`5G-E8FEN92!O9"(E<R(`3F%D86QJ
M=6H`0V]O:V]V:2!O=&]K:0!0:<6A:V]T96L`2V]P:7)A;FIE(&YI('5S<&5L
M;SH@)7,`240@<W1R;\6A96L`2V]S=&%R:6MA`"!3;&]N;VMOQ:'$C65N82!O
M8F%L82``4$=0(&YE(&UO<F4@Q:%I9G)I<F%T:2!S<&]R;\2-:6QA.@!.:2!M
M;V=O92!01U`@<&]D<&ES('-P;W)O96EL82X`3FD@;6]G;\2-92!3+TU)344@
MQ:%I9G)I<F%T:2!S<&]R;\2-:6QA+@!.:2!M;V=OQ(UE(%,O34E-12!P;V1P
M:7,@<W!O<F_$C6EL82X`3FD@;6]G;\2-92!D;V1A=&D@<W1I:V]V+B`E<RX`
M4&]V97IA=F$@>B!,1$%0('-T<F7%OFYI:V]M(&YI(&UO9V_$C6$N`$YI(&UO
M9V_$C64@:V]N=')O;&ER871I(#\_/S\_/R`E<RX`4&]V97IA=F$@>B!,1$%0
M('-T<F7%OFYI:V]M(&YI(&UO9V_$C6$N`$YE(&UO<F5M('9Z<&]S=&%V:71I
M('!O=F5Z879E(',@<W1R9<6^;FEK;VT@(B5S(B!Z('5P;W)A8F\@1E10.B`E
M<P!.92!M;W)E;2!U<W1V87)I=&D@<V5Z;F%M82!Z82!D:7-T<FEB=6-I:F\N
M("5S`$YI(&UO9V_$C64@9&7%H6EF<FER871I(%!'4"!P;V1A=&MO=CH`3FD@
M;6]G;\2-92!D9<6A:69R:7)A=&D@4R]-24U%('!O9&%T:V4N`$YE(&UO<F5M
M(&EZ8G)I<V%T:2!S=&EK;W8N("5S`$YE(&UO<F5M(&EZ8G)I<V%T:2!D:7-T
M<FEB=6-I:G-K96=A('-E>FYA;6$N("5S`$YE(&UO<F5M(&EZ8G)I<V%T:2!N
M87-T879I='9E;F4@8<6^=7)A8VEJ<VME('-K<FEP=&4@(B5S(@!.:2!M;V=O
MQ(UE(&1O;&_$C6ET:2!E;&5K=')O;G-K96=A(&YA<VQO=F$@<')E:F5M;FEK
M82X`3FD@;6]G;\2-92!D;VQOQ(UI=&D@8V5L;W1N96=A(&EM96YI:V$N`$YI
M(&UO9V_$C64@9&]L;\2-:71I(&-E;&]T;F5G82!D:7-T<FEB=6-I:G-K96=A
M('-E>FYA;6$N`$YI(&UO9V_$C64@9&]L;\2-:71I(&-E;&]T;F5G82!S97IN
M86UA(&1I<W1R:6)U8VEJ<VMI:"!S97IN86UO=@!.:2!M;V=OQ(UE(&YA;&_%
MOFET:2!S=')A=&5G:6IE("(E<R(N`$YE(&UO<F5M('1V;W)I=&D@;6%P92`B
M)7,B+@!.:2!M;V=OQ(UE(&1O8FET:2!J879N96=A(&ML:G7$C6$@;V0@:VQJ
M=<2-;F5G82!S=')EQ;YN:6MA+@!.:2!M;V=OQ(UE(&]D<')E=&D@(B5S(B!Z
M82!P:7-A;FIE+@!.:2!M;V=OQ(UE(&]D<')E=&D@)7,N`$YI(&UO9V_$C64@
M;V1P<F5T:2!M;V1U;&$@;R!O<')A=FEL=5]V>F1RQ;YE=F%N:F$@)7,@`$YI
M(&UO9V_$C64@<')E8G)A=&D@:6UE;FEK("(E<R(N`$YI(&UO9V_$C64@9&]S
M9<2-:2!,1$%0('-T<F7%OFYI:V$N`$YI(&UO9V_$C64@<')E8G)A=&D@)7,N
M`$YI(&UOQ;YN;R!P;VYA<W1A=FET:2!G97-L82!Z82!Z86AT979A;F5G82!U
M<&]R86)N:6MA+B!.96MA=&5R92!A;&D@=G-E<&]D<F]B;F]S=&D@;FES;R!P
M<F%V:6QN92X@4&]S:W5S:71E('IN;W9A(&%L:2!K;VYT86MT:7)A:G1E('9A
MQ:%E9V%U<')A=FET96QJ82P@Q(UE('!O=')E8G5J971E(&YA9&%L:FYJ;R!P
M;VUOQ(TN`$YI('5S<&5L;R!V>G!O<W1A=FET:3H@)7,@`$YI('5S<&5L;R!V
M>G!O<W1A=FET:2!I;65N:6MA.B`E<R``3FD@=7-P96QO('9Z<&]S=&%V:71I
M(&1I<W1R:6)U8VEJ<VME9V$@<V5Z;F%M83H@)7,@`$YI('5S<&5L;R!V>G!O
M<W1A=FET:2!D:7-T<FEB=6-I:G-K96=A('-E>FYA;6$Z("5S(`!.:2!U<W!E
M;&\@=GIP;W-T879I=&DZ("5S(`!:86AT979A;FD@)R5S)R!N:2!P;V1R;V)N
M;R!O8FQI:V]V86X@=B`E<R!P;V1O8FDN`$YE(&UO<F5M(&EZ8G)I<V%T:2!M
M87!E("(E<R(N`"5S(&MO;F9I9W5R86-I:F4@;FD@;6]G;\2-92!S:')A;FET
M:2X`2V]N9FEG=7)A8VEJ92!V87)N;W-T;F4@:V]P:6IE(&YI(&UO9V_$C64@
M<VAR86YI=&DN`$MO;F9I9W5R86-I:F4@=F%R;F]S=&YE(&MO<&EJ92!N:2!M
M;V=OQ(UE('-H<F%N:71I.B`E<P!.92!M;W)E;2!S:')A;FET:2!N87-T879I
M='9E;F4@8<6^=7)A8VEJ<VME('-K<FEP=&4@;F$Z("(E<R(N`$YE(&UO<F5M
M('-H<F%N:71I(&MO;F9I9W5R86-I:G-K;R!D871O=&5K;R`E<RP@=F%R;F]S
M=&YE(&MO<&EJ92X`3F4@;6]R96T@<VAR86YI=&D@(&MO;F9I9W5R86-I:G-K
M92!D871O=&5K92`E<RX@3&%H:V\@=7!O<F%B:71E(&%L:2!E;F\@;V0@;W!C
M:6H@>F$@<VAR86YI=&D@:V]D;R!Z861A:B!N82`E<R!A;&D@<F_$C6YO(&MO
M<&ER871E('-P;V1N:F\@:V]D;R!N82`E<RX`3FD@;6]G;\2-92!I<VMA;FIE
M($Q$05`@<W1R9<6^;FEK82X`3FD@;6]G;\2-92!O9'-T<F%N:71I('!O=F5Z
M879E('H@(B5S(BX`3FD@;6]G;\2-92!AQ;YU<FER871I('-T:6LN("5S+@!.
M:2!M;V=OQ(UE(&'%OG5R:7)A=&D@9&ES=')I8G5C:6IS:VD@<V5Z;F%M+B`E
M<P!.:2!M;V=OQ(UE(&YA<&ES871I(&MO;F9I9W5R86-I:F4@>F$@(B5S(CH@
M)7,`3F4@;F%J9&5M($UO>FEL;&$@4VED96)A<BX@4')E=F5R:2!A;&D@:F4@
M;V1P<G0N`"(E<R(@=7!O<F%B;FEK=2!N92!M;W)E;2!D;V1E;&ET:2!S;&5D
M9<2-:6@@<')A=FEC('IA(&UA<&\@(B5S(CH@)7,`4')EQ:%T971O(&)E<V5D
M:6QO(`!$<L6^879A`%1EQ(UA:FD`57-T=F%R:0!5<W1V87)I(&YO=F\`57-T
M=F%R:2!P;V1M87!E`$%V=&]R(&1O=F]L:F5N:@#%H'1E=FEL:V$@:W)E9&ET
M;F4@:V%R=&EC92``2')V8<6A:V$`2W5B80!3961A;FIE(#0@<F%Z=F]J;F4@
M<W1O<&YJ90!3961A;FIE('-E:F4`4V5D86YJ:2#$C6%S`%-E9&%N:FD@=7!O
M<F%B;FEK:0!3961A;FIE('9R96UE`%-E9&%N:F4@<W1A;FIE.@!.87-T879I
M=&4@86MT:79N;W-T:2P@:VD@<V4@8F]D;R!I>G9RQ:%I;&4@;V(@<')I:F%V
M:2!N82`E<RX`0VEP97(`0VER:6QI8V$H2T])."U2*0!#:7)I;&EC82`H5VEN
M9&]W<RTQ,C4Q*0!#:7)I;&EC82]5:W)A:FEN<VMI("A+3TDX+54I`,2-9<6A
M:V$@<F5P=6)L:6MA`$1$`$1.4R`H<&]G;&5J(&AT='`Z+R]P96%R+G!H<"YN
M970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H
M<"D`1&YE=FYO`%!R96=L961O=F%L;FEK(&1R979E<VYE('-T<G5K='5R90!0
M;VEZ=F5D8F$@8F%Z92!P;V1A=&MO=@!$871U;0!$871U;2!P<F5J96UA`$EZ
M8FER82!D871U;6$`1&%N`$1E8V5M8F5R`%!R:79Z971O`%!R:79Z971A($)A
M<G9A`%!R:79Z971A(&ED96YT:71E=&$`4')I=GIE=&$@;'5P:6YA`$]P<F5D
M96QI='9E`%IB<FG%H6D`6F)R:<6A:2!S:W5P:6YO`%IB<FG%H6D@9&YE=FYI
M:P!:8G)IQ:%I(&1O=F]L:F5N:F4`27IB<FG%H6D@:6X@<')EQ(UI<W1I('-P
M;W)OQ(UI;&$`27IB<FG%H6D@;V)S=&]J9<2-:2!A;'1E<FYA=&EV;FD@=GIO
M<F5C`$EZ8G)IQ:%I('-P;W)OQ(UI;&$`27IB<FG%H6D@9&]V;VQJ96YJ82!Z
M82`B)7,B`$EZ8G)IQ:%E;2!D;W9O;&IE;FIE('IA("(E<R(@:6X@=G-A('!O
M9&1O=F]L:F5N:F$_`$EZ8G)IQ:%I(&EZ8G)A;F\@:61E;G1I=&5T;P!)>F)R
M:<6A:2!P;V0@;6%P90!.92!M;W)E;2!I>F)R:7-A=&D@;F%S=&%V:71V96YE
M(&'%OG5R86-I:G-K92!S:W)I<'1E("(E<R(N`,2,87,@9&]S=&%V90!$86YS
M:V$`3W!IQ:%I=&4@=&7%OF%V;P!/<&ES`%!O9')O8FYO<W1I("AT=61I('8@
M2&]R9&]V:2!L;V<@9&%T;W1E:VDI.@!0;V1R;V)N;W-T:2!S;R!B:6QE('!R
M:6IA=FQJ96YE('IA('5P<F%V;&IA;&-A+@!287IV;VH`4F]S:<6AQ(UE`%)O
M<VG%H<2-92!Z82!P<F5JQ:%N:F\@=7)O.@!2;W-IQ:'$C64Z`$EM96YI:P!0
M<FEK8<6^96T@Q(UA<R!P;R`R-"!U<FYE;2!S:7-T96UU/P!.87-T879I='9E
M('!R:6MA>F]V86YJ80!0<FEK8<6^:2!P;V1R;V)N;R!N87!O=F5D`%!R:6MA
MQ;YI(&YA<&]V960@*%1!1BD`4')I:V'%OFD@=F5L:6MO<W0`3V)V97-T:6QO
M(&\@9&]S=&%V;&IE;FD@<&_%H71I`$3%OFEB=71I`$YE('IB<FG%H6D`3F4@
M9&]S=&]P86H@;F5P;W-R961N;R!D;R!O:')A;FIA;FIA+G!H<"``06QI('!R
M=F$@=G)S=&$@=G-E8G5J92!I;65N82!P;VQJ/R#$C64@:FEH+"!P<F5V97)I
M(&YA8FER86QN:6LZ`$1O;6EN:6-A`$1O;6EN:6MA;G-K82!297!U8FQI:V$`
M3FES=&4@<F5G:7-T<FER86YI/R!296=I<W1R:7)A:G1E('-E+B``4')E;F5S
M:2`E<P!0<F5N97-I=&4@9V5N97)I<F%N;R!K;VYF:6=U<F%C:6IO(&MO="!0
M2%`@<VMR:7!T;RX`4&%D86IOQ(UI(&UE;FD`6F1R879I;&$`16QE:W1R;VYS
M:VD@;F%S;&]V`%!R96YO<R!E;&5K=')O;G-K:6@@<W!O<F_$C6EL('8@4TU3
M+6IE('IA(&]P97)A=&5R:F4L(&MI('1O(&]M;V=OQ(UA:F\N`$524@!%:W9A
M9&]R`%5R961I`%5R961I('-T;VQP96,`57)E9&D@<VMU<&EN;P!5<F5D:2!D
M;W9O;&IE;FIE`%5R961I(&1O=F]L:F5N:F$`57)E9&D@9&]V;VQJ96YJ82!Z
M82`E<R``57)E9&D@;6_%OFYO<W1I('IA.@!5<F5D:2!D;W9O;&IE;FIA('IA
M("(E<R(`57)E9&D@9&]V;VQJ96YJ82!Z82`E<P!)>F]B<F'%OF5V86YJ90!%
M9VEP=`!386QV861O<@!%;&5K=')O;G-K82!P;\6A=&$`16QE:W1R;VYS:VD@
M;F%S;&]V`$5L96MT<F]N<VMI(&YA<VQO=B!S92!M;W)A('5J96UA=&DN`$5L
M96MT<F]N<VMA('!OQ:%T82!S('!O=')D:71V:6IO`$5M86EL+5--4R!0<F5H
M;V0`4VUEQ:%K:0!0<F%Z96YO('-P;W)OQ(UI;&\N`%!R87IE;B!R97IU;'1A
M="X`4')A>F5N(&ES:V%L;FEK`$EZ:VQO<&EM('9S=&%V;&IA;FIE('-L:6L@
M:7H@1F]T;R!'86QE<FEJ92!V('1E:W-T/P!)>FML;W!I;2!M96YI('H@9&5S
M;FEM(&ML:6MO;3\`2V]N96,@;&5T80!6;F5S:71E('9A<FYO<W1N;R!V<')A
MQ:%A;FIE+"!K:2!B;R!P;W-T879L:F5N;RP@Q(UE(&)O<W1E('!O=')E8F]V
M86QI<&]N87-T879I=&D@=F'%H64@9V5S;&\L(&YP<BX@PX+B@)YI;64@=F'%
MH65G82!L:G5B;&IE;L2-:V$@:F4_.@!6;F5S:71E('-P;V1N:F4@Q(UR:V4Z
M`$5K=F%T;W)I86QN82!'=FEN96IA`$5R:71R96IA`$YA<&%K80!.87!A:V$@
M<')I('5S='9A<FIA;FIU('-T;VQP83H@)7,N`$YA<&%K82!P<FD@8G)I<V%N
M:G4@<&]V97IA=F4@<VEN:')O;B!I>F%C:6IE.B`E<P!.87!A:V$@<')I(&)R
M:7-A;FIU(&1N979N:6MA('-I;FAR;VYI>F%C:6IE.B`E<RX`3F%P86MA('!R
M:2!P;W9E>F]V86YJ=3H@)7,N`$YA<&%K82!P<FD@8<6^=7)I<F%N:G4@9V5S
M;&$Z("5S+@!.87!A:V$@>B!E;&5K=')O;G-K:6T@<W!O<F_$C6EL;VTN`$YA
M<&%K82!P<FD@<&ES86YJ=2`B)7,B+@!%<W1O;FEJ80!%=&EO<&EJ80!%<W1O
M;FEJ80!%=G)O<&$`5G-A:VEH(#$U(&UI;G5T`%9S86MI(#(@;6EN=71I`%9S
M86MI:"`S,"!S96MU;F0`5G-A:VEH(#4@;6EN=70`5G-A:V$@<')I:F%V80!6
M<V%K92!P;VP@=7)E`%9S86MO(&UI;G5T;P!0<FEM97(@=G)E9&YO<W1I.@!)
M>G9E9&D`4&]V9<2-86H`4')IQ(UA:V]V86X@)RDG`%!R:<2-86MO=F%N82!J
M92!B:6QA(&)E<V5D82!A;&D@8F5S961N82!Z=F5Z82!V(&YA=F5D;FEC86@`
M1&%T=6T@>F%P861L;W-T:0!:87-T;W!N:6L`1E10(&YA;&_%OFET978@;F%M
M97-T:71V92X`3FD@=7-P96QO('9Z<&]S=&%V:71I('!R969E<F5N8V4N`%!O
M=F5Z879A('H@3$1!4"!S=')EQ;YN:6MO;2!N:2!U<W!E;&$N`%!O=F5Z879A
M(',@4TU"('-T<F7%OFYI:V]M(&YI('5S<&5L82``2V]P:7)A;FIE(&EZ("(E
M<R(L(&YI('5S<&5L;RX`2V]P:7)A;FIE(&YA("(E<R(L(&YI('5S<&5L;RX`
M3FD@=7-P96QO('9Z<&]S=&%V:71I(&YO=F\@4T%33"!P;W9E>F%V;RX`3FD@
M=7-P96QO('!R96UA:VYI=&D@:SH@)7,@`$YE;6]G;\2-92!P<F5B<F%T:3H@
M)7,@`$]D9&%L:FYO`$9A;&ML86YD<VMI(&]T;VMI`$9E<G-K:2!O=&]K:2``
M2'5D82!N87!A:V$A`$9A>`!&87AI`$9E8G)U87(`4&_$C75T:71I('-E(&MO
M=`!0;\2-=71I=&D@<V4@:V]T.@!.96MA:B!N86QI=F]V`$YE:V%J('-N9<6^
M;FEH(&UE=&7%OF5V`$UA=')I8V$@<&]L:F$`1FEG;&5T($-!4%1#2$$`1FEG
M;&5T('!I<V%V80!&:63%OFD`1&%T;W1E:V$`Q:!T971J92!$871O=&5K.B`E
M<R!D871O=&5K`,6@=&5T:F4@1&%T;W1E:SH@)7,@9&%T;W1E:P!5<')A=FET
M96QJ(&1A=&]T96L`26UE(&1A=&]T96ME`$EZ8FER82!D871O=&5K92X`3F%L
M;\6^:2!D871O=&5K;P!$;V1A;F$@9&%T;W1E:V$@;FD@<&]D<')T82X`1FEL
M=')I`$9I;G-K80!0<G9A('!O;&]V:6-A`%!R=F$@Q(UE=')T:6YA`%-T86QN
M92!V96QI:V]S=&D`3V)R;FD`365G;&$`)7,@;6%P82!N92!O8G-T86IA(`!(
M<F%N80!.87!O=F5D("A4048I`$1N979I(&YA<&]V961I+B`H3F%P;W9E9&$@
M;&4@;&%H:V\@>F5L;R!D;VQG82D`4W1E('!O>F%B:6QI('9AQ:%E(&=E<VQO
M/P!O8FQI:V4`4W)EQ(UA`%-R9<2-90!3<F7$C64`4W)EQ(UE(#(`5&%B;&$@
M<&]G;W9O<F]V`%!R975S;65R:71E=F4`1G(`1G)A;F-I:F$`1G)A;F-I:F$L
M($MO;&]N:6%L;F$@;65T<F]P;VQA`$9R86YC;W-K82!'=F%J86YA(`!&<F%N
M8V]S:V$@4&]L:6YE>FEJ82``1G)A;F-O<VMI(&IUQ;YN:2!T97)I=&]R:6H@
M`$]D`$]D(`!0;VQN($]P:7,Z`%!O;&YA(&QU;F$`4&]L;F\@:6UE`$=A8F]N
M`$=A;6)I:F$`57-T=F%R:2`E<R!.87-T879I='9E`$=E;F5R:7)A:B!K;V1O
M`$=R=7II:F$`3F5MQ(UI:F$`1V%N80!':6)R86QT87(`1&%N;R!I;64`4W!L
M;\6A;F4@36_%OFYO<W1I`%!O:F1I`$=O;V=L;W9E(&UA<&4`2<6AQ(UI('H@
M1V]O9VQO;0!,97-T=FEC82!S:79I;F4@`$=RQ(UI:F$`1W+%H6MI("A)4T\M
M.#@U.2TW*0!'<F5N;&%N9&EJ80!'<F5N861A`%-K=7!I;G-K82!A9&UI;FES
M=')A8VEJ80!);65N82!3:W5P:6X@;F4@<VUE:F\@8FET:2!P<F%Z;F$`075T
M:%]L9&%P.B!.92!M;W)E;2!D;V1A=&D@<VMU<&EN92`E<RX@4W!O<F_$C6EL
M;R!S=')EQ;YN:6MA.B``4VMU<%]L9&%P.B!.92!M;W)E;2!I>F)R:7-A=&D@
M<VMU<&EN92`E<P!3:W5P7VQD87`Z($YE(&UO<F5M(&YA9&=R861I=&D@<VMU
M<&EN92`E<P!3:W5P:6YE`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E
M<FYS97D`1&]V;VQJ96YJ82!Z82!G;W-T90!+;FII9V$@9V]S=&]V`$=V:6YE
M:F$`1W9I;F5J82U":7-S86\`1W9A:F%N80!(5$U,`$]V97)J96YE9V$@2%14
M4"!.:7-E;2!N8<6A96PN`$AA:71I`$AA<V@@06QG;W)I=&5M`$UE9VQI8V$`
M1VQA=F$`1VQA=F4`2&5A<F0@;W1O:R!I;B!-8T1O;F%L9&]V;R!O=&_$C6IE
M`$UOQ(UN82!N979I:'1A`$AE8G)E:G-K:2`H25-/+3@X-3DM."U)*0!6:<6A
M:6YA`%!O;6_$C0!0;VUOQ(UL;FEK`%!O;&]B;&$`5'5K86H@:F4@>F'$C65T
M96L@9&%T;W1E:V4Z`%9I<V]K;P!$;VUO=@!6871I:V%N`$1O;6'$C6D@;F%S
M;&]V`$EM96YI:P!$;VUAQ(UI('1E;&5F;VX`2&]N9'5R87,`2&]N9R!+;VYG
M`$AO<F1E`$AO<F1E+TMO;&%B.B!.979E;&IA=F5N("5S(%A-3"!P;V1A=&5K
M(&YA:F1E;B!V('-P;W)OQ(UI;'4@)7,`2&]R9&4O2V]L86(Z($YO8F5N;R!S
M<&]R;\2-:6QO('-E(&YE('5J96UA(',@<')E9&UE=&]M("5S`$AO<F1E+TMO
M;&%B.B!6('-P;W)OQ(UI;'4@)7,@;FD@;F%J9&5N(&YO8F5N('!R961M970@
M=&EP82`E<P!(;W)D92]+;VQA8CH@57-P9<6A;F\@;V1S=')A;FIE;B`E<R`B
M)7,B`$AO<F1E+TMO;&%B.B!);G1E9W)A8VEJ<VMA(&YA<')A=F$@>F%H=&5V
M82`G9&]M>&UL)R!02%`@96MS=&5N>FEJ;P!(;W)D92]+;VQA8CH@3F4@;6]R
M92!U<W1V87)I=&D@;F]V;R!834P@9')E=F\@>F$@)7,`2&]R9&4O2V]L86(Z
M($YE(&UO<F5M(&]D<W1R86YI=&D@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z
M($YE(&UO<F5M('!O:7IV961E=&D@>F$@34E-12!)1"!Z82!D96P@;V0@=G)S
M=&4@)7,`2&]R9&4O2V]L86(Z($YE(&UO<F5M('-I;FAR;VYI>FER871I("5S
M("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!.92!M;W)E;2!S:6YH<F]N:7II<F%T
M:2!D96QE.B`E<P!(;W)D92]+;VQA8CH@3F5Z;F%N82!D96QI=&5V("(E<R(`
M2V]L:6MO('!O;&H@*'-T;VQP8V5V*6IE('1A;3\`5FQAQ;YN;W-T`%9L8<6^
M;F]S=#H@`$AU;6]R:7-T:0!-863%OF%R<VMA`%5S='9A<FIA;FIE($E-05`@
M;F%B:7)A;&YI:V$@;FD@=7-P96QO.B`E<P!"<FES86YJ92!)34%0(&YA8FER
M86QN:6MA(&YI('5S<&5L;SH@)7,`57-T=F%R:F%N:F4@:W9O=&4@24U!4"!N
M86)I<F%L;FEK82P@;FD@=7-P96QO.B`E<P!)4"!.87-L;W8`25`@3F%S;&]V
M(&YI(&YA(')A>G!O;&%G;RX`25`@3F%S;&]V(&YI('8@9&]V;VQJ96YI($-)
M1%(@<VMU<&EN:2X`6F%K;&5N:F5N($E0+@!)<VQA;F1I:F$`4V%M;R!I:V]N
M90!):V]N92!Z82`E<P!):V]N92!Z(&)E<V5D:6QO;0!)9&5N=&EF:6MA8VEJ
M<VMO(&EM93H`)7,@>F$@;V1P<F5T:2!V(&YO=F5M(&]K;G4L(,2-92!N:2!P
M<F%V:6QN;R!P<FEK87IA;F\N`,2-92!V:61I=&4@=&\@<W!O<F_$C6EL;R!I
M;B!S;&G$C6EC92!N92P@<&]M96YI+"!D82!V8<6A(&)R<VMA;&YI:R!N92!M
M;W)E(&]D<')E=&D@<VQIQ(UI8V4L(&MI(&IO(,6^96QI=&4@;F%L;\6^:71I
M+@!$;V1A:B!S;&EK;P!3;&EK90!6;F]S+"!+;W)A:R`E9`!6;F7%H65N;R!P
M;VQJ93H@)7,`5FYEQ:%E;F$@<&]L:F$Z`%!O<W)E9&]V86X@;F5P<F%V:6QE
M;B!U:V%Z+@!.97!R879I;&YO('5P;W)A8FYIQ:%K;R!I;64@:6XO86QI(&=E
M<VQO+@!.97!R879I;&YO('5P;W)A8FYIQ:%K;R!I;64@86QI(&%L=&5R;F%T
M:79E;B!N87-L;W8N(%!O<VMU<VET92!Z;F]V82!A;&D@:V]N=&%K=&ER86IT
M92!V8<6A96=A('-K<F)N:6MA+"#$C64@<&]T<F5B=6IE=&4@;F%D86QJ;FIO
M('!O;6_$C2X`26YD:6IA`%!O<V%M97IN:2!5<&]R86)N:6MI(`!);F1O;F5Z
M:6IA`$EN9F]R;6%C:6IE(&\@<V5S=&%N:W4`26YF;W)M86-I:F4@;FES;R!V
M9<2-(&1O<V5G;&II=F4N`%9S=&%V:2!A;'1E<FYA=&EV96X@=GIO<F5C`%9S
M=&%V:71E(&5L96MT<F]N<VMI(&YA<VQO=B!N82!K871E<F5G82!L86AK;R!P
M<F5J;65T92!N;W9O(&=E<VQO.@!6<W1A=FET92!S<&]R;\2-:6QO`%9P:<6A
M:71E('IA:'1E=F%N(&]D9V]V;W(@;F$@=F%R;F]S=&YO('9P<F'%H6%N:F4Z
M`%-T86YJ92!N82!R8<2-=6YU(&YE('IA9&]S='5J92!Z82!P;\6A:6QJ86YJ
M92!N82#%OF5L:F5N('-P:7-E:RX`4W1A;FIE(&YA(')AQ(UU;G4@;F4@>F%D
M;W-T=6IE+@!#96QO(,6A=&5V:6QO`%-E>FYA;2!C96QI:"#%H71E=FEL`$YE
M=F5L:F%V96X@541(+B`H57-E<B!$871A($AE861E<BDN`$YE=F5L:F%V96X@
M6DE0('!O9&%T96LN(`!.979E;&IA=FYA(&%P;&EK86-I:F$N`$YE=F5L:F%V
M;FD@240@<&%K970N`$YE=F5L:F%V;FD@<&]D871K:2!S;R!B:6QI(&]D<&]S
M;&%N:2X`3F5V96QJ879E;B!N87-L;W8@;F%S;&]V;FEK82X`($YE=F5L:F%V
M;F$@;V)L:6MA(&1A=&]T96ME(`!.979E;&IA=F5N(&QI8V5NQ(UN:2!K;&IU
MQ(TN`$]D<F5J96X@;F5V96QJ879E;B!K<F%J+@!.979E;&IA=F5N('1I<%]M
M<V<N`$YE=F5L:F%V96X@86QI(&UA;FIK86IOQ(T@87!I7VED+@!.979E;&IA
M=FYI(&%L:2!M86YJ:V%J;\2-:2!P87)A;65T<FDN`$YE=F5L:F%V;F\@9&]V
M;VQJ96YJ92!S=&%RQ:%E=BX`3F5V96QJ879E;B!P87)T;F5R:F5V(&ED+@!.
M979E;&IA=FYA(&MO9&$@87)T:6ML82X`3F5V96QJ879E;B!P<F]T;VMO;"X`
M3F5V96QJ879E;B!N87-L;W9N:6LZ("(E<R(`($YE=F5L:F%V96X@;V)J96MT
M(&1E;&IE;FIA(`!.979E;&IA=F5N(&EZ=F]R;FD@;F%S;&]V+@`@3F5V96QJ
M879E;B!U;FEK;V0@<&]D871E:P!);G9E;G1U<F$O<&]P:7,`3V)R;FD@:7IB
M;W(`27)A;BP@27-L86US:V$@4F5P=6)L:6MA`$ER86L`27)S:V$`4&]S86UE
M>FYE(&YE=FEH=&4`27IR865L`$EZ9&%J871E;&H`271A;&EJ80!*86UA:FMA
M`$IA;G5A<@!*87!O;G-K80!*87!O;G-K:2`H25-/+3(P,C(M2E`I`$IE<G-E
M>0!*;W)D86YI:F$`2G5L:6H`2G5N:6H`2V%Z86AS=&%N`$]B9'+%OFEM(&EZ
M=FER;FEK/P!+96YI:F$`2V5R8F5R;W,@<W1R9<6^;FEK('IA=G)N:6P@;W9E
M<FET978N`$ME<FYE;"!N;W9I;F-I`%5S='9A<FD@2VQJ=<2-(`!/9'1I<R!+
M;&IUQ(UA`$1O;,6^:6YA($ML:G7$C6$`5&EP($ML:G7$C6$@`%5P;W)A8F$@
M2VQJ=<2-82``2VQJ=<2-(,6^92!O8G-T86IA(&YA(&IA=FYE;2!K;&IUQ(UN
M96T@<W1R9<6^;FEK=2X`3W1R;V-I`$MI<FEB871I(`!+;W)E:F$L($1E;6]K
M<F%T:<2-;F$@;&IU9'-K82!R97!U8FQI:V$@`$MO<F5J82P@4F5P=6)L:6MA
M(`!+;W)E:G-K:2`H155#+4M2*0!+=79A:G0@`$MI<F=I>FEJ82``2F5Z:6L`
M3&%O<R!L:G5D<VMA(&1E;6]K<F%T:<2-;F$@<F5P=6)L:6MA`%IA9&YJ82!P
M;VQO=FEC80!:861N:F$@<W!R96UE;6)A(&=E<VQA.B``6F%D;FIA(,2-971R
M=&EN80!:861N:F4@8<6^=7)I<F%N:F4Z`%IA9&YJ82!P<FEJ879A.B`E<R``
M6F%D;FIA('!R:6IA=F$Z("5S(&EZ("5S`%IA9&YJ82!P<FEJ879A.B!.:6MO
M;&D`3&%T=FEJ82``4')A=F\`3&EB86YO;@!,979O(&]G;&%V;&IE`%9R961N
M;W-T:2!N82!L979I`$QE<V]T;P!2879E;@!,:6)E<FEJ80!,:6)I:F$@`$QI
M96-H=&5N<W1E:6X@`%)A:&5L('!RQ:%E8P!286AE;"!D9<6^`%IG;V1A:B!R
M86AE;"!D9<6^`%!O>FYO(')A:&5L(&1EQ;X`4&QO:&$`4&QO:&$@>B!G<FUE
M;FIE;0!286AE;"!S;F5G`%-N9<6^;FD@;65T9<6^`%!O=F5Z879A`%!O=F7%
MOFD@92UN87-L;W8@<R!O8G)A>F-E;2!Z82!S97-T879O(&YO=F4@<&_%H71O
M(&UE('!R:6MA>F]V86YJ96T`4&]V97IA=F4`3&EN=7@@<&G%H6MO=&5K`%-E
M>FYA;2`M('5P;W)A8FYI:R!L86AK;R!V:61I(&UA<&\`4V5Z;F%M('!O9&%T
M:V]V;FEH(&)A>@!397IN86T@5&5M(%!O;6_$C6D@`%-E>FYA;2!T86)E;``@
M4V5Z;F%M($%R:&EV82``4V5Z;F%M(%!O;6_$C6D@`%-E>FYA;2!)9&5N=&ET
M970@`%-E>FYA;2!,87-T;FEK;W8@`%-E>FYA;2!0;\6A=&4@`%-E>FYA;2!0
M<FEJ878@`%-E>FYA;2!/9&IA=B``4W!I<V5K('-E>FYA;6$@<V5J(&YI('5S
M<&5L.B`E<RX`4V5Z;F%M('5P;W)A8FYI:V]V(&YI(&UO9V_$C64Z("5S`%-E
M>FYA;2!U<&]R86)N:6MO=B!N:2!M;V=OQ(TN`$QI=&5R871U<F$`3&ET=F$@
M`$YA;&%G86TN+BX`3&]K86QN:2#$C6%S.@!,;VMA;&EZ86-I:F$`365S=&\`
M4')I:F%V80!/9&IA=F$@<R!P<F5D:&]D;F4@<WEN8R!S96IE(`!/9&IA=F$`
M4')I:F%V80!0<FEJ879A(&YA(&]P<F%V:6QA`%!R:6IA=F$@;FD@=7-P96QA
M+B!5<&]R86)N:<6A:V\@:6UE(&%L:2!G97-L;R!N97!R879I;&YO('9N9<6A
M96YO`%!R:6IA=F$@;FD@=7-P96QA`$1O;&=O($)E<V5D:6QO`$QJ=6)E>F5N
M`$YI>F5K`$QU:W-E;6)U<F<`34T`4W!O<F_$C6EL;R!D;F5V80!-4RU43D5&
M(%!R:7!O;FMA(&YI('9S96)O=F%L82!P;V1A=&MO=BX`35-'`$UA8V%U`$UA
M:V5D;VYI:F$L(&9O<FUA;&YA($IU9V]S;&]V86YS:V$@<F5P=6)L:6MA`$UA
M9&%G87-K87(`Q(UA<F]B96X`16QE:W1R;VYS:VD@;F%S;&]V`$%D;6EN:7-T
M<F%T;W(@<&_%H71E`$UA;&%V:0!-86QE>FEJ80!-86QD:79I`$UA;&D`36%L
M=&$`57)E9&ET92!S97IN86T@:V%T96=O<FEJ(',@:V%T97)I;6D@8F]S=&4@
M;WIN8<2-:6QI('!O<W1A=FME(&EN('!R:7!A9&%J;\2-92!B87)V92!Z82!T
M92!K871E9V]R:6IE+@!:96UL:F5V:60@36%P,C0`6F5M;&IE=FED($UA<%%R
M97-T`%-H<F%N:F5N92!P;W9E>F%V90!-87)E8P!/>FYAQ(UI('H@>F%S=&%V
M:6-A;6D@5FED96YO+TYE=FED96YO`$]Z;F'$C6D@>B!O<W1A;&EM:2!Z87-T
M879I8V%M:2AN<'(N(%!O;65M8FYO+T]D9V]V;W)J96YO*0!-87)S:&%L;&]V
M;R!O=&_$C6IE`$UA<G1I;FEQ=64`56IE;6%N:F4@<&]L:@!-879R971A;FEJ
M80!-879R:6-I=7,`3F5J=F7$C2!D;W9O;&IE;FD@>FYE<V5K`$UA:W-I;6%L
M;FD@9&5L:2!S<&]R;\2-:6QA('!R96MO<F'$C65N:2X`36%K<VEM86QN82!T
M96UP97)A='5R82!Z861N:FEH(#(T('5R.@!-86MS:6UA;&YA('1E;7!E<F%T
M=7)A('IA9&YJ:6@@-B!U<CH`36%K<VEM86QN;R#%H71E=FEL;R!B;&]K;W8@
M<&]R=&%L80!-86MS:6UA;&YA(&1O;,6^:6YA`$UA:@!-87EO='1E`%ID<F%V
M:6QO("A-961I8VEN82D`Q(UL86YI`%1I<"!M96YI:F$Z`%-P;W)OQ(UI;&\`
M4W!O<F_$C6EL;R!J92!B:6QO('5S<&7%H6YO('!R979E<FIE;F\L('1O9&$@
M<&]D<&ES;FEK;W9E9V$@<&]T<F1I;&$@;FD@8FEL;R!M;V=OQ(UE('!R979E
M<FET:2X`4W!O<F_$C6EL;R!J92!P;W1E:VQO+@!4:7`@4W!O<F_$C6EL80!-
M971A<B!V<F5M90!-971A<B!B;&]K(&YI(&YA(')A>G!O;&%G;RX`4&]D<F]B
M;F]S=&D@<V\@8FEL92!P<FEJ879L:F5N92!Z82!U<')A=FQJ86QC82X`365T
M87)$0B!N:2!P;W9E>F%N+@!0;W-T;W!E:P`G)7,G('!O<W1O<&5K(&YI(&1O
M;&_$C65N+@!0;W-T;W!E:R!N:2!D;VQOQ(UE;BX@4&]S=&]P96L@8V5L:6-E
M.B`E<P!-971R:<2-;FD`365H:6MA`$UI:W)O;F5Z:6IA+"!&961E<F%T:79N
M82!D<L6^879A`%1I<"!D871O=&5K90!-:6YI;6%L;F$@=&5M<&5R871U<F$@
M>F%D;FII:"`R-"!U<CH`36EN:6UA;&YA('1E;7!E<F%T=7)A('IA9&YJ:6@@
M-B!U<CH`36EN:6UA;&YA('-T87)O<W0@9V5S;&$@Q:%E(&YI('!O=&5K;&$`
M3V=L961A;&\`36YO9V]S=')A;G-K80!0;V=R9<6A86X@4$5!4B!P86ME="P@
M2%144"!Z86AT979A;BX`4&]G<F7%H6%N;R!)1"!S<&]R;\2-:6QO+@!0;V=R
M9<6A86YO('-P;W)OQ(UI;&\@;R!Z86AT979A;F5M(%!%05(@<&%K971U+@!0
M;V=R9<6A86YA($E$('-E:F$N`%!O`$UO8FEL;F$@<&_%H71A`%IM97)N;P!$
M871U;2!S<')E;65M8F4`36]D=6QI`$UO;&1A=FEJ82P@<F5P=6)L:6MA`$UO
M;F%K;P!-;VYG;VQI:F$`365S96,@:6X@;&5T;P!-97-EQ(UN;P!-;VYT<V5R
M<F%T`$QU;FEN92!M96YE`%8@=G)S=&D@)60@:F4@;F%J9&5N:6@@=F7$C2!P
M;VQJ(&]D('!R961V:61E;FEH("5D+@!-87)O:V\`4')E=&7%OFYO(&IA<VYO
M`%!R971EQ;YN;R!O8FQAQ(UN;P!0<F5T9<6^;F\@;V)L8<2-;F\@:6X@=F5T
M<F]V;F\`4')E=&7%OFYO('-O;L2-;F\`4&]M86MN:2!S92!D;VP`4&]M86MN
M:2!S92!V(&QE=F\`4&]M86MN:2!S92!V(&1E<VYO`%!O;6%K;FD@<V4@9V]R
M`%!O;6%K;FD@<V4@9&]L`%!O;6%K;FD@<V4@9V]R`$UO>F%M8FEK`%9EQ(T@
M;FEV;VIN:2!P861A:F_$C6D@<W!I<VMI`$UU;'1I;6%P(%5+('IE;6QJ979I
M9"X`36YO9V]K<F%T96X@:7IB;W(`36]J(')AQ(UU;@!0;V1A=&MI(&UO:F5G
M82!R8<2-=6YA`$UO:B!P;W)T86P`3V)L:6MA(&UO:F4@<')V92!S=')A;FD`
M36IA;FUA<@!.92P@<V4@;F4@<W1R:6YJ86T`26UE`$YA;6EB:6IA`$YA=7)U
M`$YE<&%L`$YI>F]Z96US:V$`3FEZ;WIE;7-K:2!!;G1I;&D`3F5T<V-A<&4@
M;W-N;W9N:2!54DP`($YE='-C87!E($-!(%523"!Z82!P<F5K;&EC`$YA<VQO
M=B!.971S8V%P92!C97)T:69I:V%T80`@3F5T<V-A<&4@;V)N;W9I='9E;FD@
M55),`"!.971S8V%P92!54DP@>F$@<')E:VQI8P!.971S8V%P92!34TP@:6UE
M('-T<F7%OFYI:V$`3F5T<V-A<&4@=7)A9&YI(&MO;65N=&%R`%1I<"!.971S
M8V%P92!C97)T:69I:V%T80!/;7)EQ;YJ90!.:6MO;&D`3F]V82!+86QE9&]N
M:6IA`$YO=F$@:V%T96=O<FEJ80!.;W9A($QU;F$`3F]V;R!U<&]R86)N:<6A
M:V\@:6UE`$YO=F$@6F5L86YD:6IA`$YO=F\@9V5S;&\`3F]V;R!G97-L;R!B
M;R!P;W1E:VQO("5X+@!.;W9O(&=E<VQO('-E(&YE('5J96UA+@!.;W9I8V4`
M3F]V:<2-87)S:V$@<VMU<&EN80!.87-L961N:FD`3F%S;&5D;FIE(#0@<W1O
M<&YJ90!.87-L961N:F$@;6_%OFYO<W0`3F%S;&5D;FII/@!.:6MA<F%G=F$`
M3FEG97(`3FEG97)I:F$`3FEG97(`3FEU90!.;V)E9&5N`$YI(&1O<W1O<&YI
M:"!P;V1A=&MO=B!O(&MO;F9I9W5R86-I:FD@9&$@8FD@<&]K87IA;"!R87IL
M:6ME+@!3=')A=&5G:6IA('IA(&EZ9&5L879O($E33R!S;&EK+"!N:2!D;W-T
M;W!N82X`3FD@<&%K971N92!P<F5D;&]G90!.82#%OF5L96YE;2!M97-T(&)E
M;&7%OFMA(&YE(&]B<W1A:F$N`%IA($U#04P@;W9E<FET978@;FD@:V]L961A
M<G-K96=A(&EM96YA`&YI('-P<F5M96YJ96YO`$YA('1E:B!S=&]P;FII(&YE
M(&1O9&%J86UO(&]T<F_%H6MI:"!D;W9O;&IE;FHN`%IA("5S(&YI('-P96-I
M9FEC:7)A;FEH(&MO;F9I9W5R86-I:G-K:6@@:6YF;W)M86-I:BX`6F$@1E10
M(%9&4R!N:2!P;W-E8FYI:"!I;F9O<FUA8VEJ+@`@6F$@4U%,(%9&4R!N:2!P
M;W-E8FYI:"!I;F9O<FUA8VEJ+@`@6F$@9&%T;W1E:V\M4U%,(%9&4R!N:2!P
M;W-E8FYI:"!I;F9O<FUA8VEJ+@!.:2!S=&%N:F$@;F$@<F'$C75N=2X`3FD@
M9&5S=&EN86-I:F4`3FD@;F%L;\6^96YI:"!D871O=&5K+@!.92!N86ID96T@
M:6MO;BX`365S=&\@;FD@;F%S=&%V;&IE;F\N`$UE<W1O(&YI(&YA<W1A=FQJ
M96YO+@!.;V)E;F\@<W!O<F_$C6EL;R!D;W-T879L:F5N;RX`3FD@<W!E8VEF
M:6-I<F%N;R!N;V)E;F\@:6UE+@!.:2!S<&5C:69I8VER86YO(&YO8F5N;R#%
MH71E=FEL;RX`3F]B96YI:"!O9F5N>FEV;FEH('-R9<2-+@!0;W0@9&\@8FEN
M87)N92!D871O=&5K92!/<&5N4U-,(&YI(&)I;&$@;F%S=&%V;&IE;F$N($]P
M96Y34TP@8FEN87)N82!D871O=&5K82!J92!P;W1R96)N82!Z82!D96QO(',@
M4$M#4R`Q,B!P;V1A=&MI+@!.92!S<')E:F5M86UO('IAQ(UA<VYI:"!P<FEJ
M878`2W9O=&$@;FD@;F%S=&%V;&IE;F$O9&]L;\2-96YA+@!.:2!S<&5C:69I
M8VER86YO(&QOQ(UI;&\N`$YI('1A:V4@9&%T;W1E:V4`3F4@;F%J9&5M('IA
MQ(UA<VYE(&UA<&4@>F$@<')E9'!O;6YI;&YI:RX`3F]B96YO('5P;W)A8FYI
MQ:%K;R!I;64@:6XO86QI(&=E<VQO(&YI(&)I;&\@<&]S;&%N;RX`4&]V<F%T
M;FEH('9E;&IA=FYI:"!834P@<&]D871K;W8@;FD`0G)E>B!V<F5D;F]S=&D`
M5B!O<FEG:6YA;&YI(&MO;F9I9W5R86-I:FD@;F4@;F%J9&5M(&YO8F5N92!R
M87IL:<2-:6-E+B!/8FYO=FET:2!K;VYF:6=U<F%C:6IO+@!6('9AQ:%I(&MO
M;F9I9W5R86-I:FD@;F4@;F%J9&5M(&YO8F5N92!R87IL:<2-:6-E+B!/8FYO
M=FET92!K;VYF:6=U<F%C:6IO+@!.;V)E9&5N`$YO<F1I:G-K:2`H25-/+3@X
M-3DM,3``3F]R9F]LQ:%K:2!O=&]K:0!3979E<FYA('!O;&]B;&$`4V5V97)N
M:2!-87)I86YS:VD@;W1O:VD`3F]R=F7%H6MA`$YE(&MA<VYE:F4`3F4@<')E
M:@!.:2!I;65N:6L`3FD@:7IV961E;F\N`$YE('!O9'!I<F%M`%IA<&ES:VD`
M3FD@=G!I<V%N:6@@8F5S960@>F$@:7-K86YJ92P@=G)N:71E('-E(&YA>F%J
M+@!.;W9E;6)E<@#%H'1E=FEL;P#%H'1E=FEL;R!Z;F%K;W8`Q:!T979I;&\@
M<W1O;'!C978`Q:!T979I;&\@=G)S=&EC`$YI('-P96-I9FEC:7)A;FEH(,6A
M=&5V:6QK('IA(&'%OG5R:7)A;FIE(&EN(&1I<W1R:6)U8VEJ<VMI('-E>FYA
M;2X`6F%D979A`%5S='9A<FIA;&5C('!R961M971O=@!/<VUIQ:%K:0!/:W1O
M8F5R`%!I<V%R;F$`4W1A<F\@:6X@;F]V;R!G97-L;R!M;W)A=&$@8FET:2!R
M87IL:<2-;F$N`%-T87)O($=E<VQO`%-T87)O(&=E<VQO(&YI('!R879I;&YO
M+@!/;6%N`$UA<&4@=B!S:W5P;FD@=7!O<F%B:2!P;V1P:7)A('-A;6\@24U!
M4"!S=')EQ;YN:6LN`%-A;6\@;F5S<F%M;F4@:7IJ879E`$1O=F]L:F5N(&IE
M(&QE(&5N(&5L96MT<F]N<VMI(&YA<VQO=BX`3&4@;&%S=&YI:R!A;&D@=7!R
M879N:6L@<VES=&5M82!L86AK;R!Z86UE;FIA(&QA<W1N:<6A='9O(&%L:2!L
M87-T;FEK;W9O(&1O=F]L:F5N:F4@>F$@9&5L9<6^+@!/9'!R:2!V(&YO=F5M
M(&]K;G4`3V1P<G1A4U-,(&YA<&%K83H@3F4@;6]R96T@<&]V>F5T:2!D871U
M;6$@:7H@;WIN8<2-96YE9V$@4R]-24T@9&5L82X`3W!E<F%T:79N:2!S:7-T
M96T`36_%OFYO<W1I`$UOQ;YN;W-T:2!Z82`E<P!/<F=A;FEZ86-I:F$`3W)G
M86YI>F%C:6IS:V$@96YO=&$`3W)G86YI>F%C:6IA`$EZ=FER;F4@Q:%A8FQO
M;F4@87!L:6MA8VEJ`$EZ=FER;FD@Q:%A8FQO;F4@=B`E<SH`1')U9V\`3W-T
M86QE(&EN9F]R;6%C:6IE`$1O=F]L:F5N:F$@;&%S=&YI:V$`3W9E<FIE;FIE
M(&YI('5S<&5L;P!014%2.CH@9V]N:6QN:6L@4&_%H71E`$1I9VET86QE;B!P
M;V1P:7,@4$=0`$MO9&ER86YI(%!'4"!P;V1A=&MI`$IA=FYI(&ML:G5E(%!'
M4`!0;V1P:7-A;FDO:V]D:7)A;FD@4$=0('!O9&%T:VD`4$A0(&MO9&$`4$A0
M(&QU<&EN80!0;W!O;&1N92!R86AE;"!D9<6^`%!O<&]L9&YE(&1EQ;X`4&]P
M;VQD;F4@;F%L:79I`%!O<&]L9&YE('-N96<N`%!O<&]L9&YE('-N9<6^;FD@
M;65T9<6^:0!0;W!O;&1N92!S;VYC90!0;W!O;&1N92!N979I:'1E`%!O9W)E
MQ:%A;F$@4$]325@@96MS=&5N>FEJ80!02%`@;'5P:6YA`%!A:VES=&%N`%!A
M;&%U`%!A;&5S=&EN:VD@;VMU<&ER86YI('1E<FET;W)I:@!086YA;6$`4&%P
M=6$@3F]V82!'=FEN96IA`%!A<F%G=F%J`$1E;&YO(&]B;&'$C6YO`$=E<VQO
M`$=E<VQO('5S<&7%H6YO('-P<F5M96YJ96YO`$YE<')A=FEL;F\@9V5S;&\`
M6F$@4D%$2553(&]V97)I=&5V(&IE('IA:'1E=F%N;R!G97-L;RX`1V5S;&\@
M:6X@<&]T<F1I=&5V`$=E<VQO.@!'97-L;SH@`$=E<VQO('-E(&UO<F$@=6IE
M;6%T:2X`4')I;&5P:0!.97!O=')J96YE('!R:6IA=F4`3&IU9&IE`$EZ=G+%
MH6D@=GID<L6^979A;&YA(&1E;&$`27IV<L6A:6T@=GID<L6^979A;&YA(&1E
M;&$@;V(@<')I:F%V:3\`1&]V;VQJ96YJ90`B)7,B(&1O=F]L:F5N:F4@;FD@
M:7IB<FES86YO+@!$;W9O;&IE;FIE(&IE('IA=G)N:F5N;RX`1&]V;VQJ96YJ
M80!5<')A=FYIQ:%K82!D;W9O;&IE;FIA`$]S96)N92!I;F9O<FUA8VEJ90!0
M97)U`$QJ=6)L:F5NQ(UK:0!&:6QI<&EN:0!496QE9F]N`$9O=&]G<F%F:6IE
M`%!I=&-A:7)N`%!R;W-I;6\L(&1A('9N97-E=&4@;65S96,@:6X@;&5T;RX`
M4')O<VEM;RP@9&$@=FYE<V5T92!I;64@;F]V92!K871E9V]R:6IE.@!0<F]S
M:6UO+"!D82!V;F5S971E('9E;&IA=F5N($E0(&YA<VQO=BX`4')O<VEM;RP@
M9&$@=FYE<V5T92!V96QJ879E;B!D871U;3H@<')E=F5R:71E(,6A=&5V:6QO
M(&1N:2!V(&UE<V5C=2X`4')O<VEM;RP@9&$@=FYE<V5T92!P<F%V:6QE;B#$
MC6%S+@!0<F]S:6UO+"!D82!P<FEP<F%V:71E('!O=GIE=&5K('1EQ;YA=BX`
M4')O<VEM;RP@9&$@<VD@:7IB97)E=&4@=7!O<F%B;FG%H6MO(&EM92!I;B!G
M97-L;RX`4')O<VEM;RP@<')E8F5R:71E('-L961EQ(UE(&)E<V5D:6QO+B#$
MC64@Q;YE;&ET92!U<&]R86)L:F%T:2!T82!S:7-T96TL('-E(&UO<F%T92!S
M=')I;FIA=&D@<R!P;V=O:FDN`%!R;W-I;2P@=FYE<VET92!I;64@;F]V92!K
M871E9V]R:6IE.@!0;VQJ<VMA`%!O;&ET:6MA`$%N:V5T90!0;W)T=6=A;'-K
M80!/9&1A:B!V('1O(&UA<&\@*&YI('IA:'1E=F%N;R!O9"!)34%0*0!0861A
M=FEN92!V('IA9&YJ:6@@)7,@=7)A:#H`4&%D879I;F4\8G(@+SYC:&%N8V4`
M(%!R969S7VQD87`Z('IA:'1E=F%N96=A($Q$05`@<F%Z=&5G82!N92!N86ID
M96TN`%1L86L`5&QA:R!N82!M;W)S:VD@=FG%H6EN:3H`5&QA:SH@`%!R961O
M9VQE9`!0<F5JQ:%N:F4@;6_%OFYO<W1I`%IA<V5B96X@:VQJ=<2-`%!R;V)L
M96T`6B!O<&ES;VT@<V\@=&7%OF%V92XN`%!R;VIE:W1I`%1A:V]JQ:%N:F4@
M8F5S961I;&\`2F%V;FD@:VQJ=<2-`$%L9V]R:71E;2!J879N96=A(&ML:G7$
MC6$`26YF;W)M86-I:F4@:F%V;F5G82!K;&IUQ(UA`$IA=FYI+WIA<V5B;FD@
M<&%R(&ML:G7$C65V(&YI(&)I;"!U<W!EQ:%N;R!G96YE<FER86XN`%!O<G1O
M<FEK;P!0<F7$C6ES=&D@<W!O<F_$C6EL80!+871A<@!0;VEZ=F5D8F$`2W9O
M=&$`4E-!(&IA=FYI(&ML:G7$C2`H)60@8FET;W8I`$EZ8F5R:71E(')A9&EO
M`$1EQ;X`1&7%OB!Z:G5T<F%J`$1EQ;X@<&]P;VQD;F4`3F%L:78`1&7%OB!I
M;B!S;F5G`$1EQ;X@=B!S;F5G`%-R9<2-80!287IM97)J90!"97)I`$)E<FD@
M<W!O<F_$C6EL;P!3=&4@<')E<')IQ(UA;FDL(&1A(,6^96QI=&4@>F)R:7-A
M=&D@)7,_($EZ8G)I<V$@;FD@;6]G;\2-92!P<F5K;&EC871I+@!3=&4@<')E
M<')IQ(UA;FDL(&1A(,6^96QI=&4@>F)R:7-A=&D@=7!O<F%B;FEK;W9E('!O
M9&%T:V4@>F$@=7!O<F%B;FEK825S/R!)>F)R:7-A(&YI(&UO9V_$C64@<')E
M:VQI8V%T:2X`3W-V9<6^:0!/<W9EQ;YI(&1I;F%M:<2-;FD@;65N:2!E;&5M
M96YT;W8Z`$]S=F7%OFD@<&]R=&%L.@!296=E>`!)<VMA;&YI:R!R87IM97)I
M:@!0;VYO=FYO(&YA;&_%OFD`4')I<&]M8F4`3V1D86QJ96YI('-T<F7%OFYI
M:VD`3V1D86QJ96X@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E
M*3H`3V1S=')A;FD`3V1S=')A;FD@<W1O;'!E8P!/9'-T<F%N:2!P87(`3V1S
M=')A;FD@<VAR86YJ96YO('-K<FEP=&\@:7H@<W1R9<6^;FEK;W9E('IAQ(UA
M<VYE(&UA<&4`3V1S=')A;FD@=7!O<F%B;FEK80!/9'-T<F%N:2!U<&]R86)N
M:6MA.B`E<R``6F%H=&5V:2!N92!M;W)E;2!U9V]D:71I+B!6<FYJ96YA(&IE
M(&YA<&'$C6YA(&MO9&$Z(`!.92!N86ID96T@>F%H=&5V86YE9V$@<V5R=FES
M82X`6F%H=&5V86YI("(E<R(@;FD@<&]D<F]B;F\@;V)L:6MO=F%N('8@)7,@
M:V]N9FEG=7)A8VEJ:2X`6F%H=&5V86YI("(E<R(@;FD@<&]D<F]B;F\@;V)L
M:6MO=F%N('8@5DA3(&MO;F9I9W5R86-I:FDN`%IA:'1E=F%N:2`G)7,G(&YI
M('!O9')O8FYO(&]B;&EK;W9A;BX`6F%H=&5V86YA(&1A=&]T96MA`%!O;F%S
M=&%V:0!0;VYA<W1A=FD@9V5S;&\`4&]N87-T879I=&4@=F'%H64@9V5S;&\`
M3V)N;W9I=&4@>F%D;FIO('!O:7IV961B;P!:861E=&MI`%9R;FD@<V4@;F$@
M36_%OFYO<W1I`%!O;F]V;F\@=G!IQ:%I=&4@;F]V;R!G97-L;P!0;VYO=FYO
M('ID<G7%OFD`4&]V<FYI(&MO;F9I9W5R86-I:F\`5G)N:2!S92!N82!M;\6^
M;F]S=&D@=7)E:F5V86QN:6MA(&)E<V5D:6QA`$5N:6=M90!$97-N;R!O9VQA
M=FIE`$1E<VYE('9R961N;W-T:0!&=6YK8VEJ80!2;VUU;FEJ80!/8G)N:2!Z
M82`Q.#``3V)R;FD@;F$@;&5V;P!/8G)N:2!N82!D97-N;P!:8<6^96YI`%)U
M<VEJ80!2=6%N9&$`(%,O34E-12!K<FEP=&]G<F%F<VMI('!O9'!I<P!3+TU)
M344@:V]D:7)A;F\@<W!O<F_$C6EL;P!305-,($]V97)J86YJ92!N:2!U<W!E
M;&\`4TU3('-P;W)OQ(UI;&\`4U%,(&QU<&EN80!344P@<W1A=F5K('IA('!O
M:7IV961B;R!V<F5D;F]S=&D`4U-(`%534$5(`%-13"!L=7!I;F$`4V$`4W9E
M=&$@2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I<R``4V%I;G0@3'5C:6$`
M4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B``4V%I;G0@5FEN8V5N="!I;B!'
M<F5N861I;F4`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!I;B!0<FEN8VEP
M90!3871E;&ET<VMI(&]S:W)B;W9A;&5C`%-A=61S:V$@07)A8FEJ80!3:')A
M;FD`4VAR86YI("(E<R(`4VAR86YI("5S(`!3:')A;FD@36_%OFYO<W1I`%-H
M<F%N:71E(&=E;F5R:7)A;F\@:V]N9FEG=7)A8VEJ;R!K;W0@4$A0('-K<FEP
M=&\@;F$@>F'$C6%S;FD@;6%P:2!V8<6A96=A<W1R9<6^;FEK861I<F5C=&]R
M>2X`4VAR86YJ96YA("5S(&MO;F9I9W5R86-I:F$`4VAR86YJ96YA(&YA<W1A
M=FET=F5N92!S:W)I<'1A(&YA9&=R861N:F4@;F$Z("(E<R(N`%)A>F1I=FIA
M;F$@;F5V:6AT82!Z(&=R;65N:F5M`%IN86YO<W0`2<6AQ(UI`$ES:V%L;FEK
M:0!)>F)E<FD@9&%T;W1E:V\`27IB97)I(&1A='5M`$EZ8F5R:2!S:W5P:6YO
M+"!K:2!J;R#%OF5L:<6A(&1O9&%T:2X`27IB97)I(&YO=F5G82!L87-T;FEK
M80!)>F)E<FD@<W1R9<6^;FEK`$EZ8F5R:2!U<&]R86)N:6MA+"!K:2!G82#%
MOF5L:<6A(&1O9&%T:0!)>F)E<FD@=G-E`$EZ8F5R:2!P;W!O;&X@9&%T=6T`
M27IB97)I('!R961M970`3V1K;&IU:V%J('9S90!:;F%K92P@:VD@:FEH('!O
M=')E8G5J971E(&EZ8F5R:71E(&EZ(&]K=FER:F5V('-P;V1A:BX@3F%T;R!J
M:6@@;&%H:V\@:V]P:7)A=&4@:6X@<')I;&5P:71E('8O:7H@8F5S961I;&$N
M`$1O;&_$C6D@:V]NQ(UN:2!D871U;3H`27IB97)I(&]B;&EK;R!D871U;6$Z
M`$EZ8F5R:71E(&ED96YT:71E=&\L(&MA=&5R;R#%OF5L:71E('-P<F5M96YI
M=&DZ`$1O;&_$C6D@:V]NQ(UN;R!U<F\Z`$EZ8F5R:2!O8FQI:V\@=7)E.@!)
M>F)E<FD@9'9E('5J96UA:F_$C6D@<V4@<&]L:FDZ`$EZ8F5R:71E('9AQ:%E
M(&)A<G9N;R!K;VUB:6YA8VEJ;P!)>F)E<FET92!J97II:SH`4&_%H6QJ:2!P
M;W)OQ(UI;&\@;R!N87!A:V%H`%!OQ:%L:FD@4TU3`%-E;F5G86P`4V5N>F]R
M.@!397!R96UB97(`4W)B:6IA(&EN(,2-<FYA(&=O<F$`4V5R:6IS:V$@Q:%T
M979I;&MA`%-T<F7%OFYI:V]V(&1A='5M(&IE(&YA<&'$C65N(&%L:2!N:2!N
M82!R87IP;VQA9V\N`$%D;6EN:7-T<F%C:6IA('-E:F4`240@<V5J92!J92!P
M;W1E:VQA+@!396IE`$YA;65S=&D`3F%S=&%V:2!O<&-I:F\L(&1A('8@<')I
M;65R=2P@9&$@<&]Z86)I=&4@=F'%H64@9V5S;&\L(&QA:&MO('!O;F%S=&%V
M:71E(&QE+71O+@!5<F5D:71E(&]D9&%L:F5N92!S=')EQ;YN:6ME(&YA(&MA
M=&5R92#%OF5L:71E(&1O<W1O<&%T:2!Z('9AQ:%E9V$@<&]R=&%L80!.87-T
M879I=&4@<')I=GIE="!J97II:R!I;B!N87-T879I='9E(&1A='5M80!5<F5D
M:2!Z8<2-971N92!B87)V;F4@<VAE;64L(&%P;&EK86-I:F4L(&]S=F7%OFET
M=F4@<W1R86YI+BXN`$YA;65S=&D`3F%S=&%V:2!S:W)I<'1O('IA(&]S=F7%
MOFET978@:V]T(')A>G!O;&_%OFQJ:79O+@!-;\6^;FEH(&IE('9EQ(T@;&]K
M86-I:B!S('!A<F%M971R;VTZ`%-E:L6A96QI`$YA:W5P;W9A;FIE`$MR871E
M:R!P;W9Z971E:P!.871A=FEM('1I<&MA<G-K92!B;&G%OFYI8V4@;F$@<&]V
M97IA=F4_`%!O:V'%OFD`4&]K8<6^:2!R87IL:6ME(&UE9"!S961A:B!S:')A
M;FIE;F\@:6X@;F%J;F]V96K%H6\@9V5N97)I<F%N;R!K;VYF:6=U<F%C:6IO
M+@!0<FEK8<6^:2!D871U;2!Z861N:F4@<')I:F%V92!P;R!V<W1O<'4_`%!R
M:6MAQ;YI(&]P8VEJ92!Z82!O8F1RQ;YA=&D@;W)I9VEN86P`4&]K8<6^:2!T
M:7-T96=A+"!K:2!S<')E:F5M80!0<FEK8<6^:2!M96YI:G-K;R!V<G-T:6-O
M(&1E;&]V86YJ82!T86)E;&4`4')I:V'%OF5M("5S(&UE;FD@;F$@;&5V:2!S
M=')A;FD_`$1O9&%J(&YA;&%G86YJ90!0;&]H90!::G5T<F%J('!L;VAE`%!O
M<&]L9&YE('!L;VAE`%8@8FQIQ;YI;FD@<&QO:&4`4VMRQ(UI`$YA:G!R96H@
M<VMRQ(UI(&%L:2!P<F5M86MN:2!S;W-E9&YJ92!B96QEQ;YK92X`4VEE<G)A
M($QE;VYE`%!R:6IA=FD@<V4`4&]D<&ES`$%L9V]R:71M:<2-96X@<&]D<&ES
M`%-I;F=A<'5R`%9E;&EK;W-T`%!R97-K;\2-:2!V>F1RQ;YE=F%N:F4`4VQO
M=F'%H6MA`%-L;W9E;FEJ80!3;F5G`%-N9<6^;F$@<&QO:&$`4VYEQ;YN92!P
M;&]H90!::G5T<F%J('-N9<6^;F4@<&QO:&4`4&]P;VQD;F4@<VYEQ;YN92!P
M;&]H90!6:<6A:6YA('-N96=A.@!3;F5G=2!E:W9I=F%L96YT;F$@:V]L:<2-
M:6YA('9O9&4Z`%-A;&]M;VYO=FD@;W1O:VD`4V]M86QI:F$`4&5S;6D@:6X@
M<&]E>FEJ90!6<G-T82!U<F5J96YE9V$@:7IB;W)A`$YA<VQO=B!V:7)A`$IU
MQ;YN82!!9G)I:V$`2G7%OFYO+65V<F]P<VMI("A)4T\M.#@U.2TS*0!*=<6^
M;F$@1V5O<F=I82!I;B!O=&]K:2!*=<6^;FD@4V%N9'=I8V@`2G7%OFYA('!O
M;&]B;&$`4')E<VQE9&YI8V$`Q:!P86YI:F$`3F5Z8<6^96QE;F$@<&_%H71A
M`%9H;V0@>F$@<&]S96)N92!Z;F%K90#%H'!O<G1I`,6@<FD@3&%N:V$`4W1A
M;F1A<F1E;@!:=F5Z9&YE('-T97IE`%IAQ(UE=&YO(&QE=&\`1'+%OF%V82!A
M;&D@<')O=FEN8V$`4W1A='5S`$]B;&EK82!P;VUN:6QN:6MA`$YA<VQO=B!U
M;&EC90!3<&ES96L@8F5S961N:6@@>G9E>@`_/S\_/S\_/S\_9&]M96YA(&EZ
M(&YA<VQO=F$`3F4`3F4@;F%J9&5M('!O9&UA<&4@(B5S(@!:861E=F$`4')E
M9&QOQ;YI`%-P<F5J96QI('-M;R!Z86AT979E:R!Z82!V<&ES("(E<R(N($YE
M(&UO<F5T92!S92!P<FEJ879I=&D@9&]K;&5R('9AQ:%A('IA:'1E=F5K(&YE
M('!O('!O=')J96XN`%5S<&5H`"(E<R(@<V5M('5S<&7%H6YO(&1O9&%L(&L@
M<VES=&5M=2X`)R5S)R!S96T@=7-P9<6A;F\@;V1S=')A;FEL(&EZ('-I<W1E
M;6$N`"(E<R(@<V5M('5S<&7%H6YO(&EZ8G)I<V%L+@`B)7,B('-E;2!U<W!E
MQ:%N;R!O9'-T<F%N:6P@:7H@<VES=&5M82X`57-P9<6A;F\@;V)R;FIE;F$@
M:V]N9FEG=7)A8VEJ82X@Q(UE(,6^96QIQ:$@=FED971I('-P<F5M96UB92P@
M<&]N;W9N;R!N86QOQ;YI+@!5<W!EQ:%N;R!S:')A;FIE;F$@=F%R;F]S=&YA
M(&MO<&EJ82!K;VYF:6=U<F%C:6IE+@!5<W!EQ:%N;R!S:')A;FIE;F$@=F%R
M;F]S=&YA(&MO<&EJ82!K;V9I9W5R86-I:F4@9&%T;W1E:V4@)7,N`"(E<R(@
M:F4@8FEL('5S<&7%H6YO('!O<V]D;V)L:F5N+@`E<R!S96T@=7-P9<6A;F\@
M>F%P:7-A;"X`4W5D86X`4V]NQ(UN:2!V>FAO9`!3;V[$C6YI('IA:&]D`%-O
M;L2-;F\`4V]NQ(UN:2!V>FAO9`!3;V[$C6YI('9Z:&]D+WIA:&]D`%-O;L2-
M;FD@=GIH;V0`4V]NQ(UN:2!Z86AO9`!3;V[$C6YI('IA:&]D.@!0;V1P;W)A
M`%-U<FEN86T`4')I:6UE:P!3=F%L8F%R9"!I;B!*86X@36%Y96X`4W9A>FD`
MQ:!V961S:V$`Q:!V:6-A`$EZ8G)I<V%N('-I;FMR;VYI>F%C:6IS:VD@9&YE
M=FYI:P!3:6YK<F]N:7IA8VEJ80!.87!A:V$@=B!S:6YT86MS:2!I<VMA;&YI
M:"!P;V=O:F5V`%-I<FEJ<VMA(&%R86)S:V$@<F5P=6)L:6MA`$=R;65N:F4`
M3F5V:6AT82!Z(&=R;65N:F5M(&EN('9E=')O;0!.979I:'1A('H@9W)M96YJ
M96T`5%-6(&1A=&]T96MA`$YA<W1A=FET978@=&%B96QE`%1A:G9A;@!486EW
M86XL(&1EQ;YE;&$@2VET86IS:V4`5&%DQ;YI:VES=&%N`%1A;GIA;FEJ82P@
M6F1R=<6^96YA(')E<'5B;&EK80!/<')A=FEL80!496QE9F]N<VMA(,6A=&5V
M:6QK80!496UP97)A='5R82!V('IA9&YJ:2!U<FDZ`%1E;7!E<F%T=7)A`%1E
M;7!E<F%T=7)A.B``5&5M<&5R871U<F$\8G(@+SXH)7-(:25S+R5S3&\E<RD@
M)F1E9SLE<P`B)7,B('9Z;W)C82!N92!N86ID96TN`%5R96IE=F%L;FEK(,6A
M86)L;VX`0F5S961I;&\`4V%M;R!"97-E9&EL;P!4;P!486IS:V$`3W9E<FIE
M;FIE(&YI('5S<&5L;P!:9V]D;W9I;F$@:F4@:7IK;&]P;&IE;F$N`$AO<F1E
M+TMO;&%B(&EN=&5G<F%C:6IA(&YE('!O9'!I<F$@(B5S(@!0;W-O9&]B;&IE
M;B!D871O=&5K92!N92!M;W)E;2!S:')A;FET:2X`5GID<L6^979A;FIE.B!R
M87IR960@;FD@8FEL('5S<&7%H6YO(&YA;&_%OF5N+@!/:VYO($UOQ;YN;W-T
M:2!J92!B:6QO('IA<')T;RX@6F%K;&IU975J96TN`$%D;6EN:7-T<F%T;W(@
M;6]R82!N86IP<F5J(&YA<W1A=FET:2!S:7-T96T@>F$@<')A=FEC92X`2V]N
M=&%K=&YI($E$(&YI(&)I;"!P;W-R961O=F%N(&%L:2!N:2!B:6P@;F%J9&5V
M('8@8F%Z:2!P;V1A=&MO=BX`4W1I:R!J92!B:6P@=7-P9<6A;F\@9&]D86X@
M:R!V8<6A:6T@;F%S;&]V;VTN($ML:6MN:71E('-P;V1A:B!Z82!O9VQE9#H`
M4&]T<F5B=6IE;2!L;\2-96YO(%!'4"!P;V1P:7-A;F\@8F5L9<6^;FEC;RP@
M9&$@<')E=FER:6T@<&]D<&ES86YO('-P;W)OQ(UI;&\N`$E$('-E>FYA;6$@
M;FD@8FEL('!O<W)E9&]V82!A;&D@;FD@8FEL(&YA:F1E;B!V(&)A>FD@<&]D
M871K;W8N`%1O(&1E:F%N:F4@;FEM82!P;V1P;W)E+@!+;V1I<F%N82!V<V5B
M:6YA('IA:'1E=F$@=F%R;F\@:6YT97)N971N;R!P;W9E>F%V;RX`)7,@9&%T
M;W1E:V$@8FD@;6]R86QA('9S96)O=F%T:2`E<R!N87-T879I='9R+@`E<R!D
M871O=&5K82!B:2!M;W)A;&$@=G-E8F]V871I("5S(&YA<W1A=FET=F4N(`!$
M871O=&5K82!N92!V<V5B=6IE(&YO8F5N:6@@<&]D871K;W8N`%-T<F7%OFYI
M:R`B)7,B(&IE(&)I;"!I>F)R:7-A;BX`365S=&\@1VYU4$<@<')O9W)A;6$@
M;6]R82!B:71I('!O<W)E9&]V86YO(')A>G)E9'4@0W)Y<'1?<&=P+@!3<&]R
M;\2-:6QO('!O<VQA;F\@9&YE("5S('IA("5S('H@;F%S;&]V;VT@(B5S(B!J
M92!B:6P@<')E8G)A;BX*3FD@>F%G;W1O=FEL82!D82!J92!B:6QO(&1E:F%N
M<VMO('!R96)R86YO(&%L:2!R87IU;6QJ96YO+@!);64@>F$@<&]V97IA=F\@
M;F$@<W1R86X@>F$@<V5S=&%V;&IA;FIE('-P;W)OQ(UI;&$N`%1A('9R961N
M;W-T(&UO<F$@8FET:2#%H71E=FEL:V$N`%!O=')E8G5J96T@;W!E;G-S;"!M
M;V1U;"!Z82!(;W)D95]#<GEP=%]S;6EM93HZ(')A>G)E9"X`3F%S=&%V:65N
M92!D871O=&5K92`B)7,B(&YE(&UO<F4@<VAR86YI=&DL(&ME<B!N:F5N:2!P
M;V1A=&MI('!R97-E9V%J;VYA:G9EQ(UJ:2!D;W9O;&IE;B!O8G-E9RX`4')O
M9W)A;6$L(&MI(&]D<&ER82!P;V1A=&ME('1E('9R<W1E("@E<RD@;F4@;F%J
M9&5M('8@<VES=&5M=2X`4F%Z;65J:71E=B!M;W)A(&)I=&D@<V5S=&%V;&IE
M;F$@;&4@:7H@96YE9V$@>FYA:V$N`$QOQ(UI=&5V(&UO<F$@8FET:2!S97-T
M879L:F5N82!L92!I>B!E;F5G82!Z;F%K82X`4W1R9<6^;FEK("(E<R(@:F4@
M8FEL(&EZ8G)I<V%N+@!3=')EQ;YN:6L@(B5S(B!J92!S:')A;FIE;BX`27IB
M<F%N82!V<G-T:6-A("@E9"D@;F4@;V)S=&%J82X`5FYEQ:%E;F\@8F5S961I
M;&\@;F4@=7-T<F5Z82!B97-E9&EL;R!N82!E:W)A;G4N`%!O<V]D;V)L:F5N
M:2!P;V1A=&MI('-O(&)I;&D@:7IG=6)L:F5N:2!P<FD@<')E:L6A;FIE;2!K
M;W)A:W4N`%!O<V]D;V)L:F5N(&1A=&]T96ME(&YE(&UO<F5M('-H<F%N:71I
M+@!W96%T:&5R+F-O;2!N:2!N82!V;VQJ;RX`3F4@;F%J9&5M(&UA<&4@;V)L
M:6L@(B5S(BX`3FD@;6_%OFYO<W1I(&YA(')A>G!O;&%G;RX`1&5L:2!N92!M
M;W)E:F\@8FET:2!P<FEK87IA;FDN`%8@<&]L:G4@:F4@<')E=F7$C2!Z;F%K
M;W8N(%9T:7!K86QI('-T92`E<R!Z;F%K;W8N(%9T:7!K871I(&UO<F%T92!M
M86YJ(&MO="`E<R!Z;F%K;W8N`%!R:<6A;&\@:F4@9&\@;F%P86ME('!R:2!D
M;V1A:F%N:G4@)R5S)R!K('-I<W1E;74Z("5S`%!R:<6A;&\@:F4@9&\@;F%P
M86ME('!R:2!O9'-T<F%N:F%N:G4@)R5S)R!I>B!S:7-T96UA+@!0<FG%H6QO
M(&IE(&1O(&YA<&%K92!P<FD@;V1S=')A;FIA;FIU("<E<R<@:7H@<VES=&5M
M82X`4')IQ:%L;R!J92!D;R!N87!A:V4@<')I('!O<V]D86)L:F%N:G4@)R5S
M)SH@)7,@`%!R:2!N86QA9V%N:G4@9&%T;W1E:V4@:F4@<')IQ:%L;R!D;R!N
M87!A:V4N($YO8F5D96X@)7,@;FD@8FEL(&YA;&_%OF5N+@!0<FD@;F%L86=A
M;FIU(&1A=&]T96ME(&IE('!R:<6A;&\@9&\@;F%P86ME+B`E<R!Z87-E9&$@
M=F7$C2!P<F]S=&]R82P@:V]T(&IE(&1O=F]L:F5N;RX@1&]V;VQJ96YO(&IE
M("@E9"!B>71O=BDN`%!R:2!N86QA9V%N:G4@9&%T;W1E:V4@:F4@<')IQ:%L
M;R!D;R!N87!A:V4N("5S(&IE(&QE(&1E;&YO(&YA;&_%OF5N82X`5B!S<&]R
M;V5I;'4@<V4@:F4@<&]J879I;&$@;F5Z;F%N82!N87!A:V$N`%!R:2!S<')E
M:F5M86YJ=2!K;VYT86MT82!J92!P<FG%H6QO(&1O(&YA<&%K92X`4')I('-P
M<F5J96UA;FIU(&MO;G1A:W1A(&IE('!R:<6A;&\@9&\@;F%P86ME+@!+;VYF
M:6=U<F%C:6IS:VD@;V)R87IE8R!V<V5B=6IE(&YA<&%K;RX@5F5R:F5T;F\@
M<W1E('!O>F%B:6QI(&YA<W1A=FET:2!Z86AT979A;F\@<&]L:F4N`%!R:<6A
M;&\@:F4@9&\@;F%P86ME('!R:2!P<F]C97-I<F%N:G4@:7IB<F%N96=A(&EM
M96YI:V$N(%!R;W-I;6\@<&]S:W5S:71E('IN;W9A;F5K;VQI:V\@:V%S;F5J
M90!0<FD@<W!R96IE;6%N:G4@:V]N=&%K=&$@:F4@<')IQ:%L;R!D;R!N87!A
M:V4N(%!R;W-I;6\@<&]S:W5S:71E('IN;W9A(&MA<VYE:F4N`%!R:2!S<')E
M:F5M86YJ=2!K;VYT86MT82!J92!P<FG%H6QO(&1O(&YA<&%K92X@4')O<VEM
M;R!P;W-K=7-I=&4@:V%S;F5J92X`5F'%H2!B<G-K86QN:6L@;F4@<&]D<&ER
M82!T92!P;W1E>F4N`%1O(&YI('9E;&IA=F5N(%)!4B!A<FAI=BX`5&\@;FD@
M=F5L:F%V;F$@>FEP(&1A=&]T96MA+@#$@N*`FL6@=&5V:6QK82!K87)T:6-E
M(&YI('9E;&IA=FYA+@!';VYI;&YI:R!O;6]G;\2-92!P;\6A:6QJ86YJ92!S
M<&]R;\2-:6P@<')E:V\@;W!E<F%T97)J82!#;&EC:V%T96QL+@!';VYI;&YI
M:R!O;6]G;\2-92!P;\6A:6QJ86YJ92!S<&]R;\2-:6P@<')E:V\@;W!E<F%T
M97)J82!724XN`$=O;FEL;FEK(&]M;V=OQ(UE('!OQ:%I;&IA;FIE('-P;W)O
MQ(UI;"!P<F5K;R!O<&5R871E<FIA('-M<S)E;6%I;"X`1V]N:6QN:6L@;VUO
M9V_$C64@<&_%H6EL:F%N:F4@<W!O<F_$C6EL('!R96MO(&ET86QJ86YS:V5G
M82!O<&5R871E<FIA(%9O9&]A9F]N92Y:82!P;\6A:6QJ86YJ92!M;W)E=&4@
M:6UE=&D@<F5G:7-T<FER86YI(&YA(&AT='`Z+R]W=W<N,3DP+FET`%!O=')E
M8G5J96T@=&\@<&]L:F4N`%1O('!O;&IE(&QA:&MO('9S96)U:F4@;&4@8V5L
M82#%H71E=FEL82X`5&\@<&]L:F4@;&%H:V\@=G-E8G5J92!L92#%H71E=FEL
M82!I;B!S=&]L<&5C+@!4;R!P;VQJ92!L86AK;R!V<V5B=6IE(&QE(,6A=&5V
M:6QA+@!0;VQJ92!M;W)A('9S96)O=F%T:2!S97IN86T@Q:%T979I;"P@;&_$
MC65N:6@@>B!V96II8V\@86QI('!R97-L961K;VTN`%1A('9R961N;W-T(&UO
M<F$@8FET:2#%H71E=FEL:V$N`%1O('!O;&IE(&UO<F$@=G-E8F]V871I(&)A
M<G9N;R!K;V1O('8@4D="($AE>"!F;W)M871U+"!N82!P<FEM97(@)R,Q,C,T
M868G+@!482!O8FQI:V$@:F4@8FEL82#%OF4@;V)D96QA;F$N`%1O(&IE("5S
M+@!4;R!J92!P;V1A=&5K('-K=7!I;G-K82!U<')A=FQJ86YJ92!+;VQA8BX@
M6F$@<')E9VQE9"!T96=A('!O9&%T:V$@<&]T<F5B=6IE=&5P<F5G;&5D;&]V
M86QN:6LL(&MI('!O9'!I<F$@;F'$C6EN('IA<&ES82!+;VQA8B!'<F]U<'=A
M<F4N(%IA('-E>FYA;2!O9&IE;6%L8V5V:VD@=&\@<&]D<&ER86IO(&]B:<6A
MQ(UI=&4@)7,`4W!O<F_$C6EL;R!J92!B:6QO(&YA<&ES86YO('8@:V]D;FD@
M=&%B96QI(&1R=6=AQ(UN92!O9"!V8<6A92`H)7,I+@!4;R#%H71E=FEL;R!M
M;W)A(&)I=&D@=G-A:B!E;F$N`%1A('-T<F7%OFYI:R!N92!M;W)E(&]D<')E
M=&D@>FEP(&EN(&=Z:7`@9&%T;W1E:RX`4VES=&5M(&IE('1R96YU=&YO(&YE
M86MI=&EV96XN`%1A('9R961N;W-T(&UO<F$@8FET:2#%H71E=FEL:V$N`%1O
M(&]K;F\@;6]R871E('!O9VYA=&D@>B!O:VYA($UOQ;YN;W-T:2X`0FQI<VL`
M4')I:F%V90#$C6%S`%-L961N:F4@Q(UA<V$`3V)L:6MA(,2-87-A`$EZ8FER
M82!E87-A+@!.87-L;W8`6F$`9<2-(,6^96QI=&4@:7IB<F%T:2!V9<2-('!R
M961M971O=BP@<')I=&ES;FET92!#;VYT<F]L("A00RD@86QI($-O;6UA;F0@
M*$UA8RD@=&EP:V\L(&UE9'1E;2!K;R!N86YJ92!K;&EK871E+@!D86X`5&]G
M;P!4;VME;&%U`$MO;6]R:2``5&]N9V$`4')E=F7$C2!N975S<&5L:6@@<&]V
M97IA=B!V('IA9&YJ:6@@;6EN=71A:"X`3W)G86YI>F%C:6IA`%1R:6YI9&%D
M(&EN(%1O8F%G;P!$82!A;&D@;F4`Q(QE`%1U;FEZ:6IA`%1U<F5I:F$`5'5R
MQ:%K:2`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<L6A:VD@:6X@0V%I
M8V]S(&]T;VMI`%1U=F%L=0!6=&EP:V%J=&4@=F'%H6\@:7IB:7)O.B``52Y6
M+B!I;F1E:W,Z`%523`!54DP@=F'%H64@<VMR:7!T92!Z82!P;W)OQ(UA;FIE
M('-T871U<V$@9&]S=&%V90!59V%N9&$`56MR86II;F$`3FEM86T@9&]S=&]P
M82!D;R!61E,@:6UE;FEK82X`3F4@;6]R96T@<W!R96UE;FET:2!P<F%V:6-E
M('IA(%9&4R!D871O=&5K;R`B)7,B+@!$;W9O;&IE;FIA('IA(%9&4R`E<R\E
M<R!N92!M;W)E;2!S<')E;65N:71I+@!.92!M;W)E;2!S<')E;65N:71I(&YA
M("5S+@!.92!M;W)E;2!S<')E;65N:71I(&YA("(E<R(N`$YE(&UO<F5M('!R
M96EM96YO=F%T:2!61E,@9&%T;W1E:V4@)7,O)7,N`$YE(&UO<F5M('-E('!O
M=F5Z871I(',@4U-,+@!61E,@9&%T;W1E:V4@;F4@;6]R96T@:V]P:7)A=&DN
M`$YE(&UO<F5M('5S=&%V<FET:2!I;65N:6MA("(E<R(N`%9&4R!I;65N:6MA
M(&YE(&UO<F5M('5S=&%V<FET:2X`5D93(&1A=&]T96ME(&YE(&UO<F5M('5S
M='9A<FET:2X`3F4@;7)O96T@=7-T=F%R:71I(&EM96YI:V$@(B5S(BX`5D93
M(&1A=&]T96ME(&YE(&UO<F5M('5S='9A<FET:2X`4&]D871K;W8@;F4@;6]R
M96T@<W!R;W-T:71I+@!.92!M;W)E;2!I>F)R:7-A=&D@)7,L(&EM96YI:R!N
M:2!P<F%Z96XN`$YE(&UO<F5M(&EZ8G)I<V%T:2`G)7,G.B`E<RX`3F4@;6]R
M96T@:7IB<FES871I("5S+"!I;65N:6L@;FD@<')A>F5N+@!.92!M;W)E;2!I
M>F)R:7-A=&D@:6UE;FEK82X`3F4@;6]R96T@:7IB<FES871I(&EM96YI:V$N
M`$YE(&UO<F5M(&EZ8G)I<V%T:2!61E,@:6UE;FEK83H@)7,@`$YE(&UO<F5M
M(&EZ8G)I<V%T:2!D871O=&5K92XB)7,B+@!.92!M;W)E;2!I>F)R:7-A=&D@
M5D93(&1A=&]T96ME+@!.92!M;W)E;2!I>F)R:7-A=&D@9&%T;W1E:V4@(B5S
M(BX`3F4@;6]R96T@:7IB<FES871I(%9&4SH@)7,@`$YE(&UO<F5M(&1O;&_$
MC6ET:2!S961A;FIE9V$@:6UE;FEK82X`3F4@;6]R96T@:7IP:7-A=&D@<&]T
M<FIE;FEH('!O9')O8FYO<W1I+@!.92!M;W)E;2!S<')E;65N:71I(&YA("5S
M+@!.92!M;W)E;2!P<F5M86MN:71I(%9&4R!D871O=&5K92X`3F4@;6]R96T@
M;V1P<F5T:2!D871O=&5K92(E<R(N`$YE(&UO<F5M(&]D<')E=&D@5D93(&1A
M=&]T96ME(&YA;65N:F5N92!P:7-A;FIU+@!.92!M;W)E;2!O9'!R971I(%9&
M4R!D871O=&5K92X`3F4@;6]R96T@;V1P<F5T:2!Z9V_%H<2-96YE9V$@87)H
M:79A+@!.92!M;W)E;2!P<F5I;65N;W9A=&D@5D93(&1A=&]T96ME("5S+R5S
M+@!.92!M;W)E;2!P<F5I;65N;W9A=&D@5D93(&1A=&]T96ME+@!.92!M;W)E
M;2!P<F5B<F%T:2!61E,@;W-N;W9N96=A(&EM96YI:V$N`$YE(&UO<F5M('!R
M96EM96YO=F%T:2`E<R!V("5S.B!M87!A(,6^92!O<W1A:F$`3F4@;6]R96T@
M<')E:6UE;F]V871I(%9&4R!I;65N:6MA+@!.92!M;W)E;2!P<F5I;65N;W9A
M=&D@5D93(&EM96YI:V$Z("5S+@!.92!M;W)E;2!P<F5I;65N;W9A=&D@5D93
M(&1A=&]T96ME("(E<R(N`$YE(&UO<F5M('!R96EM96YO=F%T:2!61E,@9&%T
M;W1E:V4@)7,O)7,N`$YE(&UO<F5M('!R96EM96YO=F%T:2!61E,@9&%T;W1E
M:V4N`$YE(&UO<F5M('-P<F5M96YI=&D@;F$@)7,N`$YE(&UO<F5M('!R979E
M<W1I('1E9V$@5V]R9&]V96=A(&1O:W5M96YT82X`3F4@;6]R96T@<W!R;\6^
M:71I('!R;W-T;R]Z87-E9&5N;R!P;W-O9&]B:71E('IA("5S`$YE(&UO<F5M
M(&YA<&ES871I(%9&4R!D871O=&5K92`B)7,B+@!.92!M;W)E;2!N87!I<V%T
M:2!61E,@<&]D871K;W9N:6@@9&%T;W1E:RX`3F4@;6]R96T@;F%P:7-A=&D@
M5D93('!O9&%T:V]V;FEH(&1A=&]T96LN`$YE(&UO<F5M(&YA<&ES871I(%9&
M4R!D871O=&5K92P@:W9O=&$@8F\@<')E<V7%OF5N82X`4F%Z=F5L:F%V:2!S
M<')E;65M8F4`3F5P<FG$C6%K;W9A;B!O9&=O=F]R(',@<W1R9<6^;FEK82!V
M('!O=F5Z;W9A;FIU.@!.97!R:<2-86MO=F%N(&YE<')IQ(UA:V]V86X@;V1G
M;W9O<B!S=')EQ;YN:6MA('IA.@!.96EZ<&]L;FIE;F\`56YI:V]D("A55$8M
M."D`6F1R=<6^96YI(&%R86)S:VD@96UI<F%T:0!:9')UQ;YE;F\@:W)A;&IE
M<W1V;P!:9')UQ;YE;F4@9'+%OF%V90!:9')UQ;YE;F4@9'+%OF%V92!/=&]K
M:2!-:6YO<B!/=71L>6EN9P!%;F]T90!.97!O>FYA;F\`3F5P;WIN86YA(&%P
M:6US9VED("A)1"!!4$D@<W!O<F_$C6EL82DN`$YE<&]Z;F%N82!C;&EM<V=I
M9"`H240@=7!O<F%B;FG%H6ME9V$@<W!O<F_$C6EL82D`365S=&\@;FD@;F%S
M=&%V;&IE;F\N`$YE>FYA;F\@=7!O<F%B;FG%H6MO(&EM92!A;&D@9V5S;&\N
M`$)R97H@:6UE;F$`3F5P;V1P<G1A(')A>L6A:7)I=&5V`%!O<V]D;V)I`%!O
M<V]D;V)I("5S`%!O<V]D;V)L:F5N('5P;W)A8FYI:P!0;W-O9&]B;&IE;B`G
M)7,G+@!)>F)R:7-A;F$@<VMR:7!T82!Z82!N861G<F%D;FIO+@!.86QA9V%M
M`$YA;&_%OFD@;F$@<W1R9<6^;FEK('9S92!N86UE<W1I='9E;F4@9&%T;W1E
M:V4@87!L:6MA8VEJ+@!5<G5G=F%J`%5P;W)A8FD@<V5D86YJ:3H@)7,`57!O
M<F%B:2!34TP`57!O<F%B:2P@Q(UE(&IE('5P;W)A8FYIQ:%K;R!I;64O9V5S
M;&\@9')U9V'$C6YO(&]D($E-4U`@<W1R9<6^;FEK80!5<&]R86)N:6L`57!O
M<F%B;FEK("5S(&YI;6$@9&]S=&]P82!D;R`E<P!5<')A=F$@>F$@=7!O<F%B
M;FEK90!5<&]R86)N:<6A:V4@;F%S=&%V:71V90!296=I<W1R86-I:F$@=7!O
M<F%B;FEK80!296=I<W1R:7)A;FIE('5P;W)A8FYI:V]V(&IE(&YA('1E:B!S
M=')A;FD@;VYE;6]G;\2-96YO+@!.92!N86ID96T@=7!O<F%B;FEK;W8@<F'$
MC75N+@!5<&]R86)N:<6A:V\@:6UE`%5P;W)A8FYIQ:%K;R!I;64@(B5S(B!J
M92#%OF4@=B!U<&]R86)I+@!5<&]R86)N:<6A:V\@:6UE.B``57!O<F%B;FG%
MH6MO(&EM93H@`%5P;W)A8FYI:VDL(&MI('-O('8@<VES=&5M=3H`57IB96MI
M<W1A;@!61E,@:6UE;FEK(&YE(&]B<W1A:F$N`$]D<V]T;F]S=`!.86ID96YA
M('9E;&IA=FYA(&QO:V%C:6IA('IA:F5M83H`5F5L:F%V;F]S=`!6<F5D;F]S
M="!V(&UI;G5T86@@;V0@<V5D86H@9&%L:F4N`%9R961N;W-T('!R97-E9V$@
M;6%K<VEM86QN;R!D;VS%OFEN;R`E<RX`5G)E9&YO<W1I`%9R961N;W-T:2!O
M9"!K;V1E<B!I>F)I<F%T:0!686YU871U`%9A<FEA8FEL;F\`5F5N97IU96QA
M`%!R979E<FIA;FIE(&YE=7-P9<6A;F\@+2!M;V=OQ(UE(&IE(&)I;&\@<W!O
M<F_$C6EL;R!S<')E;65N:F5N;RX`4F%Z;&G$C6EC80!287IL:<2-:6-A`%IE
M;&\@=FES;VMO`%9I971N86T`5FEE=&YA;7-K:2`H5DE30TE)*0!0;V=L96H@
M)7,`4&]G;&5D(&YA('IU;F%N:F\@<W!L971N;R!S=')A;@!$979IQ:%K:2!O
M=&]K:2`H8G)I=&%N<VMI*0!$979IQ:%K:2!O=&]K:2`H6D1!*0!6:61L:FEV
M;W-T`%9I9&QJ:79O<W0Z`%9O9&%F;VX@271A;&EJ82!P<F5K;R!33510`$]0
M3UI/4DE,3P!/4$]:3U))3$\A(2$@4D_$C4Y/($]$4U1204Y)32!32U))4%1/
M($E:("5S+@!724X@<')E:V\@2%144`!786QL:7,@:6X@1G5T=6YA`$]P;WIO
M<FEL;P!-:0!6<F5M96YS:V$@;F%P;W9E9`!6<F5M96YS:VD@<&]D871K:2!S
M('-P;&5T80!W96%T:&5R+F-O;0!3<&QE=`!3<&QE=&YA('-T<F%N`%1E9&5N
M<VMO`$1O8G)O9&_%H6QI`$1O8G)O9&_%H6QI(&YA('-P;&5T;FEH('-T<F%N
M96@@<')O9W)A;6$@)7,`1&]B<F]D;\6A;&DL("5S`%IA:&]D;FD@*$E33RTX
M.#4Y+3$I`%IA:&]D;FD@*$E33RTX.#4Y+3$U`%IA:&]D;F$@4V%H87)A`$MA
M=&5R;R!A<&QI:V%C:6IO(&YA:B!P<FEK8<6^92`E<RP@<&\@<')I:F%V:3\`
M2V%KQ:%E;B!J92!L;\2-:6QN:2!Z;F%K/P!+86O%H65N(&IE(&YA=F5D96YI
M('IN86L_`%IE;6QJ979I9"`@5VAE<F5I<R!!=7-T<F%L:6$`4F%Z=F]J;F$@
M<W1O<&YJ80!+871E<F4@9&]D871K92!N86H@;VUO9V_$C6EM('!R:2!U<F5J
M86YJ=2!B97-E9&EL+@#%H&ER:6YA('8@96YO=&%H($-34P#%H&ER:6YA("5S
M(&UE;FEJ82!N82!L979I("AO9')A>FEL82!S92!B;R!O8B!N87-L961N:FD@
M<')I:F%V:2DZ`%=I:VD`5F5T97(Z(`!*=71R86YJ:2!V971E<CH@`$AI=')O
M<W0@=F5T<F$@=B!V;WIL:6@`5F5T97(Z`%9E=&5R.B``36]D<F]S=`!,:7-T
M82#%OF5L:F$`4VQUQ;YB80!3;'7%OF)E;FD@;F%S;&]V`%-L=<6^8F5N:2!T
M96QE9F]N`$YA<&'$C6YO(,6A=&5V:6QO('!O;&H@=B`E9"!V<G-T:2X@4')I
MQ(UA:V]V86YI:"`E9"P@;F%J9&5N:6@@)60N`$YA<&'$C6YO(,6A=&5V:6QO
M('!O;&HN(%!R:<2-86MO=F%N:6@@)60L(&YA:F1E;FEH("5D+@!.87!AQ(UE
M;B!O9&UI:R`E9"!M960@8G)A;FIE;2!D871O=&5K92!61E,N`%@M4F5F`%@U
M,#EV,R!O<VYO=FYA(&]M96II=&5V`%@U,#EV,R!287K%H6ER:F5N82!U<&]R
M86)A(&ML:G7$C6$`6#4P.78S(%IA9&5V82!A;'1E<FYA=&EV;F\@:6UE`%@U
M,#EV,R!+:G5E('IA(&1O;&]E:71I('IA9&5V;P!8-3`Y=C,@<F%ZQ:%I<FET
M978`3$P`3$Q,3`!986AO;R$@>F5M;&IE=FED`$QE=&YO`$IE;65N`$1A+@!$
M82P@<V4@<W1R:6YJ86TN`$YI;6%T92!D;W9O;&IE;FIA('5S='9A<FET:2!V
M9<2-(&MO="`E9"!B;&]K;W8N`$YI<W1E('!R:6IA=FQJ96YI`%8@:6UE;G4@
M;F4@;6]R971E(&EM971I('IN86MO=B`G7"<`3FES=&4@=G-T879I;&D@=F5L
M:F%V;F5G82!E;&5K=')O;G-K96=A(&YA<VQO=F$N`$UE9"!S<')E:F5T:6UI
M(&1A=&]T96MA;6D@;FES=&4@;WIN8<2-:6QI(&YO8F5N96=A('!O;&IA+"!K
M:2!S92!U:F5M82!S('!O;&II('8E<RX`0FEL:2!S=&4@;V1J879L:F5N:2X`
M5FYE<W1I(&UO<F%T92!V96QJ879N;R!G<VT@Q:%T979I;&MO+D1V;VQJ96YI
M('IN86MI('-O(&QE(,6A=&5V:6QK92!I;B`G*R<@:V]T('!R961P;VYA(&UE
M9&YA<F]D;FEM(,6A=&5I=FQK86TN`%9S=&%V:71I(&UO<F%T92!V96QJ879N
M;R!V<F5D;F]S="X`3V)L:6MO=F%T:2!M;W)A=&4@4VEG;G5P(&)A8VME;F0L
M(,6A96QE(&YA=&\@<V4@;&%H:V\@<')I:F%V;&IA=&4N`$]B;&EK;W9A=&D@
M;6]R871E(%9&4R!B86-K96YD+@!.86IP<F5J(&]P:<6A:71E('1EQ;YA=F4L
M(,6A96QE(&YA=&\@;&%H:V\@<&_%H6QJ971E('!O<F_$C6EL;R!O('1EQ;YA
M=F%H+@!)>F)R871I(&UO<F%T92!S=')EQ;YN:6LL(&MI(&)O(&EZ8G)I<V%N
M+@!.871A;L2-;F5J92!N879E9&ET92!U<&]R86)N:<6A:V\@:6UE+"!K:2!G
M82#%OF5L:71E(&EZ8G)I871I+@!.871A;L2-;F5J92!N879E9&ET92!U<&]R
M86)N:<6A:V\@:6UE+"!K:2!G82#%OF5L:71E(&]D<W1R86YI=&DN`$YA=&%N
MQ(UN96IE(&YA=F5D:71E('5P;W)A8FYIQ:%K;R!I;64L(&MI(&=A(,6^96QI
M=&4@9&]D871I+@!.871A;L2-;F5J92!N879E9&ET92!U<&]R86)N:<6A:V\@
M:6UE+"!K:2!G82#%OF5L:71E('!O<V]D;V)I=&DN`$YA=&%NQ(UN96IE(&YA
M=F5D:71E(&MA:B#%OF5L:71E(&YA<F5D:71I+@!6=&EP:V%J=&4@:6UE(&YO
M=F4@:V%T96=O<FEJ92X`5FYE<W1I(&UO<F%T92!I=&%L:6IA;G-K;R!T96QE
M9F]N<VMO(,6A=&5V:6QK;P!68<6A82!P<FEJ879I='9E;F$@<V5J82`E<R!J
M92!P;W1E:VQA+B!0<F]S:6UO+"!D82!S92!P;VYO=FYO('!R:6IA=FET92X`
M5F'%H2!E;&5K=')O;G-K:2!N87-L;W8Z`%9AQ:$@;F%S;&]V.@!68<6A:2!P
M;V1A=&MI`$]D('IAQ(UE=&MA("5S('-E:F4L('-E(&IE('9AQ:$@<W!L971N
M:2!N87-L;W8@<W!R96UE;FEL+B!)>B!V87)N;W-T;FEH<F%Z;&]G;W8L('-E
M(&UO<F%T92!P;VYO=FYO('!R:6IA=FET:2X`5F'%H64@:6UE.@!68<6A92!O
M>F%D:F4@>F$@;W9E<FIE;F4@;F4@<&]D<&ER82!D;V1A:F%N:F$@=7!O<F%B
M;FEK;W8N(,2-92#%OF5L:71E('5P;W)A8FET:4AO<F1E('IA(&%D;6EN:7-T
M<FER86YJ92!U<&]R86)N:<6A:VEH(')AQ(UU;F]V+"!M;W)A=&4@=7!O<F%B
M:71I(&1R=6=O(&]Z861J92!Z86]V97)J86YJ92X`5F'%H64@;WIA9&IE('IA
M(&]V97)J86YJ92!N92!P;V1P:7)A(&YA=F%J86YJ82!U<&]R86)N:6MO=B!A
M;&D@<&$@:F4@8FEL82!M;\6^;F]S="!O;F5M;V=OQ(UE;F$@:7H@9')U9VEH
M(')A>FQO9V]V+@!+8<6^92P@9&$@<V4@:F4@;V0@>F'$C65T:V$@)2!S96IE
M+"!V8<6A(&)R<VMA;&YI:R!S<')E;65N:6PN($EZ=F%R;F]S=&YI:"!R87IL
M;V=O=BP@<V4@;6]R871E('!O;F]V;F\@<')I:F%V:71I+@!68<6A(&)R<VMA
M;&YI:R!N92!P;V1P:7)A('1E(&9U;FMC:6IE+@!68<6A(&)R<VMA;&YI:R!N
M92!P;V1P:7)A(&1O;&_$C65N:6@@;6_%OFYO<W1I('!R:2!P<FEN=&%N:G4N
M(%IA('!R:6YT86YJ92!P<FET:7-N:71E($-O;G1R;VPO36_%OFYO<W1I("L@
M4"X`5F'%H2!T<F5N=71N:2#$C6%S;W9N:2!P87,Z`%9AQ:%A('!R:79Z971A
M(&ED96YT:71E=&$@:F4@8FEL82!S<')E;65N:F5N82X`4')I=GIE=&$@:61E
M;G1I=&5T80!68<6A92!I;64Z`%9AQ:%A('!R:6IA=F$@:F4@<&]T96ML82X`
M5F'%H64@;F]V92!G97-L;R!Z82`E<R!J93H@)7,`5F'%H64@;F%S=&%V:71V
M92!S;R!B:6QE('!O<V]D;V)L:F5N92!Z82#$C6%S('1E('-E:F4N`%9AQ:%E
M(&YA<W1A=FET=F4@<V\@8FEL92!P;W-O9&]B;&IE;F4N`%9AQ:%E(&=E<VQO
M(&IE(&)I;&\@<&]N87-T879L:F5N;RX`5F'%H64@9V5S;&\@:F4@8FEL;R!P
M;VYA<W1A=FQJ96YO+B!.82!V8<6A(&4M;F%S;&]V('-M;R!V86T@<&]S;&%L
M:2!N;W9O9V5S;&\@<R!K871E<FEM('-E('!R:6IA=FET92X`5F'%H64@9V5S
M;&\@:F4@<&]T96ML;RX`5F'%H6D@<&]S<F5D;FD@<W1R9<6^;FEK:3H`2G5G
M;W-L879I:F$`6F%I<@!:86UB:6IA`%II;6)A8G9E`%M3:W)I:B!C:71I<F%N
M;R!B97-E9&EL;UT`6W!O<F_$C6EL;R!O(&YA<&%K:5T`6U!O:V'%OFD@8VET
M:7)A;F\@8F5S961I;&\@+0!;4&]K8<6^:2!C:71I<F%N;R!B97-E9&EL;R`M
M("5S('9R<W1I8UT`6R5S('9R<W1I8V$@;V0@)7-=`%]#3$D`1')E=F5S;F$@
M`%]3:W5P:6YE`%!O;6_$C0!0<FEJ879A`$]D:F%V80!-;\6^;F]S=&D`1&]V
M;VQJ96YJ80!?3F%M97-T:0!?57!O<F%B;FEK:0!);65N:6L`3F%S;&]V;FEK
M(&YE>FYA;@!+;VQE9&%R`$UI<FYO`$YE(&UO<F5M('5S='9A<FET:2!I>FAO
M9&YE(&1A=&]T96ME`$YE(&UO<F5M(&]D<')E=&D@=FAO9&$`:VQI:VYI('1U
M`&YA<&%K82!V('5P;W)A8FYI('5K87IN92!V<G-T:6-E`$YA<&%K82!V(&MO
M;F9I9W5R86-I:FD`3F4@;F%J9&5M('IA:'1E=F%N92!S:7-T96US:V4@9&%T
M;W1E:V4`3F%P8<2-;F$@;V)L:6MA(&1A='5M80!5<F5D:0!.92!N86ID96T@
M=FYE<V5N:6@@<&]D871K;W8`4&%D879I;F4`9&%T;W1E:V$`:7H@)7,@*"5S
M*2!K("5S("5S`&=O<W1I;0!H.@!H:`!.97IN86YO(&EM92!G;W-T:71E;&IA
M`'1A:V]J`$UE9"!V<G-T:6-A;6D`5FAO9&YA+VEZ:&]D;F$@;F%P86MA`$EN
M=&5R;F$@;F%P86MA('8@<')O9W)A;74`=G)S=&EC90!M:VES;V9S(&YA<&%K
M82!K;V1E("5D+"!M960@<')I<')A=FQJ86YJ96T@25-/+@!M;0!I;64`;FD@
M9&]K;V[$C6%N;P#%H64@;FD@<&]D<')T80!"96QEQ;YK80!$;W9O;&IE;FIE
M(&IE('IA=G)N:F5N;RX`;F%P86MA('8@;V1D;&IE;F5M('!R;W1O:V]L=0!V
M>FAA:F%J;\2-90!397)V:7,@;FD@;F$@=F]L:F\N`%!O:V'%OFD@<F%Z;&EK
M90!S;7,R96UA:6P@<')E:V\@2%144`!S<P!3=&%B:6QN;P!3:7-T96US:V$@
M;F%P86MA+@!397IN86T@;W!R879I;"X`>F'$C6%S;F$@;V1P;W9E9`!Z82!P
M;W1R9&ET978@=G1I<&MA:G1E(&=E<VQO(&1V86MR870`96YO=&5N`&)R97H@
M:6UE;F$`27IB:7)A('5P;W)A8FYI:V$@`'8@2V%R=&EC80!W.@!W96%T:&5R
M+F-O;0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]S;%]322]H96QP+GAM;```````
M````````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S,R,"`Q,#4Q
M-30S,S<T,B`P,C$T-3<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]X;6P@=F5R<VEO;CTB,2XP(C\^"CPA+2T@)$AO<F1E
M.B!H;W)D92]L;V-A;&4O<VQ?4TDO:&5L<"YX;6PL=B`Q+C(@,C`P-"\P-2\R
M-R`R,#HR,CHQ,R!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB
M<W5M;6%R>2(@<W1A=&4](FYE=R(^"CQT:71L93Y4:&4@4&]R=&%L(%!A9V4\
M+W1I=&QE/@H@/'!A<F$^"B`@5&AI<R!P;W)T86P@<&%G92!P<F]V:61E<R!A
M('%U:6-K('-U;6UA<GD@;V8@86QL('EO=7(@:6UP;W)T86YT"B`@:6YF;W)M
M871I;VXN($9O<B!E>&%M<&QE+"!I="!M:6=H="!S:&]W(&AO=R!M86YY(&YE
M=R!E+6UA:6P@;65S<V%G97,@>6]U"B`@:&%V92!I;B!Y;W5R($E.0D]8+"!U
M<&-O;6EN9R!E=F5N=',@;VX@>6]U<B!C86QE;F1A<BP@=&%S:W,@;VX@>6]U
M<B!T;RUD;PH@(&QI<W0L(&AE861L:6YE<R!F<F]M('-E;&5C=&5D(&YE=W,@
M<V5R=FEC97,L(&%N9"!S;R!O;BX@($UA;GD@;V8@=&AE<V4*("!S=6UM87)I
M97,@=VEL;"!C;VYT86EN('%U:6-K('-H;W)T8W5T<R!T;R!C;VUM;VX@9G5N
M8W1I;VYS+"!S=6-H(&%S"B`@8V]M<&]S:6YG(&$@;F5W(&UA:6P@;65S<V%G
M92P@8W)E871I;F<@82!N97<@8V%L96YD87(@979E;G0@;W(@=&%S:RP@971C
M+@H@/"]P87)A/@H@/'!A<F$^"B`@5&AE(&-O;G1E;G1S(&]F('1H:7,@<&]R
M=&%L('!A9V4@87)E(&-U<W1O;6EZ86)L92!V:6$@=&AE($QA>6]U="!B=71T
M;VXN"B`@1F]R(&5X86UP;&4L('EO=2!C86X@8VAO;W-E('=H:6-H(&ET96US
M('1O(&EN8VQU9&4@;VX@=&AI<R!P;W)T86P@<&%G92!A<PH@('=E;&P@87,@
M:6X@=VAI8V@@;W)D97(@=&AE>2!A<F4@<VAO=VXN"B`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)N879B87(B('-T871E/2)N97<B/@H\=&ET;&4^
M5&AE($%P<&QI8V%T:6]N($YA=FEG871I;VX@0F%R/"]T:71L93X*(#QP87)A
M/@H@($%T('1H92!L969T(&AA;F0@<VED92!O9B!T:&4@=V5B('!A9V4@:7,@
M=&AE(&%P<&QI8V%T:6]N(&YA=FEG871I;VX@8F%R+@H@($-L:6-K(&]N('1H
M92!I8V]N<R!O;B!T:&ES(&YA=FEG871I;VX@8F%R('1O('%U:6-K;'D@86YD
M(&5A<VEL>2!S=VET8V@*("!B971W965N('1H92!A=F%I;&%B;&4@87!P;&EC
M871I;VYS+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M
M9&]?;6%I;G1E;F%N8V4B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E
M<F5N8V5S.B!-86EN=&5N86YC93H@1&\@36%I;G1E;F%N8V4\+W1I=&QE/@H@
M("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!P97)F;W)M(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6XL(&-H96-K('1H:7,@8F]X
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M8V]N
M9FER;5]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E
M9F5R96YC97,Z($UA:6YT96YA;F-E.B!#;VYF:7)M($UA:6YT96YA;F-E/"]T
M:71L93X*("`@(#QP87)A/@H@("`@268@>6]U('=O=6QD(&QI:V4@=&\@8V]N
M9FER;2!A;&P@;6%I;G1E;F%N8V4@=&%S:W,@8F5F;W)E('1H97D@87)E(')U
M;BP@8VAE8VL@=&AI<R!B;W@N($EF(&QE9G0@=6YC:&5C:V5D+"!A;&P@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<R!T:&%T(&YE960@=&\@8F4@<G5N('=I;&P@
M8F4@<&5R9F]R;65D(&%U=&]M871I8V%L;'D@=VET:"!N;R!C:&%N8V4@=&\@
M8V%N8V5L(&]N(&QO9VEN+@H@("`@/"]P87)A/@H\+V5N=')Y/@H\+VAE;'`^
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L;V-A;&4O<W9?4T4`````````````````````````
M````````````````````````````````````````````````````````````
M,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W
M-#(@,#$W-S,V`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]S=E]312],
M0U]-15-304=%4P``````````````````````````````````````````````
M```````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#`P,"`Q,#4Q-30S,S<T,B`P,C$U,C,`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&]C86QE+W-V7U-%+TQ#7TU%4U-!1T53+VAO<F1E+FUO````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P-#$S-30V(#$P-3$U-#,S-S0R(#`R,S(U-0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````#>$@25
M`````.0'```<````/#\``(4*``!<?@```````'"H``!(````<:@```X```"Z
MJ```#P```,FH```,````V:@```T```#FJ```"````/2H```+````_:@```P`
M```)J0``!````!:I```8````&ZD``!L````TJ0``+0```%"I```=````?JD`
M`"0```"<J0``*0```,&I```9````ZZD``"8````%J@``#````"RJ```D````
M.:H```\```!>J@``"P```&ZJ```.````>JH```4```")J@``*````(^J```(
M````N*H```H```#!J@``%0```,RJ```2````XJH```L```#UJ@``%`````&K
M```F````%JL``"<````]JP``)@```&6K``"%````C*L```X````2K```"@``
M`"&L```-````+*P``"<````ZK```(````&*L```.````@ZP``!<```"2K```
M(@```*JL```U````S:P``!$````#K0``#0```!6M```,````(ZT```T````P
MK0``!@```#ZM``"4````1:T```H```#:K0``#P```.6M```8````]:T```P`
M```.K@``#@```!NN```.````*JX```@````YK@``"0```$*N```N````3*X`
M`!H```![K@``,@```):N```X````R:X``%0````"KP``40```%>O``!:````
MJ:\``%<````$L```-````%RP```)````D;````T```";L```!P```*FP```*
M````L;````\```"\L```!0```,RP```&````TK```!$```#9L```"````.NP
M```)````]+````D```#^L```#@````BQ```(````%[$``"4````@L0``(```
M`$:Q```3````9[$``!````![L0``#P```(RQ```*````G+$```<```"GL0``
M`P```*^Q```&````L[$```\```"ZL0``%````,JQ```)````W[$```T```#I
ML0``$@```/>Q```9````"K(``!X````DL@``#P```$.R```*````4[(```\`
M``!>L@``"````&ZR```D````=[(``!<```"<L@``%````+2R```6````R;(`
M``@```#@L@``3@```.FR```M````.+,``!D```!FLP``!P```("S```,````
MB+,``"P```"5LP``#@```,*S```#````T;,```L```#5LP``!P```.&S```'
M````Z;,```4```#QLP``!0```/>S```*````_;,```,````(M```%P````RT
M```*````)+0```\````OM```#@```#^T```8````3K0``",```!GM```#@``
M`(NT```4````FK0``!<```"OM```%P```,>T```7````W[0``!,```#WM```
M#P````NU```.````&[4``"D````JM0``'P```%2U```=````=+4```<```"2
MM0``!@```)JU```(````H;4```\```"JM0``!@```+JU```*````P;4``!,`
M``#,M0``"P```."U```0````[+4``!4```#]M0``%0```!.V```'````*;8`
M`!`````QM@``!0```$*V```5````2+8``!$```!>M@``#````'"V```[````
M?;8``#@```"YM@``"0```/*V```'````_+8``!0````$MP```P```!FW```%
M````';<``!`````CMP``"0```#2W```3````/K<``#D```!2MP``$@```(RW
M```Y````G[<``"<```#9MP``+`````&X```J````+K@``"4```!9N```"0``
M`'^X```*````B;@```8```"4N```"0```)NX```'````I;@``"\```"MN```
M-P```-VX```N````%;D``%4```!$N0``+0```)JY```M````R+D``#T```#V
MN0``/P```#2Z```M````=+H``$````"BN@``(P```..Z```C````![L``$``
M```KNP``+0```&R[```S````FKL``"4```#.NP``%0```/2[```9````"KP`
M`"D````DO```)````$Z\```H````<[P``!$```"<O```$0```*Z\```*````
MP+P```0```#+O```#````-"\```*````W;P``!````#HO```%@```/F\```6
M````$+T```<````GO0``!P```"^]```4````-[T```H```!,O0``"````%>]
M```(````8+T```@```!IO0``!@```'*]```G````>;T```@```"AO0``!P``
M`*J]```'````LKT```8```"ZO0``!0```,&]```'````Q[T```8```#/O0``
M"````-:]```I````W[T```X````)O@``"@```!B^```)````([X```X````M
MO@``!````#R^```'````0;X```D```!)O@``!@```%.^```1````6KX```<`
M``!LO@``%@```'2^```$````B[X```@```"0O@``!@```)F^```-````H+X`
M``8```"NO@``'@```+6^```%````U+X``!$```#:O@``"````.R^```-````
M];X```P````#OP``#````!"_```'````';\```,````EOP```P```"F_```7
M````+;\``!,```!%OP``'0```%F_```(````=[\```0```"`OP``"````(6_
M```(````CK\```H```"7OP``00```**_```:````Y+\``"L```#_OP``(```
M`"O````5````3,````8```!BP```!@```&G````5````<,```!@```"&P```
M(@```)_````N````PL```!T```#QP```(0````_!```I````,<$```H```!;
MP0``!P```&;!```'````;L$``!4```!VP0``#@```(S!```*````F\$```\`
M``"FP0``#0```+;!```/````Q,$```T```#4P0``"0```.+!```4````[,$`
M``8````!P@``&`````C"```=````(<(``!,````_P@``$0```%/"```4````
M9<(```0```!ZP@``#````'_"```&````C,(``!0```"3P@``%P```*C"``!4
M````P,(``&0````5PP``!````'K#```.````?\,``$0```".PP``!0```-/#
M```%````V<,``!L```#?PP``&@```/O#```3````%L0``!$````JQ```$0``
M`#S$```1````3L0``!P```!@Q```*@```'W$```0````J,0``"$```"YQ```
M!0```-O$```3````X<0```L```#UQ```$@````'%```*````%,4```\````?
MQ0``#0```"_%```1````/<4``!,```!/Q0``#````&/%```&````<,4```P`
M``!WQ0``!@```(3%```7````B\4``!````"CQ0``$0```+3%```(````QL4`
M``4```#/Q0``#````-7%```0````XL4```4```#SQ0``#0```/G%```&````
M!\8```<````.Q@``#0```!;&```'````),8```L````LQ@``!P```#C&```'
M````0,8```D```!(Q@``%````%+&```)````9\8```D```!QQ@``"@```'O&
M```9````AL8``#T```"@Q@``'0```-[&```,````_,8``!`````)QP``!0``
M`!K'```E````(,<``!(```!&QP``$P```%G'```K````;<<``#L```"9QP``
M(````-7'```(````]L<``#8```#_QP``(0```#;(```0````6,@```@```!I
MR```#````'+(```&````?\@```0```"&R```#P```(O(```.````F\@```H`
M``"JR```!P```+7(```*````O<@```T```#(R```'@```-;(```?````]<@`
M`!L````5R0``'````#')```A````3LD``!X```!PR0``&0```(_)```>````
MJ<D``!L```#(R0``(0```.3)```N````!LH``"8````UR@``&P```%S*```<
M````>,H``!X```"5R@``'````+3*```F````T<H``"L```#XR@``,P```"3+
M```F````6,L``"L```!_RP``.````*O+```=````Y,L``!T````"S```%0``
M`"#,```5````-LP``"\```!,S```(````'S,```2````G<P``"````"PS```
M*0```-',```>````^\P``!X````:S0``(````#G-```2````6LT``*(```!M
MS0``%@```!#.```C````)\X``"@```!+S@``*0```'3.```H````GLX``!\`
M``#'S@``%0```.?.```5````_<X``"`````3SP``)0```#3/```H````6L\`
M`"T```"#SP``,````+'/``"2````XL\``"$```!UT```%@```)?0```6````
MKM```!P```#%T```)@```.+0```J````"=$``$$````TT0``1````';1```,
M````N]$```<```#(T0``!P```-#1```&````V-$```T```#?T0``$````.W1
M```2````_M$``!,````1T@``$@```"72```'````.-(```0```!`T@``$```
M`$72```0````5M(```P```!GT@``#@```'32```-````@](```\```"1T@``
M$P```*'2```-````M=(``"@```##T@```P```.S2```-````\-(```8```#^
MT@``$0````73```7````%],``!L````OTP``#@```$O3```"````6M,```4`
M``!=TP``$````&/3```/````=-,```0```"$TP``#0```(G3```.````E],`
M``,```"FTP``#@```*K3```(````N=,```\```#"TP``"````-+3```/````
MV],```<```#KTP``#0```//3```0`````=0```T````2U```"P```"#4```1
M````+-0```D````^U```!@```$C4```+````3]0```P```!;U```"@```&C4
M```1````<]0``!D```"%U```"P```)_4```-````J]0``"(```"YU```#P``
M`-S4```;````[-0``#0````(U0``"@```#W5```8````2-4``!(```!AU0``
M&0```'35```6````CM4``!````"EU0``(@```+;5```-````V=4```<```#G
MU0``#````._5```F````_-4``!0````CU@``"P```#C6```B````1-8``"\`
M``!GU@``"P```)?6```)````H]8``!D```"MU@``"P```,?6```7````T]8`
M`!<```#KU@``"0````/7```6````#=<```\````DUP``&0```#37```6````
M3M<```X```!EUP``!P```'37```(````?-<```T```"%UP``)@```)/7``!#
M````NM<``!(```#^UP``'P```!'8```(````,=@```L````ZV```+P```$;8
M```.````=M@```4```"%V```!@```(O8``!%````DM@```,```#8V```!P``
M`-S8```$````Y-@```H```#IV```"@```/38```/````_]@``!`````/V0``
M%P```"#9```1````.-D``!D```!*V0``%P```&39```)````?-D```4```"&
MV0``"P```(S9```*````F-D```(```"CV0``!0```*;9```-````K-D``!L`
M``"ZV0``%P```-;9```4````[MD```D````#V@``#@````W:```-````'-H`
M`!(````JV@```P```#W:```(````0=H```X```!*V@``&````%G:```8````
M<MH```4```"+V@``&````)':```>````JMH``!L```#)V@``&0```.7:```8
M````_]H``!L````8VP``$P```#3;```3````2-L```<```!<VP``"````&3;
M```&````;=L```8```!TVP``$````'O;```/````C-L``!````"<VP``#P``
M`*W;```+````O=L```\```#)VP``#````-G;```/````YML```<```#VVP``
M!@```/[;```.````!=P```P````4W```*````"'<```/````2MP```@```!:
MW```"````&/<```3````;-P``!X```"`W```(0```)_<```@````P=P``!D`
M``#BW```%P```/S<```E````%-T``!<````ZW0``%@```%+=```$````:=T`
M`!L```!NW0``#0```(K=```,````F-T```,```"EW0``!0```*G=```(````
MK]T```H```"XW0``#````,/=```+````T-T``!````#<W0``#````.W=```.
M````^MT```L````)W@``!````!7>```$````&MX``!,````?W@``%````#/>
M```,````2-X```D```!5W@``#@```%_>```+````;MX``!L```!ZW@``!P``
M`);>```'````GMX```H```"FW@``#0```+'>```8````O]X```H```#8W@``
M!````./>```F````Z-X```X````/WP``?````![?```5````F]\```4```"Q
MWP``!P```+??```,````O]\```@```#,WP``"@```-7?```&````X-\```@`
M``#GWP```@```/#?```&````\]\```8```#ZWP``%`````'@```5````%N``
M``\````LX```$0```#S@```:````3N````T```!IX```$````'?@```;````
MB.````0```"DX```"0```*G@```0````L^````D```#$X```"0```,[@```%
M````V.```!H```#>X```"````/G@```&`````N$``!D````)X0``#@```"/A
M```'````,N$```<````ZX0``!0```$+A```)````2.$```H```!2X0``#@``
M`%WA```"````;.$```8```!OX0``"P```';A```-````@N$```D```"0X0``
M!@```)KA```%````H>$```D```"GX0``!P```+'A```$````N>$``!0```"^
MX0``0@```-/A```E````%N(``"4````\X@``!@```&+B```$````:>(```D`
M``!NX@``"````'CB```1````@>(```X```"3X@``"0```*+B```&````K.(`
M``T```"SX@``!@```,'B```$````R.(``#D```#-X@``/0````?C```Z````
M1>,``!X```"`XP``!0```)_C```.````I>,```0```"TXP``!@```+GC```'
M````P.,``"$```#(XP``#0```.KC```5````^.,```8````.Y```$@```!7D
M```$````*.0``!$````MY```!@```#_D```*````1N0``"(```!1Y```!```
M`'3D```%````>>0```0```!_Y```#````(3D```.````D>0```H```"@Y```
M"````*OD```)````M.0```4```"^Y```.@```,3D```P````_^0``#4````P
MY0``*0```&;E``!'````D.4``#@```#8Y0``*0```!'F```_````.^8``"X`
M``![Y@``+0```*KF```?````V.8```\```#XY@``$@````CG```+````&^<`
M`"8````GYP``*0```$[G```D````>.<``"8```"=YP``"````,3G```*````
MS><```D```#8YP``!P```.+G```@````ZN<``"`````+Z```)@```"SH```*
M````4^@``!D```!>Z```*0```'CH```6````HN@``!(```"YZ```!P```,SH
M```*````U.@```P```#?Z```#P```.SH```0````_.@``$`````-Z0``<```
M`$[I``!F````O^D```X````FZ@``"0```#7J```*````/^H``!(```!*Z@``
M$P```%WJ```,````<>H```8```!^Z@``#P```(7J```2````E>H``!````"H
MZ@``"@```+GJ```1````Q.H``!P```#6Z@``(P```//J``!J````%^L```\`
M``""ZP``!0```)+K```0````F.L```D```"IZP``!````+/K```+````N.L`
M`"````#$ZP``%````.7K```,````^NL```P````'[```#P```!3L```5````
M).P``"D````Z[```*@```&3L```F````C^P``"<```"V[```*0```-[L```J
M````".T``!D````S[0``$0```$WM```2````7^T``!,```!R[0``%````(;M
M```/````F^T``!8```"K[0``%P```,+M```0````VNT``!$```#K[0``-```
M`/WM```3````,NX``!(```!&[@``-0```%GN```4````C^X```<```"D[@``
M#````*SN```K````N>X``"````#E[@``$`````;O```4````%^\``!$````L
M[P``%P```#[O```<````5N\``!,```!S[P``%````(?O```:````G.\``!$`
M``"W[P``&@```,GO```>````Y.\``!H````#\```$P```![P```5````,O``
M`!$```!(\```%P```%KP```4````<O```!<```"'\```%0```)_P```)````
MM?```!````"_\```&0```-#P```$````ZO````<```#O\```"P```/?P```1
M`````_$```8````5\0``!@```!SQ```&````(_$```4````J\0``!P```##Q
M```'````./$```4```!`\0``%@```$;Q```&````7?$```8```!D\0``!```
M`&OQ```$````</$```<```!U\0``#@```'WQ```,````C/$```P```"9\0``
M#0```*;Q```%````M/$``"@```"Z\0``#````./Q```/````\/$```H`````
M\@``"`````OR```)````%/(``"L````>\@``!````$KR```(````3_(```4`
M``!8\@``)@```%[R```2````A?(```\```"8\@``!@```*CR```*````K_(`
M``<```"Z\@``"````,+R```@````R_(```D```#L\@``%````/;R```,````
M"_,```T````8\P``#@```";S```6````-?,``!$```!,\P``!@```%[S```(
M````9?,```,```!N\P``!@```'+S```9````>?,```<```"3\P``!````)OS
M```+````H/,```L```"L\P``!P```+CS```%````P/,```<```#&\P``%@``
M`,[S```-````Y?,```H```#S\P``#0```/[S```*````#/0``!`````7]```
M#P```"CT```1````./0``!<```!*]```"@```&+T```1````;?0```@```!_
M]```!````(CT```/````C?0``#H```"=]```!0```-CT```,````WO0``!X`
M``#K]```#@````KU```0````&?4```L````J]0``#````#;U```)````0_4`
M``<```!-]0``"@```%7U```)````8/4```X```!J]0``$````'GU```;````
MBO4``!@```"F]0``&@```+_U```*````VO4```D```#E]0``"@```._U```,
M````^O4```\````']@``"````!?V```&````(/8```<````G]@``!0```"_V
M```+````-?8``$<```!!]@``#0```(GV```)````E_8```0```"A]@```P``
M`*;V```3````JO8``!,```"^]@``$P```-+V```&````YO8```L```#M]@``
M"@```/GV```"````!/<```0````']P``)0````SW```#````,O<```4````V
M]P``*@```#SW```*````9_<```4```!R]P``!````'CW```*````??<```T`
M``"(]P``!@```);W```(````G?<```@```"F]P``!````*_W```%````M/<`
M`&@```"Z]P``"0```"/X```,````+?@``!`````Z^```!0```$OX```&````
M4?@``!L```!8^```+P```'3X```0````I/@```H```"U^```#P```,#X```*
M````T/@```D```#;^```$P```.7X```;````^?@``!@````5^0``%P```"[Y
M```?````1OD```X```!F^0```P```'7Y```'````>?D```@```"!^0``%```
M`(KY```3````G_D``!````"S^0``#0```,3Y```.````TOD``!8```#A^0``
M!P```/CY```*`````/H```L````+^@``!P```!?Z``!1````'_H``!````!Q
M^@``#````(+Z```-````C_H``!H```"=^@``2@```+CZ```9`````_L```8`
M```=^P``&@```"3[```E````/_L```8```!E^P``!@```&S[```?````<_L`
M``8```"3^P``"0```)K[```8````I/L``!<```"]^P``*````-7[```&````
M_OL```T````%_```(@```!/\``!7````-OP``!,```"._```(P```*+\```3
M````QOP```(```#:_```"P```-W\```(````Z?P```T```#R_```"@````#]
M```'````"_T``!0````3_0``!@```"C]```(````+_T```X````X_0``!P``
M`$?]```*````3_T```L```!:_0``,@```&;]```'````F?T```P```"A_0``
M#0```*[]```,````O/T```D```#)_0``"0```-/]```*````W?T```<```#H
M_0``"0```/#]```'````^OT```H````"_@``!P````W^```;````%?X```\`
M```Q_@``$@```$'^```*````5/X``!8```!?_@``"0```';^```0````@/X`
M``<```"1_@``$@```)G^```$````K/X```<```"Q_@``!0```+G^```$````
MO_X```P```#$_@``!0```-'^```+````U_X``!0```#C_@``$0```/C^```4
M````"O\``!<````?_P``&````#?_```<````4/\``!D```!M_P``!P```(?_
M```%````C_\```T```"5_P``#````*/_```1````L/\```@```#"_P``%P``
M`,O_```+````X_\```P```#O_P``'P```/S_```:````'``!`!,````W``$`
M!````$L``0`*````4``!``0```!;``$`#0```&```0`,````;@`!``4```![
M``$`"0```($``0`%````BP`!``<```"1``$`!0```)D``0`$````GP`!``(`
M``"D``$`.````*<``0`L````X``!`!(````-`0$`*0```"`!`0`R````2@$!
M``H```!]`0$`+````(@!`0`N````M0$!`#,```#D`0$`,P```!@"`0`X````
M3`(!``\```"%`@$`%````)4"`0`8````J@(!`!````##`@$`#P```-0"`0`3
M````Y`(!`!4```#X`@$`%`````X#`0`2````(P,!`!0````V`P$`%0```$L#
M`0`M````80,!`"T```"/`P$`,0```+T#`0`N````[P,!`"\````>!`$`+```
M`$X$`0`3````>P0!``P```"/!`$`#0```)P$`0`(````J@0!`!<```"S!`$`
M"````,L$`0`,````U`0!`"L```#A!`$`(0````T%`0`:````+P4!``D```!*
M!0$`10```%0%`0!!````F@4!``\```#<!0$`!````.P%`0`3````\04!``X`
M```%!@$`$P```!0&`0`8````*`8!``8```!!!@$`"0```$@&`0`*````4@8!
M``\```!=!@$`$````&T&`0`'````?@8!``X```"&!@$`!0```)4&`0`;````
MFP8!``8```"W!@$`"````+X&`0`&````QP8!`!0```#.!@$`$0```.,&`0`.
M````]08!`#@````$!P$``@```#T'`0`&````0`<!``X```!'!P$`!0```%8'
M`0`'````7`<!``X```!D!P$`!@```','`0`H````>@<!``P```"C!P$`'```
M`+`'`0`$````S0<!`"D```#2!P$`%P```/P'`0`?````%`@!`%P````T"`$`
M%````)$(`0`^````I@@!`!\```#E"`$`$`````4)`0`4````%@D!``<````K
M"0$`#@```#,)`0`,````0@D!``P```!/"0$`$P```%P)`0`*````<`D!`!T`
M``!["0$`&0```)D)`0`%````LPD!`!$```"Y"0$`$0```,L)`0`D````W0D!
M`!(````""@$`%0```!4*`0`2````*PH!``X````^"@$`&0```$T*`0`(````
M9PH!``D```!P"@$`#0```'H*`0`'````B`H!``H```"0"@$`!P```)L*`0`/
M````HPH!``8```"S"@$`"P```+H*`0`:````Q@H!``H```#A"@$`!P```.P*
M`0`(````]`H!``4```#]"@$`'P````,+`0`&````(PL!`!`````J"P$`"```
M`#L+`0`-````1`L!``@```!2"P$`'@```%L+`0`2````>@L!`"P```"-"P$`
M&@```+H+`0`)````U0L!``H```#?"P$`%0```.H+`0`%``````P!`!0````&
M#`$`!````!L,`0`0````(`P!``8````Q#`$`!P```#@,`0`>````0`P!`"@`
M``!?#`$`"@```(@,`0`<````DPP!`!$```"P#`$`"P```,(,`0`:````S@P!
M`!0```#I#`$`!````/X,`0`$`````PT!``L````(#0$`!0```!0-`0`&````
M&@T!``@````A#0$`!@```"H-`0`*````,0T!`!L````\#0$`-````%@-`0`T
M````C0T!`"````#"#0$`*0```.,-`0`@````#0X!`$$````N#@$`&@```'`.
M`0`H````BPX!`"D```"T#@$`40```-X.`0!0````,`\!`%<```"!#P$`+```
M`-D/`0`B````!A`!``8````I$`$`"````#`0`0`%````.1`!``@````_$`$`
M&0```$@0`0`9````8A`!`"H```!\$`$`"````*<0`0`C````L!`!`!D```#4
M$`$`+@```.X0`0`T````'1$!``@```!2$0$`%P```%L1`0`*````<Q$!``<`
M``!^$0$`(0```(81`0`0````J!$!``X```"Y$0$`"P```,@1`0`'````U!$!
M`!,```#<$0$`"````/`1`0`+````^1$!``H````%$@$`%````!`2`0`/````
M)1(!`#(````U$@$`"P```&@2`0`.````=!(!``4```"#$@$`!0```(D2`0`%
M````CQ(!`!<```"5$@$`#P```*T2`0`$````O1(!``H```#"$@$`"0```,T2
M`0`+````UQ(!``T```#C$@$`#````/$2`0`.````_A(!``4````-$P$`!```
M`!,3`0`-````&!,!`#(````F$P$`10```%D3`0`7````GQ,!``<```"W$P$`
M'@```+\3`0`4````WA,!``4```#S$P$`%````/D3`0`&````#A0!``<````5
M%`$`(P```!T4`0`.````010!`"H```!0%`$`!@```'L4`0`,````@A0!``T`
M``"/%`$`$0```)T4`0`7````KQ0!``L```#'%`$`-@```-,4`0`*````"A4!
M`"(````5%0$`"P```#@5`0`/````1!4!``L```!4%0$`(````&`5`0`G````
M@14!`"L```"I%0$`"0```-45`0`R````WQ4!`"4````2%@$`,````#@6`0`Q
M````:18!`"T```";%@$`#@```,D6`0`4````V!8!``4```#M%@$`#@```/,6
M`0`3`````A<!`!(````6%P$`!P```"D7`0`1````,1<!`!,```!#%P$`!P``
M`%<7`0`4````7Q<!`!@```!T%P$`!P```(T7`0`%````E1<!``P```";%P$`
M#````*@7`0`2````M1<!``0```#(%P$`!P```,T7`0`*````U1<!``L```#@
M%P$`#````.P7`0`.````^1<!``X````(&`$`!0```!<8`0`%````'1@!`"X`
M```C&`$`)@```%(8`0`C````>1@!``,```"=&`$`$@```*$8`0`&````M!@!
M`!X```"[&`$`&````-H8`0`E````\Q@!``T````9&0$`"0```"<9`0`?````
M,1D!``,```!1&0$`!P```%49`0`*````71D!``(```!H&0$`#````&L9`0`5
M````>!D!``L```".&0$`&0```)H9`0`@````M!D!`!(```#5&0$`!0```.@9
M`0`*````[AD!`!4```#Y&0$`$@````\:`0`,````(AH!``0````O&@$`"0``
M`#0:`0`'````/AH!``P```!&&@$`4@```%,:`0`7````IAH!`"0```"^&@$`
M$@```.,:`0`'````]AH!``8```#^&@$`#@````4;`0`,````%!L!``T````A
M&P$`%0```"\;`0`2````11L!``\```!8&P$`%````&@;`0`*````?1L!`!L`
M``"(&P$`$````*0;`0`+````M1L!`&D```#!&P$`&@```"L<`0`7````1AP!
M`"<```!>'`$`&@```(8<`0`7````H1P!`!L```"Y'`$`&0```-4<`0`?````
M[QP!`!<````/'0$`$P```"<=`0`(````.QT!``<```!$'0$`"````$P=`0`)
M````51T!`!4```!?'0$`#0```'4=`0`C````@QT!``T```"G'0$`$P```+4=
M`0`(````R1T!``,```#2'0$`1@```-8=`0`_````'1X!`#<```!='@$`5P``
M`)4>`0`%````[1X!`!\```#S'@$`+P```!,?`0`*````0Q\!``@```!.'P$`
M#0```%<?`0`M````91\!``0```"3'P$`3P```)@?`0`E````Z!\!`!P````.
M(`$`"P```"L@`0`?````-R`!`!T```!7(`$`)0```'4@`0`@````FR`!`"0`
M``"\(`$`(````.$@`0`+`````B$!``<````.(0$`#0```!8A`0`,````)"$!
M`!<````Q(0$`!@```$DA`0`Y````4"$!``P```"*(0$`!P```)<A`0`)````
MGR$!`!,```"I(0$`!P```+TA`0`)````Q2$!``0```#/(0$`$````-0A`0`(
M````Y2$!``@```#N(0$`!````/<A`0`+````_"$!``P````((@$`$@```!4B
M`0`1````*"(!``P````Z(@$`&@```$<B`0`/````8B(!``<```!R(@$`#0``
M`'HB`0`4````B"(!``X```"=(@$`#````*PB`0`L````N2(!`!,```#F(@$`
M'````/HB`0`H````%R,!``8```!`(P$`!P```$<C`0`3````3R,!``4```!C
M(P$`!````&DC`0`7````;B,!``H```"&(P$`#````)$C`0`)````GB,!``8`
M``"H(P$`"0```*\C`0`(````N2,!``D```#"(P$`!0```,PC`0`*````TB,!
M`!$```#=(P$`!@```.\C`0`.````]B,!``X````%)`$`#0```!0D`0`+````
M(B0!`!T````N)`$`"P```$PD`0`"````6"0!`!P```!;)`$`!P```'@D`0`&
M````@"0!`&0```"')`$`"0```.PD`0`'````]B0!`"8```#^)`$`.````"4E
M`0`:````7B4!`"H```!Y)0$`.P```*0E`0`H````X"4!`#0````))@$`&0``
M`#XF`0`5````6"8!``4```!N)@$`!P```'0F`0`(````?"8!``<```"%)@$`
M!0```(TF`0`'````DR8!``X```";)@$`"0```*HF`0`&````M"8!``@```"[
M)@$`"P```,0F`0`'````T"8!``@```#8)@$`!P```.$F`0`6````Z28!``D`
M````)P$`!@````HG`0`+````$2<!`!`````=)P$`!@```"XG`0`<````-2<!
M`!0```!2)P$`!P```&<G`0`1````;R<!``@```"!)P$`#@```(HG`0`(````
MF2<!``4```"B)P$`$````*@G`0`)````N2<!`!````##)P$`!@```-0G`0`9
M````VR<!``H```#U)P$`'``````H`0`'````'2@!``4````E*`$`!````"LH
M`0`0````,"@!`!0```!!*`$`"P```%8H`0`-````8B@!`"@```!P*`$`&```
M`)DH`0`7````LB@!`!H```#**`$`%````.4H`0`$````^B@!``D```#_*`$`
M"@````DI`0`'````%"D!``(````<*0$`#@```!\I`0`(````+BD!`!\````W
M*0$`(P```%<I`0`C````>RD!`!\```"?*0$`.````+\I`0`F````^"D!`#$`
M```?*@$`)P```%$J`0!D````>2H!`!0```#>*@$`'````/,J`0!5````$"L!
M`#@```!F*P$`2@```)\K`0!;````ZBL!`"@```!&+`$`.````&\L`0`J````
MJ"P!`"@```#3+`$`+````/PL`0`G````*2T!`"8```!1+0$`&P```'@M`0`^
M````E"T!`",```#3+0$`%P```/<M`0`9````#RX!`$@````I+@$`A0```'(N
M`0`P````^"X!`"4````I+P$`00```$\O`0!;````D2\!`$D```#M+P$`,0``
M`#<P`0`=````:3`!`!@```"',`$`*P```*`P`0`A````S#`!`!\```#N,`$`
M*P````XQ`0`F````.C$!`"$```!A,0$`*0```(,Q`0`G````K3$!`#H```#5
M,0$`'0```!`R`0`1````+C(!`#,```!`,@$`)0```'0R`0`X````FC(!`"<`
M``#3,@$`(````/LR`0`?````'#,!`#`````\,P$`:0```&TS`0`Q````US,!
M`$$````)-`$`,P```$LT`0`E````?S0!`#T```"E-`$`90```.,T`0!-````
M234!`"\```"7-0$`+@```,<U`0`K````]C4!`#`````B-@$`*@```%,V`0`^
M````?C8!`%0```"]-@$`6@```!(W`0!(````;3<!`$H```"V-P$`,@````$X
M`0`=````-#@!`",```!2.`$`+P```'8X`0`L````IC@!`"T```#3.`$`<0``
M``$Y`0!F````<SD!`&\```#:.0$`LP```$HZ`0`7````_CH!`"4````6.P$`
M,@```#P[`0`I````;SL!`#X```"9.P$`(@```-@[`0!2````^SL!`"4```!.
M/`$`"P```'0\`0!%````@#P!`"$```#&/`$`,````.@\`0`E````&3T!`!P`
M```_/0$`,0```%P]`0`'````CCT!``<```"6/0$`!````)X]`0`-````HST!
M``L```"Q/0$`#@```+T]`0`+````S#T!``4```#8/0$`$````-X]`0`"````
M[ST!`%D```#R/0$`!0```$P^`0`2````4CX!``0```!E/@$`!P```&H^`0`(
M````<CX!``4```![/@$``P```($^`0`0````A3X!``P```"6/@$`$P```*,^
M`0`-````MSX!``(```#%/@$`!P```,@^`0`&````T#X!`!0```#7/@$`#```
M`.P^`0`8````^3X!``8````2/P$`$@```!D_`0`,````+#\!``,````Y/P$`
M*@```#T_`0`$````:#\!``8```!M/P$`!P```'0_`0`?````?#\!`#4```"<
M/P$`+@```-(_`0`O`````4`!`!<````Q0`$`'P```$E``0`B````:4`!`"4`
M``",0`$`(````+)``0`;````TT`!`!@```#O0`$`)`````A!`0`?````+4$!
M`!H```!-00$`(0```&A!`0`@````BD$!`!H```"K00$`,@```,9!`0`:````
M^4$!`"\````40@$`*P```$1"`0`?````<$(!`",```"00@$`'P```+1"`0`:
M````U$(!`"$```#O0@$`)0```!%#`0`F````-T,!`"4```!>0P$`)````(1#
M`0`8````J4,!`!T```#"0P$`)````.!#`0`8````!40!`"(````>1`$`+```
M`$%$`0`O````;D0!`!4```">1`$`)0```+1$`0`\````VD0!`!\````710$`
M(P```#=%`0`?````6T4!`"````![10$`&@```)Q%`0`8````MT4!`"8```#0
M10$`'@```/=%`0`I````%D8!`!X```!`1@$`,0```%]&`0`)````D48!``P`
M``";1@$`%P```*A&`0`O````P$8!`"0```#P1@$`!P```!5'`0`?````'4<!
M``\````]1P$`%````$U'`0`.````8D<!``T```!Q1P$`)````']'`0`%````
MI$<!``<```"J1P$`(@```+)'`0`E````U4<!`!H```#[1P$`'0```!9(`0`:
M````-$@!``<```!/2`$`QP```%=(`0`+````'TD!`!4````K20$`!@```$%)
M`0`)````2$D!`!@```!220$`"P```&M)`0`-````=TD!`!<```"%20$`!@``
M`)U)`0`S````I$D!`!,```#820$`$P```.Q)`0`'`````$H!``\````(2@$`
M!P```!A*`0`R````($H!``0```!32@$`(0```%A*`0`3````>DH!``P```".
M2@$`$0```)M*`0`R````K4H!`!8```#@2@$`"````/=*`0`=`````$L!``D`
M```>2P$`"@```"A+`0`4````,TL!``H```!(2P$`'0```%-+`0`(````<4L!
M`!\```!Z2P$`"````)I+`0`:````HTL!`"<```"^2P$`!@```.9+`0`5````
M[4L!``<````#3`$`"`````M,`0`)````%$P!`#\````>3`$`!P```%Y,`0`/
M````9DP!``X```!V3`$`$````(5,`0`)````EDP!``D```"@3`$`"````*I,
M`0`3````LTP!``<```#'3`$`&0```,],`0`*````Z4P!``H```#T3`$`"0``
M`/],`0`7````"4T!`!0````A30$`"@```#9-`0`,````04T!`!<```!.30$`
M!````&9-`0`J````:TT!``P```"630$`$0```*--`0`'````M4T!``(```"]
M30$`$````,!-`0`8````T4T!``L```#J30$``P```/9-`0`(````^DT!`!,`
M```#3@$`%P```!=.`0`&````+TX!``<````V3@$`#0```#Y.`0`+````3$X!
M`!0```!83@$`%0```&U.`0`.````@TX!`"\```"23@$`(````,).`0`<````
MXTX!`!4`````3P$`#````!9/`0`Q````(T\!``4```!53P$`$@```%M/`0`_
M````;D\!`!(```"N3P$`"@```,%/`0`&````S$\!``0```#33P$`!````-A/
M`0`*````W4\!`!,```#H3P$`!0```/Q/`0`&`````E`!``8````)4`$`"```
M`!!0`0`$````&5`!``P````>4`$`"@```"M0`0`Y````-E`!`"X```!P4`$`
M*0```)]0`0`%````R5`!`!D```#/4`$`$0```.E0`0`"````^U`!``0```#^
M4`$`"@````-1`0`&````#E$!``4````540$``P```!M1`0`,````'U$!`$4`
M```L40$`,@```')1`0`:````I5$!`#4```#`40$`-````/91`0`H````*U(!
M`!D```!44@$`<@```&Y2`0`@````X5(!`#4````"4P$`(0```#A3`0!%````
M6E,!`#````"@4P$`*````-%3`0`I````^E,!`"8````D5`$`)0```$M4`0`H
M````<50!`"@```":5`$`(@```,-4`0`K````YE0!`#`````250$`$@```$-5
M`0`3````5E4!`!````!J50$`>0```'M5`0`)````]54!`*$```#_50$`<P``
M`*%6`0!\````%5<!`"L```"25P$`5````+Y7`0`7````$U@!`"<````K6`$`
M%@```%-8`0`/````:E@!`!<```!Z6`$`'P```))8`0!`````LE@!`!\```#S
M6`$`'````!-9`0!1````,%D!`!H```""60$`%````)U9`0`*````LED!``4`
M``"]60$`!@```,-9`0`(````RED!``4```#360$`$@```-E9`0`0````[%D!
M`!,```#]60$`'0```!%:`0`/````+UH!``\````_6@$`!````$]:`0`)````
M5%H!``L```!>6@$`!P```&I:`0`%````<EH!`!0```!X6@$`!P```(U:`0`(
M````E5H!``\```">6@$`"````*Y:`0`,````MUH!``\```#$6@$`!@```-1:
M`0`4````VUH!``8```#P6@$`#````/=:`0`1````!%L!``@````66P$`!```
M`!];`0`9````)%L!`!$````^6P$`"@```%!;`0`%````6UL!`!@```!A6P$`
M$P```'I;`0`<````CEL!`!$```"K6P$`!````+U;`0`/````PEL!``<```#2
M6P$`!````-I;`0`9````WUL!``<```#Y6P$``@````%<`0`"````!%P!`!$`
M```'7`$`"0```!E<`0`&````(UP!`!(````J7`$`%P```#U<`0`&````55P!
M`"<```!<7`$``@```(1<`0`$````AUP!``\```",7`$`$P```)Q<`0`'````
ML%P!``<```"X7`$`$0```,!<`0`&````TEP!`!@```#97`$`!@```/)<`0`3
M````^5P!`!`````-70$`$@```!Y=`0`"````,5T!``8````T70$`#````#M=
M`0`)````2%T!`!$```!270$`(@```&1=`0`'````AUT!``<```"/70$`"P``
M`)==`0`%````HUT!``(```"I70$`"P```*Q=`0!B`0``N%T!`$P````;7P$`
M$0```&A?`0`2````>E\!``\```"-7P$`#@```)U?`0`'````K%\!``H```"T
M7P$`!P```+]?`0`$````QU\!`!@```#,7P$`'0```.5?`0`L`````V`!`!T`
M```P8`$`(````$Y@`0`F````;V`!`!<```"68`$`*````*Y@`0`,````UV`!
M`"L```#D8`$`#@```!!A`0`1````'V$!`!(````Q80$`!0```$1A`0`C````
M2F$!``@```!N80$`"@```'=A`0`3````@F$!``\```"680$`"P```*9A`0`5
M````LF$!`$,```#(80$`(@````QB`0`Q````+V(!`&\```!A8@$`"````-%B
M`0`*````VF(!``H```#E8@$`-P```/!B`0`B````*&,!`!````!+8P$`&P``
M`%QC`0`@````>&,!`#````"98P$`$````,IC`0`/````VV,!`!,```#K8P$`
M$````/]C`0`&````$&0!`(D````79`$`"P```*%D`0`1````K60!`!T```"_
M9`$`"@```-UD`0`0````Z&0!`!````#Y9`$`"0````IE`0`+````%&4!`"P`
M```@90$`'````$UE`0`[````:F4!`$4```"F90$`5@```.QE`0!3````0V8!
M`%D```"79@$`5@```/%F`0`^````2&<!``X```"'9P$`$P```)9G`0`.````
MJF<!`!````"Y9P$`&````,IG`0`%````XV<!``8```#I9P$`"@```/!G`0`%
M````^V<!``8````!:`$`!@````AH`0`1````#V@!``H````A:`$`)0```"QH
M`0`D````4F@!`!````!W:`$`$@```(AH`0`,````FV@!``8```"H:`$`"```
M`*]H`0`)````N&@!``P```#":`$`%````,]H`0`9````Y&@!``X```#^:`$`
M$@````UI`0`7````(&D!`!X````X:0$`(P```%=I`0`:````>VD!`!````"6
M:0$`%P```*=I`0`-````OVD!`"H```#-:0$`&````/AI`0`6````$6H!`!D`
M```H:@$`$P```$)J`0!/````5FH!`#$```"F:@$`)````-AJ`0`&````_6H!
M``D````$:P$`-`````YK`0`.````0VL!``8```!2:P$`"@```%EK`0`(````
M9&L!``@```!M:P$`!0```'9K`0`'````?&L!``H```"$:P$`!````(]K`0`<
M````E&L!``P```"Q:P$`$0```+YK`0`/````T&L!`!4```#@:P$`)@```/9K
M`0`+````'6P!`!H````I;`$`'0```$1L`0`A````8FP!`!@```"$;`$`#P``
M`)UL`0`0````K6P!`!$```"^;`$`+P```-!L`0`;`````&T!`!L````<;0$`
M!P```#AM`0`&````0&T!``@```!';0$`#````%!M`0`$````76T!``D```!B
M;0$`$P```&QM`0`+````@&T!`!$```",;0$`%@```)YM`0`?````M6T!``<`
M``#5;0$`$@```-UM`0`%````\&T!`!8```#V;0$`#P````UN`0`,````'6X!
M`#$````J;@$`0@```%QN`0`)````GVX!``@```"I;@$`%````+)N`0`%````
MQVX!``4```#-;@$`$````--N`0`+````Y&X!`!D```#P;@$`.P````IO`0`2
M````1F\!`$8```!9;P$`+P```*!O`0`T````T&\!`"X````%<`$`+0```#1P
M`0`)````8G`!``@```!L<`$`!P```'5P`0`*````?7`!``D```"(<`$`(P``
M`))P`0`T````MG`!`"(```#K<`$`1@````YQ`0`A````57$!`"$```!W<0$`
M0P```)EQ`0!"````W7$!`!\````@<@$`0````$!R`0`G````@7(!`"H```"I
M<@$`0P```-1R`0`A````&',!`"<````Z<P$`+````&)S`0`:````CW,!`!X`
M``"J<P$`*@```,ES`0`K````]',!`"L````@=`$`$@```$QT`0`.````7W0!
M``H```!N=`$`!P```'ET`0`-````@70!``@```"/=`$`#0```)AT`0`?````
MIG0!`",```#&=`$`!P```.IT`0`'````\G0!`!4```#Z=`$`"@```!!U`0`&
M````&W4!``8````B=0$`"````"EU`0`&````,G4!`"D````Y=0$`"````&-U
M`0`+````;'4!``<```!X=0$`!@```(!U`0`%````AW4!``<```"-=0$`!@``
M`)5U`0`*````G'4!`"<```"G=0$`$@```,]U`0`(````XG4!``@```#K=0$`
M#@```/1U`0`#`````W8!``<````'=@$`"0````]V`0`#````&78!``D````=
M=@$`!0```"=V`0`7````+78!``0```!%=@$`"````$IV`0`&````4W8!``T`
M``!:=@$`"0```&AV`0`G````<G8!``0```":=@$`!@```)]V`0`)````IG8!
M``H```"P=@$`#````+MV`0`,````R'8!``<```#5=@$``P```-UV`0`#````
MX78!`!<```#E=@$`%@```/UV`0`D````%'<!``@````Y=P$`!0```$)W`0`(
M````2'<!``<```!1=P$`"@```%EW`0!%````9'<!`!T```"J=P$`.````,AW
M`0`B`````7@!`!<````D>`$`!@```#QX`0`&````0W@!`!4```!*>`$`%0``
M`&!X`0`?````=G@!`"L```"6>`$`&@```,)X`0`C````W7@!`#$````!>0$`
M"0```#-Y`0`&````/7D!``@```!$>0$`%P```$UY`0`.````97D!``P```!T
M>0$`$0```(%Y`0`.````DWD!`!$```"B>0$`#@```+1Y`0`,````PWD!`!4`
M``#0>0$`"0```.9Y`0`<````\'D!`!T````->@$`$@```"MZ`0`/````/GH!
M`!(```!.>@$`!0```&%Z`0`*````9WH!``4```!R>@$`$P```'AZ`0`7````
MC'H!`%4```"D>@$`8@```/IZ`0`#````77L!`!,```!A>P$`*0```'5[`0`%
M````GWL!``0```"E>P$`'````*I[`0`>````QWL!`!$```#F>P$`#0```/A[
M`0`1````!GP!``P````8?`$`&P```"5\`0`D````07P!``4```!F?`$`'@``
M`&Q\`0`%````BWP!`!4```"1?`$`"P```*=\`0`3````LWP!``\```#'?`$`
M$@```-=\`0`3````ZGP!`!@```#^?`$`$P```!=]`0`-````*WT!``0````Y
M?0$`"P```#Y]`0`(````2GT!`!<```!3?0$`%0```&M]`0`2````@7T!``@`
M``"4?0$`!````)U]`0`-````HGT!``<```"P?0$`"0```+A]`0`/````PGT!
M``L```#2?0$`"````-Y]`0`/````YWT!``D```#W?0$`!`````%^`0`'````
M!GX!``<````.?@$`"````!9^`0`5````'WX!``<````U?@$`!0```#U^`0`%
M````0WX!`!@```!)?@$`4````&)^`0`A````LWX!``X```#5?@$`$0```.1^
M`0`%````]GX!``4```#\?@$`&0````)_`0`:````''\!`"P````W?P$`-```
M`&1_`0`H````F7\!``D```#"?P$`)0```,Q_`0`B````\G\!``\````5@`$`
M"````"6``0`,````+H`!``8````[@`$`!P```$*``0`:````2H`!`!$```!E
M@`$`"@```'>``0`+````@H`!``H```".@`$`#P```)F``0`A````J8`!`"(`
M``#+@`$`(````.Z``0`A````#X$!`"0````Q@0$`(P```%:!`0`?````>H$!
M`"8```":@0$`(0```,&!`0`D````XX$!`"D````(@@$`)0```#*"`0`=````
M6((!`!X```!V@@$`(````)6"`0`;````MH(!`"8```#2@@$`+0```/F"`0`K
M````)X,!`"(```!3@P$`*P```':#`0`W````HH,!`!T```#:@P$`'0```/B#
M`0`9````%H0!`!D````PA`$`,````$J$`0`A````>X0!`!(```"=A`$`(0``
M`+"$`0`H````TH0!`!H```#[A`$`&````!:%`0`>````+X4!`!$```!.A0$`
MM@```&"%`0`2````%X8!`!P````JA@$`)0```$>&`0`F````;88!`"````"4
MA@$`)````+6&`0`:````VH8!`!H```#UA@$`)````!"'`0`D````-8<!`"L`
M``!:AP$`+````(:'`0`G````LX<!`(P```#;AP$`'P```&B(`0`5````B(@!
M`!4```">B`$`'@```+2(`0`I````TX@!`"D```#]B`$`1````">)`0!$````
M;(D!``L```"QB0$`!````+V)`0`&````PHD!``4```#)B0$`"@```,^)`0`(
M````VHD!``\```#CB0$`%@```/.)`0`1````"HH!``@````<B@$`!````"6*
M`0`0````*HH!``\````[B@$`"P```$N*`0`.````5XH!`!````!FB@$`#@``
M`'>*`0`2````AHH!``P```"9B@$`-@```*:*`0`(````W8H!``L```#FB@$`
M!@```/**`0`2````^8H!`!@````,BP$`&P```"6+`0`(````08L!``(```!*
MBP$`!@```$V+`0`2````5(L!``X```!GBP$`!0```':+`0`.````?(L!``@`
M``"+BP$``P```)2+`0`.````F(L!``@```"GBP$`"0```+"+`0`&````NHL!
M``T```#!BP$`!P```,^+`0`,````UXL!`!$```#DBP$`#````/:+`0`,````
M`XP!`!$````0C`$`"0```"*,`0`&````+(P!``L````SC`$`#````#^,`0`+
M````3(P!`!$```!8C`$`'````&J,`0`+````AXP!``T```"3C`$`'P```*&,
M`0`4````P8P!`!H```#6C`$`,0```/&,`0`*````(XT!`!4````NC0$`$@``
M`$2-`0`5````5XT!`!(```!MC0$`%0```("-`0`D````EHT!``L```"[C0$`
M!P```,>-`0`-````SXT!`"L```#=C0$`$0````F.`0`+````&XX!`"(````G
MC@$`+P```$J.`0`*````>HX!``D```"%C@$`'@```(^.`0`+````KHX!`!L`
M``"ZC@$`&P```-:.`0`'````\HX!`!<```#ZC@$`%0```!*/`0`<````*(\!
M`!<```!%CP$`#@```%V/`0`*````;(\!``@```!WCP$`"P```("/`0`B````
MC(\!`#D```"OCP$`%P```.F/`0`C`````9`!``4````ED`$`"````"N0`0`M
M````-)`!``H```!BD`$`!@```&V0`0`&````=)`!`%8```![D`$``P```-*0
M`0`'````UI`!``4```#>D`$`"P```.20`0`+````\)`!`!````#\D`$`$@``
M``V1`0`9````()$!`!@````ZD0$`&P```%.1`0`;````;Y$!``H```"+D0$`
M!P```):1`0`+````GI$!``H```"JD0$``@```+61`0`&````N)$!``P```"_
MD0$`)0```,R1`0`@````\I$!`!8````3D@$`#````"J2`0`0````-Y(!``X`
M``!(D@$`$````%>2`0`$````:)(!``<```!MD@$`#P```'62`0`A````A9(!
M`!@```"GD@$``P```,"2`0`=````Q)(!`"P```#BD@$`*P````^3`0`<````
M.Y,!`"D```!8DP$`(P```(*3`0`7````II,!`!H```"^DP$`!P```-F3`0`(
M````X9,!``8```#JDP$`!@```/&3`0`.````^),!``X````'E`$`#P```!:4
M`0`-````)I0!`!`````TE`$`#P```$64`0`+````590!`!(```!AE`$``P``
M`'24`0`)````>)0!`!(```""E`$`#@```)64`0`O````I)0!``T```#4E`$`
M"````.*4`0`-````ZY0!`"````#YE`$`)0```!J5`0`F````0)4!`"4```!G
ME0$`(P```(V5`0`C````L94!`"L```#5E0$`(@````&6`0`:````))8!``,`
M```_E@$`#@```$.6`0`(````4I8!``L```!;E@$``P```&>6`0`%````:Y8!
M``@```!QE@$`"0```'J6`0`+````A)8!``\```"0E@$`$@```*"6`0`*````
MLY8!``X```"^E@$`#@```,V6`0`$````W)8!``,```#AE@$`$P```.66`0`5
M````^98!``P````/EP$`!P```!R7`0`&````))<!``X````KEP$`&@```#J7
M`0`&````59<!``<```!<EP$`#0```&27`0`.````<I<!`!<```"!EP$`"```
M`)F7`0`#````HI<!`"4```"FEP$`#0```,R7`0!.````VI<!`!0````IF`$`
M"````#Z8`0`*````1Y@!`!$```!2F`$`"@```&28`0`,````;Y@!``4```!\
MF`$`#@```(*8`0`"````D9@!``4```"4F`$`"0```)J8`0`3````I)@!`!H`
M``"XF`$`$P```-.8`0`8````YY@!`"``````F0$`#@```"&9`0`2````,)D!
M`!D```!#F0$`!````%V9`0`)````8ID!`!<```!LF0$`"````(29`0`1````
MC9D!``4```"?F0$`&````*69`0`(````OID!``8```#'F0$`'0```,Z9`0`-
M````[)D!``@```#ZF0$`"`````.:`0`%````#)H!``D````2F@$`!P```!R:
M`0`5````))H!``(````ZF@$`!@```#V:`0`,````1)H!``T```!1F@$`"```
M`%^:`0`4````:)H!``0```!]F@$`"````(*:`0`'````BYH!``,```"3F@$`
M$P```)>:`0`]````JYH!`"8```#IF@$`*0```!";`0`'````.IL!``0```!"
MFP$`"0```$>;`0`(````49L!`!````!:FP$`$P```&N;`0`'````?YL!``8`
M``"'FP$`#0```(Z;`0`&````G)L!``0```"CFP$`,0```*B;`0`V````VIL!
M`#,````1G`$`&@```$6<`0`%````8)P!``P```!FG`$`!0```'.<`0`&````
M>9P!``@```"`G`$`&````(F<`0`2````HIP!`!<```"UG`$`!````,V<`0`-
M````TIP!``4```#@G`$`$0```.:<`0`-````^)P!``@````&G0$`%P````^=
M`0`#````)YT!``0````KG0$``P```#"=`0`+````-)T!``H```!`G0$`#```
M`$N=`0`(````6)T!``D```!AG0$`!0```&N=`0`]````<9T!`#$```"OG0$`
M/P```.&=`0`=````(9X!`$$````_G@$`-P```(&>`0`H````N9X!`#D```#B
MG@$`+@```!R?`0`R````2Y\!`"$```!^GP$`$0```*"?`0`5````LI\!``P`
M``#(GP$`+P```-6?`0`D````!:`!`"0````JH`$`(P```$^@`0`)````<Z`!
M``H```!]H`$`"@```(B@`0`&````DZ`!`"4```":H`$`)@```,"@`0`P````
MYZ`!``D````8H0$`'@```"*A`0`J````0:$!`!H```!LH0$`$````(>A`0`&
M````F*$!``T```"?H0$`#0```*VA`0`/````NZ$!`!(```#+H0$`.P```-ZA
M`0"1````&J(!`&0```"LH@$`%0```!&C`0`*````)Z,!``L````RHP$`$0``
M`#ZC`0`2````4*,!``X```!CHP$`!@```'*C`0`2````>:,!`!0```",HP$`
M$0```*&C`0`(````LZ,!`!$```"\HP$`)````,ZC`0`J````\Z,!`&X````>
MI`$`"@```(VD`0`&````F*0!`!8```"?I`$`"@```+:D`0`$````P:0!``L`
M``#&I`$`)P```-*D`0`4````^J0!``L````/I0$`#0```!NE`0`/````*:4!
M`!,````YI0$`)0```$VE`0`D````<Z4!`!P```"8I0$`'@```+6E`0`A````
MU*4!`"````#VI0$`%@```!>F`0`1````+J8!`!````!`I@$`$P```%&F`0`2
M````9:8!`!(```!XI@$`%0```(NF`0`4````H:8!`!````"VI@$`#P```,>F
M`0`I````UZ8!`!$````!IP$`$0```!.G`0`[````):<!`!0```!AIP$`!@``
M`':G`0`,````?:<!`"<```"*IP$`(0```+*G`0`6````U*<!`!4```#KIP$`
M$@````&H`0`6````%*@!`!P````KJ`$`$P```$BH`0`5````7*@!`!H```!R
MJ`$`&````(VH`0`=````IJ@!`"$```#$J`$`(0```.:H`0`5````"*D!`!0`
M```>J0$`%````#.I`0`8````2*D!`!H```!AJ0$`&````'RI`0`6````E:D!
M``L```"LJ0$`#P```+BI`0`$````R*D!``0```#-J0$`!@```-*I`0`+````
MV:D!`!$```#EJ0$`!@```/>I`0`+````_JD!``8````*J@$`!P```!&J`0`'
M````&:H!``<````AJ@$`!0```"FJ`0`5````+ZH!``8```!%J@$`"0```$RJ
M`0`$````5JH!``0```!;J@$`!P```&"J`0`-````:*H!``P```!VJ@$`#@``
M`(.J`0`,````DJH!``4```"?J@$`*0```*6J`0`-````SZH!``L```#=J@$`
M"P```.FJ`0`)````]:H!`!````#_J@$`,````!"K`0`$````0:L!``@```!&
MJP$`!0```$^K`0`)````5:L!``@```!?JP$`$0```&BK`0`&````>JL!``D`
M``"!JP$`!P```(NK`0`%````DZL!``0```"9JP$`#````)ZK`0`1````JZL!
M``\```"]JP$`$@```,VK`0`6````X*L!`!X```#WJP$`&@```!:L`0`(````
M,:P!``@````ZK`$``P```$.L`0`&````1ZP!`"4```!.K`$`!P```'2L`0`'
M````?*P!``T```"$K`$`#0```)*L`0`'````H*P!``0```"HK`$`!P```*VL
M`0`&````M:P!``T```"\K`$`!P```,JL`0`(````TJP!``D```#;K`$`$P``
M`.6L`0`5````^:P!``T````/K0$`$@```!VM`0`(````,*T!``P````YK0$`
M"````$:M`0`$````3ZT!`!````!4K0$`0@```&6M`0`&````J*T!``0```"O
MK0$`'P```+2M`0`.````U*T!``\```#CK0$`#@```/.M`0`,`````JX!``D`
M```/K@$`!P```!FN`0`*````(:X!``D````LK@$`#@```#:N`0`0````1:X!
M`"4```!6K@$`)0```'RN`0`B````HJX!``H```#%K@$`!P```-"N`0`)````
MV*X!``L```#BK@$`"0```.ZN`0`%````^*X!``@```#^K@$`"`````>O`0`%
M````$*\!`!`````6KP$`3@```">O`0`8````=J\!``D```"/KP$`!@```)FO
M`0`#````H*\!`!````"DKP$`$````+6O`0`4````QJ\!``8```#;KP$`"@``
M`.*O`0`)````[:\!``(```#WKP$`!````/JO`0`C````_Z\!``,````CL`$`
M!0```">P`0`*````+;`!``H````XL`$`!@```$.P`0`&````2K`!``L```!1
ML`$`#0```%VP`0`&````:[`!``@```!RL`$`"@```'NP`0`$````AK`!``4`
M``"+L`$`=@```)&P`0`+````"+$!``X````4L0$`%P```".Q`0`$````.[$!
M``@```!`L0$`%0```$FQ`0`O````7[$!``T```"/L0$`"@```)VQ`0`.````
MJ+$!``L```"WL0$`"0```,.Q`0`4````S;$!`#,```#BL0$`*````!:R`0`G
M````/[(!`!H```!GL@$`#0```(*R`0`#````D+(!``<```"4L@$`!P```)RR
M`0`+````I+(!`!````"PL@$`#@```,&R`0`)````T+(!`!````#:L@$`&P``
M`.NR`0`)````![,!``D````1LP$`#P```!NS`0`*````*[,!`$T````VLP$`
M'@```(2S`0`-````H[,!``H```"QLP$`(0```+RS`0!,````WK,!`!D````K
MM`$`!0```$6T`0`?````2[0!`"X```!KM`$`!P```)JT`0`&````HK0!``L`
M``"IM`$`!@```+6T`0`'````O+0!`"<```#$M`$`)@```.RT`0`J````$[4!
M``8````^M0$`!P```$6U`0`O````3;4!`%4```!]M0$`%0```-.U`0`G````
MZ;4!`!,````1M@$``@```"6V`0`,````*+8!``@````UM@$`#````#ZV`0`*
M````2[8!``<```!6M@$`"0```%ZV`0`&````:+8!``D```!OM@$`#````'FV
M`0`(````AK8!``D```"/M@$`"````)FV`0`R````HK8!``<```#5M@$`#P``
M`-VV`0`1````[;8!`!````#_M@$`"@```!"W`0`.````&[<!``P````JMP$`
M"@```#>W`0`*````0K<!``H```!-MP$`"@```%BW`0`'````8[<!``X```!K
MMP$`'````'JW`0`'````E[<!``H```"?MP$`%````*JW`0`*````O[<!`!``
M``#*MP$`!P```-NW`0`8````X[<!``0```#\MP$`!P````&X`0`%````";@!
M``0````/N`$`#@```!2X`0`%````([@!``T````IN`$`%P```#>X`0`/````
M3[@!`!8```!?N`$`&0```':X`0`7````D+@!`!P```"HN`$`%@```,6X`0`'
M````W+@!``8```#DN`$`#@```.NX`0`+````^K@!`!<````&N0$`!@```!ZY
M`0`<````);D!``L```!"N0$`#0```$ZY`0`B````7+D!`!H```!_N0$`%0``
M`)JY`0`'````L+D!``T```"XN0$`!0```,:Y`0`0````S+D!`!,```#=N0$`
M!@```/&Y`0`)````^+D!``4````"N@$`!P````BZ`0`$````$+H!``0````5
MN@$``P```!JZ`0`[````'KH!`#,```!:N@$`$@```(ZZ`0`O````H;H!`#(`
M``#1N@$`#@````2[`0`\````$[L!`"\```!0NP$`-````("[`0`T````M;L!
M`#@```#JNP$`$@```".\`0`3````-KP!`!@```!*O`$`$P```&.\`0`5````
M=[P!`!(```"-O`$`$@```*"\`0`;````L[P!`!,```#/O`$`%0```..\`0`:
M````^;P!`"X````4O0$`+@```$.]`0`R````<KT!`"\```"EO0$`,````-6]
M`0`M````!KX!`!T````TO@$`$P```%*^`0`4````9KX!``L```![O@$`&0``
M`(>^`0`*````H;X!``\```"LO@$`+````+R^`0`N````Z;X!`"(````8OP$`
M"P```#N_`0!5````1[\!`$8```"=OP$`#@```.2_`0`%````\[\!`!P```#Y
MOP$`#````!;``0`0````(\`!`!(````TP`$`!0```$?``0`*````3<`!``D`
M``!8P`$`#P```&+``0`1````<L`!``H```"$P`$`"P```(_``0`,````F\`!
M`"````"HP`$``P```,G``0`(````S<`!``8```#6P`$`#````-W``0`.````
MZL`!``L```#YP`$`0@````7!`0`"````2,$!``8```!+P0$`#0```%+!`0`%
M````8,$!``<```!FP0$`&0```&[!`0`&````B,$!`"X```"/P0$`$````+[!
M`0`=````S\$!``0```#MP0$`*@```/+!`0`<````'<(!`"`````ZP@$`60``
M`%O"`0`4````M<(!`$<```#*P@$`&0```!+#`0`.````+,,!`!P````[PP$`
M#0```%C#`0`4````9L,!``X```![PP$`#````(K#`0`2````E\,!``H```"J
MPP$`'````+7#`0`9````TL,!``4```#LPP$`$P```/+#`0`0````!L0!`"8`
M```7Q`$`$P```#[$`0`5````4L0!`!(```!HQ`$`$0```'O$`0`9````C<0!
M``<```"GQ`$`"````*_$`0`3````N,0!``X```#,Q`$`$@```-O$`0`/````
M[L0!`!H```#^Q`$`#P```!G%`0`:````*<4!`!0```!$Q0$`"0```%G%`0`*
M````8\4!``@```!NQ0$`!0```'?%`0`)````?<4!``8```"'Q0$`$````([%
M`0`(````G\4!``X```"HQ0$`"````+?%`0`2````P,4!`!(```#3Q0$`*```
M`.;%`0`8````#\8!``D````HQ@$`"@```#+&`0`9````/<8!``H```!7Q@$`
M(@```&+&`0`&````A<8!`!@```",Q@$`"0```*7&`0`'````K\8!`!H```"W
MQ@$`*P```-+&`0`*````_L8!`!\````)QP$`#0```"G'`0`,````-\<!`!D`
M``!$QP$`%0```%['`0`$````=,<!``<```!YQP$`#````(''`0`'````CL<!
M``4```"6QP$`"````)S'`0`&````I<<!``@```"LQP$`&````+7'`0`F````
MSL<!`"T```#UQP$`&@```"/(`0`@````/L@!`!\```!?R`$`1````'_(`0`<
M````Q,@!`!T```#AR`$`)````/_(`0!;````),D!`%L```"`R0$`2@```-S)
M`0`B````)\H!`!<```!*R@$`!0```&+*`0`'````:,H!``X```!PR@$`"```
M`'_*`0`7````B,H!`!D```"@R@$`+@```+K*`0`(````Z<H!`"(```#RR@$`
M&````!7+`0`?````+LL!`#L```!.RP$`!0```(K+`0`5````D,L!``L```"F
MRP$`#P```+++`0`C````PLL!`!@```#FRP$`$0```/_+`0`.````$<P!``<`
M```@S`$`$@```"C,`0`'````.\P!``0```!#S`$`#0```$C,`0`5````5LP!
M`!@```!LS`$`+P```(7,`0`+````M<P!`!$```#!S`$`!0```-/,`0`%````
MV<P!``4```#?S`$`'````.7,`0`+`````LT!``0````.S0$`"P```!/-`0`)
M````'\T!``H````IS0$`#````#3-`0`-````0<T!`!<```!/S0$`"P```&?-
M`0`#````<\T!``\```!WS0$`.0```(?-`0!*````P<T!`!P````,S@$`"0``
M`"G.`0`@````,\X!`!,```!4S@$`!0```&C.`0`1````;LX!``@```"`S@$`
M"P```(G.`0`G````E<X!``P```"]S@$`(P```,K.`0`'````[LX!``T```#V
MS@$`#@````3/`0`3````$\\!`!D````GSP$`"P```$'/`0`S````3<\!``<`
M``"!SP$`(````(G/`0`1````JL\!`!4```"\SP$`#0```-+/`0`<````X,\!
M`$$```#]SP$`,P```#_0`0`(````<]`!`#````!\T`$`+````*W0`0`V````
MVM`!`#<````1T0$`,````$G1`0`3````>M$!`!8```".T0$`"0```*71`0`2
M````K]$!`!(```#"T0$`&````-71`0`(````[M$!`!L```#WT0$`$@```!/2
M`0`'````)M(!`!<````NT@$`(@```$;2`0`%````:=(!``4```!OT@$`"P``
M`'72`0`+````@=(!`!0```"-T@$`!````*+2`0`(````I](!``H```"PT@$`
M#@```+O2`0`,````RM(!`!````#7T@$`$````.C2`0`&````^=(!``8`````
MTP$`*P````?3`0`C````,],!`"````!7TP$``P```'C3`0`(````?-,!``8`
M``"%TP$`#P```(S3`0`;````G-,!`"<```"XTP$`#P```.#3`0`(````\-,!
M`"$```#YTP$``P```!O4`0`&````']0!``D````FU`$``@```##4`0`,````
M,]0!`!4```!`U`$`"P```%;4`0`9````8M0!`!X```!\U`$`$0```)O4`0`%
M````K=0!``H```"SU`$`%0```+[4`0`2````U-0!``P```#GU`$`!0```/34
M`0`*````^M0!``@````%U0$`$P````[5`0!,````(M4!`!T```!OU0$`)0``
M`(W5`0`1````L]4!``D```#%U0$``P```,_5`0`*````T]4!``H```#>U0$`
M#@```.G5`0`9````^-4!``T````2U@$`"P```"#6`0`=````+-8!``D```!*
MU@$`%@```%36`0`/````:]8!``H```![U@$`8````(;6`0`:````Y]8!`!$`
M```"UP$`'0```!37`0`8````,M<!`!````!+UP$`&````%S7`0`5````==<!
M`!D```"+UP$`'````*77`0`5````PM<!``H```#8UP$`!P```./7`0`(````
MZ]<!``D```#TUP$`%@```/[7`0`+````%=@!`#,````AV`$`%@```%78`0`8
M````;-@!``D```"%V`$`!````(_8`0!)````E-@!`#X```#>V`$`.0```!W9
M`0!;````5]D!``4```"SV0$`-````+G9`0`E````[MD!``P````4V@$`!@``
M`"':`0`.````*-H!`#8````WV@$`!````&[:`0!,````<]H!`"L```#`V@$`
M*0```.S:`0`+````%ML!`"$````BVP$`'@```$3;`0`7````8]L!`!,```![
MVP$`$P```(_;`0`B````H]L!`!````#&VP$`!@```-?;`0`-````WML!``L`
M``#LVP$`$0```/C;`0`)````"MP!`"\````4W`$`#````$3<`0`*````4=P!
M``@```!<W`$`$````&7<`0`'````=MP!``D```!^W`$`!P```(C<`0`0````
MD-P!``D```"AW`$`"0```*O<`0`#````M=P!``<```"YW`$`"0```,'<`0`0
M````R]P!``X```#<W`$`"0```.O<`0`:````]=P!``P````0W0$`!P```!W=
M`0`1````)=T!`!8````WW0$`"@```$[=`0`)````6=T!`"(```!CW0$`$```
M`(;=`0`C````E]T!`"L```"[W0$`"0```.?=`0`)````\=T!`!<```#[W0$`
M!P```!/>`0`$````&]X!`!T````@W@$`"0```#[>`0`+````2-X!``@```!4
MW@$`!P```%W>`0`)````9=X!``@```!OW@$`"0```'C>`0`%````@MX!``<`
M``"(W@$`$0```)#>`0`&````HMX!``X```"IW@$`"@```+C>`0`,````P]X!
M``L```#0W@$`&P```-S>`0`*````^-X!``(````#WP$`(0````;?`0`&````
M*-\!``8````OWP$`<P```#;?`0`(````JM\!``8```"SWP$`&P```+K?`0`G
M````UM\!``\```#^WP$`'0````[@`0!(````+.`!`!P```!UX`$`'P```)+@
M`0`2````LN`!``@```#%X`$`!0```,[@`0`/````U.`!``H```#DX`$`"@``
M`._@`0`&````^N`!``H````!X0$`$@````SA`0`,````'^$!``H````LX0$`
M#````#?A`0`'````1.$!``<```!,X0$`"````%3A`0`)````7>$!`!8```!G
MX0$`"0```'[A`0`'````B.$!``<```"0X0$`&@```)CA`0`&````L^$!`!<`
M``"ZX0$`!@```-+A`0`'````V>$!`!4```#AX0$`"0```/?A`0`0`````>(!
M``<````2X@$`!@```!KB`0`3````(>(!`!$````UX@$`$P```$?B`0`&````
M6^(!``8```!BX@$`"@```&GB`0`(````=.(!``0```!]X@$`"0```(+B`0`$
M````C.(!``T```"1X@$`(@```)_B`0`*````PN(!``P```#-X@$`*0```-KB
M`0`7````!.,!`!8````<XP$`&P```#/C`0`6````3^,!``0```!FXP$`"P``
M`&OC`0`-````=^,!``<```"%XP$``@```(WC`0`.````D.,!``@```"?XP$`
M(@```*CC`0`?````R^,!`",```#KXP$`(`````_D`0`U````,.0!`"$```!F
MY`$`)P```(CD`0`K````L.0!`&0```#<Y`$`$@```$'E`0`A````5.4!`#X`
M``!VY0$`(P```+7E`0!/````V>4!`$@````IY@$`)@```'+F`0`_````F>8!
M`"$```#9Y@$`+P```/OF`0`N````*^<!`"<```!:YP$`)P```(+G`0`A````
MJN<!`#8```#,YP$`&P````/H`0`1````'^@!`!8````QZ`$`2P```$CH`0!P
M````E.@!`#@````%Z0$`*@```#[I`0`U````:>D!`&(```"?Z0$`5`````+J
M`0`K````5^H!`!P```"#Z@$`#P```*#J`0`A````L.H!`!8```#2Z@$`%0``
M`.GJ`0`M````_^H!`!P````MZP$`&P```$KK`0`M````9NL!`!T```"4ZP$`
M/0```++K`0`9````\.L!``T````*[`$`+@```!CL`0`G````1^P!`#8```!O
M[`$`*0```*;L`0`<````T.P!`"````#M[`$`-@````[M`0!0````1>T!`#$`
M``"6[0$`0P```,CM`0`L````#.X!`",````Y[@$`-P```%WN`0!C````E>X!
M`$P```#Y[@$`,P```$;O`0`>````>N\!`"````"9[P$`(0```+KO`0`@````
MW.\!`#0```#][P$`7P```#+P`0!1````DO`!`#P```#D\`$`/P```"'Q`0`J
M````8?$!`!H```",\0$`*````*?Q`0`M````T/$!`"T```#^\0$`%0```"SR
M`0"#````0O(!`'<```#&\@$`@````#[S`0#(````O_,!`!D```"(]`$`(P``
M`*+T`0`N````QO0!`"<```#U]`$`1P```!WU`0`B````9?4!`%````"(]0$`
M)````-GU`0`.````_O4!`$$````-]@$`)````$_V`0`N````=/8!`"<```"C
M]@$`)````,OV`0`Z````\/8!``0````K]P$`!P```##W`0`#````./<!``\`
M```\]P$`"@```$SW`0`'````5_<!``@```!?]P$`!@```&CW`0`1````;_<!
M``0```"!]P$`6P```(;W`0`$````XO<!``\```#G]P$`!````/?W`0`'````
M_/<!``<````$^`$`!0````SX`0`#````$O@!`!`````6^`$`#@```"?X`0`3
M````-O@!`!$```!*^`$``@```%SX`0`(````7_@!``<```!H^`$`%````'#X
M`0`,````A?@!`!8```"2^`$`!@```*GX`0`/````L/@!``H```#`^`$``P``
M`,OX`0`H````S_@!``0```#X^`$`!@```/WX`0`'````!/D!`!<````,^0$`
M2````"3Y`0`I````;?D!`"P```"7^0$`%P```,3Y`0`E````W/D!`"8````"
M^@$`*0```"GZ`0`=````4_H!`!H```!Q^@$`&0```(SZ`0`;````IOH!`!@`
M``#"^@$`%P```-OZ`0`=````\_H!`!L````1^P$`&````"W[`0`G````1OL!
M`!@```!N^P$`)P```(?[`0`C````K_L!`!D```#3^P$`'0```.W[`0`;````
M"_P!`!@````G_`$`'@```$#\`0`B````7_P!`!T```""_`$`)@```*#\`0`B
M````Q_P!`!@```#J_`$`&@````/]`0`E````'OT!`!<```!$_0$`(0```%S]
M`0`P````?OT!`#,```"O_0$`$P```./]`0`F````]_T!`#X````>_@$`'P``
M`%W^`0`C````??X!`"$```"A_@$`)````,/^`0`>````Z/X!`!@````'_P$`
M(0```"#_`0`@````0O\!`#,```!C_P$`(@```)?_`0`W````NO\!``P```#R
M_P$`#P```/__`0`9````#P`"`"D````I``(`'P```%,``@`0````<P`"`"(`
M``"$``(`#P```*<``@`5````MP`"``X```#-``(`$````-P``@`;````[0`"
M``<````)`0(`!0```!$!`@`I````%P$"`"0```!!`0(`%P```&8!`@`B````
M?@$"`"0```"A`0(`!P```,8!`@#4````S@$"``P```"C`@(`%````+`"`@`)
M````Q0("``P```#/`@(`'````-P"`@`3````^0("`!$````-`P(`&P```!\#
M`@`)````.P,"`#(```!%`P(`"````'@#`@`0````@0,"``<```"2`P(`$@``
M`)H#`@`*````K0,"`#8```"X`P(`"0```.\#`@`D````^0,"`!8````>!`(`
M%0```#4$`@`4````2P0"`"8```!@!`(`'````(<$`@`,````I`0"`!P```"Q
M!`(`#0```,X$`@`.````W`0"`!4```#K!`(`"@````$%`@`8````#`4"``@`
M```E!0(`*0```"X%`@`)````6`4"``\```!B!0(`*@```'(%`@`&````G04"
M`!4```"D!0(`!P```+H%`@`(````P@4"``D```#+!0(`.P```-4%`@`'````
M$08"`!`````9!@(`$@```"H&`@`2````/08"``D```!0!@(`"P```%H&`@`'
M````9@8"`!4```!N!@(`!P```(0&`@`7````C`8"``L```"D!@(`#0```+`&
M`@`,````O@8"`!<```#+!@(`&0```.,&`@`$````_08"``4````"!P(`&0``
M``@'`@`$````(@<"`"P````G!P(`#````%0'`@`1````80<"``<```!S!P(`
M`@```'L'`@`,````?@<"``X```"+!P(`"P```)H'`@`$````I@<"``D```"K
M!P(`$P```+4'`@`6````R0<"``@```#@!P(`"0```.D'`@`1````\P<"``T`
M```%"`(`&0```!,(`@`:````+0@"``T```!("`(`,@```%8(`@`>````B0@"
M`",```"H"`(`%P```,P(`@`+````Y`@"`#,```#P"`(`!0```"0)`@`1````
M*@D"`$(````\"0(`"P```'\)`@`*````BPD"``8```"6"0(`!````)T)`@`$
M````H@D"``H```"G"0(`%````+()`@`%````QPD"``8```#-"0(`!@```-0)
M`@`*````VPD"``8```#F"0(`#@```.T)`@`/````_`D"`#0````,"@(`*@``
M`$$*`@`G````;`H"``4```"4"@(`'@```)H*`@`.````N0H"``(```#("@(`
M!````,L*`@`*````T`H"``4```#;"@(`!0```.$*`@`"````YPH"`!$```#J
M"@(`0P```/P*`@`N````0`L"`!@```!O"P(`(P```(@+`@`C````K`L"`"8`
M``#0"P(`#P```/<+`@!>````!PP"`"````!F#`(`1P```(<,`@`D````SPP"
M`$$```#T#`(`*````#8-`@`J````7PT"`#````"*#0(`,0```+L-`@`U````
M[0T"`#0````C#@(`*@```%@.`@`D````@PX"`"H```"H#@(`,@```-,.`@`0
M````!@\"`!$````7#P(`#P```"D/`@!L````.0\"``D```"F#P(`J0```+`/
M`@!?````6A`"`'<```"Z$`(`+@```#(1`@!8````81$"`!4```"Z$0(`(P``
M`-`1`@`7````]!$"`!<````,$@(`&P```"02`@`?````0!("`#D```!@$@(`
M(P```)H2`@`C````OA("`%@```#B$@(`&@```#L3`@`2````5A,"``L```!I
M$P(`!0```'43`@`&````>Q,"``@```""$P(`!0```(L3`@`2````D1,"``P`
M``"D$P(`%````+$3`@`>````QA,"``X```#E$P(`#P```/03`@`$````!!0"
M``D````)%`(`"P```!,4`@`(````'Q0"``8````H%`(`%0```"\4`@`)````
M110"``D```!/%`(`#@```%D4`@`.````:!0"``T```!W%`(`$````(44`@`&
M````EA0"`!<```"=%`(`"@```+44`@`)````P!0"``\```#*%`(`"````-H4
M`@`%````XQ0"`!0```#I%`(`%0```/X4`@`*````%!4"``8````?%0(`#P``
M`"85`@`1````-A4"`!@```!(%0(`#0```&$5`@`%````;Q4"`!@```!U%0(`
M"````(X5`@`#````EQ4"`!D```";%0(`"0```+45`@`"````OQ4"``(```#"
M%0(`#P```,45`@`&````U14"``8```#<%0(`#P```.,5`@`7````\Q4"``8`
M```+%@(`%@```!(6`@`"````*18"``0````L%@(`$@```#$6`@`2````1!8"
M`!````!7%@(`!P```&@6`@`-````<!8"``8```!^%@(`#````(46`@`(````
MDA8"`!H```";%@(`#P```+86`@`2````QA8"``(```#9%@(`!P```-P6`@`)
M````Y!8"``T```#N%@(`#P```/P6`@`K````#!<"``0````X%P(`!P```#T7
M`@`+````11<"``4```!1%P(``@```%<7`@`+````6A<"``$```!M`P``````
M`!($````````:`8``%P#``"M`@``;0<``+L!``!C`P``O0```,0%````````
M`````(L"``#\!@`````````````'````O0$``!P%``#&`P``W`(``.,```!N
M````]@```"H%```!!@```````-`#``#0!```)@(``(4```#^`@``I0,``-4!
M````````M`0``$<!```S!@``SP4``&$'``!$!```U`$```````#:`0``'@``
M`/P!``!2`@```````-````!0`@```````!T%```V`P``"0```(T&````````
MP@,````````H`P``%````($!```]`P````````````"H!0``K@$``!0!``#6
M!```B0<``.`'`````````````/\!`````````````(0$``"O!```RP$``,(&
M````````Y04```````#T`@```````(,&````````,`8``'@'``!0!P``'P(`
M`&4$````````C`8``&<!````````;P````<'``#=!```K@8```````".!P``
MJP$``*T'``"=!0```````,X#``!;````:P8``&T%``"#`0``-0````````!6
M!P```````/L$``"(!@````````````!6!0```````"($``#I`0```````#X&
M```J`P``XP0````````W`0``P00````````3`0````````````!U`P``K`$`
M``@"````````;@4``'P'``"=`0``PP8```````!R`````````+T"```:!P``
M[@(``-8&````````V00``$8%``#P`@``+@4``.X````6`@``B@$``',#``":
M````?`4``*L'`````````````,<&````````V0(``#4'``!:`@``TP```$@!
M````````8P`````````M!P``<`,``"$$`````````````#P%````````!@,`
M`-X&````````B@0``(<%```P!P``_P8`````````````;`$``/`&````````
MN0<````````U`P``I@$``.0%````````:`$```L'``````````````````#B
M!@```````!,"``"T!0```````(`&``!Q!P```````"D"```'`0``#`4`````
M````````WP(``$4'```2`0``DP<``.T"``#M!```7`(``%D```#K!@``TP0`
M`&T!````!0``T0$```````#3!@```````/8%``#``P```````)(%```\!```
M(`8````````S!```W04``+(`````````0`,```````":!```IP0``.T&```Q
M`@```````!D'```_`P``80```(T'``"6`@``5P$`````````````"@0`````
M``#0!0``>P,``)D!``#S!````````&@```#>!```<@0``%\'``!W````OP8`
M`%,$```^`@``$08```````!5`@``$0```*$%````````8@8``%P%````````
M`````-@```!8!0``)P(``,L```##`0`````````````0!0```````-X```#!
M!@```````$0%````````@P(``*0```#[!@``D`4````````=!@``V@4``$4%
M``"3!@``H0<``'`%``#Y!```Y@0``+<'``````````````````!6`@``3P<`
M````````````90(``$D#```C!@``0P4``/$&``"\````X0,`````````````
M!P(``$T"``#:`P``.P,```````!D!P``@`4```````!G!```+P0``*,'````
M````;0(``'H&```F`0``1P,```````"X`@``O@,``&8"``!\!@``Q`0``(4!
M``!"!```!0(``)4"``"$````7`0```````""````(0```*<'``"J!0``@`,`
M`-8!``"V!@``"@,```````#,`@``^P(``)8!``"X`````0,``)P!```S`0``
M#@8``!D#``#(`0``1P(``$H%````````P`4``$T'``"2!P``*04``,@"````
M``````````````!B`P``&0$``/$"``!P`````````.4!``"N`P``2P```*D"
M```[`0``+@,``$,#``"_`0```````#0!``"Q`P``204``/T````(`P``B08`
M`$@#``#V`0``W`$```````#2`0```````)D$````````H@<``,X'````````
M`````#L%``!)!```DP0```````!3!P```````(<!```:`0``(P0``#P!```=
M!P``_@0``,H'``"Q!@``CP```!X%``#Q!0``&@,```````#-````JP4``"4#
M``"`````_`4```````#A!@```````"\%``#%!0``@P4````````M`P``;@$`
M`-('``#%`@``W0```,L$`````````````*<````>`@``*P$`````````````
M`````*\```"@!@``.`0``%8&``!N`P``]`0``!@'``#(````I`<``,(`````
M````!0<``#T$``"P!@```@<``(T#```Y!@``Y@```#0"``!'````$`,``+`%
M````````J`(``"<%```W!````````&$#``#>!P``:04```````"P!P``````
M`)<%````````B0(``-P$``!G!@``)P<````'``"U`@``/0$``+D%````````
M.00```D"``"=!P```````+@#```&````S@8``#P```!>`0``704``(`!``#7
M`P``T`$``$X`````````:08``%,&```;!0``00(``(D```"O!@``'P``````
M````````SP0``(0!``#)````&P,``/D&````````Q`````````"Q`0``````
M`.\"``!5`P```````$@'````````0@<``)@&``#$`P```````!`$``!4!P``
M```````````#!P```````,,`````````S00```````"2!@``S`,```````";
M!@``[@$``(@"``!@!0``:@(``)<&```C`P````````````"Y!```+P<```L%
M``"H!P``YP0``)0!````````Z@$``*8"```+`@``T0````0!``#+`P``````
M`.<#```X!P``P````.T!``!H!``````````````2````<@$``%,"````````
MD@```````````````````,X"``"@`@```````*\%```%`````````.$!````
M````/`8``$X#``!4!```M0<```````!3!0``)`<``````````````````#\'
M```-!````````%H%````````)P,``)@#```Y`@``(P<``!,'``"0````6P$`
M`$8&``#:!P``````````````````>@0```````"3````3`0``.X%````````
M`````)0"````````Z04``,0"```X````/08``'$!``"5`P```````,$`````
M````"@8``)X!``!)!@``F04``+X'````````!@$```````!X`@```````%`!
M``"Y`@``504``(L&``"<!0``600``-<'```L`@``S`4````````,!P``H0$`
M`-8'````````.P(``$P#``",`@``P`0`````````````^P,```````!.`0``
MIP(``%8!``!U`0``/P8`````````````6@,``.`%````````1P4``*0%``#;
M!P``H@$``&H'``!,!@``F`(`````````````:P$``"P'```8!0``#@,``*D'
M``"J!````````)L!``"J`@``]`8```````!"!@```````$T&``"<!```R0$`
M`#,'````````S`$``,H&``!(!0````````````!.!P``W0,``!`'``""!@``
MT@,``$0#````````0P<``#`$`````````````,$!``#(!0```````+,$````
M````>00``/4$```A!P``HP0``#H'``#-`0``PP<``-($````````[0```(D$
M`````````````#$%``!5!P````````````#8!```?@0``'D'``"-!```Z```
M`!(#````````H@```+0&```K!P```````+8#``#_`@``2@$``.D```!B!P``
M>`8```````"%!P```````#\"``!-`0``@P<``+`"````````(@,``&\!``#5
M````?04``&T&```U!```!@<``!("```B!@``A04````````P`@``O`(``"P%
M``!8`@```@4```````"U!@``%@<```H%``""`0````````````"N!0``3`(`
M`*`!``!B````#````#8"``!E`````````+H$````````SP```",`````````
M;`4`````````````B`0```````#]!@``=00```````"C`0```````+\$``#?
M`P``%@4``'L'````````O`8``/`!````````W0<``(0&``#H!0``[@,`````
M``!1!0``:P,``*H`````````(@<``.4&```W`P``U`,``#$&````````304`
M`*L`````````9P(````````Q`0```P0``%@!``!L!@`````````````?!0``
M0`(``(<#````````:0<``$T#`````````````(L%```$!0``FP<``-$%``!"
M`0``%0(``"\&`````````````&`$``!W!```WP```,L&````````````````
M`````````````````````````````.$$```M`0``]P(``#\```"C!@``;`<`
M`#X#``"?!0``9P<```````"R`P``,@4``#\%`````````````#\$``"P`0``
M`````.0`````````5P<``,<`````````608``/T%````````;0```!@&````
M````+@$``!(%``!9!P``^P```'`$``!_````B`$``.4$``#2````Z`8``'T#
M``"*!@```````#4&````````Z00``',%``"+`P``0`0``,P&```=!```````
M`,,$``!]`0``W@4`````````````X0```+L&```3!@``7P4``'\&``!7`@``
MP@0``#H%```,`@``7P0````````0`@``2P(``+D&``#O!0``ZP0``(4&``#H
M`@``S@0``&$&``!&`P```````%X'``!:````%P8``'("``#H`0``Z0,``#<`
M``"=`@``C@$```,!``!0`P```````($'````````P`$``)0$``#T`P``````
M```````B!0``.@8```````"+!```\@8```````"R`@``F@8``.`#````````
M#P$```T'`````````````,X!``"_`P``_@4``.H%````````:`4``/`$``"B
M!0``$````)($``!^!0``-04``&P`````````+00``$$%`````````````'L`
M``!2!@```````+8$````````:`(``*<&``"`!```8P(``)L"````````&`$`
M`"`$``!8!P``6@8``&\&``"L!P``9`8``)(#``#@`0````````````"X!@``
M*@(``'8"``!.!0```````&H&``#F`P``:P`````````?!P``*0`````````W
M!P```````$@"```6!``````````````F`P``TP$``!0"``#%`0``VP```"X&
M````````$P0```````!W!0``Z@,``)X'```@!0``#0(``#`!``"S!0``O`4`
M`!<#``"U!```#@```)P````G`0``\00````````[!P``7````",!```=````
MZ`,``*,#```E`0``00````<%``!O`P```````+H'``"2`0``(`<```<#```P
M!0``*@$``"8&``"T`P``J04```````!;!@``U`8``,@'``!U!@``"````-`'
M`````````````,4#``"=````#@(``'0$````````20<```````#C!0``7P8`
M`#(&``!*!@``;P0`````````````B`<``"8```#*````^@0```8%``";!0``
M]P4``'$&````````````````````````-`,``(0"````````F0(``$,$````
M``````````````#C`P```````(X&``#*`0``8`$``$8!``!1`P``Q00``.<!
M``!V!```#P0``)\'``!^`@``````````````````]P$```\%````````>@$`
M`$`'``````````````````"D!```6@<``````````````04``.8"````````
MM0```/\$`````````````.P#```L`0``%`8```````!F`P``F`<``.(%````
M````?@<``.(```#\`@``E0$```````"]!0``ZP,````````^!````````,4`
M````````9@<``)@!```E!```:@0``#<"```B`@``=P$```````!B`@``]P0`
M`*$"``!=`P``*@8``(H#```5!```/@```+X```#'!P```````#4!``#@!@``
M.P```.X&````````#0````````"``@``O`,``+`#``#:!@``?P$````````X
M`0``I0```+\%`````````````.,&``!R!P``G`(``(@%``#\!```^@(``&8%
M````````5@,``%4````N!P``@P,``-`"```F!0``H@(```D#``#4!```!04`
M`+P'````````[`8``)<#````````E04```````"E`@```P(```````#4!0``
M%P$```X%``#*`P``$P,```````"J`P``8`<``(P$```F!````````(8$````
M`````````&0```!E`P``M@4``!D`````````9`$``+0'``````````````8"
M``"=!```70```/,#``#;!0``:0`````````E!P```````+,'``#T`0``````
M``````#$`0``\0,``$$#```<`0``C`$``.("``!>!```^04`````````````
M`````%0#`````````````/$````Z`0``T@8``+H#``";````^0(``-4&``"[
M`@``K`0``$8$```;!P``9`0```````"9`````````/@$``"!!```.0``````
M```:!@``^0,```````#I`@``2@```)$$`````````````'X#``!``0``6@$`
M``0&```5`P``-@$``%X````#`P``EP<``$$$```G``````````````#3`@``
M_````$<$``"-!0``<P0```````"/!0``+08``+\`````````>`$``-H"````
M````XP(``(8&``!?`P``K08``````````````````$P!`````````````"@!
M```'!@``\`4``+('````````I@4``````````````````#T"``"J!@``#`,`
M``````"V`0```````$("``#T!0``V0,``'$$``!K!P``5@0``-\$```)!```
MSP$``+<%``"W!```<P```+<#``!A!`````````<$````````G@````````!7
M````904``)0#``"1````'@$``%X%``#8`0``T0,``(8```#S`@``4@4`````
M```X`@``B@<```\#````````E`4``&,$````````300```````#;`P``E@0`
M````````````I`$``#8'``#)`P``)P8``!L&``!T!@``AP0``+L```#-`@``
MSP8``)4&``"!!@``8@$``$$'```A`0``^0$``!P$````````O@(``+0!``#U
M`P``_P,``*@!``````````````P!``!&`@``<@,``$(`````````)0(``/``
M```C!0``'@<```\&``">`P``7P(``&D!````````F@4``"D&``#3!0``/0<`
M``D'````````.`8``"0"``"&`@``[P8``#P#``"X`0``.@,``%L"````````
M<0,``)H#``!/`0```````(4#````````00$``"P````<`@``XP<```````",
M`P````````L```#'!```M@(``+,"````````708``+X$``!+!0``0````.(#
M`````````0(``!\$````````I@,``&L%``"D`P``60(```````"C`@``40<`
M```````R`@``]@,`````````````?`$``)X"```3!0```````-4'```<`P``
MM0$``,L%``"@!```,@````@!```R`P``_0,```````````````````````"E
M!0```````+H!``"R!@``3@8``"L"```!`0``=@$``,8$``!I`@``&04``$H$
M``#D!@``+0(``#('``"W`0``XP$``"4```#9!0``=`,``$L&````````?P,`
M`"0#`````````````'`'```L!@````````````````````$``(T```#(`P``
MD0$``.4"````````9`(``#````",!0``!@8```````"7`0``"@````````!;
M!P``LP```,4'```4!```JP8``&X"``#%!@``ZP```%,!``!,!0``Q`<`````
M``#)!P``T0<``,H$``!^`0``&`(``-("``!/!@```````/X&````````BP<`
M``````"M`0``]P8``!D$```L`P````````````#2!0``@0,```D%``#R`@``
M%`4``'T"``"<!P```````+$"```H`@````````````#X````W0$``*8```"Q
M!```D0,``(`'``"&`0``-````-H$``!8!@`````````````#!@``````````
M``#E`````````*P&``!R!0``$`8```H!````````40```"\!````````````
M``````"$!0```````*4$``""!P``VP0``)H"```````````````````>`P``
M@@,```T%``!B!0``G@8``'D```#7!```7P$``.\!````!@``>`4``.0"``"4
M!@``(@```"4%``#1!@``8P$``-4%```````````````````O`@``V0<``.0$
M```I!P``B`,``"@$```O````4@$``&0%````````K`,``"$&```V!0``.`,`
M`.4#``#G`@``3@0``"$#```S`P```````+H%```K!@``_0(```P$``!+`P``
M400``$$&``!T`0``MP(``)H!``#A`@``;P(``,0&``````````````````"D
M!@``D04``*@$``!N!@``V`,``+D!``"R!0```````*H'```%!@``0`8``&L"
M``#?!@``P@<``.P!``!P!@```````,`&``"3!0``%08``/P#``#;`0``'@0`
M``$$``!<!P```````"0!````````I@<```\"``#7`@```````$0'``!<`0``
M100``.0#``!A!0``H@0``(8%````````&P```(($````````&@````````!J
M`P``%@8````````K!```DP(``#($````````ZP(``-$"``#L````=P<`````
M````````>@(`````````````=`````````````````````````#*!0``;@<`
M``````#D`0``EP````````#-!P```````+,!``#U!@```0<``-<&````````
MEP0``,D&````````_@```/0```"P!```R`8```````!S!@``HP`````````/
M!P``V0```&<#``##`@``,00``(H"``!2!```KP,``-P'````````0@4``/H&
M```S`@``*0$``-P%``#A!0```````%4$``!]````CP8``)\&```1`P``=0``
M`)T&``!2`P````````````#&`0``S`<``(P```!0!@``L@$``+X%``"K!```
M`````*4&``"K`P``=P,``%X#``!G`````````&8$`````````````&D#``#J
M!@```````*`'``"1!P``(````$,!```^`0``_@$````````2!P```````$4!
M```7!```>`,``,$'``#@!```"`0``"L#``#L!0``1P<``-,'``!9!0``$0(`
M`(\#````````10```&X$``!V!0``$P````````!E`0``+@```(H%````````
M3P(``````````````````+D````R`0``60$```````!H`P``M@<``/@"``!]
M!P``KP<``'X````M!0``B@````````#J!```5P,``,D"`````````````'L"
M``!O!0``@04``.T%````````=`(``#D%````````<P$``!8```#B!```W`,`
M`'8```#]`0``-P4```````#5`@``]0$``/@#``"M`P``CP<```````#>`0``
MI@0``,`'``````````````````"G`P```@,`````````````U00``&@'```X
M!0```````*L"``"6!0``(`(```````#W`P``A@<`````````````=`4``+L%
M``#5`P``=@8``#P'``#1!```CP0``)X%``#4````)P0``-@&````````'0$`
M`*4'``#)!0``S@``````````````E0```'<"``#Z!0```````+$````(!0``
M`````(X#``!/!```%P```(D#``#P`P``>04``%0&``"0`0```````"0&```I
M`P``C`<``+0```````````````````#0!@```````,H"`````````````(<"
M``"0!P``"`8``+T$``#<!@``!`(``-8"``!R!@``-@```*4!```0`0``O08`
M`*D&```@`0``8P<``%L#```-`P``V`<``!D"``!W!@``Y@8```````#,````
M``````````#'`P``\@0``.H```#!`P``2P0``$,```#K!0``"P0````````%
M`P``ZP$``%`$``!4````D`,````````Q`P````(``*`%``"2`@``N`0``.\$
M``#]!```$0$````````J!P```````,\#``!2!P```````,$"````````^@$`
M`*P```!9`P``]@(``/,%``#!!0``W0(``)0'```+`0``E@8```````!L`@``
MN@8``%\`````````"0$``"@&``"0!````````$\```"_!P``#0$``!8!````
M````Q@<```````"$`P``*P```$<&````````H00``#H"``!L!````````,,%
M``".!```=@,``(X%`````````````-8%`````````@(```X$``![!```````
M```````P`P```````)X$``#L!`````````````#=!@```````+$'``!J`0``
M`````!P&``"+`0``!````+T'````````RP<``+4%```=`@``:P0``#\!``"^
M!@``F````"4&``"Z````S@4``#D#``!3`P``WP4``.('````````9@8`````
M````````?@8``*(&``#_!0``\P8``````````````````"\#``!\`P``\@,`
M``````!5!@```````-D&```I!````````&H%``"%`@``\0$``,,#``#O````
M=0(``*D`````````F`0``/\`````````WP$```````!8``````````````"^
M`0``3@(``-X"``#8`@``80$````````.`0``@0```-<!``!U!0``3P,``%T$
M``!Q````H`,``````````````````*@&``!5`0``U@````````"'!@``]P``
M``@'``!=`@``E@```'D&``"W!@``H0,``*T$``"\`0````````````!&````
M`````&P#``".`@```````#<&````````6P4``'D#``#I!@``2@<``$\%``#G
M````0@,`````````````>P4``-<````5`0``KP$``/,!```$!```F`4``#0%
M```U`@``Y@4```````#J`@``(P(``*D!``#;`@``/`(``&\'``!0````````
M`!\!````````?`````````#4`@``Q@(``','``"S`P````````````#L`@``
M`````'\%``!,````K04``.\#``!*`P``!@0``#0'```>!@``%P(``,<"``!>
M`@``&````'$%``"Y`P``(0(``/(`````````.@0````#````````L````,8%
M````````#P```.@$```2!@``,0```)`&````````!`<```````!+`0``@@(`
M`$8'```#````>0(````````8`P```````)$&``!$````-`0````````Q!P``
M^0```%,```#7!0``#`8```````!7!@``2`0```````!]!```>`````````"\
M!````````*D#``#Z`P``+@0``+T#````````>@<```````"#````?P0``'L!
M``#X`0```````"8'````````,P4``````````````````*,%```M````````
M`*@```!C!0``40$``"H$``!G!0``L@0``*P"``"(````(@$``!P```"Q!0``
M``````````!Q`@``Q@````L&``#-`P````````````"X!P``?P<``#D'```^
M!P``FP,```````"/`@``E0<``(,$``#^`P``"@(``/H```"U`P``6`0``*D$
M``#R`0``/@4``+L#`````````````&`#``"H`P``1`(``,L"``#>`P``90<`
M``T&``#&!@```````-D!``#M`P``K0```'8'``"S!@``108```````"_`@``
M&P0``&D$````````NP<```````!`!0``E@,``#,```"N!P```````#T```!]
M!@```````-P```!,!P```````#8&``"N`````````.<&````````U@,`````
M``"@`````````````````````````"P$````````K@0``'P"``"N`@``9@$`
M`.(!``#X!@``U`<``!$'``!B!```C@```,D$``!U!P```````$D````N`@``
MH08````````"!@```````%`%``!X!```2`8``)H'````````7`8``/L%``"-
M`@```````)L$```D!```70$``)D'```4!P``$00``*H!``!E!@``P@4`````
M```.!P``1`8``%0!``#;!@```````.````"?`@``GP,``#0&````````````
M`$@```!@!@``1`$``.8!```D!0``.P0``!L"```:`@```````%8```"'!P``
MI`(``&`"````````.P8``(D!```"`0``S`0``+8```!M!````````+L$``"+
M````G`,``(D%``````````````````!7!0```````)$"```+`P```````*\"
M``"W``````````````![!@``P`(````````1!0````````````#(!```E@<`
M`$4#````````GP0````````5````!00``*<%````````&@4```($````````
MTP,```````!1`@``%`,``"0`````````^P$``/4%``!)`0``A`<``,\"``!2
M````QP$````````8!```.@```%0"``"'````!`,``-@%````````"@<``!L!
M````````]@0``%X&``"4````:@```'\"``"A````%04``)4$``#U````<`$`
M`"@%````````H@,``&````!7!```?`0``%H$``````````````````"0`@``
MYP4```````!F`````````)D#```:!```]@8``!P'````````(`,`````````
M````%P<``&$"``"?`0``P@(``.$'``!%`@```````!8#``#/!P``EP(``),#
M````````(04```4!``"9!@```````$,&``!8`P````````````!;!```G`8`
M`*8&```J````%0<``(T!``#X!0```````+H"``"=`P``]0(``.0'````````
M5`4```````#-!0``S08``,<%````````.0$``$H"``""!0``%P4``'H```!S
M`@``P@$``*<!``!C!@``&08``"@'````````'P,``+0"``!D`P``[@0``$L'
M``"L!0````0``'D!``!#`@``"08``/,```"X!0```````/(%```H````````
M`($"```V!````@````````!Z`P```P4``'H%```]!0``=`<``(4$````````
M`````)\````?!@``A@,``.`"``!-`````````-H`````````WP<``"L%``"3
M`0```````$D"``!=!P````````````!P`@``'0,``%$&````````CP$`````
M`````````"`F(S$U,3L@)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+@`@*"5S(&1A>7,@
M86=O*0`@*$%C8V5S<VME>2`E<RD`("A296%D(&]N;'DI`"`H:6X@)7,@9&%Y
M<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T97)D87DI`"!A="``(B5S
M(B!I<R!N;W0@82!D:7)E8W1O<GDN`"(E<R(@:7,@;F]T(&$@=F%L:60@8VAO
M:6-E+@`B)7,B(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I
M<W1R>2X`(B5S(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"X`(B5S(B!W87,@
M861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O
M('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A=&5D
M.B`E<RX`)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2D`
M)60@)7,@86YD("5S`"5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I
M<F5S+@`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I
M;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA
M=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N
M=``E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@:&%S(&-A;F-E
M;&QE9"`E<RX`)7,@:&%S(')E<&QI960@=&\@82!F<F5E+V)U<WD@<F5Q=65S
M="X`)7,@:&%S(')E<&QI960@=&\@=&AE(&EN=FET871I;VX@=&\@)7,N`"5S
M(&AA<R!S96YT('EO=2!F<F5E+V)U<WD@:6YF;W)M871I;VXN`"5S(&ES(')E
M861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE
M8VME9"!B96QO=RX@0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS
M*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92X`)7,@:7,@<F5Q
M=6ER960`)7,@;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S(')E<75E<W1S('EO
M=7(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@`E<R!R97%U97-T<R!Y;W5R('!R
M97-E;F-E(&%T("5S+@`E<R!T;R`E<R!O9B`E<P`E<R!W:7-H97,@=&\@861D
M('1O("5S+@`E<R!W:7-H97,@=&\@;6%K92!Y;W4@87=A<F4@;V8@)7,N`"5S
M('=I<VAE<R!T;R!R96-E:79E('1H92!L871E<W0@:6YF;W)M871I;VX@86)O
M=70@)7,N`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L96YD87(`)7,G<R!.
M;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"5S.B!4:&ES(&UE<W-A9V4@
M;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@
M;V8@9F]L;&]W:6YG(&%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@
M=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BX`+"!G
M=7-T:6YG(``L(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M("5S('1O
M("5S`"TM('-E;&5C="`M+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA
M=``R-"!H;W5R<P`\4')E=FEO=7,`02!D871A8F%S92!B86-K96YD(&ES(')E
M<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA<R!O8V-U
M<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@
M82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E
M<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV
M871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D
M96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!0
M1U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A
M(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@
M82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-
M12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@
M;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N
M8W)Y<'0@82!M97-S86=E+@!!32!#;&]U9',`04T@3&EG:'0@4F%I;@!!32!2
M86EN`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W97)S`$%-+U!-`$%022!)1`!!
M8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B;W1T;VT`06)S;6ED9&QE
M`$%C8V5P="!R97%U97-T`$%C8V5P=&5D`$%C8V5S<R!D96YI960@8W)E871I
M;F<@5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@
M9FEL92X`06-C;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A<W-W;W)D`$%C
M8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%C=&EO;G,`061D`$%D9"`E<P!!
M9&0@0VAI;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z
M`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD
M(&=R;W5P('1O("(E<R(`061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`B)7,B
M`$%D9"!A(&YE=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!
M9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`
M061D('1H:7,@=&\@;7D@8V%L96YD87(`061D('1O(&%D9')E<W,@8F]O:SH`
M061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1E9"`B)7,B('1O
M('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG
M;G5P(&EN9F]R;6%T:6]N.B`E<RX`061D960@(B5S(B!T;R!T:&4@<WES=&5M
M+B!9;W4@8V%N(&QO9R!I;B!N;W<N`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE
M9"X`061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E="!P97)M
M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S`$%F
M9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&EG;FUE
M;G0Z`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L
M;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT:7!L92!A
M9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`
M06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E
M($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N
M871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E<FYA
M=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`06X@97)R;W(@;V-C=7)R960@9F]L
M;&]W:6YG('1H:7,@;&EN:SH@)7,`06X@:6QL96=A;"!V86QU92!W87,@<W!E
M8VEF:65D+@!!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+@!!;F1O<G)A
M`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`06YS=V5R`$%N=&%R
M8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D80!!<'!L:6-A=&EO;@!!<'!L:6-A
M=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L>2!T;R!#:&EL
M9"!3:&%R97,`07!P<F]V90!!<'!R;WAI;6%T92!3:7IE`$%P<FEL`$%R86)I
M8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA
M;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P
M(')E<75E<W0@9F]R("5S(#\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E
M;&5T92`B)7,B(&%N9"!A;GD@<W5B+6=R;W5P<S\`07)G96YT:6YA`$%R;65N
M:6$`07)M96YI86X@*$%235-#24DM."D`07)T`$%R=6)A`$%S8V5N<VEO;B!)
M<VQA;F0`07-C:6D@07)T`$%S:6$O4&%C:69I8R!296=I;VX`07-K(&9O<B!C
M;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1A8VAE9"!I<R!A;B!I0V%L96YD
M87(@9FEL92!R97!L>2!T;R!A(')E<75E<W0@>6]U('-E;G0`071T96UP="!T
M;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L
M971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I
M="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@
M82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=&5N9&5E<P!!='1R:6)U=&5S`$%U
M9W5S=`!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@
M:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y<G5S.B!"86-K96YD
M(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N`$%U=&A?8WER
M=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]F
M='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE
M(%!(4"!W:71H('1H92`M+65N86)L92UF='`@<W=I=&-H+@!!=71H7VEM87`Z
M(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]K<F(U
M.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A
M<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$
M:7)E8W1O<GD`075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P
M<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5Q=6ER
M960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L
M92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S`$%U=&A?
M;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S`$%U=&A?;&1A<#H@57!D
M871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C
M=&]R>2X`075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F
M86EL960N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F
M86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S
M97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!!
M=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N`$%V86EL
M86)L92!F:65L9',Z`$%W86ET:6YG(%)E<W!O;G-E`$%Z97)B86EJ86X`07IU
M<@!"3T9(($5X8W5S97,`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A
M9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"
M86AA;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S
M:`!"87(@5&EM90!"87(@=&EM90!"87)B861O<P!"87)B:64`0F%S92!G<F%P
M:&EC<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`$)A<V5L:6YE`$)E;&%R
M=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R;75D80!":'5T86X`0FER=&AD
M87D`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`
M0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";'5E($UO;VX`0FQU92!A;F0@
M5VAI=&4`0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H
M:6-K;F5S<SH`0F]R9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`
M0F]T<W=A;F$`0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@
M26YD:6%N($]C96%N(%1E<G)I=&]R>0!"<F]W;@!"<G5N96D@1&%R=7-S86QA
M;0!"=6QG87)I80!"=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)N="!/
M<F%N9V4`0G5R=6YD:0!#35,`0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S
M`$-?96QL(%!R;W!E<G1I97,N+BX`0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L
M971E9"X`0V%L96YD87(`0V%L;0!#86UB;V1I80!#86UE<F]O;@!#86UO=69L
M86=E`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N
M=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B!N;W0@=W)I=&4@=&\@9FEL
M92`B)7,B`$-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H86YD
M;&5R<RX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`0V%N)W0@
M;W!E;B!F:6QE("(E<R(N`$-A;F%D80!#86YC96P`0V%N8V5L(%!R;V)L96T@
M4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A
M('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D('=I=&AO=70@
M)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D:7)E8W1O
M<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N`$-A
M;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A<&4@
M5F5R9&4`0V%P=&EO;@!#87)R:65R`$-A=&5G;W)I97,@86YD($QA8F5L<P!#
M87EM86X@27-L86YD<P!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE<P!#96QL
M('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;&QP
M:&]N90!#96QT:6,@*$E33RTX.#4Y+3$T*0!#96YT97(`0V5N=')A;"!!9G)I
M8V%N(%)E<'5B;&EC`$-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I`$-E
M<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A=&4@3W=N97(`0V5R=&EF:6-A
M=&4@4&]L:6-I97,`0VAA9`!#:&%I<B!097)S;VX`0VAA;F=E`$-H86YG92!9
M;W5R(%!A<W-W;W)D`$-H86YG92!D969A=6QT(&ED96YT:71Y`$-H86YG92!T
M:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y
M(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%N9VEN9R!Y;W5R
M('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C
M;VYF:6=U<F%T:6]N+B`@0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-H
M87(`0VAE8U]K($QI;FLN+BX`0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A
M=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92X`0VAI
M;&4`0VAI;F$`0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@
M5')A9&ET:6]N86P@*$)I9S4I`$-H;V]S92!!<'!L:6-A=&EO;CH`0VAO;W-E
M(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&%N(&%C=&EO
M;CH`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S
M='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VAR:7-T;6%S($ES;&%N
M9`!#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE87(`0VQE
M87(@35-/9F9I8V4@=&%G<P!#;&5A<B!1=65R>0!#;&5A<B!O=70@=7-E<CH@
M)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQE87)I;F<@3&%T90!#
M;&EC:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL('9I82!(5%10`$-L;W-E(%=I
M;F1O=P!#;&]U9',`0VQO=61S($5A<FQY`$-L;W5D>0!#;V-O<R`H2V5E;&EN
M9RD@27-L86YD<P!#;VQL87!S92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S
M`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N
M`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3
M:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP
M;&5T960`0V]M<&]S92!-97-S86=E("@E<RD`0V]M<'5T97)S`$-O;F1I=&EO
M;@!#;VYD:71I;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R96YC97,`0V]N9FEG
M=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N
M9"!/=71L;V]K+@!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+@!#;VYF
M:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E
M;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#
M;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T
M;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C=',`0V]N=&%C=',@=V5R92!S
M=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O;G1E
M;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z(`!#;VYT96YT<R!O9B`B)7,B
M`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#;V]K:64`0V]P>0!#;W!Y(&9A:6QE
M9#H@)7,`0V]P>2!S96QE8W1I;VX`0V]R;F9L;W=E<@!#;W-T($E$`$-O<W1A
M(%)I8V$`0V]T92!D)TEV;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S
M<V%G92X`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z(`!#;W5L9"!N
M;W0@4$=0('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A
M9V4Z(`!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@
M;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C
M="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO
M="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0
M('-E<G9E<BX`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("(E<R(@=7-I
M;F<@1E10.B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82X`0V]U;&0@;F]T(&1E
M8W)Y<'0@4$=0(&1A=&$Z(`!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T
M82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L
M971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5L971E('-E
M='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$-O=6QD(&YO="!D971E<FUI;F4@
M=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N;W0@9F5T
M8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N;W0@9F5T8V@@8V]M
M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO="!F971C:"!T:&4@
M8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N`$-O=6QD(&YO
M="!L;V%D('-T<F%T96=Y("(E<R(N`$-O=6QD(&YO="!L;V%D('-T<F%T96=Y
M("<E<R<N`$-O=6QD(&YO="!M:V1I<B`B)7,B+@!#;W5L9"!N;W0@;6MD:7(@
M)R5S)RX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME
M>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN9RX`0V]U
M;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N("<E<R<@9F]R('=R:71I
M;F<N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S
M`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B)7,B+@!#;W5L9"!N;W0@;W!E
M;B!D:7)E8W1O<GD@)R5S)RX`0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E
M<G9E<BX`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@
M<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@
M;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@
M8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE
M<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R
M:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U
M=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A
M<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O
M=6QD(&YO="!R;61I<B`B)7,B+@!#;W5L9"!N;W0@<FUD:7(@)R5S)RX`0V]U
M;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@
M82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU
M<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD(&YO="!S879E('-E='5P('5P9W)A
M9&4@<V-R:7!T('1O.B`B)7,B+@!#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P
M(&-O;F9I9W5R871I;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O
M;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O
M9B!T:&4@;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@
M8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@;F]T
M('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U;FQI;FL@(B5S
M(BX`0V]U;&0@;F]T('5N;&EN:R`G)7,G+@!#;W5L9"!N;W0@=7!D871E(&-O
M;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S`$-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B`B)7,B.B`E
M<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R
M92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5L9&XG="!G:79E('5S97(@(B5S
M(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B.B`E
M<P!#;W5N=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@
M82!L:6YK`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S`$-R
M96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`
M0W5B80!#=7)R96YT(#0@4&AA<V5S`$-U<G)E;G0@4V5S<VEO;G,`0W5R<F5N
M="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@57-E<G,`0W5R<F5N="!7
M96%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T
M;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@
M<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H
M5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`0WIE
M8V@@4F5P=6)L:6,`1$0`1&%I;'D`1&%T851R964@0G)O=W-E<@!$871A8F%S
M92!,;V]K=7``1&%T90!$871E(%)E8V5I=F5D`$1A=&4@<V5L96-T:6]N`$1A
M>0!$95]L971E($-O;'5M;@!$96-E;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C
M;&EN960`1&5C<F5A<V4@26YD96YT`$1E9F%U;'0`1&5F875L="!#;VQO<@!$
M969A=6QT($ED96YT:71Y`$1E9F%U;'0@4VAE;&P`1&5F:6YI=&EO;G,`1&5L
M96=A=&4@<&]S:71I;VX`1&5L96=A=&5D`$1E;&5T90!$96QE=&4@0V5L;`!$
M96QE=&4@1W)O=7``1&5L971E($QO9P!$96QE=&4@4&5R;6ES<VEO;@!$96QE
M=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C;VQU
M;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@
M;65S<V%G97,`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T92!P
M97)M:7-S:6]N<R!F;W(@(B5S(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`
M1&5L971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('-U
M8B!F;VQD97)S`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L971E('1H
M92!C=7)R96YT(')O=P!$96QE=&4@=&AI<R!L:6YK`$1E;&5T960@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@(B5S(BX`1&5L:79E<GD@=&EM90!$96YM87)K`$1E
M;GD@<F5Q=65S=`!$96YY(')E<75E<W0@9F]R(&9R964O8G5S>2!I;F9O<FUA
M=&EO;@!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS
M("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N
M(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E
M=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@
M`$1I<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L
M969T`$1I<F5C=&]R>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@
M3W!T:6]N<P!$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T`$1I<W!L87D@9F]R
M96-A<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`1&EV:61E<@!$:FEB;W5T:0!$
M;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N
M8V4N<&AP`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N
M86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V%N(%)E<'5B
M;&EC`$1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"X`1&]W;FQO860`
M1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@
M87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-86EL`$5-
M86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H
M('!R;W9I9&4@=&AI<R!S97)V:6-E+@!%4E(`16-U861O<@!%9&ET`$5D:70@
M0FQO8VL`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S
M:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R
M.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO;G,@
M9F]R("5S`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN
M`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@
M;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M86EL+71O+5--4R!'
M871E=V%Y`$5M;W1I8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N
M`$5M<'1Y('-E87)C:"!T97)M<P!%;F0`16YD('EE87(`16YL87)G92!%9&ET
M;W(`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5N=&5R('1H92!L971T97)S
M(&)E;&]W.@!%<G)O<@!%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,`17)R;W(@
M9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S`$5R<F]R(&1E;&5T:6YG('-Y;F,@
M;&]G.B`E<P!%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S`$5R<F]R('-E;F1I
M;F<@<F5P;'DZ("5S+@!%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,`17)R
M;W(@=W)I=&EN9R`B)7,B+@!%<G)O<B!W<FET:6YG("<E<R<N`$5S=&]N:6$`
M171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y
M(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%
M=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP
M;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%>'!E
M8W1E9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@
M=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`1D<@0V]L;W(`1E10('5P
M;&]A9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`
M1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C
M;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S
M(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T92!N
M97<@4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&
M86EL960@=&\@<F5T<FEE=F4Z("5S`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H
M36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&87AE
M<P!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R
M<P!&97<@4VYO=R!3:&]W97)S`$9I96QD(&UA=')I>`!&:6=L970@0T%05$-(
M00!&:6=L970@9F]N=`!&:6II`$9I;&4`1FEL92!#;W5N=#H@)7,@9FEL90!&
M:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I
M;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P
M<&]R=&5D+@!&:6QT97)S`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!1=6%R
M=&5R`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R`$9O;V0`
M1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`1F]R96-A
M<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE
M9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82!L87)G
M92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*0!&
M;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y
M<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9',`1G(`1G)A
M;65S`$9R86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&<F5E+T)U<WD@26YF
M;W)M871I;VX`1G)E92]"=7-Y(%)E<&QY`$9R964O0G5S>2!297%U97-T`$9R
M964O0G5S>2!297%U97-T(%)E<W!O;G-E`$9R96YC:"!'=6EA;F$`1G)E;F-H
M(%!O;'EN97-I80!&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O;0!&
M<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE
M`$=A8F]N`$=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=A
M;6)I80!'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E
M`$=E;W)G:6$`1V5R;6%N>0!':&%N80!':6)R86QT87(`1VEV96X@3F%M90!'
M;&]B86P@3W!T:6]N<P!';P!';V5D96P`1V]O9VQE($UA<',`1V]O9VQE(%-E
M87)C:`!'<F%Y<V-A;&4`1W)E96-E`$=R965N`$=R965N;&%N9`!'<F5N861A
M`$=R97D`1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7!?;&1A<#H@56YA8FQE
M('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9#H@`$=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,`1W)O
M=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<P!'<F]U<',`1W5A
M;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W0@
M4V5R=FEC97,`1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N
M80!(5$U,`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H
M92!L87-T(&-E;&P@:6X@<F]W+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S
M('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T
M86)L92X`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA
M<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE861E<G,`2&5A<F0@27-L86YD
M(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE879Y(%0M4W1O<FT`2&5B<F5W("A)
M4T\M.#@U.2TX+4DI`$AE:6=H=`!(96EG:'0@*&EN('!I>&5L<RD`2&5L<`!(
M96QP('5S:6YG(&5D:71O<@!(96QP97(`2&5M:7-P:&5R90!(97)E(&ES('1H
M92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AI9V@`2&]?;64`2&]M90!(;VUE
M($%D9')E<W,`2&]M92!$:7)E8W1O<GD`2&]M92!0:&]N90!(;VYD=7)A<P!(
M;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A
M=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@3F\@
M;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z
M($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,`2&]R
M9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`2&]R9&4O
M2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D
M;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C
M<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E
M("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S
M(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R
M97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E<R(`2&]R:7IO
M;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W<@
M9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@;6%N>2!C
M;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L
M9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y
M;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ(`!(=6UO<FES
M=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)
M34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@
M<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S`$E0($%D9')E
M<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W
M960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)7VYS97)T
M(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS(&9O<B`E<P!)
M8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I<R!N;W0@
M9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W
M:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R
M;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@
M=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U('-E92!T:&ES
M(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@
M=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EM
M86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E(&9R;VT@
M9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G
M97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E
M9"!F:65L9',Z`$EN(%!R;V-E<W,`26Y?<V5R="!2;W<@069T97(`26YC;W)R
M96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E8W0@=7-E<FYA;64@86YD
M+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E
M(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R
M871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$EN8W)E87-E($EN9&5N
M=`!);F1I80!);F1I=FED=6%L(%5S97)S`$EN9&]N97-I80!);F9O`$EN9F]R
M;6%T:6]N`$EN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N`$EN<V5R
M="!#7V]L=6UN($%F=&5R`$EN<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS
M97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N
M97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@
M8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O
M=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O
M<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T
M:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE
M(&-U<G)E;G0@;F]D90!);G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R
M="!C96QL(&%F=&5R`$EN<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN
M(&%F=&5R`$EN<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R="!M97-S86=E<P!)
M;G-E<G0@<&%R86=R87!H(&%F=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E
M`$EN<V5R="!R;W<@869T97(`26YS97)T(')O=R!B969O<F4`26YS97)T('1H
M92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.@!)
M;G-E<G0O36]D:69Y($EM86=E`$EN<V5R="]-;V1I9GD@3&EN:P!);G-U9F9I
M8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T
M+@!);G-U9F9I8VEE;G0@8W)E9&ET+@!);G1E9V5R`$EN=&5G97(@;&ES=`!)
M;G9A;&ED($%C=&EO;B!S96QE8W1E9"!F;W(@=&AI<R!C;VUP;VYE;G0N`$EN
M=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L:60@6DE0(&1A
M=&$`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV
M86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R
M97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;&EC96YS92!K97DN
M`$EN=F%L:60@;&]C871I;VX@<')O=FED960N`$EN=F%L:60@;7-G7W1Y<&4N
M`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN
M9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A
M;&ED('!A<G1N97(@:60N`$EN=F%L:60@<')O9'5C="!C;V1E+@!);G9A;&ED
M('!R;W1O8V]L+@!);G9A;&ED(')E8VEP:65N=#H@(B5S(@!);G9A;&ED('-H
M87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N
M:6-O9&4@9&%T82X`26YV96YT;W)Y`$EN=F5R="!S96QE8W1I;VX`27)A;BP@
M27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`
M27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`
M2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`
M2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E
M<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2V5N
M>6$`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+
M97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y
M<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC
M(&ME>7-E<G9E<BX`2VED<P!+:7)I8F%T:0!+;VQA8@!+;W)E82P@1&5M;V-R
M871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`
M2V]R96%N("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$QA7WEO=70`3&%N
M9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!(
M86QF`$QA<W0@4&%S<W=O<F0@0VAA;F=E`$QA<W0@475A<G1E<@!,87-T(%5P
M9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`
M3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA`$QA=F5N9&5R`$QA=P!,87EO=70`
M3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`3&5F="!H
M96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,979E;`!,:6)E<FEA`$QI8GEA
M;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H="!";'5E`$QI
M9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT
M(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@
M5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K
M`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@
M=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN
M=7@@0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T
M($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M
M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S
M=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@<V5S
M<VEO;G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&9A:6QE9#H@)7,`3&ES
M=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N:6$`
M3&]A9&EN9RXN+@!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T
M:6]N`$QO9R!I;@!,;V<@;W5T`$QO9VEN`$QO9VEN(%1A<VMS`$QO9VEN(&9A
M:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N
M=&5R960@:6YC;W)R96-T;'DN`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO
M=F4`3&]W`$QO=V5R(&=R965K(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R
M<P!,;W=E<B!R;VUA;B!N=6UB97)S`$QO>6]L80!,;WEO;&$@0FQU90!,=7AE
M;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N
M;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S
M;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%G:6,`36%I;`!-86EL($%D
M;6EN`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA
M;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA
M=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D
M('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA
M<`!-87!P:6YG<R!S=&]R960N`$UA<F-H`$UA<F=I;@!-87)K('=I=&@@4V5E
M;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM
M<&]R=&%N="]!;G-W97)E9"D`36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E
M`$UA=&-H:6YG(&9I96QD<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87@@86QL
M;W=E9"!C<F5D:70N`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@
M=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``
M36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<P!-87AI;75M(&QE;F=T
M:`!-87D`36%Y;W1T90!-961I8VEN90!-965T:6YG($-A;F-E;&QA=&EO;@!-
M965T:6YG($EN9F]R;6%T:6]N`$UE971I;F<@4')O<&]S86P`365E=&EN9R!2
M97!L>0!-965T:6YG(%5P9&%T90!-965T:6YG(%5P9&%T92!297%U97-T`$UE
M;6)E<G,`365N=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@
M5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF
M:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N
M`$UE<W-A9V4@='EP90!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A
M=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@
M:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&%R
M1$(@:7,@;F]T(&-O;FYE8W1E9"X`365T:&]D`$UE=&AO9"`B)7,B(&ES(&YO
M="!D969I;F5D`$UE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@
M)7,`365T<FEC`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S
M(&]F`$UI9&1L90!-:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@
M`$UI;B!T96UP(&QA<W0@-B!H;W5R<SH@`$UI;FEM=6T@<&%S<W=O<F0@86=E
M(&AA<R!N;W0@>65T(&5X<&ER960`36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES
M<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O;F9I
M9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@
M=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E
M($E$+@!-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S
M:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF
M:65D($1A=&4`36]D:69Y(%523`!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC
M(&]F`$UO;F%C;P!-;VYG;VQI80!-;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO
M;G1S97)R870`36]O;B!0:&%S97,`36]R92!F:65L9',@9F]U;F0@:6X@;&EN
M92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"X`36]R;V-C;P!-;W-T;'D@0VQE
M87(`36]S=&QY($-L;W5D>0!-;W-T;'D@4W5N;GD`36]V92!$;W=N`$UO=F4@
M3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V92!D;W=N`$UO=F4@=7``36]Z
M86UB:7%U90!-;WII;&QA`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-
M=6QT:6UA<"!52R!M87``375L=&EP;&4@<V5L96-T:6]N`$UY($%C8V]U;G0`
M37D@06-C;W5N="!);F9O<FUA=&EO;@!->2!0;W)T86P`37D@4&]R=&%L($QA
M>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YA;6EB:6$`
M3F%U<G4`3F585`!.965D<R!!8W1I;VX`3F5P86P`3F5T:&5R;&%N9',`3F5T
M:&5R;&%N9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@
M4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@
M4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0`
M3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R`$YE=R!#
M86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!-97-S86=E('1O("5S`$YE=R!-
M;V]N`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!P
M87-S=V]R9`!.97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N`$YE=R!P
M87-S=V]R9',@9&]N)W0@;6%T8V@N`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W
M<P!.97=S9W)O=7!S`$YE>'0`3F5X="`T(%!H87-E<P!.97AT(&]P=&EO;G,`
M3F5X=#X`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.
M;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R
M96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)
M4T\@:6UA9V5S+@!.;R!B871C:"!T96UP;&%T92X`3F\@8FQO8VL@97AI<W1S
M(&%T('1H92!R97%U97-T960@<&]S:71I;VX`3F\@8V%L96YD87(@;F%M92!P
M<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BX`3F\@8VAA;F=E+@!.
M;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+@!.
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N
M`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&
M5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N`$YO
M(&1E<V-R:7!T:6]N(&9O=6YD`$YO(&1E<W1I;F%T:6]N('-U<'!L:65D+@!.
M;R!F:6QE('5P;&]A9&5D`$YO(&EC;VYS(&9O=6YD+@!.;R!L;V-A=&EO;B!I
M<R!S970N`$YO(&QO8V%T:6]N('!R;W9I9&5D+@!.;R!M97-S86=E('-U<'!L
M:65D+@!.;R!N86UE('-P96-I9FEE9"X`3F\@;G5M8F5R('-P96-I9FEE9"X`
M3F\@;V9F96YS:79E(&9O<G1U;F5S`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!(5%10(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@24U!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN`$YO('!E;F1I;F<@
M<VEG;G5P<RX`3F\@<75O=&$@<V5T`$YO('%U;W1A('-E="X`3F\@<G5L97,`
M3F\@<V5P87)A=&]R('-P96-I9FEE9"X`3F\@<VED97,`3F\@<W5C:"!F:6QE
M`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`
M3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N`$YO('9A;&ED(%A-
M3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN
M(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A
M=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN
M(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N(%!A<G1I8VEP86YT`$YO
M;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)F;VQK($ES;&%N9`!.;W)T:&5R
M;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`
M3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!I;7!L
M96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W1H:6YG
M('1O(&)R;W=S92P@9V\@8F%C:RX`3F]T:6-E`$YO=F5M8F5R`$YU;6)E<@!.
M=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@
M;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN
M(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/8FIE8W0`3V)J96-T($-R96%T;W(`
M3V-T86P`3V-T;V)E<@!/9F9E;G-E(&9I;'1E<@!/9F9I8V4`3VQD(&%N9"!N
M97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+@!/;&0@<&%S<W=O<F0`
M3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+@!/;6%N`$]N;'D@24U!4"!S
M97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N`$]N;'D@;V9F96YS:79E
M(&9O<G1U;F5S`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"X`3VYL
M>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG
M92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`
M3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T
M(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="X`3W!E;G,@
M=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M`$]P
M=&EO;F%L(%!A<G1I8VEP86YT`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D
M97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R
M9V%N:7II;F<`3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN
M86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/
M=VYE<B!097)M:7-S:6]N<P!004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V
M86EL86)L92X`4$5!4CHZ36%I;"!B86-K96YD`%!'4"!$:6=I=&%L(%-I9VYA
M='5R90!01U`@16YC<GEP=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I
M9VYE9"]%;F-R>7!T960@1&%T80!02%`@0V]D90!02%`@4VAE;&P`4$T@3&EG
M:'0@4F%I;@!032!286EN`%!-(%-H;W=E<G,`4$T@4VYO=P!032!3;F]W(%-H
M;W=E<G,`4$T@4W5N`%!-(%0M4W1O<FUS`%!/4TE8(&5X=&5N<VEO;B!I<R!M
M:7-S:6YG`%!?2%`@4VAE;&P`4&%D9&EN9P!086MI<W1A;@!086QA=0!086QE
M<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D`%!A;F%M80!087!U82!.97<@
M1W5I;F5A`%!A<F%G=6%Y`%!A<G1L>2!#;&]U9'D`4&%S<W=O<F0`4&%S<W=O
M<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN`%!A<W-W;W)D(&EN8V]R<F5C=`!0
M87-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!0
M87-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z
M(`!087-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP
M8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z`%!E;W!L90!097)C96YT`%!E
M<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO
M;B`B)7,B(&YO="!D96QE=&5D+@!097)M:7-S:6]N($1E;FEE9`!097)M:7-S
M:6]N<P!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!097)S;VYA;"!);F9O
M<FUA=&EO;@!097)U`%!E=',`4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I
M=&-A:7)N`%!I>&5L<P!0;&%T:71U9&5S`%!L96%S92!C;&EC:R!I;G1O('-O
M;64@8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V
M92!T:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@
M=&\@=6YL:6YK('1H:7,@96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@
M86YD(&$@>65A<BX`4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C
M871E9V]R>3H`4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RX`4&QE
M87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D
M87ES(&EN('1H92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`
M4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A
M<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A<V4@
M<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N("!9;W4@35535"!A9W)E92!W:71H
M('1H92!T97)M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E(')E860@=&AE
M(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M
M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E(')E=FEE=R!T:&4@9F]L;&]W
M:6YG(&EN9F]R;6%T:6]N+"!A;F0@=&AE;B!S96QE8W0@86X@86-T:6]N(&9R
M;VT@=&AE(&UE;G4@8F5L;W<N`%!L96%S92!S96QE8W0@86X@86-T:6]N(&9R
M;VT@=&AE(&UE;G4@8F5L;W<N`%!L96%S92!T>7!E('1H92!N97<@8V%T96=O
M<GD@;F%M93H`4&]L86YD`%!O;&ET:6-S`%!O;&QS`%!O<G1U9V%L`%!O<VET
M:6]N:6YG(&]F('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L
M90!0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`
M4&]S=&YU:V4`4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``
M4')E8VEP:71A=&EO;CQB<B`O/F-H86YC90!0<F5F<U]L9&%P.B!297%U:7)E
M9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E
M<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`
M4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R
M979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V:6]U<R!O<'1I
M;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE
M;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y
M`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R!+97D@26YF;P!0=6)L:6,O
M4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0
M=65R=&\@4FEC;P!0=7)G92!M97-S86=E<P!1871A<@!1=65R>0!1=6]T80!2
M4T$@4'5B;&EC($ME>2`H)60@8FET*0!2861I;R!S96QE8W1I;VX`4F%I;@!2
M86EN($5A<FQY`%)A:6X@3&%T90!286EN(%-H;W=E<@!286EN(&%N9"!3;F]W
M`%)A:6X@=&\@4VYO=P!286YD;VT@1F]R='5N90!2871I;P!296%D`%)E860@
M;65S<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N
M;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S
M97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E9&]E
M<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@`4F5F<F5S:"!$>6YA;6EC($UE
M;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T
M:6]N<VAI<"!"<F]W<V5R`%)E;&]A9`!296UA<FMS`%)E;65M8F5R('1H92!F
M<F5E+V)U<WD@:6YF;W)M871I;VXN`%)E;6]T92!397)V97)S`%)E;6]T92!5
M4DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M
M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`4F5M
M;W9E(&9R;VT@;7D@8V%L96YD87(`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D
M('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E
M;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!2
M96UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5P;'D@4V5N="X`4F5P;'D@
M=VET:"!.;W0@4W5P<&]R=&5D($UE<W-A9V4`4F5P;'D@=VET:"!F<F5E+V)U
M<WD@9F]R(&YE>'0@,B!M;VYT:',N`%)E<&QY('=I=&@@<F5Q=65S=&5D(&9R
M964O8G5S>2!I;F9O<FUA=&EO;BX`4F5P;'DZ("5S`%)E<75E<W0@8V]U;&1N
M)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@`%)E<75E<W1E
M9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"X`4F5Q=6ER960@(B5S(B!N
M;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E
M<R(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER
M960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN`%)E<75I
M<F5D($9I96QD`%)E<75I<F5D(%!A<G1I8VEP86YT`%)E<V5T`%)E<V5T(%!A
M<W-W;W)D`%)E<V5T(%EO=7(@4&%S<W=O<F0`4F5S=&]R92!,87-T(%%U97)Y
M`%)E<W5L=',`4F5T=7)N('1O($]P=&EO;G,`4F5T>7!E(&YE=R!P87-S=V]R
M9`!2975N:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET
M;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V
M86QU97,`4F]?=R!0<F]P97)T:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@
M,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2
M;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E
M96X@<F]W<R!O;FQY`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O
M34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP=&5D
M($UE<W-A9V4`4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE
M+@!335,@365S<V%G:6YG`%-13"!3:&5L;`!344P@<W1A=&5M96YT(&9O<B!V
M86QU92!L;V]K=7!S`%-32`!354-#15-3`%-?44P@4VAE;&P`4V$`4V%I;G0@
M2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN
M="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'
M<F5N861I;F5S`%-A;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R:6YO
M`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`4V%U
M9&D@07)A8FEA`%-A=F4`4V%V92`B)7,B`%-A=F4@)7,`4V%V92!/<'1I;VYS
M`%-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T
M('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4V%V960@
M)7,@8V]N9FEG=7)A=&EO;BX`4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@
M=&\Z("(E<R(N`%-C871T97)E9"!4+5-T;W)M<P!38VEE;F-E`%-E87)C:`!3
M96%R8V@@16YG:6YE<P!396QE8W0@1FEL97,`4V5L96-T(&$@9&%T90!396QE
M8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A
M('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@86QL`%-E;&5C
M="!A;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@86X@;V)J96-T`%-E;&5C
M="!N;VYE`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H
M92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H
M96T@9G)O;2!T:&4@=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI
M=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&ED96YT
M:71Y('EO=2!W86YT('1O(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM
M:71E<CH`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C
M:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T
M('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD($QA=&5S="!);F9O<FUA
M=&EO;@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;F5G86P`4V5N
M<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I86P@
M3G5M8F5R`%-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N`%-E
M<W-I;VX@061M:6X`4V5S<VEO;B!)1"!E>'!I<F5D+@!397-S:6]N<P!3970`
M4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O
M<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@=7`@<F5M;W1E('-E<G9E
M<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"X`
M4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T
M92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO
M<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L87D@
M;W!T:6]N<RX`4V5T=7``4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L
M90!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T
M97(Z(`!397EC:&5L;&5S`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO=6QD
M(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`
M4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@
M=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@!3:&]W(&QA<W0@
M;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@;W!T:6]N('1O(&ME
M97`@;W)I9VEN86P`4VAO=R!P:6-K97(`4VAO=R!T86)L92!O<&5R871I;VYS
M(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W
M('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A
M8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P
M97)T:65S(&1I86QO9P!3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO
M9P!3:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,
M871E`%-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y`%-H<FEN:P!3:')I;FL@;W(@
M;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER
M<W0`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R92!!
M;&=O<FET:&T`4VEM<&QE>`!3:6YG87!O<F4`4VEZ90!3:VEP($UA:6YT96YA
M;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<`4VYO=R!3:&]W97(`4VYO=R!3
M:&]W97)S`%-N;W<@4VAO=V5R<R!%87)L>0!3;F]W(%-H;W=E<G,@3&%T90!3
M;F]W(&1E<'1H.B``4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B``4V]L;VUO
M;B!)<VQA;F1S`%-O;6%L:6$`4V]N9W,@)B!0;V5M<P!3;W)T(&]R9&5R('-E
M;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@1V5O
M<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',`4V]U=&AE<FX@
M2&5M:7-P:&5R90!3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS`%-P86-E
M(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&P`4W!A8V5R`%-P
M86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3<&%M`%-P96-I86P@
M0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET
M(')O=P!3<&]R=',`4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R
M=`!3=&%R="!Y96%R`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R86=E
M(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L
M:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=
M`%-U`%-U8F1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`4W5B:F5C=`!3=6)M
M:70`4W5B;6ET=&5D(')E<75E<W0@=&\@861D("(E<R(@=&\@=&AE('-Y<W1E
M;2X@66]U(&-A;FYO="!L;V<@:6X@=6YT:6P@>6]U<B!R97%U97-T(&AA<R!B
M965N(&%P<')O=F5D+@!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@
M861D960@(B5S(B!T;R!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@8VQE87)E
M9"!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S
M9G5L;'D@9&5L971E9"`B)7,B+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`B)7,B
M(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I
M9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY
M('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@<V%V
M960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E<W-F
M=6QL>2!U<&1A=&5D("(E<R(`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U9&%N
M`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U;G)I
M<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I
M<'0`4W5P<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V86QB87)D(&%N9"!*86X@
M36%Y96X`4W=A>FEL86YD`%-W961E;@!3=VET>F5R;&%N9`!3>6YC(&QO9R!D
M96QE=&5D`%-Y;F--3`!3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS`%-Y
M<FEA;B!!<F%B(%)E<'5B;&EC`%0M4W1O<FT`5"U3=&]R;2!A;F0@5VEN9'D`
M5"U3=&]R;7,`5"U3=&]R;7,@16%R;'D`5%-6(&9I;&4`5&%B;&4`5&%B;&4@
M4')O<&5R=&EE<P!486)L92!3970`5&%B;&4@<')O<&5R=&EE<P!486EW86X`
M5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN80!486II:VES=&%N`%1A;GIA;FEA
M+"!5;FET960@4F5P=6)L:6,@;V8`5&%R9V5T.@!487-K<P!496%L`%1E;&5P
M:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R871U<F4`
M5&5M<&5R871U<F4Z(`!496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S
M*2`F9&5G.R5S`%1E;7!L871E("(E<R(@;F]T(&9O=6YD+@!496UP;&%T92!!
M9&UI;FES=')A=&EO;@!496YT871I=F5L>2!!8V-E<'0@<F5Q=65S=`!496YT
M871I=F5L>2!!8V-E<'1E9`!497AT`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E
M>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AA;FL@>6]U(&9O
M<B!U<VEN9R!T:&4@<WES=&5M+@!4:&4@)7,@;&EN:R!T;R`E<R!H87,@8F5E
M;B!R96UO=F5D+@!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE
M+@!4:&4@2&ES=&]R>2!S>7-T96T@:7,@9&ES86)L960N`%1H92!(;W)D92]+
M;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="`B)7,B
M`%1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N`%1H92!-
M86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`
M5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A
M9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!0
M97)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S
M:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&-A;&5N9&%R(&1A=&$@
M:7,@:6YV86QI9`!4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C
M:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@9&%T
M86)A<V4N`%1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@
M>6]U<B!A9&1R97-S(&)O;VLN`%1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E
M(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A
M9V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S
M<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD(&EN('1H92!D871A
M8F%S92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D
M+@!4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E
M8B!C;VYN96-T:6]N+@!4:&4@979E;G0@:&%S(&)E96X@861D960@=&\@>6]U
M<B!C86QE;F1A<BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S
M971T:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E
M='1I;F=S+@!4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L
M9BX`5&AE(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE
M(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H
M92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H
M92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!L969T+6AA
M;F0@<VED92!O;FQY`%1H92!L:6YK(&AA<R!B965N(')E;6]V960`5&AE(&QO
M8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T
M:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M97-S86=E('-E;G0@;VX@)7,@
M=&\@)7,@=VET:"!S=6)J96-T("(E<R(@:&%S(&)E96X@9&ES<&QA>65D+@I4
M:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N
M(')E860@;W(@=6YD97)S=&]O9"X`5&AE(&YA;64@=&\@=7-E('=H96X@;&EN
M:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H92!N=6UB97(@;V8@9FEE;&1S
M(&UU<W0@8F4@;G5M97)I8RX`5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I
M<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R
M969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@
M9&%T82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@
M<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@
M;F]T(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!Q=6]T92!C:&%R86-T97(@
M;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE(')I9VAT(&%N9"!L
M969T('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S
M97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE('-E
M<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H
M87,@8F5E;B!S879E9"X`5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@
M8F5E;B!R96UO=F5D+@!4:&4@<W!E8VEF:65D(')O=R`H)60I(&1O97,@;F]T
M(&5X:7-T+@!4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="X`5&AE
M('1A<VL@:&%S(&)E96X@861D960@=&\@>6]U<B!T87-K;&ES="X`5&AE('1E
M;7!O<F%R>2!F:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H92!T97AT('EO
M=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E
M;BX`5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`5&AE('1O<"!S:61E
M(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R
M979I;W5S('-T97`N`%1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S
M879E9"X`5&AE('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M871I;VX@=V%S('-U
M8V5S<V9U;&QY('-T;W)E9"X`5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO
M="!A=F%I;&%B;&4N`%1H96UE<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N
M`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@87)E(&YO
M('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R
M92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E
M(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T
M:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`B)7,B('1O('1H
M92!S>7-T96TZ("5S`%1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T
M82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A
M('!R;V)L96T@<F5M;W9I;F<@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R
M92!W87,@82!P<F]B;&5M('5P9&%T:6YG("(E<R(Z("5S`%1H97)E('=A<R!A
M('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO
M861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D
M('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H
M92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO
M861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S
M86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N
M=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!E
M=F5N=#H@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#
M86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H
M92!T87-K.B`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!U<V5R
M)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N.B`E<RX`5&AE<F4@=V%S(&%N(&5R
M<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE
M9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!P
M97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N
M+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I
M;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T
M<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AI<R!)
M34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`
M5&AI<R!A8W1I;VX@:7,@;F]T('-U<'!O<G1E9"X`5&AI<R!A8W1I;VX@:7,@
M;F]T('EE="!I;7!L96UE;G1E9"X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@
M8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@
M=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O
M(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT
M='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@
M05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H
M<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI(&=A=&5W87DL('5S
M:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R
M96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D
M<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR
M;W5G:"!T:&4@5F]D869O;F4@271A;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A
M9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I
M=&@@5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F
M:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN
M(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R
M<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@
M;V-T86P@=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S
M<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU
M<W0@8F4@82!V86QI9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN
M(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M
M<&QE("<C,3(S-&%F)RX`5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O
M8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@
M:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BX`
M5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@<V5R=F5R
M(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4:&ES('-Y
M<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L=64@;75S
M="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O
M;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R`%1I8VME=',`5&EM90!4:6UE
M(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L96-T:6]N`%1I;6]R+4QE
M<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`5&\`5&\@<V5L96-T(&UU;'1I
M<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM
M86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D87D`5&]G9VQE($A4
M34P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO<G)O=P!4;VYG80!4;W``5&]P
M(&9R86UE("A?=&]P*0!4<F%N<VQA=&EO;G,`5')I;FED860@86YD(%1O8F%G
M;P!4<G5E(&]R(&9A;'-E`%1U`%1U;FES:6$`5'5R:V5Y`%1U<FMI<V@@*$E3
M3RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N
M9',`5'5V86QU`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``55),
M`%523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R=`!5
M4DPZ`%5G86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C
M=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H
M96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O
M<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@
M9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5
M;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE("5S+R5S`%5N86)L92!T;R!C:&5C
M:R!F:6QE('-I>F4@;V8@(B5S(BX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ
M92!O9B`B)7,O)7,B+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R
M+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"X`56YA8FQE('1O(&-O<'D@
M5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B
M+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C
M<F5A=&4@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B`B
M)7,B+@!5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@
M=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B;&4@=&\@9&5L971E("(E<R(L('1H
M92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+@!5;F%B;&4@=&\@9&5L971E("(E
M<R(Z("5S+@!5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES
M(&YO="!E;7!T>0!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C
M=7)S:79E;'DN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2X`56YA
M8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(&1E
M;&5T92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE
M+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O
M(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M
M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C97)T
M:69I8V%T92!D971A:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N
M(&]F("5S+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P
M96X@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R
M('=R:71I;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@
M;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D(%9&4R!F
M:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D(%9&4R!F
M:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D(&9I
M;&4Z(`!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N
M86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A
M;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN
M`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T
M;R!R96YA;64@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(')E;F%M92!61E,@
M9FEL92`E<R\E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92X`56YA8FQE
M('1O(')U;B`G;6MI<V]F<R<N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7
M;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET92!61E,@9FEL92`B)7,B+@!5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+@!5;F%B
M;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+@!5;F1E<FQI;F4`56YD
M;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T960@
M<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP96-T
M960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N:&%N9&QE
M9"!C;VUP;VYE;G0@;V8@='EP93H@)7,`56YI8V]D92`H551&+3@I`%5N:71E
M9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`
M56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N
M:VYO=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN
M;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@;&]C
M871I;VX@<')O=FED960N`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N
M`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M960`56YP<FEV:6QE
M9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G
M<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T
M;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"!S
M:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@
M8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`
M57!D871E`%5P9&%T92`E<P!5<&1A=&4@<F5S<&]N9&5N="!S=&%T=7,`57!D
M871E('5S97(`57!D871E9"`B)7,B+@!5<&=R861E('-C<FEP="!D96QE=&5D
M+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S
M('1O('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M
M86X@;G5M8F5R<P!5<G5G=6%Y`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,`%5S
M92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V
M97(N`%5S97(`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S
M97(@061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T
M:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T
M:&ES('-I=&4N`%5S97(@86-C;W5N="!N;W0@9F]U;F0`57-E<FYA;64`57-E
M<FYA;64@(B5S(B!A;')E861Y(&5X:7-T<RX`57-E<FYA;64Z`%5S97)N86UE
M.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@9&ER96-T
M;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A=&EO;G,@
M9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O
M;2!N;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S
M+@!686QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B
M;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A
M9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9E<G-I
M;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E
M<G1I8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE=&YA;65S92`H5DE30TE)
M*0!6:65W("5S`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E
M<P!6:65W(&5V96YT`%9I97<@=&%S:P!6:7)G:6X@27-L86YD<RP@0G)I=&ES
M:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6:7-I8FEL:71Y`%9I<VEB:6QI='DZ
M(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU44`!705).`%=!4DY)3D<A(2$@4D5-
M3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+@!724X@=FEA($A45%``5V%L
M;&ES(&%N9"!&=71U;F$`5V%R;FEN9P!790!796%T:&5R($9O<F5C87-T`%=E
M871H97(@9&%T82!P<F]V:61E9"!B>0!796%T:&5R+F-O;0!796(`5V5B(%-I
M=&4`5V5B8G!L871S96X@+2!3;V)E<@!796)B<&QA='-E;B`M(%-O8F5R($Y%
M5P!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=E
M<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T
M97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y
M(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R
M/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H97)E:7,@075S=')A
M;&EA(&UA<`!7:&EC:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@
M9F]R('1H92!2:6-H(%1E>'0@961I=&]R+@!7:61T:`!7:61T:"!I;B!#4U,@
M=6YI=',`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S
M(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T86)L90!7
M:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I;F0`5VEN9"!%87)L>0!7:6YD('-P
M965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`5VES:&QI<W0`5V]R
M:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!7<F]N9R!N=6UB97(@;V8@9FEE
M;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@
M;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+@!7<F]N
M9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+@!8+5)E9@!8
M-3`Y=C,@17AT96YD960@2V5Y(%5S86=E`%@U,#EV,R!E>'1E;G-I;VYS`%E9
M`%E965D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S`%EE<RP@22!!9W)E
M90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@
M=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@86QL;W=E
M9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RX`66]U(&%R92!N;W0@
M875T:&5N=&EC871E9"X`66]U(&-A;B!N;W0@:&%V92!T:&4@)UPG(&-H87)A
M8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&-A;FYO="!H879E('1H92`G
M7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E
M;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!H879E(&)E96X@;&]G
M9V5D(&]U="X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@
M;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@
M=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O
M(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A
M=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I
M9W5R92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O
M8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`
M66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S
M('1O`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`
M66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U
M(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@
M<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y
M('1H92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA
M="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E
M9V]R>2!N86UE+@!9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO
M;F4@;G5M8F5R`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E
M(&QO9VEN(&%G86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A
M9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@061D<F5S
M<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@
M<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L
M;V=I;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@875T:&5N=&EC871I;VX@8F%C
M:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I
M<V@@=&\@=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@
M>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT(&%U=&AE;G1I8V%T:6]N(&)A8VME
M;F0N`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P
M;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I
M<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!B<F]W<V5R(&%P
M<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@
M>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO
M=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P
M<&]R="!T:&ES(&9E871U<F4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@
M*R!0('1O('!R:6YT+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E
M9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"X`66]U<B!D969A=6QT
M(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!L;V=I;B!H87,@97AP
M:7)E9"X`66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P
M=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T
M:&ES('-E<W-I;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`
M66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA
M<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET
M:"!Y;W5R(&YE=R!P87-S=V]R9"X`66]U<B!P87-S=V]R9"!H87,@97AP:7)E
M9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`675G;W-L879I80!:86ER90!:86UB
M:6$`6FEM8F%B=V4`6FEP<'D`6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M
M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X
M="`M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N
M`%]#3$D`7T1A=&%4<F5E`%]$96QE=&4@4F]W`%]'<F]U<',`7TAE;'``7TEM
M86=E(%!R;W!E<G1I97,N+BX`7TQO9R!I;@!?3&]G(&]U=`!?36]D:69Y($QI
M;FLN+BX`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN:RXN+@!?
M4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`7U5S97)S`&%D9')E<W,@8F]O
M:P!A9&1R97-S964@=6YK;F]W;@!C86QE;F1A<@!C86QM`&-A;FYO="!C<F5A
M=&4@;W5T<'5T(&9I;&4`8V%N;F]T(&]P96X@:6YP=70`8VQI8VL@:&5R90!C
M;&]C:P!C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(`8V]N9FEG=7)A=&EO;B!E
M<G)O<@!C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG`&1A=&$@9F]R;6%T
M(&5R<F]R`&5D:70`96YT<GD@;F]T(&9O=6YD`&9A;&QI;F<`9FEL90!F<F]M
M('1H92`E<R`H)7,I(&%T("5S("5S`&=U<W1I;F<`:#H`:&@`:&]S="!N86UE
M('5N:VYO=VX`:6UM961I871E`&EN;&EN90!I;G!U="]O=71P=70@97)R;W(`
M:6YT97)N86P@<V]F='=A<F4@97)R;W(`;&EN97-=`&UK:7-O9G,@97)R;W(@
M8V]D92`E9"!W:&EL92!M86MI;F<@25-/+@!M;0!N86UE`&YO="!I;7!L96UE
M;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`<&5R8V5N=`!P97)M
M:7-S:6]N(&1E;FEE9`!P:7AE;',`<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L
M`')I<VEN9P!S97)V:6-E('5N879A:6QA8FQE`'-H;W<@9&EF9F5R96YC97,`
M<VUS,F5M86EL('9I82!(5%10`'-S`'-T96%D>0!S>7-T96T@97)R;W(`=&%S
M:R!L:7-T`'1E;7!O<F%R>2!F86EL=7)E`'1Y<&4@=&AE('!A<W-W;W)D('1W
M:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5S97(@<V5L96-T`'9#
M87)D`'<Z`'=E871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@
M,RXQ"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G
M"E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`R+3$U(#$Q.C(Q*S`Q,#`*4$\M
M4F5V:7-I;VXM1&%T93H@,C`P-BTP,BTQ-B`P,#HR-BLP,3`P"DQA<W0M5')A
M;G-L871O<CH@2F]A<75I;2!(;VUR:6=H875S96X@/&IO:&]`=V5B8G!L871S
M96XN<V4^"DQA;F=U86=E+51E86TZ(%-W961I<V@@/&DQ.&Y`;&ES=',N:&]R
M9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O
M<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,0I#;VYT96YT+51R86YS9F5R+45N
M8V]D:6YG.B`X8FET"@`@)B,Q-3$[("5S(&MO;6UE<B!A='0@=71F]G)A(&1E
M('5N9&5R:.5L;'-A:W1I=FET971E<FYA('-O;2!M87)K97)A=',@;F5D86XN
M`"`H)7,@9&%G87(@<V5D86XI`"`H<VYA8F)T86YG96YT("5S*0`@*%-K<FEV
M<VMY9&1A9"D`("AO;2`E<R!D86=A<BD`("AI9&%G*0`@*&EM;W)G;VXI`"`H
M:6?E<BD`(&ML(``G)7,G(.1R(&EN=&4@96X@:V%T86QO9RX`)R5S)R#D<B!I
M;G1E(&5T="!G;V1KY&YT('9A;"X`)R5S)R#D<B!I;G1E(&MO;F9I9W5R97)A
M="!I($AO<F1E<F5G:7-T<F5R="X`5'+D9&AA;G1E<F%R96X@9O9R("5S('-A
M:VYA<RX`)R5S)R!L861E<R!T:6QL(&D@9W)U<'!S>7-T96UE="X`)R5S)R!L
M861E<R!T:6QL(&D@8F5H]G)I9VAE='-S>7-T96UE="X`)R5S)R!S:V%P861E
M<R!I;G1E.B`E<RX`)2XR9DU"(&%N=N1N="!A=B`E+C)F34(@=&EL;.5T970@
M*"4R9B4E*0`E9"`E<R!O8V@@)7,`1&ET="!L]G-E;F]R9"!U<'!H]G(@871T
M(&?D;&QA(&]M("5D(&1A9V%R+@`E9"UD86=S<')O9VYO<P`E<R`M($;V<B!K
MY&YN961O;0!&:6YG97)P<FEN="!F]G(@)7,`)7,@2T(`)7,@56YD97)HY6QL
M<V9U;FMT:6]N("T@0F5K<N1F=&5L<V4`)7,@4V5T=7``)7,@86YMY&QA;@!4
M:N1N<W1E879T86P@9O9R("5S`"5S(&9I;FYS(')E9&%N+@`E<R!K;"`E<R`E
M<P`E<R!H87(@86YN=6QL97)A="`E<RX`)7,@:&%R('-V87)A="!PY2!E;B!B
M96?D<F%N(&]M(&EN9F]R;6%T:6]N(&%N9^5E;F1E(&QE9&EG+W5P<'1A9V5N
M+@`E<R!H87(@<W9A<F%T('#E(&EN8FIU9&%N('1I;&P@)7,N`"5S(&AA<B!S
M:VEC:V%T(&1I9R!I;F9O<FUA=&EO;B!O;2!L961I9R]U<'!T86=E;BX`)7,@
M:V]M;65R(&%T="!U=&;V<F$@9&4@=6YD97)HY6QL<V%K=&EV:71E=&5R;F$@
M<V]M(&UA<FME<F%T<R!N961A;BX@36%R:V5R82!D92!A:W1I=FET971E<B!S
M;VT@9'4@=FEL;"!U=&;V<F$N`"5S(&MRY'9S`"5S(&UI;G5T97(`)7,@<V%K
M;F%S+@`E<R!E9G1E<F9RY6=A<B!I;F9O<FUA=&EO;B!O;2!NY'(@9'4@Y'(@
M;&5D:6<O=7!P=&%G96XN`"5S(&5F=&5R9G+E9V%R(&1I;B!NY')V87)O('9I
M9"`E<RX`)7,@=&EL;"`E<R!A=B`E<P`E<R!V:6QL(&SD9V=A('1I;&P@=&EL
M;"`E<RX`)7,@=FEL;"!G]G)A(&1I9R!M961V971E;B!O;2`E<RX`)7,@=FEL
M;"!E<FCE;&QA(&1E;B!S96YA<W1E(&EN9F]R;6%T:6]N96X@;VT@)7,N`$%D
M<F5S<V)O:R!F]G(@)7,`2V%L96YD97(@9O9R("5S`$%N=&5C:VYI;F=A<B!F
M]G(@)7,`57!P9VEF=&5R(&;V<B`E<P`E<SH@)7,`)7,Z($UE9&1E;&%N9&5T
M(&MA;G-K92!I;G1E(.1R(&9RY6X@9&5N('-O;2!D970@=F5R:V%R+B!687(@
M9O9R<VEK=&EG(&UE9"!A='0@9O9L:F$@;.1N:V%R(&5L;&5R('-K:6-K82!A
M=G/D;F1A<F5N('!E<G-O;FQI9R!I;F9O<FUA=&EO;BX`+"!S=&]R;6)Y87(`
M+"!S=&]R;6)Y87(@)7,@)7,`+"!V87)I97)A;F1E(&UE;&QA;B`E<R!O8V@@
M)7,`+2T@=N1L:B`M+0`Q,BUT:6UM87)S9F]R;6%T`#(T+71I;6UA<G-F;W)M
M870`,C0@=&EM;6%R`#Q&]G)E9^5E;F1E`$5N(&1A=&%B87-K;W!P;&EN9R!K
M<N1V<R!F]G(@86MT=65L;'0@8FQO8VLN`$5T="!F871A;'0@9F5L(&AA<B!I
M;G1RY&9F870`16X@<'5B;&EK(%!'4"UN>6-K96P@:W+D=G,@9O9R(&%T="!K
M<GEP=&5R82!E='0@;65D9&5L86YD92X`16X@<'5B;&EK(%!'4"UN>6-K96P@
M:W+D=G,@9O9R(&%T="!V97)I9FEE<F$@971T('-I9VYE<F%T(&UE9&1E;&%N
M9&4N`$5N('!U8FQI:R!O8V@@<')I=F%T(%!'4"UN>6-K96P@<V%M="!L]G-E
M;F]R9"!K<N1V<R!F]G(@871T(&1E:W)Y<'1E<F$@971T(&UE9&1E;&%N9&4N
M`$5N('!U8FQI:R!O8V@@<')I=F%T(%!'4"UN>6-K96P@<V%M="!L]G-E;F]R
M9"!K<N1V<R!F]G(@871T('-I9VYE<F$@971T(&UE9&1E;&%N9&4N`$5N('!U
M8FQI:R!O8V@@<')I=F%T(%,O34E-12UN>6-K96P@<V%M="!L]G-E;F]R9"!K
M<N1V<R!F]G(@871T(&1E:W)Y<'1E<F$@971T(&UE9&1E;&%N9&4N`$5N('!U
M8FQI:R!O8V@@<')I=F%T(%,O34E-12UN>6-K96P@<V%M="!L]G-E;F]R9"!K
M<N1V<R!F]G(@871T('-I9VYE<F$@971T(&UE9&1E;&%N9&4N`$5N('!U8FQI
M:R!3+TU)344M;GEC:V5L(&MRY'9S(&;V<B!A='0@:W)Y<'1E<F$@971T(&UE
M9&1E;&%N9&4N`$;V<FUI9&1A9W-M;VQN`$SD='0@9O9R;6ED9&%G<W)E9VX`
M1O9R;6ED9&%G<W)E9VX`1O9R;6ED9&%G<W-K=7)A<@!&]G)M:61D86=S<VMU
M<F%R(&UE9"!S;O8`04TO4$T`05!)($E$`$]M(&5D:71O<FX`3VTN+BX`0F]T
M=&5N`$UI='1E;@!!8V-E<'1E<F$@8F5GY')A;@!!8V-E<'1E<F%D`$)E:/9R
M:6=H970@<V%K;F%S(&%T="!S:V%P82!61E,M;6%P<"X`0F5H]G)I9VAE="!S
M86MN87,@871T('-K87!A(%9&4RUF:6PN`$MO;G1O:6YF;W)M871I;VX`3/9S
M96YO<F0@9O9R(&MO;G1O`$MO;G1O="!F<GES=`!"=61G970`Q71GY')D97(`
M3.1G9R!T:6QL`$SD9V<@=&EL;"`E<P!,Y&=G('1I;&P@=6YD97)G<G5P<`!L
MY&=G('1I;&P@=6YD97)B96CV<FEG:&5T`$SD9V<@=&EL;"!HY'(Z`$SD9V<@
M=&EL;"!N>2!G<G5P<`!,Y&=G('1I;&P@;GD@8F5H]G)I9VAE=`!,Y&=G('1I
M;&P@=6YD97)G<G5P<"!T:6QL("<E<R<`3.1G9R!T:6QL('5N9&5R8F5H]G)I
M9VAE="!T:6QL("<E<R<`3.1G9R!T:6QL(&5N(&YY(&%N=N1N9&%R93H`3.1G
M9R!T:6QL(&MO;'5M;@!,Y&=G('1I;&P@;GEA(&UE9&QE;6UA<@!,Y&=G('1I
M;&P@<&%R`$SD9V<@=&EL;"!M96YY;B!F]G(@)7,@<V]M($UO>FEL;&$@4VED
M96)A<@!,Y&=G('1I;&P@:2!M:6X@:V%L96YD97(`3.1G9R!T:6QL(&D@861R
M97-S8F]K.@!,Y&=G('1I;&P@:2!M:6X@861R97-S8F]K`$SD9V<@=&EL;"!A
M;G;D;F1A<F4`3&%D92!T:6QL("<E<R<@=&EL;"!S>7-T96UE="P@;65N(&MU
M;F1E(&EN=&4@;.1G9V$@=&EL;"!E>'1R82`@:6YF;W)M871I;VXZ("5S+@!,
M861E('1I;&P@)R5S)R!T:6QL('-Y<W1E;65T+B!$=2!K86X@;&]G9V$@:6X@
M;G4N`%5P<&SD9V<@878@86YVY&YD87)E(.1R(&EN86MT:79E<F%T+@!!9')E
M<W,`061R97-S8F]K`$%D;6EN:7-T<F%T:6]N("T@86YG92!B96CV<FEG:&5T
M(&;V<B!A;F1R82!A;G;D;F1A<F4`061M:6YI<W1R871I;VX`4F5K;&%M`$%F
M9V%N:7-T86X`06QB86YI96X`06QG97)I970`06QI87,`2G5S=&5R80!*=7-T
M97)I;F<Z`$%L;&$`06QL82!A=71E;G1I<V5R861E(&%N=N1N9&%R90!!;&QA
M(&=R=7!P97(`06QL82!B96CV<FEG:&5T97(`06QL82!F>7)A('-I9&]R`%1I
M;&SE="!F;&5R82!A9')E<W-E<@!4:6QLY70@:6YS=.1L;&YI;F<@9O9R('-O
M<G1E<F%D(&QI<W1A/P!&:6YN<R!R961A;@!!;'1E<FYA=&EV($E-4U`M:6YL
M;V=G;FEN9P!!;'1E<FYA=&EV="!L]G-E;F]R9"!F]G(@24U34`!!;'1E<FYA
M=&EV="!A;G;D;F1A<FYA;6X@9O9R($E-4U``06QT97)N871I=B!E+7!O<W0@
M861R97-S`$%L=&5R;F%T:78@;6%L;`!!;'1E<FYA=&EV('1E>'0Z`$%M97)I
M:V%N<VMA(%-A;6]A`$5T="!F96P@=7!P<W1O9"!NY'(@;.1N:V5N("@E<RD@
M<VMU;&QE(&%N=N1N9&%S`$5T="!F96QA:W1I9W0@=N1R9&4@86YG879S+@!%
M='0@;VOD;G0@9F5L(&AA<B!I;G1RY&9F870`06YD;W)R80!!;F=O;&$`06YG
M=6EL;&$`06YO;GEM('!R;WAY`%-V87(`06YT87)K=&ES`$%N=&EG=6$@;V-H
M($)A<F)U9&$`07!P;&EK871I;VX`07!P;&EK871I;VYS;&ES=&$`07!P;&EK
M871I;VYE;B#D<B!K;&%R+@!697)K<W3D;&P@=&EL;"!U;F1E<G5T9&5L;FEN
M9V%R`$=O9&OD;FX`56YG96;D<FQI9R!S=&]R;&5K`&%P<FEL`$%R86)I<VL@
M*%=I;F1O=W,M,3(U-BD`07)K:79F:6QS=&]R;&5K`$%R:VEV9FEL;F%M;@#$
M<B!D970@<^1K97)T(&%T="!D=2!V:6QL('1A(&)O<G0@8F5GY')A;B!F]G(@
M)7,_`,1R(&1E="!SY&ME<G0@871T(&1U('9I;&P@<F%D97)A("<E<R<@;V-H
M(&5V96YT=65L;&$@=6YD97)G<G5P<&5R/P!!<F=E;G1I;F$`07)M86YI96X`
M07)M96YI<VL@*$%235-#24DM."D`2V]N<W0`07)U8F$`07-C96YS:6]N($ES
M;&%N9`!!<V-I:2!K;VYS=`!!<VEE;B]3=&EL;&$@:&%V<W)E9VEO;F5N`$9R
MY6=A(&5F=&5R(&)E:W+D9G1E;'-E(&EN;F%N('5N9&5R:.5L;'-A:W1I=FET
M971E<B!U=&;V<G,_`%1I;&QD96QN:6YG<VMO;'5M;@!":69O9V%D(.1R(&5N
M(&E#86QE;F1E<B!F:6P@;65D(&5T="!S=F%R('#E(&5N(&)E9^1R86X@<V]M
M(&1U('-K:6-K870L`$;V<G/V:R!T:6QL(&%T="!R861E<F$@96X@9W)U<'`@
M<V]M(&EN=&4@9FEN;G,N`$;V<G/V:R!T:6QL(&%T="!R861E<F$@96X@8F5H
M]G)I9VAE="!S;VT@:6YT92!F:6YN<RX`1O9R<_9K(&%T="#D;F1R82!E;B!B
M96CV<FEG:&5T('-O;2!I;G1E(&9I;FYS+@!&]G)S]FL@871T(.1N9')A(&5N
M('5T9&5L;FEN9R!S;VT@:6YT92!F:6YN<RX`1&5L=&%G87)E`$%T=')I8G5T
M`&%U9W5S=&D`075S=')A;&EE;@#6<W1E<G)I:V4`075T:%]C>7)S<6PZ($E-
M05`M97AT96YS:6]N('-A:VYA<RX`075T:%]C>7)S<6PZ($MO<'!L:6YG96X@
M<V%K;F%R(&9U;FMT:6]N97(@<V]M(&MRY'9S+@!!=71H7V-Y<G5S.B!)34%0
M+65X=&5N<VEO;B!S86MN87,N`$%U=&A?9G1P.B!&5%`M=&EL;.1G9R!S86MN
M87,N($MO;7!I;&5R82!02%`@;65D('-W:71C:&5N("TM96YA8FQE+69T<"X`
M075T:%]I;6%P.B!)34%0+65X=&5N<VEO;B!S86MN87,N`$%U=&A?:W)B-3H@
M:W)B-2UE>'1E;G-I;VX@<V%K;F%S+@!!=71H7VQD87`Z($1E="!GY7(@:6YT
M92!A='0@;.1G9V$@=&EL;"!A;G;D;F1A<F4@:2!!8W1I=F4@1&ER96-T;W)Y
M`$%U=&A?;&1A<#H@1&5T(&?E<B!I;G1E(&%T="!R861E<F$@86YVY&YD87)E
M(&9RY6X@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z($Q$05`M=&EL;.1G
M9R!S86MN87,N`$%U=&A?;&1A<#H@2V%N(&EN=&4@;.1G9V$@=&EL;"!A;G;D
M;F1A<F4@)R5S)RX@4V5R=F5R;B!S=F%R861E.B``075T:%]L9&%P.B!+86X@
M:6YT92!R861E<F$@86YVY&YD87)E("5S`$%U=&A?;&1A<#H@2V%N(&EN=&4@
M=7!P9&%T97)A(&%N=N1N9&%R92`E<P!!=71H7VQD87`Z($1E="!GY7(@:6YT
M92!A='0@=7!P9&%T97)A(&%N=N1N9&%R92!I($%C=&EV92!$:7)E8W1O<GDN
M`$%U=&A?;6-A;#H@34-!3"UE>'1E;G-I;VX@<V%K;F%S+@!!=71H7W-M8F%U
M=&@Z('-M8F%U=&@M97AT96YS:6]N('-A:VYA<RX`075T96YT:7-E<FEN9R!T
M:6QL($E-05`M<V5R=F5R(&UI<W-L>6-K861E<RX`075T96YT:7-E<FEN9R!M
M:7-S;'EC:V%D97,`075T96YT:7-E<FEN9R!M:7-S;'EC:V%D97,N("5S`$%U
M=&5N=&ES97)I;F<@879V:7-A9&5S(&%V(%)!1$E54RUS97)V97)N+@!!=71E
M;G1I<V5R:6YG('1I;&P@1E10+7-E<G9E<B!M:7-S;'EC:V%D97,N`$%U=&5N
M=&ES97)I;F<@=&EL;"!334(M<V5R=F5R(&UI<W-L>6-K861E<RX`5&EL;&?D
M;F=L:6=A(&;D;'0Z`%;D;G1A<B!PY2!S=F%R`$%Z97)B86EJ86X`07IU<F)L
MY0!"3T9(+75R<^1K=&5R`$)A:V=R=6YD`$)A:V=R=6YD<V;D<F<`1F5L86MT
M:6=T(&SV<V5N;W)D(&;V<B!+97)B97)O<P!&96QA:W1I9W0@86YVY&YD87)N
M86UN(&;V<B!+97)B97)O<P!"86AA;6%S`$)A:')A:6X`0F%L=&ES:R`H25-/
M+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R=&ED`%)A9'1I9`!"87)B861O<P!"
M87)B:64`0F%S:V%T86QO9R`G)7,G(&;V<B!B:6QD97(@:&ET=&%D97,@:6YT
M92X`0F%S;&EN:F4`5FET<GES<VQA;F0`0F5L9VEE;@!"96QI>F4`0F5N:6X`
M0F5R;75D80!":'5T86X`1O9D96QS961A9P!";&]C:R`G)7,G(&;V<B!A<'!L
M:6MA=&EO;B`G)7,G('-A:VYA<RX`0FQO8VMI;G-TY&QL;FEN9V%R`$)L;V-K
M='EP`$)LY2!MY6YE`$)LY71T(&]C:"!V:71T`$9E=`!";VQI=FEA`$)O:VWD
M<FME;@!286T`4F%M8G)E9&0Z`%)A;6%R`$)O<VYI96X@;V-H($AE<GIE9V]V
M:6YA`$+E9&$`0F]T<W=A;F$`0F]T=&5N`$)O=79E="!)<VQA;F0`0G)A<VEL
M:65N`$)R:71T:7-K82!T97)R:71O<FEE="!I($EN9&ES:V$@;V-E86YE;@!"
M<G5N`$)R=6YE:0!"=6QG87)I96X`4'5N:W1L:7-T80!"=7)K:6YA($9A<V\`
M0G+D;F0@3W)A;F=E`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N
M(%!O:6YT<P!#7V5L;"!I;G-TY&QL;FEN9V%R+BXN`$-A8VAE:6YI=&EE<FEN
M9R#D<B!I;G1E(&9U;&QS=.1N9&EG+@!+86QE;F1E<@!,=6=N=`!+86UB;V1J
M80!+86UE<G5N`$MA;6]U9FQA9V4`2V%N(&EN=&4@;F]L;'-TY&QL82!L]G-E
M;F]R9"!A=71O;6%T:7-K="P@:V]N=&%K=&$@9&EN(&%D;6EN:7-T<F%T]G(N
M`$MA;B!I;G1E('-K<FEV82!T:6QL(&9I;"`G)7,G`$1E="!GY7(@:6YT92!A
M='0@861M:6YI<W1R97)A(&5X=&5R;F$@<V5S<VEO;G-H86YT97)A<F4N`$MA
M;B!I;G1E(&MO;G1A:W1A($E-05`M<V5R=F5R;CH@)7,`2V%N(&EN=&4@]G!P
M;F$@9FEL("<E<R<`2V%N861A`$%V8G)Y=`!!=F)R>70@<')O8FQE;7)A<'!O
M<G0`2V%N(&EN=&4@<F%D97)A("<E<R<N`$MA;B!I;G1E(&AI='1A(&5N('1E
M;7!RY'(@;6%P<"X`2V%N(&EN=&4@9F]R='/D='1A('5T86X@)VWE;&9I;"<M
M<&%R86UE=&5R+@!+86X@:6YT92!R861E<F$@;6%P<"`G)7,G+@!+86X@:6YT
M92!R861E<F$[("5D(&)A<FX@97AI<W1E<F%R+@!+86X@:6YT92!D:7)I9V5R
M82!M961D96QA;F1E('1I;&P@86YG:79E="!N=6UM97(N`$MA<"!697)D90!2
M=6)R:6L`3W!E<F%T]G(`2V%T96=O<FEE<B!O8V@@<G5B<FEK97(`0V%Y;6%N
M($ES;&%N9',`36]B:6QT96QE9F]N`$-E;&QI;G-TY&QL;FEN9V%R`$-E;&QU
M=&9Y;&QN860Z`$-E;&QI;G-TY&QL;FEN9V%R`$-E;&QM96QL86YR=6TZ`$UO
M8FEL=&5L969O;@!#96QT:7-K("A)4T\M.#@U.2TQ-"D`0V5N=')E<F%D`$-E
M;G1R86QA9G)I:V%N<VMA(')E<'5B;&EK96X`0V5N=')A;&5U<F]P96ES:R`H
M25-/+3@X-3DM,BD`0V5R=&EF:6MA=&1E=&%L:F5R`$-E<G1I9FEK873D9V%R
M90!#97)T:69I:V%T<&]L:6-I97,`5&-H860`3W)D9O9R86YD90#$;F1R80#$
M;F1R82!D:71T(&SV<V5N;W)D`,1N9')A(&;V<G9A;&0@:61E;G1I=&5T`,1N
M9')A(&YA;6X@;V-H(&%D<F5S<R!S;VT@;6]T=&%G87)N82!S97(@;N1R(&1E
M(&SD<V5R(&]C:"!S=F%R87(@<.4@9&EN82!M961D96QA;F1E;BX`071T(&)Y
M=&$@;/9S96YO<F0@<W3V9',@:6YT92!M960@9&5N(&YU=F%R86YD92!K;VYF
M:6=U<F%T:6]N96XN("!687(@9V]D(&MO;G1A:W1A(&%D;6EN:7-T<F%T]G)E
M;BX`5&MN`$MO;G1R;VQL97)A(&SD;FLN+BX`36%R:V5R82!D92!A:W1I=FET
M971E<B!D=2!V:6QL('5T9O9R82!N=2X`0VAI;&4`2VEN80!+:6YE<VES:W0@
M9O9R96YK;&%T("A'0C(S,3(I`$MI;F5S:7-K="!T<F%D:71I;VYE;&QT("A"
M:6<U*0!6Y&QJ(&%P<&QI:V%T:6]N.@!6Y&QJ(&SV<V5N;W)D`%;D;&H@86YV
MY&YD87)N86UN`%;D;&H@Y71GY')D.@!6Y&QJ(&AU<B!D871U;2!S:V%L;"!V
M:7-A<SH`5N1L:B!L:7-T<W1I;"`H9O9R('-O<G1E<F%D92!L:7-T;W(I`$IU
M;/9N`$ML87-S9&5F:6YI=&EO;B!F]G(@)7,@<V%K;F%S+@!296YS80!296YS
M82!-4T]F9FEC92UT86=G87(`4F5N<V$@9G+E9V$`4F5N<V$@86YVY&YD87)E
M.B`E<P!296YS82!A;G;D9&YA<F4`4F5N<V$@86YVY&YD87)D871A`%-E;F%R
M92!U<'!K;&%R;F%N9&4`2VQI8VMA(&;V<B!A='0@9F]R='/D='1A`$-L:6-K
M871E;&P@=FEA($A45%``4W3D;F<@9O9N<W1E<@!-;VQN`%1I9&EG82!M;VQN
M`$UO;&YI;F=T`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`$MO;7!R:6UE<F$@
M<VED;V;D;'1E=`!+;VUP<FEM97)A9&4@<F%M87(`2V]L;VUB:6$`1N1R9P!&
MY')G:&%N=&5R87)E`$;D<F=V86P`2V]L=6UN97(Z`$MO;'5M;B!R=6)R:6ME
M<@!,=7-T:6=H971E<@!+;VUM86YD;P!+;VUM86YD;V;V;G-T97(`2V]M;65N
M=&%R`$YA;6X`0V]M;W)O<P!&]G)E=&%G`%-L=71F]G)D`%-K<FEV(&UE9&1E
M;&%N9&4@*"5S*0!$871O<F5R`%;D9&5R`%;D9&5R`$MO;F9I9W5R871I;VYS
M<VMI;&QN861E<@!);G-TY&QL;FEN9V%R(&;V<B!A='0@<WEN:W)O;FES97)A
M(&UE9"!H86YD9&%T;W)E<BP@<VUA<G1A('1E;&5F;VYE<B!O8V@@3W5T;&]O
M:P!+;VYF:6=U<F%T:6]N(&)E:/9V97(@=7!P9&%T97)A<RX`2V]N9FEG=7)E
M<F$@)7,`0F5K<N1F=&$@;/9S96YO<F0`2V]N9V\`2V]N9V\`1O9R8FEN9&5L
M<V4@;6ES<VQY8VMA9&5S+@!&]G)B:6YD96QS92!M:7-S;'EC:V%D97,Z(`!&
M]G)B:6YD96QS92!M960@<'5B;&EK(&YY8VME;'-E<G9E<B!N96MA9&5S+@!&
M]G)B:6YD96QS92!M960@<'5B;&EK(&YY8VME;'-E<G9E<B!N96MA9&5S.B`E
M<R`H)7,I`$;V<F)I;F1E;'-E(&UE9"!&5%`M<V5R=F5R(&UI<W-L>6-K861E
M<RX`2V]N=&%K=&5R`$MO;G1A:W1E<B!L861E<R!T:6QL(&D@9&EN(&%D<F5S
M<V)O:RX`26YN96CE;&QS='EP(&;V<B!K;VUP<FEM97)A9"!F:6PZ(`!);FYE
M:.5L;"!I("<E<R<`1F]R='/D='0`0V]O:R!)<VQA;F1S`$-O;VMI90!+;W!I
M97)A`$MO<&EE<FEN9R!M:7-S;'EC:V%D97,Z("5S`$MO<&EE<F$@;6%R:V5R
M:6YG`$UA:G-B;&]M;6$`2V]S=&YA9',M240`0V]S=&$@4FEC80!%;&9E;F)E
M;G-K=7-T96X`2V%N(&EN=&4@4$=0+6MR>7!T97)A(&UE9&1E;&%N9&4N`$MA
M;B!I;G1E(%!'4"UK<GEP=&5R82!M961D96QA;F1E.B``2V%N(&EN=&4@4$=0
M+7-I9VYE<F$@;65D9&5L86YD92X`2V%N(&EN=&4@4$=0+7-I9VYE<F$@;65D
M9&5L86YD93H@`$MA;B!I;G1E(%,O34E-12UK<GEP=&5R82!M961D96QA;F1E
M+@!+86X@:6YT92!3+TU)344M<VEG;F5R82!M961D96QA;F1E+@!+86X@:6YT
M92!LY&=G82!T:6QL(&MO;G1A:W0N("5S`$UI<W-L>6-K861E<R!A='0@:V]N
M=&%K=&$@3$1!4"!S97)V97(N`$MA;B!I;G1E('9E<FEF:65R82!K;VYT;W-A
M;&1O+B`E<P!+=6YD92!I;G1E(&%N<VQU=&$@=&EL;"!,1$%0+7-E<G9E<BX`
M2V%N(&EN=&4@:V]N=&%K=&$@<V5R=F5R("<E<R<@=FEA($944#H@)7,`2V%N
M(&EN=&4@<VMA<&$@9&ES=')I8G5T:6]N<VQI<W1A+B`E<P!+86X@:6YT92!D
M96MR>7!T97)A(%!'4"UD871A+@!+86X@:6YT92!D96MR>7!T97)A(%!'4"UD
M871A.B``2V%N(&EN=&4@9&5K<GEP=&5R82!3+TU)344M9&%T82X`2V%N(&EN
M=&4@<F%D97)A(&MO;G1A:W0N("5S`$MA;B!I;G1E(')A9&5R82!D:7-T<FEB
M=71I;VYS;&ES=&$N("5S`$MA;B!I;G1E(')A9&5R82!U<'!G<F%D97)I;F=S
M<V-R:7!T('1I;&PZ("5S+@!+86X@:6YT92!B97-TY&UM82!M;W1T86=A<F5N
M<R!E4&]S="UA9')E<W,N`$MA;B!I;G1E(&CD;71A(&MO;7!L971T(&%D<F5S
M<V)O:RX`2V%N(&EN=&4@:.1M=&$@:V]M<&QE='0@9&ES=')I8G5T:6]N<VQI
M<W1A+@!+86X@:6YT92!HY&UT82!K;VUP;&5T="!L:7-T82#V=F5R(&1I<W1R
M:6)U=&EO;G-L:7-T;W(N`$MA;B!I;G1E(&QA9&1A('-T<F%T96=I("<E<R<N
M`$MA;B!I;G1E(&QA9&1A('-T<F%T96=I("<E<R<N`$MA;B!I;G1E('-K87!A
M(&UA<'`@)R5S)RX`2V%N(&EN=&4@<VMA<&$@;6%P<"`G)7,G+@!+86X@:6YT
M92!HY&UT82!P=6)L:6L@;GEC:V5L(&9RY6X@;GEC:V5L<V5R=F5R;BX`2V%N
M(&EN=&4@]G!P;F$@)R5S)R!F]G(@<VMR:79I;F<N`$MA;B!I;G1E(/9P<&YA
M("5S+@!+86X@:6YT92#V<'!N82`G)7,G(&;V<B!S:W)I=FEN9RX`2V%N(&EN
M=&4@]G!P;F$@36%I;G1E;F%N8V5?5&%S:R!M;V1U;"`E<P!+86X@:6YT92#V
M<'!N82!M87!P96X@)R5S)P!+86X@:6YT92#V<'!N82!M87!P("<E<R<`2V%N
M(&EN=&4@:V]N=&%K=&$@3$1!4"!S97)V97(N`$MA;B!I;G1E(&SD<V$@)7,N
M`$1E="!G:6-K(&EN=&4@871T(.5T97)S=.1L;&$@;/9S96YO<F1E="!F]G(@
M9&5N(&%N9VEV;F$@86YVY&YD87)E;BX@3N5G;VX@96QL97(@;N5G<F$@878@
M=7!P9VEF=&5R;F$@Y'(@:6YT92!K;W)R96MT82X@1O9R<_9K(&EG96X@96QL
M97(@:V]N=&%K=&$@861M:6YI<W1R873V<F5N(&]M(&1U(&)E:/9V97(@:&KD
M;'`N`$MA;B!I;G1E(&CD;71A($%#3`!+86X@:6YT92!HY&UT82!A9')E<W-B
M;VLN("5S`$MA;B!I;G1E(&CD;71A(&1I<W1R:6)U=&EO;G-L:7-T82X@)7,`
M2V%N(&EN=&4@:.1M=&$@9&ES=')I8G5T:6]N<VQI<W1O<BX@)7,`2V%N(&EN
M=&4@:.1M=&$@9'-E<G9E<F9U;FMT:6]N97(`2V%N(&EN=&4@Y71E<G-TY&QL
M82!K;VYF:6=U<F%T:6]N96XN`$MA;B!I;G1E(')A9&5R82!M87!P("<E<R<N
M`$MA;B!I;G1E(')A9&5R82!M87!P("<E<R<N`$MA;B!I;G1E('-P87)A(&MO
M;F9I9W5R871I;VX@9O9R("5S+@!+86X@:6YT92!S<&%R82!B86-K=7`M:V]N
M9FEG=7)A=&EO;BX`2V%N(&EN=&4@<W!A<F$@96X@8F%C:W5P+6MO;F9I9W5R
M871I;VXZ("5S+@!+86X@:6YT92!S<&%R82!U<'!G<F%D97)I;F=S<V-R:7!T
M('1I;&PZ("5S+@!+86X@:6YT92!S<&%R82!B86-K=7`M:V]N9FEG=7)A=&EO
M;B`E<RX`2V%N(&EN=&4@<W!A<F$@:V]N9FEG=7)A=&EO;G-F:6QE;B`E<RX@
M1'4@:V%N(&%N=&EN9V5N(&%N=N1N9&$@96X@878@86QT97)N871I=F5N(&%T
M="!S<&%R82!K;V1E;B!T:6QL("5S(&5L;&5R(&MO<&EE<F$@:V]D96X@;F5D
M86X@=&EL;"`E<RX`2V%N(&EN=&4@<_9K82!I($Q$05`M:V%T86QO9V5N+@!+
M86X@:6YT92!R861E<F$@)R5S)RX`2V%N(&EN=&4@<F%D97)A("<E<R<N`$MA
M;B!I;G1E('5P<&1A=&5R82!K;VYT86MT+B`E<P!+86X@:6YT92!U<'!D871E
M<F$@9&ES=')I8G5T:6]N<VQI<W1A+B`E<P!+86X@:6YT82!S<&%R82!K;VYF
M:6=U<F%T:6]N(&;V<B`G)7,G.B`E<P!+86X@:6YT92!H:71T82!-;WII;&QA
M<R!S:61O9N1L="X@5F5R:69I97)A(&%T="!S:61O9N1L=&5T(.1R(/9P<&5T
M+@!+86X@:6YT92!G92!A;G;D;F1A<F5N("<E<R<@86YG:79N82!RY'1T:6=H
M971E<B!T:6QL(&UA<'!E;B`G)7,G.B`E<P!2Y&MN860@=&5X=`!,86YD`$MU
M<G-E<@!3:V%P80!3:V%P82!LY&YK`%-K87!A(&YY`%-K87!A('5N9&5R;6%P
M<`!"96CV<FEG:&5T97(@9O9R(.1G87)A`$MR961I=&MO<G1S;G5M;65R`$MR
M;V%T:65N`$MU8F$`06MT=65L;&$@-"!F87-E<@!!:W1U96QL('-E<W-I;VX`
M06MT=65L;"!T:60`06MT=65L;"!54DP@Y'(`06MT:79A(&%N=N1N9&%R90!!
M:W1U96QL="!VY&1E<@!!:W1U96QL82!V:6QL:V]R.B``06MT=65L;"!S=&EL
M`%-K<N1D9&%R<WD@86MT:79I=&5T97(@<V]M(&OV<G,@=FED(&EN;&]G;FEN
M9R!T:6QL("5S+@!+;&EP<"!U=`!+;&EP<"!U<G9A;`!#>7!E<FX`2WER:6QL
M:7-K("A+3TDX+5(I`$MY<FEL;&ES:R`H5VEN9&]W<RTQ,C4Q*0!+>7)I;&QI
M<VLO56MR86EN<VL@*$M/23@M52D`5&IE8VMI96X`1$0`1&%G;&EG`$1A=&%4
M<F5E(&)LY&1D<F%R90!$871A8F%S=7!P<VQA9P!$871U;0!$871U;2!M;W1T
M86=E=`!$871U;79A;`!$86<`7U)A9&5R82!K;VQU;6X`9&5C96UB97(`1&5C
M:6UA;&5R`$%V8O9J=`!-:6YS:V$@:6YD<F%G`$;V<G9A;'0`1O9R=F%L9"!F
MY')G`$;V<G9A;&0@:61E;G1I=&5T`$;V<G9A;'0@<VMA;`!$969I;FET:6]N
M97(`1&5L96=E<F$@<&]S:71I;VX`1&5L96=E<F%D`%)A9&5R80!2861E<F$@
M8V5L;`!2861E<F$@9W)U<'``4F%D97)A(&QO9V<`4F%D97)A(&)E:/9R:6=H
M970`4F%D97)A(&]C:"!R96YS82!M961D96QA;F1E;@!2861E<F$@8V5L;`!2
M861E<F$@:V]L=6UN`%)A9&5R82!B969I;G1L:6<@86QT97)N871I=FUA;&P`
M4F%D97)A9&4@;65D9&5L86YD96X`4F%D97)A(&)E:/9R:6=H970@9O9R("<E
M<R<`4F%D97)A(&)E:/9R:6=H970@9O9R("<E<R<@;V-H('5N9&5R8F5H]G)I
M9VAE=&5R/P!2861E<F$@<F%D`%)A9&5R82!V86QD(&ED96YT:71E=`!2861E
M<F$@=6YD97)M87!P87(`4F%D97)A(&%K='5E;&P@:V]L=6UN`%)A9&5R82!A
M:W1U96QL(')A9`!2861E<F$@9&5N(&CD<B!LY&YK96X`4F%D97)A9&4@=7!P
M9W)A9&5R:6YG<W-C<FEP=&5T("<E<R<N`$QE=F5R86YS=&ED`$1A;FUA<FL`
M079S;.4@8F5GY')A;@!!=G-LY2!B96?D<F%N(&]M(&QE9&EG+W5P<'1A9V5N
M+6EN9F]R;6%T:6]N`$)E<VMR:78@<')O8FQE;65T`$)E<VMR:79N:6YG`$1E
M=&%L:F5R("AO8VMSY2!I($AO<F1E<R!L;V=G9FEL*3H`1&5T86QJ97(@:&%R
M(&QO9V=A=',@9O9R('-Y<W1E;6%D;6EN:7-T<F%T]G)E;BX`571V96-K;&EN
M9P!$86=G<'5N:W0`1&%G9W!U;FMT(&;V<B!S96YA<W1E('1I;6UE;CH@`$1A
M9V=P=6YK=#H@`%)I:W1N:6YG(';D;G-T97(@=&EL;"!H]F=E<@!2:6MT;FEN
M9R!H]F=E<B!T:6QL(';D;G-T97(`2V%T86QO9P!6:7-A(#(T+71I;6UA<G,@
M:VQO8VMA/P!6:7-N:6YG<VEN<W3D;&QN:6YG87(`5FES82!D971A;&IE<F%D
M(&;V<G5T<^1G96QS90!6:7-A(&;V<G5T<^1G96QS92`H5$%&*0!6:7-N:6YG
M<V9O<FUA=`!!=G-K:6QJ87)E`$1J:6)O=71I`%)A9&5R82!I;G1E`$%N=N1N
M9"!I;G1E(&UA:6YT96YA;F-E+G!H<"!D:7)E:W0`26YN96CE;&QE<B!F]G)S
M=&$@<F%D96X@9N1L=&YA;6YE;C\@3VT@)VIA)RP@;6%R:V5R82!HY'(Z`$1O
M;6EN:6MA;G-K82!R97!U8FQI:V5N`$AA<B!D=2!I;F=E="!K;VYT;S\@4F5G
M:7-T<F5R82!D:6<N`$CD;71A`$CD;71A("5S`$CD;71A(&=E;F5R97)A9"!K
M;VYF:6=U<F%T:6]N('-O;2!02%`M<VMR:7!T+@!$<F]P<&QI<W1A`$1R;V=E
M<@!%+7!O<W0`1')I=G)U=&EN(&;V<B!%+7!O<W0@=&EL;"!335,M8G)Y9V=A
M.R!F]G(@;W!E<F%T]G)E<B!S;VT@=&EL;&AA;F1A:.5L;&5R(&1E;FYA('1J
MY&YS="X`1D5,`$5K=6%D;W(`Q&YD<F$`Q&YD<F$@8FQO8VL`Q&YD<F$@9W)U
M<'``Q&YD<F$@8F5H]G)I9VAE=`#$;F1R82!B96CV<FEG:&5T97(`Q&YD<F$@
M8F5H]G)I9VAE=&5R(&;V<B`E<P#$;F1R82!I;G-TY&QL;FEN9V%R(&;V<CH`
MQ&YD<F$@8F5H]G)I9VAE=&5R(&;V<B`G)7,G`,1N9')A(&)E:/9R:6=H971E
M<B!F]G(@)R5S)P!5=&)I;&1N:6YG`$5G>7!T96X`16P@4V%L=F%D;W(`16QE
M;65N="XN+@!%;0!%+7!O<W0`12UP;W-T861R97-S`$4M<&]S=&%D<F5S<V5R
M(&WE<W1E('-TY&UM82#V=F5R<F5N<RX`12UP;W-T;65D9&5L86YD92!M960@
M8F5K<N1F=&5L<V4`12UP;W-T('1I;&P@4TU3+6)R>6=G80!+Y&YS;&]I:V]N
M97(`5&]M="!M961D96QA;F1E+@!4;VUT(')E<W5L=&%T+@!4;VUT('/V:VMR
M:71E<FEA`%-L=70`4VQU="#E<@!&]G)S=&]R82!E9&ET;W(`06YG92!S]FMV
MY&<@*%523"D@=&EL;"!B:6QD96X@:.1R`%-+<FEV(&)O:W-TY'9E<FYA(&YE
M9&%N.@!&96P`1F5L('9I9"!S:V%P86YD92!A=B!B;&]C:SH@)7,`1F5L('9I
M9"!R861E<FEN9R!A=B!S>6YK<F]N:7-E<FEN9W-MY')K93H@)7,`1F5L('9I
M9"!R861E<FEN9R!A=B!S>6YK<F]N:7-E<FEN9W-L;V=G.B`E<P!&96P@;N1R
M(&EN;F5HY6P@:.1M=&%D97,Z("5S`$9E;"!U;F1E<B!SY&YD;FEN9R!A=B!S
M=F%R<VUE9&1E;&%N9&4Z("5S`$9E;"!V:60@=7!P9&%T97)I;F<@878@;/9S
M96YO<F0Z("5S`$9E;"!V:60@<VMR:79N:6YG("<E<R<N`$9E;"!V:60@<VMR
M:79N:6YG(&%V("<E<R<N`$5S=&QA;F0`171I;W!I96X`171N:7-K`$5U<F]P
M80!687(@,34Z92!M:6YU=`!687)A;FYA;B!M:6YU=`!687(@,S`Z92!S96MU
M;F0`5F%R(#4Z92!M:6YU=`!687)J92!I;FQO9V=N:6YG`%9A<FIE(&AA;'9T
M:6UM90!687)J92!M:6YU=`!%>&5M<&5L('#E(';D<F1E;CH`2_9R`$5X<&%N
M9&5R80!%>'!A;F1E<F$@<VED;V;D;'0`1O9R=N1N=&%D92`G*2<`1O9R=N1N
M=&%D92!E;G-K:6QT(&]R9"!E;&QE<B!C:71E<F%T('/V:V)E9W)E<'``1O9R
M9F%L;&]D871U;0!%>'!O;F5N=`!&]G)G<G5N9'-FY')G`$QA9&1A('5P<"!K
M;VYF:6=U<F%T:6]N('9I82!&5%`N`$UI<W-L>6-K861E<R!A='0@:.1M=&$@
M:6YS=.1L;&YI;F=A<BX`36ES<VQY8VMA9&5S(&%T="!K;VYT86MT82!,1$%0
M('-E<G9E<BX`36ES<VQY8VMA9&5S(&%T="!K;VYT86MT82!334(@<V5R=F5R
M+@!-:7-S;'EC:V%D97,@871T(&MO<&EE<F$@9G+E;B`G)7,G+@!-:7-S;'EC
M:V%D97,@871T(&MO<&EE<F$@=&EL;"`G)7,G+@!-:7-S;'EC:V%D97,@871T
M('-K87!A(&YY(%-!4TPM9O9R8FEN9&5L<V4N`$UI<W-L>6-K861E<R!A='0@
M9FQY='1A('1I;&P@)R5S)RX`36ES<VQY8VMA9&5S(&%T="!HY&UT83H@)7,`
M0G)A`$9A;&ML86YD<_9A<FYA`$;D<O9A<FYA`$9A=&%L="!F96PZ`$9A>`!&
M87AA<@!F96)R=6%R:0!+Y&YN<R!S;VT`2^1N;G,@<V]M.B``1N5T86QI9V$@
M<VMU<F%R`$;E=&%L:6=A('-N]G-K=7)A<@!&Y&QT;6%T<FES`$9I9VQE="!#
M05!40TA!`$9I9VQE='1Y<'-N:71T`$9I:FD`1FEL`$%N=&%L(&9I;&5R.B`E
M<R!F:6P`06YT86P@9FEL97(Z("5S(&9I;&5R`$9I;&AA;G1E<F%R90!&:6QN
M86UN`$9I;'9A;`!&:6QU<'!L861D;FEN9P!&:6QU<'!L861D;FEN9R!S=/9D
M<R!I;G1E+@!&:6QT97(`1FEN;&%N9`!&]G)S=&$@:&%L=F%N`$;V<G-T82!K
M=F%R=&5N`$UA<'`@)7,@97AI<W1E<F%R(&EN=&4N`$9O;G1FY')G`$UA=`!&
M]G(@=V5B8FSD<V%R92!S;VT@:6YT92!S=/9D97(@8FEL9&5R`%!R;V=N;W,@
M*%1!1BD`06YT86P@9&%G87(@9O9R('!R;V=N;W,@*'9A<FIE(&1A9R!B971Y
M9&5R(&5N('!R;V=N;W,@9O9R(&1A9R!O8V@@96X@9O9R(&YA='0I`$=L]FUT
M(&1I='0@;/9S96YO<F0_`$9O<FUU;.1R`%9I<VAE='-O<F0`5'EP(&%V('9I
M<VAE='-O<F0`5FES:&5T<V]R9`!6:7-H971S;W)D(#(`1F]R=6T`5FED87)B
M969O<F1R87(`1G(`4F%M87(`1G)A;FMR:6ME`$9R86YK<FEK92P@365T<F]P
M;VP`3&5D:6<O57!P=&%G96X@:6YF;W)M871I;VX`3&5D:6<O57!P=&%G96X@
M<W9A<@!,961I9R]U<'!T86=E;BUF]G)F<N5G86X`4W9A<B!PY2!L961I9R]U
M<'!T86=E;BUF]G)F<N5G86X`1G)A;G-K82!'=6EA;F$`1G)A;G-K82!0;VQY
M;F5S:65N`$9R86YS:V$@<_9D<F$@=&5R<FET;W)I97(`1G+E;@!&<N5N(&1E
M;B``1G5L;'-TY&YD:6<@8F5S:W)I=FYI;F<`1G5L;&WE;F4`1G5L;'-TY&YD
M:6=T(&YA;6X`1V%B;VX`1V%L;&5R:2!A='0@=&$@8FEL9"!F<N5N`$=A;&QE
M<FDZ`$=A;6)I80!'96YE<F5R82!K;VYF:6=U<F%T:6]N(&;V<B`E<P!'96YE
M<F5R860@:V]D`$=E;W)G:65N`%1Y<VML86YD`$=H86YA`$=I8G)A;'1A<@!&
M]G)N86UN`$=L;V)A;&$@:6YS=.1L;&YI;F=A<@!/2P!';V5D96P`1V]O9VQE
M:V%R=&]R`$=O;V=L97/V:VYI;F<`1W+E<VMA;&$`1W)E:VES:R`H25-/+3@X
M-3DM-RD`1W+V;@!'<O9N;&%N9`!'<F%N861A`$=RY0!'<G5P<&%D;6EN:7-T
M<F%T:6]N`$=R;W5P7VQD87`Z($MA;B!I;G1E(&SD9V=A('1I;&P@9W)U<'`@
M)R5S)RX@4V5R=F5R;B!S=F%R861E.B``1W)O=7!?;&1A<#H@2V%N(&EN=&4@
M<F%D97)A(&=R=7!P("<E<R<`1W)O=7!?;&1A<#H@2V%N(&EN=&4@=7!P9&%T
M97)A(&=R=7!P("<E<R<`1W)U<'!E<@!'=6%M`$=U871E;6%L80!'=65R;G-E
M>0!'Y'-T8F5H]G)I9VAE=&5R`%1JY&YS=&5R(&;V<B!GY'-T97(`1^1S=&)O
M:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=6EN96$`2%1-3`!(5$U,07)E82!V
MY&=R87(@871T(')A9&5R82!S:7-T82!C96QL96X@:2!E;B!R860N`$A434Q!
M<F5A(';D9W)A<B!A='0@<F%D97)A('-I<W1A(&MO;'5M;F5N(&D@96X@=&%B
M96QL+@!(5$U,07)E82!VY&=R87(@871T(')A9&5R82!S:7-T82!R861E;B!I
M(&5N('1A8F5L;"X`2%144"!!=71E;G1I<V5R:6YG('-A:VYA<RX`2&%I=&D`
M2&%S:&%L9V]R:71M`$1I;6UA`%)U8G)I:P!2=6)R:6ME<@!(96%R9"T@;V-H
M($UC1&]N86QD]F%R;F$`2W)A9G1I9V$@Y7-K<VMU<F%R`$AE8G)E:7-K("A)
M4T\M.#@U.2TX+4DI`$CV:F0`2/9J9"`H<&EX;&%R*0!(:N1L<`!(:N1L<"!M
M960@961I=&]R;@!(:N1L<&9U;FMT:6]N`$AE;6ES9N1R`$CD<B#D<B!B]G)J
M86X@878@9FEL96XZ`$CV9P!(95]M`$AE;0!!9')E<W,L(&AE;0!(96UK871A
M;&]G`%1E;&5F;VXL(&AE;0!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R
M9&4O2V]L86(Z($]G:6QT:6=T("5S(%A-3"UD871A('#E='+D9F9A9&5S(&D@
M;65D9&5L86YD92`E<P!(;W)D92]+;VQA8CH@26YG970@;65D9&5L86YD92!M
M871C:&%R(&]B:F5K=&5T("5S`$AO<F1E+TMO;&%N.B!);F=E="!O8FIE:W0@
M878@='EP96X@)7,@:&ET=&%D97,@:2!M961D96QA;F1E="`E<P!(;W)D92]+
M;VQA8CH@4F%D97)A9&4@)7,@)R5S)P!(;W)D92]+;VQA8CH@26YT96=R871I
M;VYS;6]T;W)N(&MRY'9E<B`G9&]M>&UL)RUT:6QLY&=G970@9O9R(%!(4`!(
M;W)D92]+;VQA8CH@2V%N(&EN=&4@<VMA<&$@;GET="!834PM='+D9"!F]G(@
M;V)J96MT("5S`$AO<F1E+TMO;&%B.B!+86X@:6YT92!R861E<F$@)7,@)R5S
M)SH@)7,`2&]R9&4O2V]L86(Z($MA;B!I;G1E(&CD;71A($U)341%+4E$(&;V
M<B!D96QE;B!M960@='EP("5S`$AO<F1E+TMO;&%B.B!+86X@:6YT92!S>6YK
M<F]N:7-E<F$@)7,@)R5S)SH@)7,`2&]R9&4O2V]L86(Z($MA;B!I;G1E('-Y
M;FMR;VYI<V5R82!U=&1E;&YI;F=A<CH@)7,`2&]R9&4O2V]L86(Z($]KY&YD
M('5T9&5L;FEN9R`G)7,G`$AO<FES;VYT96QL(&QI;FIE`$AO<FES;VYT96QL
M('5T9GEL;&YA9`!(;W)I<V]N=&5L;#H`2'5R(&AA;6YA9&4@9'4@:.1R/R`H
M5F%R(&=O9"!R87!P;W)T97)A(&1E='1A(2D`2'5R(&WE;F=A(&MO;'5M;F5R
M('9I;&P@9'4@<VSE(&EH;W`_`$AU<B!MY6YG82!FY&QT("AK;VQU;6YE<BD@
M9FEN;G,@9&5T/P!(=7(@;>5N9V$@<F%D97(@=FEL;"!D=2!S;.4@<V%M;6%N
M/P!&=6MT:6=H970`1G5K=&EG:&5T.@!(=6UO<FES=&5R`%5N9V5R;@!3:V%P
M86YD92!A=B!)34%0+6UA<'`@;6ES<VQY8VMA9&4Z("5S`%)A9&5R:6YG(&%V
M($E-05`M;6%P<"!M:7-S;'EC:V%D97,Z("5S`%-K87!A;F1E(&%V('%U;W1A
M(&;V<B!)34%0+6UA<'`@;6ES<VQY8VMA9&5S.B`E<P!)4"UA9')E<W,`25`M
M861R97-S(.1R(&EN=&4@=&EL;&?D;F=L:6<N`$E0+6%D<F5S<R#D<B!I;G1E
M(&EN;VT@9V]D:^1N="!#2412+6)L;V-K+@!&]G)S]FL@871T(&MR:6YG9^4@
M25`M;.5S+@!)7VYF;V=A(')A9"!F]G)E`$ES;&%N9`!%;F)A<G0@:6MO;F5R
M`$EK;VYE<B!F]G(@)7,`26MO;F5R(&UE9"!T97AT`$ED96YT:71E=&5N<R!N
M86UN.@!/;2!D970@:6YT92!V:7-A<R!K;W)R96MT+"`E<R!F]G(@871T(/9P
M<&YA(&D@;GET="!F]FYS=&5R+@!/;2!D=2!I;G1E('-E<B!NY6=R82!I:V]N
M97(@;N1R(&1U(&%N=N1N9&5R($EN=&5R;F5T($5X<&QO<F5R+"!SY2!K86X@
M9'4@8F5H]G9A(&UA<FME<F$@9&5N;F$@<G5T82!F]G(@871T('-TY&YG82!A
M=B!G96YO;7-K:6YL:6=A(%!.1RUB:6QD9FEL97(N`$]M(&1U('-E<B!D96YN
M82!T97AT(&UE;B!I;F=E;B!B:6QD+"!SY2!K86X@:6YT92!D:6X@=V5B8FSD
M<V%R92!V:7-A(&1E;B!B:6QD(&1U(&;V<G/V:V5R(&QA9&1A('5P<"X`1O9R
M:&%N9'-G<F%N<VMA(&)I;&0Z`$)I;&1A9')E<W,`0FEL9&%D<F5S<SH`0FEL
M9"!F<N5N(&=A;&QE<FD`0FEL9"!F<N5N(&=A;&QE<FDZ`$QA9&1A('5P<"!B
M:6QD`$)I;&1E<@!);7!O<G1E<F$L('-T96<@)60`26UP;W)T97)A9&4@9N1L
M=#H@)7,`26UP;W)T97)A9&4@9N1L=#H`4.5GY65N9&4`26Y?9F]G82!R860@
M969T97(`1F5L86MT:78@86MT:79I=&5T<VMO9"!S<&5C:69I8V5R860N`$9E
M;&%K=&EG="!A;G;D;F1A<FYA;6X@;V-H+V5L;&5R(&SV<V5N;W)D+@!/9VEL
M=&EG="!A;G;D;F1A<FYA;6X@96QL97(@86QT97)N871I=B!A9')E<W,N($;V
M<G/V:R!I9V5N(&5L;&5R(&MO;G1A:W1A(&%D;6EN:7-T<F%T]G)E;B!O;2!D
M=2!B96CV=F5R(&AJY&QP+@#6:V$@:6YD<F%G`$EN9&EE;@!);F1I=FED=65L
M;&$@86YVY&YD87)E`$EN9&]N97-I96X`26YF;P!);F9O<FUA=&EO;@!);F9O
M<FUA=&EO;B#D<B!I;G1E('1I;&QGY&YG;&EG(&SD;F=R92X`26YF;V=A(&M?
M;VQU;6X@969T97(`26YF;V=A(&)I;&0`26YF;V=A('1A8F5L;`!);F9O9V$@
M=V5B8FSD;FL`26YF;V=A(%]K;VQU;6X@9O9R90!);F9O9V$@;GD@:V]L=6UN
M(&5F=&5R(&%K='5E;&P@:V]L=6UN`$EN9F]G82!N>2!K;VQU;6X@9O9R92!A
M:W1U96QL(&MO;'5M;@!);F9O9V$@<F%D(&5F=&5R(&%K='5E;&P@<F%D`$EN
M9F]G82!N>2!R860@9O9R92!E:W1U96QL(')A9`!);F9O9V$@<&%R86=R868@
M969T97(@86MT=65L;"!N;V0`26YF;V=A('!A<F%G<F%F(&;V<F4@86MT=65L
M;"!N;V0`26YF;V=A(&%L=&5R;F%T:78@;6%L;`!);F9O9V$@8V5L;"!E9G1E
M<@!);F9O9V$@8V5L;"!F]G)E`$EN9F]G82!K;VQU;6X@969T97(`26YF;V=A
M(&MO;'5M;B!F]G)E`$EN9F]G82!M961D96QA;F1E;@!);F9O9V$@<&%R86=R
M868@969T97(`26YF;V=A('!A<F%G<F%F(&;V<F4`26YF;V=A(')A9"!E9G1E
M<@!);F9O9V$@<F%D(&;V<F4`06YG92!E<F9O<F1R870@<W9A<B!T:6QL('/D
M:V5R:&5T<V9RY6=A;CH`26YF;V=A+\1N9')A(&)I;&0`26YF;V=A+\1N9')A
M(&SD;FL`3W1I;&QRY&-K;&EG(&MR961I="!F]G(@871T('-K:6-K82!T:6QL
M(&1I<W1R:6)U=&EO;G-L:7-T82X`3W1I;&QRY&-K;&EG(&MR961I="X`2&5L
M=&%L`$AE;'1A;'-L:7-T80!/9VEL=&EG(.5T9^1R9"!F]G(@9&5N(&CD<B!K
M;VUP;VYE;G1E;BX`3V=I;'1I9R!51$@@*"=U<V5R(&1A=&$@:&5A9&5R)RDN
M`$]G:6QT:6=T(%I)4"UA<FMI=F1A=&$`1F5L86MT:6<@87!P;&EK871I;VXN
M`$9E;&%K=&EG="!B871C:"U)1`!&96QA:W1I9R!D871A('-K:6-K860N`$9E
M;&%K=&EG(&1E<W1I;F%T:6]N<V%D<F5S<RX`1F5L86MT:6=T(&9I;&9O<FUA
M=`!/9VEL=&EG(&QI8V5N<VYY8VME;"X`1F5L86MT:6<@;W)T('-P96-I9FEC
M97)A9"X`1F5L86MT:6<@;65D9&5L86YD95]T>7`N`$9E;&%K=&EG(&5L;&5R
M('-A:VYA9"!A<&E?:60N`$9E;&%K=&EG="!E;&QE<B!S86MN860@<&%R86UE
M=&5R+@!&96QA:W1I9R#V=F5R;&EG9V%N9&4@8F5H]G)I9VAE="X`1F5L86MT
M:6=T('!A<G1N97(M:60N`$9E;&%K=&EG('!R;V1U:W1K;V0N`$9E;&%K=&EG
M="!P<F]T;VMO;&PN`$9E;&%K=&EG(&UO='1A9V%R93H@)R5S)P!&96QA:W1I
M9W0@=71D96QN:6YG<V]B:F5K=`!&96QA:W1I9R!A=G/D;F1A<F%D<F5S<RX`
M1F5L86MT:6=T('5N:6-O9&4M9&%T80!);G9E;G1A<FEE<@!);G9E<G1E<F$@
M=7)V86P`27)A;@!)<F%K`$ER;&%N9`!)<VQE(&]F($UA;@!%;G-T86MA(.5S
M:W-K=7)A<@!)<W)A96P`571FY')D870@878`2W5R<VEV`$ET86QI96X`2F%M
M86EC80!J86YU87)I`$IA<&%N`$IA<&%N<VL@*$E33RTR,#(R+4I0*0!*97)S
M97D`2F]R9&%N:65N`&IU;&D`:G5N:0!*=7-T97)A`$-E;G1E<FIU<W1E<F$`
M2G5S=&5R82!JY&UT`%;D;G-T97)J=7-T97)A`$CV9V5R:G5S=&5R80!+96YY
M80!+97)B97)O<W-E<G9E<FX@879V:7-A9&4@875T96YT:7-E<FEN9V5N+@!.
M>6-K96P@<VMA<&%D`$9I;F=E<G!R:6YT`$YY8VME;&SD;F=D`$YY8VME;'1Y
M<`!.>6-K96QA;G;D;F1A;F1E`$YY8VME;"!F:6YN<R!R961A;B!PY2!D96X@
M<'5B;&EK82!N>6-K96QS97)V97)N+@!"87)N`$MI<FEB871I`$MO;&%B`$YO
M<F1K;W)E80!3>61K;W)E80!+;W)E86YS:R`H155#+4M2*0!+=7=A:70`2VER
M9VES=&%N`$QA7WEO=70`4W!RY6L`3&%O<P!3:7-T82!H86QV86X`3/9S96YO
M<F0@Y&YD<F%D97,`4VES=&$@:W9A<G1A;&5T`%-E;F%S="!U<'!D871E<F%D
M.@!396YA<W1E(&EN;&]G9VYI;F<Z("5S`%-E;F%S=&4@:6YL;V=G;FEN9SH@
M)7,@9G+E;B`E<P!396YA<W1E(&EN;&]G9VYI;F<Z($%L9')I9P!,971T;&%N
M9`!,879E;F1E<@!,86<`3&%Y;W5T`$SD;6YA('1O;2!F]G(@871T('-TY&YG
M82!A=B!K86YT;&EN:F4`3&EB86YO;@!6Y&YS=&5R`%;D;G-T97)R=6)R:6L`
M5N1N<W1E<G;D<F1E;@!,97-O=&AO`$YI=N4`3&EB97)I80!,:6)Y96X`3&EE
M8VAT96YS=&5I;@!,:G5S8FSE`$1U9V=R96=N`$SD='0@<F5G;@!,Y'1T(&;V
M<FUI9&1A9W-R96=N`$SD='0@969T97)M:61D86=S<F5G;@!,Y'1T(')E9VYS
M:W5R`$SD='0@<F5G;B!M960@Y7-K80!,Y'1T('-N]@!,Y'1T('-N]G-K=7(`
M3&EM97)I8VL`3.1N:P!,Y&YK96X@<&5K87(@<.4Z`$SD;FMA(&4M<&]S=&%D
M<F5S<V5N('1I;&P@9G5N:W1I;VYE;B!F]G(@871T('-K87!A(&YY='0@;65D
M9&5L86YD90!,Y&YK87(`2V%K80!,:7-T82`M(&%N=N1N9&%R92!K86X@<V4@
M;6%P<&5N`%9I<V$@9&%T86)A<V5R`%9I<V$@:&KD;'#D;6YE;@!,:7-T82!T
M86)E;&QE<@!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/
M=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB
M90!$970@9VEC:R!I;G1E(&%T="!L:7-T82!S97-S:6]N97(Z("5S`$1E="!G
M:6-K(&EN=&4@871T(&QI<W1A(&%N=N1N9&%R93H@)7,`3&ES=&YI;F<@878@
M86YVY&YD87)E(&%V86MT:79E<F%D+@!,:71T97)A='5R`$QI=&%U96X`3&%D
M9&%R+BXN`$QO:V%L('1I9#H@`%)E9VEO;F%L=`!0;&%T<P!,;V=G82!I;@!,
M;V=G82!U=`!,;V=I;@!,;V=I;F%K=&EV:71E=&5R`$EN;&]G9VYI;F<@;6ES
M<VQY8VMA9&5S+B!4<F]L:6=T=FES('9A<B!A;G;D;F1A<FYA;6X@96QL97(@
M;/9S96YO<F0@9F5L86MT:6=T+@!);FQO9V=N:6YG(&UI<W-L>6-K861E<RX`
M3.5N9R!T97AT`$OD<FQE:P!,Y6<`1W)E:VES:V$@9V5M96YE<@!,871I;G-K
M82!G96UE;F5R`%-MY2!R;VUE<G-K82!S:69F<F]R`$QO>6]L80!,;WEO;&$@
M0FSE`$QU>&5M8G5R9P!-30!-3U1$`$U3+51.148@8FEL86=A(&EN;F5H]FQL
M(&EN9V5N(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:65N`$UA9V%G87-K87(`
M36%G:7-K`$4M<&]S=`!%+7!O<W1A9&UI;@!3:V%P82!LY&YK+BXN`$UA;&%W
M:0!-86QA>7-I80!-86QD:79E<FYA`$UA;&D`36%L=&$`56YD97)HY6QL(&QI
M<W1A;B!M960@:V%T96=O<FEE<B!D=2!A;G;D;F1E<B!F]G(@871T(&MA=&5G
M;W)I<V5R82!P;W-T97(@;65D(&]C:"!FY')G97)N82!S;VT@=&EL;&CV<B!D
M97-S82!K871E9V]R:65R+@!-87`R-"UK87)T80!-87!1=65S="UK87)T80#6
M=F5R<^1T=&YI;F=A<B!S<&%R861E+@!M87)S`$UA<F=I;F%L`$9L86=G82!S
M;VT@;.1S="]O;.1S=`!&;&%G9V$@;65D(&%N;F%N('-T871U<R`H="!E>"!V
M:6MT:6=T+V)E<W9A<F%T*0!-87)S:&%L;/9A<FYA`$UA<G1I;FEQ=64`36%T
M8VAA;F1E(&;D;'0`36%U<FET86YI96X`36%U<FET:75S`$UA>"!T:6QLY71E
M;B!K<F5D:70N`$=RY&YS(&;V<B!M87@@86YT86P@9&5L87(@:2!M961D96QA
M;F1E(/9V97)S:W)I9&5N+@!(]F=S=&$@=&5M<&5R871U<F4@<V5N87-T92`R
M-"!T:6UM87)N83H@`$CV9W-T82!T96UP97)A='5R92!S96YA<W1E(#8@=&EM
M;6%R;F$Z(`!-87AI;6%L="!A;G1A;"!P;W)T86QB;&]C:P!-87AI;6%L(&SD
M;F=D`&UA:@!-87EO='1E`$UE9&EC:6X`079B;VMA(&WV=&4`3?9T97-I;F9O
M<FUA=&EO;@!-]G1E<V;V<F9RY6=A;@!-]G1E<W-V87(`3?9T97-U<'!D871E
M<FEN9P!5<'!D871E<FEN9W-B96?D<F%N(&]M(&WV=&4`365D;&5M;6%R`$UE
M;GELY&=E.@!3;.4@:6AO<"!C96QL97(`365D9&5L86YD90!-961D96QA;F1E
M="!V97)I9FEE<F%D97,@;65N(&1E;B!S:6=N97)A9&5S(&-E<G1I9FEK870@
M:W5N9&4@:6YT92!V97)I9FEE<F%S+@!-961D96QA;F1E(&?D;&QE<B!I;G1E
M(&SD;F=R92X`365D9&5L86YD971Y<`!-971A<G;D9&5R`$UE=&%R8FQO8VME
M="#D<B!I;G1E('1I;&QGY&YG;&ET+@!-971A<BUB;&]C:R!E:B!T:6QL9^1N
M9VQI9W0N($1E=&%L:F5R(&AA<B!L;V=G871S(&;V<B!S>7-T96UA9&UI;FES
M=')A=/9R96XN`$UE=&%R1$(@Y'(@:6YT92!A;G-L=71E;BX`365T;V0`365T
M;V1E;B`G)7,G(.1R(&EN=&4@9&5F:6YI97)A9`!-971O9&5N(&AA<B!I;G1E
M(&1E9FEN97)A=',N($%N<F]P860@;65T;V0Z("5S`$UE=')I<VL`365X:6MO
M`$UI:W)O;F5S:65N`$UI='1E;@!-:6UE='EP`$SD9W-T82!T96UP97)A='5R
M('-E;F%S=&4@,C0@=&EM;6%R;F$Z(`!,Y&=S=&$@=&5M<&5R871U<B!S96YA
M<W1E(#8@=&EM;6%R;F$Z(`!-:6YS=&$@;/9S96YO<F1SY6QD97(@:&%R(&EN
M=&4@=7!P;N5T=',@Y&X`4W!E9VQA`$1I=F5R<V4`3V)L:6=A=&]R:7-K="!P
M86ME="!S86MN87,@*%!%05(@2%144%]297%U97-T*2X`2V]N9FEG=7)A=&EO
M;B!S86MN87,N($1U(&WE<W1E('-K87!A(&1E;B!N=2!O;2!D=2!V:6QL(&%N
M=N1N9&$@9&5N(&CD<B!A<'!L:6MA=&EO;F5N+@!386MN87(@;65D9&5L86YD
M92U)1"X`3V)L:6=A=&]R:7-K="!P86ME="!S86MN87,@*%!%05(@36%I;"DN
M`%-A:VYA<B!S97-S:6]N<RU)1"X`3>4`36]B:6P@92UP;W-T`$UO9&5R97)A
M`,1N9')A9"!D871U;0#$;F1R82!LY&YK`$UO9'5L=7,`36]L9&%V:65N`$UO
M;F%C;P!-;VYG;VQI970`3>5N860@;V-H(.5R`$WE;F%T;&EG`$UO='-E<G)A
M=`!-Y6YF87-E<@!&;&5R(&;D;'0@:&ET=&%D97,@<.4@<F%D("5D(.1N(&1E
M="!F]G)VY&YT861E("5D+@!-87)O8VMO`$UE<W1A9&5L<R!K;&%R=`!-97-T
M861E;',@;6]L;FEG=`!-97-T861E;',@<V]L:6=T`$9L>71T82!N960`1FQY
M='1A(';D;G-T97(`1FQY='1A(&CV9V5R`$9L>71T82!U<'``1FQY='1A(&YE
M9`!&;'ET=&$@=7!P`$UOYV%M8FEQ=64`36]Z:6QL80!&;&5R;FEVY7-L:7-T
M80!-=6QT:6UA<"!3=&]R8G)I=&%N;FEE;FMA<G1A`$9L97)V86P`36ET="!K
M;VYT;P!-:6X@:V]N=&]I;F9O<FUA=&EO;@!-:6X@<&]R=&%L`$UI;B!P;W)T
M86QL87EO=70`37EA;FUA<@!.14HL($IA9R!A8V-E<'1E<F%R(&EN=&4`3F%M
M;@!.86UI8FEA`$YA=7)U`$YE6%0`0F5H]G9E<B#E=&?D<F0`3F5P86P`3F5D
M97)LY&YD97)N80!.961E<FSD;F1S:V$@06YT:6QL97)N80!.97-C87!E(&)A
M<RU54DP`3F5T<V-A<&4@9O9R;GEE;'-E+5523`!.971S8V%P92#E=&5R:V%L
M;&5L<V4M55),`$YE='-C87!E(%-33"US97)V97)N86UN`$YE='-A<&4@8V5R
M=&EF:6MA='-K;VUM96YT87(`3F5T<V%P92!C97)T:69I:V%T<W1Y<`!.Y'1V
M97)K`$%L9')I9P!.>6$@2V%L961O;FEE;@!.>2!K871E9V]R:0!.>71T(&UE
M9&1E;&%N9&4@=&EL;"`E<P!.>6WE;F4`3GET="!A;G;D;F1A<FYA;6X@*'9A
M;&9R:71T*0!.>6$@6F5E;&%N9`!.>71T(&SV<V5N;W)D`$YY='0@;/9S96YO
M<F0@:V]M;65R(&%T="!GY2!U="`E>"X`3/9S96YO<F0@;>5S=&4@=F%R82!S
M86UM82X`3GET="!F]FYS=&5R("A?8FQA;FLI`$YY:&5T97(`3GEH971S9W)U
M<'!E<@!.Y'-T80!+;VUM86YD92`T(&9A<V5R`$[D<W1A(&EN<W3D;&QN:6YG
M87(`3N1S=&$^`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YA='0`3FEU90!.
M96H`1&5T(&9I;FYS(&EN9V5T(&MO;F9I9W5R871I;VYS9&%T82!A='0@=FES
M82!S:VEL;&YA9&5R(&;V<BX`26YG96X@=&EL;&?D;F=L:6<@<W1R871E9VD@
M9O9R(&%T="!S:V%P82!)4T\M:6UA9V4N`$EN=&4@96X@8F%T8VAM86QL+@!$
M970@9FEN;G,@:6YG970@8FQO8VL@<.4@9&5N(&)E9^1R9&$@<&]S:71I;VYE
M;@!);F=E="!K86QE;F1E<FYA;6X@9O9R($U#04P@875T96YT:7-E<FEN9R!A
M;F=I=F5T+@!);F=E;B#D;F1R:6YG+@!);F=A('5N9&5R8F5H]G)I9VAE=&5R
M(&MA;B!LY&=G87,@=&EL;"!D96X@:.1R(&)E:/9R:6=H971E;BX`26YG96X@
M:V]N9FEG=7)E<FEN9W-I;F9O<FUA=&EO;B!A;F=I=F5N(&;V<B`E<RX`26YG
M96X@:V]N9FEG=7)E<FEN9W-I;F9O<FUA=&EO;B!A;F=I=F5N(&;V<B!&5%`@
M5D93+@!);F=E;B!K;VYF:6=U<F5R:6YG<VEN9F]R;6%T:6]N(&%N9VEV96X@
M9O9R(%-13"!61E,N`$EN9V5N(&MO;F9I9W5R97)I;F=S:6YF;W)M871I;VX@
M86YG:79E;B!F]G(@4U%,+69I;"!61E,N`$EN9V5N(&MR961I="!K=F%R+@!"
M97-K<FEV;FEN9R!S86MN87,N`$EN9V5N(&UO='1A9V%R92!A;F=I=F5N+@!)
M;F=E;B!F:6P@=7!P;&%D9&%D`$EN9V$@:6MO;F5R(&AI='1A9&5S+@!);F=E
M;B!O<G0@86YG:79E;BX`26YG96X@;W)T(&%N9VEV96XN`$EN9V5T(&UE9&1E
M;&%N9&4@8FEF;V=A9&5S+@!);F=E="!N86UN(&%N9VEV970N`$EN9V5N(&YU
M;6UE<B!A;F=I=F5T+@!);F=A(&]F]G)S:^1M9&$@=FES:&5T<V]R9`!);F=E
M="!L]G-E;F]R9"!F]G(@2%144"UA=71E;G1I<V5R:6YG(&%N9VEV970N`$EN
M9V5T(&SV<V5N;W)D(&;V<B!)34%0+6%U=&5N=&ES97)I;F<@86YG:79E="X`
M26YG970@;/9S96YO<F0@9O9R($ME<F)E<F]S+6%U=&5N=&ES97)I;F<@86YG
M:79E="X`26YG970@;/9S96YO<F0@9O9R($QO9VEN+6%U=&5N=&ES97)I;F<@
M86YG:79E="X`26YG970@;/9S96YO<F0@9O9R(%!!4U-71"UA=71E;G1I<V5R
M:6YG(&%N9VEV970N`$EN9V5T(&SV<V5N;W)D(&;V<B!334(M875T96YT:7-E
M<FEN9R!A;F=I=F5T+@!);F=A(';D;G1A;F1E(')E9VES=')E<FEN9V%R+@!)
M;F=E;B!K=F]T82!A;F=I=F5N`$EN9V5N(&MV;W1A(&%N9VEV96XN`$EN9V$@
M<F5G;&5R`$EN9V5N(&%V9W+D;G-A<F4@86YG:79E;BX`26YG82!S:61O<@!)
M;F=E;B!SY61A;B!F:6P`26YG96X@=&5M<&]RY')K871A;&]G('1I;&QGY&YG
M;&EG(&;V<B!C86-H92X`26YG970@86YVY&YD87)N86UN(&]C:"]E;&QE<B!L
M]G-E;F]R9"!S:VEC:V%T+@!);F=E="!G:6QT:6<@6$U,+61A=&$@<F5T=7)N
M97)A9&5S`$EN9V$@=N1R9&5N`$EN9V5N('9E<G-I;VX@:&ET=&%D97,@:2!D
M96X@=7)S<')U;F=L:6=A(&MO;F9I9W5R871I;VYE;BX@Q71E<G-K87!A(&MO
M;F9I9W5R871I;VYE;BX`26YG96X@=F5R<VEO;B!H:71T861E<R!I(&1I;B!K
M;VYF:6=U<F%T:6]N+B#%=&5R<VMA<&$@:V]N9FEG=7)A=&EO;F5N+@!)8VME
M+61E;'1A9V%R90!);F=E;@!);F=E;B`H86YVY&YD('5N9&5R9O9R<W3E9&0I
M`$YO<F9O;&OV87)N80!.;W)R82!H96UI<V;D<F5N`$YO<G)A($UA<FEA;F'V
M87)N80!.;W)G90!);G1E(&5F=&5R`$EN=&4@9O9R90!);G1E(&5N(&MA=&%L
M;V<`16H@:6UP;&5M96YT97)A9"X`16H@86YG:79E;@!3=/9D<R!I;G1E+@!!
M;G1E8VMN:6YG87(`26YG96YT:6YG(&%T="!V:7-A+"!GY2!T:6QL8F%K82X`
M3T)3`&YO=F5M8F5R`$YU;6UE<@!!;G1A;"!T96-K96X`06YT86P@:V]L=6UN
M97(`06YT86P@<F%D97(`3G5M;65R(&EN=&4@<W!E8VEF:6-E<F%D92!F]G(@
M871T('5P<&1A=&5R82!I(&1I<W1R:6)U=&EO;G-L:7-T86XN`$]+`$]B:F5K
M=`!/8FIE:W1S:V%P87)E`$]K=&%L`&]K=&]B97(`1FEL=&5R(&;V<B!O9O9R
M<VOD;61H971E<@!+;VYT;W(`1V%M;6%L="!O8V@@;GET="!L]G-E;F]R9"!F
MY7(@:6YT92!V87)A('-A;6UA+@!'86UM86QT(&SV<V5N;W)D`$=A;6UA;'0@
M;/9S96YO<F0@Y'(@9F5L86MT:6=T`$]M86X`1&5L861E(&UA<'!A<B!S=/9D
M<R!E;F)A<G0@878@24U!4"US97)V<F%R`$5N8F%R="!O9O9R<VOD;61A('9I
M<VAE='-O<F0`16YD87-T(&5N(&4M<&]S=&%D<F5S<R!T:6QLY71E;BX`16YD
M87-T(.1G87)E(&5L;&5R('-Y<W1E;6%D;6EN:7-T<F%T]G(@:V%N(.1N9')A
M(.1G87)E(&5L;&5R(&)E:/9R:6=H971E<B!PY2!E;B!U=&1E;&YI;F<`UG!P
M;F$@:2!N>71T(&;V;G-T97(`3W!E;E-33"UF96PZ($1E="!G:6-K(&EN=&4@
M871T(&5X=')A:&5R82!D871A(&9RY6X@<VEG;F5R860@4R]-24U%+61E;"X`
MUG!P;F$@;.1N:R!I(&YY='0@9O9N<W1E<@!/<&5R871I=G-Y<W1E;0!)8VME
M(&]B;&EG871O<FES:V$@9&5L=&%G87)E`$EN<W3D;&QN:6YG87(`26YS=.1L
M;&YI;F=A<B!F]G(@)7,`4V]R=&5R860@;&ES=&$`3W)G86YI<V%T:6]N`$]R
M9V%N:7-A=&EO;G-E;FAE=`!/<F=A;FES97)A`%5R<W!R=6YG;&EG(&%P<&QI
M:V%T:6]N<VUA;&P`57)S<')U;F=L:6=A(&UA;&QA<B!I("5S.@!!;FYA;@!!
M;F1R82!I;G-TY&QL;FEN9V%R`,1G87)B96CV<FEG:&5T97(`4$%-+4%U=&5N
M=&ES97)I;F<@Y'(@:6YT92!T:6QL9^1N9VQI9RX`4$5!4CHZ36%I;"UK;W!P
M;&EN9P!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$871A
M`%!U8FQI:R!01U`M;GEC:V5L`%!'4"!3:6=N960O16YC<GEP=&5D($1A=&$`
M4$A0+6MO9`!02%`M<VMA;`!,Y'1T(&;V<FUI9&1A9W-R96=N`$;V<FUI9&1A
M9W-R96=N`$5F=&5R;6ED9&%G<W-K=7)A<@!%9G1E<FUI9&1A9W-S;O8`169T
M97)M:61D86=S<VMU<F%R(&UE9"!S;O8`169T97)M:61D86=S<V]L`,5S:W-K
M=7)A<B!PY2!E9G1E<FUI9&1A9V5N`%!/4TE8+71I;&SD9V<@<V%K;F%S`%!?
M2%`M<VMA;`!5=&9Y;&QN860Z`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN80!0
M86YA;6$`4&%P=6$M3GEA($=U:6YE80!087)A9W5A>0!$96QV:7,@;6]L;FEG
M=`!,]G-E;F]R9`!,]G-E;F]R9"#D;F1R861E<RX`3/9S96YO<F0@9F5L86MT
M:6=T`$SV<V5N;W)D(&MRY'9S(&;V<B!2041)55,@875T96YT:7-E<FEN9RX`
M3/9S96YO<F0@;65D(&)E:W+D9G1E;'-E`$SV<V5N;W)D.@!,]G-E;F]R9#H@
M`$SV<V5N;W)D(&WE<W1E('9A<F$@;&EK82X`2VQI<W1R82!I;@!+;&ES=')A
M(&EN(&9RY6X@=7)K;&EP<'-H86YT97)A<F5N`%/V:W;D9P!6Y&YT86YD92!R
M96=I<W1R97)I;F=A<CH`3>1N;FES:V]R`%!R;V-E;G0`571F]G(@=6YD97)H
MY6QL<V9U;FMT:6]N97(`571F]G(@=6YD97)HY6QL<V%K=&EV:71E=&5R('9I
M9"!I;FQO9V=N:6YG/P!"96CV<FEG:&5T`$)E:/9R:6=H970@)R5S)R!R861E
M<F%D97,@:6YT92X`Q71K;VUS="!N96MA9`!B96CV<FEG:&5T97(`0F5H]G)I
M9VAE='-A9&UI;FES=')A=&EO;@!097)S;VYL:6<@:6YF;W)M871I;VX`4&5R
M=0!(=7-D:G5R`$9I;&EP<&EN97)N80!496QE9F]N`$9O=&]N`%!I=&-A:7)N
M`%!I>&QA<@!+;&EC:.EE<@!687(@9V]D(&ML:6-K82!I(&5N(&-E;&P`0F5K
M<N1F=&$@871T(&1U('9I;&P@<F%D97)A('9A;&0@<&]S=#\`0F5K<N1F=&$@
M871T(&1U('9I;&P@<F%D97)A(&%K='5E;&QT(&5L96UE;G0N`%9A<B!G;V0@
M86YG92!MY6YA9"!O8V@@Y7(N`%9A<B!G;V0@86YG92!N86UN(&;V<B!K871E
M9V]R:6XZ`%9A<B!G;V0@86YG92!G;V1KY&YD($E0+6%D<F5S<RX`5F%R(&=O
M9"!A;F=E(&5T="!G:6QT:6=T(&1A='5M.R!K;VYT<F]L;&5R82!A;G1A;&5T
M(&1A9V%R(&D@;>5N861E;BX`5F%R(&=O9"!A;F=E(&5N(&=O9&OD;F0@=&ED
M+@!687(@9V]D('-U;6UE<F$@9&ET="!P<F]B;&5M+@!!;F=E(&1I='0@86YV
MY&YD87)N86UN(&]C:"!L]G-E;F]R9"X`5F%R(&=O9"!LY',@:6=E;F]M(&;V
M;&IA;F1E('1E>'0N($1U($W%4U1%('-A;71Y8VMA(&UE9"!V:6QL:V]R96X@
M9O9R(&%T="!A;G;D;F1A('-Y<W1E;65T+@!687(@9V]D(&SD<R!I9V5N;VT@
M9O9L:F%N9&4@=&5X="X@1'4@3<535$4@<V%M='EC:V$@;65D('9I;&QK;W)E
M;B!F]G(@871T(&%N=N1N9&$@<WES=&5M970N`$MO;G1R;VQL97)A(&;V;&IA
M;F1E(&EN9F]R;6%T:6]N(&]C:"!VY&QJ('-E9&%N(&5N(&AA;F1L:6YG(&D@
M;65N>6X*;F5D86XN`%;D;&H@96X@:&%N9&QI;F<@9G+E;B!M96YY;B!N961A
M;BX`06YG92!N>71T(&MA=&5G;W)I;F%M;CH`4&]L96X`4&]L:71I:P!5;F1E
M<G/V:VYI;F=A<@!0;W)T=6=A;`!0;W-I=&EO;F5R:6YG(&%V(&)I;&1E;@!0
M;W-I=&EO;F5R:6YG(&%V('1A8F5L;&5N`%-K<FEV('1I;&P@9&5N(&CD<B!M
M87!P96X@*&5J('1V:6YG870@878@24U!4"D`4&]S=&YU:V4`3F5D97)B]G)D
M(&1E('-E;F%S=&4@)7,@=&EM;6%R;F$Z(`!#:&%N<R!T:6QL/&)R+SYN961E
M<F+V<F0`075T:%]L9&%P.B!,1$%0+71I;&SD9V<@<V%K;F%S+@!0<F5F<U]S
M97-S:6]N.B!/8FQI9V%T;W)I<VMT('-E<W-I;VYS=&EL;.1G9R!H:71T861E
M<R!I;G1E+@!4<GEC:P!,=69T=')Y8VL@=FED(&AA=F5T.B``3'5F='1R>6-K
M.B``1O9R:&%N9'-V:7-N:6YG`$;V<FAA;F1S9W)A;G-K82!B:6QD(&D@;GET
M="!F]FYS=&5R`$;V<F5GY65N9&4@:6YS=.1L;&YI;F=A<@!3:W)I=B!U="!D
M;VMU;65N=`!0<FEV871A(&YY8VME;`!0<F]B;&5M`%!R;V)L96UB97-K<FEV
M;FEN9P!0<F]J96MT`%1E>'0`4'5B;&EK(&YY8VME;`!0=6)L:6L@;GEC:V5L
M86QG;W)I=&T`4'5B;&EK(&YY8VME;&EN9F]R;6%T:6]N`$9E;"!V:60@9V5N
M97)E<FEN9R!A=B!P=6)L:6MT+W!R:79A="!N>6-K96QP87(N`%!U97)T;R!2
M:6-O`%)E;G-A(&UE9&1E;&%N9&5N`%%A=&%R`$9RY6=A`$MV;W1A`%!U8FQI
M:R!24T$M;GEC:V5L("@E9"!B:71A<BD`16YS:VEL="!V86P`4F5G;@!4:61I
M9W0@<F5G;@!396YT(')E9VX`4F5G;G-K=7)A<@!296=N(&]C:"!S;O8`4F5G
M;B!T:6QL('-N]@!3;'5M<&WD<W-I9W0@=FES:&5T<V]R9`!&]G)HY6QL86YD
M90!,Y',`3.1S(&UE9&1E;&%N9&5N`%/D:V5R="!A='0@9'4@=FEL;"!R861E
M<F$@)7,_(%)A9&5R:6YG96X@:V%N(&EN=&4@Y6YG<F%S+@!3Y&ME<G0@871T
M(&1U('9I;&P@<F%D97)A(&%N=N1N9&%R9&%T82!F]G(@)7,_(%)A9&5R:6YG
M96X@:V%N(&EN=&4@Y6YG<F%S+@!']G(@;VT@9&EN('-E;F%S=&4@:6YM871N
M:6YG`%5P<&1A=&5R80!5<'!D871E<F$@9'EN86UI<VMA(&UE;GEE;&5M96YT
M.@!5<'!D871E<F$@<&]R=&%L=GDZ`%)E9V5X`%9I<V$@9O9R:.5L;&%N9&5N
M`$QA9&1A(&]M`$MO;6UE;G1A<F5R`$MO;2!I:.5G(&EN9F]R;6%T:6]N(&]M
M(&QE9&EG+W5P<'1A9V5N+@!&:N1R<G-E<G9R87(`55),("AH='1P.B\O=W=W
M+F5X86UP;&4N8V]M+VAO<F1E*3H`5&$@8F]R=`!482!B;W)T(&)L;V-K`%1A
M(&)O<G0@:V]L=6UN`%1A(&)O<G0@9F]R;6%T97)I;F<`5&$@8F]R="!F<N5N
M(&UI;B!K86QE;F1E<@!482!B;W)T('!A<@!2861E<F$@<W!A<F%T('-K<FEP
M="!F<N5N('-E<G9E<FYS('1E;7!O<N1R:V%T86QO9RX`5&$@8F]R=`!2861E
M<F$@9&5N;F$@;F]D(&9RY6X@9&]K=6UE;G1E=`!482!B;W)T(&%N=N1N9&%R
M90!482!B;W)T(&%N=N1N9&%R93H@)7,`4W9A<B!S:VEC:V%T+@!3=F%R82!A
M='0@8F5GY')A;B!I;G1E('-T]F1S`%-V87)A(&UE9"!I;F9O<FUA=&EO;B!O
M;2!L961I9R]U<'!T86=E;B!F]G(@:V]M;6%N9&4@=';E(&WE;F%D97(N`%-V
M87)A(&UE9"!D96X@8F5GY')D82!L961I9R]U<'!T86=E;BUI;F9O<FUA=&EO
M;F5N+@!3=F%R.B`E<P!"96?D<F%N(&MU;F1E(&EN=&4@8F5S=F%R87,N(%)E
M='5R;F5R860@9F5L:V]D.B``1&5N(&5F=&5R9G+E9V%D92!T:N1N<W1E;B!K
M=6YD92!I;G1E(&AI='1A<RX`17)F;V1R860@)R5S)R#D<B!I;G1E(&%N9VEV
M96X@:2!K;VYF:6=U<F%T:6]N96X@878@)7,N`$5R9F]D<F%D("<E<R<@Y'(@
M:6YT92!A;F=I=F5N(&D@:V]N9FEG=7)E<FEN9V5N(&%V(%9&4RX`17)F;V1R
M860@)R5S)R#D<B!I;G1E(&%N9VEV96X@:2!K;VYF:6=U<F5R:6YG96XN`$]B
M;&EG871O<FES:W1T(&;D;'0`3V)L:6=A=&]R:7-K(&1E;'1A9V%R90#%=&5R
M<W3D;&P`Q71E<G-TY&QL(&SV<V5N;W)D`,5T97)S=.1L;"!L]G-E;F]R9`#%
M<W1E<G3D;&P@<V5N87-T92!F<N5G86X`4F5S=6QT870`Q71E<G;D;F0@=&EL
M;"!I;G-TY&QL;FEN9V%R`$%N9V4@;GET="!L]G-E;F]R9`!2Z75N:6]N`,5T
M97)S=.1L;"!K;VYF:6=U<F%T:6]N`$EN<W3D;&QN:6YG87(@9O9R(%)I8V@@
M5&5X="!%9&ET;W(`1^5T;W(`2/9G97(`2/9G97)R=6)R:6L`2/9G97)VY')D
M96X`4F%?9&EN<W3D;&QN:6YG87(N+BX`4F]L;`!2=6WD;FEE;@!2;W1E<F$@
M,3@P`%)O=&5R82!VY&YS=&5R`%)O=&5R82!H]F=E<@!2861I;G-TY&QL;FEN
M9V%R`%)A9&EN<W3D;&QN:6YG87(`4F%D97(Z`$QI;FIE<@!,:6YJ97(@=FES
M87,@;65L;&%N(&%L;&$@<F%D97(@;V-H(&MO;'5M;F5R`$QI;FIE<B!V:7-A
M<R!E;F)A<G0@;65L;&%N(&MO;'5M;F5R`$QI;FIE<B!V:7-A<R!E;F)A<G0@
M;65L;&%N(')A9&5R`$OV<@!2>7-S;&%N9`!2=V%N9&$`4R]-24U%('-I9VYA
M='5R`%,O34E-12UK<GEP=&5R870@;65D9&5L86YD90!305-,+6%U=&5N=&ES
M97)I;F<@Y'(@:6YT92!T:6QL9^1N9VQI9RX`4TU3(&UE9&1E;&%N9&5N`%-1
M3"US:V%L`%-13"US96MV96YS(&;V<B!U<'!S;&%G(&%V(';D<F1E;@!34T@`
M3%E#2T%4`%-?44PM<VMA;`!,]@!386EN="!(96QE;F$`4V%I;G0@2VET=',@
M;V-H($YE=FES`%-A:6YT($QU8VEA`%-A:6YT+5!I97)R92!O8V@@36EQ=65L
M;VX`4V%I;G0@5FEN8V5N="!O8V@@1W)E;F%D:6YE<FYA`%-A;6UA(')A;2`H
M7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@;V-H(%!R:6YC:7!E
M`%-A='1E;&ET;&5V97)A;G3V<@!3875D:6%R86)I96X`4W!A<F$`4W!A<F$@
M)R5S)P!3<&%R82`E<P!3<&%R82!I;G-TY&QL;FEN9V%R`%-P87)A(&=E;F5R
M97)A9"!K;VYF:6=U<F%T:6]N('-O;2!02%`M<VMR:7!T('1I;&P@9&EN('-E
M<G9E<G,@('1E;7`M:V%T86QO9RX`4W!A<F%D92!K;VYF:6=U<F%T:6]N(&;V
M<B`E<RX`4W!A<F%D92!U<'!G<F%D97)I;F=S<V-R:7!T('1I;&PZ("5S+@!3
M<')I9&1A(.5S:W-K=7)A<@!6971E;G-K87``4_9K`%/V:VUO=&]R97(`5N1L
M:B!F:6QE<@!6Y&QJ(&5T="!D871U;0!6Y&QJ(&=R=7!P(&%T="!LY&=G82!T
M:6QL`%;D;&H@;GD@Y&=A<F4`5N1L:B!S97)V97(`5N1L:B!A;G;D;F1A<F4@
M871T(&SD9V=A('1I;&P`5N1L:B!A;&QA`%;D;&H@9&%T=6UK;VUP;VYE;G1E
M<BX`5N1L:B!E='0@;V)J96MT`%;D;&H@:6YG96X`06YG92!D92!T96-K96X@
M9'4@8F5H]G9E<B!I(')U=&]R;F$@;F5D86XN($1U(&MA;B!S961A;B!K;W!I
M97)A(&]C:"!K;&ES=')A(&EN(&1E;2!I('1E>'1A<G5T86XN`%;D;&H@879G
M<N1N<V%R92!F]G(@9&%T=6TZ`%;D;&H@9&%T=6UF;W)M870Z`%;D;&H@:61E
M;G1I=&5T(&1U('9I;&P@Y&YD<F$Z`%;D;&H@879G<N1N<V%R92!F]G(@=&ED
M.@!6Y&QJ('1I9'-F;W)M870Z`%;D;&H@=';E(&UA=&-H86YD92!FY&QT.@!6
MY&QJ(&1I='0@9N1R9W-C:&5M82X`06YG92!D:71T(&;V<G9A;&1A('-P<N5K
M.@!3:VEC:V$@<V5N87-T92!I;F9O<FUA=&EO;F5N`%-K:6-K82!P<F]B;&5M
M<F%P<&]R=`!3:VEC:V$@4TU3`%-E;F5G86P`4V5N<V]R.B``<V5P=&5M8F5R
M`%-E<F)I96X@;V-H($UO;G1E;F5G<F\`4V5R:65N=6UM97(`4V5R=F5R:6YS
M=.1L;&YI;F=A<B!F96QA:W1I9V$@96QL97(@:6YA:W1I=B!S97)V97(N`%-E
M<W-I;VYS861M:6YI<W1R871I;VX`4V5S<VEO;G,M240@:&%R(&?E='0@=70N
M`%-E<W-I;VYE<@!3Y'1T`$MO;F9I9W5R97)A(&%L=&5R;F%T:78@<V]M(&WV
M:FQI9V?V<B#E=&5R<W3D;&QN:6YG(&%V(&)O<G1G;/9M="!L]G-E;F]R9"X`
M2V]N9FEG=7)E<F$@9FKD<G)S97)V<F%R('-O;2!D=2!V:6QL(&MO;6UA(.5T
M(&9RY6X@9&EN('!O<G1A;"X`06YG92!D:71T(&;V<G9A;&1A('-P<N5K+"!T
M:61S>F]N(&-O:"!D871U;6EN<W3D;&QN:6YG87(N`%/D='0@9&ET="!I;FET
M:6%L82!A<'!L:6MA=&EO;BP@9N1R9W-C:&5M82P@<VED=7!P9&%T97)I;F<@
M;V-H(&%N9')A('9I<VYI;F=S:6YS=.1L;&YI;F=A<BX`4V5T=7``2V]N9FEG
M=7)A=&EO;G-U<'!G<F%D97)I;F=S<VMR:7!T(&9I;FYS('1I;&QGY&YG;&EG
M80!$970@9FEN;G,@9FQE<F$@;W)T97(@;65D('!A<F%M971E<FXZ`%-E>6-H
M96QL97)N80!(86YD96P`2V]R="!S=6UM97)I;F<`4VMA;&P@9V5N=N1G<W1A
M;F=E;G1E<B!D969I;F5R87,@9O9R(&1E(&9L97-T82!LY&YK87(_`%9I<V$`
M5FES82!S:VEL;&YA9&5R(&UE;&QA;B!D96X@86MT=65L;&$@;V-H(&1E;B!N
M>6QI9V5N('-K87!A9&4@:V]N9FEG=7)A=&EO;F5N+@!6:7-A('-E;F%S=&4@
M:6YL;V=G;FEN9W-T:60@=FED(&EN;&]G9VYI;F<_`%9I<V$@:6YS=.1L;&YI
M;F<@9O9R(&%T="!B96CE;&QA(&]R:6=I;F%L`%9I<V$@<&%L971T`%9I<V$@
M)W1A8F5L;&%K=&EV:71E=&5R)R!I(&UE;GEN/P!6:7-A(&UE;GD@9O9R("5S
M('1I;&P@=N1N<W1E<C\`5&%B96QL8V5L;&EN<W3D;&QN:6YG87(`5&%B96QL
M:6YS=.1L;&YI;F=A<@!486)E;&QI;G-TY&QL;FEN9V%R`%9I<V$@9&EA;&]G
M<G5T82!F]G(@8FEL9&5G96YS:V%P97(`5FES82!U<'!L861D;FEN9P!3:W5R
M87(`5&ED:6=A('-K=7)A<@!396YA('-K=7)A<@!3:W5R87(@:2!NY')H971E
M;@!&]G)M:6YS:V$`2W)Y;7`@96QL97(@9FQY='1A(&)O<G0@;N1R;&EG9V%N
M9&4@8FQO8VL@9O9R<W0`4VEE<G)A($QE;VYE`%)E9VES=')E<F$`4VEG;F%T
M=7(`4VEG;F%T=7)A;&=O<FET;0!3:6UP;&5X`%-I;F=A<&]R90!3=&]R;&5K
M`$%V8G)Y="!U;F1E<FCE;&P`4VQO=F%K:65N`%-L;W9E;FEE;@!3;O8`4V[V
M<VMU<@!3;O9S:W5R87(`5&ED:6=A('-N]G-K=7)A<@!396YA('-N]G-K=7)A
M<@!3;O9D:G5P.B``36]T<W9A<F%N9&4@<V[V(&D@=F%T=&5N.B``4V%L;VUO
M;O9A<FYA`%-O;6%L:6$`4^5N9V5R(&]C:"!D:6MT97(`4V]R=&5R:6YG<VEO
M<F1N:6YG<W9A;`!KY&QL861R97-S`%-Y9&%F<FEK80!3]F1R82!'96]R9VEA
M(&]C:"!3>7-S86YD=VEC:/9A<FYA`%/D9')A(&AE;6ES9N1R96X`571R>6UM
M92!M96QL86X@:6YT:6QL:6=G86YD92!C96QL97(`571R>6UM92!M96QL86X@
M:6YN96CE;&P@;V-H(&MA;G1E;B!I(&-E;&QE;@!-96QL86YR=6T`365L;&%N
M<G5M`$UE;&QA;G)U;2!O8V@@=71JY&UN:6YG`%-P86YI96X`4W!A;0!);FUA
M=&YI;F<@878@<W!E8VEE;&QA('1E8VME;@!$96QA(&-E;&P`1&5L82!K;VQU
M;6X`1&5L82!R860`4W!O<G1E<@!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4
M<F5K`%-T87)T`%-T87)TY7(`4W1A="!E;&QE<B!R96=I;VX`4W1A='5S`$QA
M9W)I;F=S9F]R;6%T`$=A='5A9')E<W,`1V5N;VUS=')U:V5N`%-T<N1N9VQI
M<W1A`%1A(&)O<G0@9&]MY&X@9G+E;B!A9')E<W-E;@!3=&EL(%M#4U-=`%/V
M`$MA;B!I;G1E(&AI='1A('5N9&5R:V%T86QO9R`G)7,G+@#$<F5N9&4`4VMI
M8VMA`$1I;B!B96?D<F%N(&%T="!LY&=G82!T:6QL("(E<R(@=&EL;"!S>7-T
M96UE="!H87(@<VMI8VMA=',N($1U(&MA;B!I;G1E(&QO9V=A(&EN(&EN;F%N
M(&1I;B!B96?D<F%N(&AA<B!A8V-E<'1E<F%T<RX`3F5D<^1N:W0`3'EC:V%T
M`"<E<R<@;&%D97,@=&EL;"!I('-Y<W1E;65T+@!2861E<F%D92!I;F9O<FUA
M=&EO;B!O;2!A;G;D;F1A<F4@)R5S)RX`)R5S)R!R861E<F%D97,N`"<E<R<@
M=&]G<R!B;W)T(&9RY6X@<WES=&5M970N`$MO;F9I9W5R871I;VYE;B!H87(@
MY71E<G-TY&QL=',N($QA9&1A(&]M('-I9&%N(&;V<B!A='0@<V4@9O9RY&YD
M<FEN9V%R+@!3<&%R861E(&)A8VMU<&MO;F9I9W5R871I;VXN`%-P87)A9&4@
M8F%C:W5P:V]N9FEG=7)A=&EO;B`E<RX`)R5S)R!U<'!D871E<F%D97,N`%-K
M<F5V("5S`%-U9&%N`%-A;6UA;G-TY&QL;FEN9P!3;VQU<'!GY6YG`%-O;&YE
M9&?E;F<`4V]L:6=T`%-O;'5P<&?E;F<`4V]L=7!P9^5N9R]N961GY6YG`%-O
M;'5P<&?E;F<Z(`!3;VQN961GY6YG`%-O;&YE9&?E;F<Z(`!5<'!H]FID`%-U
M<'!O<G0`4W5R:6YA;64`169T97)N86UN`%-V86QB87)D(&]C:"!*86X@36%Y
M96X`4W=A>FEL86YD`%-V97)I9V4`4V-H=V5I>@!3>6MR;VYI<V5R:6YG<VQO
M9V<@<F%D97)A9`!3>6YC34P`4WEN=&%X9F5L(&D@<_9K:W)I=&5R:6$`4WER
M:65N`,5S:W-K=7(`Q7-K<VMU<F%R(&]C:"!B;.5S:6=T`,5S:W-K=7)A<@!4
M:61I9V$@Y7-K<VMU<F%R`%135BUF:6P`5&%B96QL`%1A8F5L;&EN<W3D;&QN
M:6YG87(`5&%B96QL=7!P<^1T=&YI;F<`5&%B96QL:6YS=.1L;&YI;F=A<@!4
M86EW86X`5&%I=V%N`%1A:FEK:7-T86X`5&%N>F%N:6$`3>5L.@!5<'!G:69T
M97(`5&5A;`!496QE9F]N;G5M;65R`$CV9W-T82!T96UP97)A='5R('-E;F%S
M=&4@=&EM;65N.B``5&5M<&5R871U<@!496UP97)A='5R.B``5&5M<&5R871U
M<CQB<B`O/B@E<TUA>"5S+R5S36EN)7,I("9D96<[)7,`2V%N(&EN=&4@:&ET
M=&$@;6%L;"`E<RX`06YVY&YD87)A9&UI;FES=')A=&EO;@!';V1KY&YN(&)E
M9^1R86X@<')E;&EM:6[D<G0`4')E;&EM:6[D<G0@86-C97!T97)A=`!497AT
M`$5N8F%R="!T97AT`%1E>'1J=7-T97)I;F<`5&5X='1O<`!4;P!4:&%I("A4
M25,M-C(P*0!4:&%I;&%N9`!486-K(&;V<B!A='0@9'4@86YVY&YD97(@<WES
M=&5M970N`$SD;FME;B`E<R!T:6QL("5S(&AA<B!R861E<F%T<RX`1E10+71I
M;&SD9V=E="#D<B!I;G1E('1I;&QGY&YG;&EG="X`2&ES=&]R:6MS>7-T96UE
M="#D<B!A=F%K=&EV97)A="X`2&]R9&4O2V]L86(M:6YT96=R871I;VYS9W+D
M;G-S;FET=&5T('-T]F1E<B!I;G1E("(E<R(`24U34"UL;V=G96X@:W5N9&4@
M:6YT92!I;FET:65R87,N`$ML87-S96X@36%I;G1E;F%N8V4Z.B!K=6YD92!I
M;G1E(&QA9&1A<P!);G-TY&QL;FEN9W-F]FYS=')E="!H87(@<W3D;F=T<RX@
M079S;'5T87(N`$%D;6EN:7-T<F%T]G)E;B!MY7-T92!K;VYF:6=U<F5R82!E
M;B!P97)M86YE;G0@0F5H]G)I9VAE=',M:V]P<&QI;F<@;VT@9'4@=FEL;"!A
M;G;D;F1A($)E:/9R:6=H971E<BX`16YB87)T(&YE9')E('-I9&%N`$MA;&5N
M9&5R:6YF;W)M871I;VYE;B#D<B!F96QA:W1I9P!+;VYT86MT96YS($E$(&%N
M9V%V<R!I;G1E(&5L;&5R(&MU;F1E(&EN=&4@:&ET=&%S(&D@9&%T86)A<V5N
M+@!+;VYT86MT96X@;&%D97,@=&EL;"!I(&%D<F5S<V)O:V5N+@!$96X@;/9S
M9VIO<F1A(%!'4"US:6=N871U<F5N(&MRY'9S(&;V<B!A='0@=F5R:69I97)A
M(&1E="!S:6=N97)A9&4@;65D9&5L86YD970N`$1I<W1R:6)U=&EO;G-L:7-T
M86YS($E$(&%N9V%V<R!I;G1E(&5L;&5R(&MU;F1E(&EN=&4@:&ET=&%S(&D@
M9&%T86)A<V5N+@!$:7-T<FEB=71I;VYS;&ES=&%N(&AA<B!I;G1E(&%N9VEV
M:71S+@!+<GEP=&5R:6YG<V9U;FMT:6]N97)N82!K<N1V97(@96X@<^1K97(@
M=V5B9O9R8FEN9&5L<V4@*$A45%!3*2X`2.1N9&5L<V5N(&QA9&5S('1I;&P@
M:2!K86QE;F1E<FXN`$9I;&5N("5S('-K86QL(&EN;F5HY6QL82!E;B!I;G-T
MY&QL;FEN9R!F]G(@)7,N`$9I;&5N("5S('-K86QL(&EN;F5HY6QL82!I;G-T
MY&QL;FEN9V%R(&;V<B`E<RX`1FEL96X@:V%N(&EN=&4@:V]P:65R87,@=&EL
M;"!S:6<@<VKD;'8N`$9I;&5N(&MA;B!I;G1E(&MO<&EE<F%S('1I;&P@<VEG
M('-JY&QV+@!&:6QE;B!I;FYE:/9L;"!I;F=E;B!I;F9O<FUA=&EO;BX`2'5V
M=61FY&QT(&;V<B!D971T82!M961D96QA;F1E+W)F8S@R,FUE9&1E;&%N9&4@
M9O9L:F5R`$ED96YT:71E=&5N("<E<R<@<F%D97)A9&5S+@!"87)A(';D;G-T
M97(@<VED80!,Y&YK96X@:&%R('1A9VET<R!B;W)T`%/V:W;D9V5N('1I;&P@
M1VYU4$<M<')O9W)A;6UE="!MY7-T92!V87)A(&%N9VEV96X@=&EL;"!K;&%S
M<V5N($-R>7!T7W!G<#HZ+@!-961D96QA;F1E="!S:VEC:V%T("5S('1I;&P@
M)7,@;65D(.1R96YD92`B)7,B(&AA<B!V:7-A=',N"D1E='1A(.1R(&EN9V5N
M(&=A<F%N=&D@9O9R(&%T="!M961D96QA;F1E="!H87(@;.1S=',N`$YA;6YE
M="!S;VT@<VMA;&P@86YVY&YD87,@9O9R(&%T="!LY&YK82!T:6QL('-K87!A
M+7-I9&%N`$%N=&%L(&;D;'0@;>5S=&4@=F%R82!E='0@;G5M97)I<VMT(';D
M<F1E+@!-;V1U;&5N(&]P96YS<VP@:W+D=G,@878@:VQA<W-E;B!(;W)D95]#
M<GEP=%]S;6EM93HZ+@!);G-TY&QL;FEN9V5N("(E<R(@:W5N9&4@:6YT92!S
M<&%R87,@<.4@9W)U;F0@878@871T(&1A=&%MY&YG9&5N(/9V97)S:W)I=F5R
M(&1E;B!M87AI;6%L="!T:6QLY71N80!0<F]G<F%M;65T('-O;2!A;G;D;F1S
M(&;V<B!A='0@=FES82!D96X@:.1R(&UE9&1E;&%N9&5T>7!E;B`H)7,I('-A
M:VYA<R!PY2!S>7-T96UE="X`5&5C:VYE="!F]G(@8VET97)I;F<@;>5S=&4@
M=F%R82!E='0@=&5C:V5N+@!"87)A(&CV9V5R(&]C:"!VY&YS=&5R('-I9&]R
M`$)A<F$@:/9G97(@<VED80!397!A<F%T;W)N(&WE<W1E('9A<F$@971T('1E
M8VME;BX`4V5R=F5R("<E<R<@<F%D97)A9&5S+@!397)V97(@)R5S)R!S<&%R
M861E<RX`4')E;G5M97)A=&EO;G-B96?D<F%N(&;V<B`E<R!H87(@=&%G:71S
M(&)O<G0N`$%N9VEV96X@<F%D("@E9"D@9FEN;G,@:6YT92X`06YG:79E;B!R
M860@97AI<W1E<F%R(&EN=&4N`%5P<&=I9G1E;B!H87(@;&%G=',@=&EL;"!I
M(&1I;B!U<'!G:69T<VQI<W1A+@!496UP;W+D<B!F:6P@)R5S)R!F:6YN<R!I
M;G1E+@!497AT96X@9'4@;6%T870@:6X@<W3D;6UE<B!I;G1E(/9V97)E;G,@
M;65D('1E>'1E;B!PY2!S:^1R;65N`$)A<F$@=&]P<"!O8V@@8F]T=&5N('-I
M9&$`0F%R82!T;W!P<VED80!5<'!L861D870@9&%T82!F]G)S=F%N;B!S961A
M;B!F]G)E9^5E;F1E('-T96<N`$1E;B!U<'!L861D861E(&9I;&5N(&MU;F1E
M(&EN=&4@<W!A<F%S+@!,961I9R]U<'!T86=E;BUI;F9O<FUA=&EO;B!F]G(@
M86YVY&YD87)E;B!H87(@<W!A<F%T<RX`5V5A=&AE<BYC;VTM8FQO8VME="#D
M<B!I;G1E('1I;&QGY&YG;&EG="X`5&5M86MA=&%L;V<@)R5S)R!F:6YN<R!I
M;G1E+@!);F=A(&EN<W3D;&QN:6YG87(@=&EL;&?D;F=L:6=A+@!$970@9FEN
M;G,@:6YG82!A;'1E<FYA=&EV82!D96QA<B!S;VT@:V%N('9I<V%S(&EN;&EN
M92X`1O9R(&WE;F=A('1E8VME;B!I(&;D;'1E="X@1'4@:&%R(&%N9V5T="`E
M<R!T96-K96X[(&UA>&EM86QT(&%N=&%L('1E8VME;B#D<B`E<RX`4')O8FQE
M;2!M960@871T(&SD9V=A('1I;&P@)R5S)R!T:6QL('-Y<W1E;65T.B`E<P!0
M<F]B;&5M(&UE9"!A='0@<F5N<V$@:6YF;W)M871I;VX@;VT@86YVY&YD87)E
M("<E<R<@9G+E;B!S>7-T96UE=#H@`%!R;V)L96T@;65D(&%T="!T82!B;W)T
M("<E<R<@9G+E;B!S>7-T96UE=#H@`%!R;V)L96T@=FED('5P<&1A=&5R:6YG
M(&%V("<E<R<Z("5S`%!R;V)L96T@=FED('5P<&QA9&1N:6YG(&%V(&9I;&5N
M+B!);F=A("5S(&QA9&1A9&5S('5P<"X`1&5T('5P<'-T;V0@<')O8FQE;2!V
M:60@=7!P;&%D9&YI;F<@878@9FEL96XZ("5S(.1R('-T]G)R92#D;B!M87AI
M;6%L="!T:6QLY71E;B!S=&]R;&5K("@E9"!B>71E<RDN`$1E="!U<'!S=&]D
M('!R;V)L96T@=FED('5P<&QA9&1N:6YG(&%V(&9I;&5N.B`E<R!L861D861E
M<R!E;F)A<G0@=7!P(&1E;'9I<RX`1&5T('5P<'-T;V0@971T(&9E;"!V:60@
M=FES;FEN9R!A=B!M961D96QA;F1E9&5L96XN`$9E;"!V:60@:6UP;W)T(&%V
M(&MO;G1A:W1D871A+@!&96P@=FED(&EM<&]R="!A=B!HY&YD96QS96XZ("5S
M+@!&96P@=FED(&EM<&]R="!A=B!I0V%L96YD87(@9&%T82X`1F5L('9I9"!I
M;7!O<G0@878@=7!P9VEF=&5N.B`E<RX`1F5L('9I9"!I;7!O<G0@878@:6YF
M;W)M871I;VX@;VT@;&5D:6<O=7!P=&%G96XZ("5S+@!%='0@9F5L('#E='+D
M9F9A9&5S(&D@9F]R;75LY')E="X@2V]N=')O;&QE<F$@871T(&1U(&EN=&4@
M9VSV;70@9GEL;&$@:2!E='0@;V)L:6=A=&]R:7-K="!FY&QT+@!$970@9VEC
M:R!I;G1E(&%T="!U=&;V<F$@9&5N(&)E9^1R9&$@861R97-S8F]K<V9U;FMT
M:6]N96XN(%9A<B!G;V0@9O9R<_9K('-E;F%R92X`1F5L('9I9"!U<'!D871E
M<FEN9R!A=B!K;VYT86MT=7!P9VEF=&5R+B!&]G)S]FL@:6=E;B!S96YA<F4N
M`$9E;"!V:60@=7!P9&%T97)I;F<@878@9&ES=')I8G5T:6]N<VQI<W1A;BX@
M1O9R<_9K(&EG96X@<V5N87)E+@!$:6X@24U!4"US97)V97(@<W3V9&5R(&EN
M=&4@9&5L861E(&UA<'!A<BX`1&5N;F$@:&%N9&QI;F<@<W3V9',@:6YT92X`
M1&5N;F$@9G5N:W1I;VX@Y'(@:6YT92!I;7!L96UE;G1E<F%D(.1N+@!&:6QE
M;B!V97)K87(@:6YT92!V87)A(&5T="!G:6QT:6=T(%)!4BUA<FMI=BX`1FEL
M96X@=F5R:V%R(&EN=&4@=F%R82!E='0@9VEL=&EG="!:25`M87)K:78N`$9E
M;&%K=&EG="!K;W)T;G5M;65R+@!$96YN82!D<FEV<G5T:6X@9_9R(&1E="!M
M]FIL:6=T(&%T="!S:VEC:V$@;65D9&5L86YD96X@=FEA($-L:6-K871E;&PM
M8G)Y9V=A;B`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G96YO;2!A='0@86YV
MY&YD82!(5%10($%023IT+@!$96YN82!D<FEV<G5T:6X@9_9R(&1E="!M]FIL
M:6=T(&%T="!S:VEC:V$@;65D9&5L86YD96X@=FEA(%=)3BUB<GEG9V%N("AH
M='1P.B\O=VEN<&QC+F-O;2D@9V5N;VT@871T(&%N=N1N9&$@2%144"!!4$DZ
M=`!$96YN82!D<FEV<G5T:6X@9_9R(&1E="!M]FIL:6=T(&%T="!S:VEC:V$@
M;65D9&5L86YD96X@=FEA('-M<S)E;6%I;"UB<GEG9V%N("AH='1P.B\O<VUS
M,F5M86EL+F-O;2D@9V5N;VT@871T(&%N=N1N9&$@2%144"!!4$DZ=`!$96YN
M82!D<FEV<G5T:6X@9_9R(&1E="!M]FIL:6=T(&%T="!S:VEC:V$@;65D9&5L
M86YD96X@=FEA(%--5%`@9V5N;VT@5F]D869O;F4@271A;&EE;BUB<GEG9V%N
M("AE;F)A<G0@=&EL;"!6;V1A9F]N;G5M;65R*2X@1')I=G)U=&EN96X@:W+D
M=F5R(&5T="!E+7!O<W1K;VYT;R!H;W,@5F]D869O;F4@271A;&EE;B`H:'1T
M<#HO+W=W=RXQ.3`N:70I+@!&Y&QT970@;>5S=&4@=F%R82!I9GEL;'0N`$;D
M;'1E="!FY7(@96YB87)T(&EN;F5HY6QL82!H96QT86PN`$;D;'1E="!FY7(@
M96YB87)T(&EN;F5HY6QL82!S:69F<F]R(&]C:"!K;VQO;BX`1N1L=&5T(&;E
M<B!E;F)A<G0@:6YN96CE;&QA(&]K=&%L82!T86PN`$;D;'1E="!S:V%L;"!V
M87)A(&5N(&MO;6UA+2!E;&QE<B!M96QL86YS;&%G<W-E<&%R87)A9"!L:7-T
M82!M960@:&5L=&%L`$;D;'1E="!MY7-T92!V87)A(&5T="!G;V1KY&YT('1A
M;"X`1&5T=&$@9N1L="!MY7-T92!I;FYE:.5L;&$@96X@4D="+6;D<F=K;V0@
M:2!H97AA9&5C:6UA;'0@9F]R;6%T+"!T(&5X("<C,3(S-&%F)RX`1&5T=&$@
M9F]R;75LY'(@:&%R(')E9&%N(&)E87)B971A=',N`$1E="!HY'(@Y'(@)7,N
M`$UE9&1E;&%N9&5T('-K<F5V<R!I(&5N(&%N;F%N('1E8VME;G5P<'/D='1N
M:6YG("@E<RD@Y&X@9&EN(&5G96XN`$1E="!HY'(@;G5M<F5T(&WE<W1E('9A
M<F$@;6EN<W0@971T+@!397)V97)N(&MA;B!I;G1E('!A8VMA('5P<"!Z:7`@
M;V-H(&=Z:7`@9FEL97(N`%-Y<W1E;65T(.1R(&;V<B!T:6QL9N1L;&5T(&%V
M86MT:79E<F%T+@!$970@:.1R(';D<F1E="!MY7-T92!V87)A(&YU;65R:7-K
M="X`1&5T=&$@9O9N<W1E<B!MY7-T92!A;G)O<&%S(&9RY6X@971T(&MO;F9I
M9W5R871I;VYS9O9N<W1E<@#%<VMA`,1R96YD96X`5&ED`%1I9'-R961O=FES
M;FEN9P!4:61S9F]R;6%T`%1I9'-V86P`UG-T=&EM;W(`4G5B<FEK`%)U8G)I
M:R`H=&]O;'1I<"DZ`%1I;&P`1O9R(&%T="!M87)K97)A(&9L97)A('9A;"P@
M:.5L;"!N960@0W1R;"`H4$,I(&5L;&5R($-O;6UA;F0@*$UA8RD@=&%N9V5N
M=&5N(&[D<B!D=2!K;&EC:V%R+@!)9&%G`%9I<V$@2%1-3"UKY&QL80!4;V=O
M`%1O:V5L874`26UO<F=O;@!4;VYG80!4;W``5&]P(&9R86UE("A?=&]P*0#6
M=F5R<^1T=&YI;F=A<@!4<FEN:61A9"!O8V@@5&]B86=O`%-A;G0@96QL97(@
M9F%L<VMT`%1I`%1U;FES:65N`%1U<FMI970`5'5R:VES:R`H25-/+3@X-3DM
M.2D`5'5R:VUE;FES=&%N`%1U<FMS+2!O8V@@0V%I8V]S]F%R;F$`5'5V86QU
M`$%N9V4@9&ET="!V86PZ(`!55BUI;F1E>#H@`%523`!54DP@9O9R(&1I='0@
M;&5V97)A;G-R87!P;W)T97)I;F=S<VMR:7!T`%523#H`56=A;F1A`%5K<F%I
M;F$`2V%N(&EN=&4@;.1S82!61E,M;6%P<"X`1&5T(&=I8VL@:6YT92!A='0@
M;.1G9V$@=&EL;"!U=/9K860@86YVY&YD87)I;F9O<FUA=&EO;B!V:60@<F5G
M:7-T97)I;F<N`$MA;B!I;G1E(.1N9')A(&)E:/9R:6=H970@9O9R(%9&4RUF
M:6P@)7,N`$MA;B!I;G1E(.1N9')A(&)E:/9R:6=H970@9O9R(%9&4RUF:6P@
M)7,O)7,N`$MA;B!I;G1E(.1N9')A('1I;&P@)7,N`$MA;B!I;G1E(&MO;G1R
M;VQL97)A(&9I;'-T;W)L96L@)7,O)7,`2V%N(&EN=&4@:V]N=')O;&QE<F$@
M9FEL<W1O<FQE:R!PY2`E<RX`2V%N(&EN=&4@:V]N=')O;&QE<F$@9FEL<W1O
M<FQE:R!PY2`E<R\E<RX`2V%N(&EN=&4@:V]N=&%K=&$@4U%,+7-E<G9E<BX`
M2V%N(&EN=&4@:V]N=&%K=&$@=FEA(%-33"X`2V%N(&EN=&4@:V]P:65R82!6
M1E,M9FEL+@!+86X@:6YT92!S:V%P82!61E,M;6%P<"`E<RX`2V%N(&EN=&4@
M<VMA<&$@5D93+6UA<'`N`$MA;B!I;G1E('-K87!A(%9&4RUF:6PN`$MA;B!I
M;G1E('-K87!A(%9&4RUM87!P("<E<R<N`$MA;B!I;G1E('-K87!A('1O;2!6
M1E,M9FEL+@!+86X@:6YT92!P86-K82!U<'`@9&%T82X`2V%N(&EN=&4@<F%D
M97)A("5S+"!M87!P96X@Y'(@:6YT92!T;VTN`$MA;B!I;G1E(')A9&5R82`G
M)7,G.B`E<P!+86X@:6YT92!R861E<F$@)7,L(&UA<'!E;B#D<B!I;G1E('1O
M;2X`2V%N(&EN=&4@<F%D97)A(%9&4RUM87!P(')E:W5R<VEV="X`2V%N(&EN
M=&4@<F%D97)A(%9&4RUM87!P+@!+86X@:6YT92!R861E<F$@5D93+6UA<'`Z
M("5S+@!+86X@:6YT92!R861E<F$@5D93+69I;"`E<RX`2V%N(&EN=&4@<F%D
M97)A(%9&4RUF:6PN`$MA;B!I;G1E(')A9&5R82!61E,M;6%P<"`G)7,G+@!+
M86X@:6YT92!R861E<F$@5D93(')E:W5R<VEV=#H@)7,N`$MA;B!I;G1E(&%V
M9_9R82!A:W1U96QL(&UA<'`N`$MA;B!I;G1E(&5X=')A:&5R82!#97)T:69I
M:V%T<V1E=&%L:F5R`$MA;B!I;G1E(&QA9&1A(&1E9FEN:71I;VYE;B!A=B`E
M<RX`2V%N(&EN=&4@9FQY='1A(%9&4RUF:6PN`$MA;B!I;G1E(/9P<&YA(%9&
M4RUF:6P@)7,N`$MA;B!I;G1E(/9P<&YA(%9&4RUF:6P@9O9R('-K<FEV;FEN
M9RX`2V%N(&EN=&4@]G!P;F$@5D93+69I;"X`2V%N(&EN=&4@]G!P;F$@:V]M
M<')I;65R870@87)K:78N`$MA;B!I;G1E(&SD<V$@5D93+69I;"`H9FEL97-I
M>F4H*2!M:7-S;'EC:V%D97,I+@!+86X@:6YT92!LY'-A(%9&4RUF:6P@*&=E
M=$9I;&53:7IE*"D@;6ES<VQY8VMA9&5S*2X`2V%N(&EN=&4@;.1S82!F:6PZ
M(`!+86X@:6YT92!LY'-A(&MA=&%L;V=E;B!F]G(@)W9F<W)O;W0G+@!+86X@
M:6YT92!B>71A(&YA;6X@<.4@)7,@=&EL;"`E<SH@9&5S=&EN871I;VYS;6%P
M<"!F:6YN<R!R961A;@!+86X@:6YT92!B>71A(&YA;6X@<.4@5D93+6UA<'`N
M`$MA;B!I;G1E(&)Y=&$@;F%M;B!PY2!61E,M;6%P<#H@)7,N`$MA;B!I;G1E
M(&)Y=&$@;F%M;B!PY2!61E,M9FEL("5S+@!+86X@:6YT92!B>71A(&YA;6X@
M<.4@5D93+69I;"`E<R\E<RX`2V%N(&EN=&4@8GET82!N86UN('#E(%9&4RUF
M:6PN`$MA;B!I;G1E(&OV<F$@)VUK:7-O9G,G+@!+86X@:6YT92#V=F5R<^1T
M=&$@5V]R9&1O:W5M96YT970`2V%N(&EN=&4@<VMR:79A('1I;&P@5D93+69I
M;"`E<RX`2V%N(&EN=&4@<VMR:79A('1I;&P@5D93+69I;"`H8V]P>2@I(&UI
M<W-L>6-K861E<RDN`$MA;B!I;G1E('-K<FEV82!D871A('1I;&P@5D93+69I
M;"X`2V%N(&EN=&4@<VMR:79A('1I;&P@5D93+69I;"P@:W9O=&$@<VMU;&QE
M(/9V97)S:W)I9&%S+@!5;F1E<G-T<G5K96X`Q6YG<F$@Y&YD<FEN9V%R`,5N
M9W)A<B!D:6X@<V5N87-T92#E=&?D<F0`3W;D;G1A="!S=F%R(&9RY6X@<V5R
M=F5R('#E(&;V<F)I;F1E;'-E.B``3W;D;G1A="!S=F%R(&9RY6X@<V5R=F5R
M('1I;&PZ(`!%:B!K871E9V]R:7-E<F%D`$EC:V4@:&%N=&5R860@:V]M<&]N
M96YT(&%V('1Y<#H@)7,`56YI8V]D92`H551&+3@I`$;V<F5N861E($%R86)E
M;6ER871E;@!3=&]R8G)I=&%N;FEE;@!&]G)E;G1A(%-T871E<FYA`$%M97)I
M:V%N<VMA(%-T:6QL86AA=G/V87)N80!%;FAE=&5R`$]KY&YD`$]KY&YT(&=R
MY&YS<VYI='1S;65D9&5L86YD96ED("AA<&EM<V=I9"DN`$]KY&YT(&ML:65N
M=&UE9&1E;&%N9&5I9"`H8VQI;7-G:60I+@!/:^1N9"!O<G0@<W!E8VEF:6-E
M<F%D+@!/:^1N="!A;G;D;F1A<FYA;6X@96QL97(@;/9S96YO<F0N`%1A(&)O
M<G0@;.1N:V5N(&9RY6X@;G5V<F%N9&4@96QE;65N=`!.86UN;/9S`$EC:V4M
M<')I=FEL:6=E<F%D92!S:W)I<'0@:V%N(&EN=&4@:V]M;6$@Y70@2VQI<'`@
M=70O2V]P:65R82]+;&ES=')A+69U;FMT:6]N97)N82!A=B!SY&ME<FAE='-S
M:^1L+B!+;&EC:V$@3TL@9O9R(&%T="!S92!E;B!T96MN:7-K(&)E<VMR:79N
M:6YG(&9RY6X@;6]Z:6QL82YO<F<@;VT@:'5R(&1U(&MA;B!T:6QLY71A(&%T
M="!S:W)I<'0@:V]M;65R(.5T('5R:VQI<'`N`%1A(&)O<G0@9N1R9P!4:6QL
MY&=G970@<W3V9',@:6YT90!5<'!D871E<F$`57!P9&%T97)A("5S`%5P<&1A
M=&5R82!S=&%T=7,@<.4@<W9A<F%N9&4`57!P9&%T97)A(&%N=N1N9&%R90!5
M<'!D871E<F%D92`G)7,G+@!5<'!D871E<FEN9W-S8W)I<'0@<F%D97)A="X`
M3&%D9&$@=7!P`$QA9&1A9&4@=7!P(&%L;&$@:V]N9FEG=7)A=&EO;G-F:6QE
M<B!T:6QL('-E<G9E<FXN`%9E<G-A;&5R`%)O;65R<VMA('-I9F9R;W(`57)U
M9W5A>0!!;G;D;F0@86MT=65L;#H@)7,`06YVY&YD(%-33`!!;G;D;F0@;VT@
M;F%M;B]L]G-E;F]R9"#D<B!A;FYO<FQU;F1A(&;V<B!)35-0+7-E<G9E<BX`
M06YVY&YD87)E`$%N=N1N9&%R92`E<R#D<B!I;G1E(&)E:/9R:6<@9O9R("5S
M+@!!;G;D;F1A<F%D;6EN:7-T<F%T:6]N`$%N=N1N9&%R:6YS=.1L;&YI;F=A
M<@!!;G;D;F1A<G)E9VES=')E<FEN9P!!;G;D;F1A<G)E9VES=')E<FEN9R!H
M87(@879A:W1I=F5R871S+@!!;G;D;F1A<FMO;G1O="!H:71T861E<R!I;G1E
M`$%N=N1N9&%R;F%M;@!!;G;D;F1A<FYA;6X@)7,@9FEN;G,@<F5D86XN`$%N
M=N1N9&%R;F%M;CH`06YVY&YD87)N86UN.B``06YVY&YD87)E(&D@<WES=&5M
M970Z`%5Z8F5K:7-T86X`5D93+6UA<'`@97AI<W1E<F%R(&EN=&4N`%-E;65S
M=&5R`$=I;'1I9V$@<&QA='-E<B!S;VT@:&ET=&%D97,@:6YK;'5D97)A<CH@
M`$=I;'1I9VAE=`!-:6YU=&5R(&9RY6X@;G4`5N1R9&5T(/9V97)S=&EG97(@
M9&5T(&CV9W-T82!T:6QLY71N82`H)7,I`%;D<F1E;@!6Y')D96X@871T(';D
M;&IA(&9RY6X`5F%N=71A=0!687)I86)E;`!696YE>G5E;&$`5F5R:69I97)I
M;F<@;6ES<VQY8VMA9&5S("T@;65D9&5L86YD970@:V%N(&AA(&UA;FEP=6QE
M<F%T<RX`5F5R<VEO;@!697)S:6]N:&%N=&5R:6YG`%9E<G1I:V%L(&IU<W1E
M<FEN9P!697)T:6MA;"!U=&9Y;&QN860`5F5R=&EK86PZ`%;D;&1I9W0@:/9G
M`%9I971N86T`5FEE=&YA;65S:7-K("A625-#24DI`%9I<V$@)7,`5FES82!E
M;B!E>'1E<FX@=V5B8G-I9&$`5FES82!S;VT@)7,`5FES82!HY&YD96QS90!6
M:7-A('5P<&=I9G0`2G5N9V9R=?9A<FYA+"!"<FET=&ES:V$`2G5N9V9R=?9A
M<FYA+"!!;65R:6MA;G-K80!3:6MT`%-I:W0Z`%9O9&%F;VYE($ET86QI96X@
M=FEA(%--5%``5D%23@!605).24Y'(2$A(%)!1$5202!32U))4%1%5"!-04Y5
M14Q,5"!&4L5.("5S+@!724X@=FEA($A45%``5V%L;&ES(&]C:"!&=71U;F$`
M5F%R;FEN9P!/;@!6Y&1E<G!R;V=N;W,`5N1D97)D871A(&9RY6X`=V5A=&AE
M<BYC;VT`5V5B8@!796)B<&QA=',`5V5B8G!L871S96X@+2!3;V)E<@!796)B
M<&QA='-E;B`M(%-O8F5R($Y9`%9E8VMO=FES`%;D;&MO;6UE;@!6Y&QK;VUM
M96X@=&EL;"`E<P!6Y&QK;VUM96XL("5S`%;D<W1E<FSD;F1S:R`H25-/+3@X
M-3DM,2D`5N1S=&5R;.1N9'-K("A)4T\M.#@U.2TQ-2D`5N1S=')A(%-A:&%R
M80!6:6QK96X@87!P;&EK871I;VX@<VMA;&P@)7,@=FES82!E9G1E<B!I;FQO
M9V=N:6YG/P!6:6QK96X@Y'(@879G<N1N<VYI;F=S=&5C:VYE=#\`5FEL:V5T
M(.1R('1E8VMN970@9O9R(&-I=&5R860@=&5X=#\`5VAE<F5I<R!!=7-T<F%L
M:65N:V%R=&$`5FEL:V$@9F%S97(`5FEL:V$@<&QU9VEN('-K86QL(&%K=&EV
M97)A<R!F]G(@4FEC:"!497AT(&5D:71O<FXN`$)R961D`$)R961D(&D@0U-3
M+75N:71S`$)R961D('#E(&UE;GEN(&;V<B`G)7,G('1I;&P@=N1N<W1E<B`H
M9^1L;&5R(&9RY6X@;N1S=&$@:6YL;V=G;FEN9P!486)E;&QB<F5D9`!"<F5D
M9&5N:&5T`$)R961D.@!7:6MI`%9I;F0`5&ED:6<@=FEN9`!6:6YD:&%S=&EG
M:&5T(&D@:VYO<`!6:6YD.@!6:6YD.B``5FES9&]M`-9N<VME;&ES=&$`07)B
M971E`$%D<F5S<RP@87)B971E`%1E;&5F;VXL(&%R8F5T90!&96P@86YT86P@
M9N1L="!PY2!R860@)60N($;V<G;D;G1A9&4@)60L(&AI='1A9&4@)60N`$9E
M;"!A;G1A;"!FY&QT+B!&]G)VY&YT861E("5D+"!H:71T861E("5D+@!&96P@
M<&]S:71I;VX@)60@=FED(&SD<VYI;F<@878@5D93+69I;"X`6"U2968`6#4P
M.58S(%5T]FMA9"!N>6-K96QA;G;D;F1N:6YG`%@U,#E6,RUT:6QLY&=G`%E9
M`%E965D`66%H;V\A(&UA<`#%<FQI9P!996UE;@!*80!*82P@:F%G('-A;71Y
M8VME<@!$=2!H87(@86MT:79E<F%T('1E>'1LY&=E+B!!;G;D;F0@6SP^72!F
M]G(@871T(.5T97)GY2!T:6QL(%=94TE764<N`$1U(&AA<B!I;G1E(&)E:/9R
M:6=H970@<VMA<&$@9FQE<B#D;B`E9"!B;&]C:RX`1'4@Y'(@:6YT92!A=71E
M;G1I<V5R860N`$1U(&MA;B!I;G1E(&%N=N1N9&$@)UPG(&D@9&ET="!N86UN
M`$1U(&MA;B!I;G1E(&%N=N1N9&$@)UPG(&D@9&ET="!N86UN`$1U(&%N9V%V
M(&EN=&4@96X@9V]D:^1N9"!E+7!O<W1A9')E<W,N`$1U(.1R('5T;&]G9V%D
M+@!$=2!MY7-T92!A;F=E(&5T="!G:6QT:6=T(&UO8FEL;G5M;65R.R!E;F)A
M<G0@<VEF9G)O<B!O8V@@971T("<K)R!F]G)E(&EN=&5R;F%T:6]N96QL="!P
M<F5F:7@N`$1U(&%N9V%V(&EN=&4@971T(&=O9&OD;G0@=N1R9&4N`$1U(&WE
M<W1E(&MO;F9I9W5R97)A(&5N($1A=&%4<N1D<RUK;W!P;&EN9R!F]G(@871T
M(&%N=N1N9&$@<F5G:7-T<F5R:6YG`$1U(&WE<W1E(&MO;F9I9W5R97)A(&5N
M(%9&4RUK;W!P;&EN9P!$=2!MY7-T92!B97-K<FEV82!P<F]B;&5M96XL(&EN
M;F%N(&1U(&MA;B!R87!P;W)T97)A(&5T="!P<F]B;&5M+@!$=2!MY7-T92!A
M;F=E(&5N(%523"!S;VT@;.1N:V5N('!E:V%R('#E`$1U(&WE<W1E(&%N9V4@
M96X@<V5R=F5R('-O;2!S:V%L;"!R861E<F%S+@!$=2!MY7-T92!A;F=E(&5T
M="!A;G;D;F1A<FYA;6X@<V]M('-K86QL(')E;G-A<RX`1'4@;>5S=&4@86YG
M92!E='0@86YVY&YD87)N86UN('-O;2!S:V%L;"!R861E<F%S+@!$=2!MY7-T
M92!A;F=E(&5T="!A;G;D;F1A<FYA;6X@<V]M('-K86QL(&SD9V=A<R!T:6QL
M+@!$=2!MY7-T92!A;F=E(&5T="!A;G;D;F1A<FYA;6X@<V]M('-K86QL('5P
M<&1A=&5R87,N`$1U(&WE<W1E(&%N9V4@96X@Y71GY')D('-O;2!S:V%L;"!U
M=&;V<F%S+@!$=2!MY7-T92!A;F=E(&5T="!N>71T(&MA=&5G;W)I;F%M;BX`
M1'4@;>5S=&4@86YG92!E='0@:71A;&EE;G-K="!T96QE9F]N;G5M;65R`$1I
M;B`E<R!S97-S:6]N(&AA<B!U<'!H]G)T+B!687(@9V]D(&QO9V=A(&EN(&EG
M96XN`$1I;B!E+7!O<W1A9')E<W,`1&EN($9RY6XZ(&%D<F5S<SH`1&EN(&EN
M9F]R;6%T:6]N`$1I;B!I;G1E<FYE=&%D<F5S<R!H87(@Y&YD<F%T<R!E9G1E
M<B!A='0@9'4@;&]G9V%T(&EN('1I;&P@)R5S)RX@1O9R(&%T="!S:WED9&$@
M9&EG+"!MY7-T92!D=2!L;V=G82!I;B!I9V5N+@!$:71T(&YA;6X`1&EN(&%U
M=&5N=&ES97)I;F=S:V]P<&QI;F<@<W3V9&5R(&EN=&4@=7!P;.1G9R!A=B!A
M;G;D;F1A<F4N($]M(&1U('9I;&P@86YVY&YD82!(;W)D92!F]G(@871T(&%D
M;6EN:7-T<F5R82!A;G;D;F1A<F4@<^4@;>5S=&4@9'4@86YVY&YD82!E;B!A
M;FYA;B!A=71E;G1I<V5R:6YG<VMO<'!L:6YG+@!$:71T(&%U=&5N=&ES97)I
M;F=S:V]P<&QI;F<@<W3V9&5R(&EN=&4@;&ES=&YI;F<@878@86YVY&YD87)E
M+"!E;&QE<B!SY2#D<B!F=6YK=&EO;F5N(&%V<W3D;F=D+@!$:6X@=V5B8FSD
M<V%R92]I;G1E<FYE=&%D<F5S<R!H87(@Y&YD<F%T<R!E9G1E<B!A='0@9'4@
M;&]G9V%T(&EN('1I;&P@)R5S)RX@1O9R(&%T="!S:WED9&$@9&EG+"!MY7-T
M92!D=2!L;V=G82!I;B!I9V5N+@!$:6X@=V5B8FSD<V%R92!S=/9D97(@:6YT
M92!D96X@:.1R(&9U;FMT:6]N96XN`$1I;B!W96)B;.1S87)E('-T]F1E<B!I
M;G1E('5T<VMR:69T<V9U;FMT:6]N96XN(%1R>6-K($-T<FPO3W!T:6]N("L@
M4"!F]G(@871T('-K<FEV82!U="X`1&EN(&%K='5E;&QA('1I9'-Z;VXZ`$1I
M;B!F]G)V86QD82!I9&5N=&ET970@:&%R(.1N9')A=',N`$1I;B!F]G)V86QD
M82!I9&5N=&ET970Z`$1I='0@9G5L;'-TY&YD:6=A(&YA;6XZ`$1I;B!I;FQO
M9V=N:6YG(&AA<B!GY71T('5T+@!$:71T(&YY82!L]G-E;F]R9"!F]G(@)7,@
MY'(Z("5S`$1I;F$@:6YS=.1L;&YI;F=A<B!H87(@=7!P9&%T97)A=',@9O9R
M(&1E;B!HY'(@<V5S<VEO;F5N+@!$:6YA(&EN<W3D;&QN:6YG87(@:&%R('5P
M<&1A=&5R871S+@!$:71T(&SV<V5N;W)D(&AA<B!B;&EV:70@Y71E<G-TY&QL
M=`!$:71T(&SV<VYO<F0@:&%R(.5T97)S=.1L;'1S+"!K;VYT<F]L;&5R82!D
M:6X@92UP;W-T(&]C:"!L;V=G82!I;B!M960@9&ET="!N>6$@;/9S96YO<F0N
M`$1I='0@;/9S96YO<F0@:&%R(&?E='0@=70N`$1I;F$@9FKD<G)S97)V<F%R
M.@!*=6=O<VQA=FEE;@!:86ER90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`6T?V
M;2!C:71E<F%D('1E>'1=`%M&96QR87!P;W)T70!;5FES82!C:71E<F%D('1E
M>'0@+0!;5FES82!C:71E<F%D('1E>'0@+2`E<R!R861E<ET`6W)A9"`E<R!A
M=B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]#3$D`7T1A=&%4<N1D`%]2861E<F$@
M<F%D`%]'<G5P<&5R`%](:N1L<`!?0FEL9&EN<W3D;&QN:6YG87(N+BX`7TQO
M9V=A(&EN`%],;V=G82!U=`#$7VYD<F$@;.1N:RXN+@!?26YS=.1L;&YI;F=A
M<@!?0F5H]G)I9VAE=&5R`%]482!B;W)T(&SD;FLN+BX`7U-E='5P`%]486)E
M;&QI;G-TY&QL;FEN9V%R+BXN`%]!;G;D;F1A<F4`861R97-S8F]K`&]KY&YD
M(&UO='1A9V%R90!K86QE;F1E<@!L=6=N=`!K86X@:6YT92!S:V%P82!U=&9I
M;`!K86X@:6YT92#V<'!N82!I;F1A=&$`:VQI8VMA(&CD<@!K;&]C:V$`:V]M
M;6%N9&]R861S9F5L`&MO;F9I9W5R871I;VYS9F5L`&MR:71I<VL@<WES=&5M
M9FEL('-A:VYA<P!D871A9F]R;6%T9F5L`.1N9')A`'!O<W1E;B!K=6YD92!I
M;G1E(&AI='1A<P!F86QL86YD90!F:6P`9G+E;B!D96X@)7,@*"5S*2!K;"`E
M<R`E<P!S=&]R;6)Y87(`:#H`:&@`;VOD;F0@=N1R9&1A=&]R`&=E;F%S=`!I
M;FQI;F4`8F5A<F)E=&YI;F=S9F5L`$EN=&5R;G0@87!P;&EK871I;VYS9F5L
M`')A9&5R70!F96QK;V0@)60@9G+E;B!M:VES;V9S`&UM`&YA;6X`:6YT92!I
M;7!L96UE;G1E<F%D`&EN=&4@:6UP;&5M96YT97)A9`!A;G1E8VMN:6YG<V)L
M;V-K`'!R;V-E;G0`Y71K;VUS="!N96MA9`!P:7AL87(`<')O=&]K;VQL9F5L
M`'-T:6=A;F1E`%1JY&YS=&5N(.1R(&5J('1I;&QGY&YG;&EG`'9I<V$@<VMI
M;&QN861E<@!S;7,R96UA:6P@=FEA($A45%``<W,`<W1A9&EG=`!S>7-T96UF
M96P`=7!P9VEF='-L:7-T80!T:6QL9N1L;&EG="!F96P`86YG92!L]G-E;F]R
M9&5T('1VY2!GY6YG97(@9O9R(&%T="!B96MRY&9T80!E;F%D`&YA;6YL]G,`
M86YVY&YD87)V86P`=D-A<F0`=SH`=V5A=&AE<BYC;VT`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]S=E]312]H
M96QP+GAM;```````````````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,S,R,"`Q,#4Q-30S,S<T,B`P,C$T-C4`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]X;6P@=F5R<VEO;CTB,2XP(C\^
M"CPA+2T@)$AO<F1E.B!H;W)D92]L;V-A;&4O<W9?4T4O:&5L<"YX;6PL=B`Q
M+C(@,C`P-"\P-2\R-R`R,#HR,CHQ,B!J86X@17AP("0@+2T^"CQH96QP/@H@
M(#QE;G1R>2!I9#TB<W5M;6%R>2(@<W1A=&4](FYE=R(^"CQT:71L93Y4:&4@
M4&]R=&%L(%!A9V4\+W1I=&QE/@H@/'!A<F$^"B`@5&AI<R!P;W)T86P@<&%G
M92!P<F]V:61E<R!A('%U:6-K('-U;6UA<GD@;V8@86QL('EO=7(@:6UP;W)T
M86YT"B`@:6YF;W)M871I;VXN($9O<B!E>&%M<&QE+"!I="!M:6=H="!S:&]W
M(&AO=R!M86YY(&YE=R!E+6UA:6P@;65S<V%G97,@>6]U"B`@:&%V92!I;B!Y
M;W5R($E.0D]8+"!U<&-O;6EN9R!E=F5N=',@;VX@>6]U<B!C86QE;F1A<BP@
M=&%S:W,@;VX@>6]U<B!T;RUD;PH@(&QI<W0L(&AE861L:6YE<R!F<F]M('-E
M;&5C=&5D(&YE=W,@<V5R=FEC97,L(&%N9"!S;R!O;BX@($UA;GD@;V8@=&AE
M<V4*("!S=6UM87)I97,@=VEL;"!C;VYT86EN('%U:6-K('-H;W)T8W5T<R!T
M;R!C;VUM;VX@9G5N8W1I;VYS+"!S=6-H(&%S"B`@8V]M<&]S:6YG(&$@;F5W
M(&UA:6P@;65S<V%G92P@8W)E871I;F<@82!N97<@8V%L96YD87(@979E;G0@
M;W(@=&%S:RP@971C+@H@/"]P87)A/@H@/'!A<F$^"B`@5&AE(&-O;G1E;G1S
M(&]F('1H:7,@<&]R=&%L('!A9V4@87)E(&-U<W1O;6EZ86)L92!V:6$@=&AE
M($QA>6]U="!B=71T;VXN"B`@1F]R(&5X86UP;&4L('EO=2!C86X@8VAO;W-E
M('=H:6-H(&ET96US('1O(&EN8VQU9&4@;VX@=&AI<R!P;W)T86P@<&%G92!A
M<PH@('=E;&P@87,@:6X@=VAI8V@@;W)D97(@=&AE>2!A<F4@<VAO=VXN"B`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)N879B87(B('-T871E/2)N
M97<B/@H\=&ET;&4^5&AE($%P<&QI8V%T:6]N($YA=FEG871I;VX@0F%R/"]T
M:71L93X*(#QP87)A/@H@($%T('1H92!L969T(&AA;F0@<VED92!O9B!T:&4@
M=V5B('!A9V4@:7,@=&AE(&%P<&QI8V%T:6]N(&YA=FEG871I;VX@8F%R+@H@
M($-L:6-K(&]N('1H92!I8V]N<R!O;B!T:&ES(&YA=FEG871I;VX@8F%R('1O
M('%U:6-K;'D@86YD(&5A<VEL>2!S=VET8V@*("!B971W965N('1H92!A=F%I
M;&%B;&4@87!P;&EC871I;VYS+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<')E9G,M9&]?;6%I;G1E;F%N8V4B('-T871E/2)N97<B/@H@("`@
M/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@1&\@36%I;G1E;F%N
M8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T
M;R!P97)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6XL(&-H
M96-K('1H:7,@8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<')E9G,M8V]N9FER;5]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!#;VYF:7)M($UA
M:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U('=O=6QD
M(&QI:V4@=&\@8V]N9FER;2!A;&P@;6%I;G1E;F%N8V4@=&%S:W,@8F5F;W)E
M('1H97D@87)E(')U;BP@8VAE8VL@=&AI<R!B;W@N($EF(&QE9G0@=6YC:&5C
M:V5D+"!A;&P@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!T:&%T(&YE960@=&\@
M8F4@<G5N('=I;&P@8F4@<&5R9F]R;65D(&%U=&]M871I8V%L;'D@=VET:"!N
M;R!C:&%N8V4@=&\@8V%N8V5L(&]N(&QO9VEN+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H\+VAE;'`^"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O=')?5%(`````````
M````````````````````````````````````````````````````````````
M````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P
M,#`@,3`U,34T,S,W-#(@,#$W-S4Q`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO
M8V%L92]T<E]44B],0U]-15-304=%4P``````````````````````````````
M```````````````````````````````````````P,#`W-34@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<T,B`P,C$U,S8`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&]C86QE+W1R7U12+TQ#7TU%4U-!1T53+VAO<F1E
M+FUO````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,S,V,3`P(#$P-3$U-#,S
M-S0R(#`R,S(U-@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#>$@25`````)H&```<````[#0``-L(``"\:0```````"B-```.
M````*8T```\````XC0``#0```$B-```(````5HT```L```!?C0``#````&N-
M```$````>(T```P```!]C0``#P```(J-```+````FHT```X```"FC0``!0``
M`+6-```H````NXT```@```#DC0``"@```.V-```5````^(T``!(````.C@``
M"P```"&.```.````+8X```H````\C@``#0```$>.```.````58X``!$```!D
MC@``#0```':.```,````A(X```T```"1C@``!@```)^.```/````IHX``!@`
M``"VC@``#````,^.```.````W(X```X```#KC@``"````/J.```N`````X\`
M`!H````RCP``,@```$V/```X````@(\``%0```"YCP``40````Z0``!:````
M8)```%<```"[D```-````!.1```'````2)$```H```!0D0``#P```%N1```%
M````:Y$```8```!QD0``$0```'B1```(````BI$```D```"3D0``"0```)V1
M```E````IY$``"````#-D0``$````.Z1```/````_Y$```H````/D@```P``
M`!J2```/````'I(``!0````ND@``"0```$.2```-````39(``!(```!;D@``
M#P```&Z2```*````?I(```\```")D@``"````)F2```D````HI(``!0```#'
MD@``%@```-R2```(````\Y(``!D```#\D@``!P```!:3```,````'I,``"P`
M```KDP``#@```%B3```#````9Y,```L```!KDP``!P```'>3```'````?Y,`
M``4```"'DP``!0```(V3```*````DY,```,```">DP``%P```**3```*````
MNI,```\```#%DP``#@```-63```8````Y),``",```#]DP``#@```"&4```4
M````,)0``!<```!%E```%P```%V4```7````=90``!,```"-E```#P```*&4
M```.````L90``!\```#`E```!P```."4```&````Z)0```@```#OE```#P``
M`/B4```&````")4```H````/E0``$P```!J5```+````+I4``!`````ZE0``
M%0```$N5```5````894```<```!WE0``$````'^5```%````D)4``!4```"6
ME0``$0```*R5```,````OI4``#L```#+E0``"0````>6```'````$98``!0`
M```9E@```P```"Z6```%````,I8``!`````XE@``"0```$F6```3````4Y8`
M`#D```!GE@``$@```*&6```G````M)8``"P```#<E@``*@````F7```E````
M-)<```H```!:EP``!@```&67```)````;)<```<```!VEP``+P```'Z7```W
M````KI<``"X```#FEP``50```!68```M````:Y@``"T```"9F```+0```,>8
M``!`````]9@``",````VF0``(P```%J9```M````?ID``#,```"LF0``%0``
M`."9```9````]ID``"D````0F@``)````#J:```1````7YH```H```!QF@``
M#````'R:```*````B9H``!````"4F@``%@```*6:```6````O)H```<```#3
MF@``!P```-N:```4````XYH```H```#XF@``"`````.;```(````#)L```<`
M```5FP``!P```!V;```&````)9L```4````LFP``!P```#*;```&````.IL`
M``@```!!FP``*0```$J;```.````=)L```H```"#FP``!````(Z;```'````
MDYL```D```";FP``!@```*6;```1````K)L```<```"^FP``%@```,:;```$
M````W9L```@```#BFP``!@```.N;```-````\IL```8`````G```'@````><
M```1````)IP```@````XG```#0```$&<```,````3YP```<```!<G````P``
M`&2<```#````:)P``!<```!LG```$P```(2<```(````F)P```0```"AG```
M"````*:<```(````KYP``$$```"XG```(````/J<```&````&YT```8````B
MG0``%0```"F=```8````/YT``"(```!8G0``+@```'N=```=````JIT``"$`
M``#(G0``5````.J=```I````/YX```H```!IG@``!P```'2>```5````?)X`
M``X```"2G@``"@```*&>```/````K)X```T```"\G@``#P```,J>```-````
MVIX```D```#HG@``%````/*>```&````!Y\``!@````.GP``'0```">?```3
M````19\``!0```!9GP``!````&Z?```&````<Y\``%0```!ZGP``!````,^?
M```.````U)\```4```#CGP``!0```.F?```;````[Y\``!H````+H```$0``
M`":@```1````.*```!P```!*H```*@```&>@```0````DJ```"$```"CH```
M!0```,6@```3````RZ```!(```#?H```"@```/*@```/````_:```!$````-
MH0``$P```!^A```,````,Z$```8```!`H0``!@```$>A```7````3J$``!``
M``!FH0``$0```'>A```(````B:$```4```"2H0``#````)BA```0````I:$`
M``4```"VH0``#0```+RA```&````RJ$```<```#1H0``#0```-FA```'````
MYZ$```L```#OH0``!P```/NA```'`````Z(```D````+H@``"@```!6B```9
M````(*(```P````ZH@``$````$>B```%````6*(``"4```!>H@``$@```(2B
M```3````EZ(``"L```"KH@``.P```->B```@````$Z,``#8````THP``"```
M`&NC```,````=*,```8```"!HP``!````(BC```.````C:,```H```"<HP``
M#0```*>C```>````M:,``!L```#4HP``(0```/"C```>````$J0``!D````Q
MI```'@```$ND```;````:J0``"8```"&I```&P```*VD```>````R:0``!P`
M``#HI```)@````6E```S````+*4``"8```!@I0``*P```(>E```X````LZ4`
M`"\```#LI0``$@```!RF```I````+Z8``!(```!9I@``H@```&RF```6````
M#Z<``",````FIP``*````$JG```I````<Z<``"@```"=IP``'P```,:G```@
M````YJ<``"4````'J```*````"VH```P````5J@``)(```"'J```(0```!JI
M```<````/*D``"8```!9J0``00```("I```,````PJD```<```#/J0``!P``
M`->I```&````WZD```T```#FJ0``$````/2I```2````!:H``!,````8J@``
M$@```"RJ```'````/ZH```0```!'J@``#````$RJ```.````6:H```\```!H
MJ@``$P```'BJ```-````C*H``"@```":J@```P```,.J```-````QZH```8`
M``#5J@``$0```-RJ```7````[JH``!L````&JP``#@```"*K```"````,:L`
M``4````TJP``$````#JK```$````2ZL```T```!0JP``#@```%ZK```#````
M;:L```X```!QJP``"````("K```/````B:L```\```"9JP``!P```*FK```-
M````L:L``!````"_JP``"P```-"K```&````W*L```P```#CJP``$0```/"K
M```9`````JP```L````<K```#0```"BL```B````-JP```H```!9K```&```
M`&2L```9````?:P``!8```"7K```#0```*ZL```'````O*P``!0```#$K```
M"P```-FL```B````Y:P``"\````(K0``"P```#BM```)````1*T``!D```!.
MK0``"P```&BM```7````=*T``!<```",K0``"0```*2M```6````KJT```\`
M``#%K0``%@```-6M```.````[*T``!@```#[K0``"````!2N```-````':X`
M`"8````KK@``0P```%*N```(````EJX``!(```"?K@``"````+*N```+````
MNZX``"\```#'K@``#@```/>N```%````!J\```8````,KP```P```!.O```'
M````%Z\```0````?KP``"@```"2O```*````+Z\```\````ZKP``$````$JO
M```7````6Z\``!$```!SKP``%P```(6O```)````G:\```4```"GKP``"P``
M`*VO```*````N:\```(```#$KP``!0```,>O```-````S:\``!L```#;KP``
M%P```/>O```)````#[````X````9L```#0```"BP```2````-K```#@```!)
ML```(````(*P```(````H[````X```"LL```>P```+NP```8````-[$``!$`
M``!0L0``!P```&*Q```%````:K$``!D```!PL0``!P```(JQ```(````DK$`
M``8```";L0``!@```**Q```0````J;$```\```"ZL0``$````,JQ```/````
MV[$```L```#KL0``#P```/>Q```,````![(```\````4L@``!P```"2R```&
M````++(```X````SL@``#````$*R```H````3[(```\```!XL@``"````(BR
M```(````D;(``!,```":L@``'@```*ZR```A````S;(``"````#OL@``&0``
M`!"S```7````*K,``"4```!"LP``%P```&BS```$````@+,``!L```"%LP``
M#0```*&S```,````K[,```,```"\LP``"````,"S```*````R;,```P```#4
MLP``"P```.&S```0````[;,```P```#^LP``!`````NT```3````$+0``!0`
M```DM```#````#FT```)````1K0```X```!0M```"P```%^T```;````:[0`
M``<```"'M```!P```(^T```*````E[0```T```"BM```"0```+"T```$````
MNK0```4```"_M````P```,6T```8````R;0```H```#BM```!````.VT```F
M````\K0```X````9M0``?````"BU```5````I;4```4```"[M0``!P```,&U
M```,````R;4```@```#6M0``"@```-^U```&````ZK4```@```#QM0```@``
M`/JU```&````_;4```8````$M@``%`````NV```-````(+8``!`````NM@``
M&P```#^V```$````6[8```D```!@M@``$````&JV```)````>[8```D```"%
MM@``!0```(^V```:````E;8```@```"PM@``!@```+FV```9````P+8```X`
M``#:M@``!P```.FV```'````\;8```4```#YM@``"0```/^V```*````";<`
M``(````4MP``!@```!>W```-````'K<```D````LMP``!@```#:W```2````
M/;<```D```!0MP``!P```%JW```4````8K<``!T```!WMP``!@```)6W```*
M````G+<```0```"GMP``"0```*RW```(````MK<``!$```"_MP``"0```-&W
M```&````V[<```T```#BMP``!@```/"W```$````][<``#D```#\MP``/0``
M`#:X```Z````=+@``!X```"ON```!0```,ZX```.````U+@```0```#CN```
M!@```.BX```A````[[@``!4````1N0``!@```">Y```$````+KD``!$````S
MN0``!@```$6Y```*````3+D``"(```!7N0``!````'JY```%````?[D``!T`
M``"%N0``!````*.Y```,````J+D```H```"UN0``"````,"Y```)````R;D`
M``4```#3N0``.@```-FY```P````%+H``#4```!%N@``*0```'NZ``!'````
MI;H``#@```#MN@``*0```":[```_````4+L``"X```"0NP``+0```+^[```?
M````[;L```\````-O```$@```!V\```+````,+P``"8````\O```*0```&.\
M```D````C;P``"8```"RO```"````-F\```*````XKP```D```#MO```!P``
M`/>\```@````_[P``"`````@O0``)@```$&]```*````:+T``!D```!SO0``
M*0```(V]```6````M[T``!(```#.O0``!P```.&]```*````Z;T```P```#T
MO0``#P````&^```0````$;X``$`````BO@``<````&.^``!F````U+X```X`
M```[OP``"0```$J_```*````5+\``!(```!?OP``$P```'*_```,````AK\`
M``8```"3OP``#P```)J_```2````JK\``!````"]OP``$0```,Z_```<````
MX+\``",```#]OP``:@```"'````/````C,````4```"<P```$````*+````)
M````L\````0```"]P```"P```,+````4````SL````P```#CP```#````/#`
M```/````_<```!4````-P0``*0```"/!```J````3<$``"8```!XP0``)P``
M`)_!```I````Q\$``"H```#QP0``&0```!S"``!"````-L(``!$```!YP@``
M$@```(O"```3````GL(``!0```"RP@``#P```,?"```6````U\(``!<```#N
MP@``$`````;#```1````%\,``#0````IPP``$P```%[#```2````<L,``#4`
M``"%PP``%````+O#```'````T,,```P```#8PP``(````.7#```4````!L0`
M`!$````;Q```%P```"W$```<````1<0``!,```!BQ```$0```';$```:````
MB,0``!X```"CQ```&@```,+$```1````W<0``!0```#OQ```%P````3%```5
M````',4```D````RQ0``&0```#S%```$````5L4```<```!;Q0``"P```&/%
M```1````;\4```8```"!Q0``!@```(C%```&````C\4```4```"6Q0``!P``
M`)S%```'````I,4```4```"LQ0``%@```++%```&````R<4```8```#0Q0``
M!````-?%```$````W,4```<```#AQ0``#@```.G%```,````^,4```P````%
MQ@``#0```!+&```*````(,8```X````KQ@``!0```#K&```H````0,8```X`
M``!IQ@``#````'C&```/````A<8```H```"5Q@``"````*#&```)````J<8`
M`"L```"SQ@``!````-_&```(````Y,8``"8```#MQ@``$@```!3'```/````
M)\<```8````WQP``"@```#['```'````2<<```@```!1QP``(````%K'```)
M````>\<```P```"%QP``#0```)+'```.````H,<``!8```"OQP``$0```,;'
M```&````V,<```,```#?QP``!@```./'```9````ZL<```<````$R```!```
M``S(```+````$<@```L````=R```!P```"G(```'````,<@``!8````YR```
M#0```%#(```-````7L@```H```!LR```$````'?(```/````B,@``!$```"8
MR```%P```*K(```*````PL@``!$```#-R```"````-_(```$````Z,@```\`
M``#MR```.@```/W(```%````.,D```P````^R0``'@```$O)```.````:LD`
M`!````!YR0``"P```(K)```,````ELD```D```"CR0``!P```*W)```*````
MM<D```D```#`R0``#@```,K)```0````V<D``!H```#JR0``"@````7*```)
M````$,H```H````:R@``#````"7*```/````,LH```@```!"R@``!@```$O*
M```'````4LH```L```!:R@``1P```&;*```-````KLH```D```"\R@``!```
M`,;*```#````R\H``!,```#/R@``$P```./*```3````]\H```H````+RP``
M`@```!;+```$````&<L``"4````>RP```P```$3+```%````2,L``"H```!.
MRP``"@```'G+```%````A,L```0```"*RP``"@```(_+```-````FLL```8`
M``"HRP``"````*_+```(````N,L```0```#!RP``!0```,;+``!H````S,L`
M``D````US```#````#_,```%````3,P```8```!2S```&P```%G,```O````
M=<P``!````"ES```"@```+;,```/````P<P```H```#1S```"0```-S,```3
M````YLP``!L```#ZS```&````!;-```7````+\T```X```!'S0```P```%;-
M```'````6LT```@```!BS0``!P```&O-```*````<\T```L```!^S0``!P``
M`(K-``!1````DLT``!````#DS0``#````/7-```-`````LX``!H````0S@``
M2@```"O.```&````=LX```8```!]S@``!@```(3.```?````B\X```8```"K
MS@``"0```++.```8````O,X``!<```#5S@``!@```.W.```-````],X``"(`
M```"SP``5P```"7/```3````?<\``",```"1SP``$P```+7/```"````R<\`
M``L```#,SP``"````-C/```-````X<\```H```#OSP``!P```/K/```4````
M`M````8````7T```"````![0```.````)]````<````VT```"@```#[0```+
M````2=````<```!5T```#````%W0```-````:M````P```!XT```"0```(70
M```)````C]````H```"9T```!P```*30```)````K-````<```"VT```"@``
M`+[0```;````R=```!(```#ET```"@```/C0```)`````]$``!`````-T0``
M!P```![1```2````)M$```0````YT0``!P```#[1```%````1M$```4```!,
MT0``"P```%+1```4````7M$``!$```!ST0``&@```(71```6````H-$``!0`
M``"WT0``%P```,S1```8````Y-$``!P```#]T0``&0```!K2```'````--(`
M``4````\T@``#0```$+2```,````4-(```@```!=T@``%P```&;2```+````
M?M(``!,```"*T@``!````)[2```*````H](```0```"NT@``#````+/2```)
M````P-(```4```#*T@``!P```-#2```%````V-(```0```#>T@```@```./2
M```X````YM(``"P````?TP``$@```$S3```I````7],``#(```")TP``"@``
M`+S3```L````Q],``"X```#TTP``,P```"/4```S````5]0``#@```"+U```
M#P```,34```8````U-0``!````#MU```#P```/[4```3````#M4``!0````B
MU0``$@```#?5```4````2M4``!4```!?U0``+0```'75```M````H]4``#$`
M``#1U0``+@````/6```O````,M8``"P```!BU@``8@```(_6```3````\M8`
M``@````&UP``"`````_7```K````&-<``"$```!$UP``&@```&;7```)````
M@=<``$4```"+UP``00```-'7```$````$]@``!,````8V```%````"S8```.
M````0=@``!,```!0V```&````&38```&````?=@```D```"$V```"@```([8
M```/````F=@``!````"IV```!P```+K8```.````PM@```4```#1V```&P``
M`-?8```(````\]@```8```#\V```%`````/9```1````&-D```X````JV0``
M.````#G9```"````<MD```8```!UV0``#@```'S9```%````B]D```<```"1
MV0``#@```)G9```&````J-D```0```"OV0``*0```+39```7````WMD``!\`
M``#VV0``7````!;:```4````<]H``#X```"(V@``'P```,?:```0````Y]H`
M``<```#XV@``#@````#;```,````#]L```P````<VP``$P```"G;```*````
M/=L``!T```!(VP``&0```&;;```%````@-L``!$```"&VP``$0```)C;```D
M````JML``!4```#/VP``$@```.7;```.````^-L``!D````'W```"````"'<
M```)````*MP```T````TW```"@```$+<```'````3=P```\```!5W```"P``
M`&7<```*````<=P```<```!\W```"````(3<```%````C=P``!\```"3W```
M!@```+/<```0````NMP```@```#+W```#0```-3<```(````XMP``!(```#K
MW```+````/[<```:````*]T```D```!&W0``"@```%#=```5````6]T```4`
M``!QW0``%````'?=```$````C-T``!````"1W0``!@```*+=```'````J=T`
M`!X```"QW0``*````-#=```*````^=T``!H````$W@``%````!_>```$````
M--X```0````YW@``"P```#[>```%````2MX```8```!0W@``"````%?>```&
M````8-X```H```!GW@``&P```'+>```T````CMX``#0```##W@``(````/C>
M```I````&=\``"````!#WP``00```&3?```:````IM\``"@```#!WP``*0``
M`.K?```B````%.````8````WX```"````#[@```%````1^````@```!-X```
M&0```%;@```9````<.```"H```"*X```(P```+7@```N````V>```#0````(
MX0``"````#WA```7````1N$```H```!>X0``!P```&GA```A````<>$``!``
M``"3X0``#@```*3A```+````L^$```<```"_X0``$P```,?A```(````V^$`
M``L```#DX0``"@```/#A```4````^^$``#(````0X@``"P```$/B```%````
M3^(```4```!5X@``%P```%OB```/````<^(```0```"#X@``"@```(CB```)
M````D^(```L```"=X@``#0```*GB```,````M^(```X```#$X@``!0```-/B
M```$````V>(```T```#>X@``,@```.SB``!%````'^,``!<```!EXP``'@``
M`'WC```4````G.,```4```"QXP``%````+?C```'````S.,```X```#4XP``
M*@```./C```&````#N0```P````5Y```#0```"+D```1````,.0```L```!"
MY```-@```$[D```*````A>0``"(```"0Y```"P```+/D```/````O^0``#(`
M``#/Y```#@````+E```%````$>4```X````7Y0``$P```";E```'````.N4`
M`!$```!"Y0``!P```%3E```4````7.4``!@```!QY0``!P```(KE```%````
MDN4```P```"8Y0``#````*7E```2````LN4```0```#%Y0``!P```,KE```*
M````TN4```L```#=Y0``#````.GE```.````]N4```X````%Y@``!0```!3F
M```%````&N8``"X````@Y@``)@```$_F```C````=N8```,```":Y@``$@``
M`)[F```&````L>8``!X```"XY@``&````-?F```E````\.8```T````6YP``
M"0```"3G```#````+N<```<````RYP``"@```#KG```"````1><```P```!(
MYP``%0```%7G```+````:^<``!D```!WYP``(````)'G```2````LN<```4`
M``#%YP``"@```,OG```5````UN<``!(```#LYP``#````/_G```$````#.@`
M``<````1Z```#````!GH``!2````)N@``!<```!YZ```!P```)'H```&````
MF>@```X```"@Z```#````*_H```-````O.@``!4```#*Z```$@```.#H```/
M````\^@``!0````#Z0``&P```!CI```0````-.D``&D```!%Z0``&@```*_I
M```7````RND``"<```#BZ0``&@````KJ```7````)>H``!L````]Z@``&0``
M`%GJ```?````<^H``!,```"3Z@``"````*?J```'````L.H```@```"XZ@``
M"0```,'J```5````R^H```T```#AZ@``$P```._J```#`````^L``$8````'
MZP``/P```$[K```W````CNL``%<```#&ZP``!0```![L```?````).P``"\`
M``!$[```"@```'3L```(````?^P```T```"([```+0```);L```$````Q.P`
M`$\```#)[```)0```!GM```<````/^T```L```!<[0``'P```&CM```=````
MB.T``"4```"F[0``(````,SM```D````[>T``"`````2[@``"P```#/N```'
M````/^X```T```!'[@``#````%7N```7````8NX```8```!Z[@``.0```('N
M```,````N^X```<```#([@``"0```-#N```3````VNX```D```#N[@``!```
M`/CN```0````_>X```@````.[P``"````!?O```$````(.\```L````E[P``
M#````#'O```2````/N\``!$```!1[P``#````&/O```:````<.\```\```"+
M[P``!P```)OO```-````H^\``!0```"Q[P``#@```,;O```,````U>\``!L`
M``#B[P``+````/[O```3````*_```!P````_\```*````%SP```&````A?``
M``<```",\```$P```)3P```%````J/````0```"N\```%P```+/P```*````
MR_````P```#6\```"0```./P```&````[?````D```#T\```"````/[P```)
M````!_$```H````1\0``$0```!SQ```&````+O$```X````U\0``#@```$3Q
M```-````4_$```L```!A\0``'0```&WQ```+````B_$```(```"7\0``!P``
M`)KQ```&````HO$```D```"I\0``!P```+/Q```[````N_$``"@```#W\0``
M-````"#R```5````5?(```4```!K\@``!P```''R```(````>?(```<```""
M\@``!0```(KR```'````D/(```X```"8\@``"0```*?R```&````L?(```@`
M``"X\@``"P```,'R```'````S?(```@```#5\@``!P```-[R```6````YO(`
M``D```#]\@``!@````?S```+````#O,``!P````:\P``%````#?S```'````
M3/,```@```!4\P``"````%WS```%````9O,``!````!L\P``$````'WS```&
M````CO,``!D```"5\P``"@```*_S```<````NO,```<```#7\P``!0```-_S
M```0````Y?,``!0```#V\P``"P````OT```-````%_0``!<````E]```!```
M`#WT```)````0O0```H```!,]```!P```%?T```"````7_0```X```!B]```
M"````''T```?````>O0``",```":]```.````+[T```Q````]_0``"<````I
M]0``9````%'U```4````MO4``%4```#+]0``.````"'V``!*````6O8``%L`
M``"E]@``*`````'W```X````*O<``"@```!C]P``+````(SW```G````N?<`
M`!L```#A]P``/@```/WW``"I`0``//@``",```#F^0``%P````KZ``!(````
M(OH``(4```!K^@``,````/'Z``!!````(OL``%L```!D^P``20```,#[```=
M````"OP``!@````H_```(0```$'\```?````8_P``"L```"#_```(0```*_\
M```G````T?P``!T```#Y_```$0```!?]```S````*?T``"4```!=_0``)P``
M`(/]```?````J_T``#````#+_0``:0```/S]```]````9OX``&4```"D_@``
M30````K_```O````6/\``"X```"(_P``,````+?_``!4````Z/\``%H````]
M``$`2````)@``0!*````X0`!`#(````L`0$`+P```%\!`0`L````CP$!`"T`
M``"\`0$`<0```.H!`0!O````7`(!`+,```#,`@$`%P```(`#`0`E````F`,!
M`#(```"^`P$`*0```/$#`0`^````&P0!`"(```!:!`$`4@```'T$`0`E````
MT`0!``L```#V!`$`L0````(%`0!%````M`4!`"$```#Z!0$`,````!P&`0`E
M````308!`!P```!S!@$`,0```)`&`0`'````P@8!``<```#*!@$`!````-(&
M`0`-````UP8!``L```#E!@$`#@```/$&`0`+``````<!``4````,!P$`$```
M`!('`0`"````(P<!`%D````F!P$`!0```(`'`0`2````A@<!``0```"9!P$`
M!P```)X'`0`(````I@<!``4```"O!P$``P```+4'`0`0````N0<!``P```#*
M!P$`$P```-<'`0`-````ZP<!``(```#Y!P$`!P```/P'`0`&````!`@!`!0`
M```+"`$`#````"`(`0`8````+0@!``8```!&"`$`$@```$T(`0`,````8`@!
M``,```!M"`$`*@```'$(`0`$````G`@!``8```"A"`$`!P```*@(`0`?````
ML`@!`#4```#0"`$`+@````8)`0`O````-0D!`!<```!E"0$`(````'T)`0`;
M````G@D!`!@```"Z"0$`)````-,)`0`?````^`D!`!H````8"@$`(````#,*
M`0`:````5`H!`#(```!O"@$`+P```*(*`0`K````T@H!`!\```#^"@$`(P``
M`!X+`0`?````0@L!`!H```!B"P$`)0```'T+`0`F````HPL!`"4```#*"P$`
M)````/`+`0`8````%0P!`!T````N#`$`)````$P,`0`8````<0P!`"(```"*
M#`$`)0```*T,`0`\````TPP!`!\````0#0$`(P```#`-`0`?````5`T!`"``
M``!T#0$`&@```)4-`0`8````L`T!`"8```#)#0$`'@```/`-`0`I````#PX!
M`!X````Y#@$`"0```%@.`0`,````8@X!`!<```!O#@$`+P```(<.`0`D````
MMPX!``<```#<#@$`#P```.0.`0`4````]`X!``X````)#P$`#0```!@/`0`D
M````)@\!``4```!+#P$`!P```%$/`0`B````60\!`"4```!\#P$`'0```*(/
M`0`:````P`\!``<```#;#P$`QP```.,/`0`+````JQ`!`!4```"W$`$`!@``
M`,T0`0`)````U!`!``L```#>$`$`%P```.H0`0`&`````A$!`#,````)$0$`
M$P```#T1`0`3````41$!``<```!E$0$`#P```&T1`0`'````?1$!`#(```"%
M$0$`(0```+@1`0`3````VA$!``P```#N$0$`$0```/L1`0`R````#1(!``@`
M``!`$@$`"0```$D2`0`*````4Q(!`!0```!>$@$`"@```',2`0`=````?A(!
M``@```"<$@$`'P```*42`0`(````Q1(!`!H```#.$@$`!@```.D2`0`5````
M\!(!``<````&$P$`"`````X3`0`)````%Q,!`#\````A$P$`!P```&$3`0`/
M````:1,!``X```!Y$P$`$````(@3`0`)````F1,!``D```"C$P$`"````*T3
M`0`3````MA,!``<```#*$P$`&0```-(3`0`*````[!,!`!<```#W$P$`%```
M``\4`0`*````)!0!``P````O%`$`%P```#P4`0`$````5!0!`"H```!9%`$`
M$0```(04`0`'````EA0!``(```">%`$`$````*$4`0`8````LA0!``L```#+
M%`$``P```-<4`0`(````VQ0!``8```#D%`$`!P```.L4`0`-````\Q0!``L`
M```!%0$`%`````T5`0`5````(A4!``X````X%0$`+P```$<5`0`@````=Q4!
M`!P```"8%0$`#````+45`0`Q````PA4!``4```#T%0$`$@```/H5`0`_````
M#18!`!(```!-%@$`"@```&`6`0`&````:Q8!``0```!R%@$`!````'<6`0`*
M````?!8!`!,```"'%@$`!0```)L6`0`&````H18!``8```"H%@$`!````*\6
M`0`,````M!8!``H```#!%@$`!0```,P6`0`8````TA8!`!D```#K%@$`'P``
M``47`0`=````)1<!`!$```!#%P$``@```%47`0`$````6!<!``H```!=%P$`
M!@```&@7`0`%````;Q<!``,```!U%P$`#````'D7`0!%````AA<!`!H```#,
M%P$`-0```.<7`0`H````'1@!`%,```!&&`$`&0```)H8`0!R````M!@!`"``
M```G&0$`-0```$@9`0`A````?AD!`$4```"@&0$`,````.89`0`H````%QH!
M`"D```!`&@$`)@```&H:`0`E````D1H!`"@```"W&@$`*````.`:`0`B````
M"1L!`#`````L&P$`$@```%T;`0`3````<!L!`!````"$&P$`>0```)4;`0`)
M````#QP!`',````9'`$`?````(T<`0`K````"AT!`!<````V'0$`%@```$X=
M`0`/````91T!`!\```!U'0$`0````)4=`0`?````UAT!`!P```#V'0$`40``
M`!,>`0`4````91X!``H```!Z'@$`!0```(4>`0`&````BQX!``@```"2'@$`
M!0```)L>`0`2````H1X!`!````"T'@$`$P```,4>`0`=````V1X!``\```#W
M'@$`#P````<?`0`$````%Q\!``D````<'P$`"P```"8?`0`'````,A\!``4`
M```Z'P$`%````$`?`0`'````51\!``@```!='P$`#P```&8?`0`(````=A\!
M``P```!_'P$`#P```(P?`0`&````G!\!`!0```"C'P$`!@```+@?`0`,````
MOQ\!``@```#,'P$`!````-4?`0`*````VA\!``<```#E'P$`!````.T?`0`9
M````\A\!``(````,(`$`"0````\@`0`&````&2`!``8````@(`$`)P```"<@
M`0`$````3R`!``\```!4(`$`$P```&0@`0`'````>"`!``<```"`(`$`!@``
M`(@@`0`&````CR`!`!````"6(`$`$@```*<@`0`&````NB`!``D```#!(`$`
M(@```,L@`0`'````[B`!``<```#V(`$`"P```/X@`0`%````"B$!``(````0
M(0$`"P```!,A`0!K`0``'R$!``X```"+(@$`%````)HB`0`+````KR(!``@`
M``"[(@$`"````,0B`0`&````S2(!``@```#4(@$`"P```-TB`0`6````Z2(!
M``T`````(P$`#0````XC`0`%````'",!`!T````B(P$`"@```$`C`0`(````
M2R,!`!0```!4(P$`#0```&DC`0`+````=R,!`!$```"#(P$`"0```)4C`0`.
M````GR,!``T```"N(P$`$````+PC`0`)````S2,!``X```#7(P$`$````.8C
M`0`&````]R,!`!$```#^(P$`$@```!`D`0`)````(R0!`!<````M)`$`%P``
M`$4D`0`'````720!`#,```!E)`$`%P```)DD`0`]````L20!`$T```#O)`$`
M9````#TE`0!<````HB4!`&L```#_)0$`8P```&LF`0`_````SR8!``D````/
M)P$`"0```!DG`0`,````(R<!``4````P)P$`!@```#8G`0`4````/2<!``P`
M``!2)P$`!0```%\G`0`&````92<!`"@```!L)P$`*@```)4G`0`.````P"<!
M`!$```#/)P$`#````.$G`0`$````[B<!``T```#S)P$`#0````$H`0`,````
M#R@!``X````<*`$`#@```"LH`0`4````.B@!``H```!/*`$`#0```%HH`0`*
M````:"@!`"P```!S*`$`%0```*`H`0`4````MB@!``X```#+*`$`(P```-HH
M`0`%````_B@!``T````$*0$`,@```!(I`0`'````12D!``,```!-*0$`"@``
M`%$I`0`*````7"D!``<```!G*0$`"````&\I`0`&````>"D!``H```!_*0$`
M!````(HI`0`<````CRD!``L```"L*0$`"P```+@I`0`,````Q"D!`!@```#1
M*0$`-````.HI`0`)````'RH!`!$````I*@$`$P```#LJ`0`8````3RH!`!T`
M``!H*@$`#P```(8J`0`,````EBH!``X```"C*@$`&@```+(J`0`&````S2H!
M``8```#4*@$`"````-LJ`0`,````Y"H!``4```#Q*@$`"0```/<J`0`2````
M`2L!``@````4*P$`$````!TK`0`.````+BL!`!<````]*P$`!@```%4K`0`.
M````7"L!``4```!K*P$`%0```'$K`0`5````ARL!``P```"=*P$`.@```*HK
M`0`(````Y2L!``H```#N*P$`%````/DK`0`%````#BP!``4````4+`$`$0``
M`!HL`0`,````+"P!`!0````Y+`$`+P```$XL`0`/````?BP!`"4```".+`$`
M)````+0L`0`I````V2P!`"T````#+0$`#````#$M`0`'````/BT!``L```!&
M+0$`"0```%(M`0`O````7"T!`"P```",+0$`+0```+DM`0!?````YRT!`"P`
M``!'+@$`+````'0N`0`L````H2X!`"X```#.+@$`)````/TN`0`H````(B\!
M`"P```!++P$`,@```'@O`0`9````JR\!`!P```#%+P$`,P```.(O`0`H````
M%C`!`!,````_,`$`"@```%,P`0`1````7C`!``<```!P,`$`#0```'@P`0`7
M````AC`!`!P```">,`$`"0```+LP`0`'````Q3`!`!0```#-,`$`"0```.(P
M`0`(````[#`!``T```#U,`$`"P````,Q`0`'````#S$!``8````7,0$`!0``
M`!XQ`0`'````)#$!``8````L,0$`"0```#,Q`0`Q````/3$!``T```!O,0$`
M"0```'TQ`0`$````AS$!``<```",,0$`"@```)0Q`0`%````GS$!`!````"E
M,0$`"````+8Q`0`,````OS$!``D```#,,0$`"````-8Q`0`#````WS$!``X`
M``#C,0$`"````/(Q`0`>````^S$!``8````:,@$`"P```"$R`0`0````+3(!
M``P````^,@$`!P```$LR`0`#````4S(!``,```!7,@$`%0```%LR`0`5````
M<3(!``8```"',@$`!@```(XR`0`(````E3(!``<```">,@$`3````*8R`0`?
M````\S(!``8````3,P$`!0```!HS`0`7````(#,!`!@````X,P$`&````%$S
M`0`Q````:C,!`!H```"<,P$`'P```+<S`0!W````US,!`"P```!/-`$`"@``
M`'PT`0`&````AS0!`!@```".-`$`#@```*<T`0`,````MC0!`!$```##-`$`
M$P```-4T`0`1````Z30!`!$```#[-`$`#`````TU`0`4````&C4!``0````O
M-0$`%P```#0U`0`8````3#4!`!@```!E-0$`%@```'XU`0`#````E34!``@`
M``"9-0$`:P```*(U`0`(````#C8!`!8````7-@$`!````"XV`0`#````,S8!
M`!\````W-@$`%P```%<V`0`,````;S8!`!,```!\-@$`)P```)`V`0`S````
MN#8!`!$```#L-@$`&@```/XV`0`'````&3<!`!\````A-P$`%P```$$W`0`1
M````63<!`!@```!K-P$`&0```(0W`0`7````GC<!``\```"V-P$`"````,8W
M`0`'````SS<!``T```#7-P$`%0```.4W`0`4````^S<!``D````0.`$`!```
M`!HX`0`+````'S@!``L````K.`$`"0```#<X`0`0````03@!``4```!2.`$`
M!0```%@X`0`,````7C@!``@```!K.`$`"0```'0X`0`'````?C@!``8```"&
M.`$`#0```(TX`0`(````FS@!`!4```"D.`$`#0```+HX`0`0````R#@!``4`
M``#9.`$`'````-\X`0`8````_#@!`!@````5.0$`+````"XY`0`[````6SD!
M`"4```"7.0$`-P```+TY`0`%````]3D!``P```#[.0$`!0````@Z`0`'````
M#CH!``X````6.@$`"@```"4Z`0`-````,#H!`!P````^.@$`&P```%LZ`0`?
M````=SH!`!X```"7.@$`'P```+8Z`0`>````UCH!`!@```#U.@$`(`````X[
M`0`A````+SL!`"0```!1.P$`'P```'8[`0`>````ECL!`"\```"U.P$`(P``
M`.4[`0`E````"3P!`#$````O/`$`+@```&$\`0`-````D#P!`"4```">/`$`
M#0```,0\`0"9````TCP!`!````!L/0$`'P```'T]`0`A````G3T!`",```"_
M/0$`)````.,]`0`A````"#X!`!X````J/@$`)0```$D^`0`H````;SX!`"P`
M``"8/@$`HP```,4^`0`8````:3\!`",```""/P$`(@```*8_`0!+````R3\!
M``X````50`$`!````"1``0`'````*4`!``4````Q0`$`#@```#=``0`*````
M1D`!``\```!10`$`$0```&%``0`3````<T`!``L```"'0`$`!````)-``0`/
M````F$`!``T```"H0`$`%0```+9``0`2````S$`!`!(```#?0`$`,````/)`
M`0`#````(T$!`!,````G00$`!@```#M!`0`.````0D$!`!0```!100$`%@``
M`&9!`0`/````?4$!``(```"-00$`!@```)!!`0`5````ET$!``4```"M00$`
M#````+-!`0`,````P$$!``,```#-00$`"P```-%!`0`&````W4$!``\```#D
M00$`#P```/1!`0`*````!$(!``\````/0@$`$0```!]"`0`(````,4(!``,`
M```Z0@$`"````#Y"`0`(````1T(!`!@```!00@$`"0```&E"`0`)````<T(!
M`!D```!]0@$`"@```)="`0`4````HD(!`!0```"W0@$`%````,Q"`0`-````
MX4(!``D```#O0@$`$0```/E"`0`(````"T,!`#P````40P$`,@```%%#`0`'
M````A$,!``L```",0P$`&@```)A#`0`-````LT,!`!$```#!0P$`$0```--#
M`0`%````Y4,!`"````#K0P$`%P````Q$`0`>````)$0!`!(```!#1`$`#P``
M`%9$`0`&````9D0!``@```!M1`$`+0```'9$`0`^````I$0!``<```#C1`$`
M$P```.M$`0`%````_T0!``@````%10$`,P````Y%`0`2````0D4!``<```!5
M10$`!P```%U%`0`#````944!``<```!I10$`!P```'%%`0`,````>44!``P`
M``"&10$`#````)-%`0`0````H$4!`!@```"Q10$`%````,I%`0`8````WT4!
M``8```#X10$`!0```/]%`0`+````!48!``8````11@$``@```!A&`0`0````
M&T8!`!<````L1@$`)0```$1&`0`7````:D8!`!````""1@$`"@```)-&`0`*
M````GD8!`!,```"I1@$`3@```+U&`0`J````#$<!``H````W1P$`%@```$)'
M`0!R````64<!`!T```#,1P$`#@```.I'`0`&````^4<!``0`````2`$`(```
M``5(`0`'````)D@!``@````N2`$`!0```#=(`0`&````/4@!``T```!$2`$`
M#````%)(`0`-````7T@!``P```!M2`$`"P```'I(`0`.````AD@!``H```"5
M2`$`#P```*!(`0`(````L$@!``@```"Y2`$`%P```,)(`0`.````VD@!`"\`
M``#I2`$`%0```!E)`0`#````+TD!``T````S20$`&@```$%)`0`@````7$D!
M`",```!]20$`(@```*%)`0`D````Q$D!`"(```#I20$`)`````Q*`0`?````
M,4H!``H```!12@$`&@```%Q*`0`-````=TH!``T```"%2@$`!````)-*`0`%
M````F$H!``P```">2@$`#@```*M*`0`-````NDH!`!(```#(2@$`#````-M*
M`0`$````Z$H!`!8```#M2@$`%@````1+`0`0````&TL!``D````L2P$`#```
M`#9+`0`-````0TL!`!T```!12P$`"0```&]+`0`*````>4L!``@```"$2P$`
M"@```(U+`0`-````F$L!``4```"F2P$`!0```*Q+`0`#````LDL!``T```"V
M2P$`"@```,1+`0`%````STL!`"H```#52P$`#`````!,`0![````#4P!`!<`
M``")3`$`!P```*%,`0`%````J4P!``H```"O3`$`"````+I,`0`*````PTP!
M``@```#.3`$`#@```-=,`0`"````YDP!``H```#I3`$`!@```/1,`0`4````
M^TP!`!`````030$`$P```"%-`0`5````-4T!``8```!+30$`!@```%)-`0`-
M````64T!``<```!G30$`!P```&]-`0`%````=TT!`!T```!]30$`!P```)M-
M`0`'````HTT!`!L```"K30$`#P```,=-`0`)````UTT!``<```#A30$`!```
M`.E-`0`+````[DT!``H```#Z30$``P````5.`0`&````"4X!``P````03@$`
M"P```!U.`0`*````*4X!`!0````T3@$`"````$E.`0`'````4DX!``T```!:
M3@$`'````&A.`0`'````A4X!``@```"-3@$`!````)9.`0`)````FTX!``@`
M``"E3@$`#@```*Y.`0`-````O4X!``0```#+3@$`#````-!.`0`&````W4X!
M``0```#D3@$`,@```.E.`0`S````'$\!`#,```!03P$`(````(1/`0`%````
MI4\!`!````"K3P$`"0```+Q/`0`&````QD\!`!\```#-3P$`%P```.U/`0`)
M````!5`!``8````/4`$`&P```!90`0`(````,E`!``@````[4`$`%0```$10
M`0`&````6E`!``D```!A4`$`!P```&M0`0`(````<U`!``D```!\4`$`"P``
M`(90`0`(````DE`!``D```";4`$`!0```*50`0!(````JU`!`#<```#T4`$`
M.P```"Q1`0`G````:%$!`$D```"040$`.P```-I1`0`C````%E(!`#<````Z
M4@$`(P```')2`0`:````EE(!`!@```"Q4@$`"P```,I2`0`0````UE(!``8`
M``#G4@$`*P```.Y2`0`J````&E,!`!4```!%4P$`*@```%M3`0`#````AE,!
M``4```"*4P$`"@```)!3`0`*````FU,!`"0```"F4P$`(````,M3`0`K````
M[%,!``D````85`$`&````")4`0`O````.U0!`!0```!K5`$`%P```(!4`0`'
M````F%0!``\```"@5`$`$````+!4`0`;````P50!``T```#=5`$`10```.M4
M`0!J````,54!`($```"<50$`$````!Y6`0`+````+U8!``P````[5@$`$```
M`$A6`0`1````658!`!````!K5@$`"@```'Q6`0`4````AU8!`!@```"<5@$`
M&````+56`0`3````SE8!`!H```#B5@$`)````/U6`0!H````(E<!`!````"+
M5P$`"0```)Q7`0`5````IE<!``D```"\5P$`!0```,97`0`%````S%<!`!,`
M``#25P$`$0```.97`0`1````^%<!`!@````*6`$`$@```"-8`0`N````-E@!
M`"\```!E6`$`,````)58`0`O````QE@!`#,```#V6`$`,@```"I9`0`6````
M75D!`$,```!T60$`&P```+A9`0`:````U%D!`!H```#O60$`&0````I:`0`)
M````)%H!`!T````N6@$`'````$Q:`0`:````:5H!`!D```"$6@$`&@```)Y:
M`0`<````N5H!`!L```#66@$`+@```/):`0`.````(5L!``<````P6P$`#P``
M`#A;`0`M````2%L!`!(```!V6P$`%P```(E;`0`9````H5L!`!8```"[6P$`
M%0```-);`0`1````Z%L!`!T```#Z6P$`)````!A<`0`2````/5P!`!L```!0
M7`$`&0```&Q<`0`7````AEP!`!@```">7`$`!````+=<`0`6````O%P!``0`
M``#37`$`!P```-A<`0`/````X%P!`"````#P7`$`!@```!%=`0`'````&%T!
M``8````@70$`!@```"==`0`'````+ET!``0````V70$`!P```#M=`0`5````
M0UT!``8```!970$`!0```&!=`0`&````9ET!``<```!M70$`!0```'5=`0`,
M````>UT!``T```"(70$`"@```)9=`0`*````H5T!``H```"L70$`&````+==
M`0`%````T%T!`"4```#670$`$@```/Q=`0`-````#UX!`!$````=7@$`$```
M`"]>`0`,````0%X!`!$```!-7@$`*P```%]>`0`(````BUX!``@```"47@$`
M"@```)U>`0`*````J%X!``\```"S7@$`!@```,->`0`+````REX!``T```#6
M7@$``P```.1>`0`?````Z%X!``H````(7P$`"0```!-?`0`/````'5\!``T`
M```M7P$`&@```#M?`0`/````5E\!``<```!F7P$`!````&Y?`0`%````<U\!
M`!T```!Y7P$`!@```)=?`0`#````GE\!`!(```"B7P$`$````+5?`0`'````
MQE\!``<```#.7P$`!0```-9?`0`-````W%\!``D```#J7P$`#````/1?`0`<
M`````6`!`!H````>8`$`%0```#E@`0`:````3V`!``D```!J8`$`$@```'1@
M`0`,````AV`!``@```"48`$`$0```)U@`0!!````KV`!``L```#Q8`$`#```
M`/U@`0`D````"F$!`!@````O80$`&0```$AA`0`3````8F$!``T```!V80$`
M#@```(1A`0`*````DV$!``T```">80$`&@```*QA`0`5````QV$!`!T```#=
M80$`)@```/MA`0`(````(F(!``@````K8@$`#0```#1B`0`,````0F(!``P`
M``!/8@$``P```%QB`0`%````8&(!``4```!F8@$`#P```&QB`0!#````?&(!
M`!4```#`8@$`"@```-9B`0`#````X6(!``4```#E8@$`%````.MB`0`4````
M`&,!`!0````58P$`"@```"IC`0`"````-6,!``0````X8P$`(````#UC`0`#
M````7F,!``4```!B8P$`"0```&AC`0`*````<F,!``0```!]8P$`!0```()C
M`0`0````B&,!`!(```"98P$`!@```*QC`0`'````LV,!``D```"[8P$`!```
M`,5C`0`%````RF,!`&,```#08P$`#@```#1D`0`1````0V0!``0```!59`$`
M#0```%ID`0`A````:&0!`#\```"*9`$`$````,ID`0`(````VV0!``\```#D
M9`$`"0```/1D`0`(````_F0!`!T````'90$`)@```"5E`0`D````3&4!`",`
M``!Q90$`$0```)5E`0`%````IV4!``<```"M90$``P```+5E`0`&````N64!
M``H```#`90$`$P```,ME`0`%````WV4!`$@```#E90$`%0```"YF`0`*````
M1&8!``L```!/9@$`)P```%MF`0!,````@V8!``8```#09@$`!@```-=F`0`'
M````WF8!``H```#F9@$`!````/%F`0`)````]F8!`",`````9P$`(@```"1G
M`0`%````1V<!``@```!-9P$`)@```%9G`0!@````?6<!`!(```#>9P$`)P``
M`/%G`0`8````&6@!``,````R:`$`#````#9H`0`%````0V@!``X```!):`$`
M#````%AH`0`*````96@!``@```!P:`$`!@```'EH`0`*````@&@!``D```"+
M:`$`!0```)5H`0`*````FV@!``L```"F:`$``P```+)H`0`/````MF@!`!(`
M``#&:`$`$@```-EH`0`*````[&@!``D```#W:`$`"0````%I`0`+````"VD!
M``H````7:0$`"P```")I`0`(````+FD!`"$````W:0$`"P```%EI`0`'````
M96D!``@```!M:0$`#@```'9I`0`'````A6D!``\```"-:0$``@```)UI`0`'
M````H&D!``4```"H:0$`!0```*YI`0`(````M&D!`!(```"]:0$`$@```-!I
M`0`5````XVD!`!4```#Y:0$`%`````]J`0`2````)&H!`!<````W:@$`(```
M`$]J`0`:````<&H!``(```"+:@$`!````(YJ`0`.````DVH!``T```"B:@$`
M!P```+!J`0`<````N&H!``T```#5:@$`$P```.-J`0`(````]VH!``X`````
M:P$`!P````]K`0`2````%VL!``D````J:P$`!P```#1K`0`'````/&L!``0`
M``!$:P$`!````$EK`0`%````3FL!`$,```!4:P$`.@```)AK`0`2````TVL!
M`"L```#F:P$`.````!)L`0`.````2VP!`"D```!:;`$`,0```(1L`0`V````
MMFP!`#8```#M;`$`.P```"1M`0`*````8&T!`"<```!K;0$`&````)-M`0`8
M````K&T!`!@```#%;0$`&````-YM`0`0````]VT!`!0````(;@$`&````!UN
M`0`G````-FX!`"<```!>;@$`*P```(9N`0`H````LFX!`"D```#;;@$`)@``
M``5O`0!@````+&\!`!P```"-;P$`"0```*IO`0`'````M&\!`"8```"\;P$`
M*@```.-O`0`@````#G`!``D````O<`$`0P```#EP`0!&````?7`!``<```#$
M<`$`&0```,QP`0`<````YG`!``T````#<0$`#P```!%Q`0`5````(7$!``8`
M```W<0$`$````#YQ`0`/````3W$!``L```!?<0$`$P```&MQ`0`-````?W$!
M``\```"-<0$`!@```)UQ`0`D````I'$!``4```#)<0$`!````,]Q`0`/````
MU'$!``P```#D<0$`#````/%Q`0!`````_G$!``0````_<@$`!0```$1R`0`0
M````2G(!``\```!;<@$`!````&MR`0`4````<'(!``0```"%<@$`!0```(IR
M`0`]````D'(!`!D```#.<@$`.````.AR`0!=````(7,!`!$```!_<P$`10``
M`)%S`0`?````UW,!``\```#W<P$`"@````=T`0`2````$G0!`!`````E=`$`
M!P```#9T`0`.````/G0!``D```!-=`$`%@```%=T`0`<````;G0!``4```"+
M=`$`#@```)%T`0`.````H'0!`!T```"O=`$`$````,UT`0`4````WG0!`!$`
M``#S=`$`(P````5U`0`(````*74!``H````R=0$`#P```#UU`0`.````374!
M``8```!<=0$`$@```&-U`0`8````=G4!``L```"/=0$`"@```)MU`0`(````
MIG4!``4```"O=0$`'@```+5U`0`&````U'4!``\```#;=0$`"````.MU`0`.
M````]'4!``8````#=@$`#0````IV`0`M````&'8!``T```!&=@$`!P```%1V
M`0`'````7'8!`!X```!D=@$`"````(-V`0`0````C'8!``,```"==@$`$P``
M`*%V`0`(````M78!``4```"^=@$`'@```,1V`0`M````XW8!``0````1=P$`
M#0```!9W`0`0````)'<!``0````U=P$`#P```#IW`0`*````2G<!``<```!5
M=P$`"P```%UW`0`(````:7<!``P```!R=P$`#0```']W`0`>````C7<!`#$`
M``"L=P$`-@```-YW`0`?````%7@!`"0````U>`$`(P```%IX`0`_````?G@!
M`!\```"^>`$`(0```-YX`0`H`````'D!`"$````I>0$`!P```$MY`0`(````
M4WD!``D```!<>0$`"````&9Y`0`9````;WD!`!D```")>0$`,P```*-Y`0`J
M````UWD!`"T````">@$`,@```#!Z`0`&````8WH!`!L```!J>@$`!P```(9Z
M`0`(````CGH!`!\```"7>@$`$0```+=Z`0`.````R7H!``P```#8>@$`!0``
M`.5Z`0`1````ZWH!``@```#]>@$`$@````9[`0`,````&7L!`!@````F>P$`
M,0```#][`0`*````<7L!``4```!\>P$`!0```()[`0`:````B'L!``P```"C
M>P$`!@```+![`0`6````MWL!`!0```#.>P$`#0```.-[`0`-````\7L!`!4`
M``#_>P$`#@```!5\`0`$````)'P!``4````I?`$`#0```"]\`0!(````/7P!
M`&,```"&?`$`$P```.I\`0`?````_GP!`!D````>?0$`#0```#A]`0`/````
M1GT!``L```!6?0$`$@```&)]`0`L````=7T!``,```"B?0$`"0```*9]`0`*
M````L'T!``\```"[?0$`"P```,M]`0`R````UWT!``,````*?@$`&@````Y^
M`0`-````*7X!`!,````W?@$`)P```$M^`0`,````<WX!``<```"`?@$`$```
M`(A^`0`5````F7X!``@```"O?@$`$0```+A^`0`'````RGX!`!H```#2?@$`
M)@```.U^`0`*````%'\!``,````??P$`$@```"-_`0`.````-G\!`!4```!%
M?P$`!0```%M_`0`'````87\!`!$```!I?P$`"P```'M_`0`+````AW\!`!$`
M``"3?P$`$0```*5_`0`)````MW\!``@```#!?P$`-````,I_`0`N````_W\!
M`"X````N@`$`"````%V``0`1````9H`!``8```!X@`$`%P```'^``0`<````
MEX`!`!X```"T@`$`#@```-.``0`*````XH`!``,```#M@`$`"````/&``0`+
M````^H`!``,````&@0$`#`````J!`0`4````%X$!``L````L@0$`&````#B!
M`0`;````48$!`!<```!M@0$`!0```(6!`0`*````BX$!`!0```"6@0$`#@``
M`*N!`0`/````NH$!``8```#*@0$`"0```-&!`0`2````VX$!`$X```#N@0$`
M'0```#V"`0`%````6X(!``4```!A@@$`#P```&>"`0`-````=X(!``\```"%
M@@$`&P```)6"`0`1````L8(!`!````##@@$`(````-2"`0`?````]8(!``\`
M```5@P$`;@```"6#`0`<````E(,!`!4```"Q@P$`)@```,>#`0`;````[H,!
M`!0````*A`$`&````!^$`0`6````.(0!`!P```!/A`$`$P```&R$`0`*````
M@(0!``<```"+A`$`"P```).$`0`%````GX0!`!<```"EA`$`#0```+V$`0`?
M````RX0!``8```#KA`$`2@```/*$`0`Q````/84!`$0```!OA0$`8P```+2%
M`0`'````&(8!`#0````@A@$`*````%6&`0`&````?H8!``H```"%A@$`"0``
M`)"&`0`R````FH8!``8```#-A@$`6P```-2&`0`K````,(<!`"4```!<AP$`
M#P```(*'`0`P````DH<!`!\```##AP$`)P```..'`0`A````"X@!`"<````M
MB`$`(P```%6(`0`0````>8@!``<```"*B`$`%P```)*(`0`5````JH@!``\`
M``#`B`$`!@```-"(`0`O````UX@!``P````'B0$`!@```!2)`0`$````&XD!
M`!`````@B0$`"````#&)`0`%````.HD!``L```!`B0$`"````$R)`0`(````
M58D!``,```!>B0$`#````&*)`0`/````;XD!`!\```!_B0$`'0```)^)`0`/
M````O8D!`!8```#-B0$`#P```.2)`0`&````](D!`!(```#[B0$`%@````Z*
M`0`-````)8H!``P````SB@$`&0```$"*`0`G````6HH!``\```""B@$`(@``
M`)**`0`K````M8H!`!$```#AB@$`#@```/.*`0`<`````HL!``<````?BP$`
M$````">+`0`4````.(L!``L```!-BP$`"@```%F+`0`*````9(L!``<```!O
MBP$`"0```'>+`0`(````@8L!``D```"*BP$`#@```)2+`0`.````HXL!``4`
M``"RBP$`#P```+B+`0`,````R(L!``P```#5BP$`#0```.*+`0`:````\(L!
M``L````+C`$``P```!>,`0`$````&XP!``8````@C`$`"````">,`0`&````
M,(P!`%0````WC`$`*````(R,`0`S````M8P!`!4```#IC`$`!0```/^,`0`$
M````!8T!``H````*C0$`"@```!6-`0`'````((T!``H````HC0$`%0```#.-
M`0`,````28T!``H```!6C0$`#````&&-`0`(````;HT!``8```!WC0$`!P``
M`'Z-`0`&````AHT!`!4```"-C0$`"0```*.-`0`%````K8T!``<```"SC0$`
M(@```+N-`0`&````WHT!`!4```#EC0$`&````/N-`0`+````%(X!``<````@
MC@$`$P```"B.`0`3````/(X!``8```!0C@$`$P```%>.`0`*````:XX!``@`
M``!VC@$`!@```'^.`0`(````AHX!`!````"/C@$`&````*".`0`(````N8X!
M``H```#"C@$`#P```,V.`0`%````W8X!``P```#CC@$`$````/".`0`+````
M`8\!``,````-CP$`#0```!&/`0`'````'X\!`"P````GCP$`*@```%2/`0`Y
M````?X\!`"0```"YCP$`+0```-Z/`0!?````#)`!`!````!LD`$`5P```'V0
M`0`U````U9`!`%H````+D0$`4P```&:1`0`>````NI$!`$(```#9D0$`(```
M`!R2`0`C````/9(!`"$```!AD@$`%0```(.2`0`_````F9(!`-(!``#9D@$`
M%````*R4`0`0````P90!`$$```#2E`$`>0```!25`0`Q````CI4!`#P```#`
ME0$`4P```/V5`0!/````498!`!H```"AE@$`$````+R6`0`6````S98!`!D`
M``#DE@$`(P```/Z6`0`A````(I<!`"(```!$EP$`&@```&>7`0`0````@I<!
M`#,```"3EP$`'0```,>7`0`A````Y9<!`!P````'F`$`+@```"28`0!=````
M4Y@!`#D```"QF`$`6P```.N8`0!$````1YD!`#(```",F0$`/@```+^9`0`R
M````_ID!`%`````QF@$`;P```(*:`0!=````\IH!`%$```!0FP$`-````**;
M`0`@````UYL!`"$```#XFP$`(P```!J<`0!O````/IP!`&D```"NG`$`OP``
M`!B=`0`7````V)T!`"````#PG0$`/````!&>`0`\````3IX!`#L```"+G@$`
M)0```,>>`0!%````[9X!`!8````SGP$`!@```$J?`0#%````49\!`$$````7
MH`$`(P```%F@`0`P````?:`!`"(```"NH`$`'````-&@`0`R````[J`!``T`
M```AH0$`"````"^A`0`%````.*$!``P````^H0$`#````$NA`0`,````6*$!
M``L```!EH0$`!@```'&A`0`2````>*$!``0```"+H0$`3@```)"A`0`%````
MWZ$!`!0```#EH0$`!````/JA`0`'````_Z$!``4````'H@$`!0````VB`0`#
M````$Z(!`!(````7H@$`"0```"JB`0`2````-*(!`!$```!'H@$``@```%FB
M`0`%````7*(!``<```!BH@$`$P```&JB`0`,````?J(!`!<```"+H@$`!@``
M`*.B`0`1````JJ(!``T```"\H@$``P```,JB`0`R````SJ(!``0````!HP$`
M!@````:C`0`'````#:,!`!P````5HP$`+0```#*C`0`N````8*,!`"\```"/
MHP$`$P```+^C`0`>````TZ,!`!<```#RHP$`&P````JD`0`>````)J0!`!D`
M``!%I`$`&@```%^D`0`>````>J0!`!8```"9I`$`*0```+"D`0`?````VJ0!
M`"<```#ZI`$`%P```"*E`0`;````.J4!`!T```!6I0$`&````'2E`0`D````
MC:4!`"8```"RI0$`)P```-FE`0`7`````:8!`!@````9I@$`'````#*F`0`B
M````3Z8!`!<```!RI@$`'@```(JF`0`:````J:8!`#X```#$I@$`)`````.G
M`0`G````**<!`"H```!0IP$`*P```'NG`0`E````IZ<!`!L```#-IP$`(```
M`.FG`0`=````"J@!`#`````HJ`$`'0```%FH`0`*````=Z@!`!8```""J`$`
M$@```)FH`0`H````K*@!`!T```#5J`$`#0```/.H`0`/`````:D!`!D````1
MJ0$`$````"NI`0`;````/*D!`#$```!8J0$`"````(JI`0`*````DZD!`"(`
M``">J0$`)@```,&I`0`E````Z*D!`!D````.J@$`!P```"BJ`0#"````,*H!
M`!H```#SJ@$`%0````ZK`0`(````)*L!``P````MJP$`%````#JK`0`:````
M3ZL!``4```!JJP$`-0```'"K`0`4````IJL!`!0```"[JP$`!P```-"K`0`*
M````V*L!``H```#CJP$`0````.ZK`0`E````+ZP!`!(```!5K`$`%0```&BL
M`0`/````?JP!`#(```".K`$`#0```,&L`0`.````SZP!``\```#>K`$`&```
M`.ZL`0`*````!ZT!``\````2K0$`!0```"*M`0`?````**T!``H```!(K0$`
M'P```%.M`0`(````<ZT!`!4```!\K0$`!P```)*M`0`(````FJT!``H```"C
MK0$`.P```*ZM`0`%````ZJT!``T```#PK0$`"@```/ZM`0`0````":X!``8`
M```:K@$`"@```"&N`0`'````+*X!`!(````TK@$`#````$>N`0`=````5*X!
M`!,```!RK@$`'@```(:N`0`R````I:X!``4```#8K@$`!@```-ZN`0`<````
MY:X!``0````"KP$`*@````>O`0`0````,J\!``4```!#KP$``P```$FO`0`,
M````3:\!`!<```!:KP$`"P```'*O`0`#````?J\!``H```""KP$`"````(VO
M`0`+````EJ\!``X```"BKP$`#P```+&O`0`1````P:\!`!(```#3KP$`"@``
M`.:O`0`P````\:\!`!L````BL`$`&````#ZP`0`*````5[`!`$@```!BL`$`
M"````*NP`0`6````M+`!`$(```#+L`$`%`````ZQ`0`/````([$!``D````S
ML0$`!````#VQ`0`&````0K$!`!8```!)L0$`&@```&"Q`0`'````>[$!``@`
M``"#L0$`"````(RQ`0`"````E;$!``D```"8L0$`"P```**Q`0`%````KK$!
M`!H```"TL0$`)@```,^Q`0`5````]K$!`!X````,L@$`$0```"NR`0`"````
M/;(!``0```!`L@$`#P```$6R`0`&````5;(!``4```!<L@$`!````&*R`0`4
M````9[(!`$D```!\L@$`$0```,:R`0`E````V+(!`"\```#^L@$`6````"ZS
M`0`1````A[,!`&D```"9LP$`'P````.T`0`\````([0!`"8```!@M`$`.0``
M`(>T`0`N````P;0!`"<```#PM`$`-0```!BU`0`Q````3K4!`#$```"`M0$`
M-0```+*U`0`M````Z+4!`!\````6M@$`-@```#:V`0`:````;;8!``X```"(
MM@$`#````)>V`0!S````I+8!``8````8MP$`=0```!^W`0!J````E;<!`"L`
M````N`$`$````"RX`0`6````/;@!``L```!4N`$`&@```&"X`0`U````>[@!
M`!L```"QN`$`%0```,VX`0!7````X[@!`!<````[N0$`"@```%.Y`0`%````
M7KD!``8```!DN0$`"````&NY`0`%````=+D!`!0```!ZN0$`$````(^Y`0`6
M````H+D!`"````"WN0$`"P```-BY`0`(````Y+D!``0```#MN0$`"@```/*Y
M`0`+````_;D!``@````)N@$`!P```!*Z`0`7````&KH!``8````RN@$`!@``
M`#FZ`0`7````0+H!``L```!8N@$`!P```&2Z`0`2````;+H!``@```!_N@$`
M%P```(BZ`0`-````H+H!``T```"NN@$`!@```+RZ`0`&````P[H!``\```#*
MN@$`!P```-JZ`0`%````XKH!`!0```#HN@$``@```/VZ`0`$`````+L!``P`
M```%NP$`"0```!*[`0`B````'+L!``(````_NP$`$@```$*[`0`8````5;L!
M``L```!NNP$`!0```'J[`0`,````@+L!``H```"-NP$`#P```)B[`0`6````
MJ+L!``4```"_NP$`#0```,6[`0`G````T[L!``X```#[NP$`#P````J\`0`0
M````&KP!``4````KO`$``@```#&\`0`+````-+P!``$```#C````J0$``%L`
M``!0`0``N`(``"$%```W!@``#0,``%`#``#U!0```````#X&``#O!0``7```
M````````````:0,``"`$``!6!0``NP4``$D!```J`0````````````"<`@``
MI@4```````#W````U@4``'<$````````W`0``,(%``"P````%P$``#D$``#;
M!```-0```!H&``"0````10$``!@!``"*`0``4`4``)4$``"C````````````
M```R`0```````"X"`````````````',!`````````````&,&````````````
M`````````````````#(```!Z!0``4@0`````````````:@$``#P$```G!```
M`````%L!``!Q!0```````"X&``#L!0``808``/<!``!Q`0``````````````
M````#P$``'<"``#``0``:P,``````````````````"X%````````:P0``"X`
M``#V!```4P,``(\```!K!0`````````````D`P``%@(```````"1````0P$`
M`%4!``#Z`0``````````````````40(``(T%``"E`P```````/$```!M`@``
M608``'\"````````6@,``(@#```V!@``S`$`````````````BP(````````G
M````B`$``!H#``"@`@``2P$``'````!R!```;P$```````"V`P```````"@!
M``#Z!0``&0$``*P!````````6`,``%D#``!:!0``U@0``#4%```.````<`0`
M`$P"````````*P$```4%``##`@``2@8``#,#``!'````VP$``%H!``#[!```
M3@```.8```!F!@````$```````#7`@``P@,``"8%``!C`@``:00``(@%````
M`````````/4"``#\!```PP,``!H"````````>@0``!8%```;````7P0``"P`
M``"%!0``R00``,\!```R!@``F`8``-`"````````OP``````````````*0(`
M``````!Y`@``HP0```````!Q`````````+\"``"7`````````#H```!Z!@``
M9````)<%````````F`4````````$!```FP4``"\````&`P```````(H```#@
M!0``R````$T``````````````"$"``"^!`````````````""`0``GP$`````
M``"^````#P(``,0"````````#@(``)8&```!!````@8```````!<`@``1`8`
M``````!4`P``!0```"4!```[`0```````&@#``#7!0```````#X`````````
M30$``&4#````````R`4```````"H`P```````+<$```+!```````````````
M````3P0``(0"``!+`P```````#X!````````700``'`!``"Q!````````'P!
M```U`P```````/L"``#P`@``]P0``,@"``"=`````08````````H`P``N0``
M`,0%``#/`@``[@$``-X!```M`P``P`4``&\`````````JP0``%(&``#$!```
M&0```#@%````````P`,``"`"```U`@```````$<"``!Q!````````)T#```-
M!0``1@0``%H$``"I!`````````4#``"B`@``8P,``'T"``!E!```=P,`````
M``!X`P``%`,``,H"``"R!```?`8``"8!``#:`@``*`4``+H%``!<!```````
M``````#!````G@```&4!````````Z@(``$$&``"[`@```````+L!``!4````
M`P0``,X!````````)P(``$<%``#I!````````-P!``````````````````!.
M`@```````/0```!`!````````#8!``!V`@``?08```````#&`0``````````
M```8!```6P4``)<!``#2`0``>``````````<````.P,``.$!``"=!```,`4`
M`````````````````.@"``!#!@````````4$````````9`8``-@!````````
MC@,````````5`P````````````!U!```?0```&L"``"A!```P@```!`&``"%
M!```B@0```````"(!@``/P$```````!9`0```````(`"``#@`0``A0$``/8!
M```#`@``=`,``*X%``"L`P``YP$``-8````,`@``V00``$,`````````B0,`
M`$T#``#,`@``@`,```($```5!0``)04``)$$`````````````)8"``#7`P``
MJP(``-P%``"4!@``8````*0"``#`!```0P,``*H$````````%P,````````0
M`0``JP,``'D````)````F@4`````````````@``````````G!0``/04``%L"
M``"A!0``L`$``$0````K````.@(``%<"``!E!0``\00``+\%``!J!0``Q0``
M`&X#```+`@``1@8````````.!```.@0``.<`````````]0,``(P#````````
M!`$````````!`@``-P4```````"I````6`8``!(%````````+08``&(%````
M````:@```-0```#[!0```````(4#```9!@``"`,`````````````````````
M``")!@``TP$``!0```#0!`````````````!_!0``:@0``/<#``#[`P``````
M`(<$``#,!0``$0$``#X%````````?P$````````L`@``(08``!,```#N!```
M4@4``*X$``":`@``M`$``"\&````````W04``"(````L`P``7`,``$X$````
M````Q`,``!P$````````)@```-<$````````C`8```````"]````D@0``$L"
M```N`P```````/8#``!_`P``A`4``*`%``!K!@``X`,``'X#```9`P``````
M`/0"``#F!0``RP(```````!3`@````````<%``""!```(0,``!<%```I!@``
M5`8```````"G`````````.D"``"W`0``D0(``)$%````````V@```&$````4
M!@````8``&H"```.`0``TP(``.(```#]!```3````.$````P`@```````)T"
M````````X0(``'`&```E`@``VP```#4$``".!@``$0,``+<%``![````L`0`
M``````#[`0``Y`0``,4"``!4`@```````)L!``!\`@``ZP(```````#H`P``
M```````````,!@```````````````````````+0%```A!`````````````!+
M`````````/@$```.`P`````````````Y!0``H@,``!<$``#.!0``[`0``-T`
M``#(`0```````-4$```R!0``C0```%8$``"``0``R`0``($!``!.`0``;@$`
M`/@!``"?!0``'P,```````"$````7P```'0!``!-!```,08``.H$````````
M(@4``/,$````````!P,``'T#``#*`P``LP0```````!8`@``LP```,T!``!F
M!```-@(```<"``!S!@``]@4``-`#``!2`P````````````"$!````````%D`
M``!?!@```````&`%``````````````````#[````.`$``!\&```[!@``104`
M`,<%``"A`0``"P8``*(!```S`@``&P4```````"J````.08``/`#```F`P``
MXP(`````````````G`4``,8#``#4`P``@@4``!,#``#Q`0``0`4``,H%``"7
M!````````"P!``!-`@``-0$``$L&```Q`@````````````"F!```\0(``&H#
M``#9`@``?`4``*X```";!```L@4````````>!```?`,``*($``"-!```````
M`)P!````````<P(``.T#``!``````````#`#``#9!0``F0,```````!/````
MA@(```P````]!@``,P$```````!,!```G04``,H```!N!```<@$``-0"``![
M`0``!`,``&`"``!(!```U@,``,P$```O`0```````.P`````````1`4``&@&
M``"5!@``P@0``/`$```M`0``WP4```````!L!````````#P#````````,P4`
M`.8$``#>````WP(``%$%``!"!```F`````````#J`P``*@(``/0!````````
M?04``&8"``">!0``*`(``*0%````````1`(``(P!``"$`0``7@(``+P$```4
M`@``!`8``'T$``!P`@``[@4``)8$``"'`@```````/(%`````````````"P$
M````````*@8``#T$``!@!```<@4``!H```#^`P``Y@$`````````````````
M````````````500````````2!```;`$``(8&```:!0```````-4%``"^!0``
M``````````!$!```-@0``(L```"?````Q`$````````)!@``%P````H%````
M````W@,``%`"```W`@``JP$``-$$``#]`@``PP0```H&``!G!@``/0$``!L&
M````````.P0``````````````````+4!```0`@````````(```!A!```````
M`/\$``#)!0```````(\"``!M!@``0@8``*4$``")``````,``(X!````````
M`````/,```"3!```D@4``&("`````````````&8%```C!@``_P````````"T
M`@``-@```#D!``".!````````$<$`````````````````````````````+H$
M``#>`@``C@````````#5`0``10,```<``````````````(T#```=`0``(`,`
M`"T```"0`P```````,L#``!_````/P8``+8$``!@`0``F@,``'H#``"&!0``
MAP```(@`````````M0,``)`$``!@!@```````#H!`````````````)`"``!)
M`P``DP8``!$%`````````````'8```">`@``E````&0!``#Z````U`0```L#
M```#````P@(``)`%``"X`0``#`,``$H`````````?@(`````````````:`0`
M`'0`````````>P(``"4$````````6P8``.$#```=!@```````%T&```5!@``
M=`0``-($``#!`0``%@8``&X%``#L`P``GP,``-D!````````9`(``&4````Q
M`P``'@$``)D!``#N`@``\@(````````[!0```````*D#``!^!@``.P(``$L%
M``#H!````````%,&````````9P0```@!``!/`P``?@0``*\"````````5P$`
M`#X#```-`@```````,\%``!F`0``,04```````#^`@``8@0``&4&````````
M50````````#?!```-````$$```!1`P````````````!T`@``1P,``.H```"-
M`0``^`,````````0!0``````````````````T0```#<!```D!0``D`$``-4`
M``!Q`P``:08``-,$```5!````````*\%``!"!0```````.L!```8!0``OP$`
M`)D&````````?P8``)4%``#K``````````(!```?!```YP0``'4!``"H!```
M``````````!D!```!0$``!T"````````=0,``+(`````````@0(```````!3
M````[P$``$0!``"#`@``=08``$@"``"O!```S@,``"`!`````````````+T$
M``#Y!````````"0"``#X!0```````.,%``!C`0``BP4``.X```#J`0``OP0`
M`"D%```2`@``!08``+<#````````C08``&P&``"9!0``B@(```P%````````
M_0,```````"Q````:`4```````"\````R`,`````````````N04```````#=
M`@``L04``,L$````````*P0``&<%``#!!```(P4```````!N````%P(`````
M````````6@```.D`````````\@```+(!``!``0``'00`````````````A@,`
M`.`````[````J`(``,````#$`````````#D`````````$P4``*`#```>!0``
M^```````````````H`0```````!>`0``+@0``,D#```Q`0``8@```#\%```2
M````8@8```````#6`@``3`8``.`$``!=`P```````!$````\````2@0``-,#
M````````IP4`````````````=P4``.$%````````>08``#D"````````70``
M`&T%````````;0```-8!````````U`$``.4$```````````````````'`0``
M`````.4```!7!0``A0`````````J`P``5P````````#^!0``E0(``/D#````
M`````````%$&```@!0``Z````+P"``"D`0``M04```H```">!```T`$`````
M``"L`@```````+L#``#T`P``-P,`````````````6P,``.<"``#;`P``9`,`
M`"D#```T!0``X@(``+4$``#\`0``(````#($``"X!0``]@```*P```"/`0``
M<`4````````/!0`````````````9!0``$P(```````!0````IP(```````!=
M!0````````````#!`@``>P0``.\"````````HP$``!D$``#S`0````4``'4`
M``"3````O`$```````"2`P``-`0``(0&````````&P$``,H$``##`0``(P``
M``````"I!0``4@$```````!*!0``$00``)0%``!U!0````````````!0!```
M*P8``"4&``"#`P``OP,```T$``"C!0```````)(&````````Y`(``*8!``"M
M!````````'@&``"T!```E`(```,%```-````00(``#0&`````````````"0`
M``!E`@``F@8```````!I!0``C@4``(("```?`@``$P8```````#*`0``````
M````````````@`8``'4"``!7!@``KP,``,T%``!Z`0``=@4```````!I`@``
M@@,``(,`````````H0,```````"O`````````+P%``#%`P```````/\%``"7
M!@``"@(```````!%`@```````+X#``!N!@``Y0(```8%````````D@$``.H%
M```P!```"P```)@"````````\````(L#``!&`P``B@4```````"]!0``7`8`
M`(0#```#`P``V0,``$`"```(`````````)@#````````K0(```0"``"\`P``
M````````````````9P`````````I`0``:`$``,P#````````,0```-T!``!,
M!0``'@````````!M`P``D@```%4&```X````&`(``%<$```)`@``<@(`````
M```````````````````O!```J@4``.L%``",`@````````````!-!0``400`
M`#<````;`P``208````````K`P``3P4``!L"``"M`P``0P(``&\$``!=`0``
M=@8``+H"``!V`P```0$``'P$``````````````````#>!`````````````!R
M!@``%0``````````````L0,``!,!````````"`4``````````````````)8%
M``"1!@``FP(``,<"``#.`@``*@4``-,%````````Z`4``$8!``!X`@``M```
M`,L!``#7`0``QP```+,#``!?`@``9P(``/\"``!J!@``CP0``"H$``")!0``
M8`,```````"V`````````*0#``#S`P``*@```+4````@!@``)0````L!```D
M!@``7@4``%X&````````N@,````````K`@``_0$``!L$``#%`0```````*<$
M``!X!0``B@,````````Z!0``#P8``(\&``"T`P`````````````_!```````
M`$4$````````%@$``'X`````````P`(``.0%``"?!```<P4``.\```"`!0``
M9P$``"(!``",!0``20````````"!!```=@$``+T!``#&!````````*@````#
M`0``H0`````````5`0```````#,&````````"`(````````\`0``````````
M````````H0(``)\"```M!0``P@$``&$!````````DP$``+X"``!Y!0``````
M````````````!@```',$```:`0```````.,#````````(@,``'L#``"Q`0``
M$@8`````````````<@```&$%``",````_`(``*8````?!0``V`4`````````
M````$0(`````````````E0```!P#``#)`0``#P```$D$``!/!@``.`,``&(!
M``"%`@``0@,``&P#``"+`0``,P```'0%``!>`P``/P```#H&````````^@(`
M`+@#``!+!```5@,``,T```!1`0``0`,```````!\````=@0``-P#````````
M``````D$``"P`P``Z04``,L``````````````*(`````````+P4``*4!````
M`````````)@$``#0!0``<P,``,<!```4!0``L`4``+D!``#B!````````&X"
M``!"`@````````````#2````,@(``.T%```X`@``204``$@!``!!`0``2```
M`)H```!7`P``%0(``%\!``#&!0``K@,``),#````````LP$``'D!````````
M`@,``-P"``"M````Y0$``&(#```*`P``#@4``*````#\!0```````+8"``#?
M````-@4`````````````80,``!`#``#M`0``(0$```````#0````@P$``+<"
M```=!0```````)$!``"9!```)`$``%P%``!(`P``4@(``-4#````````T@(`
M````````````-08``*D"````````5`0``&\#````````)`0``.T$````````
MS@```$4&``!"````_@$``*8#````````D0,``.<#``!6!@``E`,``-$!```8
M`````````%P!```7!@``)P,```D#``"8`0``WP,```P$````````E`$``$(!
M````````1P$````````W!```V@$``!\!``!#!```(P$``+4"````````8P0`
M`.,!``!/`@```@4``,T#````````_P,```````#4!0``B0$``!T#``#F`@``
MV`,``%@%``"9````000``*L%````````N0(``$X#``!!!0``O0,``$\!``":
M`0``2`8``*P%``!G`P````````````#Y`@``IP$````````(!```E0,``!\`
M````````B00``/P``````````````)8```!A`@``\0,``/T```!#!0``>0,`
M`&L!```<!@``P04``-$%````````!P8``)D"``",!```CP,```````"3`@``
M=P```(,&``!Z`@``60(``#`````Z`P``@0```+L```![!@``_@0``#\#````
M````40```/(!``#:!```/0```#,$``!P`P``^`(`````````````B`0``&D`
M``!?!0``MP```%@$````````FP,```````"2`@``5@```'L%``!;!```````
M`+@$```A````Y`$`````````````<08```@&``!=`@``6````/,"```'!```
MI04``,\```!(!0``V`(````````4`0``I`````````">`P``<0(```D%``#K
M!```9@```*4````"`@``K0$```````!O!@```````#P&``"(`@``4`8``(,$
M````````'`4``,T"``#\`P``TP````````#?`0```````,8```"Y`P``````
M``````"6`0``,`$``$H"``!C!0``!@$``(8```!4`0``E`0```````!'!@``
MJP```"P&```<`0```````&P````-!@``T@4``"(&````````Z0$``.L#```$
M!0``;P4``%(```#B`0``X@,``````````````````'\$````````;0$`````
M``!^`0``9`4``*8"`````````````/`!````````Q@(``.(%```&!```````
M`$8"````````0`8``+,"``!T!@``SP0````````]`@``5`4``"P%``!3!```
MEP,````````C`P``(@0``"8&``#+!0``FP````````"H`0``\`4``"<&``#N
M`P``504``)T!````````G````.0#```>!@``+@$``$T&``"'!@``N@$``+8!
M````````]0$````"```6`P``````````````````J@,``+$"```G`0``AP$`
M````````````]0```````````````````*H"````````$@$``#0"````````
M`````!@#``#8`````````&T$``!*`P``=P$``+8%```H!@``[0```#@&```>
M`@``#0$``.4%``#<````3@4```$#````````-@,``,,``````````````),%
M```B`@``+0(```````!X!````````)H$````````B@8```X&```$````!@(`
M`,D`````````"P4``'@!``!8`0``7P,``+("``"6`P````````````#H`0``
M"0$``-D```#R`P``[P,``#`&``!3`0```````/\!``#Z!``````````````M
M!```Y0,``````````````````+T"```3!```;`4``!8`````````_@```,<$
M````````&@0``#D#`````````````)P$````````^0$``-(#``#%!```"@$`
M`.<%``">`0```````"@$``"'!0``I0(``+X!```O`@`````````````>`P``
M]P4``(8$````````[`(````````T`0``?@4```````"D!``````````$````
M````C0(``&@"``!>````<@,``-L%```0!```50(``!$&```/`P``W00``(,%
M``!:`@``Y@,``&P"```R`P``)@0``*,"`````````````*\!````````XP0`
M`","``#:!0`````````````%`@``A08``/D%``##!0```````#X$``#5`@``
MBP8``+L$``#)`@```````($%``#Q!0```````#$$```K!0``6@8``+`"````
M`````````````````````````/<"``#]!0````````````!>!```5@$``"D`
M````````@@```$X&```&!@``]00``&L```#1`@``1@4```,&``".`@``&0(`
M`#\"````````:0$``)P#```6!````````#@$``"G`P``J`4````````8!@``
M``````````"!`P``S````$H!``!$`P````````````"`!```'`(``$P!``!S
M`````````)4!``")`@````````````#1`P```````*H!``!W!@``604``,X$
M``#@`@``V@,``*P$````````H`$``((&```*!```V`0```\$````````\@0`
M`!T```"X`````````'T!`````````````$$#``#T!0```````(L$```T`P``
M9@,``.\$```2`P``N00```````!6`@``EP(``*T%``````````````````!5
M`P```````(\%``"&`0``600``($&```E`P``P0,``"D$``!%````\P4`````
M````````]@(``/0$``!H````SP,``-T#``#7````4P4```````#I`P``````
M`,<#``#;`@```````#P%````````;P(``/H#```]`P``/`(``"8"``"S!0``
M`````.$$``!Y!```AP,``'H````4!```/@(``*(%```,`0```````-X%``!)
M`@``L@,````````H````S00``!````"Z````D`8````````C!```^0```&,`
M``#%!0``+P,``.P!`````````````*X!``#M`@``K@(``.0```!,`P``1@``
M`*,#```!!0```"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*&EN
M("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S=&5R9&%Y*0`@
M870@`"5D("5S(&%N9"`E<P`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`
M)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E<FUS
M(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@)7,`
M)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S('1O
M("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L96YD87(`)7,G
M<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"P@9W5S=&EN9R`E<R`E
M<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`#$R($AO
M=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`$$@9&%T86)A<V4@
M8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E
M<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E
M9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R
M97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@
M4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K
M97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P
M<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@
M<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R
M97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04T@4F%I;@!!32!3:&]W
M97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!4$D@240`06)O=70@=&AI<R!E
M9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E<W,@9&5N
M:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E
M871I;F<@5D93(&9I;&4N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z
M96XN`$%C8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@
M4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E
M<FUI<W-I;VX`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`061D(&YE=R!M
M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@
M4VED96)A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S
M<R!B;V]K`$%D9"!U<V5R`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D
M<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N
M<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S`$%F9VAA;FES
M=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&EG;FUE;G0Z`$%L
M;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M
M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT:7!L92!A9&1R97-S
M97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR96%D
M>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@
M4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N871E(&5M
M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E<FYA=&4@=&5X
M=#H`06UE<FEC86X@4V%M;V$`06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF
M:65D+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`
M06YS=V5R`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D80!!<'!L:6-A
M=&EO;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!
M<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<'!R;WAI;6%T92!3:7IE
M`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ
M90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V
M92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)G96YT:6YA`$%R;65N
M:6$`07)M96YI86X@*$%235-#24DM."D`07)T`$%R=6)A`$%S8V5N<VEO;B!)
M<VQA;F0`07-C:6D@07)T`$%S:6$O4&%C:69I8R!296=I;VX`07-K(&9O<B!C
M;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1E;7!T('1O(&1E;&5T92!A(&YO
M;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI
M<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T
M96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N
M="!S:&%R92X`071T<FEB=71E<P!!=6=U<W0`075S=')A;&EA`$%U<W1R:6$`
M075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D
M(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS
M:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M
M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@
M)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z
M(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T
M;R!U<&1A=&4@=7-E<B`E<P!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A
M=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&9A:6QE
M9`!!=71H96YT:6-A=&EO;B!F86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E
M:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($94
M4"!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I:F%N
M`$)/1D@@17AC=7-E<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D
M(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A
M:&%M87,`0F%H<F%I;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H
M`$)A<F)A9&]S`$)A<V5L:6YE`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N
M:6X`0F5R;75D80!":'5T86X`0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A<'!L
M:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@
M5'EP90!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI
M8VMN97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!"
M;W1S=V%N80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!)
M;F1I86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A
M<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-2
M0P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P97)T:65S+BXN
M`$-A;&5N9&%R`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`0V%N(&YO="!R97-E
M="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI
M<W1R871O<BX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`0V%N
M861A`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T
M92!F:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R
M>2X`0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE
M=&5R+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M
M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E
M<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA
M=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P
M96-I9FEE9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#871E9V]R:65S
M(&%N9"!,86)E;',`0V%Y;6%N($ES;&%N9',`0V5L;"!0:&]N90!#96QL(%!R
M;W!E<G1I97,`0V5L;"!P861D:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S
M<&%C:6YG.@!#96QL<&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R
M`$-E;G1R86P@069R:6-A;B!297!U8FQI8P!#96YT<F%L($5U<F]P96%N("A)
M4T\M.#@U.2TR*0!#97)T:69I8V%T92!$971A:6QS`$-E<G1I9FEC871E(%!O
M;&EC:65S`$-H860`0VAA;F=E`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S
M<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O
M('EO=7(@96UA:6QS+@!#:&%R`$-H96-?:R!,:6YK+BXN`$-H:6QE`$-H:6YA
M`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R861I=&EO
M;F%L("A":6<U*0!#:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M
M90!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T('-T
M>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#:')I<W1M87,@27-L86YD
M`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A
M<B!-4T]F9FEC92!T86=S`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R
M`$-L96%R('5S97(@9&%T80!#;&EC:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL
M('9I82!(5%10`$-L;W-E(%=I;F1O=P!#;&]U9',`0VQO=61Y`$-O8V]S("A+
M965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O
M<F1E<G,`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE
M8W1I;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM
M86YD(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY
M`$-O;7!U=&5R<P!#;VYD:71I;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R96YC
M97,`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L
M(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&9A
M:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@
M=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T
M;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE
M8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A8W1S('=E<F4@<W5C
M8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT:6YU
M90!#;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P>2!S96QE8W1I;VX`0V]S
M=&$@4FEC80!#;W1E(&0G279O:7)E`$-O=6QD(&YO="!01U`@96YC<GEP="!M
M97-S86=E+@!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92X`0V]U;&0@;F]T
M(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG
M;B!M97-S86=E+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S`$-O=6QD(&YO
M="!B:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC
M92X@)7,`0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`
M0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N`$-O=6QD(&YO="!D96-R>7!T
M(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O
M=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO
M="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#
M;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N
M;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO
M="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES
M=',N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES
M97)V97(N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN
M=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U
M;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U
M<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@;F]T(&-O<G)E
M8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I
M9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R971R:65V92!!
M0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@
M;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@
M<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5T
M<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO="!R979E<G0@
M8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO
M;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L
M9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD(&YO
M="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L
M9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N
M(&5I=&AE<B!U<V4@;VYE(&]F('1H92!O<'1I;VYS('1O('-A=F4@=&AE(&-O
M9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W
M('1O("5S+@!#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U
M;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA
M(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5N
M=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@82!L:6YK
M`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S`$-R96%T;W(@
M4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#
M=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!796%T:&5R`$-U
M<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S
M:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N
M`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ
M,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`0WIE8V@@4F5P=6)L
M:6,`1$0`1&%I;'D`1&%T851R964@0G)O=W-E<@!$871E`$1A=&4@4F5C96EV
M960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R
M`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!);F1E;G0`1&5F875L=`!$969A
M=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F:6YI=&EO;G,`1&5L971E
M`$1E;&5T92!'<F]U<`!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U
M<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E
M(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@<F]W`$1E;&5T
M92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN
M`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L:79E<GD@=&EM90!$96YM87)K
M`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@*&%L
M<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G
M9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O
M:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER
M96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`
M1&ER96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I
M;VYS`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES
M<&]S:71I;VX@3F]T:69I8V%T:6]N`$1J:6)O=71I`$1O(&YO="!D96QE=&4`
M1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``1&]E<R!T
M:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L
M(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`
M1&]W;FQO860`1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I
M9W5R871I;VX@87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U9W,`
M12U-86EL`$524@!%8W5A9&]R`$5D:70`161I="!";&]C:P!%9&ET($=R;W5P
M`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES
M<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO
M;G,@9F]R("5S`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT
M+BXN`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU
M<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M;W1I8V]N<P!%
M;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M
M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE
M<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU
M/P!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U
M97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O
M(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@
M;V8@>6]U<B!P970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5Q=6%T
M;W)I86P@1W5I;F5A`$5R:71R96$`17)R;W(`17)R;W(@=VET:"!E;6%I;"!M
M97-S86=E+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@
M,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%
M=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V
M97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A;F0`17AP
M86YD(%-I9&5B87(`17AP96-T960@)RDG`$5X<&5C=&5D(&)A<F4@=V]R9"!O
M<B!Q=6]T960@<V5A<F-H('1E<FT`17AP:7)A=&EO;B!$871E`$5X<&]N96YT
M`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D(')E=')I979I
M;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R
M=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@
M=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A
M:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O
M(&UO=F4@=&\@(B5S(BX`1F%I<@!&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA
M<RD`1F%R;V4@27-L86YD<P!&871A;"!%<G)O<CH`1F%X`$9E8G)U87)Y`$9E
M96QS($QI:V4`1F5E;',@;&EK93H@`$9E=R!3:&]W97)S`$9E=R!3;F]W(%-H
M;W=E<G,`1FEE;&0@;6%T<FEX`$9I:FD`1FEL92!#;W5N=#H@)7,@9FEL90!&
M:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I
M;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P
M<&]R=&5D+@!&:6QT97)S`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!1=6%R
M=&5R`$9I>"!R871I;P!&;&EP`$9L;V%T`$9O9P!&;VQD97(@)7,@9&]E<R!N
M;W0@97AI<W0`1F]N="!#;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O
M;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4048I`$9O<F5C87-T($1A
M>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B
M;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@
M<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O<F0_
M`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O<G1U;F5S
M(#(`1F]R=6US`$9O<G=A<F1S`$9R`$9R86UE<P!&<F%N8V4`1G)A;F-E+"!-
M971R;W!O;&ET86X`1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R
M96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&<F]M`$9R;VT@=&AE(`!&=6QL
M($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA;64`1V%B;VX`1V%L;&5R
M>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R871E
M("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`1V5O<F=I80!'97)M
M86YY`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=O`$=O961E;`!';V]G
M;&4@4V5A<F-H`$=R87ES8V%L90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I
M`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P
M(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P<P!'=6%D96QO=7!E`$=U
M86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T
M8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E
M82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN
M(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE
M(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R969U
M<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@075T
M:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R:71H;0!(
M87IE`$AE861E<@!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`
M2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP`$AE;'`@=7-I;F<@
M961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN
M9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#
M:71Y(%-T871E*0!(;VUE`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO;F1U
M<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!8
M34P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B
M.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+
M;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E
M<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(
M;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T
M:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA8FQE
M('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+
M;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA
M8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F
M('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E
M<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E
M('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(
M;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ
M`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!M
M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY
M(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O
M=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU
M;6]R:7-T<P!(=6YG87)Y`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z
M("5S`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I
M;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S`$E0($%D9')E<W,`25`@
M061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@
M86QL;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$E?
M;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@9F]R
M("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES
M(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@
M;F5W('=I;F1O=RX`268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@
M26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES
M(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E
M('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N
M="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E
M<BX`26UA9V4@4')E=FEE=SH`26UA9V4@55),`$EM86=E(%523#H`26UA9V4@
M9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D
M`$EM86=E<P!);7!O<G0L(%-T97`@)60`26UP;W)T960@9FEE;&0Z("5S`$EM
M<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2;W<@069T97(`26YC;W)R96-T(&%C
M=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A
M<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E
M<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I
M9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$EN8W)E87-E($EN9&5N=`!);F1I
M80!);F1I=FED=6%L(%5S97)S`$EN9&]N97-I80!);F9O`$EN9F]R;6%T:6]N
M`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R="!);6%G90!);G-E<G0@5&%B
M;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E
M<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@
M82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@
M;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O
M=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A
M9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B969O
M<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@86QT97)N871E('1E;7!L871E
M`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C
M96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E<G0@8V5L;"!A9G1E<@!);G-E
M<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L
M=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`26YS97)T('!A<F%G<F%P:"!A
M9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R
M`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R
M('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`26YS97)T+TUO9&EF>2!);6%G
M90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F:6-I96YT(&-R961I="!T;R!S
M96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="X`26YS=69F:6-I96YT(&-R
M961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`26YV86QI9"!51$@N("A5<V5R
M($1A=&$@2&5A9&5R*2X`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B
M871C:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T
M:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@
M;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@
M;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S
M:6]N+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED('-H87)E(&]B:F5C=`!)
M;G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`
M26YV96YT;W)Y`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L
M86YD`$ES;&4@;V8@36%N`$ES;VQA=&5D(%0M4W1O<FUS`$ES<F%E;`!)<W-U
M97(`271A;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A;F5S
M92`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I
M9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*
M=7-T:69Y(%)I9VAT`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`
M2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N
M96P@3F5W8FEE<P!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,
M96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O
M;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E82P@
M1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L
M:6,@;V8`2V]R96%N("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$QA7WEO
M=70`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`
M3&%S="!(86QF`$QA<W0@475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G
M:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V
M97(`3&%T=FEA`$QA=P!,87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E
M<@!,96)A;F]N`$QE9G0`3&5F="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H
M;P!,:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I
M;@!,:6=H="!$<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,
M:6=H="!286EN($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W
M:71H(%1H=6YD97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE
M<FEC:P!,:6YK`$QI;FL@<&]I;G1S('1O.@!,:6YK('1H92!E;6%I;"!A9&1R
M97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS
M`$QI;G5X($-O;VMI90!,:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(`
M3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,
M:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/=VYE<@!,:7-T
M+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG
M('5S97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI80!,;V%D
M:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`
M3&]G(&EN`$QO9R!O=70`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U
M<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O
M<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W
M97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S`$QO=V5R(')O
M;6%N(&YU;6)E<G,`3'5X96UB;W5R9P!-30!-3U1$`$U3+51.148@071T86-H
M;65N="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI82P@
M5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-861A9V%S8V%R`$UA
M9VEC`$UA:6P`36%I;"!!9&UI;@!-86ME(&QI;E]K+BXN`$UA;&%W:0!-86QA
M>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C
M871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C
M;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T
M(&UA<`!-87!1=65S="!M87``36%R8V@`36%R9VEN`$UA<FL@=VET:"!3965N
M+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP
M;W)T86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`
M36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET:75S`$UA>"!A;&QO
M=V5D(&-R961I="X`36%X(&UE<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T
M96UP(&QA<W0@,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-
M87AI;75M(&QE;F=T:`!-87D`36%Y;W1T90!-961I8VEN90!-96UB97)S`$UE
M;G4@;6]D93H`365R9V4@8V5L;',`365S<V%G90!-97-S86=E(%9E<FEF:65D
M(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O
M=6QD(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E>'!I<F5D+@!-97-S86=E
M('1Y<&4`365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE
M+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E
M;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971H;V0`365T<FEC
M`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F`$UI9&1L
M90!-:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP
M(&QA<W0@-B!H;W5R<SH@`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI<W-I;F<@
M4$5!4B!P86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN9R!C;VYF:6=U<F%T
M:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@
M=&\@=7-E('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@;65S<V%G92!)1"X`
M36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"X`36ES<VEN9R!S
M97-S:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T90!-;V1I9FEE9"!$
M871E`$UO9&EF>2!54DP`36]D=6QU<P!-;VQD;W9A+"!297!U8FQI8R!O9@!-
M;VYA8V\`36]N9V]L:6$`36]N=&@@86YD('EE87(`36]N=&AL>0!-;VYT<V5R
M<F%T`$UO;VX@4&AA<V5S`$UO<F]C8V\`36]S=&QY($-L96%R`$UO<W1L>2!#
M;&]U9'D`36]S=&QY(%-U;FYY`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2
M:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E('5P`$UO>F%M8FEQ=64`375L
M=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S`$UU;'1I<&QE('-E;&5C=&EO;@!-
M>2!!8V-O=6YT`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM87(`
M3D\L($D@1&\@3D]4($%G<F5E`$YA;64`3F%M:6)I80!.875R=0!.97!A;`!.
M971H97)L86YD<P!.971H97)L86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E
M(%523`!.971S8V%P92!#02!2979O8V%T:6]N(%523`!.971S8V%P92!#02!P
M;VQI8WD@55),`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C
M871I;VX@55),`$YE='-C87!E(%-33"!S97)V97(@;F%M90!.971S8V%P92!C
M97)T:69I8V%T92!C;VUM96YT`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`
M3F5T=V]R:P!.979E<@!.97<@0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@
M36]O;@!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@
M=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@;W!T
M:6]N<P!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:6=H=`!.:75E`$YO`$YO
M(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E
M;F-E<R!F;W(N`$YO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E3
M3R!I;6%G97,N`$YO(&)A=&-H('1E;7!L871E+@!.;R!B;&]C:R!E>&ES=',@
M870@=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R
M;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO
M(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($94
M4"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@
M9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&9I;&4@=7!L;V%D960`3F\@:6-O
M;G,@9F]U;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;65S<V%G92!S=7!P
M;&EE9"X`3F\@;F%M92!S<&5C:69I960N`$YO(&YU;6)E<B!S<&5C:69I960N
M`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@2%144"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O
M('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN
M87)Y(&ES(&YE8V5S<V%R>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.
M;R!P96YD:6YG('-I9VYU<',N`$YO(')U;&5S`$YO('-I9&5S`$YO('1E;7!O
M<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA
M;64@86YD+V]R('!A<W-W;W)D('-E;G0N`$YO('9A;&ED(%A-3"!D871A(')E
M='5R;F5D`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L
M(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@
M=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A
M=&4@8V]N9FEG=7)A=&EO;BX`3F]N90!.;VYE("AU<V4@:6UP;&EC:70I`$YO
M<F1I8R`H25-/+3@X-3DM,3`I`$YO<F9O;&L@27-L86YD`$YO<G1H97)N($AE
M;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S`$YO<G=A>0!.;W0@
M069T97(`3F]T($)E9F]R90!.;W0@82!D:7)E8W1O<GD`3F]T(&EM<&QE;65N
M=&5D+@!.;W0@<V5T`$YO="!S=7!P;W)T960N`$YO=&5S`$YO=&AI;F<@=&\@
M8G)O=W-E+"!G;R!B86-K+@!.;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H
M87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M
M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I
M;VX@;&ES="X`3TL`3V)J96-T`$]B:F5C="!#<F5A=&]R`$]C=&%L`$]C=&]B
M97(`3V9F96YS92!F:6QT97(`3V9F:6-E`$]M86X`3VYL>2!)34%0('-E<G9E
M<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!O9F9E;G-I=F4@9F]R
M='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+@!/;FQY('1H
M92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W
M;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N
M(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT
M<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+@!/<&5N<R!T:&ES
M(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N
M<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R
M9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A
M=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R
M`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H
M96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!01U`@1&EG:71A;"!3:6=N
M871U<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3
M:6=N960O16YC<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H96QL`%!-($QI
M9VAT(%)A:6X`4$T@4VAO=V5R<P!032!3;F]W`%!-(%-N;W<@4VAO=V5R<P!0
M32!4+5-T;W)M<P!07TA0(%-H96QL`%!A9&1I;F<`4&%K:7-T86X`4&%L874`
M4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@
M3F5W($=U:6YE80!087)A9W5A>0!087)T;'D@0VQO=61Y`%!A<W-W;W)D`%!A
M<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553
M(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!0
M87-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`4&%S
M=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z
M`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E
M<FUI<W-I;VX`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R<V]N86P@
M26YF;W)M871I;VX`4&5R=0!0971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O
M<P!0:71C86ER;@!0:7AE;',`4&QA=&ET=61E<P!0;&5A<V4@8VQI8VL@:6YT
M;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R
M96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W
M86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO
M;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N
M97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N
M`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@
M;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I
M;64N`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`
M4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE
M87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I
M8W,`4&]L;',`4&]R='5G86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0
M;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@
M*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T
M("5S(&AO=7(H<RDZ(`!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I
M;VX@97AT96YS:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@
M<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM
M86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O
M8W5M96YT`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO
M;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@
M06QG;W)I=&AM`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E
M9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O`%%A=&%R`%%U97)Y`%)302!0
M=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@
M16%R;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I
M;B!T;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S
M86=E<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@
M8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E
M<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5D;V5S('EO
M=7(@;&%S="!A8W1I;VX`4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z
M`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T:6]N<VAI<"!"<F]W
M<V5R`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO
M+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`
M4F5M;W9E(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@<&%I<@!2
M96UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I
M<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE
M(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!297%U97-T
M(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!2
M97%U:7)E9"!&:65L9`!297-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R
M(%!A<W-W;W)D`%)E<W5L=',`4F5T=7)N('1O($]P=&EO;G,`4F5U;FEO;@!2
M979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`
M4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG:'0@=F%L=65S`%)O7W<@
M4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A=&4@
M3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I
M97,`4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@
M<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O
M;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL
M>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3+TU)344@0W)Y<'1O
M9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E9"!-97-S86=E`%-!
M4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A
M9VEN9P!344P@4VAE;&P`4U-(`%-50T-%4U,`4U]13"!3:&5L;`!380!386EN
M="!(96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A
M:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE
M($=R96YA9&EN97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I
M;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3
M875D:2!!<F%B:6$`4V%V90!3879E("5S`%-A=F4@3W!T:6]N<P!3879E(&=E
M;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R
M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I
M9W5R871I;VXN`%-C:65N8V4`4V5A<F-H`%-E87)C:"!%;F=I;F5S`%-E;&5C
M="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&=R;W5P('1O(&%D9`!3
M96QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S
M97(@=&\@861D`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@
M86X@;V)J96-T`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M
M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E
M('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L
M:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&ED
M96YT:71Y('EO=2!W86YT('1O(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E
M;&EM:71E<CH`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M
M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L
M96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P
M;W)T`%-E;F0@4TU3`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I
M82!A;F0@36]N=&5N96=R;P!397)I86P@3G5M8F5R`%-E<W-I;VX@240@97AP
M:7)E9"X`4V5T`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y
M;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T('5P(')E
M;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U
M<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO
M;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A
M=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE
M<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A9&4@<V-R:7!T
M<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T
M:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3:&]P<&EN9P!3:&]R="!3=6UM
M87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI
M;FMS/P!3:&]W`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@
M<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX`
M4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W(&]P
M=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H;W<@=&%B;&4@
M;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@
M;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9P!3
M:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L
M92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O<&5R
M=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W97)S($5A<FQY
M`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6:6-I;FET>0!3:')I;FL`
M4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T
M:&4@=V%Y(&9I<G-T`%-I97)R82!,96]N90!3:6=N('5P`%-I9VYA='5R90!3
M:6=N871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E
M;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=P!3;F]W(%-H;W=E<@!3;F]W
M(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO=V5R<R!,871E
M`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO
M;6]N($ES;&%N9',`4V]M86QI80!3;VYG<R`F(%!O96US`%-O<G0@;W)D97(@
M<V5L96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC80!3;W5T:"!%
M=7)O<&5A;B`H25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O
M=71H(%-A;F1W:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C
M92!B971W965N(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N
M="!A;F0@8F]R9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A
M;F0@<&%D9&EN9P!3<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T
M`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I
M($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R="!Y96%R`%-T871E(&]R
M(%!R;W9I;F-E`%-T871U<P!3=&]R86=E(&9O<FUA=`!3=')E970@061D<F5S
M<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I;B!F<F]M
M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=`%-U`%-U8FIE8W0`4W5B;6ET`%-U
M8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U
M<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S
M879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('-A=F5D
M('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C97-S9G5L
M;'D@=W)O=&4@)7,`4W5D86X`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U
M;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3
M=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`
M4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z
M97)L86YD`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R
M86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M<P!44U8@9FEL90!486)L90!4
M86)L92!0<F]P97)T:65S`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A
M;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI
M=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E
M<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!496UP97)A='5R
M93H@`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1E
M>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I("A425,M-C(P*0!4:&%I;&%N9`!4
M:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN`%1H92!&5%`@97AT96YS
M:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A
M=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="`B)7,B`%1H92!-86EN=&5N
M86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P
M=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A9&UI;FES
M=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S
M:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N<RX`
M5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A
M<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@
M:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY
M(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@9&5T86-H960@4$=0
M('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I
M9VYE9"!M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I
M=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I
M;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T
M('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A
M('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O
M;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I
M;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE
M9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H
M92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O
M<F9C.#(R(&UE<W-A9V4N`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N
M('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U
M92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R
M:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA
M>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O
M=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I
M="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L(%!R
M;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<;EQN66]U(&AA
M=F4@8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@3TL@:68@>6]U('-T:6QL
M('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N
M=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!L969T+6AA;F0@<VED
M92!O;FQY`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@
M8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G
M92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N
M(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S
M<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O
M('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;W!E
M;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S
M;6EM93HZ(&-L87-S+@!4:&4@<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B
M92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M
M(&%L;&]W86)L92!S:7IE`%1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES
M(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`
M5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@
M<VED92!O;FQY`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4
M:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S:6=N=7`@<F5Q
M=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE('-P96-I9FEE9"!R
M;W<@9&]E<R!N;W0@97AI<W0N`%1H92!T96UP;W)A<GD@9FEL92`B)7,B(&1O
M97,@;F]T(&5X:7-T+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4
M:&4@=&]P('-I9&4@;VYL>0!4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S
M:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U
M;&0@;F]T(&)E('-A=F5D+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T
M(&%V86EL86)L92X`5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4
M:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN
M92X`5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L
M9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E
M;G1E<B!L97-S('1H86X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T
M:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S
M(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L
M87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S
M*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@
M5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S
M(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`
M5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN
M(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E
M('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S
M<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R
M92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@
M4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P
M9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I
M;B!L871E<BX`5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H
M87)I;F<@9F]L9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V
M86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@
M82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@
M=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG
M(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C
M;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H
M:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@
M=&AE('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL
M('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN
M9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)
M=&%L>2!G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E
M<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H
M:'1T<#HO+W=W=RXQ.3`N:70I+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4
M:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H
M:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@
M9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T
M(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E
M<BX`5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H
M92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES
M(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N
M`%1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H
M:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@
M=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A
M(&QI<W0@;V8@<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4
M:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E
M<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A
M="!L96%S="!O;F4N`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP
M(&%N9"!G>FEP(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A
M8W1I=F%T960N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W
M:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4
M:'5N9&5R`%1I8VME=',`5&EM90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T
M`%1I;64@<V5L96-T:6]N`%1I;6]R+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L
M=&EP*3H`5&\`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@
M=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C
M;&EC:VEN9RX`5&]D87D`5&]G9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA
M=0!4;VUO<G)O=P!4;VYG80!4;W``5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA
M=&EO;G,`5')I;FED860@86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U
M;FES:6$`5'5R:V5Y`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A
M;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU`%1Y<&4@>6]U<B!C
M:&]I8V4Z(`!5+E8N(&EN9&5X.B``55),`%523"!F;W(@>6]U<B!S8W)I<'0@
M9&5L:79E<GD@<W1A='5S(')E<&]R=`!54DPZ`%5G86YD80!5:W)A:6YE`%5N
M86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E
M>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`56YA8FQE
M('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B
M;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5
M;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!3
M44P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"X`56YA8FQE
M('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C
M=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN`%5N
M86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@96UP
M='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L
M92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN
M`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M
M<'1Y`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L
M>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@
M9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&
M4R!F:6QE("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L
M92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E
M=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@
M8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI
M=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T
M;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE
M('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!T
M:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@)7,@=&\@
M)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@
M=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93
M(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S
M(BX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O
M(')E;F%M92!61E,@9FEL92X`56YA8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N
M86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T
M;R!W<FET92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4@*&-O<'DH*2!F86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@
M9&%T82X`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T
M(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O
M;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O
M.B``56YF:6QE9`!5;FEC;V1E("A55$8M."D`56YI=&5D($%R86(@16UI<F%T
M97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5;FET960@4W1A=&5S
M($UI;F]R($]U=&QY:6YG($ES;&%N9',`56YI=',`56YK;F]W;@!5;FMN;W=N
M(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G:60@
M*$-L:65N="!-97-S86=E($E$*2X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S
M=V]R9"X`56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R
M:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E
M('!R;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K
M($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H
M:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S
M('1H92!C;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($5X=&5N
M<VEO;@!5<&1A=&4`57!D871E("5S`%5P9&%T92!U<V5R`%5P9W)A9&4@<V-R
M:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@
M<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R
M<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`57-E($-U<G)E;G0Z("5S
M`%5S92!34TP`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O
M<B!)35-0('-E<G9E<BX`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@
M)7,N`%5S97(@061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G
M:7-T<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D
M(&9O<B!T:&ES('-I=&4N`%5S97)N86UE`%5S97)N86UE.@!5<V5R;F%M93H@
M`%5S97)S(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R
M>2!D;V5S(&YO="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O
M=6YD(&EN8VQU9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@
M;F]W+@!686QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R
M:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE
M<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9E
M<G-I;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG
M`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE=&YA;65S92`H5DE3
M0TE)*0!6:65W("5S`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A
M<R`E<P!6:7)G:6X@27-L86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@
M52Y3+@!6:7-I8FEL:71Y`%9I<VEB:6QI='DZ(`!6;V1A9F]N92!)=&%L>2!V
M:6$@4TU44`!705).`%=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,
M62!&4D]-("5S+@!786QL:7,@86YD($9U='5N80!787)N:6YG`%=E`%=E871H
M97(@1F]R96-A<W0`5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N
M8V]M`%=E8@!796(@4VET90!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S
M`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E3
M3RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H
M;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI
M;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_
M`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE
M(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7
M:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T
M(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N
M:70`5VED=&@Z`%=I:VD`5VEN9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@
M:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O;0!7;W)K`%=O<FL@061D<F5S<P!7
M;W)K(%!H;VYE`%@M4F5F`%@U,#EV,R!"87-I8R!#;VYS=')A:6YT<P!8-3`Y
M=C,@17AT96YD960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J96-T($%L=&5R;F%T
M:79E($YA;64`6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(`6#4P.78S
M(&5X=&5N<VEO;G,`65D`65E960!986AO;R$@;6%P`%EE87)L>0!996UE;@!9
M97,`665S+"!)($%G<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H
M92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@
M87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N(&YO="!H879E('1H92`G
M7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E
M;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N
M>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S
M<&]N9&EN9R!F:65L9',@:6X@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U
M="X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R
M+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN
M=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R
M(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E
M(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A
M(%9&4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B
M969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU
M<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO
M=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU
M<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@
M<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF
M>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U
M<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I
M;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N
M86UE+@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I
M;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S
M<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S
M(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I
M;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@
M86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@
M9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R
M92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO
M=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@
M8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R
M('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R
M(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&-U<G)E;G0@
M=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N
M86UE.@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T
M:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H
M:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9
M;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S
M(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H
M('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O
M<VQA=FEA`%IA:7)E`%IA;6)I80!::6UB86)W90!::7!P>0!;2&ED92!1=6]T
M960@5&5X=%T`6U!R;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M
M`%M3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S
M70!?061M:6YI<W1R871I;VX`7T-,20!?1&%T851R964`7T1E;&5T92!2;W<`
M7T=R;W5P<P!?2&5L<`!?26UA9V4@4')O<&5R=&EE<RXN+@!?3&]G(&EN`%],
M;V<@;W5T`%]-;V1I9GD@3&EN:RXN+@!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`
M7U)E;6]V92!,:6YK+BXN`%]3971U<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?
M57-E<G,`861D<F5S<R!B;V]K`&-A;&5N9&%R`&-A;&T`8VQI8VL@:&5R90!F
M86QL:6YG`&9I;&4`9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!H.@!I;6UE
M9&EA=&4`:6YL:6YE`&QI;F5S70!M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI
M;&4@;6%K:6YG($E33RX`;F%M90!N;W0@:6UP;&5M96YT960`;F]T('EE="!I
M;7!L96UE;G1E9`!N;W1E<&%D`'!E<F-E;G0`<&EX96QS`')I<VEN9P!S:&]W
M(&1I9F9E<F5N8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S=&5A9'D`=&%S:R!L
M:7-T`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE
M9`!U;FYA;65D`'5S97(@<V5L96-T`'9#87)D`'<Z`'=E871H97(N8V]M`%!R
M;VIE8W0M260M5F5R<VEO;CH@2&]R9&5V,RXP+C0*4F5P;W)T+4US9VED+4)U
M9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z
M(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`U
M+3`V+3(X(#$T.C0X*S`S,#`*3&%S="U4<F%N<VQA=&]R.B!!=71O;6%T:6-A
M;&QY(&=E;F5R871E9`I,86YG=6%G92U496%M.B!I,3AN0&QI<W1S+FAO<F1E
M+F]R9PI-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA
M:6X[(&-H87)S970]25-/+3@X-3DM.0I#;VYT96YT+51R86YS9F5R+45N8V]D
M:6YG.B`X8FET"E!L=7)A;"U&;W)M<SH@;G!L=7)A;',],3L@<&QU<F%L/3`[
M"@`@*"5S(&?\;B#V;F-E*0`H17)I_FEM($%N86AT87+]("5S*0`@*"5S(&?\
M;F1E*0`@*&)U9_QN*0`@*'EA<OUN*0`@*&3\;BD`(&1E*&1A*2``)60@)7,@
M=F4@)7,`)60M9_QN;/QK(&AA=F$@=&%H;6EN:0`E<R`M($)I;&1I<FEM`"5S
M(%!A<FUA:R#=>FD`)7,@2T(`)7,@0F%K_6T@W?YL96UL97)I("T@3VYA>6QA
M;6$`)7,@07EA<FQA<@`E<R!':7)I_@`E<R!!;FQA_FUA($MO_G5L;&%R_0`E
M<R!Z871E;B!V87(N`"5S(&1E("5S("5S`"5S(&ES=&5N;65K=&5D:7(N`"5S
M(&1A:VEK80`E<R!B=6QU;F%M863]+@`E<R`M("5S("\@)7,@`"5S($%D<F5S
M($1E9G1E<FD`)7,@5&%K=FEM`"5S($YO="!$969T97)I`"5S($?V<F5V($QI
M<W1E<VD`)7,Z("5S`"P@9OUR=/UN86S]("5S("5S`"P@9&7P:?YI;2`E<R`M
M/B`E<P`M+2!39><@+2T`,3(@4V%A=&QI:R!:86UA;B!":>=I;6D`,C0@4V%A
M=&QI:R!:86UA;B!":>=I;6D`,C0@<V%A=`!"=2#V8F5K(&GG:6X@=F5R:71A
M8F%N_2!S;VX@=7IA;G3]<_T@9V5R96MM96MT961I<BX`3VYU;&UA>B!B:7(@
M:&%T82!O;'7^='4`W6QE=&EY:2#^:69R96QE>65B:6QM96L@:>=I;B!01U`@
M8>?]:R!A;F%H=&%R_2!G97)E:VUE:W1E9&ER+@#=;7IA;&%N;?W^(&EL971I
M>6D@9&_P<G5L=?!U;G4@<V'P;&%M86L@:>=I;B!01U`@8>?]:R!A;F%H=&%R
M_2!G97)E:VUE:W1E9&ER+@#=;&5T:6YI;B#^:69R97-I;FD@Y_9Z;65K(&GG
M:6X@8>?]:R!01U`@86YA:'1A<OTL]GIE;"!01U`@86YA:'1A<OT@=F4@9V7G
M:?X@=/QM8V5C:?!I(&=E<F5K;65K=&5D:7(N`-UL971I>6D@:6UZ86QA;6%K
M(&GG:6X@8>?]:R!01U`@86YA:'1A<OTL]GIE;"!01U`@86YA:'1A<OT@=F4@
M9V7G:?X@=/QM8V5C:?!I(&=E<F5K;65K=&5D:7(N`-UL971I;FEN(/YI9G)E
M<VEN:2#G]GIM96L@:>=I;B!AY_UK(%,O34E-12!A;F%H=&%R_2P@]GIE;"!3
M+TU)344@86YA:'1A<OT@=F4@9V7G:?X@=/QM8V5C:?!I(&=E<F5K;65K=&5D
M:7(N`-UL971I>6D@:6UZ86QA;6%K(&GG:6X@8>?]:R!3+TU)344@86YA:'1A
M<OTL(/9Z96P@4R]-24U%(&%N86AT87+]('9E(&=EYVG^('3\;6-E8VGP:2!G
M97)E:VUE:W1E9&ER+@#=;&5T:7EI(/YI9G)E;&5Y96)I;&UE:R!IYVEN(&'G
M_6L@4TU)344@86YA:'1A<OT@9V5R96MM96MT961I<BX`UM8@66'P;75R`-;6
M(%-A\&YA:P#6UB!(869I9B!+87(`UM8OUE,`05!)($E$`$3\>F5N;&5Y:6-I
M(&AA:VO];F1A`$AA:VO];F1A+BXN+@!%;F%L=`!/<G1A>6$`5D93(&1I>FEN
M:2!Y87)A=/UR:V5N(&5R:?YI;2!E;F=E;&QE;F1I+@!61E,@9&EZ:6YI('EA
M<F%T_6S]<FME;B!E<FG^:6T@96YG96QL96YD:2X`2&5S87`@4&%R86QO<_T`
M2&5S87`@1&]N9'5R=6QD=2X`2&5S87!L86[]>6]R`$5K;&4`06QT($=R=7`@
M14ML90!!;'0@W7II;B!%2VQE`$)U<F%Y82!%:VQE.@!996YI($=R=7`@16ML
M90!996YI(-UZ:6X@16ML90!996YI(&MU;&QA;OUC_2!E:VQE.@!+;VQO;B!%
M:VQE`%EE;FD@_'EE(&5K;&4`W6MI;&D@16ML90`E<R!-96[\<_QN_"!-;WII
M;&QA($ME;F%R(,=U8G7P=2!/;&%R86L@16ML90!!9')E<R!D969T97)I;F4@
M96ML93H`061R97,@9&5F=&5R:6UE(&5K;&4`2W5L;&%N_6/]($5K;&4`2W5L
M;&%N_6/](&5K;&5M92!S9>=I;&5M97H@:_UL_6YD_2X`061R97,`061R97,@
M1&5F=&5R:0!9]FYE=&EM+2U$:?!E<B!K=6QL86[];&%R(&GG:6X@:7II;FQE
M<FD@8F5L:7)L97EI;@!9]FYE=&EM`$%D<P!!9F=A;FES=&%N`$%R;F%V=71L
M=6L`0V5Z87EI<@#6=&5K:2!A9`!(:7IA;&$`2&EZ86QA;6%K.@!4_&W\`%3\
M;2!$;_!R=6QA;FW]_B!+=6QL86[]8_UL87(`5/QM($=R=7!L87(`5/QM(-UZ
M:6YL97(`5/QM(&3V<G0@>?QZ`,=O:VQU(&%D<F5S;&5R92!I>FEN('9E<@!3
M_7)A;&%N;?W^(&QI<W1E('3\<OQN_"!A>6%R;&%M87EA(&EZ:6X@=F5R:6QS
M:6X@;6D_`%IA=&5N('9A<@#6=&5K:2!)35-0($=I<FG^:0#6=&5K:2!)35-0
M(%!A<F]L87/]`-9T96MI($E-4U`@2W5L;&%N_6/]($%D_0#6=&5K:2!E;&5K
M=')O;FEK('!O<W1A(&%D<F5S:0#6=&5K:2!T87-L86ML87(`UG1E:VD@;65T
M:6XZ`$%M97)I:V%N(%-A;6]A`$=EYV5R<VEZ(&1E\&5R(&)E;&ER=&EL9&DN
M`$%N9&]R80!!;F=O;&$`06YG=6EL;&$`06YO;FEM(%!R;WAY`$-E=F%P`$%N
M=&%R=&EK80!!;G1I9W5A('9E($)A<F)U9&$`57EG=6QA;6$`57EG=6QA;6$@
M3&ES=&5S:0!5>6=U;&%M82!(87K]<@!!;'0@<&%Y;&'^_6UL87)A('5Y9W5L
M80!/;F%Y;&$`66%K;&'^_6L@0F]Y=70`3FES86X`07)A<.=A("A7:6YD;W=S
M+3$R-38I`$)E;&=E;&EK($1O<WEA($)U>75T=0!"96QG96QI:R!!9/T`)7,@
M:>=I;B!G:7)I_B!I<W1E\&EN:2!K86QD_7)M86L@:7-T961I\&EN>F4@96UI
M;B!M:7-I;FEZ/P!!<FIA;G1I;@!%<FUE;FES=&%N`$5R;65N:6-E("A!4DU3
M0TE)+3@I`%-A;F%T`$%R=6)A`$%S8V5N<VEO;B!!9&%L87+]`$%S8VEI(%-A
M;F%T_0!!<WEA+U!A<VEF:6L@0O9L9V5S:0!"86O];2!I_FQE;6QE<FEN9&5N
M(/9N8V4@9&_P<G5L86UA('-O<G5L<W5N(&UU/P!!=&%M82!+;VQO;FQA<OT`
M5F%R(&]L;6%Y86X@8FER(&=R=6)U('-I;&UE(&=I<FG^:6UI+@!687(@;VQM
M87EA;B!B:7(@:7IN:2!S:6QM92!G:7)I_FEM:2X`5F%R(&]L;6%Y86X@8FER
M(&=R=6)U(&3\>F5N;&5M92!G:7)I_FEM:2X`5F%R(&]L;6%Y86X@8FER('!A
M>6QA_OUM_2!D_'IE;FQE;64@9VER:?YI;6DN`-9Z;FET96QI:VQE<@!!\'5S
M=&]S`$%V=7-T=7)A;'EA`$%V=7-T=7)Y80!!=71H7V-Y<G-Q;#H@W7-T96YE
M;B!I;6%P('5Z871A=/US_2!B=6QU;F%M863]+@!!=71H7V-Y<G5S.B#=<W1E
M;F5N('EE=&5N96ML97)E('-A:&EP(&1E\&EL+@!!=71H7V-Y<G5S.B#=<W1E
M;F5N(&EM87`@=7IA;G3]<_T@8G5L=6YA;6%D_2X`075T:%]F='`Z(-US=&5N
M96X@1E10('5Z86YT_7/](&)U;'5N86UA9/TN(%!(4"=Y:2`M+65N86)L92UF
M='`@<W=I=&-H(&1E\&G^=&ER9V5S:7EL92!D97)L97EI;BX`075T:%]I;6%P
M.B#=<W1E;F5N($E-05`@=7IA;G3]<_T@8G5L=6YA;6%D_2X`075T:%]K<F(U
M.B#=<W1E;F5N(&MR8C4@=7IA;G3]<_T@8G5L=6YA;6%D_2X`075T:%]L9&%P
M.B#=<W1E;F5N($Q$05`@=7IA;G3]<_T@8G5L=6YA;6%D_2X`075T:%]I;6%P
M.B`E<R!K=6QL86[]8_US_2!E:VQE;F5M961I+B!3=6YU8W4Z(`!!=71H7VQD
M87`Z("5S(&MU;&QA;OUC_7/]('-I;&EN96UE9&D`075T:%]L9&%P.B`E<R!K
M=6QL86[]8_US_2!G_&YC96QL96YE;65D:0!!=71H7VUC86PZ(-US=&5N96X@
M34-!3"!U>F%N=/US_2!B=6QU;F%M863]+@!!=71H7W-M8F%U=&@Z(-US=&5N
M96X@<VUB875T:"!U>F%N=/US_2!B=6QU;F%M863]+@!$;_!R=6QA;6$@8F'^
M87+]<_UZ(&]L9'4N`$1O\')U;&%M82!B8?YA<OUS_7H@;VQD=2X@)7,`1&_P
M<G5L86UA(%)!1$E54R!S=6YU8W5S=2!T87)A9OUN9&%N(&=E<FD@YV5V<FEL
M9&DN`$944"!S=6YU8W5S=6YA(&1O\')U;&%M82!B8?YA<OUS_7H@;VQD=2X`
M2W5L;&%N_6S]<B!A;&%N;&%R.@!!>F5R8F%Y8V%N`$)/1D@@0>?]:VQA;6%L
M87+]`$%R=&%L86X`07)T86QA;B!296YG:0!+]G3\(&ME<F)E<F]S('!A<F]L
M87/]+@!+]G3\(&ME<F)E<F]S(&MU;&QA;OUC_2!A9/TN`$)A:&%M86QA<@!"
M86AR97EN`$)A;'3]:R`H25-/+3@X-3DM,3,I`$)A;F=L861E_@!"87)B861O
M<P!486)A;B#G:7IG:7-I`$)E>6%Z(%)U<WEA`$)E;.=I:V$`0F5L:7IE`$)E
M;FEN`$)E<FUU9&$`0FAU=&%N`$1O\'5M9_QN_`!5>6=U;&%M82`B)7,B('-A
M:&EP(&]L9'7P=2`B)7,B(/9B9?!I(&)U;'5N86UA9/TN`-9B96L@07EA<FQA
M<OT`UF)E:R!4_'+\`$MO>74`0F]L:79Y80!997(@W6UL97)I`%/];OUR`%/]
M;OUR($MA;/UN;/WP_3H`4_UN_7)L87(`0F]S;F$@2&5R<V5K`$AE<B!):VES
M:0!";W1S=F%N80!!;'0`0F]U=F5T($%D86QA<OT`0G)E>FEL>6$`0G)I=&%N
M>6$@2&EN="!/:WEA;G5S=2!"]FQG97-I`$)R=6YE:0!"=6QG87)I<W1A;@!-
M861D92#=;6QI($QI<W1E`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4E,`
M0U),($1A\/UT_6T@3F]K=&%L87+]`%](_&-R92#6>F5L;&EK;&5R:2XN+@!4
M86MV:6T`1'5R9W5N`$MA;6)OYWEA`$MA;65R=6X`4&%R;VQA(/9Z9&5V:6YI
M;6QI(&]L87)A:R!S_6;]<FQA;F%M86UA:W1A9/UR+"!L_'1F96X@>?9N971I
M8VEN:7IL92!G]G+\_OQN+@!)34%0('-U;G5C=7-U;F$@8F'P;&%N_6QA9/TZ
M("5S`$MA;F%D80#=<'1A;`!3;W)U;B!287!O<G5N=2#=<'1A;"!%=``B)7,B
M(&1O<WEA<_T@<VEL:6YE;65D:2X`1V7G:6-I(&1I>FEN(&)U;'5N86UA9/TN
M`"=T87)G971&:6QE)R!D9?!I_G1I<F=E<VD@;VQM861A;B!D979A;2!E9&EL
M96UE>BX`(B5S(B!D:7II;FD@:V%L9/UR_6QA;6%D_2X`2V%L9/UR_6QA;6%D
M_2`L)60@86QT('EA</T@=F%R+@!996YI9&5N(&3\>F5N;&5M961I+"!Y96YI
M9&5N(&3\>F5N;&5M92!IYVEN('-A\&QA;F%N(&MA>?UT;&%R_6X@<V%Y_7/]
M(&EL92!D97!O;&%N;?W^(&]L86YL87+];B!S87G]<_T@9?YL9?YM96UE:W1E
M9&ER+@!"96QI<G1I;&UI_B!N=6UA<F%Y82!I;&5T:2!Y]FYL96YD:7)I;&5M
M961I+@!#87!E(%9E<F1E`$)A_FS]:P!+871E9V]R:6QE<B!V92!%=&EK971L
M97(`0V%Y;6%N($%D86QA<OT`0V5P(%1E;&5F;VYU`$C\8W)E(-9Z96QL:6ML
M97)I`$C\8W)E('EA<W3]:VQA;6%S_3H`2/QC<F4@UGIE;&QI:VQE<FD`2/QC
M<F4@0F_^;'5K;&%R_3H`0V5P(%1E;&5F;VYU`$ME;'1I:R`H25-/+3@X-3DM
M,30I`$]R=&$`3W)T82!!9G)I:V$@0W5M:'5R:7EE=&D`3W)T82!!=G)U<&$@
M*$E33RTX.#4Y+3(I`$]N87D@0F5L9V5S:2!!>7+];G3];&%R_0!/;F%Y($)E
M;&=E<VD@2W5R86QL87+]`,=A9`!$9?!I_G1I<@#=;G-A;FQA<OUN('-I>F1E
M;B!G96QE;B!E;&5K=')O;FEK('!O<W1A;&%R_2!O:W5R:V5N('9E(&-E=F%P
M;&%R:V5N(&?V<F3\:VQE<FD@860@=F4@861R97-I;FEZ:2!D9?!I_G1I<FEN
M+@!+87)A:W1E<@!"8?!L86YT_7G]($1E7VYE=&QE+BXN`-YI;&D`QVEN`$)A
M<VET;&7^=&ER:6QM:?X@QVEN8V4@*$=",C,Q,BD`1V5L96YE:W-E;"#':6YC
M92`H0FEG-2D`4&%R;VQA('-EYVEN`$MU;&QA;OUC_2!A9/T@<V7G:6X`5&%R
M:6AL97)I;B!N87/];"!G]G-T97)I;&5C9?!I;FD@<V7G:6XZ`$QI<W1E($)I
MYV5M(%3\<OQN_"!39>=I;B`H<_UR86QA;FW]_B!L:7-T96QE<B!IYVEN*0!#
M:')I<W1M87,@061A;&%S_0!3_6[]9B!T86[];?T@8G5L=6YA;6%D_3HE<P!4
M96UI>FQE`$U33V9F:6-E(&)IYVEM(&EM;&5R:6YI('1E;6EZ;&4`2W5L;&%N
M_6/]>?T@=&5M:7IL93H@)7,`2W5L;&%N_6/]('1E;6EZ;&4`2W5L;&%N_6/]
M('9E<FES:2!T96UI>FQE`$1E=F%M(&5T;65K(&GG:6X@=/UK;&%Y_6X`2%14
M4"!Y;VQU>6QA($-L:6-K871E;&P`4&5N8V5R97EI($MA<&%T`$)U;'5T;&%R
M`$)U;'5T;'4`0V]C;W,@061A;&%R_0!+96YA<B#'=6)U\'5N=2!$87)A;'0`
M1&%R86QT_6QM_?X@4_UN_7)L87(`2V]L;VUB:7EA`%)E;FL`4F5N:R!39>=I
M8VD`4F5N:R!39>=I;6D`2V]L;VYL87(Z`$MO;&]N($)A_FS]:VQA<OT`2V]M
M:6L`2V]M=70`2V]M=70@2V%B=?!U`$'G_6ML86UA`$]R=&%K($%D_0!#;VUO
M<F]S`-YI<FME=`!":6QG:7-A>6%R;&%R`$MO_G5L;&%R`%EA</UL86YD_7)M
M82!&87)K;&%R_0!987#];&%N9/UR.B5S`%!A<F%L;WG]($1O\')U;&$`2V]N
M9V\`1&5M;VMR871I:R!+;VYG;R!#=6UH=7)I>65T:0!"8?!L86YT_2!B8?YA
M<OUS_7H@;VQD=2X`0F'P;&%N=/T@8F'^87+]<_UZ(&]L9'4Z`$'G_6L@86YA
M:'1A<B!S=6YU8W5S=6YA(&)A\&QA;G3](')E9&1E9&EL9&DN`$'G_6L@86YA
M:'1A<B!S=6YU8W5S=6YA(&)A\&QA;G3](')E9&1E9&EL9&DN(%-E8F5B.B`E
M<R`H)7,I`$944"!S=6YU8W5N82!B8?!L86YT_2!B8?YA<OUS_7H@;VQD=2X`
MW6QE=&G^:6T@;F]K=&%L87+](&)A_F%R_7EL82!A9')E<R!D969T97)I;FEZ
M92!E:VQE;F1I+@!$979A;0!#;V]K($%D86QA<OT`QV5R97H`2V]P>6%L80!3
M9>=I;6D@2V]P>6%L80!+;W-T82!2:6MA`$-O=&4@9"=)=F]I<F4`W6QE=&D@
M4$=0(&EL92#^:69R96QE;F5M961I+@#=;&5T:2!01U`@:6QE(&EM>F%L86YA
M;6%D_2X`W6QE=&D@4R]-24U%(&EL92!S:69R96QE;F5M961I+@#=;&5T:2!3
M+TU)344@:6QE(&EM>F%L86YA;6%D_2X`W6QE=&G^:6T@;F]K=&%S_2!E:VQE
M;F5M961I+B`E<P!,1$%0('-U;G5C=7-U;F$@8F'P;&%N_6QA;6%D_2X`0F%K
M:7EE(&1E;F5T;&5N96UE9&DN("5S`$1A\/UT_6T@;&ES=&5S:2!Y87)A=/UL
M86UA9/TN("5S`%!'4"!V97)I<VEN:6X@_FEF<F5S:2#G]GK\;&5M961I+@!3
M+TU)344@=F5R:7-I;FEN(/YI9G)E<VD@Y_9Z_&QE;65D:2X`W6QE=&G^:6T@
M;F]K=&%S_2!S:6QI;F5M961I+B`E<P!$8?#]=/UM(&QI<W1E<VD@<VEL:6YE
M;65D:2X@)7,`06S]8_UN_6X@96QE:W1R;VYI:R!P;W-T82!A9')E<VD@8F5L
M:7)L96YE;65D:2X`061R97,@9&5F=&5R:2!T86UA;65N(&=E=&ER:6QE;65D
M:2X`1&'P_73];2!L:7-T97-I('1A;6%M96X@9V5T:7)I;&5M961I+@!$8?#]
M=/UM(&QI<W1E;&5R:6YI;B!L:7-T97-I('1A;6%M96X@9V5T:7)L96UE9&DN
M`$%N86AT87(@<W5N=6-U<W5N9&%N(&'G_6L@86YA:'1A<B!E9&EN:6QE;65D
M:2X`)7,@8>?];&%M863]+@!-86EN=&5N86YC95]487-K(&)I<FEM:2`E<R!A
MY_UL86UA9/TN`"5S(&]K=6YA;6%D_2X`W7-T96YE;B!K=6QL86YC_2!IYVEN
M('!A<F]L82!S_6;]<FQA;F%M863]+B!"87K]('EA9&$@=/QM(&%Y<OUN=/UL
M87(@9&_P<G4@9&7P:6PN(%EE;FED96X@9&5N97EI;B!Y861A(&1A:&$@9F%Z
M;&$@>6%R9/UM(&GG:6X@<VES=&5M('GV;F5T:6YI>FQE(&?V<OS^_&XN`$%#
M3"!E<FG^:6QE;65D:2X`061R97,@9&5F=&5R:6YE(&5R:?YI;&5M961I+B`E
M<P!$8?#]=/UM(&QI<W1E<VEN92!E<FG^:6QE;65D:2X@)7,`1&'P_73];2!L
M:7-T96QE<FEN92!E<FG^:6QE;65D:2X@)7,`4W5N=6-U;G5N('EE=&5N96ML
M97)I;F4@97)I_FEL96UE9&DN`%EA</UL86YD_7)M82!G97)I(&3V;F3\<OQL
M96UE9&DN+@`E<R!Y87#];&%N9/UR;6$@:V%Y9&5D:6QE;65D:2X`665D96L@
M8FER('EA</UL86YD_7)M82!K87ED961I;&5M961I+@!9961E:R!B:7(@>6%P
M_6QA;F3]<FUA(&MA>61E9&EL96UE9&DZ("5S`%EE9&5K('EA</UL86YD_7)M
M82!D;W-Y87/]("5S(&MA>61E9&EL96UE9&DN`%EA</UL86YD_7)M82!D;W-Y
M87/]("5S(&MA>61E9&EL96UE9&DN($)U(&1U<G5M9&$L(&MO9'4@=&5K<F%R
M("5S(&GG:6YE(&MA>61E=&UE:R!Y861A('1A:VEP(&5D96X@:V]D=2!E;"!I
M;&4@)7,@:>=I;F4@:V]P>6%L86UA:RP@<V7G96YE:VQE<FEN:2!K=6QL86YA
M8FEL:7)S:6YI>BX`3$1!4"!S=6YU8W5S=2!A<F%N86UA9/TN`-UL971I_FEM
M(&YO:W1A<_T@9_QN8V5L;&5N96UE9&DN("5S`$1A\/UT_6T@;&ES=&5S:2!G
M_&YC96QL96YE;65D:2X@)7,`36]Z:6QL82!K96YA<B#G=6)U\'4@8G5L=6YA
M;6%D_2X@2V5N87(@YW5B=?!U;G5N(&'G_6L@;VQD=?!U;F1A;B!E;6EN(&]L
M=6XN`%-A>?UL;?W^(&UE=&EN`-QL:V4`1&5R<VQE<@!987)A=`!"8?!L86YT
M_2!Y87)A=`!996YI(%EA<F%T`$%L="!D:7II;B!Y87)A=`!987)A=/UC_2#=
M>FEN;&5R:0!+<F5D:2!K87)T(&YU;6%R87/]`$C]<G9A=&ES=&%N`$O\8F$`
MWG4@06YD86MI(%IA;6%N`-YU(&%N9&%K:2!54DP`WG4@06YD86MI($AA=F$@
M1'5R=6UU`-YU($%N9&%K:2#>87)T;&%R.@!9_'+\<FS\:W1E:VD@<VET:6P`
M)7,@92!G:7)I_G1E(.=A;/W^86-A:R!G]G)E=FQE<FD@:VG^:7-E;&QE_G1I
M<FEN`$ME<P#>9>=I;&D@;VQA;FQA<OT@:V5S`$O]8G+]<P!+:7)I;"`H2T])
M."U2*0!+:7)I;"`H5VEN9&]W<RTQ,C4Q*0!+:7)I;"]5:W)A>6YA("A+3TDX
M+54I`,=E:R!#=6UH=7)I>65T:0!'1P!'_&YL_&L`5F5R:2!!\&%C_2!487)A
M>?UC_7/]`%1A<FEH`$=E;&G^(%1A<FEH:0!487)I:"!39>=I;6D`1_QN`$M?
M;VQO;G4@4VEL`$%R86S]:P!/;F1A;/UK('-A>?UL87(`1VER:6YT:7EI($%Z
M86QT`-9N('1A;OUM;/T`UFX@5&%N_6UL_2!296YK`-9N(%1A;OUM;/T@2VEM
M;&EK`%1A;OUM;&%R`%-I;`!'<G5P(%-I;`#=>FEN(%-I;`#=;&5T:6QE<FD@
M<VEL('9E('1E;6EZ;&4`2/QC<F4@4VEL`$MO;&]N(%-I;`!687)O;&%N(/9T
M96MI('1A<VQA\/T@<VEL`%-A=/UR_2!S:6P`4V7G:6QM:?X@:VEM;&GP:2!S
M:6P`WG4@86YD86MI(&MO;&]N=2!S:6P`WG4@86YD86MI('-A=/UR_2!S:6P`
M5&5S;&EM('IA;6%N_0!$86YI;6%R:V$`4V]R=6YU(%1A;OUM;&%Y_6X`0>?]
M:VQA;6$`07ER_6YT_6QA<B`H07EN_2!Z86UA;F1A($AO<F1E)W5N(&?\;FS\
M:R!D;W-Y87/];OUN(&GG:6YD92DZ`$%Y<OUN=/UL87(@>?9N971I8VD@:>=I
M;B!G_&YL_&L@;VQA<F%K(&MA>61E9&EL9&DN`$=E;&G^:6T`3F5M($UI:W1A
M<OT`4V]N('-A871T96MI(&YE;2!M:6MT87+].B``3F5M(&UI:W1A<OTZ(`!3
M;VQD86X@<V'P82!Y]FYL_`!38?!D86X@<V]L82!Y]FYL_`!$:7II;@`R-"!S
M86%T;&EK('IA;6%N(&W](&?V<W1E<FEL<VEN/P!']G+\;G3\;&5M92!39>=E
M;F5K;&5R:0!(879A('1A:&UI;FEN:2!G]G+\;G3\;&4@*%1!1BD`1_9R_&YT
M_&QE;64@0FGG:6UI`$3\>F5N($)I;&1I<FEM:0!#:6)U=&D`4VEL;65Y:6X`
M;6%I;G1E;F%N8V4N<&AP(&1O<WEA<_UN82!D;_!R=61A;B!E<FG^;65Y:6XN
M`-UL:R!S873]<B!A;&%N(&%D;&%R_6[](&GG97)I>6]R(&UU/R!%=F5T(&ES
M92!B=2!K=71U>74@<V7G:6XZ`$1O;6EN:6L`1&]M:6YI:R!#=6UH=7)I>65T
M:0#=;F1I<@`E<R#=;F1I<@!/;'7^='5R=6QA;B!Y87#];&%N9/UR;6%Y_2!0
M2%`@8F5T:?!I(&]L87)A:R!I;F1I<BX`0?YA\/T@8>?];/UR(&QI<W1E`-UL
M8>=L87(`12U0;W-T80!%4E(`16MV871O<@!$_'IE;FQE`$)L;VL@1/QZ96YL
M90!'<G5P($3\>F5N;&4`W7II;B!$_'IE;FQE`-UZ:6YL97)I($3\>F5N;&4`
M)7,@W>=I;B#=>FEN;&5R:2!$_'IE;FQE`%-EYV5N96ML97)I(&3\>F5N;&4Z
M`"5S(&GG:6X@:7II;FQE<FD@9/QZ96YL90!%\&ET:6T`3?US_7(`16P@4V%L
M=F%D;W(`UO!E+BXN`$5M`$5L96MT<F]N:6L@4&]S=&$`16QE:W1R;VYI:R!0
M;W-T82!!9')E<VD`16QE:W1R;VYI:R!P;W-T82!A<W)E<VQE<FD@9?YL9?YM
M96QI+@!/;F%Y;/T@96QE:W1R;VYI:R!P;W-T80!$=7EG=2!S:6UG97)L97)I
M`$)O_B!I;&5T:2X`0F_^('-O;G7G+@!";_X@87)A;6$@=&5R:6UL97)I`$9O
M=&_P<F%F($=A;&5R:7-I;F1E;B!M971I;FQE<FEN(&GG97)I<VEN92!G]G+\
M;G3\(&5K;&5M92!E=&MI;FQE_G1I<FEL<VEN(&UI/P!38?`@=/UK(&GG97)I
M:R!M96[\<_P@971K:6YL9?YT:7)I;'-I;B!M:3\`0FET:?X@>?UL_0!$_'IE
M;FQE>6EC:7EI($=E;FG^;&5T`%!A<F]L86[]>OT@<_UF_7)L86UA:R!I<W1E
M9&GP:6YI>F1E('-O<G5L;6%K(/QZ97)E(&)I<B!G_'9E;FQI:R!S;W)U<W4@
M9VER:6XL(-9R+B`G179C:6P@:&%Y=F%N_6[]>OUN(&%D_2!N961I<C\G.@!'
M]G+\;G3\(&%D<F5S:6YI(&)U<F%Y82!G:7)I;@!%:W9A=&]R($=I;F5S:0!%
M<FET<F4`2&%T80!%;&5T<F]N:6L@<&]S=&$@9/9N9&5R;65D92!H871A+@!%
M<W1O;GEA`$5T:7EO<'EA`$5T;FEK`$%V<G5P80!(97(@,34@9&%K:6MA`$AE
M<B`R(&1A:VEK80!(97(@,S`@<V%N:7EE`$AE<B`U(&1A:VEK80!(97(@1VER
M:?YT90!(97(@>6%R_6T@<V%A=`!(97(@9&%K:6MA`-9R;F5K(&1E\&5R;&5R
M.@#'86S]_G3]<@!'96YI_FQE=`!+96YA<B#'=6)U\'5N=2!'96YI_FQE=``G
M*2<@0F5K;&5N:7EO<@!3861E(&ME;&EM92!V97EA(&%L_6YT_2!A<F%M82!T
M97)I;6D@8F5K;&5N:7EO<@!'9>=E<FQI;&EK(%-O;B!487)I:&D`W'-T`-9N
M($%L86X@4F5N9VD`07EA<FQA<B!IYVEN($944"!Y_&ML96UE<VD`5&5R8VEH
M;&5R:6X@9V5T:6QM97-I(&)A_F%R_7/]>BX`3$1!4"!S=6YU8W5S=6YA(&)A
M\&QA;G3](&)A_F%R_7/]>BX`4TU"('-U;G5C=7-U;F$@8F'P;&%N=/T@8F'^
M87+]<_UZ+@`B)7,B(&MO;G5M=6YD86X@:V]P>6%L86UA(&)A_F%R_7/]>BX`
M(B5S(B!K;VYU;75N82!K;W!Y86QA;6$@8F'^87+]<_UZ+@!996YI(%-!4TP@
M8F'P;&%N=/US_2!O;'7^='5R=6QA;6%D_2X`(B5S(B!K;VYU;75N82!T8?[]
M;6$@8F'^87+]<_UZ+@!5>6=U;B!(879A`$9A;&ML86YD($%D86QA<OT@*$UA
M;'9I;F$I`$9A<F]E($%D86QA<OT`3VYU;&UA>B!(871A.@!&86MS`-YU8F%T
M`$AI<W-E9&EL:7EO<@!(:7-S961I;&EY;W(Z(`!(869I9B!38?!A;F%K`$AA
M9FEF($MA<B!38?!A;F'P_0!!;&%N(&UA=')I<VD`1FEJ:0!$;W-Y82!387G]
M<_TZ("5S(&1O<WEA`$1O<WEA(%-A>?US_3H@)7,@9&]S>6$`1&]S>6$@6?9N
M971I8VES:0!$;W-Y82!!9/T`1&]S>6$@<V7G:6UI`$1O<WEA('G\:VQE;64`
M1&]S>6$@>?QK;&5M92!D97-T96ML96YM:7EO<BX`4_QZ9V7G;&5R`$9I;FQA
M;F1I>6$`W6QK(%EA<OT`W6QK(,=E>7)E:P!/<F%N_2!S86)I=&QE`,=E=FER
M`$MA>6%N`%-I<P`E<R!D:7II;FD@>6]K`%EA>OT@4F5N9VD`665M96L`1_9R
M_&YT_&QE<FD@9&5S=&5K;&5M97EE;B!T87)A>?UC_6QA<B!IYVEN`%1A:&UI
M;B`H5$%&*0!486AM:6X@1_QN;&5R:2`H3F]T.B!'97)I(&3V;OQL96-E:VQE
M<B!H96T@9_QN(&AE;2!G96-E(&]L87)A:R!D]F[\;&5C96L[("EB_'G\:R!B
M:7(@<V%Y_2!G96YI_B!B:7(@]F)E:VQE('-O;G7G;&%N86-A:W3]<BD`4&%R
M;VQA;OUZ_2!M_2!U;G1T=6YU>C\`1F]R;6QA<@!$97EI_@!$97EI_B!T_'+\
M`$1E>6G^;&5R`$1E>6G^;&5R(#(`1F]R=6UL87(`6?9N;&5N9&ER;65L97(`
M0W4`QV5RYV5V96QE<@!&<F%N<V$`1G)A;G-A+"!-97)T;W!O;&ET86X`1G)A
M;G/]>B!'=7EA;F%S_0!&<F%N<_UZ(%!O;&EN97IY87/]`$9R86YS_7H@1_QN
M97D@0O9L9V5S:0!+:6UD96X`2VEM9&5N`%1A;2!"971I;6QE;64`1&]L=6YA
M>0!!Y_UK($%D`$=A8F]N`$?V<OQN=/QL97)I;B!A;/UN86-A\/T@9V%L97)I
M`$=A;&5R:3H`1V%M8FEY80`E<R!987#];&%N9/UR;6%S_6[]($]L=?YT=7(`
M3VQU_G1U<G5L86X@2V]D`$?\<F-I<W1A;@!!;&UA;GEA`$=A;F$`0V5B96QI
M=&%R_6L`5F5R:6QE;B!!9`!':70`1V]E9&5L`$=O;V=L92!!<F%M80!3:7EA
M:"!"97EA>@!9=6YA;FES=&%N`%EU;F%N8V$@*$E33RTX.#4Y+3<I`$=R]FYL
M86YD`$=R96YA9&$`1W)U<"!9]FYE=&EM:0!'<G5P(&ES:6UL97)I(&1O;'4@
M;VQM86S]9/UR`$=R=7!L87(`1W5A9&%L=7``1W5A;0!'=6%T96UA;&$`1W5E
M<FYS97D`2V]N=6L@W7II;FQE<FD`2V]N=6L@1&5F=&5R:0!':6YE`$=U:6YE
M($)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!S873]<F1A:VD@<V]N(&C\
M8W)E>6D@<VEL;65Y:2!R961D961I>6]R+@!(5$U,07)E82#G:7IE;&=E9&5K
M:2!S;VX@:V]L;VYU('-I;&UE>6D@<F5D9&5D:7EO<BX`2%1-3$%R96$@YVEZ
M96QG961E:VD@<V]N('-A=/UR_2!S:6QM97EI(')E9&1E9&EY;W(N`$A45%`@
M2VEM;&EK($1E;F5T:6UI(&)U;&%N86UA9/TN`$AA:71I`$AA<V@@06QG;W)I
M=&UA<_T`2&%F:68@4VES`$)A_FS]:P!(96%R9"!!9&%S_2!V92!-8T1O;F%L
M9"!!9&%L87+]`-UB<F%N:6-E("A)4T\M.#@U.2TX+4DI`%G\:W-E:VQI:P!9
M87)D_6T`1/QZ96YL97EI8VD@:W5L;&%R86L@>6%R9/UM`%EA<F3];6/]`%EA
M<OUK_')E`$1O<WEA;OUN(&)A_FQA;F?]8_TZ(`!9_&MS96L`7T%N87-A>69A
M`%9A=&EK86X`06YA<V%Y9F$`178@061R97-I`$5V(%1E;&5F;VYU`$AO;F1U
M<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@0G4@;65S86H@:>=I
M;F1E(&=EYV5R<VEZ("5S(%A-3"!V97)I<VD@:6QE(&MA<O[];&'^_6QD_3H@
M)7,`2&]R9&4O2V]L86(Z("5S(&YE<VYE<VD@:6QE(&EL9VEL:2!B:7(@:6QE
M=&D@8G5L=6YA;6%D_0!(;W)D92]+;VQA8CH@)7,@=/QR_&YD92!H:><@8FER
M(&YE<VYE("5S(&UE<V%J_2!IYVEN9&4@>6]K+@!(;W)D92]+;VQA8CH@)7,@
M(B5S(B!B8?YA<OT@:6QE('-I;&EN9&D`2&]R9&4O2V]L86(Z($+\=/QN;&5M
M92!M;W1O<G4@)V1O;7AM;"<@4$A0('5Z86YT_7/];F$@:6AT:7EAYR!D=7EM
M86MT863]<@!(;W)D92]+;VQA8CH@)7,@;F5S;F5S:2!IYVEN('EE;FD@6$U,
M(&'P86/](&]L=?YT=7)U;&%M_7EO<@!(;W)D92]+;VQA8CH@4VEL:6YE;65D
M:2`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@)7,@=/QR_&YD96MI(&O]<_UM
M(&GG:6X@34E-12!)1"!B=6QU;F%M863]`$AO<F1E+TMO;&%B.B!%_FQE;F5M
M961I("5S("(E<R(Z("5S`%!A>6QA_OUM;&%R(&7^;&5N96UE9&DZ("5S`$)I
M;&EN;65Y96X@<&%Y;&'^_6T@(B5S(@!9871A>2#':7IG:0!9871A>2!Y87-T
M_6ML86UA`%EA=&%Y.@!"=7)A>6$@;F%S_6P@9V5L9&EN:7H_("A,_'1F96X@
M<F%P;W(@961I;B$I`$MAYR!A9&5T(&MO;&]N=2!B:7)L9?YT:7)M96L@:7-T
M:7EO<G-U;G5Z/P!+8><@86QA;B`H:V]L;VXI('9A<C\`2V'G(&%D970@<V%T
M_7+](&)I<FQE_G1I<FUE:R!I<W1I>6]R<W5N=7H_`$YE;0!.96TZ(`!-:7IA
M:.?];&%R`$UA8V%R:7-T86X`24U!4"!P;W-T82!K=71U<W4@;VQU_G1U<G5L
M86UA9/TZ("5S`$E-05`@<&]S=&$@:W5T=7-U('-I;&EN96UE9&DZ("5S`$E-
M05`@<&]S=&$@:W5T=7-U(&MO=&%S_2!O;'7^='5R=6QA;6%D_3H@)7,`25`@
M061R97-I`$E0(&%D<F5S:2!M979C=70@9&7P:6PN(`!)4"!!9')E<VD@:7II
M;B!V97)I;&5N($-)1%(@8FQO\'4@:>=I;F1E(&1E\&EL+@!)4"!K:6QI=&QE
M;64@:6AL86QI+@#6;E]C97EE(%-A=/UR(%EE<FQE_G1I<@#=>FQA;F1A`%-A
M9&5C92!3:6UG96QE<@`E<R!IYVEN('-I;6=E;&5R`$UE=&EN(&EL92!B:7)L
M:6MT92!S:6UG96QE<@!+:6UL:?!I;B!A9/TZ`$7P97(@9&_P<G4@9_9R_&YT
M_&QE;F5M:7EO<G-A+"!Y96YI('!E;F-E<F5D92!AYVUA:R!IYVEN('3]:VQA
M>?UN("5S+@!%\&5R($EN=&5R;F5T($5X<&QO<F5R(&EL92!S:6UG96QE<FD@
M9_9R96UI>6]R<V%N_7H@8G4@:W5T=7EU('-EYV5R96L@4$Y'('-A>61A;6S]
M\/UN_2!K87!A=&UA;OUZ(&=E<F5K:7(N`$?V<OQN=/QL97)I(&?V<F5M:7EO
M<B!F86MA="!B=2!M97-A:OT@9_9R96)I;&ER>6]R<V%N_7HL('G\:VQE;65K
M(&ES=&5D:?!I;FEZ(&?V<OQN=/P@=&%R87G]8_UN_7H@=&%R86;];F1A;B!G
M]G-T97)I;&5M96UE:W1E9&ER+@!']G+\;G3\(-9N:7IL96UE`$?V<OQN=/P@
M55),`$?V<OQN=/P@55),.@!397)G:61E;B!G]G+\;G3\`%-E<F=I9&5N(&?V
M<OQN=/PZ`$?V<OQN=/P@>?QK;&5M96L`1_9R_&YT_&QE<@#=YV5R:2!!:W1A
M<BP@063];2`E9`#=YV5R:2!A:W1A<OUL86X@86QA;CH@)7,`W>=E<FD@86MT
M87+];&%N(&%L86YL87(Z`%-O;E]R87EA(%-A=/UR($5K;&4`66%N;/W^(&5Y
M;&5M(&MO9'4@9VER:6QD:2X`66%N;/W^(&MU;&QA;OUC_2!A9/T@=F4O=F5Y
M82!P87)O;&$N`%EA;FS]_B!K=6QL86[]8_T@863]('9E>6$@]G1E:VD@861R
M97,N665N:61E;B!D96YE>6EN('9E>6$@9&%H82!F87IL82!Y87)D_6T@:>=I
M;B!Y]FYE=&EC:6YI>FQE(&?V<OS^_&XN`$=I<FEN=&EY:2!!<G1T_7(`2&EN
M9&ES=&%N`$)I<F5Y<V5L($MU;&QA;OUC_6QA<@!%;F1O;F5Z>6$`0FEL9VD`
M0FEL9VD`4V]N<F%Y82!+;U]L;VX@16ML90!']G+\;G3\(%EE<FQE_G1I<@#'
M:7IE;&=E(%EE<FQE_G1I<@!796(@0F'P;&%N=/US_2!997)L9?YT:7(`UFYC
M97EE($MO;&]?;B!%:VQE`%EE;FD@:V]L;VYU(/YU(&%N9&%K:2!K;VQO;F1A
M;B!S;VYR82!Y97)L9?YT:7(`665N:2!K;VQO;G4@_G4@86YD86MI(&MO;&]N
M9&%N(/9N8V5Y92!Y97)L9?YT:7(`665N:2!S873]<OT@_G4@86YD86MI('-A
M=/UR9&%N('-O;G)A>6$@>65R;&7^=&ER`%EE;FD@<V%T_7+](/YU(&%N9&%K
M:2!S873]<F1A;B#V;F-E>64@>65R;&7^=&ER`%EE;FD@<&%R86=R86;](/YU
M(&%N9&%K:2!D_/#\;61E;B!S;VYR87EA('EE<FQE_G1I<@!996YI('!A<F%G
M<F%F_2#^=2!A;F1A:VD@9/SP_&UD96X@]FYC97EE('EE<FQE_G1I<@#6=&5K
M:2!T87-L86L@>65R;&7^=&ER`%EE;FD@8FER('!A<F%L;WG](&%L86)I;&5C
M9?!I;FEZ(&)I<B!E;&5K=')O;FEK('!O<W1A(&%D<F5S:2!G:7)I;CH`2/QC
M<F5Y:2!S;VYR87/];F$@>65R;&7^=&ER`$C\8W)E>6D@]FYC97-I;F4@>65R
M;&7^=&ER`$MO;&]N=2!S;VYR87/];F$@>65R;&7^=&ER`$MO;&]N=2#V;F-E
M<VEN92!Y97)L9?YT:7(`365S86H@9VER`%!A<F%G<F%F_2!S;VYR87/];F$@
M>65R;&7^=&ER`%!A<F%G<F%F_2#V;F-E<VEN92!Y97)L9?YT:7(`4V%T_7+]
M('-O;G)A<_UN82!Y97)L9?YT:7(`4V%T_7+](/9N8V5S:6YE('EE<FQE_G1I
M<@!'_'9E;FQI:R!S;W)U<W5N=6X@8V5V86+].@!']G+\;G3\>?P@665R;&7^
M=&ER+T1E\&G^=&ER`$)A\&QA;G3](%EE<FQE_G1I<B]$9?!I_G1I<@!$8?#]
M=/UM(&QI<W1E<VD@9_9N9&5R;65K(&GG:6X@>65T97)S:7H@:W)E9&DN`%EE
M=&5R<VEZ(&MR961I`%1A;7-A>?T`5&%M<V%Y_2!L:7-T97-I`$=EYV5R<VEZ
M(%5$2"X@*$MU;&QA;OUC_2!697)I($)A_FS]:R!":6QG:7-I*0!'9>=E<G-I
M>B!U>6=U;&%M82X`1V7G97)S:7H@>?WP_6X@:VEM;&GP:2X`1V7G97)S:7H@
M=F5R:2!G]FYD97)I;&1I+@!'9>=E<G-I>B!T97-L:6T@861R97-I`$=EYV5R
M<VEZ(&1O<WEA(&)IYVEM:0!'9>=E<G-I>B!M<V=?='EP90!'9>=E<G-I>B!Y
M861A(&%T;&%N;?W^(&%P:5]I9`!'9>=E<G-I>B!Y861A(&%T;&%N;?W^(&1E
M\&G^=&ER9V5L97(`1V7G97)S:7H@_'-T(&EZ:6XN`$=EYV5R<VEZ(&EL971I
M_FEM(&MU<F%L;&%R_0!'9>=E<G-I>B!P87EL8?[];&%N(&YE<VYE`$=EYV5R
M<VEZ(&MA>6YA:R!A9')E<VDN`$=EYV5R<VEZ('5N:6-O9&4@=F5R:7-I+@!3
M=&]K`-UR86X@W7-L86T@0W5M:'5R:7EE=&D`27)A:P#=<FQA;F1A`$UA;B!!
M9&$@1&5V;&5T:0!986S]=/UL;?W^(&?V:R!G_'+\;'3\;/P@9OUR=/UN80#=
M<W)A:6P`Q_UK87)A;@#==&%L:6L`W71A;'EA`$IA;6%I:V$`3V-A:P!*87!O
M;GEA`$IA<&]N8V$@*$E33RTR,#(R+4I0*0!*97)S97D`W')D_&X`5&5M;75Z
M`$AA>FER86X`66%S;&$`3W)T87EA(%EA<VQA`%1A;6%M96X@66%S;&$`4V]L
M82!987-L80!38?!A(%EA<VQA`$MA>F%K:7-T86X`UGIG_&X@;VQA;B!S86ML
M86YS_6X@;?T_`$ME;GEA`$ME<F)E<F]S('-U;G5C=2!D;_!R=6QA;6%Y_2!R
M961D971T:2X`QV5K:7)D96L@06-E;6EL97)I`$%N86AT87(@66%R870`06YA
M:'1A<B!087)M86MI>FD`06YA:'1A<B!5>G5N;'7P=0!!;F%H=&%R(%1I<&D`
M06YA:'1A<B!+=6QL86[];?T`0>?]:R!A;F%H=&%R('-U;G5C=7-U;F1A(&%N
M86AT87(@>F%T96X@=F%R+@#';V-U:VQA<@!+:7)I8F%T:0!+=7IE>2!+;W)E
M`$?\;F5Y($MO<F4`2V]R96-E("AE=6,M2U(I`$MU=F5Y=`!+_7)G_7II<W1A
M;@!387EF82!?1/QZ96YI`$1I;`!,86\@1&5M;VMR871I8R!(86QK($-U;6AU
M<FEY971I`%-O;B!$]G)D_&X`WFG^:VEN($%Y`%-O;B!'_&YC96QL96UE.@!3
M;VX@1VER:?XZ("5S`%-O;B!':7)I_CH@)7,@_'IE<FEN9&5N("5S`%-O;B!'
M:7)I_CH@07-L80!,971O;GEA`%EA<V$`1/QZ96X`2&GG8FER('/];OUR(&GG
M:6X@8F_^(&+]<F%K;6$`3/QB;F%N`%-O;`!3;VP@8F'^;/UK(&)I;&=I<VD`
M4V]L9&%K:2!D9?!E<FQE<@!,97-O=&AO`$QI8F5R>6$`3&EB>6$`3&EE8VAT
M96YS=&5I;@#':7-E;&EY;W(`2&%F:68@66'P;75R`$5R:V5N(%-A871L97)D
M92!(869I9B!98?!M=7(`1V7G(%-A871L97)D92!(869I9B!98?!M=7(`2&%F
M:68@66'P;75R(%-A\&%N8?#]`$?V:R!G_'+\;'3\;/P@:&%F:68@>6'P;75R
M`$AA9FEF($MA<@!(869I9B!+87(@4V'P86YA\/T`3OQK=&5L:2#>:6ER`$)A
M\&QA;G3]`$)A\&QA;G3](&YO:W1A<_TZ`$?V<OQN=/QL97)K96X@96QE:W1R
M;VYI:R!P;W-T82!A9')E<VEN:2!O;'7^='5R;6$@<V%Y9F%S_6YA(&)A\&QA
M`$)A\&QA;G3];&%R`$QI;G5X(,=E<F5Z:0!,:7-T96QE("T@:W5L;&%N_6/]
M(&1I>FEN:2!G]G)E8FEL:7(`5F5R:2!486)A;FQA<OUN_2!,:7-T96QE`%EA
M<F3];2!+;VYU;&%R_6[]($QI<W1E;&4`QVEZ96QG96QE<FD@3&ES=&5L90!,
M:7-T96QE+4%R_FEV`$QI<W1E;&4M66%R9/UM`$QI<W1E;&4M260`3&ES=&5L
M92U386AI<`!,:7-T96QE+4?V;F1E<FEL;6G^(-;P96QE<@!,:7-T96QE+5/\
M<F3\<OQM8_QL97(`3&ES=&5L92U3_')D_'+\;6/\($]L;6%Y86YL87(`2W5L
M;&%N_6/](&QI<W1E;&5M92!S9>=I;&5M97H@:_UL_6YD_2X`161E8FEY870`
M3&ET=F%N>6$`6?QK;&5N:7EO<BXN+@!997)E;"!Z86UA;CH`665R('9E(%IA
M;6%N`%EE<@!':7)I_@#'_6O]_@!':7)I_B!']G)E=FQE<FD`2W5L;&%N_6/]
M(&%D_2!V97EA('!O<F]L82!D;_!R=2!O;&UA9/WP_2!IYVEN(&=I<FG^(&)A
M_F%R_7/]>B!O;&1U+@!':7)I_B!B8?YA<OUS_7H@;VQD=2X`57IU;B!M971I
M;@!!_FL`1/S^_&L`2_SG_&L@>75N86X@:&%R9FQE<FD`2_SG_&L@;&%T:6X@
M:&%R9FQE<FD`2_SG_&L@<F]M82!R86MA;6QA<OT`3/QK<V5M8G5R9P!!00!-
M3U1$`$U3+51.148@16MI('9E<FD@:>=E<FUE;65K=&5D:7(N`$U31P!-86-A
M;P!-86ME9&]N>6$`36%D86=A<VMA<@!"_'G\`%!O<W1A`%!O<W1A(%GV;F5T
M:6-I<VD`0F'P;&%?;G3](%EA<F%T+BXN`$UA;&%V:0!-86QE>GEA`$UA;&1I
M=FQE<@!-86QI`$UA;'1A`-;P96QE<FD@971I:V5T;&5Y96-E\&EN:7H@:V%T
M96=O<FD@;&ES=&5S:6YI('9E(&MA=&5G;W)I;&5R:2!I;&G^:VEL96YD:7)E
M8V7P:6YI>B!R96YK;&5R:2!Y]FYE=&EN+@!-87`R-"!H87)I=&%S_0!-87!1
M=65S="!H87)I=&%S_0!-87)T`$ME;F%R(&)O_FQU\'4`3VMU;FUU_B]/:W5N
M;6%M_?X@;VQA<F%K(&G^87)E=&QE`$1I\&5R(&EL971I(&G^87)E=&QE<FEY
M;&4@:?YA<F5T;&4@*/9R;F5K.B#6;F5M;&DO0V5V87!L86YM_?XI(`!-87)S
M:&%L;"!!9&%L87+]`$UA<G1I;FEK`$7^;&5L96X@86QA;FQA<@!-;W)I=&%N
M>6$`36%U<FET=7,`W7II;B!V97)I;&5N(&5N('G\:W-E:R!K<F5D:2X`16X@
M>?QK<V5K(&UE<V%J('!A<N=A<_T@<V%Y_7/](&'^_6QD_2X`4V]N(#(T('-A
M871T96MI(&5N('G\:W-E:R!S_6-A:VS]:SH@`%-O;B`V('-A871T96MI(&5N
M('G\:W-E:R!S_6-A:VS]:SH@`$5N('G\:W-E:R!U>G5N;'5K`$UA>?US`$UA
M>6]T=&4`5/UP`-QY96QE<@!-96[\($MI<&DZ`$C\8W)E;&5R:2!B:7)L9?YT
M:7(`W6QE=&D`W6QE<FD@8F'^87+]>6QA(&1O\')U;&%N9/T@86UA(&EM>F%L
M87G]8_UN_6X@;VYA>2!B96QG97-I(&1O\')U;&%N86UA9/TN`$UE<V%J_6X@
M<_QR97-I(&)I='1I+@!-97-A:B!T:7!I`$AA=F$@4F%P;W)U`$AA=F$@<F%P
M;W)U(/9B9?!I(&MU;&QA;OUL86)I;&ER(&1E\&EL+@!(879A(')A<&]R=2#V
M8F7P:2!K=6QL86[];&%B:6QI<B!D9?!I;"X@07ER_6YT_6QA<B!Y]FYE=&EC
M:2!IYVEN(&?\;FS\:VQE;F1I`%GV;G1E;0!-971R:6L`365K<VEK80!-:6MR
M;VYE<WEA`$]R=&$`36EM92!4_'+\`%-O;B`R-"!S86%T=&5K:2!E;B!D_/[\
M:R!S_6-A:VS]:SH@`%-O;B`V('-A871T96MI(&5N(&3\_OQK('/]8V%K;/UK
M.B``66%N<_T`375H=&5L:68`0G5L=6YA;6%Y86X@4$5!4B!P86ME=&DZ($A4
M5%!?4F5Q=65S="X`071L86YM_?X@>6%P_6QA;F3]<FUA+B!"=2!U>6=U;&%M
M87G](&MU;&QA;FUA:R!I<W1I>6]R<V%N_7H@>6%P_6QA;F3]<FUA>?T@_')E
M=&UE:R!Z;W)U;F1A<_UN_7HN`$%T;&%N;?W^(&UE<V%J($E$+@!!=&QA;FW]
M_B!O;&%N(&=E<F5K;&D@4$5!4B!P86ME=&D@36%I;"X`071L86YM_?X@;W1U
M<G5M82!A:70@240N`%!Z=`!'97II8VD@4&]S=&$`4V%K:6X`1&7P:?YI;2!4
M87)I:&D`1&7P:?YT:7(Z55),`$UO9"!486)A;OT`36]L9&]V>6$`36]N86-O
M`$UO\&]L:7-T86X`07D@=F4@>?UL`$%Y;/UK`$UO;G1S97)R870`07D@179R
M96QE<FD`1F%S`$=E;F5L;&EK;&4@0>?]:P!'96YE;&QI:VQE($)U;'5T;'4`
M1V5N96QL:6ML92!'_&YE_FQI`$'^8?#](%1A_OT`4V]L82!48?[]`%-A\&$@
M5&'^_0!9=6MA<OT@5&'^_0!!_F'P_2!T8?[]`%EU:V%R_2!T8?[]`$UO>F%M
M8FEK`,=O:VQU(&3\>F5Y(&'^8?#](&'G_6S]<B!L:7-T96QE<@#';VML=2!3
M9>=I;0!(97-A8OUM`%!O<G1A;/UM`%!O<G1A;"!$_'IE;FEM`$UY86YM87(`
M2V%B=6P@151-25E/4E5-`$%D`$YA;6EB>6$`3F%U<G4`3F5P86P`2&]L;&%N
M9&$`2&]L;&%N9&$@06YT:6QL97)I`$YE='-C87!E(%1A8F%N(%523`!.971S
M8V%P92!#02#=<'1A;"!54DP`3F5T<V-A<&4@0T$@:W5R86P@55),`$YE='-C
M87!E(%EE;FEL96UE(%),`$YE='-C87!E(-UP=&%L(%523`!.971S8V%P92!3
M4TP@<W5N=6-U(&%D_0!.971S8V%P92!O;F%Y(&)E;&=E<VD@8>?]:VQA;6%S
M_0!.971S8V%P92!O;F%Y(&)E;&=E<VD@=/QR_`!!\`!!<VQA`%EE;FD@2V%L
M961O;GEA`%EE;FD@2V%T96=O<FD`665N:2!!>0!996YI($MU;&QA;OUC_2!!
M9/T@*%-EYVEM;&DI`%EE;FD@6F5L;&%N9&$`665N:2!096YC97)E("A?8F_^
M*0!(86)E<FQE<@!(86)E<B!'<G5P;&%R_0!3;VYR86MI`%-O;G)A:VD@4V7G
M96YE:VQE<@!.:6MA<F%G=6$`3FEJ97)Y80!.:6IE<GEA`$=E8V4`3FEU90!(
M87G]<@!&87)K;&%R_6X@9_9S=&5R:6QE8FEL96-E\&D@:W5L;&%N_6QA8FEL
M:7(@>6%P_6QA;F3]<FUA('9E<FES:2!Y;VLN`$E33R!I;6%J;&%R_2!O=?YT
M=7)M86L@:>=I;B!K=6QL86[];&%B:6QI<B!B:7(@>?9N=&5M('EO:RX`6?WP
M_6X@=&%S;&'P_2!Y;VLN`-US=&5N96X@:V]N=6UD82!H:>=B:7(@]F)E:R!B
M=6QU;FUA;6%K=&%D_7(`34-!3"!D;_!R=6QA;6%S_2!IYVEN(&AIYV)I<B!T
M86MV:6T@863]('-A\&QA;FUA;?W^=/UR+B``1&7P:?YI:VQI:R!9;VL`0G4@
M:7IN92!H:>=B:7(@86QT(&EZ:6X@96ML96YE;65Y96-E:W1I<BX`)7,@:>=I
M;B!H:>=B:7(@>6%P_6QA;F3]<FUA(&)I;&=I<VD@8F5L:7)T:6QM961I+@!&
M5%`@5D93(&GG:6X@:&GG8FER('EA</UL86YD_7)M82!B:6QG:7-I(&)E;&ER
M=&EL;65D:2X`4U%,(%9&4R!IYVEN(&AIYV)I<B!Y87#];&%N9/UR;6$@8FEL
M9VES:2!B96QI<G1I;&UE9&DN`%-13"U&:6QE(%9&4R!IYVEN(&AIYV)I<B!Y
M87#];&%N9/UR;6$@8FEL9VES:2!B96QI<G1I;&UE9&DN`$MR961I('EO:RX`
M2&GG8FER('1E<VQI;2!N;VMT87/](&)E;&ER=&EL;65M:?YT:7(N`$AIYV)I
M<B!D;W-Y82!Y_&ML96YE;65D:0!(:>=B:7(@<VEM9V4@8G5L=6YA;6%D_2X`
M2&GG8FER('EE<B!B96QI<G1I;&UE9&DN`$AIYV)I<B!M97-A:B!S8?!L86YM
M863]+@!!9"!B96QI<G1I;&UE9&DN`$YU;6%R82!B96QI<G1I;&UE9&DN`%-A
M;&3]<F=A;B!D97EI_B!K=6QL86YM80!(5%10(&1O\')U;&%M87/](&GG:6X@
M<&%R;VQA(&=I<FEL;65D:2X`24U!4"!D;_!R=6QA;6%S_2!IYVEN('!A<F]L
M82!G:7)I;&UE9&DN`$ME<F)E<F]S(&1O\')U;&%M87/](&GG:6X@<&%R;VQA
M(&=I<FEL;65D:2X`3&]G:6X@9&_P<G5L86UA<_T@:>=I;B!P87)O;&$@9VER
M:6QM961I+@!005-35T0@9&_P<G5L86UA<_T@:>=I;B!P87)O;&$@9VER:6QM
M961I+@!334(@9&_P<G5L86UA<_T@:>=I;B!P87)O;&$@9VER:6QM961I+@!/
M<&5N4U-,(&EK:6QI<VEN92!H:>=B:7(@>6]L(&)U;'5N86UA9/TN3W!E;E-3
M3"!I:VEL:7-I(%!+0U,@,3(@=F5R:7-I>6QE(&-A;/W^;6%K(&GG:6X@9V5R
M96ML:2X`W'EE(&]L;6%K(&GG:6X@8F5K;&5Y96X@>6]K+@!+=7)A;"!Y;VL`
M66%N('EO:P#6;F)E;&QE:R!IYVEN(&=EYVEC:2!D:7II;B!B=6QU;F%M863]
M+@!+=6QL86[]8_T@863]('9E+W9E>6$@<&%R;VQA(&?V;F1E<FEL;65D:2X`
M1V7G97)L:2!834P@=F5R:7-I(&=E<FD@9/9N;65D:2X`1&7P97(@>6]K`-9Z
M9_QN('EA</UL86YD_7)M861A('/\<OQM(&)U;'5N86UA9/TN66%P_6QA;F3]
M<FUA>?T@=&5K<F%R(/QR971I;BX`UGIG_&X@>6%P_6QA;F3]<FUA;OUZ9&$@
M<_QR_&T@8G5L=6YA;6%D_2Y987#];&%N9/UR;6%Y_2!T96MR87(@_')E=&EN
M+@!(:>=B:7)I`$AIYV)I<FD@*-9R=/QL_"!K=6QL86[];BD`2W5Z97D@079R
M=7!A;/T@*$E33RTX.#4Y+3$P*0!.;W)F;VQK($%D87/]`$MU>F5Y(%EA<OUM
M:_QR90!+=7IE>2!-87)I86YA($%D86QA<OT`3F]R=F7G`%-O;G)A<_UN9&$@
M1&7P:6P`UFYC97-I;F1E($1E\&EL`$1I>FEN(&1E\&EL`$=E<N=E:VQE_G1I
M<FEL;65M:?X`0F5L:7)T:6QM96UI_@!$97-T96ML96YM:7EO<BX`3F]T;&%R
M`$?V>B!A=/UL86-A:R!B:7+^97D@>6]K+"!G97)I(&3V;OQN+@!+87/];0!3
M87G]`$MA<F%K=&5R('-A>?US_0!+;VQO;B!S87G]<_T`4V%T_7(@<V%Y_7/]
M`$1A\/UT_6T@;&ES=&5L97)I;FEN(&?\;F-E;&QE;FUE<VD@:>=I;B!N=6UA
M<F%L87(@8F5L:7)T:6QM96UI_BX`179E=`!.97-N90!.97-N92!987)A=/UC
M_7/]`%-E:VEZ;&EK(%-I<W1E;0!%:VEM`%-A;&3]<F=A;FS]:R!S_'IG96-I
M`$]F:7,`56UM86X`4V%D96-E($E-05`@<W5N=6-U;&%R_2!P87EL8?[];&%N
M(&1I>FEN;&5R:2!D97-T96ML96UE:W1E9&ER+@!3861E8V4@<V%L9/UR9V%N
M(&1E>6G^;&5R`%-A9&5C92!B:7(@96QE:W1R;VYI:R!P;W-T82!A9')E<VEN
M92!I>FEN('9E<FEL;65K=&5D:7(N`$)I<B!P87EL8?[];?UN('-A:&EP;&GP
M:6YI('9E>6$@<V%H:6)I;FD@<V%D96-E('-I<WEE;2!Y]FYE=&EC:7-I('9E
M>6$@<V%H:6)I(&1E\&G^=&ER96)I;&ER+@!996YI('!E;F-E<F5D92!AYP!/
M<&5N4U-,(&AA=&%S_3K=;7IA;&%N;?W^(%,O34E-12!P87+G87/];F1A;B!V
M97)I('-EYVEP(.?]:V%T_6QA;6%D_2X`0G4@8F'P;&%N=/UY_2!Y96YI('!E
M;F-E<F5D92!AYP#=_FQE=&EM(%-I<W1E;6D`4V7G96YE:VQE<@`E<R!IYVEN
M('-EYV5N96ML97(`4_UR86QA;FW]_B!,:7-T90!+=7)U;'7^`$MU<G5M<V%L
M($)I<FEM`$3\>F5N;&5M90#6>F?\;B!U>6=U;&%M82!T87-L8?#]`"5S(&GG
M:6YD96MI(/9Z9_QN('1A<VQA:VQA<CH`1&GP97(`1&GP97(@0FEL9VEL97(`
M4V%H:7`@:7II;FQE<FD`4$%-(&1O\')U;&%M87/](&UE=F-U="!D9?!I;"X`
M4$=0(%-A>?US86P@W6UZ80!01U`@WFEF<F5L96YM:?X@5F5R:0!01U`@0>?]
M:R!!;F%H=&%R_0!01U`@:6QE(-UM>F%L86YM_?XOWFEF<F5L96YM:?X@5F5R
M:0!02%`@2V]D=0!02%`@2V%B=?!U`-93($AA9FEF(%EA\&UU<@#64R!38?!A
M;F%K;&%R_0#64R!+87(`UE,@2V%R(%-A\&%N86ML87+]`-93($?V:R!G_'+\
M;'3\;/P@9OUR=/UN80!07TA0($MA8G7P=0!987-T_6ML86UA`%!A:VES=&%N
M`%!A;&%U`-W^9V%L($5D:6QM:?X@1FEL:7-T:6X@0O9L9V5S:0!086YA;6$`
M4&%P=6$@665N:2!':6YE`%!A<F%G=6%Y`$O]<VUE;B!"=6QU=&QU`%!A<F]L
M80!986YL_?X@<&%R;VQA`%)!1$E54R!D;_!R=6QA;6%S_2!IYVEN('!A<F]L
M82!G97)E:VUE:W1E9&ER+@!/;F%Y;/T@4&%R;VQA`%!A<F]L83H`4&%R;VQA
M.@!087)O;&%L87(@9?YL9?YM96L@>F]R=6YD863]<BX`66%P_?YT_7(`4&%N
M;V1A;B!Y87#]_G3]<@!9;VP`0F5K;&5Y96X@W'EE;&EK;&5R.@#=;G-A;FQA
M<@!9_'ID90!"86O];2#=_FQE;6QE<FEN:2!'97+G96ML9?YT:7(`0F%K_6T@
M:?YL96UL97)I(&=I<FG^=&4@9V5RYV5K;&7^=&ER:6QS:6X@;6D_`-UZ:6X`
MW7II;B!9]FYE=&EM:0!+:?YI<V5L($)I;&=I;&5R`%!E<G4`179C:6P@2&%Y
M=F%N;&%R`$9I;&EP:6YL97(`5&5L969O;@!&;W1O\')A9FQA<@!0:71C86ER
M;@!297-I;2!":7)I;6D`0F5Y;&EK(%/V>FQE<@!,_'1F96X@8FER:V'G(&C\
M8W)E>64@=/UK;&%Y_6X`3/QT9F5N(&)U(/;P97EI(.?]:V%R;6%K(&ES=&5D
M:?!I;FEZ:2!D;_!R=6QA>?UN.@!,_'1F96X@8G4@]O!E;FEN(&)A\/UN_2#G
M]GIM96L@:7-T961I\&EN:7H@9&_P<G5L87G];BX`3/QT9F5N(&)I<B!A>2!V
M92!B:7(@>?UL(&=I<FEN+@!,_'1F96X@>65N:2!K871E9V]R:6YI;B!A9/UN
M_2!G:7)I;CH`3/QT9F5N(&=EYV5R;&D@8FER($E0(&%D<F5S:2!G:7)I;BX`
M3/QT9F5N(&=EYV5R;&D@8FER(&?\;B!G:7)I;BP@87ED86MI(&?\;B!S87G]
M<_UN_2!K;VYT<F]L(&5D:6XN`$S\=&9E;B!G9>=E<FQI(&)I<B!Z86UA;B!G
M:7)I;BX`3/QT9F5N('-O<G5N=6X@8FER(/9Z971I;FD@>6%P_6XN`$S\=&9E
M;B!K=6QL86[]8_T@863]('9E('!A<F]L86[]>OT@9VER:6X`3/QT9F5N('EE
M;FD@:V%T96=O<FEN:2!A9/T@9VER:6XZ`%!O;&]N>6$`4&]L:71I:V$`3WEL
M86UA;&%R`%!O<G1E:VEZ`$?V<OQN=/P@:V]N=6UL86YD_7+];/UY;W(`QVEZ
M96QG92!K;VYU;6QA;F3]<OUL_7EO<@!"=2!D:7II;F4@9_9N9&5R("A)34%0
M('1A<F%F_6YD86X@>F]R;&%N;6%M86MT863]<BD`4V]N("5S('-A871T92!D
M_/YE;B!Y8?!M=7(@=F4@:V%R(&UI:W1A<OTZ`%!R969S7VQD87`Z(-US=&5N
M96X@3$1!4"!U>F%N=/US_2!B=6QU;F%M863]+@!0<F5F<U]S97-S:6]N.B#=
M<W1E;F5N(&]T=7)U;2!U>F%N=/US_2!B=6QU;F%M863]+@!"87/];N<`1&5N
M:7H@<V5V:7EE<VEN9&5K:2!B87/];N<Z`$)A<_UNYSH`UFYI>FQE;64`1_9R
M_&YT_'G\('EE;FD@<&5N8V5R961E(/9N:7IL90#6;F-E:VD@<V7G96YE:VQE
M<@!"96QG97EI('EA>F3]<@#6>F5L($%N86AT87(`4V]R=6X`4V]R=6X@5&%N
M_6UL86UA<_T`4')O:F5L97(`365T:6X@8FEL9VD@:7-T96UI`$'G_6L@06YA
M:'1A<@!!Y_UK($%N86AT87(@86QG;W)I=&UA<_T`0>?]:R_6>F5L(&%N86AT
M87(@:6MI;&ES:2!B8?YA<OUY;&$@>6%R873];&%M863]+@!0;W)T;R!2:6MO
M`$MA=&%R`%-O<F=U`%)302!!Y_UK($%N86AT87+]("@E9"!B:70I`%)A9'EO
M(%-EYVEM:0!98?!M=7(`17)K96X@4V%A=&QE<F1E(%EA\&UU<@!'9><@4V%A
M=&QE<F1E(%EA\&UU<@!38?!A;F%K(%EA\/W^`%EA\&UU<B!V92!+87(`2V%R
M82!D]F[\_F5C96L@>6'P;75R`%)A<W1G96QE($1E>6G^`$]R86X`3VMU;6$`
MW6QE=&EL97)I($]K=0!3:6QM96L@:7-T961I\&EN:7IE(&=E<N=E:W1E;B!E
M;6EN(&UI<VEN:7H_*$)U(&G^;&5M(&=E<FD@YV5V<FEL96UE>BDZ)7,`2W5L
M;&%N_6/]("5S(&4@86ET(&MU;&QA;OUC_2!V97)I;&5R:6YI('-I;&UE:R!I
M<W1E9&GP:6YI>F4@96UI;B!M:7-I;FEZ+B!"=2!I_FQE;2!G97)I(.=E=G)I
M;&5M97HN`%-O;B!E>6QE;6D@=&5K<F%R;&$`1&5V:6YG96X@365N_"#6\&5L
M97)I;FD@5&%Z96QE.@!0;W)T86P@1_9R_&[\;?QN_"!487IE;&4Z`$3\>F5N
M;&D@W69A9&4`W6QI_FMI(%1A<F%Y_6/]`$'G_6ML86UA;&%R`%5Z86MT86MI
M(%-U;G5C=6QA<@!5>F%K=&%K:2!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC
M;VTO:&]R9&4I.@!3:6P`UF)E\&D@4VEL`$MO;&]N=2!3:6P`0FGG:6UL96UE
M>6D@4VEL`$EK:6QI>6D@4VEL`$MA>61E9&EL;6G^(&)E=&GP:2!S=6YU8W5N
M=2!G9>=I8VD@9&EZ:6YI;F1E;B!S:6PN`%-I;`!"=2!P87+G87G](&)E;&=E
M9&5N(.?]:V%R=`!+=6QL86[]8_T@4VEL`$MU;&QA;OUC_7G]('-I;#H@)7,`
MW7-T96L@8V5V87!L86YA;6%D_2Y$]F[\;&5N(&AA=&$@:V]D=3H@`$=E<F5K
M96X@06QA;@!496UI>FQE`%!A<F]L87G]('/]9OUR;&$`4&%R;VQA;OUZ_2!S
M_6;]<FQA>?UN`%-O;G7G;&%R`%-EYV5N96ML97)E($3V;OQN`%)E=6YI;VX`
M66%P_6QA;F3]<FUA>?T@1V5R:2!$]FYD_'(`6F5N9VEN($UE=&EN($3\>F5N
M;&5Y:6-I<VD@4V7G96YE:VQE<FD`0FEL;65C96QE<@!38?``4V'P(&)A_FS]
M:R!B:6QG:7-I`$1O\')U(&1E\&5R;&5R`%-A7W3]<B#6>F5L;&EK;&5R:2XN
M+@!']G)E=@!2;VUA;GEA`#$X,"!D97)E8V4@9/9N9/QR`%-O;&$@1/9N9/QR
M`%-A\&$@1/9N9/QR`%-A=/UR(-9Z96QL:6ML97)I`%-A=/UR(/9Z96QL:6ML
M97)I`%-A=/UR;&%R.@#':7IG:6QE<@#':7IG:6QE<B!T_&T@<V%T_7(@=F4@
M:V]L;VYL87(@87)A<_UN9&$@8F5L:7)E8V5K=&ER`,=I>F=I;&5R('-A9&5C
M92!K;VQO;FQA<B!A<F%S_6YD82!B96QI<F5C96MT:7(`QVEZ9VEL97(@<V%D
M96-E('-A=/UR;&%R(&%R87/];F1A(&)E;&ER96-E:W1I<@#'86S]_G3]<@!2
M=7-Y82!&961E<F%S>6]N=0!2=6%N9&$`4R]-24U%(-YI9G)E;&5M92#=;7IA
M<_T`4R]-24U%(&EL92#>:69R96QE;FUI_B#=;&5T:0!305-,(&1O\')U;&%M
M87/](&UE=F-U="!D9?!I;"X`4TU3($UE<V%J;&'^;6$`4U%,($MA8G7P=0!3
M4T@`0D'>05))3$D`4U]13"!+86)U\'4`0W1S`%-A:6YT($AE;&5N80!386EN
M="!+:71T<R!V92!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@=F4@
M36EQ=65L;VX`4V%I;G0@5FEN8V5N="!V92!'<F5N861I;F5S`$%Y;OT@YV5R
MYV5V92`H:V5N7V1I<VDI`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@=F4@
M4')I;F-I<&4`57ED=2!38?!L87G]8_T`4W5U9&D@07)A8FES=&%N`$MA>61E
M=`!+87ED970@)7,`4V7G96YE:VQE<FD@2V%Y9&5T`$]L=?YT=7)U;&%N('EA
M</UL86YD_7)M87G](%!(4"!B971I\&D@;VQA<F%K('-U;G5C=6YU;B!G9>=I
M8VD@9&EZ:6YI;F4@:V%Y9&5T+@`E<R!Y87#];&%N9/UR;6%S_2!K87ED961I
M;&1I+@!":6QI;0!!<F%M80!!<F%M82!-;W1O<FQA<OT`1&]S>6%L87+](%-E
MYP!":7(@=&%R:6@@<V7G:6X`16ML96UE:R!IYVEN(&)I<B!G<G5P('-EYVEN
M`%EE;FD@<V%H:6)I('-EYVEN`$)I<B!S=6YU8W4@<V7G:6X`16ML96UE:R!I
MYVEN(&)I<B!K=6QL86[]8_T@<V7G:6X`0OQT_&X@=&%R:6@@8FEL9?YE;FQE
M<FEN:2!S9>=I;@!":7(@;F5S;F4@<V7G:6X`W7-T961I\&YI>B!K87)A:W1E
M<FQE<FD@8?YA\/UD86MI(&MU='5L87)D86X@<V7G:6XN($1A:&$@<V]N<F$@
M;65T:6X@86QA;OUN9&%N(&MO<'EA;&%Y_7`@>6%P_?YT_7)A8FEL:7)S:6YI
M>BX`5&%R:6@@<_UN_7)L87G]8_US_6[]('-EY_UN.@!487)I:"!B:>=I;6EN
M:2!S9>=I;CH`1&7P:?YT:7)M96L@:7-T961I\&EN:7H@:VEM;&GP:2!S9>=I
M;CH`4V%A="!S_6[]<FQA>?UC_7/];OT@<V7G:6XZ`%-A870@8FGG:6UI;FD@
M<V7G:6XZ`$7^;&7^96X@:6MI(&%L86[]('-EYVEN+@!296YK(&3\>F5N:6YI
M>FD@<V7G:6XN`%1E<F-I:"!E='1I\&EN:7H@9&EL:2!S9>=I;CH`4V]R=6X@
M4F%P;W)U($?V;F1E<@!335,@1_9N9&5R`%-E;F5G86P`06QG_6QA>?UC_3H`
M17EL_&P`4_UR8FES=&%N('9E($UO;G1E;F5G<F\`4V5R:2!.=6UA<F%S_0!/
M='5R=6T@:VEM;&GP:6YI;B!S_')E<VD@9&]L9'4N`$)E;&ER=`!087)O;&%N
M_7K];OT@=6YU='5R<V%N_7H@<_UF_7)L86UA;OUZ82!I>FEN('9E<F5C96L@
M<V7G96YE:VQE<FD@8F5L:7)T:6XN(`!5;&'^;6%K(&ES=&7P:6YI>B!U>F%K
M=&%K:2!S=6YU8W5L87+](&)E;&ER;&5Y:6XN`%1E<F-I:"!E='1I\&EN:7H@
M9&EL+"!S86%T(&1I;&EM:2!V92!T87)I:"!S9>=E;F5K;&5R:6YI(&)E;&ER
M;&5Y:6XN`$)A_FQA;F?]YR!U>6=U;&%M86[]>OTL(')E;FL@9/QZ96YI;FEZ
M:2P@<V%Y9F$@=&%Z96QE;64L('9E(&1I\&5R(&?V<OQN=/P@<V7G96YE:VQE
M<FEN:2!B96QI<FQE>6EN+@!!>6%R;&%R`$MU<G5L=6T@9_QN8V5L;&5M92!B
M971I:VQE<FD@:W5L;&%N_6QA8FEL:7(@9'5R=6UD82X`1&7P:?YT:7)G92!I
M;&4@8FER9&5N(&9A>FQA('EE<B!M_&UK_&XZ(`!397G^96P`06S]_B!V97)I
M_@!+_7-A(-9Z970`QV_P=2!B8?!L86YT_2!IYVEN(&5R:?YI;2!A;F%H=&%R
M_2!T86[];6QA;G/];B!M_3\`1_9S=&5R`$AA;&5N(&MA>?UT;/T@;VQA;B!Y
M87#];&%N9/UR;6$@:6QE('EE;FD@>6%R873];&%N('EA</UL86YD_7)M82!A
M<F%S_6YD86MI(&9A<FML87+](&?V<W1E<BX`1VER:?YT92!E;B!S;VX@9VER
M:?X@=&%R:6AI(&?V<W1E<FEL<VEN(&UI/P#6>F?\;B!O;&%N_2!S86ML86UA
M('-EYV5N9?!I;FD@9_9S=&5R`%-EYVEC:7EI(&?V<W1E<@#':7IE;&=E(&G^
M;&5M;&5R:2!M96[\(.=U8G7P=6YD82!G]G-T97)I;'-I;B!M:3\`)7,@365N
M_'/\('-O;&1A(&?V<W1E<FEL<VEN(&UI/P!486)L;R!(_&-R92#6>F5L;&EK
M;&5R:2!+=71U<W5N=2!G]G-T97(`5&%B;&\@UGIE;&QI:VQE<FD@2W5T=7-U
M;G4@9_9S=&5R`%1A8FQO(%-A=/UR(-9Z96QL:6ML97)I($MU='5S=6YU(&?V
M<W1E<@!']G+\;G3\(/9Z96QL:6ML97)I(&MU='5S=6YU(&?V<W1E<@!9_&ML
M96UE>6D@9_9S=&5R`%-A\&%N86L`17)K96X@4V%A=&QE<F1E(%-A\&%N86L`
M1V7G(%-A871L97)D92!38?!A;F%K`,=E=G)E9&4@4V'P86YA:P!+_.?\;'0`
MW6QK(&]L87)A:R!K;VW^=2#V\&5L97(@:_SG_&QT<_QN('EA9&$@=&'^_6YS
M_6X`4VEE<G)A($QE;VYE`-QY92!O;`#=;7IA`-UM>F$@06QG;W)I=&UA<_T`
M4VEN9V%P=7(`0F]Y=70`0F%K_6W]($%T;&$`4VQO=F%K>6$`4VQO=F5N>6$`
M2V%R`$MA<B!38?!A;F'P_0!+87(@4V'P86YA:VQA<OT`17)K96X@4V%A=&QE
M<F1E($MA<B!38?!A;F%K;&%R_0!'9><@4V%A=&QE<F1E($MA<B!38?!A;F%K
M;&%R_0!+87(@1&5R:6YL:?!I.B``66'P86X@:V%R_6X@<W4@9?YI=&DZ(`!3
M;VQO;6]N($%D86QA<OT`4V]M86QI`-YA<FO];&%R("8@WFEI<FQE<@!3_7)A
M;&%M82!D_'IE;FD@<V7G:6UI`$MA>6YA:R!A9')E<VD`1_QN97D@069R:6MA
M`$?\;F5Y($%V<G5P82`H25-/+3@X-3DM,RD`1_QN97D@1V5O<F=I82!V92!'
M_&YE>2!386YD=VEC:"!!9&%L87+]`$?\;F5Y(%EA<OUM:_QR90!":71I_FEK
M(&C\8W)E;&5R(&%R87/];F1A:VD@8F_^;'5K`$C\8W)E9&5K:2!S_6[]<B!V
M92!IYV5R:6L@87)A<_UN9&%K:2!B;_YL=6L`0F_^;'5K($%Y87)L87G]8_T`
M07)A;/UK(&+]<F%K;6$`07)A;/UK(&+]<F%K;6$@=F4@>6%S=/UK;&%M80#=
M<W!A;GEA`-US=&5N;65Y96X@W6QE=&D`UGIE;"!+87)A:W1E<B!':7)I_FD`
M2/QC<F5Y:2!B]FP`2V]L;VYU(&+V;`!3873]<OT@8O9L`%-P;W)L87(`4W)I
M($QA;FMA`%-T86YD87)T`%5Z87D@66]L=0!"8?YL86YG_><@>?UL_0!%>6%L
M970@=F5Y82#=;`!$=7)U;0!$97!O;&%M82!B:>=I;6D`4V]K86L@061R97-I
M`-QS=/P@YVEZ9VEL:0!$:7IG:2!L:7-T97-I`$%D<F5S=&5N(&%L86X@863]
M;OT@Y_UK87)T`%-I=&EL(%M#4U-=`%!Z<@!+;VYU`$?V;F1E<@!!;'1S:6UG
M90!"8?YA<OT`66%P_6QA;F3]<FUA(&)A_F%R_7EL82!G97)I(&3V;F3\<OQL
M9/PN($1E\&G^:6ML:6ML97)I(&?V<FUE:R!IYVEN('EE;FED96X@>?QK;&5Y
M:6XN`%EE9&5K('EA</UL86YD_7)M82!B8?YA<OUY;&$@:V%Y9&5D:6QD:2X`
M665D96L@>6%P_6QA;F3]<FUA(&1O<WEA<_T@)7,@8F'^87+]>6QA(&MA>61E
M9&EL9&DN`"5S(&)A_F%R_7EL82!Y87K];&3]+@!3=61A;@#6>F5T`$?\;B!$
M;_!U;74`1_QN(&)A=/UM_0!'_&YE_FQI`$?\;B!D;_!U;74`1_QN(&1O\'5M
M=2]'_&X@8F%T_6W]`$?\;B!D;_!U;74Z(`!'_&X@8F%T_6W]`$?\;B!B873]
M;?TZ(`#<<W1S:6UG90!$97-T96L`4W5R:6YA;0!3;WEA9/T`4W9A;&)A<F0@
M=F4@2F%N($UA>65N`%-V87II;&%N9`#=<W9EYP#=<W9IYW)E`$%R86UA('1E
M<FEM;&5R:6YD92!S]GID:7II;2!H871A<_T`4W5R:7EE`$?V:R!G_'+\;'3\
M;/P@9OUR=/UN80!']FL@9_QR_&QT_&S\(&;]<G3];F%L87(`5%-6(&1O<WEA
M<_T`QVEZ96QG90#'27IE;&=E(-9Z96QL:6ML97)I`,=I>F5L9V4@]GIE;&QI
M:VQE<FD`5&%Y=F%N`%1A>79A;BP@QVEN(&5Y86QE=&D`5&%C:6MI<W1A;@!4
M86YZ86YY80!(961E9CH`1_9R979L97(`5&5L969O;B!.=6UA<F%S_0!3;VX@
M<V%A="!IYVEN('/]8V%K;/UK.B``4_UC86ML_6L`4_UC86ML_6LZ(`!487-L
M86L@6?9N971I;6D`365T:6X`4V%D96-E($UE=&EN`$UE=&EN(&AI>F%L86UA
M<_T`365T;FEN(-QS=/P`4'+^`%1A:2`H5$E3+38R,"D`5&%Y;&%N9`!3:7-T
M96UI(&MU;&QA;OUD_?#];OUZ(&GG:6X@=&7^96MK_'(@961E<FEZ+@!&5%`@
M=7IA;G3]<_T@:W5L;&%N_6QA8FEL:7(@9'5R=6UD82!D9?!I;"X`2&]R9&4O
M2V]L86(@8OQT_&YL9?YT:7)M92!M;W1O<G4@9&5S=&5K;&5M96UE:W1E9&ER
M.B`B)7,B`$)A:_UM.CH@<_UN_68@8F'^87+]>6QA('G\:VQE;F5M961I+@#>
M9>=E;F5K;&5R('!E;F-E<F5S:2!K87!A;F3]+L?]:_W^('EA</UL_7EO<BX`
M1?!E<B!I>FEN;&5R:2!K=6QL86YM86L@:7-T:7EO<G-A;OUZ('GV;F5T:6-I
M;FEZ:6X@W7II;B!S:7-T96UI;FD@>6%P_6QA;F3]<FUA<_T@9V5R96MM96MT
M961I<BX`4V%D96-E(&%L="!T87)A9@#=;&5T:?YI;2!N;VMT87/];OUN($E$
M)W-I(&)E;&ER;&5N96UE9&DL(&)O_B!B_7)A:_UL;?W^('9E>6$@=F5R:2!T
M86)A;OUN9&$@8G5L=6YA;6%D_2X`W6QE=&G^:6T@;F]K=&%S_2!B8?YA<OUY
M;&$@861R97,@9&5F=&5R:6YI>F4@96ML96YD:2X`Q_UK87)T_6QM_?X@4$=0
M(&EM>F$@]F)E\&D@:6UZ86QA;FW]_B!I;&5T:6YI;B!D;_!R=6QU\'5N=6X@
M<V'P;&%N;6%S_2!IYVEN(&=E<F5K;65K=&5D:7(N`$1A\/UT_6T@;&ES=&5S
M:2!)1"=S:2!B96QI<FQE;F5M961I+"!B;_X@8OUR86O];&W]_B!V97EA('9E
M<FD@=&%B86[];F1A(&)U;'5N86UA9/TN`$1A\/UT_6T@;&ES=&5S:2!B96QI
M<FQE;F5M961I+@#>:69R96QE;64@]GIE;&QI:VQE<FD@9_QV96YL:2!B:7(@
M=V5B(&)A\&QA;G3]<_T@9V5R96MT:7)M96MT961I<BX`)7,@9&]S>6%S_2`E
M<R!A>6%R_2!IYV5R;65L:61I<BX`)7,@9&]S>6%S_2`E<R!A>6%R;&%R_2!I
MYV5R;65L:61I<BX`1&]S>6$@:V5N9&D@_'IE<FEN92!K;W!Y86QA;F%M87HN
M`$1O<WEA('9E<FD@:>=E<FUI>6]R+@!486MI<"!E9&5N;&5R(&)U(&EL971I
M+W)F8S@R,B!I;&5T:7-I(&GG:6X@8F'^;/UK(&)I;&=I;&5R:61I<BX`0?YA
M;6%D_?#];?UZ('1A<F%Y_6/](&AA=&%L87+]('-E8F5B:7EL92!T86T@96MR
M86X@:VEP:6YI;B!);G1E<FYE="!%>'!L;W)E<B=L82!B:7)L:6MT92!S;W)U
M;B#G_6MA<F3]\/T@8FEL:6YM96MT961I<BX@06YL86US_7H@9_9R_&YT_&QE
M<FQE+"#G86S]_FUA>6%N(&UE=&EN(&3\>F5N;&5Y:6-I(&G^;&5R:7EL92!V
M92]V97EA('1A<F%Y_6/];OUN(')A<W1G96QE(.?V:VUE<VEY;&4@:V%R_OUL
M8?YA8FEL:7)S:6YI>BX@1?!E<B!S:7-T96UI;FEZ(%=I;F1O=W,@.7@@:7-E
M('G\:W-E:R!I:'1I;6%L("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&AA
M=&%S_2!A;/UP('-I<W1E;6D@>65N:61E;B!B8?YL871M86[]>B!G97)E:V5C
M96LN7&Y<;D)U(&)I<B!U>6%R_7ED_2X@1?!E<B!H86QA('1A;2!E:W)A;B!M
M971I;B!D_'IE;FQE>6EC:7-I;FD@9&5N96UE:R!I<W1I>6]R<V%N_7H@179E
M="=I('3]:VQA>?UN+@!+:6UL:6L@(B5S(B!S:6QI;F1I+@!3861E8V4@<V]L
M('1A<F%F`$-R>7!T7W!G<#HZ('/];OUF_6YA($=N=5!'(&EK:6QI<VEN:6X@
M:V]N=6UU('9E<FEL;65K('IO<G5N9&%D_7(N`"5S('1A<FEH:6YD92`E<R!E
M(&?V;F1E<FEL96X@(B5S(B!K;VYU;'4@:6QE=&D@9_9R_&YT_&QE;F1I+@I"
M=2!I;&5T:6YI;B!O:W5N9'7P=2!V97EA(&%N;&'^_6QD_?#];OT@9V%R86YT
M:6QE;65M96MT961I<BX`3VQU_G1U<B!P96YC97)E<VEN92!B8?!L86[]<FME
M;B!K=6QL86[];&%C86L@:7-I;0!(;W)D95]#<GEP=%]S:6UE.CH@<_UN_6;]
M(&]P96YS<VP@8FER:6UI(&GG:6X@9V5R96MM96MT961I<BX`(B5S(B!T97)C
M:6AI('9E<FES:2!I>FEN('9E<FEL96X@96X@>?QK<V5K(&)O>75T=2!G9>=T
M:?!I(&GG:6X@:V%Y9&5D:6QE;65M96MT961I<BX`0G4@=F5R:2!Y87!S_6[]
M*"5S*2!G]G-T97)M96L@:>=I;B!K=6QL86[];&%N('!R;V=R86T@<VES=&5M
M9&4@8G5L=6YM86UA:W1A9/UR+@!3861E8V4@<V]L('9E('-A\"!T87)A9FQA
M<@!3861E8V4@<V'P('1A<F%F`"(E<R(@<W5N=6-U<W4@<VEL:6YD:2X`(B5S
M(B!S=6YU8W5S=2!K87ED961I;&1I+@`E<R!IYVEN(&]L86X@_'EE;&EK(&ES
M=&7P:2!S:6QI;F1I+@!"96QI<G1I;&5N('-A=/UR(&)U;'5N;6%M86MT863]
M<BX`1V7G:6-I(&1O<WEA("(E<R(@8G5L=6YM86UA:W1A9/UR+@!3861E8V4@
M_'-T('9E(&%L="!T87)A9FQA<@!3861E8V4@_'-T('1A<F%F`$)I<B#V;F-E
M:VD@863];2!S_7)A<_UN9&$@>?QK;&5N96X@=F5R:2!K87EB961I;&1I+@!9
M_&ML96YE;B!D;W-Y82!K87ED961I;&5M961I+@!W96%T:&5R+F-O;2!K=6QL
M86[];&%B:6QI<B!D9?!I;"X`2&GG8FER('-EYV5N96L@;65V8W5T(&1E\&EL
M+@!-971N92!G]FW\;/P@;VQA<F%K(&?V<W1E<FEL96)I;&5C96L@:_US_6T@
M>6]K`$)U(&%L86YD82#G;VL@9F%Z;&$@:V%R86MT97(@=F%R+B5S('1A;F4@
M:V%R86MT97(@9VER9&EN:7H[("5S('1A;F5D96X@87H@9VER;65N:7H@9V5R
M96MI<F1I+@!$;W-Y82`H:V%R_OUD86XI('G\:VQE;FUE<VEN9&4@<V]R=6X@
M=F%R.B`E<R!Y_&ML96YE;65D:2X`1&]S>6$@>?QK;&5N:7)K96X@8FER('-O
M<G5N(&]L=?YT=3H@)7,@96X@8OQY_&L@:7II;B!V97)I;&5N(&)O>75T=&%N
M("@E9"!B>71E*2!D86AA(&+\>?QK+@!$;W-Y82!Y_&ML96YI<FME;B!B:7(@
M<V]R=6X@;VQU_G1U.B`E<R!S861E8V4@:_US;6D@;VQA<F%K('G\:VQE;F1I
M+@!);&5T:6YI;B!B=2!K_7-M_6[](&?V<OQN=/QL96YM97-I;F1E(&AA=&$@
M;VQU_G1U+@#=;&5T:?YI;2!N;VMT87/];OUN('9E<FEL97)I("AIYV5R:2D@
M86MT87+];/UR:V5N(&AA=&$@;VQU_G1U+@!I0V%L96YD87(@=F5R:7-I("AI
MYV5R:2D@86MT87+];/UR:V5N(&AA=&$@;VQU_G1U+@!987#];&%N9/UR;6$@
M9F]R;75N9&$@8FER(&AA=&$@=F%R+B!'97)E:VQI(&)I<B!A;&%N_2!D;VQD
M=7)M86W]_B!O;&%B:6QI<G-I;FEZ+@!"96QI<G1I;&5N(&%D<F5S(&1E9G1E
M<FD@:?YL979I;FEN(&=E<N=E:VQE_G1I<FEL;65S:2!S_7)A<_UN9&$@<V]R
M=6X@;VQU_G1U+B!,_'1F96X@9&%H82!S;VYR82!T96MR87(@9&5N97EI;BX`
MW6QE=&G^:6T@;F]K=&%S_6[];B!A>7+];G3];&%R_6[](&?\;F-E;&QE<FME
M;B!H871A(&]L=?YT=2X@3/QT9F5N(&1A:&$@<V]N<F$@=&5K<F%R(&1E;F5Y
M:6XN`$1A\/UT_6T@;&ES=&5S:6YI(&?\;F-E;&QE<FME;B!B:7(@:&%T82!O
M;'7^='4N($S\=&9E;B!D86AA('-O;G)A('1E:W)A<B!D96YE>6EN+@!"=2!)
M34%0('-U;G5C=7-U('!A>6QA_OUL86X@9&EZ:6YL97)I(&1E<W1E:VQE;6EY
M;W(N`$)U(&=EYV5R;&D@8FER(')A<B!A<OYI=FD@9&7P:6PN`$)U(&=EYV5R
M;&D@8FER('II<"!D;W-Y87/](&1E\&EL+@!"=2!G9>=E<FQI(&)I<B!K87)T
M(&YU;6%R87/](&1E\&EL+@!"=2!S_'+\8_P@0VQI8VMA=&5L;"`H:'1T<#HO
M+V-L:6-K871E;&PN8V]M*2!A\"!G9>=I9&D@_'IE<FEN9&5N($A45%`@05!)
M(&MU;&QA;F%R86L@;65S86H@871M86[]>F$@:7II;B!V97)I<BX`0G4@<_QR
M_&/\('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"D@8?`@9V7G:61I(/QZ
M97)I;F1E;B!(5%10($%022!K=6QL86YA<F%K(&UE<V%J(&%T;6%N_7IA(&EZ
M:6X@=F5R:7(N`$)U('/\<OQC_"!33510('EO;'5Y;&$@5F]D869O;F4@271A
M;'D@8?`@9V7G:61I(/QZ97)I;F1E;BP@<V%D96-E(%9O9&5F;VYE(&YU;6%R
M86QA<OUN82!M97-A:B!A=&UA;OUZ82!I>FEN('9E<FER+B!6;V1E9F]N92!)
M=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I(&5L96MT<F]N:6L@<&]S=&$@861R
M97-I(&=E<F5K=&ER;65K=&5D:7(N`$)U(&=E<F5K;&D@8FER(&%L86YD_7(N
M`$)U(&%L86X@<V%D96-E('-A>?T@:>=E<FUE;&ED:7(N`$)U(&%L86X@<V%D
M96-E('-A>?T@=F4@:6MI(&YO:W1A(/QS=/QS=&4@:?YA<F5T:2!IYV5R96)I
M;&ER+@!"=2!A;&%N('-A9&5C92!S96MI>FQI:R!S87G]('-I<W1E;6EN9&5N
M(&1E\&5R;&4@:>=E<F5B:6QI<BX`0G4@86QA;B!V:7)G_&P@=F5Y82!B;_YL
M=6ML82!A>7+];&W]_B!S87G](&QI<W1E(&]L;6%L_63]<BX`0G4@86QA;B!G
M9>=E<FQI(&)I<B!N=6UA<F$@;VQM86S]9/UR+@!"=2!A;&%N(%)'0B!(97@@
M8FGG:6UI;F1E(&)I<B!R96YK(&MO9'4@:>=E<FUE;&ED:7(L(/9R;F5K.B`G
M(S$R,S1A9B<`0G4@9F]R;2!Z871E;B!I_FQE;F1I+@!"=2`E<RX`0G4@8FER
M($MO;&%B($=R;W5P=V%R92!N97-N97-I9&ER+B!"=2!N97-N97EI(&?V<F5B
M:6QM96L@:>=I;B!+;VQA8B!'<F]U<'=A<F4@8FGG:6UI;FD@86YL87EA8FEL
M96X@8FER(&5L96MT<F]N:6L@<&]S=&$@:7-T96UC:7-I;F4@9V5R96L@=F%R
M+D)U(&5L96MT<F]N:6L@:7-T96UC:2!L:7-T97-I(&GG:6X@)7,@861R97-I
M;F4@=?!R87G];BX`0G4@:6QE=&D@<VEZ:6X@:V%R86MT97(@:_QM96YI>F1E
M;B!F87)K;/T@;VQA<F%K*"5S*2!Y87K];&W]_G3]<BX`0G4@;G5M87)A(&5N
M(&%Z_6YD86X@8FER(&]L;6%L_63]<BX`0G4@<W5N=6-U('II<"!V92!G>FEP
M(&1O<WEA;&%R_6[](&'G86UA;6%K=&%D_7(N`%-I<W1E;6EN(&5T:VEN;&GP
M:2!K86QD_7+];&W]_G3]<BX`0G4@9&7P97(@8FER('-A>?T@;VQM86S]9/UR
M+@!"=2!P96YC97)E(%-EYV5N96ML97(@<&5N8V5R97-I;F1E;B#G8?!R_6QM
M86S]9/UR+@!']FL@9_QR_&QT_'/\`$)I;&5T;&5R`%IA;6%N`%IA;6%N(-UZ
M;&5M90!:86UA;B!":>=I;6D`6F%M86X@4V7G:6UI`%1I;6]R+4QE<W1E`$)A
M_FS]:P!"8?YL_6L@*&'G_6ML86UA*3H`2VEM90#';VML=2#V\&4@<V7G:6UI
M(&GG:6XL('3]:VQA<FME;B!#;VYT<F]L("A00RD@=F5Y82!#;VUM86YD("A-
M86,I('1U_G5N82!B87/];BX`0G5G_&X`2%1-3"!+87EN8?#];F$@1V7G:6X`
M5&]G;P!4;VME;&%U`%EA<OUN`%1O;F=A`-QS=`#<<W0@QV5RYV5V92`HW%]S
M="D`QV5V:7)I;&5R`%1R:6YI9&%D('9E(%1O8F%G;P!$;_!R=2!V97EA(%EA
M;FS]_@!380!4=6YU<P!4_')K:7EE`%3\<FOG92`H25-/+3@X-3DM.2D`5/QR
M:VUE;FES=&%N`%1U<FMS('9E($-A:6-O<R!!9&%L87+]`%1U=F%L=0!39>=I
M;6EN:7II(&=I<FEN.@!5+E8N(&5N9&5K<SH@`%523`!"971I:VQE<FEN(&1U
M<G5M(')A<&]R;&%R_6[];B!T97-L:6T@961I;&5C9?!I(%523`!54DPZ`%5G
M86YD80!5:W)A>6YA`%9&4R!D:7II;FEN92!E<FG^:6QE;65M:7EO<BX`W'EE
M(&]L=7)K96X@96L@:W5L;&%N_6/](&)I;&=I<VD@96ML96YE;6EY;W(N`"(E
M<R(@5D93(&1O<WEA<_UN_6X@:7II;FQE<FD@9&7P:?YT:7)I;&5M:7EO<BX`
M)7,O)7,@5D93(&1O<WEA<_UN_6X@:7II;FQE<FD@9&7P:?YT:7)I;&5M:7EO
M<BX`)7,@9&7P:?YT:7)I;&5M961I+@!344P@<W5N=6-U<W5N82!B8?!L86[]
M;&%M_7EO<BX`4U-,(&EL92!B8?!L86[];&%M_7EO<BX`5D93(&1O<WEA<_T@
M:V]P>6%L86YA;?UY;W(N`"(E<R(@5D93(&1I>FEN:2!Y87)A=/UL86W]>6]R
M+@!61E,@9&EZ:6YI('EA<F%T_6QA;?UY;W(N`%9&4R!D;W-Y87/]('EA<F%T
M_6QA;?UY;W(N`$)O_B!61E,@9&]S>6%S_2!Y87)A=/UL86W]>6]R+@!697)I
M('/]:_W^=/UR_6QA;?UY;W(N`"(E<R(@9&EZ:6YI('-I;&EN96UI>6]R+"!D
M:7II;B!B;_X@9&7P:6PN`"5S('-I;&EN96UI>6]R+"!D:7II;B!B;_X@9&7P
M:6P`5D93(&1I>FEN:2#V>GEI;F5L:2!O;&%R86L@<VEL:6YE;6EY;W(N`%9&
M4R!D:7II;FD@<VEL:6YE;6EY;W(N`%9&4R!D:7II;FD@<VEL:6YE;6EY;W(Z
M("5S+@!61E,@9&]S>6%S_2`B)7,B('-I;&EN96UI>6]R+@!61E,@9&]S>6%S
M_2!S:6QI;F5M:7EO<BX`5D93(/9Z>6EN96QI(&]L87)A:R!S:6QI;F5M:7EO
M<CH@)7,N`%G\<OQR;/QK=&5K:2!D:7II;F4@:V%R87(@=F5R:6QE;6EY;W(N
M`$]N87D@8F5L9V5S:2!A>7+];G3];&%R_2#G_6MA<G3];&%M_7EO<@!486[]
M;?T@>?QK;&5N96UI>6]R.B`E<P!61E,@9&]S>6%S_2!T8?[];F%M_7EO<BX`
M5D93(&1O<WEA<_T@(B5S(B!AY_UL86W]>6]R+@!61E,@9&]S>6%S_2!Y86UA
M:R!IYVEN(&'G_6QA;?UY;W(N`%9&4R!D;W-Y87/](&'G_6QA;?UY;W(N`%/]
M:_W^=/UL_6W]_B!A<OYI=B!AY_UL86W]>6]R+@!69G-R;V]T(&1I>FEN:2!O
M:W5N86W]>6]R+@`E<RT^)7,@;VQA<F%K('EE;FED96X@861L86YD_7+];&%M
M_7EO<CH@:&5D968@9&EZ:6X@>F%T96X@=F%R+@!61E,@9&EZ:6YI('EE;FED
M96X@861L86YD_7+];&%M_7EO<BX`5D93(&1I>FEN:2!Y96YI9&5N(&%D;&%N
M9/UR_6QA;?UY;W(Z("5S`%9&4R!D;W-Y87/]("(E<R(@>65N:61E;B!A9&QA
M;F3]<OUL86W]>6]R+@`E<R\E<R!61E,@9&]S>6%S_2!Y96YI9&5N(&%D;&%N
M9/UR_6QA;?UY;W(N`%9&4R!D;W-Y87/]('EE;FED96X@861L86YD_7+];&%M
M_7EO<BX`)VUK:7-O9G,G(.=A;/W^=/UR_6QA;?UY;W(N`$)U(%=O<F0@8F5L
M9V5S:2#G979I<FEL:6QE;6EY;W(N`%9&4R!D;W-Y87/]("(E<R(@>6%Z_6QA
M;?UY;W(N`%9&4R!D;W-Y87/]('EA>OUL86W]>6]R("AC;W!Y*"D@8F'^87+]
M<_UZ(&]L9'4I+@!61E,@9&]S>6$@=F5R:7-I('EA>OUL86W]>6]R+@!!;'3]
M;OT@YVEZ`$1E\&G^:6ML:6ML97)I($=E<FD@06P`4V]N(&5Y;&5M:2!G97)I
M(&%L`$)A\&QA;G3]9&$@<W5N=6-U9&%N(&)E:VQE;FUE>65N('EA;OUT.B``
M4W5N=6-U9&%N(&)E:VQE;FUE>65N('EA;OUT.B``1&]L9'5R=6QM86W]_@!5
M;FEC;V1E("A55$8M."D`0FER;&7^:6L@07)A<"!%;6ER;&EK;&5R:0!":7)L
M9?YI:R!+<F%L;/UK`$%M97)I:V$@0FER;&7^:6L@1&5V;&5T;&5R:0!!;65R
M:6MA($)I<FQE_FEK($1E=FQE=&QE<FEN:6X@2_SG_&L@57IA:R!!9&%L87+]
M`$)I<FEM;&5R`$)I;&EN;65Y96X`0FEL:6YM97EE;B!A<&EM<V=I9"`H05!)
M($UE<V%J($E$*0!":6QI;FUE>65N(&-L:6US9VED("C=<W1E;6-I(&UE<V%J
M($E$*0!":6QI;FUE>65N(&MU;&QA;OUC_2!A9/T@=F5Y82!P87)O;&$N`-YU
M(&%N:VD@]O!E;FEN(&)A\/UN_2#G]GH`W7-I;7-I>@!!>7+]8V%L_6MS_7H@
M8F5T:6ML97(@<')O9W)A;7-A;"!O;&%R86L@2V5S+TMO<'EA;&$O66%P_?YT
M_7(G82!G_'9E;FQI:R!N961E;FEY;&4@97)I_F5M97IL97(N($)E=&EK;&5R
M:6X@<&%N;WEA(&YA<_UL('5L8?YA8V'P_6[](&?V<W1E<F5N(&UO>FEL;&$N
M;W)G('1E:VYI:R!N;W1U;G4@9_9R;65K(&GG:6X@159%5"!I('3]:VQA>?UN
M+@!"96QI<G1I;&UI_B!R96YK=&5N('9A>F=EYP!$97-T96ML96YM97EE;B!5
M>F%N=/T`1_QN8V5L;&4`1_QN8V5L;&4Z("5S`$MU;&QA;OUC_7G](&?\;F-E
M;&QE`%G\:W-E;'1M92!B971I\&D@<VEL:6QN9&DN`%G\:VQE`$+\=/QN('5Y
M9W5L86UA;&%R_6X@87EA<B!D;W-Y86QA<OT@<W5N=6-U>6$@>?QK;&5N9&DN
M`$+\>?QK(&QA=&EN(&AA<F9L97)I`$+\>?QK(')O;6$@<F%K86UL87+]`%5R
M=6=U87D`2W5L;&%N.B`E<P!34TP@:W5L;&%N`$MU;&QA;OUC_2!A9/UN_7HO
M<&%R;VQA;OUZ($E-4U`@<W5N=6-U(&GG:6X@9F%R:VS](&ES92!K=6QL86[]
M;BX`)7,@:W5L;&%N_6/]<_T@)7,@:>=I;B!D;_!R=6QA;F%M863]+@!+=6QL
M86[]8_T@6?9N971I;6D`2W5L;&%N_6/](%-EYV5N96ML97)I`$MU;&QA;OUC
M_2!+87G]=`!"=2!S:71E(&GG:6X@:W5L;&%N_6/](&MA>63]('-EYVEL;65Z
M(&O];/UN;?W^=/UR+@!+=6QL86[]8_T@063]`$MU;&QA;OUC_2!!9/TZ`$MU
M;&QA;OUC_2!A9/TZ(`!3:7-T96UD96MI(&MU;&QA;OUC_6QA<CH`UGIB96MI
M<W1A;@!61E,@9&EZ:6YI('EO:RX`5&%T:6P`1V7G97)L:2!K;VYU;6QA<OUN
M(&GG97)D:6ML97)I.@!'9>=E<FQI;&EK`-YU(&%N9&%N(&ET:6)A<F5N(&1A
M:VEK82!D9?!E<FD`1&7P97)L97(`1&7P97)L97)I;B!S9>=I;&5C9?!I`%9A
M;G5A='4`1&7P:?YK96X`5F5N97IU96QL80!$;_!R=6QA;6$@8F'^87+]<_UZ
M(&]L9'4@+2!B=2!I;&5T:2!K=7)C86QA;FW]_B!O;&%B:6QI<BX@(`!3_'+\
M;0!3_'+\;2!+;VYT;VS\`$3\_F5Y($AI>F$`1/S^97D@>6%S=/UK;&%M80!$
M_/YE>3H`QV]K(%G\:W-E:P!6:65T;F%M`%9I971N86UC82`H5DE30TE)*0!'
M]G+\;G3\;&4@)7,`0FER(&3]_B!W96(@<V%Y9F%S_2!G]G+\;G3\;&4`)7,@
M;VQA<F%K(&?V<OQN=/QL90!"<FET86YY82=Y82!A:70@5FER9VEN($%D86QA
M<OT`06UE<FEK82!":7)L97+^:6L@1&5V;&5T;&5R:2=N92!A:70@5FER9VEN
M($%D86QA<OT`1_9R_/X`1_9R_/XZ`%--5%`@>6]L=7EL82!6;V1A9F]N92#=
M=&%L>6$`5T%23@!564%222$A(25S(-W'W4Y$14X@0D54W=#=($5,(-U,12#'
M24M!4E1)3BX`5V%L;&ES('9E($9U='5N80!5>6%R_0#'<OX`2&%V82!486AM
M:6YI`$AA=F$@=F5R:7-I('-A\&QA>?UC_7/]`%=E871H97(N8V]M`%=E8@!7
M96(@4VET97-I`$AA9G1A;/UK`$AO_F=E;&1I;FEZ`"5S($AO_F=E;&1I;FEZ
M`$AO_F=E;&1I;FEZ+"`E<P!"873]("A)4T\M.#@U.2TQ*0!"873]("A)4T\M
M.#@U.2TQ-2D`0F%T_2!386AR80`E<R!G:7)I_G1E;B!S;VYR82!H86YG:2!U
M>6=U;&%M87G](&?V<OQN=/QL97-I;C\`4_UN_7)L87G]8_T@:V%R86MT97(@
M;F5D:7(_`$%K=&%R_6T@:V%R86MT97)I(&YE9&ER/P!(86YG:2!%=G)E`%IE
M;F=I;B!-971I;B!D_'IE;FQE>6EC:7-I(&GG:6X@:&%N9VD@=7EU;6QU(&5K
M;&5R('-EYVEL96)I;&ER(&O];/UN<_UN+@!'96YI_FQI:P!#4U,@8FER:6UI
M>6QE(&=E;FG^;&EK`%-O;&1A:VD@)7,@;65N_'/\;OQN(&=E;FG^;&GP:2`H
M8FER('-O;G)A:VD@9VER:?YT92!E=&MI;B!O;&%C86LI.@#':7IE;&=E;FEN
M(&=E;FG^;&GP:0!'96YI_FQI:R!B:7)I;6D`1V5N:?YL:6LZ`%=I:VD`4OQZ
M9V%R`$5R:V5N(%-A871L97)D92!2_'IG87(`2VYO="!B:7)I;6EN9&4@<OQZ
M9V%R(&C]>OT`4OQZ9V%R.@!2_'IG87(Z(`!":6QG96QI:P#=_@#=_B!!9')E
M<VD`W?X@5&5L969O;G4`6"U2968`6#4P.78S(%1E;65L($O]<_UT;&%M86QA
M<OT`6#4P.78S($=E;FG^;&5T:6QM:?X@06YA:'1A<B!+=6QL86[];?T`6#4P
M.78S(-9T96MI($MO;G4@063]`%@U,#EV,R!+;VYU($%N86AT87(@5&%N_73]
M8_US_0!8-3`Y=C,@=7IA;G3];&%R_0!960!965E9`%EA:&]O(2!H87)I=&%S
M_0!9_6QL_6L`665M96X`179E=`!%=F5T+"!+86)U;"!%9&EY;W)U;0!-153=
M3B!-3T153D1!4TE.25HN(%L\/ET@9/SP;65L97)I;FD@:W5L;&%N87)A:R!7
M65-)5UE'(&?V<OQN_&W\;F4@9/9N_&XN`$1O\')U;&%N86UA9/UN_7HN`"=<
M)R!K87)A:W1E<FD@=&%M(&%D_6[]>F1A(&)U;'5N86UA>BX`1V7G97)L:2!B
M:7(@96QE:W1R;VYI:R!P;W-T82!A9')E<VD@9VER;65D:6YI>BX`)7,@:>=I
M;F1E(&MA<O[];/UK(&=E;&5N(&%L86YL87)L82`H:>=E<FDI(&%K=&%R_6QA
M;B!D;W-Y861A:VD@86QA;FQA<OT@9?YL9?YT:7)M961I;FEZ+@#'_6O]_B!Y
M87!M863];OUZ+@!'9>=E<FQI(&)I<B!C97`@=&5L969O;G4@;G5M87)A<_T@
M9VER;65L:7-I;FEZ+"!S87G];&%R('9E('-EYV5N96ML:2!O;&%R86L@=6QU
M<VQA<F%R87/](&%R86UA(/9N96MI("<K)R``1V7G97)L:2!B:7(@9&7P97(@
M9VER;65L:7-I;FEZ+@#<>64@:V%Y9/T@>6%P86)I;&UE:R!IYVEN(&)I<B!6
M97)I0?!A8_T@>6%P_6QA;F3]<FUA;/US_6[]>BX`5D93('-O;B!A_F%M87/]
M;OT@>6%P_6QA;F3]<FUA;/US_6[]>BX`4')O8FQE;2!R87!O<G4@9_9N9&5R
M;65D96X@]FYC92!S;W)U;G4@=&%R9FD@971M96QI<VEN:7HN`$)U(&)A\&QA
M;G3];OUN(&?V<W1E<F1I\&D@8FER(%523"!G:7)M96QI<VEN:7H`4VEL:6YM
M97-I(&GG:6X@8FER('-U;G5C=2!S9>=M96QI<VEN:7HN`%1E;6EZ;&5N;65S
M:6X@:>=I;B!B:7(@:W5L;&%N_6/](&%D_2!B96QI<G1M96QI<VEN:7HN`%-I
M;&EN;65S:2!IYVEN(&)I<B!K=6QL86[]8_T@863](&)E;&ER=&UE;&ES:6YI
M>BX`16ML96YM97-I(&GG:6X@8FER(&MU;&QA;OUC_2!A9/T@8F5L:7)T;65L
M:7-I;FEZ+@!'_&YC96QL96YM97-I(&GG:6X@8FER(&MU;&QA;OUC_2!A9/T@
M8F5L:7)T;65L:7-I;FEZ+@!'97+G96ML9?YT:7)I;&5C96L@8FER(&5Y;&5M
M(&)E;&ER=&UE;&ES:6YI>BX`665N:2!K871E9V]R>2!A9/T@9VER;65L:7-I
M;FEZ+@`E<R!O='5R=6UU;G5N('/\<F5S:2!D;VQD=2X@3/QT9F5N('1E:W)A
M<B!G:7)I_B!Y87#];BX`16QE:W1R;VYI:R!0;W-T82!!9')E<VEN:7H`2VEM
M9&5N.B!A9')E<SH`0FEL9VEL97)I;FEZ`"5S(&]T=7)U;75N=7IU;B!B8?YL
M86YG_6/];F1A(-UN=&5R;F5T($%D<F5S:6YI;FEZ(&1E\&G^=&DN($?\=F5N
M;&GP:6YI>FD@:V]R=6UA:R!IYVEN+"!Y96YI9&5N(&=I<FG^('EA<&UA;/US
M_6[]>BX`063];OUZ`$MI;6QI:R!D96YE=&EM:6YI>B!K=6QL86[]8_T@;&ES
M=&5L96UE>6D@9&5S=&5K;&5M96UE:W1E9&ER('9E>6$@8G4@]GIE;&QI:R!B
M:7(@;F5D96X@>?QZ_&YD96X@<V7G:6QE;65Z(&O];/UN;?W^=/UR+@`E<R!O
M='5R=6UU;G5Z=6X@8F'^;&%N9_UC_6YD82!T87)A>?UC_6[]>B!D9?!I_G1I
M+B!'_'9E;FQI\&EN:7II(&MO<G5M86L@:>=I;BP@>65N:61E;B!G:7)I_B!Y
M87!M86S]<_UN_7HN`%1A<F%Y_6/];OUZ(&)U(/9Z96QL:?!I(&1E<W1E:VQE
M;65M96MT961I<BX`6F%M86X@1&EL:6UI;FEZ.@#6;B!T86[];6S](&MI;6QI
M\&EN:7HZ`%1A;2!!9/UN_7HZ`"5S(&GG:6X@>65N:2!P87)O;&%N_7HZ("5S
M`%-EYV5N96ML97)I;FEZ(&)U(&]T=7)U;75N('/\<F5S:2!IYVEN9&4@9_QN
M8V5L;&5N9&DN`%-EYV5N96ML97)I;FEZ(&?\;F-E;&QE;F1I+@!087)O;&%N
M_7H@<_UF_7)L86YD_2X`4&%R;VQA;OUZ('/]9OUR;&%N9/TL(&5L96MT<F]N
M:6L@<&]S=&%N_7K](&MO;G1O;"!E9&EN('9E('EE;FD@<&%R;VQA;OUZ;&$@
M9VER:?X@>6%P_6XN`%5Z86MT86MI('-U;G5C=6QA<OUN_7HZ`%EU9V]S;&%V
M>6$`6F%I<F4`6F%M8FEA`%II;6)A8G9E`$C]>FS]`%M!;/UN=/T@365T;FD@
M4V%K;&%=`%M0<F]B;&5M(%)A<&]R=5T`6T%L_6YT_2!-971N:2!']G-T97(@
M+0!;06S];G3]($UE=&YI($?V<W1E<B`M("5S('-A=/UR70`E<R\E<R!S873]
M<@!?6?9N971I;0!?0TQ)`%]697)I0?!A8_T`4V%T_7+](%]3:6P`7T=R=7!L
M87(`66%R7V3];0!']G+\;G3\(-9?>F5L;&EK;&5R:2XN+@!':5]R:?X`Q_U?
M:_W^`%]"8?!L86YT_7G]($1E\&G^=&ER+BXN`%]39>=E;F5K;&5R`%](86ML
M87(`0F'P;&%?;G3]>?T@4VEL+BXN`%]!>6%R;&%R`,=I>F5?;&=E(-9Z96QL
M:6ML97)I+BXN`$M?=6QL86[]8_UL87(`861R97,@9&5F=&5R:0!T86MV:6T`
M_6S];6S]`&)U<F%Y82!T_6ML87G];@!D_/[\>6]R`&1O<WEA`"5S("@E<RD@
M9&5N("5S("5S(&1E`&@Z`$%C:6P`365T;F4@9_9M_&S\`'-A=/UR;&%R70!M
M:VES;V9S($E33R!Y87!A<FME;B!H871A(&MO9'4Z)60N`&%D`&=E<N=E:VQE
M_G1I<FEL;65D:0!H96[\>B!G97+G96ML9?YT:7)I;&UE9&D`;F]T(&1E9G1E
M<FD`>?QZ9&4`<F5S:6T@8FER:6UI`'G\:W-E;&EY;W(`9F%R:VQA<OT@9_9S
M=&5R`$A45%`@>6]L=7EL82!S;7,R96UA:6P`<V%B:70`9_9R978@;&ES=&5S
M:0!P87)O;&%Y_2!D;_!R=6QA;6%K(&GG:6X@:6MI(&1E9F$@9VER:6X`8FER
M;&7^=&ER:6QM:?X`861L86YD_7+];&UA;?W^`&MU;&QA;OUC_2!S9>=I;6D`
M=D-A<F0`=SH`=V5A=&AE<BYC;VT`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO
M8V%L92]T<E]44B]H96QP+GAM;```````````````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P-C8R,"`Q,#4Q-30S,S<T,B`P,C$U,#8`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]X;6P@=F5R
M<VEO;CTB,2XP(B!E;F-O9&EN9STB:7-O+3@X-3DM.2(_/@H\(2TM("1(;W)D
M93H@:&]R9&4O;&]C86QE+W1R7U12+VAE;'`N>&UL+'8@,2XQ+C(N,2`R,#`U
M+S$P+S$X(#$Q.C,S.C0V(&IA;B!%>'`@)"`M+3X*/&AE;'`^"@H\(2TM($5N
M9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB<W5M;6%R>2(^"CQT:71L93Y4:&4@
M4&]R=&%L(%!A9V4\+W1I=&QE/@H@/'!A<F$^"B`@5&AI<R!P;W)T86P@<&%G
M92!P<F]V:61E<R!A('%U:6-K('-U;6UA<GD@;V8@86QL('EO=7(@:6UP;W)T
M86YT"B`@:6YF;W)M871I;VXN($9O<B!E>&%M<&QE+"!I="!M:6=H="!S:&]W
M(&AO=R!M86YY(&YE=R!E+6UA:6P@;65S<V%G97,@>6]U"B`@:&%V92!I;B!Y
M;W5R($E.0D]8+"!U<&-O;6EN9R!E=F5N=',@;VX@>6]U<B!C86QE;F1A<BP@
M=&%S:W,@;VX@>6]U<B!T;RUD;PH@(&QI<W0L(&AE861L:6YE<R!F<F]M('-E
M;&5C=&5D(&YE=W,@<V5R=FEC97,L(&%N9"!S;R!O;BX@($UA;GD@;V8@=&AE
M<V4*("!S=6UM87)I97,@=VEL;"!C;VYT86EN('%U:6-K('-H;W)T8W5T<R!T
M;R!C;VUM;VX@9G5N8W1I;VYS+"!S=6-H(&%S"B`@8V]M<&]S:6YG(&$@;F5W
M(&UA:6P@;65S<V%G92P@8W)E871I;F<@82!N97<@8V%L96YD87(@979E;G0@
M;W(@=&%S:RP@971C+@H@/"]P87)A/@H@/'!A<F$^"B`@5&AE(&-O;G1E;G1S
M(&]F('1H:7,@<&]R=&%L('!A9V4@87)E(&-U<W1O;6EZ86)L92!V:6$@=&AE
M($QA>6]U="!B=71T;VXN"B`@1F]R(&5X86UP;&4L('EO=2!C86X@8VAO;W-E
M('=H:6-H(&ET96US('1O(&EN8VQU9&4@;VX@=&AI<R!P;W)T86P@<&%G92!A
M<PH@('=E;&P@87,@:6X@=VAI8V@@;W)D97(@=&AE>2!A<F4@<VAO=VXN"B`\
M+W!A<F$^"CPO96YT<GD^"BTM/@H\96YT<GD@:60](G-U;6UA<GDB(&UD-3TB
M-CAC83,S9C=F,&,Y86%E-&,Q,#-E8C0W-#DR8V1C,34B('-T871E/2)U<'1O
M9&%T92(^"CQT:71L93Y':7)I_B!387EF87/]/"]T:71L93X*/'!A<F$^"D=I
M<FG^('-A>69A<_T@<VEZ92#V;F5M;&D@8FEL9VEL97)I;FEZ:6X@:_US82#V
M>F5T:6YI('9E<FER+B#6<FYE\&EN+"!G96QE;B!K=71U;G5Z9&$@:V'G('1A
M;F4@>65N:2!E;&5K=')O;FEK('!O<W1A(&]L9'7P=6YU+"!T86MV:6UI;FEZ
M9&5K:2!Y86ML8?YA;B!O;&%Y;&%R_2P@>6%P_6QA8V%K;&%R(&QI<W1E<VEN
M9&5K:2!I_FQE<FEN:7II+"!S9>=I;&D@:&%B97(@<V5R=FES:6YD96MI(&)A
M_FS]:VQA<OT@=G,N(&?V<W1E<FER+B!"=2#V>F5T;&5R:6X@YV_P=2!G96YE
M;"!F;VYK<VEY;VYL87(@:>=I;B!K_7-A>6]L;&%R(&GG97)E8V5K=&ER+"`@
M>65N:2!P;W-T82!O;'7^='5R;6%K+"!Y96YI('1A:W9I;2!O;&%Y_2!Y82!D
M82!I_FD@;VQU_G1U<FUA:R!G:6)I+@H\+W!A<F$^"CQP87)A/@I':7)I_B!S
M87EF87/];OUN(&GG97)I\&D@9/QZ96YL96UE('1U_G4@:6QE(&ES=&7P92!U
M>6%R;&%N86)I;&ER+B`BUG)N9?!I;BP@9VER:?X@<V%Y9F%S_6[];B!H86YG
M:2#V\&5L97)I(&GG97)E8V7P:6YI;B!Y86[];F1A(&)U(/;P96QE<FEN(&?V
M<W1E<FEL;64@<_UR86QA<OT@9&$@<V7G:6QE8FEL:7(N"CPO<&%R83X*/"]E
M;G1R>3X*"@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB;F%V8F%R
M(CX*/'1I=&QE/E1H92!!<'!L:6-A=&EO;B!.879I9V%T:6]N($)A<CPO=&ET
M;&4^"B`\<&%R83X*("!!="!T:&4@;&5F="!H86YD('-I9&4@;V8@=&AE('=E
M8B!P86=E(&ES('1H92!A<'!L:6-A=&EO;B!N879I9V%T:6]N(&)A<BX*("!#
M;&EC:R!O;B!T:&4@:6-O;G,@;VX@=&AI<R!N879I9V%T:6]N(&)A<B!T;R!Q
M=6EC:VQY(&%N9"!E87-I;'D@<W=I=&-H"B`@8F5T=V5E;B!T:&4@879A:6QA
M8FQE(&%P<&QI8V%T:6]N<RX*(#PO<&%R83X*/"]E;G1R>3X*+2T^"@H\96YT
M<GD@:60](FYA=F)A<B(@;60U/2)B.&-F,&%E,3EE-3=D9F$P8S)B.38R934Q
M-C<X,F8T-R(@<W1A=&4](G5P=&]D871E(CX*/'1I=&QE/E5Y9W5L86UA($1O
M;&'^_6T@QW5B=?!U/"]T:71L93X*/'!A<F$^"E5Y9W5L86UA(&1O;&'^_6T@
MYW5B=?!U('=E8B!S87EF87/];OUN('-O;"!K96YA<OUD_7(N($UE=F-U="!U
M>6=U;&%M86QA<B!A<F%S_6YD82`@:/UZ;/T@=F4@:V]L87EC82!G97II;F5B
M:6QM96L@:>=I;B!U;&'^_6T@YW5B=?!U;F1A:VD@<VEM9V5L97)I('3]:VQA
M>?UN_7HN"CPO<&%R83X*/"]E;G1R>3X*"@H\(2TM($5N9VQI<V@@96YT<GDZ
M"CQE;G1R>2!I9#TB<')E9G,M9&]?;6%I;G1E;F%N8V4B/@H@("`@/'1I=&QE
M/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@1&\@36%I;G1E;F%N8V4\+W1I
M=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!P97)F
M;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6XL(&-H96-K('1H
M:7,@8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@HM+3X*"CQE;G1R>2!I9#TB
M<')E9G,M9&]?;6%I;G1E;F%N8V4B(&UD-3TB9&0Y-61F,#=A,#,P,S$R,S)B
M865A.3$Y,C@X8C)D,#`B('-T871E/2)U<'1O9&%T92(^"CQT:71L93Y497)C
M:6AL97(Z($)A:_UM.B!"86O];2!987!M83PO=&ET;&4^"CQP87)A/@I3:7-T
M96UE(&=I<F5R:V5N(&)A:_UM(&G^;&5M;&5R:2!Y87!M86L@:7-T97)S96YI
M>B!B=2!K=71U>74@:?YA<F5T;&5Y:6YI>BX*/"]P87)A/@H\+V5N=')Y/@H*
M/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](G!R969S+6-O;F9I<FU?
M;6%I;G1E;F%N8V4B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N
M86YC93H@0V]N9FER;2!-86EN=&5N86YC93PO=&ET;&4^"B`@("`\<&%R83X*
M("`@($EF('EO=2!W;W5L9"!L:6ME('1O(&-O;F9I<FT@86QL(&UA:6YT96YA
M;F-E('1A<VMS(&)E9F]R92!T:&5Y(&%R92!R=6XL(&-H96-K('1H:7,@8F]X
M+B!)9B!L969T('5N8VAE8VME9"P@86QL(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@=&AA="!N965D('1O(&)E(')U;B!W:6QL(&)E('!E<F9O<FUE9"!A=71O
M;6%T:6-A;&QY('=I=&@@;F\@8VAA;F-E('1O(&-A;F-E;"!O;B!L;V=I;BX*
M("`@(#PO<&%R83X*/"]E;G1R>3X*+2T^"@H\96YT<GD@:60](G!R969S+6-O
M;F9I<FU?;6%I;G1E;F%N8V4B(&UD-3TB83(Q,38R8V1F9C-B,60X9F%E861B
M-S(Y-C(T,#`S-F4B('-T871E/2)U<'1O9&%T92(^"CQT:71L93Y497)C:6AL
M97(Z($)A:_UM.B!"86O];2!$;_!R=6QA;6$\+W1I=&QE/@H\<&%R83X*0F%K
M_6T@9_9R979L97)I;FD@YV%L_?YM87EA(&)A_FQA;6%D86X@]FYC92!D;_!R
M=6QA;6%K(&ES=&EY;W)S86[]>B!B=2!K=71U>74@:?YA<F5T;&5Y:6YI>BX@
M1?!E<B!K=71U(&G^87)E=&QE;FUE;6G^(&ES92#G86S]_FUA<_T@9V5R96ME
M;B!B_'3\;B!B86O];2!I_FQE;6QE<FEN:7H@<VES=&5M92!G:7)E<FME;B`L
M:7!T86P@971M92#^86YS_6[]>B!O;&UA9&%N(&]T;VUA=&EK(&]L87)A:R!G
M97+G96ML9?YE8V5K=&ER+@H\+W!A<F$^"CPO96YT<GD^"@H\+VAE;'`^"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M;V-A;&4O=6M?54$`````````````````````````````````````````````
M````````````````````````````````````````,#`P-S4U(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W-#(@,#$W-S(S`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]U:U]502],0U]-15-304=%4P``````
M````````````````````````````````````````````````````````````
M```P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S
M,S<T,B`P,C$U,3``(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+W5K7U5!
M+TQ#7TU%4U-!1T53+VAO<F1E+FUO````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#$Q,3$P(#$P-3$U-#,S-S0R(#`R,S(Q-P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#>$@25`````%`````<````G`(`
M`&L````<!0```````,@&```H````R08```@```#R!@``#P```/L&```(````
M"P<```@````4!P``&0```!T'```'````-P<```X````_!P``!0```$X'```1
M````5`<```@```!F!P``%0```&\'```*````A0<```P```"0!P``!P```)T'
M```0````I0<```(```"V!P``!0```+D'```0````OP<```8```#0!P``%```
M`-<'```%````[`<```T```#R!P``!0`````(```+````!@@```\````2"```
M`P```"((```$````)@@```P````K"```"@```#@(```%````0P@``!(```!)
M"```$````%P(```0````;0@``!H```!^"```!@```)D(```'````H`@```(`
M``"H"```!````*L(```/````L`@```<```#`"```!P```,@(```$````T`@`
M``4```#5"```"````-L(```5````Y`@``!X```#Z"```!0```!D)```H````
M'PD``"D```!("0``$P```'()```+````A@D```4```"2"0``$0```)@)```$
M````J@D```P```"O"0``&@```+P)```7````UPD``!<```#O"0``$P````<*
M```0````&PH``!<````L"@``!P```$0*```%````3`H```,```!2"@``#```
M`%8*```(````8PH``!0```!L"@``!P```($*```&````B0H```L```"0"@``
M#````)P*```*````J0H```(```"T"@``!@```+<*``!%````O@H``"8````$
M"P``)0```"L+```0````40L``&<!``!B"P``.@```,H,```)````!0T``!H`
M```/#0``"P```"H-```2````-@T``"(```!)#0``!@```&P-```/````<PT`
M``D```"##0``#@```(T-```/````G`T``!\```"L#0``%````,P-```-````
MX0T```@```#O#0``%````/@-```"````#0X```<````0#@``$````!@.```'
M````*0X``!`````Q#@``!P```$(.```3````2@X```<```!>#@``#0```&8.
M```2````=`X```0```"'#@``"````(P.```.````E0X``!````"D#@``!0``
M`+4.```4````NPX``!$```#0#@``&0```.(.```I````_`X```8````F#P``
M!0```"T/```"````,P\```H````V#P``#P```$$/```$````40\```@```!6
M#P``!````%\/```'````9`\```8```!L#P``&````',/```?````C`\```<`
M``"L#P``*0```+0/```N````W@\```T````-$```#````!L0```(````*!``
M`!0````Q$```!````$80```.````2Q```!D```!:$```%0```'00```5````
MBA```",```"@$```%P```,00```9````W!````<```#V$```!0```/X0```#
M````!!$```\````($0``$0```!@1```6````*A$```4```!!$0``!P```$<1
M```-````3Q$```T```!=$0``#P```&L1```"````>Q$```<```!^$0``10``
M`(81```Q````S!$``#$```#^$0``%P```#`2```!`````````$T````=````
M10```!4````(````(@```#D``````````````!P```!'`````````!0````N
M`````````#L````V````20```"8````Q````````````````````)P```!X`
M```M````#0`````````I``````````(`````````3P```"4```!"````3```
M````````````*````#X````8````'P```!8````;````(P````D````P````
M-0````0````+````!0````P````/````+P```$`````:````1@```$L```!.
M````,@```$,````]````!@```"L``````````````#\```!(````.`````H`
M```````````````````\``````````X`````````$P```!$````@````$```
M`"$```!*``````````,```!0````$@```#0`````````````````````````
M%P```$$````S````&0```"H`````````)``````````'````-P```$0````Z
M````+``````E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T
M:6]N`#(T(&AO=7)S`$%D9"!A(&YE=R!U<V5R.@!!9&0@<&%I<@!!9&0@=7-E
M<@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`061M:6YI<W1R
M871I;VX`06QI87,`079A:6QA8FQE(&9I96QD<SH`0FER=&AD87D`0V%N8V5L
M(%!R;V)L96T@4F5P;W)T`$-E;&P@4&AO;F4`0VQO<V4@5VEN9&]W`$-O;7!A
M;GD`0V]N9FER;2!087-S=V]R9`!$1`!$86EL>0!$969A=6QT($ED96YT:71Y
M`$1E;&5T90!$97-C<FEB92!T:&4@4')O8FQE;0!%;6%I;`!%;7!T>2!R97-U
M;'0N`$5R<F]R`$5V97)Y($QO9VEN`$5X86UP;&4@=F%L=65S.@!&87@`2&5L
M<`!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;W)D90!);7!O<G1E9"!F:65L
M9#H@)7,`26UP;W)T960@9FEE;&1S.@!,:7-T($AE;'`@5&]P:6-S`$QI<W1I
M;F<@=7-E<G,@:7,@9&ES86)L960N`$QO9R!I;@!,;V<@;W5T`$U-`$UA:6P`
M36%T8VAI;F<@9FEE;&1S`$UE<W-A9V4`36]N=&AL>0!.86UE`$YO=&5S`%!A
M<W-W;W)D`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!097)F;W)M($UA:6YT96YA
M;F-E($]P97)A=&EO;G,`4&AO;F4`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y
M(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE
M(&%N9"!P87-S=V]R9`!0<F]B;&5M($1E<V-R:7!T:6]N`%)E;6]V92!P86ER
M`%)E<V5T`%)E='5R;B!T;R!/<'1I;VYS`%)O;&4`4V%V92!/<'1I;VYS`%-E
M;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M
M870Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;F0@4')O8FQE;2!297!O
M<G0`4VMI<"!-86EN=&5N86YC90!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3
M=6-C97-S`%1I=&QE`%523`!5;F1O($-H86YG97,`57-E<FYA;64`57-E<G,@
M:6X@=&AE('-Y<W1E;3H`5V%R;FEN9P!7965K;'D`5V5L8V]M92P@)7,`5V]R
M:R!!9&1R97-S`%=O<FL@4&AO;F4`65D`665A<FQY`%EO=2!M=7-T(&1E<V-R
M:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L
M96T@<F5P;W)T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M
M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%M0
M<F]B;&5M(%)E<&]R=%T`4')O:F5C="U)9"U697)S:6]N.B!(;W)D92!V,BXQ
M"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/
M5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V
M:7-I;VXM1&%T93H@,C`P,BTP,2TP-2`Q-CHQ-2LP,C`P"DQA<W0M5')A;G-L
M871O<CH@06YD<FEY($MO<'ES='EA;G-K>2`\86YR:4!P;VQY;F5T+FQV:78N
M=6$^"DQA;F=U86=E+51E86TZ(%5K<F%I;FEA;B`\=V5B;6%S=&5R0'!O;'EN
M970N;'9I=BYU83X*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T
M97AT+W!L86EN.R!C:&%R<V5T/4M/23@M50I#;VYT96YT+51R86YS9F5R+45N
M8V]D:6YG.B`X+6)I=`H`[]#%TL'#IM$@T-+/QJ;,P<O4R=[.S\?/(,_"T\S5
MQ\_7U=?!SL[1("5S("T@\*;$U-?%TL36Q<[.T0`R-"#'S\3)SLD`Y,_$P=3)
M(,[/U\_'SR#+S]+)T]35U\'>P3H`Y,_$P=3)(-#!TM4`Y,_$P=3)(,O/TLG3
MU-77P=[!`.3/Q,'7P<[.T2#+S]+)T]35U\'>IM<@VL'"S]+/SL7.Q2X`X<32
MQ=/!`.'$S:;.IM/4TM77P<[.T0#PT\77Q,_.ILT`Y,_3U-70SJ8@T,_,T3H`
MY,7.V"#.P=+/Q-;%SL[1`/>FQ,VFSLG4R2#0S]>FQ,_-S,7.SM$@T-+/PLS%
MS<D`\]2FS-C.R<O/U\G*(-3%S,7&S\X`^L'+TLG4R2#7ILO.SP#KS\W0P<ZF
MT0#PIL34U\72Q-;%SL[1(-#!TL_,P`#DY`#]S\3%SL[/`._3SL_7SL$@IM#/
MT]3!T]@`]\G4Q=+4R0#OT,G;IM38(-#2S\+,Q<W5`.4MT,_;U,$`\,_2S];.
MILH@TL7:U<S8U,'4+@#PS\W)S,O!`.O/UL[/Q\\@U\C/Q-4`Y,'.IB#$S-$@
MT-+)R\S!Q-4Z`.;!R],`Y,_0S\W/Q\$`Y,_-P=O.T2#!Q-+%T\$`Y,_-P=O.
MILH@U,7,Q<;/S@!(;W)D90"VS=#/TM3/U\'.Q2#0S\S%.B`E<P"VS=#/TM3/
MU\'.IB#0S\S1.@#PQ=+%S*;+(-+/VL2FS*;7(.3/T,_-S\?)`/#%TL7'S-'$
M(-/0R=/+U2#+S]+)T]35U\'>IM<@VL'"S]+/SL7.R<HN`/?7ILK4R0#WR<K4
MR0#M[0!)35`MT,_2U,',`/>FQ-#/UZ;$SJ8@T,_,T0#LR=/4`/W/S:;3T</1
M`+;-8-$`[L_4P=3+R0#PP=+/S-@`\,'2S\S8(,W5T\G4V"#3T*;7T,'3U,DN
M`/?)R\_.P=3)(-#2S\:FS,'+U,G>SJ8@S]#%TL'#IJ<`],7,Q<;/S@#BU<38
M+<S!T\O!+"#$P<K4Q2#+S]+/U,O)RB#/T,G3(-#2S\+,Q<W)+@#BU<38+<S!
MT\O!+"#7R\'6IM38(,[!VM?5(,O/TLG3U-77P=[!(*8@T,'2S\S8`._0R=,@
MT-+/PLS%S<D`]\G4Q=+4R2#0P=+5`._>R=/4R=3)`/#/U\72SM74R=/1(,3/
M(._0PZ;*`/+/S-@`^L+%TL7'U,D@S]##IJ<`]\G"Q=*FU-@@TL_:Q*;,P-?!
MWB#$P=3).@#WR<+%TJ;4V"#&S]+-P=0@Q,'4R3H`]\G"Q=*FU-@@QL_2S<'4
M(-[!T]4Z`/>FQ*;3S,'4R2#0S]>FQ,_-S,7.SM$@T-+/(-#2S\+,Q<W5`/#2
MS]#5T]3)U,D@T-+/QJ;,P<O4R<O5`/?7IL0@\]#%PZ;!S-C.R<@@T\G-U\_,
MIM<`]=/0IMO.SP#TR=35S`!54DP`\\O!T]77P=3)(-K-IL[)`.[!VM?!(,O/
MTLG3U-77P=[!`.O/TLG3U-77P=ZF(-<@T\G3U,7-ICH`]=?!Q\$`_<_4R=;.
MT0#WIM3!P"#WP=,L("5S`/+/PL_>P2#!Q-+%T\$`\L_"S][)RB#4Q<S%QL_.
M`/+R`/W/TJ;>SL\`]\D@T,_7R<[.IB#/T,G3P=3)(-#2S\+,Q<W5+"#0Q=+;
M(,ZFUB#7IL33R<S!U,D@T,_7IL3/S<S%SL[1(-#2SR#.Q:<N`/?!S2#3S*;$
M(-?+P=K!U,D@SL':U]4@R\_2R=/4U=?!WL$@Q,S1(-?)Q,',Q<[.T2X`]\'-
M(-/,IL0@U\O!VL'4R2#.P=K7U2#+S]+)T]35U\'>P2#$S-$@Q,_$P=?!SL[1
M+@!;\,_7IL3/S<S%SL[1(/#2S\+,Q<W)70``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L
M92]U:U]502]H96QP+GAM;```````````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,S,R,"`Q,#4Q-30S,S<T,B`P,C$T-3(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]X;6P@=F5R<VEO
M;CTB,2XP(C\^"CPA+2T@)$AO<F1E.B!H;W)D92]L;V-A;&4O=6M?54$O:&5L
M<"YX;6PL=B`Q+C(@,C`P-"\P-2\R-R`R,#HR,CHQ,B!J86X@17AP("0@+2T^
M"CQH96QP/@H@(#QE;G1R>2!I9#TB<W5M;6%R>2(@<W1A=&4](FYE=R(^"CQT
M:71L93Y4:&4@4&]R=&%L(%!A9V4\+W1I=&QE/@H@/'!A<F$^"B`@5&AI<R!P
M;W)T86P@<&%G92!P<F]V:61E<R!A('%U:6-K('-U;6UA<GD@;V8@86QL('EO
M=7(@:6UP;W)T86YT"B`@:6YF;W)M871I;VXN($9O<B!E>&%M<&QE+"!I="!M
M:6=H="!S:&]W(&AO=R!M86YY(&YE=R!E+6UA:6P@;65S<V%G97,@>6]U"B`@
M:&%V92!I;B!Y;W5R($E.0D]8+"!U<&-O;6EN9R!E=F5N=',@;VX@>6]U<B!C
M86QE;F1A<BP@=&%S:W,@;VX@>6]U<B!T;RUD;PH@(&QI<W0L(&AE861L:6YE
M<R!F<F]M('-E;&5C=&5D(&YE=W,@<V5R=FEC97,L(&%N9"!S;R!O;BX@($UA
M;GD@;V8@=&AE<V4*("!S=6UM87)I97,@=VEL;"!C;VYT86EN('%U:6-K('-H
M;W)T8W5T<R!T;R!C;VUM;VX@9G5N8W1I;VYS+"!S=6-H(&%S"B`@8V]M<&]S
M:6YG(&$@;F5W(&UA:6P@;65S<V%G92P@8W)E871I;F<@82!N97<@8V%L96YD
M87(@979E;G0@;W(@=&%S:RP@971C+@H@/"]P87)A/@H@/'!A<F$^"B`@5&AE
M(&-O;G1E;G1S(&]F('1H:7,@<&]R=&%L('!A9V4@87)E(&-U<W1O;6EZ86)L
M92!V:6$@=&AE($QA>6]U="!B=71T;VXN"B`@1F]R(&5X86UP;&4L('EO=2!C
M86X@8VAO;W-E('=H:6-H(&ET96US('1O(&EN8VQU9&4@;VX@=&AI<R!P;W)T
M86P@<&%G92!A<PH@('=E;&P@87,@:6X@=VAI8V@@;W)D97(@=&AE>2!A<F4@
M<VAO=VXN"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)N879B87(B
M('-T871E/2)N97<B/@H\=&ET;&4^5&AE($%P<&QI8V%T:6]N($YA=FEG871I
M;VX@0F%R/"]T:71L93X*(#QP87)A/@H@($%T('1H92!L969T(&AA;F0@<VED
M92!O9B!T:&4@=V5B('!A9V4@:7,@=&AE(&%P<&QI8V%T:6]N(&YA=FEG871I
M;VX@8F%R+@H@($-L:6-K(&]N('1H92!I8V]N<R!O;B!T:&ES(&YA=FEG871I
M;VX@8F%R('1O('%U:6-K;'D@86YD(&5A<VEL>2!S=VET8V@*("!B971W965N
M('1H92!A=F%I;&%B;&4@87!P;&EC871I;VYS+@H@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB<')E9G,M9&]?;6%I;G1E;F%N8V4B('-T871E/2)N
M97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@1&\@
M36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U
M;&0@;&EK92!T;R!P97)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@
M;&]G:6XL(&-H96-K('1H:7,@8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB<')E9G,M8V]N9FER;5]M86EN=&5N86YC92(@<W1A=&4]
M(FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!#
M;VYF:7)M($UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A/@H@("`@268@
M>6]U('=O=6QD(&QI:V4@=&\@8V]N9FER;2!A;&P@;6%I;G1E;F%N8V4@=&%S
M:W,@8F5F;W)E('1H97D@87)E(')U;BP@8VAE8VL@=&AI<R!B;W@N($EF(&QE
M9G0@=6YC:&5C:V5D+"!A;&P@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!T:&%T
M(&YE960@=&\@8F4@<G5N('=I;&P@8F4@<&5R9F]R;65D(&%U=&]M871I8V%L
M;'D@=VET:"!N;R!C:&%N8V4@=&\@8V%N8V5L(&]N(&QO9VEN+@H@("`@/"]P
M87)A/@H\+V5N=')Y/@H\+VAE;'`^"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O>FA?
M0TX`````````````````````````````````````````````````````````
M````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`P,#`@,3`U,34T,S,W-#(@,#$W-S(P`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQO8V%L92]Z:%]#3B],0U]-15-304=%4P``````````````````
M```````````````````````````````````````````````````P,#`W-34@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<T,B`P,C$U
M,#4`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+WIH7T-.+TQ#7TU%4U-!
M1T53+VAO<F1E+FUO````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,3<W-3,Q
M(#$P-3$U-#,S-S0R(#`R,S(T,``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#>$@25`````'L$```<````]",``/L%``#,1P``
M`````+A?```.````N5\```\```#(7P``"````-A?```,````X5\```0```#N
M7P``#P```/-?```+`````V````X````/8```!0```!Y@```H````)&````H`
M``!-8```%0```%A@```2````;F````L```"!8```#@```(U@```*````G&``
M``T```"G8```#@```+5@```&````Q&````\```#+8```&````-M@```,````
M]&````@````!80``+@````IA```:````.6$``#(```!480``.````(=A``!4
M````P&$``%$````58@``6@```&=B``!7````PF(``#0````:8P``!0```$]C
M```&````56,``!$```!<8P``"````&YC```E````=V,``"````"=8P``#P``
M`+YC```*````SF,```,```#98P``#P```-UC```4````[6,```D````"9```
M#0````QD```2````&F0```\````M9```#P```#UD```(````360``"0```!6
M9```"````'MD```9````A&0```<```">9```#````*9D```L````LV0```X`
M``#@9````P```.]D```+````\V0```<```#_9```!P````=E```%````#V4`
M`!<````590``"@```"UE```/````.&4``!@```!(90``#@```&%E```4````
M<&4``!<```"%90``%P```)UE```3````M64```X```#)90``'P```-AE```'
M````^&4```8`````9@``"`````=F```/````$&8```H````@9@``$P```"MF
M```+````/V8``!4```!+9@``%0```&%F```'````=V8```4```!_9@``%0``
M`(5F```1````FV8```P```"M9@``.P```+IF```)````]F8```<`````9P``
M%`````AG```%````'6<``!`````C9P``$P```#1G```Y````2&<``"<```""
M9P``+````*IG```J````UV<``"4````":```"@```"AH```&````,V@```D`
M```Z:```!P```$1H```O````3&@``#<```!\:```+@```+1H``!5````XV@`
M`"T````Y:0``+0```&=I```M````E6D``$````##:0``(P````1J```C````
M*&H``"T```!,:@``,P```'IJ```5````KFH``!D```#$:@``*0```-YJ```D
M````"&L``!$````M:P``"@```#]K```0````2FL``!8```!;:P``%@```')K
M```'````B6L```<```"1:P``%````)EK```*````KFL```@```"Y:P``!P``
M`,)K```'````RFL```8```#2:P``!0```-EK```'````WVL```8```#G:P``
M"````.YK```.````]VL```H````&;```!````!%L```'````%FP```D````>
M;```%@```"AL```(````/VP```T```!(;```!@```%9L```>````76P``!$`
M``!\;```"````(YL```-````EVP```P```"E;```!P```+)L```#````NFP`
M``,```"^;```%P```,)L```(````VFP```0```#C;```"````.AL```(````
M\6P``"````#Z;```!@```!MM```&````(FT``!4````I;0``&````#]M```=
M````6&T``%0```!V;0``*0```,MM```*````]6T```X`````;@``"@````]N
M```4````&FX``!@````O;@``'0```$AN```3````9FX``!0```!Z;@``!```
M`(]N```&````E&X```4```";;@``!0```*%N```;````IVX``!H```##;@``
M$0```-YN```1````\&X``!P````";P``$````!]O```A````,&\``!$```!2
M;P``#````&1O```&````<6\``!<```!X;P``"````)!O```%````F6\```P`
M``"?;P``!@```*QO```'````LV\```T```"[;P``!P```,EO```+````T6\`
M``<```#=;P``!P```.5O```*````[6\```P```#X;P``$`````5P```%````
M%G```"4````<<```$P```$)P```[````5G```"````"2<```#````+-P```.
M````P'````H```#/<```#0```-IP```>````Z'```!L````'<0``(0```"-Q
M```>````17$``!X```!D<0``&P```(-Q```>````GW$``#,```"^<0``+P``
M`/)Q```2````(G(``"D````U<@``$@```%]R```6````<G(``"@```")<@``
M(````+)R```A````TW(``$$```#U<@``!P```#=S```&````/W,``!(```!&
M<P``$P```%ES```2````;7,```<```"`<P``!````(AS```,````C7,```\`
M``":<P``$P```*IS```-````OG,```T```#,<P``!@```-IS```1````X7,`
M`!<```#S<P``&P````MT```.````)W0```(````V=```!0```#ET```$````
M/W0```T```!$=```#@```%)T```#````870```@```!E=```#P```&YT```0
M````?G0```8```"/=```#````)9T```1````HW0``!D```"U=```#0```,]T
M```'````W70``!0```#E=```"P```/IT```B````!G4``"\````I=0``"P``
M`%EU```)````974``!D```!O=0``"P```(EU```7````E74``!<```"M=0``
M"0```,5U```6````SW4```\```#F=0``#@```/9U```(````!78```T````.
M=@``)@```!QV``!#````0W8```@```"'=@``$@```)!V```(````HW8```L`
M``"L=@``+P```+AV```.````Z'8```8```#W=@```P```/YV```'`````G<`
M``0````*=P``"@````]W```*````&G<```\````E=P``$````#5W```7````
M1G<``!$```!>=P``%P```'!W```%````B'<```L```".=P``!0```)IW```-
M````H'<``!L```"N=P``%P```,IW```)````XG<```X```#L=P``#0```/MW
M```(````"7@```X````2>```$0```"%X```'````,W@```4````[>```!P``
M`$%X```(````27@```8```!2>```$````%EX```0````:G@```\```![>```
M"P```(MX```/````EW@```P```"G>```#P```+1X```'````Q'@```8```#,
M>```#P```--X```(````XW@``!,```#L>```'@````!Y```A````'WD``"``
M``!!>0``&0```&)Y```7````?'D``"4```"4>0``%P```+IY```;````TGD`
M``T```#N>0```P```/QY```(`````'H```H````)>@``#````!1Z```$````
M(7H``!,````F>@``%````#IZ```,````3WH```D```!<>@``"P```&9Z```;
M````<GH```<```".>@``!P```)9Z```*````GGH```T```"I>@``"0```+=Z
M```$````P7H``!@```#&>@``"@```-]Z``!\````ZGH```4```!G>P``!P``
M`&U[```,````=7L```@```"">P``!@```(M[```(````DGL```(```";>P``
M!@```)Y[```-````I7L``!````"S>P``!````,1[```)````R7L``!````#3
M>P``"0```.1[```)````[GL```4```#X>P``!@```/Y[```9````!7P```<`
M```??```!P```"=\```%````+WP```D````U?```"@```#]\```"````2GP`
M``T```!-?```"0```%M\```&````97P``!(```!L?```"0```']\```'````
MB7P``!0```"1?```'0```*9\```&````Q'P```H```#+?```!````-9\```)
M````VWP```@```#E?```$0```.Y\```)`````'T```8````*?0``#0```!%]
M```&````'WT```0````F?0``'@```"M]```%````2GT```X```!0?0``!@``
M`%]]```A````9GT``!4```"(?0``!````)Y]```1````HWT```8```"U?0``
M(@```+Q]```=````WWT```0```#]?0``#`````)^```*````#WX```@````:
M?@``"0```"-^```%````+7X```\````S?@``)````$-^```(````:'X```H`
M``!Q?@``!P```'Q^```@````A'X``"````"E?@``)@```,9^```9````[7X`
M`"D````'?P``!P```#%_```*````.7\```\```!$?P``#````%1_```&````
M87\```\```!H?P``$@```'A_```0````BW\``!P```"<?P``#P```+E_```%
M````R7\``!````#/?P``"0```.!_```$````ZG\```L```#O?P``#````/M_
M```/````"(```!D````8@```#P```#*````3````0H```!(```!6@```!P``
M`&F````,````<8```"````!^@```%````)^````1````M(```!<```#&@```
M'````-Z````3````^X```!$````/@0``&@```"&!```>````/($``!H```!;
M@0``$0```':!```7````B($``!4```"@@0``&0```+:!```$````T($```<`
M``#5@0``"P```-V!```&````Z8$```8```#P@0``!@```/>!```%````_H$`
M``<````$@@``!P````R"```%````%((``!8````:@@``!@```#&"```&````
M.((```0````_@@``!````$2"```.````28(```P```!8@@``#````&6"```-
M````<H(```H```"`@@``#@```(N"```%````FH(``"@```"@@@``#````,F"
M```/````UH(```H```#F@@``"````/&"```)````^H(``"L````$@P``"```
M`#"#```F````.8,``!(```!@@P``#P```'.#```&````@X,```H```"*@P``
M"````)6#```@````GH,```D```"_@P``#````,F#```-````UH,```X```#D
M@P``%@```/.#```1````"H0```8````<A```!@```".$```'````*H0```<`
M```RA```!P```#J$```6````0H0```T```!9A```!````&>$```%````;(0`
M`!X```!RA```$````)&$```,````HH0```D```"OA```!P```+F$```*````
MP80```D```#,A```#@```-:$```0````Y80``!H```#VA```"@```!&%```)
M````'(4```P````FA0``#P```#.%```(````0X4```8```!,A0``!P```%.%
M```%````6X4``$<```!AA0``#0```*F%```*````MX4```(```#"A0``!```
M`,6%```E````RH4```,```#PA0``!0```/2%```J````^H4```H````EA@``
M!````#"&```*````-88```8```!`A@``"````$>&```(````4(8```0```!9
MA@``!0```%Z&```%````9(8``!L```!JA@``+P```(:&```0````MH8```H`
M``#'A@``#P```-*&```*````XH8```D```#MA@``&P```/>&```8````$X<`
M`!<````LAP``#@```$2'```#````4X<```<```!7AP``!P```%^'```*````
M9X<```<```!RAP``40```'J'```0````S(<```P```#=AP``&@```.J'``!*
M````!8@```8```!0B```!@```%>(```&````7H@``!\```!EB```"0```(6(
M```8````CX@``!<```"HB```!@```,"(``!7````QX@``!,````?B0``$P``
M`#.)```"````1XD```L```!*B0``#0```%:)```'````9(D``!0```!LB0``
M!@```(&)```(````B(D```X```"1B0``!P```*")```*````J(D```L```"S
MB0``!P```+^)```)````QXD```D```#1B0``"@```-N)```'````YHD```D`
M``#NB0``!P```/B)```*`````(H``!(````+B@``"@```!Z*```)````*8H`
M`!`````SB@``!P```$2*```2````3(H```0```!?B@``!P```&2*```%````
M;(H```4```!RB@``"P```'B*```4````A(H``!$```"9B@``&````*N*```<
M````Q(H``!D```#AB@``!P```/N*```%`````XL```T````)BP``"````!>+
M```7````((L```L````XBP``$P```$2+```$````6(L```0```!=BP``#```
M`&*+```)````;XL```4```!YBP``!P```'^+```%````AXL```0```"-BP``
M*0```)*+```R````O(L``"X```#OBP``,P```!Z,```S````4HP``#@```"&
MC```$````+^,```3````T(P``"T```#DC```+0```!*-```Q````0(T``"X`
M``!RC0``+P```*&-```L````T8T``!,```#^C0``*P```!*.```:````/HX`
M``D```!9C@``10```&..``!!````J8X```0```#KC@``%````/".```.````
M!8\``!,````4CP``&````"B/```&````08\```D```!(CP``"@```%*/```/
M````78\```X```!MCP``!0```'R/```(````@H\```8```"+CP``%````)*/
M```1````IX\```X```"YCP```@```,B/```.````RX\```4```#:CP``!P``
M`."/```&````Z(\```0```#OCP``*0```/2/```?````'I```%P````^D```
M%````)N0```'````L)````X```"XD```#````,>0```,````U)```!,```#A
MD```'0```/60```9````$Y$```4````MD0``$0```#.1```1````19$``"0`
M``!7D0``%0```'R1```2````DI$```X```"ED0``&0```+21```(````SI$`
M``D```#7D0``"````.&1```%````ZI$``!\```#PD0``!@```!"2```0````
M%Y(```@````HD@``"````#&2```L````.I(``!H```!GD@``"0```(*2```*
M````C)(``!4```"7D@``!0```*V2```4````LY(```0```#(D@``$````,V2
M```>````WI(``"@```#]D@``"@```":3```1````,9,```L```!#DP``&@``
M`$^3```4````:I,```0```!_DP``"P```(23```%````D),```8```"6DP``
M"````)V3```@````II,``$$```#'DP``&@````F4```H````))0``"D```!-
ME```!@```'>4```%````?I0```@```"$E```*@```(V4```C````N)0``"X`
M``#<E```-`````N5```(````0)4``!<```!)E0``"@```&&5```'````;)4`
M`!````!TE0``"P```(65```3````D94```@```"EE0``"P```*Z5```*````
MNI4``!0```#%E0``,@```-J5```+````#98```4````9E@``%P```!^6```/
M````-Y8```4```!'E@``!````$V6```-````4I8``#(```!@E@``%P```).6
M```4````JY8```4```#`E@``!P```,:6```.````SI8``"H```#=E@``!@``
M``B7```,````#Y<```L````<EP``-@```"B7```+````7Y<```\```!KEP``
M,@```'N7```%````KI<```<```"TEP``$0```+R7```'````SI<```0```#6
MEP``!P```-N7```*````XY<```L```#NEP``#````/J7```#````!Y@``!(`
M```+F```!@```!Z8```>````)9@``!@```!$F```)0```%V8```-````@Y@`
M``D```"1F````P```)N8```'````GY@```(```"GF```#````*J8```5````
MMY@```L```#-F```&0```-F8```@````\Y@``!(````4F0``!0```">9```*
M````+9D``!4````XF0``$@```$Z9```,````89D```0```!NF0``!P```'.9
M```,````>YD``%(```"(F0``%P```-N9```&````\YD```T```#ZF0``%0``
M``B:```2````'IH```\````QF@``%````$&:```;````5IH``&D```!RF@``
M&@```-R:```7````]YH``!H````/FP``%P```"J;```;````0IL``!D```!>
MFP``'P```'B;```3````F)L```<```"LFP``"````+2;```)````O9L``!4`
M``#'FP``#0```-V;```3````ZYL```,```#_FP``/P````.<```W````0YP`
M`%<```![G```+P```-.<```*`````YT```@````.G0``#0```!>=```M````
M)9T```0```!3G0``)0```%B=```+````?IT``!T```"*G0``!@```*B=```,
M````KYT```<```"\G0``"0```,2=```3````SIT```D```#BG0``!````.R=
M```0````\9T```@````"G@``"`````N>```,````%)X```\````AG@``!P``
M`#&>```4````.9X```X```!.G@``#````%V>```;````:IX``"P```"&G@``
M$P```+.>```%````QYX```0```#-G@``%P```-*>```)````ZIX```@```#T
MG@``"@```/V>```1````")\```8````:GP``#@```"&?```.````,)\```T`
M```_GP``"P```$V?```"````69\```<```!<GP``!@```&2?```)````:Y\`
M``<```!UGP``%0```'V?```%````DY\```<```"9GP``"````*&?```'````
MJI\```<```"RGP``#@```+J?```)````R9\```8```#3GP``"````-J?```+
M````XY\```<```#OGP``"````/>?```'`````*```!8````(H```"0```!^@
M```&````*:````L````PH```%````#R@```(````4:````8```!:H```&0``
M`&&@```*````>Z```!P```"&H```!P```*.@```%````JZ```!````"QH```
M%````,*@```+````UZ````T```#CH```%P```/&@```$````":$```D````.
MH0```@```!BA```.````&Z$```@````JH0``'P```#.A```C````4Z$``#$`
M``!WH0``)P```*FA``!*````T:$``#@````<H@``*````%6B```L````?J(`
M`!L```"KH@``/@```,>B``!(````!J,``$$```!/HP``6P```)&C``!)````
M[:,``"$````WI```'P```%FD```K````>:0``"$```"EI```,P```,>D```E
M````^Z0``"<````AI0``,````$FE``!I````>J4``#T```#DI0``90```"*F
M``!-````B*8``"\```#6I@``+@````:G``!4````-:<``#(```"*IP``+P``
M`+VG```L````[:<``"T````:J```%P```$BH```E````8*@``#(```"&J```
M*0```+FH```^````XZ@``"(````BJ0``4@```$6I```E````F*D```L```"^
MJ0``(0```,JI```P````[*D``"4````=J@``'````$.J```Q````8*H```0`
M``"2J@``#0```)>J```+````I:H```X```"QJ@``"P```,"J```%````S*H`
M``(```#2J@``60```-6J```%````+ZL``!(````UJP``!````$BK```'````
M3:L```@```!5JP``!0```%ZK```3````9*L```T```!XJP```@```(:K```'
M````B:L```8```"1JP``%````)BK```,````K:L``!@```"ZJP``!@```-.K
M```2````VJL```P```#MJP```P```/JK```$````_JL```8````#K```!P``
M``JL```?````$JP``#4````RK```+@```&BL```O````EZP``!<```#'K```
M(````-^L```;`````*T``!@````<K0``)````#6M```?````6JT``!H```!Z
MK0``&@```)6M```O````L*T``"L```#@K0``'P````RN```C````+*X``!\`
M``!0K@``&@```'"N```E````BZX``"8```"QK@``)0```-BN```D````_JX`
M`!@````CKP``'0```#RO```D````6J\``!@```!_KP``(@```)BO```E````
MNZ\``!\```#AKP``(P````&P```?````);```"````!%L```&@```&:P```F
M````@;```!X```"HL```'@```,>P```)````YK````P```#PL```%P```/VP
M```O````%;$``"0```!%L0``#P```&JQ```4````>K$```X```"/L0``#0``
M`)ZQ```D````K+$```4```#1L0``!P```->Q```=````W[$``!4```#]L0``
M!@```!.R```)````&K(```L````DL@``%P```#"R```&````2+(``#,```!/
ML@``!P```(.R```A````B[(``!,```"ML@``#````,&R```1````SK(``#(`
M``#@L@``"````!.S```)````'+,```H````FLP``%````#&S```*````1K,`
M`!T```!1LP``"````&^S```?````>+,```@```"8LP``&@```*&S```&````
MO+,```<```##LP``"````,NS```)````U+,``#\```#>LP``!P```!ZT```/
M````)K0```@````VM```$P```#^T```'````4[0``!D```!;M```"@```'6T
M```7````@+0``!0```"8M```"@```*VT```,````N+0``!<```#%M```!```
M`-VT```J````XK0``!$````-M0``!P```!^U```"````)[4``!`````JM0``
M`P```#NU```(````/[4```8```!(M0``!P```$^U```-````5[4```L```!E
MM0``%````'&U```5````AK4```X```"<M0``+P```*NU```@````V[4``!P`
M``#\M0``$P```!FV```%````+;8```8````SM@``#````#JV```*````1[8`
M`!$```!2M@```@```&2V```$````9[8```H```!LM@``!@```'>V```%````
M?K8```P```"$M@``10```)&V```H````U[8``%,`````MP``&0```%2W```@
M````;K<``#4```"/MP``10```,6W```P````"[@``"@````\N```)@```&6X
M```E````C+@``"@```"RN```*````-NX```P````!+D``!(````UN0``$```
M`$BY``!Y````6;D```D```#3N0``<P```-VY``!\````4;H``"L```#.N@``
M%P```/JZ```?````$KL``!0````RNP``"@```$>[```%````4KL```8```!8
MNP``"````%^[```0````:+L```\```!YNP``!````(F[```9````CKL```(`
M``"HNP``"0```*N[```$````M;L```\```"ZNP``$P```,J[```B````WKL`
M``<````!O```"P````F\```%````%;P```(````;O```"P```!Z\``!/`0``
M*KP```H```!ZO0``#````(6]```'````DKT```<```":O0```@```**]```2
M````I;T```L```"XO0``!P```,2]```%````S+T``!(```#2O0``!P```.6]
M```+````[;T```D```#YO0``"P````.^```)````#[X```4````9O@``"@``
M`!^^```/````*KX```8````ZO@``#````$&^```2````3KX```H```!AO@``
M"0```&R^```=````=KX``!0```"4O@``)0```*F^```M````S[X``#P```#]
MO@``0````#J_``!`````>[\``$8```"\OP``)P````/````%````*\````@`
M```QP```#@```#K````'````2<```!L```!1P```&P```&W````+````B<``
M``0```"5P```!````)K````*````G\````P```"JP```"@```+?````*````
MPL````@```#-P```#0```-;````-````Y,````8```#RP```'P```/G````(
M````&<$``!D````BP0``!````#S!```&````0<$``!\```!(P0``!````&C!
M```(````;<$```8```!VP0``"@```'W!```*````B,$```0```"3P0``$```
M`)C!```*````J<$```@```"TP0``%````+W!```&````TL$```X```#9P0``
M#@```.C!```.````]\$```@````&P@``"@````_"```5````&L(```8````P
MP@``!@```#?"```&````/L(```@```!%P@``!@```$["```0````5<(```@`
M``!FP@``#@```&_"```2````?L(```0```"1P@``!````);"```7````F\(`
M``P```"SP@``#````,#"```:````S<(```8```#HP@``"````._"```6````
M^,(```8````/PP``"@```!;#```/````(<,``!T````QPP``&P```$_#```9
M````:\,``!L```"%PP``&0```*'#```$````N\,```0```#`PP``"````,7#
M```&````SL,``"H```#5PP``(P````#$```I````),0``&L```!.Q```*```
M`+K$```H````X\0``"@````,Q0``)P```#7%```:````7<4``!H```!XQ0``
M*````)/%```N````O,4```D```#KQ0``#````/7%```0`````L8```T````3
MQ@``"P```"'&```(````+<8```@````VQ@``$@```#_&```4````4L8```H`
M``!GQ@``!````'+&```8````=\8```@```"0Q@``"````)G&```(````HL8`
M``8```"KQ@``!@```++&```$````N<8```H```"^Q@``!````,G&```$````
MSL8```@```#3Q@``"````-S&```$````Y<8```@```#JQ@``!````//&```4
M````^,8```@````-QP``"````!;'```$````'\<```X````DQP``!````#/'
M```(````.,<```@```!!QP``"@```$K'```&````5<<```P```!<QP```P``
M`&G'```*````;<<```0```!XQP``!@```'W'```&````A,<```8```"+QP``
M&@```)+'```&````K<<```0```"TQP``#````+G'```2````QL<``!(```#9
MQP``,0```.S'```9````'L@```8````XR```"````#_(```(````2,@``!8`
M``!1R```"@```&C(```1````<\@```@```"%R```"````([(```$````E\@`
M``0```"<R```!````*'(```$````IL@``!$```"KR```#P```+W(```(````
MS<@```X```#6R```#0```.7(```&````\\@``!4```#ZR```#````!#)```(
M````'<D```0````FR0``"@```"O)```(````-LD```0````_R0``!@```$3)
M```$````2\D```0```!0R0``"````%7)```$````7LD```8```!CR0``!@``
M`&K)```$````<<D```0```!VR0``!P```'O)```(````@\D```0```",R0``
M"@```)')```*````G,D``"L```"GR0``&@```-/)```(````[LD```@```#W
MR0``"@````#*```(````"\H``!0````4R@``&````"G*```7````0LH``!<`
M``!:R@``%````'+*```2````A\H``!4```":R@``'0```+#*```=````SLH`
M``P```#LR@``%P```/G*```,````$<L``!<````>RP``&````#;+```3````
M3\L``!8```!CRP``,````'K+```$````J\L```0```"PRP``#````+7+```,
M````PLL```H```#/RP``"````-K+```$````X\L```@```#HRP``"````/'+
M```*````^LL```@````%S```"`````[,```(````%\P``!$````@S```%P``
M`#+,```:````2LP```H```!ES````@```'#,```$````<\P```0```!XS```
M"````'W,```(````ALP```0```"/S```!@```)3,```(````F\P```P```"D
MS```!````+',```*````MLP```@```#!S```#@```,K,```(````V<P```0`
M``#BS```"````.?,```$````\,P``!T```#US```%P```!/-```$````*\T`
M``@````PS0``%@```#G-```*````4,T```@```!;S0``"````&3-```$````
M;<T``!$```!RS0``"````(3-```(````C<T```8```"6S0``!@```)W-```<
M````I,T``"D```#!S0``"````.O-```.````],T```0````#S@``!P````C.
M```>````$,X```@````OS@``"````#C.```$````0<X```@```!&S@``!```
M`$_.```(````5,X```H```!=S@``"````&C.```(````<<X```X```!ZS@``
M"````(G.```.````DLX```0```"AS@``"````*;.```(````K\X```P```"X
MS@``%0```,7.```,````V\X```@```#HS@``"0```/'.```)````^\X```0`
M```%SP``"@````K/```*````%<\```H````@SP``!````"O/```(````,,\`
M``H````YSP``!````$3/```*````2<\```H```!4SP``"0```%_/```(````
M:<\```H```!RSP``"0```'W/```'````A\\```0```"/SP``!````)3/```&
M````F<\```8```"@SP``#0```*?/```0````M<\``!4```#&SP``%````-S/
M```0````\<\``!`````"T```&P```!/0```0````+]```!T```!`T```"```
M`%[0```$````9]````0```!LT```"````''0```*````>M````0```"%T```
M$P```(K0```1````GM````H```"PT```"````+O0```(````Q-```!4```#-
MT```!@```./0```$````ZM````8```#OT```!@```/;0```(````_=````0`
M```&T0``#@````O1```(````&M$``$X````CT0``!````'+1```$````=]$`
M``@```!\T0``!````(71```$````BM$```@```"/T0``!@```)C1```$````
MG]$```H```"DT0``#@```*_1```&````OM$```(```#%T0``"````,C1```$
M````T=$```0```#6T0``!````-O1```&````X-$``!(```#GT0``"````/K1
M```$`````](```0````(T@``"`````W2```"````%M(```0````9T@``"P``
M`![2```$````*M(```0````OT@``$P```#32```&````2-(```@```!/T@``
M"@```%C2```2````8](```8```!VT@``"@```'W2```$````B-(```@```"-
MT@``"````);2```(````G](```@```"HT@``!@```+'2```0````N-(```8`
M``#)T@``!````-#2```1````U=(```0```#GT@``"0```.S2```$````]M(`
M`!````#[T@``%P````S3```$````)-,```X````ITP``!````#C3```1````
M/=,```8```!/TP``!````%;3```(````6],```@```!DTP``"````&W3```(
M````=M,```4```!_TP``!@```(73```-````C-,```0```":TP``!@```)_3
M```&````IM,``!4```"MTP``%0```,/3```=````V=,``!````#WTP``(```
M``C4```$````*=0```@````NU```"@```#?4```(````0M0```0```!+U```
M#0```%#4```,````7M0```D```!KU```$P```'74```(````B=0```0```"2
MU```"````)?4```*````H-0```0```"KU```!````+#4```(````M=0```P`
M``"^U```#@```,O4```(````VM0```T```#CU```$0```/'4```$`````]4`
M``8````(U0``&0````_5```/````*=4```\````YU0``#P```$G5```.````
M6=4``!````!HU0``$````'G5```6````BM4``!,```"AU0``#P```+75```/
M````Q=4```\```#5U0``$0```.75```0````]]4```8````(U@``!@````_6
M```$````%M8```8````;U@``!@```"+6```$````*=8```8````NU@``!@``
M`#76```$````/-8```P```!!U@``$@```$[6```&````8=8```0```!HU@``
M!````&W6```$````<M8```0```!WU@``"````'S6```(````A=8```@```".
MU@``"@```)?6```*````HM8```8```"MU@``$@```+36```(````Q]8```@`
M``#0U@``"````-G6```(````XM8```@```#KU@``*````/36```.````'=<`
M``0````LUP``!````#'7```-````-M<```8```!$UP``"@```$O7```$````
M5M<```0```!;UP``!@```&#7```&````9]<```D```!NUP``#@```'C7```4
M````A]<``!8```"<UP``"````+/7```(````O-<```8```#%UP``!@```,S7
M```(````T]<```8```#<UP``"@```./7```$````[M<```0```#SUP``'0``
M`/C7```,````%M@``!$````CV```#P```#78```3````1=@``!$```!9V```
M$0```&O8```/````?=@``!,```"-V```%````*'8```$````MM@```8```"[
MV```"@```,+8```*````S=@```0```#8V```!````-W8```$````XM@```0`
M``#GV```*P```.S8```)````&-D```8````BV0```@```"G9```(````+-D`
M`!L````UV0```P```%'9```(````5=D```P```!>V0``#````&O9```$````
M>-D```@```!]V0``!@```(;9```(````C=D```@```"6V0``!````)_9```&
M````I-D```0```"KV0``$@```+#9```D````P]D```H```#HV0``"@```//9
M```,````_MD```H````+V@``"````!;:```7````']H``!@````WV@``%P``
M`%#:```,````:-H```0```!UV@``"@```'K:```$````A=H```D```"*V@``
M!````)3:```L````F=H```L```#&V@``"````-+:```3````V]H``"L```#O
MV@``!````!O;```$````(-L```8````EVP``$@```"S;```)````/]L``!@`
M``!)VP``%P```&+;```$````>ML``#<```!_VP``$````+?;```0````R-L`
M``8```#9VP``"````.#;```(````Z=L```0```#RVP``"````/?;```&````
M`-P```0````'W```!@````S<```$````$]P```H````8W```"````"/<```&
M````+-P```0````SW```!````#C<```$````/=P```0```!"W```!````$?<
M```$````3-P```@```!1W```!````%K<```(````7]P```@```!HW```$```
M`''<```$````@MP```L```"'W```!````)/<```(````F-P```0```"AW```
M!@```*;<```$````K=P```P```"RW```$P```+_<```7````T]P``!,```#K
MW```$0```/_<```$````$=T```0````6W0``#````!O=```$````*-T``!$`
M```MW0``!@```#_=```/````1MT```0```!6W0``!@```%O=```*````8MT`
M``@```!MW0``!@```';=```(````?=T```0```"&W0``!@```(O=```:````
MDMT``!\```"MW0``%P```,W=```<````Y=T``!L````"W@``(````![>```*
M````/]X``!````!*W@``&P```%O>```;````=]X``!\```"3W@``'````+/>
M```=````T-X``!H```#NW@``$P````G?```3````'=\``!D````QWP``!@``
M`$O?```O````4M\``#$```""WP```@```+3?```6````M]\```@```#.WP``
M!@```-??```.````WM\```0```#MWP``!@```/+?```&````^=\```P`````
MX```"`````W@```&````%N````8````=X```!````"3@```&````*>````@`
M```PX```!````#G@```"````/N````H```!!X```!@```$S@```$````4^``
M``8```!8X```!````%_@```C````9.```!,```"(X```)@```)S@```.````
MP^````0```#2X```"0```-?@```(````X>````0```#JX```"````._@```0
M````^.```!0````)X0``!````![A```(````(^$```H````LX0``#0```#?A
M```,````1>$```P```!2X0``#````%_A```6````;.$```P```"#X0``"```
M`)#A```(````F>$```0```"BX0``$````*?A```&````N.$```X```"_X0``
M!@```,[A```$````U>$``!T```#:X0``"````/CA```%`````>(```8````'
MX@``#0````[B```$````'.(```0````AX@``!````";B```*````*^(```P`
M```VX@``$P```$/B```$````5^(```@```!<X@``!````&7B```(````:N(`
M``0```!SX@``!````'CB```&````?>(```0```"$X@``!````(GB```(````
MCN(``!4```"7X@``)@```*WB```1````U.(``!$```#FX@``%@```/CB```$
M````#^,```0````4XP``!@```!GC```K````(.,``!8```!,XP``*0```&/C
M```O````C>,```0```"]XP``#````,+C```&````S^,```0```#6XP``"@``
M`-OC```(````YN,```@```#OXP``!````/CC```(````_>,```@````&Y```
M#`````_D```:````'.0```@````WY```!@```$#D```4````1^0```0```!<
MY```!````&'D```$````9N0```@```!KY```)0```'3D```(````FN0```T`
M``"CY```"@```+'D```$````O.0```H```#!Y```*````,SD```$````]>0`
M``@```#ZY```!@````/E```G````"N4```@````RY0``#````#OE```7````
M2.4```0```!@Y0``!````&7E```(````:N4``!(```!SY0``!````(;E```2
M````B^4```L```">Y0``"````*KE```(````L^4```0```"\Y0``&P```,'E
M```/````W>4```\```#MY0``%@```/WE```.````%.8```0````CY@``"@``
M`"CF```*````,^8```0````^Y@``!@```$/F```*````2N8```X```!5Y@``
M"@```&3F```4````;^8``!(```"$Y@``$@```)?F```&````JN8```@```"Q
MY@``$````+KF```*````R^8```H```#6Y@``!````.'F```'````YN8```@`
M``#NY@``.@```/?F```/````,N<```0```!"YP``#````$?G```6````5.<`
M`!(```!KYP``#@```'[G```4````C><``!$```"BYP``0P```+3G```-````
M^.<``!$````&Z```#0```!CH```1````)N@``!<````XZ```$````%#H```-
M````8>@```P```!OZ```$@```'SH```(````C^@```0```"8Z```+````)WH
M```$````RN@```\```#/Z```!````-_H```A````Y.@``",````&Z0``.@``
M`"KI```<````9>D``!,```""Z0``!````);I```(````F^D``"$```"DZ0``
M!````,;I```@````R^D```H```#LZ0``$P```/?I```$````"^H``!<````0
MZ@``!````"CJ```$````+>H```@````RZ@``$@```#OJ```$````3NH```@`
M``!3Z@``$P```%SJ```5````<.H```H```"&Z@``'````)'J```2````KNH`
M``P```#!Z@``"````,[J```3````U^H``!$```#KZ@``+````/WJ```&````
M*NL```X````QZP``"````$#K```,````2>L``!0```!6ZP``!````&OK```(
M````<.L```(```!YZP``!````'SK```(````@>L```0```"*ZP``!@```(_K
M```(````ENL```8```"?ZP``!````*;K```$````J^L```0```"PZP``!```
M`+7K```-````NNL```P```#(ZP``!````-7K```$````VNL```0```#?ZP``
M!````.3K```)````Z>L```8```#SZP``!````/KK```&````_^L```0````&
M[```!`````OL```1````$.P```0````B[```%@```"?L```4````/NP```T`
M``!3[```$@```&'L```=````=.P``!````"2[```!````*/L```$````J.P`
M`!4```"M[```)P```,/L```%````Z^P```@```#Q[```"````/KL```2````
M`^T```0````6[0``!@```!OM```(````(NT```0````K[0``!@```##M```&
M````-^T```X````^[0``#P```$WM```1````7>T``!@```!O[0``'````(CM
M```6````I>T``"@```"\[0``&P```.7M```=`````>X``!T````?[@``$0``
M`#WN```9````3^X``#(```!I[@``+P```)SN```Q````S.X``"\```#^[@``
M%P```"[O```7````1N\``!8```!>[P``$P```'7O```?````B>\``!,```"I
M[P``&0```+WO```1````U^\``$(```#I[P``)````"SP```Y````4?```"\`
M``"+\```%P```+OP```;````T_```#@```#O\```)0```"CQ```>````3O$`
M`!X```!M\0``&P```(SQ```1````J/$``!D```"Z\0``&P```-3Q```;````
M\/$``"0````,\@``#P```#'R```]````0?(``!,```!_\@``"````)/R```3
M````G/(``"T```"P\@``%P```-[R```/````]O(``"0````&\P``!````"OS
M```(````,/,```@````Y\P``"````$+S```+````2_,```0```!7\P``!@``
M`%SS``!/````8_,```0```"S\P``#0```+CS```$````QO,```H```#+\P``
M!````-;S```$````V_,``!````#@\P``!@```/'S```&````^/,```8```#_
M\P``!@````;T```5````#?0```H````C]```$@```"[T```&````0?0```X`
M``!(]```#````%?T```$````9/0```4```!I]```!@```&_T```&````=O0`
M`!(```!]]```'0```)#T```>````KO0``!\```#-]```#@```.WT```6````
M_/0``!(````3]0``$@```";U```7````.?4``!(```!1]0``$@```&3U```1
M````=_4``!H```")]0``$0```*3U```2````MO4``!8```#)]0``%P```.#U
M```2````^/4``!4````+]@``$P```"'V```0````-?8``!<```!&]@``$@``
M`%[V```7````<?8``!(```")]@``$@```)SV```1````K_8``!8```#!]@``
M&````-CV```6````\?8``!X````(]P``'P```"?W```8````1_<``!(```!@
M]P``%P```'/W```6````B_<```8```"B]P``"````*GW```$````LO<``!X`
M``"W]P``&P```-;W```.````\O<``!`````!^```!````!+X```$````%_@`
M`"0````<^```!````$'X```&````1O@``!,```!-^```#@```&'X```$````
M</@```<```!U^```"````'WX```/````AO@```0```"6^```)0```)OX```&
M````P?@``!T```#(^```"````.;X```(````[_@```@```#X^```&P````'Y
M```&````'?D```<````D^0``!@```"SY```-````,_D```P```!!^0``$0``
M`$[Y```$````8/D``!(```!E^0``!@```'CY```8````?_D```(```"8^0``
M"````)OY```$````I/D```@```"I^0``)````++Y```$````U_D```@```#<
M^0``!````.7Y```/````ZOD```<```#Z^0``#`````+Z```*````#_H```X`
M```:^@``#````"GZ```&````-OH```@````]^@``'0```$;Z```$````9/H`
M`!L```!I^@``$````(7Z```$````EOH```8```";^@``"````*+Z```$````
MJ_H```0```"P^@``!````+7Z```$````NOH```D```"_^@``"````,GZ```1
M````TOH``!(```#D^@``"````/?Z```C`````/L```\````D^P``#0```#3[
M```(````0OL```4```!+^P``!@```%'[```*````6/L```H```!C^P``#0``
M`&[[```"````?/L```(```!_^P``#````(+[```$````C_L```0```"4^P``
M"P```)G[```]````I?L``"$```#C^P``)0````7\```+````*_P``!<````W
M_```/P```$_\```A````C_P``!P```"Q_```%0```,[\```3````Y/P``!,`
M``#X_```$P````S]```3````(/T``!X````T_0``$````%/]```(````9/T`
M`%$```!M_0``"````+_]```K````R/T``%$```#T_0``&P```$;^```3````
M8OX```\```!V_@``#P```(;^```(````EOX```8```"?_@``!@```*;^```(
M````K?X```H```"V_@``%````,'^```$````UOX``!,```#;_@```P```._^
M```$````\_X```0```#X_@``"0```/W^```)````!_\``!H````1_P``!@``
M`"S_```(````,_\```4````\_P``!0```$+_```0````2/\```$````J`P``
M^`$``!P#``"8`@``[0,```````!P`P``Q@(```@#```$!```5P(``)0"````
M````G@$``%(!``!3`P``K@$``+(````]!```"0(`````````````H0$``.0#
M``"<`P``)0$``)4!``"9`P```````*X"````````4@,``(@!``#X`P``````
M`!<$`````````````#P!```[`@``-P(``!<#``!B`P``#P$``/(!``#$````
MP````)D!``!/`@``````````````````7`````````!(`P``8P0`````````
M````Z@,``&T#```Y`P``P`$``+4```#E`P``'@0```````!K`@``'P,`````
M```,`@````````````!G`0``U0,```````")````@P(``'0$``!?````Z@``
M``,!````````50```+4"``````````````````!F`@``K0(````````<`0``
M5`(```````#C`P``F`````````"*````"@(```8```#O````@@````````!%
M`P``!0(``-P"`````````````#@"````````%@0```````!G!```J@```!T"
M```P`0```````-$#``#C`````````.(```!:````B`,```````#U````)@,`
M`(L!``#M````$P(````````S````<@(``&,"```8`0``7P0``$H"``"R`P``
ME@,``(0#``!$`0``400``%````!7!```.`````````!F`````@(```````!'
M`@``@0$``(<!``#[`P``````````````````60```&`"```3`0```````)D`
M``#L`P``_P$```P#``!J`0``7`0``(`````K`P``800``)$```!Z`P``>`0`
M`.\!``#-````TP```#@#``#\`0``T`(``&X#```*`P``H0,``.$`````````
M`````%H!```A`P``N`(``/H``````````````,\!``"[````:@,``+<"```_
M`P``80$``*\"```L`@```````/0````````````````````<````$@$`````
M``"B````/````+H#```7`@``>````!X"``!%!```'P$````````B````````
M``L"``#=`````````*P!``````````````````!Y````\0``````````````
MV`,`````````````;P,````````T!```0@````````!I`P``+00``/D```#0
M`0``!P0``(\!``"C`P```````-("``".`0``/@,``"8!``"D`P``````````
M```@````20$``#0"``"4````$0(``'$#```-`@``)@(``'4"```7````=0``
M`.X"````````UP(``)T!````````JP,``*4"````````(P0````#```7`0``
M:@(```````!9`@``>0,`````````````*P0````````W````/@(``"0$```8
M````S0$``,T"````````I@(``'0"``!.`P``XP$````````C`````````&X"
M``!>!````````"T#```4!```RP,``*$````#`@``,0,``#(```!"`0``:```
M``````````````````````#A`P````````````#*`P``J@(``$8"````````
M!`,``%H$``!8`0```````+P"``#1`0``-`$``$`"``!S!```Z`,``#8$```:
M`@``3@```*T```#;`P``)P0``*\#```K````6P0``)`"``#V`0``%`$``"X!
M``#Y`@``-0,``"X"``!,`P``>@```)L`````````2P```,4!``#K````@`(`
M`/`#``"L`P``^@$``'X#````````QP(``%\"````````,`0``#\$``!2!```
M&P$``$L"``":`````````)<!````````80,``!0#```S!````````%L!````
M````-P$``/P#````````2P,`````````````5@```'`$``!?`P```````"$"
M``!Q!```<`$``/H#``#=`P``.`0``-P#`````````@$``/@"````````+P(`
M`,P#``!<`@``)0(``%L"```!`0``0P0``%0`````````;P$``*X````9````
MR0(``/,"````````,0$``.(#``"T````0````/,```!P``````````````"=
M`@``D0(``%L```#;`@``GP```.X!``#1`````````$@"``#)`0```````"H$
M````````G`(``'H!``#K`@``+`0``-4"``#^`@``CP(`````````````70``
M```````A`0``*P(``$L!``"Q`0``%0,``)`!``!0!```]`(```````!&````
MS@(``'T```!S`P``200``(X"``![`P``_P,``(("``!.`@``X0$``$@$````
M````L`(``#L!``!1`0``H`,``$,"````````A@$```````"C`````````$0#
M``!F!```YP,``$H!``"B`0``C@```$4`````````1P````````!?`0``````
M`!$$``"T`@``(00``,P"```9!````````#P"``#=`0```````*<"````````
M;`,``&0"``!`!```Y`(````````/!```N0,``(L```"C`@``````````````
M````!@$``'8$``!^`@``MP```)<"````````>`$````!``!(`0``````````
M``#[`0``#@0``&,#``#W````.P0```````!1`P```````,L"```#!```````
M`(,#``!V`@``[P(``(H!````````M`$``,(```!/`0``)````$T!````````
M.00`````````````B0$``'$!```H````?@$``$@````````````````````P
M````,0```'T!``"Q`P``*0,``$0$```+`0``G`$``(,!```^!```9`,``(4#
M``#>`````````/T"````````P0$````````]`@``P`(``!`!```1`P``````
M``````!-!```R`(``"`#```%`P``6@(```````#"`0``$P,``$`!``"X`P``
M!@,``"@"``#B`0``6`(``.X#````````I@,``/8"``!/`P``?````$,#``#'
M````A`````````"8`0``5@,``.0!``!6`@``"````.4"````````"P,``/D#
M``#!`P``U@,``$8$`````````````,D```"&````9P````L$```F````C0$`
M`/(#``!_````_`(``.D!````````5P$```T!``#W`P``O0(``%0#``#+`0``
M.@,```````!U!```/`0``+\"```8!```IP,```````#Q`P``8@0````````Y
M`0``(@(``"($``!D!```U@(``/@```!5`P``B`(``"4$```)`P``I0,``$T`
M```$`@```````/H"``#&`0``G0```'@"```Y``````````````!5`@``-P,`
M`,X``````````````$`#````````&@0``!@#````````[P,``,<#``!T`P``
M!@(``-0```!<`P```````'$````P`P``````````````````'@$``'8#``!8
M````%0(``(H"````````_P```#D"``"O`0````````````"+`@``Z@(`````
M```%!```SP````````!K`0``!@0``/$"``!Y`@``"`0``!X#``#[````````
M`*@#``#9````#@$``+L"``#L`0``/0$``&,!``````````````````"D`@``
MAP```.L#````````'0```%0!````````?`,``!@"``"0````*0(````````R
M`P```````"T"``!1````,P(```````#(`P``I`$``'P"``#7`P``Q0,`````
M``!=`@``Q`$``.`````$````:0```'\#``"4`0``)P,``-\#````````````
M`&8#``"^`P``(`$``!T!``#P````20``````````````\`$``,("``#:`P``
MAP,``!L#``!9!````````*@!``#L`@``+P0``%X!```>````+P$```````"5
M`@``````````````````R@```,L``````````````%@#``#K`0``````````
M``#>`0``N@```.8#`````````@,``+(!``````````````````![`@``````
M`)(!````````N0```%P!````````=@```(P!````````:P,```````#$`@``
M@0(``+T```!$````V`$``(\````I`0``%@$``#T```##`0```````(8#``"5
M`P``K`(``)(`````````HP$```````"^`0```````,X!````````+P,``+,!
M````````70$```T#``#]`P``UP```+H!``#>`P```````)8````V`@``````
M``````"]`P``700``)\"``"D````_`````````":`0```````&@"``"]`0``
M`````!8#``"V`````````"X````H!````````,8```!Z!```*`$``),```"?
M`P```````.D`````````;`$``#H!```[`````````$\````0!```,0(``&,`
M```;`@``Z0(```````"[`0``,P$```P$```Z!```7@,``,P!````````IP$`
M``P```"I`@``00`````````#`P``````````````````H@(``+D"``!L`@``
M-0````````"?`0```````/,!`````````````%(```!5`0``````````````
M````?P$```````"2`P``#0````````"$`0``/P``````````````"00``'<#
M````````3P0```````#I`P```````%`#``#9`0``*`,``#X!``!.`0``````
M`-H```#%`@``L@(``!P"````````G@```!("``")`@``$P```#4$```J`0``
M000``-8`````````$0``````````````I@```#P#````````1P0```````#[
M`@``'00``.0````K`0``U0````````!3`@``E`,```````!!`0```````$($
M``#W`@````````P!`````````````+8#``#F````<P```&@#````````O@``
M````````````````````````````3@0```($``!&`0``$@```)H"``!E`@``
MT@$```````#C`@``_0````\#```*!```D`,``&H$````````'0,``#,#```R
M`0```@```/<!```'`0``(0```!\"``"K`0```````#L#``!B`0``7@```$P!
M``#=`@``!`$``)$#````````900``*`"``";`0````````H`````````G```
M`-D#``"K`@``C`,``(P"``"H`````````&X`````````(@$``.`!````````
M``````X````5`````````#H"``!'`0``+@,``-4!````````T`,``$(#``!,
M`@``S````!H!````````SP,``&`#``````````````````"_````*0```*X#
M``!G`@``)P```"<!````````30(````````5!```10$``-L```#3`P``C@,`
M`)$!````````:0$``)@#``"%`@```````*8!``##````DP,``/D!````````
MJP```+\#``"!`````````),!``"2`@``%@(```````![!```00,``'P!``"P
M`0``60$``-\"``"Q`@``4@(``!4!``"=`P```````*\```!7`P``70,`````
M`````````````(T````R`@``-@$``/("``"!`P```````'@#``#R````````
M`&T$``#@`@```````!0"````````4`$``"P```#1`@``AP(``+<#``#3`0``
MV0(```````#3`@```````"0"``#(````)0```&0!``"\````/P$```\```![
M````WP````````!;`P``E@$`````````````Z````%8$``#:`0``FP(`````
M``"6`@``P@,```````!)`@``-@````````#V````J@$``)X#``#;`0````(`
M`(\#``#.`P``[@`````````2!```0P```/4#``"&`@``)`$``"`$````````
MT@```/8#``!]`P``?@```````````````````*$"`````````````+D!``#M
M`@``X@(``",!````````'`0`````````````N`$``"(#```!`P``*00`````
M``"V`@```````',!``!R````_@``````````````=0,``*T#``!U`0``````
M`+P#````````&0(``+`#``!3````_@,``,$`````````$`,``+0#``#E`0``
M`````&X!``"I`P``-````'<$``!$`@``-`,``+4#``!I!```Q0``````````
M````IP````<```#!`@``8`0```````!H`0``:P```%4$````````H@,``/$!
M``#]`0```````(0"``"E````E0````````#>`@``>0$``&<#````````0@(`
M`*P```!O!```<P(```@"``!)`P```````'0!``!1`@``LP(``'($``#``P``
MO@(``"T!``#<`0``=P```#T#````````B@,``!8```!L!````````(`#``!3
M`0``#@(``!0````U`@``M0$``(4!``!Y!````````.`#```M````````````
M````````J@,``$H```#0`````````%,$```!`@``H`````@!``#4`P``8`$`
M``````!,````WP$``"0#``#*`@````````D!````````:`0``,,#````````
M5@$```````#^`0``QP$``#8#``````````````````![`0``&0,``-(#``#/
M`@``]0(``#$$``#G````#@,``,T#```!!````````)D"``"\`0``M@$``+,`
M``!:`P``$````.P````F!```'P````````#F`@`````````````)````6`0`
M`&(````?!```10(``&X$````````;0$``+H"``#T`P``90$```````#)`P``
M`````)H#````````C0(``"`"``!O`@``/P(``&P```"[`P````````````!'
M`P``&P````````"+`P``=````&$"``"H`@``Q`,```````#G`@```````'`"
M``!V`0``#00```````#<````$0$``&H`````````&@```%X"```U`0``````
M`,8#````````<0(``(T#``!M`@``(P(``'H"`````````````$P$````````
M[0$```<"``"P````PP(``/,#``#8`@```````'<!```G`@``````````````
M`````````.$"``#F`0``G@(``-<!``!!`@``@`$```````#J`0``?0(``#@!
M```9`0```````/4!``!9`P``2@,``!(#````````)0,``$L$```#````+@0`
M``````"_`0````````````"3`@``B`````````!W`@````````L```#_`@``
M8@(``&D"```*`0``90,``-H"``"S`P``R@$``%<```!0`@``5`0``)L#``#4
M`0``B0,``$,!``"E`0``;P````````!@````,`(``+@```!M`````````"P#
M```%````90```"P!```/`@``V```````````````U`(``(P`````````EP,`
M`!L$``#G`0```````!H#````````*@(``&8!```%`0``U@$``(,```"I````
MK0$``(4```!R`0````0``*D!``!&`P``-P0``$H$````````/@```"\```"7
M````*@````````""`0``$P0``#($```'`P```````.@"``"@`0```````((#
M```0`@``(P,``/`"``#E````.@````````!R`P``30,`````````````?P(`
M`+$```!D`````````+<!``#H`0``]`$```````#(`0``80```&L$````("@E
M<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I`"`H=&]D87DI`"`H>65S=&5R
M9&%Y*0`@870@`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!&:6YG
M97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N
M9FER;6%T:6]N`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M96YT`"5S
M(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!I<R!R97%U:7)E9``E
M<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@)7,@;V8@)7,`)7,Z("5S
M`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@
M<V5L96-T("TM`#(T(&AO=7)S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U
M:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R
M960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@
M;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I
M9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T
M92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C
M<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M
M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K
M97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@
M;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE
M<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R
M>7!T(&$@;65S<V%G92X`04TO4$T`05!)($E$`$%B;W5T('1H:7,@961I=&]R
M`$%B;W5T+BXN`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R
M>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`06-C;W5N="!F
M<F]Z96XN`$%C8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI
M;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W
M(%!E<FUI<W-I;VX`061D(&$@;F5W('5S97(Z`$%D9"!N97<@;65M8F5R<P!!
M9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`
M061D('5S97(`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D
M9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O
M=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`069G:&%N:7-T86X`06QB
M86YI80!!;&=E<FEA`$%L:6%S`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L
M;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;&]W(&UU;'1I<&QE(&%D9')E
M<W-E<P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E
M<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!
M;'1E<FYA=&4@=&5M<&QA=&5S`$%M97)I8V%N(%-A;6]A`$%N(&EL;&5G86P@
M=F%L=64@=V%S('-P96-I9FEE9"X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`
M06YO;GEM;W5S(%!R;WAY`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D
M80!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P;'D@=&\@
M0VAI;&0@4VAA<F5S`$%P<')O=F4`07!R:6P`07)A8FEC("A7:6YD;W=S+3$R
M-38I`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!<F4@>6]U('-U
M<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@
M)7,@/P!!<F=E;G1I;F$`07)M96YI80!!<FUE;FEA;B`H05)-4T-)22TX*0!!
M<G5B80!!<V-E;G-I;VX@27-L86YD`$%S:6$O4&%C:69I8R!296=I;VX`07-K
M(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P
M97)A=&EO;G,_`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R
M;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S
M:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO
M;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+@!!='1R
M:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y<G-Q;#H@
M4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y<G5S
M.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N
M`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF='`@<W=I=&-H+@!!
M=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"X`
M075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O(')E
M;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R
M("5S`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N
M(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T
M:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$
M2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL
M960N`$%V86EL86)L92!F:65L9',Z`$%Z97)B86EJ86X`0F%C:V=R;W5N9"!#
M;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R
M;F%M92X`0F%H86UA<P!"86AR86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A
M;F=L861E<V@`0F%R8F%D;W,`0F5L87)U<P!"96QG:75M`$)E;&EZ90!"96YI
M;@!"97)M=61A`$)H=71A;@!":7)T:&1A>0!";&]C:R!3971T:6YG<P!";&]C
M:R!4>7!E`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]S;FEA(&%N9"!(97)Z
M96=O=FEN80!";W1S=V%N80!";W5V970@27-L86YD`$)R87II;`!"<FET:7-H
M($EN9&EA;B!/8V5A;B!497)R:71O<GD`0G)U;F5I($1A<G5S<V%L86T`0G5L
M9V%R:6$`0G5L;&5T960@3&ES=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`
M0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S`$-A;&5N9&%R`$-A;&T`0V%M
M8F]D:6$`0V%M97)O;VX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@
M)7,`0V%N861A`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T
M(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y("(E
M<R(N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE
M9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#
M86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#87!E
M(%9E<F1E`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L=&EC("A)4T\M
M.#@U.2TQ-"D`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@175R
M;W!E86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I;',`0V5R=&EF
M:6-A=&4@4&]L:6-I97,`0VAA9`!#:&%N9V4`0VAI;&4`0VAI;F$`0VAI;F5S
M92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I
M9S4I`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S
M92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAR:7-T;6%S($ES;&%N9`!#;&%S
M<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"X`0VQI8VL@=&\@0V]N=&EN
M=64`0VQO<V4@5VEN9&]W`$-L;W5D<P!#;V-O<R`H2V5E;&EN9RD@27-L86YD
M<P!#;VQO;6)I80!#;VQO<@!#;VQO<B!0:6-K97(`0V]M:6-S`$-O;6UA;F0`
M0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M
M<&%N>0!#;VYD:71I;VYS`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D
M`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4`
M0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE
M('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N
M('1O($944"!S97)V97(@9F%I;&5D+@!#;V]K($ES;&%N9',`0V]P>2!S96QE
M8W1I;VX`0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O=6QD(&YO="!01U`@
M96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92X`
M0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3
M+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E
M<G9E<BX`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N`$-O=6QD(&YO="!D
M96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R
M96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&]B=&%I;B!P
M=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@
M)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S
M`$-O=6QD(&YO="!R96%D("5S+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O
M=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,`0V]U;&0@
M;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-E87)C:"!T
M:&4@3$1!4"!S97)V97(N`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED
M96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN`$-O=6YT<GD`
M0W)E871E`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&]R(%!E<FUI<W-I;VYS
M`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N="!4:6UE
M`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E;G0@
M<W1Y;&4`0W5T('-E;&5C=&EO;@!#>7!R=7,`0WER:6QL:6,@*$M/23@M4BD`
M0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O56MR86EN:6%N("A+
M3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$`$1A:6QY`$1A=&4`1&%T92!296-E
M:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5C96UB97(`1&5C<F5A<V4@26YD
M96YT`$1E9F%U;'0@261E;G1I='D`1&5L971E`$1E;&5T92!'<F]U<`!$96QE
M=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&EV
M97)Y('1I;64`1&5N;6%R:P!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP
M=&EO;@!$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I
M;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E
M=F5L;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@
M`$1E=R!P;VEN=#H@`$1I<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO
M;B!R:6=H="!T;R!L969T`$1I<F5C=&]R>0!$:7-P;&%Y(#(T+6AO=7(@=&EM
M97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&9O<FUA=`!$:FEB;W5T:0!$
M;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N
M8V4N<&AP`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N
M86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI
M8V%N(%)E<'5B;&EC`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E
M;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1R;W`@9&]W
M;B!L:7-T`$4M36%I;`!%4E(`16-U861O<@!%9&ET`$5D:70@0FQO8VL`161I
M="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N<P!%9&ET
M(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E
M<FUI<W-I;VYS(&9O<B`E<P!%9WEP=`!%;"!386QV861O<@!%;6%I;`!%;6%I
M;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I;"!W
M:71H(&-O;F9I<FUA=&EO;@!%;6]T:6-O;G,`16UP='D@;65S<V%G92X`16UP
M='D@<F5S=6QT+@!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%<75A=&]R:6%L
M($=U:6YE80!%<FET<F5A`$5R<F]R`$5S=&]N:6$`171H:6]P:6$`175R;W!E
M`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI
M;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T
M90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A;F0`17AP:7)A=&EO;B!$
M871E`$5X<&]N96YT`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D(')E=')I
M979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@
M<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL
M960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N
M`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D
M('1O(&UO=F4@=&\@(B5S(BX`1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I
M`$9A<F]E($ES;&%N9',`1F%X`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E;',@
M;&EK93H@`$9I:FD`1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E
M<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@=7!L;V%D`$9I
M;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QT97)S`$9I;FQA;F0`1FER
M<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&EP`$9O;&1E<B`E
M<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R`$9O<F5C87-T($1A>7,@*&YO
M=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A
M>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT
M(&EN(&$@=VED92!B;&]C:RD`1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y<&4`
M1F]R='5N97,`1F]R=6US`$9O<G=A<F1S`$9R`$9R86YC90!&<F5N8V@@1W5I
M86YA`$9R96YC:"!0;VQY;F5S:6$`1G)O;0!&<F]M('1H92``1G5L;"!$97-C
M<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$=A8F]N`$=A;6)I80!'96YE
M<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;W)G:6$`1V5R;6%N>0!':&%N80!'
M:6)R86QT87(`1VEV96X@3F%M90!';P!';V]G;&4@4V5A<F-H`$=R87ES8V%L
M90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N861A
M`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N
M+65M<'1Y`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N
M<V5Y`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A
M+4)I<W-A=0!'=7EA;F$`2%1-3`!(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F
M;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`2&5A9&5R`$AE87)D($ES;&%N
M9"!A;F0@36-$;VYA;&0@27-L86YD<P!(96)R97<@*$E33RTX.#4Y+3@M22D`
M2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP97(`2&5R92!I<R!T:&4@8F5G
M:6YN:6YG(&]F('1H92!F:6QE.@!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T
M871E*0!(;VUE`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO
M;F<@2V]N9P!(;W)D90!(;W)I>F]N=&%L(%)U;&4`2&]W(&UA;GD@9FEE;&1S
M("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AU;6ED:71Y`$AU;6ED:71Y.B``2'5N
M9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA
M:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@
M8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N
M`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$EC
M96QA;F0`26-O;G,@3VYL>0!)8V]N<R!W:71H('1E>'0`26UA9V4@=7!L;V%D
M`$EM86=E<P!);7!O<G0L(%-T97`@)60`26UP;W)T960@9FEE;&0Z("5S`$EM
M<&]R=&5D(&9I96QD<SH`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!)
M;F-R96%S92!);F1E;G0`26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O;F5S
M:6$`26YF;P!);F9O<FUA=&EO;@!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,
M:6YK`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS97)T(&UE<W-A9V5S
M`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN=&5G
M97(`26YT96=E<B!L:7-T`$EN=F%L:60@541(+B`H57-E<B!$871A($AE861E
M<BDN`$EN=F%L:60@87!P;&EC871I;VXN`$EN=F%L:60@8F%T8V@@240N`$EN
M=F%L:60@9&%T82!S=6)M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@861D
M<F5S<RX`26YV86QI9"!F:6QE(&9O<FUA=`!);G9A;&ED(&US9U]T>7!E+@!)
M;G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+@!);G9A;&ED(&]R(&UI<W-I;F<@
M<&%R86UE=&5R<RX`26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV86QI
M9"!P<F]T;V-O;"X`26YV86QI9"!S;W5R8V4@861D<F5S<RX`26YV86QI9"!U
M;FEC;V1E(&1A=&$N`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)
M<F5L86YD`$ES;&4@;V8@36%N`$ES<F%E;`!)<W-U97(`271A;&EC`$ET86QY
M`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A;F5S92`H25-/+3(P,C(M2E`I
M`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD@0V5N=&5R`$IU<W1I
M9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+87IA:VAS=&%N
M`$ME97`@;W)I9VEN86P_`$ME;GEA`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E
M9"!A=71H96YT:6-A=&EO;BX`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN
M=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@86QR96%D>2!E
M>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$MI<FEB871I`$MO<F5A
M+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U
M8FQI8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`3&%N
M9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!(
M86QF`$QA<W0@475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S
M`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T
M=FEA`$QA>6]U=`!,96)A;F]N`$QE<V]T:&\`3&EB97)I80!,:6)Y86X@07)A
M8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`3&EN:P!,:6YK<P!,:7-T("T@
M=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!(96QP(%1O<&EC<P!,:7-T
M+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/=VYE<@!,:7-T+5!O
M<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG('5S
M97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI80!,;V-A;"!T
M:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@;W5T
M`$QO9VEN`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@
M<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN(&9A:6QE
M9"X`3'5X96UB;W5R9P!-30!-3U1$`$U3+51.148@071T86-H;65N="!C;VYT
M86EN960@;F\@9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O<FUE
M<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-861A9V%S8V%R`$UA:6P`36%I;"!!
M9&UI;@!-86QA=VD`36%L87ES:6$`36%L9&EV97,`36%L:0!-86QT80!-87)C
M:`!-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T:&5R
M(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`36%R<VAA;&P@27-L
M86YD<P!-87)T:6YI<75E`$UA=&-H:6YG(&9I96QD<P!-875R:71A;FEA`$UA
M=7)I=&EU<P!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@
M;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM
M=6T@;&5N9W1H`$UA>0!-87EO='1E`$UE;6)E<G,`365N=2!M;V1E.@!-97-S
M86=E`$UE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG
M;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S
M86=E(&5X<&ER960N`$UE<W-A9V4@='EP90!-971A<B!B;&]C:R!N;W0@879A
M:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA
M=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971H;V0`
M365T<FEC`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F
M`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``36EN('1E;7`@
M;&%S="`V(&AO=7)S.B``36ER<F]R`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@
M66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S
M92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I
M;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE($UA:6P`36]D:69I960@1&%T90!-
M;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYG;VQI80!-
M;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1S97)R870`36]O;B!0:&%S97,`
M36]R;V-C;P!-;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5
M<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA;6)I<75E`$UU;'1I<&QE('-E;&5C
M=&EO;@!->2!!8V-O=6YT`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T`$UY
M86YM87(`3D\L($D@1&\@3D]4($%G<F5E`$YA;64`3F%M:6)I80!.875R=0!.
M97!A;`!.971H97)L86YD<P!.971H97)L86YD<R!!;G1I;&QE<P!.971S8V%P
M92!"87-E(%523`!.971S8V%P92!34TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@
M8V5R=&EF:6-A=&4@8V]M;65N=`!.971S8V%P92!C97)T:69I8V%T92!T>7!E
M`$YE='=O<FL`3F5V97(`3F5W($-A;&5D;VYI80!.97<@36]O;@!.97<@57-E
M<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@=VEN9&]W("A?8FQA
M;FLI`$YE=W,`3F5X=`!.97AT(&]P=&EO;G,`3FEC87)A9W5A`$YI9V5R`$YI
M9V5R:6$`3FEG:'0`3FEU90!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E
M<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-
M0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&
M4RX`3F\@9FEL92!U<&QO861E9`!.;R!L;V-A=&EO;B!I<R!S970N`$YO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+@!.;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BX`3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I
M;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC
M871I;VXN`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@=&5M<&]R87)Y(&1I<F5C
M=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!V86QI9"!834P@9&%T82!R
M971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA
M;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO
M('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R
M871E(&-O;F9I9W5R871I;VXN`$YO;F4`3F]R9&EC("A)4T\M.#@U.2TQ,"D`
M3F]R9F]L:R!)<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R;B!-
M87)I86YA($ES;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E`$YO
M="!A(&1I<F5C=&]R>0!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W9E;6)E<@!.
M=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M;G,`
M3G5M8F5R(&]F(')O=W,`3TL`3V)J96-T($-R96%T;W(`3V-T86P`3V-T;V)E
M<@!/9F9I8V4`3VUA;@!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E
M9"!F;VQD97)S+@!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N
M;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N
M9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E
M`$]P96X@:6X@82!N97<@=VEN9&]W`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`
M3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET
M`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E;7!L
M871E<R!I;B`E<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`3W=N97(@4&5R
M;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N
M`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D($1A=&$`4$=0
M(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`@0V]D
M90!02%`@4VAE;&P`4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET
M;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A
M>0!087-S=V]R9`!087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE
M;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!087-S=V]R
M9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%S
M=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z`%!E<F9O
M<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B!$
M96YI960`4&5R;6ES<VEO;G,`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`
M4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0:&EL:7!P:6YE<P!0:&]N90!0
M:&]T;W,`4&ET8V%I<FX`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A
M<BX`4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E
M<B!O9B!D87ES(&EN('1H92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@
M=&EM92X`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M
M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0
M;VQA;F0`4&]L;',`4&]R='5G86P`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T
M(&5N9F]R8V5D(&)Y($E-05`I`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@
M:&]U<BAS*3H@`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N
M(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A="!S96$@
M;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEO=7,@;W!T:6]N<P!0
M<FEV871E($ME>0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP
M="!T97AT`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC
M+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`
M4'5E<G1O(%)I8V\`46%T87(`4E-!(%!U8FQI8R!+97D@*"5D(&)I="D`4F%D
M:6\@<V5L96-T:6]N`%)A=&EO`%)E860`4F5A9"!M97-S86=E<P!296%L;'D@
M9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!2
M961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H(%!O<G1A;"!6:65W.@!2
M96=E>`!296UA<FMS`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z
M+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K
M`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G
M<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=7-E<@!296UO=F4@=7-E
M<CH@)7,`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@
M97)R;W)C;V1E.B``4F5S970`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2
M975N:6]N`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O
M=&%T92!2:6=H=`!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3+TU)
M344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E9"!-
M97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`
M4TU3($UE<W-A9VEN9P!344P@4VAE;&P`4U-(`%-50T-%4U,`4V$`4V%I;G0@
M2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN
M="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'
M<F5N861I;F5S`%-A;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R:6YO
M`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`4V%U
M9&D@07)A8FEA`%-A=F4`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G96YE
M<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S
M97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U
M<F%T:6]N+@!396%R8V@`4V5L96-T(&$@9&%T90!396QE8W0@82!G<F]U<"!T
M;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E<@!396QE
M8W0@82!U<V5R('1O(&%D9`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`
M4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S
M(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M
M('1H92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E
M;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET
M97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI
M;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y
M;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!3
M96YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:6$@86YD($UO;G1E;F5G
M<F\`4V5R:6%L($YU;6)E<@!397-S:6]N($E$(&5X<&ER960N`%-E=`!3970@
M=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O
M;2!Y;W5R('!O<G1A;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T
M:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P
M<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD
M(&]T:&5R(&1I<W!L87D@;W!T:6]N<RX`4V5V97)A;"!L;V-A=&EO;G,@<&]S
M<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3:&]P<&EN
M9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D
M(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H
M96X@;&]G9VEN9R!I;C\`4VAO=R!P:6-K97(`4VAO=R!T:&4@)7,@365N=2!O
M;B!T:&4@;&5F=#\`4VAR:6YK`%-I97)R82!,96]N90!3:6=N('5P`%-I9VYA
M='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@
M36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=R!D97!T:#H@`%-O
M;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O<G0@;W)D97(@<V5L96-T:6]N`%-O
M=7)C92!A9&1R97-S`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H25-/
M+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H
M($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%I;@!3<&%M`%-P96-I
M86P@0VAA<F%C=&5R($EN<'5T`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R="!Y
M96%R`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R86=E(&9O<FUA=`!3
M=')E970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-U`%-U
M8FIE8W0`4W5B;6ET`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!W
M<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N<FES
M90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U
M<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A
M;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`4WER
M:6%N($%R86(@4F5P=6)L:6,`5%-6(&9I;&4`5&%I=V%N`%1A:7=A;BP@4')O
M=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E
M<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!496UP
M(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!496UP97)A='5R93H@`%1E
M;7!L871E($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1H`%1H86D@
M*%1)4RTV,C`I`%1H86EL86YD`%1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y
M<W1E;2X`5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`5&AE
M($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL
M>0!4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE
M(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@
M=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&5N8W)Y<'1I;VX@9F5A
M='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&9I
M;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL92`E
M<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL92!C
M;VYT86EN960@;F\@9&%T82X`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E
M<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&QO8V%T
M:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@
M0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U
M:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P
M<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S
M(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE
M('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S
M(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<V5R=F5R("(E<R(@:&%S
M(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D
M+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N
M`%1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+@!4:&4@=7!L;V%D
M960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE
M('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=V5A=&AE
M<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE<F4@87)E(&YO('!A
M<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T
M;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N
M=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N
M("5S+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D
M.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE
M(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E('=A<R!A
M('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL
M>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P
M;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R
M(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@
M;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H:7,@24U!4"!S97)V97(@9&]E<R!N
M;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@9&]E<R!N;W0@87!P
M96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@
M87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@
M<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&9I96QD(&ES
M(')E<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E
M<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T
M:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V
M86QU97,N`%1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E
M<&%R871E9"!L:7-T(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@;75S="!B92!A
M('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO
M<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q
M,C,T868G+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N
M`%1H:7,@:7,@)7,N`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE
M+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F
M:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+@!4
M:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W(&UU<W0@
M8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&EM90!4:6UE(%1R
M86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L96-T:6]N`%1I;6]R+4QE<W1E
M`%1I=&QE`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N
M('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@
M8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O:V5L
M874`5&]M;W)R;W<`5&]N9V$`5')I;FED860@86YD(%1O8F%G;P!4<G5E(&]R
M(&9A;'-E`%1U`%1U;FES:6$`5'5R:V5Y`%1U<FMI<V@@*$E33RTX.#4Y+3DI
M`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU
M`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``55),`%523#H`56=A
M;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+@!5
M;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N
M:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F
M:6QE("(E<R(N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93
M(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N9V4@=&\@)7,N`%5N86)L92!T
M;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I
M=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R
M96%T92!61E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93
M(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE
M('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE
M(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E;&5T92!61E,@
M9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D
M:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N
M`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&1E
M;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E
M;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y
M+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N86)L
M92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V
M92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`56YA
M8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T;R!O
M<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI
M=F4N`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA
M8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE
M(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE
M("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI
M<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET92!61E,@9FEL92`B)7,B
M+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`56YD97)L:6YE`%5N
M9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D
M(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C
M=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B``56YI8V]D92`H551&+3@I
M`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3
M=&%T97,`56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N
M:71S`%5N:VYO=VX`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YS
M=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`57!D871E('5S
M97(`57!G<F%D92!S8W)I<'0@9&5L971E9"X`57!L;V%D`%5P;&]A9&5D(&%L
M;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+@!5<G5G
M=6%Y`%5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R($%D
M;6EN:7-T<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5
M<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S
M:71E+@!5<V5R;F%M90!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T
M:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@
M97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E
M.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L=65S
M`%9A;G5A='4`5F%R:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL
M960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H
M+@!697)S:6]N`%9E<G-I;VX@0V]N=')O;`!6:65T($YA;0!6:65T;F%M97-E
M("A625-#24DI`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6
M:65W(&%S("5S`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA
M;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET
M86QY('9I82!33510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!
M3E5!3$Q9($923TT@)7,N`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`
M5V5A=&AE<B!&;W)E8V%S=`!796(`5V5B(%-I=&4`5V5E:VQY`%=E;&-O;64`
M5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!797-T97)N("A)4T\M.#@U.2TQ
M*0!797-T97)N("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!386AA<F$`5VAA="!A
M<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA
M="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@<75O
M=&4@8VAA<F%C=&5R/P!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z
M(`!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!8-3`Y=C,@97AT96YS:6]N<P!9
M60!965E9`%EA:&]O(2!M87``665A<FQY`%EE;65N`%EE<RP@22!!9W)E90!9
M;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@
M<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&1I9"!N;W0@96YT97(@82!V
M86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S
M(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@
M9FEE;&1S(&EN("5S+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!H
M879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R
M92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T
M(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE
M('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E
M('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@<V5L96-T(&%N('-E<G9E
M<B!T;R!B92!D96QE=&5D+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@
M=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A
M9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`
M66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9;W5R
M("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`
M66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E
M<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@
M;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL
M('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT
M:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R
M<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@
M;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H
M86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN
M(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A
M:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R
M92X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!O<'1I;VYS(&AA=F4@
M8F5E;B!U<&1A=&5D+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA
M`%IA:7)E`%IA;6)I80!::6UB86)W90!;4')O8FQE;2!297!O<G1=`%ML:6YE
M("5S(&]F("5S70!F:6QE`&9R;VT@=&AE("5S("@E<RD@870@)7,@)7,`:#H`
M:6UM961I871E`&YA;64`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@:6UP;&5M
M96YT960`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FYA
M;65D`'5S97(@<V5L96-T`'9#87)D`'<Z`'=E871H97(N8V]M`%!R;VIE8W0M
M260M5F5R<VEO;CH@2&]R9&4@,BXP"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D
M979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P
M+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P,2TP-BTQ."`R
M,CHP-2LP.#`P"DQA<W0M5')A;G-L871O<CH@;&EA;V)I;B`\;&EA;V)I;D!J
M:71E+FYE=#X*3&%N9W5A9V4M5&5A;3H@0VAI;F5S92`\:3$X;D!L:7-T<RYH
M;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X
M="]P;&%I;CL@8VAA<G-E=#U'0C(S,3(*0V]N=&5N="U4<F%N<V9E<BU%;F-O
M9&EN9SH@."UB:70*`"`H)7,@S.S'L"D`("B_[+W=O/P@)7,I`"`HO?',["D`
M("C7\LSL*0#3V@#7[KW\("5D(,SLQOC/\]2DL:@`)7,@+2"QN,W\PKP`)7,@
MUKC.Q@`E<R!+0@`E<R#.K+NDLMG7]R`M(,BWR,\`)7,@UZ*RX0`E<R#-K-+B
MS^[$OP`E<R#2T;3FU-H`)7,@U-H@)7,@)7,`L=C0Z-*J("5S`"5S(+?6`-72
MLKNUO2`E<RX`("5S(+6]("5S(+FR("5S`"5S.B`E<P`L(-7SM^<@)7,@)7,`
M++'DNZ_!O[33("5S(+6]("5S`"TM(-&AU/$@+2T`,C0@T*'*L=;&`+3+Q_B_
MZ;'8T.O2JM:XMJC*_;[=O^*W_L[QMLLN`+>BR?K!R]*[N/;1S];8M<2T[<[S
M`-/[O-/#W-/*O/XLN[G0Z-*JT]#2N[CV(%!'4""YJ[^JP]S4ORX`T_O1Z=:D
MTM''J</[M<33RKS^++NYT.C2JM/0TKNX]B!01U`@N:N_JL/<U+\N`-/[O>+#
MW-/*O/XLN[G0Z-*JT]#2N[CVN:N_JB!01U`@P]S4ORS+O</<(%!'4"##W-2_
M+-+4O+"_VL'N+@#3^]:TT-#3RKS^QZG#^RR[N=#HTJK3T-*[N/:YJ[^J(%!'
M4"##W-2_+,N]P]P@4$=0(,/<U+\LTM2\L+_:P>XN`-/[O>+#W-/*O/XLN[G0
MZ-*JT]#2N[CVN:N_JB!334E-12##W-2_+,N]P]P@4TU)344@P]S4ORS2U+RP
MO]K![BX`T_O6M-#0T\J\_L>IP_LLN[G0Z-*JT]#2N[CVN:N_JB!3+TU)344@
MP]S4ORS+O</<(%,O34E-12##W-2_+-+4O+"_VL'N+@#3^[S3P]S3RKS^++NY
MT.C2JM/0TKNX]B!334E-12"YJ[^JP]S4ORX`04TO4$T`05!)(+'@NL4`N=C3
MVM7BN/:QX+RMQO<`N=C3VBXN+@#(J,_>LKO7XRS.WK>HO:C!HB!61E,@Q+_"
MO"X`R*C/WK*[U^,LSMZWJ+VHP:(@5D93(,[$O/XN`-7+NL72T;:SO>$N`+WA
MU<H`T,+4]@#0PM3VS\*\MM?I`-#"U/;/PKRVR*C/W@#4VK3+T,+4]J.Z`-#"
MU/;3P[NGU^D`T,+4]LBHS]X`T,+4]M*[N/;3P[NG.@#0PM3VTKNX]K/)U+$Z
M`-#"U/:VU`#0PM3V("5S(,ZJ($UO>FEL;&$@4VED96)A<B"RR[6E`-#"U/;3
MP[NG`-#"U/;3P[NGM<2YIL3<M;''L+&[N=BQU2X`M=C6MP#-J-&VLKX`L\G.
MJKG<P.W4L2`M(,ZJQN3+_-/#NZ?%Y-;#R*C/W@"YW,#M`+GCN.:YW,#M`+"B
MN+NZN0"PHK;[L,W$X=''`+"BMON\L,#[T<<`L?##^P#+^=/0TM'1Z=:DM<33
MP[NG`,OYT]#3P[NGU^D`R_G3T,BHS]X`U,K0[;;@N/:UY]?3T\J\_K78UK<`
MTM&TYM3:`+'DN/P@24U34""UQ\*\`+'DN/P@24U34"##W,+K`+'DN/P@24U3
M4"#3P[NG`+'DN/S$H[#F`,/`RO3(^,2FT<<`TKNX]K*[NL^WJ+7$UK6QN\JY
MT\,N`+"RM<"V^P"PLKCGP*T`L+*YY\"M`,3DP_NT^L#M`,3/O*O6W@"PLLSA
MN<^\L+#-MONRO+3O`-.FT\.SS-#R`-.FT\.SS-#RTM&^S=#W`-.FT\.UO<OY
MT]#/PKRVN;+/[0#%^M>\`,O$U,(`L*+`K;*NSL0@*%=I;F1O=W,M,3(U-BD`
MT;G+]<[$O/ZT\]"A`-&YR_7.Q+S^P_NSQ@#$^LBWMJC2JLF^L_T@)7,@M<37
MHK+APO`@/P"PHKCYS:(`T<?#P,3AT<<`T<?#P,3AT<?.Q"`H05)-4T-)22TX
M*0"PHL*SL,T`L*+)K<O)R+JUN@#1Q];>+\RKQKW1\[78Q_@`UK30T,ZLNZ2R
MV=?WQ[#/U,J^R+?(S[;4N["_\C\`RM3-O,F^L_W2N[CVLKNTYM3:M<33P[NG
MU^DN`,K4S;S)OK/]TKNX]K*[M.;4VK7$R*C/WBX`RM3-O+'@O*W2N[CVLKNT
MYM3:M<33P[NGU^DN`,K4S;RQX+RMTKNX]K*[M.;4VK7$N;+/[2X`RO30U`"P
MR]3"`+#$M//`^]''`+#"M=C`^P!!=71H7V-R>7-Q;#H@U=*RN[6]R_G0Z-*J
MM<0@:6UA<"#`J=6YU^F\_BX`075T:%]C>7)U<SH@M_[.\;;+LJ+.M,SAN:FX
MP\_NUJ>SUBX`075T:%]C<GEU<SH@U=*RN[6]R_G0Z-*JM<0@:6UA<"#`J=6Y
MU^F\_BX`075T:%]F='`Z(-72LKNUO<OYT.C2JK7$($944"#`J=6YU^F\_B['
MZ];8T,*QX-+K(%!(4""RHL?2O-/(ZR`M+65N86)L92UF='`@T:'/[BS`_<CG
M(&-O;F9I9W5R92`M+65N86)L92UF='``075T:%]I;6%P.B#5TK*[M;W+^=#H
MTJJUQ"!)34%0(,"IU;G7Z;S^+@!!=71H7VMR8C4Z(-72LKNUO<OYT.C2JK7$
M(&MR8C4@P*G5N=?IO/XN`$%U=&A?;&1A<#H@U=*RN[6]R_G0Z-*JM<0@3$1!
M4"#`J=6YU^F\_BX`075T:%]L9&%P.B#.WK>HT,+4]M/#NZ<@)7,N(+?^SO'&
M][O8TZ8Z`$%U=&A?;&1A<#H@SMZWJ,F^L_W3P[NG("5S`$%U=&A?;&1A<#H@
MSMZWJ+C\T,+3P[NG("5S`$%U=&A?;6-A;#H@U=*RN[6]R_G0Z-*JM<0@34-!
M3"#`J=6YU^F\_BX`075T:%]S;6)A=71H.B#5TK*[M;W+^=#HTJJUQ"!S;6)A
M=71H(,"IU;G7Z;S^+@#1Z=:DRJ>PW"X`T>G6I,JGL-PN("5S`%)!1$E54R#1
MZ=:DM.W.\RX`1E10(-'IUJ2T[<[S+@"_R=/#M<37UK;..@"PHLC[L-V]K@"Q
ML[ZPT=7)JP!K97)B97)O<R##W,+KM.W.\RX`:V5R8F5R;W,@T\.[I\/[M.W.
M\RX`L,VY_L+MR+JUN@"PS<'6`+*HPMZUQ+JCSL0@*$E33RTX.#4Y+3$S*0##
MS[S3P*VY^@"PS;#-MN#+N0"PU[;MPM[+N0"QR,#[RK$`LJ[`^]?(`+&TQ/X`
ML-G$O;3SR+JUN@"RN[6D`,GZR-4`Q_B_Z<7DUL,`Q_B_Z<#@T,T`M-;,Y0"R
MH\#[SJS1QP#*Z<>I`+*HR[G$X=''NLVZVLC[N.?.K,3'`+*IM,3-W\3)`+*H
MSJS,V+6Z`+#-SO<`TZ+*]-.AMLC1\\'LM=@`SL3`LP"QH[S3P/O1QP#/[L2_
MM_NZQ0"RO+RJQ,FWJ,OW`+*\PJ&USP#$VLC=N=S`[<^US;,`0U)#`$-23""W
MUK*\M>,`R-7`^@#!X[RVM^<`O.W&TM6O`+^FPO/"H0#.WK>HP:J[^M;!($E-
M05`@M_[.\<;W.B`E<P"\T\3#M/,`R*'/^P#(H<_[SLK,XK&HN.8`SMZWJ,F^
ML_W.Q+S^("(E<R(N`,[>MZC)OK/]Q+_"O"`B)7,B+@#.WK>HUMC7Z:&CR_G,
MX;FIM<2\Q\*\ROW$O]/KS\C'L,OYL:.TYK7$ROV^W;*[M_LN`,[>MZBTJ\O-
MT,7/HK6]UKBVJ+7$NL7"ZRX`M_"UP[W'`+^JPOS(NK6Z`-+&MJ^UY[NP`,C[
MMOO,V,[$("A)4T\M.#@U.2TQ-"D`UM"WQ[FRNLVY^@#6T,6W("A)4T\M.#@U
M.2TR*0#&OM:DS[B]V@#&OM:DLM_"U`#5I[7#`+C\N,0`UL?`^P#6T+GZ`+SR
MS.76T,[$("A'0C(S,3(I`+>QS.76T,[$("A":6<U*0#1H=3QP]S"ZP#1H=3Q
MTKNX]M/#NZ?#^P#(U<;:S]3*OK>]RKTZ`,JEM:ZUN@#5TK*[M;T@)7,@M<3`
MX+'PMJC2Y2X`L+3*\['JO/R\S-#X`+G8L=6TL+_:`-3&P;\`O\:_QLNYR+JU
MN@"XY\+7L<C1QP#1U<FK`+7WR:O%S`"_J,VH`,/\P>X`P_S![KW%L;X`QL#"
MVP#-J-/#P_L`O\;$IL+>`+FKR[X`S/6\_@#%Y-;#("5S`,BWR,_#W,+K`+C5
MN?L`N-6Y^[FRNLVY^@#!K+W3RJ>PW#H@`,&LO=/6P;FKOZK#W-2_M_[.\<;W
MRK'4XK[<OO@N(-2MTO(Z("5S("@E<RD`P:R]T];!($944"#.Q+S^M_[.\<;W
MRJ>PW"X`O^*_R\BZM;H`N+36QM&AU/$`N.?+N;3OP.B\TP"_QLS8M<_-WP#.
MWK>HTM0@4$=0(+S3P]S3RKS^+@#.WK>HSJH@4$=0(-:TT-#3RKS^QZG#^RX`
MSMZWJ-+4(%,O34E-12"\T\/<T\J\_BX`SMZWJ,ZJ(%,O34E-12#3RKS^QZG#
M^RX`SMZWJ+#SMJ@@3$1!4""W_L[QQO<`SMZWJ+WBP]P@4$=0(,K]OMTN`,[>
MMZB]XL/<(%,O34E-12#*_;[=+@#.WK>HOO:VJ,K5O/[(R[7$M>?7T]/*O/ZU
MV-:W+@#.WK>HU]3#W-2_M_[.\<;WR*&UP[FKOZK#W-2_+@#.WK>HM/*_JB`E
M<RX`SMZWJ+3ROZK.K+NDN:37]\2CO^D@)7,`SMZWJ+;!R*$@)7,N`,[>MZBV
MP<BAM.;(H;_8UL:Q[2A!0TPI`,[>MZBVP<BAM_[.\<;WM<3/X+G8S-C0U`#.
MWK>HL:.TYB`E<R"UQ,7DUL,N`,[>MZBRZ=72($Q$05`@(+?^SO'&]RX`U=*R
MN[6]($UO>FEL;&$@4VED96)A<BX@Q^O(M\C/('-I9&5B87(@RL>W\;3ROZHN
M`+GZO-(`O:C!H@"]J,&BU]/.Q+S^O-``O:C!HM7?M<3(J,_>`-#%T\._J+K%
MPNL`O\O"WK78T<<`N<6PS0"UL<>PRK&\Y`"UL<>PS.S&^`"UL<>PU[2_]CH@
M`+6QQ["WY[CQ`+STQ]#1H=3Q`,C[QM;"M\NY`,[WP.^V^\[$("A+3TDX+5(I
M`,[WP.^V^\[$("A7:6YD;W=S+3$R-3$I`,[WP.^V^\[$+\[:O\O`O,[$("A+
M3TDX+54I`+W=O\NYLKK-N?H`R-4`P[_(U0#(U<;:`,K5M;W(U<;:`-&AU/'(
MU<;:`+#7S.P`RJZV_M3"`+SUR=G+]<7%`,2LR,_)[;?=RK:Q\`#)OK/]`,F^
ML_W3P[NGU^D`R;ZS_<BHS]X`R;ZS_:&BQ^6_U=/*O/X`M=W+S<JQO.0`M:3"
M\P#.RLSBP^C*]@##Z,KV`,^XO=H@*,?KLLZ_O"!(;W)D92"\Q\*\SL2\_BDZ
M`,^XO=K'Z[+.O[S/M<VSN=S`[;7'PKPN`-'0MZ(`PK:UX\["ML@`U^ZZ\]*[
MT*'*L;7$PK:UX\["ML@Z(`#"MK7CSL*VR#H@`+33U_/6P=/2`+33T]+6P=?S
M`,2_PKP`TM0@,C0@T*'*L=;&S]3*OC\`S]3*OM&AS^X`S]3*OKCQRKT`O*JR
MO,SA`+*[R;ZS_0"RN]*JUK&]T[3FR*$@;6%I;G1E;F%N8V4N<&AP`+7:TKNQ
MRKS'PKS*Q[?QL/RZK-?6ML[#^[/&/R#(Y[G[RL?'Z]&AU/$N`+;@P]?$X;S3
M`+;@P]?$X;S3N;*ZS;GZ`,_"U-@`S\+4V"`E<P#/PM38R?JSR;7$Q>36P\[$
MO/[.JB!02%`@L\S0\BX`S\+`K;++M:4`M>?7T]/*O/X`M.W.\P"V\KG/MN"V
M^P"QX+RM`+'@O*W'^+_I`+'@O*W3P[NGU^D`L>"\K<BHS]X`L>"\K<BHS]X`
ML>"\K2`E<R"UQ,BHS]X`L>"\K=&AS^X`L>"\K2`E<R"UQ,BHS]X`L*.\L`#(
M^+;[S=^VX`"UY]?3T\J\_@"UY]?3T\J\_K78UK<`M>?7T]/*O/ZUV-:WL=C0
MZ\['NL\N`+7GU]/3RKS^R+?(SP"Q[<?IM_NZQ0"_U;#7T,6\_BX`O]6PU[WA
MN?LN`,3JM=<`M\6T\['@O*W&]P"SX+7`O+C$VM''`+;RP:+,V,#OT<<`M.W.
M\P"PKLFSQ.'1QP"PH\C[MNVQR-''`,6WUMX`P[\@,34@M];6TP##OR`S,"##
MZ];3`,._(#4@M];6TP##O[3.M<?"O`##OR`S,""WUM;3`,._(#$@M];6TP"W
MML#]UK4Z`-:TT-``U;F_J@"UO<;:R-4`O>++M=2Q`$944"#)S[2KQ>36PRX`
MML'(H<:KNL/%Y-;#RJ>PW`#.WK>HP:R]TR!,1$%0(+?^SO'&]RX`SMZWJ,&L
MO=,@4TU"(+?^SO'&]RX`N+36QLJGL-S7U"`B)7,B+@"XM-;&RJ>PW+6]("(E
M<R(N`,[>MZB]J,&BTKNX]M#"M<0@4T%33"#!K+W3+@#2QK:OM;T@(B5S(LJG
ML-PN`+>HP+R_R[BCR+JUNB`HPNVV^\ZLQ,G+N<BZM;HI`+>HPM[(NK6Z`+2K
MU>8`MO[4P@"XT+[US_'*QP"XT+[US_'*QSH@`.RSO,,`SL2\_LK]Q+\Z("5S
M(+CVSL2\_@#.Q+S^ROW$OSH@)7,@SL2\_@#.Q+S^N=S`[<;W`,[$O/[#^[/&
M`,[$O/[)S[2K`,[$O/[)S[2KN:;$W,ZTL;O6I[/6+@"Y_<++QO<`M]+`O`#)
MS[#KU,(`R<_/TM3"`+G,MJBQR,#]`+>MUZH`Q+_"O"`E<R"RN[3FU-H`U];0
MS='5R:L`U*2QJ,SLROT@*-2DL:C,[,K]L/S`J+#7S.S2U+RPTKF\Y+7$ROV^
MW3O(Y[G[U*2QJ,SLROV]S[.DO:O5O-/#L<B]S[_MM_FUQ+#FP^8I`+2PS.4`
MR^/#_`#+X\/\P.#0S0#+X\/\`,+;S+,`U]2VK]>JT,4`T,?&VL[E`+>HN?H`
MMZC*]+GGT<?$QP"WJ,KTLJ/`^\3ASO?1QP"\Q+S^R,L`M-,`S>K5^\/HRO8`
MPOK4P@#(J\/[`+S3Q>X`N-2QR-''`++ZR?H@)7,@M<3/M<VSQ>36PP"X\<*S
MO*K1QP"UPKGZ`.7(Q,D`UK&RO,+>S=,`P_L`UZJUO0!';V]G;&4@R]'+]P"[
MTK;(`,^CP+``SZ/`L,[$("A)4T\M.#@U.2TW*0"X\<'JP+P`N/'!UL3)M.\`
MT\.[I]?IN=S`[0#3P[NGU^G#^[/&LKNUP[_5L-<`T\.[I]?I`+G/M<+"WL;5
MM;H`N=BUN@#.H[78PNW`K0"X\;;WSO>UN@"WP[_-R*C/W@"WP[_-P?31U`"\
MN,3:T<<`O+C$VM''L<C)W+FRNLVY^@"YY]''Q,<`2%1-3`#5TK*[M;T@2%14
M4"#1Z=:D+@"ZH[78`-33M-4MR^.WJ`"Q[<VW`+K5M<*ZS<+TM;'`S<BZM;H`
MSZ.RKL"TSL0@*$E33RTX.#4Y+3@M22D`L._6^@"QX+RMQO?*N=/#L._6^@"P
M[];Z`-7BP._*Q\[$O/ZUQ+^JRKPZ`.CSM=FXU`#*U]*S`,K7TK.UV-:W`,K7
MTK.UY[NP`+KIMKS`K<NY`-;0N?K/X[C;`$AO<F1E`,NNQKW/WP#7UK;.ROW$
MO[FRO,8_`,JJML@`RJJVR#H@`-#9T<#`^P!)34%0(-/*S^2]J,&BRJ>PW#H@
M)7,`24U!4"#3RL_DR;ZS_<JGL-PZ("5S`$E-05`@T\K/Y+3%Q<S%Y-;#O:C!
MHLJGL-PZ("5S`$E0(+78UK?.WK>HRKG3PRX`25`@M=C6M[*BLKO4VB!#2412
M(+7$O=/*W,?XO^G6T"X`L?FUN@#6N]/0S;RQZ@#-O+'JO+#.Q-?6`,G/M*O-
MO,:L`,V\QJP`N^/(ZRP@LKW6Z"`E9`"[X\CKU]:VSCH@)7,`N^/(Z]?6MLXZ
M`,KDR.NRN]7]R+>UQ-?WT\/"ZRX`U/:\T\OUQ<4`TZ&VR`"X]K'PT\.[IP#3
MH;;(Q.'.]]''`-#%SZ(`T,7/H@"RY<CKL>VX\0"RY<CKS?C"Y\&LO=,`LN7(
MZ[_)S.:T^L2CL.8`LN7(Z]/*O/X`LN7(ZR^QY+C\S;S&K`"RY<CK+['DN/S-
M^,+GP:R]TP#5^\K]`-7[ROW!T`#.WM"GM<0@541(*-/#NZ?*_;[=L>W-MRDN
M`,[>T*>UQ-.FT\.SS-#R+@#.WM"GM<3%^K3.NL7"ZRX`S.&]N[7$ROV^W<[>
MT*<N`,[>T*>UQ,2_L>K7H=:W`+*[NL^WJ+7$SL2\_KCQRKT`SM[0I[7$(&US
M9U]T>7!E+@#.WM"GM<2[\M72LKNUO2!A<&E?:60N`,[>T*>UQ+ORU=*RN[6]
MLL[*_2X`LKNZS[>HM<2XN,BHS]XN`,[>T*>UQ,VHT;;0K=+I+@#.WM"GM<3`
MM-2TUZ'6MRX`SM[0I[7$S?+3P\+KROV^W2X`TL'`RM+!R[G`O+FRNLVY^@#2
MP<"MO\L`L*ZV^\"\`,+\M;H`TM3)J\'0`,>IMZ+5WP#0L<SE`-+BM//`^P#1
MP,+RO-,`TKO4P@!*87!A;B`HR-6QOBD`R-7.Q"`H25-/+3(P,C(M2E`I`-3S
MSO>UN@#4O+6I`,;?U,(`P?G4P@#6P];0`-?ST]*VU,;K`+^_U_.VU,;K`+^_
MT]*VU,;K`+G^R/B_R\NYS+D`L:/!]-2MT?D@/P"_S\3AT<<`2V5R8F5R;W,@
MR,_6I+3MSO,N`,/<U+^]J,&B`,/<U+_,V-7W`,/<U+^SI+;(`,/<U+_`X-#-
M`,/<U+_3[[>H`+6QQ["UQ+FKOZK#W-2_M_[.\<;WUM`LTM&^K;3FU-K$^K7$
MP]S4ORX`N_G`[[#-R[FYLKK-N?H`LZ_/R@"ZJ[GZ`+JKSL0@*$550RU+4BD`
MO\;-_LS8`+RJMON\JLNYS+D`T^_1U`#`S\[.`,_"L.O4P@#/PL_2U,(`R<^T
MSKC\T,(Z`,G/TKNTSK7'PKPZ("5S`,G/TKNTSK7'PKPZ("5S(-?4("5S`,G/
MTKNTSK7'PKPZ(+7:TKNTSK7'PKP`P*W-T<ZLT<<`L.;#YL7DUL,`P.BPS<3;
M`,"SR_?-T`#`^['(P._1QP#`^['(T<<`P=#6I[;8RK^UQP#!K+W3`,&LO=,`
MP="S]B`M(-/#NZ>_R=+4O[2UO=7BN/;.Q+S^O-``P="S]LNUP_>QZLSB`,S6
MPMO3P[NGU^DMSL2\_KGQ`,S6PMO3P[NGU^DMQ_/6^@#,UL+;T\.[I]?I+<JV
ML?"ZQ<+K`,S6PMO3P[NGU^DMT[73T-7?`,S6PMO3P[NGU^DMO,2\_LC+`,S6
MPMO3P[NGU^DMMJG4Q`#,UL+;T\.[I]?I+<BAS_NVJ=3$`,'0L_;3P[NGM<2Y
MIL3<L;NYV+'5`,[$T:<`P:+,U<WP`+6QM=C*L;SD.B``M=C'^-/KRK&\Y`"U
MV,?X`+7'PKP`UZ+/^@"UQ\*\`+7'PKS*I[#<+"#'Z[SLLNG$^K7$T\.[I\/[
MNLW#W,+K+"#(N[KSUMC*U"X`M<?"O,JGL-PN`,*LR:VQI`#4P@##O\C5T,7/
MH@!-4RU43D5&(+B]O-/.Q+S^UM##N]/0ROV^W2X`35-'`-;0N?JPQ,/%`,+M
MQN2VV;FRNLVY^@#"[;3OO-/+N;S3M;H`T\J\_@#3RKS^N=S`[0#"[<"MS?X`
MPNW`M,[WT<<`PNVV^[3ZM_(`PNW`^P#"[;;ZR_L`R/W4P@"QZKS'L\D@O[2Y
M_2_.M+^TN?T`L>J\Q[/)QN3+_+7$RK:Q\"`HP/W(YRX@UMC2JB_2T;O8N+0I
M`,+MR=RV^\BZM;H`PNW,X<3AO\NUN@#5_=3:QJ7%Y-?6MLX`PZO`[\O^Q.'1
MQP##J\#OQ_/+N0"XO;S^ROW$O]+1LZRS]KW3RMS)S\_>+@#7[KW\(#(T(-"A
MRK&UQ-?NN-_.PK;(.B``U^Z]_"`V(-"ARK&UQ-?NN-_.PK;(.B``O=/*W-?N
MM/.SI+;(`,[EU,(`PNW4O,S8R+JUN@"SR=2Q`-&AM:7$H\J].@#3RKS^`-/*
MO/[1Z=:DTM'-ZK/)++6KRL?3P[NGM<3'J</[R+3.WK>HS:BY_='IUJ0N`-#%
MSZ+2T;G]QMHN`-#%SZ+`X-#-`$UE=&%R(,?XO^G.WK>HRKG3PRX`365T87(@
MQ_B_Z<[>MZC*N=/#+B#/N+W:Q^NRSK^\S[7-L[G<P.VUQ\*\+@"WO;>H`+FK
MUL8`Q*O.][CG`,/<O\O"WL3ASO?1Q\&JL.ZY^@!-:6UE(,#@T,T`U^Z]_"`R
M-"#0H<JQM<37[K7-SL*VR#H@`-?NO?P@-B#0H<JQM<37[KC?SL*VR#H@`-.S
MR>0`Q>36P\[$O/[2Q<JG+B#(Y[G[TJK*N=/#U>*X]M.FT\.SS-#RQ/JQV-#K
MS];4VK[-LOK)^LO[+@#5TK*[M;W0Q<^BM<0@240N`-72LKNUO;OAQMJUQ"!)
M1"X`T,?&VM*[`-#0MJ_3RKS^`+C\T,+(U<;:`,2CO^D`Q*:V^[;@S=\`Q*;$
MR;CG`,/)N<4`U,*ZS<3J`,._U,(`P\G,V,C[P*W,V`#4PL'!TZ^_]P#$IL+E
MN.<`S\+2Q@#7\]+&`-/2TL8`R<_2Q@#/PM+&`,G/TL8`Q*K)H['(O\L`N+31
MH0#.TK7$U<NZQ0#.TK7$P\6[IP#.TK7$P\6[I]*SP^;%Y-;#`,/EM>D`LKLL
MSM*RN\VLTN(`P_NSQ@#$R</7L<C1QP#HI\*S`,3ALK2V^P"ZR<"\`+K)RO2P
MLK78P=#+N0"[^=/:3F5T<V-A<&4@M<3-^-:W`$YE='-C87!E(%-33""W_L[Q
MQO?#^[/&`$YE='-C87!E(,C/UJ2UQ,7ZUZ(`3F5T<V-A<&4@R,_6I,#@T,T`
MS?C"YP"TT\ZT`-#"OZ;`[[;@Q.'1QP#0PM3"`-#"T\.[I\/[("BWQ['8TJHI
M`-#"SO?`O`#0PK2PO]H@*%]B;&%N:RD`T,+.Q0#/PM*[LKT`S\+2N[CVT:'/
M[@#$X;S3P*VYSP#$X<C5MOL`Q.'(U<#[T<<`S>W)SP#%IK"CM;H`R_G6N+:H
MM<3.N];#R<_#N]/0Q_B_Z;3FU-H`P[O3T,SAN:G(U<#ZP_NSQM+4N:D@34-!
M3"#1Z=:D+@##N]/0UKBVJ+7$("5S(,7DUL/0Q<^B+@##N]/0UKBVJ+7$($94
M4"!61E,@Q>36P]#%SZ(N`,.[T]#6N+:HM<0@4U%,(%9&4\7DUL/0Q<^B+@##
MN]/0UKBVJ+7$(%-13"U&:6QE(%9&4\7DUL/0Q<^B+@#.Q+S^SK3)S[2K`,Z[
MUL/0Q<^BR=#.M,7DUL,`P[O3T-:XMJC#W,+KTM2YJ2!(5%10(-'IUJ0N`,.[
MT]#6N+:HP]S"Z]+4N:D@24U!4"#1Z=:D+@##N]/0UKBVJ,/<PNO2U+FI($ME
M<F)E<F]S(-'IUJ0N`,.[T]#6N+:HP]S"Z]+4N:D@3&]G:6X@T>G6I"X`P[O3
MT-:XMJC#W,+KTM2YJ2!005-35T0@T>G6I"X`P[O3T-:XMJC#W,+KTM2YJ2!3
M34(@T>G6I"X`P[O3T+3]R?.UQ->BLN')ZL?K+@#.WM3=M.;$O\*\O\FYJ;_L
MR*$N`,.[T]"ZS[>HM<0@6$U,(,K]OMVQN[2KN]@`O]6PU]:U`-2MRKS%Y-;#
MSL2\_M;0U=*RN[6]L.:QOM#%SZ(N(-;8T,*R^LGZQ>36P\[$O/XN`-3:Q/JU
MQ,7DUL/.Q+S^UM#5TK*[M;VPYK&^T,7/HBX@UMC0PK+ZR?K%Y-;#SL2\_BX`
MSMX`R-6V^L+\SL0@*$E33RTX.#4Y+3$P*0#%M;BCO\NUN@"QL;#KQ_(`L;'"
M[<#OT<?$R<BZM;H`Q;+-_@"WQ]:NNO,`M\?6KL>P`+*[RL?2N[CVQ+_"O`#.
MM+&[UJ>SU@"QN,W\PKP`RJ[2N]3"`,K]U]8`U]:W^\K]`-?6ML[*_<2_`+'*
MROT`3TL`MM3/\[VHP:+5WP"PR[WXSKL`RJ[4P@"P[+FKRM(`L*+"_`#6N]/0
M($E-05`@M_[.\<;WUJ>SUL[$O/Z\T+FRS^VYIL3<+@#6N[W3RMS2N[CVT\J\
M_K78UK<N`-:[T]#3M=/0U=_3Z\^US;.YW,#MU+&_R=+4L>2X_+FRS^W(J,_>
M`-3:T,*TL+_:UM"T\K^J`-&AS^X`)7,@M<31H<_N`,_NQ+^QX+K%`-?IUJ\`
MU^G6K[6ESKL`U*W*O-.FT\.SS-#RQ*.PY@#4VB`E<SH@UM"UQ-2MRKS$H[#F
M+@#&Y,O\`,;DR_S0Q<^B`-.UT]#5W\BHS]X`4$%-(-'IUJ3.WM"G+@!01U`@
MROW7UL>IP_L`4$=0(+S3P]S7RL'/`%!'4""YJ[^JP]S4OP!01U`@TM''J</[
M+]+1O-/#W"#7RL'/`%!(4""SS-#RM/K"ZP!02%`@O<6QO@"PS;OYR[G,N0#%
MP<#-`+#-P-7+N<RYL;O5O,'LQ_@`L,W$P\+M`+#-LKS1Q]#"O+C$VM''`+#-
MP*VYYP##W,+K`,.[T]#6N+:HP]S"Z]+4N:D@4D%$2553(-'IUJ0N`,/<PNO(
MM\C/`,/<PNLZ`,/<PNLZ(`##W,+KL=C0Z\['NL\N`,SYR<\`S/G)SP#"M[ZV
M`+3]R?.UQ\*\H[H`UK30T,ZLNZ2RV=?W`+7'PKRZ\]:TT-#.K+NDLMG7]S\`
MR*C/W@"TYLBAU.*^W`#(J,_>`,BHS]ZYW,#M`,[2M<0`P]C"LP"WQL+)L?8`
MM>>[L`#5U<:L`,:DS-B_M;6Z`,?KRN3(Z]*[N/;4PK?=O+#$ZK?=+@#'Z\KD
MR.O2N[CVNL^WJ+7$R-7&VCO1H=3QM,O4PK?=M<3(U<;:+@#'Z\KDR.NZS[>H
MM<3*L;SD+@#'Z\SAN:G.RLSBM<35JM*J+@#'Z\KDR.O$^K7$T\.[I\/[O+##
MW,+K`+*HP+P`S;;&L0#&S\S1T<``M=W+S=/*O/ZUO=7BN/;.Q+S^O-`@*&YO
M="!E;F9O<F-E9"!B>2!)34%0*0#7[KW\("5S(-"ARK&UQ+VUT^K!OSH@`%!R
M969S7VQD87`Z(-72LKNUO<OYT.C2JK7$($Q$05`@P*G5N=?IO/XN`%!R969S
M7W-E<W-I;VXZ(-72LKNUO<OYT.C2JK7$('-E<W-I;VX@P*G5N=?IO/XN`,;X
MT;D`NJ/&O</FQOC1N3H@`,;XT;DZ(`#4I,#``,G/TKNX]M&AS^X`R[W#W,/<
MU+\`SLK,XL/HRO8`UZBPN`#,X<J^Q-K(W0"YJ[^JP]S4OP"YJ[^JP]S4O]'=
MR^,`N:N_JB_+O</<P]S4O[;4LJ+.M+&[LOK)^BX`LJBVX,#HN/<`OZC+_K;[
M`%)302"YJ[^JP]S4OR`H)60@SKLI`+6ET:$`L<C"R@"VP<BA`+;!R*'3RKS^
M`-7FM<32JLF^L_T@)7,@PO`_(-7BS^ZRV=?WO:O.WK>HN]:XM"X`R*'/^[BT
MU*T`RZ+0PL/%NZ?*T\V\.@"YYM3RL>VT[\J]`,;`PML`U+:SS+?^SO'&]P#4
MMK/,S?C6MR`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`,F^L_T`
MR;ZS_<?XO^D`R;ZS_;;4`-?4M_[.\<;WU-VTYL2_PKS6T,F^L_W2T;&CM.:U
MQ,7DUL.SS-#R+@#)OK/]T\.[IP#)OK/]T\.[ISH@)7,`T.C'\\ZTL;O/[-.F
M.B"T[<[SNL7"ZSH`UMC)Z`"]X;G[`+>UN]C1H<_N`%)E=6YI;VX@*,'TQ.'-
M^K6Z*0"]Q\FK`%)O;6%N:6$@*,+>PNW$X=''*0#0_=>J(#$X,""VR`#/\M?S
MT/W7J@#/\M/2T/W7J@#6M-#0`%)U<W-I86X@1F5D97)A=&EO;B`HMNW"WLNY
M*0!2=V%N9&$@*,*LL+*T[RD`4R]-24U%(+S3P]S'J</[`-/*O/[2T<JYT\,@
M4R]-24U%(+S3P]P`4T%33"#1Z=:DSM[0IRX`T,7/H@#*_;[=O^*]Q;&^`+S3
MP]S6U;;+N_H`L\FYI@#0Q\;:P?D`RJ6ZU<#5Q,.UN@#*I;OYM<*ZS<'0SJS+
MN0#*I<*LSO?1Q[6Z`,JEQJ2PH[;[NLW"\[_+PM?(NK6Z`,JESL3)K<S8NLVX
M\<'6Q,FT[P#-K-*[N/:TL+_:("A?<V5L9BD`R/C$IM''`,JEPNW!IL6U`,JE
MMN##P+K-QM7!UL[WL<@`SL#0Q\SAN:G5WP#)L\S8L*+`K;*N`+&CM.8`L:.T
MYB`E<P"QH[3FT:'/[@"]J[+ZR?JUQ,7DUL/.Q+S^TM0@4$A0(-/OT=2X\<J]
ML:.TYK6]Q/JUQ+?^SO'&]]3=M.;$O\*\UM`N`,7DUL,@)7,@TM&QH[3F+@#+
MT=&P`-&AU/'2N[CVR-7&V@#1H=3QTKNX]M/#NZ?7Z=/#TM30PM3V`-&AU/'2
MN\Z[T,*UQ-.UT]#5WP#1H=3QTKNRO[?^SO'&]P#1H=3QTKO.N]/#NZ?3P]+4
MT,+4]@#1H=3QR_G3T,C5QMK7Z;S^+@#3VM+4S\*UQ+2PO]K6T-&AR*'$^M*J
MM<37UK?[+M+4RO.QZKBTUL;+^=&ASL37UBS(N[KSS/G)S\[$O/ZQX+RMQ_@N
M`-&AU/'(U<;:M]:X]#H`T:'4\<C5QMK(U<;:N/'*O3H`T:'4\<JQO.2WUKCT
M.@#1H=3QR-7&VLJQO.2X\<J].@#1H=3QS^"[I<:EQ>2UQ+;^N/;7UK;.+@#1
MH=3QQ/JUQ-'5R:O%Y-;#`-&AU/'&J[K#T^_1U#H`M*O+S<[*S.*WM-.F`%-E
M;F5G86P@*,C[Q-J\T[;[*0"TJ[C0QO<Z(`"^Q=3"`%-E<F)I82!A;F0@36]N
M=&5N96=R;R`HR/NV^\ZLT<?3Z\/)S-C$X;CGPMXI`-#RNL4`N^'&VB!)1"#2
MT;G]QMHN`,7DUL,`Q>36P]2VL\RW_L[QQO?)S\KTT]K$^K7$N/;(R]6^S*@N
M`,7DUL/$^K7$QJNZP]/OT=0L(,JQQ_C2U+RPR-7&VKCQRKTN`,7DUL/$^K7$
MQO3*O-.FT\.SS-#R+-'5R:O%Y-;#+-*SP^:X_-#"QK7"RBR\L,;DR_S/U,J^
MT:'/[BX`T]"ZP[RXN/:UV+7CNLW5XKCVLL[*_=/0N=@Z(`!397EC:&5L;&5S
M("C(^\[TMOLI`+FZSN\`O/*VS-6JTJH`RL>W\<ZJM/.RO[?=M<3!K+W3MJC2
MY;_LO=VYIL3<O/P_`,_4RKX`P[^TSK7'PKRZ\\_4RK[)S]*[M,ZUQ+7'PKS*
ML;SD(#\`S]3*OK7CT:'&]P#3VM?SL=_/U,J^("5S(+++M:4_`,K5R_4`4VEE
M<G)A($QE;VYE("C*J-?3R;VY^BD`UZ*RX0#'J</[`,>IP_O1W<OC`%-I;F=A
M<&]R92`HT,*\T\;"*0"T\]"A`,+4N?W.K+ND`%-L;W9A:VEA("C+N<+EMZ6_
MRRD`4VQO=F5N:6$@*,NYPN6WI<3AT<<I`+O]T:G)[K;(.B``4V]L;VUO;B!)
M<VQA;F1S("C+]\+>P\7(NK6Z*0!3;VUA;&EA("C+]\+MP/O1QRD`Q<7!T+>]
MS_+1H=3Q`,"TU+2UV-:W`%-O=71H($%F<FEC82`HQ,^WQRD`Q,_%MR`H25-/
M+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H
M($ES;&%N9',`Q,^PZ\?R`%-P86EN("C.][#@T<`I`,"LN_C3RKS^`,S8RN+7
MUK?[RN3(ZP!3<FD@3&%N:V$@*,NYP._`O+^H*0"QZM>\`,;TRKS$ZK?=`,JA
M`->TS*P`L:.TYKCQRKT`O=:UP`#)OK/]S]\`U]:W^[2NP=``T,?&VLSL`-;W
MUKP`S.&]NP#/PK'J`+/)N:8`TM&SR;FFN+*XQR`E<P!3=61A;B`HR]6UI"D`
MU:K2J@#(U;/V`,C5PN0`R-6S]@#(U;/V+\C5PN0`R-6S]CH@`,C5PN0`R-7"
MY#H@`,G/L>H`UJ>SU@!3=7)I;F%M92`HR]7`^\3/*0"TPKK%`%-V86QB87)D
M(&%N9"!*86X@36%Y96X`4W=A>FEL86YD("C*M\W?O,/`O"D`4W=E9&5N("C(
M\+7D*0!3=VET>F5R;&%N9"`HR/#*ORD`4WER:6%N($%R86(@4F5P=6)L:6,@
M*-#PP/O1QRD`5$%"(+?6N/2X\<J]SL2\_@#,J,WE`,RHS>4`5&%J:6MI<W1A
M;B`HR_Z\JLNYS+DI`%1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8@*,RY
MR=#$X=''*0#$O['J.@"T_;#LRL+/[@"UY[NPNL7"ZP#7[KW\TKO0H<JQM<3.
MPK;(.B``SL*VR`#.PK;(.B``Q*.PYKG<P.T`Q-K(W0"TO\[$U]8`T,?&VLO$
M`,RISL0@*%1)4RTV,C`I`%1H86EL86YD("C,J;GZ*0#0N]"[Q/K*N=/#L;[/
MM<VS+@!&5%`@T=/)["AE>'1E;G-I;VXISM[0IRX`36%I;G1E;F%N8V4@P."Q
M\+*BSK2SR;FFU-C(ZP#1H<_NM+"_VM+4N=BQU2[`Z[^JUM`N`-'IUJ33RKS^
MQZG#^]#HTJK3T-*[N/;2T;WBOZJUQ"!01U`@Q_B_Z2X`T.C2JM*[N/:^K;G]
MO-/#W+7$S?C"Y\&LO=,N`,[$O/X@)7,@TZ:XP[#\NJS2N[CV("5S(,7DUL,N
M`,[$O/X@)7,@TZ:XP[#\NJS2N]"I("5S(,7DUL,N`+3+SL2\_M;0P[O3T,K]
MOMTN`-+4S\+*QR!R9F,X,C(@T\J\_K7$L>W-MRX`1VYU4$<@MO[4JL[$O/ZU
MQ,*WOK:QV-#KMJC2Y=3:($-R>7!T7W!G<#HZ(,#@L?#6T"X`2&]R9&5?0W)Y
M<'1?<VUI;64Z.B#`X+'P++'8T.C2JM/0(&]P96YS<VP@Q*._Z2X`M,O&J[K#
M("(E<R(@ROV^W=+RSJJSK+G]U^ZT\[W3RMS6M2S+^=+4SMZWJ+&[L:.TY@#3
MP]+4O.S*T[3+ROV^W<#@T,T@*"5S*2"UQ+/,T/*RHK*[M.;4VM/:S[7-L\G/
M+@"TR[?^SO'&]R`B)7,B(-+1L;O)OK/]+@"TR[?^SO'&]R`B)7,B(-+1L;NQ
MH[3F+@`E<R"UQ->BLN'0Z,?STM&QN\F^L_TN`-:XMJBUQ+S'PKRRHK*[M.;4
MVBX`M-/)S]*[N/:RO=;HUJZZ\\G/M*NUQ,K]OMW2Q<JG+@#)S[2KSL2\_K*B
MSK2QN[&CM.8N`'=E871H97(N8V]M(,?XO^G.WK>HRKG3PRX`SMZXO;S^O\G6
ML;W3M/*_JBX`M,O7UK;.UM"P_+JLS*NVX+7$U];*_2[$^M+1RN3(ZR`E<R"X
M]M?6ROT[Q/K*Y,CKM<37ULK]L=C0Z]"AT]H@)7,N`,G/M*O.Q+S^RK&WHLGZ
MTKNX]L[*S.(Z("5S(,ZTL;O)S[2K+@#)S[2KSL2\_LJQMZ+)^M*[N/;.RLSB
M.B`E<R"T\]"ALZRY_;W3RMS7[K3SUK4@*"5D(&)Y=&5S*2X`R<^TJ\[$O/[*
ML;>BR?K2N[CVSLK,XCH@O?:RO[?6M<0@)7,@SL2\_K&[R<^TJRX`O.S*T]/*
MO/[*L;>BR?K2N[CVM.W.\RX`N^/(Z[3+S:C1MK*^ROV^W<JQMZ+)^K3MSO,N
M`-3:Q>36P[2PS.76T+>BR?K!R]*[N/:T[<[S+M/0O\G$W,3ZTL7"J<'+L=C0
MZ\SNT+2UQ-?6MLXN`+3+($E-05`@M_[.\<;WLJ+.M-:GL];.Q+S^O-"WUL_M
MN:;$W"X`U>++QKKULKO*Q]7]R+>UQ"!R87(@T;G+]<[$O/XN`-7BR\:Z];*[
MRL?5_<BWM<0@>FEP(-&YR_7.Q+S^+@#5XLO&NO6RN\K'U?W(M[7$T,73P[^H
MNL7"ZRX`M,O7UK;.RL>QV-#HTJJUQ"X`M,O7UK;.Q-K(W=:[O=/*W-7[ROW*
M_=?6+@"TR]?6ML[$VLC=UKN]T\K<ROW7UKRPP["ZQ2X`M,O7UK;.Q-K(W=:[
MO=/*W+#+O?C6QLK]UK4N`+3+U]:VSL3:R-VQV-#KSJJVNKK%N_*_U;#7M]:X
M]+7$ROW7U@"QV-#KRL?2N[CVROW7UBX`M,O7UK;.Q-K(W;'8T.NP_+JLTKO7
MZ<JNP?F]^-;&M<0@4D="(-'5R:NT^L+K+,#]R.<@)R,Q,C,T868G+@#5XKCV
MM+#,Y=+1L;NTIL#MN?TN`-7BRL<@)7,N`+3+ROW6M=?NR=FQV-#KRL<@,2X`
MM,NW_L[QQO?.WK>HMM0@>FEP(+RP(&=Z:7`@N/'*O<[$O/Z]^-#0O>+1N<OU
M`+3+S[7-L[6QQ[#*Q\VCT\.UQ->TS*PN`+'8T.O*Q]*[N/;*_=?6+@"TR[2P
MO]JQV-#KTJK3R=&AS^ZTL+_:*$]P=&EO;BG+^;KTO=``RK&\Y`#*L;SDU[?7
MV0#*L;SDN/'*O0#*L<?XT:'4\0!4:6UO<BU,97-T90"QZLSB`,K5O/[(RP#(
MY[G[TJJXM-&A+,?KU-JUX]&ARO.QZK7$S:S*L;"T($-O;G1R;VR\_"BX]LC+
MO,;+X[OZ*2"[\B!#;VUM86YDO/PHQKNY^[S&R^.[^BDN`+WQS.P`2%1-3"#4
MK<J\SL2\_@"VX+CG`,W0O\O`S<BZM;H`P_?,[`#,P+S3`,S8P:+$X;3ONLVV
MX+#-N.<`U>:[\KS9`-#'QMJV_@#-N\3AR[D`S<&V^L;D`,W!MOK&Y,[$("A)
M4T\M.#@U.2TY*0#-P;_BPOS+N<RY`,S8O\O+N;K-OZV_QLNYR+JUN@#-O,W?
MPJP`RN3(Z\3ZM<31H=3Q.B``U\_-XL_?UKC*_3H@`,WXUK<`S?C6MSH`SMJX
MR;3O`,[:O\O`O`#.WK>HM.;(H2!61E,@Q+_"O"X`UZ*RX<JQSMZWJ-3VO-.V
M[LWBM<33P[NGT,7/HBX`SMZWJ+C$L>0@5D93(,[$O/X@(B5S(B"UQ,BHS]XN
M`,[>MZBQY+C\(%9&4R#.Q+S^("5S+R5S(+7$R*C/WBX`SMZWJ+'DN/S.JB`E
M<RX`SMZWJ,&LO=/6P2!344P@M_[.\<;W+@#.WK>HRKG3PR!34TP@P:R]TRX`
MSMZWJ+BTUL8@5D93(,[$O/XN`,[>MZB]J,&B(%9&4R#$O\*\("(E<R(N`,[>
MMZB]J,&B(%9&4R#$O\*\+@#.WK>HO:C!HB!61E,@SL2\_BX`SMZWJ+VKROV^
MW;WBT;G+]2X`SMZWJ,F^L_T@)7,LM,O$O\*\LJ*WQ[_5L-<`SMZWJ+7=N>G)
MOK/]Q+_"O"X`SMZWJ,F^L_T@5D93(,2_PKPN`,[>MZC)OK/](%9&4R#$O\*\
M.B`E<RX`SMZWJ,F^L_T@5D93(,[$O/X@(B5S(BX`SMZWJ,F^L_T@5D93(,[$
MO/XN`,[>MZBUW;GIR;ZS_2!61E,Z("5S+@#.WK>HQ="VS[6QQ["UQ,2_PKPN
M`,[>MZB]XK^JQK[6I,^XO=H`SMZWJ+S3U-@@)7,@M<2VJ-+EROV^W2X`SMZW
MJ-+&MJ\@5D93(,[$O/XN`,[>MZBT\K^J(%9&4R#.Q+S^("(E<R(N`,[>MZC0
MM,CK(%9&4R#.Q+S^+@#.WK>HM/*_JB!61E,@SL2\_BX`SMZWJ+3ROZK1N<OU
MSL2\_BX`SMZWJ+;!R*$@=F9S<F]O="#$O\*\+@#.WK>HL>2X_"!61E,@Q+_"
MO+7$P_NSQBX`SMZWJ,F^L_T@5D93(,2_PKPZ("5S+@#.WK>HL>2X_"!61E,@
MSL2\_B`B)7,B(+7$P_NSQBX`SMZWJ+'DN/P@5D93(,[$O/X@)7,O)7,@M<3#
M^[/&+@#.WK>HL>2X_"!61E,@SL2\_K7$P_NSQBX`SMZWJ->JN[L@5V]R9"#.
MQ+S^`,[>MZC0M,CK(%9&4R`B)7,B(,[$O/XN`,[>MZC0M,CK(%9&4R#.Q+S^
MROV^W2X`S\*[KL_?`,BAS_NX_+C$`+BTU*T`M_[.\<;WP:R]T\JQMZ+)^LZT
MU*3&VK7$N]C3ICH@`+>BR?K.M-2DQMJUQ+O8TZ8LT\FW_L[QQO<Z(`#-\M/#
MPNL@*%541BTX*0"PHL"MLJ[!JKK/Q_6SI+GZ`-.BN?H`P\"Y^@!5;FET960@
M4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`M:74J@#.M-:JM<0`SK36
MJK7$T\.[I\/[N_+#W,+K+@#.M-:GL]:UQ,"IU;G#^P"QY+C\`+C\T,(@)7,`
MN/S0PM/#NZ<`N/S0PK/,T/+2T<F^L_TN`,G/M*L`TM')S[2KR_G3T-.FT\.S
MS-#RM<3%Y-;#SL2\_K6]M_[.\<;W+@#.VL"MN><`T\.[IR`E<R#.M,VHN?T@
M)7,@M<3*VLBHT>G6I"X`T\.[I[G<P.T`T\.[I]&AS^X`T\.[I]>BLN$`M,O5
MOLRHM<33P[NGUZ*RX<^US;/2T<VCT\,N`-/#NZ?#^P#3P[NGP_LZ`-/#NZ<Z
M(`#/M<VSUM"UQ-/#NZ<Z`,[:U\BQ\+_+R[G,N0!61E,@Q+_"O+*BLKNTYM3:
M+@"\V<;:`-+1U=*UO=/0T*>UQ+78M>,Z(`#3T-"GT-0`TM2WUM;3SJJUI<Z[
M*+33S];4VL;PR^,I`-:U`,W?PK.PHLV\`+'DNZ\`SJ_$VLCPP*T`T>G6I,JG
ML-P@+2"TR]/*O/Z_R<3<TM'4XLC+R</7U+3;N,0N`+#FL;X`L.:QOK_8UL8`
MU+W$SP#4O<3/SL0@*%9)4T-)22D`O.S*TR`E<P#4VM#"M+"_VK3ROZH`TM0@
M)7,@LNF_M`#3HLKTSJRV^[ZIR+JUN@##P,KTSJR^J<BZM;H`Q-R\^[;(`,3<
MO/NVR#H@`-+BM//`^[?\M<*WY[7GT,6YJ\N^S;BY_2!33510`+ZON.8`OJ^X
MYB$A(2"TTR`E<R#*UK:OR;ZS_;/,T/(N`,W?P/O+N;K-N+O-O,BZM;H`OJ^X
MY@#0Q\;:R/T`S.S&^-2DLN(`S?C5O@#-^-6^`,._UMP`N[;3K0"[MM.MM;T@
M)7,`N[;3K2P@)7,`SO?%MR`H25-/+3@X-3DM,2D`SO?%MR`H25-/+3@X-3DM
M,34I`,[WR/:Y_L"M`+7'PKRZ\].FN,//R,_4RKX@)7,@Q,32N[CVTZ;3P[/,
MT/(_`-?6MLZUQ+?6N/37UK?[/P#2_<KVM<3'L+6\M_L_`+?GR]DHO=HI`+?G
MR]DZ`+?GR]DZ(`"P[+FKRM*UV-:W`+#LN:O*TK7GN[``6#4P.78S(,"IU;G#
M^P#$Z@#$Z@!986AO;R`A(+78S;P`P[_$Z@#2LL/%`,K'M<0LSM+-K-+B`,3Z
MM;''L,JYT\.TO\[$U]:QX-"TQ*/*O2X@RKG3PR!;/#Y=(+"TQ:6_R<?0N[O.
MJLWXTK.QX-"TQ*/*O2X`Q/JRHLZTRN3(Z]*[N/:ZS[>HM<2UY]?3T\J\_K78
MUK<N`,3ZLJ+.M-/)M;S(Z[7$SL2\_M;0MM33L\C.NL[7UK;.M;T@)7,`Q/K2
MT;ZMUZ+/^BX`Q/JQV-#KRN3(Z]*[N/:ZS[>HM<36M2X`Q/JQV-#KS\BYYKNN
MNL/*_;[=RO<H1&%T851R964IM_[.\;;+LL7$W+S,T/C*N=/#T,+3P[NGUZ*R
MX;?^SO$N`,?KP^C*]L[*S.*CK-3:Q/JTJ\O-SLK,XK&HN.;6KL>P+@#$^K'8
MT.O*Y,CKM,O!K+W3R_G6N,_RM<3-^-:W`,?KUKBVJ-*JR;ZS_;7$M_[.\<;W
M+@#'Z]:XMJC2JLF^L_VUQ-/#NZ<N`,?KUKBVJ-*JT,+4]K7$T\.[IRX`Q^O6
MN+:HTJJX_-#"M<33P[NG+@#'Z]:XMJC2JM:TT-"UQ-?WT\,N`,3ZM<0@)7,@
MN^'&VM+1N?W*L2['Z];8T,*UQ\*\+@#$^K7$M>?7T]/*O/ZUV-:W`,3ZM<30
MQ<^B`-?4M-/$^K7$("5S(+OAQMJ_JLJ\TM3`M,3ZM<32\LS8S?BUV-:WTM&Q
MY+C\+B#.JK&CNZ3$^K7$L++(J\;PO/NCK,3ZL=C0Z];8T,*UQ\*\+@#$^K7$
MT-7#^P#$^K7$T>G6I+;+LJ+.M-:GL];!T+/VT\.[I[ORN,.YIL3<TM&QN[G8
ML=4N`-?4M-/$^K7$("5S(+OAQMJ_JLJ\TM3`M,3ZM<3DK\#`QO?+QKKUTM&Q
MY+C\+B#.JK&CNZ3$^K7$L++(J\;PO/NCK,3ZL=C0Z];8T,*UQ\*\+@#$^K7$
MY*_`P,;WLJ+.M-:GL];5XKCVN:;$W"X`Q/JUL<>PR_G%Y-;#M<3*L<?X.@#$
M^K7$T:'/[M+1N/S0PBX`Q/JUQ-2VL\RW_L[QQO<Z`,3/R[G`K;?R`-3ZTL&V
M^P#4WK'(T<<`O?*PS;*\SJ0`6\[*S.*QJ+CF70!;SKO3VM#0("5S(+FR("5S
M(-#070#.Q+S^`+33("5S("@E<RD@T]H@)7,@)7,`RK$Z`,&BO+0`P_NSQ@#)
MT,ZTRK7/UBX`R=#.M,JUS]8N`-39M,[*Y,CKQ/JUQ,/<PNO2U,BWR,_.WL[S
M`,ZTP_S#^P#3P[NGT:'4\0!V0V%R9`#0Q\;:.@!W96%T:&5R+F-O;2#-^-6^
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&]C86QE+WIH7T-.+VAE;'`N>&UL````````````````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S,S(P(#$P-3$U-#,S-S0R
M(#`R,30T-P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/WAM;"!V97)S:6]N/2(Q+C`B/SX*/"$M+2`D2&]R9&4Z(&AO<F1E
M+VQO8V%L92]Z:%]#3B]H96QP+GAM;"QV(#$N,B`R,#`T+S`U+S(W(#(P.C(R
M.C$R(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED/2)S=6UM87)Y
M(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H92!0;W)T86P@4&%G93PO=&ET;&4^
M"B`\<&%R83X*("!4:&ES('!O<G1A;"!P86=E('!R;W9I9&5S(&$@<75I8VL@
M<W5M;6%R>2!O9B!A;&P@>6]U<B!I;7!O<G1A;G0*("!I;F9O<FUA=&EO;BX@
M1F]R(&5X86UP;&4L(&ET(&UI9VAT('-H;W<@:&]W(&UA;GD@;F5W(&4M;6%I
M;"!M97-S86=E<R!Y;W4*("!H879E(&EN('EO=7(@24Y"3U@L('5P8V]M:6YG
M(&5V96YT<R!O;B!Y;W5R(&-A;&5N9&%R+"!T87-K<R!O;B!Y;W5R('1O+61O
M"B`@;&ES="P@:&5A9&QI;F5S(&9R;VT@<V5L96-T960@;F5W<R!S97)V:6-E
M<RP@86YD('-O(&]N+B`@36%N>2!O9B!T:&5S90H@('-U;6UA<FEE<R!W:6QL
M(&-O;G1A:6X@<75I8VL@<VAO<G1C=71S('1O(&-O;6UO;B!F=6YC=&EO;G,L
M('-U8V@@87,*("!C;VUP;W-I;F<@82!N97<@;6%I;"!M97-S86=E+"!C<F5A
M=&EN9R!A(&YE=R!C86QE;F1A<B!E=F5N="!O<B!T87-K+"!E=&,N"B`\+W!A
M<F$^"B`\<&%R83X*("!4:&4@8V]N=&5N=',@;V8@=&AI<R!P;W)T86P@<&%G
M92!A<F4@8W5S=&]M:7IA8FQE('9I82!T:&4@3&%Y;W5T(&)U='1O;BX*("!&
M;W(@97AA;7!L92P@>6]U(&-A;B!C:&]O<V4@=VAI8V@@:71E;7,@=&\@:6YC
M;'5D92!O;B!T:&ES('!O<G1A;"!P86=E(&%S"B`@=V5L;"!A<R!I;B!W:&EC
M:"!O<F1E<B!T:&5Y(&%R92!S:&]W;BX*(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](FYA=F)A<B(@<W1A=&4](FYE=R(^"CQT:71L93Y4:&4@07!P
M;&EC871I;VX@3F%V:6=A=&EO;B!"87(\+W1I=&QE/@H@/'!A<F$^"B`@070@
M=&AE(&QE9G0@:&%N9"!S:61E(&]F('1H92!W96(@<&%G92!I<R!T:&4@87!P
M;&EC871I;VX@;F%V:6=A=&EO;B!B87(N"B`@0VQI8VL@;VX@=&AE(&EC;VYS
M(&]N('1H:7,@;F%V:6=A=&EO;B!B87(@=&\@<75I8VML>2!A;F0@96%S:6QY
M('-W:71C:`H@(&)E='=E96X@=&AE(&%V86EL86)L92!A<'!L:6-A=&EO;G,N
M"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD;U]M86EN
M=&5N86YC92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z
M($UA:6YT96YA;F-E.B!$;R!-86EN=&5N86YC93PO=&ET;&4^"B`@("`\<&%R
M83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O('!E<F9O<FT@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<R!O;B!L;V=I;BP@8VAE8VL@=&AI<R!B;W@N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUC;VYF:7)M7VUA
M:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E
M<SH@36%I;G1E;F%N8V4Z($-O;F9I<FT@36%I;G1E;F%N8V4\+W1I=&QE/@H@
M("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!C;VYF:7)M(&%L
M;"!M86EN=&5N86YC92!T87-K<R!B969O<F4@=&AE>2!A<F4@<G5N+"!C:&5C
M:R!T:&ES(&)O>"X@268@;&5F="!U;F-H96-K960L(&%L;"!M86EN=&5N86YC
M92!O<&5R871I;VYS('1H870@;F5E9"!T;R!B92!R=6X@=VEL;"!B92!P97)F
M;W)M960@875T;VUA=&EC86QL>2!W:71H(&YO(&-H86YC92!T;R!C86YC96P@
M;VX@;&]G:6XN"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L<#X*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQO8V%L92]Z:%]45P``````````````````````````````````
M```````````````````````````````````````````````````P,#`W-34@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<T,B`P,3<W
M-3(`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+WIH7U17+TQ#7TU%4U-!
M1T53````````````````````````````````````````````````````````
M`````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P
M(#$P-3$U-#,S-S0R(#`R,34S-P`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A
M;&4O>FA?5%<O3$-?34534T%'15,O:&]R9&4N;6\`````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`S-#$P-C,@,3`U,34T,S,W-#(@,#(S,C8S`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````-X2!)4`````30<`
M`!P```"$.@``QPD``.QT````````")P```X````)G```#P```!B<```-````
M*)P```@````VG```"P```#^<```,````2YP```0```!8G```&````%V<```;
M````=IP``"T```"2G```'0```,"<```D````WIP``"D````#G0``&0```"V=
M```F````1YT```P```!NG0``)````'N=```/````H)T```L```"PG0``#@``
M`+R=```%````RYT``"@```#1G0``"````/J=```*`````YX``!4````.G@``
M$@```"2>```+````-YX``(4```!#G@``#@```,F>```*````V)X```T```#C
MG@``#@```/&>```1`````)\```T````2GP``#````""?```-````+9\```8`
M```[GP``E````$*?```*````UY\```\```#BGP``&````/*?```,````"Z``
M``X````8H```#@```">@```(````-J````D````_H```+@```$F@```:````
M>*```#(```"3H```.````,:@``!4````_Z```%$```!4H0``6@```*:A``!7
M`````:(``#0```!9H@``"0```(ZB```-````F*(```<```"FH@``"@```*ZB
M```/````N:(```4```#)H@``!@```,^B```1````UJ(```@```#HH@``"0``
M`/&B```)````^Z(``"4````%HP``(````"NC```3````3*,``!````!@HP``
M#P```'&C```*````@:,```,```",HP``#P```)"C```4````H*,```D```"U
MHP``#0```+^C```2````S:,``!D```#@HP``'@```/JC```/````&:0```H`
M```II```#P```#2D```(````1*0``"0```!-I```%````'*D```6````AZ0`
M``@```">I```3@```*>D```M````]J0``!D````DI0``!P```#ZE```,````
M1J4``"P```!3I0``#@```("E```#````CZ4```L```"3I0``!P```)^E```'
M````IZ4```4```"OI0``!0```+6E```*````NZ4```,```#&I0``%P```,JE
M```*````XJ4```\```#MI0``#@```/VE```8````#*8``",````EI@``#@``
M`$FF```4````6*8``!<```!MI@``%P```(6F```7````G:8``!,```"UI@``
M#P```,FF```.````V:8``!\```#HI@``'0````BG```'````)J<```8````N
MIP``"````#6G```/````/J<```8```!.IP``"@```%6G```3````8*<```L`
M``!TIP``$````("G```5````D:<``!4```"GIP``!P```+VG```0````Q:<`
M``4```#6IP``%0```-RG```1````\J<```P````$J```.P```!&H```X````
M3:@```D```"&J```!P```)"H```4````F*@```,```"MJ```!0```+&H```0
M````MZ@```D```#(J```$P```-*H```Y````YJ@``!(````@J0``)P```#.I
M```L````6ZD``"H```"(J0``)0```+.I```*````V:D```8```#DJ0``"0``
M`.NI```'````]:D``"\```#]J0``-P```"VJ```N````9:H``%4```"4J@``
M+0```.JJ```M````&*L``#T```!&JP``/P```(2K```M````Q*L``$````#R
MJP``(P```#.L```C````5ZP``$````![K```+0```+RL```S````ZJP``"4`
M```>K0``%0```$2M```9````6JT``"D```!TK0``)````)ZM```H````PZT`
M`!$```#LK0``"@```/ZM```*````":X``!`````4K@``%@```"6N```6````
M/*X```<```!3K@``!P```%NN```4````8ZX```H```!XK@``"````(.N```G
M````C*X```@```"TK@``!P```+VN```'````Q:X```8```#-K@``!0```-2N
M```'````VJX```8```#BK@``"````.FN```I````\JX```X````<KP``"@``
M`"NO```$````-J\```<````[KP``"0```$.O```&````3:\``!$```!4KP``
M!P```&:O```6````;J\```0```"%KP``"````(JO```&````DZ\```T```":
MKP``!@```*BO```>````KZ\``!$```#.KP``"````."O```-````Z:\```P`
M``#WKP``!P````2P```#````#+````,````0L```%P```!2P```3````++``
M`!T```!`L```"````%ZP```$````9[````@```!LL```"````'6P``!!````
M?K```!H```#`L```(````-NP```5````_+````8````2L0``!@```!FQ```5
M````(+$``!@````VL0``(@```$^Q```N````<K$``!T```"AL0``(0```+^Q
M``!4````X;$``"D````VL@``"@```&"R```'````:[(``!4```!SL@``#@``
M`(FR```*````F+(```\```"CL@``#0```+.R```/````P;(```T```#1L@``
M"0```-^R```4````Z;(```8```#^L@``&`````6S```=````'K,``!,````\
MLP``$0```%"S```4````8K,```0```!WLP``!@```'RS```4````@[,``%0`
M``"8LP``9````.VS```$````4K0```X```!7M```!0```&:T```%````;+0`
M`!L```!RM```&@```(ZT```3````J;0``!$```"]M```$0```,^T```<````
MX;0``"H```#^M```$````"FU```A````.K4```4```!<M0``$P```&*U```+
M````=K4``!(```""M0``"@```)6U```/````H+4```T```"PM0``$0```+ZU
M```3````T+4```P```#DM0``!@```/&U```,````^+4```8````%M@``%P``
M``RV```0````)+8``!$````UM@``"````$>V```%````4+8```P```!6M@``
M$````&.V```%````=+8```T```!ZM@``!@```(BV```'````C[8```T```"7
MM@``!P```*6V```+````K;8```<```"YM@``!P```,&V```)````R;8```D`
M``#3M@``"@```-VV```9````Z+8``#T````"MP``'0```$"W```,````7K<`
M`!````!KMP``!0```'RW```E````@K<``!(```"HMP``$P```+NW```K````
MS[<``#L```#[MP``(````#>X```(````6+@``#8```!AN```(0```)BX```0
M````NK@```@```#+N```#````-2X```$````X;@```\```#FN```#@```/:X
M```*````!;D```T````0N0``'P```!ZY```<````/KD``"$```!;N0``'@``
M`'VY```9````G+D``!X```"VN0``'0```-6Y```;````\[D``"`````/N@``
M+@```#"Z```F````7[H``!P```"&N@``'@```*.Z```<````PKH``"8```#?
MN@``*P````:[```S````,KL``"8```!FNP``*P```(V[```X````N;L``!T`
M``#RNP``%0```!"\```O````)KP``"````!6O```$@```'>\```I````BKP`
M`!X```"TO```(````-.\```2````]+P``*(````'O0``%@```*J]```C````
MP;T``"@```#EO0``*0````Z^```H````.+X``!\```!AO@``%0```(&^```@
M````E[X``"4```"XO@``*````-Z^```M````![\``#`````UOP``D@```&:_
M```A````^;\``!8````;P```'````#+````F````3\```"H```!VP```00``
M`*'```!$````X\````P````HP0``!P```#7!```'````/<$```8```!%P0``
M#0```$S!```0````6L$``!(```!KP0``$P```'[!```2````DL$```<```"E
MP0``!````*W!```0````LL$```P```##P0``#@```-#!```-````W\$```\`
M``#MP0``$P```/W!```-````$<(``"@````?P@```P```$C"```-````3,(`
M``8```!:P@``$0```&'"```7````<\(``!L```"+P@``#@```*?"```"````
MML(``$D```"YP@``!0````/#```0````"<,```\````:PP``!````"K#```-
M````+\,```X````]PP```P```$S#```.````4,,```@```!?PP``#P```&C#
M```/````>,,```<```"(PP``#0```)##```0````GL,```T```"OPP``"P``
M`+W#```&````R<,```L```#0PP``#````-S#```*````Z<,``!$```#TPP``
M&0````;$```+````(,0```T````LQ```(@```#K$```;````7<0``#0```!Y
MQ```"@```*[$```8````N<0``!D```#2Q```%@```.S$```B`````\4```T`
M```FQ0``!P```#3%```4````/,4```L```!1Q0``(@```%W%```O````@,4`
M``L```"PQ0``"0```+S%```9````QL4```L```#@Q0``%P```.S%```7````
M!,8```D````<Q@``%@```";&```/````/<8``!D```!-Q@``%@```&?&```.
M````?L8``!@```"-Q@``"````*;&```-````K\8``"8```"]Q@``0P```.3&
M```(````*,<``!(````QQP``'P```$3'```(````9,<```L```!MQP``+P``
M`'G'```.````J<<```4```"XQP``!@```+['```#````Q<<```<```#)QP``
M!````-''```*````UL<```H```#AQP``#P```.S'```0````_,<``!<````-
MR```$0```"7(```9````-\@``!<```!1R```"0```&G(```%````<\@```L`
M``!YR```"@```(7(```%````D,@```T```"6R```&P```*3(```7````P,@`
M`!0```#8R```"0```.W(```.````]\@```T````&R0``$@```!3)```X````
M)\D``"````!@R0``"````(')```.````BLD``'L```"9R0``&````!7*```1
M````+LH```<```!`R@``!0```$C*```8````3LH``!X```!GR@``&P```(;*
M```9````HLH``!L```"\R@``$P```-C*```'````[,H```@```#TR@``!@``
M`/W*```&````!,L``!`````+RP``#P```!S+```0````+,L```\````]RP``
M"P```$W+```/````6<L```P```!IRP``#P```';+```'````ALL```8```".
MRP``#@```)7+```,````I,L```\```"QRP``"````,'+```(````RLL``!,`
M``#3RP``'@```.?+```A````!LP``"`````HS```&0```$G,```7````8\P`
M`"4```![S```%P```*',```6````N<P```0```#0S```&P```-7,```-````
M\<P```P```#_S````P````S-```%````$,T```@````6S0``"@```!_-```,
M````*LT```L````WS0``$````$/-```,````5,T```0```!AS0``$P```&;-
M```4````>LT```P```"/S0``"0```)S-```.````ILT```L```"US0``&P``
M`,'-```'````W<T```<```#ES0``"@```.W-```-````^,T```D````&S@``
M!````!#.```%````%<X```,````;S@``&````!_.```*````.,X```0```!#
MS@``)@```$C.```.````;\X``'P```!^S@``%0```/O.```%````$<\```<`
M```7SP``#````!_/```(````+,\```H````USP``!@```$#/```(````1\\`
M``(```!0SP``!@```%//```&````6L\``!0```!ASP``#0```';/```0````
MA,\``!L```"5SP``!````+'/```)````ML\``!````#`SP``"0```-'/```)
M````V\\```4```#ESP``"````.O/```&````],\``!D```#[SP``#@```!70
M```'````)-````<````LT```!0```#30```)````.M````H```!$T````@``
M`$_0```&````4M````L```!9T```#0```&70```)````<]````8```!]T```
M$@```(30```)````E]````<```"AT```%````*G0```=````OM```$(```#<
MT```)0```!_1```E````1=$```8```!KT0``"@```'+1```$````?=$```D`
M``""T0``"````(S1```1````E=$```D```"GT0``!@```+'1```-````N-$`
M``8```#&T0``!````,W1```>````TM$```4```#QT0``#@```/?1```$````
M!M(```8````+T@``!P```!+2```A````&M(```T````\T@``%0```$K2```&
M````8-(```0```!GT@``$0```&S2```&````?M(```H```"%T@``(@```)#2
M```$````L](```4```"XT@``'0```+[2```$````W-(```P```#AT@``#@``
M`.[2```*````_=(```@````(TP``"0```!'3```%````&],``#H````ATP``
M,````%S3```U````C=,``"D```##TP``1P```.W3```X````-=0``"D```!N
MU```/P```)C4```N````V-0``"T````'U0``'P```#75```/````5=4``!(`
M``!EU0``"P```'C5```F````A-4``"D```"KU0``)````-75```F````^M4`
M``@````AU@``"@```"K6```)````-=8```<````_U@``(````$?6```@````
M:-8``"8```")U@``"@```+#6```9````N]8``"D```#5U@``$@```/_6```'
M````$M<```H````:UP``#````"77```/````,M<``!````!"UP``0````%/7
M``!P````E-<``&8````%V```#@```&S8```)````>]@```H```"%V```$@``
M`)#8```3````H]@```P```"WV```!@```,38```/````R]@``!(```#;V```
M$````.[8```1````_]@``!P````1V0``(P```"[9``!J````4MD```\```"]
MV0``!0```,W9```0````T]D```D```#DV0``!````.[9```+````\]D``"``
M``#_V0``%````"#:```,````-=H```P```!"V@``#P```$_:```5````7]H`
M`"D```!UV@``*@```)_:```F````RMH``"<```#QV@``*0```!G;```J````
M0]L``!D```!NVP``0@```(C;```1````R]L``!(```#=VP``$P```/#;```4
M````!-P```\````9W```%@```"G<```7````0-P``!````!8W```$0```&G<
M```T````>]P``!,```"PW```$@```,3<```U````U]P``!0````-W0``!P``
M`"+=```,````*MT``"`````WW0``$````%C=```4````:=T``!$```!^W0``
M%P```)#=```<````J-T``!,```#%W0``%````-G=```:````[MT``!$````)
MW@``&@```!O>```>````-MX``!H```!5W@``$P```'#>```5````A-X``!$`
M``":W@``%P```*S>```4````Q-X``!<```#9W@``%0```/'>```)````!]\`
M`!`````1WP``&0```"+?```$````/-\```<```!!WP``"P```$G?```1````
M5=\```8```!GWP``!@```&[?```&````==\```4```!\WP``!P```(+?```'
M````BM\```4```"2WP``%@```)C?```&````K]\```8```"VWP``!````+W?
M```$````PM\```<```#'WP``#@```,_?```,````WM\```P```#KWP``#0``
M`/C?```*````!N````X````1X```!0```"#@```H````)N````X```!/X```
M#````%[@```/````:^````H```![X```"````(;@```)````C^```"L```"9
MX```!````,7@```(````RN```"8```#3X```$@```/K@```/````#>$```8`
M```=X0``"@```"3A```'````+^$```@````WX0``(````$#A```)````8>$`
M`!0```!KX0``#````(#A```-````C>$```X```";X0``%@```*KA```1````
MP>$```8```#3X0```P```-KA```&````WN$```<```#EX0``!````.WA```+
M````\N$```L```#^X0``!P````KB```'````$N(``!8````:X@``#0```#'B
M```-````/^(```H```!-X@``$````%CB```/````:>(``!$```!YX@``%P``
M`(OB```*````H^(``!$```"NX@``"````,#B```$````R>(```\```#.X@``
M.@```-[B```%````&>,``!X````?XP``#@```#[C```0````3>,```L```!>
MXP``#````&KC```)````=^,```<```"!XP``"@```(GC```)````E.,```X`
M``">XP``$````*WC```;````ON,``!@```#:XP``&@```//C```*````#N0`
M``D````9Y```"@```"/D```,````+N0```\````[Y```"````$OD```&````
M5.0```<```!;Y```!0```&/D```+````:>0``$<```!UY```#0```+WD```)
M````R^0```0```#5Y````P```-KD```3````WN0``!,```#RY```$P````;E
M```*````&N4```(````EY0``!````"CE```E````+>4```,```!3Y0``!0``
M`%?E```J````7>4```H```"(Y0``!0```)/E```$````F>4```H```">Y0``
M#0```*GE```&````M^4```@```"^Y0``"````,?E```$````T.4```4```#5
MY0``:````-OE```)````1.8```P```!.Y@``!0```%OF```&````8>8``!L`
M``!HY@``+P```(3F```0````M.8```H```#%Y@``#P```-#F```*````X.8`
M``D```#KY@``$P```/7F```;````"><``!@````EYP``%P```#[G```?````
M5N<```X```!VYP```P```(7G```'````B><```@```"1YP``!P```)KG```*
M````HN<```L```"MYP``!P```+GG``!1````P><``!`````3Z```#````"3H
M```:````,>@``$H```!,Z```&0```)?H```&````L>@``!H```"XZ```)0``
M`-/H```&````^>@```8`````Z0``'P````?I```&````)^D```D````NZ0``
M&````#CI```7````4>D``"@```!IZ0``!@```)+I```-````F>D``"(```"G
MZ0``5P```,KI```3````(NH``",````VZ@``$P```%KJ```"````;NH```L`
M``!QZ@``"````'WJ```-````ANH```H```"4Z@``!P```)_J```4````I^H`
M``8```"\Z@``"````,/J```.````S.H```<```#;Z@``"@```./J```+````
M[NH``#(```#ZZ@``!P```"WK```,````->L```T```!"ZP``#````%#K```)
M````7>L```D```!GZP``"@```''K```'````?.L```D```"$ZP``!P```([K
M```*````ENL``!L```"AZP``$@```+WK```*````T.L``!8```#;ZP``"0``
M`/+K```0````_.L```<````-[```$@```!7L```$````*.P```<````M[```
M!0```#7L```%````.^P```L```!![```%````$WL```1````8NP``!H```!T
M[```%@```(_L```4````INP``!<```"[[```&````-/L```<````[.P``!D`
M```)[0``!P```"/M```%````*^T```T````Q[0``#````#_M```1````3.T`
M``@```!>[0``%P```&?M```+````?^T```P```"+[0``'P```)CM```:````
MN.T``!,```#3[0``!````.?M```*````[.T```0```#W[0``#````/SM```%
M````">X```D````/[@``!0```!GN```'````'^X```4````G[@``!````"WN
M```"````,NX``#@````U[@``+````&[N```2````F^X``"D```"N[@``,@``
M`-CN```*````"^\``"P````6[P``+@```$/O```S````<N\``#,```"F[P``
M.````-KO```/````$_```!@````C\```$````#SP```/````3?```!,```!=
M\```%0```''P```4````A_```!(```"<\```%````*_P```M````Q/```"T`
M``#R\```,0```"#Q```N````4O$``"\```"!\0``+````+'Q``!B````WO$`
M`!,```!!\@``#0```%7R```(````8_(``!<```!L\@``"````(3R```,````
MC?(``"L```":\@``(0```,;R```:````Z/(```D````#\P``10````WS``!!
M````4_,```0```"5\P``$P```)KS```4````KO,```X```##\P``$P```-+S
M```8````YO,```8```#_\P``"0````;T```*````$/0```\````;]```$```
M`"OT```'````//0```X```!$]```!0```%/T```;````6?0```@```!U]```
M!@```'[T```4````A?0``!$```":]```#@```*ST```X````N_0```(```#T
M]```!@```/?T```.````_O0```4````-]0``!P```!/U```&````&_4``"@`
M```B]0``#````$OU```<````6/4```0```!U]0``*0```'KU```?````I/4`
M`%P```#$]0``%````"'V```^````-O8``!\```!U]@``$````)7V```'````
MIO8```X```"N]@``#````+WV```,````RO8``!,```#7]@``"@```.OV```=
M````]O8``!D````4]P``!0```"[W```1````-/<``!$```!&]P``)````%CW
M```2````??<``!4```"0]P``$@```*;W```.````N?<``!D```#(]P``"```
M`.+W```)````Z_<```T```#U]P``"@````/X```'````#O@```\````6^```
M!@```";X```+````+?@``!H````Y^```"@```%3X```'````7_@```@```!G
M^```!0```'#X```?````=O@```8```"6^```$````)WX```(````KO@```T`
M``"W^```"````,7X```>````SO@``!(```#M^```+`````#Y```:````+?D`
M``D```!(^0``"@```%+Y```5````7?D```4```!S^0``%````'GY```$````
MCOD``!````"3^0``!@```*3Y```'````J_D``!X```"S^0``*````-+Y```*
M````^_D``!P````&^@``$0```"/Z```+````-?H``!H```!!^@``%````%SZ
M```$````<?H```0```!V^@``"P```'OZ```%````A_H```8```"-^@``"```
M`)3Z```&````G?H``!L```"D^@``-````,#Z```T````]?H``"`````J^P``
M*0```$O[```@````=?L``$$```"6^P``&@```-C[```H````\_L``"D````<
M_```4````$;\```B````E_P```8```"Z_```"````,'\```%````ROP```@`
M``#0_```&0```-G\```9````\_P``"H````-_0``(P```#C]```9````7/T`
M`"X```!V_0``-````*7]```(````VOT``!<```#C_0``"@```/O]```'````
M!OX``"$````._@``$````##^```.````0?X```L```!0_@``!P```%S^```3
M````9/X```@```!X_@``"P```('^```*````C?X``!0```"8_@``#P```*W^
M```R````O?X```L```#P_@``!0```/S^```%`````O\```4````(_P``%P``
M``[_```/````)O\```0````V_P``"@```#O_```)````1O\```L```!0_P``
M#0```%S_```,````:O\```X```!W_P``!0```(;_```$````C/\```T```"1
M_P``,@```)__``!%````TO\``!<````8``$`!P```#```0`>````.``!`!0`
M``!7``$`!0```&P``0`4````<@`!``8```"'``$`!P```(X``0`.````E@`!
M`"H```"E``$`!@```-```0`,````UP`!``T```#D``$`$0```/(``0`+````
M!`$!`#8````0`0$`"@```$<!`0`B````4@$!``L```!U`0$`#P```($!`0`R
M````D0$!`"4```#$`0$`,````.H!`0`Q````&P(!`"T```!-`@$`#@```'L"
M`0`%````B@(!``X```"0`@$`$P```)\"`0`2````LP(!``<```#&`@$`$0``
M`,X"`0`3````X`(!``<```#T`@$`%````/P"`0`8````$0,!``<````J`P$`
M!0```#(#`0`,````.`,!``P```!%`P$`$@```%(#`0`$````90,!``<```!J
M`P$`"@```'(#`0`+````?0,!``P```")`P$`#@```)8#`0`.````I0,!``4`
M``"T`P$`!0```+H#`0`N````P`,!`"8```#O`P$`(P```!8$`0`#````.@0!
M`!(````^!`$`!@```%$$`0`>````6`0!`!@```!W!`$`)0```)`$`0`-````
MM@0!``D```#$!`$``P```,X$`0`'````T@0!``H```#:!`$``@```.4$`0`,
M````Z`0!`!4```#U!`$`"P````L%`0`9````%P4!`"`````Q!0$`$@```%(%
M`0`%````904!``H```!K!0$`%0```'8%`0`2````C`4!``P```"?!0$`!```
M`*P%`0`)````L04!``<```"[!0$`#````,,%`0!2````T`4!`!<````C!@$`
M)````#L&`0`2````8`8!``<```!S!@$`!@```'L&`0`.````@@8!``P```"1
M!@$`#0```)X&`0`5````K`8!`!(```#"!@$`#P```-4&`0`4````Y08!``H`
M``#Z!@$`&P````4'`0`0````(0<!``L````R!P$`:0```#X'`0`:````J`<!
M`!<```##!P$`)P```-L'`0`:`````P@!`!<````>"`$`&P```#8(`0`9````
M4@@!`!\```!L"`$`$P```(P(`0`(````H`@!``<```"I"`$`"````+$(`0`)
M````N@@!`!4```#$"`$`#0```-H(`0`C````Z`@!``T````,"0$`$P```!H)
M`0`(````+@D!``,````W"0$`1@```#L)`0`_````@@D!`#<```#""0$`5P``
M`/H)`0`%````4@H!`!\```!8"@$`+P```'@*`0`*````J`H!``@```"S"@$`
M#0```+P*`0`M````R@H!``0```#X"@$`3P```/T*`0`E````30L!``L```!S
M"P$`'P```'\+`0`=````GPL!`"4```"]"P$`(````.,+`0`D````!`P!`"``
M```I#`$`"P```$H,`0`'````5@P!``T```!>#`$`#````&P,`0`7````>0P!
M``8```"1#`$`#````)@,`0`'````I0P!``D```"M#`$`$P```+<,`0`)````
MRPP!``0```#5#`$`$````-H,`0`(````ZPP!``@```#T#`$`!````/T,`0`+
M`````@T!``P````.#0$`$@```!L-`0`1````+@T!``P```!`#0$`#P```$T-
M`0`'````70T!``T```!E#0$`%````',-`0`.````B`T!``P```"7#0$`&P``
M`*0-`0`L````P`T!`!,```#M#0$`!@````$.`0`'````"`X!`!,````0#@$`
M!0```"0.`0`$````*@X!`!<````O#@$`"@```$<.`0`,````4@X!``D```!?
M#@$`!@```&D.`0`)````<`X!``@```!Z#@$`"0```(,.`0`*````C0X!`!$`
M``"8#@$`!@```*H.`0`.````L0X!``X```#`#@$`#0```,\.`0`+````W0X!
M`!T```#I#@$`"P````</`0`"````$P\!`!P````6#P$`!P```#,/`0`&````
M.P\!`&0```!"#P$`"0```*</`0`'````L0\!`"8```"Y#P$`.````.`/`0`:
M````&1`!`"H````T$`$`.P```%\0`0`H````FQ`!`#0```#$$`$`&0```/D0
M`0`5````$Q$!``4````I$0$`!P```"\1`0`(````-Q$!``<```!`$0$`!0``
M`$@1`0`'````3A$!``X```!6$0$`"0```&41`0`&````;Q$!``@```!V$0$`
M"P```'\1`0`'````BQ$!``@```"3$0$`!P```)P1`0`6````I!$!``D```"[
M$0$`!@```,41`0`+````S!$!`!````#8$0$`!@```.D1`0`<````\!$!`!0`
M```-$@$`!P```"(2`0`1````*A(!``@````\$@$`#@```$42`0`(````5!(!
M``4```!=$@$`$````&,2`0`0````=!(!``8```"%$@$`&0```(P2`0`*````
MIA(!`!P```"Q$@$`!P```,X2`0`%````UA(!`!````#<$@$`%````.T2`0`+
M`````A,!``T````.$P$`*````!P3`0`8````11,!`!<```!>$P$`!````'83
M`0`)````>Q,!``H```"%$P$`!P```)`3`0`"````F!,!``X```";$P$`"```
M`*H3`0`C````LQ,!`#@```#7$P$`)@```!`4`0`Q````-Q0!`"<```!I%`$`
M9````)$4`0`4````]A0!`%4````+%0$`.````&$5`0!*````FA4!`%L```#E
M%0$`*````$$6`0`X````:A8!`"@```"C%@$`+````,P6`0`F````^18!`!L`
M```@%P$`/@```#P7`0`C````>Q<!`!<```"?%P$`2````+<7`0"%`````!@!
M`#````"&&`$`)0```+<8`0!!````W1@!`%L````?&0$`20```'L9`0`Q````
MQ1D!`!T```#W&0$`&````!4:`0`K````+AH!`"$```!:&@$`'P```'P:`0`K
M````G!H!`"$```#(&@$`)P```.H:`0`Z````$AL!`!T```!-&P$`$0```&L;
M`0`S````?1L!`"4```"Q&P$`)P```-<;`0`@````_QL!`!\````@'`$`,```
M`$`<`0!I````<1P!`#$```#;'`$`00````T=`0`S````3QT!`"4```"#'0$`
M/0```*D=`0!E````YQT!`$T```!-'@$`+P```)L>`0`N````RQX!`#````#Z
M'@$`5````"L?`0!:````@!\!`$@```#;'P$`2@```"0@`0`R````;R`!`"\`
M``"B(`$`+````-(@`0`M````_R`!`!<````M(0$`)0```$4A`0`R````:R$!
M`"D```">(0$`/@```,@A`0`B````!R(!`%(````J(@$`)0```'TB`0`+````
MHR(!`+$```"O(@$`10```&$C`0`A````IR,!`#````#)(P$`)0```/HC`0`<
M````("0!`#$````])`$`!P```&\D`0`'````=R0!``0```!_)`$`#0```(0D
M`0`+````DB0!``X```">)`$`"P```*TD`0`%````N20!`!````"_)`$``@``
M`-`D`0!9````TR0!``4````M)0$`$@```#,E`0`$````1B4!``<```!+)0$`
M"````%,E`0`%````7"4!``,```!B)0$`$````&8E`0`3````=R4!``T```"+
M)0$``@```)DE`0`'````G"4!``8```"D)0$`%````*LE`0`,````P"4!`!@`
M``#-)0$`!@```.8E`0`2````[24!``P`````)@$``P````TF`0`$````$28!
M``8````6)@$`!P```!TF`0`?````)28!`#4```!%)@$`+@```'LF`0`O````
MJB8!`!<```#:)@$`(@```/(F`0`E````%2<!`"`````[)P$`&P```%PG`0`8
M````>"<!`"0```"1)P$`'P```+8G`0`:````UB<!`"$```#Q)P$`(````!,H
M`0`:````-"@!`#(```!/*`$`&@```((H`0`O````G2@!`"L```#-*`$`'P``
M`/DH`0`C````&2D!`!\````]*0$`&@```%TI`0`A````>"D!`"4```":*0$`
M)@```,`I`0`E````YRD!`"0````-*@$`&````#(J`0`=````2RH!`"0```!I
M*@$`&````(XJ`0`B````IRH!`"P```#**@$`+P```/<J`0`5````)RL!`"4`
M```]*P$`/````&,K`0`?````H"L!`",```#`*P$`'P```.0K`0`@````!"P!
M`!H````E+`$`&````$`L`0`F````62P!`!X```"`+`$`*0```)\L`0`>````
MR2P!`#$```#H+`$`"0```!HM`0`,````)"T!`!<````Q+0$`+P```$DM`0`D
M````>2T!``<```">+0$`#P```*8M`0`4````MBT!``X```#++0$`#0```-HM
M`0`D````Z"T!``4````-+@$`!P```!,N`0`B````&RX!`"4````^+@$`&@``
M`&0N`0`=````?RX!`!H```"=+@$`!P```+@N`0#'````P"X!``L```"(+P$`
M%0```)0O`0`&````JB\!``D```"Q+P$`"P```+LO`0`-````QR\!`!<```#5
M+P$`!@```.TO`0`S````]"\!`!,````H,`$`$P```#PP`0`'````4#`!``\`
M``!8,`$`!P```&@P`0`R````<#`!``0```"C,`$`(0```*@P`0`3````RC`!
M``P```#>,`$`$0```.LP`0`R````_3`!`!8````P,0$`"````$<Q`0`=````
M4#$!``D```!N,0$`"@```'@Q`0`4````@S$!``H```"8,0$`'0```*,Q`0`(
M````P3$!`!\```#*,0$`"````.HQ`0`:````\S$!``8````.,@$`%0```!4R
M`0`'````*S(!``@````S,@$`"0```#PR`0`_````1C(!``<```"&,@$`#P``
M`(XR`0`.````GC(!`!````"M,@$`"0```+XR`0`)````R#(!``@```#2,@$`
M$P```-LR`0`'````[S(!`!D```#W,@$`"@```!$S`0`7````'#,!`!0````T
M,P$`"@```$DS`0`,````5#,!`!<```!A,P$`!````'DS`0`J````?C,!``P`
M``"I,P$`$0```+8S`0`'````R#,!``(```#0,P$`$````-,S`0`8````Y#,!
M``L```#],P$``P````DT`0`(````#30!``8````6-`$`!P```!TT`0`-````
M)30!``L````S-`$`%````#\T`0`5````5#0!``X```!J-`$`+P```'DT`0`@
M````J30!`!P```#*-`$`%0```.<T`0`,````_30!`#$````*-0$`!0```#PU
M`0`2````0C4!`#\```!5-0$`$@```)4U`0`*````J#4!``8```"S-0$`!```
M`+HU`0`$````OS4!``H```#$-0$`$P```,\U`0`%````XS4!``8```#I-0$`
M!@```/`U`0`(````]S4!``0`````-@$`#`````4V`0`*````$C8!`#D````=
M-@$`+@```%<V`0`9````AC8!`!\```"@-@$`'0```,`V`0`1````WC8!``(`
M``#P-@$`!````/,V`0`*````^#8!``8````#-P$`!0````HW`0`#````$#<!
M``P````4-P$`10```"$W`0`R````9S<!`!H```":-P$`-````+4W`0`H````
MZC<!`%,````3.`$`&0```&<X`0!R````@3@!`"````#T.`$`-0```!4Y`0`A
M````2SD!`$4```!M.0$`,````+,Y`0`H````Y#D!`"D````-.@$`)@```#<Z
M`0`E````7CH!`"@```"$.@$`*````*TZ`0`B````UCH!`"L```#Y.@$`,```
M`"4[`0`2````5CL!`!,```!I.P$`$````'T[`0!Y````CCL!``D````(/`$`
MH0```!(\`0!S````M#P!`'P````H/0$`*P```*4]`0!4````T3T!`!<````F
M/@$`)P```#X^`0`6````9CX!``\```!]/@$`%P```(T^`0`?````I3X!`$``
M``#%/@$`'P````8_`0`<````)C\!`%$```!#/P$`&@```)4_`0`4````L#\!
M``H```#%/P$`!0```-`_`0`&````UC\!``@```#=/P$`$@```.8_`0`0````
M^3\!`!,````*0`$`'0```!Y``0`/````/$`!``\```!,0`$`!````%Q``0`)
M````84`!``L```!K0`$`!P```'=``0`%````?T`!`!0```"%0`$`!P```)I`
M`0`(````HD`!``\```"K0`$`"````+M``0`,````Q$`!``\```#10`$`!@``
M`.%``0`4````Z$`!``8```#]0`$`#`````1!`0`(````$4$!`!D````:00$`
M$0```#1!`0`*````1D$!`!@```!100$`$P```&I!`0`<````?D$!`!$```";
M00$`#P```*U!`0`$````O4$!`!D```#"00$`!P```-Q!`0`"````Y$$!``(`
M``#G00$`$0```.I!`0`)````_$$!``8````&0@$`$@````U"`0`7````($(!
M``8````X0@$``@```#]"`0`$````0D(!``\```!'0@$`$P```%="`0`'````
M:T(!``<```!S0@$`$0```'M"`0`&````C4(!`!@```"40@$`!@```*U"`0`3
M````M$(!`!````#(0@$`$@```-E"`0`"````[$(!``8```#O0@$`#````/9"
M`0`)`````T,!`!$````-0P$`(@```!]#`0`'````0D,!``<```!*0P$`"P``
M`%)#`0`%````7D,!``(```!D0P$`"P```&=#`0!A`0``<T,!``H```#51`$`
M#````.!$`0`*````[40!``<```#X1`$`!P````!%`0`'````"$4!``(````0
M10$`$0```!-%`0`8````)44!`"L````^10$`&@```&I%`0`=````A44!`!,`
M``"C10$`$0```+=%`0`I````R44!``T```#S10$`&P````%&`0`2````'48!
M``L````P1@$`!P```#Q&`0`%````1$8!`!(```!*1@$`!P```%U&`0`'````
M948!``L```!M1@$`"0```'E&`0`+````@T8!`#P```"/1@$`"0```,Q&`0`%
M````UD8!``H```#<1@$`#P```.=&`0`*````]T8!``H````"1P$`"@````U'
M`0`*````&$<!``8````C1P$`60```"I'`0`'````A$<!``P```",1P$`$@``
M`)E'`0`*````K$<!``D```"W1P$`"0```,%'`0`)````RT<!``8```#51P$`
M'0```-Q'`0`4````^D<!`"4````/2`$`+0```#5(`0!`````8T@!`$0```"D
M2`$`1````.E(`0!*````+DD!`"<```!Y20$`"````*%)`0`(````JDD!``@`
M``"S20$`"````+Q)`0`(````Q4D!``D```#.20$`"````-A)`0`.````X4D!
M``<```#P20$`!@```/A)`0`&````_TD!`!L````&2@$`&P```")*`0`(````
M/DH!``H```!'2@$`"P```%)*`0`$````7DH!``0```!C2@$`"@```&A*`0`*
M````<TH!``D```!^2@$`"````(A*`0`(````D4H!`!$```":2@$`$````*Q*
M`0`/````O4H!``@```#-2@$`#0```-9*`0`&````Y$H!`!D```#K2@$`#P``
M``5+`0`0````%4L!``H````F2P$`,P```#%+`0`K````94L!`!L```"12P$`
M!````*U+`0`&````LDL!`"$```"Y2P$`!````-M+`0`$````X$L!`!0```#E
M2P$`%````/I+`0`4````#TP!``@````D3`$`!````"U,`0`)````,DP!``0`
M```\3`$`$@```$%,`0`(````5$P!``@```!=3`$`!@```&9,`0`6````;4P!
M`!<```"$3`$`!@```)Q,`0`.````HTP!``X```"R3`$`$````,%,`0`0````
MTDP!``@```#C3`$`"````.Q,`0`=````]4P!`!,````330$`%0```"=-`0`0
M````/4T!``\```!.30$`$P```%Y-`0`,````<DT!``0```!_30$`%0```(1-
M`0`J````FDT!``@```#%30$`#````,Y-`0`.````VTT!`!(```#J30$`!```
M`/U-`0`(`````DX!``0````+3@$`%P```!!.`0`*````*$X!``H````S3@$`
M&@```#Y.`0`D````64X!`!(```!^3@$`$@```)%.`0`6````I$X!``0```"[
M3@$`$````,!.`0`0````T4X!``@```#B3@$`#P```.M.`0`;````^TX!``@`
M```73P$`&0```"!/`0`9````.D\!`!D```!43P$`&0```&Y/`0`$````B$\!
M``0```"-3P$`%````))/`0`0````IT\!`"H```"X3P$`(P```.-/`0`I````
M!U`!`&L````Q4`$`*````)U0`0`H````QE`!`#$```#O4`$`,0```"%1`0`H
M````4U$!`"D```!\40$`'````*91`0`<````PU$!`#$```#@40$`*````!)2
M`0`N````.U(!`!0```!J4@$`"0```']2`0`,````B5(!`!````"64@$`#0``
M`*=2`0`-````M5(!``L```##4@$`%0```,]2`0`$````Y5(!``@```#J4@$`
M$@```/-2`0`8````!E,!`!`````?4P$`#@```#!3`0`8````/U,!`!,```!8
M4P$`$0```&Q3`0`4````?E,!``0```"34P$`!P```)A3`0`0````H%,!``\`
M``"Q4P$`#````,%3`0`0````SE,!``T```#?4P$`!````.U3`0`A````\E,!
M``@````45`$`"````!U4`0`$````)E0!`!(````K5`$`!````#Y4`0`$````
M0U0!``@```!(5`$`!````%%4`0`M````5E0!``0```"$5`$`$0```(E4`0`$
M````FU0!``T```"@5`$`#0```*Y4`0`>````O%0!`!@```#;5`$`$P```/14
M`0`(````"%4!`!D````150$`$````"M5`0`(````/%4!``,```!%50$`"@``
M`$E5`0`/````5%4!`!,```!D50$`!@```'A5`0`&````?U4!`!$```"&50$`
M$0```)A5`0`F````JE4!`!$```#150$`&@```.-5`0`2````_E4!``\````1
M5@$`!````"%6`0`,````)E8!`!(````S5@$`#P```$96`0`C````5E8!`!(`
M``!Z5@$`&@```(U6`0`Q````J%8!`!D```#:5@$`$P```/16`0`(````"%<!
M``H````15P$`&0```!Q7`0`(````-E<!``H````_5P$`"P```$I7`0`*````
M5E<!``L```!A5P$`"````&U7`0`6````=E<!``0```"-5P$`)0```))7`0`1
M````N%<!``@```#*5P$`"@```--7`0`(````WE<!``L```#G5P$`!````/-7
M`0`,````^%<!`!L````%6`$`+0```"%8`0`$````3U@!``T```!46`$`#```
M`&)8`0`,````;U@!`!$```!\6`$`#P```(Y8`0`-````GE@!``@```"L6`$`
M$@```+58`0`-````R%@!`!(```#66`$`&0```.E8`0`5`````UD!``(````9
M60$`%````!Q9`0`(````,5D!``X````Z60$`"@```$E9`0`0````5%D!``8`
M``!E60$`#@```&Q9`0`4````>UD!``@```"060$`!````)E9`0`&````GED!
M``(```"E60$`%P```*A9`0`*````P%D!``@```#+60$`$P```-19`0`$````
MZ%D!``8```#M60$`#@```/19`0`#`````UH!``@````'6@$`!````!!:`0`$
M````%5H!``@````:6@$`!````"-:`0`$````*%H!`!`````M6@$`!````#Y:
M`0`$````0UH!``0```!(6@$`!````$U:`0`$````4EH!`#0```!76@$`#0``
M`(Q:`0`'````FEH!``@```"B6@$`#````*M:`0`R````N%H!``D```#K6@$`
M"@```/5:`0`;`````%L!`"D````<6P$`&@```$9;`0`&````85L!`!\```!H
M6P$`%````(A;`0`-````G5L!``0```"K6P$`%P```+!;`0`$````R%L!``P`
M``#-6P$`!````-I;`0`7````WUL!`!@```#W6P$`%0```!!<`0`9````)EP!
M`!<```!`7`$`%P```%A<`0`2````<%P!`!0```"#7`$`%````)A<`0`0````
MK5P!`!8```"^7`$`(@```-5<`0`4````^%P!`!,````-70$`%0```"%=`0`2
M````-UT!`!0```!*70$`%@```%]=`0`=````=ET!`!4```"470$`%P```*I=
M`0`9````PET!`!(```#<70$`$@```.]=`0`=`````EX!`!4````@7@$`#```
M`#9>`0`7````0UX!`!(```!;7@$`%@```&Y>`0`,````A5X!`$L```"27@$`
M)P```-Y>`0`2````!E\!`!0````97P$`%````"Y?`0`8````0U\!``T```!<
M7P$`$@```&I?`0`3````?5\!`!$```"17P$`%0```*-?`0`9````N5\!`!0`
M``#37P$`3````.A?`0`6````-6`!``X```!,8`$`$@```%M@`0`4````;F`!
M`!D```"#8`$`*@```)U@`0`M````R&`!``8```#V8`$`!````/U@`0`$````
M`F$!``0````'80$`#`````QA`0`,````&6$!``P````F80$`#````#-A`0`*
M````0&$!`!(```!+80$`"P```%YA`0`(````:F$!``@```!S80$`"````'QA
M`0`,````A6$!``@```"280$`#````)MA`0`*````J&$!`!\```"S80$`!```
M`--A`0`$````V&$!`!$```#=80$`$0```.]A`0`7`````6(!`!H````98@$`
M&P```#1B`0`"````4&(!`%4```!38@$`!````*EB`0`,````KF(!``H```"[
M8@$`!````,9B`0`(````RV(!``@```#48@$`!````-UB`0`*````XF(!``8`
M``#M8@$`"@```/1B`0`(````_V(!``0````(8P$`"`````UC`0`.````%F,!
M`!4````E8P$`!````#MC`0`$````0&,!``H```!%8P$`"````%!C`0`(````
M66,!``@```!B8P$`#@```&MC`0`*````>F,!``@```"%8P$`$@```(YC`0`.
M````H6,!`"````"P8P$`!@```-%C`0`8````V&,!``X```#Q8P$`#`````!D
M`0`5````#60!``@````C9`$`#@```"QD`0`(````.V0!``0```!$9`$`'0``
M`$ED`0`7````9V0!``0```!_9`$`"````(1D`0`6````C60!``H```"D9`$`
M"````*]D`0`(````N&0!``0```#!9`$`$0```,9D`0`(````V&0!``X```#A
M9`$`#@```/!D`0`(````_V0!``@````(90$`$0```!%E`0`&````(V4!`!P`
M```J90$`*0```$=E`0`3````<64!`",```"%90$`$P```*EE`0`$````O64!
M``<```#"90$`'````,IE`0`*````YV4!``0```#R90$`"````/=E`0`$````
M`&8!`!(````%9@$`!````!AF`0`(````'68!``@````F9@$`"````"]F`0`(
M````.&8!``P```!!9@$`"````$YF`0`.````5V8!``P```!F9@$`!````'-F
M`0`,````>&8!`!8```"%9@$`!P```)QF`0`(````I&8!``P```"M9@$`%0``
M`+IF`0`,````T&8!`!,```#=9@$`"````/%F`0`)````^F8!``D````$9P$`
M#`````YG`0`J````&V<!`!,```!&9P$`"````%IG`0`*````8V<!`#P```!N
M9P$`$@```*MG`0`>````OF<!`!0```#=9P$`!````/)G`0`4````]V<!`!L`
M```,:`$`&P```"AH`0`6````1&@!`!<```!;:`$`%0```'-H`0`2````B6@!
M`!,```"<:`$`!````+!H`0`-````M6@!``H```##:`$`"0```,YH`0`*````
MV&@!``D```#C:`$`"````.UH`0`*````]F@!``D````!:0$`!P````MI`0`$
M````$VD!``0````8:0$`"@```!UI`0`(````*&D!``8````Q:0$`!@```#AI
M`0`(````/VD!``T```!(:0$`$````%9I`0`7````9VD!`!8```!_:0$`$```
M`)9I`0`0````IVD!`!L```"X:0$`$````-1I`0`,````Y6D!``0```#R:0$`
M+@```/=I`0`-````)FH!``D````T:@$`!````#YJ`0`$````0VH!``0```!(
M:@$`!````$UJ`0`&````4FH!``8```!9:@$`"````&!J`0`(````:6H!``L`
M``!R:@$`$P```'YJ`0`1````DFH!``@```"D:@$`"````*UJ`0`(````MFH!
M``@```"_:@$`%0```,AJ`0`&````WFH!``X```#E:@$`!@```/1J`0`$````
M^VH!``@`````:P$`"`````EK`0`$````$FL!``(````7:P$`#@```!IK`0`(
M````*6L!``0````R:P$`&P```#=K`0`.````4VL!`$X```!B:P$`"@```+%K
M`0`$````O&L!``0```#!:P$`"````,9K`0`$````SVL!``8```#4:P$`!```
M`-MK`0`(````X&L!``8```#I:P$`!````/!K`0`-````]6L!`!0````#;`$`
M&@```!AL`0`A````,VP!`!L```!5;`$`!@```'%L`0`"````>&P!``@```![
M;`$`!````(1L`0`$````B6P!``P```".;`$`!0```)ML`0`/````H6P!`!(`
M``"Q;`$`$````,1L`0`6````U6P!``X```#L;`$`#````/ML`0`4````"&T!
M``0````=;0$`!````")M`0`&````)VT!``L````N;0$`"P```#IM`0`$````
M1FT!``T```!+;0$`$P```%EM`0`4````;6T!`!(```"";0$`"````)5M`0`0
M````GFT!`"D```"O;0$`&P```-EM`0`;````]6T!``0````1;@$`%0```!9N
M`0`+````+&X!`!0````X;@$`"````$UN`0`(````5FX!``@```!?;@$`#P``
M`&AN`0`@````>&X!``\```"9;@$`#````*EN`0`1````MFX!``P```#(;@$`
M"0```-5N`0`"````WVX!``0```#B;@$`!````.=N`0`A````[&X!``8````.
M;P$`%P```!5O`0`$````+6\!``0````R;P$`#@```#=O`0`$````1F\!``0`
M``!+;P$`$0```%!O`0`"````8F\!``0```!E;P$`$0```&IO`0`"````?&\!
M``@```!_;P$`!@```(AO`0`(````CV\!`!,```"8;P$`$````*QO`0`%````
MO6\!`#````##;P$`'@```/1O`0`L````$W`!`"$```!`<`$`+@```&)P`0`F
M````D7`!`"$```"X<`$`,0```-IP`0`A````#'$!`!T````N<0$`'````$QQ
M`0`&````:7$!``@```!P<0$`!0```'EQ`0`6````?W$!`!4```"6<0$`#0``
M`*QQ`0`1````NG$!``0```#,<0$`!@```-%Q`0`(````V'$!`!````#A<0$`
M%0```/)Q`0`5````"'(!`!T````><@$`!P```#QR`0`0````1'(!`"````!5
M<@$`#@```'9R`0`.````A7(!``8```"4<@$`"````)MR`0`*````I'(!``\`
M``"O<@$`,````+]R`0!I````\'(!`#X```!:<P$`"0```)ES`0`(````HW,!
M``D```"L<P$`#````+9S`0`-````PW,!``@```#1<P$`!````-IS`0`-````
MWW,!``P```#M<P$`"0```/IS`0`.````!'0!`!,````3=`$`&@```"=T`0!&
M````0G0!``@```")=`$`#````))T`0`*````GW0!`!````"J=`$`!````+MT
M`0`$````P'0!``T```#%=`$`$````--T`0`(````Y'0!``@```#M=`$`#```
M`/9T`0`0`````W4!`!P````4=0$`'````#%U`0`8````3G4!`!@```!G=0$`
M&@```(!U`0`:````FW4!``X```"V=0$`&P```,5U`0`0````X74!`!````#R
M=0$`#@````-V`0`.````$G8!``@````A=@$`#@```"IV`0`.````.78!``P`
M``!(=@$`#````%5V`0`/````8G8!``T```!R=@$`$0```(!V`0`A````DG8!
M``D```"T=@$`!````+YV`0`&````PW8!`!L```#*=@$`$````.9V`0`/````
M]W8!``\````'=P$`#P```!=W`0`.````)W<!``X````V=P$`#0```$5W`0`+
M````4W<!`!````!?=P$`%@```'!W`0`3````AW<!``T```";=P$`$0```*EW
M`0`-````NW<!``\```#)=P$`$0```-EW`0`/````ZW<!``\```#[=P$`$0``
M``MX`0`$````'7@!``@````B>`$`(````"MX`0`-````3'@!`!````!:>`$`
M$@```&MX`0`(````?G@!``\```"'>`$`!@```)=X`0`$````GG@!``X```"C
M>`$`$````+)X`0`$````PW@!``P```#(>`$`$@```-5X`0`&````Z'@!``T`
M``#O>`$`!````/UX`0`$`````GD!``0````'>0$`!`````QY`0`(````$7D!
M``@````:>0$`"````"-Y`0`*````+'D!``H````W>0$`#````$)Y`0`2````
M3WD!``@```!B>0$`"````&MY`0`(````='D!``@```!]>0$`"````(9Y`0`(
M````CWD!`"@```"8>0$`!````,%Y`0`3````QGD!`"T```#:>0$`&0````AZ
M`0`-````(GH!``\````P>@$`"@```$!Z`0`*````2WH!``0```!6>@$`)P``
M`%MZ`0`&````@WH!`!(```"*>@$`!@```)UZ`0`)````I'H!``X```"N>@$`
M%````+UZ`0`6````TGH!`!$```#I>@$`!````/MZ`0`(`````'L!`!`````)
M>P$`!````!I[`0`(````'WL!``8````H>P$`$````"][`0`2````0'L!`!\`
M``!3>P$`&@```'-[`0`$````CGL!``0```"3>P$`"````)A[`0`(````H7L!
M``8```"J>P$`"````+%[`0`$````NGL!``8```"_>P$`!@```,9[`0`$````
MS7L!``D```#2>P$`(````-Q[`0`$````_7L!`!\````"?`$`"@```")\`0`,
M````+7P!``@````Z?`$`#P```$-\`0`-````4WP!`!$```!A?`$`#P```'-\
M`0`/````@WP!``T```"3?`$`$0```*%\`0`0````LWP!`!(```#$?`$`%@``
M`-=\`0`$````[GP!`!(```#S?`$`"0````9]`0`*````$'T!``H````;?0$`
M!````"9]`0`$````*WT!``0````P?0$`!````#5]`0`(````.GT!`"T```!#
M?0$`"0```'%]`0`$````>WT!``0```"`?0$``@```(5]`0`,````B'T!``P`
M``"5?0$`#````*)]`0`3````KWT!``(```##?0$`"````,9]`0`;````SWT!
M``,```#K?0$`#````.]]`0`Y````_'T!`!<````V?@$`!````$Y^`0`$````
M4WX!``@```!8?@$`#0```&%^`0`/````;WX!`!,```!_?@$`$P```)-^`0`+
M````IWX!``X```"S?@$`(````,)^`0`*````XWX!``T```#N?@$`!````/Q^
M`0`$`````7\!`!(````&?P$`)````!E_`0`=````/G\!`!<```!<?P$`"@``
M`'1_`0`7````?W\!`!0```"7?P$`#P```*Q_`0`7````O'\!`!@```#4?P$`
M%P```.U_`0`,````!8`!``P````2@`$`!````!^``0`2````)(`!``0````W
M@`$`!````#R``0`)````08`!``H```!+@`$`!````%:``0`N````6X`!``L`
M``"*@`$`"````):``0`3````GX`!`"L```"S@`$`$0```-^``0`$````\8`!
M`!(```#V@`$`&@````F!`0`$````)($!``\````I@0$`+@```#F!`0`$````
M:($!``D```!M@0$`&````'>!`0`7````D($!`!0```"H@0$`!````+V!`0`$
M````PH$!`!X```#'@0$`-0```.:!`0`0````'((!`!P````M@@$`$````$J"
M`0`&````6X(!``@```!B@@$`!````&N"`0`(````<((!``@```!Y@@$`!```
M`(*"`0`?````AX(!``\```"G@@$`#P```+>"`0`&````QX(!``0```#.@@$`
M"````-."`0`$````W((!`",```#A@@$`!@````6#`0`(````#(,!``@````5
M@P$`"````!Z#`0`$````)X,!``0````L@P$`!````#&#`0`$````-H,!``0`
M```[@P$`!````$"#`0`5````18,!`!````!;@P$`!````&R#`0`(````<8,!
M``P```!Z@P$`"````(>#`0`0````D(,!``X```"A@P$`"P```+"#`0`$````
MO(,!`!(```#!@P$`#````-2#`0`.````X8,!`!(```#P@P$`(P````.$`0`5
M````)X0!`!4````]A`$`%0```%.$`0`1````:80!`!$```![A`$`%P```(V$
M`0`3````I80!`!$```"YA`$`"````,N$`0`$````U(0!`!P```#9A`$`"```
M`/:$`0`)````_X0!``0````)A0$`%0````Z%`0`4````)(4!``8````YA0$`
M$0```$"%`0`-````4H4!``\```!@A0$`!````'"%`0`(````=84!``8```!^
MA0$`"@```(6%`0`&````D(4!`!0```"7A0$`#````*R%`0`2````N84!``0`
M``#,A0$`#0```-&%`0`"````WX4!`!D```#BA0$`&@```/R%`0`-````%X8!
M`!H````EA@$`(0```$"&`0`)````8H8!`!L```!LA@$`%P```(B&`0`<````
MH(8!`!L```"]A@$`(````-F&`0`+````^H8!``L````&AP$`"@```!*'`0`+
M````'8<!`!`````IAP$`$0```#J'`0`+````3(<!``L```!8AP$`"P```&2'
M`0`;````<(<!`!L```",AP$`'P```*B'`0`<````R(<!`!T```#EAP$`&@``
M``.(`0!(````'H@!`!,```!GB`$`#@```'N(`0`&````BH@!`!4```"1B`$`
M!@```*>(`0`(````KH@!`!,```"WB`$`%P```,N(`0`7````XX@!``8```#[
MB`$`*P````*)`0`M````+HD!``(```!<B0$`$0```%^)`0`6````<8D!`!D`
M``"(B0$`!@```**)`0`8````J8D!``T```#"B0$`!@```-")`0`&````UXD!
M``P```#>B0$`#0```.N)`0`&````^8D!``@`````B@$`!@````F*`0`2````
M$(H!``8````CB@$`!````"J*`0`&````+XH!``@````VB@$`!````#^*`0`9
M````1(H!``(```!>B@$`!````&&*`0`*````9HH!``8```!QB@$`!````'B*
M`0`&````?8H!`!<```"$B@$`!@```)R*`0`,````HXH!``L```"PB@$`(P``
M`+R*`0`3````X(H!`"8```#TB@$`#@```!N+`0`M````*HL!`!(```!8BP$`
M"````&N+`0`$````=(L!``8```!YBP$`"````("+`0`$````B8L!``@```".
MBP$`!````)>+`0`0````G(L!`!0```"MBP$`!````,*+`0`(````QXL!``H`
M``#0BP$`#0```-N+`0`0````Z8L!``P```#ZBP$`#`````>,`0`,````%(P!
M`!8````AC`$`"@```#B,`0`(````0XP!``@```!,C`$`"````%6,`0`(````
M7HP!``@```!GC`$`!@```'",`0`(````=XP!`!0```"`C`$`"@```)6,`0`$
M````H(P!`!,```"EC`$`#````+F,`0`P````QHP!``\```#WC`$`(0````>-
M`0`1````*8T!``0````[C0$`!````$"-`0`-````18T!``H```!3C0$`'0``
M`%Z-`0`(````?(T!``4```"%C0$`!@```(N-`0`-````DHT!``0```"@C0$`
M!````*6-`0`$````JHT!``H```"OC0$`!````+J-`0`&````OXT!``P```#&
MC0$`$P```-.-`0`$````YXT!`!,```#LC0$`"`````".`0`$````"8X!``@`
M```.C@$`!````!>.`0`+````'(X!``0````HC@$`%````"V.`0`$````0HX!
M``0```!'C@$`"````$R.`0`$````58X!`!````!:C@$`$P```&N.`0`;````
M?XX!`!4```";C@$`%0```+&.`0`8````QXX!`"8```#@C@$`%0````>/`0`1
M````'8\!`!H````OCP$`+@```$J/`0`3````>8\!``T```"-CP$`!````)N/
M`0`$````H(\!`!$```"ECP$`"````+>/`0`(````P(\!`"L```#)CP$`%@``
M`/6/`0`.````#)`!`"D````;D`$`+P```$60`0`$````=9`!``P```!ZD`$`
M!@```(>0`0`$````CI`!`!(```"3D`$`"@```*:0`0`(````L9`!``@```"Z
MD`$`!````,.0`0`(````R)`!``0```#1D`$`"````-:0`0`(````WY`!``P`
M``#HD`$`#````/60`0`:`````I$!`!8````=D0$`#````#21`0`$````09$!
M``@```!&D0$`%@```$^1`0`&````9I$!``(```!MD0$`!@```'"1`0`&````
M=Y$!``0```!^D0$`!@```(.1`0`&````BI$!``@```"1D0$`!````)J1`0`$
M````GY$!``@```"DD0$`)0```*V1`0`R````TY$!``@````&D@$`"`````^2
M`0`5````&)(!`!4````ND@$`"@```$22`0`*````3Y(!``0```!:D@$`!```
M`%^2`0`*````9)(!`"@```!OD@$`!````)B2`0`(````G9(!``@```"FD@$`
M"````*^2`0`&````N)(!`"<```"_D@$`!````.>2`0`4````[)(!``H````!
MDP$`#@````R3`0`7````&Y,!`!$````SDP$`&@```$63`0`7````8),!`!4`
M``!XDP$`"````(Z3`0`$````EY,!``@```"<DP$`#0```*63`0`0````LY,!
M``0```#$DP$`"````,F3`0`.````TI,!`!(```#ADP$`"````/23`0`.````
M_9,!``0````,E`$`!````!&4`0`(````%I0!``8````?E`$`"P```":4`0`$
M````,I0!`!(````WE`$`"P```$J4`0`0````5I0!`!````!GE`$`!@```'B4
M`0`&````?Y0!``(```"&E`$`!````(F4`0`,````CI0!``@```";E`$`!@``
M`*24`0`$````JY0!`!L```"PE`$`#P```,R4`0`/````W)0!`!8```#LE`$`
M#@````.5`0`$````$I4!``H````7E0$`"@```"*5`0`$````+94!``P````R
ME0$`!@```#^5`0`7````1I4!`"P```!>E0$`%@```(N5`0`9````HI4!`#,`
M``"\E0$`$@```/"5`0`2`````Y8!`!4````6E@$`*````"R6`0`*````598!
M`!L```!@E@$`!````'R6`0`)````@98!``<```"+E@$`"````).6`0`X````
MG)8!``\```#5E@$`%P```.66`0`(````_98!``0````&EP$`!`````N7`0`(
M````$)<!``@````9EP$`#````"*7`0`4````+Y<!`!(```!$EP$`#@```%>7
M`0`6````9I<!``@```!]EP$`$0```(:7`0`,````F)<!``8```"EEP$`0P``
M`*R7`0`-````\)<!`!$```#^EP$`%0```!"8`0`-````)I@!`!$````TF`$`
M%P```$:8`0`0````7I@!``T```!OF`$`#````'V8`0`(````BI@!`!(```"3
MF`$`"````*:8`0`$````KY@!`"P```"TF`$`!````.&8`0`;````YI@!``@`
M```"F0$`#P````N9`0`$````&YD!``@````@F0$`*````"F9`0`A````4ID!
M`",```!TF0$`.@```)B9`0`$````TYD!``P```#8F0$`'````.69`0`3````
M`IH!``0````6F@$`"````!N:`0`A````))H!``0```!&F@$`'P```$N:`0`@
M````:YH!``H```",F@$`%````)>:`0`5````K)H!`!8```#"F@$`%````-F:
M`0`2````[IH!`!0````!FP$`"````!:;`0`(````'YL!``@````HFP$`"```
M`#&;`0`*````.IL!``0```!%FP$`%P```$J;`0`$````8IL!``0```!GFP$`
M"````&R;`0`2````=9L!``0```"(FP$`"````(V;`0`3````EIL!`!4```"J
MFP$``@```,";`0`$````PYL!``0```#(FP$`"````,V;`0`(````UIL!``H`
M``#?FP$`'````.J;`0`2````!YP!``8````:G`$`#````"&<`0`(````+IP!
M`!,````WG`$`$0```$N<`0`L````79P!``8```"*G`$`!@```)&<`0`$````
MF)P!``H```"=G`$`#@```*B<`0`(````MYP!``P```#`G`$`"````,V<`0`(
M````UIP!``8```#?G`$`!````.:<`0`4````ZYP!``0`````G0$`"@````6=
M`0`(````$)T!``(````9G0$`!````!R=`0`(````(9T!``0````JG0$`!@``
M`"^=`0`&````-IT!`!@````]G0$`"@```%:=`0`&````89T!`!$```!HG0$`
M!````'J=`0`$````?YT!`#\```"$G0$`!````,2=`0`$````R9T!`!D```#.
MG0$`)0```.B=`0`/````#IX!`!@````>G@$`)0```#>>`0`5````79X!`!@`
M``!SG@$`#P```(R>`0`/````G)X!``P```"LG@$`!````+F>`0`$````OIX!
M``0```##G@$``@```,B>`0`$````RYX!``D```#0G@$`!@```-J>`0`$````
MX9X!``8```#FG@$`!````.V>`0`$````\IX!`!$```#WG@$`!`````F?`0`6
M````#I\!`!0````EGP$`#0```#J?`0`2````2)\!``X```!;GP$`#````&J?
M`0`4````=Y\!`!T```",GP$`!````*J?`0`(````KY\!``0```"XGP$`#```
M`+V?`0`0````RI\!``0```#;GP$`"````."?`0`(````Z9\!``0```#RGP$`
M!````/>?`0`5````_)\!`"<````2H`$`!0```#J@`0`(````0*`!``@```!)
MH`$`$@```%*@`0`$````9:`!``8```!JH`$`(0```'&@`0`0````DZ`!``@`
M``"DH`$`!````*V@`0`&````LJ`!``@```"YH`$`#````,*@`0`&````SZ`!
M``X```#6H`$`#P```.6@`0`8````]:`!`"$````.H0$`%````#"A`0`<````
M1:$!`!8```!BH0$`.P```'FA`0`&````M:$!`"8```"\H0$`'P```..A`0`H
M`````Z(!`#H````LH@$`#P```&>B`0`;````=Z(!`!T```"3H@$`'0```+&B
M`0`3````SZ(!`!$```#CH@$`&0```/6B`0`5````#Z,!``8````EHP$`,```
M`"RC`0!E````7:,!`!X```##HP$`#P```.*C`0`O````\J,!`#$````BI`$`
M+P```%2D`0`5````A*0!``@```":I`$`!@```*.D`0`9````JJ0!`!<```#$
MI`$`%P```-RD`0`6````]*0!`!,````+I0$`$P```!^E`0`=````,Z4!``@`
M``!1I0$`!@```%JE`0`?````8:4!`!,```"!I0$`&0```)6E`0`8````KZ4!
M``T```#(I0$`$0```-:E`0!"````Z*4!`"0````KI@$`)0```%"F`0`?````
M=J8!`!P```"6I@$`)````+.F`0`Y````V*8!`"\````2IP$`%P```$*G`0`;
M````6J<!`"(```!VIP$`.````)FG`0`Q````TJ<!`"L````$J`$`*0```#"H
M`0`E````6J@!`!X```"`J`$`'@```)^H`0`;````OJ@!`!$```#:J`$`&0``
M`.RH`0`;````!JD!`!L````BJ0$`)````#ZI`0`/````8ZD!`#T```!SJ0$`
M$P```+&I`0`(````Q:D!`&H```#.J0$`,P```#FJ`0`3````;:H!`"T```"!
MJ@$`%P```*^J`0`/````QZH!`"0```#7J@$``@```/RJ`0`(````_ZH!``0`
M```(JP$`"`````VK`0`(````%JL!``@````?JP$`"P```"BK`0`$````-*L!
M``\````YJP$`!@```$FK`0!+````4*L!``0```"<JP$`"P```*&K`0`+````
MK:L!``<```"YJP$`!````,&K`0`,````QJL!``0```#3JP$`$0```-BK`0`.
M````ZJL!``8```#YJP$`!@````"L`0`2````!ZP!``\````:K`$`%0```"JL
M`0`,````0*P!`!@```!-K`$`#P```&:L`0`.````=JP!``P```"%K`$`!```
M`)*L`0`%````EZP!``\```"=K`$`$````*VL`0`2````OJP!`!\```#1K`$`
M'@```/&L`0`?````$*T!``X````PK0$`%@```#^M`0`9````5JT!`!0```!P
MK0$`$@```(6M`0`2````F*T!`!<```"KK0$`$@```,.M`0`2````UJT!`!<`
M``#IK0$`&`````&N`0`1````&JX!`!T````LK@$`$0```$JN`0`:````7*X!
M`!$```!WK@$`$@```(FN`0`6````G*X!`!<```"SK@$`$@```,NN`0`7````
MWJX!`!4```#VK@$`$P````RO`0`0````(*\!`!$````QKP$`$@```$.O`0`7
M````5J\!`!(```!NKP$`$@```(&O`0`/````E*\!`"8```"DKP$`*0```,NO
M`0`.````]:\!`!8````$L`$`)P```!NP`0`8````0[`!`!8```!<L`$`'@``
M`'.P`0`?````DK`!`!@```"RL`$`$P```,NP`0`2````W[`!`!<```#RL`$`
M(@````JQ`0`6````+;$!`"````!$L0$`!````&6Q`0`(````:K$!``0```!S
ML0$`'@```'BQ`0`;````E[$!``8```"SL0$`#@```+JQ`0`G````R;$!`!4`
M``#QL0$`%`````>R`0`D````'+(!``0```!!L@$`!@```$:R`0`E````3;(!
M`"0```!SL@$`#P```)BR`0`7````J+(!`!(```#`L@$`!@```-.R`0"-````
MVK(!``@```!HLP$`#@```'&S`0`$````@+,!``<```"%LP$`"@```(VS`0`+
M````F+,!``\```"DLP$`!````+2S`0`C````N;,!``P```#=LP$`#````.JS
M`0`0````][,!``X````(M`$`"````!>T`0`U````(+0!``8```!6M`$`'P``
M`%VT`0`*````?;0!``H```"(M`$`"@```).T`0`=````GK0!`!````"\M`$`
M"@```,VT`0`7````V+0!``L```#PM`$`"````/RT`0`/````!;4!`!4````5
MM0$`$0```"NU`0`$````/;4!`!(```!"M0$`!@```%6U`0`8````7+4!``(`
M``!UM0$`"````'BU`0`2````@;4!``0```"4M0$`%````)FU`0`D````KK4!
M``0```#3M0$`"````-BU`0`(````X;4!``@```#JM0$`!0```/.U`0`&````
M^;4!``\`````M@$`#P```!"V`0`'````(+8!``P````HM@$`"@```#6V`0`F
M````0+8!`",```!GM@$`!@```(NV`0`(````DK8!`!T```";M@$`!````+FV
M`0`;````OK8!``T```#:M@$`$0```.BV`0`$````^K8!``8```#_M@$`"```
M``:W`0`,````#[<!`!`````<MP$`!````"VW`0`$````,K<!``0````WMP$`
M!````#RW`0`)````0;<!``@```!+MP$`$0```%2W`0`2````9K<!`!D```!Y
MMP$`(P```).W`0`/````M[<!``\```#'MP$`%@```->W`0`(````[K<!`"(`
M``#WMP$`!````!JX`0`3````'[@!`",````SN`$`"````%>X`0`(````8+@!
M``4```!IN`$`"````&^X`0`"````>+@!``8```![N`$`"````(*X`0`%````
MB[@!``8```"1N`$`!````)BX`0`(````G;@!``0```"FN`$`"@```*NX`0`*
M````MK@!`#@```#!N`$`,````/JX`0`3````*[D!`!,````_N0$`%0```%.Y
M`0`-````:;D!``(```!WN0$``@```'JY`0`,````?;D!``0```"*N0$`#```
M`(^Y`0`"````G+D!``L```"?N0$`/0```*NY`0`9````Z;D!``L````#N@$`
M(0````^Z`0`A````,;H!`"4```!3N@$`"P```'FZ`0!3````A;H!`!<```#9
MN@$`00```/&Z`0`H````,[L!`"$```!<NP$`'````'Z[`0`5````F[L!`!4`
M``"QNP$`%0```,>[`0`5````W;L!`!4```#SNP$`$P````F\`0`7````';P!
M`"(````UO`$`'@```%B\`0`0````=[P!`!<```"(O`$`"````*"\`0!3````
MJ;P!``@```#]O`$`5@````:]`0`M````7;T!`%$```"+O0$`&P```-V]`0`V
M````^;T!`!,````PO@$`&0```$2^`0`3````7KX!``D```!RO@$`#P```'R^
M`0`8````C+X!`!L```"EO@$`#P```,&^`0`2````T;X!`#H```#DO@$`#P``
M`!^_`0`/````+[\!`!4````_OP$`#````%6_`0`/````8K\!`!$```!ROP$`
M"@```(2_`0`*````C[\!``L```":OP$`$@```*:_`0`4````N;\!``8```#.
MOP$`"````-6_`0`*````WK\!``@```#IOP$`!@```/*_`0`&````^;\!``T`
M````P`$`!@````[``0`&````%<`!``T````<P`$`!@```"K``0`&````,<`!
M``\````XP`$`!@```$C``0`-````3\`!``@```!=P`$`!@```&;``0`&````
M;<`!`!````!TP`$`#````(7``0`$````DL`!``X```"7P`$`"````*;``0`2
M````K\`!``P```#"P`$`"@```,_``0`$````VL`!`!,```#?P`$`!````//`
M`0`#````^,`!``(```#\P`$`$@```/_``0`$````$L$!`!`````7P0$`#0``
M`"C!`0`,````-L$!``,```!#P0$``@```$?!`0`$````2L$!``D```!/P0$`
M"0```%G!`0`&````8\$!``8```!JP0$`"````''!`0`$````>L$!`!````!_
MP0$`!````)#!`0`,````E<$!``@```"BP0$`$P```*O!`0`"````O\$!``0`
M``#"P0$`"````,?!`0`&````T,$!``P```#7P0$`&@```.3!`0`$````_\$!
M``8````$P@$`"@````O"`0`%````%L(!``4````<P@$`$````"+"`0`!````
M304```````#P!@``@04``$T$```[!@``P@```)8"``"D!```R`4``#4$``"6
M`0```````#8`````````````````````````L`$``'T#```5!```8P(``)L`
M````````[0$``*\$``#-````N`8```````#@`0``;P0``/$`````````U0``
M````````````Y`$```````"C!0``7`$``&\&````````20<``%,&``#_`@``
M`````*0%```4`0```````.\!``!,````A@4```````````````<````$``#W
M!```=`$``",&``";!@``@@4```````"F!@``0@0``*X#```_`@``=0$```,%
M``#]!@``QP````````#E!```1P,``"<#``"4`0``/P4``"$'```^`@``N08`
M`((&``!V!```>`8``$P"```!`P``90```(,```#R`P``<P(``&H"````````
MV`8```8#``")!@````````L```#D!@```````'D%````````^P(``"$#``#G
M!@``"````*@#````````;P```%X%``````````````````!(!@```````*`"
M````````)P4``+8&```L!```3`,``!("````````\@0````````>!```KP4`
M`!L'``#5`0``+P(``%0%``#,`0```````&`"````````]`8``)P#``!J!@``
M```````````%!0````````````#H!0``)P8`````````````&```````````
M````M`,``.4%``"1`@````````````!1`0``J@$``*\&``!Z````$`0``-T$
M```<!```!P8``'L#``!$`@``B@0``#<$``!9!0``M0(``$4%``#)````````
M`/H$```"!P``C0$``&\#``#0!```-0$``&8````2!@```````+\%``"M!@``
M`````)4&``#/`0``^08``*P!``#<`P``2`<``),"``#\`@``V@0``-H#```6
M!0```````$`"``!O!0``-P4``&<&``"0````5@,``,@$``#X!0```````!($
M````````!0(```````"B`@``-`,``&P`````````@@,``/X!````````600`
M`(0#```$`````````&,&````````R@````````"3!```?`4``'P````!`@``
MV`4``#$`````````%0<``"$&````````R@0``````````````````$(`````
M````/`0``&P%``#_!@``D`4``#`%````````R0(``&$%`````@``GP8``#<#
M````````400``"T%``",`0``,`````````"%!0``0P8```X%``"1`P``Q@8`
M`,8%``!D`0``F@4`````````````L08```H$``!B!@``X@0````````F`0``
M``````````#]````_@4``)H#``#G````:P```*$`````````:P8``!4&``"$
M`0``(@````````#P`P``[`0``&T#``!0`P````````````"4!@``````````
M``#"!@``Q08``#4#``"D!@``#P4``!@!```N!P````````(!``#H!```````
M`$P!``"2`P``:P0```X$`````````````(T$```9````-`$``.L#``"7`P``
M"0,``+0!``!(!```!P0``%<"```&`@``>`4``.0"``!)````M`4``&4&````
M``````````,```"-`@````````````!$`P``)0,``"\%`````````````#$'
M``"/!````P<``-<```!T!```508```````#$!```10```/4&``!J````"@,`
M`%(#``#`!@``T0```#0%````````80,``.H"``#N````7P```%<&````````
M1P(``#\'```P`@`````````````D`P``C`4``'`````7!0```````-@$```0
M`0``-@8``$L#```2!0``@0,``%P`````````^0$``!,&```?!@``````````
M`````````````'X#``#(`@``/@,```````"#`@``W`$``,0!```>`P``O0``
M`%8```"/`@``I@(``!,#``"7!@```````$H'``#9!0```````$(#````````
MMP4``'@!````````S@(``$8#``"4````/P```"\&``":`0``T00``#P%````
M`````````-X#```&!@``>````(4#```V!```[0,`````````````$P```+\#
M````````'0(``````````````````!4!``"$!@``"P0```````!]!```TP4`
M``````#R!0``*0<``&P&``!!!```^P,``-\#``#J!```004``*D"```-!P``
MXP$````````J!0``QP,``!D#``"]!0``WP8``+D%````````,@(``.("```U
M!P``_`8```````#\`0``'`(```````!Z`0```````'H#```>`@```````&(%
M``!I!@```````*L%````````S04`````````````R0,```T%````````G`(`
M``````",`P``=@,``.(!``"F`0```````-,!````````A0(```````"M!0``
M"04`````````````_@````````!Q`0``#P```.4&````````^@,``+@$````
M````O08`````````````KP,``(X&``#F!```GP0``(<"````````(`<`````
M```"!0``@@0`````````````D`$``-0&``#A!@``D@8`````````````&@,`
M`-($``#@````!0```"`!``!)!@``.0,``/(&``"S!@```````"(!``!F!0``
M,`<``($&```4!P```````/<%```V!0``3`4``'\"``"5`0``1P0```D````=
M`````````'<````>!@```````/T!``"C`@```````$T!```4`P```````$X!
M```````````````````@`P```````'$$``#R`@``%`4``",!````````=08`
M`"H"````````XP0`````````````Y`4``!`#``"9!0```````'$%````````
MZ0$```````"=`0````````<#``!2!@``"00``(L"````````N`(`````````
M````4@````@"``!E`@```````!D&```N`@``7P8````````P`0``@P8``#$%
M````````BP0``````````````````+0```"-!0``$0$``)P%``"=`P``KP$`
M`'X!```D!@``/@```',%``""`@``50,```````!F`P``7`8``(H&``!1````
MH`0``*$!````````=@```+4$````````'0<````````L`0```````*<#````
M`````````+$%``!#`0```````!\```#%`0``%`0``-8$```0````````````
M```5!0``0@8```````"&`@``]@````````#F````\P````````!`!```(`(`
M``````#"!0``BP8``-\$````````S`,``.8&``"K`P``(0(```````!F`@``
M`````,T&``!%!```W@0``&4$``![`0```P$``(D!``#S`0````````````"V
M!0```````$P$``"Y````_@0``%X&````````/0<`````````````&@$``#<`
M````````N````#`$``"T`@```````.\#`````````````*T"````````````
M`'D`````````QP8``,D&```U!@``O`$```````#Z!@``+`,``.H%``#(`P``
M]`0``)`$``!U!````````!\#``#&`@``Q0,``(X```#7!```+00`````````
M````SP```/@&```H!0``/0(``#0$````````,P```/`!``#B`````````(D$
M````````T`4``*($``"0`P``H08``+L$```H!P``3@,``'<&````````M@(`
M`&`#``#T``````````````#$`@``S@,```0'``"1!```'`8``"P"``!@!0``
M'`4``,````!+!```'@```)@```"K`````````+4&``````````````````"*
M`0```````,L!````````"@```+X!````````^0,``*H"``#3!@```````%D`
M``#+````X@8```````#G`0```````%X!``#9````2@$``+`$``"I!@``````
M`"8#``````````````````"#`P```````(`%``##``````````````"@!0``
M7P,``(@$````````/`8``/8!``#U`0```````$X$``!*````B04``.<%```0
M!0```````%`%````````_`4``#X%``#,`````````$$"````````AP```%@%
M``!A````7P$``&H%````````_0,``"D!``![````4@0`````````````````
M`/L$```L!@```````*\```!Z!```T0,```````#N`0``.`8``!8&``#S!@``
MSP4``,($``#W`0``]P8```````#L`P``/`````````#H`0``%P8``(`"````
M````5`$``'`&````````6@0``-T"``"P`P``J`8``!`"``"U`P``U@```"D`
M``!I`0``B`,```````"F`P``````````````````L00``*X&````````&@0`
M``T```!;`P``2@0``,P$``!7`P``A00``.\$``"3`0``6`(``)P!```C`P``
M`````/`"``!8`0```````,<$```X!0``P`,``)$&```F!@``U@4``)\%````
M````*@8``&0%``!!`````````!P#````````H`$```<'```D!0``````````
M````````V0(``&,%``#E`@``+P,``/,#``#B`P``0P```*P&``!Q`@``7P(`
M`&4#````````T0$``#(!`````````````,,$``#(`0```````%,%````````
MW````"(#```H`````````-0"````````^@$```D'``!W`0``:```````````
M``````````````"W`@```````$`&``"K!```NP8``#($```#!`````4``*X`
M``````````````,"``"-`P```````.L"````````!08``&,!```H`0``````
M`%<$`````````````&@!````````3@````@#``!5!0```````"@&```,!```
ML`4```````!F!````````#,#``#9!@```````$X"````````.P0``'0"``"7
M````<P```%D!``#@!0``0@(``%$#``!%`P``0````-T`````````;@$``'P$
M```+`P``$00``,P"``"!!```'P$``%,!``"5!0````````````"I````,0,`
M`'\$``!N!````````*L!``".`P``*P```#L#``!/`P``EP$``$4"````````
M'P4```````#;`@``````````````````30(``,H&``#!`0``G@,``'\```">
M````IP8``%(%````````X`,``%H```!"`0``,@4``,H!``"9````^@4``+@!
M``"/````80$```P"``"E`P``&0<```````#S`@``$@<``.D%``!@````````
M`"$```!F`0```````!8#````````````````````````&P,``'($``!X`@``
MK00```````!-!@``!@4``#T%````````:P,``.4```#:!@``&0$``+,"``#_
M`P``G`0``+@%````````!`,``&($```E!@```````'T!```F!```)@4``#`#
M```C!P``P04```@'```````````````````8!0``*`(``"H'``!(!0``````
M`/$&``!9`P``50$``*,!```;!0``BP$``*4%`````````````+<`````````
M``````L%````````<08``+@#``"R!0```````-(!``"_`0```````(P&``#7
M!0```````!0```"#!```2@(``"(&``!4!@``+0$``#H&``#A!0``8`8``-@!
M```,!0``E@4``/``````````DP4```````!N`P``F0$``)`"``".!```````
M```````$`@```````!\'````````EP(```````!&!```^0```'4%````````
M#P$``+L```!J`0``O`4``.<#``!!`P``O`8```````!B````^P```.$"``!G
M!0``(P0``%$"```;`@`````````````7!P```08``%H"``!<`@```````)0"
M````````6P4``!,"```J````N@0``&0"```Y!```?0````\$``"G`@``,0$`
M`!,!`````````````*T````.`P```````'\&````````/P8``"`%```]`P``
M0`4``"D$``"H!```J`$``$\!``#/!@```````%,```"/`0``````````````
M````HP0``*H$`````````````$(%```'`0``2`(````````<````GP(``,X%
M```9`@``<@$`````````````+P```%8!```8!```*0,``%X"```M`@``D`8`
M`-P"``#.!@`````````````/`P```````*(&``!=!@``5`(``"H#````````
M=@4``&0```#6`@```````-L````.!@```````&P!``!J!```O00``-0!````
M````J0$``'D$```X`P``6`0``'H&``#\!```Z0```-8&``!&`@``Z````+D$
M````````]`(```$'```6!P```````"T`````````)`$``'(````D````E@``
M`$D!````````G04``(@"``!/````B`8``+,#``#X````N@$``.\````S!0``
M%0(``.,%````````:`,``(<#``#0`@``P`4``&P"```(!```$P4``!T&``#Q
M`@``W0,``-,"``!;`0``*`,``#@!``!>````2P8``%L&````````D@``````
M``#&````500``.H#``"H`@``)`(```````#R`0``3@8````````8!@``*P0`
M`````````````````*D#``"C````]@4````````=!```/08```H&``#^`P``
M`04``+4```#F!0``R`8``$,%``!C!```A`4``.L!``#N`P``V@```(H#```P
M!@``!`8```````!'!P````````P'``#Q!```OP8```H%``#:!0``-P<``(8`
M````````9`8```````!5````WP$```0$`````````````.4#```\!P``````
M`-T&````````;`0``+H"``!\!@````````````#G`@``````````````````
M204``,0%``"?`0```````'L%```K!0``0P(``/4"``!!!@``6@,`````````
M````U00``#@"```O!```D@0```````!Z`@``[P(``.D#```;`0``P@(``+``
M````````&P0```````#L!@```````#@'``#U!```F`8```P```";!```````
M`*H#``#/`@``W@```-(&```7!```5P4``"$$````````%P,```````!P!```
M`````),```"2`@```````-D#````````$@,``+,%```Q!@``70(``"\'``!P
M`@``IP$``*<%```/!@````````````#8`@``K`,``/\````;!@``YP0``/\$
M``"]`0```````(`!``!9!@``:P$``(X%``#Z`@``6P```%0#``#W`P``1```
M`+D!```[`@``I`,``'`!````````904``!D$``#H`P```````/0%``#!!```
M)P0``/L!``"O`@``\P4``(X"``"=````8@(``*$"``#L`0``&`<``!X'``!R
M!0``[00``#X&````````>08``%T```"[`0``3`8``.\&```3!P```````.8!
M````````;04``#$$``!C`P```@8````````T!P``*P,`````````````K@(`
M````````````O@(``-$&``!+`0``BP````````!$!````````$D#``"9`P``
MH@```#<&``#2`P``O0,``*(#```'````VP$````````R!@``)04````````&
M`````````-("``"Y`P``VP,``!4```"H!0``(P(```T!````````1P4`````
M``!H!```C`0``(`$``````````````L'``!&````.@<``"T&``!0!@``````
M`#L%``#0!@``[P4``.L```"[`@``/@0``&@%``!%`0``6P0``$8&``"T!@``
M=0,```````"H````R@(``%T%````````%P```.H!``!6!```:04``-H"``",
M`@``8P``````````````#`8``+T"````````U0(``/@$````````[`4``#4`
M``!M`0```````',#``#.`0``(@0``'`#```Z`````````+X`````````<P$`
M`-0```!!`0```````!H"``!G!```H@4```(```!*!@```````)(!``#K!```
M`````*````"E````"P8````````_`0``=P,``%\%``#!`@```````%H&``#*
M!0``B`4``#P"```=!0``AP0``%<`````````FP$``,D$``#>`@```````&H#
M`````````````'$#``"9!@``80(``&T"```@````[@4````````S!P``````
M`*T#``#E`0``.0<``#8#```(!0``Q````%("``"V`P``\0$``,T$````````
M4`$``#8'````````)`0``-D!``#!`P``Y`,``"$!``!0!```DP,``-4&``!8
M!@``Z08``,T#```D!P``````````````````1`<``'$`````````,0(``-(%
M```^`0``F@0``#H%```%!P```````-8#``"Z!@``1`4``"X&``#,!0``FP4`
M``````"@`P``=P4```````!9`@``;00`````````````,P$```````#!````
M`````&<#``""````50(``*X$``"#!0``HP,``)P````I!0``Z0(``*4"``"D
M`@``30<``"L!``#`!```H04`````````````G0(```\'``!#!P``2````'(#
M``#(````9P$``/@#``"F!```*08```````#Q`P```````)<$````````!P4`
M`)@%````````W@8```````!%!@``#@$```````">!0``0`$`````````````
MFP,``!$"```U!0``B0````8!```N`P```@(``$<```"4!```)P$```````##
M`P``L`8```````#J!@``V````+$!```J`0```````#(```!D!```J04``!`'
M``#*`P``7@,``````````````````*(!````````+0,``#@$``"1````````
M``````#'`0``L@,``*T!``#M!0```````%`"``!)`@``K@4``.`&``"&`0``
M5@(`````````````(P4``*,&``"D`0``2@4``-L$``"@!@``5`0``(8#``"'
M!0``GP,``,\$`````````````#<"``#J`````````)X"``#)!0```````%H!
M`````````````,L&``"E!@`````````````_`P``(@4``)H```"%!@``?P$`
M````````````````````````````1P$```````!\`0``F`(````````@!```
MY``````````6!```&`(``!8````4`@``%P(``(4!``#3!```_`,``/X&````
M`````````.P"``````````````````!N````$@$```````#4`P``FP(````#
M````````WP4``/`%`````````````($`````````/`$``$L```"W!```A@0`
M`+X%``"U`0``7`4``&\"```<`0``V00````````&!P``\04``&L"``"V`0``
M`````-$"```)!@``/@<```````"/!0```````$@!``"R`@``C0````````#D
M!````````.@"``!D`P``^`(```````"K`@``B@(```````#P!```>P8`````
M``"^`P````````$$``"=!```I0$``(<!``#5!0``]@(``&(#``!0````I@``
M`/8#``#+`@``PP(``+<#``#T`0``W`4``,L#``!M!@```````!X%```K!P``
M+@0`````````````1`8``````````````````%\$``#$!@``X`(```````#L
M`````````"<```!&!P```````.$````L!P``(`8``$('``!/!0``?P4``,4$
M``"5`P```````$4'``!,!P``K`4``/X"``"A`P``Y@,``'X"``#Y!```UP$`
M`%0```"P`@````````````#%!0``,P8``*0```"^!@``J@8``'0````-!@``
M>0(```L"``!H`@``PP8``%$&``#\````C@$``%,"``"7!0``&@4``)\````C
M````-`(``'H%```]`0``A`0``#@```#>`0```````&\!```N`````````/L&
M``!=`P````````P#``"[!0``:0```%T!`````````````"4$``"A!```UP(`
M`+L#``#]!```L0(```T#``#]`@``[@(``-X%````````#00```````"9`@``
M``````@!``!<!````````'D#``",```````````````*!P````````````!\
M`@``AP8``&D$``!N!0``P@$`````````````]P(``&X"``!R`@``G`8``-P$
M``!`!P````````H"``!&`0````````````"/`P``````````````````+```
M`#4"``#K!@``J00``#<!``#A!```:0(``%,#``"8!````````.,```#!!@``
M(@(``%$%```1!0``Z`8``!$'``"V````F`,```````!!!P``M`0```````"*
M````BP4``,X$``"F!0```````&$&```1````Q`,``/D"``"$`@``)@```+(`
M`````````````%P#```V`0``PP4```````#U`P````````````#A`P``F@8`
M`$,$````````=`,``'0&```V`@```````(`#``!;`@```````!4#````````
MT``````````0!@``IP```"<"```#!@``N@4```$!``#1!0``G@8```D"``#;
M!@``,P0`````````!@``LP$``',&``!A!````````"X%````````.@,``$,#
M``!G`@``3P0```X"``#C`@``[@0``,\#```E`@``.P$`````````````T@``
M``````#=`0``?@8``-P&``"Q````'P(``*L&``#%`@``Z00``.(%```7`0``
MIP0``!(```#U````7@0`````````````N@````````![!````````&X&``"_
M````]04```4!``!*`P``K``````````]````)@<``,<%``#&!```B````',$
M```O`0``U`4```````"=!@````````````#C`P```@,``!$#````````N@,`
M`"<'``"V!````````+\$```H!```B`$``'<"````````2P<``$`#``"&!@``
M700```X'``#M````-`````,#``":`@``Q@$``'\#````````2P4``-H!``!]
M`@``^@```````````````````"8"``!T!0``@0(``/8$```<!P``\@```!\$
M``!X`P``I00````````\`P``B0,``($!````````K`(``.X&``"U!0``.@$`
M`*X!````````_P$```````!@!```````````````````(@<``+($```_!```
MA0```$D$``"5!```D04``/T%``"`!@``RP0``+<&``"R`0``90$``$X%````
M````#0(``(T&``#4!```5@4``!0&``!]!@``J@4``)X$```[!P``.@0``)@!
M``!K!0``!0,``(,!``!B`0``.0(``+<!```1!@``=@8`````````````````
M``\"``"$````UP8```````````````````X```!'!@``B@4``$0!````````
M^`$``.T"```E!P``QP(```L!```Y`0``BP,``/D%``"6`P``:0,``)$!````
M````E`,``)D$````````CP8```````!X!````@0``"H$````````>0$``.$!
M````````?04``,T"``![`@```````#L```#F`@``.0`````````,`0``$P0`
M`(D"`````````````&T`````````&`,``+D"``#``0``````````````````
MO`(``+$#``#S!````````#T$```=`0````````0!``#6`0```````,T!``#0
M`P```````#0&``"2!0``O`0``,(#``!^`````````-<#``!2`0``"0$```8$
M``!7`0``9P```*P$````````=0(``'8!``!P!0``^P4``"P%``#%````+0<`
M`$L"``"`````````````````````U0,``%,$``#0`0``3P8``!H&```$!0``
MO`,``.T&```E`0``````````````````*0(``%8&```R!P``'0,``,8#```%
M!```P`(```<"```A!0``6`,``.L%``#?`@``'@$``/<`````````O@0``.`$
M``!(`P``,@,``$\"`````````````'X$````````8`$```````#8`P``,P(`
M````````````E@8```````#,!@```````)8$````````E`4```````"3!@``
M`````-\```!H!@``?@4``$T````9!0```````.,&``"\````&@```&P#``#)
M`0```````'8"```E````=0`````````N`0``W04```H!````````&P```"L"
M``">`0``6````!H'``!-`P``TP```#H"````````1@4````!````````?`,`
M`/8&````````.04``)4`````````L@8``/\%````````PP$``,L%``"S!```
M``````````"5`@``%@$````````6`@``9@8```````!:!0``J@````@&``#.
M`````````#D&````````TP,``'(&`````````````"L&``"S````@@$``'<$
M``#;!0```````/0#``"_`@```"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y
M("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S
M=&5R9&%Y*0`@870@`"(E<R(@:7,@;F]T(&$@9&ER96-T;W)Y+@`B)7,B(&ES
M(&YO="!A('9A;&ED(&-H;VEC92X`(B5S(B!I<R!N;W0@8V]N9FEG=7)E9"!I
M;B!T:&4@2&]R9&4@4F5G:7-T<GDN`"(E<R(@=')E92!R96YD97)E<B!N;W0@
M9F]U;F0N`"(E<R(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+@`B
M)7,B('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+@`B)7,B
M('=A<R!N;W0@8W)E871E9#H@)7,N`"4N,F9-0B!U<V5D(&]F("4N,F9-0B!A
M;&QO=V5D("@E+C)F)24I`"5D("5S(&%N9"`E<P`E9"!D87ES('5N=&EL('EO
M=7(@<&%S<W=O<F0@97AP:7)E<RX`)60M9&%Y(&9O<F5C87-T`"5S("T@3F]T
M:6-E`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A
M=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T=7``)7,@4VEG;B!5<``E<R!4
M97)M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D>2!E>&ES=',N`"5S(&%T("5S
M("5S`"5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P
M97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE(&)O>"!F;W(@86YY
M(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM
M92X`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S
M('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L96YD87(`
M)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"5S.B!4:&ES(&UE
M<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"
M97=A<F4@;V8@9F]L;&]W:6YG(&%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V
M:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO
M;BX`+"!G=7-T:6YG(``L(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M
M("5S('1O("5S`"TM('-E;&5C="`M+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R
M($9O<FUA=``R-"!H;W5R<P`\4')E=FEO=7,`02!D871A8F%S92!B86-K96YD
M(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA
M<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N
M8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D
M('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y
M+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I
M=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@
M4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E
M8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E
M(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S
M:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D
M('1O(&5N8W)Y<'0@82!M97-S86=E+@!!32!#;&]U9',`04T@3&EG:'0@4F%I
M;@!!32!286EN`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W97)S`$%-+U!-`$%0
M22!)1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B;W1T;VT`06)S
M;6ED9&QE`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2X`
M06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`06-C;W5N="!);F9O
M<FUA=&EO;@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!8V-O
M=6YT:6YG`$%D9`!!9&0@0VAI;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I
M;VX`061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S:6]N
M`$%D9"!A(&-H:6QD(&=R;W5P('1O("(E<R(`061D(&$@8VAI;&0@<&5R;6ES
M<VEO;B!T;R`B)7,B`$%D9"!A(&YE=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N
M97<@;65M8F5R<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII
M;&QA(%-I9&5B87(`061D('1O(&%D9')E<W,@8F]O:SH`061D('1O(&UY(&%D
M9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TL
M(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T
M:6]N.B`E<RX`061D960@(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO
M9R!I;B!N;W<N`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!
M9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@
M;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S`$%F9VAA;FES=&%N`$%L
M8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&EG;FUE;G0Z`$%L;`!!;&P@
M075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N
M<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT:7!L92!A9&1R97-S97,`06QL
M;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR96%D>2!E>&ES
M=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O
M<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N871E(&5M86EL(&%D
M9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`06UE
M<FEC86X@4V%M;V$`06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!
M;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+@!!;F1O<G)A`$%N9V]L80!!
M;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`06YS=V5R`$%N=&%R8W1I8V$`06YT
M:6=U82!A;F0@0F%R8G5D80!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!,:7-T
M`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L>2!T;R!#:&EL9"!3:&%R97,`
M07!P<F]V90!!<'!R;WAI;6%T92!3:7IE`$%P<FEL`$%R86)I8R`H5VEN9&]W
M<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO
M=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@
M9F]R("5S(#\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92`B)7,B
M(&%N9"!A;GD@<W5B+6=R;W5P<S\`07)G96YT:6YA`$%R;65N:6$`07)M96YI
M86X@*$%235-#24DM."D`07)T`$%R=6)A`$%S8V5N<VEO;B!)<VQA;F0`07-C
M:6D@07)T`$%S:6$O4&%C:69I8R!296=I;VX`07-K(&9O<B!C;VYF:7)M871I
M;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%S<VEG
M;FUE;G0@8V]L=6UN<P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N
M="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R
M;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI
M<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92X`
M071T<FEB=71E<P!!=6=U<W0`075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S
M<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]C
M>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI
M=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F
M;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C
M:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D
M(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E
M<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H
M7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T
M:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@
M=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!
M=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R
M($%C=&EV92!$:7)E8W1O<GDN`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M
M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@870@
M24U!4"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO;B!F86EL960`075T
M:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E
M9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R
M=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@
M9F%I;&5D+@!!=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I:F%N`$)A8VMG<F]U
M;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A
M9"!K97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"86AR86EN`$)A;'1I8R`H
M25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`0F%S92!G<F%P:&EC
M<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`$)A<V5L:6YE`$)E;&%R=7,`
M0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R;75D80!":'5T86X`0FER=&AD87D`
M0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO
M8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";VQD`$)O;&EV:6$`0F]O:VUA<FMS
M`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!";W)D97)S`$)O<VYI82!A;F0@
M2&5R>F5G;W9I;F$`0F]T:`!";W1S=V%N80!";W1T;VT`0F]U=F5T($ES;&%N
M9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE
M:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&
M87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#
M7V5L;"!0<F]P97)T:65S+BXN`$-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T
M960N`$-A;&5N9&%R`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`0V%N(&YO="!R
M97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M
M:6YI<W1R871O<BX`0V%N(&YO="!W<FET92!T;R!F:6QE("(E<R(`0V%N)W0@
M8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`0V%N)W0@;W!E;B!F:6QE("(E
M<R(N`$-A;F%D80!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;FYO
M="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D
M:7)E8W1O<GDN`$-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G
M('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%N
M;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N`$-A;FYO="!R96]R9&5R
M+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S
M(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#86YN;W0@<F]U=&4@;65S<V%G
M92!T;R!S<&5C:69I960@;G5M8F5R+@!#87!E(%9E<F1E`$-A<'1I;VX`0V%T
M96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`
M0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S
M`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I
M`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O
M<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I
M8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H86YG90!#
M:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E
M<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T
M;R!Y;W5R(&5M86EL<RX`0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@
M<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@($-O
M;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#:&%R`$-H96-?:R!,:6YK+BXN
M`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN
M97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@07!P;&EC871I;VXZ`$-H
M;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!H;W<@
M=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R
M(&]R9&5R960@;&ES=',I`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI
M=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%R`$-L96%R($U33V9F:6-E('1A
M9W,`0VQE87(@475E<GD`0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S97(`
M0VQE87(@=7-E<B!D871A`$-L96%R:6YG($QA=&4`0VQI8VL@=&\@0V]N=&EN
M=64`0VQI8VMA=&5L;"!V:6$@2%144`!#;&]S92!7:6YD;W<`0VQO=61S`$-L
M;W5D<R!%87)L>0!#;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`0V]L
M;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO;6)I80!#;VQO
M<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#;VQU;6X@
M=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#
M;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M<'5T97)S`$-O;F1I=&EO
M;@!#;VYD:71I;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R96YC97,`0V]N9FEG
M=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N
M9"!/=71L;V]K+@!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+@!#;VYF
M:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E
M;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#
M;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T
M;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C=',`0V]N=&%C=',@=V5R92!S
M=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O;G1E
M;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z(`!#;VYT96YT<R!O9B`B)7,B
M`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#;W!Y`$-O<'D@9F%I;&5D.B`E<P!#
M;W!Y('-E;&5C=&EO;@!#;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@
M;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4$=0('-I9VX@
M;65S<V%G93H@`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#
M;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C
M;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U
M;&0@;F]T(&)I;F0@=&\@;&1A<"!S97)V97(`0V]U;&0@;F]T(&-H96-K(&)A
M;&%N8V4N("5S`$-O=6QD(&YO="!C;VYN96-T('1O(&QD87`@<V5R=F5R`$-O
M=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B`B)7,B('5S:6YG($944#H@)7,`
M0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@
M;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z(`!#;W5L9"!N;W0@9&5C<GEP="!3+TU)
M344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N
M;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5L
M971E('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$-O=6QD(&YO="!D971E
M<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N
M;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N;W0@9F5T
M8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO="!F971C
M:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N`$-O
M=6QD(&YO="!L;V%D('-T<F%T96=Y("(E<R(N`$-O=6QD(&YO="!M:V1I<B`B
M)7,B+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y
M<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`B)7,B(&9O<B!W<FET:6YG+@!#;W5L
M9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S
M:R!M;V1U;&4@)7,`0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y("(E<R(N`$-O
M=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!R96%D
M("5S+@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q
M=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS(&%R92!N
M;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES
M=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T(')E
M=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E
M<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O
M=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S`$-O=6QD
M(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,`0V]U;&0@;F]T
M(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<FUD:7(@(B5S(BX`
M0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A
M=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A
M8VMU<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD(&YO="!S879E('-E='5P('5P
M9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!#;W5L9"!N;W0@<V%V92!T:&4@8F%C
M:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE
M(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N
M92!O9B!T:&4@;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@
M;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@
M;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U;FQI;FL@
M(B5S(BX`0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@
M=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@=W)I=&4@
M8V]N9FEG=7)A=&EO;B!F;W(@(B5S(CH@)7,`0V]U;&1N)W0@9FEN9"!T:&4@
M36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E
M;BX`0V]U;&1N)W0@9VEV92!U<V5R("(E<R(@=&AE(&9O;&QO=VEN9R!R:6=H
M=',@9F]R('1H92!F;VQD97(@(B5S(CH@)7,`0V]U;G1E9"!T97AT`$-O=6YT
M<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@
M;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R
M961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N="!397-S:6]N
M<P!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!5<V5R<P!#
M=7)R96YT(%=E871H97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T
M>6QE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`
M0W5T`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Y<FEL;&EC("A+3TDX+5(I`$-Y
M<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])
M."U5*0!#>F5C:"!297!U8FQI8P!$1`!$4TX@*'-E92!H='1P.B\O<&5A<BYP
M:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S
M;BYP:'`I`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T86)A<V4@3&]O:W5P
M`$1A=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5?;&5T
M92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E($EN
M9&5N=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$
M969A=6QT(%-H96QL`$1E9FEN:71I;VYS`$1E;&5T90!$96QE=&4@0V5L;`!$
M96QE=&4@1W)O=7``1&5L971E($QO9P!$96QE=&4@4&5R;6ES<VEO;@!$96QE
M=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C;VQU
M;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@
M<&5R;6ES<VEO;G,@9F]R("(E<R(`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B
M)7,B(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@<F]W`$1E;&5T
M92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN
M`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L971E9"!S971U<"!U<&=R861E
M('-C<FEP="`B)7,B+@!$96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5S8W)I8F4@
M=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(;W)D
M92=S(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H
M92!A9&UI;FES=')A=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O
M:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F
M="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`
M1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA
M>2!D971A:6QE9"!F;W)E8V%S=`!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I
M<W!L87D@9F]R;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T
M:0!$;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E
M;F%N8V4N<&AP`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L
M9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M
M:6YI8V%N(%)E<'5B;&EC`$1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U
M<"X`1&]W;FQO860`1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O
M;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U
M9W,`12U-86EL`$524@!%8W5A9&]R`$5D:70`161I="!";&]C:P!%9&ET($=R
M;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R
M;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES
M<VEO;G,@9F]R("(E<R(`161I="!P97)M:7-S:6]N<R!F;W(@)7,`161U8V%T
M:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`16UA:6P`16UA:6P@
M061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UA:6P@=VET
M:"!C;VYF:7)M871I;VX`16UA:6PM=&\M4TU3($=A=&5W87D`16UO=&EC;VYS
M`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H('1E
M<FUS`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L
M;&5R:65S(&EN('1E>'0_`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE
M;G4_`$5N9"!Y96%R`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I='D@
M<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@
M=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M
M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`17%U
M871O<FEA;"!'=6EN96$`17)I=')E80!%<G)O<@!%<G)O<B!C<F5A=&EN9R!B
M;&]C:SH@)7,`17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S`$5R<F]R
M(&1E;&5T:6YG('-Y;F,@;&]G.B`E<P!%<G)O<B!G971T:6YG(&-O;G1E;G0Z
M("5S`$5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<P!%<G)O<B!W<FET:6YG
M("(E<R(N`$5S=&]N:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5R>2`Q
M-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V
M97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E
M<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A
M;F0@4VED96)A<@!%>'!E8W1E9"`G*2<`17AP:7)A=&EO;B!$871E`$5X<&]N
M96YT`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D(')E=')I
M979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@
M<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL
M960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N
M`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D
M('1O(&UO=F4@=&\@(B5S(BX`1F%I;&5D('1O(')E=')I979E.B`E<P!&86ER
M`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A
M=&%L($5R<F]R.@!&87@`1F%X97,`1F5B<G5A<GD`1F5E;',@3&EK90!&965L
M<R!L:6ME.B``1F5W(%-H;W=E<G,`1F5W(%-N;W<@4VAO=V5R<P!&:65L9"!M
M871R:7@`1FEJ:0!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S
M(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`
M1FEL92!U<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E
M<G,`1FEN;&%N9`!&:7)S="!(86QF`$9I<G-T(%%U87)T97(`1FEX(')A=&EO
M`$9L:7``1FQO870`1F]G`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT
M($-O;&]R`$9O;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I
M;6%G97,`1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T
M('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N
M:6=H=#L@82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W
M:61E(&)L;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N
M90!&;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R
M=V%R9',`1G(`1G)A;65S`$9R86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&
M<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N
M(%1E<G)I=&]R:65S`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`
M1G5L;"!-;V]N`$9U;&P@3F%M90!'86)O;@!'86QL97)Y.@!'86UB:6$`1V5N
M97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'96]R9VEA
M`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`1V\`1V]E9&5L
M`$=O;V=L92!-87!S`$=O;V=L92!396%R8V@`1W)A>7-C86QE`$=R965C90!'
M<F5E:R`H25-/+3@X-3DM-RD`1W)E96YL86YD`$=R96YA9&$`1W)O=7`@061M
M:6YI<W1R871I;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O
M=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T
M('1H92!S97)V97(@<V%I9#H@`$=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE
M=&4@9W)O=7`@)7,`1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U
M<"`E<P!'<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E
M>0!'=65S="!097)M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U"
M:7-S874`1W5Y86YA`$A434P`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U
M;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE861E<G,`
M2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE879Y(%0M4W1O
M<FT`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP`$AE;'`@=7-I
M;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN
M;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VQY(%-E92`H5F%T:6-A
M;B!#:71Y(%-T871E*0!(;VUE`$AO;64@061D<F5S<P!(;VUE($1I<F5C=&]R
M>0!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+
M;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S
M86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O
M(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@
M9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY
M(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N
M(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(
M;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R
M(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B
M)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@
M240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA
M8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N
M:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P
M861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE
M87-E(')E<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@
M=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E
M/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI
M9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-05`@;6%I;&)O
M>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F
M86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z
M("5S`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!
M9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)7VYS97)T
M(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS(&9O<B`E<P!)
M8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I<R!N;W0@
M9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W
M:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R
M;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@
M=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U('-E92!T:&ES
M(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@
M=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EM
M86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E(&9R;VT@
M9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G
M97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E
M9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C="!A8W1I;VX@
M8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R
M9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4
M<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U
M(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD
M:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA=&EO;@!);F9O
M<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+@!);G-E<G0@0U]O;'5M;B!!
M9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN
M:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A
M9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O
M<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE
M(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R
M96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@
M;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO
M9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@
M861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S
M=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN
M<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T
M(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G
M<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R
M90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@
M<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,
M:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I
M8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT
M96=E<B!L:7-T`$EN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN
M=F%L:60@6DE0(&1A=&$`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B
M871C:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T
M:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@
M;&EC96YS92!K97DN`$EN=F%L:60@;&]C871I;VX@<')O=FED960N`$EN=F%L
M:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L
M:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M
M:7-S:6]N+@!);G9A;&ED('!A<G1N97(@:60N`$EN=F%L:60@<')O9'5C="!C
M;V1E+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED(')E8VEP:65N=#H@(B5S
M(@!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S
M+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$EN=F5R="!S96QE
M8W1I;VX`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`
M27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)
M=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)
M4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*
M=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I
M9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY80!+97)B
M97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME<FYE;"!.
M97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T
M:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I`$MO<F5A+"!$96UO
M8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O
M9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U=`!,
M86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T
M($AA;&8`3&%S="!087-S=V]R9"!#:&%N9V4`3&%S="!1=6%R=&5R`$QA<W0@
M57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E
M<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`3&%W`$QA>6]U=`!,96)A;F]N
M`$QE9G0`3&5F="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,:6)E<FEA
M`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H="!$
M<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN
M($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD
M97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6YK
M`$QI;FL@<&]I;G1S('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H
M92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI<W0@+2!U
M<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T($AE
M;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,:7-T+4AE;'``
M3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,
M:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<P!,
M:7-T:6YG('5S97)S(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A
M8FQE9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]A9&EN9RXN+@!,;V-A;"!T
M:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@;W5T
M`$QO9VEN`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@
M=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN
M`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K
M(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB
M97)S`$QU>&5M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N
M=&%I;F5D(&YO(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M
M97(@675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I8P!-86EL
M`$UA:6P@061M:6X`36%K92!L:6Y?:RXN+@!-86QA=VD`36%L87ES:6$`36%L
M9&EV97,`36%L:0!-86QT80!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE
M<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S
M<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87`R-"!M87``36%P
M475E<W0@;6%P`$UA<F-H`$UA<F=I;@!-87)K('=I=&@@4V5E;B]5;G-E96X@
M9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!
M;G-W97)E9"D`36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H:6YG
M(&9I96QD<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87@@86QL;W=E9"!C<F5D
M:70N`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M<"!L87-T
M(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``36%X:6UU;2!.
M=6UB97(@;V8@4&]R=&%L($)L;V-K<P!-87AI;75M(&QE;F=T:`!-87D`36%Y
M;W1T90!-961I8VEN90!-96UB97)S`$UE;G4@;6]D93H`365R9V4@8V5L;',`
M365S<V%G90!-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE
M('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`
M365S<V%G92!E>'!I<F5D+@!-97-S86=E('1Y<&4`365T87(@8FQO8VL@;F]T
M(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL
M<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T
M87)$0B!I<R!N;W0@8V]N;F5C=&5D+@!-971H;V0`365T:&]D("(E<R(@:7,@
M;F]T(&1E9FEN960`365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D
M.B`E<P!-971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T
M97,@;V8`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S
M.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36EN:6UU;2!P87-S=V]R9"!A
M9V4@:&%S(&YO="!Y970@97AP:7)E9`!-:7)R;W(`36ES8V5L;&%N96]U<P!-
M:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N`$UI<W-I;F<@8V]N
M9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO
M=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A
M9V4@240N`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN`$UI
M<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D
M:69I960@1&%T90!-;V1I9GD@55),`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L
M:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`
M36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)E(&9I96QD<R!F;W5N9"!I;B!L
M:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+@!-;W)O8V-O`$UO<W1L>2!#
M;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!3=6YN>0!-;W9E($1O=VX`36]V
M92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V92!U<`!-
M;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT:7!L
M92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!!8V-O=6YT($EN9F]R;6%T:6]N
M`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@
M3D]4($%G<F5E`$YA;64`3F%M:6)I80!.875R=0!.97!A;`!.971H97)L86YD
M<P!.971H97)L86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E(%523`!.971S
M8V%P92!#02!2979O8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@55),
M`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C871I;VX@55),
M`$YE='-C87!E(%-33"!S97)V97(@;F%M90!.971S8V%P92!C97)T:69I8V%T
M92!C;VUM96YT`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.
M979E<@!.97<@0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@365S<V%G92!T
M;R`E<P!.97<@36]O;@!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A
M;&%N9`!.97<@<&%S<W=O<F0`3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N
M("5X+@!.97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+@!.97<@=VEN9&]W("A?
M8FQA;FLI`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@;W!T:6]N<P!.97AT
M/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:6=H=`!.:75E`$YO`$YO(&%V
M86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E
M<R!F;W(N`$YO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I
M;6%G97,N`$YO(&)A=&-H('1E;7!L871E+@!.;R!B;&]C:R!E>&ES=',@870@
M=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I
M9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H
M:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!6
M1E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S
M=&EN871I;VX@<W5P<&QI960N`$YO(&9I;&4@=7!L;V%D960`3F\@:6-O;G,@
M9F]U;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;&]C871I;VX@<')O=FED
M960N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.
M;R!N=6UB97(@<W!E8VEF:65D+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M2%144"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($E-05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H
M92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y
M(&ES(&YE8V5S<V%R>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P
M96YD:6YG('-I9VYU<',N`$YO('%U;W1A('-E="X`3F\@<G5L97,`3F\@<V5P
M87)A=&]R('-P96-I9FEE9"X`3F\@<VED97,`3F\@<W5C:"!F:6QE`$YO('1E
M;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E
M<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N`$YO('9A;&ED(%A-3"!D871A
M(')E='5R;F5D`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I
M;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`
M3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N
M97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N90!.;VYE("AU<V4@:6UP;&EC:70I
M`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO<F9O;&L@27-L86YD`$YO<G1H97)N
M($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S`$YO<G=A>0!.
M;W0@069T97(`3F]T($)E9F]R90!.;W0@82!D:7)E8W1O<GD`3F]T(&EM<&QE
M;65N=&5D+@!.;W0@<V5T`$YO="!S=7!P;W)T960N`$YO=&5S`$YO=&AI;F<@
M=&\@8G)O=W-E+"!G;R!B86-K+@!.;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F
M(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`
M3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB
M=71I;VX@;&ES="X`3TL`3V)J96-T`$]B:F5C="!#<F5A=&]R`$]C=&%L`$]C
M=&]B97(`3V9F:6-E`$]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I
M9F9E<F5N="X`3VQD('!A<W-W;W)D`$]L9"!P87-S=V]R9"!I<R!N;W0@8V]R
M<F5C="X`3VUA;@!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F
M;VQD97)S+@!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@
M=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@
M;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P
M96X@:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E
M>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N`$]P96YS('1H
M:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/<'1I
M;VYS`$]P=&EO;G,@9F]R("5S`$]R9&5R960@3&ES=`!/<F=A;FES871I;VX`
M3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L(&%P<&QI
M8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E<SH`3W1H
M97(`3W1H97(@26YF;W)M871I;VX`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U
M=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!%05(Z.DUA:6P@8F%C
M:V5N9`!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$871A
M`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D($1A=&$`4$A0
M($-O9&4`4$A0(%-H96QL`%!-($QI9VAT(%)A:6X`4$T@4VAO=V5R<P!032!3
M;F]W`%!-(%-N;W<@4VAO=V5R<P!032!3=6X`4$T@5"U3=&]R;7,`4$]325@@
M97AT96YS:6]N(&ES(&UI<W-I;F<`4%](4"!3:&5L;`!0861D:6YG`%!A:VES
M=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N
M86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`4&%R=&QY($-L;W5D>0!0
M87-S=V]R9`!087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2X`4&%S<W=O
M<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T
M:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W
M;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!0
M87-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O
M<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E
M<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES
M<VEO;@!097)M:7-S:6]N("(E<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I;VX@
M1&5N:65D`%!E<FUI<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N
M`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G4`4&5T<P!0:&EL:7!P:6YE<P!0
M:&]N90!0:&]T;W,`4&ET8V%I<FX`4&EX96QS`%!L96%S92!C;&EC:R!I;G1O
M('-O;64@8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E
M;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A
M;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N
M=&@@86YD(&$@>65A<BX`4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE
M=R!C871E9V]R>3H`4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RX`
M4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O
M9B!D87ES(&EN('1H92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM
M92X`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0
M;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A
M<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I
M=&@@=&AE('1E<FUS('1O('5S92!T:&4@<WES=&5M+@!0;&5A<V4@='EP92!T
M:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0;VQI=&EC<P!0;VQL<P!0
M;W)T=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG
M(&]F('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R
M8V5D(&)Y($E-05`I`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS
M*3H@`%!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4`4')E9G-?;&1A<#H@4F5Q
M=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5F<U]S97-S:6]N
M.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R97-S
M=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R97-S=7)E.B``4')E=FEE
M=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E=FEO=7,@
M;W!T:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV871E($ME>0!0<F]B;&5M`%!R
M;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C=',`4')O;7!T('1E>'0`4'5B;&EC
M($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,@2V5Y($EN9F\`4'5B
M;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL
M>2X`4'5E<G1O(%)I8V\`46%T87(`475E<GD`475O=&$`4E-!(%!U8FQI8R!+
M97D@*"5D(&)I="D`4F%D:6\@<V5L96-T:6]N`%)A:6X`4F%I;B!%87)L>0!2
M86EN($QA=&4`4F%I;B!3:&]W97(`4F%I;B!A;F0@4VYO=P!286EN('1O(%-N
M;W<`4F%N9&]M($9O<G1U;F4`4F%T:6\`4F5A9`!296%D(&UE<W-A9V5S`%)E
M86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O
M;F4N`%)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES
M(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!2961O97,@>6]U<B!L87-T
M(&%C=&EO;@!2969R97-H`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S
M.@!2969R97-H(%!O<G1A;"!6:65W.@!296=E>`!296QA=&EO;G-H:7`@0G)O
M=W-E<@!296QO860`4F5M87)K<P!296UO=&4@4V5R=F5R<P!296UO=&4@55),
M("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V
M92!";&]C:P!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E;6]V
M92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP
M;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T:&ES(&YO9&4@
M9G)O;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z("5S
M`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R
M8V]D93H@`%)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"X`
M4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I
M;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG
M=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I
M9W5R871I;VXN`%)E<75I<F5D($9I96QD`%)E<V5T`%)E<V5T(%!A<W-W;W)D
M`%)E<V5T(%EO=7(@4&%S<W=O<F0`4F5S=&]R92!,87-T(%%U97)Y`%)E<W5L
M=',`4F5T=7)N('1O($]P=&EO;G,`4F5T>7!E(&YE=R!P87-S=V]R9`!2975N
M:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T
M:6]N<P!2:61D;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`
M4F]?=R!0<F]P97)T:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O
M=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O
M<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N
M(&%L;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R(&)E='=E
M96X@8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W
M<R!O;FQY`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O34E-12!#
M<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP=&5D($UE<W-A
M9V4`4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@
M365S<V%G:6YG`%-13"!3:&5L;`!34T@`4U5#0T534P!37U%,(%-H96QL`%-A
M`%-A:6YT($AE;&5N80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C
M:6$`4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N
M9"!T:&4@1W)E;F%D:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N
M($UA<FEN;P!386\@5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I
M9&5R`%-A=61I($%R86)I80!3879E`%-A=F4@(B5S(@!3879E("5S`%-A=F4@
M3W!T:6]N<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0
M('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN
M`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A9&4@
M<V-R:7!T('1O.B`B)7,B+@!38V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!3
M96%R8V@`4V5A<F-H($5N9VEN97,`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A
M=&4`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!3
M96QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L
M;`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C
M=`!396QE8W0@;F]N90!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@
M9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P
M87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E
M(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H
M92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM
M92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T
M=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N
M`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M
M(%)E<&]R=`!396YD(%--4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!3
M97)B:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397)V97(@9&%T
M82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+@!397-S:6]N($%D;6EN`%-E<W-I
M;VX@240@97AP:7)E9"X`4V5S<VEO;G,`4V5T`%-E="!O<'1I;VYS('1O(&%L
M;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O
M<F=E="!I="X`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@
M=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E
M9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO
M=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E
M9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E
M='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO
M;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3
M:&]P<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D
M969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R96YC97,@
M8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T
M960@8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L
M;V=G:6YG(&EN/P!3:&]W('!I8VME<@!3:&]W('1A8FQE(&]P97)A=&EO;G,@
M;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@
M=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B
M;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E
M<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G
M`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R<R!%87)L>0!3:&]W97)S($QA
M=&4`4VAO=V5R<R!I;B!T:&4@5FEC:6YI='D`4VAR:6YK`%-I97)R82!,96]N
M90!3:6=N('5P`%-I9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I;F=A
M<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`
M4VYO=P!3;F]W(%-H;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A
M<FQY`%-N;W<@4VAO=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3;VQO;6]N($ES
M;&%N9',`4V]M86QI80!3;VYG<R`F(%!O96US`%-O<G0@;W)D97(@<V5L96-T
M:6]N`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A
M;B`H25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A
M;F1W:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C97(`4W!A
M8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P86EN`%-P86T`4W!E8VEA;"!#
M:&%R86-T97(@26YP=70`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@
M<F]W`%-P;W)T<P!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K`%-T87)T
M('EE87(`4W1A=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T;W)A9V4@9F]R;6%T
M`%-T<F5E="!!9&1R97-S`%-T<FEK971H<F]U9V@`4W1R:6YG(&QI<W0`4W1R
M:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,`4W1Y;&4@6T-34UT`4W4`4W5B
M9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!3=6)J96-T`%-U8FUI=`!3=6)M
M:71T960@<F5Q=65S="!T;R!A9&0@(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@
M8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R(')E<75E<W0@:&%S(&)E96X@87!P
M<F]V960N`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!A9&1E9"`B
M)7,B('1O('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@
M9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!D
M96QE=&5D("(E<R(N`%-U8V-E<W-F=6QL>2!R96UO=F5D("(E<R(@9G)O;2!T
M:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO
M;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3=6-C97-S9G5L;'D@<V%V960@
M8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL>2!S879E9"!T:&4@
M8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`4W5C8V5S<V9U;&QY('5P
M9&%T960@(B5S(@!3=6-C97-S9G5L;'D@=W)O=&4@)7,`4W5D86X`4W5M;6%R
M>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS
M970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P
M;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@86YD($IA;B!-87EE;@!3
M=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y;F,@;&]G(&1E;&5T960`
M4WEN8TU,`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R
M86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M(&%N9"!7:6YD>0!4+5-T;W)M
M<P!4+5-T;W)M<R!%87)L>0!44U8@9FEL90!486)L90!486)L92!0<F]P97)T
M:65S`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@
M;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC
M(&]F`%1A<F=E=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L
M87-T(&AO=7(Z(`!496UP97)A='5R90!496UP97)A='5R93H@`%1E;7!E<F%T
M=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,`5&5M<&QA=&4@(B5S
M(B!N;W0@9F]U;F0N`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X
M="!/;FQY`%1E>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I("A425,M-C(P*0!4
M:&%I;&%N9`!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4
M:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U
M<'!O<G0@(B5S(@!4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI
M>F5D+@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C
M8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET
M:6YG+@!4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P
M97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U
M<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H92!C;VYT
M86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O
M<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A8W0@
M=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`
M5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@
M=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO
M;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N
M:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T
M:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T:6]N(&9E
M871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!F
M:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@
M)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@
M8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@8V]N=&%I
M;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O
M<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!I9&5N=&ET>2`B
M)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!L969T+6AA;F0@<VED92!O;FQY
M`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV
M96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT
M(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L
M87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H
M87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W
M:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;G5M8F5R(&]F
M(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N`%1H92!O<&5N<W-L(&UO9'5L92!I
M<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N
M`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U
M<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I
M>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E
M<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<75O=&4@8VAA
M<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!R:6=H
M="!A;F0@;&5F="!S:61E<R!O;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL
M>0!4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N
M`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R
M("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@
M)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N
M;W0@97AI<W0N`%1H92!T96UP;W)A<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X
M:7-T+@!4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T
M97AT(&]N('1H92!S8W)E96XN`%1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O
M;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!U<&QO861E9"!D871A('=A<R!L
M;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL
M92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I
M<R!N;W0@879A:6QA8FQE+@!4:&5M97,@9&ER96-T;W)Y("(E<R(@;F]T(&9O
M=6YD+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R
M92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R
M92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@
M:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE
M<W,@=&AA;B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@(B5S(B!T
M;R!T:&4@<WES=&5M.B`E<P!4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG
M(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W
M87,@82!P<F]B;&5M(')E;6]V:6YG("(E<R(@9G)O;2!T:&4@<WES=&5M.B``
M5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R`B)7,B.B`E<P!4:&5R92!W
M87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@
M=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL
M;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@
M=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@
M;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE
M(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@:4-A;&5N9&%R(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@
M8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A(')E
M<75I<F5D(&9I96QD+@!4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T
M:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E('1R
M>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H
M92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H
M97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI
M<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H:7,@24U!4"!S97)V97(@
M9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@9&]E<R!N
M;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E
M<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E
M<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&9I
M96QD(&ES(')E<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@
M:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S
M(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O
M8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P
M86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@;75S
M="!B92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@
M82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP
M;&4@)R,Q,C,T868G+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C
M97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@
M;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@
M96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P
M=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"!C;&EE;G1S
M('!L96%S92!V:7-I="`E<P!4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@
M82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BX`5&AI
M<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@<V5R=F5R(&-A
M;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4:&ES('-Y<W1E
M;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L=64@;75S="!B
M92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A
M;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R`%1I8VME=',`5&EM90!4:6UE(%1R
M86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L96-T:6]N`%1I;6]R+4QE<W1E
M`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`5&\`5&\@<V5L96-T(&UU;'1I<&QE
M(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD
M("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D87D`5&]G9VQE($A434P@
M4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO<G)O=P!4;VYG80!4;W``5&]P(&9R
M86UE("A?=&]P*0!4<FEN:61A9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L<V4`
M5'4`5'5N:7-I80!4=7)K97D`5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE
M;FES=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L86YD<P!4=79A;'4`5'EP92!Y
M;W5R(&-H;VEC93H@`%4N5BX@:6YD97@Z(`!54DP`55),.@!59V%N9&$`56MR
M86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T
M;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N
M`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S
M(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E
M<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-H96-K
M(&9I;&4@<VEZ92!O9B`B)7,B+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE
M(&]F("(E<R\E<R(N`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N
M`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!6
M1E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y("(E<R(N
M`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R
M96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R("(E
M<R(N`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T
M;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@=&AE
M(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@(B5S
M(CH@)7,N`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@
M;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U
M<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L
M971E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N
M`%5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@
M9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D971E<FUI
M;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R86-T(&-E<G1I
M9FEC871E(&1E=&%I;',`56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@
M;V8@)7,N`%5N86)L92!T;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E
M;B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@
M=W)I=&EN9RX`56YA8FQE('1O(&]P96X@5D93(&9I;&4N`%5N86)L92!T;R!O
M<&5N(&-O;7!R97-S960@87)C:&EV92X`56YA8FQE('1O(')E860@5D93(&9I
M;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@5D93(&9I
M;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@9FEL
M93H@`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA
M8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L
M<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`
M56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O
M(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@
M=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O
M<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N
M86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L
M92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N`%5N9&5R;&EN90!5;F1O
M($-H86YG97,`56YD;V5S('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R
M97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E
M9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@`%5N9FEL960`56YI8V]D92`H
M551&+3@I`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N
M:71E9"!3=&%T97,`56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA
M;F1S`%5N:71S`%5N:VYO=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A
M9V4@240I+@!5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN
M`%5N:VYO=VX@;&]C871I;VX@<')O=FED960N`%5N:VYO=VX@=7-E<FYA;64@
M;W(@<&%S<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M
M960`56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P
M>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N
M("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA
M+F]R9R!W:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O
M(&%C8V5S<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E
M9"!%>'1E;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&1A
M=&5D("(E<R(N`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO
M861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E
M<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R
M=6=U87D`57-E($-U<G)E;G0Z("5S`%5S92!34TP`57-E(&EF(&YA;64O<&%S
M<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E<@!5<V5R
M("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A
M=&EO;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<B!296=I
M<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`57-E
M<B!A8V-O=6YT(&YO="!F;W5N9`!5<V5R;F%M90!5<V5R;F%M92`B)7,B(&%L
M<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T
M:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@
M97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E
M.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L=65S
M`%9A;'5E<R!T;R!S96QE8W0@9G)O;0!686YU871U`%9A<FEA8FQE`%9E;F5Z
M=65L80!697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H
M879E(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO;@!697)S:6]N($-O;G1R
M;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`
M5F5R>2!(:6=H`%9I970@3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE=R`E
M<P!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I97<@87,@)7,`5FER9VEN
M($ES;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES:6)I
M;&ET>0!6:7-I8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%2
M3@!705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RX`
M5TE.('9I82!(5%10`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A
M=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE
M<BYC;VT`5V5B`%=E8B!3:71E`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@
M)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H
M25-/+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@
M<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E
M;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E
M<C\`5VAE<F5I<R!!=7-T<F%L:6$@;6%P`%=H:6-H('!H87-E<P!7:&EC:"!P
M;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I
M9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O
M;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED
M=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN9`!7
M:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I
M<V1O;0!7:7-H;&ES=`!7;W)K`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%=R
M;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L
M(&9O=6YD("5D+@!7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E
M9"P@9F]U;F0@)60N`%@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4`6#4P.78S
M(%-U8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y=C,@4W5B:F5C="!+97D@
M261E;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!960!965E9`%EA:&]O(2!M
M87``665A<FQY`%EE;65N`%EE<P!997,L($D@06=R964`66]U(&%R92!I;B!4
M15A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K
M('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO
M<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N
M`%EO=2!C86YN;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U
M;&P@;F%M92X`66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R
M97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R
M=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9
M;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E('1O(&5N=&5R(&$@
M=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O
M<'1I;VYA;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E
M9FEX+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@;75S
M="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S
M+@!9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"X`66]U(&UU<W0@
M9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@
M<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@
M=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R
M('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T
M;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R
M96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`
M66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@
M;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T
M('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U(&YE960@=&\@<')O=FED
M92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9;W5R("5S('-E<W-I;VX@:&%S
M(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R
M97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R
M($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN
M;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U
M<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U
M=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@
M=7-E<G,N($EF('EO=2!W:7-H('1O('5S92!(;W)D92!T;R!A9&UI;FES=&5R
M('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="!A=71H
M96YT:6-A=&EO;B!B86-K96YD+@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME
M;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A
M='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN
M`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T
M:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y
M;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W
M<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&)R;W=S
M97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@
M0V]N=')O;"]#;VUM86YD("L@4"!T;R!P<FEN="X`66]U<B!C=7)R96YT('1I
M;64@>F]N93H`66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG
M960N`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO
M=7(@;&]G:6X@:&%S(&5X<&ER960N`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E
M<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T
M:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V
M92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970`
M66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I
M;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@<&%S
M<W=O<F0@:&%S(&5X<&ER960N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S
M;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%M(:61E(%%U;W1E9"!497AT
M70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!497AT("T`6U-H;W<@
M475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI;F4@)7,@;V8@)7-=`%]!9&UI
M;FES=')A=&EO;@!?0TQ)`%]$871A5')E90!?1&5L971E(%)O=P!?1W)O=7!S
M`%](96QP`%]);6%G92!0<F]P97)T:65S+BXN`%],;V<@:6X`7TQO9R!O=70`
M7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4F5M;W9E
M($QI;FLN+BX`7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN`%]5<V5R<P!A
M9&1R97-S(&)O;VL`8V%L96YD87(`8V%N;F]T(&-R96%T92!O=71P=70@9FEL
M90!C86YN;W0@;W!E;B!I;G!U=`!C;&EC:R!H97)E`&-O;6UA;F0@;&EN92!U
M<V%G92!E<G)O<@!C;VYF:6=U<F%T:6]N(&5R<F]R`&-R:71I8V%L('-Y<W1E
M;2!F:6QE(&UI<W-I;F<`9&%T82!F;W)M870@97)R;W(`96YT<GD@;F]T(&9O
M=6YD`&9I;&4`9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!G=7-T:6YG`&@Z
M`&AH`&AO<W0@;F%M92!U;FMN;W=N`&EM;65D:6%T90!I;FQI;F4`:6YP=70O
M;W5T<'5T(&5R<F]R`&EN=&5R;F%L('-O9G1W87)E(&5R<F]R`&QI;F5S70!M
M;0!N86UE`&YO="!I;7!L96UE;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO
M=&5P860`<&5R8V5N=`!P97)M:7-S:6]N(&1E;FEE9`!P:7AE;',`<F5M;W1E
M(&5R<F]R(&EN('!R;W1O8V]L`')I<VEN9P!S97)V:6-E('5N879A:6QA8FQE
M`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10`'-S`'-T96%D
M>0!S>7-T96T@97)R;W(`=&%S:R!L:7-T`'1E;7!O<F%R>2!F86EL=7)E`'1Y
M<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA
M;65D`'5S97(@<V5L96-T`'9#87)D`'<Z`'=E871H97(N8V]M`%!R;VIE8W0M
M260M5F5R<VEO;CH@2&]R9&4@,RXP+6-V<PI297!O<G0M37-G:60M0G5G<RU4
M;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P
M-BTP,2TP-2`Q-3HP-"LP.#`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#$M,3(M
M,C`@,3(Z,#`K,#@P,`I,87-T+51R86YS;&%T;W(Z($1A=FED($-H86YG(#QD
M879I9$!T;78N9V]V+G1W/@I,86YG=6%G92U496%M.B!4<F%D:71I;VYA;"!#
M:&EN97-E(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q
M+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4))1S4*0V]N
M=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@."UB:70*`"`H)7,@I-&K92D`("BG
MUK&VP>0@)7,I`"`H)7,@I-&DNBD`("BDM:31*0`@**GZI-$I`"`HK%&DT2D`
MJ?,`(B5S(B"DHZQ/I$"MTZ78O_T`(B5S(B"DHZQ/I$"MTZ:SKL2JNK_OOMPN
M`"(E<R(@J7REO*9B($A/4D1%(*JZM?FE5<#)*%)E9VES=')Y*:2DLUVI=RX`
MI^2DHZCL("(E<R(@=')E92!R96YD97)E<BX`(B5S(J1WIJBE7*JZI5ND2JCL
MN'.RU:ATLLZDI"X`(B5S(J1WI5ND2L5VK:VH=++.+@`B)7,BJ,.EO*O8I=\Z
M("5S+@"D=ZC/I<X@)2XR9DU"("RN9;9Q("4N,F9-0B`LL]&^;"`H)2XR9B4E
M*0`E9"`E<R"E2*3.("5S`+/,JO&D0*:XL4N]6,7<I_.I\R`E9""DT:ME+@"S
MS*KQ("5D(*31KO"V2+EWL_@`)7,@+2"SQJ?1O_T`)7,@J_ROO@`E<R!+0@`E
M<R"Z^\5`OMZG0"`M(+U4NWL`)7,@LUVI=P`E<R"U^:55`"5S(*90MTZVM:78
M`"5S(*1WIG.F8@`E<R"F8B`E<R`E<P`E<R"D=[1.I%6F0ZC&MK6JNKK[Q4"^
MWJ=`M$ZZ_"X@O="I\Z:YKLFDQ+_OIT&W4:UNOMZG0*JZMK6EV"X`I;*[W:UN
M("5S`"5S(*3``*?DI*.H["`E<RX`("5S(*CL("5S(*9`("5S`"5SJKJS<;!4
MO_T`)7.JNJ;FJ,:^Y``E<ZJZL\:GT;_]`"5SJKJKW;_LPZ\`)7,Z("5S`"5S
M.B"S;ZO*JTBE\Z2CI$"I=Z]UI=&K2*2DJKJQ2*7SI$BITK%(M6\N(+W0JF"W
M3J15ID.ITJ:SJKJZ]+CTLW.ULJ:SI6FOX*RJNGRG0:JZK=.D2+CJKL8N`"P@
ML'VMMR``+""P?:VW("5S("5S`"S%W*3&MG&Q<2`E<R"H["`E<P`M+2"_[[[<
M("TM`#$R(*1PKLFH[@`R-""D<*[)J.X`,C0@I'"NR:CN`*17I$"MM@"FN;#/
MMO2ELK:WK6ZK_*EWN.JNQJYWIOBJ0;K=+@"U;Z7-I$:D0*W3Q%FMJZJZO_F[
M?@"Q_:5;L4NV;*7S+,'9N]VM;J:SI$"MTR!01U`@I+VV?:KWQE\N`+']Q>?#
MTJ1WP[&SN:JZMFRE\RS!V;O=K6ZFLZ1`K=,@4$=0(*2]MGVJ]\9?+@"Q_;C1
ML4NV;*7S+,'9N]VM;J:SI$"MTZ2]MGT@4$=0(*KWQE\LJ'"Q2R!01U`@JO?&
M7RRE2*3.LW'#]J1FI4\N`+']L/6FYK9LI?/#L;.Y+,'9N]VM;J:SI$"MTZ2]
MMGT@4$=0(*KWQE\LJ'"Q2R!01U`@JO?&7RRE2*3.LW'#]J1FI4\N`+']N-&Q
M2[9LI?,LP=F[W:UNIK.D0*W3I+VV?2!334E-12"J]\9?+*APL4L@4TU)344@
MJO?&7RRE2*3.LW'#]J1FI4\N`+']L/6FYK9LI?/#L;.Y+,'9N]VM;J:SI$"M
MTZ2]MGT@4R]-24U%(*KWQE\LJ'"Q2R!3+TU)344@JO?&7RRE2*3.LW'#]J1F
MI4\N`+']I5NQ2[9LI?,LP=F[W:UNIK.D0*W3(%--24U%(*2]MGVJ]\9?+@"D
MR*MEIK.VLP"DR*MEI'"K0@"DR*MEIK.K0@"DR*MEL'VK0@"DR*MEL'VSMP"D
MR*ME+Z3(J^$`05!)(+USN+D`P_:I\[-OK=.]<[_HOKD`P_:I\RXN+@"EOZ15
MI.@`I;^DI*6A`,5VK:VDHZBL++5,JFNKV*7?(%9&4R"EV+_]+@#%=JVMI*.H
MK"RU3*IKJ]BEWR!61E,@P,FNURX`L6*XN;CJL%0`L6*XN;M0L4N]6`"Q8KBY
MI'>MX;6R+@"ULK%B`+=SO%<`MW.\5Z:XN'.RU0"W<[Q7I&S%=JVM`*9BIKFW
M<[Q7.@"W<[Q7N'.RU0"W<[Q7Q7:MK0"W<[Q7IKBX<[+5J.P@(B5S(@"W<[Q7
MIKC%=JVMIMPB)7,B`+=SO%>D0*W3J,^ESJK,.@"W<[Q7Q.:F[`"W<[Q7I$"M
MTZ:HK?LZ`+=SO%>Y[P"W<[Q7("5S(*RP($UO>FEL;&$@JKJDP*VV`+=SO%>H
M[*JZLW&P5+_].@"W<[Q7J.RGVJJZLW&P5+_]`+=SO%>HSZ7.JLP`I'>W<[Q7
M("(E<R(@J.RH=++.I*0N(*;]M4RJ:[=SO%?#0J5^JKJU^:55N.JP5#H@)7,N
M`*1WMW.\5R`B)7,B(*CLJ'2RSJ2D+B"G0;)[IF*E::5(MFFFYK5NI$JD1BX`
MMW.\5ZC/I<ZJS*JZI5ROX*78JV6S4</VLZPN`*9AIWT`LW&P5+_]`*:HK+"Z
MWK)ZK?L@+2"LL*CDI4RHSZ7.JLRS7:EWQ7:MK0"ZWK)Z`+QSIVD`069G:&%N
M:7-T86X@**K\M$FFO2D`06QB86YI82`HJORZN*3:I:>HR"D`06QG97)I82`H
MJORZN*3.IU&HR"D`MFRE\Z=/IE<`N>^[]`"Y[[OTI.BFH3H`J=*FLP"ITJ:S
MI'?%Y\/2JKJHSZ7.JLP`J=*FL[ASLM4`J=*FL\5VK:T`I7ZNV+UU`*2YLURF
M;K18K=.Y<:1LMFRE\Z9AIWT`I+FS7,7<I_.VM:78O7.XN:JZJZRZ03\`I'>F
M<Z9B`,7<I_,@24U34""U;J1*`,7<I_,@24U34""Q2[U8`,7<I_,@24U34""H
MSZ7.JLP`Q=RG\[EQI&RV;*7SINVG?0#%W*?SO,NJ3P"TP*5.I.6F<@!!;65R
M:6-A;B!386UO82`HK/S$4K#MPL2\KZC(*0"D0*W3M4RNQ*JZK<BS4:C/I<XN
M`+5OI<VD1J1`K=.EO*J^JKJ_^;M^+@!!;F1O<G)A("BF=[E$IM4I`$%N9V]L
M82`HIG>M]*G4*0!!;F=U:6QL82`HIG>F8ZG4KG$I`+#.IE>E3K)ZIG.H^@"U
MJJ[7`$%N=&%R8W1I8V$@**MNMZ6D:K.P*0!!;G1I9W5A(&%N9"!"87)B=61A
M("BF=[2CI<JN<:3.I-JZN*6LN4:N<2D`P+.ESK5[IJ$`P+.ESK5[IJ&R3;/F
M`,"SI<ZU>Z:AI'>T3KK\`*Y-I<ZH[*G2IK.JNJ:XID"HR0"GY:WC`+EWIO2D
M:J1P`*5\I.L`JORIU*="I.4@*%=I;F1O=W,M,3(U-BD`P*/!6<#)I&JD<`#`
MH\%9P,FF5[K9`*=!O52I=ZUNIU*PHR`E<R"JNK7YI56VW"`_`*=!O52I=ZUN
MIU*PHR`B)7,B(*5(I,ZE]*;SJKJFN+ASLM4@/P!!<F=E;G1I;F$@**K\KMJG
MRBD`07)M96YI82`HJ,BL_*6GJ,@I`*C(K/REIZC(I.4@*$%235-#24DM."D`
MP\"S3@!!<G5B82`HJOR^?*3:KG$I`$%S8V5N<VEO;B!)<VQA;F0`I.6F<L/`
MLTX`J,BL=R^DTZ6MK':F8;#/`+#UIN:^WJ=`NOO%0*MEQ>.EW+U4NWNY[[C<
M/P"DP+!TQ.:F[`#`?+C5IU*PHZ1`K=.DHZ9SIF*JNKASLM4N`,!\N-6G4K"C
MI$"MTZ2CIG.F8JJZQ7:MK2X`P'RXU;USO^BD0*W3I*.F<Z9BJKJX<[+5+@#`
M?+C5O7._Z*1`K=.DHZ9SIF*JNJ9`J,DN`,3=J<H`I$NDZP!!=7-T<F%L:6$@
M*+]$I&JG4:C(*0!!=7-T<FEA("BV^*9AIU$I`$%U=&A?8W)Y<W%L.B"GY*2C
MJ.RITKO=K6ZJNB!I;6%P(*FUIOFN3:7S+@!!=71H7V-Y<G5S.B"F^*I!NMVH
MPZ6\M*.HT;C3MK6DY+2I+@!!=71H7V-R>75S.B"GY*2CJ.RITKO=K6ZJNB!I
M;6%P(*FUIOFN3:7S+@!!=71H7V9T<#H@I^2DHZCLJ=*[W:UNJKH@1E10(*FU
MIOFN3:7S+KW0K:NW<[USQ+8@4$A0(*C#I4*E6Z1*("TM96YA8FQE+69T<""_
M[[:U+*C2IG`@8V]N9FEG=7)E("TM96YA8FQE+69T<`!!=71H7VEM87`Z(*?D
MI*.H[*G2N]VM;JJZ($E-05`@J;6F^:Y-I?,N`$%U=&A?:W)B-3H@I^2DHZCL
MJ=*[W:UNJKH@:W)B-2"IM:;YKDVE\RX`075T:%]L9&%P.B"W<[Q7J,^ESJK,
MLV^VM:5<K^"EV*MEJ,.DHZ3DM*FEV+_]JD&PR`!!=71H7VQD87`Z(*=2L*.H
MSZ7.JLRS;[:UI5ROX*78JV6HPZ2CI.2TJ:78O_VJ0;#(`$%U=&A?;&1A<#H@
MI^2DHZCLJ=*[W:UNJKH@3$1!4""IM:;YKDVE\RX`075T:%]L9&%P.B"U3*IK
MMW.\5ZC/I<ZJS"`E<RX@IOBJ0;ZYIE[`LSH`075T:%]L9&%P.B"U3*IKLKZP
MHZC/I<ZJS"`E<P!!=71H7VQD87`Z(+5,JFNG\[=SJ,^ESJK,("5S`$%U=&A?
M;&1A<#H@I_.W<ZC/I<ZJS+-OMK6E7*_@I=BK9:C#I*.DY+2II=B__:I!L,@`
M075T:%]M8V%L.B"GY*2CJ.RITKO=K6ZJNB!-0T%,(*FUIOFN3:7S+@!!=71H
M7W-M8F%U=&@Z(*?DI*.H[*G2N]VM;JJZ('-M8F%U=&@@J;6F^:Y-I?,N`$E-
M05`@IOBJ0;ZYQ>?#TK_YNWXN`,7GP]*EHK'1+@#%Y\/2I:*QT2X@)7,`4D%$
M2553(,7GP]*_^;M^+@!&5%`@Q>?#TK_YNWXN`%--0B#%Y\/2O_F[?BX`I6FE
MSJJZQ.:F[#H`07IE<F)A:6IA;B`HJ,BVZZOTM4TI`*U)M+H`K4FTNL-#IN(`
M:V5R8F5R;W,@L4N]6+_YNWXN`&ME<F)E<F]S(*C/I<ZJS*97NMF_^;M^+@!"
M86AA;6%S("BDVJNBL*@I`$)A:')A:6X@**3:JDPI`*IIP[FJNJ[\I.4@*$E3
M3RTX.#4Y+3$S*0!"86YG;&%D97-H("BI<Z5;J=0I`$)A<F)A9&]S("BDVJBI
MIF@I`*?DI*.H[+G/I=REV+_]("(E<R(N`+#RO74`0F5L87)U<P!"96QG:75M
M("BD\:=1KLDI`$)E;&EZ92`HJ*FHO;2U*0!"96YI;B`HJ*FYYRD`0F5R;75D
M82`HILJ\?;E&*0!":'5T86X@**2CI*8I`*7-I.D`I^2DHZCLP+.ESK5[IJ$B
M)3(D<R*JNK#/MO0B)3$D<R(N`+#/MO2S7:EW`+#/MO2KK+I!`++*Q>D`0F]L
M:79I82`HK,&G4;K[J,@I`*[1Q=(`KMB]=0"NV+UUI&JD<`"NV+UU`$)O<VYI
M82!A;F0@2&5R>F5G;W9I;F$@**III&BEIZC(I,ZVPL')K?2Z^ZBZ*0"E_K.A
M`$)O='-W86YA("BJ::6^J+HI`*FSLZ$`0F]U=F5T($ES;&%N9`!"<F%Z:6P@
M**3:IN@I`$)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>0!"<G5N96D@
M1&%R=7-S86QA;2`HJ%JUW"D`0G5L9V%R:6$@**M/I5NG4:C(*0"VM:78LL6X
MN0!"=7)K:6YA($9A<V\@**6LM%BOQZIKK\$I`$)U<G5N9&D@*+M:MJFF82D`
MJJFML;K>LGH`0U)#`$-23""DP+.APDD`P'BF<Z[FI+JN92XN+E]E`*?6J/JJ
M[*ELI,:I?*6\I[FFJ"X`IN:HQK[D`+ESK\6MMP!#86UB;V1I82`HK%JN2+GK
M*0!#86UE<F]O;B`HL]BSP;:I*0"U3*IKIMNPRJVKN&VQ2[U8++W0P7"UN*=!
MJKJH=++.NMZR>JW[+@"U3*IKO&>D2L#)KM<@(B5S(@"U3*IKLW.]=:;<($E-
M05`@IOBJ0;ZY.B`E<P"U3*IKMGVQTL#)KM<@(B5S(BX`0V%N861A("BE6ZZS
MI&HI`*CZKO@`J/JN^+#=PT2F7K/X`+5,JFNG4K"CP,FNUR`B)7,B+@"GY*2C
MJ.R\R*9SI=B__2X`K\JDUB`G=&%R9V5T1FEL92<@L-&\QK5,JFO$?L3RLT*R
M>BX`M4RJ:[*^L*.EV+_]("(E<R(N`+5,JFNROK"C.R`E9""MTZ1LMK"D=Z9S
MIF(N`+5,JFNMJ[+5H4.ITK2CJ-&JNK!/O_V\QJ78NU"E_:MEJ=+`>*9SJKJX
MZJ[&I*.RQ2X`M4RJ:[;'L&7"LK!4J.RK_*EWJKJXN;U8+@!#87!E(%9E<F1E
M("BZ^[QWJ*0I`+NAJ?JDY:9R`*3`P_Z[4+S0Q=(`0V%Y;6%N($ES;&%N9',@
M*+9]L-*X<ZYQ*0"FYK#*N7&XW`#`>*9SKN:DNJYE`,!XIG.NYKG4I5(Z`,!X
MIG.NYJ2ZKF4`P'BF<Z[FMJ&V6CH`IN:PRKEQN-P`MNNZN*]3I.4@*$E33RTX
M.#4Y+3$T*0"X;:2D`$-E;G1R86P@069R:6-A;B!297!U8FQI8R`HI*2K1*9`
MJ4VPZBD`I*2\VB`H25-/+3@X-3DM,C``OLS#TK+3N&``OLS#TK[6IK.JS`"^
MS,/2K$:UI@!#:&%D("BL9+QW*0"G\Z?O`*?SI^^G0:JZL4N]6`"G\Z?OIT&J
MNJJZI?ZF5Z5(I,ZF7K9LIF&G?2X`I=BK9:JZLUVI=ZC#I;RDY+2IL4N]6,7<
MI_,N(+W0P7"UN*=!JKJZWK)ZK?LN`*9RI+@`P,NL9+-SM;(N+BY?:P!#:&EL
M92`HM+RG42D`0VAI;F$@**2DL.HI`,*RQ>FDI*3E("A'0C(S,3(I`*6_Q>FD
MI*3E("A":6<U*0"_[[[<P+.ESK5[IJ$Z`+_OOMRQ2[U8`+_OOMRD0*W3J,^E
MSJK,IE>ZV0"DZ;3!Q>.EW*3HIJ$Z`+_OOMRVM:78JZRZ0:JZK;>NY@!#:')I
M<W1M87,@27-L86YD("BX=+W/KG$I`*?DI*.H["`E<R"JNL/^IT^I=[AQ+@"T
MN`"R3;"CMTRS;B!/9F9I8V4@O-#%T@"R3;"CK&2XWP"R3;"CJ,^ESJK,.B`E
M<P"R3;"CJ,^ESJK,`+)-L*.HSZ7.JLRJNKCJKL8`L=_"X+2X`*OVM\:YJ\'D
MI4C$?L3R`$-L:6-K871E;&P@LWJY3"!(5%10`,/VLZRU^+6A`+:SMG$`IJVF
M:+:S`+.Q`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`*?IQ7RXZJ[&IZ@`I^G%
M?,/DK,D`0V]L;VUB:6$@**WTK=ND\:C(*0##0Z;B`+W5IN*]3``Q-K9IINS#
M0Z;BI4Z]6`#$YCH`Q.:F[+S0PT0`I62S<0"I4J5/`*?EIKBI4J5/`+7[O=<`
MNMFI20!#;VUO<F]S("BL[+ROP[DI`*2]I7$`N7&XHP#`]+G2`+'XI?,`KG2R
MIP"[4"!01$$@M'BD5ZNLN7&XHRRTO+QZJZRDXK[WI4BDSB!/=71L;V]K(*JZ
MIE"H0K-=J7<N`+-=J7>XZJ[&N4RTP2X`LUVI=R`E<P"]5+M[L4N]6`!#;VYG
M;R`HK>BJ1RD`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H
M92`HK>BJ1Z9`J4VPZBD`LW.ULJ6BL=$N`+-SM;*EHK'1.B``LW.ULJ;<I+VV
M?:KWQE^F^*I!OKFNR;Y$J=HN`+-SM;*FW*2]MGVJ]\9?IOBJ0;ZYKLF^1*G:
M+B"M[*9=.B`E<R`H)7,I`+-SM;*FW"!&5%`@P,FNUZ;XJD&^N:6BL=$N`+-S
MM;BD2`"P3[_]I'>FJ*5<IF&W<[Q7IMRG0:JZLW&P5+_]I*0N`,"CP5G`R:[7
MJKJDNJYEJZRZ03H@`"(E<R(@P,FNUZ2ZKF4`Q'[$\@!#;V]K($ES;&%N9',@
M**SLITJX<ZYQ*0"]QKMS`+W&NW.EHK'1.B`E<P"]QKMS`$-O<W1A(%)I8V$@
M**WTM+6D:KZDI5LI`$-O=&4@9"=)=F]I<F4@*+9(I/JN_*FD*0"U3*IKI4@@
M4$=0(*5;L4NV;*7S.B``M4RJ:Z5((%!'4""P]:;FMFRE\\.QL[DZ(`"U3*IK
MI4@@4R]-24U%(*5;L4NV;*7S+@"U3*IKK+`@4R]-24U%(+9LI?/#L;.Y+@"U
M3*IKMW.\5[-SM;BD2"X@)7,`M4RJ:\.TM;(@3$1!4""F^*I!OKD`M4RJ:\.T
MM;(@;&1A<""F^*I!OKD`M4RJ:\#+K&2W;*]Q+B`E<P"U3*IKLW.ULJ;<(&QD
M87`@IOBJ0;ZY`+5,JFNS<[6RIMRF^*I!OKD@(B5S(B"HSZ7.($944#H@)7,`
MM4RJ:ZO8I=^P=+AMN'.RU2X@)7,`M4RJ:[C1L4L@4$=0(+CJKL8Z(`"U3*IK
MN-&Q2R!3+TU)344@N.JNQBX`M4RJ:Z=2L*.S<[6XI$@N("5S`+5,JFNG4K"C
ML'2X;;)-L^8N("5S`+5,JFNG4K"CI_.W<[5[IJ$@(B5S(BX`M4RJ:ZA-J7>F
MK*7SI$BJNKEQI&RV;*7SINRG?2X`M4RJ:\#RJ/JGN;[CJKJS<;!4O_TN`+5,
MJFO`\JCZI[F^XZJZL'2X;;)-L^8N`+5,JFO`\JCZL'2X;;)-L^:DI*JZN'.R
MU2X`M4RJ:[C\I$JUIK*D("(E<R(N`+5,JFNKV*7?I=B__2`B)7,B+@"U3*IK
MIMNJ]\9?IOBJ0;ZYJ/JQ;Z2]MGVJ]\9?+@"U3*IKMGVQTB`B)7,B(*5(O&>D
M2BX`M4RJ:[9]L=(@)7,N`+5,JFNV?;'2NOO%0*1UIT"\TK+5("5S`+5,JFNV
M?;'2I=B__2`B)7,B+@"U3*IKLW.QM2!,1$%0(""F^*I!OKDN`+5,JFO%JJCZ
M("5S+@"U3*IKK:NW<[-=J7>HSZ7.JLRJNK%+O5@N(+.AI,"JNK+3N&"DHZ6_
MO50N(+W0P7"UN*=!JKJH=++.NMZR>JW[I4BH\Z=5LT*R>BX`M4RJ:\6JJ/JF
M<ZCZL;&H[JKM*$%C8V5S<R!#;VYT<F]L($QI<W0I`+5,JFO%JJCZLW&P5+_]
M+B`E<P"U3*IKQ:JH^K!TN&VR3:55+B`E<P"U3*IKQ:JH^K!TN&VR3:55+B`E
M<P"U3*IKQ:JH^J;XJD&^N:JZK-O#]J]3J<H`M4RJ:Z9>M%^S7:EW+@"U3*IK
MIU*PHZ78O_T@(B5S(BX`M4RJ:\!XIG,@)7,@JKJS7:EW+@"U3*IKP'BF<[/&
MI?>S7:EW+@"U3*IKP'BF<[/&I?>S7:EW.B`E<RX`M4RJ:\!XIG.G\[=SM7NF
MH:CL.B`B)7,B+@"U3*IKP'BF<[/&I?>S7:EW("5S+@"U3*IKP'BF<[-=J7?`
MR25S+B"G0:5II4BHSZ7.)7.DI*JZJ.2E3*5<K^#`>*9SLUVI=ZG.I.*PRKW&
MNW.D5:VQM7NFH;U8J.P@)7,N`+5,JFNW:K1-($Q$05`@(*;XJD&^N2X`M4RJ
M:Z=2L*,@(B5S(BX`M4RJ:Z?SMW.S<[6XI$@N("5S`+5,JFNG\[=SL'2X;;)-
MI54N("5S`+5,JFO"T+QG("(E<R(Z("5S(*JZLUVI=RX`I^2DHZCL($UO>FEL
M;&$@JKJDP*VV+B"]T+U4NWNDP*VVK$^G7[9]L=(N`+5,JFN]X:2IJ,^ESJK,
M("(E<R(@I%6F0\5VK:VH[*M(I?.G6"`B)7,B.B`E<P"GWK-.I7D`L.JN80"]
MTJKM`*O8I=\`J]BEWZ1`K=.S<[6R`*O8I=^D0*W3MW.JN@"KV*7?IKBK2*7S
MIU@`J]BEWZK,JKK%=JVM`*M(I<ZE9+BYO5@`0W)O871I82`HITK#N:;HJ,@I
M`$-U8F$@**5JI-HI`*78JV6W?+3!`*78JV6NR;:A`*78JV6Z]*=]`*78JV6J
MNJC/I<ZJS`"EV*MEI-&N\`"EV*MEJKJJK*IP.B``I=BK9:JZK;>NY@"FVZUQ
MI$"HQ[5NI$HE<ZOAJ=*M;K#UIN:JNJ1UIT`N`+#%I%4`L,6D50!#>7!R=7,@
M*,')M+:PQ[2U*0"FZ*B]NKBDY2`H2T])."U2*0"FZ*B]NKBDY2`H5VEN9&]W
M<RTQ,C4Q*0"FZ*B]NKBDY2^O4:=*Q/6DY2`H2T])."U5*0!#>F5C:"!297!U
M8FQI8R`HL;:G2J9`J4VPZBD`I.D`N.JNQJC3M[VF5[K9("B]T+#1IM(@:'1T
M<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD
M8BYI;G1R;RUD<VXN<&AP*0"H0Z3I`+[PJJRXZJ[&PG/$_0"XZJ[&KG>W:K1-
M`*3IM,$`IJRH[*3IM,$`O^^^W*3IM,$`I=6DT0"G4K"CQ.:F[%]L`*11I$>D
MZP"D4;9IINR\QJ9R`+3NI-;!6;'&`+EWLUT`N7>S7<-#IN(`N7>S7:JZJ*VE
M]\/1IT\`N7>S7:E2I4^XT:I2OKDH4VAE;&PI`*EWN'$`IU*PHP"G4K"CP'BF
M<Z[F`*=2L*.X<[+5`*=2L*.L]K_]`*=2L*/%=JVM`*=2L*.A0K)-JL6V;*7S
M`*=2L*/`>*9SKN8`IU*PH\3FINP`IU*PH[)[IG.JNK3`I4Z\RZI/`*=2L*,B
M)7,BJKK%=JVM`+U4J7>M;J=2L*,B)7,BJKK%=JVMI4BDSJ:XQ7:MK2`_`*=2
ML*.F0P"G4K"CJ=*_[[[<JKJHK:7WP]&G3[CJKL8`IU*PHZ78JV6JNL3FINP`
MIU*PHZ78JV6JNJ9#`*?SMW.U>Z:A("(E<R(@I'>G4K"C+@"[O+!EKLFVH0!$
M96YM87)K("BDIK/!*0"PW<-$M'FM>@"T>:UZ`++3N&`@*+W0L-&FTB!(;W)D
M92"P3[_]P,FNURDZ`++3N&"]T+#1IM*H=++.NMZR>K5NO_TN`*SCM6\`Q5/"
M2;?%J]<`L\RKX:1`I'"NR:JZQ5/"2;?%J]<Z(`#%4\))M\6KUSH@`+%QI:JF
MW*5K`+%QI6NFW*6J`*78O_T`I4@@,C0@I'"NR:CNQ>.EW#\`Q>.EW+_OMK4`
MQ>.EW+C4LM.JNKEWL_@`Q>.EW+EWL_@@*%1!1BD`Q>.EW*[FIJ$`ML>P9:9>
ML?@`1&II8F]U=&D@**9.I:RF82D`I*.G4K"C`*2CK6ZJO;&UIG.H^B!M86EN
M=&5N86YC92YP:'``LL2D0+6GL$^__:Q/IU^E7:=TQ.:F[*97NMD_(*9PJD>L
M3[W0I,2_[RX`1&]M:6YI8V$@**9HJ?JEIZ5;*0!$;VUI;FEC86X@4F5P=6)L
M:6,@**9HJ?JEIZ5;ID"I3;#J*0#!V:A3IK.Q8KBYMMP_(+7YI54N`*15N/P`
MI%6X_"`E<P"D5;C\LUVI=\#)KM>E=*9SK+`@4$A0(+5[IJ$N`*15J=2E7*_@
MJNT`P\2K?@"Y<:1LMFRE\P"_^;M^`$5C=6%D;W(@**3,I<JF:+JX*0"]<[_H
M`+USO^BPS[;T`+USO^BX<[+5`+USO^C%=JVM`+USO^C%=JVM`+USO^@E<ZJZ
MQ7:MK0"]<[_HO^^VM0"]<[_H(B5S(JJZQ7:MK0"]<[_H)7.JNL5VK:T`L="H
M?`!%9WEP="`HKDJDSBD`16P@4V%L=F%D;W(@*,+$NKBERZ9H*0"DN*7S+BXN
M`+EQI&RV;*7S`+EQI&RV;*7SINVG?0"Y<:1LMFRE\Z;MIWVELK:WIVNF6"X`
MN7&D;+9LI?.]5+M[`$5M86EL+71O+5--4R"Y:+E$OKD`JNVQH;+%N+D`JL6E
MU:M(I?,N`*K%I=6ULJI'+@"JQ:75MVJT3;:UI=@`I+FS7*;;P\"T6;2AI$JW
MTZ3YJ.RK2*7SI*0HNO2MMKUSO&>\TJ:A*2`_`+'2L,JWQKFKI6O!Y*5<K^"J
M[3\`M;*G]*9^I?<`J?&D:KUSO^B^N0"F<*I'IT&[W:UNK:NS7;%+O5@LO="_
MZ:1*I$"MTZ9WI?ZPW:5Y+*C2IG`@)Z=!PV2JJZJZIE>ZV2`_)SH`IF*FN;_I
MI$J\=KFSJKJZ]*=]`$5Q=6%T;W)I86P@1W5I;F5A("BHJKE$M%BDNJC(*0!%
M<FET<F5A("BDS*7?KU.HO:9W*0"_^;M^`*O8I=^PS[;T)7.NR;5OI<V_^;M^
M`*=2L*.F4*A"P>/"23H@)7,@KLFU;Z7-O_F[?@"G4K"CIE"H0K!/O_TZ("5S
M(*[)M6^ES;_YNWX`Q:JH^J2ZKF4Z)7,@KLFU;Z7-O_F[?@"G\[=SL4N]6#H@
M)7,@KLFU;Z7-O_F[?@"\9Z1*("(E<R(@KLFU;Z7-O_F[?BX`17-T;VYI82`H
MMU*H1J6GJ,@I`$5T:&EO<&EA("BFYZ_!I/&HR"D`NMBQV@!%=7)O<&4@*+S:
MK'<I`*A#(#$U(*3`Q,$`J$,@,B"DP,3!`*A#(#,P(*SMQ,$`J$,@-2"DP,3!
M`*A#IKBU;J1*`*A#(#,P(*3`Q,$`J$,@,2"DP,3!`+UDJ-*MR#H`L/6FY@"N
M:;9]`*YIMGVXZJ[&IZ@`K6ZH1"`G*2<`J.RTP:3I`+C1NZ&M^P"K9;2ZPT.F
MX@!&5%`@I%>VQ[-=J7<N`,6JJ/JPOJ9NLUVI=Z6BL=$`M4RJ:[-SO76FW"!,
M1$%0(*;XJD&^N2X`M4RJ:[-SO76FW"!334(@IOBJ0;ZY+@"]QKMSI:*QT:;;
M("(E<R(N`+W&NW.EHK'1J.P@(B5S(BX`M4RJ:ZO8I=^D0*W3MW.JNB!305-,
M(+-SL;4N`+=HLKZEHK'1J.P@(B5S(BX`PEZH^J6BL=$Z("5S`+2VLW$`1F%L
M:VQA;F0@27-L86YD<R"J:\3UITJZUKASKG$@*+"HNKBZ^Z_'M+6X<ZYQ*0!&
M87)O92!)<VQA;F1S`,19K:N_^;M^.@"VQZ]U`+;'KW4`I$>DZP"W4,2Q`+=0
MQ+$Z(`"D\J3RJT(`M76\R+!]L[<`Q.:F[+!]ID,`1FEJ:2`HM+3`V2D`P,FN
MU[S&I=@Z("5S(*W3P,FNUP#`R:[7O,:EV#H@)7,@P,FNUP#`R:[7P6"ZW@#`
MR:[7IE>ZV0#`R:[7O^^^W`#`R:[7I%>VQP#`R:[7I%>VQZ5<K^"EO+-1I.2T
MJ2X`N4S";[ZY`$9I;FQA;F0@**KBQ/4I`*17I6*DZP"D5ZFV`*E4J7>D\:C2
M`*17I%7$0:W+`*]"L,H`P_H`I=B__2`E<R"DHZ9SIF(`IG*KK,-#IN(`K;FJ
MJP"F7:RPPG/$_;ZYJ,.EO*3DM*F\=KFSI5ROX"X`KO"V2+EWL_@@*%1!1BD`
MN7>S^*31O,8@*+EWL_BDT;S&I5VL0:75I-&E2*3.J5VVH:JZN.JNQCNF<*I'
MN7>S^*31O,:X^ZKXL4ZF^Z7.I/&X^[QEM%2JNJJIK;$I`*?1L$^Q2[U8(#\`
MJNVSY@"D<+MY`*1PNWG#_JNL`*1PNWD`I'"[>2`R`+W7OL(`IMNPRL+@JT@`
MK%"TP:2M`*[8K%L`1G)A;F-E("BJ:[#J*0!&<F%N8V4L($UE=')O<&]L:71A
M;@!&<F5N8V@@1W5I86YA("BJ:\3=NURHR*BZ*0!&<F5N8V@@4&]L>6YE<VEA
M("BJ:\3=K,&G4:6GINBHR"D`1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S
M`+%(I?.D2`"Q<0"GN;[CM'FM>@"ZH:3K`*7^IE<`1V%B;VX@**5;M%XI`,/`
MM%DZ`$=A;6)I82`HI<RD\:C(*0"RHZ7-("5S(*W3J'2RSK-=J7<`I'>RHZ7-
MJKJS7:EWN.JNQ@!'96]R9VEA("BS[*IVJ,BF0*E-L.HI`$=E<FUA;GD@*+QW
ML.HI`$=H86YA("BM>Z_'*0!':6)R86QT87(@**J]I:S#N:K[*0"F5[K9`*ME
MJ;D`K?2\=[JX`$=O;V=L92"F8;G/`$=O;V=L92"W:K1-`*;'MJ4`1W)E96-E
M("BGQL.^*0"GQL.^I.4@*$E33RTX.#4Y+3<I`$=R965N;&%N9"`HKN:SKL3U
MKG$I`&=R96YA9&$@**[FM^>OQ[E&*0"X<[+5NMZR>@"X<[+5IE>ZV:2CL6^J
MQ:75`$=R;W5P7VQD87`Z(+5,JFNW<[Q7N'.RU2`E<RX@IOBJ0;ZYIE[`LSH@
M`$=R;W5P7VQD87`Z(+5,JFNG4K"CN'.RU2`E<P!'<F]U<%]L9&%P.B"U3*IK
MI_.W<[ASLM4@)7,`N'.RU0!'=6%D96QO=7!E("BM]+QWK*6TMBD`1W5A;2`H
MP_:N<2D`1W5A=&5M86QA("BERJ9AL*BIU"D`KN:NIJ;HKG$`J-.[J\5VK:T`
MLUBKR*]DJ*4`1W5I;F5A("BT6*2ZJ,@I`$=U:6YE82U":7-S874@*+18I+JH
MR*3QK\&F0*E-L.HI`$=U>6%N82`HNURHR*BZ*0"V5Z3ELW.ULKMYJ*4`I^2D
MHZCL($A45%`@Q>?#TBX`2&%I=&D@**[\IF$I`,+XM.HMNG2ZX@#&1P"J[<!9
M`*KMP%D`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`*1JN7"K
M0@"GQJ="J-.DY2`H25-/+3@X-3DM."U)*0"PJJO7`+NAJ?H`O7._Z+ZYJ,^E
MSKNAJ?H`NZ&I^@"E8K)Y`+-ON,RL3\#)KM>JNK9]J6PZ`+"J`*YA7VT`2&]L
M>2!3964@*+'KO\VIHRD`KF$`INVN8:9AIWT`KF&EV+_]`*;MKF&Y<;C<`$AO
M;F1U<F%S("BGN[.CJ=2TM2D`2&]N9R!+;VYG("BMN[3D*0!(;W)D90!(;W)D
M92]+;VQA8CH@MFRE\R`E,B1S(*2DN4JH[+5,KL2JNB`E,21S(%A-3+CJKL8`
M2&]R9&4O2V]L86(Z(+5,MFRE\[Y!IEBJJZ7S("5S`$AO<F1E+TMO;&%B.B"V
M;*7S("4R)',@I*2GY*2CJ.RJJZ7SJZRZ02`E,21S`$AO<F1E+TMO;&%B.B"D
M=Z:HI5RJNK*^L*,@)7,@(B5S(@!(;W)D92]+;VQA8CH@ON.F6*1UM7N[W:UN
M("=D;VUX;6PG(*JZ(%!(4""IM:;Y`$AO<F1E+TMO;&%B.B"U3*IKJ]BEWR`E
M<R"JJZ7SJKH@6$U,(+[P`$AO<F1E+TMO;&%B.B"U3*IKLKZPHR`E<R`B)7,B
M.B`E<P!(;W)D92]+;VQA8CH@M4RJ:\#RJ/JSH:7W("5S(*NLND&JNB!-24U%
M(,/1IT^XN;U8`$AO<F1E+TMO;&%B.B"U3*IKIE"H0B`E<R`B)7,B.B`E<P!(
M;W)D92]+;VQA8CH@M4RJ:Z90J$*DP*C).B`E<P!(;W)D92]+;VQA8CH@I;RJ
MOJJZI,"HR2`B)7,B`*3TI:V]=0"D]*6MN=2E4@"D]*6M.@"G0:9PIO.H[*:Y
M(#\@*+W0L=2M>B$I`*=!K6ZF6*C6IFBDUJW3Q.:F[*E//P#$YJ;LO,:EV*9`
MK7`_`*=!K6ZF6*C6IFBDUJ9#J4\_`+?#J]<`M\.KUSH@`+?&O5VD:JYV`$AU
M;F=A<GD@**9)I/JG42D`24U!4""V;+UCJ]BEWZ6BL=$Z("5S`$E-05`@MFR]
M8Z=2L*.EHK'1.B`E<P!)34%0(+9LO6.ZS[K0L'2X;:O8I=^EHK'1.B`E<P!)
M4""F[*=]`$E0(*;LIWVU3*IKJ,^ESBX`25`@INRG?:C#I*.F8B!#2412(*JZ
MI+FS7+#/MO2DI"X`IF*KX:VQM*&D2J9#7VX`26-E;&%N9"`HID*N<2D`K\*Y
MSZ7<`"5SJKJYSZ7<`+G/I=RDSJ3EIG(`J*VE]\/1IT^JNJ97NMDZ`*9PJD>U
M3*IKI;^]5*9AQ>.EW"P@)7,@I4BE=+9]L=*V;*7SJ?.W<[7XM:&W[:2D+@"H
MSZ7.($EN=&5R;F5T($5X<&QO<F5R(,)SQ/V^N:[)IG"J1ZA3IK.LW:CLI?2F
M\ZJZI'"YSZ7<+""G0:5IK^"[W:UNI,2_[[-OK=.VM:78I4C#]K.L(%!.1R"\
M=KFSJKK!],+#KL2J1RX`IG"J1ZS=J.RS;ZMHJ%.FL[QVN;.JNK!4KJ<LLV^J
M[:7<IT&JNL)SQ/V^N;5,JFO%XZ7<I%>VQZJZO':YLRX`O':YL[EWQ/TZ`+QV
MN;.Z]*=]`+QVN;.Z]*=].@"\=KFSJ-.FV\/`M%D`O':YLZC3IMO#P+19.@"D
M5[;'O':YLP"\=KFS`+;7I$HL(*A"QDH@)60`MM>D2L3FINPZ("5S`+;7I$K$
MYJ;L.@"F8JOAK;&TH:1*ID-?<P"_Z:1*I*.EO[U4JKJG0*7.O5@N`+W0P,NL
M9*=!JKJHSZ7.JLRF5[K9I,ZQ2[U8`*C/I<ZJS*97NMFDHZ6_O52ISJK,N7&D
M;+9LI?.F[:=]I'?%W*?S+KW0P7"UN*=!JKJH=++.NMZR>JW[I4BH\Z=5LT*R
M>BX`O%>E6\%9L<8`26YD:6$@**9,J]<I`*W3IT^HSZ7.JLP`26YD;VYE<VEA
M("BF3*6G*0"XZK!4`+CJL%0`M4RE::7.JKJXZK!4+@"F8JOAK;&TH:1*Q.:F
M[%]O`+2AI$JYSZ3Y`+2AI$JJ[:[F`+2AI$JZ]+CTLW.UL@"F8JMEK;&TH:1*
MQ.:F[%]#`*9BI=BK9<3FINRKX:VQM*&D2J1`K=.W<\3FINP`IF*EV*MEQ.:F
M[*MEK;&TH:1*I$"MT[=SQ.:F[`"F8J78JV6F0ZOAK;&TH:1*I$"MT[=SID,`
MIF*EV*MEID.K9:VQM*&D2J1`K=.W<Z9#`*9BI=BK9;A@PDFKX:VQM*&D2J1`
MK=.L<;BH`*9BI=BK9;A@PDFK9:VQM*&D2J1`K=.L<;BH`+2AI$JE:;3`I4Z\
MRZI/`+=SL4N]6+%.L4BU;ZCLLV^MT[9LI?.F8:=].@"F8JOAK;&TH:1*P'BF
M<Z[F`*9BJV6ML;2AI$K`>*9SKN8`IF*KX:VQM*&D2L3FINP`IF*K9:VQM*&D
M2L3FINP`M*&D2K9LI?,`IF*KX:VQM*&D2JQQN*@`IF*K9:VQM*&D2JQQN*@`
MIF*KX:VQM*&D2J9#`*9BJV6ML;2AI$JF0P"F=Z7^L-VE>:JZM:JNUSH`M*&D
M2B_%W*?SO':YLP"TH:1*+\7<I_.Z]+CTLW.UL@#"2;S&I*.HK*5(IMRI\[5,
MJFNVQ[!EM;FP=+AMN'.RU2X`PDF\QJ2CJ*PN`+[CO,8`ON.\QJ9#`+5,KL2J
MNB!51$@HJ,^ESJK,N.JNQJKMP%DI+@"U3*[$JKH@6DE0(+CJKL8N`+5,KL2J
MNL"SI<ZU>Z:A+@"U3*[$JKJGY::XN+F]6"X`L&6E6*JZN.JNQK5,KL0N`+5,
MKL2JNJ78O-"F[:=]`+5,KL2JNL#)KM>NYJ:A`+5,KL2JNK'"Q7:]6"X`M4RN
MQ*JZIF&PSRX`M4RNQ*JZ(&US9U]T>7!E+@"U3*[$JKJISJ?DI*.H["!A<&E?
M:60N`+5,KL2JNJG.I^2DHZCLL-&\QBX`M4RNQ*JZI/?%=JVM+@"U3*[$JKJY
MV:;QP]&G3[U8+@"U3*[$JKJRHZM^O5@N`+5,KL2JNK-QL%2H\ZEW+@"U3*[$
MJKJFK*7SI$@Z(B5S(@"U3*[$JKJDP*C)JJNE\RX`M4RNQ*JZJ-.WO:;MIWTN
M`+5,KL2JNKA5L.J]6+CJKL8N`+CJLJ,`IEZT7[_OOMP`27)A;BP@27-L86UI
M8R!297!U8FQI8R!O9B`HI>RNU"D`27)A<2`HI>RIU*=**0!)<F5L86YD("BW
M4KJXQ/4I`$ES;&4@;V8@36%N("BPTJYQ*0"GO;.AN7"K0@!)<W)A96P@**5(
MIN*F0RD`P[&U;ZK,`+'7Q>D`271A;'D@*+AQI&JG42D`2F%M86EC82`HI/JV
M4J5;*0"D0*3K`$IA<&%N("BDZ:6[*0"DZ:3E("A)4T\M,C`R,BU*4"D`OT&F
MZ*YQ`$IO<F1A;B`HK/FEN2D`I$.DZP"DNZ3K`+GON_0`N&VDI`"EJJ5KN>^[
M]`"^8:6JN>^[]`"^8:5KN>^[]`!+87IA:VAS=&%N`*M/KV2M[+S+(#\`2V5N
M>6$@**K6J,@I`$ME<F)E<F]S(+M[P]*_^;M^+@"NUJ3?MW.DX@"J]\9?J]BE
MWP"J]\9?KU.\>`"J]\9?JOBKUP"J]\9?JZRZ00"J]\9?NWFJ:P"EV*MEJKJD
MO;9]JO?&7Z;XJD&^N:2D+*1WN&>F<Z9BIT&JNJKWQE\N`*C@M:,`2VER:6)A
M=&D@*+#RJ+VDVK2U*0!+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U
M8FQI8R!O9B`HI5_!^BD`2V]R96$L(%)E<'5B;&EC(&]F("BK;L'Z*0#!^J3E
M("A%54,M2U(I`$MU=V%I="`HK.RKPJ]3*0!+>7)G>7IS=&%N`*JIK;&P=+AM
M7WD`NWFHI0!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R`HO&2P
MZBD`I%6E8J3K`+/,JO&D0*:XL4N]6,7<I_.I\P"D5:FVI.L`I%>FN*?SMW,Z
M`*17I$"FN+5NI$HZ("5S`*17I$"FN+5NI$HZ("5S(*;;("5S`*17I$"FN+5N
MI$HZ(++$I$"FN+5NI$H`3&%T=FEA("BIU++FNONHR"D`JFNKWP"JJ:VQL'2X
M;0!,96)A;F]N("B^I*3:N>`I`*6JP^0`I:K#Y*KMP%D`I:K#Y*W(`$QE<V]T
M:&\@*+_@K\&FJRD`3&EB97)I82`HO^"D\;?GJ,@I`$QI8GEA;B!!<F%B($IA
M;6%H:7)I>6$@**=1I/&HR"D`3&EE8VAT96YS=&5I;B`HID.DY+2PM+6U;BD`
MMTRK0@"D<*M"`*:MIK.D<*M"`+'?IK.D<*M"`*1PL'VK0@"D<*M"IK.Y<`"D
M<+.W`*1PL'VSMP"EM*ION-8`LW.UL@"S<[6RPDFH[#H`Q>.EW*[)LW.ULK9L
MI?.F[:=]J.R]<[QGMFRE\ZVVK;$`LW.UL@"F0Z58("T@J,^ESJK,I6FE2*S=
MJ.RS;ZW3JTBE\Z=8`*9#I5BXZJ[&KG<`ID.E6+NAJ?J\T,-$`*9#I5BJ[:[F
M`+!1O=>X<[+5+<#)KM?"9`"P4;W7N'.RU2VH1*=5`+!1O=>X<[+5+</1IT^X
MN;U8`+!1O=>X<[+5+;[6IK.JS`"P4;W7N'.RU2VQ2*7SI$@`L%&]U[ASLM4M
MK7&^7`"P4;W7N'.RU2VH^J[XK7&^7`"F0Z58MWRTP:6BL=$Z("5S`*9#I5BH
MSZ7.JLREHK'1.B`E<P"F0Z58J,^ESJK,JKJE7*_@LU'#]K.L`*3EOL<`3&ET
M:'5A;FEA("BEW[.SJ7LI`+C\I$JDI"XN+@"W[:9AKLFVH3H@`*9AL,^[4*[)
MMJ$`IF&PSP"U;J1*`+5NI5@`M6ZD2@"U;J1*I'6G0`"U;J1*I:*QT2P@O=#`
MRZQDN]6D5:JZI<ZDX:97J4VQ2[U8+""U3:OAK:NXU2X`M6ZD2J6BL=$N`*KX
MI7D`MU*QH0"G0P"D<+QGI\;#OKS&IG(`I'"\9ZG4I$*\QJ9R`*1PO&?#N;"H
MO,:F<@!,=7AE;6)O=7)G("B_8[3+L_DI`*3K`*A#I.FP5*ZG`$U3+51.148@
MJOZE6\#)KM>DI*A3IK.XZJ[&+@!-4T<`36%C86\@*+]$JODI`$UA8V5D;VYI
M82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B`HL*BHY+EYID"I
M3;#J*0!-861A9V%S8V%R("BPJ+E&I5NTM:5;*0#%7;-.`+9LI?,`MFRE\[K>
MLGH`J]BEW[-SM;)?:RXN+@!-86QA=VD@*+"HJ=2KPBD`36%L87ES:6$@*+"H
MJ-.FZ*C(*0!-86QD:79E<R`HL*BZN*9AI-(I`$UA;&D@*+"HIU$I`$UA;'1A
M("BPJ+JXI4PI`+K>LGJG0:JZI,##_BRHPZ5"K+"DP,/^LUVI=\-#IN(N`$UA
M<#(T(*9AN<\`36%P475E<W0@IF&YSP"D5*3K`,/DK,D`O-"P3Z:H(*S=N4PO
MI;RLW;E,`+S0L$^FJ*CDI4RJNL/1IT\@**C2IG`N(*VKK6XOI'>F7L+0*0!-
M87)S:&%L;"!)<VQA;F1S("BPJ*Y,NKBX<ZYQ*0!-87)T:6YI<75E("BPJ+2C
MI:>G2JYQ*0"DQ[!TQ.:F[*2D`$UA=7)I=&%N:6$@**U4IU&V\*6GJ,@I`$UA
M=7)I=&EU<R`HO*^HO:;HM+4I`*2YLURJNK/,I&K"2;S&+@"J_J7SO,:EV*1W
MME>E6*2YLURD5ZVM+@"SS*KQ(#(T(*1PKLFJNK/,L*JWQ:O7.B``L\RJ\2`V
M(*1PKLFJNK/,L*JWQ:O7.B``L,^V]*17K:V\QJ78`*2YLURSS*1JJOBKUP"D
MK:3K`$UA>6]T=&4@*+"HK/FO4ZYQ*0#"Y;['`*:HK?L`O^^SYKS2IJ$Z`*98
MJ-;`>*9SKN8`MFRE\P"V;*7SQ>?#TJ1WI[FFJ"RF_:Q/J,^ESJK,JKK#L;.Y
MJV^U3*IKLW&Y3,7GP](N`,*RL%2D=[E,M,$N`,*RL%2KK+I!`$UE=&%R(+#/
MMO2U3*IKJ,^ESBX`365T87(@L,^V]+5,JFNHSZ7.+B"RT[A@O="PT:;2J'2R
MSKK>LGJU;K_]+@!-971A<D1"(*E\I;RS<[&U+@"DZ*IK`*3HJFL@(B5S(B"E
MO+-1J7>X<0"DZ*IKI;RI=[AQ+B"E2*E)I7.DZ*IK.B`E<P"DO:CN`$UE>&EC
M;R`HOJ6FZ*WT*0!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F("BQ
M2Z=*P[FEIZ;HJ,@I`*2DMJ$`36EM92"KK+I!`+/,JO$@,C0@I'"NR:JZL\RG
M0[?%J]<Z(`"SS*KQ(#8@I'"NR:JZL\RPJK?%J]<Z(`"SS+5UL4N]6*[$M,&I
M?*6\J.RTP0"L3:YG`,+XMK4`I^2DHZCL(%!%05(@I5VXRR!(5%107U)E<75E
M<W0N`+-=J7?`R;_RI:(N(*9PJD>M;JC/I<ZS;ZW3P+.ESK5[IJ&G0:6RMK>R
M>Z9BM$ZRHZ7-I4PN`*?DI*.H[,*RL%2JNB!)1"X`I^2DHZCLI;*VMZJZ(%!%
M05(@I5VXRR!-86EL+@"GY*2CJ.RW?+3!JKH@240N`*Q0M,&D0`"FYK#*MFRE
M\P"WQ:E-`*?SMW.DZ;3!`*W7I^^Z]*=]`+S2LM4`36]L9&]V82P@4F5P=6)L
M:6,@;V8@*+RONKBF:*7+*0!-;VYA8V\@*+ROK\>M]"D`36]N9V]L:6$@*+M8
MI6HI`*3KI,ZF?@"H0Z3K`+M8MNNIU*]3`*3KK-L`IF*RQ"5DIN:GY*CLJKK$
MYJ;LO,:EV*1WME>E6+EWM,$E9"X`O*^LI:WT`*9HMK.NR;2X`*9HMK.NR;.Q
M`+2XKLFF:+:S`*15LKX`I:JRO@"E:[*^`*17LKX`I%6RO@"D5[*^`$UO>F%M
M8FEQ=64@*++VI%2D\:=**0"]QK_OIJ&D5:G4I5ROX*KM`+W&O^\`I]JJNK%B
MN+D`I]JJNK%BN+FXZK!4`*W3I$BON*5X`*W3I$BON*5XK;:ML;!TN&T`37EA
M;FUA<B`HO7&H;"D`I*,LI]JDHZ90MTX`IE>ZV0!.86UI8FEA("BHNJ;,I/&H
MR"D`3F%U<G4@*+_5OGPI`$YE<&%L("BEIZIYNK@I`$YE=&AE<FQA;F1S("BR
M_,3U*0!.971H97)L86YD<R!!;G1I;&QE<R`HLOS$W:9WIF&F0[2U*0!.971S
M8V%P92"LL+#RPJ:JNKKTIWT`3F5T<V-A<&4@OLS#TJ=`O&^Z]*=]`$YE='-C
M87!E(+[,P]*L1K6FNO2G?0!.971S8V%P92"G\[=SNO2G?0!.971S8V%P92"G
M0+QONO2G?0!.971S8V%P92!34TP@IOBJ0;ZYIE>ZV0!.971S8V%P92"^S,/2
MJKJU^;C1`$YE='-C87!E(+[,P]*KK+I!`+KTN/2D=:CC`+%QI;P`3F5W($-A
M;&5D;VYI82`HMW.SV*B]IFBEIZC(*0"W<[Q7I,##_@"\9ZM(M;D@)7,`MW.D
MZP"W<ZC/I<ZJS*97NMD@**M$I;*M;BD`3F5W(%IE86QA;F0@**_#INC$]2D`
MMW.Q2[U8`+=SL4N]6+%.J?,E>*CLM,$N`+=SL4N]6*2CLL6F6"X`MW.U^+6A
M("A?8FQA;FLI`+=SNT0`MW.[1+ASLM4`I%6D0*A"`*15I$"MT[_OMK4`I%6D
M0*VV`$YI8V%R86=U82`HI:>E6ZG4I<HI`$YI9V5R("BEIZ3I*0!.:6=E<FEA
M("BI8*3.IU&HR"D`L=^D5P!.:75E("BOPZY*KG$I`*=?`+5,I6FHT<7CI=RN
M=+*GJKJS7:EWN.JNQBX`M4RE::7.JKJUIK*DJ]BS>2!)4T\@O':YLRX`J%.F
MLZ?EIKB\RZ:A+@"ITJO\J7>JNJ;LN&VD5ZA3IK.PS[;TIG.F8@"H4Z:SM*.H
MT:;FJ,:^Y*97NMFE2*C1($U#04P@Q>?#TBX`J%.FL\7<I_,N`+5,JFNF8J78
MJV7%=JVMI*2\5Z5;IKC%=JVM+@"H4Z:SJ_RI=ZJZ("5S(+-=J7>XZK!4+@"H
M4Z:SJ_RI=ZJZ($944"!61E,@LUVI=[CJL%0N`*A3IK.K_*EWJKH@4U%,(%9&
M4[-=J7>XZK!4+@"H4Z:SJ_RI=ZJZ(%-13"U&:6QE(%9&4[-=J7>XZK!4+@"U
M3+/1OFS"2;S&+@"EO+2CJ-&EV*JZ+@#`R:[7I;RD5[;'`*?DI*.H[+G/I=PN
M`*;LN&VXZK!4J7REO+-=J7<`J7REO+2CJ-&F[+AMN.JP5"X`I;RTHZC1PK*P
M5"X`I;RK_*EWIE>ZV2X`I;RK_*EWN+F]6"X`J%.FLZO\J7>Q2[U8I4BHT2!(
M5%10(,7GP](N`*A3IK.K_*EWL4N]6*5(J-$@24U!4"#%Y\/2+@"H4Z:SJ_RI
M=[%+O5BE2*C1($ME<F)E<F]S(,7GP](N`*A3IK.K_*EWL4N]6*5(J-$@3&]G
M:6X@Q>?#TBX`J%.FLZO\J7>Q2[U8I4BHT2!005-35T0@Q>?#TBX`J%.FLZO\
MJ7>Q2[U8I4BHT2!334(@Q>?#TBX`I;R_Z:1*($]P96Y34TP@I$>DN+#UIN;`
MR:JZI?ZX]*Y\+B!02T-3(#$R(+-7KN:JNJ5;L4NXZJ[&N]VM;J7.J.RXT[5[
MIJ$N`*A3IK.KW;QFJKJU^:55I=.]T"X`NL^ZT+!TPT*EO+-=J7<`M4RNYKUU
M`*E\I;RK_*EWQ.:F[*3`N6JF<J2X+@"U3*[8O74`M4RFN<#)KM<`M4R\R*9S
MI=B__:5IJ-&GUJCZ+@"EO+;'L&6HSZ7.JLRF5[K9J<ZQ2[U8+@"U3*5II<ZJ
MNB!834P@N.JNQK-1ML>F7@"JQ:75K<@`K>RI;+-=J7?`R:2DI^2DHZCLJJFE
MN[CJL%0N(*VKMW.RHZ7-LUVI=\#)+@"F8J=!JKJS7:EWP,FDI*?DI*.H[*JI
MI;NXZK!4+B"MJ[=SLJ.ES;-=J7?`R2X`M4P`M4P@*'5S92!I;7!L:6-I="D`
MI.FFU;#2I.4@*$E33RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N9"`HO]6ZUJ=*
MKG$I`*5?I6*R>0!.;W)T:&5R;B!-87)I86YA($ES;&%N9',`3F]R=V%Y("BN
MOZO"*0"K1*2GJ^$`JT2DIZME`*2CK$^D0*W3I=B__0"U>Z:AJ7REO*>YIJ@N
M`*2CLUVI=P"EO+-1I.2TJ0"SQJ?1O_T`J%.FLZ5IPG/$_:JZ+*9>I6@N`*11
MI$"DZP"\QJ9R`*9RI+B\Q@"F<J2XO&6KUP"FYKS&`*?SMW.P=+AMN'.RU:[)
MI;RK_*EWO,:EV"X`3TL`JJNE\P"JJZ7SJ]BEWZK,`*1+MFFF[`"D4:3K`+_L
MI+VKQP"W<[%+O5BELK:WNU#"PK%+O5BDHZ90+@#"PK%+O5@`PL*Q2[U8I*.E
MO[U4`$]M86X@**K\L-(I`*5UIK,@24U!4""F^*I!OKFDY+2IJTBE\Z=8I,"H
MR:5<K^`N`*5UI+FS7*1`K=.V;*7SINVG?2X`I76FL[[6IK.JS+M0J'2RSKK>
MLGJM^Z5II4C%W*?SID"HR<5VK:T`IF*W<ZJZM?BUH;9]L=(`3W!E;E-33""_
M^;M^.B"U3*IKL7$@4R]-24U%(,.QL[FJ_J7SN-&V?;CJKL8N`*9BMW.JNK7X
MM:&V?;'2LW.UL@"G0+=^J'2RS@"_[[:U`"5SO^^VM0"VM:78O7.XN0"RU<*T
M`++5PK2SYJ;L`++5PK0`K>RI;,"SI<ZU>Z:AO,NJ3P"F8B`E<SH@I*2JNJWL
MJ6R\RZI/+@"HY*5,`*CDI4RXZK!4`+[6IK.JS,5VK:T`4$%-(,7GP]*U3*[$
M+@!014%2.CJV;*7SIOBJ0;K=`%!'4""\QJ;LP[&SN0!01U`@I5NQ2[CJKL8`
M4$=0(*2]MGVJ]\9?`%!'4""D=\.QL[DOI'>E6[%+(+CJKL8`4$A0(+5[IJ&]
M6`!02%`@K_.]6@"DR*OAI'"K0@"DR*OAL'VK0@"DR*OAIK.SMP"DR*OAL'VS
MMP"DR*OAM+@`I,BKX;EPJT(`4$]325@@97AT96YS:6]N(+_RI:(`4$A0(*_S
MO5I?2`"YU*52`%!A:VES=&%N("BDVK#RM+6I6BD`4&%L874@**FMKULI`%!A
M;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960@**3:L,>TM:E:ION[XK#/
M*0!086YA;6$@**3:KK.PJ"D`4&%P=6$@3F5W($=U:6YE82`HI-JEK*C(MW.T
M6*2ZJ,@I`%!A<F%G=6%Y("BDVJG4IF,I`*9HMK,`L4N]6`"Q2[U8Q=RG\Z>Y
MIJ@N`+%+O5BDHZ6_O50`J%.FLZO\J7>Q2[U8I4BHT2!2041)55,@Q>?#TBX`
ML4N]6+U4NWL`L4N]6#H`L4N]6#H@`+%+O5BELK:WIVNF6"X`MDND5P"V2Z17
M`+CTKGP`J]V\9K5NO_VA1P"FJ*W[`*;*I,"D\0"P]:;FNOO%0+[>IT``M6ZD
M2JOAL/6FYKK[Q4"^WJ=`/P#%=JVM`"(E<R*JNL5VK:VEO+-1IU*PHRX`IG.H
M^KY$J=H`Q7:MK0#%=JVMNMZR>@"GVJJZ`%!E<G4@**^UOGPI`,-DJJL`4&AI
M;&EP<&EN97,@*+7AJ]^[JRD`N7&XW`##P+19`%!I=&-A:7)N`+FSK\``O="V
M::1*P'BF<Z[FPDF_[P"]T+U4J7>M;K*^L*.FN:2XI?,Z`+W0O52I=Z=!K6ZD
MI,)?IKFDN*7SJKJS<[6R+@"]T+_II$JD0*W3I.NE]Z3.IGZE]RX`O="_Z:1*
MMW.\5Z3`P_ZJNJ97NMDZ`+W0O^FD2J1`K=.FLZ[$JKH@25`@INRG?0"]T+_I
MI$JD0*W3IK.NQ*JZI.FTP3NDQ+_OIKFDZZ7WJKJDZ;3!+@"]T+_II$JD0*W3
MIK.NQ*JZKLFVH2X`O="THZC1L-W#1*JZNDNM;BX`O="_Z:1*IT&JNJC/I<ZJ
MS*97NMFDSK%+O5@`O="^7,6JI%6F0Z2ZKF4NIT&ELK:WIE"W3K-OJ,>HQK:U
MI'ZOX*C/I<ZH=++.+@"]T+_II$JW<ZJZI,##_J97NMDZ`%!O;&%N9"`HJFG$
M]2D`K$:J=@"GZ[*\`%!O<G1U9V%L("BXLK7EI/HI`+QVN;.F[+AM`*KMKN:F
M[+AM`+N\L&6V;*7SJ.RS;ZW3JTBE\Z=8("AN;W0@96YF;W)C960@8GD@24U!
M4"D`L\RJ\2`E<R"D<*[)JKJML*M"MG$Z(`"ML*M"/&)R("\^OO>R=@!0<F5F
M<U]L9&%P.B"GY*2CJ.RITKO=K6ZJNB!,1$%0(*FUIOFN3:7S+@!0<F5F<U]S
M97-S:6]N.B"GY*2CJ.RITKO=K6ZJNB!S97-S:6]N(*FUIOFN3:7S+@"N\,"C
M`*[\I:VML:[PP*,Z(`"N\,"C.B``N7?$_0"F8K=SJKJU^+6AN7?$_;QVN;,`
MI%>D0*W3O^^VM0"F0Z9,I.6E\P"H<+%+JO?&7P"PW<-$`+#=PT2T>:UZ`+%-
MKM<`M*.EW*2ZKF4`I+VV?:KWQE\`I+VV?:KWQE^Z=+KB`*2]MGVJ]\9?N.JP
M5`"DO;9]+ZAPL4NJ]\9?N>^HPZ6\LU&RHZ7-+@!0=65R=&\@4FEC;R`HJFFF
M:+ZDIE4I`%%A=&%R("BE9+E&*0"L9+C?`+K/NM"P=+AM`%)302"DO;9]JO?&
M7R`H)60@INRDN"D`O^^^W+9S`*M"`*:MIK.K0@"QWZ:SJT(`L'VK0@"K0J:S
ML[<`JT+"X+.W`,!(OO>D<+MY`*3QLG8`Q:JH^@#%JJCZMFRE\P"O=:JZK6ZG
M4K"C("5S(+;</R"S;[:UOMZG0+%.M4RJ:ZOLM%\N`*]UJKJM;K)-L*.HSZ7.
MJLP@)7,@JKJXZJ[&MMP@/R"S;[:UOMZG0+%.M4RJ:ZOLM%\N`*CZKOBT7ZWL
M`*VKMW.^X[)Z`*VKMW.^X[)ZL,JZ0:78O_VDN*7S.@"MJ[=SON.R>JW3I$BO
MN*5XI+JN93H`L6"S5ZKMI=RFH0##]L%PPG/$_;ZY`*VKQ:H`M?N]UP"[M[K=
MIOBJ0;ZY`+NWNMVZ]*=]("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E
M*3H`LKZPHP"ROK"CL,^V]`"ROK"CQ.:F[`"E:+"CKN:FH0"ROK"CN>\`IMNF
M^*I!OKF\R*9SI=B__:2DLKZPHZ1WP'BF<ZJZLUVI=[5[IJ$N`+*^L*,`IMND
MY:7SI*2ROK"CIKFD0+A@PDD`LKZPHZC/I<ZJS`"ROK"CJ,^ESJK,.B`E<P"[
MW:A$I;RS4:9>P+,Z(+_YNWZXN;U8.@"GY*2CJ.RITKO=JKJJ0;#(+@`E,B1S
M(*JZLUVI=Z6RMK>K_*EW("(E,21S(@!61E,@JKJS7:EWI;*VMZO\J7<@(B5S
M(@"S7:EWN.JNQJ6RMK>K_*EW("(E<R(`I;*VM\3FINP`K:NS70"MJ[-=L4N]
M6`"MJ[-=IT&JNK%+O5@Z`*9>IG.SS*OAI$"MTZQDN-\`M;*J1P"J\*9>O^^V
MM0"F0::XO^FD2K=SL4N]6`!2975N:6]N("BO9*6GJ?2N<2D`IEZT7[-=J7<`
MNO2MMKUSO^B^N;_OMK4`P;R[>0"E:\/D`*5KP^2J[<!9`*5KP^2MR`"F0Z2Z
MKF5?=RXN+@"HI*;B`%)O;6%N:6$@*,.YL*BEIZC(*0"QV\+@(#$X,""KUP"P
M9J[)L'<@.3`@J]>QV\+@`+:VKLFP=R`Y,""KU[';PN``ID.DNJYE`*9#I+JN
M90"F0P"NYKUU`,3FINR[4*9#KN:]=0#$YJ;LKN:]=0"F0Z[FO74`L/6FY@!2
M=7-S:6%N($9E9&5R871I;VX@**M8P[FTM2D`4G=A;F1A("B_8Z9WN48I`%,O
M34E-12"E6[%+P[&SN0"V;*7SI'>HSZ7.(%,O34E-12"E6[%+`%-!4TP@Q>?#
MTK5,KL0N`,*RL%0`N.JNQJYWK_.]6@"E6[%+LM>ZW;[W`*:HI5P`N.JNQJYW
MK_.]6E]1`*Q0M,&DNP!386EN="!(96QE;F$@*+ATNZZPQZ_'*0!386EN="!+
M:71T<R!A;F0@3F5V:7,@*+ATITJHO;2UIFBZUJ3.I:>Z^[2U*0!386EN="!,
M=6-I82`HN'3%4Z;HJ,@I`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I
M;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,@*+ATI.6TRZ3.KN:WYZBZ
MI$(I`*90I$"MT[7XM:$@*%]S96QF*0!386UO82`HPL2\KZC(N'.N<2D`4V%N
M($UA<FEN;R`HN'2PJ*=1O]4I`%-A;R!4;VUE(&%N9"!0<FEN8VEP92`HN'2F
M:*S\I,ZTMJI,INBD\2D`O<.L4+2CJ-&JS`!3875D:2!!<F%B:6$@**A&KU&F
M8:K\J=2G0BD`P'BF<P#`>*9S("(E<R(`P'BF<R`E<P#`>*9SO^^VM0"Q3K*C
MI<VJNK-=J7?`R:5((%!(4""[>:BEKN:FH<!XIG.H[*=!JKJF^*I!OKF\R*9S
MI=B__:2D+@"S7:EW("5S(*1WP'BF<RX`I_.W<[5[IJ&D=\!XIG.H[#H@(B5S
M(BX`N7.L4+EPJT(`K.R^QP"W:K1-`+=JM$VDWL"Z`+_OOMS`R:[7`+_OOMRD
M0*W3I.FTP0"_[[[<I$"MT[ASLM6ESJ5(MW.\5P"_[[[<I$"F[+=SJKJ^UJ:S
MJLP`O^^^W*1`LZ&F^*I!OKD`O^^^W*1`INRHSZ7.JLRESJ5(MW.\5P"_[[[<
MJ=*FLP"_[[[<J=*FLZ3IM,&DN*7S+@"_[[[<I$"MTZJKI?,`I*._[[[<`*GS
MI4BD5:JZM?BUH:2DO^^H^J=!K6ZJNJ9RI+@NI4BWQKFKO<:[<ZG2O^^DY:9R
M++5-J^&V2Z17I.6E\[USO^BPSRX`O^^^W*3IM,&DP+EJ.@"_[[[<I.FTP:3I
MM,&NYJ:A.@"_[[[<L?W%W*?SJKJHK:7WP]&G3SH`O^^^W*[)MJ&DP+EJ.@"_
M[[[<I.FTP:[)MJ&NYJ:A.@"_[[[<K-NDK*3'L'2JNJ1'K=/$YJ;L+@"_[[[<
MIT&JNL-#IN*P=+AM`+_OOMRPOJ9NNWFHI3H`ML>P9;#=PT2DS\"S`+;'L&7"
MLK!4`%-E;F5G86P@*+;KI+JE6[JX*0"W4+3ZOKDZ(`"D1:3K`%-E<F)I82!A
M;F0@36]N=&5N96=R;R`HMNNZN+K[J,B[4+M8KU.EIZWTP[DI`*?'N+D`IOBJ
M0;ZYN.JNQK_YNWZISJK,M4RJ:ZC/I<XN`+=\M,&ZWK)Z`+=\M,$@240@I'>Y
M3+3!+@"W?+3!`*[6J/JDZ+;T`*2YLURG0:GSI]&P3[%+O5BJNJ[)K=0LI6FE
M2*;;IN:MJ[-=L4N]6"X`LUVI=[NWNMVF^*I!OKFD5\3=J?.G0:JZK=.D2*^X
MI7@N`+-=J7>G0:JZL+ZF;KMYJ*4L(*[)L,^E2*3.I.FTP:[FIJ$N`+-=J7>G
M0:JZL=*I;,"SI<ZU>Z:A+,-#IN*P=+AM+*VVK;&G\[=SP%>R=BRDSJCDI4S%
MXZ7<O^^VM2X`LUVI=P"G\[=SM7NFH;1.NOP`IK.F;K18K=.F8<))J4VS;ZW3
ML-&\QJ:SP_8Z(`!397EC:&5L;&5S("BVZZGUNK@I`,'*JJL`PK*U=;I+K6X`
MK$^G7ZRPI&JSH:7WJKJS<[6RJ7>X<:?6L;:E7*_@P>0_`,7CI=P`Q>.EW+=S
MLJ.ES;M0K>S`>*9SLUVI=\#)JKJN=+*G+@"H0Z:XM6ZD2JOAQ>.EW*17I$"F
MN*JZM6ZD2J[)MJ$@/P#%XZ7<PDF_[[ZY`,7CI=RJ[:[FOMZG0*5<K^"J[2`_
M`*GSI:K#Y,7CI=P@)7,@I5ROX*KM/P#%XZ7<P'BF<Z[FI+JN9;GON-RDZ+;T
M`,7CI=RJ[:[FI+JN9;GON-RDZ+;T`,7CI=RF0Z2ZKF6Y[[C<I.BV]`#%XZ7<
MO':YLZ2ZKF6Y[[C<I.BV]`#%XZ7<I%>VQP"K^<3RL'VK0@"FK::SL'VK0@"Q
MWZ:SL'VK0@"[MZ3HIK.P?:M"`*:LP5D`4VEE<G)A($QE;VYE("BWX*1LI'.P
MZBD`M?FE50##L;.Y`,.QL[FZ=+KB`%-I;F=A<&]R92`HMW.E6ZE9*0"D:J1P
M`+*DN4RZ^\5``%-L;W9A:VEA("BTM:REI>^G2BD`4VQO=F5N:6$@*+2UK*6E
M[Z6GJ,@I`+.W`+!]L[<`L'VSMP"FK::SL'VSMP"QWZ:SL'VSMP"_;K.WLF"K
MUSH@`%-O;&]M;VX@27-L86YD<R`HK\'#N:KYN'.N<2D`4V]M86QI82`HK\&P
MJ*=1J,@I`+IQNU"XU@"QQJ9#I.BF5K_OOMP`J-.WO:9AIWT`4V]U=&@@069R
M:6-A("BK;JM$*0"K;KS:("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N
M9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P"K;J5BLGD`JL6EU:;F`+:A
MMEH`MJ&V6KM0N=2E4@!3<&%I;B`HINBO6J3Z*0"I5:>CMFRE\P"O4Z[MIG*D
MN+_II$H`I,"SSL!XIG,`I,"SSL3FINP`I,"SSJ9#`+E"L,H`4W)I($QA;FMA
M("BTM:B]Q/6E9"D`O-"WQP"L4+O:JJ?%4;[4`+'2J6RF?J7W`*S9`*JLND$`
MP'BF<Z[FIJ$`M?.Y1`"G4K"CO74`IG*FZJ9#`*;;MFRE\Z9AIWVDI*5HL*.Z
M]+#LIE>ZV0"\RZ:A(%M#4U-=`*Q0M,&DT0"GY*2CJ.RFN*78O_T@(B5S(@"E
M1*:N`+!EI5@`O%>E6R`B)7,B(*CLJ'2RSJJZI=.]T*1WL&6E6"X@IT&ELK:W
MM:6H[+C3I=.]T+-1KM:MXZOAI'ZOX+5NI$HN`*15O-``IJBE7`"FJ*5<JKJE
M6Z1*("(E<R(@J.RH=++.I*0N`*:HI5RJNJ;;J'2RSJ2DLDVPHZC/I<ZJS"`B
M)7,B(*JZN.JNQBX`(B5S(J1WIU*PHZ>YIJ@N`*:HI5RJNJ;;J'2RSJ2DLKZP
MHR`B)7,B+@"D=Z:HI5RJNJ9>M%^S7:EW+B"]T*VKMW.X_*1*P,NU^*YTLJ<N
M`*1WIJBE7*JZL\:E][-=J7>XZJ[&+@"D=Z:HI5RJNK/&I?>S7:EWN.JNQB`E
M<RX`IJBE7*JZI_.W<R`B)7,B`*1WIJBE7*JZPM"\9R`E<P!3=61A;B`HQ*RD
MIBD`NDNM;@"DZ:58`*3IN*@`M+@`I.FE6`"DZ:58+Z3IN*@`I.FE6#H@`*3I
MN*@`I.FXJ#H@`*17O-``I.2TJ0!3=7)I;F%M92`HQ*RG4:MN*0"Z[[BY`%-V
M86QB87)D(&%N9"!*86X@36%Y96X`4W=A>FEL86YD("BE=J7+P-G$]2D`4W=E
M9&5N("BWYZCE*0!3=VET>F5R;&%N9"`HM^>D:"D`IE"H0K!/O_VD=Z=2L*,`
MIE"H0J;FL,JXR[AM`+=JM$VVM:78I*2JNKMYJFN_^;M^`%-Y<FEA;B!!<F%B
M(%)E<'5B;&EC("BQU*=1J,@I`+EPJT(`N7"K0J:SK;<`N7"K0@"FK::SJ_G$
M\KEPJT(`5$%"(*3`N6JNYJ:AP,FNUP"J[;/F`*KMKN:DNJYE`*KMKN:DNJYE
M`*5XQE<`I7C&5P!486II:VES=&%N("BV\*9.M+6I6BD`5&%N>F%N:6$L(%5N
M:71E9"!297!U8FQI8R!O9B`HJ5JI?*6GJ,@I`*78O-`Z`*O=O^RHQK:U`+EQ
MN-RXN;U8`+/,JO&D0*1PKLFJNK?%J]<Z(`"WQ:O7`+?%J]<Z(`"WQ:O7/&)R
M("\^*"5SL*HE<R\E<Z=#)7,I("9D96<[)7,`I^2DHZCLO,NJ3R`B)7,B+@"\
MRZI/NMZR>@"DNJYE`*_"I.6F<@"Y[[OTI.6F<@"Y[[OTI.6F<K.[NMT`K%"T
MP:5\`*[UI.4@*%1)4RTV,C`I`%1H86EL86YD("BN];#J*0!&5%`@J;6F^2AE
M>'1E;G-I;VXIM4RNQ"X`2&]R9&4O2V]L86(@ON.F6*1UM7NHPZ6\I.2TJ2`B
M)7,B`$E-4U`@K/:__;5,JFNS4:KLJ6PN`$UA:6YT96YA;F-E(,/^IT^HPZ6\
MIJBE7+C\I$H`O^^VM;7XM:&E2,/VLZPNPO>V?:2D+@"G0:JZJ'2RSKK>LGJM
M^Z6RMK>E_;-=J7>F;J1`K=/%=JVMJ^&ZW:1^K^#%_:=!J,^ESL5VK:VH=++.
M+@"ILZ[8O74`P7"UN+BYO5BEO*O\J7<LJL6EU:G.IF*XZJ[&KG>DI*?DI*.H
M["X`I'>FJ*5<JKJQ3L%PM;BD2+=SO%>FW+-QL%2__:2D+@#%Y\/2MFRE\\.Q
ML[F[W:UNIK.D0*W3I'>XT;9]JKH@4$=0(+#/MO0N`+!TN&VX<[+5JKK#T:=/
MN+F]6"A)1"FDHZQ/I;RK_*EW++1.K$^JQ:75J<ZJS*2CIF*XZJ[&KG>DI"X`
ML'2X;;ASLM6EO*O\J7<N`+O=K6ZD0*W3N&>Y3*5;L4NJNKKTN/2S<[6R+@#`
MR:[7("5S(,"SN-.E7:=TI$"MTR`E<R"S7:EW+@#`R:[7("5S(,"SN-.E7:=T
MI$"HQR`E<R"S7:EW+@"U3*IKO<:[<ZCLIMNHK<#)KM<N`*:YP,FNUZ2DJ%.F
ML[CJKL8N`*5(I%6L3R!R9F,X,C(@MFRE\ZJZJNW`62X`J*VE]\/1IT\@)7,@
MI'>S4:=2L*,N`*6JKMB]=0!';G501R"D1Z2XP,FJNKCTKGRELK:WJ7>X<:9B
M($-R>7!T7W!G<#HZ(,/^IT^DI"X`IT&TOZGS("5S(+%(M;D@)7,@I$"KRJ5$
MIJZLL"`B)7,B(*JZJTBE\Z1WLU&V?;'2+@JF_;-OJ,.DHZ_@JT_#TKC3JTBE
M\ZJZI+JN9:1WI[FE_K-1IJRE\Z1(K-VGN:G.I$:XT2X`LW.ULJCLO7.\9[9L
MI?.MMJVQJ=*HSZ7.JKJF5[K9`*6RMK>L3Z1`K=.\QJ9R+@!(;W)D95]#<GEP
M=%]S;6EM93HZ(,/^IT\LI;*[W:UNIK,@;W!E;G-S;""\TK+5+@"FN;"^IFX@
M(B5S(B"XZJ[&IEVLL+97N4RSS*1JI+FS7*W(+*G2I4BU3*IKLU'`>*9S`*7.
MI4C`R[7XIKFXZJ[&P_ZKK"`H)7,I(*JZM7NFH:C#I*.F<Z9BJ?.H=++.I%<N
M`*3>K7JF<J6RMK>LL+/FI$"F<J2X+@"EJJ5KKMB]=0"E:Z[8O74`Q.:F[*3`
MN6JF<J6RMK>LL+/FI$"F<J2X+@"FN:;XJD&^N2`B)7,B(*1WLU&G4K"C+@"F
MN:;XJD&^N2`B)7,B(*1WLU'`>*9S+@`E<R"JNK7YI56[W:A$I'>S4;*^L*,N
M`*O\J7>JNK!/O_VHPZ2CIG.F8BX`O,BF<\#)KM<B)7,BI*.F<Z9B+@"G0:G2
MO^FD2JJZN.JNQKM0M66ML;CJKL:DH[+%+@"D5Z15KMB]=0"D5Z[8O74`L7&D
M5Z1`K=.H0L9*I*>KX:17ML>JNKCJKL:_\J6B+@"D5[;'P,FNUZC#I;RS4<!X
MIG,N`'=E871H97(N8V]M(+#/MO2U3*IKJ,^ESBX`I^2DHZCLO,NFH;!TN&VE
MV+_]("(E<R(N`+5,I6FESJJZO^^VM2X`M4RJ_J7SI6FJO;&UMGVQTBX`IKG$
MYJ;LI*2E7:=TI-.F:*JZIG*\QBZG0:1WO^FD2B`E<R"MTZ9RO,8[IT&_Z:1*
MJKJF<KS&I;*VMZ1PJ?,@)7,N`+=SO%<@(B5S(B"H[*ATLLXZ("5S(*[)M6^E
MS:1`K=.PW<-$+@"FVZATLLZR3;"C("(E<R(@JKJXZJ[&KLFU;Z7-I$"MT[#=
MPT0Z`*;;J'2RSK*^L*,@(B5S(B"NR;5OI<VD0*W3L-W#1#H`I_.W<R`B)7,B
M.B`E<R"NR;5OI<VD0*W3L-W#1`"D5[;'P,FNUZ[)M6^ES:1`K=.PW<-$.B`E
M<R"EO+-1I%>VQRX`I%>VQ\#)KM>NR;5OI<VD0*W3L-W#1#H@)7,@I&JD<+97
MN4RDN;-<L\RD:JW(("@E9"!B>71E<RDN`*17ML?`R:[7KLFU;Z7-I$"MT[#=
MPT0Z(+;(LZ&DP*JZ("5S(,#)KM>S4:17ML<N`,#+M?BV;*7SKLFU;Z7-I$"M
MT[_YNWXN`+;7I$JFN;-QL%2__;CJKL:NR;5OI<V_^;M^+@"VUZ1*(&E#86QE
M;F1A<B"XZJ[&KLFU;Z7-I$"MT[_YNWXN`*9BLUVI=ZKML^:DI+5OI<VD1J1`
MK=._^;M^+J:SI6FOX*=!O_*Z?*1&I;*VM[;QO&>JNL3FINPN`+#UIN:S<;!4
MO_VK_*EWI5ROX*[)M6^ES:1`K=._^;M^+B"]T+5YJ^&F0;C5I$"FN"X`I_.W
M<\%PM;BD2+CJKL:NR;5OI<VD1J1`K=._^;M^+B"]T+5YJ^&F0;C5+@"G\[=S
ML'2X;;ASLM6NR;5OI<VD1J1`K=._^;M^+B"]T+5YJ^&F0;C5+@"FN2!)34%0
M(*;XJD&^N:C#I;RDY+2IJTBE\Z=8I,"HR:5<K^`N`+-OIORE1Z2CK$^EO[U4
MJKH@<F%R(,"CP5G`R:[7+@"S;Z;\I4>DHZQ/I;^]5*JZ('II<"#`H\%9P,FN
MURX`LV^F_*5'I*.L3Z6_O52JNJM(I<ZE9+BYO5@N`*:YQ.:F[*Q/I;*[W:UN
MJKHN`*:YQ.:F[*2ZKF6E=:2YLUR^X[S&O,:F<BX`IKG$YJ;LI+JN9:5UI+FS
M7+S&IG*DSJM?N+DN`*:YQ.:F[*2ZKF6E=:2YLURD2[9IINR\QJW(+@"FN<3F
MINRDNJYEI;*VMZRPLW*XN:G.JL6EU:3`N6JJNKS&IG(`I;*VMZQ/I$"MT[S&
MIG(N`*:YQ.:F[*2ZKF6ELK:WI5VG=*1`LM6D4:2[MFFF[*JZ(%)'0B##0Z;B
MI4Z]6"RHTJ9P("<C,3(S-&%F)RX`LV^MTZKML^:D=[-1LT*R>KE,+@"S;ZQ/
M("5S+@"S;ZQ/($MO;&%B(+ASLM6JNJ1`K=.JJZ7S+B"Q_<#+M?BFN:JKI?.[
MW:UNK^"DY+2I2V]L86(@N'.RU:[FIJ&JNKEQI&RV;*7SLV[%Z2Z]T+#1IM(@
M)7,@I4BD1KC1LV^HQ[9LI?.S;L7I`+-OJ\JV;*7SJ,.K1*5(IT&Z1*7.JKJF
M<J2XMK"FTZQ/J,^ESB`H)7,I(*[1O&>FTZ:H+@"FN;S&K<BSS*36I;*VMZQ/
M(#$N`*:YIOBJ0;ZYM4RJ:[GO('II<""DSB!G>FEP(*[FIJ'`R:[7MFFFYKC1
MP*/!60"FN:ATLLZEV*MEK$^PL:7.JKJJK+I!+@"ELK:WK$^D0*W3O,:F<BX`
MIKFU^+6AI;*VMZUNI=&_[[:UM?BUH2A/<'1I;VXIJ=*I2:5S`+EP`+#=PT2P
M;,+<`*[)MJ$`KLFVH:O\JVX`KLFVH:[FIJ$`KLFPS[_OOMP`5&EM;W(M3&5S
M=&4`O-##1`"\T,-$("AT;V]L=&EP*3H`IJRE\Z1(`*9PJD>M;KW&O^\LO="F
M8L))O^^WQKFKJKJF4*[)J_8@0V]N=')O;,'D**W3I$BY<;BC*2"ISB!#;VUM
M86YDP>0HQ*NJ1[EQN*,I+@"DM:31`$A434P@K>RI;,#)`%1O9V\@**9HK?0I
M`%1O:V5L874`J?JDT0!4;VYG82`HJD:E6RD`L[NSH0"SS*17O&BNV*Q;("A?
M=&]P*0"D9*B]N4:DSJ:KJ*FM]`"O=:G.L+``K%"TP:1'`%1U;FES:6$@**SP
MI:>FZ*C(*0!4=7)K97D@**1GIM6HY"D`I&>FU:CDI.4@*$E33RTX.#4Y+3DI
M`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU
M("BD9Z7+OGPI`+_II$JG0:JZO^^^W#H@`+6UI7Z]=:O\O,8Z(`"Z]*=]`+KT
MIWTZ`%5G86YD82`HKU&D>KE&*0!5:W)A:6YE("BO4:=*Q/4I`+5,JFNF<ZCZ
M(%9&4R"EV+_]+@"U^:55KLFU3*IKO%>E6\-"I7ZJNJC/I<ZJS+CJL%0N`+5,
MJFNG[\7<(%9&4R#`R:[7("(E<R(@JKK%=JVM+@"U3*IKQ=RG\R!61E,@P,FN
MUR`E<R\E<R"JNL5VK:TN`+5,JFO%W*?SK+`@)7,N`+5,JFO`RZQDP,FNUZ1J
MI'`@(B5S(BX`M4RJ:\#+K&3`R:[7I&JD<"`B)7,O)7,B+@"U3*IKLW.ULB!3
M44P@IOBJ0;ZY+@"U3*IKJ,^ESB!34TP@LW.ULBX`M4RJ:[W&NW,@5D93(,#)
MKM<N`+5,JFNKV*7?(%9&4R"EV+_]("(E<R(N`+5,JFNKV*7?(%9&4R"EV+_]
M+@"U3*IKJ]BEWR!61E,@P,FNURX`M4RJ:ZO8I=\@5D93(*78O_T@(B5S(BX`
MM4RJ:ZO8I=^JQ:75JKH@5D93(,#)KM<N`+5,JFNQ3KCJKL:XT<"CP5DN`+5,
MJFNG4K"C("(E<R(LIKFEV+_]J,.K1*K%I=4N`+5,JFNG4K"C("(E<R(Z("5S
M`+5,JFNG4K"C("5S+*:YI=B__:C#JT2JQ:75`+5,JFN[O+!JIU*PHZ78O_TN
M`+5,JFNG4K"C(%9&4R"EV+_]+@"U3*IKIU*PHR!61E,@I=B__3H@)7,N`+5,
MJFNG4K"C(%9&4R#`R:[7("(E<R(N`+5,JFNG4K"C(%9&4R#`R:[7+@"U3*IK
MIU*PHR!61E,@I=B__2`B)7,B+@"U3*IKN[RP:J=2L*,@5D93.B`E<RX`M4RJ
M:Z=0PE^EV*MEJKJEV+_]+@"U3*IKN-&V?;[,P]*RT[A@`+5,JFNX_*1*)7.J
MNJEWN'$N`+5,JFNW:+*^(%9&4R#`R:[7+@"U3*IKMGVQTB!61E,@P,FNUR`B
M)7,B+@"U3*IKO&>D2B!61E,@P,FNURX`M4RJ:[9]L=(@5D93(,#)KM<N`+5,
MJFNV?;'2P*/!6<#)+@"U3*IKQ:JH^B!61E,@P,FNUR`H9FEL97-I>F4H*2!F
M86EL960I+@"U3*IKQ:JH^B!61E,@P,FNUR`H9V5T1FEL95-I>F4H*2!F86EL
M960I+@"U3*IKQ:JH^L#)KM<Z(`"U3*IKQ:JH^B!V9G-R;V]T(*78O_TN`+5,
MJFNG\Z97("5S(*RP("5S.B"F7:RPI=B\T*M(I?.G6*1WIG.F8@"U3*IKQ=RG
M\R!61E,@I=B__:JZIE>ZV2X`M4RJ:[*^L*,@5D93(*78O_TZ("5S+@"U3*IK
MQ=RG\R!61E,@P,FNUR`B)7,B(*JZIE>ZV2X`M4RJ:\7<I_,@5D93(,#)KM<@
M)7,O)7,@JKJF5[K9+@"U3*IKQ=RG\R!61E,@P,FNUZJZIE>ZV2X`M4RJ:[#U
MIN8@)VUK:7-O9G,G+@"U3*IKPN"TJR!7;W)D(*3EI?,`M4RJ:[QGI$H@5D93
M("(E<R(@P,FNURX`M4RJ:[QGI$H@5D93(,#)KM<@*&-O<'DH*2!F86EL960I
M+@"U3*IKO&>D2B!61E,@P,FNU[CJKL8N`+5,JFN\9Z1*(%9&4R#`R:[7+""Z
MS[K0L'3#0J1WNJ$N`*FSO74`J/JN^*?SI^\`M%^M[`"F^*I!OKFS<[6RKLFU
M;Z7-I;RY=[3!JKJF7L"S.B``M6^ES:6\N7>TP:JZIE[`LRRET:;XJD&^N3H@
M`*6\I,##_@"X5;#JO5@@*%541BTX*0!5;FET960@07)A8B!%;6ER871E<R`H
MJORIU*="P7"F6*1JI+VPZBD`56YI=&5D($MI;F=D;VT@**U>L.HI`%5N:71E
M9"!3=&%T97,@**S\L.HI`%5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@
M27-L86YD<P"SYJ;L`*6\JKZJN@"EO*J^JKH@05!)(+!4KJ>]<[BY("A!4$D@
M365S<V%G92!)1"DN`*6\JKZJNJO(I.&P5*ZGO7.XN2`H05!)($UE<W-A9V4@
M240I+@"EO*J^JKJF[+AMN.JP5"X`I;RJOJJZJ,^ESJK,IE>ZV:G.L4N]6"X`
MI*3"7Z78JV6DN*7SJKJS<[6R`*6\J5*F5P"F7:9WI?[%5;Q[I*.DN;-<I;RQ
MPL5VJKJU>Z:AL/6FYK#%I%4OO<:[<R^V2Z17+B#"2;_OO52I=Z5(P,NU^"!M
M;WII;&QA+F]R9R"ITK2CJ-&JNJS;P_:GWK-.I.6E\RS%_:=!I6FE2+C1L*.F
MN:1`K:VH[JC#IMNFYK9]J?&U>Z:AIG.H^K#%MDO#KRX`J/JN^,-#IN(`I;RD
MY+2IJKJPQL#)IE<`Q=RG\P"G\[=S("5S`*?SMW.HSZ7.JLP`(B5S(J1WI_.W
M<RX`I_.W<[5[IJ&D=Z=2L*,N`*17ML<`I'>D5[;'J=*FL\"SI<ZU>Z:AJKJS
M7:EWP,FH[*;XJD&^N2X`I&J\9ZG4I$*\QJ9R`*1JO&?#N;"HO,:F<@!5<G5G
M=6%Y("BO4:G4IF,I`*C/I<ZEV*MEJKHZ("5S`*C/I<X@4U-,`*9PJD>G0:JZ
MJ,^ESJK,IE>ZV2^Q2[U8NU`@24U34""F^*I!OKFDHZ90+*5IIF*FN;-=J7<N
M`*C/I<ZJS`"HSZ7.JLP@)7,@I;RS<;E,("5S(*JZL<+%=L7GP](N`*C/I<ZJ
MS+K>LGH`J,^ESJK,O^^VM0"HSZ7.JLRU^:55`*:YK[BE>*JZJ,^ESJK,M?FE
M5:ATLLZD=["QI<XN`*?DI*.H[*C/I<ZJS+%BN+D`J,^ESJK,IE>ZV0"HSZ7.
MJLRF5[K9("(E<R(@I'>F<Z9B+@"HSZ7.JLRF5[K9.@"HSZ7.JLPZ(`"H=++.
MI*2JNJC/I<ZJS#H`57IB96MI<W1A;B`HKU&O]Z=/ITHI`%9&4R"EV+_]J,.D
MHZ9SIF(N`+"RM,$`I'>GY*CLIK.NQ*JZIF'"23H@`*:SKL2IR@"E2*3`Q,&L
ML+/FINPHL7&R>Z9BL%^ZXBD`K<@`O^^H^JW(IML`5F%N=6%T=2`HI<NEHZK\
MN<\I`,7<I,8`5F5N97IU96QA("BI9:2ZM^>IU"D`Q>?#TJ6BL=$@+2"FN;9L
MI?.E::_@I'>^1*1(OM6FV[]YI^\N`*JII;L`JJFEN[&QJ.X`JZNJO;GON_0`
MJZNJO;G4I5(`JZNJO3H`JT2Q8+"J`%9I970@3F%M("BV5JMN*0"V5JMNI.4@
M*%9)4T-)22D`P,NU^"`E<P"F8K=SM?BUH;9]L=(`I4@@)7,@P,NU^`!6:7)G
M:6X@27-L86YD<RP@0G)I=&ES:"`HK5[$W;K[J,JX<ZYQ*0!6:7)G:6X@27-L
M86YD<RP@52Y3+B`HK/S$W;K[J,JX<ZYQ*0"OX*BCJ]<`K^"HHZO7.B``N'&D
M:J=1I?&\=ZVWN7&K2*2]I7&S>KE,(%--5%``Q+6G:0#$M:=I(2$A(+%Q("5S
M(*3BL,JROK"CM7NFH2X`5TE.(+AGI=$@2%144`!786QL:7,@86YD($9U='5N
M80#$M:=I`*Q0M,&D5`"DT:[PN7>T^@"N\+9(N.JNQK2CJ-$`=V5A=&AE<BYC
M;VT@NO2ON`"Z]*^X`+KTK[@`J$.V9P#%=ZKO`,5WJN^H["`E<P#%=ZKO+"`E
M<P"FZ+S:("A)4T\M.#@U.2TQ*0"FZ+S:("A)4T\M.#@U.2TQ-2D`5V5S=&5R
M;B!386AA<F$@**;HO+NKHJG4*0"U;J1*J^'`L[C3I?W%XZ7<("5S(*W^I$"M
MT\"SI<ZU>Z:A/P#$YJ;LJKJDP+EJIG*DN#\`I-ZM>JJZJV6X;:9RI+@_`%=H
M97)E:7,@075S=')A;&EA(*9AN<\`K?ZMTZ3KK-L`NO2MMKUSO^B^N:JZM*&E
M\RAP;'5G:6YS*;'2L,JQL:CN+@"\9:O7`*5(($-34R"LL+/FINRJNKQEJ]<`
MI:K#Y"5SI5ROX*KMJKJ\9:O7**15IKBU;J1*J6RES:[$*3H`JNVNYKQEJ]<`
MO&6KU[/FINP`O&6KUSH`MK#%Z;/0IT``K;<`IJVFLZVW`*VWLW0HN&`I`*VW
MLW0Z`*VWLW0Z(`"TO+QZ`+3!J]W"IZJK`*1UIT``O^RDO:O'IF&G?0"_[*2]
MJ\>Y<;C<`++$)62FYJJZQ.:F[+S&I=BDHZ6_O50N(,"SN-.M;J:S)62MT\3F
MINPLI76GY*CL)62MT\3FINPN`,3FINR\QJ78I*.EO[U4+B#`L[C3K6ZFLR5D
MK=/$YJ;L+*5UI^2H["5DK=/$YJ;L+@!8-3`Y=C,@J;6F^:KWQE^[>:IK`%@U
M,#EV,R"E1*:NM,"E3J97NMD`6#4P.78S(*5$IJZJ]\9?P]&G3ZK,`%@U,#EV
M,R"PQL#)IE<`IGX`IGX`66%H;V\@(2"F8;G/`*A#IGX`665M96X@*+BMJODI
M`*Q/`*Q/JKHLI]JF4+=.`*=!I=BK9:C/I<ZOPJ3EIG*]<[QGO-*FH2X@J,^E
MSB!;/#Y=(*OVMG.E::3!M*NLL+KTK;:]<[QGO-*FH2X`I*.DN;-<IT&KV*7?
M)62E2*17JKJPS[;T+@"G0:6\LU&QPL5V+@"G0:JZI?ZF5Z2DI*.E:::S("=<
M)R"S;[S+JKJF<J2X+B``IT&HPZ6\O^FD2J1`K=.FLZ[$JKJY<:1LMFRE\Z;L
MIWTN`*=!J,.EO*71MM>D2JJZP,FNUZ2DN>^L3:7TIO/$YJ;LJ.P@)7,`IT&D
M=[AGM6ZE6"X`O="_Z:1*I$"MTZ:SKL2JNKEQN-RXN;U8++#JN]JY<;C<N+F]
M6+;(I76DN;-<O,:F<KBYO5@LJ,.U^+&AJG"E::GSJV6ML:9!I5ND0*W3("<K
M)RX`IT&ELK:WO^FD2J1`K=.FLZ[$JKJMR"X`IT&ELK:WI?VS5[FZIFZ^\*JL
MN.JNQBA$871A5')E92FF^*I!NMVD?J_@Q'[$\JC/I<ZW<Z7.I.&U^:55JD&P
MR"X`IT&ELK:WI?VS5[FZI$"MT[7JP,#`R:[7J'2RSBA61E,IIOBJ0;K=+@"]
MT+1YK7JPW<-$H4&F8J=!ML>P9;#=PT2S^*=II*>K92X`IT&ELK:WO^FD2J:Y
MLW.ULJG2J_RF5JJZNO2G?0"]T*O\J7>M;J=2L*.JNJ;XJD&^N2X`O="K_*EW
MK6ZR3;"CJKJHSZ7.JLPN`+W0J_RI=ZUNLKZPHZJZJ,^ESJK,+@"]T*O\J7>M
M;K=SO%>JNJC/I<ZJS"X`O="K_*EWK6ZG\[=SJKJHSZ7.JLPN`+W0J_RI=ZUN
ML/6FYJJZIT"ESBX`IT&ELK:WO^FD2K=SI,##_JJZIE>ZV2X`IT&ELK:WM*.H
MT:1`K=.X<:1JIU&YTJ2ZJKJY<;C<N+F]6`"G0:JZ("5S(+=\M,&D=[E,KLDN
MO="MJ[=SM6ZD2BX`IT&JNKEQI&RV;*7SINVG?0"G0:JZL4BE\Z1(N7&D;+9L
MI?.F[:=].@"G0:JZN.JP5`"FV[%QIT&JNB`E<R"W?+3!MGVI;*5(J-.G0:JZ
MNO2[VKKTN/2F[*=]I'?%W*?S+B"LL*M/Q4"G0:JZIG>E_K!?J*.A0:=!I;*V
MMZVKMW.U;J1*+@"G0:JZIE>ZV0"G0:JZQ>?#TJ;XJD&ZW:C#I*.DY+2IMW.\
M5ZC/I<ZJS"X@IG"J1Z=!I\:QYKK>LGJHSZ7.JLRQ8KBY+*=!I;*VMZ5TO^^H
MY*5,JKK%Y\/2IOBJ0;K=+@"G0:JZQ>?#TKK=J,.EO*3DM*FF0Z58J,^ESJK,
MJ<ZXTZ5<K^"D=[-1P_:SK"X`IMNQ<:=!JKH@)7,@MWRTP;9]J6RE2*C3IT&J
MNL)SQ/V^N:;\I4>D=\7<I_,N(*RPJT_%0*=!JKJF=Z7^L%^HHZ%!IT&ELK:W
MK:NW<[5NI$HN`*=!JKK"<\3]OKFHPZ6\I.2TJ;-OK=.E7*_@+@"G0:JZPG/$
M_;ZYJ,.EO*3DM*FF0Z9,O^^VM2Z]T*OV($-44DPO0V]M;6%N9"`K(%`@ID.F
M3"X`IT&EV*MEJ=*S7:EWJKJNR;#/.@"[U:15N7>S7:JZJ*VE]\/1IT^D=\7<
MI_,N`+O5I%6Y=[-=JKJHK:7WP]&G3SH`IT&JNJ7^IE<Z`*=!JKJU;J1*I'>H
M[+3!+@"G0:9B("5S(*2DJKJW<[%+O5BL3SH@)7,`IT&F8K5NI$JTP;:AJKJ_
M[[:UI'>S4:?SMW,N`*=!JKJ_[[:UI'>G\[=S+@"G0:JZL4N]6*1WK:NW<[-=
MJ7<`L4N]6*1WLU&MJ[=SLUVI=RRW<ZJZL4N]6*1WLWJY3+EQI&RV;*7SL4BU
M;[W0I4BXT[%+O5BU;J1*+@"G0:JZL4N]6*1WJ.RTP2X`IT&JNKNWNMVF^*I!
MOKDZ`%EU9V]S;&%V:6$@**MNM+6IU*32*0!:86ER92`HPL2E["D`6F%M8FEA
M("BI?*3QJ,@I`%II;6)A8G=E("BHKZ3:J\(I`%O!],+#I-ZM>ET`6[#=PT2D
MSZQ-70!;Q>.EW*3>K7H@+0!;Q>.EW*3>K7H@+2`E<R"FYET`6Z;LJ?.FYB`E
M<R"F0"`E<R"FYET`NMZR>E]!`*E2I4^F0U]#`+[PJJRXZJ[&7T0`IU*PHZ9#
M7T0`N'.RU5]'`+NAJ?I?2`"\=KFSI+JN95])+BXN`+5NI$I?3`"U;J587TP`
MK=>G[[-SM;)?32XN+@"_[[:U7T\`Q7:MK5]0`+*^L*.Y[[-SM;)?4BXN+@"S
M7:EW7U,`JNVNYJ2ZKF5?5"XN+@"HSZ7.JLQ?50"S<;!4O_T`IN:HQK[D`+5,
MJFNKV*7?O^FE6,#)KM<`M4RJ:[9]L=*_Z:1*`*OVIKD`L4NE3Z9#NWFJ:[_Y
MNWX`LUVI=[_YNWX`O_*EHJVKK6ZJNJATLL[`R:[7`+CJKL:NYJ:AO_F[?@"G
MY*2CJ.RP3[_]`,#)KM<`L7$@)7,@*"5S*2"I\R`E<R`E<P"P?:VW`*[).@"N
MR0"EO*J^JKJV;*7SI42^]Z97NMD`I=^G60"JO;&UQ>.EW*GSI;NDY;#/`+_I
MI$HOO^FE6+_YNWX`I+JSH;-NQ>F_^;M^`*;F70"DP`"F5[K9`*E\I;RYZJ=`
M+@"I?*6\N>JG0"X`L\:GT;_]`*;*I,"D\0"F<ZCZOD2IV@"YLZ_``+-QJTBH
M\ZEWN[>ZW;_YNWX`I%>DR0"U3*5II<ZJNJI!L,@`Q>.EW*YTLJ<`<VUS,F5M
M86EL(+AGI=$@2%144`"L[0##K:EW`*ATLLZ_^;M^`*O=O^S#KP"\R*[)J<JJ
MNJ6BL=$`ID&FN+_II$JG0:JZL4N]6*5(O52[>[5,NWX`ON.F6`"EO*E2IE<`
MJ,^ESJK,O^^^W`!V0V%R9`"L4+3!.@!W96%T:&5R+F-O;2"Z]*^X````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+WIH7U17+VAE
M;'`N>&UL````````````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`R-30P(#$P-3$U-#,S-S0R(#`R,34P-``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/WAM;"!V97)S:6]N/2(Q+C`B(&5N
M8V]D:6YG/2)"24<U(C\^"CPA+2T@)$AO<F1E.B!H;W)D92]L;V-A;&4O>FA?
M5%<O:&5L<"YX;6PL=B`Q+C,N,3`N,2`R,#`V+S`R+S$P(#$T.C`Q.C(S(&IA
M;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED/2)S=6UM87)Y(B!M9#4]
M(C8X8V$S,V8W9C!C.6%A931C,3`S96(T-S0Y,F-D8S$U(B!S=&%T93TB=7!T
M;V1A=&4B/@H\=&ET;&4^I$JD9JVVK;$\+W1I=&QE/@H@/'!A<F$^"B`@LV^M
MTZVVK;&THZC1J=*FL\/VJ?.G0:JZK:O"2;I+K6ZXZK!4H4.HTJ9PH4&EIJ5I
MI4C%XZ7<I5BF8J=!JKJFK*7SO6.DI*78JV6FL[18J\JW<[9LI?.A0Z;FJ,:^
MY*2DIUFQ3JC3J.RJNJC&L:&A0:5.O^S#KZ2DJKJFLZW^J,>KW;_LJ,:VM:%!
MMW.[1*I!L,BJNK/,MW.N^*ZGM:6UI:%#IM.S;ZC'NDNM;J90KLFD7:5=IW2D
M1J?6L;:E7*_@H4'$M*9PMFRE\[QGIT"A0:O8I=^W<ZJZIN:HQK[DJ,:E\[6E
MM:6A0PH@/"]P87)A/@H@/'!A<F$^"B"FT[-OJ,>Z2ZUNJKJDNJYEI6FE2,7]
MIT&X9Z71JJFML;!TN&VK]K9SIMNFYJ9WL<:A0ZC2IG"A0:=!I6FE2+_OOMRM
M;J5;I$JM_J1`J,>VM:78J.RD2J1FK;:ML:2DJ,.QQJ9#J.2VMJ?'H4,*(#PO
M<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB;F%V8F%R(B!M9#4](F(X
M8V8P864Q.64U-V1F83!C,F(Y-C)E-3$V-S@R9C0W(B!S=&%T93TB=7!T;V1A
M=&4B/@H\=&ET;&4^P+.ESK5[IJ&^R<3]ID,\+W1I=&QE/@H@/'!A<F$^"B`@
MIF*MMJVQL\REJL/DJKJD0+'&N<^NU[K9K+#`LZ7.M7NFH;[)Q/VF0Z%#PDF_
M[Z17K;&JNJ7TI$"MTZ1PN<^EW+%.I6F[M*GVI]:S=*JZI,&TJZGSI*.F4*JZ
MP+.ESK5[IJ&A0PH@/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)P
M<F5F<RUD;U]M86EN=&5N86YC92(@<W1A=&4](G5P=&]D871E(B!M9#4](F1D
M.35D9C`W83`S,#,Q,C,R8F%E83DQ.3(X.&(R9#`P(CX*("`@(#QT:71L93ZP
MOJ9NLUVI=SH@NOO%0#H@L/6FYKK[Q4`\+W1I=&QE/@H@("`@/'!A<F$^"B`@
M(""DQ+_OIKFD0+:UI=BA0:9PJD>G0:?&L>:F8K5NI$JJNJ90KLFP]:;FNOO%
M0*1UIT"A0PH@("`@/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)P
M<F5F<RUC;VYF:7)M7VUA:6YT96YA;F-E(B!S=&%T93TB=7!T;V1A=&4B(&UD
M-3TB83(Q,38R8V1F9C-B,60X9F%E861B-S(Y-C(T,#`S-F4B/@H@("`@/'1I
M=&QE/K"^IFZS7:EW.B"Z^\5`.B"]5+M[L/6FYKK[Q4`\+W1I=&QE/@H@("`@
M/'!A<F$^"B`@(""DQ+_OIKFD0+:UI=BA0:9PJD>G0:?&L>:F8K#UIN:Z^\5`
MI'6G0*MEN]VF0::XO'BH1*=!JKJF4+=.H4.G7ZMHJ=*FL[K[Q4"D=:=`L4ZI
M\[5NI$JKX:;;L,JP]:;FH4,*("`@(#PO<&%R83X*("`\+V5N=')Y/@H\+VAE
M;'`^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L;V-A;&4O+FAT86-C97-S````````````````````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,38@,3`U,34T,S,W-#(@,#(P
M-3<Q`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`$1E;GD@9G)O;2!A;&P*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\`
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#`P,#<U-2``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S0S(#`Q-C`W-P`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P;R]F85])4BYP;P``````````````````````````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#$P,#4S,#,@,3`U,34T,S,W
M-#(@,#$W-#<W`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````",@2&]R9&4@4&5R<VEA;B!T<F%N<VQA=&EO;G,N"B,@5&AI<R!F
M:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@
M=&AE($AO<F1E('!A8VMA9V4N"B,@"B,@0V]P>7)I9VAT("A#*2`R,#`T($AI
M9V@@0V]N8VEL(&]F($EN9F]R;6%T:6-S("AW=W<N<VAC:2YI<BD*(R!0<F]V
M:61E9"!B>2`@06UI<FMA8FER($UE=&%N971W;W)K:6YG($QT9"P@,C`P-"`\
M<&5R<VEA;BUH;W)D94!M971A;F5T=V]R:VEN9RYC;VT^"B,@36]H<V5N($YA
M9&5R+4)A9'(@("`@("`@/&YA9&5R:4!M971A;F5T=V]R:VEN9RYC;VT^"B,@
M0VAA8VMA;65H($UO<G1E>F%N:6$@("`@/&UO<G1E>F%N:6%`;65T86YE='=O
M<FMI;F<N8V]M/@HC(%-A;&UA;B!.:6MS969A="`@("`@("`@(#QN:6MS969A
M=$!M971A;F5T=V]R:VEN9RYC;VT^"B,@2&%M960@1VAE>6)I("`@("`@("`@
M("`@/&=H97EB:4!M971A;F5T=V]R:VEN9RYC;VT^"B,@5F%H:60@1VAA9F%R
M<&]U<B`@("`@("`@/&=H869A<G!O=7)`;65T86YE='=O<FMI;F<N8V]M/@HC
M(%IA:')A($%H;6%D:2`@("`@("`@("`@(#QA:&UA9&E`;65T86YE='=O<FMI
M;F<N8V]M/@HC(`IM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R
M<VEO;CH@2&]R9&4@,R!<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`
M;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ
M,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`U+3`W
M+3`X(#$U.C(W*S`R,#!<;B(*(DQA<W0M5')A;G-L871O<CI!;6ER:V%B:7(@
M365T86YE='=O<FMI;F<@;'1D+B`\<&5R<VEA;BUH;W)D94!M971A;F5T=V]R
M:VEN9RXB"B)C;VT^7&XB"B),86YG=6%G92U496%M.B!097)S:6%N(#QI,3AN
M0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#
M;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]551&+3A<;B(*(D-O
M;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(S-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E
M<R!D87ES(&%G;RDB"FUS9W-T<B`B("C8L=F(V+(@V8+8J-F$("5S*2(*"B,@
M(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC
M"B,@"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,W,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B*-JIV83;
MC-BO(-BOV+/8JMBQV+/;C"`E<RDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S<W"B,L('!H<"UF;W)M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB
M"FUS9W-T<B`B*-BOV+$@)7,@V+'9B-BR*2(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(S-S,*;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(B`HV*?9
MA=BQV8C8LBDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<U"FUS
M9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(@*-F!V+'8K]BG*2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S$*;7-G:60@(B`H>65S=&5R9&%Y
M*2(*;7-G<W1R("(@*-BOVXS8L=F(V+(I(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(U-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S8Q"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,#<*;7-G:60@
M(B!A="`B"FUS9W-T<B`B(-BOV+$@(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HR,34*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<
M(B!I<R!N;W0@82!D:7)E8W1O<GDN(@IM<V=S='(@(MN,VJD@V+38I]BNV8<@
MV8;;C-BSV*HB"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<R"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@
M8VAO:6-E+B(*;7-G<W1R("(G)7,G(-BGV8;8JMBNV*?8J"#9A=BYV*K8J-BQ
MVXP@V8;;C-BSV*HB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T
M<GDN<&AP.C8U.0HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN
M<&AP.C$P-#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I
M<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S
M='(@(B<E<R<@V*_8L2#8L=BLVXS8L]BJV+$@V8?9B-BQV*\@V;[;C-JIV+'8
MJ-F&V*_;C"#9AMBTV*_9AR#8I]BSV*HB"@HC.B!F<F%M97=O<FLO5')E92]4
M<F5E+G!H<#HQ-S$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<
M(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B)R5S)R#8I]BL
MV+'8IR#:J=F&V8;8K]F'(-BOV+'8KMBJ(-F^VXS8K]BG(-F&V+38KR(*"B,@
M(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC
M"B,@"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS
M9W-T<B`B7"(E<UPB(-BHV8<@VJ_8L=F(V8?B@(S9A]BGVXP@V+/8I]F%V*?9
MAMF'(-BGV+;8I]F!V8<@V+38KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M
M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+W!E<FUS+V%D
M9&-H:6QD+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S
M(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(EPB
M)7-<(B#8J-F'(-BSV*?9A=BGV8;9AR#9A=BLV8C8LN*`C-F'V*<@V*?8MMBG
MV8'9AR#8M-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E
M(#,I("`C+2,M(RTC+2,*(R`*(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI
M;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M7"(E<UPB('=A<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(EPB)7-<(B#8
MI]N,V*S8I]BO(-F&V+38K]F'(-BHV8C8KSH@)7,N(@H*(R`*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-
M0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B4N
M,F9-0B#8I]BSV*K9@=BGV*_9AR#8M-BOV8<@V*?8LB`E+C)F34(@V878K-BG
MV+(@*"4N,F9-0BDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C,W"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R
M("(E9"`E<R#9B"`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z,C8X(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU-3<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N
M(@IM<V=S='(@(MBGV+/9A2#8L=F%V+(@V+39A=BG("5D(-BQV8C8LB#8K]N,
MVJ_8L2#9A=BYV*K8J-BQ(-BGV+/8JBXB"@HC(",M(RTC+2,M(R`@8V]M<&5N
M9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C@U"B,L('!H<"UF;W)M870*;7-G:60@(B5D
M+61A>2!F;W)E8V%S="(*;7-G<W1R("+9OMN,V+3"K=BHVXS9AMN,("5D+=BQ
MV8C8LMF'(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I
M("`C+2,M(RTC+2,*(R`*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C8X
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B5S
M("T@V*K9B-BLV8<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C<P-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*
M;7-G<W1R("+8I]BKV+$@V*?9AMJOV+38JB`E<R(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C@S,R!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HX,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B
M"FUS9W-T<B`BVJG;C-F$V8C8J-BGVXS8JB`E<R(*"B,@(RTC+2,M(RTC("!C
M;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z('-E<G9I
M8V5S+VUA:6YT96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S
M='(@(B5S(-BYV879A-N,V*?8JB#9AMJOV8?8K]BGV+';C"`M(-BJV*/;C-N,
MV*\B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B
M"FUS9W-T<B`B(-BQV*?9AR8C>#(P,&,[V*?9AMBOV*?8LMN,("5S("(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(E<R#8J]BHV*H@V8;8
MI]F%(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C
M+2,M(RTC+2,*(R`*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4Y"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*;7-G
M<W1R("+8M-BQV8C8MR#8JMF(V*?9@=F"("5S(@H*(R`*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HT,C@@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HT.3`*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV-3$@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B5S(-BGV+(@V8+8J-F$(-F%
MV8C8K-F(V*\@V*?8L]BJ(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ-3D@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C4@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,SD*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#4@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@
M)7,B"FUS9W-T<B`B)7,@V*_8L2`E<R`E<R(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<R!I<R!R
M96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H
M96-K960@8F5L;W<N($-H96-K('1H92`B"B)B;W@@9F]R(&%N>2!O<&5R871I
M;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N(@IM<V=S
M='(@(B(*(B5S(-BBV878I]BOV8<@V*?8K-BQV*?;C"#8N=F%V83;C-BGV*H@
MV8;:K]F'V*_8I]BQVXP@V*?9AMBJV*[8I]BH(-BTV*_9AR#8I]BSV*HN(-BL
MV+G8J-F'(-F'V+$@V+G9A=F$VXS8I]BJVXP@V+'8IR#:J=F'(-F'V84@V*?:
MJ=F&V8C9AB`B"B+9A=N,XH",V*[9B-BGV8?;C-BO(-BGV*S8L=BG(-JIV8;;
MC-BO(-BYV838I]F%V*H@V*C8LMF&VXS8KR(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(S-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q
M=6ER960B"FUS9W-T<B`B)7,@V879B-BQV*\@V8;;C-BGV+(@V*?8L]BJ(@H*
M(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC
M+2,*(R`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R("(E<R#8K]F"VXS9@MF'(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R,PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B5S
M(-F^VXS8K]BG(-F&V+38KR(*"B,@"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@
M)7,B"FUS9W-T<B`B)7,@V*C9AR`E<R#8I]BR("5S(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G
M<R!!9&1R97-S($)O;VLB"FUS9W-T<B`BVJG8JMBGV*C:AMF'V90@V*+8K]BQ
MV+,@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ-`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@(MBJV8+9
MB-N,V84@)7,B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@
M,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDP-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T
M<B`B)7,G<R!.;W1E<&%D(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G
M<W1R("+9@=F'V+'8L]BJ(-F(V+C8I]N,V8$@)7,B"@HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP
M.CDV"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(E<SH@
M)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR
M-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,Z(%1H:7,@;65S<V%G92!M
M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O
M9B!F;VQL;W=I;F<@(@HB86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN
M9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+B(*
M;7-G<W1R("(B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@
M,RD@(",M(RTC+2,M(PHC(`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S8U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,3`*;7-G:60@
M(BP@9W5S=&EN9R`B"FUS9W-T<B`BV(P@V*C8I]BO(@H*(R`C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ.#@@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S='(@
M(MB,(-BHV*?8KR`E<R`E<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Q
M"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T;R`E
M<R(*;7-G<W1R("+8C"#9A=BJV+K;C-N,V+$@V*?8LB`E<R#8J-F'("5S(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR.30@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HS-#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C`V.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3(X"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HW-#D*;7-G:60@
M(BTM('-E;&5C="`M+2(*;7-G<W1R("(@V*?9AMBJV*[8I]BH("(*"B,Z(&QI
M8B]";&]C:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS
M9W-T<B`BV8+8I]F$V*@@V[';LB#8L]BGV+G8JMN,(@H*(SH@;&EB+T)L;V-K
M+W1I;64N<&AP.C$Y"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R("+9
M@MBGV838J"#;LMNT(-BSV*?8N=BJVXPB"@HC.B!T96UP;&%T97,O9&%T82]T
M:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`BV[+;M"#8L]BG
MV+G8JMF'(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0HC+"!F
M=7IZ>0IM<V=I9"`B/%!R979I;W5S(@IM<V=S='(@(MBUV8'8K=F'(-F"V*C9
MA-N,(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3D*;7-G:60@(D$@9&%T
M86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RXB"FUS
M9W-T<B`BVXS:J2#9OMBTV*K;C-BHV*?9AB#8K]BGV*_:K]BGV88@V*C8L=BG
MVXP@V*?;C-F&(-BHV838I]JI(-F%V8C8L=BO(-F&VXS8I]BR(-BGV+/8JB(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38P"FUS9VED(")!(&9A
M=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R("+;C-JI(-BNV+?8I]N,
M(-BLV*_;C"#8L=BN(-BOV*?8K]F'(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.CDS-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME
M>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B
MVXS:J2#:J=F$VXS8KR#8N=F%V8C9A=N,(%!'4"#8J-BQV*?;C"#8L=F%V++8
MJ-F&V*_;C"#;C-JI(-F^VXS8NMBGV84@V879B-BQV*\@V8;;C-BGV+(@V*?8
ML]BJ(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V-0IM
M<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@
M82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`BVXS:J2#:J=F$VXS8KR#8N=F%
MV8C9A=N,(%!'4"#8J-BQV*?;C"#8J-BGV++8J-N,V8;;C"#;C-JI(-F^VXS8
MNMBGV84@V*?9A=BVV*?8H2#8M-BOV8<@V879B-BQV*\@V8;;C-BGV+(@V*?8
ML]BJ(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Y-PIM
M<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*(FUE
M<W-A9V4N(@IM<V=S='(@(B(*(MN,VJD@VJG9A-N,V*\@V+G9A=F(V87;C-B,
M(-N,VJD@VJG9A-N,V*\@V*[8M=F(V+7;C"!01U`@V8@@VXS:J2#8N=BHV*?8
ML=BJ(-JOV+#8L2#8J-BQV*?;C"#8L=F%V++:K]BTV*?;C-N,(-N,VJD@V;[;
MC-BZV*?9A2#9A=F(V+'8KR`B"B+9AMN,V*?8LB#8I]BSV*HB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#$U"FUS9VED("(B"B)!('!U
M8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B
M(@HBVXS:J2#:J=F$VXS8KR#8N=F%V8C9A=N,V(P@VXS:J2#:J=F$VXS8KR#8
MKMBUV8C8M=N,(%!'4"#9B"#;C-JI(-BYV*C8I]BQV*H@VJ_8L-BQ(-BHV+'8
MI]N,(-BGV878MMBGV*$@VXS:J2#9OMN,V+K8I]F%(-F%V8C8L=BO("(*(MF&
MVXS8I]BR(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3`U"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV
M871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R`B"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@HBVXS:J2#:J=F$
MVXS8KR#8N=F%V8C9A=N,V(P@VXS:J2#:J=F$VXS8KR#8KMBUV8C8M=N,(%,O
M34E-12#9B"#;C-JI(-BYV*C8I]BQV*H@VJ_8L-BQ(-BHV+'8I]N,(-BQV878
MLMJOV+38I]N,VXP@V;[;C-BZV*?9A2#9A=F(V+'8KR`B"B+9AMN,V*?8LB#8
MI]BSV*HB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0S
M,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)
M344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B`B
M"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*(MN,VJD@VJG9A-N,V*\@V+G9A=F(
MV87;C-B,(-N,VJD@VJG9A-N,V*\@V*[8M=F(V+7;C"!3+TU)344@V8@@VXS:
MJ2#8N=BHV*?8L=BJ(-JOV+#8L2#8J-BQV*?;C"#8I]F%V+;8I]BA(-N,VJD@
MV;[;C-BZV*?9A2#9A=F(V+'8KR`B"B+9AMN,V*?8LB#8I]BSV*HB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P
M=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S
M86=E+B(*;7-G<W1R("+;C-JI(-JIV83;C-BO(-BYV879B-F%VXP@4R]-24U%
M(-BHV+'8I]N,(-BQV878LMBHV8;8K]N,(-F^VXS8NMBGV84@V879B-BQV*\@
MV8;;C-BGV+(@V*?8L]BJ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z.0HC+"!F=7IZ>0IM<V=I9"`B04T@0VQO=61S(@IM<V=S
M='(@(MBGV*C8L=F'V*<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ,`IM<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R("+8
MJ-BGV+'8I]F&(-BSV*C:J2#8M=BHV*W:K]BGV8?;C"(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"FUS9VED(")!32!286EN
M(@IM<V=S='(@(MBHV*?8L=BGV88@V+78J-BMVJ_8I]F'VXPB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@
M4VAO=V5R<R(*;7-G<W1R("+8L=JOV*C8I]BQ(-BUV*C8K=JOV*?9A]N,(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G
M:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G<W1R("+8JMJOV+':KR#8M=BHV*W:
MK]BGV8?;C"(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED
M(")!32]032(*;7-G<W1R("+8M=BHV*TOV+G8M=BQ(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`P"FUS9VED(")!
M4$D@240B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS
M9W-T<B`BV*_8L=BHV*?8L=F'(-BGVXS9AB#9B-N,V+'8I]BSV*K8I]BQ(@H*
M(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3(*;7-G:60@(D%B;W5T+BXN
M(@IM<V=S='(@(MBOV+'8J-BGV+'9ARXN+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*
M;7-G<W1R("+9OMBGVXS;C-F&(-F%V+?9A-F"(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED9&QE
M(@IM<V=S='(@(MF(V+/8MR#9A=BWV839@B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I
M;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`BV*?;C-BLV*?8KR#8M-BGV*[9
MAR!61E,@V878K-F(V+(@V*_8L]BJV+'8L]N,(-F&V*_8I]BQV*\B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3,V"FUS9VED(")!8V-E<W,@
M9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G<W1R("+8I]N,V*S8I]BO
M(-F^V+'9B-F&V*_9AR!61E,@V878K-F(V+(@V*_8L]BJV+'8L]N,(-F&V*_8
MI]BQV*\B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,PIM<V=I9"`B06-C
M;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R("+8I]BWV838I]BYV*?8JB#8K=BS
MV*?8J"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-0IM<V=I9"`B06-C
M;W5N="!087-S=V]R9"(*;7-G<W1R("+8I]BSV84@V+'9A=BR(-BMV+/8I]BH
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDS"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`BV*W8L]BG
MV*@@V878L]BOV8C8KR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M,S,*;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T<B`BV*W8L]BGV*C8K]BGV+';
MC"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30X('1E;7!L
M871E<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V%D9&-H:6QD+FEN8SHQ,0IM<V=I9"`B061D(@IM<V=S='(@(MBGV+;8
MI]F!V8<@VJG8L=BOV88B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI
M;B]G<F]U<',N<&AP.C(R-0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S
M='(@(MBGV+;8I]F!V8<@VJG8L=BOV88@VJ_8L=F(V8<@V8'8L=BYVXPB"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDX(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S
M:6]N(@IM<V=S='(@(MBGV+;8I]F!V8<@VJG8L=BOV88@V878K-F(V+(@V8'8
ML=BYVXSB@(PB"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM<V=I
M9"`B061D($AE<F4Z(@IM<V=S='(@(MBGVXS9AMBLV*<@V*?8MMBGV8'9AR#:
MJ=F&.B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP
M:'`Z,C$Y"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S='(@(MBGV+;8I]F!
MV8<@VJG8L=BOV88@VJ_8L=F(V8<@V*S8K]N,V*\B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z.#@*;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO;B(*;7-G<W1R("+8
MI]BVV*?9@=F'(-JIV+'8K]F&(-F%V*S9B-BR(-BLV*_;C-BO(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z-PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB
M(@IM<V=S='(@(MBGV+;8I]F!V8<@VJG8L=BOV88@VXS:J2#:K]BQV8C9AR#9
M@=BQV+G;C"#8J-F'("<E<R<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!P
M97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R("+8I]BVV*?9@=F'(-JIV+'8
MK]F&(-N,VJD@V878K-F(V+(@V8'8L=BYVXP@V*C9AR!<(B5S7"(B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S
M='(@(MBGV+;8I]F!V8<@VJG8L=BOV88@VXS:J2#:J=BGV+'8J-BQ(-BLV*_;
MC-BO.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HU-30*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`BV*?8MMBGV8'9AR#:
MJ=BQV*_9AB#8L]BJV8C9AB(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M961I="YI;F,Z,S0*;7-G:60@(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R("+8
MI]BVV*?9@=F'(-JIV+'8K]F&(-BGV+G8MMBGVXP@V*S8K]N,V*\B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@<&%I<B(*
M;7-G<W1R("+8I]BVV*?9@=F'(-JIV+'8K]F&(-BRV8C8K"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D
M('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S='(@(B#8
MI]BVV*?9@=F'(-JIV+'8K]F&(-JOV++;C-F&VJ_8I]F&("5S(-BHV+G9AMF(
MV*?9AB#9AMF(V*?8L2#8K-BGV8;8J-N,(-F%V8C8LMN,V838IR(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW,0IM<V=I9"`B
M061D('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`BV*?8MMBGV8'9AR#:J=BQ
MV*_9AB#8J-F'(-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS.B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW.`IM<V=I9"`B061D
M('1O(&UY(&%D9')E<W,@8F]O:R(*;7-G<W1R("+8I]BVV*?9@=F'(-JIV+'8
MK]F&(-BHV8<@VJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@V879AB(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R("+8I]BV
MV*?9@=F'(-F#V+'8K]F&(-JIV*?8L=BHV+$B"@HC(",M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]U
M<V5R+G!H<#HW.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB061D
M960@7"(E<UPB('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D
M9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`B"B(E<RXB"FUS9W-T<B`B
M(@HB)R5S)R#8J-F'(-BSV*?9A=BGV8;9AR#8I]BVV*?9@=F'(-BTV*_8C"#8
MI]F%V*<@V8;9A=N,XH",V*K9B-BGV88@V*?8M]F$V*?8N=BGV*H@V*_;C-JO
MV+$@V*?9@=BJV*K8I]BM(-BMV+/8I]BH(-BQV*<@V*?8MMBGV8'9AR#:J=BQ
MV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M
M(RTC+2,M(PHC(`HC.B!S:6=N=7`N<&AP.C0U"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A
M;B!L;V<@:6X@;F]W+B(*;7-G<W1R("(G)7,G(-BHV8<@V+/8I]F%V*?9AMF'
M(-BGV+;8I]F!V8<@V+38KRX@V*?:J=F&V8C9AB#8M-F%V*<@V87;C.*`C-BJ
MV8C8I]F&VXS8KR#9B-BGV+'8KR#8M-F(VXS8KR(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@
M9&ES86)L960N(@IM<V=S='(@(MBGV+;8I]F!V8<@VJG8L=BOV88@VJG8I]BQ
MV*C8L=BGV88@V8'8N=BGV80@V8;;C-BSV*HB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-S,@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,30T,0IM<V=I9"`B061D<F5S<R(*;7-G<W1R("+8HMBOV+'8LR(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,SD*;7-G:60@(D%D9')E
M<W,@0F]O:R(*;7-G<W1R("+:J=BJV*?8J-J&V8?9E"#8HMBOV+'8LR`B"@HC
M(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M
M(PHC(`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M-`IM<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H
M97(@=7-E<G,B"FUS9W-T<B`BV+/8L=F^V+'8L]BJ(-BSV*?9A=BGV8;9ART@
MV*K8N=N,VXS9AB#9A=BLV8C8LMF'V*?;C"#:J=BGV+'8J-BQV*?9AB#8K]N,
MVJ_8L2(*"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ.2!S97)V:6-E<R]P;W)T86PO
M<VED96)A<BYP:'`Z,3$S"FUS9VED(")!9&UI;FES=')A=&EO;B(*;7-G<W1R
M("+8L]BQV;[8L=BSV*K;C"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS-#$*;7-G:60@(D%D<R(*;7-G<W1R("+8JMBHV83;C-BZV*?8JB(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-38*(RP@9G5Z>GD*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@
M(MBSV*?8LMF%V*?9AB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*(RP@9G5Z>GD*;7-G:60@(D%L
M8F%N:6$B"FUS9W-T<B`BV878N=BGV*_9A"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*(RP@9G5Z
M>GD*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`BV878N=BGV*_9A"(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*;7-G:60@
M(D%L:6%S(@IM<V=S='(@(MF%V+G8I]BOV80B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$V"FUS9VED(")!;&EG
M;B(*;7-G<W1R("+8JMBQV*?8LB#:J=BQV*_9AB(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N
M=#HB"FUS9W-T<B`BV*K8L=BGV+(Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C@W"FUS9VED(")!;&PB"FUS9W-T<B`BV8?9A=F'(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS
M9W-T<B`BV*K9A=BGV87;C"#:J=BGV+'8J-BQV*?9AB#8JMBCVXS;C-BO(-BU
MV838I]BMVXS8JB#8M-BOV8<B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S(&%D
M;6EN+V=R;W5P<RYP:'`Z,C(R"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S='(@
M(MF'V879AR#:K]BQV8C9A^*`C-F'V*<B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.CDQ(&9R86UE=V]R:R]097)M<R]097)M<R]D871A=')E
M92YP:'`Z-S4*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R("+9A]F%
MV8<@V878K-F(V++B@(S9A]BG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED
M97,B"FUS9W-T<B`BV8?9A=F'V90@VH;9A]BGV+$@V+/9A=BJ(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,0IM<V=I9"`B06QL;W<@;75L=&EP
M;&4@861D<F5S<V5S(@IM<V=S='(@(MBGV*S8I]BRV8<@VH;9AMBO(-BBV*_8
ML=BSVXPB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,T"FUS9VED(")!
M;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R("+8
MHMN,V*<@V*?8K-BGV++9AR#8JMF&V+C;C-F%(-F&V8C8N2#9@=F'V+'8L]BJ
M(-F%V+'8JMBH(-BOV*?8K]F'(-BTV8C8K]B?(@H*(SH@9G)A;65W;W)K+T1A
M=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS9VED(")!;')E861Y(&5X
M:7-T<R(*;7-G<W1R("+8I]BR(-F"V*C9A"#9A=F(V*S9B-BO(-BGV+/8JB(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C,*;7-G:60@(D%L=&5R;F%T
M92!)35-0($QO9VEN(@IM<V=S='(@(MF(V+'9B-BO($E-4U`@V*S8I]N,VJ_8
MLMN,V88B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`W"FUS9VED(")!
M;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R("+8I]BSV84@V+'9A=BR
M($E-4U`@V*S8I]N,VJ_8LMN,V88B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#DY"FUS9VED(")!;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G<W1R
M("+9AMBGV84@VJG8I]BQV*C8L=N,($E-4U`@V*S8I]N,VJ_8LMN,V88B"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS-0IM<V=I9"`B06QT97)N
M871E(&5M86EL(&%D9')E<W,B"FUS9W-T<B`BV*+8K]BQV+,@V;[8L]BJ(-BG
MV83:J=BJV+'9B-F&VXS:J2#8K-BGVXS:K]BRVXS9AB(*"B,Z(&%D;6EN+W1E
M;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM
M<V=S='(@(MBGV83:K]F(XH",V8?8I]N,(-BLV*?;C-JOV++;C-F&(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C(*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS9W-T<B`BV878JMF&
M(-BLV*?;C-JOV++;C-F&.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N
M(%-A;6]A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z.34@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,34*;7-G
M:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB"FUS9W-T<B`B
MVXS:J2#9A=F"V*_8I]BQ(-F&V*?8K]BQV+/8JB#8JMBYVXS;C-F&(-BTV*_9
MAR#8J-F(V*\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38W
M"B,L(&9U>GIY"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D
M+B(*;7-G<W1R("+;C-JI(-BNV+?8I]N,(-BLV*_;C"#8L=BN(-BOV*?8K]F'
M(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%N9&]R<F$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YG;VQA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3<*;7-G:60@(D%N9W5I;&QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X
M>2(*;7-G<W1R("+9OMN,V+3:J=BGV+$B"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@(MF^V*?8L]BN
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN
M<&AP.C,U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3@@=&5M
M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC
M871I;VXB"FUS9W-T<B`BV*C8L=F&V*?9A=F'V93B@(P@VJG8I]BQV*C8L=BO
MVXPB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI
M8V%T:6]N($QI<W0B"FUS9W-T<B`BV8'9A]BQV+/8JB#8J-BQV8;8I]F%V8?B
M@(S9A]BGVXP@VJG8I]BQV*C8L=BOVXPB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,30P"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T
M<B`BV*C8L=F&V*?9A=F'(-BBV878I]BOV8<@V*?8L]BJ(@H*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O($-H:6QD
M(%-H87)E<R(*;7-G<W1R("+8I]BYV878I]F$(-BHV+$@V+'9B-N,(-BGV+38
MJMBQV*?:J=F'V*?;C"#9@=BQV+G;C"(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(MBJ
MV+79B-N,V*@B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HX,S,*;7-G:60@(D%P<')O>&EM871E(%-I>F4B"FUS9W-T<B`BV*?9AMBO
MV*?8LMF'(-BJV8+8L=N,V*C;C"(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!<')I;"(*;7-G<W1R("+8HMF(
MV+';C-F$(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S4*;7-G:60@(D%R
M86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R(")!<F%B:6,@*%=I;F1O=W,M
M,3(U-BDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C4Y(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C8*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,0IM<V=I9"`B
M07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`BV*?9AMBOV*?8LMF'(-F^V+'9
MB-F&V*_9AR#8HMBQV+3;C-F((@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HU."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C8U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#`*;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R("+9AMBGV84@V*+8
ML=BTVXS9B"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E
M9"YI;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO
M=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B
M"FUS9W-T<B`BV*+;C-BG(-BTV878IR#9A=BWV878IMF&VXS8KR#:J=F'(-F%
MVXSB@(S8KMF(V*?9A]N,V*\@V*?8M]F$V*?8N=BGV*H@V*?9@=BJV*K8I]BM
M(-BMV+/8I]BH("5S(-BQV*<@V;[8I]JI(-JIV8;;C-BOV)\B"@HC(",M(RTC
M+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O
M(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R("+8
MHMN,V*<@V+39A=BG(-F%V+?9A=BFV8;;C-BO(-JIV8<@V87;C.*`C-BNV8C8
MI]F'VXS8KR`G)7,G(-F((-BJV878I]F%(-BRVXS8L2#:K]BQV8C9A^*`C-F'
MV*?;C-BT(-BQV*<@V*W8L-F!(-JIV8;;C-BOV)\B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS
M9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B
M07)M96YI82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W
M-@IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B07)M96YI
M86X@*$%235-#24DM."DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*
M;7-G:60@(D%R="(*;7-G<W1R("+9A]F&V+$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED
M(")!<G5B82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@07)T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM
M<V=I9"`B07-I82]086-I9FEC(%)E9VEO;B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#(U"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA
M=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS
M9W-T<B`BV*+;C-BG(-F"V*C9A"#8I]BR(-BYV879A-N,V*?8JB#9AMJOV8?8
MK]BGV+';C"#8J-BQV*?;C"#8JMBCVXS;C-BO(-BBV88@V+/8IMF(V*?9A"#8
MM-F(V*_8GR`B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$S"FUS
M9VED(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS9W-T<B`BV*?9AMBJV+/8I]BH
M(-BSV*K9B-F&V8?8IR(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@
M(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G
M<W1R("+8L]BYVXP@V*_8L2#8K=BPV8$@VJ_8L=F(V8?;C"#8M-BOV8<@V*?8
ML]BJ(-JIV8<@V879B-BLV8C8KR#9AMN,V+/8JB(*"B,Z(&%D;6EN+W!E<FUS
M+V1E;&5T92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N
M+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(MBSV+G;C"#8K]BQ(-BM
MV+#9@2#9A=BLV8C8LMN,(-BTV*_9AR#8I]BSV*H@VJG9AR#9A=F(V*S9B-BO
M(-F&VXS8L]BJ(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*;7-G:60@
M(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*
M;7-G<W1R("+8L]BYVXP@V*_8L2#9B-N,V+'8I]N,V+0@V878K-F(V++;C"#8
MM-BOV8<@V*?8L]BJ(-JIV8<@V879B-BLV8C8KR#9AMN,V+/8JB(*"B,Z('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I9"`B071T96UP="!T;R!E
M9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R("+8L]BYVXP@V*_8
ML2#9B-N,V+'8I]N,V+0@V*?8M-BJV+'8I]JIVXP@V+38K]F'(-BGV+/8JB#:
MJ=F'(-F%V8C8K-F(V*\@V8;;C-BSV*HB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C8T(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-S$*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HX-@IM<V=I9"`B071T<FEB=71E<R(*;7-G<W1R("+B@(S9B-N,
MVIC:K]N,V8?8IR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,#@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`BV*+:K]F(V+/8JB(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4Y"B,L(&9U>GIY"FUS9VED(")!=7-T<FEA(@IM<V=S='(@(MBBVJ_9
MB-BSV*HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,38X
M"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G-Q;#H@V*C8L]BW(-F%V8C8
ML=BO(-F&VXS8I]BR($E-05`@V;[;C-BOV*<@V8;8M-BO(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED(")!=71H7V-Y<G5S
M.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N
M(@IM<V=S='(@(D%U=&A?8WER<W%L.B#8L]BGV878I]F&V8<@V;[8M-BJVXS8
MJ-BGV88@V8+8I]BHV83;C-BJV8?8I]N,(-F%V8C8L=BO(-F&VXS8I]BR(-BQ
MV*<@V8;8K]BGV+'8KR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N
M<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H:6UP.B#8J-BSV+<@V879
MB-BQV*\@V8;;C-BGV+(@24U!4"#9OMN,V*_8IR#9AMBTV*\B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U=&A?9G1P
M.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!0
M2%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B
M075T:%]F='`Z(-BHV+/8MR#9A=F(V+'8KR#9AMN,V*?8LB!&5%`@V;[;C-BO
MV*<@V8;8M-BO(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HV
M-`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:6UP.B#8J-BSV+<@V879B-BQV*\@
MV8;;C-BGV+(@24U!4"#9OMN,V*_8IR#9AMBTV*\B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I
M<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]K
M<F(U.B#8J-BSV+<@V879B-BQV*\@V8;;C-BGV+(@:W)B-2#9OMN,V*_8IR#9
MAMBTV*\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,P,@IM
M<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E
M9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C,U-PIM<V=I9"`B075T:%]L9&%P.B!2
M96UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER
M96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z-C,*;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VQD87`Z(-BHV+/8MR#9
MA=F(V+'8KR#9AMN,V*?8LB!,1$%0(-F^VXS8K]BG(-F&V+38KR(*"B,@"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@HB075T
M:%]L9&%P.MBGV+;8I]F!V8<@VJG8L=BOV88@VJG8I]BQV*C8L2`E<R#9A=F%
MVJG9AB#9AMN,V+/8JBX@V*?;C-F&(-J&VXS8LMN,(-BGV+/8JB#:J=F'(-JI
MV*?8L=BSV*?8LB#:K]F!V*K9AR#8I]BSV*HB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H
M7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R(")!=71H
M7VQD87`ZV*W8L-F!(-JIV*?8L=BHV+$@)7,@V879A=JIV88@V8;;C-BSV*H@
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S
M97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.MBHV+'9B-BRV+'8L]BGV8;;C"#:
MJ=BGV+'8J-BQ("5S(-F%V87:J=F&(-F&VXS8L]BJ(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HT,#4*;7-G:60@(D%U=&A?;&1A<#H@57!D
M871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C
M=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L
M+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;6-A;#H@V*C8L]BW(-F%
MV8C8L=BO(-F&VXS8I]BR($U#04P@V;[;C-BOV*<@V8;8M-BO(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U
M=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B075T:%]S;6)A=71H.B#8J-BSV+<@V879B-BQV*\@V8;;C-BGV+(@
M<VUB875T:"#9OMN,V*_8IR#9AMBTV*\B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@(D%U=&AE;G1I
M8V%T:6]N(&9A:6QE9"(*;7-G<W1R("+8JMBUV*_;C-F"(-F'V8C;C-F1V*H@
MV8;8I]F%V8C9@=F1V8(@V*C9B-BO(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R("+8JMBU
MV*_;C-F"(-F'V8C;C-F1V*H@V8;8I]F%V8C9@=F1V8(@V*C9B-BO+B`E<R(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-S8*;7-G:60@
M(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM
M<V=S='(@(MBJV+78K]N,V8(@V8?9B-N,V9'8JB#8I]BR(-BWV+'9@2#:J=BG
MV+'8L]BGV+(@4D%$2553(-BQV*\@V+38K]F'(-BGV+/8JB(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z.#4Q"FUS9VED(")!=71H96YT:6-A=&EO
M;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`BV*K8M=BOVXS9@B#9
MA]F(VXS9D=BJ(-BOV+$@VJG8I]BQV+/8I]BR($944"#9AMBGV879B-F!V9'9
M@B#8J-F(V*\@(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HW,`HC
M+"!F=7IZ>0IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V
M97(@9F%I;&5D+B(*;7-G<W1R("+8JMBUV*_;C-F"(-F'V8C;C-F1V*H@V*_8
ML2#:J=BGV+'8L]BGV+(@1E10(-F&V*?9A=F(V8'9D=F"(-BHV8C8KR`B"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C<U"FUS9VED(")!=F%I;&%B
M;&4@9FEE;&1S.B(*;7-G<W1R("+9@=N,V838K]F'V*?;C"#9@MBGV*C9A"#8
MK]BSV*K8L=BSVXPZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07IE<F)A:6IA;B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@
M(D)/1D@@17AC=7-E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O
M=6YD(@IM<V=S='(@(MF^V+/B@(S8LMF%VXS9AMF'(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R
M;W5N9"!#;VQO<B(*;7-G<W1R("+8L=F&VJ\@V;[8L^*`C-BRV87;C-F&V8<B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@Q"FUS9VED(")"
M860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(MBGV+/9A2#8L=F%V+(@
MV8;8I]BOV+'8L]BJ(&ME<F)E<F]S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N86UE+B(*
M;7-G<W1R("+9AMBGV84@VJG8I]BQV*C8L2#9AMBGV*_8L=BSV*H@:V5R8F5R
M;W,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8R"FUS9VED(")"86AA;6%S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(D)A:')A:6XB"FUS9W-T<B`BV*W8
MI]BTVXS9AR(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<W"FUS9VED(")"
M86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R(")"86QT:6,@*$E33RTX.#4Y
M+3$S*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A;F=L861E<V@B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")"87-E(&=R87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O
M=6YD+B(*;7-G<W1R("+8M-BGV*[9AR#:K]BQV*?9@=N,VJG;C"#9A=BHV8;8
MI]N,("<E<R<@VXS8I]F!V*H@V8;8M-BO(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S"FUS9VED(")"87-E;&EN
M92(*;7-G<W1R("+8KMBW(-F%V*C9AMBG(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HT.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B
M0F5L87)U<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"96QG:75M
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(D)E;&EZ
M92(*;7-G<W1R("+8KMBW(-F%V*C9AMBG(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HT,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0HC+"!F=7IZ
M>0IM<V=I9"`B0F5N:6XB"FUS9W-T<B`BVJ_8L=BOV8?9A=BGVXS;C"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G:60@(D)I<G1H9&%Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N
M+G!H<#HS-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F
M(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(MBHV839
MB-JI(%PB)7-<(B#8I]BR(-BHV+'9AMBGV879A]F4(-JIV*?8L=BHV+'8K]N,
M(%PB)7-<(B#;C-BGV8'8JB#9AMBTV*\B"@HC.B!T96UP;&%T97,O<&]R=&%L
M+VQA>6]U="YI;F,Z.#D*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@
M(MBJV8;8N-N,V878I]BJ(-BHV839B-JI(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@(MF&
MV8C8N2#8J-F$V8C:J2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G<W1R("+8L]N,V*?9AR(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(P-0IM<V=I9"`B0F]O:VUA<FMS(@IM
M<V=S='(@(MJ&V8C8J"#8I]F$V8$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(P"FUS9VED(")";W)D97(B"FUS
M9W-T<B`BV838J-F'(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T
M<B`BV;[9A]F&V*?;C"#9A-BHV8<Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0IM<V=I9"`B0F]R9&5R<R(*
M;7-G<W1R("+9A-BHV8?B@(S9A]BG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S
M;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z.38*;7-G:60@(D)O=&@B"FUS9W-T<B`BV8?8L2#8K]F(
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<U
M"FUS9VED(")";W1T;VTB"FUS9W-T<B`BV;[8I]N,VXS9AB(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C,*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,@HC+"!F=7IZ>0IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(MF&V*?9A=F'(-BG
MV83:J=BJV+'9B-F&VXS:J=N,(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(D)R:71I
M<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8R"FUS9VED(")"<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Q"FUS9VED(")"=6QG87)I82(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"FUS9VED(")"=6QL
M971E9"!,:7-T(@IM<V=S='(@(MF$VXS8L]BJ(-BHV8C9A-BJXH",V*_8I]BQ
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,SD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0T-`IM<V=I9"`B0TU3(@IM<V=S='(@
M(D--4R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S4*;7-G:60@(D-20R(*;7-G<W1R(")#4D,B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B0U),($1I<W1R:6)U=&EO
M;B!0;VEN=',B"FUS9W-T<B`BV8;9@MBGV+<@V*K9B-BRVXS8N2!#4DPB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`BV*[8
MM=F(V+7;C-BGV*H@V+/9A-F(V80N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,38S"B,L(&9U>GIY"FUS9VED(")#86-H92!I;FET('=A
M<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R("+9@=F'V+'8L]BJ(-BJV8C8LMN,
MV+G;C"#9A=BTV*[8M2#9AMBTV*_9AR#8I]BSV*HB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@T(&-O;F9I9R]H;V]K<RYP
M:'`N9&ES=#HY.#<*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$U-0IM
M<V=I9"`B0V%L96YD87(B"FUS9W-T<B`BV*K9@MF(VXS9A2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#8*;7-G:60@(D-A;&TB"FUS9W-T
M<B`BV*+8L=BGV84B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B0V%M97)O;VXB
M"FUS9W-T<B`BV878K]N,V+$B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HR,`IM<V=I9"`B0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T
M:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B
M(@HBV8;9A=N,XH",V*K9B-BGV88@V*?8L]F%(-BQV878LB#8L=BG(-BHV+?9
MB-BQ(-BNV8C8K]JIV*?8L2#8K]F(V*C8I]BQV8<@V*C8I]BRV8;8M-BGV8;8
MK]B,(-BHV*<@V+/8L=F^V+'8L]BJ(-BSV*?9A=BGV8;9AR#8KMF(V*\@V*K9
MA=BGV+,@(@HBV*C:K]N,V+';C-BO(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z,S$X"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B!N;W0@=W)I
M=&4@=&\@9FEL92!<(B5S7"(B"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@
MV*_8L2#9OMBQV8C9AMBOV8<@7"(E<UPB(-F&V8C8M-BJ(@H*(SH@861M:6XO
M<V5S<VEO;G,N<&AP.C(R"FUS9VED(")#86XG="!A9&UI;FES=&5R(&5X=&5R
M;F%L('-E<W-I;VX@:&%N9&QE<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER=7,N<&AP.C(S-2!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G-Q;"YP:'`Z,S$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&-O
M;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM<V=S='(@(MF&V87;C.*`C-BJ
MV8C8I]F&(-BHV8<@VJG8I]BQV+/8I]BR(-F^V+/8JB#8I]F$VJG8JMBQV8C9
MAMN,VJD@V878JMBUV80@V+38KSH@)7,B"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HT,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E
M;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V;[8
ML=F(V8;8K]F'(%PB)7-<(B#8L=BG(-BHV*?8LB#:J=BQV*\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8T"B,L(&9U>GIY"FUS9VED(")#86YA9&$B"FUS9W-T<B`BV*K9@MF(VXS9
MA2(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,2!A9&UI;B]U<V5R+G!H<#HQ,C`*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8U"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,2!T96UP;&%T
M97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O<F5M;W9E+FEN8SHQ,@IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(MBG
MV8;8M=BQV*?9@2(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B"FUS9W-T<B`BV*?9
MAMBUV+'8I]F!(-BGV+(@V*?8L=BSV*?9A"#:K]BRV*?8L=BT(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BV8;9A=N,
MXH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%PB)7-<(B#8L=BG(-BMV+#9@2#:
MJ=BQV*\@("(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HT-@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C4R"FUS9VED(")#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E
M8W1O<GDN(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-N,VJD@V+38I]BN
MV8<@V879B-F"V*H@V;[;C-BOV*<@VJG8L=BO(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T('!R
M;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R
M("+9AMF%VXSB@(S8JMF(V*?9AB#8J-BOV8C9AB#9OMBGV+'8I]F%V*K8L2`G
MV;[8L=F(V8;8K]F'(-F%V8+8M=BO)R#8I]BOV*?9A=F'(-BOV*?8KR(*"B,@
M(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC
M"B,@"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$T"B,L('!H<"UF
M;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB
M"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V+38I]BNV8<@7"(E<UPBV+'8
MIR#8K=BPV8$@VJG8L=BO("(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A
M5')E92YP:'`Z,3(X(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN
M<&AP.C8X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E+"`E
M9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@
MV*W8L-F!(-F&V879B-BOV(P@)60@V8'8L=BRV8;8KR#9A=F(V*S9B-BO(-BG
MV+/8JB(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP
M.C8P.`IM<V=I9"`B(@HB0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R
M:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E
M<B`B"B)S=&]R960N(@IM<V=S='(@(B(*(MF&V87;C.*`C-BJV8C8I]F&(-BO
MV8C8J-BGV+'9AR#9A=BQV*K8J"#9AMF%V8C8K]B,(-BHV+'8KMN,(-BGV+(@
MV8C8L=F(V*_;C-F'V*?;C"#9@=BQV*?9A]F%(-BTV*_9AR#8J-BQV*?;C"#9
MA=BQV*K8J"#8L]BGV++;C"#8J-BG("(*(MBTV878I]BQV8?B@(S9A]BGVXP@
MV+#8KMN,V+'9AR#8M-BOV8?8C"#8L]BGV++:K]BGV+$@V8;;C-BSV*HB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#D*;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N
M=6UB97(N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F^VXS8NMBGV84@
MV+'8IR#8J-F'(-BTV878I]BQV8<@V*K8N=N,VXS9AB#8M-BOV8<@VJ_8L-BQ
M(-BOV*?8KR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR-`IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R("+8N=F&V8C8I]F&
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z
M,3`T"FUS9VED(")#87)R:65R(@IM<V=S='(@(MBMV*?9A=F$(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDP"FUS9VED(")#871E9V]R:65S(&%N9"!,
M86)E;',B"FUS9W-T<B`BVJ_8L=F(V8?B@(S9A]BG(-F((-BHV+':AMBSV*C9
MA]BG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`BV879B-BHV*?;C-F$
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR-0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(MBNV+79
MB-BUVXS8I]BJ(-BSV839B-F$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS
M9W-T<B`BV8'8I]BUV839AR#8L]F$V8C9A"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@
M<')O<&5R=&EE<R(*;7-G<W1R("+8KMBUV8C8M=N,V*?8JB#8L]F$V8C9A"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R
M"FUS9VED(")#96QL('-P86-I;F<Z(@IM<V=S='(@(MF!V*?8M=F$V8?B@(S:
MK]BPV*?8L=N,(-BSV839B-F$(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(W-`IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(MF%V8C8J-BGVXS9
MA"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED(")#96QT:6,@
M*$E33RTX.#4Y+3$T*2(*;7-G<W1R(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R("+9A=BQVJG8LB(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C4*;7-G:60@(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B0V5N=')A
M;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T<B`B0V5N=')A;"!%=7)O
M<&5A;B`H25-/+3@X-3DM,BDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8Y.0IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G
M<W1R("+8K-BRV*;;C-BGV*H@VJ_9B-BGV8?;C"`B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Q,0HC+"!F=7IZ>0IM<V=I9"`B0V5R
M=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`BV*S8LMBFVXS8I]BJ(-JOV8C8I]F'
MVXP@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.38*
M;7-G:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(MBSVXS8I]BS
MV*K9A]BGVXP@VJ_9B-BGV8?;C"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`HC+"!F=7IZ>0IM
M<V=I9"`B0VAA9"(*;7-G<W1R("+9AMF(VXS8L]F'(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHY-@IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(MBJV+K;C-N,V+$@(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,Q"FUS9VED(")#:&%N
M9V4@66]U<B!087-S=V]R9"(*;7-G<W1R("+8I]BSV84@V+'9A=BR(-BNV8C8
MKR#8L=BG(-BJV+K;C-N,V+$@V*_9A]N,V*\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-C8*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D
M<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY
M('1O('EO=7(@(@HB96UA:6QS+B(*;7-G<W1R("(B"B+8JMBZVXS;C-BQV*_8
MI]BOV88@V8;8I]F%(-F((-BBV*_8L=BSVXP@VJG9AR#8I]F!V+'8I]BO(-F'
MV8;:K]BGV84@V*[9B-BGV8;8K]F&(-F((-F^V*?8L]BN(-BOV*?8K]F&(-BH
MV8<@V8;8I]F%V8?9E"#8M-F%V*<@V*[9B-BGV8?9AMBO("(*(MBOVXS8KR`B
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*;7-G:60@(B(*
M(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H
M('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#;VYT86-T('EO=7(@
M861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HBV*K8NMN,VXS8L=BOV*?8K]F&
M(-BGV+/9A2#8L=F%V+(@V+39A=BG(-BOV+$@V;[;C-JIV+'8J-F&V*_;C"#9
M@=BYV83;C"#9OMBTV*K;C-BHV*?9AMN,(-F&V87;C.*`C-BTV8C8KRX@V*C8
MIR#8L]BQV;[8L=BSV*H@V+/8I]F%V*?9AMF'(-BNV8C8KR`B"B+8JMF%V*?8
MLR#8J-JOVXS8L=N,V*\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(W"FUS9VED(")#:&%R(@IM<V=S='(@(MF&
MV8C;C-BSV8<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S
M='(@(MBHV+'8L=BSVXP@V;[;C-F(V8;8KRXN+B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G
M:60@(D-H:6QE(@IM<V=S='(@(N*`C"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*(RP@9G5Z>GD*
M;7-G:60@(D-H:6YA(@IM<V=S='(@(MF&V8C;C-BSV8<B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X,`IM<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'
M0C(S,3(I(@IM<V=S='(@(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#:&EN97-E(%1R
M861I=&EO;F%L("A":6<U*2(*;7-G<W1R(")#:&EN97-E(%1R861I=&EO;F%L
M("A":6<U*2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR
M-CD*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(MBGV8;8JMBN
MV*?8J"#;C-JI(-BGV+/9A2#8L=F%V+(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+U-I9VYU<"YP:'`Z,C8X"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*
M;7-G<W1R("+8I]F&V*K8KMBGV*@@VXS:J2#9AMBGV84@VJG8I]BQV*C8L=N,
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y.`IM<V=I9"`B0VAO;W-E
M(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G<W1R("+8I]F&V*K8KMBGV*@@
MVH;:K]F(V8;:K]N,(-F&V878I]N,V+0@V*K8I]BQVXS8KCHB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R
M"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L
M:7-T<RDB"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-F&V8C8N2#8L]BHVJD@V8'9
MA]BQV+/8JB`HV*C8L=BGVXP@V8'9A]BQV+/8JMF'V*?;C"#9A=BQV*K8J"DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8X"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4RYP:'`Z,CDT(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HX.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQA<W,@
M9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(MBJV+G8L=N,
MV8$@VJG9A-BGV+,@)7,@VXS8I]F!V*H@V8;8M-BO(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*;7-G:60@(D-L96%R(@IM
M<V=S='(@(MBUV*?9@2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E('1A9W,B"FUS
M9W-T<B`BV;[8I]JI(-JIV+'8K]F&(-BJVJ_9A]BGVXP@35-/9F9I8V4B"@HC
M.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"B,L(&9U>GIY"FUS9VED(")#;&5A
M<B!1=65R>2(*;7-G<W1R("+9OMBGVJD@VJG8L=BOV88@VJG8I]BQV*C8L2(*
M"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M
M(RTC"B,@"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHU"B,L
M('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R
M("+9OMBGVJD@VJG8L=BOV88@VJG8I]BQV*C8L2`Z("5S(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$Q"FUS9VED(")#;&5A<B!U<V5R
M(@IM<V=S='(@(MF^V*?:J2#:J=BQV*_9AB#:J=BGV+'8J-BQ(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L96%R('5S
M97(@9&%T82(*;7-G<W1R("+9OMBGVJD@VJG8L=BOV88@V*_8I]BOV8?9E"#:
MJ=BGV+'8J-BQ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,34*(RP@9G5Z>GD*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T
M<B`BV*C8I]BQV*?9AB#8K]N,V+'9A]F&VJ_8I]F%(@H*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-C`*;7-G:60@(D-L:6-K
M('1O($-O;G1I;G5E(@IM<V=S='(@(MBHV+'8I]N,(-BGV*_8I]F%V8?8C"#:
MJ=F$VXS:J2#:J=F&VXS8KR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@
M2%144"(*;7-G<W1R(")#;&EC:V%T96QL(-BGV+(@V+?8L=N,V8(@2%144"(*
M"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(MBH
MV+/8JMF&(-F^V8;8K-BQV8<B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T
M-`IM<V=I9"`B0VQO=61S(@IM<V=S='(@(MBGV*C8L=F'V*<B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-@HC+"!F=7IZ>0IM
M<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(MBGV*C8L=N,(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3<*;7-G:60@(D-L
M;W5D>2(*;7-G<W1R("+8I]BHV+';C"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-O
M8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P;W)T86PO<VED96)A<BYI;F,Z,C,*;7-G:60@(D-O;&QA<'-E(%-I9&5B
M87(B"FUS9W-T<B`BV*S9A=BY(-BTV*_9AB#9AMF(V*?8L2#:J=F&V*?8L=N,
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`BVH;9
MA=BY(-BTV*_9AB#9A-BHV8?B@(S9A]BG(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PHC+"!F=7IZ
M>0IM<V=I9"`B0V]L;VUB:6$B"FUS9W-T<B`BV+'9AMJO(@H*(SH@;&EB+T)L
M;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*
M;7-G:60@(D-O;&]R(@IM<V=S='(@(MBQV8;:KR(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C0*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-0HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`P('-E<G9I8V5S+VEM86=E<R]C
M;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R(%!I8VME<B(*;7-G<W1R
M("+8I]F&V*K8KMBGV*@@VJG9AMF&V*_9AR#8L=F&VJ\B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.#0V"FUS9VED(")#;VQO=7(@<V5L96-T:6]N
M(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#8L=F&VJ\B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB
M"FUS9W-T<B`BV+/8JMF(V8;9A]BG.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y-#8*;7-G:60@(D-O;'5M;B!T:71L97,B"FUS9W-T<B`BV+G9
MAMBGV8C;C-F&(-BSV*K9B-F&V8?8IR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR-C0*;7-G:60@(D-O;6EC<R(*;7-G<W1R("+9A=BVV*W:J2(*
M"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-0IM<V=I9"`B0V]M;6%N9"(*;7-G
M<W1R("+9@=BQV878I]F&(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS
M9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@(MF^V8C8L]BJV8<@V8'8L=F%
MV*?9AB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM
M<V=I9"`B0V]M;65N="(*;7-G<W1R("+8JMF(V+;;C-BM(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C8*;7-G:60@(D-O;6UO;B!.
M86UE(@IM<V=S='(@(MF&V*?9A2#8N=F%V8C9A=N,(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HU.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*
M(RP@9G5Z>GD*;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`BV8'8L=BOV*<B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS
M9VED(")#;VUP86YY(@IM<V=S='(@(MBTV+':J=BJ(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`BV+'8
MI]N,V*?9AMF'XH",V8?8IR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.3<*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R("+8M-BQV+<B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T.0IM<V=I9"`B0V]N9&ET:6]N<R(*
M;7-G<W1R("+8M-BQV*?;C-BW(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z
M.38*;7-G:60@(D-O;F9I9W5R871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B
MV*K9@=BGV8C8JMF'V*?;C"#9OMN,VJG8L=BHV8;8K]N,(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$T,PIM<V=I9"`B0V]N9FEG=7)A=&EO;B!F;W(@
M<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,U"B,L(&9U
M>GIY"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*;7-G
M<W1R("+9OMN,VJG8L=BHV8;8K]N,(-BHV8<@V*C8L=F(V++8L=BSV*?9AMN,
M(-F&VXS8I]BR(-BOV*?8L=BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN
M<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B
M"FUS9W-T<B`BV;[;C-JIV+'8J-F&V*_;C"`E<R(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z-3$*;7-G:60@(D-O;F9I<FT@4&%S<W=O
M<F0B"FUS9W-T<B`BV*K8H]N,VXS8KR#8I]BSV84@V+'9A=BR(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C4Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-@HC+"!F=7IZ>0IM<V=I9"`B0V]N9V\B"FUS9W-T<B`BV+'9AMJO(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-0IM<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B
M;&EC(&]F('1H92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB
M"FUS9W-T<B`BV*?8JMBUV*?9A"#9AMBGV879B-F!V9'9@B#8J-F(V*\B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED
M(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(MBGV*K8M=BGV80@V8;8
MI]F%V8C9@=F1V8(@V*C9B-BO(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-SDP"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE
M('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(MBGV*K8M=BGV80@V*C9AR#:
MJ=BGV+'8L]BGV+(@VJG9A-N,V*\@V+G9A=F(V87;C"#8L=BO(-BTV*\B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`BV*?8JMBUV*?9
MA"#8J-F'(-JIV*?8L=BSV*?8LB#:J=F$VXS8KR#8N=F%V8C9A=N,(-BQV*\@
MV+38KRX@V*_9A-N,V80Z("5S("@E<RDB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C@T-0IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R
M(&9A:6QE9"XB"FUS9W-T<B`BV*?8JMBUV*?9A"#8J-F'(-JIV*?8L=BSV*?8
MLB!&5%`@V8;8I]F%V8C9@=F1V8(@V*C9B-BO(@H*(SH@8V]N9FEG+VAO;VMS
M+G!H<"YD:7-T.C$P,30*;7-G:60@(D-O;G1A8W1S(@IM<V=S='(@(MF&V878
MI]BSV8?8IR(*"B,@"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@
M861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(MBJV878I]BS
MV8?8IR#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@V*C9AR#:J=BJV*?8J-J&V8?9
ME"#8HMBOV+'8LR#8M-F%V*<@V*?8MMBGV8'9AR#8M-BOV8<@V*C9B-BO(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU-B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R("+9A=BM
MV*K9B-BGVXP@)R5S)R`B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HR.2!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S,*;7-G:60@(D-O
M;G1I;G5E(@IM<V=S='(@(MBGV*_8I]F%V8<B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED
M(")#;V]K($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,R"FUS9VED(")#;V]K:64B"FUS9W-T<B`BVJG9B-JIVXPB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`BV+'9B-F&V8C8M-BJ(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C@*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R("+8I]BJV+78
MI]F$(-F&V*?9A=F(V8'9D=F"(-BHV8C8KR(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T
M:6]N(@IM<V=S='(@(MBQV8C9AMF(V+38JB#8J-BQV*_8I]BTV*K9AB#8I]BR
M(-BHV*[8M"#8I]F&V*K8KMBGV*C;C"(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-S8*;7-G:60@(D-O=6QD
M(&YO="!01U`@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("+9AMF%VXSB@(S8
MJMF(V*?9AMBO(-F^VXS8NMBGV84@V+'8IR#8L=F%V++8J-F&V*_;C"#:J=F&
MV*\@4$=0(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`U
M,PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N(@IM<V=S='(@
M(MF&V87;C.*`C-BJV8C8I]F&V*\@V;[;C-BZV*?9A2#8L=BG(-BGV878MMBG
MV*$@VJG9AMBO(%!'4"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,SDS"FUS9VED(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S
M<V%G92XB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV8;8KR#9OMN,V+K8I]F%
M(-BQV*<@V+'9A=BRV*C9AMBOVXP@VJG9AMBO(%,O34E-12(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L9"!N
M;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`BV8;9A=N,XH",V*K9
MB-BGV8;8KR#9OMN,V+K8I]F%(-BQV*<@V*?9A=BVV*?8H2#:J=F&V*\@4R]-
M24U%(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C
M+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8
MJMF%V*?8L]F'V*<@V+'8IR#8I]BVV*?9@=F'(-JIV+'8KR`E<R(*"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C$R,0IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@
M3$1!4"!S97)V97(N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BHV8<@
MVJG8I]BQV+/8I]BR($Q$05`@V;[;C-F(V+/8JB`B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-#4W"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!L9&%P
M('-E<G9E<B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8J-F'(-JIV*?8
ML=BSV*?8LB!L9&%P(-F^VXS9B-BSV*HB"@HC(",M(RTC+2,M(R`@8V]M<&5N
M9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$U-@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM
M<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BHV*?9A-BGV8;8LR#8L=BG(-J&
MVJD@VJG8L=BO("5S(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0T,0IM
M<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@;&1A<"!S97)V97(B"FUS9W-T
M<B`BV8;9A=N,XH",V*K9B-BGV88@V*C9AR#:J=BGV+'8L]BGV+(@;&1A<"#9
MA=BJV+79A"#8M-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO
M<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C0X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N
M;F5C="!T;R!S97)V97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS9W-T<B`B
MV8;9A=N,XH",V*K9B-BGV88@V*C8IR#8I]BSV*K9@=BGV*_9AR#8I]BR($94
M4"#8J-F'(-JIV*?8L=BSV*?8LB`G)7,G(-F(V+79A"#8M-BO.B`E<R(*"B,@
M(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC
M"B,@"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,S(R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8
MI]F&(-F!V8?8L=BSV*H@V*K9B-BRVXS8N=N,(-BGVXS8K-BGV*\@VJG8L=BO
M+B`E<R(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@
M(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$Q,C4*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+B(*;7-G
M<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8K]BGV*_9AR!01U`@V+'8IR#8L=F%
MV++:K]BTV*?;C-N,(-F&V879B-BO("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3(R"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3
M+TU)344@9&%T82XB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V*_8I]BO
MV8<@4R]-24U%(-BQV*<@V+'9A=BRVJ_8M-BGVXS;C"#9AMF%V8C8KR`B"@HC
M(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M
M(PHC(`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C(T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E
M(&-O;G1A8W0N("5S(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BJV878
MI]BS(-BQV*<@V*W8L-F!(-F&V879B-BO+B`E<R(*"B,@(RTC+2,M(RTC("!C
M;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F!V8?8L=BS
MV*H@V*K9B-BRVXS8N=N,(-BQV*<@V*W8L-F!(-F&V879B-BO+B`E<R(*"B,@
M(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC
M"B,@"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A
M9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@
MV*?8L]JIV+';C-F^V*H@V*C8L=F(V++8L=BSV*?9AMN,(-BQV*?9A^*`C-BG
MV8;8K]BGV++;C"#8L=BG(-BMV+#9@2#9AMF%V8C8KR`G)7,G+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.CDU,PIM<V=I9"`B0V]U;&0@;F]T(&1E=&5R
M;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N(@IM<V=S='(@
M(MF&V87;C.*`C-BJV8C8I]F&(-BBV*_8L=BS(-JOVXS8L=F&V*_9AR#9AMBG
MV879A]F4(-BGV83:J=BJV+'9B-F&VXS:J=N,(-BQV*<@V*K8M-BNVXS8M2#8
MK]BGV*\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C(X,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D
M9')E<W,@8F]O:RXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@VJG9A"#:
MJ=BJV*?8J-J&V8?9E"#8HMBOV+'8LR#8L=BG(-F(V*?:J=BTVXP@V8;9A=F(
MV*\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C0Y,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R
M:6)U=&EO;B!L:7-T+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#:J=F$
M(-F!V8?8L=BSV*H@V*K9B-BRVXS8N=N,(-BQV*<@V8C8I]JIV+3;C"#9AMF%
MV8C8KR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-#0V"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E
M(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R("+9AMF%VXSB
M@(S8JMF(V*?9AB#9@=F'V+'8L]BJ(-JIV*?9A=F$(-F!V8?8L=BSV*H@V*K9
MB-BRVXS8N=N,(-BQV*<@V8C8I]JIV+3;C"#9AMF%V8C8KR(*"B,@(RTC+2,M
M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDN<&AP.C8X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<
M(BXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V*?8L]BJV+'8I]BJVIC;
MC"#8L=BG(-BHV*?8L2#:J=BQV*\@)R5S)R(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HQ,3`*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R
M("+9AMF%VXSB@(S8JMF(V*?9AB#8M-BGV*[9AR`G)7,GV*?;C-BLV*?8KR#:
MJ=BQV*\@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S$Y
M"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@
M:V5Y<V5R=F5R+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#:J=F$VXS8
MKR#8N=F%V8C9A=N,(-BQV*<@V*?8LB#:J=BGV+'8L]BGV+(@VJG9A-N,V*\@
MV*C8K]BSV*H@V*+9B-BQV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M,3,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E
M;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8
MI]F&("<E<R<@V+'8IR#8J-BQV*?;C"#9AMF(V+38JMF&(-BHV*?8LB#:J=BQ
MV*\@(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C
M+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!O<&5N("5S+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB`E<R#8L=BG
M(-BHV*?8LB#:J=BQV*\B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I
M;G1E;F%N8V4N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*;7-G<W1R("+9
MAMF%VXSB@(S8JMF(V*?9AB#9A=BOV8C9A"#9B-BXV*?;C-F!(-F&VJ_9A]BO
MV*?8L=N,("5S(-BQV*<@V*C8I]BR(-F&V879B-BO(@H*(R`C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("+9AMF%
MVXSB@(S8JMF(V*?9AB#8M-BGV*[9AR`G)7,G(-BQV*<@V*C8I]BR(-F&V879
MB-BO(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q,2!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR,S<@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C0W.`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z-3$V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV,3(*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8U-B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-CDY"B,L(&9U>GIY"FUS9VED(")#
M;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R("+9AMF%
MVXSB@(S8JMF(V*?9AB#:J=BGV+'8L]BGV+(@3$1!4"#8L=BG(-BLV+/8JMBL
MV8@@VJG8L=BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E
M(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+U9&4R]61E,O3V)J96-T
M+G!H<#HR,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@
M)7,N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&("5S(-BQV*<@V*[9B-BG
MV8;8KR(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED
M("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q
M=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R
M92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI
M;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T
M<B`B(@HBV8;9A=N,XH",V*K9B-BGV88@V*?8L]F%(-BQV878LB#8L=BG(-BH
MV+'8I]N,(-JIV*?8L=BHV+$@V879B-BQV*\@V8;8N-BQ(-BHV*?8LMF&V+38
MI]F&V*\N(-BHV+G8MMN,(-N,V*<@V8?9A=F'(-BLV++8IMN,V*?8JB#9A=BQ
MV*C9B-BW(-BHV8<@(@HBV*+9AB#9AMBGV*_8L=BSV*H@V87;C.*`C-BHV*?8
MM-BO+B#8K]F(V*C8I]BQV8<@V+/8N=N,(-JIV8;;C-BO(-N,V*<@V*C8L=BG
MVXP@VJG9A=JI(-BHVXS8M-BJV+$@V*C8IR#8L]BQV;[8L=BSV*H@V+/8I]F%
MV*?9AMF'(-BNV8C8KR`B"B+8JMF%V*?8LR#8J-JOVXS8L=N,V*\B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#D*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0P"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-PHC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#,*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y"FUS9VED(")#;W5L9"!N
M;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&($%#
M3"#8L=BG(-BOV8C8J-BGV+'9AR#8J-BOV+/8JB#8HMF(V+'8KR(*"B,@(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,C<T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A
M9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-JI
MV*K8I]BHVH;9A]F4(-BBV*_8L=BS(-BQV*<@V*_9B-BHV*?8L=F'(-BHV*_8
ML]BJ(-BBV8C8L=BO+B`E<R(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O
M("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B
M"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V8'9A]BQV+/8JB#8JMF(V++;
MC-BYVXP@V+'8IR#8K]F(V*C8I]BQV8<@V*C8K]BSV*H@V*+9B-BQV*\N("5S
M(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M
M(RTC+2,*(R`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E
M=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`BV8;9A=N,
MXH",V*K9B-BGV88@V8'9A]BQV+/8JB#8JMF(V++;C-BYVXP@V+'8IR#8K]F(
MV*C8I]BQV8<@V*C8K]BSV*H@V*+9B-BQV*\N("5S(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*;7-G:60@(D-O=6QD(&YO="!R
M971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`BV8;9A=N,
MXH",V*K9B-BGV88@V8+8I]BHV83;C-BJV8?8I]N,(-JIV*?8L=BSV*?8LB#8
ML=BG(-BOV8C8J-BGV+'9AR#8J-BOV+/8JB#8HMF(V+'8KR(*"B,@(RTC+2,M
M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@(D-O=6QD(&YO="!R
M979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BG
MV88@V;[;C-JIV+'8J-F&V*_;C"#8L=BG(-BHV*?8LMJOV+'8K]BGV8;8KR(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`BV8;9A=N,
MXH",V*K9B-BGV88@V+38I]BNV8<@)R5S)R#8L=BG(-BMV+#9@2#9AMF%V8C8
MKR`N(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C
M+2,M(RTC+2,*(R`*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V;[;C-JIV+'8J-F&
MV*_;C"`E<R#8L=BG(-BOV*[;C-BQV8<@VJG8L=BO(@H*(R`C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C4Y"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I
M;VXN(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F^VXS:J=BQV*C9AMBO
MVXP@V;[8M-BJVXS8J-BGV88@V+'8IR#8K=F!V+@@VJG8L=BO(@H*(R`C+2,M
M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B
M"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V;[;C-JIV+'8J-F&V*_;C"#9
MOMBTV*K;C-BHV*?9AB#8L=BG(-BMV8'8N"#:J=BQV*\Z("5S("(*"B,@(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDU"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C
M<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8
MI]BSVJG8L=N,V;[8JB#8J-BQV8C8LMBQV+/8I]F&VXP@V+'8I]F'XH",V*?9
MAMBOV*?8LMN,(-BQV*<@V*W9@=BX(-F&V879B-BO.B`G)7,G+B(*"B,@(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N
M(&9I;&4@)7,N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&
MV*_9AR#9OMBTV*K;C-BHV*?9AB#9OMN,VJG8L=BHV8;8K]N,("5S(-BQV*<@
MV*W9@=BX(-JIV+'8KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(
M;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@
M=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E
M(&]N92!O9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@
M;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB
M"FUS9W-T<B`B(@HBV8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(-F^
MVXS:J=BQV*C9AMBOVXP@)7,@V+'8IR#8K=F!V+@@V8;9A=F(V*\N(-BTV878
MIR#9A=N,(-BJV8C8I]F&VXS8KR#8I]BR(-N,VJG;C"#8I]BR(-JOV++;C-F&
MV8?B@(S9A]BG(-BHV+'8I]N,("(*(MBMV8'8N"#:J=BO(-BHV+$@V+'9B-N,
M("5S(-BGV+/8JMF!V*?8K]F'(-F&V878I]N,VXS8KR#9B"#;C-BG(-BGVXS9
MAMJIV8<@V*?8LB#:J=BO(-BHV8<@V+79B-BQV*H@V*_8L]BJVXP@V*_8L25S
M(-BQV8C9AMF(V+38JB`B"B+8JMF'VXS9AR#9AMF%V*?;C-N,V*\B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$T,PIM<V=I9"`B0V]U;&0@
M;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(MF&V87;C.*`
MC-BJV8C8I]F&(-JIV*?8L=BSV*?8LB!,1$%0(-BQV*<@V*S8L]BJV*S9B"#:
MJ=BQV*\B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R
M("+9AMF%VXSB@(S8JMF(V*?9AB#9OMN,V8C9AMBO("<E<R<@V+'8IR#9@MBW
MV+D@VJG8L=BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E
M(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R("+9AMF%VXSB@(S8
MJMF(V*?9AB#8JMF%V*?8LR`@V+'8IR#8J-BQV8C8LMBQV+/8I]F&VXP@VJG8
ML=BO+B`E<R(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S
M*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,SDV"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(MF&
MV87;C.*`C-BJV8C8I]F&(-F!V8?8L=BSV*H@V*K9B-BRVXS8N=N,(-BQV*<@
MV*C8L=F(V++8L=BSV*?9AMN,(-JIV+'8KRX@)7,B"@HC(",M(RTC+2,M(R`@
M8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B!<(B5S7"(Z
M("5S(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F^VXS:J=BQV*C9AMBO
MVXP@V+'8IR#8J-BQV*?;C"`G)7,G(-F&V8C8M-BJ.B`E<R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-C8*;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE
M($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P
M96XN(@IM<V=S='(@(B(*(MF&V87;C.*`C-BJV8C8I]F&(-F&V8C8I]BQ(-BL
MV*?9AMBHVXP@V879B-BRVXS9A-BG(-BQV*<@V;[;C-BOV*<@VJG8L=BO+B#9
MA=BWV878IMF&(-BTV8C;C-BO(-JIV8<@V8;9B-BGV+$@V*S8I]F&V*C;C"#8
MJ-BGV+(@V*?8L]BJ(@H*(R`*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,34T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H92!F;VQL;W=I;F<@<FEG
M:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B"FUS9W-T<B`BV8;9A=N,
MXH",V*K9B-BGV88@V*C9AR#:J=BGV+'8J-BQ("<E<R<@V*_8L]BJV+'8L]N,
MV8?8I]N,(-BRVXS8L2#8J-BQV*?;C"#9OMF(V+39AR`G)7,G(-BOV*?8KSH@
M)7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#$Y"FUS9VED(")#
M;W5N=&5D('1E>'0B"FUS9W-T<B`BV878JMF&(-BTV878I]BQV+0@V+38K]F'
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G
M:60@(D-O=6YT<GDB"FUS9W-T<B`BVJG8M-F(V+$B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C<S"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(MBO
MV8C8L=F'XH",V8?8IR(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I9"`B0W)E871E(@IM<V=S
M='(@(MBGVXS8K-BGV*\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T92!A(&QI;FLB
M"FUS9W-T<B`BV*?;C-BLV*?8KR#;C-JI(-F^VXS9B-F&V*\B"@HC.B!T96UP
M;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDT"FUS9VED(")#<F5A
M=&4@82!N97<@;VYE(@IM<V=S='(@(MBGVXS8K-BGV*\@VXS:J=N,(-BLV*_;
MC-BO(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.3(*;7-G:60@(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R("+8I]N,V*S8
MI]BO(-BRVXS8L=F^V8C8M-F'XH",V8?8IR(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS
M(@IM<V=S='(@(MF%V*S9B-BRV8?8I]N,(-BGVXS8K-BGV*\@VJG9AMF&V*_9
MAR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R,S`*;7-G:60@(D-R
M961I="!C87)D(&YU;6)E<B(*;7-G<W1R("+8M-F%V*?8L=F'(-JIV*?8L=BJ
M(-BGV+G8JMBHV*?8L=N,(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@
M(D-R;V%T:6$B"FUS9W-T<B`BV*?;C-BLV*?8KR(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G
M:60@(D-U8F$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(V
M"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@(MF!
MV*?8LB#9@=BYV83;C"(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HT.`HC+"!F
M=7IZ>0IM<V=I9"`B0W5R<F5N="!397-S:6]N<R(*;7-G<W1R("+9A=BLV8C8
MLMF'V*?;C"#8I]N,V*S8I]BO(-JIV8;9AMBOV8<B"@HC.B!L:6(O0FQO8VLO
M=&EM92YP:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E
M;G0@5&EM92(*;7-G<W1R("+8L]BGV+G8JB#9@=BYV83;C"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-`IM
M<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T<B`B55),(-F!V+G9A-N,(-F'
MV+/8JB(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS,PHC+"!F=7IZ>0IM<V=I
M9"`B0W5R<F5N="!5<V5R<R(*;7-G<W1R("+9@=BGV+(@V8'8N=F$VXPB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS9VED(")#=7)R96YT(%=E871H
M97(B"FUS9W-T<B`BV*+8J"#9B"#9A]F(V*?;C"#9@=BYV83;C"(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-S4*;7-G:60@(D-U<G)E;G0@
M8V]N9&ET:6]N.B`B"FUS9W-T<B`BV+38L=BGVXS8MR#9@=BYV83;C#H@(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,@IM
M<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R("+8L]BHVJD@V8'8N=F$VXPB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`X"B,L('!H<"UF;W)M870*
M;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E
M<RXB"FUS9W-T<B`BV+/9@=BGV+'8M-N,(-JIV+'8K]F&(-F(V+C8I]N,V8$@
MV8?9AMJOV*?9A2#9B-BQV8C8KR#8J-F'("5S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED(")#
M=70B"FUS9W-T<B`BV*C8L=N,V*_9AB(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I;VXB
M"FUS9W-T<B`BV*C8L=N,V*_9AB#8I]F&V*K8KMBGV*@B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X
M"FUS9VED(")#>7!R=7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#(*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(D-Y
M<FEL;&EC("A+3TDX+5(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*
M;7-G:60@(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(D-Y<FEL
M;&EC("A7:6YD;W=S+3$R-3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#0*;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R
M(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS
M9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4Q('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R(")$1"(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,R.#$*;7-G:60@(B(*(D133B`H<V5E(&AT='`Z
M+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N
M:6YT<F\M9'-N+G!H<"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT
M96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T
M<B`BV+'9B-BRV*?9AMF'(@H*(SH@861M:6XO9&%T871R964N<&AP.C8U"FUS
M9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@(MF%V+'9B-BQVJ_8L2#8
MK]BQV*[8JB#8K]BGV*_9AR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,R-SD*;7-G:60@(D1A=&%B87-E($QO;VMU<"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(S.3D*;7-G:60@(D1A=&4B"FUS9W-T<B`B
MV*K8I]BQVXS8KB(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N
M:6YC.C$S"FUS9VED(")$871E(%)E8V5I=F5D(@IM<V=S='(@(MBJV*?8L=N,
MV*X@V*_8L=N,V*?9@=BJ(-BTV*_9AR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X,#<*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM<V=S='(@(MBJ
MV*?8L=N,V*X@V*?9AMBJV*[8I]BH(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Y,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S(R
M"FUS9VED(")$87DB"FUS9W-T<B`BV+'9B-BR(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,V"FUS9VED(")$
M95]L971E($-O;'5M;B(*;7-G<W1R("+8K=BPV8$@V+/8JMF(V88B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@IM<V=I9"`B
M1&5C96UB97(B"FUS9W-T<B`BV*_8L]BGV878J-BQ(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I
M9"`B1&5C:6UA;"!N=6UB97)S(@IM<V=S='(@(MBGV+G8K]BGV*\@V*_9A]BO
MV8?;C"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C`*;7-G:60@(D1E8W)E87-E($EN9&5N="(*;7-G<W1R("+:J=F%(-JI
MV+'8K]F&(-BJV8C8L=F!V*K:K]N,(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HQ.#<@;&EB+W!R969S+G!H<#HQ,3<*;7-G:60@(D1E9F%U
M;'0B"FUS9W-T<B`BV;[;C-BT(-F!V+'8MB(*"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"FUS9VED(")$969A=6QT($-O
M;&]R(@IM<V=S='(@(MBQV8;:KR#9OMN,V+0@V8'8L=BV(@H*(SH@9G)A;65W
M;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HY,0IM<V=I9"`B1&5F875L="!)
M9&5N=&ET>2(*;7-G<W1R("+9A]F(VXS9D=BJ(-F^VXS8M"#9@=BQV+8B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C<*;7-G:60@(D1E9F%U;'0@4VAE
M;&PB"FUS9W-T<B`BV;[9B-BSV*K9A]F4(-F^VXS8M"#9@=BQV+8B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@(D1E9FEN:71I;VYS(@IM
M<V=S='(@(MBJV+G8I]BQVXS9@2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C8*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HT,C(@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HT,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C<P"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z.3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ.#(*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C<S('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY.`HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*;7-G<W1R("+8K=BP
MV8$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S(*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S
M='(@(MBMV+#9@2#8L]F$V8C9A"(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DY
M(&%D;6EN+V=R;W5P<RYP:'`Z,C(W"FUS9VED(")$96QE=&4@1W)O=7`B"FUS
M9W-T<B`BV*W8L-F!(-JOV+'9B-F'(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C0Y"B,L(&9U>GIY"FUS9VED(")$96QE=&4@3&]G(@IM<V=S
M='(@(MBMV+#9@2#8L]BWV+$B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C<W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`Q"FUS
M9VED(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R("+8K=BPV8$@V878K-F(
MV+(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M,PIM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R("+8
MK=BPV8$@V8@@V;[8I]JIV+/8I]BRVXP@V;[;C-BZV*?9A=F'V*<B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W
M"FUS9VED(")$96QE=&4@8V5L;"(*;7-G<W1R("+8K=BPV8$@V+/9A-F(V80B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8S"FUS9VED(")$96QE=&4@8V]L=6UN(@IM<V=S='(@(MBMV+#9@2#8
ML]BJV8C9AB(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS9VED(")$
M96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(MBM
MV+#9@2#8I]F$VJ_9B-N,(-BLV*?;C-JOV++;C-F&(-F%V8C8K-F(V*\B"@HC
M(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M
M(PHC(`HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<
M(B(*;7-G<W1R("+8K=BPV8$@V878K-F(V++9A]BG(-BHV+'8I]N,("!<(B5S
M7"(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<
M(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T<B`BV*+;C-BG(-F%
MV*S9B-BRV8?8IR#9B"#8LMN,V+'9A=BLV8C8LMF'V*<@V*C8L=BGVXP@7"(E
M<UPB(-BMV+#9@2#8M-F(V*_8GR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!R;W<B
M"FUS9W-T<B`BV*W8L-F!(-BSV+?8L2(*"B,Z('1E;7!L871E<R]P<F5F<R]D
M96QE=&5I9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I
M9&5N=&ET>2(*;7-G<W1R("+8K=BPV8$@V8?9B-N,V9'8JB#8I]F&V*K8KMBG
MV*@@V+38K]F'(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@
M8V]L=6UN(@IM<V=S='(@(MBMV+#9@2#8L]BJV8C9AB#9@=BYV83;C"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV,PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O=R(*;7-G<W1R("+8
MK=BPV8$@V+/8M]BQ(-F!V+G9A-N,(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z,S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1E
M;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R("+8
MI]BSVJG8L=N,V;[8JB#8K=BPV8$@V+38K]F'V90@V*C8L=F(V++8L=BSV*?9
MAMN,(-BJV8;8N-N,V878I]BJ("<E<R<N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C,*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.34*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(Q"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PIM<V=I
M9"`B1&5L:79E<GD@=&EM92(*;7-G<W1R("+8LMF%V*?9AB#8I]BQV+/8I]F$
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV.0HC+"!F=7IZ>0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R
M("+8JMF(V+;;C-BMV*?8JB(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R
M("+8M-BQV*T@V878M-JIV80B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HY,S@@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`BV*K9B-BVVXS8
MK2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DU"FUS9VED(")$
M971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@(MBL
MV++9D-BFVXS8I]BJ.B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,3DY"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R("(@V*S8LMBFVXS8I]BJ(-BHV+'8I]N,
M(-BSV+'9OMBQV+/8JB#8L]BGV878I]F&V8<@V*O8J-BJ(-BTV*_9AR#8I]BS
MV*HB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C$Y"FUS9VED(")$
M979E;&]P;65N="(*;7-G<W1R("+:K]BSV*K8L=BT(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,3<*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R("+9AMF"
MV+?9AR#8M-BHV8;9A2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDT"FUS
M9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(MF&V8+8
MM]F'(-BTV*C9AMF%(-BHV+'8I]N,(-BSV*?8N=BJ(-JOV+#8M-BJV8<Z("(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C<*;7-G:60@(D1E
M=R!P;VEN=#H@(@IM<V=S='(@(MF&V8+8M]F'(-BTV*C9AMF%.B`B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED
M(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R("+8K-F'V*H@V*?8
MLB#:AMF^(-BHV8<@V+'8I]BSV*HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@
M=&\@;&5F="(*;7-G<W1R("+8K-F'V*H@V*?8LB#8L=BGV+/8JB#8J-F'(-J&
MV;XB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T
M;W)Y(@IM<V=S='(@(MBTV*?8KMF'(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(V-@IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R
M("+8HMN,V*<@V++9A=BGV88@,C0@V+/8I]BYV*K9AR#9AMF%V*?;C-BT(-BO
MV*?8K]F'(-BTV8C8K]B?(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW
M"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`BVJ_8LMN,V8;9A^*`
MC-F'V*?;C"#9AMF%V*?;C-BT(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.CDV"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM
M<V=S='(@(MF&V878I]N,V+0@V*S8LMBFVXS8I]BJ(-F^VXS8M,*MV*C;C-F&
MVXPB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@U"FUS9VED(")$:7-P;&%Y
M(&9O<F5C87-T("A4048I(@IM<V=S='(@(MF&V878I]N,V+0@V;[;C-BTPJW8
MJ-N,V8;;C"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3<*;7-G
M:60@(D1I<W!L87D@9F]R;6%T(@IM<V=S='(@(MF&V878I]N,V+0@V8+8I]F$
MV*@B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,3DP"FUS9VED
M(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`BV*W8I]F$V*H@
MV*K8L-JIV+$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,@IM<V=I
M9"`B1&\@;F]T(&1E;&5T92(*;7-G<W1R("+8K=BPV8$@V8;8M-F(V*\B"@HC
M.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O(&YO="!D
M:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@(MBOV+/8
MJMBQV+/;C"#9A=BSV*K9@MN,V84@V*C9AR!M86EN=&5N86YC92YP:'`@V879
MA=JIV88@V8;;C-BSV*HB"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN
M8SHQ,B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E
M<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y
M97,L(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R("(B"B+8HMN,V*<@V+/8M]BQ
M(-BGV8C9A"#8M-BGV879A"#9@=N,V838KR#9AMBGV84@V87;C.*`C-BHV*?8
MM-BOV)\@V*?:K]BQ(-J&V8;;C-F&(-BGV+/8JMB,(-BGVXS9AB#8K-BYV*C9
MAR#8L=BG(-BYV838I]F%V*H@V*C8LMF&VXS8KSHB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS
M9VED(")$;VUI;FEC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")$
M;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHY-@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT
M/R!3:6=N('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HX-#0*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(MBG
MV+/8JMF"V+'8I]BQ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.#0T"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S(@IM
M<V=S='(@(MBGV+/8JMF"V+'8I]BQ("5S(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`BV*?8L]BJV8+8L=BGV+$@
MV;[;C-JIV+'8J-F&V*_;C"#8JMF(V83;C-BO(-BTV*_9AR#8J-BYV8;9B-BG
MV88@V*_8L]BJ(-F&V8C;C-BS(%!(4"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q,#<*;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@(MF!
MV8?8L=BSV*H@V;[8I]N,VXS9AN*`C-F^V+$B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(MBOV*?8L=F(V8?8
MIR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I
M9"`B12U-86EL(@IM<V=S='(@(MF&V*?9A=F'(-BGV83:J=BJV+'9B-F&VXS:
MJ=N,(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP
M:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R
M(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS9W-T<B`B15)2
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-2!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-CD@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S
M.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,2!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z-S(*(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET
M+FEN8SHR-0IM<V=I9"`B161I="(*;7-G<W1R("+9B-N,V+'8I]N,V+0B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4P('1E;7!L871E<R]P
M;W)T86PO961I="YI;F,Z,C4*;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T<B`B
MV8C;C-BQV*?;C-BT(-BHV839B-JI(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ
M.3@@861M:6XO9W)O=7!S+G!H<#HR,C8*;7-G:60@(D5D:70@1W)O=7`B"FUS
M9W-T<B`BV8C;C-BQV*?;C-BT(-JOV+'9B-F'(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HW-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C$P,`IM<V=I9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@(MF(VXS8
ML=BGVXS8M"#9A=BLV8C8LB(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H
M<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`BV8C;C-BQ
MV*?;C-BT(-F%V*S9B-BRV8?8IR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M
M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z('-E<G9I8V5S+W-H87)E
M<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!097)M
M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`BV8C;C-BQV*?;C-BT(-F%V*S9B-BR
MV8?8IR#8J-BQV*?;C"`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC
M.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@(MJOV++;C-F&
MV8?B@(S9A]BGVXP@V8C;C-BQV*?;C-BT.B(*"B,@(RTC+2,M(RTC("!C;VUP
M96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@
M(D5D:70@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R("+9B-N,V+'8
MI]N,V+0@V878K-F(V++B@(S9A]BG(-BHV+'8I]N,(%PB)7-<(B(*"B,@(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`BV8C;
MC-BQV*?;C-BT(-F%V*S9B-BRXH",V8?8IR#8J-BQV*?;C"`E<R(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS-0IM<V=I9"`B161U8V%T:6]N(@IM<V=S
M='(@(MBJV*W8M=N,V838I]BJ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16=Y<'0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B16ET:&5R(&5N86)L92!I="!T:&5N.B`E
M<RP@;W(@=7-E('1H92!B87-I8R!(5$U,('9E<G-I;VXZ("5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHT,PIM<V=I9"`B16QE;65N="XN+B(*;7-G<W1R("+8N=F&V+78
ML2XN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R(")%;2(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@V.0IM<V=I9"`B16UA:6PB"FUS9W-T<B`BV8;8I]F%V8<@
MV*?9A-JIV*K8L=F(V8;;C-JIVXPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4V-2!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N
M:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C@*
M;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`BV*+8K]BQV+,@V8;8I]F%
MV8?9E"#8I]F$VJG8JMBQV8C9AMN,VJG;C"(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Y-C,*;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA
M=&-H+B(*;7-G<W1R("+8HMBOV+'8L]F'V*?;C"#9AMBGV879A^*`C-F'V*?;
MC"#8I]F$VJG8JMBQV8C9AMN,VJG;C"#8J-BGVXS8KR#9A=F&V+?8J-F"(-BH
MV*?8M-BO(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DX.0IM<V=I
M9"`B16UA:6P@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`BV8;8I]F%V8?9
ME"#8I]F$VJG8JMBQV8C9AMN,VJG;C"#8J-BG(-BJV*/;C-N,V*\B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I
M9"`B16UA:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y.`IM<V=I9"`B16UO
M=&EC;VYS(@IM<V=S='(@(MBGV*W8L]BGV+/8I]BJ(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R"FUS9VED(")%
M;7!T>2!M97-S86=E+B(*;7-G<W1R("+8KMBGV83;C"#:J=BQV*_9AB#9OMN,
MV+K8I]F%("(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR
M-#,@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0X-`HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C8R(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HW,#4*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HQ-3`*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`BV*[8
MI]F$VXP@VJG8L=BOV88@V8;8JMN,V*S9AR(*"B,Z(&9R86UE=V]R:R]344PO
M4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E87)C:"!T97)M
M<R(*;7-G<W1R("+8KMBGV83;C"#:J=BQV*_9AB#9A=F(V*?8L=BO(-BLV+/8
MJMBLV8@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-30S"FUS9VED(")%
M;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE
M<R!I;B!T97AT/R(*;7-G<W1R("+8HMN,V*<@V*_8L=BL(-BJV+78I]F(VXS8
ML2#8I]BR(-JOV*?9A-BQVXS9A]BGVXP@V+G:J=BS(-BOV+$@V878JMF&(-F!
MV+G8I]F$(-BTV8C8K]B?(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q
M.`IM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS
M9W-T<B`BV*+;C-BG(-JOV++;C-F&VJ_8I]F&(-BRV87;C-F&V8<@V+'9B-N,
M(-JIV83;C-JI(-BQV*?8L]BJ(-F!V+G8I]F$(-BTV8C8K]B?(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y."!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.#$Q"FUS9VED(")%;F0@>65A<B(*;7-G<W1R("+8I]F&V*K9A]BG
MVXP@V+/8I]F$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%9&ET;W(B"FUS9W-T<B`BV*C8
MLMBQVJ\@VJG8L=BOV88@V8C;C-BQV*?8L]BJV*?8L2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,C$*;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@
M<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@
M=&\@<F5S970@>6]U<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@
M;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B"B+;C-JI(-BSV*;9B-BG
MV80@V*?9A=F&VXS8JMN,(-BHV+'8I]N,(-F^V+'8L]BT(-BGV+(@V+39A=BG
M(-BHV8<@V8?9AMJOV*?9A2#8J-BGV++9AMBTV*?9AMBOV88@V*?8L]F%(-BQ
MV878LB#9B-BGV+'8KR#:J=F&VXS8K]B,(-F%V*O9A-BGV9(@(@HB)]F&V*?9
MA2#8K=N,V8C8I]F&(-BNV*?9AMJOVXP@V+39A=BG(-J&VXS8L]BJV)\G(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS
M9W-T<B`B55),(-BJV+79B-N,V+$@V+'8IR#8I]N,V8;8K-BG(-F(V*?8L=BO
M(-JIV8;;C-BO(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C@Y,0IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4U"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S8@<V5R=FEC97,O<&]R=&%L+VEN9&5X
M+G!H<#HX,@IM<V=I9"`B17)R;W(B"FUS9W-T<B`BV*[8M]BG(@H*(R`*(SH@
M9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S='(@
M(MBHV839B-JI(-BGVXS8K-BGV*\@V*[8M]BG.B`E<R(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C<R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T<B`B
MV*[8M]BG(-BOV+$@V*C8L=F(V++8L=BSV*?9AMN,(-BGV+/9A2#8L=F%V+(@
M.B`E<R(*"B,@"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@S"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC
M(&QO9SH@)7,B"FUS9W-T<B`BV*C9A-F(VJD@V*?;C-BLV*?8KR#8KMBWV*<Z
M("5S(@H*(R`*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT
M.B`E<R(*;7-G<W1R("+8KMBWV*<@V*_8L2#:J=BSV*@@V878K=BJV8C8ISHE
M<R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS
M9W-T<B`BV*[8M]BG(-BOV+$@V*C8L=F(V++8L=BSV*?9AMN,(-BGV+/9A2#8
ML=F%V+(@.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET:"!E;6%I;"!M97-S
M86=E+B(*;7-G<W1R("+8KMBWV*<@V*C8IR#9OMN,V+K8I]F%(-F&V*?9A=F'
MV90@V*?9A-JIV*K8L=F(V8;;C-JIVXPB"@HC(`HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z,30R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET
M:6YG(%PB)7-<(BXB"FUS9W-T<B`BV*[8M]BGVXP@V8;9B-BTV*K9AB`G)7,G
M("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S`*(RP@9G5Z>GD*;7-G:60@(D5S=&]N:6$B"FUS9W-T
M<B`BV+G8JMN,V8+9AR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T:&EO<&EA(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-@IM<V=I9"`B
M171H;FEC(@IM<V=S='(@(MBYV*K;C-F"V8<B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*;7-G<W1R("+8I]BQ
MV8C9OMBG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S.0IM<V=I9"`B
M179E<GD@,34@;6EN=71E<R(*;7-G<W1R("+9A]BQ(-F^V*?9AMBRV*_9AR#8
MK]F"VXS9@MF'(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X.0IM<V=I
M9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(MF'V+$@V*_9B"#8K]F"VXS9
M@MF'(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S@W"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S
M='(@(MF'V+$@V+/;C"#8K]F"VXS9@MF'(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,S."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDP"FUS9VED(")%
M=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`BV8?8L2#9OMF&V*P@V*_9@MN,V8+9
MAR(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z
M-C`*;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S='(@(MBOV+$@V8?8L2#9B-BQ
MV8C8KR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`*;7-G:60@(D5V
M97)Y(&AA;&8@:&]U<B(*;7-G<W1R("+9A]BQ(-F&VXS9A2#8L]BGV+G8JB(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S<@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,X.`IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@(MF'V+$@
MV*_9@MN,V8+9AR(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(T
M"FUS9VED(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`BV879@MBGV*_;C-BQ
M(-F%V*O8I]F$.B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HX,2!A9&UI;B]C
M;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP.C$R-PIM<V=I9"`B
M17AE8W5T92(*;7-G<W1R("+8I]BLV+'8IR(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C0W-0IM<V=I9"`B17AP86YD(@IM<V=S='(@
M(MBHV*?8LB#:J=BQV*_9AB(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A
M<BYI;F,Z,S(*;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@(MBHV*?8
MLMJIV+'8K]F&(-F&V8C8I]BQ(-JIV8;8I]BQVXPB"@HC.B!F<F%M97=O<FLO
M4U%,+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B
M"FUS9W-T<B`BV*?9AMBJV+C8I]BQ(-BHV+'8I]N,("<H)R(*"B,Z(&9R86UE
M=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-S4*;7-G:60@(D5X<&5C=&5D
M(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")%
M>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`BV*K8I]BQVXS8KB#8I]F&V8+8MMBG
MV*$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-@IM
M<V=I9"`B17AP;VYE;G0B"FUS9W-T<B`BV8;9A=BGVXS9AMBOV8<B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Q
M"FUS9VED(")&1R!#;VQO<B(*;7-G<W1R("+8L=F&VJ\@V;[;C-BTXH",V++9
MA=N,V8;9AR(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S<*;7-G:60@
M(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B1E10('5P;&]A9"!O9B!S
M971U<"(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S<6PN<&AP.C(Q-@IM
M<V=I9"`B1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N(@IM<V=S='(@
M(B#8J-BGV++;C-BGV*C;C"#8JMF"V*_9A=BGV*H@V8;8I]F%V8C9@=F1V8(@
MV*C9B-BO(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<U
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z.3@*;7-G:60@(D9A:6QE
M9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R("(@V*?8JMBU
MV*?9A"#8J-F'(-JIV*?8L=BSV*?8LB!,1$%0(-F&V*?9A=F(V8'9D=F"(-BH
MV8C8KR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HY.`IM<V=I
M9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`B
M(-BGV*K8M=BGV80@V*C9AR#:J=BGV+'8L]BGV+(@4TU"(-F&V*?9A=F(V8'9
MD=F"(-BHV8C8KR`B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8X
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!F<F]M(%PB
M)7-<(BXB"FUS9W-T<B`B(-BJV8?;C-F'(-BQV8C9AMF(V+38JB#8I]BR(%PB
M)7-<(B#9AMBGV879B-F!V9'9@B#8J-F(V*\B"@HC(",M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C8Y,0HC+"!P:'`M9F]R;6%T"FUS9VED(")&
M86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(MBGVXS8K-BGV*\@
MV+'9B-F&V8C8M-BJ(-BOV+$@7"(E<UPB(-F&V*?9A=F(V8'9D=F"(-BHV8C8
MKR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#<*;7-G:60@
M(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T
M<B`B(-BGVXS8K-BGV*\@VXS:J2#8I]BJV+78I]F$(-BLV*_;C-BO(%-!4TP@
MV8;8I]F%V8C9@=F1V8(@V*C9B-BO(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HT.3<@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,C0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*
M;7-G<W1R("(@V*?9AMBJV8+8I]F$(-BHV8<@7"(E<UPB(-F&V*?9A=F(V8'9
MD=F"(-BHV8C8KR(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8Q
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@<F5T<FEE
M=F4Z("5S(@IM<V=S='(@(B#8I]F&V*K9@MBGV80@V*C9AR!<(B5S7"(@V8;8
MI]F%V8C9@=F1V8(@V*C9B-BO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T<B`BV838M]N,
MV8$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<R"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV
M:6YA<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C,X
M"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`BV*[8M]BGVXP@V*S8K]N,
M.B`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3@W"FUS9VED(")&87@B"FUS9W-T<B`BV8':J=BS(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,T.0HC+"!F=7IZ>0IM<V=I9"`B1F%X97,B"FUS
M9W-T<B`BV8':J=BS(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(MF!V8C8L=N,
MV8<B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R,`IM<V=I9"`B1F5E;',@
M3&EK92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C,Q"FUS9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E
M=R!3:&]W97)S(@IM<V=S='(@(MBQVJ_8J-BGV+$@V*[9@=N,V8$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B
M1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R("+:J=F%VXP@V*K:K]BQVJ\B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30T"FUS9VED(")&:65L9"!M
M871R:7@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S,S-`IM<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S.`IM<V=I9"`B1FEG;&5T(&9O;G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEJ:2(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*
M;7-G:60@(D9I;&4B"FUS9W-T<B`BV;[8L=F(V8;8K]F'(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL
M92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R("+8M-F%V*?8L=BT(-F^V+'9B-F&
MV*_9ASH@)7,@V;[8L=F(V8;8K]F'(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@
M9FEL97,B"FUS9W-T<B`BV+39A=BGV+'8M"#9OMBQV8C9AMBOV8<Z("5S(-F^
MV+'9B-F&V*_9AR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#<*
M;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R("+9A=BOVXS8L2#9OMBQV8C9
MAMBOV8<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C8S(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-0IM<V=I9"`B
M1FEL92!.86UE(@IM<V=S='(@(MF&V*?9A2#9OMBQV8C9AMBOV8<B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3DU"FUS9VED(")&:6QE('-E;&5C
M=&EO;B(*;7-G<W1R("+8I]F&V*K8KMBGV*@@V;[8L=F(V8;8K]F'(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30X-@IM<V=I9"`B1FEL92!U<&QO
M860B"FUS9W-T<B`BV*?8L=BSV*?9A"#9OMBQV8C9AMBOV8<B"@HC.B!F<F%M
M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-3D*;7-G:60@(D9I;&4@=7!L
M;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("+8I]BQV+/8I]F$(-F^V+'9
MB-F&V*_9AR#9OMBTV*K;C-BHV*?9AMN,(-F&V87;C.*`C-BTV8C8KRXN(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Y"FUS9VED(")&:6QT97)S
M(@IM<V=S='(@(MF!VXS9A-BJV+'9A]BG(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0HC+"!F=7IZ
M>0IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R("+8K]BQV*[8MR(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B
MV8;;C-F%V8<@V*?9B-F$(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI
M8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A<G1E<B(*;7-G
M<W1R("+8L=BHV+D@V*?9B-F$(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(U-@IM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@
M(MF&V+/8J-BJ(-BKV*?8J-BJ(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(S,0IM<V=I9"`B1FQI<"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,R"FUS9VED(")&;&]A="(*;7-G<W1R("+8I]BYV+38I]BQVXPB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B
M1F]G(@IM<V=S='(@(MF%V8?B@(S8HMF$V8C8KR(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,C,T(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HQ,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T
M(&5X:7-T(@IM<V=S='(@(MF^V8C8M-F'("5S(-F%V8C8K-F(V*\@V8;;C-BS
MV*H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R("+8L=F&VJ\@V8+9A-F%
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS9VED(")&;V]D(@IM
M<V=S='(@(MBZV+#8IR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R;W=S97)S
M('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`BV*C8L=BGVXP@
MV878L=F(V+':K]BQV8?8I]N,VXP@VJG9AR#8JMBUV*?9B-N,V+$@V+'8IR#9
MOMBTV*K;C-BHV*?9AMN,(-F&V87;C.*`C-JIV8;9AMBO(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS,S0*;7-G:60@(D9O<F5C87-T("A4048I(@IM<V=S
M='(@(MF^VXS8M,*MV*C;C-F&VXPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-SD*;7-G:60@(B(*(D9O<F5C87-T($1A>7,@*&YO=&4@=&AA
M="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@
M;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN
M(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHQ,#(*;7-G:60@(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*
M;7-G<W1R("+8I]BSV84@V+'9A=BR(-BNV8C8KR#8L=BG(-F!V+'8I]F%V8C8
MM"#:J=BQV*_9A^*`C-BGXH",VXS8K]B?(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0V,@IM<V=I9"`B1F]R;7,B"FUS9W-T<B`BV8'8L=F%V8?8
MIR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N
M92(*;7-G<W1R("+8M]BGV838N2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S='(@(MF&V8C8N2#8M]BG
MV838N2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM<V=I9"`B1F]R
M='5N97,B"FUS9W-T<B`BV+?8I]F$V+G9A]BG(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,Y"FUS9VED(")&;W)T=6YE<R`R(@IM<V=S='(@(MBWV*?9
MA-BYV8?8IR#;LB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-3,*
M;7-G:60@(D9O<G5M<R(*;7-G<W1R("+8I]F&V*S9A=F&V8?8IR(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#D*;7-G:60@(D9O<G=A<F1S(@IM
M<V=S='(@(MBGV+'8K-BGV+G9A]BG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`BV*S9
MA=BYV8<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,S"FUS9VED(")&<F%M97,B"FUS9W-T<B`BVH;8I]BQVH;9
MB-BHV8?8IR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S,*(RP@9G5Z>GD*;7-G:60@(D9R86YC92(*
M;7-G<W1R("+:AMBGV+':AMF(V*C9A]BG(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDQ(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H
M97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB"FUS9W-T
M<B`BV*?8LB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#@@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,`HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-#`V"FUS9VED(")&<F]M('1H92`B"FUS9W-T
M<B`BV*?8LB`B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT
M.`IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R("+8M-BQV*T@VJG8
MI]F%V80B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K+VUO
M;VXN<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(MF%V*?9AR#:
MJ=BGV879A"(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8P"FUS9VED(")&=6QL($YA;64B
M"FUS9W-T<B`BV8;8I]F%(-JIV*?9A=F$(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B
M1V%B;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL97)Y('1O
M('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R("+:K]BGV838L=N,(-BHV+'8I]N,
M(-BOV+';C-BGV8'8JB#8JMBUV8C;C-BQ("(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I9"`B
M1V%L;&5R>3HB"FUS9W-T<B`BVJ_8I]F$V+';C#HB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS
M9VED(")'86UB:6$B"FUS9W-T<B`B(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E
M<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(MBJV8C9A-N,V*\@V;[;C-JIV+'8
MJ-F&V*_;C"`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N
M:'1M;#HX"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G<W1R("+:J=BO(-BJ
MV8C9A-N,V*\@V+38K]F'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1V5O<F=I82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")'97)M86YY(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S4*;7-G:60@(D=H86YA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-0IM<V=I9"`B1VEV96X@3F%M
M92(*;7-G<W1R("+9AMBGV84@V*_8I]BOV8<@V+38K]F'(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V%P<"YI;F,Z,3(*;7-G:60@(D=O(@IM<V=S='(@(MBHV+'9
MB"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,`IM<V=I9"`B1V]E9&5L
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,3(X"B,L(&9U>GIY"FUS9VED(")';V]G;&4@36%P<R(*;7-G
M<W1R("+8K-BSV8;8K-F(VXP@VJ_9B-JOV80B"@HC.B!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H(@IM<V=S='(@(MBL
MV+/9AMBLV8C;C"#:K]F(VJ_9A"(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,S<*;7-G:60@(D=R87ES8V%L92(*;7-G<W1R
M("+8K]BQV*S9AR#8KMBGVJG8L]BJV+';C"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED
M(")'<F5E8V4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#4*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R(")'<F5E:R`H
M25-/+3@X-3DM-RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDU
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'<F5E;FQA;F0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1W)E;F%D82(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W.0IM<V=I9"`B1W)O=7`@061M:6YI
M<W1R871I;VXB"FUS9W-T<B`BV+/8L=F^V+'8L]BJVXP@VJ_8L=F(V8<B"@HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`N<&AP.C4Y(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@
M8F4@;F]N+65M<'1Y(@IM<V=S='(@(MF&V*?9A2#:K]BQV8C9AR#9AMBHV*?;
MC-BO(-BNV*?9A-N,(-BHV*?8M-BO(@H*(R`*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C,P-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I
M<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*(D%U=&A?;&1A
M<#K8I]BVV*?9@=F'(-JIV+'8K]F&(-JIV*?8L=BHV+$@)7,@V879A=JIV88@
MV8;;C-BSV*HN(-BGVXS9AB#:AMN,V++;C"#8I]BSV*H@VJG9AR#:J=BGV+'8
ML]BGV+(@VJ_9@=BJV8<@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C$Q."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,3(T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT,3@*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L
M92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS9W-T<B`B075T:%]L9&%P.MBHV+'9
MB-BRV+'8L]BGV8;;C"#:J=BGV+'8J-BQ("5S(-F%V87:J=F&(-F&VXS8L]BJ
M(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,S."!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R
M;W5P("5S(@IM<V=S='(@(D%U=&A?;&1A<#K8J-BQV8C8LMBQV+/8I]F&VXP@
MVJG8I]BQV*C8L2`E<R#9A=F%VJG9AB#9AMN,V+/8JB(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,S$T(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<W"FUS9VED(")'
M<F]U<',B"FUS9W-T<B`BVJ_8L=F(V8<F(W@R,#!C.]F'V*<B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W
M"FUS9VED(")'=6%M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'
M=6%T96UA;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY,@HC+"!F=7IZ>0IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`BV++;
MC-BQV;[;C-BQV*?9A]F&VXPB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED
M(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R("+9A=BLV8C8LMF'V*?;C"#9
MA=F'V878I]F&(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W,`IM
M<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(MJIV*K8I]BHVH;9A]F4(-N,V*?8
MK]BHV8C8KR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(D=U:6YE82(*
M;7-G<W1R("+:F-F(V*;9AB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5I;F5A
M+4)I<W-A=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U>6%N
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-C`*
M;7-G:60@(DA434PB"FUS9W-T<B`B2%1-3"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G:60@(DA434Q!
M<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@
M:6X@<F]W+B(*;7-G<W1R(")(5$U,07)E82#8K=BPV8$@V*+8KMBQVXS9AB#8
ML]F$V8C9A"#8L=BG(-BOV+$@V+'8K]N,V8$@V+'8KR#9A=N,XH",VJG9AMBO
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D
M96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R(")(5$U,
M07)E82#8K=BPV8$@V*+8KMBQVXS9AB#8L]BJV8C9AB#8L=BG(-BOV+$@V*S8
MK]F(V80@V+'8KR#9A=N,XH",VJG9AMBO(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R
M96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN
M('1A8FQE+B(*;7-G<W1R(")(5$U,07)E82#8K=BPV8$@V*+8KMBQVXS9AB#8
ML=BOVXS9@2#8L=BG(-BOV+$@V*S8K]F(V80@V+'8KR#9A=N,XH",VJG9AMBO
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HQ-3<*;7-G:60@
M(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("+8JMBU
MV*_;C-F"(-F'V8C;C-F1V*H@2%144"#;C-BGV8'8JMF'(-F&V+38KR(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,`HC+"!F=7IZ>0IM<V=I9"`B2&%I=&DB"FUS9W-T<B`BV8;8
ML]BHV*HB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*
M;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(MBGV83:K]F(V+';C-BJ
MV84@2&%S:"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@(MF%V8?B@(S8HMF$V8C8KR(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDQ.2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.3,R"FUS9VED(")(96%D97(B"FUS9W-T<B`BV+/8L=BB
MV878KR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP
M:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(DAE861E<G,B"FUS9W-T<B`BV+/8L=BB
MV878KR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-
M8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"B,L(&9U>GIY"FUS9VED(")(96%V
M>2!4+5-T;W)M(@IM<V=S='(@(E0M4W1O<FUS(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#8*;7-G:60@(DAE8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G
M<W1R(")(96)R97<@*$E33RTX.#4Y+3@M22DB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T"FUS9VED(")(96EG
M:'0B"FUS9W-T<B`BV*C9A-F&V*_;C"(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92](96QP+G!H<#HQ-SD@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N
M<&AP.C$X-@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ-R!T96UP;&%T
M97,O:&5L<"]I;F1E>"YI;F,Z,PIM<V=I9"`B2&5L<"(*;7-G<W1R("+8L=BG
MV8?9AMF%V*<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R("+8
ML=BGV8?9AMF%V*?;C"#8I]BSV*K9@=BGV*_9AR#8I]BR(-F(VXS8L=BGVXS8
MM-JOV+$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<Q"FUS9VED
M(")(96QP97(B"FUS9W-T<B`BVJG9A=JI(-JIV8;9AMBOV8<B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`B
MV8;;C-F%XH",VJG8L=F'(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI
M;F,Z,3`@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3`*;7-G:60@(DAE
M<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`BV*?;
MC-F&V*S8IR#8I]BHV*K8K]BGVXP@V;[8L=F(V8;8K]F'XH",(-F%VXSB@(S8
MJ-BGV+38KSHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV.0IM<V=I9"`B2&EG:"(*;7-G<W1R("+8J-BGV838IR(*"B,Z('1E
M;7!L871E<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M
M;6]N+6AE861E<BYI;F,Z-0IM<V=I9"`B2&]?;64B"FUS9W-T<B`BV*[8I]F&
MV8<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")(;VQY(%-E92`H5F%T:6-A;B!#
M:71Y(%-T871E*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C$U,S4*;7-G:60@(DAO;64B"FUS9W-T<B`BV*[8I]F&V8<B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-34*;7-G
M:60@(DAO;64@061D<F5S<R(*;7-G<W1R("+8HMBOV+'8LR#8KMBGV8;9AR(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-`IM<V=I9"`B2&]M92!$:7)E
M8W1O<GDB"FUS9W-T<B`BV+38I]BNV8?9E"#8I]BUV83;C"(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3`*;7-G:60@(DAO
M;64@4&AO;F4B"FUS9W-T<B`BV+39A=BGV+'9AR#8JMF$V8'9AB#9A=F&V++9
MA"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<X"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8U"FUS9VED(")(;W)D92(*;7-G
M<W1R("+9A]F(V+'8KR(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M-#0R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED
M("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z("5S(-BHV*<@V*_8I]BOV8<@V8;8I]BOV+'8L]BJ
M(%A-3"#8K]BQ(-F^VXS8NMBGV84@)7,@V879B-BGV*S9AR#8M-BOV8<@V*?8
ML]BJ(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR.3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S
M<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B#9A]N,
MVH8@V;[;C-BZV*?9A=N,(-F%V+?8I]BHV8+8JB#8J-BG(-BTVXS8H2`E<R#9
MAMBOV*?8L=BO(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT,S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O
M9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O
M2V]L86(Z(-F'VXS:AB#8M-N,V*;;C"#8I]BR(-F&V8C8N2`E<R#8K]BQ(-F^
MVXS8NMBGV84@)7,@VXS8I]F!V*H@V8;8M-BO(@H*(R`*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HQ,C4P"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS
M9W-T<B`B2&]R9&4O2V]L86(Z(-BHV*<@V879B-F!V9'9@MN,V9'8JB`E<R!<
M(B5S7"(@V*W8L-F!(-BTV*\B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E
M;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HU,#,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A
M=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O
M2V]L86(Z(-BJV8C9A-N,V*\@VXS:J2#8K]BQV*[8JB#8K-BOVXS8KR!834P@
MV*C8L=BGVXP@V+3;C-BA("5S(-F%V8+8K]F(V+$@V8;;C-BSV*H@(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0W"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<
M(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(-BMV+#9@2`E<R!<(B5S7"(Z
M)7,@V879@MBOV8C8L2#9AMN,V+/8JB(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z-#<T"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@
M='EP92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@V*C8I]BRVXS8I]BHVXP@
M($U)344@240@V*C8L=BGVXP@V8+8L]F%V*K;C"#8I]BR(-F&V8C8N2`E<R#9
MA=F"V*_9B-BQ(-F&VXS8L]BJ("(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,3$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M56YA8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B
M2&]R9&4O2V]L86(Z(-BSV8;:J=BQV8C9AB#:J=BQV*_9AB`E<R!<(B5S7"(Z
M("5S(-F%V8+8K]F(V+$@V8;;C-BSV*HB"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C$S,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@
M(DAO<F1E+TMO;&%B.B#8L]F&VJG8L=F(V88@VJG8L=BOV88@V*?8M-BJV+'8
MI]JIV8?8IR#9A=F"V*_9B-BQ(-F&VXS8L]BJ.B`E<R(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*;7-G<W1R(")(;W)D
M92]+;VQA8CH@V*?8M-BJV+'8I]JI(-F&V*?8M-F&V*?8KMBJV8<@7"(E<UPB
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M-`IM<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(MF"V*?9AMF(V88@
MV*?9@=F"VXPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B
MV8'8I]BUV839A^*`C-JOV+#8I]BQVXP@V*?9@=F"VXPB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I
M>F]N=&%L.B(*;7-G<W1R("(ZV*?9@=F"VXPB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3$*;7-G:60@(DAO
M=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I(@IM<V=S='(@
M(MJ&VJ_9B-F&V8<@V*C8IR#8I]N,V8;8K-BG(-BBV+39AMBG(-BTV*_;C-BO
MV)\@*-F$V+?9@=BGV8L@VJ_8LMBGV+'8M"#8K]F'VXS8KRDA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0IM
M<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G
M93\B"FUS9W-T<B`BVH;9AMBO(-BSV*K9B-F&(-BQV*<@V87;C.*`C-BNV8C8
MI]F'VXS8KR#8I]BOV+K8I]F%(-JIV8;;C-BOV)\B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC
M;VQU;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@(MJ&V8;8KR#9@=N,V838KR`H
MV+/8JMF(V88I(-F(V*S9B-BO(-BOV*?8L=BOV)\B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(
M;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R
M("+:AMF&V*\@V+/8M]BQ(-BQV*<@V87;C.*`C-BNV8C8I]F'VXS8KR#8I]BO
MV+K8I]F%(-JIV8;;C-BOV)\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S`P(&QI8B]";&]C:R]M971A<BYP:'`Z,C,P"FUS9VED(")(=6UI
M9&ET>2(*;7-G<W1R("+8L=BWV8C8J-BJ(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(U.0IM<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R("+8
ML=BWV8C8J-BJ.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G
M:60@(DAU;6]R:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@
M(DAU;F=A<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)U<RYP:'`Z,3<R(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR
M,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N
M(&9A:6QE9#H@)7,B"FUS9W-T<B`BV*?;C-BLV*?8KR#9AMBGV879A^*`C-BO
MV*?9AB!)34%0(-F&V*?9A=F(V8'9D=F"(-BHV8C8KSH@("5S(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C$T(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!
M4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`BV*W8L-F!
M(-F&V*?9A=F'XH",V*_8I]F&($E-05`@V8;8I]F%V8C9@=F1V8(@V*C9B-BO
M(#H@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-SD@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(T,@HC+"!P:'`M9F]R
M;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D
M.B`E<R(*;7-G<W1R("+8I]N,V*S8I]BO(-F%V*W8K]F(V*_;C-F1V*H@V8;8
MI]F%V8?B@(S8K]BGV88@24U!4"#9AMBGV879B-F!V9'9@B#8J-F(V*\@.B`E
M<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,38*;7-G:60@(DE0
M($%D9')E<W,B"FUS9W-T<B`BV*+8K]BQV+,@25`B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED("))4"!!9&1R97-S(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(MBBV*_8L=BS($E0(-F"V*?8J-F$(-BO
MV+/8JMBQV+/;C"#9AMN,V+/8JB(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I=&AI;B!A
M;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@(MBBV*_8L=BS($E0(-BOV+$@
MV*_8I]BNV80@V*C9A-F(VJD@0TE$4B#8I]BLV*?8LMF'(-BOV*?8K]F'(-F&
MV87;C.*`C-BTV8C8KR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO;&%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W($)E
M9F]R92(*;7-G<W1R("+8I]BHV*K8K]BG(-BSV+?8L2#8L=BG(-F(V*?8L=BO
M(-JIV8;;C-BO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))8V5L86YD(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S8*;7-G:60@(DEC
M;VYS($]N;'DB"FUS9W-T<B`BV8'9@MBW(-BBVXS:J=F(V8;9A]BG(@H*(R`C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*
M(R`*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M870*
M;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R("+8HMN,VJG9B-F&V8?8IR#8
MJ-BQV*?;C"`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S<*;7-G
M:60@(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R("+8HMN,VJG9B-F&V8?8IR#8
MJ-BG(-F%V*K9AB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3`*;7-G
M:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`BV8;8I]F%(-F'V8C;C-F1
MV*HZ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DR
M"B,L('!H<"UF;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@
M8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS
M9W-T<B`BV*?:K]BQ(-BBV88@V*C9AR#8K]BQV+/8JMN,(-F&V878I]N,V+0@
MV*_8I]BOV8<@V8;8M-BOV(P@)7,@(-BHV+'8I]N,(-BHV*?8LB#:J=BQV*_9
MAB#8HMF&(-BOV+$@VXS:J2#9OMF&V*S8L=F'(-BLV*_;C-BO(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0U-0IM<V=I9"`B(@HB268@>6]U(&1O;B=T
M('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M
M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@
M=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"B+8I]JOV+$@V+39A=BG(-F'VXS:
MAB#8HMN,VJG9B-F&VXP@V+'8IR#8K]BQ(-F%V+'9B-BQVJ_8L2#9AMBHVXS9
MAMN,V*_8C"#9A=F%VJG9AB#8I]BSV*H@V838I]BRV84@V*C8I]BTV*\@VJG9
MAR!03D<@(@HB5')A;G-P87)E;F-Y(-BQV*<@V*[8I]F%V8C8M"#:J=F&VXS8
MKR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M-S,*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I
M;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B
M"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"B+8I]JO
MV+$@V+39A=BG(-BGVXS9AB#9OMN,V+K8I]F%(-BQV*<@V878M-BGV8?8K]F'
M(-JIV8;;C-BO(-BGV878IR#8JMBUV8C;C-BQVXP@V+'8IR#9A=BTV*?9A]BO
MV8<@V8;:J=F&VXS8K]B,(-BGVXS9AB#8J-F'(-BGVXS9AB#8N=F$V*H@(@HB
MV*[9B-BGV8?8KR#8J-F(V*\@VJG9AR#9A=BQV8C8L=JOV+$@V+39A=BG(-F!
MV*?8K]BQ(-BHV8<@V8;9A=BGVXS8M"#8JMBUV8C;C-BQ(-F&VXS8L]BJ("(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR.`IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T<B`BV;[;
MC-BTXH",V8;9A=BGVXP@V*K8M=F(VXS8L3HB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,W"FUS9VED("));6%G
M92!54DPB"FUS9W-T<B`B55),(-BJV+79B-N,V+$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G
M:60@(DEM86=E(%523#HB"FUS9W-T<B`B55),(-BJV+79B-N,V+$Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`BV*K8
MM=F(VXS8L2#8I]BR(-JOV*?9A-BQVXPB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@(DEM
M86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`BV*K8M=F(VXS8L2#8I]BR(-JO
MV*?9A-BQVXPZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,0IM
M<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(MBGV+'8L]BGV80@V*K8M=F(
MVXS8L2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("));6%G
M97,B"FUS9W-T<B`BV*K8M=BGV8C;C-BQ(@H*(R`C+2,M(RTC+2,@(&-O;7!E
M;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@=&5M<&QA=&5S
M+V1A=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T82]D871E;6%P+FEN
M8SHW"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-30@=&5M<&QA=&5S
M+V1A=&$O8W-V:6YF;RYI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("));7!O
M<G0L(%-T97`@)60B"FUS9W-T<B`BV*_8L=F(V8;B@(S8J-BQV*_8C"#:K]BG
MV84@)60B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@
M(",M(RTC+2,M(PHC(`HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHQ
M-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS
M9W-T<B`BV8';C-F$V*\@V*_8L=F(V8;B@(S8J-BQV*\@V+38K]F'.B`E<R(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM<&]R
M=&5D(&9I96QD<SHB"FUS9W-T<B`BV8';C-F$V*_B@(S9A]BGVXP@V*_8L=F(
MV8;B@(S8J-BQV*\@V+38K]F'.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2
M;W<@069T97(B"FUS9W-T<B`BV*C8N=BOV*?9BR#8L]BWV+$@V+'8IR#9B-BG
MV+'8KR#:J=F&VXS8KR(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]Z:7`N<&AP.C$S-0IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I
M=F5N+B(*;7-G<W1R("+:J=BO(-BYV879A-JIV+'8KR#9AMBGV*_8L=BSV*H@
MV*_8I]BOV8<@V+38K]F'(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"FUS9VED("));F-O<G)E8W0@
M=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+B(*;7-G<W1R("(@V8;8I]F%(-JI
MV*?8L=BHV+$OV*?8L]F%(-BQV878LB`@V8;8I]BOV+'8L]BJ(-BGV+/8JB(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED("(B"B))
M;F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A
M9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M:6YI<W1R871O<B!I9B!Y;W4@
M;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(MF&V*?9A2#:J=BGV+'8
MJ-BQ(-N,V*<@V*+8K]BQV+,@V*S8I]N,VJ_8LMN,V88@V8;8I]BOV+'8L]BJ
M(-F%VXSB@(S8J-BGV+38KRX@V838M]F!V*<@V878K-BOV*_8I]F2(-BSV+G;
MC"#:J=F&VXS8KR#9B"#;C-BG(-BOV+$@V+79B-BQV*H@(@HBV8;;C-BGV+(@
MV*C9AR#:J=F%VJD@V*C;C-BTV*K8L2#8J-BG(-BSV+'9OMBQV+/8JB#8L]BG
MV878I]F&V8<@V*K9A=BGV+,@V*C:K]N,V+';C-BO(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A
M<V4@26YD96YT(@IM<V=S='(@(MBGV8'8LMBGVXS8M"#8JMF(V+'9@=BJVJ_;
MC"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B26YD:6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS
M9W-T<B`BVJG8I]BQV*C8L=BGV88@V*[8I]BU(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS
M9VED("));F1O;F5S:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B26YF;R(*;7-G<W1R
M("+8I]BWV838I]BYV*?8JB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR-3<*;7-G:60@(DEN9F]R;6%T:6]N(@IM<V=S='(@(MBGV+?9A-BGV+G8
MI]BJ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,S,`IM<V=I
M9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB"FUS9W-T<B`B
MV*?8M]F$V*?8N=BGV*H@V*_;C-JOV+$@V*_8L2#8K]BSV*K8L=BS(-F&VXS8
ML]BJ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G
M<W1R("+8K]BQV*P@V+/8JMF(V88@V*C8N=BO(-BGV+(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*
M;7-G:60@(DEN<V5R="!);6%G92(*;7-G<W1R("+8K]BQV*P@V*K8M=F(VXS8
ML2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R("+8K]BQV*P@V*S8K]F(
MV80B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(U"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`BV*_8L=BL(-F^
MVXS9B-F&V*\@V8C8J"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T(%]#;VQU;6X@
M0F5F;W)E(@IM<V=S='(@(MBGV*C8JMBOV*<@V+/8JMF(V88@V+'8IR#8K]BQ
MV*P@VJG9AMN,V*\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU
M;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(MN,VJD@V+/8JMF(
MV88@V*S8K]N,V*\@V*C8N=BO(-BGV+(@V+/8JMF(V88@V8'8N=F$VXP@V*_8
ML=BL(-JIV8;;C-BO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("));G-E<G0@82!N97<@8V]L
M=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`BVXS:J2#8L]BJ
MV8C9AB#8K-BOVXS8KR#9@MBHV80@V*?8LB#8L]BJV8C9AB#9@=BYV83;C"#8
MK]BQV*P@VJG9AMN,V*\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R
M;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(MN,VJD@V+/8M]BQ
M(-BLV*_;C-BO(-BHV+G8KR#8I]BR(-BSV+?8L2#9@=BYV83;C"#8K]BQV*P@
MVJG9AMN,V*\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F
M;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("+;C-JI(-BSV+?8L2#8K-BO
MVXS8KR#9@MBHV80@V*?8LB#8L]BWV+$@V8'8N=F$VXP@V*_8L=BL(-JIV8;;
MC-BO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C<P"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@869T97(@
M=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("+;C-JI(-F^V*?8L=BGVJ_8L=BG
MV8$@V*C8N=BO(-BGV+(@VJ_8L=F'(-F!V+G9A-N,(-BOV+'8K"#:J=F&VXS8
MKR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T
M:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(MN,VJD@V;[8I]BQV*?:K]BQV*?9
M@2#9@MBHV80@V*?8LB#:K]BQV8<@V8'8N=F$VXP@V*_8L=BL(-JIV8;;C-BO
M(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A
M;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`BV*_8L=BL(-BGV83:K]F(VXP@
MV*S8I]N,VJ_8LMN,V88B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,Y
M"FUS9VED("));G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@
M8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`BVXS:J2#8
MHMBOV+'8LR#9OMBSV*H@V*?9A-JIV*K8L=F(V8;;C-JI(-BHV+'8I]N,(-BO
MV+';C-BGV8'8JB#8I]BSV84@V+'9A=BR("#8K-BOVXS8KR#8K]BQV*P@VJG9
MAMN,V*\@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU.`IM<V=I9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T
M<B`BV*_8L=BL(-BSV839B-F$(-BHV+G8KR(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R
M="!C96QL(&)E9F]R92(*;7-G<W1R("+8K]BQV*P@V+/9A-F(V80@V8+8J-F$
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R("+8
MK]BQV*P@V+/8JMF(V88@V*C8N=BO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O
M;'5M;B!B969O<F4B"FUS9W-T<B`BV*_8L=BL(-BSV*K9B-F&(-F"V*C9A"(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS
M9VED("));G-E<G0@;65S<V%G97,B"FUS9W-T<B`BV*_8L=BL(-F^VXS8NMBG
MV84B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-#4*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS
M9W-T<B`BV*_8L=BL(-F^V*?8L=BGVJ_8L=BGV8$@V*C8N=BO(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T
M"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*;7-G<W1R("+8K]BQ
MV*P@V;[8I]BQV*?:K]BQV*?9@2#9@MBHV80B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Y"FUS9VED("));G-E
M<G0@<F]W(&%F=&5R(@IM<V=S='(@(MBOV+'8K"#8L]BWV+$@V*C8N=BO("(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C@*;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM<V=S='(@(MBOV+'8
MK"#8L]BWV+$@V8+8J-F$(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S
M,`IM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E
M8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R("+9OMBGV+/8KB#9A=F(V+'8KR#9
MAMN,V*?8LB#8L=BG(-BHV+'8I]N,(-BSV*;9B-BGV80@V*?9A=F&VXS8JMN,
M(-BOV+'8K"#:J=F&VXS8KSHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(V"FUS9VED("));G-E<G0O36]D:69Y($EM86=E
M(@IM<V=S='(@(MBOV+'8K"_8JMBZVXS;C-BQ(-BJV+79B-N,V+$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED
M("));G-E<G0O36]D:69Y($QI;FLB"FUS9W-T<B`BV*_8L=BL+]BJV+K;C-N,
MV+$@V;[;C-F(V8;8KR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET
M('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("+8
MI]BYV*K8J-BGV+$@V8;8I]JIV*?9@=N,(-BHV+'8I]N,(-BGV+'8L]BGV80@
MV*C9AR#9@=F'V+'8L]BJ(-BJV8C8LMN,V+G;C"(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("));G-U
M9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R("+8I]BYV*K8J-BGV+$@V8;8I]JI
MV*?9@=N,(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`W-0IM<V=I
M9"`B26YT96=E<B(*;7-G<W1R("+8N=BOV*\@V+78K=N,V*TB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3,S"FUS9VED("));G1E9V5R(&QI<W0B
M"FUS9W-T<B`BV8'9A]BQV+/8JB#8N=BOV*\@V+78K=N,V*TB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G
M:60@(DEN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN(@IM<V=S='(@
M(E5$2"#9AMBGV878N=BJV*C8L2(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]Z:7`N<&AP.C$W,`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M
M<')E<W,O>FEP+G!H<#HR,#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+WII<"YP:'`Z,C$P"B,L(&9U>GIY"FUS9VED("));G9A;&ED(%I)4"!D
M871A(@IM<V=S='(@(MBOV*?8K]F'(-N,V8C9AMN,VJG8KR#9AMBGV878N=BJ
MV*C8L2`B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T"FUS9VED("))
M;G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R("+8J-BQV8;8I]F%V8?9E"#:
MJ=BGV+'8J-BQV*_;C"#9AMBGV878N=BJV*C8L2(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV
M86QI9"!B871C:"!)1"XB"FUS9W-T<B`BV*_8L]BJV8<@240@V8;8I]F%V+G8
MJMBHV+$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#@W(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(S,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,CDY"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<*;7-G:60@
M(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@(MBOV*?8K]F'V90@
MV8;8I]F%V+G8JMBHV+$@V*?8L=BGV*;9AR#8M-BOV8<B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*;7-G:60@
M(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB"FUS9W-T<B`BV*+8K]BQ
MV+,@V879@MBUV*\@V8;8I]F%V+G8JMBHV+$B"@HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HX,0HC.B!F<F%M97=O<FLO0V]M<')E
M<W,O0V]M<')E<W,O9&)X+G!H<#HQ,#`*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+V1B>"YP:'`Z,C(P"FUS9VED("));G9A;&ED(&9I;&4@9F]R
M;6%T(@IM<V=S='(@(MF"V*?9A-BH(-F^V+'9B-F&V*_9A]F4(-F&V*?9A=BY
MV*K8J-BQ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-PHC
M+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS9W-T<B`B
MV*C8L=F&V*?9A=F'V90@VJG8I]BQV*C8L=BOVXP@V8;8I]F%V+G8JMBHV+$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<Q"B,L(&9U>GIY
M"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("+8
MJ-BQV8;8I]F%V8?9E"#:J=BGV+'8J-BQV*_;C"#9AMBGV878N=BJV*C8L2(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T<B`BV8;9B-BY
M(-F^VXS8NMBGV84@V8;8I]F%V+G8JMBHV+$B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*;7-G:60@(DEN=F%L
M:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(F%P:5]I9"#9AMBGV878
MN=BJV*C8L2#8I]BSV*H@V8@@VXS8IR#8I]BR(-BHVXS9AB#8L=F!V*K9AR#8
MI]BSV*HB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.38*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T
M97)S+B(*;7-G<W1R("+9OMBGV+'8I]F%V*K8L2#9AMBGV878N=BJV*C8L2#9
MB"#;C-BG(-BGV+(@V*C;C-F&(-BQV8'8JMF'(@H*(SH@861M:6XO<&5R;7,O
M861D8VAI;&0N<&AP.C(W"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S
M:6]N+B(*;7-G<W1R("+9A=BLV8C8LB#9OMBOV+$@V8;8I]F%V+G8JMBHV+$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<S"B,L(&9U>GIY
M"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(MF%V*S9B-BR
M(-F^V*_8L2#9AMBGV878N=BJV*C8L2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-S4*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@<')O9'5C
M="!C;V1E+B(*;7-G<W1R("+9OMBQV8C8JMJIV80@V8;8I]F%V+G8JMBHV+$B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#8*;7-G:60@(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(MF^V+'9
MB-BJVJG9A"#9AMBGV878N=BJV*C8L2(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HW,2!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@
M<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`BVJ_;C-BQV8;8K]F'V90@V8;8
MI]F%V+G8JMBHV+$Z(%PB)7-<(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,3`W-B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-C(*;7-G
M:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S='(@(MBTVXS8H2#8J-F'
M(-BGV+38JMBQV*?:J2#:K]BPV*?8M-BJV8<@V+38K]F'V90@V8;8I]F%V+G8
MJMBHV+$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#$*;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM
M<V=S='(@(MBBV*_8L=BS(-BSV+':AMBTV879AR#9AMBGV878N=BJV*C8L2(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q,0IM<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@(MBO
MV*?8K]F'(-N,V8C9AMN,VJG8KR#9AMBGV878N=BJV*C8L2`B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4W"FUS9VED("));G9E;G1O<GDB"FUS
M9W-T<B`BV879B-BLV8C8K]N,(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C8W.0IM<V=I9"`B26YV97)T('-E;&5C=&EO;B(*
M;7-G<W1R("+8J-BQVJ_8L=BOV*?9AMBOV88@V*?9AMBJV*[8I]BH(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@R"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@;V8@
M36%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(T"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R
M(")4+5-T;W)M<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27-R865L(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C(U
M"FUS9VED("))<W-U97(B"FUS9W-T<B`BV879AMBJV+38L2#:J=F&V8;8K]F'
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M"FUS9VED("))=&%L:6,B"FUS9W-T<B`BV*W8L=F(V8$@VJG8K"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,@HC+"!F=7IZ>0IM<V=I9"`B271A;'DB"FUS9W-T<B`BV*W8L=F(
MV8$@VJG8K"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R("+:F-BGV8;9B-N,V8<B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#,*;7-G:60@(DIA<&%N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@W"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I
M(@IM<V=S='(@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`IM<V=I9"`B(@HB2F%V87-C<FEP="!H
M87,@8F5E;B!D:7-A8FQE9"!O;B!Y;W5R(&)R;W=S97(@86YD('1H:7,@<&%G
M92!M87D@;F]T(&)E("(*(F1I<W!L87EI;F<@8V]R<F5C=&QY+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,@IM<V=I9"`B
M2F5R<V5Y(@IM<V=S='(@(MBRVXS8L=F^VXS8L=BGV8?9AMN,(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@S"FUS9VED(")*;W)D86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS
M9W-T<B`BVIC9B-BFVXS9AR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S='(@(MJ8V8C8IMF&
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R("+9A]F%XH",V*K8L=BG
MV+(@VJG8L=BOV88B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS
M9W-T<B`BV8?9A>*`C-BJV+'8I]BRVXP@V8C8L]BW(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3<*;7-G:60@
M(DIU<W1I9GD@1G5L;"(*;7-G<W1R("+9A]F%XH",V*K8L=BGV++;C"#:J=BG
MV879A"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y($QE9G0B"FUS9W-T<B`BV8?9
MA>*`C-BJV+'8I]BRVXP@VH;9OB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V"FUS9VED(")*=7-T:69Y(%)I
M9VAT(@IM<V=S='(@(MF'V87B@(S8JMBQV*?8LMN,(-BQV*?8L]BJ("(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C8T"FUS9VED
M(")+965P(&]R:6=I;F%L/R(*;7-G<W1R("+8I]BUV83;C"#9AMJOV8<@V*_8
MI]BTV*K9AR#8M-F(V*_8GR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2V5N>6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX
M-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R("+:J=BGV+'8L]BGV+(@:V5R8F5R;W-E(-BJV+78K]N,
MV8(@V8?9B-N,V9'8JB#8L=BG(-BQV*\@VJG8L=BO(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C0R"FUS9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G
M:60@(DME>2!#<F5A=&EO;B(*;7-G<W1R("+8I]N,V*S8I]BO(-JIV83;C-BO
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$T"FUS9VED
M(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`BV*?8J]BQ(-BGV8;:K]BTV*H@
MVJG9A-N,V*\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,3(*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`BV+?9B-F$(-JIV83;C-BO
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED
M(")+97D@5'EP92(*;7-G<W1R("+9AMF(V+D@VJG9A-N,V*\B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.`IM<V=I9"`B2V5Y(%5S
M86=E(@IM<V=S='(@(MJIV*?8L=BHV+'8KR#:J=F$VXS8KR(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A
M9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("+:
MJ=F$VXS8KR#9@MBHV838I]F+(-BOV+$@VJG8I]BQV+/8I]BR(-BYV879B-F%
MVXP@VJG9A-N,V*\@V879B-BLV8C8KR#8I]BSV*HB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`BXH",V*C:AMF'
MXH",V8?8IR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@1&5M;V-R871I8R!0
M96]P;&4G<R!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*
M;7-G:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM
M<V=S='(@(DMO<F5A;B`H155#+4M2*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B
M2W5W86ET(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2WER9WEZ
M<W1A;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC
M.C@*;7-G:60@(DQA7WEO=70B"FUS9W-T<B`BV*S8I]F&V878I]N,VXPB"@HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S"FUS9VED("),86YG=6%G
M92(*;7-G<W1R("+8LMBHV*?9AB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&%O
M(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S
M='(@(MF&VXS9A=F'V90@V*+8KMBQ(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C<V"FUS9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R("+8
MJMBZVXS;C-BQ(-BBV*[8L=N,V88@V*?8L]F%(-BQV878LB(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HX-B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@*;7-G:60@
M(DQA<W0@475A<G1E<B(*;7-G<W1R("+8L=BHV+D@V*+8KMBQ(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ-3$*;7-G:60@(DQA<W0@57!D871E9#HB"FUS
M9W-T<B`BV*+8KMBQVXS9AB#8J-BQV8C8LMBQV+/8I]F&VXPZ(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@
M(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(MBBV*[8L=N,V88@V8C8L=F(V*\Z
M("5S(@H*(R`*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S(Q"B,L('!H
M<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T
M<B`BV*+8KMBQVXS9AB#9B-BQV8C8KR`Z("5S(-BGV+(@)7,B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HW,38*;7-G:60@(DQA<W0@;&]G:6XZ($YE
M=F5R(@IM<V=S='(@(MBBV*[8L=N,V88@V8C8L=F(V*\Z(-F'V+':K]BR(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@Y"B,L(&9U>GIY"FUS9VED("),871V:6$B"FUS9W-T<B`B
MV*_8I]BOV8<B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*;7-G:60@
M(DQA=R(*;7-G<W1R("+8K=F"V8C9@B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0IM<V=I9"`B3&%Y;W5T(@IM
M<V=S='(@(MBLV*?9AMF%V*?;C-N,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R
M(&YO(&)O<F1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQE
M8F%N;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C8Y"FUS9VED("),969T(@IM<V=S='(@(MJ&
MV;XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$Y"FUS9VED("),
M969T(&AE861E<B(*;7-G<W1R("+8L]BQV*+9A=BO(-J&V;XB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$U"FUS9VED("),969T('9A;'5E<R(*
M;7-G<W1R("+9A=F"V*?8K]N,V+$@VH;9OB(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,30S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`HC+"!F
M=7IZ>0IM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("+8L=F(V+0B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(DQE
M=F5L(@IM<V=S='(@(MBYV+39@B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EB
M97)I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI8GEA;B!!
M<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED
M("),:65C:'1E;G-T96EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),:6=H="!$<FEZ>FQE
M(@IM<V=S='(@(MF&V87B@(S9AMF%(-BHV*?8L=BGV88B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@IM<V=I9"`B3&EG:'0@
M4F%I;B(*;7-G<W1R("+8J-BGV+'9AMBOVJ_;C"#8L]BHVJDB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG
M:'0@4F%I;B!%87)L>2(*;7-G<W1R("+8J-BGV+'9AMBOVJ_;C"#8L]BHVJD@
MV++9B-BOV8?9AMJOV*?9A2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),:6=H="!286EN($QA=&4B"FUS9W-T
M<B`BV*C8I]BQV8;8K]JOVXP@V+/8J-JI(-BOVXS8L=F'V8;:K]BGV84B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM<V=I
M9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`BV*C8I]BQV8;8K]JOVXP@
MV8@@V+':K]BHV*?8L2#8L]BHVJDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H
M=6YD97(B"FUS9W-T<B`BV*C8I]BQV*?9AB#8L]BHVJD@V*C9AR#9A]F%V+'8
MI]F'(-BQV+G8KR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,Q"FUS9VED("),:6=H="!3;F]W(@IM<V=S='(@(MBHV+'9@2#8
ML]BHVJDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS,@IM<V=I9"`B3&EG:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`BV*C8L=F!
M(-F((-BQVJ_8J-BGV+$@V+/8J-JI(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0U"FUS9VED("),:6UE<FEC:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#$T"FUS9VED("),:6YK(@IM<V=S='(@(MF^
MVXS9B-F&V*\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*;7-G
M<W1R("+9AMF"V*?8MR#9OMN,V8C9AMBO(-BHV8<Z(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3@W-0IM<V=I9"`B3&EN:R!T:&4@96UA:6P@861D
M<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(*;7-G
M<W1R("+8HMBOV+'8LR#9OMBSV*H@V*?9A-JIV*K8L=F(V8;;C-JI(-BQV*<@
MV*C9AR#8M=F!V*W9AR#8I]N,V*S8I]BO(-F^VXS8NMBGV878C"#8J-F'(-F'
MV8;:K]BGV84@V878M-BGV8?8K]F'V(P@V;[;C-F(V8;8KR#8K]F'VXS8KR(*
M"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:'1M;#)T97AT+G!H
M<#HQ.#,*;7-G:60@(DQI;FMS(@IM<V=S='(@(MF^VXS9B-F&V*_B@(S9A]BG
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0V"FUS9VED("),:6YU>"!#
M;V]K:64B"FUS9W-T<B`BVJG9B-JIVXP@V83;C-F&V8C:J=BS(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G:60@(DQI
M<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R("+9@=F'V+'8
ML]BJ("T@VJG8I]BQV*C8L2#9A=N,XH",V*K9B-BGV8;8KR#9OMF(V+39AR#8
ML=BG(-BHV*C;C-F&V*\B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,S"FUS
M9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R("+9@=F'V+'8L]BJ(-BOV*?8
MK]JOV*?9AMF'V*?B@(PB"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU
M,`IM<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R("+9@=F'V+'8L]BJ
M(-BYV8;8I]F(VXS9AB#8L=BGV8?9AMF%V*<B"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3,R"FUS9VED("),:7-T(%1A8FQE<R(*;7-G<W1R("+9@=F'V+'8
ML]BJ(-BLV*_8I]F(V80B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E
M<G,N<&AP.C4Y-`IM<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S='(@(MF!V8?8
ML=BSV*H@V*+8L=BTVXS9B"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A
M9&5R<RYP:'`Z-3@Y"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`BV8'9A]BQ
MV+/8JB#8L=BGV8?9AMF%V*<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE
M861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U)9"(*;7-G<W1R("+9@=F'V+'8
ML]BJ($ED(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU
M.3(*;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T<B`BV8'9A]BQV+/8JB#9A=BG
MV83:J2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DS
M"FUS9VED("),:7-T+5!O<W0B"FUS9W-T<B`BV8'9A]BQV+/8JB#9OMBSV*K;
MC"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DQ"FUS
M9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("+9@=F'V+'8L]BJ(-BYV+;9
MB-N,V9'8JB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z
M-3DP"FUS9VED("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(MF!V8?8L=BS
MV*H@V+G8K]F%(-BYV+;9B-N,V9'8JB(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H
M<#HU,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!S97-S
M:6]N<R!F86EL960Z("5S(@IM<V=S='(@(MF!V8?8L=BSV*H@VJG8I]BQV*C8
ML=BGV88@V8'8N=BGV80@V8;9A=N,XH",V*C8I]BTV*\B"@HC.B!A9&UI;B]S
M97-S:6]N<RYP:'`Z,S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DQI
M<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R("+9@=F'V+'8L]BJ(-JI
MV*?8L=BHV+'8I]F&(-F!V+G8I]F$(-F&V87;C.*`C-BHV*?8M-BO(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED("),:7-T
M:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("+9@=F'V+'8L]BJ(-JI
MV*?8L=BHV+'8I]F&(-F!V+G8I]F$(-F&V87;C.*`C-BHV*?8M-BO(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),:71E<F%T=7)E(@IM
M<V=S='(@(MBGV*_8J-N,V*?8JB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0HC+"!F=7IZ>0IM
M<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(MF(V*?8K=BO(-F^V8?9AMBG(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6UA9V5S+G!H<#HX,PIM
M<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R("+8J-BGV+':J=BQV*_9ABXN+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3$*;7-G:60@(DQO
M8V%L('1I;64Z("(*;7-G<W1R("+8L]BGV+G8JB#9A=BMV83;C#H@(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@S"FUS9VED("),;V-A;&4@86YD(%1I
M;64B"FUS9W-T<B`BV878K=F$VXS9D=BJ(-F((-BSV*?8N=BJ(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S$@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C8T"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HR
M,B!L:6(O0FQO8VLO;65T87(N<&AP.C8U"FUS9VED("),;V-A=&EO;B(*;7-G
M<W1R("+9A=F(V8+8N=N,V*HB"@HC.B!L;V=I;BYP:'`Z,3<R('-E<G9I8V5S
M+W!O<G1A;"]S:61E8F%R+G!H<#HQ.3$@=&5M<&QA=&5S+VQO9VEN+VUO8FEL
M92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-2!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDP"FUS9VED("),;V<@:6XB"FUS9W-T
M<B`BV8C8L=F(V*\B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M-#4*;7-G:60@(DQO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$X-0IM<V=I
M9"`B3&]G(&]U="(*;7-G<W1R("+8KMBQV8C8K"(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HU.0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`BV8C8L=F(V*\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W"FUS9VED("),;V=I;B!4
M87-K<R(*;7-G<W1R("+9B-BXV*?;C-F!(-F(V+'9B-BO(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z.3DV"FUS9VED("),;V=I;B!F86EL960@8F5C
M875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN
M8V]R<F5C=&QY+B(*;7-G<W1R("+9B-BQV8C8KR#9AMBGV879B-F!V9'9@B#8
MJ-F(V*\@V++;C-BQV*<@V8;8I]F%(-JIV*?8L=BHV+$@V8@@VXS8IR#8I]BS
MV84@V+'9A=BR(-F(V*?8L=BO(-BTV*_9AR#8I]BTV*K8J-BGV8<@V*C9B-BO
M("(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY,@IM<V=I9"`B3&]G
M:6X@9F%I;&5D+B(*;7-G<W1R("+9B-BQV8C8KR#9AMBGV879B-F!V9'9@B#8
MJ-F(V*\N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-0IM<V=I
M9"`B3&]N9R!T97AT(@IM<V=S='(@(MF%V*K9AB#8J-F$V8;8KR(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT.`IM<V=I9"`B3&]V92(*;7-G<W1R("+8
MN=BTV8(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV-PIM<V=I9"`B3&]W(@IM<V=S='(@(MF^V*?;C-N,V88B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(Q
M"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@(MBMV+'9B-F!
M(-JIV8C:AMJI(-N,V8C9AMBGV8;;C"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R
M(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`BV*W8L=F(V8$@VJG9B-J&VJD@V838
MI]BJVXS9AB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B
M"FUS9W-T<B`BV*?8N=BOV*?8KR#:J=F(VH;:J2#;C-F(V8;8I]F&VXPB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,`HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,X('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R(")-32(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#$*;7-G:60@(DU/5$0B"FUS
M9W-T<B`BV;[;C-BZV*?9A2#8L=F(V+(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM
M96YT(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R("+9OMN,V8C8L]BJ($U3
M+51.148@V+38I]F%V80@V8?;C-J&(-BOV*?8K]F'XH",V*?B@(S;C-N,(-F&
MVXS8L]BJ(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I
M;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S='(@
M(DU31R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,@HC+"!F=7IZ>0IM<V=I9"`B36%C86\B"FUS
M9W-T<B`BV*K8N=BWVXS9A-BGV*HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA
M8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUA9&%G87-C87(B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"FUS9VED(")-86=I
M8R(*;7-G<W1R("+8K-BGV*_9B"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HX,0IM<V=I9"`B36%I;"(*;7-G<W1R("+9AMBGV879AR#8I]F$VJG8
MJMBQV8C9AMN,VJG;C"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU
M,C(*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`BV+/8L=F^V+'8L]BJ(-F&
MV*?9A=F'(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S='(@
M(MBSV*?8KMBJV88@V;[;C-F(V8;8KRXN+B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F
M=7IZ>0IM<V=I9"`B36%L87=I(@IM<V=S='(@(MF&V*?9A=F'(-BGV83:J=BJ
MV+'9B-F&VXS:J=N,(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-86QA>7-I82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&1I=F5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,@HC+"!F=7IZ>0IM<V=I9"`B36%L:2(*;7-G
M<W1R("+9AMBGV879AR#8I]F$VJG8JMBQV8C9AMN,VJG;C"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-`HC+"!F=7IZ>0IM<V=I9"`B36%L=&$B"FUS9W-T<B`BV8;8I]F%V8<@
MV*?9A-JIV*K8L=F(V8;;C-JIVXPB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.3$*;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S
M('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@(@HB
M87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@(MF%
MV*_;C-BQVXS8JB#9B"#8JMBYVXS;C-F&(-BQV8;:KR#8K]BSV*K9A^*`C-F'
MV*?;C-N,(-JIV8<@V+39A=BG(-F%V8C8I]BQV*\@V+'8IR#8J-BG(-BBV8;9
MA]BG(-F&V*?9A>*`C-JOV+#8I]BQVXP@V87;C.*`C-JIV8;;C-BO(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-3,*;7-G
M:60@(DUA<#(T(&UA<"(*;7-G<W1R(")-87`R-"!M87`B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X-`HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$V.`IM<V=I9"`B36%P
M475E<W0@;6%P(@IM<V=S='(@(DUA<%%U97-T(&UA<"(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`BV878I]BQV+,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0Q"FUS9VED(")-87)G:6XB"FUS9W-T<B`BV*W8I]BTVXS9AR(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-
M87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`BV+G9A-BGV878
MJB#:K]BPV*?8L=N,(-BHV*<@V;[8L=J&V84@V878M-BGV8?8K]F'(-BTV*_9
MAR\@V878M-BGV8?8K]F'(-F&V+38K]F'(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE
M<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@(B#8
MN=F$V*?9A=BJ(-JOV+#8I]BQVXP@V*C8IR#8N=F$V*?8IMF%(-BOVXS:K]BQ
M("C9A=BGV8;9AMBO(-F%V8?9A2_9OMBGV+/8KB#8K]BGV*_9AR#8M-BOV8<I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,PHC+"!F=7IZ>0IM<V=I9"`B36%R=&EN:7%U
M92(*;7-G<W1R("+8K=BGV+3;C-F'(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R("+9
M@=N,V838K^*`C-F'V*?;C"#8I]F&V+?8J-BGV8(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*
M(RP@9G5Z>GD*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`BV*W8I]BTVXS9
MAR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R("+8J-N,
MV+3;C-F&V8<@V*?8N=BJV*C8I]BQ(-F%V*S8I]BR(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-
M87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB"FUS9W-T<B`BV*K8KMBWVXP@
MV*?8LB#8J-N,V+3;C-F&V8<@V8+8L]F%V*K9A]BGVXP@V;[;C-BZV*?9A2(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`V"FUS9VED(")-87@@=&5M<"!L
M87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`BV*C;C-BTVXS9AMF'(-BOV878IR#8
MK]BQ(-NRV[0@V+/8I]BYV*H@VJ_8L-BTV*K9ASH@(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR.3@*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@
M(@IM<V=S='(@(MBHVXS8M-N,V8;9AR#8K]F%V*<@V*_8L2#;MB#8L]BGV+G8
MJB#:K]BPV+38JMF'.B`B"@HC.B!L:6(O87!I+G!H<#HX-@IM<V=I9"`B36%X
M:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3@@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(Q-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y"FUS
M9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R("+8J-N,V+3;C-F&V8<@V+?9
MB-F$(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-CD*;7-G:60@(DUA>2(*;7-G<W1R("+9A=N,(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PHC
M+"!F=7IZ>0IM<V=I9"`B36%Y;W1T92(*;7-G<W1R("+8K-BGV8;9A=BGVXS;
MC"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I
M;F4B"FUS9W-T<B`BV;[8LMBTVJG;C"(*"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O961I="YI;F,Z,38*;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`BV*?8
MN=BVV*?8H2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S@*;7-G:60@
M(DUE;G4@;6]D93HB"FUS9W-T<B`BV878KR#:K]BRVXS9AMJOV*?9AMN,.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@(MBGV*_8NMBGV84@
MV+/9A-F(V839A]BG(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I
M9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`B
MV;[;C-BZV*?9A2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,C$V"FUS9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL
M>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92`B
M"B)V97)I9FEE9"XB"FUS9W-T<B`BV;[;C-BZV*?9A2#8J-BG(-F%V8C9@=F1
MV8+;C-F1V*H@V*C8I]BRV*C;C-F&VXP@V+38KR#8I]F%V*<@VJ_9B-BGV8?;
MC"#8I]F%V+;8I]BA(-JIV8;9AMBOV8<@V8;9A=N,XH",V*K9B-BGV8;8KR#8
MJ-BGV++8J-N,V8;;C"#8M-F(V*\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*;7-G:60@(DUE<W-A9V4@97AP
M:7)E9"XB"FUS9W-T<B`BV;[;C-BZV*?9A2#9A=F&V8+8MMN,(-BTV*\B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V
M.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8P,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C8P"FUS9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`BV8;9
MB-BY(-F^VXS8NMBGV84B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G
M:60@(DUE=&%R(%=E871H97(B"FUS9W-T<B`BV*+8J"#9B"#9A]F(V*?;C"!-
M971A<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R
M(&)L;V-K(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(MBHV839B-JI($UE=&%R
M(-F"V*?8J-F$(-BOV+/8JMBQV+,@V8;;C-BSV*HB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$Q,@IM<V=I9"`B(@HB365T87(@8FQO8VL@;F]T(&%V86EL
M86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI
M<W1R871O<BXB"FUS9W-T<B`BV*C9A-F(VJD@365T87(@V8+8I]BHV80@V*_8
ML]BJV+'8LR#9AMN,V+/8JBX@V*S8LMBFVXS8I]BJ(-BHV+'8I]N,(-BSV+'9
MOMBQV+/8JB#8L]BGV878I]F&V8<@V*O8J-BJ(-BTV*_9AR#8I]BSV*HB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38U"B,L(&9U>GIY"FUS
M9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T960N(@IM<V=S='(@(MBGV+/9
MA2#8L=F%V+(@(-F"V*_;C-F%VXP@V8;8I]BOV+'8L]BJ(-BGV+/8JB(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B365T:&]D
M(@IM<V=S='(@(MBQV8C8M"(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P
M8RYP:'`Z.#$@9G)A;65W;W)K+U)00R]24$,O<V]A<"YP:'`Z,3$W"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D
M969I;F5D(@IM<V=S='(@(MBQV8C8M"`G)7,G(-BJV+G8L=N,V8$@V8;8M-BO
MV8<@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL
M960@;65T:&]D.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-0IM<V=I9"`B
M365T<FEC(@IM<V=S='(@(MBGV8;8K]BGV++9A^*`C-BGVXPB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.34*(RP@9G5Z>GD*;7-G:60@(DUE>&EC;R(*;7-G<W1R("+8I]F&V*_8
MI]BRV8?B@(S8I]N,(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O;F5S:6$L
M($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"FUS9VED(")-
M:61D;&4B"FUS9W-T<B`BV8C8L]BW(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*;7-G<W1R
M("+9AMF(V+D@36EM92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$P"FUS
M9VED(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B(-JIV87;
MC-F&V8<@V*_9A=BGVXP@V[+;M"#8L]BGV+G8JB#:K]BPV+38JMF'.B`B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P,@IM<V=I9"`B36EN('1E;7`@;&%S
M="`V(&AO=7)S.B`B"FUS9W-T<B`B(-JIV87;C-F&V8<@V*_9A=BGVXP@V[8@
MV+/8I]BYV*H@VJ_8L-BTV*K9ASH@(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HT,SD*(RP@9G5Z>GD*;7-G:60@(DUI;FEM=6T@<&%S<W=O
M<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960B"FUS9W-T<B`BV*?8L]F%(-BQ
MV878LB`@V+39A=BG(-F%V8;9@MBVVXP@V+38K]F'(-BGV+/8JB(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S0*;7-G:60@
M(DUI<G)O<B(*;7-G<W1R("+8HMN,V8;9AR(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU,0IM<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R("+9A=BJ
MV8'8L=F"V8<B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8W,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS-#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A4
M5%!?4F5Q=65S="XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$Q-0IM<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@
M:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H
M:7,@(@HB87!P;&EC871I;VXN(@IM<V=S='(@(B(*(MF^VXS:J=BQV*C9AMBO
MVXP@V879B-BLV8C8KR#9AMN,V+/8JBX@V+39A=BG(-BGVJ_8L2#9A=N,XH",
MV*[9B-BGV8?;C-BO(-BGV+(@V*?;C-F&(-BHV+'9AMBGV879A]F4(-JIV*?8
ML=BHV+'8K]N,(-BGV+/8JMF!V*?8K]F'(-JIV8;;C-BO("(*(MBHV*?;C-BO
M(-BBV8;8L=BG(-BJV8C9A-N,V*\@VJG9AMN,V*\B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI
M<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T<B`BV*?8LB#8J-N,V88@V+'9@=BJ
MV88@240@V;[;C-BZV*?9A2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED(")-:7-S:6YG(')E<75I
M<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G:60@
M(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`BV*?8LB#8J-N,V88@V+'9
M@=BJV88@240@V8;8M-BSV*H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`BV*_9B-BT
MV8;8J-F'(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C<T"FUS9VED
M(")-;V)I;&4@36%I;"(*;7-G<W1R("+9OMBSV*H@V+/9A-F(V83;C"(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED
M(")-;V1E<F%T92(*;7-G<W1R("+9A=BYV*K8K]F$(-JIV+'8K]F&(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#@*;7-G:60@(DUO9&EF:65D($1A
M=&4B"FUS9W-T<B`BV*K8I]BQVXS8KB#8JMBZVXS;C-BQ(-N,V*?9@=BJV8<B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`BV*K8NMN,VXS8
ML2!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W
M,PIM<V=I9"`B36]D=6QU<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G
M:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,`IM<V=I9"`B36]N86-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM
M<V=I9"`B36]N9V]L:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C4Y-`IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B
MV878I]F'(-F((-BSV*?9A"(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-
M86EN=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`BV878
MI]F'V*?9AMF'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"B,L(&9U>GIY"FUS9VED(")-;VYT
M<V5R<F%T(@IM<V=S='(@(MF%V+G8JMBOV80@VJG8L=BOV88B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@
M(DUO;VX@4&AA<V5S(@IM<V=S='(@(MF!V*?8LMF'V*?;C"#9A=BGV8<B"@HC
M.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-S(@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z,C4S"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@
M9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS,PIM<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@(MBHVXS8M-BJV+$@
MV+78I]F!(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S0*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`BV*C;C-BTV*K8
ML2#8I]BHV+';C"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`BV*C;C-BT
MV*K8L2#8HMF!V*K8I]BHVXPB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HU,#D*;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R("+8I]F&
MV*K9@MBGV80@V*C9AR#9OMBGVXS;C-F&(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z-3$S"FUS9VED(")-;W9E($QE9G0B"FUS9W-T
M<B`BV*?9AMBJV8+8I]F$(-BHV8<@V*C8I]F$V*<B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,3<*;7-G:60@(DUO=F4@4FEG:'0B
M"FUS9W-T<B`BV*?9AMBJV8+8I]F$(-BHV8<@V+'8I]BSV*HB"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,#4*;7-G:60@(DUO=F4@
M57`B"FUS9W-T<B`BV*?9AMBJV8+8I]F$(-BHV8<@V*C8I]F$V*<B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS9VED
M(")-;W9E(&1O=VXB"FUS9W-T<B`BV*?9AMBJV8+8I]F$(-BHV8<@V;[8I]N,
MVXS9AB(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HU,C,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C4R-`IM<V=I9"`B36]V92!U<"(*;7-G<W1R("+8I]F&V*K9@MBGV80@V*C9
MAR#8J-BGV838IR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36]Z86UB:7%U92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@T"FUS
M9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`BV8'9
MA]BQV+/8JB#9OMBGVXS;C-F&XH",V;[8L2#:AMF&V*\@V+/8M]BMVXPB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U-0IM
M<V=I9"`B375L=&EM87`@54L@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(R-#(*;7-G:60@(DUU;'1I<&QE('-E;&5C=&EO
M;B(*;7-G<W1R("+:AMF&V*\@V*?9AMBJV*[8I]BHVXPB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#`P"FUS9VED(")->2!!8V-O=6YT(@IM<V=S
M='(@(MBMV+/8I]BH(-F%V88B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M,C@*;7-G:60@(DUY($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`BV*?8
MM]F$V*?8N=BGV*H@V*W8L]BGV*@@V879AB(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]I;F1E>"YP:'`Z-30*;7-G:60@(DUY(%!O<G1A;"(*;7-G<W1R("+8K]BQ
MVJ_8I]F'(-F%V88B"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z,3,V
M"FUS9VED(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(MBLV*?9AMF%V*?;
MC-N,(-BOV+':K]BGV8<@V879AB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,34U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B37EA
M;FUA<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I
M;G1E;F%N8V4N:'1M;#HU-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM
M<V=S='(@(MF&V8?8C"#9A=F&(-F%V8C8I]F!V8(@V8;;C-BSV*K9A2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,2!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(").86UE(@IM<V=S
M='(@(MF&V*?9A2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDW"FUS9VED(").971H97)L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@
M(DYE='-C87!E($)A<V4@55),(@IM<V=S='(@(E523"#9OMBGVXS9AR!.971S
M8V%P92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@S
M"FUS9VED(").971S8V%P92!#02!2979O8V%T:6]N(%523"(*;7-G<W1R(").
M971S8V%P92!#02!2979O8V%T:6]N(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P92!#02!P;VQI
M8WD@55),(@IM<V=S='(@(DYE='-C87!E($-!('!O;&EC>2!54DPB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-`IM<V=I9"`B3F5T
M<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B3F5T<V-A<&4@4F5N97=A;"!5
M4DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,@IM
M<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B3F5T<V-A
M<&4@4F5V;V-A=&EO;B!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3@W"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM96YT(@IM
M<V=S='(@(MBJV8C8MMN,V*T@VJ_9B-BGV8?;C"!.971S8V%P92(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@P"FUS9VED(").971S
M8V%P92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@(MF&V8C8N2#:K]F(V*?9
MA]N,($YE='-C87!E(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U
M,0IM<V=I9"`B3F5T=V]R:R(*;7-G<W1R("+8M-BHVJG9AR(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S,U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#8*;7-G:60@
M(DYE=F5R(@IM<V=S='(@(MF'V+':K]BR(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"B,L(&9U
M>GIY"FUS9VED(").97<@0V%L961O;FEA(@IM<V=S='(@(MBOV+/8JMF'(-BL
MV*_;C-BO(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N
M86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R("+8K]BS
MV*K9AR#8K-BOVXS8KR(*"B,@"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&
M:6QT97(O96UA:6QS+G!H<#HX,0HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O
M1FEL=&5R+V5M86EL<RYP:'`Z.#<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R
M+T9I;'1E<B]E;6%I;',N<&AP.CDW"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E
M<B]&:6QT97(O96UA:6QS+G!H<#HQ,#$*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(DYE=R!-97-S86=E('1O("5S(@IM<V=S='(@(MBGVXS8K-BGV*\@
MV;[;C-BZV*?9A2`H)7,I(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI
M8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS
M9VED(").97<@36]O;B(*;7-G<W1R("+9A=BGV8<@V8;9B"(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R
M;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(MF&V*?9A2#:J=BGV+'8J-BQVXP@
MV*S8K]N,V*\@*-BGV*[8JMN,V*?8L=N,*2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I
M9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C,W"FUS9VED(").97<@<&%S<W=O<F0B"FUS9W-T<B`B
MV*?8L]F%(-BQV878LB#8K-BOVXS8KR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W
M;W)D('=I;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R("+8I]BSV84@V+'9A=BR
M(-F$V+K9B"#8KMF(V*?9A]BO(-BTV*\@V*_8L2`E>"`B"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*;7-G:60@(DYE=R!P87-S=V]R9',@
M9&]N)W0@;6%T8V@N(@IM<V=S='(@(MBGV+/9A2#8L=F%V++9A]BGVXP@V*S8
MK]N,V*\@V*K8M]BGV*C9@B#9AMBOV*?8L=BO(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O
M=R`H7V)L86YK*2(*;7-G<W1R("+9OMF&V*S8L=F'(-BLV*_;C-BO("C8KMBG
MV83;C"DB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X
M.0IM<V=I9"`B3F5W<R(*;7-G<W1R("+8I]BNV*C8I]BQ(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,P-0IM<V=I9"`B3F5W<V=R;W5P<R(*;7-G
M<W1R("+:K]BQV8C9A^*`C-F'V*?;C"#8KMBHV+';C"(*"B,Z('1E;7!L871E
M<R]D871A+W1S=FEN9F\N:6YC.C$U('1E;7!L871E<R]D871A+V1A=&5M87`N
M:6YC.C0Q"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C(U"FUS9VED(").97AT(@IM<V=S='(@
M(MBHV+G8K]N,(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"B,L(&9U>GIY
M"FUS9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@(MF!V*?8LB#8J-BYV*_;
MC"(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<R(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<V"FUS9VED(").97AT(&]P=&EO
M;G,B"FUS9W-T<B`BVJ_8LMN,V8;9A^*`C-F'V*?;C"#8J-BYV*_;C"(*"B,Z
M(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z,3`S"B,L(&9U>GIY"FUS9VED
M(").97AT/B(*;7-G<W1R("+8J-BYV*_;C"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I
M9"`B3FEC87)A9W5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@HC+"!F=7IZ
M>0IM<V=I9"`B3FEG97(B"FUS9W-T<B`BV+38J"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM
M<V=I9"`B3FEG97)I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S@P"FUS9VED(").:6=H="(*;7-G<W1R("+8M-BH(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-SD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDW"B,L(&9U>GIY"FUS9VED(").:75E(@IM<V=S='(@(MBY
MV*_8KR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HY-C,*;7-G:60@(DYO(@IM<V=S='(@(MF&V8<B"@HC.B!T96UP;&%T97,O
M861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V86EL86)L92!C
M;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM
M<V=S='(@(MBOV*?8K]F'(-F^VXS:J=BQV*C9AMBOVXP@V*_8L2#8K]BSV*K8
ML=BSVXP@V*C8L=BGVXP@V8;8M-BGV88@V*_8I]BOV88@V*K9@=BGV8C8JMF'
MV*<@V8C8K-F(V*\@V8;8K]BGV+'8KR(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<BYP:'`Z,3`U"FUS9VED(").;R!A=F%I;&%B;&4@
M<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R("))4T\@
MV8;;C-BSV*H@V*?8L]BJV+'8I]BJVIC;C"#8K]BQ(-BOV+/8JMBQV+/;C"#8
MJ-BQV*?;C"#8L]BGV*[8JMF&(-BJV+79B-N,V+$@(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").
M;R!B871C:"!T96UP;&%T92XB"FUS9W-T<B`BV*?9A-JOV8C;C"#8K]BSV*K9
MA^*`C-BGVXS;C"#9AMN,V+/8JB(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C<Y(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C(T-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR
M-C<*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O
M<VET:6]N(@IM<V=S='(@(MBHV838I]JIVXP@V*_8L2#9A=F(V8+8N=N,V*H@
MV*_8L=BNV8C8I]BSV*H@V+38K]F'(-F%V8C8K-F(V*\@V8;;C-BSV*HB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C4P"FUS9VED(").;R!C
M86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R("+9A]N,VH8@V8;8I]F%(-BJV8+9B-N,V87;C"#8J-BQV*?;
MC"#8JMBUV*_;C-F"(-F'V8C;C-F1V*H@34-!3"#9@=BQV*?9A]F%(-F&V+38
MK]F'(-BGV+/8JB(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4T"FUS9VED
M(").;R!C:&%N9V4N(@IM<V=S='(@(MBHV*_9B-F&(-BJV+K;C-N,V+$B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B3F\@
M8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS
M9W-T<B`BV8?;C-J&(-F%V*S9B-BR(-F!V+'8N=N,XH",V*?;C"#9AMF%VXSB
M@(S8JMF(V*?9AMBO(-BHV8<@V*?;C-F&(-F%V*S9B-BR(-BGV+;8I]F!V8<@
MV+39B-BO(@H*(R`*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C<@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#(*(SH@9G)A;65W;W)K+U5T
M:6PO571I;"YP:'`Z-S<S"B,L('!H<"UF;W)M870*;7-G:60@(DYO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T
M<B`BV8?;C-J&(-BGV+?9A-BGV+G8I]BJ(-F^VXS:J=BQV*C9AMBOVXP@V*C8
ML=BGVXP@)7,@V878M-BNV+4@V8;8M-BO(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HX,C0*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R("+9A]N,VH8@
MV*?8M]F$V*?8N=BGV*H@V;[;C-JIV+'8J-F&V*_;C"#8J-BQV*?;C"!&5%`@
M5D93(-F%V+38KMBU(-F&V+38KR(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z-C8Y"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`BV8?;C-J&(-BGV+?9
MA-BGV+G8I]BJ(-F^VXS:J=BQV*C9AMBOVXP@V*C8L=BGVXP@4U%,(%9&4R#9
MA=BTV*[8M2#9AMBTV*\B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z-S$W"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R("+9A]N,VH8@
MV*?8M]F$V*?8N=BGV*H@V;[;C-JIV+'8J-F&V*_;C"#8J-BQV*?;C"!344PM
M1FEL92!61E,@V878M-BNV+4@V8;8M-BO(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D
M:70@;&5F="XB"FUS9W-T<B`BV8?;C-J&(-BGV+G8JMBHV*?8L=N,(-BHV*?9
M@MN,(-F&V878I]F&V*\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S-`IM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P
M<&QI960N(@IM<V=S='(@(MF'VXS:AB#9A=F"V+78K]N,(-F!V+'8I]F'V84@
MV8;8M-BO(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#<W
M"FUS9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(MF'VXS:AB#9OMBQ
MV8C9AMBOV8?B@(S8I]N,VXP@V*?8L=BSV*?9A"#9AMBTV*\B"@HC.B!U=&EL
M+VEC;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*
M;7-G<W1R("+9A]N,VH8@V*+;C-JIV8C9AMN,XH",(-F^VXS8K]BG(-F&V+38
MKR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C@@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(S
M"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(MF'VXS:AB#9
MA=JIV*?9AMN,(-BJV8;8N-N,V84@V8;8M-BOV8<B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,38Y"B,L(&9U>GIY"FUS9VED(").;R!L;V-A
M=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`BV8?;C-J&(-F%VJG8I]F&VXP@V*K9
MAMBXVXS9A2#9AMBTV*_9AR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").;R!M97-S86=E('-U<'!L
M:65D+B(*;7-G<W1R("+9A]N,VH8@V;[;C-BZV*?9A=N,(-F!V+'8I]F'V84@
MV8;8M-BO(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S8*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R
M("+9A]N,VH8@V8;8I]F%VXP@V878M-BNV+4@V8;8M-BO(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*;7-G:60@
M(DYO(&YU;6)E<B!S<&5C:69I960N(@IM<V=S='(@(MF'VXS:AB#8M-F%V*?8
ML=F'XH",V*?B@(S;C-N,(-F%V+38KMBU(-F&V+38KR(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S
M(@IM<V=S='(@(MBBVXS9AMBOV8<@V8;8I]F%V+?8J-F(V+G;C"#9AMN,V+/8
MJB(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z.3$*;7-G:60@
M(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R("+8J-BQV*?;C"#8JMBUV*_;C-F"(-F'V8C;C-F1V*H@2%14
M4"#8I]BSV84@V+'9A=BRVXP@V8'8L=BGV8?9A2#9AMBTV*_9AR#8I]BSV*HB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C$P.`IM<V=I9"`B
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(MBHV+'8I]N,(-BJV+78K]N,V8(@V8?9B-N,V9'8JB!)34%0
M(-BGV+/9A2#8L=F%V++;C"#9@=BQV*?9A]F%(-F&V+38K]F'(-BGV+/8JB(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-S(*;7-G:60@(DYO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`BV*C8L=BGVXP@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ($ME
M<F)E<F]S(-BGV+/9A2#8L=F%V++;C"#9@=BQV*?9A]F%(-F&V+38K]F'(-BG
MV+/8JB(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z-S<@9G)A
M;65W;W)K+T%U=&@O075T:"]L;V=I;BYP:'`Z.#0*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]P86TN<&AP.C<U"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN(@IM<V=S='(@(MBHV+'8I]N,
M(-BJV+78K]N,V8(@V8?9B-N,V9'8JB#9B-BQV8C8KR#8I]BSV84@V+'9A=BR
MVXP@V8'8L=BGV8?9A2#9AMBTV*_9AR#8I]BSV*HB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W!A<W-W9"YP:'`Z,3,U"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+8
MJ-BQV*?;C"#8JMBUV*_;C-F"(-F'V8C;C-F1V*H@4$%34U=$(-BGV+/9A2#8
ML=F%V++;C"#9@=BQV*?9A]F%(-F&V+38K]F'(-BGV+/8JB(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HX-`IM<V=I9"`B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BV*C8
ML=BGVXP@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ(%--0B#8I]BSV84@V+'9A=BR
MVXP@V8'8L=BGV8?9A2#9AMBTV*_9AR#8I]BSV*HB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R.#8*;7-G:60@(B(*(DYO('!A=&@@
M=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B
M:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O<FL@=VET:"!02T-3(#$R(&1A
M=&$N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O
M=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS9W-T<B`B
MV*K9@MBGV+;8I]N,(-BKV*C8JB#9AMBGV87;C"#8K]BQ(-BGV8;8JMBXV*?8
ML2#8JMBCVXS;C-BO(-F&VXS8L]BJ(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C<U,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3F\@<75O=&$@
M<V5T+B(*;7-G<W1R("+8JMF&V+C;C-F%(-F&V+38K]F'(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PIM<V=I
M9"`B3F\@<G5L97,B"FUS9W-T<B`BV*C8K]F(V88@V8+9B-BGV+G8KR(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T.0IM<V=I9"`B3F\@<V5P
M87)A=&]R('-P96-I9FEE9"XB"FUS9W-T<B`BV8?;C-J&(-BLV*_8I]JIV8;9
MAMBOV8?B@(S8I^*`C-N,VXP@V878M-BNV+4@V8;8M-BO(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`IM<V=I
M9"`B3F\@<VED97,B"FUS9W-T<B`BV*C8K]F(V88@V+/9A=BJ(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#,*(RP@9G5Z>GD*;7-G:60@(DYO
M('-U8V@@9FEL92(*;7-G<W1R("+8J-BOV8C9AB#8L]F%V*HB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3,X"FUS9VED(").;R!T96UP;W)A
M<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(MBT
MV*?8KMF'(-F%V8C9@MBJVXP@V*C8L=BGVXP@VJG8I]BTV8<@V879B-BLV8C8
MKR#9AMN,V+/8JB(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,C(Q"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O
M<F0@<V5N="XB"FUS9W-T<B`BV8?;C-J&(-F&V*?9A2#:J=BGV+'8J-BQVXP@
MV8@@VXS8IR#8I]BSV84@V+'9A=BRVXP@V*?8L=BSV*?9A"#9AMBTV*\B"@HC
M.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B3F\@
M=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`BV8?;C-J&(-BOV*?8
MK]F'(%A-3"#9A=BYV*K8J-BQVXP@V*C8I]BRVJ_8L=BOV*?9AMBOV8<@V8;8
MM-BOV8<@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.CDW,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.3@Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HY.3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$P,#D*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R("+8J-BOV8C9
MAB#9A=F"V*_8I]BQ(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R,`IM
M<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T
M:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(MF&V+/8
MKMF'XH",(-BOV+$@V;[;C-JIV+'8J-F&V*_;C"#8I]BUV83;C"#9OMN,V*_8
MIR#9AMBTV*\N(-F^VXS:J=BQV*C9AMBOVXP@V+'8IR#8K]F(V*C8I]BQV8<@
MV*K9B-F$VXS8KR#:J=F&VXS8KR(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ,C@*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U
M<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(MF&
MV+/8KMF'XH",(-BOV+$@V;[;C-JIV+'8J-F&V*_;C"#8M-F%V*<@V;[;C-BO
MV*<@V8;8M-BOV8<@V*?8L]BJ+B#9OMN,VJG8L=BHV8;8K]N,(-BQV*<@V*_9
MB-BHV*?8L=F'(-BJV8C9A-N,V*\@VJG9AMN,V*\B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E
M9G,O:61E;G1I='ES96QE8W0N:6YC.CDS"FUS9VED(").;VYE(@IM<V=S='(@
M(MF'VXS:AN*`C-JIV*_8I]F%(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET
M*2(*;7-G<W1R("+9A]N,VH;B@(S:J=BOV*?9A2`HV+;9A=F&VXP@V*?8L]BJ
MV8'8I]BOV8<@VJG9AMN,V*\I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#D*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(DYO<F1I
M8R`H25-/+3@X-3DM,3`I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").;W)F;VQK
M($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@
M;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS9VED(").;W)T:&5R;B!(96UI<W!H
M97)E(@IM<V=S='(@(MF&VXS9A2#:J=BQV8<@V+39A=BGV83;C"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,PIM<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0P"FUS9VED
M(").;W0@069T97(B"FUS9W-T<B`BV8;9AR#8J-BYV*\B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B3F]T($)E9F]R
M92(*;7-G<W1R("+9AMF'(-F"V*C9A"(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C0P.`IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@
M(MN,VJD@V+38I]BNV8<@V8;;C-BSV*HB"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(N<&AP.C8S"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C@S"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDN<&AP.CDT"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-#@*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H
M<#HU.0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*;7-G<W1R("+9OMN,V*?8
MK]F'XH",V+/8I]BRVXP@V8;8M-BOV8<B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C8X"FUS9VED(").;W0@<V5T(@IM<V=S
M='(@(MBJV8;8N-N,V84@V8;8M-BOV8<B"@HC.B!F<F%M97=O<FLO4V5S<VEO
M;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$T,PHC.B!F<F%M97=O<FLO
M4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$U.`HC.B!F<F%M
M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$W,PHC
M.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP
M.C$X-PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L
M97(N<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,3DP"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HR,#4@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(S
M,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C0X(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HR-C4*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(X,2!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,CDW"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HS,3(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,R.0HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,S8R(&9R86UE=V]R:R]61E,O5D93+G!H<#HT,C(*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C4P,2!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z-3<P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU.#<@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C8V-0IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T
M<B`BV;[8M-BJVXS8J-BGV8;;C"#9AMBTV*_9AR(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0@8V]N9FEG+VAO;VMS+G!H
M<"YD:7-T.C$P,#4*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$W.`IM
M<V=I9"`B3F]T97,B"FUS9W-T<B`BVXS8I]BOV*_8I]BTV*K9A]BG(@H*(SH@
M<V5R=FEC97,O;V)R;W=S97(O:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG
M('1O(&)R;W=S92P@9V\@8F%C:RXB"FUS9W-T<B`BVH;;C-BRVXP@V*C8L=BG
MVXP@V878L=F(V+$@V8;;C-BSV*K8C"#8J-F'(-BYV8+8J"#8J-BQVJ_8L=BO
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q
M,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Y
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S4*
M;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@(MF&V8C8I]F%V*C8L2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-#8*;7-G:60@(DYU;6)E<B(*;7-G
M<W1R("+8N=BOV*\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(U
M"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R("+8JMBYV*_8
MI]BO(-F&V8C;C-BSV8?B@(S9A]BG(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,V.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(S"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#4@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU
M;6YS(@IM<V=S='(@(MBJV+G8K]BGV*\@V+/8JMF(V8;9A]BG(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-R!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#,@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@
M(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(MBJV+G8K]BGV*\@V+/8M]BQV8?8
MIR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0T"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T
M:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("+8I]BYV*_8I]BO
M(-BHV+'8I]N,(-BHV+'9B-BRV+'8L]BGV8;;C"#9@=F'V+'8L]BJ(-BJV8C8
MLMN,V+G;C"#9A=BTV*[8M2#9AMBTV*_9AMBO(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R
M("+8JMBCVXS;C-BO(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C@W,PIM<V=I9"`B3V)J96-T(@IM<V=S='(@(MBTVXS8H2(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS9VED(")/8FIE
M8W0@0W)E871O<B(*;7-G<W1R("+8I]N,V*S8I]BO(-JIV8;9AMBOV8<@V+3;
MC-BA(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C
M+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$P-`IM
M<V=I9"`B3V-T86PB"FUS9W-T<B`BV8?8M-BJV*?;C-N,(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,`HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B
M97(B"FUS9W-T<B`BV*?:J=BJV*C8L2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HY,@IM<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`BV8';C-F$
MV*K8L2#8J-N,XH",V*W8L=F%V*K;C"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS,C8*;7-G:60@(D]F9FEC92(*;7-G<W1R("+8K]F!V*K8L2#:
MJ=BGV+$B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G
M:60@(D]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB
M"FUS9W-T<B`BV*?8L]F%(-BQV878LB#8K-BOVXS8KR#9B"#8I]BSV84@V+'9
MA=BR(-F!V+G9A-N,(-BHV*?;C-BO(-F%V*K9@=BGV8C8JB#8J-BGV+39AMBO
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V"FUS9VED(")/
M;&0@<&%S<W=O<F0B"FUS9W-T<B`BV*?8L]F%(-BQV878LB#9@MBOVXS9A=N,
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C0V"FUS9VED(")/
M;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N(@IM<V=S='(@(MBGV+/9A2#8
ML=F%V+(@(-F"V*_;C-F%VXP@V8;8I]BOV+'8L]BJ(-BGV+/8JB(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY.`IM<V=I9"`B3VUA;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HW,PIM<V=I9"`B3VYL>2!)34%0
M('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RXB"FUS9W-T<B`BV*K9
MAMF'V*<@VJG8I]BQV+/8I]BRV8?8I]N,($E-05#9OMF(V+39A^*`C-F'V*?;
MC"#9A=BTV*K8L=JI(-BQV*<@V;[8M-BJVXS8J-BGV8;;C"#9A=N,XH",VJG9
MAMF&V*\@(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDU"FUS9VED(")/
M;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("+9@=F"V+<@V*+;C-F&
MV*_9AR#9AMBGV878M]BHV8C8N2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$X-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW,0IM<V=I9"`B
M3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R("+8JMF&
MV8?8IR#;C-JI(-BBV*_8L=BS(-F^V+/8JB#8I]F$VJG8JMBQV8C9AMN,VJG;
MC"#9A=BLV*?8LB#8I]BSV*HB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP
M:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI
M;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*(G!E
M<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(B(*(MBJV8;9A]BG(-F%
MV*?9A-JI(-N,V*<@V+/8L=F^V+'8L]BJ(-BSV*?9A=BGV8;9AR#9A=N,XH",
MV*K9B-BGV8;8KR#9A=BGV83:J=N,V*H@VXS8IR#9A=BLV8C8LMF'V*?;C"#9
MA=BGV83:J2#8L=BG(-BHV+'8I]N,(-N,VJD@V*?8M-BJV+'8I]JI("(*(MBJ
MV+K;C-N,V+$@V*_9A]BO(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,S4*
M;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(MBOV+$@VXS:
MJ2#9OMF&V*S8L=F'(-BLV*_;C-BO(-BHV*?8LB#8M-F(V*\B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-3
M3"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3
M+TU)344@<&%R="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")/<&5N<R!T
M:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(MBGVXS9AB#9OMN,
MV8C9AMBO(-BOV+$@VXS:J2#9OMF&V*S8L=F'(-BLV*_;C-BO(-BHV*?8LB#8
MM-F(V*\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*;7-G:60@(D]P
M97)A=&EN9R!3>7-T96TB"FUS9W-T<B`BV+/;C-BSV*K9A2#8N=BGV879A"(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3$*;7-G:60@(D]P
M=&EO;G,B"FUS9W-T<B`BVJ_8LMN,V8;9AR8C>#(P,&,[V8?8IR(*"B,@(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@
M"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS,2!T96UP;&%T97,O<')E9G,O87!P
M+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*
M;7-G<W1R("+:K]BRVXS9AMF'XH",V8?8I]N,("5S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E
M9"!,:7-T(@IM<V=S='(@(MF$VXS8L]BJ(-F%V+'8JMBH(-BTV*_9AR(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38W"FUS9VED(")/
M<F=A;FES871I;VXB"FUS9W-T<B`BV+/8I]BRV878I]F&(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A
M=&EO;F%L(%5N:70B"FUS9W-T<B`BV8C8I]BMV*\@V+/8I]BRV878I]F&VXPB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,R"FUS9VED(")/<F=A
M;FEZ:6YG(@IM<V=S='(@(MBSV*?8LMF%V*?9AMBOV8?;C"(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO
M;B!T96UP;&%T92(*;7-G<W1R("+8I]F$VJ_9B-N,(-BGV+79A-N,(-BHV+'9
MAMBGV879A]F4(-JIV*?8L=BHV+'8K]N,(@H*(R`C+2,M(RTC+2,@(&-O;7!E
M;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@
M=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R("+8I]F$VJ_9B-F'V*?;C"#8I]BU
MV83;C"#8K]BQ("5S.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE<B(*
M;7-G<W1R("+8K]N,VJ_8L2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3,Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-#$*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(MBGV+?9A-BG
MV+G8I]BJ(-BOVXS:K]BQ(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHS,0IM<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`BV878K-F(
MV++B@(S9A]BGVXP@V878I]F$VJDB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W!A;2YP:'`Z-SD*;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@
M879A:6QA8FQE+B(*;7-G<W1R("+8JMBUV*_;C-F"(-F'V8C;C-F1V*H@4$%-
M(-F"V*?8J-F$(-BOV+/8JMBQV+/;C"#9AMN,V+/8JB(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-0IM<V=I9"`B4$5!
M4CHZ36%I;"!B86-K96YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$R-S,*;7-G:60@(E!'4"!$:6=I=&%L(%-I9VYA
M='5R92(*;7-G<W1R("+8I]F%V+;8I]BAXH",(-BOVXS8K-N,V*K8I]F$VXP@
M4$=0(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,Q.0IM
M<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S='(@(MF^VXS8NMBGV84@
MV+'9A=BRV*C9AMBOVXP@V+38K]F'V90@4$=0(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3,W,0IM<V=I9"`B4$=0(%!U8FQI8R!+97DB
M"FUS9W-T<B`B(-JIV83;C-BO(-BYV879B-F%VXP@4$=0(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,U,PIM<V=I9"`B4$=0(%-I9VYE
M9"]%;F-R>7!T960@1&%T82(*;7-G<W1R("+9OMN,V+K8I]F%(-BQV878LMBH
MV8;8K]N,(-BTV*_9AR_8I]F%V+;8I]BA(-BTV*_9AR!01U`B"@HC.B!A9&UI
M;B]P:'!S:&5L;"YP:'`Z-C@*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(MJI
MV*\@4$A0(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@
M4VAE;&PB"FUS9W-T<B`BV;[9B-BSV*K9AR!02%`B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-PIM<V=I9"`B4$T@3&EG:'0@
M4F%I;B(*;7-G<W1R("+8J-BGV+'9AMBOVJ_;C"#8L]BHVJD@V+G8M=BQVJ_8
MI]F'VXPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS.`IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R("+8L=JOV*C8I]BQ(-BY
MV+78L=JOV*?9A]N,(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`BV*C8L=F!(-BY
MV+78L=JOV*?9A]N,(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#`*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R("+8
MJMJOV+':KR#8N=BUV+':K]BGV8?;C"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"B,L(&9U>GIY"FUS9VED(")032!3=6XB
M"FUS9W-T<B`BV*C8L=F!(-BYV+78L=JOV*?9A]N,(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E!-(%0M4W1O
M<FUS(@IM<V=S='(@(E0M4W1O<FUS(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C(W-`IM<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS
M9W-T<B`BV*C8L]BW(%!/4TE8(-BGV+(@V*C;C-F&(-BQV8'8JMF'(.*`C-BG
MV+/8JB(*"B,Z(&QI8B]A<&DN<&AP.C$T.0IM<V=I9"`B4%](4"!3:&5L;"(*
M;7-G<W1R("+9OMF(V+/8JMF'(%!(4"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B
M"FUS9W-T<B`BV8'8I]BUV839A^*`C-JOV+#8I]BQVXPB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3D*(RP@9G5Z>GD*;7-G:60@(E!A:VES=&%N(@IM<V=S='(@(MJ&V+/8J-BG
MV8;8K]F&(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.30@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L874B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y
M+"!/8V-U<&EE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*(RP@9G5Z>GD*
M;7-G:60@(E!A;F%M82(*;7-G<W1R("+9AMBGV84B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$X-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$W-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*
M;7-G:60@(E!A<'5A($YE=R!'=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.34@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,@IM<V=I9"`B4&%R86=U87DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S8*;7-G:60@(E!A<G1L>2!#
M;&]U9'DB"FUS9W-T<B`BV8+8L]F%V*K;C"#8I]BHV+';C"(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34Q(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,3@*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHW-R!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C0S"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C,*;7-G:60@(E!A
M<W-W;W)D(@IM<V=S='(@(MBGV+/9A2#8L=F%V+(@(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED(")087-S=V]R9"!C:&%N9V5D
M('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`BV*?8L]F%(-BQV878LB#8J-BG(-F%
MV8C9@=F1V8+;C-F1V*H@V*K8NMN,VXS8L2#;C-BGV8'8JBXB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$S,C(*;7-G:60@(E!A<W-W
M;W)D(&EN8V]R<F5C="(*;7-G<W1R("+8I]BSV84@V+'9A=BR("#9AMBGV*_8
ML=BSV*H@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N
M<&AP.C$U,@IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BV*?8L]F%(-BQV878LB`@V*C9AR#8
MJMBUV*_;C-F"(-F'V8C;C-F1V*H@4D%$2553(-F&VXS8I]BR(-BOV*?8L=BO
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`U,PIM<V=I9"`B4&%S
M<W=O<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`BV*?8L]F%(-BQV878
MLB`@V*C8IR#8JMBCVXS;C-BO(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.CDP"FUS9VED(")087-S=V]R9#HB"FUS9W-T<B`BV*?8L]F%(-BQ
MV878LB`Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*;7-G
M:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`BV*?8L]F%(-BQV878LB`Z("(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$U,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,#,T"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G
M:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G<W1R("+8I]BSV84@V+'9
MA=BRXH",V8?8IR#8J-BGVXS8KR#9A=F&V+?8J-F"(-BHV*?8M-F&V*\B"@HC
M.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3$Y('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS
M9W-T<B`BVH;8L]BHV*?9AMBOV88B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,W"FUS9VED(")087-T92!F<F]M(&-L:7!B
M;V%R9"(*;7-G<W1R("+:AMBSV*C8I]F&V*_9AB#8I]BR(-BJV*[8JMF'(-BQ
MV+/9A2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`BV878L]N,V+$B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B4&5N9&EN9R!3:6=N
M=7!S.B(*;7-G<W1R("+8J]BHV*H@V8;8I]F%V8?8I]N,(-F&V*?9A=BYV839
MB-F%(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T"FUS9VED(")096]P
M;&4B"FUS9W-T<B`BV878L=BOV84B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R
M("+8K]BQV+78KR(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N
M86YC92YH=&UL.C0Y"FUS9VED(")097)F;W)M($UA:6YT96YA;F-E($]P97)A
M=&EO;G,B"FUS9W-T<B`BV*?8K-BQV*?;C"#8N=F%V83;C-BGV*H@V8;:K]F'
MV*_8I]BQVXPB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#`V"FUS9VED
M(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM
M<V=S='(@(MBBVXS8IR#8N=F%V83;C-BGV*H@V8;:K]F'V*_8I]BQVXP@V*_8
ML2#9A-BMV+C9AR#9B-BQV8C8KR#8I]BLV+'8IR#8M-F(V*_8GR(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED(")097)M:7-S
M:6]N(@IM<V=S='(@(MF%V*S9B-BR(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@861M:6XO<&5R;7,O
M9&5L971E+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N
M(%PB)7-<(B!N;W0@9&5L971E9"XB"FUS9W-T<B`BV878K-F(V+(@(%PB)7-<
M(B#8K=BPV8$@V8;8M-BO(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HU.#8*(RP@9G5Z>GD*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S
M='(@(MF%V*S9B-BR(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HQ-C$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C0*;7-G:60@
M(E!E<FUI<W-I;VYS(@IM<V=S='(@(MF%V*S9B-BRV8?8IR(*"B,Z(&%D;6EN
M+W!E<FUS+V5D:70N<&AP.C$P.2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z
M-C`*(SH@861M:6XO<&5R;7,O:6YD97@N<&AP.C(R(&%D;6EN+W!E<FUS+V1E
M;&5T92YP:'`Z-3@*;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N
M(@IM<V=S='(@(MBSV+'9OMBQV+/8JMN,(-F%V*S9B-BRV8?8IR(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV-0IM<V=I9"`B4&5R<V]N86P@26YF;W)M
M871I;VXB"FUS9W-T<B`BV*?8M]F$V*?8N=BGV*H@V+38KMBUVXPB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0971S(@IM<V=S='(@(MBMVXS9B-BG
MV8;8I]BJ(-BNV*?9AMJOVXPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!H:6QI
M<'!I;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM<V=S='(@(MBJV839
M@=F&(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W.`IM<V=I9"`B
M4&AO=&]S(@IM<V=S='(@(MBYVJG8L]F'V*<B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS
M9VED(")0:71C86ER;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX96QS(@IM<V=S
M='(@(MF^VXS:J=BSV839A]BG(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4V"FUS9VED(")0;&%T:71U9&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@
M(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R("+9A-BWV8'8
MI]F+(-BOV*?8KMF$(-J&V8;8KR#8L]F$V8C9A"#:J=F$VXS:J2#:J=F&VXS8
MKR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N
M="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R("+9A-BWV8'8I]F+
M(-BJV*/;C-N,V*\@VJG9AMN,V*\@VJG9AR#9A=N,XH",V*[9B-BGV8?;C-BO
M(-BGVXS9AB#8N=F&V+78L2#8L=BG(-BMV+#9@2#:J=F&VXS8KSHB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL
M:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`BV838M]F!V*?9BR#8JMBCVXS;
MC-BO(-JIV8;;C-BO(-JIV8<@V87;C.*`C-BNV8C8I]F'VXS8KR#9OMN,V8C9
MAMBO(-BGVXS9AB#8N=F&V+78L=F'V*<@V+'8IR#9@MBWV+D@VJG9AMN,V*\B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3<Q"FUS9VED(")0;&5A
M<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+B(*;7-G<W1R("+9A-BWV8'8
MI]F+(-N,VJD@V878I]F'(-F((-N,VJD@V+/8I]F$(-F(V*?8L=BO(-JIV8;;
MC-BO+B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C$R"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W
M(&-A=&5G;W)Y.B(*;7-G<W1R("+9A-BWV8'8I]F+(-F&V*?9A=N,(-BHV+'8
MI]N,(-BOV+/8JMF'(-BLV*_;C-BO(-F(V*?8L=BO(-JIV8;;C-BO.B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#$*;7-G:60@(E!L96%S92!E
M;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(MF$V+?9@=BGV8L@
MV*+8K]BQV+,@25`@V878N=BJV*C8L=N,(-F(V*?8L=BO(-JIV8;;C-BO(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,`IM<V=I9"`B4&QE87-E
M(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES
M(&EN('1H92!M;VYT:"XB"FUS9W-T<B`BV838M]F!V*?9BR#;C-JI(-BJV*?8
ML=N,V*X@V878N=BJV*C8L2#9B-BGV+'8KR#:J=F&VXS8K]B,(-BJV+G8K]BG
MV*\@V+'9B-BRV8?8IR#8K]BQ(-F%V*?9AR#8L=BG(-JIV8;8JMBQV80@VJG9
MAMN,V*\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4Q"FUS9VED
M(")0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+B(*;7-G<W1R("+9A-BWV8'8
MI]F+(-N,VJD@V++9A=BGV88@V878N=BJV*C8L2#9B-BGV+'8KR#:J=F&VXS8
MKR(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@
M(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS
M9W-T<B`BV838M]F!V*?9BR#8KMF$V*?8M=F'XH",V*?B@(S;C-N,(-BGV+(@
MV878M-JIV80@V+'8IR#8J-F&V8C;C-BSVXS8KR(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z,C(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR
M-@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S
M<W=O<F0B"FUS9W-T<B`BV838M]F!V*?9BR#9AMBGV84@VJG8I]BQV*C8L2#9
MB"#8I]BSV84@V+'9A=BR("#8KMF(V*\@V+'8IR#8HMF%V*?8K]F'(-JIV8;;
MC-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C
M+2,M(RTC+2,*(R`*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4X"FUS
M9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-
M55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M
M+B(*;7-G<W1R("(B"B+9A-BWV8'8I]F+(-F%V*K9AB#8LMN,V+$@V+'8IR#8
MJ-BNV8C8I]F&VXS8KRX@V+39A=BG(-BHV+'8I]N,(-BGV+/8JMF!V*?8K]F'
M(-BGV+(@V+/8I]F%V*?9AMF'(-BHV*?;C-BO(-BTV+'9B-BW(-BQV*<@V8+8
MJ-F(V80@VJG9AMN,V*\B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T
M96=O<GE-86YA9V5R+G!H<#HW,`IM<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE
M=R!C871E9V]R>2!N86UE.B(*;7-G<W1R("+9A-BWV8'8I]F+(-F&V*?9A2#8
MK]BSV*K9AR#8K-BOVXS8KR#8L=BG(-F(V*?8L=BO(-JIV8;;C-BO.B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY.0HC+"!F=7IZ>0IM<V=I9"`B4&]L86YD(@IM<V=S='(@(MF!
MV+'9A=BGV88B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@
M(E!O;&ET:6-S(@IM<V=S='(@(MBSVXS8I]BSV*K9A]BG(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0X-PIM<V=I9"`B4&]L;',B"FUS9W-T<B`B
MV*+8L=BGV*$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"B,L(&9U>GIY"FUS9VED(")0;W)T
M=6=A;"(*;7-G<W1R("+8K]BQVJ_8I]F'(-F%V88B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C<*;7-G
M:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T<B`BV878K=F$
M(-F"V+'8I]BQVJ_8L=F!V*K9AB#8I]N,V88@V*K8M=F(VXS8L2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED
M(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(MF%V*W9A"#9
M@MBQV*?8L=JOV+'9@=BJV88@V*?;C-F&(-BLV*_9B-F$(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@(E!O<W0@
M=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R
M("+9OMBSV*H@V*C9AR#8I]N,V88@V;[9B-BTV8<B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(V-B!L:6(O0FQO8VLO;65T87(N<&AP.C(W,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H
M<RDZ("(*;7-G<W1R("+8K]BQV+78KR#8L=BWV8C8J-BJ(-BOV+$@)7,@V+/8
MI]BYV*H@V8+8J-F$.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR.3@*;7-G:60@(E!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+VQD87`N<&AP.CDX"FUS
M9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(E!R969S7VQD87`Z(-BHV+/8MR#9A=F(V+'8KR#9
MAMN,V*?8LB!,1$%0(-F^VXS8K]BG(-F&V+38KR(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO
M;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R(")0<F5F<U]S97-S:6]N.B#8J-BSV+<@V879B-BQV*\@V8;;C-BGV+(@
M<V5S<VEO;B#9OMN,V*_8IR#9AMBTV*\B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(R-0IM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`BV8'8M-BGV+$B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U.0IM<V=I9"`B4')E<W-U<F4@870@
M<V5A(&QE=F5L.B`B"FUS9W-T<B`BV8'8M-BGV+$@V*_8L2#8L]BWV*T@V*_8
ML=N,V*<Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S4*
M;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T<B`BV8'8M-BGV+$Z("(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,#4*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@(MF^VXS8M.*`C-F&V878I]N,
MV+0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C0*;7-G:60@(E!R979I97<@=&AE(&EM86=E(&EN(&$@
M;F5W('=I;F1O=R(*;7-G<W1R("+9OMN,V+3B@(S9AMF%V*?;C-BT(-BJV+79
MB-N,V+$@V*_8L2#;C-JI(-F^V8;8K-BQV8<@V*S8K]N,V*\@(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C(@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HS-C8*;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS
M9W-T<B`BVJ_8LMN,V8;9A^*`C-F'V*?;C"#9@MBHV83;C"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R
M:6YT(&1O8W5M96YT(@IM<V=S='(@(MJ&V*?9OB#8L]F&V*\B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@
M2V5Y(@IM<V=S='(@(MJIV83;C-BO(-BTV*[8M=N,(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V.0IM<V=I9"`B4')O8FQE;2(*;7-G
M<W1R("+9A=BTVJG9A"(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-@IM
M<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R("+8JMF(V+;;C-BM
M(-F%V+3:J=F$(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,V.0IM
M<V=I9"`B4')O:F5C=',B"FUS9W-T<B`BV;[8L=F(VIC9A^*`C-F'V*<B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3$Q(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Q.#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X
M-0IM<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`BV878JMF&(-BGV+G9A-BG
MV88B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G
M:60@(E!U8FQI8R!+97DB"FUS9W-T<B`BVJG9A-N,V*\@V+G9A=F(V87;C"(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED
M(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R("+8I]F$VJ_9B-BQVXS8
MJMF%(-JIV83;C-BO(-BYV879B-F%VXPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8T-`HC+"!F=7IZ>0IM<V=I9"`B4'5B;&EC($ME
M>2!);F9O(@IM<V=S='(@(MJIV83;C-BO(-BYV879B-F%VXPB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HR-#$*;7-G:60@(E!U8FQI8R]0
M<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM
M<V=S='(@(MBLV8'8JB#:J=F$VXS8KR#8N=F%V8C9A=N,+]BNV+79B-BUVXP@
MV*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BJV8C9A-N,V*\@V8;8M-BO(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,@HC+"!F=7IZ>0IM<V=I9"`B46%T87(B"FUS9W-T<B`BV*_8
MI]BOV8<B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C,*;7-G:60@(E%U97)Y
M(@IM<V=S='(@(MF^V+'8L^*`C-F(V*S9B"(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HW,`IM<V=I9"`B475O=&$B"FUS9W-T<B`BV+/9A]F%VXS9AR(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C8S"B,L('!H
M<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S
M='(@(B#:J=F$VXS8KR#8N=F%V8C9A=N,(%)302`H)60@V*C;C-BJ*2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C0*;7-G:60@(E)A9&EO('-E
M;&5C=&EO;B(*;7-G<W1R("+8I]F&V*K8KMBGV*@@V+'8I]BOVXS9B"(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0S"FUS9VED
M(")286EN(@IM<V=S='(@(MBHV*?8L=BGV88B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4F%I;B!%87)L>2(*
M;7-G<W1R("+8J-BGV+'8I]F&(-BRV8C8K]F'V8;:K]BGV84B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I
M;B!,871E(@IM<V=S='(@(MBHV*?8L=BGV88@V*_;C-BQV8?9AMJOV*?9A2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0V"FUS
M9VED(")286EN(%-H;W=E<B(*;7-G<W1R("+8J-BGV+'8I]F&(-F((-BQVJ_8
MJ-BGV+$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT-PIM<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R("+8J-BGV+'8I]F&
M(-F((-BHV+'9@2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0X"FUS9VED(")286EN('1O(%-N;W<B"FUS9W-T<B`BV*C8I]BQ
MV*?9AB#8J-F'(-BHV+'9@2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R("+8M]BGV838N2#8JMBU
MV*?8K]F!VXPB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*
M;7-G:60@(E)A=&EO(@IM<V=S='(@(MF&V+/8J-BJ(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*;7-G:60@(E)E860B"FUS9W-T
M<B`BV*[9B-BGV8;8K]F&(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.#<*;7-G:60@(E)E860@;65S<V%G97,B"FUS9W-T<B`B
MV*[9B-BGV8;8K]F&(-F^VXS8NMBGV879A]BG("(*"B,@(RTC+2,M(RTC("!C
M;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@
M8F4@=6YD;VYE+B(*;7-G<W1R("+9B-BGV8+8N=BGV9(@)7,@V*W8L-F!(-BT
MV8C8K]B?(-BGVXS9AB#8N=F%V80@V8+8I]BHV80@V8C8I]JOV+'8KR#9AMN,
MV+/8JB(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@
M(RTC+2,M(RTC"B,@"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN
M8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D
M871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD
M;VYE+B(*;7-G<W1R("+9B-BGV8+8N=BGV8L@V*_8I]BOV8?9E"#:J=BGV+'8
MJ-BQVXP@V*C8L=BGVXP@VJG8I]BQV*C8L2`E<R#8K=BPV8$@V+39B-BOV)\@
MV*?;C-F&(-BYV879A"#9@MBGV*C9A"#9B-BGVJ_8L=BO(-F&VXS8L]BJ(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM
M<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`BV*?9AMBL
MV*?9A2#8HMBNV+';C-F&(-BYV879A"#8M-F%V*<@V*?8LB#9AMF((@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@
M16QE;65N=',Z(@IM<V=S='(@(MBHV*?8LMBBV8C8L=N,(-BYV8;8I]BUV+$@
MVJ_8LMN,V8;:K]BGV88@V*_;C-F&V*?9A=N,VJG;C#HB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S0Q"FUS9VED(")2969R97-H(%!O<G1A;"!6:65W
M.B(*;7-G<W1R("+8J-BGV++8HMF(V+';C"#9AMF%V*?;C"#8K]BQVJ_8I]F'
M.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-"!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,C$S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R,S4*(RP@9G5Z>GD*;7-G:60@(E)E9V5X(@IM<V=S='(@(MBHV*?8LMF&
MV+38I]F&VXPB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C0Y"FUS
M9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R("+9A=BQV8C8L=JO
MV+$@V+'8I]BHV+?9A^*`C-BGXH",VXS;C"(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M,#@*(RP@9G5Z>GD*;7-G:60@(E)E;&]A9"(*;7-G<W1R("+8KMF(V*?9AMBO
MV88B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R-@IM<V=I9"`B4F5M87)K
M<R(*;7-G<W1R("+8JMF(V+;;C-BMV*?8JB(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,30*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(MJI
MV*?8L=BSV*?8LMF'V*?;C"#8L=BGV8?B@(S8K]F(V+$B"@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@*&AT
M='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R(")54DPB"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(R('1E;7!L871E
M<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3,*;7-G:60@(E)E;6]V92(*;7-G
M<W1R("+8K=BPV8$B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M,3$*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R("+8K=BPV8$@V*C9A-F(
MVJDB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-34W"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(MBMV+#9@2#8L]BJ
MV8C9AB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-#`*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(MBMV+#9
M@2#9@MBGV838J"#8J-F&V*_;C"(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z,3(X"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R("+8K=BPV8$@
MV++9B-BL(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B
M4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D
M:7)E8W1O<GDN(@IM<V=S='(@(MBMV+#9@2#8K]BSV*H@XH",V8;9B-N,V+/9
MA]BGVXP@V*W9@=BX(-BTV*_9AR#8K]BQ(-BTV*?8KMF'(-F%V8C9@MBJ(-JI
MV*?8L=BSV*?8LB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHT,@IM<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R
M("+8K=BPV8$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O
M;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`BV*W8L-F!(-BGVXS9AB#:K]BQV8<@
MV*?8LB#8L]F&V*\B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N
M:6YC.C$Q"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R("+8K=BPV8$@VJG8
MI]BQV*C8L2(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S
M*2`@(RTC+2,M(RTC"B,@"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M92YI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@=7-E<CH@)7,B
M"FUS9W-T<B`BV*W8L-F!(-JIV*?8L=BHV+$Z("5S(@H*(SH@9G)A;65W;W)K
M+U)00R]24$,O>&UL<G!C+G!H<#HQ,S@*;7-G:60@(E)E<75E<W0@8V]U;&1N
M)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@
M(MBJV8+8I]BVV*<@V8+8I]BHV80@V;[8I]BSV*[:K]F(VXS;C"#9AMN,V+/8
MJBX@VJG8KR#8KMBWV*?;C"#8J-BQVJ_8L=BOV*?9AMBOV8<@V+38K]F'.B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*(RP@9G5Z>GD*
M;7-G:60@(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"XB
M"FUS9W-T<B`BV;[8L=F(V8;8K]F'(-BGV+'8L]BGV80@V+38K]F'(-F&V87;
MC.*`C-BJV8C8I]F&V*\@V*W9@=BX(-BTV8C8KR(*"B,@(RTC+2,M(RTC("!C
M;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,3<T(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z-3$R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E
M9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R("(G)7,G(-F%V8C8L=BO(-F&VXS8I]BR(-BOV+$@V;[;C-JIV+'8
MJ-F&V*_;C"`E<R#9A=BTV*[8M2#9AMBTV*_9AR#8I]BSV*HB"@HC(",M(RTC
M+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8W-2!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C@S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z-S(S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E
M9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B)R5S)R#9A=F(V+'8KR#9AMN,V*?8LB#8K]BQ(-F^VXS:J=BQ
MV*C9AMBOVXP@5D93(-F%V+38KMBU(-F&V+38K]F'(-BGV+/8JB(*"B,@(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@
M"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<X,0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@
M:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B)R5S)R#9A=F(V+'8KR#9AMN,
MV*?8LB#8K]BQ(-F^VXS:J=BQV*C9AMBOVXP@V878M-BNV+4@V8;8M-BOV8<@
MV*?8L]BJ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z
M,S,U"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R("+9@=N,V838K]F'
MV*?;C"#9A=F(V+'8KR#9AMN,V*?8LB(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S.0HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+U)E;F1E<F5R+G!H<#HS,C`@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C$P,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C<W"FUS9VED(")297-E="(*;7-G<W1R("+8J-BGV++9AMBTV*?9AMN,(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#8*;7-G:60@(E)E<V5T
M(%!A<W-W;W)D(@IM<V=S='(@(MBHV*?8LMF&V+38I]F&VXP@V*?8L]F%(-BQ
MV878LB(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W"FUS9VED
M(")297-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(MBGV+/9A2#8L=F%V+(@
MV*[9B-BO(-BQV*<@V*C8I]BRV8;8M-BGV8;;C"#:J=F&VXS8KR(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,S`*(RP@9G5Z>GD*;7-G:60@(E)E<W1O<F4@
M3&%S="!1=65R>2(*;7-G<W1R("+8L=BHV+D@V*+8KMBQ(@H*(SH@861M:6XO
M<&AP<VAE;&PN<&AP.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S
M<6QS:&5L;"YP:'`Z-C8*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`BV8;8JMBG
MVXS8K"(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@=&5M
M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO
M;G,B"FUS9W-T<B`BV*C8I]BRVJ_8M-BJ(-BHV8<@VJ_8LMN,V8;9A^*`C-F'
MV*<B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S@*;7-G:60@
M(E)E='EP92!N97<@<&%S<W=O<F0B"FUS9W-T<B`BV*K8I]N,V;X@V*_9B-BH
MV*?8L=F'(-BGV+/9A2#8L=F%V+(@(-BLV*_;C-BO("(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#(*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`BVJ_8L=BOV8?9A=BGVXS;C"(*
M"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M
M(RTC"B,@"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB
M"FUS9W-T<B`BV*C8I]BRVJ_8L=BOV*?9AMBOV88@V;[;C-JIV+'8J-F&V*_;
MC"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S(*;7-G:60@(E)I8V@@
M5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R("+:K]BRVXS9AMF'XH",V8?8
MI]N,(-F(VXS8L=BGVXS8M-JOV+$@V878JMF&(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4X"FUS9VED(")2:61D;&5S(@IM<V=S='(@(MF%V+G9A=BG
MV8?8IR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW,`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`BV+'8I]BSV*HB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(Q"FUS9VED(")2:6=H="!H
M96%D97(B"FUS9W-T<B`BV+/8L=BBV878KR#8L=BGV+/8JB(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3<*;7-G:60@(E)I9VAT('9A;'5E<R(*
M;7-G<W1R("+9A=F"V*?8K]N,V+$@V+'8I]BSV*HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@
M(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R("+8KMBUV8C8M=N,V*?8JB#8
ML]BWV+$N+BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(MF&V8+8M"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R-0IM<V=I9"`B4F]T
M871E(#$X,"(*;7-G<W1R("+:AMBQV*[8M"#;L=NXV[`@V*_8L=BLV8<B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(R"FUS
M9VED(")2;W1A=&4@3&5F="(*;7-G<W1R("+:AMBQV*[8M"#8J-F'(-J&V;XB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(X
M"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`BVH;8L=BNV+0@V*C9AR#8
ML=BGV+/8JB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0<F]P97)T:65S(@IM<V=S='(@
M(MBNV+79B-BUVXS8I]BJ(-BSV+?8L2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P<F]P
M97)T:65S(@IM<V=S='(@(MBNV+79B-BUVXS8I]BJ(-BSV+?8L2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED
M(")2;W=S.B(*;7-G<W1R("+8L]BWV+'9A]BG.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G:60@(E)U
M;&5S(@IM<V=S='(@(MF"V8C8I]BYV*\B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE<R!W
M:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S
M='(@(MF"V8C8I]BYV*\@V*C;C-F&(-BJV878I]F%(-BSV+?8L=F'V*<@V8@@
MV+/8JMF(V8;9A]BG(-F&V878I]N,V*?9AB#8KMF(V*?9A]BO(-BTV*\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4Q"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@
M;VYL>2(*;7-G<W1R("+9@MF(V*?8N=BO(-F!V8+8MR#8J-N,V88@V*K9A=BG
MV84@V+/8JMF(V8;9A]BG(-F&V878I]N,V*?9AB#8KMF(V*?9A]BO(-BTV*\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@
M;VYL>2(*;7-G<W1R("+9@MF(V*?8N=BO(-F!V8+8MR#8J-N,V88@V*K9A=BG
MV84@V+/8M]BQV8?8IR#9AMF%V*?;C-BGV88@V*[9B-BGV8?8KR#8M-BO(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R,`IM<V=I9"`B4G5N(@IM<V=S='(@
M(MBGV*S8L=BG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G5S<VEA;B!&961E
M<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*(RP@9G5Z>GD*;7-G
M:60@(E)W86YD82(*;7-G<W1R("+8KMF(V*?9AMBOV88B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%($-R
M>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S(S"FUS9VED(")3+TU)344@16YC
M<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`BV;[;C-BZV*?9A2#8L=F%V++8J-F&
MV*_;C"`@V+38K]F'V90@4R]-24U%("(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<V%S;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@
M;F]T(&%V86EL86)L92XB"FUS9W-T<B`BV*K8M=BOVXS9@B#9A]F(VXS9D=BJ
M(%-!4TP@V8+8I]BHV80@V*_8L]BJV+'8L]N,(-F&VXS8L]BJ(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4P-`IM<V=I9"`B4TU3($UE<W-A9VEN
M9R(*;7-G<W1R("+9OMN,V+K8I]F%(%--4R(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(MF^V8C8L]BJV8<@
M4U%,(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,PIM<V=I9"`B
M4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P<R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Q"FUS9VED(")34T@B"FUS
M9W-T<B`B4U-((@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC
M871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*
M;7-G<W1R("+9A=F(V8'9D=F"VXS9D=BJ(@H*(SH@;&EB+V%P:2YP:'`Z,34S
M"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@(MF^V8C8L]BJV8<@4U%,(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0IM
M<V=I9"`B4V$B"FUS9W-T<B`BV+39AMBHV8<B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS
M9VED(")386EN="!(96QE;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS
M9VED(")386EN="!+:71T<R!A;F0@3F5V:7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,SD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@W"B,L(&9U>GIY"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R("+8
MJ-BGV+'8I]F&(-BOVXS8L=F'V8;:K]BGV84B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS
M9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,34*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N
M861I;F5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*
M;7-G<W1R("+9A]F%V*?9AB#:AMBGV+':AMF(V*@@*-BNV8C8K]BT*2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(E-A;6]A(@IM<V=S='(@(MF'
MV+'8LMF&V*?9A=F'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@HC+"!F=7IZ>0IM<V=I9"`B
M4V%N($UA<FEN;R(*;7-G<W1R("+8K=BGV+3;C-F'(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-PIM<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*(RP@9G5Z>GD*;7-G
M:60@(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R("+9B-BVV+G;C-BJ(-BM
MV8C8LMF'XH",V8?8IR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R
M86)I82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI
M;F,Z.3@*;7-G:60@(E-A=F4B"FUS9W-T<B`BV*W9@=BX(-JIV+'8K]F&(@H*
M(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC
M+2,*(R`*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T
M<B`BV*W9@=BX(-JIV+'8K]F&("5S(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHR,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E
M<R(*;7-G<W1R("+8K=F!V+@@VJG8L=BOV88@)7,B"@HC.B!T96UP;&%T97,O
M<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`B
MV*W9@=BX(-JOV++;C-F&V8?B@(S9A]BG(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$V-PIM<V=I9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A
M=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A
M<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R("+9OMN,VJG8L=BHV8;8K]N,(-BJ
MV8C9A-N,V*\@V+38K]F'(-BHV+G9AMF(V*?9AB#8K]BSV*H@XH",V8;9B-N,
MV+,@4$A0(-BOV+$@V+38I]BNV8?9E"#9A=F(V8+8JB#:J=BGV+'8L]BGV+(@
MV+39A=BG(-BMV8'8N"#8M-F(V*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU
M;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+9OMN,VJG8L=BHV8;8K]N,("5S(-BM
MV8'8N"#8M-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E
M(#,I("`C+2,M(RTC+2,*(R`*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M.3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P
M9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(MBOV+/8JB#B@(S9
MAMF(VXS8LR#8J-BQV8C8LMBQV+/8I]F&VXP@V+'8I]F'XH",V*?9AMBOV*?8
MLMN,(-BMV8'8N"#8M-BO(-BOV+$@.B<E<R<@+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"B,L(&9U>GIY"FUS9VED(")3
M8V%T=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B5"U3=&]R;7,B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B
MV+G9A-F%(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C
M:"(*;7-G<W1R("+8K-BSV*KB@(S9B-BLV8@B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S(P"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R
M("+8K-F(VXS8M-JOV+'9A]BG(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,CDW,PIM<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S='(@(MBGV8;8JMBN
MV*?8J"#9OMBQV8C9AMBOV8?B@(S9A]BG(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-`IM<V=I9"`B4V5L96-T(&$@9&%T
M92(*;7-G<W1R("+8I]F&V*K8KMBGV*@@VXS:J2#8JMBGV+';C-BN(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.3@*;7-G:60@(E-E;&5C="!A
M(&=R;W5P('1O(&%D9"(*;7-G<W1R("+8I]F&V*K8KMBGV*@@VXS:J2#:K]BQ
MV8C9AR#8J-BQV*?;C"#8I]BVV*?9@=F'(-JIV+'8K]F&(@H*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W
M;F5R(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#;C-JI(-F%V*?9A-JI(-BLV*_;
MC-BO(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS9VED
M(")396QE8W0@82!S97)V97(B"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-N,VJD@
MVJG8I]BQV+/8I]BR(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M-38*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S='(@(MBGV8;8
MJMBNV*?8J"#;C-JI(-JIV*?8L=BHV+$@V*C8L=BGVXP@V*?8MMBGV8'9AR#:
MJ=BQV*_9AB(*"B,@(RTC+2,M(RTC("!F85])4BYP;R`H5'5R8F$@,2XR+C(I
M("`C+2,M(RTC+2,*(R!M<V=I9"`B4V5A<F-H(%)E<W5L=',B"B,@;7-G<W1R
M("+9AMBJV*?;C-BL(-BLV+/8JMBLV8@B"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HV-S<*;7-G:60@(E-E;&5C="!A;&PB"FUS
M9W-T<B`BV*?9AMBJV*[8I]BH(-F'V879AR(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(V-C,*;7-G:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE
M;G1S+B(*;7-G<W1R("+8I]F&V*K8KMBGV*@@V*K9A=BGV84@V878I-F$V8'9
MA^*`C-F'V*?;C"#8JMBGV+';C-BN(@H*(R`C+2,M(RTC+2,@(&9A7TE2+G!O
M("A4=7)B82`Q+C(N,BD@(",M(RTC+2,M(PHC(&US9VED(")396%R8V@@4F5S
M=6QT<R(*(R!M<V=S='(@(MF&V*K8I]N,V*P@V*S8L]BJV*S9B"(*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B
M4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R("+8I]F&V*K8KMBGV*@@VXS:J2#8
MM-BF(@H*(R`C+2,M(RTC+2,@(&9A7TE2+G!O("A4=7)B82`Q+C(N,BD@(",M
M(RTC+2,M(PHC(&US9VED(")396%R8V@@4F5S=6QT<R(*(R!M<V=S='(@(MF&
MV*K8I]N,V*P@V*S8L]BJV*S9B"(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C8W.`IM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T
M<B`BV*?9AMBJV*[8I]BH(-F'VXS:AN*`C-JIV*_8I]F%(@H*(SH@<V5R=FEC
M97,O:V5Y8F]A<F0N<&AP.C,W"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A
M8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@
M=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E
M82XB"FUS9W-T<B`B(@HBV8;9B-N,V+/9A^*`C-F'V*?;C-N,(-JIV8<@V838
MI]BRV84@V*_8I]BQVXS8KR#8L=BG(-BGV+(@V*S8N=BHV8<@V++;C-BQ(-BG
MV8;8JMBNV*?8J"#:J=F&VXS8KRX@V+/9OMBS(-BTV878IR#9A=N,XH",V*K9
MB-BGV8;;C-BO(-BGV+(@V*+9AMF'V*<@(@HBV*_8L2#9A=F&V+?9@MF'(-F%
MV*K9AB#9AMBSV*[9A^*`C-BHV+'8K]BGV+';C"#:J=BQV*_9AR#9B"#8K]BQ
M(-F%V*W9A"#8K]N,VJ_8L2#8J-J&V+/8J-BGV8;;C-BO(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D
M96QI;6ET97(Z(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#9A=BMV*_9B-BOV8<@
MV*K8I]BQVXS8KCHB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-`IM
M<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`BV*?9AMBJ
MV*[8I]BH(-F"V*?9A-BH(-BJV*?8L=N,V*XZ(@H*(SH@=&5M<&QA=&5S+W!R
M969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L96-T('1H92!I
M9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(MBGV8;8JMBN
MV*?8J"#9A]F(VXS9D=BJVXP@VJG9AR#9A=N,XH",V*[9B-BGV8?;C-BO(-BJ
MV+K;C-N,V+$@V*_9A]N,V*\Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI
M;F,Z,38*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S
M='(@(MBGV8;8JMBNV*?8J"#9A=BMV*_9B-BOV8?9E"#8LMF%V*?9ACHB"@HC
M.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H
M92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-F"V*?9A-BH
M(-BRV878I]F&.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*
M;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R("+8
MI]F&V*K8KMBGV*@@V*_9B"#9@=N,V838KR#9A=F&V+?8J-F"(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,P-@IM<V=I9"`B4V5L96-T('EO=7(@8V]L
M;W(@<V-H96UE+B(*;7-G<W1R("+8I]F&V*K8KMBGV*@@V+?8L=BM(-BQV8;:
MKR#8M-F%V*<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0X"FUS9VED
M(")396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(MBG
MV8;8JMBNV*?8J"#8LMBHV*?9AB#9A=F(V+'8KR#9AMBXV+$@V+39A=BG.B(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")3
M96YD(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(MBGV+'8L]BGV80@VJ_8LMBG
MV+'8M"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,#,Y"FUS9VED(")396YD(%--4R(*;7-G<W1R("+8I]BQV+/8I]F$(%--
M4R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,38*;7-G:60@(E-E;G-O<CH@(@IM
M<V=S='(@(MBMV+/:K]BQ.B`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`Y"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW,PIM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(MBS
MV;[8JMBGV878J-BQ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R;R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,0IM
M<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R("+8I]BYV*_8I]BO(-BJV+'8
MJMN,V*C;C"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*
M(RP@9G5Z>GD*;7-G:60@(E-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I
M;&%B;&4N(@IM<V=S='(@(MBHV839B-JI($UE=&%R(-F"V*?8J-F$(-BOV+/8
MJMBQV+,@V8;;C-BSV*HB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C<*(RP@
M9G5Z>GD*;7-G:60@(E-E<W-I;VX@061M:6XB"FUS9W-T<B`BV+/8L=F^V+'8
ML]BJVXP@V878K-F(V++9A]BG(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")397-S:6]N($E$(&5X
M<&ER960N(@IM<V=S='(@(DE$(-F&V+38L]BJ(-F%V8;9@MBVVXP@V+38K]F'
M(-BGV+/8JB(*"B,Z(&QI8B]A<&DN<&AP.C$T-0HC+"!F=7IZ>0IM<V=I9"`B
M4V5S<VEO;G,B"FUS9W-T<B`BV878K-F(V++9A]BG(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C,Q-`IM<V=I9"`B4V5T(@IM<V=S='(@(MBJV8;8
MN-N,V84B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8*;7-G:60@(E-E
M="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D
M(&EF('EO=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B(@HBV*K9AMBXVXS9
MA2#:K]BRVXS9AMF'XH",V8?8IR#8J-BQV*?;C"#8I]BLV*?8LMF'(-BOV*?8
MK]F&(-BHV8<@V+39A=BG(-BHV+'8I]N,(-BHV*?8LMF&V+38I]F&VXP@V*?8
ML]F%(-BQV878LB#8J-F'(-F'V8;:K]BGV84@V8'8L=BGV879B-BTVXP@(@HB
MV*+9AB`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED(")3
M970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@
M9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B(@HBV*K9AMBXVXS9A2#:J=BG
MV+'8L]BGV++9A]BGVXP@V+'8I]F'(-BOV8C8L=N,(-JIV8<@V+39A=BG(-F%
MVXSB@(S8KMF(V*?9A]N,V*\@V*?8LB#8K]BQVJ_8I]F'(-BNV8C8KR#8J-F'
M(-BBV88@V*_8L]BJV+'8L]N,(-BOV*?8M-BJV8<@(@HBV*C8I]BTVXS8KR(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-`IM<V=I9"`B4V5T('EO=7(@
M<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS
M+B(*;7-G<W1R("+8I]F&V*K8KMBGV*@@V++8J-BGV88@V879B-BQV*\@V8;8
MN-BQV(P@V+/8I]BYV*H@V8@@VJ_8LMN,V8;9A^*`C-F'V*?;C"#8JMBGV+';
MC-BN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX"FUS9VED("(B"B)3
M970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A
M9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB
M"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-BHV+'9AMBGV879AR#8LMF%V*?9AB#8
MM-BQV8C8N=B,(-BWV+'8K2#8L=F&VJ_8C"#8J-BGV++8HMF(V+';C"#8M=F!
MV*W9AR#9B"#8J-F"VXS9AR#:K]BRVXS9AMF'XH",V8?8I]N,(-F&V878I]N,
MV+0B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<U"FUS9VED(")3971U
M<"(*;7-G<W1R("+8L=BGV8<F(W@R,#!C.]BGV8;8K]BGV++;C"(*"B,@(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@
M"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,W"FUS9VED
M(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S='(@(MBO
MV+/8JB#B@(S9AMF(VXS8LR`@V*C8L=F(V++8L=BSV*?9AMN,(-BQV*?9A^*`
MC-BGV8;8K]BGV++;C"#8K]BQ(-BOV+/8JMBQV+,@V*?8L]BJ(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$X-@IM<V=I9"`B4V5V97)A;"!L
M;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T
M<B`BVH;9AMBOVXS9AB#9A=F(V8+8N=N,V9'8JB#8J-BG(-F^V*?8L=BGV878
MJMBQ(-F%V87:J=F&(-BGV+/8JCHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3
M97EC:&5L;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT.38*;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@(MBNV+';C-BO(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@(E-H
M;W)T(%-U;6UA<GDB"FUS9W-T<B`BV*[9A-BGV+79AR#:J=F(V*K8I]F'(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T-@IM<V=I9"`B4VAO=6QD(&%C
M8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@
M(MBBVXS8IR#:J=F$VXS8K]F'V*?;C"#8K]BSV*K8L=BSVXP@V*C8I]N,V*\@
MV*C8L=BGVXP@V*C;C-BTV*K8L2#9OMN,V8C9AMBOV8?8IR#8JMBYV+';C-F!
M(-BTV8C9AMBOV)\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R
M,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,S"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z-C<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY
M,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,R!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$S-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$W.0IM<V=I9"`B4VAO=R(*;7-G<W1R("+9AMF%V*?;C-BT(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$U-0IM<V=I9"`B(@HB4VAO=R!D:69F
M97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY
M(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(@V8;9A=BG
MVXS8M"#8JMF!V*?9B-BJV8?8I]N,(-F%VXS8I]F&(-F^VXS:J=BQV*C9AMBO
MVXP@V*W9@=BX(-BTV*_9AR#9@=BYV83;C"#9B"#8JMF(V83;C-BO(-BTV*_9
MAR#8K-BOVXS8KR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3`*;7-G
M:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS
M9W-T<B`BV*+;C-BG(-BRV878I]F&(-BBV*[8L=N,V88@V8C8L=F(V*\@V*C9
MAR#9A]F&VJ_8I]F%(-F(V+'9B-BO(-F&V+38I]F&(-BOV*?8K]F'(-BTV8C8
MK]B?(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V-0IM<V=I9"`B
M4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R("+9AMF%V*?;
MC-BT(-JOV++;C-F&V8?B@(S9A]BG(-BHV+'8I]N,(-F&VJ_9A]BOV*?8L=N,
M(-BGV+79A"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3,*;7-G
M:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#9@]F&V8;8
MK]F'(-F&V878I]N,V+0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(V
M"FUS9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM<V=S
M='(@(MBBVXS8IR#9A=N,V839AR#:K]BRVXS9AMJOV*?9AB#8N=F%V83;C-BG
MV*H@V*S8K]F(V83B@(P@V8;9A=BGVXS8M"#8K]BGV*_9AR#8M-F(V*_8GR(*
M"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M
M(RTC"B,@"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\B"FUS
M9W-T<B`BV*+;C-BG(-JOV++;C-F&VJ_8I]F&("5S(-BSV878JB#8L=BGV+/8
MJB#9AMBTV*?9AB#8K]BGV*_9AR#8M-F(V*_8GR(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.0IM<V=I9"`B
M4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R
M("+9AMF%V*?;C-BT(-JOV8'8JN*`C-F(VJ_9B-N,(-BNV+79B-BUVXS8I]BJ
M(-BSV839B-F$(-BLV*_9B-F$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8T"FUS9VED(")3:&]W('1H92!4
M86)L92!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("+9AMF%V*?;C-BT(-JO
MV8'8JMJOV8C;C"#8KMBUV8C8M=N,V*?8JB#8K-BOV8C9A"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`IM
M<V=I9"`B4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM
M<V=S='(@(MF&V878I]N,V+0@VJ_9@=BJVJ_9B-N,(-BNV+79B-BUVXS8I]BJ
M(-BSV+?8L2#8K-BOV8C9A"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA
M9V4@<')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`BV8;9A=BGVXS8M"#:K]F!
MV*K:K]F(VXP@V*[8M=F(V+7;C-BGV*H@V*K8M=F(VXS8L2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C,*;7-G:60@(E-H;W<@=7!L;V%D(@IM
M<V=S='(@(MF&V878I]N,V+0@V*?8L=BSV*?9A"(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4P"FUS9VED(")3:&]W97)S(@IM
M<V=S='(@(MBJVJ_8L=JO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-3$*;7-G:60@(E-H;W=E<G,@16%R;'DB"FUS9W-T<B`B
MV+':K]BHV*?8L2#8LMF(V*_9A]F&VJ_8I]F%(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H;W=E<G,@3&%T
M92(*;7-G<W1R("+8L=JOV*C8I]BQ(-BOVXS8L=F'V8;:K]BGV84B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,PIM<V=I9"`B
M4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#@P"FUS9VED(")3:')I;FLB
M"FUS9W-T<B`BV*S9A=BY(-BTV*_9AB(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C<W-"!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HX,S8*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z.3(R(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.CDX-`HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,#0W(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$P.#<*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$Q-B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HQ,30Y"FUS9VED(")3:')I;FL@;W(@;6]V92!N
M96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0B"FUS
M9W-T<B`BV*S9A=BY(-BTV*_9AB#;C-BG(-BGV8;8JMF"V*?9A"#8J-F$V8C:
MJ=F'V*?;C"#9A=BLV*?9B-BQ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VEE
M<G)A($QE;VYE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M4VEG;G5P+G!H<#HR-C4*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`BV*O8J-BJ
M(-F&V*?9A2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-S$R"FUS9VED(")3:6=N871U<F4B"FUS9W-T<B`BV*?9A=BVV*?8H2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$Q"FUS9VED(")3
M:6=N871U<F4@06QG;W)I=&AM(@IM<V=S='(@(MBGV83:K]F(V+';C-BJV84@
MV*?9A=BVV*?8H2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*(RP@9G5Z>GD*;7-G:60@(E-I
M;F=A<&]R92(*;7-G<W1R("+8I]F%V+;8I]BA(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HV-2!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C<R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DV"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,34@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(S-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0V
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S`*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$R,PIM<V=I9"`B4VEZ92(*;7-G<W1R("+8I]F&V*_8
MI]BRV8<B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N
M:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R("+8M=BQ
MV8'9AMBXV+$@V*?8LB#9AMJOV8?8K]BGV+';C"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*
M;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G
M:60@(E-L;W9E;FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4T"FUS9VED(")3;F]W(@IM<V=S='(@(MBH
MV+'9@2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4U"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R("+8JMJOV+':KR(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V"FUS9VED
M(")3;F]W(%-H;W=E<G,B"FUS9W-T<B`BV*K:K]BQVJ\B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3
M:&]W97)S($5A<FQY(@IM<V=S='(@(MBQVJ_8J-BGV+$@V++9B-BOV8?9AMJO
MV*?9A2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4X"FUS9VED(")3;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R("+8L=JOV*C8
MI]BQ(-BOVXS8L=F'V8;:K]BGV84B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(W.`IM<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@(MBYV879@B#8J-BQ
MV8$Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@R"FUS9VED(")3;F]W
M(&5Q=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R("+9A=BYV*?8K]F$(-BH
MV+'9@2#8K]BQ(-BBV*@Z("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M
M;VX@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3
M;VUA;&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV
M,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R("+8M-BYV+'9A]BG(-F(
M(-BBV8C8I]BRV8?8IR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y
M,C8*;7-G:60@(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(MBGV8;8
MJMBNV*?8J"#8K-F'V*H@V878L=BJV*@@V+/8I]BRVXPB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U.0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C0W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,38V
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"FUS
M9VED(")3;W5R8V4@861D<F5S<R(*;7-G<W1R("+8HMBOV+'8LR#8L]BQVH;8
MM-F%V8<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")3;W5T:"!!9G)I8V$B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@(E-O
M=71H($5U<F]P96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R(")3;W5T:"!%=7)O
M<&5A;B`H25-/+3@X-3DM,RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(E-O=71H
M($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O
M;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B
MV8;;C-F%(-JIV+'9AR#8K-F&V8C8J-N,(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E
M96X@861J86-E;G0@8V5L;',B"FUS9W-T<B`BV8'8I]BUV839A]F4(-BHVXS9
MAB#8L]F$V8C9A-F'V*?;C"#9A=BLV*?9B-BQ(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E
M='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`BV8'8
MI]BUV839A]F4(-BHVXS9AB#9A=BMV*K9B-BG(-F((-F$V*C9AR#8K]BQ(-BS
MV839B-F$(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#$U"FUS9VED
M(")3<&%C97(B"FUS9W-T<B`BV8'8I]BUV839A^*`C-JOV+#8I]BQ(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P
M"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(MF!V*?8M=F$V8<B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS
M9VED(")3<&%C:6YG(&%N9"!P861D:6YG(@IM<V=S='(@(MF!V*?8M=F$V8?B
M@(S:K]BPV*?8L=N,(-F((-BOV+'8LMJOV+#8I]BQVXPB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,0HC+"!F=7IZ>0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`BV8'8I]BUV839AR(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY.`IM<V=I9"`B4W!A;2(*
M;7-G<W1R("+9A]BQV++9AMBGV879AR(*"B,Z('-E<G9I8V5S+VME>6)O87)D
M+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T
M<B`BVJG8I]BQV*?:J=BJV+$@V*[8I]BU(-F(V*?8L=BO(-BTV*\B"@HC(",M
M(RTC+2,M(R`@9F%?25(N<&\@*%1U<F)A(#$N,BXR*2`@(RTC+2,M(RTC"B,@
M;7-G:60@(E-E87)C:"!297-U;'1S(@HC(&US9W-T<B`BV8;8JMBGVXS8K"#8
MK-BSV*K8K-F((@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S='(@(MBJ
MV8+8L]N,V84@V+/9A-F(V80B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI="!C;VQU;6XB
M"FUS9W-T<B`BV*K9@MBSVXS9A2#8L]BJV8C9AB(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@(E-P
M;&ET(')O=R(*;7-G<W1R("+8JMF"V+/;C-F%(-BSV+?8L2(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV,0IM<V=I9"`B4W!O<G1S(@IM<V=S='(@(MF(
MV+'8LMBTVXPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*(RP@9G5Z>GD*;7-G:60@(E-R:2!,
M86YK82(*;7-G<W1R("+8K-F%V+D@V+38K]F&(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C<S(&QI8B]";&]C:R]M971A<BYP:'`Z-S0*;7-G
M:60@(E-T86YD87)D(@IM<V=S='(@(MBGV+/8JMBGV8;8K]BGV+'8KR(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM
M<V=S='(@(MBSV*K8I]BQV8<B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-3DV(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#D*;7-G:60@(E-T
M87)T('EE87(B"FUS9W-T<B`BV+/8I]F$(-BTV+'9B-BY(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@(E-T871E(&]R
M(%!R;W9I;F-E(@IM<V=S='(@(MF(V+;8N=N,V*H@V*W9B-BRV8?B@(S9A]BG
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G
M:60@(E-T871U<R(*;7-G<W1R("+9B-BVV+G;C-BJXH",(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-0IM<V=I9"`B4W1O<F%G92!F;W)M870B
M"FUS9W-T<B`BV8+8I]F$V*@@V+#8KMN,V+'9AR#8L]BGV++;C"(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<R"FUS9VED(")3=')E
M970@061D<F5S<R(*;7-G<W1R("+8HMBOV+'8LR#8KMN,V*?8J-BGV88B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q"FUS
M9VED(")3=')I:V5T:')O=6=H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$R,S,*;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@
M(MF!V8?8L=BSV*H@V+'8M-BJV8<B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.#<S"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G<W1R
M("+8M-N,V8C9AR!;0U-372(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@(E-U(@IM<V=S='(@(MN,VJG8M-F&
MV*C9AR(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS-PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U
M;F0N(@IM<V=S='(@(B#8LMN,V+'8M-BGV*[9AR`G)7,G(-F^VXS8K]BG(-F&
MV+38KRXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N
M<&AP.C<S"FUS9VED(")3=6)J96-T(@IM<V=S='(@(MBYV8;9B-BGV88B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(@9G)A;65W;W)K+T9O<FTO
M1F]R;2]296YD97)E<BYP:'`Z,S$W"FUS9VED(")3=6)M:70B"FUS9W-T<B`B
MV*?8L=BSV*?9A"(*"B,Z('-I9VYU<"YP:'`Z-#D*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"!<(B5S
M7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@;&]G(&EN('5N=&EL('EO
M=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B(@HB
MV*K9@MBGV+;8I]N,(-BGV+;8I]F!V8<@V+38K]F&("<E<R<@V*C9AR#8L]BG
MV878I]F&V8<@V*?8L=BGV*;9AR#8M-BO+B#8JMBG(-F'V8;:K]BGV87;C"#:
MJ=F'(-BJV8+8I]BVV*?;C"#8M-F%V*<@V*K8H]N,VXS8KR`B"B+9AMJOV+'8
MK]BO(-F&V87;C.*`C-BJV8C8I]F&VXS8KR#8J-F'(-BSV*?9A=BGV8;9AR#9
MB-BGV+'8KR#8M-F(VXS8KR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R("+8
MLMN,V+'9AMF(VXS8LR(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#0*(SH@
M9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O
M<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R("+9A=F(V8'9
MD=F"VXS9D=BJ(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E
M(#,I("`C+2,M(RTC+2,*(R`*(SH@861M:6XO=7-E<BYP:'`Z.#4*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S
M7"(@=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B)R5S)R#8J-BG(-F%V8C9@=F1
MV8+;C-F1V*H@V*C9AR#8L]BGV878I]F&V8<@V*?8MMBGV8'9AR#8M-BO(@H*
M(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC
M+2,*(R`*(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R
M(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(B#8K]BGV*_9A]F4
M(-JIV*?8L=BHV+$@)R5S)]BHV*<@V879B-F!V9'9@MN,V9'8JB#8I]BR(-BS
MV*?9A=BGV8;9AR#9OMBGVJD@V+38KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD
M:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N(@IM<V=S
M='(@(EPB)7-<(B#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@V*W8L-F!(-BTV*\B
M"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC
M+2,M(PHC(`HC.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M
M('1H92!S>7-T96TN(@IM<V=S='(@(B<E<R<@V*C8IR#9A=F(V8'9D=F"VXS9
MD=BJ(-BGV+(@V+/8I]F%V*?9AMF'(-F^V*?:J2#8M-BO(@H*(R`C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY
M(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E
M<RXB"FUS9W-T<B`B(@HBV;[;C-JIV+'8J-F&V*_;C"#8J-BG(-F%V8C9@=F1
MV8+;C-F1V*H@V*C8I]BRVJ_8L=BOV*?9AMBOV8<@V+38KRX@V*C8L=BGVXP@
MV878M-BGV8?8K]F'(-BJV+K;C-N,V+'8I]BJ(-F%V*S8K]BOV*?9DB#8HMF&
MV+'8IR#8J-BGV+$@V8;9A=BGVXS;C-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E
M;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS
M9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(MF^VXS:J=BQV*C9AMBOVXP@V;[8M-BJVXS8J-BGV88@V*C8
MIR#9A=F(V8'9D=F"VXS9D=BJ(-BMV8'8N"#8M-BO(@H*(R`C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I
M;&4@)7,N(@IM<V=S='(@(MF^V+'9B-F&V*_9AR#9OMBTV*K;C-BHV*?9AB#9
MOMN,VJG8L=BHV8;8K]N,("5S(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8K=F!
MV+@@V+38KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S
M*2`@(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@7"(E
M<UPB(@IM<V=S='(@(B<E<R<@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BHV8<@
MV+'9B-BR(-BTV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R
M9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`B)7,@V*C8IR#9
MA=F(V8'9D=F"VXS9D=BJ(-F&V8C8M-BJV8<@V+38KR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#0*(RP@9G5Z>GD*;7-G:60@(E-U9&%N(@IM<V=S='(@(MBBV8'8JMBGV*C;
MC"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-38*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`BV*[9A-BGV+79AR(*
M"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV-0IM<V=I9"`B4W5N(%)I<V4B
M"FUS9W-T<B`BV+?9A-F(V+D@V*+9@=BJV*?8J"(*"B,Z(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*;7-G<W1R("+8NMBQV8C8
MJ"#8HMF!V*K8I]BH(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-3D*;7-G:60@(E-U;FYY(@IM<V=S='(@(MBBV8'8JMBGV*C;
MC"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*;7-G:60@
M(E-U;G)I<V4B"FUS9W-T<B`BV+?9A-F(V+DB"@HC.B!L:6(O0FQO8VLO<W5N
M<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,38*;7-G:60@(E-U
M;G)I<V4O4W5N<V5T(@IM<V=S='(@(MBWV839B-BY+]BZV+'9B-BH(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-0IM<V=I9"`B4W5N<FES
M93H@(@IM<V=S='(@(MBWV839B-BY.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C$Y"FUS9VED(")3=6YS970B"FUS9W-T<B`BV+K8L=F(
MV*@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$X"FUS9VED
M(")3=6YS970Z("(*;7-G<W1R("+8NMBQV8C8J#H@(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S
M8W)I<'0B"FUS9W-T<B`BV*C8I]F$V*?9AMF(VXS8LR(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS-S@*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B
MV;[8M-BJVXS8J-BGV8;;C"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C$U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*(RP@9G5Z>GD*;7-G
M:60@(E-U<FEN86UE(@IM<V=S='(@(MF&V*?9A2#8KMBGV8;9B-BGV*_:K]N,
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S0*;7-G
M:60@(E-U<FYA;64B"FUS9W-T<B`BV8;8I]F%(-BNV*?9AMF(V*?8K]JOVXPB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA>65N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V"B,L(&9U>GIY
M"FUS9VED(")3>6YC(&QO9R!D96QE=&5D(@IM<V=S='(@(MBMV+#9@2#9AMBT
MV8C8KR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#(*;7-G:60@(E-Y
M;F--3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D
M<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B
M"FUS9W-T<B`BV*[8M]BGVXP@V8;8K=F(VXP@V*_8L2#9A=F(V*?8L=BO(-BL
MV+/8JMBLV8@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")3>7)I86X@07)A8B!2
M97!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV,`IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R(")4+5-T
M;W)M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8Q"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B
M5"U3=&]R;7,B"FUS9W-T<B`B5"U3=&]R;7,B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B5"U3
M=&]R;7,@16%R;'DB"FUS9W-T<B`BV+':K]BHV*?8L2#8LMF(V*_9A]F&VJ_8
MI]F%(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$V-@IM<V=I
M9"`B5%-6(&9I;&4B"FUS9W-T<B`BV;[8L=F(V8;8K]F'(%135B(*"B,Z(&9R
M86UE=V]R:R]522]522]486)L92YP:'`Z,3,T"FUS9VED(")486)L92(*;7-G
M<W1R("+8K-BOV8C9A"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B
M"FUS9W-T<B`BV*[8M=F(V+7;C-BGV*H@V*S8K]F(V80B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W"B,L(&9U>GIY"FUS
M9VED(")486)L92!3970B"FUS9W-T<B`BV*S8K]F(V80B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<R"FUS9VED
M(")486)L92!P<F]P97)T:65S(@IM<V=S='(@(MBNV+79B-BUVXS8I]BJ(-BL
MV*_9B-F$(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S0@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0HC+"!F=7IZ>0IM<V=I9"`B
M5&%I=V%N(@IM<V=S='(@(MBHV*?8L=BGV88B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC
M92!O9B!#:&EN82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4
M86II:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A
M;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B
M5&%R9V5T.B(*;7-G<W1R("+9A]BOV8$Z(@H*(SH@8V]N9FEG+VAO;VMS+G!H
M<"YD:7-T.CDY-B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@W"FUS9VED
M(")487-K<R(*;7-G<W1R("+9B-BXV*?;C-F!(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E1E;&5P:&]N92!.=6UB
M97(B"FUS9W-T<B`BV+39A=BGV+'9AR#8JMF$V8'9AB(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,CDP"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*
M;7-G<W1R("+8K]F%V*?;C"#8L]BGV+G8JB#8I]BNVXS8L3H@(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,30*;7-G:60@(E1E;7!E<F%T=7)E(@IM<V=S
M='(@(MBOV+'8K-F'(-BMV+'8I]BQV*HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C(S"FUS9VED(")496UP97)A='5R93H@(@IM<V=S='(@
M(MBOV+'8K-F'(-BMV+'8I]BQV*HZ("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR.3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1E
M;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T
M<B`B("@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(-BOV878IR(*"B,Z(&9R86UE
M=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-C@W"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G
M<W1R("(@V*?9A-JOV8C;C"`G)7,GV;[;C-BOV*<@V8;8M-BO(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T
M<F%T:6]N(@IM<V=S='(@(MBGV83:K]F(VXP@V+/8L=F^V+'8L]BJVXPB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$Q(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,S,S8*;7-G:60@(E1E>'0B"FUS9W-T<B`BV878JMF&(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-0IM<V=I9"`B5&5X="!/;FQY
M(@IM<V=S='(@(MF!V8+8MR#9A=BJV88B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L
M:6=N(@IM<V=S='(@(MBJV+'8I]BR(-F%V*K9AB(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B
M"FUS9W-T<B`BV*C8I]F$V*?;C"#9A=BJV88B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R
M("+9OMF&V*S8M-F&V*C9AR(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ
M"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R(")4:&%I("A425,M-C(P
M*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1H86EL86YD(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX.`IM<V=I9"`B5&AA;FL@
M>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+B(*;7-G<W1R("+8I]BR(-BTV878
MIR#8J-F'(-BNV*?8M]BQ(-BGV+/8JMF!V*?8K]F'(-BGV+(@V+/8I]F%V*?9
MAMF'(-F%V*K8M-JIV+';C-F%(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX,C`*;7-G:60@(E1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I
M;&%B;&4N(@IM<V=S='(@(MBHV+/8MR!&5%`@V8+8I]BHV80@V*_8L]BJV+'8
MLR#9AMN,V+/8JB(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,T
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A
M=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O0F]O:RYP:'`Z,3(Y,@HC
M+"!F=7IZ>0IM<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET
M:6%L:7IE9"XB"FUS9W-T<B`BV;[8L=F(V8;8K]F'(-BGV+'8L]BGV80@V+38
MK]F'(-F&V87;C.*`C-BJV8C8I]F&V*\@V*W9@=BX(-BTV8C8KR(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA
M;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R
M("+9AMJOV8?8K]BGV+';C#HZ(-JIV838I]BS(-BHV*<@V879B-F!V9'9@MN,
MV9'8JB#8J-BGV+$@V8;8M-BO(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R
M<&EC:V5R+G!H<#HR.0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C
M;&]S960N($5X:71I;F<N(@IM<V=S='(@(MF^V8;8K-BQV8?9E"#:K]BRVXS9
MAMF'XH",V8?8IR#8J-BSV*K9AR#8M-BO+B#8KMBQV8C8K"(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C$Q(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C4R
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C8T(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O
M<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@
M8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM
M<V=S='(@(B(*(MBSV+'9OMBQV+/8JB#8J-BGVXS8KR#;C-JI(-F^V+38JMN,
MV*C8I]F&(-F%V*S9B-BRV8?8IR#8L=BGV(P@(-BOV+$@V+79B-BQV*H@V*K9
MA=BGVXS9A"#8M-F%V*<@V*C9AR#8I]BSV*K9@=BGV*_9AR#8I]BR(-F%V*S9
MB-BRV8?8I]B,("(*(MF^VXS:J=BQV*C9AMBOVXP@VJG9AMBO+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*
M;7-G:60@(E1H92!B;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(MBJV8;9A]BG
M(-BSV878JB#9OMBGVXS;C-F&(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT86-T
M($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W
M87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`BV+39
MA=BGV+'9AR!)1"#8JMF%V*?8LR#9A=BTV*[8M2#9AMBTV*_9AR#8I]BSV*K8
MC"#8I]N,V88@V+39A=BGV+'9AR#8K]BQ(-BOV*?8K]JOV*?9AB#;C-BGV8'8
MJB#9AMBTV*\B"@HC(`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z-3$*;7-G:60@(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L
M;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(MBJV878
MI]BS("`E<R#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@V*C9AR#:J=BJV*?8J-J&
MV8<@V*+8K]BQV+,@V+39A=BG(-BGV+;8I]F!V8<@V+38KR(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-CD*;7-G:60@(B(*(E1H92!D
M971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E
M<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(MN,VJD@V*C9A-F(
MVJD@V*?9A=BVV*?;C"!01U`@V*C8L=BGVXP@V*C8I]BRV*C;C-F&VXP@VXS:
MJ2#9OMN,V+K8I]F%(-BGV878MMBGV*$@V+38K]F'(-F%V8C8L=BO(-F&VXS8
MI]BR(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI
M<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R
M(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@(DE$(-F!
MV8?8L=BSV*H@V*K9B-BRVXS8N=N,(-F%V+38KMBU(-F&V+38K]F'(-BGV+/8
MJB#9B"#;C-BG(-BOV+$@V*_8I]BOVJ_8I]F&(-F%V8C8K-F(V*\@V8;;C-BS
MV*HB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@
M<W!E8VEF:65D+B(*;7-G<W1R("+9@=F'V+'8L]BJ(-BJV8C8LMN,V+G;C"#9
MA=BTV*[8M2#9AMBTV*_9AR#8I]BSV*HB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0N<&AP.C$Q,PIM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@
M<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`BV878
MM-BNV+79A^*`C.*`C-F'V*?;C"#8L=F%V++8J-F&V*_;C"#9AMN,V*?8LMF%
MV8;8KR#;C-JI(-BGV+'8JMBUV*?9A"#8I]F%V88@V8C8J"#9A=N,XH",V*C8
MI]BTV8;8KR(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<U(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$S"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB
M"FUS9W-T<B`BV;[8L=F(V8;8K]F'("5S(-BHV*?;C-BO(-BOV*?8L=BGVXP@
MV*K9AMBXVXS9A2`E<R#8J-BGV+38KR(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,38X(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`S"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN
M('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(MF^V+'9B-F&V*_9AR`E<R#8
MJ-BGVXS8KR#8K=BGV8C;C"#8JMF&V+C;C-F%V*?8JB`E<R#8J-BGV+38KR(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(Q.0IM<V=I9"`B5&AE
M(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N(@IM<V=S='(@
M(MF^V+'9B-F&V*_9AR#8J-BQ(-BQV8C;C"#8KMF(V*_8M"#9AMF%VXSB@(S8
MJMF(V*?9AMBO(-BQV8C9AMF(V+38JB#8M-F(V*\B"@HC.B!F<F%M97=O<FLO
M1&%T82]$871A+G!H<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N
M;R!D871A+B(*;7-G<W1R("+9OMBQV8C9AMBOV8<@V*W8I]F(VXP@V*_8I]BO
MV8?B@(S8I^*`C-N,VXP@V8;;C-BSV*H@(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN
M9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S
M<V%G92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO
M9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%
M>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N
M)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@
M(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@
M86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y
M<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G
M;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@86YD(&YE
M960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE
M87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@
M9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R("(B"B+9A=BO(-BJV878I]F%
M(-BUV8'8K=F'(-BHV*<@244@V878M-JIV80@V*_8I]BQV*\@V8@@V*?;C-F&
M(-BGV+(@V878M-JIV838I]BJ(-F%V+'9B-BQVJ_8L2#9A=N,XH",V*C8I]BT
MV*\N(-BGVJ_8L2#9A]F&V8C8LB`B"B+9A=N,XH",V*[9B-BGV8?;C-BO(-BM
MV*?9A-BJ(-F(VXS8L=BGVXS8M-JOV+$@V*K9A=BGV84@V+79@=BMV8<@V+'8
MIR#8I]F%V*K8K=BGV88@VJG9AMN,V*_8C"#9A-BWV8'8I]F+(-JIV83;C-BO
M(-BJV*/;C-N,V*\@V+'8IR#9@=BTV*?8L2`B"B+8K]F'VXS8KR`B"@HC(`HC
M.B!S97)V:6-E<R]P<F5F<RYP:'`Z.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R
M("+9A]F(VXS9D=BJ(%PB)7-<(B#8K=BPV8$@V+38K]F'(-BGV+/8JB(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S8*;7-G:60@(E1H92!L969T+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(MBJ
MV8;9A]BG(-BSV878JB#:AMF^(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N
M=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C
M;&%S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN
M<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@;65S<V%G92!S
M96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<(B5S7"(@:&%S(&)E96X@
M9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@
M;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N(@IM<V=S='(@
M(B(*(MF^VXS8NMBGV84@V8'8L=BSV*K8I]BOV8<@V+38K]F'(-BQV8C;C"`E
M<R#8J-F'("5S(-BHV*<@V879B-BVV8C8N2!<(B5S7"(@V8;9A=BGVXS8M"#8
MK]BGV*_9AR#8M-BOV8<@V*?8L]BJ+EQN(@HBV*K8MMF%VXS9AMN,(-BHV+'8
MI]N,(-BNV8C8I]F&V*_9AR#8M-BOV88@V8@@VXS8IR#8K]BQVJD@V*+9AB#9
MB-BLV8C8KR#9AMBOV*?8L=BO(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@W-PIM<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T
M;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S='(@(MF&V*?9A=N,(-JIV8<@V*C9
MAR#9A]F&VJ_8I]F%(-F^VXS9B-F&V*_8K]F'VXP@V*C9AR#8M=F!V*W9AR#8
MI]N,V*S8I]BO(-F&V*?9A=F'(-BGV+/8JMF!V*?8K]F'(-F%VXSB@(S8M-F(
MV*\B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#$*;7-G:60@
M(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS9W-T
M<B`BV*K8N=BOV*?8KR#9@=N,V838K^*`C-F'V*<@V*C8I]N,V*\@VXS:J2#8
MN=BOV*\@V*C8I]BTV*\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C$R,S$*;7-G:60@(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U
M:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,CDP"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L
M9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@
M(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"B+8I]F(V839
MB-N,V*H@7"(E<UPB(-F&V87;C.*`C-BJV8C8I]F&V*\@V*W9@=BX(-JOV+'8
MK]BO(-BRVXS8L=BG(-F%V8+8K]BGV+$@V*_8I]BOV8<@V*+9AB#8I]BR(-BM
MV*\@V878K-BGV+(@V*C;C-BTV*K8L2#8I]BSV*HB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]D96(N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<G!M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]W96)C<'`N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A
M('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(@IM<V=S
M='(@(B(*(MBHV+'9AMBGV879A^*`C-BGXH",VXS;C"#:J=F'(-BHV+'8I]N,
M(-F%V+38I]F'V*_9AR#8I]N,V88@V8;9B-BY(-BOV*?8K]F'("@E<RD@V8+8
MJ-F$V*?9BR#9A=F(V+'8KR#8I]BSV*K9@=BGV*_9AR#9@MBQV*?8L2#9A=N,
MXH",VJ_8L=F!V*K8C"#8K]BQ("(*(MBSV*?9A=BGV8;9AR#9A=F(V*S9B-BO
M(-F&VXS8L]BJ(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#4T
M"B,L(&9U>GIY"FUS9VED(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@
M;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(MBLV*_8IR#:J=F&V8;8
MK]F'(-BHV*?;C-BO(-N,VJD@V8;9B-N,V+/9AR#8J-BGV+38KR(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*
M;7-G:60@(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@
M(MBJV8;9A]BG(-BSV878JB#8L=BGV+/8JB#9B"#:AMF^(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I
M9"`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(MBJV8;9A]BG
M(-BSV878JB#8L=BGV+/8JB(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C0T-@IM<V=I9"`B5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG
M;&4@8VAA<F%C=&5R+B(*;7-G<W1R("+8K-BOV*<@VJG9AMF&V*_9AR#8J-BG
MVXS8KR#;C-JI(-F&V8C;C-BSV8<@V*C8I]BTV*\B"@HC(",M(RTC+2,M(R`@
M8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!S97)V
M:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R
M("+:J=BGV+'8L]BGV+(@7"(E<UPB(-BMV+#9@2#8M-BOV8<@V*?8L]BJ(@H*
M(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC
M+2,*(R`*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V
M960N(@IM<V=S='(@(MJIV*?8L=BSV*?8LB!<(B5S7"(@V*W9@=BX(-BTV*_9
MAR#8I]BSV*HB"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@
M,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@
M8F5E;B!R96UO=F5D+B(*;7-G<W1R("+8K]BQV*[9B-BGV+/8JB#8I]F!V*K8
MJMBGV*T@V*W8L]BGV*@@V*C8L=BGVXP@)7,@V*W8L-F!(-BTV*_9AR#8I]BS
MV*HB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HS,S`*
M;7-G:60@(E1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+B(*;7-G
M<W1R("+8L=BOVXS9@2#9A=BTV*[8M2#8M-BOV8<@V8C8K-F(V*\@V8;8K]BG
MV+'8KR(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3<W"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!T96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E
M<R!N;W0@97AI<W0N(@IM<V=S='(@(MF^V+'9B-F&V*_9AR#9A=F(V8+8JMN,
M("!<(B5S7"+9A=F(V*S9B-BO(-F&VXS8L]BJ(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S,Q,0IM<V=I9"`B5&AE('1E>'0@>6]U(&5N=&5R960@
M9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<Y"FUS9VED(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL
M>2(*;7-G<W1R("+8JMF&V8?8IR#8L]F%V*H@V*C8I]F$V*<@V8@@V;[8I]N,
MVXS9AB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@
M(MBJV8;9A]BG(-BSV878JB#8J-BGV838IR(*"B,Z(&9R86UE=V]R:R]$871A
M+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO
M<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@(MBOV*?8K]F'
MV90@V*?8L=BSV*?9A"#8M-BOV8<@V*?8LB#:K]BGV84@V8+8J-F$VXP@V*?8
MLB#8K]BSV*H@V+'9@=BJV8<@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+T1A=&$O
M1&%T82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z
M,3<R"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V
M960N(@IM<V=S='(@(MF^V+'9B-F&V*_9AR#8I]BQV+/8I]F$(-BTV*_9AR#9
MAMF%VXSB@(S8JMF(V*?9AMBO(-BMV8'8N"#8M-F(V*\B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#8@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C4V"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,34@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q.0IM<V=I9"`B5&AE('=E
M871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(MBH
MV839B-JI('=E871H97(N8V]M(-F"V*?8J-F$(-BOV+/8JMBQV+,@V8;;C-BS
MV*HB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F
M;W5N9"XB"FUS9W-T<B`BV+38I]BNV8<@V*K9A2`G)7,G(-N,V*?9@=BJ(-F&
MV+38KR(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3<X"FUS
M9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@
M(MJOV++;C-F&V8?B@(S8I^*`C.*`C-N,VXP@V*_8L2#8K]BSV*K8L=BS(-F&
MVXS8L]BJ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z
M,S0R"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES
M<&QA>65D(&EN;&EN92XB"FUS9W-T<B`BV*C8KMBTVXP@VJG9AR#8J-BJV8C8
MI]F&V*\@V*C8L=BNV+<@V8;9A=BGVXS8M"#8K]BGV*_9AR#8M-F(V*\@V879
MB-BLV8C8KR#9AMN,V+/8JB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$T,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M
M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E
M9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L97-S('1H86X@
M)7,N(@IM<V=S='(@(B(*(MF&V8C;C-BSV8?B@(S9A]BGVXP@V++;C-BGV*_;
MC"#8K]BQ(-BGVXS9AB#9@=N,V838KR#9@MBQV*?8L2#8K]BGV+'8KRX@V+39
MA=BG("5S(-F&V8C;C-BSV8<@V8C8I]BQV*\@VJG8L=BOV8?B@(S8I^*`C-N,
MV*\@V*_8L2#8K=BGV83;C"#:J=F'("(*(MBTV878IR#8J-BGVXS8KR#:J=F%
MV*K8L2#8I]BR("5S(-F&V8C;C-BSV8<@V8C8I]BQV*\@VJG9AMN,V*\B"@HC
M(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M
M(PHC(`HC.B!S:6=N=7`N<&AP.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D
M9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`BV878M-JI
MV83;C"#8K]BQ(-BGV+;8I]F!V8<@VJG8L=BOV88@)R5S)R#8J-F'(-BSV*?9
MA=BGV8;9AR#8L=BN(-BOV*?8K]F'(-BGV+/8JCH@)7,B"@HC(",M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<
M(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`BV878M-JIV83;C"#8
MK]BQ(-F^V*?:J2#:J=BQV*_9AB#8K]BGV*_9A]F4(-JIV*?8L=BHV+$@)R5S
M)R#8I]BR(-BSV*?9A=BGV8;9AR#8L=BN(-BOV*?8K]F'(-BGV+/8JCH@(@H*
M(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC
M+2,*(R`*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<
M(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("+9A=BTVJG9A-N,(-BOV+$@
MV*W8L-F!("<E<R<@V*?8LB#8L]BGV878I]F&V8<@V+'8KB#8K]BGV*_9AR#8
MI]BSV*HZ("(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S
M*2`@(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A
M=&EN9R!<(B5S7"(Z("5S(@IM<V=S='(@(MF%V+3:J=F$VXP@V*_8L2#8J-BQ
MV8C8LMBQV+/8I]F&VXP@)R5S)R#8L=BN(-BOV*?8K]F'(-BGV+/8JCH@)7,B
M"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F
M:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R("+9A=BT
MVJG9A-N,(-BOV+$@V*?8L=BSV*?9A"#9OMBQV8C9AMBOV8<@V+'8KB#8K]BG
MV*_9AR#8I]BSV*HZ("5S(-BGV+'8L]BGV80@V8;8M-BO(@H*(SH@9G)A;65W
M;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO
M860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB86QL
M;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@(B(*(MF%V+3:J=F$VXP@
MV*_8L2#8I]BQV+/8I]F$(-F^V+'9B-F&V*_9AR#8L=BN(-BOV*?8K]F'(-BG
MV+/8JCH@V*?9AMBOV*?8LMF'("5S(-BHVXS8M-BJV+$@V*?8LB#8K=BO(-F%
MV*S8I]BR(-BHV8C8K]F'(-BGV+/8JB`H("5D("(*(MBHV*?;C-BJ*2XB"@HC
M.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.3$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F
M:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E
M9"XB"FUS9W-T<B`B(@HBV878M-JIV83;C"#8K]BQ(-BGV+'8L]BGV80@V;[8
ML=F(V8;8K]F'(-F(V*S9B-BO(-BOV*?8M-BJV8<@V*?8L]BJ.B`@)7,@V*C9
MAR#8M=F(V+'8JB#8JMJIV8?B@(S8I^*`C-N,VXP@V*?8L=BSV*?9A"#8M-BO
MV8<@V*?8L]BJ("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y
M:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(MBNV+?8I]N,VXP@V*_8
ML2#9AMF%V*?;C-BT(-BGVXS9AB#8J-BNV+0@V;[;C-BZV*?9A2#8L=BN(-BO
MV*?8K]F'(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HS.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I
M;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`BV*[8M]BGVXS;C"#8K]BQ
M(-BOV+'9B-F&XH",V*C8L=BO(-JIV+'8K]F&(-BOV*?8K]F'(-BJV878I]BS
M(-BQV*X@V*_8I]BOV8<@V*?8L]BJ(@H*(R`*(SH@9G)A;65W;W)K+T1A=&$O
M1&%T82]I;6,N<&AP.C,Q"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`BV*[8M]BGVXS;
MC"#8K]BQ(-BOV+'9B-F&XH",V*C8L=BO(-JIV+'8K]F&(-BOV*?8K]F'V90@
MV*K9@MF(VXS9A2#8L=BN(-BOV*?8K]F'(-BGV+/8JB(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z.#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O
M<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T
M(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("(B"B+8KMBWV*?;
MC-N,(-BOV+$@V;[;C-JIV+'8J-F&V*_;C"#9@=BQV84@V+'8KB#8K]BGV*_9
MAR#8I]BSV*HN(-BTV*?;C-BO(-F!VXS9A-BO(-F%V8C8L=BO(-F&VXS8I]BR
MVXP@V+'8IR#8K-BG(-BGV8;8K]BGV*[8JMF'XH",V*?B@(S;C-BO(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S
M<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y
M(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B+8KMBWV*?;C-N,(-BOV+$@V*?8
MK-BQV*<@VJG8L=BOV88@V+G9A=F$VXS8I]BJ(-F%V+38KMBU(-BTV*_9A]F4
M(-JIV*K8I]BHVH;9AR#8HMBOV+'8LR#8L=BN(-BOV*?8K]F'(-BGV+/8JBX@
MV838M]F!V*?9BR#8K]F(V*C8I]BQV8<@V+/8N=N,("(*(MJIV8;;C-BO(@H*
M(R`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T
M:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*
M;7-G<W1R("+8KMBWV*?;C-N,(-BOV+$@V*C8L=F(V++8L=BSV*?9AMN,(-BL
MV++8IMN,V*?8JB#8JMF%V*?8LR#8L=BN(-BOV*?8K]F'(-BGV+/8JBX@V838
MM]F!V*?9BR#8K]F(V*C8I]BQV8<@V+/8N=N,(-JIV8;;C-BO(@H*(R`*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C(*;7-G
M:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I
M8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@
M(MBNV+?8I]N,VXP@V*_8L2#8J-BQV8C8LMBQV+/8I]F&VXP@V8'9A]BQV+/8
MJB#8JMF(V++;C-BYVXP@V+'8KB#8K]BGV*_9AR#8I]BSV*HN(-F$V+?9@=BG
MV8L@V*_9B-BHV*?8L=F'(-BSV+G;C"#:J=F&VXS8KR(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T.`IM<V=I9"`B5&AI<R!)
M34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB
M"FUS9W-T<B`B(-JIV*?8L=BSV*?8LB!)34%0V;[9B-BTV8?B@(S9A]BGVXP@
MV878M-BJV+':J2#8L=BG(-F^V+38JMN,V*C8I]F&VXP@V8;9A=N,XH",VJG9
MAMBO(@H*(R`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI
M9"!R87(@87)C:&EV92XB"FUS9W-T<B`B(-BHV8<@V8;8N-BQ(-F&V87;C.*`
MC-BQV+/8KR#:J=F'(-BBV+'8M-N,V8@@<F%R(-F%V+G8JMBHV+';C"#8J-BG
MV+38KR(*"B,@"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L
M:60@>FEP(&9I;&4N(@IM<V=S='(@(B#8J-F'(-F&V+C8L2#9AMF%VXSB@(S8
ML=BSV*\@VJG9AR#9OMBQV8C9AMBOV8<@>FEP(-F%V+G8JMBHV+';C"#8J-BG
MV+38KR(*"B,@"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q-#4*;7-G
M:60@(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M
M8F5R+B(*;7-G<W1R("+8J-F'(-F&V+C8L2#9AMF%VXSB@(S8L=BSV*\@VJG9
MAR#8M-F%V*?8L=F'(-JIV*?8L=BJ(-F%V+G8JMBHV+';C"#8J-BGV+38KR(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L
M:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HQ,S0*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI
M("(*(F=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q
M-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S
M<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M
M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M
M='`N<&AP.C@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN
M9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)
M=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET
M(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)
M=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HY-S@@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3`U-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#@V(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,34*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3$X,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C4V"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#4@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,Y.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-34W(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,SD*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3DU."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`U"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,CD@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`W.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,30Y
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,C$*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C0Q,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4T
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-3<@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@R.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,3,W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,#8*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S@Q-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M.#(R"FUS9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R("+8
MI]N,V88@V8';C-F$V*\@V879B-BQV*\@V8;;C-BGV+(@V*?8L]BJ(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V-0IM<V=I9"`B5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R("+8I]N,V88@
MV8';C-F$V*\@V879A=JIV88@V*?8L]BJ(-BTV*?9A=F$(-BGV+G8K]BGV*\@
MV+78K=N,V*T@V*C8I]BTV*\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-#$X"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M
M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R("+8I]N,V88@V8';C-F$V*\@
MV879A=JIV88@V*?8L]BJ(-BTV*?9A=F$(-BGV+G8K]BGV*\@V8@@V8C;C-BQ
MVJ_9B-F$(-BHV*?8M-BO(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3`Y-`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L
M('9A;'5E<RXB"FUS9W-T<B`BV*?;C-F&(-F!VXS9A-BO(-F%V87:J=F&(-BG
MV+/8JB#8M-BGV879A"#9A=F"V*?8K]N,V+$@V8?8M-BJ(-F'V+38JMN,(-BH
MV*?8M-BO(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$R,PIM<V=I
M9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A
M=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T<B`B(@HBV*?;C-F&(-F!VXS9
MA-BO(-BHV*?;C-BO(-BMV*?9B-N,(-JIV*?9A=BG(-F((-N,V*<@V8'9A]BQ
MV+/8JMN,(-BGV+(@V*?8N=BOV*?8KR#8M=BMVXS8K2#8K-BOV*<@V+38K]F'
M(-BHV*<@V8;9B-N,V+/9AR#8KMBGV83;C"#8J-BGV+38KR(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.CDX.0IM<V=I9"`B5&AI<R!F:65L9"!M=7-T
M(&)E(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R("+8I]N,V88@V8';C-F$V*\@
MV*C8I]N,V*\@VXS:J2#8N=BOV*\@V878N=BJV*C8L2#8J-BGV+38KR(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,S8*;7-G:60@(B(*(E1H:7,@
M9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE
M>"!F;W)M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z-38Q"FUS9VED(")4:&ES
M(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@(B(*
M"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M
M(RTC"B,@"B,Z('1E;7!L871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@(MBGVXS9AB`E<R#9
MA=N,XH",V*C8I]BTV*\B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C0U.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@
M1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL
M;"!N965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H
M92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@
M96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DQ"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A
M(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G
M<W1R("(B"B+8I]N,V88@V;[;C-BZV*?9A2#8J-BG(-F%V*S9A=F(V+G9AR#:
MJ=BGV+'8I]JIV*K8L2`E<R#9AMF(V+38JMF'(-BTV*_9AR#8I]BSV*H@VJG9
MAR#8J-BG(-F%V*S9A=F(V+G9AR#:J=BGV+'8I]JIV*K8L2#8M-F%V*<@V878
MJMF!V*?9B-BJ("(*(MBGV+/8JB(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE
M87-T(&]N92XB"FUS9W-T<B`BV*?;C-F&(-BYV*_8KR#8K=BOV*?9@MF$(-BH
MV*?;C-BO(-N,VJD@V*C8I]BTV*\B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T
M('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R("+8I]N,
MV88@VJG8I]BQV+/8I]BR(-F^V+'9B-F&V*_9A^*`C-F'V*?;C"!Z:7`@V8@@
M9WII<"#8L=BG(-BHV*?8LB#9AMF%VXSB@(S:J=F&V*\B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$X.0IM<V=I9"`B5&AI<R!S
M>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R("+8I]N,
MV88@V+/8I]F%V*?9AMF'(-BOV+$@V*W8I]F$(-BMV*?8MMBQ(-BZVXS8L2#9
M@=BYV*?9A"#8I]BSV*HB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*
M;7-G<W1R("+8I]N,V88@V879@MBOV*?8L2#8J-BGVXS8KR#8N=BOV*\@V*C8
MI]BTV*\B"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U
M"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P
M=&EO;G,@=VEN9&]W(@IM<V=S='(@(MBGVXS9AB#9OMF&V*S8L=F'(-BHV*?;
MC-BO(-BGV+(@V;[9AMBLV+'9A]F4(-JOV++;C-F&V8?B@(SB@(S9A]BG(-F!
MV+'8I]BNV8C8I]F&VXP@V+39B-BO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C0*;7-G:60@(E1H=6YD97(B"FUS9W-T<B`B
MV+'8N=BO(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S-`IM<V=I
M9"`B5&EC:V5T<R(*;7-G<W1R("+8J-F$VXS8M]F'V*<B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-#(X('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(U-0IM<V=I9"`B5&EM92(*;7-G<W1R("+8LMF%V*?9AB(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#8*;7-G:60@(E1I;64@5')A8VMI
M;F<B"FUS9W-T<B`BV+'8K]N,V*?8J-N,(-BRV878I]F&(@H*(SH@;&EB+T)L
M;V-K+W1I;64N<&AP.C$W"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R("+9
M@MBGV838J"#8LMF%V*?9AB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(U,SD*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@(B#8I]F&V*K8
MKMBGV*@@V++9A=BGV88@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M
M3&5S=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I
M9"`B5&ET;&4B"FUS9W-T<B`BV+G9AMF(V*?9AB(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT
M;V]L=&EP*3HB"FUS9W-T<B`BV+G9AMF(V*?9AB`HV+'8I]F'V8;9A=BGVXP@
MV*+9AMN,*3HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R("+8J-F'(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U-`IM<V=I9"`B(@HB
M5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R
M;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN
M9RXB"FUS9W-T<B`B(@HBV*C8L=BGVXP@V*?9AMBJV*[8I]BH(-J&V8;8KR#9
M@=N,V838K]B,(-BOVJG9A=F'($-T<FP@V+'9B-N,("A00RD@VXS8IR!#;VUM
M86YD(-BQV8C;C"`H36%C*2#8L=BG(-BOV+$@V878K]BJ(-JIV83;C-JI("(*
M(MJIV+'8K]F&(-F&VJ_9A]BOV*?8L=N,V*\B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S$Q"FUS9VED(")4;V1A>2(*;7-G<W1R("+8I]F%
MV+'9B-BR(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#D*(RP@9G5Z>GD*;7-G:60@(E1O9V\B"FUS9W-T<B`B
MV*C9AR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,PIM<V=I9"`B
M5&]M;W)R;W<B"FUS9W-T<B`BV8'8L=BOV*<B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"B,L
M(&9U>GIY"FUS9VED(")4;VYG82(*;7-G<W1R("+8I]F%V+'9B-BR(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<W
M"FUS9VED(")4;W`B"FUS9W-T<B`BV*C8I]F$V*<B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A
M;64@*%]T;W`I(@IM<V=S='(@(MJ&V*?8L=J&V8C8J"#8J-BGV838IR`HV*C8
MI]F$V*<I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S"FUS9VED(")4
M<F%N<VQA=&EO;G,B"FUS9W-T<B`BV*K8L=BLV879A^*`C-F'V*<B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W.3`*;7-G:60@(E1R
M=64@;W(@9F%L<V4B"FUS9W-T<B`BV*_8L=BSV*H@V8@@VXS8IR#9AMBGV*_8
ML=BSV*HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R("+8L]F'(-BTV8;8J-F'(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.3(*;7-G:60@(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@IM
M<V=S='(@(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM
M<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*
M;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-,22]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC
M93H@(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#8KMF(V*\@V+'8IR#8JMBGVXS9
MOB#:J=F&VXS8KSHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C8Y"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS9W-T<B`BV+38I]BNV+4@52Y6
M+B`Z("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HR-#D@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@(E523"(*;7-G
M<W1R(")54DPB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4T,0IM<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP="!D96QI
M=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3<*;7-G:60@(E523#HB"FUS
M9W-T<B`B55),.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5G86YD82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$R"B,L(&9U>GIY"FUS9VED(")5:W)A:6YE
M(@IM<V=S='(@(MBRVXS8L=BNV+?B@(S8K]BGV+$B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HT,3(*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@
M5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`BV*?9A=JIV*?9AB#8K]BSV*K8L=BS
MVXP@V*C9AR#8M-BGV*[9AR!61E,@V8;;C-BSV*HB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@
M97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S
M='(@(MBGV87:J=BGV88@V*?8MMBGV8'9AR#:J=BQV*_9AB#8I]BWV838I]BY
MV*?8JB#8I]BVV*?9@=N,(-JIV*?8L=BHV+$@V*C9AR#9A]F&VJ_8I]F%(-BK
MV*C8JB#9AMBGV84@V8;;C-BSV*HB"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU
M;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C,X.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V878K-F(V++9A]BG(-BQV*<@V*C8
ML=BGVXP@V;[8L=F(V8;8K]F'(%PB)7-<(B#8JMBZVXS;C-BQ(-BOV*?8KR(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,X-2!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N
M(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F%V*S9B-BRV8?8IR#8L=BG
M(-BHV+'8I]N,(-F^V+'9B-F&V*_9AR`E<R\E<R!61E,@(-BJV+K;C-N,V+$@
MV*_8I]BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I
M("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW
M-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E
M<RXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V*_8L2`E<R#8JMBZVXS;
MC-BQ(-BOV*?8KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D
M92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,C,R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M8VAE8VL@9FEL92!S:7IE(&]F(%PB)7-<(BXB"FUS9W-T<B`BV8;9A=N,XH",
MV*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&4R!<(B5S7"(@V+'8IR#8J-BGV+(@
MV8;9A=F(V*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@
M,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HV.#@@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ,#$V"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HX,S0*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E
M<R\E<UPB+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBO
MV8<@5D93("5S+R5S(-BQV*<@V*K8NMN,VXS8L2#9AMBGV84@V*_8I]BO(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C0S-0IM<V=I9"`B56YA
M8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`BV8;9A=N,
MXH",V*K9B-BGV88@V*C9AR#:J=BGV+'8L]BGV+(@4U%,V878JMBUV80@V+38
MKR(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,Y"FUS9VED(")5
M;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`BV8;9A=N,XH",
MV*K9B-BGV88@V*C8IR!34TP@V878JMBUV80@V+38KR(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(R-2!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$Y
M-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Q"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#D*;7-G:60@(E5N86)L92!T
M;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8
MI]BR(-F^V+'9B-F&V*_9AR!61E,@V+'9B-F&V8C8M-BJ(-BJV8?;C-F'(-F&
MV879B-BO(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-C4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T
M;W)Y(%PB)7-<(BXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V+38I]BN
MV8<@5D93(%PB)7-<(B#8L=BG(-BGVXS8K-BGV*\@V8;9A=F(V*\B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-30@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C(U.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,C4V"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O
M<GDN(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BTV*?8KMF'(%9&4R#8
ML=BG(-BGVXS8K-BGV*\@V8;9A=F(V*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N
M9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,3(T"FUS9VED(")5;F%B;&4@=&\@8W)E871E
M(%9&4R!F:6QE+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9
MAMBOV8<@5D93(-BQV*<@V*?;C-BLV*?8KR#9AMF%V8C8KR(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z,C@V"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@7"(E<UPB+B(*
M;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@5D93(%PB
M)7-<(B#8L=BG(-BJV+K;C-N,V+$@V8;8I]F%(-BOV*?8KR(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C(V-0IM<V=I9"`B56YA8FQE('1O(&-R
M96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BG
MV88@V;[8L=F(V8;8K]F'(-BNV*?9A-N,(%9&4R`@V*?;C-BLV*?8KR#9AMF%
MV8C8KR(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N<&AP
M.C<V"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HW
M.0IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B
MV8;9A=N,XH",V*K9B-BGV88@V*_8I]BOV8<@V+'8IR#8J-BGV+(@VJG8L=BO
M("(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C(T(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,CDX"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E
M;7!T>2XB"FUS9W-T<B`BV*W8L-F!(%PB)7-<(B#9A=F%VJG9AB#9AMN,V+/8
MJMB,(-BTV*?8KMF'(-BNV*?9A-N,(-F&VXS8L]BJ(@H*(R`C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@861M
M:6XO9W)O=7!S+G!H<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E
M<RXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@7"(E<UPB(-BQV*<@V*W8
ML-F!(-JIV+'8KSH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,S,Q(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,SDR"B,Z(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,3$@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C,S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(*;7-G
M<W1R("+8K=BPV8$@)7,@V879A=JIV88@V8;;C-BSV*K8C"#8M-BGV*[9AR#8
MKMBGV83;C"#9AMN,V+/8JB(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HS-#@@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,U
M,@IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R
M<VEV96QY+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8M-BGV*[9AR!6
M1E,@V+'8IR#8J-F'(-BUV8C8L=BJ(-BJV8@@V*_8L2#8JMF((-BMV+#9@2#9
MAMF%V8C8KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S
M*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C,S-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,S4@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C,T,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,S0T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN
M(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BTV*?8KMF'(%9&4R#8L=BG
M(-BMV+#9@2#9AMF%V8C8KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O
M("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z-#$W(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#(Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>3H@)7,N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BTV*?8KMF'
M(%9&4R#8L=BG(-BMV+#9@2#9AMF%V8C8KSH@)7,N(@H*(R`C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,#<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(MF&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR!61E,@7"(E<UPB(-BQ
MV*<@V*W8L-F!(-F&V879B-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN
M<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,S`S(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C@X
M"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ-C<@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C$X,`HC.B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,3@W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS
M.#,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,Y,0IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS9W-T<B`BV8;9A=N,
MXH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&4R#8L=BG(-BMV+#9@2#9AMF%
MV8C8KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@
M(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C0T
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9
MAB#9OMBQV8C9AMBOV8<@5D93(%PB)7-<(B#8L=BG(-BMV+#9@2#9AMF%V8C8
MKR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC
M+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#`V"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R
M<VEV96QY.B`E<RXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@5D93(-BQ
MV*<@V*C9AR#8M=F(V+'8JB#8JMF((-BOV+$@V*K9B"#8K=BPV8$@V8;9A=F(
MV*\Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#`S"FUS
M9VED(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*
M;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8M-BGV*[9A]F4(-F!V+G9A-N,
M(-BQV*<@V*K8M-BNVXS8M2#8K]BGV*\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8P,PIM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@
M8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9
MAB#8K-BRV*;;C-BGV*H@VJ_9B-BGV8?;C"#8L=BG(-BGV+/8JMBNV+'8I]BL
M(-F&V879B-BO(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`N<&AP.C0U
M,2!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]!=71H+G!H<#HQ,3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@
M;V8@)7,N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BJV+G8L=N,V8$@
M)7,@(-BQV*<@V*C8I]BQ(-F&V879B-BO(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P
M,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,38V(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-S$*;7-G:60@(E5N86)L92!T
M;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#9
MOMBQV8C9AMBOV8<@5D93(-BQV*<@V*?9AMBJV8+8I]F$(-BOV*?8KR(*"B,@
M(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC
M"B,@"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z.3,@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HQ,#(*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HV-#@@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HY.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N
M(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR!61E,@
M7"(E<UPB(-BQV*<@V*C8I]BR(-F&V879B-BO(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,C<W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S
M,PIM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N
M(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR!61E,@
MV+'8IR#8J-BQV*?;C"#9AMF(V+38JMF&(-BHV*?8LB#:J=BQV*\B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HX,"!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C<R"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB"FUS9W-T
M<B`BV8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&4R#8L=BG(-BH
MV*?8LB#9AMF%V8C8KR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S960@
M87)C:&EV92XB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V*+8L=BTVXS9
MB"#9@=BTV+'8K]F'(-BQV*<@V*C8I]BR(-JIV+'8KR(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HX,S4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R
M96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(B#9
MAMF%VXSB@(S8JMF(V*?9AB#8K]BQ(-F^V+'9B-F&V*_9AR!61E,@V8;9B-BT
MV*HN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@V-@HC+"!F=7IZ>0IM
M<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@
M9F%I;&5D*2XB"FUS9W-T<B`B(-F&V87;C.*`C-BJV8C8I]F&(-BOV+$@V;[8
ML=F(V8;8K]F'(%9&4R#9AMF(V+38JBXB"@HC.B!F<F%M97=O<FLO4V5S<VEO
M;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*(RP@9G5Z>GD*
M;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R("+9AMF%VXSB
M@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@5D93(-BQV*<@V*K8NMN,VXS8L2#9
MAMBGV84@V*_8I]BO(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M-C8Y"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O
M<GDN(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BTV*?8KMF'('9F<W)O
M;W0@V+'8IR#8KMF(V*?9AMBO(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HQ,3`U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T
M<R(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB`E<R#8L=BG(-BHV8<@)7,@
M(-BJV+K;C-N,V+$@V8;8I]F%(-BOV*?8KSH@V;[9B-BTV8<@V879@MBUV*\@
MV*?8LB#9@MBHV80@V879B-BLV8C8KR#8I]BSV*HB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,CDS"FUS9VED(")5;F%B;&4@=&\@<F5N
M86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&
M(-BTV*?8KMF'(%9&4R#8L=BG(-BJV+K;C-N,V+$@V8;8I]F%(-BOV*?8KR(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(Y"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N
M(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BTV*?8KMF'(%9&4R#8L=BG
M(-BJV+K;C-N,V+$@V8;8I]F%(-BOV*?8KSH@)7,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HR-C<@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HS-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!6
M1E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F^
MV+'9B-F&V*_9AR!61E,@7"(E<UPB(-BQV*<@V*K8NMN,VXS8L2#9AMBGV84@
MV*_8I]BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I
M("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M-C$P(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,CD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RXB
M"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&4R`E
M<R\E<R#8L=BG(-BJV+K;C-N,V+$@V8;8I]F%(-BOV*?8KR(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(S(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HR,3,*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0U
M,B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C@U"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,#$*;7-G:60@(E5N86)L92!T
M;R!R96YA;64@5D93(&9I;&4N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&
M(-F^V+'9B-F&V*_9AR!61E,@V+'8IR#8JMBZVXS;C-BQ(-F&V*?9A2#8K]BG
MV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M
M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O;6MI<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O
M9G,G+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB`G;6MI<V]F<R<@V+'8
MIR#8I]BLV+'8IR#9AMF%V8C8KR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L92!T;R!T<F%N<VQA
M=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8
MI]F&(-BGVXS9AB#8L]F&V*\@5V]R9"#8L=BG(-BJV+'8K-F%V8<@V8;9A=F(
MV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M
M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$T.2!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$U,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M("(@V8;9A=N,XH",V*K9B-BGV88@V*_8L2#9OMBQV8C9AMBOV8<@7"(E<UPB
M(%9&4R`@V8;9B-BTV*HB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HQ-SD*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I
M(&9A:6QE9"DN(@IM<V=S='(@(B#9AMF%VXSB@(S8JMF(V*?9AB#8K]BQ(-F^
MV+'9B-F&V*_9AR!61E,@V8;9B-BTV*HN(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,C@Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ,S@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$T,PIM
M<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@
M(MF&V87;C.*`C-BJV8C8I]F&(-BOV+$@V;[8L=F(V8;8K]F'V90@V*_8I]BO
MV8<@5D93(-F&V8C8M-BJ(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@T
M,0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q
M=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(*;7-G<W1R("(@V8;9A=N,XH",V*K9
MB-BGV88@V*_8L2#9OMBQV8C9AMBOV8<@5D93(-F&V8C8M-BJ+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*;7-G:60@
M(E5N9&5R;&EN92(*;7-G<W1R("+8LMN,V+'8KMBWXH",V*_8I]BQ(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S
M(@IM<V=S='(@(MF(V*?:K]BQV*_8I]F&V*_9AB#8JMBZVXS;C-BQV*?8JB(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*
M;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(MF(V*?:
MK]BQV*_8I]F&V*_9AB#8HMBNV+';C-F&(-BYV879A"#8M-F%V*<B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,SDP"FUS9VED(")5
M;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ
M("(*;7-G<W1R("+9OMBGV+/8KB#8NMN,V+$@V879AMBJV+C8L=F'(-BGV+(@
MVJG8I]BQV+/8I]BR(-BHV+$@V+'9B-N,(-BGV*K8M=BGV80Z(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,0HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S@*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@T"FUS9VED(")5;F5X<&5C
M=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`BV;[8I]BS
MV*X@V+K;C-BQ(-F%V8;8JMBXV+'9AR#8I]BR(-JIV*?8L=BSV*?8LB#8J-F'
M.B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C8Q"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(MBZVXS8L2#8K=F(V++9
MAR(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS"FUS9VED(")5;FEC;V1E
M("A55$8M."DB"FUS9W-T<B`B56YI8V]D92`H551&+3@I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-38*;7-G:60@(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R($]U
M=&QY:6YG($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C8Y(&QI8B]";&]C:R]M971A<BYP:'`Z-S$*;7-G:60@
M(E5N:71S(@IM<V=S='(@(MF(V*?8K=BOV8?8IR(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0R.2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,S`*;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`BV*_8I]BOV8<@
MV8;8I]BTV8;8I]BNV*K9AR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I
M9"`H05!)($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@(E5N
M:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U.0HC+"!F=7IZ
M>0IM<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B
MV8?;C-J&(-F%VJG8I]F&VXP@V*K9AMBXVXS9A2#9AMBTV*_9AR(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,0IM
M<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B
MV8;8I]F%(-JIV*?8L=BHV+$@V8@@VXS8IR#8I]BSV84@V+'9A=BR(-F&V*?8
MM-F&V*?8KMBJV8<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N
M="!E;&5M96YT(@IM<V=S='(@(MF"V+?8N2#9OMN,V8C9AMBO(-BYV8;8M=BQ
M(-F!V+G9A-N,(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H
M<#HR.38*;7-G:60@(E5N;F%M960B"FUS9W-T<B`BV*C;C"#9AMBGV84B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y"FUS
M9VED("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U
M="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@
M<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T
M(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@
M82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*
M(MBOV+/8JB#B@(S9AMF(VXS8L]F'V*?;C"#8J-BOV8C9AB#8I]F%V*K;C-BG
MV+(@V*C9AR#8K]F$VXS9A"#8I]F%V8;;C-BJVXP@V8;9A=N,XH",V*K9B-BG
MV8;9AMBO(-BGV+(@V+?8L=N,V8(@V*C8L=F&V*?9A=F'(-F&V8C;C-BSVXP@
MV*C8L=N,V*_9AR\B"B+8L=F(V8;9B-BTV*H@VJ_8L=F!V*K9AR_:AMBSV*C;
MC-BOV8<@V+39B-F&V*\N(-JIV83;C-BO(-BJV*/;C-N,V*\@V+'8IR#9@=BT
MV*?8L2#8K]F'VXS8KR#8JMBG(-F%V*K9AB#9@=F&VXSB@(S8I^*`C-N,VXP@
MV+'8IR#8K]BQ("(*(FUO>FEL;&$N;W)G(-BHV*<@V+G9AMF(V*?9AB#:AMJO
MV8C9AMJOVXP@V*_8L]BJV+'8L]N,(-N,VJD@V*_8L]BJ(.*`C-F&V8C;C-BS
M(-BHV8<@V*K8KMBJV8?9E"#8L=BSV84@V+'8IR#9A=BTV*?9A]BOV8<@VJG9
MAMN,V*\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R("+8L=F&
MVJ\@V*K9AMBXVXS9A2#9AMBTV*_9AR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-C@V(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z.3(V"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M.3,R"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`BV*C8
ML]BW(-BHV*_9B-F&(-F^V+38JMN,V*C8I]F&VXPB"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C$Y-R!T96UP;&%T97,O861M:6XO=7-E<B]L
M:7-T+FEN8SHS,PIM<V=I9"`B57!D871E(@IM<V=S='(@(MBHV+'9B-BRV+'8
ML]BGV8;;C"(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S
M*2`@(RTC+2,M(RTC"B,@"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S
M='(@(MBHV+'9B-BRV+'8L]BGV8;;C"`E<R(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z-S8*;7-G:60@(E5P9&%T92!U<V5R(@IM<V=S
M='(@(MBHV+'9B-BRV+'8L]BGV8;;C"#:J=BGV+'8J-BQ(@H*(R`C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@
M861M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I="YP:'`Z,3`R
M('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@(EPB)7-<(B#8J-BQV8C8
MLMBQV+/8I]F&VXP@V+38KR(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C@S"FUS9VED(")5<&=R861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R("+8
MK]BSV*KB@(P@V8;9B-N,V+,@V*C9A]N,V8;9A^*`C-BSV*?8LMN,(-BMV+#9
M@2#8M-BO(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W."!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DY"FUS9VED(")5<&QO
M860B"FUS9W-T<B`BV*?8L=BSV*?9A"#:J=BQV*_9AB(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ.#8*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A
M=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R("+8JMF%
MV*?9A2#9OMBQV8C9AMBOV8?B@(SB@(S9A]BGVXP@V*K9AMBXVXS9A2#8J-BQ
MV8;8I]F%V8?B@(S9A]BGVXP@VJG8I]BQV*C8L=BOVXP@V*C9AR#:J=BGV+'8
ML]BGV+(@V*?8L=BSV*?9A"#8M-BO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@
M;&%T:6X@;&5T=&5R<R(*;7-G<W1R("+8K=BQV8C9@2#8J-BRV+':KR#9A-BG
MV*K;C-F&(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R<R(*
M;7-G<W1R("+8I]BYV*_8I]BO(-N,V8C9AMBGV8;;C"#8J-BRV+':KR(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(B#8
MI]BSV*K9@=BGV*_9AR#9@=BYV83;C#H@)7,B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-3
M3"(*;7-G<W1R("+8I]BSV*K9@=BGV*_9AR#8I]BR(%-33"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,C0*;7-G:60@(E5S92!I9B!N86UE+W!A<W-W
M;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM<V=S='(@(MBG
MVJ_8L2#9AMBGV84OV*?8L]F%(-BQV878LB#8J-BQV*?;C"#:J=BGV+'8L]BG
MV+(@24U34"#9A=BJV8'8I]F(V*H@V*?8L]BJV(P@V*?8L]BJV8'8I]BOV8<@
MVJG9AMN,V*\B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC
M.C(Q"B,L(&9U>GIY"FUS9VED(")5<V5R(@IM<V=S='(@(MJIV*?8L=BHV+'8
MI]F&(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HW
M,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@875T:&]R
M:7-E9"!F;W(@)7,N(@IM<V=S='(@(MJIV*?8L=BHV+$@)7,@(-BHV+'8I]N,
M("5S(-BGV*W8L=BGV+(@V8?9B-N,V9'8JB#9AMBTV*_9AR#8I]BSV*HB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S97(@061M:6YI<W1R871I
M;VXB"FUS9W-T<B`BV+/8L=F^V+'8L]BJVXP@VJG8I]BQV*C8L2(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C4Q"FUS9VED(")5<V5R($]P
M=&EO;G,B"FUS9W-T<B`BVJ_8LMN,V8;9A^*`C-F'V*?;C"#:J=BGV+'8J-BQ
M(@H*(SH@<VEG;G5P+G!H<#HV,@IM<V=I9"`B57-E<B!296=I<W1R871I;VXB
M"FUS9W-T<B`BV*O8J-BJ(-F&V*?9A2#:J=BGV+'8J-BQ(@H*(SH@<VEG;G5P
M+G!H<#HR,@IM<V=I9"`B57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES
M86)L960@9F]R('1H:7,@<VET92XB"FUS9W-T<B`BV*O8J-BJ(-JIV*?8L=BH
MV+$@V*C8L=BGVXP@V*?;C-F&(-F^V*?;C-JOV*?9AR#8NMN,V+$@V8'8N=BG
MV80@V+38K]F'(-BGV+/8JB(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT
M-CD*;7-G:60@(E5S97(@86-C;W5N="!N;W0@9F]U;F0B"FUS9W-T<B`BV*W8
ML]BGV*@@VJG8I]BQV*C8L2#9OMN,V*_8IR#9AMBTV*\B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.CDX
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U
M,"!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,PHC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C<R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O
M=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G<W1R("+9AMBGV84@VJG8
MI]BQV*C8L2(*"B,@"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H
M<#HQ,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB
M)7-<(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`BV8;8I]F%(-JIV*?8L=BH
MV+$@)R5S)R#8I]BR(-F"V*C9A"#9A=F(V*S9B-BO(-BGV+/8JB(*"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PIM<V=I9"`B57-E<FYA;64Z
M(@IM<V=S='(@(MF&V*?9A2#:J=BGV+'8J-BQ.B(*"B,Z('1E;7!L871E<R]L
M;V=I;B]M;V)I;&4N:6YC.C@*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B
MV8;8I]F%(-JIV*?8L=BHV+$Z("(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S
M='(@(MJIV*?8L=BHV+'8I]F&(-BSV*?9A=BGV8;9ASHB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$T"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C$V,R!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HR-34*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N
M(@IM<V=S='(@(MBTV*?8KMF'(%9&4R#9B-BLV8C8KR#9AMBOV*?8L=BO(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q.`IM<V=I9"`B5F%C871I
M;VXB"FUS9W-T<B`BV*K8N=BWVXS9A-BGV*HB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HX-C8*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I
M;F-L=61E.B`B"FUS9W-T<B`BV879B-F"V+G;C-BJV8?8I]N,(-F%V+G8JMBH
MV+$@VXS8I]F!V*K9AR#8M-BOV8<@V+G8J-BGV+'8JMF&V*\@V*?8LCHB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.`IM<V=I9"`B
M5F%L:61I='DB"FUS9W-T<B`BV*?8N=BJV*C8I]BQ(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.3<*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U"FUS9VED
M(")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R("+9A=F"V*_8
MI]BQ(-BHV8<@V*_9@MN,V8+9AR#8I]BR(-BMV*?9A-BG(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.#4V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Q-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@;W9E<B!T:&4@
M;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@(MF%V8+8K]BGV+$@V*?8
MLB#8J-N,V+3;C-F&V8<@V+?9B-F$(-F%V*S8I]BR("5S(-BHVXS8M-BJV+$@
MV*?8L]BJ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-"!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8V"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR.`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED
M(")686QU97,B"FUS9W-T<B`BV879@MBGV*_;C-BQ(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C$P.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,3@V"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`BV879
M@MBGV*_;C-BQ(-BHV+'8I]N,(-BGV8;8JMBNV*?8J"#8I]BR(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0T"FUS9VED(")687)I86)L92(*;7-G
M<W1R("+9A=BJV+K;C-N,V+$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")696YE
M>G5E;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES
M(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,`IM
M<V=I9"`B5F5R<VEO;B(*;7-G<W1R("+9AMBSV*[9AR(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR,C8*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*
M;7-G<W1R("+:J=F&V*K8L=F$(-F&V+/8KMF'(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R
M=&EC86P@86QI9VXB"FUS9W-T<B`BV*K8L=BGV+(@V+G9A=F(V*_;C"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G
M:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`BV8'8I]BUV839A^*`C-JO
MV+#8I]BQVXP@V+G9A=F(V*_;C"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R
M("+8N=F%V8C8K]N,.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C<P"FUS9VED(")697)Y($AI9V@B"FUS9W-T<B`BV*[;C-F$
MVXP@V*C8I]F$V*<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"B,L(&9U>GIY"FUS9VED(")6
M:65T($YA;2(*;7-G<W1R("+9AMBGV84@V;[8L=F(V8;8K]F'(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.30*;7-G:60@(E9I971N86UE<V4@*%9)4T-)
M22DB"FUS9W-T<B`B5FEE=&YA;65S92`H5DE30TE)*2(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.CDV,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")6:65W("5S(@IM<V=S='(@(MF&V878I]N,("5S(@H*(SH@;&EB+T)L
M;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@
M<&%G92(*;7-G<W1R("+9AMF%V*?;C"#;C-JI(-BUV8'8K=F'(-F(V*@@V*[8
MI]BQV*S;C"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.C@R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@
M(B#9AMF%V*<@V*C9AR#8N=F&V8C8I]F&("5S(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM
M<V=I9"`B5FER9VEN($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#D*;7-G:60@(E9I<VEB
M:6QI='DB"FUS9W-T<B`BV8+8I]BHV83;C-BJ(-F%V+38I]F'V*_9AR(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-C,*;7-G:60@(E9I<VEB
M:6QI='DZ("(*;7-G<W1R("+9@MBGV*C9A-N,V*H@V878M-BGV8?8K]F'.B`B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P
M+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R("(B
M"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC
M+2,M(PHC(`HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,
M3%D@1E)/32`E<RXB"FUS9W-T<B`BV*?8KMBWV*?8L2$A(2#8K]BSV*H@XH",
MV8;9B-N,V+,@V+'8IR#8J-BWV8C8L2#8K]BSV*K;C"#8I]BR("5S(-BMV+#9
M@2#:J=F&VXS8KR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,3,S"FUS9VED(")724X@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-PIM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES
M=&5N97(O<W1A='5S+G!H<#HR.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]H=&UL+G!H<#HR-S(@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@S"FUS
M9VED(")787)N:6YG(@IM<V=S='(@(MBGV*[8M]BGV+$Z("(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E
M(@IM<V=S='(@(MJ&V8?8I]BQV+39AMBHV8<B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H97(@1F]R96-A<W0B"FUS
M9W-T<B`BV;[;C-BTXH",V*C;C-F&VXP@V8?9B-BG(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C0R-PIM<V=I9"`B5V5A=&AE<B!D871A('!R
M;W9I9&5D(&)Y(@IM<V=S='(@(MBOV*?8K]F'(-BBV*@@V8@@V8?9B-BGVXS;
MC"#9@=BQV*?9A]F%(-BTV*_9AR#8J-F'(-F(V+/;C-F$V8<B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3(*;7-G:60@(E=E871H97(N8V]M(@IM
M<V=S='(@(G=E871H97(N8V]M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M,S8*;7-G:60@(E=E8B(*;7-G<W1R("+9B-BH(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0S-PIM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`BV8C8
MJ.*`C-JOV*?9AR(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N
M86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R("+9A]F!V*K:K]N,
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*;7-G:60@(E=E
M;&-O;64B"FUS9W-T<B`BV*[9B-BT(-BBV878K]N,V*\B"@HC(",M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(",M(RTC
M+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC
M(",M(RTC+2,M(R`@9F%?25(N<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*
M(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C4W"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@
M=&\@)7,B"FUS9W-T<B`BV*C9AR`E<R#8KMF(V+0@V*+9A=BOVXS8KR(*"B,@
M(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC
M"B,@"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E;7!L871E
M<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC
M;VUE+"`E<R(*;7-G<W1R("(E<]B,(-BNV8C8M"#8HMF%V*_;C-BO(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@(E=E<W1E<FX@*$E33RTX
M.#4Y+3$I(@IM<V=S='(@(E=E<W1E<FX@*$E33RTX.#4Y+3$I(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.38*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y
M+3$U*2(*;7-G<W1R(")797-T97)N("A)4T\M.#@U.2TQ-2DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B(@H*(R`C+2,M
M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R
M(&QO9VEN/R(*;7-G<W1R("+:AMF'(-BHV+'9AMBGV879A]F4(-JIV*?8L=BH
MV+'8K]N,(-BQV*<@)7,@V*C8I]N,V*\@V*C8N=BO(-BGV+(@V8C8L=F(V*\@
MV8;8M-BGV88@V*_9A]BOV)\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E
M<C\B"FUS9W-T<B`BV8;9B-N,V+/9A]F4XH",(-BMV*?8IMF$(-J&VXS8L]BJ
MV)\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B
M5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R("+9AMF(VXS8
ML]F'XH",VXP@V8;9@MF$(-F"V8C9A"#:AMN,V+/8JMB?(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C$*;7-G:60@(E=H
M97)E:7,@075S=')A;&EA(&UA<"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E<R(*;7-G<W1R("+:J=BO
MV*?9A2#9@=BGV+(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S"FUS
M9VED(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X
M="!E9&ET;W(N(@IM<V=S='(@(MJIV*_8I]F%(-BHV+'9AMBGV879A^*`C-F'
MV*?;C"#9A=BJV+79A.*`C-JIV8;9AMBOV8<@XH",V*C8L=BGVXP@V8C;C-BQ
MV*?;C-BTVJ_8L2#9A=BJV88@V8'8N=BGV80@V*C8I]BTV8;8KR(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*
M;7-G:60@(E=I9'1H(@IM<V=S='(@(MBYV+'8MB(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,Q,C4*;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*
M;7-G<W1R("(@V;[9A]F&V*<@V*_8L2#9B-BGV*W8KR!#4U,@(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7
M:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T
M(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`BV;[9A]F&V*?;C"#:K]BRVXS9
MAMJOV*?9AB`E<R#8K]BQ(-BQV*?8L]BJ("C8K]BQ(-F(V+'9B-BO(-BHV+G8
MK]N,(-F%V8C8J]BQ(-F%VXSB@(S:K]BQV*_8KRDZ(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H
M(&]F('1H92!T86)L92(*;7-G<W1R("+9OMF'V8;8I]N,(-BLV*_9B-F$(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*
M;7-G:60@(E=I9'1H('5N:70B"FUS9W-T<B`BV8C8I]BMV*\@V;[9A]F&V*<B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M-0IM<V=I9"`B5VED=&@Z(@IM<V=S='(@(MF^V8?9AMBG.B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HU,3,*;7-G:60@(E=I:VDB"FUS9W-T<B`B
M5VEK:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C4*;7-G:60@(E=I
M;F0B"FUS9W-T<B`BV*C8I]BO.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8V"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@
M(MBHV*?8KR#8LMF(V*_9A]F&VJ_8I]F%.B`B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C@P"FUS9VED(")7:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@
M(MBSV+'8N=BJ(-BHV*?8KR#8J-BQV*W8L]BH(-F!V8C8JB#8J-BQ(-BSV*?8
MN=BJ(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-38*;7-G:60@(E=I;F0Z
M(@IM<V=S='(@(MBHV*?8KSHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C0R"FUS9VED(")7:6YD.B`B"FUS9W-T<B`BV*C8I]BO.B`B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@(E=I<V1O;2(*;7-G
M<W1R("+8N=F"V80B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DV
M"B,L(&9U>GIY"FUS9VED(")7:7-H;&ES="(*;7-G<W1R("+9A-N,V+/8JB#8
MHMBQV++9B-F'V*<B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G
M:60@(E=O<FLB"FUS9W-T<B`BVJG8I]BQ(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B
M"FUS9W-T<B`BV*+8K]BQV+,@V878K=F$(-JIV*?8L2(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@
M4&AO;F4B"FUS9W-T<B`BV*K9A-F!V88@V878K=F$(-JIV*?8L2(*"B,Z(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$V.2!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M
M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@
M)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C,P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE
M;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$Q-`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!6
M1E,@9FEL92XB"FUS9W-T<B`BV*?;C-BLV*?8KR#9OMBQV8C9AMBOV8<@5D93
M(-F%V*S9B-BR(-BOV+/8JMBQV+/;C"#9AMBOV*?8L=BO(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(T,PIM<V=I9"`B6"U2968B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G
M:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,@IM<V=I9"`B6#4P
M.78S($5X=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S(%-U
M8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U
M8FIE8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#(*;7-G:60@(E@U,#EV,R!E>'1E
M;G-I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS
M9VED(")962(*;7-G<W1R("+B@(Q962(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0U-0IM<V=I9"`B65E962(*;7-G<W1R(")9
M65E9(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$Q,#@*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I9"`B665A
M<FQY(@IM<V=S='(@(MBSV*?9A-BGV8;9AR(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G
M:60@(EEE;65N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(EEE<R(*;7-G<W1R("+8HMBQ
MVXPB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M
M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(MBHV839A]B,(-F%
MV8C8I]F!V8+9A2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E
M('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*
M;7-G<W1R("+8M-F%V*<@V*_8L2#9A=BO(-F%V*K9AB#9A]BSV*K;C-BO+B#8
MI]BR(-BOVJG9A=F'("!;/#Y=(-BHV+'8I]N,(-BHV+':K]BTV*K9AB#8J-F'
M(%=94TE764<@V*?8L]BJV8'8I]BOV8<@VJG9AMN,V*\B"@HC.B!S97)V:6-E
M<R]P;W)T86PO961I="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U
M(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M-#$Q"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R
M("+8M-F%V*<@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ(-F&V+38K]N,V*\B"@HC
M.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,P,@IM<V=I9"`B
M66]U(&-A;B!N;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F
M=6QL(&YA;64N(@IM<V=S='(@(MBTV878IR#9AMF%VXSB@(S8JMF(V*?9AMN,
MV*\@V8;9B-N,V+/9AR`G7%PG(-BQV*<@V*_8L2#9AMBGV84@VJG8I]F%V80@
MV*[9B-BO(-BOV*?8M-BJV8<@V*C8I]BTVXS8KR(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$X-34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW
M-0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R
M97-S+B(*;7-G<W1R("+8M-F%V*<@V*+8K]BQV+,@V;[8L]BJ(-BGV83:J=BJ
MV+'9B-F&VXS:J2#9A=BYV*K8J-BQVXP@V8C8I]BQV*\@V8;:J=BQV*_9A^*`
MC-BGVXS8KR(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(Y,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S
M(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@
M9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R("(B"B+8M-F%V*<@V8?;C-J&(-F!
MVXS9A-BOVXP@V+'8IR#8K]BQ(-F^V+'9B-F&V*_9AR#8K]BQV8C9AN*`C-BH
MV+'8KR#8M-BOV8<@V*C9AR#9@=N,V838KR#9A=BJV8+8I]BHV83;C"#8K]BQ
M("5S(-F&VJ_8I]BTV*H@V8;:J=BQV*_9A^*`C-BGVXS8KR(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.CDX.`IM<V=I9"`B66]U(&AA=F4@8F5E;B!L
M;V=G960@;W5T+B(*;7-G<W1R("+8M-F%V*<@V*[8I]BQV*P@V+38K]N,V*\B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8Q"FUS9VED("(B"B)9
M;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I
M9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT
M97)N871I;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B(@HBV+39A=BG
M(-F%V*S8J-F(V+$@V8?8L]BJVXS8KR#;C-JI(-BTV878I]BQV8<@V*K9A-F!
MV88@V878N=BJV*C8L2#9B-BGV+'8KR#:J=F&VXS8K]B,(-BGV+(@V+G9A-BG
MV878JB`G*R<@V*C8L=BGVXP@V+39A=BGV+'9A^*`C-F'V*?;C"`B"B+8J-N,
MV88@V*?9A-F%V839A-N,(-BGV+/8JMF!V*?8K]F'(-JIV8;;C-BO(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X.`IM<V=I9"`B66]U(&AA=F4@
M=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`BV+39A=BG(-F%V*S8
MJ-F(V+$@V8?8L]BJVXS8KR#;C-JI(-F%V8+8K]BGV+$@V878N=BJV*C8L2#9
MB-BGV+'8KR#:J=F&VXS8KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O
M("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O4VEG;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@
M1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`BV+39
MA=BG(-BHV*?;C-BO(-N,VJD@V;[8M-BJVXS8J-BGV88@V*_8L=BNV*H@V*_8
MI]BOV8<@V*C8L=BGVXP@V*?8L]BJV8'8I]BOV8<@V*?8LB#8J]BHV*H@V8;8
MI]F%(-F^VXS:J=BQV*C9AMBOVXP@VJG9AMN,V*\B"@HC(",M(RTC+2,M(R`@
M8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0U-@IM<V=I9"`B66]U(&UU<W0@8V]N
M9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(MBTV878IR#8J-BGVXS8
MKR#;C-JI(-BSV*?9A=BGV8;9AR#9OMBTV*K;C-BHV*?9AB!61E,@V+'8IR#9
MOMN,VJG8L=BHV8;8K]N,(-JIV8;;C-BO(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H
M92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P
M;W)T+B(*;7-G<W1R("+9@MBHV80@V*?8LB#8I]BQV+/8I]F$(-JOV++8I]BQ
MV+38C"#8J-BGVXS8KR#9A=BTVJG9A"#8L=BG(-BTV+'8K2#8K]F'VXS8KR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*
M;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK
M('!O:6YT<R!T;R(*;7-G<W1R("+8M-F%V*<@V*C8I]N,V*\@55),V*?;C"#:
MJ=F'(-BGVXS9AB#9OMN,V8C9AMBO(-BHV8<@V*+9AB#8I]BTV*?8L=F'(-F%
MVXSB@(S:J=F&V*\@V+'8IR#9B-BGV+'8KR#:J=F&VXS8KR(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9;W4@;75S="!S96QE
M8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(MBTV878IR#8
MJ-BGVXS8KR#;C-JI(-JIV*?8L=BSV*?8LMB,(-BHV+'8I]N,(-BMV+#9@2#:
MJ=BQV*_9AB#8I]F&V*K8KMBGV*@@VJG9AMN,V*\B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,3D*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T
M;R!C;&5A<B!O=70N(@IM<V=S='(@(MBTV878IR#8J-BGVXS8KR#;C-JI(-F&
MV*?9A2#:J=BGV+'8J-BQV(P@V*C8L=BGVXP@V*W8L-F!(-JIV+'8K]F&(-F%
MV+38KMBU(-JIV8;;C-BO(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"FUS9VED
M(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G
M<W1R("+8M-F%V*<@V*C8I]N,V*\@VXS:J2#9AMBGV84@VJG8I]BQV*C8L=B,
M(-BHV+'8I]N,(-BMV+#9@2#8M-BOV88@V878M-BNV+4@VJG9AMN,V*\B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE
M('1O(&%D9"XB"FUS9W-T<B`BV+39A=BG(-BHV*?;C-BO(-N,VJD@V8;8I]F%
M(-JIV*?8L=BHV+'8C"#8J-BQV*?;C"#8I]BVV*?9@=F'(-JIV+'8K]F&(-F%
MV+38KMBU(-JIV8;;C-BO(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS9VED
M(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM
M<V=S='(@(MBTV878IR#8J-BGVXS8KR#;C-JI(-BTV8;8I]BSV8<@VJG8I]BQ
MV*C8L=B,(-BHV+'8I]N,(-BHV+'9B-BRV+'8L]BGV8;;C"#8I]F&V*K8KMBG
MV*@@VJG9AMN,V*\B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M>FEP+G!H<#HQ,S@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I
M;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`BV+39A=BG(-BHV*?;C-BO(-F%V+38
MKMBU(-JIV8;;C-BO(-JIV8<@VH;9AR#8N=F%V83;C"#8J-BGVXS8KR#8I]F&
MV*S8I]F%(-JOVXS8L=BO(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A
M=&5G;W)Y36%N86=E<BYP:'`Z-S$*;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N
M97<@8V%T96=O<GD@;F%M92XB"FUS9W-T<B`BV+39A=BG(-BHV*?;C-BO(-F&
MV*?9A2#8K-BOVXS8KR#8K]BSV*K9AR#8L=BG(-BJV*?;C-F^(-JIV8;;C-BO
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT
M<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA
M;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z.3<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S
M<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R
M("+9AMBTV+/8JB`E<R#8M-F%V*<@V879AMF"V+;;C"#8M-BOV8<@V*?8L]BJ
M+B#9A-BWV8'8I]F+(-BOV8C8J-BGV+'9AR#9B-BGV+'8KR#8M-F(VXS8KR(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED(")9
M;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`BV*+8K]BQV+,@V*?9A-JIV*K8
ML=F(V8;;C-JIVXP@V+39A=BG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(Q,@IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R("+8HMBO
MV+'8LR#9@=BQV+/8JMF&V*_9ASH@V+39A=BG.B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S0@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C@R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M.0IM<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R("+8I]BWV838I]BY
MV*?8JB#8M-F%V*<B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R97-S
M(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S
M97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T
M(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B+8HMBOV+'8LR#8I]N,V8;8JMBQ
MV8;8JMN,(-BTV878IR#9AMBSV*C8JB#8J-F'(-BGV*C8JMBOV*?;C"#9AMBT
MV+/8JB`E<R#8M-F%V*<@V*K8NMN,VXS8L2#:J=BQV*_9AR#8I]BSV*HNV*C8
ML=BGVXP@V+'8N=BGVXS8JB#9A=BSV*?8IMF$("(*(MBGV879AMN,V*K;C"#8
MJ-BGVXS8KR#8K]F(V*C8I]BQV8<@V8C8I]BQV*\@V+39B-N,V*\B"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B66]U<B!.
M86UE(@IM<V=S='(@(MF&V*?9A2#8M-F%V*<B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]N;V%D9"YI;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B(@HB66]U<B!A
M=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG
M('5S97)S+B!)9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R9&4@=&\@861M:6YI
M<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@
M(@HB875T:&5N=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T<B`B(@HBV+/8I]F%
MV*?9AMF'(-F^V+38JMN,V*C8I]F&(-BJV+78K]N,V8(@V8?9B-N,V9'8JB#8
MM-F%V*<@V*?8MMBGV8'9AR#:J=BQV*_9AB#:J=BGV+'8J-BQV*?9AB#8L=BG
M(-F^V+38JMN,V*C8I]F&VXP@V8;9A=N,XH",VJG9AMBOV(P@VXS8IR#8M-BG
MVXS8KR`B"B+8J-F&V*<@V*C9AR#8K]F$VXS9A"#8K]N,VJ_8L=N,(-BGVXS9
MAB#:J=BGV+$@V*?9AMBLV*?9A2#9AMF%VXSB@(S8M-F(V*\B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*;7-G:60@(B(*(EEO=7(@
M875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I
M;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D
M(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@HBV+/8I]F%V*?9
MAMF'(-F^V+38JMN,V*C8I]F&(-BJV+78K]N,V8(@V8?9B-N,V9'8JB#8M-F%
MV*<@V8'9A]BQV+/8JB#:J=BQV*_9AB#:J=BGV+'8J-BQV*?9AB#8L=BG(-F^
MV+38JMN,V*C8I]F&VXP@V8;9A=N,XH",VJG9AMBOV(P@VXS8IR#8M-BGVXS8
MKR`B"B+8J-F&V*<@V*C9AR#8K]F$VXS9A"#8K]N,VJ_8L=N,(-BGVXS9AB#:
MJ=BGV+$@V*?9AMBLV*?9A2#9AMF%VXSB@(S8M-F(V*\B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+G!H<#HY.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H
M92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T
M('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R
M("(B"B+8N-BGV8?8L2#9A=BQV8C8L=JOV+$@V+39A=BG(-F&V+/8J-BJ(-BH
MV8<@V*?8J-BJV*_8I]N,(-F&V+38L]BJ("5S(-BTV878IR#8JMBZVXS;C-BQ
M(-JIV+'8K]F'(-BGV+/8JB[8J-BQV*?;C"#8L=BYV*?;C-BJ(-F%V+/8I]BF
MV80@(@HBV*?9A=F&VXS8JMN,(-BHV*?;C-BO(-BOV8C8J-BGV+'9AR#9B-BG
MV+'8KR#8M-F(VXS8KR(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C4P"FUS
M9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U
M<F4N(@IM<V=S='(@(MF%V+'9B-BQVJ_8L2#8M-F%V*<@V*?;C-F&(-F%V+38
MKMBUV8<@V+'8IR#9OMBTV*K;C-BHV*?9AMN,(-F&V87;C.*`C-JIV8;8KRXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]P<FEN="YJ<SHT,@HC+"!F=7IZ
M>0IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI
M<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@(@HB
M=&\@<')I;G0N(@IM<V=S='(@(B(*(MF%V+'9B-BQVJ_8L2#8M-F%V*<@V*?;
MC-F&(-JOV++;C-F&V8?9E.*`C"#:AMBGV;X@V+'8IR#9OMBTV*K;C-BHV*?9
MAMN,(-F&V87;C.*`C-JIV8;8KRX@0V]N=')O;"]/<'1I;VX@*R!0(-BQV*<@
MV*C8L=BGVXP@VH;8I]F^("(*(MF!V+38I]BQ(-BOV8?;C-BO(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(U-PIM<V=I9"`B66]U<B!C=7)R96YT('1I
M;64@>F]N93HB"FUS9W-T<B`BV++9A=BGV88@V8'8N=F$VXP@V879AMBWV8+9
MAR#8K-BZV+'8I]F!VXS8I]N,VXP@V+39A=BG.B(*"B,Z('-E<G9I8V5S+W!R
M969S+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT
M:71Y(&AA<R!B965N(&-H86YG960N(@IM<V=S='(@(MF'V8C;C-F1V*H@V;[;
MC-BT(-F!V+'8MB#8M-F%V*<Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$U.`IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R("+9
MA]F(VXS9D=BJ(-F^VXS8M"#9@=BQV+8@V+39A=BG.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,#$*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G
M<W1R("+9AMBGV84@VJG8I]F%V80@V+39A=BG.B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.C$P,#`*;7-G:60@(EEO=7(@;&]G:6X@:&%S(&5X<&ER
M960N(@IM<V=S='(@(MF(V+'9B-BO(-BTV878IR#9A=F&V8+8MMN,(-BTV*_9
MAR#8I]BSV*HB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@
M:7,Z("5S(@IM<V=S='(@(MBGV+/9A2#8L=F%V+(@(-BLV*_;C-BO(-BTV878
MIR#8J-BQV*?;C"`E<R#9A]BSV*HZ("5S(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ-30*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E
M96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BXB
M"FUS9W-T<B`BVJ_8LMN,V8;9A^*`C-F'V*?;C"#8M-F%V*<@V*C8L=BGVXP@
MV+?9B-F$(-BGVXS9AB#9AMBTV+/8JB#8J-BQV8C8LMBQV+/8I]F&VXP@V+38
MK]F'(-BGV+/8JB`B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*
M;7-G<W1R("+:K]BRVXS9AMF'XH",V8?8I]N,(-BTV878IR#8J-BQV8C8LMBQ
MV+/8I]F&VXP@V+38K]F'(-BGV+/8JB(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!B965N(')E
M<V5T(@IM<V=S='(@(MBGV+/9A2#8L=F%V+(@(-BTV878IR#8J-BGV++9AMBT
MV*?9AMN,(-BTV*_9AR#8I]BSV*HB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R
M97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N
M97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*(MBGV+/9A2#8L=F%V+(@V+39
MA=BG(-BHV*?8LMF&V+38I]F&VXP@V+38K]F'(-BGV+/8JMB,(-F^V+/8JB#8
MI]F$VJG8JMBQV8C9AMN,VJD@V*[9B-BO(-BQV*<@VH;:J2#:J=F&VXS8KR#9
MB"#8J-BG(-BGV+/9A2#8L=F%V+(@V*S8K]N,V*\@(@HBV*[9B-BO(-F(V*?8
ML=BO(-BTV8C;C-BO(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S,R
M"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+B(*;7-G<W1R("+8
MI]BSV84@V+'9A=BR("#8M-F%V*<@V879AMF"V+;;C"#8M-BOV8<@V*?8L]BJ
M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9
M;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R("+:J=BGV+'8L]BGV++B@(S9
MA]BGVXP@V+'8I]F'XH",V*_9B-BQ(-BTV878ISHB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*(RP@9G5Z>GD*;7-G:60@(EIA
M:7)E(@IM<V=S='(@(MF$V+?;C-F!(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B
M6F%M8FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EII;6)A
M8G=E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-@IM
M<V=I9"`B6FEP<'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL
M=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@
M475O=&5D(%1E>'1=(@IM<V=S='(@(EO9OMF&V8?8I]F&(-JIV+'8K]F&(-F%
MV*K9AB#9AMF"V80@V8+9B-F$(-BTV*_9AUTB"@HC.B!S97)V:6-E<R]P<F]B
M;&5M+G!H<#HX.`IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R(");
MVJ_8LMBGV+'8M"#9A=BTVJG9A%T@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT
M("TB"FUS9W-T<B`B6]F&V878I]N,V+0@V878JMF&(-F&V8+9A"#9@MF(V80@
MV+38K]F'("TB"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI
M9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,L('!H<"UF;W)M870*;7-G:60@(EM3
M:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM<V=S='(@(MF&V878I]N,
MV+0@V878JMF&(-F&V8+9A"#9@MF(V80@V+38K]F'6R`M("5S(-BNV+==(@H*
M(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC
M+2,*(R`*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(EO8KMBW
M("5S(-BGV+(@)7,@72`B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$U-#$@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHQ,0IM<V=I9"`B7T%D
M;6EN:7-T<F%T:6]N(@IM<V=S='(@(MBSV+'9OMBQV+/8JMN,(@H*(SH@;&EB
M+V%P:2YP:'`Z,34W"FUS9VED(")?0TQ)(@IM<V=S='(@(D-,22(*"B,Z(&QI
M8B]A<&DN<&AP.C$T,0IM<V=I9"`B7T1A=&%4<F5E(@IM<V=S='(@(MBOV+'8
MKMBJ(-BOV*?8K]F'(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED(")?1&5L971E(%)O=R(*;7-G
M<W1R("+8K=BPV8$@V+/8M]BQ(@H*(SH@;&EB+V%P:2YP:'`Z,3,S"FUS9VED
M(")?1W)O=7!S(@IM<V=S='(@(MJOV+'9B-F')B-X,C`P8SO9A]BG(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W-0IM<V=I9"`B7TAE
M;'`B"FUS9W-T<B`BV+'8I]F'V8;9A=BG(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S"FUS9VED(")?26UA
M9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R("+8KMBUV8C8M=N,V*?8JB#8JMBU
MV8C;C-BQ+BXN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP
M.C$Y-`IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R("+9B-BQV8C8KR(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.3`*;7-G:60@(E],;V<@
M;W5T(@IM<V=S='(@(MBNV+'9B-BL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y
M($QI;FLN+BXB"FUS9W-T<B`BV*K8NMN,VXS8L2#9OMN,V8C9AMBO+BXN(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V-`IM<V=I9"`B
M7T]P=&EO;G,B"FUS9W-T<B`BVJ_8LMN,V8;9A^*`C-F'V*<B"@HC.B!L:6(O
M87!I+G!H<#HQ,S<*;7-G:60@(E]097)M:7-S:6]N<R(*;7-G<W1R("+9A=BL
MV8C8LMF'V*<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G
M<W1R("+8K=BPV8$@V;[;C-F(V8;8KRXN+B(*"B,Z(&QI8B]A<&DN<&AP.C$R
M-0IM<V=I9"`B7U-E='5P(@IM<V=S='(@(MBQV*?9AR8C>#(P,&,[V*?9AMBO
MV*?8LMN,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,S"FUS9VED(")?5&%B;&4@4')O<&5R=&EE<RXN+B(*
M;7-G<W1R("+8KMBUV8C8M=N,V*?8JB#8K-BOV8C9A"XN+B(*"B,Z(&QI8B]A
M<&DN<&AP.C$R.0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(MJIV*?8L=BHV+'8
MI]F&(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C$*;7-G:60@
M(F%D9')E<W,@8F]O:R(*;7-G<W1R("+:J=BJV*?8J-J&V8?9E"#8HMBOV+'8
MLR`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S-`HC
M+"!F=7IZ>0IM<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`BVJG8
MJMBGV*C:AMF'V90@V*+8K]BQV+,@(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HY,3,*;7-G:60@(F-A;&5N9&%R(@IM<V=S='(@(MBJV8+9B-N,
MV84B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M
M(RTC+2,M(PHC(`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,U.`HC+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM
M<V=S='(@(MBBV+'8I]F%(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ-3@*(RP@9G5Z>GD*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T
M<'5T(&9I;&4B"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V*_8L2#9OMBQ
MV8C9AMBOV8<@7"(E<UPB(-F&V8C8M-BJ(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C4Y,@IM<V=I9"`B8VQI8VL@:&5R92(*;7-G<W1R("+8I]N,V8;8K-BG
M(-BQV*<@V8'8M-BGV+$@V*_9A]N,V*\B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E
M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,3<X"B,L(&9U>GIY"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R
M<F]R(@IM<V=S='(@(MBJV8'8I]F(V*K9A]BGVXP@V;[;C-JIV+'8J-F&V*_;
MC"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34T"FUS
M9VED(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(V"FUS9VED
M(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$X,@HC+"!F=7IZ>0IM<V=I9"`B96YT
M<GD@;F]T(&9O=6YD(@IM<V=S='(@(B5S(-F^VXS8K]BG(-F&V+38KR(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED
M(")F86QL:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R
M;W=S97(N<&AP.C@U-0IM<V=I9"`B9FEL92(*;7-G<W1R("+9OMBQV8C9AMBO
MV8<B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M
M(RTC+2,M(PHC(`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W-"!L:6(O0FQO
M8VLO;65T87(N<&AP.C,V,"!L:6(O0FQO8VLO;65T87(N<&AP.C,X-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S(@IM
M<V=S='(@(MBGV+(@)7,@*"5S*2#8K]BQ("5S("5S(@H*(R`C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,`IM<V=I9"`B9W5S=&EN9R(*
M;7-G<W1R("+8J-BGV*\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C0Y"FUS9VED(")H.B(*;7-G<W1R(")H.B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-3@*;7-G:60@
M(FAH(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,3,X"FUS9VED(")H;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,C,*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R("+9@=F(V+'8I]F+
M(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF
M9BYP:'`Z-SD*;7-G:60@(FEN;&EN92(*;7-G<W1R("+8K]BQV*[8MR(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,38R"FUS9VED(")I
M;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN=&5R;F%L('-O9G1W
M87)E(&5R<F]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(")L:6YE<UTB"FUS9W-T<B`BV*[8
MM]F(V+==(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*;7-G:60@(FUK:7-O9G,@
M97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S8Y"FUS
M9VED(")M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C(Y,2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,S(*;7-G:60@(FYA;64B
M"FUS9W-T<B`BV8;8I]F%(@H*(SH@9G)A;65W;W)K+U)00R]24$,N<&AP.C$R
M,0IM<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(MF^VXS8I]BOV8<@
MV+/8I]BRVXP@V8;8M-BOV8<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C$R,3D*;7-G:60@(FYO="!Y970@:6UP;&5M96YT960B"FUS
M9W-T<B`BV8?9AMF(V+(@V;[;C-BGV*_9AR#8L]BGV++;C"#9AMBTV*_9AR#8
MI]BSV*HB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-0IM<V=I
M9"`B;F]T97!A9"(*;7-G<W1R(")N;W1E<&%D(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.`IM<V=I9"`B<&5R
M8V5N="(*;7-G<W1R("+8K]BQV+78KR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,3<T"B,L(&9U>GIY"FUS9VED(")P97)M:7-S:6]N
M(&1E;FEE9"(*;7-G<W1R("+9A=BLV8C8LB(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L
M<R(*;7-G<W1R("+9OMN,VJG8L]F$V8?8IR(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED(")R96UO=&4@97)R;W(@:6X@
M<')O=&]C;VPB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-S,*;7-G:60@(G)I<VEN9R(*;7-G<W1R("+8M]F$
MV8C8N2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,30R
M"B,L(&9U>GIY"FUS9VED(")S97)V:6-E('5N879A:6QA8FQE(@IM<V=S='(@
M(MBHV839B-JI($UE=&%R(-F"V*?8J-F$(-BOV+/8JMBQV+,@V8;;C-BSV*HB
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.CDY"FUS9VED(")S:&]W(&1I
M9F9E<F5N8V5S(@IM<V=S='(@(MF&V878I]N,V+0@V*K9@=BGV8C8JMF'V*<B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS.#4*;7-G
M:60@(G-S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")S=&5A9'DB"FUS9W-T<B`BV;[;C.*`
MC-BOV+'9OMN,(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,#D*
M;7-G:60@(G-W:71C:"!O9F8@:F%V87-C<FEP="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES
M=&5M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3(Y"FUS9VED(")T87-K(&QI<W0B"FUS9W-T<B`BV8'9A]BQV+/8
MJB#9B-BXVXS9@=F'(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S`U"B,L(&9U>GIY"FUS
M9VED(")T<GD@86=A:6XB"FUS9W-T<B`BV*_8L2#9A]BQ(-F(V+'9B-BO(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,S8@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N
M=7`N<&AP.C(V.0IM<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@
M8V]N9FER;2(*;7-G<W1R("+8I]BSV84@V+'9A=BR(-BQV*<@V*C8L=BGVXP@
MV*K8H]N,VXS8KR#8K]F(V*C8I]BQ(-F(V*?8L=BO(-JIV8;;C-BO(@H*(SH@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z
M-SD*;7-G:60@(G5N:69I960B"FUS9W-T<B`BVXS:K]BGV8;9AR#8M-BOV8<B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U!A<G0N<&AP.C(W"FUS9VED(")U
M;FYA;65D(@IM<V=S='(@(MBHVXP@V8;8I]F%(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")U
M<V5R('-E;&5C="(*;7-G<W1R("+8I]F&V*K8KMBGV*@@VJG8I]BQV*C8L2(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS-0IM
M<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0Q"FUS9VED(")W.B(*;7-G<W1R
M(")W.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED
M(")W96%T:&5R+F-O;2(*;7-G<W1R(")W96%T:&5R+F-O;2(*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P;R]E<U]%4RYP;P``````````````````````
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`W,38R-S,@,3`U,34T
M,S,W-#(@,#$W-3,S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````",@4W!A;FES:"!T<F%N<VQA=&EO;G,@9F]R(&AO<F1E('!A
M8VMA9V4*(R!4<F%D=6-C:6]N97,@86P@97-P8?%O;"!P87)A(&5L('!A<75E
M=&4@:&]R9&4N"B,@0V]P>7)I9VAT("A#*2`R,#`T($AO<F1E(%!R;VIE8W0*
M(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC
M96YS92!A<R!T:&4@:&]R9&4@<&%C:V%G92X*(R!!=71O;6%T:6-A;&QY(&=E
M;F5R871E9"P@,C`P-"X*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M
M260M5F5R<VEO;CH@2&]R9&4@,RXP+6-V<UQN(@HB4F5P;W)T+4US9VED+4)U
M9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$
M871E.B`R,#`V+3`U+3$X(#`X.C$W*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A
M=&4Z(#(P,#8M,#(M,34@,3<Z,C0K,#$P,%QN(@HB3&%S="U4<F%N<VQA=&]R
M.B!-86YU96P@4"X@07EA;&$@/&UA>6%L84!U;F5X+F5S/EQN(@HB3&%N9W5A
M9V4M5&5A;3H@:3$X;D!L:7-T<RYH;W)D92YO<F=<;B(*(DU)344M5F5R<VEO
M;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]
M25-/+3@X-3DM,5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I
M=%QN(@HB4&QU<F%L+49O<FUS.B!N<&QU<F%L<STR.R!P;'5R86P]*&X@(3T@
M,2D[7&XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,V.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(@*&AA8V4@)7,@
M9.UA<RDB"@HC.B!L:6(O2&]R9&4N<&AP.C$S.#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B`H06-C961I96YD;R!A
M("5S*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S<W"B,L('!H<"UF;W)M
M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B("AE;B`E<R!D[6%S
M*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S<S"FUS9VED("(@*'1O9&%Y
M*2(*;7-G<W1R("(@*&AO>2DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W
M-0IM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B("AM8?%A;F$I(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S$*;7-G:60@(B`H>65S=&5R9&%Y*2(*
M;7-G<W1R("(@*&%Y97(I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(T-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4P"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.38*;7-G:60@(B!A="`B"FUS
M9W-T<B`B96X@(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C(Q.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R
M(")<(B5S7"(@;F\@97,@=6X@9&ER96-T;W)I;RXB"@HC.B!L:6(O2&]R9&4O
M0TQ)+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO
M="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B7"(E<UPB(&YO(&5S('5N82!E
M;&5C8VGS;B!VX6QI9&$N(@H*(SH@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HW
M,3`@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HQ,#DX"B,L('!H<"UF;W)M870*
M;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@
M4F5G:7-T<GDN(@IM<V=S='(@(DYO('-E(&AA(&-O;F9I9W5R861O(%PB)7-<
M(B!E;B!E;"!R96=I<W1R;R!D92!(;W)D92XB"@HC.B!L:6(O2&]R9&4O5')E
M92YP:'`Z,3<Q"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!T<F5E(')E
M;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B3F\@<V4@96YC;VYT<O,@96P@
M9V5N97)A9&]R(&1E(.%R8F]L97,@9&4@7"(E<UPB+B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A
M9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B4V4@:&$@8?%A
M9&ED;R!<(B5S7"(@86P@<VES=&5M82!D92!G<G5P;W,N(@H*(SH@861M:6XO
M<&5R;7,O861D8VAI;&0N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(EPB
M)7-<(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS
M9W-T<B`B4V4@:&$@8?%A9&ED;R!<(B5S7"(@86P@<VES=&5M82!D92!P<FEV
M:6QE9VEO<RXB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4T(&%D;6EN+W!E<FUS
M+V%D9&-H:6QD+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B3F\@<V4@:&$@8W)E861O
M(%PB)7-<(CH@)7,N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@P"B,L
M('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO
M=V5D("@E+C)F)24I(@IM<V=S='(@(E5S861O<R`E+C)F34(@9&4@)2XR9DU"
M('!E<FUI=&ED;W,@*"4N,F8E)2DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C(V"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N9"`E
M<R(*;7-G<W1R("(E9"`E<R!Y("5S(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C4Y-"!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HR-C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER
M97,N(@IM<V=S='(@(E%U961A;B`E9"!D[6%S(&AA<W1A('%U92!E>'!I<F4@
M;&$@8V]N=')A<V7Q82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*
M;7-G<W1R("(E9"!P<F]N\W-T:6-O<R!D:6%R:6]S(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@
M3F]T:6-E(@IM<V=S='(@(B5S("T@079I<V\B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C<P-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG
M97)P<FEN="(*;7-G<W1R(")(=65L;&$@9&EG:71A;"!D92`E<R(*"B,Z(&QI
M8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-#(@;&EB+TAO<F1E+TU)344O
M0V]N=&5N=',N<&AP.C@T-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*
M;7-G<W1R("(E<R!+0B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N86YC92!/<&5R871I
M;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B5S(&]P97)A8VEO;F5S(&1E
M(&UA;G1E;FEM:65N=&\@+2!#;VYF:7)M86-I\VXB"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B0V]N9FEG=7)A
M8VGS;B!D92`E<R(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8T
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B1FER
M;6$@9&4@)7,B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S
M='(@(D%C=65R9&]S(&1E(&QI8V5N8VEA(&1E("5S(@H*(SH@;&EB+U9&4R]F
M='`N<&AP.C8Y,"!L:6(O5D93+V9T<"YP:'`Z-S8S(&QI8B]61E,O<VUB+G!H
M<#HT-#$*(SH@;&EB+U9&4R]S;6(N<&AP.C4P-PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B66$@97AI<W1E("5S
M+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,38V(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A<BYP:'`Z,C0V"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S4R(&QI8B]";&]C:R]M971A<BYP:'`Z,S4X"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B5S(&$@;&%S
M("5S("5S(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0X"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@
M=&AE("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P
M97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B(@HB)7,@97-TX2!P<F5P
M87)A9&\@<&%R82!R96%L:7IA<B!L87,@;W!E<F%C:6]N97,@9&4@;6%N=&5N
M:6UI96YT;R`B"B)S96QE8V-I;VYA9&%S+D%C=&EV92!L87,@8V%S:6QL87,@
M9&4@;&%S(&]P97)A8VEO;F5S('%U92!D97-E82!E:F5C=71A<B!E;B`B"B)E
M<W1A(&]C87-I\VXN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-#`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`B2&%C
M92!F86QT82`E<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDS"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(&UI;G5T97,B"FUS9W-T<B`B)7,@;6EN=71O
M<R(*"B,Z(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R(").;R!S
M92!H82!E;F-O;G1R861O("5S+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@
M)7,B"FUS9W-T<B`B)7,@86P@)7,@9&4@)7,B"@HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.CDR-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@
M0F]O:R(*;7-G<W1R(")$:7)E8V-I;VYE<R!D92`E<R(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z.3$X"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L
M96YD87(B"FUS9W-T<B`B06=E;F1A(&1E("5S(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HY,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D
M(@IM<V=S='(@(DQI8G)E=&$@9&4@;F]T87,@9&4@)7,B"@HC.B!L:6(O2&]R
M9&4O2V]L86(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A
M<VML:7-T(@IM<V=S='(@(E1A<F5A<R!D92`E<R(*"B,Z(&QI8B](;W)D92].
M;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B)7,Z("5S(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R-PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B(E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M
M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@
M;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A
M;GD@<&5R<V]N86P@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*(B5S.B!%<W1E
M(&UE;G-A:F4@<'5E9&4@<75E(&YO('!R;V-E9&$@9&4@<75I96X@<&%R96-E
M('-E<BX@179I=&4@<V5G=6ER("(*(F-U86QQ=6EE<B!V[6YC=6QO(&EN8VQU
M[61O(&\@<W5M:6YI<W1R87(@8W5A;'%U:65R(&EN9F]R;6%C:?-N('!E<G-O
M;F%L(&%L("(*(G)E;6ET96YT92XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S4T(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.3D*
M;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B+"!V96YT;W-O("(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3DU(&QI8B]";&]C:R]M971A<BYP:'`Z,C`P
M"B,L('!H<"UF;W)M870*;7-G:60@(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R
M("(L('9E;G1O<V\@)7,@)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P
M.`HC+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@
M)7,B"FUS9W-T<B`B+"!V87)I86)L92!D92`E<R!A("5S(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(P-CD@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,C@*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<T."!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C(Y-`HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C,T.`IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(BTM('-E;&5C8VEO
M;F%R("TM(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P"FUS9VED("(Q,B!(
M;W5R($9O<FUA="(*;7-G<W1R(")&;W)M871O(&1E(#$R(&AO<F%S(@H*(SH@
M;&EB+T)L;V-K+W1I;64N<&AP.C$Y"FUS9VED("(R-"!(;W5R($9O<FUA="(*
M;7-G<W1R(")&;W)M871O(&1E(#(T(&AO<F%S(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T(&AO
M<F%S(@H*(SH@;&EB+TAO<F1E+U5)+U!A9V5R+G!H<#HV.0IM<V=I9"`B/%!R
M979I;W5S(@IM<V=S='(@(CQ!;G1E<FEO<B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3(V"FUS9VED(")!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER
M960@9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@(E!A<F$@97-T92!B;&]Q=64@
M:&%C92!F86QT82!U;B!M;W1O<B!D92!B87-E(&1E(&1A=&]S+B(*"B,Z(&QI
M8B](;W)D92YP:'`Z,3<Q"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U
M<G)E9"(*;7-G<W1R(")392!H82!P<F]D=6-I9&\@=6X@97)R;W(@:7)R97!A
M<F%B;&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@
M(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE
M<W-A9V4N(@IM<V=S='(@(DAA8V4@9F%L=&$@=6YA(&-L879E(%!'4"!P^F)L
M:6-A('!A<F$@8VEF<F%R('5N(&UE;G-A:F4N(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z,3$V.`IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R
M97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B
M2&%C92!F86QT82!U;F$@8VQA=F4@4$=0('#Z8FQI8V$@<&%R82!C;VUP<F]B
M87(@=6X@;65N<V%J92!F:7)M861O+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C$P.3D*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A
M=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E
M8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"B)(86-E;B!F86QT82!U
M;F$@8VQA=F4@4$=0('#Z8FQI8V$L('5N82!C;&%V92!01U`@<')I=F%D82!Y
M('5N82!F<F%S92!C;&%V92`B"B)P87)A(&1E<V-I9G)A<B!U;B!M96YS86IE
M+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$P,38*;7-G:60@(B(*
M(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S86=E+B(*;7-G
M<W1R("(B"B)(86-E;B!F86QT82!U;F$@8VQA=F4@4$=0('#Z8FQI8V$L('5N
M82!C;&%V92!01U`@<')I=F%D82!Y('5N82!F<F%S92!C;&%V92`B"B)P87)A
M(&9I<FUA<B!U;B!M96YS86IE+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3`V"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV
M871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R`B"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@HB2&%C96X@9F%L
M=&$@=6YA(&-L879E(%,O34E-12!P^F)L:6-A+"!U;F$@8VQA=F4@4R]-24U%
M('!R:79A9&$@>2!U;F$@9G)A<V4@(@HB8VQA=F4@<&%R82!D97-C:69R87(@
M=6X@;65N<V%J92XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C0S
M,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)
M344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B`B
M"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*(DAA8V5N(&9A;'1A('5N82!C;&%V
M92!3+TU)344@</IB;&EC82P@=6YA(&-L879E(%,O34E-12!P<FEV861A('D@
M=6YA(&9R87-E("(*(F-L879E('!A<F$@9FER;6%R('5N(&UE;G-A:F4N(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G:60@(D$@<'5B
M;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G
M92XB"FUS9W-T<B`B2&%C92!F86QT82!U;F$@8VQA=F4@4TU)344@</IB;&EC
M82!P87)A(&-I9G)A<B!U;B!M96YS86IE+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.CD*;7-G:60@(D%-($-L;W5D<R(*;7-G
M<W1R(").=6)E<R!M871I;F%L97,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G
M<W1R("),:6=E<F$@;&QU=FEA(&UA=&EN86PB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G
M<W1R("),;'5V:6$@;6%T:6YA;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED(")!32!3:&]W97)S(@IM<V=S='(@
M(D%G=6%C97)O<R!M871I;F%L97,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM
M<V=S='(@(D%G=6%C97)O(&UA=&EN86P@9&4@;FEE=F4B"@HC.B!T96UP;&%T
M97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`B04TO
M4$TB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM
M<V=I9"`B05!)($E$(@IM<V=S='(@(DE$(&1E($%022(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T
M('1H:7,@961I=&]R(@IM<V=S='(@(D%C97)C82!D96P@961I=&]R(@H*(SH@
M<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3,*;7-G:60@(D%B;W5T+BXN(@IM
M<V=S='(@(D%C97)C82!D92XN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R
M("));F9E<FEO<B!!8G,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED9&QE(@IM<V=S='(@(D5N
M(&UE9&EO($%B<RXB"@HC.B!L:6(O5D93+VUU<W%L+G!H<#HR.#(*;7-G:60@
M(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B4V4@:&$@9&5N96=A9&\@96P@86-C97-O(&%L(&-R96%R(&5L(&1I<F5C
M=&]R:6\@5D93+B(*"B,Z(&QI8B]61E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B
M06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92XB"FUS9W-T<B`B4V4@
M:&$@9&5N96=A9&\@96P@86-C97-O(&%L(&-R96%R(&5L(&%R8VAI=F\@5D93
M+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS"FUS9VED(")!8V-O=6YT
M($EN9F]R;6%T:6]N(@IM<V=S='(@(DED96YT:61A9"(*"B,Z(&-O;F9I9R\N
M8F%K+W!R969S+G!H<"YD:7-T.C<X"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D
M(@IM<V=S='(@(D-O;G1R87-E\6$@9&4@86-C97-O(@H*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*;7-G:60@(D%C8V]U;G0@9G)O
M>F5N+B(*;7-G<W1R("))9&5N=&ED860@8FQO<75E861A+B(*"B,Z(&-O;F9I
M9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C,S-0IM<V=I9"`B06-C;W5N=&EN
M9R(*;7-G<W1R(")#;VYT86)I;&ED860B"@HC.B!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C$T."!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z,3$*;7-G:60@(D%D
M9"(*;7-G<W1R(")!\6%D:7(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A
M9&UI;B]G<F]U<',N<&AP.C(R-0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM
M<V=S='(@(D'Q861I<B!G<G5P;R!D97-C96YD:65N=&4B"@HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.CDX(&QI8B](;W)D92]097)M<R]522YP:'`Z.3D*
M;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N(@IM<V=S='(@(D'Q861I<B!P
M<FEV:6QE9VEO(&1E<V-E;F1I96YT92(*"B,Z('1E;7!L871E<R]P;W)T86PO
M861D+FEN8SHU"FUS9VED(")!9&0@2&5R93HB"FUS9W-T<B`B0?%A9&ER(&%Q
M=>TZ(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O=7!S+G!H
M<#HR,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B0?%A9&ER(&=R
M=7!O(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HX-R!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB"FUS
M9W-T<B`B0?%A9&ER('!R:79I;&5G:6\B"@HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V%D9&-H:6QD+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%D
M9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R(")!\6%D:7(@82!<
M(B5S7"(@=6X@9W)U<&\@9&5S8V5N9&EE;G1E(@H*(SH@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI
M;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B0?%A9&ER(&$@7"(E
M<UPB('5N('!R:79I;&5G:6\@9&5S8V5N9&EE;G1E(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R(")!\6%D
M:7(@=6X@=7-U87)I;SHB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-34V"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S='(@(D'Q861I
M<B!C;VQU;6YA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN
M8SHS-`IM<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S='(@(D'Q861I<B!M
M:65M8G)O<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z.34*;7-G
M:60@(D%D9"!P86ER(@IM<V=S='(@(D'Q861I<B!P87(B"@HC.B!C;VYF:6<O
M+F)A:R]P<F5F<RYP:'`N9&ES=#HS-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S='(@
M(D'Q861I<B!E;"!M96[Z("5S(&-O;6\@<&%N96P@;&%T97)A;"!D92!-;WII
M;&QA(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HW,0IM
M<V=I9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B0?%A9&ER(&$@
M;&%S(&1I<F5C8VEO;F5S.B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z-S@*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS
M9W-T<B`B0?%A9&ER(&$@;&%S(&1I<F5C8VEO;F5S.B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R(")!\6%D:7(@=7-U
M87)I;R(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@
M;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N
M(@IM<V=S='(@(B(*(E-E(&AA(&'Q861I9&\@7"(E<UPB(&%L('-I<W1E;6$L
M('!E<F\@;F\@<V4@<'5E9&4@8?%A9&ER(&QA(&EN9F]R;6%C:?-N("(*(F%D
M:6-I;VYA;"!D92!A;'1A.B`E<RXB"@HC.B!S:6=N=7`N<&AP.C0U"B,L('!H
M<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9
M;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(E-E(&AA(&'Q861I9&\@7"(E
M<UPB(&%L('-I<W1E;6$N(%EA('!U961E(&EN:6-I87(@;&$@<V5S:?-N+B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHR"FUS9VED(")!
M9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(DQA(&%D:6-I\VX@
M9&4@=7-U87)I;W,@97-TX2!D97-H86)I;&ET861A+B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ-#0Q(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3(V"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S
M"FUS9VED(")!9&1R97-S(@IM<V=S='(@(D1I<F5C8VGS;B(*"B,Z(&-O;F9I
M9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C$T,0IM<V=I9"`B061D<F5S<R!"
M;V]K(@IM<V=S='(@(D1I<F5C8VEO;F5S(@H*(SH@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.CDT(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T
M+G!H<#HU-@IM<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F
M;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`B061M:6YI<W1R861O<B`M(&1E9FEN
M92!P<FEV:6QE9VEO<R!D92!O=')O<R!U<W5A<FEO<R(*"B,Z(&%D;6EN+VEN
M9&5X+G!H<#HQ.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3$W"FUS
M9VED(")!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')A8VGS;B(*
M"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C,T,PIM<V=I9"`B
M061S(@IM<V=S='(@(D%N=6YC:6]S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ.`IM<V=I9"`B069G:&%N:7-T86XB"FUS
M9W-T<B`B069G86YI<W3A;B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C4W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C$*;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B06QB
M86YI82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-S0*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B07)G96QI82(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA
M<R(*;7-G<W1R(")!;&EA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*;7-G:60@(D%L:6=N(@IM<V=S='(@
M(D%L:6YE87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@(D%L:6YE86-I
M\VXZ(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C@W"FUS9VED(")!;&PB
M"FUS9W-T<B`B5&]D;W,B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(P
M-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8U"FUS9VED(")!;&P@075T
M:&5N=&EC871E9"!5<V5R<R(*;7-G<W1R(")4;V1O<R!L;W,@=7-U87)I;W,@
M875T96YT:69I8V%D;W,B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S(&%D;6EN
M+V=R;W5P<RYP:'`Z,C(R"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S='(@(E1O
M9&]S(&QO<R!G<G5P;W,B"@HC.B!L:6(O2&]R9&4O4&5R;7,O9&%T871R964N
M<&AP.C<U(&QI8B](;W)D92]097)M<R]522YP:'`Z.3$*;7-G:60@(D%L;"!0
M97)M:7-S:6]N<R(*;7-G<W1R(")4;V1O<R!L;W,@<')I=FEL96=I;W,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G<W1R(")4;V1O<R!L;W,@
M;&%D;W,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W,0IM<V=I9"`B06QL
M;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(E!E<FUI=&ER('9A<FEA
M<R!D:7)E8V-I;VYE<R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T
M.C4S.`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP
M93\B"FUS9W-T<B`BOU!E<FUI=&ER(&-O;F9I9W5R86-I\VX@9&4@=&EP;R!D
M92!L:7-T87,@;W)D96YA9&%S/R(*"B,Z(&QI8B](;W)D92]$871A5')E92]S
M<6PN<&AP.C4P-`IM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`B66$@
M97AI<W1E(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,3(V"FUS
M9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R(")!8V-E<V\@24U3
M4"!A;'1E<FYA=&EV;R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T
M.C4Q,0IM<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B
M0VQA=F4@24U34"!A;'1E<FYA=&EV82(*"B,Z(&-O;F9I9R\N8F%K+W!R969S
M+G!H<"YD:7-T.C4P,PIM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B
M"FUS9W-T<B`B57-U87)I;R!)35!3(&%L=&5R;F%T:79O(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z,S4*;7-G:60@(D%L=&5R;F%T92!E;6%I
M;"!A9&1R97-S(@IM<V=S='(@(D1I<F5C8VGS;B!E;&5C='+S;FEC82!A;'1E
M<FYA=&EV82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!
M;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(E!L86YT:6QL87,@86QT97)N
M871I=F%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3(R"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS
M9W-T<B`B5&5X=&\@86QT97)N871I=F\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HU."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(W"FUS9VED(")!;65R:6-A;B!386UO
M82(*;7-G<W1R(")386UO82!!;65R:6-A;F$B"@HC.B!L:6(O2&]R9&4O4')E
M9G,O54DN<&AP.CDU(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3$U"FUS9VED
M(")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N(@IM<V=S='(@(E-E
M(&AA(&EN9&EC861O('5N('9A;&]R(&EL96=A;"XB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,34U"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R
M(&AA<R!O8V-U<F5D+B(*;7-G<W1R(")392!H82!P<F]D=6-I9&\@=6X@97)R
M;W(@9&5S8V]N;V-I9&\N(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-@IM<V=I9"`B06YD;W)R82(*;7-G<W1R(")!;F1O
M<G)A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-`IM<V=I9"`B06YG;VQA(@IM<V=S='(@(D%N9V]L82(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C4W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`*;7-G:60@(D%N
M9W5I;&QA(@IM<V=S='(@(D%N9W5I;&$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R(")0
M<F]X>2!A;O-N:6UO(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R(")297-P=65S=&$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HU."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U"FUS9VED(")!
M;G1A<F-T:6-A(@IM<V=S='(@(D%N=.%R=&ED82(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C4V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3D*;7-G:60@(D%N=&EG=6$@
M86YD($)A<F)U9&$B"FUS9W-T<B`B06YT:6=U82!Y($)A<F)A9&]S(@H*(SH@
M861M:6XO<&AP<VAE;&PN<&AP.C,V(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@
M;&EB+TAO<F1E+T)L;V-K+U5)+G!H<#HU.`HC.B!T96UP;&%T97,O861M:6XO
M<V5T=7`O:6YD97@N:'1M;#HV"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R
M(")!<&QI8V%C:?-N(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R"FUS
M9VED(")!<'!L:6-A=&EO;B!,:7-T(@IM<V=S='(@(DQI<W1A(&1E(&%P;&EC
M86-I;VYE<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,SD*;7-G:60@
M(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R("),82!A<&QI8V%C:?-N
M(&5S=.$@;&ES=&$N(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR
M,3@*;7-G:60@(D%P<&QY('1O($-H:6QD(%-H87)E<R(*;7-G<W1R(")!<&QI
M8V%R(&$@<F5C=7)S;W,@8V]M<&%R=&ED;W,@9&5S8V5N9&EE;G1E<R(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!
M<'!R;W9E(@IM<V=S='(@(D%P<F]B87(B"@HC.B!L:6(O2&]R9&4O34E-12]#
M;VYT96YT<RYP:'`Z.#0R"FUS9VED(")!<'!R;WAI;6%T92!3:7IE(@IM<V=S
M='(@(E1A;6'Q;R!A<')O>&EM861O(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P-2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(D%B<FEL(@H*(SH@
M8V]N9FEG+RYB86LO;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B07)A8FEC("A7
M:6YD;W=S+3$R-38I(@IM<V=S='(@(D%RX6)I9V\@*%=I;F1O=W,M,3(U-BDB
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HU.2!L:6(O2&]R
M9&4O34E-12]6:65W97(O=&=Z+G!H<#HW.`HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O>FEP+G!H<#HV-@IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS
M9W-T<B`B5&%M8?%O(&1E;"!A<F-H:79O(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-3@@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-S<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*;7-G
M:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R(").;VUB<F4@9&5L(&%R8VAI=F\B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$P
M"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T
M;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@
M(K]%<W1A('-E9W5R;R!D92!Q=64@9&5S96$@96QI;6EN87(@;&$@<V]L:6-I
M='5D(&1E(&%L=&$@9&4@)7,_(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]D96QE=&4N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S
M=7)E('EO=2!W:7-H('1O(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O
M=7!S/R(*;7-G<W1R("*_17-TX2!S96=U<F\@9&4@<75E(&1E<V5A(&5L:6UI
M;F%R(%PB)7-<(B!Y('1O9&]S('-U<R!S=6)G<G5P;W,_(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-@IM<V=I9"`B07)G
M96YT:6YA(@IM<V=S='(@(D%R9V5N=&EN82(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C4W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(*;7-G:60@(D%R;65N:6$B"FUS
M9W-T<B`B07)M96YI82(*"B,Z(&-O;F9I9R\N8F%K+VYL<RYP:'`N9&ES=#HQ
M-SD*;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@(D%R;65N
M:6\@*$%235-#24DM."DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*
M;7-G:60@(D%R="(*;7-G<W1R(")!<G1E(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,`IM<V=I9"`B07)U8F$B"FUS9W-T
M<B`B07)U8F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34*;7-G:60@
M(D%S8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B27-L82!!<V-E;G-I\VXB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*
M;7-G<W1R(")'<N%F:6-O<R!!<V-I:2(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C4U"FUS9VED(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@
M(E)E9VGS;B!D92!!<VEA+U!A8^UF:6-O(@H*(SH@8V]N9FEG+RYB86LO<')E
M9G,N<&AP+F1I<W0Z-#(Y"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B
M969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`B
M(@HBOU-O;&EC:71A<B!C;VYF:7)M86-I\VX@86YT97,@9&4@<F5A;&EZ87(@
M;W!E<F%C:6]N97,@9&4@;6%N=&5N:6UI96YT;S\B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,S`Y-0IM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S
M='(@(D-O;'5M;F%S(&1E(&%S:6=N86-I\VXB"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C<T"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N
M="!G<F]U<"XB"FUS9W-T<B`B26YT96YT82!E;&EM:6YA<B!U;B!G<G5P;R!I
M;F5X:7-T96YT92XB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C(Y"FUS
M9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S
M:6]N+B(*;7-G<W1R("));G1E;G1A(&5L:6UI;F%R('5N('!R:79I;&5G:6\@
M:6YE>&ES=&5N=&4N(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*;7-G
M:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N
M+B(*;7-G<W1R("));G1E;G1A(&UO9&EF:6-A<B!U;B!P<FEV:6QE9VEO(&EN
M97AI<W1E;G1E+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM
M<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(*
M;7-G<W1R("));G1E;G1A(&UO9&EF:6-A<B!U;B!R96-U<G-O(&-O;7!A<G1I
M9&\@:6YE>&ES=&5N=&4N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C0@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#,*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*;7-G:60@(D%T=')I
M8G5T97,B"FUS9W-T<B`B071R:6)U=&]S(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P.2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R(")!9V]S=&\B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Y
M"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B075S=')A;&EA(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR.`IM<V=I9"`B
M075S=')I82(*;7-G<W1R(")!=7-T<FEA(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M8WER<W%L+G!H<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I
M;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER<W%L
M.B!.;R!S92!E;F-O;G1R\R!L82!E>'1E;G-I\VX@:6UA<"!N96-E<V%R:6$N
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$S-0IM<V=I9"`B075T
M:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B
M:6QI=&5S+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!%;"!M;W1O<B!C87)E8V4@
M9&4@;&%S(&-A<&%C:61A9&5S(&YE8V5S87)I87,N(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER
M960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y
M<G5S.B!.;R!S92!E;F-O;G1R\R!L82!E>'1E;G-I\VX@:6UA<"!N96-E<V%R
M:6$N(@H*(SH@;&EB+TAO<F1E+T%U=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB
M075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#
M;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*
M;7-G<W1R("(B"B)!=71H7V9T<#H@3F\@<V4@96YC;VYT<O,@;&$@97AT96YS
M:?-N($944"!N96-E<V%R:6$N($-O;7!I;&4@4$A0(&-O;B!L82`B"B)O<&-I
M\VX@+2UE;F%B;&4M9G1P+B(*"B,Z(&QI8B](;W)D92]!=71H+VEM87`N<&AP
M.C8T"FUS9VED(")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]I;6%P.B!.;R!S92!E;F-O;G1R
M\R!L82!E>'1E;G-I\VX@24U!4"!N96-E<V%R:6$N(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q=6ER960@
M:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VMR8C4Z
M($YO('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!K<F(U(&YE8V5S87)I82XB
M"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?
M;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV
M92!$:7)E8W1O<GDB"FUS9W-T<B`B(@HB075T:%]L9&%P.B!.;R!E<W3A('-O
M<&]R=&%D82!L82!A9&EC:?-N(&1E('5S=6%R:6]S(&1E($%C=&EV92!$:7)E
M8W1O<GDB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS-3<*;7-G:60@
M(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F
M;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"B)!=71H7VQD87`Z($YO
M(&5S=.$@<V]P;W)T861A(&QA(&5L:6UI;F%C:?-N(&1E('5S=6%R:6]S(&1E
M($%C=&EV92!$:7)E8W1O<GDB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H
M<#HV,PIM<V=I9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;&1A<#H@3F\@<V4@96YC;VYT
M<O,@;&$@97AT96YS:?-N($Q$05`@;F5C97-A<FEA+B(*"B,Z(&QI8B](;W)D
M92]!=71H+VQD87`N<&AP.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H
M7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H
M92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*(D%U=&A?;&1A<#H@3F\@<V4@
M<'5E9&4@8?%A9&ER(&5L('5S=6%R:6\@)7,N(,ES=&\@97,@;&\@<75E(&1I
M:F\@96P@(@HB<V5R=FED;W(Z("(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N
M<&AP.C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L
M92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z($EN8V%P
M87H@9&4@96QI;6EN87(@96P@=7-U87)I;R`E<R(*"B,Z(&QI8B](;W)D92]!
M=71H+VQD87`N<&AP.C0Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD
M87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD
M87`Z($EN8V%P87H@9&4@86-T=6%L:7IA<B!E;"!U<W5A<FEO("5S(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-#`U"FUS9VED(")!=71H7VQD87`Z
M(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$
M:7)E8W1O<GDN(@IM<V=S='(@(B(*(D%U=&A?;&1A<#H@3F\@97-TX2!S;W!O
M<G1A9&$@;&$@86-T=6%L:7IA8VGS;B!D92!U<W5A<FEO<R!D92!!8W1I=F4@
M1&ER96-T;W)Y(@H*(SH@;&EB+TAO<F1E+T%U=&@O;6-A;"YP:'`Z-#8*;7-G
M:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R(")!=71H7VUC86PZ($YO('-E(&5N8V]N='+S(&QA(&5X
M=&5N<VGS;B!-0T%,(&YE8V5S87)I82XB"@HC.B!L:6(O2&]R9&4O075T:"]S
M;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U
M=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]S;6)A=71H
M.B!.;R!S92!E;F-O;G1R\R!L82!E>'1E;G-I\VX@<VUB875T:"!N96-E<V%R
M:6$N(@H*(SH@;&EB+TAO<F1E+TE-05`O061M:6XN<&AP.C$P-@IM<V=I9"`B
M075T:&5N=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+B(*;7-G<W1R
M(")&86QL\R!L82!A=71E;G1I9FEC86-I\VX@8V]N(&5L('-E<G9I9&]R($E-
M05`N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*
M;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R(")&86QL\R!L
M82!A=71E;G1I9FEC86-I\VXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C8W(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D
M+B`E<R(*;7-G<W1R(")&86QL\R!L82!A=71E;G1I9FEC86-I\VXN("5S(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O<F%D:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE
M;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S='(@
M(D5L('-E<G9I9&]R(%)!1$E54R!H82!R96-H87IA9&\@;&$@875T96YT:69I
M8V%C:?-N+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX.34*;7-G:60@(D%U=&AE
M;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")&86QL
M\R!L82!A=71E;G1I9FEC86-I\VX@8V]N(&5L('-E<G9I9&]R($944"XB"@HC
M.B!L:6(O5D93+W-M8BYP:'`Z-S`*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O
M('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B1F%L;/,@;&$@875T
M96YT:69I8V%C:?-N(&-O;B!E;"!S97)V:61O<B!334(N(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD
M<SHB"FUS9W-T<B`B0V%M<&]S(&1I<W!O;FEB;&5S.B(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C4Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S$*;7-G:60@(D%Z97)B
M86EJ86XB"FUS9W-T<B`B07IE<F)A:6IA;B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS,`IM<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(D5X8W5S
M87,@0D]&2"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`B1F]N
M9&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(D-O;&]R(&1E
M(&9O;F1O(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z.#$*;7-G:60@
M(D)A9"!K97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`B0V]N=')A<V7Q82!K
M97)B97)O<R!I;F-O<G)E8W1A+B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N
M<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@
M(DYO;6)R92!D92!U<W5A<FEO(&ME<F)E<F]S(&EN8V]R<F5C=&\N(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-0IM<V=I
M9"`B0F%H86UA<R(*;7-G<W1R(")"86AA;6%S(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(W
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS.`IM<V=I9"`B0F%H<F%I;B(*
M;7-G<W1R(")"86AR86EN(@H*(SH@8V]N9FEG+RYB86LO;FQS+G!H<"YD:7-T
M.C$X,`IM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B0N%L
M=&EC;R`H25-/+3@X-3DM,3,I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HS-`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R
M(")"86YG;&%D97-H(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HS,PIM<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B0F%R8F%D
M;W,B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F
M;W5N9"XB"FUS9W-T<B`B3F\@<V4@96YC;VYT<O,@96P@9&ER96-T;W)I;R!B
M87-E(&1E(&EMX6=E;F5S(%PB)7-<(BXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<S"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*;7-G:60@(D)A<V5L:6YE
M(@IM<V=S='(@(DSM;F5A(&)A<V4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C0Y"FUS9VED(")"96QA<G5S(@IM<V=S='(@
M(D)E;&%R=7,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C,U"FUS9VED(")"96QG:75M(@IM<V=S='(@(D+I;&=I8V$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4P"FUS
M9VED(")"96QI>F4B"FUS9W-T<B`B0F5L:7IE(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,S
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,`IM<V=I9"`B0F5N:6XB"FUS
M9W-T<B`B0F5N:6XB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C0Q"FUS9VED(")"97)M=61A(@IM<V=S='(@(D)E<FUU9&%S
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C,U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT
M-@IM<V=I9"`B0FAU=&%N(@IM<V=S='(@(D)H=71A;B(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")":7)T:&1A>2(*
M;7-G<W1R(")#=6UP;&5A\6]S(@H*(SH@;&EB+TAO<F1E+T)L;V-K+T-O;&QE
M8W1I;VXN<&AP.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S
M7"(@;V8@87!P;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B
M3F\@<V4@96YC;VYT<O,@96P@8FQO<75E(%PB)7-<(B!D92!L82!A<&QI8V%C
M:?-N(%PB)7-<(BXB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M.3`*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(D]P8VEO;F5S(&1E
M(&)L;W%U92(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM
M<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R(")4:7!O(&1E(&)L;W%U92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.`IM<V=I
M9"`B0F]L9"(*;7-G<W1R(").96=R:71A(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,PIM<V=I9"`B0F]L:79I82(*;7-G
M<W1R(")";VQI=FEA(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I
M<W0Z,C`W"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`B36%R8V%D;W)E<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C`*;7-G:60@(D)O<F1E<B(*;7-G<W1R(")";W)D92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O
M<F1E<B!T:&EC:VYE<W,Z(@IM<V=S='(@(D=R;W-O<B!D96P@8F]R9&4Z(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR,0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R(")";W)D97,B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,R"FUS9VED(")"
M;W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(D)O<VYI82!(97)Z96=O
M=FEN82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T
M:"(*;7-G<W1R(")!;6)O<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-#@*;7-G:60@(D)O='-W86YA(@IM<V=S='(@(D)O
M='-W86YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(R"FUS9VED(")";W1T;VTB"FUS9W-T<B`B26YF97)I;W(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,SD*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0W
M"FUS9VED(")";W5V970@27-L86YD(@IM<V=S='(@(DES;&$@9&4@0F]U=F5T
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C0P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT
M-`IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(D)R87-I;"(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HT,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$W"FUS9VED(")"<FET
M:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B5&5R<FET;W)I
M;R!O8V7A;FEC;R!D92!L82!);F1I82!B<FETX6YI8V$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0R"FUS9VED(")"<G5N
M96D@1&%R=7-S86QA;2(*;7-G<W1R(")"<G5N96D@1&%R=7-S86QA;2(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HT,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S<*;7-G
M:60@(D)U;&=A<FEA(@IM<V=S='(@(D)U;&=A<FEA(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T
M960@3&ES="(*;7-G<W1R("),:7-T82!D97-O<F1E;F%D82(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HT-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S8*;7-G:60@(D)U
M<FMI;F$@1F%S;R(*;7-G<W1R(")"=7)K:6YA($9A<V\B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,Y"FUS9VED(")"=7)U
M;F1I(@IM<V=S='(@(D)U<G5N9&DB"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R
M>2YP:'`N9&ES=#HT-#8*;7-G:60@(D--4R(*;7-G<W1R(")#35,B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM
M<V=S='(@(D-20R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DX
M"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R(")0=6YT
M;W,@9&4@9&ES=')I8G5C:?-N($-20R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-PIM<V=I9"`B0U]E;&P@
M4')O<&5R=&EE<RXN+B(*;7-G<W1R(")0<F]P:65D861E<R!D92!?8V5L9&$N
M+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Q"FUS9VED
M(")#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R(").;R!S
M92!H82!F:6YA;&EZ861O(&5L(&EN:6-I;R!D92!L82!C86-HZ2XB"@HC.B!L
M:6(O2&]R9&4O2V]L86(N<&AP.CDQ-B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#@U"B,Z(&-O;F9I9R\N8F%K+VAO;VMS+G!H<"YD:7-T
M.C$P-#`@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z,34W"FUS9VED
M(")#86QE;F1A<B(*;7-G<W1R(")!9V5N9&$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C,U"FUS9VED(")#86QM(@IM<V=S='(@(D-A;&UA
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C0V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,C@*;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@(D-A;6)O>6$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8P"FUS9VED(")#
M86UE<F]O;B(*;7-G<W1R(")#86UE<OIN(@H*(SH@;&EB+U9&4R]F:6QE+G!H
M<#HR,S(@;&EB+U9&4R]F='`N<&AP.C8W-B!L:6(O5D93+W-M8BYP:'`Z-#,U
M"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(P,PIM<V=I9"`B0V%N(&YO="!C
M;W!Y(&9I;&4H<RD@+2!S;W5R8V4@86YD(&1E<W1I;F%T:6]N(&%R92!T:&4@
M<V%M92XB"FUS9W-T<B`B(@HB3F\@<V4@<'5E9&4H;BD@8V]P:6%R(&5L+VQO
M<R!A<F-H:79O*',I("T@;W)I9V5N('D@9&5S=&EN;R!S;VX@96P@;6ES;6\N
M(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR,#(@;&EB+U9&4R]F='`N<&AP.C<U
M,B!L:6(O5D93+W-M8BYP:'`Z-3`Q"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP
M.C$V.`IM<V=I9"`B0V%N(&YO="!M;W9E(&9I;&4H<RD@+2!D97-T:6YA=&EO
M;B!I<R!W:71H:6X@<V]U<F-E+B(*;7-G<W1R("(B"B).;R!S92!P=65D92AN
M*2!T<F%S;&%D87(@96PO;&]S(&%R8VAI=F\H<RD@+2!E;"!D97-T:6YO(&5S
M=.$@9&5N=')O(&1E;"`B"B)O<FEG96XN(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@
M875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM
M<V=S='(@(B(*(DYO('-E('!U961E(')E86IU<W1A<B!L82!C;&%V92!A=71O
M;>%T:6-A;65N=&4L('#S;F=A<V4@96X@8V]N=&%C=&\@8V]N(&5L("(*(F%D
M;6EN:7-T<F%D;W(@9&5L('-I<W1E;6$N(@H*(SH@;&EB+T9I;&4O0U-6+G!H
M<#HS-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W<FET92!T;R!F
M:6QE(%PB)7-<(B(*;7-G<W1R(").;R!S92!P=65D92!E<V-R:6)I<B!E;B!E
M;"!A<F-H:79O(%PB)7-<(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,@IM
M<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L
M97)S+B(*;7-G<W1R(").;R!S92!P=65D96X@861M:6YI<W1R87(@;6%N96IA
M9&]R97,@9&4@<V5S:?-N(&5X=&5R;F]S+B(*"B,Z(&QI8B](;W)D92]!=71H
M+V-Y<G-Q;"YP:'`Z,S$Y(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HR,S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E
M<G9E<CH@)7,B"FUS9W-T<B`B3F\@<V4@<'5E9&4@8V]N96-T87(@86P@<V5R
M=FED;W(@24U!4#H@)7,B"@HC.B!L:6(O1FEL92]#4U8N<&AP.C0T-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#86XG="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G
M<W1R(").;R!S92!P=65D92!A8G)I<B!E;"!A<F-H:79O(%PB)7-<(BXB"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4Q"FUS
M9VED(")#86YA9&$B"FUS9W-T<B`B0V%N863A(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M8VQE87(N:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI
M;F,Z,3(@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q"FUS
M9VED(")#86YC96PB"FUS9W-T<B`B0V%N8V5L87(B"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@
M4F5P;W)T(@IM<V=S='(@(D-A;F-E;&%R(&EN9F]R;64@9&4@<')O8FQE;6%S
M(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,R,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").;R!S92!P
M=65D92!E;&EM:6YA<B!E;"!A<F-H:79O(%PB)7-<(BXB"@HC.B!L:6(O5D93
M+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*(SH@
M;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M-#8*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B3F\@<V4@96YC=65N=')A('5N(&1I<F5C=&]R:6\@=&5M<&]R
M86PN(@H*(SH@;&EB+U9&4R])4T]7<FET97(N<&AP.CDQ"FUS9VED(")#86YN
M;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N(@IM
M<V=S='(@(DYO('-E('!U961E(&-O;G1I;G5A<B!S:6X@96P@<&%RX6UE=')O
M("=T87)G971&:6QE)RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,S$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<
M(BXB"FUS9W-T<B`B3F\@<V4@<'5E9&4@96QI;6EN87(@96P@9&ER96-T;W)I
M;R!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T1A=&%4<F5E+G!H<#HQ,C@@;&EB
M+TAO<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L('!H<"UF;W)M870*;7-G
M:60@(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R
M(").;R!S92!P=65D92!E;&EM:6YA<BP@=&EE;F4@)60@9&5S8V5N9&EE;G1E
M<RXB"@HC.B!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HV,#@*;7-G:60@
M(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE
M9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D
M+B(*;7-G<W1R("(B"B).;R!S92!P=65D92!R96]R9&5N87(L(&5L(&[Z;65R
M;R!D92!E;G1R861A<R!Q=64@<V4@9&5S96$@;W)D96YA<B!N;R`B"B)C;VEN
M8VED92!C;VX@;&%S(&%L;6%C96YA9&%S+B(*"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@<F]U=&4@;65S
M<V%G92!T;R!S<&5C:69I960@;G5M8F5R+B(*;7-G<W1R(").;R!S92!P=65D
M92!D:7)I9VER(&5L(&UE;G-A:F4@86P@;OIM97)O(&5S<&5C:69I8V%D;RXB
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8U
M"FUS9VED(")#87!E(%9E<F1E(@IM<V=S='(@(D-A8F\@5F5R9&4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T
M"FUS9VED(")#87!T:6]N(@IM<V=S='(@(E-U8G3M='5L;R(*"B,Z(&QI8B].
M970O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`T"FUS9VED(")#87)R:65R(@IM
M<V=S='(@(E!R;W9E961O<B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD
M:7-T.CDS"FUS9VED(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`B
M0V%T96=O<NUA<R!Y(&5T:7%U971A<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,U"FUS9VED(")#87EM86X@27-L86YD
M<R(*;7-G<W1R("))<VQA<R!#86EMX6XB"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L;"!0:&]N92(*;7-G<W1R
M(")496SI9F]N;R!M\W9I;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*;7-G:60@(D-E;&P@4')O<&5R=&EE
M<R(*;7-G<W1R(")0<F]P:65D861E<R!D92!C96QD82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL
M('!A9&1I;F<Z(@IM<V=S='(@(DUA<F=E;B!D92!C96QD83HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Q"FUS
M9VED(")#96QL('!R;W!E<G1I97,B"FUS9W-T<B`B4')O<&EE9&%D97,@9&4@
M8V5L9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R(")%<W!A8VEA
M9&\@9&4@8V5L9&$Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-S0*;7-G
M:60@(D-E;&QP:&]N92(*;7-G<W1R(")496SI9F]N;R!M\W9I;"(*"B,Z(&-O
M;F9I9R\N8F%K+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-E;'1I8R`H25-/
M+3@X-3DM,30I(@IM<V=S='(@(D/I;'1I8V\@*$E33RTX.#4Y+3$T*2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R(")#96YT<F%R(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C4Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-`IM<V=I9"`B0V5N
M=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@(E)E</IB;&EC82!#96YT
M<F]A9G)I8V%N82(*"B,Z(&-O;F9I9R\N8F%K+VYL<RYP:'`N9&ES=#HQ.#(*
M;7-G:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@
M(D5U<F]P82!#96YT<F%L("A)4T\M.#@U.2TR*2(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED(")#97)T:69I8V%T92!$971A:6QS
M(@IM<V=S='(@(D1E=&%L;&5S(&1E;"!C97)T:69I8V%D;R(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-C$R"FUS9VED(")#97)T:69I8V%T92!/
M=VYE<B(*;7-G<W1R(")0<F]P:65T87)I;R!D96P@8V5R=&EF:6-A9&\B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B0V5R=&EF
M:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B4&]L[71I8V%S(&1E;"!C97)T:69I
M8V%D;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P."!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(R,0IM<V=I9"`B0VAA9"(*;7-G<W1R(")#:&%D(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHY-@IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(D-A;6)I87(B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*;7-G:60@(D-H86YG
M92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(D-A;6)I92!L82!C;VYT<F%S9?%A
M(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z-CD*;7-G:60@(B(*
M(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@
M=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS+B(*
M;7-G<W1R("(B"B)#86UB:6$@96P@;F]M8G)E('D@;&$@9&ER96-C:?-N(&5L
M96-T<O-N:6-A('9I<VEB;&5S(&%L(&QE97(@;R!R97-P;VYD97(@82`B"B)S
M=7,@;65N<V%J97,N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C(T"FUS9VED("(B"B)#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S
M=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB
M0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(DQA(&-O
M;F9I9W5R86-I\VX@86-T=6%L(&YO('-O<&]R=&$@96P@8V%M8FEO(&1E(&-O
M;G1R87-E\6%S+B!0\VYG87-E(&5N("(*(F-O;G1A8W1O(&-O;B!E;"!A9&UI
M;FES=')A9&]R(&1E;"!S:7-T96UA+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*;7-G:60@(D-H87(B"FUS
M9W-T<B`B1W+A9FEC;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB
M"FUS9W-T<B`B5F5R:69I8V%R(%]V[6YC=6QO+BXN(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C4S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU.0IM<V=I9"`B0VAI;&4B
M"FUS9W-T<B`B0VAI;&4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C8Q"FUS9VED(")#:&EN82(*;7-G<W1R(")#:&EN82(*
M"B,Z(&-O;F9I9R\N8F%K+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(D-H:6YE
M<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R(")#:&EN;R!S:6UP;&EF
M:6-A9&\@*$=",C,Q,BDB"@HC.B!C;VYF:6<O+F)A:R]N;',N<&AP+F1I<W0Z
M,3@T"FUS9VED(")#:&EN97-E(%1R861I=&EO;F%L("A":6<U*2(*;7-G<W1R
M(")#:&EN;R!T<F%D:6-I;VYA;"`H0FEG-2DB"@HC.B!T96UP;&%T97,O<')E
M9G,O87!P+FEN8SHW"FUS9VED(")#:&]O<V4@07!P;&EC871I;VXZ(@IM<V=S
M='(@(D%P;&EC86-I\VXZ(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H
M<#HR-S`*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(D5L:6IA
M('5N82!C;VYT<F%S9?%A(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H
M<#HR-CD*;7-G:60@(D-H;V]S92!A('5S97)N86UE(@IM<V=S='(@(D5L:6IA
M('5N(&YO;6)R92!D92!U<W5A<FEO(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N
M<&AP+F1I<W0Z,S`R"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T
M97,Z(@IM<V=S='(@(D5L:6IA(&/S;6\@;6]S=')A<B!L87,@9F5C:&%S.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA
M;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O
M<F1E<F5D(&QI<W1S*2(*;7-G<W1R(")396QE8V-I;VYA<B!T:7!O(&1E(&5S
M=&EL;R!D92!L:7-T82`H<&%R82!L:7-T87,@;W)D96YA9&%S*2(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8X(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HU-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C8*;7-G:60@
M(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B27-L82!D92!087-C=6$B"@HC
M.B!L:6(O5D93+G!H<#HY,30@;&EB+TYE="]335,N<&AP.C(Y-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N
M9"XB"FUS9W-T<B`B3F\@<V4@96YC;VYT<O,@;&$@9&5F:6YI8VGS;B!D92!C
M;&%S92!D92`E<RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ-`IM<V=I9"`B0VQE87(B"FUS9W-T<B`B3&EM<&EA<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G
M:60@(D-L96%R($U33V9F:6-E('1A9W,B"FUS9W-T<B`B16QI;6EN87(@971I
M<75E=&%S($U33V9F:6-E(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.0IM
M<V=I9"`B0VQE87(@475E<GDB"FUS9W-T<B`B0F]R<F%R(&-O;G-U;'1A(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM<V=S='(@(D)O<G)A
M<B!U<W5A<FEO.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R
M+FEN8SHQ,0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R(")";W)R87(@=7-U
M87)I;R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T"FUS
M9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`B0F]R<F%R(&1A=&]S(&1E
M;"!U<W5A<FEO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,34*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B1&5S<&5J
M861O('1A<F3M;R(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N
M86YC92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R
M(")(86=A(&-L:6-K('!A<F$@<V5G=6ER(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A4
M5%`B"FUS9W-T<B`B0VQI8VMA=&5L;"!P;W(@2%144"(*"B,Z('-E<G9I8V5S
M+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(D-E<G)A<B!V96YT86YA
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3$*;7-G:60@(D-L;W5D<R(*
M;7-G<W1R(").=6)E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C$V"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`B3G5B
M97,@=&5M<')A;F%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3<*;7-G:60@(D-L;W5D>2(*;7-G<W1R(")N=6)O<V\B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-38*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4R"FUS
M9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R("))<VQA<R!D
M92!C;V-O<R`H2V5E;&EN9RDB"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B
M87(N:6YC.C(S"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@(D]C
M=6QT87(@8F%R<F$@;&%T97)A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B
M;W)D97)S(@IM<V=S='(@(D-O;&%P<V%R(&)O<F1E<R(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HU-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C(*;7-G:60@(D-O;&]M
M8FEA(@IM<V=S='(@(D-O;&]M8FEA(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H
M<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R
M(@IM<V=S='(@(D-O;&]R(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C4P,R!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z
M,S,X"B,Z(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HS,SD@<V5R
M=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,@IM<V=I9"`B0V]L;W(@
M4&EC:V5R(@IM<V=S='(@(E-E;&5C=&]R(&1E(&-O;&]R(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(X,C@*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS
M9W-T<B`B4V5L96-C:?-N(&1E(&-O;&]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S
M='(@(D-O;'5M;F%S.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.30V"FUS
M9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S='(@(E3M='5L;W,@9&4@;&%S(&-O
M;'5M;F%S(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z,C8V
M"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B0_-M:6-S(@H*(SH@861M:6XO8VUD
M<VAE;&PN<&AP.C(V"FUS9VED(")#;VUM86YD(@IM<V=S='(@(D-O;6%N9&\B
M"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE
M;&PB"FUS9W-T<B`B26YTZ7)P<BX@8V]M86YD;W,B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B0V]M
M96YT87)I;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-38W"FUS
M9VED(")#;VUM;VX@3F%M92(*;7-G<W1R(").;VUB<F4@8V]M^FXB"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,`IM<V=I
M9"`B0V]M;W)O<R(*;7-G<W1R(")#;VUO<F]S(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@(D-O;7!A;GDB"FUS9W-T
M<B`B0V]M<&'Q[6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S$*;7-G
M:60@(D-O;7!U=&5R<R(*;7-G<W1R(")/<F1E;F%D;W)E<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#8*;7-G:60@(D-O;F1I=&EO;B(*
M;7-G<W1R(")#;VYD:6-I\VXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U
M-@IM<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R(")#;VYD:6-I;VYE<R(*"B,Z
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N
M($1I9F9E<F5N8V5S(@IM<V=S='(@(D1I9F5R96YC:6%S(&1E(&QA(&-O;F9I
M9W5R86-I\VXB"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HQ-#8*
M;7-G:60@(D-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3
M;6%R='!H;VYE<R!A;F0@3W5T;&]O:RXB"FUS9W-T<B`B(@HB0V]N9FEG=7)A
M8VGS;B!P87)A('-I;F-R;VYI>F%C:?-N(&-O;B!01$%S+"!-\W9I;&5S(&-O
M;B!A9V5N9&$@>2!/=71L;V]K+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ,S0*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM
M<V=S='(@(DQA(&-O;F9I9W5R86-I\VX@97-TX2!D97-A8W1U86QI>F%D82XB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`P"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R(")#;VYF:6=U<F%R("5S(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,0IM<V=I9"`B
M0V]N9FER;2!087-S=V]R9"(*;7-G<W1R(")#;VYF:7)M87(@8V]N=')A<V7Q
M82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-34*;7-G:60@(D-O;F=O(@IM<V=S='(@(D-O;F=O(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C8P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,PIM<V=I9"`B0V]N9V\L
M(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R(")#;VYG
M;RP@4F5P^F)L:6-A($1E;6]C<N%T:6-A(&1E;"(*"B,Z(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3<@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,P.`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960N(@IM<V=S
M='(@(D9A;&SS(&QA(&-O;F5X:?-N+B(*"B,Z(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HQ.3<@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,P.`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("(*;7-G<W1R(")&
M86QL\R!L82!C;VYE>&GS;CH@(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z-SDP"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI
M8R!K97ES97)V97(N(@IM<V=S='(@(E-E(&AA(')E8VAA>F%D;R!L82!C;VYE
M>&GS;B!A;"!S97)V:61O<B!D92!C;&%V97,@</IB;&EC;RXB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!2
M96%S;VXZ("5S("@E<RDB"FUS9W-T<B`B(@HB4V4@:&$@<F5C:&%Z861O(&QA
M(&-O;F5X:?-N(&%L('-E<G9I9&]R(&1E(&-L879E<R!P^F)L:6-O+B!-;W1I
M=F\Z("5S("@E<RDB"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#@Y"FUS9VED(")#
M;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")(82!F
M86QL861O(&QA(&-O;F5X:?-N(&%L('-E<G9I9&]R($944"XB"@HC.B!L:6(O
M2&]R9&4O2V]L86(N<&AP.CDR-"!C;VYF:6<O+F)A:R]H;V]K<RYP:'`N9&ES
M=#HQ,#8W"FUS9VED(")#;VYT86-T<R(*;7-G<W1R(")#;VYT86-T;W,B"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C4S"FUS9VED(")#
M;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E
M<W,@8F]O:RXB"FUS9W-T<B`B4V4@:&%N(&'Q861I9&\@8V]R<F5C=&%M96YT
M92!L;W,@8V]N=&%C=&]S(&$@<W5S(&1I<F5C8VEO;F5S(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-C`*;7-G:60@(D-O;G1E;G0@='EP
M92!O9B!C;VUP<F5S<V5D(&9I;&4Z("(*;7-G<W1R(")4:7!O(&1E(&-O;G1E
M;FED;R!D96P@87)C:&EV;R!C;VUP<FEM:61O.B`B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O<F%R+G!H<#HU-B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=&=Z+G!H<#HW-0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O9B!<(B5S7"(B"FUS
M9W-T<B`B0V]N=&5N:61O(&1E(%PB)7-<(B(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HS,R!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR
M.0IM<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`B0V]N=&EN=6%R(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C8Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU.`IM<V=I9"`B
M0V]O:R!)<VQA;F1S(@IM<V=S='(@(DES;&%S($-O;VLB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R(")#;V]K
M:64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B0V]P:6%R(@H*(SH@
M;&EB+U9&4R]S;6(N<&AP.C0X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y
M(&9A:6QE9#H@)7,B"FUS9W-T<B`B1F%L;/,@;&$@8V]P:6$Z("5S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I
M9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B0V]P:6%R('-E;&5C8VGS;B(*
M"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ-S`@;&EB+TYE="]335,O
M=VEN7VAT='`N<&AP.C$Y-0IM<V=I9"`B0V]S="!)1"(*;7-G<W1R("))1"!D
M92!C;W-T92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-C,*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B0V]S=&$@4FEC
M82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-3<*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B0V]S=&$@9&4@36%R
M9FEL(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.3<W"FUS9VED(")#
M;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@(@IM<V=S='(@(DYO('-E
M('!U961E(&-I9G)A<B!E;"!M96YS86IE(&UE9&EA;G1E(%!'4#H@(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3`U-0IM<V=I9"`B0V]U;&0@;F]T
M(%!'4"!S:6=N(&UE<W-A9V4Z("(*;7-G<W1R(").;R!S92!P=65D92!F:7)M
M87(@96P@;65N<V%J92!M961I86YT92!01U`Z("(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z,SDS"FUS9VED(")#;W5L9"!N;W0@4R]-24U%(&5N
M8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B3F\@<V4@<'5E9&4@8VEF<F%R(&5L
M(&UE;G-A:F4@;65D:6%N=&4@4R]-24U%(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD(&YO="!3+TU)344@<VEG;B!M
M97-S86=E+B(*;7-G<W1R(").;R!S92!P=65D92!F:7)M87(@96P@;65N<V%J
M92!M961I86YT92`@4R]-24U%(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C$X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M861D(&-O;G1A8W0N("5S(@IM<V=S='(@(DYO('-E('!U961E(&'Q861I<B!E
M;"!C;VYT86-T;RX@)7,B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#@R
M(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HY-@HC.B!L:6(O2&]R9&4O075T
M:"]L9&%P+G!H<#HQ,C$*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$05`@
M<V5R=F5R+B(*;7-G<W1R(").;R!S92!P=65D92!E;FQA>F%R(&%L('-E<G9I
M9&]R($Q$05`N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HQ-S,@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C$U-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B
M"FUS9W-T<B`B3F\@<V4@<'5E9&4@8V]M<')O8F%R(&5L('-A;&1O+B`E<R(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-C8*;7-G:60@(D-O=6QD(&YO
M="!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(").;R!S92!P=65D
M92!C;VYE8W1A<B!A;"!S97)V:61O<B!,1$%0+B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M8V]N;F5C="!T;R!S97)V97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS9W-T
M<B`B3F\@<V4@<'5E9&4@8V]N96-T87(@86P@<V5R=FED;W(@7"(E<UPB(&UE
M9&EA;G1E($944#H@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,S(R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A
M=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYO('-E('!U961E
M(&-R96%R(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS;BX@)7,B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,3(X"FUS9VED(")#;W5L9"!N;W0@9&5C
M<GEP="!01U`@9&%T83H@(@IM<V=S='(@(DYO('-E('!U961E;B!D97-C:69R
M87(@;&]S(&1A=&]S(%!'4#H@(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HU,C,*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A
M+B(*;7-G<W1R(").;R!S92!P=65D96X@9&5S8VEF<F%R(&QO<R!D871O<R!3
M+TU)344N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(T
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&-O;G1A
M8W0N("5S(@IM<V=S='(@(DYO('-E('!U961E(&5L:6UI;F%R(&5L(&-O;G1A
M8W1O+B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS
M-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3F\@<V4@<'5E9&4@96QI;6EN
M87(@;&$@;&ES=&$@9&4@9&ES=')I8G5C:?-N+B`E<R(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C,X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G
M<W1R("(B"B).;R!S92!P=65D92!E;&EM:6YA<B!E;"!G=6GS;B!D92!A8W1U
M86QI>F%C:?-N(&1E(&-O;F9I9W5R86-I\VX@7"(E<UPB+B(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.CDU,R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C,X,0IM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I
M96YT)W,@92UM86EL(&%D9')E<W,N(@IM<V=S='(@(DYO('-E('!U961E(&1E
M=&5R;6EN87)A(&QA(&1I<F5C8VGS;B!D92!C;W)R96\@9&5L(&1E<W1I;F%T
M87)I;RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S
M"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K
M+B(*;7-G<W1R(").;R!S92!P=65D92!T<F%E<B!L82!L:6)R971A(&1E(&1I
M<F5C8VEO;F5S(&-O;7!L971A+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HT.3,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T
M92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B3F\@<V4@<'5E9&4@=')A
M97(@;&$@;&ES=&$@9&4@9&ES=')I8G5C:?-N(&-O;7!L971A+B(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD
M(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@
M;&ES=',N(@IM<V=S='(@(DYO('-E('!U961E('1R865R(&QA(&QI<W1A(&-O
M;7!L971A(&1E(&QI<W1A<R!D92!D:7-T<FEB=6-I\VXN(@H*(SH@;&EB+U9&
M4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,Z(&QI8B]6
M1E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E<UPB
M+B(*;7-G<W1R(").;R!S92!P=65D92!C87)G87(@;&$@97-T<F%T96=I82!<
M(B5S7"(N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T
M96=Y+V1I<F5C="YP:'`Z,S`*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(DYO('-E('!U961E
M(&-R96%R(&5L(&1I<F5C=&]R:6\@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C<Q.0IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L
M:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`B3F\@<V4@<'5E
M9&4@;V)T96YE<B!L82!C;&%V92!P^F)L:6-A(&1E;"!S97)V:61O<B!D92!C
M;&%V97,N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z,3,Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B3F\@<V4@<'5E
M9&4@86)R:7(@7"(E<UPB('!A<F$@97-C<FEB:7(N(@H*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8W-PHC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z
M,C8R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*
M;7-G<W1R(").;R!S92!P=65D92!A8G)I<B`E<RXB"@HC.B!L:6(O2&]R9&4O
M36%I;G1E;F%N8V4N<&AP.C0R,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*;7-G<W1R
M(").;R!S92!P=65D92!A8G)I<B!E;"!M\V1U;&\@9&4@=&%R96%S(&1E(&UA
M;G1E;FEM:65N=&\@)7,B"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(").;R!S
M92!P=65D92!A8G)I<B!E;"!D:7)E8W1O<FEO(%PB)7-<(BXB"@HC.B!L:6(O
M2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,3$Q(&QI8B](;W)D92]'<F]U<"]L9&%P
M+G!H<#HQ-#0*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C(S-R!L:6(O
M2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-#<X"B,Z(&QI8B](;W)D92]'<F]U<"]L
M9&%P+G!H<#HU,38@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!L
M:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-C4V(&QI8B](;W)D92]'<F]U<"]L
M9&%P+G!H<#HV.3D*;7-G:60@(D-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S
M97)V97(N(@IM<V=S='(@(DYO('-E('!U961E(&QO8V%L:7IA<B!E;"!S97)V
M:61O<B!,1$%0+B(*"B,Z(&QI8B]61E,O3V)J96-T+G!H<#HR-#`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S='(@(DYO
M('-E('!U961E(&QE97(@)7,N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O
M<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE
M("(*(F1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N
M=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE
M<B!H96QP+B(*;7-G<W1R("(B"B).;R!S92!P=65D92!R97-T86)L96-E<B!L
M82!C;VYT<F%S9?%A(&1E;"!U<W5A<FEO('-O;&EC:71A9&\N(%!A<G1E(&1E
M(&QO<R`B"B)D971A;&QE<R!O('1O9&]S+"!S;VX@:6YC;W)R96-T;W,N(%!R
M=65B92!O=')A('9E>B!O('#S;F=A<V4@96X@8V]N=&%C=&\@8V]N("(*(F5L
M(&%D;6EN:7-T<F%D;W(@9&5L('-I<W1E;6$@<&%R82!MX7,@:6YF;W)M86-I
M\VXN(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P-R!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S,X"B,Z(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S4@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,X,0HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S@W"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S
M='(@(DYO('-E('!U961E(&]B=&5N97(@;&$@04-,+B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,B"FUS9W-T
M<B`B3F\@<V4@<'5E9&4@;V)T96YE<B!L82!L:6)R971A(&1E(&1I<F5C8VEO
M;F5S+B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT
M.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(").;R!S92!P=65D92!O8G1E
M;F5R(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS;BX@)7,B"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S
M(@IM<V=S='(@(DYO('-E('!U961E;B!O8G1E;F5R(&QA<R!L:7-T87,@9&4@
M9&ES=')I8G5C:?-N+B`E<R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HQ.3<@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q
M-PHC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(Q"FUS9VED
M(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM
M<V=S='(@(DYO('-E('!U961E;B!O8G1E;F5R(&QA<R!C87!A8VED861E<R!D
M96P@<V5R=FED;W(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"FUS
M9VED(")#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(DYO('-E('!U961E(')E<W1A=7)A<B!L82!C;VYF:6=U<F%C:?-N+B(*"B,Z
M(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP
M.CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<(B5S
M7"(N(@IM<V=S='(@(DYO('-E('!U961E(&5L:6UI;F%R(&5L(&1I<F5C=&]R
M:6\@7"(E<UPB+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(DYO('-E('!U961E(&=U87)D87(@;&$@8V]N9FEG
M=7)A8VGS;B!D92`E<RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3D*;7-G:60@(D-O=6QD(&YO="!S
M879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B3F\@<V4@<'5E
M9&4@9W5A<F1A<B!U;F$@8V]P:6$@9&4@;&$@8V]N9FEG=7)A8VGS;BXB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*
M;7-G<W1R(").;R!S92!P=65D92!G=6%R9&%R('5N82!C;W!I82!D92!L82!C
M;VYF:6=U<F%C:?-N.B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('-E='5P
M('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(B(*(DYO('-E
M('!U961E(&=U87)D87(@96P@9W5I\VX@9&4@86-T=6%L:7IA8VGS;B!D92!L
M82!C;VYF:6=U<F%C:?-N(&5N.B!<(B5S7"(N(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HV-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T
M<B`B3F\@<V4@<'5E9&4@9W5A<F1A<B!L82!C;W!I82`E<R!D92!L82!C;VYF
M:6=U<F%C:?-N+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I
M9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T
M:&4@(@HB;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@
M8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B
M(@HB3F\@<V4@<'5E9&4@9W5A<F1A<B!E;"!A<F-H:79O("5S(&1E(&-O;F9I
M9W5R86-I\VXN(%!U961E('5T:6QI>F%R('5N82!D92`B"B)L87,@;W!C:6]N
M97,@<&%R82!R97-T875R87(@96P@8_-D:6=O(&1E("5S(&\@8V]P:6%R(&UA
M;G5A;&UE;G1E(&$@)7,@96P@(@HB8_-D:6=O('-I9W5I96YT92XB"@HC.B!L
M:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ-#,*;7-G:60@(D-O=6QD(&YO="!S
M96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R(").;R!S92!P=65D92!B
M=7-C87(@96X@96P@<V5R=FED;W(@3$1!4"XB"@HC.B!L:6(O5D93+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB"FUS9W-T<B`B
M3F\@<V4@<'5E9&4@9&5S=FEN8W5L87(@7"(E<UPB+B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R(").;R!S
M92!P=65D92!A8W1U86QI>F%R(&5L(&-O;G1A8W1O+B`E<R(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B
M"FUS9W-T<B`B3F\@<V4@<'5E9&4@86-T=6%L:7IA<B!L82!L:7-T82!D92!D
M:7-T<FEB=6-I\VXN("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U
M<F%T:6]N(&9O<B!<(B5S7"(Z("5S(@IM<V=S='(@(DYO('-E('!U961E(&5S
M8W)I8FER(&QA(&-O;F9I9W5R86-I\VX@9&4@7"(E<UPB.B`E<R(*"B,Z(&-O
M;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C,W,`IM<V=I9"`B0V]U;&1N)W0@
M9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B
M87(@:7,@;W!E;BXB"FUS9W-T<B`B(@HB3F\@<V4@<'5E9&4@;&]C86QI>F%R
M(&5L('!A;F5L(&QA=&5R86P@9&4@36]Z:6QL82X@0V]M<')U96)E('%U92!E
M<W3I("(*(F%B:65R=&\N(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C$U-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG="!G
M:79E('5S97(@7"(E<UPB('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@
M9F]L9&5R(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@HB3F\@<V4@<'5E9&5N(&]T
M;W)G87(@86P@=7-U87)I;R!<(B5S7"(@;&]S('-I9W5I96YT97,@9&5R96-H
M;W,@<&%R82!L82`B"B)C87)P971A(%PB)7-<(CH@)7,B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,30Q.0IM<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@
M(E1E>'1O(&-O;G1A9&\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4W,`IM<V=I9"`B0V]U;G1R>2(*;7-G<W1R(")08>US(@H*(SH@8V]N9FEG
M+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z,C<U"FUS9VED(")#;W5R<V5S(@IM
M<V=S='(@(D-U<G-O<R(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I9"`B0W)E871E(@IM<V=S
M='(@(D-R96%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S
M='(@(D-R96$@=6X@=NUN8W5L;R(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N
M=&ET>7-E;&5C="YI;F,Z.30*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS
M9W-T<B`B0W)E87(B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.3(@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C4R"FUS9VED
M(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B0W)E87(@<W5B8V%R<&5T
M87,B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(T,`IM<V=I9"`B0W)E
M871O<B!097)M:7-S:6]N<R(*;7-G<W1R(")0<FEV:6QE9VEO<R!D92!C<F5A
M9&]R(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R,3(*;7-G:60@(D-R961I
M="!C87)D(&YU;6)E<B(*;7-G<W1R(").^FUE<F\@9&4@=&%R:F5T82!D92!C
M<NED:71O(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,#D*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B0W)O86-I82(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HV-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C0*;7-G
M:60@(D-U8F$B"FUS9W-T<B`B0W5B82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HR-@IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R("(T($9A<V5S
M(&%C='5A;&5S(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4P"FUS9VED(")#
M=7)R96YT(%-E<W-I;VYS(@IM<V=S='(@(E-E<VEO;F5S(&%C='5A;&5S(@H*
M(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I;64N<&AP.C,P
M"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T<B`B2&]R82!A8W1U86PB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-30*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@(E523"!A8W1U
M86PB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S4*;7-G:60@(D-U<G)E;G0@
M57-E<G,B"FUS9W-T<B`B57-U87)I;W,@86-T=6%L97,B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(U"FUS9VED(")#=7)R96YT(%=E871H97(B"FUS9W-T
M<B`B5&EE;7!O(&%C='5A;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-C0*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`B
M0V]N9&EC:?-N(&%C='5A;#H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G
M<W1R(")%<W1I;&\@86-T=6%L(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP
M+F1I<W0Z,3$Q"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K
M<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B4&5R<V]N86QI
M>F$@;&%S('1A<F5A<R!A(&5J96-U=&%R(&%L(&EN:6-I87(@<V5S:?-N(&5N
M("5S+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(D-O<G1A<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G
M:60@(D-U="!S96QE8W1I;VXB"FUS9W-T<B`B0V]R=&%R('-E;&5C8VGS;B(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HV-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C<*
M;7-G:60@(D-Y<')U<R(*;7-G<W1R(")#:&EP<F4B"@HC.B!C;VYF:6<O+F)A
M:R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*
M;7-G<W1R(")#:7+M;&EC;R`H2T])."U2*2(*"B,Z(&-O;F9I9R\N8F%K+VYL
M<RYP:'`N9&ES=#HQ.#8*;7-G:60@(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I
M(@IM<V=S='(@(D-I<NUL:6-O("A7:6YD;W=S+3$R-3$I(@H*(SH@8V]N9FEG
M+RYB86LO;FQS+G!H<"YD:7-T.C$X-PIM<V=I9"`B0WER:6QL:6,O56MR86EN
M:6%N("A+3TDX+54I(@IM<V=S='(@(D-I<NUL:6-O+U5C<F%N:6%N;R`H2T])
M."U5*2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-C@*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@(E)E</IB;&EC
M82!#:&5C82(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-3(@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S
M='(@(D1$(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R-S(*;7-G:60@(B(*
M(D133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA
M9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS9W-T<B`B(@HB1%-.
M("AV96$@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO97,O<&%C:V%G92YD
M871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*"B,Z(&QI8B](;W)D92]-86EN
M=&5N86YC92YP:'`Z-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(D1I87)I86UE
M;G1E(@H*(SH@861M:6XO9&%T871R964N<&AP.C8U"FUS9VED(")$871A5')E
M92!"<F]W<V5R(@IM<V=S='(@(L%R7V)O;"!D871O<R(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HS,C<P"FUS9VED(")$871A8F%S92!,;V]K=7`B"FUS9W-T
M<B`B0V]N<W5L=&$@9&4@;&$@8F%S92!D92!D871O<R(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,SDX(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N
M<&AP.C<R"FUS9VED(")$871E(@IM<V=S='(@(D9E8VAA(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G:60@(D1A=&4@4F5C
M96EV960B"FUS9W-T<B`B4V4@:&$@<F5C:6)I9&\@;&$@9F5C:&$B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C<X.0IM<V=I9"`B1&%T92!S96QE8W1I;VXB
M"FUS9W-T<B`B4V5L96-C:?-N(&1E(&9E8VAA(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(X,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S$Q"FUS9VED(")$87DB"FUS9W-T<B`B1.UA(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,V"FUS9VED
M(")$95]L971E($-O;'5M;B(*;7-G<W1R(")%7VQI;6EN87(@8V]L=6UN82(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3,@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$96-E
M;6)E<B(*;7-G<W1R(")$:6-I96UB<F4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V"FUS9VED(")$96-I
M;6%L(&YU;6)E<G,B"FUS9W-T<B`B3OIM97)O<R!D96-I;6%L97,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(P"FUS9VED
M(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`B4F5D=6-I<B!S86YG<F%D;R(*
M"B,Z(&QI8B]P<F5F<RYP:'`Z,3$W(&QI8B](;W)D92]0<F5F<R]522YP:'`Z
M,3@W"FUS9VED(")$969A=6QT(@IM<V=S='(@(E!O<B!O;6ES:?-N(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#4*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-S<*;7-G
M:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B0V]L;W(@<&]R(&]M:7-I\VXB
M"@HC.B!L:6(O2&]R9&4O261E;G1I='DN<&AP.CDV"FUS9VED(")$969A=6QT
M($ED96YT:71Y(@IM<V=S='(@(DED96YT:61A9"!P;W(@;VUI<VGS;B(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW-0IM<V=I9"`B1&5F875L="!3:&5L
M;"(*;7-G<W1R(")3:&5L;"!P;W(@;VUI<VGS;B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS,PIM<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`B1&5F
M:6YI8VEO;F5S(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW,2!L:6(O2&]R9&4O
M4&5R;7,N<&AP.C,R-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C0R,@HC.B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C0S.2!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C,V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,PHC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$Q-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.0HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z-S,*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.CDX('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,`IM<V=I9"`B1&5L
M971E(@IM<V=S='(@(B9N8G-P.T5L:6UI;F%R)FYB<W`[(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"FUS
M9VED(")$96QE=&4@0V5L;"(*;7-G<W1R(")%;&EM:6YA<B!C96QD82(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z,3DY(&%D;6EN+V=R;W5P<RYP:'`Z,C(W"FUS
M9VED(")$96QE=&4@1W)O=7`B"FUS9W-T<B`B16QI;6EN87(@9W)U<&\B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#D*;7-G:60@(D1E;&5T
M92!,;V<B"FUS9W-T<B`B16QI;6EN87(@<F5G:7-T<F\B"@HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C<W(&QI8B](;W)D92]097)M<R]522YP:'`Z,3`Q
M"FUS9VED(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R(")%;&EM:6YA<B!P
M<FEV:6QE9VEO(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP
M.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S='(@
M(D5L:6UI;F%R('D@=F%C:6%R(&UE;G-A:F5S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L
M971E(&-E;&PB"FUS9W-T<B`B16QI;6EN87(@8V5L9&$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8S"FUS9VED
M(")$96QE=&4@8V]L=6UN(@IM<V=S='(@(D5L:6UI;F%R(&-O;'5M;F$B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T
M:6YG(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R(")%;&EM:6YA<B!P;&%N
M=&EL;&%S(&%L=&5R;F%T:79A<R!E>&ES=&5N=&5S(@H*(SH@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S0S,30N<&AP.C4T"FUS9VED(")$96QE=&4@;65S<V%G
M97,B"FUS9W-T<B`B16QI;6EN87(@;65N<V%J97,B"@HC.B!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.C0R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@
M<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R(")%;&EM:6YA<B!P<FEV
M:6QE9VEO<R!D92!<(B5S7"(B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C0R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@
M9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T<B`B
MOT5L:6UI;F%R('!R:79I;&5G:6]S('!A<F$@7"(E<UPB('D@8W5A;'%U:65R
M('!R:79I;&5G:6\@9&5S8V5N9&EE;G1E/R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T
M92!R;W<B"FUS9W-T<B`B16QI;6EN87(@9FEL82(*"B,Z('1E;7!L871E<R]P
M<F5F<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S96QE
M8W1E9"!I9&5N=&ET>2(*;7-G<W1R(")%;&EM:6YA<B!I9&5N=&ED860@<V5L
M96-C:6]N861A(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP
M.C4S"FUS9VED(")$96QE=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B16QI;6EN
M87(@<W5B8V%R<&5T87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!T:&4@8W5R
M<F5N="!C;VQU;6XB"FUS9W-T<B`B16QI;6EN82!L82!C;VQU;6YA(&%C='5A
M;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O=R(*;7-G
M<W1R(")%;&EM:6YA(&QA(&9I;&$@86-T=6%L(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!S
M971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(E-E(&AA(&5L
M:6UI;F%D;R!E;"!G=6GS;B!D92!A8W1U86QI>F%C:?-N(&1E(&QA(&-O;F9I
M9W5R86-I\VX@7"(E<UPB+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C(Q(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C4S"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C,@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-0IM<V=I9"`B1&5L:79E
M<GD@=&EM92(*;7-G<W1R(")(;W)A(&1E(&5N=')E9V$Z(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C8X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,0IM<V=I9"`B1&5N
M;6%R:R(*;7-G<W1R(")$:6YA;6%R8V$B"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB
M"FUS9W-T<B`B1&5S8W)I8F$@96P@<')O8FQE;6$B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z.3,X('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S`*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(D1E
M<V-R:7!C:?-N(@H*(SH@;&EB+TAO<F1E+G!H<#HR,#8*;7-G:60@(D1E=&%I
M;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B1&5T86QL
M97,@*'1A;6)IZ6X@96X@96P@87)C:&EV;R!D92!R96=I<W1R;R!D92!(;W)D
M92DZ(@H*(SH@;&EB+TAO<F1E+G!H<#HR,3`*;7-G:60@(D1E=&%I;',@:&%V
M92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@
M(E-E(&AA;B!R96=I<W1R861O(&QO<R!D971A;&QE<R!P87)A(&5L(&%D;6EN
M:7-T<F%D;W(N(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z
M,C(Q"FUS9VED(")$979E;&]P;65N="(*;7-G<W1R(")$97-A<G)O;&QO(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C0*;7-G:60@(D1E=R!0;VEN="(*
M;7-G<W1R(")0=6YT;R!D92!C;VYD96YS86-I\VXB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,P,0IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z
M("(*;7-G<W1R(")0=6YT;R!D92!C;VYD96YS86-I\VX@9&4@;&$@^FQT:6UA
M(&AO<F$Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*
M;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(E!U;G1O(&1E(&-O;F1E;G-A
M8VGS;CH@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS9W-T
M<B`B1&4@:7IQ=6EE<F1A(&$@9&5R96-H82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R
M:6=H="!T;R!L969T(@IM<V=S='(@(D1E(&1E<F5C:&$@82!I>G%U:65R9&$B
M"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y
M(@IM<V=S='(@(D1I<F5C=&]R:6\B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP
M:'`N9&ES=#HR-S`*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS
M9W-T<B`BOTUO<W1R87(@96X@9F]R;6%T;R!D92`R-"UH;W)A<S\B"@HC.B!C
M;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HQ,#`*;7-G:60@(D1I<W!L87D@
M3W!T:6]N<R(*;7-G<W1R(")/<&-I;VYE<R!D92!6:7-U86QI>F%C:?-N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C@Y"FUS9VED(")$:7-P
M;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM<V=S='(@(DUO<W1R87(@<')O;O-S
M=&EC;R!D971A;&QA9&\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.CDR"FUS
M9VED(")$:7-P;&%Y(&9O<F5C87-T("A4048I(@IM<V=S='(@(DUO<W1R87(@
M<')O;O-S=&EC;R`H5$%&*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-SDY
M"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R(")&;W)M871O(&1E('9I
M<W5Z86QI>F%C:?-N(@H*(SH@;&EB+TAO<F1E+TU)344O341.+G!H<#HQ.3$*
M;7-G:60@(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B(*;7-G<W1R(").;W1I
M9FEC86-I\VX@9&4@8V]N<W5L=&$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C<P"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R
M(")$:FEB;W5T:2(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-#(R"FUS
M9VED(")$;R!N;W0@9&5L971E(@IM<V=S='(@(DYO(&5L:6UI;F%R(@H*(SH@
M<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER
M96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R(").;R!A8V-E
M9&5R(&1I<F5C=&%M96YT92!A(&UA:6YT96YA;F-E+G!H<"(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C$R('1E;7!L871E<R]D871A+W1S=FEN
M9F\N:6YC.C$R"FUS9VED(")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T
M:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S
M='(@(B(*(K]#;VYT:65N92!L82!P<FEM97)A(&9I;&$@;&]S(&YO;6)R97,@
M9&4@;&]S(&-A;7!O<S\@4VD@97,@87/M+"!S96QE8V-I;VYE("(*(F5S=&$@
M8V%S:6QL83HB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C<R"FUS9VED(")$;VUI;FEC82(*;7-G<W1R(")$;VUI;FEC82(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HW,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S,*
M;7-G:60@(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R(")297#Z8FQI8V$@
M1&]M:6YI8V%N82(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*
M;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T
M<B`BOTYO(&1I<W!O;F4@9&4@8W5E;G1A/R!3;VQI8^UT96QA+B(*"B,Z(&QI
M8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-3,*;7-G:60@(D1O=VYL;V%D
M(@IM<V=S='(@(D1E<V-A<F=A<B(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E
M;G1S+G!H<#HX-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B
M"FUS9W-T<B`B1&5S8V%R9V%R("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$V,0IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I
M;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`B1&5S8V%R9V%R(&QA(&-O;F9I
M9W5R86-I\VX@9V5N97)A9&$@8V]M;R!U;B!G=6GS;B!02%`N(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(Q,#<*;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM
M<V=S='(@(DQI<W1A(&1E<W!L96=A8FQE(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G<W1R(")$<F]G87,B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D4M36%I;"(*;7-G
M<W1R(")#;W)R96\B"@HC.B!L:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP
M.CDR"FUS9VED(")%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C
M87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B
M(@HB0V]N=')O;&%D;W(@9&4@<&%S87)E;&$@0V]R<F5O+6$M4TU3('!A<F$@
M<')O=F5E9&]R97,@<75E('!R;W!O<F-I;VYE;B!E<W1E("(*(G-E<G9I8VEO
M+B(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE
M+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@(D524B(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HW,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S4*;7-G:60@(D5C=6%D
M;W(B"FUS9W-T<B`B16-U861O<B(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z
M,S(U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@IM<V=I
M9"`B161I="(*;7-G<W1R("(F;F)S<#M-;V1I9FEC87(F;F)S<#LB"@HC.B!L
M:6(O2&]R9&4O0FQO8VLO54DN<&AP.C4P"FUS9VED(")%9&ET($)L;V-K(@IM
M<V=S='(@(DUO9&EF:6-A<B!B;&]Q=64B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C$Y."!A9&UI;B]G<F]U<',N<&AP.C(R-@IM<V=I9"`B161I="!'<F]U<"(*
M;7-G<W1R(")-;V1I9FEC87(@9W)U<&\B"@HC.B!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C<V(&QI8B](;W)D92]097)M<R]522YP:'`Z,3`P"FUS9VED(")%
M9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`B36]D:69I8V%R('!R:79I;&5G:6\B
M"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"FUS9VED(")%9&ET
M(%!E<FUI<W-I;VYS(@IM<V=S='(@(DUO9&EF:6-A<B!P<FEV:6QE9VEO<R(*
M"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B36]D
M:69I8V%R('!R:79I;&5G:6]S(&1E("5S(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`B
M36]D:69I8V%R(&]P8VEO;F5S(&1E.B(*"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO
M;G,@9F]R(%PB)7-<(B(*;7-G<W1R(")-;V1I9FEC87(@<')I=FEL96=I;W,@
M9&4@7"(E<UPB(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*
M;7-G<W1R(")-;V1I9FEC87(@<')I=FEL96=I;W,@9&4@)7,B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R
M(")%9'5C86-I\VXB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C<W"FUS9VED(")%9WEP="(*;7-G<W1R(")%9VEP=&\B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C<T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3<*
M;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@(D5L(%-A;'9A9&]R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C0S"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@(D5L96UE;G1O+BXN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*
M;7-G:60@(D5M(@IM<V=S='(@(D5M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$X-CD@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0*;7-G
M:60@(D5M86EL(@IM<V=S='(@(D-O<G)E;R(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-38V('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z-C@*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`IM
M<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R(")$:7)E8V-I\VX@9&4@8V]R
M<F5O(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-C,*;7-G:60@(D5M86EL
M(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*;7-G<W1R("),87,@9&ER96-C:6]N
M97,@9&4@8V]R<F5O('1I96YE;B!Q=64@8V]I;F-I9&ER+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ.3@Y"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA
M=&EO;B(*;7-G<W1R(")#;W)R96\@8V]N(&-O;F9I<FUA8VGS;B(*"B,Z(&QI
M8B].970O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O
M+5--4R!'871E=V%Y(@IM<V=S='(@(E!A<V%R96QA($-O<G)E;RUA+5--4R(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR.3D*;7-G
M:60@(D5M;W1I8V]N<R(*;7-G<W1R(")%;6]T:6-O;F5S(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*;7-G:60@(D5M<'1Y(&UE
M<W-A9V4N(@IM<V=S='(@(DUE;G-A:F4@96X@8FQA;F-O(@H*(SH@;&EB+TAO
M<F1E+T=R;W5P+VQD87`N<&AP.C(T,R!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP
M:'`Z-#@T"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV-C(@;&EB+TAO
M<F1E+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!L:6(O2&]R9&4O075T:"]L9&%P
M+G!H<#HQ-3`*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B4F5S=6QT
M861O(&5N(&)L86YC;RXB"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H
M<#HQ,3,*;7-G:60@(D5M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R("),:6UP
M:6%R('3I<FUI;F]S(&1E(&+Z<W%U961A(@H*(SH@8V]N9FEG+RYB86LO<')E
M9G,N<&AP+F1I<W0Z-30W"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM
M86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R("*_
M4&5R;6ET:7(@:6YS97)C:?-N(&1E(&EMX6=E;F5S(&1E(&QA<R!'86QE<NUA
M<R!D92!F;W1O<S\B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HU
M,C(*;7-G:60@(D5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM
M<V=S='(@(K]097)M:71I<B!M96[Z(&1E(&-O;G1E>'1O(&1E;"!B;W3S;B!D
M97)E8VAO(&1E;"!R873S;C\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4X
M."!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y,PIM<V=I9"`B16YD('EE87(B"FUS
M9W-T<B`B0?%O(&1E('1E<FUI;F%C:?-N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%9&ET
M;W(B"FUS9W-T<B`B06=R86YD87(@961I=&]R(@H*(SH@8V]N9FEG+RYB86LO
M<')E9G,N<&AP+F1I<W0Z,C(T"FUS9VED("(B"B)%;G1E<B!A('-E8W5R:71Y
M('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D
M('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE
M(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@HB26YT<F]D=7IC82!U
M;F$@<')E9W5N=&$@9&4@<V5G=7)I9&%D('%U92!S92!L92!F;W)M=6QA<N$@
M<VD@<')E8VES82`B"B)R96%J=7-T87(@;&$@8V]N=')A<V7Q82P@<"YE+B`G
MOT-UX6P@97,@96P@;F]M8G)E(&1E('-U(&UA<V-O=&$_)SHB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3D*;7-G:60@(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(*;7-G<W1R("))
M;G1R;V1U>F-A(&%Q=>T@;&$@55),(&1E(&QA(&EM86=E;B(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX.3(*;7-G:60@(D5N=&5R
M('1H92!L971T97)S(&)E;&]W.B(*;7-G<W1R("));G1R;V1U>F-A(&QA<R!L
M971R87,@9&4@9&5B86IO.B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z.3D*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM
M<V=S='(@(D=U:6YE82!%8W5A=&]R:6%L(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HW.0IM<V=I9"`B17)I=')E82(*;7-G
M<W1R(")%<FET<F5A(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#@*(SH@;&EB+TAO<F1E+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B](;W)D92]"
M;&]C:R],87EO=70O5FEE=RYP:'`Z.30*;7-G:60@(D5R<F]R(@IM<V=S='(@
M(D5R<F]R(@H*(SH@;&EB+TAO<F1E+U1E;7!L871E+G!H<#HT-C,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B17)R;W(@8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S
M='(@(D5R<F]R(&%L(&-R96%R(&5L(&)L;W%U93H@)7,B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T<B`B17)R;W(@
M86P@96QI;6EN87(@86YC;&$@9&4@<VEN8W)O;FEZ86-I\VXZ("5S(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S(@IM<V=S='(@(D5R
M<F]R(&%L(&5L:6UI;F%R(&5L(')E9VES=')O(&1E('-I;F-R;VYI>F%C:?-N
M.B`E<R(*"B,Z(&QI8B](;W)D92]496UP;&%T92YP:'`Z-#8X"B,L('!H<"UF
M;W)M870*;7-G:60@(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS9W-T
M<B`B17)R;W(@86P@;V)T96YE<B!C;VYT96YI9&]S.B`E<R(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`B17)R;W(@
M86P@86-T=6%L:7IA<B!L82!C;VYT<F%S9?%A.B`E<R(*"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H
M(&5M86EL(&UE<W-A9V4N(@IM<V=S='(@(D5R<F]R(&-O;B!E;"!M96YS86IE
M(&1E(&-O<G)E;RXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R
M;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(D5R<F]R(&%L(&5S8W)I8FER
M(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C<V"FUS9VED(")%<W1O;FEA(@IM<V=S='(@(D5S=&]N:6$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@Q"FUS
M9VED(")%=&AI;W!I82(*;7-G<W1R(")%=&EO<.UA(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T<B`BR71N:6-O
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P
M92(*;7-G<W1R(")%=7)O<&$B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N
M9&ES=#HS-#,*;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`B0V%D
M82`Q-2!M:6YU=&]S(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z
M,SDS"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`B0V%D82`R(&UI
M;G5T;W,B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HS-#`@8V]N
M9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")%=F5R>2`S,"!S
M96-O;F1S(@IM<V=S='(@(D-A9&$@,S`@<V5G=6YD;W,B"@HC.B!C;VYF:6<O
M+F)A:R]P<F5F<RYP:'`N9&ES=#HS-#(@8V]N9FEG+RYB86LO<')E9G,N<&AP
M+F1I<W0Z,SDT"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B0V%D
M82`U(&UI;G5T;W,B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C8P
M"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R(")#861A(&EN:6-I;R!D92!S
M97-I\VXB"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HS-#0*;7-G
M:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R(")#861A(&UE9&EA(&AO<F$B
M"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HS-#$@8V]N9FEG+RYB
M86LO<')E9G,N<&AP+F1I<W0Z,SDR"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS
M9W-T<B`B0V%D82!M:6YU=&\B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P
M+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V86QU97,Z(@IM<V=S='(@(E9A;&]R
M97,@9&4@96IE;7!L;SHB"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z-3$@861M
M:6XO<&AP<VAE;&PN<&AP.C@R(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*;7-G
M:60@(D5X96-U=&4B"FUS9W-T<B`B16IE8W5T87(B"@HC.B!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8Q-`IM<V=I9"`B17AP86YD(@IM
M<V=S='(@(D5X<&%N9&ER(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R
M+FEN8SHS,@IM<V=I9"`B17AP86YD(%-I9&5B87(B"FUS9W-T<B`B36]S=')A
M<B!B87)R82!L871E<F%L(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP
M:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B<V4@97-P97)A
M8F$@)RDG(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS
M9VED(")%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M
M(@IM<V=S='(@(E-E(&5S<&5R86)A('5N82#Z;FEC82!P86QA8G)A(&\@=6X@
M=.ER;6EN;R!D92!B^G-Q=65D82!E;G1R96-O;6EL;&%D;R(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$871E
M(@IM<V=S='(@(D9E8VAA(&1E('9E;F-I;6EE;G1O(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HV-S<*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@
M(D5X<&]N96YT92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(D-O
M;&]R(&1E(&QE=')A(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-@IM
M<V=I9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R(")#87)G87(@;&$@
M8V]N9FEG=7)A8VGS;B!P;W(@1E10(@H*(SH@;&EB+TAO<F1E+U!R969S+W-Q
M;"YP:'`Z,C(P"FUS9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E
M<RXB"FUS9W-T<B`B1F%L;&\@86P@=')A97(@;&%S('!R969E<F5N8VEA<RXB
M"@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-S4@;&EB+TAO<F1E+T%U
M=&@O;&1A<"YP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$
M05`@<V5R=F5R+B(*;7-G<W1R("));F-A<&%Z(&1E(&-O;F5C=&%R<V4@86P@
M<V5R=FED;W(@3$1!4"XB"@HC.B!L:6(O2&]R9&4O075T:"]S;6(N<&AP.CDX
M"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*;7-G
M<W1R("));F-A<&%Z(&1E(&-O;F5C=&%R<V4@86P@<V5R=FED;W(@4TU"+B(*
M"B,Z(&QI8B]61E,O9G1P+G!H<#HW,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@(D9A;&QO(&%L
M(&-O<&EA<B!D92!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<S,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!T;R!<(B5S7"(N
M(@IM<V=S='(@(D9A;&QO(&%L(&-O<&EA<B!A(%PB)7-<(BXB"@HC.B!L:6(O
M2&]R9&4O075T:"]S87-L+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R96%T
M92!N97<@4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R(")&86QL;R!A;"!C<F5A
M<B!U;F$@8V]N97AI\VX@4T%33"(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW-C@@
M;&EB+U9&4R]S;6(N<&AP.C4Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL
M960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(D9A;&QO(&%L('1R87-L
M861A<B!<(B5S7"(N(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C0W-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")&86EL960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@
M(D9A;&QO(&%L(')E8W5P97)A<CH@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R(")$
M97-P96IA9&\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C@T"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB
M"FUS9W-T<B`B27-L87,@36%L=FEN87,@*$9A;&ML86YD*2(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<S(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HX,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#8*;7-G:60@(D9A
M<F]E($ES;&%N9',B"FUS9W-T<B`B27-L87,@1F%R;V4B"@HC.B!L:6(O2&]R
M9&4O0TQ)+G!H<#HR,S@*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R(")%
M<G)O<B!I<G)E8W5P97)A8FQE.B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3@W"FUS9VED(")&87@B"FUS9W-T<B`B1F%X(@H*(SH@
M8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z,S4Q"FUS9VED(")&87AE
M<R(*;7-G<W1R(")&87AE<R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#,@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8V"FUS9VED(")&96)R=6%R>2(*;7-G<W1R(")&96)R97)O(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C<*;7-G:60@(D9E96QS($QI:V4B"FUS
M9W-T<B`B4V4@<VEE;G1E(&-O;6\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C(P"FUS9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B4V4@
M<VEE;G1E(&-O;6\Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C$Y"FUS9VED(")&97<@4VAO=V5R<R(*;7-G<W1R(")0;V-A
M<R!L;'5V:6%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B17-C
M87-O(&%G=6%C97)O(&1E(&YI979E(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$Y-#0*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R(")-871R:7H@9&4@
M8V%M<&]S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,C4*;7-G:60@(D9I
M9VQE="!#05!40TA!(@IM<V=S='(@(D-!4%1#2$$@9&4@1FEG;&5T(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C,S,CD*;7-G:60@(D9I9VQE="!F;VYT(@IM
M<V=S='(@(DQE=')A(&1E($9I9VQE="(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#,*;7-G:60@(D9I:FDB"FUS9W-T<B`B
M1FEJ:2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I
M9"`B1FEL92(*;7-G<W1R(")!<F-H:79O(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C`@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-SD*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R
M(").NB!D92!A<F-H:79O<SH@)7,@87)C:&EV;R(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R87(N<&AP.C8P(&QI8B](;W)D92]-24U%+U9I97=E<B]T
M9WHN<&AP.C<Y"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8W
M"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM
M<V=S='(@(DZZ(&1E(&%R8VAI=F]S.B`E<R!A<F-H:79O<R(*"B,Z(&-O;F9I
M9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C0P.0IM<V=I9"`B1FEL92!-86YA
M9V5R(@IM<V=S='(@(D%R8VAI=F]S(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C,@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z
M.#(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*;7-G:60@
M(D9I;&4@3F%M92(*;7-G<W1R(").;VUB<F4@9&4@87)C:&EV;R(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR.3<W"FUS9VED(")&:6QE('-E;&5C=&EO;B(*
M;7-G<W1R(")396QE8V-I\VX@9&4@87)C:&EV;R(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ-#@V"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R(")#87)G
M87(@87)C:&EV;R(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HY,#`*;7-G
M:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("),82!C
M87)G82!D92!A<F-H:79O<R!N;R!E<W3A('-O<&]R=&%D82XB"@HC.B!C;VYF
M:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HY,0IM<V=I9"`B1FEL=&5R<R(*
M;7-G<W1R(")&:6QT<F]S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HX,@IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R(")&:6YL
M86YD:6$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED(")&:7)S
M="!(86QF(@IM<V=S='(@(D-U87)T;R!C<F5C:65N=&4B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&
M:7)S="!1=6%R=&5R(@IM<V=S='(@(D-U87)T;R!C<F5C:65N=&4B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4W"FUS9VED(")&
M:7@@<F%T:6\B"FUS9W-T<B`B4F%Z\VX@9FEJ82(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,S(*;7-G:60@(D9L:7`B"FUS9W-T
M<B`B5F]L=&5A<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(D1I<W!O
M<VEC:?-N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R(").:65B;&$B"@HC.B!L:6(O5D93
M+VUU<W%L+G!H<#HQ,#<@;&EB+U9&4R]S<6PN<&AP.C(S-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B
M3&$@8V%R<&5T82`E<R!N;R!E>&ES=&4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*
M;7-G<W1R(")#;VQO<B!D92!L971R82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R(")#;VUI9&$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,C,*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA
M9V5S(@IM<V=S='(@(E!A<F$@;F%V96=A9&]R97,@<75E(&YO(&%D;6ET86X@
M:6WA9V5N97,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T,0IM<V=I9"`B
M1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B4')O;O-S=&EC;R`H5$%&*2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,@IM<V=I9"`B(@HB1F]R
M96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R
M971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G92!N=6UB97(@
M:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R("(B
M"B)$[6%S(&1E;"!P<F]N\W-T:6-O("AT96YG82!E;B!C=65N=&$@<75E(&5L
M('!R;V[S<W1I8V\@9F%C:6QI=&%D;R!I;F-L=7EE("(*(G1A;G1O(&5L(&3M
M82!C;VUO(&QA(&YO8VAE.R!U;B!N^FUE<F\@9W)A;F1E('-E('1R861U8VER
MX2!E;B!U;B!B;&]Q=64@;75Y("(*(F%N8VAO*2(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z,3`R"FUS9VED(")&;W)G;W0@>6]U<B!P87-S=V]R
M9#\B"FUS9W-T<B`BOTAA(&]L=FED861O(&QA(&-O;G1R87-E\6$_(@H*(SH@
M8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z-#8T"FUS9VED(")&;W)M
M<R(*;7-G<W1R(")&;W)M=6QA<FEO<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*;7-G<W1R(")&;W)T=6YA(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED(")&;W)T=6YE('1Y<&4B
M"FUS9W-T<B`B5&EP;R!D92!F;W)T=6YA(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,X"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R(")&;W)T=6YA<R(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@
M,B(*;7-G<W1R(")&;W)T=6YA<R`R(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T
M<GDN<&AP+F1I<W0Z-#4U"FUS9VED(")&;W)U;7,B"FUS9W-T<B`B1F]R;W,B
M"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HQ,3$*;7-G:60@
M(D9O<G=A<F1S(@IM<V=S='(@(E)E96YV[6]S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T
M<B`B5FEE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS,PIM<V=I9"`B1G)A;65S(@IM<V=S='(@(D9R86UE<R(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HX,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#<*
M;7-G:60@(D9R86YC92(*;7-G<W1R(")&<F%N8VEA(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI=&%N
M(@IM<V=S='(@(D9R86YC:6$L($UE=')O<&]L:71A;F$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDQ"FUS9VED(")&<F5N
M8V@@1W5I86YA(@IM<V=S='(@(D=U87EA;F$@9G)A;F-E<V$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-`IM<V=I9"`B
M1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R(")0;VQI;F5S:6$@9G)A;F-E<V$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C@V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,C(*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*;7-G<W1R
M(")497)R:71O<FEO<R!F<F%N8V5S97,@9&5L('-U<B(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S
M='(@(D1E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-R!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0Y"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS.34*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R
M(")$96P@(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*
M;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`B1&5S8W)I<&-I\VX@
M8V]M<&QE=&$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K
M+VUO;VXN<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(DQU;F$@
M;&QE;F$B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C4@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHV,`IM<V=I9"`B1G5L;"!.86UE(@IM
M<V=S='(@(DYO;6)R92!C;VUP;&5T;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#@*;7-G:60@(D=A8F]N(@IM<V=S='(@
M(D=A8O-N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA
M9V4@9G)O;2(*;7-G<W1R(")'86QE<NUA(&1E(&QA('%U92!O8G1E;F5R(&QA
M(&EM86=E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B
M1V%L97+M83HB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.CDV"FUS9VED(")'86UB:6$B"FUS9W-T<B`B1V%M8FEA(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(D=E;F5R87(@
M8V]N9FEG=7)A8VGS;B!D92`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U
M<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G<W1R
M(")#\V1I9V\@9V5N97)A9&\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.CDP"FUS9VED(")'96]R9VEA(@IM<V=S='(@(D=E
M;W)G:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C8Y"FUS9VED(")'97)M86YY(@IM<V=S='(@(D%L96UA;FEA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.CDQ"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,PIM<V=I
M9"`B1VAA;F$B"FUS9W-T<B`B1VAA;F$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDT"FUS9VED(")':6)R86QT87(B"FUS
M9W-T<B`B1VEB<F%L=&%R(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU-S8*;7-G:60@(D=I=F5N($YA;64B"FUS9W-T<B`B3F]M8G)E(&EN9&EC
M861O(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W.2!T96UP
M;&%T97,O<')E9G,O87!P+FEN8SHQ,`HC.B!T96UP;&%T97,O<')E9G,O87!P
M+FEN8SHQ.0IM<V=I9"`B1VQO8F%L($]P=&EO;G,B"FUS9W-T<B`B3W!C:6]N
M97,@9VQO8F%L97,B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-PIM
M<V=I9"`B1V\B"FUS9W-T<B`B27(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G<W1R(")';V5D96PB"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$S,0IM<V=I9"`B1V]O
M9VQE($UA<',B"FUS9W-T<B`B36%P87,@9&4@1V]O9VQE(@H*(SH@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE+G!H<#HR,2!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE(%-E87)C:"(*;7-G
M<W1R(")"^G-Q=65D82!E;B!';V]G;&4B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C,X"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T
M<B`B17-C86QA(&1E(&=R:7-E<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3`P"FUS9VED(")'<F5E8V4B"FUS9W-T<B`B
M1W)E8VEA(@H*(SH@8V]N9FEG+RYB86LO;FQS+G!H<"YD:7-T.C$X.`IM<V=I
M9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(D=R:65G;R`H25-/+3@X
M-3DM-RDB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.CDU"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B1W)O96YL86YD:6$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.34*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@Y
M"FUS9VED(")'<F5N861A(@IM<V=S='(@(D=R86YA9&$B"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C$W.0IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB"FUS
M9W-T<B`B061M:6YI<W1R86-I\VX@9&4@9W)U<&]S(@H*(SH@;&EB+TAO<F1E
M+T=R;W5P+G!H<#HU.2!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS
M9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R("),
M;W,@;F]M8G)E<R!D92!G<G5P;R!N;R!P=65D96X@9&5J87)S92!E;B!B;&%N
M8V\B"@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L('!H<"UF
M;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@
M)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("(B
M"B)'<F]U<%]L9&%P.B!.;R!S92!P=65D92!A\6%D:7(@96P@9W)U<&\@)7,N
M(,ES=&\@97,@;&\@<75E(&1I:F\@96P@<V5R=FED;W(Z("(*"B,Z(&QI8B](
M;W)D92]'<F]U<"]L9&%P+G!H<#HQ,3@@;&EB+TAO<F1E+T=R;W5P+VQD87`N
M<&AP.C$R-`HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L('!H
M<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@
M9W)O=7`@)7,B"FUS9W-T<B`B1W)O=7!?;&1A<#H@26YC87!A>B!D92!E;&EM
M:6YA<B!E;"!G<G5P;R`E<R(*"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H
M<#HS,S@@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C,W.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P
M("5S(@IM<V=S='(@(D=R;W5P7VQD87`Z($EN8V%P87H@9&4@86-T=6%L:7IA
M<B!E;"!G<G5P;R`E<R(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X(&QI
M8B](;W)D92]097)M<R]522YP:'`Z,S$T"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS9W-T<B`B1W)U<&]S(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.CDV"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY.`IM
M<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R(")'=6%D86QU<&4B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,PIM<V=I9"`B
M1W5A;2(*;7-G<W1R(")'=6%M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,#(*;7-G:60@(D=U871E;6%L82(*;7-G<W1R
M(")'=6%T96UA;&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3(*;7-G
M:60@(D=U97)N<V5Y(@IM<V=S='(@(D=U97)N97-E>2(*"B,Z(&QI8B](;W)D
M92]097)M<R]522YP:'`Z,C(V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M.#@*;7-G:60@(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(E!R:79I;&5G
M:6]S(&1E(&EN=FET861O(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP
M+F1I<W0Z-#<R"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`B3"X@:6YV:71A
M9&]S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HY-PIM<V=I9"`B1W5I;F5A(@IM<V=S='(@(D=U:6YE82(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<X(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,#`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-`IM<V=I9"`B
M1W5I;F5A+4)I<W-A=2(*;7-G<W1R(")'=6EN96$M0FES<V%U(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$P,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`U"FUS9VED
M(")'=7EA;F$B"FUS9W-T<B`B1W5A>6%N82(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HY-C`*;7-G:60@(DA434PB"FUS9W-T<B`B2%1-3"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G
M:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L
M87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R(")(5$U,('-E(&YI96=A(&-O8F%R
M9&5M96YT92!A(&5L:6UI;F%R(&QA(/IL=&EM82!C96QD82!D92!L82!F:6QA
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@
M9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB"FUS9W-T<B`B(@HB
M2%1-3$%R96$@<V4@;FEE9V$@8V]B87)D96UE;G1E(&$@96QI;6EN87(@;&$@
M^FQT:6UA(&-O;'5M;F$@9&4@;&$@=&%B;&$N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W
M(&EN('1A8FQE+B(*;7-G<W1R(")(5$U,('-E(&YI96=A(&-O8F%R9&5M96YT
M92!A(&5L:6UI;F%R(&QA(/IL=&EM82!F:6QA(&1E(&QA('1A8FQA+B(*"B,Z
M(&QI8B](;W)D92]!=71H+VAT='`N<&AP.C$U-PIM<V=I9"`B2%144"!!=71H
M96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(DYO('-E(&5N8V]N='+S
M(&QA(&%U=&5N=&EF:6-A8VGS;B!(5%10+B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#(*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,`IM<V=I9"`B2&%I=&DB"FUS
M9W-T<B`B2&%I=.TB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3,*
M;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(D%L9V]R:6UO($AA<V@B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@IM
M<V=I9"`B2&%Z92(*;7-G<W1R(").96)L:6YA(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.CDQ.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDQ-`IM<V=I9"`B2&5A
M9&5R(@IM<V=S='(@(D-A8F5C97)A(@H*(SH@;&EB+TAO<F1E+T9O<FTO5'EP
M92]T86)L97-E="YP:'`Z-C$*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B0V%B
M96-E<F%S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3`W"FUS9VED(")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES
M;&%N9',B"FUS9W-T<B`B27-L82!(96%R9"!E($ES;&%S($UC1&]N86QD(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C,*;7-G
M:60@(DAE879Y(%0M4W1O<FTB"FUS9W-T<B`B5&]R;65N=&$@=')O<&EC86P@
M:6YT96YS82(*"B,Z(&-O;F9I9R\N8F%K+VYL<RYP:'`N9&ES=#HQ.#D*;7-G
M:60@(DAE8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R(")(96)R96\@*$E3
M3RTX.#4Y+3@M22DB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HR,B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T"FUS
M9VED(")(96EG:'0B"FUS9W-T<B`B06QT=7)A(@H*(SH@;&EB+TAO<F1E+TAE
M;'`N<&AP.C$X-"!L:6(O2&]R9&4O2&5L<"YP:'`Z,3@V('-E<G9I8V5S+VAE
M;'`O:6YD97@N<&AP.C$W"B,Z('1E;7!L871E<R]H96QP+VEN9&5X+FEN8SHT
M"FUS9VED(")(96QP(@IM<V=S='(@(D%Y=61A(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN
M9R!E9&ET;W(B"FUS9W-T<B`B07EU9&$@9&5L(&5D:71O<B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,S<Q"FUS9VED(")(96QP97(B"FUS9W-T<B`B07EU
M9&%N=&4B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@(DAE;6ES
M<&AE<F4B"FUS9W-T<B`B2&5M:7-F97)I;R(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$P
M"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM
M<V=S='(@(D%Q=>T@=&EE;F4@96P@8V]M:65N>F\@9&5L(&%R8VAI=F\Z(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*;7-G
M:60@(DAI9V@B"FUS9W-T<B`B06QT82(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;65N=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z
M-0IM<V=I9"`B2&]?;64B"FUS9W-T<B`B7TEN:6-I;R(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#,*;7-G:60@(DAO
M;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I(@IM<V=S='(@(E-A;G1A(%-E
M9&4@*$-I=61A9"U%<W1A9&\@9&5L(%9A=&EC86YO*2(*"B,Z(&QI8B](;W)D
M92YP:'`Z,34T.`IM<V=I9"`B2&]M92(*;7-G<W1R("));FEC:6\B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R,B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S
M(@IM<V=S='(@(D1O;6EC:6QI;R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HW,`IM<V=I9"`B2&]M92!$:7)E8W1O<GDB"FUS9W-T<B`B1&ER96-T;W)I
M;R!P97)S;VYA;"(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(E1E;.EF;VYO('!A
M<G1I8W5L87(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,#@*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@(DAO;F1U<F%S
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$P-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3`V"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`B2&]N9R!+;VYG(@H*(SH@
M8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z-C<*;7-G:60@(DAO<F1E
M(@IM<V=S='(@(DAO<F1E(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT-3(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@
M6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<R(*;7-G<W1R("(B
M"B)(;W)D92]+;VQA8CH@4V4@:&%N(&5N8V]N=')A9&\@9&%T;W,@6$U,("5S
M(&YO(';A;&ED;W,@96X@96P@;65N<V%J92`E<R(*"B,Z(&QI8B](;W)D92]+
M;VQA8BYP:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R
M(")(;W)D92]+;VQA8CH@3FEN9_IN(&UE;G-A:F4@8V]R<F5S<&]N9&4@86P@
M;V)J971O("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT-#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E
M("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z
M($YO('-E(&5N8V]N='+S('5N(&]B:F5T;R!D92!T:7!O("5S(&5N(&5L(&UE
M;G-A:F4@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$R-3$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO
M=F5D("5S(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@4V4@:&$@96QI
M;6EN861O(&-O<G)E8W1A;65N=&4@)7,@7"(E<UPB(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R
M871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS
M:6]N(@IM<V=S='(@(B(*(DAO<F1E+TMO;&%B.B!%;"!M;W1O<B!D92!I;G1E
M9W)A8VGS;B!P<F5C:7-A(&1E(&QA(&5X=&5N<VGS;B!02%`@)V1O;7AM;"<B
M"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C4Q,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R
M964@9F]R(&]B:F5C="`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@26YC87!A
M>B!D92!C<F5A<B!N=65V;R#A<F)O;"!834P@9&5L(&]B:F5T;R`E<R(*"B,Z
M(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(T.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S
M(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!);F-A<&%Z(&1E(&5L:6UI;F%R("5S
M(%PB)7-<(CH@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0X,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I
M979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B
M2&]R9&4O2V]L86(Z($EN8V%P87H@9&4@;V)T96YE<B!)1"!-24U%(&1E(&QA
M('!A<G1E(&1E('1I<&\@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$Q
M.3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!S>6YC:')O;FES92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E+TMO
M;&%B.B!);F-A<&%Z(&1E('-I;F-R;VYI>F%R("5S(%PB)7-<(CH@)7,B"@HC
M.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$S,S<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z
M("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!);F-A<&%Z(&1E('-I;F-R;VYI
M>F%R(&5L96UE;G1O<R!C;VUP87)T:61O<SH@)7,B"@HC.B!L:6(O2&]R9&4O
M2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(Z
M($5L96UE;G1O(&-O;7!A<G1I9&\@9&5S8V]N;V-I9&\@7"(E<UPB(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I
M9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(DSM;F5A(&AO<FEZ;VYT86PB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@R
M"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B36%R9V5N(&AO
M<FEZ;VYT86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R(")(;W)I>F]N
M=&%L.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0
M;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`BOT/S;6\@;&QE9_,@:&%S=&$@87%U
M[3\@**%#;VUU;NUQ=65L;RP@<&]R(&9A=F]R(2DB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(
M;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G
M<W1R("*_0W5A;G1A<R!C;VQU;6YA<R!D97-E82!C;VUB:6YA<C\B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@
M9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@(K]#=>%N=&]S
M(&-A;7!O<R`H8V]L=6UN87,I(&AA>3\B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N
M>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R("*_0W5A
M;G1A<R!F:6QA<R!D97-E82!C;VUB:6YA<C\B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(S-R!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Y"FUS
M9VED(")(=6UI9&ET>2(*;7-G<W1R(")(=6UE9&%D(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(T.`IM<V=I9"`B2'5M:61I='DZ("(*;7-G
M<W1R(")(=6UE9&%D.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*
M;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R(")(=6UO<FES=&%S(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$P-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$Q"FUS9VED
M(")(=6YG87)Y(@IM<V=S='(@(DAU;F=R[6$B"@HC.B!L:6(O2&]R9&4O075T
M:"]C>7)S<6PN<&AP.C(S-2!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3<R
M"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F
M86EL960Z("5S(@IM<V=S='(@(DAA(&9A;&QA9&\@;&$@8W)E86-I\VX@9&5L
M(&)U>O-N($E-05`Z("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H
M<#HR.34@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C(Q-`HC+"!P:'`M9F]R
M;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*
M;7-G<W1R(")(82!F86QL861O(&QA(&5L:6UI;F%C:?-N(&1E;"!B=7KS;B!)
M34%0.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,C0R(&QI
M8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ-SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS
M9W-T<B`B2&$@9F%L;&%D;R!L82!C<F5A8VGS;B!D92!E<W!A8VEO(&%S:6=N
M861O(&1E;"!B=7KS;B!)34%0.B`E<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,S$V"FUS9VED("))4"!!9&1R97-S(@IM<V=S='(@(D1I<F5C8VGS;B!)
M4"(*"B,Z(&QI8B](;W)D92]!=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED("))
M4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DQA(&1I<F5C8VGS
M;B!)4"!N;R!E<W3A(&1I<W!O;FEB;&4N(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I=&AI;B!A
M;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@(DQA(&1I<F5C8VGS;B!)4"!N
M;R!E<W3A(&5N=')E(&)L;W%U97,@0TE$4B!P97)M:71I9&]S+B(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))4"!L
M;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S='(@(E9I;VQA8VGS;B!L;V-K9&]W
M;B!)4"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G
M<W1R("))7VYS97)T87(@9FEL82!E;F-I;6$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C`*;7-G:60@(DEC96QA;F0B
M"FUS9W-T<B`B27-L86YD:6$B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N
M9&ES=#HS.#`*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B4_-L;R!I8V]N
M;W,B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@(DEC;VYO<R!D92`E<R(*
M"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C,X,0IM<V=I9"`B26-O
M;G,@=VET:"!T97AT(@IM<V=S='(@(DEC;VYO<R!C;VX@=&5X=&\B"@HC.B!C
M;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HQ.3,*;7-G:60@(DED96YT:71Y
M)W,@;F%M93HB"FUS9W-T<B`B3F]M8G)E(&1E(&QA(&ED96YT:61A9#HB"@HC
M.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z-C`P"B,L('!H<"UF;W)M
M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E
M<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B4VD@;F\@
M<V4@;75E<W1R82!C;W)R96-T86UE;G1E+"`E<R!P87)A(&%B<FER;&\@96X@
M=6YA('9E;G1A;F$@;G5E=F$N(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP
M+F1I<W0Z-#4Y"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N
M<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H
M96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN
M(@IM<V=S='(@(B(*(E-I(&YO('9E(&YI;F?Z;B!I8V]N;R!M961I86YT92!)
M;G1E<FYE="!%>'!L;W)E<BP@<'5E9&4@=&5N97(@<75E(&%C=&EV87(@(@HB
M97-T82!C87-I;&QA('!A<F$@9&5S86-T:79A<B!L82!T<F%N<W!A<F5N8VEA
M(%!.1RXB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3<R"FUS9VED("(B"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@
M:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@
M(@HB9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@HB4VD@
M=F4@97-T92!M96YS86IE('-I;B!N:6YG=6YA(&EM86=E;BP@;&$@:6UA9V5N
M('%U92!Q=6EE<F4@8V%R9V%R(&YO('-E("(*(G!U961E(&UO<W1R87(@96X@
M<W4@;F%V96=A9&]R+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0IM<V=I9"`B26UA9V4@4')E=FEE
M=SHB"FUS9W-T<B`B5FES=&$@<')E=FEA.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E
M(%523"(*;7-G<W1R(")54DP@9&4@;&$@:6UA9V5N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Q"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X"FUS
M9VED("));6%G92!54DPZ(@IM<V=S='(@(E523"!D92!L82!I;6%G96XZ(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B
M26UA9V5N(&1E(&QA(&=A;&5R[6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@(DEM86=E
M(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B26UA9V5N(&1E(&QA(&=A;&5R[6$Z
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W-C$*;7-G:60@(DEM86=E('5P
M;&]A9"(*;7-G<W1R(")392!H82!C87)G861O(&QA(&EM86=E;B(*"B,Z(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B"FUS9W-T<B`B
M26WA9V5N97,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-30*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T96UA<"YI;F,Z-R!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW"B,L
M('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("))
M;7!O<G1A<BP@<&%S;R`E9"(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N
M:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E
M<R(*;7-G<W1R(")#86UP;R!I;7!O<G1A9&\Z("5S(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*
M;7-G<W1R(")#86UP;W,@:6UP;W)T861O<SHB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN
M7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@(DEN7W-E<G1A<B!F:6QA(&1E8F%J
M;R(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C$S-`IM<V=I9"`B
M26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R(")392!H82!I
M;F1I8V%D;R!U;B!C\V1I9V\@9&4@86-C:?-N(&EN8V]R<F5C=&\N(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@IM<V=I9"`B26YC
M;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`B3F]M
M8G)E(&1E('5S=6%R:6\@>2]O(&-O;G1R87-E\6$@:6YC;W)R96-T;W,N(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN
M8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G
M86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N
M965D(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB3F]M8G)E(&1E('5S=6%R
M:6\@;R!D:7)E8V-I\VX@86QT97)N871I=F$@:6YC;W)R96-T;W,N(%9U96QV
M82!A(&EN=&5N=&%R;&\@;R`B"B)P\VYG87-E(&5N(&-O;G1A8W1O(&-O;B!E
M;"!A9&UI;FES=')A9&]R(&1E('-I<W1E;6%S('!A<F$@;>%S(&EN9F]R;6%C
M:?-N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C$*;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R(")!=6UE;G1A
M<B!S86YG<F%D;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$Q-@IM<V=I9"`B26YD:6$B"FUS9W-T<B`B26YD:6$B"@HC
M.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(U-"!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R
M(")5<W5A<FEO<R!I;F1I=FED=6%L97,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3(*;7-G:60@(DEN9&]N97-I82(*
M;7-G<W1R("));F1O;F5S:6$B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M<F9C.#(R+G!H<#HV-PIM<V=I9"`B26YF;R(*;7-G<W1R("));F9O<FUA8VGS
M;B(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C(U.0IM<V=I
M9"`B26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M86-I\VXB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Y"FUS9VED("));F9O<FUA=&EO
M;B!N;R!L;VYG97(@879A:6QA8FQE+B(*;7-G<W1R("),82!I;F9O<FUA8VGS
M;B!Y82!N;R!E<W3A(&1I<W!O;FEB;&4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,U"FUS9VED("));G-E
M<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R("));G-E<G1A<B!C7V]L=6UN82!D
M971RX7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3<*;7-G:60@(DEN<V5R="!);6%G92(*;7-G<W1R
M("));G-E<G1A<B!I;6%G96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED("));G-E<G0@5&%B;&4B"FUS9W-T
M<B`B26YS97)T87(@=&%B;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(U"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS
M9W-T<B`B26YS97)T87(@=NUN8W5L;R!796(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G:60@(DEN
M<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R("));G-E<G1A<B!?8V]L=6UN
M82!D96QA;G1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN
M(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("));G-E<G1A('5N82!N
M=65V82!C;VQU;6YA(&1E='+A<R!D92!L82!A8W1U86PB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G
M:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N
M92(*;7-G<W1R("));G-E<G1A('5N82!N=65V82!C;VQU;6YA(&1E;&%N=&4@
M9&4@;&$@86-T=6%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8R"FUS9VED("));G-E<G0@82!N97<@<F]W
M(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("));G-E<G1A('5N82!F
M:6QA(&YU979A(&1E8F%J;R!D92!L82!A8W1U86PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@
M(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G
M<W1R("));G-E<G1A('5N82!F:6QA(&YU979A(&5N8VEM82!D92!L82!A8W1U
M86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-S`*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T
M:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(DEN<V5R=&$@=6X@<.%R<F%F;R!T
M<F%S(&5L(&YO9&\@86-T=6%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P
M87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B26YS
M97)T82!U;B!PX7)R869O(&%N=&5S(&1E;"!N;V1O(&%C='5A;"(*"B,Z(&%D
M;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS9VED("));G-E<G0@86QT97)N871E
M('1E;7!L871E(@IM<V=S='(@(DEN<V5R=&%R('!L86YT:6QL82!A;'1E<FYA
M=&EV82(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C(T,@IM<V=I
M9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R
M96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(DEN<V5R=&%R('5N
M82!D:7)E8V-I\VX@9&4@8V]R<F5O(&5N(&QA('%U92!R96-I8FER(&QA(&-O
M;G1R87-E\6$Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU.`IM<V=I9"`B26YS97)T(&-E;&P@869T97(B"FUS
M9W-T<B`B26YS97)T87(@8V5L9&$@9&5T<N%S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0IM<V=I9"`B26YS
M97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(DEN<V5R=&%R(&-E;&1A(&%N=&5S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R("))
M;G-E<G1A<B!C;VQU;6YA(&1E='+A<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C
M;VQU;6X@8F5F;W)E(@IM<V=S='(@(DEN<V5R=&%R(&-O;'5M;F$@86YT97,B
M"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C4P"FUS9VED("));G-E<G0@;65S
M<V%G97,B"FUS9W-T<B`B26YS97)T87(@;65N<V%J97,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G
M:60@(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`B26YS97)T87(@
M<.%R<F%F;R!D971RX7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A
M<&@@8F5F;W)E(@IM<V=S='(@(DEN<V5R=&%R('#A<G)A9F\@86YT97,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8Y"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(DEN<V5R=&%R
M(&9I;&$@9&5B86IO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B
M"FUS9W-T<B`B26YS97)T87(@9FEL82!E;F-I;6$B"@HC.B!C;VYF:6<O+F)A
M:R]P<F5F<RYP:'`N9&ES=#HR,S,*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER
M960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B
M26YS97)T87(@;&$@<F5S<'5E<W1A(&YE8V5S87)I82!A(&QA('!R96=U;G1A
M(&1E('-E9W5R:61A9#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(V"FUS9VED("));G-E<G0O36]D:69Y($EM86=E(@IM
M<V=S='(@(DEN<V5R=&%R+TUO9&EF:6-A<B!I;6%G96XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("));G-E
M<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B26YS97)T87(O36]D:69I8V%R(';M
M;F-U;&\B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S
M"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I
M<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(")386QD;R!I;G-U9FEC:65N=&4@
M<&%R82!E;G9I87(@82!L82!L:7-T82!D92!D:7-T<FEB=6-I\VXN(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS
M=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`B4V%L9&\@:6YS=69I8VEE;G1E
M+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,#<U"FUS9VED("));G1E9V5R
M(@IM<V=S='(@(D5N=&5R;R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3,S
M"FUS9VED("));G1E9V5R(&QI<W0B"FUS9W-T<B`B3&ES=&$@9&4@96YT97)O
M<R(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS
M9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R
M(")51$@@*$-A8F5C97)A(&1E($1A=&]S(&1E(%5S=6%R:6\I(&YO(';A;&ED
M82XB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ-C<@;&EB+TAO
M<F1E+T-O;7!R97-S+WII<"YP:'`Z,3DT"B,Z(&QI8B](;W)D92]#;VUP<F5S
M<R]Z:7`N<&AP.C(Q,@IM<V=I9"`B26YV86QI9"!:25`@9&%T82(*;7-G<W1R
M(")$871O<R!:25`@;F\@=N%L:61O<R(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P;&EC871I;VXN(@IM<V=S='(@
M(D%P;&EC86-I\VX@;F\@=N%L:61A+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED("));G9A;&ED(&)A=&-H($E$+B(*
M;7-G<W1R("))1"!D92!L;W1E(&YO(';A;&ED;RXB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C`X-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$U."!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C(S,@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(Y.2!L
M:6(O2&]R9&4O1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS-PIM<V=I9"`B26YV
M86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`B4V4@:&%N(&5N=FEA9&\@
M9&%T;W,@;F\@=N%L:61O<RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P,`IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO;B!A9&1R
M97-S+B(*;7-G<W1R(")$:7)E8V-I\VX@9&4@8V]R<F5O(&YO(';A;&ED82XB
M"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HQ,#D@;&EB+TAO<F1E
M+T-O;7!R97-S+V1B>"YP:'`Z,3,Y"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]D
M8G@N<&AP.C(T,0IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R
M(")&;W)M871O(&1E(&%R8VAI=F\@;F\@=N%L:61O(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$V-0IM<V=I9"`B26YV86QI9"!L:6-E;G-E
M(&ME>2XB"FUS9W-T<B`B0VQA=F4@9&4@;&EC96YC:6$@;F\@=N%L:61A+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3D*;7-G:60@(DEN
M=F%L:60@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(E-E(&AA(&EN9&EC
M861O('5N82!U8FEC86-I\VX@;F\@=N%L:61A+B(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US9U]T
M>7!E+B(*;7-G<W1R(")M<V=?='EP92!N;R!VX6QI9&\N(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*;7-G:60@(DEN=F%L:60@
M;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(F%P:5]I9"!N;R!VX6QI9&\@
M;R!D97-A<&%R96-I9&\N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.38*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T
M97)S+B(*;7-G<W1R(")087+A;65T<F]S(&YO(';A;&ED;W,@;R!D97-A<&%R
M96-I9&]S+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR-PIM<V=I
M9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B4')I=FEL
M96=I;R!D96P@<&%D<F4@;F\@=N%L:61O<RXB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,38Q"FUS9VED("));G9A;&ED('!A<G1N97(@:60N
M(@IM<V=S='(@(DE$(&1E(&%S;V-I861O(&YO(';A;&ED;RXB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38S"FUS9VED("));G9A;&ED('!R
M;V1U8W0@8V]D92XB"FUS9W-T<B`B0_-D:6=O(&1E('!R;V1U8W1O(&YO(';A
M;&ED;RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B4')O=&]C;VQO
M(&YO(';A;&ED;RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z.3,@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C<Q"B,Z(&QI8B].970O
M4TU3+W=I;E]H='1P+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A
M;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S='(@(D1E<W1I;F%T87)I;R!N
M;R!VX6QI9&\Z(%PB)7-<(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3`X
M,"!L:6(O2&]R9&4O2V]L86(N<&AP.C$R-C,*;7-G:60@(DEN=F%L:60@<VAA
M<F4@;V)J96-T(@IM<V=S='(@(D]B:F5T;R!C;VUP87)T:61O(&YO(';A;&ED
M;RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM
M<V=I9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B1&ER96-C
M:?-N(&1E;"!R96UI=&5N=&4@;F\@=N%L:61A(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D
M92!D871A+B(*;7-G<W1R(")$871O<R!U;FEC;V1E(&YO(';A;&ED;W,N(@H*
M(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z,S4Y"FUS9VED("))
M;G9E;G1O<GDB"FUS9W-T<B`B26YV96YT87)I;R(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HV-S@*;7-G:60@(DEN=F5R="!S96QE
M8W1I;VXB"FUS9W-T<B`B26YV97)T:7(@<V5L96-C:?-N(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$Q,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$Y"FUS9VED("))
M<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM<V=S='(@(DERX6XL(%)E</IB
M;&EC82!)<VSA;6EC82!D92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$Q.`IM<V=I9"`B27)A<2(*;7-G<W1R("))<F%Q
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3$S"FUS9VED("))<F5L86YD(@IM<V=S='(@(DER;&%N9&$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G
M<W1R("))<VQA(&1E($UA;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(T"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G
M<W1R(")";W)R87-C87,@86ES;&%D87,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,30*;7-G:60@(DES<F%E;"(*;7-G
M<W1R("))<W)A96PB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8R
M-@IM<V=I9"`B27-S=65R(@IM<V=S='(@(D5M:7-O<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC
M(@IM<V=S='(@(D-U<G-I=F$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,C$*;7-G:60@(DET86QY(@IM<V=S='(@(DET
M86QI82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$R,PIM<V=I9"`B2F%M86EC82(*;7-G<W1R(")*86UA:6-A(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB
M"FUS9W-T<B`B16YE<F\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,C4*;7-G:60@(DIA<&%N(@IM<V=S='(@(DIA</-N
M(@H*(SH@8V]N9FEG+RYB86LO;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B2F%P
M86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R(")*87!O;NES("A)4T\M,C`R
M,BU*4"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(R"FUS9VED(")*
M97)S97DB"FUS9W-T<B`B2F5R<V5Y(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(T"FUS9VED(")*;W)D86XB"FUS9W-T
M<B`B2F]R9.%N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P."!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*
M;7-G:60@(DIU;'DB"FUS9W-T<B`B2G5L:6\B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R(")*=6YI;R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`B2G5S=&EF:6-A<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$U"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R(")!;&EN96%R(&%L
M(&-E;G1R;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B
M2G5S=&EF:6-A<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y($QE9G0B"FUS9W-T
M<B`B06QI;F5A<B!A(&QA(&EZ<75I97)D82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V"FUS9VED(")*=7-T
M:69Y(%)I9VAT(@IM<V=S='(@(D%L:6YE87(@82!L82!D97)E8VAA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$Q.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,V"FUS
M9VED(")+87IA:VAS=&%N(@IM<V=S='(@(DMA>F%K:'-T86XB"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C8U"FUS9VED(")+965P
M(&]R:6=I;F%L/R(*;7-G<W1R("*_0V]N<V5R=F%R(&5L(&]R:6=I;F%L/R(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,C`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R
M-@IM<V=I9"`B2V5N>6$B"FUS9W-T<B`B2V5N>6$B"@HC.B!L:6(O2&]R9&4O
M075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C
M=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")%;"!S97)V:61O<B!+97)B
M97)O<R!H82!R96-H87IA9&\@;&$@875T96YT:69I8V%C:?-N+B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B
M"FUS9W-T<B`B3F]V871O<R!D96P@2V5R;F5L(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`B
M0W)E86-I\VX@9&4@8VQA=F4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HT,30*;7-G:60@(DME>2!&:6YG97)P<FEN="(*;7-G<W1R(")(=65L;&$@
M9&EG:71A;"!D92!L82!C;&%V92(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R(")486UA\6\@9&4@
M8VQA=F4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@
M(DME>2!4>7!E(@IM<V=S='(@(E1I<&\@9&4@8VQA=F4B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4Y.0IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S
M='(@(E5S;R!D92!L82!C;&%V93HB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HW-#`*;7-G:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B
M;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B3&$@8VQA=F4@>6$@97AI<W1E(&5N
M(&5L('-E<G9I9&]R(&1E(&-L879E<R!P^F)L:6-O+B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G<W1R(").:?%O<R(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@T(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,C$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R
M.0IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B2VER:6)A=&DB"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S(*;7-G:60@
M(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM<V=S
M='(@(D-O<F5A+"!297#Z8FQI8V$@4&]P=6QA<B!$96UO8W+A=&EC82!D92(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@U(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,C,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S
M,PIM<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(D-O<F5A+"!2
M97#Z8FQI8V$@9&4B"@HC.B!C;VYF:6<O+F)A:R]N;',N<&AP+F1I<W0Z,3DQ
M"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`B0V]R96%N;R`H155#
M+4M2*2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@V(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$S-`IM<V=I9"`B2W5W86ET(@IM<V=S='(@(DMU=V%I="(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@S(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,C4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-PIM<V=I
M9"`B2WER9WEZ<W1A;B(*;7-G<W1R(")+>7)G>7IS=&%N(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED("),85]Y;W5T(@IM<V=S='(@
M(E]$:7-T<FEB=6-I\VXB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C@S"FUS9VED("),86YG=6%G92(*;7-G<W1R("))9&EO;6$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S<*;7-G:60@
M(DQA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(DQA
M;RP@4F5P^F)L:6-A($1E;6]C<N%T:6-A(%!O<'5L87(B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),87-T($AA;&8B"FUS9W-T<B`B0W5A
M<G1O(&UE;F=U86YT92(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX.`IM
M<V=I9"`B3&%S="!087-S=V]R9"!#:&%N9V4B"FUS9W-T<B`BVFQT:6UO(&-A
M;6)I;R!D92!C;VYT<F%S9?%A(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@V
M(&QI8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R=&5R(@IM
M<V=S='(@(D-U87)T;R!M96YG=6%N=&4B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$U.`IM<V=I9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R("+:;'1I;6$@
M86-T=6%L:7IA8VGS;CHB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z-S$W"B,L
M('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(MIL
M=&EM82!S97-I\VXZ("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C<Q.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM
M<V=S='(@(MIL=&EM82!S97-I\VXZ("5S(&1E<V1E("5S(@H*(SH@;&EB+TAO
M<F1E+T%U=&@N<&AP.C<Q-`IM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS
M9W-T<B`BVFQT:6UA('-E<VGS;CH@3G5N8V$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#8*;7-G:60@(DQA='9I82(*
M;7-G<W1R("),871V:6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*
M;7-G:60@(DQA=R(*;7-G<W1R("),97EE<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0IM<V=I9"`B3&%Y;W5T
M(@IM<V=S='(@(D1I<W1R:6)U8VGS;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O
M<B!N;R!B;W)D97(B"FUS9W-T<B`B1&5J87(@96X@8FQA;F-O('!A<F$@96QI
M;6EN87(@96P@8F]R9&4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,S@*;7-G:60@(DQE8F%N;VXB"FUS9W-T<B`B3&5B
M86YO;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT,`IM<V=I9"`B3&5F="(*;7-G<W1R("))>G%U:65R9&$B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P,0IM<V=I9"`B3&5F="!H96%D97(B
M"FUS9W-T<B`B0V%B96-E<F$@:7IQ=6EE<F1A(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C,P.3<*;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@(E9A;&]R
M97,@9&4@;&$@:7IQ=6EE<F1A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,30S"FUS9VED("),97-O=&AO(@IM<V=S='(@
M(DQE<V]T:&\B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*
M;7-G:60@(DQE=F5L(@IM<V=S='(@(DYI=F5L(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S
M,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30R"FUS9VED("),:6)E<FEA
M(@IM<V=S='(@(DQI8F5R:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-#<*;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H
M:7)I>6$B"FUS9W-T<B`B3&EB>6%N($%R86(@2F%M86AI<FEY82(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@X(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,S(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,`IM<V=I
M9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("),:65C:'1E;G-T96EN(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@
M(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`B3&EG97)A(&QL;W9I>FYA(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*;7-G:60@
M(DQI9VAT(%)A:6XB"FUS9W-T<B`B3&QU=FEA(&QI9V5R82(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H
M="!286EN($5A<FQY(@IM<V=S='(@(DQL=79I82!L:6=E<F$@;6%T=71I;F$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM
M<V=I9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(DQL=79I82!L:6=E<F$@
M=F5S<&5R=&EN82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R(")!
M9W5A8V5R;R!L:6=E<F\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS,`IM<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B
M"FUS9W-T<B`B3&QU=FEA<R!Y('1R=65N;W,B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B3&EG:'0@4VYO=R(*
M;7-G<W1R(").979A9&$@<W5A=F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B3&EG:'0@4VYO=R!3:&]W97(B
M"FUS9W-T<B`B3&EG97)O(&%G=6%C97)O(&1E(&YI979E(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0U"FUS9VED("),:6UE<FEC:R(*;7-G<W1R(")#
M:&%S8V%R<FEL;&\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@Q-`IM<V=I
M9"`B3&EN:R(*;7-G<W1R(")6[6YC=6QO(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED("),:6YK
M('!O:6YT<R!T;SHB"FUS9W-T<B`B16P@=NUN8W5L;R!A<'5N=&$@83HB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W-0IM<V=I9"`B3&EN:R!T:&4@96UA
M:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN
M9R(*;7-G<W1R(")6:6YC=6QA<B!D:7)E8V-I\VX@9&4@8V]R<F5O(&$@;&$@
M<.%G:6YA(&1E(&-O;7!O<VEC:?-N(&%L(&UO<W1R87(B"@HC.B!L:6(O2&]R
M9&4O5&5X="]&:6QT97(O:'1M;#)T97AT+G!H<#HQ.#(*;7-G:60@(DQI;FMS
M(@IM<V=S='(@(E;M;F-U;&]S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0V"FUS9VED("),:6YU>"!#;V]K:64B"FUS9W-T<B`B0V]O:VEE($QI;G5X
M(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V(&QI8B](
M;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HT-@IM<V=I9"`B3&ES="`M('5S
M97(@8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(DQI<W1A<B`M(&5L('5S
M=6%R:6\@<'5E9&4@97AA;6EN87(@;&$@8V%R<&5T82(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,S0*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@
M(DQI<W1A<B!B87-E<R!D92!D871O<R(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD
M97@N<&AP.C4Q"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(DQI
M<W1A<B!T96UA<R!D92!A>75D82(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,S,*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(DQI<W1A<B!T86)L87,B
M"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HV,#$*;7-G:60@(DQI
M<W0M07)C:&EV92(*;7-G<W1R("),:7-T+4%R8VAI=F4B"@HC.B!L:6(O2&]R
M9&4O34E-12](96%D97)S+G!H<#HU.38*;7-G:60@(DQI<W0M2&5L<"(*;7-G
M<W1R("),:7-T+4AE;'`B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H
M<#HV,#,*;7-G:60@(DQI<W0M260B"FUS9W-T<B`B3&ES="U)9"(*"B,Z(&QI
M8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y.0IM<V=I9"`B3&ES="U/=VYE
M<B(*;7-G<W1R("),:7-T+4]W;F5R(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A
M9&5R<RYP:'`Z-C`P"FUS9VED("),:7-T+5!O<W0B"FUS9W-T<B`B3&ES="U0
M;W-T(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DX"FUS9VED
M("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("),:7-T+5-U8G-C<FEB92(*"B,Z
M(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y-PIM<V=I9"`B3&ES="U5
M;G-U8G-C<FEB92(*;7-G<W1R("),:7-T+55N<W5B<V-R:6)E(@H*(SH@861M
M:6XO<V5S<VEO;G,N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I
M;F<@<V5S<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R(")(82!F86QL861O(&5L
M(&QI<W1A9&\@9&4@;&%S('-E<VEO;F5S.B`E<R(*"B,Z(&%D;6EN+W-E<W-I
M;VYS+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('5S97)S
M(&9A:6QE9#H@)7,B"FUS9W-T<B`B2&$@9F%L;&%D;R!E;"!L:7-T861O(&1E
M('5S=6%R:6]S.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES
M="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS
M9W-T<B`B16P@;&ES=&%D;R!D92!U<W5A<FEO<R!E<W3A(&1E<VAA8FEL:71A
M9&\N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),:71E
M<F%T=7)E(@IM<V=S='(@(DQI=&5R871U<F$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#0*;7-G:60@(DQI=&AU86YI
M82(*;7-G<W1R("),:71U86YI82(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]I;6%G97,N<&AP.C<W"FUS9VED("),;V%D:6YG+BXN(@IM<V=S='(@(DQE
M>65N9&\N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`P
M"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B2&]R82!L;V-A;#H@(@H*
M(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z.#8*;7-G:60@(DQO8V%L
M92!A;F0@5&EM92(*;7-G<W1R("))9&EO;6$@>2!H;W)A(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HW,B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4W(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-3<R"FUS9VED("),;V-A=&EO;B(*;7-G<W1R(")58FEC
M86-I\VXB"@HC.B!L;V=I;BYP:'`Z,3@Y('-E<G9I8V5S+W!O<G1A;"]S:61E
M8F%R+G!H<#HR,#0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY,`HC.B!T
M96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS('1E;7!L871E<R]L;V=I;B]M
M;V)I;&4N:6YC.C$U"FUS9VED("),;V<@:6XB"FUS9W-T<B`B26YI8VEA<B!S
M97-I\VXB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*;7-G
M:60@(DQO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B4F5G
M:7-T<F\@9&4@;&%S('-E<VEO;F5S(&1E('-I;F-R;VYI>F%C:?-N(&%N=&5R
M:6]R97,B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3DX"FUS
M9VED("),;V<@;W5T(@IM<V=S='(@(E-A;&ER(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C8Q"FUS9VED("),;V=I;B(*;7-G<W1R("));FEC:6%R('-E
M<VGS;B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$Q,`IM<V=I
M9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B5&%R96%S(&1E(&EN:6-I;R!D92!S
M97-I\VXB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3DU"FUS9VED("),;V=I
M;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A
M<R!E;G1E<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R("(B"B)&86QL\R!E;"!I
M;FEC:6\@9&4@<V5S:?-N('!O<G%U92!I;G1R;V1U:F\@:6YC;W)R96-T86UE
M;G1E('-U(&YO;6)R92!D92`B"B)U<W5A<FEO(&\@8V]N=')A<V7Q82XB"@HC
M.B!L:6(O2&]R9&4O075T:"YP:'`Z.3DQ"FUS9VED("),;V=I;B!F86EL960N
M(@IM<V=S='(@(D9A;&SS(&5L(&EN:6-I;R!D92!S97-I\VXN(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$S-C4*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R
M(")497AT;R!C;VUP;&5T;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M.`IM<V=I9"`B3&]V92(*;7-G<W1R(")!;6]R(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DQO=R(*;7-G<W1R
M(")"86IA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*
M;7-G<W1R(")!;&9A8F5T;R!G<FEE9V\@96X@;6EN^G-C+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*
M;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B06QF86)E=&\@
M;&%T:6YO(&5N(&UI;OIS8RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$W"FUS9VED("),;W=E<B!R;VUA
M;B!N=6UB97)S(@IM<V=S='(@(D[Z;65R;W,@<F]M86YO<R!E;B!M:6[Z<V,N
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$S-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,30U"FUS9VED("),=7AE;6)O=7)G(@IM<V=S='(@(DQU>&5M8G5R9V\B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Q(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,SD*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(DU-(@H*(SH@8V]N9FEG
M+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z,C@S"FUS9VED(")-3U1$(@IM<V=S
M='(@(DU/5$0B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&YE9BYP:'`Z
M,S8*;7-G:60@(DU3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T
M82XB"FUS9W-T<B`B16P@861J=6YT;R!-4RU43D5&(&YO(&-O;G1E;NUA(&1A
M=&]S+B(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B
M:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S='(@(DU31R(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDR(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,S4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-PIM<V=I9"`B
M36%C86\B"FUS9W-T<B`B36%C86\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-3,*;7-G:60@(DUA8V5D;VYI82P@5&AE
M($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G<W1R(")-86-E9&]N
M:6$L($%N=&EG=6$@4F5P^F)L:6-A(%EU9V]S;&%V82!D92(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDP(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,S<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,0IM<V=I9"`B
M36%D86=A<V-A<B(*;7-G<W1R(")-861A9V%S8V%R(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C0Y"FUS9VED(")-86=I8R(*;7-G<W1R(")-86=I82(*
M"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C@S"FUS9VED(")-
M86EL(@IM<V=S='(@(D-O<G)E;R(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y
M+G!H<"YD:7-T.C4R-`IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R(")!9&TN
M(&-O<G)E;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R
M(")#<F5A<B!?=NUN8W5L;RXN+B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDT(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$V-0IM<V=I9"`B36%L87=I(@IM<V=S='(@
M(DUA;&%W:2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$V-PIM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B36%L87-I82(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-#`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V
M-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B36%L9&EV87,B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-30*;7-G:60@
M(DUA;&DB"FUS9W-T<B`B36%L:2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDT(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$V,@IM<V=I9"`B36%L=&$B"FUS9W-T<B`B
M36%L=&$B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HY-`IM<V=I
M9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@
M=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D
M('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B(@HB1V5S=&EO;F$@
M;&$@;&ES=&$@9&4@8V%T96=O<NUA<R!C;VX@;&$@<75E(&5T:7%U971A<B!E
M;&5M96YT;W,@>2!L;W,@8V]L;W)E<R`B"B)A<V]C:6%D;W,@82!D:6-H87,@
M8V%T96=O<NUA<RXB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3$U-@IM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(DUA<&$@;6%P
M,C0B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X
M-PHC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$W,0IM
M<V=I9"`B36%P475E<W0@;6%P(@IM<V=S='(@(DUA<&$@;6%P<75E<W0B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I
M;F=S('-T;W)E9"XB"FUS9W-T<B`B0V]R<F5S<&]N9&5N8VEA<R!A;&UA8V5N
M861A<RXB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`T(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I
M9"`B36%R8V@B"FUS9W-T<B`B36%R>F\B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q"FUS9VED(")-87)G:6XB
M"FUS9W-T<B`B36%R9V5N(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C@X(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HT.`IM
M<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L86=S(@IM<V=S='(@(DUA
M<F-A<B!C;VX@;&%S(&)A;F1E<F%S(&1E($QE[61O+U-I;B!L965R(@H*(SH@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@Y(&QI8B](;W)D92])
M34%0+T%#3"]R9F,T,S$T+G!H<#HT.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R
M(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B36%R
M8V%R(&-O;B!O=')A<B!B86YD97)A<R`H<"YE+B!);7!O<G1A;G1E+U)E<W!O
M;F1I9&\I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3$@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,34R"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(DES
M;&%S($UA<G-H86QL(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,34Y"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@(DUA
M<G1I;FEC82(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS
M9VED(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`B0V%M<&]S(&-O:6YC:61E
M;G1E<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDS(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$V,`IM<V=I9"`B36%U<FET86YI82(*;7-G<W1R(")-875R:71A;FEA
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$T-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,38S"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`B36%U<FEC:6\B"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X
M(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R(")386QD;R!MX7AI;6\@<&5R;6ET
M:61O+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X
M"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB"FUS9W-T<B`B
M4V4@:&$@<V]B<F5P87-A9&\@96P@;OIM97)O(&WA>&EM;R!D92!P87)T97,@
M9&4@;65N<V%J92XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,PIM<V=I
M9"`B36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(E1E;7`N(&WA
M>&EM82#Z;'1I;6%S(#(T(&AO<F%S.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,P-0IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T
M<B`B5&5M<"X@;>%X:6UA(/IL=&EM87,@-B!H;W)A<SH@(@H*(SH@;&EB+V%P
M:2YP:'`Z.#8*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C
M:W,B"FUS9W-T<B`B3OIM97)O(&WA>&EM;R!D92!B;&]Q=65S(&1E;"!P;W)T
M86PB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DX(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,C$W(&QI8B](;W)D92]&;W)M+G!H<#HQ,C,Y"FUS9VED(")-87AI
M;75M(&QE;F=T:"(*;7-G<W1R("),;VYG:71U9"!MX7AI;6$B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@
M(DUA>6\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C4S"FUS9VED(")-87EO='1E(@IM<V=S='(@(DUA>6]T=&4B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*;7-G:60@(DUE9&EC:6YE(@IM
M<V=S='(@(DUE9&EC:6YA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E
M9&ET+FEN8SHQ-@IM<V=I9"`B365M8F5R<R(*;7-G<W1R(")-:65M8G)O<R(*
M"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C,X,@IM<V=I9"`B365N
M=2!M;V1E.B(*;7-G<W1R(")&;W)M871O(&1E;"!M96[Z.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*;7-G
M:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@(D-O;6)I;F%R(&-E;&1A<R(*"B,Z
M(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS
M,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DUE
M<W-A9V4B"FUS9W-T<B`B365N<V%J92(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z,C$V"FUS9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U8V-E
M<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO
M="!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@HB4V4@:&$@8V]M<')O8F%D
M;R!C;W)R96-T86UE;G1E(&5L(&UE;G-A:F4@<&5R;R!N;R!S92!P=65D92!V
M97)I9FEC87(@96P@(@HB8V5R=&EF:6-A9&\@9&5L(&9I<FUA;G1E+B(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"FUS9VED(")-
M97-S86=E(&5X<&ER960N(@IM<V=S='(@(DUE;G-A:F4@8V%D=6-A9&\N(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4V.2!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C`R"FUS9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`B5&EP
M;R!D92!M96YS86IE(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS9VED
M(")-971A<B!796%T:&5R(@IM<V=S='(@(E1I96UP;R!D92!-971A<B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(D)L;W%U92!-971A<B!N;R!D:7-P;VYI
M8FQE+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED("(B"B)-
M971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L
M;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)";&]Q
M=64@365T87(@;F\@9&ES<&]N:6)L92X@4V4@:&%N(')E9VES=')A9&\@;&]S
M(&1E=&%L;&5S('!A<F$@96P@(@HB861M:6YI<W1R861O<BXB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34S"FUS9VED(")-971A<D1"(&ES
M(&YO="!C;VYN96-T960N(@IM<V=S='(@(DYO(&5S=.$@8V]N96-T861A(&QA
M($UE=&%R1$(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV
M-R!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B365T
M:&]D(@IM<V=S='(@(DWI=&]D;R(*"B,Z(&QI8B](;W)D92]24$,O<V]A<"YP
M:'`Z,3$W(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HX,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D(@IM<V=S
M='(@(D5L(&WI=&]D;R!<(B5S7"(@;F\@97-TX2!D969I;FED;R(*"B,Z(&QI
M8B](;W)D92]24$,O<F5S="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D.B`E<R(*;7-G<W1R
M(")-Z71O9&\@;F\@9&5F:6YI9&\N($WI=&]D;R!L;&%M861O.B`E<R(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z.#(@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C8W"FUS9VED(")-971R:6,B"FUS9W-T<B`B3>ET<FEC;R(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-#@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-@IM
M<V=I9"`B365X:6-O(@IM<V=S='(@(DWI:FEC;R(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-#D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@U"FUS9VED(")-:6-R;VYE
M<VEA+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(DUI8W)O;F5S:6$L
M($5S=&%D;W,@1F5D97)A9&]S(&1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0R"FUS9VED(")-:61D;&4B"FUS
M9W-T<B`B16X@;65D:6\B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&YE
M9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*;7-G<W1R(")4:7!O($UI;64B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q-PIM<V=I9"`B36EN('1E;7`@
M;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(E1E;7`N(&WM;BX@;&%S(/IL=&EM
M87,@,C0@:&]R87,Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`Y"FUS
M9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R(")496UP+B!M
M[6XN(&QA<R#Z;'1I;6%S(#8@:&]R87,Z("(*"B,Z(&QI8B](;W)D92]!=71H
M+VQD87`N<&AP.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S
M(&YO="!Y970@97AP:7)E9"(*;7-G<W1R(")4;V1A=NUA(&YO(&AA(&5X<&ER
M861O(&QA(&%N=&EG_&5D860@;>UN:6UA(&1E(&QA(&-O;G1R87-E\6$B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,U"FUS9VED
M(")-:7)R;W(B"FUS9W-T<B`B4F5F;&5J87(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B36ES
M8V5LX6YE82(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S0P(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(*(SH@;&EB
M+TYE="]335,O=VEN7VAT='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!014%2
M('!A8VMA9V4@2%144%]297%U97-T+B(*;7-G<W1R(")087%U971E(%!%05(@
M2%144%]297%U97-T(&1E<V%P87)E8VED;RXB"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3$T"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN
M(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U
M<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@HB1F%L=&$@;&$@
M8V]N9FEG=7)A8VGS;BX@5&EE;F4@<75E(&=E;F5R87)L82!A:&]R82!S:2!D
M97-E82!U=&EL:7IA<B!E<W1A("(*(F%P;&EC86-I\VXN(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@
M;65S<V%G92!)1"XB"FUS9W-T<B`B240@9&4@;65N<V%J92!D97-A<&%R96-I
M9&\N(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU
M.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"XB
M"FUS9W-T<B`B4&%Q=65T92!014%2($UA:6P@9&5S87!A<F5C:61O+B(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDT"FUS9VED(")-
M:7-S:6YG('-E<W-I;VX@240N(@IM<V=S='(@(DE$(&1E('-E<VGS;B!D97-A
M<&%R96-I9&\N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`B3'5N(@H*(SH@8V]N9FEG
M+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z-S8*;7-G:60@(DUO8FEL92!-86EL
M(@IM<V=S='(@(D-O<G)E;R!M\W9I;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C<P"FUS9VED(")-;V1E<F%T92(*;7-G<W1R
M(")-;V1E<F%D;R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP
M.C8V(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@U"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"FUS9VED(")-;V1I9FEE9"!$
M871E(@IM<V=S='(@(E-E(&AA(&UO9&EF:6-A9&\@;&$@9F5C:&$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B36]D:69I8V%R(%523"(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C<T"FUS9VED(")-;V1U
M;'5S(@IM<V=S='(@(DWS9'5L;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDP(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$U,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L
M:6,@;V8B"FUS9W-T<B`B36]L9&%V:6$L(%)E</IB;&EC82!D92(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDP(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-3$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T.0IM<V=I
M9"`B36]N86-O(@IM<V=S='(@(DWS;F%C;R(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDR(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3(*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-@IM<V=I9"`B36]N9V]L:6$B
M"FUS9W-T<B`B36]N9V]L:6$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4X
M-`IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B365S('D@8?%O(@H*
M(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL
M>2(*;7-G<W1R(")-96YS=6%L;65N=&4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C$*;7-G:60@(DUO;G1S97)R870B
M"FUS9W-T<B`B36]N='-E<G)A="(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS
M(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS
M9W-T<B`B1F%S97,@9&4@;&$@;'5N82(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z
M,3DV(&QI8B]&:6QE+T-35BYP:'`Z,C@P"B,L('!H<"UF;W)M870*;7-G:60@
M(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T
M960@)60N(@IM<V=S='(@(E-E(&AA;B!E;F-O;G1R861O(&WA<R!C86UP;W,@
M96X@;&$@;.UN96$@)60@<75E(&QO<R`E9"!E<W!E<F%D;W,N(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$U-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30X"FUS9VED
M(")-;W)O8V-O(@IM<V=S='(@(DUA<G)U96-O<R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@0VQE
M87(B"FUS9W-T<B`B1G5N9&%M96YT86QM96YT92!D97-P96IA9&\B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-`IM<V=I9"`B
M36]S=&QY($-L;W5D>2(*;7-G<W1R(")&=6YD86UE;G1A;&UE;G1E(&YU8F]S
M;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,U
M"FUS9VED(")-;W-T;'D@0VQO=61Y(&%N9"!7:6YD>2(*;7-G<W1R(")&=6YD
M86UE;G1A;&UE;G1E(&YU8F]S;R!Y('9E;G1O<V\B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B36]S=&QY(%-U
M;FYY(@IM<V=S='(@(D9U;F1A;65N=&%L;65N=&4@<V]L96%D;R(*"B,Z(&QI
M8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C0X"FUS9VED(")-
M;W9E($1O=VXB"FUS9W-T<B`B1&5S<&QA>F%R(&AA8VEA(&%B86IO(@H*(SH@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-3(*;7-G:60@
M(DUO=F4@3&5F="(*;7-G<W1R(")$97-P;&%Z87(@82!L82!I>G%U:65R9&$B
M"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U-@IM
M<V=I9"`B36]V92!2:6=H="(*;7-G<W1R(")$97-P;&%Z87(@82!L82!D97)E
M8VAA(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV
M-#0*;7-G:60@(DUO=F4@57`B"FUS9W-T<B`B1&5S<&QA>F%R(&AA8VEA(&%R
M<FEB82(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU
M,C8*;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R(")$97-P;&%Z87(@:&%C:6$@
M86)A:F\B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-3(U(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU,C8*;7-G
M:60@(DUO=F4@=7`B"FUS9W-T<B`B1&5S<&QA>F%R(&AA8VEA(&%R<FEB82(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-34*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V
M.`IM<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R(")-;WIA;6)I<75E(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(Q.#0*;7-G:60@(DUU;'1I+6QE=F5L(&1R
M;W`@9&]W;B!L:7-T<R(*;7-G<W1R("),:7-T87,@9&5S<&QE9V%B;&5S(&UU
M;'1I+6YI=F5L(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$P-3D*;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R(")-87!A
M(%5+(&WZ;'1I<&QE(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-#(*;7-G
M:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R(")396QE8V-I\VX@;?IL
M=&EP;&4B"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HT,#(*
M;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T<B`B261E;G1I9&%D(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C(X"FUS9VED(")->2!!8V-O=6YT($EN9F]R
M;6%T:6]N(@IM<V=S='(@(DUI(&ED96YT:61A9"(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]I;F1E>"YP:'`Z-#0*;7-G:60@(DUY(%!O<G1A;"(*;7-G<W1R(")-
M:2!P;W)T86PB"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z-#(*;7-G
M:60@(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B1&ES=')I8G5C:?-N(&1E
M(&UI('!O<G1A;"(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$U-0IM<V=I9"`B37EA;FUA<B(*;7-G<W1R(")->6%N;6%R
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ
M-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R(").3RP@3D\@
M97-T;WD@9&4@86-U97)D;R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T
M;F5F+G!H<#HS."!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$P
M,@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DYA;64B
M"FUS9W-T<B`B3F]M8G)E(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,38Y"FUS9VED(").86UI8FEA(@IM<V=S='(@(DYA
M;6EB:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-S@*;7-G:60@(DYA=7)U(@IM<V=S='(@(DYA=7)U(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$U.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<W"FUS9VED
M(").97!A;"(*;7-G<W1R(").97!A;"(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDW(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-0IM<V=I9"`B3F5T:&5R;&%N9',B
M"FUS9W-T<B`B2&]L86YD82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C4W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(S"FUS9VED(").971H97)L86YD<R!!;G1I;&QE
M<R(*;7-G<W1R(")!;G1I;&QA<R!(;VQA;F1E<V%S(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G:60@(DYE='-C87!E($)A<V4@55),
M(@IM<V=S='(@(E523"!B87-E(&1E($YE='-C87!E(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU.#0*;7-G:60@(DYE='-C87!E($-!(%)E=F]C
M871I;VX@55),(@IM<V=S='(@(E523"!D92!A;G5L86-I\VX@9&4@0T$@9&4@
M3F5T<V-A<&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-@IM
M<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R(")54DP@9&4@
M<&]L[71I8V%S(&1E($-!(&1E($YE='-C87!E(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU.#4*;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),
M(@IM<V=S='(@(E523"!D92!R96YO=F%C:?-N(&1E($YE='-C87!E(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C87!E
M(%)E=F]C871I;VX@55),(@IM<V=S='(@(E523"!D92!A;G5L86-I\VX@9&4@
M3F5T<V-A<&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-PIM
M<V=I9"`B3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(DYO;6)R
M92!D92!S97)V:61O<B!34TP@9&4@3F5T<V-A<&4B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C4X.`IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A
M=&4@8V]M;65N="(*;7-G<W1R(")#;VUE;G1A<FEO(&1E;"!C97)T:69I8V%D
M;R!D92!.971S8V%P92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3@Q"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@
M(E1I<&\@9&4@8V5R=&EF:6-A9&\@9&4@3F5T<V-A<&4B"@HC.B!C;VYF:6<O
M+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HR-3,*;7-G:60@(DYE='=O<FLB"FUS
M9W-T<B`B4F5D(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(U(&-O
M;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C,S.0HC.B!C;VYF:6<O+F)A:R]P
M<F5F<RYP:'`N9&ES=#HS.3`*;7-G:60@(DYE=F5R(@IM<V=S='(@(DYU;F-A
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$V,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3<P"FUS9VED(").97<@0V%L961O;FEA(@IM<V=S='(@(DYU979A($-A;&5D
M;VYI82(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP
M.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C(V"FUS9VED(").97<@0V%T96=O<GDB"FUS9W-T<B`B3G5E=F$@8V%T96=O
M<NUA(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N
M+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED(").97<@36]O
M;B(*;7-G<W1R("),=6YA(&YU979A(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA
M;"DB"FUS9W-T<B`B3G5E=F\@;F]M8G)E(&1E('5S=6%R:6\@*&]P8VEO;F%L
M*2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$X,`IM<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B3G5E=F$@6F5L86YD
M82(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-PIM<V=I9"`B
M3F5W('!A<W-W;W)D(@IM<V=S='(@(D-O;G1R87-E\6$@;G5E=F$B"@HC.B!L
M:6(O2&]R9&4O075T:"]S<6PN<&AP.C(R-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(").97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@(DQA
M(&YU979A(&-O;G1R87-E\6$@97AP:7)A<N$@96P@)7@N(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R"FUS9VED(").97<@<&%S<W=O<F1S
M(&1O;B=T(&UA=&-H+B(*;7-G<W1R("),87,@8V]N=')A<V7Q87,@;F\@8V]I
M;F-I9&5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B
M3G5E=F$@=F5N=&%N82`H7V)L86YK*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU,B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,`HC.B!C;VYF:6<O+F)A
M:R]R96=I<W1R>2YP:'`N9&ES=#HR.3$*;7-G:60@(DYE=W,B"FUS9W-T<B`B
M3F]T:6-I87,B"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HS
M,#<*;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T<B`B1RX@9&4@;F]T:6-I87,B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR-2!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C$R.0HC.B!T96UP;&%T97,O9&%T82]D871E;6%P
M+FEN8SHT,2!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ-0IM<V=I9"`B
M3F5X="(*;7-G<W1R(")3:6=U:65N=&4B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,C<*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B4'+S>&EM87,@
M-"!F87-E<R(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S8V(&QI8B](
M;W)D92]0<F5F<R]522YP:'`Z,S<P"FUS9VED(").97AT(&]P=&EO;G,B"FUS
M9W-T<B`B3W!C:6]N97,@<VEG=6EE;G1E<R(*"B,Z(&QI8B](;W)D92]522]0
M86=E<BYP:'`Z,3`S"FUS9VED(").97AT/B(*;7-G<W1R(")3:6=U:65N=&4^
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$V-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3<T"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B3FEC87)A9W5A(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$V-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<Q"FUS
M9VED(").:6=E<B(*;7-G<W1R(").:6=E<B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDV(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C8*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,PIM<V=I9"`B3FEG97)I82(*
M;7-G<W1R(").:6=E<FEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,V.0IM<V=I9"`B3FEG:'0B"FUS9W-T<B`B3F]C:&4B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-SD*;7-G:60@
M(DYI=64B"FUS9W-T<B`B3FEU92(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HY-C8*;7-G:60@(DYO(@IM<V=S='(@(DYO(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS9VED(").;R!A
M=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC
M97,@9F]R+B(*;7-G<W1R(").;R!H87D@9&%T;W,@9&4@8V]N9FEG=7)A8VGS
M;B!P87)A(&UO<W1R87(@9&EF97)E;F-I87,N(@H*(SH@;&EB+U9&4R])4T]7
M<FET97(N<&AP.C$P-@IM<V=I9"`B3F\@879A:6QA8FQE('-T<F%T96=Y(&9O
M<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B3F\@<V4@9&ES<&]N92!D
M92!E<W1R871E9VEA(&1E(&5L86)O<F%C:?-N(&1E(&EMX6=E;F5S($E33RXB
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I
M9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(DYO(&AA>2!P;&%N=&EL
M;&$@9&4@;&]T97,B"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.C$P,0HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.C,X-0HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C0P-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@
M<&]S:71I;VXB"FUS9W-T<B`B3F\@:&%Y(&)L;W%U97,@96X@;&$@<&]S:6-I
M\VX@:6YD:6-A9&$B"@HC.B!L:6(O2&]R9&4O075T:"]M8V%L+G!H<#HU,`IM
M<V=I9"`B3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`B3F\@<V4@:&$@:6YT<F]D=6-I9&\@=6X@
M;F]M8G)E(&1E(&%G96YD82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!-0T%,
M+B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4T"FUS9VED(").;R!C:&%N
M9V4N(@IM<V=S='(@(E-I;B!C86UB:6]S+B(*"B,Z(&QI8B](;W)D92]097)M
M<R]522YP:'`Z,34V"FUS9VED(").;R!C:&EL9')E;B!C86X@8F4@861D960@
M=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R(").;R!S92!P=65D96X@8?%A
M9&ER(&1E<V-E;F1I96YT97,@82!E<W1E('!R:79I;&5G:6\N(@H*(SH@;&EB
M+TAO<F1E+G!H<#HQ-S@@;&EB+TAO<F1E+G!H<#HU,3<@;&EB+TAO<F1E+U5T
M:6PN<&AP.C<X,@HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@(DYO
M('-E(&AA(&5S<&5C:69I8V%D;R!I;F9O<FUA8VGS;B!D92!C;VYF:6=U<F%C
M:?-N('!A<F$@)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@V.`IM<V=I9"`B
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($94
M4"!61E,N(@IM<V=S='(@(DYO('-E(&AA(&5S<&5C:69I8V%D;R!I;F9O<FUA
M8VGS;B!D92!C;VYF:6=U<F%C:?-N('!A<F$@5D93('!O<B!&5%`N(@H*(SH@
M;&EB+U9&4R]S<6PN<&AP.C8X-`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S='(@(DYO
M('-E(&AA(&5S<&5C:69I8V%D;R!I;F9O<FUA8VGS;B!D92!C;VYF:6=U<F%C
M:?-N('!A<F$@5D93('!O<B!344PN(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z-S4S"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R("(B"B).;R!S92!H
M82!E<W!E8VEF:6-A9&\@:6YF;W)M86-I\VX@9&4@8V]N9FEG=7)A8VGS;B!P
M87)A(%9&4R!P;W(@87)C:&EV;R!344PN(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO(&-R961I="!L969T+B(*
M;7-G<W1R(").;R!Q=65D82!S86QD;RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED(").;R!D97-T:6YA=&EO;B!S=7!P
M;&EE9"XB"FUS9W-T<B`B3F\@<V4@:&$@:6YT<F]D=6-I9&\@96P@9&5S=&EN
M;RXB"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3$X"FUS9VED(").;R!F
M:6QE('5P;&]A9&5D(@IM<V=S='(@(DYO('-E(&AA(&-A<F=A9&\@;FEN9_IN
M(&%R8VAI=F\B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@
M(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R(").;R!S92!H86X@96YC;VYT<F%D
M;R!I8V]N;W,N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,S`@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ,38*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B
M3F\@<V4@:&$@9&5F:6YI9&\@;&$@=6)I8V%C:?-N+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*;7-G:60@(DYO(&QO8V%T:6]N('!R
M;W9I9&5D+B(*;7-G<W1R(").;R!S92!H82!D969I;FED;R!L82!U8FEC86-I
M\VXN(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,PIM
M<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`B3F\@<V4@:&$@
M:6YT<F]D=6-I9&\@=6X@;65N<V%J92XB"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,V"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB
M"FUS9W-T<B`B3F\@<V4@:&$@97-P96-I9FEC861O('5N(&YO;6)R92XB"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS9VED(").
M;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R(").;R!S92!H82!E<W!E8VEF
M:6-A9&\@=6X@;OIM97)O+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY
M-`IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(DYO(&]F
M96YS:79A<R(*"B,Z(&QI8B](;W)D92]!=71H+VAT='`N<&AP.CDQ"FUS9VED
M(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`B3F\@<V4@:&$@:6YT<F]D=6-I9&\@=6YA(&-O;G1R87-E
M\6$@<&%R82!L82!A=71E;G1I9FEC86-I\VX@2%144"XB"@HC.B!L:6(O2&]R
M9&4O075T:"]I;6%P+G!H<#HQ,#@*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").;R!S92!H
M82!I;G1R;V1U8VED;R!U;F$@8V]N=')A<V7Q82!P87)A(&QA(&%U=&5N=&EF
M:6-A8VGS;B!)34%0+B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C<R
M"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(DYO('-E(&AA(&EN=')O9'5C:61O('5N
M82!C;VYT<F%S9?%A('!A<F$@;&$@875T96YT:69I8V%C:?-N($ME<F)E<F]S
M+B(*"B,Z(&QI8B](;W)D92]!=71H+VQO9VEN+G!H<#HX-"!L:6(O2&]R9&4O
M075T:"]P86TN<&AP.C<U"B,Z(&QI8B](;W)D92]!=71H+W-A<VPN<&AP.C<W
M"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(DYO('-E(&AA(&EN=')O9'5C:61O('5N82!C
M;VYT<F%S9?%A('!A<F$@;&$@875T96YT:69I8V%C:?-N(&1E(&EN:6-I;RXB
M"@HC.B!L:6(O2&]R9&4O075T:"]P87-S=V0N<&AP.C$S-0IM<V=I9"`B3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B3F\@<V4@:&$@:6YT<F]D=6-I9&\@=6YA(&-O;G1R87-E\6$@
M<&%R82!L82!A=71E;G1I9FEC86-I\VX@4$%34U=$+B(*"B,Z(&QI8B](;W)D
M92]!=71H+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYO('-E(&AA(&EN
M=')O9'5C:61O('5N82!C;VYT<F%S9?%A('!A<F$@;&$@875T96YT:69I8V%C
M:?-N(%--0BXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R.#<*
M;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I
M9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O
M<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*(DYO('-E(&AA(&EN
M9&EC861O(';M82!D92!A8V-E<V\@82!L;W,@8FEN87)I;W,@3W!E;E-33"X@
M4&%R82!T<F%B86IA<B!C;VX@(@HB9&%T;W,@4$M#4R`Q,B!H86-E;B!F86QT
M82!L;W,@8FEN87)I;W,@3W!E;E-33"XB"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]A<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N
M(@IM<V=S='(@(E-I;B!A;'1A<R!P96YD:65N=&5S+B(*"B,Z(&QI8B]61E,N
M<&AP.C<V-@IM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R(")#87)E8V4@
M9&4@<75O=&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT,PIM<V=I9"`B3F\@<G5L97,B"FUS9W-T<B`B4VEN
M(')A>6%S(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HT.#(*;7-G:60@(DYO('-E
M<&%R871O<B!S<&5C:69I960N(@IM<V=S='(@(DYO('-E(&AA(&5S<&5C:69I
M8V%D;R!U;B!S97!A<F%D;W(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`IM<V=I9"`B3F\@<VED97,B"FUS
M9W-T<B`B3FEN9W5N;R(*"B,Z(&QI8B]61E,O<VUB+G!H<#HV,#`*;7-G:60@
M(DYO('-U8V@@9FEL92(*;7-G<W1R(").;R!E>&ES=&4@96P@87)C:&EV;R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C8*;7-G:60@(DYO
M('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS
M9W-T<B`B3F\@<V4@9&ES<&]N92!D92!U;B!D:7)E8W1O<FEO(&1E(&%L;6%C
M96YA;6EE;G1O('1E;7!O<F%L+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S$@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C(R,0IM
M<V=I9"`B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S
M='(@(DYO('-E(&AA(&5N=FEA9&\@96P@;F]M8G)E(&1E('5S=6%R:6\@>2]O
M(&QA(&-O;G1R87-E\6$N(@H*(SH@;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP
M.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T
M<B`B3F\@<V4@:&%N(&1E=G5E;'1O(&1A=&]S(%A-3"!VX6QI9&]S(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW-"!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@T"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HY.34*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$P,3(*;7-G:60@(DYO('9A;'5E<R(*;7-G
M<W1R(")3:6X@=F%L;W)E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M,3D*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG
M=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B
M"B).;R!S92!E;F-O;G1R\R!L82!V97)S:?-N(&5N(&QA(&-O;F9I9W5R86-I
M\VX@;W)I9VEN86PN(%)E9V5N97)A<B!L82`B"B)C;VYF:6=U<F%C:?-N+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C<*;7-G:60@(DYO('9E<G-I
M;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(DYO('-E(&5N8V]N='+S(&QA('9E
M<G-I\VX@96X@;&$@8V]N9FEG=7)A8VGS;BX@4F5G96YE<F%R(&QA(&-O;F9I
M9W5R86-I\VXN(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(W('1E
M;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3,*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-0IM<V=I
M9"`B3F]N92(*;7-G<W1R(").:6YG=6YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM
M<&QI8VET*2(*;7-G<W1R(").:6YG=6YO("AU<V\@:6UP;.UC:71O*2(*"B,Z
M(&-O;F9I9R\N8F%K+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(DYO<F1I8R`H
M25-/+3@X-3DM,3`I(@IM<V=S='(@(D[S<F1I8V\@*$E33RTX.#4Y+3$P*2(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-C@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W
M,@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B27-L82!D92!.;W)F
M;VQK(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N
M+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(")(
M96UI<V9E<FEO(&YO<G1E(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,34X"FUS9VED(").;W)T:&5R;B!-87)I86YA($ES
M;&%N9',B"FUS9W-T<B`B27-L87,@36%R:6%N87,@9&5L($YO<G1E(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$W,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<V"FUS
M9VED(").;W)W87DB"FUS9W-T<B`B3F]R=65G82(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-C0Q"FUS9VED(").;W0@069T97(B"FUS9W-T<B`B
M3F\@9&5S<'7I<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0P
M"FUS9VED(").;W0@0F5F;W)E(@IM<V=S='(@(DYO(&%N=&5S(@H*(SH@;&EB
M+U9&4R]F:6QE+G!H<#HT,C$*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G
M<W1R(").;R!E<R!U;B!D:7)E8W1O<FEO(@H*(SH@;&EB+U9&4R])4T]7<FET
M97(N<&AP.C8S(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+G!H<#HT.`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2YP:'`Z-3D*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T
M96=Y+G!H<#HX-`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R
M871E9WDN<&AP.CDU"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@
M(E-I;B!D97-A<G)O;&QA<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C8X"FUS9VED(").;W0@<V5T(@IM<V=S='(@(E-I
M;B!E<W1A8FQE8V5R(@H*(SH@;&EB+U9&4RYP:'`Z,3DS(&QI8B]61E,N<&AP
M.C(P."!L:6(O5D93+G!H<#HR,S0@;&EB+U9&4RYP:'`Z,C4R"B,Z(&QI8B]6
M1E,N<&AP.C(V.2!L:6(O5D93+G!H<#HR.#4@;&EB+U9&4RYP:'`Z,S`Q(&QI
M8B]61E,N<&AP.C,Q-@HC.B!L:6(O5D93+G!H<#HS,S,@;&EB+U9&4RYP:'`Z
M,S8V(&QI8B]61E,N<&AP.C0R-B!L:6(O5D93+G!H<#HU,#4*(SH@;&EB+U9&
M4RYP:'`Z-3<T(&QI8B]61E,N<&AP.C4Y,2!L:6(O5D93+G!H<#HV-CD*(SH@
M;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#4@;&EB+TAO<F1E+U-E
M<W-I;VY(86YD;&5R+G!H<#HQ-C`*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD
M;&5R+G!H<#HQ-S4@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#D*
M(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HR,S8*;7-G:60@(DYO
M="!S=7!P;W)T960N(@IM<V=S='(@(DYO(&5S=.$@<V]P;W)T861O+B(*"B,Z
M(&QI8B](;W)D92]+;VQA8BYP:'`Z.3`X(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,C0T"B,Z(&-O;F9I9R\N8F%K+VAO;VMS+G!H<"YD:7-T
M.C$P-3@@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z,3@P"FUS9VED
M(").;W1E<R(*;7-G<W1R(").;W1A<R(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R
M+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A
M8VLN(@IM<V=S='(@(DYO(&AA>2!N861A('9I<W5A;&EZ86)L92P@<F5T<F]C
M961A+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,3(@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED
M(").;W9E;6)E<B(*;7-G<W1R(").;W9I96UB<F4B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3`T-@IM<V=I9"`B3G5M8F5R(@IM<V=S='(@(D[Z;65R;R(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(U"FUS9VED(").=6UB97(@;V8@
M8VAA<F%C=&5R<R(*;7-G<W1R(").^FUE<F\@9&4@8V%R86-T97)E<R(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,S8Y(&QI8B](;W)D92]&;W)M+G!H<#HQ
M-#(S(&QI8B](;W)D92]&;W)M+G!H<#HQ-#0U"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB97(@;V8@
M8V]L=6UN<R(*;7-G<W1R(").^FUE<F\@9&4@8V]L=6UN87,B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3,V-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R,2!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,30T,PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B
M"FUS9W-T<B`B3OIM97)O(&1E(&9I;&%S(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E8VEF
M:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T
M<B`B(@HB3F\@<V4@:&%N(&5S<&5C:69I8V%D;R!N^FUE<F]S(&$@86-T=6%L
M:7IA<B!E;B!L82!L:7-T82!D92!D:7-T<FEB=6-I\VXN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8T"FUS9VED(")/2R(*
M;7-G<W1R(")!8V5P=&%R(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C@W,PIM<V=I9"`B3V)J96-T(@IM<V=S='(@(D]B:F5T;R(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS9VED(")/8FIE
M8W0@0W)E871O<B(*;7-G<W1R(")#<F5A9&]R(&1E(&]B:F5T;W,B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3$P-`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B
M3V-T86PB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#$Q(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#D*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I
M9"`B3V-T;V)E<B(*;7-G<W1R(")/8W1U8G)E(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R(")&
M:6QT<F%R(&]F96YS87,B"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N
M9&ES=#HS,C@*;7-G:60@(D]F9FEC92(*;7-G<W1R(")/9FEC:6YA(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/;&0@86YD
M(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N(@IM<V=S='(@(DQA
M(&-O;G1R87-E\6$@86YT:6=U82!Y(&QA(&YU979A(&1E8F5N('-E<B!D:7-T
M:6YT87,N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V"FUS
M9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`B0V]N=')A<V7Q82!A;G1I9W5A
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C0V"FUS9VED(")/
M;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N(@IM<V=S='(@(DQA(&-O;G1R
M87-E\6$@86YT:6=U82!N;R!E<R!C;W)R96-T82XB"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#$*;7-G:60@(D]M86XB
M"FUS9W-T<B`B3VWA;B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HW,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R
M960@9F]L9&5R<RXB"FUS9W-T<B`B4_-L;R!L;W,@<V5R=FED;W)E<R!)34%0
M('-O<&]R=&%N(&QA<R!C87)P971A<R!C;VUP87)T:61A<RXB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O
M<G1U;F5S(@IM<V=S='(@(E/S;&\@;V9E;G-I=F%S(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$X-3$@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-S$*;7-G:60@
M(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"XB"FUS9W-T<B`B4_-L
M;R!S92!P97)M:71E('5N82!D:7)E8V-I\VX@9&4@8V]R<F5O+B(*"B,Z('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@
M;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE
M<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS
M9W-T<B`B(@HB4_-L;R!E;"!P<F]P:65T87)I;R!O('5N(&%D;6EN:7-T<F%D
M;W(@9&4@<VES=&5M87,@<'5E9&4@8V%M8FEA<B!L82`B"B)P<F]P:65D860@
M;R!L;W,@<')I=FEL96=I;W,@9&4@<')O<&EE=&%R:6\@9&4@=6X@<F5C=7)S
M;R!C;VUP87)T:61O(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-#$@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z-#(*;7-G:60@(D]P96X@:6X@82!N97<@=VEN
M9&]W(@IM<V=S='(@(D%B<FER(&5N('5N82!N=65V82!V96YT86YA(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@
M97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-
M24U%('!A<G0N(@IM<V=S='(@(D5R<F]R($]P96Y34TPZ($YO('-E('!U961E
M;B!E>'1R865R(&1A=&]S(&1E(&QA('!A<G1E(%,O34E-12!F:7)M861A+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O
M=R(*;7-G<W1R(")!8G)I<B!E<W1E(';M;F-U;&\@96X@=6YA('9E;G1A;F$@
M;G5E=F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*;7-G:60@(D]P
M97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B4VES=&5M82!O<&5R871I=F\B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34U"FUS9VED(")/<'1I
M;VYS(@IM<V=S='(@(D]P8VEO;F5S(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP
M.C,Q('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@(D]P8VEO;F5S(&1E("5S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(DQI<W1A(&]R9&5N861A
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R
M9V%N:7-A=&EO;B(*;7-G<W1R(")/<F=A;FEZ86-I\VXB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I9"`B3W)G86YI<V%T:6]N86P@
M56YI="(*;7-G<W1R(")5;FED860@;W)G86YI>F%T:79A(@H*(SH@8V]N9FEG
M+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z,3,T"FUS9VED(")/<F=A;FEZ:6YG
M(@IM<V=S='(@(D]R9V%N:7IA8VGS;B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP
M:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*
M;7-G<W1R(")0;&%N=&EL;&$@9&4@87!L:6-A8VGS;B!O<FEG:6YA;"(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@
M(D]R:6=I;F%L('1E;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B4&QA;G1I;&QA
M<R!O<FEG:6YA;&5S(&5N("5S.B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R
M(@IM<V=S='(@(D]T<F\B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES
M=#HY.2!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HQ,#D*(SH@8V]N9FEG
M+RYB86LO<')E9G,N<&AP+F1I<W0Z,3$V(&-O;F9I9R\N8F%K+W!R969S+G!H
M<"YD:7-T.C$R-0HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HQ,S0@
M8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,30T"FUS9VED(")/=&AE<B!)
M;F9O<FUA=&EO;B(*;7-G<W1R(")/=')A(&EN9F]R;6%C:?-N(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,0IM<V=I9"`B3W=N97(@4&5R;6ES
M<VEO;G,B"FUS9W-T<B`B4')I=FEL96=I;W,@9&5L('!R;W!I971A<FEO(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O<&%M+G!H<#HW.0IM<V=I9"`B4$%-(&%U=&AE
M;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DQA(&%U=&5N
M=&EF:6-A8VGS;B!004T@;F\@97-TX2!D:7-P;VYI8FQE+B(*"B,Z(&QI8B].
M970O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL
M(&)A8VME;F0B"FUS9W-T<B`B4$5!4CHZ36]T;W(@9&4@8V]R<F5O(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3(W-@IM<V=I9"`B4$=0($1I9VET
M86P@4VEG;F%T=7)E(@IM<V=S='(@(D9I<FUA(&1I9VET86P@4$=0(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3,R,@IM<V=I9"`B4$=0($5N8W)Y
M<'1E9"!$871A(@IM<V=S='(@(D1A=&]S(&-I9G)A9&]S(&-O;B!01U`B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,S<T"FUS9VED(")01U`@4'5B
M;&EC($ME>2(*;7-G<W1R(")#;&%V92!01U`@</IB;&EC82(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C$S-38*;7-G:60@(E!'4"!3:6=N960O16YC
M<GEP=&5D($1A=&$B"FUS9W-T<B`B1&%T;W,@9FER;6%D;W,O8VEF<F%D;W,@
M8V]N(%!'4"(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV.0IM<V=I9"`B4$A0
M($-O9&4B"FUS9W-T<B`B0_-D:6=O(%!(4"(*"B,Z(&%D;6EN+W!H<'-H96QL
M+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(DEN=.ER<'(N(%!(
M4"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,X
M"FUS9VED(")032!,:6=H="!286EN(@IM<V=S='(@(DQL;W9I>FYA('9E<W!E
M<G1I;F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS.0IM<V=I9"`B4$T@4F%I;B(*;7-G<W1R("),;'5V:6$@=F5S<&5R=&EN
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P
M"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@(D-H87!A<G)O;F5S('9E<W!E
M<G1I;F]S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#$*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`B3FEE=F4@=F5S<&5R=&EN
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0R
M"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B06=U86-E<F\@9&4@
M;FEE=F4@=F5S<&5R=&EN;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0S"FUS9VED(")032!3=6XB"FUS9W-T<B`B4V]L('9E
M<W!E<G1I;F\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT-`IM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T<B`B0F]R<F%S8V%S
M('9E<W!E<G1I;F%S(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X-@IM
M<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T<B`B3F\@
M<V4@96YC=65N=')A(&QA(&5X=&5N<VGS;B!03U-)6"(*"B,Z(&QI8B]A<&DN
M<&AP.C$T.0IM<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R("));G3I<G!R+B!0
M7TA0(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R(")-87)G96XB"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#<*
M;7-G:60@(E!A:VES=&%N(@IM<V=S='(@(E!A:VES=.%N(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-S,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-`IM<V=I9"`B
M4&%L874B"FUS9W-T<B`B4&%L874B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DR"FUS9VED(")086QE<W1I;FEA;B!4
M97)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@(E!A;&5S=&EN;W,L(%1E<G)I
M=&]R:6]S($]C=7!A9&]S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3@R"FUS9VED(")086YA;6$B"FUS9W-T<B`B4&%N
M86WA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3@U"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(E!A</IA
M($YU979A($=U:6YE82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ.34*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(E!A
M<F%G=6%Y(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S<*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B4&%R8VEA;&UE
M;G1E(&YU8F]S;R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ-SD*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HQ.3D@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-PHC
M.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,34Q(&QI8B](;W)D92]&;W)M
M+G!H<#HR,#$X"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,PHC.B!C;VYF:6<O+F)A
M:R]R96=I<W1R>2YP:'`N9&ES=#HT,C4*;7-G:60@(E!A<W-W;W)D(@IM<V=S
M='(@(D-O;G1R87-E\6$B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+B(*
M;7-G<W1R("),82!C;VYT<F%S9?%A('-E(&-A;6)I861O(&-O<G)E8W1A;65N
M=&4N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,S(S"FUS9VED
M(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`B0V]N=')A<V7Q82!I;F-O
M<G)E8W1A(@H*(SH@;&EB+TAO<F1E+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G
M:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(DAA>2!Q=64@:6YT<F]D=6-I<B!U;F$@8V]N=')A<V7Q
M82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!2041)55,N(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(P-3,*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER
M;6%T:6]N(@IM<V=S='(@(D-O;G1R87-E\6$@8V]N(&-O;F9I<FUA8VGS;B(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`IM<V=I9"`B4&%S
M<W=O<F0Z(@IM<V=S='(@(D-O;G1R87-E\6$Z(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VUO8FEL92YI;F,Z,3$*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`B
M0V]N=')A<V7Q83H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&QI8B](;W)D
M92]&;W)M+G!H<#HR,#,T"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G<W1R
M("),87,@8V]N=')A<V7Q87,@=&EE;F5N('%U92!C;VEN8VED:7(N(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$R,"!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G:60@(E!A<W1E(@IM<V=S
M='(@(E!E9V%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T
M<B`B4&5G87(@9&5L('!O<G1A<&%P96QE<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T
M<B`B5NUA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z
M,B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C<*;7-G
M:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`B06QT87,@<&5N9&EE;G1E
M<SHB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*;7-G:60@(E!E;W!L
M92(*;7-G<W1R(")'96YT92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT(@IM<V=S='(@(E!O
M<F-E;G1A:F4B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N
M8V4N:'1M;#HT.0IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I
M;VYS(@IM<V=S='(@(E)E86QI>F%R(&]P97)A8VEO;F5S(&1E(&UA;G1E;FEM
M:65N=&\B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HT,3`*;7-G
M:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B
M"FUS9W-T<B`BOU)E86QI>F%R(&]P97)A8VEO;F5S(&1E(&UA;G1E;FEM:65N
M=&\@86P@:6YI8VEA<B!S97-I\VX_(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B4')I=FEL96=I
M;R(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T960N(@IM<V=S
M='(@(DYO('-E(&AA(&5L:6UI;F%D;R!E;"!P<FEV:6QE9VEO(%PB)7-<(BXB
M"@HC.B!L:6(O5D93+W-M8BYP:'`Z-C`S"FUS9VED(")097)M:7-S:6]N($1E
M;FEE9"(*;7-G<W1R(")0<FEV:6QE9VEO(&1E;F5G861O(@H*(SH@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HQ-C$@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ
M-C0*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@(E!R:79I;&5G:6]S(@H*
M(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P(&%D;6EN+W!E<FUS+V1E
M;&5T92YP:'`Z-3@*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D;6EN
M+W!E<FUS+VEN9&5X+G!H<#HR,@IM<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI
M<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R86-I\VX@9&4@<')I=FEL96=I
M;W,B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HV.`IM<V=I9"`B
M4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M86-I\VX@<&5R
M<V]N86PB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY."!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ.#,*;7-G:60@(E!E<G4B"FUS9W-T<B`B4&5R^B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU-0IM<V=I9"`B4&5T<R(*;7-G<W1R(")-87-C
M;W1A<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$X-@IM<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B1FEL:7!I;F%S
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G
M:60@(E!H;VYE(@IM<V=S='(@(E1E;.EF;VYO(@H*(SH@8V]N9FEG+RYB86LO
M<F5G:7-T<GDN<&AP+F1I<W0Z-#@P"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B
M1F]T;V=R86;M87,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3DP"FUS9VED(")0:71C86ER;B(*;7-G<W1R(")0:71C
M86ER;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T<B`B4.UX96QE<R(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G
M<W1R(")4\W!I8V]S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@
M<V]M92!C96QL(@IM<V=S='(@(E!U;'-E(&5N('5N82!C96QD82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO
M=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R(")#;VYF:7)M92!Q=64@9&5S96$@
M96QI;6EN87(@97-T92!E;&5M96YT;SHB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L96%S
M92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N
M="XB"FUS9W-T<B`B0V]N9FER;64@<75E(&1E<V5A(&5L:6UI;F%R(&5L(';M
M;F-U;&\@82!E<W1E(&5L96UE;G1O+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR-38R"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R
M+B(*;7-G<W1R("));G1R;V1U>F-A('5N(&UE<R!Y('5N(&'Q;RXB"@HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I
M9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB
M"FUS9W-T<B`B26YT<F]D=7IC82!E;"!N;VUB<F4@9&4@;&$@;G5E=F$@8V%T
M96=O<NUA.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S`Q"FUS9VED(")0
M;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R("));G1R
M;V1U>F-A('5N82!D:7)E8V-I\VX@25`@=N%L:61A+B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR-C0P"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!D
M871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+B(*
M;7-G<W1R("));G1R;V1U>F-A('5N82!F96-H82!VX6QI9&$L(&-O;7!R=65B
M92!E;"!N^FUE<F\@9&4@9.UA<R!D96P@;65S+B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR-#0W"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T:6UE
M+B(*;7-G<W1R("));G1R;V1U>F-A('5N82!H;W)A(';A;&ED82XB"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@
M<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@(E!R
M;W!O<F-I;VYE('5N(')E<W5M96X@9&5L('!R;V)L96UA+B(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHR-@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A
M;F0@<&%S<W=O<F0B"FUS9W-T<B`B26YT<F]D=7IC82!S=2!N;VUB<F4@9&4@
M=7-U87)I;R!Y(&-O;G1R87-E\6$N(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N
M8V4N<&AP.C4X"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG
M('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T
M:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B"B),96$@96P@=&5X=&\@<VEG=6EE
M;G1E+B!$14)%(&%C97!T87(@;&]S('3I<FUI;F]S('-I('%U:65R92!U<V%R
M(&5L('-I<W1E;6$N(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N
M86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@8V%T96=O
M<GD@;F%M93HB"FUS9W-T<B`B26YT<F]D=7IC82!E;"!N=65V;R!N;VUB<F4@
M9&4@8V%T96=O<NUA.B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$X.`IM<V=I9"`B4&]L86YD(@IM<V=S='(@(E!O;&]N
M:6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET
M:6-S(@IM<V=S='(@(E!O;.UT:6-A(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T
M<GDN<&AP+F1I<W0Z-#@Y"FUS9VED(")0;VQL<R(*;7-G<W1R(")%;F-U97-T
M87,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3DS"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R(")0;W)T=6=A;"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R-`IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G
M<W1R(")0;W-I8VGS;B!D92!L82!I;6%G96XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI
M;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R(")0;W-I8VGS;B!D92!L82!T86)L
M82(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,2!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3$*;7-G:60@(E!O<W0@=&\@
M=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R(")%
M;G9I87(@82!E<W1A(&-A<G!E=&$@*&YO(&]B;&EG861O('!O<B!)34%0*2(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<S(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C<X"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R
M(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(E!R96-I<&ET86-I;VYE<R!D
M92!L82AS*2#Z;'1I;6$H<RD@)7,@:&]R82AS*3H@(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(X-PIM<V=I9"`B4')E8VEP:71A=&EO;CQB
M<B`O/F-H86YC92(*;7-G<W1R(")0<F]B86)I;&ED860\8G(@+SYD92!P<F5C
M:7!I=&%C:?-N(@H*(SH@;&EB+TAO<F1E+U!R969S+VQD87`N<&AP.CDX"FUS
M9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(E!R969S7VQD87`Z(&YO('-E(&5N8V]N='+S(&QA
M(&5X=&5N<VGS;B!,1$%0(')E<75E<FED82XB"@HC.B!L:6(O2&]R9&4O4')E
M9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@(E!R969S7W-E<W-I;VXZ(%)E<75I
M<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E
M9G-?<V5S<VEO;CH@;F\@<V4@96YC;VYT<O,@;&$@97AT96YS:?-N(&1E('-E
M<VGS;B!R97%U97)I9&$N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S(*
M;7-G:60@(E!R97-S=7)E(@IM<V=S='(@(E!R97-I\VXB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(V-@IM<V=I9"`B4')E<W-U<F4@870@<V5A(&QE=F5L
M.B`B"FUS9W-T<B`B4')E<VGS;B!A;"!N:79E;"!D96P@;6%R.B`B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(T"FUS9VED(")0<F5S<W5R
M93H@(@IM<V=S='(@(E!R97-I\VXZ("(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(S"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"FUS9VED(")0<F5V:65W
M(@IM<V=S='(@(E9I<W1A('!R979I82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,0IM<V=I9"`B4')E
M=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(E9I<W1A
M('!R979I82!D92!L82!I;6%G96X@96X@=6YA(&YU979A('9E;G1A;F$B"@HC
M.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,U-B!L:6(O2&]R9&4O4')E9G,O
M54DN<&AP.C,V,`IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R(")/
M<&-I;VYE<R!A;G1E<FEO<F5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS
M9W-T<B`B26UP<FEM:7(@9&]C=6UE;G1O(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z-#(S"FUS9VED(")0<FEV871E($ME>2(*;7-G<W1R(")#;&%V
M92!P<FEV861A(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$V.0IM<V=I9"`B
M4')O8FQE;2(*;7-G<W1R("*_4')O8FQE;6%S/R(*"B,Z('-E<G9I8V5S+W!R
M;V)L96TN<&AP.C$R-PIM<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G
M<W1R(")$97-C<FEP8VGS;B!D96P@<')O8FQE;6$B"@HC.B!C;VYF:6<O+F)A
M:R]R96=I<W1R>2YP:'`N9&ES=#HS-S$*;7-G:60@(E!R;VIE8W1S(@IM<V=S
M='(@(E!R;WEE8W1O<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,3$Q(&QI
M8B](;W)D92]&;W)M+G!H<#HR,3@X(&QI8B](;W)D92]&;W)M+G!H<#HS,C<V
M"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R(")497AT;R!D96P@:6YD=6-T
M;W(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U
M8FQI8R!+97DB"FUS9W-T<B`B0VQA=F4@4$=0('#Z8FQI8V$B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T-@IM<V=I9"`B4'5B;&EC($ME>2!!
M;&=O<FET:&TB"FUS9W-T<B`B06QG;W)I=&UO(&1E(&-L879E('#Z8FQI8V$B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B
M;&EC($ME>2!);F9O(@IM<V=S='(@(DEN9F]R;6%C:?-N(&1E(&-L879E('#Z
M8FQI8V$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HR-#$*;7-G:60@
M(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S
M9G5L;'DN(@IM<V=S='(@(DYO('-E(&=E;F5R87)O;B!C;W)R96-T86UE;G1E
M(&QA<R!C;&%V97,@4/IB;&EC82]0<FEV861A+B(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3$*;7-G:60@(E!U97)T
M;R!2:6-O(@IM<V=S='(@(E!U97)T;R!2:6-O(@H*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S0S,30N<&AP.C4U"FUS9VED(")0=7)G92!M97-S86=E<R(*
M;7-G<W1R("),:6UP:6%R(&UE;G-A:F5S(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#0*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-@IM<V=I9"`B46%T87(B"FUS
M9W-T<B`B46%T87(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C0*;7-G:60@
M(E%U97)Y(@IM<V=S='(@(D-O;G-U;'1A(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C@P"FUS9VED(")1=6]T82(*;7-G<W1R(")1=6]T82(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C8T"B,L('!H<"UF;W)M870*;7-G
M:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@(D-L879E(%)3
M02!P^F)L:6-A("@E9"!B:70I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R
M-C0*;7-G:60@(E)A9&EO('-E;&5C=&EO;B(*;7-G<W1R(")";W3S;B!D92!O
M<&-I\VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT-0IM<V=I9"`B4F%I;B(*;7-G<W1R("),;'5V:6$B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B4F%I;B!%
M87)L>2(*;7-G<W1R("),;'5V:6$@;6%T=71I;F$B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-PIM<V=I9"`B4F%I;B!,871E
M(@IM<V=S='(@(DQL=79I82!V97-P97)T:6YA(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@4VAO=V5R
M(@IM<V=S='(@(D%G=6%C97)O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#D*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T
M<B`B3&QU=FEA('D@3FEE=F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU,`IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@
M(DQL=79I82!A($YI979E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*
M;7-G:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@(E)U961A(&1E(&QA(&9O
M<G1U;F$B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV."!L
M:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW-@IM<V=I9"`B4F%T:6\B
M"FUS9W-T<B`B4F%Z\VXB"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C,R-"!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,0HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-"!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$X,`IM<V=I9"`B4F5A9"(*;7-G<W1R("(F;F)S<#M,965R)FYB<W`[(@H*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W(&QI8B](;W)D
M92])34%0+T%#3"]R9F,T,S$T+G!H<#HT-PIM<V=I9"`B4F5A9"!M97-S86=E
M<R(*;7-G<W1R("),965R(&UE;G-A:F5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL
M>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N
M(@IM<V=S='(@(K]%;&EM:6YA<B!R96%L;65N=&4@)7,_($5S=&$@;W!E<F%C
M:?-N(&YO('-E('!U961E(&1E<VAA8V5R+B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL
M>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO
M;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"B*_16QI;6EN87(@<F5A
M;&UE;G1E(&QO<R!D871O<R!D96P@=7-U87)I;R`E<S\@17-T82!O<&5R86-I
M\VX@;F\@<V4@<'5E9&4@(@HB9&5S:&%C97(N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B4F5D;V5S('EO
M=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B5G5E;'9E(&$@<F5A;&EZ87(@;&$@
M^FQT:6UA(&%C8VGS;B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED(")2969R97-H(@IM<V=S
M='(@(D%C='5A;&EZ87(B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES
M=#HS.34*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*
M;7-G<W1R(")!8W1U86QI>F%R(&5L96UE;G1O<R!D92!M96[Z(&1I;N%M:6-O
M<SHB"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HS-#4*;7-G:60@
M(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(D%C='5A;&EZ87(@=FES
M=&$@9&5L('!O<G1A;"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX.30@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$R,3,@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,S4*
M;7-G:60@(E)E9V5X(@IM<V=S='(@(E)E9V5X(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C,R,S$*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S
M='(@(DYA=F5G861O<B!D92!R96QA8VEO;F5S(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(P.`IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(E)E9G)E<V-A<B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S,S"FUS9VED(")296UA<FMS(@IM<V=S='(@
M(D]B<V5R=F%C:6]N97,B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES
M=#HQ,3<*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(E-E<G9I9&]R
M97,@<F5M;W1O<R(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX
M-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H
M;W)D92DZ(@IM<V=S='(@(E523"!R96UO=&$@*&AT='`Z+R]W=W<N96IE;7!L
M;RYC;VTO:&]R9&4I.B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O
M=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E
M9"YI;F,Z,3,@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,@IM
M<V=I9"`B4F5M;W9E(@IM<V=S='(@(E%U:71A<B(*"B,Z('1E;7!L871E<R]P
M;W)T86PO;&%Y;W5T+FEN8SHQ,0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S
M='(@(E%U:71A<B!B;&]Q=64B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-34Y"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@
M(E%U:71A<B!C;VQU;6YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHT,`IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS
M9W-T<B`B16QI;6EN87(@9F]R;6%T;R(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,Z,3(X"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R(")1=6ET
M87(@<&%R(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,0IM<V=I9"`B
M4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D
M:7)E8W1O<GDN(@IM<V=S='(@(D5L:6UI;F%R(&=U:?-N(&=U87)D861O(&1E
M;"!D:7)E8W1O<FEO('1E;7!O<F%L(&1E;"!S97)V:61O<BXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*
M;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T<B`B16QI;6EN87(@(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P
M"FUS9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM
M<V=S='(@(D5L:6UI;F%R(&5S=&4@;F]D;R!D96P@9&]C=6UE;G1O(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0IM<V=I9"`B4F5M
M;W9E('5S97(B"FUS9W-T<B`B16QI;6EN87(@=7-U87)I;R(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")296UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B16QI;6EN87(@=7-U87)I
M;SH@)7,B"@HC.B!L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED
M(")297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O
M<F-O9&4Z("(*;7-G<W1R(").;R!S92!P=65D92!R97-P;VYD97(@82!L82!S
M;VQI8VET=60N($/S9&EG;R!D92!E<G)O<B!D979U96QT;SH@(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T-0IM<V=I9"`B4F5Q=65S=&5D
M('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*;7-G<W1R(").;R!S92!E
M;F-O;G1R\R!E;"!S97)V:6-I;R!S;VQI8VET861O+B(*"B,Z(&QI8B](;W)D
M92YP:'`Z,3@U(&QI8B](;W)D92YP:'`Z-3(W"B,L('!H<"UF;W)M870*;7-G
M:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(DYO('-E(&AA(&5S<&5C:69I8V%D;R!E;"!<
M(B5S7"(@<F5Q=65R:61O(&5N(&QA(&-O;F9I9W5R86-I\VX@9&4@)7,N(@H*
M(SH@;&EB+U9&4R]F='`N<&AP.C@W-"!L:6(O5D93+W-Q;"YP:'`Z-CDP(&QI
M8B]61E,O<W%L7V9I;&4N<&AP.C<U.0HC+"!P:'`M9F]R;6%T"FUS9VED(")2
M97%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B3F\@<V4@:&$@97-P96-I9FEC861O(&5L(%PB)7-<
M(B!R97%U97)I9&\@96X@;&$@8V]N9FEG=7)A8VGS;B!D92!61E,N(@H*(SH@
M;&EB+TAO<F1E+U5T:6PN<&AP.C<Y,`HC+"!P:'`M9F]R;6%T"FUS9VED(")2
M97%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R(").;R!S92!H82!E<W!E8VEF:6-A9&\@96P@7"(E<UPB(')E
M<75E<FED;R!E;B!L82!C;VYF:6=U<F%C:?-N+B(*"B,Z(&QI8B](;W)D92]&
M;W)M+U)E;F1E<F5R+G!H<#HS,S8*;7-G:60@(E)E<75I<F5D($9I96QD(@IM
M<V=S='(@(D-A;7!O(&YE8V5S87)I;R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q
M(&QI8B](;W)D92]&;W)M+G!H<#HS,SD*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(R,"!L:6(O2&]R9&4O1F]R;2]296YD97)E<BYP
M:'`Z,S(Q"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S970B
M"FUS9W-T<B`B3&EM<&EA<B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C0V"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R("),:6UP:6%R
M(&-O;G1R87-E\6$B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR
M-PIM<V=I9"`B4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R("),:6UP:6%R
M(&-O;G1R87-E\6$B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,Q"FUS9VED
M(")297-T;W)E($QA<W0@475E<GDB"FUS9W-T<B`B4F5S=&%U<F%R(/IL=&EM
M82!C;VYS=6QT82(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR.2!A9&UI;B]P
M:'!S:&5L;"YP:'`Z-S(@861M:6XO<W%L<VAE;&PN<&AP.C8W"FUS9VED(")2
M97-U;'1S(@IM<V=S='(@(E)E<W5L=&%D;W,B"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*
M;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(E)E9W)E<V%R(&$@
M;W!C:6]N97,B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S@*
M;7-G:60@(E)E='EP92!N97<@<&%S<W=O<F0B"FUS9W-T<B`B4F5E<V-R:6)I
M<B!C;VYT<F%S9?%A(&YU979A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-PIM<V=I9"`B4F5U;FEO;B(*;7-G<W1R
M(")2975N:?-N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A
M=&EO;B(*;7-G<W1R(")297-T875R87(@8V]N9FEG=7)A8VGS;B(*"B,Z(&-O
M;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$S-0IM<V=I9"`B4FEC:"!497AT
M($5D:71O<B!/<'1I;VYS(@IM<V=S='(@(D]P8VEO;F5S(&1E(&5D:6-I\VX@
M9&4@=&5X=&\@96YR:7%U96-I9&\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B0W)I8F%S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0X"FUS
M9VED(")2:6=H="(*;7-G<W1R(")$97)E8VAA(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C,Q,#,*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G<W1R(")#86)E
M8V5R82!D97)E8VAA(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,P.3D*;7-G
M:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R(")686QO<F5S(&1E(&QA(&1E<F5C
M:&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R
M(")0<F]P:65D861E<R!D92!?9FEL82XN+B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(D9U
M;F-I\VXB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3DX"FUS9VED(")2;VUA;FEA(@IM<V=S='(@(E)U;6%N[6$B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(V"FUS9VED
M(")2;W1A=&4@,3@P(@IM<V=S='(@(D=I<F%R(#$X,"(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HR,C,*;7-G:60@(E)O=&%T92!,
M969T(@IM<V=S='(@(D=I<F%R(&$@;&$@:7IQ=6EE<F1A(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R.0IM<V=I9"`B4F]T871E
M(%)I9VAT(@IM<V=S='(@(D=I<F%R(&$@;&$@9&5R96-H82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G
M:60@(E)O=R!0<F]P97)T:65S(@IM<V=S='(@(E!R;W!I961A9&5S(&1E(&9I
M;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R(")0<F]P
M:65D861E<R!D92!F:6QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S='(@(D9I;&%S
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3,*;7-G:60@(E)U;&5S(@IM<V=S='(@(E)A>6%S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,`IM
M<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@
M8V]L=6UN<R(*;7-G<W1R(")!<&%R96-E<N%N(')A>6%S(&5N=')E('1O9&%S
M(&QA<R!F:6QA<R!Y(&-O;'5M;F%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`B07!A<F5C
M97+A;B!R87EA<R!S\VQO(&5N=')E(&QA<R!C;VQU;6YA<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G
M:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S
M='(@(D%P87)E8V5RX6X@<F%Y87,@<_-L;R!E;G1R92!L87,@9FEL87,B"@HC
M.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(Q"FUS9VED(")2=6XB"FUS9W-T<B`B
M16IE8W5T87(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3DY"FUS9VED(")2=7-S:6%N($9E9&5R871I;VXB"FUS9W-T
M<B`B1F5D97)A8VGS;B!2=7-A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(P,`IM<V=I9"`B4G=A;F1A(@IM<V=S='(@
M(E)U86YD82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C@U"FUS
M9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B
M1FER;6$@8W)I<'1O9W+A9FEC82!3+TU)344B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S
M86=E(@IM<V=S='(@(DUE;G-A:F4@8VEF<F%D;R!E;B!3+TU)344B"@HC.B!L
M:6(O2&]R9&4O075T:"]S87-L+G!H<#HX,0IM<V=I9"`B4T%33"!A=71H96YT
M:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(").;R!E<W3A(&1I
M<W!O;FEB;&4@;&$@875T96YT:69I8V%C:?-N(%-!4TPN(@H*(SH@8V]N9FEG
M+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z-3`V"FUS9VED(")335,@365S<V%G
M:6YG(@IM<V=S='(@(DUE;G,N(%--4R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(DEN=.ER<'(N(%-13"(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C<T"FUS9VED(")344P@<W1A=&5M
M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(E-E;G1E;F-I82!344P@
M<&%R82!C;VYS=6QT87,@9&4@=F%L;W)E<R(*"B,Z(&-O;F9I9R\N8F%K+W)E
M9VES=')Y+G!H<"YD:7-T.C0S,PIM<V=I9"`B4U-((@IM<V=S='(@(E-32"(*
M"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H
M<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R("+)6$E43R(*"B,Z(&QI8B]A
M<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R("));G3I<G!R
M+B!37U%,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`B4V%B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.#D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-PIM<V=I9"`B4V%I
M;G0@2&5L96YA(@IM<V=S='(@(E-A;G1A($AE;&5N82(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.3`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,0IM<V=I9"`B4V%I
M;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@(E-A:6YT($MI='1S('D@3F5V
M:7,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,SD*;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S='(@(E-A;G1A($QU8^UA
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$X.0IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R
M(")386EN="!0:65R<F4@>2!-:7%U96QO;B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#0*;7-G:60@(E-A:6YT(%9I
M;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM<V=S='(@(E-A;B!6:6-E;G1E
M('D@1W)A;F%D:6YA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G
M<W1R(")-:7-M;R!F<F%M92`H7W-E;&8I(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.30*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,0IM<V=I9"`B4V%M;V$B"FUS
M9W-T<B`B4V%M;V$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C$R"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@(E-A
M;B!-87)I;F\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#<@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C$V"FUS9VED(")386\@5&]M92!A;F0@4')I;F-I<&4B"FUS
M9W-T<B`B4V%N=&\@5&]MX7,@>2!0<NUN8VEP92(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R(@IM
M<V=S='(@(E!R;W9E961O<B!D92!S873I;&ET92(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DW"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#$*;7-G:60@(E-A=61I
M($%R86)I82(*;7-G<W1R(")!<F%B:6$@4V%U9&ET82(*"B,Z('1E;7!L871E
M<R]P;W)T86PO;&%Y;W5T+FEN8SHY.0IM<V=I9"`B4V%V92(*;7-G<W1R(")'
M=6%R9&%R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E(%PB)7-<(B(*;7-G<W1R(")'
M=6%R9&%R(%PB)7-<(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,C$V"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`B1W5A
M<F1A<B`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@
M(E-A=F4@3W!T:6]N<R(*;7-G<W1R(")'=6%R9&%R(&]P8VEO;F5S(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-@IM<V=I9"`B(@HB4V%V92!G96YE
M<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S
M97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R("(B"B)'
M=6%R9&%R(&QA(&-O;F9I9W5R86-I\VX@9V5N97)A9&$@8V]M;R!U;B!G=6GS
M;B!02%`@96X@96P@9&ER96-T;W)I;R`B"B)T96UP;W)A;"!D92!S=2!S97)V
M:61O<BXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M(")392!H82!G=6%R9&%D;R!L82!C;VYF:6=U<F%C:?-N(&1E("5S+B(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L('!H<"UF;W)M870*;7-G
M:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM
M<V=S='(@(D=U87)D87(@9W5I\VX@9&4@86-T=6%L:7IA8VGS;B!D92!L82!C
M;VYF:6=U<F%C:?-N(&5N.B!<(B5S7"(N(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@(E-C871T97)E9"!4+5-T
M;W)M<R(*;7-G<W1R(")";W)R87-C87,@86ES;&%D87,B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B0VEE
M;F-I82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E
M;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED(")396%R8V@B
M"FUS9W-T<B`B0G5S8V%R(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP
M+F1I<W0Z,S(R"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R(")-+B!B
M^G-Q=65D82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.34U"FUS9VED(")3
M96QE8W0@1FEL97,B"FUS9W-T<B`B4V5L96-C:6]N87(@87)C:&EV;W,B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@U"FUS9VED
M(")396QE8W0@82!D871E(@IM<V=S='(@(E-E;&5C8VEO;F4@=6YA(&9E8VAA
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.3@*;7-G:60@(E-E
M;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R(")396QE8V-I;VYE(&5L(&=R
M=7!O(&$@8?%A9&ER(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT
M,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@(E-E;&5C8VEO
M;F4@=6X@;G5E=F\@<')O<&EE=&%R:6\B"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z-C`*;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R
M(")396QE8V-I;VYE('5N('-E<G9I9&]R(@H*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM
M<V=S='(@(E-E;&5C8VEO;F4@96P@=7-U87)I;R!A(&'Q861I<B(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HV-S8*;7-G:60@(E-E
M;&5C="!A;&PB"FUS9W-T<B`B4V5L96-C:6]N87(@=&]D;R(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR-C0S"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M
M<&]N96YT<RXB"FUS9W-T<B`B4V5L96-C:6]N92!T;V1O<R!L;W,@8V]M<&]N
M96YT97,@9&4@;&$@9F5C:&$N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G
M<W1R(")396QE8V-I;VYA<B!U;B!O8FIE=&\B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<W"FUS9VED(")396QE8W0@;F]N92(*
M;7-G<W1R(")3:6X@<V5L96-C:?-N(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N
M<&AP.C,W"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE
M960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N
M9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B
M(@HB4V5L96-C:6]N92!L;W,@8V%RX6-T97)E<R!Q=64@;F5C97-I=&4@9&4@
M;&%S(&-A<VEL;&%S(&1E(&%B86IO+B!0=65D92`B"B)C;W!I87)L;W,@>2!P
M96=A<FQO<R!D96P@X7)E82!D92!T97AT;RXB"@HC.B!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H92!D871E(&1E;&EM:71E
M<CHB"FUS9W-T<B`B4V5L96-C:6]N92!E;"!D96QI;6ET861O<B!D92!F96-H
M87,Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E
M;&5C="!T:&4@9&%T92!F;W)M870Z(@IM<V=S='(@(E-E;&5C8VEO;F4@96P@
M9F]R;6%T;R!D92!F96-H87,Z(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT
M:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y
M;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(E-E;&5C8VEO;F4@;&$@:61E
M;G1I9&%D('%U92!Q=6EE<F$@8V%M8FEA<CHB"@HC.B!T96UP;&%T97,O9&%T
M82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E
M<CHB"FUS9W-T<B`B4V5L96-C:6]N92!E;"!D96QI;6ET861O<B!D92!H;W)A
M<SHB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L
M96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`B4V5L96-C:6]N92!E;"!F
M;W)M871O(&1E(&AO<F%S.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z-3<*;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G
M<W1R(")396QE8V-I;VYE(&1O<R!C86UP;W,@8V]I;F-I9&5N=&5S+B(*"B,Z
M(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C,Q,`IM<V=I9"`B4V5L96-T
M('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R(")396QE8V-I;VYE('-U(&-O
M;6)I;F%C:?-N(&1E(&-O;&]R97,N(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N
M<&AP+F1I<W0Z,C4R"FUS9VED(")396QE8W0@>6]U<B!P<F5F97)R960@;&%N
M9W5A9V4Z(@IM<V=S='(@(E-E;&5C8VEO;F4@<W4@:61I;VUA('!R969E<FED
M;SHB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I
M9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")%;G9I87(@:6YF;W)M
M92!D92!P<F]B;&5M87,B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3`T,@IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B16YV:6%R
M(%--4R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,3,*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B4V5N96=A;"(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S(S"FUS9VED(")396YS;W(Z("(*;7-G
M<W1R(")396YS;W(Z("(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,3`@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C<S"FUS9VED(")397!T96UB97(B"FUS9W-T<B`B4V5P=&EE;6)R92(*"B,Z
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I
M82!A;F0@36]N=&5N96=R;R(*;7-G<W1R(")397)B:6$@>2!-;VYT96YE9W)O
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#(*;7-G:60@(E-E
M<FEA;"!.=6UB97(B"FUS9W-T<B`B3OIM97)O(&1E('-E<FEE(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T.0IM<V=I9"`B4V5R=F5R(&1A
M=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B1&%T;W,@9&5L
M('-E<G9I9&]R(&5R<O-N96]S(&\@;F\@9&ES<&]N:6)L97,N(@H*(SH@861M
M:6XO<V5S<VEO;G,N<&AP.C(W"FUS9VED(")397-S:6]N($%D;6EN(@IM<V=S
M='(@(D%D;6EN:7-T<F%C:?-N(&1E('-E<VGS;B(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")397-S:6]N($E$(&5X
M<&ER960N(@IM<V=S='(@(DAA(&-A9'5C861O(&5L($E$(&1E('-E<VGS;BXB
M"@HC.B!L:6(O87!I+G!H<#HQ-#4*;7-G:60@(E-E<W-I;VYS(@IM<V=S='(@
M(E-E<VEO;F5S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S,30*;7-G:60@
M(E-E="(*;7-G<W1R(")%<W1A8FQE8V5R(@H*(SH@8V]N9FEG+RYB86LO<')E
M9G,N<&AP+F1I<W0Z-SD*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO
M=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I
M="XB"FUS9W-T<B`B(@HB17-T86)L96-E(&]P8VEO;F5S('%U92!L92!P97)M
M:71E;B!R96%J=7-T87(@<W4@8V]N=')A<V7Q82!S:2!L;&5G87)A(&$@(@HB
M;VQV:61A<FQA+B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$Q
M.`IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@
M=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(D-O;F9I9W5R
M82!S97)V:61O<F5S(')E;6]T;W,@82!L;W,@<75E(&1E<V5E(&%C8V5D97(@
M9&5S9&4@96P@<&]R=&%L+B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD
M:7-T.C@W"FUS9VED(")3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I
M;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S='(@(D1E9FEN92!L87,@
M;W!C:6]N97,@<')E9F5R:61A<R!D92!I9&EO;6$L('IO;F$@:&]R87)I82!Y
M(&9E8VAA<RXB"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HQ,#$*
M;7-G:60@(B(*(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R
M('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA
M>2!O<'1I;VYS+B(*;7-G<W1R("(B"B)$969I;F4@;&$@87!L:6-A8VGS;B!D
M92!I;FEC:6\L(&QA(&-O;6)I;F%C:?-N(&1E(&-O;&]R97,L(&QA(&%C='5A
M;&EZ86-I\VX@(@HB9&4@<.%G:6YA('D@;W1R87,@;W!C:6]N97,@9&4@=FES
M=6%L:7IA8VGS;BXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<W"FUS
M9VED(")3971U<"(*;7-G<W1R(")#;VYF:6=U<F%C:?-N(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*;7-G:60@(E-E='5P('5P
M9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`B2&%Y(&=U:6]N97,@
M9&4@86-T=6%L:7IA8VGS;B!D92!L82!C;VYF:6=U<F%C:?-N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-0IM<V=I9"`B4V5V97)A;"!L
M;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T
M<B`B5F%R:6%S('5B:6-A8VEO;F5S(&1I<W!O;FEB;&5S(&-O;B!E;"!P87+A
M;65T<F\Z("(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,#,*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T<B`B4V5Y8VAE
M;&QE<R(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C0Y.`IM
M<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B0V]M<')A<R(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S"FUS9VED(")3:&]R="!3=6UM87)Y
M(@IM<V=S='(@(E)E<W5M96X@8V]R=&\B"@HC.B!C;VYF:6<O+F)A:R]P<F5F
M<RYP:'`N9&ES=#HT-3`*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D
M969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R("*_1&5F:6YI<B!C;&%V
M97,@9&4@86-C97-O('!A<F$@;&$@;6%Y;W+M82!D92!L;W,@=NUN8W5L;W,_
M(@H*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H
M;W<B"FUS9W-T<B`B)FYB<W`[36]S=')A<B9N8G-P.R(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-30*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@
M8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T
M960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B375E<W1R82!L87,@9&EF
M97)E;F-I87,@96YT<F4@;&$@;G5E=F$@8V]N9FEG=7)A8VGS;B!Y(&QA(&%L
M;6%C96YA9&$B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HT.30*
M;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B
M"FUS9W-T<B`BOTUO<W1R87(@:&]R82!D92!L82#Z;'1I;6$@<V5S:?-N(&%L
M(&EN:6-I87(_(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W-C4*;7-G:60@
M(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS9W-T<B`B36]S=')A
M<B!O<&-I\VX@9&4@8V]N<V5R=F%R(&5L(&]R:6=I;F%L(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(W.34*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@
M(DUO<W1R87(@<V5L96-T;W(B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N
M9&ES=#HU,S`*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A
M<C\B"FUS9W-T<B`BOTUO<W1R87(@;&$@8F%R<F$@9&4@;65N^B!D92!O<&5R
M86-I;VYE<R!D92!T86)L83\B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N
M9&ES=#HS-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N
M=2!O;B!T:&4@;&5F=#\B"FUS9W-T<B`BOTUO<W1R87(@96P@;65N^B`E<R!A
M(&QA(&EZ<75I97)D83\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE
M($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B375E<W1R82!E;"!D
M:>%L;V=O(&1E('!R;W!I961A9&5S(&1E(&-E;&1A(&1E('1A8FQA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8T"FUS9VED(")3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9R(*
M;7-G<W1R(")-=65S=')A(&5L(&1IX6QO9V\@9&4@<')O<&EE9&%D97,@9&4@
M=&%B;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P
M97)T:65S(&1I86QO9R(*;7-G<W1R(")-=65S=')A(&5L(&1IX6QO9V\@9&4@
M<')O<&EE9&%D97,@9&4@9FEL82!D92!T86)L82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I9"`B
M4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B375E
M<W1R82!E;"!D:>%L;V=O(&1E('!R;W!I961A9&5S(&1E(&EM86=E;B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8S"FUS9VED(")3:&]W('5P;&]A9"(*
M;7-G<W1R(")-;W-T<F%R(&-A<F=A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`B
M06=U86-E<F]S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@16%R;'DB"FUS9W-T<B`B3&QU=FEA
M<R!M871U=&EN87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU-`IM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(DQL=79I
M87,@=F5S<&5R=&EN87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU-0IM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB
M"FUS9W-T<B`B06=U86-E<F]S(&5N(&QA('9E8VEN9&%D(@H*(SH@;&EB+TAO
M<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV,3D*;7-G:60@(E-H<FEN
M:R(*;7-G<W1R(")2961U8VER(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HY,3`*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-
M86YA9V5R+G!H<#HY-S(*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA
M9V5R+G!H<#HQ,#4X"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z,3$R,`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.C$Q.#,*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HQ,C(S"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z
M,3(U,@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R
M.#4*;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS
M*2!O=70@;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R(")0<FEM97)O(')E9'5Z
M8V$@;R!Q=6ET92!D92!E;FUE9&EO(&QO<R!B;&]Q=65S(&-E<F-A;F]S(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,#$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q
M,0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(E-I97)R82!,96]N82(*
M"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8V"FUS9VED(")3:6=N
M('5P(@IM<V=S='(@(D%L=&$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C<Q,PIM<V=I9"`B4VEG;F%T=7)E(@IM<V=S='(@(D9I<FUA(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R
M92!!;&=O<FET:&TB"FUS9W-T<B`B06QG;W)I=&UO(&1E(&9I<FUA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,#(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-@IM
M<V=I9"`B4VEN9V%P;W)E(@IM<V=S='(@(E-I;F=A<'5R(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C@Y-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q-2!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3(S-PHC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(T
M-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDQ,B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,S$P-0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV-2!L:6(O
M2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX-`HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O>FEP+G!H<#HW,@IM<V=I9"`B4VEZ92(*;7-G<W1R(")486UA
M\6\B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M
M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R(")/;6ET:7(@
M;6%N=&5N:6UI96YT;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,3`*;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@(D5S
M;&]V87%U:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-`HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C`X"FUS9VED(")3;&]V96YI82(*;7-G<W1R(")%<VQO=F5N
M:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M-@IM<V=I9"`B4VYO=R(*;7-G<W1R(").:65V92(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS9VED(")3;F]W(%-H;W=E
M<B(*;7-G<W1R(")!9W5A8V5R;R!D92!N:65V92(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")3;F]W(%-H;W=E
M<G,B"FUS9W-T<B`B06=U86-E<F\@9&4@;FEE=F4B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.0IM<V=I9"`B4VYO=R!3:&]W
M97)S($5A<FQY(@IM<V=S='(@(D%G=6%C97)O(&1E(&YI979E(&UA='5T:6YO
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*
M;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(D%G=6%C97)O(&1E
M(&YI979E('9E<W!E<G1I;F\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X
M-0IM<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@(D5S<&5S;W(@9&4@;&$@
M;FEE=F4Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@Y"FUS9VED(")3
M;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R(")%<75I=F%L96YT
M92!D92!L82!N:65V92!E;B!A9W5A.B`B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`R"FUS9VED(")3;VQO;6]N($ES
M;&%N9',B"FUS9W-T<B`B27-L87,@4V%L;VWS;B(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,30*;7-G:60@(E-O;6%L
M:6$B"FUS9W-T<B`B4V]M86QI82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R(")#86YC:6]N97,@
M)B!0;V5M87,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDP.`IM<V=I9"`B
M4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`B4V5L96-C:?-N(&1E;"!S
M96YT:61O(&1E(&QA(&-L87-I9FEC86-I\VXB"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Q-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(T-PHC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-34Y(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@
M;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$V-B!L:6(O3F5T+U--4R]W:6Y?
M:'1T<"YP:'`Z,3@Y"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G<W1R(")2
M96UI=&5N=&4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C4U"FUS9VED(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`B4W5D
MX69R:6-A(@H*(SH@8V]N9FEG+RYB86LO;FQS+G!H<"YD:7-T.C$Y,PIM<V=I
M9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(D5U<F]P
M82!D96P@<W5R("A)4T\M.#@U.2TS*2(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,0IM<V=I9"`B4V]U=&@@1V5O<F=I
M82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B1V5O
M<F=I82!D96P@4W5R(&4@27-L87,@4V%N9'=I8V@@9&5L(%-U<B(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G
M:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B2&5M:7-F97)I;R!S
M=7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G
M<W1R(")%<W!A8VEA9&\@96YT<F4@8V5L9&%S(&%D>6%C96YT97,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I
M9"`B4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*
M;7-G<W1R(")%<W!A8VEA9&\@96YT<F4@96P@8V]N=&5N:61O('D@96P@8F]R
M9&4@9&4@=6YA(&-E;&1A(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Q-0IM
M<V=I9"`B4W!A8V5R(@IM<V=S='(@(E-E<&%R861O<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0IM<V=I9"`B
M4W!A8VEN9R(*;7-G<W1R(")%<W!A8VEA9&\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C
M:6YG(&%N9"!P861D:6YG(@IM<V=S='(@(D5S<&%C:6%D;R!Y(&UA<F=E;B(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,#D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@P
M"FUS9VED(")3<&%I;B(*;7-G<W1R(")%<W!A\6$B"@HC.B!C;VYF:6<O+F)A
M:R]R96=I<W1R>2YP:'`N9&ES=#HQ,#`*;7-G:60@(E-P86TB"FUS9W-T<B`B
M4W!A;2(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E
M8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`B17-C<FET=7)A(&1E(&-A
M<F%C=&5R97,@97-P96-I86QE<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G:60@(E-P;&ET(&-E;&PB
M"FUS9W-T<B`B1&EV:61I<B!C96QD82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O
M;'5M;B(*;7-G<W1R(")$:79I9&ER(&-O;'5M;F$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED(")3
M<&QI="!R;W<B"FUS9W-T<B`B1&EV:61I<B!F:6QA(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C8Q"FUS9VED(")3<&]R=',B"FUS9W-T<B`B1&5P;W)T
M97,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX."!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-#$*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R(")3<FD@3&%N:V$B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C@Q(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HV-@IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`B17-TX6YD87(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G:60@(E-T87(@5')E
M:R(*;7-G<W1R(")3=&%R(%1R96LB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C4X-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y,0IM<V=I9"`B4W1A<G0@>65A
M<B(*;7-G<W1R(")!\6\@9&4@:6YI8VEO(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU-S$*;7-G:60@(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S
M='(@(D5S=&%D;R!O('!R;W9I;F-I82(*"B,Z('1E;7!L871E<R]A9&UI;B]S
M971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B17-T
M861O(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(W.3<*;7-G:60@(E-T;W)A
M9V4@9F]R;6%T(@IM<V=S='(@(D9O<FUA=&\@9&4@86QM86-E;F%M:65N=&\B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,PIM<V=I9"`B4W1R
M965T($%D9')E<W,B"FUS9W-T<B`B1&ER96-C:?-N(&1E(&QA(&-A;&QE(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM
M<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R(")486-H861A(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$R,S,*;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S
M='(@(DQI<W1A(&1E(&-A9&5N87,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3@W,PIM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS
M9W-T<B`B16QI;6EN87(@9&]M:6YI;R!D92!L82!D:7)E8V-I\VXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(S
M"FUS9VED(")3='EL92!;0U-372(*;7-G<W1R(")%<W1I;&\@6T-34UTB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS
M9VED(")3=2(*;7-G<W1R(")$;VTB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP
M:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB)7-<
M(B!N;W0@9F]U;F0N(@IM<V=S='(@(DYO('-E(&5N8V]N='+S(&5L('-U8F1I
M<F5C=&]R:6\@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J96-T(@IM<V=S='(@(D%S=6YT;R(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,S(@;&EB+TAO<F1E+T9O<FTO4F5N
M9&5R97(N<&AP.C,Q.`IM<V=I9"`B4W5B;6ET(@IM<V=S='(@(D5N=FEA<B(*
M"B,Z('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B
M;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9
M;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@:&%S(&)E
M96X@87!P<F]V960N(@IM<V=S='(@(B(*(E-E(&AA(&5N=FEA9&\@=6YA('-O
M;&EC:71U9"!D92!A;'1A(&1E(%PB)7-<(B!E;B!E;"!S:7-T96UA+B!.;R!P
M;V1RX2`B"B)I;FEC:6%R('-E<VGS;B!H87-T82!Q=64@<V4@:&%Y82!A<')O
M8F%D;R!L82!S;VQI8VET=60N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S='(@
M(E-U8NUN9&EC92(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#4@;&EB+TAO
M<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED
M(")3=6-C97-S(@IM<V=S='(@(LEX:71O(@H*(SH@861M:6XO=7-E<BYP:'`Z
M.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D(%PB
M)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G<W1R(")392!H82!A\6%D:61O(&-O
M<G)E8W1A;65N=&4@7"(E<UPB(&%L('-I<W1E;6$N(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C
M;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB
M"FUS9W-T<B`B(@HB4V4@:&%N(&5L:6UI;F%D;R!C;W)R96-T86UE;G1E(&QO
M<R!D871O<R!D96P@=7-U87)I;R!<(B5S7"(@9&5L('-I<W1E;6$N(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V
M"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE=&5D(%PB
M)7-<(BXB"FUS9W-T<B`B4V4@:&$@96QI;6EN861O(&-O<G)E8W1A;65N=&4@
M7"(E<UPB+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@
M<WES=&5M+B(*;7-G<W1R(")392!H82!E;&EM:6YA9&\@8V]R<F5C=&%M96YT
M92!<(B5S7"(@9&5L('-I<W1E;6$N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R
M871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B(@HB4V4@
M:&$@<F5S=&%U<F%D;R!C;W)R96-T86UE;G1E(&QA(&-O;F9I9W5R86-I\VXN
M(%)E9G)E<W%U92!P87)A('9E<B!L;W,@(@HB8V%M8FEO<RXB"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B4V4@:&$@9W5A<F1A9&\@8V]R<F5C=&%M96YT82!L
M82!C;W!I82!D92!L82!C;VYF:6=U<F%C:?-N+B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*
M;7-G<W1R(")392!H82!G=6%R9&%D;R!C;W)R96-T86UE;G1E(&QA(&-O<&EA
M("5S(&1E(&QA(&-O;F9I9W5R86-I\VXN(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,38X"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D
M(%PB)7-<(B(*;7-G<W1R(")392!H82!A8W1U86QI>F%D;R!C;W)R96-T86UE
M;G1E(%PB)7-<(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(E-U
M8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R(")392!H82!E<V-R:71O(&-O
M<G)E8W1A;65N=&4@)R5S)R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,#0*;7-G:60@(E-U9&%N(@IM<V=S='(@(E-U
M9.%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU-@IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R(")297-U;65N(@H*
M(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED(")3=6X@4FES92(*
M;7-G<W1R(")!;6%N96-E<B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV
M.`IM<V=I9"`B4W5N(%-E="(*;7-G<W1R(")!=&%R9&5C97(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B4W5N
M;GDB"FUS9W-T<B`B4V]L96%D;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,#4*;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`B06UA;F5C97(B
M"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES
M92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@(D%M86YE
M8V5R+T%T87)D96-E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,#0*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R(")!;6%N96-E<CH@(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P.`IM<V=I9"`B4W5N
M<V5T(@IM<V=S='(@(D%T87)D96-E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,#<*;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@(D%T87)D
M96-E<CH@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`B4W5P97+M;F1I
M8V4B"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HS.#`*;7-G
M:60@(E-U<'!O<G0B"FUS9W-T<B`B4V]P;W)T92(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,34*;7-G:60@(E-U<FEN
M86UE(@IM<V=S='(@(E-U<FEN86TB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4W-0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R(")!<&5L;&ED;R(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,#D*;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B4W9A
M;&)A<F0@>2!*86X@36%Y96XB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C$Y"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T
M<B`B4W=A>FEL86YD:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C`U"FUS9VED(")3=V5D96XB"FUS9W-T<B`B4W5E
M8VEA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-38*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S='(@(E-U:7IA(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*;7-G:60@(E-Y;F,@;&]G
M(&1E;&5T960B"FUS9W-T<B`B4F5G:7-T<F\@9&4@<VEN8W)O;FEZ86-I\VX@
M96QI;6EN861O(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,30U
M"FUS9VED(")3>6YC34PB"FUS9W-T<B`B4WEN8TU,(@H*(SH@;&EB+TAO<F1E
M+U-13"]+97EW;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S
M96%R8V@@=&5R;7,B"FUS9W-T<B`B17)R;W(@9&4@<VEN=&%X:7,@96X@;&]S
M('3I<FUI;F]S(&1E(&+Z<W%U961A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q.`IM<V=I9"`B4WER:6%N($%R86(@
M4F5P=6)L:6,B"FUS9W-T<B`B4F5P^F)L:6-A(,%R86)E(&1E(%-I<FEA(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G
M:60@(E0M4W1O<FTB"FUS9W-T<B`B0VAU8F%S8V\B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3=&]R;2!A
M;F0@5VEN9'DB"FUS9W-T<B`B0F]R<F%S8V]S;R!Y('9E;G1O<V\B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-`IM<V=I9"`B
M5"U3=&]R;7,B"FUS9W-T<B`B0F]R<F%S8V%S(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C4*;7-G:60@(E0M4W1O<FUS($5A
M<FQY(@IM<V=S='(@(D)O<G)A<V-A<R!M871U=&EN87,B"@HC.B!L:6(O2&]R
M9&4O1&%T82]T<W8N<&AP.C$V-@IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B
M07)C:&EV;R!44U8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<S"FUS9VED(")486)L92!0<F]P97)T:65S(@IM
M<V=S='(@(E!R;W!I961A9&5S(&1E('1A8FQA(@H*(SH@;&EB+TAO<F1E+T9O
M<FTO5'EP92]T86)L97-E="YP:'`Z-3<*;7-G:60@(E1A8FQE(%-E="(*;7-G
M<W1R(")486)L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS
M9W-T<B`B4')O<&EE9&%D97,@9&4@=&%B;&$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3$@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-`IM<V=I
M9"`B5&%I=V%N(@IM<V=S='(@(E1A:7?A;B(*"B,Z(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@
M0VAI;F$B"FUS9W-T<B`B5&%I=^%N+"!0<F]V:6YC:6$@9&4@0VAI;F$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(Q.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(U
M"FUS9VED(")486II:VES=&%N(@IM<V=S='(@(E1A>6EK:7-TX6XB"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(R,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,U"FUS
M9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S='(@(E1A
M;GIA;FEA+"!297#Z8FQI8V$@56YI9&$@9&4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU"FUS9VED(")487)G970Z(@IM
M<V=S='(@(D1E<W1I;F\Z(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,S(@
M8V]N9FEG+RYB86LO:&]O:W,N<&AP+F1I<W0Z,3`T.0HC.B!C;VYF:6<O+F)A
M:R]R96=I<W1R>2YP:'`N9&ES=#HQ.#D*;7-G:60@(E1A<VMS(@IM<V=S='(@
M(E1A<F5A<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<T"FUS
M9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(D[Z;65R;R!D92!T96SI
M9F]N;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDW"FUS9VED(")496UP
M(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")496UP97)A='5R82!D=7)A;G1E
M(&QA(/IL=&EM82!H;W)A.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R
M,0IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B5&5M<&5R871U<F$B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$R"FUS9VED(")496UP
M97)A='5R93H@(@IM<V=S='(@(E1E;7!E<F%T=7)A.B`B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@R"B,L('!H<"UF;W)M870*;7-G:60@
M(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS
M9W-T<B`B5&5M<&5R871U<F$\8G(@+SXH)7--X7@E<R\E<TWM;B5S*2`F9&5G
M.R5S(@H*(SH@;&EB+TAO<F1E+U1E;7!L871E+G!H<#HV.34*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T
M<B`B3F\@<V4@96YC;VYT<O,@;&$@<&QA;G1I;&QA(%PB)7-<(BXB"@HC.B!A
M9&UI;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I9"`B5&5M<&QA=&4@061M:6YI
M<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R86-I\VX@9&4@<&QA;G1I;&QA
M<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C$Q(&QI8B](;W)D92]&;W)M
M+G!H<#HS,S(W"FUS9VED(")497AT(@IM<V=S='(@(E1E>'1O(@H*(SH@8V]N
M9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,S<Y"FUS9VED(")497AT($]N;'DB
M"FUS9W-T<B`B4_-L;R!T97AT;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G:60@(E1E>'0@86QI9VXB
M"FUS9W-T<B`B06QI;F5A8VGS;B!D92!T97AT;R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B
M"FUS9W-T<B`B0F]R9&4@<W5P97)I;W(@9&5L('1E>'1O(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I9"`B5&@B
M"FUS9W-T<B`B2G5E(@H*(SH@8V]N9FEG+RYB86LO;FQS+G!H<"YD:7-T.C$Y
M-`IM<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B5&%I;&%N9.ES("A4
M25,M-C(P*2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,C0*;7-G:60@(E1H86EL86YD(@IM<V=S='(@(E1A:6QA;F1I
M82(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX-C0*;7-G:60@(E1H92!&5%`@97AT
M96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DYO(&5S=.$@9&ES
M<&]N:6)L92!L82!E>'1E;G-I\VX@1E10+B(*"B,Z(&QI8B](;W)D92](:7-T
M;W)Y+G!H<#HU-0IM<V=I9"`B5&AE($AI<W1O<GD@<WES=&5M(&ES(&1I<V%B
M;&5D+B(*;7-G<W1R(")%;"!S:7-T96UA(&AI<W3S<FEC;R!E<W3A(&1E<VAA
M8FEL:71A9&\N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,S@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N
M9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R(")%;"!M;W1O
M<B!D92!I;G1E9W)A8VGS;B!(;W)D92]+;VQA8B!N;R!S;W!O<G1A(%PB)7-<
M(B(*"B,Z(&QI8B].970O24U34"]";V]K+G!H<#HQ,CDX"FUS9VED(")4:&4@
M24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R(").
M;R!S92!P=65D92!I;FEC:6%R(&5L(')E9VES=')O(&1E($E-4U`N(@H*(SH@
M<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@36%I;G1E
M;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S
M='(@(DYO('-E(&AA(&-A<F=A9&\@8V]R<F5C=&%M96YT92!L82!C;&%S92!-
M86EN=&5N86YC93HZ(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R
M+G!H<#HR.0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N
M($5X:71I;F<N(@IM<V=S='(@(E-E(&AA(&-E<G)A9&\@;&$@=F5N=&%N82!D
M92!O<&-I;VYE<RX@4V%L:65N9&\N(@H*(SH@;&EB+TAO<F1E+U!E<FUS+G!H
M<#HQ.#D@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,#`@;&EB+TAO<F1E+U!E<FUS
M+G!H<#HR,3$*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,C,@;&EB+TAO<F1E
M+U!E<FUS+G!H<#HR,S0@;&EB+TAO<F1E+U!E<FUS+G!H<#HR-3(*(SH@;&EB
M+TAO<F1E+U!E<FUS+G!H<#HR-C0@;&EB+TAO<F1E+U!E<FUS+G!H<#HS,#,*
M;7-G:60@(B(*(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R
M92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2`B"B)W
M86YT('1O('5S92!097)M:7-S:6]N<RXB"FUS9W-T<B`B(@HB4VD@9&5S96$@
M=71I;&EZ87(@<&5R;6ES;W,L(&5L(&%D;6EN:7-T<F%D;W(@=&EE;F4@<75E
M(&-O;F9I9W5R87(@=6X@<V]P;W)T92`B"B)D92!P97)M:7-O<R!P97)M86YE
M;G1E+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T;VT@<VED92!O;FQY(@IM<V=S
M='(@(E/S;&\@96P@8F]R9&4@:6YF97)I;W(B"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)
M1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S
M(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*(D5L
M($E$(&1E;"!C;VYT86-T;R!N;R!S92!E<W!E8VEF:6/S+"!S92!D96KS(&5N
M(&)L86YC;R!O(&YO('-E(&5N8V]N='+S(&5N("(*(FQA(&)A<V4@9&4@9&%T
M;W,N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0IM
M<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y
M;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B4V4@:&$@8?%A9&ED;R!C;W)R
M96-T86UE;G1E(&5L(&-O;G1A8W1O(&$@<W5S(&1I<F5C8VEO;F5S+B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q-S(*;7-G:60@(B(*(E1H92!D
M971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E
M<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*(E!A<F$@8V]M
M<')O8F%R(&5L(&UE;G-A:F4@9FER;6%D;R!H86-E(&9A;'1A(&5L(&)L;W%U
M92!D92!F:7)M82!S97!A<F%D;RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI
M<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R
M(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@(B(*(D5L
M($E$(&1E(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS;B!N;R!S92!E<W!E8VEF
M:6/S+"!S92!D96KS(&5N(&)L86YC;R!O(&YO("(*(G-E(&5N8V]N='+S(&5N
M(&QA(&)A<V4@9&4@9&%T;W,N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A
M<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R(").;R!S92!E<W!E8VEF:6/S(&QA
M(&QI<W1A(&1E(&1I<W1R:6)U8VGS;BXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0N
M<&AP.C$Q-@IM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER
M92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B3&%S(&-A<F%C
M=&5R[7-T:6-A<R!D92!C:69R861O(&YE8V5S:71A;B!U;F$@8V]N97AI\VX@
M=V5B('-E9W5R82XB"@HC.B!L:6(O2&]R9&4N<&AP.C$X-B!L:6(O2&]R9&4N
M<&AP.C4R.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U
M;&0@8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@(D5L(&%R8VAI=F\@
M)7,@=&5N9'+M82!Q=64@8V]N=&5N97(@=6YA(&]P8VGS;B`E<RXB"@HC.B!L
M:6(O2&]R9&4N<&AP.C$W.2!L:6(O2&]R9&4N<&AP.C4Q.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S
M('-E='1I;F=S+B(*;7-G<W1R(")%;"!A<F-H:79O("5S('1E;F1R[6$@<75E
M(&-O;G1E;F5R(&%L9W5N87,@;W!C:6]N97,@)7,N(@H*(SH@;&EB+TAO<F1E
M+T1A=&$N<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A
M=&$N(@IM<V=S='(@(D5L(&%R8VAI=F\@;F\@8V]N=&EE;F4@9&%T;W,N(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@
M(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A
M9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(D$@8V]N=&EN=6%C:?-N('1I
M96YE(&QA<R!C86)E8V5R87,@9&4@97-T92!M96YS86IE(&UE<W-A9V4O<F9C
M.#(R+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N
M('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U
M92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@
M=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@
M9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD
M;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN
M9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='
M96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O
M="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S
M<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N
M(&5D:71O<BXB"FUS9W-T<B`B(@HB4V4@<V%B92!Q=64@96P@;6]D;R!D92!P
M86YT86QL82!C;VUP;&5T82!D82!P<F]B;&5M87,@8V]N($EN=&5R;F5T($5X
M<&QO<F5R("(*(F1E8FED;R!A(&9A;&QO<R!D96P@;F%V96=A9&]R('%U92!N
M;R!H96UO<R!P;V1I9&\@<V]S;&%Y87(N(%!U961E('-U9G)I<B`B"B)V:7-U
M86QI>F%C:?-N(&1E(&)A<W5R82P@<.ER9&ED82!D92!F=6YC:6]N97,@9&5L
M(&5D:71O<B!Y+V\@8W5E;&=U97,@(@HB86QE871O<FEO<R!D96P@;F%V96=A
M9&]R+B!3:2!S=2!S:7-T96UA(&]P97)A=&EV;R!E<R!7:6YD;W=S(#EX+"!E
M<R!M=7D@(@HB<')O8F%B;&4@<75E('-U9G)A('5N(&9A;&QO(&1E('!R;W1E
M8V-I\VX@9V5N97)A;"!Y('1E;F=A('%U92!R96EN:6-I87(@96P@(@HB97%U
M:7!O+EQ<;EQ<;EEA(&5S=.$@879I<V%D;RX@4'5L<V4@06-E<'1A<B!S:2!A
M^FX@9&5S96$@<')O8F%R(&5L(&5D:71O<B!E;B`B"B)M;V1O(&1E('!A;G1A
M;&QA(&-O;7!L971A+B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HQ,3$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@8F5E
M;B!D96QE=&5D+B(*;7-G<W1R(")392!H82!E;&EM:6YA9&\@;&$@:61E;G1I
M9&%D(%PB)7-<(BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I9&4@
M;VYL>2(*;7-G<W1R(")3\VQO(&5L(&)O<F1E(&EZ<75I97)D;R(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T
M:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@
M0W)Y<'1?<&=P.CH@8VQA<W,N(@IM<V=S='(@(B(*(DAA>2!Q=64@:6YD:6-A
M<FQE(&$@;&$@8VQA<V4@0W)Y<'1?<&=P.CH@;&$@=6)I8V%C:?-N(&1E(&QO
M<R!B:6YA<FEO<R!';G501RXB"@HC.B!L:6(O2&]R9&4O34E-12]-1$XN<&AP
M.C(P,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@;65S<V%G92!S96YT
M(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<(B5S7"(@:&%S(&)E96X@9&ES
M<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S
M<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N(@IM<V=S='(@(B(*
M(E-E(&AA(&UO<W1R861O(&5L(&UE;G-A:F4@96YV:6%D;R!E;"`E<R!A("5S
M(&-O;B!E;"!A<W5N=&\@7"(E<UPB+EQN(@HBR7-T;R!N;R!G87)A;G1I>F$@
M<75E(&5L(&UE;G-A:F4@:&%Y82!S:61O(&QE:61O(&\@8V]M<')E;F1I9&\N
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S<*;7-G:60@(E1H92!N86UE
M('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G
M<W1R(").;VUB<F4@=71I;&EZ861O(&%L('9I;F-U;&%R(&$@;&$@<.%G:6YA
M(&1E(&-O;7!O<VEC:?-N(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HT-S0*;7-G
M:60@(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS
M9W-T<B`B16P@;OIM97)O(&1E(&-A;7!O<R!T:65N92!Q=64@<V5R('5N(&[Z
M;65R;RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R,S(*;7-G
M:60@(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO
M<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@(DAA8V4@9F%L=&$@
M96P@;?-D=6QO(&]P96YS<VP@<&%R82!L82!C;&%S92!(;W)D95]#<GEP=%]S
M;6EM93HZ+B(*"B,Z(&QI8B](;W)D92]0<F5F<RYP:'`Z,CDU"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N
M;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@(@HB
M;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"B).;R!S92!P=65D
M92!G=6%R9&%R(&QA('!R969E<F5N8VEA(%PB)7-<(B!P;W)Q=64@<W5S(&1A
M=&]S('-O8G)E<&%S86X@96P@(@HB=&%M8?%O(&WA>&EM;R!P97)M:71I9&\B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O9&5B+G!H<#HS,B!L:6(O2&]R
M9&4O34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R<&TN<&AP.C,R(&QI8B](;W)D92]-24U%+U9I97=E<B]S
M<F-H:6=H;&ET92YP:'`Z,S<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W=E
M8F-P<"YP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R
M86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F
M;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R("(B"B).;R!S92!E;F-O;G1R
M\R!E;B!E;"!S:7-T96UA(&5L('!R;V=R86UA('!A<F$@=F5R(&5S=&4@=&EP
M;R!D92!D871O<R`H)7,I+B(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z-#@W"FUS
M9VED(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C
M:&%R86-T97(N(@IM<V=S='(@(D5L(&-A<N%C=&5R(&1E(&-I=&$@9&5B92!S
M97(@<V5R('/S;&\@=6YO+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A;F0@
M;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(E/S;&\@;&]S(&QA9&]S(&EZ<75I
M97)D;R!Y(&1E<F5C:&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S
M:61E(&]N;'DB"FUS9W-T<B`B4_-L;R!E;"!L861O(&1E<F5C:&\B"@HC.B!L
M:6(O1FEL92]#4U8N<&AP.C0W.0IM<V=I9"`B5&AE('-E<&%R871O<B!M=7-T
M(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R(")%;"!S97!A<F%D
M;W(@9&5B92!S97(@<_-L;R!U;F\N(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P
M8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<
M(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B4V4@:&$@96QI;6EN
M861O(&5L('-E<G9I9&]R(%PB)7-<(BXB"@HC.B!S97)V:6-E<R]P;W)T86PO
M<G!C<W5M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R
M(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B4V4@:&$@9W5A<F1A
M9&\@96P@<V5R=FED;W(@7"(E<UPB+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R
M("5S(&AA<R!B965N(')E;6]V960N(@IM<V=S='(@(E-E(&AA(&5L:6UI;F%D
M;R!L82!S;VQI8VET=60@9&4@86QT82!D92`E<RXB"@HC.B!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C0W,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@<W!E8VEF:65D(')O=R`H)60I(&1O97,@;F]T(&5X:7-T+B(*
M;7-G<W1R("),82!F:6QA(&5S<&5C:69I8V%D82`H)60I(&YO(&5X:7-T92XB
M"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,3<Y"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!T96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM
M<V=S='(@(D5L(&%R8VAI=F\@=&5M<&]R86P@7"(E<UPB(&YO(&5X:7-T92XB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,P,@IM<V=I9"`B5&AE('1E>'0@
M>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R
M965N+B(*;7-G<W1R(")%;"!T97AT;R!Q=64@:&$@:6YT<F]D=6-I9&\@;F\@
M8V]I;F-I9&4@8V]N(&5L(&1E(&QA('!A;G1A;&QA+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@
M(E1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@(E/S;&\@
M;&]S(&QA9&]S('-U<&5R:6]R(&4@:6YF97)I;W(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4
M:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R(")3\VQO(&5L(&QA9&\@<W5P97)I
M;W(B"@HC.B!L:6(O2&]R9&4O1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L
M;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB
M"FUS9W-T<B`B4V4@<&5R9&EE<F]N(&QO<R!D871O<R!C87)G861O<R!D97-D
M92!E;"!P87-O(&%N=&5R:6]R+B(*"B,Z(&QI8B](;W)D92]$871A+V-S=BYP
M:'`Z,C8R(&QI8B](;W)D92]$871A+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@
M=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(DYO
M('-E('!U9&\@9W5A<F1A<B!E;"!A<F-H:79O(&-A<F=A9&\N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Y(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ,3`*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I
M<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(").;R!E<W3A(&1I<W!O;FEB;&4@
M96P@8FQO<75E(&1E('=E871H97(N8V]M+B(*"B,Z('5T:6PO:6-O;E]B<F]W
M<V5R+G!H<#HR-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER96-T
M;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(DYO('-E(&5N8V]N='+S
M(&5L(&1I<F5C=&]R:6\@9&4@5&5M87,@7"(E<UPB+B(*"B,Z(&QI8B](;W)D
M92]0<F5F<R]522YP:'`Z,3<X"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N
M<R!A=F%I;&%B;&4N(@IM<V=S='(@(DYO('-E(&1I<W!O;F4@9&4@;W!C:6]N
M97,N(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C,U,`IM<V=I
M9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I
M;FQI;F4N(@IM<V=S='(@(DYO(&AA>2!P87)T97,@<75E('-E('!U961A;B!M
M;W-T<F%R(&5N(&SM;F5A+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#`Q
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C
M:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@
M8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+B(*
M;7-G<W1R("(B"B)%;B!E<W1E(&-A;7!O(&AA>2!D96UA<VEA9&]S(&-A<F%C
M=&5R97,N($AA(&EN=')O9'5C:61O("5S(&-A<F%C=&5R97,@>2`B"B)T:65N
M92!Q=64@:6YT<F]D=6-I<B!M96YO<R!D92`E<RXB"@HC.B!S:6=N=7`N<&AP
M.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A('!R;V)L96T@861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M
M.B`E<R(*;7-G<W1R(")392!P<F]D=6IO('5N('!R;V)L96UA(&%L(&'Q861I
M<B!A(%PB)7-<(B!A;"!S:7-T96UA.B`E<R(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M
M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E
M;3H@(@IM<V=S='(@(B(*(E-E('!R;V1U:F\@=6X@<')O8FQE;6$@86P@8F]R
M<F%R(&QO<R!D871O<R!D96P@=7-U87)I;R!<(B5S7"(@9&5L('-I<W1E;6$Z
M("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H
M92!S>7-T96TZ("(*;7-G<W1R(")392!P<F]D=6IO('5N('!R;V)L96UA(&%L
M(&5L:6UI;F%R(&$@7"(E<UPB(&1E;"!S:7-T96UA.B`B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@
M<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z("5S(@IM<V=S='(@(E-E('!R;V1U
M:F\@=6X@<')O8FQE;6$@86P@86-T=6%L:7IA<B!<(B5S7"(Z("5S(@H*(SH@
M;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDR-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.
M;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(E-E('!R;V1U:F\@=6X@<')O
M8FQE;6$@8V]N(&QA(&-A<F=A(&1E;"!A<F-H:79O.B!.;R!S92!C87)G\R`E
M<RXB"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3,P"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@
M(@HB86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@(B(*(E-E('!R
M;V1U:F\@=6X@<')O8FQE;6$@8V]N(&QA(&-A<F=A(&1E;"!A<F-H:79O+B!%
M;"`E<R!E<F$@;>%S(&=R86YD92!Q=64@96P@(@HB=&%M8?%O(&WA>&EM;R!P
M97)M:71I9&\@*"5D(&)Y=&5S*2XB"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP
M:'`Z.3,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R
M;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P
M87)T:6%L;'D@=7!L;V%D960N(@IM<V=S='(@(B(*(E-E('!R;V1U:F\@=6X@
M<')O8FQE;6$@8V]N(&QA(&-A<F=A(&1E;"!A<F-H:79O+B!3\VQO('-E(&-A
M<F?S('!A<F-I86QM96YT92`B"B)E;"`E<RXB"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B4V4@
M<')O9'5J;R!U;B!E<G)O<B!A;"!M;W-T<F%R(&5S=&$@<&%R=&4@9&5L(&UE
M;G-A:F4B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB
M"FUS9W-T<B`B4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!I;7!O<G1A<B!L;W,@
M9&%T;W,@9&5L(&-O;G1A8W1O+B(*"B,Z(&QI8B](;W)D92]$871A+VEM8RYP
M:'`Z,S$*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE
M(&E#86QE;F1A<B!D871A+B(*;7-G<W1R(")392!P<F]D=6IO('5N(&5R<F]R
M(&%L(&EM<&]R=&%R(&QO<R!D871O<R!I0V%L96YD87(N(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HX,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R
M<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE
M9G0@;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(B(*(E-E('!R
M;V1U:F\@=6X@97)R;W(@96X@96P@9F]R;75L87)I;R!D92!C;VYF:6=U<F%C
M:?-N+B!0=65D92!Q=64@:&%Y82`B"B)O;'9I9&%D;R!R96QL96YA<B!U;B!C
M86UP;R!N96-E<V%R:6\N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O
M<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L
M96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(E-E('!R;V1U
M:F\@=6X@97)R;W(@86P@96IE8W5T87(@;&$@9G5N8VGS;B!E<W!E8VEF:6-A
M9&$@9&4@;&$@;&EB<F5T82!D92`B"B)D:7)E8V-I;VYE<RX@5G5E;'9A(&$@
M<')O8F%R(&WA<R!A9&5L86YT92XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C0P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I
M;B!L871E<BXB"FUS9W-T<B`B(@HB4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!A
M8W1U86QI>F%R(&QO<R!D971A;&QE<R!D96P@8V]N=&%C=&\N(%9U96QV82!A
M('!R;V)A<B`B"B)MX7,@861E;&%N=&4N(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8T-2!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z
M,C(R"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE
M(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*
M;7-G<W1R("(B"B)392!P<F]D=6IO('5N(&5R<F]R(&%L(&%C='5A;&EZ87(@
M;&$@;&ES=&$@9&4@9&ES=')I8G5C:?-N+B!6=65L=F$@82!P<F]B87(@(@HB
M;>%S(&%D96QA;G1E+B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HQ-#@*;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P
M<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(D5S=&4@<V5R=FED;W(@
M24U!4"!N;R!S;W!O<G1A(&QA<R!C87)P971A<R!C;VUP87)T:61A<RXB"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HT.`IM<V=I9"`B5&AI
M<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92XB
M"FUS9W-T<B`BR7-T92!N;R!P87)E8V4@<V5R('5N(&%R8VAI=F\@<F%R(';A
M;&ED;RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HU,@IM
M<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@
M9FEL92XB"FUS9W-T<B`BR7-T92!N;R!P87)E8V4@<V5R('5N(&%R8VAI=F\@
M>FEP(';A;&ED;RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$R-PIM<V=I
M9"`B5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB
M97(N(@IM<V=S='(@(LES=&4@;F\@<&%R96-E('-E<B!U;B!N^FUE<F\@9&4@
M=&%R:F5T82!VX6QI9&\N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HQ.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z
M+R\B"B)C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@
M05!)(@IM<V=S='(@(B(*(D5S=&4@8V]N=')O;&%D;W(@<&5R;6ET92!E;G9I
M87(@;65N<V%J97,@82!T<F%VZ7,@9&4@;&$@<&%S87)E;&$@0VQI8VMA=&5L
M;"`B"B(H:'1T<#HO+V-L:6-K871E;&PN8V]M*2P@;65D:6%N=&4@;&$@05!)
M($A45%`B"@HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED
M("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T
M:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y
M+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB17-T92!C;VYT<F]L
M861O<B!P97)M:71E(&5N=FEA<B!M96YS86IE<R!A('1R87;I<R!D92!L82!P
M87-A<F5L82!724X@*&AT='`Z+R\B"B)W:6YP;&,N8V]M*2P@;65D:6%N=&4@
M;&$@05!)($A45%`B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3$U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S
M;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS
M9W-T<B`B(@HB17-T92!C;VYT<F]L861O<B!P97)M:71E(&5N=FEA<B!M96YS
M86IE<R!A('1R87;I<R!D92!L82!P87-A<F5L82!S;7,R96UA:6P@(@HB*&AT
M='`Z+R]S;7,R96UA:6PN8V]M*2P@;65D:6%N=&4@;&$@05!)($A45%`B"@HC
M.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U"FUS9VED
M("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V
M:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y
M+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M
M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W
M=RXQ.3`N:70I+B(*;7-G<W1R("(B"B)%<W1E(&-O;G1R;VQA9&]R('!E<FUI
M=&4@96YV:6%R(&UE;G-A:F5S('9I82!33510(&$@=')A=NES(&1E(&QA('!A
M<V%R96QA(&1E("(*(E9O9&%F;VYE(&1E($ET86QI82P@<_-L;R!A(&[Z;65R
M;W,@5F]D869O;F4N($AA8V4@9F%L=&$@=6YA(&-U96YT82!D92!C;W)R96\@
M(@HB9&4@5F]D869O;F4@9&4@271A;&EA("AH='1P.B\O=W=W+C$Y,"YI="DN
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDW."!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3`U-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`X-@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3$Q-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$X,B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3(U-@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,P-2!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3,Y."!L:6(O2&]R9&4O1F]R;2YP:'`Z,34U
M-PHC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@S.2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3DU."!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`P-0HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C`R.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`W."!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C$T.0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(R,2!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C0P."!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0U
M,`HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C8S-R!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C@Q,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$Q.0HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,S(Y-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,S@P-2!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,S@Q,PIM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E
M9"XB"FUS9W-T<B`B2&%C92!F86QT82!E<W1E(&-A;7!O+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,#8U"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@(D5S=&4@8V%M<&\@<_-L;R!P
M=65D92!C;VYT96YE<B!E;G1E<F]S+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR-#$V"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M
M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R(")%<W1E(&-A;7!O('/S;&\@
M<'5E9&4@8V]N=&5N97(@;OIM97)O<R!Y(&QO<R!D;W,@<'5N=&]S+B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,#DT"FUS9VED(")4:&ES(&9I96QD(&UA
M>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R(")%<W1E(&-A
M;7!O('/S;&\@<'5E9&4@8V]N=&5N97(@=F%L;W)E<R!O8W1A;&5S+B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,3(S"FUS9VED(")4:&ES(&9I96QD(&UU
M<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E
M9V5R<R(*;7-G<W1R("(B"B)%<W1E(&-A;7!O('1I96YE('%U92!S97(@=6YA
M(&QI<W1A(&1E(&5N=&5R;W,@<V5P87)A9&]S('!O<B!C;VUA<R!O(&5S<&%C
M:6]S+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY.#D*;7-G:60@(E1H:7,@
M9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`B17-T92!C
M86UP;R!T:65N92!Q=64@<V5R('5N(&[Z;65R;R!VX6QI9&\N(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(X,3@*;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S
M="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L
M(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T<B`B(@HB17-T92!C
M86UP;R!T:65N92!Q=64@8V]N=&5N97(@=6X@8_-D:69O(&1E(&-O;&]R(&5N
M(&9O<FUA=&\@4D="($AE>&%D96-I;6%L+"`B"B)P;W(@96IE;7!L;R`G(S$R
M,S1A9B<N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C4V,0IM<V=I9"`B5&AI
M<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R(")9
M82!S92!H82!P<F]C97-A9&\@97-T92!F;W)M=6QA<FEO+B(*"B,Z('1E;7!L
M871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M:7,@:7,@)7,N(@IM<V=S='(@(D5S=&\@97,@)7,N(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HT-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I
M<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE
M8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E
M<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES
M="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I<VET("5S(@IM
M<V=S='(@(B(*(LES=&\@97,@=6X@;V)J971O(&1E($MO;&%B($=R;W5P=V%R
M92X@4&%R82!V97)L;R!N96-E<VET82!U;B!C;&EE;G1E(&1E("(*(F-O<G)E
M;R`@<75E(&5N=&EE;F1A(&5L(&9O<FUA=&\@2V]L86(@1W)O=7!W87)E+B!0
M87)A('9E<B!U;F$@;&ES=&$@9&4@(@HB9&EC:&]S(&-L:65N=&5S('9I<VET
M92`E<R(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HU.3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN
M(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM
M<V=S='(@(B(*(D5S=&4@;65N<V%J92!S92!E<V-R:6)I\R!C;VX@=6X@:G5E
M9V\@9&4@8V%R86-T97)E<R`H)7,I(&1I<W1I;G1O(&%L('-U>6\N(@H*(SH@
M;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R
M(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R(")%<W1E(&[Z;65R;R!D
M96)E('-E<B!P;W(@;&\@;65N;W,@=6X@=6YO+B(*"B,Z(&QI8B](;W)D92]#
M;VUP<F5S<R]G>FEP+G!H<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@
M=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@(D5S=&4@
M<V5R=FED;W(@;F\@<'5E9&4@9&5S8V]M<')I;6ER(&%R8VAI=F]S('II<"!Y
M(&=Z:7`N(@H*(SH@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HQ.#D*;7-G:60@
M(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"XB"FUS9W-T
M<B`B17-T92!S:7-T96UA(&%C='5A;&UE;G1E(&5S=.$@9&5S86-T:79A9&\N
M(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ,C0*;7-G:60@(E1H:7,@
M=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS9W-T<B`B17-T92!V86QO<B!T
M:65N92!Q=64@<V5R('5N(&[Z;65R;RXB"@HC.B!S97)V:6-E<R]I;6%G97,O
M8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E
M(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S='(@(D5S=&$@
M=F5N=&%N82!S\VQO('!U961E(&%B<FER<V4@9&5S9&4@=6YA('9E;G1A;F$@
M9&4@;W!C:6]N97,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV-@IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R(")4<G5E;F\B"@HC
M.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HR,S8*;7-G:60@(E1I
M8VME=',B"FUS9W-T<B`B26YC:61E;F-I87,B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C0R-2!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G
M:60@(E1I;64B"FUS9W-T<B`B2&]R82(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES
M=')Y+G!H<"YD:7-T.C,X.`IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R
M(")#+B!T:65M<&]S(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W"FUS9VED
M(")4:6UE(&9O<FUA="(*;7-G<W1R(")&;W)M871O(&AO<F%R:6\B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C4S,0IM<V=I9"`B5&EM92!S96QE8W1I;VXB
M"FUS9W-T<B`B4V5L96-C:?-N(&1E(&AO<F$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R
M,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,P"FUS9VED(")4:6UO<BU,
M97-T92(*;7-G<W1R(")4:6UO<BU,97-T92(*"B,Z(&QI8B]";&]C:R]I9G)A
M;64N<&AP.C(P(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y
M"FUS9VED(")4:71L92(*;7-G<W1R(")4[71U;&\B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L92`H
M=&]O;'1I<"DZ(@IM<V=S='(@(E3M='5L;R`H8V]N<V5J;RDZ(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM
M<V=S='(@(E!A<F$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C4T"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L
M(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@
M:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"B)087)A('-E;&5C
M8VEO;F%R('9A<FEO<R!C86UP;W,L(&UA;G1E;F=A('!U;'-A9&$@;&$@=&5C
M;&$@0V]N=')O;"`H4$,I(&\@(@HB0V]M86YD;R`H36%C*2!A;"!H86-E<B!C
M;&EC:RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P"FUS
M9VED(")4;V1A>2(*;7-G<W1R(")(;WDB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3
M;W5R8V4B"FUS9W-T<B`B0V]N;75T87(@;W)I9V5N($A434PB"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(R,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(S"FUS9VED
M(")4;V=O(@IM<V=S='(@(E1O9V\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(V"FUS9VED(")4;VME;&%U(@IM<V=S
M='(@(E1O:V5L874B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S`R"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R(")-8?%A;F$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(R-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(Y"FUS9VED
M(")4;VYG82(*;7-G<W1R(")4;VYG82(*"B,Z(&QI8B](;W)D92]!=71H+VMO
M;&%B+G!H<#HQ,#0*;7-G:60@(E1O;R!M86YY(&EN=F%L:60@;&]G:6YS(&1U
M<FEN9R!T:&4@;&%S="!M:6YU=&5S+B(*;7-G<W1R(")$96UA<VEA9&]S(&EN
M=&5N=&]S(&9A;&QI9&]S(&5N(&QO<R#Z;'1I;6]S(&UI;G5T;W,N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Q
M"FUS9VED(")4;W`B"FUS9W-T<B`B4W5P97)I;W(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A
M;64@*%]T;W`I(@IM<V=S='(@(D9R86UE('-U<&5R:6]R("A?=&]P*2(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I9"`B5')A;G-L871I;VYS
M(@IM<V=S='(@(E1R861U8V-I;VYE<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S(*;7-G:60@(E1R:6YI9&%D(&%N
M9"!4;V)A9V\B"FUS9W-T<B`B5')I;FED860@>2!4;V)A9V\B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3<Y,`IM<V=I9"`B5')U92!O<B!F86QS92(*;7-G
M<W1R(")697)D861E<F\@;R!F86QS;R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(DUA
M<B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,C@*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B5/IN97HB"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(R.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,Q"FUS9VED
M(")4=7)K97DB"FUS9W-T<B`B5'5R<77M82(*"B,Z(&-O;F9I9R\N8F%K+VYL
M<RYP:'`N9&ES=#HQ.34*;7-G:60@(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@IM
M<V=S='(@(E1U<F-O("A)4T\M.#@U.2TY*2(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C<*;7-G:60@(E1U<FMM96YI
M<W1A;B(*;7-G<W1R(")4=7)K;65N:7-TX6XB"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S
M,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(P"FUS9VED(")4=7)K<R!A
M;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B27-L87,@5'5R:W,@>2!#86EC
M;W,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C,S"FUS9VED(")4=79A;'4B"FUS9W-T<B`B5'5V86QU(@H*(SH@;&EB
M+TAO<F1E+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO:6-E.B`B
M"FUS9W-T<B`B17-C<FEB82!S=2!E;&5C8VGS;CH@(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(U.`IM<V=I9"`B52Y6+B!I;F1E>#H@(@IM
M<V=S='(@(LUN9&EC92!5+E8N.B`B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H
M<#HQ-R!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(T.0IM<V=I
M9"`B55),(@IM<V=S='(@(E523"(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L
M:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R(")54DP@9&4@<W4@:6YF;W)M
M92!D92!E<W1A9&\@9&4@96YV[6\@9&5L(&=U:?-N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PIM<V=I9"`B55),.B(*
M;7-G<W1R(")54DPZ(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$R
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(S-PIM<V=I9"`B56=A;F1A(@IM<V=S='(@(E5G86YD
M82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,S8*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B56-R86YI82(*"B,Z(&QI
M8B]61E,O9FEL92YP:'`Z-#(U"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&
M4R!D:7)E8W1O<GDN(@IM<V=S='(@(DEN8V%P87H@9&4@86-C961E<B!A;"!D
M:7)E8W1O<FEO(%9&4RXB"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP
M.CDV"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I
M;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R("(B"B));F-A<&%Z(&1E(&'Q
M861I<B!I;F9O<FUA8VGS;B!D92!U<W5A<FEO(&%D:6-I;VYA;"!A;"!R96%L
M:7IA<B!E;"!A;'1A+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS.38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O
M<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DEN8V%P87H@9&4@8V%M8FEA
M<B!L;W,@<')I=FEL96=I;W,@9&5L(&%R8VAI=F\@5D93(%PB)7-<(BXB"@HC
M.B!L:6(O5D93+V9I;&4N<&AP.C,Y."!L:6(O5D93+VUU<W%L+G!H<#HT.#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S
M:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B26YC87!A>B!D92!C
M86UB:6%R(&QO<R!P<FEV:6QE9VEO<R!D96P@87)C:&EV;R!61E,@)7,O)7,N
M(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<Y.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R("));F-A<&%Z(&1E
M(&-A;6)I87(@82`E<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,C,W"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@
M7"(E<UPB+B(*;7-G<W1R("));F-A<&%Z(&1E(&-O;7!R;V)A<B!E;"!T86UA
M\6\@9&4@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-S`W(&QI8B]6
M1E,O<W%L+G!H<#HQ,#0P(&QI8B]61E,O<W%L7V9I;&4N<&AP.C@W.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F
M(%PB)7,O)7-<(BXB"FUS9W-T<B`B26YC87!A>B!D92!C;VUP<F]B87(@96P@
M=&%M8?%O(&1E(%PB)7,O)7-<(BXB"@HC.B!L:6(O2&]R9&4O075T:"]S<6PN
M<&AP.C0S.0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E
M<BXB"FUS9W-T<B`B26YC87!A>B!D92!C;VYE8W1A<G-E(&%L('-E<G9I9&]R
M(%-13"XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#@S"FUS9VED(")5;F%B;&4@
M=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`B26YC87!A>B!D92!C;VYE
M8W1A<B!C;VX@4U-,+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C,X(&QI8B]6
M1E,O9FEL92YP:'`Z,C0S(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(Q-`HC.B!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HR,3D@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z
M,C(W"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B
M26YC87!A>B!D92!C;W!I87(@96P@87)C:&EV;R!61E,N(@H*(SH@;&EB+U9&
M4R]F='`N<&AP.C,W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("));F-A<&%Z
M(&1E(&-R96%R(&5L(&1I<F5C=&]R:6\@5D93(%PB)7-<(BXB"@HC.B!L:6(O
M5D93+V9I;&4N<&AP.C,V-R!L:6(O5D93+VUU<W%L+G!H<#HR-S`@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z,C<T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&
M4R!D:7)E8W1O<GDN(@IM<V=S='(@(DEN8V%P87H@9&4@8W)E87(@96P@9&ER
M96-T;W)I;R!61E,N(@H*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,3(T"FUS9VED
M(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R("));F-A<&%Z
M(&1E(&-R96%R(&5L(&%R8VAI=F\@5D93+B(*"B,Z(&QI8B]61E,O<VUB+G!H
M<#HR.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!6
M1E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B26YC87!A>B!D92!C<F5A<B!L
M82!C87)P971A(%9&4R!<(B5S7"(B"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(W
M.`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS
M9W-T<B`B26YC87!A>B!D92!C<F5A<B!U;B!A<F-H:79O(%9&4R!V86/M;RXB
M"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O9WII<"YP:'`Z-SD@;&EB+TAO<F1E
M+T-O;7!R97-S+W1A<BYP:'`Z-S8*;7-G:60@(E5N86)L92!T;R!D96-O;7!R
M97-S(&1A=&$N(@IM<V=S='(@(DEN8V%P87H@9&4@9&5S8V]M<')I;6ER(&QO
M<R!D871O<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,S`S(&QI8B]61E,O<VUB
M+G!H<#HR,C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R
M("));F-A<&%Z(&1E(&5L:6UI;F%R(%PB)7-<(BP@96P@9&ER96-T;W)I;R!N
M;R!E<W3A('9A8^UO+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S@@861M:6XO
M<&5R;7,O9&5L971E+G!H<#HT-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM<V=S='(@(DEN8V%P87H@9&4@
M96QI;6EN87(@7"(E<UPB.B`E<RXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,T
M-"!L:6(O5D93+VUU<W%L+G!H<#HS,C,@;&EB+U9&4R]S<6PN<&AP.C0P-PHC
M.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS-S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@
M96UP='DB"FUS9W-T<B`B26YC87!A>B!D92!E;&EM:6YA<B`E<RP@96P@9&ER
M96-T;W)I;R!N;R!E<W3A('9A8^UO(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z,S@T(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,X.`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R
M("));F-A<&%Z(&1E(&5L:6UI;F%R(&5L(&1I<F5C=&]R:6\@5D93(&1E(&9O
M<FUA(')E8W5R<VEV82XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,U,"!L:6(O
M5D93+VUU<W%L+G!H<#HS,S0@;&EB+U9&4R]M=7-Q;"YP:'`Z,S0W"B,Z(&QI
M8B]61E,O;75S<6PN<&AP.C,U-2!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS.#`*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B26YC87!A>B!D92!E;&EM:6YA<B!E;"!D:7)E8W1O<FEO(%9&4RXB"@HC
M.B!L:6(O5D93+W-Q;"YP:'`Z-#,R(&QI8B]61E,O<W%L+G!H<#HT-#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T
M;W)Y.B`E<RXB"FUS9W-T<B`B26YC87!A>B!D92!E;&EM:6YA<B!E;"!D:7)E
M8W1O<FEO(%9&4SH@)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C(Q,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`B26YC87!A>B!D92!E;&EM:6YA<B!E;"!A<F-H:79O
M(%9&4R!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS,38@;&EB+U9&
M4R]M=7-Q;"YP:'`Z,38W(&QI8B]61E,O;75S<6PN<&AP.C$X,`HC.B!L:6(O
M5D93+VUU<W%L+G!H<#HQ.#<@;&EB+U9&4R]S<6PN<&AP.C(Y,2!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HT,3D*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-#(W
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R("))
M;F-A<&%Z(&1E(&5L:6UI;F%R(&5L(&%R8VAI=F\@5D93+B(*"B,Z(&QI8B]6
M1E,O<VUB+G!H<#HR-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B26YC87!A>B!D
M92!E;&EM:6YA<B!L82!C87)P971A(%9&4R!<(B5S7"(N(@H*(SH@;&EB+U9&
M4R]S<6PN<&AP.C0R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(DEN8V%P87H@
M9&4@96QI;6EN87(@96P@5D93(&1E(&9O<FUA(')E8W5R<VEV83H@)7,N(@H*
M(SH@;&EB+U9&4R]F='`N<&AP.C@T-PIM<V=I9"`B56YA8FQE('1O(&1E=&5R
M;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`B26YC87!A>B!D92!D
M971E<FUI;F%R(&5L(&1I<F5C=&]R:6\@86-T=6%L+B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-C`T"FUS9VED(")5;F%B;&4@=&\@97AT<F%C
M="!C97)T:69I8V%T92!D971A:6QS(@IM<V=S='(@(DEN8V%P87H@9&4@97AT
M<F%E<B!L;W,@9&5T86QL97,@9&5L(&-E<G1I9FEC861O+B(*"B,Z(&QI8B].
M970O24U34"YP:'`Z-#,W(&QI8B].970O24U34"]!=71H+G!H<#HQ,C,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I
M;VX@;V8@)7,N(@IM<V=S='(@(DEN8V%P87H@9&4@8V%R9V%R(&QA(&1E9FEN
M:6-I\VX@9&4@)7,N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR,#@@;&EB+U9&
M4R]F:6QE+G!H<#HR,3,@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3<Y"B,Z(&QI
M8B]61E,O<W%L7V9I;&4N<&AP.C$X-`IM<V=I9"`B56YA8FQE('1O(&UO=F4@
M5D93(&9I;&4N(@IM<V=S='(@(DEN8V%P87H@9&4@=')A<VQA9&%R(&5L(&%R
M8VAI=F\@5D93+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HY."!L:6(O5D93+W-M
M8BYP:'`Z.3,@;&EB+U9&4R]S;6(N<&AP.C$P-@HC.B!L:6(O5D93+W-M8BYP
M:'`Z-C8U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&
M4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B26YC87!A>B!D92!A8G)I<B!E;"!A
M<F-H:79O(%9&4R!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR.3`@
M;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3,X(&QI8B]61E,O<W%L7V9I;&4N<&AP
M.C$T,0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I
M;F<N(@IM<V=S='(@(DEN8V%P87H@9&4@86)R:7(@96P@87)C:&EV;R!61E,@
M<&%R82!E<V-R:6)I<BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C@S(&QI8B]6
M1E,O9FEL92YP:'`Z,3,W(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<V"FUS9VED
M(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB"FUS9W-T<B`B26YC87!A>B!D
M92!A8G)I<B!E;"!A<F-H:79O(%9&4RXB"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=&=Z+G!H<#HT-0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E
M<W-E9"!A<F-H:79E+B(*;7-G<W1R("));F-A<&%Z(&1E(&%B<FER(&5L(&%R
M8VAI=F\@8V]M<')I;6ED;RXB"@HC.B!L:6(O5D93+G!H<#HX-38*;7-G:60@
M(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN
M(@IM<V=S='(@(DEN8V%P87H@9&4@;&5E<B!U;B!A<F-H:79O(%9&4R`H:&$@
M9F%L;&%D;R!F:6QE<VEZ92@I*2XB"@HC.B!L:6(O5D93+G!H<#HX.#<*;7-G
M:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A
M:6QE9"DN(@IM<V=S='(@(DEN8V%P87H@9&4@;&5E<B!U;B!A<F-H:79O(%9&
M4R`H:&$@9F%L;&%D;R!G971&:6QE4VEZ92@I*2XB"@HC.B!L:6(O2&]R9&4O
M4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*;7-G:60@(E5N86)L92!T;R!R
M96%D(&9I;&4Z("(*;7-G<W1R("));F-A<&%Z(&1E(&QE97(@=6X@87)C:&EV
M;SH@(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HV.#@*;7-G:60@(E5N86)L92!T
M;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`B26YC87!A
M>B!D92!L965R(&5L(&1I<F5C=&]R:6\@=F9S<F]O="XB"@HC.B!L:6(O2&]R
M9&4O2V]L86(N<&AP.C$Q,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A
M9'D@97AI<W1S(@IM<V=S='(@(DEN8V%P87H@9&4@<F5N;VUB<F%R("5S(&-O
M;6\@)7,Z(&QA(&-A<G!E=&$@9&5S=&EN;R!Y82!E>&ES=&4B"@HC.B!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HS,C,*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B26YC87!A>B!D92!R96YO;6)R87(@
M96P@9&ER96-T;W)I;R!61E,N(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C,T-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E
M8W1O<GDZ("5S+B(*;7-G<W1R("));F-A<&%Z(&1E(')E;F]M8G)A<B!E;"!D
M:7)E8W1O<FEO(%9&4SH@)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,U,2!L
M:6(O5D93+W-M8BYP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("));F-A<&%Z
M(&1E(')E;F]M8G)A<B!E;"!A<F-H:79O(%9&4R!<(B5S7"(B"@HC.B!L:6(O
M5D93+V9I;&4N<&AP.C8R.2!L:6(O5D93+VUU<W%L+G!H<#HR-#$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E
M<RXB"FUS9W-T<B`B26YC87!A>B!D92!R96YO;6)R87(@96P@87)C:&EV;R!6
M1E,@)7,O)7,N(@H*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,C$S(&QI8B]61E,O
M;75S<6PN<&AP.C0V-"!L:6(O5D93+W-Q;"YP:'`Z,S,X"B,Z(&QI8B]61E,O
M<W%L7V9I;&4N<&AP.C,Q-2!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS,S<*;7-G
M:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N(@IM<V=S='(@(DEN8V%P
M87H@9&4@<F5N;VUB<F%R(&5L(&%R8VAI=F\@5D93+B(*"B,Z(&QI8B]61E,O
M25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS9VED(")5;F%B;&4@=&\@<G5N
M("=M:VES;V9S)RXB"FUS9W-T<B`B26YC87!A>B!D92!E:F5C=71A<B`G;6MI
M<V]F<R<N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ.#$T"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!T<FEG9V5R(&9R964O8G5S>2!U<&1A
M=&4@9F]R("5S(@IM<V=S='(@(B(*(DYO('-E('!U961E(&%C=&EV87(@;&$@
M86-T=6%L:7IA8VGS;B!D92!I;F9O<FUA8VGS;B!D92!T:65M<&\@9&ES<&]N
M:6)L92!D92`E(@HB<R(*"B,Z(&QI8B]61E,O9G1P+G!H<#HQ-30@;&EB+U9&
M4R]F='`N<&AP.C$U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("));F-A<&%Z(&1E(&5S
M8W)I8FER(&5L(&%R8VAI=F\@5D93(%PB)7-<(BXB"@HC.B!L:6(O5D93+V9I
M;&4N<&AP.C$X-@IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC
M;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B26YC87!A>B!D92!E<V-R:6)I<B!U
M;B!A<F-H:79O(%9&4R`H:&$@9F%L;&%D;R!C;W!Y*"DI+B(*"B,Z(&QI8B]6
M1E,O9FEL92YP:'`Z,CDT(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$T-B!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HQ-3$*;7-G:60@(E5N86)L92!T;R!W<FET92!6
M1E,@9FEL92!D871A+B(*;7-G<W1R("));F-A<&%Z(&1E(&5S8W)I8FER(&QO
M<R!D871O<R!D96P@87)C:&EV;R!61E,N(@H*(SH@;&EB+U9&4RYP:'`Z.#8R
M"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@
M8F4@97AC965D960N(@IM<V=S='(@(DEN8V%P87H@9&4@97-C<FEB:7(@=6X@
M87)C:&EV;R!61E,L('-E('-U<&5R87+A(&QA('%U;W1A+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*;7-G:60@(E5N
M9&5R;&EN92(*;7-G<W1R(")3=6)R87EA9&$B"@HC.B!T96UP;&%T97,O<')E
M9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B1&5S
M:&%C97(@8V%M8FEO<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N
M(@IM<V=S='(@(D1E<VAA8V4@;&$@^FQT:6UA(&%C8VGS;B(*"B,Z(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C$@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,X.`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS
M92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`B4F5S<'5E
M<W1A(&EN97-P97)A9&$@9&5L('-E<G9I9&]R(&5N(&QA(&-O;F5X:?-N.B`B
M"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$W(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,SD*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,W-B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S@R"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@
M<V5R=F5R('1O.B`B"FUS9W-T<B`B4F5S<'5E<W1A(&EN97-P97)A9&$@9&5L
M('-E<G9I9&]R(&$Z("(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA
M;F%G97(N<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C8Q"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(E-I;B!C871E
M9V]R[6$B"@HC.B!C;VYF:6<O+F)A:R]N;',N<&AP+F1I<W0Z,3DV"FUS9VED
M(")5;FEC;V1E("A55$8M."DB"FUS9W-T<B`B56YI8V]D92`H551&+3@I(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-38@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(S-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<*
M;7-G:60@(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(D5M:7)A=&]S
M(,%R86)E<R!5;FED;W,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,S@*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S
M='(@(DEN9VQA=&5R<F$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C0P"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S
M='(@(D5S=&%D;W,@56YI9&]S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(S.0IM<V=I9"`B56YI=&5D(%-T871E<R!-
M:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S='(@(D5S=&%D;W,@56YI9&]S
M(&UE;F]S(&QA<R!I<VQA<R!P97)I9NER:6-A<R(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z-S@@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8R"FUS
M9VED(")5;FET<R(*;7-G<W1R(")5;FED861E<R(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]T9WHN<&AP.C4X(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C0R.0HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,S`*;7-G:60@(E5N
M:VYO=VXB"FUS9W-T<B`B1&5S8V]N;V-I9&\B"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I
M9"`H05!)($UE<W-A9V4@240I+B(*;7-G<W1R(")!<&EM<V=I9"!D97-C;VYO
M8VED;R`H240@9&4@;65N<V%J92!D92!L82!!4$DI+B(*"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN;W=N(&-L
M:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@(D-L:6US9VED
M(&1E<V-O;F]C:61O("A)1"!D92!M96YS86IE(&1E;"!C;&EE;G1E*2XB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30W"FUS9VED(")5;FMN
M;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(")392!H82!D969I;FED
M;R!U;F$@=6)I8V%C:?-N(&1E<V-O;F]C:61A+B(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S97)N
M86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R(")5<W5A<FEO(&\@8V]N=')A<V7Q
M82!D97-C;VYO8VED;W,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U
M<G)E;G0@96QE;65N="(*;7-G<W1R(")%;&EM:6YA<B!V[6YC=6QO(&1E;"!E
M;&5M96YT;R!A8W1U86PB"@HC.B!L:6(O2&]R9&4O261E;G1I='DN<&AP.C,P
M,@IM<V=I9"`B56YN86UE9"(*;7-G<W1R(")3:6X@;F]M8G)E(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B
M(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P
M>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O
M;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII
M;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R
M:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"B),;W,@
M9W5I;VYE<R!S:6X@<')I=FEL96=I;W,@;F\@<'5E9&5N(&%C8V5D97(@9&4@
M9F]R;6$@<')O9W)A;>%T:6-A(&$@0V]R=&%R+R(*(D-O<&EA<B]096=A<B!P
M;W(@<F%Z;VYE<R!D92!S96=U<FED860N(%!U;'-E($%C97!T87(@<&%R82!V
M97(@96X@;6]Z:6QL82YO<F<@(@HB=6YA(&YO=&$@=.EC;FEC82!Q=64@;&4@
M;75E<W1R92!C\VUO('!E<FUI=&ER('%U92!U;B!G=6GS;B!A8V-E9&$@86P@
M(@HB<&]R=&%P87!E;&5S+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM
M<V=S='(@(D%N=6QA<B!C;VQO<B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-C@W(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z.3(W"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z.3,S"FUS9VED(")5;G-U<'!O<G1E
M9"!%>'1E;G-I;VXB"FUS9W-T<B`B17AT96YS:?-N(&YO('-O<&]R=&%D82(*
M"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,3DW('1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B06-T
M=6%L:7IA<B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@(D%C
M='5A;&EZ87(@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C<V"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R(")!8W1U86QI>F%R
M('5S=6%R:6\B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$T-"!A9&UI;B]P97)M
M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS9W-T<B`B
M4V4@:&$@86-T=6%L:7IA9&\@7"(E<UPB+B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C@S"FUS9VED(")5<&=R861E('-C<FEP="!D96QE=&5D+B(*
M;7-G<W1R(")392!H82!E;&EM:6YA9&\@96P@9W5I\VX@9&4@86-T=6%L:7IA
M8VGS;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HQ.3@*;7-G:60@(E5P;&]A9"(*
M;7-G<W1R(")#87)G87(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@U
M"FUS9VED(")5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@
M=&\@=&AE('-E<G9E<BXB"FUS9W-T<B`B(@HB4V4@:&%N(&-A<F=A9&\@96X@
M96P@<V5R=FED;W(@=&]D;W,@;&]S(&%R8VAI=F]S(&1E(&-O;F9I9W5R86-I
M\VX@9&4@(@HB87!L:6-A8VEO;F5S+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R
M(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B06QF86)E=&\@;&%T:6YO(&5N(&UA
M>?IS8RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM
M<V=S='(@(D[Z;65R;W,@<F]M86YO<R!E;B!M87GZ<V,N(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$S(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,S@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,0IM<V=I9"`B
M57)U9W5A>2(*;7-G<W1R(")5<G5G=6%Y(@H*(SH@;&EB+TAO<F1E+U!R969S
M+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(E5S87(@86-T=6%L.B`E<R(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S
M92!34TPB"FUS9W-T<B`B57-A<B!34TPB"@HC.B!C;VYF:6<O+F)A:R]P<F5F
M<RYP:'`N9&ES=#HQ,C<*;7-G:60@(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES
M(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM<V=S='(@(E-E('5S82!S
M:2!E;"!U<W5A<FEO+V-O;G1R87-E\6$@<V]N(&1I<W1I;G1O<R!E;B!E;"!S
M97)V:61O<B!)35-0+B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I
M="YI;F,Z,C$*;7-G:60@(E5S97(B"FUS9W-T<B`B57-U87)I;R(*"B,Z(&QI
M8B](;W)D92]296=I<W1R>2YP:'`Z-S<T"B,L('!H<"UF;W)M870*;7-G:60@
M(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+B(*;7-G<W1R(")%
M;"!U<W5A<FEO("5S(&-A<F5C92!D92!A=71O<FEZ86-I\VX@<&%R82`E<RXB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S97(@061M:6YI<W1R
M871I;VXB"FUS9W-T<B`B061M:6YI<W1R86-I\VX@9&4@=7-U87)I;W,B"@HC
M.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C(T-0IM<V=I9"`B57-E<B!/<'1I
M;VYS(@IM<V=S='(@(D]P8VEO;F5S(&1E('5S=6%R:6\B"@HC.B!S:6=N=7`N
M<&AP.C8R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R(")296=I
M<W1R;R!D92!U<W5A<FEO<R(*"B,Z('-I9VYU<"YP:'`Z,C(*;7-G:60@(E5S
M97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I
M=&4N(@IM<V=S='(@(D5S=&$@<V5D92!T:65N92!D97-A8W1I=F%D;R!E;"!R
M96=I<W1R;R!D92!U<W5A<FEO<RXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-#DT"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@
M(DYO('-E(&AA(&5N8V]N=')A9&\@;&$@:61E;G1I9&%D(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W.`HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y."!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE
M:71A;'E?<VUT<"YP:'`Z.3@@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$U
M,`HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,R!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C<R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G<W1R(")5<W5A<FEO
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HQ,C0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*
M;7-G<W1R(")982!E>&ES=&4@96P@;F]M8G)E(&1E('5S=6%R:6\@7"(E<UPB
M+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PIM<V=I9"`B
M57-E<FYA;64Z(@IM<V=S='(@(E5S=6%R:6\Z(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VUO8FEL92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R(")5
M<W5A<FEO.B`B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR
M"FUS9VED(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R(")5<W5A<FEO
M<R!E;B!E;"!S:7-T96UA.B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR-#(*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T
M<B`B57IB96MI<W3A;B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3<P(&QI8B]6
M1E,O9FEL92YP:'`Z,C8X"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T
M(&5X:7-T+B(*;7-G<W1R(").;R!E>&ES=&4@96P@9&ER96-T;W)I;R!61E,N
M(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z,3(P"FUS9VED
M(")686-A=&EO;B(*;7-G<W1R(")!=7-E;F-I82(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HX-C8*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L
M=61E.B`B"FUS9W-T<B`B3&%S('5B:6-A8VEO;F5S(';A;&ED87,@96YC;VYT
M<F%D87,@:6YC;'5Y96XZ("(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-C,Y"FUS9VED(")686QI9&ET>2(*;7-G<W1R(")686QI9&5Z(@H*(SH@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PIM<V=I9"`B5F%L=64@:6X@;6EN
M=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B5F%L;W(@96X@;6EN=71O<R!A('!A
M<G1I<B!D92!A:&]R82XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#4V(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,3<W"B,L('!H<"UF;W)M870*;7-G:60@(E9A
M;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R
M(")%;"!V86QO<B!E>&-E9&4@96P@=&%M8?%O(&WA>&EM;R!D92`E<RXB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(T-"!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C(V-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,Q-@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,CDQ,"!L:6(O2&]R9&4O1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU
M.0IM<V=I9"`B5F%L=65S(@IM<V=S='(@(E9A;&]R97,B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C$P.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$X-@IM<V=I
M9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(E9A;&]R97,@82!S
M96QE8V-I;VYA<B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR-#D*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B5F%N=6%T
M=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S,*;7-G:60@
M(E9A<FEA8FQE(@IM<V=S='(@(E9A<FEA8FQE(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M-#$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-0IM<V=I9"`B5F5N97IU
M96QA(@IM<V=S='(@(E9E;F5Z=65L82(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z,C$X"FUS9VED(")697)I9FEC871I;VX@9F%I;&5D("T@=&AI
M<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"XB"FUS9W-T
M<B`B2&$@9F%L;&%D;R!L82!C;VUP<F]B86-I\VX@+2!E<W1E(&UE;G-A:F4@
M<'5E9&4@:&%B97)S92!F;W)Z861O+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-S`Q"FUS9VED(")697)S:6]N(@IM<V=S='(@(E9E<G-I\VXB
M"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HR,C@*;7-G:60@
M(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R(")#+B!V97)S:6]N97,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S
M"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G<W1R(")!;&EN96%C:?-N('9E
M<G1I8V%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*;7-G<W1R(")-87)G
M96X@=F5R=&EC86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`B5F5R=&EC
M86PZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-S(*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R(")-=7D@86QT82(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#@*;7-G
M:60@(E9I970@3F%M(@IM<V=S='(@(E9I971N86TB"@HC.B!C;VYF:6<O+F)A
M:R]N;',N<&AP+F1I<W0Z,3DW"FUS9VED(")6:65T;F%M97-E("A625-#24DI
M(@IM<V=S='(@(E9I971N86UI=&$@*%9)4T-)22DB"@HC.B!L:6(O2&]R9&4O
M34E-12]#;VYT96YT<RYP:'`Z.3<Q"B,L('!H<"UF;W)M870*;7-G:60@(E9I
M97<@)7,B"FUS9W-T<B`B5F5R("5S(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP
M:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*;7-G<W1R
M(")697(@=6YA('#A9VEN82!W96(@97AT97)N82(*"B,Z(&QI8B](;W)D92]-
M24U%+T-O;G1E;G1S+G!H<#HX,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE
M=R!A<R`E<R(*;7-G<W1R(")697(@8V]M;R`E<R(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#8*;7-G:60@(E9I<F=I
M;B!)<VQA;F1S+"!"<FET:7-H(@IM<V=S='(@(DES;&%S(%;M<F=E;F5S+"!"
M<FETX6YI8V%S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(T-PIM<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB"FUS
M9W-T<B`B27-L87,@5NUR9V5N97,L(%4N4RXB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(Q-@IM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R(")6:7-I8FEL
M:61A9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3(*;7-G
M:60@(E9I<VEB:6QI='DZ("(*;7-G<W1R(")6:7-I8FEL:61A9#H@(@H*(SH@
M;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-`IM<V=I9"`B
M5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B5F]D869O;F4@9&4@
M271A;&EA(&UE9&EA;G1E(%--5%`B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T
M<B`B059)4T\B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")705).24Y'(2$A(%)%34]612!30U))4%0@34%.
M54%,3%D@1E)/32`E<RXB"FUS9W-T<B`BH:&A041615)414Y#24$A(2$@14Q)
M34E.12!-04Y504Q-14Y412!%3"!'54G33B!$12`E<RXB"@HC.B!L:6(O3F5T
M+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS9VED(")724X@=FEA($A45%`B"FUS
M9W-T<B`B5TE.('!O<B!(5%10(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(U,`IM<V=I9"`B5V%L;&ES(&%N9"!&=71U
M;F$B"FUS9W-T<B`B5V%L;&ES('D@1G5T=6YA(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.CDU(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O
M<W1A='5S+G!H<#HR.0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:'1M;"YP
M:'`Z,3(W"FUS9VED(")787)N:6YG(@IM<V=S='(@(D%D=F5R=&5N8VEA(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM
M<V=I9"`B5V4B"FUS9W-T<B`B36EE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM<V=S='(@
M(E!R979I<VGS;B!D96P@=&EE;7!O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C0Q-@IM<V=I9"`B5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y
M(@IM<V=S='(@(D1A=&]S(&1E;"!T:65M<&\@<W5M:6YI<W1R861O<R!P;W(B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DR"FUS9VED(")796%T:&5R+F-O
M;2(*;7-G<W1R(")796%T:&5R+F-O;2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N
M<&AP.C,V"FUS9VED(")796(B"FUS9W-T<B`B5V5B(@H*(SH@8V]N9FEG+RYB
M86LO<F5G:7-T<GDN<&AP+F1I<W0Z-#,Y"FUS9VED(")796(@4VET92(*;7-G
M<W1R(")3961E(%=E8B(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z
M-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R(")396UA;F%L;65N=&4B"@HC.B!S
M97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`IM<V=I9"`B5V5L8V]M92(*
M;7-G<W1R(")":65N=F5N:61O(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHU-R!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT"B,L('!H<"UF
M;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B0FEE;G9E;FED
M;W,@82`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E
M;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")796QC;VUE+"`E<R(*;7-G<W1R(")":65N=F5N:61O+"`E<R(*"B,Z(&-O
M;F9I9R\N8F%K+VYL<RYP:'`N9&ES=#HQ.3@*;7-G:60@(E=E<W1E<FX@*$E3
M3RTX.#4Y+3$I(@IM<V=S='(@(D]E<W1E("A)4T\M.#@U.2TQ*2(*"B,Z(&-O
M;F9I9R\N8F%K+VYL<RYP:'`N9&ES=#HQ.3D*;7-G:60@(E=E<W1E<FX@*$E3
M3RTX.#4Y+3$U*2(*;7-G<W1R(")/97-T92`H25-/+3@X-3DM,34I(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(T-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S@*;7-G
M:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(E/A:&%R82!/8V-I9&5N=&%L
M(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z-#0Q"B,L('!H<"UF
M;W)M870*;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L
M87D@869T97(@;&]G:6X_(@IM<V=S='(@(K]1=>D@87!L:6-A8VGS;B!D96)E
M<NUA(&UO<W1R87(@)7,@86P@:6YI8VEA<B!L82!S97-I\VX_(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,30*;7-G:60@(E=H870@:7,@=&AE
M(&1E;&EM:71E<B!C:&%R86-T97(_(@IM<V=S='(@(K]#=>%L(&5S(&5L(&-A
M<N%C=&5R(&1E;&EM:71A9&]R/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC.C$W"FUS9VED(")7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_
M(@IM<V=S='(@(K]#=>%L(&5S(&5L(&-A<N%C=&5R(&1E(&-I=&%D;S\B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V-0IM<V=I
M9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S='(@(DUA<&$@9&4@;&]C
M86QI>F%C:?-N(&1E($%U<W1R86QI82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(E%UZ2!F87-E<R(*
M"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$S-@IM<V=I9"`B5VAI
M8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R
M+B(*;7-G<W1R(")0;'5G:6YS(&AA8FEL:71A9&]S(&1E;"!E9&ET;W(@9&4@
M=&5X=&\@96YR:7%U96-I9&\N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T
M<B`B06YC:'5R82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3`W"FUS9VED
M(")7:61T:"!I;B!#4U,@=6YI=',B"FUS9W-T<B`B06YC:'5R82!E;B!U;FED
M861E<R!#4U,B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HS-C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@
M=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S
M='(@(D%N8VAU<F$@9&5L(&UE;OH@)7,@:7IQ=6EE<F1O("AD:7-P;VYI8FQE
M(&5N(&QA('!R\WAI;6$@<V5S:?-N*3HB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE
M('1A8FQE(@IM<V=S='(@(D%N8VAU<F$@9&4@;&$@=&%B;&$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`IM<V=I9"`B
M5VED=&@@=6YI="(*;7-G<W1R(")5;FED861E<R!D92!A;F-H=7)A(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G
M:60@(E=I9'1H.B(*;7-G<W1R(")!;F-H=7)A.B(*"B,Z(&-O;F9I9R\N8F%K
M+W)E9VES=')Y+G!H<"YD:7-T.C4Q-0IM<V=I9"`B5VEK:2(*;7-G<W1R(")7
M:6MI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X.2!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I9"`B5VEN
M9"(*;7-G<W1R(")6:65N=&\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B5VEN9"!%87)L>2(*;7-G<W1R(")6
M:65N=&\@;6%T=71I;F$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@W"FUS
M9VED(")7:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@(E9E;&]C:61A9"!D
M96P@=FEE;G1O(&5N(&YU9&]S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M-C,*;7-G:60@(E=I;F0Z(@IM<V=S='(@(E9I96YT;SHB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS9VED(")7:6YD.B`B"FUS9W-T
M<B`B5FEE;G1O.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G
M:60@(E=I<V1O;2(*;7-G<W1R(")386)I9'5R[6$B"@HC.B!C;VYF:6<O+F)A
M:R]R96=I<W1R>2YP:'`N9&ES=#HQ.3@*;7-G:60@(E=I<VAL:7-T(@IM<V=S
M='(@(D1E<V5O<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I
M9"`B5V]R:R(*;7-G<W1R(")%;7!L96\B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$R-"!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$V-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(D1I<F5C
M8VGS;B!D96P@=')A8F%J;R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(E1E;.EF
M;VYO(&1E;"!T<F%B86IO(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HQ.3,@;&EB
M+T9I;&4O0U-6+G!H<#HR.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@
M;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U
M;F0@)60N(@IM<V=S='(@(D[Z;65R;R!E<G+S;F5O(&1E(&-A;7!O<R!E;B!L
M82!L[6YE82`E9"X@4V4@97-P97)A8F%N("5D('D@:&%Y("5D+B(*"B,Z(&QI
M8B]&:6QE+T-35BYP:'`Z,S,R"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG
M(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS
M9W-T<B`B3OIM97)O(&5R<O-N96\@9&4@8V%M<&]S+B!392!E<W!E<F%B86X@
M)60@>2!H87D@)60N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ,C$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@
M82!61E,@9FEL92XB"FUS9W-T<B`B3V9F<V5T("5D(&5R<O-N96\@86P@;&5E
M<B!U;B!A<F-H:79O(%9&4RXB"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP
M:'`N9&ES=#HR-#4*;7-G:60@(E@M4F5F(@IM<V=S='(@(E@M4F5F(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!"
M87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R("),:6UI=&%C:6]N97,@8N%S:6-A
M<R!8-3`Y=C,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM
M<V=I9"`B6#4P.78S($5X=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R(")5<V\@
M9&4@8VQA=F4@97AT96YD:61A(%@U,#EV,R(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA
M=&EV92!.86UE(@IM<V=S='(@(DYO;6)R92!A;'1E<FYA=&EV;R!D92!A<W5N
M=&\@6#4P.78S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.38*
M;7-G:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@
M(DED96YT:69I8V%D;W(@9&4@8VQA=F4@9&4@87-U;G1O(%@U,#EV,R(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C@S"FUS9VED(")8-3`Y=C,@
M97AT96YS:6]N<R(*;7-G<W1R(")%>'1E;G-I;VYE<R!8-3`Y=C,B"@HC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T<B`B04$B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$T(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-38*;7-G:60@(EE965DB
M"FUS9W-T<B`B04%!02(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,3$Q"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@(J%-87!A
M(&1E(%EA:&]O(2(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z-38*
M;7-G:60@(EEE87)L>2(*;7-G<W1R(")!;G5A;&UE;G1E(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR-#<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,@IM<V=I9"`B
M665M96XB"FUS9W-T<B`B665M96XB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.38V"FUS9VED(")997,B"FUS9W-T<B`B4^TB"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM
M<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(E/M+"!L;R!A8V5P=&\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R"FUS
M9VED(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T
M;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`B(@HB17-T
MX2!E;B!-3T1/(%1%6%1/+B!5=&EL:6-E(&5L(&)O=/-N(%L\/ET@<&%R82!R
M96=R97-A<B!A;"!M;V1O(%=94TE764<N(@H*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HR,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L
M;V-K<RXB"FUS9W-T<B`B3F\@9&ES<&]N92!D92!P<FEV:6QE9VEO<R!P87)A
M(&-R96%R(&WA<R!D92`E9"!B;&]Q=65S+B(*"B,Z(&QI8B](;W)D92YP:'`Z
M,30R-`IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC871E9"XB"FUS9W-T
M<B`B3F\@97-TX2!A=71E;G1I9FEC861O+B(*"B,Z(&QI8B](;W)D92])9&5N
M=&ET>2YP:'`Z,S`X"FUS9VED(")9;W4@8V%N;F]T(&AA=F4@=&AE("=<7"<@
M8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*;7-G<W1R(").;R!P=65D
M92!I;F-L=6ER(&5L(&-A<N%C=&5R(%PB7%Q<(B!E;B!E;"!N;VUB<F4@8V]M
M<&QE=&\N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-34@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$Y-S4*;7-G:60@(EEO=2!D:60@;F]T(&5N=&5R(&$@=F%L
M:60@96UA:6P@861D<F5S<RXB"FUS9W-T<B`B3F\@:6YT<F]D=6IO('5N82!D
M:7)E8V-I\VX@9&4@8V]R<F5O(';A;&ED82XB"@HC.B!L:6(O2&]R9&4O1&%T
M82YP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N)W0@
M;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@
M8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*(DYO
M(&%S;V-I\R!N:6YG=6YO(&1E(&QO<R!C86UP;W,@9&5L(&%R8VAI=F\@:6UP
M;W)T861O(&$@;&]S(&-A;7!O<R`B"B)C;W)R97-P;VYD:65N=&5S(&1E("5S
M+B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY.#<*;7-G:60@(EEO=2!H879E
M(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`B2&$@<V%L:61O(&1E(&QA('-E
M<VGS;BXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(V,0IM<V=I9"`B(@HB
M66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D
M:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F;W(@=&AE(&EN
M=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@(B(*(E1I96YE
M('%U92!I;G1R;V1U8VER('5N(&[Z;65R;R!D92!T96SI9F]N;R!M\W9I;"!V
MX6QI9&\L('/S;&\@9.UG:71O<R!C;VX@=6X@(@HB)RLG(&]P8VEO;F%L('!A
M<F$@96P@<')E9FEJ;R!D92!L;&%M861A(&EN=&5R;F%C:6]N86PN(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$Q.#@*;7-G:60@(EEO=2!H879E('1O(&5N
M=&5R(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(E1I96YE('%U92!I;G1R;V1U
M8VER('5N('9A;&]R(';A;&ED;RXB"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N
M=7`N<&AP.C,W"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E
M92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R(")087)A('5S87(@
M06QT87,@=&EE;F4@<75E(&-O;F9I9W5R87(@=6X@;6]T;W(@9&4@1&%T851R
M964N(@H*(SH@;&EB+TAO<F1E+G!H<#HT-S$*;7-G:60@(EEO=2!M=7-T(&-O
M;F9I9W5R92!A(%9&4R!B86-K96YD+B(*;7-G<W1R(")4:65N92!Q=64@8V]N
M9FEG=7)A<B!U;B!M;W1O<B!61E,N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P
M<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T
M+B(*;7-G<W1R(")$96)E(&1E<V-R:6)I<B!E;"!P<F]B;&5M82!A;G1E<R!D
M92!E;G9I87(@96P@:6YF;W)M92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E<B!T
M:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`B5&EE
M;F4@<75E(&EN=')O9'5C:7(@;&$@55),(&$@;&$@<75E(&%P=6YT82!E<W1E
M(';M;F-U;&\B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`IM
M<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D
M+B(*;7-G<W1R(")4:65N92!Q=64@<V5L96-C:6]N87(@=6X@<V5R=FED;W(@
M82!E;&EM:6YA<BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*;7-G:60@(EEO
M=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S
M='(@(E1I96YE('%U92!E<W!E8VEF:6-A<B!U;B!U<W5A<FEO(&$@96QI;6EN
M87(N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@;75S="!S
M<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R(")4:65N92!Q
M=64@97-P96-I9FEC87(@=6X@=7-U87)I;R!A(&5L:6UI;F%R+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C8R('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@
M861D+B(*;7-G<W1R(")4:65N92!Q=64@97-P96-I9FEC87(@96P@=7-U87)I
M;R!A(&'Q861I<BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#8*;7-G:60@(EEO
M=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T
M<B`B5&EE;F4@<75E(&5S<&5C:69I8V%R(&5L('5S=6%R:6\@82!A8W1U86QI
M>F%R+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C$S.`IM<V=I
M9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*
M;7-G<W1R(")4:65N92!Q=64@97-P96-I9FEC87(@<77I(&%C8VGS;B!S92!E
M:F5C=71A<N$N(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E
M<BYP:'`Z-S$*;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@
M;F%M92XB"FUS9W-T<B`B5&EE;F4@<75E(&EN=')O9'5C:7(@=6X@;G5E=F\@
M;F]M8G)E(&1E(&-A=&5G;W+M82XB"@HC.B!L:6(O3F5T+U--4R]V;V1A9F]N
M96ET86QY7W-M='`N<&AP.C<S"FUS9VED(")9;W4@;F5E9"!T;R!P<F]V:61E
M(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(@IM<V=S='(@(E1I96YE('%U92!I
M;G1R;V1U8VER('5N(&[Z;65R;R!D92!T96SI9F]N;R!I=&%L:6%N;R(*"B,Z
M(&QI8B](;W)D92]!=71H+G!H<#HY-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A
M:6XN(@IM<V=S='(@(DAA(&5X<&ER861O('-U('-E<VGS;B`E<RX@5G5E;'9A
M(&$@:6YI8VEA<B!S97-I\VXN(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z,S@*;7-G:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R
M(")3=2!D:7)E8V-I\VX@9&4@8V]R<F5O(@H*(SH@8V]N9FEG+RYB86LO<')E
M9G,N<&AP+F1I<W0Z,C$U"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM
M<V=S='(@(D1I<F5C8VGS;B!$93HB"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP
M:'`N9&ES=#HV-R!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HW-PHC.B!C
M;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HX-2!C;VYF:6<O+F)A:R]P<F5F
M<RYP:'`N9&ES=#HY,@IM<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R
M(")3=2!I;F9O<FUA8VGS;B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY-SD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R97-S
M(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S
M97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T
M(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B)(82!C86UB:6%D;R!S=2!D:7)E
M8V-I\VX@9&4@26YT97)N970@9&5S9&4@96P@8V]M:65N>F\@9&4@<W4@<V5S
M:?-N("5S+B!0;W(@(@HB<F%Z;VYE<R!D92!S96=U<FED860@=&EE;F4@<75E
M('9O;'9E<B!A(&EN:6-I87(@;&$@<V5S:?-N+B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED(")9;W5R($YA;64B"FUS9W-T
M<B`B4W4@;F]M8G)E(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N
M:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D
M;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@
M(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U
M(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N(&)A8VME
M;F0N(@IM<V=S='(@(B(*(E-U(&UO=&]R(&1E(&%U=&5N=&EF:6-A8VGS;B!N
M;R!P97)M:71E(&'Q861I<B!U<W5A<FEO<RX@4VD@<75I<VEE<F$@=7-A<B`B
M"B)(;W)D92!P87)A(&%D;6EN:7-T<F%R(&-U96YT87,@9&4@=7-U87)I;RP@
M=&5N9'+A('%U92!U=&EL:7IA<B!U;B!M;W1O<B!D92`B"B)A=71E;G1I9FEC
M86-I\VX@9&ES=&EN=&\N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L
M:7-T+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME
M;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A
M='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S
M;VXN(@IM<V=S='(@(B(*(E-U(&UO=&]R(&1E(&%U=&5N=&EF:6-A8VGS;B!N
M;R!P97)M:71E(&QI<W1A<B!U<W5A<FEO<RP@;R!S92!H82`B"B)D97-H86)I
M;&ET861O(&QA(&-A<F%C=&5R[7-T:6-A('!O<B!A;&?Z;B!M;W1I=F\N(@H*
M(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDX,PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN
M8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R
M;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM
M<V=S='(@(B(*(E!A<F5C92!Q=64@:&$@8V%M8FEA9&\@<W4@;F%V96=A9&]R
M(&1E<V1E(&5L(&-O;6EE;GIO(&1E('-U('-E<VGS;B`E<RX@4&]R("(*(G)A
M>F]N97,@9&4@<V5G=7)I9&%D('1I96YE('%U92!V;VQV97(@82!I;FEC:6%R
M(&QA('-E<VGS;BXB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU-PIM<V=I
M9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E
M+B(*;7-G<W1R(")3=2!N879E9V%D;W(@;F\@861M:71E(&5S=&$@8V%R86-T
M97+M<W1I8V$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z
M-#(*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H
M:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*
M(G1O('!R:6YT+B(*;7-G<W1R("(B"B)%;"!N879E9V%D;W(@;F\@861M:71E
M(&5S=&$@;W!C:?-N(&1E(&EM<')E<VGS;BX@4')E<VEO;F4@0V]N=')O;"]#
M;VUA;F1O("L@(@HB4"!P87)A(&EM<')I;6ER+B(*"B,Z(&-O;F9I9R\N8F%K
M+W!R969S+G!H<"YD:7-T.C(V,0IM<V=I9"`B66]U<B!C=7)R96YT('1I;64@
M>F]N93HB"FUS9W-T<B`B6F]N82!H;W)A<FEA(&%C='5A;#HB"@HC.B!S97)V
M:6-E<R]P<F5F<RYP:'`Z,3$W"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I
M='D@:&%S(&)E96X@8VAA;F=E9"XB"FUS9W-T<B`B4V4@:&$@8V%M8FEA9&\@
M<W4@:61E;G1I9&%D('!O<B!O;6ES:?-N+B(*"B,Z(&-O;F9I9R\N8F%K+W!R
M969S+G!H<"YD:7-T.C$V,0IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y
M.B(*;7-G<W1R("))9&5N=&ED860@<&]R(&]M:7-I\VXZ(@H*(SH@8V]N9FEG
M+RYB86LO<')E9G,N<&AP+F1I<W0Z,C`T"FUS9VED(")9;W5R(&9U;&P@;F%M
M93HB"FUS9W-T<B`B3F]M8G)E(&-O;7!L971O.B(*"B,Z(&QI8B](;W)D92]!
M=71H+G!H<#HY.3D*;7-G:60@(EEO=7(@;&]G:6X@:&%S(&5X<&ER960N(@IM
M<V=S='(@(E-E(&AA(&%G;W1A9&\@<W4@=&EE;7!O(&1E(&-O;F5X:?-N+B(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M
M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS
M9W-T<B`B3&$@;G5E=F$@8V]N=')A<V7Q82!P87)A("5S(&5S.B`E<R(*"B,Z
M(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO
M;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES
M('-E<W-I;VXN(@IM<V=S='(@(E-E(&AA;B!A8W1U86QI>F%D;R!S=7,@;W!C
M:6]N97,@<_-L;R!P;W(@;&$@9'5R86-I\VX@9&4@;&$@<V5S:?-N+B(*"B,Z
M(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,34V"FUS9VED(")9;W5R(&]P=&EO
M;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S='(@(E-E(&AA;B!A8W1U86QI
M>F%D;R!S=7,@;W!C:6]N97,N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B
M"FUS9W-T<B`B4V4@:&$@<F5A:G5S=&%D;R!S=2!C;VYT<F%S9?%A(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*(EEO=7(@
M<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD
M(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G<W1R("(B
M"B)392!H82!R96%J=7-T861O('-U(&-O;G1R87-E\6$L(&-O;7!R=65B92!E
M;"!C;W)R96\@92!I;FEC:64@<V5S:?-N(&-O;B!S=2`B"B)N=65V82!C;VYT
M<F%S9?%A+B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HW,S,*;7-G:60@(EEO
M=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S='(@(DQA(&-O;G1R87-E
M\6$@:&$@97AP:7)A9&\N(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C4X"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R(")3
M97)V:61O<F5S(')E;6]T;W,Z(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$X(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-30*;7-G:60@(EEU9V]S
M;&%V:6$B"FUS9W-T<B`B675G;W-L879I82(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B6F%I<F4B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(T.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4V
M"FUS9VED("):86UB:6$B"FUS9W-T<B`B6F%M8FEA(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR-#D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-PIM<V=I9"`B6FEM
M8F%B=V4B"FUS9W-T<B`B6FEM8F%B=V4B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-C8*;7-G:60@(EII<'!Y(@IM<V=S='(@(EII<'!Y(@H*(SH@;&EB
M+TAO<F1E+U1E>'0O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED
M(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T<B`B6T]C=6QT87(@=&5X=&\@
M8VET861O72(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C@Y"FUS9VED(");
M4')O8FQE;2!297!O<G1=(@IM<V=S='(@(EM);F9O<FUE(&1E('!R;V)L96UA
M72(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S
M"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M(@IM<V=S='(@(EM-;W-T<F%R
M('1E>'1O(&-I=&%D;R`M(@H*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VAI
M9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,L('!H<"UF;W)M870*;7-G:60@(EM3
M:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM<V=S='(@(EM-;W-T<F%R
M('1E>'1O(&-I=&%D;R`M("5S(&SM;F5A<UTB"@HC.B!L:6(O2&]R9&4N<&AP
M.C(P-`HC+"!P:'`M9F]R;6%T"FUS9VED(");;&EN92`E<R!O9B`E<UTB"FUS
M9W-T<B`B6VSM;F5A("5S(&1E("5S72(*"B,Z(&QI8B](;W)D92YP:'`Z,34U
M-"!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q"FUS9VED(")?061M:6YI
M<W1R871I;VXB"FUS9W-T<B`B7T%D;6EN:7-T<F%C:?-N(@H*(SH@;&EB+V%P
M:2YP:'`Z,34W"FUS9VED(")?0TQ)(@IM<V=S='(@(E]#3$DB"@HC.B!L:6(O
M87!I+G!H<#HQ-#$*;7-G:60@(E]$871A5')E92(*;7-G<W1R("+!<E]B;VP@
M9&%T;W,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S$*;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(D5?
M;&EM:6YA<B!F:6QA(@H*(SH@;&EB+V%P:2YP:'`Z,3,S"FUS9VED(")?1W)O
M=7!S(@IM<V=S='(@(E]'<G5P;W,B"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z
M,3<U"FUS9VED(")?2&5L<"(*;7-G<W1R(")!7WEU9&$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G
M:60@(E]);6%G92!0<F]P97)T:65S+BXN(@IM<V=S='(@(E!R;W!I961A9&5S
M(&1E(%]I;6%G96XN+BXB"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,3DT"FUS
M9VED(")?3&]G(&EN(@IM<V=S='(@(E]);FEC:6%R('-E<VGS;B(*"B,Z(&QI
M8B](;W)D92]-96YU+G!H<#HQ.3`*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@
M(E]386QI<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S
M='(@(DUO9&EF:6-A<B!?=NUN8W5L;RXN+B(*"B,Z(&QI8B](;W)D92]-96YU
M+G!H<#HQ-C0*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(E]/<&-I;VYE<R(*
M"B,Z(&QI8B]A<&DN<&AP.C$S-PIM<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S
M='(@(E]0<FEV:6QE9VEO<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@IM<V=I9"`B7U)E;6]V92!,:6YK
M+BXN(@IM<V=S='(@(E]%;&EM:6YA<B!V[6YC=6QO+BXN(@H*(SH@;&EB+V%P
M:2YP:'`Z,3(U"FUS9VED(")?4V5T=7`B"FUS9W-T<B`B0V]N7V9I9W5R86,N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,S"FUS9VED(")?5&%B;&4@4')O<&5R=&EE<RXN+B(*;7-G<W1R
M(")0<F]P:65D861E<R!D92!?=&%B;&$N+BXB"@HC.B!L:6(O87!I+G!H<#HQ
M,CD*;7-G:60@(E]5<V5R<R(*;7-G<W1R(")?57-U87)I;W,B"@HC.B!L:6(O
M2&]R9&4O2V]L86(N<&AP.CDR-0IM<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S
M='(@(F1I<F5C8VEO;F5S(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP
M:'`Z,3,T"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R(")D97-T
M:6YA=&%R:6\@9&5S8V]N;V-I9&\B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.CDQ-PIM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B86=E;F1A(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ-SD@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R(")C86QM82(*"B,Z
M(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N;F]T
M(&-R96%T92!O=71P=70@9FEL92(*;7-G<W1R(")N;R!S92!P=65D92!C<F5A
M<B!E;"!A<F-H:79O(&1E(&1E<W1I;F\B"@HC.B!L:6(O2&]R9&4O34E-12]-
M97-S86=E+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S
M='(@(FYO('-E('!U961E(&%B<FER(&5L(&]R:6=E;B(*"B,Z(&QI8B](;W)D
M92]-24U%+T-O;G1E;G1S+G!H<#HV,#`*;7-G:60@(F-L:6-K(&AE<F4B"FUS
M9W-T<B`B<'5L<V4@87%U[2(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N
M<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S
M='(@(F5R<F]R(&1E(&SM;F5A(&1E(&-O;6%N9&\B"@HC.B!L:6(O2&]R9&4O
M34E-12]-97-S86=E+G!H<#HQ-S@*;7-G:60@(F-O;F9I9W5R871I;VX@97)R
M;W(B"FUS9W-T<B`B97)R;W(@9&4@8V]N9FEG=7)A8VGS;B(*"B,Z(&QI8B](
M;W)D92]-24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC86P@<WES
M=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R(")F86QT82!U;B!A<F-H:79O(&-R
M[71I8V\@9&5L('-I<W1E;6$B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E
M+G!H<#HQ,C8*;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(F5R
M<F]R(&1E(&9O<FUA=&\@9&4@9&%T;W,B"@HC.B!T96UP;&%T97,O<&]R=&%L
M+V5D:70N:6YC.C,P"FUS9VED(")E9&ET(@IM<V=S='(@(FUO9&EF:6-A<B(*
M"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$X,@IM<V=I9"`B96YT
M<GD@;F]T(&9O=6YD(@IM<V=S='(@(F5N=')A9&$@;F\@96YC;VYT<F%D82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"FUS
M9VED(")F86QL:6YG(@IM<V=S='(@(F1E<V-E;G-O(@H*(SH@;&EB+TAO<F1E
M+T)R;W=S97(N<&AP.C@Y-@IM<V=I9"`B9FEL92(*;7-G<W1R(")A<F-H:79O
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#$@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS-C<@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R(")D
M96P@)7,@*"5S*2!A(&QA<R`E<R`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,SD*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B=F5N=&]S
M;R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR-3`*
M;7-G:60@(F@Z(@IM<V=S='(@(F@Z(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C,U.0IM<V=I9"`B:&@B"FUS9W-T<B`B:&@B"@HC
M.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@
M;F%M92!U;FMN;W=N(@IM<V=S='(@(FYO;6)R92!D92!A;F9I=')I\VX@9&5S
M8V]N;V-I9&\B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(R,R!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"FUS9VED
M(")I;6UE9&EA=&4B"FUS9W-T<B`B:6YM961I871A;65N=&4B"@HC.B!A9&UI
M;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM
M<V=I9"`B:6YL:6YE(@IM<V=S='(@(F5N(&SM;F5A(@H*(SH@;&EB+TAO<F1E
M+TU)344O365S<V%G92YP:'`Z,38R"FUS9VED(")I;G!U="]O=71P=70@97)R
M;W(B"FUS9W-T<B`B97)R;W(@9&4@96YT<F%D82]S86QI9&$B"@HC.B!L:6(O
M2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN=&5R;F%L('-O
M9G1W87)E(&5R<F]R(@IM<V=S='(@(F5R<F]R(&1E('-O9G1W87)E(&EN=&5R
M;F\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ
M,PIM<V=I9"`B;&EN97-=(@IM<V=S='(@(FSM;F5A<UTB"@HC.B!L:6(O5D93
M+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB"FUS
M9W-T<B`B8_-D:6=O(&1E(&5R<F]R(&UK:7-O9G,@)60@86P@<F5A;&EZ87(@
M25-/+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS
M-S`*;7-G:60@(FUM(@IM<V=S='(@(FUM(@H*(SH@;&EB+TAO<F1E+U!R969S
M+U5)+G!H<#HR.#4@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W-`HC
M.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C0S"FUS9VED(")N86UE
M(@IM<V=S='(@(FYO;6)R92(*"B,Z(&QI8B](;W)D92]24$,N<&AP.C$R-`IM
M<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(G-I;B!D97-A<G)O;&QA
M<B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(R,`IM<V=I9"`B
M;F]T('EE="!I;7!L96UE;G1E9"(*;7-G<W1R(")A^FX@;F\@<V4@:&$@9&5S
M87)R;VQL861O(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,#D*;7-G:60@
M(FYO=&5P860B"FUS9W-T<B`B;F]T87,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED(")P97)C96YT
M(@IM<V=S='(@(G!O<F-E;G1A:F4B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S
M86=E+G!H<#HQ-S0*;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@
M(G!R:79I;&5G:6\@9&5N96=A9&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS
M9W-T<B`B<.UX96QE<R(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP
M.C$W,`IM<V=I9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@
M(F5R<F]R(')E;6]T;R!D92!P<F]T;V-O;&\B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW-0IM<V=I9"`B<FES:6YG(@IM<V=S
M='(@(F5N(&%U;65N=&\B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H
M<#HQ-#(*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B<V5R
M=FEC:6\@;F\@9&ES<&]N:6)L92XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C$P,0IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R(")M;W-T
M<F%R(&1I9F5R96YC:6%S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@
M(G-M<S)E;6%I;"!P;W(@2%144"(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HS.#<*;7-G:60@(G-S(@IM<V=S='(@(G-S(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S0*;7-G:60@
M(G-T96%D>2(*;7-G<W1R(")E<W1A8FQE(@H*(SH@;&EB+TAO<F1E+TU)344O
M365S<V%G92YP:'`Z,34P"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`B
M97)R;W(@9&5L('-I<W1E;6$B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDS
M,PIM<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@(G1A<F5A<R(*"B,Z(&QI8B](
M;W)D92]-24U%+TUE<W-A9V4N<&AP.C$V-@IM<V=I9"`B=&5M<&]R87)Y(&9A
M:6QU<F4B"FUS9W-T<B`B9F%L;&\@=&5M<&]R86PB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HS-B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(W,`IM<V=I9"`B
M='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R(")E
M<V-R:6)A(&1O<R!V96-E<R!L82!C;VYT<F%S9?%A('!A<F$@8V]N9FER;6%R
M;&$B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D
M:69F+G!H<#HW.0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R(")U;FEF:6-A9&\B
M"@HC.B!L:6(O2&]R9&4O34E-12]087)T+G!H<#HR-PIM<V=I9"`B=6YN86UE
M9"(*;7-G<W1R(")S:6X@;F]M8G)E(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,C,@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4V-0IM<V=I9"`B=7-E<B!S96QE8W0B"FUS9W-T<B`B=7-U87)I;R!S
M96QE8V-I;VYA9&\B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR-#(*;7-G:60@(G<Z(@IM
M<V=S='(@(G<Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*
M;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(G=E871H97(N8V]M(@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O>FA?0TXN<&\`````
M````````````````````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M-C4Q-C<Q(#$P-3$U-#,S-S0R(#`Q-S4S-@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````C($AO<F1E(%-I;7!L:69I960@0VAI
M;F5S92!4<F%N<VQA=&EO;@HC($-O<'ER:6=H="`H0RD@,C`P,2!786YG2&5N
M9U=E;BX*(R!786YG2&5N9U=E;B`\=VAW0&UY,38Y+F-O;3XL(#(P,#$N"B,@
M1&%V:60@0VAA;F<@/&1A=FED0'1M=BYG;W8N='<^+"`R,#`Q+@HC(&QI86]B
M:6X@/&QI86]B:6Y`:FET92YN970^+#(P,#0N"B,@"FUS9VED("(B"FUS9W-T
M<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`R+C!<;B(*(E)E<&]R
M="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M
M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2
M979I<VEO;BU$871E.B`R,#`Q+3`V+3$X(#(R.C`U*S`X,#!<;B(*(DQA<W0M
M5')A;G-L871O<CH@;&EA;V)I;B`\;&EA;V)I;D!J:71E+FYE=#Y<;B(*(DQA
M;F=U86=E+51E86TZ($-H:6YE<V4@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/EQN
M(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P
M;&%I;CL@8VAA<G-E=#U'0C(S,3)<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC
M;V1I;F<Z(#@M8FET7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S8Y"B,L('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S
M='(@(B`H)7,@S.S'L"DB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$S-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM
M<V=S='(@(B`HO^R]W;S\("5S*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S-S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B`H:6X@)7,@
M9&%Y<RDB"FUS9W-T<B`B("@E<R#,[,>P*2(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(S-S,*;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(B`HO?',
M["DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<U"B,L(&9U>GIY
M"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("+#]\SL(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,0IM<V=I9"`B("AY97-T97)D87DI(@IM
M<V=S='(@(B`HU_+,["DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C4V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C$*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0P-PIM<V=I9"`B(&%T("(*;7-G
M<W1R("+3VB(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C$U"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER
M96-T;W)Y+B(*;7-G<W1R("*RN\K'TKNX]L2_PKPB"@HC.B!F<F%M97=O<FLO
M0TQ)+T-,22YP:'`Z,C<R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<
M(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R("(G)7,G(+*[
MRL?2N[CVT]#0I[7$T:'4\2XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M4F5G:7-T<GDN<&AP.C8U.0HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G
M:7-T<GDN<&AP.C$P-#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB
M)7-<(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN
M(@IM<V=S='(@(B<E<R<@R=#.M-3:($A/4D1%(+7$UZ*RX<[$O/XH4F5G:7-T
M<GDIUM#%Y-;#+B(*"B,Z(&9R86UE=V]R:R]4<F5E+U1R964N<&AP.C$W,0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R964@<F5N9&5R
M97(@;F]T(&9O=6YD+B(*;7-G<W1R("+5TK*[M;T@)7,N(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HU-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B
M)R5S)R#2T;/)N::\T\CKM;W3P[NGU^G/M<VSUM`N(@H*(SH@861M:6XO<&5R
M;7,O861D8VAI;&0N<&AP.C4R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN
M(@IM<V=S='(@(B<E<R<@TM&\T\CKR*C/WL^US;,N(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3`*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-R96%T960Z
M("5S+B(*;7-G<W1R("(G)7,G(+*BSK2]J,&B.B`E<RXB"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"
M('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S='(@(B5S(-+1
MR*'/^R`E<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C(V
M."!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-34W"B,L('!H<"UF;W)M870*;7-G
M:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@U"B,L
M('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R("+7
M[KW\("5D(,SLQOC/\]2DL:@B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP
M:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T
M<B`B)7,@+2"QN,W\PKPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C<P-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN
M="(*;7-G<W1R("(E<R#6N,[&(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z.#,S(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C@S-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(E
M<R!+0B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N
M9FER;6%T:6]N(@IM<V=S='(@(B5S(,ZLNZ2RV=?W("T@R+?(SR(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8S"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B)7,@UZ*RX2(*
M"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`B)7,@S:S2
MXL_NQ+\B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0R."!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y,`HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C8U,2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<Q.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T
M<B`B)7,@TM&TYM3:(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3D@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ-C4@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,SD*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#4@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T
M<B`B)7,@U-H@)7,@)7,B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M-#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y
M('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME
M9"!B96QO=RX@0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS
M*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B
MT:'4\<3ZS^O2JK+9U_>UQ,SUQ+\N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U:7)E
M9"(*;7-G<W1R("*QV-#HTJH@)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(X-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S='(@
M(B5S(+?6(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN
M<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM
M<V=S='(@(M72LKNUO2`E<RXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L
M:7-T+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S
M(@IM<V=S='(@(B`E<R"UO2`E<R"YLB`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z.3(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R("+-J-&VLKXB"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.CDQ-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R("+(U<#Z(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#8*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R("(E<R`M(+&XS?S"O"(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,P"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H
M<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B)7,Z
M("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z
M,C<R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@
M;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@
M;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I
M;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V
M-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#$P"B,L(&9U>GIY"FUS
M9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(BP@U?.WYR`E<R`E<R(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3@X(&QI8B]";&]C:R]M971A<BYP:'`Z,3DS
M"B,L('!H<"UF;W)M870*;7-G:60@(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R
M("(L(-7SM^<@)7,@)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P,0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B
M"FUS9W-T<B`B++'DNZ_!O[33("5S(+6]("5S(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HR.30@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HS-#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`V.2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3(X"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HW-#D*;7-G:60@(BTM('-E;&5C="`M+2(*
M;7-G<W1R("(M+2#1H=3Q("TM(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P
M"B,L(&9U>GIY"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R("+$^K7$
MT,7/HB(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ.0HC+"!F=7IZ>0IM<V=I
M9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T<B`BQ/JUQ-#%SZ(B"@HC.B!T96UP
M;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T
M<B`B,C0@T*'*L=;&(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HV
M.0HC+"!F=7IZ>0IM<V=I9"`B/%!R979I;W5S(@IM<V=S='(@(LG/TKO2LR(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED(")!(&1A=&%B87-E
M(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@
M(K3+Q_B_Z;'8T.O2JM:XMJC*_;[=O^*W_L[QMLLN(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ-C`*;7-G:60@(D$@9F%T86P@97)R;W(@:&%S
M(&]C8W5R<F5D(@IM<V=S='(@(K>BR?K!R]*[N/;1S];8M<2T[<[S(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U
M8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E
M+B(*;7-G<W1R("+3^[S3P]S3RKS^++NYT.C2JM/0TKNX]B!01U`@N:N_JL/<
MU+\N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V-0IM
M<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@
M82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`BT_O1Z=:DTM''J</[M<33RKS^
M++NYT.C2JM/0TKNX]B!01U`@N:N_JL/<U+\N(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3`Y-PIM<V=I9"`B(@HB02!P=6)L:6,@4$=0
M(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@(M/[O>+#
MW-/*O/XLN[G0Z-*JT]#2N[CVN:N_JB!01U`@P]S4ORS+O</<(%!'4"##W-2_
M+-+4O+"_VL'N+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$P,34*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B
M"B)M97-S86=E+B(*;7-G<W1R("+3^]:TT-#3RKS^QZG#^RR[N=#HTJK3T-*[
MN/:YJ[^J(%!'4"##W-2_+,N]P]P@4$=0(,/<U+\LTM2\L+_:P>XN(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,#4*;7-G:60@(B(*
M(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S
M86=E+B(*;7-G<W1R("+3^[WBP]S3RKS^++NYT.C2JM/0TKNX]KFKOZH@4TU)
M344@P]S4ORS+O</<(%--24U%(,/<U+\LTM2\L+_:P>XN(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B
M;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M97-S86=E+B(*;7-G
M<W1R("+3^]:TT-#3RKS^QZG#^RR[N=#HTJK3T-*[N/:YJ[^J(%,O34E-12##
MW-2_+,N]P]P@4R]-24U%(,/<U+\LTM2\L+_:P>XN(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G:60@(D$@<'5B;&EC(%--
M24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS
M9W-T<B`BT_N\T\/<T\J\_BR[N=#HTJK3T-*[N/8@4TU)344@N:N_JL/<U+\N
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0HC
M+"!F=7IZ>0IM<V=I9"`B04T@0VQO=61S(@IM<V=S='(@(M3&P;\B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B
M04T@3&EG:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M,@IM<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B04T@4VYO=R!3
M:&]W97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC
M.C(Y"FUS9VED(")!32]032(*;7-G<W1R(")!32]032(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B
M05!)($E$(@IM<V=S='(@(D%022"QX+K%(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E
M9&ET;W(B"FUS9W-T<B`BN=C3VM7BN/:QX+RMQO<B"@HC.B!S97)V:6-E<R]H
M96QP+VEN9&5X+G!H<#HU,@IM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`BN=C3
MVBXN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M
M:61D;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER
M96-T;W)Y+B(*;7-G<W1R("+(J,_>LKO7XRS.WK>HO:C!HB!61E,@Q+_"O"XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3,V"FUS9VED(")!
M8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G<W1R("+(J,_>
MLKO7XRS.WK>HO:C!HB!61E,@SL2\_BXB"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B06-C;W5N="!);F9O<FUA=&EO;B(*
M;7-G<W1R("+$^K7$T,7/HB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M-0HC+"!F=7IZ>0IM<V=I9"`B06-C;W5N="!087-S=V]R9"(*;7-G<W1R("+(
MM\C/P]S"ZR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S='(@
M(M7+NL72T;:SO>$N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S
M,PIM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R("*]X=7*(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A;"]A
M9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N
M:6YC.C$Q"FUS9VED(")!9&0B"FUS9W-T<B`BT,+4]B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z,C(T(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!9&0@
M0VAI;&0@1W)O=7`B"FUS9W-T<B`BT,+4]L_"O+;7Z2(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z.3@@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HY.0IM<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T
M<B`BT,+4]L_"O+;(J,_>(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC
M.C4*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R("+4VK3+T,+4]J.Z(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O=7!S+G!H<#HR,3D*;7-G
M:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`BT,+4]M/#NZ?7Z2(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HX.`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM
M<V=S='(@(M#"U/;(J,_>(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A
M9&1C:&EL9"YI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D
M(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(M#"U/;/PKRVT\.[
MI]?I("<E<R<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T
M-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R
M;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`BT,+4]L_"O+;(J,_>UL$@)R5S
M)R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E
M<CHB"FUS9W-T<B`BT,+4]M*[N/;3P[NG.B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HU-30*;7-G:60@(D%D9"!C;VQU;6XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN
M8SHS-`IM<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S='(@(M#"U/;2N[CV
ML\G4L3HB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED
M(")!9&0@<&%I<B(*;7-G<W1R("+0PM3VMM0B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@
M365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R("+0PM3V("5S(,ZJ
M($UO>FEL;&$@4VED96)A<B"RR[6E(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")!9&0@=&\@
M861D<F5S<R!B;V]K.B(*;7-G<W1R("+0PM3VM;W.TK7$S:C1MK*^(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<X"B,L(&9U
M>GIY"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(M#"
MU/:UO<[2M<3-J-&VLKXB"@HC.B!A9&UI;B]U<V5R+G!H<#HS,0IM<V=I9"`B
M061D('5S97(B"FUS9W-T<B`BT,+4]M/#NZ<B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HW.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB061D960@7"(E
M<UPB('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N
M86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`B"B(E<RXB"FUS9W-T<B`BTM'0PM3V
M("<E<R<@M;W/M<VSUM`N(+6KSMZWJ-#"U/:V[LWBM<37HK+AT,7/HCH@)7,N
M(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B061D960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN
M(&YO=RXB"FUS9W-T<B`BTM'0PM3V("<E<R<@M;W/M<VSUM`N(,3ZS];4VK_)
MTM2]^-#0M<?"O,'++B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D
M+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S
M='(@(M#"U/;3P[NGM<2YIL3<M;''L+&[N=BQU2XB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-S,@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,30T,0IM<V=I9"`B061D<F5S<R(*;7-G<W1R("*UV-:W(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S.0IM<V=I9"`B061D<F5S
M<R!";V]K(@IM<V=S='(@(LVHT;:ROB(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.CDT"FUS9VED(")!9&UI;FES=&5R("T@<V5T
M('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R("*SR<ZJN=S`
M[=2Q("T@SJK&Y,O\T\.[I\7DUL/(J,_>(@H*(SH@861M:6XO:6YD97@N<&AP
M.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D
M;6EN:7-T<F%T:6]N(@IM<V=S='(@(KG<P.TB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S0Q"FUS9VED(")!9',B"FUS9W-T<B`BN>.XYKG<P.TB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4V"FUS9VED(")!9F=H86YI<W1A;B(*;7-G<W1R("*PHKB[
MNKDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;&)A;FEA(@IM<V=S='(@(K"BMONP
MS<3AT<<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(K"B
MMON\L,#[T<<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R("*Q\,/[(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@HC
M+"!F=7IZ>0IM<V=I9"`B06QI9VXB"FUS9W-T<B`BL?##^R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*(RP@9G5Z>GD*
M;7-G:60@(D%L:6=N;65N=#HB"FUS9W-T<B`BO\V[I[;+(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C@W"FUS9VED(")!;&PB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E
M<G,B"FUS9W-T<B`BR_G3T-+1T>G6I+7$T\.[IR(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U
M<',B"FUS9W-T<B`BR_G3T-/#NZ?7Z2(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+V1A=&%T<F5E
M+G!H<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(LOYT]#(
MJ,_>(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,0IM<V=I9"`B06QL;W<@
M;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(M3*T.VVX+CVM>?7T]/*O/ZU
MV-:W(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S-`IM<V=I9"`B06QL
M;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS
M9VED(")!;')E861Y(&5X:7-T<R(*;7-G<W1R("+2T;3FU-HB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3(S"FUS9VED(")!;'1E<FYA=&4@24U34"!,
M;V=I;B(*;7-G<W1R("*QY+C\($E-4U`@M<?"O"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,#<*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D
M(@IM<V=S='(@(K'DN/P@24U34"##W,+K(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0Y.0IM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B"FUS
M9W-T<B`BL>2X_"!)35-0(-/#NZ<B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HS-0HC+"!F=7IZ>0IM<V=I9"`B06QT97)N871E(&5M86EL(&%D
M9')E<W,B"FUS9W-T<B`BL>2X_,2CL.8B"@HC.B!A9&UI;B]T96UP;&%T97,N
M<&AP.C$T,@IM<V=I9"`B06QT97)N871E('1E;7!L871E<R(*;7-G<W1R("*Q
MY+C\Q*.PYB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR-0HC+"!F=7IZ>0IM<V=I9"`B06QT97)N871E
M('1E>'0Z(@IM<V=S='(@(K'DN/S$H[#F(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B
M06UE<FEC86X@4V%M;V$B"FUS9W-T<B`BP\#*],CXQ*;1QR(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z.34@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P
M96-I9FEE9"XB"FUS9W-T<B`BTKNX]K*[NL^WJ+7$UK6QN\JYT\,N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-PHC+"!F=7IZ>0IM<V=I
M9"`B06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`BMZ+)
M^L'+TKNX]K3MSO,Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B06YD;W)R82(*;7-G
M<W1R("*PLK7`MOLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T
M<B`BL+*XY\"M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T
M<B`BL+*YY\"M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S='(@(L3DP_NT^L#M(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;G1A<F-T:6-A(@IM
M<V=S='(@(L3/O*O6WB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%N=&EG=6$@86YD
M($)A<F)U9&$B"FUS9W-T<B`BL++,X;G/O+"PS;;[LKRT[R(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN<&AP.C,U"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3@@=&5M<&QA=&5S+V%D;6EN
M+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T
M<B`BTZ;3P[/,T/(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*(RP@
M9G5Z>GD*;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`BTZ;3P[/,
MT/(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,30P"FUS9VED(")!<'!L
M:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`BTZ;3P[/,T/+2T;[-T/<B"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@
M=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@(M.FT\.UO<OYT]#/PKRVN;+/[2(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED
M(")!<'!R;W9E(@IM<V=S='(@(L7ZU[PB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HX,S,*;7-G:60@(D%P<')O>&EM871E(%-I>F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(LO$U,(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$W-0IM<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R
M-38I(@IM<V=S='(@(K"BP*VRKL[$("A7:6YD;W=S+3$R-38I(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8V"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z.#$*;7-G:60@(D%R8VAI=F4@1FEL92!3
M:7IE(@IM<V=S='(@(M&YR_7.Q+S^M//0H2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HV-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C@P"FUS9VED(")!<F-H:79E($YA;64B"FUS9W-T<B`BT;G+
M]<[$O/[#^[/&(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E
M=65D+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@
M>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@
M/R(*;7-G<W1R("+$^LBWMJC2JLF^L_T@)7,@M<37HK+APO`@/R(*"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHW"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L
M971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(L3ZR+>V
MJ-*JR;ZS_2`G)7,G(-+4O+#(SKK.U]/3P[NGU^D@/R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*
M;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R("*PHKCYS:(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W
M"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(M''P\#$X=''(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ-S8*;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I
M(@IM<V=S='(@(M''P\#$X=''SL0@*$%235-#24DM."DB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4Y"FUS9VED(")!<G5B82(*;7-G<W1R("*PHL*SL,TB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L
M86YD(@IM<V=S='(@(K"BR:W+R<BZM;HB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I
M8R!296=I;VXB"FUS9W-T<B`BT<?6WB_,J\:]T?.UV,?X(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0R-0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I
M;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S
M='(@(M:TT-#.K+NDLMG7]\>PS]3*OLBWR,^VU+NPO_(_(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q,PIM<V=I9"`B07-S:6=N;65N="!C;VQU
M;6YS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@
M(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G
M<W1R("+*U,V\R;ZS_=*[N/:RN[3FU-JUQ-/#NZ?7Z2XB"@HC.B!A9&UI;B]P
M97)M<R]D96QE=&4N<&AP.C(Y"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A
M(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("+*U,V\R;ZS_=*[
MN/:RN[3FU-JUQ,BHS]XN(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*
M;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S
M:6]N+B(*;7-G<W1R("+*U,V\L>"\K=*[N/:RN[3FU-JUQ-/#NZ?7Z2XB"@HC
M.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@
M=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T<B`BRM3-O+'@
MO*W2N[CVLKNTYM3:M<2YLL_M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C0@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HW,0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C@V"FUS9VED(")!='1R:6)U=&5S(@IM<V=S='(@(LKTT-0B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#8*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B
M075G=7-T(@IM<V=S='(@(K#+U,(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T
M<F%L:6$B"FUS9W-T<B`BL,2T\\#[T<<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!
M=7-T<FEA(@IM<V=S='(@(K#"M=C`^R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L.B!297%U:7)E
M9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8W)Y
M<W%L.B#5TK*[M;W+^=#HTJJUQ"!I;6%P(,"IU;G7Z;S^+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$S-0IM<V=I9"`B075T:%]C>7)U
M<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S
M+B(*;7-G<W1R(")!=71H7V-Y<G5S.B"W_L[QMLNRHLZTS.&YJ;C#S^[6I[/6
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I
M9"`B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R(")!=71H7V-R>75S.B#5TK*[M;W+^=#HTJJUQ"!I;6%P
M(,"IU;G7Z;S^+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O9G1P+G!H<#HS
M-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92TB"B)F
M='`@<W=I=&-H+B(*;7-G<W1R("(B"B)!=71H7V9T<#H@U=*RN[6]R_G0Z-*J
MM<0@1E10(,"IU;G7Z;S^+L?KUMC0PK'@TNL@4$A0(+*BQ]*\T\CK("TM96YA
M8FQE+69T<"#1H2(*(L_N+,#]R.<@8V]N9FEG=7)E("TM96YA8FQE+69T<"(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z-C0*;7-G:60@(D%U
M=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")!=71H7VEM87`Z(-72LKNUO<OYT.C2JK7$($E-05`@P*G5N=?I
MO/XN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HU,0IM<V=I
M9"`B075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(D%U=&A?:W)B-3H@U=*RN[6]R_G0Z-*JM<0@:W)B-2#`
MJ=6YU^F\_BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,P
M,@IM<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O
M<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,U-PIM<V=I9"`B075T:%]L9&%P
M.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@
M1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z-C,*;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VQD87`Z(-72LKNU
MO<OYT.C2JK7$($Q$05`@P*G5N=?IO/XN(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HS,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L
M9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60Z("(*;7-G<W1R(")!=71H7VQD87`Z(,[>MZC0PM3VT\.[
MIR`E<RX@M_[.\<;WN]C3ICHB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N
M86)L92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z(,[>
MMZC)OK/]T\.[IR`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z-#DY"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE
M('1O('5P9&%T92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@SMZWJ+C\
MT,+3P[NG("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT
M,#4*;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U
M<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M
M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(D%U=&A?;6-A;#H@U=*RN[6]R_G0Z-*JM<0@34-!3"#`J=6YU^F\_BXB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U
M=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R(")!=71H7W-M8F%U=&@Z(-72LKNUO<OYT.C2JK7$('-M
M8F%U=&@@P*G5N=?IO/XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")!=71H96YT:6-A=&EO;B!F
M86EL960B"FUS9W-T<B`BT>G6I,JGL-PN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R("+1
MZ=:DRJ>PW"X@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP
M:'`Z,3<V"FUS9VED(")!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)
M55,@<V5R=F5R+B(*;7-G<W1R(")2041)55,@T>G6I+3MSO,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-3$*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")&5%`@T>G6I+3M
MSO,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HW,`HC+"!F=7IZ
M>0IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I
M;&5D+B(*;7-G<W1R(")&5%`@T>G6I+3MSO,N(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS
M9W-T<B`BO\G3P[7$U]:VSCHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I
M:F%N(@IM<V=S='(@(K"BR/NPW;VN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,P"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`HC
M+"!F=7IZ>0IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R("*QL[ZPT=7)JR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C,*
M;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`BL;.^L-'5R:LB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@Q"FUS9VED(")"860@
M:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(FME<F)E<F]S(,/<PNNT[<[S
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@
M(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS9W-T<B`B:V5R8F5R;W,@T\.[
MI\/[M.W.\RXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"86AA;6%S(@IM<V=S='(@
M(K#-N?["[<BZM;HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"86AR86EN(@IM<V=S
M='(@(K#-P=8B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-PIM<V=I9"`B
M0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`BLJC"WK7$NJ/.Q"`H25-/
M+3@X-3DM,3,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G
M<W1R("+#S[S3P*VY^B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM
M<V=S='(@(K#-L,VVX,NY(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S(&1I
M<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("+5TK*[M;T@)7,@
MM<3`X+'PMJC2Y2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S,*(RP@9G5Z>GD*;7-G:60@(D)A<V5L:6YE(@IM
M<V=S='(@(K*NP/O7R"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&%R=7,B"FUS
M9W-T<B`BL->V[<+>R[DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"96QG:75M(@IM
M<V=S='(@(K'(P/O*L2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&EZ92(*;7-G
M<W1R("*RKL#[U\@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"96YI;B(*;7-G<W1R
M("*QM,3^(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R("*P
MV<2]M//(NK6Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@
M(K*[M:0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G<W1R("+)^LC5(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,U,PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T
M:6]N(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(M72LKNUO2`E<R"UQ,#@
ML?"VJ-+E+B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHX.0IM
M<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`BQ_B_Z<7DUL,B"@HC.B!T
M96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y
M<&4B"FUS9W-T<B`BQ_B_Z<#@T,TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T<B`BM-;,
MY2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`BLJ/`^\ZL
MT<<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`U"FUS9VED(")"
M;V]K;6%R:W,B"FUS9W-T<B`BRNG'J2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*(RP@9G5Z>GD*;7-G:60@
M(D)O<F1E<B(*;7-G<W1R(")(;W)D92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE
M<W,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C$*(RP@9G5Z>GD*;7-G:60@(D)O<F1E<G,B
M"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")";W-N:6$@86YD
M($AE<GIE9V]V:6YA(@IM<V=S='(@(K*HR[G$X=''NLVZVLC[N.?.K,3'(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV"B,L(&9U>GIY"FUS9VED(")"
M;W1H(@IM<V=S='(@(M3"(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]T<W=A;F$B
M"FUS9W-T<B`BLJFTQ,W?Q,DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(R"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@(D)O='1O;2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V970@27-L86YD(@IM<V=S='(@
M(K*HSJS,V+6Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)A>FEL(@IM<V=S='(@
M(K#-SO<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E
M86X@5&5R<FET;W)Y(@IM<V=S='(@(M.BRO33H;;(T?/![+78(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`BSL3`LR(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C$*;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@(K&CO-/`^]''
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M.0IM<V=I9"`B0G5L;&5T960@3&ES="(*;7-G<W1R("+/[L2_M_NZQ2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C$*;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R("*RO+RJQ,FW
MJ,OW(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R("*RO,*A
MM<\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0T"FUS9VED(")#
M35,B"FUS9W-T<B`BQ-K(W;G<P.W/M<VS(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S='(@(D-2
M0R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DW"FUS
M9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R(")#4DP@M]:R
MO+7C(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C,*;7-G
M:60@(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#0@
M8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDX-PHC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,34U"FUS9VED(")#86QE;F1A<B(*;7-G<W1R("+(U<#Z(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-@IM<V=I9"`B0V%L
M;2(*;7-G<W1R("+!X[RVM^<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B0V%M8F]D
M:6$B"FUS9W-T<B`BO.W&TM6O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O
M;VXB"FUS9W-T<B`BOZ;"\\*A(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA
M=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,Q.`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W<FET92!T;R!F:6QE(%PB
M)7-<(B(*;7-G<W1R("+.WK>HR;ZS_<[$O/X@7"(E<UPB+B(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HR,@IM<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E
M<FYA;"!S97-S:6]N(&AA;F1L97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)S<6PN<&AP.C,Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C
M;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R("+.WK>HP:J[^M;!
M($E-05`@M_[.\<;W.B`E<R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C0Q,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E
M;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BSMZWJ,F^L_W.Q+S^(%PB)7-<(BXB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8T"FUS9VED(")#86YA9&$B"FUS9W-T<B`BO-/$P[3S(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E<R]A
M9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F4N:6YC.C$R"FUS9VED(")#86YC96PB"FUS9W-T<B`BR*'/^R(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#
M86YC96P@4')O8FQE;2!297!O<G0B"FUS9W-T<B`BR*'/^\[*S.*QJ+CF(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
MSMZWJ,F^L_W.Q+S^(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P
M=713=')A=&5G>2]C;W!Y+G!H<#HU,@HC+"!F=7IZ>0IM<V=I9"`B0V%N;F]T
M(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("+.WK>HR;ZS
M_<2_PKP@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@
M)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HS,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("+.WK>H
MR;ZS_<2_PKP@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A
M5')E92YP:'`Z,3(X(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN
M<&AP.C8X,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E
M;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(L[>MZC)OK/].]/0
MS\*\MK3FU-H@*"5S*2(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E
M92]S<6PN<&AP.C8P.`IM<V=I9"`B(@HB0V%N;F]T(')E;W)D97(L(&YU;6)E
M<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA
M=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM<V=S='(@(L[>MZC6V-?IH:/+^<SA
MN:FUQ+S'PKS*_<2_T^O/R,>PR_FQH[3FM<3*_;[=LKNW^RXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G
M:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N
M(@IM<V=S='(@(L[>MZBTJ\O-T,7/HK6]UKBVJ+7$NL7"ZRXB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8X"FUS9VED(")#87!E(%9E<F1E(@IM<V=S='(@(K?PM<.]QR(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*
M(RP@9G5Z>GD*;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`BT:'/[B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`HC+"!F
M=7IZ>0IM<V=I9"`B0V%R<FEE<B(*;7-G<W1R("*WV[KLR:LB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3`*;7-G:60@(D-A=&5G;W)I97,@86YD($QA
M8F5L<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y;6%N($ES
M;&%N9',B"FUS9W-T<B`BOZK"_,BZM;HB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#96QL(%!H;VYE(@IM
M<V=S='(@(M+&MJ^UY[NP(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0HC+"!F=7IZ>0IM<V=I9"`B0V5L;"!0
M<F]P97)T:65S(@IM<V=S='(@(M+&MJ^UY[NP(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D
M9&EN9SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$R"FUS9VED(")#96QL('-P86-I;F<Z(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-S0*(RP@9G5Z>GD*;7-G
M:60@(D-E;&QP:&]N92(*;7-G<W1R("+2QK:OM>>[L"(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3<X"FUS9VED(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*
M;7-G<W1R("+(^[;[S-C.Q"`H25-/+3@X-3DM,30I(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-@HC+"!F=7IZ
M>0IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(KVHP:(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C4T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS
M9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`BUM"WQ[FR
MNLVY^B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")#96YT
M<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*2(*;7-G<W1R("+6T,6W("A)4T\M
M.#@U.2TR*2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-CDY"FUS9VED(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(L:^UJ3/
MN+W:(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3$*
M(RP@9G5Z>GD*;7-G:60@(D-E<G1I9FEC871E($]W;F5R(@IM<V=S='(@(L:^
MUJ3/N+W:(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.38*;7-G:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(L:^UJ2R
MW\+4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")#:&%D(@IM<V=S='(@(M6GM<,B
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.CDV"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B
MN/RXQ"(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,0HC+"!F
M=7IZ>0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`BR+?(
MS\/<PNLB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G:60@(B(*
M(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@
M=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS+B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*
M;7-G:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O
M<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#;VYT
M86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PHC+"!F
M=7IZ>0IM<V=I9"`B0VAA<B(*;7-G<W1R("+5I[7#(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED
M(")#:&5C7VL@3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED
M(")#:&EL92(*;7-G<W1R("+6Q\#[(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI
M;F$B"FUS9W-T<B`BUM"Y^B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P
M"FUS9VED(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS9W-T<B`B
MO/+,Y=;0SL0@*$=",C,Q,BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M,0IM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B
MM[',Y=;0SL0@*$)I9S4I(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N
M=7`N<&AP.C(V.0IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B
MT:'4\</<PNLB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z
M,C8X"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R("+1H=3QTKNX
M]M/#NZ?#^R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.3@*;7-G:60@
M(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SHB"FUS9W-T<B`BR-7&VL_4
MRKZWO<J].B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE('1Y
M<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X
M"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(LJEM:ZUNB(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4RYP:'`Z,CDT(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HX.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI
M=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(M72LKNUO2`E<R"UQ,#@
ML?"VJ-+E+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$T"B,L(&9U>GIY"FUS9VED(")#;&5A<B(*;7-G<W1R("+(U<#Z(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM
M<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,3(X"B,L(&9U>GIY"FUS9VED(")#;&5A<B!1=65R
M>2(*;7-G<W1R("+*_;[=O^*RZ=&O(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O8VQE87(N:6YC.C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-L
M96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R("+)OK/]T\.[ISH@)7,B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3$*;7-G:60@(D-L96%R
M('5S97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z,S0*(RP@9G5Z>GD*;7-G:60@(D-L96%R('5S97(@9&%T82(*;7-G
M<W1R("+1H=3QTKO.N]/#NZ?3P]+4T,+4]B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"FUS9VED(")#;&5A<FEN9R!,871E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N
M86YC92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R
M("*PM,KSL>J\_+S,T/@B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A4
M5%`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD
M;W<B"FUS9W-T<B`BN=BQU;2PO]HB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(T-`IM<V=I9"`B0VQO=61S(@IM<V=S='(@(M3&P;\B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-@HC+"!F=7IZ>0IM<V=I
M9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(M3&P;\B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-PHC+"!F=7IZ>0IM<V=I9"`B
M0VQO=61Y(@IM<V=S='(@(M3&P;\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#;V-O
M<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R("*_QK_&R[G(NK6Z(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR,PIM<V=I9"`B0V]L;&%P
M<V4@4VED96)A<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(X"FUS9VED(")#;VQL87!S960@
M8F]R9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;VQO;6)I
M82(*;7-G<W1R("*XY\+7L<C1QR(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP:'`Z
M,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#;VQO<B(*
M;7-G<W1R("+1U<FK(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE
M8W1I;VXN<&AP.C,R-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C
M=&EO;BYP:'`Z,S(U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HU,#`@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ
M-`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT
M.0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU
M,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV
M-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV
M-@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX
M,0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX
M,@IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@(K7WR:O%S"(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X-#8*(RP@9G5Z>GD*;7-G:60@(D-O
M;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`BO/3'T-&AU/$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PHC+"!F=7IZ>0IM
M<V=I9"`B0V]L<SHB"FUS9W-T<B`BS;;&L2(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Y-#8*;7-G:60@(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V-`IM<V=I9"`B0V]M
M:6-S(@IM<V=S='(@(K^HS:@B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*
M;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`BP_S![B(*"B,Z(&%D;6EN+V-M9'-H
M96QL+G!H<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R("+#_,'N
MO<6QOB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM
M<V=I9"`B0V]M;65N="(*;7-G<W1R("+&P,+;(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C8*;7-G:60@(D-O;6UO;B!.86UE(@IM
M<V=S='(@(LVHT\/#^R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")#;VUO<F]S(@IM
M<V=S='(@(K_&Q*;"WB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HR,SD*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`BN:O+OB(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B
M0V]M<'5T97)S(@IM<V=S='(@(M+1S>JSR2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR.3<*(RP@9G5Z>GD*;7-G:60@(D-O;F1I=&EO;B(*
M;7-G<W1R("+,];S^(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#D*;7-G
M:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`BS/6\_B(*"B,Z(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.CDV"B,L(&9U>GIY"FUS9VED(")#;VYF:6=U<F%T:6]N($1I
M9F9E<F5N8V5S(@IM<V=S='(@(L7DUL,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,30S"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I
M=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S4*(RP@9G5Z>GD*;7-G:60@
M(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@(L7DUL,B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`P"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R("+%Y-;#("5S(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,0IM<V=I9"`B0V]N9FER
M;2!087-S=V]R9"(*;7-G<W1R("+(M\C/P]S"ZR(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G
M:60@(D-O;F=O(@IM<V=S='(@(KC5N?LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#
M;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@
M(KC5N?NYLKK-N?HB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S$P"B,L(&9U>GIY"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB
M"FUS9W-T<B`BP:R]T\JGL-PZ("(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B
M"FUS9W-T<B`BP:R]T\JGL-PZ("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C<Y,`HC+"!F=7IZ>0IM<V=I9"`B0V]N;F5C=&EO;B!R969U
M<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("+!K+W3UL&Y
MJ[^JP]S4O[?^SO'&]\JQU.*^W+[X+B#4K=+R.B`E<R`H)7,I(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDR"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(L&LO=/6P;FKOZK#W-2_
MM_[.\<;WRK'4XK[<OO@N(-2MTO(Z("5S("@E<RDB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C@T-0IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@
M<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`BP:R]T];!($944"#.Q+S^M_[.\<;W
MRJ>PW"XB"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`Q-`IM<V=I9"`B
M0V]N=&%C=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C4S"B,L(&9U>GIY"FUS9VED(")#;VYT86-T<R!W
M97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB
M"FUS9W-T<B`BS:C1MLK]OMW2T;/)N::UQ-3VO-.UO<3ZM<3-J-&VLK[6T"[3
MP\KSL>JPM,_"P=#/[L2_TM2\[,K3.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-38@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HV,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C<X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT
M<R!O9B!<(B5S7"(B"FUS9W-T<B`B)R5S)R#.Q+S^Q-K(W2(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HS,PHC+"!F=7IZ>0IM<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`B
MS/6\_B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R
M("*_XK_+R+JUNB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I
M9"`B0V]O:VEE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0HC+"!F=7IZ>0IM<V=I9"`B
M0V]P>2(*;7-G<W1R("*YJ\N^(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HT-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O<'D@9F%I
M;&5D.B`E<R(*;7-G<W1R("+!K+W3RJ>PW#H@(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE
M8W1I;VXB"FUS9W-T<B`BN+36QM&AU/$B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C$W,`HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I9"`B0V]S="!)1"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8W"FUS9VED(")#;W-T82!2:6-A(@IM<V=S='(@(KCGR[FT
M[\#HO-,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S
M='(@(K_&S-BUS\W?(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z.3<V"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92XB
M"FUS9W-T<B`BSMZWJ-+4(%!'4""\T\/<T\J\_BXB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#4S"FUS9VED(")#;W5L9"!N;W0@4$=0
M('-I9VX@;65S<V%G92XB"FUS9W-T<B`BSMZWJ,ZJ(%!'4"#6M-#0T\J\_L>I
MP_LN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3,*
M;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G
M<W1R("+.WK>HTM0@4R]-24U%(+S3P]S3RKS^+B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L9"!N;W0@4R]-
M24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`BSMZWJ,ZJ(%,O34E-12#3RKS^
MQZG#^RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C$X-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R("+.WK>HM/*_JB`E<RXB"@HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z.38@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HQ,C$*;7-G:60@(D-O=6QD(&YO="!B:6YD
M('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R("+.WK>HL/.VJ"!,1$%0(+?^SO'&
M]R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-3<*(RP@9G5Z>GD*;7-G
M:60@(D-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(L[>
MMZBP\[:H($Q$05`@M_[.\<;W(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T
M<B`BSMZWJ+;!R*$@)7,N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0T
M,0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@;&1A<"!S
M97)V97(B"FUS9W-T<B`BSMZWJ,&LO=,@4TU"(+?^SO'&]RXB"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@
M1E10.B`E<R(*;7-G<W1R("+.WK>HP:R]T];!M_[.\<;W("<E<R<@RKG3PR!&
M5%`Z("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HS,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(L[>
MMZB]J,&BL;ZUV-/OT=0@)7,@R_G0Z-*JM<3$O\*\.B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q,C4*;7-G:60@(D-O=6QD(&YO="!D
M96-R>7!T(%!'4"!D871A+B(*;7-G<W1R("+.WK>HO>+#W"!01U`@ROV^W2XB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R,@IM<V=I
M9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(L[>
MMZB]XL/<(%,O34E-12#*_;[=+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S(@IM<V=S='(@
M(L[>MZC)OK/]N/S0PK/,T/(@)R5S)RXB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,B"FUS9W-T<B`BSMZWJ,F^L_VX_-#"L\S0\B`G)7,G+B(*"B,Z(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T
M(%PB)7-<(BXB"FUS9W-T<B`BSMZWJ,F^L_VX_-#"L\S0\B`G)7,G+B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU,PIM<V=I9"`B0V]U;&0@;F]T(&1E
M=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N(@IM<V=S
M='(@(L[>MZB^]K:HRM6\_LC+M<2UY]?3T\J\_K78UK<N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*(RP@9G5Z
M>GD*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O
M;VLN(@IM<V=S='(@(L[>MZB^]K:HRM6\_LC+M<2UY]?3T\J\_K78UK<N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT
M.3,*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D
M:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`BSMZWJ+#\NJS7ULSEMJC2Y<[$
MO/XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@
M;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R
M871E9WDN<&AP.C8X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB
M"FUS9W-T<B`BSMZWJ+;!R*$@)7,N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q
M,`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U
M='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(L[>
MMZBVP<BA("5S+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C<Q.0IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@
M=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`BSMZWJ-?4P]S4O[?^SO'&]\BAM<.Y
MJ[^JP]S4ORXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R
M:71I;F<N(@IM<V=S='(@(L[>MZBT\K^J("5S+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(V,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`BSMZWJ+3R
MOZH@)7,N(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E
M+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@
M36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`BSMZWJ+3ROZK.
MK+NDN:37]\2CO^D@)7,B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C=&]R
M>2!<(B5S7"(N(@IM<V=S='(@(L[>MZC)OK/]Q+_"O"!<(B5S7"(N(@H*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HR,S<@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C0W.`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z-CDY"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@
M<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R("+.WK>HLNG5TB!,1$%0
M(""W_L[QQO<N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O3V)J96-T+G!H<#HR
M,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N(@IM
M<V=S='(@(L[>MZBVP<BA("5S+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W
M;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H
M92`B"B)D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O
M;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U<G1H
M97(@:&5L<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S`Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,T,`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS-S<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S@S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,X.0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G
M<W1R("+.WK>HML'(H;3FR*&_V-;&L>TH04-,*2(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B
M;V]K+B`E<R(*;7-G<W1R("+.WK>HML'(H;?^SO'&][7$S^"YV,S8T-0B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("+.WK>HML'(H;?^
MSO'&][7$S^"YV,S8T-0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C0S-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B
M"FUS9W-T<B`BSMZWJ+;!R*&W_L[QQO>UQ,_@N=C,V-#4(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*;7-G:60@(D-O=6QD(&YO
M="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`BSMZW
MJ+;!R*&W_L[QQO>UQ,_@N=C,V-#4(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("+.WK>HL:.TYB`E<R"UQ,7DUL,N(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.CDT"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R("+.WK>HML'(H2`E
M<RXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R("+.WK>HL:.TYB`E<R"UQ,7DUL,N(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y"B,L(&9U
M>GIY"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I
M;VXN(@IM<V=S='(@(L[>MZBQH[3F("5S(+7$Q>36PRXB"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS
M9W-T<B`BSMZWJ+&CM.8@)7,@M<3%Y-;#+B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.CDU"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*
M;7-G<W1R("+.WK>HL:.TYKC\T,*SS-#RM;TZ("<E<R<N(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I
M;&4@)7,N(@IM<V=S='(@(L[>MZBQH[3F("5S(+7$Q>36PRXB"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C<U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE
M("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS
M('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY
M('1H92!C;V1E(&)E;&]W('1O("5S+B(*;7-G<W1R("+.WK>HT+3(ZRX@Q/J_
MR=+4RKG3P\C.NLZUQ,G]O+:SS-#RN_+*UK:ON+36QL_"P^:SS-#RM/K"Z[6]
M("5S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,30S"FUS
M9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T
M<B`BSMZWJ++IU=(@3$1!4"`@M_[.\<;W+B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HX-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N
M;&EN:R!<(B5S7"(N(@IM<V=S='(@(L[>MZBT\K^J("5S+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&-O;G1A
M8W0N("5S(@IM<V=S='(@(L[>MZBT\K^J("5S+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<R(*;7-G<W1R("+.WK>HL/RZK-?6S.6VJ-+ESL2\_BXB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B!<
M(B5S7"(Z("5S(@IM<V=S='(@(L[>MZBXLKC'("<E<R<Z("5S(+7$Q>36PRXB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8V"FUS9VED(")#;W5L9&XG
M="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED
M96)A<B!I<R!O<&5N+B(*;7-G<W1R("+5TK*[M;T@36]Z:6QL82!3:61E8F%R
M+B#'Z\BWR,\@<VED96)A<B#*Q[?QM/*_JBXB"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O
M;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G
M<W1R("+.WK>HN+/3Z-/#NZ<@)R5S)R#/PL'0R*C/WK6]SL2\_KS0("<E<R<Z
M("5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q.0HC+"!F=7IZ
M>0IM<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(LSARK[$VLC=(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D-O
M=6YT<GDB"FUS9W-T<B`BN?J\TB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR-S,*(RP@9G5Z>GD*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`BT*'*
ML2(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C$P,`IM<V=I9"`B0W)E871E(@IM<V=S='(@(KVHP:(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C@*(RP@9G5Z>GD*;7-G:60@(D-R96%T92!A(&QI;FLB"FUS9W-T<B`B
MO:C!HB(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z
M.30*(RP@9G5Z>GD*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`B
MT:'4\=*[SKO0PK7$T[73T-7?(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@(D-R96%T92!S=6(@9F]L9&5R<R(*
M;7-G<W1R("*]J,&BU]/.Q+S^O-`B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C(T,`IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*;7-G
M<W1R("*]J,&BU=^UQ,BHS]XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,C,P"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`BT,73
MP[^HNL7"ZR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")#<F]A=&EA(@IM<V=S='(@
M(K_+PMZUV-''(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B82(*;7-G<W1R("*Y
MQ;#-(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(V"B,L(&9U>GIY"FUS9VED
M(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@(K6QQ[#/X,Z[(@H*(SH@861M
M:6XO<V5S<VEO;G,N<&AP.C0X"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(%-E
M<W-I;VYS(@IM<V=S='(@(KVHP:+5W[7$R*C/WB(*"B,Z(&QI8B]";&]C:R]T
M:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N
M="!4:6UE(@IM<V=S='(@(K6QQ[#*L;SD(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4T"B,L(&9U>GIY"FUS
M9VED(")#=7)R96YT(%523"!I<R(*;7-G<W1R("*UL<>PRK&\Y"(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HS,PHC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!5
M<V5R<R(*;7-G<W1R("*UL<>PS^#.NR(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C4*;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R("*UL<>PS.S&
M^"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-S4*;7-G:60@
M(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`BM;''L->TO_8Z("(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G
M:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`BM;''L+?GN/$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3`X"B,L('!H<"UF;W)M870*;7-G:60@(D-U
M<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(P"B,L(&9U>GIY"FUS9VED(")#=70B"FUS9W-T<B`BN?J\
MTB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S4*;7-G:60@(D-U="!S96QE8W1I;VXB"FUS9W-T<B`BO/3'T-&AU/$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8X"FUS9VED(")#>7!R=7,B"FUS9W-T<B`BR/O&UL*WR[DB"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,@IM<V=I9"`B0WER:6QL:6,@*$M/
M23@M4BDB"FUS9W-T<B`BSO?`[[;[SL0@*$M/23@M4BDB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U
M,2DB"FUS9W-T<B`BSO?`[[;[SL0@*%=I;F1O=W,M,3(U,2DB"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N
M("A+3TDX+54I(@IM<V=S='(@(L[WP.^V^\[$+\[:O\O`O,[$("A+3TDX+54I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS9W-T<B`B
MO=V_R[FRNLVY^B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-3$@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$
M(@IM<V=S='(@(LC5(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X
M,0IM<V=I9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU
M86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N
M<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R("+#O\C5(@H*(SH@861M:6XO
M9&%T871R964N<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-SD*;7-G:60@
M(D1A=&%B87-E($QO;VMU<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S.3D*;7-G:60@(D1A=&4B"FUS9W-T<B`BR-7&VB(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED(")$871E
M(%)E8V5I=F5D(@IM<V=S='(@(LK5M;W(U<;:(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@P-PIM<V=I9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T
M<B`BT:'4\<C5QMHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,CDR(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,C(*;7-G:60@(D1A
M>2(*;7-G<W1R("*PU\SL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,V"B,L(&9U>GIY"FUS9VED(")$95]L
M971E($-O;'5M;B(*;7-G<W1R("+)OK/]T\.[I]?I(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R
M(@IM<V=S='(@(LJNMO[4PB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*(RP@9G5Z>GD*;7-G:60@(D1E
M8VEM86P@;G5M8F5R<R(*;7-G<W1R("+0\KK%(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@
M26YD96YT(@IM<V=S='(@(KSUR=G+]<7%(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ.#<@;&EB+W!R969S+G!H<#HQ,3<*(RP@9G5Z>GD*
M;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`BR;ZS_2(*"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"B,L(&9U>GIY"FUS9VED
M(")$969A=6QT($-O;&]R(@IM<V=S='(@(M?6T,W1U<FK(@H*(SH@9G)A;65W
M;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HY,0IM<V=I9"`B1&5F875L="!)
M9&5N=&ET>2(*;7-G<W1R("+$K,C/R>VWW<JVL?`B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0@4VAE;&PB
M"FUS9W-T<B`BQ*S(S\GMM]W*MK'P(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,S"B,L(&9U>GIY"FUS9VED(")$969I;FET:6]N<R(*;7-G<W1R("+,
M];S^(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW,2!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C,R-@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C0R,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0S.0HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z-S`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,R!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$S.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.CDX"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M9&5L971E+FEN8SHQ,"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS
M,0IM<V=I9"`B1&5L971E(@IM<V=S='(@(LF^L_TB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S(*(RP@9G5Z
M>GD*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S='(@(LF^L_TB"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G<F]U<',N<&AP.C(R-PIM<V=I9"`B
M1&5L971E($=R;W5P(@IM<V=S='(@(LF^L_W3P[NGU^DB"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR-#D*(RP@9G5Z>GD*;7-G:60@(D1E;&5T
M92!,;V<B"FUS9W-T<B`BR;ZS_2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z-S<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#$*
M;7-G:60@(D1E;&5T92!097)M:7-S:6]N(@IM<V=S='(@(LF^L_W(J,_>(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G
M:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`BR;ZS_:&B
MQ^6_U=/*O/XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4W"B,L(&9U>GIY"FUS9VED(")$96QE=&4@8V5L;"(*
M;7-G<W1R("+)OK/](@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV,PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E(&-O
M;'5M;B(*;7-G<W1R("+)OK/]T\.[I]?I(@H*(SH@861M:6XO=&5M<&QA=&5S
M+G!H<#HQ-#@*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E
M<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`BLN7(Z[_)S.:T^L2CL.8B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B
M"FUS9W-T<B`BR;ZS_2`G)7,GM<3(J,_>(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HT,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E
M<FUI<W-I;VYS/R(*;7-G<W1R("+(M[:HTJK)OK/]("<E<R>UQ,BHS][2U+RP
MS\*\MLBHS]X@/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!R;W<B
M"FUS9W-T<B`BR;ZS_=/#NZ?7Z2(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE
M=&5I9&5N=&ET>2YI;F,Z,34*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!S96QE
M8W1E9"!I9&5N=&ET>2(*;7-G<W1R("+1H=3QR-7&VB(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I
M9"`B1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C,*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E
M<UPB+B(*;7-G<W1R("*X_-#"L\S0\B`G)7,G(-+1R;ZS_2XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V,PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M,C$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C4S"FUS9VED(")$96QI=F5R>2!T:6UE(@IM<V=S='(@(K7=R\W*L;SD
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R("*UI,+S(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E
M<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(L[*S.+#Z,KV(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3,X('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*;7-G:60@(D1E<V-R:7!T:6]N
M(@IM<V=S='(@(L/HRO8B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$Y-0IM<V=I9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I
M.B(*;7-G<W1R("+/N+W:("C'Z[+.O[P@2&]R9&4@O,?"O,[$O/XI.B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DY"FUS9VED(")$971A:6QS
M(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G
M<W1R("+/N+W:Q^NRSK^\S[7-L[G<P.VUQ\*\+B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR,3D*;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S='(@
M(M'0MZ(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-PIM<V=I9"`B1&5W
M(%!O:6YT(@IM<V=S='(@(L*VM>/.PK;((@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR.30*;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS
M9W-T<B`BU^ZZ\]*[T*'*L;7$PK:UX\["ML@Z("(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,C<*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S
M='(@(L*VM>/.PK;(.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H
M="(*;7-G<W1R("*TT]?SUL'3TB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T
M;R!L969T(@IM<V=S='(@(K33T]+6P=?S(@H*(SH@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R("+$O\*\(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V-@IM<V=I9"`B1&ES<&QA>2`R-"UH
M;W5R('1I;65S/R(*;7-G<W1R("+2U"`R-"#0H<JQUL;/U,J^/R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PIM<V=I9"`B1&ES<&QA>2!/<'1I;VYS
M(@IM<V=S='(@(L_4RK[1H<_N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.CDV"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O
M<F5C87-T(@IM<V=S='(@(L_4RKZX\<J](@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HX-0HC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&
M*2(*;7-G<W1R("+/U,J^N/'*O2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(X,3<*;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM<V=S='(@(L_4RKZX
M\<J](@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C$Y,`IM<V=I
M9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(KRJLKS,X2(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R"FUS9VED(")$;R!N;W0@
M9&5L971E(@IM<V=S='(@(K*[R;ZS_2(*"B,Z('-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN
M=&5N86YC92YP:'`B"FUS9W-T<B`BLKO2JM:QO=.TYLBA(&UA:6YT96YA;F-E
M+G!H<"(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$R('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C$R"FUS9VED(")$;V5S('1H92!F:7)S
M="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@
M=&AI<R!B;W@Z(@IM<V=S='(@(K7:TKNQRKS'PKS*Q[?QL/RZK-?6ML[#^[/&
M/R#(Y[G[RL?'Z]&AU/$N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&]M:6YI8V$B
M"FUS9W-T<B`BMN##U\3AO-,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")$;VUI;FEC
M86X@4F5P=6)L:6,B"FUS9W-T<B`BMN##U\3AO-.YLKK-N?HB"@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDV"FUS9VED(")$;VXG="!H879E(&%N
M(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C@T-`IM<V=I9"`B1&]W;FQO860B"FUS
M9W-T<B`BS\+4V"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C@T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G
M<W1R("+/PM38("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM
M<V=I9"`B1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0
M('-C<FEP="XB"FUS9W-T<B`BS\+4V,GZL\FUQ,7DUL/.Q+S^SJH@4$A0(+/,
MT/(N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P-PIM<V=I9"`B
M1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`BS\+`K;++M:4B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B12U-
M86EL(@IM<V=S='(@(K7GU]/3RKS^(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G
M871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI
M<R!S97)V:6-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T
M:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED
M(")%4E(B"FUS9W-T<B`BM.W.\R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5C=6%D
M;W(B"FUS9W-T<B`BMO*YS[;@MOLB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C,R-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$X,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M-S(*(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I
M="(*;7-G<W1R("*QX+RM(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)
M+G!H<#HU,"!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%
M9&ET($)L;V-K(@IM<V=S='(@(K'@O*W'^+_I(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H<#HR,C8*;7-G:60@(D5D:70@1W)O
M=7`B"FUS9W-T<B`BL>"\K=/#NZ?7Z2(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z-S8@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ
M,#`*;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R("*QX+RMR*C/WB(*
M"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@
M4&5R;6ES<VEO;G,B"FUS9W-T<B`BL>"\K<BHS]XB"@HC.B!S97)V:6-E<R]S
M:&%R97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@
M4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(K'@O*T@)7,@M<3(J,_>(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I
M;VYS(&9O<CHB"FUS9W-T<B`BL>"\K=&AS^XB"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C,V-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B161I="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(K'@O*T@
M)7,@M<3(J,_>(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*
M;7-G<W1R("*QX+RM("5S(+7$R*C/WB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS-0HC+"!F=7IZ>0IM<V=I9"`B161U8V%T:6]N(@IM<V=S='(@(K78
MQ_@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*;7-G<W1R("*PH[RP(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B16ET:&5R(&5N86)L92!I="!T:&5N.B`E<RP@;W(@=7-E('1H
M92!B87-I8R!(5$U,('9E<G-I;VXZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@(LCXMOO-W[;@(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%
M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,C(T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-CD*;7-G
M:60@(D5M86EL(@IM<V=S='(@(K7GU]/3RKS^(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C4@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]E9&ET+FEN8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C8X"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(K7GU]/3RKS^
MM=C6MR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C,*;7-G:60@
M(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*;7-G<W1R("*UY]?3T\J\
M_K78UK>QV-#KSL>ZSRXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.3@Y"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R("*U
MY]?3T\J\_LBWR,\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I
M8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W87DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(Y.`IM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(K'MQ^FW^[K%(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`R"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R("*_U;#7T,6\_BXB
M"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C0S(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT.#0*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C8V,B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-S`U"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M,34P"FUS9VED(")%;7!T>2!R97-U;'0N(@IM<V=S='(@(K_5L->]X;G[+B(*
M"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@
M(D5M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-30S"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM
M86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$X"FUS9VED(")%;F%B;&4@
M<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DX(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(X,3$*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(L3JM=<B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED
M(")%;FQA<F=E($5D:71O<B(*;7-G<W1R("*WQ;3SL>"\K<;W(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(R,0IM<V=I9"`B(@HB16YT97(@82!S96-U
M<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@
M;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES
M('1H92!N86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M,@IM<V=I9"`B16YT97(@=&AE(&EM86=E(%523"!H97)E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX.3$*
M;7-G:60@(D5N=&5R('1H92!L971T97)S(&)E;&]W.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDY(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<V"FUS9VED(")%<75A=&]R:6%L($=U:6YE82(*;7-G<W1R("*S
MX+7`O+C$VM''(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E82(*;7-G<W1R
M("*V\L&BS-C`[]''(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I
M9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C4U"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S8@<V5R=FEC97,O<&]R
M=&%L+VEN9&5X+G!H<#HX,@IM<V=I9"`B17)R;W(B"FUS9W-T<B`BM.W.\R(*
M"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8S"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@
M)7,B"FUS9W-T<B`BM*O+S;O8N+3*L;>BR?JT[<[S.B`E<RXB"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<R(*
M;7-G<W1R("*TJ\O-N]BXM,JQMZ+)^K3MSO,Z("5S+B(*"B,Z(&9R86UE=V]R
M:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8X"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@
M(K2KR\V[V+BTRK&WHLGZM.W.\SH@)7,N(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C<V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`BM*O+S;O8N+3*
ML;>BR?JT[<[S.B`E<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@
M;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN9R!<(B5S
M7"(N(@IM<V=S='(@(K2KR\V[V+BTRK&WHLGZM.W.\SH@)7,N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,`IM<V=I9"`B17-T;VYI82(*;7-G<W1R("*PKLFSQ.'1QR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S$*;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(K"CR/NV[;'(T<<B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*(RP@9G5Z>GD*;7-G:60@(D5T
M:&YI8R(*;7-G<W1R("*PKLFSQ.'1QR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(L6WUMXB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Y"FUS9VED(")%=F5R>2`Q-2!M
M:6YU=&5S(@IM<V=S='(@(L._(#$U(+?6UM,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S@Y"B,L(&9U>GIY"FUS9VED(")%=F5R>2`R(&UI;G5T97,B
M"FUS9W-T<B`BP[\@-2"WUM;3(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,S-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@W"FUS9VED(")%=F5R>2`S
M,"!S96-O;F1S(@IM<V=S='(@(L._(#,P(,/KUM,B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S,X(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3`*;7-G
M:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R("+#OR`U(+?6UM,B"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED
M(")%=F5R>2!,;V=I;B(*;7-G<W1R("+#O[3.M<?"O"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-#`*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G
M<W1R("+#OR`S,""WUM;3(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S
M-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@X"FUS9VED(")%=F5R>2!M:6YU
M=&4B"FUS9W-T<B`BP[\@,2"WUM;3(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M96UA<"YI;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R("*W
MML#]UK4Z(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C@Q(&%D;6EN+V-M9'-H
M96QL+G!H<#HU,"!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(W"FUS9VED(")%>&5C
M=71E(@IM<V=S='(@(M:TT-`B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HT-S4*;7-G:60@(D5X<&%N9"(*;7-G<W1R("+5N;^J(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHS,@HC+"!F=7IZ>0IM
M<V=I9"`B17AP86YD(%-I9&5B87(B"FUS9W-T<B`BQ.JUUR(*"B,Z(&9R86UE
M=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-C@*(RP@9G5Z>GD*;7-G:60@
M(D5X<&5C=&5D("<I)R(*;7-G<W1R("+6M-#0(@H*(SH@9G)A;65W;W)K+U-1
M3"]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP96-T960@8F%R92!W
M;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER871I
M;VX@1&%T92(*;7-G<W1R("*UO<;:R-4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8W-@IM<V=I9"`B17AP;VYE;G0B"FUS9W-T<B`B
MO>++M=2Q(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS,0HC+"!F=7IZ>0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T
M<B`BU];0S='5R:LB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS
M9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(D944"#)S[2KQ>36
MPRXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<W%L+G!H<#HR,38*;7-G
M:60@(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+B(*;7-G<W1R("*V
MP<BAQJNZP\7DUL/*I[#<(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C<U(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z.3@*;7-G
M:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R
M("+.WK>HP:R]TR!,1$%0(+?^SO'&]RXB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W-M8BYP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--
M0B!S97)V97(N(@IM<V=S='(@(L[>MZC!K+W3(%--0B"W_L[QQO<N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@(KBT
MUL;*I[#<U]0@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z-CDQ"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O
M(%PB)7-<(BXB"FUS9W-T<B`BN+36QLJGL-RUO2!<(B5S7"(N(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O
M(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R("+.WK>HO:C!
MHM*[N/;0PK7$(%-!4TP@P:R]TRXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C0Y-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM
M<V=S='(@(M+&MJ^UO2!<(B5S7"+*I[#<+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z-#8Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&
M86EL960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(M+&MJ^UO2!<(B5S7"+*
MI[#<+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$X"B,L(&9U>GIY"FUS9VED(")&86ER(@IM<V=S='(@(M3ZTL&V^R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S(*;7-G:60@(D9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*2(*
M;7-G<W1R("*WJ,"\O\NXH\BZM;H@*,+MMOO.K,3)R[G(NK6Z*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S,*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`BMZC"WLBZM;HB
M"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C,X"B,L(&9U>GIY"FUS9VED
M(")&871A;"!%<G)O<CHB"FUS9W-T<B`BT<_6V+3MSO,A(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X
M(@IM<V=S='(@(K2KU>8B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S0Y"B,L(&9U>GIY"FUS9VED(")&87AE<R(*;7-G<W1R("*TJ]7F(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@
M(D9E8G)U87)Y(@IM<V=S='(@(K;^U,(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(R,`IM<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R("*XT+[US_'*QR(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*;7-G:60@(D9E
M96QS(&QI:V4Z("(*;7-G<W1R("*XT+[US_'*QSH@(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W
M97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(P"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#0*;7-G:60@(D9I
M96QD(&UA=')I>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,S,T"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,X"B,L(&9U>GIY"FUS9VED
M(")&:6=L970@9F]N="(*;7-G<W1R("+5TK*[M;W.Q+S^(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,@IM<V=I9"`B1FEJ:2(*;7-G<W1R("+LL[S#(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")&:6QE(@IM<V=S
M='(@(L[$O/XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@
M(L[$O/[*_<2_.B`E<R"X]L[$O/XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F
M:6QE<R(*;7-G<W1R("+.Q+S^ROW$OSH@)7,@SL2\_B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT,#<*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G
M<W1R("+.Q+S^N=S`[<;W(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HV,R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<P"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z
M.#4*;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R("+.Q+S^P_NSQB(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y.34*(RP@9G5Z>GD*;7-G:60@(D9I
M;&4@<V5L96-T:6]N(@IM<V=S='(@(LJQQ_C1H=3Q(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30X-@IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T
M<B`BSL2\_LG/M*LB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H
M<#HX-3D*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G
M<W1R("+.Q+S^R<^TJ[FFQ-S.M+&[UJ>SUBXB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z.#D*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`BN?W"R\;W
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,0IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R("*WTL"\(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L9B(*
M;7-G<W1R("+)S[#KU,(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB
M+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S
M='(@(LG/S]+4PB(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR-38*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R("*YS+:HL<C`
M_2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,S$*;7-G:60@(D9L:7`B"FUS9W-T<B`BMZW7JB(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L
M;V%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E
M<R!N;W0@97AI<W0B"FUS9W-T<B`BQ+_"O"`E<R"RN[3FU-HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(R"FUS9VED(")&
M;VYT($-O;&]R(@IM<V=S='(@(M?6T,W1U<FK(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M-@HC+"!F=7IZ>0IM<V=I9"`B1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P
M<&]R="!I;6%G97,B"FUS9W-T<B`BQ/JUQ.2OP,#&][*BSK36I[/6U>*X]KFF
MQ-PN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,S0*;7-G:60@(D9O<F5C
M87-T("A4048I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HW.0IM<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T
M('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N
M:6=H=#L@82`B"B)L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@
M82!W:61E(&)L;V-K*2(*;7-G<W1R("(B"B+4I+&HS.S*_2`HU*2QJ,SLROVP
M_,"HL-?,[-+4O+#2N;SDM<3*_;[=.\CGN?O4I+&HS.S*_;W/LZ2]J]6\T\.Q
MR+W/O^VW^;7$L.8B"B+#YBDB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C$P,@HC+"!F=7IZ>0IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_
M(@IM<V=S='(@(M&AU/'#W,+K(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0V,@IM<V=I9"`B1F]R;7,B"FUS9W-T<B`BM+#,Y2(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*;7-G<W1R("++
MX\/\(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED(")&;W)T
M=6YE('1Y<&4B"FUS9W-T<B`BR^/#_,#@T,TB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S@*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(LOCP_PB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,SD*(RP@9G5Z>GD*;7-G:60@(D9O
M<G1U;F5S(#(B"FUS9W-T<B`BR^/#_"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT-3,*;7-G:60@(D9O<G5M<R(*;7-G<W1R("+"V\RS(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P.0IM<V=I9"`B1F]R=V%R9',B
M"FUS9W-T<B`BU]2VK]>JT,4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R("+0Q\;:SN4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,S"B,L(&9U>GIY"FUS9VED(")&<F%M97,B"FUS9W-T<B`BM+#,Y2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92(*;7-G<W1R("*WJ+GZ(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4L
M($UE=')O<&]L:71A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&
M<F5N8V@@1W5I86YA(@IM<V=S='(@(K>HRO2YY]''Q,<B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M.`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R("*WJ,KTLJ/`^\3A
MSO?1QR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E
M<G)I=&]R:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB"FUS9W-T<B`BO,2\
M_LC+(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T."!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8P"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HT,#8*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R("*T
MTR(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"FUS9VED
M(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(LWJU?O#Z,KV(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G
M:60@(D9U;&P@36]O;B(*;7-G<W1R("+"^M3"(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C8Q('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-C`*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R("+(J\/[(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,PIM<V=I9"`B1V%B;VXB"FUS9W-T<B`BO-/%[B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I
M9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U
M"FUS9VED(")'86UB:6$B"FUS9W-T<B`BN-2QR-''(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T
M92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(K+ZR?H@)7,@M<3/M<VSQ>36
MPR(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS
M9VED(")'96YE<F%T960@0V]D92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS
M9VED(")'96]R9VEA(@IM<V=S='(@(KCQPK.\JM''(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.CDP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM
M<V=I9"`B1V5R;6%N>2(*;7-G<W1R("*UPKGZ(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.CDQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I
M9"`B1VAA;F$B"FUS9W-T<B`BY<C$R2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=I
M8G)A;'1A<B(*;7-G<W1R("+6L;*\PM[-TR(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3<U"FUS9VED(")':79E;B!.86UE(@IM<V=S
M='(@(L/[(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3(*;7-G:60@
M(D=O(@IM<V=S='(@(M>JM;TB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#`*;7-G:60@(D=O961E;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$R.`HC+"!F=7IZ>0IM<V=I9"`B
M1V]O9VQE($UA<',B"FUS9W-T<B`B1V]O9VQE(,O1R_<B"@HC.B!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H(@IM<V=S
M='(@(D=O;V=L92#+T<OW(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(S-PIM<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@(KO2
MML@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W)E96-E(@IM<V=S='(@(L^CP+`B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B1W)E96L@*$E3
M3RTX.#4Y+3<I(@IM<V=S='(@(L^CP+#.Q"`H25-/+3@X-3DM-RDB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<U"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`BN/'!ZL"\(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-`IM<V=I9"`B1W)E;F%D82(*;7-G<W1R("*X\<'6Q,FT[R(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y"FUS9VED(")'<F]U<"!!9&UI;FES=')A
M=&EO;B(*;7-G<W1R("+3P[NGU^FYW,#M(@H*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+G!H<#HU.2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M,38Y"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G
M<W1R("+3P[NGU^G#^[/&LKNUP[_5L-<B"@HC.B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z,S`W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES
M('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B075T:%]L9&%P.B#.
MWK>HT,+4]M/#NZ<@)7,N(+?^SO'&][O8TZ8Z(@H*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C$Q."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HT,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z
M(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS9W-T<B`B075T:%]L9&%P
M.B#.WK>HN/S0PM/#NZ<@)7,B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,S,X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS
M-SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N
M86)L92!T;R!U<&1A=&4@9W)O=7`@)7,B"FUS9W-T<B`B075T:%]L9&%P.B#.
MWK>HN/S0PM/#NZ<@)7,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C,Q-"!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.`HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(M/#
MNZ?7Z2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B
MN<^UPL+>QM6UNB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@
M(KG8M;HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@
M(LZCM=C"[<"M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,@IM
M<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`BN/&V]\[WM;HB"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C@X"FUS9VED(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R("*W
MP[_-R*C/WB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S`*;7-G
M:60@(D=U97-T8F]O:R(*;7-G<W1R("*WP[_-P?31U"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*
M;7-G:60@(D=U:6YE82(*;7-G<W1R("*\N,3:T<<B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*
M;7-G:60@(D=U:6YE82U":7-S874B"FUS9W-T<B`BO+C$VM''L<C)W+FRNLVY
M^B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(KGGT<?$
MQR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDV,`IM<V=I9"`B2%1-
M3"(*;7-G<W1R(")(5$U,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D
M;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S
M97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T
M;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.C$U-PIM<V=I9"`B2%14
M4"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(M72LKNUO2!(
M5%10(-'IUJ0N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(86ET:2(*;7-G<W1R
M("*ZH[78(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S
M"FUS9VED(")(87-H+4%L9V]R:71H;2(*;7-G<W1R("+4T[35+<OCMZ@B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@HC+"!F
M=7IZ>0IM<V=I9"`B2&%Z92(*;7-G<W1R("*Q[<VW(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.3$Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y
M,S(*;7-G:60@(DAE861E<B(*;7-G<W1R("*Q[<VW(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0HC+"!F=7IZ>0IM<V=I
M9"`B2&5A9&5R<R(*;7-G<W1R("*Q[<VW(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED
M(")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',B"FUS9W-T<B`B
MNM6UPKK-PO2UL<#-R+JUNB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(S"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@V"FUS9VED(")(96)R97<@
M*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`BSZ.RKL"TSL0@*$E33RTX.#4Y+3@M
M22DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,T"B,L(&9U>GIY"FUS9VED(")(96EG:'0B"FUS9W-T<B`BS>W)
MSR(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ-SD@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$X-@HC.B!S97)V:6-E<R]H
M96QP+VEN9&5X+G!H<#HQ-R!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z,PIM
M<V=I9"`B2&5L<"(*;7-G<W1R("*P[];Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E
M9&ET;W(B"FUS9W-T<B`BL>"\K<;WRKG3P[#OUOHB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,S<Q"FUS9VED(")(96QP97(B"FUS9W-T<B`BL._6
M^B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0HC+"!F=7IZ>0IM<V=I9"`B
M2&5M:7-P:&5R92(*;7-G<W1R("*QL;#KQ_(B"@HC.B!T96UP;&%T97,O9&%T
M82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ
M,`IM<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*
M;7-G<W1R("+5XL#ORL?.Q+S^M<2_JLJ\.B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"B,L(&9U>GIY"FUS9VED(")(:6=H
M(@IM<V=S='(@(LWMR<\B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC
M.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C4*(RP@9G5Z
M>GD*;7-G:60@(DAO7VUE(@IM<V=S='(@(LK7TK,B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T
M"FUS9VED(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R
M("+H\[79N-0B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U,S4*
M;7-G:60@(DAO;64B"FUS9W-T<B`BRM?2LR(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S
M(@IM<V=S='(@(LK7TK.UV-:W(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C8T"B,L(&9U>GIY"FUS9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R("+$
MO\*\(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$Y,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R("+*U]*SM>>[L"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW.0IM<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`BNNFVO,"MR[DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N9R(*;7-G<W1R("+6T+GZ
MS^.XVR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-0IM<V=I9"`B
M2&]R9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C0T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E
M(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C0S-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@
M;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C$R-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T
M<B`BTM&SR;FFN+*XQR`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z,C(S"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N
M9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C4P,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T
M92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-#<*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S
M(%PB)7-<(CH@)7,B"FUS9W-T<B`B075T:%]L9&%P.B#.WK>HR;ZS_=/#NZ<@
M)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0W-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E
M($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DS"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@
M)7,@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C$S,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<
M(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B
MRZ[&O<_?(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX,@HC+"!F=7IZ>0IM<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM
M<V=S='(@(LNNQKW/WR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#$*(RP@9G5Z>GD*;7-G:60@(DAO<FEZ;VYT86PZ(@IM
M<V=S='(@(LNNQKW/WR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T
M(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0HC+"!F
M=7IZ>0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T
M;R!M97)G93\B"FUS9W-T<B`BU]:VSLK]Q+^YLKS&/R(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@
M*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`BU]:VSLK]Q+^YLKS&/R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@
M;65R9V4_(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS,#`@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S`*;7-G:60@(DAU;6ED
M:71Y(@IM<V=S='(@(LJJML@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C4Y"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@(LJJML@Z("(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G
M<W1R("+0V='`P/LB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H
M<#HQ-S(@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(S-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D
M.B`E<R(*;7-G<W1R("))34%0(-/*S^2]J,&BRJ>PW#H@)7,B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,30@9G)A;65W;W)K+T%U=&@O
M075T:"]C>7)S<6PN<&AP.C(Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0
M(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("))34%0(-/*
MS^3)OK/]RJ>PW#H@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S
M+G!H<#HQ-SD@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(T,@HC
M+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I
M;VX@9F%I;&5D.B`E<R(*;7-G<W1R("))34%0(-/*S^2TQ<7,Q>36P[VHP:+*
MI[#<.B`E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,38*(RP@
M9G5Z>GD*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`BM=C6MR(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D
M9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B25`@M=C6M\[>MZC*N=/#
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z.#D*;7-G
M:60@(DE0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN
M(@IM<V=S='(@(DE0(+78UK>RHK*[U-H@0TE$4B"UQ+W3RMS'^+_IUM`N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDU"FUS9VED("))4"!L;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*;7-G<W1R("*Q^;6Z(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-@IM<V=I9"`B26-O;G,@3VYL
M>2(*;7-G<W1R("+6N]/0S;RQZB(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H
M<#HT.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S
M(@IM<V=S='(@(B5S(+7$T:'/[B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-S<*;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R("+-O+'JO+#.
MQ-?6(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B261E
M;G1I='DG<R!N86UE.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HU.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@
M:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@
M:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#4U"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I
M8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O
M(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N
M8WDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ-S,*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S
M86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A
M9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C@*(RP@9G5Z>GD*;7-G:60@(DEM86=E(%!R979I
M97<Z(@IM<V=S='(@(M2DP,`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,W"B,L(&9U>GIY"FUS9VED("));6%G
M92!54DPB"FUS9W-T<B`BS;S&K"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,0HC+"!F=7IZ>0IM<V=I
M9"`B26UA9V4@55),.B(*;7-G<W1R("+-O,:L(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,R"FUS9VED
M("));6%G92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS
M9VED("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C$*;7-G:60@(DEM86=E('5P;&]A9"(*
M;7-G<W1R("+)S[2KS;S&K"(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W
M"FUS9VED("));6%G97,B"FUS9W-T<B`BS;S&K"(*"B,Z('1E;7!L871E<R]D
M871A+W1S=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z
M-PHC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4T('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T
M+"!3=&5P("5D(@IM<V=S='(@(KOCR.LL(+*]UN@@)60B"@HC.B!T96UP;&%T
M97,O9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("))
M;7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`BN^/(Z]?6MLXZ("5S(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T960@
M9FEE;&1S.B(*;7-G<W1R("*[X\CKU]:VSCHB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN
M7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP
M<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S-0IM<V=I9"`B26YC;W)R96-T(&%C
M=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R("+*Y,CKLKO5_<BWM<37]]/#PNLN
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,S(*(RP@9G5Z>GD*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O
M;W(@<&%S<W=O<F0N(@IM<V=S='(@(LZTUJJUQ-/#NZ?#^[ORP]S"ZRXB"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC
M;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A
M:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE
M960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S92!)
M;F1E;G0B"FUS9W-T<B`BU/:\T\OUQ<4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@
M(DEN9&EA(@IM<V=S='(@(M.AML@B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C(U-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM
M<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R("*X]K'PT\.[IR(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,`IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(M.AMLC$X<[W
MT<<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP
M.C8W"FUS9VED("));F9O(@IM<V=S='(@(M#%SZ(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C4W"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R
M("+0Q<^B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,S,`IM
M<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C`*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!);6%G
M92(*;7-G<W1R("*RY<CKT\J\_B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G
M<W1R("*RY<CKL>VX\2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C4*;7-G:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R
M("*RY<CKS?C"Y\&LO=,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G:60@(DEN<V5R="!?0V]L=6UN
M($)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(DEN<V5R="!A(&YE
M=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U
M<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,@IM<V=I9"`B26YS97)T(&$@
M;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8Q"FUS9VED("));G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N
M="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C<P"FUS9VED("));G-E<G0@82!P87)A
M9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-CD*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E
M;G0@;F]D92(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U
M,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("*R
MY<CKO\G,YK3ZQ*.PYB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,SD*
M;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C
M86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X
M"B,L(&9U>GIY"FUS9VED("));G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R("*R
MY<CKT\J\_B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-3D*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!C96QL(&)E
M9F]R92(*;7-G<W1R("*RY<CKL>VX\2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C
M;VQU;6X@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O
M;'5M;B!B969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.3`*;7-G:60@(DEN<V5R="!M97-S86=E<R(*
M;7-G<W1R("*RY<CKT\J\_B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-0IM<V=I9"`B26YS97)T('!A<F%G
M<F%P:"!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P
M87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*(RP@9G5Z>GD*;7-G
M:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`BLN7(Z['MN/$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8X
M"B,L(&9U>GIY"FUS9VED("));G-E<G0@<F]W(&)E9F]R92(*;7-G<W1R("*R
MY<CKL>VX\2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S`*;7-G:60@
M(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q
M=65S=&EO;CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR-@IM<V=I9"`B26YS97)T+TUO9&EF>2!);6%G
M92(*;7-G<W1R("*RY<CK+['DN/S-O,:L(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF
M>2!,:6YK(@IM<V=S='(@(K+ER.LOL>2X_,WXPN?!K+W3(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@
M(DEN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T
M:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("));G-U9F9I8VEE;G0@
M8W)E9&ET+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,#<U"FUS9VED("));G1E9V5R(@IM<V=S='(@(M7[ROTB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3,S"FUS9VED("));G1E9V5R(&QI<W0B
M"FUS9W-T<B`BU?O*_<'0(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("));G9A;&ED(%5$2"X@*%5S
M97(@1&%T82!(96%D97(I+B(*;7-G<W1R("+.WM"GM<0@541(*-/#NZ?*_;[=
ML>W-MRDN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP
M:'`Z,3<P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP
M.C(P,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR
M,3`*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`B
MSM[0I[7$S?+3P\+KROV^W2XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R("+.WM"G
MM<33IM/#L\S0\BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM
M<V=S='(@(L[>T*>UQ,7ZM,ZZQ<+K+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U.`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C,R(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R.3D*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE
M<V5T+G!H<#HS-PIM<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS
M9W-T<B`BS.&]N[7$ROV^W<[>T*<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED("));G9A;&ED(&1E
M<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(L[>T*>UQ,2_L>K7H=:W(@H*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z.#$*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,3`P"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C(R,`IM<V=I9"`B
M26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R("*RN[K/MZBUQ,[$O/ZX\<J]
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-PHC+"!F=7IZ
M>0IM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS9W-T<B`BSM[0I[7$
MTZ;3P[/,T/(N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W
M,0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB
M"FUS9W-T<B`BSM[0I[7$TZ;3P[/,T/(N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("));G9A;&ED
M(&US9U]T>7!E+B(*;7-G<W1R("+.WM"GM<0@;7-G7W1Y<&4N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S"FUS
M9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*;7-G<W1R("+.WM"G
MM<2[\M72LKNUO2!A<&E?:60N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI
M<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`BSM[0I[7$N_+5TK*[M;VRSLK]
M+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR-PIM<V=I9"`B26YV
M86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`BLKNZS[>HM<2XN,BH
MS]XN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W,PHC+"!F
M=7IZ>0IM<V=I9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R("*RN[K/
MMZBUQ+BXR*C/WBXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3<U"B,L(&9U>GIY"FUS9VED("));G9A;&ED('!R;V1U8W0@8V]D92XB"FUS
M9W-T<B`BSM[0I[7$S:C1MM"MTNDN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED("));G9A;&ED('!R
M;W1O8V]L+B(*;7-G<W1R("+.WM"GM<3-J-&VT*W2Z2XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HX,`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R("+.
MWM"GM<2PYK&^NL7"ZR(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,3`W-B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-C(*(RP@9G5Z>GD*
M;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S='(@(K*[NL^WJ+7$
MSL2\_KCQRKTB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#$*;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N
M(@IM<V=S='(@(L[>T*>UQ,"TU+37H=:W+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0IM<V=I9"`B26YV86QI
M9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@(L[>T*>UQ,WRT\/"Z\K]OMTN(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U-PIM<V=I9"`B26YV96YT
M;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HV-SD*(RP@9G5Z>GD*;7-G:60@(DEN=F5R="!S96QE8W1I
M;VXB"FUS9W-T<B`BO/3'T-&AU/$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DER
M86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`BTL'`RM+!R[G`O+FR
MNLVY^B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("+2P<"M
MO\LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS9W-T<B`BL*ZV
M^\"\(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34*;7-G:60@
M(DES;&4@;V8@36%N(@IM<V=S='(@(L+\M;HB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O;&%T960@5"U3
M=&]R;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<W)A96PB
M"FUS9W-T<B`BTM3)J\'0(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV,C4*;7-G:60@(DES<W5E<B(*;7-G<W1R("+'J;>BU=\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*;7-G
M:60@(DET86QI8R(*;7-G<W1R("+0L<SE(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED
M("))=&%L>2(*;7-G<W1R("+2XK3SP/LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@
M(DIA;6%I8V$B"FUS9W-T<B`BT<#"\KS3(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,0HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T
M<B`BTKO4PB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F%P86XB"FUS9W-T<B`B
M2F%P86X@*,C5L;XI(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*;7-G
M:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`BR-7.Q"`H25-/
M+3(P,C(M2E`I(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*
M;7-G:60@(B(*(DIA=F%S8W)I<'0@:&%S(&)E96X@9&ES86)L960@;VX@>6]U
M<B!B<F]W<V5R(&%N9"!T:&ES('!A9V4@;6%Y(&YO="!B92`B"B)D:7-P;&%Y
M:6YG(&-O<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R("+4\\[WM;HB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R("+4O+6I(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-PHC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G
M:60@(DIU;'DB"FUS9W-T<B`BQM_4PB(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S='(@(L'Y
MU,(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,X"B,L(&9U>GIY"FUS9VED(")*=7-T:69Y(@IM<V=S='(@(K^_
MU_.VU,;K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@
M(M;#UM`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(M?S
MT]*VU,;K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,30*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R("*_
MO]?SMM3&ZR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$V"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@
M(K^_T]*VU,;K(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM
M<V=S='(@(KG^R/B_R\NYS+DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C8T"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G
M<W1R("*QH\'TU*W1^2`_(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*
M;7-G<W1R("*_S\3AT<<B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N
M<&AP.C@U"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(DME<F)E<F]S(,C/UJ2T[<[S+B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#$Q"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`BP]S4O[VHP:(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@(DME
M>2!&:6YG97)P<FEN="(*;7-G<W1R("+#W-2_S-C5]R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*
M;7-G<W1R("+#W-2_LZ2VR"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`BP]S4O\#@T,TB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.`IM<V=I
M9"`B2V5Y(%5S86=E(@IM<V=S='(@(L/<U+_3[[>H(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S0P"FUS9VED(")+97D@86QR96%D>2!E
M>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(K6QQ["U
MQ+FKOZK#W-2_M_[.\<;WUM`LTM&^K;3FU-K$^K7$P]S4ORXB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,CD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@T"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R("*[^<#OL,W+
MN;FRNLVY^B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T
M:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`BLZ_/RB(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(KJK
MN?HB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B2V]R96%N
M("A%54,M2U(I(@IM<V=S='(@(KJKSL0@*$550RU+4BDB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R("*_QLW^S-@B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`BO*JV^[RJR[G,N2(*"B,Z
M('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B
M3&%?>6]U="(*;7-G<W1R("*PYL/FQ>36PR(*"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(M/OT=0B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G<R!$96UO8W)A=&EC
M(%)E<'5B;&EC(@IM<V=S='(@(L#/SLXB"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,38Y"FUS9VED("),87-T($AA;&8B"FUS9W-T<B`BS\*PZ]3"(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<V"B,L(&9U>GIY"FUS9VED("),87-T
M(%!A<W-W;W)D($-H86YG92(*;7-G<W1R("+#W,+K.B`B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED("),
M87-T(%%U87)T97(B"FUS9W-T<B`BS\+/TM3"(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ-3$*;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`BR<^T
MSKC\T,(Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(LG/TKNT
MSK7'PKPZ("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S(Q"B,L
M('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS
M9W-T<B`BR<_2N[3.M<?"O#H@)7,@U]0@)7,B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HW,38*;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S
M='(@(LG/TKNTSK7'PKPZ(+7:TKNTSK7'PKPB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G
M:60@(DQA='9I82(*;7-G<W1R("+`K<W1SJS1QR(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0IM<V=I
M9"`B3&%Y;W5T(@IM<V=S='(@(K#FP^;%Y-;#(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP
M='D@9F]R(&YO(&)O<F1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G
M:60@(DQE8F%N;VXB"FUS9W-T<B`BP.BPS<3;(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"B,L(&9U>GIY"FUS
M9VED("),969T(@IM<V=S='(@(M?STL8B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,3$Y"FUS9VED("),969T(&AE861E<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$U"B,L(&9U>GIY"FUS9VED
M("),969T('9A;'5E<R(*;7-G<W1R("*_U;#7UK4B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*
M;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`BP+/+]\W0(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED("),979E;"(*
M;7-G<W1R("*TT\ZT(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:6)E<FEA(@IM
M<V=S='(@(L#[L<C`[]''(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:6)Y86X@
M07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(L#[L<C1QR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("+!T-:GMMC*O[7'(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*(RP@
M9G5Z>GD*;7-G:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`BM:W`MB(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"B,L(&9U
M>GIY"FUS9VED("),:6=H="!286EN(@IM<V=S='(@(K7'PKPB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG
M:'0@4F%I;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B!,871E
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,`IM
M<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*(RP@9G5Z
M>GD*;7-G:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`BM:W`MB(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED("),:6=H
M="!3;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#4*(RP@9G5Z>GD*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(L#[
ML<C`[]''(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q-`IM<V=I
M9"`B3&EN:R(*;7-G<W1R("+!K+W3(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O
M:6YT<R!T;SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@W-0IM<V=I9"`B3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@
M8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@S
M"FUS9VED("),:6YK<R(*;7-G<W1R("+!K+W3(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0V"FUS9VED("),:6YU>"!#;V]K:64B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G
M:60@(DQI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R("+!
MT+/V("T@T\.[I[_)TM2_M+6]U>*X]L[$O/Z\T"(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HQ,S,*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4P"FUS9VED("),:7-T($AE
M;'`@5&]P:6-S(@IM<V=S='(@(L'0L_;+M</WL>K,XB(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,S(*(RP@9G5Z>GD*;7-G:60@(DQI<W0@5&%B;&5S(@IM
M<V=S='(@(K+ER.NQ[;CQ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D
M97)S+G!H<#HU.30*;7-G:60@(DQI<W0M07)C:&EV92(*;7-G<W1R("+,UL+;
MT\.[I]?I+<[$O/ZY\2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R
M<RYP:'`Z-3@Y"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`BS-;"V]/#NZ?7
MZ2W'\];Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU
M.38*;7-G:60@(DQI<W0M260B"FUS9W-T<B`BS-;"V]/#NZ?7Z2W*MK'PNL7"
MZR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DR"FUS
M9VED("),:7-T+4]W;F5R(@IM<V=S='(@(LS6PMO3P[NGU^DMT[73T-7?(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3,*;7-G:60@
M(DQI<W0M4&]S="(*;7-G<W1R("+,UL+;T\.[I]?I+;S$O/[(RR(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DQ"FUS9VED("),:7-T
M+5-U8G-C<FEB92(*;7-G<W1R("+,UL+;T\.[I]?I+;:IU,0B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,`IM<V=I9"`B3&ES="U5
M;G-U8G-C<FEB92(*;7-G<W1R("+,UL+;T\.[I]?I+<BAS_NVJ=3$(@H*(SH@
M861M:6XO<V5S<VEO;G,N<&AP.C4P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED("),:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,B"FUS9W-T<B`BP="S
M]M/#NZ>UQ+FFQ-RQN[G8L=4B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S4*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I
M;&5D.B`E<R(*;7-G<W1R("+!T+/VT\.[I[7$N:;$W+&[N=BQU2(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN
M9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`BP="S]M/#NZ>UQ+FFQ-RQ
MN[G8L=4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G:60@(DQI
M=&5R871U<F4B"FUS9W-T<B`BSL31IR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B
M3&ET:'5A;FEA(@IM<V=S='(@(L&BS-7-\"(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.#,*(RP@9G5Z>GD*;7-G:60@(DQO
M861I;F<N+BXB"FUS9W-T<B`BU-C(Z[JORKV_XM;0+BXN(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,0IM<V=I9"`B3&]C86P@=&EM93H@
M(@IM<V=S='(@(K6QM=C*L;SD.B`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#,*;7-G:60@(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R("*UV,?XT^O*
ML;SD(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S$@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8T"B,Z(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP.C8U"FUS9VED("),
M;V-A=&EO;B(*;7-G<W1R("*UV,?X(@H*(SH@;&]G:6XN<&AP.C$W,B!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3DQ('1E;7!L871E<R]L;V=I;B]M
M;V)I;&4N:6YC.C,*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY,`IM<V=I9"`B3&]G(&EN(@IM
M<V=S='(@(K7'PKPB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M-#4*;7-G:60@(DQO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$X-0IM<V=I
M9"`B3&]G(&]U="(*;7-G<W1R("+7HL_Z(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C4Y"FUS9VED("),;V=I;B(*;7-G<W1R("*UQ\*\(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$P-PHC+"!F=7IZ>0IM<V=I9"`B3&]G:6X@
M5&%S:W,B"FUS9W-T<B`BP:R]TR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.CDY-@IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R
M;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS
M9W-T<B`BM<?"O,JGL-PL(,?KO.RRZ<3ZM<33P[NGP_NZS</<PNLL(,B[NO/6
MV,K4+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY,@IM<V=I9"`B
M3&]G:6X@9F%I;&5D+B(*;7-G<W1R("*UQ\*\RJ>PW"XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,S8U"B,L(&9U>GIY"FUS9VED("),;VYG('1E
M>'0B"FUS9W-T<B`BUZ+/^B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M.`HC+"!F=7IZ>0IM<V=I9"`B3&]V92(*;7-G<W1R("+)OK/](@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(DQO
M=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T
M97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE
M='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@
M;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M
M8F]U<F<B"FUS9W-T<B`BPJS)K;&D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P,`HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#,X('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P
M"FUS9VED(")-32(*;7-G<W1R("+4PB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR.#$*;7-G:60@(DU/5$0B"FUS9W-T<B`BP[_(U=#%SZ(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I
M9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G
M<W1R(")-4RU43D5&(+B]O-/.Q+S^UM##N]/0ROV^W2XB"@HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N
M<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B35-'(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR
M"FUS9VED(")-86-A;R(*;7-G<W1R("+6T+GZL,3#Q2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,0IM<V=I9"`B36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(L+MQN2VV;FRNLVY^B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM
M<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R("+"[;3OO-/+N;S3M;HB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*(RP@9G5Z>GD*;7-G:60@(DUA9VEC
M(@IM<V=S='(@(L+MP/LB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M.#$*;7-G:60@(DUA:6PB"FUS9W-T<B`BT\J\_B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HU,C(*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`B
MT\J\_KG<P.TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QA=VDB"FUS9W-T<B`BPNW`
MK<W^(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-86QA>7-I82(*;7-G<W1R("+"
M[<"TSO?1QR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T
M<B`BPNVV^[3ZM_(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA;&DB"FUS9W-T
M<B`BPNW`^R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L=&$B"FUS9W-T<B`B
MPNVV^LO[(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ"FUS9VED("(B
M"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L
M86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@=VET
M:"!T:&]S92!C871E9V]R:65S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U,PIM<V=I9"`B36%P,C0@
M;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,#@T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,38X"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-
M87!P:6YG<R!S=&]R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#,*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED(")-87)C:"(*;7-G<W1R
M("+(_=3"(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT,0HC+"!F=7IZ>0IM<V=I9"`B36%R9VEN(@IM<V=S='(@
M(L+MS.'$X;_+M;HB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L86=S
M(@IM<V=S='(@(K'JO,>SR2"_M+G]+\ZTO[2Y_2(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K('=I=&@@
M;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R
M("*QZKS'L\G&Y,O\M<3*MK'P("C`_<CG+B#6V-*J+]+1N]BXM"DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3$*;7-G:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`BPNW)
MW+;[R+JUNB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R=&EN:7%U92(*;7-G
M<W1R("+"[<SAQ.&_R[6Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN
M8SHQ,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R("+5_=3:QJ7%
MY-?6MLXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T
M<B`BPZO`[\O^Q.'1QR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S
M(@IM<V=S='(@(L.KP._'\\NY(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED(")-87@@86QL;W=E9"!C
M<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@<&%R
M=',@97AC965D960N(@IM<V=S='(@(KB]O/[*_<2_TM&SK+/VO=/*W,G/S]XN
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@(DUA>"!T96UP
M(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("+7[KW\(#(T(-"ARK&UQ-?NN-_.
MPK;(.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y.`IM<V=I9"`B36%X
M('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`BU^Z]_"`V(-"ARK&UQ-?N
MN-_.PK;(.B`B"@HC.B!L:6(O87!I+G!H<#HX-@IM<V=I9"`B36%X:6UU;2!.
M=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HX.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3(Q-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y"FUS9VED(")-
M87AI;75M(&QE;F=T:"(*;7-G<W1R("*]T\K<U^ZT\[.DML@B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y
M(@IM<V=S='(@(L[EU,(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")-87EO='1E
M(@IM<V=S='(@(L+MU+S,V,BZM;HB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(M"[OO@B
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED
M(")-96UB97)S(@IM<V=S='(@(K/)U+$B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S<X"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S='(@(M&AM:7$H\J]
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T
M871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U
M"FUS9VED(")-97-S86=E(@IM<V=S='(@(M/*O/XB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S<V%G92!6
M97)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I
M8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(M/*O/[1
MZ=:DTM'-ZK/)++6KRL?3P[NGM<3'J</[R+3.WK>HS:BY_='IUJ0N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P
M"FUS9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(M#%SZ+2T;G]QMHN
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,#(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C(W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(V,`IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@
M(M#%SZ+`X-#-(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"B,L(&9U>GIY
M"FUS9VED(")-971A<B!796%T:&5R(@IM<V=S='(@(K6QQ[#,[,;X(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO8VL@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B365T87(@Q_B_Z<[>MZC*N=/#+B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3$R"FUS9VED("(B"B)-971A<B!B;&]C
M:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R
M('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")-971A<B#'^+_ISMZWJ,JY
MT\,N(,^XO=K'Z[+.O[S/M<VSN=S`[;7'PKPN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$V-0IM<V=I9"`B365T87)$0B!I<R!N;W0@8V]N
M;F5C=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C8W(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R("*WO;>H(@H*(SH@9G)A
M;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HX,2!F<F%M97=O<FLO4E!#+U)0
M0R]S;V%P+G!H<#HQ,3<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DUE
M=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`BM[VWJ"`G)7,G
M(,ZTL;NVJ-+E(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL
M960@;65T:&]D.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-0IM<V=I9"`B
M365T<FEC(@IM<V=S='(@(KFKUL8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$V-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUE
M>&EC;R(*;7-G<W1R("+$J\[WN.<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC
M<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(*;7-G<W1R("+#W+_+PM[$
MX<[WT<?!JK#NN?HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S8*(RP@9G5Z>GD*;7-G:60@(DUI9&1L92(*;7-G
M<W1R("+$H[_I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE
M9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*;7-G<W1R(")-:6UE(,#@T,TB
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,`IM<V=I9"`B36EN('1E;7`@
M;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(M?NO?P@,C0@T*'*L;7$U^ZUS<["
MML@Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`R"FUS9VED(")-:6X@
M=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("+7[KW\(#8@T*'*L;7$U^ZX
MW\["ML@Z("(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#,Y
M"FUS9VED(")-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I
M<F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,S0*;7-G:60@(DUI<G)O<B(*;7-G<W1R("+3L\GD(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Q"FUS9VED(")-:7-C96QL86YE
M;W5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA
M9V4@2%144%]297%U97-T+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3$U"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN
M(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U
M<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB"FUS9W-T<B`BQ>36P\[$O/[2Q<JG
M+B#(Y[G[TJK*N=/#U>*X]M.FT\.SS-#RQ/JQV-#KS];4VK[-LOK)^LO[+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R("+5TK*[
MM;W0Q<^BM<0@240N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F
M;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@
M4$5!4B!P86-K86=E($UA:6PN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES
M<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R("+5TK*[M;V[X<;:M<0@240N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-@IM
M<V=I9"`B36\B"FUS9W-T<B`BT,?&VM*[(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C<T"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R("+0T+:O
MT\J\_B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8X"B,L(&9U>GIY"FUS9VED(")-;V1E<F%T92(*;7-G<W1R("+#R<S8R/O`
MK<S8(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV
M-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#@*;7-G:60@(DUO
M9&EF:65D($1A=&4B"FUS9W-T<B`BN/S0PLC5QMHB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*;7-G:60@
M(DUO9&EF>2!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV-S,*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`BQ*._
MZ2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B
M"FUS9W-T<B`BQ*:V^[;@S=\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;F%C
M;R(*;7-G<W1R("+$IL3)N.<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O
M;&EA(@IM<V=S='(@(L/)N<4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-3DT"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R("+4PKK-Q.HB
M"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4W
M"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(L._U,(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*
M;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`BP\G,V,C[P*W,V"(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I
M9"`B36]O;B!0:&%S97,B"FUS9W-T<B`BU,+!P=.OO_<B"@HC.B!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HQ-S(@9G)A;65W;W)K+T9I;&5?0U-6+T-3
M5BYP:'`Z,C4S"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@9FEE;&1S(&9O
M=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R("+$IL+E
MN.<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M,PIM<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED(")-;W-T;'D@
M0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`Y"FUS
M9VED(")-;W9E($1O=VXB"FUS9W-T<B`BS\+2QB(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C4Q,PIM<V=I9"`B36]V92!,969T(@IM
M<V=S='(@(M?STL8B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HU,3<*;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`BT]+2QB(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4P-0IM<V=I9"`B
M36]V92!5<"(*;7-G<W1R("+)S]+&(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`IM<V=I9"`B36]V92!D;W=N(@IM<V=S
M='(@(L_"TL8B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-3(S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HU,C0*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`BR<_2QB(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-0IM<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R("+$JLFCL<B_RR(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#0*(RP@9G5Z>GD*;7-G
M:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R("+/PL"M
MLLNUI2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,#4U"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T,@IM<V=I9"`B375L=&EP;&4@
M<V5L96-T:6]N(@IM<V=S='(@(KBTT:$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#`P"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@(L[2M<35
MR[K%(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X"B,L(&9U>GIY"FUS
M9VED(")->2!!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(L3ZM<30Q<^B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HU-`IM<V=I9"`B37D@
M4&]R=&%L(@IM<V=S='(@(L[2M<3#Q;NG(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+V5D:70N<&AP.C$S-@IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R
M("+.TK7$P\6[I]*SP^;%Y-;#(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-38*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")->6%N
M;6%R(@IM<V=S='(@(L/EM>DB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O
M;6%I;G1E;F%N8V4N:'1M;#HU-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E
M(@IM<V=S='(@(K*[+,[2LKO-K-+B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#$Q(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE
M9BYP:'`Z,S@*;7-G:60@(DYA;64B"FUS9W-T<B`BP_NSQB(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R("+$R</7L<C1QR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`BZ*?"LR(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`BQ.&RM+;[(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDW"FUS9VED(").971H97)L86YD<R(*;7-G<W1R("*ZR<"\(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$V,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3<*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@(KK)
MRO2PLK78P=#+N2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3@Q"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R("*[^=/:
M3F5T<V-A<&4@M<3-^-:W(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.#,*(RP@9G5Z>GD*;7-G:60@(DYE='-C87!E($-!(%)E=F]C
M871I;VX@55),(@IM<V=S='(@(KOYT]I.971S8V%P92"UQ,WXUK<B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-0HC+"!F=7IZ>0IM
M<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R("*[^=/:3F5T
M<V-A<&4@M<3-^-:W(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.#0*(RP@9G5Z>GD*;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),
M(@IM<V=S='(@(KOYT]I.971S8V%P92"UQ,WXUK<B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,@HC+"!F=7IZ>0IM<V=I9"`B3F5T
M<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`BN_G3VDYE='-C87!E(+7$
MS?C6MR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V
M"FUS9VED(").971S8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B3F5T
M<V-A<&4@4U-,(+?^SO'&]\/[L\8B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@
M8V]M;65N="(*;7-G<W1R(").971S8V%P92#(S]:DM<3%^M>B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#`*;7-G:60@(DYE='-C
M87!E(&-E<G1I9FEC871E('1Y<&4B"FUS9W-T<B`B3F5T<V-A<&4@R,_6I,#@
MT,TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4Q"FUS9VED(").
M971W;W)K(@IM<V=S='(@(LWXPN<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-0HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V"FUS9VED(").979E<B(*;7-G<W1R
M("*TT\ZT(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").97<@0V%L961O;FEA(@IM
M<V=S='(@(M#"OZ;`[[;@Q.'1QR(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C(V"B,L(&9U>GIY"FUS9VED(").97<@
M0V%T96=O<GDB"FUS9W-T<B`BT,*_IL#OMN#$X=''(@H*(SH@9G)A;65W;W)K
M+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@Q"B,Z(&9R86UE=V]R
M:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HX-PHC.B!F<F%M97=O
M<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.3<*(SH@9G)A;65W
M;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C$P,0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B3F5W($UE<W-A9V4@=&\@)7,B"FUS9W-T
M<B`BT,7/HL#@T,TB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L
M;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*;7-G:60@
M(DYE=R!-;V]N(@IM<V=S='(@(M#"U,(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO
M;F%L*2(*;7-G<W1R("+0PM/#NZ?#^R`HM\>QV-*J*2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M.`IM<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`BT,+.]\"\(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,W"B,L(&9U>GIY"FUS9VED(").
M97<@<&%S<W=O<F0B"FUS9W-T<B`BP]S"ZR(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A
M<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*(RP@9G5Z>GD*;7-G:60@(DYE
M=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(L/<PNNQV-#KSL>Z
MSRXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDQ"FUS9VED(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(M#"M+"_
MVB`H7V)L86YK*2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C@Y"FUS9VED(").97=S(@IM<V=S='(@(M#"SL4B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S`U"B,L(&9U>GIY"FUS9VED(").97=S9W)O
M=7!S(@IM<V=S='(@(M/#NZ?7Z2(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN
M9F\N:6YC.C$U('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0Q"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C(U"FUS9VED(").97AT(@IM<V=S='(@(L_"TKNRO2(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B3F5X="`T
M(%!H87-E<R(*;7-G<W1R("+/PM*[TK,B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C,W,B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C,W-@IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@(L_"TKNX]M&AS^XB
M"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C$P,PHC+"!F=7IZ>0IM
M<V=I9"`B3F5X=#XB"FUS9W-T<B`BS\+2N[*](@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS
M9VED(").:6-A<F%G=6$B"FUS9W-T<B`BQ.&\T\"MN<\B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.38*;7-G:60@(DYI9V5R(@IM<V=S='(@(L3AR-6V^R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-@IM<V=I9"`B3FEG97)I82(*;7-G<W1R("+$X<C5P/O1QR(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.#`*;7-G:60@(DYI9VAT(@IM<V=S
M='(@(LWMR<\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYI=64B"FUS9W-T<B`B
MQ::PH[6Z(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.CDV,PHC+"!F=7IZ>0IM<V=I9"`B3F\B"FUS9W-T<B`BSMXB"@HC.B!T
M96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V
M86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E
M<R!F;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<BYP:'`Z,3`U"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E
M9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G
M:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW.2!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HR-#4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z,C8W"FUS9VED(").;R!B;&]C:R!E>&ES=',@870@=&AE
M(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R("++^=:XMJBUQ,Z[UL/)S\.[
MT]#'^+_IM.;4VB(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z
M-3`*;7-G:60@(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(L.[T]#,X;FIR-7`^L/[L\;2U+FI
M($U#04P@T>G6I"XB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`HC+"!F
M=7IZ>0IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R("+.M+'DN/PN(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*(RP@9G5Z>GD*;7-G
M:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I
M;VXN(@IM<V=S='(@(K6QQ[#+^;2FM<35XKCVM<B\ML[>MZC4]KS3M,[(J,_>
M+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38W(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z-3`R"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN
M<&AP.C<W,PHC+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@(L.[T]#6
MN+:HM<0@)7,@Q>36P]#%SZ(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX,C0*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R("+#N]/0UKBVJ+7$($94
M4"!61E,@Q>36P]#%SZ(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HV-CD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R("+#N]/0UKBVJ+7$(%-13"!6
M1E/%Y-;#T,7/HBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z-S$W"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R("+#N]/0UKBVJ+7$
M(%-13"U&:6QE(%9&4\7DUL/0Q<^B+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET
M(&QE9G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"B,L(&9U>GIY"FUS9VED(").;R!D97-T
M:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`BP[O3T,/HRO8B"@HC.B!F<F%M
M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-S<*;7-G:60@(DYO(&9I;&4@
M=7!L;V%D960B"FUS9W-T<B`BSL2\_LZTR<^TJR(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N
M(@IM<V=S='(@(L.[T]##Z,KV(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$R."!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ,C,*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB
M"FUS9W-T<B`BSKO6P]#%SZ+)T,ZTQ>36PR(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@(DYO(&QO8V%T:6]N
M('!R;W9I9&5D+B(*;7-G<W1R("+.N];#T,7/HLG0SK3%Y-;#(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*(RP@
M9G5Z>GD*;7-G:60@(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(M#%
MSZ+2T;G]QMHN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S8*(RP@9G5Z>GD*;7-G:60@(DYO(&YA;64@<W!E8VEF
M:65D+B(*;7-G<W1R("+.M-:XMJBUL;78T^_1U"XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PHC+"!F=7IZ>0IM
M<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`BSK36N+:HM;&U
MV-/OT=0N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS9VED(").
M;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(L.[T]#6
MN+:HP]S"Z]+4N:D@2%144"#1Z=:D+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BP[O3T-:XMJC#W,+K
MTM2YJ2!)34%0(-'IUJ0N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U
M+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E
M<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+#N]/0UKBVJ,/<PNO2U+FI
M($ME<F)E<F]S(-'IUJ0N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L
M+G!H<#HW-R!F<F%M97=O<FLO075T:"]!=71H+VQO9VEN+G!H<#HX-`HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-S4*;7-G:60@(DYO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`BP[O3T-:XMJC#W,+KTM2YJ2!,;V=I;B#1Z=:D+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<&%S<W=D+G!H<#HQ,S4*;7-G:60@(DYO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(L.[T]#6N+:HP]S"Z]+4N:D@4$%34U=$(-'IUJ0N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]S;6(N<&AP.C@T"FUS9VED(").;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+#N]/0UKBV
MJ,/<PNO2U+FI(%--0B#1Z=:D+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,3(X-@IM<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E
M;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N
M96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM
M<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R("+#N]/0M/W)\[7$
MUZ*RX<GJQ^LN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C<U,`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R
M("+.N];#T,7/HLG0SK3%Y-;#(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PHC+"!F=7IZ>0IM<V=I9"`B3F\@
M<G5L97,B"FUS9W-T<B`BO]6PU]:U(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z-#0Y"B,L(&9U>GIY"FUS9VED(").;R!S97!A<F%T;W(@<W!E
M8VEF:65D+B(*;7-G<W1R("+.M-:XMJBUL;78T^_1U"XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T"B,L(&9U
M>GIY"FUS9VED(").;R!S:61E<R(*;7-G<W1R("*QN,W\PKPB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X,PIM<V=I9"`B3F\@<W5C:"!F:6QE
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M,S@*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O
M<B!C86-H92XB"FUS9W-T<B`BSM[4W;3FQ+_"O+_)N:F_[,BA+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"B,L(&9U
M>GIY"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB
M"FUS9W-T<B`BSK36JK7$T\.[I\/[N_+#W,+K+B(*"B,Z(&9R86UE=V]R:R]2
M4$,O4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED(").;R!V86QI9"!834P@9&%T
M82!R971U<FYE9"(*;7-G<W1R("+#N]/0NL^WJ+7$(%A-3"#*_;[=L;NTJ[O8
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW
M,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@Q
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY.3(*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,#D*
M;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R("*_U;#7UK4B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN
M(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`BU*W*O,7DUL/.Q+S^UM#5TK*[M;VPYK&^T,7/HBX@
MUMC0PK+ZR?K%Y-;#SL2\_BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3(X"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A
M=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+4VL3Z
MM<3%Y-;#SL2\_M;0U=*RN[6]L.:QOM#%SZ(N(-;8T,*R^LGZQ>36P\[$O/XN
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*
M(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,PIM<V=I
M9"`B3F]N92(*;7-G<W1R("+.WB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I
M="DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G
M:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(LC5MOK"_,[$("A)
M4T\M.#@U.2TQ,"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L
M86YD(@IM<V=S='(@(L6UN*._R[6Z(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M
M:7-P:&5R92(*;7-G<W1R("*QL;#KQ_(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$U."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@
M(DYO<G1H97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R("*QL<+MP._1Q\3)
MR+JUNB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM<V=S='(@(L6R
MS?XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,`IM
M<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(K?'UJZZ\R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(").;W0@0F5F;W)E
M(@IM<V=S='(@(K?'UJ['L"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C0P.`IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@(K*[RL?2
MN[CVQ+_"O"(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<BYP:'`Z-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#,*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.30*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+G!H<#HT.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"B,L(&9U>GIY"FUS
M9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@(LG0SK3*M<_6+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*(RP@
M9G5Z>GD*;7-G:60@(DYO="!S970B"FUS9W-T<B`BL;C-_,*\(@H*(SH@9G)A
M;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#,*
M(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H
M<#HQ-3@*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD
M;&5R+G!H<#HQ-S,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I
M;VY(86YD;&5R+G!H<#HQ.#<*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R
M+U-E<W-I;VY(86YD;&5R+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C$Y,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C`U(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(T."!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,C8U"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(Y-PHC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z,S$R(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,CD*
M(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,V,B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z-#(R"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU,#$@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C4W,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M-3@W(&9R86UE=V]R:R]61E,O5D93+G!H<#HV-C4*;7-G:60@(DYO="!S=7!P
M;W)T960N(@IM<V=S='(@(LZTL;O6I[/6(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(T-"!C;VYF:6<O:&]O:W,N<&AP+F1I
M<W0Z,3`P-0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3<X"FUS9VED
M(").;W1E<R(*;7-G<W1R("*QN,W\PKPB"@HC.B!S97)V:6-E<R]O8G)O=W-E
M<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B
M86-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`BRJ[2N]3"
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`T-@IM<V=I9"`B3G5M
M8F5R(@IM<V=S='(@(LK]U]8B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-#(U"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R("+7
MUK?[ROTB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8Y(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C,*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,30T-2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P-`IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`BU]:V
MSLK]Q+\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8W(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,30T,R!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`BL<K*_2(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C0T"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG
M(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM
M<V=S='(@(D]+(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C@W,PHC+"!F=7IZ>0IM<V=I9"`B3V)J96-T(@IM<V=S='(@(M;W
MUKPB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B
M3V)J96-T($-R96%T;W(B"FUS9W-T<B`BMM3/\[VHP:+5WR(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,#0*;7-G:60@(D]C=&%L(@IM<V=S='(@
M(K#+O?C.NR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,3`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C<T"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(LJNU,(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C8*;7-G
M:60@(D]F9FEC92(*;7-G<W1R("*P[+FKRM(B"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W;W)D
M<R!M=7-T(&)E(&1I9F9E<F5N="XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C,V"B,L(&9U>GIY"FUS9VED(")/;&0@<&%S
M<W=O<F0B"FUS9W-T<B`BP]S"ZR(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HT-@IM<V=I9"`B3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T
M<B`BL*+"_"(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E
M9"!F;VQD97)S+B(*;7-G<W1R("+6N]/0($E-05`@M_[.\<;WUJ>SUL[$O/Z\
MT+FRS^VYIL3<+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I
M9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U,2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.3<Q"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W
M960N(@IM<V=S='(@(M:[O=/*W-*[N/;3RKS^M=C6MRXB"@HC.B!S97)V:6-E
M<R]S:&%R97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R
M(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP
M(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@
M(M:[T]#3M=/0U=_3Z\^US;.YW,#MU+&_R=+4L>2X_+FRS^W(J,_>(@H*(SH@
M;&EB+T)L;V-K+VEF<F%M92YP:'`Z,S4*;7-G:60@(D]P96X@:6X@82!N97<@
M=VEN9&]W(@IM<V=S='(@(M3:T,*TL+_:UM"T\K^J(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@97)R
M;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%
M('!A<G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0HC+"!F=7IZ>0IM<V=I9"`B3W!E
M;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("+4VM#"M+"_
MVM;0M/*_JB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I9"`B
M3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<VED96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS(@IM<V=S='(@(M&A
MS^XB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S
M+V%P<"YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@
M)7,B"FUS9W-T<B`B)7,@M<31H<_N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM
M<V=S='(@(L_NQ+^QX+K%(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-C<*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R("+7Z=:O
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C@*;7-G
M:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`BU^G6K[6ESKLB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,R"B,L(&9U>GIY"FUS9VED
M(")/<F=A;FEZ:6YG(@IM<V=S='(@(M?IUJ\B"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA
M=&4B"FUS9W-T<B`BU*W*O-.FT\.SS-#RQ*.PYB(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E
M;7!L871E<R!I;B`E<SHB"FUS9W-T<B`BU-H@)7,Z(-;0M<34K<J\Q*.PYBXB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y('-E<G9I8V5S
M+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`BQN3+_"(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3`V"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3,@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$R,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3,Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#$*;7-G:60@(D]T:&5R($EN
M9F]R;6%T:6]N(@IM<V=S='(@(L;DR_S0Q<^B(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHS,0IM<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS
M9W-T<B`BT[73T-7?R*C/WB(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M
M+G!H<#HW.0IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I
M;&%B;&4N(@IM<V=S='(@(E!!32#1Z=:DSM[0IRXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%05(Z
M.DUA:6P@8F%C:V5N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,C<S"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U
M<F4B"FUS9W-T<B`B4$=0(,K]U];'J</[(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3,Q.0IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A
M(@IM<V=S='(@(E!'4""\T\/<U\K!SR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$S-S$*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S
M='(@(E!'4""YJ[^JP]S4OR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$S-3,*;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B
M"FUS9W-T<B`B4$=0(-+1QZG#^R_2T;S3P]P@U\K!SR(*"B,Z(&%D;6EN+W!H
M<'-H96QL+G!H<#HV.`IM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B4$A0(+/,
MT/*T^L+K(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@
M4VAE;&PB"FUS9W-T<B`B4$A0(+W%L;XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS-PIM<V=I9"`B4$T@3&EG:'0@4F%I;B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS.`IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B4$T@
M4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT,`IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q
M"FUS9VED(")032!3=6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E!-(%0M4W1O<FUS(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR-S0*;7-G:60@
M(E!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&QI
M8B]A<&DN<&AP.C$T.0HC+"!F=7IZ>0IM<V=I9"`B4%](4"!3:&5L;"(*;7-G
M<W1R(")02%`@O<6QOB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDY"FUS9VED(")086MI<W1A;B(*;7-G<W1R("*PS;OY
MR[G,N2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(L7!
MP,TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QE<W1I;FEA;B!497)R:71O
M<GDL($]C8W5P:65D(@IM<V=S='(@(K#-P-7+N<RYL;O5O,'LQ_@B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3@*;7-G:60@(E!A;F%M82(*;7-G<W1R("*PS<3#PNTB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3D*;7-G:60@(E!A<'5A($YE=R!'=6EN96$B"FUS9W-T<B`BL,VR
MO-''T,*\N,3:T<<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")087)A9W5A>2(*
M;7-G<W1R("*PS<"MN><B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS-@IM<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3@P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3,W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C$U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#$X"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(S
M"FUS9VED(")087-S=V]R9"(*;7-G<W1R("+#W,+K(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED(")087-S=V]R9"!C:&%N9V5D
M('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HQ,S(R"B,L(&9U>GIY"FUS9VED(")087-S=V]R
M9"!I;F-O<G)E8W0B"FUS9W-T<B`BP]S"ZSH@(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]R861I=7,N<&AP.C$U,@IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER
M960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BP[O3T-:X
MMJC#W,+KTM2YJ2!2041)55,@T>G6I"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,#4S"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO
M;B(*;7-G<W1R("+#W,+KR+?(SR(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHY,`IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(L/<PNLZ(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*;7-G:60@(E!A<W-W
M;W)D.B`B"FUS9W-T<B`BP]S"ZSH@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S0*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@
M;6%T8V@N(@IM<V=S='(@(L/<PNNQV-#KSL>ZSRXB"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3$Y('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`BS/G)SR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S<*
M;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@(LSYR<\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q"FUS
M9VED(")0871H(@IM<V=S='(@(L*WOK8B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M97%U975E9"YI;F,Z-PIM<V=I9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R
M("*T_<GSM<?"O*.Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T"B,L
M(&9U>GIY"FUS9VED(")096]P;&4B"FUS9W-T<B`BO<?)JR(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")0
M97)C96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M
M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED(")097)F;W)M($UA:6YT96YA;F-E
M($]P97)A=&EO;G,B"FUS9W-T<B`BUK30T,ZLNZ2RV=?W(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0P-@IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC
M92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R("*UQ\*\NO/6M-#0SJR[
MI++9U_<_(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*
M;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`BR*C/WB(*"B,Z(&%D;6EN+W!E
M<FUS+V1E;&5T92YP:'`Z-3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R("(G)7,G
M(+7$R*C/WLZTL;O)OK/]+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z-3@V"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("*TYLBA
MU.*^W"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38Q(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38T"FUS9VED(")097)M:7-S
M:6]N<R(*;7-G<W1R("+(J,_>(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z
M,3`Y(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,`HC.B!A9&UI;B]P97)M
M<R]I;F1E>"YP:'`Z,C(@861M:6XO<&5R;7,O9&5L971E+G!H<#HU.`IM<V=I
M9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VXB"FUS9W-T<B`BR*C/WKG<
MP.TB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4*;7-G:60@(E!E<G-O
M;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(L[2M<0B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$X,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*
M;7-G:60@(E!E<G4B"FUS9W-T<B`BP]C"LR(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU-0HC+"!F=7IZ>0IM<V=I9"`B4&5T<R(*;7-G<W1R("+7J+"X
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDY"FUS9VED(")0:&EL:7!P:6YE<R(*;7-G<W1R("*W
MQL+)L?8B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G<W1R("*UY[NP(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0W.`IM<V=I9"`B4&AO=&]S(@IM<V=S='(@
M(M75QJPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0:71C86ER;B(*;7-G<W1R
M("+&I,S8O[6UNB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS9VED(")0;&%T:71U9&5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L
M;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#D*;7-G:60@(E!L96%S92!C;VYF:7)M('1H
M870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT
M('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(U-S$*;7-G:60@(E!L96%S92!E;G1E<B!A
M(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(L?KRN3(Z]*[N/;4PK?=O+#$
MZK?=+B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C$R"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O
M<B!T:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R("+'Z\KDR.O2N[CVU,*WW;RP
MQ.JWW2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`Q"B,L(&9U
M>GIY"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*
M;7-G<W1R("+'Z\KDR.NZS[>HM<3*L;SD+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(V-C`*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED(&1A
M=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM
M<V=S='(@(L?KRN3(Z]*[N/:ZS[>HM<3(U<;:.]&AU/&TR]3"M]VUQ,C5QMHN
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U,0IM<V=I9"`B4&QE
M87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`BQ^O*Y,CKNL^WJ+7$
MRK&\Y"XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS
M9VED(")0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN
M(@IM<V=S='(@(L?KS.&YJ<[*S.*UQ-6JTJHN(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V
M"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S
M=V]R9"(*;7-G<W1R("+'Z\KDR.O$^K7$T\.[I\/[O+##W,+K(@H*(SH@<V5R
M=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4X"B,L(&9U>GIY"FUS9VED("(B"B)0
M;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E
M('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R
M("+'Z]3$ML'/PL'0Q-K(W2[$^K'8T.O-K-+BU>+0J<K"S^ZRQ<3<RKG3P\^U
MS;,N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E
M<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@
M;F%M93HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0;VQA;F0B
M"FUS9W-T<B`BLJC`O"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-PHC
M+"!F=7IZ>0IM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`BS;;&L2(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#<*;7-G:60@(E!O;&QS(@IM<V=S
M='(@(LVVQK$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T=6=A;"(*;7-G
M<W1R("+&S\S1T<`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$R-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F
M('1H:7,@:6UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F
M('1H:7,@=&%B;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD
M97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R("*UW<O-T\J\_K6]
MU>*X]L[$O/Z\T"`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H
M;W5R*',I.B`B"FUS9W-T<B`BU^Z]_"`E<R#0H<JQM<2]M=/JP;\Z("(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3@*;7-G:60@(E!R96-I
M<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+VQD87`N<&AP.CDX"FUS9VED(")0<F5F<U]L9&%P.B!2
M97%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R
M969S7VQD87`Z(-72LKNUO<OYT.C2JK7$($Q$05`@P*G5N=?IO/XN(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0
M<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(E!R969S7W-E<W-I;VXZ(-72LKNUO<OYT.C2JK7$
M('-E<W-I;VX@P*G5N=?IO/XN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,C4*;7-G:60@(E!R97-S=7)E(@IM<V=S='(@(L;XT;DB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(U.0IM<V=I9"`B4')E<W-U<F4@870@<V5A(&QE=F5L
M.B`B"FUS9W-T<B`BNJ/&O</FQOC1N3H@(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(S-0IM<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R("+&
M^-&Y.B`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C`U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R("+4I,#`
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(T"B,L(&9U>GIY"FUS9VED(")0<F5V:65W('1H92!I;6%G
M92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`BU-K0PK2PO]K6T+3ROZHB"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V,B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C,V-@IM<V=I9"`B4')E=FEO=7,@;W!T:6]N
M<R(*;7-G<W1R("+)S]*[N/;1H<_N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#(S"FUS9VED(")0<FEV871E($ME>2(*;7-G<W1R("++O</<P]S4OR(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-CD*(RP@9G5Z>GD*
M;7-G:60@(E!R;V)L96TB"FUS9W-T<B`BSLK,XC\B"@HC.B!S97)V:6-E<R]P
M<F]B;&5M+G!H<#HQ,C8*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS
M9W-T<B`BSLK,XL/HRO8B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S8Y"FUS9VED(")0<F]J96-T<R(*;7-G<W1R("+7J+"X(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,3@X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#4*;7-G:60@
M(E!R;VUP="!T97AT(@IM<V=S='(@(LSARK[$VLC=(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM
M<V=S='(@(KFKOZK#W-2_(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S
M='(@(KFKOZK#W-2_T=W+XR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C0T"B,L(&9U>GIY"FUS9VED(")0=6)L:6,@2V5Y($EN9F\B
M"FUS9W-T<B`BN:N_JL/<U+\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HR-#$*;7-G:60@(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T
M(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(KFKOZHOR[W#W,/<
MU+^VU+*BSK2QN[+ZR?HN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O
M(%)I8V\B"FUS9W-T<B`BLJBVX,#HN/<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED
M(")1871A<B(*;7-G<W1R("*_J,O^MOLB"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(E%U97)Y(@IM<V=S='(@(LK]OMV_XK+I
MT:\B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*(RP@9G5Z>GD*;7-G
M:60@(E%U;W1A(@IM<V=S='(@(K^HR_ZV^R(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C8S"B,L('!H<"UF;W)M870*;7-G:60@(E)3
M02!0=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@(E)302"YJ[^JP]S4OR`H
M)60@SKLI(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-`IM<V=I
M9"`B4F%D:6\@<V5L96-T:6]N(@IM<V=S='(@(K6ET:$B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,PHC+"!F=7IZ>0IM<V=I
M9"`B4F%I;B(*;7-G<W1R(")3<&%I;B`HSO>PX-'`*2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")286EN($5A
M<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0U"B,L(&9U>GIY"FUS9VED(")286EN($QA=&4B"FUS9W-T
M<B`BRJ7"K,[WT<>UNB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0V"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-PIM<V=I
M9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!T;R!3;F]W
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"B,L(&9U
M>GIY"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R("++X\/\(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV."!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<V"FUS9VED(")2871I;R(*
M;7-G<W1R("*QR,+*(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS
M,C0@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ.#`*;7-G:60@(E)E860B"FUS9W-T<B`BML'(H2(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W"FUS9VED(")296%D
M(&UE<W-A9V5S(@IM<V=S='(@(K;!R*'3RKS^(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E
M86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O
M;F4N(@IM<V=S='(@(M7FM<32JLF^L_T@)7,@PO`_(-7BS^ZRV=?WO:O.WK>H
MN]:XM"XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R
M(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U
M;F1O;F4N(@IM<V=S='(@(M7FM<32JLF^L_T@)7,@PO`_(-7BS^ZRV=?WO:O.
MWK>HN]:XM"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G
M<W1R("+(H<_[N+34K2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED(")2969R97-H(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(E)E
M9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q"FUS9VED(")2969R97-H(%!O<G1A
M;"!6:65W.B(*;7-G<W1R("++HM#"P\6[I\K3S;PZ(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.#DT(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M,3,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-0IM<V=I9"`B4F5G
M97@B"FUS9W-T<B`BN>;4\K'MM._*O2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,R-#D*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(RP@9G5Z>GD*;7-G:60@(E)E
M;&]A9"(*;7-G<W1R("*VP<BA(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,C8*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`BQL#"VR(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,30*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S
M='(@(M2VL\RW_L[QQO<B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC
M;VTO:&]R9&4I.B(*;7-G<W1R("+4MK/,S?C6MR`H:'1T<#HO+W=W=RYE>&%M
M<&QE+F-O;2]H;W)D92DZ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E
M9&ET+FEN8SHR,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR
M.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S
M"FUS9VED(")296UO=F4B"FUS9W-T<B`BR;ZS_2(*"B,Z('1E;7!L871E<R]P
M;W)T86PO;&%Y;W5T+FEN8SHQ,0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S
M='(@(LF^L_W'^+_I(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C4U-PHC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*
M;7-G<W1R("+)OK/]T\.[IR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-#`*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!F;W)M
M871T:6YG(@IM<V=S='(@(LF^L_VVU"(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,Z,3(X"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R("+)OK/]
MMM0B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R"FUS9VED(")296UO
M=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C
M=&]R>2XB"FUS9W-T<B`BU]2W_L[QQO?4W;3FQ+_"O-;0R;ZS_=+1L:.TYK7$
MQ>36P[/,T/(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C0R"B,L(&9U>GIY"FUS9VED(")296UO=F4@=&AE
M(@IM<V=S='(@(LF^L_W3P[NG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO=F4@=&AI
M<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*;7-G:60@(E)E;6]V92!U
M<V5R(@IM<V=S='(@(LF^L_W3P[NG(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U
M<V5R.B`E<R(*;7-G<W1R("+)OK/]T\.[ISH@)7,B"@HC.B!F<F%M97=O<FLO
M4E!#+U)00R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q=65S="!C;W5L9&XG
M="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS9W-T<B`B
MT.C'\\ZTL;O/[-.F.B"T[<[SNL7"ZSHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,34W"B,L(&9U>GIY"FUS9VED(")297%U97-T960@<V5R
M=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@(LG/M*O.Q+S^LJ+.
MM+&[L:.TYBXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-"!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@
M)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B)3(D<R"UQ,7DUL.QV-#KUKBV
MJ"`G)3$D<R<B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8W-2!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S,`HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z-S(S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B5D93(+7$Q>36P['8T.O6N+:H("<E<R<B
M"@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW.#$*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D
M(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(L7DUL/*_;[=L=C0Z]:XMJ@@
M)R5S)R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,S
M-0IM<V=I9"`B4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,S$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Y"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,R,"!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(M;8R>@B"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT-@HC+"!F=7IZ>0IM<V=I
M9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`BP]S"ZR(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C(W"B,L(&9U>GIY"FUS9VED(")297-E="!9
M;W5R(%!A<W-W;W)D(@IM<V=S='(@(LBWR,_#W,+K(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C$S,`HC+"!F=7IZ>0IM<V=I9"`B4F5S=&]R92!,87-T(%%U
M97)Y(@IM<V=S='(@(L_"S]+4PB(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HW
M,2!A9&UI;B]C;61S:&5L;"YP:'`Z,C@@861M:6XO<W%L<VAE;&PN<&AP.C8V
M"FUS9VED(")297-U;'1S(@IM<V=S='(@(KWAN?LB"@HC.B!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N:6YC
M.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(K>UN]C1H<_N
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"B,L(&9U>GIY
M"FUS9VED(")2971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(M&AU/'#W,+K
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R(")2975N
M:6]N("C!],3AS?JUNBDB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(E)E
M=F5R="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(K+ZR?H@)7,@M<3/M<VSQ>36
MPR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S(*(RP@9G5Z>GD*;7-G
M:60@(E)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R("*WM;O8T:'/
M[B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S`*(RP@9G5Z>GD*;7-G:60@(E)I9VAT(@IM<V=S
M='(@(LWMR<\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(Q"FUS
M9VED(")2:6=H="!H96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$Q-PHC+"!F=7IZ>0IM<V=I9"`B4FEG:'0@=F%L=65S
M(@IM<V=S='(@(K6MP+8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE
M<RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(KW'R:LB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM<V=S='(@(E)O;6%N:6$@
M*,+>PNW$X=''*2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,C4*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`BT/W7JB`Q
M.#`@ML@B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C(R"FUS9VED(")2;W1A=&4@3&5F="(*;7-G<W1R("+/\M?ST/W7JB(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C@*
M;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R("+/\M/2T/W7JB(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*
M;7-G:60@(E)O=R!0<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@
M(E)O=R!P<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4S"B,L(&9U>GIY"FUS9VED(")2=6QE<R(*;7-G<W1R("*]
MQ\FK(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A
M;&P@<F]W<R!A;F0@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O
M=W,@;VYL>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P
M"FUS9VED(")2=6XB"FUS9W-T<B`BUK30T"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G
M:60@(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R(")2=7-S:6%N($9E9&5R
M871I;VX@*+;MPM[+N2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=V%N9&$B
M"FUS9W-T<B`B4G=A;F1A("C"K+"RM.\I(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P
M:&EC(%-I9VYA='5R92(*;7-G<W1R(")3+TU)344@O-/#W,>IP_LB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-
M24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@(M/*O/[2T<JYT\,@4R]-
M24U%(+S3P]PB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@Q
M"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(E-!4TP@T>G6I,[>T*<N(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C4P-`IM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R("+0
MQ<^B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS9VED(")344P@4VAE
M;&PB"FUS9W-T<B`BROV^W;_BO<6QOB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,R.#,*;7-G:60@(E-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO
M;VMU<',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0S,0IM<V=I9"`B4U-((@IM<V=S='(@(KS3P]S6U;;+N_HB"@HC.B!F<F%M
M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I
M;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(K/)N:8B"@HC.B!L
M:6(O87!I+G!H<#HQ-3,*(RP@9G5Z>GD*;7-G:60@(E-?44P@4VAE;&PB"FUS
M9W-T<B`BROV^W;_BO<6QOB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@(M#'QMK!^2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R("+*
MI;K5P-7$P[6Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")386EN="!+:71T<R!A
M;F0@3F5V:7,B"FUS9W-T<B`BRJ6[^;7"NLW!T,ZLR[DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#<*;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S='(@(LJEPJS.]]''M;HB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`P"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N
M(@IM<V=S='(@(LJEQJ2PH[;[NLW"\[_+PM?(NK6Z(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-0IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS
M9W-T<B`BRJ7.Q,FMS-BZS;CQP=;$R;3O(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H
M7W-E;&8I(@IM<V=S='(@(LVLTKNX]K2PO]H@*%]S96QF*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S='(@(LCXQ*;1QR(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#8*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T<B`BRJ7"[<&FQ;4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`W"FUS9VED(")386\@5&]M92!A;F0@4')I;F-I<&4B"FUS
M9W-T<B`BRJ6VX,/`NLW&U<'6SO>QR"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G
M<W1R("+.P-#'S.&YJ=7?(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@
M07)A8FEA(@IM<V=S='(@(LFSS-BPHL"MLJXB"@HC.B!T96UP;&%T97,O<&]R
M=&%L+VQA>6]U="YI;F,Z.3@*;7-G:60@(E-A=F4B"FUS9W-T<B`BL:.TYB(*
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#4*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(K&C
MM.8@)7,B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@(K&CM.8@)7,B"@HC
M.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO
M;G,B"FUS9W-T<B`BL:.TYM&AS^XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,38W"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N
M(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B
M"B)D:7)E8W1O<GDN(@IM<V=S='(@(KVKLOK)^K7$Q>36P\[$O/[2U"!02%`@
MT^_1U+CQRKVQH[3FM;W$^K7$M_[.\<;WU-VTYL2_PKS6T"XB"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+%Y-;#("5S(-+1L:.T
MYBXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@
M=&\Z(%PB)7-<(BXB"FUS9W-T<B`BN/S0PK/,T/+2T;&CM.:UO3H@)R5S)RXB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM
M<V=I9"`B4V-A='1E<F5D(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S
M='(@(LO1T;`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(P"B,L
M(&9U>GIY"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R("++T=&P(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDW,PHC+"!F=7IZ>0IM<V=I
M9"`B4V5L96-T($9I;&5S(@IM<V=S='(@(M&AU/'2N[CVR-7&VB(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#0*;7-G:60@
M(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`BT:'4\=*[N/;(U<;:(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.3@*;7-G:60@(E-E;&5C="!A(&=R
M;W5P('1O(&%D9"(*;7-G<W1R("+1H=3QTKNX]M/#NZ?7Z=/#TM30PM3V(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T
M(&$@;F5W(&]W;F5R(@IM<V=S='(@(M&AU/'2N\Z[T,*UQ-.UT]#5WR(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T
M(&$@<V5R=F5R(@IM<V=S='(@(M&AU/'2N[*_M_[.\<;W(@H*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C="!A('5S97(@
M=&\@861D(@IM<V=S='(@(M&AU/'2N\Z[T\.[I]/#TM30PM3V(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-PHC+"!F=7IZ
M>0IM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R("+1H=3QTKNX]LC5QMHB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8S"FUS9VED(")396QE8W0@
M86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`BT:'4\<OYT]#(U<;:U^F\
M_BXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.#<S"B,L(&9U>GIY"FUS9VED(")396QE8W0@86X@;V)J96-T(@IM<V=S='(@
M(M&AU/'2N\Z[T,*UQ-.UT]#5WR(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HV-S@*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!N
M;VYE(@IM<V=S='(@(M&AU/'2N\Z[T,*UQ-.UT]#5WR(*"B,Z('-E<G9I8V5S
M+VME>6)O87)D+G!H<#HS-PIM<V=I9"`B(@HB4V5L96-T('1H92!C:&%R86-T
M97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H
M96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N
M(@IM<V=S='(@(M/:TM3/PK7$M+"_VM;0T:'(H<3ZTJJUQ-?6M_LNTM3*\['J
MN+36QLOYT:'.Q-?6+,B[NO/,^<G/SL2\_K'@O*W'^"XB"@HC.B!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H92!D871E(&1E
M;&EM:71E<CHB"FUS9W-T<B`BT:'4\<C5QMJWUKCT.B(*"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R
M;6%T.B(*;7-G<W1R("+1H=3QR-7&VLC5QMJX\<J].B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3`*;7-G:60@(E-E;&5C="!T
M:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H
M92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`BT:'4\<JQO.2WUKCT.B(*"B,Z
M('1E;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE
M('1I;64@9F]R;6%T.B(*;7-G<W1R("+1H=3QR-7&VLJQO.2X\<J].B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C="!T
M=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R("+1H=3QS^"[I<:EQ>2UQ+;^
MN/;7UK;.+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#8*;7-G:60@
M(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`BT:'4\<3ZM<31
MU<FKQ>36PR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#@*;7-G:60@
M(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`BT:'4
M\<:KNL/3[]'4.B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C4X"FUS9VED(")396YD(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(K2KR\W.
MRLSBM[33IB(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,#,Y"FUS9VED(")396YD(%--4R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`V"FUS9VED(")396YE9V%L(@IM<V=S='(@(E-E;F5G86P@*,C[Q-J\
MT[;[*2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$V"FUS9VED(")396YS
M;W(Z("(*;7-G<W1R("*TJ[C0QO<Z("(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS9W-T
M<B`BOL74PB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DY"FUS9VED(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T<B`B4V5R
M8FEA(&%N9"!-;VYT96YE9W)O("C(^[;[SJS1Q]/KP\G,V,3AN.?"WBDB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B
M4V5R:6%L($YU;6)E<B(*;7-G<W1R("+0\KK%(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$V,0HC+"!F=7IZ>0IM<V=I9"`B4V5R=F5R(&1A
M=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B365T87(@Q_B_
MZ<[>MZC*N=/#+B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR-PHC+"!F=7IZ
M>0IM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G<W1R("+(J,_>N=S`[2(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M,@IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R("*[X<;:($E$
M(-+1N?W&VBXB"@HC.B!L:6(O87!I+G!H<#HQ-#4*(RP@9G5Z>GD*;7-G:60@
M(E-E<W-I;VYS(@IM<V=S='(@(LBHS]XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S$T"FUS9VED(")3970B"FUS9W-T<B`BQ>36PR(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HW-@IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@
M86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@
M9F]R9V5T(&ET+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$U"FUS9VED(")3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@
M=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`BQ>36
MP]2VL\RW_L[QQO?)S\KTT]K$^K7$N/;(R]6^S*@N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@T"FUS9VED(")3970@>6]U<B!P<F5F97)R960@;&%N
M9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S='(@(L7D
MUL/$^K7$QJNZP]/OT=0L(,JQQ_C2U+RPR-7&VKCQRKTN(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDX"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P
M(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@
M86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`BQ>36P\3Z
MM<3&],J\TZ;3P[/,T/(LT=7)J\7DUL,LTK/#YKC\T,+&M<+*++RPQN3+_,_4
MRK[1H<_N+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*(RP@9G5Z
M>GD*;7-G:60@(E-E='5P(@IM<V=S='(@(L7DUL,B"@HC.B!T96UP;&%T97,O
M861M:6XO<V5T=7`O:6YD97@N:'1M;#HS-PHC+"!F=7IZ>0IM<V=I9"`B4V5T
M=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R("*X_-#"L\S0
M\M+1L:.TYK6].B`G)7,G+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ.#8*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I
M=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(M/0NL.\N+CVM=BUX[K-U>*X
M]K+.ROW3T+G8.B`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L;&5S
M(@IM<V=S='(@(E-E>6-H96QL97,@*,C[SO2V^RDB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#DV"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R("*Y
MNL[O(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G
M:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`BO/*VS-6JTJHB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#0V"FUS9VED(")3:&]U;&0@86-C97-S(&ME
M>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`BRL>W\<ZJ
MM/.RO[?=M<3!K+W3MJC2Y;_LO=VYIL3<O/P_(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS
M,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`B
MS]3*OB(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*
M(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD
M('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y,`IM<V=I9"`B4VAO
M=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R("+#
MO[3.M<?"O+KSS]3*OLG/TKNTSK7$M<?"O,JQO.0@/R(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$W-C4*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME
M97`@;W)I9VEN86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C@Q,PIM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`BS]3*OK7C
MT:'&]R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C8*;7-G:60@(E-H
M;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R("+3VM?S
ML=_/U,J^("5S(+++M:4_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!486)L
M92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM
M<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R
M=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")3:&]W('1H
M92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8S"B,L(&9U>GIY"FUS9VED(")3:&]W
M('5P;&]A9"(*;7-G<W1R("+.Q+S^R<^TJR(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4P"B,L(&9U>GIY"FUS9VED(")3:&]W
M97)S(@IM<V=S='(@(L_4RKXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU,0HC+"!F=7IZ>0IM<V=I9"`B4VAO=V5R<R!%87)L
M>2(*;7-G<W1R("*\\K;,U:K2JB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED(")3:&]W97)S($QA=&4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-3,*;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C0X,`IM<V=I
M9"`B4VAR:6YK(@IM<V=S='(@(LK5R_4B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HW-S0@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z.#,V"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.CDR,B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY.#0*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3`T-R!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,#@W"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q,38@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z,3$T.0IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@
M;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-I97)R82!,96]N92(*
M;7-G<W1R(")3:65R<F$@3&5O;F4@*,JHU]/)O;GZ*2(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C4*;7-G:60@(E-I9VX@=7`B"FUS
M9W-T<B`BUZ*RX2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-S$R"FUS9VED(")3:6=N871U<F4B"FUS9W-T<B`BQZG#^R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$Q"FUS9VED(")3:6=N
M871U<F4@06QG;W)I=&AM(@IM<V=S='(@(L>IP_O1W<OC(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-`IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S='(@(E-I;F=A<&]R92`HT,*\
MT\;"*2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C4@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@W(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C@Y-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C$U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S<*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.3,P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C,*;7-G:60@
M(E-I>F4B"FUS9W-T<B`BM//0H2(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]M86EN=&5N86YC92YH=&UL.C4R"FUS9VED(")3:VEP($UA:6YT96YA;F-E
M(@IM<V=S='(@(L+4N?W.K+ND(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO
M=F%K:6$B"FUS9W-T<B`B4VQO=F%K:6$@*,NYPN6WI;_+*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#4*;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@(E-L;W9E;FEA("C+N<+E
MMZ7$X=''*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4T"B,L(&9U>GIY"FUS9VED(")3;F]W(@IM<V=S='(@(L_4RKXB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I
M9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*;7-G:60@(E-N;W<@4VAO=V5R<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU-PIM<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS
M9VED(")3;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(W.`IM<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@
M(KO]T:G)[K;(.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X,@IM<V=I
M9"`B4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(E-O
M;&]M;VX@27-L86YD<R`HR_?"WL/%R+JUNBDB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS
M9VED(")3;VUA;&EA(@IM<V=S='(@(E-O;6%L:6$@*,OWPNW`^]''*2(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(V
M"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R("+%Q<'0M[W/
M\M&AU/$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,3@Y"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G<W1R
M("+`M-2TM=C6MR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(E-O=71H($%F<FEC
M82(*;7-G<W1R(")3;W5T:"!!9G)I8V$@*,3/M\<I(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.3`*;7-G:60@(E-O=71H($5U<F]P96%N("A)4T\M.#@U
M.2TS*2(*;7-G<W1R("+$S\6W("A)4T\M.#@U.2TS*2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H
M($ES;&%N9',B"FUS9W-T<B`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H
M(%-A;F1W:6-H($ES;&%N9',B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@
M;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(96UI<W!H
M97)E(@IM<V=S='(@(L3/L.O'\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B971W965N(&%D
M:F%C96YT(&-E;&QS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W965N
M(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Q-0HC+"!F=7IZ>0IM<V=I9"`B4W!A
M8V5R(@IM<V=S='(@(L"LN_C3RKS^(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"B,L(&9U>GIY"FUS9VED(")3
M<&%C:6YG(@IM<V=S='(@(E-P86EN("C.][#@T<`I(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B
M4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM
M<V=I9"`B4W!A:6XB"FUS9W-T<B`B4W!A:6X@*,[WL.#1P"DB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3@*;7-G:60@(E-P86TB"FUS9W-T<B`B
MP*R[^-/*O/XB"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@
M(E-P96-I86P@0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(LS8RN+7UK?[RN3(
MZR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C(*;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM
M<V=I9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@(E-P
M;&ET(')O=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C$*(RP@9G5Z>GD*;7-G:60@(E-P;W)T<R(*;7-G<W1R("+6I[/6(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@X"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T<B`B4W)I($QA;FMA
M("C+N<#OP+R_J"DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-S,@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-`IM<V=I9"`B4W1A;F1A<F0B"FUS
M9W-T<B`BL>K7O"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@HC+"!F
M=7IZ>0IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(L;TRKS$ZK?=(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#`Y"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@(L;TRKS$
MZK?=(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`*
M;7-G:60@(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(LJA(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U
M<R(*;7-G<W1R("+7M,RL(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C@Q-0IM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`BL:.TYKCQRKTB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,@IM<V=I
M9"`B4W1R965T($%D9')E<W,B"FUS9W-T<B`BO=:UP"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK
M971H<F]U9V@B"FUS9W-T<B`BR;ZS_<_?(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(S,PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`BU]:W
M^[2NP=`B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<S"FUS9VED
M(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*
M;7-G<W1R("+0Q\;:S.PB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S
M7"(@;F]T(&9O=6YD+B(*;7-G<W1R("+5TK*[M;T@)7,N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B
M:F5C="(*;7-G<W1R("+6]]:\(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S,R(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,Q-PIM
M<V=I9"`B4W5B;6ET(@IM<V=S='(@(LSAO;LB"@HC.B!S:6=N=7`N<&AP.C0Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O
M(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@;&]G(&EN
M('5N=&EL('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S='(@(L_"L>HB"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3`T"B,Z(&9R86UE=V]R:R].;W1I9FEC871I
M;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@
M(E-U8V-E<W,B"FUS9W-T<B`BL\FYIB(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D
M960@7"(E<UPB('1O('1H92!S>7-T96TN(@IM<V=S='(@(K/)N::\T\CK("<E
M<R<@M;W/M<VSUM`N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A
M(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(K/)
MN:;7U,^US;/6T,F^L_T@)R5S)R`N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX
M,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N(@IM<V=S
M='(@(K/)N:;)OK/]("<E<R<@+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V
M960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`BL\FYIM?4S[7-
ML];0R;ZS_2`G)7,G("XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q
M"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@
M4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*
M(RP@9G5Z>GD*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`BQ>36PR`E<R#2T;&CM.8N(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I
M;&4@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@
M7"(E<UPB(@IM<V=S='(@(K/)N::X_-#"("<E<R<B"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T
M<B`BTM&SR;FFN+*XQR`E<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U9&%N
M(@IM<V=S='(@(E-U9&%N("C+U;6D*2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*;7-G:60@(E-U;6UA<GDB
M"FUS9W-T<B`BU:K2JB(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV-0IM
M<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`BR-6S]B(*"B,Z(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*;7-G<W1R("+(U<+D(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*(RP@
M9G5Z>GD*;7-G:60@(E-U;FYY(@IM<V=S='(@(E-U9&%N("C+U;6D*2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*;7-G:60@(E-U;G)I
M<V4B"FUS9W-T<B`BR-6S]B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS
M(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS
M970B"FUS9W-T<B`BR-6S]B_(U<+D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Q-0IM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(LC5L_8Z
M("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3D*;7-G:60@
M(E-U;G-E="(*;7-G<W1R("+(U<+D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Q.`IM<V=I9"`B4W5N<V5T.B`B"FUS9W-T<B`BR-7"Y#H@
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,PIM<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`BR<^QZB(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS-S@*;7-G:60@(E-U<'!O<G0B"FUS9W-T
M<B`BUJ>SUB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-U<FEN86UE(@IM<V=S
M='(@(E-U<FEN86UE("C+U<#[Q,\I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-S0*;7-G:60@(E-U<FYA;64B"FUS9W-T<B`BM,*Z
MQ2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y
M96XB"FUS9W-T<B`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R(")3=V%Z:6QA;F0@*,JW
MS=^\P\"\*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G<W1R
M(")3=V5D96X@*,CPM>0I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HU-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L
M86YD(@IM<V=S='(@(E-W:71Z97)L86YD("C(\,J_*2(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C@V"B,L(&9U>GIY"FUS9VED(")3>6YC(&QO
M9R!D96QE=&5D(@IM<V=S='(@(K*[R;ZS_2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-#(*;7-G:60@(E-Y;F--3"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E
M<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-PIM<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B4WER:6%N
M($%R86(@4F5P=6)L:6,@*-#PP/O1QRDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV,`IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M,0IM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*(RP@9G5Z>GD*
M;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(K2PS.4B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3=&]R;7,@
M16%R;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N
M<&AP.C$V-@IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B5$%"(+?6N/2X\<J]
MSL2\_B(*"B,Z(&9R86UE=V]R:R]522]522]486)L92YP:'`Z,3,T"B,L(&9U
M>GIY"FUS9VED(")486)L92(*;7-G<W1R(")496%L(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B
M5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W"FUS9VED(")486)L92!3970B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-"!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")486EW86XB"FUS
M9W-T<B`BS*C-Y2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM<V=S
M='(@(LRHS>4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")486II:VES=&%N(@IM
M<V=S='(@(E1A:FEK:7-T86X@*,O^O*K+N<RY*2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*
M;7-G:60@(E1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8B"FUS9W-T<B`B
M5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B`HS+G)T,3AT<<I(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I
M9"`B5&%R9V5T.B(*;7-G<W1R("+$O['J.B(*"B,Z(&-O;F9I9R]H;V]K<RYP
M:'`N9&ES=#HY.38@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X-PIM<V=I
M9"`B5&%S:W,B"FUS9W-T<B`BM/VP[,K"S^XB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4W,PIM<V=I9"`B5&5L97!H;VYE($YU;6)E
M<B(*;7-G<W1R("*UY[NPNL7"ZR(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,CDP"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("+7[KW\
MTKO0H<JQM<3.PK;(.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-`IM
M<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`BSL*VR"(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,C,*;7-G:60@(E1E;7!E<F%T=7)E.B`B
M"FUS9W-T<B`BSL*VR#H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")496UP97)A='5R93QB<B`O
M/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-C@W"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G
M<W1R("+5TK*[M;W$H[#F("<E<R<N(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H
M<#HQ-CD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(L2CL.:YW,#M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,V"FUS9VED(")497AT(@IM<V=S
M='(@(L3:R-TB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<U"FUS9VED
M(")497AT($]N;'DB"FUS9W-T<B`BM+_.Q-?6(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`HC+"!F=7IZ>0IM
M<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R("*TO\[$U]8B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"B,L(&9U>GIY"FUS
M9VED(")497AT=&]P(@IM<V=S='(@(L3:R-TB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R
M("+0Q\;:R\0B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B
M5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`BS*G.Q"`H5$E3+38R,"DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`Y"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R(")4:&%I;&%N9"`H
MS*FY^BDB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#@*;7-G:60@
M(E1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2XB"FUS9W-T<B`BT+O0
MN\3ZRKG3P[&^S[7-LRXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C@R,`IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L
M92XB"FUS9W-T<B`B1E10(-'3R>PH97AT96YS:6]N*<[>T*<N(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO
M="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7TE-4U`O24U34"]";V]K+G!H<#HQ,CDR"B,L(&9U>GIY"FUS9VED(")4:&4@
M24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R("+)
MS[2KSL2\_K*BSK2QN[&CM.8N(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C,Q"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T
M(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(DUA:6YT96YA;F-E(,#@L?"R
MHLZTL\FYIM38R.LB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N
M<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@
M17AI=&EN9RXB"FUS9W-T<B`BT:'/[K2PO]K2U+G8L=4NP.N_JM;0+B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,C$Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,C4R"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C8T(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4:&4@861M:6YI
M<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES
M<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO
M;G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T;VT@<VED92!O
M;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)1"!N
M=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO
M="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0HC+"!F=7IZ
M>0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T
M;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`BS:C1MLK]OMW2T;/)N::U
MQ-3VO-.UO<3ZM<3-J-&VLK[6T"[3P\KSL>JPM,_"P=#/[L2_TM2\[,K3.B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-CD*;7-G:60@
M(B(*(E1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I
M<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(M'I
MUJ33RKS^QZG#^]#HTJK3T-*[N/;2T;WBOZJUQ"!01U`@Q_B_Z2XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM
M<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@
M;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@
M=&AE(&1A=&%B87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,@HC+"!F=7IZ>0IM<V=I9"`B
M5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G
M<W1R("*TR]?WT\/.M+&[UJ>SUBXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0N<&AP.C$Q,PIM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q
M=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`BT.C2JM*[
MN/:^K;G]O-/#W+7$S?C"Y\&LO=,N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ-S4@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@
M82`E<R!S971T:6YG+B(*;7-G<W1R("+.Q+S^("5S(-.FN,.P_+JLTKNX]B`E
M<R#%Y-;#+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38X(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`S"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN
M9W,N(@IM<V=S='(@(L[$O/X@)7,@TZ:XP[#\NJS2N]"I("5S(,7DUL,N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C$Y"B,L(&9U>GIY"FUS
M9VED(")4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB
M"FUS9W-T<B`BM,O.Q+S^UM##N]/0ROV^W2XB"@HC.B!F<F%M97=O<FLO1&%T
M82]$871A+G!H<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D
M871A+B(*;7-G<W1R("*TR\[$O/[6T,.[T]#*_;[=+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F
M;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C
M.#(R(&UE<W-A9V4N(@IM<V=S='(@(M+4S\+*QR!R9F,X,C(@T\J\_K7$L>W-
MMRXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T
M;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@
M(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O
M<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E(&1I
M<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M
M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O
M=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N
M97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N
M7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E<W,@
M3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E
M9&ET;W(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY,`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y(%PB)7-<
M(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("*TR[?^SO'&]R!<(B5S7"(@
MTM&QN\F^L_TN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N
M;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I
M;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB
M"FUS9W-T<B`B1VYU4$<@MO[4JL[$O/ZUQ,*WOK:QV-#KMJC2Y=3:($-R>7!T
M7W!G<#HZ(,#@L?#6T"XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP
M:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E('-E
M;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D
M:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M
M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-PIM<V=I9"`B5&AE
M(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T
M,0HC+"!F=7IZ>0IM<V=I9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B
M92!N=6UE<FEC+B(*;7-G<W1R("*QV-#KRL?2N[CVROW7UBXB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S$*;7-G:60@(E1H92!O
M<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T
M7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@(DAO<F1E7T-R>7!T7W-M:6UE.CH@
MP."Q\"RQV-#HTJK3T"!O<&5N<W-L(,2CO^DN(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E
M(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M87AI;75M(&%L;&]W86)L92!S
M:7IE(@IM<V=S='(@(K3+QJNZPR!<(B5S7"(@ROV^W=+RSJJSK+G]U^ZT\[W3
MRMS6M2S+^=+4SMZWJ+&[L:.TYB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W=E8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I
M('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`BT\/2U+SL
MRM.TR\K]OMW`X-#-("@E<RD@M<2SS-#RLJ*RN[3FU-K3VL^US;/)SRXB"@HC
M.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-30*;7-G:60@(E1H92!Q
M=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L969T('-I
M9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I9VAT+6AA
M;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C0T-@IM<V=I9"`B5&AE('-E<&%R871O<B!M=7-T(&)E(&]N
M92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("*TR[?^
MSO'&]R!<(B5S7"(@TM&QN\F^L_TN(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P
M8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<
M(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(K3+M_[.\<;W(%PB)7-<
M(B#2T;&[L:.TYBXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E
M;B!R96UO=F5D+B(*;7-G<W1R("(E<R"UQ->BLN'0Z,?STM&QN\F^L_TN(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,S,P"FUS9VED
M(")4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B
MUKBVJ+7$O,?"O+*BLKNTYM3:+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z,3<W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M
M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("+6
MN+:HM<2\Q\*\LJ*RN[3FU-HN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S,Q,0IM<V=I9"`B5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M
M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y
M"FUS9VED(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HS,C<*;7-G:60@(E1H92!U
M<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P
M+B(*;7-G<W1R("*TT\G/TKNX]K*]UNC6KKKSR<^TJ[7$ROV^W=+%RJ<N(@H*
M(SH@9G)A;65W;W)K+T1A=&$O1&%T82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO
M1&%T82]$871A+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@=7!L;V%D960@9FEL
M92!C;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(LG/M*O.Q+S^LJ+.M+&[
ML:.TYBXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#8@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4V"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ,34@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$Q.0IM<V=I9"`B5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I
M;&%B;&4N(@IM<V=S='(@(G=E871H97(N8V]M(,?XO^G.WK>HRKG3PRXB"@HC
M.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB
M"FUS9W-T<B`BU=*RN[6]Q*.PYB`G)7,G+B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,3<X"B,L(&9U>GIY"FUS9VED(")4:&5R92!A<F4@
M;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@(DUE=&%R(,?XO^G.WK>H
MRKG3PRXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HS
M-#(*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P
M;&%Y960@:6YL:6YE+B(*;7-G<W1R("+.WKB]O/Z_R=:QO=.T\K^J+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,#$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI
M<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y
M;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@(K3+U]:VSM;0
ML/RZK,RKMN"UQ-?6ROTNQ/K2T<KDR.L@)7,@N/;7ULK].\3ZRN3(Z[7$U];*
M_;'8T.O0H=/:("5S+B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP
M:'`Z-S,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M('!R;V)L96T@861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G
M<W1R("+0PM3V("<E<R<@M;W/M<VS.B`E<R#*L;>BR?K2N[CVSLK,XBXB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E
M<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`BU]3/M<VSR;ZS
M_2`G)7,G(,JQMZ+)^M*[N/;.RLSB.B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P
M,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O
M8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T
M<B`BU]3/M<VSR;ZS_2`G)7,G(,JQMZ+)^M*[N/;.RLSB.B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$U.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z("5S(@IM<V=S='(@
M(KC\T,(@)R5S)SH@)7,@RK&WHLGZTKNX]L[*S.(B"@HC.B!F<F%M97=O<FLO
M0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@
M)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R("+)S[2KSL2\_LJQMZ+)^M*[N/;.
MRLSB.B`E<R#.M+&[R<^TJRXB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W
M<V5R+G!H<#HX.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S
M(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L
M87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y
M=&5S*2XB"FUS9W-T<B`BR<^TJ\[$O/[*L;>BR?K2N[CVSLK,XCH@)7,@M//0
MH;.LN?V]T\K<U^ZT\]:U("@E9"!B>71E<RDN(@H*(SH@9G)A;65W;W)K+T)R
M;W=S97(O0G)O=W-E<BYP:'`Z.#DQ"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H
M92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N(@IM<V=S='(@(LG/
MM*O.Q+S^RK&WHLGZTKNX]L[*S.(Z(+WVLK^WUK7$("5S(,[$O/ZQN\G/M*LN
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HS
M-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M
M97-S86=E('!A<G0B"FUS9W-T<B`BO.S*T]/*O/[*L;>BR?K2N[CVM.W.\RXB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T
M(&1A=&$N(@IM<V=S='(@(KOCR.NTR\VHT;:ROLK]OMW*L;>BR?JT[<[S+B(*
M"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS,0HC+"!F=7IZ>0IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N
M9&%R(&1A=&$N(@IM<V=S='(@(KOCR.NTR\VHT;:ROLK]OMW*L;>BR?JT[<[S
M+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#`*;7-G:60@(B(*(E1H
M97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!0
M97)H87!S('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G
M<W1R("+4VL7DUL.TL,SEUM"WHLGZP<O2N[CVM.W.\R[3T+_)Q-S$^M+%PJG!
MR['8T.O,[M"TM<37UK;.+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,X"FUS9VED("(B"B)4:&5R92!W87,@86X@
M97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F
M=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-#`*(RP@9G5Z>GD*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U
M<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN
M(&QA=&5R+B(*;7-G<W1R("*[X\CKM,O-J-&VLK[*_;[=RK&WHLGZM.W.\RXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R
M,@HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T
M:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L
M871E<BXB"FUS9W-T<B`BN^/(Z[3+S:C1MK*^ROV^W<JQMZ+)^K3MSO,N(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS
M9VED(")4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN
M9R!F;VQD97)S+B(*;7-G<W1R("*TRR!)34%0(+?^SO'&][*BSK36I[/6SL2\
M_KS0M];/[;FFQ-PN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@
M82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`BU>++QKKULKO*Q]7]R+>U
MQ"!R87(@T;G+]<[$O/XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@
M8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`BU>++QKKULKO*Q]7]R+>U
MQ"!Z:7`@T;G+]<[$O/XN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S$T-0IM<V=I9"`B5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@
M8V%R9"!N=6UB97(N(@IM<V=S='(@(M7BR\:Z];*[RL?5_<BWM<30Q=/#OZBZ
MQ<+K+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO
M+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!
M4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HQ,S0*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L
M8RYC;VTI("(*(F=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB
M<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET
M86QY7W-M='`N<&AP.C@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A
M9F]N92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E
M<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A
M9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-S@@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3`U-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#@V
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,34*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$X,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C4V
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#4@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3,Y.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-34W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,SD*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3DU."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,#`U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,CD@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C`W.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,30Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,C$*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-#4T"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-3<@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C@R.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,3,W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,#8*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@Q-"!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS.#(R"FUS9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G
M<W1R("*TR]?6ML[*Q['8T.C2JK7$+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$P-C4*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I
M;B!I;G1E9V5R<RXB"FUS9W-T<B`BM,O7UK;.Q-K(W=:[O=/*W-7[ROW*_=?6
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3@*;7-G:60@(E1H
M:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L
M;VXN(@IM<V=S='(@(K3+U]:VSL3:R-W6N[W3RMS*_=?6O+##L+K%+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.30*;7-G:60@(E1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(K3+
MU]:VSL3:R-W6N[W3RMRPR[WXUL;*_=:U+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A(&-O
M;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S
M='(@(K3+U]:VSL3:R-VQV-#KSJJVNKK%N_*_U;#7M]:X]+7$ROW7UB(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDX.0IM<V=I9"`B5&AI<R!F:65L
M9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R("*QV-#KRL?2N[CV
MROW7UBXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#,V"FUS9VED
M("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@
M=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N
M(@IM<V=S='(@(K3+U]:VSL3:R-VQV-#KL/RZK-*[U^G*KL'YO?C6QK7$(%)'
M0B#1U<FKM/K"ZRS`_<CG("<C,3(S-&%F)RXB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HU-C$*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B
M965N('!R;V-E<W-E9"XB"FUS9W-T<B`BU>*X]K2PS.72T;&[M*;`[;G]+B(*
M"B,Z('1E;7!L871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@(M7BRL<@)7,N(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I
M97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE
M;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA
M="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E
M('9I<VET("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C4Y,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE
M<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H
M97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@
M8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R("*TR\K]UK77[LG9L=C0Z\K'(#$N
M(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C0U
M"FUS9VED(")4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@
M9WII<"!F:6QE<RXB"FUS9W-T<B`BM,NW_L[QQO?.WK>HMM0@>FEP(+RP(&=Z
M:7`@N/'*O<[$O/Z]^-#0O>+1N<OU(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+U)E9VES=')Y+G!H<#HQ.#D*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U
M<G)E;G1L>2!D96%C=&EV871E9"XB"FUS9W-T<B`BM,O/M<VSM;''L,K'S:/3
MP[7$U[3,K"XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R
M-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R
M("*QV-#KRL?2N[CVROW7UBXB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P
M:6-K97(N<&AP.C,U"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE
M9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S='(@(K3+M+"_VK'8T.O2
MJM/)T:'/[K2PO]HH3W!T:6]N*<OYNO2]T"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4:'5N9&5R(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,S0*(RP@9G5Z
M>GD*;7-G:60@(E1I8VME=',B"FUS9W-T<B`BO\V[I[FDU_>UI2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,C@@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C4U"FUS9VED(")4:6UE(@IM<V=S='(@(LJQO.0B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@V"FUS9VED(")4:6UE(%1R86-K
M:6YG(@IM<V=S='(@(LJQO.37M]?9(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP
M.C$W"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R("+*L;SDN/'*O2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U,SD*;7-G:60@(E1I;64@<V5L
M96-T:6]N(@IM<V=S='(@(LJQQ_C1H=3Q(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I
M9"`B5&EM;W(M3&5S=&4B"FUS9W-T<B`B5&EM;W(M3&5S=&4B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C(P"FUS9VED(")4:71L92(*;7-G<W1R("*QZLSB(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM
M<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED(")4;R(*
M;7-G<W1R("+*U;S^R,LB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-C4T"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@
M:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@
M*$UA8RD@:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"B+(Y[G[
MTJJXM-&A+,?KU-JUX]&ARO.QZK7$S:S*L;"T($-O;G1R;VR\_"BX]LC+O,;+
MX[OZ*2"[\B!#;VUM86YDO/PHQKNY^[S&R^,B"B*[^BDN(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B5&]D87DB"FUS9W-T
M<B`BO?',["(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R(")(
M5$U,(-2MRKS.Q+S^(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&]G;R(*;7-G
M<W1R("*VX+CG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA=2(*;7-G
M<W1R("+-T+_+P,W(NK6Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,Q,PIM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`BP_?,["(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3`*;7-G:60@(E1O;F=A(@IM<V=S='(@(LS`O-,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Q"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S<*(RP@
M9G5Z>GD*;7-G:60@(E1O<"(*;7-G<W1R("+*U;S^R,LB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@
M9G)A;64@*%]T;W`I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B5')A;G-L871I;VYS(@IM<V=S='(@
M(M?IUJ\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A;F0@5&]B
M86=O(@IM<V=S='(@(LS8P:+$X;3ONLVVX+#-N.<B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-SDP"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S
M='(@(M7FN_*\V2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(M#'QMJV_B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`BS;O$X<NY(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(LW!MOK&Y"(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED(")4=7)K:7-H("A)4T\M
M.#@U.2TY*2(*;7-G<W1R("+-P;;ZQN3.Q"`H25-/+3@X-3DM.2DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$P"FUS9VED(")4=7)K;65N:7-T86XB"FUS9W-T<B`BS<&_XL+\
MR[G,N2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@
M27-L86YD<R(*;7-G<W1R("+,V+_+R[FZS;^MO\;+N<BZM;HB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`BS;S-W\*L(@H*(SH@9G)A
M;65W;W)K+T-,22]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC
M93H@(@IM<V=S='(@(LKDR.O$^K7$T:'4\3H@(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(V.0IM<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S
M='(@(M?/S>+/W]:XROTZ("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,3<*;7-G
M:60@(E523"(*;7-G<W1R("+-^-:W(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U
M<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW"FUS
M9VED(")54DPZ(@IM<V=S='(@(LWXUK<Z(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I
M9"`B56=A;F1A(@IM<V=S='(@(L[:N,FT[R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G
M:60@(E5K<F%I;F4B"FUS9W-T<B`BSMJ_R\"\(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z-#$R"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&
M4R!D:7)E8W1O<GDN(@IM<V=S='(@(L[>MZBTYLBA(%9&4R#$O\*\+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B56YA
M8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN
M9R!U<"XB"FUS9W-T<B`BUZ*RX<JQSMZWJ-3VO-.V[LWBM<33P[NGT,7/HBXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,X.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&
M4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BSMZWJ+C$L>0@5D93(,[$O/X@7"(E
M<UPB(+7$R*C/WBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS
M.#4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0V.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&
M4R!F:6QE("5S+R5S+B(*;7-G<W1R("+.WK>HL>2X_"!61E,@SL2\_B`E<R\E
M<R"UQ,BHS]XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-34*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB
M"FUS9W-T<B`BSMZWJ+'DN/S.JB`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C(S,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(L[>
MMZBT\K^J(%9&4R#.Q+S^(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HV.#@@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ,#$V
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HX,S0*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I
M>F4@;V8@7"(E<R\E<UPB+B(*;7-G<W1R("+.WK>HL>2X_"!61E,@SL2\_B`E
M<R\E<R"UQ,/[L\8N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP
M.C0S-0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB
M"FUS9W-T<B`BSMZWJ,&LO=/6P2!344P@M_[.\<;W+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#,Y"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C
M="!W:71H(%-33"XB"FUS9W-T<B`BSMZWJ,JYT\,@4U-,(,&LO=,N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C(U(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#$*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P.0IM<V=I9"`B
M56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(L[>MZBXM-;&(%9&
M4R#.Q+S^+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S8U"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C
M=&]R>2!<(B5S7"(N(@IM<V=S='(@(L[>MZB]J,&B(%9&4R#$O\*\(%PB)7-<
M(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-30@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C(U.`HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,C4V"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&
M4R!D:7)E8W1O<GDN(@IM<V=S='(@(L[>MZB]J,&B(%9&4R#$O\*\+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0*;7-G:60@(E5N86)L
M92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(L[>MZB]J,&B(%9&4R#.
MQ+S^+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C@V"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F
M;VQD97(@7"(E<UPB+B(*;7-G<W1R("+.WK>HL>2X_"!61E,@SL2\_B!<(B5S
M7"(@M<3#^[/&+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(V
M-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@
M9FEL92XB"FUS9W-T<B`BSMZWJ+VHP:(@5D93(,[$O/XN(@H*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+W1A<BYP:'`Z-S8*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"FUS9VED(")5;F%B;&4@
M=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R("+.WK>HO:O*_;[=O>+1N<OU
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C(T(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,CDX"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I
M<R!N;W0@96UP='DN(@IM<V=S='(@(L[>MZC)OK/]("5S++3+Q+_"O+*BM\>_
MU;#7(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW."!A9&UI;B]P97)M<R]D96QE
M=&4N<&AP.C0T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM<V=S='(@(L[>MZC)OK/]("<E<R<Z
M("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S,2!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,Y,@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,S$Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HS,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E
M<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`BSMZWJ,F^
ML_T@)7,LM,O$O\*\LJ*WQ[_5L-<B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,S0X(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HS-3(*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R
M96-U<G-I=F5L>2XB"FUS9W-T<B`BSMZWJ+7=N>G)OK/]Q+_"O"XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S<@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C,R,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,S,U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T-`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("+.WK>HR;ZS_2!6
M1E,@Q+_"O"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0Q-R!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0R.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G
M<W1R("+.WK>HR;ZS_2!61E,@Q+_"O#H@)7,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HR,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(L[>MZC)OK/]
M(%9&4R#.Q+S^(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HS,#,@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR.#@*(SH@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$V-R!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HQ.#<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,X,PHC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDQ"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R("+.WK>HR;ZS_2!61E,@
MSL2\_BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(T-`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`BSMZWJ,F^L_T@5D93(,[$O/X@7"(E
M<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#`V"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV
M96QY.B`E<RXB"FUS9W-T<B`BSMZWJ+7=N>G)OK/](%9&4SH@)7,N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,#,*;7-G:60@(E5N86)L92!T
M;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(L[>MZC%
MT+;/M;''L+7$Q+_"O"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8P,PIM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A
M=&4@9&5T86EL<R(*;7-G<W1R("+.WK>HO>*_JL:^UJ3/N+W:(@H*(SH@9G)A
M;65W;W)K+TYE=%])35-0+TE-4U`N<&AP.C0U,2!F<F%M97=O<FLO3F5T7TE-
M4U`O24U34"]!=71H+G!H<#HQ,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(L[>
MMZB\T]38("5S(+7$MJC2Y<K]OMTN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P,0HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,38V(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-S$*;7-G:60@(E5N86)L92!T;R!M
M;W9E(%9&4R!F:6QE+B(*;7-G<W1R("+.WK>HTL:VKR!61E,@SL2\_BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.CDS(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z,3`R"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M-C0X(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G
M<W1R("+.WK>HM/*_JB!61E,@SL2\_B!<(B5S7"(N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,C<W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C$S,PIM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I
M;F<N(@IM<V=S='(@(L[>MZC0M,CK(%9&4R#.Q+S^+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C@P(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(*
M;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R("+.WK>H
MM/*_JB!61E,@SL2\_BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C0U"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D
M(&%R8VAI=F4N(@IM<V=S='(@(L[>MZBT\K^JT;G+]<[$O/XN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C@S-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE
M('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T
M<B`BSMZWJ+'DN/P@5D93(,[$O/X@7"(E<UPB(+7$P_NSQBXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z.#8V"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@
M=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+B(*;7-G
M<W1R("+.WK>HT+3(ZR!61E,@SL2\_LK]OMTN(@H*(SH@9G)A;65W;W)K+U-E
M<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`BSMZW
MJ+'DN/P@5D93(,[$O/ZUQ,/[L\8N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z-C8Y"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O
M="!D:7)E8W1O<GDN(@IM<V=S='(@(L[>MZBVP<BA('9F<W)O;W0@Q+_"O"XB
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q,#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN
M871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.3,*;7-G:60@(E5N86)L
M92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`BSMZWJ+'DN/P@
M5D93(,2_PKRUQ,/[L\8N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HS,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!6
M1E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`BSMZWJ,F^L_T@5D93(,2_PKPZ
M("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C8W(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,S0S"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+.
MWK>HL>2X_"!61E,@SL2\_B!<(B5S7"(@M<3#^[/&+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C8Q,"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(L[>MZBQY+C\(%9&4R#.Q+S^
M("5S+R5S(+7$P_NSQBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C,R,R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$S"B,Z(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-3(@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C(X-0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,S`Q"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*
M;7-G<W1R("+.WK>HL>2X_"!61E,@SL2\_K7$P_NSQBXB"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*(RP@
M9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R
M("+.WK>HL>2X_,ZJ("5S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L92!T;R!T<F%N<VQA=&4@
M=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(L[>MZC7JKN[(%=O<F0@SL2\
M_B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,30Y(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,34R"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(L[>MZC0
MM,CK(%9&4R!<(B5S7"(@SL2\_BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HQ-SD*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!W<FET92!6
M1E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(L[>MZC0M,CK(%9&
M4R#.Q+S^ROV^W2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR
M.#$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S.`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,30S"FUS9VED(")5;F%B;&4@
M=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T<B`BSMZWJ-"TR.L@5D93
M(,[$O/[*_;[=+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-#$*(RP@
M9G5Z>GD*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@
M=VEL;"!B92!E>&-E961E9"XB"FUS9W-T<B`BSMZWJ-"TR.L@5D93(,[$O/[*
M_;[=+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`*;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R("+/PKNNS]\B"@HC.B!T
M96UP;&%T97,O<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B
M"FUS9W-T<B`BR*'/^[C\N,0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C
M=&EO;B(*;7-G<W1R("*XM-2M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,C(S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,Y,`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F
M<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`BM_[.\<;WP:R]
MT\JQMZ+)^LZTU*3&VK7$N]C3ICH@(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,T,0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS-S@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S@T"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R
M;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`BMZ+)^LZTU*3&VK7$N]C3IBS3R;?^
MSO'&]SH@(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N
M86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z-C$*(RP@9G5Z>GD*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B
MRJ>PW"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS"FUS9VED(")5;FEC
M;V1E("A55$8M."DB"FUS9W-T<B`BS?+3P\+K("A55$8M."DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-@IM<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`BL*+`
MK;*NP:JZS\?ULZ2Y^B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI
M;F=D;VTB"FUS9W-T<B`BTZ*Y^B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N
M:71E9"!3=&%T97,B"FUS9W-T<B`BP\"Y^B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G
M:60@(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G
M<W1R(")5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-CD@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HW,0IM<V=I9"`B56YI=',B"FUS9W-T<B`BM:74JB(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R.2!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,S`*;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`B
MSK36JK7$(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P:6US9VED("A!4$D@365S
M<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM
M<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y"B,L(&9U>GIY"FUS9VED(")5
M;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("+.N];#T,7/HLG0
MSK3%Y-;#(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A<W-W
M;W)D+B(*;7-G<W1R("+.M-:JM<33P[NGP_N[\L/<PNLN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X"FUS
M9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C(Y-@HC+"!F=7IZ
M>0IM<V=I9"`B56YN86UE9"(*;7-G<W1R("+.M,/\P_LB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y"FUS9VED("(B"B)5
M;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A
M<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@
M($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N
M;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@
M=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*(RP@
M9G5Z>GD*;7-G:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@(M?6T,W1U<FK(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#8@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,C8*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HY,S(*;7-G:60@(E5N<W5P<&]R=&5D($5X
M=&5N<VEO;B(*;7-G<W1R("+.M-:GL]:UQ,"IU;G#^R(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,3DW('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`BL>2X_"(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,CD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@(KC\T,(@)7,B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"FUS9VED(")5<&1A
M=&4@=7-E<B(*;7-G<W1R("*X_-#"T\.[IR(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,30T(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R
M97,O961I="YP:'`Z,C,P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5
M<&1A=&5D(%PB)7-<(BXB"FUS9W-T<B`BTM&X_-#"("<E<R<N(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T
M(&1E;&5T960N(@IM<V=S='(@(KC\T,*SS-#RTM')OK/]+B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ-S@@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$Y.0IM<V=I9"`B57!L;V%D(@IM<V=S='(@(LG/M*LB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5<&QO861E
M9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB
M"FUS9W-T<B`BTM')S[2KR_G3T-.FT\.SS-#RM<3%Y-;#SL2\_K6]M_[.\<;W
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@
M(L[:P*VYYR(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA
M;F%G97(N<&AP.C0U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@
M0W5R<F5N=#H@)7,B"FUS9W-T<B`BM;''L,_@SKLB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E
M(%-33"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T
M"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R
M($E-4U`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V5D:70N:6YC.C(Q"B,L(&9U>GIY"FUS9VED(")5<V5R(@IM<V=S
M='(@(M/#NZ<B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN
M<&AP.C<R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A
M=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`BT\.[IR`E<R#.M,VHN?T@)7,@
MM<3*VLBHT>G6I"XB"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S
M97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`BT\.[I[G<P.TB"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(U,0IM<V=I9"`B57-E<B!/<'1I
M;VYS(@IM<V=S='(@(M/#NZ?1H<_N(@H*(SH@<VEG;G5P+G!H<#HV,@IM<V=I
M9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T<B`BT\.[I]>BLN$B"@HC.B!S
M:6=N=7`N<&AP.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E
M;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R("*TR]6^S*BUQ-/#
MNZ?7HK+AS[7-L]+1S:/3PRXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-#8Y"B,L(&9U>GIY"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM
M<V=S='(@(M72LKNUO2`E<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.CDX"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,"!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HS,PHC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C<R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED
M(")5<V5R;F%M92(*;7-G<W1R("+3P[NGP_LB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")5<V5R;F%M92!<(B5S7"(@86QR96%D>2!E>&ES=',N(@IM<V=S='(@
M(M/#NZ?#^R`G)7,G(-+1M.;4VBXB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R("+3P[NGP_LZ
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`IM<V=I9"`B57-E
M<FYA;64Z("(*;7-G<W1R("+3P[NG.B`B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*
M;7-G<W1R("+/M<VSUM"UQ-/#NZ<Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B
M57IB96MI<W1A;B(*;7-G<W1R("+.VM?(L?"_R\NYS+DB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HQ-C,@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C4U"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T
M+B(*;7-G<W1R(")61E,@Q+_"O+*BLKNTYM3:+B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ,3@*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(KS9
MQMHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-C8*;7-G:60@(E9A
M;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`BTM'5TK6]
MT]#0I[7$M=BUXSH@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV,S@*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(M/0T*?0U"(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(U-0IM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T
M<B`BTM2WUM;3SJJUI<Z[*+33S];4VL;PR^,I(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#4V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q-S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU
M;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(R-#0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$V(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Y,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A
M8FQE<V5T+G!H<#HU.0IM<V=I9"`B5F%L=65S(@IM<V=S='(@(M:U(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P.2!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,3@V"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R
M("+-W\*SL*+-O"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-#0*;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@(K'DNZ\B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$U"FUS9VED(")696YE>G5E;&$B"FUS9W-T<B`BSJ_$VLCPP*TB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R
M:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N
M('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(M'IUJ3*I[#<("T@M,O3RKS^O\G$
MW-+1U.+(R\G#U]2TV[C$+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-S`P"FUS9VED(")697)S:6]N(@IM<V=S='(@(K#FL;XB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(V"FUS9VED(")697)S:6]N
M($-O;G1R;VPB"FUS9W-T<B`BL.:QOK_8UL8B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")697)T
M:6-A;"!A;&EG;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I9"`B
M5F5R>2!(:6=H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I
M970@3F%M(@IM<V=S='(@(M2]Q,\B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$Y-`IM<V=I9"`B5FEE=&YA;65S92`H5DE30TE)*2(*;7-G<W1R("+4O<3/
MSL0@*%9)4T-)22DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HY-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R
M("*\[,K3("5S(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B
M5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*;7-G<W1R("+4VM#"M+"_VK3R
MOZHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R("+2U"`E
M<R"RZ;^T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L
M($)R:71I<V@B"FUS9W-T<B`BTZ+*],ZLMON^J<BZM;HB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R("+#P,KT
MSJR^J<BZM;HB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P.0IM<V=I9"`B
M5FES:6)I;&ET>2(*;7-G<W1R("+$W+S[ML@B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C8S"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T
M<B`BQ-R\^[;(.B`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O
M;F5I=&%L>5]S;71P+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA
M(%--5%`B"FUS9W-T<B`BTN*T\\#[M_RUPK?GM>?0Q;FKR[[-N+G](%--5%`B
M"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]M;V)I;&4N<&AP.C,V"FUS9VED(")705).(@IM<V=S='(@(KZON.8B
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/
M32`E<RXB"FUS9W-T<B`BOJ^XYB$A(2"TTR`E<R#*UK:OR;ZS_;/,T/(N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G
M:60@(E=)3B!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS
M9VED(")786QL:7,@86YD($9U='5N82(*;7-G<W1R("+-W\#[R[FZS;B[S;S(
MNK6Z(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]H=&UL+G!H<#HR-S(@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@S
M"FUS9VED(")787)N:6YG(@IM<V=S='(@(KZON.8B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G
M<W1R("+0Q\;:R/TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,CD*;7-G:60@(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`BS.S&^-2DLN(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#(W"FUS9VED(")7
M96%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.#DR"B,L(&9U>GIY"FUS9VED(")796%T:&5R
M+F-O;2(*;7-G<W1R(")W96%T:&5R+F-O;2#-^-6^(@H*(SH@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R("+-^-6^(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S-PIM<V=I9"`B5V5B(%-I=&4B
M"FUS9W-T<B`BS?C5OB(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN
M=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R("+#O];<(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*;7-G:60@(E=E;&-O
M;64B"FUS9W-T<B`BN[;3K2(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N
M:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(KNVTZVUO2`E<R(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E;7!L871E<R]P
M;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE
M+"`E<R(*;7-G<W1R("*[MM.M+"`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3DU"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R("+.
M]\6W("A)4T\M.#@U.2TQ*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV
M"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`BSO?%MR`H
M25-/+3@X-3DM,34I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H
M87)A(@IM<V=S='(@(L[WR/:Y_L"M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N
M('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R("*UQ\*\
MNO/3IKC#S\C/U,J^("5S(,3$TKNX]M.FT\.SS-#R/R(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T(&ES('1H92!D96QI
M;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R("+7UK;.M<2WUKCTU]:W^S\B"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I
M<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R("+2_<KVM<3'L+6\M_L_
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P
M-C$*(RP@9G5Z>GD*;7-G:60@(E=H97)E:7,@075S=')A;&EA(&UA<"(*;7-G
M<W1R("*PQ+3SP/O1QR(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I
M9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,S,*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O
M<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`HC+"!F
M=7IZ>0IM<V=I9"`B5VED=&@B"FUS9W-T<B`BM^?+V3HB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,3(U"FUS9VED(")7:61T:"!I;B!#4U,@=6YI
M=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T
M:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`HC
M+"!F=7IZ>0IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R("+!HLS5S?`B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0HC
M+"!F=7IZ>0IM<V=I9"`B5VED=&@Z(@IM<V=S='(@(K?GR]DZ(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4Q,PIM<V=I9"`B5VEK:2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"B,L(&9U>GIY"FUS
M9VED(")7:6YD(@IM<V=S='(@(K?GR]DZ(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*(RP@9G5Z>GD*;7-G:60@(E=I;F0@
M16%R;'DB"FUS9W-T<B`BM^?+V3H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HX,`IM<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R("*WY\O9
M*+W:*2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34V"FUS9VED(")7:6YD
M.B(*;7-G<W1R("*WY\O9.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-#(*;7-G:60@(E=I;F0Z("(*;7-G<W1R("*WY\O9.B`B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@(E=I<V1O;2(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DV"B,L(&9U>GIY
M"FUS9VED(")7:7-H;&ES="(*;7-G<W1R("+&VK3]S^[$OR(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*;7-G
M:60@(E=O<FL@061D<F5S<R(*;7-G<W1R("*P[+FKRM*UV-:W(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B
M5V]R:R!0:&]N92(*;7-G<W1R("*P[+FKRM*UY[NP(@H*(SH@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z,38Y(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@
M9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S`P"B,L
M('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X
M<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,3$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE
M+B(*;7-G<W1R("+(J,_>LKO7XRS.WK>HO:C!HB!61E,@SL2\_BXB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C0S"FUS9VED(")8+5)E9B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y
M,PIM<V=I9"`B6#4P.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DR"FUS9VED
M(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y
M=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y
M=C,@4W5B:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X,@IM<V=I9"`B6#4P.78S
M(&5X=&5N<VEO;G,B"FUS9W-T<B`B6#4P.78S(,"IU;G#^R(*"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R("+$ZB(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3,*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-0IM<V=I9"`B
M65E962(*;7-G<W1R("+$ZB(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,3`X"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@
M(EEA:&]O("$@M=C-O"(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN
M=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G<W1R("+#O\3J(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-PIM<V=I9"`B665M96XB"FUS9W-T<B`BTK+#Q2(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G
M:60@(EEE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O
M;6%I;G1E;F%N8V4N:'1M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E(@IM<V=S
M='(@(LK'M<0LSM+-K-+B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I;B!415A4($U/1$4N
M("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE7
M64<N(@IM<V=S='(@(L3ZM;''L,JYT\.TO\[$U]:QX-"TQ*/*O2X@RKG3PR!;
M/#Y=(+"TQ:6_R<?0N[O.JLWXTK.QX-"TQ*/*O2XB"@HC.B!S97)V:6-E<R]P
M;W)T86PO961I="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R
M92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#$Q
M"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,P,@IM<V=I
M9"`B66]U(&-A;B!N;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U
M<B!F=6QL(&YA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$X-34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW-0IM<V=I
M9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+B(*
M;7-G<W1R("+$^K*BSK3*Y,CKTKNX]KK/MZBUQ+7GU]/3RKS^M=C6MRXB"@HC
M.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I
M;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I
M;B`E<RXB"FUS9W-T<B`BQ/JRHLZTT\FUO,CKM<3.Q+S^UM"VU-.SR,ZZSM?6
MMLZUO2`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX.`IM<V=I
M9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R("+$^M+1OJW7
MHL_Z+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-C$*;7-G:60@
M(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E
M<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H
M92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@X"FUS9VED(")9;W4@:&%V
M92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R("+$^K'8T.O*Y,CK
MTKNX]KK/MZBUQ-:U+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P
M+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@
M8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`BQ/JQV-#KS\BYYKNN
MNL/*_;[=RO<H1&%T851R964IM_[.\;;+LL7$W+S,T/C*N=/#T,+3P[NGUZ*R
MX;?^SO$N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT-38*(RP@
M9G5Z>GD*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD
M+B(*;7-G<W1R("+$^K'8T.O/R+GFNZZZP\K]OMW*]RA$871A5')E92FW_L[Q
MMLNRQ<3<O,S0^,JYT\,@2&]R9&4N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P
M<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T
M+B(*;7-G<W1R("+'Z\/HRO;.RLSBHZS4VL3ZM*O+S<[*S.*QJ+CFUJ['L"XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX
M"FUS9VED(")9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN
M:R!P;VEN=',@=&\B"FUS9W-T<B`BQ/JQV-#KRN3(Z[3+P:R]T\OYUKC/\K7$
MS?C6MR(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED
M(")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM
M<V=S='(@(L?KUKBVJ-*JR;ZS_;7$M_[.\<;W+B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$Q.0HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S
M97)N86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`BQ^O6N+:HTJK)OK/]M<33
MP[NG+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`BQ^O6N+:H
MTJK)OK/]M<33P[NG+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E
M8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R("+'Z]:XMJC2JM#"
MU/:UQ-/#NZ<N(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9;W4@
M;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@
M(L?KUKBVJ-*JN/S0PK7$T\.[IRXB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O>FEP+G!H<#HQ,S@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@
M=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`BQ^O6N+:HTJK6M-#0
MM<37]]/#+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA
M;F%G97(N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!T>7!E(&$@
M;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(L?KUKBVJ-*JR;ZS_;7$T\.[
MIRXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S
M;71P+G!H<#HW,PIM<V=I9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L
M:6%N('!H;VYE(&YU;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HY-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S
M97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S
M='(@(L3ZM<0@)7,@N^'&VM+1N?W*L2['Z];8T,*UQ\*\+B(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED(")9;W5R($5M86EL
M($%D9')E<W,B"FUS9W-T<B`BQ/JUQ+7GU]/3RKS^M=C6MR(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR,3(*(RP@9G5Z>GD*;7-G:60@(EEO=7(@1G)O
M;3H@861D<F5S<SHB"FUS9W-T<B`BQ/JUQ+7GU]/3RKS^M=C6MR(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX.0IM<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R("+$
M^K7$T,7/HB(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S
M(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I
M;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G
M:6X@86=A:6XN(@IM<V=S='(@(B(*(M?4M-/$^K7$("5S(+OAQMJ_JLJ\TM3`
MM,3ZM<32\LS8S?BUV-:WTM&QY+C\+B#.JK&CNZ3$^K7$L++(J\;PO/NCK,3Z
ML=C0Z];8T,(B"B*UQ\*\+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C,S"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`BQ/JUQ-#5P_LB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z-0HC+"!F=7IZ
M>0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@
M;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R`B"B)U
M<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S
M="!U<V4@82!D:69F97)E;G0@(@HB875T:&5N=&EC871I;VX@8F%C:V5N9"XB
M"FUS9W-T<B`BQ/JUQ-'IUJ2VR[*BSK36I[/6T,+4]M/#NZ>[\KC#N:;$W-+1
ML;NYV+'5+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z
M-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@
M;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB
M:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G
M<W1R("+$^K7$T>G6I+;+LJ+.M-:GL];!T+/VT\.[I[ORN,.YIL3<TM&QN[G8
ML=4N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@T"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@
M8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO
M;BX@(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I
M;B!A9V%I;BXB"FUS9W-T<B`B(@HBU]2TT\3ZM<0@)7,@N^'&VK^JRKS2U,"T
MQ/JUQ.2OP,#&]\O&NO72T;'DN/PN(,ZJL:.[I,3ZM<2PLLBKQO"\^Z.LQ/JQ
MV-#KUMC0PB(*(K7'PKPN(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3`*
M;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A
M='5R92XB"FUS9W-T<B`BQ/JUQ.2OP,#&][*BSK36I[/6U>*X]KFFQ-PN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z-#(*(RP@9G5Z>GD*
M;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@
M<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O
M('!R:6YT+B(*;7-G<W1R("+$^K7$Y*_`P,;WLJ+.M-:GL]:T\M.AT:'/[B['
MZ["T($-44DPK4"#2U+3RTZ$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(U-PIM<V=I9"`B66]U<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`B
MQ/JUL<>PR_G%Y-;#M<3*L<?X.B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY
M-@HC+"!F=7IZ>0IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B
M965N(&-H86YG960N(@IM<V=S='(@(L3ZM<31H<_NTM&X_-#"+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3@*(RP@9G5Z>GD*;7-G:60@(EEO=7(@
M9&5F875L="!I9&5N=&ET>3HB"FUS9W-T<B`BQ*S(S\GMM]W*MK'P(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P,0HC+"!F=7IZ>0IM<V=I9"`B66]U
M<B!F=6QL(&YA;64Z(@IM<V=S='(@(L3ZM<30U</[(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z,3`P,`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!L;V=I
M;B!H87,@97AP:7)E9"XB"FUS9W-T<B`BQ/JUQ-&AS^[2T;C\T,(N(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-`HC+"!F
M=7IZ>0IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O
M<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R("+$^K7$
MT:'/[M+1N/S0PBXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*
M;7-G<W1R("+$^K7$T:'/[M+1N/S0PBXB"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@8F5E;B!R
M97-E="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@
M8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB
M<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.C<S,@IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS
M9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R("+$^K7$U+:SS+?^
MSO'&]SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-"!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA
M(@IM<V=S='(@(L3/R[G`K;?R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`BU/K2P;;[(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(M3>L<C1QR(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(KWRL,VRO,ZD
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI
M9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#@*;7-G:60@
M(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B6\[*S.*QJ+CF72(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(");
M4VAO=R!1=6]T960@5&5X="`M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]4
M97AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE
M<UTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S
M='(@(EO.N]/:T-`@)7,@N;(@)7,@T-!=(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ-30Q('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,3$*
M(RP@9G5Z>GD*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R("*YW,#M
M(@H*(SH@;&EB+V%P:2YP:'`Z,34W"FUS9VED(")?0TQ)(@IM<V=S='(@(B(*
M"B,Z(&QI8B]A<&DN<&AP.C$T,0HC+"!F=7IZ>0IM<V=I9"`B7T1A=&%4<F5E
M(@IM<V=S='(@(LK]OMTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*(RP@9G5Z>GD*;7-G:60@(E]$96QE
M=&4@4F]W(@IM<V=S='(@(LF^L_TB"@HC.B!L:6(O87!I+G!H<#HQ,S,*(RP@
M9G5Z>GD*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`BT\.[I]?I(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W-0HC+"!F=7IZ>0IM<V=I
M9"`B7TAE;'`B"FUS9W-T<B`BL._6^B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E
M(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+TUE;G4N<&AP.C$Y-`HC+"!F=7IZ>0IM<V=I9"`B7TQO9R!I;B(*
M;7-G<W1R("*UQ\*\(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N
M<&AP.C$Y,`HC+"!F=7IZ>0IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`BUZ+/
M^B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR-`HC+"!F=7IZ>0IM<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM
M<V=S='(@(K+ER.LOL>2X_,WXPN?!K+W3(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+TUE;G4N<&AP.C$V-`HC+"!F=7IZ>0IM<V=I9"`B7T]P=&EO;G,B
M"FUS9W-T<B`BT:'/[B(*"B,Z(&QI8B]A<&DN<&AP.C$S-PHC+"!F=7IZ>0IM
M<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@(LBHS]XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*(RP@
M9G5Z>GD*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R("+)OK/]MM0B
M"@HC.B!L:6(O87!I+G!H<#HQ,C4*(RP@9G5Z>GD*;7-G:60@(E]3971U<"(*
M;7-G<W1R("+%Y-;#(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED(")?5&%B;&4@4')O<&5R=&EE
M<RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,CD*(RP@9G5Z>GD*
M;7-G:60@(E]5<V5R<R(*;7-G<W1R("+3P[NG(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,C$*(RP@9G5Z>GD*;7-G:60@(F%D9')E<W,@8F]O
M:R(*;7-G<W1R("+-J-&VLKXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$S-`IM<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3,*(RP@9G5Z
M>GD*;7-G:60@(F-A;&5N9&%R(@IM<V=S='(@(LC5P/HB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U.`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R("+!X[RVM^<B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I
M9"`B8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N
M;F]T(&]P96X@:6YP=70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z-3DR"FUS9VED(")C;&EC:R!H97)E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(R
M"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S@*(RP@9G5Z
M>GD*;7-G:60@(F-O;F9I9W5R871I;VX@97)R;W(B"FUS9W-T<B`BQ>36PR(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED
M(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(V"FUS9VED(")D
M871A(&9O<FUA="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$X,@HC+"!F=7IZ>0IM<V=I9"`B96YT<GD@
M;F]T(&9O=6YD(@IM<V=S='(@(M72LKNUO2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")F86QL:6YG(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U-0IM
M<V=I9"`B9FEL92(*;7-G<W1R("+.Q+S^(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C`@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B9G)O;2!T:&4@)7,@
M*"5S*2!A="`E<R`E<R(*;7-G<W1R("*TTR`E<R`H)7,I(-/:("5S("5S(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,`HC+"!F=7IZ>0IM
M<V=I9"`B9W5S=&EN9R(*;7-G<W1R("(L(-7SM^<@)7,@)7,B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0Y"FUS9VED(")H
M.B(*;7-G<W1R("+*L3HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,S4X"FUS9VED(")H:"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N
M86UE('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA
M=&4B"FUS9W-T<B`BP:*\M"(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")I;FQI
M;F4B"FUS9W-T<B`BS\*[KL_?(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T
M-@IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*(RP@
M9G5Z>GD*;7-G:60@(FQI;F5S72(*;7-G<W1R("*WUB(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@
M;6%K:6YG($E33RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C,V.0IM<V=I9"`B;6TB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR.3$@<V5R=FEC97,O
M<&]R=&%L+W-I9&5B87(N<&AP.C$W,`HC.B!S97)V:6-E<R]P;W)T86PO<VED
M96)A<BYP:'`Z,C,R"FUS9VED(")N86UE(@IM<V=S='(@(L/[L\8B"@HC.B!F
M<F%M97=O<FLO4E!#+U)00RYP:'`Z,3(Q"FUS9VED(")N;W0@:6UP;&5M96YT
M960B"FUS9W-T<B`BR=#.M,JUS]8N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HQ,C$Y"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D
M(@IM<V=S='(@(LG0SK3*M<_6+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3`U"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G
M:60@(G!E<F-E;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-S0*(RP@9G5Z>GD*;7-G:60@(G!E<FUI<W-I;VX@
M9&5N:65D(@IM<V=S='(@(K3FR*'4XK[<(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,3<P"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-S,*(RP@9G5Z>GD*;7-G:60@(G)I<VEN9R(*;7-G<W1R("+(J,_>(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#(*(RP@9G5Z>GD*
M;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B365T87(@Q_B_
MZ<[>MZC*N=/#+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.3D*;7-G
M:60@(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*;7-G:60@(G-M
M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@U"FUS9VED(")S<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW
M,@HC+"!F=7IZ>0IM<V=I9"`B<W1E861Y(@IM<V=S='(@(K;!R*$B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P.0IM<V=I9"`B<W=I=&-H(&]F
M9B!J879A<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,34P"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,CD*(RP@9G5Z
M>GD*;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R("+7UK?[M*[!T"(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,38V"FUS9VED(")T96UP
M;W)A<GD@9F%I;'5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C,P-0HC+"!F=7IZ>0IM<V=I9"`B=')Y(&%G86EN(@IM<V=S
M='(@(L._M,ZUQ\*\(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@9G)A;65W;W)K
M+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B='EP92!T:&4@<&%S
M<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R("+4V;3.RN3(Z\3ZM<3#
MW,+KTM3(M\C/SM[.\R(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D
M;6EN+W-E='5P+V1I9F8N<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")U;FEF:65D
M(@IM<V=S='(@(LJGL-PB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U!A<G0N
M<&AP.C(W"FUS9VED(")U;FYA;65D(@IM<V=S='(@(LZTP_S#^R(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R
M,PIM<V=I9"`B=7-E<B!S96QE8W0B"FUS9W-T<B`BT\.[I]&AU/$B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@
M(G9#87)D(@IM<V=S='(@(G9#87)D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(T,0IM<V=I9"`B=SHB"FUS9W-T<B`BT,?&
MVCHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B
M=V5A=&AE<BYC;VTB"FUS9W-T<B`B=V5A=&AE<BYC;VT@S?C5OB(*````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M;R]Z:%]45RYP;P``````````````````````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`V-#`T,C,@,3`U,34T,S,W-#(@,#$W-38Q`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````",@2&]R9&4@
M5')A9&ET:6]N86P@0VAI;F5S92!4<F%N<VQA=&EO;BX*(R!#;W!Y<FEG:'0@
M*$,I(#(P,#$@1&%V:60@0VAA;F<N(+%IJ'VDY2RE>,97"B,@1&%V:60@0VAA
M;F<@/&1A=FED0'1M=BYG;W8N='<^+"`R,#`Q+@HC"FUS9VED("(B"FUS9W-T
M<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C`M8W9S7&XB"B)2
M97!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB
M4$]4+4-R96%T:6]N+41A=&4Z(#(P,#8M,#$M,#4@,34Z,#0K,#@P,%QN(@HB
M4$\M4F5V:7-I;VXM1&%T93H@,C`P,2TQ,BTR,"`Q,CHP,"LP.#`P7&XB"B),
M87-T+51R86YS;&%T;W(Z($1A=FED($-H86YG(#QD879I9$!T;78N9V]V+G1W
M/EQN(@HB3&%N9W5A9V4M5&5A;3H@5')A9&ET:6]N86P@0VAI;F5S92`\:3$X
M;D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB
M0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4))1S5<;B(*(D-O
M;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET7&XB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C,W,PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A
M>7,@86=O*2(*;7-G<W1R("(@*"5S(*31JV4I(@H*(SH@;&EB+TAO<F1E+G!H
M<#HQ,S<T"B,L('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*
M;7-G<W1R("(@**?6L;;!Y"`E<RDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C,X,0HC+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S
M='(@(B`H)7,@I-&DNBDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W-PIM
M<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B("BDM:31*2(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,S<Y"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(@
M**GZI-$I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S4*;7-G:60@(B`H
M>65S=&5R9&%Y*2(*;7-G<W1R("(@**Q1I-$I(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(T-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S4P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.38*;7-G
M:60@(B!A="`B"FUS9W-T<B`BJ?,B"@HC.B!L:6(O5D93+W-M8BYP:'`Z,C$Y
M"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E8W1O
M<GDN(@IM<V=S='(@(EPB)7-<(B"DHZQ/I$"MTZ78O_TB"@HC.B!L:6(O2&]R
M9&4O0TQ)+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES
M(&YO="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B7"(E<UPB(*2CK$^D0*W3
MIK.NQ*JZO^^^W"XB"@HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C8U,B!L
M:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C$P-#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I
M<W1R>2XB"FUS9W-T<B`B7"(E<UPB(*E\I;RF8B!(3U)$12"JNK7YI57`R2A2
M96=I<W1R>2FDI+-=J7<N(@H*(SH@;&EB+TAO<F1E+U1R964N<&AP.C$W,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@
M9F]U;F0N(@IM<V=S='(@(J?DI*.H["!<(B5S7"(@=')E92!R96YD97)E<BXB
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4V"B,L('!H<"UF;W)M870*;7-G:60@
M(EPB)7-<(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S
M='(@(EPB)7-<(J1WIJBE7*JZI5ND2JCLN'.RU:ATLLZDI"XB"@HC.B!A9&UI
M;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*
M;7-G<W1R(")<(B5S7"*D=Z5;I$K%=JVMJ'2RSBXB"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C4T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS
M9W-T<B`B7"(E<UPBJ,.EO*O8I=\Z("5S+B(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E9"!O
M9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R("*D=ZC/I<X@)2XR
M9DU"("RN9;9Q("4N,F9-0B`LL]&^;"`H)2XR9B4E*2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)60@)7,@86YD("5S(@IM<V=S='(@(B5D("5S(*5(I,X@)7,B"@HC.B!L:6(O
M2&]R9&4O075T:"]L9&%P+G!H<#HR-C@@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C4U-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!D87ES('5N=&EL('EO=7(@
M<&%S<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`BL\RJ\:1`IKBQ2[U8Q=RG\ZGS
M("5D(*31JV4N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(W
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B"FUS9W-T
M<B`BL\RJ\2`E9""DT:[PMDBY=[/X(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N
M8V4N<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM
M<V=S='(@(B5S("T@L\:GT;_](@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HW,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B
M"FUS9W-T<B`B)7,@J_ROOB(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S
M+G!H<#HX-#`@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@T,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(E<R!+0B(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM
M<V=S='(@(B5S(+K[Q4"^WJ=`("T@O52[>R(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q-0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R("(E<R"S7:EW(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-C0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(E<R"U^:55(@H*(SH@<V5R=FEC
M97,O;6%I;G1E;F%N8V4N<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(%1E<FUS(&]F($%G<F5E;65N="(*;7-G<W1R("(E<R"F4+=.MK6EV"(*"B,Z
M(&QI8B]61E,O<VUB+G!H<#HT,S(@;&EB+U9&4R]S;6(N<&AP.C0Y-"!L:6(O
M5D93+V9T<"YP:'`Z-C<Q"B,Z(&QI8B]61E,O9G1P+G!H<#HW,SD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B5S
M(*1WIG.F8B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Y(&QI8B]";&]C
M:R]M971A<BYP:'`Z,38U(&QI8B]";&]C:R]M971A<BYP:'`Z,C,Y"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S0U(&QI8B]";&]C:R]M971A<BYP:'`Z,S4Q
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B5S
M(*9B("5S("5S(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0X"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E<F9O<FT@
M=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE
M8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T
M;R!P97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B)7,@I'>T3J15ID.H
MQK:UJKJZ^\5`OMZG0+1.NOPN(+W0J?.FN:[)I,2_[Z=!MU&M;K[>IT"JNK:U
MI=@N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`BI;*[W:UN("5S(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@;6EN=71E<R(*;7-G<W1R("(E<R"DP"(*"B,Z(&QI8B](;W)D92]"
M;&]C:R]#;VQL96-T:6]N+G!H<#HQ,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@;F]T(&9O=6YD+B(*;7-G<W1R("*GY*2CJ.P@)7,N(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R("(@)7,@J.P@)7,@ID`@)7,B"@HC
M.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDR,0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R("(E<ZJZLW&P5+_](@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HY,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,G<R!#86QE;F1A<B(*;7-G<W1R("(E<ZJZIN:HQK[D(@H*(SH@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HY,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.
M;W1E<&%D(@IM<V=S='(@(B5SJKJSQJ?1O_TB"@HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.CDR.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T
M(@IM<V=S='(@(B5SJKJKW;_LPZ\B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,Z("5S(@IM<V=S='(@(B5S.B`E<R(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]H=&UL+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I
M;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@(@HB86YY(&QI;FMS(&EN
M(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O
M;F%L(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"B(E<SH@LV^KRJM(I?.DHZ1`
MJ7>O=:71JTBDI*JZL4BE\Z1(J=*Q2+5O+B"]T*I@MTZD5:9#J=*FLZJZNO2X
M]+-SM;*FLZ5IK^"LJKI\(@HBIT&JNJW3I$BXZJ[&+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS-30@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,Y.0IM<V=I9"`B+"!G=7-T:6YG("(*;7-G<W1R("(L(+!]K;<@
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#@@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S
M(@IM<V=S='(@(BP@L'VMMR`E<R`E<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E
M<R!T;R`E<R(*;7-G<W1R("(LQ=RDQK9QL7$@)7,@J.P@)7,B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C`W,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$S,B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(Y-`HC.B!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C,T."!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-S0U"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B+2T@O^^^W"`M+2(*
M"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&;W)M
M870B"FUS9W-T<B`B,3(@I'"NR:CN(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP
M.C$Y"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R("(R-""D<*[)J.XB
M"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U
M<G,B"FUS9W-T<B`B,C0@I'"NR:CN(@H*(SH@;&EB+TAO<F1E+U5)+U!A9V5R
M+G!H<#HV.0IM<V=I9"`B/%!R979I;W5S(@IM<V=S='(@(J17I$"MMB(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED(")!(&1A=&%B87-E(&)A
M8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@(J:Y
ML,^V]*6RMK>M;JO\J7>XZJ[&KG>F^*I!NMTN(@H*(SH@;&EB+TAO<F1E+G!H
M<#HQ-C(*;7-G:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S
M='(@(K5OI<VD1J1`K=/$6:VKJKJ_^;M^(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("*Q_:5;L4NV;*7S
M+,'9N]VM;J:SI$"MTR!01U`@I+VV?:KWQE\N(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z,3$V.`IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R
M97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B
ML?W%Y\/2I'?#L;.YJKJV;*7S+,'9N]VM;J:SI$"MTR!01U`@I+VV?:KWQE\N
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3`Y.0IM<V=I9"`B(@HB
M02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM
M<V=S='(@(K']N-&Q2[9LI?,LP=F[W:UNIK.D0*W3I+VV?2!01U`@JO?&7RRH
M<+%+(%!'4""J]\9?+*5(I,ZS<</VI&:E3RXB"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HQ,#$V"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P
M<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`BL?VP]:;FMFRE\\.QL[DL
MP=F[W:UNIK.D0*W3I+VV?2!01U`@JO?&7RRH<+%+(%!'4""J]\9?+*5(I,ZS
M<</VI&:E3RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4P-@IM
M<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP
M="!A(&UE<W-A9V4N(@IM<V=S='(@(K']N-&Q2[9LI?,LP=F[W:UNIK.D0*W3
MI+VV?2!334E-12"J]\9?+*APL4L@4TU)344@JO?&7RRE2*3.LW'#]J1FI4\N
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G:60@(B(*
M(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M97-S86=E
M+B(*;7-G<W1R("(B"B*Q_;#UIN:V;*7SP[&SN2S!V;O=K6ZFLZ1`K=.DO;9]
M(%,O34E-12"J]\9?+*APL4L@4R]-24U%(*KWQE\LI4BDSK-QP_:D9J5/+B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U
M8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A
M9V4N(@IM<V=S='(@(K']I5NQ2[9LI?,LP=F[W:UNIK.D0*W3(%--24U%(*2]
MMGVJ]\9?+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.CD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R("*DR*MEIK.VLR(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED
M(")!32!,:6=H="!286EN(@IM<V=S='(@(J3(JV6D<*M"(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3$*;7-G:60@(D%-(%)A
M:6XB"FUS9W-T<B`BI,BK9::SJT(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R
M("*DR*MEL'VK0B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$S"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`BI,BK
M9;!]L[<B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B
M04TO4$TB"FUS9W-T<B`BI,BK92^DR*OA(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G<W1R(")!
M4$D@O7.XN2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@(L/V
MJ?.S;ZW3O7._Z+ZY(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3,*
M;7-G:60@(D%B;W5T+BXN(@IM<V=S='(@(L/VJ?,N+BXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T"FUS9VED(")!8G-B
M;W1T;VTB"FUS9W-T<B`BI;^D5:3H(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED9&QE(@IM<V=S
M='(@(J6_I*2EH2(*"B,Z(&QI8B]61E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B
M06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R
M("+%=JVMI*.HK"RU3*IKJ]BEWR!61E,@I=B__2XB"@HC.B!L:6(O5D93+VUU
M<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93
M(&9I;&4N(@IM<V=S='(@(L5VK:VDHZBL++5,JFNKV*7?(%9&4R#`R:[7+B(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS"FUS9VED(")!8V-O=6YT($EN
M9F]R;6%T:6]N(@IM<V=S='(@(K%BN+FXZK!4(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C<X"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@
M(K%BN+F[4+%+O5@B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y,PIM<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S='(@(K%BN+FD
M=ZWAM;(N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S-0IM<V=I
M9"`B06-C;W5N=&EN9R(*;7-G<W1R("*ULK%B(@H*(SH@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q"FUS9VED
M(")!9&0B"FUS9W-T<B`BMW.\5R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T
M(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B
M"FUS9W-T<B`BMW.\5Z:XN'.RU2(*"B,Z(&QI8B](;W)D92]097)M<R]522YP
M:'`Z.3@@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HY.0IM<V=I9"`B061D($-H
M:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`BMW.\5Z1LQ7:MK2(*"B,Z('1E;7!L
M871E<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!9&0@2&5R93HB"FUS9W-T
M<B`BIF*FN;=SO%<Z(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO
M9W)O=7!S+G!H<#HR,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B
MMW.\5[ASLM4B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C@W(&QI8B](
M;W)D92]097)M<R]522YP:'`Z.#@*;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO
M;B(*;7-G<W1R("*W<[Q7Q7:MK2(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O861D8VAI;&0N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@
M8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(K=SO%>FN+ASLM6H["!<
M(B5S7"(B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$T-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<
M(B(*;7-G<W1R("*W<[Q7IKC%=JVMIMQ<(B5S7"(B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S='(@(K=SO%>D
M0*W3J,^ESJK,.B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HU-3,*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`BMW.\5\3FINPB
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,T"FUS9VED
M(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`BMW.\5Z1`K=.FJ*W[.B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER
M(@IM<V=S='(@(K=SO%>Y[R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@
M36]Z:6QL82!3:61E8F%R(@IM<V=S='(@(K=SO%<@)7,@K+`@36]Z:6QL82"J
MNJ3`K;8B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C<Q
M"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R("*W<[Q7J.RJ
MNK-QL%2__3HB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C<X"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(K=S
MO%>H[*?:JKJS<;!4O_TB"@HC.B!A9&UI;B]U<V5R+G!H<#HS,0IM<V=I9"`B
M061D('5S97(B"FUS9W-T<B`BMW.\5ZC/I<ZJS"(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D(%PB)7-<(B!T
M;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I
M9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@(J1WMW.\5R!<(B5S
M7"(@J.RH=++.I*0N(*;]M4RJ:[=SO%?#0J5^JKJU^:55N.JP5#H@)7,N(@H*
M(SH@<VEG;G5P+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<
M(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G
M<W1R("*D=[=SO%<@7"(E<UPB(*CLJ'2RSJ2D+B"G0;)[IF*E::5(MFFFYK5N
MI$JD1BXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM
M<V=I9"`B061D:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("*W<[Q7
MJ,^ESJK,JKJE7*_@I=BK9;-1P_:SK"XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,30T-2!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$W,PIM<V=I9"`B
M061D<F5S<R(*;7-G<W1R("*F8:=](@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$T,0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(K-QL%2_
M_2(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I
M9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E
M<G,B"FUS9W-T<B`BIJBLL+K>LGJM^R`M(*RPJ.2E3*C/I<ZJS+-=J7?%=JVM
M(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E
M8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(KK>
MLGHB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0S"FUS9VED(")!
M9',B"FUS9W-T<B`BO'.G:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@
M(D%F9VAA;FES=&%N("BJ_+1)IKTI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06QB86YI82(*;7-G<W1R
M(")!;&)A;FEA("BJ_+JXI-JEIZC(*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HW-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D%L9V5R:6$B"FUS9W-T
M<B`B06QG97)I82`HJORZN*3.IU&HR"DB"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T<B`BMFRE
M\Z=/IE<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C$V"FUS9VED(")!;&EG;B(*;7-G<W1R("*Y[[OT(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I
M9"`B06QI9VYM96YT.B(*;7-G<W1R("*Y[[OTI.BFH3HB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R("*ITJ:S(@H*
M(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B
M"FUS9W-T<B`BJ=*FLZ1WQ>?#TJJZJ,^ESJK,(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM<V=I9"`B06QL($=R;W5P
M<R(*;7-G<W1R("*ITJ:SN'.RU2(*"B,Z(&QI8B](;W)D92]097)M<R]522YP
M:'`Z.3$@;&EB+TAO<F1E+U!E<FUS+V1A=&%T<F5E+G!H<#HW-0IM<V=I9"`B
M06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(JG2IK/%=JVM(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I
M9"`B06QL(&9O=7(@<VED97,B"FUS9W-T<B`BI7ZNV+UU(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$X-S4*;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E
M<W-E<R(*;7-G<W1R("*DN;-<IFZT6*W3N7&D;+9LI?.F8:=](@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4S.`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O
M9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`BI+FS7,7<I_.VM:78O7.X
MN:JZJZRZ03\B"@HC.B!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HU,#0*
M;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@(J1WIG.F8B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C8*;7-G:60@(D%L=&5R;F%T92!)35-0
M($QO9VEN(@IM<V=S='(@(L7<I_,@24U34""U;J1*(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4Q,0IM<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O
M<F0B"FUS9W-T<B`BQ=RG\R!)35-0(+%+O5@B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3`S"FUS9VED(")!;'1E<FYA=&4@24U34"!5<V5R;F%M92(*
M;7-G<W1R("+%W*?S($E-4U`@J,^ESJK,(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z,S4*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S
M(@IM<V=S='(@(L7<I_.Y<:1LMFRE\Z;MIWTB"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C$T,@IM<V=I9"`B06QT97)N871E('1E;7!L871E<R(*;7-G<W1R
M("+%W*?SO,NJ3R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z
M(@IM<V=S='(@(K3`I4ZDY:9R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@4V%M;V$B"FUS
M9W-T<B`B06UE<FEC86X@4V%M;V$@**S\Q%*P[<+$O*^HR"DB"@HC.B!L:6(O
M2&]R9&4O4')E9G,O54DN<&AP.CDU(&QI8B](;W)D92]0<F5F<R]522YP:'`Z
M,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N(@IM
M<V=S='(@(J1`K=.U3*[$JKJMR+-1J,^ESBXB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,34U"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA
M<R!O8V-U<F5D+B(*;7-G<W1R("*U;Z7-I$:D0*W3I;RJOJJZO_F[?BXB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4U"FUS
M9VED(")!;F1O<G)A(@IM<V=S='(@(D%N9&]R<F$@**9WN42FU2DB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X"FUS9VED
M(")!;F=O;&$B"FUS9W-T<B`B06YG;VQA("BF=ZWTJ=0I(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG
M=6EL;&$B"FUS9W-T<B`B06YG=6EL;&$@**9WIF.IU*YQ*2(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY
M(@IM<V=S='(@(K#.IE>E3K)ZIG.H^B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T<B`BM:JNUR(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G
M:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`B06YT87)C=&EC82`HJVZWI:1JL[`I
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU
M-@IM<V=I9"`B06YT:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R(")!;G1I9W5A
M(&%N9"!"87)B=61A("BF=[2CI<JN<:3.I-JZN*6LN4:N<2DB"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS-2!L:6(O
M2&]R9&4O0FQO8VLO54DN<&AP.C4X"B,Z('1E;7!L871E<R]A9&UI;B]S971U
M<"]I;F1E>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(L"S
MI<ZU>Z:A(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R"FUS9VED(")!
M<'!L:6-A=&EO;B!,:7-T(@IM<V=S='(@(L"SI<ZU>Z:ALDVSYB(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#`*;7-G:60@(D%P<&QI8V%T:6]N(&ES
M(')E861Y+B(*;7-G<W1R("+`LZ7.M7NFH:1WM$ZZ_"(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3
M:&%R97,B"FUS9W-T<B`BKDVESJCLJ=*FLZJZIKBF0*C)(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B
M"FUS9W-T<B`BI^6MXR(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H
M<#HX-#`*;7-G:60@(D%P<')O>&EM871E(%-I>F4B"FUS9W-T<B`BN7>F]*1J
MI'`B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`R
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B
M07!R:6PB"FUS9W-T<B`BI7RDZR(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3<Q"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`BJORI
MU*="I.4@*%=I;F1O=W,M,3(U-BDB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O<F%R+G!H<#HU.2!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV
M-@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW.`IM<V=I9"`B
M07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`BP*/!6<#)I&JD<"(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C4X(&QI8B](;W)D92]-24U%
M+U9I97=E<B]Z:7`N<&AP.C8U"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T
M9WHN<&AP.C<W"FUS9VED(")!<F-H:79E($YA;64B"FUS9W-T<B`BP*/!6<#)
MIE>ZV2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI
M;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W
M86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B"FUS
M9W-T<B`BIT&]5*EWK6ZG4K"C("5S(*JZM?FE5;;<(#\B"@HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E(%PB)7-<(B!A
M;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(J=!O52I=ZUNIU*PHR!<(B5S
M7"(@I4BDSJ7TIO.JNJ:XN'.RU2`_(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B07)G96YT:6YA(@IM<V=S
M='(@(D%R9V5N=&EN82`HJORNVJ?**2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T
M<B`B07)M96YI82`HJ,BL_*6GJ,@I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ-S(*;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@(JC(
MK/REIZC(I.4@*$%235-#24DM."DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,C@*;7-G:60@(D%R="(*;7-G<W1R("+#P+-.(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C,P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B
M"FUS9W-T<B`B07)U8F$@**K\OGRDVJYQ*2(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R(")!
M<V-E;G-I;VX@27-L86YD(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Y
M"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`BI.6F<L/`LTXB"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I9FEC(%)E
M9VEO;B(*;7-G<W1R("*HR*QW+Z33I:VL=J9AL,\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#(Y"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B
M969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`B
ML/6FYK[>IT"Z^\5`JV7%XZ7<O52[>[GON-P_(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C,Q,#(*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R
M("*DP+!TQ.:F["(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@(D%T
M=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R
M("+`?+C5IU*PHZ1`K=.DHZ9SIF*JNKASLM4N(@H*(SH@861M:6XO<&5R;7,O
M9&5L971E+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM
M97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`BP'RXU:=2L*.D0*W3I*.F
M<Z9BJKK%=JVM+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED
M(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB
M"FUS9W-T<B`BP'RXU;USO^BD0*W3I*.F<Z9BJKJX<[+5+B(*"B,Z('-E<G9I
M8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I9"`B071T96UP="!T;R!E9&ET
M(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R("+`?+C5O7._Z*1`K=.D
MHZ9SIF*JNJ9`J,DN(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C0@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#,*;7-G:60@(D%T=')I8G5T
M97,B"FUS9W-T<B`BQ-VIRB(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#8@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`BI$NDZR(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U
M<W1R86QI82(*;7-G<W1R(")!=7-T<F%L:6$@*+]$I&JG4:C(*2(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@
M(D%U<W1R:6$B"FUS9W-T<B`B075S=')I82`HMOBF8:=1*2(*"B,Z(&QI8B](
M;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@
M4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!
M=71H7V-R>7-Q;#H@I^2DHZCLJ=*[W:UNJKH@:6UA<""IM:;YKDVE\RXB"@HC
M.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED(")!=71H7V-Y
M<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET
M97,N(@IM<V=S='(@(D%U=&A?8WER=7,Z(*;XJD&ZW:C#I;RTHZC1N-.VM:3D
MM*DN(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B
M075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R(")!=71H7V-R>75S.B"GY*2CJ.RITKO=K6ZJNB!I;6%P(*FU
MIOFN3:7S+B(*"B,Z(&QI8B](;W)D92]!=71H+V9T<"YP:'`Z,S8*;7-G:60@
M(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N
M9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C
M:"XB"FUS9W-T<B`B(@HB075T:%]F='`Z(*?DI*.H[*G2N]VM;JJZ($944""I
MM:;YKDVE\RZ]T*VKMW.]<\2V(%!(4""HPZ5"I5ND2B`M+65N86)L92UF='`@
MO^\B"B*VM2RHTJ9P(&-O;F9I9W5R92`M+65N86)L92UF='`B"@HC.B!L:6(O
M2&]R9&4O075T:"]I;6%P+G!H<#HV-`IM<V=I9"`B075T:%]I;6%P.B!297%U
M:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?
M:6UA<#H@I^2DHZCLJ=*[W:UNJKH@24U!4""IM:;YKDVE\RXB"@HC.B!L:6(O
M2&]R9&4O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U.B!297%U
M:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?
M:W)B-3H@I^2DHZCLJ=*[W:UNJKH@:W)B-2"IM:;YKDVE\RXB"@HC.B!L:6(O
M2&]R9&4O075T:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@061D
M:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O
M<GDB"FUS9W-T<B`B075T:%]L9&%P.B"W<[Q7J,^ESJK,LV^VM:5<K^"EV*ME
MJ,.DHZ3DM*FEV+_]JD&PR"(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP
M.C,U-PIM<V=I9"`B075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@
M<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(D%U=&A?
M;&1A<#H@IU*PHZC/I<ZJS+-OMK6E7*_@I=BK9:C#I*.DY+2II=B__:I!L,@B
M"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HV,PIM<V=I9"`B075T:%]L
M9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(D%U=&A?;&1A<#H@I^2DHZCLJ=*[W:UNJKH@3$1!4""IM:;YKDVE\RXB
M"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS,SD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R(")!=71H7VQD
M87`Z(+5,JFNW<[Q7J,^ESJK,("5S+B"F^*I!OKFF7L"S.B(*"B,Z(&QI8B](
M;W)D92]!=71H+VQD87`N<&AP.C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!
M=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R(")!
M=71H7VQD87`Z(+5,JFNROK"CJ,^ESJK,("5S(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O;&1A<"YP:'`Z-#DY"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A
M<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A
M<#H@M4RJ:Z?SMW.HSZ7.JLP@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P
M+G!H<#HT,#4*;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@
M;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B
M075T:%]L9&%P.B"G\[=SJ,^ESJK,LV^VM:5<K^"EV*MEJ,.DHZ3DM*FEV+_]
MJD&PR"(*"B,Z(&QI8B](;W)D92]!=71H+VUC86PN<&AP.C0V"FUS9VED(")!
M=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B075T:%]M8V%L.B"GY*2CJ.RITKO=K6ZJNB!-0T%,(*FUIOFN
M3:7S+B(*"B,Z(&QI8B](;W)D92]!=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U
M=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R(")!=71H7W-M8F%U=&@Z(*?DI*.H[*G2N]VM;JJZ('-M
M8F%U=&@@J;6F^:Y-I?,N(@H*(SH@;&EB+TAO<F1E+TE-05`O061M:6XN<&AP
M.C$P-@IM<V=I9"`B075T:&5N=&EC871I;VX@870@24U!4"!S97)V97(@9F%I
M;&5D+B(*;7-G<W1R("))34%0(*;XJD&^N<7GP]*_^;M^+B(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")!=71H96YT
M:6-A=&EO;B!F86EL960B"FUS9W-T<B`BQ>?#TJ6BL=$N(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-R!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&AE
M;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`BQ>?#TJ6BL=$N("5S(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O<F%D:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE
M;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S='(@
M(E)!1$E54R#%Y\/2O_F[?BXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#<Q"FUS
M9VED(")!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS
M9W-T<B`B1E10(,7GP]*_^;M^+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HW,`IM
M<V=I9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D
M+B(*;7-G<W1R(")334(@Q>?#TK_YNWXN(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T
M<B`BI6FESJJZQ.:F[#HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S$@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S='(@(D%Z
M97)B86EJ86X@**C(MNNK]+5-*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS,`IM<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G
M:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`BK4FTNB(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U
M;F0@0V]L;W(B"FUS9W-T<B`BK4FTNL-#IN(B"@HC.B!L:6(O2&]R9&4O075T
M:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*
M;7-G<W1R(")K97)B97)O<R"Q2[U8O_F[?BXB"@HC.B!L:6(O2&]R9&4O075T
M:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N86UE+B(*
M;7-G<W1R(")K97)B97)O<R"HSZ7.JLRF5[K9O_F[?BXB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"86AA
M;6%S(@IM<V=S='(@(D)A:&%M87,@**3:JZ*PJ"DB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(W
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"86AR86EN
M(@IM<V=S='(@(D)A:')A:6X@**3:JDPI(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ-S,*;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@
M(JIIP[FJNJ[\I.4@*$E33RTX.#4Y+3$S*2(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HS-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A;F=L861E<V@B
M"FUS9W-T<B`B0F%N9VQA9&5S:"`HJ7.E6ZG4*2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HS,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S
M(@IM<V=S='(@(D)A<F)A9&]S("BDVJBIIF@I(@H*(SH@=71I;"]I8V]N7V)R
M;W=S97(N<&AP.C,Q"B,L('!H<"UF;W)M870*;7-G:60@(D)A<V4@9W)A<&AI
M8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(J?DI*.H
M[+G/I=REV+_](%PB)7-<(BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C$Y"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*;7-G:60@(D)A<V5L:6YE(@IM<V=S
M='(@(K#RO74B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#D@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8S"FUS9VED(")"96QA<G5S(@IM<V=S='(@(D)E;&%R=7,B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S4@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C,Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS
M9VED(")"96QG:75M(@IM<V=S='(@(D)E;&=I=6T@**3QIU&NR2DB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C,R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED
M(")"96QI>F4B"FUS9W-T<B`B0F5L:7IE("BHJ:B]M+4I(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C0P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HS,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F5N
M:6XB"FUS9W-T<B`B0F5N:6X@**BIN><I(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C0Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G
M<W1R(")"97)M=61A("BFRKQ]N48I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C0V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@
M(D)H=71A;B`HI*.DIBDB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`BI<VDZ2(*"B,Z
M(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HS-30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<
M(B!N;W0@9F]U;F0N(@IM<V=S='(@(J?DI*.H[,"SI<ZU>Z:A7"(E,B1S7"*J
MNK#/MO1<(B4Q)'-<(BXB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI
M;F,Z.3`*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(K#/MO2S7:EW
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")"
M;&]C:R!4>7!E(@IM<V=S='(@(K#/MO2KK+I!(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S
M='(@(K+*Q>DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#,@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8R"FUS9VED(")";VQI=FEA(@IM<V=S='(@(D)O;&EV:6$@**S!
MIU&Z^ZC(*2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,#<*;7-G
M:60@(D)O;VMM87)K<R(*;7-G<W1R("*NT<72(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`IM<V=I9"`B0F]R
M9&5R(@IM<V=S='(@(J[8O74B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*
M;7-G<W1R("*NV+UUI&JD<"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T
M<B`BKMB]=2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C`*;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B"FUS9W-T
M<B`B0F]S;FEA(&%N9"!(97)Z96=O=FEN82`HJFFD:*6GJ,BDSK;"P<FM]+K[
MJ+HI(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED(")";W1H
M(@IM<V=S='(@(J7^LZ$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W1S=V%N82(*;7-G<W1R(")";W1S
M=V%N82`HJFFEOJBZ*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(JFS
MLZ$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#<@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C,Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8S"FUS9VED(")";W5V970@27-L86YD(@IM<V=S='(@(D)O=79E="!)<VQA
M;F0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#0@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C0P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8R"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B0G)A>FEL("BDVJ;H*2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C0Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS
M9VED(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B
M0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C0R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT
M,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I
M($1A<G5S<V%L86TB"FUS9W-T<B`B0G)U;F5I($1A<G5S<V%L86T@**A:M=PI
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,W(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HT,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B0G5L9V%R:6$@**M/I5NG4:C(
M*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3D*;7-G:60@(D)U;&QE=&5D($QI<W0B"FUS9W-T<B`BMK6EV++%N+DB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S8@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C0T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS
M9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B0G5R:VEN82!&87-O("BEK+18
MK\>J:Z_!*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS.2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B0G5R=6YD:2`HNUJV
MJ:9A*2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#8*;7-G:60@
M(D--4R(*;7-G<W1R("*JJ:VQNMZR>B(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B0U)#(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3@*;7-G:60@(D-23"!$:7-T
M<FEB=71I;VX@4&]I;G1S(@IM<V=S='(@(D-23""DP+.APDDB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*
M;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`BP'BF<Z[FI+JN
M92XN+E]E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U,0IM
M<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T<B`B
MI]:H^JKLJ6RDQJE\I;RGN::H+B(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT.#(@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDX-PHC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,34W"FUS9VED(")#86QE;F1A
M<B(*;7-G<W1R("*FYJC&ON0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C,U"FUS9VED(")#86QM(@IM<V=S='(@(KESK\6MMR(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C0V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED
M(")#86UB;V1I82(*;7-G<W1R(")#86UB;V1I82`HK%JN2+GK*2(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HV,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@
M(D-A;65R;V]N(@IM<V=S='(@(D-A;65R;V]N("BSV+/!MJDI(@H*(SH@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S
M970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN
M:7-T<F%T;W(N(@IM<V=S='(@(K5,JFNFV[#*K:NX;;%+O5@LO=#!<+6XIT&J
MNJATLLZZWK)ZK?LN(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HS-3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W<FET92!T;R!F:6QE(%PB)7-<(B(*
M;7-G<W1R("*U3*IKO&>D2L#)KM<@7"(E<UPB(@H*(SH@861M:6XO<V5S<VEO
M;G,N<&AP.C(R"FUS9VED(")#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E
M<W-I;VX@:&%N9&QE<G,N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H
M+V-Y<G5S+G!H<#HR,S4@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HS,3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E
M<G9E<CH@)7,B"FUS9W-T<B`BM4RJ:[-SO76FW"!)34%0(*;XJD&^N3H@)7,B
M"@HC.B!L:6(O1FEL92]#4U8N<&AP.C0T-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#86XG="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G<W1R("*U3*IKMGVQTL#)
MKM<@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C0*;7-G:60@(D-A;F%D82(*;7-G<W1R(")#86YA9&$@**5;
MKK.D:BDB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z
M,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV
M-0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*;7-G<W1R
M("*H^J[X(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*
M;7-G:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R("*H^J[XL-W#
M1*9>L_@B"@HC.B!L:6(O5D93+V9T<"YP:'`Z,S(S"B,L('!H<"UF;W)M870*
M;7-G:60@(D-A;FYO="!D96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@(K5,
MJFNG4K"CP,FNUR!<(B5S7"(N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@;&EB+U9&4R])4T]7<FET
M97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R"FUS9VED(")#86YN
M;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(J?DI*.H
M[+S(IG.EV+_]+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+G!H<#HY,0IM<V=I
M9"`B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE
M=&5R+B(*;7-G<W1R("*ORJ36("=T87)G971&:6QE)R"PT;S&M4RJ:\1^Q/*S
M0K)Z+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R
M("*U3*IKLKZPHZ78O_T@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92]$871A5')E
M92YP:'`Z,3(X(&QI8B](;W)D92]$871A5')E92]S<6PN<&AP.C8X,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E
M>&ES="XB"FUS9W-T<B`BM4RJ:[*^L*,[("5D(*W3I&RVL*1WIG.F8BXB"@HC
M.B!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HV,#@*;7-G:60@(B(*(D-A
M;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@
M<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G
M<W1R("*U3*IKK:NRU:%#J=*THZC1JKJP3[_]O,:EV+M0I?VK9:G2P'BF<ZJZ
MN.JNQJ2CLL4N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE
M9"!N=6UB97(N(@IM<V=S='(@(K5,JFNVQ[!EPK*P5*CLJ_RI=ZJZN+F]6"XB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C4@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C0Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8X
M"FUS9VED(")#87!E(%9E<F1E(@IM<V=S='(@(D-A<&4@5F5R9&4@*+K[O'>H
MI"DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(T"FUS9VED(")#87!T:6]N(@IM<V=S='(@(KNAJ?JDY:9R(@H*
M(SH@;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0*(RP@9G5Z>GD*
M;7-G:60@(D-A<G)I97(B"FUS9W-T<B`BK[NL]:;B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDS"FUS9VED(")#871E9V]R:65S(&%N9"!,86)E;',B
M"FUS9W-T<B`BI,##_KM0O-#%TB(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@V"FUS9VED(")#87EM86X@27-L86YD<R(*
M;7-G<W1R(")#87EM86X@27-L86YD<R`HMGVPTKASKG$I(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO
M;F4B"FUS9W-T<B`BIN:PRKEQN-PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U"FUS9VED(")#96QL(%!R;W!E
M<G1I97,B"FUS9W-T<B`BP'BF<Z[FI+JN92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I
M;F<Z(@IM<V=S='(@(L!XIG.NYKG4I5(Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P
M<F]P97)T:65S(@IM<V=S='(@(L!XIG.NYJ2ZKF4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S
M<&%C:6YG.B(*;7-G<W1R("+`>*9SKN:VH;9:.B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,C<X"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`BIN:PRKEQ
MN-PB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-`IM<V=I9"`B0V5L=&EC
M("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`BMNNZN*]3I.4@*$E33RTX.#4Y+3$T
M*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R("*X;:2D(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C4T(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HU,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B
M0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@(D-E;G1R86P@069R
M:6-A;B!297!U8FQI8R`HI*2K1*9`J4VPZBDB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$W-0IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM
M,BDB"FUS9W-T<B`BI*2\VB`H25-/+3@X-3DM,C`B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL
M<R(*;7-G<W1R("*^S,/2LM.X8"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-C$R"FUS9VED(")#97)T:69I8V%T92!/=VYE<B(*;7-G<W1R("*^
MS,/2OM:FLZK,(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3<*
M;7-G:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(K[,P]*L1K6F
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`X"FUS9VED(")#:&%D(@IM<V=S='(@(D-H860@**QDO'<I(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHY-@IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(J?SI^\B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*;7-G:60@(D-H86YG
M92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(J?SI^^G0:JZL4N]6"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV.0IM<V=I9"`B(@HB0VAA;F=E('1H92!N
M86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A
M9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(J?SI^^G
M0:JZJKJE_J97I4BDSJ9>MFRF8:=]+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U<B!P87-S=V]R
M9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A
M=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R
M("*EV*MEJKJS7:EWJ,.EO*3DM*FQ2[U8Q=RG\RX@O=#!<+6XIT&JNKK>LGJM
M^RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(W"FUS9VED(")#:&%R(@IM<V=S='(@(J9RI+@B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*
M;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(L#+K&2S<[6R+BXN7VLB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3D@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C4S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W
M"FUS9VED(")#:&EL92(*;7-G<W1R(")#:&EL92`HM+RG42DB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C4T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#
M:&EN82(*;7-G<W1R(")#:&EN82`HI*2PZBDB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$W-@IM<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I
M(@IM<V=S='(@(L*RQ>FDI*3E("A'0C(S,3(I(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ-S<*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I
M(@IM<V=S='(@(J6_Q>FDI*3E("A":6<U*2(*"B,Z('1E;7!L871E<R]P<F5F
M<R]A<'`N:6YC.C<*;7-G:60@(D-H;V]S92!!<'!L:6-A=&EO;CHB"FUS9W-T
M<B`BO^^^W,"SI<ZU>Z:A.B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP
M:'`Z,C<P"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R("*_[[[<
ML4N]6"(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED
M(")#:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R("*_[[[<I$"MTZC/I<ZJS*97
MNMDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`R"FUS9VED(")#:&]O
M<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(J3IM,'%XZ7<I.BF
MH3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP
M95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T>7!E("AF
M;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`BO^^^W+:UI=BKK+I!JKJMMZ[F
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8V(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HU-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R(")#:')I<W1M87,@
M27-L86YD("BX=+W/KG$I(@H*(SH@;&EB+U9&4RYP:'`Z.3$S(&QI8B].970O
M4TU3+G!H<#HR.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI
M=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(J?DI*.H["`E<R"JNL/^
MIT^I=[AQ+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$T"FUS9VED(")#;&5A<B(*;7-G<W1R("*TN"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R
M($U33V9F:6-E('1A9W,B"FUS9W-T<B`BLDVPH[=,LVX@3V9F:6-E(+S0Q=(B
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"FUS9VED(")#;&5A<B!1=65R
M>2(*;7-G<W1R("*R3;"CK&2XWR(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V-L96%R+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U
M<V5R.B`E<R(*;7-G<W1R("*R3;"CJ,^ESJK,.B`E<R(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,0IM<V=I9"`B0VQE87(@=7-E<B(*
M;7-G<W1R("*R3;"CJ,^ESJK,(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;&ES="YI;F,Z,S0*;7-G:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R("*R
M3;"CJ,^ESJK,JKJXZJ[&(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,34*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B
ML=_"X+2X(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E
M+FAT;6PZ-C`*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(JOV
MM\:YJ\'DI4C$?L3R(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T<B`B
M0VQI8VMA=&5L;""S>KE,($A45%`B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP
M:'`Z,30V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L
M;W-E(%=I;F1O=R(*;7-G<W1R("+#]K.LM?BUH2(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C0T"FUS9VED(")#;&]U9',B"FUS9W-T<B`BMK.V<2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$V"FUS9VED
M(")#;&]U9',@16%R;'DB"FUS9W-T<B`BIJVF:+:S(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3<*;7-G:60@(D-L;W5D>2(*
M;7-G<W1R("*SL2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C0*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM
M<V=S='(@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]S:61E8F%R+FEN8SHR,PIM<V=I9"`B0V]L;&%P<V4@4VED96)A
M<B(*;7-G<W1R("*GZ<5\N.JNQJ>H(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D
M(&)O<F1E<G,B"FUS9W-T<B`BI^G%?,/DK,DB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;VQO;6)I82(*
M;7-G<W1R(")#;VQO;6)I82`HK?2MVZ3QJ,@I(@H*(SH@;&EB+T)L;V-K+V-O
M;&]R+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@
M(D-O;&]R(@IM<V=S='(@(L-#IN(B"@HC.B!L:6(O2&]R9&4O0FQO8VLO0V]L
M;&5C=&EO;BYP:'`Z,S(U(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H
M<#HS,C8*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4P
M,"!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@R"FUS9VED(")#
M;VQO<B!0:6-K97(B"FUS9W-T<B`BO=6FXKU,(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(X,S4*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B
M,3:V::;LPT.FXJ5.O5@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`BQ.8Z(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-3`*;7-G:60@(D-O;'5M;B!T:71L
M97,B"FUS9W-T<B`BQ.:F[+S0PT0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C8V"FUS9VED(")#;VUI8W,B"FUS9W-T<B`BI62S<2(*"B,Z(&%D
M;6EN+V-M9'-H96QL+G!H<#HR-0IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R("*I
M4J5/(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM86YD
M(%-H96QL(@IM<V=S='(@(J?EIKBI4J5/(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z-#$S"FUS9VED(")#;VUM96YT(@IM<V=S='(@(K7[O=<B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B0V]M;6]N
M($YA;64B"FUS9W-T<B`BNMFI22(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@T"FUS9VED(")#;VUO<F]S(@IM<V=S='(@
M(D-O;6]R;W,@**SLO*_#N2DB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R("*DO:5Q(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B
M"FUS9W-T<B`BN7&XHR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR.#8*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R("+`]+G2(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR-#D*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T
M<B`BL?BE\R(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED(")#
M;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S='(@(JYTLJ<B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30V"FUS9VED(")#;VYF:6=U<F%T:6]N
M(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO
M;VLN(@IM<V=S='(@(KM0(%!$02"T>*17JZRY<;BC++2\O'JKK*3BOO>E2*3.
M($]U=&QO;VL@JKJF4*A"LUVI=RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3,U"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*
M;7-G<W1R("*S7:EWN.JNQKE,M,$N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS
M9W-T<B`BLUVI=R`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z-3$*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`BO52[
M>[%+O5@B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-34@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8V"FUS9VED(")#;VYG;R(*;7-G<W1R(")#;VYG;R`HK>BJ1RDB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3,@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C8P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8U"FUS
M9VED(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM
M<V=S='(@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4@
M**WHJD>F0*E-L.HI(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C$Y.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS
M9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`BLW.ULJ6BL=$N(@H*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.2!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N
M(&9A:6QE9#H@(@IM<V=S='(@(K-SM;*EHK'1.B`B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HW.3`*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T
M;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`BLW.ULJ;<I+VV?:KW
MQE^F^*I!OKFNR;Y$J=HN(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M-SDR"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T
M;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S
M='(@(K-SM;*FW*2]MGVJ]\9?IOBJ0;ZYKLF^1*G:+B"M[*9=.B`E<R`H)7,I
M(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@V-0IM<V=I9"`B0V]N;F5C=&EO;B!T
M;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`BLW.ULJ;<($944"#`R:[7
MIOBJ0;ZYI:*QT2XB"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`Q-`IM
M<V=I9"`B0V]N=&%C=',B"FUS9W-T<B`BLW.UN*1((@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R
M92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM
M<V=S='(@(K!/O_VD=Z:HI5RF8;=SO%>FW*=!JKJS<;!4O_VDI"XB"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HV,`IM<V=I9"`B0V]N=&5N
M="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@(@IM<V=S='(@(L"CP5G`R:[7
MJKJDNJYEJZRZ03H@(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-38@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-S4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@(EPB)7-<(B#`R:[7
MI+JN92(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,PIM<V=I9"`B0V]N=&EN=64B"FUS
M9W-T<B`BQ'[$\B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU."!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R(")#;V]K
M($ES;&%N9',@**SLITJX<ZYQ*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS,@HC+"!F=7IZ>0IM<V=I9"`B0V]O:VEE(@IM<V=S='(@(L-#IN(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`BO<:[<R(*"B,Z(&QI8B]61E,O
M<VUB+G!H<#HT-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z
M("5S(@IM<V=S='(@(KW&NW.EHK'1.B`E<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T
M:6]N(@IM<V=S='(@(KW&NW,B"@HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP
M:'`Z,3<P(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O
M<W0@240B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8S
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R(")#
M;W-T82!2:6-A("BM]+2UI&J^I*5;*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HU-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O=&4@9"=)=F]I<F4B
M"FUS9W-T<B`B0V]T92!D)TEV;VER92`HMDBD^J[\J:0I(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z.3<W"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N
M8W)Y<'0@;65S<V%G93H@(@IM<V=S='(@(K5,JFNE2"!01U`@I5NQ2[9LI?,Z
M("(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$P-34*;7-G:60@(D-O
M=6QD(&YO="!01U`@<VEG;B!M97-S86=E.B`B"FUS9W-T<B`BM4RJ:Z5((%!'
M4""P]:;FMFRE\\.QL[DZ("(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z,SDS"FUS9VED(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G
M92XB"FUS9W-T<B`BM4RJ:Z5((%,O34E-12"E6[%+MFRE\RXB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@;F]T(%,O
M34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(K5,JFNLL"!3+TU)344@MFRE
M\\.QL[DN(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C$X
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A8W0N
M("5S(@IM<V=S='(@(K5,JFNW<[Q7LW.UN*1(+B`E<R(*"B,Z(&QI8B](;W)D
M92]'<F]U<"]L9&%P+G!H<#HY-B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ
M,C$*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G
M<W1R("*U3*IKP[2ULB!,1$%0(*;XJD&^N2(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HT-3<*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R
M=F5R(@IM<V=S='(@(K5,JFO#M+6R(&QD87`@IOBJ0;ZY(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C$U-B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C$W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`BM4RJ:\#+K&2W;*]Q
M+B`E<R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-#$*;7-G:60@(D-O
M=6QD(&YO="!C;VYN96-T('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(K5,JFNS
M<[6RIMP@;&1A<""F^*I!OKDB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@
M<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(K5,JFNS<[6R
MIMRF^*I!OKD@7"(E<UPB(*C/I<X@1E10.B`E<R(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T
M<B`BM4RJ:ZO8I=^P=+AMN'.RU2X@)7,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HQ,3(X"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T
M83H@(@IM<V=S='(@(K5,JFNXT;%+(%!'4""XZJ[&.B`B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4R,PIM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y
M<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(K5,JFNXT;%+(%,O34E-12"XZJ[&
M+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E
M<R(*;7-G<W1R("*U3*IKIU*PH[-SM;BD2"X@)7,B"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S
M='(@(K5,JFNG4K"CL'2X;;)-L^8N("5S(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E
M;&5T92!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(K5,
MJFNG4K"CI_.W<[5[IJ$@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z,S@Q(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.CDU,PIM<V=I
M9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL
M(&%D9')E<W,N(@IM<V=S='(@(K5,JFNH3:EWIJRE\Z1(JKJY<:1LMFRE\Z;L
MIWTN(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PIM
M<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB
M"FUS9W-T<B`BM4RJ:\#RJ/JGN;[CJKJS<;!4O_TN(@H*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PIM<V=I9"`B0V]U;&0@;F]T(&9E
M=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("*U3*IK
MP/*H^J>YON.JNK!TN&VR3;/F+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M
M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(K5,
MJFO`\JCZL'2X;;)-L^:DI*JZN'.RU2XB"@HC.B!L:6(O5D93+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z(&QI8B]61E,O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@
M(K5,JFNX_*1*M::RI"!<(B5S7"(N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z(&QI8B]61E,O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S
M='(@(K5,JFNKV*7?I=B__2!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z-S$Y"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K
M97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R("*U3*IKIMNJ]\9?IOBJ
M0;ZYJ/JQ;Z2]MGVJ]\9?+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S='(@
M(K5,JFNV?;'2(%PB)7-<(B"E2+QGI$HN(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8W-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,T-0HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R
M("*U3*IKMGVQTB`E<RXB"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP
M.C0R,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN
M=&5N86YC95]487-K(&UO9'5L92`E<R(*;7-G<W1R("*U3*IKMGVQTKK[Q4"D
M=:=`O-*RU2`E<R(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(K5,JFNV?;'2
MI=B__2!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$Q
M,2!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&QI8B](;W)D92]'
M<F]U<"]L9&%P+G!H<#HR,S<@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C0W
M.`HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-3$V(&QI8B](;W)D92]'
M<F]U<"]L9&%P+G!H<#HV,3(*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP
M.C8U-B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-CDY"FUS9VED(")#;W5L
M9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R("*U3*IKLW.Q
MM2!,1$%0(""F^*I!OKDN(@H*(SH@;&EB+U9&4R]/8FIE8W0N<&AP.C(T,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T
M<B`BM4RJ:\6JJ/H@)7,N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z.#4*;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@
M9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*
M(F1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C
M="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H
M96QP+B(*;7-G<W1R("(B"B*U3*IKK:NW<[-=J7>HSZ7.JLRJNK%+O5@N(+.A
MI,"JNK+3N&"DHZ6_O50N(+W0P7"UN*=!JKJH=++.NMZR>JW[I4BH\Z=5LT*R
M>BXB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#`*(SH@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-R!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S@S"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS.#D*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T
M<B`BM4RJ:\6JJ/JF<ZCZL;&H[JKM*$%C8V5S<R!#;VYT<F]L($QI<W0I(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K
M+B`E<R(*;7-G<W1R("*U3*IKQ:JH^K-QL%2__2X@)7,B"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B
M"FUS9W-T<B`BM4RJ:\6JJ/JP=+AMLDVE52X@)7,B"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM
M<V=S='(@(K5,JFO%JJCZL'2X;;)-I54N("5S(@H*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C$Y.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,C$Y"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HR,C,*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A
M8FEL:71I97,B"FUS9W-T<B`BM4RJ:\6JJ/JF^*I!OKFJNJS;P_:O4ZG*(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`IM<V=I9"`B0V]U;&0@;F]T
M(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("*U3*IKIEZT7[-=J7<N
M(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER
M(%PB)7-<(BXB"FUS9W-T<B`BM4RJ:Z=2L*.EV+_](%PB)7-<(BXB"@HC.B!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("*U
M3*IKP'BF<R`E<R"JNK-=J7<N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C8S(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y"FUS9VED(")#;W5L9"!N
M;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@(K5,JFO`
M>*9SL\:E][-=J7<N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O
M;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`BM4RJ:\!XIG.SQJ7WLUVI=SH@)7,N
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.34*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@
M=&\Z(%PB)7-<(BXB"FUS9W-T<B`BM4RJ:\!XIG.G\[=SM7NFH:CL.B!<(B5S
M7"(N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R
M871I;VX@9FEL92`E<RXB"FUS9W-T<B`BM4RJ:\!XIG.SQJ7WLUVI=R`E<RXB
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<U"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I
M;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO
M;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L
M;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*(K5,JFO`>*9S
MLUVI=\#))7,N(*=!I6FE2*C/I<XE<Z2DJKJHY*5,I5ROX,!XIG.S7:EWJ<ZD
MXK#*O<:[<Z15K;&U>Z:AO5BH["`E<RXB"@HC.B!L:6(O2&]R9&4O075T:"]L
M9&%P+G!H<#HQ-#,*;7-G:60@(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@
M<V5R=F5R+B(*;7-G<W1R("*U3*IKMVJT32!,1$%0(""F^*I!OKDN(@H*(SH@
M;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S
M7"(N(@IM<V=S='(@(K5,JFNG4K"C(%PB)7-<(BXB"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`BM4RJ:Z?S
MMW.S<[6XI$@N("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C,Y-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("*U3*IKI_.W<[!TN&VR
M3:55+B`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F
M;W(@7"(E<UPB.B`E<R(*;7-G<W1R("*U3*IKPM"\9R!<(B5S7"(Z("5S(*JZ
MLUVI=RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<P"FUS9VED(")#
M;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T
M:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R("*GY*2CJ.P@36]Z:6QL82"J
MNJ3`K;8N(+W0O52[>Z3`K;:L3Z=?MGVQTBXB"@HC.B!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,34T"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(D-O=6QD;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H
M=',@9F]R('1H92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R("*U3*IKO>&D
MJ:C/I<ZJS"!<(B5S7"(@I%6F0\5VK:VH[*M(I?.G6"!<(B5S7"(Z("5S(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C,*;7-G:60@(D-O=6YT960@=&5X
M="(*;7-G<W1R("*GWK-.I7DB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4W,`IM<V=I9"`B0V]U;G1R>2(*;7-G<W1R("*PZJYA(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W-0IM<V=I9"`B0V]U<G-E<R(*;7-G
M<W1R("*]TJKM(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B
MJ]BEWR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV.`IM<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R("*K
MV*7?I$"MT[-SM;(B"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE
M8W0N:6YC.CDT"FUS9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(JO8
MI=^D0*W3MW.JNB(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HY,@IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(JO8I=^F
MN*M(I?.G6"(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,C0P"FUS9VED
M(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(JO8I=^JS*JZQ7:MK2(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C$Y"FUS9VED(")#<F5D:70@8V%R
M9"!N=6UB97(B"FUS9W-T<B`BJTBESJ5DN+F]6"(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8T
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")#<F]A=&EA
M(@IM<V=S='(@(D-R;V%T:6$@**=*P[FFZ*C(*2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HV-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS
M9W-T<B`B0W5B82`HI6JDVBDB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*
M(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`BI=BK
M9:JZI.NLVR(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`IM<V=I9"`B0W5R
M<F5N="!397-S:6]N<R(*;7-G<W1R("*EV*MEMWRTP2(*"B,Z(&QI8B]";&]C
M:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R
M<F5N="!4:6UE(@IM<V=S='(@(J78JV6NR;:A(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4T"FUS9VED(")#
M=7)R96YT(%523"!I<R(*;7-G<W1R("*EV*MENO2G?2(*"B,Z(&%D;6EN+W-E
M<W-I;VYS+G!H<#HS-0IM<V=I9"`B0W5R<F5N="!5<V5R<R(*;7-G<W1R("*E
MV*MEJKJHSZ7.JLPB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS9VED
M(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`BI=BK9:31KO`B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8T"FUS9VED(")#=7)R96YT(&-O
M;F1I=&EO;CH@(@IM<V=S='(@(J78JV6JNJJLJG`Z("(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E
M;G0@<W1Y;&4B"FUS9W-T<B`BI=BK9:JZK;>NYB(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE
M('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R("*FVZUQ
MI$"HQ[5NI$HE<ZOAJ=*M;K#UIN:JNJ1UIT`N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED(")#
M=70B"FUS9W-T<B`BL,6D52(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I;VXB"FUS9W-T
M<B`BL,6D52(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C@*;7-G:60@(D-Y<')U<R(*;7-G<W1R(")#>7!R=7,@*,')M+:P
MQ[2U*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED(")#>7)I
M;&QI8R`H2T])."U2*2(*;7-G<W1R("*FZ*B]NKBDY2`H2T])."U2*2(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")#>7)I;&QI8R`H5VEN
M9&]W<RTQ,C4Q*2(*;7-G<W1R("*FZ*B]NKBDY2`H5VEN9&]W<RTQ,C4Q*2(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS9VED(")#>7)I;&QI8R]5
M:W)A:6YI86X@*$M/23@M52DB"FUS9W-T<B`BINBHO;JXI.4OKU&G2L3UI.4@
M*$M/23@M52DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8Y"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R(")#>F5C
M:"!297!U8FQI8R`HL;:G2J9`J4VPZBDB"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P
M"FUS9VED(")$1"(*;7-G<W1R("*DZ2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HS,C<P"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T
M+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I
M(@IM<V=S='(@(B(*(KCJKL:HT[>]IE>ZV2`HO="PT:;2(&AT='`Z+R]P96%R
M+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M
M(@HB9'-N+G!H<"DB"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4Y
M"FUS9VED(")$86EL>2(*;7-G<W1R("*H0Z3I(@H*(SH@861M:6XO9&%T871R
M964N<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@(K[P
MJJRXZJ[&PG/$_2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C8X"FUS9VED
M(")$871A8F%S92!,;V]K=7`B"FUS9W-T<B`BN.JNQJYWMVJT32(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR-#`R(&QI8B](;W)D92]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C<R"FUS9VED(")$871E(@IM<V=S='(@(J3IM,$B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T
M92!296-E:79E9"(*;7-G<W1R("*FK*CLI.FTP2(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR-SDV"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R("*_
M[[[<I.FTP2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#$@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B1&%Y(@IM
M<V=S='(@(J75I-$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM
M<V=S='(@(J=2L*/$YJ;L7VPB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$P(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`BI%&D1Z3K(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHQ-@IM<V=I9"`B1&5C:6UA;"!N=6UB97)S(@IM<V=S='(@(J11MFFF[+S&
MIG(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`BM.ZDUL%9L<8B
M"@HC.B!L:6(O<')E9G,N<&AP.C$Q-R!L:6(O2&]R9&4O4')E9G,O54DN<&AP
M.C$X-PIM<V=I9"`B1&5F875L="(*;7-G<W1R("*Y=[-=(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-S<*;7-G:60@(D1E
M9F%U;'0@0V]L;W(B"FUS9W-T<B`BN7>S7<-#IN(B"@HC.B!L:6(O2&]R9&4O
M261E;G1I='DN<&AP.CDV"FUS9VED(")$969A=6QT($ED96YT:71Y(@IM<V=S
M='(@(KEWLUVJNJBMI??#T:=/(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C8W"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@(KEWLUVI4J5/N-&J
M4KZY*%-H96QL*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,PIM<V=I
M9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`BJ7>X<2(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-S$@;&EB+TAO<F1E+U!E<FUS+G!H<#HS,C8@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HT,C(*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,SD@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C<P('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3,*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ.#(@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY."!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V1E;&5T92YI;F,Z,3`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*;7-G<W1R("*G4K"C(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R
M"FUS9VED(")$96QE=&4@0V5L;"(*;7-G<W1R("*G4K"CP'BF<Z[F(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR,C<*;7-G
M:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R("*G4K"CN'.RU2(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T.0IM<V=I9"`B1&5L971E($QO9R(*
M;7-G<W1R("*G4K"CK/:__2(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z
M-S<@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ,#$*;7-G:60@(D1E;&5T92!0
M97)M:7-S:6]N(@IM<V=S='(@(J=2L*/%=JVM(@H*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E
M(&UE<W-A9V5S(@IM<V=S='(@(J=2L*.A0K)-JL6V;*7S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I
M9"`B1&5L971E(&-E;&PB"FUS9W-T<B`BIU*PH\!XIG.NYB(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*;7-G
M:60@(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`BIU*PH\3FINPB"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L
M=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("*G4K"CLGNF<ZJZM,"E3KS+JD\B
M"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C0R,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R
M("*G4K"C7"(E<UPBJKK%=JVM(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS
M(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@
M(KU4J7>M;J=2L*-<(B5S7"*JNL5VK:VE2*3.IKC%=JVM(#\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS
M9VED(")$96QE=&4@<F]W(@IM<V=S='(@(J=2L*.F0R(*"B,Z('1E;7!L871E
M<R]P<F5F<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S
M96QE8W1E9"!I9&5N=&ET>2(*;7-G<W1R("*G4K"CJ=*_[[[<JKJHK:7WP]&G
M3[CJKL8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU
M;6XB"FUS9W-T<B`BIU*PHZ78JV6JNL3FINPB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@(D1E
M;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`BIU*PHZ78JV6JNJ9#(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM
M<V=S='(@(J?SMW.U>Z:A(%PB)7-<(B"D=Z=2L*,N(@H*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4V,R!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3DU"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C(Q(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S
M"FUS9VED(")$96QI=F5R>2!T:6UE(@IM<V=S='(@(KN\L&6NR;:A(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<Q(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HV.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I
M9"`B1&5N;6%R:R(*;7-G<W1R(")$96YM87)K("BDIK/!*2(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T
M:&4@4')O8FQE;2(*;7-G<W1R("*PW<-$M'FM>B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HY-#(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`BM'FM
M>B(*"B,Z(&QI8B](;W)D92YP:'`Z,3DW"FUS9VED(")$971A:6QS("AA;'-O
M(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@(K+3N&`@*+W0L-&FTB!(
M;W)D92"P3[_]P,FNURDZ(@H*(SH@;&EB+TAO<F1E+G!H<#HR,#$*;7-G:60@
M(D1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T
M;W(N(@IM<V=S='(@(K+3N&"]T+#1IM*H=++.NMZR>K5NO_TN(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R,0IM<V=I9"`B1&5V96QO<&UE;G0B
M"FUS9W-T<B`BK..U;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$W"FUS
M9VED(")$97<@4&]I;G0B"FUS9W-T<B`BQ5/"2;?%J]<B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(Y-`IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO
M=7(Z("(*;7-G<W1R("*SS*OAI$"D<*[)JKK%4\))M\6KUSH@(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-@IM<V=I9"`B1&5W('!O:6YT
M.B`B"FUS9W-T<B`BQ5/"2;?%J]<Z("(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L969T
M('1O(')I9VAT(@IM<V=S='(@(K%QI:JFW*5K(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N
M(')I9VAT('1O(&QE9G0B"FUS9W-T<B`BL7&E:Z;<I:HB"@HC.B!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(J78
MO_TB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<P"FUS9VED(")$:7-P
M;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@(J5((#(T(*1PKLFH[L7CI=P_
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,`IM<V=I9"`B1&ES<&QA
M>2!/<'1I;VYS(@IM<V=S='(@(L7CI=R_[[:U(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C@Y"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O
M<F5C87-T(@IM<V=S='(@(L7CI=RXU++3JKJY=[/X(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HX-0IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*
M;7-G<W1R("+%XZ7<N7>S^"`H5$%&*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR.#`V"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R("+%XZ7<KN:F
MH2(*"B,Z(&QI8B](;W)D92]-24U%+TU$3BYP:'`Z,3DP"FUS9VED(")$:7-P
M;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`BML>P9:9>L?@B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C8Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED
M(")$:FEB;W5T:2(*;7-G<W1R(")$:FEB;W5T:2`HIDZEK*9A*2(*"B,Z(&QI
M8B](;W)D92]097)M<R]522YP:'`Z-#(R"FUS9VED(")$;R!N;W0@9&5L971E
M(@IM<V=S='(@(J2CIU*PHR(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC
M92YP:'`B"FUS9W-T<B`BI*.M;JJ]L;6F<ZCZ(&UA:6YT96YA;F-E+G!H<"(*
M"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$R('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C$R"FUS9VED(")$;V5S('1H92!F:7)S="!R;W<@
M8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B
M;W@Z(@IM<V=S='(@(K+$I$"UI[!/O_VL3Z=?I5VG=,3FINRF5[K9/R"F<*I'
MK$^]T*3$O^\N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<R(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B1&]M:6YI8V$@
M**9HJ?JEIZ5;*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S`*;7-G:60@(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R
M(")$;VUI;FEC86X@4F5P=6)L:6,@**9HJ?JEIZ5;ID"I3;#J*2(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@
M86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`BP=FH4Z:SL6*XN;;</R"U
M^:55+B(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-3$*;7-G
M:60@(D1O=VYL;V%D(@IM<V=S='(@(J15N/PB"@HC.B!L:6(O2&]R9&4O34E-
M12]#;VYT96YT<RYP:'`Z.#4Q"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL
M;V%D("5S(@IM<V=S='(@(J15N/P@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,38R"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A
M=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R("*D5;C\LUVI=\#)KM>E=*9S
MK+`@4$A0(+5[IJ$N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,3$*;7-G
M:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@(J15J=2E7*_@JNTB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@
M(L/$JWXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@
M(D4M36%I;"(*;7-G<W1R("*Y<:1LMFRE\R(*"B,Z(&QI8B].970O4TU3+V=E
M;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y
M(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V
M:6-E+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R("*_^;M^
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<U(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HW,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M,`IM<V=I9"`B16-U861O<B(*;7-G<W1R(")%8W5A9&]R("BDS*7*IFBZN"DB
M"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C,R-2!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-CD@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S
M.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,2!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z-S(*(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET
M+FEN8SHR-0IM<V=I9"`B161I="(*;7-G<W1R("*]<[_H(@H*(SH@;&EB+TAO
M<F1E+T)L;V-K+U5)+G!H<#HU,"!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC
M.C(U"FUS9VED(")%9&ET($)L;V-K(@IM<V=S='(@(KUSO^BPS[;T(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H<#HR,C8*;7-G
M:60@(D5D:70@1W)O=7`B"FUS9W-T<B`BO7._Z+ASLM4B"@HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C<V(&QI8B](;W)D92]097)M<R]522YP:'`Z,3`P
M"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`BO7._Z,5VK:TB"@HC
M.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"FUS9VED(")%9&ET(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(KUSO^C%=JVM(@H*(SH@<V5R=FEC97,O<VAA
M<F5S+V5D:70N<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E
M<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("*]<[_H)7.JNL5VK:TB"@HC.B!T
M96UP;&%T97,O<')E9G,O87!P+FEN8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@
M9F]R.B(*;7-G<W1R("*]<[_HO^^VM2(*"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO
M;G,@9F]R(%PB)7-<(B(*;7-G<W1R("*]<[_H7"(E<UPBJKK%=JVM(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("*]<[_H)7.J
MNL5VK:TB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D
M=6-A=&EO;B(*;7-G<W1R("*QT*A\(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C<W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`B
M16=Y<'0@**Y*I,XI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`W"FUS9VED(")%;"!386QV861O<B(*;7-G<W1R(")%
M;"!386QV861O<B`HPL2ZN*7+IF@I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M96YT
M+BXN(@IM<V=S='(@(J2XI?,N+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S,@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HR,C0*;7-G:60@(D5M86EL(@IM<V=S='(@(KEQI&RV
M;*7S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-C8@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"FUS9VED(")%;6%I;"!!9&1R97-S(@IM
M<V=S='(@(KEQI&RV;*7SINVG?2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M.38W"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS9W-T
M<B`BN7&D;+9LI?.F[:=]I;*VMZ=KIE@N(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$Y.3,*;7-G:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S
M='(@(KEQI&RV;*7SO52[>R(*"B,Z(&QI8B].970O4TU3+V=E;F5R:6-?<VUT
M<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E=V%Y(@IM<V=S='(@
M(D5M86EL+71O+5--4R"Y:+E$OKDB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,CDW"FUS9VED(")%;6]T:6-O;G,B"FUS9W-T<B`B
MJNVQH;+%N+DB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P,@IM<V=I9"`B16UP='D@;65S<V%G92XB"FUS9W-T<B`BJL6EU:M(I?,N
M(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C(T,R!L:6(O2&]R9&4O
M1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H
M<#HV-C(@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!L:6(O2&]R
M9&4O075T:"]L9&%P+G!H<#HQ-3`*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS
M9W-T<B`BJL6EU;6RJD<N(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP
M:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`BJL6E
MU;=JM$VVM:78(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T-PIM<V=I
M9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL
M97)I97,@:6X@=&5X=#\B"FUS9W-T<B`BI+FS7*;;P\"T6;2AI$JWTZ3YJ.RK
M2*7SI*0HNO2MMKUSO&>\TJ:A*2`_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4R,@IM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N
M=3\B"FUS9W-T<B`BL=*PRK?&N:NE:\'DI5ROX*KM/R(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR-3DR(&QI8B](;W)D92]&;W)M+G!H<#HR.#`P"FUS9VED
M(")%;F0@>65A<B(*;7-G<W1R("*ULJ?TIGZE]R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@
M161I=&]R(@IM<V=S='(@(JGQI&J]<[_HOKDB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C(T"FUS9VED("(B"B)%;G1E<B!A('-E8W5R:71Y('%U97-T
M:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E
M<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@
M;V8@>6]U<B!P970_)SHB"FUS9W-T<B`BIG"J1Z=!N]VM;JVKLUVQ2[U8++W0
MO^FD2J1`K=.F=Z7^L-VE>2RHTJ9P(">G0<-DJJNJNJ97NMD@/R<Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T
M<B`BIF*FN;_II$J\=KFSJKJZ]*=](@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C@X.0IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@
M8F5L;W<Z(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY
M.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM
M<V=S='(@(D5Q=6%T;W)I86P@1W5I;F5A("BHJKE$M%BDNJC(*2(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HW.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@
M(D5R:71R96$B"FUS9W-T<B`B17)I=')E82`HI,REWZ]3J+VF=RDB"@HC.B!L
M:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0X(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S8*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HX,@IM
M<V=I9"`B17)R;W(B"FUS9W-T<B`BO_F[?B(*"B,Z(&QI8B](;W)D92]496UP
M;&%T92YP:'`Z-#8S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&-R96%T
M:6YG(&)L;V-K.B`E<R(*;7-G<W1R("*KV*7?L,^V]"5SKLFU;Z7-O_F[?B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C<R"B,L('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G
M<W1R("*G4K"CIE"H0L'CPDDZ("5S(*[)M6^ES;_YNWXB"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B"FUS9W-T<B`BIU*PHZ90J$*P
M3[_].B`E<R"NR;5OI<V_^;M^(@H*(SH@;&EB+TAO<F1E+U1E;7!L871E+G!H
M<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT
M96YT.B`E<R(*;7-G<W1R("+%JJCZI+JN93HE<R"NR;5OI<V_^;M^(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*
M;7-G:60@(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<R(*;7-G<W1R("*G
M\[=SL4N]6#H@)7,@KLFU;Z7-O_F[?B(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`U"B,L(&9U>GIY"FUS9VED(")%<G)O<B!W:71H
M(&5M86EL(&UE<W-A9V4N(@IM<V=S='(@(KUSO^BD0*MHL%2NIR(*"B,Z(&QI
M8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB
M"FUS9W-T<B`BO&>D2B!<(B5S7"(@KLFU;Z7-O_F[?BXB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C<W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%<W1O
M;FEA(@IM<V=S='(@(D5S=&]N:6$@*+=2J$:EIZC(*2(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HX,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T:&EO
M<&EA(@IM<V=S='(@(D5T:&EO<&EA("BFYZ_!I/&HR"DB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R("*ZV+':
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P
M92(*;7-G<W1R(")%=7)O<&4@*+S:K'<I(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,T,PIM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R("*H
M0R`Q-2"DP,3!(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,PIM<V=I
M9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(JA#(#(@I,#$P2(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,Y,0IM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R("*H0R`S,""L
M[<3!(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,SDT"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T
M<B`BJ$,@-2"DP,3!(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HV
M,`IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T<B`BJ$.FN+5NI$HB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0T"FUS9VED(")%=F5R>2!H86QF(&AO
M=7(B"FUS9W-T<B`BJ$,@,S`@I,#$P2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-#$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,@IM<V=I9"`B179E
M<GD@;6EN=71E(@IM<V=S='(@(JA#(#$@I,#$P2(*"B,Z('1E;7!L871E<R]D
M871A+V1A=&5M87`N:6YC.C(T"FUS9VED(")%>&%M<&QE('9A;'5E<SHB"FUS
M9W-T<B`BO62HTJW(.B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HX,2!A9&UI
M;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP.C$R-PIM<V=I
M9"`B17AE8W5T92(*;7-G<W1R("*P]:;F(@H*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="YP:'`Z-#<U"FUS9VED(")%>'!A;F0B"FUS9W-T<B`BKFFV?2(*
M"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S(*;7-G:60@(D5X
M<&%N9"!3:61E8F%R(@IM<V=S='(@(JYIMGVXZJ[&IZ@B"@HC.B!L:6(O2&]R
M9&4O4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D("<I)R(*
M;7-G<W1R("*M;JA$("<I)R(*"B,Z(&QI8B](;W)D92]344PO2V5Y=V]R9',N
M<&AP.C$W-0IM<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S
M96%R8V@@=&5R;2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HT,3(*;7-G:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R("*H[+3!
MI.DB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8W-PIM<V=I9"`B
M17AP;VYE;G0B"FUS9W-T<B`BN-&[H:W[(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L
M;W(B"FUS9W-T<B`BJV6TNL-#IN(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3<W"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(D94
M4""D5[;'LUVI=RXB"@HC.B!L:6(O2&]R9&4O4')E9G,O<W%L+G!H<#HR,C4*
M;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+B(*;7-G<W1R
M("+%JJCZL+ZF;K-=J7>EHK'1(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N
M<&AP.C<U(&QI8B](;W)D92]!=71H+VQD87`N<&AP.CDX"FUS9VED(")&86EL
M960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`BM4RJ:[-S
MO76FW"!,1$%0(*;XJD&^N2XB"@HC.B!L:6(O2&]R9&4O075T:"]S;6(N<&AP
M.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*
M;7-G<W1R("*U3*IKLW.]=:;<(%--0B"F^*I!OKDN(@H*(SH@;&EB+U9&4R]F
M='`N<&AP.C<P-@HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P
M>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`BO<:[<Z6BL=&FVR!<(B5S7"(N(@H*
M(SH@;&EB+U9&4R]F='`N<&AP.C<Q,0HC+"!P:'`M9F]R;6%T"FUS9VED(")&
M86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(KW&NW.EHK'1J.P@
M7"(E<UPB+B(*"B,Z(&QI8B](;W)D92]!=71H+W-A<VPN<&AP.C@W"FUS9VED
M(")&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S
M='(@(K5,JFNKV*7?I$"MT[=SJKH@4T%33""S<[&U+B(*"B,Z(&QI8B]61E,O
M<VUB+G!H<#HU,#$@;&EB+U9&4R]F='`N<&AP.C<T-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(K=H
MLKZEHK'1J.P@7"(E<UPB+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HT-C4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G
M<W1R("+"7JCZI:*QT3H@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R("*TMK-Q(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@T(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HW.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,@IM
M<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@(D9A
M;&ML86YD($ES;&%N9',@JFO$]:=*NM:X<ZYQ("BPJ+JXNONOQ[2UN'.N<2DB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#8@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C@P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S
M"FUS9VED(")&87)O92!)<VQA;F1S(@IM<V=S='(@(D9A<F]E($ES;&%N9',B
M"@HC.B!L:6(O2&]R9&4O0TQ)+G!H<#HR,S@*;7-G:60@(D9A=&%L($5R<F]R
M.B(*;7-G<W1R("+$6:VKO_F[?CHB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@(K;'KW4B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4Q"FUS9VED(")&87AE<R(*
M;7-G<W1R("*VQZ]U(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P,"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(J1'I.LB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(R,`IM<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R("*W
M4,2Q(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,`IM<V=I
M9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(K=0Q+$Z("(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Y"FUS9VED(")&97<@4VAO
M=V5R<R(*;7-G<W1R("*D\J3RJT(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*
M;7-G<W1R("*U=;S(L'VSMR(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.30X
M"FUS9VED(")&:65L9"!M871R:7@B"FUS9W-T<B`BQ.:F[+!]ID,B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,S,R,PIM<V=I9"`B1FEG;&5T($-!4%1#2$$B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,C<*(RP@9G5Z
M>GD*;7-G:60@(D9I9VQE="!F;VYT(@IM<V=S='(@(K_OOMS`R:[7I4BVUZ1*
M.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B1FEJ:2`HM+3`V2DB"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(D9I
M;&4B"FUS9W-T<B`BP,FNUR(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R
M87(N<&AP.C8P(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`BP,FNU[S&
MI=@Z("5S(*W3P,FNUR(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N
M<&AP.C8P(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(L#)KM>\QJ78
M.B`E<R#`R:[7(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P.0IM
M<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S='(@(L#)KM?!8+K>(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S`*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#(*;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R("+`R:[7IE>ZV2(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.3@T"FUS9VED(")&:6QE('-E;&5C
M=&EO;B(*;7-G<W1R("+`R:[7O^^^W"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ-#DP"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R("+`R:[7I%>VQR(*
M"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HX.#4*;7-G:60@(D9I;&4@=7!L
M;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("+`R:[7I%>VQZ5<K^"EO+-1
MI.2TJ2XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3$*;7-G:60@
M(D9I;'1E<G,B"FUS9W-T<B`BN4S";[ZY(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C@R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B1FEN;&%N9"(*;7-G
M<W1R(")&:6YL86YD("BJXL3U*2(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ
M-C8*;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T<B`BI%>E8J3K(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I
M9"`B1FER<W0@475A<G1E<B(*;7-G<W1R("*D5ZFV(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U-0IM<V=I9"`B1FEX(')A=&EO
M(@IM<V=S='(@(JE4J7>D\:C2(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(S,`IM<V=I9"`B1FQI<"(*;7-G<W1R("*D5Z15Q$&M
MRR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(J]"L,HB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G
M(@IM<V=S='(@(L/Z(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C(S-R!L:6(O5D93
M+VUU<W%L+G!H<#HQ,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S
M(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(J78O_T@)7,@I*.F<Z9B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I
M9"`B1F]N="!#;VQO<B(*;7-G<W1R("*F<JNLPT.FXB(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R("*MN:JK(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(V"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P
M;W)T(&EM86=E<R(*;7-G<W1R("*F7:RPPG/$_;ZYJ,.EO*3DM*F\=KFSI5RO
MX"XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S-`IM<V=I9"`B1F]R96-A
M<W0@*%1!1BDB"FUS9W-T<B`BKO"V2+EWL_@@*%1!1BDB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S(*;7-G:60@(B(*(D9O<F5C87-T($1A
M>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B
M;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@8V]U
M;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@HBN7>S^*31
MO,8@*+EWL_BDT;S&I5VL0:75I-&E2*3.J5VVH:JZN.JNQCNF<*I'N7>S^*31
MO,:X^ZKXL4ZF^Z7.I/&X^[QEM%2JNJJI(@HBK;$I(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHQ,#(*;7-G:60@(D9O<F=O="!Y;W5R('!A<W-W
M;W)D/R(*;7-G<W1R("*GT;!/L4N]6"`_(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0V-`IM<V=I9"`B1F]R;7,B"FUS9W-T<B`BJNVSYB(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*;7-G
M<W1R("*D<+MY(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED
M(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`BI'"[></^JZPB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S@*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(J1P
MNWDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U
M;F5S(#(B"FUS9W-T<B`BI'"[>2`R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0U-0IM<V=I9"`B1F]R=6US(@IM<V=S='(@(KW7OL(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3$Q"FUS9VED(")&;W)W87)D<R(*
M;7-G<W1R("*FV[#*PN"K2"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S='(@(JQ0M,&DK2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S,*;7-G:60@(D9R86UE<R(*;7-G<W1R("*NV*Q;(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C@W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HX,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A
M;F-E(@IM<V=S='(@(D9R86YC92`HJFNPZBDB"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS
M9W-T<B`B1G)A;F-E+"!-971R;W!O;&ET86XB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z.3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I
M86YA(@IM<V=S='(@(D9R96YC:"!'=6EA;F$@**IKQ-V[7*C(J+HI(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G
M:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B1G)E;F-H(%!O;'EN97-I
M82`HJFO$W:S!IU&EIZ;HJ,@I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(R,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@
M5&5R<FET;W)I97,B"FUS9W-T<B`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R
M:65S(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*
M;7-G:60@(D9R;VTB"FUS9W-T<B`BL4BE\Z1((@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S-R!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S0Y"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.34*;7-G
M:60@(D9R;VT@=&AE("(*;7-G<W1R("*Q<2(*"B,Z('1E;7!L871E<R]P<F]B
M;&5M+W!R;V)L96TN:6YC.C0X"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM
M<V=S='(@(J>YON.T>:UZ(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI
M8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R
M("*ZH:3K(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*;7-G:60@(D9U;&P@3F%M92(*
M;7-G<W1R("*E_J97(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@X(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW,PIM<V=I9"`B1V%B;VXB"FUS9W-T<B`B1V%B;VX@**5;
MM%XI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@
M9G)O;2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM
M<V=S='(@(L/`M%DZ(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDV(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX.`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW-0IM<V=I9"`B1V%M8FEA(@IM<V=S='(@(D=A;6)I82`H
MI<RD\:C(*2(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G
M<W1R("*RHZ7-("5S(*W3J'2RSK-=J7<B"@HC.B!T96UP;&%T97,O861M:6XO
M<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS
M9W-T<B`BI'>RHZ7-JKJS7:EWN.JNQB(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HY,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T
M<B`B1V5O<F=I82`HL^RJ=JC(ID"I3;#J*2(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HV.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS
M9W-T<B`B1V5R;6%N>2`HO'>PZBDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':&%N82(*;7-G<W1R(")'
M:&%N82`HK7NOQRDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.30@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<U"FUS9VED(")':6)R86QT87(B"FUS9W-T<B`B1VEB<F%L
M=&%R("BJO:6LP[FJ^RDB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4W-@IM<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R("*F5[K9(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3(*;7-G:60@(D=O(@IM<V=S='(@(JME
MJ;DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O961E
M;"(*;7-G<W1R("*M]+QWNK@B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3$R.`IM<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B
M1V]O9VQE(*9AN<\B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS
M9VED(")';V]G;&4@4V5A<F-H(@IM<V=S='(@(D=O;V=L92"W:K1-(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-@IM<V=I9"`B
M1W)A>7-C86QE(@IM<V=S='(@(J;'MJ4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3`P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W)E96-E(@IM<V=S
M='(@(D=R965C92`HI\;#OBDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M,0IM<V=I9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(J?&P[ZDY2`H
M25-/+3@X-3DM-RDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.34@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<U"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B1W)E96YL
M86YD("BNYK.NQ/6N<2DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#D@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<T"FUS9VED(")'<F5N861A(@IM<V=S='(@(F=R96YA
M9&$@**[FM^>OQ[E&*2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y"FUS9VED
M(")'<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R("*X<[+5NMZR>B(*"B,Z
M(&QI8B](;W)D92]'<F]U<"YP:'`Z-3D@;&EB+TAO<F1E+T=R;W5P+VQD87`N
M<&AP.C$V.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='DB
M"FUS9W-T<B`BN'.RU:97NMFDH[%OJL6EU2(*"B,Z(&QI8B](;W)D92]'<F]U
M<"]L9&%P+G!H<#HS,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A
M<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9#H@(@IM<V=S='(@(D=R;W5P7VQD87`Z(+5,JFNW<[Q7N'.R
MU2`E<RX@IOBJ0;ZYIE[`LSH@(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N
M<&AP.C$Q."!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,3(T"B,Z(&QI8B](
M;W)D92]'<F]U<"]L9&%P+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<R(*;7-G<W1R
M(")'<F]U<%]L9&%P.B"U3*IKIU*PH[ASLM4@)7,B"@HC.B!L:6(O2&]R9&4O
M1W)O=7`O;&1A<"YP:'`Z,S,X(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HS
M-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O
M('5P9&%T92!G<F]U<"`E<R(*;7-G<W1R(")'<F]U<%]L9&%P.B"U3*IKI_.W
M<[ASLM4@)7,B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,Q-"!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(KASLM4B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.CDV"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'
M=6%D96QO=7!E(@IM<V=S='(@(D=U861E;&]U<&4@**WTO'>LI;2V*2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#,@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.CDW"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<W"FUS
M9VED(")'=6%M(@IM<V=S='(@(D=U86T@*,/VKG$I(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$P,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U871E
M;6%L82(*;7-G<W1R(")'=6%T96UA;&$@**7*IF&PJ*G4*2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B
MKN:NIJ;HKG$B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(R-B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED(")'=65S="!097)M:7-S
M:6]N<R(*;7-G<W1R("*HT[NKQ7:MK2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT-S(*;7-G:60@(D=U97-T8F]O:R(*;7-G<W1R("*S6*O(KV2H
MI2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S4*;7-G:60@(D=U:6YE82(*;7-G<W1R(")'=6EN96$@*+18I+JHR"DB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`T(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@*
M;7-G:60@(D=U:6YE82U":7-S874B"FUS9W-T<B`B1W5I;F5A+4)I<W-A=2`H
MM%BDNJC(I/&OP:9`J4VPZBDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3`U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U>6%N82(*;7-G<W1R(")'
M=7EA;F$@*+M<J,BHNBDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.38T"FUS
M9VED(")(5$U,(@IM<V=S='(@(K97I.6S<[6RNWFHI2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G:60@
M(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T
M(&-E;&P@:6X@<F]W+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS9VED(")(5$U,07)E
M82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@
M:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A(&-O
M=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L
M92XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O:'1T<"YP:'`Z,34W
M"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`BI^2DHZCL($A45%`@Q>?#TBXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3$P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#(*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAA:71I(@IM<V=S='(@
M(DAA:71I("BN_*9A*2(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q
M,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`BPOBTZBVZ=+KB(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G
M:60@(DAA>F4B"FUS9W-T<B`BQD<B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M.3(S(&QI8B](;W)D92]&;W)M+G!H<#HR.3(Q"FUS9VED(")(96%D97(B"FUS
M9W-T<B`BJNW`62(*"B,Z(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N
M<&AP.C8Q"FUS9VED(")(96%D97)S(@IM<V=S='(@(JKMP%DB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3`W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@
M(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R(")(
M96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PIM<V=I9"`B2&5A=GD@
M5"U3=&]R;2(*;7-G<W1R("*D:KEPJT(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X,@IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@
M(J?&IT*HTZ3E("A)4T\M.#@U.2TX+4DI(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM<V=I9"`B2&5I9VAT
M(@IM<V=S='(@(K"JJ]<B"@HC.B!L:6(O2&]R9&4O2&5L<"YP:'`Z,3@T(&QI
M8B](;W)D92](96QP+G!H<#HQ.#8@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z
M,3<*(SH@=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C0*;7-G:60@(DAE;'`B
M"FUS9W-T<B`BNZ&I^B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S
M='(@(KUSO^B^N:C/I<Z[H:GZ(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S
M-S4*;7-G:60@(DAE;'!E<B(*;7-G<W1R("*[H:GZ(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM<V=S='(@(J5BLGDB
M"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHQ,`IM<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN
M:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R("*S;[C,K$_`R:[7JKJV?:EL.B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"FUS
M9VED(")(:6=H(@IM<V=S='(@(K"J(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M
M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHU
M"FUS9VED(")(;U]M92(*;7-G<W1R("*N85]M(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(T,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L>2!3
M964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`B2&]L>2!3964@*+'K
MO\VIHRDB"@HC.B!L:6(O2&]R9&4N<&AP.C$U,SD*;7-G:60@(DAO;64B"FUS
M9W-T<B`BKF$B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$R,B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I
M9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(J;MKF&F8:=](@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C8T"FUS9VED(")(;VUE($1I<F5C=&]R>2(*;7-G
M<W1R("*N8:78O_TB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R("*F[:YAN7&XW"(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#@@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$P-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M.0IM<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`B2&]N9'5R87,@**>[LZ.IU+2U
M*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#8@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$P-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(DAO;F<@2V]N9R`HK;NT
MY"DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C<*;7-G:60@(DAO
M<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT
M-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@
M)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<R(*;7-G<W1R
M(")(;W)D92]+;VQA8CH@MFRE\R`E,B1S(*2DN4JH[+5,KL2JNB`E,21S(%A-
M3+CJKL8B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD
M<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(+5,MFRE\[Y!
MIEBJJZ7S("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT,S4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E
M("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z
M(+9LI?,@)3(D<R"DI*?DI*.H[*JKI?.KK+I!("4Q)',B"@HC.B!L:6(O2&]R
M9&4O2V]L86(N<&AP.C$R-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R
M(")(;W)D92]+;VQA8CH@I'>FJ*5<JKJROK"C("5S(%PB)7-<(B(*"B,Z(&QI
M8B](;W)D92]+;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D92]+;VQA8CH@5&AE
M(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0
M(&5X=&5N<VEO;B(*;7-G<W1R(")(;W)D92]+;VQA8CH@ON.F6*1UM7N[W:UN
M("=D;VUX;6PG(*JZ(%!(4""IM:;Y(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HU,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z(+5,JFNKV*7?("5S(*JKI?.JNB!834P@OO`B"@HC
M.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$R-#,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E
M<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@M4RJ:[*^L*,@)7,@7"(E<UPB.B`E
M<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#<S"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)
M1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R(")(;W)D92]+;VQA
M8CH@M4RJ:\#RJ/JSH:7W("5S(*NLND&JNB!-24U%(,/1IT^XN;U8(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,3DR"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB
M.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@M4RJ:Z90J$(@)7,@7"(E<UPB
M.B`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3,S,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E
M('-H87)E<SH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(+5,JFNF4*A"I,"H
MR3H@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B
M"FUS9W-T<B`B2&]R9&4O2V]L86(Z(*6\JKZJNJ3`J,D@7"(E<UPB(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I
M9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(J3TI:V]=2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO
M<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R("*D]*6MN=2E4B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO
M<FEZ;VYT86PZ(@IM<V=S='(@(J3TI:TZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@
M9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*2(*;7-G<W1R("*G
M0:9PIO.H[*:Y(#\@*+W0L=2M>B$I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@
M8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`BIT&M
M;J98J-:F:*36K=/$YJ;LJ4\_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E
M('1H97)E/R(*;7-G<W1R("+$YJ;LO,:EV*9`K7`_(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B
M2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T
M<B`BIT&M;J98J-:F:*36ID.I3S\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C@Y(&QI8B]";&]C:R]M971A<BYP:'`Z,C,P"FUS9VED(")(
M=6UI9&ET>2(*;7-G<W1R("*WPZO7(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(T.`IM<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R("*WPZO7
M.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R
M:7-T<R(*;7-G<W1R("*WQKU=I&JN=B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G
M<W1R(")(=6YG87)Y("BF2:3ZIU$I(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER
M=7,N<&AP.C$W,B!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C(S-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D
M.B`E<R(*;7-G<W1R("))34%0(+9LO6.KV*7?I:*QT3H@)7,B"@HC.B!L:6(O
M2&]R9&4O075T:"]C>7)U<RYP:'`Z,C$T(&QI8B](;W)D92]!=71H+V-Y<G-Q
M;"YP:'`Z,CDU"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D
M96QE=&EO;B!F86EL960Z("5S(@IM<V=S='(@(DE-05`@MFR]8Z=2L*.EHK'1
M.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ-SD@;&EB+TAO
M<F1E+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T
M<B`B24U!4""V;+UCNL^ZT+!TN&VKV*7?I:*QT3H@)7,B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3,R,`IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R("))
M4""F[*=](@H*(SH@;&EB+TAO<F1E+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G
M:60@(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B25`@INRG
M?;5,JFNHSZ7.+B(*"B,Z(&QI8B](;W)D92]!=71H+VEP8F%S:6,N<&AP.C@Y
M"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L
M;V-K+B(*;7-G<W1R("))4""F[*=]J,.DHZ9B($-)1%(@JKJDN;-<L,^V]*2D
M+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS
M9VED("))4"!L;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(J9BJ^&ML;2A
MI$JF0U]N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@R"FUS9VED("))8V5L86YD(@IM<V=S='(@(DEC96QA;F0@**9"
MKG$I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,`IM<V=I9"`B26-O
M;G,@3VYL>2(*;7-G<W1R("*OPKG/I=PB"@HC.B!U=&EL+VEC;VY?8G)O=W-E
M<BYP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM
M<V=S='(@(B5SJKJYSZ7<(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X
M,0IM<V=I9"`B26-O;G,@=VET:"!T97AT(@IM<V=S='(@(KG/I=RDSJ3EIG(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DS"FUS9VED("))9&5N=&ET
M>2=S(&YA;64Z(@IM<V=S='(@(JBMI??#T:=/JKJF5[K9.B(*"B,Z(&QI8B](
M;W)D92]-24U%+T-O;G1E;G1S+G!H<#HU.3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P
M96X@:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R("*F<*I'M4RJ:Z6_O52F
M8<7CI=PL("5S(*5(I72V?;'2MFRE\ZGSMW.U^+6AM^VDI"XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#4Y"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@
M<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA
M>2!N965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T
M<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*(JC/I<X@26YT97)N970@17AP;&]R
M97(@PG/$_;ZYKLFF<*I'J%.FLZS=J.RE]*;SJKJD<+G/I=PL(*=!I6FOX+O=
MK6ZDQ+_OLV^MT[:U(@HBI=BE2,/VLZP@4$Y'(+QVN;.JNL'TPL.NQ*I'+B(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ-S(*;7-G
M:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@
M=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D:7-P
M;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("*F<*I'K-VH[+-OJVBH
M4Z:SO':YLZJZL%2NIRRS;ZKMI=RG0:JZPG/$_;ZYM4RJ:\7CI=RD5[;'JKJ\
M=KFS+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T
M<B`BO':YL[EWQ/TZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@
M(KQVN;.Z]*=](@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S
M='(@(KQVN;.Z]*=].B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G
M86QL97)Y(@IM<V=S='(@(KQVN;.HTZ;;P\"T62(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I
M9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R("*\=KFSJ-.FV\/`M%DZ
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W-C4*;7-G:60@(DEM86=E('5P
M;&]A9"(*;7-G<W1R("*D5[;'O':YLR(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N
M<&AP.C,W"FUS9VED("));6%G97,B"FUS9W-T<B`BO':YLR(*"B,Z('1E;7!L
M871E<R]D871A+W1S=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA
M<"YI;F,Z-PHC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4T('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(K;7I$HL(*A"QDH@)60B"@HC.B!T
M96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`BMM>D2L3FINPZ("5S
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP
M;W)T960@9FEE;&1S.B(*;7-G<W1R("*VUZ1*Q.:F[#HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S`*;7-G
M:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@(J9BJ^&ML;2AI$JF0U]S
M(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3,T"FUS9VED("))
M;F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(K_II$JDHZ6_
MO52JNJ=`I<Z]6"XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,R"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W
M;W)D+B(*;7-G<W1R("*]T,#+K&2G0:JZJ,^ESJK,IE>ZV:3.L4N]6"(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED("(B"B));F-O
M<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I
M;B!O<B!C;VYT86-T('EO=7(@(@HB861M:6YI<W1R871O<B!I9B!Y;W4@;F5E
M9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(JC/I<ZJS*97NMFDHZ6_O52ISJK,
MN7&D;+9LI?.F[:=]I'?%W*?S+KW0P7"UN*=!JKJH=++.NMZR>JW[I4BH\Z=5
MLT*R>BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(Q"FUS9VED("));F-R96%S92!);F1E;G0B"FUS9W-T<B`BO%>E6\%9
ML<8B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$V(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#$*;7-G:60@(DEN9&EA(@IM<V=S='(@(DEN9&EA("BF3*O7*2(*"B,Z
M(&QI8B](;W)D92]097)M<R]522YP:'`Z,C4T('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3,T"FUS9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@
M(JW3IT^HSZ7.JLPB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$R(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#`*;7-G:60@(DEN9&]N97-I82(*;7-G<W1R("));F1O
M;F5S:6$@**9,I:<I(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R
M,BYP:'`Z-C<*;7-G:60@(DEN9F\B"FUS9W-T<B`BN.JP5"(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR-3D*;7-G:60@(DEN9F]R;6%T:6]N(@IM
M<V=S='(@(KCJL%0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S$Y"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+B(*
M;7-G<W1R("*U3*5II<ZJNKCJL%0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,U"FUS9VED("));G-E<G0@
M0U]O;'5M;B!!9G1E<B(*;7-G<W1R("*F8JOAK;&TH:1*Q.:F[%]O(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(P"FUS9VED("));G-E<G0@26UA9V4B"FUS9W-T<B`BM*&D2KG/I/DB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P
M"FUS9VED("));G-E<G0@5&%B;&4B"FUS9W-T<B`BM*&D2JKMKN8B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED
M("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`BM*&D2KKTN/2S<[6R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,T"FUS9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`BIF*K
M9:VQM*&D2L3FINQ?0R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W(&-O
M;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`BIF*EV*MEQ.:F
M[*OAK;&TH:1*I$"MT[=SQ.:F["(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@
M;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(J9B
MI=BK9<3FINRK9:VQM*&D2J1`K=.W<\3FINPB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@(DEN
M<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@
M(J9BI=BK9:9#J^&ML;2AI$JD0*W3MW.F0R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS
M97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@
M(J9BI=BK9:9#JV6ML;2AI$JD0*W3MW.F0R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM<V=I9"`B26YS
M97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B"FUS9W-T
M<B`BIF*EV*MEN&#"2:OAK;&TH:1*I$"MTZQQN*@B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@
M(DEN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*
M;7-G<W1R("*F8J78JV6X8,))JV6ML;2AI$JD0*W3K'&XJ"(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z,34P"FUS9VED("));G-E<G0@86QT97)N871E('1E
M;7!L871E(@IM<V=S='(@(K2AI$JE:;3`I4Z\RZI/(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(T,@IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E
M<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z
M(@IM<V=S='(@(K=SL4N]6+%.L4BU;ZCLLV^MT[9LI?.F8:=].B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*
M;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(J9BJ^&ML;2AI$K`
M>*9SKN8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4Y"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T
M<B`BIF*K9:VQM*&D2L!XIG.NYB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU
M;6X@869T97(B"FUS9W-T<B`BIF*KX:VQM*&D2L3FINPB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U"FUS9VED
M("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R("*F8JMEK;&TH:1*Q.:F
M["(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I
M9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S='(@(K2AI$JV;*7S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U
M"FUS9VED("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(J9BJ^&M
ML;2AI$JL<;BH(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E
M9F]R92(*;7-G<W1R("*F8JMEK;&TH:1*K'&XJ"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*;7-G:60@(DEN
M<V5R="!R;W<@869T97(B"FUS9W-T<B`BIF*KX:VQM*&D2J9#(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`IM
M<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`BIF*K9:VQM*&D2J9#
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,PIM<V=I9"`B26YS97)T
M('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N
M.B(*;7-G<W1R("*F=Z7^L-VE>:JZM:JNUSHB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(V"FUS9VED("));G-E<G0O36]D
M:69Y($EM86=E(@IM<V=S='(@(K2AI$HOQ=RG\[QVN;,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("));G-E
M<G0O36]D:69Y($QI;FLB"FUS9W-T<B`BM*&D2B_%W*?SNO2X]+-SM;(B"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("))
M;G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO
M;B!L:7-T+B(*;7-G<W1R("+"2;S&I*.HK*5(IMRI\[5,JFNVQ[!EM;FP=+AM
MN'.RU2XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U
M"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R("+"2;S&I*.H
MK"XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`W.0IM<V=I9"`B26YT96=E
M<B(*;7-G<W1R("*^X[S&(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,S<*
M;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R("*^X[S&ID,B"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI
M9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`BM4RNQ*JZ(%5$
M2"BHSZ7.JLRXZJ[&JNW`62DN(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII
M<"YP:'`Z,38W(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C$Y-`HC.B!L
M:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HR,3(*;7-G:60@(DEN=F%L:60@
M6DE0(&1A=&$B"FUS9W-T<B`BM4RNQ*JZ(%I)4""XZJ[&+B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P;&EC871I
M;VXN(@IM<V=S='(@(K5,KL2JNL"SI<ZU>Z:A+B(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED("));G9A;&ED(&)A=&-H
M($E$+B(*;7-G<W1R("*U3*[$JKJGY::XN+F]6"XB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C`Y,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$V,B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C(S-@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,P,R!L
M:6(O2&]R9&4O1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS-PIM<V=I9"`B26YV
M86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`BL&6E6*JZN.JNQK5,KL0N
M(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*;7-G
M:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB"FUS9W-T<B`BM4RN
MQ*JZI=B\T*;MIWTB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HQ
M,#D@;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP:'`Z,3,Y"B,Z(&QI8B](;W)D
M92]#;VUP<F5S<R]D8G@N<&AP.C(T,0IM<V=I9"`B26YV86QI9"!F:6QE(&9O
M<FUA="(*;7-G<W1R("*U3*[$JKK`R:[7KN:FH2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-C4*;7-G:60@(DEN=F%L:60@;&EC96YS92!K
M97DN(@IM<V=S='(@(K5,KL2JNK'"Q7:]6"XB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,34Y"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R
M;W9I9&5D+B(*;7-G<W1R("*U3*[$JKJF8;#/+B(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US9U]T
M>7!E+B(*;7-G<W1R("*U3*[$JKH@;7-G7W1Y<&4N(@H*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*;7-G:60@(DEN=F%L:60@;W(@
M;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(K5,KL2JNJG.I^2DHZCL(&%P:5]I
M9"XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-@IM
M<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@
M(K5,KL2JNJG.I^2DHZCLL-&\QBXB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL
M9"YP:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN(@IM
M<V=S='(@(K5,KL2JNJ3WQ7:MK2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,38Q"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S
M='(@(K5,KL2JNKG9IO'#T:=/O5@N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$V,PIM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O9&4N(@IM
M<V=S='(@(K5,KL2JNK*CJWZ]6"XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS
M9W-T<B`BM4RNQ*JZLW&P5*CSJ7<N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.CDS(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HW,0HC
M.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R("*U3*[$
MJKJFK*7SI$@Z7"(E<UPB(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,#<U
M(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(U.`IM<V=I9"`B26YV86QI9"!S:&%R
M92!O8FIE8W0B"FUS9W-T<B`BM4RNQ*JZI,"HR:JKI?,N(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@(DEN=F%L:60@
M<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(K5,KL2JNJC3M[VF[:=]+B(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("))
M;G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T<B`BM4RNQ*JZN%6PZKU8N.JN
MQBXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4Y"FUS9VED("))
M;G9E;G1O<GDB"FUS9W-T<B`BN.JRHR(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HV-S4*;7-G:60@(DEN=F5R="!S96QE8W1I;VXB
M"FUS9W-T<B`BIEZT7[_OOMPB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3$Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DER86XL($ES;&%M:6,@4F5P
M=6)L:6,@;V8B"FUS9W-T<B`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B`H
MI>RNU"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$X(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#$*;7-G:60@(DER87$B"FUS9W-T<B`B27)A<2`HI>RIU*=**2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3,@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Q,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M,`IM<V=I9"`B27)E;&%N9"(*;7-G<W1R("))<F5L86YD("BW4KJXQ/4I(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-
M86XB"FUS9W-T<B`B27-L92!O9B!-86X@*+#2KG$I(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D
M(%0M4W1O<FUS(@IM<V=S='(@(J>]LZ&Y<*M"(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$Q-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<W)A96PB
M"FUS9W-T<B`B27-R865L("BE2*;BID,I(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HV,C8*;7-G:60@(DES<W5E<B(*;7-G<W1R("+#L;5OJLPB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*
M;7-G:60@(DET86QI8R(*;7-G<W1R("*QU\7I(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$R,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R"FUS9VED("))=&%L>2(*
M;7-G<W1R("))=&%L>2`HN'&D:J=1*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G
M<W1R(")*86UA:6-A("BD^K92I5LI(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C,Y.2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#,W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`BI$"DZR(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C4@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$Q-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM
M<V=I9"`B2F%P86XB"FUS9W-T<B`B2F%P86X@**3II;LI(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*
M4"DB"FUS9W-T<B`BI.FDY2`H25-/+3(P,C(M2E`I(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$R,@IM<V=I9"`B2F5R<V5Y(@IM<V=S='(@(K]!INBN
M<2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C0@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX,PIM<V=I9"`B2F]R9&%N(@IM<V=S='(@(DIO<F1A;B`HK/FEN2DB"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*
M;7-G<W1R("*D0Z3K(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P-"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`BI+NDZR(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU
M<W1I9GDB"FUS9W-T<B`BN>^[]"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$U"FUS9VED(")*=7-T:69Y($-E
M;G1E<B(*;7-G<W1R("*X;:2D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3<*;7-G:60@(DIU<W1I9GD@1G5L
M;"(*;7-G<W1R("*EJJ5KN>^[]"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y($QE
M9G0B"FUS9W-T<B`BOF&EJKGON_0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2
M:6=H="(*;7-G<W1R("*^8:5KN>^[]"(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*
M;7-G<W1R(")+87IA:VAS=&%N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(V,PIM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T
M<B`BJT^O9*WLO,L@/R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C8@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T<B`B2V5N>6$@
M**K6J,@I(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z.#4*;7-G:60@
M(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B2V5R8F5R;W,@NWO#TK_YNWXN(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0R"FUS9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R("*NUJ3?
MMW.DXB(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B
M2V5Y($-R96%T:6]N(@IM<V=S='(@(JKWQE^KV*7?(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS
M9W-T<B`BJO?&7Z]3O'@B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT
M,3(*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`BJO?&7ZKXJ]<B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!4>7!E(@IM
M<V=S='(@(JKWQE^KK+I!(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU.3D*;7-G:60@(DME>2!5<V%G92(*;7-G<W1R("*J]\9?NWFJ:R(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A
M9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("*E
MV*MEJKJDO;9]JO?&7Z;XJD&^N:2D+*1WN&>F<Z9BIT&JNJKWQE\N(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S='(@
M(JC@M:,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(Y(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#0*;7-G:60@(DMI<FEB871I(@IM<V=S='(@(DMI<FEB871I("BP
M\JB]I-JTM2DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,R(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L
M92=S(%)E<'5B;&EC(&]F("BE7\'Z*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(DMO<F5A+"!297!U8FQI8R!O9B`HJV[!^BDB"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B2V]R96%N("A%54,M
M2U(I(@IM<V=S='(@(L'ZI.4@*$550RU+4BDB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3,T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C0*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*
M;7-G<W1R(")+=7=A:70@**SLJ\*O4RDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3(W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB
M"FUS9W-T<B`B2WER9WEZ<W1A;B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N
M=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R("*JJ:VQL'2X;5]Y(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A
M9V4B"FUS9W-T<B`BNWFHI2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C
M<F%T:6,@4F5P=6)L:6,B"FUS9W-T<B`B3&%O(%!E;W!L92=S($1E;6]C<F%T
M:6,@4F5P=6)L:6,@*+QDL.HI(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V
M.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(J15I6*DZR(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HW-@IM<V=I9"`B3&%S="!087-S=V]R9"!#:&%N
M9V4B"FUS9W-T<B`BL\RJ\:1`IKBQ2[U8Q=RG\ZGS(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S
M="!1=6%R=&5R(@IM<V=S='(@(J15J;:DZR(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,34Q"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(J17IKBG
M\[=S.B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HW,3<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`BI%>D0*:XM6ZD2CH@
M)7,B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*
M;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T<B`BI%>D0*:X
MM6ZD2CH@)7,@IML@)7,B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z-S$T"FUS
M9VED("),87-T(&QO9VEN.B!.979E<B(*;7-G<W1R("*D5Z1`IKBU;J1*.B"R
MQ*1`IKBU;J1*(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@Y"FUS9VED("),871V:6$B"FUS9W-T<B`B3&%T=FEA("BI
MU++FNONHR"DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*;7-G:60@
M(DQA=R(*;7-G<W1R("*J:ZO?(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"FUS9VED("),87EO=70B"FUS9W-T
M<B`BJJFML;!TN&TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S@@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R("),96)A;F]N
M("B^I*3:N>`I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C8Y"FUS9VED("),969T(@IM<V=S='(@(J6JP^0B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P.`IM<V=I9"`B3&5F="!H96%D97(B
M"FUS9W-T<B`BI:K#Y*KMP%DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P
M-`IM<V=I9"`B3&5F="!V86QU97,B"FUS9W-T<B`BI:K#Y*W((@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$T,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X"FUS9VED
M("),97-O=&AO(@IM<V=S='(@(DQE<V]T:&\@*+_@K\&FJRDB"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(DQE
M=F5L(@IM<V=S='(@(K=2L:$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,30R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B
M3&EB97)I82`HO^"D\;?GJ,@I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$T-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:6)Y86X@07)A8B!*86UA
M:&ER:7EA(@IM<V=S='(@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$@**=1I/&H
MR"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30P(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#@*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B3&EE8VAT96YS
M=&5I;B`HID.DY+2PM+6U;BDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR-0IM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R
M("*W3*M"(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C8*;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`BI'"K0B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),
M:6=H="!286EN($5A<FQY(@IM<V=S='(@(J:MIK.D<*M"(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT
M(%)A:6X@3&%T92(*;7-G<W1R("*QWZ:SI'"K0B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H="!286EN
M(%-H;W=E<B(*;7-G<W1R("*D<+!]JT(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I9"`B3&EG:'0@4F%I;B!W:71H
M(%1H=6YD97(B"FUS9W-T<B`BI'"K0J:SN7`B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B3&EG:'0@4VYO=R(*
M;7-G<W1R("*D<+.W(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@
M(J1PL'VSMR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B
M3&EM97)I8VLB"FUS9W-T<B`BI;2J;[C6(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$X,3@*;7-G:60@(DQI;FLB"FUS9W-T<B`BLW.ULB(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM
M<V=I9"`B3&EN:R!P;VEN=',@=&\Z(@IM<V=S='(@(K-SM;+"2:CL.B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<Y"FUS9VED("),:6YK('1H92!E;6%I
M;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG
M(@IM<V=S='(@(L7CI=RNR;-SM;*V;*7SINVG?:CLO7.\9[9LI?.MMJVQ(@H*
M(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@R"FUS
M9VED("),:6YK<R(*;7-G<W1R("*S<[6R(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0V"B,L(&9U>GIY"FUS9VED("),:6YU>"!#;V]K:64B"FUS9W-T
M<B`BPT.FXB(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX
M-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S
M='(@(J9#I5@@+2"HSZ7.JLRE::5(K-VH[+-OK=.K2*7SIU@B"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,3,S"FUS9VED("),:7-T($1A=&%B87-E<R(*;7-G
M<W1R("*F0Z58N.JNQJYW(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z
M-3$*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`BID.E6+NAJ?J\
MT,-$(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,@IM<V=I9"`B3&ES="!4
M86)L97,B"FUS9W-T<B`BID.E6*KMKN8B"@HC.B!L:6(O2&]R9&4O34E-12](
M96%D97)S+G!H<#HU.30*;7-G:60@(DQI<W0M07)C:&EV92(*;7-G<W1R("*P
M4;W7N'.RU2W`R:[7PF0B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H
M<#HU.#D*;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R("*P4;W7N'.RU2VH1*=5
M(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DV"FUS9VED("),
M:7-T+4ED(@IM<V=S='(@(K!1O=>X<[+5+</1IT^XN;U8(@H*(SH@;&EB+TAO
M<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),:7-T+4]W;F5R(@IM
M<V=S='(@(K!1O=>X<[+5+;[6IK.JS"(*"B,Z(&QI8B](;W)D92]-24U%+TAE
M861E<G,N<&AP.C4Y,PIM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(K!1O=>X
M<[+5+;%(I?.D2"(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y
M,0IM<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS9W-T<B`BL%&]U[ASLM4MK7&^
M7"(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y,`IM<V=I9"`B
M3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R("*P4;W7N'.RU2VH^J[XK7&^7"(*
M"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED
M("),:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,B"FUS9W-T<B`BID.E6+=\
MM,&EHK'1.B`E<R(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("),:7-T:6YG('5S97)S(&9A:6QE9#H@)7,B"FUS9W-T
M<B`BID.E6*C/I<ZJS*6BL=$Z("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;F]L:7-T+FEN8SHR"FUS9VED("),:7-T:6YG('5S97)S(&ES(&1I<V%B
M;&5D+B(*;7-G<W1R("*F0Z58J,^ESJK,JKJE7*_@LU'#]K.L(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),:71E<F%T=7)E(@IM<V=S
M='(@(J3EOL<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30T(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S,*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R("),:71H=6%N
M:6$@**7?L[.I>RDB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6UA9V5S
M+G!H<#HW-PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R("*X_*1*I*0N+BXB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`P"FUS9VED("),
M;V-A;"!T:6UE.B`B"FUS9W-T<B`BM^VF8:[)MJ$Z("(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX-@IM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S
M='(@(J9AL,^[4*[)MJ$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4W,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-3<*(SH@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C:R]M971A<BYP:'`Z-C4*;7-G
M:60@(DQO8V%T:6]N(@IM<V=S='(@(J9AL,\B"@HC.B!L;V=I;BYP:'`Z,3@V
M('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.3$@=&5M<&QA=&5S+VQO
M9VEN+VUO8FEL92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN
M8SHQ-2!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDP"FUS9VED("),;V<@
M:6XB"FUS9W-T<B`BM6ZD2B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3@U
M"FUS9VED("),;V<@;W5T(@IM<V=S='(@(K5NI5@B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-3D*;7-G:60@(DQO9VEN(@IM<V=S='(@(K5NI$HB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$P"FUS9VED("),;V=I;B!487-K
M<R(*;7-G<W1R("*U;J1*I'6G0"(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY
M.3(*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@
M;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@
M(K5NI$JEHK'1+""]T,#+K&2[U:15JKJESJ3AIE>I3;%+O5@L(+5-J^&MJ[C5
M+B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY.#@*;7-G:60@(DQO9VEN(&9A
M:6QE9"XB"FUS9W-T<B`BM6ZD2J6BL=$N(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$S-CD*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R("*J^*5Y(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED("),;W9E(@IM<V=S='(@
M(K=2L:$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV-PIM<V=I9"`B3&]W(@IM<V=S='(@(J=#(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B
M3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R("*D<+QGI\;#OKS&IG(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L971T97)S(@IM<V=S='(@(J1P
MO&>IU*1"O,:F<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E
M<G,B"FUS9W-T<B`BI'"\9\.YL*B\QJ9R(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$T-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),=7AE;6)O=7)G
M(@IM<V=S='(@(DQU>&5M8F]U<F<@*+]CM,NS^2DB"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,SDX(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,S8*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*
M;7-G:60@(DU-(@IM<V=S='(@(J3K(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(X,PIM<V=I9"`B34]41"(*;7-G<W1R("*H0Z3IL%2NIR(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B35,M
M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")-
M4RU43D5&(*K^I5O`R:[7I*2H4Z:SN.JNQBXB"@HC.B!L:6(O2&]R9&4O3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*
M;7-G<W1R(")-4T<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA8V%O(@IM<V=S='(@(DUA8V%O("B_
M1*KY*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3,@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY,0IM<V=I9"`B36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9
M=6=O<VQA=B!297!U8FQI8R!O9B`HL*BHY+EYID"I3;#J*2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$S-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B
M36%D86=A<V-A<B(*;7-G<W1R(")-861A9V%S8V%R("BPJ+E&I5NTM:5;*2(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.0IM<V=I9"`B36%G:6,B"FUS
M9W-T<B`BQ5VS3B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX,PIM
M<V=I9"`B36%I;"(*;7-G<W1R("*V;*7S(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C4R-`IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R("*V;*7S
MNMZR>B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R("*K
MV*7?LW.ULE]K+BXN(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QA=VDB"FUS9W-T<B`B36%L87=I
M("BPJ*G4J\(I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDU"FUS9VED(")-86QA>7-I82(*;7-G<W1R(")-86QA>7-I
M82`HL*BHTZ;HJ,@I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD:79E<R(*;7-G<W1R(")-86QD
M:79E<R`HL*BZN*9AI-(I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86QI(@IM<V=S='(@(DUA;&D@
M*+"HIU$I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDT"FUS9VED(")-86QT82(*;7-G<W1R(")-86QT82`HL*BZN*5,
M*2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-`IM<V=I9"`B(@HB36%N
M86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@
M:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO
M<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`BNMZR>J=!JKJDP,/^+*C#I4*LL*3`
MP_ZS7:EWPT.FXBXB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3$U,PIM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(DUA<#(T(*9A
MN<\B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X
M-`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$V.`IM
M<V=I9"`B36%P475E<W0@;6%P(@IM<V=S='(@(DUA<%%U97-T(*9AN<\B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I
M;F=S('-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P,2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@(J14I.LB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q
M"FUS9VED(")-87)G:6XB"FUS9W-T<B`BP^2LR2(*"B,Z(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO
M56YS965N(&9L86=S(@IM<V=S='(@(KS0L$^FJ""LW;E,+Z6\K-VY3"(*"B,Z
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R
M:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"DB
M"FUS9W-T<B`BO-"P3Z:HJ.2E3*JZP]&G3R`HJ-*F<"X@K:NM;B^D=Z9>PM`I
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(DUA<G-H86QL
M($ES;&%N9',@*+"HKDRZN+ASKG$I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$U.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-87)T:6YI<75E(@IM
M<V=S='(@(DUA<G1I;FEQ=64@*+"HM*.EIZ=*KG$I(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*
M;7-G<W1R("*DQ[!TQ.:F[*2D(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$V,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-875R:71A;FEA(@IM<V=S
M='(@(DUA=7)I=&%N:6$@**U4IU&V\*6GJ,@I(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$V,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-875R:71I
M=7,B"FUS9W-T<B`B36%U<FET:75S("B\KZB]INBTM2DB"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W
M960@8W)E9&ET+B(*;7-G<W1R("*DN;-<JKJSS*1JPDF\QBXB"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B36%X(&UE
M<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@(JK^I?.\QJ78I'>V5Z58
MI+FS7*17K:TN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@
M(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("*SS*KQ(#(T(*1P
MKLFJNK/,L*JWQ:O7.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y.`IM
M<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`BL\RJ\2`V
M(*1PKLFJNK/,L*JWQ:O7.B`B"@HC.B!L:6(O87!I+G!H<#HX-@IM<V=I9"`B
M36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R("*PS[;T
MI%>MK;S&I=@B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3`R(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,C(Q(&QI8B](;W)D92]&;W)M+G!H<#HQ,C0S"FUS9VED
M(")-87AI;75M(&QE;F=T:"(*;7-G<W1R("*DN;-<L\RD:JKXJ]<B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#$*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S
M='(@(J2MI.LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4S(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$W"FUS9VED(")-87EO='1E(@IM<V=S='(@(DUA>6]T=&4@
M*+"HK/FO4ZYQ*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,`IM<V=I
M9"`B365D:6-I;F4B"FUS9W-T<B`BPN6^QR(*"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O961I="YI;F,Z,38*;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`B
MIJBM^R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#(*;7-G:60@(DUE
M;G4@;6]D93HB"FUS9W-T<B`BO^^SYKS2IJ$Z(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R
M9V4@8V5L;',B"FUS9W-T<B`BIEBHUL!XIG.NYB(*"B,Z(&QI8B](;W)D92].
M;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DUE<W-A9V4B"FUS9W-T
M<B`BMFRE\R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C$V"FUS
M9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE
M('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92`B"B)V97)I9FEE
M9"XB"FUS9W-T<B`BMFRE\\7GP]*D=Z>YIJ@LIOVL3ZC/I<ZJS*JZP[&SN:MO
MM4RJ:[-QN4S%Y\/2+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S$P"FUS9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(L*R
ML%2D=[E,M,$N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4V.2!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"FUS9VED(")-97-S86=E('1Y<&4B
M"FUS9W-T<B`BPK*P5*NLND$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*
M(RP@9G5Z>GD*;7-G:60@(DUE=&%R(%=E871H97(B"FUS9W-T<B`BI=BK9:31
MKO`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W"FUS9VED(")-971A<B!B
M;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")-971A<B"PS[;TM4RJ:ZC/
MI<XN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3(*;7-G:60@(B(*(DUE
M=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO
M9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(DUE=&%R(+#/
MMO2U3*IKJ,^ESBX@LM.X8+W0L-&FTJATLLZZWK)ZM6Z__2XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34S"FUS9VED(")-971A<D1"(&ES
M(&YO="!C;VYN96-T960N(@IM<V=S='(@(DUE=&%R1$(@J7REO+-SL;4N(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R
M("*DZ*IK(@H*(SH@;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP.C@Q(&QI8B](
M;W)D92]24$,O<V]A<"YP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(DUE
M=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`BI.BJ:R!<(B5S
M7"(@I;RS4:EWN'$B"@HC.B!L:6(O2&]R9&4O4E!#+W)E<W0N<&AP.C@R"B,L
M('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D
M(&UE=&AO9#H@)7,B"FUS9W-T<B`BI.BJ:Z6\J7>X<2X@I4BI2:5SI.BJ:SH@
M)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C<@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HW-0IM<V=I9"`B365T<FEC(@IM<V=S='(@(J2]J.XB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38V(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.34*;7-G:60@(DUE>&EC;R(*;7-G<W1R(")-97AI8V\@*+ZEINBM]"DB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#4@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$T.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,@IM
M<V=I9"`B36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(*;7-G<W1R
M(")-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F("BQ2Z=*P[FEIZ;H
MJ,@I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<V"FUS9VED(")-:61D;&4B"FUS9W-T<B`BI*2VH2(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4
M>7!E(@IM<V=S='(@(DUI;64@JZRZ02(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S$P"FUS9VED(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T
M<B`BL\RJ\2`R-""D<*[)JKJSS*=#M\6KUSH@(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,#(*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@(@IM
M<V=S='(@(K/,JO$@-B"D<*[)JKJSS+"JM\6KUSH@(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O;&1A<"YP:'`Z-#,Y"FUS9VED(")-:6YI;75M('!A<W-W;W)D(&%G
M92!H87,@;F]T('EE="!E>'!I<F5D(@IM<V=S='(@(K/,M76Q2[U8KL2TP:E\
MI;RH[+3!(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(S,PIM<V=I9"`B36ER<F]R(@IM<V=S='(@(JQ-KF<B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T
M<B`BPOBVM2(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-S(@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#`*(SH@;&EB
M+TYE="]335,O=VEN7VAT='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!014%2
M('!A8VMA9V4@2%144%]297%U97-T+B(*;7-G<W1R("*GY*2CJ.P@4$5!4B"E
M7;C+($A45%!?4F5Q=65S="XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3$U"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E
M('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B
M"B)A<'!L:6-A=&EO;BXB"FUS9W-T<B`BLUVI=\#)O_*EHBX@IG"J1ZUNJ,^E
MSK-OK=/`LZ7.M7NFH:=!I;*VM[)[IF*T3K*CI<VE3"XB"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M
M97-S86=E($E$+B(*;7-G<W1R("*GY*2CJ.S"LK!4JKH@240N(@H*(SH@;&EB
M+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I9"`B36ES
M<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"XB"FUS9W-T<B`BI^2D
MHZCLI;*VMZJZ(%!%05(@I5VXRR!-86EL+B(*"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E<W-I;VX@
M240N(@IM<V=S='(@(J?DI*.H[+=\M,&JNB!)1"XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G
M<W1R("*L4+3!I$`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S8*
M;7-G:60@(DUO8FEL92!-86EL(@IM<V=S='(@(J;FL,JV;*7S(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*;7-G:60@(DUO
M9&5R871E(@IM<V=S='(@(K?%J4TB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O<F%R+G!H<#HV-B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW
M,PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX-0IM<V=I9"`B
M36]D:69I960@1&%T92(*;7-G<W1R("*G\[=SI.FTP2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I
M9"`B36]D:69Y(%523"(*;7-G<W1R("*MUZ?ONO2G?2(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-C<T"FUS9VED(")-;V1U;'5S(@IM<V=S='(@
M(KS2LM4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34P(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3`*;7-G:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@
M(DUO;&1O=F$L(%)E<'5B;&EC(&]F("B\K[JXIFBERRDB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,30Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO
M;F%C;R(*;7-G<W1R(")-;VYA8V\@*+ROK\>M]"DB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,34V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O
M;&EA(@IM<V=S='(@(DUO;F=O;&EA("B[6*5J*2(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR-3@X"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R("*D
MZZ3.IGXB"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED
M(")-;VYT:&QY(@IM<V=S='(@(JA#I.LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,38Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUO;G1S97)R870B
M"FUS9W-T<B`BNUBVZZG4KU,B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S
M='(@(J3KK-LB"@HC.B!L:6(O1FEL92]#4U8N<&AP.C$Y-B!L:6(O1FEL92]#
M4U8N<&AP.C(X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD<R!F
M;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R
M("*F8K+$)62FYJ?DJ.RJNL3FINR\QJ78I'>V5Z58N7>TP25D+B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$U-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I
M9"`B36]R;V-C;R(*;7-G<W1R("*\KZREK?0B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B36]S=&QY($-L96%R
M(@IM<V=S='(@(J9HMK.NR;2X(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S0*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T
M<B`BIFBVLZ[)L[$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS-0IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@(K2XKLFF
M:+:S(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-3`Y"FUS9VED
M(")-;W9E($1O=VXB"FUS9W-T<B`BI%6ROB(*"B,Z(&QI8B](;W)D92]";&]C
M:R],87EO=70N<&AP.C4Q,PIM<V=I9"`B36]V92!,969T(@IM<V=S='(@(J6J
MLKXB"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HU,3<*;7-G:60@
M(DUO=F4@4FEG:'0B"FUS9W-T<B`BI6NROB(*"B,Z(&QI8B](;W)D92]";&]C
M:R],87EO=70N<&AP.C4P-0IM<V=I9"`B36]V92!5<"(*;7-G<W1R("*D5[*^
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R,PIM
M<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(J15LKXB"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(R(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HU,C,*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`B
MI%>ROB(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C@@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY-0IM<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R(")-;WIA;6)I<75E
M("BR]J14I/&G2BDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$X.`IM<V=I
M9"`B375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(KW&O^^F
MH:15J=2E7*_@JNTB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3`U-0HC+"!F=7IZ>0IM<V=I9"`B375L=&EM87`@54L@;6%P(@IM
M<V=S='(@(J9HO':YLR(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C0V"FUS
M9VED(")-=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`BO<:_[R(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#(*;7-G:60@(DUY($%C8V]U;G0B
M"FUS9W-T<B`BI]JJNK%BN+DB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M,C@*;7-G:60@(DUY($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`BI]JJ
MNK%BN+FXZK!4(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HU-`IM
M<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(JW3I$BON*5X(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+V5D:70N<&AP.C$S-@IM<V=I9"`B37D@4&]R=&%L($QA>6]U
M="(*;7-G<W1R("*MTZ1(K[BE>*VVK;&P=+AM(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$U-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR"FUS9VED(")->6%N;6%R
M(@IM<V=S='(@(DUY86YM87(@*+UQJ&PI(@H*(SH@=&5M<&QA=&5S+VUA:6YT
M96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/
M5"!!9W)E92(*;7-G<W1R("*DHRRGVJ2CIE"W3B(*"B,Z(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C0Q,2!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$P,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*
M;7-G:60@(DYA;64B"FUS9W-T<B`BIE>ZV2(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*
M;7-G<W1R(").86UI8FEA("BHNJ;,I/&HR"DB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3<X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3@*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM
M<V=S='(@(DYA=7)U("B_U;Y\*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B
M3F5P86P@**6GJGFZN"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<U
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@
M(DYE=&AE<FQA;F1S("BR_,3U*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H97)L86YD<R!!;G1I
M;&QE<R(*;7-G<W1R(").971H97)L86YD<R!!;G1I;&QE<R`HLOS$W:9WIF&F
M0[2U*2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED
M(").971S8V%P92!"87-E(%523"(*;7-G<W1R(").971S8V%P92"LL+#RPJ:J
MNKKTIWTB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-`IM<V=I
M9"`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B3F5T<V-A
M<&4@OLS#TJ=`O&^Z]*=](@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU.#8*;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!54DPB"FUS9W-T<B`B
M3F5T<V-A<&4@OLS#TJQ&M::Z]*=](@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU.#4*;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S
M='(@(DYE='-C87!E(*?SMW.Z]*=](@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM
M<V=S='(@(DYE='-C87!E(*=`O&^Z]*=](@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M
M92(*;7-G<W1R(").971S8V%P92!34TP@IOBJ0;ZYIE>ZV2(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-3@X"FUS9VED(").971S8V%P92!C97)T
M:69I8V%T92!C;VUM96YT(@IM<V=S='(@(DYE='-C87!E(+[,P]*JNK7YN-$B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T
M<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R(").971S8V%P92"^S,/2
MJZRZ02(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3,*;7-G:60@
M(DYE='=O<FLB"FUS9W-T<B`BNO2X]*1UJ.,B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S.0HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDP"FUS9VED(").979E<B(*;7-G<W1R
M("*Q<:6\(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDU"FUS9VED(").97<@0V%L961O;FEA(@IM<V=S='(@(DYE=R!#
M86QE9&]N:6$@*+=SL]BHO:9HI:>HR"DB"@HC.B!L:6(O2&]R9&4O4')E9G,O
M0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM
M<V=S='(@(K=SO%>DP,/^(@H*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M
M86EL<RYP:'`Z.#$@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z
M.#<*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z.3<@;&EB
M+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z,3`Q"B,L('!H<"UF;W)M
M870*;7-G:60@(DYE=R!-97-S86=E('1O("5S(@IM<V=S='(@(KQGJTBUN2`E
M<R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB
M"FUS9W-T<B`BMW.DZR(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S
M='(@(K=SJ,^ESJK,IE>ZV2`HJT2ELJUN*2(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ.#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3F5W(%IE86QA
M;F0B"FUS9W-T<B`B3F5W(%IE86QA;F0@**_#INC$]2DB"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*;7-G:60@(DYE=R!P87-S=V]R9"(*
M;7-G<W1R("*W<[%+O5@B"@HC.B!L:6(O2&]R9&4O075T:"]S<6PN<&AP.C(R
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL;"!E>'!I
M<F4@;VX@)7@N(@IM<V=S='(@(K=SL4N]6+%.J?,E>*CLM,$N(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R"FUS9VED(").97<@<&%S<W=O
M<F1S(&1O;B=T(&UA=&-H+B(*;7-G<W1R("*W<[%+O5BDH[+%IE@N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I
M9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R("*W<[7XM:$@*%]B;&%N
M:RDB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Y,0IM
M<V=I9"`B3F5W<R(*;7-G<W1R("*W<[M$(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,P-PIM<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R("*W<[M$
MN'.RU2(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$U('1E;7!L
M871E<R]D871A+V1A=&5M87`N:6YC.C0Q"B,Z('1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,Z,3(Y('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(U"FUS
M9VED(").97AT(@IM<V=S='(@(J15I$"H0B(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B3F5X="`T(%!H87-E<R(*;7-G<W1R
M("*D5:W3I.NLVR(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S<R(&QI
M8B](;W)D92]0<F5F<R]522YP:'`Z,S<V"FUS9VED(").97AT(&]P=&EO;G,B
M"FUS9W-T<B`BI%6D0*W3O^^VM2(*"B,Z(&QI8B](;W)D92]522]086=E<BYP
M:'`Z,3`S"FUS9VED(").97AT/B(*;7-G<W1R("*D5:1`K;8B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3<T(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G:60@
M(DYI8V%R86=U82(*;7-G<W1R(").:6-A<F%G=6$@**6GI5NIU*7**2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S$@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$V-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@IM
M<V=I9"`B3FEG97(B"FUS9W-T<B`B3FEG97(@**6GI.DI(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$W,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"FUS9VED(").
M:6=E<FEA(@IM<V=S='(@(DYI9V5R:6$@**E@I,ZG4:C(*2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-CD*;7-G:60@(DYI9VAT(@IM<V=S
M='(@(K'?I%<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<Y(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C<*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3<*;7-G:60@(DYI=64B"FUS9W-T<B`B3FEU92`HK\.N2JYQ
M*2(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY-C,*
M;7-G:60@(DYO(@IM<V=S='(@(J=?(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E
M='5P+V1I9F8N:'1M;#HY"FUS9VED(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A
M=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*;7-G<W1R("*U
M3*5IJ-'%XZ7<KG2RIZJZLUVI=[CJKL8N(@H*(SH@;&EB+U9&4R])4T]7<FET
M97(N<&AP.C$P-@IM<V=I9"`B3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M
M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`BM4RE::7.JKJUIK*DJ]BS>2!)
M4T\@O':YLRXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(JA3IK.G
MY::XO,NFH2XB"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HW.2!L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HR-#4*(SH@;&EB+TAO<F1E+T)L
M;V-K+TQA>6]U="YP:'`Z,C8W"FUS9VED(").;R!B;&]C:R!E>&ES=',@870@
M=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R("*ITJO\J7>JNJ;LN&VD
M5ZA3IK.PS[;TIG.F8B(*"B,Z(&QI8B](;W)D92]!=71H+VUC86PN<&AP.C4P
M"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R("*H4Z:SM*.HT:;FJ,:^Y*97NMFE2*C1
M($U#04P@Q>?#TBXB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`IM<V=I
M9"`B3F\@8VAA;F=E+B(*;7-G<W1R("*H4Z:SQ=RG\RXB"@HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E
M(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`BM4RJ:Z9BI=BK
M9<5VK:VDI+Q7I5NFN,5VK:TN(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-CD@;&EB
M+TAO<F1E+G!H<#HU,#@@;&EB+TAO<F1E+U5T:6PN<&AP.C<V.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@(JA3IK.K_*EWJKH@)7,@LUVI=[CJ
ML%0N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@T-`IM<V=I9"`B3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N(@IM
M<V=S='(@(JA3IK.K_*EWJKH@1E10(%9&4R"S7:EWN.JP5"XB"@HC.B!L:6(O
M5D93+W-Q;"YP:'`Z-C<R"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`BJ%.FLZO\
MJ7>JNB!344P@5D93LUVI=[CJL%0N(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z-S(U"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R("*H4Z:SJ_RI=ZJZ
M(%-13"U&:6QE(%9&4[-=J7>XZK!4+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS
M9W-T<B`BM4RST;YLPDF\QBXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,T"FUS9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB
M"FUS9W-T<B`BI;RTHZC1I=BJNBXB"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP
M:'`Z.3`S"FUS9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(L#)KM>E
MO*17ML<B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO
M(&EC;VYS(&9O=6YD+B(*;7-G<W1R("*GY*2CJ.RYSZ7<+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,38@;&EB+T)L;V-K+W-U;G)I<V4N
M<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(S"FUS9VED(").;R!L
M;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(J;LN&VXZK!4J7REO+-=J7<B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W"FUS9VED(").;R!L
M;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`BJ7REO+2CJ-&F[+AMN.JP5"XB
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED
M(").;R!M97-S86=E('-U<'!L:65D+B(*;7-G<W1R("*EO+2CJ-'"LK!4+B(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*;7-G:60@
M(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R("*EO*O\J7>F5[K9+B(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*;7-G:60@(DYO
M(&YU;6)E<B!S<&5C:69I960N(@IM<V=S='(@(J6\J_RI=[BYO5@N(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT"B,L(&9U>GIY"FUS9VED(").;R!O
M9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`BI^2DHZCLN<^EW"XB"@HC.B!L
M:6(O2&]R9&4O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(JA3
MIK.K_*EWL4N]6*5(J-$@2%144"#%Y\/2+B(*"B,Z(&QI8B](;W)D92]!=71H
M+VEM87`N<&AP.C$P.`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($E-05`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(JA3IK.K_*EWL4N]6*5(
MJ-$@24U!4"#%Y\/2+B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C<R
M"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(JA3IK.K_*EWL4N]6*5(J-$@2V5R8F5R
M;W,@Q>?#TBXB"@HC.B!L:6(O2&]R9&4O075T:"]S87-L+G!H<#HW-R!L:6(O
M2&]R9&4O075T:"]L;V=I;BYP:'`Z.#0*(SH@;&EB+TAO<F1E+T%U=&@O<&%M
M+G!H<#HW-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("*H4Z:SJ_RI=[%+O5BE2*C1($QO
M9VEN(,7GP](N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<&%S<W=D+G!H<#HQ,S4*
M;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(JA3IK.K_*EWL4N]6*5(J-$@4$%34U=$(,7G
MP](N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<VUB+G!H<#HX-`IM<V=I9"`B3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`BJ%.FLZO\J7>Q2[U8I4BHT2!334(@Q>?#TBXB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C$R.#<*;7-G:60@(B(*(DYO('!A=&@@=&\@
M=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA
M<GD@:7,@;F5C97-S87)Y('1O("(*(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N
M(@IM<V=S='(@(B(*(J6\O^FD2B!/<&5N4U-,(*1'I+BP]:;FP,FJNJ7^N/2N
M?"X@4$M#4R`Q,B"S5Z[FJKJE6[%+N.JNQKO=K6ZESJCLN-.U>Z:A+B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO
M('!E;F1I;F<@<VEG;G5P<RXB"FUS9W-T<B`BJ%.FLZO=O&:JNK7YI56ET[W0
M+B(*"B,Z(&QI8B]61E,N<&AP.C<V-0IM<V=I9"`B3F\@<75O=&$@<V5T+B(*
M;7-G<W1R("*ZS[K0L'3#0J6\LUVI=R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*;7-G:60@(DYO(')U;&5S
M(@IM<V=S='(@(K5,KN:]=2(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z-#@R"FUS
M9VED(").;R!S97!A<F%T;W(@<W!E8VEF:65D+B(*;7-G<W1R("*I?*6\J_RI
M=\3FINRDP+EJIG*DN"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0T"FUS9VED(").;R!S:61E<R(*;7-G<W1R
M("*U3*[8O74B"@HC.B!L:6(O5D93+W-M8BYP:'`Z-3@W"FUS9VED(").;R!S
M=6-H(&9I;&4B"FUS9W-T<B`BM4RFN<#)KM<B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3(V"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T
M;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(K5,O,BF<Z78O_VE
M::C1I]:H^BXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,Q(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HR,C$*;7-G:60@(DYO('5S
M97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R("*EO+;'L&6H
MSZ7.JLRF5[K9J<ZQ2[U8+B(*"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C+G!H
M<#HQ-#`*;7-G:60@(DYO('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S
M='(@(K5,I6FESJJZ(%A-3""XZJ[&LU&VQZ9>(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW,2!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.3@Q"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HY.3(*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$P,#D*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R("*JQ:75K<@B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V97)S
M:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A
M=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BK>RI;+-=J7?`R:2DI^2DHZCL
MJJFEN[CJL%0N(*VKMW.RHZ7-LUVI=\#)+B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(J9BIT&JNK-=J7?`R:2DI^2DHZCLJJFEN[CJL%0N(*VKMW.RHZ7-LUVI
M=\#)+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R-R!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0U"B,Z('1E
M;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3,*;7-G:60@(DYO
M;F4B"FUS9W-T<B`BM4PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CDP"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM
M<V=S='(@(K5,("AU<V4@:6UP;&EC:70I(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#4*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@
M(J3IIM6PTJ3E("A)4T\M.#@U.2TQ,"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3<R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L
M86YD(@IM<V=S='(@(DYO<F9O;&L@27-L86YD("B_U;K6ITJN<2DB"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS
M9VED(").;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(J5?I6*R>2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3@@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$V.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,PIM
M<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S='(@(DYO<G1H
M97)N($UA<FEA;F$@27-L86YD<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM<V=S='(@
M(DYO<G=A>2`HKK^KPBDB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C8T,0IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(JM$I*>KX2(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0P"FUS9VED(").;W0@0F5F;W)E
M(@IM<V=S='(@(JM$I*>K92(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-#$R"FUS
M9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`BI*.L3Z1`K=.EV+_](@H*
M(SH@;&EB+U9&4R])4T]7<FET97(N<&AP.C8S(&QI8B]61E,O25-/5W)I=&5R
M+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#0*(SH@;&EB+U9&4R])4T]7<FET
M97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-0HC.B!L:6(O5D93+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-#@*(SH@;&EB+U9&4R])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"FUS9VED(").;W0@:6UP
M;&5M96YT960N(@IM<V=S='(@(K5[IJ&I?*6\I[FFJ"XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8X"FUS9VED(").;W0@
M<V5T(@IM<V=S='(@(J2CLUVI=R(*"B,Z(&QI8B]61E,N<&AP.C$Y,R!L:6(O
M5D93+G!H<#HR,#@@;&EB+U9&4RYP:'`Z,C,S(&QI8B]61E,N<&AP.C(U,0HC
M.B!L:6(O5D93+G!H<#HR-C@@;&EB+U9&4RYP:'`Z,C@T(&QI8B]61E,N<&AP
M.C,P,"!L:6(O5D93+G!H<#HS,34*(SH@;&EB+U9&4RYP:'`Z,S,R(&QI8B]6
M1E,N<&AP.C,V-2!L:6(O5D93+G!H<#HT,C4@;&EB+U9&4RYP:'`Z-3`T"B,Z
M(&QI8B]61E,N<&AP.C4W,R!L:6(O5D93+G!H<#HU.3`@;&EB+U9&4RYP:'`Z
M-C8X"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,30U(&QI8B](
M;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,38P"B,Z(&QI8B](;W)D92]397-S
M:6]N2&%N9&QE<BYP:'`Z,3<U(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP
M:'`Z,3@Y"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,C,V"FUS
M9VED(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R("*EO+-1I.2TJ2(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T(&-O;F9I9R]H;V]K
M<RYP:'`N9&ES=#HQ,#`U"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ
M.#`*;7-G:60@(DYO=&5S(@IM<V=S='(@(K/&I]&__2(*"B,Z('-E<G9I8V5S
M+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W
M<V4L(&=O(&)A8VLN(@IM<V=S='(@(JA3IK.E:<)SQ/VJNBRF7J5H+B(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED(").;W9E;6)E
M<B(*;7-G<W1R("*D4:1`I.LB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`U
M,`IM<V=I9"`B3G5M8F5R(@IM<V=S='(@(KS&IG(B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,30R.0IM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS
M9W-T<B`BIG*DN+S&(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-S,@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$T,C<@;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#D*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*
M;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@(J9RI+B\9:O7(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-S$@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$T,C4@;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#<*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O
M9B!R;W=S(@IM<V=S='(@(J;FO,8B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C0T"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@
M9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("*G
M\[=SL'2X;;ASLM6NR:6\J_RI=[S&I=@N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R(")/
M2R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX-S`*
M;7-G:60@(D]B:F5C="(*;7-G<W1R("*JJZ7S(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,3$*;7-G:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S
M='(@(JJKI?.KV*7?JLPB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$P.`IM
M<V=I9"`B3V-T86PB"FUS9W-T<B`BI$NV::;L(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P."!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS9W-T<B`BI%&D
MZR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B3V9F96YS
M92!F:6QT97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,R.`IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(K_LI+VKQR(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N
M97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R("*W<[%+
MO5BELK:WNU#"PK%+O5BDHZ90+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HS-@IM<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@(L+"L4N]
M6"(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B
M3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R("+"PK%+O5BD
MHZ6_O50B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@Q(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T<B`B3VUA;B`HJORPTBDB"@HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N
M;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S
M='(@(J5UIK,@24U!4""F^*I!OKFDY+2IJTBE\Z=8I,"HR:5<K^`N(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDU"B,L(&9U>GIY"FUS9VED(")/;FQY
M(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("*GY*2CJ.RYSZ7<+B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ.#4U(&QI8B](;W)D92]&;W)M+G!H<#HQ
M.3<U"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM
M<V=S='(@(J5UI+FS7*1`K=.V;*7SINVG?2XB"@HC.B!S97)V:6-E<R]S:&%R
M97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y
M<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W
M;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(J5UIK.^
MUJ:SJLR[4*ATLLZZWK)ZK?NE::5(Q=RG\Z9`J,G%=JVM(@H*(SH@;&EB+T)L
M;V-K+VEF<F%M92YP:'`Z,SD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-#`*;7-G
M:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(J9BMW.JNK7XM:&V
M?;'2(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@
M(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S
M:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@(D]P96Y34TP@O_F[?CH@M4RJ
M:[%Q(%,O34E-12##L;.YJOZE\[C1MGVXZJ[&+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B
M3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("*F8K=S
MJKJU^+6AMGVQTK-SM;(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*
M;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T<B`BIT"W?JATLLXB"@HC
M.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I
M;VYS(@IM<V=S='(@(K_OMK4B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S$@
M=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B)7._[[:U(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D
M97)E9"!,:7-T(@IM<V=S='(@(K:UI=B]<[BY(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R
M("*RU<*T(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G
M:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`BLM7"M+/FINPB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,T"FUS9VED(")/<F=A;FEZ
M:6YG(@IM<V=S='(@(K+5PK0B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S
M-0IM<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T
M<B`BK>RI;,"SI<ZU>Z:AO,NJ3R(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E;7!L871E<R!I
M;B`E<SHB"FUS9W-T<B`BIF(@)7,Z(*2DJKJM[*ELO,NJ3RXB"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP
M.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDT"FUS9VED(")/=&AE<B(*;7-G<W1R("*HY*5,(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDY(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#D*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3(U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S0@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$T-`IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB"FUS
M9W-T<B`BJ.2E3+CJL%0B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R("*^UJ:SJLS%
M=JVM(@H*(SH@;&EB+TAO<F1E+T%U=&@O<&%M+G!H<#HW.0IM<V=I9"`B4$%-
M(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(E!!
M32#%Y\/2M4RNQ"XB"@HC.B!L:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP
M.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM<V=S='(@(E!%05(Z
M.K9LI?.F^*I!NMTB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,C<V
M"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B4$=0(+S&
MINS#L;.Y(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3,R,@IM<V=I
M9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S='(@(E!'4""E6[%+N.JNQB(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$S-S0*;7-G:60@(E!'4"!0
M=6)L:6,@2V5Y(@IM<V=S='(@(E!'4""DO;9]JO?&7R(*"B,Z(&QI8B](;W)D
M92]#<GEP="]P9W`N<&AP.C$S-38*;7-G:60@(E!'4"!3:6=N960O16YC<GEP
M=&5D($1A=&$B"FUS9W-T<B`B4$=0(*1WP[&SN2^D=Z5;L4L@N.JNQB(*"B,Z
M(&%D;6EN+W!H<'-H96QL+G!H<#HV.`IM<V=I9"`B4$A0($-O9&4B"FUS9W-T
M<B`B4$A0(+5[IJ&]6"(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I
M9"`B4$A0(%-H96QL(@IM<V=S='(@(E!(4""O\[U:(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*;7-G:60@(E!-($QI9VAT
M(%)A:6XB"FUS9W-T<B`BI,BKX:1PJT(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS.`IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G
M<W1R("*DR*OAL'VK0B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,Y"FUS9VED(")032!3;F]W(@IM<V=S='(@(J3(J^&FL[.W
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#`*
M;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R("*DR*OAL'VSMR(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"FUS9VED
M(")032!3=6XB"FUS9W-T<B`BI,BKX;2X(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E!-(%0M4W1O<FUS(@IM
M<V=S='(@(J3(J^&Y<*M"(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(W
M-`IM<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T<B`B
M4$]325@@97AT96YS:6]N(+_RI:(B"@HC.B!L:6(O87!I+G!H<#HQ-#D*;7-G
M:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B4$A0(*_SO5I?2"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G
M:60@(E!A9&1I;F<B"FUS9W-T<B`BN=2E4B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ.#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%K:7-T86XB
M"FUS9W-T<B`B4&%K:7-T86X@**3:L/*TM:E:*2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ.30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W
M,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U
M(@IM<V=S='(@(E!A;&%U("BIK:];*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ.3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N
M(%1E<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B4&%L97-T:6YI86X@5&5R
M<FET;W)Y+"!/8V-U<&EE9"`HI-JPQ[2UJ5JF^[OBL,\I(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$X,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(")0
M86YA;6$B"FUS9W-T<B`B4&%N86UA("BDVJZSL*@I(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$X-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY"FUS9VED(")087!U
M82!.97<@1W5I;F5A(@IM<V=S='(@(E!A<'5A($YE=R!'=6EN96$@**3:I:RH
MR+=SM%BDNJC(*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.34@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(E!A<F%G
M=6%Y("BDVJG4IF,I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S8*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`BIFBV
MLR(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ.#`@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,C(*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4S-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$Y.0HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,34Q
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHT,R!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#(U"FUS9VED(")087-S=V]R9"(*;7-G<W1R("*Q2[U8(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED(")087-S=V]R9"!C
M:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`BL4N]6,7<I_.GN::H+B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3,R,PIM<V=I9"`B4&%S
M<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(K%+O5BDHZ6_O50B"@HC.B!L:6(O
M2&]R9&4O075T:"]R861I=7,N<&AP.C$U,@IM<V=I9"`B4&%S<W=O<F0@<F5Q
M=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BJ%.F
MLZO\J7>Q2[U8I4BHT2!2041)55,@Q>?#TBXB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C`U-PIM<V=I9"`B4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VXB
M"FUS9W-T<B`BL4N]6+U4NWLB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z.3`*;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R("*Q2[U8.B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"FUS9VED(")087-S=V]R
M9#H@(@IM<V=S='(@(K%+O5@Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C`S.`HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C$U"FUS9VED(")087-S=V]R9',@;75S="!M871C:"XB
M"FUS9W-T<B`BL4N]6*6RMK>G:Z98+B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,3D@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(R"FUS9VED(")087-T92(*;7-G<W1R("*V2Z17(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B
M4&%S=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T<B`BMDND5R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A
M=&@B"FUS9W-T<B`BN/2N?"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D
M+FEN8SHW"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(JO=O&:U
M;K_]H4<B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*;7-G:60@(E!E
M;W!L92(*;7-G<W1R("*FJ*W[(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`B
MILJDP*3Q(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E
M+FAT;6PZ-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<R(*;7-G<W1R("*P]:;FNOO%0+[>IT`B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#$P"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@;VX@;&]G:6X_(@IM<V=S='(@(K5NI$JKX;#UIN:Z^\5`OMZG0#\B"@HC
M.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B4&5R;6ES<VEO
M;B(*;7-G<W1R("+%=JVM(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@
M9&5L971E9"XB"FUS9W-T<B`B7"(E<UPBJKK%=JVMI;RS4:=2L*,N(@H*(SH@
M;&EB+U9&4R]S;6(N<&AP.C4Y,`IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B
M"FUS9W-T<B`BIG.H^KY$J=HB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C$V,2!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R;6ES
M<VEO;G,B"FUS9W-T<B`BQ7:MK2(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP
M.C$P.2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C`*(SH@861M:6XO<&5R
M;7,O:6YD97@N<&AP.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3@*;7-G
M:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(L5VK:VZ
MWK)Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X"FUS9VED(")097)S
M;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R("*GVJJZ(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$X,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(")097)U
M(@IM<V=S='(@(E!E<G4@**^UOGPI(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4U"FUS9VED(")0971S(@IM<V=S='(@(L-DJJLB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3@V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!H
M:6QI<'!I;F5S(@IM<V=S='(@(E!H:6QI<'!I;F5S("BUX:O?NZLI(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H
M;VYE(@IM<V=S='(@(KEQN-PB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#@P"FUS9VED(")0:&]T;W,B"FUS9W-T<B`BP\"T62(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$X,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@
M(E!I=&-A:7)N(@IM<V=S='(@(E!I=&-A:7)N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*
M;7-G<W1R("*YLZ_`(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS
M9VED(")0;&%T:71U9&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S
M92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R("*]T+9II$K`>*9SKN;"
M2;_O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W
M86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@(KW0O52I=ZUN
MLKZPHZ:YI+BE\SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H
M870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B
MO="]5*EWIT&M;J2DPE^FN:2XI?.JNK-SM;(N(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(U-C8*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A
M('EE87(N(@IM<V=S='(@(KW0O^FD2J1`K=.DZZ7WI,ZF?J7W+B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C$R"FUS9VED
M(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*
M;7-G<W1R("*]T+_II$JW<[Q7I,##_JJZIE>ZV3HB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3,P-0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@
M861D<F5S<RXB"FUS9W-T<B`BO="_Z:1*I$"MTZ:SKL2JNB!)4""F[*=](@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(V-#<*;7-G:60@(E!L96%S92!E;G1E
M<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T
M:&4@;6]N=&@N(@IM<V=S='(@(KW0O^FD2J1`K=.FLZ[$JKJDZ;3!.Z3$O^^F
MN:3KI?>JNJ3IM,$N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(T-3$*;7-G
M:60@(E!L96%S92!E;G1E<B!A('9A;&ED('1I;64N(@IM<V=S='(@(KW0O^FD
M2J1`K=.FLZ[$JKJNR;:A+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C<*;7-G:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T
M:&4@<')O8FQE;2XB"FUS9W-T<B`BO="THZC1L-W#1*JZNDNM;BXB"@HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA
M;64@86YD('!A<W-W;W)D(@IM<V=S='(@(KW0O^FD2J=!JKJHSZ7.JLRF5[K9
MI,ZQ2[U8(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4X"FUS9VED
M("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4
M(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*
M;7-G<W1R("*]T+Y<Q:JD5:9#I+JN92ZG0:6RMK>F4+=.LV^HQZC&MK6D?J_@
MJ,^ESJATLLXN(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E
M<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@
M;F%M93HB"FUS9W-T<B`BO="_Z:1*MW.JNJ3`P_ZF5[K9.B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$X,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B
M4&]L86YD(@IM<V=S='(@(E!O;&%N9"`HJFG$]2DB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S(@IM<V=S='(@(JQ&JG8B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@Y"FUS9VED(")0;VQL
M<R(*;7-G<W1R("*GZ[*\(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B
M4&]R='5G86P@*+BRM>6D^BDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N
M:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T<B`BO':YLZ;LN&TB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B
M4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R("*J[:[FINRX;2(*
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B
M4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM
M<V=S='(@(KN\L&6V;*7SJ.RS;ZW3JTBE\Z=8("AN;W0@96YF;W)C960@8GD@
M24U!4"DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V-B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I=&%T
M:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R("*SS*KQ("5S(*1P
MKLFJNJVPJT*V<3H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(X-PIM<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R
M("*ML*M"/&)R("\^OO>R=B(*"B,Z(&QI8B](;W)D92]0<F5F<R]L9&%P+G!H
M<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]L9&%P.B"GY*2CJ.RITKO=
MK6ZJNB!,1$%0(*FUIOFN3:7S+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]S97-S
M:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S
M<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]S97-S
M:6]N.B"GY*2CJ.RITKO=K6ZJNB!S97-S:6]N(*FUIOFN3:7S+B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C(U"FUS9VED(")0<F5S<W5R92(*;7-G<W1R
M("*N\,"C(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3D*;7-G:60@(E!R
M97-S=7)E(&%T('-E82!L979E;#H@(@IM<V=S='(@(J[\I:VML:[PP*,Z("(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C0*;7-G:60@(E!R
M97-S=7)E.B`B"FUS9W-T<B`BKO#`HSH@(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(P-`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R979I
M97<B"FUS9W-T<B`BN7?$_2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T
M:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(J9BMW.JNK7XM:&Y
M=\3]O':YLR(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S8R(&QI8B](
M;W)D92]0<F5F<R]522YP:'`Z,S8V"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS
M(@IM<V=S='(@(J17I$"MT[_OMK4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*
M;7-G<W1R("*F0Z9,I.6E\R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C0R,PIM<V=I9"`B4')I=F%T92!+97DB"FUS9W-T<B`BJ'"Q2ZKWQE\B"@HC
M.B!L:6(O2&]R9&4O365N=2YP:'`Z,38Y"FUS9VED(")0<F]B;&5M(@IM<V=S
M='(@(K#=PT0B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C<*;7-G:60@
M(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`BL-W#1+1YK7HB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<Q"FUS9VED(")0<F]J96-T<R(*
M;7-G<W1R("*Q3:[7(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,34@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(Q.3(@;&EB+TAO<F1E+T9O<FTN<&AP.C,R-S0*
M;7-G:60@(E!R;VUP="!T97AT(@IM<V=S='(@(K2CI=RDNJYE(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM
M<V=S='(@(J2]MGVJ]\9?(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HV-#8*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(J2]
MMGVJ]\9?NG2ZXB(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0U
M"FUS9VED(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`BI+VV?:KWQE^XZK!4
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L
M:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY
M+B(*;7-G<W1R("*DO;9]+ZAPL4NJ]\9?N>^HPZ6\LU&RHZ7-+B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ.3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$X,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G
M:60@(E!U97)T;R!2:6-O(@IM<V=S='(@(E!U97)T;R!2:6-O("BJ::9HOJ2F
M52DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DV(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`R"FUS9VED(")1871A<B(*;7-G<W1R(")1871A<B`HI62Y1BDB"@HC
M.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C,*;7-G:60@(E%U97)Y(@IM<V=S='(@
M(JQDN-\B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*;7-G:60@(E%U
M;W1A(@IM<V=S='(@(KK/NM"P=+AM(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HV-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+
M97D@*"5D(&)I="DB"FUS9W-T<B`B4E-!(*2]MGVJ]\9?("@E9""F[*2X*2(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C8X"FUS9VED(")2861I;R!S96QE
M8W1I;VXB"FUS9W-T<B`BO^^^W+9S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#,*;7-G:60@(E)A:6XB"FUS9W-T<B`BJT(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM
M<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R("*FK::SJT(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I;B!,
M871E(@IM<V=S='(@(K'?IK.K0B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0V"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R
M("*P?:M"(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#<*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`BJT*FL[.W(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*;7-G
M:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R("*K0L+@L[<B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U;F4B"FUS9W-T
M<B`BP$B^]Z1PNWDB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H
M<#HV."!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW-@IM<V=I9"`B
M4F%T:6\B"FUS9W-T<B`BI/&R=B(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z
M,S(T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3@P"FUS9VED(")296%D(@IM<V=S='(@(L6JJ/HB"@HC.B!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*;7-G:60@(E)E860@;65S
M<V%G97,B"FUS9W-T<B`BQ:JH^K9LI?,B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY
M(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB
M"FUS9W-T<B`BKW6JNJUNIU*PHR`E<R"VW#\@LV^VM;[>IT"Q3K5,JFNK[+1?
M+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX"B,L('!H
M<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U
M<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G
M<W1R("*O=:JZK6ZR3;"CJ,^ESJK,("5S(*JZN.JNQK;<(#\@LV^VM;[>IT"Q
M3K5,JFNK[+1?+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM
M<V=S='(@(JCZKOBT7ZWL(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#8*;7-G:60@(E)E9G)E<V@B"FUS
M9W-T<B`BK:NW<[[CLGHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDU
M"FUS9VED(")2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T
M<B`BK:NW<[[CLGJPRKI!I=B__:2XI?,Z(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,T-0IM<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB"FUS9W-T
M<B`BK:NW<[[CLGJMTZ1(K[BE>*2ZKF4Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C@Y."!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q-R!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3(S.0IM<V=I9"`B4F5G97@B"FUS9W-T<B`BL6"S5ZKMI=RFH2(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C,X"FUS9VED(")296QA=&EO;G-H
M:7`@0G)O=W-E<B(*;7-G<W1R("+#]L%PPG/$_;ZY(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(P.`IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(JVKQ:HB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,R-@IM<V=I9"`B4F5M87)K<R(*;7-G<W1R("*U
M^[W7(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-PIM<V=I9"`B4F5M
M;W1E(%-E<G9E<G,B"FUS9W-T<B`BN[>ZW:;XJD&^N2(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T
M<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@IM<V=S='(@(KNWNMVZ]*=]
M("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"@HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(R('1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E
M;6]V97%U975E9"YI;F,Z,3,*;7-G:60@(E)E;6]V92(*;7-G<W1R("*ROK"C
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"FUS9VED(")2
M96UO=F4@0FQO8VLB"FUS9W-T<B`BLKZPH[#/MO0B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34V"FUS9VED(")296UO=F4@8V]L
M=6UN(@IM<V=S='(@(K*^L*/$YJ;L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`IM<V=I9"`B4F5M;W9E(&9O<FUA='1I
M;F<B"FUS9W-T<B`BI6BPHZ[FIJ$B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M
M87`N:6YC.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`BLKZPH[GO
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E
M('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O
M<GDN(@IM<V=S='(@(J;;IOBJ0;ZYO,BF<Z78O_VDI+*^L*.D=\!XIG.JNK-=
MJ7>U>Z:A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHT,@IM<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R("*R
MOK"C(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4P"FUS9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE
M(&1O8W5M96YT(@IM<V=S='(@(J;;I.6E\Z2DLKZPHZ:YI$"X8,))(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0IM<V=I9"`B4F5M
M;W9E('5S97(B"FUS9W-T<B`BLKZPHZC/I<ZJS"(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V92YI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")2
M96UO=F4@=7-E<CH@)7,B"FUS9W-T<B`BLKZPHZC/I<ZJS#H@)7,B"@HC.B!L
M:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED(")297%U97-T(&-O
M=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G
M<W1R("*[W:A$I;RS4:9>P+,Z(+_YNWZXN;U8.B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-#4*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E
M(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T<B`BI^2DHZCLJ=*[W:JZJD&P
MR"XB"@HC.B!L:6(O2&]R9&4N<&AP.C$W-B!L:6(O2&]R9&4N<&AP.C4Q.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I
M9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(E,B1S(*JZLUVI
M=Z6RMK>K_*EW(%PB)3$D<UPB(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C8W."!L
M:6(O5D93+V9T<"YP:'`Z.#4P(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<S,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I
M9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B5D93(*JZLUVI
M=Z6RMK>K_*EW(%PB)7-<(B(*"B,Z(&QI8B](;W)D92]5=&EL+G!H<#HW-S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C
M:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BLUVI=[CJKL:ELK:W
MJ_RI=R!<(B5S7"(B"@HC.B!L:6(O2&]R9&4O1F]R;2]296YD97)E<BYP:'`Z
M,S,U"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R("*ELK:WQ.:F["(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C,Q(&QI8B](;W)D92]&;W)M+G!H<#HS-#,@
M;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,R,`HC.B!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z,3`P('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(JVKLUTB"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B4F5S970@4&%S
M<W=O<F0B"FUS9W-T<B`BK:NS7;%+O5@B"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S970@66]U<B!087-S=V]R9"(*;7-G
M<W1R("*MJ[-=IT&JNK%+O5@Z(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S
M,`IM<V=I9"`B4F5S=&]R92!,87-T(%%U97)Y(@IM<V=S='(@(J9>IG.SS*OA
MI$"MTZQDN-\B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S$@861M:6XO8VUD
M<VAE;&PN<&AP.C(X(&%D;6EN+W-Q;'-H96QL+G!H<#HV-@IM<V=I9"`B4F5S
M=6QT<R(*;7-G<W1R("*ULJI'(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C$P,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2
M971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R("*J\*9>O^^VM2(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS.`IM<V=I9"`B4F5T>7!E(&YE=R!P
M87-S=V]R9"(*;7-G<W1R("*F0::XO^FD2K=SL4N]6"(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ.3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$X-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)E
M=6YI;VXB"FUS9W-T<B`B4F5U;FEO;B`HKV2EIZGTKG$I(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0X
M"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("*F7K1?LUVI
M=R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@(E)I8V@@
M5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R("*Z]*VVO7._Z+ZYO^^VM2(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE<R(*
M;7-G<W1R("+!O+MY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<P"FUS9VED(")2:6=H="(*;7-G<W1R("*E:\/D
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,3`*;7-G:60@(E)I9VAT(&AE
M861E<B(*;7-G<W1R("*E:\/DJNW`62(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HS,3`V"FUS9VED(")2:6=H="!V86QU97,B"FUS9W-T<B`BI6O#Y*W((@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`BID.D
MNJYE7W<N+BXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R("*HI*;B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$Y."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M
M86YI82(*;7-G<W1R(")2;VUA;FEA("C#N;"HI:>HR"DB"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(T"FUS9VED(")2;W1A=&4@
M,3@P(@IM<V=S='(@(K';PN`@,3@P(*O7(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(R,0IM<V=I9"`B4F]T871E($QE9G0B"FUS
M9W-T<B`BL&:NR;!W(#DP(*O7L=O"X"(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,C<*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G
M<W1R("*VMJ[)L'<@.3`@J]>QV\+@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E
M<G1I97,B"FUS9W-T<B`BID.DNJYE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I9"`B4F]W('!R;W!E
M<G1I97,B"FUS9W-T<B`BID.DNJYE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S='(@
M(J9#(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU,PIM<V=I9"`B4G5L97,B"FUS9W-T<B`BKN:]=2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*
M;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD
M(&-O;'5M;G,B"FUS9W-T<B`BQ.:F[+M0ID.NYKUU(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T
M<B`BQ.:F[*[FO74B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(')O=W,@;VYL>2(*;7-G<W1R("*F0Z[FO74B"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3(P"FUS9VED(")2=6XB"FUS9W-T<B`BL/6FYB(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3D@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$X-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*
M;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R(")2=7-S:6%N($9E
M9&5R871I;VX@**M8P[FTM2DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C`P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=V%N9&$B"FUS9W-T<B`B
M4G=A;F1A("B_8Z9WN48I(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*
M;7-G<W1R(")3+TU)344@I5NQ2\.QL[DB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E
M(@IM<V=S='(@(K9LI?.D=ZC/I<X@4R]-24U%(*5;L4LB"@HC.B!L:6(O2&]R
M9&4O075T:"]S87-L+G!H<#HX,0IM<V=I9"`B4T%33"!A=71H96YT:6-A=&EO
M;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")305-,(,7GP]*U3*[$+B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,#8*;7-G:60@(E--4R!-
M97-S86=I;F<B"FUS9W-T<B`BPK*P5"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(KCJKL:N=Z_SO5HB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(W,@IM<V=I9"`B4U%,('-T871E;65N
M="!F;W(@=F%L=64@;&]O:W5P<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#,S"FUS9VED(")34T@B"FUS9W-T<B`BI5NQ2[+7
MNMV^]R(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B
M:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R("*FJ*5<(@H*(SH@
M;&EB+V%P:2YP:'`Z,34S"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@(KCJ
MKL:N=Z_SO5I?42(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@(JQ0M,&DNR(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$X.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G
M:60@(E-A:6YT($AE;&5N82(*;7-G<W1R(")386EN="!(96QE;F$@*+ATNZZP
MQZ_'*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@
M(E-A:6YT($MI='1S(&%N9"!.979I<R`HN'2G2JB]M+6F:+K6I,ZEI[K[M+4I
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S.2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@W"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R(")386EN="!,=6-I82`H
MN'3%4Z;HJ,@I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO
M;B(*;7-G<W1R(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(T-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DS"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-0IM<V=I
M9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B
M4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,@*+ATI.6TRZ3.KN:W
MYZBZI$(I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(J90
MI$"MT[7XM:$@*%]S96QF*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M-3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S='(@(E-A
M;6]A("C"Q+ROJ,BX<ZYQ*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T
M<B`B4V%N($UA<FEN;R`HN'2PJ*=1O]4I(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(Q-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4V%O(%1O;64@
M86YD(%!R:6YC:7!E(@IM<V=S='(@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92`H
MN'2F:*S\I,ZTMJI,INBD\2DB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R("*]PZQ0
MM*.HT:K,(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P,2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(E-A=61I
M($%R86)I82`HJ$:O4:9AJORIU*="*2(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;&%Y;W5T+FEN8SHY.0IM<V=I9"`B4V%V92(*;7-G<W1R("+`>*9S(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3879E(%PB)7-<(B(*;7-G<W1R("+`>*9S(%PB)7-<(B(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V"B,L('!H<"UF;W)M
M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`BP'BF<R`E<R(*"B,Z('1E;7!L
M871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G
M<W1R("+`>*9SO^^VM2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C<*
M;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!0
M2%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C
M=&]R>2XB"FUS9W-T<B`BL4ZRHZ7-JKJS7:EWP,FE2"!02%`@NWFHI:[FIJ'`
M>*9SJ.RG0:JZIOBJ0;ZYO,BF<Z78O_VDI"XB"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("*S7:EW("5S(*1WP'BF<RXB"@HC.B!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G
M<W1R("*G\[=SM7NFH:1WP'BF<ZCL.B!<(B5S7"(N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*;7-G:60@(E-C871T97)E
M9"!4+5-T;W)M<R(*;7-G<W1R("*Y<ZQ0N7"K0B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R("*L[+['(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C:"(*;7-G<W1R
M("*W:K1-(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R,@IM<V=I
M9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T<B`BMVJT3:3>P+HB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,CDV,@IM<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S
M='(@(K_OOMS`R:[7(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0X,@IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R("*_[[[<
MI$"MTZ3IM,$B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM
M<V=I9"`B4V5L96-T(&$@9W)O=7`@=&\@861D(@IM<V=S='(@(K_OOMRD0*W3
MN'.RU:7.I4BW<[Q7(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT
M,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@(K_OOMRD0*;L
MMW.JNK[6IK.JS"(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV
M,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(K_OOMRD0+.AIOBJ
M0;ZY(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-38*;7-G:60@
M(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S='(@(K_OOMRD0*;LJ,^ESJK,
MI<ZE2+=SO%<B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-C<S"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(K_OOMRITJ:S(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(V-3`*;7-G:60@(E-E;&5C="!A;&P@
M9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R("*_[[[<J=*FLZ3IM,&DN*7S+B(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX-S`*;7-G
M:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`BO^^^W*1`K=.JJZ7S(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-`IM<V=I
M9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`BI*._[[[<(@H*(SH@<V5R=FEC97,O
M:V5Y8F]A<F0N<&AP.C,W"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A8W1E
M<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE
M;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82XB
M"FUS9W-T<B`BJ?.E2*15JKJU^+6AI*2_[ZCZIT&M;JJZIG*DN"ZE2+?&N:N]
MQKMSJ=*_[Z3EIG(LM4VKX;9+I%>DY:7SO7._Z+#/+B(*"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C,T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9&5L
M:6UI=&5R.B(*;7-G<W1R("*_[[[<I.FTP:3`N6HZ(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M
M870Z(@IM<V=S='(@(K_OOMRDZ;3!I.FTP:[FIJ$Z(@H*(SH@=&5M<&QA=&5S
M+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L96-T('1H
M92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(K_OOMRQ
M_<7<I_.JNJBMI??#T:=/.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC
M.C$V"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R
M("*_[[[<KLFVH:3`N6HZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z
M,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(K_O
MOMRDZ;3!KLFVH:[FIJ$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN
M8SHU-PIM<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N(@IM<V=S
M='(@(K_OOMRLVZ2LI,>P=*JZI$>MT\3FINPN(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,Q,`IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE
M+B(*;7-G<W1R("*_[[[<IT&JNL-#IN*P=+AM(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(U,@IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D(&QA
M;F=U86=E.B(*;7-G<W1R("*_[[[<L+ZF;KMYJ*4Z(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE;2!2
M97!O<G0B"FUS9W-T<B`BML>P9;#=PT2DS\"S(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,SD*;7-G:60@(E-E;F0@4TU3(@IM
M<V=S='(@(K;'L&7"LK!4(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R(")3
M96YE9V%L("BVZZ2ZI5NZN"DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q
M-@IM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`BMU"T^KZY.B`B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I9"`B4V5P=&5M8F5R(@IM
M<V=S='(@(J1%I.LB"@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DY"FUS9VED(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T<B`B4V5R
M8FEA(&%N9"!-;VYT96YE9W)O("BVZ[JXNONHR+M0NUBO4Z6GK?3#N2DB"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,@IM<V=I9"`B4V5R:6%L
M($YU;6)E<B(*;7-G<W1R("*GQ[BY(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$T.0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`BIOBJ0;ZYN.JNQK_YNWZISJK,M4RJ:ZC/
MI<XN(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(W"FUS9VED(")397-S:6]N
M($%D;6EN(@IM<V=S='(@(K=\M,&ZWK)Z(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E
M9"XB"FUS9W-T<B`BMWRTP2!)1""D=[E,M,$N(@H*(SH@;&EB+V%P:2YP:'`Z
M,30U"FUS9VED(")397-S:6]N<R(*;7-G<W1R("*W?+3!(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(S,3@*;7-G:60@(E-E="(*;7-G<W1R("*NUJCZI.BV
M]"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.0IM<V=I9"`B4V5T(&]P
M=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@
M>6]U(&5V97(@9F]R9V5T(&ET+B(*;7-G<W1R("*DN;-<IT&I\Z?1L$^Q2[U8
MJKJNR:W4+*5II4BFVZ;FK:NS7;%+O5@N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Q.`IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@
M>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@
M(K-=J7>[M[K=IOBJ0;ZYI%?$W:GSIT&JNJW3I$BON*5X+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HX-PIM<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D
M(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R
M("*S7:EWIT&JNK"^IFZ[>:BE+""NR;#/I4BDSJ3IM,&NYJ:A+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#$*;7-G:60@(B(*(E-E="!Y;W5R('-T
M87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H
M:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R("*S
M7:EWIT&JNK'2J6S`LZ7.M7NFH2S#0Z;BL'2X;2RMMJVQI_.W<\!7LG8LI,ZH
MY*5,Q>.EW+_OMK4N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0IM
M<V=I9"`B4V5T=7`B"FUS9W-T<B`BLUVI=R(*"B,Z('1E;7!L871E<R]A9&UI
M;B]S971U<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3971U<"!U<&=R861E('-C
M<FEP=',@879A:6QA8FQE(@IM<V=S='(@(J?SMW.U>Z:AM$ZZ_"(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S4*;7-G:60@(E-E=F5R86P@
M;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S
M='(@(J:SIFZT6*W3IF'"2:E-LV^MT[#1O,:FL\/V.B`B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C`S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3
M97EC:&5L;&5S(@IM<V=S='(@(E-E>6-H96QL97,@*+;KJ?6ZN"DB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DX"FUS9VED(")3:&]P<&EN9R(*
M;7-G<W1R("+!RJJK(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z-#,*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`BPK*U=;I+K6XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4P"FUS9VED(")3:&]U;&0@
M86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T
M<B`BK$^G7ZRPI&JSH:7WJKJS<[6RJ7>X<:?6L;:E7*_@P>0_(@H*(SH@;&EB
M+TAO<F1E+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T
M<B`BQ>.EW"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@
M(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@
M86YD('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`BQ>.EW+=SLJ.ES;M0K>S`>*9SLUVI=\#)JKJN=+*G+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT.30*;7-G:60@(E-H;W<@;&%S="!L;V=I
M;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`BJ$.FN+5NI$JKX<7C
MI=RD5Z1`IKBJNK5NI$JNR;:A(#\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3<V.0IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@P,@IM<V=I9"`B4VAO
M=R!P:6-K97(B"FUS9W-T<B`BQ>.EW,))O^^^N2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,S`*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M
M96YU(&)A<C\B"FUS9W-T<B`BQ>.EW*KMKN:^WJ=`I5ROX*KM(#\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4S"B,L('!H<"UF;W)M870*;7-G:60@
M(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@(JGSI:K#
MY,7CI=P@)7,@I5ROX*KM/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.0IM<V=I9"`B4VAO=R!T:&4@5&%B
M;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("+%XZ7<P'BF<Z[F
MI+JN9;GON-RDZ+;T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L92!0
M<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("+%XZ7<JNVNYJ2ZKF6Y[[C<I.BV
M]"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV,`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I
M97,@9&EA;&]G(@IM<V=S='(@(L7CI=RF0Z2ZKF6Y[[C<I.BV]"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M,@IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B"FUS
M9W-T<B`BQ>.EW+QVN;.DNJYEN>^XW*3HMO0B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3<V-PIM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T<B`BQ>.EW*17
MML<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M,`IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R("*K^<3RL'VK0B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"FUS9VED(")3:&]W
M97)S($5A<FQY(@IM<V=S='(@(J:MIK.P?:M"(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H;W=E<G,@3&%T
M92(*;7-G<W1R("*QWZ:SL'VK0B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I
M;FET>2(*;7-G<W1R("*[MZ3HIK.P?:M"(@H*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="YP:'`Z-#@P"FUS9VED(")3:')I;FLB"FUS9W-T<B`BIJS!62(*
M"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C<W-"!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+G!H<#HX,S8*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="YP:'`Z.3(R(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.CDX-`HC.B!L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HQ,#0W(&QI8B](;W)D92]";&]C
M:R],87EO=70N<&AP.C$P.#<*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP
M:'`Z,3$Q-B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HQ,30Y"FUS9VED
M(")3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F
M('1H92!W87D@9FER<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(Q,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE
M;VYE(@IM<V=S='(@(E-I97)R82!,96]N92`HM^"D;*1SL.HI(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-C8*;7-G:60@(E-I9VX@=7`B"FUS
M9W-T<B`BM?FE52(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S$S
M"FUS9VED(")3:6=N871U<F4B"FUS9W-T<B`BP[&SN2(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED(")3:6=N871U<F4@06QG;W)I
M=&AM(@IM<V=S='(@(L.QL[FZ=+KB(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(P-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E(@IM
M<V=S='(@(E-I;F=A<&]R92`HMW.E6ZE9*2(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HY,#`@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,3D@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$R-#$*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-3`@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(Y,3D@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,3(*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C4@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#0*;7-G:60@(E-I>F4B"FUS9W-T<B`BI&JD<"(*"B,Z('1E
M;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4R"FUS9VED
M(")3:VEP($UA:6YT96YA;F-E(@IM<V=S='(@(K*DN4RZ^\5`(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-0IM<V=I
M9"`B4VQO=F%K:6$B"FUS9W-T<B`B4VQO=F%K:6$@*+2UK*6E[Z=**2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#@@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(P-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*
M;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@(E-L;W9E;FEA("BTM:REI>^EIZC(
M*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4T
M"FUS9VED(")3;F]W(@IM<V=S='(@(K.W(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@(E-N;W<@4VAO=V5R(@IM
M<V=S='(@(K!]L[<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@(K!]L[<B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM
M<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S='(@(J:MIK.P?;.W(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G
M:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(K'?IK.P?;.W(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S@*;7-G:60@(E-N;W<@9&5P=&@Z("(*
M;7-G<W1R("*_;K.WLF"KUSH@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M.#(*;7-G:60@(E-N;W<@97%U:79A;&5N="!I;B!W871E<CH@(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(P-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#,*;7-G:60@(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R(")3;VQO;6]N
M($ES;&%N9',@**_!P[FJ^;ASKG$I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(Q-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V]M86QI82(*;7-G
M<W1R(")3;VUA;&EA("BOP;"HIU&HR"DB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`BNG&[4+C6
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,34*;7-G:60@(E-O<G0@;W)D
M97(@<V5L96-T:6]N(@IM<V=S='(@(K'&ID.DZ*96O^^^W"(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4X.0HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Q-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(T-PHC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,38V(&QI8B].970O
M4TU3+W=I;E]H='1P+G!H<#HQ.#D*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM
M<V=S='(@(JC3M[VF8:=](@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S
M='(@(E-O=71H($%F<FEC82`HJVZK1"DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X-@IM<V=I9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM
M<V=S='(@(JMNO-H@*$E33RTX.#4Y+3,I(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$P,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<W"FUS9VED(")3;W5T:"!'96]R
M9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R(")3
M;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z
M-C(*;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`BJVZE8K)Y
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,34*;7-G:60@(E-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R
M(&EN(&-E;&PB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Q
M.0IM<V=I9"`B4W!A8V5R(@IM<V=S='(@(JK%I=6FYB(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`IM<V=I9"`B
M4W!A8VEN9R(*;7-G<W1R("*VH;9:(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A
M;F0@<&%D9&EN9R(*;7-G<W1R("*VH;9:NU"YU*52(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C@P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E-P86EN
M(@IM<V=S='(@(E-P86EN("BFZ*]:I/HI(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$P,`IM<V=I9"`B4W!A;2(*;7-G<W1R("*I5:>CMFRE\R(*
M"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#
M:&%R86-T97(@26YP=70B"FUS9W-T<B`BKU.N[:9RI+B_Z:1*(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM
M<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R("*DP+/.P'BF<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*;7-G
M:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R("*DP+/.Q.:F["(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G
M:60@(E-P;&ET(')O=R(*;7-G<W1R("*DP+/.ID,B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-C$*;7-G:60@(E-P;W)T<R(*;7-G<W1R("*Y0K#*(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X
M"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T<B`B4W)I($QA;FMA("BTM:B]Q/6E
M9"DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C8@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HW-`IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`BO-"W
MQR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4
M<F5K(@IM<V=S='(@(JQ0N]JJI\51OM0B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C4Y,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y.`IM<V=I9"`B4W1A<G0@
M>65A<B(*;7-G<W1R("*QTJELIGZE]R(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3<Q"FUS9VED(")3=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R
M("*LV2(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R
M"FUS9VED(")3=&%T=7,B"FUS9W-T<B`BJJRZ02(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR.#`T"FUS9VED(")3=&]R86=E(&9O<FUA="(*;7-G<W1R("+`
M>*9SKN:FH2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<S"FUS
M9VED(")3=')E970@061D<F5S<R(*;7-G<W1R("*U\[E$(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R
M:6ME=&AR;W5G:"(*;7-G<W1R("*G4K"CO74B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3(S-PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`BIG*FZJ9#
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S<*;7-G:60@(E-T<FEP(&1O
M;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@(J;;MFRE\Z9AIWVDI*5H
ML*.Z]+#LIE>ZV2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@
M(KS+IJ$@6T-34UTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R("*L4+3!I-$B"@HC.B!U
M=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4W5B9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(J?DI*.H
M[*:XI=B__2!<(B5S7"(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C
M.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R("*E1*:N(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C,S-B!L:6(O2&]R9&4O1F]R;2]296YD97)E
M<BYP:'`Z,S$W"FUS9VED(")3=6)M:70B"FUS9W-T<B`BL&6E6"(*"B,Z('-I
M9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D
M(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N
M;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@:&%S(&)E96X@87!P
M<F]V960N(@IM<V=S='(@(KQ7I5L@7"(E<UPB(*CLJ'2RSJJZI=.]T*1WL&6E
M6"X@IT&ELK:WM:6H[+C3I=.]T+-1KM:MXZOAI'ZOX+5NI$HN(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B
M4W5B<V-R:7!T(@IM<V=S='(@(J15O-`B"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3`T(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S
M+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R("*FJ*5<(@H*(SH@861M
M:6XO=7-E<BYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY(&%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G<W1R("*FJ*5<
MJKJE6Z1*(%PB)7-<(B"H[*ATLLZDI"XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@
M9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R
M("*FJ*5<JKJFVZATLLZDI+)-L*.HSZ7.JLP@7"(E<UPB(*JZN.JNQBXB"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z
M-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@
M7"(E<UPB+B(*;7-G<W1R(")<(B5S7"*D=Z=2L*.GN::H+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("*F
MJ*5<JKJFVZATLLZDI+*^L*,@7"(E<UPB+B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF
M:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(J1W
MIJBE7*JZIEZT7[-=J7<N(+W0K:NW<[C\I$K`R[7XKG2RIRXB"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`BI'>FJ*5<JKJSQJ7WLUVI=[CJKL8N(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I
M;&4@)7,N(@IM<V=S='(@(J1WIJBE7*JZL\:E][-=J7>XZJ[&("5S+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C
M97-S9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`BIJBE7*JZI_.W<R!<
M(B5S7"(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S
M9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`BI'>FJ*5<JKK"T+QG("5S(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM
M<V=I9"`B4W5D86XB"FUS9W-T<B`B4W5D86X@*,2LI*8I(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@IM<V=I
M9"`B4W5M;6%R>2(*;7-G<W1R("*Z2ZUN(@H*(SH@;&EB+T)L;V-K+W-U;G)I
M<V4N<&AP.C8U"FUS9VED(")3=6X@4FES92(*;7-G<W1R("*DZ:58(@H*(SH@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S
M='(@(J3IN*@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU.0IM<V=I9"`B4W5N;GDB"FUS9W-T<B`BM+@B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`U"FUS9VED(")3=6YR:7-E(@IM<V=S
M='(@(J3II5@B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO
M8VLO<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S
M='(@(J3II5@OI.FXJ"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,#0*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R("*DZ:58.B`B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`X"FUS9VED(")3=6YS970B
M"FUS9W-T<B`BI.FXJ"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,#<*;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@(J3IN*@Z("(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@
M(E-U<&5R<V-R:7!T(@IM<V=S='(@(J17O-`B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S@P"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(J3DM*DB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$U(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`V"FUS9VED(")3=7)I;F%M92(*;7-G<W1R(")3=7)I;F%M92`HQ*RG4:MN
M*2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<U"FUS9VED(")3
M=7)N86UE(@IM<V=S='(@(KKON+DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C`Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@
M2F%N($UA>65N(@IM<V=S='(@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$Y(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X
M"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`B4W=A>FEL86YD("BE=J7+P-G$
M]2DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`U(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS9W-T<B`B4W=E9&5N("BWYZCE*2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V
M"FUS9VED(")3=VET>F5R;&%N9"(*;7-G<W1R(")3=VET>F5R;&%N9"`HM^>D
M:"DB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@IM<V=I9"`B
M4WEN8R!L;V<@9&5L971E9"(*;7-G<W1R("*F4*A"L$^__:1WIU*PHR(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#4*;7-G:60@(E-Y;F--3"(*;7-G
M<W1R("*F4*A"IN:PRKC+N&TB"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S
M+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*
M;7-G<W1R("*W:K1-MK6EV*2DJKJ[>:IKO_F[?B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q
M-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-Y<FEA
M;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC
M("BQU*=1J,@I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C`*;7-G:60@(E0M4W1O<FTB"FUS9W-T<B`BN7"K0B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Q"FUS9VED(")4
M+5-T;W)M(&%N9"!7:6YD>2(*;7-G<W1R("*Y<*M"IK.MMR(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS9VED(")4+5-T
M;W)M<R(*;7-G<W1R("*Y<*M"(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C,*;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM<V=S
M='(@(J:MIK.K^<3RN7"K0B(*"B,Z(&QI8B](;W)D92]$871A+W1S=BYP:'`Z
M,38V"FUS9VED(")44U8@9FEL92(*;7-G<W1R(")404(@I,"Y:J[FIJ'`R:[7
M(@H*(SH@;&EB+TAO<F1E+U5)+U1A8FQE+G!H<#HQ,S0*;7-G:60@(E1A8FQE
M(@IM<V=S='(@(JKML^8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<S"FUS9VED(")486)L92!0<F]P97)T:65S
M(@IM<V=S='(@(JKMKN:DNJYE(@H*(SH@;&EB+TAO<F1E+T9O<FTO5'EP92]T
M86)L97-E="YP:'`Z-3<*(RP@9G5Z>GD*;7-G:60@(E1A8FQE(%-E="(*;7-G
M<W1R("*J[;/F(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G
M<W1R("*J[:[FI+JN92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S0@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")486EW86XB"FUS
M9W-T<B`BI7C&5R(*"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`B
MI7C&5R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C4@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B5&%J:6MI<W1A
M;B`HMO"F3K2UJ5HI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!297!U
M8FQI8R!O9B(*;7-G<W1R(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F
M("BI6JE\I:>HR"DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDU"FUS9VED(")487)G970Z(@IM<V=S='(@(J78O-`Z(@H*
M(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDY-B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3@Y"FUS9VED(")487-K<R(*;7-G<W1R("*KW;_LJ,:VM2(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<T"FUS9VED(")496QE
M<&AO;F4@3G5M8F5R(@IM<V=S='(@(KEQN-RXN;U8(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR.3`*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM
M<V=S='(@(K/,JO&D0*1PKLFJNK?%J]<Z("(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C$T"FUS9VED(")496UP97)A='5R92(*;7-G<W1R("*WQ:O7(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,@IM<V=I9"`B5&5M
M<&5R871U<F4Z("(*;7-G<W1R("*WQ:O7.B`B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C@R"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E
M<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B
MM\6KUSQB<B`O/B@E<["J)7,O)7.G0R5S*2`F9&5G.R5S(@H*(SH@;&EB+TAO
M<F1E+U1E;7!L871E+G!H<#HV.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M
M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`BI^2DHZCLO,NJ3R!<
M(B5S7"(N(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@(E1E
M;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(KS+JD^ZWK)Z(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$R,34@;&EB+TAO<F1E+T9O<FTN<&AP.C,S
M,C4*;7-G:60@(E1E>'0B"FUS9W-T<B`BI+JN92(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-SD*;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R("*OPJ3E
MIG(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<T"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@(KGON_2DY:9R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M,0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R("*Y[[OTI.6F<K.[NMTB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED
M(")4:"(*;7-G<W1R("*L4+3!I7PB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X-PIM<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`BKO6DY2`H5$E3
M+38R,"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(T(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,C$*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`Y"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R(")4:&%I;&%N9"`H
MKO6PZBDB"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#0P"FUS9VED(")4:&4@1E10
M(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")&5%`@J;6F
M^2AE>'1E;G-I;VXIM4RNQ"XB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDS
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R
M871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@
M(DAO<F1E+TMO;&%B(+[CIEBD=;5[J,.EO*3DM*D@7"(E<UPB(@H*(SH@;&EB
M+TYE="])35-0+T)O;VLN<&AP.C$R.3@*;7-G:60@(E1H92!)35-0(&QO9R!C
M;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(DE-4U`@K/:__;5,
MJFNS4:KLJ6PN(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS
M9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C
M8V5S<V9U;&QY(@IM<V=S='(@(DUA:6YT96YA;F-E(,/^IT^HPZ6\IJBE7+C\
MI$HB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS
M9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB
M"FUS9W-T<B`BO^^VM;7XM:&E2,/VLZPNPO>V?:2D+B(*"B,Z(&QI8B](;W)D
M92]097)M<RYP:'`Z,3@Y(&QI8B](;W)D92]097)M<RYP:'`Z,C`P(&QI8B](
M;W)D92]097)M<RYP:'`Z,C$Q"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,C(S
M(&QI8B](;W)D92]097)M<RYP:'`Z,C,T(&QI8B](;W)D92]097)M<RYP:'`Z
M,C4R"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,C8T(&QI8B](;W)D92]097)M
M<RYP:'`Z,S`S"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T
M;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I
M9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(J=!
MJKJH=++.NMZR>JW[I;*VMZ7]LUVI=Z9NI$"MT\5VK:VKX;K=I'ZOX,7]IT&H
MSZ7.Q7:MK:ATLLXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N
M;'DB"FUS9W-T<B`BJ;.NV+UU(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R
M('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U
M;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R("+!<+6XN+F]6*6\J_RI
M=RRJQ:75J<ZF8KCJKL:N=Z2DI^2DHZCL+B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z-3$*;7-G:60@(E1H92!C;VYT86-T('=A<R!S
M=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S
M='(@(J1WIJBE7*JZL4[!<+6XI$BW<[Q7IMRS<;!4O_VDI"XB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,3<R"FUS9VED("(B"B)4:&4@9&5T86-H
M960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@
M=&AE('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("+%Y\/2MFRE\\.QL[F[W:UN
MIK.D0*W3I'>XT;9]JKH@4$=0(+#/MO0N(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO
M;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N
M:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R("*P
M=+AMN'.RU:JZP]&G3[BYO5@H240II*.L3Z6\J_RI=RRT3JQ/JL6EU:G.JLRD
MHZ9BN.JNQJYWI*0N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@
M<W!E8VEF:65D+B(*;7-G<W1R("*P=+AMN'.RU:6\J_RI=RXB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0N<&AP.C$Q-@IM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A
M='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T
M<B`BN]VM;J1`K=.X9[E,I5NQ2ZJZNO2X]+-SM;(N(@H*(SH@;&EB+TAO<F1E
M+G!H<#HQ-S<@;&EB+TAO<F1E+G!H<#HU,3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*
M;7-G<W1R("+`R:[7("5S(,"SN-.E7:=TI$"MTR`E<R"S7:EW+B(*"B,Z(&QI
M8B](;W)D92YP:'`Z,3<P(&QI8B](;W)D92YP:'`Z-3`Y"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@
M<V5T=&EN9W,N(@IM<V=S='(@(L#)KM<@)7,@P+.XTZ5=IW2D0*C'("5S(+-=
MJ7<N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR,C,*;7-G:60@(E1H92!F:6QE
M(&-A;FYO="!B92!C;W!I960@;VYT;R!I='-E;&8N(@IM<V=S='(@(K5,JFN]
MQKMSJ.RFVZBMP,FNURXB"@HC.B!L:6(O2&]R9&4O1&%T82YP:'`Z,C@P"FUS
M9VED(")4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`BIKG`
MR:[7I*2H4Z:SN.JNQBXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C
M.#(R+G!H<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E
M<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B
MI4BD5:Q/(')F8S@R,B"V;*7SJKJJ[<!9+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL
M('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@
M26YT97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA
M="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E
M>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@
M9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@
M(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY
M('1H870@>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U
M;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A
M<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T
M;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<')E9G,N<&AP.CDR"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B
MJ*VE]\/1IT\@)7,@I'>S4:=2L*,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M
M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`BI:JNV+UU(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@
M=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P
M9W`Z.B!C;&%S<RXB"FUS9W-T<B`B1VYU4$<@I$>DN,#)JKJX]*Y\I;*VMZEW
MN'&F8B!#<GEP=%]P9W`Z.B##_J=/I*0N(@H*(SH@;&EB+TAO<F1E+TU)344O
M341.+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A
M9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B
M965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@
M=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G
M<W1R("(B"B*G0;2_J?,@)7,@L4BUN2`E<R"D0*O*I42FKJRP(%PB)7-<(B"J
MNJM(I?.D=[-1MGVQTBY<;B(*(J;]LV^HPZ2CK^"K3\/2N-.K2*7SJKJDNJYE
MI'>GN:7^LU&FK*7SI$BLW:>YJ<ZD1KC1+B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ.#@Q"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG
M('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`BLW.ULJCLO7.\9[9LI?.M
MMJVQJ=*HSZ7.JKJF5[K9(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HT-S0*;7-G
M:60@(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS
M9W-T<B`BI;*VMZQ/I$"MT[S&IG(N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HQ,C,R"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q
M=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G
M<W1R(")(;W)D95]#<GEP=%]S;6EM93HZ(,/^IT\LI;*[W:UNIK,@;W!E;G-S
M;""\TK+5+B(*"B,Z(&QI8B](;W)D92]0<F5F<RYP:'`Z,C@S"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N
M;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@(@HB
M;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("*FN;"^IFX@7"(E<UPB
M(+CJKL:F7:RPME>Y3+/,I&JDN;-<K<@LJ=*E2+5,JFNS4<!XIG,B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O9&5B+G!H<#HS,B!L:6(O2&]R9&4O34E-
M12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]M<W=O<F0N<&AP.C,R(&QI8B](;W)D92]-24U%+U9I97=E<B]R<&TN
M<&AP.C,R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]W96)C<'`N<&AP.C,W
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T
M:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E
M;2XB"FUS9W-T<B`BI<ZE2,#+M?BFN;CJKL;#_JNL("@E<RD@JKJU>Z:AJ,.D
MHZ9SIF*I\ZATLLZD5RXB"@HC.B!L:6(O1FEL92]#4U8N<&AP.C0X-PIM<V=I
M9"`B5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA
M<F%C=&5R+B(*;7-G<W1R("*DWJUZIG*ELK:WK+"SYJ1`IG*DN"XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W
M"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R
M("*EJJ5KKMB]=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H="UH86YD('-I9&4@
M;VYL>2(*;7-G<W1R("*E:Z[8O74B"@HC.B!L:6(O1FEL92]#4U8N<&AP.C0W
M.0IM<V=I9"`B5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA
M<F%C=&5R+B(*;7-G<W1R("+$YJ;LI,"Y:J9RI;*VMZRPL^:D0*9RI+@N(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB
M"FUS9W-T<B`BIKFF^*I!OKD@7"(E<UPB(*1WLU&G4K"C+B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R("*F
MN:;XJD&^N2!<(B5S7"(@I'>S4<!XIG,N(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F
M;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B)7,@JKJU^:55N]VH
M1*1WLU&ROK"C+B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C,S
M,`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N(@IM
M<V=S='(@(JO\J7>JNK!/O_VHPZ2CIG.F8BXB"@HC.B!L:6(O5D93+W-Q;"YP
M:'`Z,3<Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T96UP;W)A<GD@9FEL
M92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(KS(IG/`R:[77"(E
M<UPBI*.F<Z9B+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,S`P"FUS9VED
M(")4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT
M(&]N('1H92!S8W)E96XN(@IM<V=S='(@(J=!J=*_Z:1*JKJXZJ[&NU"U9:VQ
MN.JNQJ2CLL4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I
M9&5S(&]N;'DB"FUS9W-T<B`BI%>D5:[8O74B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@
M=&]P('-I9&4@;VYL>2(*;7-G<W1R("*D5Z[8O74B"@HC.B!L:6(O2&]R9&4O
M1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@;&]S
M="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`BL7&D5Z1`K=.H
M0L9*I*>KX:17ML>JNKCJKL:_\J6B+B(*"B,Z(&QI8B](;W)D92]$871A+V-S
M=BYP:'`Z,C8R(&QI8B](;W)D92]$871A+W1S=BYP:'`Z,3<R"FUS9VED(")4
M:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@
M(J17ML?`R:[7J,.EO+-1P'BF<RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-#D@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q,`IM
M<V=I9"`B5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(G=E871H97(N8V]M(+#/MO2U3*IKJ,^ESBXB"@HC.B!U=&EL
M+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("*GY*2C
MJ.R\RZ:AL'2X;:78O_T@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]5
M22YP:'`Z,3<X"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B
M;&4N(@IM<V=S='(@(K5,I6FESJJZO^^VM2XB"@HC.B!L:6(O2&]R9&4O34E-
M12]#;VYT96YT<RYP:'`Z,S0Y"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@
M=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`BM4RJ_J7S
MI6FJO;&UMGVQTBXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30P-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C
M=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A
M8W1E<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T
M<B`BIKG$YJ;LI*2E7:=TI-.F:*JZIG*\QBZG0:1WO^FD2B`E<R"MTZ9RO,8[
MIT&_Z:1*JKJF<KS&I;*VMZ1PJ?,@)7,N(@H*(SH@<VEG;G5P+G!H<#HU,R!A
M9&UI;B]U<V5R+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B
M"FUS9W-T<B`BMW.\5R!<(B5S7"(@J.RH=++..B`E<R"NR;5OI<VD0*W3L-W#
M1"XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R
M(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("*FVZATLLZR3;"C
M(%PB)7-<(B"JNKCJKL:NR;5OI<VD0*W3L-W#1#HB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O
M8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T
M<B`BIMNH=++.LKZPHR!<(B5S7"(@KLFU;Z7-I$"MT[#=PT0Z(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,34Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A('!R;V)L96T@=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R("*G\[=S
M(%PB)7-<(CH@)7,@KLFU;Z7-I$"MT[#=PT0B"@HC.B!L:6(O2&]R9&4O0G)O
M=W-E<BYP:'`Z.3$P"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO
M861E9"XB"FUS9W-T<B`BI%>VQ\#)KM>NR;5OI<VD0*W3L-W#1#H@)7,@I;RS
M4:17ML<N(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDQ-0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE
M(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI
M;75M("(*(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("*D5[;'
MP,FNUZ[)M6^ES:1`K=.PW<-$.B`E<R"D:J1PME>Y3*2YLURSS*1JK<@@*"5D
M(&)Y=&5S*2XB"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3$W"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T
M:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L
M;V%D960N(@IM<V=S='(@(J17ML?`R:[7KLFU;Z7-I$"MT[#=PT0Z(+;(LZ&D
MP*JZ("5S(,#)KM>S4:17ML<N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P
M;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(L#+M?BV;*7SKLFU
M;Z7-I$"MT[_YNWXN(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HS.2!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T
M(&1A=&$N(@IM<V=S='(@(K;7I$JFN;-QL%2__;CJKL:NR;5OI<V_^;M^+B(*
M"B,Z(&QI8B](;W)D92]$871A+VEM8RYP:'`Z,S$*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G
M<W1R("*VUZ1*(&E#86QE;F1A<B"XZJ[&KLFU;Z7-I$"MT[_YNWXN(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HX,`IM<V=I9"`B(@HB5&AE<F4@=V%S
M(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@
M>6]U(&QE9G0@;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(J9B
MLUVI=ZKML^:DI+5OI<VD1J1`K=._^;M^+J:SI6FOX*=!O_*Z?*1&I;*VM[;Q
MO&>JNL3FINPN(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S.`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@
M=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B
M"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(K#UIN:S<;!4O_VK_*EWI5RO
MX*[)M6^ES:1`K=._^;M^+B"]T+5YJ^&F0;C5I$"FN"XB"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0P"FUS9VED("(B"B)4:&5R92!W
M87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE
M87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`BI_.W<\%PM;BD2+CJKL:N
MR;5OI<VD1J1`K=._^;M^+B"]T+5YJ^&F0;C5+B(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4@;&EB+TYE="]335,O=VEN7VAT='`N
M<&AP.C(R,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG
M('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E
M<BXB"FUS9W-T<B`BI_.W<[!TN&VX<[+5KLFU;Z7-I$:D0*W3O_F[?BX@O="U
M>:OAID&XU2XB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,30X"FUS9VED(")4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@
M<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R("*FN2!)34%0(*;XJD&^N:C#I;RD
MY+2IJTBE\Z=8I,"HR:5<K^`N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E
M(&$@=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(K-OIORE1Z2CK$^EO[U4
MJKH@<F%R(,"CP5G`R:[7+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z
M:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A
M('9A;&ED('II<"!F:6QE+B(*;7-G<W1R("*S;Z;\I4>DHZQ/I;^]5*JZ('II
M<"#`H\%9P,FNURXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$S-`IM<V=I
M9"`B5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB
M97(N(@IM<V=S='(@(K-OIORE1Z2CK$^EO[U4JKJK2*7.I62XN;U8+B(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U"FUS9VED("(B
M"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O
M=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI
M(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!L
M:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED("(B"B)4:&ES(&1R
M:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!7
M24X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y+"!U<VEN9R!T:&4@
M2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E
M;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P
M.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@
M05!)(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?
M<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE
M($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@
M270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE
M($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HY.#(@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-C$@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$P.3`*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$Q,3D@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q.#8@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$R-C`*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S,#D@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$T,#(@;&EB+TAO<F1E+T9O<FTN<&AP.C$U-C$*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$X-#,@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-C(@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(P,#D*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(P,S,@;&EB+TAO<F1E+T9O<FTN<&AP.C(P.#(@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(Q-3,*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R,C4@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(T,3(@;&EB+TAO<F1E+T9O<FTN<&AP.C(T-30*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(V-#0@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,3<@
M;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,C8*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C,R.34@;&EB+TAO<F1E+T9O<FTN<&AP.C,X,#,@;&EB+TAO<F1E+T9O<FTN
M<&AP.C,X,3$*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S
M='(@(J:YQ.:F[*Q/I;*[W:UNJKHN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$P-CD*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E
M9V5R<RXB"FUS9W-T<B`BIKG$YJ;LI+JN9:5UI+FS7+[CO,:\QJ9R+B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR-#(P"FUS9VED(")4:&ES(&9I96QD(&UA
M>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R
M("*FN<3FINRDNJYEI76DN;-<O,:F<J3.JU^XN2XB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3`Y.`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT
M86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`BIKG$YJ;LI+JN9:5UI+FS7*1+
MMFFF[+S&K<@N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,C<*;7-G:60@
M(E1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E
M9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S='(@(J:YQ.:F[*2ZKF6ELK:WK+"S
M<KBYJ<ZJQ:75I,"Y:JJZO,:F<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY
M.3,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB
M"FUS9W-T<B`BI;*VMZQ/I$"MT[S&IG(N(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(X,C4*;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@
M8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE
M("(*(B<C,3(S-&%F)RXB"FUS9W-T<B`BIKG$YJ;LI+JN9:6RMK>E7:=TI$"R
MU:11I+NV::;LJKH@4D="(,-#IN*E3KU8+*C2IG`@)R,Q,C,T868G+B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HU-C4*;7-G:60@(E1H:7,@9F]R;2!H87,@
M86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`BLV^MTZKML^:D=[-1
MLT*R>KE,+B(*"B,Z('1E;7!L871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@(K-OK$\@)7,N
M(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT-3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O
M('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C
M;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O
M<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE
M87-E('9I<VET("5S(@IM<V=S='(@(B(*(K-OK$\@2V]L86(@N'.RU:JZI$"M
MTZJKI?,N(+']P,NU^*:YJJNE\[O=K6ZOX*3DM*E+;VQA8B"X<[+5KN:FH:JZ
MN7&D;+9LI?.S;B(*(L7I+KW0L-&FTB`E<R"E2*1&N-&S;ZC'MFRE\[-NQ>DB
M"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z-3DX"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H
M87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R
M("*S;ZO*MFRE\ZC#JT2E2*=!ND2ESJJZIG*DN+:PIM.L3ZC/I<X@*"5S*2"N
MT;QGIM.FJ"XB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$R-@IM<V=I
M9"`B5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@
M(J:YO,:MR+/,I-:ELK:WK$\@,2XB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O
M9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E
M<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R("*FN:;XJD&^N;5,JFNY
M[R!Z:7`@I,X@9WII<""NYJ:AP,FNU[9IIN:XT<"CP5DB"@HC.B!L:6(O2&]R
M9&4O4F5G:7-T<GDN<&AP.C$X,@IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R
M<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R("*FN:ATLLZEV*MEK$^PL:7.
MJKJJK+I!+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3(T"FUS9VED
M(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(J6RMK>L
M3Z1`K=.\QJ9R+B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP
M:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@
M86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`BIKFU^+6AI;*VMZUNI=&_[[:U
MM?BUH2A/<'1I;VXIJ=*I2:5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C0*;7-G:60@(E1H=6YD97(B"FUS9W-T<B`BN7`B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,V"FUS9VED(")4:6-K
M971S(@IM<V=S='(@(K#=PT2P;,+<(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(T,CD@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")4
M:6UE(@IM<V=S='(@(J[)MJ$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S@X"FUS9VED(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(J[)MJ&K_*MN
M(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W"FUS9VED(")4:6UE(&9O<FUA
M="(*;7-G<W1R("*NR;:AKN:FH2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M-3,U"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R("*NR;#/O^^^W"(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(R,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@(E1I;6]R+4QE<W1E(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@;&EB+T)L
M;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@(KS0PT0B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDV
M"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@(KS0PT0@*'1O;VQT
M:7`I.B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U
M"FUS9VED(")4;R(*;7-G<W1R("*FK*7SI$@B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C4Q"FUS9VED("(B"B)4;R!S96QE8W0@
M;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R
M($-O;6UA;F0@*$UA8RD@:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R
M("(B"B*F<*I'K6Z]QK_O++W0IF+"2;_OM\:YJZJZIE"NR:OV($-O;G1R;VS!
MY"BMTZ1(N7&XHRD@J<X@0V]M;6%N9,'D*,2KJD>Y<;BC*2XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P"FUS9VED(")4;V1A>2(*;7-G
M<W1R("*DM:31(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@
M(DA434P@K>RI;,#)(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&]G;R(*;7-G<W1R(")4;V=O("BF
M:*WT*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C8@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,3`*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B5&]K96QA=2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#(*;7-G:60@(E1O;6]R
M<F]W(@IM<V=S='(@(JGZI-$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C(Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G<W1R(")4
M;VYG82`HJD:E6RDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S<*;7-G:60@(E1O<"(*;7-G<W1R("*SN[.A(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM
M<V=I9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R("*SS*17O&BNV*Q;("A?
M=&]P*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PHC+"!F=7IZ>0IM
M<V=I9"`B5')A;G-L871I;VYS(@IM<V=S='(@(L7<I,8B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C,R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4
M<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S='(@(J1DJ+VY1J3.IJNHJ:WT(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W.30*;7-G:60@(E1R=64@;W(@9F%L
M<V4B"FUS9W-T<B`BKW6ISK"P(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T<B`BK%"TP:1'
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q,`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R(")4=6YI<VEA("BL\*6GINBH
MR"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,Q(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,C@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T<B`B5'5R:V5Y("BD9Z;5J.0I
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(E1U<FMI<V@@
M*$E33RTX.#4Y+3DI(@IM<V=S='(@(J1GIM6HY*3E("A)4T\M.#@U.2TY*2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(R.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3`*;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R(")4=7)K;65N:7-T86XB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(P(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,S`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`X"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B
M5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(S,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5V86QU(@IM
M<V=S='(@(E1U=F%L=2`HI&>ER[Y\*2(*"B,Z(&QI8B](;W)D92]#3$DN<&AP
M.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S='(@(K_II$JG
M0:JZO^^^W#H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U
M.`IM<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@(K6UI7Z]=:O\O,8Z("(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]"
M;&]C:R]I9G)A;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T<B`BNO2G?2(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@
M(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.CDW"FUS9VED(")54DPZ(@IM<V=S='(@(KKTIWTZ(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(S-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,@IM<V=I
M9"`B56=A;F1A(@IM<V=S='(@(E5G86YD82`HKU&D>KE&*2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(S,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@
M(E5K<F%I;F4B"FUS9W-T<B`B56MR86EN92`HKU&G2L3U*2(*"B,Z(&QI8B]6
M1E,O9FEL92YP:'`Z-#$V"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D
M:7)E8W1O<GDN(@IM<V=S='(@(K5,JFNF<ZCZ(%9&4R"EV+_]+B(*"B,Z(&QI
M8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A
M9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM
M<V=S='(@(K7YI56NR;5,JFN\5Z5;PT*E?JJZJ,^ESJK,N.JP5"XB"@HC.B!L
M:6(O5D93+V9T<"YP:'`Z,SDS"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*
M;7-G<W1R("*U3*IKI^_%W"!61E,@P,FNUR!<(B5S7"(@JKK%=JVM+B(*"B,Z
M(&QI8B]61E,O9FEL92YP:'`Z,S@Y(&QI8B]61E,O;75S<6PN<&AP.C0V.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I
M;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("*U3*IKQ=RG\R!61E,@
MP,FNUR`E<R\E<R"JNL5VK:TN(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<W-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*
M;7-G<W1R("*U3*IKQ=RG\ZRP("5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HR
M,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@
M<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(K5,JFO`RZQDP,FNUZ1JI'`@7"(E
M<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-CDR(&QI8B]61E,O<W%L+G!H
M<#HQ,#$Y(&QI8B]61E,O<W%L7V9I;&4N<&AP.C@T,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<
M(BXB"FUS9W-T<B`BM4RJ:\#+K&3`R:[7I&JD<"!<(B5S+R5S7"(N(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O<W%L+G!H<#HT,SD*;7-G:60@(E5N86)L92!T;R!C
M;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(K5,JFNS<[6R(%-13""F
M^*I!OKDN(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@U.0IM<V=I9"`B56YA8FQE
M('1O(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S='(@(K5,JFNHSZ7.(%-33""S
M<[6R+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C(Y(&QI8B]61E,O9FEL92YP
M:'`Z,C,T(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(P-`HC.B!L:6(O5D93+W-Q
M;%]F:6QE+G!H<#HR,#D@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C$W"FUS9VED
M(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`BM4RJ:[W&NW,@
M5D93(,#)KM<N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,W,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E
M<UPB+B(*;7-G<W1R("*U3*IKJ]BEWR!61E,@I=B__2!<(B5S7"(N(@H*(SH@
M;&EB+U9&4R]F:6QE+G!H<#HS-3@@;&EB+U9&4R]M=7-Q;"YP:'`Z,C4X(&QI
M8B]61E,O<W%L7V9I;&4N<&AP.C(V-`IM<V=I9"`B56YA8FQE('1O(&-R96%T
M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("*U3*IKJ]BEWR!61E,@I=B__2XB
M"@HC.B!L:6(O5D93+VUU<W%L+G!H<#HQ,C0*;7-G:60@(E5N86)L92!T;R!C
M<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(K5,JFNKV*7?(%9&4R#`R:[7+B(*
M"B,Z(&QI8B]61E,O<VUB+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B
MM4RJ:ZO8I=\@5D93(*78O_T@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP
M:'`Z,C8Y"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE
M+B(*;7-G<W1R("*U3*IKJ]BEWZK%I=6JNB!61E,@P,FNURXB"@HC.B!L:6(O
M2&]R9&4O0V]M<')E<W,O=&%R+G!H<#HW-B!L:6(O2&]R9&4O0V]M<')E<W,O
M9WII<"YP:'`Z-SD*;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N
M(@IM<V=S='(@(K5,JFNQ3KCJKL:XT<"CP5DN(@H*(SH@;&EB+U9&4R]S;6(N
M<&AP.C(R."!L:6(O5D93+V9T<"YP:'`Z,S`S"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y(&ES
M(&YO="!E;7!T>2XB"FUS9W-T<B`BM4RJ:Z=2L*,@7"(E<UPB+*:YI=B__:C#
MJT2JQ:75+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S@@861M:6XO<&5R;7,O
M9&5L971E+G!H<#HT-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%PB)7-<(CH@)7,N(@IM<V=S='(@(K5,JFNG4K"C(%PB)7-<(CH@
M)7,B"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,S-2!L:6(O5D93+W-Q;"YP:'`Z
M,SDU(&QI8B]61E,O;75S<6PN<&AP.C,Q,0HC.B!L:6(O5D93+W-Q;%]F:6QE
M+G!H<#HS-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`BM4RJ
M:Z=2L*,@)7,LIKFEV+_]J,.K1*K%I=4B"@HC.B!L:6(O5D93+W-Q;%]F:6QE
M+G!H<#HS-38@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S8P"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S
M='(@(K5,JFN[O+!JIU*PHZ78O_TN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS
M-#$@;&EB+U9&4R]M=7-Q;"YP:'`Z,S(R(&QI8B]61E,O;75S<6PN<&AP.C,S
M-0HC.B!L:6(O5D93+VUU<W%L+G!H<#HS-#,@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z,S4R"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN
M(@IM<V=S='(@(K5,JFNG4K"C(%9&4R"EV+_]+B(*"B,Z(&QI8B]61E,O<W%L
M+G!H<#HT,C`@;&EB+U9&4R]S<6PN<&AP.C0S,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G
M<W1R("*U3*IKIU*PHR!61E,@I=B__3H@)7,N(@H*(SH@;&EB+U9&4R]F='`N
M<&AP.C(Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BM4RJ:Z=2L*,@5D93(,#)KM<@
M7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S`W(&QI8B]61E,O<W%L
M+G!H<#HR.3$@;&EB+U9&4R]M=7-Q;"YP:'`Z,38W"B,Z(&QI8B]61E,O;75S
M<6PN<&AP.C$X,"!L:6(O5D93+VUU<W%L+G!H<#HQ.#<@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z,SDQ"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,Y.0IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS9W-T<B`BM4RJ:Z=2
ML*,@5D93(,#)KM<N(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C(T.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@7"(E
M<UPB+B(*;7-G<W1R("*U3*IKIU*PHR!61E,@I=B__2!<(B5S7"(N(@H*(SH@
M;&EB+U9&4R]S<6PN<&AP.C0P.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(K5,
MJFN[O+!JIU*PHR!61E,Z("5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX,C,*
M;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN
M(@IM<V=S='(@(K5,JFNG4,)?I=BK9:JZI=B__2XB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C8P-`IM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@
M8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R("*U3*IKN-&V?;[,P]*RT[A@
M(@H*(SH@;&EB+TYE="])35-0+G!H<#HT,S<@;&EB+TYE="])35-0+T%U=&@N
M<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T
M:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`BM4RJ:[C\I$HE<ZJZJ7>X
M<2XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(P,"!L:6(O5D93+V9I;&4N<&AP
M.C(P-2!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-S0*(SH@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z,3<Y"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB
M"FUS9W-T<B`BM4RJ:[=HLKX@5D93(,#)KM<N(@H*(SH@;&EB+U9&4R]S;6(N
M<&AP.CDS(&QI8B]61E,O<VUB+G!H<#HQ,#8@;&EB+U9&4R]S;6(N<&AP.C8U
M,@HC.B!L:6(O5D93+V9T<"YP:'`Z.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("*U3*IK
MMGVQTB!61E,@P,FNUR!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR
M.#$@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3,X(&QI8B]61E,O<W%L7V9I;&4N
M<&AP.C$T,0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R
M:71I;F<N(@IM<V=S='(@(K5,JFN\9Z1*(%9&4R#`R:[7+B(*"B,Z(&QI8B]6
M1E,O9FEL92YP:'`Z.#,@;&EB+U9&4R]F:6QE+G!H<#HQ,S0@;&EB+U9&4R]S
M<6Q?9FEL92YP:'`Z-S8*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M+B(*;7-G<W1R("*U3*IKMGVQTB!61E,@P,FNURXB"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=&=Z+G!H<#HT-0IM<V=I9"`B56YA8FQE('1O(&]P96X@
M8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R("*U3*IKMGVQTL"CP5G`R2XB
M"@HC.B!L:6(O5D93+G!H<#HX-34*;7-G:60@(E5N86)L92!T;R!R96%D(%9&
M4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(K5,JFO%JJCZ
M(%9&4R#`R:[7("AF:6QE<VEZ92@I(&9A:6QE9"DN(@H*(SH@;&EB+U9&4RYP
M:'`Z.#@V"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL
M95-I>F4H*2!F86EL960I+B(*;7-G<W1R("*U3*IKQ:JH^B!61E,@P,FNUR`H
M9V5T1FEL95-I>F4H*2!F86EL960I+B(*"B,Z(&QI8B](;W)D92]397-S:6]N
M2&%N9&QE<B]N;VYE+G!H<#HS.`IM<V=I9"`B56YA8FQE('1O(')E860@9FEL
M93H@(@IM<V=S='(@(K5,JFO%JJCZP,FNUSH@(@H*(SH@;&EB+U9&4R]F:6QE
M+G!H<#HV-S,*;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I
M<F5C=&]R>2XB"FUS9W-T<B`BM4RJ:\6JJ/H@=F9S<F]O=""EV+_]+B(*"B,Z
M(&QI8B](;W)D92]+;VQA8BYP:'`Z,3$P-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD
M97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`BM4RJ:Z?SIE<@)7,@K+`@)7,Z
M(*9=K+"EV+S0JTBE\Z=8I'>F<Z9B(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z,S`Q"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN
M(@IM<V=S='(@(K5,JFO%W*?S(%9&4R"EV+_]JKJF5[K9+B(*"B,Z(&QI8B]6
M1E,O<W%L+G!H<#HS,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`BM4RJ:[*^L*,@
M5D93(*78O_TZ("5S+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HR-S$@;&EB+U9&
M4R]F='`N<&AP.C,T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BM4RJ:\7<I_,@5D93
M(,#)KM<@7"(E<UPB(*JZIE>ZV2XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C8Q
M-"!L:6(O5D93+VUU<W%L+G!H<#HR,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`BM4RJ
M:\7<I_,@5D93(,#)KM<@)7,O)7,@JKJF5[K9+B(*"B,Z(&QI8B]61E,O<W%L
M+G!H<#HS,C8@;&EB+U9&4R]M=7-Q;"YP:'`Z,C$S(&QI8B]61E,O;75S<6PN
M<&AP.C0U,@HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR.3,@;&EB+U9&4R]S
M<6Q?9FEL92YP:'`Z,S`Y"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE+B(*;7-G<W1R("*U3*IKQ=RG\R!61E,@P,FNUZJZIE>ZV2XB"@HC.B!L
M:6(O5D93+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE
M('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@(K5,JFNP]:;F("=M:VES;V9S
M)RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0IM
M<V=I9"`B56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B
M"FUS9W-T<B`BM4RJ:\+@M*L@5V]R9""DY:7S(@H*(SH@;&EB+U9&4R]F='`N
M<&AP.C$U-"!L:6(O5D93+V9T<"YP:'`Z,34W"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(K5,JFN\9Z1*(%9&4R!<(B5S7"(@P,FNURXB"@HC.B!L:6(O5D93+V9I;&4N
M<&AP.C$X,PIM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y
M*"D@9F%I;&5D*2XB"FUS9W-T<B`BM4RJ:[QGI$H@5D93(,#)KM<@*&-O<'DH
M*2!F86EL960I+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C@U(&QI8B]61E,O
M<W%L7V9I;&4N<&AP.C$T-B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-3$*;7-G
M:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+B(*;7-G<W1R("*U
M3*IKO&>D2B!61E,@P,FNU[CJKL8N(@H*(SH@;&EB+U9&4RYP:'`Z.#8Q"FUS
M9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@
M97AC965D960N(@IM<V=S='(@(K5,JFN\9Z1*(%9&4R#`R:[7+""ZS[K0L'3#
M0J1WNJ$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(JFSO74B"@HC.B!T
M96UP;&%T97,O<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B
M"FUS9W-T<B`BJ/JN^*?SI^\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C
M=&EO;B(*;7-G<W1R("*T7ZWL(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C(R,R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,SDP"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N
M(&-O;FYE8W1I;VXZ("(*;7-G<W1R("*F^*I!OKFS<[6RKLFU;Z7-I;RY=[3!
MJKJF7L"S.B`B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,C$Y(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#$*(SH@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W."!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S@T"FUS9VED(")5;F5X<&5C=&5D(')E<W!O
M;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`BM6^ES:6\N7>TP:JZIE[`
MLRRET:;XJD&^N3H@(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N
M86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z-C$*;7-G:60@(E5N9FEL960B"FUS9W-T<B`BI;RDP,/^(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(E5N:6-O9&4@*%54
M1BTX*2(*;7-G<W1R("*X5;#JO5@@*%541BTX*2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4V"FUS9VED(")5;FET960@
M07)A8B!%;6ER871E<R(*;7-G<W1R(")5;FET960@07)A8B!%;6ER871E<R`H
MJORIU*="P7"F6*1JI+VPZBDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C,X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM
M<V=S='(@(E5N:71E9"!+:6YG9&]M("BM7K#J*2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR-#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S
M-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E
M9"!3=&%T97,B"FUS9W-T<B`B56YI=&5D(%-T871E<R`HK/RPZBDB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,Y(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,S<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$S"FUS
M9VED(")5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',B"FUS
M9W-T<B`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8R(&QI8B]";&]C:R]M
M971A<BYP:'`Z-S$*;7-G:60@(E5N:71S(@IM<V=S='(@(K/FINPB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,CD@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z-#,P"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C4X
M"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(J6\JKZJNB(*"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P
M:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@(J6\JKZJNB!!4$D@
ML%2NI[USN+D@*$%022!-97-S86=E($E$*2XB"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I
M9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R("*EO*J^JKJKR*3AL%2N
MI[USN+D@*$%022!-97-S86=E($E$*2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,30W"FUS9VED(")5;FMN;W=N(&QO8V%T:6]N('!R;W9I
M9&5D+B(*;7-G<W1R("*EO*J^JKJF[+AMN.JP5"XB"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R
M;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`BI;RJOJJZJ,^ESJK,IE>ZV:G.
ML4N]6"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-3@*;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M
M96YT(@IM<V=S='(@(J2DPE^EV*MEI+BE\ZJZLW.ULB(*"B,Z(&QI8B](;W)D
M92])9&5N=&ET>2YP:'`Z,S`Q"FUS9VED(")5;FYA;65D(@IM<V=S='(@(J6\
MJ5*F5R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A
M8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S
M96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L
M(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T
M;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS
M9W-T<B`B(@HBIEVF=Z7^Q56\>Z2CI+FS7*6\L<+%=JJZM7NFH;#UIN:PQ:15
M+[W&NW,OMDND5RX@PDF_[[U4J7>E2,#+M?@@;6]Z:6QL82YO<F<@J=(B"B*T
MHZC1JKJLV\/VI]ZS3J3EI?,LQ?VG0:5II4BXT;"CIKFD0*VMJ.ZHPZ;;IN:V
M?:GQM7NFH:9SJ/JPQ;9+PZ\N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@IM<V=I9"`B56YS970@8V]L;W(B
M"FUS9W-T<B`BJ/JN^,-#IN(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C8X-R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.CDR-PHC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.CDS,PIM<V=I9"`B56YS=7!P;W)T960@
M17AT96YS:6]N(@IM<V=S='(@(J6\I.2TJ:JZL,;`R:97(@H*(SH@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HQ.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z,S,*;7-G:60@(E5P9&%T92(*;7-G<W1R("+%W*?S(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHR.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`BI_.W<R`E<R(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S8*;7-G:60@(E5P9&%T92!U
M<V5R(@IM<V=S='(@(J?SMW.HSZ7.JLPB"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C$T-"!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC97,O<VAA<F5S
M+V5D:70N<&AP.C(S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB
M)7-<(BXB"FUS9W-T<B`B7"(E<UPBI'>G\[=S+B(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C@S"FUS9VED(")5<&=R861E('-C<FEP="!D96QE=&5D
M+B(*;7-G<W1R("*G\[=SM7NFH:1WIU*PHRXB"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3<X(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ.3@*;7-G:60@(E5P;&]A9"(*;7-G<W1R("*D5[;'(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI
M8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(J1W
MI%>VQZG2IK/`LZ7.M7NFH:JZLUVI=\#)J.RF^*I!OKDN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM
M<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("*D:KQGJ=2D0KS&
MIG(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP
M95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S
M='(@(J1JO&?#N;"HO,:F<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M-#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B
M57)U9W5A>2`HKU&IU*9C*2(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R
M>4UA;F%G97(N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E5S92!#=7)R
M96YT.B`E<R(*;7-G<W1R("*HSZ7.I=BK9:JZ.B`E<R(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S92!34TPB"FUS
M9W-T<B`BJ,^ESB!34TPB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(W
M"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R
M($E-4U`@<V5R=F5R+B(*;7-G<W1R("*F<*I'IT&JNJC/I<ZJS*97NMDOL4N]
M6+M0($E-4U`@IOBJ0;ZYI*.F4"RE::9BIKFS7:EW+B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$*;7-G:60@(E5S97(B"FUS9W-T
M<B`BJ,^ESJK,(@H*(SH@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HW,38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F
M;W(@)7,N(@IM<V=S='(@(JC/I<ZJS"`E<R"EO+-QN4P@)7,@JKJQPL5VQ>?#
MTBXB"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S97(@061M:6YI
M<W1R871I;VXB"FUS9W-T<B`BJ,^ESJK,NMZR>B(*"B,Z(&QI8B](;W)D92]0
M<F5F<R]522YP:'`Z,C4Q"FUS9VED(")5<V5R($]P=&EO;G,B"FUS9W-T<B`B
MJ,^ESJK,O^^VM2(*"B,Z('-I9VYU<"YP:'`Z-C(*;7-G:60@(E5S97(@4F5G
M:7-T<F%T:6]N(@IM<V=S='(@(JC/I<ZJS+7YI54B"@HC.B!S:6=N=7`N<&AP
M.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE
M9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R("*FN:^XI7BJNJC/I<ZJS+7YI56H
M=++.I'>PL:7.+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-CD*;7-G
M:60@(E5S97(@86-C;W5N="!N;W0@9F]U;F0B"FUS9W-T<B`BI^2DHZCLJ,^E
MSJK,L6*XN2(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ-SD*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4S-B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.CDX"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX(&QI8B].970O
M4TU3+W=I;E]H='1P+G!H<#HQ-3`*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z,S,@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA
M;64B"FUS9W-T<B`BJ,^ESJK,IE>ZV2(*"B,Z(&QI8B](;W)D92]!=71H+U-I
M9VYU<"YP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB
M)7-<(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`BJ,^ESJK,IE>ZV2!<(B5S
M7"(@I'>F<Z9B+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX
M-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(JC/I<ZJS*97NMDZ(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z
M("(*;7-G<W1R("*HSZ7.JLPZ("(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S
M='(@(JATLLZDI*JZJ,^ESJK,.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS
M9W-T<B`B57IB96MI<W1A;B`HKU&O]Z=/ITHI(@H*(SH@;&EB+U9&4R]F:6QE
M+G!H<#HQ-C<@;&EB+U9&4R]F:6QE+G!H<#HR-3D*;7-G:60@(E9&4R!D:7)E
M8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(E9&4R"EV+_]J,.DHZ9S
MIF(N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$R,`IM<V=I9"`B
M5F%C871I;VXB"FUS9W-T<B`BL+*TP2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HX-S`*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B
M"FUS9W-T<B`BI'>GY*CLIK.NQ*JZIF'"23H@(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(J:S
MKL2IRB(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.3<@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*;7-G:60@(E9A
M;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(J5(I,#$P:RPL^:F
M["BQ<;)[IF*P7[KB*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX-C`@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$Q.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L
M=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C0X(&QI8B](;W)D92]&;W)M
M+G!H<#HR,C<P(&QI8B](;W)D92]&;W)M+G!H<#HR,S(P"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR.3$W(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N
M<&AP.C4Y"FUS9VED(")686QU97,B"FUS9W-T<B`BK<@B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C$Q,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Y,`IM<V=I
M9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(K_OJ/JMR*;;(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T.2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R(")686YU871U("BERZ6CJORYSRDB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,S"FUS9VED(")6
M87)I86)L92(*;7-G<W1R("+%W*3&(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(T-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM
M<V=S='(@(E9E;F5Z=65L82`HJ66DNK?GJ=0I(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@
M+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*
M;7-G<W1R("+%Y\/2I:*QT2`M(*:YMFRE\Z5IK^"D=[Y$I$B^U:;;OWFG[RXB
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B5F5R
M<VEO;B(*;7-G<W1R("*JJ:6[(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(R.`IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(JJII;NQ
ML:CN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI9VXB"FUS9W-T<B`BJZNJ
MO;GON_0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@(JNKJKVY
MU*52(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(JNKJKTZ(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*;7-G:60@(E9E
M<GD@2&EG:"(*;7-G<W1R("*K1+%@L*HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C0X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:65T($YA;2(*
M;7-G<W1R(")6:65T($YA;2`HME:K;BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$Y,`IM<V=I9"`B5FEE=&YA;65S92`H5DE30TE)*2(*;7-G<W1R("*V
M5JMNI.4@*%9)4T-)22DB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP
M:'`Z.38Y"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B
MP,NU^"`E<R(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I
M97<@86X@97AT97)N86P@=V5B('!A9V4B"FUS9W-T<B`BIF*W<[7XM:&V?;'2
M(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@R.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@(J5(("5S(,#+M?@B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0V(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR-#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R(")6
M:7)G:6X@27-L86YD<RP@0G)I=&ES:"`HK5[$W;K[J,JX<ZYQ*2(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR-#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(T-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G
M:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@(E9I<F=I;B!)<VQA
M;F1S+"!5+E,N("BL_,3=NONHRKASKG$I(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,#D*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`BK^"HHZO7(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,@IM<V=I9"`B5FES
M:6)I;&ET>3H@(@IM<V=S='(@(J_@J*.KUSH@(@H*(SH@;&EB+TYE="]335,O
M=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@271A
M;'D@=FEA(%--5%`B"FUS9W-T<B`BN'&D:J=1I?&\=ZVWN7&K2*2]I7&S>KE,
M(%--5%`B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO
M8FEL92YP:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T<B`BQ+6G:2(*"B,Z(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@
M(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*
M;7-G<W1R("+$M:=I(2$A(+%Q("5S(*3BL,JROK"CM7NFH2XB"@HC.B!L:6(O
M3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS9VED(")724X@=FEA($A45%`B
M"FUS9W-T<B`B5TE.(+AGI=$@2%144"(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR-3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E=A;&QI<R!A;F0@
M1G5T=6YA(@IM<V=S='(@(E=A;&QI<R!A;F0@1G5T=6YA(@H*(SH@;&EB+TAO
M<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,C0@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C@S"FUS9VED(")787)N:6YG(@IM<V=S='(@(L2UIVDB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS
M9VED(")792(*;7-G<W1R("*L4+3!I%0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H97(@1F]R96-A<W0B"FUS9W-T
M<B`BI-&N\+EWM/HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-#$V"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS9W-T<B`B
MKO"V2+CJKL:THZC1(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Y-@IM<V=I
M9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B=V5A=&AE<BYC;VT@NO2ON"(*"B,Z
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED(")796(B"FUS9W-T<B`B
MNO2ON"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,SD*;7-G:60@
M(E=E8B!3:71E(@IM<V=S='(@(KKTK[@B"@HC.B!L:6(O2&]R9&4O36%I;G1E
M;F%N8V4N<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`BJ$.V9R(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED(")796QC;VUE
M(@IM<V=S='(@(L5WJN\B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN
M8SHT('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-3<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R("+%=ZKOJ.P@)7,B"@HC
M.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R
M=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@
M)7,B"FUS9W-T<B`BQ7>J[RP@)7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$Y,0IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`BINB\
MVB`H25-/+3@X-3DM,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,@IM
M<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,34I(@IM<V=S='(@(J;HO-H@*$E3
M3RTX.#4Y+3$U*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW."!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R(")7
M97-T97)N(%-A:&%R82`HINB\NZNBJ=0I(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0T,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T
M:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R("*U
M;J1*J^'`L[C3I?W%XZ7<("5S(*W^I$"MT\"SI<ZU>Z:A/R(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T(&ES('1H92!D
M96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R("+$YJ;LJKJDP+EJIG*DN#\B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA
M="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R("*DWJUZJKJK9;AM
MIG*DN#\B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3`V,0IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S='(@(E=H
M97)E:7,@075S=')A;&EA(*9AN<\B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,C,*;7-G:60@(E=H:6-H('!H87-E<R(*;7-G<W1R("*M_JW3I.NLVR(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S8*;7-G:60@(E=H:6-H('!L=6=I
M;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T
M<B`BNO2MMKUSO^B^N:JZM*&E\RAP;'5G:6YS*;'2L,JQL:CN+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*
M;7-G:60@(E=I9'1H(@IM<V=S='(@(KQEJ]<B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,S$Q-`IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@
M(J5(($-34R"LL+/FINRJNKQEJ]<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S8Q"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H92`E<R!M
M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI
M.B(*;7-G<W1R("*EJL/D)7.E7*_@JNVJNKQEJ]<HI%6FN+5NI$JI;*7-KL0I
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`V"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`BJNVNYKQE
MJ]<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q,`IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R("*\9:O7L^:F["(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS
M9VED(")7:61T:#HB"FUS9W-T<B`BO&6KUSHB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-3$U"FUS9VED(")7:6MI(@IM<V=S='(@(K:PQ>FST*=`
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X.2!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B5VEN9"(*
M;7-G<W1R("*MMR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8V"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@(J:MIK.MMR(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#`*;7-G:60@(E=I;F0@<W!E960@
M:6X@:VYO=',B"FUS9W-T<B`BK;>S="BX8"DB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$U-@IM<V=I9"`B5VEN9#HB"FUS9W-T<B`BK;>S=#HB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS9VED(")7:6YD.B`B
M"FUS9W-T<B`BK;>S=#H@(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T
M"FUS9VED(")7:7-D;VTB"FUS9W-T<B`BM+R\>B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ.3@*;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@(K3!
MJ]W"IZJK(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7
M;W)K(@IM<V=S='(@(J1UIT`B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$R-"!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$V-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(K_LI+VKQZ9AIWTB
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I
M9"`B5V]R:R!0:&]N92(*;7-G<W1R("*_[*2]J\>Y<;C<(@H*(SH@;&EB+T9I
M;&4O0U-6+G!H<#HQ.3,@;&EB+T9I;&4O0U-6+G!H<#HR.30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D
M+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(K+$)62FYJJZQ.:F
M[+S&I=BDHZ6_O50N(,"SN-.M;J:S)62MT\3FINPLI76GY*CL)62MT\3FINPN
M(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HS,S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD
M("5D+B(*;7-G<W1R("+$YJ;LO,:EV*2CI;^]5"X@P+.XTZUNIK,E9*W3Q.:F
M["RE=:?DJ.PE9*W3Q.:F["XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$Q.`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H
M:6QE(')E861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`BM4RJ:\7<I_,@5D93
M(,#)KM>JNJ97NMDN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T
M-0IM<V=I9"`B6"U2968B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT
M<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y
M,PIM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R(")8
M-3`Y=C,@J;6F^:KWQE^[>:IK(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA
M;64B"FUS9W-T<B`B6#4P.78S(*5$IJZTP*5.IE>ZV2(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+
M97D@261E;G1I9FEE<B(*;7-G<W1R(")8-3`Y=C,@I42FKJKWQE_#T:=/JLPB
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8X,PIM<V=I9"`B6#4P
M.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B6#4P.78S(+#&P,FF5R(*"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R("*F?B(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3$@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,PIM<V=I9"`B65E962(*
M;7-G<W1R("*F?B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,3`X"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@(EEA:&]O("$@
MIF&YSR(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@
M(EEE87)L>2(*;7-G<W1R("*H0Z9^(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(U,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B665M96XB"FUS9W-T
M<B`B665M96X@*+BMJODI(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.CDV,PIM<V=I9"`B665S(@IM<V=S='(@(JQ/(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@
M(EEE<RP@22!!9W)E92(*;7-G<W1R("*L3ZJZ+*?:IE"W3B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO
M=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S
M=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R("*G0:78JV6HSZ7.K\*D
MY:9RO7.\9[S2IJ$N(*C/I<X@6SP^72"K]K9SI6FDP;2KK+"Z]*VVO7.\9[S2
MIJ$N(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C@R"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO
M<F4@=&AA;B`E9"!B;&]C:W,N(@IM<V=S='(@(J2CI+FS7*=!J]BEWR5DI4BD
M5ZJZL,^V]"XB"@HC.B!L:6(O2&]R9&4N<&AP.C$T,34*;7-G:60@(EEO=2!A
M<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(J=!I;RS4;'"Q78N(@H*
M(SH@;&EB+TAO<F1E+TED96YT:71Y+G!H<#HS,#<*;7-G:60@(EEO=2!C86YN
M;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N
M(@IM<V=S='(@(J=!JKJE_J97I*2DHZ5IIK,@)UQ<)R"S;[S+JKJF<J2X+B`B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@U.2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3DW.0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I
M;"!A9&1R97-S+B(*;7-G<W1R("*G0:C#I;R_Z:1*I$"MTZ:SKL2JNKEQI&RV
M;*7SINRG?2XB"@HC.B!L:6(O2&]R9&4O1&%T82YP:'`Z,CDP"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O
M;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L
M9',@(@HB:6X@)7,N(@IM<V=S='(@(J=!J,.EO*71MM>D2JJZP,FNUZ2DN>^L
M3:7TIO/$YJ;LJ.P@)7,B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3@T"FUS
M9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(J=!I'>X
M9[5NI5@N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-C4*;7-G:60@(B(*
M(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@
M9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I
M;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"B*]T+_I
MI$JD0*W3IK.NQ*JZN7&XW+BYO5@LL.J[VKEQN-RXN;U8MLBE=:2YLUR\QJ9R
MN+F]6"RHP[7XL:&J<*5IJ?.K9:VQID&E6Z1`(@HBK=,@)RLG+B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,3DR"FUS9VED(")9;W4@:&%V92!T;R!E;G1E
M<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R("*G0:6RMK>_Z:1*I$"MTZ:SKL2J
MNJW(+B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@
M(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E
M(%-I9VYU<',N(@IM<V=S='(@(J=!I;*VMZ7]LU>YNJ9NOO"JK+CJKL8H1&%T
M851R964IIOBJ0;K=I'ZOX,1^Q/*HSZ7.MW.ESJ3AM?FE5:I!L,@N(@H*(SH@
M;&EB+TAO<F1E+G!H<#HT-C(*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A
M(%9&4R!B86-K96YD+B(*;7-G<W1R("*G0:6RMK>E_;-7N;JD0*W3M>K`P,#)
MKM>H=++.*%9&4RFF^*I!NMTN(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B
M;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*
M;7-G<W1R("*]T+1YK7JPW<-$H4&F8J=!ML>P9;#=PT2S^*=II*>K92XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS
M9VED(")9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P
M;VEN=',@=&\B"FUS9W-T<B`BIT&ELK:WO^FD2J:YLW.ULJG2J_RF5JJZNO2G
M?2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9
M;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S
M='(@(KW0J_RI=ZUNIU*PHZJZIOBJ0;ZY+B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$Q.0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L
M96%R(&]U="XB"FUS9W-T<B`BO="K_*EWK6ZR3;"CJKJHSZ7.JLPN(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@
M=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R("*]T*O\J7>M;K*^L*.JNJC/
MI<ZJS"XB"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE
M('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`BO="K_*EWK6ZW<[Q7JKJHSZ7.
MJLPN(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9;W4@;75S="!S
M<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@(KW0J_RI
M=ZUNI_.W<ZJZJ,^ESJK,+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N
M<&AP.C$S.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T
M;R!P97)F;W)M+B(*;7-G<W1R("*]T*O\J7>M;K#UIN:JNJ=`I<XN(@H*(SH@
M;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*;7-G:60@
M(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T<B`B
MIT&ELK:WO^FD2K=SI,##_JJZIE>ZV2XB"@HC.B!L:6(O3F5T+U--4R]V;V1A
M9F]N96ET86QY7W-M='`N<&AP.C<S"FUS9VED(")9;W4@;F5E9"!T;R!P<F]V
M:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(@IM<V=S='(@(J=!I;*VM[2C
MJ-&D0*W3N'&D:J=1N=*DNJJZN7&XW+BYO5@B"@HC.B!L:6(O2&]R9&4O075T
M:"YP:'`Z.3<R"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO
M;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R("*G
M0:JZ("5S(+=\M,&D=[E,KLDNO="MJ[=SM6ZD2BXB"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHS.`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R
M97-S(@IM<V=S='(@(J=!JKJY<:1LMFRE\Z;MIWTB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C$U"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM
M<V=S='(@(J=!JKJQ2*7SI$BY<:1LMFRE\Z;MIWTZ(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C8W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-R!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDR"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(J=!JKJXZK!4
M(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDW-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN
M8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R
M;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM
M<V=S='(@(B(*(J;;L7&G0:JZ("5S(+=\M,&V?:ELI4BHTZ=!JKJZ]+O:NO2X
M]*;LIWVD=\7<I_,N(*RPJT_%0*=!JKJF=Z7^L%^HHZ%!IT&ELK:WK:LB"B*W
M<[5NI$HN(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*
M;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R("*G0:JZIE>ZV2(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U
M=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@
M=7-E<G,N($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI;FES
M=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="`B
M"B)A=71H96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R("(B"B*G0:JZQ>?#
MTJ;XJD&ZW:C#I*.DY+2IMW.\5ZC/I<ZJS"X@IG"J1Z=!I\:QYKK>LGJHSZ7.
MJLRQ8KBY+*=!I;*VMZ5TO^^HY*5,JKK%YR(*(L/2IOBJ0;K=+B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U
M<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES
M=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L
M960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("*G0:JZQ>?#TKK=
MJ,.EO*3DM*FF0Z58J,^ESJK,J<ZXTZ5<K^"D=[-1P_:SK"XB"@HC.B!L:6(O
M2&]R9&4O075T:"YP:'`Z.3@P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO
M=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@
M8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y
M;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B
M(@HBIMNQ<:=!JKH@)7,@MWRTP;9]J6RE2*C3IT&JNL)SQ/V^N:;\I4>D=\7<
MI_,N(*RPJT_%0*=!JKJF=Z7^L%^HHZ%!IT&ELK:WK:NW<R(*(K5NI$HN(@H*
M(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-34*;7-G:60@(EEO=7(@8G)O=W-E
M<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`BIT&J
MNL)SQ/V^N:C#I;RDY+2ILV^MTZ5<K^`N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O<')I;G0N:G,Z-#(*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S
M(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L
M+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R("*G0:JZPG/$_;ZY
MJ,.EO*3DM*FF0Z9,O^^VM2Z]T*OV($-44DPO0V]M;6%N9"`K(%`@ID.F3"XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C8Q"FUS9VED(")9;W5R(&-U
M<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R("*G0:78JV6ITK-=J7>JNJ[)L,\Z
M(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDX"FUS9VED(")9;W5R(&1E9F%U
M;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"XB"FUS9W-T<B`BN]6D5;EW
MLUVJNJBMI??#T:=/I'?%W*?S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-C$*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>3HB"FUS9W-T<B`B
MN]6D5;EWLUVJNJBMI??#T:=/.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,#0*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R("*G0:JZI?ZF
M5SHB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3DV"FUS9VED(")9;W5R(&QO
M9VEN(&AA<R!E>'!I<F5D+B(*;7-G<W1R("*G0:JZM6ZD2J1WJ.RTP2XB"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S
M='(@(J=!IF(@)7,@I*2JNK=SL4N]6*Q/.B`E<R(*"B,Z(&QI8B](;W)D92]0
M<F5F<R]522YP:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N
M('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM
M<V=S='(@(J=!IF*U;J1*M,&VH:JZO^^VM:1WLU&G\[=S+B(*"B,Z(&QI8B](
M;W)D92]0<F5F<R]522YP:'`Z,34V"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V
M92!B965N('5P9&%T960N(@IM<V=S='(@(J=!JKJ_[[:UI'>G\[=S+B(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A
M<W-W;W)D(&AA<R!B965N(')E<V5T(@IM<V=S='(@(J=!JKJQ2[U8I'>MJ[=S
MLUVI=R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED
M("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R
M(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB
M"FUS9W-T<B`BL4N]6*1WLU&MJ[=SLUVI=RRW<ZJZL4N]6*1WLWJY3+EQI&RV
M;*7SL4BU;[W0I4BXT[%+O5BU;J1*+B(*"B,Z(&QI8B](;W)D92]!=71H+G!H
M<#HW,S`*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S
M='(@(J=!JKJQ2[U8I'>H[+3!+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T
M<B`BIT&JNKNWNMVF^*I!OKDZ(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(U-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EEU9V]S
M;&%V:6$B"FUS9W-T<B`B675G;W-L879I82`HJVZTM:G4I-(I(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G<W1R
M("):86ER92`HPL2E["DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4V
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS9W-T<B`B6F%M
M8FEA("BI?*3QJ,@I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T<B`B6FEM
M8F%B=V4@**BOI-JKPBDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*
M;7-G:60@(EII<'!Y(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]497AT+T9I
M;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O=&5D
M(%1E>'1=(@IM<V=S='(@(EO!],+#I-ZM>ETB"@HC.B!S97)V:6-E<R]P<F]B
M;&5M+G!H<#HX.0IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R(");
ML-W#1*3/K$U=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C
M:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS9W-T<B`B
M6\7CI=RDWJUZ("TB"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O:&EG:&QI
M9VAT<75O=&5S+G!H<#HQ-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@
M475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B6\7CI=RDWJUZ("T@
M)7,@IN9=(@H*(SH@;&EB+TAO<F1E+G!H<#HQ.34*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(ENF[*GSIN8@)7,@ID`@
M)7,@IN9=(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-30U('1E;7!L871E<R]P;W)T
M86PO;65N=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R
M("*ZWK)Z7T$B"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS
M9W-T<B`BJ5*E3Z9#7T,B"@HC.B!L:6(O87!I+G!H<#HQ-#$*;7-G:60@(E]$
M871A5')E92(*;7-G<W1R("*^\*JLN.JNQE]$(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED(")?
M1&5L971E(%)O=R(*;7-G<W1R("*G4K"CID-?1"(*"B,Z(&QI8B]A<&DN<&AP
M.C$S,PIM<V=I9"`B7T=R;W5P<R(*;7-G<W1R("*X<[+57T<B"@HC.B!L:6(O
M2&]R9&4O365N=2YP:'`Z,3<U"FUS9VED(")?2&5L<"(*;7-G<W1R("*[H:GZ
M7T@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P97)T:65S+BXN(@IM<V=S
M='(@(KQVN;.DNJYE7TDN+BXB"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,3DT
M"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(K5NI$I?3"(*"B,Z(&QI8B](;W)D
M92]-96YU+G!H<#HQ.3`*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(K5NI5A?
M3"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR-`IM<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(JW7
MI^^S<[6R7TTN+BXB"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,38T"FUS9VED
M(")?3W!T:6]N<R(*;7-G<W1R("*_[[:U7T\B"@HC.B!L:6(O87!I+G!H<#HQ
M,S<*;7-G:60@(E]097)M:7-S:6]N<R(*;7-G<W1R("+%=JVM7U`B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C8*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R("*ROK"CN>^S<[6R
M7U(N+BXB"@HC.B!L:6(O87!I+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G
M<W1R("*S7:EW7U,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L92!0<F]P97)T:65S
M+BXN(@IM<V=S='(@(JKMKN:DNJYE7U0N+BXB"@HC.B!L:6(O87!I+G!H<#HQ
M,CD*;7-G:60@(E]5<V5R<R(*;7-G<W1R("*HSZ7.JLQ?52(*"B,Z(&QI8B](
M;W)D92]+;VQA8BYP:'`Z.3(P"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T
M<B`BLW&P5+_](@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3,T
M"B,L(&9U>GIY"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R("*S
M<;!4O_TB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDQ,@IM<V=I9"`B8V%L
M96YD87(B"FUS9W-T<B`BIN:HQK[D(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(F-A;&TB"FUS9W-T<B`BN7.OQ:VW(@H*(SH@;&EB+TAO
M<F1E+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN;W0@8W)E871E
M(&]U='!U="!F:6QE(@IM<V=S='(@(K5,JFNKV*7?O^FE6,#)KM<B"@HC.B!L
M:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O
M<&5N(&EN<'5T(@IM<V=S='(@(K5,JFNV?;'2O^FD2B(*"B,Z(&QI8B](;W)D
M92]-24U%+T-O;G1E;G1S+G!H<#HU.3D*;7-G:60@(F-L:6-K(&AE<F4B"FUS
M9W-T<B`BJ_:FN2(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$R
M,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@(K%+
MI4^F0[MYJFN_^;M^(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z
M,3<X"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(K-=J7>_
M^;M^(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED
M(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(K_RI:*M
MJZUNJKJH=++.P,FNUR(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP
M.C$R-@IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`BN.JNQJ[F
MIJ&_^;M^(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3@R"FUS
M9VED(")E;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`BI^2DHZCLL$^__2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"B,L(&9U
M>GIY"FUS9VED(")F86QL:6YG(@IM<V=S='(@(K7[I,`B"@HC.B!L:6(O2&]R
M9&4O0G)O=W-E<BYP:'`Z.#@Q"FUS9VED(")F:6QE(@IM<V=S='(@(L#)KM<B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W-"!L:6(O0FQO8VLO;65T87(N
M<&AP.C,V,"!L:6(O0FQO8VLO;65T87(N<&AP.C,X-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S(@IM<V=S='(@(K%Q
M("5S("@E<RD@J?,@)7,@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C,Y"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(K!]K;<B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0X"FUS9VED(")H
M.B(*;7-G<W1R("*NR3HB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,S4W"FUS9VED(")H:"(*;7-G<W1R("*NR2(*"B,Z(&QI8B](
M;W)D92]-24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE('5N
M:VYO=VXB"FUS9W-T<B`BI;RJOJJZMFRE\Z5$OO>F5[K9(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-2!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E(@IM<V=S='(@
M(J7?IUDB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U
M<"]D:69F+G!H<#HW.0IM<V=I9"`B:6YL:6YE(@IM<V=S='(@(JJ]L;7%XZ7<
MJ?.ENZ3EL,\B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-C(*
M;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R("*_Z:1*+[_II5B_
M^;M^(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,30V"FUS9VED
M(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R("*DNK.ALV[%Z;_Y
MNWXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ
M,PIM<V=I9"`B;&EN97-=(@IM<V=S='(@(J;F72(*"B,Z(&QI8B]61E,O25-/
M5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*;7-G:60@(FUK
M:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S8X
M"FUS9VED(")M;2(*;7-G<W1R("*DP"(*"B,Z(&QI8B](;W)D92]0<F5F<R]5
M22YP:'`Z,CDQ('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S`*(SH@
M<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(S,@IM<V=I9"`B;F%M92(*
M;7-G<W1R("*F5[K9(@H*(SH@;&EB+TAO<F1E+U)00RYP:'`Z,3(T"FUS9VED
M(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`BJ7REO+GJIT`N(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,C(P"FUS9VED(")N;W0@>65T(&EM
M<&QE;65N=&5D(@IM<V=S='(@(JE\I;RYZJ=`+B(*"B,Z(&QI8B](;W)D92]+
M;VQA8BYP:'`Z.3`T"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(K/&I]&__2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`BILJDP*3Q(@H*(SH@;&EB
M+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3<T"FUS9VED(")P97)M:7-S:6]N
M(&1E;FEE9"(*;7-G<W1R("*F<ZCZOD2IVB(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L
M<R(*;7-G<W1R("*YLZ_`(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP
M:'`Z,3<P"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T
M<B`BLW&K2*CSJ7>[M[K=O_F[?B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C<S"FUS9VED(")R:7-I;F<B"FUS9W-T<B`BI%>D
MR2(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$T,@IM<V=I9"`B
M<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R("*U3*5II<ZJNJI!L,@B"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.CDY"FUS9VED(")S:&]W(&1I9F9E
M<F5N8V5S(@IM<V=S='(@(L7CI=RN=+*G(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10
M(@IM<V=S='(@(G-M<S)E;6%I;""X9Z71($A45%`B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@T"FUS9VED(")S<R(*;7-G<W1R
M("*L[2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C<R"FUS9VED(")S=&5A9'DB"FUS9W-T<B`BPZVI=R(*"B,Z(&QI8B](;W)D
M92]-24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM
M<V=S='(@(JATLLZ_^;M^(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,C@*
M;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R("*KW;_LPZ\B"@HC.B!L:6(O2&]R
M9&4O34E-12]-97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL
M=7)E(@IM<V=S='(@(KS(KLFIRJJZI:*QT2(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C,V(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C<P"FUS9VED(")T>7!E
M('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@(J9!IKB_
MZ:1*IT&JNK%+O5BE2+U4NWNU3+M^(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP
M:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(G5N:69I960B
M"FUS9W-T<B`BON.F6"(*"B,Z(&QI8B](;W)D92]-24U%+U!A<G0N<&AP.C(W
M"FUS9VED(")U;FYA;65D(@IM<V=S='(@(J6\J5*F5R(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S='(@
M(JC/I<ZJS+_OOMPB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR-#`*;7-G:60@(G<Z(@IM
M<V=S='(@(JQ0M,$Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C8*;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(G=E871H97(N8V]M(+KT
MK[@B"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+VAU
M7TA5+G!O````````````````````````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#<Q-S(W-B`Q,#4Q-30S,S<T,B`P,3<U-3$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````(R!(;W)D92!(=6YG
M87)I86X@=')A;G-L871I;VX@9FEL92X*(R!#;W!Y<FEG:'0@*$,I(#(P,#(M
M,C`P-B!,87-Z;&\@3"X@5&]R;F]C:0HC(%1H:7,@9FEL92!I<R!D:7-T<FEB
M=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!(;W)D92!P86-K
M86=E+@HC($QA=&5S="!V97)S:6]N<SH@9G1P.B\O>&5N:6$N<V]T92YH=2]P
M=6(O;&EN=7@O:&]R9&4O"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T
M+4ED+59E<G-I;VXZ($AO<F1E(#,N,5QN(@HB4F5P;W)T+4US9VED+4)U9W,M
M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E
M.B`R,#`V+3`R+3$W(#$P.C`P*S`Q,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z
M(#(P,#8M,#(M,3<@,3`Z,S@K,#$P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!,
M87-Z;&\@3"X@5&]R;F]C:2`\=&]R;&%S>D!X96YI82YS;W1E+FAU/EQN(@HB
M3&%N9W5A9V4M5&5A;3H@2'5N9V%R:6%N(#QI,3AN0&QI<W1S+FAO<F1E+F]R
M9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E
M>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,EQN(@HB0V]N=&5N="U4<F%N
M<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(S-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS
M9W-T<B`B("@E<R!N87!P86P@97IE;/5T="DB"@HC.B!L:6(O2&]R9&4N<&AP
M.C$S-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM
M<V=S='(@(B`H06QT+6)I;&QE;G1Y^R`E<RDB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C,X,0HC+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I
M(@IM<V=S='(@(B`H)7,@;F%P(&WZ;'9A*2(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR,S<W"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(@*&UA*2(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,S<Y"FUS9VED("(@*'1O;6]R<F]W*2(*
M;7-G<W1R("(@*&AO;&YA<"DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W
M-0IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@(B`H=&5G;F%P*2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#4@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,U,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,SDV"FUS9VED("(@870@(@IM<V=S='(@(B`Z("(*"B,Z(&QI8B]6
M1E,O<VUB+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES
M(&YO="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B7"(E<UPB(&YE;2!A;&OV;GEV
M=.%R+B(*"B,Z(&QI8B](;W)D92]#3$DN<&AP.C(W,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R
M(")<(B5S7"(@;F5M(.ER=NEN>65S(';A;&%S>G3A<RXB"@HC.B!L:6(O2&]R
M9&4O4F5G:7-T<GDN<&AP.C<Q,"!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C$P
M.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U
M<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B7"(E<UPB(&YI
M;F-S(&MO;F9I9W5RX6QV82!A($AO<F1E(%)E9VES=')Y8F5N+B(*"B,Z(&QI
M8B](;W)D92]4<F5E+G!H<#HQ-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R(")<(B5S7"(@
M9F%S=')U:W3Z<F$M;65G:F5L96[M=/4@;F5M('1A;.%L:&%T\RXB"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C4V"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<
M(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(EPB
M)7-<(BUT(&AO>GKA861T=6L@82!C<V]P;W)T;VMH;WHN(@H*(SH@861M:6XO
M<&5R;7,O861D8VAI;&0N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(EPB
M)7-<(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS
M9W-T<B`B7"(E<UPB+70@:&]Z>N%A9'1U:R!A(&IO9V]S=6QT<^%G:2!R96YD
M<WIE<FAE>BXB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4T(&%D;6EN+W!E<FUS
M+V%D9&-H:6QD+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B7"(E<UPB+70@;F5M(&AO
M>G1U:R!LZ71R93H@)7,N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P
M"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N,F9-0B!A
M;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B4N,F9-0B!F96QH87-Z;N%L="!A
M("4N,F9-0B!M96=E;F=E9&5T=&+U;"`H)2XR9B4E*2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)60@)7,@86YD("5S(@IM<V=S='(@(B5D("5S(.ES("5S(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O;&1A<"YP:'`Z,C8X(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU
M-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A
M<W-W;W)D(&5X<&ER97,N(@IM<V=S='(@(B5D(&YA<"!M^FQV82!L96KA<B!J
M96QS>F%VX6YA:R#I<G;I;GEE<W/I9V4N(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@
M9F]R96-A<W0B"FUS9W-T<B`B)60@;F%P;W,@96SU<F5J96QZZ7,B"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B)7,@+2!&:6=Y96QM97IT973I<R(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`U"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B5S(&QE;GEO;6%T
M(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@T,2!L:6(O2&]R
M9&4O34E-12]#;VYT96YT<RYP:'`Z.#0S"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S($M"(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N86YC92!/<&5R
M871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B5S(&MA<F)A;G1A<G3A
M<VD@9F5L861A=&]K("T@;65G97+U<^UTZ7,B"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,34*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B)7,@8F7A;&SM=.%S
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-C0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(E<R!L;V=I;B!NZ78@
M:6?I;GELZ7,B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S
M='(@(B5S('-Z;VQGX6QT873A<VD@9F5L=.ET96QE:R(*"B,Z(&QI8B]61E,O
M<VUB+G!H<#HT,S(@;&EB+U9&4R]S;6(N<&AP.C0Y-"!L:6(O5D93+V9T<"YP
M:'`Z-C@R"B,Z(&QI8B]61E,O9G1P+G!H<#HW-3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(D$@7"(E<UPB(&YE
M=OL@X6QL;VWA;GD@;>%R(&SI=&5Z:6LN(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-#8*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3(@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@
M)7,@)7,B"FUS9W-T<B`B)7,@.B`E<R`E<R(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<R!I<R!R
M96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H
M96-K960@8F5L;W<N($-H96-K('1H92`B"B)B;W@@9F]R(&%N>2!O<&5R871I
M;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N(@IM<V=S
M='(@(B(*(D$H>BD@)7,@:^ES>F5N(.%L;"!A>B!A;.%B8FD@:V%R8F%N=&%R
M=.%S:2!F96QA9&%T;VL@96QVZ6=ZZ7/I<F4N2F5L]FQJ92!K:2`B"B)A>F]K
M870@82!F96QA9&%T;RAK82ET+"!A;6DH:V4I="!M;W-T(&5L(&OM=N%N(';I
M9V5Z;FDN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`B)7,@:VET]FQT
MZ7-E('-Z_&MSZ6=E<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDS"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&UI;G5T97,B"FUS9W-T<B`B)7,@<&5R
M8R(*"B,Z(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,CD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(E<R!N
M96T@=&%LX6QH873S+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS
M9W-T<B`B)7,@+2`E<R`H]G-S>F5S96X@)7,I(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HY,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S
M($)O;VLB"FUS9W-T<B`B)7,@8^UM:F5G>7KI:V4B"@HC.B!L:6(O2&]R9&4O
M2V]L86(N<&AP.CDQ.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N
M9&%R(@IM<V=S='(@(B5S(&YA<'3A<F$B"@HC.B!L:6(O2&]R9&4O2V]L86(N
M<&AP.CDQ,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS
M9W-T<B`B)7,@9F5L:F5G>7KI<V5I(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G
M<W1R("(E<R!F96QA9&%T;&ES=.%J82(*"B,Z(&QI8B](;W)D92].;W1I9FEC
M871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<SH@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+VAT;6PN<&AP.C$R-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@
M5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T
M;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@
M;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@
M:6YF;W)M871I;VXN(@IM<V=S='(@(B(*(B5S.B!,96AE='/I9V5S+"!H;V=Y
M(&5Z(&$@;&5VZ6P@=F%L\VKA8F%N(&YE;2!A(&UE9V%D;W1T(&9E;&%D\W3S
M;"`B"B)S>N%R;6%Z:6LN($=O;F1O;&IA(&UE9RP@;6EE;/5T="!RX6MA='1I
M;G0@=F%L86UI<F4L('9A9WD@<WIE;>EL>65S("(*(FEN9F]R;>%C:?-T(&%D
M(&UE9RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4T(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.3D*;7-G:60@(BP@9W5S=&EN
M9R`B"FUS9W-T<B`B+"!S>NEL;/9KZ7-E:R(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3DU(&QI8B]";&]C:R]M971A<BYP:'`Z,C`P"B,L('!H<"UF;W)M
M870*;7-G:60@(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(L("5S("5S+7,@
M<WKI;&SV:^ES96LB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P.`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B"FUS
M9W-T<B`B+"!VX6QT;WKS("5S(.ES("5S(&OV>O9T="(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,#<S(&QI8B](;W)D92]&;W)M+G!H<#HR,3,R(&QI8B](
M;W)D92]097)M<R]522YP:'`Z,CDT"B,Z(&QI8B](;W)D92]097)M<R]522YP
M:'`Z,S0X(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HW-#@*
M;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(M+2!VX6QA<W-Z;VX@+2TB
M"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO=7(@1F]R
M;6%T(@IM<V=S='(@(C$R(/-RX7,@9F]R;>%T=6TB"@HC.B!L:6(O0FQO8VLO
M=&EM92YP:'`Z,3D*;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(C(T
M(/-RX7,@9F]R;>%T=6TB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR
M.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@\W)A(@H*(SH@;&EB+TAO
M<F1E+U5)+U!A9V5R+G!H<#HV.0IM<V=I9"`B/%!R979I;W5S(@IM<V=S='(@
M(CQ%;/5Z]2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(V"FUS9VED(")!
M(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN
M(@IM<V=S='(@(D5Z96X@8FQO:VL@:&%S>F[A;&%TX6AO>B!E9WD@861A=&+A
M>FES(&%L<F5N9'-Z97(@<WK\:W/I9V5S+B(*"B,Z(&QI8B](;W)D92YP:'`Z
M,38R"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R
M(")(96QY<F5H;WIH871A=&QA;B!H:6)A('3V<G3I;G0B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@
M:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(D$@
M;&5VZ6P@=&ET:V]S[73A<^%H;WH@96=Y(&YY:6QVX6YO<R!01U`@:W5L8W,@
M<WK\:W/I9V5S+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q-C@*
M;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y
M(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*(D$@9&EG:73A;&ES86X@
M86SA[7)T(&QE=NEL(&5L;&5N]7)ZZ7/I:&5Z(&5G>2!N>6EL=N%N;W,@4$=0
M(&MU;&-S('-Z_&MSZ6=E<RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HQ,#DY"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'
M4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T
M(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB02!T:71K;W/M=&]T="!L97;I
M;"!D96OS9&]LX7/A:&]Z(&5G>2!N>6EL=N%N;W,@4$=0(&MU;&-S+"!E9WD@
M=&ET:V]S(%!'4"`B"B)K=6QC<R#I<R!E9WD@:F5L;6]N9&%T('-Z_&MSZ6=E
M<RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#$V"FUS9VED("(B
M"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS
M9W-T<B`B(@HB02!L97;I;"!D:6=I=.%L:7,@86SA[7+A<^%H;WH@96=Y(&YY
M:6QVX6YO<R!01U`@:W5L8W,L(&5G>2!T:71K;W,@4$=0(&MU;&-S("(*(NES
M(&5G>2!J96QM;VYD870@<WK\:W/I9V5S+B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-3`V"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y
M+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@HB02!T
M:71K;W/M=&]T="!L97;I;"!D96OS9&]LX7/A:&]Z(&5G>2!N>6EL=N%N;W,@
M4R]-24U%(&MU;&-S+"!E9WD@=&ET:V]S(%,O(@HB34E-12!K=6QC<R#I<R!E
M9WD@:F5L;6]N9&%T('-Z_&MSZ6=E<RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@
M<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*(D$@;&5VZ6P@
M9&EG:73A;&ES(&%LX>URX7/A:&]Z(&5G>2!N>6EL=N%N;W,@4R]-24U%(&MU
M;&-S+"!E9WD@=&ET:V]S(%,O34E-12`B"B)K=6QC<R#I<R!E9WD@:F5L;6]N
M9&%T('-Z_&MSZ6=E<RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O
M(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(")!(&QE=NEL('1I=&MO<^UT
MX7/A:&]Z(&5G>2!N>6EL=N%N;W,@4R]-24U%(&MU;&-S('-Z_&MSZ6=E<RXB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HY"FUS
M9VED(")!32!#;&]U9',B"FUS9W-T<B`B1.EL96SU='0@8F]R=6QT(.EG(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*;7-G
M:60@(D%-($QI9VAT(%)A:6XB"FUS9W-T<B`B1.EL96SU='0@9WEE;F=E(&5S
M]2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q
M"FUS9VED(")!32!286EN(@IM<V=S='(@(D3I;&5L]71T(&5S]2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED(")!
M32!3:&]W97)S(@IM<V=S='(@(D3I;&5L]71T:2!ZX7!O<F]K(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-
M(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")$Z6QE;/5T="!H\WKA<&]R;VLB"@HC
M.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB"FUS
M9W-T<B`B9&4O9'4B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S='(@(D%022!)1"`H82!P<F]G
M<F%M;WKA<VD@9F5L_&QE="!A>F]N;W/M=/-J82DB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T
M:&ES(&5D:71O<B(*;7-G<W1R(")%<G+U;"!A>B!E9&ET;W)R\VPB"@HC.B!S
M97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,PIM<V=I9"`B06)O=70N+BXB"FUS
M9W-T<B`B3NEV:F5G>2XN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R(")A
M8G-Z(&%L=6PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<R"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B86)S>B!K]GKI
M<"(*"B,Z(&QI8B]61E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E
M;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").:6YC<R!J
M;V=O<W5L='/A9V$@82!61E,@86QK]FYY=G3A<B!LZ71R96AO>N%SX6AO>BXB
M"@HC.B!L:6(O5D93+VUU<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI
M960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@(DYI;F-S(&IO9V]S=6QT
M<^%G82!A(%9&4R!FX6IL(&SI=')E:&]ZX7/A:&]Z+B(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HS"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM
M<V=S='(@(D)E:F5L96YT:V5ZZ7-I(&EN9F]R;>%C:?,B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-S@*;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS
M9W-T<B`B2F5L<WKS(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.3,*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R(")!(&IO
M9V]S=6QT<^%G(&9E;"!V86X@9OQG9V5S>G1V92XB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S,U"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@
M(E#I;GK\9WEE:R(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,30X('1E
M;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0IM<V=I9"`B061D(@IM<V=S='(@(D)E
M=FET96PB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G<F]U<',N
M<&AP.C(R-0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S='(@(D%L8W-O
M<&]R="!LZ71R96AO>N%S82(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z
M.3@@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HY.0IM<V=I9"`B061D($-H:6QD
M(%!E<FUI<W-I;VXB"FUS9W-T<B`B2F]G;W-U;'1SX6=I(&%L8W-O<&]R="!L
MZ71R96AO>N%S82(*"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS
M9VED(")!9&0@2&5R93HB"FUS9W-T<B`B061D:G5K(&AO>GKA(&ET=#HB"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q.0IM
M<V=I9"`B061D($YE=R!'<F]U<"(*;7-G<W1R("+::B!C<V]P;W)T(&SI=')E
M:&]ZX7-A(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HX-R!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB
M"FUS9W-T<B`BVFH@:F]G;W-U;'1SX6<@;.ET<F5H;WKA<V$B"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHW"B,L('!H<"UF;W)M
M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R
M(")!;&-S;W!O<G0@:&]Z>N%A9.%S82!<(B5S7"(M:&5Z(@H*(SH@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D
M(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B2F]G;W-U
M;'1SX6=I(&%L8W-O<&]R="!H;WIZX6%DX7-A(%PB)7-<(BUH97HB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S
M='(@(MIJ(&9E;&AA<WINX6SS(&SI=')E:&]ZX7-A.B(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HU-38*;7-G:60@(D%D9"!C;VQU
M;6XB"FUS9W-T<B`BVFH@;W-Z;&]P(&AO>GKA863A<V$B"@HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,T"FUS9VED(")!9&0@;F5W(&UE
M;6)E<G,B"FUS9W-T<B`BVFH@=&%G;VL@9F5L=NET96QE(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D('!A:7(B"FUS9W-T
M<B`BVFH@<.%R(&AO>GKA863A<V$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S<Q"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A
M<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R(")!*'HI("5S(&UE;OQT(&%D
M:G5K(&AO>GKA(&$@36]Z:6QL82!M96[\<V]R:&]Z(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HW,0IM<V=I9"`B061D('1O(&%D9')E
M<W,@8F]O:SHB"FUS9W-T<B`B061J=6L@:&]Z>N$@82!C[6UJ96=Y>NEK:&5Z
M.B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*;7-G
M:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`B061J=6L@:&]Z
M>N$@82!C[6UJ96=Y>NEK96UH97HB"@HC.B!A9&UI;B]U<V5R+G!H<#HS,0IM
M<V=I9"`B061D('5S97(B"FUS9W-T<B`BVFH@9F5L:&%S>F[A;/,@:&]Z>N%A
M9.%S82(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@
M;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N
M(@IM<V=S='(@(B(*(EPB)7-<(B!F96QH87-Z;N%L\W0@:&]Z>N%A9'1U:R!A
M(')E;F1S>F5R:&5Z+"!D92!N96T@<VEK97+\;'0@82!T]F)B:2`B"B)B96IE
M;&5N=&ME>NES:2!A9&%T('3A<F]LX7-A.B`E<RXB"@HC.B!S:6=N=7`N<&AP
M.C0U"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@
M<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(EPB)7-<(B!F
M96QH87-Z;N%L\W0@9F5L=F5T=.EK(&$@<F5N9'-Z97)B92X@36]S="!MX7(@
M8F5J96QE;G1K97IH970N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A
M9&0N:6YC.C(*;7-G:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS
M9W-T<B`B02!R96YD<WIE<FAE>B!N96T@861H873S:R!H;WIZX2#Z:B!F96QH
M87-Z;N%L\VLN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#4@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ-S,*;7-G:60@(D%D9')E<W,B"FUS9W-T
M<B`B0^UM(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$T,0IM<V=I
M9"`B061D<F5S<R!";V]K(@IM<V=S='(@(D/M;6IE9WEZZ6LB"@HC.B!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-38@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.CDT"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E
M<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R(")!9&UI;FES>G1R
MX6-I\R`M(&IO9V]S=6QT<^%G;VL@863A<V$@=&]VX6)B:2!F96QH87-Z;N%L
M\VMN86LB"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T
M<B`B061M:6YI<WIT<N%C:?,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S0S"FUS9VED(")!9',B"FUS9W-T<B`B2&ER9&5TZ7-E:R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-38*;7-G:60@
M(D%F9VAA;FES=&%N(@IM<V=S='(@(D%F9V%N:7-Z=.%N(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06QB
M86YI82(*;7-G<W1R(")!;&+A;FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C<T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B06QG97)I82(*;7-G<W1R
M(")!;&?I<FEA(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,#<*;7-G:60@(D%L:6%S(@IM<V=S='(@(D%L:6%S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I
M9"`B06QI9VXB"FUS9W-T<B`B16QH96QY97KI<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N
M=#HB"FUS9W-T<B`B4F5N9&5ZZ7,Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C@W"FUS9VED(")!;&PB"FUS9W-T<B`B87H@]G-S>F5S970B"@HC.B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*;7-G
M<W1R(")-:6YD96X@;F5M('9E;F3I9R!F96QH87-Z;N%L\R(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L
M;"!'<F]U<',B"FUS9W-T<B`B36EN9&5N(&-S;W!O<G0B"@HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.CDQ(&QI8B](;W)D92]097)M<R]D871A=')E92YP
M:'`Z-S4*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R(")-:6YD96X@
M:F]G;W-U;'1SX6<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G
M<W1R(")-:6YD(&$@;NEG>2!O;&1A;&]N(&QE9WEE;B!K97)E="(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ.#<U"FUS9VED(")!;&QO=R!M=6QT:7!L92!A
M9&1R97-S97,B"FUS9W-T<B`B16YG961J_&YK(&UE9R!T]F)B(&/M;65T(&ES
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S.`IM<V=I9"`B06QL;W<@
M<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B02!S;W)S
M>N%M;W,@9F5L<V]R;VSA<R!T[7!U<V$@=N%L=&]Z=&%T:&%T\R!L96=Y96X_
M(@H*(SH@;&EB+TAO<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS9VED(")!
M;')E861Y(&5X:7-T<R(*;7-G<W1R(")-X7(@;.ET97II:R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,C8*;7-G:60@(D%L=&5R;F%T92!)35-0($QO
M9VEN(@IM<V=S='(@(DE-4U`@8F5J96QE;G1K97KI<VD@<&%R86WI=&5R96LB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$Q"FUS9VED(")!;'1E<FYA
M=&4@24U34"!087-S=V]R9"(*;7-G<W1R(")-X7-I:RP@24U34"!J96QS>O,B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`S"FUS9VED(")!;'1E<FYA
M=&4@24U34"!5<V5R;F%M92(*;7-G<W1R(")-X7-I:RP@24U34"!B96IE;&5N
M=&ME>NES:2!NZ78B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS
M-0IM<V=I9"`B06QT97)N871E(&5M86EL(&%D9')E<W,B"FUS9W-T<B`B3>%S
M:6L@96UA:6P@8^UM(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*;7-G
M:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`B06QT97)N873M=B!S
M86)L;VYO:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM
M<V=S='(@(D%L=&5R;F%T[78@<WKV=F5G.B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A
M;6]A(@IM<V=S='(@(D%M97)I:V%I(%-Z86UO82(*"B,Z(&QI8B](;W)D92]0
M<F5F<R]522YP:'`Z.34@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ,34*;7-G
M:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB"FUS9W-T<B`B
M02!M96=A9&]T="#I<G3I:R!N96T@9F]G861H873S(&5L+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-34*;7-G:60@(D%N('5N:VYO=VX@
M97)R;W(@:&%S(&]C8W5R960N(@IM<V=S='(@(DES;65R971L96X@:&EB82!T
M]G)TZ6YT+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-34*;7-G:60@(D%N9&]R<F$B"FUS9W-T<B`B06YD;W)R82(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G
M:60@(D%N9V]L82(*;7-G<W1R(")!;F=O;&$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;F=U:6QL82(*
M;7-G<W1R(")!;F=U:6QL82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S='(@(D%N;VYI;2!P
M<F]X>6X@:V5R97-Z=/QL:2!I;G1E<FYE="!E;.ERZ7,B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@
M(E;A;&%S>B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`B06YT87)K=&ES
M>B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-38*;7-G:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B06YT:6=U
M82#I<R!"87)B=61A(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HW-"!A9&UI
M;B]P:'!S:&5L;"YP:'`Z,S4@;&EB+TAO<F1E+T)L;V-K+U5)+G!H<#HU.`HC
M.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HV"FUS9VED(")!
M<'!L:6-A=&EO;B(*;7-G<W1R(")!;&MA;&UA>N%S(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T(@IM<V=S
M='(@(D%L:V%L;6%ZX7-O:R!L:7-TX6IA(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$T,`IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S
M='(@(D%Z(&%L:V%L;6%ZX7,@:^ES>BXB"@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM
M<V=S='(@(D$@:_9Z]G,@=.%R=&5R_&QE="!A;&-S;W!O<G1J86ER82!I<R#I
M<G;I;GEE<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC
M.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(DKS=N%H86=YX7,B"@HC.B!L
M:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#0Q"FUS9VED(")!<'!R;WAI
M;6%T92!3:7IE(@IM<V=S='(@(DOV<OQL8F5L_&QI(&WI<F5T(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-2!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S
M='(@(N%P<FEL:7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I
M9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(F%R86(@*%=I;F1O
M=W,M,3(U-BDB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HU
M.2!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV-@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=&=Z+G!H<#HW.`IM<V=I9"`B07)C:&EV92!&:6QE
M(%-I>F4B"FUS9W-T<B`B02!T]FWV<NUT971T(.%L;&]MX6YY(&WI<F5T92(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C4X(&QI8B](;W)D
M92]-24U%+U9I97=E<B]Z:7`N<&AP.C8U"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]T9WHN<&AP.C<W"FUS9VED(")!<F-H:79E($YA;64B"FUS9W-T<B`B
M02!T]FWV<NUT971T(.%L;&]MX6YY(&YE=F4B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$P"B,L('!H<"UF;W)M870*;7-G
M:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU
M<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(D)I>G1O<R!B96YN92P@:&]G
M>2!T]G+V;&YI(&OM=N%N:F$@)7,@8F5J96QE;G1K97KI<VD@:6?I;GGI=#\B
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L
M971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(D)I>G1O
M<RP@:&]G>2!T]G+V;&YI(&%K87)J82!<(B5S7"(M="!A;&-S;W!O<G1J86EV
M86P@96=Y_'1T/R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R(")!<F=E;G3M
M;F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C4W"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(M9R;>EN>6]R<WKA9R(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")!<FUE;FEA;B`H05)-
M4T-)22TX*2(*;7-G<W1R("+V<FWI;GD@*$%235-#24DM."DB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R="(*;7-G<W1R(")-^W;I
M<WIE="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-3D*;7-G:60@(D%R=6)A(@IM<V=S='(@(D%R=6)A(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM
M<V=S='(@(E!O:&YP96DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*
M;7-G:60@(D%S8VEI($%R="(*;7-G<W1R(")!<V-I:2!R86IZ;VLB"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I9FEC
M(%)E9VEO;B(*;7-G<W1R("+!>G-I82]#<V5N9&5S+?-C9>%N:2!RZ6=I\R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,CD*;7-G:60@(D%S:R!F;W(@
M8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I
M;VYS/R(*;7-G<W1R("(B"B)+Z7)J96X@82!R96YD<WIE<B!M96=E<O5S[73I
M<W0@82!K87)B86YT87)TX7-I(&9E;&%D871O:R!E;';I9WKI<V4@96SU='0_
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,P.3D*;7-G:60@(D%S<VEG;FUE
M;G0@8V]L=6UN<R(*;7-G<W1R(")(;WIZX7)E;F1E;.ES:2!O<WIL;W!O:R(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@(D%T=&5M<'0@=&\@9&5L
M971E(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R(").96ULZ71E>O4@
M8W-O<&]R=&]T(&OM<^ER96QT(&UE9R!T]G+V;&YI+B(*"B,Z(&%D;6EN+W!E
M<FUS+V1E;&5T92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@
M;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(DYE;6SI=&5Z]2!J
M;V=O<W5L='/A9V]T(&OM<^ER96QT(&UE9R!T]G+V;&YI+B(*"B,Z(&%D;6EN
M+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N
M;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B3F5M;.ET97KU(&IO
M9V]S=6QT<^%G;W0@:^USZ7)E;'0@;65G(&UE9W;A;'1O>G1A=&YI+B(*"B,Z
M('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I9"`B071T96UP="!T
M;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R(").96ULZ71E
M>O4@:_9Z]G,@=.%R=&5R_&QE=&5T(&OM<^ER96QT(&UE9R!M96=VX6QT;WIT
M871N:2XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV-"!L
M:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,0HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=&=Z+G!H<#HX,PIM<V=I9"`B071T<FEB=71E<R(*;7-G
M<W1R(")4=6QA:F1O;G/A9V]K(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P.2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R(")A=6=U<WIT=7,B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,CD@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS
M9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B075S>G1RX6QI82(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U
M<W1R:6$B"FUS9W-T<B`B075S>G1R:6$B"@HC.B!L:6(O2&]R9&4O075T:"]C
M>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM
M87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)S<6PZ
M(&$@<WK\:W/I9V5S(&EM87`@8O5V[73I<R!N96T@=&%LX6QH873S+B(*"B,Z
M(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER
M=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E
M<RXB"FUS9W-T<B`B(@HB075T:%]C>7)U<SH@82!HX71TZ7)S>F]L9^%L=&%T
MX7,@;F5M(')E;F1E;&ME>FEK(&$@:^UVX6YT(&OI<&5S<^EG96MK96PN(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C
M>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R(")!=71H7V-Y<G5S.B!A('-Z_&MSZ6=E<R!I;6%P(&+U=NUTZ7,@;F5M
M('1A;.%L:&%T\RXB"@HC.B!L:6(O2&]R9&4O075T:"]F='`N<&AP.C,V"FUS
M9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S
M=VET8V@N(@IM<V=S='(@(B(*(D%U=&A?9G1P.B!A('-Z_&MSZ6=E<R!F='`@
M8O5V[73I<R!N96T@=&%LX6QH873S+B!&;W)D[71S82!L92!A(%!(4"UT(&%Z
M("TM(@HB96YA8FQE+69T<"!O<&-I\W9A;"XB"@HC.B!L:6(O2&]R9&4O075T
M:"]I;6%P+G!H<#HV-`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:6UA<#H@82!S
M>OQK<^EG97,@:6UA<"!B]7;M=.ES(&YE;2!T86SA;&AA=/,N(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q
M=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H
M7VMR8C4Z(&$@<WK\:W/I9V5S(&MR8C4@8O5V[73I<R!N96T@=&%LX6QH873S
M+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B075T
M:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T
M:79E($1I<F5C=&]R>2(*;7-G<W1R(")!=71H7VQD87`Z(&YE;2!H;WIH873S
M:R!LZ71R92#Z:B!F96QH87-Z;N%L\VL@06-T:79E($1I<F5C=&]R>2!E<V5T
MZ6XB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS-3<*;7-G:60@(D%U
M=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@
M06-T:79E($1I<F5C=&]R>2(*;7-G<W1R(")!=71H7VQD87`Z(&9E;&AA<WIN
MX6SS:R!N96T@=/9R]FQH973U:R!!8W1I=F4@1&ER96-T;W)Y(&5S973I;B(*
M"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C8S"FUS9VED(")!=71H7VQD
M87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B075T:%]L9&%P.B!A('-Z_&MSZ6=E<R!,1$%0(&+U=NUTZ7,@;F5M('1A
M;.%L:&%T\RXB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS,SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S
M97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R
M(")!=71H7VQD87`Z("5S(&9E;&AA<WINX6SS(&AO>GKA863A<V$@;F5M('-I
M:V5R_&QT+B!!('-Z97)V97(@=N%L87-Z83H@(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A
M<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A
M<#H@)7,@9F5L:&%S>F[A;/,@=/9R;.ES92!N96T@<VEK97+\;'0B"@HC.B!L
M:6(O2&]R9&4O075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS9W-T
M<B`B075T:%]L9&%P.B`E<R!F96QH87-Z;N%L\R!A9&%T86EN86L@;65G^FKM
M=.%S82!N96T@<VEK97+\;'0B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H
M<#HT,#4*;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T
M('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B075T
M:%]L9&%P.B!A(&9E;&AA<WINX6SS:R!N96T@;?-D;W/M=&AA=/-K($%C=&EV
M92!$:7)E8W1O<GD@97-E=.EN(@H*(SH@;&EB+TAO<F1E+T%U=&@O;6-A;"YP
M:'`Z-#8*;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VUC86PZ(&$@<WK\:W/I9V5S
M($U#04P@8O5V[73I<R!N96T@=&%LX6QH873S+B(*"B,Z(&QI8B](;W)D92]!
M=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@
M<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7W-M
M8F%U=&@Z(&$@<WK\:W/I9V5S('-M8F%U=&@@8O5V[73I<R!N96T@=&%LX6QH
M873S+B(*"B,Z(&QI8B](;W)D92])34%0+T%D;6EN+G!H<#HQ,#8*;7-G:60@
M(D%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T
M<B`B3F5M('-I:V5R_&QT(&%Z($E-05`@<WIE<G9E<F5N('9A;/,@9F5L:&%S
M>F[A;/-A>F]N;W/M=.%S+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDP"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS
M9W-T<B`B02!F96QH87-Z;N%L\V%Z;VYO<^UTX7,@;F5M('-I:V5R_&QT+B(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!=71H96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S='(@(D$@9F5L
M:&%S>F[A;/-A>F]N;W/M=.%S(&YE;2!S:6ME<OQL="X@)7,B"@HC.B!L:6(O
M2&]R9&4O075T:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B075T:&5N=&EC871I
M;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS9W-T<B`B02!F96QH
M87-Z;N%L\R!A>F]N;W/M=.%SX70@82!2041)55,@<WIE<G9E<B!E;'5T87/M
M=&]T=&$N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@X,@IM<V=I9"`B075T:&5N
M=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(DYE;2!S
M:6ME<OQL="!A>B!&5%`@<WIE<G9E<FAE>B!V86SS(&9E;&AA<WINX6SS87IO
M;F]S[73A<RXB"@HC.B!L:6(O5D93+W-M8BYP:'`Z-S`*;7-G:60@(D%U=&AE
M;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B
M3F5M('-I:V5R_&QT(&%Z(%--0B!S>F5R=F5R96X@=F%L\R!F96QH87-Z;N%L
M\V%Z;VYO<^UTX7,N(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW
M-0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`B02!R96YD96QK
M97KI<W)E(.%L;/,@;65Z]6LZ(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C,Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R
M(")!>F5R8F%J9'ISX6XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*
M;7-G:60@(D)/1D@@17AC=7-E<R(*;7-G<W1R(")!(&=O;F]S>B!R96YD<WIE
M<F=A>F1A(&UE;G1SZ6=E:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS
M9W-T<B`B2.%T=.ER(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R
M(")(X71TZ7(@<WKM;B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C@Q
M"FUS9VED(")"860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(DYE;2!M
M96=F96QE;/4@:V5R8F5R;W,@:F5L<WKS+B(*"B,Z(&QI8B](;W)D92]!=71H
M+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM
M<V=S='(@(DYE;2!M96=F96QE;/4@:V5R8F5R;W,@9F5L:&%S>F[A;/-NZ78N
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0U(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M,@IM<V=I9"`B0F%H86UA<R(*;7-G<W1R(")"86AA;>%K(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C,X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H
M<F%I;B(*;7-G<W1R(")"86AR96EN(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#`*;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(F)A
M;'1I("A)4T\M.#@U.2TQ,RDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H(@IM<V=S='(@
M(D)A;F=L861E<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(D)A<F)A9&]S
M(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L('!H<"UF;W)M870*
M;7-G:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U
M;F0N(@IM<V=S='(@(D$@9W)A9FEK=7,@X6QL;VWA;GEO:R!<(B5S7"(@86QK
M]FYY=G3A<F$@;F5M('1A;.%L:&%T\RXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*;7-G:60@(D)A<V5L:6YE
M(@IM<V=S='(@(F%L87!V;VYA;&]N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C0Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L87)U<R(*;7-G<W1R
M(")&96CI<F]R;W-Z;W)S>N%G(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C,U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R(")"
M96QG:75M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4P(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV,PIM<V=I9"`B0F5L:7IE(@IM<V=S='(@(D)E;&EZ92(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HT,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@
M(D)E;FEN(@IM<V=S='(@(D)E;FEN(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C0Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R
M(")"97)M=61A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0V(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@(D)H=73A;B(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")"
M:7)T:&1A>2(*;7-G<W1R(")3>OQL973I<VYA<"(*"B,Z(&QI8B](;W)D92]"
M;&]C:R]#;VQL96-T:6]N+G!H<#HS-C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N
M(@IM<V=S='(@(D$@7"(E<UPB(&)L;VMK(&$@7"(E<UPB('!R;V=R86UM86P@
M;F5M('1A;.%L:&%T\RXB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI
M;F,Z.3`*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(DOI<&5R;GGU
M<NES>B!B9>%L;.UTX7,B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI
M;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B2^EP97)N>?5RZ7-Z
M('3M<'5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S='(@(F;I;&OV=NER(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C0S(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HS-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B
M0F]L:79I82(*;7-G<W1R(")";VSM=FEA(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(P-PIM<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@(DME9'9E
M;F,@=V5B8^UM96LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(P"FUS9VED(")";W)D97(B"FUS9W-T<B`B2V5R
M970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G<W1R(")+97)E='9A
M<W1A9W/A9SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(Q"FUS9VED(")";W)D97)S(@IM<V=S='(@(DME<F5T
M96LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C,W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8P"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(D)O
M<WIN:6$M2&5R8V5G;W9I;F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M.38*;7-G:60@(D)O=&@B"FUS9W-T<B`B36EN9&ME='3U(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C0X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HS.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]T
M<W=A;F$B"FUS9W-T<B`B0F]T<W=A;F$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(R"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@(D)O='1O;2(*
M;7-G<W1R(")A;'5L(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R(")"
M;W5V970M<WII9V5T(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0T(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(D)R87KM;&EA
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#$*;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G
M<W1R(")"<FET($EN9&EA:2WS8V7A;FD@5&5R_&QE="(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HT,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R=6YE
M:2!$87)U<W-A;&%M(@IM<V=S='(@(D)R=6YE:2!$87)U<W-A;&%M(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,W(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HT,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I
M9"`B0G5L9V%R:6$B"FUS9W-T<B`B0G5L9^%R:6$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"FUS9VED(")"=6QL971E
M9"!,:7-T(@IM<V=S='(@(D9E;'-O<F]LX7,B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)K:6YA($9A
M<V\B"FUS9W-T<B`B0G5R:VEN82!&87-O(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C,Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R=6YD:2(*;7-G
M<W1R(")"=7)U;F1I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0T
M-@IM<V=I9"`B0TU3(@IM<V=S='(@(E=E8F]L9&%L(&MA<F)A;G1A<G3A<R(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED(")#
M4D,B"FUS9W-T<B`B0U)#(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU.3@*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM<V=S='(@
M(D$@=&%N^G/M=';A;GEV:7-S>F%V;V[A<VD@;&ES=.%K("A#4DPI(&/M;65I
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@
M(D-E;&QA('1U;&%J9&]N<^%G;VLB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,34Q"FUS9VED(")#86-H92!I;FET('=A<R!N;W0@8V]M<&QE
M=&5D+B(*;7-G<W1R(")!(&-A8VAE(&EN:6-I86QI>N%LX7-A(&YE;2!F96IE
M>O5D]G1T(&)E+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT.#4@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-#`*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$U-PIM<V=I9"`B0V%L96YD87(B"FUS9W-T
M<B`B3F%P=.%R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S
M-0IM<V=I9"`B0V%L;2(*;7-G<W1R(").>75G;V1T(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$R."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(D-A;6)O
M9&EA(@IM<V=S='(@(DMA;6)O9'IS82(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HV,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-A;65R;V]N(@IM<V=S
M='(@(DMA;65R=6XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR
M,`IM<V=I9"`B0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY
M+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B3F5M('-I
M:V5R_&QT(&$@:F5L<WKS="#A=.%L;.UT86YI+"!F;W)D=6QJ;VX@82!R96YD
M<WIE<F=A>F3A:&]Z+B(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z,S4P"B,L('!H
M<"UF;W)M870*;7-G:60@(D-A;B!N;W0@=W)I=&4@=&\@9FEL92!<(B5S7"(B
M"FUS9W-T<B`B02AZ*2!<(B5S7"(@X6QL;VWA;GD@;F5M(.UR:&%T\RXB"@HC
M.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T
M97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B02!K_&QS
M]2!F96QH87-Z;N%L\VMA<&-S;VQA="UK97IE;/5K(&YE;2!A9&UI;FES>G1R
MX6QH873S:RXB"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,C,U(&QI
M8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,S$Y"B,L('!H<"UF;W)M870*;7-G
M:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM<V=S='(@
M(D$@:_9V971K97KU($E-05`@<WIE<G9E<B!N96T@Z7)H973U(&5L.B`E<R(*
M"B,Z(&QI8B]&:6QE+T-35BYP:'`Z-#0V"B,L('!H<"UF;W)M870*;7-G:60@
M(D-A;B=T(&]P96X@9FEL92!<(B5S7"(N(@IM<V=S='(@(D$H>BD@7"(E<UPB
M(.%L;&]MX6YY(&YE;2!N>6ET:&%T\R!M96<N(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C4Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT.`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V%N861A(@IM
M<V=S='(@(DMA;F%D82(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,2!A9&UI;B]U
M<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN
M8SHQ,2!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,@IM<V=I9"`B0V%N8V5L
M(@IM<V=S='(@(DWI9W-E(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R
M(")-Z6=S92!K_&QD]FL@:&EB86IE;&5N=.ES="(*"B,Z(&QI8B]61E,O9G1P
M+G!H<#HS,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`B02AZ*2!<(B5S7"(@X6QL;VWA;GD@;F5M
M('3V<O9L:&5T]2XB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HT-@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L
M3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*;7-G:60@(D-A;FYO="!F:6YD
M(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F5M('1A;.%L:&%T
M\R!A>B!I9&5I9VQE;F5S(.%L;&]MX6YY;VMA="!T87)T86QM87KS(&%L:_9N
M>79TX7(N(@H*(SH@;&EB+U9&4R])4T]7<FET97(N<&AP.CDQ"FUS9VED(")#
M86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N
M(@IM<V=S='(@(D$@)W1A<F=E=$9I;&4G('!A<F%MZ71E<B!M96=A9.%S82!N
MZ6QK_&P@;F5M(&9O;'ET871H871J=6LN(@H*(SH@;&EB+U9&4R]F='`N<&AP
M.C,Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I<F5C
M=&]R>2!<(B5S7"(N(@IM<V=S='(@(D$H>BD@7"(E<UPB(&%L:_9N>79TX7(@
M;F5M('3V<O9L:&5T]2XB"@HC.B!L:6(O2&]R9&4O1&%T851R964N<&AP.C$R
M."!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HV.#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM
M<V=S='(@(DYE;2!T]G+V;&AE=/4L("5D(&%L8W-O<&]R=&IA('9A;BXB"@HC
M.B!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HV,#@*;7-G:60@(B(*(D-A
M;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@
M<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G
M<W1R("(B"B)!>B#Z:B!S;W)B87)E;F1E>NES(&YE;2!L96AE='/I9V5S+"!A
M(&UE9V%D;W1T(&%D871O:R!S>N%M82!N96T@96=Y97II:R!A("(*(G3A<F]L
M=&%KZ79A;"XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D
M(&YU;6)E<BXB"FUS9W-T<B`B02!M96=A9&]T="!S>N%M<F$@;F5M(&O\;&1H
M973U(&5L(&%Z(/QZ96YE="XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#87!E(%9E<F1E(@IM<V=S='(@
M(EKV;&0M9F]K:2US>FEG971E:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*;7-G:60@(D-A<'1I;VXB"FUS
M9W-T<B`BP6)R87-Z]G9E9R(*"B,Z(&QI8B].970O4TU3+V=E;F5R:6-?<VUT
M<"YP:'`Z,3`T"FUS9VED(")#87)R:65R(@IM<V=S='(@(E-Z;VQGX6QT873S
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS"FUS9VED(")#871E9V]R
M:65S(&%N9"!,86)E;',B"FUS9W-T<B`B2V%T96?S<FGA:R#I<R!J96SV;.ES
M_&LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,U(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX-@IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B2V%J;>%N+7-Z
M:6=E=&5K(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B36]B:6P@=&5L969O;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C4*;7-G:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G<W1R(")#96QL871U
M;&%J9&]N<^%G;VLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R(")#
M96QL82!B96QS]2!M87)G\SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I
M97,B"FUS9W-T<B`B0V5L;&%T=6QA:F1O;G/A9V]K(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@
M<W!A8VEN9SHB"FUS9W-T<B`B0V5L;.%K(&OV>O9T=&D@<NES.B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,C<X"FUS9VED(")#96QL<&AO;F4B"FUS9W-T
M<B`B36]B:6P@=&5L969O;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q
M"FUS9VED(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*;7-G<W1R(")K96QT82`H
M25-/+3@X-3DM,30I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(FOV
M>NEP(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4T(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@
M(DOV>NEP+6%F<FEK86D@2_9Z=.%R<V%SX6<B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X,@IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM
M,BDB"FUS9W-T<B`B:V5L970M975R\W!A:2`H25-/+3@X-3DM,BDB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B0V5R=&EF:6-A
M=&4@1&5T86EL<R(*;7-G<W1R(")!('1A;OIS[71VX6YY('+I<WIL971E:2(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C$R"FUS9VED(")#97)T
M:69I8V%T92!/=VYE<B(*;7-G<W1R(")!('1A;OIS[71VX6YY('1U;&%J9&]N
M;W-A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@
M(D-E<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(E1A;OIS[71VX6YY(&9E
M;&AA<WINX6SA<VD@:7+A;GEE;'9E:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B0VAA9"(*;7-G<W1R
M(")#<^%D(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@IM<V=I9"`B0VAA;F=E(@IM
M<V=S='(@(E;A;'1O>G1A=.%S(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C,Q"FUS9VED(")#:&%N9V4@66]U<B!087-S=V]R9"(*;7-G<W1R
M(")!(&IE;'-Z\R#A=.%L;.UTX7-A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C8Y"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@
M=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y
M;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B07H@UFX@X6QT86P@96QK_&QD]G1T
M(&QE=F5L96ME;B!S>F5R97!L]2!NZ78@Z7,@8^UM(&UE9W;A;'1O>G1A=.%S
M82XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*;7-G:60@
M(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W
M:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#;VYT86-T('EO
M=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB02!J96QE;B!K;VYF:6=U
M<N%C:?-B86X@;F5M(&QE:&5T<^EG97,@82!J96QS>F%V86L@;?-D;W/M=.%S
M82X@1F]R9'5L:F]N(&$@(@HB<F5N9'-Z97)G87IDX6AO>BXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(W"FUS
M9VED(")#:&%R(@IM<V=S='(@(DMA<F%K=&5R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#
M:&5C7VL@3&EN:RXN+B(*;7-G<W1R("),:6Y?:V5L;&5N]7)ZZ7,N+BXB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3D@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C4S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS
M9VED(")#:&EL92(*;7-G<W1R(")#:&EL92(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HV,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S
M='(@(DOM;F$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B
M0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(FOM;F%I+"!E
M9WES>F5R^W/M=&5T="`H1T(R,S$R*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@T"FUS9VED(")#:&EN97-E(%1R861I=&EO;F%L("A":6<U*2(*;7-G
M<W1R(")K[6YA:2P@:&%G>6]MX6YY;W,@*$)I9S4I(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V%P<"YI;F,Z-PIM<V=I9"`B0VAO;W-E($%P<&QI8V%T:6]N.B(*
M;7-G<W1R(")6X6QA<W-Z;VX@:VD@96=Y(&%L:V%L;6%ZX7-T.B(*"B,Z(&QI
M8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C<P"FUS9VED(")#:&]O<V4@82!P
M87-S=V]R9"(*;7-G<W1R(")6X6QA<W-Z;VX@:F5L<WKS="(*"B,Z(&QI8B](
M;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")#:&]O<V4@82!U<V5R
M;F%M92(*;7-G<W1R(")6X6QA<W-Z;VX@96=Y(&9E;&AA<WINX6SS;F5V970B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`R"FUS9VED(")#:&]O<V4@
M:&]W('1O(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(E;A;&%S<WIA(&MI(&$@
M9.%T=6UO:R!M96=J96QE;NUTZ7-I(&9O<FWA:N%T.B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G
M:60@(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S
M*2(*;7-G<W1R(")6X6QA<W-Z82!K:2!A(&9E;'-O<F]LX7,@=.UP=7/A="`H
M<WKA;6]Z;W1T(&QI<W3A:V[A;"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#:')I<W1M87,@27-L86YD
M(@IM<V=S='(@(DMA<N%C<V]N>2US>FEG971E:R(*"B,Z(&QI8B]61E,N<&AP
M.CDQ-"!L:6(O3F5T+U--4RYP:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G:60@
M(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R(")!
M*'HI("5S(&-L87-S(&1E9FEN[6-I\VIA(&YE;2!T86SA;&AA=/,N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*;7-G:60@
M(D-L96%R(@IM<V=S='(@(D1E<OQL="(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E
M('1A9W,B"FUS9W-T<B`B5/9R;&D@87H@35-/9F9I8V4@=&%G96ME="(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*;7-G:60@(D-L96%R(%%U97)Y(@IM
M<V=S='(@(D$@;&5KZ7)D97KI<R!T]G)LZ7-E(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE
M87(@;W5T('5S97(Z("5S(@IM<V=S='(@(B5S(&9E;&AA<WINX6SS('3V<FSI
M<V4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3$*;7-G
M:60@(D-L96%R('5S97(B"FUS9W-T<B`B02!F96QH87-Z;N%L\R!T]G)LZ7-E
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@
M(D-L96%R('5S97(@9&%T82(*;7-G<W1R(")!(&9E;&AA<WINX6SS(&%D871A
M:6YA:R!T]G)LZ7-E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,34*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B17-T
MZ7)E(&1E<OQL="#I9R(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN
M=&5N86YC92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G
M<W1R(")!(&9O;'ET873A<VAO>B!K871T:6YT<V]N(&%Z(&5GZ7)R96PB"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B
M0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R(")#;&EC:V%T96QL('-Z;VQG
MX6QT873A<R!(5%10+6X@:V5R97-Z=/QL(@H*(SH@<V5R=FEC97,O:V5Y8F]A
M<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED
M(")#;&]S92!7:6YD;W<B"FUS9W-T<B`B07H@86)L86L@8F5ZX7+A<V$B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U,0IM<V=I9"`B0VQO=61S(@IM<V=S
M='(@(D)O<G5L="#I9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C$V"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`B4F5G
M9V5L(&9E;&CU<R!I9/4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(D9E;&CU<R!I
M9/4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C4V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8T"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R(")+
M\VMU<WHM<WII9V5T96LB"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N
M:6YC.C(S"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@(E3\;G1E
M<W/\:R!E;"!A>B!O;&1A;'/S(&UE;OQT(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P
M<V5D(&)O<F1E<G,B"FUS9W-T<B`BUG-S>F5ZX7)T(&ME<F5T96LB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C4W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED
M(")#;VQO;6)I82(*;7-G<W1R(")+;VQU;6)I82(*"B,Z(&QI8B]";&]C:R]C
M;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED
M(")#;VQO<B(*;7-G<W1R(")3>NUN(@H*(SH@;&EB+TAO<F1E+T)L;V-K+T-O
M;&QE8W1I;VXN<&AP.C,S,2!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP
M:'`Z,S,R"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU
M,#,@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,@IM<V=I9"`B
M0V]L;W(@4&EC:V5R(@IM<V=S='(@(E-Z[6YVX6QA<WIT\R(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR.#,R"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM
M<V=S='(@(E-Z[6YVX6QA<WITX7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`B
M3W-Z;&]P;VLZ(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-3`*;7-G:60@
M(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B07H@;W-Z;&]P;VL@8^UM96DB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8V"FUS9VED(")#;VUI8W,B
M"FUS9W-T<B`B5FEC8V5K(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(U"FUS
M9VED(")#;VUM86YD(@IM<V=S='(@(E!A<F%N8W,B"@HC.B!A9&UI;B]C;61S
M:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B4&%R
M86YC<^ER=&5L;65Z]2(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q
M,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R(")-96=J96=Y>NES(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G:60@(D-O;6UO;B!.86UE
M(@IM<V=S='(@(D[I=BP@96QN979E>NES(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$S,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(D-O;6]R;W,B"FUS
M9W-T<B`B0V]M;W)E+7-Z:6=E=&5K(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`B0^EG
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP=71E
M<G,B"FUS9W-T<B`B4WKA;>UT\V?I<&5K(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(X-@IM<V=I9"`B0V]N9&ET:6]N(@IM<V=S='(@(DED
M]6KA<N%S:2!H96QY>F5T(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-38*
M;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B263U:N%RX7-I(&AE;'EZ970B
M"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A
M=&EO;B!$:69F97)E;F-E<R(*;7-G<W1R(")+_&SV;F)SZ6=E:R!A(&MO;F9I
M9W5RX6-I\V)A;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#8*;7-G
M:60@(D-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R
M='!H;VYE<R!A;F0@3W5T;&]O:RXB"FUS9W-T<B`B(@HB2^EZ:7-ZX6WM=/-G
MZ7!E:VME;"P@;VMO<W1E;&5F;VYO:VMA;"P@3W5T;&]O:VMA;"!V86SS(&%D
M871S>FEN:W)O;FEZX6SA<R`B"B)K;VYF:6=U<N%C:?-J82(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ,S4*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@
M;W5T(&]F(&1A=&4N(@IM<V=S='(@(D$@:V]N9FEG=7+A8VGS(&WA<B!N96T@
MZ7)VZ6YY97,N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B)7,@:V]N
M9FEG=7+A8VGS:F$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C4Q"FUS9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(D$@:F5L
M<WKS(&UE9V5R]7/M=.ES92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O(@IM<V=S='(@(DMO;F?S
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4S(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HV,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M-0IM<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H
M92(*;7-G<W1R(")+;VYG\VD@1&5M;VMR871I:W5S($OV>G3A<G-A<^%G(@H*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y-R!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`X"FUS9VED(")#;VYN96-T:6]N
M(&9A:6QE9"XB"FUS9W-T<B`B4VEK97)T96QE;B!A(&MA<&-S;VQA="XB"@HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DW(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#@*;7-G:60@(D-O;FYE8W1I;VX@
M9F%I;&5D.B`B"FUS9W-T<B`B4VEK97)T96QE;B!A(&MA<&-S;VQA=#H@(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-SDP"FUS9VED(")#;VYN96-T
M:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@
M(D$@;GEI;';A;F]S(&MU;&-S;VL@<WIE<G9E<F4@96QU=&%S[71J82!A(&MA
M<&-S;VQA=&]T+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<Y,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE
M('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R(")!
M(&YY:6QVX6YO<R!K=6QC<V]K('-Z97)V97)E(&5L=71A<^UT:F$@82!K87!C
M<V]L871O="X@3VMA.B`E<R`H)7,I(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@W
M-@IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS
M9W-T<B`B4VEK97)T96QE;B!A>B!&5%`@<WIE<G9E<G)E;"!V86SS(&MA<&-S
M;VQA="XB"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`V-PIM<V=I9"`B
M0V]N=&%C=',B"FUS9W-T<B`B4&%R=&YE<F5K(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S
M=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S
M='(@(D$@<&%R=&YE<F5K970@<VEK97)E<V5N(&AO>GKA861T=6L@82!C[6UJ
M96=Y>NEKZ6AE>BXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H
M<#HV,`IM<V=I9"`B0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@
M(@IM<V=S='(@(D$@=/9M]G+M=&5T="#A;&QO;>%N>2!T[7!U<V$Z("(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C4V(&QI8B](;W)D92]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]T9WHN<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1E;G1S(&]F
M(%PB)7-<(B(*;7-G<W1R(")<(B5S7"(@=&%R=&%L;6$B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HR.2!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z,S,*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@(D9O;'ET873A<R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU."!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8*
M;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R(")#;V]K+7-Z:6=E=&5K(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,R"FUS9VED(")#;V]K:64B"FUS
M9W-T<B`B4_QT:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR,0IM<V=I9"`B0V]P>2(*;7-G<W1R(")-X7-O
M;&IU:R#A="(*"B,Z(&QI8B]61E,O<VUB+G!H<#HT-S(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@(D$@;>%S;VSA<R!N
M96T@<VEK97+\;'0Z("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T
M<B`B02!K:6IE;/9L="!RZ7-Z(&WA<V]LX7-A(@H*(SH@;&EB+TYE="]335,O
M=VEN7VAT='`N<&AP.C$W,"!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3DU
M"FUS9VED(")#;W-T($E$(@IM<V=S='(@(E-ZX6ULX7KA<VD@87IO;F]S[73S
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8S(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HV,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R(")#;W-T82!2:6-A(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4W(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HV,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I
M9"`B0V]T92!D)TEV;VER92(*;7-G<W1R(")%;&5FX6YT8W-O;G1P87)T(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.3<W"FUS9VED(")#;W5L9"!N
M;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@(@IM<V=S='(@(DYE;2!S:6ME<OQL
M="!01U`M=F5L('1I=&MO<^UT86YI(&$@;&5V96QE=#H@(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z,3`U-0IM<V=I9"`B0V]U;&0@;F]T(%!'4"!S
M:6=N(&UE<W-A9V4Z("(*;7-G<W1R(")!(&QE=F5L970@;F5M('-I:V5R_&QT
M(%!'4"!A;.'M<N%S<V%L(&5L;.%T;FDZ("(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z,SDS"FUS9VED(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y
M<'0@;65S<V%G92XB"FUS9W-T<B`B02!L979E;&5T(&YE;2!S:6ME<OQL="!A
M>B!3+TU)344@<WIA8G;A;GD@<WIE<FEN="!T:71K;W/M=&%N:2XB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@;F]T
M(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(D$@;&5V96QE="!N96T@
M<VEK97+\;'0@4R]-24U%(&%LX>URX7-S86P@96QLX71N:2XB"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,B"FUS9W-T<B`B02!P
M87)T;F5R(&%D871A:70@;F5M('-I:V5R_&QT(&5L=.%R;VQN:2X@)7,B"@HC
M.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z.38@;&EB+TAO<F1E+T%U=&@O
M;&1A<"YP:'`Z,3(Q"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-3<*;7-G
M:60@(D-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(")!
M>B!,1$%0('-Z97)V97(@;F5M(.ER:&5T]2!E;"XB"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R(").96T@<VEK97+\;'0@96QL
M96[U<FEZ;FD@82!S>N%M;.%JX6X@<F5N9&5L:V5ZZ7-R92#A;&SS(/9S<WIE
M9V5T+B`E<R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-#$*;7-G:60@
M(D-O=6QD(&YO="!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(").
M96T@<VEK97+\;'0@87H@3$1!4"!S>F5R=F5R:&5Z(&MA<&-S;VSS9&YI+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@7"(E<UPB('5S:6YG
M($944#H@)7,B"FUS9W-T<B`B3F5M('-I:V5R_&QT(&$H>BD@7"(E<UPB('-Z
M97)V97)R96P@1E10(&MA<&-S;VQA=&]T(&9E;'9E;FYI.B`E<R(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,B"FUS9W-T<B`B3F5M('-I:V5R_&QT(&SI=')E:&]Z;FD@82!K]G)L97;I
M;&QI<W3A="X@)7,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,3(X
M"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@(@IM<V=S='(@
M(D%Z(&%D871O:R!01U`@=&ET:V]S[73A<V+S;"!T]G)TZ6[U(&1E:_-D;VSA
M<V$@;F5M('-I:V5R_&QT.B`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4R,PIM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N
M(@IM<V=S='(@(D%Z(&%D871O:R!3+TU)344@=&ET:V]S[73A<V+S;"!T]G)T
MZ6[U(&1E:_-D;VSA<V$@;F5M('-I:V5R_&QT+B(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R(")!('!A<G1N
M97(@=/9R;.ES92!N96T@<VEK97+\;'0N("5S(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R
M(")!(&OV<FQE=NEL;&ES=&$@=/9R;.ES92!N96T@<VEK97+\;'0N("5S(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="!<
M(B5S7"(N(@IM<V=S='(@(DYE;2!S:6ME<OQL="!T]G+V;&YI(&$H>BD@7"(E
M<UPB('-E='5P('5P9W)A9&4@<')O9W)A;6]T+B(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z,S@Q(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.CDU
M,PIM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@
M92UM86EL(&%D9')E<W,N(@IM<V=S='(@(DYE;2!S:6ME<OQL="!M96?A;&QA
M<.UT86YI(&$@8^UM>F5T="!E;6%I;"!C[6WI="XB"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#;W5L9"!N;W0@9F5T
M8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R(").96T@<VEK97+\
M;'0@8F5O;'9A<VYI(&$@=&5L:F5S(&/M;6IE9WEZZ6ME="XB"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N
M;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@
M(DYE;2!S:6ME<OQL="!B96]L=F%S;FD@82!T96QJ97,@:_9R;&5VZ6QL:7-T
MX70N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T-@IM
M<V=I9"`B0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I
M<W1R:6)U=&EO;B!L:7-T<RXB"FUS9W-T<B`B3F5M('-I:V5R_&QT(&)E;VQV
M87-N:2!A(&OV<FQE=NEL;&ES=.%K('1E;&IE<R!F96QS;W)O;.%SX70N(@H*
M(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV
M.`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z
M.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E
M9WD@7"(E<UPB+B(*;7-G<W1R(")!*'HI(%PB)7-<(B!S=')A=.EG:6$@;F5M
M('1A;.%L:&%T\RXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B02AZ*2!<
M(B5S7"(@86QK]FYY=G3A<B!N96T@:&]Z:&%T\R!LZ71R92XB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO="!O8G1A
M:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@(D$@
M;GEI;';A;F]S(&MU;&-S;W0@;F5M('-I:V5R_&QT(&UE9W-Z97)E>FYI(&$@
M:W5L8W-S>F5R=F5R<O5L+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S='(@
M(DYE;2!S:6ME<OQL="!<(B5S7"(M="#M<N%S:2!CZ6QL86P@;65G;GEI=&YI
M+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*(SH@;&EB+TYE="]3
M35,O=VEN7VAT='`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B3F5M('-I:V5R_&QT("5S+70@;65G
M;GEI=&YI+B(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z-#(P"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E
M7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(D$@)7,@:V%R8F%N=&%R=.%S:2!M
M;V1U;"!N96T@;GEI=&AA=/,@;65G(@H*(SH@;&EB+U9&4R])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T
M<B`B02AZ*2!<(B5S7"(@86QK]FYY=G3A<B!N96T@;GEI=&AA=/,@;65G+B(*
M"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ,3$@;&EB+TAO<F1E+T=R
M;W5P+VQD87`N<&AP.C$T-`HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z
M,C,W(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@;&EB+TAO<F1E
M+T=R;W5P+VQD87`N<&AP.C4Q-B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z
M-C$R"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV-38@;&EB+TAO<F1E
M+T=R;W5P+VQD87`N<&AP.C8Y.0IM<V=I9"`B0V]U;&0@;F]T(')E86-H('1H
M92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B07H@3$1!4"!S>F5R=F5R(&YE;2#I
M<FAE=/4@96PN(@H*(SH@;&EB+U9&4R]/8FIE8W0N<&AP.C(T,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T<B`B)7,@
M;F5M(&]L=F%S:&%T\RXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HX-0IM<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F
M;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB
M9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T
M('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE
M;'`N(@IM<V=S='(@(B(*(DYE;2!S:6ME<OQL="!A(&OM=N%N="!F96QH87-Z
M;N%L\R!J96QS>F%VX70@X73A;&SM=&%N:2X@07H@;65G861O='0@861A=&]K
M("(*(FYE;2!V86=Y(&YE;2!T96QJ97-E;B!F96QE;&YE:R!M96<N(%!R\V+A
M;&IA(/IJ<F$L('9A9WD@:&$@=&]VX6)B:2`B"B)S96?M='/I9W)E('9A;B!S
M>OQK<^EG92P@9F]R9'5L:F]N(&$@<F5N9'-Z97)G87IDX6AO>BXB"@HC.B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`W(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS,S@*(SH@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,W-2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S@Q"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#<*
M;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B3F5M('-I
M:V5R_&QT(&UE9VAA=.%R;WIN:2!A>B!E;.ERZ7-I(&IO9V]S=6QT<^%G;VMA
M="`H04-,*2(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR
M-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&%D
M9')E<W,@8F]O:RX@)7,B"FUS9W-T<B`B3F5M('-I:V5R_&QT(&)E;VQV87-N
M:2!A(&/M;6IE9WEZZ6ME="X@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3F5M
M('-I:V5R_&QT(&)E;VQV87-N:2!A(&OV<FQE=NEL;&ES=.%T+B`E<R(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L
M:7-T<RX@)7,B"FUS9W-T<B`B3F5M('-I:V5R_&QT(&)E;VQV87-N:2!A(&OV
M<FQE=NEL;&ES=.%K870N("5S(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C$Y-R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,C$W"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C$*;7-G
M:60@(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B
M"FUS9W-T<B`B3F5M('-I:V5R_&QT(&UE9VAA=.%R;WIN:2!A('-Z97)V97(@
M:^EP97-SZ6=E:70B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"FUS
M9VED(")#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(DYE;2!S:6ME<OQL="!V:7-S>F'A;&SM=&%N:2!E>B!E<F5D971I(&MO;F9I
M9W5RX6-I\W0N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDO8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`B02AZ*2!<(B5S7"(@86QK]FYY
M=G3A<B!N96T@=/9R]FQH973U+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DYE;2!S:6ME<OQL="!E;&UE;G1E
M;FD@)7,@:V]N9FEG=7+A8VGS="XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3D*;7-G:60@(D-O=6QD
M(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B3F5M
M('-I:V5R_&QT(&5L;65N=&5N:2!A(&)A8VMU<"!K;VYF:6=U<N%C:?-T+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S
M(@IM<V=S='(@(DYE;2!S:6ME<OQL="!E;&UE;G1E;FD@82!B86-K=7`@:V]N
M9FEG=7+A8VGS=#H@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U
M<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(").96T@<VEK97+\
M;'0@96QM96YT96YI(&$H>BD@7"(E<UPB('-E='5P('5P9W)A9&4@<')O9W)A
M;6]T+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U
M<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(DYE;2!S:6ME<OQL="!E;&UE;G1E
M;FD@82AZ*2`E<R!B86-K=7`@:V]N9FEG=7+A8VGS="XB"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C<W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O
M=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C
M86X@96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T
M:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@
M8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*(D$H>BD@)7,@:V]N9FEG=7+A8VGS
M<R#A;&QO;>%N>70@;F5M('-I:V5R_&QT(&5L;65N=&5N:2X@5F%G>2!H87-Z
M;N%L:F$@82`E<R`B"B)O;&1A;&]N(&QE=O4@;&5H973U<^EG96ME="P@=F%G
M>2!MX7-O;&IA(.%T(&%Z(&%LX6)B:2!K\V1O="!I9&4Z("5S+B(*"B,Z(&QI
M8B](;W)D92]!=71H+VQD87`N<&AP.C$T,PIM<V=I9"`B0V]U;&0@;F]T('-E
M87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(D%Z($Q$05`@<WIE<G9E
M<F5N(&YE;2!S:6ME<OQL="!E;';I9V5Z;FD@82!K97)E<^ES="XB"@HC.B!L
M:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<
M(BXB"FUS9W-T<B`B7"(E<UPB(&YE;2!V;VQT('3V<O9L:&5T]2XB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T
M<B`B02!P87)T;F5R(&%D871A:70@;F5M('-I:V5R_&QT(&WS9&]S[71A;FDN
M("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<R(*;7-G<W1R(").96T@<VEK97+\;'0@82!K]G)L97;I
M;&QI<W1A(&WS9&]S[73A<V$N("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C
M;VYF:6=U<F%T:6]N(&9O<B!<(B5S7"(Z("5S(@IM<V=S='(@(DYE;2!S:6ME
M<OQL="!E;&UE;G1E;FD@7"(E<UPB(&MO;F9I9W5RX6-I\VKA=#H@)7,B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<P"FUS9VED(")#;W5L9&XG="!F
M:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A
M<B!I<R!O<&5N+B(*;7-G<W1R(")!($UO>FEL;&$@;65N_'-O<B!N96T@=&%L
MX6QH873S+B!%;&QE;O5R:7IZ92P@:&]G>2!M96<@=F%N+64@;GEI='9A+B(*
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T
M:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S
M(@IM<V=S='(@(B(*(DYE;2!S:6ME<OQL="!<(B5S7"(@9F5L:&%S>F[A;/-N
M86L@:F]G;W-U;'1SX6=O="!A9&YI(&$H>BD@7"(E<UPB(&UA<'#A:&]Z.B`E
M(@HB<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(S"FUS9VED(")#;W5N
M=&5D('1E>'0B"FUS9W-T<B`B2V]R;.%T;W,@<WKV=F5G(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@(D-O=6YT<GDB"FUS9W-T
M<B`B3W)S>N%G(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W-0IM
M<V=I9"`B0V]U<G-E<R(*;7-G<W1R(")4X79O:W1A=.%S(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P
M"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B3.ET<F5H;WKA<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM
M<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R("),:6YK(&SI=')E:&]ZX7-A
M(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY-`IM
M<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R("+::B!LZ71R96AO>N%S
M82(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HU,B!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@(D-R96%T92!S
M=6(@9F]L9&5R<R(*;7-G<W1R(")!;&UA<'#A:R!LZ71R96AO>N%S82(*"B,Z
M(&QI8B](;W)D92]097)M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A=&]R(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(D%Z(&]B:F5K='5M(&SI=')E:&]Z\VKA;F%K
M(&IO9V]S=6QT<^%G86DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(Q-@IM
M<V=I9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(DAI=&5L:^%R='EA
M<WKA;2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#D@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<Y"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(DAO<G;A=&]R<WKA9R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*
M;7-G:60@(D-U8F$B"FUS9W-T<B`B2W5B82(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HR-@IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R(")*96QE
M;FQE9VD@-"!FX7II<R(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`IM<V=I
M9"`B0W5R<F5N="!397-S:6]N<R(*;7-G<W1R(")!(&IE;&5N;&5G:2!F96QH
M87-Z;N%L\VMA<&-S;VQA=&]K(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@
M;&EB+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS
M9W-T<B`B4&]N=&]S(&ED]2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@
M:7,B"FUS9W-T<B`B02!J96QE;FQE9VD@55),(@H*(SH@861M:6XO<V5S<VEO
M;G,N<&AP.C,U"FUS9VED(")#=7)R96YT(%5S97)S(@IM<V=S='(@(DIE;&5N
M;&5G:2!F96QH87-Z;N%L\VLB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U
M"FUS9VED(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`B2F5L96YL96=I(&ED
M]6KA<N%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V-`IM
M<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R(")!(&IE;&5N;&5G
M:2!I9/5JX7+A<VD@:&5L>7IE=#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM
M<V=S='(@(DIE;&5N;&5G:2!S=.UL=7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3$Q"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K
M<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B(@HB36EL>65N
M('!A<F%N8W-O:R!F=7-S86YA:R!L92!A=71O;6%T:6MU<V%N(&$@)7-B92!T
M]G)TZ6[U(&)E:F5L96YT:V5ZZ7-K;W(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED(")#=70B
M"FUS9W-T<B`B2VEVX6?A<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I;VXB"FUS9W-T
M<B`B02!K:6IE;/9L="!RZ7-Z(&MI=N%GX7-A(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C8W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV-@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S(@IM
M<V=S='(@(D-I<')U<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS
M9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R(")C:7)I;&P@*$M/23@M
M4BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B0WER:6QL
M:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`B8VER:6QL("A7:6YD;W=S+3$R
M-3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*;7-G:60@(D-Y<FEL
M;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R(")C:7)I;&PM=6MRX6X@
M*$M/23@M52DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8Y"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R(")#<V5H
M($OV>G3A<G-A<^%G(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0U,B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B1$0B
M"FUS9W-T<B`B1$0B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(W-@IM<V=I
M9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO
M<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B
M"B)$4TX@*&%D871F;W)RX7-L9>UR\R`M(&SA<V0Z(&AT='`Z+R]P96%R+G!H
M<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N(@HB9&(N:6YT<F\M
M9'-N+G!H<"DB"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS
M9VED(")$86EL>2(*;7-G<W1R(")N87!O;G1A(@H*(SH@861M:6XO9&%T871R
M964N<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@(D1A
M=&%4<F5E(&+V;F?I<WKU(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R-S0*
M;7-G:60@(D1A=&%B87-E($QO;VMU<"(*;7-G<W1R(")!9&%T8N%Z:7-B86X@
M=F%L\R!K97)E<^ES(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,#(@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(*;7-G:60@(D1A=&4B
M"FUS9W-T<B`B1.%T=6TB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R
M;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E:79E9"(*;7-G<W1R(")!(&)E
MZ7)K97KI<R!N87!J82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-SDS"FUS
M9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R(")$X71U;2!K:7;A;&%S>G3A
M<V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Q(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3$*;7-G:60@(D1A>2(*;7-G<W1R
M(")N87!P86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S
M='(@(D]S>FQO<"!T]G)LZ7-E(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0Q,R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#4Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(F1E8V5M8F5R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N
M9RYJ<SHQ-@IM<V=I9"`B1&5C:6UA;"!N=6UB97)S(@IM<V=S='(@(G-ZX6UO
M:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C`*;7-G:60@(D1E8W)E87-E($EN9&5N="(*;7-G<W1R(")"96ME>F3I<R!K
M:6IJ96)B(@H*(SH@;&EB+W!R969S+G!H<#HQ,3<@;&EB+TAO<F1E+U!R969S
M+U5)+G!H<#HQ.#<*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B06QA<.ER=&5L
M;65Z971T(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N
M="YI;F,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N
M="YI;F,Z-S<*;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B07H@86QA
M<.ER=&5L;65ZZ7,@<WIE<FEN=&D@<WKM;B(*"B,Z(&QI8B](;W)D92])9&5N
M=&ET>2YP:'`Z.38*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B
M06QA<.ER=&5L;65ZZ7,@<WIE<FEN=&D@87IO;F]S[73S(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C8W"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S
M='(@(D%L87#I<G1E;&UE>F5T="!S:&5L;"(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS,PIM<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`B1&5F:6[M
M8VGS:R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@;&EB+TAO<F1E+U!E<FUS
M+G!H<#HS,C8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,C(*(SH@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HT,SD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHS-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C<P('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z.3,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,38@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#(@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C<S"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY
M."!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*
M;7-G<W1R(")4]G)LZ7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S(*;7-G:60@(D1E;&5T92!#96QL(@IM
M<V=S='(@(D$@8V5L;&$@=/9R;.ES92(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,3DY(&%D;6EN+V=R;W5P<RYP:'`Z,C(W"FUS9VED(")$96QE=&4@1W)O=7`B
M"FUS9W-T<B`B02!C<V]P;W)T('3V<FSI<V4B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-#D*;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T<B`B
M02!N87!L\^%L;&]MX6YY('3V<FSI<V4B"@HC.B!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C<W(&QI8B](;W)D92]097)M<R]522YP:'`Z,3`Q"FUS9VED(")$
M96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R(")!(&IO9V]S=6QT<^%G('3V<FSI
M<V4B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G
M:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B3&5V96QE
M:R!T]G)LZ7-E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E(&-E;&PB"FUS9W-T<B`B
M02!C96QL82!T]G)LZ7-E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E(&-O;'5M;B(*
M;7-G<W1R(")!>B!O<WIL;W`@=/9R;.ES92(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z,30X"FUS9VED(")$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E
M;7!L871E(@IM<V=S='(@(E3V<O9L:OQK(&MI(&$@;65G;.EV]2!A;'1E<FYA
M=.UV('-A8FQO;G0B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP
M:'`Z-30*;7-G:60@(D1E;&5T92!M97-S86=E<R(*;7-G<W1R(")!(&QE=F5L
M96L@=/9R;.ES92(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-#(Q"B,L
M('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E
M<UPB(@IM<V=S='(@(EPB)7-<(B!J;V=O<W5L='/A9V%I;F%K('3V<FSI<V4B
M"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C0R-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B!A;F0@86YY
M('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T<B`B5/9R]FQJ_&L@7"(E<UPB(&IO
M9V]S=6QT<^%G86ET(.ES(&5N;F5K(&5S971L96=E<R!A;&-S;W!O<G1J86ET
M/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T<B`B02!S;W(@=/9R
M;.ES92(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I9&5N=&ET>2YI;F,Z
M,34*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET>2(*;7-G<W1R(")!
M(&MI=N%L87-Z=&]T="!A>F]N;W/M=/,@=/9R;.ES92(*"B,Z(&QI8B](;W)D
M92])34%0+T%#3"]R9F,T,S$T+G!H<#HU,PIM<V=I9"`B1&5L971E('-U8B!F
M;VQD97)S(@IM<V=S='(@(D%Z(&%L;6%P<.%K('3V<FSI<V4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*
M;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`B02!J
M96QE;FQE9VD@;W-Z;&]P('3V<FSI<V4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T
M92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B02!J96QE;FQE9VD@<V]R('3V
M<FSI<V4B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB
M)7-<(BXB"FUS9W-T<B`B5/9R]FQT_&L@82AZ*2!<(B5S7"(@<V5T=7`@=7!G
M<F%D92!P<F]G<F%M;W0N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4V,R!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(Q(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"FUS9VED(")$96QI=F5R
M>2!T:6UE(@IM<V=S='(@(D$@:^EZ8F5S[73I<R!I9&5J92(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HW,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1E
M;FUA<FLB"FUS9W-T<B`B1.%N:6$B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS
M9W-T<B`B061J;VX@;&7M<N%S="!A('!R;V)LZ6WA<O-L(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.CDT,B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,P"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R
M("),9>URX7,B"@HC.B!L:6(O2&]R9&4N<&AP.C$Y-PIM<V=I9"`B1&5T86EL
M<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R(")2Z7-Z;&5T
M96L@*&$@2&]R9&4@;&]G9N%J;&)A;B!I<R!M96=T86SA;&AA=/,I.B(*"B,Z
M(&QI8B](;W)D92YP:'`Z,C`Q"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L
M;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")!('+I<WIL
M971E:R!A(')E;F1S>F5R9V%Z9&$@<WKA;>%R82!KZ7-Z_&SU(&YA<&SS9N%J
M;&)A(&ME<OQL=&5K+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M,C$*;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S='(@(D9E:FQE<WITZ7,B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-`IM<V=I9"`B1&5W(%!O:6YT(@IM
M<V=S='(@(DAA<FUA='!O;G0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P
M,0IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")(
M87)M871P;VYT(&IE;&5N;&5G.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C$V"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R(")(87)M
M871P;VYT.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G
M<W1R(")B86QR\VP@:F]B8G)A(.URX7,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG
M:'0@=&\@;&5F="(*;7-G<W1R(")J;V)B<O-L(&)A;')A(.URX7,B"@HC.B!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S
M='(@(D/M;73A<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-S`*;7-G
M:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B07H@:63U<&]N
M=&]K870@,C0@\W+A<R!F;W)MX71U;6)A;B!J96QE;NUT<_QK(&UE9S\B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`P"FUS9VED(")$:7-P;&%Y($]P
M=&EO;G,B"FUS9W-T<B`B365G:F5L96[M=.ES:2!B9>%L;.UTX7-O:R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HX.0IM<V=I9"`B1&ES<&QA
M>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R(")!('+I<WIL971E<R!E;/5R
M96IE;'KI<R!M96=J96QE;NUTZ7-E(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HY,@IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R(")%
M;/5R96IE;'KI<R!M96=J96QE;NUTZ7-E("AR97#\;/5TZ7)I*2(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR.#`S"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*
M;7-G<W1R(")-96=J96QE;NUTZ7-I(&9O<FWA='5M(@H*(SH@;&EB+TAO<F1E
M+TU)344O341.+G!H<#HQ.3$*;7-G:60@(D1I<W!O<VET:6]N($YO=&EF:6-A
M=&EO;B(*;7-G<W1R("+)<G1E<^UTZ7,@82!KZ7IB97/M=&5T="!L97;I;"!S
M;W)SX7+S;"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(D1Z<VEB=71I(@H*
M(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,C(*;7-G:60@(D1O(&YO="!D
M96QE=&4B"FUS9W-T<B`B3F4@=/9R]FQJ_&LB"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O(&YO="!D:7)E8W1L>2!A8V-E<W,@
M;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@(D$@;6%I;G1E;F%N8V4N<&AP(&YE
M;2#I<FAE=/4@96P@:_9Z=F5T;&5N_&PN(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M='-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*
M;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N
M86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B07H@96QS
M]2!S;W(@82!M97KU:R!N979E:70@=&%R=&%L;6%Z>F$_($AA(&EG96XL(&IE
M;/9L:F4@:VD@97IT.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-CD*;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@(D1O;6EN
M:6MA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<S(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(D1O;6EN
M:6MA:2!+]GITX7)S87/A9R(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB
M"FUS9W-T<B`B3FEN8W,@;>EG(&QO9VEN(&YE=F4_($EGZ6YY96QJ96X@96=Y
M970N(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@U,@IM<V=I
M9"`B1&]W;FQO860B"FUS9W-T<B`B3&5T]FQTZ7,B"@HC.B!L:6(O2&]R9&4O
M34E-12]#;VYT96YT<RYP:'`Z.#4R"B,L('!H<"UF;W)M870*;7-G:60@(D1O
M=VYL;V%D("5S(@IM<V=S='(@(E3V;'1S_&L@;&4@)7,M="(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ-C(*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E
M9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(E3V;'1S
M_&L@;&4@4$A0('!R;V=R86T@9F]R;>%JX6)A;B!A>B!E;&OI<WK\;'0@:V]N
M9FEG=7+A8VGS="XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Q,0IM<V=I
M9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B3&5G]G)D_&SU(&QI<W1A(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G
M<W1R(")+X6+M=/-S>F5R96LB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HT,3,*;7-G:60@(D4M36%I;"(*;7-G<W1R(")E;6%I;"(*"B,Z(&QI8B].
M970O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--
M4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@
M=&AI<R!S97)V:6-E+B(*;7-G<W1R("(B"B)%;6%I;&+U;"!335,M:_QL9/4@
M;65G:&%J=/,L(&AA(&$@=&5L969O;G3A<G-A<^%G(&)I>G1O<^UT:F$@97IT
M(&$@(@HB<WIO;&?A;'1A=.%S="XB"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R
M(")(24)!(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<U(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G<W1R(")%8W5A9&]R(@H*(SH@
M;&EB+TAO<F1E+U!E<FUS+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHS-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,34@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C<R"FUS9VED(")%9&ET(@IM<V=S='(@(DWS9&]S[73A
M<R(*"B,Z(&QI8B](;W)D92]";&]C:R]522YP:'`Z-3`*;7-G:60@(D5D:70@
M0FQO8VLB"FUS9W-T<B`B0FQO:VL@;?-D;W/M=.%S(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H<#HR,C8*;7-G:60@(D5D:70@
M1W)O=7`B"FUS9W-T<B`B0W-O<&]R="!M\V1O<^UTX7,B"@HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C<V(&QI8B](;W)D92]097)M<R]522YP:'`Z,3`P
M"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`B2F]G;W-U;'1SX6<@
M;?-D;W/M=.%S(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM
M<V=I9"`B161I="!097)M:7-S:6]N<R(*;7-G<W1R(")*;V=O<W5L='/A9V]K
M(&WS9&]S[73A<V$B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S
M(@IM<V=S='(@(B5S(&IO9V]S=6QT<^%G86EN86L@;?-D;W/M=.%S82(*"B,Z
M('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N
M<R!F;W(Z(@IM<V=S='(@(DUE;'EI:R!O<&-I\VMA="!VX6QT;WIT87-S=6LZ
M(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS-C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@
M(EPB)7-<(B!J;V=O<W5L='/A9V%I;F%K(&WS9&]S[73A<V$B"@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@
M(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(B5S(&IO9V]S=6QT
M<^%G86EN86L@;?-D;W/M=.%S82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS-0IM<V=I9"`B161U8V%T:6]N(@IM<V=S='(@(D]K=&%TX7,B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C<S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED
M(")%9WEP="(*;7-G<W1R(")%9WEI<'1O;2(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B16P@4V%L=F%D
M;W(B"FUS9W-T<B`B4V%L=F%D;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L96UE;G0N
M+BXB"FUS9W-T<B`B16QE;2XN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R(")A>B`G
M;2<@8F5T^R!S>NEL97-SZ6=E(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X
M-S,@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0*;7-G:60@
M(D5M86EL(@IM<V=S='(@(D5M86EL(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU-C8@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ
M,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"FUS9VED
M(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D5M86EL(&/M;2(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ.38W"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S
M="!M871C:"XB"FUS9W-T<B`B07H@96UA:6P@8^UM96MN96L@96=Y97IN:?QK
M(&ME;&PN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y.3,*;7-G:60@(D5M
M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(D5M86EL('9I<W-Z86EG
M87IO;.%S<V%L(@H*(SH@;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H<#HY
M,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B16UA:6PM
M4TU3(.%T:N%R\R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HR.3D*;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R(")(86YG=6QA=&EK
M;VYO:R(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R
M"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R("+<<F5S(/QZ96YE="XB
M"@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,C0S(&QI8B](;W)D92]'
M<F]U<"]L9&%P+G!H<#HT.#0*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP
M.C8V,B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&QI8B](;W)D
M92]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G
M<W1R(").:6YC<R!I;'EE;BXB"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S
M+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R(")4
M]G+V;&K\:R!K:2!A(&ME<F5SZ7-E:V5T(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4T-PIM<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@
M9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B16YG961J
M_&L@;65G+"!H;V=Y(&OI<&5K970@:6QL97-S>OQN:R!A('-Z]G9E9V)E(&$@
M1F]T\V=A;.ER:>%K8O-L/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,C(*;7-G:60@(D5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM
M<V=S='(@(DQE9WEE;B!J;V)B(&5GZ7)G;VUB8F%L(&5LZ7)H973U+"!K;VYT
M97AT=7-F_&=G]2!M96[\/R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3DR
M(&QI8B](;W)D92]&;W)M+G!H<#HR-SDW"FUS9VED(")%;F0@>65A<B(*;7-G
M<W1R(")!>B!U=&]L<_,@Z78B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G
M<W1R("+!=';A;'3A<R!K_&SV;B!A8FQA:W)A(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(R-`IM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S
M=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R
M97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE
M(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*(D%D:F$@;65G(&%Z="!A(&)I
M>G1O;G/A9VD@:^ER9.ES="P@86UE;'ER92!M86ID(';A;&%S>F]L;FEA(&ME
M;&P@:F5L<WIA=N%N86L@(@HBX73A;&SM=.%SX6AO>BP@<&PN("=H;V=Y(&CM
M=FKA:R!A(&MU='GA:N%T/R<Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T
M:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T<B`B061J82!M96<@82!KZ7`@55),
M+6KI="!I='0B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.#DR"FUS9VED(")%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SHB"FUS9W-T
M<B`BS7)J82!B92!A>B!A;.%B8FD@8F5T^VME=#HB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z.3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<U
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<V"FUS9VED(")%<75A=&]R
M:6%L($=U:6YE82(*;7-G<W1R(")%9WEE;FSM=/5I+4=U:6YE82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HW.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@
M(D5R:71R96$B"FUS9W-T<B`B17)I=')E82(*"B,Z(&QI8B](;W)D92].;W1I
M9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+U9I97<N<&AP.CDT(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HT.`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,V"FUS9VED(")%
M<G)O<B(*;7-G<W1R(")(:6)A(@H*(SH@;&EB+TAO<F1E+U1E;7!L871E+G!H
M<#HT-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@8W)E871I;F<@8FQO
M8VLZ("5S(@IM<V=S='(@(DAI8F$@=/9R=.EN="!A(&)L;VMK(&SI=')E:&]Z
MX7-A:V]R.B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C<R
M"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC
M:&]R.B`E<R(*;7-G<W1R(")(:6)A('3V<G3I;G0@87H@861A='-Z:6YK<F]N
M:7KA8VGS<R!J96P@=/9R;.ES96MO<CH@)7,B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D
M96QE=&EN9R!S>6YC(&QO9SH@)7,B"FUS9W-T<B`B07H@861A='-Z:6YK<F]N
M:7KA8VGS<R!N87!L\^%L;&]MX6YY('3V<FSI<V4@;F5M('-I:V5R_&QT.B`E
M<R(*"B,Z(&QI8B](;W)D92]496UP;&%T92YP:'`Z-#8X"B,L('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS9W-T<B`B
M2&EB82!T]G)TZ6YT(&%Z(&%D871L96OI<NES8F5N.B`E<R(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`B2&EB82!T
M]G)TZ6YT(&$@:F5L<WKS(&UE9W;A;'1O>G1A=.%S86MO<CH@)7,B"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R
M;W(@=VET:"!E;6%I;"!M97-S86=E+B(*;7-G<W1R(")(:6)A(&%Z(&5M86EL
M(/QZ96YE=&)E;BXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R
M;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(D$H>BD@7"(E<UPB(.%L;&]M
MX6YY<F$@;F5M('-I:V5R_&QT(.UR;FDN(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C<V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B17-T;VYI82(*;7-G
M<W1R("+)<WIT;W)S>N%G(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW.`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`B171I
M\W!I82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-@IM<V=I9"`B171H
M;FEC(@IM<V=S='(@(DYE;7IE=&ESZ6=E:R(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B175R\W!A(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,PIM<V=I9"`B179E<GD@,34@
M;6EN=71E<R(*;7-G<W1R("(Q-2!P97)C96YKZ6YT(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,Y,PIM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S
M='(@(C(@<&5R8V5N:^EN="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-#`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B179E<GD@,S`@
M<V5C;VYD<R(*;7-G<W1R("(S,"!MX7-O9'!E<F-E;FOI;G0B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S0R(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.30*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R("(U('!E<F-E;FOI
M;G0B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%
M=F5R>2!,;V=I;B(*;7-G<W1R(")M:6YD96X@8F5J96QE;G1K97KI<VMO<B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#0*;7-G:60@(D5V97)Y(&AA
M;&8@:&]U<B(*;7-G<W1R(")FZ6SS<N%N:^EN="(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-#$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,@IM<V=I
M9"`B179E<GD@;6EN=71E(@IM<V=S='(@(G!E<F-E;FOI;G0B"@HC.B!T96UP
M;&%T97,O9&%T82]D871E;6%P+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V86QU
M97,Z(@IM<V=S='(@(E#I;&1A(.ER=.EK96LZ(@H*(SH@861M:6XO<&AP<VAE
M;&PN<&AP.C@Q(&%D;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3(W"FUS9VED(")%>&5C=71E(@IM<V=S='(@(E;I9W)E:&%J=.%S
M(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV,30*
M;7-G:60@(D5X<&%N9"(*;7-G<W1R(").>6ES<W5K('-ZZ70B"@HC.B!T96UP
M;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R"FUS9VED(")%>'!A;F0@4VED
M96)A<B(*;7-G<W1R(")*96QE;NUT<_QK(&UE9R!A>B!O;&1A;'/S(&UE;OQT
M(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%
M>'!E8W1E9"`G*2<B"FUS9W-T<B`B271T("<I)R!K96QL96YE(&OV=F5T:V5Z
M>F5N(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED
M(")%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM
M<V=S='(@(B(*(DET="!C<W5P87-Z('-Z\VYA:R!V86=Y(&EDZ7KU:F5L8F5N
M(&QE=O4@:V5R97/I<VD@:VEF96IE>NES;F5K(&ME;&QE;F4@;&5N;FEE(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")%>'!I<F%T
M:6]N($1A=&4B"FUS9W-T<B`B07H@Z7)VZ6YY97-SZ6<@;&5JX7)A=&$B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8W-PIM<V=I9"`B17AP;VYE
M;G0B"FUS9W-T<B`B2VET97;U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS
M9W-T<B`B4WKM;B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S<*;7-G
M:60@(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B02!K;VYF:6=U<N%C
M:?,@1E10+6X@X70@=F%L\R!F96QT]FQTZ7-E(@H*(SH@;&EB+TAO<F1E+U!R
M969S+W-Q;"YP:'`Z,C(U"FUS9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F
M97)E;F-E<RXB"FUS9W-T<B`B02!S>F5MZ6QY97,@8F7A;&SM=.%S;VMA="!N
M96T@<VEK97+\;'0@8F5O;'9A<VYI+B(*"B,Z(&QI8B](;W)D92]'<F]U<"]L
M9&%P+G!H<#HW-2!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B
M1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(D%Z
M($Q$05`@<WIE<G9E<B!N96T@Z7)H973U(&5L+B(*"B,Z(&QI8B](;W)D92]!
M=71H+W-M8BYP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--
M0B!S97)V97(N(@IM<V=S='(@(D%Z(%--0B!S>F5R=F5R(&YE;2#I<FAE=/4@
M96PN(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<Q-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B3F5M
M('-I:V5R_&QT(&$H>BD@7"(E<UPB+6+U;"!T]G)TZ6[U(&WA<V]LX7,N(@H*
M(SH@;&EB+U9&4R]F='`N<&AP.C<R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&
M86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(DYE;2!S:6ME<OQL
M="!A*'HI(%PB)7-<(BUB92!T]G)TZ6[U(&WA<V]LX7,N(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O<V%S;"YP:'`Z.#<*;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@
M;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`B3F5M('-I:V5R_&QT(/IJ
M(%-!4TP@:V%P8W-O;&%T;W0@;.ET<F5H;WIN:2XB"@HC.B!L:6(O5D93+W-M
M8BYP:'`Z-3`Q(&QI8B]61E,O9G1P+G!H<#HW-34*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R(").96T@
M<VEK97+\;'0@82AZ*2!<(B5S7"(M8F4@=/9R=.EN]2#A=&AE;'EE>NES+B(*
M"B,Z(&QI8B]61E,O<VUB+G!H<#HT-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G<W1R("+!;&QO;>%N>6AO>GKA
M9NERZ7-I(&AI8F$Z("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T<B`B5&ES>G1A(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@T(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HW.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,@IM
M<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@(D9A
M;&ML86YD+7-Z:6=E=&5K("A-86QV:6YA<RDB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z.#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&87)O92!)<VQA
M;F1S(@IM<V=S='(@(D9A<F]E+7-Z:6=E=&5K(@H*(SH@;&EB+TAO<F1E+T-,
M22YP:'`Z,C,X"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`B2&5L>7)E
M:&]Z:&%T871L86X@:&EB83HB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@(D9A>"(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3$*;7-G:60@(D9A>&5S(@IM<V=S
M='(@(D9A>"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#,@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS
M9VED(")&96)R=6%R>2(*;7-G<W1R(")F96)R=>%R(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,C<*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B2/5M
MZ7)SZ6ML973I<GIE="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,C`*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R(")(]6WI<G/I:VQE
M=.ER>F5T.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ.0IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B16=Y+65G>2!Z
MX7!O<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(P"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(E-Z\W)VX6YY
M;W-A;B!H\WKA<&]R;VLB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DT.`IM
M<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(DUE>O4@;>%T<FEX(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C,S,CD*;7-G:60@(D9I9VQE="!#05!40TA!
M(@IM<V=S='(@(D9I9VQE="!#05!40TA!("AB973[:VER86OS(&AU;>%N=&5S
M>G0I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,S,*;7-G:60@(D9I9VQE
M="!F;VYT(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B1FED>G-I
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")&
M:6QE(@IM<V=S='(@(D;A:FPB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M<F%R+G!H<#HV,"!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV-PHC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(D$@9N%J
M;&]K('-ZX6UA.B`E<R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N
M<&AP.C8P(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(D$@9N%J;&]K
M('-ZX6UA.B`E<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#D*
M;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R(")&X6IL(&UE;F5D>G-E<B(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8S(&QI8B](;W)D
M92]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]T9WHN<&AP.C@R"FUS9VED(")&:6QE($YA;64B"FUS9W-T<B`B1N%J
M;&[I=B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.3@Q"FUS9VED(")&:6QE
M('-E;&5C=&EO;B(*;7-G<W1R(")&X6IL(&MI:F5L]FSI<R(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ-#DP"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R
M(")&X6IL(&9E;'3V;'3I<V4B"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z
M.3`R"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T
M<B`B1N%J;&]K(&9E;'3V;'3I<V4@;F5M(&QE:&5T<^EG97,N(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDQ"FUS9VED(")&:6QT97)S(@IM<V=S
M='(@(E-Z^W+U:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S$*;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`B1FEN;F]R<WKA
M9R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA
M;&8B"FUS9W-T<B`B96QS]2!FZ6PB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R=&5R
M(@IM<V=S='(@(F5L<_4@;F5G>65D(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(U-PIM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@
M(E;A;'1O>F%T;&%N(&WI<F5T87+A;GDB"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C,R"FUS9VED(")&;&EP(@IM<V=S='(@(E3\
M:W+V>NES("AF]FPO;&4I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*
M;7-G:60@(D9O9R(*;7-G<W1R(")+]F0B"@HC.B!L:6(O5D93+W-Q;"YP:'`Z
M,C,W(&QI8B]61E,O;75S<6PN<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B)7,@;6%P<&$@
M;F5M(&SI=&5Z:6LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(D)E=/MS
M>NUN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS9VED(")&;V]D
M(@IM<V=S='(@(LET96QE:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R;W=S
M97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B3VQY86X@
M8O9N9^ES>O5K('-ZX6WA<F$L(&%M:6L@;F5M(&IE;&5N[71I:R!M96<@82!K
MZ7!E:V5T(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#$*;7-G:60@(D9O
M<F5C87-T("A4048I(@IM<V=S='(@(D5L]7)E:F5L>NES("AR97#\;/5TZ7)I
M*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,@IM<V=I9"`B
M(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E
M8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G92!N
M=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G
M<W1R("(B"B)!>B!E;/5R96IE;'KI<R!I9/5T87)T86UA(&YA<&]K8F%N("AA
M>B!E;/5R96IE;'KI<R!N87!P86QI(.ES(.EJ<WIA:V%I("(*(F%D871O:V%T
M('1A<G1A;&UA>BP@97KI<G0@82!N86=Y('-ZX6UO:R!S>NEL97,@8FQO:VMO
M="!E<F5D;>EN>65Z;F5K*2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z,3`R"FUS9VED(")&;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T<B`B
M16QF96QE:G1E='1E(&$@:F5L<WIA=N%T/R(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT-C0*;7-G:60@(D9O<FUS(@IM<V=S='(@(MMR;&%P:V5Z
M96SI<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0IM<V=I9"`B1F]R
M='5N92(*;7-G<W1R("))9.EZ970B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R("))9.EZ970@9F%J
M=.%J82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM<V=I9"`B1F]R
M='5N97,B"FUS9W-T<B`B263I>F5T96LB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B263I>F5T96L@
M,B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-34*;7-G:60@(D9O
M<G5M<R(*;7-G<W1R(")&\W)U;6]K(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$Q,0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B5&]VX6)B[73A
M<V]K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`B4.DB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S"FUS9VED(")&<F%M
M97,B"FUS9W-T<B`B1G)A;64M96LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B
M1G)A;F-I86]R<WKA9R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S
M"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R(")&<F%N8VEA
M;W)S>N%G(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDQ(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R(")&<F%N8VEA
M($=U>6%N82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#0@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDX"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(D9R
M86YC:6$@4&]L:6[I>FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R
M<FET;W)I97,B"FUS9W-T<B`B1G)A;F-I82!$Z6QI(%1E<OQL971E:R(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&
M<F]M(@IM<V=S='(@(D9E;&%D\R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,S<@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,T.0HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDU"FUS9VED(")&<F]M
M('1H92`B"FUS9W-T<B`B27+A;GDZ("(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C0X"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S
M='(@(E+I<WIL971E<R!L9>URX7,B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M.#$@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM
M<V=S='(@(G1E;&EH;VQD(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*;7-G:60@(D9U
M;&P@3F%M92(*;7-G<W1R(")496QJ97,@;NEV(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C@X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1V%B;VXB"FUS
M9W-T<B`B1V%B;VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K
M92!I;6%G92!F<F]M(@IM<V=S='(@(DUE;'EI:R!G86SI<FGA8O-L('9E9WG\
M:R!A(&OI<&5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G<W1R
M(")+Z7!G86SI<FEA.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R(")'86UB:6$B
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M870*
M;7-G:60@(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B2&]Z
M>G5K(&SI=')E(&$H>BD@)7,@:V]N9FEG=7+A8VGS:N%T(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL.C@*;7-G:60@(D=E;F5R871E
M9"!#;V1E(@IM<V=S='(@(D$@:V5L971K97IE='0@:_-D(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.CDP(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HX.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1V5O
M<F=I82(*;7-G<W1R(")'<OIZ:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")'97)M86YY(@IM<V=S='(@
M(D[I;65T;W)S>N%G(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDS(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`B1VCA;F$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.30@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.CDR"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U"FUS
M9VED(")':6)R86QT87(B"FUS9W-T<B`B1VEB<F%L=.%R(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S8*;7-G:60@(D=I=F5N($YA;64B"FUS
M9W-T<B`B2V5R97-Z=&[I=B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HQ-S4@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3`*(SH@=&5M<&QA
M=&5S+W!R969S+V%P<"YI;F,Z,3D*;7-G:60@(D=L;V)A;"!/<'1I;VYS(@IM
M<V=S='(@(D=L;V+A;&ES(&)EX6QL[73A<V]K(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V%P<"YI;F,Z,3<*;7-G:60@(D=O(@IM<V=S='(@(DUE:&5T(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D96PB"FUS9W-T
M<B`B1_9D96PB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3$S,0IM<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B1V]O9VQE('3I
M<FOI<"(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O
M;V=L92!396%R8V@B"FUS9W-T<B`B1V]O9VQE(&ME<F5SZ7,B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,X"FUS9VED(")'<F%Y
M<V-A;&4B"FUS9W-T<B`B1F5K971E+V9E:.ER(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$P,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965C92(*
M;7-G<W1R(")']G+V9V]R<WKA9R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@X"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B9_9R]F<@
M*$E33RTX.#4Y+3<I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDU(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W)E96YL86YD(@IM<V=S='(@(D=R]FYL
M86YD(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW-`IM<V=I9"`B1W)E;F%D82(*;7-G<W1R(")'<F5N861A(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HQ-SD*;7-G:60@(D=R;W5P($%D;6EN:7-T<F%T:6]N
M(@IM<V=S='(@(D-S;W!O<G0@861M:6YI<WIT<N%C:?,B"@HC.B!L:6(O2&]R
M9&4O1W)O=7`N<&AP.C4Y(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ-CD*
M;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@
M(D$@8W-O<&]R=&[I=B!M87)A9&AA="#\<F5S96XB"@HC.B!L:6(O2&]R9&4O
M1W)O=7`O;&1A<"YP:'`Z,S`W"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P
M7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R(")'<F]U<%]L9&%P.B`E<R!C<V]P
M;W)T(&AO>GKA863A<V$@;F5M('-I:V5R_&QT+B!!('-Z97)V97(@=N%L87-Z
M83H@(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$Q."!L:6(O2&]R
M9&4O1W)O=7`O;&1A<"YP:'`Z,3(T"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P
M+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA
M8FQE('1O(&1E;&5T92!G<F]U<"`E<R(*;7-G<W1R(")'<F]U<%]L9&%P.B`E
M<R!C<V]P;W)T('3V<FSI<V4@;F5M('-I:V5R_&QT(@H*(SH@;&EB+TAO<F1E
M+T=R;W5P+VQD87`N<&AP.C,S."!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z
M,S<Y"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T
M;R!U<&1A=&4@9W)O=7`@)7,B"FUS9W-T<B`B1W)O=7!?;&1A<#H@)7,@8W-O
M<&]R="!A9&%T86EN86L@;65G^FKM=.%S82!N96T@<VEK97+\;'0B"@HC.B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO9V]O9VQE+G!H
M<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B
M1W)O=7!S(@IM<V=S='(@(D-S;W!O<G1O:R(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HY."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B
M"FUS9W-T<B`B1W5A9&5L;W5P92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(D=U
M86TB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`R(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@(D=U871E;6%L82(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS
M9W-T<B`B1W5E<FYS97DB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(R
M-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED(")'=65S="!0
M97)M:7-S:6]N<R(*;7-G<W1R(")696YDZ6<@:F]G;W-U;'1SX6=O:R(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S(*;7-G:60@(D=U97-T8F]O
M:R(*;7-G<W1R(")696YDZ6=K]FYY=B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HY-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=U:6YE82(*;7-G<W1R
M(")'=6EN96$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`T(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S@*;7-G:60@(D=U:6YE82U":7-S874B"FUS9W-T<B`B0FES
M<V%U+4=U:6YE82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#4@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(D=U>6%N82(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY-C0*;7-G:60@(DA434PB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T
M;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@(DA434Q!
M<F5A(&=YX79A<^%G8O-L(&YE;2!H86IL86YD\R!A('-O<B!U=&]L<_,@8V5L
M;.%JX70@=/9R]FQN:2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@V"FUS9VED(")(5$U,07)E82!C;W=A<F1L
M>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N
M(@IM<V=S='(@(DA434Q!<F5A(&=YX79A<^%G8O-L(&YE;2!H86IL86YD\R!A
M('3A8FSA>F%T('5T;VQS\R!O<WIL;W#A="!T]G+V;&YI+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G
M:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L
M87-T(')O=R!I;B!T86)L92XB"FUS9W-T<B`B2%1-3$%R96$@9WGA=F%SX6=B
M\VP@;F5M(&AA:FQA;F3S(&$@=.%B;.%Z870@=71O;'/S('-O<N%T('3V<O9L
M;FDN(@H*(SH@;&EB+TAO<F1E+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED(")(
M5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B02!(5%10
M(&9E;&AA<WINX6SS87IO;F]S[73A<R!N96T@=&%LX6QH873S+B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$P,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I
M9"`B2&%I=&DB"FUS9W-T<B`B2&%I=&DB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(DAA
M<V@@86QG;W)I=&UU<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@(DOV9"(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HY,C,@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,3@*
M;7-G:60@(DAE861E<B(*;7-G<W1R(")&96ILZ6,B"@HC.B!L:6(O2&]R9&4O
M1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*;7-G
M<W1R(")&96ILZ6,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA
M;&0@27-L86YD<R(*;7-G<W1R(")(96%R9"T@Z7,@36-$;VYA;&0M<WII9V5T
M96LB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M,PIM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R(")%<O5S('II=F%T87(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B2&5B<F5W("A)
M4T\M.#@U.2TX+4DI(@IM<V=S='(@(FCI8F5R("A)4T\M.#@U.2TX+4DI(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S='(@(DUA9V%S<^%G(@H*(SH@;&EB
M+TAO<F1E+TAE;'`N<&AP.C$X-"!L:6(O2&]R9&4O2&5L<"YP:'`Z,3@V('-E
M<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W"B,Z('1E;7!L871E<R]H96QP+VEN
M9&5X+FEN8SHT"FUS9VED(")(96QP(@IM<V=S='(@(E-E9^UT<^EG(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I
M9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`B4V5G[71SZ6<@82!S>F5R
M:V5S>G3U(&AA<WINX6QA=.%H;WHB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3,W-0IM<V=I9"`B2&5L<&5R(@IM<V=S='(@(E-E9^UT<^EG(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM<V=S='(@
M(D;I;'1E:V4B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,`IM<V=I9"`B2&5R92!I<R!T
M:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R(")%>B!A(&;A:FP@
M96QE:F4Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-S`*;7-G:60@(DAI9V@B"FUS9W-T<B`B;F%G>2(*"B,Z('1E;7!L871E
M<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE
M861E<BYI;F,Z-0IM<V=I9"`B2&]?;64B"FUS9W-T<B`B2V5Z9/5L87`B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0S(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$T
M"FUS9VED(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R
M(")6871I:^%N=N%R;W,B"@HC.B!L:6(O2&]R9&4N<&AP.C$U,SD*;7-G:60@
M(DAO;64B"FUS9W-T<B`B2V5Z9/5L87`B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$R,B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(D]T=&AO
M;FD@8^UM(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8T"FUS9VED(")(
M;VUE($1I<F5C=&]R>2(*;7-G<W1R(")3>F5MZ6QY97,@86QK]FYY=G3A<B(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS9VED
M(")(;VUE(%!H;VYE(@IM<V=S='(@(D]T=&AO;FD@=&5L969O;B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$P-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I
M9"`B2&]N9'5R87,B"FUS9W-T<B`B2&]N9'5R87,B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3`V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@
M2V]N9R(*;7-G<W1R(")(;VYG:V]N9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HV-PIM<V=I9"`B2&]R9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!L
M:6(O2&]R9&4O2V]L86(N<&AP.C0U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I
M;B!M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!H:6+A<R`E<R!8
M34P@861A="!V86X@82AZ*2`E<R#\>F5N971B96XB"@HC.B!L:6(O2&]R9&4O
M2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z(&YI;F-S(&$H>BD@)7,@;V)J96MT=6UN86L@;65G
M9F5L96SU(/QZ96YE="(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#0U"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@
M='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO
M;&%B.B!N:6YC<R`E<R!T[7!U<_H@;V)J96MT=6T@82AZ*2`E<R#\>F5N971B
M96XB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$R-3$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S
M(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@4VEK97)E<V5N('3V<O9L
M=/QK(&5Z=#H@)7,@7"(E<UPB(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HR
M,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE
M(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N(@IM<V=S='(@
M(DAO<F1E+TMO;&%B.B!A>B!I;G1E9W+A;/,@<')O9W)A;6AO>B!S>OQK<^EG
M97,@82`G9&]M>&UL)R!02%`@8O5V[73I<R(*"B,Z(&QI8B](;W)D92]+;VQA
M8BYP:'`Z-3$R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5
M;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S(@IM
M<V=S='(@(DAO<F1E+TMO;&%B.B!N96T@<VEK97+\;'0@^FH@6$U,(&;A="!L
MZ71R96AO>FYI(&$H>BD@)7,@;V)J96MT=6UH;WHB"@HC.B!L:6(O2&]R9&4O
M2V]L86(N<&AP.C$R-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(
M;W)D92]+;VQA8CH@3F5M('-I:V5R_&QT('3V<O9L;FD@)7,M="!<(B5S7"(Z
M("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT.#,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%
M($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S='(@(B(*(DAO<F1E
M+TMO;&%B.B!N96T@<VEK97+\;'0@;65G:&%TX7)O>FYI(&$@34E-12!)1"UJ
MX70@82!K]G9E=&ME>O4@=.UP=7/Z("(*(FUE;&SI:VQE=&YE:SH@)7,B"@HC
M.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$Q.3<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<(B5S
M7"(Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!.96T@<VEK97+\;'0@<WII
M;FMR;VYI>N%L;FD@)7,@7"(E<UPB.B`E<R(*"B,Z(&QI8B](;W)D92]+;VQA
M8BYP:'`Z,3,S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B(@HB
M2&]R9&4O2V]L86(Z($YE;2!S:6ME<OQL="!A(&OV=F5T:V5Z]2!K]GKV<R!T
MX7)T97+\;&5T('-Z:6YK<F]N:7KA;.%S83H@)7,B"@HC.B!L:6(O2&]R9&4O
M2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(Z
M(&ES;65R971L96X@:_9Z]G,@=.%R=&5R_&QE="!<(B5S7"(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(T"FUS9VED(")(
M;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B5NUZ<WII;G1E<R!V;VYA;"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G
M:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R(")6[7IS>FEN=&5S(&UA
M<F?S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B5NUZ<WII;G1E<SHB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E
M(')E<&]R="$I(@IM<V=S='(@(DAO9WD@:G5T;W1T(&ED93\@*$OI<FK\:R#M
M<FIA(&UE9R$I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L
M9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B2.%N>2!O<WIL;W!O="!K
M[7;A;B#V<W-Z96]L=F%S>G1A;FD_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@
M87)E('1H97)E/R(*;7-G<W1R(")(X6YY(&UE>O4@*&]S>FQO<"D@=F%N/R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@
M;65R9V4_(@IM<V=S='(@(DCA;GD@<V]R="!K[7;A;B#V<W-Z96]L=F%S>G1A
M;FD_(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X.2!L:6(O
M0FQO8VLO;65T87(N<&AP.C(S-PIM<V=I9"`B2'5M:61I='DB"FUS9W-T<B`B
M4.%R871A<G1A;&]M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(T.`IM<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R(")0X7)A=&%R=&%L;VTZ
M("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B2'5M;W)I
M<W1S(@IM<V=S='(@(DAU;6]R:7-TX6LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3$Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS
M9W-T<B`B36%G>6%R;W)S>N%G(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N
M<&AP.C$W,B!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C(S-0HC+"!P:'`M
M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E
M<R(*;7-G<W1R(")!>B!)34%0(&QE=NEL;.%D82!LZ71R96AO>N%S82!N96T@
M<VEK97+\;'0Z("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C(Q
M-"!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C(Y-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*;7-G
M<W1R(")!>B!)34%0(&QE=NEL;.%D82!T]G)LZ7-E(&YE;2!S:6ME<OQL=#H@
M)7,B"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3<Y(&QI8B](;W)D
M92]!=71H+V-Y<G-Q;"YP:'`Z,C0R"B,L('!H<"UF;W)M870*;7-G:60@(DE-
M05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@
M(D%Z($E-05`@;&5VZ6QLX63A:&]Z('1A<G1O>O,@:W;S=&$@;.ET<F5H;WKA
M<V$@;F5M('-I:V5R_&QT.B`E<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,S(P"FUS9VED("))4"!!9&1R97-S(@IM<V=S='(@(DE0(&/M;2(*"B,Z(&QI
M8B](;W)D92]!=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED("))4"!!9&1R97-S
M(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D%Z($E0(&/M;2!N96T@:&%TX7)O
M>FAA=/,@;65G+B(*"B,Z(&QI8B](;W)D92]!=71H+VEP8F%S:6,N<&AP.C@Y
M"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L
M;V-K+B(*;7-G<W1R(")!>B!)4"!C[6T@;FEN8W,@82!M96=E;F=E9&5T="!#
M2412('1A<G1O;>%N>6)A;BXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*
M;7-G<W1R(")4:6QT;W1T+VUE9W;A;'1O>F]T="!)4"!C[6TN(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y
M"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B4V]R(&)E:6QL
M97-Z=.ES92!E9O9LZ2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*;7-G<W1R("))>FQA
M;F0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@P"FUS9VED("))8V]N
M<R!/;FQY(@IM<V=S='(@(F-S86L@:6MO;F]K(@H*(SH@=71I;"]I8V]N7V)R
M;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(DEC;VYS(&9O<B`E
M<R(*;7-G<W1R("(E<R!I:V]N:F%I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,X,0IM<V=I9"`B26-O;G,@=VET:"!T97AT(@IM<V=S='(@(FEK;VYO
M:R#I<R!S>O9V96<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DS"FUS
M9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@(D%Z(&%Z;VYO<^UT\VAO
M>B!VX6QA<WIT;W1T(&5L;F5V97KI<SHB"@HC.B!L:6(O2&]R9&4O34E-12]#
M;VYT96YT<RYP:'`Z-3DY"B,L('!H<"UF;W)M870*;7-G:60@(DEF(&ET(&ES
M(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@
M;F5W('=I;F1O=RXB"FUS9W-T<B`B2&$@82!M96=J96QE;NUTZ7,@;F5M(&UE
M9V9E;&5L]2P@)7,@96=Y(/IJ(&%B;&%K8F%N('9A;/,@;65G;GEI=.%S:&]Z
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-3D*;7-G:60@(B(*(DEF
M('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO
M<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R
M;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T<B`B(@HB2&$@UFX@26YT
M97)N970@17AP;&]R97)T(&AA<WINX6PL(.ES(&YE;2!J96QE;FYE:R!M96<@
M87H@:6MO;F]K+"!A:VMO<B`B"B)VX6QA<W-Z82!E>G0@87H@;W!C:?-T+"!M
M96QL>65L(&MI:V%P8W-O;&IA(&$@4$Y'(&OI<&5K('1R86YS>G!A<F5N8VGA
M:N%T+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M-S(*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I
M;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B
M"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"B)(82!L
MX71J82!E>G0@82!S>O9V96=E="P@9&4@82!KZ7!E="!N96TL(&%K:V]R(&+V
M;F?I<WKU<')O9W)A;6IA(&YE;2!KZ7!E<R`B"B)M96=J96QE;NUT96YI(&$@
M<WIE<G9E<G)E(&O\;&1E;F3U(&OI<&5T+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B
M26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B16SU>F5T97,@;NEZ970Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@(D$@:^EP(%523"UJ92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R(")!(&OI<"!54DPM
M:F4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB"FUS
M9W-T<B`B365L>6EK(&=A;.ER:>%B\VP@=F%N(&$@:^EP(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q
M"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(DOI<"!E8F+U
M;"!A(&=A;.ER:>%B\VPZ(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W-C4*
M;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R(")+Z7`@9F5L=/9L=.ES92(*
M"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B"FUS
M9W-T<B`B2^EP96LB"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW
M('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C<*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHU-"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW
M"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R
M("));7!O<G3A;.%S+"`E9"X@;.EPZ7,B"@HC.B!T96UP;&%T97,O9&%T82]D
M871E;6%P+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F
M:65L9#H@)7,B"FUS9W-T<B`B07H@:6UP;W)TX6QT(&UE>O4Z("5S(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T960@
M9FEE;&1S.B(*;7-G<W1R(")!>B!I;7!O<G3A;'0@;65Z]6LZ(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P
M"FUS9VED("));E]S97)T(%)O=R!!9G1E<B(*;7-G<W1R(")3;W(@8F5I;&QE
M<WITZ7-E(&5Z86SA(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z
M,3,T"FUS9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S
M='(@(DAI8N%S('!A<F%N8W-P87)A;>ET97(N(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S,@IM<V=I9"`B26YC;W)R96-T('5S97)N
M86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`B3F5M(&UE9V9E;&5L]2!A
M(&)E:F5L96YT:V5ZZ7-I(&[I=B#I<R]V86=Y(&$@:F5L<WKS+B(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED("(B"B));F-O<G)E
M8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O
M<B!C;VYT86-T('EO=7(@(@HB861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F
M=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(DYE;2!M96=F96QE;/4@82!F96QH
M87-Z;N%L\VD@;NEV('9A9WD@87H@86QT97)N873M=B!C[6TN(%!R\V+A;&IA
M(/IJ<F$@=F%G>2`B"B)F;W)D=6QJ;VX@82!R96YD<WIE<F=A>F3A:&]Z+"!H
M82!T;W;A8F)I('-E9^UT<^EG<F4@=F%N('-Z_&MSZ6=E+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*;7-G:60@(DEN
M8W)E87-E($EN9&5N="(*;7-G<W1R(")"96ME>F3I<R!B96QJ96)B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS
M9VED("));F1I82(*;7-G<W1R("));F1I82(*"B,Z(&QI8B](;W)D92]097)M
M<R]522YP:'`Z,C4T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS
M9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@(D5G>65S(&9E;&AA<WIN
MX6SS:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3(@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX,`IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(DEN9&]NZ7II82(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED
M("));F9O(@IM<V=S='(@(DEN9F]R;>%C:?,B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C4Y"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R("))
M;F9O<FWA8VGS(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q
M.0IM<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB"FUS
M9W-T<B`B07H@:6YF;W)MX6-I\R!MX7(@;F5M(.%L;"!R96YD96QK97KI<W)E
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B"FUS9W-T
M<B`B3W-Z;&]P(&)E<WKZ<N%S82!E>G5TX6XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G:60@
M(DEN<V5R="!);6%G92(*;7-G<W1R(")+Z7`@8F5I;&QE<WITZ7-E(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I
M9"`B26YS97)T(%1A8FQE(@IM<V=S='(@(E3A8FSA>F%T(&)E:6QL97-Z=.ES
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C4*;7-G:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("),:6YK(&SI=')E
M:&]ZX7-A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,T"FUS9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B
M"FUS9W-T<B`B3W-Z;&]P(&)E<WKZ<N%S82!E>F5LZ2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I
M9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B
M"FUS9W-T<B`B3W-Z;&]P(&)E<WKZ<N%S82!E>G5TX6XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G
M:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N
M92(*;7-G<W1R(")/<WIL;W`@8F5S>OIRX7-A(&5Z96SI(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R"FUS
M9VED("));G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(*
M;7-G<W1R(")3;W(@8F5S>OIRX7-A(&5Z86SA(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("))
M;G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T
M<B`B4V]R(&)E<WKZ<N%S82!E9O9LZ2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM<V=I9"`B26YS97)T
M(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B
M0F5K97IDZ7,@8F5I;&QE<WITZ7-E(&5Z=73A;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.0IM<V=I9"`B
M26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E(@IM
M<V=S='(@(D)E:V5Z9.ES(&)E:6QL97-Z=.ES92!E>F5LZ2(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z,34P"FUS9VED("));G-E<G0@86QT97)N871E('1E
M;7!L871E(@IM<V=S='(@(DAO>GIU;FL@;.ET<F4@86QT97)N873M=B!S86)L
M;VYT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T,@IM<V=I9"`B26YS
M97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E
M('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(D%D:F]N(&UE9R!E9WD@96UA
M:6P@8^UM970L(&UE;'ER92!E;&O\;&1H973U(&%Z(-9N(/IJ(&IE;'-Z879A
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(D-E
M;&QA(&)E:6QL97-Z=.ES92!E>G5TX6XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Y"FUS9VED("));G-E<G0@
M8V5L;"!B969O<F4B"FUS9W-T<B`B0V5L;&$@8F5I;&QE<WITZ7-E(&5Z96SI
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R(")/
M<WIL;W`@8F5S>OIRX7-A(&5Z=73A;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C
M;VQU;6X@8F5F;W)E(@IM<V=S='(@(D]S>FQO<"!B97-Z^G+A<V$@97IE;.DB
M"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3`@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED("));G-E<G0@;65S
M<V%G97,B"FUS9W-T<B`B3&5V96QE:R!B96WA<V]LX7-A(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS
M9VED("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(D)E:V5Z9.ES
M(&)E:6QL97-Z=.ES92!E>G5TX6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P
M87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@(D)E:V5Z9.ES(&)E:6QL97-Z=.ES
M92!E>F5LZ2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T
M<B`B4V]R(&)E<WKZ<N%S82!E>F%LX2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*;7-G:60@(DEN<V5R="!R
M;W<@8F5F;W)E(@IM<V=S='(@(E-O<B!B97-Z^G+A<V$@96;V;.DB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,S"FUS9VED("));G-E<G0@=&AE(')E
M<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S
M='(@(D%D:F$@;65G(&$@:^UVX6YT(';A;&%S>G0@82!B:7IT;VYSX6=I(&OI
M<F3I<W)E.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B
M2^EP(&)E:6QL97-Z=.ES92]M\V1O<^UTX7-A(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO
M9&EF>2!,:6YK(@IM<V=S='(@(DQI;FL@8F5I;&QE<WITZ7-E+VWS9&]S[73A
M<V$B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS
M9VED("));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R
M:6)U=&EO;B!L:7-T+B(*;7-G<W1R(")!('-ZX6ULX6KA;B!N:6YC<R!E;.EG
M(&9E9&5Z970@_'IE;F5T970@:_QL9&5N:2!A(&OV<FQE=NEL;&ES=.%R82XB
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED
M("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R(")!('-ZX6ULX6KA;B!N
M:6YC<R!E;.EG(&9E9&5Z970N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P
M-SD*;7-G:60@(DEN=&5G97(B"FUS9W-T<B`B16?I<WHB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3$S-PIM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S='(@
M(D5GZ7-Z('-ZX6UO:R!L:7-TX6IA(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.3<*;7-G:60@(DEN=F%L:60@541(+B`H57-E<B!$
M871A($AE861E<BDN(@IM<V=S='(@(DAI8N%S+V5L9F]G861H871A=&QA;B!5
M1$@@*%5S97(@1&%T82!(96%D97(I+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S
M<R]Z:7`N<&AP.C$V-R!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ.30*
M(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,C$R"FUS9VED("));G9A
M;&ED(%I)4"!D871A(@IM<V=S='(@(DAI8N%S+V5L9F]G861H871A=&QA;B!:
M25`@=/9M]G+M=.ES(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM
M<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`B2&EBX7,O96QF
M;V=A9&AA=&%T;&%N(&%L:V%L;6%ZX7,N(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@240N
M(@IM<V=S='(@(DAI8N%S+V5L9F]G861H871A=&QA;B!B871C:"!A>F]N;W/M
M=/,N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P.3$@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(Q-C(@;&EB+TAO<F1E+T9O<FTN<&AP.C(R,S8*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(S,#,@;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L97-E
M="YP:'`Z,S<*;7-G:60@(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S
M='(@(D$@:_QL9/9T="!A9&%T(&AI8N%S+V5L9F]G861H871A=&QA;BXB"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,`IM<V=I9"`B
M26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R(")(:6+A<R]E
M;&9O9V%D:&%T871L86X@8^UM>NES+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S
M<R]D8G@N<&AP.C$P.2!L:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HQ,SD*
M(SH@;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP:'`Z,C0Q"FUS9VED("));G9A
M;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@(DAI8N%S+V5L9F]G861H871A=&QA
M;B!FX6IL(&9O<FWA='5M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$V-0IM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS9W-T<B`B
M2&EBX7,O96QF;V=A9&AA=&%T;&%N(&QI8V5N<WIK=6QC<RXB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y"FUS9VED("));G9A;&ED(&QO
M8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(")(:6+A<R]E;&9O9V%D:&%T871L
M86X@=N%R;W,N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@(DAI8N%S
M+V5L9F]G861H871A=&QA;B#\>F5N971T[7!U<RXB"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B26YV86QI9"!O<B!M
M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`B2&EBX7,O96QF;V=A9&AA=&%T;&%N
M('9A9WD@:&GA;GEZ\R!P<F]G<F%M;WKA<VEF96S\;&5T+6%Z;VYO<^UT\RXB
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-@IM<V=I
M9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@(DAI
M8N%S+V5L9F]G861H871A=&QA;B!P87)A;>ET97)E:RXB"@HC.B!A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R96YT('!E
M<FUI<W-I;VXN(@IM<V=S='(@(DAI8N%S(&%Z(&]B:F5K='5M(&5LZ7+I<VD@
M:F]G;W-U;'1SX6=A+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-C$*;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B2&EB
MX7,O96QF;V=A9&AA=&%T;&%N('!A<G1N97)A>F]N;W/M=/,N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,PIM<V=I9"`B26YV86QI9"!P
M<F]D=6-T(&-O9&4N(@IM<V=S='(@(DAI8N%S+V5L9F]G861H871A=&QA;B!T
M97)MZ6MK\V0N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#8*;7-G:60@(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(DAI8N%S
M+V5L9F]G861H871A=&QA;B!P<F]T;VMO;&PN(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.CDS(&QI8B].970O4TU3+W=I;E]H='1P+G!H
M<#HW,0HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z.#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R
M(")(:6+A<R]E;&9O9V%D:&%T871L86X@8^UM>F5T=#H@7"(E<UPB(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,#@P(&QI8B](;W)D92]+;VQA8BYP:'`Z
M,3(V,PIM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B2&EB
MX7,O96QF;V=A9&AA=&%T;&%N(&UE9V]S>G1O='0@;V)J96MT=6TB"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B26YV
M86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B2&EBX7,O96QF;V=A9&AA
M=&%T;&%N(&9E;&%D\VD@8^UM+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB
M"FUS9W-T<B`B2&EBX7,O96QF;V=A9&AA=&%T;&%N('5N:6-O9&4@861A="XB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4Y"FUS9VED("));G9E
M;G1O<GDB"FUS9W-T<B`B3GEI;';A;G1A<G3A<R(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HV-S@*;7-G:60@(DEN=F5R="!S96QE
M8W1I;VXB"FUS9W-T<B`B02!K:6IE;/9LZ7,@:6YV97)TX6SA<V$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$Y(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G
M:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B27+A;FD@
M27-Z;.%M($OV>G3A<G-A<^%G(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$Q."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM<V=S='(@(DER
M86LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$S(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS9W-T<B`BS7)O<G-ZX6<B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*
M;7-G<W1R(")-86XM<WII9V5T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM
M<V=S='(@(E-Z\W)VX6YY;W,@>FEV871A<F]K(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$Q-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<W)A96PB
M"FUS9W-T<B`B27IR865L(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HV,C8*;7-G:60@(DES<W5E<B(*;7-G<W1R(")!('1A;OIS[71VX6YY(&MI
M863S:F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CD*;7-G:60@(DET86QI8R(*;7-G<W1R(")D]6QT(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$R,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R"FUS9VED("))
M=&%L>2(*;7-G<W1R(")/;&%S>F]R<WKA9R(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*
M;7-G<W1R(")*86UA:6-A(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P,B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B:F%N=>%R(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$R-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED
M(")*87!A;B(*;7-G<W1R(")*87#A;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3DP"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@
M(FIA<.%N("A)4T\M,C`R,BU*4"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3(R"FUS9VED(")*97)S97DB"FUS9W-T<B`B2F5R<V5Y(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$R-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED
M(")*;W)D86XB"FUS9W-T<B`B2F]R9.%N:6$B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R(")J^FQI=7,B
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N
M92(*;7-G<W1R(")J^FYI=7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S
M='(@(E-O<FMI>N%RX7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B
M"FUS9W-T<B`B:_9ZZ7!R92!R96YD97KI<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$W"FUS9VED(")*=7-T
M:69Y($9U;&PB"FUS9W-T<B`B<V]R:VEZX7+A<R!M:6YD:^ET(&]L9&%L<F$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(G-O<FMI>N%R
MX7,@8F%L<F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R
M(")S;W)K:7KA<N%S(&IO8F)R82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G
M<W1R(")+87IA:'-Z=.%N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(V-0IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B
M5&%R='-U:R!M96<@87H@97)E9&5T:70_(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$R-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*;7-G
M<W1R(")+96YY82(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C@U"FUS
M9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(D$@:V5R8F5R;W,@<WIE<G9E<B!E;'5T87/M=&]T=&$@82!F
M96QH87-Z;N%L\V%Z;VYO<^UTX7-T+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B2V5Z9/4@
M:V5R;F5L9F5J;&5S>G3U:R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C0Q,0IM<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S='(@(DMU;&-S(&SI=')E
M:&]ZX7-A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$T"FUS9VED
M(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B02!K=6QC<R!L96YY;VUA=&$B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME>2!,
M96YG=&@B"FUS9W-T<B`B2W5L8W-H;W-S>OISX6<B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(DMU
M;&-S('3M<'5S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3D*
M;7-G:60@(DME>2!5<V%G92(*;7-G<W1R(")!(&MU;&-S(&AA<WINX6QA=&$B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW-#`*;7-G:60@(DME>2!A
M;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T
M<B`B02!K=6QC<R!MX7(@;.ET97II:R!A(&YY:6QVX6YO<R!K=6QC<W-Z97)V
M97)E;BXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI
M9',B"FUS9W-T<B`B1WEE<F5K96LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3(Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(DMI<FEB871I(@IM<V=S
M='(@(DMI<FEB871I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@1&5M;V-R871I8R!096]P
M;&4G<R!297!U8FQI8R!O9B(*;7-G<W1R(")+;W)E86D@3NEP:2!$96UO:W)A
M=&EK=7,@2_9Z=.%R<V%SX6<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3,S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!297!U8FQI8R!O
M9B(*;7-G<W1R(")+;W)E86D@2_9Z=.%R<V%SX6<B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$Y,0IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@
M(FMO<F5A:2`H155#+4M2*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@(DMU
M=F%I="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX,PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R(")+:7)G:7II<WIT
MX6XB"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*;7-G:60@(DQA
M7WEO=70B"FUS9W-T<B`B7U1E<G9E>NES(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B3GEE;'8B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,W(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#<*;7-G:60@(DQA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM
M<V=S='(@(DQA;W-Z:2!.Z7!I($1E;6]K<F%T:6MU<R!+]GITX7)S87/A9R(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-CD*;7-G:60@(DQA<W0@2&%L9B(*
M;7-G<W1R(")U=&]L<_,@9NEL(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C<V"FUS9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R(")!>B!U
M=&]L<_,@:F5L<WKS=N%L=.%S(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@V
M(&QI8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R=&5R(@IM
M<V=S='(@(G5T;VQS\R!N96=Y960B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$U.`IM<V=I9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R(")5=&]L<_,@=N%L
M=&]Z=&%TX7,Z(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C<Q-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R(")5=&]L<_,@
M8F5J96QE;G1K97KI<SH@)7,B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z-S$Y
M"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B
M"FUS9W-T<B`B571O;'/S(&)E:F5L96YT:V5ZZ7,Z("5S+"`E<R!C[6UR]6PB
M"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z-S$T"FUS9VED("),87-T(&QO9VEN
M.B!.979E<B(*;7-G<W1R(")5=&]L<_,@8F5J96QE;G1K97KI<SH@;>EG('-O
M:&$@;F5M('9O;'0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30V(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#D*;7-G:60@(DQA='9I82(*;7-G<W1R("),971T;W)S
M>N%G(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED("),87<B
M"FUS9W-T<B`B2F]G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<Y"FUS9VED("),87EO=70B"FUS9W-T<B`B16QH
M96QY97KI<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS
M9W-T<B`B2&%G>6IA(/QR97-E;BP@:&$@;F5M(&%K87(@:V5R971E="(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S@@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$R.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-PIM
M<V=I9"`B3&5B86YO;B(*;7-G<W1R("),:6)A;F]N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"FUS9VED("),
M969T(@IM<V=S='(@(F)A;"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3`U
M"FUS9VED("),969T(&AE861E<B(*;7-G<W1R(")"86P@;VQD86QI(&9E:FSI
M8R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3`Q"FUS9VED("),969T('9A
M;'5E<R(*;7-G<W1R(")"86P@;VQD86QI(.ER=.EK96LB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,30S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,CD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQE
M<V]T:&\B"FUS9W-T<B`B3&5S;W1H;R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(U-0IM<V=I9"`B3&5V96PB"FUS9W-T<B`B4WII;G0B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30R(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,S`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*
M;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B3&EBZ7)I82(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$S,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&EB
M>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R("),[6)I86D@07)A8B!3>F]C
M:6%L:7-T82!.86=Y($[I<&D@2_9Z]G-SZ6<B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,30P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S(*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI96-H=&5N
M<W1E:6XB"FUS9W-T<B`B3&EE8VAT96YS=&5I;B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),:6=H="!$<FEZ
M>FQE(@IM<V=S='(@(D=Y96YG92!S>FETX6SS(&5S]2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"FUS9VED("),:6=H="!2
M86EN(@IM<V=S='(@(D=Y96YG92!E<_4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L
M>2(*;7-G<W1R(")$Z6QE;/5T="!G>65N9V4@97/U(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A
M:6X@3&%T92(*;7-G<W1R(")$Z6QU=.%N+V5S=&4@9WEE;F=E(&5S]2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS9VED
M("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R(")'>65N9V4@>N%P;W(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I
M9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B1WEE;F=E('II
M=F%T87(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS,0IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R(")'>65N9V4@:&%V87KA
M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R
M"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R(")'>65N9V4@:/-Z
MX7!O<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM
M97)I8VLB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X,3@*
M;7-G:60@(DQI;FLB"FUS9W-T<B`B3&EN:R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B3&EN
M:R!P;VEN=',@=&\Z(@IM<V=S='(@(D$@;&EN:R!I9&4@;75T870Z(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$X-SD*;7-G:60@(DQI;FL@=&AE(&5M86EL
M(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B
M"FUS9W-T<B`B365G:F5L96[M=.ES:V]R(&UU=&%S<V]N(&5G>2!L:6YK(&$@
M;&5VZ6QC[6UR]6P@82!L97;I;.UR\R!A8FQA:VAO>B(*"B,Z(&QI8B](;W)D
M92]497AT+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,@IM<V=I9"`B3&EN:W,B
M"FUS9W-T<B`B3&EN:V5K(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0V
M"FUS9VED("),:6YU>"!#;V]K:64B"FUS9W-T<B`B3&EN=7@B"@HC.B!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#8@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T("T@=7-E<B!C86X@<V5E
M('1H92!F;VQD97(B"FUS9W-T<B`B3&ES=.%ZX7,@+2!A(&9E;&AA<WINX6SS
M(&SA=&IA(&$@;6%P<.%T(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,PIM
M<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`B07H@861A=&+A>FES;VL@
M;&ES=.%J82(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4Q"FUS9VED
M("),:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(D%Z;VMN86L@82!TZ6WA:VYA
M:R!A(&QI<W3A:F$@86UI<O5L('-E9^UT<^EG(&MA<&AA=/,B"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,3,R"FUS9VED("),:7-T(%1A8FQE<R(*;7-G<W1R
M(")!>B!A9&%T=.%B;.%K(&QI<W3A:F$B"@HC.B!L:6(O2&]R9&4O34E-12](
M96%D97)S+G!H<#HU.30*;7-G:60@(DQI<W0M07)C:&EV92(*;7-G<W1R("),
M:7-T82!A<F-H[79U;2(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP
M.C4X.0IM<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(DQI<W1A('-E9^UT<^EG
M:^ERZ7,B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.38*;7-G
M:60@(DQI<W0M260B"FUS9W-T<B`B3&ES=&$@87IO;F]S[73S(@H*(SH@;&EB
M+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),:7-T+4]W;F5R
M(@IM<V=S='(@(DQI<W1A('1U;&%J9&]N;W,B"@HC.B!L:6(O2&]R9&4O34E-
M12](96%D97)S+G!H<#HU.3,*;7-G:60@(DQI<W0M4&]S="(*;7-G<W1R("),
M:7-T82!L97;I;.URX7,B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H
M<#HU.3$*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(DQI<W1A(&9E
M;&ER871K;WKA<R`H<W5B<V-R:6)E*2(*"B,Z(&QI8B](;W)D92]-24U%+TAE
M861E<G,N<&AP.C4Y,`IM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R
M("),:7-T82!L96ER871K;WKA<R`H=6YS=6)S8W)I8F4I(@H*(SH@861M:6XO
M<V5S<VEO;G,N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@
M<V5S<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R(")!(&9E;&AA<WINX6SS:V%P
M8W-O;&%T;VL@:VEL:7-TX7KA<V$@;F5M('-I:V5R_&QT.B`E<R(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T
M:6YG('5S97)S(&9A:6QE9#H@)7,B"FUS9W-T<B`B02!F96QH87-Z;N%L\VL@
M:VEL:7-TX7KA<V$@;F5M('-I:V5R_&QT.B`E<R(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I
M<R!D:7-A8FQE9"XB"FUS9W-T<B`B02!F96QH87-Z;N%L\VL@:VEL:7-TX7KA
M<V$@=&EL='9A('9A;BXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*
M;7-G:60@(DQI=&5R871U<F4B"FUS9W-T<B`B27)O9&%L;VTB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,30T(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,S,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@
M(DQI=&AU86YI82(*;7-G<W1R("),:71VX6YI82(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]I;6%G97,N<&AP.C<W"FUS9VED("),;V%D:6YG+BXN(@IM
M<V=S='(@(DQE=/9L=.ES+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(P,`IM<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S='(@(DAE;'EI
M(&ED]3H@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V"FUS9VED("),
M;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B3GEE;'8L(&3A='5M+"!I9/4B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-3<*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R
M(&QI8B]";&]C:R]M971A<BYP:'`Z-S(*;7-G:60@(DQO8V%T:6]N(@IM<V=S
M='(@(DAE;'DB"@HC.B!L;V=I;BYP:'`Z,3@Y('-E<G9I8V5S+W!O<G1A;"]S
M:61E8F%R+G!H<#HR,#`@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,PHC
M.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-2!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.CDP"FUS9VED("),;V<@:6XB"FUS9W-T<B`B0F5J96QE
M;G1K97KI<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM
M<V=I9"`B3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R(")!
M>B!E;/5Z]2!A9&%T<WII;FMR;VYI>N%C:?,@;F%P;//A;&QO;>%N>6$B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3DT"FUS9VED("),;V<@
M;W5T(@IM<V=S='(@(DMI:F5L96YT:V5ZZ7,B"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-3D*;7-G:60@(DQO9VEN(@IM<V=S='(@(D)E:F5L96YT:V5Z
MZ7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$P"FUS9VED("),;V=I
M;B!487-K<R(*;7-G<W1R(")"96IE;&5N=&ME>NES<V5L(&MA<&-S;VQA=&]S
M(&9E;&%D871O:R(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY.34*;7-G:60@
M(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O
M<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@(B(*(D$@8F5J
M96QE;G1K97KI<R!N96T@<VEK97+\;'0L(&UE<G0@<F]S<WH@9F5L:&%S>F[A
M;/-N979E="!V86=Y(&IE;'-Z\W0@861O='0@(@HB;65G+B(*"B,Z(&QI8B](
M;W)D92]!=71H+G!H<#HY.3$*;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T
M<B`B02!B96IE;&5N=&ME>NES(&YE;2!S:6ME<OQL="XB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3,V.0IM<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@(DAO
M<W-Z^B!S>O9V96<B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G
M:60@(DQO=F4B"FUS9W-T<B`B4WIE<F5L96TB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B3&]W(@IM<V=S='(@
M(F%L86-S;VYY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R
M<R(*;7-G<W1R(")G]G+V9R!K:7-B973[:R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO
M=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B;&%T:6X@:VES8F5T^VLB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C$W"FUS9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(FMI
M<V)E=/MS('+S;6%I('-ZX6UO:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3'5X96UB;W5R9R(*;7-G
M<W1R("),=7AE;6)U<F<B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`Q(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,SD*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(DU-(@IM<V=S
M='(@(DU-(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X,PIM<V=I
M9"`B34]41"(*;7-G<W1R(").87!I(/QZ96YE=&5K(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W1N968N<&AP.C,V"FUS9VED(")-4RU43D5&($%T=&%C
M:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(D%Z($U3+51.148@
M;65L;.EK;&5T8F5N(&YI;F-S(&%D870N(@H*(SH@;&EB+TAO<F1E+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS
M9W-T<B`BW%I%3D54(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86-A;R(*;7-G<W1R(")-86MA\R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3,@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$S-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M,0IM<V=I9"`B36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(DUA:V5D\VYI82(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A
M<B(*;7-G<W1R(")-861A9V%S>FOA<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT.0IM<V=I9"`B36%G:6,B"FUS9W-T<B`B5F%RX7IS;&%T(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@S"FUS9VED(")-86EL(@IM<V=S
M='(@(DQE=F5L97KI<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU
M,C0*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`B16UA:6P@9&]M86EN(&ME
M>F5LZ7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B
M3&EN:R!KZ7-Z[73I<V4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38U
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&%W:2(*;7-G<W1R(")-86QA
M=VDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38W(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.34*;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@(DUA;&%J>FEA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS
M9VED(")-86QD:79E<R(*;7-G<W1R(")-86QD[78M<WII9V5T96LB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34T(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(*;7-G
M:60@(DUA;&DB"FUS9W-T<B`B36%L:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L=&$B"FUS9W-T
M<B`B3>%L=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.30*;7-G:60@
M(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O
M(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W
M:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*(D%D871A:70@:V%T
M96?S<FGA:V)A('-O<F]L:&%T:F$N($5Z96L@:71T(&1E9FEN:>%L:&%T\VLL
M(&WS9&]S[71H873S:RP@(@HB=&]VX6)BX2!S>NUN96L@<F5N9&5L:&5T]6L@
M:&]Z>N%J=6LN(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$Q-38*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R(")-87`R-"!TZ7)K
MZ7`B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X
M-PHC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$W,0IM
M<V=I9"`B36%P475E<W0@;6%P(@IM<V=S='(@(DUA<%%U97-T('3I<FOI<"(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I9"`B36%P
M<&EN9W,@<W1O<F5D+B(*;7-G<W1R(")!(&AO>GKA<F5N9&5LZ7-E:V5T(&5L
M;65N=&5T=/QK+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#0@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W
M"FUS9VED(")-87)C:"(*;7-G<W1R(")MX7)C:75S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0IM<V=I9"`B
M36%R9VEN(@IM<V=S='(@(DUA<F?S(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S0S,30N<&AP.C0X(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L86=S(@IM<V=S
M='(@(D%Z($]L=F%S;W1T+T]L=F%S871L86X@:F5L>F5T96L@:&%S>F[A;&%T
M82(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HT.2!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET
M:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S
M='(@(DWA<R!J96QZ971E:R`H<&PN($9O;G1O<R]-96=VX6QA<WIO;'0I(&AA
M<WINX6QA=&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34R(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3$*;7-G:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`B
M36%R<VAA;&PM<WII9V5T96LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,34Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T
M<B`B36%R=&EN:7%U92(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M,3`S"FUS9VED(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`B16=Y;>%S;F%K
M(&UE9V9E;&5L]2!M97KU:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%U<FET86YI82(*;7-G<W1R
M(")-875R:73A;FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDT"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`B36%U
M<FET:75S(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T<B`B36%X:6WA
M;&ES(')E;F1E;&ME>NES<F4@X6QL\R!S>N%M;&'V<W-Z96<N(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@(DUA>"!M
M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G<W1R(")!>B#\>F5N970@=/IL
M('-O:R!RZ7-Z8O5L(.%L;"XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q
M,PIM<V=I9"`B36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(D%Z
M(&5L;?IL="`R-"#S<F$@;6%X:6WA;&ES(&CU;>ER<^EK;&5T93H@(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#4*;7-G:60@(DUA>"!T96UP(&QA<W0@
M-B!H;W5R<SH@(@IM<V=S='(@(D%Z(&5L;?IL="`V(/-R82!M87AI;>%L:7,@
M:/5MZ7)SZ6ML971E.B`B"@HC.B!L:6(O87!I+G!H<#HX-@IM<V=I9"`B36%X
M:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R(")!>B#V<W-Z
M96?U;VQD86P@8FQO:VMJ86EN86L@;6%X:6WA;&ES('-ZX6UA(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.CDP,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(R,2!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3(T,PIM<V=I9"`B36%X:6UU;2!L96YG=&@B
M"FUS9W-T<B`B36%X:6WA;&ES(&AO<W-Z(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P-B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R(")MX6IU<R(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3,@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$T-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*
M;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B36%Y;W1T92(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B3W)V
M;W-T=61O;>%N>2(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI
M;F,Z,38*;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`B5&%G;VLB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S@R"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S
M='(@(D$@;65N_"!M96=J96QE;NES93HB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C
M96QL<R(*;7-G<W1R(")#96QLX6L@96=Y8F5O;'9A<WITX7-A(@H*(SH@;&EB
M+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G
M92(*;7-G<W1R("+<>F5N970B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C(Q-@IM<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L
M;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@
M(@HB=F5R:69I960N(@IM<V=S='(@(B(*(D$@9&EG:73A;&ES86X@86SA[7)T
M(/QZ96YE="!H:71E;&5S+"!D92!A>B!A;.'M<O,@=&%N^G/M=';A;GGA="!N
M96T@<VEK97+\;'0@(@HB96QL96[U<FEZ;FDN(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*;7-G:60@(DUE<W-A9V4@97AP:7)E
M9"XB"FUS9W-T<B`B3&5JX7)T(&%Z(/QZ96YE="#I<G;I;GEE<W/I9V4N(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V.2!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C(W(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C8P"FUS9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`B07H@
M_'IE;F5T('3M<'5S82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I
M9"`B365T87(@5V5A=&AE<B(*;7-G<W1R(")-971A<B!I9/5JX7+A<VIE;&5N
M=.ES(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@
M8FQO8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B02!-971A<B!B;&]K:R!N
M96T@X6QL(')E;F1E;&ME>NES<F4N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ,3D*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E
M=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N
M(@IM<V=S='(@(B(*(D$@365T87(@8FQO:VL@;F5M(.%L;"!R96YD96QK97KI
M<W)E+B!!('+I<WIL971E:R!A(')E;F1S>F5R9V%Z9&$@<WKA;>%R82`B"B)K
MZ7-Z_&SU(&YA<&SS9N%J;&)A(&ME<OQL=&5K+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-3,*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O
M;FYE8W1E9"XB"FUS9W-T<B`B02!-971A<D1"(&YE;2#I<FAE=/4@96PN(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R
M(")-\V1S>F5R(@H*(SH@;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP.C@Q(&QI
M8B](;W)D92]24$,O<V]A<"YP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@
M(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`B02AZ*2!<
M(B5S7"(@;?-D<WIE<B!D969I;FGA;&%T;&%N(@H*(SH@;&EB+TAO<F1E+U)0
M0R]R97-T+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@;F]T
M(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S(@IM<V=S='(@(D$@;?-D<WIE
M<B!D969I;FGA;&%T;&%N+B!!(&UE9VCM=F]T="!M\V1S>F5R.B`E<R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-R!L:6(O0FQO8VLO;65T
M87(N<&AP.C@R"FUS9VED(")-971R:6,B"FUS9W-T<B`B365T<FEK=7,B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38V(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*
M;7-G:60@(DUE>&EC;R(*;7-G<W1R(")-97AI:_,B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z.#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T
M.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N
M97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(*;7-G<W1R(")-:6MR;V[I>FEA
M:2!3>O9V971SZ6=I(,%L;&%M;VLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0R"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S8*;7-G:60@(DUI9&1L92(*;7-G
M<W1R(")K]GKI<"(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T;F5F+G!H
M<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S='(@(DU)344@=.UP=7,B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q-PIM<V=I9"`B36EN('1E;7`@;&%S
M="`R-"!H;W5R<SH@(@IM<V=S='(@(D%Z(&5L;?IL="`R-"#S<F$@;&5G86QA
M8W-O;GEA8F(@:/5MZ7)SZ6ML971E.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,P.0IM<V=I9"`B36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T
M<B`B07H@96QM^FQT(#8@\W)A(&QE9V%L86-S;VYY86)B(&CU;>ER<^EK;&5T
M93H@(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-#,Y"FUS9VED(")-
M:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D(@IM<V=S
M='(@(DWI9R!N96T@=&5L="!E;"!A(&UI;FEMX6QI<R!I9/4@82!J96QS>O,@
M;65G=N%L=&]Z=&%TX7/A:&]Z(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(S-0IM<V=I9"`B36ER<F]R(@IM<V=S='(@(E3\:W+V
M>NES("AJ;V)B+V)A;"DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*
M;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B5F5G>65S(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W,B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T
M<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E
M<75E<W0N(@IM<V=S='(@(DAIX6YY>FEK(&$@2%144%]297%U97-T(%!%05(@
M8W-O;6%G+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*;7-G:60@
M(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A
M=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI8V%T
M:6]N+B(*;7-G<W1R("(B"B)+;VYF:6=U<N%C:?,@<WK\:W/I9V5S+B!%>G0@
M;6]S="!K96QL(&SI=')E:&]Z;FEA+"!H82!H87-Z;N%L;FD@86MA<FIA(&%Z
M("(*(F%L:V%L;6%ZX7-T+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`T"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@240N(@IM<V=S
M='(@(DAIX6YY>FEK(&%Z(/QZ96YE="!A>F]N;W/M=/-J82XB"@HC.B!L:6(O
M3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED(")-:7-S
M:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R(")(:>%N
M>7II:R!A($UA:6P@4$5!4B!C<V]M86<N(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)
M1"XB"FUS9W-T<B`B2&GA;GEZ:6L@82!F96QH87-Z;N%L\VMA<&-S;VQA="!A
M>F]N;W/M=/-J82`H<V5S<VEO;B!)1"DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`B
M2.DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S8*;7-G:60@(DUO
M8FEL92!-86EL(@IM<V=S='(@(DQE=F5L97KI<R!M;V)I;'1E;&5F;VYR\VPB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.0IM
M<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B2_9Z97!E<R(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]R87(N<&AP.C8V(&QI8B](;W)D92]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<S"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP
M.C@U"FUS9VED(")-;V1I9FEE9"!$871E(@IM<V=S='(@(D$@;?-D;W/M=.%S
M(&3A='5M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D:69Y(%523"(*;7-G<W1R(")!
M>B!54DP@;?-D;W/M=.%S82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-C<T"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(DUO9'5L=7,B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34P(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G
M:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUO;&1O=F%I($OV
M>G3A<G-A<^%G(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B36]N86-O(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR
M"FUS9VED(")-;VYG;VQI82(*;7-G<W1R(")-;VYG\VQI82(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR-3@X"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G
M<W1R(")(\VYA<"#I<R#I=B(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP
M:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`B:&%V;VYT82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$U,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I
M9"`B36]N='-E<G)A="(*;7-G<W1R(")-;VYT<V5R<F%T(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-
M;V]N(%!H87-E<R(*;7-G<W1R(")(;VQD9N%Z:7-O:R(*"B,Z(&QI8B]&:6QE
M+T-35BYP:'`Z,3DV(&QI8B]&:6QE+T-35BYP:'`Z,C@P"B,L('!H<"UF;W)M
M870*;7-G:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T
M:&4@97AP96-T960@)60N(@IM<V=S='(@(D$@)60N('-O<F)A;B!T]F)B(&UE
M>O4@=F]L="P@;6EN="!A(';A<G0@)60N(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$T."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM
M<V=S='(@(DUA<F]K:_,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS,PIM<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@(E3V
M8F)N>6ER92!D97+\;'0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS-`IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R(")4
M]F)B;GEI<F4@8F]R=6QT(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S4*;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R(")4
M]F)B;GEI<F4@;F%P;W,B"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.C8T.`IM<V=I9"`B36]V92!$;W=N(@IM<V=S='(@(G9I9WG\
M:R!L92(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z
M-C4R"FUS9VED(")-;W9E($QE9G0B"FUS9W-T<B`B=FEG>?QK(&)A;')A(@H*
M(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-38*;7-G
M:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`B=FEG>?QK(&IO8F)R82(*"B,Z(&QI
M8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C0T"FUS9VED(")-
M;W9E(%5P(@IM<V=S='(@(G9I9WG\:R!F]FPB"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(V"FUS9VED(")-;W9E(&1O=VXB"FUS
M9W-T<B`B=FEG>?QK(&QE(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C4R-2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-3(V"FUS9VED(")-;W9E('5P(@IM<V=S='(@(G9I9WG\:R!F]FPB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*
M;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B36]Z86UB:6LB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C$X.`IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D
M;W=N(&QI<W1S(@IM<V=S='(@(E3V8F)S>FEN=/L@;&5G]G)D_&SU(&QI<W3A
M:R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#4X
M"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B375L=&EM87`@3F%G
M>2U"<FET86YN:6$@=.ER:^EP(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R
M-#8*;7-G:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R(")4]F)B<WKV
M<O9S(';A;&%S>G3A<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M,#(*;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T<B`B0F5J96QE;G1K97KI<VD@
M8F7A;&SM=.%S;VLB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*;7-G
M:60@(DUY($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B0F5J96QE;G1K
M97KI<VD@861A=&%I;2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z
M-#4*;7-G:60@(DUY(%!O<G1A;"(*;7-G<W1R(")386KA="#V<W-Z96=Z]2!O
M;&1A;&%M(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C0S"FUS9VED
M(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(E-A:N%T(/9S<WIE9WKU(&]L
M9&%L86T@=&5R=F5ZZ7-E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S='(@(DUI
M86YM87(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N
M:'1M;#HU-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM<V=S='(@(DY%
M32P@;F5M(&5G>65Z96T@8F5L92XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HT,3$@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(").
M86UE(@IM<V=S='(@(D[I=B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R(").
M86WM8FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W."!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDW"FUS9VED(").875R=2(*;7-G<W1R(").875R=2(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$U.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I
M9"`B3F5P86PB"FUS9W-T<B`B3F5PX6PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3<U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE=&AE<FQA;F1S
M(@IM<V=S='(@(DAO;&QA;F1I82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H97)L86YD<R!!;G1I
M;&QE<R(*;7-G<W1R(")(;VQL86YD($%N=&EL;.%K(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G:60@(DYE='-C87!E($)A<V4@55),
M(@IM<V=S='(@(DYE='-C87!E(&+A>FES+5523"(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P92!#02!2979O8V%T
M:6]N(%523"(*;7-G<W1R(").971S8V%P92!T86[Z<^UT=N%N>6MI863A<VEJ
M;V<H0T$I+79I<W-Z879O;N%S:2!54DPB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*
M;7-G<W1R(").971S8V%P92!T86[Z<^UT=N%N>69E;&AA<WINX6SA<VD@:7+A
M;GEE;'8@55),(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#4*
M;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@(DYE='-C87!E
M('1A;OIS[71VX6YY;65G^FKM=.%S:2!54DPB"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!5
M4DPB"FUS9W-T<B`B3F5T<V-A<&4@=&%N^G/M=';A;GEV:7-S>F%V;V[A<VD@
M55),(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@
M(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R(").971S8V%P92!3
M4TP@<WIE<G9E<F[I=B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3@X"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S
M='(@(DYE='-C87!E('1A;OIS[71VX6YY(&UE9VIE9WEZZ7,B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@8V5R
M=&EF:6-A=&4@='EP92(*;7-G<W1R(").971S8V%P92!T86[Z<^UT=N%N>73M
M<'5S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U,PIM<V=I9"`B
M3F5T=V]R:R(*;7-G<W1R(")(X6SS>F%T(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z-#(U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,Y,`IM<V=I9"`B3F5V97(B"FUS9W-T<B`B
M<V]H82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S`@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY-0IM<V=I9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R("+::BU+86QE
M9/-N:6$B"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H
M<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHR-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(MIJ(&MA=&5G\W)I
M82(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]E;6%I;',N<&AP.C@Q(&QI
M8B](;W)D92]497AT+T9I;'1E<B]E;6%I;',N<&AP.C@W"B,Z(&QI8B](;W)D
M92]497AT+T9I;'1E<B]E;6%I;',N<&AP.CDW(&QI8B](;W)D92]497AT+T9I
M;'1E<B]E;6%I;',N<&AP.C$P,0HC+"!P:'`M9F]R;6%T"FUS9VED(").97<@
M365S<V%G92!T;R`E<R(*;7-G<W1R("+::B!L97;I;"`E<R!C[6UR92(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@
M;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB"FUS9W-T
M<B`B^FIH;VQD(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B
MVFH@9F5L:&%S>F[A;/-NZ78@*&]P8VEO;N%L:7,I(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$X,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(").97<@
M6F5A;&%N9"(*;7-G<W1R("+::BU:Z6QA;F0B"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z,S<*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R
M("+::B!J96QS>O,B"@HC.B!L:6(O2&]R9&4O075T:"]S<6PN<&AP.C(R-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@
M;VX@)7@N(@IM<V=S='(@(D%Z(/IJ(&IE;'-Z\R#I<G;I;GEE<W/I9V4@96MK
M;W(@:N%R(&QE.B`E>"XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z-3(*;7-G:60@(DYE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S
M='(@(D$@;65G861O='0@^FH@:F5L<WIA=F%K(&YE;2!E9WEE>FYE:RXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS
M9VED(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(MIJ(&%B;&%K("C\
M<F5S*2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,CDQ
M"FUS9VED(").97=S(@IM<V=S='(@(DCM<F5K(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,P-PIM<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R(")(
M[7)C<V]P;W)T;VLB"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ
M-2!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT,0HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHR-0IM<V=I9"`B3F5X="(*;7-G<W1R(")+]G9E=&ME>O4B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,C<*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T
M<B`B2_9V971K97KU(#0@9N%Z:7,B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN
M<&AP.C,V-B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,W,`IM<V=I9"`B3F5X
M="!O<'1I;VYS(@IM<V=S='(@(DOV=F5T:V5Z]2!O<&-I\VLB"@HC.B!L:6(O
M2&]R9&4O54DO4&%G97(N<&AP.C$P,PIM<V=I9"`B3F5X=#XB"FUS9W-T<B`B
M2_9V971K97KU/B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S0@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEC87)A9W5A(@IM<V=S='(@(DYI8V%R
M86=U82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY-@IM<V=I9"`B3FEG97(B"FUS9W-T<B`B3FEG97(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3<S(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G:60@
M(DYI9V5R:6$B"FUS9W-T<B`B3FEGZ7)I82(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS-CD*;7-G:60@(DYI9VAT(@IM<V=S='(@(NEJ<WIA
M:V$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-C<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3<*;7-G:60@(DYI=64B"FUS9W-T<B`B3FEU92(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HY-C8*;7-G:60@(DYO(@IM<V=S
M='(@(DYE;2(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ
M.0IM<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S
M:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`B(@HB3FEN8W,@<F5N9&5L
M:V5ZZ7-R92#A;&SS(&MO;F9I9W5RX6-I\RP@86UI:&5Z(&OI<&5S="!A(&O\
M;/9N8G/I9V5K970@;65G("(*(FQE:&5T;F4@;75T871N:2XB"@HC.B!L:6(O
M5D93+TE33U=R:71E<BYP:'`Z,3`V"FUS9VED(").;R!A=F%I;&%B;&4@<W1R
M871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R(").:6YC<R!L
M96AE=/5SZ6<@25-/(.%L;&]MX6YY;VL@;.ET<F5H;WKA<^%R82XB"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B3F\@
M8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(DAIX6YY>FEK(&$@:_9T96=E;'0@
M9F5L9&]L9V]ZX7-H;WH@<WK\:W/I9V5S(&UI;G1A("AB871C:"!T96UP;&%T
M92DN(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ
M,#$*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HS.#4*
M(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT,#<*;7-G
M:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N
M(@IM<V=S='(@(D$@:^UVX6YT(&AE;'EE;B!N:6YC<R!B;&]K:R(*"B,Z(&QI
M8B](;W)D92]!=71H+VUC86PN<&AP.C4P"FUS9VED(").;R!C86QE;F1A<B!N
M86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M(")!>B!-0T%,(&9E;&AA<WINX6SS87IO;F]S[73A<VAO>B!N:6YC<R!M96=A
M9'9A(&$@;F%P=.%R(&YE=F4N(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z
M-30*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T<B`B3FEN8W,@=N%L=&]ZX7,N
M(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(DYO(&-H
M:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S
M='(@(D5H:&5Z(&$@:F]G;W-U;'1SX6=H;WH@;F5M(&AO>FAA=/,@;.ET<F4@
M:F]G;W-U;'1SX6=I(&%L8W-O<&]R="XB"@HC.B!L:6(O2&]R9&4N<&AP.C$V
M.2!L:6(O2&]R9&4N<&AP.C4P."!L:6(O2&]R9&4O571I;"YP:'`Z-S8X"B,L
M('!H<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B2&GA;GEO>FYA:R!A(&MO
M;F9I9W5RX6-I\W,@861A=&]K("5S+6AE>BXB"@HC.B!L:6(O5D93+V9T<"YP
M:'`Z.#4U"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B07H@1E10(%9&4R!N:6YC
M<R!K;VYF:6=U<N%L=F$N(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C8W,@IM<V=I
M9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M(%-13"!61E,N(@IM<V=S='(@(D%Z(%-13"!61E,@;FEN8W,@:V]N9FEG=7+A
M;'9A+B(*"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<R-0IM<V=I9"`B3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&
M:6QE(%9&4RXB"FUS9W-T<B`B07H@4U%,+49I;&4@5D93(&YI;F-S(&MO;F9I
M9W5RX6QV82XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(D%Z(-9N('-Z
MX6ULX6KA;B!E;&9O9WEO='0@82!R96YD96QK97KI<W)E(.%L;/,@]G-S>F5G
M+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S0*;7-G
M:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G<W1R(").:6YC<R!C
M[6UZZ7,N(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDR,`IM<V=I9"`B
M3F\@9FEL92!U<&QO861E9"(*;7-G<W1R(")!('-Z97)V97)R92!N96T@=/9L
M=/5D]G1T(&9E;"!S96UM:6QY96X@X6QL;VWA;GDB"@HC.B!U=&EL+VEC;VY?
M8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R
M(")!>B!I:V]N;VL@;F5M('1A;.%L:&%T\VLN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$Q-B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,S`*;7-G:60@(DYO(&QO8V%T:6]N
M(&ES('-E="XB"FUS9W-T<B`B3FEN8W,@;65G861V82!A(&AE;'DN(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-PIM<V=I9"`B3F\@;&]C
M871I;VX@<')O=FED960N(@IM<V=S='(@(DYI;F-S(&UE9V%D=F$@82!H96QY
M+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*;7-G
M:60@(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(D%Z(/QZ96YE="#\
M<F5S+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*
M;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R(").:6YC<R!M96=A
M9'9A(&$@;NEV+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,S<*;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I960N(@IM<V=S='(@(DYI
M;F-S(&UE9V%D=F$@82!S>N%M+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HY-`IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(DYE
M(&QE9WEE;B!M96=B;W1RX6YK;WIT873S(&EDZ7IE="(*"B,Z(&QI8B](;W)D
M92]!=71H+VAT='`N<&AP.CDQ"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3FEN8W,@:F5L
M<WKS(&UE9V%D=F$@82!(5%10(&%L87#Z(&9E;&AA<WINX6SS:2!A>F]N;W/M
M=.%S:&]Z+B(*"B,Z(&QI8B](;W)D92]!=71H+VEM87`N<&AP.C$P.`IM<V=I
M9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(DYI;F-S(&IE;'-Z\R!M96=A9'9A(&%Z($E-05`@86QA
M</H@9F5L:&%S>F[A;/-I(&%Z;VYO<^UTX7-H;WHN(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O:W)B-2YP:'`Z-S(*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3FEN8W,@
M:F5L<WKS(&UE9V%D=F$@82!+97)B97)O<R!A;&%P^B!F96QH87-Z;N%L\VD@
M87IO;F]S[73A<VAO>BXB"@HC.B!L:6(O2&]R9&4O075T:"]S87-L+G!H<#HW
M-R!L:6(O2&]R9&4O075T:"]L;V=I;BYP:'`Z.#0*(SH@;&EB+TAO<F1E+T%U
M=&@O<&%M+G!H<#HW-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").:6YC<R!J96QS>O,@
M;65G861V82!A($QO9VEN(&%L87#Z(&9E;&AA<WINX6SS:2!A>F]N;W/M=.%S
M:&]Z+B(*"B,Z(&QI8B](;W)D92]!=71H+W!A<W-W9"YP:'`Z,3,U"FUS9VED
M(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R(").:6YC<R!J96QS>O,@;65G861V82!A(%!!4U-71"!A
M;&%P^B!F96QH87-Z;N%L\VD@87IO;F]S[73A<VAO>BXB"@HC.B!L:6(O2&]R
M9&4O075T:"]S;6(N<&AP.C@T"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").:6YC<R!J96QS
M>O,@;65G861V82!A>B!334(@86QA</H@9F5L:&%S>F[A;/-I(&%Z;VYO<^UT
MX7-H;WHN(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,C@W"FUS
M9VED("(B"B).;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E
M9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K
M('=I=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B"B).:6YC<R!M96=A9'9A
M(&%Z($]P96Y34TP@<')O9W)A;2!E;.ERZ7-I(/IT=F]N86QA+B!!>B!/<&5N
M4U-,('!R;V=R86T@(@HB<WK\:W/I9V5S(&$@4$M#4R`Q,B!A9&%T;VL@:V5Z
M96SI<^EH97HN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI
M;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R(").:6YC
M<R#Z:B!B96IE;&5N=&ME>NES:2!I9^EN>2XB"@HC.B!L:6(O5D93+G!H<#HW
M-C8*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B3FEN8W,@:W;S=&$@
M8F7A;&SM='9A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#,*;7-G:60@(DYO(')U;&5S(@IM<V=S='(@(DYE
M(&QE9WEE;F5K('9O;F%L86L@<V5H;VPN(@H*(SH@;&EB+T9I;&4O0U-6+G!H
M<#HT.#(*;7-G:60@(DYO('-E<&%R871O<B!S<&5C:69I960N(@IM<V=S='(@
M(DYI;F-S(&1E9FEN:>%L=F$@96QVX6QA<WIT\R!K87)A:W1E<BXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T
M"FUS9VED(").;R!S:61E<R(*;7-G<W1R(").92!L96=Y96X@:V5R970B"@HC
M.B!L:6(O5D93+W-M8BYP:'`Z-3@W"FUS9VED(").;R!S=6-H(&9I;&4B"FUS
M9W-T<B`B3FEN8W,@:6QY96X@9N%J;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ,C8*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@
M879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B3FEN8W,@:61E:6=L96YE
M<R#A;&QO;>%N>6]K('3A<F]LX7/A<F$@<WIO;&?A;/,@86QK]FYY=G3A<BXB
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q(&QI8B].
M970O4TU3+W=I;E]H='1P+G!H<#HR,C$*;7-G:60@(DYO('5S97)N86UE(&%N
M9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R(")(:>%N>7II:R!A(&9E;&AA
M<WINX6SS;NEV(.ES+W9A9WD@82!J96QS>O,N(@H*(SH@;&EB+TAO<F1E+U)0
M0R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T
M=7)N960B"FUS9W-T<B`B02!V:7-S>F%K87!O='0@861A=&]K(&YE;2#I<G;I
M;GEE<R!834P@861A=&]K(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.CDW-"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.3@T"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY
M.34*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,3(*
M;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R(").:6YC<R!A9&%T(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N
M9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(DYI;F-S(&WI9R!K;VYF:6=U<N%C:?,L(&=E
M;F5RX6QJ;VX@96=Y970N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R
M.`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I
M;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B3FEN8W,@
M;>EG(&MO;F9I9W5RX6-I\VIA+"!G96YE<N%L:F]N(&5G>65T+B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C0R-R!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0U"B,Z('1E;7!L871E<R]P<F5F
M<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3,*;7-G:60@(DYO;F4B"FUS9W-T<B`B
M;FEN8W,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDP"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(FYI
M;F-S(&UE9V%D=F$@*&QE9WEE;B!A;&%PZ7)T96QM97IE='0I(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM
M,3`I(@IM<V=S='(@(FYO<F1I:W5S("A)4T\M.#@U.2TQ,"DB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3<R(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-C@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G:60@
M(DYO<F9O;&L@27-L86YD(@IM<V=S='(@(DYO<F9O;&LM<WII9V5T(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM
M<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("+)<WIA:VD@9NEL
M=&5K92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3@@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY,PIM<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S
M='(@(LES>F%K:2U-87)I86YA+7-Z:6=E=&5K(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$W-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").;W)W87DB
M"FUS9W-T<B`B3F]R=NEG:6$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C8T,0IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(DYE;2!KZ7/U8F(B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T
M($)E9F]R92(*;7-G<W1R(").96T@:V]RX6)B86XB"@HC.B!L:6(O5D93+V9I
M;&4N<&AP.C0Q-0IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@(DYE
M;2!A;&OV;GEV=.%R(@H*(SH@;&EB+U9&4R])4T]7<FET97(N<&AP.C8S(&QI
M8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#0*(SH@
M;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-0HC
M.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-#@*
M(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y
M"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@(D$@<')O9W)A;6YA
M:R!E>B!A('+I<WIE(&WI9R!N:6YC<R!M96=V86SS<^UT=F$N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`IM<V=I9"`B
M3F]T('-E="(*;7-G<W1R(").:6YC<R!B9>%L;.UT=F$B"@HC.B!L:6(O5D93
M+G!H<#HQ.3,@;&EB+U9&4RYP:'`Z,C`X(&QI8B]61E,N<&AP.C(S-"!L:6(O
M5D93+G!H<#HR-3(*(SH@;&EB+U9&4RYP:'`Z,C8Y(&QI8B]61E,N<&AP.C(X
M-2!L:6(O5D93+G!H<#HS,#$@;&EB+U9&4RYP:'`Z,S$V"B,Z(&QI8B]61E,N
M<&AP.C,S,R!L:6(O5D93+G!H<#HS-C8@;&EB+U9&4RYP:'`Z-#(V(&QI8B]6
M1E,N<&AP.C4P-0HC.B!L:6(O5D93+G!H<#HU-S0@;&EB+U9&4RYP:'`Z-3DQ
M(&QI8B]61E,N<&AP.C8V.0HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N
M<&AP.C$T-2!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$V,`HC.B!L
M:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$W-2!L:6(O2&]R9&4O4V5S
M<VEO;DAA;F1L97(N<&AP.C$X.0HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L
M97(N<&AP.C(S-@IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B3F5M
M('3A;6]G871O='0N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HR-#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-3@*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$X,`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B
M1F5L:F5G>7KI<V5K(@H*(SH@<V5R=FEC97,O;V)R;W=S97(O:6YD97@N<&AP
M.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RXB"FUS9W-T
M<B`B3FEN8W,@8O9N9^ES>FAE=/4@861A="P@=.ER:F5N('9I<W-Z82XB"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB
M97(B"FUS9W-T<B`B;F]V96UB97(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3`U,`IM<V=I9"`B3G5M8F5R(@IM<V=S='(@(E-ZX6TB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,30R.0IM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B
M"FUS9W-T<B`B2V%R86MT97)E:R!S>N%M82(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,S<S(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(W(&QI8B](;W)D92]&
M;W)M+G!H<#HQ-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R
M(")/<WIL;W!O:R!S>N%M82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S<Q
M(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(U(&QI8B](;W)D92]&;W)M+G!H<#HQ
M-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`R"FUS9VED(").=6UB97(@;V8@<F]W<R(*;7-G<W1R(")3;W)O:R!S>N%M
M82(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*;7-G
M:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES
M=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(D$@:_9R;&5VZ6QL:7-T82!M\V1O
M<^UTX7/A:&]Z(&YE;2!A9&]T="!M96<@<WKA;6]K870N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8T"FUS9VED(")/2R(*
M;7-G<W1R(")/2R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HX-S,*;7-G:60@(D]B:F5C="(*;7-G<W1R(")/8FIE:W1U;2(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@
M0W)E871O<B(*;7-G<W1R(")!>B!O8FIE:W1U;2!LZ71R96AO>O-J82(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,3`X"FUS9VED(")/8W1A;"(*;7-G<W1R
M(")/:W3A;&ES('-ZX6TB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#$Q(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R(")O:W3S8F5R(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*
M;7-G<W1R(")3>OMRZ7,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S(X"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B2&EV871A;"]M=6YK86AE;'DB
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G:60@(D]L
M9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB"FUS9W-T
M<B`B02!RZ6=I(.ES(&%Z(/IJ(&IE;'-Z\VYA:R!K_&SV;F+V>FYI92!K96QL
M+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-@IM<V=I9"`B
M3VQD('!A<W-W;W)D(@IM<V=S='(@(D$@<NEG:2!J96QS>O,B"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*;7-G:60@(D]L9"!P87-S=V]R
M9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`B02!RZ6=I(&IE;'-Z\R!N96T@
M;65G9F5L96SU+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#$@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*;7-G<W1R(")/;>%N(@H*(SH@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY
M($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+B(*;7-G<W1R
M(")#<V%K(&%Z($E-05`@<WIE<G9E<F5K('3A;6]G871JX6L@82!M87!PX6L@
M;65G;W-Z=.%SX70N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDU"FUS
M9VED(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R(")#<V%K(&UE
M9V)O='+A;FMO>G1A=/,@:63I>F5T(&QE9WEE;B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ.#4U(&QI8B](;W)D92]&;W)M+G!H<#HQ.3<U"FUS9VED(")/
M;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(D-S86L@
M96=Y(&5M86EL(&/M;2!A9&AA=/,@;65G+B(*"B,Z('-E<G9I8V5S+W-H87)E
M<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES
M=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N
M97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@HB0W-A
M:R!A('1U;&%J9&]N;W,@=F%G>2!A(')E;F1S>F5R9V%Z9&$@=N%L=&]Z=&%T
M:&%T:F$@;65G(&5G>2!K]GKV<R`B"B)TX7)T97+\;&5T('1U;&%J9&]N;W/A
M="!V86=Y(&5LZ7+I<VD@:F]G;W-U;'1SX6=A:70B"@HC.B!L:6(O0FQO8VLO
M:69R86UE+G!H<#HS.2!L:6(O0FQO8VLO:69R86UE+G!H<#HT,`IM<V=I9"`B
M3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B3GEI<W-U:R!M96<@^FH@
M86)L86MB86XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(T-0IM
M<V=I9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F
M<F]M('-I9VYE9"!3+TU)344@<&%R="XB"FUS9W-T<B`B(@HB3W!E;E-33"!H
M:6)A.B!.96T@<VEK97+\;'0@:VEN>65R;FD@87H@861A=&]K870@87H@86SA
M[7)T(%,O34E-12!RZ7-Z8O5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")/<&5N<R!T:&ES
M(&QI;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(DYY:7-S=6L@;65G(&5Z
M="!A(&/M;65T(&5G>2#Z:B!A8FQA:V)A;B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R(")/
M<&5RX6-I\W,@<F5N9'-Z97(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A
M<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS(@IM<V=S='(@(D]P8VGS:R(*"B,Z
M('-E<G9I8V5S+W!R969S+G!H<#HS,2!T96UP;&%T97,O<')E9G,O87!P+FEN
M8SHQ.0HC+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G
M<W1R("(E<R!B9>%L;.UTX7-A:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES="(*;7-G
M<W1R(")3;W)S>N%M;W,@9F5L<V]R;VSA<R(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`B
M4WIE<G9E>F5T(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-CD*
M;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`B4WIE<G9E>F5T
M:2!E9WESZ6<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,T"FUS
M9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(DUU;FMA<WIE<G9E>NES(@H*(SH@
M861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI
M8V%T:6]N('1E;7!L871E(@IM<V=S='(@(D%Z(&%L:V%L;6%ZX7,@97)E9&5T
M:2!S86)L;VYJ82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W"B,L('!H
M<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E;7!L871E<R!I;B`E<SHB"FUS
M9W-T<B`B)7,@97)E9&5T:2!S86)L;VYJ86DZ(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I
M9"`B3W1H97(B"FUS9W-T<B`B16=YZ6(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.3D@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.0HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3$V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C4*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-"!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,30T"FUS9VED(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R(")%
M9WGI8B!I;F9O<FWA8VGS(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHS,0IM<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B02!T=6QA
M:F1O;F]S(&IO9V]S=6QT<^%G86DB"@HC.B!L:6(O2&]R9&4O075T:"]P86TN
M<&AP.C<Y"FUS9VED(")004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL
M86)L92XB"FUS9W-T<B`B02!004T@9F5L:&%S>F[A;/-A>F]N;W/M=.%S(&YE
M;2#A;&P@<F5N9&5L:V5ZZ7-R92XB"@HC.B!L:6(O3F5T+U--4R]G96YE<FEC
M7W-M='`N<&AP.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM<V=S
M='(@(E!%05(Z.DUA:6P@86QR96YD<WIE<B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C$R-S8*;7-G:60@(E!'4"!$:6=I=&%L(%-I9VYA='5R92(*
M;7-G<W1R(")01U`@9&EG:73A;&ES(&%LX>URX7,B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HQ,S(R"FUS9VED(")01U`@16YC<GEP=&5D($1A=&$B
M"FUS9W-T<B`B4$=0+79E;"!T:71K;W/M=&]T="!A9&%T(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z,3,W-`IM<V=I9"`B4$=0(%!U8FQI8R!+97DB
M"FUS9W-T<B`B4$=0(&YY:6QVX6YO<R!K=6QC<R(*"B,Z(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C$S-38*;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D
M($1A=&$B"FUS9W-T<B`B4$=0+79E;"!A;.'M<G0O=&ET:V]S[71O='0@861A
M="(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV.`IM<V=I9"`B4$A0($-O9&4B
M"FUS9W-T<B`B4$A0(&OS9"(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM
M<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")032!,:6=H="!286EN
M(@IM<V=S='(@(D3I;'5TX6XO97-T92!G>65N9V4@97/U(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@(E!-(%)A
M:6XB"FUS9W-T<B`B1.EL=73A;B!E<_4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G
M<W1R(")$Z6QU=.%N+V5S=&4@>N%P;W)O:R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")032!3;F]W(@IM<V=S
M='(@(D3I;'5TX6XO97-T92!H879A>N%S(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*;7-G:60@(E!-(%-N;W<@4VAO=V5R
M<R(*;7-G<W1R(")$Z6QU=.%N+V5S=&4@:/-ZX7!O<F]K(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E!-(%-U
M;B(*;7-G<W1R(")$Z6QU=.%N(&YA<'/\=.ES(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#,*;7-G:60@(E!-(%0M4W1O<FUS
M(@IM<V=S='(@(D3I;'5TX6XO97-T92!Z:79A=&%R;VLB"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z,C<T"FUS9VED(")03U-)6"!E>'1E;G-I;VX@:7,@
M;6ES<VEN9R(*;7-G<W1R(")(:>%N>7II:R!A(%!/4TE8(&+U=NUTZ7,B"@HC
M.B!L:6(O87!I+G!H<#HQ-#D*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R(")B96QS]2!M87)G\R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$W,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M.0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`B4&%K:7-Z=.%N(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,0IM<V=I
M9"`B4&%L874B"FUS9W-T<B`B4&%L874B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3DR(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QE<W1I;FEA
M;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@(E!A;&5S>G1I;B!497+\
M;&5T("AM96=S>N%L;'0I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDX"FUS9VED(")086YA;6$B"FUS9W-T<B`B4&%N
M86UA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDY"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(E#A<'5A
M(-IJ+4=U:6YE82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.34@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(E!A<F%G
M=6%Y(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S8*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B3>ER<^EK96QT96X@
M8F]R=6QT(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$X,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`R,@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,3DY"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H
M<#HQ-3$@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW-PHC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT,C4*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(DIE;'-Z\R(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S
M<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(D$@:F5L<WKS
M="!S:6ME<F5S96X@;65G=N%L=&]Z=&%T='5K+B(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z,3,R,PIM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T
M(@IM<V=S='(@(DYE;2!M96=F96QE;/4@:F5L<WKS(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D
M(&9O<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(D$@4D%$2553
M(&9E;&AA<WINX6SS87IO;F]S[73A<VAO>B!J96QS>O,@<WK\:W/I9V5S+B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,#4W"FUS9VED(")087-S=V]R9"!W
M:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")*96QS>O,@;65G97+U<^UTZ7-S
M96PB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@
M(E!A<W-W;W)D.B(*;7-G<W1R(")*96QS>O,Z(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VUO8FEL92YI;F,Z,3$*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`B
M2F5L<WKS.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3`@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(P,S@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(D$@
M:F5L<WIA=F%K;F%K(&5G>65Z;FG\:R!K96QL+B(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HQ,3D@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T92(*;7-G<W1R(")"96EL;&5S
M>G3I<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@(D)E
M:6QL97-Z=.%S(&$@=N%G\V%S>G1A;'+S;"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T
M<B`BVG1V;VYA;"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N
M:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHW
M"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(MIJ(&9E;&AA<WIN
MX6SS;F%K(&)E:F5L96YT:V5Z971T96LZ(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4T"FUS9VED(")096]P;&4B"FUS9W-T<B`B16UB97)E:R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS
M9VED(")097)C96YT(@IM<V=S='(@(G-ZX7IA;.EK(@H*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@(E!E<F9O
M<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R(")+87)B86YT87)T
MX7-I(&9E;&%D871O:R!VZ6=R96AA:G3A<V$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#$P"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@(D)E:F5L96YT:V5ZZ7-K;W(@:&%J
M='-U:R!VZ6=R92!A(&MA<F)A;G1A<G3A<VD@9F5L861A=&]K870_(@H*(SH@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I;VXB
M"FUS9W-T<B`B2F]G;W-U;'1SX6<B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N
M<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB
M(&YO="!D96QE=&5D+B(*;7-G<W1R(")!*'HI(%PB)7-<(B!J;V=O<W5L='/A
M9V]T(&YE;2!T]G+V;'3\:RXB"@HC.B!L:6(O5D93+W-M8BYP:'`Z-3DP"FUS
M9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("+6;FYE:R!N:6YC<R!E
M:&AE>B!E;&5G96YD]2!J;V=O<W5L='/A9V$B"@HC.B!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C$V,2!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$V-`IM<V=I
M9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B2F]G;W-U;'1SX6=O:R(*"B,Z(&%D
M;6EN+W!E<FUS+V5D:70N<&AP.C$P.2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP
M:'`Z-C`*(SH@861M:6XO<&5R;7,O:6YD97@N<&AP.C(R(&%D;6EN+W!E<FUS
M+V1E;&5T92YP:'`Z-3@*;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(DIO9V]S=6QT<^%G(&%D;6EN:7-Z='+A8VGS(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X"FUS9VED(")097)S;VYA;"!);F9O
M<FUA=&EO;B(*;7-G<W1R(")3>F5MZ6QY97,@861A=&]K(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$X,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(")0
M97)U(@IM<V=S='(@(E!E<G4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-34*;7-G:60@(E!E=',B"FUS9W-T<B`BP6QL871K961V96YC96LB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@V(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G
M:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(D;\;/9P+7-Z:6=E=&5K(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H
M;VYE(@IM<V=S='(@(E1E;&5F;VXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#@P"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B1NEN>6OI<&=A;.ER
M:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DP(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`P"FUS9VED(")0:71C86ER;B(*;7-G<W1R(")0:71C86ER;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS
M9VED(")0:7AE;',B"FUS9W-T<B`B<&EX96PB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-38*;7-G:60@(E!L871I='5D97,B"FUS9W-T<B`B2_9Z:&5L
M>65K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL
M(@IM<V=S='(@(DMA='1I;G1S;VX@=F%L86UE;'EI:R!C96QLX7)A(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E
M;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@(D)I>G1O<V%N('3V<O9L;FD@
M86MA<FIA(&5Z="!A>B!E;&5M970Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED(")0;&5A<V4@
M8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N
M(@IM<V=S='(@(DOI<F5M(&5R]7/M='-E(&UE9RP@:&]G>2!V86SS8F%N('3V
M<O9L;FD@:^UVX6YJ82!E>G0@87H@96QE;65T+B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR-38V"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@
M82!Y96%R+B(*;7-G<W1R(")+Z7)E;2!A9&IO;B!M96<@96=Y(&CS;F%P;W0@
MZ7,@96=Y(.EV970N(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z,3(*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R
M('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@(DOI<F5M(&%D:F$@;65G(&%Z
M(/IJ(&MA=&5G\W)I82!N97;I=#HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3,P-0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB
M"FUS9W-T<B`B2^ER96T@=F%L\W,@25`@8^UM970@861J;VX@;65G+B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR-C0T"FUS9VED(")0;&5A<V4@96YT97(@
M82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE
M(&UO;G1H+B(*;7-G<W1R(")+Z7)E;2!V86SS<R!DX71U;6]T(&%D:F]N(&UE
M9RP@96QL96[U<FEZ>F4@82!H\VYA<"!N87!J86ET+B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR-#4Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T
M:6UE+B(*;7-G<W1R(")+Z7)E;2!V86SS<R!DX71U;6]T(&%D:F]N(&UE9RXB
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0
M;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S
M='(@(DOI<F5M('+V=FED96X@[7)J82!L92!A('!R;V)LZ6UA(&SI;GEE9^ET
M+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U
M<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B2^ER96T@861J82!M
M96<@82!B96IE;&5N=&ME>NES:2!N97;I="#I<R!J96QS>F%VX70B"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(B(*(E!L96%S92!R
M96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T
M:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*(DOI
M<F5M(&]L=F%S<V$@96P@82!K]G9E=&ME>O4@<WKV=F5G970N($$@<F5N9'-Z
M97(@:&%S>F[A;&%TX6YA:R!F96QTZ71E;&5I="`B"B)E;"!+14Q,(&9O9V%D
M;FEA+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP
M.C<P"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z
M(@IM<V=S='(@(DOI<F5M(&%D:F$@;65G(&%Z(/IJ(&MA=&5G\W)I82!N97;I
M=#HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@X(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3D*;7-G:60@(E!O;&%N9"(*;7-G<W1R("),96YG>65L;W)S>N%G(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*
M;7-G<W1R(")0;VQI=&EK82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT.#D*;7-G:60@(E!O;&QS(@IM<V=S='(@(E-Z879A>N%S;VLB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DS(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ.#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q"FUS
M9VED(")0;W)T=6=A;"(*;7-G<W1R(")0;W)T=6?A;&EA(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W
M"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(D$@
M:^EP(&5L:&5L>65ZZ7-E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@
M=&%B;&4B"FUS9W-T<B`B02!TX6)LX7IA="!E;&AE;'EE>NES92(*"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HU,2!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD
M97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R("(B"B)+]GIV971L
M96X@;&5VZ6QK_&QDZ7,@96)B92!A(&UA<'#A8F$@*$E-05`@;F5M(&UI;F1I
M9R!V97-Z:2!F:6=Y96QE;6)E*2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C<S(&QI8B]";&]C:R]M971A<BYP:'`Z,C<X"B,L('!H<"UF;W)M870*;7-G
M:60@(E!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S
M='(@(D%Z(&5L;?IL="`E<R#S<F$@8W-A<&%DZ6MM96YN>6ESZ6=E.B`B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@W"FUS9VED(")0<F5C
M:7!I=&%T:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(D-S87!A9.EK/&)R("\^
M=F%L\W-Z[6[[<^EG(@H*(SH@;&EB+TAO<F1E+U!R969S+VQD87`N<&AP.CDX
M"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(E!R969S7VQD87`Z(&YE;2!T86SA;&AA=/,@
M82!S>OQK<^EG97,@3$1!4"!K:71E<FIE<WITZ7,N(@H*(SH@;&EB+TAO<F1E
M+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N.B!2
M97%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(E!R969S7W-E<W-I;VXZ(&YE;2!T86SA;&AA=/,@82!S>OQK<^EG97,@*'-E
M<W-I;VXI(&MI=&5R:F5S>G3I<RXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(S,@IM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B3.EG;GEO;>%S(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C8*;7-G:60@(E!R97-S=7)E(&%T('-E
M82!L979E;#H@(@IM<V=S='(@(D$@=&5N9V5R<WII;G1N96L@;65G9F5L96SU
M(&SI9VYY;VWA<SH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(R-`IM<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R("),Z6=N>6]MX7,Z("(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,#,*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@(D5L]7IE=&5S(&UE9W1E
M:VEN=.ES(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(T"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I
M;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B02!KZ7`@96SU>F5T97,@;65G=&5K
M:6YTZ7-E(/IJ(&%B;&%K8F%N(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H
M<#HS-38@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-C`*;7-G:60@(E!R979I
M;W5S(&]P=&EO;G,B"FUS9W-T<B`B16SU>O4@;W!C:?-K(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I
M;G0@9&]C=6UE;G0B"FUS9W-T<B`B02!D;VMU;65N='5M(&MI;GEO;71A=.%S
M82(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4')I
M=F%T92!+97DB"FUS9W-T<B`B5&ET:V]S(&MU;&-S(@H*(SH@;&EB+TAO<F1E
M+TUE;G4N<&AP.C$V.0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R(")(:6)A8F5J
M96QE;G3I<R(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-PIM<V=I9"`B
M4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R(")!(&AI8F$@;&7M<N%S82(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S$*;7-G:60@(E!R;VIE
M8W1S(@IM<V=S='(@(E!R;VIE:W0@:V5Z96SI<R(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR,3$U(&QI8B](;W)D92]&;W)M+G!H<#HR,3DR(&QI8B](;W)D
M92]&;W)M+G!H<#HS,C@P"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R(")!
M('!R;VUP="!S>O9V96=E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(DYY:6QVX6YO<R!K=6QC
M<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0V"FUS9VED(")0
M=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R(").>6EL=N%N;W,@:W5L8W/Z
M(&%L9V]R:71M=7,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T
M-0IM<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(DYY:6QVX6YO<R!K
M=6QC<R!I;F9O<FWA8VGS(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M,C0Q"FUS9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T
M960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")!(&YY:6QVX6YO<R]T:71K;W,@
M:W5L8W-PX7)T(&YE;2!S:6ME<OQL="!LZ71R96AO>FYI+B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$X,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@
M(E!U97)T;R!2:6-O(@IM<V=S='(@(E!U97)T;R!2:6-O(@H*(SH@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C4U"FUS9VED(")0=7)G92!M97-S
M86=E<R(*;7-G<W1R(")!(&QE=F5L96L@=NEG;&5G97,@=/9R;.ES92(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.38@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$X-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*
M;7-G:60@(E%A=&%R(@IM<V=S='(@(DMA=&%R(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C8S"FUS9VED(")1=65R>2(*;7-G<W1R(")+97)E<_4O<&%R86YC
M<R!S=')I;F<B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*;7-G:60@
M(E%U;W1A(@IM<V=S='(@(DMV\W1A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HV-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+
M97D@*"5D(&)I="DB"FUS9W-T<B`B4E-!(&YY:6QVX6YO<R!K=6QC<R`H)60@
M8FET97,I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-C@*;7-G:60@(E)A
M9&EO('-E;&5C=&EO;B(*;7-G<W1R(")2X61I\V=O;6)O<R!K:7;A;&%S>G3A
M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T
M"FUS9VED(")286EN(@IM<V=S='(@(D5S]2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")286EN($5A<FQY(@IM
M<V=S='(@(D5S]2!DZ6QE;/5T="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0V"FUS9VED(")286EN($QA=&4B"FUS9W-T<B`B
M17/U(&3I;'5TX6XO97-T92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R("):
MX7!O<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0X"FUS9VED(")286EN(&%N9"!3;F]W(@IM<V=S='(@(D5S]2#I<R!H879A
M>N%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#D*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R(")(879A<V5S]2(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R='5N
M92(*;7-G<W1R(")6Z6QE=&QE;B!I9.EZ970B"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O<F%R+G!H<#HV."!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP
M+G!H<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T<B`B07+A;GDB"@HC.B!L:6(O
M2&]R9&4O4&5R;7,N<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C,T"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$Q-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A9"(*;7-G<W1R
M(")/;'9A<^%S(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP
M.C0W(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PIM<V=I9"`B
M4F5A9"!M97-S86=E<R(*;7-G<W1R("),979E;&5K(&]L=F%SX7-A(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M
M870*;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A
M;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*(E3I;GEL96<@=/9R]FQJ_&L@
M)7,@9F5L:&%S>F[A;/-T/R!%>B!A(';A;'1O>G1A=.%S(&YE;2!F;W)D[71H
M873S('9I<W-Z82XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI
M;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@<F5M;W9E('5S97(@
M9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N
M9&]N92XB"FUS9W-T<B`B(@HB5.EN>6QE9R!T]G+V;&K\:R`E<R!F96QH87-Z
M;N%L\R!A9&%T86ET/R!%>B!A(';A;'1O>G1A=.%S(&YE;2!F;W)D[71H873S
M("(*(G9I<W-Z82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*
M;7-G<W1R("+::G)A(';I9W)E:&%J=&IA(&%Z('5T;VQS\R!VX6QT;WIT873A
M<W0B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R(")&<FES<^UT
MZ7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDU"FUS9VED(")2969R
M97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B02!M96[\(&1I
M;F%M:6MU<R!E;&5M96EN96L@9G)I<W/M=.ES:2!G>6%K;W)I<^%G83HB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0U"FUS9VED(")2969R97-H(%!O
M<G1A;"!6:65W.B(*;7-G<W1R(")!>B#V<W-Z96=Z]6]L9&%L(&9R:7-S[73I
M<^EN96L@9WEA:V]R:7/A9V$Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Y
M."!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q-R!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3(S.0IM<V=I9"`B4F5G97@B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C,R,S4*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S
M='(@(D]B:F5K='5M(&+V;F?I<WKU(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`IM
M<V=I9"`B4F5L;V%D(@IM<V=S='(@(D9R:7-S[73I<R(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S,S"FUS9VED(")296UA<FMS(@IM<V=S='(@(DUE9VIE
M9WEZZ7-E:R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3<*;7-G:60@
M(E)E;6]T92!397)V97)S(@IM<V=S='(@(E3A=F]L:2!S>F5R=F5R96LB"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T
M92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R
M(")!('3A=F]L:2!54DP@*'!L+B!H='1P.B\O=W=W+G9A;&%M:2YH=2]M96=V
M86QA;6DI.B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z
M,C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,PIM<V=I9"`B
M4F5M;W9E(@IM<V=S='(@(E3V<FSI<R(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;&%Y;W5T+FEN8SHQ,0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@(D)L
M;VMK('3V<FSI<V4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-34Y"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(D]S>FQO
M<"!T]G)LZ7-E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHT,`IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`B
M02!F;W)M871TX6SA<R!T]G)LZ7-E(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHQ,C@*;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@(D$@<.%R
M('3V<FSI<V4B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R"FUS9VED
M(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB5/9R]FQJ_&L@87H@96QM96YT971T
M('!R;V=R86UO="!A('-Z97)V97(@:61E:6=L96YE<R#A;&QO;>%N>6]K870@
M=&%R=&%L;6%Z\R`B"B)A;&OV;GEV=.%RX6+S;"XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*;7-G:60@
M(E)E;6]V92!T:&4B"FUS9W-T<B`B5F5G>?QK(&MI("(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I
M9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G<W1R
M(")696=Y_&L@:VD@97IT(&$@<NES>G0@82!D;VMU;65N='5M8O-L(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0IM<V=I9"`B4F5M
M;W9E('5S97(B"FUS9W-T<B`B02!F96QH87-Z;N%L\R!T]G)LZ7-E(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHU"B,L('!H<"UF;W)M
M870*;7-G:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R("(E<R!F96QH87-Z
M;N%L\R!T]G)LZ7-E(@H*(SH@;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP.C$S
M.`IM<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N
M960@97)R;W)C;V1E.B`B"FUS9W-T<B`B02!KZ7+I<R!N96T@=&5L:F5S[71H
M973U+B!!(&MA<&]T="!H:6)A:_-D.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,30U"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L
M9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@(D$@:V5R97-E='0@<WIO;&?A;'1A
M=.%S(&YE;2!T86SA;&AA=/,N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-S8@;&EB
M+TAO<F1E+G!H<#HU,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@
M7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B02!K]G1E;&5Z]65N(&UE9V%D86YD\R!<(B5S7"(@;F5M('-Z97)E
M<&5L("5S(&MO;F9I9W5RX6-I\VKA8F%N+B(*"B,Z(&QI8B]61E,O<W%L+G!H
M<#HV-S@@;&EB+U9&4R]F='`N<&AP.C@V,2!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HW,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO
M="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D$@
M:_9T96QE>O5E;B!M96=A9&%N9/,@7"(E<UPB(&YE;2!S>F5R97!E;"!A(%9&
M4R!K;VYF:6=U<N%C:?-JX6)A;BXB"@HC.B!L:6(O2&]R9&4O571I;"YP:'`Z
M-S<V"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@
M<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D$@:_9T96QE
M>O5E;B!M96=A9&%N9/,@7"(E<UPB(&YE;2!S>F5R97!E;"!A(&MO;F9I9W5R
MX6-I\V)A;BXB"@HC.B!L:6(O2&]R9&4O1F]R;2]296YD97)E<BYP:'`Z,S,U
M"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R(")3>OQK<^EG97,@;65Z
M]2(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q(&QI8B](;W)D92]&;W)M+G!H<#HS
M-#,@;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,R,`HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(P('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`B4F5S970B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B4F5S970@4&%S
M<W=O<F0B"FUS9W-T<B`B02!J96QS>O,@X73A;&SM=.%S82(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W"FUS9VED(")297-E="!9;W5R(%!A
M<W-W;W)D(@IM<V=S='(@(D%Z(-9N(&IE;'-Z87;A;F%K(.%TX6QL[73A<V$B
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,P"FUS9VED(")297-T;W)E($QA
M<W0@475E<GDB"FUS9W-T<B`B07H@=71O;'/S(&ME<F5SZ7,@=FES<WIAX6QL
M[73A<V$B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S$@861M:6XO8VUD<VAE
M;&PN<&AP.C(X(&%D;6EN+W-Q;'-H96QL+G!H<#HV-@IM<V=I9"`B4F5S=6QT
M<R(*;7-G<W1R(")%<F5D;>EN>2(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B
M4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B5FES<WIA(&%Z(&]P8VGS:VAO
M>B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS.`IM<V=I9"`B
M4F5T>7!E(&YE=R!P87-S=V]R9"(*;7-G<W1R(")!>B#Z:B!J96QS>O-T(.UR
M:F$@8F4@:7-MZ70B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DW(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`R"FUS9VED(")2975N:6]N(@IM<V=S='(@(E+I=6YI
M;VXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM
M<V=S='(@(L%L;.UT<W5K('9I<W-Z82!A(&MO;F9I9W5RX6-I\W0B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,U"FUS9VED(")2:6-H(%1E>'0@161I
M=&]R($]P=&EO;G,B"FUS9W-T<B`B4FEC:"!497AT($5D:71O<B!O<&-I\VLB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B
M"FUS9W-T<B`B5&%LX6SS<R!KZ7)DZ7-E:R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`IM<V=I9"`B4FEG:'0B
M"FUS9W-T<B`B:F]B8B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3`W"FUS
M9VED(")2:6=H="!H96%D97(B"FUS9W-T<B`B2F]B8B!O;&1A;&D@9F5J;.EC
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#,*;7-G:60@(E)I9VAT('9A
M;'5E<R(*;7-G<W1R(")*;V)B(&]L9&%L:2#I<G3I:V5K(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X"FUS
M9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B4V]R('1U;&%J9&]N
M<^%G;VLN+BXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R(")3>F5R97`B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3DX(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2
M;VUA;FEA(@IM<V=S='(@(E)O;>%N:6$B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C(V"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S
M='(@(D9O<F=A=.%S(#$X,"!F;VMK86PB"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C(S"FUS9VED(")2;W1A=&4@3&5F="(*;7-G
M<W1R(")"86QR82!F;W)G873A<R(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,CD*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R
M(")*;V)B<F$@9F]R9V%TX7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE
M<R(*;7-G<W1R(")3;W(@='5L86ID;VYSX6=O:R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O
M=R!P<F]P97)T:65S(@IM<V=S='(@(E-O<B!T=6QA:F1O;G/A9V]K(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G
M:60@(E)O=W,Z(@IM<V=S='(@(E-O<F]K.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G:60@(E)U;&5S
M(@IM<V=S='(@(E9O;F%L86LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P
M<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(DUI
M;F1E;B!S;W(@Z7,@;W-Z;&]P(&OV>O9T="!L96=Y96X@=F]N86PB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q
M"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL
M>2(*;7-G<W1R(")#<V%K(&%Z(&]S>FQO<&]K(&OV>O9T="!L96=Y96X@=F]N
M86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O
M=W,@;VYL>2(*;7-G<W1R(")#<V%K(&$@<V]R;VL@:_9Z]G1T(&QE9WEE;B!V
M;VYA;"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`*;7-G:60@(E)U;B(*
M;7-G<W1R(")&=71T873A<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M.3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO
M;B(*;7-G<W1R(")/<F]S>B!&]F1E<N%C:?,B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C`P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#@*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=V%N9&$B
M"FUS9W-T<B`B4G5A;F1A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*
M;7-G<W1R(")3+TU)344@9&EG:73A;&ES(&%LX>URX7,B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E
M9"!-97-S86=E(@IM<V=S='(@(E,O34E-12!S>F%B=N%N>2!S>F5R:6YT('1I
M=&MO<^UT;W1T(&QE=NEL(@H*(SH@;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'`Z
M.#$*;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L
M92XB"FUS9W-T<B`B4T%33"!F96QH87-Z;N%L\V%Z;VYO<^UTX7,@;F5M('1A
M;.%L:&%T\RXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3`V"FUS
M9VED(")335,@365S<V%G:6YG(@IM<V=S='(@(E--4R!K_&QDZ7,B"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(W.`IM<V=I9"`B4U%,('-T
M871E;65N="!F;W(@=F%L=64@;&]O:W5P<R(*;7-G<W1R(")344P@<&%R86YC
M<R!A(&ME<F5SZ7-H97HB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#,S"FUS9VED(")34T@B"FUS9W-T<B`B4U-((@H*(SH@;&EB+TAO<F1E+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#
M15-3(@IM<V=S='(@(E-)2T52W$Q4(@H*(SH@;&EB+V%P:2YP:'`Z,34S"FUS
M9VED(")37U%,(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@
M(E-Z;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R(")3>F5N="!)
M;&]N82US>FEG970B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,Q(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*
M;7-G<W1R(")386EN="!+:71T<R#I<R!.979I<R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y
M,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B4V%I;G0@
M3'5C:6$B"FUS9W-T<B`B4V%I;G0@3'5C:6$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3@Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3(*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")386EN="!0
M:65R<F4@86YD($UI<75E;&]N(@IM<V=S='(@(E-A:6YT(%!I97)R92#I<R!-
M:7%U96QO;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#0@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,34*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N
M861I;F5S(@IM<V=S='(@(E-A:6YT(%9I;F-E;G0@Z7,@1W)E;F%D:6YE+7-Z
M:6=E=&5K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(E5G
M>6%N87H@82!F<F%M92`H7W-E;&8I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(U,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B4V%M;V$B"FUS9W-T
M<B`B4WIA;6]A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P-@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R(")386X@
M36%R:6YO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P-PIM<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S
M='(@(E-A;R!4;VWI(.ES(%!R[6YC:7!E(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$Y"FUS9VED(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T
M<B`B3?MH;VQD87,@:6YT97)N971E;.ERZ7,B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C`Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3<*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3875D:2!!
M<F%B:6$B"FUS9W-T<B`B4WIA^F0M07+A8FEA(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]L87EO=70N:6YC.CDY"FUS9VED(")3879E(@IM<V=S='(@(DUE;G3I
M<R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B7"(E<UPB
M(&UE;G3I<V4B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@(B5S(&UE;G3I
M<V4B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E
M($]P=&EO;G,B"FUS9W-T<B`B02!B9>%L;.UTX7-O:R!M96YTZ7-E(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-PIM<V=I9"`B(@HB4V%V92!G96YE
M<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S
M97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R("(B"B)-
M96YT<_QK(&5L(&%Z(&5L:^ES>OQL="!K;VYF:6=U<N%C:?-T(%!(4"!P<F]G
M<F%M(&9O<FWA:N%B86X@82!S>F5R=F5R("(*(FED96EG;&5N97,@X6QL;VWA
M;GEO:V%T('1A<G1A;&UA>O,@86QK]FYY=G3A<N%B86XN(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V
M960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B)7,@:V]N9FEG=7+A8VGS
M:N%T(&5L;65N=&5T=/QK+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.CDS"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@
M<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(D5L;65N=&5T=/QK(&$@<V5T
M=7`@=7!G<F%D92!P<F]G<F%M;W0@:61E.B!<(B5S7"(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I9"`B4V-A='1E
M<F5D(%0M4W1O<FUS(@IM<V=S='(@(E-Z\W)VX6YY;W,@>FEV871A<F]K(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE;F-E(@IM
M<V=S='(@(E1U9&]MX6YY(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G
M:60@(E-E87)C:"(*;7-G<W1R(")+97)E<^ES(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,R,@IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T
M<B`B2V5R97/I<VD@<WIO;&?A;'1A=.%S;VLB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,CDU.0IM<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S='(@(L%L;&]M
MX6YY;VL@:VEVX6QA<WITX7-A(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0X-0IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R
M(")6X6QA<W-Z;VX@:VD@96=Y(&3A='5M;W0B"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B4V5L96-T(&$@9W)O=7`@=&\@861D
M(@IM<V=S='(@(DUE;'EI:R!C<V]P;W)T;W0@:^UVX6YJ82!H;WIZX6%D;FDB
M"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S"FUS9VED(")396QE
M8W0@82!N97<@;W=N97(B"FUS9W-T<B`B5N%L87-S>F$@:VD@87H@^FH@='5L
M86ID;VYO<W0B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*
M;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R(")6X6QA<W-Z;VX@<WIE
M<G9E<G0B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U-@IM<V=I
M9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`B365L>6EK(&9E;&AA
M<WINX6SS="!K[7;A;FIA(&AO>GKA861N:2(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HV-S8*;7-G:60@(E-E;&5C="!A;&PB"FUS
M9W-T<B`B36EN9&5T(&MI:F5L]FQJ_&LB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C8T-PIM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM
M<V=S='(@(E;A;&%S<WIA(&MI(&%Z(/9S<WIE<R!DX71U;?9S<WIE=&5V]70N
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM
M<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R(")6X6QA<W-Z;VX@96=Y
M(&]B:F5K='5M;W0B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C<W"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R(")%9WD@<V4@
M;&5G>65N(&MI:F5L]FQV92(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HS
M-PIM<V=I9"`B(@HB4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R
M;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB
M<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N(@IM<V=S='(@(B(*(E;A
M;&%S<WIA(&MI(&$@:^UVX6YT(&MA<F%K=&5R*&5K92ET(&%Z(&%LX6)B:2!L
M96AE=/5SZ6=E:R!K]GK\;"X@17IU=.%N("(*(EPB8V]P>2]P87-T95PB(&WS
M9'-Z97)R96P@82!M96=F96QE;/4@:&5L>7)E(&WA<V]L:&%T:F$@]6ME="XB
M"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T
M('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`B5N%L87-S>F$@:VD@82!D
MX71U;65L=N%L87-Z=/,@:V%R86MT97)T.B(*"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*
M;7-G<W1R(")6X6QA<W-Z82!K:2!A(&3A='5M(&9O<FWA='5MX70Z(@H*(SH@
M=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B
M4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S
M='(@(E;A;&%S<WIA(&MI+"!M96QY:6L@87IO;F]S[73S:N%T(&OM=N%N:F$@
M;65G=N%L=&]Z=&%T;FDZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z
M,38*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S='(@
M(E;A;&%S<WIA(&MI(&%Z(&ED]65L=N%L87-Z=/,@:V%R86MT97)T.B(*"B,Z
M('1E;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE
M('1I;64@9F]R;6%T.B(*;7-G<W1R(")6X6QA<W-Z82!K:2!A>B!I9/4@9F]R
M;>%T=6WA=#HB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4W"FUS
M9VED(")396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`B5N%L
M87-S>F]N(&MI(&OI="!E9WEMX7-N86L@;65G9F5L96SU(&UE>O5T+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,3`*;7-G:60@(E-E;&5C="!Y;W5R
M(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B5N%L87-S>F$@:VD@82!K[7;A;G0@
M<WKM;F5G>?QT=&5S="XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4R
M"FUS9VED(")396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S
M='(@(E;A;&%S<WIA(&MI(&%Z(-9N;F5K(&UE9V9E;&5L]2!N>65L=F5T.B(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")3
M96YD(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(DAI8F%J96QE;G3I<R!K_&QD
MZ7-E(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P
M-#(*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(E--4R!K_&QDZ7-E(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DX"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-@IM
M<V=I9"`B4V5N96=A;"(*;7-G<W1R(")3>F5N96?A;"(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S(S"FUS9VED(")396YS;W(Z("(*;7-G<W1R(")3>F5N
M>F]R.B`B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#$P(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I
M9"`B4V5P=&5M8F5R(@IM<V=S='(@(G-Z97!T96UB97(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD($UO
M;G1E;F5G<F\B"FUS9W-T<B`B4WIE<F)I82#I<R!-;VYT96YE9W+S(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#(*;7-G:60@(E-E<FEA;"!.
M=6UB97(B"FUS9W-T<B`B4V]R;WIA='-ZX6TB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,30Y"FUS9VED(")397)V97(@9&%T82!W<F]N9R!O
M<B!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")!('-Z97)V97)T]6P@:V%P;W1T
M(&%D870@:&EBX7,L('9A9WD@;F5M(.%L;"!R96YD96QK97KI<W)E+B(*"B,Z
M(&%D;6EN+W-E<W-I;VYS+G!H<#HR-PIM<V=I9"`B4V5S<VEO;B!!9&UI;B(*
M;7-G<W1R(")!(&9E;&AA<WINX6SS:V%P8W-O;&%T;VL@861M:6YI<WIT<N%C
M:?-J82(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR
M"FUS9VED(")397-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@(DQE:N%R="!A
M(&9E;&AA<WINX6SS:V%P8W-O;&%T(&%Z;VYO<^UT\VIA("AS97-S:6]N($E$
M*2XB"@HC.B!L:6(O87!I+G!H<#HQ-#4*;7-G:60@(E-E<W-I;VYS(@IM<V=S
M='(@(D9E;&AA<WINX6SS:V%P8W-O;&%T;VLB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C,Q.`IM<V=I9"`B4V5T(@IM<V=S='(@(DAA;&UA>B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HW.0IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@
M86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@
M9F]R9V5T(&ET+B(*;7-G<W1R("),96AE=/5SZ6<@:F5L<WIA=N%N86L@X73A
M;&SM=.%SX7)A+"!A8F)A;B!A>B!E<V5T8F5N+"!H82!E;&9E;&5J=&5NZ2XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$X"FUS9VED(")3970@=7`@
M<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y
M;W5R('!O<G1A;"XB"FUS9W-T<B`B(@HB5.%V;VQI('-Z97)V97)E:R!E;.ER
MZ7-E(.%L;.UT:&%T\R!B92P@;65L>65K970@87H@:6YD=6SS;VQD86SA;B!K
M[7;A;B`B"B)M96=J96QE;NUT96YI+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX-PIM<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T
M:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R(")!(&OM=N%N="!N
M>65L=BP@:63U>O-N82#I<R!DX71U;69O<FWA='5M(&)EX6QL[73A<V$N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,0IM<V=I9"`B(@HB4V5T('EO
M=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E
M9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S
M='(@(B(*(D)EX6QL[71H873S+"!H;V=Y(&UE;'EI:R!A;&MA;&UA>N%S(&IE
M;&5N:F5N(&UE9R!A(&)E:F5L96YT:V5ZZ7,@=73A;BP@(@HB;6EL>65N('-Z
M[6YE9WG\='1E<W0L(&]L9&%L9G)I<W/M=.ES:2!G>6%K;W)I<^%G;W0@:6QL
M+B!E9WGI8B!B9>%L;.UTX7-O:V%T("(*(G-Z97)E=&YE+B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-S<*;7-G:60@(E-E='5P(@IM<V=S='(@(D)E
MX6QL[73A<V]K(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT
M;6PZ,S<*;7-G:60@(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B
M"FUS9W-T<B`B02!B9>%L;.UTX7-O:V%T(&UE9_IJ[73S('!R;V=R86UO:R#A
M;&QN86L@<F5N9&5L:V5ZZ7-R92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-S4*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE
M('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(D$@;65G861O='0@<&%R
M86WI=&5R('3V8F(@:&5L>65T(&ES(&IE;&5N=&AE=#H@(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(P,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B
M4V5Y8VAE;&QE<R(*;7-G<W1R(")397EC:&5L;&4M<WII9V5T96LB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DX"FUS9VED(")3:&]P<&EN9R(*
M;7-G<W1R(")6X7/A<FSA<R(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C0S"FUS9VED(")3:&]R="!3=6UM87)Y(@IM<V=S='(@(E+V=FED
M(/9S<WIE9F]G;&%LX7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4P
M"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S
M="!L:6YK<S\B"FUS9W-T<B`B16P@:^UVX6YJ82#I<FYI(&%Z(&5G>65S(&9U
M;FMC:?-K870@06QT+6)I;&QE;G1Y^RUK;VUB:6[A8VGS:VMA;"!I<S\B"@HC
M.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C,R,R!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C,S"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C<@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$Q,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*
M;7-G<W1R(")-96=J96QE;NUTZ7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,34U"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R
M<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(B(*(DUU=&%S<W5K(&UE9R!A(&O\;/9N8G/I
M9V5K970@87H@96QM96YT971T(.ES(&%Z(/IJ;VYN86X@;.ET<F5H;WIO='0@
M(@HB:V]N9FEG=7+A8VGS(&OV>O9T="XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#DT"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO
M9V=I;F<@:6X_(@IM<V=S='(@(B(*(DUI;F1E;B!B96IE;&5N=&ME>NES:V]R
M(.UR\V1JZ6L@:VD@82!K;W+A8F)I('5T;VQS\R!B96IE;&5N=&ME>NES(&ED
M96IE/R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8Y"FUS9VED(")3:&]W
M(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(E;A;&%S>G1H873S
M(&QE9WEE;B!A>B!E<F5D971I(&UE9W1A<G3A<V$B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C<Y.0IM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B3&5G
M>65N(&3A='5M=N%L87-Z=/,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3,P"FUS9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM
M<V=S='(@(DQE9WEE;B!E9WD@=.%B;.%Z871K97IE;/4@;65N_'-O<C\B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4S"B,L('!H<"UF;W)M870*;7-G
M:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@(DUU
M=&%S<W5K(&$@)7,@;65N_'0@82!B86P@;VQD86QO;C\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G
M:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS
M9W-T<B`B3NEZ>OQK(&UE9R!TX6)LX7IA="!C96QLX6EN86L@='5L86ID;VYS
MX6=A:70B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I
M97,@9&EA;&]G(@IM<V=S='(@(D[I>GK\:R!M96<@=.%B;.%Z870@='5L86ID
M;VYSX6=A:70B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%)O=R!0
M<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(").Z7IZ_&L@;65G('3A8FSA>F%T
M('-O<F%I;F%K('1U;&%J9&]N<^%G86ET(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")3:&]W
M('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(").Z7IZ_&L@
M;65G(&$@:^EP('1U;&%J9&]N<^%G86ET(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$W-C<*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(DUU=&%S<W5K
M(&$@9F5L=/9L=.ES="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4Q"FUS9VED(")3:&]W97)S(@IM<V=S='(@(EKA<&]R;VLB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM
M<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R("):X7!O<F]K(&3I;&5L]71T
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*
M;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G<W1R("):X7!O<F]K(&3I;'5TX6XO
M97-T92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4T"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R(")(
M96QY:2!ZX7!O<F]K(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA
M9V5R+G!H<#HV,3D*;7-G:60@(E-H<FEN:R(*;7-G<W1R(")+:6-S:6YY[73I
M<R(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z.3$P
M"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z.3<R"B,Z
M(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3`U.`HC.B!L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$Q,C`*(SH@;&EB
M+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,3@S"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(R,PHC.B!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R-3(*(SH@;&EB+TAO<F1E
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C@U"FUS9VED(")3:')I;FL@
M;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@
M9FER<W0B"FUS9W-T<B`B(@HB16SU<WKV<B!K:6-S:6YY[71E;FEE(&ME;&PL
M('9A9WD@96P@:V5L;"!M;WID[71A;FEA(&$@:&5L>65T(&5L9F]G;&%L\R`B
M"B)B;&]K:V]K870N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@
M(E-I97)R82!,96]N92(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z
M,C8V"FUS9VED(")3:6=N('5P(@IM<V=S='(@(MIJ(&9E;&AA<WINX6SS:R!B
M96IE;&5N=&ME>NES92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-S$S"FUS9VED(")3:6=N871U<F4B"FUS9W-T<B`B1&EG:73A;&ES(&%LX>UR
MX7,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM<V=I9"`B
M4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R(")!(&1I9VETX6QI<R!A;.'M
M<N%S(&%L9V]R:71M=7-A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P
M-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S='(@
M(E-Z:6YG87#Z<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY,#`@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$R,3D@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-#$*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(R-3`@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y
M,38@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#D*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C4@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP
M:'`Z-S(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#0*;7-G
M:60@(E-I>F4B"FUS9W-T<B`B3>ER970B"@HC.B!T96UP;&%T97,O;6%I;G1E
M;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N
M86YC92(*;7-G<W1R(")!(&MA<F)A;G1A<G3A<R!K:6AA9WGA<V$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$P(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS
M9VED(")3;&]V86MI82(*;7-G<W1R(")3>FQO=N%K:6$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C`X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3
M;&]V96YI82(*;7-G<W1R(")3>FQO=NEN:6$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VYO=R(*;7-G<W1R
M(")(879A>N%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-38*;7-G:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@(DCS>N%P;W(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM
M<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@(DCS>N%P;W)O:R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")3
M;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B2/-ZX7!O<F]K(&3I;&5L]71T
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*
M;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(DOI<_4@9.EL=73A
M;FDO97-T:2!H\WKA<&]R;VLB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X
M-0IM<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@(D$@:/,@;>EL>7/I9V4Z
M("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@Y"FUS9VED(")3;F]W(&5Q
M=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R(")(\R!V[7IM96YN>6ESZ6=E
M8F5N(&MI9F5J97IV93H@(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM
M<V=S='(@(E-A;&%M;VXM<WII9V5T96LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C$T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#8*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3;VUA;&EA(@IM
M<V=S='(@(E-Z;VWA;&EA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P
M"FUS9VED(")3;VYG<R`F(%!O96US(@IM<V=S='(@(D1A;&]K+"!V97)S96LB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDQ,@IM<V=I9"`B4V]R="!O<F1E
M<B!S96QE8W1I;VXB"FUS9W-T<B`B02!S;W)B87)E;F1E>NES(&ERX6YYX6YA
M:R!K:7;A;&%S>G3A<V$B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-34Y(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-#<*(SH@;&EB+TYE="]335,O
M=VEN7VAT='`N<&AP.C$V-B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y
M"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G<W1R(")&96QA9/-I(&/M;2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-34@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(P-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3@*;7-G:60@(E-O=71H($%F<FEC82(*;7-G<W1R(")$Z6PM069R:6MA(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E-O=71H($5U<F]P
M96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R(")DZ6PM975R\W!A:2`H25-/+3@X
M-3DM,RDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`Q(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S<*;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!3
M86YD=VEC:"!)<VQA;F1S(@IM<V=S='(@(D3I;&DM1V5O<F=I82#I<R!$Z6QI
M(%-A;F1W:6-H+7-Z:6=E=&5K(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S
M(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P
M:&5R92(*;7-G<W1R(")$Z6QI(&;I;'1E:V4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T
M=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R(")3>F]M<WKI9&]S(&-E;&SA
M:R!K]GKV='1I('3A=F]L<^%G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E='=E96X@8V]N
M=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B02!C96QL82!T87)T
M86QM82#I<R!K97)E=&4@:_9Z]G1T:2!TX79O;'/A9R(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HX,3D*;7-G:60@(E-P86-E<B(*;7-G<W1R(")(96QY:VET
M]FQT]2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX,`IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R(")4X79O;'/A9R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-30*;7-G:60@(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B5.%V
M;VQSX6<@Z7,@8F5L<_4@;6%R9_,@8F7A;&SM=.%S(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C@P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E-P86EN
M(@IM<V=S='(@(E-P86YY;VQO<G-ZX6<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3`P"FUS9VED(")3<&%M(@IM<V=S='(@(E-P86UA<W-A<W-I
M;F4@8F7A;&SM=.%S;VLB"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*
M;7-G:60@(E-P96-I86P@0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(E-P96-I
MX6QI<R!K87)A:W1E<B!B979I=&5L92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G:60@(E-P;&ET(&-E
M;&PB"FUS9W-T<B`B02!C96QL82!K971TZ6)O;G3A<V$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V"FUS9VED
M(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B07H@;W-Z;&]P(&ME='3I8F]N=.%S
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*;7-G<W1R(")!('-O<B!K971T
MZ6)O;G3A<V$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*;7-G:60@
M(E-P;W)T<R(*;7-G<W1R(")3<&]R="(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I($QA;FMA(@IM
M<V=S='(@(E-R[2!,86YK82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HV-B!L:6(O0FQO8VLO;65T87(N<&AP.C@Q"FUS9VED(")3=&%N9&%R
M9"(*;7-G<W1R(")3=&%N9&%R9"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(E-T87(@5')E:R(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR-3DP(&QI8B](;W)D92]&;W)M+G!H<#HR
M-SDU"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@(D%Z(&5L<_4@Z78B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,0IM<V=I9"`B4W1A=&4@
M;W(@4')O=FEN8V4B"FUS9W-T<B`BP6QL86T@=F%G>2!T87)T;VWA;GDB"@HC
M.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B
M4W1A='5S(@IM<V=S='(@(L%L;&%P;W0B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C@P,0IM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`B365N=.ES
M:2!F;W)MX71U;2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<S
M"FUS9VED(")3=')E970@061D<F5S<R(*;7-G<W1R(")#[6T@*'5T8V$I(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM
M<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R("+A=&CZ>F]T="(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,C,W"FUS9VED(")3=')I;F<@;&ES="(*;7-G
M<W1R(")3=')I;F<@;&ES=&$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W
M-PIM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS9W-T
M<B`B5/9R]FQJ_&L@82!C[6UB]6P@82!`('5TX6YI('+I<WIT(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM
M<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B4W3M;'5S(%M#4U-=(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM<V=I
M9"`B4W4B"FUS9W-T<B`B5F$B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z
M,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N
M;W0@9F]U;F0N(@IM<V=S='(@(D$H>BD@7"(E<UPB(&%L:_9N>79TX7(@;F5M
M('1A;.%L:&%T\RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R
M+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R(")4X7)G>2(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HS,S8@;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N
M<&AP.C,Q-PIM<V=I9"`B4W5B;6ET(@IM<V=S='(@(DO\;&1J_&L@96PB"@HC
M.B!S:6=N=7`N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI
M='1E9"!R97%U97-T('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U
M(&-A;FYO="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N
M(&%P<')O=F5D+B(*;7-G<W1R("(B"B)<(B5S7"(@^FH@9F5L:&%S>F[A;/,@
M8F5J96QE;G1K97KI<VD@:^ER96QMZ70@=&]VX6)B[71O='1U:RX@UFX@8W-A
M:R`B"B)KZ7)E;&WI;F5K(&5L9F]G863A<^%T(&OV=F5T]65N('1U9"!M86ID
M(&)E:F5L96YT:V5Z;FDN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S='(@(F%L
M<_,@:6YD97@B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`T(&QI8B](;W)D
M92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B
M4W5C8V5S<R(*;7-G<W1R(")3:6ME<OQL="(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<
M(B5S7"(@=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B4VEK97)E<V5N(&AO>GKA
M861T=6L@7"(E<UPB+70@82!R96YD<WIE<FAE>BXB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L
M96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*
M;7-G<W1R(")<(B5S7"(@9F5L:&%S>F[A;/,@861A=&%I="!S:6ME<F5S96X@
M=/9R]FQT_&L@82!R96YD<WIE<F+U;"XB"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R(")3
M:6ME<F5S96X@=/9R]FQT_&L@7"(E<UPB+70N(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3`U"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO
M=F5D(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(E-I:V5R97-E
M;B!E;'3A=F]L[71O='1U:R!<(B5S7"(M="!A(')E;F1S>F5R8O5L+B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U8V-E<W-F=6QL
M>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG
M97,N(@IM<V=S='(@(B(*(D$@:V]N9FEG=7+A8VGS="!S:6ME<F5S96X@=FES
M<WIAX6QL[71O='1U:RX@02!VX6QT;WKA<V]K(&UE9W1E:VEN=.ESZ6AE>B`B
M"B)F<FES<^UT<V4@87H@;VQD86QT+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HU.2!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU-PIM<V=I9"`B4W5C
M8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M(")!(&)A8VMU<"!K;VYF:6=U<N%C:?-T(&5L;65N=&5T=/QK+B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F
M:6QE("5S+B(*;7-G<W1R(")3:6ME<F5S96X@96QM96YT971T_&L@82AZ*2`E
M<R!B86-K=7`@:V]N9FEG=7+A8VGS="XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@
M7"(E<UPB(@IM<V=S='(@(EPB)7-<(B!A9&%T86EN86L@;?-D;W/M=.%S82!S
M:6ME<F5S96X@;65G=/9R=.EN="XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`B4VEK97)E
M<V5N(&5L;65N=&5T=/QK(&$@)7,@X6QL;VWA;GET+B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(Q,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U
M9&%N(@IM<V=S='(@(E-Z=63A;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*;7-G:60@(E-U;6UA<GDB"FUS
M9W-T<B`BUG-S>F5F;V=L86SA<R(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H
M<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B3F%P:V5L=&4B"@HC.B!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U;B!3970B"FUS9W-T
M<B`B3F%P;GEU9W1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-C`*;7-G:60@(E-U;FYY(@IM<V=S='(@(FYA<&]S(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-0IM<V=I9"`B4W5N<FES
M92(*;7-G<W1R(").87!K96QT92(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H
M<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3
M=6YS970B"FUS9W-T<B`B3F%P:V5L=&4O;F%P;GEU9W1A(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-`IM<V=I9"`B4W5N<FES93H@(@IM
M<V=S='(@(DYA<&ME;'1E.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C`X"FUS9VED(")3=6YS970B"FUS9W-T<B`B3F%P;GEU9W1A(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-PIM<V=I9"`B4W5N
M<V5T.B`B"FUS9W-T<B`B3F%P;GEU9W1A.B`B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S"FUS9VED(")3=7!E<G-C<FEP
M="(*;7-G<W1R(")F96QS]2!I;F1E>"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS.#`*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B3VYL:6YE(&MO
M;6UU;FEKX6-I\R`H8VAA="DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C$U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3=7)I;F%M92(*;7-G<W1R
M(")3=7)I;F%M92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<U
M"FUS9VED(")3=7)N86UE(@IM<V=S='(@(D-S86SA9&[I=B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(Q,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@
M(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B4W9A;&)A<F0@Z7,@
M2F%N($UA>65N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P.`IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(E-Z=N%Z
M:6;V;&0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`U(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS9W-T<B`B4W;I9&]R<WKA9R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V
M"FUS9VED(")3=VET>F5R;&%N9"(*;7-G<W1R(")3=N%J8R(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V"FUS9VED(")3>6YC(&QO9R!D96QE
M=&5D(@IM<V=S='(@(D%Z(&%D871S>FEN:W)O;FEZX6-I\W,@;F%P;//A;&QO
M;>%N>70@=/9R]FQT_&LB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30U
M"FUS9VED(")3>6YC34PB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U-13"]+
M97EW;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@
M=&5R;7,B"FUS9W-T<B`B4WII;G1A:W1I:V%I(&AI8F$@82!K97)E<_5K:69E
M:F5ZZ7-B96XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$X(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`W"FUS9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*;7-G
M<W1R(")3>NUR:6%I($%R86(@2_9Z=.%R<V%SX6<B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B5"U3=&]R;2(*
M;7-G<W1R(")::79A=&%R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM<V=S
M='(@(EII=F%T87(L(&5R]7,@<WKI;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8S"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R
M(")::79A=&%R;VLB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV-`IM<V=I9"`B5"U3=&]R;7,@16%R;'DB"FUS9W-T<B`B2V]R
M86D@>FEV871A<F]K(@H*(SH@;&EB+TAO<F1E+T1A=&$O='-V+G!H<#HQ-C8*
M;7-G:60@(E135B!F:6QE(@IM<V=S='(@(E135B`H5$%"(&MA<F%K=&5R<F5L
M(&5L=N%L87-Z=&]T="#I<G3I:V5K*2#A;&QO;>%N>2(*"B,Z(&QI8B](;W)D
M92]522]486)L92YP:'`Z,3,T"FUS9VED(")486)L92(*;7-G<W1R(")4X6)L
MX7IA="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`B
M02!TX6)LX7IA="!T=6QA:F1O;G/A9V%I(@H*(SH@;&EB+TAO<F1E+T9O<FTO
M5'EP92]T86)L97-E="YP:'`Z-3<*;7-G:60@(E1A8FQE(%-E="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P97)T:65S(@IM<V=S='(@(D$@
M=.%B;.%Z870@='5L86ID;VYSX6=A:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,S0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4
M86EW86XB"FUS9W-T<B`B5&%J=F%N(@H*(SH@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(Q.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN
M82(*;7-G<W1R(")486IV86XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C(U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")486II:VES=&%N(@IM<V=S
M='(@(E1A9'IS:6MI<WITX6XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C,U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(E1A;GKA;FEA:2!%9WEE<_QL="!+:7+A
M;'ESX6<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDU"FUS9VED(")487)G970Z(@IM<V=S='(@(D$@8^EL.B(*"B,Z(&-O
M;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#0Y(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ.#D*;7-G:60@(E1A<VMS(@IM<V=S='(@(D9E;&%D871O:R(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<T"FUS9VED(")496QE<&AO
M;F4@3G5M8F5R(@IM<V=S='(@(E1E;&5F;VYS>N%M(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR.3<*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM
M<V=S='(@(D%Z(&5L;?IL="#S<F$@:/5MZ7)SZ6ML971E.B`B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(R,0IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T
M<B`B2/5MZ7)SZ6ML970B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C$R"FUS9VED(")496UP97)A='5R93H@(@IM<V=S='(@(DCU;>ER<^EK
M;&5T.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@R"B,L
M('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E
M<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B2/5MZ7)SZ6ML970\8G(@+SXH)7--
M87@E<R\E<TUI;B5S*2`F9&5G.R5S(@H*(SH@;&EB+TAO<F1E+U1E;7!L871E
M+G!H<#HV.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB
M(&YO="!F;W5N9"XB"FUS9W-T<B`B02AZ*2!<(B5S7"(@<V%B;&]N(&YE;2!T
M86SA;&AA=/,N(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@
M(E1E;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E-A8FQO;F]K(&%D
M;6EN:7-Z=.%C:?-J82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C$U(&QI
M8B](;W)D92]&;W)M+G!H<#HS,S,Q"FUS9VED(")497AT(@IM<V=S='(@(E-Z
M]G9E9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-SD*;7-G:60@(E1E
M>'0@3VYL>2(*;7-G<W1R(")C<V%K('-Z]G9E9R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G:60@(E1E
M>'0@86QI9VXB"FUS9W-T<B`B4WKV=F5G96QH96QY97KI<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E
M>'1T;W`B"FUS9W-T<B`B<WKV=F5G('1E=&5J92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S
M='(@(D-S_"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")4
M:&%I("A425,M-C(P*2(*;7-G<W1R(")T:&%I("A425,M-C(P*2(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(R,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G
M:60@(E1H86EL86YD(@IM<V=S='(@(E1H86EF]FQD(@H*(SH@;&EB+U9&4R]F
M='`N<&AP.C@U,0IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B07H@9G1P(&+U=NUTZ7,@;F5M('1A;.%L:&%T
M\RXB"@HC.B!L:6(O2&]R9&4O2&ES=&]R>2YP:'`Z-34*;7-G:60@(E1H92!(
M:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B02!(:7-T;W)Y
M(')E;F1S>F5R(&W[:_9DZ7-E(&YI;F-S(&5N9V5DZ6QY97IV92XB"@HC.B!L
M:6(O2&]R9&4O2V]L86(N<&AP.CDS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U
M<'!O<G0@7"(E<UPB(@IM<V=S='(@(D$@2&]R9&4O2V]L86(@:6YT96=RX6-I
M\R!E>G0@;F5M('3A;6]G871J83H@7"(E<UPB(@H*(SH@;&EB+TYE="])35-0
M+T)O;VLN<&AP.C$R.3@*;7-G:60@(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@
M8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(D%Z($E-4U`@;F%P;/-ZX7-T(&YE
M;2!S:6ME<OQL="!M96=K97ID96YI+B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED
M(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R(")!($UA:6YT96YA;F-E
M.CH@;W-Z=.%L>2!B973V;'3I<V4@;F5M('-I:V5R_&QT(@H*(SH@<V5R=FEC
M97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I9"`B5&AE($]P=&EO
M;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM<V=S='(@(D%Z($]P
M8VGS(&%B;&%K(&)E>N%R;V1O='0N($MI;.EPZ7,@:_9V971K97II:RXB"@HC
M.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C$X.2!L:6(O2&]R9&4O4&5R;7,N<&AP
M.C(P,"!L:6(O2&]R9&4O4&5R;7,N<&AP.C(Q,0HC.B!L:6(O2&]R9&4O4&5R
M;7,N<&AP.C(R,R!L:6(O2&]R9&4O4&5R;7,N<&AP.C(S-"!L:6(O2&]R9&4O
M4&5R;7,N<&AP.C(U,@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(V-"!L:6(O
M2&]R9&4O4&5R;7,N<&AP.C,P,PIM<V=I9"`B(@HB5&AE(&%D;6EN:7-T<F%T
M;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS
M(&)A8VME;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+B(*
M;7-G<W1R("(B"B)!($IO9V]S=6QT<^%G;VL@:&%S>F[A;&%TX6YA:R!E;/5F
M96QTZ71E;&4L(&AO9WD@82!R96YD<WIE<F=A>F1A("(*(FMO;F9I9W5RX6QJ
M;VX@96=Y(&$@:F]G;W-U;'1SX6=I(&%D871O:V%T('1A<G3S<V%N('3A<F]L
M;FD@:^EP97,@86QR96YD<WIE<G0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O
M;2!S:61E(&]N;'DB"FUS9W-T<B`B0W-A:R!A;'5L(&QE9WEE;B!K97)E="(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@
M(B(*(E1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@
M;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S
M92XB"FUS9W-T<B`B(@HB02!P87)T;F5R(&%Z;VYO<^UT\W-ZX6UA(&YE;2!V
M;VQT(&UE9V%D=F$O_')E<V5N(&UA<F%D="!V86=Y(&%Z(&%D871BX7II<V)A
M;B`B"B)N96T@=F]L="!M96=T86SA;&AA=/,N(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S
M('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS
M9W-T<B`B02!P87)T;F5R(&%D871A:70@<VEK97)E<V5N(&AO>GKA861T=6L@
M82!C[6UJ96=Y>NEKZ6AE>BXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HQ,3<R"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B
M;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E
M+B(*;7-G<W1R("(B"B)+_&SV;N%L;/,@4$=0(&%LX>URX7-I(&)L;VMK('-Z
M_&MSZ6=E<R!A(&1I9VETX6QI<V%N(&%LX>UR="#\>F5N970@(@HB:&ET96QE
M<W/I9^EN96L@96QL96[U<GKI<^EH97HN(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO
M;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N
M:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R("(B
M"B)!(&OV<FQE=NEL;&ES=&$@87IO;F]S[73S<WKA;6$@;F5M('9O;'0@;65G
M861V82_\<F5S96X@;6%R861T('9A9WD@87H@(@HB861A=&+A>FES8F%N(&YE
M;2!V;VQT(&UE9W1A;.%L:&%T\RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@
M=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@(D$@:_9R;&5VZ6QL:7-T82!N
M96T@=F]L="!M96=A9'9A+B(*"B,Z(&QI8B](;W)D92]#<GEP="YP:'`Z,3$V
M"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C
M=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("(B"B)!('1I=&MO<^UTX7-I
M('-Z;VQGX6QT873A<V]K:&]Z(&)I>G1O;G/A9V]S("AT:71K;W/M=&]T="D@
M=V5B(&MA<&-S;VQA="!K96QL+B(*"B,Z(&QI8B](;W)D92YP:'`Z,3<W(&QI
M8B](;W)D92YP:'`Z-3$Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE
M("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B02AZ
M*2`E<R#A;&QO;>%N>6)A;B!S>F5R97!E;&YI92!K96QL96YE(&5G>2`E<R!B
M9>%L;.UTX7-N86LN(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-S`@;&EB+TAO<F1E
M+G!H<#HU,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO
M=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS9W-T<B`B(@HB02AZ
M*2`E<R#A;&QO;>%N>6)A;B!S>F5R97!E;&YI92!K96QL96YE('9A;&%M:6QY
M96X@)7,@8F7A;&SM=.%S*&]K*6YA:RXB"@HC.B!L:6(O5D93+V9I;&4N<&AP
M.C(R-@IM<V=I9"`B5&AE(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET
M<V5L9BXB"FUS9W-T<B`B02!FX6IL(&YE;2!MX7-O;&AA=/,@]FYM86?A<F$N
M(@H*(SH@;&EB+TAO<F1E+T1A=&$N<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@
M8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(D$@9N%J;&)A;B!N96T@=F]L
M="!A9&%T+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP
M.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@
M=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R(")!>B#\>F5N
M970@9F5J;.EC<V]R86D@82!K]G9E=&ME>O5K+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F
M=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I
M=&@@26YT97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@
M=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H
M="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET
M;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@
M268@(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK
M96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R;W1E8W1I;VX@
M1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N
M('=A<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N
M="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS9W-T<B`B(@HB
M02!T96QJ97,@:^EP97)N>?5S(/QZ96UM\V0@<')O8FSI;>%K870@;VMO>FAA
M="!A>B!);G1E<FYE="!%>'!L;W)E<B`B"B)H87-Z;N%L871A(&5S973I;BP@
M;65R="!E8F)E;B!O;'EA;B!P<F]G<F%M:&EBX6L@=F%N;F%K+"!A;6EK970@
M;F5M('1U9'1U;FL@(@HB;65G:V5R_&QN:2X@02!KZ7!E<FYY]6IE(&]L=F%S
M:&%T871L86YNX2!VX6QH870L(&)I>F]N>6]S(&5D:71O<B!F=6YK8VGS:R`B
M"B)H:>%N>6]Z:&%T;F%K(.ES+W9A9WD@=N%R871L86YU;"!L969A9WEH870@
M82!B]FYGZ7-Z]7!R;V=R86TN(%=I;F1O=W,@.7@@(@HB:&%S>F[A;&%T82!E
M<V5TZ6X@;F%G>6]N('9A;/-S>NUN^RP@:&]G>2`G1V5N97)A;"!P<F]T96-T
M:6]N(&9A=6QT)R!H:6)A("(*(FUI871T(/IJ<F$@:V5L;"!I;F3M=&%N:6$@
M;6%J9"!A(&?I<.ET+EQ<;EQ<;D9I9WEE;&UE>G1E='3\:R$@2V%T=&EN='-O
M;B!A>B`B"B)/2R!G;VUB<F$L(&AA(&WI9VES(&UE9R!K[7;A;FIA(&OM<^ER
M96QN:2!A('1E;&IE<R!KZ7!E<FYY]7,@_'IE;6WS9&]T+B(*"B,Z('-E<G9I
M8V5S+W!R969S+G!H<#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED
M96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")!(%PB
M)7-<(B!A>F]N;W/M=/-T(&MI=/9R]FQT_&LN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE
M(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B0W-A:R!B86P@;VQD86QO
M;B!L96=Y96X@:V5R970B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ
M-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y
M(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G
M<W1R("(B"B)!($=N=5!'('!R;V=R86T@:&5L>>ET(&UE9R!K96QL(&%D;FD@
M82!#<GEP=%]P9W`Z.B!O<WITX6QY(&AA<WINX6QA=.%H;WHN(@H*(SH@;&EB
M+TAO<F1E+TU)344O341.+G!H<#HR,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@
M7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A
M<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E
M<G-T;V]D+B(*;7-G<W1R("(B"B)!(&QE=NEL+"!M96QY970@)7,@;F%P:N%N
M(&O\;&3V='0@)7,@8^UM>F5T=&YE:R!<(B5S7"(@=.%R9WEB86XL(&$@8^UM
M>F5T="`B"B)S>N%M[73S9^EPZ6X@;65G:F5L96YT+B!!<G)A(&YI;F-S(&=A
M<F%N8VEA+"!H;V=Y(&5L(&ES(&]L=F%S=.%K(&EL;"X@:&]G>2`B"B)M96?I
M<G1E='3I:RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@X,0IM<V=I9"`B
M5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P
M86=E(@IM<V=S='(@(DUI(&QE9WEE;B!A(&QE=NEL[7+S(&%B;&%K:&]Z(&UU
M=&%T\R!L:6YK(&5L;F5V97KI<V4B"@HC.B!L:6(O1FEL92]#4U8N<&AP.C0W
M-`IM<V=I9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC
M+B(*;7-G<W1R(")!(&UE>O5K('-ZX6UA(&-S86L@;G5M97)I:W5S(.ER=.EK
M(&QE:&5T+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(S,@IM
M<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@
M2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B(@HB07H@;W!E
M;G-S;"!M;V1U;"!S>OQK<^EG97,@82!(;W)D95]#<GEP=%]S;6EM93HZ(&]S
M>G3A;'D@:&%S>F[A;&%TX6AO>BXB"@HC.B!L:6(O2&]R9&4O4')E9G,N<&AP
M.C(X,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<
M(B5S7"(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC
M965D960@=&AE("(*(FUA>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B
M(@HB02!<(B5S7"(@<WIE;>EL>65S(&)EX6QL[73A<R!N96T@;65N=&AE=/4@
M96PL(&UE<G0@;>ER971E(&UE9VAA;&%D:F$@82`B"B)M96=E;F=E9&5T="!M
M87AI;75M;W0B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O9&5B+G!H<#HS
M,B!L:6(O2&]R9&4O34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]W96)C<'`N<&AP.C,W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]S<F-H
M:6=H;&ET92YP:'`Z,S<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS97AC
M96PN<&AP.C,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F]G<F%M
M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U
M;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@HB3F5M('1A;.%L:&%T\R!A
M>B!A('!R;V=R86T@82!S>F5R=F5R96XL(&%M:2!S>OQK<^EG97,@96YN96L@
M87H@861A='3M<'5S;F%K("(*(B@E<RD@82!M96=J96QE;NUTZ7/I:&5Z+B(*
M"B,Z(&QI8B]&:6QE+T-35BYP:'`Z-#@W"FUS9VED(")4:&4@<75O=&4@8VAA
M<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@
M(D%Z(&EDZ7KU:F5L(&MA<F%K=&5R(&-S86L@96=Y971L96X@:V%R86MT97(@
M;&5H970N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S
M(&]N;'DB"FUS9W-T<B`B2F]B8B#I<R!B86P@;VQD86QO;B!L96=Y96X@:V5R
M970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS
M9W-T<B`B0W-A:R!J;V)B(&]L9&%L;VX@;&5G>65N(&ME<F5T(@H*(SH@;&EB
M+T9I;&4O0U-6+G!H<#HT-SD*;7-G:60@(E1H92!S97!A<F%T;W(@;75S="!B
M92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B07H@96QVX6QA<WIT
M\R!K87)A:W1E<B!C<V%K(&5G>65T;&5N(&MA<F%K=&5R(&QE:&5T+B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM
M<V=S='(@(D$H>BD@7"(E<UPB('-Z97)V97)T('3V<O9L=/QK+B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R
M(")!*'HI(%PB)7-<(B!S>F5R=F5R="!E;&UE;G1E='3\:RXB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU
M<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R("(E
M<R!B96IE;&5N=&ME>NES:2!KZ7)E;&WI="!T]G+V;'3\:RXB"@HC.B!L:6(O
M2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C0W,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R`H)60I(&1O97,@;F]T(&5X
M:7-T+B(*;7-G<W1R(")!(&UE9V%D;W1T('-O<B`H)60I(&YE;2!LZ71E>FEK
M+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HQ-SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB
M"FUS9W-T<B`B02AZ*2!<(B5S7"(@:61E:6=L96YE<R!FX6IL(&YE;2!LZ71E
M>FEK+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,S`V"FUS9VED(")4:&4@
M=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H
M92!S8W)E96XN(@IM<V=S='(@(D$@8F7M<G0@<WKV=F5G(&YE;2!E9WEE>FEK
M(&$@:^EP97)N>?5N(&QE=O5V96PN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A
M;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B06QU;"#I<R!F]FS\;"!L
M96=Y96X@:V5R970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@;VYL>2(*
M;7-G<W1R(")#<V%K(&9E;G0@;&5G>65N(&ME<F5T(@H*(SH@;&EB+TAO<F1E
M+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO
M<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@(D$@9F5L=/9L
M=/9T="!A9&%T;VL@87H@96SU>O4@;.EPZ7,@\W1A(&5L=F5S>G1E:RXB"@HC
M.B!L:6(O2&]R9&4O1&%T82]C<W8N<&AP.C(V,B!L:6(O2&]R9&4O1&%T82]T
M<W8N<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T
M(&)E('-A=F5D+B(*;7-G<W1R(")!(&9E;'3V;'3V='0@9N%J;'0@;F5M('-I
M:V5R_&QT(&5L;65N=&5N:2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-#D@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q,`IM<V=I
M9"`B5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(D$@=V5A=&AE<BYC;VT@8FQO:VL@;F5M(&AA<WINX6QH873S+B(*
M"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5M97,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S
M='(@(D$@;65G:F5L96[I<VD@<W3M;'5S("AT:&5M97,I(&%L:_9N>79TX7(@
M7"(E<UPB(&YE;2!T86SA;&AA=/,N(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)
M+G!H<#HQ-S@*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L
M92XB"FUS9W-T<B`B3FEN8W-E;B!VX6QA<WIT:&%T\R!O<&-I\RXB"@HC.B!L
M:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z,S0Y"FUS9VED(")4:&5R92!A
M<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS
M9W-T<B`B3FEN8W,@82!L97;I;"!B96QS96KI8F5N(&UE9VIE;&5N[71H973U
M(&UE;&SI:VQE="XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30P-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C
M=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A
M8W1E<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T
M<B`B(@HB5/IL('-O:R!K87)A:W1E<B!V86X@96)B96X@82!M97KU8F5N+B#6
M;B`E<R!K87)A:W1E<G0@861O='0@;65G.R!A("(*(FUA>&EMX6QI<V%N(&UE
M9V%D:&%T\R!P961I9R!K979E<V5B8BP@;6EN="`E<RXB"@HC.B!S:6=N=7`N
M<&AP.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG(%PB)7-<(B!T;R!T:&4@<WES
M=&5M.B`E<R(*;7-G<W1R(")<(B5S7"(@9F5L:&%S>F[A;/-N86L@82!R96YD
M<WIE<FAE>B!A9.%S86MO<B!H:6)A('3V<G3I;G0N("5S(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3(R"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T
M:&4@<WES=&5M.B`B"FUS9W-T<B`B7"(E<UPB(&9E;&AA<WINX6SS(&%D871A
M:6YA:R!T]G)LZ7-E('-O<N%N(&AI8F$@;.EP971T(&9E;#H@(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@
M(@IM<V=S='(@(EPB)7-<(B!R96YD<WIE<F+U;"!V86SS('3V<FSI<V5K;W(@
M:&EB82!LZ7!E='0@9F5L.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN
M9R!<(B5S7"(Z("5S(@IM<V=S='(@(EPB)7-<(B!M\V1O<^UTX7-A('-O<N%N
M(&AI8F$@;.EP971T(&9E;#H@)7,B"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP
M:'`Z.3(W"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L
M96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB
M"FUS9W-T<B`B(@HB07H@X6QL;VWA;GET(&YE;2!S:6ME<OQL="!A('-Z97)V
M97)R92!F96QT]FQT96YI+B`E<R!N96T@=/9L=/5D]G1T(&9E;"XB"@HC.B!L
M:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3,R"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E
M9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@(B(*(D%Z(.%L;&]MX6YY="!N
M96T@<VEK97+\;'0@82!S>F5R=F5R<F4@9F5L=/9L=&5N:2X@)7,@;F%G>6]B
M8BP@;6EN="!A("(*(FUA>&EMX6QI<V%N(&UE9V5N9V5D971T(&WI<F5T("@E
M9"!BX6IT*2XB"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3,T"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T
M:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L
M;V%D960N(@IM<V=S='(@(B(*(D%Z(.%L;&]MX6YY="!N96T@<VEK97+\;'0@
M82!S>F5R=F5R<F4@9F5L=/9L=&5N:2X@02AZ*2`E<R!FX6IL;F%K(&-S86L@
M96=Y("(*(G+I<WIE('3V;'3U9/9T="!F]FPN(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(D$@
M;&5VZ6P@92!RZ7-ZZ6YE:R!M96=J96QE;NUTZ7-E:V]R(&AI8F$@=/9R=.EN
M="(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G
M<W1R(")!('!A<G1N97(@861A=&]K(&EM<&]R=.%LX7-A('-O<N%N(&AI8F$@
M=/9R=.EN="XB"@HC.B!L:6(O2&]R9&4O1&%T82]I;6,N<&AP.C,Q"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@
M9&%T82XB"FUS9W-T<B`B07H@:4-A;&5N9&%R(&%D871O:R!I;7!O<G3A;.%S
M82!S;W+A;B!H:6)A('3V<G3I;G0N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HX,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C
M;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB
M<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(B(*(DAI8N%S(&$@;65G861O='0@
M:V]N9FEG=7+A8VGS+B!,96AE="P@:&]G>2!N96T@=/9L=/9T="!K:2!E9WD@
M<WK\:W/I9V5S("(*(FUE>O5T+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P
M97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N
M+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B)!('!A
M<G1N97)J96=Y>NEK:V5L(&MA<&-S;VQA=&]S(&9E;&%D870@=NEG<F5H86IT
MX7-A('-O<N%N(&AI8F$@;.EP971T(&9E;"X@(@HB2^ER96T@<'+S8N%L:F$@
M;65G(&OI<_5B8BXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@
M=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB
M"FUS9W-T<B`B(@HB2&EB82!T]G)TZ6YT(&$@<&%R=&YE<B!A9&%T86EN86L@
M9G)I<W/M=.ES92!S;W+A;BX@2^ER96T@<'+S8N%L:F$@;65G(&OI<_5B8BXB
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U(&QI8B].
M970O4TU3+W=I;E]H='1P+G!H<#HR,C(*;7-G:60@(B(*(E1H97)E('=A<R!A
M;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S
M92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(D$@:_9R;&5VZ6QL:7-T
M82!A9&%T86EN86L@9G)I<W/M=.ES92!S;W+A;B!H:6)A('3V<G3I;G0N($OI
M<F5M('!R\V+A;&IA(&UE9R`B"B)KZ7/U8F(N(@H*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C$T.`IM<V=I9"`B5&AI<R!)34%0('-E<G9E
M<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B
M(@HB17H@87H@24U!4"!S>F5R=F5R(&YE;2!TX6UO9V%T:F$@82!M87!PX6MH
M;WH@=F%L\R!H;WIZX6;I<NES(&UE9V]S>G3A<^%T+B(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]R87(N<&AP.C0X"FUS9VED(")4:&ES(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R(")%
M>B!N96T@=/MN:6L@<WIA8N%L>6]S(')A<B#A;&QO;>%N>6YA:RXB"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D
M;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T
M<B`B17H@;F5M('3[;FEK('-Z86+A;'EO<R!Z:7`@X6QL;VWA;GEN86LN(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,S$*;7-G:60@(E1H:7,@9&]E<R!N
M;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R(")%
M>B!N96T@=/MN:6L@Z7)VZ6YY97,@:^%R='EA<WKA;6YA:RXB"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T
M:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G871E
M=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB17H@82!M96=H
M86IT\R!L96AE=/5VZ2!T97-Z:2P@:&]G>2!(5%10+6MA<&-S;VQA=&]N(%--
M4RUT(&O\;&1J_&YK(&$@(@HB0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E
M;&PN8V]M*2!S>F]L9^%L=&%T\VX@X70N(@H*(SH@;&EB+TYE="]335,O=VEN
M7VAT='`N<&AP.C$S-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E
M;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN
M<&QC+F-O;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S
M='(@(B(*(D5Z(&$@;65G:&%J=/,@;&5H973U=ND@=&5S>FDL(&AO9WD@2%14
M4"UK87!C<V]L871O;B!335,M="!K_&QD:OQN:R!A(%=)3B`B"B(H:'1T<#HO
M+W=I;G!L8RYC;VTI('-Z;VQGX6QT873S;B#A="XB"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"FUS9VED("(B"B)4:&ES(&1R:79E
M<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R
M96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN
M9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB17H@82!M96=H86IT\R!L96AE
M=/5VZ2!T97-Z:2P@:&]G>2!(5%10+6MA<&-S;VQA=&]N(%--4RUT(&O\;&1J
M_&YK(&%Z("(*(G-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI('-Z
M;VQGX6QT873S;B#A="XB"@HC.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY
M7W-M='`N<&AP.C@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N
M9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N
M92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N
M($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N
M92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"B)%>B!A
M(&UE9VAA:G3S(&QE:&5T]7;I('1E<WII+"!H;V=Y(%--5%`M:V%P8W-O;&%T
M;VX@4TU3+70@:_QL9&K\;FL@5F]D869O;F4@(@HB<WKA;6]K<F$@82!6;V1A
M9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I('-Z;VQGX6QT873S;B#A
M="X@02`B"B)S>F]L9^%L=&%TX7,@:6?I;GEB97;I=&5LZ6AE>B!6;V1A9F]N
M92!)=&%L>2!E;6%I;"!C[6T@<WK\:W/I9V5S+B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HY.#(@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-C$@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$P.3`*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,3D@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$Q.#8@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-C`*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S,#D@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$T,#(@;&EB+TAO<F1E+T9O<FTN<&AP.C$U-C$*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$X-#,@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-C(@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(P,#D*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,S,@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(P.#(@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q-3,*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R,C4@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(T,3(@;&EB+TAO<F1E+T9O<FTN<&AP.C(T-30*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(V-#$@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,30@;&EB+TAO<F1E
M+T9O<FTN<&AP.C,Q,C,*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,#$@;&EB
M+TAO<F1E+T9O<FTN<&AP.C,X,#D@;&EB+TAO<F1E+T9O<FTN<&AP.C,X,3<*
M;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@(D5Z(&$@
M;65Z]2!N96T@;6%R861H870@_')E<RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3`V.0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN
M=&5G97)S+B(*;7-G<W1R(")%8F)E;B!A(&UE>O5B96X@8W-A:R!E9^ES>B!S
M>N%M;VL@X6QL:&%T;F%K+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-#(P
M"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A
M;F0@=&AE(&-O;&]N+B(*;7-G<W1R(")%8F)E;B!A(&UE>O5B96X@8W-A:R!E
M9^ES>B!S>N%M;VL@Z7,@:V5T=/5S<&]N="!L96AE="XB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3`Y.`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C
M;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B16)B96X@82!M97KU8F5N
M(&-S86L@;VMTX6QI<R!S>N%M;VL@X6QL:&%T;F%K+B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,3(W"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C
M;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G
M<W1R("(B"B)%>B!A(&UE>O4@8W-A:R!V97-S>O5V96P@=F%G>2!S>O-K]GIZ
M96P@96QVX6QA<WIT;W1T(&5GZ7-Z('-ZX6UO:V%T("(*(G1A<G1A;&UA>FAA
M="(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY.3,*;7-G:60@(E1H:7,@9FEE
M;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`B17H@87H@Z7)T
MZ6L@8W-A:R!S>N%M(&QE:&5T+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M.#(R"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R
M(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G
M(S$R,S1A9B<N(@IM<V=S='(@(D5B8F5N(&$@;65Z]6)E;B!H97AA9&5C:6WA
M;&ES(%)'0B!S>NUN:_-D(.%L;&AA="P@<&PN("<C,3(S-&%F)RXB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z-38U"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L
M<F5A9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@(D5Z96X@861A=&]K:V%L
M(&MA<&-S;VQA=&]S(&9E;&%D871O:V%T(&$@<WIE<G9E<B!MX7(@96QVZ6=E
M>G1E+B(*"B,Z('1E;7!L871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@(D5Z("5S(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HT-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@
M=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@
M=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@
M1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I
M<VET("5S(@IM<V=S='(@(B(*(D5Z(&5G>2!+;VQA8B!'<F]U<'=A<F4@;V)J
M96MT=6TN($%Z(&EL>65N(&]B:F5K='5M(&UE9VIE;&5N[73I<^EH97H@;VQY
M86X@(@HB96UA:6P@:VQI96YS<')O9W)A;2!S>OQK<^EG97,L(&%M96QY(&OI
M<&5S(&$@2V]L86(@1W)O=7!W87)E(&9O<FWA='5M("(*(FME>F5LZ7/I<F4N
M($EL>65N(&5M86EL(&ML:65N<V5K(&QI<W3A:F$@;.%T:&%T\R!I='0Z("5S
M(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C4Y.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C
M:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T
M<B`B17IT(&$@;&5V96QE="!MX7,@:V%R86MT97)KZ7-Z;&5T=&5L("@E<RD@
M[7)TX6LL(&UI;G0@86UI="#6;B!H87-Z;N%L+B(*"B,Z(&QI8B](;W)D92]0
M<F5F<R]522YP:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T
M(&QE87-T(&]N92XB"FUS9W-T<B`B17H@82!S>N%M(&YE;2!L96AE="!E9WEN
MZ6P@:VES96)B+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]G>FEP+G!H<#HT
M-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD
M(&=Z:7`@9FEL97,N(@IM<V=S='(@(D5Z(&$@<WIE<G9E<B!N96T@:^EP97,@
M:VEB;VYT86YI(&$@>FEP(&EL;"X@9WII<"#A;&QO;>%N>6]K870N(@H*(SH@
M;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HQ.#D*;7-G:60@(E1H:7,@<WES=&5M
M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"XB"FUS9W-T<B`B17H@82!R96YD
M<WIE<B!J96QE;FQE9R!I;F%K=&EVX6QV82!V86XN(@H*(SH@;&EB+TAO<F1E
M+U!R969S+U5)+G!H<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@;75S="!B92!A
M(&YU;6)E<BXB"FUS9W-T<B`B17H@87H@Z7)TZ6L@8W-A:R!S>N%M(&QE:&5T
M+B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G
M:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N
M<R!W:6YD;W<B"FUS9W-T<B`B17IT(&%Z(&%B;&%K(&-S86L@87H@3W!C:?-K
M(&%B;&%K8O-L(&CM=FAA=/,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R(")6:6QL
MX6ULX7,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,V"FUS9VED
M(")4:6-K971S(@IM<V=S='(@(DAI8F%B96IE;&5N=.ES+6ME>F5LZ7,B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0R.2!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR-34*;7-G:60@(E1I;64B"FUS9W-T<B`B263U(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X.`IM<V=I9"`B5&EM92!4<F%C:VEN
M9R(*;7-G<W1R(")-=6YK86ED]2UN>6EL=N%N=&%R=.%S(@H*(SH@;&EB+T)L
M;V-K+W1I;64N<&AP.C$W"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R("))
M9/4@9F]R;>%T=6TB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4S-0IM<V=I
M9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B263U(';A;&%S>G3A<R(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(R,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*
M;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@(DME;&5T+51I;6]R(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@;&EB+T)L;V-K
M+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@(E1I='5L=7,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDV
M"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@(D/M;2`H=&]O;'1I
M<"DB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM
M<V=I9"`B5&\B"FUS9W-T<B`B0^UM>F5T="(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HV-30*;7-G:60@(B(*(E1O('-E;&5C="!M
M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@
M0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@
M(B(*(DAA('3V8F(@96QE;65T(&ES(&MI(&%K87(@:F5L]FQN:2P@=&%R='-A
M(&QE;GEO;79A(&$@0V]N=')O;"`H4$,I('9A9WD@82`B"B)#;VUM86YD("A-
M86,I(&)I;&QE;G1Y^W0@82!K871T:6YTX7,@:_9Z8F5N+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`*;7-G:60@(E1O9&%Y(@IM<V=S
M='(@(DUA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@(DA4
M34P@9F]R<N%S;NEZ970@:VDO8F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C(S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4;V=O(@IM<V=S='(@
M(E1O9V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(V(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$P"FUS9VED(")4;VME;&%U(@IM<V=S='(@(E1O:V5L874B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`R"FUS9VED(")4;VUO
M<G)O=R(*;7-G<W1R(")(;VQN87`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C(Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G<W1R
M(")4;VYG82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW-PIM<V=I9"`B5&]P(@IM<V=S='(@(F;V;/QL(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I
M9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R("),96=F96QS]2!F<F%M92`H
M7W1O<"DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R
M86YS;&%T:6]N<R(*;7-G<W1R(")&;W)D[73A<V]K(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(S,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5')I
M;FED860@86YD(%1O8F%G;R(*;7-G<W1R(")4<FEN:61A9"#I<R!4;V)A9V\B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<Y-`IM<V=I9"`B5')U92!O<B!F
M86QS92(*;7-G<W1R("))9V%Z('9A9WD@:&%M:7,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G
M<W1R(")+92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B5'5NZ7II82(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(R.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3$*;7-G:60@(E1U<FME>2(*;7-G<W1R(")4]G+V:V]R<WKA9R(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")4=7)K:7-H("A)4T\M.#@U
M.2TY*2(*;7-G<W1R(")T]G+V:R`H25-/+3@X-3DM.2DB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C(W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,CD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4
M=7)K;65N:7-T86XB"FUS9W-T<B`B5/QR:VUE;FES>G3A;B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(S,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@
M(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R(")4=7)K<RT@Z7,@
M0V%I8V]S+7-Z:6=E=&5K(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5V86QU(@IM<V=S='(@(E1U
M=F%L=2(*"B,Z(&QI8B](;W)D92]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y
M;W5R(&-H;VEC93H@(@IM<V=S='(@(LUR:F$@8F4L(&UI="!VX6QA<WIT;W1T
M.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4X"FUS9VED
M(")5+E8N(&EN9&5X.B`B"FUS9W-T<B`B558@:6YD97@Z("(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A
M;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T,0IM<V=I9"`B55),(&9O<B!Y
M;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S='(@(B(*
M(E523"P@;65L>65N(&5G>2!P<F]G<F%M(&5L9F]G861J82!A('-Z;VQGX6QT
M873S(.%L=&%L(&O\;&3V='0@:_QL9/9T="`B"B)KZ7IB97/M=.ES:2!J96QE
M;G3I<W0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDW"FUS9VED(")54DPZ(@IM<V=S='(@(E523#HB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C,W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")5
M9V%N9&$B"FUS9W-T<B`B56=A;F1A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(S-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56MR86EN92(*;7-G
M<W1R(")5:W)A:FYA(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HT,3D*;7-G:60@
M(E5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F5M
M('-I:V5R_&QT(&$@5D93(&%L:_9N>73A<F)A(&)E;.EP;FDN(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B56YA8FQE('1O(&%D
M9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"XB"FUS
M9W-T<B`B(@HB02!B96IE;&5N=&ME>NES:2!J;V=O<W5L='/A9R!I9^EN>6SI
M<V5K;W(@;F5M('-I:V5R_&QT(&%Z(&%D871O:R!E;'3A<F]LX7-A+B(*"B,Z
M(&QI8B]61E,O9G1P+G!H<#HS.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N
M(@IM<V=S='(@(B(*(DYE;2!S:6ME<OQL="!A*'HI(%PB)7-<(B!61E,@9N%J
M;"!E;.ERZ7-I(&IO9V]S=6QT<^%G86ET(&UE9W;A;'1O>G1A=&YI+B(*"B,Z
M(&QI8B]61E,O9FEL92YP:'`Z,SDR(&QI8B]61E,O;75S<6PN<&AP.C0V.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I
M;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("(B"B).96T@<VEK97+\
M;'0@82AZ*2`E<R\E<R!61E,@9N%J;"!E;.ERZ7-I(&IO9V]S=6QT<^%G86ET
M(&UE9W;A;'1O>G1A=&YI+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW.#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS
M9W-T<B`B3F5M('-I:V5R_&QT(&$H>BD@)7,@86QK]FYY=G3A<F)A(&)E;.EP
M;FDN(@H*(SH@;&EB+U9&4R]F='`N<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7-<(BXB"FUS
M9W-T<B`B02AZ*2!<(B5S7"(@X6QL;VWA;GD@;>ER971E(&YE;2#A;&QA<.UT
M:&%T\R!M96<N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HV.34@;&EB+U9&4R]S
M<6PN<&AP.C$P,C@@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z.#4P"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E
M<R\E<UPB+B(*;7-G<W1R(")!*'HI(%PB)7,O)7-<(B#A;&QO;>%N>2!MZ7)E
M=&4@;F5M(.%L;&%P[71H873S(&UE9RXB"@HC.B!L:6(O2&]R9&4O075T:"]S
M<6PN<&AP.C0S.0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E
M<G9E<BXB"FUS9W-T<B`B07H@4U%,('-Z97)V97(@;F5M(.ER:&5T]2!E;"XB
M"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#<P"FUS9VED(")5;F%B;&4@=&\@8V]N
M;F5C="!W:71H(%-33"XB"FUS9W-T<B`B07H@4U-,(&MA<&-S;VQA="!N96T@
MZ7#M=&AE=/4@9F5L+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C,R(&QI8B]6
M1E,O9FEL92YP:'`Z,C,W(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(P-`HC.B!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HR,#D@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z
M,C$W"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B
M02!61E,@9N%J;"!N96T@;>%S;VQH873S(.%T+B(*"B,Z(&QI8B]61E,O9G1P
M+G!H<#HS-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T
M92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B3F5M('-I:V5R_&QT
M(&$H>BD@7"(E<UPB(%9&4R!A;&OV;GEV=.%R="!LZ71R96AO>FYI+B(*"B,Z
M(&QI8B]61E,O9FEL92YP:'`Z,S8Q(&QI8B]61E,O;75S<6PN<&AP.C(U."!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HR-C0*;7-G:60@(E5N86)L92!T;R!C<F5A
M=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F5M('-I:V5R_&QT(&SI=')E
M:&]Z;FD@82!61E,@86QK]FYY=G3A<G0N(@H*(SH@;&EB+U9&4R]M=7-Q;"YP
M:'`Z,3(T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G
M<W1R(").96T@<VEK97+\;'0@;.ET<F5H;WIN:2!A(%9&4R!FX6IL="XB"@HC
M.B!L:6(O5D93+W-M8BYP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(D$H
M>BD@7"(E<UPB(%9&4R!M87!P82!N96T@:&]Z:&%T\R!LZ71R92XB"@HC.B!L
M:6(O5D93+V9I;&4N<&AP.C(W,@IM<V=I9"`B56YA8FQE('1O(&-R96%T92!E
M;7!T>2!61E,@9FEL92XB"FUS9W-T<B`B3F5M('-I:V5R_&QT(&SI=')E:&]Z
M;FD@_')E<R!61E,@9N%J;'0N(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+W1A
M<BYP:'`Z-S8@;&EB+TAO<F1E+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"FUS9VED
M(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R(")!('3V;?9R
M[71E='0@X6QL;VWA;GET(&YE;2!S:6ME<OQL="!K:6)O;G1A;FDN(@H*(SH@
M;&EB+U9&4R]S;6(N<&AP.C(R."!L:6(O5D93+V9T<"YP:'`Z,S`S"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@
M9&ER96-T;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B7"(E<UPB(&YE;2!T
M]G+V;&AE=/4L(&%Z(&%L:_9N>79TX7(@;F5M(/QR97,N(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB
M"FUS9W-T<B`B7"(E<UPB('3V<FSI<V4@;F5M('-I:V5R_&QT.B`E<RXB"@HC
M.B!L:6(O5D93+V9I;&4N<&AP.C,S."!L:6(O5D93+W-Q;"YP:'`Z,SDU(&QI
M8B]61E,O;75S<6PN<&AP.C,Q,0HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS
M-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@
M=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B)7,@;F5M('3V
M<O9L:&5T]2P@87H@86QK]FYY=G3A<B!N96T@_')E<RXB"@HC.B!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HS-38@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S8P"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E
M;'DN(@IM<V=S='(@(D$@5D93(&%L:_9N>79TX7(@;F5M('3V<O9L:&5T]2!R
M96MU<GKM=F%N+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S0T(&QI8B]61E,O
M;75S<6PN<&AP.C,R,B!L:6(O5D93+VUU<W%L+G!H<#HS,S4*(SH@;&EB+U9&
M4R]M=7-Q;"YP:'`Z,S0S(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,U,@IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")!
M(%9&4R!A;&OV;GEV=.%R(&YE;2!T]G+V;&AE=/4N(@H*(SH@;&EB+U9&4R]S
M<6PN<&AP.C0R,"!L:6(O5D93+W-Q;"YP:'`Z-#,R"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N(@IM
M<V=S='(@(D$@5D93(&%L:_9N>79TX7(@;F5M('3V<O9L:&5T]3H@)7,N(@H*
M(SH@;&EB+U9&4R]F='`N<&AP.C(Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B02AZ
M*2!<(B5S7"(@5D93(&;A:FP@;F5M('3V<O9L:&5T]2XB"@HC.B!L:6(O5D93
M+V9I;&4N<&AP.C,Q,"!L:6(O5D93+W-Q;"YP:'`Z,CDQ(&QI8B]61E,O;75S
M<6PN<&AP.C$V-PHC.B!L:6(O5D93+VUU<W%L+G!H<#HQ.#`@;&EB+U9&4R]M
M=7-Q;"YP:'`Z,3@W(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,Y,0HC.B!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HS.3D*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M5D93(&9I;&4N(@IM<V=S='(@(D$@5D93(&;A:FP@;F5M('3V<O9L:&5T]2XB
M"@HC.B!L:6(O5D93+W-M8BYP:'`Z,C0X"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@
M(D$H>BD@7"(E<UPB(%9&4R!M87!P82!N96T@=/9R]FQH973U+B(*"B,Z(&QI
M8B]61E,O<W%L+G!H<#HT,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R(").96T@
M=NEG97IH973S(')E:W5R>NUV('3V<FSI<R!A(%9&4RUB96XZ("5S+B(*"B,Z
M(&QI8B]61E,O9G1P+G!H<#HX,S0*;7-G:60@(E5N86)L92!T;R!D971E<FUI
M;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(DYE;2!H873A<F]Z:&%T
M\R!M96<@82!J96QE;FQE9R#I<G;I;GEE<R!A;&OV;GETX7(N(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,#0*;7-G:60@(E5N86)L92!T;R!E
M>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B02!T86[Z<^UT
M=N%N>2!RZ7-Z;&5T97,@861A=&%I(&YE;2!H873A<F]Z:&%T\VL@;65G(@H*
M(SH@;&EB+TYE="])35-0+G!H<#HT,S<@;&EB+TYE="])35-0+T%U=&@N<&AP
M.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@
M9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B3F5M('-I:V5R_&QT(&)E;VQV
M87-N:2`E<R!D969I;NUC:?-JX70N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR
M,#,@;&EB+U9&4R]F:6QE+G!H<#HR,#@@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z
M,3<T"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$W.0IM<V=I9"`B56YA8FQE
M('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(D$@5D93(&;A:FP@;F5M(&AE
M;'EE>FAE=/,@X70N(@H*(SH@;&EB+U9&4R]S;6(N<&AP.CDS(&QI8B]61E,O
M<VUB+G!H<#HQ,#8@;&EB+U9&4R]S;6(N<&AP.C8U,@HC.B!L:6(O5D93+V9T
M<"YP:'`Z.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@
M5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")!*'HI(%PB)7-<(B!61E,@9N%J
M;"!N96T@;GEI=&AA=/,@;65G+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C@T
M(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$S."!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HQ-#$*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET
M:6YG+B(*;7-G<W1R(")!(%9&4R!FX6IL(&YE;2!N>6ET:&%T\R!M96<@[7+A
M<VD@8^EL;&%L+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z.#,@;&EB+U9&4R]F
M:6QE+G!H<#HQ,S<@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S8*;7-G:60@(E5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R(")!(%9&4R!FX6IL(&YE
M;2!N>6ET:&%T\R!M96<@+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T
M9WHN<&AP.C0U"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R
M8VAI=F4N(@IM<V=S='(@(D$@=/9M]G+M=&5T="#A;&QO;>%N>2!N96T@;GEI
M=&AA=/,@;65G+B(*"B,Z(&QI8B]61E,N<&AP.C@U-@IM<V=I9"`B56YA8FQE
M('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T
M<B`B02!61E,@9N%J;"!N96T@;VQV87-H873S("AA(&9I;&5S:7IE*"D@<VEK
M97)T96QE;B!V;VQT*2XB"@HC.B!L:6(O5D93+G!H<#HX.#<*;7-G:60@(E5N
M86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN
M(@IM<V=S='(@(D$@5D93(&;A:FP@;F5M(&]L=F%S:&%T\R`H82!G971&:6QE
M4VEZ92@I('-I:V5R=&5L96X@=F]L="DN(@H*(SH@;&EB+TAO<F1E+U-E<W-I
M;VY(86YD;&5R+VYO;F4N<&AP.C,X"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F
M:6QE.B`B"FUS9W-T<B`B17H@82!FX6IL(&YE;2!O;'9A<VAA=/,Z("(*"B,Z
M(&QI8B]61E,O9FEL92YP:'`Z-C<V"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T
M:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(D$@=F9S<F]O="!A;&OV
M;GEV=.%R(&YE;2!O;'9A<VAA=/,N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HQ,3`Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*
M;7-G<W1R("(E<R!N96T@;F5V97IH973U(.%T("5S(&[I=G)E.B!MX7(@;.ET
M97II:R!I;'EE;B!N97;[(&UA<'!A(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z,S`Q"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN
M(@IM<V=S='(@(D$@5D93(&%L:_9N>79TX7(@;F5M(&YE=F5Z:&5T]2#A="XB
M"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,S,R"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@
M(D$@5D93(&%L:_9N>79TX7(@;F5M(&YE=F5Z:&5T]2#A=#H@)7,N(@H*(SH@
M;&EB+U9&4R]S;6(N<&AP.C(W,2!L:6(O5D93+V9T<"YP:'`Z,S0X"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E
M<UPB+B(*;7-G<W1R(")!*'HI(%PB)7-<(B!61E,@9N%J;"!N96T@;F5V97IH
M973U(.%T+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-C$W(&QI8B]61E,O;75S
M<6PN<&AP.C(R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N
M86UE(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R(")!*'HI("5S+R5S(%9&4R!F
MX6IL(&YE;2!N979E>FAE=/4@X70N(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C,R
M-B!L:6(O5D93+VUU<W%L+G!H<#HR,3,@;&EB+U9&4R]M=7-Q;"YP:'`Z-#4R
M"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(Y,R!L:6(O5D93+W-Q;%]F:6QE
M+G!H<#HS,#D*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N(@IM
M<V=S='(@(D$@5D93(&;A:FP@;F5M(&YE=F5Z:&5T]2#A="XB"@HC.B!L:6(O
M5D93+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O
M(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@(D%Z("=M:VES;V9S)R!P<F]G<F%M
M(&YE;2!F=71T871H873S+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M
M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E('1H:7,@
M5V]R9"!D;V-U;65N="(*;7-G<W1R(").96T@<VEK97+\;'0@;&5F;W)D[71A
M;FD@97IT(&$@5V]R9"!D;VMU;65N='5M;W0B"@HC.B!L:6(O5D93+V9T<"YP
M:'`Z,34T(&QI8B]61E,O9G1P+G!H<#HQ-3<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M02AZ*2!<(B5S7"(@5D93(&;A:FP@;F5M(.UR:&%T\RXB"@HC.B!L:6(O5D93
M+V9I;&4N<&AP.C$X-@IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B02!61E,@9N%J;"!N96T@[7)H
M873S("AA(&-O<'DH*2!S:6ME<G1E;&5N('9O;'0I+B(*"B,Z(&QI8B]61E,O
M9FEL92YP:'`Z,C@X(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$T-B!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HQ-3$*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@
M9FEL92!D871A+B(*;7-G<W1R(")!(%9&4R!FX6IL(&%D871A:2!N96T@[7)H
M873S:R!K:2XB"@HC.B!L:6(O5D93+G!H<#HX-C(*;7-G:60@(E5N86)L92!T
M;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"XB"FUS
M9W-T<B`B02!61E,@9N%J;"#M<N%S82!K=O-T873Z;&SI<.ES(&UI871T(&YE
M;2!F96IE>FAE=/4@8F4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(F%L
MX6CZ>F]T="(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@
M(E5N9&\@0VAA;F=E<R(*;7-G<W1R(")-Z6=S92!M96YT<_QK(&5L(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PIM<V=I
M9"`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B5FES<WIA=F]N
M:F$@87H@=71O;'/S(';A;'1O>G1A=.%S="(*"B,Z(&QI8B](;W)D92])34%0
M+T%#3"]R9F,R,#@V+G!H<#HR,C$@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,X.`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E
M<G9E<B!O;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`B(@HB02!K87!C<V]L870@
M9F5L=NET96SI="!K]G9E=/5E;B!VX7)A=&QA;B!VX6QA<WH@Z7)K97IE='0@
M82!S>F5R=F5R=/5L.B`B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,C$W(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,SD*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@R"FUS9VED(")5;F5X<&5C=&5D
M(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B5N%R871L86X@
M=N%L87-Z(.ER:V5Z971T(&$@<WIE<G9E<G3U;"!E<G)E.B`B"@HC.B!L:6(O
M2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV,0IM<V=I9"`B56YF
M:6QE9"(*;7-G<W1R(")"97-O<F]L871L86XB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y-@IM<V=I9"`B56YI8V]D92`H551&+3@I(@IM<V=S='(@(E5N
M:6-O9&4@*%541BTX*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C4V"FUS9VED(")5;FET960@07)A8B!%;6ER871E<R(*
M;7-G<W1R(")%9WEE<_QL="!!<F%B($5M[7)SZ6=E:R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(S-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B56YI
M=&5D($MI;F=D;VTB"FUS9W-T<B`B16=Y97/\;'0@2VERX6QY<^%G(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,PIM
M<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R(")%9WEE<_QL="#!;&QA;6]K
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S.2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA
M;F1S(@IM<V=S='(@(D5G>65S_&QT(,%L;&%M;VLL(&MI<V5B8B!K_&QS]2!S
M>FEG971E:R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV,B!L
M:6(O0FQO8VLO;65T87(N<&AP.C<X"FUS9VED(")5;FET<R(*;7-G<W1R(")E
M9WESZ6<B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,CD@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z-#,P"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]T9WHN<&AP.C4X"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(DES;65R971L
M96XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM
M<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*;7-G
M<W1R("))<VUE<F5T;&5N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@
M(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T
M<B`B27-M97)E=&QE;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#<*;7-G:60@(E5N
M:VYO=VX@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(D$@;65G861O='0@
M:&5L>2!I<VUE<F5T;&5N+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A<W-W
M;W)D+B(*;7-G<W1R("))<VUE<F5T;&5N(&9E;&AA<WINX6SS:2!NZ78@=F%G
M>2!J96QS>O,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@
M96QE;65N="(*;7-G<W1R(")4X79O;.UT<W5K(&5L(&EN;F5N(&$@;&EN:V5T
M(@H*(SH@;&EB+TAO<F1E+TED96YT:71Y+G!H<#HS,#(*;7-G:60@(E5N;F%M
M960B"FUS9W-T<B`B3FEN8W,@96QN979E>G9E(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV
M:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P
M<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N("!#;&EC
M:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W
M:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C
M8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"B)":7IT;VYSX6=I(&]K
M;VMB\VP@82!F96QH87-Z;N%L\VD@<')O9W)A;6]K(&YE;2!H87-Z;N%L:&%T
M:N%K(&$@2VEVX6?A<R\B"B)-X7-O;.%S+T)E:6QL97-Z=.ES(&WS9'-Z97)T
M+B!+871T:6YT<V]N(&%Z($]+(&=O;6)R82P@:&$@82!M;WII;&QA+F]R9R`B
M"B)W96)O;&1A;&]N(&5L(&OM=N%N:F$@;VQV87-N:2!A('1E8VAN:6MA:2!L
M9>URX7-T(&UE;'D@;65G861J82P@:&]G>6%N(&QE:&5T("(*(F5Z="!MZ6=I
M<R!E;F=E9.EL>65Z;FDN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@IM<V=I9"`B56YS970@8V]L;W(B"FUS
M9W-T<B`B02!S>NUN('9I<W-Z8>%L;.UTX7-A(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HV.#<@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HY
M,C<*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HY,S,*;7-G:60@(E5N
M<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R(").96T@=.%M;V=A=&]T="!E
M>'1E;GII\R(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,3DW('1E;7!L
M871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS
M9W-T<B`B3?-D;W/M=.%S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHR.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS
M9W-T<B`B)7,@861A=&%I;F%K(&WS9&]S[73A<V$B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"FUS9VED(")5<&1A=&4@=7-E<B(*
M;7-G<W1R(")!(&9E;&AA<WINX6SS(&%D871A:6YA:R!M\V1O<^UTX7-A(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I="YP:'`Z
M,3`R('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@(EPB)7-<(B!VX6QT
M;WKA<V%I="!E;&UE;G1E='3\:RXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HX,PIM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T
M<B`B07H@=7!G<F%D92!P<F]G<F%M;W0@=/9R]FQT_&LN(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$W."!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3DX"FUS9VED(")5<&QO860B"FUS9W-T<B`B1F5L=/9L=.ES
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D
M960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N
M(@IM<V=S='(@(D%Z(/9S<WIE<R!A;&MA;&UA>N%S(&MO;F9I9W5RX6-I\VKA
M="!F96QT]FQT]G1T_&L@82!S>F5R=F5R<F4N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B
M57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R(")L871I;B!N86=Y8F5T^VLB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@
M(FYA9WEB973[<R!R\VUA:2!S>N%M;VLB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C0Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S@*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5<G5G=6%Y(@IM
M<V=S='(@(E5R=6=U87DB"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-
M86YA9V5R+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N
M=#H@)7,B"FUS9W-T<B`B2&%S>F[A;&IU:R!A(&IE;&5N;&5G:70Z("5S(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I9"`B
M57-E(%-33"(*;7-G<W1R(")(87-Z;N%L:G5N:R!34TPM="(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,C<*;7-G:60@(E5S92!I9B!N86UE+W!A<W-W
M;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM<V=S='(@(B(*
M(D%K:V]R(&AA<WINX6QJ=6LL(&AA(&%Z($E-4U`@<WIE<G9E<F5N(&WA<R!A
M(&)E:F5L96YT:V5ZZ7-I(&YE=OQN:R\B"B)J96QS>F%V=6YK+B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$*;7-G:60@(E5S97(B
M"FUS9W-T<B`B1F5L:&%S>F[A;/-I(&[I=B(*"B,Z(&QI8B](;W)D92]296=I
M<W1R>2YP:'`Z-S<T"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@
M;F]T(&%U=&AO<FES960@9F]R("5S+B(*;7-G<W1R("(E<R!F96QH87-Z;N%L
M\R!N96T@:F]G;W-U;'0@)7,M<F4N(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S
M"FUS9VED(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D9E;&AA<WIN
MX6SS:R!A9&UI;FES>G1RX6SA<V$B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN
M<&AP.C(T-0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(D9E;&AA<WIN
MX6SS:2!B9>%L;.UTX7-O:R(*"B,Z('-I9VYU<"YP:'`Z-C(*;7-G:60@(E5S
M97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(D)E:F5L96YT:V5ZZ7,@:F]G;W-U
M;'1SX6<@:6?I;GELZ7-E(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I9"`B57-E
M<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET
M92XB"FUS9W-T<B`B(@HB17IE;B!A(')E;F1S>F5R96X@;FEN8W,@96YG963I
M;'EE>G9E(&%Z(/IJ(&9E;&AA<WINX6SS:R!B96IE;&5N=&ME>NES:2`B"B)J
M;V=O<W5L='/A9^%N86L@:6?I;GELZ7-E+B(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HT-CD*;7-G:60@(E5S97(@86-C;W5N="!N;W0@9F]U;F0B"FUS
M9W-T<B`B07H@9F5L:&%S>F[A;/-I(&%Z;VYO<^UT\R!N96T@=&%LX6QH873S
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$W.0HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V(&QI
M8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.3@*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@@;&EB+TYE="]335,O=VEN
M7VAT='`N<&AP.C$U,`HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS
M,R!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<R"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G
M<W1R(")&96QH87-Z;N%L\VD@;NEV(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG
M;G5P+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E
M<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R(")!*'HI(%PB)7-<(B!F96QH
M87-Z;N%L\VD@;NEV(&WA<B!LZ71E>FEK+B(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHX-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(D9E
M;&AA<WINX6SS:2!NZ78Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI
M;F,Z.`IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R(")&96QH87-Z;N%L\VD@
M;NEV.B`B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS
M9VED(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R(")!(')E;F1S>F5R
M(&9E;&AA<WINX6SS:3HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0R
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@
M(MQZ8F5G:7-Z=.%N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ-S`@;&EB+U9&
M4R]F:6QE+G!H<#HR-C(*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@
M97AI<W0N(@IM<V=S='(@(D$@5D93(&%L:_9N>79TX7(@;F5M(&SI=&5Z:6LN
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$R,`IM<V=I9"`B5F%C
M871I;VXB"FUS9W-T<B`B4WIA8F%D<^%G(&%L871T:2!A=71O;6%T:6MU<R!E
M;6%I;"UVX6QA<WHB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#<P"FUS9VED
M(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(D$@
M:_9V971K97KU(&AE;'EE:V5T('1A;.%L='5K.B`B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B
MR7)VZ6YY97-SZ6<B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3DW(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U"FUS
M9VED(")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R(")!>B#I
M<G3I:V5K970@<&5R8V)E;B!A9&IU:R!M96<L(&UO<W1A;G3S;"!S>N%M[71V
M82XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#8P(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,3@Q"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@
M=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R(")!(.ER=.EK(&YA
M9WEO8F(L(&UI;G0@82!L96=N86=Y;V)B(&UE9V5N9V5D971T(&AO<W-Z^G/A
M9SH@)7,N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-#@@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(R-S`@;&EB+TAO<F1E+T9O<FTN<&AP.C(S,C`*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(Y,30@;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L
M97-E="YP:'`Z-3D*;7-G:60@(E9A;'5E<R(*;7-G<W1R("+)<G3I:V5K(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,3,@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(Q.3`*;7-G:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R(")6
MX6QA<WIT:&%T\R#I<G3I:V5K(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(T.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R
M(")686YU871U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S
M,PIM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B=N%L=&]Z\R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR-#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(T,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@
M(E9E;F5Z=65L82(*;7-G<W1R(")696YE>G5E;&$B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE
M9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N
M(@IM<V=S='(@(B(*(D$@:&ET96QE<^UTZ7,@;F5M('-I:V5R_&QT("T@;&5H
M970L(&AO9WD@82!L979E;&5T('9A;&%K:2!M96=VX6QT;WIT871T82XB"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B5F5R<VEO
M;B(*;7-G<W1R(")697)Z:?,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C(X"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`B5F5R>FGS
M:_9V973I<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@
M(D;\9V<N(&5L:&5L>65ZZ7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM
M<V=S='(@(D;\9V?U;&5G97,@8F5L<_4@;6%R9_,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@S"FUS9VED(")697)T:6-A
M;#HB"FUS9W-T<B`B9OQG9_5L96=E<SHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S
M='(@(FYA9WEO;B!M86=A<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M-#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I970@3F%M(@IM<V=S='(@
M(E9I971N86TB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-PIM<V=I9"`B
M5FEE=&YA;65S92`H5DE30TE)*2(*;7-G<W1R(")V:65T;F%M:2`H5DE30TE)
M*2(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HY-S`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R("(E<R!M96=T96MI;G3I
M<V4B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS"FUS9VED(")6:65W(&%N
M(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S='(@(DO\;'/U('=E8F]L9&%L(&UE
M9VIE;&5N[73I<V4B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z
M.#(Y"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B
M2F5L96[M='/\:R!M96<L(&UI;G0@)7,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C0V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L
M86YD<RP@0G)I=&ES:"(*;7-G<W1R(")"<FET(%9I<F=I;BUS>FEG971E:R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(T-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@(D%M97)I
M:V%I(%9I<F=I;BUS>FEG971E:R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C$V"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S='(@(DSA=/-TX79O;'/A9R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3(*;7-G:60@(E9I
M<VEB:6QI='DZ("(*;7-G<W1R("),X73S=.%V;VQSX6<Z("(*"B,Z(&QI8B].
M970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O9&%F
M;VYE($ET86QY('9I82!33510(@IM<V=S='(@(E9O9&%F;VYE($ET86QY('-Z
M;VQGX6QT873A<R!33510+6X@:V5R97-Z=/QL(@H*(SH@;&EB+TAO<F1E+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS9VED(")705).
M(@IM<V=S='(@(D9)1UE%3$U%6E1%5,E3(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!2
M14U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(D9)1UE%
M3$U%6E1%5,E3(2!+R5I:14P@5,%63TS-5%-!($5,($$@4T-225!4150@)7,M
M4M5,+B(*"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G:60@
M(E=)3B!V:6$@2%144"(*;7-G<W1R(")724X@<WIO;&?A;'1A=.%S($A45%`M
M;B#A="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3`@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,3<*;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(E=A
M;&QI<R#I<R!&=71U;F$B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+VAT;6PN<&AP.C$R-R!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#,*;7-G:60@
M(E=A<FYI;F<B"FUS9W-T<B`B1FEG>65L;65Z=&5TZ7,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")792(*
M;7-G<W1R(")3>F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,CD*;7-G:60@(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`B263U:N%RX7,@
M96SU<F5J96QZZ7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-#$V"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS9W-T<B`B
M07H@:63U:N%RX7-I(&%D871O:R!F;W)RX7-A(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C@Y-@IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R(")7
M96(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Y"FUS9VED(")7
M96(@4VET92(*;7-G<W1R(")796)H96QY96LB"@HC.B!L:6(O2&]R9&4O36%I
M;G1E;F%N8V4N<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`B:&5T96YT
M92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED(")7
M96QC;VUE(@IM<V=S='(@(MQD=O9Z]FQJ_&LB"@HC.B!T96UP;&%T97,O;&]G
M:6XO;6]B:6QE+FEN8SHT('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-3<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R("+<
M9';V>O9L:OQK.B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP
M.C(Y('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")796QC;VUE+"`E<R(*;7-G<W1R("+<9';V>O9L:OQK+"`E<R(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DX"FUS9VED(")797-T97)N("A)
M4T\M.#@U.2TQ*2(*;7-G<W1R(")N>75G870M975R\W!A:2`H25-/+3@X-3DM
M,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y.0IM<V=I9"`B5V5S=&5R
M;B`H25-/+3@X-3DM,34I(@IM<V=S='(@(FYY=6=A="UE=7+S<&%I("A)4T\M
M.#@U.2TQ-2DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B3GEU
M9V%T+5-Z86AA<F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0Q"B,L
M('!H<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S
M(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@(DUI;'EE;B!A;&MA;&UA
M>N%S="!M=71A<W-O;B`E<R!A(&)E:F5L96YT:V5ZZ7,@=73A;C\B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I<R!T
M:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B36D@87H@96QVX6QA
M<WIT\R!K87)A:W1E<C\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G
M<W1R(")-:2!A>B!I9.EZ971K87)A:W1E<C\B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V-`IM<V=I9"`B5VAE<F5I<R!!=7-T
M<F%L:6$@;6%P(@IM<V=S='(@(E=H97)E:7,@075S>G1RX6QI82!TZ7)KZ7`B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E
M<R(*;7-G<W1R(")-96QY:6L@8VEK;'5S(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$S-@IM<V=I9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R
M('1H92!2:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R(")-96QY:6L@;6]D=6QO
M:V%T(&%K=&EVX6QJ=6L@82!2:6-H(%1E>'0@961I=&]R8F%N/R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*
M;7-G:60@(E=I9'1H(@IM<V=S='(@(E-ZZ6QE<W/I9R(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HS,3$Q"FUS9VED(")7:61T:"!I;B!#4U,@=6YI=',B"FUS
M9W-T<B`B4WKI;&5S<^EG($-34R!E9WESZ6=B96XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S8Q"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F
M('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X
M="!L;V<M:6XI.B(*;7-G<W1R("(B"B)!("5S(&UE;OP@<WKI;&5S<^EG92!A
M(&)A;"!O;&1A;&]N("AA(&OV=F5T:V5Z]2!B96IE;&5N=&ME>NES="!K]G9E
M=/5E;B!L97-Z("(*(NER=NEN>65S*2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T:&4@
M=&%B;&4B"FUS9W-T<B`B02!TX6)LX7IA="!S>NEL97-SZ6=E(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G:60@
M(E=I9'1H('5N:70B"FUS9W-T<B`B02!S>NEL97-SZ6<@;>ER=.EK96=Y<^EG
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`U"FUS9VED(")7:61T:#HB"FUS9W-T<B`B4WKI;&5S<^EG.B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,34*;7-G:60@(E=I:VDB"FUS9W-T
M<B`B5VEK:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@
M(E=I;F0B"FUS9W-T<B`B4WKI;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8W"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@
M(E-ZZ6P@82!R96=G96QI(/-RX6MB86XB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C@W"FUS9VED(")7:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@(E-Z
MZ6QS96)E<W/I9R!C<V]M\V)A;B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,38S"FUS9VED(")7:6YD.B(*;7-G<W1R(")3>NEL.B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*;7-G:60@(E=I;F0Z("(*;7-G<W1R
M(")3>NEL.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@
M(E=I<V1O;2(*;7-G<W1R(")"]FQC<V5S<^EG(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$Y.`IM<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`B2^UV
MX6YSX6=L:7-T82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I
M9"`B5V]R:R(*;7-G<W1R(")-=6YK82(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3(T(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`B375N:V%H
M96QY:2!C[6TB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R(")-=6YK86AE;'EI('1E
M;&5F;VXB"@HC.B!L:6(O1FEL92]#4U8N<&AP.C$Y,R!L:6(O1FEL92]#4U8N
M<&AP.C(Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@
M9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS
M9W-T<B`B02`E9"X@<V]R8F%N(&YE;2!M96=F96QE;/4@82!M97KU:R!S>N%M
M82X@5N%R=#H@)60L('1A;.%L=#H@)60N(@H*(SH@;&EB+T9I;&4O0U-6+G!H
M<#HS,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I
M96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R(").96T@;65G
M9F5L96SU(&$@;65Z]6L@<WKA;6$N(%;A<G0Z("5D+"!T86SA;'0Z("5D+B(*
M"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3(Q"B,L('!H<"UF;W)M870*;7-G:60@
M(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N(@IM
M<V=S='(@(DAI8N%S(&]F9G-E="`H)60I(&$@5D93(&;A:FP@;VQV87/A<V%K
M;W(N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T-0IM<V=I9"`B
M6"U2968B"FUS9W-T<B`B3&EN=7@@9F]R<N%S:_-D(&ME<F5S>G)E9F5R96YC
M:6$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B
M6#4P.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(E@U,#EV,R!A;&%P
M=F5T]2!K;W)LX71O>N%S;VLB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4Y,PIM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME>2!5<V%G92(*;7-G
M<W1R(")8-3`Y=C,@:VET97)J97-Z=&5T="!K=6QC<VAA<WINX6QA="(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@
M4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(E@U,#EV,R!T=6QA
M:F1O;F]S(&%L=&5R;F%T[78@;65G;F5V97KI<V4B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y
M($ED96YT:69I97(B"FUS9W-T<B`B6#4P.78S('1U;&%J9&]N;W,@:W5L8W-A
M>F]N;W/M=/,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8X,PIM
M<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B6#4P.78S(&MI=&5R
M:F5S>G3I<V5K(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9
M(@IM<V=S='(@(EE9(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0Q-"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#4V"FUS9VED(")965E9(@IM<V=S='(@(EE965DB"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$Q,0IM<V=I9"`B66%H;V\A(&UA
M<"(*;7-G<W1R(")986AO;R$@=.ER:^EP(@H*(SH@;&EB+TAO<F1E+TUA:6YT
M96YA;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@(NEV96YT92(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3(@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(T-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3<*;7-G:60@(EEE;65N(@IM<V=S='(@(DIE;65N(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV-@IM<V=I9"`B665S(@IM<V=S
M='(@(DEG96XB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N
M8V4N:'1M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(DEG96XL
M(&)E;&5G>65Z96TN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I;B!415A4($U/1$4N("!5
M<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N
M(@IM<V=S='(@(B(*(DUO<W0@2%1-3"!415A4(&WS9&)A;B!V86XN($AA<WIN
MX6QJ82!A(%L\/ET@9V]M8F]T+"!H82!V:7-S>F$@86MA<B!VX6QT86YI(&$@
M(@HB<WIO:^%S;W,@9W)A9FEK=7,@*%=94TE764<I(&UE9VIE;&5N[73I<W)E
M+B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,C,V
M"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@
M8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N(@IM<V=S='(@(DYE;2!H;WIH
M870@;.ET<F4@)60@8FQO:VMNX6P@=/9B8F5T+B(*"B,Z(&QI8B](;W)D92YP
M:'`Z,30Q-0IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC871E9"XB"FUS
M9W-T<B`B07H@UFX@9F5L:&%S>F[A;/-A>F]N;W/M=.%S82!N96T@=/9R=.EN
M="!M96<N(@H*(SH@;&EB+TAO<F1E+TED96YT:71Y+G!H<#HS,#@*;7-G:60@
M(EEO=2!C86YN;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F
M=6QL(&YA;64N(@IM<V=S='(@(D$@=&5L:F5S(&[I=F)E;B!N96T@<WIE<F5P
M96QH970@82`G7%PG(&MA<F%K=&5R+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ.#4Y(&QI8B](;W)D92]&;W)M+G!H<#HQ.3<Y"FUS9VED(")9;W4@9&ED
M(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S='(@(DYE
M;2!A9&]T="!M96<@Z7)VZ6YY97,@96UA:6P@8^UM970N(@H*(SH@;&EB+TAO
M<F1E+T1A=&$N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@
M9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@
M=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R
M("(B"B).96T@861T82!M96<@82!M96=F96QE;'1E=.ES="!A>B!I;7!O<G3A
M;'0@9N%J;"#I<R!A*'HI("5S(&UE>O5I(&OV>O9T="XB"@HC.B!L:6(O2&]R
M9&4O075T:"YP:'`Z.3@W"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O
M=70N(@IM<V=S='(@(E-I:V5R97-E;B!K:6IE;&5N=&ME>F5T="XB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3(V-0IM<V=I9"`B(@HB66]U(&AA=F4@=&\@
M96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W
M:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@
M9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@(B(*(D5G>2!M;V)I;'1E;&5F;VYS
M>N%M;W0@:V5L;"!M96=A9&YI82P@8W-A:R!A('-ZX6UJ96=Y96ME="P@97-E
M=&QE9R!E9WD@)RLG("(*(FMA<F%K=&5R<F5L(&ME>F1V92P@:&$@;F5M>F5T
M:_9Z:2!TX7)C<^%ZX7-I(&WS9&]T(&OM=N%N(&AA<WINX6QN:2XB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3$Y,@IM<V=I9"`B66]U(&AA=F4@=&\@96YT
M97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`B16QF;V=A9&AA=/,@Z7)TZ6ME
M="!K96QL(&UE9V%D;FEA+B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP
M:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A
M8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(B(*(D$@1&%T851R964@
M86QR96YD<WIE<G0@8F4@:V5L;"#A;&SM=&%N:2!A(&)E:F5L96YT:V5ZZ7-I
M(&IO9V]S=6QT<^%G;VL@(@HB:6?I;GELZ7/I:&5Z+B(*"B,Z(&QI8B](;W)D
M92YP:'`Z-#8R"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C
M:V5N9"XB"FUS9W-T<B`B02!61E,@86QR96YD<WIE<B!N:6YC<R!B9>%L;.UT
M=F$N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G
M:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@
M8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R("(B"B)%;/5B
M8B!L92!K96QL(.UR;FEA+"!H;V=Y(&UI;'EE;B!P<F]B;.EMX70@=&%P87-Z
M=&%L="P@;6EE;/5T="!E;&O\;&1I(&$@(@HB:&EB86IE;&5N=.ES="XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS
M9VED(")9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P
M;VEN=',@=&\B"FUS9W-T<B`B365G(&ME;&P@861N:2!E9WD@55),+70L(&%H
M;W9A(&5Z(&$@;&EN:R!M=71A="(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S
M=6TN<&AP.C@P"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O
M(&)E(&1E;&5T960N(@IM<V=S='(@(DMI(&ME;&P@=N%L87-Z=&%N:2!E9WD@
M=/9R;&5N9/4@<WIE<G9E<G0N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$Y"FUS
M9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T
M+B(*;7-G<W1R(")-96<@:V5L;"!A9&YI82P@:&]G>2!M96QY:6L@9F5L:&%S
M>F[A;/,@861A=&%I="!K[7;A;FIA('3V<O9L;FDN(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3`P"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@
M=&\@<F5M;W9E+B(*;7-G<W1R(")-96<@:V5L;"!A9&YI82!A>B!E;'3A=F]L
M[71A;F3S(&9E;&AA<WINX6SS:2!N979E="XB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@
M(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T
M<B`B365G(&ME;&P@861N:6$@82!H;WIZX6%D86YD\R!F96QH87-Z;N%L\R!N
M97;I="XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#8*;7-G:60@(EEO=2!M=7-T
M('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`B365G
M(&ME;&P@861N:6$L(&AO9WD@;65L>6EK(&9E;&AA<WINX6SS(&%D871A:70@
M:^UVX6YJ82#A=.UR;FDN(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP
M:'`Z,3,X"FUS9VED(")9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O
M('!E<F9O<FTN(@IM<V=S='(@(DUE9R!K96QL(&%D;FEA(&5G>2!P87)A;F-S
M;W0N(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z
M-S$*;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB
M"FUS9W-T<B`B365G(&ME;&P@861N:6$@87H@^FH@:V%T96?S<FEA(&YE=NET
M+B(*"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*
M;7-G:60@(EEO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N
M=6UB97(B"FUS9W-T<B`B3VQA<WIO<G-ZX6=I('1E;&5F;VYS>N%M;W0@:V5L
M;"!M96=A9&YI82(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY-S4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0
M;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(D%Z(-9N("5S(&MA<&-S
M;VQA=&$@:63U=/IL;.EPZ7,@;6EA='0@;65G<WIA:V%D="X@2^ER96T@:F5L
M96YT:V5Z>F5N(&)E(/IJ<F$N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z,S@*;7-G:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R
M(")!>B#6;B!E;6%I;"!C[6UE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(Q-0IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R(")!>B#6
M;B!F96QA9/-I("A&<F]M.BD@8^UM93HB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<W(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(*;7-G
M:60@(EEO=7(@26YF;W)M871I;VXB"FUS9W-T<B`B4WIE;>EL>65S(&EN9F]R
M;>%C:?,B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3<Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E
M9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@
M(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I
M;BXB"FUS9W-T<B`B(@HB07H@UFX@)7,@:V%P8W-O;&%TX6YA:R!K97ID971E
M(/-T82!M96=VX6QT;WIO='0@87H@:6YT97)N970@8^UM92X@(@HB0FEZ=&]N
M<^%GX6YA:R#I<F1E:^EB96X@:7-MZ70@8F4@:V5L;"!J96QE;G1K97IN:64N
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*;7-G:60@
M(EEO=7(@3F%M92(*;7-G<W1R(")!>B#6;B!N979E(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;F]A9&0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N
M=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R
M<RX@268@>6]U('=I<V@@=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@
M=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U
M=&AE;G1I8V%T:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*(D%Z(-9N(&9E;&AA
M<WINX6SS87IO;F]S[73S(&%L<F5N9'-Z97)E(&YE;2!T97-Z:2!L96AE=/5V
MZ2!A>B#Z:B!F96QH87-Z;N%L\VL@(@HB;.ET<F5H;WKA<^%T+B!(82!A($AO
M<F1E(')E;F1S>F5R<F5L(&OM=N%N:F$@:V5Z96QN:2!A(&9E;&AA<WINX6SS
M:2`B"B)A9&%T;VMA="P@86MK;W(@;>%S:6L@9F5L:&%S>F[A;/-A>F]N;W/M
M=/,@86QR96YD<WIE<G)E('9A;B!S>OQK<^EG92XB"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N
M=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E
M<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S
M;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@HB07H@UFX@9F5L:&%S>F[A
M;/-A>F]N;W/M=/,@86QR96YD<WIE<F4@;F5M('1E<WII(&QE:&5T]7;I(&$@
M9F5L:&%S>F[A;/-K("(*(FQI<W3A>N%SX70L('9A9WD@=F%L86UI(&]K8O-L
M(&QE=&EL=&]T=.%K(&5Z="!A(&QE:&5T]7/I9V5T+B(*"B,Z(&QI8B](;W)D
M92]!=71H+G!H<#HY.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B
M<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I
M;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@
M<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B)!
M>B#6;B!B]FYGZ7-Z]7!R;V=R86UJ82!M96=VX6QT;WIO='0@87H@UFX@)7,@
M;75N:V%K87!C<V]L873A;F%K(&ME>F1E=&4@(@HB\W1A+B!":7IT;VYSX6=A
M(.ER9&5KZ6)E;B!I<VWI="!B92!K96QL(&IE;&5N=&ME>FYI92XB"@HC.B!L
M:6(O0FQO8VLO:69R86UE+G!H<#HU-0IM<V=I9"`B66]U<B!B<F]W<V5R(&1O
M97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R(")!>B#6;B!B
M]FYGZ7-Z]7!R;V=R86UJ82!N96T@=.%M;V=A=&IA(&5Z="!A(&QE:&5T]7/I
M9V5T+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"FUS
M9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R
M:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T;R!P
M<FEN="XB"FUS9W-T<B`B(@HB07H@UFX@8O9N9^ES>O5P<F]G<F%M:F$@;F5M
M('3A;6]G871J82!E>G0@82!N>6]M=&%TX7-I(&]P8VGS="X@4'+S8N%L:F]N
M(&$@(@HB0W1R;"U0("AV86=Y($-O;6UA;F0M4"D@;&5N>6]MX7/A=F%L(&YY
M;VUT871N:2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C8Q"FUS9VED
M(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R(")!(&IE;&5N;&5G
M(.ER=NEN>65S(&ED]7KS;F$Z(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C$Q
M-PIM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG
M960N(@IM<V=S='(@(D%Z(-9N(&%L87#I<G1E;&UE>NES('-Z97)I;G1I(&%Z
M;VYO<^UT\VIA(&UE9W;A;'1O>F]T="XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,38Q"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S
M='(@(D%Z(-9N(&%L87#I<G1E;&UE>NES('-Z97)I;G1I(&%Z;VYO<^UT\VIA
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#0*;7-G:60@(EEO=7(@
M9G5L;"!N86UE.B(*;7-G<W1R(")!>B#6;B!T96QJ97,@;F5V93HB"@HC.B!L
M:6(O2&]R9&4O075T:"YP:'`Z.3DY"FUS9VED(")9;W5R(&QO9VEN(&AA<R!E
M>'!I<F5D+B(*;7-G<W1R("),96KA<G0@82!B96IE;&5N=&ME>NES:2!J;V=O
M<W5L='/A9V$N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S
M(&ES.B`E<R(*;7-G<W1R(")!>B#6;B`E<RUR92!H87-Z;N%L="#Z:B!J96QS
M>F%V83H@)7,B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$U-`IM<V=I
M9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R
M871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R(")!>B#6;B#Z:B!B9>%L
M;.UTX7-A:70@Z7)VZ6YY97/M=&5T=/QK(&$@;6]S=&%N:2!B96IE;&5N=&ME
M>NES(&ED96KI<F4N(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ-38*
M;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS9W-T
M<B`B07H@UFX@^FH@8F7A;&SM=.%S86ET(&5L;65N=&5T=/QK+B(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A<W-W
M;W)D(&AA<R!B965N(')E<V5T(@IM<V=S='(@(D%Z(-9N(&IE;'-Z87;A="#A
M=.%L;.UT;W1T=6LB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW
M.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE
M8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S
M<W=O<F0N(@IM<V=S='(@(B(*(D%Z(-9N(&IE;'-Z87;A="#A=.%L;.UT;W1T
M=6LL(&[I>GIE(&UE9R!A(&QE=F5L96ET+"!M86ID(&IE;&5N=&ME>GIE;B!B
M92!A>B`B"B+Z:B!J96QS>O-V86PN(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP
M.C<S,PIM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"XB"FUS9W-T
M<B`B07H@UFX@:F5L<WIA=N%N86L@;&5JX7)T(&%Z(.ER=NEN>65S<^EG:2!I
M9&5J92XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G
M:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(D%Z(-9N(.%L=&%L
M(&AA<WINX6QT('3A=F]L:2!S>F5R=F5R96LZ(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(U-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G
M:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B2G5G;W-Z;.%V:6$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@
M(EIA:7)E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(EIA;6)I82(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(T.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*
M;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(EII;6)A8G=E(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P>2(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ
M-S0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*
M;7-G:60@(EM(:61E(%%U;W1E9"!497AT72(*;7-G<W1R(");3F4@;75T87-S
M=6L@82!B96EDZ7IE='0@<WKV=F5G971=(@H*(SH@<V5R=FEC97,O<')O8FQE
M;2YP:'`Z.#D*;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B6TAI
M8F%J96QE;G3I<UTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L
M;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R
M(");375T87-S=6L@82!B96EDZ7IE='0@<WKV=F5G970@+2(*"B,Z(&QI8B](
M;W)D92]497AT+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S
M72(*;7-G<W1R(");375T87-S=6L@82!B96EDZ7IE='0@<WKV=F5G970@+2`E
M<R!S;W)=(@H*(SH@;&EB+TAO<F1E+G!H<#HQ.34*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(ELE<R\E<R!S;W)=(@H*
M(SH@;&EB+TAO<F1E+G!H<#HQ-30U('1E;7!L871E<R]P;W)T86PO;65N=2YI
M;F,Z,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R(")?061M:6YI
M<WIT<N%C:?,B"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS
M9W-T<B`B7U!A<F%N8W-S;W(B"@HC.B!L:6(O87!I+G!H<#HQ-#$*;7-G:60@
M(E]$871A5')E92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*;7-G:60@(E]$96QE=&4@
M4F]W(@IM<V=S='(@(E-O<G3V<FSI<R(*"B,Z(&QI8B]A<&DN<&AP.C$S,PIM
M<V=I9"`B7T=R;W5P<R(*;7-G<W1R(")?0W-O<&]R=&]K(@H*(SH@;&EB+TAO
M<F1E+TUE;G4N<&AP.C$W-0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`B4V5?9^UT
M<^EG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G
M<W1R(")!(&OI<"!T=6QA:F1O;G/A9V%I+BXN(@H*(SH@;&EB+TAO<F1E+TUE
M;G4N<&AP.C$Y-`IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R(")"96IE;&5N=&ME
M>NES(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I9"`B7TQO9R!O
M=70B"FUS9W-T<B`B7TMI:F5L96YT:V5ZZ7,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G:60@(E]-
M;V1I9GD@3&EN:RXN+B(*;7-G<W1R(")!(&QI;FL@;?-D;W/M=.%S82XN+B(*
M"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ-C0*;7-G:60@(E]/<'1I;VYS(@IM
M<V=S='(@(E]/<&-I\VLB"@HC.B!L:6(O87!I+G!H<#HQ,S<*;7-G:60@(E]0
M97)M:7-S:6]N<R(*;7-G<W1R(")?2F]G;W-U;'1SX6=O:R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@IM
M<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@(D$@;&EN:R!T]G)LZ7-E
M+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3(U"FUS9VED(")?4V5T=7`B"FUS9W-T
M<B`B7T)EX6QL[73A<V]K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED(")?5&%B;&4@4')O<&5R
M=&EE<RXN+B(*;7-G<W1R(")4X6)LX7IA="!T=6QA:F1O;G/A9V]K(@H*(SH@
M;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?57-E<G,B"FUS9W-T<B`B7T9E;&AA
M<WINX6SS:R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3(U"FUS9VED(")A
M9&1R97-S(&)O;VLB"FUS9W-T<B`B8^UM:F5G>7KI:R(*"B,Z(&QI8B](;W)D
M92]-24U%+TUE<W-A9V4N<&AP.C$S-`IM<V=I9"`B861D<F5S<V5E('5N:VYO
M=VXB"FUS9W-T<B`B82!C[6UZ971T(&ES;65R971L96XB"@HC.B!L:6(O2&]R
M9&4O2V]L86(N<&AP.CDQ-PIM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B;F%P
M=.%R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-SD@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R
M(")N>75G;V1T(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,34X
M"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(F$@
M:VEM96YE=&D@X6QL;VWA;GD@;F5M(&AO>FAA=/,@;.ET<F4B"@HC.B!L:6(O
M2&]R9&4O34E-12]-97-S86=E+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N
M(&EN<'5T(@IM<V=S='(@(F$@8F5M96[U(.%L;&]MX6YY(&YE;2!N>6ET:&%T
M\R!M96<B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z-3DY"FUS
M9VED(")C;&EC:R!H97)E(@IM<V=S='(@(FMA='1I;G1S;VX@:61E(@H*(SH@
M;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3(R"FUS9VED(")C;VUM86YD
M(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T<B`B<&%R86YC<W-O<FD@:&EB82(*
M"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$W.`IM<V=I9"`B8V]N
M9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R(")K;VYF:6=U<N%C:?-S(&AI8F$B
M"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-30*;7-G:60@(F-R
M:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B:&GA;GEZ:6L@
M96=Y(&9O;G1O<R!R96YD<WIE<N%L;&]MX6YY(@H*(SH@;&EB+TAO<F1E+TU)
M344O365S<V%G92YP:'`Z,3(V"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*
M;7-G<W1R(")A9&%T9F]R;>%T=6T@:&EB82(*"B,Z('1E;7!L871E<R]P;W)T
M86PO961I="YI;F,Z,S`*;7-G:60@(F5D:70B"FUS9W-T<B`B;?-D;W/M=.%S
M(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3@R"FUS9VED(")E
M;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`B87H@861A="!N96T@=&%LX6QH873S
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S(*
M;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B8W/V:VME;B(*"B,Z(&QI8B](;W)D
M92]"<F]W<V5R+G!H<#HX.3@*;7-G:60@(F9I;&4B"FUS9W-T<B`B9N%J;"(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@Q(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S8W(&QI8B]";&]C:R]M971A<BYP:'`Z,SDS"B,L('!H<"UF;W)M870*
M;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B)7,@
M*"5S*2!I<N%N>6+S;"P@)7,@)7,@<V5B97-SZ6=G96PB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Y"FUS9VED(")G=7-T:6YG(@IM<V=S
M='(@(G-ZZ6QL]FOI<V5K(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(U,`IM<V=I9"`B:#HB"FUS9W-T<B`B;3HB"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4Y"FUS9VED(")H:"(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ,S@*
M;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(F$@9^EP(&YE=F4@
M;F5M(&ES;65R="(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-C4@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G
M:60@(FEM;65D:6%T92(*;7-G<W1R(")A>F]N;F%L:2(*"B,Z(&%D;6EN+W-E
M='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED
M(")I;FQI;F4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G
M92YP:'`Z,38R"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`B
M:6YP=70O;W5T<'5T(&AI8F$B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E
M+G!H<#HQ-#8*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S
M='(@(F)E;'/U('!R;V=R86UH:6)A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R(")S
M;W)=(@H*(SH@;&EB+U9&4R])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE
M(&UA:VEN9R!)4T\N(@IM<V=S='(@(B(*(D%Z(&UK<VEO9G,@<')O9W)A;2`E
M9"!H:6)A:_-D9&%L(&QEX6QL="!A>B!)4T\@X6QL;VWA;GD@:^ES>NUTZ7-E
M(&OV>F)E;BXB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,S<P"FUS9VED(")M;2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4')E
M9G,O54DN<&AP.C(X-2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR-#$*;7-G:60@(FYA
M;64B"FUS9W-T<B`B;NEV(@H*(SH@;&EB+TAO<F1E+U)00RYP:'`Z,3(T"FUS
M9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`B02!P<F]G<F%M;F%K(&5Z
M(&$@<NES>F4@;>EG(&YI;F-S(&UE9W9A;/-S[71V82XB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C$R,C`*;7-G:60@(FYO="!Y970@:6UP;&5M
M96YT960B"FUS9W-T<B`B02!P<F]G<F%M;F%K(&5Z(&$@<NES>F4@;>EG(&YI
M;F-S(&UE9W9A;/-S[71V82XB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDP
M.0IM<V=I9"`B;F]T97!A9"(*;7-G<W1R(")J96=Y>F5T=/9M8B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*
M;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B<WKA>F%LZ6LB"@HC.B!L:6(O2&]R
M9&4O34E-12]-97-S86=E+G!H<#HQ-S0*;7-G:60@(G!E<FUI<W-I;VX@9&5N
M:65D(@IM<V=S='(@(FYI;F-S(&UE9V9E;&5L]2!J;V=O<W5L='/A9V$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@Y"FUS9VED(")P:7AE;',B"FUS9W-T<B`B<&EX96PB"@HC.B!L:6(O2&]R
M9&4O34E-12]-97-S86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I
M;B!P<F]T;V-O;"(*;7-G<W1R(")A9&%TX71V:71E;&D@*'!R;W1O:V]L;"D@
M:&EB82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C<T"FUS9VED(")R:7-I;F<B"FUS9W-T<B`B96UE;&ME9&EK(@H*(SH@;&EB
M+TAO<F1E+TU)344O365S<V%G92YP:'`Z,30R"FUS9VED(")S97)V:6-E('5N
M879A:6QA8FQE(@IM<V=S='(@(F$@<WIO;&?A;'1A=.%S(&YE;2#A;&P@<F5N
M9&5L:V5ZZ7-R92(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,3`Q"FUS
M9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@(F[I>GK\:R!M96<@82!K
M_&SV;F)SZ6=E:V5T(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@(G-M
M<S)E;6%I;"!S>F]L9^%L=&%TX7,@2%144"UN(.%T(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-PIM<V=I9"`B<W,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-S,*;7-G:60@(G-T96%D>2(*;7-G<W1R(")VX6QT;WIA=&QA;B(*"B,Z(&QI
M8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R
M<F]R(@IM<V=S='(@(G)E;F1S>F5R:&EB82(*"B,Z(&QI8B](;W)D92]+;VQA
M8BYP:'`Z.3,S"FUS9VED(")T87-K(&QI<W0B"FUS9W-T<B`B9F5L861A=&QI
M<W1A(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,38V"FUS9VED
M(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R("+A=&UE;F5T:2!H:6)A(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,S8@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H
M<#HR-S`*;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I
M<FTB"FUS9W-T<B`B;65G97+U<^UTZ7-KZ6YT(&OI='-Z97(@[7)J82!B92!A
M(&IE;'-Z\W0B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S
M971U<"]D:69F+G!H<#HW.0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O34E-12]087)T+G!H<#HR-PIM<V=I9"`B=6YN86UE9"(*
M;7-G<W1R(")NZ78@;NEL:_QL(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4V-2!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(R,PIM<V=I9"`B=7-E<B!S96QE8W0B"FUS9W-T<B`B82!F96QH87-Z;N%L
M\R#A;'1A;"!VX6QA<WIT:&%T\R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S='(@(G9#87)D(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T,@IM<V=I
M9"`B=SHB"FUS9W-T<B`B<WHZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C8*;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(B(*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+V9I7T9)+G!O````````````
M````````````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#<S,C(P
M,"`Q,#4Q-30S,S<T,B`P,3<T-S4`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````(R!&:6YN:7-H('1R86YS;&%T:6]N(&9O<B!(
M;W)D92X*(R!#;W!Y<FEG:'0@*$,I"B,@3&5E;F$@2&5I;F\@/&QI:6YU0'5T
M82YF:3XL(#(P,#$M,C`P-BX*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE
M8W0M260M5F5R<VEO;CH@2&]R9&4@,RXQ+6-V<UQN(@HB4F5P;W)T+4US9VED
M+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO
M;BU$871E.B`R,#`V+3`R+3(W(#$Y.C4Q*S`R,#!<;B(*(E!/+5)E=FES:6]N
M+41A=&4Z(#(P,#8M,#(M,C0@,3(Z-3DK,#(P,%QN(@HB3&%S="U4<F%N<VQA
M=&]R.B!,965N82!(96EN;R`\;&EI;G5`=71A+F9I/EQN(@HB3&%N9W5A9V4M
M5&5A;3H@1FEN;FES:"`\:3$X;D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%
M+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C
M:&%R<V5T/6ES;RTX.#4Y+3%<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I
M;F<Z(#@M8FET7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<S
M"B,L('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@
M(B`H)7,@<.1I=N3D('-I='1E;BDB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C$S-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@
M)7,I(@IM<V=S='(@(B`H4&EK86[D<'#D:6X@)7,I(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C,X,0HC+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN
M("5S(&1A>7,I(@IM<V=S='(@(B`H)7,@<.1I=N1S<^0I(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-PIM<V=I9"`B("AT;V1A>2DB"FUS9W-T
M<B`B("ATY&[DY&XI(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W
M.0IM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B("AH=6]M96YN82DB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<U"FUS9VED("(@*'EE<W1E
M<F1A>2DB"FUS9W-T<B`B("AE:6QE;BDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C0U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M-3`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y-@IM<V=I9"`B
M(&%T("(*;7-G<W1R("(@(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A(&1I
M<F5C=&]R>2XB"FUS9W-T<B`B7"(E<UPB(&5I(&]L92!H86ME;6ES=&\B"@HC
M.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G
M:60@(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(EPB
M)7-<(B!E:2!K96QP86$@=F%L:6YN86MS:2XB"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<Q,`HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O4F5G:7-T<GDN<&AP.C$P.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R
M>2XB"FUS9W-T<B`B7"(E<UPB(&5I(&]L92!A<V5N;F5T='4@2&]R9&5N(')E
M:VES=&5R:7-SY"XB"@HC.B!F<F%M97=O<FLO5')E92]4<F5E+G!H<#HQ-S$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R964@<F5N9&5R97(@;F]T
M(&9O=6YD+B(*;7-G<W1R(")<(B5S7"(@<'5I9&5N(&MU=F%A:F%A(&5I(&SV
M>71Y;GET+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E
M;2XB"FUS9W-T<B`B7"(E<UPB(&QI<^1T=&EI;B!R>6AMY&KD<FIE<W1E;&WD
MY&XN(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4R"B,L('!H<"UF
M;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I
M;VYS('-Y<W1E;2XB"FUS9W-T<B`B7"(E<UPB(&QI<^1T=&EI;B!O:6ME=6MS
M:6EN+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-30@861M:6XO<&5R;7,O861D
M8VAI;&0N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@
M;F]T(&-R96%T960Z("5S+B(*;7-G<W1R(")<(B5S7"(@96D@;'5O='4Z("5S
M+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E
M*2(*;7-G<W1R("(E+C)F34(@:^1Y=&5T='D@)2XR9DU"('-A;&QI='5S=&$@
M*"4N,F8E)2DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(V
M"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R("(E
M9"`E<R!J82`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M,C8X(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU-3<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N(@IM
M<V=S='(@(E-A;&%S86YA<VD@=F%N:&5N='5U("5D('#D:7;D;B!PY.1S=.0N
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(W-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B"FUS9W-T<B`B)60@<.1I
M=N1N(&5N;G5S='5S(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C8X
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B5S
M("T@26QM;VET=7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C<P-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*
M;7-G<W1R("(E<R!3;W)M96YJY&QK:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.C@T,"!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HX-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T
M<B`B)7,@2T(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M
M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(E<R!9;&SD<&ET;W1O:6UE;G!I=&5E
M="`M(%9A<FUI<W1U<R(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!3971U<"(*;7-G<W1R("(E<R!A<V5N;G5S(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!3:6=N(%5P(@IM<V=S='(@(B5S(&MI<FIA=71U;6EN96XB"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S='(@(B5S(&OD>71T]F5H
M9&]T(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.#(@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HW-3`*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HT,S(@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@
M(B5S(&]N(&IO(&]L96UA<W-A+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,38V(&QI8B]";&]C:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C0V"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S4R(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S4X"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S
M(@IM<V=S='(@(B5S('-U=6YT82`E<R`E<R(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<R!I<R!R
M96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H
M96-K960@8F5L;W<N($-H96-K('1H92`B"B)B;W@@9F]R(&%N>2!O<&5R871I
M;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N(@IM<V=S
M='(@(B(*(B5S(&]N('9A;&UI<R!S=6]R:71T86UA86X@>6QLY'!I=&]T;VEM
M96YP:71E:73D+B!686QI='-E('9A;&EN=&%R=75D=6ES=&$@(@HB<W5O<FET
M971T879A="!T;VEM96YP:71E970N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C,T-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U:7)E
M9"(*;7-G<W1R("(E<R!O;B!P86MO;&QI;F5N(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*
M;7-G<W1R("(E<R!M:6YU=71T:6$B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO0V]L;&5C=&EO;BYP:'`Z,3(Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&YO="!F;W5N9"XB"FUS9W-T<B`B)7,@96D@;/9Y='EN>70N(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R("(E<R`M("5S("\@)7,B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR-@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R("(E<SIN(&]S;VET
M96MI<FIA(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R("(E<SIN
M(&MA;&5N=&5R:2(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$P
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R("(E
M<SIN(&UU:7-T:6QI<W1A(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G
M<W1R("(E<SIN('1E:'3D=N1L:7-T82(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@(B5S.B`E<R(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R-PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@
M8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO
M=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S
M96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN(@IM<V=S='(@
M(B(*(B5S(#H@5.1MY"!V:65S=&D@96D@;VQE(';D;'1TY&WD='3D('-I;'3D
M(&SD:&5T=.1JY&QTY"P@:F]K82!O;B!M97)K:71T>2`B"B)LY&AE='3D:N1K
M<VDN(%-U:'1A=61U('9A<F%U:W-E;&QA('9I97-T:7-SY"!O;&5V:6EN(&QI
M;FMK96EH:6X@:F$@=F%R;R`B"B)A;G1A;6%S=&$@;.1H971TY&KD;&QE(&UI
M=.3D;B!Y:W-I;/9I=FGD('1I971O:F$N(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,U-"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,SDY"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(BP@<'5U<VMI='1A:7-T
M82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3DU(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C`P"B,L('!H<"UF;W)M870*;7-G:60@(BP@9W5S=&EN9R`E<R`E
M<R(*;7-G<W1R("(L('!U=7-K:71T86ES=&$@)7,@)7,B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(P.`HC+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA
M8FQE(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B+"!V86EH=&5L979A82`E<R`M
M("5S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C<T."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Y-`HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,T."!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,#<S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,S(*
M;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(M+2!V86QI='-E("TM(@H*
M(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P"FUS9VED("(Q,B!(;W5R($9O<FUA
M="(*;7-G<W1R("(Q,BUT=6YN:6X@:N1R:F5S=&5L;>0B"@HC.B!L:6(O0FQO
M8VLO=&EM92YP:'`Z,3D*;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@
M(C(T+71U;FYI;B!JY')J97-T96QMY"(*"B,Z('1E;7!L871E<R]D871A+W1I
M;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(R-"!T=6YT:6$B
M"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C8Y"FUS9VED("(\4')E
M=FEO=7,B"FUS9W-T<B`B/$5D96QL:6YE;B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3(V"FUS9VED(")!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER
M960@9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@(E1I971O:V%N=&%T875S=&%J
MY')J97-T96QMY.0@96D@;VQE(&WDY')I=&5L='D@=.1L;&4@;W-I;VQL92(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38R"FUS9VED(")!(&9A
M=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R(")487!A:'1U:2!V86MA
M=F$@=FER:&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY
M,S4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC
M<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(E9I97-T:6X@<V%L875K<V5E;B!T
M87)V:71A86X@:G5L:VEN96X@4$=0+6%V86EN+B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C$Q-C@*;7-G:60@(D$@<'5B;&EC(%!'4"!K
M97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM
M<V=S='(@(D%L;&5K:7)J;VET971U;B!V:65S=&EN('1A<FMI<W1U:W-E96X@
M=&%R=FET86%N(&IU;&MI;F5N(%!'4"UA=F%I;BXB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#DY"FUS9VED("(B"B)!('!U8FQI8R!0
M1U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB
M4V%L871U;B!V:65S=&EN(&%V86%M:7-E96X@=&%R=FET86%N(&IU;&MI;F5N
M(%!'4"UA=F%I;BP@<V%L86EN96X@4$=0+6%V86EN("(*(FIA('-A;&%S86YA
M=&5K<W1I+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P
M,38*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M
M97-S86=E+B(*;7-G<W1R("(B"B)6:65S=&EN(&%L;&5K:7)J;VET=&%M:7-E
M:W-I('1A<G9I=&%A;B!J=6QK:6YE;B!01U`M879A:6XL('-A;&%I;F5N(%!'
M4"TB"B)A=F%I;B!J82!S86QA<V%N871E:W-T:2XB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4P-@IM<V=I9"`B(@HB02!P=6)L:6,@
M4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S
M='(@(B(*(E9I97-T:6X@879A86UI<V5E;B!T87)V:71A86X@:G5L:VEN96X@
M4R]-24U%+6%V86EN+"!S86QA:6YE;B!3+TU)344M879A:6X@:F$@(@HB<V%L
M87-A;F%T96MS=&DN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A
M=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B"B)6:65S=&EN(&%L;&5K
M:7)J;VET=&%M:7-E:W-I('1A<G9I=&%A;B!J=6QK:6YE;B!3+TU)344M879A
M:6XL('-A;&%I;F5N(%,O(@HB34E-12UA=F%I;B!J82!S86QA<V%N871E:W-T
M:2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,V-`IM
M<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y
M<'0@82!M97-S86=E+B(*;7-G<W1R(")6:65S=&EN('-A;&%U:W-E96X@=&%R
M=FET86%N(&IU;&MI;F5N(%--24U%+6%V86EN+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.CD*;7-G:60@(D%-($-L;W5D<R(*
M;7-G<W1R(")!32!0:6QV:>0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R
M(")!32!K979Y='3D('-A9&5T=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R(")!
M32!S861E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`B04T@<V%T96ET82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS
M9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B04T@;'5M:7-A=&5I=&$B
M"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB
M"FUS9W-T<B`B04TO4$TB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G<W1R(")!
M4$D@240B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R(")4:65T
M;VIA(&5D:71O<FES=&$B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU
M,PIM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B5&EE=&]J82XN+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@
M(D%B<V)O='1O;2(*;7-G<W1R(")!8G,N(&%L:6XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M:61D
M;&4B"FUS9W-T<B`B06)S+B!K97-K96QLY"(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I
M;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B4VEN=6QL82!E:2!O;&4@;VEK
M975K<VEA(&QU;V1A(%9&4RUH86ME;6ES=&]A+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E
M871I;F<@5D93(&9I;&4N(@IM<V=S='(@(E-I;G5L;&$@96D@;VQE(&]I:V5U
M:W-I82!L=6]D82!61E,M=&EE9&]S=&]A+B(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HS"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@
M(DOD>71TY&KD='5N;G5K<V5N('1I961O="(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HW.`IM<V=I9"`B06-C;W5N="!087-S=V]R9"(*;7-G<W1R(")+
MY'ET=.1JY'1U;FYU:W-E;B!S86QA<V%N82(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N
M="!F<F]Z96XN(@IM<V=S='(@(DOD>71TY&KD=&EL:2!S=6QJ971T=2XB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,U"FUS9VED(")!8V-O=6YT
M:6YG(@IM<V=S='(@(DMI<FIA;G!I=&\B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C$T."!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z,3$*;7-G
M:60@(D%D9"(*;7-G<W1R("),:7/DY"(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,C(T(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!9&0@0VAI;&0@1W)O
M=7`B"FUS9W-T<B`B3&ESY.0@86QI<GEH;>0B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.CDX(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z.3D*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N(@IM<V=S='(@(DQI
M<^3D(&%L:6]I:V5U<R(*"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU
M"FUS9VED(")!9&0@2&5R93HB"FUS9W-T<B`B3&ESY.0@=.1HY&XZ(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O=7!S+G!H<#HR,3D*;7-G
M:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B3&ESY.0@=75S:2!R>6AMY"(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#<@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HX.`IM<V=I9"`B061D($YE=R!097)M:7-S
M:6]N(@IM<V=S='(@(DQI<^3D('5U<VD@;VEK975S(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")!9&0@82!C:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B3&ES
MY.0@86QI<GEH;>0@<GEH;>3D;B!<(B5S7"(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@
M82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R("),:7/DY"!A
M;&EO:6ME=61E="!<(B5S7"(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I
M9"`B061D(&$@;F5W('5S97(Z(@IM<V=S='(@(DQI<^3D('5U<VD@:^1Y='3D
M:N0Z(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C4U-@IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R("),:7/DY"!S87)A:V4B
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,T"FUS9VED
M(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`B3&ESY.0@=75S:6$@:N1S96YI
MY"(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D
M9"!P86ER(@IM<V=S='(@(DQI<^3D('!A<FDB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S<Q"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@
M365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R("),:7/DY"`E<R!V
M86QI:VMO($UO>FEL;&%N(%-I9&5B87(@;W-I;V]N(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<Q"FUS9VED(")!9&0@=&\@
M861D<F5S<R!B;V]K.B(*;7-G<W1R("),:7/DY"!O<V]I=&5K:7)J86%N.B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW.`IM
M<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O:R(*;7-G<W1R("),:7/DY"!O
M<V]I=&5K:7)J86%N:3HB"@HC.B!A9&UI;B]U<V5R+G!H<#HS,0IM<V=I9"`B
M061D('5S97(B"FUS9W-T<B`B3&ESY.0@:^1Y='3D:N0B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S
M7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA
M;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R("(B"B),:7/D
M='1I:6X@7"(E<UPB(&KD<FIE<W1E;&WDY&XL(&UU='1A(&5I('9O:2!L:7/D
M=.0@<VESY.1N:VER:F%U='5M:7-P>7EN;O9N("(*(FQI<^1T:65T;VIA.B`E
M<RXB"@HC.B!S:6=N=7`N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(D%D
M9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N
M(@IM<V=S='(@(DQI<^1T=&EI;B!<(B5S7"(@:N1R:F5S=&5L;>3D;BX@5F]I
M="!N>70@:VER:F%U='5A('-I<^3D;BXB"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I<V%B
M;&5D+B(*;7-G<W1R(")+Y'ET=.1J:65N(&QI<^3D;6EN96X@;VX@97-T971T
M>2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3(V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M-S,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T-0IM<V=I9"`B061D<F5S
M<R(*;7-G<W1R(")/<V]I=&4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,30Q"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B3W-O:71E:VER
M:F$B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU
M-@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY-0IM
M<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@
M=7-E<G,B"FUS9W-T<B`B5F]I(&%S971T86$@=&%I(&WDY')I=&5L;.0@;VEK
M975K<VEA('1O:7-I;&QE(&OD>71TY&II;&QE(@H*(SH@861M:6XO:6YD97@N
M<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@
M(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(EEL;.1P:71O(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,T,PIM<V=I9"`B061S(@IM<V=S='(@(DUA
M:6YO:W-E="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S
M='(@(D%F9V%N:7-T86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q"FUS9VED(")!;&)A;FEA(@IM
M<V=S='(@(D%L8F%N:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T"FUS9VED(")!;&=E<FEA(@IM
M<V=S='(@(D%L9V5R:6$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R(")!;&EA<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,38*;7-G:60@(D%L:6=N(@IM<V=S='(@(E1A<V%A(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI
M9VYM96YT.B(*;7-G<W1R(")487-A=7,Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C@W"FUS9VED(")!;&PB"FUS9W-T<B`B2V%I:VMI(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B
M"FUS9W-T<B`B2V%I:VMI(&%U=&5N=&EK;VED=70@:^1Y='3D:N1T(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM<V=I
M9"`B06QL($=R;W5P<R(*;7-G<W1R(")+86EK:VD@<GEH;>1T(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+V1A=&%T<F5E+G!H<#HW-2!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.CDQ"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B2V%I:VMI(&]I:V5U9&5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O
M=7(@<VED97,B"FUS9W-T<B`B2V%I:VEL=&$@;F5L:N1L=.0@<VEV=6QT82(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S4*;7-G:60@(D%L;&]W
M(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R(")386QL:2!M;VYE="!O<V]I
M='1E970B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,X"FUS9VED(")!
M;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R(")3
M86QL:2!JY')J97-T971Y;B!L:7-T86X@='EY<&EN(&%S971U<RXB"@HC.B!F
M<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HU,#0*;7-G:60@
M(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@(D]N(&IO(&]L96UA<W-A(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-@IM<V=I9"`B06QT97)N871E($E-
M4U`@3&]G:6XB"FUS9W-T<B`B5F%I:'1O96AT;VEN96X@24U34"US:7/DY&YK
M:7)J875T=6UI;F5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q,0IM
M<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B5F%I:'1O
M96AT;VEN96X@24U34"US86QA<V%N82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU,#,*;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S
M='(@(E9A:6AT;V5H=&]I;F5N($E-4U`M:^1Y='3D:N1T=6YN=7,B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS-0IM<V=I9"`B06QT97)N871E
M(&5M86EL(&%D9')E<W,B"FUS9W-T<B`B5F%I:'1O96AT;VES970@<^1H:_9P
M;W-T:6]S;VET=&5E="(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS
M9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(E9A:6AT;V5H=&]I
M<V5T(&UA;&QI="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z
M(@IM<V=S='(@(E9A:6AT;V5H=&]I;F5N('1E:W-T:3HB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(W
M"FUS9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R(")9:&1Y<W9A;'1A:6X@
M4V%M;V$B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.CDU(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I;&QE
M9V%L('9A;'5E('=A<R!S<&5C:69I960N(@IM<V=S='(@(D%N;F5T='4@87)V
M;R!E:2!K96QP86$N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$U-0IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS
M9W-T<B`B=&%P86AT=6D@='5N=&5M871O;B!V:7)H92XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(D%N9&]R<F$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B06YG;VQA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,`IM
M<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B06YG=6EL;&$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O
M>'DB"FUS9W-T<B`B06YO;GEY;6D@<')O>'DB"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@(E9A<W1A
M=7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(D%N
M=&%R:W1I<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3D*;7-G:60@(D%N=&EG=6$@86YD($)A<F)U
M9&$B"FUS9W-T<B`B06YT:6=U82!J82!"87)B=61A(@H*(SH@861M:6XO<&AP
M<VAE;&PN<&AP.C,V(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU."!T96UP;&%T97,O861M:6XO<V5T
M=7`O:6YD97@N:'1M;#HV"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R(")/
M:&IE;&UA(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R"FUS9VED(")!
M<'!L:6-A=&EO;B!,:7-T(@IM<V=S='(@(D]H:F5L;6%L:7-T82(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#`*;7-G:60@(D%P<&QI8V%T:6]N(&ES
M(')E861Y+B(*;7-G<W1R(")/:&IE;&UA(&]N('9A;&UI<RXB"@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI
M;&0@4VAA<F5S(@IM<V=S='(@(DQA:71A(&OD>71T]O9N(&MA:6MK:2!A;&EJ
M86MO:6AI;B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC
M.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(DAY=N1K<WDB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#`*;7-G:60@(D%P<')O
M>&EM871E(%-I>F4B"FUS9W-T<B`B07)V:6]I='4@:V]K;R(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!<')I
M;"(*;7-G<W1R(")H=6AT:6MU=2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3<X"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`B07)A
M8FEA("A7:6YD;W=S+3$R-38I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C<X"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C8*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@(E!A:V5T
M:6X@:V]K;R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-3@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW-PHC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8U"FUS9VED
M(")!<F-H:79E($YA;64B"FUS9W-T<B`B4&%K971I;B!N:6UI(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E
M('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R(")/;&5T:V\@
M=F%R;6$L(&5T=.0@:&%L=6%T('!O:7-T86$@<VESY.1N:VER:F%U='5M:7-P
M>7EN;O9N("5S(#\B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T
M92YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U
M('=I<V@@=&\@9&5L971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM
M<V=S='(@(D]L971K;R!V87)M82P@971TY"!H86QU870@<&]I<W1A82!<(B5S
M7"(@:F$@:V%I:VMI('-E;B!A;&ER>6AMY'0_(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-@IM<V=I
M9"`B07)G96YT:6YA(@IM<V=S='(@(D%G96YT:6EN82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(*
M;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B07)M96YI82(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")!<FUE;FEA;B`H05)-4T-)22TX*2(*
M;7-G<W1R(")!<FUE;FEA("A!4DU30TE)+3@I(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B5&%I9&4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,P"FUS9VED(")!<G5B82(*;7-G<W1R(")!<G5B82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA
M;F0B"FUS9W-T<B`B07-C96YS:6]N('-A87)E="(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@07)T(@IM<V=S='(@(D%S8VEI
M+71A:61E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS
M9VED(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@(D%S:6%N+U1Y>6YE
M;FUE<F5N(&%L=64B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(Y"FUS
M9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`B2WES>2!V87)M:7-T=7,@96YN
M96X@:W5I;B!T96ADY.1N('EL;.1P:71O=&]I;65N<&ET965T+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,P.3D*;7-G:60@(D%S<VEG;FUE;G0@
M8V]L=6UN<R(*;7-G<W1R(")496ATY';D<V%R86MK965T(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HW-`IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM
M97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(EER:71E='1I:6X@<&]I<W1A82!O
M;&5M871O;G1A(')Y:&WDY"XB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP
M.C(Y"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P
M97)M:7-S:6]N+B(*;7-G<W1R(")9<FET971T:6EN('!O:7-T86$@;VQE;6%T
M;VYT82!O:6ME=71T82XB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HX-PIM
M<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I
M;VXN(@IM<V=S='(@(EER:71E='1I:6X@;75O:V%T82!O;&5M871O;G1A(&]I
M:V5U='1A+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I
M9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G
M<W1R(")9<FET971T:6EN(&UU;VMA=&$@;VQE;6%T;VYT82!J86MO82XB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8T(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#,*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,0IM<V=I9"`B071T<FEB=71E
M<R(*;7-G<W1R("),:7/D;>3D<FET>6MS970B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Y"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B075G=7-T(@IM<V=S
M='(@(F5L;VMU=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD*;7-G:60@(D%U<W1R86QI82(*;7-G
M<W1R(")!=7-T<F%L:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X"FUS9VED(")!=7-T<FEA(@IM
M<V=S='(@(DETY'9A;'1A(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S
M<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)S<6PZ(%1A
M<G9I='1A=F%A($E-05`M;&%A:F5N;G5S=&$@96D@;/9Y='EN>70N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED(")!=71H
M7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I
M;&ET97,N(@IM<V=S='(@(D%U=&A?8WER=7,Z(%1A=7-T86KD<FIE<W1E;&WD
M(&5I('1U92!T87)V:71T879I82!O;6EN86ES=75K<VEA+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U
M<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M(")!=71H7V-Y<G5S.B!487)V:71T879A82!)34%0+6QA86IE;FYU<W1A(&5I
M(&SV>71Y;GET+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O9G1P+G!H<#HS
M-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92TB"B)F
M='`@<W=I=&-H+B(*;7-G<W1R("(B"B)!=71H7V9T<#H@=&%R=FET=&%V86$@
M1E10+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET+B!+Y.1N;N0@4$A0(&OD>71T
MY&5N("TM(@HB96YA8FQE+69T<"!A<V5T=7-T82XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VEM87`N<&AP.C8T"FUS9VED(")!=71H7VEM87`Z(%)E<75I
M<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]I
M;6%P.B!487)V:71T879A82!)34%0+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@
M(D%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R(")!=71H7VMR8C4Z(%1A<G9I='1A=F%A(&MR8C4M;&%A:F5N
M;G5S=&$@96D@;/9Y='EN>70N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES
M(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B
M075T:%]L9&%P.B!KY'ET=.1J:65N(&QI<^3D;6EN96X@06-T:79E($1I<F5C
M=&]R>7EN(&5I(&]L92!T=65T='4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C,U-PIM<V=I9"`B075T:%]L9&%P.B!296UO=FEN9R!U<V5R
M<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S
M='(@(D%U=&A?;&1A<#H@2^1Y='3D:FEE;B!P;VES=&%M:65N;B!!8W1I=F4@
M1&ER96-T;W)Y<W3D(&5I(&]L92!T=65T='4B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C8S"FUS9VED(")!=71H7VQD87`Z(%)E<75I<F5D
M($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]L9&%P
M.B!487)V:71T879A82!,1$%0+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S
M+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@HB
M075T:%]L9&%P.B!%:2!V;VED82!L:7/D=.0@:^1Y='3D:N3D("5S+B!086QV
M96QI;65N('9I<FAE:6QM;VET=7,@;VQI.B`B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H
M7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R(")!=71H
M7VQD87`Z($5I('9O:61A('!O:7-T86$@:^1Y='3D:N3D("5S(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS
M9W-T<B`B075T:%]L9&%P.B!%:2!V;VED82!PY&EVY'1TY.0@:^1Y='3D:N3D
M("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,#4*;7-G
M:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E
M9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B075T:%]L9&%P.B!+
MY'ET=.1J:65N('#D:79I='3D;6EN96X@06-T:79E($1I<F5C=&]R>7EN(&5I
M(&]L92!T=65T='4N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H
M<#HT-@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;6-A;#H@5&%R=FET=&%V86$@
M34-!3"UL86%J96YN=7-T82!E:2!L]GET>6YY="XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q
M=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!
M=71H7W-M8F%U=&@Z(%1A<G9I='1A=F%A('-M8F%U=&@M;&%A:F5N;G5S=&$@
M96D@;/9Y='EN>70N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!9&UI;BYP
M:'`Z,3`V"FUS9VED(")!=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F
M86EL960N(@IM<V=S='(@(D%U=&5N=&EK;VEN=&D@24U!4"UP86QV96QI;65L
M;&4@97#D;VYN:7-T=6DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")!=71H96YT:6-A=&EO;B!F
M86EL960B"FUS9W-T<B`B075T96YT:6MO:6YT:2!E<.1O;FYI<W1U:2(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE
M9"X@)7,B"FUS9W-T<B`B075T96YT:6MO:6YT:2!E<.1O;FYI<W1U:2X@)7,B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED
M(")!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*
M;7-G<W1R(")!=71E;G1I:V]I;G1I(%)!1$E54RUP86QV96QI;65L=&$@97#D
M;VYN:7-T=6DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX.#(*
M;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*
M;7-G<W1R(")!=71E;G1I:V]I;G1I($944"UP86QV96QI;65L;&4@97#D;VYN
M:7-T=6DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HW,`IM<V=I
M9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*
M;7-G<W1R(")!=71E;G1I:V]I;G1I(%--0BUP86QV96QI;65L;&4@97#D;VYN
M:7-T=6DN(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I
M9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`B2^1Y=&5T=.1V:7-SY&]L
M979A="!K96YTY'0Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,0IM<V=I9"`B07IE<F)A:6IA;B(*
M;7-G<W1R(")!>F5R8F%I>F1A;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS,`IM<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(D)/1D@@<V5L:71Y
M:W-E="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`B5&%U<W1A
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R(")4875S=&%VY')I
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B
M0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R(")6Y.1RY"!K97)B97)O
M<R!S86QA<V%N82XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP
M.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@(E;D
MY'+D(&ME<F)E<F]S(&OD>71TY&KD='5N;G5S+B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#4*;7-G
M:60@(D)A:&%M87,B"FUS9W-T<B`B0F%H86UA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS.`IM<V=I
M9"`B0F%H<F%I;B(*;7-G<W1R(")"86AR86EN(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#`*;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S
M='(@(D)A;'1I82`H25-/+3@X-3DM,3,I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-`IM<V=I9"`B
M0F%N9VQA9&5S:"(*;7-G<W1R(")"86YG;&%D97-H(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,PIM
M<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B0F%R8F%D;W,B"@HC.B!U=&EL+VEC
M;VY?8G)O=W-E<BYP:'`Z,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G
M<F%P:&EC<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B
M1W)A9FEI:V]I9&5N('!E<G5S:&%K96UI<W1O82!<(B5S7"(@96D@;/9Y='EN
M>70N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C$Y"FUS9VED(")"87-E;&EN92(*;7-G<W1R(")097)U<W9I:79A
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HT.0IM<V=I9"`B0F5L87)U<R(*;7-G<W1R(")686QK;RU6
M96[D:N0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C,U"FUS9VED(")"96QG:75M(@IM<V=S='(@(D)E
M;&=I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-3`*;7-G:60@(D)E;&EZ92(*;7-G<W1R(")"96QI
M>F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C0P"FUS9VED(")"96YI;B(*;7-G<W1R(")"96YI;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#$*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B0F5R;75D82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#8*;7-G:60@(D)H=71A;B(*;7-G<W1R(")":'5T86XB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS
M9VED(")":7)T:&1A>2(*;7-G<W1R(")3>6YT>6WD<.1I=N0B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S8T"B,L('!H<"UF
M;W)M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S
M7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")/<VEO=&$@7"(E<UPB(&]H:F5L;6%L
M;&4@7"(E<UPB(&5I(&SV>71Y;GET+B(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;&%Y;W5T+FEN8SHY,`IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B
M3W-I;VX@87-E='5K<V5T(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N
M:6YC.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@(D]S:6]N('1Y>7!P
M:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.`IM<V=I9"`B0F]L9"(*;7-G<W1R("),:6AA=F]I='4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S
M"FUS9VED(")";VQI=FEA(@IM<V=S='(@(D)O;&EV:6$B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C`W"FUS9VED(")";V]K;6%R:W,B"FUS9W-T
M<B`B2VER:F%N;65R:VET(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`IM<V=I9"`B0F]R9&5R(@IM<V=S='(@
M(E)E=6YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B4F5U
M;F%N('9A:'9U=7,Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR,0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R(")2
M975N870B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C,R"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V
M:6YA(@IM<V=S='(@(D)O<VYI82!(97)Z96=O=FEN82(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G<W1R(")-;VQE;6UA
M="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#@*;7-G:60@(D)O='-W86YA(@IM<V=S='(@(D)O='-W
M86YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(R"FUS9VED(")";W1T;VTB"FUS9W-T<B`B06QI;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#<*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B0F]U=F5T('-A
M87)E="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#0*;7-G:60@(D)R87II;"(*;7-G<W1R(")"<F%S
M:6QI82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$W"FUS9VED(")"<FET:7-H($EN9&EA;B!/8V5A
M;B!497)R:71O<GDB"FUS9W-T<B`B0G)I=&%N;FEA;B!);G1I86X@=F%L=&%M
M97)E;B!T97)R:71O<FEO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,@IM<V=I9"`B0G)U;F5I($1A
M<G5S<V%L86TB"FUS9W-T<B`B0G)U;F5I($1A<G5S86QA;2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,S<*;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@(D)U;&=A<FEA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B
M0G5L;&5T960@3&ES="(*;7-G<W1R(")086QL=6MK86QI<W1A(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HS-@IM<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(D)U<FMI;F$@1F%S
M;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,SD*;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B0G5R=6YD
M:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#8*;7-G:60@(D--
M4R(*;7-G<W1R(")#35,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B0U)#(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@*;7-G:60@(D-23"!$
M:7-T<FEB=71I;VX@4&]I;G1S(@IM<V=S='(@(D-23"UJ86ME;'5O<V]I='1E
M970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T
M<B`B4U]O;'5N('1I961O="XN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-3$*;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T
M960N(@IM<V=S='(@(E;D;&EM=6ES=&EN(&%L=7-T=7,@96D@=F%L;6ES='5N
M=70N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0X-2!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ-@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,34W(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ
M,#0P"FUS9VED(")#86QE;F1A<B(*;7-G<W1R(")+86QE;G1E<FDB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,U"FUS9VED(")#86QM(@IM
M<V=S='(@(E1Y>6YI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C@*;7-G:60@(D-A;6)O9&EA(@IM
M<V=S='(@(DMA;7!U='-E82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C`*;7-G:60@(D-A;65R;V]N
M(@IM<V=S='(@(DMA;65R=6XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HR,`IM<V=I9"`B0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T
M:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B
M4V%L87-A;F%A(&5I('9O:2!T>6AJ96YTY.0@875T;VUA871T:7-E<W1I+"!O
M=&$@>6AT97ET=.0@>6QLY'!I=.1JY.1N+B(*"B,Z(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C,U,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86X@;F]T
M('=R:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@(D5I('9O:2!K:7)J;VET
M=&%A('1I961O<W1O;VX@7"(E<UPB(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP
M.C(R"FUS9VED(")#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@
M:&%N9&QE<G,N(@IM<V=S='(@(E5L:V]I<VEA(&ES='5N=&]KY'-I='1E;&EJ
M]FETY"!E:2!O;&4@;6%H9&]L;&ES=&$@:&%L;&ET82XB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,S$Y(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER=7,N<&AP.C(S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C
M;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R("))34%0+7!A;'9E
M;&EM965N(&5I('-A871U('EH=&5Y='3D.B`E<R(*"B,Z(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C0T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG
M="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")%:2!V;VD@879A=&$@=&EE
M9&]S=&]A(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q"FUS9VED(")#86YA9&$B"FUS
M9W-T<B`B2V%N861A(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S
M97(N<&AP.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-C4@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q"FUS9VED(")#86YC96PB"FUS
M9W-T<B`B4&5R=2(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B4&5R
M=2!O;F=E;&UA=FEE<W1I(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HS,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE
M(%PB)7-<(BXB"FUS9W-T<B`B16D@=F]I9&$@<&]I<W1A82!T:65D;W-T;V$@
M7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C0V"FUS9VED(")#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E
M8W1O<GDN(@IM<V=S='(@(E;D;&EA:6MA:7-H86ME;6ES=&]A(&5I(&SV>71Y
M;GET+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP
M:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I
M;&4G('!A<F%M971E<BXB"FUS9W-T<B`B16D@=F]I9&$@:F%T:V%A(&EL;6%N
M("=T87)G971&:6QE)R`M<&%R86UE=')I82XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C,Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@
M<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(D5I('9O:61A('!O
M:7-T86$@:&%K96UI<W1O82!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+T1A=&%4
M<F5E+T1A=&%4<F5E+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4
M<F5E+W-Q;"YP:'`Z-C@P"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R
M96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R(")%:2!V;VED82!P
M;VES=&%A+"`E9"!A;&ET87-O:F$@;VQE;6%S<V$N(@H*(SH@9G)A;65W;W)K
M+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B"B)#86YN
M;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E
M;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T
M<B`B(@HB16D@=F]I('5U9&5L;&5E;FKD<FIE<W3DY"P@86YN971T=6IE;B!T
M:65T=65I9&5N(&WDY'+D(&5I('9A<W1A82`B"B)T86QL971E='1U:F5N('1I
M971U96ED96X@;>3D<N3D+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE
M<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B16D@=F]I(&]H
M:F%T82!V:65S=&GD(&%N;F5T='5U;B!N=6UE<F]O;BXB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8U
M"FUS9VED(")#87!E(%9E<F1E(@IM<V=S='(@(DMA<"!697)D92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*
M;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`B2W5V871E:W-T:2(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B
M0V%R<FEE<B(*;7-G<W1R(")086QV96QU;G1A<FIO86IA(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDS"FUS9VED(")#871E9V]R:65S(&%N9"!,86)E
M;',B"FUS9W-T<B`B2V%T96=O<FEA="!J82!O='-I:V]T(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,S4*;7-G:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(D-A>6UA;B!S86%R
M970B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3DT"FUS9VED(")#96QL(%!H;VYE(@IM<V=S='(@(E!U:&5L:6XH1U--*2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C4*;7-G:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G<W1R(")3;VQU;B!T
M:65D;W0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R(")3;VQU;B!T
MY'ET93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS9W-T<B`B
M4V]L=6X@=&EE9&]T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`B
M4V]L=6X@=N1L>7,Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(W
M.`IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(DUA=&MA<'5H96QI;B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#96QT:6,@*$E33RTX
M.#4Y+3$T*2(*;7-G<W1R(")+96QT=&D@*$E33RTX.#4Y+3$T*2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*
M;7-G:60@(D-E;G1E<B(*;7-G<W1R(")+97-K:71E='1Y(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M-`IM<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@(DME
M<VMI+4%F<FEK86X@=&%S879A;'1A(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#(*;7-G:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM
M<V=S='(@(DME<VMI+45U<F]O<'!A("A)4T\M.#@U.2TR*2(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED(")#97)T:69I
M8V%T92!$971A:6QS(@IM<V=S='(@(E9A<FUE;G1E96X@=&EE9&]T(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3(*;7-G:60@(D-E
M<G1I9FEC871E($]W;F5R(@IM<V=S='(@(E9A<FUE;G1E96X@;VUI<W1A:F$B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I
M9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B5F%R;65N=&5E;B!P
M;VQI=&EI:V%T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Q"FUS9VED(")#:&%D(@IM<V=S='(@
M(E1S860B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"FUS9VED(")#:&%N9V4B"FUS
M9W-T<B`B375U=&$B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M,S$*;7-G:60@(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(E9A:6AD
M82!S86QA<V%N87-I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Y"FUS
M9VED("(B"B)#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P
M;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M
M86EL<RXB"FUS9W-T<B`B(@HB5F]I="!M=75T=&%A(&SD:&5T=.1M:7-SY'-I
M('/D:&OV<&]S=&5I<W-A(&[D:WEV:>0@;FEM:2T@=&%I(&]S;VET971I971O
M:F$N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED
M("(B"B)#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@
M=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(E-A;&%S86YA;B!V86EH
M=&\@96D@;VQE(&OD>73V<W/D(&YY:WEI<VEL;.0@87-E='5K<VEL;&$N($]T
M82!Y:'1E>71TY"`B"B)Y;&SD<&ETY&II:6XN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PIM<V=I9"`B0VAA
M<B(*;7-G<W1R(")-97)K:VDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK
M+BXN(@IM<V=S='(@(E1A<FMI<W1?82!L:6YK:VDN+BXB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Y
M"FUS9VED(")#:&EL92(*;7-G<W1R(")#:&EL92(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C4T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C$*;7-G
M:60@(D-H:6YA(@IM<V=S='(@(DMI:6YA(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#,*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*
M;7-G<W1R(")+:6EN82!Y:W-I;FME<G1A:7-T971T=2`H1T(R,S$R*2(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@T"FUS9VED(")#:&EN97-E(%1R861I
M=&EO;F%L("A":6<U*2(*;7-G<W1R(")+:6EN82!P97)I;G1E:6YE;B`H0FEG
M-2DB"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHW"FUS9VED(")#:&]O
M<V4@07!P;&EC871I;VXZ(@IM<V=S='(@(E9A;&ET<V4@;VAJ96QM82(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@(D-H
M;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(E9A;&ET<V4@<V%L87-A;F$B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")#
M:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R(")686QI='-E(&OD>71TY&KD='5N
M;G5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P,@IM<V=I9"`B0VAO
M;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G<W1R(")686QI='-E('#D
M:7;D;>3D<FEE;B!E<VET>7-A<W4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E
M(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I(@IM<V=S='(@
M(E9A;&ET<V4@;&ES=&%N('1Y>7!P:2`H:N1R:F5S=&5T>6EL;&4@;&ES=&]I
M;&QE*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-C8*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS
M9W-T<B`B2F]U;'5S86%R970B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M.3$T(&9R86UE=V]R:R].971?4TU3+U--4RYP:'`Z,CDT"B,L('!H<"UF;W)M
M870*;7-G:60@(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*
M;7-G<W1R("),=6]K:V%MY.1R:71Y<W3D("5S(&5I(&SV>71Y;GET+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS9VED
M(")#;&5A<B(*;7-G<W1R(")396QK9>0B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC
M92!T86=S(@IM<V=S='(@(E!O:7-T82!-4T]F9FEC92!T86=I="(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,CD*;7-G:60@(D-L96%R(%%U97)Y(@IM<V=S
M='(@(E!O:7-T82!K>7-E;'DB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C
M;&5A<BYI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@=7-E
M<CH@)7,B"FUS9W-T<B`B4&]I<W1A(&OD>71TY&KD.B`E<R(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,0IM<V=I9"`B0VQE87(@=7-E
M<B(*;7-G<W1R(")0;VES=&$@:^1Y='3D:N0B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]L:7-T+FEN8SHS-`IM<V=I9"`B0VQE87(@=7-E<B!D871A(@IM
M<V=S='(@(E!O:7-T82!KY'ET=.1JY&X@=&EE9&]T(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,34*;7-G:60@(D-L96%R:6YG
M($QA=&4B"FUS9W-T<B`B4V5L:V5N97;DY"!M>?9HY.1N(@H*(SH@=&5M<&QA
M=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-C`*;7-G:60@(D-L
M:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(DYA<'-A=71A(&IA=&MA86MS97-I
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(D-L
M:6MA=&5L;"!(5%10.FX@:V%U='1A(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N
M<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED(")#
M;&]S92!7:6YD;W<B"FUS9W-T<B`B4W5L:F4@:6MK=6YA(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR-3$*;7-G:60@(D-L;W5D<R(*;7-G<W1R(")0:6QV
M:>0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M-@IM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(E!I;'9I;F5N(&%I:V%I
M<VEN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,3<*;7-G:60@(D-L;W5D>2(*;7-G<W1R(")0:6QV:6YE;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C4V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-3(*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(DMO
M;VMO<R`H2V5E;&EN9RD@<V%A<F5T(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S
M:61E8F%R+FEN8SHR,PIM<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R
M(")0:65N96YNY"!S:79U=F%L:6MK;R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E
M9"!B;W)D97)S(@IM<V=S='(@(E!I96YE;FYE='ET(')E=6YA="(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C4W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-C(*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(DMO;'5M8FEA(@H*(SH@
M;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@(E;D<FDB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`S"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,S4*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,S-B!S97)V:6-E<R]I;6%G
M97,O8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS
M9W-T<B`B5N1R:79A;&ET<VEN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C@S,@IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R(")6Y')I
M=F%L:6YT82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R(")387)A:SHB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.34P"FUS9VED(")#;VQU;6X@=&ET
M;&5S(@IM<V=S='(@(E-A<F%K:V5I9&5N(&]T<VEK;W0B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C8V"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B
M4V%R:F%K=79A="(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-@IM<V=I9"`B
M0V]M;6%N9"(*;7-G<W1R(")+;VUE;G1O(@H*(SH@861M:6XO8VUD<VAE;&PN
M<&AP.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@(DMO;65N=&]T
M=6QK:VDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*
M;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B2V]M;65N='1I(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G:60@(D-O;6UO;B!.
M86UE(@IM<V=S='(@(EEL96EN96X@;FEM:2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,P"FUS9VED
M(")#;VUO<F]S(@IM<V=S='(@(DMO;6]R:70B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM
M<V=S='(@(EER:71Y<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,0IM
M<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(E1I971O:V]N965T(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-@IM<V=I9"`B0V]N9&ET:6]N
M(@IM<V=S='(@(D]L;W-U:&1E(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-38*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B3VQO<W5H=&5E="(*"B,Z
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N
M($1I9F9E<F5N8V5S(@IM<V=S='(@(D%S971U:W-I96X@97)O="(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#8*;7-G:60@(D-O;F9I9W5R871I;VX@
M9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O
M:RXB"FUS9W-T<B`B07-E='5K<V5T(%!$02UL86ET=&5I9&5N+"#D;'EP=6AE
M;&EM:65N(&IA($]U=&QO;VMI;B!S>6YK<F]N;VET:6EN+B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ,S4*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@
M;W5T(&]F(&1A=&4N(@IM<V=S='(@(D%S971U:W-I82!P:73DY"!PY&EV:71T
MY.0N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B07-E=&$@87-E='5K
M<V5T("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHU
M,0IM<V=I9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R(")686AV:7-T82!K
M:7)J;VET=&%M86QL82!S86QA<V%N82!U=61E<W1A86XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4U
M"FUS9VED(")#;VYG;R(*;7-G<W1R(")+;VYG;R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C8P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3,*;7-G
M:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4B"FUS
M9W-T<B`B2V]N9V]N(&1E;6]K<F%A='1I;F5N('1A<V%V86QT82(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.`HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#D*;7-G:60@(D-O
M;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R(")9:'1E>7,@97#D;VYN:7-T=6DN
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DX
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.0IM
M<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("(*;7-G<W1R(")9:'1E>7,@97#D
M;VYN:7-T=6DZ("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+B(*;7-G<W1R(")9:'1E>7,@:G5L:VES=&5N(&%V86EN=&5N
M('!A;'9E;&EM96QL92!E<.1O;FYI<W1U:2XB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N
M;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S
M;VXZ("5S("@E<RDB"FUS9W-T<B`B66AT97ES(&IU;&MI<W1E;B!A=F%I;G1E
M;B!P86QV96QI;65L;&4@97#D;VYN:7-T=6DN(%9I<FAE.B`E<R`H)7,I(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-S8*;7-G:60@(D-O;FYE
M8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(EEH=&5Y<R!F
M='`M<&%L=F5L:6UE;&QE(&5PY&]N;FES='5I+B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.3(T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#8W
M"FUS9VED(")#;VYT86-T<R(*;7-G<W1R(")9:'1E>7-T:65D;W0B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@
M(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D
M<F5S<R!B;V]K+B(*;7-G<W1R(")9:'1E>7-T:65D;W0@;&ESY'1T:6EN(&]S
M;VET96MI<FIA87-I+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z-C`*;7-G:60@(D-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D
M(&9I;&4Z("(*;7-G<W1R(")4:6EV:7-T971Y;B!T:65D;W-T;VX@='EY<'!I
M.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW-0HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R(")<(B5S7"(Z
M;B!S:7/D;'3V(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y"FUS9VED(")#;VYT:6YU
M92(*;7-G<W1R(")*871K82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@*;7-G:60@(D-O;VL@27-L
M86YD<R(*;7-G<W1R(")#;V]K('-A87)E="(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS,@IM<V=I9"`B0V]O:VEE(@IM<V=S='(@(D5VY'-T92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR,0IM<V=I9"`B0V]P>2(*;7-G<W1R(")+;W!I;VDB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C0W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`B2V]P:6]I;G1I(&5PY&]N;FES='5I
M.B`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S='(@(DMO<&EO:2!V
M86QI;G1A(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HQ-S`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ
M.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B0V]S="!)1"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-C,*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B0V]S=&$@4FEC82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-3<*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B3F]R<W5N
M;'5U<F%N;FEK:V\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HY-S<*;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E.B`B
M"FUS9W-T<B`B5FEE<W1I;B!01U`M<V%L875S=&$@96D@=F]I='4@=&5H9.0Z
M("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P-34*;7-G
M:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E.B`B"FUS9W-T<B`B5FEE
M<W1I:6X@96D@=F]I='4@;75O9&]S=&%A(%!'4"UA;&QE:VER:F]I='5S=&$Z
M("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,SDS"FUS
M9VED(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T
M<B`B5FEE<W1I;B!3+TU)344M<V%L875S=&$@96D@=F]I='4@=&5H9.0N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT-C<*;7-G:60@
M(D-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+B(*;7-G<W1R(")6:65S
M=&EI;B!E:2!V;VET=2!M=6]D;W-T86$@4R]-24U%+6%L;&5K:7)J;VET=7-T
M82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C$X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O
M;G1A8W0N("5S(@IM<V=S='(@(D5I('9O:71U(&]T=&%A('EH=&5Y='3D+B`E
M<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$R,0HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-#4W"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E
M<G9E<BXB"FUS9W-T<B`B3&1A<"UP86QV96QI;65E;B!E:2!S86%T=2!A=71O
M<FES;VET=6$@>6AT97ET=.0N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R(")%:2!V
M;VET=2!T87)K:7-T86$@<V%L9&]A+B`E<R(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HT-#$*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O($Q$05`@
M<V5R=F5R+B(*;7-G<W1R("),1$%0+7!A;'9E;&EM965N(&5I('-A871U('EH
M=&5Y='3D+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@7"(E
M<UPB('5S:6YG($944#H@)7,B"FUS9W-T<B`B16D@=F]I='4@;W1T86$@>6AT
M97ET=.0@<&%L=F5L:6UE96X@7"(E<UPB(&OD>71TY&5N($944#H@)7,B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")%:2!V;VET=2!L=6]D82!J86ME
M;'5L:7-T86$N("5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,3$R.`IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z("(*
M;7-G<W1R(")01U`M<V%L871T=6$@=&EE=&]A(&5I('9O:71U(&%U:V%I<W1A
M.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R,PIM
M<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@
M(E,O34E-12US86QA='1U82!T:65T;V$@96D@=F]I='4@875K86ES=&$N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR
M-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT
M86-T+B`E<R(*;7-G<W1R(")%:2!V;VET=2!P;VES=&%A('EH=&5Y<W1I971O
M82X@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L
M971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")%:2!V;VET=2!P
M;VES=&%A(&IA:V5L=6QI<W1A82X@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L
M971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B16D@
M=F]I='4@<&]I<W1A82!PY&EV:71Y<W-K<FEP=&GD(%PB)7-<(BXB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,X,2!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-3,*;7-G:60@(D-O=6QD(&YO="!D971E
M<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R
M(")6:65S=&EN(&SD:&5T=.1JY&X@<^1H:_9P;W-T:6]S;VET971T82!E:2!P
M>7-T>71T>2!MY.1R:71T96QE;>3D;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U;&0@;F]T
M(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B16D@=F]I
M='4@:&%K96$@:V]K;R!O<V]I=&5K:7)J86$N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*;7-G:60@(D-O=6QD
M(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T
M<B`B16D@=F]I='4@:&%K96$@:V]K;R!J86ME;'5L:7-T86$N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G
M:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T
M<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(D5I('9O:71U(&AA:V5A(&MO:V\@
M;&ES=&%A(&IA:V5L=6QI<W1O:7-T82XB"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDN<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T<B`B16D@=F]I='4@;'5K
M96$@<W1R871E9VEA82!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP
M.C,P"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B2V]M96YT;R!M
M:V1I<B!<(B5S7"(@97#D;VYN:7-T=6DN(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-S$Y"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U
M8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R(")*=6QK:7-T
M96X@879A:6YT96X@<&%L=F5L:6UE;'1A(&5I('-A871U(&IU;&MI<W1A(&%V
M86EN=&$N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM
M<V=S='(@(E1I961O<W1O;VX@7"(E<UPB(&5I('9O:2!K:7)J;VET=&%A+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8W-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB
M"FUS9W-T<B`B16D@=F]I='4@875K86ES=&$@)7,N(@H*(SH@9G)A;65W;W)K
M+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HT,C`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U
M;&4@)7,B"FUS9W-T<B`B66QLY'!I=&]M;V1U=6QI;B`E<R!A=6MA:7-U(&5P
MY&]N;FES='5I(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM
M<V=S='(@(D5I('9O:2!A=6MA:7-T82!H86ME;6ES=&]A(%PB)7-<(BXB"@HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$Q(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C(S-R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z-#<X"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HU
M,38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C4V(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HV.3D*;7-G:60@(D-O=6QD(&YO="!R96%C:"!T
M:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(DQ$05`M<&%L=F5L:6UE;'1A(&5I
M(&]L92!M86AD;VQL:7-T82!E='-IY"XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]/8FIE8W0N<&AP.C(T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<F5A9"`E<RXB"FUS9W-T<B`B)7,ZY.0@96D@=F]I='4@;'5K96$N(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O
M=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@
M=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C
M;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B)+
MY'ET=.1JY&X@<V%L87-A;F%A(&5I('9O:71U(&YO;&QA=&$N($IO=&MU="!T
M87)V:71T879A="!T:65D;W0@;W9A="!VY.1R:6XN("(*(EER:73D('5U9&5S
M=&%A;B!T86D@;W1A('EH=&5Y='3D('EL;.1P:71O;VX@:F]S('1A<G9I='-E
M="!L:7/DY"!A<'5A+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,P.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS,SD*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S<V"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,X,@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS.#@*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B
M16D@=F]I='4@:&%K96$@04-,+71I971O:F$B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*
M;7-G<W1R(")%:2!V;VET=2!H86ME82!O<V]I=&5K:7)J86$N("5S(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")%:2!V;VET=2!H86ME82!J86ME
M;'5L:7-T86$N("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B
M16D@=F]I='4@:&%K96$@:F%K96QU;&ES=&]J82X@)7,B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3@*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$X"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,@IM<V=I9"`B0V]U;&0@;F]T
M(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R(")%:2!V
M;VET=2!H86ME82!T:65T;VIA('!A;'9E;&EM96X@=&]I;6EN;F]I<W1A(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`IM<V=I9"`B0V]U;&0@;F]T
M(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")%:2!V;VET=2!P86QA
M=71T86$@87-E='5K<VEA+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G
M<W1R(")+;VUE;G1O(')M9&ER(%PB)7-<(B!E<.1O;FYI<W1U:2XB"@HC.B!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")%
M:2!V;VET=2!T86QL971T86$@)7,@87-E='5K<VEA+B(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C4Y(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,PIM
M<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*
M;7-G<W1R(")%:2!V;VET=2!T86QL971T86$@87-E='5S=&5N('9A<FUU=7-K
M;W!I;W1A+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U
M871I;VXZ("5S(@IM<V=S='(@(D5I('9O:71U('1A;&QE='1A82!A<V5T=7-T
M96X@=F%R;75U<VMO<&EO=&$@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HY-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S
M971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(")%:2!V
M;VET=2!T86QL971T86$@87-E='5S<.1I=FET>7-S:W)I<'1IY#H@7"(E<UPB
M+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T
M:6]N(&9I;&4@)7,N(@IM<V=S='(@(D5I('9O:71U('1A;&QE='1A82!A<V5T
M=7-T96X@=F%R;75U<VMO<&EO=&$@)7,N(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HW-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@
M<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE
M<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@
M8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O
M("5S+B(*;7-G<W1R("(B"B)!<V5T=7-T:65D;W-T;VX@)7,@=&%L;&5T=7,@
M97#D;VYN:7-T=6DN(%9O:70@:^1Y='3DY"!J;W1A:VEN(&%S971U<W1A("(*
M(G1A;&QE='1A86MS97-I(&MO;V1I;B!T86MA:7-I;B`E<R!T86D@=&%I(&MO
M<&EO:61A(&OD<VEN(&%L;&$@;VQE=F%N(&MO;V1I;B`B"B)T:65D;W-T;V]N
M("5S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,30S"FUS
M9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T
M<B`B3$1!4"UP86QV96QI;65L=&$@96D@;VQE(&UA:&1O;&QI<W1A(&5T<VGD
M+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB"FUS9W-T<B`B2V]M96YT;R!U
M;FQI;FL@7"(E<UPB(&5PY&]N;FES='5I+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B
M16D@=F]I='4@<.1I=FET=.3D('EH=&5Y<W1I971O:F$N("5S(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I
M;VX@;&ES="X@)7,B"FUS9W-T<B`B16D@=F]I='4@<.1I=FET=.3D(&IA:V5L
M=6QI<W1A82X@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I
M;VX@9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B5FEE<W1E:N0@96D@=F]I='4@
M<&]I<W1A82!K86YS:6]S=&$@7"(E<UPB.B`E<R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-S`*;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL
M;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM
M<V=S='(@(DUO>FEL;&$@4VED96)A<B!E:2!L]GET>6YY="X@5F%R;6ES=&$@
M971TY"!3:61E8F%R(&]S:6\@;VX@875K:2XB"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T:&4@9F]L;&]W:6YG
M(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S(@IM<V=S='(@(B(*
M(DOD>71TY&KD;&QE(%PB)7-<(B!E:2!V;VET=2!A;G1A82!S975R86%V:6$@
M;VEK975S:6$@:V%N<VEO;VX@7"(E<UPB.B`E<R(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T,C,*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R
M("),87-K971T=2!T96MS=&DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4W,`IM<V=I9"`B0V]U;G1R>2(*;7-G<W1R(")-86$B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C<U"FUS9VED(")#;W5R<V5S
M(@IM<V=S='(@(DMU<G-S:70B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*
M;7-G<W1R("),=6\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T92!A(&QI;FLB"FUS
M9W-T<B`B3'5O('5U<VD@;&EN:VMI(@H*(SH@=&5M<&QA=&5S+W!R969S+VED
M96YT:71Y<V5L96-T+FEN8SHY-`IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*
M;7-G<W1R("),=6\@=75S:2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S0S,30N<&AP.C4R"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.CDS"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T
M<B`B5F]I(&QU;V1A('5U<VEA(&MA;G-I;VET82(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I
M;VYS(@IM<V=S='(@(D]I:V5U9&5T('1E:VEJY&QLY"(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,R,38*;7-G:60@(D-R961I="!C87)D(&YU;6)E
M<B(*;7-G<W1R("),=6]T=&]K;W)T:6YN=6UE<F\B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.0IM
M<V=I9"`B0W)O871I82(*;7-G<W1R(")+<F]A=&EA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-`IM
M<V=I9"`B0W5B82(*;7-G<W1R(")+=75B82(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HR-@IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R(")4Y&WD
M;FAE=&MI;F5N(#0@=F%I:&5T=&$B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z
M-3`*;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B"FUS9W-T<B`B5.1MY&YH971K
M:7-E="!I<W1U;FYO="(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]"
M;&]C:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@
M(DME;&QO;F%I:V$@=.1L;.0@:&5T:V5L;.0B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U
M<G)E;G0@55),(&ES(@IM<V=S='(@(E3D;>1N:&5T:VEN96X@55),(&]N(@H*
M(SH@861M:6XO<V5S<VEO;G,N<&AP.C,U"FUS9VED(")#=7)R96YT(%5S97)S
M(@IM<V=S='(@(E3D;>1N:&5T:VES970@:^1Y='3D:N1T(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR-0IM<V=I9"`B0W5R<F5N="!796%T:&5R(@IM<V=S
M='(@(E3D;>1N:&5T:VEN96X@<^3D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(V-`IM<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G
M<W1R(")4Y&WD;FAE=&MI;F5N('1I;&$Z("(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y
M;&4B"FUS9W-T<B`B5.1MY&YH971K:6YE;B!T>7EL:2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M
M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R("(B
M"B)6;VET(&UU;VMA=&$@=&5H=.1V:>0L(&IO=&MA('-U;W)I=&5T86%N(&MU
M;B!K:7)J875D=71A86X@<VESY.1N(&]H:F5L;6%A;B`E(@HB<RXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C`*;7-G:60@(D-U="(*;7-G<W1R("),96EK:V%A(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E
M;&5C=&EO;B(*;7-G<W1R("),96EK:V%A('9A;&ET='4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8W
M"FUS9VED(")#>7!R=7,B"FUS9W-T<B`B2WEP<F]S(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#4*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S
M='(@(DMY<FEL;&EN96X@*$M/23@M4BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X-@IM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T
M<B`B2WER:6QL:6YE;B`H5VEN9&]W<RTQ,C4Q*2(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@W"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M
M52DB"FUS9W-T<B`B2WER:6QL:6YE;B]5:W)A:6YA("A+3TDX+54I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV.`IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS9W-T<B`B5'-E:VEN
M('1A<V%V86QT82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-3(@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$
M(@IM<V=S='(@(E!0(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W
M-@IM<V=I9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU
M86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G
M<W1R("(B"B)$4TX@*&QI<^1T:65T;V$@:'1T<#HO+W!E87(N<&AP+FYE="]M
M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN(@HB<&AP
M*2(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z
M-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(E#D:79I='3D:6XB"@HC.B!A9&UI
M;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS
M9W-T<B`B1&%T851R964M<V5L86EN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S(W-`IM<V=I9"`B1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@(E1I
M971O:V%N=&%H86MU(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F9C.#(R+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#`R"FUS
M9VED(")$871E(@IM<V=S='(@(E#D:7;D>7,B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E:79E9"(*
M;7-G<W1R(")0Y&EVY&WDY'+D('9A<W1A86YO=&5T='4B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-SDS"FUS9VED(")$871E('-E;&5C=&EO;B(*
M;7-G<W1R(")0Y&EVY&WDY'+D;B!V86QI;G1A(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(X,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S$Q"FUS9VED(")$87DB"FUS9W-T<B`B4.1I=N0B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*;7-G
M:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(E!O7VES=&$@<V%R86ME(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,PHC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4Q"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G
M:60@(D1E8V5M8F5R(@IM<V=S='(@(FIO=6QU:W5U(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I
M9"`B1&5C:6UA;"!N=6UB97)S(@IM<V=S='(@(D1E<VEM86%L:6YU;65R;W0B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(P
M"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`B4&EE;F5N;N0@<VES
M96YN>7-TY"(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3@W
M(&QI8B]P<F5F<RYP:'`Z,3$W"FUS9VED(")$969A=6QT(@IM<V=S='(@(D]L
M971U<R(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C<W"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(D]L971U<W;D
M<FDB"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.CDV"FUS
M9VED(")$969A=6QT($ED96YT:71Y(@IM<V=S='(@(D]L971U<W!R;V9I:6QI
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8W"FUS9VED(")$969A=6QT
M(%-H96QL(@IM<V=S='(@(D]L971U<R!K;VUE;G1O='5L:VMI(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I;FET:6]N<R(*;7-G
M<W1R(")-Y.1R:71E;&WD="(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C8*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HT,C(@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HT,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C<P"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z.3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ.#(*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY.`HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]L:7-T+FEN8SHS,2!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V1E;&5T92YI;F,Z,3`*;7-G:60@(D1E;&5T92(*;7-G<W1R(")0;VES=&$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S(*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S='(@(E!O:7-T82!S
M;VQU(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S+G!H
M<#HR,C<*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R(")0;VES=&$@<GEH
M;>0B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#D*;7-G:60@
M(D1E;&5T92!,;V<B"FUS9W-T<B`B4&]I<W1A(&QO:VDB"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<W(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,3`Q"FUS9VED(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R
M(")0;VES=&$@;VEK975S(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.30*;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G
M97,B"FUS9W-T<B`B5F]I('!O:7-T86$@:F$@='5H;W1A('!O:7-T971T=6IA
M('9I97-T96KD(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E(&-E;&PB"FUS9W-T<B`B
M4&]I<W1A('-O;'4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@8V]L=6UN(@IM<V=S
M='(@(E!O:7-T82!S87)A:V4B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T
M.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T92(*
M;7-G<W1R(")0;VES=&$@;VQE;6%S<V$@;VQE=F%T('9A:6AT;V5H=&]I;F5N
M(&UA;&QI(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP
M:'`Z-30*;7-G:60@(D1E;&5T92!M97-S86=E<R(*;7-G<W1R(")6;VD@<&]I
M<W1A82!V:65S=&5JY"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z-#(Q"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N
M<R!F;W(@7"(E<UPB(@IM<V=S='(@(E!O:7-T82!<(B5S7"(Z;B!O:6ME=6MS
M:6$B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<
M(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T<B`B3VQE=&MO('9A
M<FUA+"!E='3D(&AA;'5A="!P;VES=&%A(%PB)7-<(B!J82!K86EK:VD@<V5N
M(&%L:6]I:V5U9&5T/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T
M<B`B4&]I<W1A(')I=FDB"@HC.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E
M;G1I='DN:6YC.C$U"FUS9VED(")$96QE=&4@<V5L96-T960@:61E;G1I='DB
M"FUS9W-T<B`B4&]I<W1A('9A;&ET='4@<')O9FEI;&DB"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,PIM<V=I9"`B1&5L971E
M('-U8B!F;VQD97)S(@IM<V=S='(@(E9O:2!L=6]D82!U=7-I82!K86YS:6]I
M=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB
M"FUS9W-T<B`B4&]I<W1A('9A;&ET='4@<V%R86ME(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED
M(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM<V=S='(@(E!O:7-T82!V86QI
M='1U(')I=FDB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T
M(%PB)7-<(BXB"FUS9W-T<B`B4&]I<W1E='1U('#D:79I='ES<VMR:7!T:2!<
M(B5S7"(N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(U,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4V,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4Y-0IM<V=I9"`B1&5L:79E<GD@=&EM92(*
M;7-G<W1R(")4;VEM:71U<V%I:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Q"FUS9VED(")$96YM
M87)K(@IM<V=S='(@(E1A;G-K82(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G
M<W1R(")/;F=E;&UA;B!K=79A=7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HY-#(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B2W5V875S
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3<*;7-G:60@(D1E
M=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B5&%R
M:V5M;6%T('1I961O="`H;/9Y='EVY'0@;7GV<R!(;W)D93IN(&QO:VET:65D
M;W-T;W-T82DZ(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HR,#$*
M;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN
M:7-T<F%T;W(N(@IM<V=S='(@(E1A<FME;6UA="!T:65D;W0@;VX@=&%L;&5T
M971T=2!Y;&SD<&ED;VX@:^1S:71E;'3D=N1K<VDN(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(R,0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T
M<B`B2V5H:71Y<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(T"FUS9VED
M(")$97<@4&]I;G0B"FUS9W-T<B`B2V]S=&5U<W!I<W1E(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS,#$*;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H
M;W5R.B`B"FUS9W-T<B`B161E;&QI<V5N('1U;FYI;B!K;W-T975S<&ES=&4Z
M("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*;7-G:60@
M(D1E=R!P;VEN=#H@(@IM<V=S='(@(DMO<W1E=7-P:7-T93H@(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B
M1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`B4W5U;G1A('9A<V5M
M;6%L=&$@;VEK96%L;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F
M="(*;7-G<W1R(")3=75N=&$@;VEK96%L=&$@=F%S96UM86QL92(*"B,Z(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T
M<B`B2&%K96UI<W1O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W,`IM
M<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R(")+Y'ETY"`R
M-"UT=6YN:6X@86EK865S:71Y<W3D+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,#`*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R(").Y&MY
M;>1N(&%S971U:W-E="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HX.0IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R
M(")%<VET>7-T87!A('EK<VET>6ES:V]H=&%I;F5N(&5N;G5S=&4B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.CDR"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T
M("A4048I(@IM<V=S='(@(D5S:71Y<W1A<&$@96YN=7-T965L;&4@*%1!1BDB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`S"FUS9VED(")$:7-P
M;&%Y(&9O<FUA="(*;7-G<W1R(")%<VET>7-T87!A(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-1$XN<&AP.C$Y,0IM<V=I9"`B1&ES<&]S:71I;VX@3F]T
M:69I8V%T:6]N(@IM<V=S='(@(E!E<FEL;&5M96YO:6QM;VET=7,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C<P"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R(")$:FEB;W5T:2(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R"FUS9VED(")$;R!N
M;W0@9&5L971E(@IM<V=S='(@(D5I('-A82!P;VES=&%A(@H*(SH@<V5R=FEC
M97,O;6%I;G1E;F%N8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@
M86-C97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R("+$;.0@:^1Y=.0@<W5O
M<F%A;B!M86EN=&5N86YC92YP:'`Z=.0B"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHQ,B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,@IM
M<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA
M;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R(")*;W,@96YS
M:6UMY&EN96X@<FEV:2!S:7/D;'3DY"!S87)A:VME:61E;B!O='-I:V]T+"!N
M:6EN('9A;&ET<V4Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,@IM<V=I9"`B1&]M:6YI8V$B"FUS
M9W-T<B`B1&]M:6YI:V%A;FEN96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<S"FUS9VED(")$;VUI
M;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B1&]M:6YI:V%A;FEN96X@=&%S879A
M;'1A(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY-@IM<V=I9"`B
M1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R(")%:6OV
M(&]L92!KY'ET=.1JY'1U;FYU<W1A/R!+:7)J875D=2!KY'ET=.1JY&MS:2XB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-3$*;7-G
M:60@(D1O=VYL;V%D(@IM<V=S='(@(E1A;&QE;FYA(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#4Q"B,L('!H<"UF;W)M870*;7-G
M:60@(D1O=VYL;V%D("5S(@IM<V=S='(@(E1A;&QE;FYA("5S(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO860@9V5N97)A
M=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`B5&%L
M;&5N;F$@;'5O='4@87-E='5S(%!(4"US:W)I<'1I;N0N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q,0IM<V=I9"`B1')O<"!D;W=N(&QI<W0B
M"FUS9W-T<B`B06QA<W9E=&]V86QI:VMO(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G<W1R(")(=75M965T(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")%+4UA
M:6PB"FUS9W-T<B`B4^1H:_9P;W-T:6]S;VET92(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDR"FUS9VED(")%36%I;"UT
M;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V
M:61E('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B(@HB14UA:6PM=&\M4TU3(&=A
M=&5W87D@86IU<FDL(&YI:6QL92!P86QV96QU;G1A<FIO86II;&QE+"!J;W1K
M82!T87)J;V%V870@=.1TY"`B"B)P86QV96QU82XB"@HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP
M.C,T"FUS9VED(")%4E(B"FUS9W-T<B`B5DE22$4B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<U"FUS
M9VED(")%8W5A9&]R(@IM<V=S='(@(D5C=6%D;W(B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C,R-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C,U"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-CD@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,2!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z-S(*;7-G:60@(D5D:70B"FUS9W-T<B`B375O:VMA82(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3`*;7-G:60@(D5D:70@
M0FQO8VLB"FUS9W-T<B`B375O:VMA82!O<VEO=&$B"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C$Y."!A9&UI;B]G<F]U<',N<&AP.C(R-@IM<V=I9"`B161I="!'
M<F]U<"(*;7-G<W1R(")-=6]K:V%A(')Y:&WDY"(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z-S8@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HQ,#`*;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R(")-=6]K
M:V%A(&]I:V5U='1A(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S
M-PIM<V=I9"`B161I="!097)M:7-S:6]N<R(*;7-G<W1R(")-=6]K:V%A(&]I
M:V5U:W-I82(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS
M9W-T<B`B375O:VMA82`G)7,G.FX@;VEK975K<VEA(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS
M9W-T<B`B375O:VMA82!A<V5T=6MS:6$Z(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P
M97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(DUU;VMK86$@7"(E<UPB
M.FX@;VEK975K<VEA(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E
M<R(*;7-G<W1R(")-=6]K:V%A("5S.FX@;VEK975K<VEA(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,U"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B
M2V]U;'5T=7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C<W"FUS9VED(")%9WEP="(*;7-G<W1R(")%
M9WEP=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,3<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S
M='(@(D5L(%-A;'9A9&]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM
M<V=S='(@(D5L96UE;G1T:2XN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R(")%;2(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,PIM<V=I9"`B16UA:6PB"FUS
M9W-T<B`B4^1H:_9P;W-T:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-38V('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-C@*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`IM<V=I
M9"`B16UA:6P@061D<F5S<R(*;7-G<W1R(")3Y&AK]G!O<W1I;W-O:71E(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DV-PIM<V=I9"`B16UA:6P@
M861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM<V=S='(@(E/D:&OV<&]S=&EO<V]I
M='1E:61E;B!P:73DY"!O;&QA('-A;6%T+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Y.3,*;7-G:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N
M(@IM<V=S='(@(E/D:&OV<&]S=&D@=F%R;6ES='5K<V5L;&$B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B
M16UA:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B16UA:6PM=&\M4TU3($=A
M=&5W87DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,CDY"FUS9VED(")%;6]T:6-O;G,B"FUS9W-T<B`B2'EM:?9T(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R
M"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R(")4>6AJY"!V:65S=&DN
M(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(T,R!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HV-C(@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C<P-0HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C$U,`IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R(")4>6AJY"!V87-T
M875S+B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ,3,*
M;7-G:60@(D5M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R(")4>6AJY"!H86MU
M=&5R;6DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-30W"FUS9VED(")%
M;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE
M<R!I;B!T97AT/R(*;7-G<W1R(")386QL:2!K=79I96X@;&%I='1A;6EN96X@
M:W5V86=A;&QE<FEA<W1A('1E:W-T:6X@:F]U:VMO;VXN(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4R,@IM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K
M(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B3&%I=&$@<.3D;&QE(&]I:V5A;B!P
M86EN:6MK965N(&MO;G1E:W-T:6UE;G4N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C4Y,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-SDW"FUS
M9VED(")%;F0@>65A<B(*;7-G<W1R(")0Y.1T='EM:7-V=6]S:2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@
M(D5N;&%R9V4@161I=&]R(@IM<V=S='(@(E-U=7)E;FYA(&5D:71O<FEA(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R-`IM<V=I9"`B(@HB16YT97(@
M82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I
M9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W
M:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*(D%N
M;F$@:WES>6UY<R!J;VMA(&MY<WETY.1N+"!J;W,@<V%L87-A;F%S:2!J;W5D
M=71A86X@;F]L;&%A;6%A;B!E<VEM97)K:6MS:2`B"B(G;6EKY"!O;B!L96UM
M:6MK:7-I(&YI;6D_)SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I
M;6%G92!54DP@:&5R92(*;7-G<W1R("),86ET82!K=79A(%523"!TY&CD;B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX.3(*
M;7-G:60@(D5N=&5R('1H92!L971T97)S(&)E;&]W.B(*;7-G<W1R(")!;FYA
M(&MI<FIA:6UE="!A;&QE.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3D*;7-G:60@(D5Q=6%T;W)I
M86P@1W5I;F5A(@IM<V=S='(@(D5K=F%T;W)I86%L:6YE;B!'=6EN96$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<Y"FUS9VED(")%<FET<F5A(@IM<V=S='(@(D5R:71R96$B"@HC
M.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]S=&%T=7,N<&AP.C(W"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70O5FEE=RYP:'`Z.30@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#@*;7-G:60@(D5R<F]R(@IM<V=S
M='(@(E9I<FAE(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H
M<#HT-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@8W)E871I;F<@8FQO
M8VLZ("5S(@IM<V=S='(@(E9I<FAE('#D:79I=&5T=.1E<W/D(&]S:6]T83H@
M)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B
M"FUS9W-T<B`B5FER:&4@<.1I=FET971TY&5S<^0@<WEN8R!A;F-H;W(@+71I
M971O83H@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@
M)7,B"FUS9W-T<B`B5FER:&4@<&]I<W1E='1A97-S82!S>6YC(&QO:VEA.B`E
M<R(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8X"B,L
M('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B
M"FUS9W-T<B`B5FER:&4@:&%E='1A97-S82!S:7/D;'3VY#H@)7,N(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*
M;7-G:60@(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<R(*;7-G<W1R(")6
M:7)H92!PY&EV:71E='3D97-SY"!S86QA<V%N86$Z("5S(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED
M(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM<V=S='(@(E9I<FAE('/D
M:&OV<&]S=&EV:65S=&ES<^0N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS
M9W-T<B`B5FER:&4@:VER:F]I=&5T=&%E<W-A(%PB)7-<(BXB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C<V"FUS9VED(")%<W1O;FEA(@IM<V=S='(@(D5E<W1I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`B171I;W!I82(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S='(@(D5T
M;FEN96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G
M:60@(D5U<F]P92(*;7-G<W1R(")%=7)O;W!P82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-#,*;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T
M<B`B,34@;6EN=75T:6X@=N1L96EN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,Y,PIM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(C(@;6EN
M=75T:6X@=N1L96EN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,"!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")%=F5R>2`S,"!S96-O
M;F1S(@IM<V=S='(@(C,P('-E:W5N;FEN(';D;&5I;B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-#(@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y-`IM
M<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(C4@;6EN=75T:6X@=N1L
M96EN(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H
M<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T<B`B2F]K86ES96QL82!S
M:7/DY&YK:7)J875T=6UI<V5L;&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S0T"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`B4'5O;&5N
M('1U;FYI;B!VY&QE:6XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3(*;7-G:60@(D5V97)Y(&UI;G5T
M92(*;7-G<W1R(")-:6YU=71I;B!VY&QE:6XB"@HC.B!T96UP;&%T97,O9&%T
M82]D871E;6%P+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V86QU97,Z(@IM<V=S
M='(@(D5S:6UE<FMK:6%R=F]T.B(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HU
M,2!A9&UI;B]P:'!S:&5L;"YP:'`Z.#(@861M:6XO<W%L<VAE;&PN<&AP.C$R
M.`IM<V=I9"`B17AE8W5T92(*;7-G<W1R(")3=6]R:71A(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV,30*;7-G:60@
M(D5X<&%N9"(*;7-G<W1R("),86%J96YN82(*"B,Z('1E;7!L871E<R]P;W)T
M86PO<VED96)A<BYI;F,Z,S(*;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S
M='(@(DQA86IE;FYA('-I=G5V86QI:VMO(@H*(SH@9G)A;65W;W)K+U-13"]3
M44PO2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP96-T960@)RDG(@IM<V=S
M='(@(D]D;W1E='1I:6X@;65R:VMIY"`G*2<B"@HC.B!F<F%M97=O<FLO4U%,
M+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B87)E('=O
M<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@(E-A;F$@<V5L;&%I
M<V5N86%N('1A:2!H86MU=&5R;6D@;&%I;F%U<VUE<FME:7-SY"(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B17AP:7)A
M=&EO;B!$871E(@IM<V=S='(@(DQO<'!U<.1I=N1MY.1RY"(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<W"FUS9VED(")%>'!O;F5N
M="(*;7-G<W1R(")%:W-P;VYE;G1T:2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R
M(@IM<V=S='(@(D9'(';D<FDB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3<W"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(D%S971U
M<W1I961O<W1O:F5N('1U;VYT:2!&5%`Z;&SD(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+W-Q;"YP:'`Z,C(U"FUS9VED(")&86EL960@<F5T<FEE=FEN
M9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`B07-E='5S=&5N(&AA:W4@97#D;VYN
M:7-T=6DN(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<U
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z.3@*;7-G:60@(D9A:6QE
M9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(")9:'1E>7,@
M3$1!4"UP86QV96QI;65E;B!E<.1O;FYI<W1U:2XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W-M8BYP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T
M('1O(%--0B!S97)V97(N(@IM<V=S='(@(EEH=&5Y<R!334(M<&%L=F5L:6UE
M96X@97#D;VYN:7-T=6DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HW,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O
M;2!<(B5S7"(N(@IM<V=S='(@(DMO<&EO:6YT:2!<(B5S7"(Z;'3D(&5PY&]N
M;FES='5I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S(R"B,L
M('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB
M"FUS9W-T<B`B2V]P:6]I;G1I(%PB)7-<(CIL;&4@97#D;VYN:7-T=6DN(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX-PIM<V=I9"`B1F%I
M;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R(")5
M=61E;B!305-,+7EH=&5Y9&5N(&QU;VUI;F5N(&5PY&]N;FES='5I+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4U(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z-3`Q"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T
M;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B4VEI<G1O(%PB)7-<(CKDY&X@
M97#D;VYN:7-T=6DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT
M-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(')E=')I979E.B`E
M<R(*;7-G<W1R(")3:6ER=&\@97#D;VYN:7-T=6DZ("5S(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A:7(B
M"FUS9W-T<B`B2V%U;FES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-`IM<V=I9"`B1F%L:VQA;F0@
M27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@(D9A;&ML86YD:6X@<V%A<F5T
M("A-86QV:6YA<RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@V"FUS9VED(")&87)O92!)<VQA;F1S
M(@IM<V=S='(@(D;D<B!S86%R970B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP
M:'`Z,C,X"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`B5F%K879A('9I
M<FAE.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R(")&86MS:2(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS-3$*;7-G:60@(D9A>&5S(@IM<V=S='(@(D9A
M:W-I="(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8V"FUS9VED(")&96)R=6%R>2(*;7-G<W1R(")H96QM:6MU=2(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C(W"FUS9VED(")&965L<R!,:6ME(@IM<V=S
M='(@(E1U;G1U=2!K=6EN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(R,`IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(E1U;G1U=2!K
M=6EN.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ.0IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B375U=&%M:6$@<V%T
M96ET82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(P"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(DUU=71A;6EA
M(&QU;6ES871E:71A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT
M.`IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(DME;G1TY&UA=')I:7-I
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R.0IM<V=I9"`B1FEG
M;&5T($-!4%1#2$$B"FUS9W-T<B`B1FEG;&5T($-!4%1#2$$B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,S"FUS9VED(")&:6=L970@9F]N="(*
M;7-G<W1R(")&:6=L970@:VER:F%S:6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S"FUS9VED(")&
M:6II(@IM<V=S='(@(D9I9'II(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C4U"FUS9VED(")&:6QE(@IM<V=S='(@(E1I961O<W1O(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R(")4:65D;W-T;VIE;B!L
M=6MU;>3D<N0Z("5S('1I961O<W1O(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C<Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@
M9FEL97,B"FUS9W-T<B`B5&EE9&]S=&]J96X@;'5K=6WDY'+D.B`E<R!T:65D
M;W-T;V$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`Y"FUS9VED
M(")&:6QE($UA;F%G97(B"FUS9W-T<B`B5&EE9&]S=&]J96X@:^1S:71T96QY
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,R!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*;7-G:60@(D9I;&4@
M3F%M92(*;7-G<W1R(")4:65D;W-T;VX@;FEM:2(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Y.#$*;7-G:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S
M='(@(E1I961O<W1O;B!V86QI;G1A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,30Y,`IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`B5&EE9&]S
M=&]N('1U;VYT:2(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP
M.CDP,@IM<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM<V=S
M='(@(E1I961O<W1O:F5N('1U;VYT:2!E:2!O;&4@:^1Y=&5T=.1V:7-SY"XB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3$*;7-G:60@(D9I;'1E
M<G,B"FUS9W-T<B`B4W5O9&%T=&EM970B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@R"FUS9VED(")&
M:6YL86YD(@IM<V=S='(@(E-U;VUI(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C$V-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R(")%;G-I;6WD:6YE;B!P
M=6]L:7-K;R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O0FQO8VLO
M;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U87)T97(B"FUS9W-T<B`B16YS
M:6UMY&EN96X@;F5L:N1N;F5S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(U-PIM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@
M(DMO<FIA82!S=6AD92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,S(*;7-G:60@(D9L:7`B"FUS9W-T<B`B2^3D;F[D('EM
M<.1R:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(DME;&QU=F$B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I
M9"`B1F]G(@IM<V=S='(@(E-U;74B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,3`W(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C,W"B,L
M('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*
M;7-G<W1R(")+86YS:6]T82`E<R!E:2!O;&4@;VQE;6%S<V$N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B
M1F]N="!#;VQO<B(*;7-G<W1R(")+:7)J87-I;65N(';D<FDB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`B4G5O
M:V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$R,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T
M('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@(E-E;&%I;6EL;&4L(&IO=&MA(&5I
M=N1T('1U92!K=79I82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S0Q"FUS
M9VED(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R(")%;FYU<W1E("A4048I(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<R"FUS9VED("(B"B)&
M;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T
M(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E
M<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@
M(B(*(D5N;G5S=&5T=&%V870@=G5O<F]K875D970@*$AU;VUA871H86X@971T
MY"!E;FYU<W1U:W-E<W-A(&]N('1I961O="!S96OD("(*(G#D:79I<W3D(&5T
M=.0@]FES=.0L(&IO=&5N('-U=7)I(&WDY'+D('#D:79IY"!A:6AE=71T86$@
M;&EI86X@;&5V9>1N(&]S:6]N*2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,3`R"FUS9VED(")&;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T
M<B`B56YO:&1I=&MO('-A;&%S86YA<VD_(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0V-`IM<V=I9"`B1F]R;7,B"FUS9W-T<B`B3&]M86MK965T
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"FUS9VED(")&;W)T=6YE
M(@IM<V=S='(@(DUI971E;&%U<V4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R(")-:65T96QA=7-E
M96X@='EY<'!I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,X"FUS9VED
M(")&;W)T=6YE<R(*;7-G<W1R(")-:65T96QA=7-E970B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B
M36EE=&5L875S965T(#(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#4U"FUS9VED(")&;W)U;7,B"FUS9W-T<B`B1F]O<G5M:70B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3$Q"FUS9VED(")&;W)W87)D<R(*;7-G
M<W1R(")5=61E;&QE96YO:&IA=6MS970B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R(")P
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S,*;7-G:60@(D9R86UE<R(*;7-G<W1R(")+96AY:W-E="(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#<*;7-G:60@(D9R86YC92(*;7-G<W1R(")286YS:V$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@
M365T<F]P;VQI=&%N(@IM<V=S='(@(E)A;G-K82P@365T<F]P;VQI(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY,0IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R(")286YS:V%N
M($=U>6%N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@T"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA
M(@IM<V=S='(@(E)A;G-K86X@4&]L>6YE<VEA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(R"FUS
M9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B4F%N
M<VMA;B!E=&5LY&ES970@=&5R<FET;W)I;W0B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S
M='(@(DSD:&5T=.1JY"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,S<@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,T.0HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDU"FUS9VED(")&<F]M('1H92`B
M"FUS9W-T<B`B4W5U;FYA<W1A("(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C0X"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@
M(E!I9&5M<&D@:W5V875S.B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB"FUS9W-T
M<B`B5.1Y<VEK=74B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C$@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV,`IM<V=I9"`B1G5L;"!.
M86UE(@IM<V=S='(@(DMO:V\@;FEM:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#@*;7-G:60@(D=A
M8F]N(@IM<V=S='(@(D=A8F]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL97)Y
M('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R(")'86QL97)I82P@:F]S=&$@
M:W5V82!O=&5T86%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G
M<W1R(")'86QL97)I83HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDV"FUS9VED(")'86UB:6$B"FUS
M9W-T<B`B1V%M8FEA(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N
M(@IM<V=S='(@(E1E92`E<R!A<V5T=6MS970B"@HC.B!T96UP;&%T97,O861M
M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I9"`B1V5N97)A=&5D($-O9&4B
M"FUS9W-T<B`B1V5N97)O:71U(&MO;V1I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,`IM<V=I9"`B
M1V5O<F=I82(*;7-G<W1R(")'96]R9VEA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV.0IM<V=I9"`B
M1V5R;6%N>2(*;7-G<W1R(")386MS82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3,*;7-G:60@(D=H
M86YA(@IM<V=S='(@(D=H86YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-`IM<V=I9"`B1VEB<F%L
M=&%R(@IM<V=S='(@(D=I8G)A;'1A<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3<V"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@
M(D5T=6YI;6DB"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<U
M('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$P"B,Z('1E;7!L871E<R]P<F5F
M<R]A<'`N:6YC.C$Y"FUS9VED(")';&]B86P@3W!T:6]N<R(*;7-G<W1R(")9
M;&5I<V5T(&%S971U:W-E="(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC
M.C$W"FUS9VED(")';R(*;7-G<W1R(")-96YE(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0P"FUS9VED(")';V5D96PB"FUS9W-T<B`B1_9D96PB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$S,0IM
M<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B1V]O9VQE($MA<G1A="(*"B,Z
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R
M8V@B"FUS9W-T<B`B1V]O9VQE(&AA:W4B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,X"FUS9VED(")'<F%Y<V-A;&4B"FUS
M9W-T<B`B2&%R;6%A<^1V>2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P"FUS9VED(")'<F5E8V4B
M"FUS9W-T<B`B2W)E:6MK82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X
M"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B2W)E:6MK82`H
M25-/+3@X-3DM-RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDU"FUS9VED(")'<F5E;FQA;F0B"FUS
M9W-T<B`B1W+V;FQA;G1I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.0IM<V=I9"`B1W)E;F%D82(*
M;7-G<W1R(")'<F5N861A(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-SD*;7-G
M:60@(D=R;W5P($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E)Y:&WD;B!Y;&SD
M<&ET;R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"YP:'`Z-3D@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$V.0IM<V=I9"`B1W)O=7`@;F%M
M97,@;75S="!B92!N;VXM96UP='DB"FUS9W-T<B`B4GEH;6EE;B!N:6UE="!E
M:7;D="!S86$@;VQL82!T>6AJ:>0B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,S`W"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD
M87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60Z("(*;7-G<W1R("(B"B)'<F]U<%]L9&%P.B!%:2!V;VED
M82!L:7/D=.0@:^1Y='3D:N3D("5S+B!086QV96QI;65N('9I<FAE:6QM;VET
M=7,@;VQI.B`B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M,3$X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,C0*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S
M(@IM<V=S='(@(D=R;W5P7VQD87`Z($5I('9O:61A('#D:7;D='3DY"!KY'ET
M=.1JY.0@)7,B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M,S,X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G
M<F]U<"`E<R(*;7-G<W1R(")'<F]U<%]L9&%P.B!%:2!V;VED82!PY&EVY'1T
MY.0@:^1Y='3D:N3D("5S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HS,30@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R(")2
M>6AMY'0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDX"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@
M(D=U861E;&]U<&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,PIM<V=I9"`B1W5A;2(*;7-G<W1R
M(")'=6%M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#(*;7-G:60@(D=U871E;6%L82(*;7-G<W1R
M(")'=6%T96UA;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDR
M"FUS9VED(")'=65R;G-E>2(*;7-G<W1R(")'=65R;G-E>2(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,C(V('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z.#@*;7-G:60@(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@
M(E9I97)A:6QI:F%N(&]I:V5U9&5T(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0W,@IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(E9I97)A<VMI
M<FIA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY-PIM<V=I9"`B1W5I;F5A(@IM<V=S='(@(D=U:6YE
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P-`IM<V=I9"`B1W5I;F5A+4)I<W-A=2(*;7-G<W1R
M(")'=6EN96$M0FES<V%U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`U"FUS9VED(")'=7EA;F$B
M"FUS9W-T<B`B1W5Y86YA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.38T"FUS9VED(")(5$U,(@IM<V=S='(@(DA434PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C
M96QL(&EN(')O=RXB"FUS9W-T<B`B2%1-3$%R96$@<&5L:W5R:6UA:7-E<W1I
M(&MI96QTY'ET>7D@<&]I<W1A;6%S=&$@<FEV:6X@=FEI;65I<W3D('-O;'5A
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@
M9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB"FUS9W-T<B`B(@HB
M2%1-3$%R96$@<&5L:W5R:6UA:7-E<W1I(&MI96QTY'ET>7D@<&]I<W1A;6%S
M=&$@=FEI;65I<W3D('-A<F%K971T82`B"B)T875L=6MO<W1A+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*
M;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H
M92!L87-T(')O=R!I;B!T86)L92XB"FUS9W-T<B`B(@HB2%1-3$%R96$@<&5L
M:W5R:6UA:7-E<W1I(&MI96QTY'ET>7D@<&]I<W1A;6%S=&$@=FEI;65I<W3D
M(')I=FGD('1A=6QU:V]S=&$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H
M='1P+G!H<#HQ-3<*;7-G:60@(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R(")(5%10+6%U=&5N=&EK;VEN=&EA(&5I(&SV>71Y;GET
M+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q,`IM<V=I9"`B2&%I=&DB"FUS9W-T<B`B2&%I=&DB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@
M(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(DAA<V@M86QG;W)I=&UI(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@
M(DAA>F4B"FUS9W-T<B`B57-V82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.CDR,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3$X"FUS9VED(")(
M96%D97(B"FUS9W-T<B`B3W1S86ME(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R
M(")/='-A:V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#<*;7-G:60@(DAE87)D($ES;&%N9"!A
M;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R(")(96%R9"!J82!-8T1O;F%L
M9"!S86%R970B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HR,PIM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R(")6;VEM86MA
M<R!U:VMO<VUY<G-K>2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS
M9VED(")(96)R97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`B2&5P<F5A("A)
M4T\M.#@U.2TX+4DI(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C(@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM
M<V=I9"`B2&5I9VAT(@IM<V=S='(@(DMO<FME=7,B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3@T(&9R86UE=V]R:R](;W)D92](;W)D
M92](96QP+G!H<#HQ.#8*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@
M=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C0*;7-G:60@(DAE;'`B"FUS9W-T
M<B`B3VAJ92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(D%P
M=6$@961I=&]R:6X@:^1Y='3V]FXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,S<U"FUS9VED(")(96QP97(B"FUS9W-T<B`B3VAJ92(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R
M(")086QL;VYP=6]L:7-K;SHB"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHQ,"!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,`IM<V=I9"`B
M2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R(")4
MY'-SY"!O;B!T:65D;W-T;VX@86QK=6]S83HB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B2&EG:"(*;7-G<W1R
M(")+;W)K96$B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@=&5M
M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C4*;7-G:60@(DAO7VUE
M(@IM<V=S='(@(DMO7W1I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,PIM<V=I9"`B2&]L>2!3
M964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`B4'EHY"!I<W1U:6X@
M*%9A=&EK86%N:6X@:V%U<'5N:VEV86QT:6\I(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ-30Q"FUS9VED(")(;VUE(@IM<V=S='(@(DMO=&DB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-34*
M;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R(")+;W1I;W-O:71E(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8T"FUS9VED(")(;VUE($1I<F5C=&]R
M>2(*;7-G<W1R(")+;W1I:&%K96UI<W1O(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N92(*
M;7-G<W1R(")0=6AE;&EN("AK;W1I*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.`IM<V=I9"`B
M2&]N9'5R87,B"FUS9W-T<B`B2&]N9'5R87,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#8*;7-G
M:60@(DAO;F<@2V]N9R(*;7-G<W1R(")(;VYG($MO;F<B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-C<*;7-G:60@(DAO<F1E(@IM<V=S='(@(DAO
M<F1E(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A
M=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+
M;VQA8CH@17#D:V5L<&]A("5S(%A-3"UD871A82!V:65S=&ES<^0@)7,B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T
M;R!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(%EK<VEKY.1N('9I
M97-T:2!E:2!V87-T86$@;V)J96MT:6$@)7,B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C0T-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E
M<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@66ATY&ODY&X@;V)J96MT:6$@)7,@
M96D@;/9Y='EN>70@=FEE<W1I<W3D("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HQ,C4Q"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T<B`B
M2&]R9&4O2V]L86(Z(%!O:7-T971T:6EN("5S(%PB)7-<(B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D92]+;VQA8CH@
M5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@
M4$A0(&5X=&5N<VEO;B(*;7-G<W1R("(B"B)(;W)D92]+;VQA8CH@26YT96=R
M86%T:6]K;VYE('9A871I:2!T;VEM:6%K<V5E;B`G9&]M>&UL)R!02%`M;&%A
M:F5N;G5K<V5N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HU,3(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C
M<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R
M9&4O2V]L86(Z($5I('9O:61A(&QU;V1A('5U='1A(%A-3"UP=75T82!O8FIE
M:W1I;&QE("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0X
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($5I
M('9O:71U('!O:7-T86$@)7,@7"(E<UPB.B`E<R(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z-#@S"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A
M<G0@;V8@='EP92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@16D@=F]I9&$@
M:&%K96$@34E-12!)1#KD(&]S:6]L;&4@='EY<'!IY"`E<R(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$Y-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<
M(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($5I('9O:2!S>6MR;VYO:61A
M("5S(%PB)7-<(CH@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C$S,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@(DAO<F1E+TMO
M;&%B.B!%:2!V;VED82!S>6YK<F]N;VED82!J86MO:F$Z("5S(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@
M(DAO<F1E+TMO;&%B.B!4=6YT96UA=&]N(&IA:V\@7"(E<UPB(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B
M2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(E9A86MA<W5O<F$@<^3D;G3V(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM
M<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(E9A86MA<W5O<F$@
M=.1Y=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R(")686%K87-U;W)A
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A
M<V4@<F5P;W)T(2DB"FUS9W-T<B`B36ET96X@='5L:70@=.1N;F4_("A287!O
M<G1O:2!K:6ET;W,A*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@
M=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(DMU:6YK82!M;VYT
M82!S87)A:V5T=&$@:&%L=6%T('EH9&ES=.3D/R(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O
M;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`B2V5N='1I96X@*'-A<F%K:V5I
M9&5N*2!L=6MU;>3D<N0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W
M;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B2W5I;FMA(&UO;G1A
M(')I=FGD(&AA;'5A="!Y:&1I<W3DY#\B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(S-R!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Y"FUS9VED
M(")(=6UI9&ET>2(*;7-G<W1R(")+;W-T975S(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(T.`IM<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R
M(")+;W-T975S.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G
M:60@(DAU;6]R:7-T<R(*;7-G<W1R(")(=6UO<FES=&ET(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$Q"FUS9VED(")(=6YG87)Y(@IM<V=S='(@(E5N:V%R:2(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O
M075T:"]C>7)U<RYP:'`Z,3<R"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@
M;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(DE-05`M<&]S
M=&EL86%T:6MO;B!L=6]N=&D@97#D;VYN:7-T=6DZ("5S(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y-2!F<F%M97=O<FLO075T:"]!
M=71H+V-Y<G5S+G!H<#HR,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M
M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B24U!4"UP;W-T
M:6QA871I:V]N('!O:7-T;R!E<.1O;FYI<W1U:3H@)7,B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C0R(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER=7,N<&AP.C$W.0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA
M:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("))34%0
M+7!O<W1I;&%A=&EK;VX@:VEI;G1I]FX@;'5O;G1I(&5PY&]N;FES='5I.B`E
M<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,C`*;7-G:60@(DE0
M($%D9')E<W,B"FUS9W-T<B`B25`M;W-O:71E(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B25`@061D<F5S<R!N;W0@
M879A:6QA8FQE+B(*;7-G<W1R("))4"UO<V]I=&4@96D@;VQE(&OD>71E='3D
M=FES<^0N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HX
M.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B
M;&]C:RXB"FUS9W-T<B`B25`M;W-O:71E(&5I(&]L92!S86QL:71U;B!#2412
M+6)L;VMI;B!S:7/D;&SD(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W;B!V:6]L
M871I;VXN(@IM<V=S='(@(DE0+7/DY&YN]G-T]FX@<FEK:V]M=7,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,CD*;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R("),7V%I=&$@
M<FEV:2!E;FYE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,`IM<V=I9"`B26-E;&%N9"(*;7-G
M<W1R("))<VQA;G1I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,`IM
M<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R(")686EN(&EK;VYI="(*"B,Z('5T
M:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("))
M8V]N<R!F;W(@)7,B"FUS9W-T<B`B26MO;FET("5S.FQL92(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.#$*;7-G:60@(DEC;VYS('=I=&@@=&5X="(*
M;7-G<W1R(")):V]N:70@:F$@=&5K<W1I(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Y,PIM<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R(")0
M<F]F:6EL:6X@;FEM:3HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HU.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T
M(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@
M=VEN9&]W+B(*;7-G<W1R(")*;W,@<VEV=2!E:2!NY'D@:W5N;F]L;&$L(&YI
M:6X@875K86ES92`E<R!E<FEL;&ES97-SY"!I:VMU;F%S<V$N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0U.0IM<V=I9"`B(@HB268@>6]U(&1O;B=T
M('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M
M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@
M=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"B)*;W,@970@;N1E(&EK;VYE:71A
M(&OD>71TY&5S<^1S:2!);G1E<FYE="!%>'!L;W)E<B!S96QA:6YT82P@;FEI
M;B!S:6YU;B`B"B)P:73DY"!O='1A82!P;VES('#DY&QTY"!03D<@;.1P:6[D
M:WEV>7ES(')A<W1I='1A;6%L;&$@=.1MY"!L86%T:6MK;RXB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3<R"FUS9VED("(B
M"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I
M;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA>65D
M(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@HB2F]S(&[D970@=.1MY&X@
M=FEE<W1I;BP@;75T=&$@970@:W5V86$L(&YI:6X@='5O;6%A<VD@:W5V86$@
M96D@=F]I(&[D>71TY.0@(@HB:^1Y='3D;>1S<^1S:2!S96QA:6UE<W-A+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR.`IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B2W5V
M:65N(&5S:6MA='-E;'4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,W"FUS9VED("));6%G92!54DPB"FUS9W-T
M<B`B2W5V82!54DPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM86=E(%523#HB"FUS
M9W-T<B`B2W5V82!54DPZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M
M(&=A;&QE<GDB"FUS9W-T<B`B2W5V82!G86QL97)I87-T82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS
M,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R(")+=79A(&=A
M;&QE<FEA<W1A.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C4*
M;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R(")+=79A;B!V:65N=&DB"@HC
M.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S
M='(@(DMU=F%T(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-"!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW"B,Z('1E;7!L871E<R]D871A
M+V1A=&5M87`N:6YC.C<@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z-PHC
M+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`B
M5'5O;G1I+"!A<VME;"`E9"(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N
M:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E
M<R(*;7-G<W1R(")4=6]T=2!K96YT=.0Z("5S(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G
M<W1R(")4=6]D=70@:V5N=.1T.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2
M;W<@069T97(B"FUS9W-T<B`B3&%?:71A(')I=FD@:N1L:V5E;B(*"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S-`IM<V=I9"`B
M26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R(")6Y.1RY"!T
M;VEM:6YT;VMO;V1I(&%N;F5T='4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*;7-G:60@(DEN8V]R<F5C="!U
M<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(DOD>71TY&KD='5N
M;G5S('1A:2!S86QA<V%N82!O;B!VY.1R:6XN(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M
M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@
M>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L
M<"XB"FUS9W-T<B`B(@HB5N3D<N0@:^1Y='3D:N1T=6YN=7,@=&%I('9A:6AT
M;V5H=&]I;F5N(&]S;VET92X@67)I=.0@=75D97-T86%N(&IA(&]T82`B"B)Y
M:'1E>71TY"!Y;&SD<&ET;V]N(&IO<R!T87)V:71S970@;&ESY.0@87!U82XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q
M"FUS9VED("));F-R96%S92!);F1E;G0B"FUS9W-T<B`B3&ESY.0@<VES96YN
M>7-TY"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q-@IM<V=I9"`B26YD:6$B"FUS9W-T<B`B26YT
M:6$B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U-"!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5
M<V5R<R(*;7-G<W1R(")9:W-I='3D:7-E="!KY'ET=.1JY'0B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,3(*;7-G:60@(DEN9&]N97-I82(*;7-G<W1R("));F1O;F5S:6$B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS
M9VED("));F9O(@IM<V=S='(@(DEN9F\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C4Y"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R("));F9O
M<FUA871I;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3D*
M;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S
M='(@(E1I971O82!E:2!O;&4@96[DY"!S86%T879I;&QA+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM
M<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B"FUS9W-T<B`B3&%I=&$@<U]A
M<F%K92!JY&QK965N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS9VED("));G-E<G0@26UA9V4B
M"FUS9W-T<B`B3&%I=&$@:W5V82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G
M<W1R("),86ET82!T875L=6MK;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@(DEN<V5R="!796(@3&EN:R(*
M;7-G<W1R("),86ET82!W=W<M;&EN:VMI(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED("));G-E
M<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B3&%I=&$@7W-A<F%K92!E;FYE
M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T
M:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B3&%I=&$@=75S:2!S87)A:V4@;GEK
M>6ES96X@:N1L:V5E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O
M;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DQA:71A('5U
M<VD@<V%R86ME(&5N;F5N(&YY:WEI<W3D(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R"FUS9VED("));G-E
M<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("),
M86ET82!U=7-I(')I=FD@;GEK>6ES96X@:N1L:V5E;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I
M9"`B26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM
M<V=S='(@(DQA:71A('5U<VD@<FEV:2!E;FYE;B!N>6MY:7-TY"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW
M,`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT
M(&YO9&4B"FUS9W-T<B`B3&%I=&$@:V%P<&%L92!N>6MY:7-E;B!N;V1E;B!J
MY&QK965N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F
M;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B3&%I=&$@:V%P<&%L92!E
M;FYE;B!N>6MY:7-TY"!N;V1E82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M,34P"FUS9VED("));G-E<G0@86QT97)N871E('1E;7!L871E(@IM<V=S='(@
M(DQA:71A('9A:6AT;V5H=&]I;F5N(&UA;&QI(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(T,@IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@
M=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM
M<V=S='(@(D%N;F$@<^1H:_9P;W-T:6]S;VET92!J;VAO;B!U=7-I('-A;&%S
M86YA(&SD:&5T973DY&XZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`IM<V=I9"`B26YS97)T(&-E;&P@869T
M97(B"FUS9W-T<B`B3&%I=&$@<V]L=2!JY&QK965N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0IM<V=I9"`B
M26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(DQA:71A('-O;'4@96YN96XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8T"FUS9VED("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@(DQA
M:71A('-O;'4@:N1L:V5E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C;VQU;6X@
M8F5F;W)E(@IM<V=S='(@(DQA:71A('-A<F%K92!E;FYE;B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4P"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED("));G-E<G0@
M;65S<V%G97,B"FUS9W-T<B`B5F]I(&QA:71T86$@=FEE<W1E:N0B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-#4*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`B3&%I
M=&$@:V%P<&%L92!JY&QK965N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED("));G-E<G0@<&%R
M86=R87!H(&)E9F]R92(*;7-G<W1R("),86ET82!K87!P86QE(&5N;F5N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV.0IM<V=I9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R("),86ET82!R
M:79I(&5N;F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS
M9W-T<B`B3&%I=&$@<FEV:2!JY&QK965N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(S,PIM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@
M=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R(")!;FYA('9A861I
M='1A=F$@=F%S=&%U<R!T=7)V86MY<WEM>6MS965N.B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN<V5R
M="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B3&EI=.0O375O:VMA82!K=79I82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#D*
M;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*;7-G<W1R("),:6ETY"]-=6]K
M:V%A(&QI;FMK:>0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B26YS=69F:6-I96YT(&-R961I="!T
M;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@HB
M4VEN=6QL82!E:2!O;&4@=&%R<&5E:W-I(&MR961I:71T96KD(&SD:&5T=.3D
M:W-E<VD@=FEE<W1I;B!J86ME;'5L:7-T86QL92XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS
M=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`B4FEI='3D;>1T=/9MY'-T:2!K
M<F5D:6ET=&5JY"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-SD*
M;7-G:60@(DEN=&5G97(B"FUS9W-T<B`B2V]K;VYA:7-L=6MU(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$S-PIM<V=I9"`B26YT96=E<B!L:7-T
M(@IM<V=S='(@(DMO:V]N86ES;'5K=6QI<W1A(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("));G9A
M;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R(")%<.1K96QP
M;R`@541(("A5<V5R($1A=&$@2&5A9&5R*2XB"@HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ-C<*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+WII<"YP:'`Z,3DT"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]Z:7`N<&AP.C(Q,@IM<V=I9"`B26YV86QI9"!:25`@9&%T
M82(*;7-G<W1R(")%<.1K96QP;V$@6DE0+71I971O82XB"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N
M+B(*;7-G<W1R(")%<.1K96QP;R!O:&IE;&UA+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV
M86QI9"!B871C:"!)1"XB"FUS9W-T<B`B17#D:V5L<&\@8F%T8V@@240N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`Y,2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,38R"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R
M,S8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,P,PHC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED
M(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R("),Y&AE=&5T=&EI;B!E<.1K96QP
M;V$@=&EE=&]A+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P,`IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO;B!A
M9&1R97-S+B(*;7-G<W1R(")%<.1K96QP;R!V87-T86%N;W1T86IA;B!O<V]I
M=&4N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z
M,3`Y"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$S
M.0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR-#$*
M;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B17#D:V5L<&\@
M=&EE9&]S=&]M=6]T;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-C4*;7-G:60@(DEN=F%L:60@;&EC96YS92!K97DN(@IM<V=S='(@(D5P
MY&ME;'!O(&QI<V5N<W-I879A:6XN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$U.0IM<V=I9"`B26YV86QI9"!L;V-A=&EO;B!P<F]V:61E
M9"XB"FUS9W-T<B`B17#D:V5L<&\@<&%I:VMA=&EE=&\N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED
M("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R(")%<.1K96QP;R!M<V=?='EP
M92`N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`S"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*
M;7-G<W1R(")%<.1K96QP;R!T86D@<'5U='1U=F$@87!I7VED+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-@IM
M<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@
M(D5PY&ME;'!O('1A:2!P=75T='5V82!P87)A;65T<FDN(@H*(SH@861M:6XO
M<&5R;7,O861D8VAI;&0N<&AP.C(W"FUS9VED("));G9A;&ED('!A<F5N="!P
M97)M:7-S:6]N+B(*;7-G<W1R(")%<.1K96QV;W0@;VEK975D970@>6QE;6WD
M;&SD('1A<V]L;&$N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$V,0IM<V=I9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R(")%<.1K
M96QP;R!P87)N97(@:60N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$V,PIM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O9&4N(@IM<V=S='(@
M(D5PY&ME;'!O('1U;W1E:V]O9&DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED("));G9A;&ED('!R
M;W1O8V]L+B(*;7-G<W1R(")%<.1K96QP;R!P<F]T;VMO;&QA+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HW,2!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C@P"B,L('!H<"UF;W)M870*
M;7-G:60@(DEN=F%L:60@<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`B17#D
M:V5L<&\@=F%S=&%A;F]T=&%J83H@7"(E<UPB(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HQ,#@P(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,3(V,PIM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B17#D
M:V5L<&\@:F%K;RUO8FIE:W1I(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"FUS9VED("));G9A;&ED('-O=7)C
M92!A9&1R97-S+B(*;7-G<W1R(")%<.1K96QP;R!LY&AD96]S;VET92XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R(")%<.1K
M96QP;V$@=6YI8V]D92UT:65T;V$N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,U.0IM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@(DEN=F5N=&%A
M<FEO(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C8W.`IM<V=I9"`B26YV97)T('-E;&5C=&EO;B(*;7-G<W1R(")+Y.1N;N0@
M=F%L:6YT82!KY.1N=&5I<V5K<VDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3D*;7-G:60@(DER
M86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B27)A;BP@27-L86UI
M;&%I;F5N('1A<V%V86QT82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q.`IM<V=I9"`B27)A<2(*
M;7-G<W1R("))<F%K(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$S"FUS9VED("))<F5L86YD(@IM
M<V=S='(@(DER;&%N=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B36%N+7-A87)I(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G
M:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM<V=S='(@(D5R:6QL:7-IY"!5:VMO
M<VUY<G-K>6KD(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$T"FUS9VED("))<W)A96PB"FUS9W-T
M<B`B27-R865L(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV,C8*;7-G:60@(DES<W5E<B(*;7-G<W1R("),:6EK:V5E;&QE;&%S:VEJ
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(DMU<G-I=F]I='4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C$*;7-G:60@(DET86QY(@IM<V=S='(@(DET86QI82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$R,PIM<V=I9"`B2F%M86EC82(*;7-G<W1R(")*86UA:6MA(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA
M;G5A<GDB"FUS9W-T<B`B=&%M;6EK=74B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C4*;7-G:60@
M(DIA<&%N(@IM<V=S='(@(DIA<&%N:2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3DP"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@
M(DIA<&%N:2`H25-/+3(P,C(M2E`I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R(")*97)S97DB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,C0*;7-G:60@(DIO<F1A;B(*;7-G<W1R(")*;W)D86YI82(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#@*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS
M9VED(")*=6QY(@IM<V=S='(@(FAE:6[D:W5U(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T
M<B`B:V5SY&MU=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`B2V5S
M:VETY"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R(")+
M97-K:73D(&ME<VME;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*;7-G:60@(DIU<W1I9GD@1G5L;"(*
M;7-G<W1R(")+97-K:73D('3D>7-I;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"FUS9VED(")*=7-T:69Y
M($QE9G0B"FUS9W-T<B`B2V5S:VETY"!V87-E;6UA;&QE(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*;7-G
M:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`B2V5S:VETY"!O:6ME86QL92(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R(")+87IA
M:W-T86XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C8U"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G<W1R(")3Y&EL>73D
M(&%L:W5P97+D:6YE;C\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C8*;7-G:60@(DME;GEA(@IM
M<V=S='(@(DME;FEA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H
M<#HX-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R(")!=71E;G1I:V]I;G1I(&5PY&]N;FES='5I($ME
M<F)E<F]S+7!A;'9E;&EM96QL92XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B:65S(@IM<V=S='(@(DME<FYE;"!A
M;&]I='1E;&EJ870B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO;B(*;7-G<W1R(")!=F%I;65N(&QU
M;VYT:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q-`IM
M<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(D%V86EM96X@='5N;FES
M=&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G
M:60@(DME>2!,96YG=&@B"FUS9W-T<B`B079A:6UE;B!P:71U=7,B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!4
M>7!E(@IM<V=S='(@(D%V86EM96X@='EY<'!I(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3D*;7-G:60@(DME>2!5<V%G92(*;7-G
M<W1R(")!=F%I;65N(&OD>71T]B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")!=F%I;B!O;B!J;R!J=6QK
M:7-T96X@879A:6YT96X@<&%L=F5L:6UE;&QA(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S='(@(DQA<'-E="(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R.0IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B2VER:6)A=&DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S(*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L
M92=S(%)E<'5B;&EC(&]F(@IM<V=S='(@(DMO<F5A+"!D96UO:W)A871T:6YE
M;B!K86YS86YT87-A=F%L=&$@*%!O:&IO:7,M2V]R96$I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,S"FUS9VED(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B2V]R96$L
M('1A<V%V86QT82`H171E;.0M2V]R96$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.3$*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R(")+;W)E
M82`H155#+4M2*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-`IM<V=I9"`B2W5W86ET(@IM<V=S
M='(@(DMU=V%I="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-PIM<V=I9"`B2WER9WEZ<W1A;B(*
M;7-G<W1R(")+:7)G:7-T86XB"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N
M:6YC.C@*;7-G:60@(DQA7WEO=70B"FUS9W-T<B`B07-?971T96QU(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B
M"FUS9W-T<B`B2VEE;&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S<*;7-G:60@(DQA;R!096]P
M;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(DQA;W,L(&1E;6]K
M<F%A='1I;F5N(&MA;G-A;G1A<V%V86QT82(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ-CD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R(")*Y&QK:6UMY&EN
M96X@<'5O;&ES:V\B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S8*;7-G
M:60@(DQA<W0@4&%S<W=O<F0@0VAA;F=E(@IM<V=S='(@(D5D96QL:6YE;B!S
M86QA<V%N86YV86EH=&\B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB
M+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED("),87-T(%%U87)T97(B"FUS9W-T
M<B`B2N1L:VEM;>1I;F5N(&YE;&KD;FYE<R(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,34X"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(E#D:79I
M=&5T='D@=FEI;65K<VDZ(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M-S$W"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S
M='(@(D5D96QL:6YE;B!S:7/DY&YK:7)J875T=6UI;F5N.B`E<R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(D5D96QL:6YE;B!S
M:7/DY&YK:7)J875T=6UI;F5N.B`E<RP@)7,B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HW,30*;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S
M='(@(D5D96QL:6YE;B!S:7/DY&YK:7)J875T=6UI;F5N.B!%:2!M:6QL;VEN
M:V%A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T-@IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(DQA
M='9I82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W
M(@IM<V=S='(@(DQA:VDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,SD*;7-G:60@(DQA>6]U="(*;7-G<W1R(")!
M<V5T=&5L=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS
M9W-T<B`B2N1TY"!T>6AJY&MS:2!J;W,@96D@<F5U;F]J82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S.`IM<V=I9"`B3&5B86YO;B(*;7-G<W1R("),:6)A;F]N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0P"FUS
M9VED("),969T(@IM<V=S='(@(E9A<V5N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$P-0IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B5F%S
M96X@;W1S86ME(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P,0IM
M<V=I9"`B3&5F="!V86QU97,B"FUS9W-T<B`B5F%S96X@87)V;W0B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#,*;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`B3&5S;W1O(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED("),979E;"(*
M;7-G<W1R(")487-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30R"FUS9VED("),:6)E<FEA(@IM
M<V=S='(@(DQI8F5R:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#<*;7-G:60@(DQI8GEA;B!!
M<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B3&EB>6$@07)A8B!*86UA:&ER:7EA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,30P"FUS9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@
M(DQI8VAT96YS=&%I;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(U"FUS9VED("),:6=H="!$<FEZ>FQE(@IM<V=S='(@(DME
M=GET=.0@<N1N=.3D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C8*;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`B2VER:F%U
M9'4@<VESY.1N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B2V5V
M>71TY"!S861E='1A(&%I:V%I<VEN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*
M;7-G<W1R(")+979Y='3D('-A9&5T=&$@;7GV:&5M;6EN(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI9VAT
M(%)A:6X@4VAO=V5R(@IM<V=S='(@(DME=GEI=.0@<V%D96MU=7)O:F$B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I
M9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B2V5V>71TY"!S
M861E='1A(&IA(&UY<G-K>6ES=.0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R
M(")+979Y='3D(&QU;6ES861E='1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R
M(@IM<V=S='(@(DME=GEI=.0@;'5M:6MU=7)O:F$B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(DQI;65R
M:6MI="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,3@*;7-G:60@
M(DQI;FLB"FUS9W-T<B`B3&EN:VMI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O
M:6YT<R!T;SHB"FUS9W-T<B`B3&EN:VMI(&]S;VET=&%A.B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X-SD*;7-G:60@(DQI;FL@=&AE(&5M86EL
M(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B
M"FUS9W-T<B`B3&EN:VETY"!SY&AK]G!O<W1I;W-O:71E(&MI<FIO:71A('5U
M<VD@=FEE<W1I('-I=G5L;&4@;N1K>6WD<W/D(@H*(SH@9G)A;65W;W)K+U1E
M>'1?1FEL=&5R+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,@IM<V=I9"`B3&EN
M:W,B"FUS9W-T<B`B3&EN:VET(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0V"FUS9VED("),:6YU>"!#;V]K:64B"FUS9W-T<B`B3&EN=7@@<&EP87)E
M:71A(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z
M-#8*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*
M;7-G:60@(DQI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R
M(")6;VD@;&ES=&%U:W-E<W-A(&[D:&3D(&MA;G-I;VXB"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3,T"FUS9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R
M(").Y'ETY"!T:65T;VMA;FYA="(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N
M<&AP.C4Q"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(D[D>73D
M(&]H:F5I9&5N(&%I:&5E="(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*
M;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(D[D>73D('1A=6QU="(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DT"FUS9VED("),
M:7-T+4%R8VAI=F4B"FUS9W-T<B`B3&ES=&%N+4%R:VES=&\B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4X.0IM<V=I9"`B3&ES="U(
M96QP(@IM<V=S='(@(DQI<W1A;BU/:&IE(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12](96%D97)S+G!H<#HU.38*;7-G:60@(DQI<W0M260B"FUS9W-T<B`B
M3&ES=&%N+4ED(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H
M<#HU.3(*;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T<B`B3&ES=&%N+4]M:7-T
M86IA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3,*
M;7-G:60@(DQI<W0M4&]S="(*;7-G<W1R("),:7-T82UV:65S=&DB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,0IM<V=I9"`B3&ES
M="U3=6)S8W)I8F4B"FUS9W-T<B`B3&ES=&%N+51I;&%U<R(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DP"FUS9VED("),:7-T+55N
M<W5B<V-R:6)E(@IM<V=S='(@(DQI<W1A;BU4:6QA=6MS96XM;&]P971T86UI
M;F5N(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4R"B,L('!H<"UF;W)M870*
M;7-G:60@(DQI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R("))
M<W1U;G1O:F5N(&QI<W1A=7,@97#D;VYN:7-T=6DZ("5S(@H*(SH@861M:6XO
M<V5S<VEO;G,N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@
M=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R(")+Y'ET=.1J:65N(&QI<W1A=7,@
M97#D;VYN:7-T=6DZ("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L
M:7-T+FEN8SHR"FUS9VED("),:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*
M;7-G<W1R(")+Y'ET=.1JY'1I971O:F5N(&[D>71TY&UI;F5N(&]N(&5S=&5T
M='DN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),:71E
M<F%T=7)E(@IM<V=S='(@(DMI<FIA;&QI<W5U<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-`IM
M<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(DQI971T=6$B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I;6%G97,N<&AP.C<W"FUS9VED("),;V%D
M:6YG+BXN(@IM<V=S='(@(DQA9&%T86%N+BXN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(P,`IM<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S
M='(@(E!A:6MA;&QI<W1A(&%I:V%A.B`B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.#8*;7-G:60@(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R("),;VMA
M;&ES86%T:6\@:F$@86EK82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3<R(&QI8B]";&]C:R]M971A<BYP:'`Z-S(*(SH@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HU-PIM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B4&%I:VMA(@H*(SH@;&]G
M:6XN<&AP.C$X.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C`P('1E
M;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C,*(SH@=&5M<&QA=&5S+VQO9VEN
M+VUO8FEL92YI;F,Z,34@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY,`IM
M<V=I9"`B3&]G(&EN(@IM<V=S='(@(DMI<FIA=61U('-I<^3D;B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R
M979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R(")%9&5L;&ES96X@<WEN:W)O
M;F]I;G1I<V5S<VEO;B!L;VMI(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$Y-`IM<V=I9"`B3&]G(&]U="(*;7-G<W1R(")+:7)J875D=2!U
M;&]S(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4Y"FUS9VED("),;V=I
M;B(*;7-G<W1R(")+:7)J875D=2!S:7/DY&XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3$P"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R(")496AT
MY';D="!S:7/DY&YK:7)J875T=6UI<V5S<V$B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HY.34*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO
M=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T
M;'DN(@IM<V=S='(@(B(*(E-I<^3D;FMI<FIA=71U;6ES97-I(&5PY&]N;FES
M='5I+B!4;V1E;F[D:_9I<V5S=&D@:VER:F]I=&ET(';DY')I;B`B"B)KY'ET
M=.1JY'1U;FYU:W-E<VD@=&%I('-A;&%S86YA<VDN(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z.3DQ"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S
M='(@(E-I<^3D;FMI<FIA=71U;6EN96X@97#D;VYN:7-T=6DN(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V.0IM<V=I9"`B3&]N9R!T97AT(@IM
M<V=S='(@(E!I=&OD('1E:W-T:2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT.`IM<V=I9"`B3&]V92(*;7-G<W1R(")286MK875S(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DQO=R(*
M;7-G<W1R(")-871A;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L:7-T='EP95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L
M971T97)S(@IM<V=S='(@(E!I96YE="!K<F5I:VMA;&%I<V5T(&MI<FIA:6UE
M="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T
M<B`B4&EE;F5T(&QA=&EN86QA:7-E="!K:7)J86EM970B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$W"FUS
M9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(E!I96YE="!R;V]M
M86QA:7-E="!N=6UE<F]T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30U"FUS9VED("),=7AE;6)O
M=7)G(@IM<V=S='(@(DQU>&5M8G5R9R(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0S.2!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU
M,`IM<V=I9"`B34TB"FUS9W-T<B`B2TLB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C@S"FUS9VED(")-3U1$(@IM<V=S='(@(DU/5$0B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B
M35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R
M(")-4RU43D5&(&QI:71E=&EE9&]S=&\@;VQI('1Y:&KD+B(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL
M92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R(")624535$DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-3<*;7-G:60@(DUA8V%O(@IM<V=S='(@(DUA8V%O(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34S"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P
M=6)L:6,@;V8B"FUS9W-T<B`B36%K961O;FEA+"!%;G1I;F5N($IU9V]S;&%V
M:6%N('1A<V%V86QL86XN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Q"FUS9VED(")-861A9V%S
M8V%R(@IM<V=S='(@(DUA9&%G87-K87(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#D*;7-G:60@(DUA9VEC(@IM<V=S='(@(E1A:6MU=7,B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#,*;7-G:60@(DUA:6PB"FUS9W-T
M<B`B4^1H:_9P;W-T:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU
M,C0*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`B4&]S=&EN('EL;.1P:71O
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S='(@(E1E92!L
M:6YK7VMI+BXN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U"FUS9VED(")-86QA=VDB"FUS9W-T
M<B`B36%L87=I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38W"FUS9VED(")-86QA>7-I82(*;7-G
M<W1R(")-86QE<VEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T"FUS9VED(")-86QD:79E<R(*
M;7-G<W1R(")-86QE9&EI=FET(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T"FUS9VED(")-86QI
M(@IM<V=S='(@(E!O<W1I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38R"FUS9VED(")-86QT82(*
M;7-G<W1R(")-86QT82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-`IM
M<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA
M=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA
M=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B(@HB5F]I="!H
M86QL:6YN;VED82!L:7-T86$@:V%T96=O<FEO:7-T82P@:F]I9&5N(&%V=6QL
M82!V;VET(&QI:71TY.0@87-I;VET82`B"B)Y:'1E96X@<V%M;VIE;B!O='-A
M:VME:61E;B!A;&QE(&IA(&QI:71TY.0@;FEI:&EN(';D<F5JY"XB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U-@IM<V=I
M9"`B36%P,C0@;6%P(@IM<V=S='(@(DUA<#(T(&MA<G1T82(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#@W"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3<Q"FUS9VED(")-
M87!1=65S="!M87`B"FUS9W-T<B`B36%P475E<W0@:V%R='1A(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S
M=&]R960N(@IM<V=S='(@(E9A<W1A879U=61E="!T86QL971E='1U+B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#0*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED
M(")-87)C:"(*;7-G<W1R(")M86%L:7-K=74B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q"FUS9VED(")-87)G
M:6XB"FUS9W-T<B`B36%R9VEN86%L:2(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S0S,30N<&AP.C0X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K('=I=&@@4V5E;B]5;G-E
M96X@9FQA9W,B"FUS9W-T<B`B5F]I(&UE<FMI=.0@5F%N:&$O575S:2!T:65T
M;VIA(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z
M-#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*
M;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O
M06YS=V5R960I(@IM<V=S='(@(E9O:2!M97)K:73D('9I97-T96KD("AE<VEM
M+B!4Y')K9>0O5F%S=&%T='4I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34R"FUS9VED(")-87)S
M:&%L;"!)<VQA;F1S(@IM<V=S='(@(DUA<G-H86QL('-A87)E="(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U.0IM<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R(")-87)T:6YI<75E
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA
M=&-H:6YG(&9I96QD<R(*;7-G<W1R(")4Y'-MY.1VY'0@:V5N=.1T(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38P"FUS9VED(")-875R:71A;FEA(@IM<V=S='(@(DUA=7)I=&%N
M:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-C,*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R(")-
M875R:71I=7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB"FUS
M9W-T<B`B4W5U<FEN('-A;&QI='1Y(&MR961I:71T:2XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@
M(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G<W1R(")3=75R:6X@
M<V%L;&ET='4@=FEE<W1I;W-I;VWDY'+D('EL:71E='1Y+B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S$S"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO
M=7)S.B`B"FUS9W-T<B`B161E;&QI<V5N(#(T('1U;FYI;B!K;W)K96EN(&SD
M;7#V=&EL83H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#4*;7-G:60@
M(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(D5D96QL:7-E;B`V
M('1U;FYI;B!K;W)K96EN(&SD;7#V=&EL83H@(@H*(SH@;&EB+V%P:2YP:'`Z
M.#8*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS
M9W-T<B`B4&]R=&%A;&EO<VEO:61E;B!E;FEM;>1I<VWDY'+D(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3`R(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(T,PIM<V=I
M9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T<B`B4W5U<FEN('-A;&QI='1U('!I
M='5U<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8Y"FUS9VED(")-87DB"FUS9W-T<B`B=&]U:V]K=74B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4S"FUS9VED(")-87EO='1E(@IM<V=S='(@(DUA>6]N971T92(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T
M<B`B3.3D:V5T:65D92(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I
M="YI;F,Z,38*;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`B2N1S96YE="(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#(*;7-G:60@(DUE;G4@;6]D93HB
M"FUS9W-T<B`B365N=6X@;75O=&\Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L
M;',B"FUS9W-T<B`B66AD:7-TY"!S;VQU="(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S
M86=E(@IM<V=S='(@(E9I97-T:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,C$V"FUS9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U
M8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD
M(&YO="!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@HB5FEE<W1I;B!T87)K
M:7-T=7,@;VYN:7-T=6DL(&UU='1A(&%L;&5K:7)J;VET=&%J86X@=F%R;65N
M;F5T=&$@96D@=F]I='4@(@HB=&%R:VES=&%A+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B365S
M<V%G92!E>'!I<F5D+B(*;7-G<W1R(")6:65S=&D@=F%N:&5N:2XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C8P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-38Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C`R"FUS9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`B5FEE<W1I
M;B!T>7EP<&DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE
M=&%R(%=E871H97(B"FUS9W-T<B`B365T87(@<^3D(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO8VL@;F]T(&%V86EL86)L
M92XB"FUS9W-T<B`B365T87(M;W-I;R!E:2!O;&4@:^1Y=&5T=.1V:7-SY"XB
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q.0IM<V=I9"`B(@HB365T87(@
M8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D
M(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB365T87(M;W-I
M;R!E:2!O;&4@:^1Y=&5T=.1V:7-SY"X@5&%R:V5M;6%T('1I961O="!O;B!T
M86QL971E='1U('EL;.1P:61O;B`B"B)KY'-I=&5L=.1VY&MS:2XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34S"FUS9VED(")-971A<D1"
M(&ES(&YO="!C;VYN96-T960N(@IM<V=S='(@(DUE=&%R1$(@96D@;VQE('EH
M9&ES=&5T='DN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HV-R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<T
M"FUS9VED(")-971H;V0B"FUS9W-T<B`B365T;V1I(@H*(SH@9G)A;65W;W)K
M+U)00R]24$,O<V]A<"YP:'`Z,3$W(&9R86UE=V]R:R]24$,O4E!#+WAM;')P
M8RYP:'`Z.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(%PB)7-<(B!I
M<R!N;W0@9&5F:6YE9"(*;7-G<W1R(")-971O9&EA(%PB)7-<(B!E:2!O;&4@
M;>3D<FET96QT>2(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+W)E<W0N<&AP.C@R
M"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L
M;&5D(&UE=&AO9#H@)7,B"FUS9W-T<B`B365T;V1I82!E:2!O;&4@;>3D<FET
M96QT>2X@2W5T<W5V82!M971O9&DZ("5S(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HX,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C<*;7-G:60@
M(DUE=')I8R(*;7-G<W1R(")-971R:6YE;B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-@IM<V=I
M9"`B365X:6-O(@IM<V=S='(@(DUE:W-I:V\B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-0IM<V=I
M9"`B36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(*;7-G<W1R(")-
M:6MR;VYE<VEA+"!9:&1I<W1Y;F5E="!V86QT:6]T(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0R"FUS9VED(")-
M:61D;&4B"FUS9W-T<B`B2V5S:V5L;.0B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S
M='(@(DUI;64M='EY<'!I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3<*
M;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R(")%9&5L
M;&ES96X@,C0@='5N;FEN(&UA=&%L:6X@;.1M</9T:6QA.B`B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,P.0IM<V=I9"`B36EN('1E;7`@;&%S="`V(&AO
M=7)S.B`B"FUS9W-T<B`B161E;&QI<V5N(#8@='5N;FEN(&UA=&%L:6X@;.1M
M</9T:6QA.B`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0S
M.0IM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP
M:7)E9"(*;7-G<W1R(")386QA<V%N82!E:2!O;&4@=FEE;.0@=&%R<&5E:W-I
M('9A;FAA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(S-0IM<V=I9"`B36ER<F]R(@IM<V=S='(@(E!E:6QI:W5V82(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM<V=I9"`B36ES8V5L;&%N96]U
M<R(*;7-G<W1R(")396MA;&%I<V5T(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0P"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG(%!%
M05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S='(@(E!%05(M<&%K971T
M:2!(5%107U)E<75E<W0@<'5U='1U=2XB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3$U"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO
M=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@
M=&AI<R`B"B)A<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@HB4'5U='1U=F%T(&%S
M971U<W1I961O<W1O+B!3:6YU;B!P:73DY"!T96ADY"!A<V5T=7-T:65D;W-T
M;R!J;W,@:&%L=6%T("(*(FOD>71TY.0@=.1TY"!O:&IE;&UA82XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*
M;7-G:60@(DUI<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T<B`B4'5U='1U=F$@
M;65S<V%G92!)1"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O
M;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!0
M14%2('!A8VMA9V4@36%I;"XB"FUS9W-T<B`B5N1L='3D;>1T]FX@4$5!4BUP
M86ME='1I($UA:6P@<'5U='1U=2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S
M<VEO;B!)1"XB"FUS9W-T<B`B4'5U='1U=F$@<V5S<VEO;B!)1"XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED
M(")-;R(*;7-G<W1R(")M82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HW-@IM<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`B36]B:6EL:7/D:&OV
M<&]S=&DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HW,`IM<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B2V]H=&%L86EN96XB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8V(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,PIM<V=I9"`B36]D:69I960@
M1&%T92(*;7-G<W1R(")-=6]K:V%U:W-E;B!PY&EVY&WDY'+D(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4S
M"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@(DUU;VMK86$@55),.FEA(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S0*;7-G:60@
M(DUO9'5L=7,B"FUS9W-T<B`B2V5R<F]I;B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,`IM<V=I
M9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B36]L9&]V82P@=&%S
M879A;'1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30Y"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B
M36]N86-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34V"FUS9VED(")-;VYG;VQI82(*;7-G<W1R
M(")-;VYG;VQI82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.#@*
M;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@(FMU=6MA=7-I(&IA('9U
M;W-I(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H
M<#HU-PIM<V=I9"`B36]N=&AL>2(*;7-G<W1R(")+=75K875S:71T86EN(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38Q"FUS9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(DUO;G1S
M97)R870B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S='(@(DMU=6X@=F%I
M:&5E="(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$Y-B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR.#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E
M8W1E9"`E9"XB"FUS9W-T<B`B4FEV:6QTY"`E9"!L]GET>6D@96YE;6WD;B!K
M96YT=&GD(&MU:6X@;V1O=&5T='4@)60N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30X"FUS9VED
M(")-;W)O8V-O(@IM<V=S='(@(DUA<F]K:V\B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B36]S=&QY($-L96%R
M(@IM<V=S='(@(D5N:6UMY&MS:2!S96QK9>3D(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*;7-G:60@(DUO<W1L>2!#;&]U
M9'DB"FUS9W-T<B`B16YI;6WD:W-I('!I;'9I<W3D(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*;7-G:60@(DUO<W1L>2!#
M;&]U9'D@86YD(%=I;F1Y(@IM<V=S='(@(D5N:6UMY&MS965N('!I;'9I<W3D
M(&IA('1U=6QI<W1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S8*;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R(")%;FEM
M;>1K<V5E;B!A=7)I;FMO:7-T82(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70O36%N86=E<BYP:'`Z-C0X"FUS9VED(")-;W9E($1O=VXB"FUS
M9W-T<B`B4VEI<G+D(&%L87-PY&EN(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-3(*;7-G:60@(DUO=F4@3&5F="(*
M;7-G<W1R(")3:6ER<N0@=F%S96UM86QL92(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C4V"FUS9VED(")-;W9E(%)I
M9VAT(@IM<V=S='(@(E-I:7)RY"!O:6ME86QL92(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C0T"FUS9VED(")-;W9E
M(%5P(@IM<V=S='(@(E-I:7)RY"!Y;/9S<.1I;B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HU,C8*;7-G:60@(DUO=F4@9&]W
M;B(*;7-G<W1R(")3:6ER<N0@86QA<W#D:6XB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(U"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HU,C8*;7-G:60@(DUO=F4@=7`B"FUS
M9W-T<B`B4VEI<G+D('EL]G-PY&EN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38X"FUS9VED(")-
M;WIA;6)I<75E(@IM<V=S='(@(DUO<V%M8FEK(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C$X.`IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D;W=N
M(&QI<W1S(@IM<V=S='(@(DUO;FET87-O:6YE;B!A;&%S=F5T;W9A;&EK:V\B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U
M.`IM<V=I9"`B375L=&EM87`@54L@;6%P(@IM<V=S='(@(DUU;'1I;6%P($ES
M;RU"<FET86YN:6%N(&MA<G1T82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(R-#8*;7-G:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R(")-
M;VYI=F%L:6YT82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#(*
M;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T<B`B2^1Y='3D:N1T=6YN=6MS96YI
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X"FUS9VED(")->2!!8V-O
M=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(D]M86X@:^1Y='3D:N1T=6YN=6MS
M96X@=&EE9&]T(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HT-0IM
M<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(D]M82!P;W)T86%L:2(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HT,PIM<V=I9"`B37D@4&]R=&%L($QA
M>6]U="(*;7-G<W1R(")/;6%N('!O<G1A86QI;B!A<V5T=&5L=2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U-0IM<V=I9"`B37EA;FUA<B(*;7-G<W1R(")->6%N;6%R("A"=7)M
M82DB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M
M;#HU-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM<V=S='(@(D5)+"!%
M3B!S=6]S='4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F
M+G!H<#HS.`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3`R(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I
M9"`B3F%M92(*;7-G<W1R(").:6UI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Y"FUS9VED(").
M86UI8FEA(@IM<V=S='(@(DYA;6EB:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S@*;7-G:60@
M(DYA=7)U(@IM<V=S='(@(DYA=7)U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<W"FUS9VED(").
M97!A;"(*;7-G<W1R(").97!A;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-0IM<V=I9"`B3F5T
M:&5R;&%N9',B"FUS9W-T<B`B06QA;FMO;6%A="(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S"FUS
M9VED(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R(")!;&%N:V]M86ED
M96X@06YT:6QL:70B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B3F5T
M<V-A<&4@0F%S92!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB
M"FUS9W-T<B`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A
M<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R(").971S8V%P92!#02!P;VQI8WD@
M55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#4*
M;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@(DYE='-C87!E
M(%)E;F5W86P@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.#,*;7-G:60@(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM<V=S
M='(@(DYE='-C87!E(%)E=F]C871I;VX@55),(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C87!E(%-33"!S
M97)V97(@;F%M92(*;7-G<W1R(").971S8V%P92!34TPM<&%L=F5L:6UE;B!O
M<V]I=&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X
M.`IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R
M(").971S8V%P92!V87)M96YT965N(&MO;6UE;G1T:2(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!C
M97)T:69I8V%T92!T>7!E(@IM<V=S='(@(DYE='-C87!E('9A<FUE;G1E96X@
M='EY<'!I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U,PIM<V=I
M9"`B3F5T=V]R:R(*;7-G<W1R(")697)K:V\B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S
M.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDP"FUS9VED(").979E<B(*
M;7-G<W1R(")%:2!K;W-K86%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<P"FUS9VED(").97<@
M0V%L961O;FEA(@IM<V=S='(@(E5U<VDM2V%L961O;FEA(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3`*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,C8*;7-G:60@
M(DYE=R!#871E9V]R>2(*;7-G<W1R(")5=7-I(&QU;VMI='5S(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED(").97<@36]O;B(*;7-G<W1R(")5
M=7-I:W5U(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS
M-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B575S
M:2!KY'ET=.1JY'1U;FYU<R`H=F%P86%E:'1O:6YE;BDB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#`*;7-G:60@(DYE=R!:96%L86YD(@IM<V=S='(@(E5U<VDM4V5E;&%N=&DB
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*;7-G:60@(DYE
M=R!P87-S=V]R9"(*;7-G<W1R(")5=7-I('-A;&%S86YA(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]S<6PN<&AP.C(R-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(").97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@(E5U
M<VD@<V%L87-A;F$@=F%N:&5N964@)7@N(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C4R"FUS9VED(").97<@<&%S<W=O<F1S(&1O;B=T(&UA
M=&-H+B(*;7-G<W1R(")!;G1A;6%S:2!U=61E="!S86QA<V%N870@96EVY'0@
M=.1S;>3D+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B
M575S:2!I:VMU;F$@*%]B;&%N:RDB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H
M<#HT,"!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3(*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(Y,0IM<V=I9"`B3F5W<R(*;7-G<W1R(")5=71I<V5T
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-PIM<V=I9"`B3F5W
M<V=R;W5P<R(*;7-G<W1R(")+97-K=7-T96QU<GEH;>1T(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,CD@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z,C4*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$@=&5M
M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34*;7-G:60@(DYE>'0B"FUS9W-T
M<B`B4V5U<F%A=F$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*;7-G:60@
M(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B4V5U<F%A=F%T(#0@=F%I:&5T=&$B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V-B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C,W,`IM<V=I9"`B3F5X="!O<'1I;VYS
M(@IM<V=S='(@(E-E=7)A879A="!A<V5T=6MS970B"@HC.B!F<F%M97=O<FLO
M54DO54DO4&%G97(N<&AP.C$P,PIM<V=I9"`B3F5X=#XB"FUS9W-T<B`B4V5U
M<F%A=F$^(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<T"FUS9VED(").:6-A<F%G=6$B"FUS9W-T
M<B`B3FEC87)A9W5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q"FUS9VED(").:6=E<B(*;7-G
M<W1R(").:6=E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,PIM<V=I9"`B3FEG97)I82(*;7-G
M<W1R(").:6=E<FEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,V.0IM<V=I9"`B3FEG:'0B"FUS9W-T<B`B6?8B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-SD*
M;7-G:60@(DYI=64B"FUS9W-T<B`B3FEU92(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HY-C8*;7-G:60@(DYO(@IM<V=S='(@
M(D5I(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS
M9VED(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@
M9&EF9F5R96YC97,@9F]R+B(*;7-G<W1R(")!<V5T=7-T:65T;VIA(&5I(&]L
M92!S86%T879I;&QA+"!J;W-T82!V;VES:2!NY'ET=.3D(&5R;V%V86ES=75K
M<VEA+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP
M:'`Z,3`V"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN
M9R!)4T\@:6UA9V5S+B(*;7-G<W1R(")%:2!O;&4@<V%A=&%V:6QL82!S=75N
M;FET96QM86$@25-/(&QE=GEK=79A=&EE9&]S=&]J96X@=&5K96UI<V5K<VDN
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S$S"FUS9VED(").;R!B871C:"!T96UP;&%T92XB"FUS9W-T<B`B16D@
M97+D;6%L;&EA+B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70O36%N86=E<BYP:'`Z,S@U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70O36%N86=E<BYP:'`Z-#`W"FUS9VED(").;R!B;&]C:R!E>&ES=',@
M870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R(")/<VEO=&$@96D@
M;VQE('!Y>61E='ES<^0@<&%I:V%S<V$N(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]M8V%L+G!H<#HU,`IM<V=I9"`B3F\@8V%L96YD87(@;F%M92!P<F]V
M:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B2V%L96YT
M97)I;B!N:6UEY"!E:2!O;&4@86YN971T=2!-0T%,+6%U=&5N=&EK;VEN;FEL
M;&4N(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-30*;7-G:60@(DYO(&-H
M86YG92XB"FUS9W-T<B`B16D@;75U=&]S=&$N(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B
M92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(D%L:71A<V]J
M82!E:2!V;VD@;&ESY'3D('3D;&QE(&]I:V5U9&5L;&4N(@H*(SH@9G)A;65W
M;W)K+U5T:6PO571I;"YP:'`Z-S8X(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,38Y"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`X"B,L('!H
M<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B07-E='5K<VEA(&5I(&SV>71Y
M;GET("5S.FQL92XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@U
M-0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R($944"!61E,N(@IM<V=S='(@(D%S971U:W-I82!E:2!L]GET>6YY
M="!&5%`@5D93.FQL92XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C8W,@IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R(%-13"!61E,N(@IM<V=S='(@(D%S971U:W-I82!E:2!L]GET
M>6YY="!344P@5D93.FQL92XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z-S(U"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R(")!<V5T
M=6MS:6$@96D@;/9Y='EN>70@4U%,+49I;&4@5D93.FQL92XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G
M:60@(DYO(&-R961I="!L969T+B(*;7-G<W1R(")+<F5D:6ET:70@;&]P<'4N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,S0*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G<W1R
M(")+;VAD971T82!E:2!A;FYE='1U+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R
M+T)R;W=S97(N<&AP.CDR,`IM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G
M<W1R(")%:2!T=6]T=2!A:6YU='1A:V%A;B!T:65D;W-T;V$B"@HC.B!U=&EL
M+VEC;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*
M;7-G<W1R(")):V]N96ET82!E:2!L]GET>6YY="XB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$S,"!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q-@IM<V=I9"`B3F\@;&]C871I
M;VX@:7,@<V5T+B(*;7-G<W1R(")086EK:V%A(&5I(&]L92!A<V5T971T=2XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W"FUS9VED(").
M;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B4&%I:VMA82!E:2!O;&4@
M86YN971T=2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S,PIM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS
M9W-T<B`B16D@86YN971T=2!V:65S=&GD+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS9VED(").;R!N86UE
M('-P96-I9FEE9"XB"FUS9W-T<B`B3FEM9>0@96D@;VQL=70@86YN971T=2XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S-PIM<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`B3'5K
M=6WDY'+DY"!E:2!O;&QU="!A;FYE='1U+B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S
M='(@(D5I(&QO=6MK86%V870@;6EE=&5L875S965T(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(E-A;&%S
M86YA82!E:2!O;&4@86YN971T=2!(5%10+6%U=&5N=&EK;VEN;FES<V$N(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HQ,#@*;7-G:60@(DYO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R(")386QA<V%N86$@96D@;VQE(&%N;F5T='4@24U!4"UA=71E;G1I
M:V]I;FYI<W-A+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z
M-S(*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B4V%L87-A;F%A(&5I(&]L92!A;FYE
M='1U($ME<F)E<F]S+6%U=&5N=&EK;VEN;FES<V$N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L;V=I;BYP:'`Z.#0@9G)A;65W;W)K+T%U=&@O075T:"]P
M86TN<&AP.C<U"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z-S<*
M;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B4V%L87-A;F%A(&5I(&]L92!A;FYE='1U($QO
M9VEN(&%U=&5N=&EK;VEN;FES<V$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]P87-S=V0N<&AP.C$S-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B4V%L87-A;F%A
M(&5I(&]L92!A;FYE='1U(%!!4U-71"UA=71E;G1I:V]I;FYI<W-A+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HX-`IM<V=I9"`B3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B4V%L87-A;F%A(&5I(&]L92!A;FYE='1U(%--0BUA=71E;G1I:V]I;FYI
M<W-A+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X
M-PIM<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O
M=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB
M=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@HB4&]L:W5A($]P
M96Y34TP@:V]M96YT;V]N(&5I(&]L92!MY.1R:71E;'1Y+B!/<&5N4U-,('!I
M=.3D(&]L;&$@:^1Y=&5T=.1V:7-SY"`B"B)J;W,@:^1S:71E;&SDY&X@4$M#
M4R`Q,B!D871A82XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E
M+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM<V=S='(@(D5I
M('-I<^3D;FMI<FIA=71U;6ES<'EY;G3V:N0@:F]N;W-S82XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z-S8V"FUS9VED(").;R!Q=6]T82!S970N(@IM
M<V=S='(@(DMI:6YT:?9TY"!E:2!O;&4@87-E=&5T='4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0S"FUS9VED
M(").;R!R=6QE<R(*;7-G<W1R(")%:2!SY.1N=/9JY"(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C0X,@IM<V=I9"`B3F\@<V5P87)A=&]R('-P
M96-I9FEE9"XB"FUS9W-T<B`B17)O=&EN=&$@96D@;VQE(&WDY')I=&5L='DN
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT-`IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B16D@<F5U;F]J82(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@W"FUS9VED(").;R!S
M=6-H(&9I;&4B"FUS9W-T<B`B16D@;/9Y='EN>70@=&EE9&]S=&]A(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$R-@IM<V=I9"`B3F\@=&5M
M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+B(*;7-G<W1R
M(")6Y&QI;75I<W1I;&QE(&5I(&]L92!VY&QI86EK86ES:&%K96UI<W1O82XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R
M,0IM<V=I9"`B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM
M<V=S='(@(DOD>71TY&KD='5N;G5S=&$@=&%I('-A;&%S86YA82!E:2!LY&AE
M=&5T='DN(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ-#`*
M;7-G:60@(DYO('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@(DMA
M:6MK:2!P86QA=71U;G5T(%A-3"UD871A(&]L:2!E<.1K96QP;V$B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3<T"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY.#0*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDY-0HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`Q,@IM<V=I9"`B
M3F\@=F%L=65S(@IM<V=S='(@(D5I(&%R=F]J82(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ,C`*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I
M9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R("(B"B)697)S:6]T:65T;VIA(&5I(&SV>71Y;GET(&%L:W5P
M97+D:7-I=.0@87-E='5K<VES=&$N(%-I;G5N('!I=.3D('1E:&3D("(*(F%S
M971U:W-E="!U=61E<W1A86XN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$R.`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R
M871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB
M5F5R<VEO=&EE=&]J82!E:2!L]GET>6YY="!A<V5T=6MS:7-T82X@4VEN=6X@
M<&ETY.0@=&5H9.0@87-E='5K<V5T('5U9&5S=&%A;BXB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C<@=&5M<&QA=&5S+W!R969S+VED
M96YT:71Y<V5L96-T+FEN8SHY,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0U"FUS9VED(").;VYE(@IM<V=S='(@
M(D5I(&UI=.3D;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T
M<B`B16D@;6ETY.1N("A+Y'ETY"!I;7!L:7-I:71T:7-TY"DB"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y,@IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ
M,"DB"FUS9W-T<B`B3&%P<&DO4&]H:F]I<VUA870O17-K:6UO("A)4T\M.#@U
M.2TQ,"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S(*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM
M<V=S='(@(DYO<F9O;&L@<V%A<F5T(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M
M:7-P:&5R92(*;7-G<W1R(")0;VAJ;VEN96X@<&%L;&]N<'5O;&ES:V\B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-3@*;7-G:60@(DYO<G1H97)N($UA<FEA;F$@27-L86YD<R(*
M;7-G<W1R(")0;VAJ;VES970@36%R:6%A;FEE;B!S86%R970B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S8*;7-G:60@(DYO<G=A>2(*;7-G<W1R(").;W)J82(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0Q"FUS9VED(").;W0@069T
M97(B"FUS9W-T<B`B16D@:N1L:V5E;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-C0P"FUS9VED(").;W0@0F5F;W)E(@IM<V=S='(@
M(D5I(&5N;F5N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#$U
M"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B16D@;VQE(&AA:V5M
M:7-T;R(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP
M:'`Z-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R
M871E9WDN<&AP.C@T"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDU"FUS9VED(").;W0@:6UP
M;&5M96YT960N(@IM<V=S='(@(D5I(&]L92!T;W1E=71E='1U+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*;7-G:60@
M(DYO="!S970B"FUS9W-T<B`B16D@87-E=&5T='4B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,3DS(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,#@*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,C4R"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-CD@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C(X-0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S`Q
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,38*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C,S,R!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S8V"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HT,C8@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4P
M-0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3<T(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HU.3$*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C8V.2!F<F%M
M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$T-0HC
M.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP
M.C$V,`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L
M97(N<&AP.C$W-0HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO
M;DAA;F1L97(N<&AP.C$X.0HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O
M4V5S<VEO;DAA;F1L97(N<&AP.C(S-@IM<V=I9"`B3F]T('-U<'!O<G1E9"XB
M"FUS9W-T<B`B16D@='5E='1U+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HR-#0@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,#@*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X,"!C;VYF:6<O
M:&]O:W,N<&AP+F1I<W0Z,3`U.`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B375I
M<W1I:6YP86YO="(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS
M-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@
M(D5I(&UI=.3D;B!S96QA='1A=F%A+"!P86QA82!T86MA:7-I;BXB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B
M3F]V96UB97(B"FUS9W-T<B`B;6%R<F%S:W5U(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3`U,`IM<V=I9"`B3G5M8F5R(@IM<V=S='(@(DQU:W5M
MY.1RY"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,CD*;7-G:60@
M(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(DUE<FMK:65N(&QU:W5M
MY.1RY"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-S,@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,30R-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#0Y('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`T"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R(")387)A
M:VME:61E;B!L=6MU;>3D<N0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,S<Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C4*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,30T-R!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS
M9W-T<B`B4FEV:65N(&QU:W5MY.1RY"(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"FUS9VED(").=6UB97)S(&YO
M="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T
M+B(*;7-G<W1R(")*86ME;'5L:7-T86X@;G5M97)O:71A(&5I(&]L92!MY.1R
M:71E;'1Y('#D:79I=&5T=.1VY&MS:2XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM<V=S='(@(D]+
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W
M,PIM<V=I9"`B3V)J96-T(@IM<V=S='(@(D]B:F5K=&DB"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B3V)J96-T($-R96%T;W(B
M"FUS9W-T<B`B3V)J96MT:6X@;'5O:F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,3`X"FUS9VED(")/8W1A;"(*;7-G<W1R(")/:W1A86QI(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,0HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G
M:60@(D]C=&]B97(B"FUS9W-T<B`B;&]K86MU=2(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HY,@IM<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B
M3&]U:VMA879U=7-S=6]D871I;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS,C@*;7-G:60@(D]F9FEC92(*;7-G<W1R(")4;VEM:7-T;R(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N
M9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R(")5
M=7-I('-A;&%S86YA(&5I('-A82!O;&QA('-A;6$@:W5I;B!N>6MY:6YE;B!S
M86QA<V%N87-I+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS
M-@IM<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@(E9A;FAA('-A;&%S86YA
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C0V"FUS9VED(")/
M;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N(@IM<V=S='(@(E9A;FAA('-A
M;&%S86YA(&]N(';DY')I;BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#$*;7-G:60@(D]M86XB
M"FUS9W-T<B`B3VUA;B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T
M('-H87)E9"!F;VQD97)S+B(*;7-G<W1R(")686EN($E-05`M<&%L=F5L:6UE
M="!T=6ME=F%T(&IA971T=6IA(&MA;G-I;VET82XB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S
M(@IM<V=S='(@(E9A:6X@;&]U:VMA879A="!M:65T96QA=7-E970B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4U(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y-S4*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL
M;W=E9"XB"FUS9W-T<B`B5F]I="!L86ET=&%A('9A:6X@>6AD96X@<^1H:_9P
M;W-T:6]S;VET=&5E;BXB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z
M-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES
M=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI
M<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(B(*(E9A:6X@;VUI<W1A:F$@
M=&%I(&KD<FIE<W1E;&WD;B!Y;&SD<&ETY&KD('9O:2!M=75T=&%A(&IA:V]J
M96X@;VUI<W1A:FEA('1A:2`B"B)O:6ME=6MS:6$B"@HC.B!L:6(O0FQO8VLO
M:69R86UE+G!H<#HT,2!L:6(O0FQO8VLO:69R86UE+G!H<#HT,@IM<V=I9"`B
M3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B079A82!U=61E<W-A(&EK
M:W5N87-S82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D
M871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*;7-G<W1R("(B"B)/<&5N
M4U-,('9I<FAE.B!4:65T;VIA(&5I('-A871U(&5S:6QL92!A;&QE:VER:F]I
M=&5T=7-T82!3+TU)344M;W-A<W1A+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@
M=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")!=F%A('3D;>1N
M(&QI;FMI;B!U=61E<W-A(&EK:W5N87-S82(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R(")+
MY'ET=/9JY')J97-T96QMY"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HQ-3$*;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`B07-E='5K<V5T(@H*
M(SH@<V5R=FEC97,O<')E9G,N<&AP.C,Q('1E;7!L871E<R]P<F5F<R]A<'`N
M:6YC.C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM
M<V=S='(@(D%S971U:W-E="`E<SIL;&4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B
M"FUS9W-T<B`B2N1R:F5S=&5T='D@;&ES=&$B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N(@IM
M<V=S='(@(D]R9V%N:7-A871I;R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-38Y"FUS9VED(")/<F=A;FES871I;VYA;"!5;FET(@IM
M<V=S='(@(D]R9V%N:7-A871I;WEK<VEK:_8B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3,T"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(D]R
M9V%N:7-O:6YT:2(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3,U"FUS9VED
M(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R(")!;&MU
M<&5RY&EN96X@;VAJ96QM86X@;6%L;&DB"@HC.B!A9&UI;B]T96UP;&%T97,N
M<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T
M97,@:6X@)7,Z(@IM<V=S='(@(D%L:W5P97+D:7-E="!M86QL:70@)7,Z<W/D
M.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R=FEC
M97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G<W1R(")-=74B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3D@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$P.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$V(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,C4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30T"FUS9VED(")/=&AE<B!)
M;F9O<FUA=&EO;B(*;7-G<W1R(")-=75T('1I961O="(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS
M(@IM<V=S='(@(D]M:7-T86IA;B!O:6ME=61E="(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<&%M+G!H<#HW.0IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N
M(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(E!!32UA=71E;G1I:V]I;G1I
M82!E:2!O;&4@:^1Y=&5T=.1V:7-SY"XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%05(Z.DUA:6P@
M8F%C:V5N9"(*;7-G<W1R(")014%2.CI-86EL('1A=7-T86KD<FIE<W1E;&WD
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3(W-@IM<V=I
M9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S='(@(D1I9VET86%L:6YE
M;B!01U`M86QL96MI<FIO:71U<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$S,C(*;7-G:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G
M<W1R(")01U`M<V%L871T=6$@=&EE=&]A(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3,W-`IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS
M9W-T<B`B2G5L:VEN96X@4$=0+6%V86EN(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3,U-@IM<V=I9"`B4$=0(%-I9VYE9"]%;F-R>7!T
M960@1&%T82(*;7-G<W1R(")01U`M86QL96MI<FIO:71E='1U82!J82!S86QA
M='1U82!T:65T;V$B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-CD*;7-G:60@
M(E!(4"!#;V1E(@IM<V=S='(@(E!(4"UK;V]D:2(*"B,Z(&%D;6EN+W!H<'-H
M96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(E!(4"UK;VUE
M;G1O='5L:VMI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S@*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B4$T@:V5V
M>71TY"!S861E='1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%)A:6XB"FUS9W-T<B`B4$T@<V%D92(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS
M9VED(")032!3:&]W97)S(@IM<V=S='(@(E!-(&MU=7)O:F$B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@
M4VYO=R(*;7-G<W1R(")032!L=6UI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*
M;7-G<W1R(")032!L=6UI<V%T96ET82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0S"FUS9VED(")032!3=6XB"FUS9W-T<B`B
M4$T@;'5M:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0T"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R(")032!U:VMO<VUY
M<G-K>6KD(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(W-`IM<V=I9"`B
M4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T<B`B4$]325@M;&%A
M:F5N;G5K<V5T('!U=71T=79A="(*"B,Z(&QI8B]A<&DN<&AP.C$T.0IM<V=I
M9"`B4%](4"!3:&5L;"(*;7-G<W1R(")07TA0+6MO;65N=&]T=6QK:VDB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0V"FUS9VED(")0861D:6YG(@IM<V=S='(@(E3D>71E(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@W"FUS9VED(")086MI<W1A;B(*;7-G<W1R(")086MI<W1A;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.30*;7-G:60@(E!A;&%U(@IM<V=S='(@(E!A;&%U(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y,@IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE
M9"(*;7-G<W1R(")086QE<W1I:6YA("AM:65H:71E='1Y(&%L=64I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@R"FUS9VED(")086YA;6$B"FUS9W-T<B`B4&%N86UA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@U"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(E!A
M<'5A(%5U<VDM1W5I;F5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-0IM<V=I9"`B4&%R86=U
M87DB"FUS9W-T<B`B4&%R86=U87DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS-PIM<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G
M<W1R(")/<VET=&%I;B!P:6QV:7-TY"(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34Q(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(P,C(*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW
M-R!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT,C4*;7-G:60@(E!A<W-W;W)D(@IM<V=S
M='(@(E-A;&%S86YA(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C@R"FUS9VED(")087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS
M9W-T<B`B4V%L87-A;F%N('9A:6AT;R!O;FYI<W1U:2XB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$S,C,*;7-G:60@(E!A<W-W;W)D
M(&EN8V]R<F5C="(*;7-G<W1R(")6Y.1RY"!S86QA<V%N82(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D
M(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(E-A;&%S86YA82!T87)V:71A86X@4D%$2553+6%U=&5N=&EK;VEN=&EI;BXB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#4W"FUS9VED(")087-S
M=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")386QA<V%N82!V87)M
M:7-T=6MS96QL82(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY
M,`IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(E-A;&%S86YA.B(*"B,Z('1E
M;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"FUS9VED(")087-S=V]R9#H@
M(@IM<V=S='(@(E-A;&%S86YA.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3`@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`S.`HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS9VED(")087-S=V]R9',@;75S="!M
M871C:"XB"FUS9W-T<B`B4V%L87-A;F]J96X@<&ETY.0@;VQL82!S86UA="XB
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B
M"FUS9W-T<B`B3&EI=.0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,W"FUS9VED(")087-T92!F<F]M(&-L:7!B;V%R9"(*
M;7-G<W1R("),:6ETY"!L96EK97#V>63D;'3D(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G
M<W1R(")0;VQK=2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N
M:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHW
M"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(DIO;F]S<V$@;VQE
M=F%T('-I<^3D;FMI<FIA=71U;6ES<'EY;F[V=#HB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-30*;7-G:60@(E!E;W!L92(*;7-G<W1R(")):&UI<V5T
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`B4')O<V5N='1I(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@
M(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R(")3=6]R
M:71A('EL;.1P:71O=&]I;65N<&ET965T(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0Q,`IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I
M;VYS(&]N(&QO9VEN/R(*;7-G<W1R(")3=6]R:71A('EL;.1P:71O=&]I;65N
M<&ET965T('-I<^3D;FMI<FIA=71U;6ES96X@>6AT97ED97-SY"XB"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B4&5R;6ES
M<VEO;B(*;7-G<W1R(")/:6ME=7,B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N
M<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB
M(&YO="!D96QE=&5D+B(*;7-G<W1R(")/:6ME=71T82!<(B5S7"(@96D@<&]I
M<W1E='1U+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3DP"FUS
M9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R(")+Y'ET=/8@:VEE;&QE
M='1Y(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C$@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C0*;7-G:60@(E!E<FUI<W-I
M;VYS(@IM<V=S='(@(D]I:V5U9&5T(@H*(SH@861M:6XO<&5R;7,O861D8VAI
M;&0N<&AP.C8P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3@*(SH@861M:6XO
M<&5R;7,O961I="YP:'`Z,3`Y(&%D;6EN+W!E<FUS+VEN9&5X+G!H<#HR,@IM
M<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VXB"FUS9W-T<B`B3VEK
M975K<VEE;B!Y;&SD<&ET;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M.`IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`B3VUA="!T
M:65D;W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#,*;7-G:60@(E!E<G4B"FUS9W-T<B`B4&5R
M=2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-0IM<V=I9"`B4&5T<R(*
M;7-G<W1R("),96UM:6MI="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-@IM<V=I9"`B4&AI;&EP
M<&EN97,B"FUS9W-T<B`B1FEL:7!P:6EN:70B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G
M<W1R(")0=6AE;&EN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X
M,`IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(E9A;&]K=79A="(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.3`*;7-G:60@(E!I=&-A:7)N(@IM<V=S='(@(E!I=&-A:7)N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G
M:60@(E!I>&5L<R(*;7-G<W1R(")0:6MS96QI(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4V"FUS9VED(")0;&%T:71U9&5S(@IM<V=S='(@(DML:7-E
M970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB
M"FUS9W-T<B`B3F%P<V%U=&$@:F]T86EN('-O;'5A(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED
M(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES
M(&5L96UE;G0Z(@IM<V=S='(@(E9A<FUI<W1A(&5T=.0@:&%L=6%T('!O:7-T
M86$@=.1MY&X@96QE;65N=&EN.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O
M;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*
M;7-G<W1R(")687)M:7-T82!E='3D(&AA;'5A="!P;VES=&%A(&QI;FMI='EK
M<V5N('3D:.1N(&5L96UE;G1T:6EN+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(U-C8*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A
M('EE87(N(@IM<V=S='(@(D%N;F$@:W5U:V%U<VD@:F$@=G5O<VDN(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G
M:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ
M(@IM<V=S='(@(D%N;F$@;FEM:2!U=61E;&QE(&QU;VMI='5K<V5L;&4Z(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P-0IM<V=I9"`B4&QE87-E
M(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B06YN82!O:6ME
M82!)4"UO<V]I=&4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8T
M-`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE
M(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B06YN82!O
M:6ME82!PY&EVY&WDY'+D.R!487)K:7-T82!PY&EV:65N(&QU:W5MY.1RY"!K
M=75K875D97-S82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4Q
M"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+B(*;7-G<W1R(")!
M;FYA(&%I:V$@;VEK96%S<V$@;75O9&]S<V$N(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S
M=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R(")!;FYA(&QY:'ET(&MU
M=F%U<R!O;F=E;&UA<W1A+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z,C(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE
M87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T
M<B`B06YN82!KY'ET=.1JY'1U;FYU:W-E<VD@:F$@<V%L87-A;F%S:2(*"B,Z
M('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B(@HB4&QE87-E
M(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H
M('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B(@HB
M3'5E('-E=7)A879A('1E:W-T:2X@4VEN=6X@4$E4Q,0@<W5O<W1U82!KY'ET
M=/9E:'1O:6AI;B!V;VED86MS97-I(&OD>71TY.0@(@HB:N1R:F5S=&5L;>3D
M+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C<P"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA
M;64Z(@IM<V=S='(@(D%N;F$@;FEM:2!U=61E;&QE(&QU;VMI='5K<V5L;&4Z
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@X"FUS9VED(")0;VQA;F0B"FUS9W-T<B`B4'5O;&$B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S
M(@IM<V=S='(@(E!O;&ET:6EK:V$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#@Y"FUS9VED(")0;VQL<R(*;7-G<W1R(")+>7-E;'ET(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y,PIM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B4&]R='5G86QI
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(W"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E
M(@IM<V=S='(@(E3D;>1N(&MU=F%N('!A:6MK82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO
M;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(E3D;>1N('1A=6QU:V]N('!A
M:6MK82(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP
M.C4Q"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR
M"FUS9VED(")0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@
M24U!4"DB"FUS9W-T<B`B5F]I(&SD:&5T=.3D('9I97-T96KD(&MA;G-I;V]N
M("AE:2!K;W-K92!)34%0('EH=&5Y:W-IY"DB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(W,R!L:6(O0FQO8VLO;65T87(N<&AP.C(W.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ
M("(*;7-G<W1R(")3861E;>3D<N0@961E;&QI<VEL;&4@)7,@='5N;FEL;&4Z
M("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#<*;7-G:60@
M(E!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B2&%I:'1U=G5U
M<R`\8G(@+SYT;V1E;F[D:_9I<WEY<R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@
M3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]L9&%P
M.B!487)V:71T879A82!,1$%0+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET+B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I
M9"`B4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]S97-S:6]N.B!487)V:71T879A
M82!S97-S:6]N+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,S(*;7-G:60@(E!R97-S=7)E(@IM<V=S='(@(DEL
M;6%N<&%I;F4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V-@IM<V=I9"`B
M4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B26QM86YP86EN92!M
M97)E;G!I;FYA<W-A.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C(T"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@(DEL;6%N<&%I;F4Z
M("(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@(D5S:6MA='-E
M;'4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C0*;7-G:60@(E!R979I97<@=&AE(&EM86=E(&EN(&$@
M;F5W('=I;F1O=R(*;7-G<W1R(")%<VEK871S96QE(&MU=F$@=75D97-S82!I
M:VMU;F%S<V$B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,U
M-B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V,`IM<V=I9"`B4')E
M=FEO=7,@;W!T:6]N<R(*;7-G<W1R(")%9&5L;&ES970@87-E='5K<V5T(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM
M<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B5'5L;W-T82!D;VMU;65N
M='1I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS
M9VED(")0<FEV871E($ME>2(*;7-G<W1R(")386QA:6YE;B!A=F%I;B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-CD*;7-G:60@(E!R
M;V)L96TB"FUS9W-T<B`B3VYG96QM82(*"B,Z('-E<G9I8V5S+W!R;V)L96TN
M<&AP.C$R-PIM<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R(")/
M;F=E;&UA;B!K=79A=7,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S<Q"FUS9VED(")0<F]J96-T<R(*;7-G<W1R(")0<F]J96MT:70B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3$U(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q.3(*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,`IM
M<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`B2V5H;W1T965N('1E:W-T:2(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B
M4'5B;&EC($ME>2(*;7-G<W1R(")*=6QK:6YE;B!A=F%I;B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0V"FUS9VED(")0=6)L:6,@
M2V5Y($%L9V]R:71H;2(*;7-G<W1R(")*=6QK:7-E;B!A=F%I;65N(&%L9V]R
M:71M:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U
M"FUS9VED(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`B2G5L:VES96X@879A
M:6UE;B!T:65D;W0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HR-#$*;7-G:60@(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R
M871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(DIU;&MI<V5N+W-A;&%I<V5N
M(&%V86EN<&%R:6X@;'5O;G1I(&5PY&]N;FES='5I+B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.3$*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S='(@(E!U97)T;R!2:6-O(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-34*;7-G
M:60@(E!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(E9O:2!T=6AO=&$@<&]I<W1E
M='1U:F$@=FEE<W1E:N0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DV"FUS9VED(")1871A<B(*
M;7-G<W1R(")1871A<B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HV-`IM<V=I
M9"`B475E<GDB"FUS9W-T<B`B2WES96QE(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C<P"FUS9VED(")1=6]T82(*;7-G<W1R(")+:6EN=&GV(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B
M4E-!($IU;&MI;F5N(&%V86EN("@E9"!B:71T:>0I(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C(V.`IM<V=I9"`B4F%D:6\@<V5L96-T:6]N(@IM
M<V=S='(@(E)A9&EO<&%I;FEK92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")286EN(@IM<V=S='(@(E-A9&4B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM
M<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R(")3861E='1A(&%I:V%I<VEN(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G
M:60@(E)A:6X@3&%T92(*;7-G<W1R(")3861E='1A(&UY]FCDY&XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B
M4F%I;B!3:&]W97(B"FUS9W-T<B`B4V%D96MU=7)O(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*;7-G:60@(E)A:6X@86YD
M(%-N;W<B"FUS9W-T<B`B5F5S:2!J82!L=6UI(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3`*;7-G:60@(E)A:6X@=&\@4VYO
M=R(*;7-G<W1R(")6961E<W3D(&QU;65E;B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R(")3871U
M;FYA:6YE;B!M:65T96QA=7-E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HV."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<V"FUS9VED(")2871I;R(*;7-G<W1R(")3=6AD92(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(T('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3$T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@P"FUS9VED(")296%D
M(@IM<V=S='(@(DQU:W4B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,T,S$T+G!H<#HT-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HX.`IM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R(")6;VD@
M;'5K96$@=FEE<W1E:N0B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO
M=F4N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E
M<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B
M4&]I<W1E=&%A;FMO("5S/R!4Y'3D('1O:6UI;G1O82!E:2!V;VD@<&5R=75T
M=&%A+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX"B,L
M('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O
M<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*
M;7-G<W1R(")0;VES=&5T86%N:V\@=&EE9&]T(&OD>71TY&KD<W3D("5S/R!4
MY'3D('1O:6UI;G1O82!E:2!V;VD@<&5R=75T=&%A+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E
M<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(E1E92!M=75T;VMS970@=75D
M97-T86%N(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B4.1I
M=FETY"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.34*;7-G:60@(E)E
M9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G<W1R(")0Y&EVY'0@
M9'EN86%M:7-E="!V86QI:VMO96QE;65N=&ET.B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-#4*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM
M<V=S='(@(E#D:79I=.0@<&]R=&%A;&ENY&MY;>3D.B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C@Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C$W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,SD*;7-G:60@(E)E
M9V5X(@IM<V=S='(@(E/DY&YN]FQL:6YE;B!L875S96ME(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S(S-0IM<V=I9"`B4F5L871I;VYS:&EP($)R
M;W=S97(B"FUS9W-T<B`B4F5L86%T:6]S96QA:6XB"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C`X"FUS9VED(")296QO860B"FUS9W-T<B`B3&%T86$@=75D96QL965N
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,S,*;7-G:60@(E)E;6%R:W,B
M"FUS9W-T<B`B375I<W1I:6YP86YO="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,3<*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(D5TY'!A
M;'9E;&EM970B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*
M;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R
M9&4I.B(*;7-G<W1R(")%=.1P86QV96QU;B!54DP@*&AT='`Z+R]W=W<N97AA
M;7!L92YC;VTO:&]R9&4I.B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U
M975E9"YI;F,Z,3,@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR
M,@IM<V=I9"`B4F5M;W9E(@IM<V=S='(@(E!O:7-T82(*"B,Z('1E;7!L871E
M<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM
M<V=S='(@(E!O:7-T82!O<VEO(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C4U.0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G
M<W1R(")0;VES=&$@<V%R86ME(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHT,`IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B
M"FUS9W-T<B`B4&]I<W1A(&UU;W1O:6QU(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHQ,C@*;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@(E!O
M:7-T82!P87)I(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I
M9"`B4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R
M>2!D:7)E8W1O<GDN(@IM<V=S='(@(E!O:7-T82!T86QL971E='1U('-K<FEP
M=&D@<&%L=F5L:6UE;B!VY&QI86EK86ES:&%K96UI<W1O<W1A+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M,@IM<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R(")0;VES=&$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*
M;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS
M9W-T<B`B4&]I<W1A('3D;>0@;F]O9&D@9&]K=6UE;G1I<W1A(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0IM<V=I9"`B4F5M;W9E
M('5S97(B"FUS9W-T<B`B4&]I<W1A(&OD>71TY&KD(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@
M(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R(")0;VES=&$@:^1Y='3D:N0Z("5S
M(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ,S@*;7-G:60@
M(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R
M8V]D93H@(@IM<V=S='(@(E!Y>6YT]O9N(&5I('9O:71U('9A<W1A=&$N(%9I
M<FAE:V]O9&DZ("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-#4*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N
M9"XB"FUS9W-T<B`B4'EY9&5T='GD('!A;'9E;'5A(&5I(&SV>71Y;GET+B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<V(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z-3$X"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I
M<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(E1A<G9I='1A=F%A(%PB)7-<(BUT:65T;V$@96D@;VQL=70@
M;>3D<FET96QT>2`E<R!A<V5T=6MS:7-S82XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C@V,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z-S,Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C<X"B,L('!H
M<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D
M(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")487)V:71T879A82!<
M(B5S7"(M=&EE=&]A(&5I(&]L;'5T(&WDY')I=&5L='D@5D93(&%S971U:W-I
M<W-A+B(*"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<W-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I
M;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")487)V:71T879A82!<(B5S7"(M
M=&EE=&]A(&5I(&]L;'5T(&WDY')I=&5L='D@87-E='5K<VES<V$N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S,U"FUS9VED(")2
M97%U:7)E9"!&:65L9"(*;7-G<W1R(")086MO;&QI;F5N(&ME;G1TY"(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C,Q(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,C`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S0S
M(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,R,`HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(E1Y:&IE
M;F[D(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#8*;7-G:60@
M(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(E1Y:&IE;F[D('-A;&%S86YA(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*;7-G:60@(E)E<V5T
M(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B5'EH:F5N;N0@<V%L87-A;F%S:2(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S$*;7-G:60@(E)E<W1O<F4@3&%S
M="!1=65R>2(*;7-G<W1R(")086QA=71A(&5D96QL:6YE;B!K>7-E;'DB"@HC
M.B!A9&UI;B]C;61S:&5L;"YP:'`Z,CD@861M:6XO<&AP<VAE;&PN<&AP.C<R
M(&%D;6EN+W-Q;'-H96QL+G!H<#HV-PIM<V=I9"`B4F5S=6QT<R(*;7-G<W1R
M(")4=6QO:W-E="(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ
M,#$@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O
M($]P=&EO;G,B"FUS9W-T<B`B4&%L86$@87-E='5K<VEI;B(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS.`IM<V=I9"`B4F5T>7!E(&YE=R!P
M87-S=V]R9"(*;7-G<W1R(")686AV:7-T82!U=7-I('-A;&%S86YA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y-PIM<V=I9"`B4F5U;FEO;B(*;7-G<W1R(")2975N:6]N(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R
M(")086QA=71A(&%S971U:W-E="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,S4*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R
M(")2:6-H(%1E>'0@161I=&]R:6X@87-E='5K<V5T(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4X"FUS9VED(")2:61D;&5S(@IM<V=S='(@(D%R=F]I
M='5K<V5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0X"FUS9VED(")2:6=H="(*;7-G<W1R(")/:6ME82(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,#<*;7-G:60@(E)I9VAT(&AE
M861E<B(*;7-G<W1R(")/:6ME82!O='-A:V4B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,3`S"FUS9VED(")2:6=H="!V86QU97,B"FUS9W-T<B`B
M3VEK96$@87)V;W0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN
M+B(*;7-G<W1R(")2:79I7VX@=&EE9&]T+BXN(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G
M<W1R(")2;V]L:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3@*;7-G:60@(E)O;6%N:6$B"FUS
M9W-T<B`B4F]M86YI82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,C8*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B2^3D
M;F[D(#$X,"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR,C,*;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@(DODY&YNY"!V
M87-T87#D:7;DY&XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C(Y"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`B2^3D
M;F[D(&UY]G3D<.1I=N3D;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0<F]P97)T:65S
M(@IM<V=S='(@(E)I=FEN('1I961O="(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P<F]P
M97)T:65S(@IM<V=S='(@(E)I=FEN('1I961O="(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*
M;7-G<W1R(")2:79I=#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4S"FUS9VED(")2=6QE<R(*;7-G<W1R(")6
M:6EV;VET:6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W
M965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(E9I:79O:71I;B!N
MY&MY>2!K86EK:VEE;B!R:79I96X@:F$@<V%R86MK96ED96X@=N1L:6QLY"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN
M<R!O;FQY(@IM<V=S='(@(E9I:79O:71I;B!NY&MY>2!V86EN('-A<F%K:V5I
M9&5N(';D;&EL;.0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(')O=W,@;VYL>2(*;7-G<W1R(")6:6EV;VET:6X@;N1K>7D@=F%I
M;B!R:79I96X@=N1L:6QLY"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C$*
M;7-G:60@(E)U;B(*;7-G<W1R(")3=6]R:71A(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y.0IM
M<V=I9"`B4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(E9E;N1JY&X@1F5D
M97)A=&EI=FEN96X@=&%S879A;'1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,`IM<V=I9"`B
M4G=A;F1A(@IM<V=S='(@(E)U86YD82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI
M8R!3:6=N871U<F4B"FUS9W-T<B`B4R]-24U%(&MR>7!T;V=R86%F:6YE;B!A
M;&QE:VER:F]I='5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*;7-G
M<W1R(")3+TU)344@<V%L871T=2!V:65S=&DB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W-A<VPN<&AP.C@Q"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N
M(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(E-!4TPM875T96YT:6MO:6YT
M:2!E:2!O;&4@:^1Y=&5T=.1V:7-SY"XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-3`V"FUS9VED(")335,@365S<V%G:6YG(@IM<V=S='(@(E--
M4R!496MS=&EV:65S=&ET(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS
M9VED(")344P@4VAE;&PB"FUS9W-T<B`B4U%,+6MO;65N=&]T=6QK:VDB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<X"FUS9VED(")344P@<W1A
M=&5M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(E-13"UL875S92!A
M<G9O:F5N(&AA:V5M:7-E96XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#,S"FUS9VED(")34T@B"FUS9W-T<B`B4U-((@H*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H
M<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R(")/3DY)4U1522(*"B,Z(&QI
M8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R(")37U%,
M+6MO;65N=&]T=6QK:VDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")382(*;7-G<W1R(")L82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#<*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R(")386EN="!(
M96QE;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S$*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.
M979I<R(*;7-G<W1R(")386EN="!+:71T<R!J82!.979I<R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S.0IM<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B4V%I;G0@3'5C:6$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@Y"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E
M;&]N(@IM<V=S='(@(E-A:6YT(%!I97)R92!J82!-:7%U96QO;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-#0*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I
M;F5S(@IM<V=S='(@(E-A:6YT(%9I;F-E;G0@:F$@1W)E;F%D:6EN:70B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS
M9VED(")386UE(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B4V%M86%N(&ME:'EK
M<V5E;B`H7W-E;&8I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,0IM<V=I9"`B4V%M;V$B"FUS
M9W-T<B`B4V%M;V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$R"FUS9VED(")386X@36%R:6YO
M(@IM<V=S='(@(E-A;B!-87)I;F\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V"FUS9VED(")3
M86\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B4V%O(%1O;64@:F$@4')I
M;F-I<&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS
M9VED(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B4V%T96QL:6ET=&D@
M<&%L=F5L=6YT87)J;V%J82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$*;7-G:60@(E-A=61I
M($%R86)I82(*;7-G<W1R(")3875D:6$@07)A8FEA(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]L87EO=70N:6YC.CDY"FUS9VED(")3879E(@IM<V=S='(@(E1A
M;&QE=&$B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U
M"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(E1A
M;&QE=&$@7"(E<UPB(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR
M,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R(")486QL
M971A("5S(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B
M4V%V92!/<'1I;VYS(@IM<V=S='(@(E1A;&QE=&$@87-E='5K<V5T(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-PIM<V=I9"`B(@HB4V%V92!G96YE
M<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S
M97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R("(B"B)4
M86QL971A(&QU;V1U="!A<V5T=6MS970@4$A0+7-K<FEP=&ENY"!P86QV96QI
M;65S:2!VY&QI86EK86ES:&%K96UI<W1O;VXN("(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E1A;&QE=&5T=&EI;B`E<SIN(&%S
M971U:W-E="XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U<&=R861E('-C<FEP="!T
M;SH@7"(E<UPB+B(*;7-G<W1R(")!<V5T=7-T96X@<.1I=FET>7-S:W)I<'1I
M(&]N('1A;&QE=&5T='4@<&%I:VMA86XZ(%PB)7-<(BXB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,0IM<V=I9"`B4V-A='1E
M<F5D(%0M4W1O<FUS(@IM<V=S='(@(DAA:F%N86ES:6$@=6MK;W-M>7)S:WEJ
MY"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC
M92(*;7-G<W1R(")4:65D92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI
M<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS
M9VED(")396%R8V@B"FUS9W-T<B`B2&%K=2(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS,C(*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@
M(DAA:W5K;VYE970B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.34Y
M"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B5F%L:71S92!T:65D;W-T
M;W0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#@U"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(E9A;&ET<V4@<.1I
M=N1MY.1RY"(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX"FUS
M9VED(")396QE8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B5F%L:71S92!L
M:7/D='3D=N0@<GEH;>0B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C0S"FUS9VED(")396QE8W0@82!N97<@;W=N97(B"FUS9W-T<B`B5F%L:71S
M92!U=7-I(&]M:7-T86IA(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C8P"FUS9VED(")396QE8W0@82!S97)V97(B"FUS9W-T<B`B5F%L:71S
M92!P86QV96QI;B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,34V
M"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*;7-G<W1R(")686QI='-E
M(&QI<^1T=.1VY"!KY'ET=.1JY"(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HV-S8*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T
M<B`B5F%L:71S92!K86EK:VDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-C0W"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS
M9W-T<B`B5F%L:71S92!K86EK:VD@<.1I=N1MY.1RY&MO;7!O;F5N=&ET(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM
M<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R(")686QI='-E(&]B:F5K
M=&DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-C<W"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R(")4>6AJ96YNY"!V86QI
M;G1A(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W"FUS9VED("(B"B)3
M96QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@
M8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R
M;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B(@HB5F%L:71S92!T87)V:71T
M879A="!M97)K:70@86QL82!O;&5V:7-T82!V86QI:V]I<W1A+B!6;VET('-E
M;B!JY&QK965N("(*(FMO<&EO:61A(&IA(&QI:71TY.0@;65R:VET('1E:W-T
M:6ES:2XB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B
M4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`B5F%L:71S92!P
MY&EVY'EK<V5N(&5R;W1I;FUE<FMK:3HB"@HC.B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT-`IM<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS
M9W-T<B`B5F%L:71S92!PY&EVY'EK<V5N(&5S:71Y<W1A<&$Z(@H*(SH@=&5M
M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L
M96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@
M(E9A;&ET<V4@;75U=&5T=&%V82!P<F]F:6EL:3HB"@HC.B!T96UP;&%T97,O
M9&%T82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM
M:71E<CHB"FUS9W-T<B`B5F%L:71S92!K96QL;VYA:F%N(&5R;W1I;FUE<FMK
M:3HB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L
M96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`B5F%L:71S92!A:F%N(&5S
M:71Y<W1A<&$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-PIM
M<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N(@IM<V=S='(@(E9A
M;&ET<V4@:V%K<VD@>6AT965N<V]P:79A82!K96YT=.3D+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS,3`*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R
M('-C:&5M92XB"FUS9W-T<B`B5F%L:71S92!VY')I=&5E;6$N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(U,@IM<V=I9"`B4V5L96-T('EO=7(@<')E
M9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R(")686QI='-E(&OD>71E='3D=N0@
M:VEE;&DZ(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*
M;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B3.1H973D(&]N
M9V5L;6%V:65S=&DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3`T,@IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B3.1H973D
M(%--4R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,3,*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B
M4V5N96=A;"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(S"FUS9VED(")3
M96YS;W(Z("(*;7-G<W1R(")4=6YN:7-T:6XZ("(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,3`*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B
M"FUS9W-T<B`B<WEY<VMU=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS
M9W-T<B`B4V5R8FEA(&IA($UO;G1E;F5G<F\B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C<P,@IM<V=I9"`B4V5R:6%L($YU;6)E<B(*
M;7-G<W1R(")387)J86YU;65R;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-#D*;7-G:60@(E-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A
M=F%I;&%B;&4N(@IM<V=S='(@(E!A;'9E;&EM96X@=&EE9&]T(&]V870@=N3D
M<FGD('1A:2!E:7;D="!O;&4@:^1Y=&5T=.1V:7-SY"XB"@HC.B!A9&UI;B]S
M97-S:6]N<RYP:'`Z,C<*;7-G:60@(E-E<W-I;VX@061M:6XB"FUS9W-T<B`B
M27-T=6YT;VIE;B!H86QL:6YT82(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E
M>'!I<F5D+B(*;7-G<W1R(")397-S:6]N($E$(&]N('9A;FAE;G1U;G5T+B(*
M"B,Z(&QI8B]A<&DN<&AP.C$T-0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B
M27-T=6YN;W0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$X"FUS
M9VED(")3970B"FUS9W-T<B`B07-E=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-SD*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R
M97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB"FUS
M9W-T<B`B(@HB4V%L87-A;F%N(')E<V5T;VEN=&EI;B!L:6ET='EV:>0@87-E
M='5K<VEA+"!J;W,@:F]S:W5S('5N;VAD870@<V%L87-A;F%S:2XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$X"FUS9VED(")3970@=7`@<F5M;W1E
M('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O
M<G1A;"XB"FUS9W-T<B`B(@HB5F]I="!A<V5T=&%A('5L:V]I<W1E;B!P86QV
M96QI;6EE;B!A<V5T=6MS970L(&IO:71A(&AA;'5A="!KY'ET=.3D("(*(G!O
M<G1A86QI<W-A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-PIM<V=I
M9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@
M9&%T92!O<'1I;VYS+B(*;7-G<W1R("(B"B)6;VET(&%S971T86$@:^1Y=&5T
M=.1VY&X@:VEE;&5N+"!A:6MA=GGV:'EK:V5E;B!J82!M=6ET82!PY&EVY&WD
MY'+D87-E='5K<VEA+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#$*
M;7-G:60@(B(*(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R
M('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA
M>2!O<'1I;VYS+B(*;7-G<W1R("(B"B)6;VET(&%S971T86$@86QO:71U<V]H
M:F5L;6%N+"!VY')I=&5E;6%N+"!NY&MY;>1N('#D:79I='EK<V5N(&IA(&UU
M:71A("(*(F[D:WEMY.1N(&QI:71T>79IY"!A<V5T=6MS:6$N(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-PIM<V=I9"`B4V5T=7`B"FUS9W-T<B`B
M07-E;FYU<R(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL
M.C,W"FUS9VED(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM
M<V=S='(@(D%S96YN=6MS96X@<.1I=FET>7-S:W)I<'1I(&]N('-A871A=FEL
M;&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<U"FUS9VED
M(")3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T
M97(Z("(*;7-G<W1R(")5<V5A="!P86EK870@<V]P:79A="!A;FYE='1U=6X@
M<&%R86UE=')I:6XZ("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#,*;7-G:60@(E-E>6-H96QL
M97,B"FUS9W-T<B`B4V5Y8VAE;&QI="(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT.3@*;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@(D]S=&]K<V5T
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@
M(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`B3'EH>70@:W5V875S.B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT-3`*;7-G:60@(E-H;W5L9"!A8V-E<W,@
M:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R(")!<V5T
M971A('!I:V%V86QI;G1A;N1P<.1I;65T('5S96EM;6EL;&4@;&EN:V5I;&QE
M+B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(S('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3$S('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS
M9VED(")3:&]W(@IM<V=S='(@(D[D>73D(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$U-0IM<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N
M(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B).Y'ETY"!E<F]A=F%I<W5U9&5T
M(&%S971U:W-I96X@=&%L;&5T971U<W-A(&IA('5U9&5S<V$@:G5U<FD@;75O
M:V%T=7-S82`B"B)V97)S:6]S<V$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0Y-`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G
M:6YG(&EN/R(*;7-G<W1R(").Y'ETY"!E9&5L;&ES96X@<VESY.1N:VER:F%U
M='5M:7-E;B!PY&EVY'ES+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$W-CD*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS
M9W-T<B`B3N1Y=.0@87-E='5S('!I=.3D:W-E<VD@86QK=7!E<N1I<V5N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<Y.0IM<V=I9"`B4VAO=R!P
M:6-K97(B"FUS9W-T<B`B3N1Y=.0@=F%L:71S:6XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3,P"FUS9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@
M;65N=2!B87(_(@IM<V=S='(@(D[D>73D('1A=6QU:VMO=&]I;6EN;F]T('9A
M;&EK:V\N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/R(*
M;7-G<W1R(").Y'ETY"!V87-E;6UA;&QA("5S('9A;&EK:V\N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y
M"FUS9VED(")3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G
M(@IM<V=S='(@(D[D>73D('1A=6QU:V]N('-O;'5N('1I961O="!D:6%L;V=I
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I
M86QO9R(*;7-G<W1R(").Y'ETY"!T875L=6MO;B!T:65D;W0@9&EA;&]G:2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV,`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@
M9&EA;&]G(@IM<V=S='(@(D[D>73D('1A=6QU:V]N(')I=FEN('1I961O="!D
M:6%L;V=I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4R"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T
M:65S(&1I86QO9R(*;7-G<W1R(").Y'ETY"!K=79A;B!T:65D;W0@9&EA;&]G
M:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C<*;7-G:60@(E-H
M;W<@=7!L;V%D(@IM<V=S='(@(D[D>73D('1U;VYT:2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED(")3:&]W97)S
M(@IM<V=S='(@(E-A=&5I=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R
M(")3871E:71A(&%I:V%I<VEN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-30*;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G<W1R
M(")3871E:71A(&UY]FAE;6UI;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I
M;FET>2(*;7-G<W1R(")3871E:71A(&SD:&5T='EV:6QL82(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C$Y"FUS9VED
M(")3:')I;FLB"FUS9W-T<B`B4&EE;F5N;N0B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.CDQ,`HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.CDW,@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$P-3@*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,3(P"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3$X
M,PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C$R,C,*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HQ,C4R"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z,3(X-0IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R
M:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(E!I
M96YE;F[D('1A:2!S:6ER<N0@=FEE<F5I<VGD(&]S:6]I=&$L(&IO='1A(&YE
M(&5I=N1T(&]L92!T:65L;.0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Q"FUS9VED(")3:65R
M<F$@3&5O;F4B"FUS9W-T<B`B4VEE<G)A($QE;VYE(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V-@IM<V=I9"`B4VEG;B!U<"(*;7-G
M<W1R(")+:7)J875D=2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-S$S"FUS9VED(")3:6=N871U<F4B"FUS9W-T<B`B06QL96MI<FIO
M:71U<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$R
M"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S='(@(D%L;&5K:7)J
M;VET=6MS96X@86QG;W)I=&UI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-@IM<V=I9"`B4VEN
M9V%P;W)E(@IM<V=S='(@(E-I;F=A<&]R92(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C4@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HX-`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDP,`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$Y(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R-#$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(U,"!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3$V"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,Q,#D*;7-G:60@(E-I>F4B"FUS9W-T<B`B2V]K;R(*"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4R"FUS
M9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S='(@(D]H:71A('EL;.1P:71O
M=&5H=.1VY'0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$P"FUS9VED(")3;&]V86MI82(*;7-G
M<W1R(")3;&]V86MI82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#@*;7-G:60@(E-L;W9E;FEA
M(@IM<V=S='(@(E-L;W9E;FEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-38*;7-G:60@(E-N;W<B"FUS9W-T<B`B3'5M:2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS
M9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R("),=6UI<V%D971T82(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")3
M;F]W(%-H;W=E<G,B"FUS9W-T<B`B3'5M:7-A=&5I=&$B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.0IM<V=I9"`B4VYO=R!3
M:&]W97)S($5A<FQY(@IM<V=S='(@(DQU;6ES871E:71A(&%I:V%I<VEN(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G
M:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(DQU;6ES871E:71A(&UY
M]FCDY&XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X-0IM<V=I9"`B4VYO
M=R!D97!T:#H@(@IM<V=S='(@(DQU;65N('-Y=GEY<SH@(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR.#D*;7-G:60@(E-N;W<@97%U:79A;&5N="!I;B!W
M871E<CH@(@IM<V=S='(@(DQU;65N(&WDY'+D('9E=&5NY#H@(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P,@IM<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(E-A;&]M
M;VX@<V%A<F5T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-`IM<V=I9"`B4V]M86QI82(*;7-G
M<W1R(")3;VUA;&EA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS
M9VED(")3;VYG<R`F(%!O96US(@IM<V=S='(@(DQA=6QU="!J82!2=6YO=7,B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3$R"FUS9VED(")3;W)T
M(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R(")*Y')J97-T>6MS96X@<W5U;FYA
M;B!V86QI;G1A(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C$W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(T-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C$V-@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C$X.0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS
M9W-T<B`B3.1H9&5O<V]I=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4U"FUS9VED(")3;W5T
M:"!!9G)I8V$B"FUS9W-T<B`B171E;.0M069R:6MK82(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DS"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X
M-3DM,RDB"FUS9W-T<B`B171E;.0M175R;V]P<&$@*$E33RTX.#4Y+3,I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`Q"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U
M=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R(")%=&5LY"U'96]R9VEA(&IA
M(&5T96SD:7-E="!386YD=VEC:"!S86%R970B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R
M;B!(96UI<W!H97)E(@IM<V=S='(@(D5T96SD:6YE;B!P86QL;VYP=6]L:7-K
M;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$S"FUS9VED(")3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM<V=S
M='(@(E;D;&D@=FEE<F5I<V5T('-O;'5J96X@=N1L:7-SY"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3
M<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S
M='(@(E;D;&D@<V]L=6X@;&5I<.1T96MS=&EN(&IA(')E=6YA;B!VY&QI<W/D
M("(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Q.0IM<V=I9"`B4W!A
M8V5R(@IM<V=S='(@(E;D;&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*;7-G:60@(E-P86-I;F<B"FUS9W-T
M<B`B5N1L:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I;F<@86YD('!A9&1I;F<B"FUS
M9W-T<B`B5N1L:2!J82!TY'ET92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@P"FUS9VED(")3<&%I
M;B(*;7-G<W1R(")%<W!A;FIA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$P,`IM<V=I9"`B4W!A;2(*;7-G<W1R(")2;W-K87!O<W1I(@H*(SH@
M<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C:6%L($-H87)A
M8W1E<B!);G!U="(*;7-G<W1R(")%<FEK;VES;65R:VMI96X@<WGV='3V(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R(")*86$@<V]L=2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C8*;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R(")*86$@<V%R86ME(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S='(@(DIA82!R:79I(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Q"FUS9VED(")3<&]R=',B"FUS9W-T
M<B`B57)H96EL=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,0IM<V=I9"`B4W)I($QA;FMA(@IM
M<V=S='(@(E-R:2!,86YK82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#$@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8V"FUS9VED(")3=&%N9&%R
M9"(*;7-G<W1R(")3=&%N9&%R9&DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*;7-G<W1R(")3=&%R(%1R96LB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DP(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(W.34*;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B06QK
M86UI<W9U;W-I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU-S$*;7-G:60@(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(DSDY&YI
M('1A:2!A;'5E(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT
M;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G<W1R(")4:6QA(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C@P,0IM<V=I9"`B4W1O<F%G92!F;W)M870B
M"FUS9W-T<B`B5&%L;&5N;G5S;75O=&\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4W,PIM<V=I9"`B4W1R965T($%D9')E<W,B"FUS
M9W-T<B`B2V%T=6]S;VET92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T
M<B`B3.1P:6QY]FYT:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M,S<*;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@(DUE<FMK:6IO;F]L:7-T
M82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S<*;7-G:60@(E-T
M<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@(E!O:7-T82!T
M;VEM:6%L=64@;W-O:71T965S=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(S"FUS9VED(")3='EL92!;0U-3
M72(*;7-G<W1R(")4>7EL:2!;0U-372(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@(E-U(@IM<V=S='(@(G-U
M(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L('!H<"UF;W)M870*
M;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R
M(")!;&EH86ME;6ES=&]A(%PB)7-<(B!E:2!L]GET>6YY="XB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S"FUS9VED(")3
M=6)J96-T(@IM<V=S='(@(D]T<VEK:V\B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,S8@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z
M,S$W"FUS9VED(")3=6)M:70B"FUS9W-T<B`B3.1H973D(@H*(SH@<VEG;G5P
M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q
M=65S="!T;R!A9&0@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@
M;&]G(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E
M9"XB"FUS9W-T<B`B(@HB3.1H971E='1I:6X@7"(E<UPB.FX@;&ESY'ES<'EY
M;G3V+B!%="!V;VD@:VER:F%U='5A('-I<^3D;B!E;FYE;B!K=6EN("(*(G!Y
M>6YT]G-I(&]N(&OD<VET96QT>2!J82!H>7;D:W-Y='1Y+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U
M8G-C<FEP="(*;7-G<W1R(")!;&EK:7)J;VET=7,B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3`U"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B
M"FUS9W-T<B`B3VYN:7-T=6DB"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O
M('1H92!S>7-T96TN(@IM<V=S='(@(EPB)7-<(CH@;&ESY.1M:6YE;B!JY')J
M97-T96QMY.1N(&]N;FES='5I+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A
M(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(DOD
M>71TY&KD;B!<(B5S7"(@:^1Y='3D:N1T:65T;VIE;B!P;VES=&%M:6YE;B!J
MY')J97-T96QMY'-TY"!O;FYI<W1U:2XB"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R(")<
M(B5S7"(@<&]I<W1E='1I:6X@;VYN:7-T=6YE97-T:2XB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B7"(E
M<UPB.B!O;FYI<W1U='1I:6X@<&]I<W1A;6%A;B!JY')J97-T96QMY'-TY"XB
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S
M9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C
M:&%N9V5S+B(*;7-G<W1R("(B"B)086QA='1I:6X@;VYN:7-T=6YE97-T:2!V
M86YH;VEH:6X@87-E='5K<VEI;BX@3&%T86$@<VEV=2!U=61E<W1A86X@(@HB
M;N1H9.1K<V5S:2!M=75T;VMS970N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z-3<@861M:6XO<V5T=7`O:6YD97@N<&AP.C4Y"FUS9VED(")3=6-C
M97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(E1A;&QE;FYE='1I:6X@87-E='5K<VEE;B!V87)M=75S:V]P:6\N(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N
M(&9I;&4@)7,N(@IM<V=S='(@(E1A;&QE;FYE='1I:6X@87-E='5K<VEE;B!V
M87)M=75S:V]P:6\@)7,N(@H*(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*
M;7-G<W1R("(G)7,G.B!PY&EV:71Y<R!O;FYI<W1U:2XB"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS
M9W-T<B`B)7,Z;B!K:7)J;VET=&%M:6YE;B!O;FYI<W1U:2XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`T"FUS9VED(")3=61A;B(*;7-G<W1R(")3=61A;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*;7-G
M:60@(E-U;6UA<GDB"FUS9W-T<B`B66AT965N=F5T;R(*"B,Z(&QI8B]";&]C
M:R]S=6YR:7-E+G!H<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B075R
M:6YG;VYN;W5S=2(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV.`IM<V=I
M9"`B4W5N(%-E="(*;7-G<W1R(")!=7)I;F=O;FQA<VMU(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E-U;FYY
M(@IM<V=S='(@(D%U<FEN:V]I;F5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(P-0IM<V=I9"`B4W5N<FES92(*;7-G<W1R(")!=7)I;F=O
M;FYO=7-U(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K
M+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R
M(")!=7)I;FMO(&YO=7-E92]L87-K964B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C`T"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B075R
M:6YG;VYN;W5S=3H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(P.`IM<V=I9"`B4W5N<V5T(@IM<V=S='(@(D%U<FEN9V]N;&%S:W4B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`W"FUS9VED(")3=6YS
M970Z("(*;7-G<W1R(")!=7)I;F=O;FQA<VMU.B`B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S"FUS9VED(")3=7!E<G-C
M<FEP="(*;7-G<W1R(")0Y.1L;&5K:7)J;VET=7,B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S@P"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(E1U
M:VDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$U"FUS9VED(")3=7)I;F%M92(*;7-G<W1R(")3
M=7)I;F%M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-S4*;7-G:60@(E-U<FYA;64B"FUS9W-T<B`B4W5K=6YI;6DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`Y"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@
M(DAU:7!P=79U;W)E="!J82!*86X@36%Y96XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y"FUS
M9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`B4W=A>FEM86$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`U"FUS9VED(")3=V5D96XB"FUS9W-T<B`B4G5O='-I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-38*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S='(@(E-V96ET<VDB"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@IM<V=I9"`B4WEN8R!L;V<@
M9&5L971E9"(*;7-G<W1R(")3>6YC(&QO:VD@<&]I<W1E='1U(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$T-0IM<V=I9"`B4WEN8TU,(@IM<V=S='(@
M(E-Y;F--3"(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HY
M-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R
M(")3>6YT86MS:79I<FAE(&AA:W5T97)M96ES<^0B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$X
M"FUS9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*;7-G<W1R(")3>7ER:6$L
M(&%R86)I=&%S879A;'1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E0M4W1O<FTB"FUS9W-T<B`B56MK;W-M
M>7)S:WDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV,PIM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B56MK;W-M
M>7)S:WEJY"!J82!T=75L:7-T82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R(")5
M:VMO<VUY<G-K>70B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV-0IM<V=I9"`B5"U3=&]R;7,@16%R;'DB"FUS9W-T<B`B56MK
M;W-M>7)S:WEJY"!A:6MA:7-I;B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O
M='-V+G!H<#HQ-C8*;7-G:60@(E135B!F:6QE(@IM<V=S='(@(E135BUT:65D
M;W-T;R(*"B,Z(&9R86UE=V]R:R]522]522]486)L92YP:'`Z,3,T"FUS9VED
M(")486)L92(*;7-G<W1R(")4875L=6MK;R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE
M(%!R;W!E<G1I97,B"FUS9W-T<B`B5&%U;'5K;VX@=&EE9&]T(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PIM<V=I9"`B
M5&%B;&4@4V5T(@IM<V=S='(@(E1A=6QU:V]N(&%S971U:W-E="(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*
M;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS9W-T<B`B5&%U;'5K;VX@=&EE
M9&]T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,2!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-`IM<V=I9"`B5&%I=V%N(@IM<V=S
M='(@(E1A:7=A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM<V=S
M='(@(E1A:7=A;BP@2VEI;F%N(&UA86MU;G1A(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-0IM
M<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R(")4861Z:6MI<W1A;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,S4*;7-G:60@(E1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8B
M"FUS9W-T<B`B5&%N>F%N:6$L(%EH9&ES='EN>70@=&%S879A;'1A(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I
M9"`B5&%R9V5T.B(*;7-G<W1R(")+;VAD93HB"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.CDS,B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@Y
M"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#0Y"FUS9VED(")487-K<R(*
M;7-G<W1R(")496ATY';D="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3<T"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@
M(E!U:&5L:6YN=6UE<F\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-PIM
M<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B3.1M</9T:6QA
M(&5D96QL:7-E;&QE('1U;FYI;&QE.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(R,0IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B3.1M</9T:6QA
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,@IM<V=I9"`B
M5&5M<&5R871U<F4Z("(*;7-G<W1R("),Y&UP]G1I;&$Z("(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<R(*
M;7-G<W1R("),Y&UP]G1I;&$\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE
M<R(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-CDU"B,L
M('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N
M(@IM<V=S='(@(DUA;&QI82!<(B5S7"(@96D@;/9Y='EN>70N(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T
M<F%T:6]N(@IM<V=S='(@(DUA;&QI96X@:&%L;&EN=&$B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C$U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,S,S$*;7-G:60@(E1E>'0B"FUS9W-T<B`B5&5K<W1I(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,W.0IM<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@
M(E9A:6X@=&5K<W1I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW-`IM<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R
M(")496MS=&EN('1A<V%U<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`B5&5K
M<W1I=&]P(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T<B`B=&\B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B
M5&AA:2`H5$E3+38R,"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(T"FUS9VED(")4:&%I;&%N
M9"(*;7-G<W1R(")4:&%I;6%A(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX-3$*;7-G:60@(E1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I
M;&%B;&4N(@IM<V=S='(@(D944"UL:7/D=&]I;6EN=&\@96D@;VQE(&OD>71E
M='3D=FES<^0N(@H*(SH@9G)A;65W;W)K+TAI<W1O<GDO2&ES=&]R>2YP:'`Z
M-34*;7-G:60@(E1H92!(:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"XB"FUS
M9W-T<B`B2&ES=&]R>2!JY')J97-T96QMY"!E:2!O;&4@:^1Y=&5T=.1V:7-S
MY"XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG
M:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO
M;&%B(&EN=&5G<F]I;G1I;6]O='1O<FD@96D@='5E(%PB)7-<(B(*"B,Z(&9R
M86UE=V]R:R].971?24U34"])35-0+T)O;VLN<&AP.C$R.3@*;7-G:60@(E1H
M92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@
M(DE-4U`@;&]K:6$@96D@=F]I='4@86QU<W1A82XB"@HC.B!S97)V:6-E<R]M
M86EN=&5N86YC92YP:'`Z,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L
M87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B36%I;G1E
M;F%N8V4Z.B`M;'5O:V%N(&QA=&%A;6EN96X@97#D;VYN:7-T=6DB"@HC.B!S
M97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@
M3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B
M07-E='5K<V5T(&EK:W5N82!O;B!S=6QJ971T=2X@4&]I<W1U=&%A;BXB"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$X.2!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C(P,`HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C(Q,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(R,PHC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C(S-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C(U,@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(V-"!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,P,PIM<V=I9"`B(@HB5&AE(&%D;6EN
M:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI
M<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI<W-I
M;VYS+B(*;7-G<W1R("(B"B)9;&SD<&ED;VX@<&ETY.0@;W1T86$@:^1Y='3V
M]FX@<'ES>7;D('1A;&QE='5S='EY<'!I(%!E<FUI<W-I;VXL(&IO<R!H86QU
M870@(@HB:^1Y='3DY"!N:6ETY"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M
M('-I9&4@;VYL>2(*;7-G<W1R(")686EN(&%L87!U;VQI(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@
M(B(*(E1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@
M;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S
M92XB"FUS9W-T<B`B(@HB0V]N=&%C="!I9"!N=6UE<F]A(&5I(&]L92!MY.1R
M:71E;'1Y+"!O;B!T>6AJY"!T86D@96D@;/9Y='EN>70@=&EE=&]K86YN87-T
M82XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M-3$*;7-G:60@(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@
M=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(EEH=&5Y<W1I961O="!L
M:7/D='1I:6X@;VYN:7-T=6YE97-T:2!O<V]I=&5K:7)J86%S:2XB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3<R"FUS9VED("(B"B)4
M:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T
M;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"B)6:65S
M=&EN(&%L;&5K:7)J;VET=6MS96X@=&%R:VES=&%M:7-E96X@=&%R=FET86%N
M(&5R:6QL:6YE;B!01U`M(@HB86QL96MI<FIO:71U<VQO:&MO+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS
M9VED("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N
M;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T
M:&4@9&%T86)A<V4N(@IM<V=S='(@(B(*(DIA:V5L=6QI<W1A;B!)1"!E:2!O
M;&QU="!MY.1R:71E;'1Y+"!O;B!T>6AJY"!T86D@96D@;/9Y='EN>70@=&EE
M=&]K86YN87-T82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T
M('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R(")*86ME;'5L:7-T86$@96D@
M;VQL=70@;>3D<FET96QT>2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N
M<&AP.C$Q-@IM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER
M92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B4V%L875S=&]I
M;6EN;F]N(&OD>71T]B!V86%T:2!S86QA='1U82!75U<M>6AT97ET=.0N(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S<@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HU,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I
M;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R(")4
M:65D;W-T;W-S82`E<R!P:73D:7-I(&]L;&$@)7,@87-E='5S+B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<P(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z-3`Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S
M('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(E1I
M961O<W1O<W-A("5S('!I=.1I<VD@;VQL82!J;VET86MI;B`E<R!A<V5T=6MS
M:6$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C(V"FUS9VED
M(")4:&4@9FEL92!C86YN;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+B(*;7-G
M<W1R(")4:65D;W-T;V$@96D@=F]I9&$@:V]P:6]I9&$@:71S96YSY"!PY.1L
M;&4N(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,C@P"FUS9VED(")4
M:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B5&EE9&]S=&\@
M;VQI('1Y:&KD+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D
M97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@
M(E-E=7)A879A<W-A(&]N(&]T<VEK:V]T:65D;W0@=.1S=.0@;65S<V%G92]R
M9F,X,C(@+79I97-T:7-TY"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@
M;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T
M($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R
M96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC
M92`B"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N
M<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@
M<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO
M=2=L;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@
M;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0
M;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H
M92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*(DMO:V]R=75D=6X@
M;N1Y='3V=&EL82!A:6AE=71T86$@;VYG96QM:6$@:F]I;&QA:VEN($EN=&5R
M;F5T($5X<&QO<F5R("(*(G-E;&%I;65N(&OD>71TY&II;&SD+B!686QI=&5T
M=&%V87-T:2!K>7-E:6YE;B!S96QA:6X@<VESY&QTY.0@<&EI<G1E:73D(&IA
M("(*(G9I<FAE:73D(&IO:6AI;B!E:2!O;&4@;/9Y='EN>70@:V]R:F%U<W1A
M('1A:2!K96EN;V$@:VEE<G3DY"!O;F=E;&UA+B`B"B)(=6]M86%T:&%N(&5T
M=.0@:F]S(&OD>73D="!TY'3D(&[D>71T]G1I;&%A(&IA($EN=&5R;F5T($5X
M<&QO<F5R('-E;&%I;G1A+"`B"B)N:6EN(&[D>71T]B!S86%T=&%A(&UE;F[D
M('-E:V%I<VEN+"!J;W1K=70@=&]I;6EN;F]T(&5I=N1T('1O:6UI('1A:2!S
M96QA:6X@(@HB<V%A='1A82!K86%T=6$N($IO<R!KY'ETY'0@5VEN9&]W<R`Y
M>"!T86D@344@=F5R<VEO=&$L(&YI:6X@;VX@;6%H9&]L;&ES=&$@(@HB971T
MY"!KY'ET=/9JY')J97-T96QMY"!K86%T=74@;G,N("='96YE<F%L(%!R;W1E
M8W1I;VX@1F%U;'0G("UV:7)H965S965N(&IA("(*(G-I;G5N('!I=.3D(&OD
M>6YN:7-TY.0@:V]N92!U=61E<W1A86XN7%QN7%QN($UU:7-T82!E='3D('-I
M;G5A(&]N("(*(G9A<F]I=&5T='4N($YA<'-A=71A($]++6YA<'!U;&%A(&IO
M<R!H86QU870@:V]K96EL;&4@961I=&]R:6X@:V]K;W)U=71U("(*(F[D>71T
M]G1I;&%A+B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HQ,3$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE
M=&5D+B(*;7-G<W1R(")0;VES=&5T=&EI;B!P<F]F:6EL:2!<(B5S7"(N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B
M5F%I;B!V87-E;B!P=6]L:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G50
M1R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA
M<W,N(@IM<V=S='(@(D=N=5!'(&]H:F5L;6%N('-I:F%I;G1I('!I=.3D(&WD
MY')I=&5L;.0@0W)Y<'1?<&=P.CH@+6QU;VMA<W-A+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O341.+G!H<#HR,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@
M7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A
M<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E
M<G-T;V]D+B(*;7-G<W1R("(B"B)6:65S=&D@;.1H971E='1Y("5S('9A<W1A
M86YO='1A:F%L;&4@)7,@;W1S:6MK;VYA(%PB)7-<(B!O;B!NY'ET971T>2Y<
M;B(*(D5I(&]L92!M:73DY&X@=&%K96ET82!S:6ETY"!E='3D('9I97-T:2!O
M;B!L=65T='4@=&%I('EM;>1R<F5T='DN(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@X,0IM<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN
M:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S='(@(DYI;6D@:F]T82!K
MY'ET973DY&X@;&EN:VET971TY&5S<V$@;'5O('-I=G5L;&4B"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-S0*;7-G:60@(E1H92!N=6UB97(@
M;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`B2V5N='1I96X@
M;>3D<N0@<&ETY.0@86YT86$@;G5M97)O:6YA+B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,3(S,@IM<V=I9"`B5&AE(&]P96YS<VP@
M;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z
M.B!C;&%S<RXB"FUS9W-T<B`B36]D=75L:2!O<&5N<W-L('1A<G9I=&%A;B!(
M;W)D95]#<GEP=%]S;6EM93HZ("UL=6]K86X@:^1Y='3D;6ES96MS:2XB"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,N<&AP.C(X,PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E
M('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM
M=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@HB07-E='5S=&$@7"(E<UPB
M(&MO<VMA('-E;B!T:65D;W0@>6QI='1I=N1T('1A;&QE='5S=&%V86X@<W5U
M<FEM;6%N('-A;&QI='5N("(*(G)A:F%N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O9&5B+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E
M("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R("(B
M"B)/:&IE;&UA82P@:F]L;&$@=F]I(&MA='-O82!V:65S=&ET>7EP<&GD("@E
M<RDL(&5I(&SV>71Y;GET(&KD<FIE<W1E;&WD<W3D+B(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C0X-PIM<V=I9"`B5&AE('%U;W1E(&-H87)A
M8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("),
M86EN875S;65R:VMI('!I=.3D(&]L;&$@>6MS:71TY&EN96X@;65R:VMI+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(@IM
M<V=S='(@(E9A:6X@;VEK96$@:F$@=F%S96X@<'5O;&DB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED
M(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B5F%I;B!O:6ME
M82!P=6]L:2(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0W.0IM
M<V=I9"`B5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C
M=&5R+B(*;7-G<W1R(")%<F]T:6X@<&ETY.0@;VQL82!Y:W-I='3D:6YE;B!M
M97)K:VDN(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@
M9&5L971E9"XB"FUS9W-T<B`B4&%L=F5L:6X@7"(E<UPB(&]N('!O:7-T971T
M=2XB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S879E
M9"XB"FUS9W-T<B`B4&%L=F5L:6X@7"(E<UPB(&]N('1A;&QE=&5T='4N(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS
M9W-T<B`B4VESY.1N:VER:F%U='5M:7-P>7EN=/8@)7,@;VX@<&]I<W1E='1U
M+B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP
M:'`Z-#<P"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S<&5C:69I960@<F]W
M("@E9"D@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(DWDY')I=&5L='GD(')I
M=FGD("@E9"D@96D@;VQE(&]L96UA<W-A+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z,3<Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T96UP
M;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(E9A
M;&GD86EK86ES=&EE9&]S=&]A(%PB)7-<(B!E:2!O;&4@;VQE;6%S<V$N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,P-@IM<V=I9"`B5&AE('1E
M>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@
M<V-R965N+B(*;7-G<W1R(")+:7)J;VET=&%M87-I('1E:W-T:2!E:2!V87-T
M86$@=&5K<W1IY"!R=75D=6QL82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED(")4:&4@=&]P(&%N
M9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R(")686EN('ELY'!U;VQI(&IA
M(&%L87!U;VQI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS
M9W-T<B`B5F%I;B!Y;.1P=6]L:2(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N
M<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN
M8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@(E1U;W1U('1I971O(&CD
M=FES:2!E9&5L;&ES96X@:V]H9&%N(&%I:V%N82XB"@HC.B!F<F%M97=O<FLO
M1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R86UE=V]R:R]$871A+T1A=&$O='-V
M+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B
M92!S879E9"XB"FUS9W-T<B`B5'5O='5A('1I961O<W1O82!E:2!V;VET=2!T
M86QL971T86$N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Y
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,3`*;7-G:60@(E1H92!W
M96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")/
M<VEO=&$@=V5A=&AE<BYC;VT@96D@;VQE(&OD>71E='3D=FES<^0N(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B
M5&5E;6%H86ME;6ES=&]A(%PB)7-<(B!E:2!L]GET>6YY="XB"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$W.`IM<V=I9"`B5&AE<F4@87)E
M(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R(")!<V5T=6MS:6$@96D@
M;VQE('-A871A=FEL;&$N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT
M96YT<RYP:'`Z,S0X"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C
M86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B16D@;VQE(&]S:6]I
M=&$L(&IO=&MA('9O:61A86X@;N1Y='3DY"!V:65S=&EE;B!Y:'1E>61E<W/D
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@
M:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S
M.R`B"B)Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*
M(E3D<W/D(&ME;G3D<W/D(&]N(&QI:6%N(&UO;G1A(&UE<FMK:>0N($%N;F]I
M="`E<R!M97)K:VGD.R!S:6YU;B!P:73DY"!A;G1A82`B"B)VY&AE;6WD;B!K
M=6EN("5S(&UE<FMK:>0N(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U<V5R
M+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B
M;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`B
M2F]I=&%K:6X@;VYG96QM:6$@7"(E<UPB(&QI<^3D;6ES97-SY"!JY')J97-T
M96QMY.1N.B`E<R(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@
M9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(B(*
M(DOD>71TY&KD;B!<(B5S7"(@:^1Y='3D:N1T:65T;VIE;B!P;VES=&%M:7-E
M<W-A(&KD<FIE<W1E;&WD<W/D(&]L:2!O;F=E;&UI83H@(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM
M<V=S='(@(DIO:71A:VEN(&]N9V5L;6EA(%PB)7-<(B!P;VES=&%M:7-E<W-A
M(&KD<FIE<W1E;&WD<W3D.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN
M9R!<(B5S7"(Z("5S(@IM<V=S='(@(DIO:71A:VEN(&]N9V5L;6EA(%PB)7-<
M(B!PY&EV:71Y:W-E<W/D.B`E<R(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R
M;W=S97(N<&AP.CDR-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L
M;V%D960N(@IM<V=S='(@(E1I961O<W1O;B!T=6]N;FES<V$@;VQI(&]N9V5L
M;6EA+B!9:'3DY&X@)7,Z82!E:2!T=6]T=2(*"B,Z(&9R86UE=V]R:R]"<F]W
M<V5R+T)R;W=S97(N<&AP.CDS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@
M)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*(F%L;&]W960@<VEZ
M92`H)60@8GET97,I+B(*;7-G<W1R("(B"B)4:65D;W-T;VX@='5O;FYI<W-A
M(&]L:2!O;F=E;&UI82X@)7,@:V]K;R!O;&D@<W5U<F5M<&D@:W5I;B!S=75R
M:6X@<V%L;&ET='4@(@HB:V]K;R`H)60@=&%V=6$I+B(*"B,Z(&9R86UE=V]R
M:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D
M.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R
M(")4:65D;W-T;VX@='5O;FYI<W-A(&]L:2!O;F=E;&UI82X@)7,@;&%T875T
M=6D@=F%I;B!O<V%K<VDN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I
M<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B5&%P86AT=6D@
M=FER:&4@;N1Y=&5T=.1E<W/D('9I97-T:6X@=.1TY"!O<VEO=&$B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N
M(@IM<V=S='(@(EEH=&5Y<W1I971O:F5N('1U;VYN:7-S82!T87!A:'1U:2!V
M:7)H92XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+VEM8RYP:'`Z,S$*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A
M<B!D871A+B(*;7-G<W1R(")I0V%L96YD87(M=&EE=&]J96X@='5O;FYI<W-A
M('1A<&%H='5I('9I<FAE+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M.#(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG
M=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A("(*(G)E<75I
M<F5D(&9I96QD+B(*;7-G<W1R("(B"B)!<V5T=7-T:65T;VQO;6%K:V5E<W-A
M(&]N(&IO:VEN('9I<FAE+B!%:&OD(&KD=&ET(&IO;FMU;B!P86MO;&QI<V5N
M(&MO:&1A;B`B"B)TY'ET=.1MY'1TY"XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S
M(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM
M<V=S='(@(B(*(E1A<&%H='5I('9I<FAE('ER:71E='3D97-SY"!S=6]R:71T
M86$@;W-O:71E:VER:F%T;VEM:6YT;V$N(%ER:73D(&UY]FAE;6UI;B`B"B)U
M=61E<W1A86XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U
M<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN
M(&QA=&5R+B(*;7-G<W1R("(B"B)9:'1E>7-T:65T;VIE;B!PY&EV:71Y:W-E
M<W/D('1A<&%H='5I('9I<FAE+B!9<FETY"!M>?9H96UM:6X@=75D97-T86%N
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M,C(R"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE
M(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*
M;7-G<W1R(")*86ME;'5L:7-T86X@<.1I=FET>6MS97-SY"!T87!A:'1U:2!V
M:7)H92X@67)I=.0@;7GV:&5M;6EN('5U9&5S=&%A;BXB"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#D*;7-G:60@(E1H:7,@
M24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N
M(@IM<V=S='(@(E3D;>0@24U!4"!P86QV96QI;B!E:2!T=64@:V%N<VEO:61E
M;B!J86MA;6ES=&$N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@
M82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`B5.1MY"!T:65D;W-T;R!E
M:2!V86EK=71A(')A<BUT:65D;W-T;VQT82XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R(")4Y&WD
M('1I961O<W1O(&5I('9A:6MU=&$@>FEP+71I961O<W1O;'1A+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,S$*;7-G:60@(E1H:7,@9&]E<R!N
M;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R(")4
MY&WD(&5I('9A:6MU=&$@;VEK96%L=&$@:V]R='1I;G5M97)O;'1A+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X
M-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S
M<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K
M871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T
M<B`B(@HB5.1L;.0@86IU<FEL;&$@=F]I(&SD:&5T=.3D('9I97-T96KD($-L
M:6-K871E;&QI;B`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2`B"B)G871E=V%Y
M('!A;'9E;'5A($A45%`@05!).FQL82XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C$S-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@
M86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH
M='1P.B\O=VEN<&QC+F-O;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE($A45%`@
M05!)(@IM<V=S='(@(B(*(E3D;&SD(&%J=7)I;&QA('9O:2!LY&AE='3DY"!V
M:65S=&5JY"!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2!G871E=V%Y("(*(G!A
M;'9E;'5N(&MA=71T82!(5%10($%023IL;&$N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G:60@(B(*(E1H
M:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@
M=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W
M87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"B)4Y&QLY"!A:G5R
M:6QL82!V;VD@;.1H971TY.0@=FEE<W1E:N0@<VUS,F5M86EL("AH='1P.B\O
M<VUS,F5M86EL+F-O;2D@(@HB9V%T97=A>2!P86QV96QU;B!K875T=&$@2%14
M4"!!4$DZ;&QA+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N
M96ET86QY7W-M='`N<&AP.C@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO
M=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6
M;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU
M;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6
M;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B
M"B)4Y&QLY"!A:G5R:6QL82!V;VD@;.1H971TY.0@=FEE<W1E:N0@5F]D869O
M;F5N(&YU;65R;VEH:6X@4TU44#IL;.0@:^1Y='3D96X@(@HB5F]D869O;F4@
M271A;'D@9V%T97=A>2!P86QV96QU82X@5.1TY"!P86QV96QU82!V;VD@:^1Y
M='3DY"!V86EN(%9O9&%F;VYE("(*(DET86QY("AH='1P.B\O=W=W+C$Y,"YI
M="D@='5N;G5K<VEL;&$N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.3@R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C$*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3`Y,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,3$Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#8@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(V,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,S`Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,#(*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,34V,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.#0S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C(@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`P.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,#,S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P.#(*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U,R!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,C(U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3(@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U-`HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-C0Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,30*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,R!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,S`Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,#D@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@Q-PIM<V=I9"`B5&AI<R!F:65L
M9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B5.1MY"!K96YT=.0@;VX@<&%K;VQL
M:6YE;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#8Y"FUS9VED
M(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S
M='(@(E3D<W/D(&ME;G3D<W/D('!I=.3D(&]L;&$@=F%I;B!K;VMO;F%I<VQU
M:W5J82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#(P"FUS9VED
M(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE
M(&-O;&]N+B(*;7-G<W1R(")4Y'-SY"!K96YTY'-SY"!P:73DY"!O;&QA(&YU
M;65R;VET82!J82!P:6QK:W4M;65R:VME:N0N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3`Y.`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C
M;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B5.1S<^0@:V5N=.1S<^0@
M<&ETY.0@;VQL82!O:W1A86QI;'5K=6IA+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Q,C<*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A(&-O
M;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S
M='(@(B(*(E3D<W/D(&ME;G3D<W/D('!I=.3D(&]L;&$@;&ES=&$@:V]K;VYA
M:7-L=6MU:F$L(&IO=&MA('!I=.3D(&]L;&$@97)O=&5T='4@(@HB<&EL:W5L
M;&$@=&%I(';D;&EL>?9N;FEL;.0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HY.3,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU
M;6)E<BXB"FUS9W-T<B`B07)V;VX@<&ETY.0@;VQL82!N=6UE<F\N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@R,@IM<V=I9"`B(@HB5&AI<R!F
M:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X
M(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R("(B
M"B)4Y'-SY"!K96YTY'-SY"!O;B!VY')I;>3D<FET>7,L(&IO;FMA('!I=.3D
M(&]L;&$@4D="($AE>"!M=6]D;W-S+"`B"B)E<VEM97)K:6MS:2`G(S$R,S1A
M9B<N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z-38U"FUS9VED(")4
M:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@
M(E3D;>0@;&]M86ME(&]N(&IO(&OD<VET96QT>2XB"@HC.B!T96UP;&%T97,O
M:&5L<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES
M("5S+B(*;7-G<W1R(")4Y&WD(&]N("5S+B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z-#8Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@
M:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J
M96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD
M97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI
M<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*
M;7-G<W1R("(B"B)4Y&WD(&]N($MO;&%B($=R;W5P=V%R92!O8FIE:W1I+B!+
M871S;V%K<V5S:2!TY&WD;B!O8FIE:W1I;B!S:6YU;&QA('!I=.3D("(*(F]L
M;&$@<^1H:_9P;W-T:6]H:F5L;6$L(&IO:V$@>6UMY')TY.0@2V]L86(@1W)O
M=7!W87)E(&9O<FUA871T:6$N($QI<W1A("(*(GEH=&5E;G-O<&EV:7-T82!S
MY&AK]G!O<W1I;VAJ96QM:7-T82!L]GET>7D@;W-O:71T965S=&$@)7,B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@
M8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S
M='(@(B(*(E3D;>0@=FEE<W1I(&]N(&MI<FIO:71E='1U(&5R:2!M97)K:7-T
M]FQLY"`H)7,I(&MU:6X@;6EKY"!S:6YU;&QA(&]N("(*(FOD>73V<W/D+B`B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B
M5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(DYU
M;65R;VX@<&ETY.0@;VQL82!VY&AI;G3DY&X@>6MS:2XB"@HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@
M<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*
M;7-G<W1R(")4Y&QLY"!P86QV96QI;65L;&$@96D@=F]I(&%U:V%I<W1A('II
M<"T@=&%I(&=Z:7`M=&EE9&]S=&]J82XB"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O4F5G:7-T<GDN<&AP.C$X.0IM<V=I9"`B5&AI<R!S>7-T96T@:7,@
M8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R(")4Y&WD(&KD<FIE<W1E
M;&WD(&]N('!O:7,@<.3D;'3D+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB
M97(N(@IM<V=S='(@(D%R=F]N('!I=.3D(&]L;&$@;G5M97)O+B(*"B,Z('-E
M<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@
M=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B
M"FUS9W-T<B`B5.1MY&X@:6MK=6YA;B!V;VD@875K86ES=&$@=F%I;B!!<V5T
M=6MS970@:6MK=6YA<W1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E1H=6YD97(B"FUS9W-T<B`B37ER<VMY
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S-@IM<V=I9"`B5&EC
M:V5T<R(*;7-G<W1R(")4:6ME=&ET(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C0R.2!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G
M:60@(E1I;64B"FUS9W-T<B`B06EK82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS.#@*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS9W-T<B`B06IA
M;G-E=7)A;G1A(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W"FUS9VED(")4
M:6UE(&9O<FUA="(*;7-G<W1R(")!:F%N(&5S:71Y<VUU;W1O(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4S-0IM<V=I9"`B5&EM92!S96QE8W1I
M;VXB"FUS9W-T<B`B06IA;B!V86QI;G1A(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,`IM<V=I
M9"`B5&EM;W(M3&5S=&4B"FUS9W-T<B`B5&EM;W(M3&5S=&4B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C(P"FUS9VED(")4:71L92(*;7-G<W1R(")4:71T96QI
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R(")/='-I:VMO("AT
M;V]L=&EP*3HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R(")687-T86%N;W1T86IA(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U-`IM
M<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@
M=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL
M92!C;&EC:VEN9RXB"FUS9W-T<B`B(@HB5F]I9&%K<V5S:2!V86QI=&$@=7-E
M86UP:6$@=F%I:'1O96AT;VIA+"!P:63D($-O;G1R;VPM("A00RD@=&%I($-O
M;6UA;F0M("(*(BA-86,I(&[D<'#D:6YTY"!P;VAJ87-S82!K=6X@;F%P<V%U
M=&%T(&AI:7)E;B!P86EN:6ME='1A+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS,#`*;7-G:60@(E1O9&%Y(@IM<V=S='(@(E3D;N3D;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*
M;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R(").Y'ETY"!(5$U,
M+6SD:&1E:V]O9&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(S"FUS9VED(")4;V=O(@IM<V=S
M='(@(E1O9V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(V"FUS9VED(")4;VME;&%U(@IM<V=S
M='(@(E1O:V5L874B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S`R"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R(")(=6]M96YN82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,CD*;7-G:60@(E1O;F=A(@IM<V=S='(@(E1O;F=A(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]K;VQA8BYP:'`Z,3`T"FUS9VED(")4;V\@;6%N
M>2!I;G9A;&ED(&QO9VEN<R!D=7)I;F<@=&AE(&QA<W0@;6EN=71E<RXB"FUS
M9W-T<B`B(@HB3&EI86X@;6]N=&$@97#D;VYN:7-T=6YU='1A(&MI<FIA=71U
M;6ES>7)I='ES=.0@=FEI;65I<VEM<&EE;B!M:6YU=71T:65N("(*(FMU;'5E
M<W-A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX,0IM<V=I9"`B5&]P(@IM<V=S='(@(EEL]G,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4
M;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@(EEL:6UPY.1N(&ME:'EK<V5E;B`H
M7W1O<"DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R
M86YS;&%T:6]N<R(*;7-G<W1R(")+Y.1N;O9K<V5T(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M,@IM<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G<W1R(")4<FEN:61A
M9"!J82!4;V)A9V\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-SDT
M"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@(E1O<VD@=F%I(&5PY'1O
M<VDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C4W"FUS9VED(")4=2(*;7-G<W1R(")T:2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C@*;7-G
M:60@(E1U;FES:6$B"FUS9W-T<B`B5'5N:7-I82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S$*
M;7-G:60@(E1U<FME>2(*;7-G<W1R(")4=7)K:VDB"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$Y-0IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS
M9W-T<B`B5'5R:VMI("A)4T\M.#@U.2TY*2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<*;7-G
M:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R(")4=7)K;65N:7-T86XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(P"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS
M9W-T<B`B5'5R:W,@:F$@0V%I8V]S('-A87)E="(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S,*
M;7-G:60@(E1U=F%L=2(*;7-G<W1R(")4=79A;'4B"@HC.B!F<F%M97=O<FLO
M0TQ)+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS
M9W-T<B`B2VER:F]I=&$@=F%L:6YT87-I.B`B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C4X"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS9W-T
M<B`B52Y6+B`M:6YD96MS:3H@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM
M<V=I9"`B55),(@IM<V=S='(@(E523"(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@9F]R('EO
M=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B55),
M(&IO:&]N('!A;&%U=&5T86%N('-K<FEP=&EN('-T871U<R!R87!O<G1T:2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3<*
M;7-G:60@(E523#HB"FUS9W-T<B`B55),.B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S<*;7-G
M:60@(E5G86YD82(*;7-G<W1R(")59V%N9&$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,V"FUS
M9VED(")5:W)A:6YE(@IM<V=S='(@(E5K<F%I;F$B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HT,3D*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@
M5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B5D93+6AA:V5M:7-T;V$@96D@=F]I
M='4@;'5K96$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.CDV"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I
M;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R(")+Y'ET=.1JY&X@;&ESY'1I
M971O:F5N(&QI<^1Y<R!E:2!O;FYI<W1U;G5T(&MI<FIA=71U;6ES97-S82XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Y,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&
M4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B16D@=F]I('9A:6AT86$@;VEK975K
M<VEA(%9&4RUT:65D;W-T;VQL92!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,SDR(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P
M97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B16D@=F]I
M('9A:6AT86$@;VEK975K<VEA(%9&4RUT:65D;W-T;VQL92`E<R\E<RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<X-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R(")%:2!V
M;VED82!V86EH=&%A("5S.FXN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K
M(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(E1I961O<W1O;B!<(B5S
M7"(@:V]K;V$@96D@=F]I='4@=&%R:VES=&%A+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C8Y-2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z.#4P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3`R.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE
M(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`B16D@=F]I9&$@;FEM973D('5U9&5L
M;&5E;B!61E,M=&EE9&]S=&]A(%PB)7,O)7-<(BXB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W-Q;"YP:'`Z-#,Y"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C
M="!T;R!344P@<V5R=F5R+B(*;7-G<W1R(")344PM<&%L=F5L:6UE96X@96D@
M<V%A9&$@>6AT97ET=.0N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HX-S`*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G
M<W1R(")9:'1E>71TY"!E:2!V;VED82!M=6]D;W-T86$@4U-,+7-A;&%T='5N
M82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,S(@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,C,W"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HR,#0@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C(P.0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C$W
M"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B5D93
M+71I961O<W1O82!E:2!V;VED82!K;W!I;VED82XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C,W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")%
M:2!V;VED82!L=6]D82!61E,M:&%K96UI<W1O82!<(B5S7"(N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S8Q(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C(V-`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y
M+B(*;7-G<W1R(")%:2!V;VED82!L=6]D82!61E,M:&%K96UI<W1O82XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3(T"FUS9VED(")5;F%B
M;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R(")%:2!V;VET=2!L=6]D
M82!61E,M=&EE9&]S=&]A(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!6
M1E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B16D@=F]I9&$@;FEM973D('5U
M9&5L;&5E;B!61E,M:V%N<VEO=&$@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C(W,@IM<V=I9"`B56YA8FQE('1O(&-R96%T92!E
M;7!T>2!61E,@9FEL92XB"FUS9W-T<B`B16D@=F]I='4@;'5O9&$@='EH:N3D
M(%9&4RUT:65D;W-T;V$N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+V=Z:7`N<&AP.C<Y"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]T87(N<&AP.C<V"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A
M+B(*;7-G<W1R(")4:65T;V$@96D@=F]I9&$@;&%A:F5N=&%A+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S`S(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z,C(X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2XB"FUS
M9W-T<B`B16D@=F]I9&$@<&]I<W1A82!<(B5S7"(L(&AA:V5M:7-T;R!E:2!O
M;&4@='EH:N0N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW."!A9&UI;B]P97)M
M<R]D96QE=&4N<&AP.C0T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T<B`B16D@=F]I9&$@<&]I<W1A
M82!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C,S."!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S$Q"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#(@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HS.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T
M<B`B16D@=F]I9&$@<&]I<W1A82`E<RP@:&%K96UI<W1O(&5I(&]L92!T>6AJ
MY"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4V(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-C`*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T
M<B`B16D@=F]I9&$@<&]I<W1A82!61E,M:&%K96UI<W1O82!R96MU<G-I:79I
M<V5S=&DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S0T(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,C(*(SH@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C,S-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,S0S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-3(*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B16D@=F]I9&$@<&]I<W1A82!61E,M:&%K96UI<W1O82XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0R,"!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C0S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R(")%:2!V;VED82!P;VES
M=&%A(%9&4RUH86ME;6ES=&]A.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C(Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B16D@=F]I9&$@<&]I
M<W1A82!61E,M=&EE9&]S=&]A(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HS,3`@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C$V-PHC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,Y,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,SDY"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,CDQ"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R(")%:2!V
M;VED82!P;VES=&%A(%9&4RUT:65D;W-T;V$N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HR-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B16D@=F]I
M9&$@<&]I<W1A82!61E,M:V%N<VEO=&$@7"(E<UPB+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z-#`Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B
M16D@=F]I9&$@<&]I<W1A82!61E,ZY.0@<F5K=7)S:6EV:7-E<W1I.B`E<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S-`IM<V=I9"`B56YA
M8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M3GEK>6ES=.0@:&%K96UI<W1O82!E:2!V;VET=2!S96QV:71TY.0N(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,#0*;7-G:60@(E5N
M86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B
M5F%R;65N=&5E;B!T:65T;VIA(&5I('9O:61A(&5X=')A:W1O:61A(@H*(SH@
M9G)A;65W;W)K+TYE=%])35-0+TE-4U`N<&AP.C0S-R!F<F%M97=O<FLO3F5T
M7TE-4U`O24U34"]!=71H+G!H<#HQ,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@
M(DWDY')I='EK<V5N("5S(&QU:V5M:6YE;B!E<.1O;FYI<W1U:2XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,#,@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,C`X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HQ-S0@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$W.0IM
M<V=I9"`B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(D5I('9O
M:61A('-I:7)TY.0@5D93+71I961O<W1O82XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.CDX(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z.3,*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ,#8@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HV-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")%:2!V;VED82!P
M;VES=&%A(%9&4RUT:65D;W-T;V$@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C(X-"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,3,X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ
M-#$*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG
M+B(*;7-G<W1R(")%:2!V;VED82!A=F%T82!61E,M=&EE9&]S=&]A(&MI<FIO
M:71U<W1A('9A<G1E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HX,R!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,S<*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<V"FUS9VED(")5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92XB"FUS9W-T<B`B16D@=F]I9&$@879A=&$@5D93+71I
M961O<W1O82XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C0U"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI
M=F4N(@IM<V=S='(@(E1I:79I<W1E='EN('1I961O<W1O;B!A=6MA:7-U(&5P
MY&]N;FES='5I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-38*;7-G
M:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE
M9"DN(@IM<V=S='(@(D5I('9O:71U(&QU:V5A(%9&4RUT:65D;W-T;V$@*&9I
M;&5S:7IE*"D@97#D;VYN:7-T=6DI+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HX.#<*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&
M:6QE4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(D5I('9O:61A(&QU:V5A(%9&
M4RUT:65D;W-T;V$@*&=E=$9I;&53:7IE*"D@97#D;VYN:7-T=6DI+B(*"B,Z
M(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]N;VYE
M+G!H<#HS.`IM<V=I9"`B56YA8FQE('1O(')E860@9FEL93H@(@IM<V=S='(@
M(D5I('9O:71U(&QU:V5A('1I961O<W1O83H@(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z-C<V"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@
M=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(G9F<W)O;W0@:G5U<FEH86ME
M;6ES=&]A(&5I('9O:71U(&QU:V5A+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,3$P.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E
M>&ES=',B"FUS9W-T<B`B(@HB575D96QL965N;FEM9>1M:6YE;B`E<R`E<SIK
M<VD@97#D;VYN:7-T=6D@:V]S:V$@:V]H9&5H86ME;6ES=&\@;VX@:F\@;VQE
M;6%S<V$B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q
M"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(D5I('9O:61A(&YI;65TY"!U=61E;&QE96X@5D93+6AA:V5M:7-T;V$N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E
M<RXB"FUS9W-T<B`B16D@=F]I9&$@;FEM973D('5U9&5L;&5E;B!61E,M:&%K
M96UI<W1O83H@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS
M-#@@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-S$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92!<(B5S7"(N(@IM
M<V=S='(@(D5I('9O:61A(&YI;65TY"!U=61E;&QE96X@5D93+71I961O<W1O
M82!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C$W
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,CD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RXB"FUS
M9W-T<B`B16D@=F]I9&$@;FEM973D('5U9&5L;&5E;B!61E,M=&EE9&]S=&]A
M("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,3,@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0U,@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,CDS(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HS,#D*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS
M,C8*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N(@IM<V=S='(@
M(D5I('9O:71U(&YI;65TY"!U=61E;&QE96X@5D93+71I961O<W1O82XB"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP
M:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R
M(")%:2!V;VED82!S=6]R:71T86$@:V]M96YT;V$@)VUK:7-O9G,G+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G
M:60@(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM
M<V=S='(@(E=O<F0M9&]K=6UE;G1T:6$@96D@=F]I='4@:^3D;G3DY"(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,34T(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,34W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(D5I('9O:61A(&MI
M<FIO:71T86$@5D93+71I961O<W1O82!<(B5S7"(N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,3@V"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R(")%:2!V;VED82!K
M:7)J;VET=&%A(%9&4RUT:65D;W-T;V]N("AC;W!Y*"D@97#D;VYN:7-T=6DI
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(X."!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,30V"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HQ-3$*;7-G:60@(E5N86)L92!T;R!W<FET92!6
M1E,@9FEL92!D871A+B(*;7-G<W1R(")%:2!V;VED82!K:7)J;VET=&%A(%9&
M4RUT:65D;W-T;VX@=&EE=&]J82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z.#8R"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A
M('=I;&P@8F4@97AC965D960N(@IM<V=S='(@(D5I('9O:61A(&MI<FIO:71T
M86$@5D93+71I961O<W1O82P@:VEI;G1I]B!O;B!TY'EN;N0N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,`IM<V=I9"`B
M56YD97)L:6YE(@IM<V=S='(@(D%L;&5V:6EV871T=2(*"B,Z('1E;7!L871E
M<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R
M(")097)U(&UU=71O:W-E="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@86-T
M:6]N(@IM<V=S='(@(E!E<G5U='1A82!E9&5L;&ES96X@=&]I;65N<&ET965N
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(R
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.0IM
M<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN
M96-T:6]N.B`B"FUS9W-T<B`B5'5N=&5M871O;B!V87-T875S('!A;'9E;&EM
M96QT82!Y:'1E>71E96XZ(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,C$X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,T,`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS-S<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S@S"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R
M=F5R('1O.B`B"FUS9W-T<B`B5'5N=&5M871O;B!V87-T875S('!A;'9E;&EM
M96QT83H@(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N
M86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z-C$*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B3'5O:VET=&5L
M96UA=&]N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.38*;7-G:60@(E5N
M:6-O9&4@*%541BTX*2(*;7-G<W1R(")5;FEC;V1E("A55$8M."DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-PIM<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B
M66AD:7-T>6YE970@87)A8FEE;6ER86%T:70B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S@*;7-G
M:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(EEH9&ES='EN965T(&MU;FEN
M9V%S:W5N;F%T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,`IM<V=I9"`B56YI=&5D(%-T871E
M<R(*;7-G<W1R(")9:&1Y<W9A;&QA="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,SD*;7-G:60@
M(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R
M(")9:&1Y<W9A;'1O:F5N(%1Y>6YE;FUE<F5N(&5R:6QL:7-S86%R970B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C<X(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HV,@IM<V=I9"`B56YI=',B"FUS9W-T<B`B36ET=&%Y:W-I:_9T
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HU."!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,CD*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#,P"FUS9VED(")5;FMN;W=N(@IM<V=S
M='(@(E1U;G1E;6%T;VXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@
M*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B5'5N=&5M871O;B!A<&EM<V=I
M9"`H05!)($UE<W-A9V4@240I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM
M<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R(")4=6YT96UA=&]N
M(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$T-PIM<V=I9"`B56YK;F]W;B!L;V-A=&EO
M;B!P<F]V:61E9"XB"FUS9W-T<B`B06YN971T=2!P86EK:V%T:65T;R!O;B!T
M=6YT96UA=&]N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P
M87-S=V]R9"XB"FUS9W-T<B`B5'5N=&5M871O;B!KY'ET=.1JY'1U;FYU<R!T
M86D@<V%L87-A;F$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E
M;G0@96QE;65N="(*;7-G<W1R(")0;VES=&$@;GEK>6ES96X@96QE;65N=&EN
M(&QI;FMI='ES(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H
M<#HS,#(*;7-G:60@(E5N;F%M960B"FUS9W-T<B`B3FEM973V;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@
M(B(*(E5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O
M<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S
M;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z
M:6QL82YO<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C
M<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@HB5&EE
M=&]T=7)V87-Y:7-TY"!E:2UP<FEV:6QE96=I<V5T('-K<FEP=&ET(&5I=N1T
M('9O:2!K=71S=6$@3&5I:VMA82]+;W!I;VDO(@HB3&EI=.0@=&]I;6EN=&]J
M82X@3F%P<V%U=&$@3TLM;F%P<'5L86$@;N1H9.1K<V5S:2!M;WII;&QA+F]R
M9R!S:79U:6QL82`B"B)O;&5V86X@;VAJ965N+"!J;W-S82!N975V;W1A86X@
M;6ET96X@<VMR:7!T:7-I('9O:79A="!KY'ET=.3D(&QE:6ME</9Y=.3D+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@(E!O:7-T82!VY')I
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#<@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,C<*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,S,*;7-G:60@(E5N<W5P<&]R=&5D
M($5X=&5N<VEO;B(*;7-G<W1R(")%:2UT=65T='4@;&%A:F5N;G5S(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ.3<@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P9&%T92(*;7-G<W1R(")0
MY&EV:73D(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHR
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B4.1I
M=FETY"`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-S8*;7-G:60@(E5P9&%T92!U<V5R(@IM<V=S='(@(E#D:79I=.0@:^1Y='3D
M:N0B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$T-"!A9&UI;B]P97)M<R]E9&ET
M+G!H<#HQ,#(@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS9W-T<B`B4.1I=FET
M971T:6EN(%PB)7-<(BXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX
M,PIM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B4.1I
M=FET>7-S:W)I<'1I('!O:7-T971T:6EN+B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ-S@@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$Y.`IM<V=I9"`B57!L;V%D(@IM<V=S='(@(E1U;R(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ.#8*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L
M:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R(")T
M=6\@:V%I:VMI(&]H:F5L;6EE;B!A<V5N;G5S=&EE9&]S=&]T('!A;'9E;&EM
M96QL92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C(P"FUS9VED(")5<'!E<B!L871I;B!L971T97)S(@IM
M<V=S='(@(DES;W0@;&%T:6YA;&%I<V5T(&MI<FIA:6UE="(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*
M;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B27-O="!R;V]M
M86QA:7-E="!N=6UE<F]T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,0IM<V=I9"`B57)U9W5A
M>2(*;7-G<W1R(")5<G5G=6%Y(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(DOD>73D(&YY:WEI<W3D.B`E<R(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(DOD>73D(%-33"US86QA=7-T
M82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C<*;7-G:60@(E5S92!I
M9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N
M(@IM<V=S='(@(DOD>73D(&IO<R!T=6YN=7,O<V%L87-A;F$@;VX@97)I($E-
M4U`M<&%L=F5L:6UE;&QE+B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M961I="YI;F,Z,C$*;7-G:60@(E5S97(B"FUS9W-T<B`B2^1Y='3D:N0B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<W-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O
M<B`E<RXB"FUS9W-T<B`B2^1Y='3D:N1L;.0@)7,@96D@;VQE(&]I:V5U:W-I
M82!T96ADY"`E<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S
M97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`B2^1Y='3D:FEE;B!Y;&SD<&ET
M;R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C0U"FUS9VED
M(")5<V5R($]P=&EO;G,B"FUS9W-T<B`B2^1Y='3D:N1N(&%S971U:W-E="(*
M"B,Z('-I9VYU<"YP:'`Z-C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM
M<V=S='(@(DOD>71TY&KD;B!R96MI<W1E<O9I;6EN96XB"@HC.B!S:6=N=7`N
M<&AP.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A
M8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R(")4Y'-SY"!JY')J97-T96QM
MY'-SY"!E:2!V;VD@<F5K:7-T97+V:63D(&OD>71TY&IIY"XB"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-#8Y"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T
M(&9O=6YD(@IM<V=S='(@(DOD>71TY&KD='5N;G5S=&$@96D@;/9Y='EN>70N
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$W.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HQ-3`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A
M;'E?<VUT<"YP:'`Z.3@*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M,S,@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS
M9W-T<B`B2^1Y='3D:N1T=6YN=7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE
M(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B2^1Y='3D:N1T=6YN
M=7,@7"(E<UPB(&]N(&IO(&]L96UA<W-A+B(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHX-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(DOD
M>71TY&KD='5N;G5S.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC
M.C@*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B2^1Y='3D:N1T=6YN=7,Z
M("(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@
M(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(DKD<FIE<W1E;&WD;B!K
MY'ET=.1JY'0Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,@IM<V=I9"`B57IB96MI<W1A;B(*
M;7-G<W1R(")5>F)E:VES=&%N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,3<P(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(V,@IM<V=I
M9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B5D93
M+6AA:V5M:7-T;V$@96D@;VQE(&]L96UA<W-A+B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ,C`*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(E!O
M:7-S86]L;W9I97-T:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@W
M,`IM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G
M<W1R(")086EK:V]J82!L]GET>6D@97-I;65R:VEK<VDZ("(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(")686QI9&ET
M>2(*;7-G<W1R(")6;VEM87-S86]L;V%I:V$B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.3<*;7-G:60@(E9A
M;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(D%R=F\@;6EN=75T
M96ES<V$@;GEK>6AE=&ME<W3D+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C@V,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@Q"B,L('!H<"UF
M;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H
M(&]F("5S+B(*;7-G<W1R(")!<G9O(&]N('EL:2!P:71U=61E;B!M86MS:6UI
M87)V;VX@)7,N/"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#@@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(W,`HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,S(P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,30*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0IM
M<V=I9"`B5F%L=65S(@IM<V=S='(@(D%R=F]T(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C$Q,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3DP
M"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B5F%L:71T
M879A="!A<G9O="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#D*;7-G:60@(E9A;G5A='4B"FUS
M9W-T<B`B5F%N=6%T=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,S,*;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@(E9A:6AT96QE=F%A(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@(E9E;F5Z
M=65L82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X
M"FUS9VED(")697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA
M>2!H879E(&)E96X@=&%M<&5R960@=VET:"XB"FUS9W-T<B`B5&%R:VES='5S
M(&5PY&]N;FES='5I("T@5.1TY"!V:65S=&GD(&]N('9O:71U(&OD<VET96QL
MY"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,0IM
M<V=I9"`B5F5R<VEO;B(*;7-G<W1R(")697)S:6\B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C(X"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS
M9W-T<B`B5F5R<VEO;FAA;&QI;G1A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@
M86QI9VXB"FUS9W-T<B`B4'ES='ES=6]R82!T87-A=7,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T"FUS9VED(")697)T
M:6-A;"!P861D:6YG(@IM<V=S='(@(E!Y<W1Y<W5O<F$@=.1Y=&4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@S"FUS9VED
M(")697)T:6-A;#HB"FUS9W-T<B`B4'ES='ES=6]R83HB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,@IM<V=I9"`B5F5R>2!(
M:6=H(@IM<V=S='(@(D5R:71TY&EN(&MO<FME82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#@*
M;7-G:60@(E9I970@3F%M(@IM<V=S='(@(E9I971N86TB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$Y-PIM<V=I9"`B5FEE=&YA;65S92`H5DE30TE)*2(*
M;7-G<W1R(")6:65T;F%M("A625-#24DI(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z.38Y"B,L('!H<"UF;W)M870*;7-G:60@(E9I
M97<@)7,B"FUS9W-T<B`B3N1Y=.0@)7,B"@HC.B!L:6(O0FQO8VLO:69R86UE
M+G!H<#HS"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S
M='(@(D[D>73D(&5R:6QL:7-E;N0@=W=W+7-I=G5N82(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@R.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")6:65W(&%S("5S(@IM<V=S='(@(D[D>73D("5S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T-@IM<V=I9"`B5FER9VEN($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B
M3F5I='-Y='-A87)E="P@0G)I='1I;.1I;F5N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-PIM
M<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B3F5I='-Y='-A
M87)E="P@66AD>7-V86QT86EN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,38*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B3N1K>7;D:7-Y>7,B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4R"FUS9VED(")6:7-I
M8FEL:71Y.B`B"FUS9W-T<B`B3N1K>7;D:7-Y>7,Z("(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS9VED
M(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R(")6;V1A9F]N92!)
M=&%L>2!33510.FX@879U;&QA(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B
M5T%23B(*;7-G<W1R(")605)/25154R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-
M3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R(")605)/2515
M4R$A(2!03TE35$$@4TM225!422!+Y%-)3B!004Q614Q)345,5$$@)7,N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G
M:60@(E=)3B!V:6$@2%144"(*;7-G<W1R(")724X@2%144#IN(&%V=6QL82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-3`*;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S
M='(@(E=A;&QI<R!J82!&=71U;F$B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T
M:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R-R!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z.#,*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B5F%R
M;VET=7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C4X"FUS9VED(")792(*;7-G<W1R(")K92(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*
M;7-G<W1R(")3Y.1E;FYU<W1E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C0Q-@IM<V=I9"`B5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM
M<V=S='(@(E/DY'1I961O="!O;B!T;VEM:71T86YU="(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C@Y-@IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T
M<B`B5V5A=&AE<BYC;VTB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM
M<V=I9"`B5V5B(@IM<V=S='(@(E=75R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT,SD*;7-G:60@(E=E8B!3:71E(@IM<V=S='(@(E=75RUS:79U
M<W1O(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H
M<#HU.`IM<V=I9"`B5V5E:VQY(@IM<V=S='(@(E9I:6MO:71T86EN(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*;7-G:60@(E=E;&-O;64B
M"FUS9W-T<B`B5&5R=F5T=6QO82(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(E1E<G9E='5L
M;V$@;VAJ96QM86%N("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP
M:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M
M870*;7-G:60@(E=E;&-O;64L("5S(@IM<V=S='(@(E1E<G9E='5L;V$L("5S
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3@*;7-G:60@(E=E<W1E<FX@
M*$E33RTX.#4Y+3$I(@IM<V=S='(@(DSD;G-I;6%I;F5N("A)4T\M.#@U.2TQ
M*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DY"FUS9VED(")797-T97)N
M("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B3.1N<VEM86EN96XO175R;R`H25-/
M+3@X-3DM,34I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S@*;7-G:60@(E=E<W1E<FX@4V%H87)A
M(@IM<V=S='(@(DSD;G-I+5-A:&%R82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO
M;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B36EN
M:^0@;VAJ96QM86X@)7,@:^1Y;FYI<W3DY"!S:7/DY&YK:7)J875T=6UI<V5N
M(&KD;&ME96XN(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,30*
M;7-G:60@(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_(@IM<V=S
M='(@(DUI=.0@;65R:VMIY"!KY'ET973DY&X@97)O='1I;65N83\B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T
M:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R(")-:73D(&UE<FMK:>0@:^1Y
M=&5TY.1N(&QA:6YA=6MS965N/R(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,#8T"FUS9VED(")7:&5R96ES($%U<W1R86QI
M82!M87`B"FUS9W-T<B`B5VAE<F5I<R!!=7-T<F%L:6%N(&MA<G1T82(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM
M<V=S='(@(DUI=&OD('9A:6AE970B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3,V"FUS9VED(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE
M(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@(E9O:70@;>3D<FET96QLY"!L
M:7/D=&]I;6EN=&]J82!L86ET971A86X@<.3D;&QE(%)I8V@@5&5X="!E9&ET
M;W)I<W-A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#0*;7-G:60@(E=I9'1H(@IM<V=S='(@(DQE=F5Y<R(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3$*;7-G:60@(E=I9'1H
M(&EN($-34R!U;FET<R(*;7-G<W1R("),979E>7,@0U-3(&UI='1A>6MS:6MK
M]FENY"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@
M*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@(B(*(E9A
M<V5M;6%L;&$@;VQE=F%N("5S('9A;&EK;VX@;&5V97ES("AT=6QE92!V;VEM
M86%N('-E=7)A879A;&QA("(*(G-I<^3D;FMI<FIA=71U;6ES96QL82DZ(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#8*
M;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*;7-G<W1R(")4875L=6MO;B!L
M979E>7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q,`IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R("),979E>61E;B!Y
M:W-I:VOV(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G<W1R("),979E>7,Z(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4Q-0IM<V=I9"`B5VEK:2(*;7-G
M<W1R(")7:6MI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X
M.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I
M9"`B5VEN9"(*;7-G<W1R(")4=75L:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")7:6YD($5A<FQY(@IM<V=S
M='(@(E1U=6QI<W1A(&%I:V%I<VEN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HX-PIM<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R(")4=75L
M96YN;W!E=7,@<V]L;75I<W-A(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M-C,*;7-G:60@(E=I;F0Z(@IM<V=S='(@(E1U=6QI.B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*;7-G:60@(E=I;F0Z("(*;7-G<W1R
M(")4=75L:3H@(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED
M(")7:7-D;VTB"FUS9W-T<B`B5FEI<V%U<R(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ.3@*;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@(E1O:79E
M;&ES=&%T(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7
M;W)K(@IM<V=S='(@(E1Y]B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$V-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@
M(D]S;VET92`H='GV*2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`B4'5H
M96QI;B`H='GV*2(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$Y
M,R!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR.30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%
M>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(E;DY'+D(&WDY'+D(&ME
M;G1T:>0@<FEV:6QLY"`E9"X@3V1O=&5T=&EI;B`E9"P@;/9Y='EI("5D+B(*
M"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,S,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E
M9"P@9F]U;F0@)60N(@IM<V=S='(@(E;DY'+D(&WDY'+D(&ME;G1T:>0N($]D
M;W1E='1I:6X@)60L(&SV>71Y:2`E9"XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HQ,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F
M<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B5N3D
M<N0@<&]I:VME86UA("5D(&QU971T865S<V$@5D93+71I961O<W1O82XB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C0U"FUS9VED(")8+5)E9B(*
M;7-G<W1R(")8+5)E9B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS
M9W-T<B`B6#4P.78S('!E<G5S<F%J;VET=&5E="(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@17AT96YD
M960@2V5Y(%5S86=E(@IM<V=S='(@(E@U,#EV,R!L:7/D=&]I;6EN;F]T(&%V
M86EM96X@:^1Y=/9L;&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@
M3F%M92(*;7-G<W1R(")8-3`Y=C,@2V]H=&5E;B!V86EH=&]E:'1O:6YE;B!N
M:6UI(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.38*
M;7-G:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@
M(E@U,#EV,R!+;VAT965N(&%V86EM96X@='5N;FES=&4B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X,PIM<V=I9"`B6#4P.78S(&5X
M=&5N<VEO;G,B"FUS9W-T<B`B6#4P.78S+6QA86IE;FYU:W-E="(*"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R(")65B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,30*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-@IM<V=I
M9"`B65E962(*;7-G<W1R(")65E96(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,3$*;7-G:60@(EEA:&]O(2!M87`B"FUS
M9W-T<B`B66%H;V\A(&MA<G1T82(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC
M92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G<W1R(")6
M=6]S:71T86EN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,@IM<V=I9"`B665M96XB"FUS9W-T
M<B`B2F5M96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.38V"FUS9VED(")997,B"FUS9W-T<B`B2WEL;.0B"@HC.B!T96UP
M;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM<V=I9"`B
M665S+"!)($%G<F5E(@IM<V=S='(@(DMY;&SD+"!S=6]S='5N+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@
M(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T
M;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R("(B"B)+Y'ETY'0@
M5$5+4U1)5$E,04$N($OD>73D(%L\/ET@;F%P<'5L86$@=F%I:'1A86MS97-I
M('1A:V%I<VEN(%=94TE764<M=&EL86%N+B(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,C,V"B,L('!H<"UF;W)M870*
M;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA
M;B`E9"!B;&]C:W,N(@IM<V=S='(@(D5T('9O:2!T96ADY"!E;F5M<.3D(&MU
M:6X@)60@;W-I;W1A+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,30Q-0IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC871E9"XB"FUS9W-T
M<B`B170@;VQE(&%U=&5N=&EK;VET=6YU="XB"@HC.B!F<F%M97=O<FLO261E
M;G1I='DO261E;G1I='DN<&AP.C,P.`IM<V=I9"`B66]U(&-A;FYO="!H879E
M('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T
M<B`B3FEM97-SY'-I(&5I('-A82!O;&QA("=<7"<M;65R:VMIY"XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4Y(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y-SD*;7-G:60@(EEO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@
M96UA:6P@861D<F5S<RXB"FUS9W-T<B`B170@86YT86YU="!O:6ME86X@;75O
M=&]I<W1A('/D:&OV<&]S=&EO<V]I=&5T=&$N(@H*(SH@9G)A;65W;W)K+T1A
M=&$O1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D
M:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T
M;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S='(@
M(B(*(D5T(&WDY')I=&5L;'ET(&UI=&OD('1U;V1U;B!T:65D;W-T;VX@:V5N
M=.1T('9A<W1A879A="!M:73D:VEN(&ME;G1T:>0@)7,Z(@HB<W/D+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX-PIM<V=I9"`B66]U(&AA=F4@
M8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R(")/;&5T(&MI<FIA=71U;G5T('5L
M;W,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(V-0IM<V=I9"`B
M(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R
M+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F;W(@=&AE
M(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@(B(*(E-I
M;G5N('!I=.3D(&%N=&%A(&]I:V5A(&UA=&MA<'5H96QI;FYU;65R;RP@=F%I
M;B!N=6UE<F]I=&$@:F$@;6%H9&]L;&ES97-T:2`B"B(G*R<@:F]S(&OD>73D
M="!K86YS86EN=N1L:7-TY"!P=6AE;&EN;G5M97)O;75O=&]A+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.3(*;7-G:60@(EEO=2!H879E('1O
M(&5N=&5R(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(E-I;G5N('3D>71Y>2!A
M;G1A82!O:6ME82!A<G9O+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG
M;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R
M964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B(@HB4VEN=6X@
M<&ETY.0@87-E;G1A82!$871A5')E92UT875S=&%JY')J97-T96QMY"!E;FYE
M;B!K=6EN('9O:70@:^1Y='3DY"`B"B)3:6=N=7`M=&]I;6EN=&]J82XB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0V,@IM<V=I9"`B66]U(&UU
M<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(E-I;G5N('!I
M=.3D(&%S96YT86$@5D93+71A=7-T86KD<FIE<W1E;&WD+B(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D
M97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P
M<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B(@HB4VEN=6X@='5L964@:W5V86EL
M;&$@;VYG96QM871I;&%N;F5T=&$@96YN96X@:W5I;B!V;VET(&SD:&5T=.3D
M("(*(F]N9V5L;6%V:65S=&EN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H
M92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*;7-G<W1R(")3:6YU
M;B!P:73DY"!A;G1A82!54DP@;6EH:6X@=.1MY"!L:6YK:VD@;W-O:71T86$B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`IM<V=I9"`B66]U
M(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R
M(")3:6YU;B!P:73DY"!V86QI=&$@<&]I<W1E='1A=F$@<&%L=F5L:6XN(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3$Y"FUS9VED(")9;W4@;75S="!S<&5C:69Y
M(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R(")3:6YU;B!P:73D
MY"!A;G1A82!P;VES=&5T=&%V82!KY'ET=.1JY'1U;FYU<RXB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R
M;F%M92!T;R!R96UO=F4N(@IM<V=S='(@(E-I;G5N('!I=.3D(&%N=&%A('!O
M:7-T971T879A(&OD>71TY&KD='5N;G5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C8R('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B
M66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R
M(")3:6YU;B!P:73DY"!A;G1A82!L:7/D='3D=N0@:^1Y='3D:N1T=6YN=7,N
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9;W4@;75S="!S<&5C
M:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@(E-I;G5N('!I
M=.3D(&%N=&%A('#D:79I=&5T=.1VY"!KY'ET=.1JY'1U;FYU<RXB"@HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S@*;7-G:60@
M(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB"FUS
M9W-T<B`B4VEN=6X@<&ETY.0@=F%L:71A('-U;W)I=&5T=&%V82!T;VEM:6YT
M;RXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R
M+G!H<#HW,0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N
M86UE+B(*;7-G<W1R(")3:6YU;B!P:73DY"!A;G1A82!U=61E;B!K871E9V]R
M:6%N(&YI;6DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE
M:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D('1O('!R;W9I9&4@
M86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B4VEN=6X@<&ETY.0@
M86YT86$@:71A;&EA;&%I;F5N('!U:&5L:6YN=6UE<F\B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+G!H<#HY-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U
M<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN
M(@IM<V=S='(@(DES='5N=&]S:2`E<R!O;B!V86YH96YT=6YU="X@2VER:F%U
M9'4@=75D96QL965N('-I<^3D;BXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHS.`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S
M='(@(E/D:&OV<&]S=&EO<V]I='1E97-I(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(Q-0IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R
M(")3:6YU;B!LY&AE='3D:N1O<V]I='1E97-I.B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S<@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C@U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M,@IM<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R(")/;6%T('1I971O
M<VDB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-SD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N
M9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4
M;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G
M86EN+B(*;7-G<W1R("(B"B)3:6YU;B!T:65T;VMO;F5E<VD@:^1Y='3D;>0@
M=&EE=&]V97)K:V\M;W-O:71E(&]N(&UU=71T=6YU="!S96X@:N1L:V5E;B!K
M=6X@(@HB;VQE="!A;&]I='1A;G5T("5S(&ES='5N;F]N+B!4:65T;W1U<G9A
M<WEI<W3D('-I;G5N('!I=.3D(&MI<FIA=71U82`B"B)U=61E<W1A86X@:N1R
M:F5S=&5L;>3D;BXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHS,PIM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@(DYI;65S:2(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHU"FUS9VED("(B"B)9;W5R
M(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I
M;F<@=7-E<G,N($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI
M;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N
M="`B"B)A=71H96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R("(B"B)+Y'ET
M=.1MY'-I(&%U=&AE;G1I8V%T:6]N('1A=7-T86KD<FIE<W1E;&WD(&5I('1U
M92!KY'ET=.1J:65N(&QI<^3D;6ES=.0N("(*(DIO<R!H86QU870@:&%L;&EN
M;F]I9&$@:^1Y='3D:N1T=6YN=6MS:6$L('-I;G5N('!I=.3D(&OD>71TY.0@
M:F]T86MI;B!T;VES=&$@(@HB875T:&5N=&EC871I;VX@=&%U<W1A:N1R:F5S
M=&5L;>3D+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z
M-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@
M;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB
M:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G
M<W1R("(B"B)+Y'ET=.1MY'-I(&%U=&AE;G1I8V%T:6]N('1A=7-T86KD<FIE
M<W1E;&WD(&5I('1U92!KY'ET=.1JY'1I971O:F5N("(*(F[D>71TY&UI<W3D
M('1A:2!TY&WD('!I:7)R92!E:2!O;&4@:F]S=&%K:6X@<WEY<W3D(&OD>71E
M='3D=FES<^0N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@S"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O
M(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@
M<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S
M="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB4VEN=6X@:^1Y='3D;>1S:2!W
M=W<M<V5L86EN(&[D>71TY.0@;VQE=F%N(&UU=71T=6YU="!S96X@:N1L:V5E
M;B!K=6X@;VQE="`B"B)A;&]I='1A;G5T("5S(&ES='5N;F]N+B!4:65T;W1U
M<G9A<WEI<W3D('-I;G5N('!I=.3D(&MI<FIA=71U82`B"B)U=61E<W1A86YJ
MY')J97-T96QMY.1N+B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C4W"FUS
M9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U
M<F4N(@IM<V=S='(@(E-E;&%I;65S:2!E:2!T=64@=.1TY"!T;VEM:6YT;V$N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z-#(*;7-G:60@
M(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@
M;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT
M+B(*;7-G<W1R("(B"B)396QA:6UE<VD@96D@='5E('1A<G9I='1A=F%A('1U
M;&]S='5S=&]I;6EN=&]A+B!086EN82!#;VYT<F]L+T]P=&EO;B`K(%`@(@HB
M='5L;W-T86%K<V5S:2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C8Q
M"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R(")!:6MA
M=GGV:'EK:V5E<VDZ(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C$Q-PIM<V=I
M9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N(@IM
M<V=S='(@(D]L971U<W!R;V9I:6QI<VD@;VX@;75U=&5T='4N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$V,0IM<V=I9"`B66]U<B!D969A=6QT(&ED
M96YT:71Y.B(*;7-G<W1R(")/;&5T=7-P<F]F:6EL:7-I.B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR,#0*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*
M;7-G<W1R(").:6UE<VDZ(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M.3DY"FUS9VED(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*;7-G<W1R("))
M<W1U;G1O<VD@;VX@=F%N:&5N='5N=70N(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@
M<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R(")3:6YU;B!S86QA<V%N
M87-I("5S.FQL92!O;CH@)7,B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C$U-`IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A
M=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R
M(")!<V5T=6MS97-I(&]N('#D:79I=&5T='D@:F$@;F4@;W9A="!V;VEM87-S
M82!TY&WD;B!I<W1U;FYO;B!A:F%N+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,34V"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N
M('5P9&%T960N(@IM<V=S='(@(D%S971U:W-E<VD@;VX@<.1I=FET971T>2XB
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U
M<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="(*;7-G<W1R(")386QA<V%N87-I
M(&]N(&YO;&QA='1U(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H
M96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A
M<W-W;W)D+B(*;7-G<W1R("(B"B)386QA<V%N87-I(&]N(&YO;&QA='1U+"!T
M87)K:7-T82!SY&AK]G!O<W1I<VD@:F$@:VER:F%U9'4@<VESY.1N('5U9&5L
M;&$@(@HB<V%L87-A;F%L;&%S:2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HW,S,*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM
M<V=S='(@(E-A;&%S86YA<VD@;VX@=F%N:&5N='5N=70N(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9;W5R(')E;6]T92!S
M97)V97)S.B(*;7-G<W1R(")%=.1P86QV96QI;65S:3HB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C4T"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S='(@(DIU9V]S;&%V
M:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED
M("):86ER92(*;7-G<W1R("):86ER92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-38*;7-G:60@
M(EIA;6)I82(*;7-G<W1R(")386UB:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4W"FUS9VED
M(")::6UB86)W92(*;7-G<W1R(")::6UB86)W92(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B6FEP<'DB"@HC
M.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E
M<RYP:'`Z,3<T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS
M+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T<B`B6U!I
M:6QO=&$@;&%I;F%T='4@=&5K<W1I72(*"B,Z('-E<G9I8V5S+W!R;V)L96TN
M<&AP.C@Y"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM<V=S='(@(EM/;F=E
M;&UA72(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS
M.C$S"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M(@IM<V=S='(@(EM.Y'ET
MY"!L86EN871T=2!T96MS=&D@+2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E
M<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T
M<B`B6T[D>73D(&QA:6YA='1U('1E:W-T:2`M("5S(')I=FGD72(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DU"B,L('!H<"UF;W)M870*;7-G
M:60@(EML:6YE("5S(&]F("5S72(*;7-G<W1R(");<FEV:6QLY"`E<R\E<UTB
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U-#<@=&5M<&QA=&5S
M+W!O<G1A;"]M96YU+FEN8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(E]9;&SD<&ET;R(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I9"`B
M7T-,22(*;7-G<W1R(")?2V]M96YT;W1U;&MK:2(*"B,Z(&QI8B]A<&DN<&AP
M.C$T,0IM<V=I9"`B7T1A=&%4<F5E(@IM<V=S='(@(E]$871A5')E92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS,0IM<V=I9"`B7T1E;&5T92!2;W<B"FUS9W-T<B`B7U!O:7-T82!R:79I
M(@H*(SH@;&EB+V%P:2YP:'`Z,3,S"FUS9VED(")?1W)O=7!S(@IM<V=S='(@
M(E]2>6AMY'0B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z
M,3<U"FUS9VED(")?2&5L<"(*;7-G<W1R(")?3VAJ92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I
M9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B7TMU=F%N('1I961O
M="XN+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.30*
M;7-G:60@(E],;V<@:6XB"FUS9W-T<B`B7TMI<FIA=61U('-I<^3D;B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.3`*;7-G:60@(E],
M;V<@;W5T(@IM<V=S='(@(E]+:7)J875D=2!U;&]S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED
M(")?36]D:69Y($QI;FLN+BXB"FUS9W-T<B`B7TUU;VMK86$@;&EN:VMIY"(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-C0*;7-G:60@
M(E]/<'1I;VYS(@IM<V=S='(@(E]!<V5T=6MS970B"@HC.B!L:6(O87!I+G!H
M<#HQ,S<*;7-G:60@(E]097)M:7-S:6]N<R(*;7-G<W1R(")?3VEK975D970B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C8*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R(")0;VES
M=&$@;&EN:VMI+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3(U"FUS9VED(")?4V5T
M=7`B"FUS9W-T<B`B7T%S96YN=7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L92!0
M<F]P97)T:65S+BXN(@IM<V=S='(@(E]4875L=6MO;B!T:65D;W0N+BXB"@HC
M.B!L:6(O87!I+G!H<#HQ,CD*;7-G:60@(E]5<V5R<R(*;7-G<W1R(")?2^1Y
M='3D:N1T(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C4*;7-G
M:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R(")O<V]I=&5K:7)J82(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,T"FUS9VED(")A9&1R
M97-S964@=6YK;F]W;B(*;7-G<W1R(")V87-T86%N;W1T86IA('1U;G1E;6%T
M;VXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ-PIM<V=I9"`B
M8V%L96YD87(B"FUS9W-T<B`B:V%L96YT97)I(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ-SD@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R(")T>7EN=.0B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N;F]T(&-R
M96%T92!O=71P=70@9FEL92(*;7-G<W1R(")E:2!V;VD@;'5O9&$@='5L;W-T
M:65D;W-T;V$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$S,`IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B"FUS9W-T<B`B96D@=F]I
M(&%U:V%I<W1A(&SD:&1E='3D(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z-3DX"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@(FYA
M<'-A=71A('3D<W3D(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G
M<W1R(")V:7)H92!K;VUE;G1O<FEV:6QLY"(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,3<X"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R
M<F]R(@IM<V=S='(@(F%S971U<W9I<FAE(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ-30*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F
M:6QE(&UI<W-I;F<B"FUS9W-T<B`B:W)I:71T:6YE;B!JY')J97-T96QMY'1I
M961O<W1O('!U=71T=74B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B
M;75O=&]V:7)H92!T:65D;VES<V$B"@HC.B!T96UP;&%T97,O<&]R=&%L+V5D
M:70N:6YC.C,P"FUS9VED(")E9&ET(@IM<V=S='(@(FUU;VMK86$B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$X,@IM<V=I9"`B96YT
M<GD@;F]T(&9O=6YD(@IM<V=S='(@(G1I971U971T82!E:2!L]GET>6YY="(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"FUS
M9VED(")F86QL:6YG(@IM<V=S='(@(FQA<VME=F$B"@HC.B!F<F%M97=O<FLO
M0G)O=W-E<B]"<F]W<V5R+G!H<#HX.3@*;7-G:60@(F9I;&4B"FUS9W-T<B`B
M=&EE9&]S=&\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X,2!L:6(O0FQO
M8VLO;65T87(N<&AP.C,V-R!L:6(O0FQO8VLO;65T87(N<&AP.C,Y,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S(@IM
M<V=S='(@(G-U=6YN87-T82`E<R`H)7,I(&YO<&5U9&5L;&$@)7,@)7,B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Y"FUS9VED(")G=7-T
M:6YG(@IM<V=S='(@(G!U=7-K:71T86EN(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U,`IM<V=I9"`B:#HB"FUS9W-T<B`B
M:#HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,S4Y"FUS9VED(")H:"(*;7-G<W1R(")H:"(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,3,X"FUS9VED(")H;W-T(&YA;64@=6YK;F]W
M;B(*;7-G<W1R(")T=6YT96UA=&]N('!A;'9E;&EM96X@;FEM:2(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V
M-0IM<V=I9"`B:6UM961I871E(@IM<V=S='(@(G;D;&ET=/9MY'-T:2(*"B,Z
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP
M.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B:6YL:6YE(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U
M='!U="!E<G)O<B(*;7-G<W1R(")I;RUV:7)H92(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S;V9T
M=V%R92!E<G)O<B(*;7-G<W1R(")O:&IE;&UI<W1O;B!S:7/D:6YE;B!V:7)H
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S
M"FUS9VED(")L:6YE<UTB"FUS9W-T<B`B<FEV:71=(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H
M<"UF;W)M870*;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M
M86MI;F<@25-/+B(*;7-G<W1R(")M:VES;V9S('9I<FAE:V]O9&D@)60@25-/
M.F$@=&5H9&5S<^0N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,W,`IM<V=I9"`B;6TB"FUS9W-T<B`B;6TB"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(X-2!S97)V:6-E<R]P;W)T86PO
M<VED96)A<BYP:'`Z,3<P"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HR-#$*;7-G:60@(FYA;64B"FUS9W-T<B`B;FEM:2(*"B,Z(&9R86UE=V]R
M:R]24$,O4E!#+G!H<#HQ,C0*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G
M<W1R(")E:2!O;&4@=&]T975T971T=2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z,3(R,`IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E
M9"(*;7-G<W1R(")E:2!O;&4@=FEE;.0@=&]T975T971T=2(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`Y"FUS9VED(")N;W1E<&%D(@IM<V=S
M='(@(FUU:7-T:6QI<W1A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R
M(")P<F]S96YT=&DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$W-`IM<V=I9"`B<&5R;6ES<VEO;B!D96YI960B"FUS9W-T<B`B:^1Y
M='3V(&MI96QL971T>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R(")P
M:6MS96QE:73D(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R
M(")E=.1V:7)H92!P<F]T;VMO;&QA<W-A(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S4*;7-G:60@(G)I<VEN9R(*;7-G<W1R
M(")N;W5S979A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-#(*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B<&%L
M=F5L=2!E:2!O;&4@:^1Y=&5T=.1V:7-SY"(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z,3`Q"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@
M(F[D>73D(&5R;W0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM
M<V=S='(@(G-M<S)E;6%I;"!(5%10.FX@879U;&QA(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-PIM<V=I9"`B<W,B"FUS
M9W-T<B`B<W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HW-`IM<V=I9"`B<W1E861Y(@IM<V=S='(@(G9A:V%A(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E
M;2!E<G)O<B(*;7-G<W1R(")JY')J97-T96QMY'9I<FAE(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S,*;7-G:60@(G1A<VL@;&ES="(*;7-G
M<W1R(")T96ATY';D;&ES=&$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$V-@IM<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T
M<B`B=N1L:6%I:V%I;F5N('9I<FAE(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W,`IM<V=I9"`B='EP
M92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R(")V87)M
M:7-T86%K<V5S:2!K:7)J;VET82!S86QA<V%N82!K86AD97-T:2(*"B,Z(&%D
M;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y
M"FUS9VED(")U;FEF:65D(@IM<V=S='(@(G5N:69I960B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U!A<G0N<&AP.C(W"FUS9VED(")U;FYA;65D(@IM<V=S
M='(@(FYI;65T]FXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-C4*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S
M='(@(FOD>71TY&KD;B!V86QI;G1A(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V
M0V%R9"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR-#(*;7-G:60@(G<Z(@IM<V=S='(@(G<Z(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@
M(G=E871H97(N8V]M(@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P;R]E=%]%12YP;P``````````````````````
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`W,C`R,#$@,3`U,34T
M,S,W-#(@,#$W-3`P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````",@2$]21$4@15-43TY)04X@5%)!3E-,051)3TX@"B,*(R!4
M;V]M87,@06%S(#QT;V]M87,N86%S0&UA:6PN964^+"`R,#`R("T@,C`P-B`*
M(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@2&]R
M9&4@,RXQ+6-V<UQN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T
M<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X
M(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#,M,S`@
M,38Z,3$K,#,P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!4;V]M87,@06%S(#QT
M;V]M87,N86%S0&UA:6PN964^7&XB"B),86YG=6%G92U496%M.B!%<W1O;FEA
M;B`\9&5V0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP
M7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X
M-3DM,3-<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-CD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS9W-T<B`B("@E<R!PY&5V82!T
M86=A<VDI(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ,S<P"B,L
M('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(@
M*$MI:7)K;&%H=B`E<RDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S<W"B,L('!H<"UF;W)M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T
M<B`B("@E<R!PY&5V82!PY')A<W0I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C,W,PIM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B("ATY&YA*2(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S4*;7-G:60@(B`H=&]M
M;W)R;W<I(@IM<V=S='(@(B`H:&]M;64I(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C,W,0IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@(B`H
M96EL92DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4V(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C$*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C0P-PIM<V=I9"`B(&%T("(*;7-G<W1R("(@:VEI
M<G5S96=A("(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C$U"B,L
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E8W1O<GDN
M(@IM<V=S='(@(EPB)7-<(B!E:2!O;&4@:V%T86QO;V<N(@H*(SH@9G)A;65W
M;W)K+T-,22]#3$DN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S
M7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R(")<(B5S7"(@96D@
M;VQE(';U:6UA;&EK('9A;&EK+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]296=I<W1R>2YP:'`Z-C4Y"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]2
M96=I<W1R>2YP:'`Z,3`T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*;7-G
M<W1R(")<(B5S7"(@96D@;VQE($AO<F1E(')E9VES=')I<R!HY.1L97-T871U
M9"XB"@HC.B!F<F%M97=O<FLO5')E92]4<F5E+G!H<#HQ-S$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(*
M;7-G<W1R(")<(B5S7"(@<'5U(&5S:71A:F%T(&5I(&QE:71U9"XB"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C4V"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<
M(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(EPB
M)7-<(B!L:7-A=&D@9W)U<'!I9&4@<_QS=&5E;6DN(@H*(SH@861M:6XO<&5R
M;7,O861D8VAI;&0N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<
M(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T
M<B`B7"(E<UPB(&QI<V%T:2#U:6=U<W1E('/\<W1E96UI+B(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z-30@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-R96%T960Z("5S
M+B(*;7-G<W1R(")<(B5S7"(@96D@;&]O9'5D.B`E<RXB"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"
M('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T<B`B)2XR
M9DU"(&MA<W5T871U9"!K;VMK=2`E+C)F34(M<W0@*"4N,F8E)2DB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,W"B,L('!H<"UF;W)M870*
M;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R("(E9"`E<R!J82`E<R(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,C8X(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HU-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U
M;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N(@IM<V=S='(@(E-I;G4@<&%R
M;V]L(&%E9W5B("5D('#D979A('#D<F%S="XB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C@U"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A
M>2!F;W)E8V%S="(*;7-G<W1R("(E9"!PY&5V82!E;FYU<W1U<R(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R`M($YO=&EC92(*;7-G<W1R("(E<R`M(%3D:&5L97!A;G4B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P-`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*;7-G<W1R("(E<R!S]7)M96KD
M;&<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S,@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,U"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B5S($M"(@H*(SH@<V5R=FEC
M97,O;6%I;G1E;F%N8V4N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T
M<B`B)7,@:&]O;&1U<W3V]F0@+2!K:6YN:71U<R(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R("(E<R!P86EG86QD
M=7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8S"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B)7,@:V]N
M=&\@=&%O=&QE;6EN92(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE;G0B
M"FUS9W-T<B`B)7,@:V%S=71U<W1I;F=I;75S960B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C0R."!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C0Y,`HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8U,2!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B)7,@;VX@:G5B82!O;&5M87,N
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3D@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ-C4@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,SD*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS-#4@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B)7,@:VEI<G5S
M96=A("5S("5S(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0X"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E<F9O<FT@
M=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE
M8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T
M;R!P97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B(@HB)7,@;VX@=F%L
M;6ES('1E9V5M82!A;&QP;V]L(&QO971L971U9"!H;V]L9'5S=/;V9"X@3>1R
M9VES=&$@=/;V9"P@;6ED82`B"B)S;V]V:60@<')A96=U('1E:&$N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,T,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("(E<R!O;B!K;VAU<W1U<VQI
M:R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@V"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&UI;G5T97,B"FUS9W-T<B`B)7,@;6EN=71I="(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,C,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(E<R!E:2!L
M96ET=60N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R("(E
M<R!K=6YI("5S("5S+7-T(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB
M"FUS9W-T<B`B2V%S=71A:F$@)7,@86%D<F5S<VER86%M870B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R=S($-A;&5N9&%R(@IM<V=S='(@(DMA<W5T86IA("5S(&MA;&5N9&5R
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(DMA<W5T86IA("5S
M(&WD<FMM960B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(DMA
M<W5T86IA("5S(/QL97-A;F1E9"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I
M;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@(B5S.B`E<R(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C(W,@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@
M9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN
M9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD
M97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*
M(B5S.B!3964@=&5A9&4@96D@<')U=6=I(&]L;&$@<V%A=&IA;'0L(&ME;&QE
M;'0@<V5E('!A:7-T86(@;VQE=F%T+B#$<F$@(@HB:VEI<G5S=&$@:VSU<'-A
M;6$@<V5L;&5S(&5S:6YE=F%I9"!L:6YK92!V]6D@97-I=&%M82!S86%T:F%L
M92`B"B)M:6YG:71I<VEK;&EK:W4@:6YF;W0N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,V-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-#$P"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(BP@='5U;&5I:6QI
M9"`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X."!L:6(O0FQO8VLO;65T
M87(N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U<W1I;F<@)7,@
M)7,B"FUS9W-T<B`B+"!T=75L96EI;&ED("5S("5S(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L
M92!F<F]M("5S('1O("5S(@IM<V=S='(@(BP@=F%H96UI:W5S("5S(&MU;FD@
M)7,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Y-"!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,T.`HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,#8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,C@*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<T.0IM
M<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(BTM('9A;&D@+2TB"@HC.B!L
M:6(O0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM
M<V=S='(@(C$R+71U;FYI;F4@97-I='5S(@H*(SH@;&EB+T)L;V-K+W1I;64N
M<&AP.C$Y"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R("(R-"UT=6YN
M:6YE(&5S:71U<R(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(X"FUS
M9VED("(R-"!H;W5R<R(*;7-G<W1R("(R-"!T=6YD:2(*"B,Z(&9R86UE=V]R
M:R]522]522]086=E<BYP:'`Z-CD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R
M("(\165L;6EN92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED
M(")!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO
M8VLN(@IM<V=S='(@(E-E92!B;&]K:R!V86IA8B!A;F1M96)A87-I('1U9V4N
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C`*;7-G:60@(D$@
M9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(DIU:'1U<R!K;VAU
M=&%V('9I9V$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY
M,S4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC
M<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(DMI<FIA(&MR_'!T965R:6UI<V5K
M<R!O;B!V86IA(&%V86QI:VMU(%!'4"!V]71I="XB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38U"FUS9VED(")!('!U8FQI8R!01U`@
M:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(*
M;7-G<W1R(")!;&QK:7)J82!K;VYT<F]L;&EM:7-E:W,@;VX@=F%J82!A=F%L
M:6MK=2!01U`@=O5T:70N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3`Y-PIM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T
M92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C
M<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(DMR_'!T965R:71U9"!K
M:7)J82!A=F%M:7-E:W,@;VX@=F%J82!A=F%L:6MK=2!01U`@=O5T:70L('-A
M;&%J87-T(%!'4"!V]71I="`B"B)J82!S86QA<_5N82XB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#$U"FUS9VED("(B"B)!('!U8FQI
M8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB
M2VER:F$@86QL:VER:F%S=&%M:7-E:W,@;VX@=F%J82!A=F%L:6MK=2!01U`@
M=O5T:70L('-A;&%J87-T(%!'4"!V]71I="!J82`B"B)S86QA<_5N82XB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4P-0IM<V=I9"`B
M(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A(&UE
M<W-A9V4N(@IM<V=S='(@(B(*(DMR_'!T965R:71U9"!K:7)J82!A=F%M:7-E
M:W,@;VX@=F%J82!A=F%L:6MK=2!3+TU)344@=O5T:70L('-A;&%J87-T(%,O
M34E-12`B"B)V]71I="!J82!S86QA<_5N82XB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-
M24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*
M(DMI<FIA(&%L;&MI<FIA<W1A;6ES96MS(&]N('9A:F$@879A;&EK:W4@4R]-
M24U%(';U=&ET+"!S86QA:F%S="!3+TU)344@=O5T:70@(@HB:F$@<V%L87/U
M;F$N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS-C0*
M;7-G:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R
M>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B2VER:F$@:W+\<'1E97)I;6ES96MS
M(&]N('9A:F$@879A;&EK:W4@4R]-24U%(';U=&ET(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B04T@0VQO=61S
M(@IM<V=S='(@(D5,('!I;'9I;F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G
M<W1R(")%3"!K97)G92!V:6AM(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3$*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B14P@
M=FEH;2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$R"FUS9VED(")!32!3:&]W97)S(@IM<V=S='(@(D5,(&AO;W9I:&TB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PIM<V=I
M9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(D5,('1U9V5V(&QU;65S861U
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-+U!-
M(@IM<V=S='(@(D5,+U!,(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C`P"FUS9VED(")!4$D@240B"FUS9W-T<B`B
M05!)($E$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`B4V5L
M;&4@961I=&]R:2!I;F9O(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z
M-3(*;7-G:60@(D%B;W5T+BXN(@IM<V=S='(@(DEN9F\N+BXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T"FUS9VED(")!
M8G-B;W1T;VTB"FUS9W-T<B`B06)S8F]T=&]M(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED9&QE
M(@IM<V=S='(@(D%B<VUI9&1L92(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B5D93(&MA=&%L;V]G:2!L;V]M:7-E:W,@
M:G5U<F1E<.3D<R!K965L871U9"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93
M(&9I;&4N(@IM<V=S='(@(E9&4R!F86EL:2!L;V]M:7-E:W,@:G5U<F1E<.3D
M<R!K965L871U9"XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,PIM<V=I
M9"`B06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R(")+;VYT;R!I;F9O(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U"FUS9VED(")!8V-O=6YT(%!A
M<W-W;W)D(@IM<V=S='(@(DMO;G1O('-A;&%S]6YA(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!
M8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`B2V]N=&\@;'5K=7-T871U9"XB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,S"FUS9VED(")!8V-O=6YT
M:6YG(@IM<V=S='(@(E)A86UA='5P:61A;6EN92(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,30X('1E;7!L871E<R]P;W)T86PO861D+FEN
M8SHQ-`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ
M,0IM<V=I9"`B061D(@IM<V=S='(@(DQI<V$B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C(R-"!A9&UI;B]G<F]U<',N<&AP.C(R-0IM<V=I9"`B061D($-H:6QD
M($=R;W5P(@IM<V=S='(@(DQI<V$@86QA;6=R=7!P(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HY."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.CDY"FUS9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R
M("),:7-A(&%L86WU:6=U<R(*"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN
M8SHU"FUS9VED(")!9&0@2&5R93HB"FUS9W-T<B`B3&ES82!S:6EA.B(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP:'`Z,C$Y"FUS
M9VED(")!9&0@3F5W($=R;W5P(@IM<V=S='(@(DQI<V$@=75S(&=R=7!P(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I
M;VXB"FUS9W-T<B`B3&ES82!U=7,@]6EG=7,B"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@
M(D%D9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R("),:7-A(&=R
M=7!P(%PB)7-<(B!A;&QA(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R
M;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B3&ES82#U:6=U<R!<(B5S7"(@
M86QL82(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@
M=7-E<CHB"FUS9W-T<B`B3&ES82!U=7,@:V%S=71A:F$Z(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-`IM<V=I9"`B061D
M(&-O;'5M;B(*;7-G<W1R("),:7-A('9E97)G(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHS-`IM<V=I9"`B061D(&YE=R!M96UB97)S
M(@IM<V=S='(@(DQI<V$@=75E9"!L:6EK;65D(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D('!A:7(B"FUS9W-T<B`B3&ES
M82!P86%R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I
M9&5B87(B"FUS9W-T<B`B5&5E("5S(&UE;OS\($UO>FEL;&$@:_QL9W)I8F%K
M<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW
M,0IM<V=I9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B3&ES82!A
M861R97-S:7)A86UA='5S<V4Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C<X"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B
M;V]K(@IM<V=S='(@(DQI<V$@;6EN=2!A861R97-S:7)A86UA='5S<V4B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HS,0IM<V=I9"`B061D('5S97(B"FUS9W-T<B`B
M3&ES82!K87-U=&%J82(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B
M=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO
M;CH@(@HB)7,N(@IM<V=S='(@(B(*(EPB)7-<(B!L:7-A=&D@<_QS=&5E;6DL
M(&MU:60@=.1I96YD879A="!L:6ET=6UI<VEN9F]T('!O;&YU9"!V]6EM86QI
M:R`B"B)L:7-A9&$Z("5S+B(*"B,Z('-I9VYU<"YP:'`Z-#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B061D960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C
M86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`B7"(E<UPB(&QI<V%T:2!S_'-T965M
M:2X@3OS\9"!V]6ED('-I<W-E(&QO9VED82XB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I
M<V%B;&5D+B(*;7-G<W1R(")+87-U=&%J871E(&QI<V%M:6YE('!O;&4@;'5B
M871U9"XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3(V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ-S,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,0IM<V=I9"`B061D
M<F5S<R(*;7-G<W1R(")!861R97-S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$S.0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(D%A9')E
M<W-I<F%A;6%T(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.30*;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@
M9F]R(&]T:&5R('5S97)S(@IM<V=S='(@(DAA;&1U<R`M(&UU=61A('1E:7-T
M92!K87-U=&%J871E(/5I9W5S:2(*"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ.2!S
M97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED(")!9&UI;FES
M=')A=&EO;B(*;7-G<W1R(")(86QD=7,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S0Q"FUS9VED(")!9',B"FUS9W-T<B`B4F5K;&%A;2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@(D%F9V%N:7-T
M86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;&)A;FEA(@IM<V=S='(@(D%L8F%A
M;FEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B06QG97)I82(*;7-G<W1R(")!;'IE
M97)I82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,#<*;7-G:60@(D%L:6%S(@IM<V=S='(@(D%L:6%S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I
M9"`B06QI9VXB"FUS9W-T<B`B2F]O;F1U<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N=#HB
M"FUS9W-T<B`B2F]O;F1U<SHB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M.#<*;7-G:60@(D%L;"(*;7-G<W1R(")+]6EK(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`B
M2_5I:R!S:7-S96QO9VET=60@:V%S=71A:F%D(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM<V=I9"`B06QL($=R;W5P
M<R(*;7-G<W1R(")+]6EK(&=R=7!I9"(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+V1A=&%T<F5E
M+G!H<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(DOU:6L@
M]6EG=7-E9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@
M(DOU:6L@;F5L:2!K_&QG92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X-S$*;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R
M("),=6)A(&UI='5T(&%A9')E<W-I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4S-`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@
M='EP93\B"FUS9W-T<B`B3'5B82!MY.1R871A(&KD<FIE<W1A='5D(&QO96YD
M:2!T_/QP(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP
M:'`Z-3`T"FUS9VED(")!;')E861Y(&5X:7-T<R(*;7-G<W1R(")/;B!J=6)A
M(&]L96UA<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C,*;7-G:60@
M(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@(D%L=&5R;F%T:6EV;F4@
M24U34"!K;VYT;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#<*;7-G
M:60@(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S='(@(D%L=&5R;F%T
M:6EV;F4@24U34"!S86QA<_5N82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT.3D*;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S='(@
M(D%L=&5R;F%T:6EV;F4@24U34"!K87-U=&%J86YI;6DB"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HS-0IM<V=I9"`B06QT97)N871E(&5M86EL
M(&%D9')E<W,B"FUS9W-T<B`B06QT97)N871I:79N92!E+7!O<W1I(&%A9')E
M<W,B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B06QT97)N
M871E('1E;7!L871E<R(*;7-G<W1R(")!;'1E<FYA=&EI=G-E9"!M86QL:60B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R
M,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R(")!
M;'1E<FYA=&EI=FYE('1E:W-T.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%M97)I
M8V%N(%-A;6]A(@IM<V=S='(@(D%M965R:6MA(%-A;6]A(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HY-2!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@:6QL96=A;"!V86QU92!W87,@<W!E
M8VEF:65D+B(*;7-G<W1R(")3:7-E<W1A=&D@;'5B86UA='4@=N3D<G1U<RXB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38W"FUS9VED(")!
M;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+B(*;7-G<W1R(")*=6AT=7,@
M='5N9&UA='4@=FEG82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%N9&]R<F$B"FUS
M9W-T<B`B06YD;W)R82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*;7-G
M<W1R(")!;F=O;VQA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS
M9W-T<B`B06YG=6EL;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B06YO;OS\
M;6YE('9A:&5N9&%J82(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T<B`B5F%S='5S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M.`IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R(")!;G1A<FMT:6MA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU-@IM<V=I9"`B06YT:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R(")!
M;G1I9W5A(&IA($)A<F)U9&$B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C<T
M(&%D;6EN+W!H<'-H96QL+G!H<#HS-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO54DN<&AP.C4X('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL
M.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(E)A:V5N9'5S(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,
M:7-T(@IM<V=S='(@(E)A:V5N9'5S=&4@;FEM96MI<FDB"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,30P"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D
M>2XB"FUS9W-T<B`B4F%K96YD=7,@;VX@=/;V=F%L;6ES+B(*"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL
M9"!3:&%R97,B"FUS9W-T<B`B4F%K96YD82!A;&%M:F%G=61E;&4B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B07!P
M<F]V92(*;7-G<W1R(")+:6YN:71A(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z.#,S"FUS9VED(")!<'!R;WAI;6%T92!3:7IE(@IM
M<V=S='(@(DQI9VEK875D;F4@<W5U<G5S(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-`HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@
M(D%P<FEL;"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<U"FUS9VED(")!
M<F%B:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`B07)A86)I82`H5VEN9&]W
M<RTQ,C4V*2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-3D@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@Q"FUS9VED
M(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R(")!<FAI:79I('-U=7)U<R(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-0HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@P"FUS9VED(")!<F-H:79E
M($YA;64B"FUS9W-T<B`B07)H:6EV:2!N:6UI(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N
M=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R(")/;&5D('-A(&MI;F1E;"!E
M="!S;V]V:60@)7,@;&EI='5M:7-S;V]V:2!K=7-T=71A9&$_(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<(B5S
M7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R("(B"B)/;&5D('-A(&MI
M;F1E;"!E="!S;V]V:60@:W5S='5T861A(&=R=7!I(%PB)7-<(B!J82!K]6EK
M('1E;6$@86QA;6=R=7!I9#\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!<F=E;G1I
M;F$B"FUS9W-T<B`B07)G96YT:6EN82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%R
M;65N:6$B"FUS9W-T<B`B07)M965N:6$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$W-@IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B
M07)M965N:6$@*$%235-#24DM."DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,C@*;7-G:60@(D%R="(*;7-G<W1R(")+=6YS="(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*
M;7-G:60@(D%R=6)A(@IM<V=S='(@(D%R=6)A(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G
M<W1R("),:6AA=O5T=&5S86%R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B05-#24D@:F]O;FES='5S
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!
M<VEA+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@(D%A<VEA+U9A:6MS92!O;VME
M86YI('!I:7)K;VYD(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R-0IM
M<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@(DO\<VD@:&]O;&1U<W3V]F1E
M('1E9V5M:7-E:W,@:VEN;FET=7-T(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S$Q,PIM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@
M(E9E97)U9"(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@(D%T=&5M
M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R(")+
M871S92!K=7-T=71A9&$@;VQE;6%T=70@9W)U<'!I+B(*"B,Z(&%D;6EN+W!E
M<FUS+V1E;&5T92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@
M;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(DMA='-E(&MU<W1U
M=&%D82!O;&5M871U="#U:6=U<W0N(@H*(SH@861M:6XO<&5R;7,O961I="YP
M:'`Z.#<*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P
M97)M:7-S:6]N+B(*;7-G<W1R(")+871S92!M=75T82!O;&5M871U="#U:6=U
M<W0N(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!
M='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@
M(DMA='-E(&UU=71A(&]L96UA='5T(&IA9W4N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HV-"!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C<Q"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#8*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B071R
M:6)U=61I9"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B075G=7-T(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU.0IM<V=I9"`B075S=')A;&EA(@IM<V=S='(@(D%U<W1R86%L:6$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4Y"FUS9VED(")!=7-T<FEA(@IM<V=S='(@(D%U<W1R:6$B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,38X"FUS9VED(")!
M=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R(")!=71H7V-Y<G-Q;#H@=F%J86QI:VMU($E-05`@;&%I96YD
M=7-T(&5I(&QE:71U9"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S
M+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@
M:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB"FUS9W-T<B`B075T:%]C>7)U
M<SH@<_QS=&5E;6EL('!U=61U=F%D('9A:F%L:6MU9"!V]6EM960N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3(R"FUS9VED(")!=71H
M7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(D%U=&A?8WER=7,Z('9A:F%L:6MK=2!)34%0(&QA:65N9'5S="!E
M:2!L96ET=60N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]F='`N<&AP.C,V
M"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T
M<"!S=VET8V@N(@IM<V=S='(@(B(*(D%U=&A?9G1P.B!686IA;&EK:W4@1E10
M(&QA:65N9'5S="!E:2!L96ET=60N($MO;7!I;&5E<FD@4$A0(';U=&UE9V$@
M+2UE;F%B;&4M(@HB9G1P+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA
M<"YP:'`Z-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VEM87`Z(%9A:F%L:6MK
M=2!)34%0(&QA:65N9'5S="!E:2!L96ET=60N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E
M9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:W)B
M-3H@5F%J86QI:VMU(&MR8C4@;&%I96YD=7-T(&5I(&QE:71U9"XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B075T:%]L
M9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E
M($1I<F5C=&]R>2(*;7-G<W1R(")!=71H7VQD87`Z($%C=&EV92!$:7)E8W1O
M<GDG<W-E(&MA<W5T86IA=&4@;&ES86UI<V4@='5G:2!P=75D=6(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,U-PIM<V=I9"`B075T:%]L
M9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I
M=F4@1&ER96-T;W)Y(@IM<V=S='(@(D%U=&A?;&1A<#H@06-T:79E($1I<F5C
M=&]R>7-T(&MA<W5T86IA=&4@965M86QD86UI<V4@='5G:2!P=75D=6(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C8S"FUS9VED(")!=71H
M7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B075T:%]L9&%P.B!686IA;&EK:W4@3$1!4"!L86EE;F1U<W0@96D@
M;&5I='5D+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S,Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D
M9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS
M9W-T<B`B075T:%]L9&%P.B!%:2!S86$@;&ES861A(&MA<W5T86IA="`E<RX@
M4V5R=F5R(/QT;&5S.B`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L
M92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z($5I('-A
M82!E96UA;&1A9&$@:V%S=71A:F%T("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L
M9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS9W-T<B`B075T:%]L
M9&%P.B!%:2!S86$@;75U=&$@:V%S=71A:F%T("5S(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HT,#4*;7-G:60@(D%U=&A?;&1A<#H@57!D
M871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C
M=&]R>2XB"FUS9W-T<B`B075T:%]L9&%P.B!!8W1I=F4@1&ER96-T;W)Y(&MA
M<W5T86IA=&4@;75U=&UI<V4@='5G:2!P=75D=6(N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L.B!297%U
M:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?
M;6-A;#H@5F%J86QI:VMU($U#04P@;&%I96YD=7-T(&5I(&QE:71U9"XB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?
M<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R(")!=71H7W-M8F%U=&@Z(%9A:F%L:6MK=2!S;6)A=71H(&QA
M:65N9'5S="!E:2!L96ET=60N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")!=71H96YT:6-A=&EO
M;B!F86EL960B"FUS9W-T<B`B4VES<V5L;V=I;6EN92!N=7)J=7,B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960N
M("5S(@IM<V=S='(@(E-I<W-E;&]G:6UI;F4@;G5R:G5S+B`E<R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE
M;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S='(@
M(E)!1$E54R!S97)V97(@96D@;'5B86YU9"!S:7-S92!L;V=I9&$N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-3$*;7-G:60@(D%U=&AE;G1I
M8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")&5%`@<V5R
M=F5R:7-S92!S:7-S96QO9VEM:6YE(&YU<FIU<RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C<P"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!T
M:&4@4TU"('-E<G9E<B!F86EL960N(@IM<V=S='(@(E--0B!S97)V97)I<W-E
M('-I<W-E;&]G:6UI;F4@;G5R:G5S+B(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@
M(DMA<W5T871A=F%D(';D;&IA9#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R
M8F%I:F%N(@IM<V=S='(@(D%S97)B86ED>F%A;B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS,`IM<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(D)/
M1D@@971T96ODY&YD960B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O=6YD(@IM<V=S
M='(@(E1A=7-T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R(")4
M875S=&$@=N1R=B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z
M.#$*;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`B5F%L
M92!K97)B97)O<V4@<V%L87/U;F$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N86UE+B(*
M;7-G<W1R(")686QE(&ME<F)E<F]S92!K87-U=&%J86YI;6DN(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,@IM<V=I9"`B0F%H86UA<R(*;7-G<W1R(")"86AA;6$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Q"FUS9VED(")"86AR86EN(@IM<V=S='(@(D)A:')E:6XB"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$W-PIM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ
M,RDB"FUS9W-T<B`B0F%L=&D@*$E33RTX.#4Y+3$S*2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*
M;7-G:60@(D)A;F=L861E<V@B"FUS9W-T<B`B0F%N9VQA9&5S:"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(D)A<F)A9&]S(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L('!H<"UF;W)M870*;7-G:60@
M(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM
M<V=S='(@(D=R86%F:6MA('#U:&EK871A;&]O9VD@7"(E<UPB(&5I(&QE:71U
M9"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S,*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(D)A<V5L:6YE(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,PIM<V=I9"`B0F5L87)U<R(*;7-G<W1R(")686QG979E;F4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8P"FUS9VED(")"96QG:75M(@IM<V=S='(@(D)E;&=I82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C,*;7-G:60@(D)E;&EZ92(*;7-G<W1R(")"96QI>F4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Q"FUS9VED(")"96YI;B(*;7-G<W1R(")"96YI;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B0F5R;75D82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R(")":'5T86XB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")"
M:7)T:&1A>2(*;7-G<W1R(")3_&YN:7#D978B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S4S"B,L('!H<"UF;W)M870*;7-G
M:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O
M=6YD+B(*;7-G<W1R(")";&]K:VD@7"(E<UPB(')A:V5N9'5S97,@7"(E<UPB
M(&5I(&QE:71U9"XB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M.#D*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(D)L;VMI(&CDY&QE
M<W1U<R(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I
M9"`B0FQO8VL@5'EP92(*;7-G<W1R(")";&]K:2!T_/QP(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX"FUS9VED(")";VQD
M(@IM<V=S='(@(E!A:W,@:VER:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV
M:6$B"FUS9W-T<B`B0F]L:6EV:6$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C`U"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`B2N1R:F5H;VED
M:F%D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR,`IM<V=I9"`B0F]R9&5R(@IM<V=S='(@(E!I:7)J;V]N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM
M<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B2F]O;F4@<&%K<W5S
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B4&EI<FIO;VYE9"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C`*;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B"FUS
M9W-T<B`B0F]S;FEA(&IA($AE<G1S96=O=FEI;F$B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z.38*;7-G:60@(D)O=&@B"FUS9W-T<B`B3?5L96UA9"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C,*;7-G:60@(D)O='-W86YA(@IM<V=S='(@(D)O='-W86YA
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<U"FUS9VED(")";W1T;VTB"FUS9W-T<B`B06QL82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C,*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B0F]U=F5T('-A87(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8R"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B0G)A<VEI;&EA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#$*;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E
M<G)I=&]R>2(*;7-G<W1R(")"<FET:2!);F1I82!/;VME86YI(%1E<G)I=&]O
M<FEU;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM
M<V=S='(@(D)R=6YE:2!3=6QT86YI<FEI:R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@
M(D)U;&=A<FEA(@IM<V=S='(@(D)U;&=A87)I82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D
M($QI<W0B"FUS9W-T<B`B3&]E=&5L=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U
M<FMI;F$@1F%S;R(*;7-G<W1R(")"=7)K:6YA($9A<V\B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q
M"FUS9VED(")"=7)U;F1I(@IM<V=S='(@(D)U<G5N9&DB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#0T"FUS9VED(")#35,B"FUS9W-T<B`B4VES
M=6AA;&1U<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-S4*;7-G:60@(D-20R(*;7-G<W1R(")#4D,B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B0U),($1I<W1R:6)U
M=&EO;B!0;VEN=',B"FUS9W-T<B`B5/QH:7-T=7-N:6UE:VER:F$@:F%O='5S
M<'5N:W1I9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*
M;7-G<W1R("),7V%H=')I(&]M861U<V5D+BXN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$V,PIM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T
M(&-O;7!L971E9"XB"FUS9W-T<B`B5F%H96WD;'4@:6YI='-I86QI<V5E<FEM
M:6YE(&5I(&KU=61N=60@;/5P=6QE+B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT.#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T
M.CDX-PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,34U"FUS9VED(")#
M86QE;F1A<B(*;7-G<W1R(")+86QE;F1E<B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-#8*;7-G:60@(D-A;&TB"FUS9W-T<B`B5F%I:VYE
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@(DMA;6)O
M9'IH82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(DMA
M;65R=6XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I
M9"`B0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT
M86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB4&%R;V]L:2!E
M:2!S86$@875T;VUA871S96QT('3\:&ES=&%D82P@=O5T82#\:&5N9'5S="!A
M9&UI;FES=')A871O<FEG82XB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W<FET92!T
M;R!F:6QE(%PB)7-<(B(*;7-G<W1R(")%:2#U;FYE<W1U(&MI<FIU=&%D82!F
M86EL:2!<(B5S7"(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@
M(D-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RXB
M"FUS9W-T<B`B5N1L:7-E:60@<V5S<VEO;VYI:&%L9'5R96ED('!O;&4@=O5I
M;6%L:6L@861M:6YI<W1R965R:61A+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER=7,N<&AP.C(S-2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP
M:'`Z,S$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@
M24U!4"!S97)V97(Z("5S(@IM<V=S='(@(D5I('-A82#\:&5N9'5S="!)34%0
M('-E<G9E<FEG83H@)7,B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HT,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`B16D@]6YN97-T=2!A=F%D82!F86EL:2!<(B5S7"(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8T"FUS9VED(")#86YA9&$B"FUS9W-T<B`B2V%N861A(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E<R]A
M9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F4N:6YC.C$R"FUS9VED(")#86YC96PB"FUS9W-T<B`B3&]O8G4B
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B
M0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(DQO;V)U(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B16D@]6YN
M97-T=2!K=7-T=71A9&$@9F%I;&D@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HT-@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R"FUS9VED(")#86YN;W0@
M9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(D5I(&QE:6$@
M86IU=&ES="!K871A;&]O9VDB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(N<&AP.CDQ"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H
M;W5T("=T87)G971&:6QE)R!P87)A;65T97(N(@IM<V=S='(@(DEL;6$@)W1A
M<F=E=$9I;&4G('!A<F%M965T<FET82!E:2!S86$@:N1T:V%T82XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@
M(D5I(/5N;F5S='4@965M86QD861A(&MA=&%L;V]G:2!<(B5S7"(N(@H*(SH@
M9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+G!H<#HQ,C@@9G)A;65W;W)K
M+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L('!H<"UF;W)M870*
M;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G
M<W1R(")%:2!S86$@965M86QD861A+"`E9"UL(&]N(&%L;'5V86ED+B(*"B,Z
M(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8P.`IM<V=I
M9"`B(@HB0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L
M:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R
M960N(@IM<V=S='(@(B(*(D5I('-A82#\;6)E<B!JY')J97-T861A+"#\;6)E
M<FKD<FIE<W1A;6ES96MS(&WDY')A='5D(&MA;FYE=&4@87)V(&5I(&ML87!I
M("(*(G-A;'9E<W1A='5D(&%R=G5G82XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R
M;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(D5I
M('-A82!S=75N871A('1E861E="!MY.1R871U9"!N=6UB<FEL92XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8X"FUS9VED(")#87!E(%9E<F1E(@IM<V=S='(@(E)O:&5L:7-E($YE
M96UE('-A87)E9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C0*;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`B4&5A
M;&MI<FDB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P
M+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B"FUS9W-T<B`B5&5E;G5S97!A:VMU
M:F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`*;7-G:60@(D-A=&5G
M;W)I97,@86YD($QA8F5L<R(*;7-G<W1R(")+871E9V]O<FEA9"!J82!MY')G
M96YD:60B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS
M9W-T<B`B0V%Y;6%N:2!386%R960B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#96QL(%!H;VYE(@IM<V=S
M='(@(DUO8FEI;'1E;&5F;VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(U"FUS9VED(")#96QL(%!R;W!E<G1I
M97,B"FUS9W-T<B`B3&%H=')I(&]M861U<V5D(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D
M9&EN9SHB"FUS9W-T<B`B3&%H=')I('9O;V1E<F1U<SHB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Q"FUS9VED
M(")#96QL('!R;W!E<G1I97,B"FUS9W-T<B`B3&%H=')I(&]M861U<V5D(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*
M;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`B3&%H=')I=&4@=F%H96MA
M=6=U<SHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C<T"FUS9VED
M(")#96QL<&AO;F4B"FUS9W-T<B`B36]B:6EL=&5L969O;B(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED(")#96QT:6,@*$E33RTX.#4Y+3$T
M*2(*;7-G<W1R(")+96QT:2`H25-/+3@X-3DM,30I(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-@IM<V=I9"`B
M0V5N=&5R(@IM<V=S='(@(DME<VME;&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C4T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#
M96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B2V5S:RU!869R:6MA
M(%9A8F%R:6EK(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@
M(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(DME<VLM
M175R;V]P82`H25-/+3@X-3DM,BDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8Y.0IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*
M;7-G<W1R(")397)T:69I:V%A9&D@_&MS:6MA<VIA9"(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C$Q"FUS9VED(")#97)T:69I8V%T
M92!/=VYE<B(*;7-G<W1R(")397)T:69I:V%A9&D@;VUA;FEK(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G:60@(D-E<G1I
M9FEC871E(%!O;&EC:65S(@IM<V=S='(@(E-E<G1I9FEK86%D:2!P;VQI:71I
M:V%D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")#:&%D(@IM<V=S='(@(E1S:&%A
M9"(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*;7-G:60@(D-H86YG92(*;7-G<W1R
M(")-=75D82(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,0IM
M<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B375U9&$@<V%L
M87/U;F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G:60@(B(*
M(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@
M=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS+B(*
M;7-G<W1R("(B"B)-=75D82!N:6UE(&IA(&%A9')E<W-I(&UI9&$@:6YI;65S
M960@;N1E=F%D(&MU:2!N860@<VEN=2!K:7)J=2!L;V5V860@:F$@(@HB;F5I
M;&4@=F%S=&%V860N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C(T"FUS9VED("(B"B)#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S
M=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB
M0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(E/\<W1E
M96UI(&MO;F9I9W5R871S:6]O;B!E:2!V]6EM86QD82!S86QA<_5N82!M=75T
M82X@5O5T82#\:&5N9'5S="`@(@HB861M:6YI<W1R86%T;W)I9V$N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M-PIM<V=I9"`B0VAA<B(*;7-G<W1R(")-Y')K(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#
M:&5C7VL@3&EN:RXN+B(*;7-G<W1R(")?2V]N=')O;&QI(&QI;FMI+BXN(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-PIM<V=I9"`B0VAI;&4B"FUS9W-T<B`B5'-H:6EL:2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@(DAI:6YA(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE
M9"`H1T(R,S$R*2(*;7-G<W1R(")(:6EN82!L:6AT<W5S=&%T=60@*$=",C,Q
M,BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0VAI;F5S
M92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B2&EI;F$@=')A9&ET<VEO
M;VYI;&EN92`H0FEG-2DB"@IM<V=I9"`B0VAO;W-E($%P<&QI8V%T:6]N.B(*
M;7-G<W1R(")686QI(')A:V5N9'5S.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM
M<V=S='(@(E9A;&D@<V%L87/U;F$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,C8X"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*;7-G
M<W1R(")686QI(&MA<W5T86IA;FEM:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR.3@*;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SHB
M"FUS9W-T<B`B5F%L:2!K=75PY&5V861E(&5S:71U<W9I:7,Z(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR
M,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@
M;&ES=',I(@IM<V=S='(@(E9A;&D@;&]E;F1I('-T:6EL("AJY')J97-T871U
M9"!L;V5N9&ET92!J86]K<RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-34*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#:')I<W1M
M87,@27-L86YD(@IM<V=S='(@(DKU=6QU<V%A<F5D(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+G!H<#HR.30@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@Y
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D969I;FET:6]N(&]F("5S
M(&YO="!F;W5N9"XB"FUS9W-T<B`B2VQA<W-I("5S(&MI<FIE;&1U<W0@96D@
M;&5I='5D+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$T"FUS9VED(")#;&5A<B(*;7-G<W1R(")396QG92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L
M96%R($U33V9F:6-E('1A9W,B"FUS9W-T<B`B165M86QD82!-4T]F9FEC92!M
MY')G96YD:60B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"FUS9VED(")#
M;&5A<B!1=65R>2(*;7-G<W1R(")4_&AJ96YD82!PY')I;F<B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B165M86QD82!K87-U
M=&%J83H@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z
M,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B165M86QD82!K87-U=&%J
M82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T"FUS9VED
M(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`B5/QH:F5N9&$@:V%S=71A:F$@
M86YD;65D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,34*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`BU6AT=6P@<V5L
M9VEN96(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N
M:'1M;#HV,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B2VSU
M<'-A(&KD=&MA;6ES96MS(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL('9I82!(
M5%10(@IM<V=S='(@(D-L:6-K871E;&P@_&QE($A45%`B"@HC.B!S97)V:6-E
M<R]K97EB;V%R9"YP:'`Z,30V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3(*;7-G:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R(")3=6QE(&%K96XB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-`IM<V=I9"`B0VQO=61S(@IM<V=S
M='(@(E!I;'9E9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$V"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`B2&]M;6EK
M=6P@<&EL=F5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3<*;7-G:60@(D-L;W5D>2(*;7-G<W1R(")0:6QV97,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8T"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R
M(")+;V]K;W-S86%R960@*$ME96QI;F=I('-A87)E9"DB"@HC.B!T96UP;&%T
M97,O<&]R=&%L+W-I9&5B87(N:6YC.C(S"FUS9VED(")#;VQL87!S92!3:61E
M8F%R(@IM<V=S='(@(E!E:61A(&O\;&=R:6)A(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L
M;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B4&5I9&5T=60@<&EI<FIO;VYE9"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C<*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(DMO;'5M8FEA
M(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N
M<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@(E;D<G8B"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(T"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C4*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4P,"!S97)V:6-E
M<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K
M97(B"FUS9W-T<B`B5N1R=FEV86QI:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X-#8*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B
M5N1R=FD@=F%L:6LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`B5F5E<F=E.B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#8*;7-G:60@(D-O;'5M
M;B!T:71L97,B"FUS9W-T<B`B5F5E<F=U9&4@<&5A;&MI<FIA9"(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C0*;7-G:60@(D-O;6EC<R(*;7-G
M<W1R(")+;V]M:6MS:60B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*;7-G
M:60@(D-O;6UA;F0B"FUS9W-T<B`B2^1S:R(*"B,Z(&%D;6EN+V-M9'-H96QL
M+G!H<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R(")+Y'-U<FED
M82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I
M9"`B0V]M;65N="(*;7-G<W1R(")+;VUM96YT86%R(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C8*;7-G:60@(D-O;6UO;B!.86UE
M(@IM<V=S='(@(DQI:'1N:6UI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(D-O;6]R
M;W,B"FUS9W-T<B`B2V]M;V]R:60B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@
M(D9I<FUA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#
M;VUP=71E<G,B"FUS9W-T<B`B07)V=71I9"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR.3<*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R("))
M;&TB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T.0IM<V=I9"`B0V]N9&ET
M:6]N<R(*;7-G<W1R("));&TB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HY
M-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*;7-G<W1R(")+
M;VYF:6=U<F%T<VEO;VYI(&5R:6YE=G5S960B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,30S"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG
M('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@
M(E-E861I<W1U<R!S_&YK<F]N:7-E97)I;6ES96MS(%!$061E+"!N=71I=&5L
M969O;FED92!J82!/=71L;V]K:6=A+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ,S4*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N
M(@IM<V=S='(@(E-E861I<W1U<R!O;B!A96=U;G5D+B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG
M=7)E("5S(@IM<V=S='(@(E-E861I<W1A("5S(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHU,0IM<V=I9"`B0V]N9FER;2!087-S=V]R
M9"(*;7-G<W1R(")+:6YN:71A('-A;&%S]6YA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I
M9"`B0V]N9V\B"FUS9W-T<B`B2V]N9V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#
M;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@
M(DMO;F=O($1E;6]K<F%A=&QI:R!686)A<FEI:R(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@
M9F%I;&5D+B(*;7-G<W1R("+<:&5N9'5S(&YU<FIU<RXB"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T
M:6]N(&9A:6QE9#H@(@IM<V=S='(@(MQH96YD=7,@;G5R:G5S.B`B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3`*;7-G:60@(D-O;FYE
M8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T
M<B`B079A;&EK(';U=&UE<V5R=F5R(&5I(&%N;F$@_&AE;F1U<W0N(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDR"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME
M>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(D%V86QI:R!V]71M
M97-E<G9E<B!E:2!A;FYA(/QH96YD=7-T+B!0]6AJ=7,Z("5S("@E<RDB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@T-0IM<V=I9"`B0V]N;F5C
M=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`BW&AE;F1U<R!&
M5%`@<V5R=F5R:6=A(&YU<FIU<RXB"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I
M<W0Z,3`Q-`IM<V=I9"`B0V]N=&%C=',B"FUS9W-T<B`B2V]N=&%K=&ED(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4S"FUS
M9VED(")#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R
M(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B2V]N=&%K=&ED(/5N;F5S='5S(&QI
M<V%D82!S:6YU(&%A9')E<W-I<F%A;6%T=7-S92XB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4V(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-C,*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT
M<R!O9B!<(B5S7"(B"FUS9W-T<B`B7"(E<UPB('-I<W4B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HR.2!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z,S,*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@(DKD=&MA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-@IM<V=I9"`B0V]O:R!)<VQA;F1S(@IM<V=S='(@(D-O;VMI(%-A
M87)E9"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O
M:VEE(@IM<V=S='(@(DWU='1E=&5R82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0IM<V=I9"`B0V]P>2(*
M;7-G<W1R(")+;W!E97)I(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z("5S(@IM
M<V=S='(@(DMO<&5E<FEM:6YE(&YU<FIU<SH@)7,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,V"FUS9VED(")#;W!Y('-E
M;&5C=&EO;B(*;7-G<W1R(")+;W!E97)I('9A;&EK(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B"FUS
M9W-T<B`B0V]S="!)1"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B
M"FUS9W-T<B`B2V]S=&%R:6EK82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O=&4@
M9"=)=F]I<F4B"FUS9W-T<B`B0V]T92!D)TEV;VER92(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.CDW-@IM<V=I9"`B0V]U;&0@;F]T(%!'
M4"!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(D5I('-A86YU9"!K:7)J82!0
M1U!G82!K<OQP=&ED82XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HQ,#4S"FUS9VED(")#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92XB
M"FUS9W-T<B`B16D@<V%A;G5D(&MI<FIA(%!'4&=A(&%L;&MI<FIA<W1A9&$N
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3,*;7-G
M:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R
M(")%:2!S86%N=60@:VER:F$@4R]-24U%9V$@:W+\<'1I9&$N(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD
M(&YO="!3+TU)344@<VEG;B!M97-S86=E+B(*;7-G<W1R(")%:2!S86%N=60@
M:VER:F$@4R]-24U%9V$@86QL:VER:F%S=&%D82XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$X-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S(@IM<V=S='(@
M(D5I('-A86YU9"!L:7-A9&$@:V]N=&%K=&DN("5S(@H*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.CDV(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z,3(Q"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E
M<G9E<BXB"FUS9W-T<B`B16D@<V%A;G5D('-I<W-E($Q$05`@<V5R=F5R:7-S
M92XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#4W"FUS9VED(")#;W5L
M9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E<B(*;7-G<W1R(")%:2!S86%N=60@
M<VES<V4@3$1!4"!S97)V97)I<W-E(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R(")%
M:2!S86%N=60@:V]N=&]JY.1K:2!K;VYT<F]L;&ED82X@)7,B"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-#0Q"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C
M="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B16D@<V%A;G5D(/QH96YD=7-T
M($Q$05`@<V5R=F5R:6=A+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S
M97)V97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS9W-T<B`B16D@<V%A;G5D
M('-E<G9E<FEG82!<(B5S7"(@1E10(&%B:6P@_&AE;F1U<W0Z("5S(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B2F%O='5S;FEM96MI<FIA(&QO;VUI
M;F4@;G5R:G5S+B`E<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$Q,C4*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+B(*
M;7-G<W1R(")%:2!S86%N=60@4$=0(&%N9&UE:60@9&5K<OQP=&ED82XB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R,@IM<V=I9"`B
M0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(D5I('-A
M86YU9"!3+TU)344@86YD;65I9"!D96MR_'!T:61A+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,B"FUS
M9W-T<B`B16D@<V%A;G5D(&MU<W1U=&%D82!K;VYT86MT:2X@)7,B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")%:2!S86%N=60@:W5S='5T861A(&IA
M;W1U<VYI;65K:7)J82X@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E('-E
M='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B16D@<V%A;G5D
M(&MU<W1U=&%D82!P86EG86QD=7-E('5U96YD86UI<V4@<VMR:7!T:2!<(B5S
M7"(N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.#$@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.34S"FUS9VED(")#;W5L
M9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S
M<RXB"FUS9W-T<B`B16D@<W5U=&YU9"!VY&QJ82!S96QG:71A9&$@861R97-S
M86%D:2!E+7!O<W1I(&%A9')E<W,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U;&0@;F]T(&9E
M=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B2V]G=2!A861R
M97-S:7)A86UA='4@:V]H86QE=&ER:6UI;F4@;G5R:G5S+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"FUS9VED
M(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N
M(@IM<V=S='(@(DMO9W4@:F%O='5S;FEM96MI<FIA(&MO:&%L971I<FEM:6YE
M(&YU<FIU<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C0T-@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP
M;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS9W-T<B`B2V]G
M=2!J86]T=7-N:6UE:VER:F%D92!N:6UE:VER:F$@:V]H86QE=&ER:6UI;F4@
M;G5R:G5S+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@
M7"(E<UPB+B(*;7-G<W1R(")%:2#U;FYE<W1U;G5D(&QA861I9&$@<W1R871E
M96=I870@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2]D:7)E8W0N<&AP.C,P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(FUK9&ER(%PB)7-<(B!N=7)J
M=7,N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S$Y"FUS
M9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y
M<V5R=F5R+B(*;7-G<W1R(")%:2!S86%N=60@=O5T;65S97)V97)I<W0@879A
M;&EK:W4@=O5T:70@:^1T=&4N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R
M('=R:71I;F<N(@IM<V=S='(@(EPB)7-<(B!A=F%M:6YE(&MI<FIU=&%M:7-E
M:W,@;G5R:G5S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@;W!E;B`E<RXB"FUS9W-T<B`B)7,@879A;6EN92!N=7)J=7,N(@H*(SH@
M9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HT,3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?
M5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B16D@<W5U=&YU9"!KY&EV:71A9&$@
M:&]O;&1U<W3V]B!M;V]D=6QI="`E<R(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HW
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O
M<GD@7"(E<UPB+B(*;7-G<W1R(")%:2!S86%N=60@879A9&$@:V%T86QO;V=I
M(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M,3$Q(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(S-R!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z-#<X"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HU,38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C8Q,@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C4V(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV.3D*;7-G:60@(D-O=6QD
M(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(D5I('-A86YU
M9"!KY'1T92!,1$%0('-E<G9E<FET+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+T]B:F5C="YP:'`Z,C,X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!R96%D("5S+B(*;7-G<W1R("(E<R!L=6=E;6EN92!N=7)J=7,N(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD
M(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E
M<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C;W)R
M96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@
M:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B)3;V]V
M:71U9"!K87-U=&%J82!P87)O;VQI('3\:&IE;F1A;6EN92!N=7)J=7,N($WU
M;F5D(&%N9&UE9"!E:2!O;&4@]6EG960N("(*(E!R;V]V:2!U=65S=&D@=O5I
M(';U=&$@_&AE;F1U<W0@861M:6YI<W1R86%T;W)I9V$L(&MU:2!V86IA9"!S
M:6ES:VD@86)I+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,P.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS-#`*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S<W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,X,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M.#D*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B04-,
M:2!L86%D:6UI;F4@96)A]6YN97-T=7,B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G
M<W1R(")!861R97-S:7)A86UA='4@;&%A9&EM:6YE(&5B8?5N;F5S='5S+B`E
M<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B2F%O='5S;FEM96MI
M<FIA(&QA861I;6EN92!E8F'U;FYE<W1U<RX@)7,B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0S-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI
M<W1S+B`E<R(*;7-G<W1R(")*86]T=7-N:6UE:VER:F%D92!L86%D:6UI;F4@
M96)A]6YN97-T=7,N("5S(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HR,C,*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!S97)V97(G
M<R!C87!A8FEL:71I97,B"FUS9W-T<B`B4V5R=F5R:2!V]6EM86QU<W1E(&QA
M861I;6EN92!E8F'U;FYE<W1U<R(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-30*;7-G:60@(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B2V]N9FEG=7)A='-I;V]N:2!T86=A<VEM=75T;6EN92!N=7)J
M=7,N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S='(@(G)M9&ER(%PB
M)7-<(B!E:2#U;FYE<W1U;G5D+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B5S('-E861I<W1U<V4@<V%L=F5S
M=&%M:6YE(&YU<FIU<RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3D*;7-G:60@(D-O=6QD(&YO="!S
M879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B2V]N9FEG=7)A
M='-I;V]N:2!V87)U:V]O<&EA('-A;'9E<W1A;6EN92!N=7)J=7,N(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS
M9W-T<B`B2V]N9FEG=7)A='-I;V]N:2!V87)U:V]O<&EA('-A;'9E<W1A;6EN
M92!N=7)J=7,Z("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.34*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G
M<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B4&%I9V%L9'5S92!U
M=65N9&%M:7-E('-K<FEP=&D@96D@<V%A;G5D('-A;'9E<W1A9&$@:V]H=&$Z
M(%PB)7-<(BXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N
M9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R(")%:2#U;FYE<W1U;G5D('-A
M;'9E<W1A9&$@:V]N9FEG=7)A='-I;V]N:69A:6QI('9A<G5K;V]P:6%T("5S
M+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@
M9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@(@HB;W!T
M:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU
M86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B(@HB2V]N9FEG
M=7)A='-I;V]N:69A:6QI("5S(&5I(/5N;F5S='5N=60@<V%L=F5S=&%D82X@
M4V$@=O5I9"!K87-U=&%D82#\:'0@(@HB=O5I;6%L=7-T(&MO;V1I('-A;'9E
M<W1A;6ES96MS('1A9V%S:2!F86EL:2`E<R!V]6D@:V]P965R:61A(&MO;V0@
M:^1S:71S:2`B"B)F86EL:2`E<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C$T,PIM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!
M4"!S97)V97(N(@IM<V=S='(@(DQ$05`@;W1S:6YG(&YU<FIU<RXB"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDO8V]P>2YP:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(G5N;&EN:R!<(B5S7"(@;G5R
M:G5S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A
M=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B2V]N=&%K=&D@=75E;F1A;6EN92!N
M=7)J=7,N("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B2F%O='5S
M;FEM96MI<FIA('5U96YD86UI;F4@;G5R:G5S+B`E<R(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G<W1R
M(")<(B5S7"(@<V5A9&ES='5S92!S86QV97-T86UI;F4@;G5R:G5S.B`E<R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C8*;7-G:60@(D-O=6QD;B=T
M(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E
M8F%R(&ES(&]P96XN(@IM<V=S='(@(D5I(&QE:61N=60@36]Z:6QL82!K_&QG
M:7)B82X@5F%A=&$@970@:_QL9W)I8F$@;VQE:W,@879A='5D+B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H
M92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B
M"FUS9W-T<B`B2V%S=71A:F%L92!<(B5S7"(@96D@<V%A;G5D(&%N9&$@:N1R
M9VUI<VD@]6EG=7-E:60@:V%U<W1A;&4@7"(E<UPB.B`E<R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T,3D*;7-G:60@(D-O=6YT960@=&5X="(*
M;7-G<W1R(")0:6ER871U9"!P:6MK=7-E9V$@=&5K<W0B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I9"`B0V]U;G1R>2(*
M;7-G<W1R(")2:6EK(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W
M,PIM<V=I9"`B0V]U<G-E<R(*;7-G<W1R(")+=7)S=7-E9"(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P
M,`IM<V=I9"`B0W)E871E(@IM<V=S='(@(DQO;R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B
M0W)E871E(&$@;&EN:R(*;7-G<W1R("),:7-A(&QI;FLB"@HC.B!T96UP;&%T
M97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDT"FUS9VED(")#<F5A=&4@
M82!N97<@;VYE(@IM<V=S='(@(DQI<V$@=75S(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@(D-R96%T92!S=6(@
M9F]L9&5R<R(*;7-G<W1R("),:7-A(&%L86UK875S=&%D(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-#`*;7-G:60@(D-R96%T;W(@4&5R
M;6ES<VEO;G,B"FUS9W-T<B`B075T;W)I(/5I9W5S960B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,C,P"FUS9VED(")#<F5D:70@8V%R9"!N=6UB
M97(B"FUS9W-T<B`B2W)E9&EI=&MA87)D:2!N=6UB97(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M.0IM<V=I9"`B0W)O871I82(*;7-G<W1R(")(;W)V86%T:6$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8X"FUS9VED(")#=6)A(@IM<V=S='(@(DMU=6)A(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C(V"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@
M(E!R865G=7-E9"`T(&9A87-I(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C0X
M"FUS9VED(")#=7)R96YT(%-E<W-I;VYS(@IM<V=S='(@(D%K=&EI=G-E9"!S
M97-S:6]O;FED(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K
M+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T<B`B2V5L
M;&%A96<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@
M(E!R865G=6YE(%523"!O;B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS,PIM
M<V=I9"`B0W5R<F5N="!5<V5R<R(*;7-G<W1R(")!:W1I:79S960@:V%S=71A
M:F%D(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I9"`B0W5R<F5N
M="!796%T:&5R(@IM<V=S='(@(E!R865G=6YE(&EL;2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-S4*;7-G:60@(D-U<G)E;G0@8V]N9&ET
M:6]N.B`B"FUS9W-T<B`B4')A96=U;F4@:6QM.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@
M<W1Y;&4B"FUS9W-T<B`B4')A96=U;F4@<W1I:6PB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3`X"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ
M92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B2.3D
M;&5S=&$@=/9I9"!M:61A('1E:&%K<V4@<VES96YE;6ES96P@)7,M:2XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C`*;7-G:60@(D-U="(*;7-G<W1R("),]6EK82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@(D-U="!S
M96QE8W1I;VXB"FUS9W-T<B`B3/5I:V$@=F%L:6LB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS
M9VED(")#>7!R=7,B"FUS9W-T<B`B2_QP<F]S(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#(*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@
M(DMI<FEL;&ET<V$@*$M/23@M4BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X,PIM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`B
M2VER:6QL:71S82`H5VEN9&]W<RTQ,C4Q*2(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@T"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB
M"FUS9W-T<B`B2VER:6QL:71S82]5:W)A:6YA("A+3TDX+54I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.0IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS9W-T<B`B5'-E:&AI(%9A
M8F%R:6EK(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0U,2!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B1$0B"FUS
M9W-T<B`B4%`B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@Q"FUS
M9VED("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E
M;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@IM<V=S='(@
M(B(*(D133B`H=F%A=&$@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO
M<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*"B,Z(&9R86UE
M=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3D*;7-G:60@(D1A
M:6QY(@IM<V=S='(@(DEG82!PY&5V(@H*(SH@861M:6XO9&%T871R964N<&AP
M.C8U"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@(D1A=&%4<F5E
M('-I<G9I:F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<Y"FUS
M9VED(")$871A8F%S92!,;V]K=7`B"FUS9W-T<B`B06YD;65B86%S:6]T<VEN
M9R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y.0IM<V=I9"`B1&%T92(*
M;7-G<W1R(")+=75PY&5V(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z,3,*;7-G:60@(D1A=&4@4F5C96EV960B"FUS9W-T<B`B4V%A
M8G5M:7-E(&MU=7#D978B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.#`W"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R(")+=75PY&5V82!V
M86QI:R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3(@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,R,@IM<V=I9"`B1&%Y(@IM<V=S
M='(@(E#D978B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S
M='(@(DMU7W-T=71A('9E97)G(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(D1E
M='-E;6)E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G
M<W1R(")+_&UN96YD;G5M8G)I9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C`*;7-G:60@(D1E8W)E87-E($EN9&5N="(*
M;7-G<W1R(")6Y&AE;F1A('1A86YD<FED82(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,3@W(&QI8B]P<F5F<RYP:'`Z,3$W"FUS9VED(")$
M969A=6QT(@IM<V=S='(@(E9A:6MI;6ES:2(*"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"FUS9VED(")$969A=6QT($-O
M;&]R(@IM<V=S='(@(E9A:6MI;6ES:2!VY')V(@H*(SH@9G)A;65W;W)K+TED
M96YT:71Y+TED96YT:71Y+G!H<#HY,0IM<V=I9"`B1&5F875L="!)9&5N=&ET
M>2(*;7-G<W1R(")686EK96ED96YT:71E970B"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-C<*;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`B5F%I
M:VEM:7-I('-H96QL(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS
M9VED(")$969I;FET:6]N<R(*;7-G<W1R(")3]6YA<V5L971U<V5D(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HW,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C,R-@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C,V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$Q-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$S.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.CDX"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN
M8SHQ,"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B
M1&5L971E(@IM<V=S='(@(DMU<W1U=&$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S(*;7-G:60@(D1E;&5T
M92!#96QL(@IM<V=S='(@(DMU<W1U=&$@;&%H=&5R(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR,C<*;7-G:60@(D1E;&5T
M92!'<F]U<"(*;7-G<W1R(")+=7-T=71A(&=R=7!P(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,C0Y"FUS9VED(")$96QE=&4@3&]G(@IM<V=S
M='(@(DMU<W1U=&$@;&]G:2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z-S<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#$*;7-G
M:60@(D1E;&5T92!097)M:7-S:6]N(@IM<V=S='(@(DMU<W1U=&$@]6EG=7,B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,PIM
M<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R(")+=7-T
M=71A(&IA(&5E;6%L9&$@:VER:F%D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E(&-E
M;&PB"FUS9W-T<B`B2W5S='5T82!L86AT97(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8S"FUS9VED(")$96QE
M=&4@8V]L=6UN(@IM<V=S='(@(DMU<W1U=&$@=F5E<F<B"@HC.B!A9&UI;B]T
M96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R
M;F%T92!T96UP;&%T92(*;7-G<W1R(")+=7-T=71A(&]L96UA<V]L978@86QT
M97)N871I:79N92!M86QL(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C-#,Q-"YP:'`Z-30*;7-G:60@(D1E;&5T92!M97-S86=E<R(*;7-G<W1R
M(")+:7)J861E(&MU<W1U=&%M:6YE(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E
M<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B2W5S='5T82#U:6=U<V5D
M(%PB)7-<(BUL92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M-#(T"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F
M;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R(")+
M=7-T=71A(/5I9W5S960@7"(E<UPB+6QE(&IA(&OU:6L@86QA;?5I9W5S960_
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV-PIM<V=I9"`B1&5L971E(')O=R(*;7-G<W1R(")+=7-T=71A(')I
M9&$B"@HC.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U
M"FUS9VED(")$96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B2W5S
M='5T82!V86QI='5D(&ED96YT:71E970B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T
M92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`B2W5S='5T82!A:W1I:79N
M92!V965R9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O
M=R(*;7-G<W1R(")+=7-T=71A(&%K=&EI=FYE(')I9&$B"@HC.B!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HS-@HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE
M=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B2W5S
M='5T87-I;B!P86EG86QD=7-E('5U96YD86UI<V4@<VMR:7!T:2!<(B5S7"(N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU.34*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(U,PIM<V=I9"`B1&5L:79E<GD@=&EM92(*;7-G<W1R
M(")+Y'1T971O:6UE=&%M:7-E(&%E9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1E
M;FUA<FLB"FUS9W-T<B`B5&%A;FDB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS
M9W-T<B`B2VER:F5L9&$@<')O8FQE96UI(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.3,X('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S`*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(DMI
M<FIE;&1U<R(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DU"FUS
M9VED(")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S
M='(@(MQK<VEK87-J860@*&MA;G1U9"!K82!(;W)D92!L;V=I9F%I;&DI.B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DY"FUS9VED(")$971A
M:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*
M;7-G<W1R("+<:W-I:V%S:F%D(&QO9VET:2!A9&UI;FES=')A871O<FD@:F%O
M:W,N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Q.0IM<V=I9"`B
M1&5V96QO<&UE;G0B"FUS9W-T<B`B07)E;F1U<R(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C$W"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B2V%S=&5P
M=6YK="(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDT"FUS9VED(")$97<@
M4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(D5E;&UI<V4@='5N;FD@
M:V%S=&5P=6YK="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,C<*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(DMA<W1E<'5N:W0Z(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM
M<V=I9"`B1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`B4W5U;F0@
M=F%S86MU;'0@<&%R96UA;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@
M;&5F="(*;7-G<W1R(")3=75N9"!P87)E;6%L="!V87-A:W5L92(*"B,Z(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T
M<B`B2V%T86QO;V<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C8V"FUS
M9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@(D5S:71A(&ME
M;&QA86IA9"`R-"UT=6YN:7-E;F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.3<*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R(")%:W)A86YI
M('-E861E9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HY-@IM
M<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R(").Y&ET
M82!P]6AJ86QI:VMU(&5N;G5S='5S="(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z.#4*;7-G:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B
M3N1I=&$@96YN=7-T=7-T("A4048I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C@Q-PIM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B16MR
M86%N:2!S96%D960B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z
M,3DP"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B
M1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B
M1&II8F]U=&DB"FUS9W-T<B`B1&II8F]U=&DB"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C0R,@IM<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G
M<W1R("+$<F$@:W5S='5T82(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC
M92YP:'`B"FUS9W-T<B`BQ')A(/QR:71A(&UA:6YT96YA;F-E+G!H<"!F86EL
M:2!O='-E(&OD:79I=&%D82(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N
M:6YC.C$R('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$R"FUS9VED(")$
M;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF
M('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(DMU:2!E<VEM96YE(')I
M9&$@<VES86QD86(@=N1L:F%D92!N:6UE<VED+"!MY')G:2!S964@<G5U=#HB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R(")$;VUI;FEC
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S`*;7-G:60@(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G
M<W1R(")$;VUI;FEK86%N:2!686)A<FEI:R(*"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@
M4VEG;B!U<"XB"FUS9W-T<B`B4W5L('!O;&4@:V]N=&]T/R!296=I<W1R965R
M=2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*
M;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(E-A;'9E<W1A(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0T"B,L('!H<"UF;W)M870*
M;7-G:60@(D1O=VYL;V%D("5S(@IM<V=S='(@(E-A;'9E<W1A("5S(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO860@9V5N
M97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`B
M4V%L=F5S=&$@;&]O9'5D('-E861I<W1U<R!02%`@<VMR:7!T:6YA+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#<*;7-G:60@(D1R;W`@9&]W
M;B!L:7-T(@IM<V=S='(@(DYI;65K:7)I(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G<W1R(")2879I;6ED(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")%+4UA
M:6PB"FUS9W-T<B`B12UP;W-T(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E
M=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S
M97)V:6-E+B(*;7-G<W1R("(B"B)%+7!O<W0M4TU3:6QE('9A:&5N9'5S9')A
M:79E<BP@=&5E;G5S97!A:VMU:F%T96QE(&ME;&QE;"!S96QL:6YE('1E96YU
M<R!O;B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R(")%
M4E(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<P"FUS9VED(")%8W5A9&]R(@IM<V=S='(@(D5K=6%D
M;W(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-2!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,2!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="(*;7-G<W1R(")-=75D82(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3`@=&5M<&QA=&5S
M+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="!";&]C:R(*;7-G<W1R
M(")-=75D82!B;&]K:VDB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y."!A9&UI
M;B]G<F]U<',N<&AP.C(R-@IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R(")-
M=75D82!G<G5P<&DB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C<V(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`P"FUS9VED(")%
M9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`B375U9&$@]6EG=7-T(@H*(SH@<V5R
M=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B161I="!097)M:7-S
M:6]N<R(*;7-G<W1R(")-=75D82#U:6=U<VDB"@HC.B!S97)V:6-E<R]S:&%R
M97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@4&5R
M;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(DUU=61A("5S(/5I9W5S:2(*"B,Z
M('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N
M<R!F;W(Z(@IM<V=S='(@(DUU=61A('-E861E:60Z(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M161I="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(DUU=61A(%PB
M)7-<(B#U:6=U<VDB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T
M"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S
M(@IM<V=S='(@(DUU=61A("5S(/5I9W5S:2(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS-0IM<V=I9"`B161U8V%T:6]N(@IM<V=S='(@(DAA<FED=7,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*;7-G<W1R(")%9VEP='5S(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B16ET:&5R(&5N86)L92!I="!T:&5N.B`E<RP@;W(@=7-E('1H
M92!B87-I8R!(5$U,('9E<G-I;VXZ("5S+B(*;7-G<W1R("),_&QI=&$@<V5E
M('-I<W-E(&IA('-I:7,Z("5S+"!V]6D@:V%S=71A(&QI:'1S870@2%1-3"!V
M97)S:6]O;FDZ("5S+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B16P@4V%L=F%D
M;W(B"FUS9W-T<B`B16P@4V%L=F%D;W(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L96UE
M;G0N+BXB"FUS9W-T<B`B16QE;65N="XN+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R
M(")%;2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HR,C0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V.0IM<V=I9"`B16UA
M:6PB"FUS9W-T<B`B12UP;W-T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-C4@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN
M8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"FUS
M9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D4M<&]S=&D@86%D<F5S<R(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C,*;7-G:60@(D5M86EL
M(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")%+7!O<W1I(&%A9')E
M<W-I9"!P96%V860@:VQA<'!I;6$N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3DX.0IM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M871I;VXB"FUS
M9W-T<B`B12UP;W-T(&MI;FYI='5S96=A(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O+5--
M4R!'871E=V%Y(@IM<V=S='(@(D4M<&]S="U335-I;&4@;/S\<R(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR.3@*;7-G:60@
M(D5M;W1I8V]N<R(*;7-G<W1R(")3;6%I;&ED(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R"FUS9VED(")%;7!T
M>2!M97-S86=E+B(*;7-G<W1R(")3]6YU;2!O;B!T_&AI+B(*"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR-#,@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C0X-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-C8R(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW
M,#4*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-3`*;7-G:60@
M(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B5'5L96UU<R!O;B!T_&AI+B(*"B,Z
M(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M
M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R(")/='-I;F=U=&EN9VEM=7,@;VX@
M=/QH:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#,*;7-G:60@(D5N
M86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S
M(&EN('1E>'0_(@IM<V=S='(@(DQU8F$@=&5K<W1I('-I<W-E(&QI<V%D82!P
M:6QT92!F;W1O9V%L97)I:61E<W0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3$X"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU
M/R(*;7-G<W1R("),=6)A('!A<F5M:VSU<'-U9V$@:/QP:6MM96[\_"(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.3@@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C@Q,0IM<V=I9"`B16YD('EE87(B"FUS9W-T<B`B06%S=&$@
M;/5P<"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@(E-U=7)E;F1A
M(&5D:71O<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C$*;7-G:60@
M(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@
M8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S=V]R
M9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G
M<W1R("(B"B)3:7-E<W1A('-A;&%J86YE(&O\<VEM=7,@;6ED82!S:6YU;'0@
M:_QS:71A:W-E('!A<F]O;&D@;75U=&UI<V5K<RP@;N1I=&5K<R`B"B(G;6ES
M(&]N('-I;G4@;&5M;6EK;&]O;6$@;FEM:3\G.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I
M9"`B16YT97(@=&AE(&EM86=E(%523"!H97)E(@IM<V=S='(@(E-I<V5S=&$@
M<VEI82!P:6QD:2!54DPB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.#DQ"FUS9VED(")%;G1E<B!T:&4@;&5T=&5R<R!B96QO
M=SHB"FUS9W-T<B`B4VES97-T82!A;&QA('3D:&5D.B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*
M;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(D5K=F%T;W)I86%L
M+4=I;F5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E82(*;7-G<W1R(")%
M<FET<F5A(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I
M;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4U
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S8@<V5R=FEC97,O<&]R=&%L+VEN
M9&5X+G!H<#HX,@IM<V=I9"`B17)R;W(B"FUS9W-T<B`B5FEG82(*"B,Z(&9R
M86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8S"B,L('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R(")6
M:6=A(&)L;VMI(&QO;VUI<V5L.B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T
M:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G<W1R(")6:6=A('/\;FMR;VYI<V5E
M<FEM:7-A;FMR=2!K=7-T=71A;6ES96PZ("5S(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M9&5L971I;F<@<WEN8R!L;V<Z("5S(@IM<V=S='(@(E9I9V$@<_QN:W)O;FES
M965R:6UI<V4@;&]G:2!K=7-T=71A;6ES96PZ("5S(@H*(SH@9G)A;65W;W)K
M+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*;7-G<W1R(")6:6=A('-I
M<W4@;&%A9&EM:7-E;#H@)7,B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=7!D871I;F<@
M<&%S<W=O<F0Z("5S(@IM<V=S='(@(E9I9V$@<V%L87/U;F$@;75U=&UI<V5L
M.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET:"!E;6%I;"!M97-S86=E+B(*
M;7-G<W1R(")6:6=A(&4M<&]S=&D@=&5A=&5S+B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN9R!<
M(B5S7"(N(@IM<V=S='(@(E9I9V$@7"(E<UPB(&MI<FIU=&%M:7-E;"XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<P"FUS9VED(")%<W1O;FEA(@IM<V=S='(@(D5E<W1I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`B171I;V]P:6$B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G
M<W1R(")286AV=7-L:6LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-34*;7-G:60@(D5U<F]P92(*;7-G<W1R(")%=7)O;W!A(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,S.0IM<V=I9"`B179E<GD@,34@;6EN=71E
M<R(*;7-G<W1R("))9V$@,34@;6EN=71I('1A9V%N="(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.#D*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G
M<W1R("))9V$@,B!M:6YU=&D@=&%G86YT(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,S-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@W"FUS9VED(")%
M=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(DEG82`S,"!S96MU;F1I('1A9V%N
M="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S@@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,Y,`IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@
M(DEG82`U(&UI;G5T:2!T86=A;G0B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N
M8V4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G
M<W1R("))9V%L('-I<W-E;&]G:6UI<V5L(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,T,`IM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(DEG
M82!P;V]L92!T=6YN:2!T86=A;G0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S,W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#@*;7-G:60@(D5V97)Y
M(&UI;G5T92(*;7-G<W1R(")+;W)D(&UI;G5T:7,B"@HC.B!T96UP;&%T97,O
M9&%T82]D871E;6%P+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V86QU97,Z(@IM
M<V=S='(@(D[D:61I<W;DY')T=7-E9#HB"@HC.B!A9&UI;B]P:'!S:&5L;"YP
M:'`Z.#$@861M:6XO8VUD<VAE;&PN<&AP.C4P(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,C<*;7-G:60@(D5X96-U=&4B"FUS9W-T<B`B2^1I=FET82(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C0W-0IM<V=I9"`B17AP
M86YD(@IM<V=S='(@(DQA:65N9&$B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I
M9&5B87(N:6YC.C,R"FUS9VED(")%>'!A;F0@4VED96)A<B(*;7-G<W1R(").
MY&ET82!K_&QG<FEB82(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S
M+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R(")/;W1A<VEN
M("<I)R(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-S4*
M;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E
M<FTB"FUS9W-T<B`B3V]T87-I;B!L:6AT<V%T('/U;F$@=O5I(&IU='5MY')K
M:61E<R!O='-I;F=U9G)A87-I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$R"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B
M065G=6UI<V4@:W5U<.1E=B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C<V"FUS9VED(")%>'!O;F5N="(*;7-G<W1R(")%:W-P;VYE
M;G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,Q"FUS9VED(")&1R!#;VQO<B(*;7-G<W1R(")496MS=&D@=N1R
M=B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S<*;7-G:60@(D944"!U
M<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B4V5A9&ES='5S92#\;&5S;&%A9&EM
M:6YE($944"!K875D=2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S<6PN
M<&AP.C(Q-@IM<V=I9"`B1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N
M(@IM<V=S='(@(DCDY&QE<W1U<V4@;&%A9&EM:6YE(&YU<FIU<RXB"@HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S4@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@
M=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(D5I('-A86YU9"#\:&5N9'5S="!,
M1$%0('-E<G9E<FEG82XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP
M:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N
M(@IM<V=S='(@(D5I('-A86YU9"#\:&5N9'5S="!334(@<V5R=F5R:6=A+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C@V"B,L('!H<"UF;W)M
M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R
M(")%:2!S86%N=60@:V]P965R:61A(%PB)7-<(BUS="XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C8Y,0HC+"!P:'`M9F]R;6%T"FUS9VED(")&
M86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(D5I('-A86YU9"!K
M;W!E97)I9&$@7"(E<UPB+6DN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S
M87-L+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C
M;VYN96-T:6]N+B(*;7-G<W1R(")5=64@4T%33"#\:&5N9'5S92!L;V]M:6YE
M(&YU<FIU<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y-R!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(D5I('-A
M86YU9"!T]7-T82!<(B5S7"(M:2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C0V,0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@<F5T
M<FEE=F4Z("5S(@IM<V=S='(@(D5I('-A86YU9"!T:7)I9&$Z("5S(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*;7-G:60@
M(D9A:7(B"FUS9W-T<B`B2&5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA
M;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@(D9A;&ML86YD:2!S86%R
M960@*$UA;'9I:6YI9"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&87)O92!)<VQA
M;F1S(@IM<V=S='(@(D;DY')I('-A87)E9"(*"B,Z(&9R86UE=V]R:R]#3$DO
M0TQ)+G!H<#HR,S@*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R(")+;VAU
M=&%V('9I9V$Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@(D9A:W,B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Y"FUS9VED(")&87AE<R(*;7-G<W1R
M(")&86MS:60B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B5F5E8G)U87(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R,`IM<V=I9"`B1F5E;',@3&EK92(*
M;7-G<W1R(")4=6YD=6(@;F%G=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,S$*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R(")4=6YD
M=6(@;F%G=3H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S='(@(MQK<VEK=60@
M=FEH;6%H;V]D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`BW&MS
M:6MU9"!L=6UE<V%J=6AO;V0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.30T"FUS9VED(")&:65L9"!M871R:7@B"FUS9W-T<B`B1FEE;&0@;6%T
M<FEX(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S-`IM<V=I9"`B
M1FEG;&5T($-!4%1#2$$B"FUS9W-T<B`B1FEG;&5T($-!4%1#2$$B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,X"FUS9VED(")&:6=L970@9F]N
M="(*;7-G<W1R(")&:6=L970@9F]N="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9I
M:FDB"FUS9W-T<B`B1FED>FDB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR-34*;7-G:60@(D9I;&4B"FUS9W-T<B`B1F%I;"(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I
M;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B1F%I;&ED92!A<G8Z("5S(&9A
M:6PB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R(")&86EL
M:61E(&%R=CH@)7,@9F%I;&DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#`W"FUS9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`B1F%I;&EH86QD
M=7(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8S
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-0IM<V=I9"`B1FEL
M92!.86UE(@IM<V=S='(@(D9A:6QI(&YI;6DB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.3DU"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R
M(")&86EL:2!V86QI:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T
M.#8*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(D9A:6QI(/QL97-L86%D
M:6UI;F4B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-3D*
M;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R(")&
M86EL:61E(/QL97-L86%D:6UI<W0@96D@=&]E=&%T82XB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z.#D*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`B
M1FEL=')I9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`B
M4V]O;64B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED(")&:7)S
M="!(86QF(@IM<V=S='(@(D5S:6UE;F4@<&]O;"(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T
M(%%U87)T97(B"FUS9W-T<B`B17-I;65N92!V965R86YD(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U-@IM<V=I9"`B1FEX
M(')A=&EO(@IM<V=S='(@(E/D:6QI=&$@<W5H92(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,S$*;7-G:60@(D9L:7`B"FUS
M9W-T<B`B4&5E9V5L9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R(")(
M]6QJ=78B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR,0IM<V=I9"`B1F]G(@IM<V=S='(@(E5D=2(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,C,T(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HQ,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T
M(&5X:7-T(@IM<V=S='(@(DMA=&%L;V]G:2`E<R!P;VQE(&]L96UA<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G
M:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`B5&5K<W1I(';D<G8B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`B5&]I
M="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R;W=S97)S('1H870@9&]N)W0@
M<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B5F5E8FEL96AI='-E:F%T96QE(&UI
M<R!P:6QT92!E:2!T;V5T82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,T
M"FUS9VED(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R(")%;FYU<W1U<R`H5$%&
M*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW.0IM<V=I9"`B
M(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E
M8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G92!N
M=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G
M<W1R("(B"B)0Y&5V861E(&%R=B`H;VQG=2#V96QD=60@970@=&%G87-T871A
M=B!E;FYU<W1U<R!S:7-A;&1A8B!N:6D@<.1E=FD@:W5I(/9I9#L@(@HB<W5U
M<B!A<G8@=O5I8B!B;&]K:2!L86EA:W,@=F5N:71A9&$I(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,#(*;7-G:60@(D9O<F=O="!Y;W5R('!A
M<W-W;W)D/R(*;7-G<W1R(")5;G5S=&%S:60@<V%L87/U;F$_(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V,@IM<V=I9"`B1F]R;7,B"FUS9W-T
M<B`B5F]R;6ED(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"FUS9VED
M(")&;W)T=6YE(@IM<V=S='(@(DMI;&0B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R(")+:6QL=2!T
M_/QP(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,X"FUS9VED(")&;W)T
M=6YE<R(*;7-G<W1R(")+:6QL=60B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B2VEL;'5D(#(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4S"FUS9VED(")&;W)U;7,B
M"FUS9W-T<B`B1F]O<G5M:60B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3`Y"FUS9VED(")&;W)W87)D<R(*;7-G<W1R(")%9&%S='5S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,`IM<V=I
M9"`B1G(B"FUS9W-T<B`B4F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,S"FUS9VED(")&<F%M97,B"FUS9W-T
M<B`B4F%A;6ED(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E(@IM<V=S='(@
M(E!R86YT<W5S;6%A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R(")0<F%N
M='-U<VUA82P@175R;V]P82UO<V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N
M8V@@1W5I86YA(@IM<V=S='(@(E!R86YT<W5S92!'=6%J86%N82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDX"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(E!R86YT
M<W5S92!0;VS\;F5E<VEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@
M4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B4')A;G1S=7-E($SU=6YA
M86QA9"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP
M:'`Z-S0*;7-G:60@(D9R;VTB"FUS9W-T<B`B2V5L;&5L="(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#@@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,V,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-#`V"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B4W5U;F%G82`B"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT.`IM<V=I9"`B1G5L;"!$
M97-C<FEP=&EO;B(*;7-G<W1R(")0]6AJ86QI:R!K:7)J96QD=7,B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-@IM
M<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(E3D:7-K=74B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHV,`IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(E3D:7-N:6UI(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,PIM<V=I9"`B1V%B;VXB"FUS9W-T<B`B1V%B;VXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S
M='(@(D=A;&5R:6DL(&MU<W0@<&EL="!V]71T82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I
M9"`B1V%L;&5R>3HB"FUS9W-T<B`B1V%L97)I:3HB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS
M9VED(")'86UB:6$B"FUS9W-T<B`B1V%M8FEA(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E
M<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(D=E;F5R965R:2`E<R!K;VYF:6=U
M<F%T<VEO;VXB"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT
M;6PZ.`IM<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B1V5N97)E97)I
M='5D(&MO;V0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDP(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'96]R9VEA(@IM<V=S='(@
M(D=R=75S:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")'97)M86YY(@IM<V=S='(@
M(E-A:W-A;6%A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`B
M1V%A;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDT(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':6)R86QT87(B"FUS9W-T<B`B
M1VEB<F%L=&%R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU-S4*;7-G:60@(D=I=F5N($YA;64B"FUS9W-T<B`B165S;FEM:2(*"FUS
M9VED(")';&]B86P@3W!T:6]N<R(*;7-G<W1R("+<;&1I<V5D('-E861E9"(*
M"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$R"FUS9VED(")';R(*;7-G
M<W1R(")-:6YE(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED
M(")';V5D96PB"FUS9W-T<B`B1_9D96PB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$R.`IM<V=I9"`B1V]O9VQE($UA<',B
M"FUS9W-T<B`B1V]O9VQE(&MA87)D:60B"@HC.B!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G
M;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H(@IM<V=S='(@(D=O;V=L
M92!O='-I;F<B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C,W"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B2&%L;'1O;VYI
M9&5S<V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W)E96-E(@IM<V=S='(@(DMR
M965K82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED(")'<F5E
M:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B2W)E96MA("A)4T\M.#@U.2TW*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S4*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R(")'<O;V;FEM
M86$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<T"FUS9VED(")'<F5N861A(@IM<V=S='(@(D=R96YA
M9&$B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W.0IM<V=I9"`B1W)O=7`@061M
M:6YI<W1R871I;VXB"FUS9W-T<B`B1W)U<'!I9&4@:&%L9'5S(@H*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+G!H<#HU.2!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO
M;BUE;7!T>2(*;7-G<W1R(")'<G5P<&ED92!N:6UE9"!E:2!V]6D@;VQL82!T
M_&AJ860B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S`W
M"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A
M9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*
M;7-G<W1R(")'<F]U<%]L9&%P.B!%:2!S86$@;&ES861A(&=R=7!P:2`E<RX@
M4V5R=F5R(/QT;&5S.B`B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z,3$X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,C0*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0Q.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R
M;W5P("5S(@IM<V=S='(@(D=R;W5P7VQD87`Z($5I('-A82!K=7-T=71A9&$@
M9W)U<'!I("5S(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C,S."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@
M9W)O=7`@)7,B"FUS9W-T<B`B1W)O=7!?;&1A<#H@16D@<V%A(&UU=71A(&=R
M=7!P:2`E<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S$T
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS9W-T<B`B1W)U<&ED(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-@IM<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R(")'=6%D96QO
M=7!E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U86TB"FUS9W-T<B`B1W5A;2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<W"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B1W5A=&5M
M86%L82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3(*;7-G:60@
M(D=U97)N<V5Y(@IM<V=S='(@(D=U97)N<V5Y(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B2_QL86QI
M<V4@]6EG=7-E9"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S`*
M;7-G:60@(D=U97-T8F]O:R(*;7-G<W1R(")+_&QA;&ES=&5R86%M870B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDW(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<U"FUS9VED(")'=6EN96$B"FUS9W-T<B`B1VEN96$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S@*;7-G:60@(D=U:6YE82U":7-S874B"FUS9W-T<B`B1VEN96$M
M0FES<V%U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B
M1W5A:F%A;F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-C`*;7-G
M:60@(DA434PB"FUS9W-T<B`B2%1-3"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G:60@(DA434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@
M<F]W+B(*;7-G<W1R(")(5$U,07)E82!K965L9'5B(&%R9W#\:W-L:6MU;'0@
M:W5S='5T86UA<W0@<F5A('9I:6UA<W0@;&%H=')I="XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS9VED
M(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(DA434Q!<F5A(&ME96QD=6(@
M87)G</QK<VQI:W5L="!K=7-T=71A;6%S="!T86)E;&D@=FEI;6%S="!V965R
M9W4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T
M;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R(")(5$U,
M07)E82!K965L9'5B(&%R9W#\:W-L:6MU;'0@:W5S='5T86UA<W0@=&%B96QI
M('9I:6UA<W0@<FED82XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N
M<&AP.C$U-PIM<V=I9"`B2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(DA45%`@875T96YT:6UI<W0@96D@;&5I='5D+B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,`IM<V=I9"`B2&%I=&DB"FUS9W-T<B`B2&%I:71I(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")(87-H+4%L
M9V]R:71H;2(*;7-G<W1R(")2Y'-I86QG;W)I=&TB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@IM<V=I9"`B2&%Z92(*;7-G
M<W1R(")(Y&=U(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3$Y(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S(*;7-G:60@(DAE861E<B(*;7-G
M<W1R(")0Y&ES(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE
M<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R(")0Y&ES960B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@
M27-L86YD<R(*;7-G<W1R(")(96%R9&D@<V%A<B!J82!-8T1O;F%L9&D@<V%A
M<F5D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C,*;7-G:60@(DAE879Y(%0M4W1O<FTB"FUS9W-T<B`B4N1N:R#D:6ME<V5T
M;W)M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@(DAE8G)E
M=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R(")(965B<F5A("A)4T\M.#@U.2TX
M+4DI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S='(@(DOU<F=U<R(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ-SD@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$X-@HC.B!S97)V:6-E<R]H96QP+VEN
M9&5X+G!H<#HQ-R!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z,PIM<V=I9"`B
M2&5L<"(*;7-G<W1R(")!8FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O<B(*
M;7-G<W1R(")%9&ET;W)I(&MA<W5T86UI<V4@86)I(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3,W,0IM<V=I9"`B2&5L<&5R(@IM<V=S='(@(D%B
M:6QI;F4B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@(DAE;6ES
M<&AE<F4B"FUS9W-T<B`B<&]O;&ME<F$B"@HC.B!T96UP;&%T97,O9&%T82]T
M<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,`IM
M<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G
M<W1R(")3:6EN(&]N(&9A:6QI(&%L9W5S(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DAI9V@B"FUS9W-T<B`B
M2_5R9V4B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@=&5M<&QA
M=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C4*;7-G:60@(DAO7VUE(@IM
M<V=S='(@(E]!=F%L96AT(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L>2!3
M964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`B4/QH82!4;V]L("A6
M871I:V%N:2!,:6YN<FEI:RDB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C$U,S4*;7-G:60@(DAO;64B"FUS9W-T<B`B079A;&5H96QE(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R,@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U"FUS9VED
M(")(;VUE($%D9')E<W,B"FUS9W-T<B`B2V]D=6YE(&%A9')E<W,B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*;7-G:60@(DAO;64@1&ER96-T;W)Y
M(@IM<V=S='(@(DMO9'5K871A;&]O9R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS
M9W-T<B`B2V]D=6YE('1E;&5F;VXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO
M;F1U<F%S(@IM<V=S='(@(DAO;F1U=7)A<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I
M9"`B2&]N9R!+;VYG(@IM<V=S='(@(DAO;F=K;VYG(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C8U"FUS9VED(")(;W)D92(*;7-G<W1R(")(;W)D
M92(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#0R"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A
M(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L
M86(Z(%9I9V%S960@)7,@6$U,(&%N9&UE9"!K:7)J87,@)7,B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE
M8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($]B:F5K=&EL92`E<R!E:2!V
M87-T82#\:W-K:2!K:7)I(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HT,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&]B
M:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B
M2&]R9&4O2V]L86(Z($5I(&QE:71U9"#\:'1K:2`E<R!T_/QP:2!O8FIE:W1I
M(&MI<FIA<R`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(U
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U
M;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B#5
M;FYE<W1U<R!E96UA;&1A9&$@)7,@7"(E<UPB(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT
M96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT
M96YS:6]N(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!);G1E9W)A='-I;V]N:6UO
M;W1O<B!V86IA8B`G9&]M>&UL)R!02%`@;&%I96YD=7-T(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O
M<B!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($5I('-A82!L=75A
M('5U="!834P@<'5U9"!O8FIE:W1I("5S(&IA;VMS(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HQ,C0W"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS
M9W-T<B`B2&]R9&4O2V]L86(Z($5I('-A82!E96UA;&1A9&$@)7,@7"(E<UPB
M.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#<T"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE
M=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R(")(
M;W)D92]+;VQA8CH@16D@]6YN97-T=2!H86YK:61A($U)344@240M9"`E<R!T
M_/QP:2!O<V$@:F%O:W,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C$Q.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!S>6YC:')O;FES92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E
M+TMO;&%B.B!%:2!S86$@<_QN:W)O;FES965R:61A("5S(%PB)7-<(CH@)7,B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$S,S8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES
M92!S:&%R97,Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!%:2!S86$@<_QN
M:W)O;FES965R:61A(&IA9W5S:60Z("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B
M.B!4=6YD;6%T=2!J86=U(%PB)7-<(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@4G5L
M92(*;7-G<W1R(")(;W)I<V]N=&%A;&IO;VXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L
M('!A9&1I;F<B"FUS9W-T<B`B2&]R:7-O;G1A86QN92!V;V]D97)D=7,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Q"FUS
M9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R(")(;W)I<V]N=&%A;&YE.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU,0IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P
M;W)T(2DB"FUS9W-T<B`B2W5I9&%S('-A('-I:6$@<V%T='5S:60_("A086QU
M;B!T96%T82$I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L
M9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B2W5I('!A;&IU('9E97)G
M92!S;V]V:6MS:60@_&AE;F1A9&$_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@
M87)E('1H97)E/R(*;7-G<W1R(")+=6D@<&%L:G4@=N1L:G4@*'9E97)G92D@
M;VX_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK
M92!T;R!M97)G93\B"FUS9W-T<B`B2W5I('!A;&IU(')I9'4@<V]O=FEK<VED
M(/QH96YD861A/R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M,#`@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S`*;7-G:60@(DAU;6ED:71Y(@IM
M<V=S='(@(DYI:7-K=7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C4Y"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@(DYI:7-K=7,Z(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED(")(=6UO<FES=',B
M"FUS9W-T<B`B2'5M;W)I<W1I9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N
M9V%R>2(*;7-G<W1R(")5;F=A<FDB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G5S+G!H<#HQ-S(@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP
M.C(S-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I
M;VX@9F%I;&5D.B`E<R(*;7-G<W1R("))34%0('!O<W1K87-T:2!L;V]M:6YE
M(&YU<FIU<SH@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H
M<#HR,30@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D
M.B`E<R(*;7-G<W1R("))34%0('!O<W1K87-T:2!K=7-T=71A;6EN92!N=7)J
M=7,Z("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<Y
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE
M9#H@)7,B"FUS9W-T<B`B24U!4"!P;W-T:V%S=&D@:W9O;V1I(&QO;VUI;F4@
M;G5R:G5S.B`E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,38*
M;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`B25`@86%D<F5S<R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D
M9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B25`@86%D<F5S<R!P;VQE
M('1E861A+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z
M.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@
M8FQO8VLN(@IM<V=S='(@(DE0(&%A9')E<W,@96D@:W5U;'4@;'5B871U9"!#
M2412(&)L;VMK:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO
M;BXB"FUS9W-T<B`B25`@<&EI<F%N9W4@<FEK:W5M:6YE+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.0IM
M<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(DQI<V$@<FED82!?
M96YN92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*;7-G<W1R("))
M<VQA;F0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<V"FUS9VED("))
M8V]N<R!/;FQY(@IM<V=S='(@(D%I;G5L="!I:V]O;FED(@H*(SH@=71I;"]I
M8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(DEC;VYS
M(&9O<B`E<R(*;7-G<W1R("(E<R!I:V]O;FED(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,W-PIM<V=I9"`B26-O;G,@=VET:"!T97AT(@IM<V=S='(@
M(DEK;V]N:60@:F$@=&5K<W0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3DP"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@(DED96YT:71E
M961I(&YI;6DZ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z-3DR"B,L('!H<"UF;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P
M;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O
M=RXB"FUS9W-T<B`B2W5I('-E9&$@]6EE=&D@96D@;N1I9&%T82P@)7,@:F$@
M<V5E(&%V871A:W-E('5U97,@86MN87,N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0U-0IM<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A;GD@:6-O
M;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C
M:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y
M+B(*;7-G<W1R("(B"B)+=6D@<V$@:V%S=71A9"!);G1E<FYE="!%>'!L;W)E
M<FET(&IA(&5I(&[D92#\;&1S92!I:V]O;F4L('-I:7,@<')O;W9I("(*(FWD
M<FMI9&$@<V5E(')U=70L(&S\;&ET86UA:W,@<VES<V4@4$Y'(&SD8FEP86ES
M='9U<RXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3<S"FUS9VED("(B"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@
M;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@
M8F4@(@HB9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@HB
M2W5I('-A(&[D960@<V5D82!T96%D970@86=A('!I;'1I(&5I(&[D92P@<VEI
M<R!E:2!O<VMA('-I;G4@=F5E8FEL96AI='-E:F$@(@HB;N1I9&%T82!S961A
M('!I;'1I+"!M:61A('-O;W9I9"#\;&5S(&QA861I9&$N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(X
M"FUS9VED("));6%G92!0<F5V:65W.B(*;7-G<W1R(")0:6QD:2!E96QV86%D
M93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,W"FUS9VED("));6%G92!54DPB"FUS9W-T<B`B4&EL9&D@55),
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(E!I;&1I
M(%523#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*
M;7-G<W1R(")0:6QT(&=A;&5R:6ES="(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA
M9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R(")0:6QT(&=A;&5R:6ES=#HB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8Q"FUS9VED("));6%G92!U
M<&QO860B"FUS9W-T<B`B4&EL9&D@_&QE<VQA861I;6EN92(*"B,Z(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B"FUS9W-T<B`B4&EL
M9&ED(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T
M97,O9&%T82]D871E;6%P+FEN8SHW"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z-30@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`B26UP;W)T
M+"!S86UM("5D(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,38*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S
M='(@(DEM<&]R9&ET=60@=N1L:3H@)7,B"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C8U"FUS9VED("));7!O<G1E9"!F:65L9',Z(@IM<V=S='(@
M(DEM<&]R9&ET=60@=N1L:F%D.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2
M;W<@069T97(B"FUS9W-T<B`B3&ES82!R:61A(%]PY')A<W0B"@HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S4*;7-G:60@(DEN
M8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B17-I=&%T:2!V
M86QE('1E9V5V=7-E(&MO;V0N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*;7-G:60@(DEN8V]R<F5C="!U<V5R
M;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(E9A;&4@:V%S=71A:F%N
M:6UI(&IA+W;U:2!P87)O;VPN(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E
M<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A
M9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB"FUS9W-T
M<B`B(@HB5F%L92!K87-U=&%J86YI;6D@=O5I(&%L=&5R;F5T:6EV;F4@86%D
M<F5S<RX@4')O;W9I('5U97-T:2!V]6D@=O5T82#\:&5N9'5S="`B"B)A9&UI
M;FES=')A871O<FEG82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S92!);F1E;G0B"FUS9W-T
M<B`B4W5U<F5N9&$@=&%A;F1R:61A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))
M;F1I82(*;7-G<W1R("));F1I82(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,C4T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS
M9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@(MQK<VEK=60@:V%S=71A
M:F%D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`B
M26YD;VYE97-I82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z-C<*;7-G:60@(DEN9F\B"FUS9W-T<B`B26YF;R(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3<*;7-G:60@(DEN9F]R;6%T:6]N
M(@IM<V=S='(@(DEN9F]R;6%T<VEO;VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S,P"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@
M879A:6QA8FQE+B(*;7-G<W1R(")496%V92!E:2!O;&4@96YA;2!KY'1T97-A
M861A=BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S4*;7-G:60@(DEN<V5R="!#7V]L=6UN($%F=&5R(@IM
M<V=S='(@(DQI<V$@7W9E97)G('#D<F%S="(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B
M26YS97)T($EM86=E(@IM<V=S='(@(DQI<V$@<&EL="(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R
M="!486)L92(*;7-G<W1R("),:7-A('1A8F5L(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E
M8B!,:6YK(@IM<V=S='(@(DQI<V$@:/QP97)L:6YK(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED
M("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B3&ES82!V965?<F<@
M96YN92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E
M<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B3&ES82!U=7,@=F5E<F<@86MT
M:6EV<V4@=F5E<G4@:N1R96QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("));G-E<G0@82!N
M97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B3&ES
M82!U=7,@=F5E<F<@86MT:6EV<V4@=F5E<G4@971T92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,@IM<V=I
M9"`B26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS
M9W-T<B`B3&ES82!U=7,@<FED82!A:W1I:79S92!R96$@:N1R96QE(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8Q"FUS9VED("));G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N
M="!O;F4B"FUS9W-T<B`B3&ES82!U=7,@<FED82!A:W1I:79S92!R96$@971T
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHW,`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H
M92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B3&ES82!L]6EK('!R865G=7-E(&%S
M=6MO:&$@:N1R96QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A9W)A
M<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B3&ES82!L]6EK
M('!R865G=7-E(&%S=6MO:&$@971T92(*"B,Z(&%D;6EN+W1E;7!L871E<RYP
M:'`Z,34P"FUS9VED("));G-E<G0@86QT97)N871E('1E;7!L871E(@IM<V=S
M='(@(DQI<V$@86QT97)N871I:79N92!M86QL(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(S.0IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@
M=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM
M<V=S='(@(E-I<V5S=&$@;6%I;&EA861R97-S(&MU:'4@<V%A:W,@<W5L;&4@
M=75E('!A<F]O;&D@<V%A=&$Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`IM<V=I9"`B26YS97)T(&-E;&P@
M869T97(B"FUS9W-T<B`B3&ES82!L86AT97(@<.1R87-T(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0IM<V=I
M9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(DQI<V$@;&%H=&5R(&5N
M;F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@
M(DQI<V$@=F5E<F<@<.1R87-T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M
M;B!B969O<F4B"FUS9W-T<B`B3&ES82!V965R9R!E;FYE(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*;7-G:60@(DEN<V5R
M="!M97-S86=E<R(*;7-G<W1R("),:7-A(&MI<FIA9"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-0IM<V=I
M9"`B26YS97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R("),:7-A(&SU:6L@
M<.1R87-T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0T"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E9F]R
M92(*;7-G<W1R("),:7-A(&SU:6L@96YN92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R
M="!R;W<@869T97(B"FUS9W-T<B`B3&ES82!R:61A('#D<F%S="(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*
M;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM<V=S='(@(DQI<V$@<FED82!E
M;FYE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,`IM<V=I9"`B26YS
M97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T
M:6]N.B(*;7-G<W1R(")+:7)J=71A('-A;&%K_'-I;75S92#U:6=E('9A<W1U
M<SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(V"FUS9VED("));G-E<G0O36]D:69Y($EM86=E(@IM<V=S='(@(DQI<V$O
M;75U9&$@<&EL="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*;7-G<W1R
M("),:7-A+VUU=61A(&QI;FLB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B26YS=69F:6-I96YT(&-R
M961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T
M<B`B2F%O='5S;FEM96MI<FIA;&4@<V%A=&UI<V5K<R!E:2!JY'1K=2!K<F5D
M:6ET:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T
M<B`B2W)E9&EI=&D@96D@:N1T:W4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3`W-0IM<V=I9"`B26YT96=E<B(*;7-G<W1R(")4Y&ES87)V(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$S,PIM<V=I9"`B26YT96=E
M<B!L:7-T(@IM<V=S='(@(E3D:7-A<G9U9&4@;FEM96MI<FDB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G
M:60@(DEN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN(@IM<V=S='(@
M(E9I9V%N92!51$@@*%5S97(@1&%T82!(96%D97(I+B(*"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$W,`HC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,#$*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C$P"FUS9VED("));G9A;&ED(%I)
M4"!D871A(@IM<V=S='(@(E9I9V%S960@6DE0(&%N9&UE9"XB"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T
M:6]N+B(*;7-G<W1R(")6:6=A;F4@<F%K96YD=7,N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED("))
M;G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R(")686QE(&)A=&-H($E$(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`X-R!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,34X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,S(@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(Y.0HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A
M=&$@<W5B;6ET=&5D+B(*;7-G<W1R(")3:7-E<W1A=&D@=FEG87-E9"!A;F1M
M960N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`P"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N
M(@IM<V=S='(@(E9I9V%N92!S:6AT86%D<F5S<RXB"@HC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HX,0HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,#`*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+V1B>"YP:'`Z,C(P"FUS9VED("));G9A;&ED(&9I;&4@
M9F]R;6%T(@IM<V=S='(@(E9A;&4@9F%I;&EF;W)M86%T(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-PIM<V=I9"`B26YV86QI9"!L:6-E
M;G-E(&ME>2XB"FUS9W-T<B`B5FEG86YE(&QI='-E;G1S:7;U=&DN(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W,0IM<V=I9"`B26YV86QI
M9"!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B4VES97-T871I('9I9V%N
M92!A<W5K;VAT(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*;7-G
M<W1R(")6:6=A;F4@;7-G7W1Y<&4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*;7-G:60@(DEN=F%L:60@;W(@
M;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(F%P:5]I9"!O;B!P=75D=2!V]6D@
M=FEG86YE+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y-@IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M
M971E<G,N(@IM<V=S='(@(E9I9V%S960@=O5I('!U=61U=F%D('!A<F%M965T
M<FED+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR-PIM<V=I9"`B
M26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B5FEG86YE(/QL
M96WU:6=U<RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<S
M"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(E9I9V%N92!P
M87)T;F5R:2!)1"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-S4*;7-G:60@(DEN=F%L:60@<')O9'5C="!C;V1E+B(*;7-G<W1R(")6:6=A
M;F4@=&]O=&5K;V]D+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB
M"FUS9W-T<B`B5FEG86YE('!R;W1O:V]L;"XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A
M;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S='(@(E9I9V%N92!S86%J83H@
M7"(E<UPB(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,#<V(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(V,@IM<V=I9"`B26YV86QI9"!S
M:&%R92!O8FIE8W0B"FUS9W-T<B`B5FEG86YE(&IA9V%T=60@;V)J96MT(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`Q"FUS9VED("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R(")6
M:6=A;F4@;.1H=&5A861R97-S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0IM<V=I9"`B26YV86QI9"!U;FEC
M;V1E(&1A=&$N(@IM<V=S='(@(E9I9V%S960@=6YI8V]D92!A;F1M960N(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U-PIM<V=I9"`B26YV96YT
M;W)Y(@IM<V=S='(@(DYI;65K:7)I(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C8W.0IM<V=I9"`B26YV97)T('-E;&5C=&EO
M;B(*;7-G<W1R(")0]O9R9'9A;&EK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))
M<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM<V=S='(@(DER86%N:2!)<VQA
M;6EV86)A<FEI:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R
M("))<F%A:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G<W1R
M(")):7)I;6%A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34*
M;7-G:60@(DES;&4@;V8@36%N(@IM<V=S='(@(DUA;FD@<V%A<B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(T"FUS9VED("))
M<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R("+<:W-I:W5D(.1I:V5S971O<FUI
M9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27-R865L(@IM<V=S='(@(DEI<W)A
M96PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R-0IM
M<V=I9"`B27-S=65R(@IM<V=S='(@(E;D;&IA86YD:F$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET86QI
M8R(*;7-G<W1R(")+86QD:VER:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B271A
M;'DB"FUS9W-T<B`B271A86QI82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M
M86EC82(*;7-G<W1R(")*86UA:6MA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P,0HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B
M2F%A;G5A<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F%P86XB"FUS9W-T<B`B
M2F%A<&%N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*;7-G:60@(DIA
M<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`B2F%A<&%N:2`H25-/+3(P
M,C(M2E`I(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*;7-G
M:60@(B(*(DIA=F%S8W)I<'0@:&%S(&)E96X@9&ES86)L960@;VX@>6]U<B!B
M<F]W<V5R(&%N9"!T:&ES('!A9V4@;6%Y(&YO="!B92`B"B)D:7-P;&%Y:6YG
M(&-O<G)E8W1L>2XB"FUS9W-T<B`B(@HB2W5N82!S:6YU('9E96)I;&5H:71S
M96IA<R!O;B!*879A<V-R:7!T(&ME96QA='5D+"!E:2!P<G5U9VD@<V5E(&QE
M:'0@]6EE=&D@(@HB<&%I<W1A+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3(R"FUS9VED(")*97)S97DB"FUS9W-T<B`B2F5R<V5Y(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@S"FUS9VED(")*;W)D86XB"FUS9W-T<B`B2F]R9&%A;FEA(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-PHC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G
M:60@(DIU;'DB"FUS9W-T<B`B2G5U;&DB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R(")*
M=75N:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`B4O;V<'-E;'0B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T<B`B2V5S:V5L
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B4O;V<'-E
M;'0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(E9A<V%K
M=6QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`B4&%R
M96UA;&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T
M<B`B2V%S86AS=&%N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(V-`IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B
M4^1I;&ET82!O<FEG:6YA86P_(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY
M82(*;7-G<W1R(")+965N:6$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR
M8C4N<&AP.C@U"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(DME<F)E<F]S92!S97)V97(@96D@;&%S
M:VYU9"!S:7-S92XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G
M:60@(DME<FYE;"!.97=B:65S(@IM<V=S='(@(DME<FYE;&D@=O5H:6MU9"(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B
M2V5Y($-R96%T:6]N(@IM<V=S='(@(E;U=&UE(&QO;VUI;F4B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@(DME>2!&:6YG
M97)P<FEN="(*;7-G<W1R(")6]71M92!S]7)M96KD;&<B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME>2!,96YG=&@B
M"FUS9W-T<B`B5O5T;64@<&EK:W5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@5'EP92(*;7-G<W1R(")6]71M
M92!T_/QP(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.3@*;7-G:60@(DME>2!5<V%G92(*;7-G<W1R(")6]71M92!K87-U='5S(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S0P"FUS9VED(")+
M97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM
M<V=S='(@(E;U=&D@;VX@879A;&EK=7,@<V5R=F5R:7,@:G5B82!O;&5M87,N
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM
M<V=S='(@(DQA<'-E9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B2VER:6)A=&DB
M"FUS9W-T<B`B2VER:6)A=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A
M+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM<V=S='(@(DMO
M<F5A(%)A:'9A9&5M;VMR86%T;&EK(%9A8F%R:6EK(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U
M"FUS9VED(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B2V]R96$@5F%B
M87)I:6LB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B2V]R
M96%N("A%54,M2U(I(@IM<V=S='(@(DMO<F5A("A%54,M2U(I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@V"FUS9VED(")+=7=A:70B"FUS9W-T<B`B2W5V96ET(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@S"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(DOU<F?U>G-T86XB
M"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*;7-G:60@(DQA7WEO
M=70B"FUS9W-T<B`B7TMU:G5N9'5S(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B2V5E;"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P
M=6)L:6,B"FUS9W-T<B`B3&%O<V4@4F%H=F%D96UO:W)A871L:6L@5F%B87)I
M:6LB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),87-T($AA
M;&8B"FUS9W-T<B`B5FEI;6%N92!P;V]L(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C<V"FUS9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R
M(")6:6EM86YE('!A<F]O;&D@;75U='5S(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R
M=&5R(@IM<V=S='(@(E9I:6UA;F4@=F5E<F%N9"(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,34Q"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(E9I
M:6UA=&D@;75U9&5T=60Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S
M='(@(D5E;&UI;F4@:_QL87-T=7,Z("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z-S(Q"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ
M("5S(&9R;VT@)7,B"FUS9W-T<B`B165L;6EN92!K_&QA<W1U<SH@)7,@86%D
M<F5S<VEL="`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q-@IM
M<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`B165L;6EN92!K_&QA
M<W1U<SH@;6ET=&4@:W5N86=I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),871V
M:6$B"FUS9W-T<B`B3.1T:2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M-`IM<V=I9"`B3&%W(@IM<V=S='(@(E-E861U<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0IM<V=I9"`B3&%Y
M;W5T(@IM<V=S='(@(DMU:G5N9'5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R
M(&YO(&)O<F1E<B(*;7-G<W1R(")4_&AI('3D:&5N9&%B('!I:7)J;V]N92!P
M=75D=6UI<W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQE8F%N;VXB"FUS9W-T
M<B`B3&EI8F%N;VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B"FUS9W-T<B`B5F%S86LB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$Y"FUS9VED("),969T
M(&AE861E<B(*;7-G<W1R(")687-A:R!PY&ES(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$Q-0IM<V=I9"`B3&5F="!V86QU97,B"FUS9W-T<B`B
M5F%S86MU9"!VY.1R='5S960B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQE<V]T
M:&\B"FUS9W-T<B`B3&5S;W1H;R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(U-0IM<V=I9"`B3&5V96PB"FUS9W-T<B`B5&%S92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX.`IM<V=I9"`B3&EB97)I82(*;7-G<W1R("),:6)E97)I82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX.0IM<V=I9"`B3&EB>6%N($%R86(@2F%M86AI<FEY82(*;7-G
M<W1R("),:6EB_&$@07)A86)I82!686)A<FEI:R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM
M<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("),:65C:'1E;G-T96EN(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G
M:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`B5&EB=71A8B!V:6AM82(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"FUS9VED
M("),:6=H="!286EN(@IM<V=S='(@(E-E96YE=FEH;2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!2
M86EN($5A<FQY(@IM<V=S='(@(DAO;6UI:W5L('1I8G5T86(@=FEH;6$B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I
M9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(M5H='5L('1I8G5T86(@=FEH
M;6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M.0IM<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B2V5R9V4@:&]O
M=FEH;2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,P"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G<W1R(")+
M97)G92!V:6AM(&IA(.1I:V4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R(")+
M97)G92!L=6UE<V%D=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,R"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R
M(")+97)G92!L=6UE=&]R;2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M-0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B3&EM97)I:R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X,30*;7-G:60@(DQI;FLB"FUS9W-T<B`B
M3&EN:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU-PIM<V=I9"`B3&EN:R!P;VEN=',@=&\Z(@IM<V=S='(@
M(DQI;FL@=FEI=&%B(&%S=6MO:'1A.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$X-S4*;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@
M=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T<B`B17-I
M=&%M:7-E;"!S96]S=&$@92UP;W-T:2!A861R97-S('5U92!K:7)J82!A:VYA
M9V$B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAT;6PR=&5X
M="YP:'`Z,3@S"FUS9VED("),:6YK<R(*;7-G<W1R("),:6YG:60B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI92(*
M;7-G<W1R("),:6YU>&D@<'+DY&YI:R(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T("T@=7-E<B!C86X@
M<V5E('1H92!F;VQD97(B"FUS9W-T<B`B3&ES="`M(&MA<W5T86IA(';U:6(@
M:V%U<W1A(&[D:&$B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,S"FUS9VED
M("),:7-T($1A=&%B87-E<R(*;7-G<W1R(")!;F1M96)A87-I9&4@;&]E=&5L
M=2(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4P"FUS9VED("),:7-T
M($AE;'`@5&]P:6-S(@IM<V=S='(@(D%B:6EN9F\@=&5E;6%D92!N:6UE:VER
M:2(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S(*;7-G:60@(DQI<W0@5&%B
M;&5S(@IM<V=S='(@(E1A8F5L:71E(&QO971E;'4B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TAE861E<G,N<&AP.C4Y-`IM<V=I9"`B3&ES="U!<F-H:79E
M(@IM<V=S='(@(DQI<W0M07)C:&EV92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O2&5A9&5R<RYP:'`Z-3@Y"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`B
M3&ES="U(96QP(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H
M<#HU.38*;7-G:60@(DQI<W0M260B"FUS9W-T<B`B3&ES="U)9"(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),:7-T
M+4]W;F5R(@IM<V=S='(@(DQI<W0M3W=N97(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TAE861E<G,N<&AP.C4Y,PIM<V=I9"`B3&ES="U0;W-T(@IM<V=S
M='(@(DQI<W0M4&]S="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R
M<RYP:'`Z-3DQ"FUS9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("),:7-T
M+5-U8G-C<FEB92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP
M:'`Z-3DP"FUS9VED("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(DQI<W0M
M56YS=6)S8W)I8F4B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*;7-G:60@
M(DQI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R(")397-S:6]O
M;FED92!N:6UE:VER:F$@97-I=&%M:6YE(&YU<FIU<SH@)7,B"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN
M9R!U<V5R<R!F86EL960Z("5S(@IM<V=S='(@(DMA<W5T86IA=&4@;FEM96MI
M<FIA(&5S:71A;6EN92!N=7)J=7,Z("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED("),:7-T:6YG('5S97)S(&ES(&1I
M<V%B;&5D+B(*;7-G<W1R(")+87-U=&%J871E(&YI;65K:7)J82!P;VQE(&QU
M8F%T=60@;N1H82XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G
M:60@(DQI=&5R871U<F4B"FUS9W-T<B`B2VER:F%N9'5S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@Y"FUS9VED("),:71H=6%N:6$B"FUS9W-T<B`B3&5E9'4B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I;6%G97,N<&AP.C@S"FUS9VED("),
M;V%D:6YG+BXN(@IM<V=S='(@(DQA96XN+BXB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C$Q"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T
M<B`B2V]H86QI:R!A96<Z("(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M,PIM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(E)E9VEO;VX@:F$@
M865G(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S$@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8T"B,Z(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP.C8U"FUS9VED("),
M;V-A=&EO;B(*;7-G<W1R(")!<W5K;VAT(@H*(SH@;&]G:6XN<&AP.C$W,B!S
M97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3DQ('1E;7!L871E<R]L;V=I
M;B]M;V)I;&4N:6YC.C,*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z
M,34@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY,`IM<V=I9"`B3&]G(&EN
M(@IM<V=S='(@(DQO9VD@<VES<V4B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR-#4*;7-G:60@(DQO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I
M;VXB"FUS9W-T<B`B165L;6ES92!S_&YK<F]N:7-E97)I;6ES92!L;V=I(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$X-0IM<V=I9"`B3&]G
M(&]U="(*;7-G<W1R("),;V=I(';D;&IA(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C4Y"FUS9VED("),;V=I;B(*;7-G<W1R(")+87-U=&%J86YI;6DB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W"FUS9VED("),;V=I;B!4
M87-K<R(*;7-G<W1R(")4]O9D('-I<W-E;&]G:6UI<V5L(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z.3DV"FUS9VED("),;V=I;B!F86EL960@8F5C
M875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN
M8V]R<F5C=&QY+B(*;7-G<W1R(")3:7-S96QO9VEM:6YE(&YU<FIU<RP@:W5N
M82!K87-U=&%J86YI;6D@=O5I('!A<F]O;"!P;VQN=60@]6EG92XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HY.3(*;7-G:60@(DQO9VEN(&9A:6QE
M9"XB"FUS9W-T<B`B4VES<V5L;V=I;6EN92!N=7)J=7,N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-0IM<V=I9"`B3&]N9R!T97AT(@IM<V=S
M='(@(E!I:VL@=&5K<W0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*
M;7-G:60@(DQO=F4B"FUS9W-T<B`B07)M87-T=7,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I9"`B3&]W(@IM<V=S
M='(@(DUA9&%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R
M<R(*;7-G<W1R(")+<F5E:V$@=N1I:V5TY&AE9"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@
M(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B3&%D:6YA(';D:6ME=.1H
M960B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP
M95]L86YG+FIS.C$W"FUS9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S
M='(@(E;D:6ME<V5D(')O;VUA(&YU;6)R:60B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G
M:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B3'5K<V5M8G5R9R(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#`*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S."!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B2TLB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Q"FUS9VED(")-3U1$(@IM<V=S='(@
M(DU/5$0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H
M<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D
M871A+B(*;7-G<W1R(")-4RU43D5&(&QI<V%N9"!E:2!S:7-A;&1A;G5D(&%N
M9&UE:60N(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I
M;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S='(@
M(DU31R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C86\B"FUS9W-T<B`B36%K
M86\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE
M<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G<W1R(")-86ME9&]O;FEA("A%
M;F1I;F4@2G5G;W-L86%V:6$@5F%B87)I:6LI(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS
M9VED(")-861A9V%S8V%R(@IM<V=S='(@(DUA9&%G87-K87(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#D*;7-G:60@(DUA9VEC(@IM<V=S='(@(DUA
M86=I82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX,0IM<V=I9"`B
M36%I;"(*;7-G<W1R(")%+7!O<W0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-3(R"FUS9VED(")-86EL($%D;6EN(@IM<V=S='(@(E!O<W1I(&%D
M;6EN:7-T<F%A=&]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM
M<V=S='(@(E]4964@;&EN:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,38U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L87=I
M(@IM<V=S='(@(DUA;&%W:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,38W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36%L87ES
M:6$B"FUS9W-T<B`B36%L86ES:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$V-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA
M;&1I=F5S(@IM<V=S='(@(DUA;&1I:79I9"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I
M9"`B36%L:2(*;7-G<W1R(")-86QI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-
M86QT82(*;7-G<W1R(")-86QT82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,0IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@
M>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A
M<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B(@HB
M4V5A9&ES=&$@:V%T96=O;W)I86ED+"!M:61A(&MA<W5T871A:W-E(/QK<W5S
M=&4@;>1R9V5N9&%M:7-E:W,@:F$@;F5N9&5L92`B"B)K871E9V]O<FEA=&5L
M92!V87-T879A:60@=N1R=F4N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$Q-3,*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R
M(")-87`R-"!K86%R="(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,#@T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,38X"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T<B`B
M36%P475E<W0@:V%A<G0B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B5F%S=&%V
M=7-E9"!S86QV97-T871U9"XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`S"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`B3>1R=',B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0Q"FUS9VED(")-87)G:6XB"FUS9W-T<B`B4V5R=B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-87)K
M('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`B5.1H:7-T82!L;V5T
M=60O;'5G96UA=&$@<W1A871U<R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@9FQA
M9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R(")4Y&AI<W1A
M(&UU=2!S=&%A='5S("AN="X@=.1H=&ES+W9A<W1A='5D*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,0IM<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R(")-87)S:&%L
M;&D@<V%A<F5D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-87)T:6YI<75E(@IM
M<V=S='(@(DUA<G1I;FEQ=64B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C$P,PIM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(E-O8FEV
M860@=N1L:F%D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-875R:71A;FEA(@IM
M<V=S='(@(DUA=7)E=&%A;FEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-875R
M:71I=7,B"FUS9W-T<B`B36%U<FEI=&EU<R(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L
M;&]W960@8W)E9&ET+B(*;7-G<W1R(")3=75R:6T@;'5B871U9"!K<F5D:6ET
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM
M<V=S='(@(DMI<FIA(&]S861E('!I:7)A;F<@_&QE=&%T=60N(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@
M:&]U<G,Z("(*;7-G<W1R(")6:6EM87-E(#(T('1U;FYI(&OU<F=E:6T@=&5M
M<&5R871U=7(Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDX"FUS9VED
M(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R(")6:6EM87-E(#8@
M='5N;FD@:_5R9V5I;2!T96UP97)A='5U<CH@(@H*(SH@;&EB+V%P:2YP:'`Z
M.#8*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS
M9W-T<B`B4W5U<FEM('!O<G1A86QI(&)L;VMK:61E(&%R=B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C@Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C$W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,SD*;7-G:60@
M(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(E-U=7)I;2!P:6MK=7,B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B
M36%Y(@IM<V=S='(@(DUA:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(DUA>6]T
M=&4B"FUS9W-T<B`B36%Y;W1T92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B365D:71S:6EN(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@IM<V=I9"`B365M
M8F5R<R(*;7-G<W1R("),:6EK;65D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,W.`IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R(")-96[\_"!E<VET
M=7,Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T<B`BW&AE;F1A
M(&QA:'1R:60B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*;7-G<W1R(")496%D
M92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$V"FUS
M9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE
M('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92`B"B)V97)I9FEE
M9"XB"FUS9W-T<B`B(@HB2VER:2!O;B!E9'5K86QT(&MO;G1R;VQL:71U9"P@
M96YT(&%L;&MI<FIA<W1A:F$@<V5R=&EF:6MA871I(&5I('-A86YU9"`B"B)K
M;VYT<F]L;&ED82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,3`*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS
M9W-T<B`B5&5A9&4@;VX@865G=6YU9"XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V.0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"FUS9VED
M(")-97-S86=E('1Y<&4B"FUS9W-T<B`B5&5A=&4@=/S\<"(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B365T87(@5V5A=&AE<B(*;7-G<W1R
M(")-971A<B!I;&TB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W"FUS9VED
M(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")-971A<B!B
M;&]K:R!E:2!O;&4@<V%A9&%V86PN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ,3(*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E
M=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N
M(@IM<V=S='(@(DUE=&%R(&)L;VMK(&5I(&]L92!S86%D879A;"X@W&MS:6MA
M<VIA9"!L;V=I=&D@861M:6YI<W1R86%T;W)I(&IA;VMS+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C4*;7-G:60@(DUE=&%R1$(@:7,@
M;F]T(&-O;FYE8W1E9"XB"FUS9W-T<B`B365T87)$0B#\:&5N9'5S('!U=61U
M8BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8W
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@
M(DUE=&AO9"(*;7-G<W1R(")-965T;V0B"@HC.B!F<F%M97=O<FLO4E!#+U)0
M0R]X;6QR<&,N<&AP.C@Q(&9R86UE=V]R:R]24$,O4E!#+W-O87`N<&AP.C$Q
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D
M969I;F5D(@IM<V=S='(@(DUE971O9"!<(B5S7"(@96D@;VQE(&1E9FEN965R
M:71U9"(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+W)E<W0N<&AP.C@R"B,L('!H
M<"UF;W)M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE
M=&AO9#H@)7,B"FUS9W-T<B`B365E=&]D(&5I(&]L92!D969I;F5E<FET=60N
M($OD:79I=&%T=60@;65E=&]D.B`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HW-"!L:6(O0FQO8VLO;65T87(N<&AP.C<U"FUS9VED(")-
M971R:6,B"FUS9W-T<B`B365E=&5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-
M97AI8V\B"FUS9W-T<B`B365H:&EK;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")-
M:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(DUI:W)O
M;F5E<VEA($;V9&5R871S:6]O;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@IM<V=I9"`B36ED9&QE(@IM<V=S
M='(@(DME<VME;&4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S='(@(DU)344@=/S\
M<"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$P"FUS9VED(")-:6X@=&5M
M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B5FEI;6%S92`R-"!T=6YN:2!M
M861A;&%I;2!T96UP97)A='5U<CHB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,P,@IM<V=I9"`B36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B
M5FEI;6%S92`V('1U;FYI(&UA9&%L86EM('1E;7!E<F%T=75R(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,SD*;7-G:60@(DUI;FEM=6T@
M<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960B"FUS9W-T<B`B4&%R
M;V]L:2!M:6YI;6%A;&YE('9A;G5S('!O;&4@=F5E;"!TY&ES(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-`IM<V=I9"`B
M36ER<F]R(@IM<V=S='(@(E!E96=E;&1A(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(DUI=&UE
M<W5G=7-T(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-S(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S0P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%10
M7U)E<75E<W0N(@IM<V=S='(@(E!U=61U8B!014%2('!A:V5T="!(5%107U)E
M<75E<W0N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q-0IM<V=I9"`B
M(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T
M92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC871I
M;VXN(@IM<V=S='(@(B(*(DMO;F9I9W5R871S:6]O;B!P=75D=6(N($MU:2!T
M86AA9"!S961A(')A:V5N9'5S="!K87-U=&%D82P@<&5A9"!E;FYE("(*(F=E
M;F5R965R:6UA(&MO;F9I9W5R871S:6]O;FDN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`T"FUS9VED(")-:7-S
M:6YG(&UE<W-A9V4@240N(@IM<V=S='(@(E!U=61U8B!S]6YU;6D@240N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA
M:6PN(@IM<V=S='(@(E!U=61U8B!V86IA;&EK(%!%05(@<&%K971T($UA:6PN
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM<V=S='(@(E!U
M=61U8B!S97-S:6]O;FD@240N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`B17,B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S0*;7-G:60@(DUO8FEL92!-
M86EL(@IM<V=S='(@(DUO8FEI;&YE(&4M<&]S="(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")-;V1E<F%T92(*
M;7-G<W1R(")-]?5D=6MA<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C8@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HW,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C@X"FUS9VED(")-;V1I9FEE9"!$871E(@IM<V=S='(@(DUU=71M:7-E(&MU
M=7#D978B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B375U
M9&$@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M-S,*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B2N3D:R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B36]L9&]V
M82!686)A<FEI:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]N86-O(@IM<V=S
M='(@(DUO;F%K;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36]N9V]L:6$B"FUS
M9W-T<B`B36]N9V]O;&EA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C4Y-`IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B2W5U(&IA(&%A
M<W1A(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H
M<#HU-PIM<V=I9"`B36]N=&AL>2(*;7-G<W1R(")+;W)D(&MU=7,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.30*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B36]N='-E<G)A
M="(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H
M<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B2W5U9F%A<VED(@H*
M(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3<R(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C(U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E
M(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D
M+B(*;7-G<W1R(")296%S("5D(&QE:71I(')O:&ME;2!VY&QJ=2!K=6D@965L
M9&%T878@)60N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S
M='(@(DUA<F]K;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@0VQE87(B"FUS9W-T<B`B5F%L9&%V
M86QT('-E;&=E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S0*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B5F%L9&%V
M86QT('!I;'9E<R(*"FUS9VED(")-;W-T;'D@0VQO=61Y(&%N9"!7:6YD>2(*
M;7-G<W1R(")686QD879A;'0@<&EL=F5S(&IA('1U=6QI;F4B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B36]S
M=&QY(%-U;FYY(@IM<V=S='(@(E9A;&1A=F%L="!PY&EK97-E<&%I<W1E;&EN
M92(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4P.0IM
M<V=I9"`B36]V92!$;W=N(@IM<V=S='(@(DYI:'5T82!A;&QA(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$S"FUS9VED(")-;W9E
M($QE9G0B"FUS9W-T<B`B3FEH=71A('9A<V%K=6QE(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$W"FUS9VED(")-;W9E(%)I9VAT
M(@IM<V=S='(@(DYI:'5T82!P87)E;6%L92(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C4P-0IM<V=I9"`B36]V92!5<"(*;7-G<W1R
M(").:6AU=&$@_&QE<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HU,C0*;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R(").:6AU
M=&$@86QL82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HU,C,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C4R-`IM<V=I9"`B36]V92!U<"(*;7-G<W1R(").:6AU=&$@_&QE<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-0IM<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R(")-;W-A
M;6)I:6LB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@T"FUS9VED
M(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B36ET;65T
M87-E;65L:6YE(&QO96YD(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$P-34*;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G
M<W1R(")-=6QT:6UA<"!52R!K86%R="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R-#(*;7-G:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R
M(")686QI:R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#`*;7-G
M:60@(DUY($%C8V]U;G0B"FUS9W-T<B`B36EN=2!K;VYT;R(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HR.`IM<V=I9"`B37D@06-C;W5N="!);F9O<FUA
M=&EO;B(*;7-G<W1R(")-:6YU(&MO;G1O(&EN9F\B"@HC.B!S97)V:6-E<R]P
M;W)T86PO:6YD97@N<&AP.C4T"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B
M36EN=2!P;W)T86%L(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C$S
M-@IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R(")-:6YU('!O<G1A
M86QI(&MU:G5N9'5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM
M<V=S='(@(DUY86YM87(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I
M;G1E;F%N8V4N:'1M;#HU-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM
M<V=S='(@(D5)+"!M82!%22!/3$4@;O5U<R(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0Q,2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3`R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1N968N<&AP.C,X"FUS9VED(").86UE(@IM<V=S='(@(DYI;6DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B3F%M:6EB:6$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(DYA=7)U(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R(").97!A86PB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(DAO;&QA;F0B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS
M9W-T<B`B2&]L;&%N9&D@06YT:6QL:60B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB
M"FUS9W-T<B`B3F5T<V-A<&4@0F%S92!54DPB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@0T$@4F5V
M;V-A=&EO;B!54DPB"FUS9W-T<B`B3F5T<V-A<&4@0T$@=/QH:7-T=7-E(%52
M3"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U"FUS
M9VED(").971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(DYE='-C87!E
M($-!('!O;&EC>2!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T
M<B`B3F5T<V-A<&4@=75E;F1U<V4@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G:60@(DYE='-C87!E(%)E=F]C871I
M;VX@55),(@IM<V=S='(@(DYE='-C87!E('3\:&ES='5S92!54DPB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T
M<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(DYE='-C87!E(%-33"!S
M97)V97)I(&YI;6DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*
M;7-G<W1R(").971S8V%P92!S97)T:69I:V%A9&D@:V]M;65N=&%A<B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@P"FUS9VED(").
M971S8V%P92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@(DYE='-C87!E('-E
M<G1I9FEK86%D:2!T_/QP(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(U,0IM<V=I9"`B3F5T=V]R:R(*;7-G<W1R(")6]7)K(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(U(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS,S4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X-@IM<V=I9"`B
M3F5V97(B"FUS9W-T<B`B36ET=&4@:W5N86=I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS
M9VED(").97<@0V%L961O;FEA(@IM<V=S='(@(E5U<RU+86QE9&]O;FEA(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z
M-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R(")5=7,@:V%T96=O;W)I
M82(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H
M<#HX,0HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP
M:'`Z.#<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N
M<&AP.CDW"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS
M+G!H<#HQ,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W($UE<W-A9V4@=&\@
M)7,B"FUS9W-T<B`B575S(&MI<FD@)7,M;&4B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(DYO;W)K=74B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,U"FUS9VED(").
M97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R(")5=7,@:V%S=71A:F%N
M:6UI("AP;VQE(&MO:'5S='5S;&EK*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B
M3F5W(%IE86QA;F0B"FUS9W-T<B`B575S+4UE<F5M86$B"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*;7-G:60@(DYE=R!P87-S=V]R9"(*
M;7-G<W1R(")5=7,@<V%L87/U;F$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W-Q;"YP:'`Z,C(W"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!P87-S=V]R
M9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS9W-T<B`B575S('-A;&%S]6YA(&%E
M9W5B("5X+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU,@IM
M<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"XB"FUS9W-T<B`B4V%L
M87/U;F%D('!E879A9"!K;&%P<&EM82XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@=VEN9&]W("A?
M8FQA;FLI(@IM<V=S='(@(E5U97,@86MN87,@*%]B;&%N:RDB"@HC.B!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3(*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X.0IM<V=I9"`B3F5W<R(*
M;7-G<W1R(")5=61I<V5D(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,P-0IM<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R(")'<G5P:60B"@HC.B!T
M96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ-2!T96UP;&%T97,O9&%T82]D
M871E;6%P+FEN8SHT,0HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R
M.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR-0IM<V=I9"`B3F5X="(*
M;7-G<W1R(")*Y')G;6EN92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PIM
M<V=I9"`B3F5X="`T(%!H87-E<R(*;7-G<W1R(")*Y')G;6ES960@-"!F86%S
M:2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<R(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<V"FUS9VED(").97AT(&]P=&EO
M;G,B"FUS9W-T<B`B2N1R9VUI<V5D('-E861E9"(*"B,Z(&9R86UE=V]R:R]5
M22]522]086=E<BYP:'`Z,3`S"FUS9VED(").97AT/B(*;7-G<W1R(")*Y')G
M;6EN93XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R
M(").:6MA<F%A9W5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<B(*;7-G
M<W1R(").:6=E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*;7-G
M<W1R(").:6=E97)I82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS.#`*;7-G:60@(DYI9VAT(@IM<V=S='(@(M;V(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW
M"FUS9VED(").:75E(@IM<V=S='(@(DYI=64B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED(").;R(*;7-G<W1R
M(")%:2(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM
M<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W
M(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`B4'5U9'5V860@:V]N9FEG=7)A
M='-I;V]N:6%N9&UE9"!M:6QL92!E<FEN979U<VD@;N1I9&%T82XB"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C$P-0IM<V=I
M9"`B3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E
M<RXB"FUS9W-T<B`B4'5U9'5B('-T<F%T965G:6$@25-/9&4@;&]O;6ES96MS
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(E!U
M=61U8B!M86QL+B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C<Y(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C(T-0HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-C<*;7-G:60@
M(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM
M<V=S='(@(E-E;&QE<R!A<W5K;VAA<R!E:2!O;&4@8FQO:VMI(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HU,`IM<V=I9"`B3F\@8V%L96YD
M87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B34-!3"!A=71E;G1I;6ES96MS('9A:F%L:6L@:V%L96YD<FD@;FEM
M:2!O;B!P=75D=2XB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`IM<V=I
M9"`B3F\@8VAA;F=E+B(*;7-G<W1R(")%<FEN979U<VD@96D@;VQE+B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED(").;R!C
M:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G
M<W1R(")396QL96QE(/5I9W5S96QE(&5I('-A82!A;&%M86ED(&QI<V%D82XB
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V-R!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C4P,@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H
M<#HW-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R("(E<R!HY.1L
M97-T=7-I;F9O('!U=61U8BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C@R-`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R($944"!61E,N(@IM<V=S='(@(D944"!61E,@:.3D;&5S
M='5S:6YF;R!P=75D=6(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HV-CD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R(")344P@5D93(&CDY&QE<W1U
M<VEN9F\@<'5U9'5B+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HW,3<*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(E-13"U&:6QE
M(%9&4R!HY.1L97-T=7-I;F9O('!U=61U8BXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO(&-R
M961I="!L969T+B(*;7-G<W1R(")+<F5D:6ET(&]N(&%M;65N9&%T=60N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,S0*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G<W1R(")3
M:6AT:V]H="!MY.1R86UA=&$N(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O
M=W-E<BYP:'`Z.#<W"FUS9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@
M(D9A:6QI(&5I(&QA971U9"(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HW
M,0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@(DEK;V]N92!E:2!L
M96ET=60N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$R."!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ,C,*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B07-U
M:V]H="!MY.1R86UA=&$N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$V.0IM<V=I9"`B3F\@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@
M(D%S=6MO:'0@;>3D<F%M871A(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*;7-G:60@(DYO(&UE<W-A9V4@<W5P
M<&QI960N(@IM<V=S='(@(E/U;G5M('!U=61U8BXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@IM<V=I9"`B3F\@
M;F%M92!S<&5C:69I960N(@IM<V=S='(@(DYI;6D@<'5U9'5B+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS
M9VED(").;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R(").=6UB97(@<'5U
M9'5B+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B3F\@
M;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(D%I;G5L="!V:6ES86MA9"!K
M:6QL=60B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.CDQ"FUS
M9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`B2%144"!A=71E;G1I;6ES92!S86QA<_5N82!P=75D
M=6(N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HQ,#@*;7-G
M:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R("))34%0(&%U=&5N=&EM:7-E('-A;&%S]6YA('!U=61U
M8BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C<R"FUS9VED
M(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(DME<F)E<F]S(&%U=&5N=&EM:7-E('-A;&%S]6YA
M('!U=61U8BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C<W
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&]G:6XN<&AP.C@T"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<&%M+G!H<#HW-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("),;V=I
M;B!A=71E;G1I;6ES92!S86QA<_5N82!P=75D=6(N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]P87-S=V0N<&AP.C$S-0IM<V=I9"`B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B
M4$%34U=$(&%U=&5N=&EM:7-E('-A;&%S]6YA('!U=61U8BXB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(E--
M0B!A=71E;G1I;6ES92!S86QA<_5N82!P=75D=6(N(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C@V"FUS9VED("(B"B).;R!P871H
M('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@
M8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I=&@@4$M#4R`Q,B!D
M871A+B(*;7-G<W1R("(B"B)/<&5N4U-,('!R;V=R86UM:2!A<W5K;VAT(&5I
M(&]L92!MY.1R871U9"X@3W!E;E-33"!P<F]G<F%M;2!O;B!V86IA;&EK("(*
M(E!+0U,C,3(@86YD;65T96=A('3V]G1A;6ES96MS+B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@
M<VEG;G5P<RXB"FUS9W-T<B`B3V]T96P@;&EI='5M:7-S;V]V92!E:2!O;&4N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C<U,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(").;R!Q=6]T82!S970N(@IM<V=S='(@(E!I:7)A;F=U="!E:2!O
M;&4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT,PIM<V=I9"`B3F\@<G5L97,B"FUS9W-T<B`B4'5U9'5V860B
M"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#D*;7-G:60@(DYO
M('-E<&%R871O<B!S<&5C:69I960N(@IM<V=S='(@(D5R86QD86IA('!O;&4@
M;>3D<F%T=60N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT-`IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B36ET
M=&4@_&MS:VD@:_QL9R(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M-3@S"FUS9VED(").;R!S=6-H(&9I;&4B"FUS9W-T<B`B4V5L;&ES="!F86EL
M:2!E:2!O;&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3,X
M"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@
M8V%C:&4N(@IM<V=S='(@(E!U:'9E<F1A;6ES96MS('!U=61U8B!A:G5T:6YE
M(&MA=&%L;V]G+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,C(Q"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O
M<F0@<V5N="XB"FUS9W-T<B`B2V%S=71A:F%N:6UE(&IA+W;U:2!S86QA<_5N
M82!E:2!S86%D971U9"XB"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N
M<&AP.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS
M9W-T<B`B16D@=&%G87-T871U9"!K;W)R96MT<V5I9"!834P@86YD;65I9"(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-S$*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX,0HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3DR"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#`Y"FUS
M9VED(").;R!V86QU97,B"FUS9W-T<B`B5N3D<G1U<V5D('!U=61U=F%D(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B3F\@=F5R<VEO
M;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(D%L9VYE(&MO;F9I9W5R871S
M:6]O;B!E:2!S:7-A;&1A('9E<G-I;V]N:2X@3&]O(&MO;F9I9W5R871S:6]O
M;B!U=65S=&DN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R.`IM<V=I
M9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E
M9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B4VEN=2!K;VYF:6=U
M<F%T<VEO;VX@96D@<VES86QD82!V97)S:6]O;FDN($QO;R!K;VYF:6=U<F%T
M<VEO;VX@=75E<W1I+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0R-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0U"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C
M="YI;F,Z.3,*;7-G:60@(DYO;F4B"FUS9W-T<B`B3>3D<F%M871A(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I
M9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R(")-Y.1R86UA=&$B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B3F]R9&EC("A)4T\M
M.#@U.2TQ,"DB"FUS9W-T<B`B4/5H:F%M86%D("A)4T\M.#@U.2TQ,"DB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM<V=S='(@(DYO
M<F9O;&MI('-A87(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L
M;V-K+VUO;VXN<&AP.C8P"FUS9VED(").;W)T:&5R;B!(96UI<W!H97)E(@IM
M<V=S='(@(E#U:&IA<&]O;&ME<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO
M<G1H97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R(")0]6AJ82U-87)I86%N
M:2!S86%R960B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYO<G=A>2(*;7-G<W1R
M(").;W)R82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C0P"FUS9VED(").;W0@069T97(B"FUS9W-T<B`B36ET=&4@:&EL:F5M(&MU
M:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS
M9VED(").;W0@0F5F;W)E(@IM<V=S='(@(DUI='1E('9A<F5M(&MU:2(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0P.`IM<V=I9"`B3F]T(&$@
M9&ER96-T;W)Y(@IM<V=S='(@(D5I(&]L92!K871A;&]O9R(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z-C,*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G
M>2YP:'`Z.#,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.30*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDN<&AP.C4Y"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S
M='(@(E!O;&4@=&5O<W1A='5D+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-C@*;7-G:60@(DYO="!S970B"FUS9W-T<B`B
M3>3D<F%M871A(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I
M;VY(86YD;&5R+G!H<#HQ-#,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R
M+U-E<W-I;VY(86YD;&5R+G!H<#HQ-3@*(SH@9G)A;65W;W)K+U-E<W-I;VY(
M86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S,*(SH@9G)A;65W;W)K+U-E
M<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#<*(SH@9G)A;65W
M;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HR,S0@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,C`U(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,S`*(SH@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C(T."!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C8U"B,Z
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C(Y-PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S$R(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HS,CD*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,V
M,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-#(R"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HU,#$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4W,`HC.B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z-3@W(&9R86UE=V]R:R]61E,O5D93+G!H<#HV
M-C4*;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(D5I(&]L92!T;V5T
M871U9"XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,C0T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#`U"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ-S@*;7-G:60@(DYO=&5S(@IM<V=S='(@(DWD
M<FMM960B"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G
M:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R(")0;VQE
M(&UI9&%G:2!S:7)V:61A+"!M:6YE('1A9V%S:2XB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#D*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B
M"FUS9W-T<B`B3F]V96UB97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,#0V"FUS9VED(").=6UB97(B"FUS9W-T<B`B07)V(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,30R-0IM<V=I9"`B3G5M8F5R(&]F(&-H87)A
M8W1E<G,B"FUS9W-T<B`B3>1R:VED92!A<G8B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,S8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C,*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T-2!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R(&]F
M(&-O;'5M;G,B"FUS9W-T<B`B5F5E<F=U9&4@87)V(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3,V-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#,@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E
M<B!O9B!R;W=S(@IM<V=S='(@(E)I9&%D92!A<G8B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B3G5M
M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I
M;VX@;&ES="XB"FUS9W-T<B`B2F%O='5S;FEM96MI<FIA<R!M=75T;6ES96QE
M(&MU=6QU=F%D(&YU;6)R:60@<&]L92!MY.1R871U9"XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM
M<V=S='(@(D]+(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C@W,PIM<V=I9"`B3V)J96-T(@IM<V=S='(@(D]B:F5K="(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@
M0W)E871O<B(*;7-G<W1R(")/8FIE:W1I(&QO;VIA(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3$P-`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B2V%H
M96MS86YD;G5M8F5R(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0Q,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS9W-T<B`B3VMT;V]B97(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@
M9FEL=&5R(@IM<V=S='(@(E9I:7-A:W5S92!A<W1E(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,R-@IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(DMO
M;G1O<FET]O8B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3@*
M;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N
M="XB"FUS9W-T<B`B5F%N82!J82!U=7,@<V%L87/U;F$@<&5A=F%D(&]L96UA
M(&5R:6YE=F%D+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS
M-@IM<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@(E!R865G=6YE('-A;&%S
M]6YA(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C0V"FUS9VED
M(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N(@IM<V=S='(@(E!R865G
M=6YE('-A;&%S]6YA(&5I(&]L92#U:6=E+B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I
M9"`B3VUA;B(*;7-G<W1R(")/;6%A;B(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R
M<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+B(*;7-G<W1R("+<:&ES:V%U<W1U
M(';U:6UA;&1A=F%D(&%I;G5L="!)34%0('-E<G9E<FED+B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R
M='5N97,B"FUS9W-T<B`B06EN=6QT(&5B879I:7-A:V%D(&MI;&QU9"(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-3$@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3DW,0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@861D<F5S<R!A
M;&QO=V5D+B(*;7-G<W1R("),=6)A='5D(&]N(&%I;G5L="#\:W,@92UP;W-T
M:2!A861R97-S+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM
M<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T
M;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO
M;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@HB2F%O(&]M86YI:VMU(';U:2!O
M;6%N:6MU(/5I9W5S:2!S86%B(&UU=71A(&%I;G5L="!O;6%N:6L@=O5I('/\
M<W1E96UI("(*(F%D;6EN:7-T<F%A=&]R+B(*"B,Z(&QI8B]";&]C:R]I9G)A
M;64N<&AP.C,U"FUS9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R
M(")!=F$@=75E<R!A:VYA<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@
M97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*;7-G<W1R
M(")/<&5N4U-,('9I9V$Z($%N9&UE=&4@97)A;&1A;6EN92!A;&QK:7)J87-T
M871U9"!3+TU)344@;W-A<W0@;G5R:G5S+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E
M;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")!=F%B('-E
M;&QE(&QI;F=I('5U97,@86MN87,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-3,*;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B3W!E<F%T
M<VEO;VYI<_QS=&5E;2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ-3$*;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`B4V5A9&5D(@H*(SH@<V5R
M=FEC97,O<')E9G,N<&AP.C,Q('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$T
M"B,L('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@
M(E-E861I<W1U<SH@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B
M3G5M;65R9&%T=60@;&]E=&5L=2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-38W"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`B
M3W)G86YI<V%T<VEO;VXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N86P@56YI="(*;7-G<W1R
M(")!;&S\:W-U<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S(*
M;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B26YF;R(*"B,Z(&%D;6EN+W1E
M;7!L871E<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T
M96UP;&%T92(*;7-G<W1R(")286ME;F1U<V4@86QG;F4@;6%L;"(*"B,Z(&%D
M;6EN+W1E;7!L871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R
M:6=I;F%L('1E;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B06QG<V5D(&UA;&QI
M9"!K871A;&]O9VES("5S.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE
M<B(*;7-G<W1R(")-=74B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3$S(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C(*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$S,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30Q
M"FUS9VED(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R(")-=74@:6YF;R(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R
M(%!E<FUI<W-I;VYS(@IM<V=S='(@(D]M86YI:W4@]6EG=7-E9"(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW.0IM<V=I9"`B4$%-(&%U=&AE
M;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(E!!32!A=71E
M;G1I;6EN92!E:2!O;&4@<V%A9&%V86PN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL
M(&)A8VME;F0B"FUS9W-T<B`B4$5!4CHZ36%I;"!T=6=I(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3(W,PIM<V=I9"`B4$=0($1I9VET
M86P@4VEG;F%T=7)E(@IM<V=S='(@(E!'4"!D:6=I=&%A;&%L;&MI<FDB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S$Y"FUS9VED(")0
M1U`@16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B4$=0(&MR_'!T:71U9"!A;F1M
M960B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S<Q"FUS
M9VED(")01U`@4'5B;&EC($ME>2(*;7-G<W1R(")01U`@879A;&EK(';U=&DB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S4S"FUS9VED
M(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(E!'4"!A;&QK
M:7)J87-T871U9"]K<OQP=&ET=60@86YD;65D(@H*(SH@861M:6XO<&AP<VAE
M;&PN<&AP.C8X"FUS9VED(")02%`@0V]D92(*;7-G<W1R(")02%`@:V]O9"(*
M"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM
M<V=S='(@(E!(4"!KY'-U<FED82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")032!,:6=H="!286EN(@IM<V=S
M='(@(E!,(&ME<F=E('9I:&TB"@IM<V=I9"`B4$T@4F%I;B(*;7-G<W1R(")0
M3"!V:6AM(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S@*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B4$P@:&]O=FEH;6%D
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,SD*
M;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`B4$P@;'5M:2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")032!3;F]W
M(%-H;W=E<G,B"FUS9W-T<B`B4$P@=&EH92!L=6UE<V%D=2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"FUS9VED(")032!3
M=6XB"FUS9W-T<B`B4$P@<.1I:V4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T
M<B`B4$P@Y&EK97-E=&]R;2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR
M-S0*;7-G:60@(E!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@
M(E!/4TE8(&QA:65N9'5S('!U=61U8B(*"B,Z(&QI8B]A<&DN<&AP.C$T.0IM
M<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R(")07TA0(&OD<W5R:61A(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R(")4Y&ED92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M.0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`B4&%K:7-T86XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`Q"FUS9VED(")086QA=2(*;7-G<W1R(")086QA=2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DR(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B
M"FUS9W-T<B`B4&%L97-T:6EN82!O:W5P965R:71U9"!T97)R:71O;W)I=6TB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3@*;7-G:60@(E!A;F%M82(*;7-G<W1R(")086YA;6$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A<'5A($YE=R!'=6EN96$B"FUS9W-T
M<B`B4&%A<'5A(%5U<RU':6YE82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3DU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A
M<F%G=6%Y(@IM<V=S='(@(E!A<F%G=6%I(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S8*;7-G:60@(E!A<G1L>2!#;&]U9'DB
M"FUS9W-T<B`B5F%H96QD=78@<&EL=FES=7,B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#$X"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,PHC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(S"FUS9VED(")087-S=V]R9"(*
M;7-G<W1R(")386QA<_5N82(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN
M(@IM<V=S='(@(E-A;&%S]6YA(&UU=61E='5D+B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,3,R,@IM<V=I9"`B4&%S<W=O<F0@:6YC
M;W)R96-T(@IM<V=S='(@(E9A;&4@<V%L87/U;F$B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W)A9&EU<RYP:'`Z,34R"FUS9VED(")087-S=V]R9"!R97%U
M:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")2041)
M55,@875T96YT:6UI<V5K<R!O;B!V86IA;&EK('-A;&%S]6YA+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-3,*;7-G:60@(E!A<W-W;W)D('=I
M=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(E-A;&%S]6YA(&MI;FYI='5S96=A
M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP"FUS9VED(")0
M87-S=V]R9#HB"FUS9W-T<B`B4V%L87/U;F$Z(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VUO8FEL92YI;F,Z,3$*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`B
M4V%L87/U;F$Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#,T"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G
M<W1R(")386QA<_5N860@<&5A=F%D(&ML87!P:6UA+B(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,3D@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T92(*;7-G<W1R(")!<V5T
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@(D%S971A
M(&SU:6ME<'5H=G)I<W0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C4Q"FUS9VED(")0871H(@IM<V=S='(@(D%S=6MO:'0B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B4&5N
M9&EN9R!3:6=N=7!S.B(*;7-G<W1R(")/;W1E;"!L:6ET=6UI<W-O;W9I9#HB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*;7-G:60@(E!E;W!L92(*
M;7-G<W1R("));FEM97-E9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT(@IM<V=S='(@(E!R
M;W1S96YT:2(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC
M92YH=&UL.C0Y"FUS9VED(")097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO
M;G,B"FUS9W-T<B`B2^1I=FET82!H;V]L9'5S=/;V9"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT,#8*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`B5&5E('-I<W-E;&]G:6UI
M<V5L(&AO;VQD=7-T]FED(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`BU6EG=7,B"@HC
M.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G
M:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R("+5
M:6=U<W0@7"(E<UPB(&5I(&MU<W1U=&%T=60N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HU.#8*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM
M<V=S='(@(DIU=7)D97#DY',@:V5E;&%T=60B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C$V-`IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`BU6EG=7-E9"(*
M"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P.2!A9&UI;B]P97)M<R]A9&1C
M:&EL9"YP:'`Z-C`*(SH@861M:6XO<&5R;7,O:6YD97@N<&AP.C(R(&%D;6EN
M+W!E<FUS+V1E;&5T92YP:'`Z-3@*;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN
M:7-T<F%T:6]N(@IM<V=S='(@(M5I9W5S=&4@:&%L9'5S(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8U"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO
M;B(*;7-G<W1R("))<VEK;&EK(&EN9F\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@
M(E!E<G4B"FUS9W-T<B`B4&5R=74B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-34*;7-G:60@(E!E=',B"FUS9W-T<B`B3&5M;6EK;&]O;6%D(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDY"FUS9VED(")0:&EL:7!P:6YE<R(*;7-G<W1R(")&:6QI<&EI
M;FED(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$Y-@IM<V=I9"`B4&AO;F4B"FUS9W-T<B`B5&5L969O;B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT-S@*;7-G:60@(E!H;W1O<R(*;7-G<W1R
M(")&;W1O9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DP(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A:7)N(@IM<V=S
M='(@(E!I=&-A:7)N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R(")0:6MS;&ET
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS9VED(")0;&%T:71U
M9&5S(@IM<V=S='(@(DWU='1E='5S960B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A<V4@
M8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B2VSU<'-A(&WU;F1A(&QA
M:'1R:7-S92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y
M;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R(")+:6YN
M:71A(&5T('-O;W9I9"!S96QL92!E;&5M96YD:2!E96UA;&1A9&$Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4V"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N
M;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(DMI;FYI=&$@970@<V]O=FED
M('-E;&QE(&5L96UE;F1I(&QA:'1I(/QH96YD861A+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(U-S$*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO
M;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(E-I<V5S=&$@:W5U(&IA(&%A<W1A
M+B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C$R"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A
M=&5G;W)Y.B(*;7-G<W1R(")3:7-E<W1A('-E;&QE('5U92!K871E9V]O<FEA
M(&YI;6DZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P,0IM<V=I
M9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B
M4VES97-T82!K;W)R96MT;F4@25`@86%D<F5S<RXB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-C8P"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI
M9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H
M+B(*;7-G<W1R(")3:7-E<W1A(&MO<G)E:W1N92!K=75PY&5V+"!K;VYT<F]L
M;&D@<.1E=F%D92!A<G9U(&MU=7,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C0U,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB
M"FUS9W-T<B`B4VES97-T82!K;W)R96MT;F4@865G+B(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@(E!L96%S92!P<F]V:61E
M(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS9W-T<B`B2VER:F5L9&$@
M<')O8FQE96UI+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE87-E('!R
M;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B4VES
M97-T82!O;6$@:V%S=71A:F%N:6UI(&IA('-A;&%S]6YA(@H*(SH@<V5R=FEC
M97,O;6%I;G1E;F%N8V4N<&AP.C4X"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T
M:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E
M<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B"B),;V4@:N1R
M9VYE=B!T96MS="!LY&)I+B!3_'-T965M:2!K87-U=&%M:7-E:W,@4$5!1"!T
M:6YG:6UU<W1E9V$@;O5U<W1U;6$N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E
M('1H92!N97<@8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B2VER:G5T82!U=64@
M:V%T96=O;W)I82!N:6UI.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&]L86YD
M(@IM<V=S='(@(E!O;VQA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4W
M"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R(")0;VQI:71I:V$B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@W"FUS9VED(")0;VQL<R(*;7-G<W1R
M(")+_'-I=&QU<V5D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&]R='5G86PB
M"FUS9W-T<B`B4&]R='5G86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N
M:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T<B`B4V5L;&4@<&EL9&D@<&%I9W5T
M=7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R
M(")396QL92!T86)E;&D@<&%I9W5T=7,B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES(&9O
M;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(DMI<FIU=&$@
M<V5L;&5S<V4@:V%U<W1A("A)34%0(&5I(&MO;G1R;VQL:2DB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(V-B!L:6(O0FQO8VLO;65T87(N<&AP.C(W,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S
M(&AO=7(H<RDZ("(*;7-G<W1R(")6:6EM87-E("5S('1U;FYI('-A9&5M960Z
M("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3@*;7-G:60@
M(E!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B4V%D96UE=&4\
M8G(@+SYT]65NY&]S=7,B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O;&1A
M<"YP:'`Z.3@*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?;&1A<#H@5F%J86QI
M:VMU($Q$05`@;&%I96YD=7-T(&5I(&QE:71U9"XB"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@(E!R969S7W-E<W-I
M;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B4')E9G-?<V5S<VEO;CH@5F%J86QI:VMU('-E<W-I;VX@;&%I96YD
M=7-T(&5I(&QE:71U9"XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-0IM
M<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`BU6AU<O5H:R(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C4Y"FUS9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ
M("(*;7-G<W1R("+5:'5R]6AK(&UE<F5P:6YN86PZ(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(S-0IM<V=I9"`B4')E<W-U<F4Z("(*;7-G
M<W1R("+5:'5R]6AK.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S
M='(@(D5E;'9A861E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(T"FUS9VED(")0<F5V:65W('1H92!I
M;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B4&EL9&D@965L=F%A9&4@
M=75E<R!A:VYA<R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,S8R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8V"FUS9VED(")0
M<F5V:6]U<R!O<'1I;VYS(@IM<V=S='(@(D5E;&UI<V5D('-E861E9"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G
M:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@(E1R_&MI(&1O:W5M96YT(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0
M<FEV871E($ME>2(*;7-G<W1R(")386QA:F%N92!V]71I(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V.0IM<V=I9"`B4')O8FQE;2(*
M;7-G<W1R(")0<F]B;&5E;2(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R
M-@IM<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R(")0<F]B;&5E
M;6D@:VER:F5L9'5S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,V
M.0IM<V=I9"`B4')O:F5C=',B"FUS9W-T<B`B4')O:F5K=&ED(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q,2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,3@X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#4*;7-G
M:60@(E!R;VUP="!T97AT(@IM<V=S='(@(E-E;&=I=&%V('1E:W-T(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L
M:6,@2V5Y(@IM<V=S='(@(D%V86QI:R!V]71I(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@06QG
M;W)I=&AM(@IM<V=S='(@(D%V86QI:W4@=O5T;64@86QG;W)I=&TB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-`IM<V=I9"`B4'5B
M;&EC($ME>2!);F9O(@IM<V=S='(@(D%V86QI:W4@=O5T;64@:6YF;R(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B
M;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL
M>2XB"FUS9W-T<B`B5O5T;65P86%R:2!G96YE<F5E<FEM:6YE(&5I(/5N;F5S
M='5N=60N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS
M9W-T<B`B4'5E<G1O<FEI:V\B"@IM<V=I9"`B4'5R9V4@;65S<V%G97,B"FUS
M9W-T<B`B2W5S='5T871U9"!K:7)J861E(&5E;6%L9&%M:6YE(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.38@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,@IM<V=I9"`B46%T87(B"FUS9W-T<B`B2V%T87(B"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z-C,*;7-G:60@(E%U97)Y(@IM<V=S='(@(E#D<FEN
M9R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`IM<V=I9"`B475O=&$B
M"FUS9W-T<B`B4&EI<F%N9R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C8S"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@
M2V5Y("@E9"!B:70I(@IM<V=S='(@(E)302!A=F%L:6L@=O5T:2`H)60@8FET
M=&DI(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-`IM<V=I9"`B
M4F%D:6\@<V5L96-T:6]N(@IM<V=S='(@(E9A;&EK(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#,*;7-G:60@(E)A:6XB"FUS
M9W-T<B`B5FEH;2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0T"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@(DAO;6UI:W5L
M('9I:&TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT-0IM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(M5H='5L('9I:&TB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM<V=I
M9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B2&]O=FEH;2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")286EN(&%N
M9"!3;F]W(@IM<V=S='(@(E9I:&T@:F$@;'5M:2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")286EN('1O(%-N
M;W<B"FUS9W-T<B`B5FEH;2!J82!L=6UI(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,*;7-G:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@(DIU:'5S
M;&EK(&MI;&0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*
M;7-G:60@(E)A=&EO(@IM<V=S='(@(E!R;W1S96YT(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*;7-G:60@(E)E860B"FUS9W-T
M<B`B3&]E(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.#<*;7-G:60@(E)E860@;65S<V%G97,B"FUS9W-T<B`B3&]E(&MI<FIU
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H
M<"UF;W)M870*;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T
M:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(DMA<R!T]65S=&D@:W5S
M='5T861A("5S/R!3964@=&]I;6EN9R!O;B!P]O9R9'5M871U+B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4
M:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R(")+87,@
M=/5E<W1I(&MU<W1U=&%D82!K87-U=&%J82`E<R!A;F1M960_(%-E92!T;VEM
M:6YG(&]N('#V]G)D=6UA='4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A
M8W1I;VXB"FUS9W-T<B`B5&%A<W1A8B!V:6EM87-E('1E9V5V=7-E(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B5N1R<VME;F1A(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B4F5F<F5S:"!$>6YA
M;6EC($UE;G4@16QE;65N=',Z(@IM<V=S='(@(E;D<G-K96YD82!D_&YA86UI
M;&ES960@;65N_/P@96QE;65N9&ED.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-#$*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@
M(E;D<G-K96YD82!P;W)T86%L:2!V86%D93HB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HX.30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,PHC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,U"FUS9VED(")296=E>"(*
M;7-G<W1R(")296=U;&%A<F%V86QD:7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,C0Y"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G
M<W1R(")3=6AE=&4@<VER=FEJ82(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*;7-G
M:60@(E)E;&]A9"(*;7-G<W1R("),864@=75E<W1I(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,C8*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B3>1R:W5S
M960B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$T"FUS9VED(")296UO
M=&4@4V5R=F5R<R(*;7-G<W1R(")6Y&QI<V5D('-E<G9E<FED(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED(")296UO=&4@55),
M("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T<B`B5N1L
M:6YE(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,B!T96UP;&%T97,O
M861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F5Q=65U960N:6YC.C$S"FUS9VED(")296UO=F4B"FUS9W-T
M<B`B165M86QD82(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ
M,0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@(D5E;6%L9&$@8FQO:VLB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34W
M"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(DMU<W1U=&$@=F5E<F<B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0P
M"FUS9VED(")296UO=F4@9F]R;6%T=&EN9R(*;7-G<W1R(")%96UA;&1A(&MU
M:G5N9'5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,C@*;7-G
M:60@(E)E;6]V92!P86ER(@IM<V=S='(@(D5E;6%L9&$@<&%A<B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HR,#(*;7-G:60@(E)E;6]V92!S879E9"!S
M8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G
M<W1R(")+=7-T=71A('-A;'9E<W1A='5D('-K<FEP="!S97)V97)I(&%J=71I
M<V5S="!K871A;&]O9VES="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*;7-G:60@(E)E;6]V92!T:&4B
M"FUS9W-T<B`B165M86QD82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I9"`B4F5M;W9E('1H:7,@
M;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G<W1R(")%96UA;&1A(&1O:W5M
M96YD:7-T(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ
M,0IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`B2W5S='5T82!K87-U=&%J
M82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")296UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B2W5S
M='5T82!K87-U=&%J83H@)7,B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR
M<&,N<&AP.C$S.`IM<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E
M9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS9W-T<B`B4.1R:6YG=6QE('!O
M;&YU9"!V]6EM86QI:R!V87-T871A+B!486=A<W1A=&D@=F5A:V]O9#H@(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-PIM<V=I9"`B4F5Q
M=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*;7-G<W1R(")3
M;V]V:71A=F%T('1E96YU<W0@96D@;&5I='5D+B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,3<T(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M-3$R"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@
M<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E9A:F%L
M:6L@7"(E<UPB('!U=61U8B`E<R!S96%D:7-T=7-E<RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C8W-2!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C@S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(S
M"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E
M8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")686IA;&EK
M(%PB)7-<(B!P=75D=6(@5D93('-E861I<W1U<V5S+B(*"B,Z(&9R86UE=V]R
M:R]5=&EL+U5T:6PN<&AP.C<X,0HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U
M:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R(")686IA;&EK(%PB)7-<(B!P=75D=6(@<V5A9&ES='5S97,N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S,U"FUS9VED
M(")297%U:7)E9"!&:65L9"(*;7-G<W1R(")+;VAU<W1U<VQI:R!VY&QI(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,S$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,R,"!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@
M(E3\:&IE;F1A(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#8*
M;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(DUU=61A('-A;&%S]6YA
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*;7-G:60@(E)E
M<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B56YU<W1A<VEN(&]M82!S86QA
M<_5N82(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S`*;7-G:60@(E)E<W1O
M<F4@3&%S="!1=65R>2(*;7-G<W1R(")486%S=&$@965L;6EN92!PY')I;F<B
M"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S$@861M:6XO8VUD<VAE;&PN<&AP
M.C(X(&%D;6EN+W-Q;'-H96QL+G!H<#HV-@IM<V=I9"`B4F5S=6QT<R(*;7-G
M<W1R(")4=6QE;75S960B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R
M;B!T;R!/<'1I;VYS(@IM<V=S='(@(E1A9V%S:2!S96%D:7-T=7-S92(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS.`IM<V=I9"`B4F5T>7!E
M(&YE=R!P87-S=V]R9"(*;7-G<W1R(")+;W)D82!U=70@<V%L87/U;F$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`R"FUS9VED(")2975N:6]N(@IM<V=S='(@(E)E=6YI;VXB
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM<V=S
M='(@(E;U=&$@:V]N9FEG=7)A='-I;V]N('1A9V%S:2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,S(*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@3W!T
M:6]N<R(*;7-G<W1R(")2:6-H(%1E>'0@161I=&]R:2!S96%D:7-T=7,B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS
M9W-T<B`B3?5I<W1A='5S960B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@
M(E!A<F5M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,0IM<V=I
M9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(E!A<F5M('#D:7,B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$W"FUS9VED(")2:6=H="!V86QU97,B
M"FUS9W-T<B`B4&%R96UA9"!VY.1R='5S960B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O
M7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")?4F5A('-E861E9"XN+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,S0*;7-G
M:60@(E)O;&4B"FUS9W-T<B`B4F]L;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@
M(E)O;6%N:6$B"FUS9W-T<B`B4G5M965N:6$B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(U"FUS9VED(")2;W1A=&4@,3@P
M(@IM<V=S='(@(E#V]G)A(#$X,"(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,C(*;7-G:60@(E)O=&%T92!,969T(@IM<V=S
M='(@(E#V]G)A('9A<V%K=6QE(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(R.`IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S
M='(@(E#V]G)A('!A<F5M86QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I
M97,B"FUS9W-T<B`B4F5A('-E861E9"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P<F]P
M97)T:65S(@IM<V=S='(@(E)E82!S96%D960B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W<SHB"FUS
M9W-T<B`B4FED=3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4S"FUS9VED(")2=6QE<R(*;7-G<W1R(")*;V]N
M960B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L
M;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(DIO;VYE9"!T96MI=F%D(&OU
M:6=I(')I9&%D92!J82!V965R9W5D92!V86AE;&4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R
M(")*;V]N960@=&5K:79A9"!A:6YU;'0@=F5E<F=U9&4@=F%H96QE(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB
M"FUS9W-T<B`B2F]O;F5D('1E:VEV860@86EN=6QT(')I9&%D92!V86AE;&4B
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P"FUS9VED(")2=6XB"FUS9W-T
M<B`B2^1I=FET82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DY
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)U<W-I86X@1F5D
M97)A=&EO;B(*;7-G<W1R(")696YE($;V9&5R871S:6]O;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#,*;7-G:60@(E)W86YD82(*;7-G<W1R(")2=6%N9&$B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%
M($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(E,O34E-12!K<OQP
M=&]G<F%A9FEL:6YE(&%L;&MI<FDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S
M86=E(@IM<V=S='(@(E,O34E-12!K<OQP=&ET=60@:VER:2(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T:&5N
M=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B4T%33"!A=71E
M;G1I;6EN92!E:2!O;&4@<V%A9&%V86PN(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C4P-`IM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R(")3
M35,@;/QH:7/U;G5M:60B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G
M:60@(E-13"!3:&5L;"(*;7-G<W1R(")344P@:^1S=7)I9&$B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@S"FUS9VED(")344P@<W1A=&5M96YT
M(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(E-13"!A=F%L9&ES(';DY')T
M=7-T92!L96ED;6ES96MS(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0S,0IM<V=I9"`B4U-((@IM<V=S='(@(E-32"(*"B,Z(&9R86UE=V]R:R].
M;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z
M,S4*;7-G:60@(E-50T-%4U,B"FUS9W-T<B`BU4Y.15-455,B"@HC.B!L:6(O
M87!I+G!H<#HQ-3,*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B4U]13"!K
MY'-U<FED82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@(DQA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@(E-A:6YT($AE;&5N82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES(@IM
M<V=S='(@(E-A:6YT($MI='1S(&IA($YE=FES(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS
M9VED(")386EN="!,=6-I82(*;7-G<W1R(")386EN="!,=6-I82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ=65L;VXB"FUS
M9W-T<B`B4V%I;G0@4&EE<G)E(&IA($UI<75E;&]N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-0IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS
M9W-T<B`B4V%I;G0@5FEN8V5N="!J82!'<F5N861I:6YI9"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A
M;64@9G)A;64@*%]S96QF*2(*;7-G<W1R(")386UA<R!R86%M:7,@*%]S96QF
M*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S='(@(E-A;6]A
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R(")3
M86X@36%R:6YO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,38@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4V%O(%1O;64@86YD
M(%!R:6YC:7!E(@IM<V=S='(@(E-A;R!4;VUE(&IA(%!R:6YC:7!E(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL
M:71E(%!R;W9I9&5R(@IM<V=S='(@(E-A=&5L;&EI='-I9&4@:V%S=71A:F$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`S"FUS9VED(")3875D:2!!<F%B:6$B"FUS9W-T<B`B
M4V%U9&D@07)A86)I82(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN
M8SHY.`IM<V=I9"`B4V%V92(*;7-G<W1R(")386QV97-T82`B"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L('!H<"UF;W)M870*
M;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(E-A;'9E<W1A(%PB)7-<(B(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V"B,L('!H<"UF;W)M
M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`B4V%L=F5S=&$@)7,B"@HC.B!T
M96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B
M"FUS9W-T<B`B4V%L=F5S=&$@<V5A9&ES='5S(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$V-PIM<V=I9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG
M=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP
M;W)A<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R("(B"B)386QV97-T82!G96YE
M<F5E<FET=60@:V]N9FEG=7)A='-I;V]N(%!(4"!S:W)I<'1I;F$@<V5R=F5R
M:2!A:G5T:7-S92`B"B)K871A;&]O9VDN(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B)7,@:V]N9FEG=7)A='-I;V]N('-A;'9E
M<W1A='5D+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L('!H
M<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O
M.B!<(B5S7"(N(@IM<V=S='(@(E!A:6=A;&1U<V4@=75E;F1A;6ES92!S:W)I
M<'0@<V%L=F5S=&%T=60@9F%I;&DZ(%PB)7-<(BXB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM<V=I9"`B4V-A='1E<F5D
M(%0M4W1O<FUS(@IM<V=S='(@(DAA:G5S860@Y&EK97-H;V]D(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE;F-E(@IM<V=S='(@
M(E1E861U<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$T
M('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED(")396%R
M8V@B"FUS9W-T<B`B3W1S:6YG(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,R,`IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T<B`B3W1S:6YG
M=6UO;W1O<FED(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDW,PIM
M<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S='(@(E9A;&D@9F%I;&ED(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-`IM<V=I
M9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R(")686QI(&MU=7#D978B"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B4V5L96-T(&$@
M9W)O=7`@=&\@861D(@IM<V=S='(@(E9A;&D@;&ES871A=B!G<G5P<"(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A
M(&YE=R!O=VYE<B(*;7-G<W1R(")686QI('5U<R!O;6%N:6LB"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@(E-E;&5C="!A('-E
M<G9E<B(*;7-G<W1R(")686QI('-E<G9E<B(*"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,34V"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*
M;7-G<W1R(")686QI(&QI<V%T878@:V%S=71A:F$B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<W"FUS9VED(")396QE8W0@
M86QL(@IM<V=S='(@(E9A;&D@:_5I:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(V-C,*;7-G:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S
M+B(*;7-G<W1R(")686QI(&OU:6L@:W5U<.1E=F$@:V]O<W1I<V]S860N(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM
M<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R(")686QI(&]B:F5K="(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-S@*
M;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(L1R82!V86QI(&UI9&%G:2(*
M"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HS-PIM<V=I9"`B(@HB4V5L96-T
M('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W
M+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H
M92!T97AT(&%R96$N(@IM<V=S='(@(E9A;&D@=F%J86QI:W5D(&WD<F=I9"!K
M87-T:61E<W0N(%-I:7,@<V%A9"!N965D(&MO<&5E<FED82!K:7)J82!S:7-S
M92XB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L
M96-T('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`B5F%L:2!K=75PY&5V
M82!E<F%L9&%J83HB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-`IM
M<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`B5F%L:2!K
M=75PY&5V82!E<VET=7-V:6ES.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N
M=&ET>7-E;&5C="YI;F,Z.3`*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@
M>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R(")686QI(&ED96YT:71E970@
M;6ED82!S;V]V:60@;75U=&$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI
M;F,Z,38*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S
M='(@(E9A;&D@:V5L;&%A:F$@97)A;&1A:F$Z(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM92!F;W)M870Z
M(@IM<V=S='(@(E9A;&D@:V5L;&%A:F$@97-I='5S=FEI<SHB"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C4W"FUS9VED(")396QE8W0@='=O(&UA
M=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`B5F%L:2!K86MS('-O8FEV870@=N1L
M:F$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P-@IM<V=I9"`B4V5L
M96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R(")686QI(';D<G9I<VME
M96TN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T.`IM<V=I9"`B4V5L
M96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R(")686QI(&]M
M82!L96UM:6MK965L.B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C4X"FUS9VED(")396YD(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(E-A
M861A('!R;V)L965M:2!K:7)J96QD=7,B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`S.0IM<V=I9"`B4V5N9"!335,B"FUS
M9W-T<B`B4V%A9&$@4TU3(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A
M;"(*;7-G<W1R(")396YE9V%L(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,38*;7-G:60@(E-E;G-O<CH@(@IM<V=S='(@(E-E;G-O<CH@(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.0HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0W"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@(E-E
M<'1E;6)E<B(*;7-G<W1R(")397!T96UB97(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT
M96YE9W)O(@IM<V=S='(@(E-E<F)I82!J82!-;VYT96YE9W)O(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#$*;7-G:60@(E-E<FEA
M;"!.=6UB97(B"FUS9W-T<B`B2N1R:F5N=6UB97(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,38Q"FUS9VED(")397)V97(@9&%T82!W<F]N
M9R!O<B!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")397)V97)I(&%N9&UE9"!O
M;B!V86QE9"!V]6D@<'5U9'5V860N(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP
M.C(W"FUS9VED(")397-S:6]N($%D;6EN(@IM<V=S='(@(E-E<W-I;V]N:61E
M(&AA;&1U<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G
M<W1R(")397-S:6]O;FD@240@;VX@865G=6YU9"XB"@HC.B!L:6(O87!I+G!H
M<#HQ-#4*;7-G:60@(E-E<W-I;VYS(@IM<V=S='(@(E-?97-S:6]O;FED(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-`IM<V=I9"`B4V5T(@IM
M<V=S='(@(DAU;&LB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8*;7-G
M:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A
M<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B(@HB3>3D
M<F$@86YD;65D(&UI<R!V]6EM86QD879A9"!S=6P@;VUA('!A<F]O;&D@Y')A
M(&UU=71A(&MU:2!S82!S96QL92!U;G5S=&%D+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,34*;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T
M:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G
M<W1R(")396%D:7-T82!VY&QI<V5D('-E<G9E<FED(&UI9&$@<V]O=FED(&]M
M82!P;W)T86%L:7,@:V%S=71A9&$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@T"FUS9VED(")3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I
M;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S='(@(E!A;F4@<&%I:V$@
M;VUA(&ME96QE+"!A:F%V]O9N9&D@:F$@:W5U<.1E=F$@<V5A9&ES='5S+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.`IM<V=I9"`B(@HB4V5T('EO
M=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E
M9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S
M='(@(B(*(DWDY')A(&]M82!A;&=R86ME;F1U<RP@=N1R=FES:V5E;2P@;&5H
M96O\;&IE(';D<G-K96YD86UI<V4@<V%G961U<R!J82!M=75D("`B"B)E<VET
M=7-E('-E861E9"XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<U"FUS
M9VED(")3971U<"(*;7-G<W1R(")086EG86QD=7,B"@HC.B!T96UP;&%T97,O
M861M:6XO<V5T=7`O:6YD97@N:'1M;#HS-PIM<V=I9"`B4V5T=7`@=7!G<F%D
M92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R(")/;&5M87-O;&5V860@<&%I
M9V%L9'5S92!U=65N9&%M:7-E('-K<FEP=&ED(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$X-@IM<V=I9"`B4V5V97)A;"!L;V-A=&EO;G,@
M<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T<B`B4&%R86UE
M971E<B!MY.1R86(@;6ET=2!V]6EM86QI:VMU(&%S=6MO:'1A.B`B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`T"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@(E-E:7-H96QL
M:60B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DV"FUS9VED(")3
M:&]P<&EN9R(*;7-G<W1R(")/<W1L96UI;F4B"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHT,PIM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G
M<W1R("),_&AI:V]K:W5V]71E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0T-@IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R
M(&UO<W0@;&EN:W,_(@IM<V=S='(@(DMA<R!E;F%M=7-E;&4@;&EN:VED96QE
M('1U;&5K<R!MY.1R871A(&MI:7)K;&%H=FED/R(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,S(S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3$S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@
M(D[D:71A(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U-0IM<V=I9"`B
M(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A
M;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R(").Y&ET82!O;&5M87-O;&5V82!J82#D<VIA(&=E;F5R965R:71U9"!K
M;VYF:6=U<F%T<VEO;VYI(&5R:6YE=G5S:2XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#DP"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N
M(&QO9V=I;F<@:6X_(@IM<V=S='(@(D[D:71A('-I<W-E;&]G:6UI<V5L(&5E
M;&UI<V4@<VES<V5L;V=I;6ES92!A96=A(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3<V-0IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG
M:6YA;"(*;7-G<W1R(")086MU(';U:6UA;'5S="!O<FEG:6YA86QI('/D:6QI
M=&%M:7-E:W,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$S"FUS
M9VED(")3:&]W('!I8VME<B(*;7-G<W1R(").Y&ET82!V86QI:F%T(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R-@IM<V=I9"`B4VAO=R!T86)L92!O
M<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R(").Y&ET82!T86)E;&ET;VEM
M:6YG=71E(&UE;OS\<FEB82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T
M:&4@;&5F=#\B"FUS9W-T<B`B3N1I=&$@=F%S86MU;"`E<R!M96[\_&0B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D
M:6%L;V<B"FUS9W-T<B`B3N1I=&$@=&%B96QI(&QA:'1R:2!O;6%D=7-T92!D
M:6%L;V]G:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R
M=&EE<R!D:6%L;V<B"FUS9W-T<B`B3N1I=&$@=&%B96QI(&]M861U<W1E(&1I
M86QO;V=I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O
M<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B3N1I=&$@=&%B96QI(')E82!O;6%D
M=7-T92!D:6%L;V]G:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@
M<')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B3N1I=&$@<&EL9&D@;VUA9'5S
M=&4@9&EA;&]O9VDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8S
M"FUS9VED(")3:&]W('5P;&]A9"(*;7-G<W1R(").Y&ET82!U<&QO861I(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3`*;7-G
M:60@(E-H;W=E<G,B"FUS9W-T<B`B2&]O=FEH;2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"FUS9VED(")3:&]W97)S($5A
M<FQY(@IM<V=S='(@(DAO;6UI:W5L(&AO;W9I:&UA9"(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED(")3:&]W97)S
M($QA=&4B"FUS9W-T<B`BU6AT=6P@:&]O=FEH;6%D(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@
M:6X@=&AE(%9I8VEN:71Y(@IM<V=S='(@(DAO;W9I:&UA9"#\;6)R=7-K;VYN
M87,B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT.#`*
M;7-G:60@(E-H<FEN:R(*;7-G<W1R(")+:71S96YD82(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<W-"!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HX,S8*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z.3(R(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.CDX-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ
M,#0W(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$P.#<*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$Q-B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,30Y"FUS9VED(")3:')I;FL@
M;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@
M9FER<W0B"FUS9W-T<B`B2VET<V5N9&$@:_5I9V5P96%L="!N86%B97)B;&]K
M:V4@=O5I(&YI:'5T82!N965D(&5E<W0@Y')A(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM
M<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(E-I97)R82!,96]N92(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C4*;7-G:60@(E-I
M9VX@=7`B"FUS9W-T<B`B3&EI='4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C<Q,@IM<V=I9"`B4VEG;F%T=7)E(@IM<V=S='(@(D%L
M;&MI<FDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q
M,0IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R(")!;&QK:7)J
M82!A;&=O<FET;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*
M;7-G<W1R(")3:6YG87!U<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C4@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HW,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C@W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,C$U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M,S<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.3,P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,C,*;7-G:60@(E-I>F4B"FUS9W-T<B`B4W5U<G5S(@H*(SH@=&5M<&QA
M=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K
M:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B2N1T82!H;V]L9'5S('9A:&5L92(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@(E-L;W9A
M:VMI82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@
M(E-L;W9E96YI82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C4T"FUS9VED(")3;F]W(@IM<V=S='(@(DQU;6DB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VYO
M=R!3:&]W97(B"FUS9W-T<B`B5&EH92!L=6UE<V%D=2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V"FUS9VED(")3;F]W(%-H
M;W=E<G,B"FUS9W-T<B`B5&EH961A9"!L=6UE<V%J=60B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3
M:&]W97)S($5A<FQY(@IM<V=S='(@(DAO;6UI:W5L('1I:&5D860@;'5M97-A
M:G5D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-3@*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(M5H='5L('1I
M:&5D860@;'5M97-A:G5D(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S@*
M;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R("),=6UE('!A:W-U<SH@(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#(*;7-G:60@(E-N;W<@97%U:79A
M;&5N="!I;B!W871E<CH@(@IM<V=S='(@(DQU;64@=F5E+65K=FEV86QE;G0Z
M("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M;VX@27-L86YD<R(*;7-G
M<W1R(")386%L;VUO;FD@<V%A<F5D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B
M4V]M86QI82(*;7-G<W1R(")3;VUA86QI82(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R("),875L
M=60@:F$@;'5U;&5T=7-E9"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Y,C8*;7-G:60@(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(E-O
M<G1E97)I;6ES:N1R:F5K;W)R82!V86QI:R(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Q-PHC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-#<*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-C8*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.#D*;7-G:60@(E-O
M=7)C92!A9&1R97-S(@IM<V=S='(@(DSD:'1E86%D<F5S<R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3@*;7-G:60@(E-O=71H($%F<FEC82(*;7-G<W1R("),]75N82U!869R
M:6MA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@(E-O=71H
M($5U<F]P96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R("),]75N82U%=7)O;W!A
M("A)4T\M.#@U.2TS*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O
M<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B
M3/5U;F$M1V5O<F=I82!J82!,]75N82U386YD=VEC:&D@4V%A<F5D(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM
M<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("),]75N87!O;VQK
M97)A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',B"FUS
M9W-T<B`B5F%H92!L86AT<FET92!V86AE;"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W
M965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@(E9A:&4@
M;&%H=')I('-I<W4@:F$@Y.1R92!V86AE;"(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C@Q-0IM<V=I9"`B4W!A8V5R(@IM<V=S='(@(D5R86QD86IA
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@P"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(E9A:&4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS
M9VED(")3<&%C:6YG(&%N9"!P861D:6YG(@IM<V=S='(@(E9A:&5D(&IA('9O
M;V1E<F1U<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")3<&%I;B(*;7-G<W1R(")(
M:7-P86%N:6$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3@*;7-G
M:60@(E-P86TB"FUS9W-T<B`B4N1M<'-P;W-T(@H*(SH@<V5R=FEC97,O:V5Y
M8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C:6%L($-H87)A8W1E<B!);G!U="(*
M;7-G<W1R(")%<FEMY')K:61E('-I<V5S='5S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L
M:70@8V5L;"(*;7-G<W1R(")%<F%L9&$@;&%H=')I9"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*;7-G:60@
M(E-P;&ET(&-O;'5M;B(*;7-G<W1R("),86AU=&$@=F5E<F<B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS
M9VED(")3<&QI="!R;W<B"FUS9W-T<B`B3&%H=71A(')I9&$B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-C$*;7-G:60@(E-P;W)T<R(*;7-G<W1R(")3
M<&]R="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@
M(E-R:2!,86YK82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW
M,R!L:6(O0FQO8VLO;65T87(N<&AP.C<T"FUS9VED(")3=&%N9&%R9"(*;7-G
M<W1R(")3=&%N9&%R9"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@IM
M<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(E-T87(@5')E:R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(U.38@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C@P.0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R(")!;&=U<V%A<W1A
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G
M:60@(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(D]S87)I:6L@=O5I(&UA
M86MO;F0B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ
M,@IM<V=I9"`B4W1A='5S(@IM<V=S='(@(D]L96LB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.#$U"FUS9VED(")3=&]R86=E(&9O<FUA="(*;7-G
M<W1R(")386QV97-T=7-F;W)M86%T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-S(*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S
M='(@(E3D;F%V(&IA(&UA:F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q"FUS9VED(")3=')I:V5T:')O=6=H(@IM<V=S
M='(@(DSD8FEJ;V]N:71U9"!T96MS="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R,S,*;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@(E-T<FEN
M9VED92!L;V5N9"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S,*
M;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@
M(D5R86QD82!D;VUE96X@86%D<F5S<VES="(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE
M(%M#4U-=(@IM<V=S='(@(E-T:6EL(%M#4U-=(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T
M<B`B4/PB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM
M<V=S='(@(D%L86UK871A;&]O9VD@7"(E<UPB(&5I(&QE:71U9"XB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S"FUS9VED
M(")3=6)J96-T(@IM<V=S='(@(E1E96UA(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S,R(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP
M.C,Q-PIM<V=I9"`B4W5B;6ET(@IM<V=S='(@(DMI;FYI=&$B"@HC.B!S:6=N
M=7`N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R
M97%U97-T('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N
M;W0@;&]G(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R
M;W9E9"XB"FUS9W-T<B`B(@HB4V]O=B!<(B5S7"(@;&ES86UI<V5K<R!S_'-T
M965M:2!O;B!S86QV97-T871U9"X@4V$@96D@<V%A('-I<W-E(&QO9VED82!E
M;FYE("(*(FMU:2!S:6YU('-O;W8@;VX@:&5A:W,@:VEI9&5T=60N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I
M9"`B4W5B<V-R:7!T(@IM<V=S='(@(D%L86EN9&5K<R(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I
M9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S
M<R(*;7-G<W1R("),Y&MS(&MO<F1A(@H*(SH@861M:6XO=7-E<BYP:'`Z.#4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D(%PB)7-<
M(B!T;R!T:&4@<WES=&5M+B(*;7-G<W1R(")<(B5S7"(@;VX@<_QS=&5E;6D@
M;&ES871U9"XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<
M(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R(")<(B5S7"(@86YD;65D
M(&]N('/\<W1E96UI<W0@965M86QD871U9"XB"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R
M(")<(B5S7"(@;VX@:W5S='5T871U9"XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@
M7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B7"(E<UPB(&]N('/\
M<W1E96UI<W0@965M86QD871U9"XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A
M=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R("(B"B)+;VYF
M:6=U<F%T<VEO;VX@;VX@=&%G87-I(';U971U9"X@375U='5S=&4@;N1G96UI
M<V5K<R!VY')S:V5N9&$@=F%A9&5T+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HU.2!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU-PIM<V=I9"`B4W5C
M8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M(")+;VYF:6=U<F%T<VEO;VYI('9A<G5K;V]P:6$@]6YN97-T=7,@<V%L=F5S
M=&%D82XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8R"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O
M;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B2V]N9FEG=7)A='-I;V]N
M:69A:6QI('9A<G5K;V]P:6$@)7,@]6YN97-T=7,@<V%L=F5S=&%D82XB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY('5P9&%T960@7"(E<UPB(@IM<V=S='(@(EPB)7-<(B!M=75T
M;6EN92#U;FYE<W1U<RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`B)7,@:VER:G5T86UI
M;F4@]6YN97-T=7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=61A;B(*;7-G
M<W1R(")3=61A86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4V"FUS9VED(")3=6UM87)Y(@IM<V=S='(@(E-I
M<W5K;VMK=7;U=&4B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C4*;7-G
M:60@(E-U;B!2:7-E(@IM<V=S='(@(E#D:6ME<V5T]75S(@H*(SH@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(E#D
M:6ME<V5L;V]J86YG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-3D*;7-G:60@(E-U;FYY(@IM<V=S='(@(E#D:6ME<V5P86ES
M=&5L:6YE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-@IM
M<V=I9"`B4W5N<FES92(*;7-G<W1R(")0Y&EK97-E=/5U<R(*"B,Z(&QI8B]"
M;&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@IM
M<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`B4.1I:V5S973U=7,O;&]O
M:F%N9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,34*;7-G
M:60@(E-U;G)I<V4Z("(*;7-G<W1R(")0Y&EK97-E=/5U<SH@(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.0IM<V=I9"`B4W5N<V5T(@IM
M<V=S='(@(E#D:6ME<V5L;V]J86YG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Q.`IM<V=I9"`B4W5N<V5T.B`B"FUS9W-T<B`B4.1I:V5S
M96QO;VIA;F<Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@(MQL86EN
M9&5K<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S@*;7-G:60@
M(E-U<'!O<G0B"FUS9W-T<B`B5'5G:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@
M(E-U<FEN86UE(@IM<V=S='(@(E-U<FEN86UI(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S0*;7-G:60@(E-U<FYA;64B"FUS9W-T
M<B`B4&5R96MO;FYA;FEM:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-V86QB
M87)D(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B4W9A;&)A<F0@:F$@2F%N($UA
M>65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@
M(E-V86%S:6UA82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G
M<W1R(")2;V]T<VDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B
M"FUS9W-T<B`B4VAV96ET<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C@V"FUS9VED(")3>6YC(&QO9R!D96QE=&5D(@IM<V=S='(@(E/\;FMR
M;VYI<V5E<FEM:7-E(&QO9VD@:W5S='5T871U9"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-#(*;7-G:60@(E-Y;F--3"(*;7-G<W1R(")3>6YC34PB
M"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z.3<*;7-G:60@
M(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B2VER:F%V
M:6=A(&]T<VEN9W5T:6YG:6UU<W1E<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@
M(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(E/\_')I82!!<F%A8FEA
M(%9A8F%R:6EK(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C`*;7-G:60@(E0M4W1O<FTB"FUS9W-T<B`BQ&EK97-E=&]R;2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Q"FUS
M9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G<W1R(")4=75L:6YE(&IA(.1I
M:V5S96QI;F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV,@IM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`BQ&EK97-E<'5H86YG
M=60B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M,PIM<V=I9"`B5"U3=&]R;7,@16%R;'DB"FUS9W-T<B`B2&]M;6EK=6P@Y&EK
M97-E<'5H86YG=60B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z
M,38V"FUS9VED(")44U8@9FEL92(*;7-G<W1R(")44U8@9F%I;"(*"B,Z(&9R
M86UE=V]R:R]522]522]486)L92YP:'`Z,3,T"FUS9VED(")486)L92(*;7-G
M<W1R(")486)E;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS
M9W-T<B`B5&%B96QI(&]M861U<V5D(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PIM<V=I9"`B5&%B;&4@4V5T(@IM<V=S
M='(@(E1A8F5L:71E(&AU;&LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P97)T
M:65S(@IM<V=S='(@(E1A8F5L:2!O;6%D=7-E9"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3$*;7-G:60@(E1A:7=A;B(*;7-G<W1R(")486EV86XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I9"`B5&%I=V%N
M+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R(")486EV86XL($AI:6YA('!R
M;W9I;G1S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G
M<W1R(")4861Z:6MI<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A;GIA
M;FEA+"!5;FET960@4F5P=6)L:6,@;V8B"FUS9W-T<B`B5&%N<V%A;FEA(-QH
M96YD=F%B87)I:6LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDU"FUS9VED(")487)G970Z(@IM<V=S='(@(D%V86YE;6EN
M93HB"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3DV(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ.#<*;7-G:60@(E1A<VMS(@IM<V=S='(@(E3V]F0B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,PIM<V=I
M9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R(")496QE9F]N:6YU;6)E<B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDP"FUS9VED(")496UP(&9O<B!L
M87-T(&AO=7(Z("(*;7-G<W1R(")6:6EM87-E('1U;FYI('1E;7!E<F%T=75R
M.B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$T"FUS9VED(")496UP97)A
M='5R92(*;7-G<W1R(")496UP97)A='5U<B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,C,*;7-G:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T
M<B`B5&5M<&5R871U=7(Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&5R871U<F4\8G(@
M+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<R(*;7-G<W1R(")496UP97)A='5U
M<CQB<B`O/B@E<TUA>"5S+R5S36EN)7,I("9D96<[)7,B"@HC.B!F<F%M97=O
M<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C8X-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")496UP;&%T92!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")-86QL
M:2!<(B5S7"(@96D@;&5I='5D+B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M,38Y"FUS9VED(")496UP;&%T92!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")-
M86QL:61E(&AA;&1U<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S-@IM<V=I9"`B5&5X="(*
M;7-G<W1R(")496MS="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S4*
M;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R(")!:6YU;'0@=&5K<W0B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<T
M"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@(E1E:W-T:2!J;V]N9'5S(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM
M<V=I9"`B5&5X='1O<"(*;7-G<W1R(")497AT=&]P(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I9"`B5&@B"FUS
M9W-T<B`B3F4B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B
M5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B5&%I("A425,M-C(P*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#D*;7-G:60@(E1H86EL86YD(@IM<V=S='(@(E1A:2(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX.`IM<V=I9"`B5&AA;FL@>6]U(&9O
M<B!U<VEN9R!T:&4@<WES=&5M+B(*;7-G<W1R(")4Y&YA;64@:_QL87-T86UA
M<W0N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,C`*;7-G:60@
M(E1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(D944"!L86EE;F1U<R!E:2!O;&4@<V%A9&%V86PN(@H*;7-G:60@(E1H92!(
M:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B2&ES=&]R>2!S
M_'-T965M(&]N(';D;&IA(&S\;&ET871U9"XB"@HC('!H<"UF;W)M870*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S0*;7-G:60@(E1H92!(;W)D
M92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<
M(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(@:6YT96=R871S:6]O;FEM;V]T
M;W(@96D@=&]E=&$@7"(E<UPB+6DB"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O
M24U34"]";V]K+G!H<#HQ,CDR"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@
M;F]T(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R("))35-0(&QO9VD@86QG=N3D
M<G1U<W1A;6EN92!N=7)J=7,N(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C,Q"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T
M(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(DUA:6YT96YA;F-E.CH@:VQA
M<W-I(&QA861I;6EN92!N=7)J=7,B"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L
M;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S
M(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B4V5A9&5T92!A:V5N(&]N('-U
M;&5T=60N(%;D;&IU;BXB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C$X.2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(P,`HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C(Q,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C(R,PHC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(S-"!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(U,@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C(V-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,P,PIM
M<V=I9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E
M(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A
M;G0@=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B"B)+=6D@=&%H860@
M:V%S=71A9&$@]6EG=7-I+"!P96%B(&%D;6EN:7-T<F%A=&]R('-E861I<W1A
M;6$@</QS:79A(/5I9W5S=&4@(@HB<_QS=&5E;6DN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B
M5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T<B`B06EN=6QT(&%L=6UI;F4@
M:_QL9R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S
M(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I
M;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*(DMO;G1A:W1I($E$(&YU
M;6)R:70@96D@;>3D<F%T=60L(&KD971I('3\:&IA:W,@=O5I('-E92!P=75D
M=6(@86YD;65B86%S:7,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C4Q"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S
M<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R(")+
M:7)J92#U;FYE<W1U<R!L:7-A9&$@<VEN=2!A861R97-S:7)A86UA='5S<V4N
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V.0IM<V=I
M9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B
M(@HB06QL:VER:F%S=&%T=60@:VER:F$@:V]N=')O;&QI;6ES96MS(&]N('9A
M:F$@97)A;&1I(%!'4"!A;&QK:7)J86)L;VMK:2XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B(@HB
M5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I
M9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B
M87-E+B(*;7-G<W1R(")*86]T=7-N:6UE:VER:F$@240@;VX@;>3D<F%M871A
M+"!JY&5T:2!T_&AJ86MS(';U:2!P=75D=6(@86YD;65B86%S:7,N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*
M;7-G:60@(E1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE
M9"XB"FUS9W-T<B`B2F%O='5S;FEM96MI<FD@<&]L92!MY.1R871U9"XB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q,PIM<V=I9"`B5&AE(&5N
M8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C
M=&EO;BXB"FUS9W-T<B`B2W+\<'1I;6ES96MS(&]N('9A:F$@='5R=F%L:7-T
M($A45%`@_&AE;F1U<W0N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HQ-S4@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S
M971T:6YG+B(*;7-G<W1R(")&86EL("5S('!E86MS('-I<V%L9&%M82`E<R!M
MY.1R86YG=70N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C@@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T
M:6YG<RXB"FUS9W-T<B`B1F%I;"`E<R!P96%K<R!S:7-A;&1A;6$@;6EN9V5I
M9"`E<R!MY.1R86YG=6ED+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(Q.0IM<V=I9"`B5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT
M;R!I='-E;&8N(@IM<V=S='(@(D9A:6QI(&5I('-A82!K;W!E97)I9&$@:7-E
M96YD86QE(&]T<V$N(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,C@P
M"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B
M1F%I;"!E:2!S:7-A;&1A;G5D(&%N9&UE:60N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B5&AE(&9O;&QO
M=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@
M;65S<V%G92XB"FUS9W-T<B`B2N1R9VYE=F%D('-E;&QE(&UE<W-A9V4O<F9C
M.#(R(&MI<FIA('#D:7-E9"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@
M;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T
M($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R
M96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC
M92`B"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N
M<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@
M<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO
M=2=L;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@
M;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0
M;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H
M92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*(E3D:7-E:W)A86YI
M<F5Z:6EM:2!K87-U=&%M:6YE('1E:VET86(@<')O8FQE96UE($EN=&5R;F5T
M($5X<&QO<F5R:7,@=.1N=2`B"B)S96QL92!V965B:6QE:&ET<V5J82!V:6=A
M9&5L92P@;6ED82!M96EL(&5I(/5N;F5S='4@;6%H82!S=7)U9&$N($5S:6YE
M9&$@(@HB=O5I8B!LY&)U(&MU:G5T:7-E<RP@961I=&]R:2!F=6YK='-I;V]N
M:61E('!U=61U;6ES="!J82]V]6D@=F5E8FEL96AI='-E:F$@(@HB:G5H=7-L
M:6MK=2!K:6YN:6IO;VMS;6ES="X@2W5I('-I;G4@87)V=71I(&]P97)A='-I
M;V]N:6MS(&]N(%=I;F1O=W,@.7@L("(*(G-I:7,@;VX@=N1G82!T]65NY&]L
M:6YE(&5T('-A860@7")'96YE<F%L(%!R;W1E8W1I;VX@1F%U;'1<(B!V96%T
M96%T92!J82`B"B)P96%D(&%R=G5T:2!T86%S:^1I=FET86UA+EQ<;EQ<;E-I
M;F0@;VX@:&]I871A='5D+B!+;/5P<V$@3TLL(&MU:2!S;V]V:60@(@HB<VEI
M<VMI('3D:7-E:W)A86YI<F5Z:6EM:2!P<F]O=FED82XB"@HC.B!S97)V:6-E
M<R]P<F5F<RYP:'`Z.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT
M:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("))9&5N=&ET
M965T(%PB)7-<(B!O;B!K=7-T=71A='5D+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L
M969T+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(D%I;G5L="!V87-A:R!K_&QG
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,34W"FUS9VED
M("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E
M(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B0W)Y
M<'1?<&=P.CH@:VQA<W-I(&IA;VMS('!E86(@;VQE;6$@;>3D<F%T=60@1VYU
M4$<@<')O9W)A;6UI(&%S=6MO:'0N(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-1$XN<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@;65S
M<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<(B5S7"(@:&%S
M(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R86YT964@=&AA
M="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N(@IM
M<V=S='(@(B(*(DMI<FD@;6ES('-A861E=&D@)7,@86%D<F5S<VEL92`E<R!T
M965M86=A(%PB)7-<(B!O;B!A=F%T=60N7&XB"B)3964@96D@9V%R86YT965R
M:2!E="!K:7)I(&SD8FD@;&]E=&D@=O5I('-E;&QE<W0@87)U('-A861I+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S<*;7-G:60@(E1H92!N
M86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*
M;7-G<W1R(").:6UI(&UI9&$@:V%S=71A9&$@961I=&]R:2!L96AE9V$@;&EN
M:VEM:7-E;"(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T,0IM
M<V=I9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*
M;7-G<W1R(")6Y&QJ861E(&%R=B!P96%B(&]L96UA(&%R=BXB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S$*;7-G:60@(E1H92!O
M<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T
M7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@(DAO<F1E7T-R>7!T7W-M:6UE.CH@
M:VQA<W,@=F%J86(@;W!E;G-S;"!M;V]D=6QI="XB"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U
M<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM=6T@86QL;W=A8FQE
M('-I>F4B"FUS9W-T<B`B(@HB165L:7-T=7-T(%PB)7-<(B!E:2#U;FYE<W1U
M;G5D('-A;'9E<W1A9&$L(&MU;F$@86YD;65T92!H=6QK(/QL971A<R!S=75R
M:6UA("(*(FQU8F%T=60@;>3D<F$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]D96(N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<G!M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]W96)C<'`N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S
M*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(@IM<V=S='(@(B(*(E-E
M9&$@=/S\<&D@86YD;65T92`H)7,I('9A871A;6ES96MS('9A:F%L:6MK=2!P
M<F]G<F%M;6D@96D@;&5I='5D('/\<W1E96UI<W0N(@H*(SH@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z-#4T"FUS9VED(")4:&4@<75O=&4@8VAA<F%C
M=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(DIU
M='5MY')K('!E86(@;VQE;6$@_&MS(&WD<FLN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE
M(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'DB"FUS9W-T<B`B06EN=6QT('9A
M<V%K(&IA('!A<F5M(&O\;&<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N
M9"!S:61E(&]N;'DB"FUS9W-T<B`B06EN=6QT('!A<F5M(&O\;&<B"@HC.B!F
M<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#8*;7-G:60@(E1H92!S97!A
M<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B
M17)A;&1A:F$@<&5A8B!O;&5M82#\:W,@;>1R:RXB"@HC.B!S97)V:6-E<R]P
M;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")397)V
M97(@7"(E<UPB(&]N(&MU<W1U=&%T=60N(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E
M<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(E-E<G9E<B!<(B5S
M7"(@;VX@<V%L=F5S=&%T=60N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@
M:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B)7,@;&EI='5M:7-S;V]V(&]N
M(&5E;6%L9&%T=60N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z,S,P"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E
M>&ES="XB"FUS9W-T<B`B3>3D<F%T=60@<FED82!P;VQE(&]L96UA<RXB"@IM
M<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES="XB
M"FUS9W-T<B`B3>3D<F%T=60@<FED82`H)60I('!O;&4@;VQE;6%S+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3<W"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!T96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI
M<W0N(@IM<V=S='(@(D%J=71I<W0@9F%I;&D@7"(E<UPB('!O;&4@;VQE;6%S
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,3$*;7-G:60@(E1H
M92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@
M=&AE('-C<F5E;BXB"FUS9W-T<B`B4VEN=2!S:7-E<W1A='5D('1E:W-T(&5I
M(&MA='1U(&5K<F%A;FEL(&]L979A9V$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O
M<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B06EN=6QT(/QL96UI
M;F4@:F$@86QU;6EN92!K_&QG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E
M(&]N;'DB"FUS9W-T<B`B06EN=6QT(/QL96UI;F4@:_QL9R(*"B,Z(&9R86UE
M=V]R:R]$871A+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A
M=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@
M(E-A861E='5D(&%N9&UE9"!O;B!V86AE<&5A;"!K86]T<VD@;.1I;G5D+B(*
M"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A;65W;W)K
M+T1A=&$O1&%T82]T<W8N<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D(&9I
M;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R(")386%D971U9"!F86EL
M:2!E:2!S86%N=60@<V%L=F5S=&%D82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-#8@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4V
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,34@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$Q.0IM<V=I9"`B5&AE('=E871H97(N8V]M
M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(G=E871H97(N8V]M
M(&)L;VMK(&5I(&]L92!KY'1T97-A861A=BXB"@HC.B!U=&EL+VEC;VY?8G)O
M=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE;65S(&1I<F5C
M=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")+=6IU;F1U<W1E(&MA
M=&%L;V]G:2!<(B5S7"(@96D@;&5I='5D+B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,3<X"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N
M<R!A=F%I;&%B;&4N(@IM<V=S='(@(D5I(&]L92!M:61A9VD@<V5A9&ES=&%D
M82XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HS-#(*
M;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y
M960@:6YL:6YE+B(*;7-G<W1R(")+:7)J86P@96D@;VQE('9A:&5T=6QT(&5S
M:71A=&%V86ED(&]S:2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N
M>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@
M)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S
M+B(*;7-G<W1R("(B"B)396QL97,@=N1L:F%S(&]N(&QI:6%L="!P86QJ=2!M
MY')K92X@4V$@<VES97-T87-I9"`E<R!MY')K:3L@;'5B871U9"!P;VQE("(*
M(G)O:&ME;2!K=6D@)7,N(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U<V5R
M+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B
M;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`B
M7"(E<UPB(&QI<V%M:7-E;"!S_'-T965M:2!T96MK:7,@<')O8FQE96TZ("5S
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<
M(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B2V%S=71A:F$@7"(E
M<UPB(&%N9&UE=&4@<_QS=&5E;6ES="!E96UA;&1A;6ES96P@=&5K:VES('!R
M;V)L965M.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@
M9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B7"(E<UPB(&5E;6%L9&%M:7-E
M;"!S_'-T965M:7-T('1E:VMI<R!P<F]B;&5E;3H@(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,34Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R
M;V)L96T@=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R(")<(B5S7"(@;75U
M=&UI<V5L('1E:VMI<R!P<F]B;&5E;3H@)7,B"@HC.B!F<F%M97=O<FLO0G)O
M=W-E<B]"<F]W<V5R+G!H<#HX.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@
M=V%S('5P;&]A9&5D+B(*;7-G<W1R(")&86EL:2!L86%D:6UI<V5L('-E<G9E
M<FES<V4@=&5K:VES('!R;V)L965M.B`E<R!E:2!L865T=60N(@H*(SH@9G)A
M;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB
M86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@(B(*(D9A:6QI(&QA
M861I;6ES96P@<V5R=F5R:7-S92!T96MK:7,@<')O8FQE96TZ("5S(&]L:2!S
M=75R96T@:W5I(';U:6UA;&1A8B`B"B)P:6ER86YG("@E9"!B86ET:2DN(@H*
M(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#DQ"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@
M9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D
M960N(@IM<V=S='(@(B(*(D9A:6QI(&QA861I;6ES96P@<V5R=F5R:7-S92!T
M96MK:7,@<')O8FQE96TZ("5S(&QA971I(&%I;G5L="!O<V%L:7-E;'0N(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HS-0IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S
M86=E('!A<G0B"FUS9W-T<B`B4V5L;&4@:VER:F$@;W-A(&5S:71A;6ES96P@
M=&5K:VES('9I9V$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,SD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C0X"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG
M('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(DMO;G1A:W1A;F1M971E(&EM
M<&]R=&EM:7-E;"!T96MK:7,@=FEG82XB"@HC.B!F<F%M97=O<FLO1&%T82]$
M871A+VEM8RYP:'`Z,S$*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O
M<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R(")I0V%L96YD87(G
M:2!A;F1M971E(&EM<&]R=&EM:7-E;"!T96MK:7,@=FEG82XB"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C@P"FUS9VED("(B"B)4:&5R92!W87,@86X@
M97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@
M;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B(@HB4V5A
M9&ES='5S92!V;W)M:6P@97-I;F5S('9I9V$N($5H:R!JY'1S:60@=.1I=&UA
M=&$@;?5N92!K;VAU<W1U<VQI:W4@=N1L:F$N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*(E1H
M97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D
M<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R
M+B(*;7-G<W1R("(B"B)3;V]V:71U9"!A861R97-S:7)A86UA='4@;W!E<F%T
M<VEO;VYI('-O;W)I=&%M:7-E;"!T96MK:7,@=FEG82X@4&%L=6X@<')O;W9I
M("(*(FAI;&IE;2!U=65S=&DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-#`*;7-G:60@(B(*(E1H97)E('=A<R!A
M;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@
M=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R(")+;VYT86MT86YD;65T92!U=65N
M9&%M:7-E;"!T96MK:7,@=FEG82X@4&%L=6X@<')O;W9I(&AI;&IE;2!U=65S
M=&DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HR,C(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T
M:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N
M(@IM<V=S='(@(DIA;W1U<VYI;65K:7)J82!U=65N9&%M:7-E;"!T96MK:7,@
M=FEG82X@4&%L=6X@<')O;W9I(&AI;&IE;2!U=65S=&DN(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS9VED(")4:&ES
M($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S
M+B(*;7-G<W1R(")3964@24U!4"!S97)V97(@96D@=O5I;6%L9&$@:V%U<W1A
M9&4@:F%G86UI<W0N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@
M82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`B4V5E(&5I(&[D:2!O;&5V
M870@:V]R<F%L:6L@4D%2(&%R:&EI=BXB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P
M<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R(")3964@96D@
M;N1I(&]L979A="!K;W)R86QI:R!:25`@9F%I;"XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,30U"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@
M=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`B4V5E(&5I(&[D
M:2!O;&5V870@:V5H=&EV(&MA87)D:2!N=6UB97(N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U"FUS9VED("(B
M"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O
M=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI
M(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"B)3964@
M9')A:79E<B!V]6EM86QD86(@<V%A=&$@<_5N=6UE:60@;.1B:2!#;&EC:V%T
M96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI("(*(FS\_'-I+"!K87-U=&%D
M97,@2%144"!!4$ET(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HQ,S0*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L
M8RYC;VTI("(*(F=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R
M("(B"B)3964@9')A:79E<B!V]6EM86QD86(@<V%A=&$@<_5N=6UE:60@;.1B
M:2!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2!L_/QS:2P@(@HB:V%S=71A9&5S
M($A45%`@05!)="XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH
M='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A4
M5%`@05!)(@IM<V=S='(@(B(*(E-E92!D<F%I=F5R(';U:6UA;&1A8B!S86%T
M82!S]6YU;65I9"!LY&)I('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC
M;VTI("(*(FS\_'-I+"!K87-U=&%D97,@2%144"!!4$ET+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U"FUS
M9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E
M<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G871E
M=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N
M(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO
M+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"B)3964@9')A:79E<B!V]6EM86QD
M86(@<_5N=6UI=&4@<V%A=&UI<W0@4TU44"!P<F]T;VMO;&QI9V$@;.1B:2!6
M;V1A9F]N92`B"B))=&%L>2!L_/QS:2P@86EN=6QT(%9O9&%F;VYE(&YU;6)R
M:71E;&4N(%-E;&QE:W,@;VX@=F%J82!6;V1A9F]N92!)=&%L>2!E+2(*(G!O
M<W1I(&MO;G1O="`H:'1T<#HO+W=W=RXQ.3`N:70I(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.3<X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P
M-3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`X-B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,3$U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Q.#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(U-@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,S`U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$S.3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34U-R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Y-3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P-0HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#(Y(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(P-S@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$T.2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(T,3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U-`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C4W(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S-R!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S`V"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,X,30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@R,@IM
M<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B4V5E(';D
M;&D@;VX@:V]H=7-T=7-L:6LN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3`V-0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN
M=&5G97)S+B(*;7-G<W1R(")3964@=N1L:2!V]6EB('-I<V%L9&%D82!V86ED
M('3D:7-A<G9E+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3@*
M;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N
M9"!T:&4@8V]L;VXN(@IM<V=S='(@(E-E92!VY&QI(';U:6(@<VES86QD861A
M(&%I;G5L="!N=6UB<F5I9"!J82!K;V]L;VYI="XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,#DT"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R(")3964@=N1L:2!V]6EB
M('-I<V%L9&%D82!A:6YU;'0@:V%H96MS86YD87)V92XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,3(S"FUS9VED(")4:&ES(&9I96QD(&UU<W0@
M8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R
M<R(*;7-G<W1R(")3964@=N1L:2!P96%B(&]L96UA(&MO;6%G82!V]6D@=/QH
M:6MU9V$@97)A;&1A='5D('3D:7-A<G9U9&4@;&]E;F0B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HY.#D*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B
M92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`B4V5E(';D;&D@<&5A8B!O;&5M
M82!K;W)R96MT;F4@87)V+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,S8*;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L
M;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*
M(B<C,3(S-&%F)RXB"FUS9W-T<B`B4V5E(';D;&D@<&5A8B!S:7-A;&1A;6$@
M=N1R=FEK;V]D:2!21T(@2&5X(&MU:G5L+"!NY&ET96MS("<C,3(S-&%F)RXB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU-C$*;7-G:60@(E1H:7,@
M9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B4V5E
M('9O<FT@;VX@:G5B82!LY&)I('3V]G1A='5D+B(*"B,Z('1E;7!L871E<R]H
M96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@
M)7,N(@IM<V=S='(@(E-E92!O;B`E<RXB"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C0U.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES
M(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C
M="!Y;W4@=VEL;"!N965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N9&5R
M<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T
M(&]F('-U8V@@96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B"FUS
M9W-T<B`B(@HB4V5E(&]N($MO;&%B($=R;W5P=V%R92!O8FIE:W0N(%-E;&QE
M(&]B:F5K=&D@=F%A=&%M:7-E:W,@=F%J860@92UP;W-T:2`B"B)K;&EE;G1I
M(&UI<R!M]6ES=&%B($MO;&%B($=R;W5P=V%R92!F;W)M86%T:2X@4V5L;&ES
M=&4@92UP;W-T:2!K;&EE;G1I9&4@(@HB;FEM96MI<FIA(&QE:6%D(&%A9')E
M<W-I;'0@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HU.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W
M<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U
M<B!O=VXN(@IM<V=S='(@(E-E92!K:7)I(&]N(&MI<FIU=&%T=60@;>1R9VES
M=&EK=7,@*"5S*2!M:7,@97)I;F5B('-I;G4@;VUA<W0N(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R
M(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R(")3964@87)V('!E86(@
M;VQE;6$@=N1H96UA;'0@_&MS+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]G>FEP+G!H<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@
M=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@(E-E92!S
M97)V97(@96D@;?5I<W1A(&QA:'1I('!A:VMI9&$@>FEP(&IA(&=Z:7`@9F%I
M;&4N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ
M.#D*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E
M9"XB"FUS9W-T<B`B4V5E('/\<W1E96T@;VX@<')A96=U(';D;&IA(&S\;&ET
M871U9"XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-`IM
M<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R(")3
M96QL92!K;VAA('!E86P@<&5A8B!O;&5M82!A<G8N(@H*(SH@<V5R=FEC97,O
M:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM<V=I9"`B5&AI<R!W:6YD;W<@
M;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R
M(")3964@86ME;B!T=6QE8B!A=F%D82!396%D971E(&%K;F%S="(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4
M:'5N9&5R(@IM<V=S='(@(L1I:V4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C,T"FUS9VED(")4:6-K971S(@IM<V=S='(@(DAE;'!D97-K(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0R."!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(E1I;64B"FUS9W-T<B`B065G(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X-@IM<V=I9"`B5&EM92!4
M<F%C:VEN9R(*;7-G<W1R(")4]O9A:F%T86)E;"(*"B,Z(&QI8B]";&]C:R]T
M:6UE+G!H<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`B06IA(&5S
M:71U<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U,SD*;7-G:60@
M(E1I;64@<V5L96-T:6]N(@IM<V=S='(@(D%J82!V86QI:R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@(DED82U4:6UO<B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@
M;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@
M(E!E86QK:7)I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R(")0
M96%L:VER:2`H=&]O;'1I<"DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R(")+96QL96QE
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U
M-`IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O
M=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W
M:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B(@HB36ET;64@;V)J96MT:2!V86QI
M;6ES96MS(&AO:6$@86QL($-T<FP@*%!#*2!V]6D@0V]M;6%N9"`H36%C*2!K
M;&%H=FD@:F$@(@HB:VSU<'-A(&]B:F5K=&ED96PN(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B5&]D87DB"FUS9W-T<B`B
M5.1N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R(")(5$U,
M(&MO;V1I(')E>FEI;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1O9V\B"FUS
M9W-T<B`B5&]G;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O:V5L874B"FUS
M9W-T<B`B5&]K96QA=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS,3,*;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(DAO;6UE(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,CD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,`IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B5&]N9V$B"@IM<V=I9"`B
M5&]O(&UA;GD@:6YV86QI9"!L;V=I;G,@9'5R:6YG('1H92!L87-T(&UI;G5T
M97,N(@IM<V=S='(@(E9I:6UA<W1E;"!M:6YU=&ET96P@;VX@;&EI9V$@<&%L
M:G4@;G5R:G5N=60@<VES<V5L;V=I;6ES:2XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S<*;7-G:60@(E1O<"(*
M;7-G<W1R("+<;&5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY,PIM<V=I9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R
M(")096%L;6ES97,@<F%A;6ES("A?=&]P*2(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV,PIM<V=I9"`B5')A;G-L871I;VYS(@IM<V=S='(@(E3U;&ME
M9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B
M"FUS9W-T<B`B5')I;FED860@:F$@5&]B86=O(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3<Y,`IM<V=I9"`B5')U92!O<B!F86QS92(*;7-G<W1R
M(")4]61E(';U:2!V86QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T<B`B5&4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$P"FUS9VED(")4=6YI<VEA(@IM<V=S='(@(E1U;F5E<VEA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(E3\<F=I(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(E1U<FMI<V@@*$E3
M3RTX.#4Y+3DI(@IM<V=S='(@(E3\<F=I("A)4T\M.#@U.2TY*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3`*;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R(")4=7)K;65N
M:7-T86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S
M($ES;&%N9',B"FUS9W-T<B`B5'5R:W,@:F$@0V%I8V]S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,0IM<V=I9"`B5'5V86QU(@IM<V=S='(@(E1U=F%L=2(*"B,Z(&9R86UE
M=V]R:R]#3$DO0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z
M("(*;7-G<W1R(")+:7)J=71A(&]M82!V86QI:SHB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C8Y"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS
M9W-T<B`B558M:6YD96MS.B`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS
M9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U
M<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R(")3:6YU
M('-K<FEP=&D@:^1T=&5T;VEM971A;6ES<F%P;W)T:2!54DPB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW"FUS9VED(")5
M4DPZ(@IM<V=S='(@(E523#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")59V%N
M9&$B"FUS9W-T<B`B56=A;F1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56MR
M86EN92(*;7-G<W1R(")5:W)A:6YA(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z-#$R"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E
M8W1O<GDN(@IM<V=S='(@(D5I('#DY'-E(&QI9VD@5D93(&MA=&%L;V]G:6QE
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I
M9"`B56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@
M<VEG;FEN9R!U<"XB"FUS9W-T<B`B5.1I96YD879A(&MA<W5T86IA:6YF;R!L
M:7-A;6EN92!L:6ET=6UI<V5L(&5I(/5N;F5S='4N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HS.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N
M(@IM<V=S='(@(D5I('-A82!M=75T82!61E,@9F%I;&D@7"(E<UPB(/5I9W5S
M:2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS.#4@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S
M+R5S+B(*;7-G<W1R(")%:2!S86$@;75U=&$@5D93(&9A:6QI("5S+R5S(/5I
M9W5S:2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G
M<W1R(")%:2!S86$@;6EN;F$@:V%T86QO;V=I("5S+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,C,R"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<UPB+B(*;7-G<W1R(")&
M86EL:2!<(B5S7"(@<W5U<G5S="!P;VQE(';U:6UA;&EK(&MO;G1R;VQL:61A
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8X."!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C$P,38*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C@S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`B1F%I
M;&D@7"(E<R\E<UPB('-U=7)U<W0@<&]L92!V]6EM86QI:R!K;VYT<F]L;&ED
M82XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z-#,U"FUS9VED
M(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+B(*;7-G<W1R(")%
M:2!S86$@_&AE;F1U<W0@4U%,('-E<G9E<FEG82XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C@S.0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@
M=VET:"!34TPN(@IM<V=S='(@(E-33"#\:&5N9'5S92!A;&=A=&%M:6YE(&YU
M<FIU<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,C4@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C(P,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,C`Y"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B
M5D93(&9A:6QI(&MO<&5E<FEM:6YE(&YU<FIU<RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C,V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")6
M1E,@:V%T86QO;V=I(%PB)7-<(B!L;V]M:6YE(&YU<FIU<RXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-30@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C(U.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,C4V"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN
M(@IM<V=S='(@(E9&4R!K871A;&]O9VD@;&]O;6EN92!N=7)J=7,N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$R-`IM<V=I9"`B56YA8FQE
M('1O(&-R96%T92!61E,@9FEL92XB"FUS9W-T<B`B5D93(&9A:6QI(&QO;VUI
M;F4@;G5R:G5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C@V
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9O
M;&1E<B!<(B5S7"(N(@IM<V=S='(@(E9&4R!K875S=&$@7"(E<UPB(&QO;VUI
M;F4@;G5R:G5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(V
M-0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS
M9W-T<B`B16D@<V%A(&QU=6$@=/QH:F$@5D93(&9A:6QI+B(*"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N<&AP.C<V"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HW.0IM<V=I9"`B56YA8FQE
M('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B3&%H=&EP86MK:6UI;F4@
M;G5R:G5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C(T(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,CDX"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y(&ES
M(&YO="!E;7!T>2XB"FUS9W-T<B`B7"(E<UPB(&5I('-A82!K=7-T=71A9&$L
M(&MA=&%L;V]G(&5I(&]L92!T_&AI+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M-S@@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM<V=S='(@(D5I
M('-A82!K=7-T=71A9&$@7"(E<UPB.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HS,S$@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS
M.3(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,Q,2!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S,T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(*;7-G<W1R
M("(E<R!E:2!S86$@:W5S='5T861A+"!K871A;&]O9R!E:2!O;&4@=/QH:2(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#@@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,U,@IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R(")6
M1E,@:V%T86QO;V=I<'5U(&MU<W1U=&%M:6YE(&YU<FIU<RXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S<@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C,R,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,S,U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T-`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")61E,@:V%T86QO;V=I
M(&MU<W1U=&%M:6YE(&YU<FIU<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C0Q-R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0R.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O
M<GDZ("5S+B(*;7-G<W1R(")%:2!S86$@:W5S='5T861A(%9&4R!K871A;&]O
M9VDZ("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C`W"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@
M7"(E<UPB+B(*;7-G<W1R(")%:2!S86$@:W5S='5T861A(%9&4R!F86EL:2!<
M(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S`S(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C@X"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HQ-C<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C$X,`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@W(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.#,*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,Y,0IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@9FEL92XB"FUS9W-T<B`B5D93(&9A:6QI(&MU<W1U=&%M:6YE(&YU
M<FIU<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(T-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@
M7"(E<UPB+B(*;7-G<W1R(")%:2!S86$@:W5S='5T861A(%9&4R!K875S=&$@
M7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#`V"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R
M<VEV96QY.B`E<RXB"FUS9W-T<B`B16D@<V%A(&MU<W1U=&%D82!61E-I(')E
M:W5R<VEI=G-E;'0Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z.#`S"FUS9VED(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER
M96-T;W)Y+B(*;7-G<W1R(")*;V]K<W9A="!K871A;&]O9VD@96D@]6YN97-T
M=2!T=79A<W1A9&$N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV,#,*;7-G:60@(E5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E
M(&1E=&%I;',B"FUS9W-T<B`B16D@<V%A(&OD='1E('-E<G1I9FEK86%D:2#\
M:W-I:V%S:G4B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z-#4Q
M(&9R86UE=V]R:R].971?24U34"])35-0+T%U=&@N<&AP.C$Q.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O
M9B`E<RXB"FUS9W-T<B`B)7,@9&5F:6YI='-I;V]N:2!L86%D:6UI;F4@;G5R
M:G5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$Y-B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$V-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,3<Q"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB"FUS
M9W-T<B`B5D93(&9A:6QI(/QM8F5R=/5S=&UI;F4@;G5R:G5S+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z.3,@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HQ,#(*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HV-#@@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HY.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(D5I('-A82!A=F%D82!61E,@9F%I;&D@7"(E<UPB+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(W-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ,S,*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET
M:6YG+B(*;7-G<W1R(")%:2!S86$@879A9&$@5D93(&9A:6QI(&UU=71M:7-E
M:W,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z.#`@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HW,@IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I
M;&4N(@IM<V=S='(@(E9&4R!F86EL:2!A=F%M:6YE(&YU<FIU<RXB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C0U"FUS9VED(")5
M;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@(E!A
M:VET=60@87)H:6EV:2!A=F%M:6YE(&YU<FIU<RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z.#,U"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL
M92`H9FEL97-I>F4H*2!F86EL960I+B(*;7-G<W1R(")%:2!S86$@;'5G961A
M(%9&4R!F86EL:2`H9FEL97-I>F4H*2!N=7)J=7,I+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HX-C8*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F
M:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(D5I('-A82!L
M=6=E9&$@5D93(&9A:6QI("AG971&:6QE4VEZ92@I(&YU<FIU<RDN(@H*(SH@
M9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+VYO;F4N
M<&AP.C,X"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`B
M16D@]6YN97-T=2!L=6=E9&$@9F%I;&DZ("(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C8V.0IM<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F
M<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R(")V9G-R;V]T(&MA=&%L;V]G:2!L
M=6=E;6EN92!N=7)J=7,N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HQ,3`U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*
M;7-G<W1R("(E<R!E:2!S86$@_&UB97(@;FEM971A9&$@)7,M:W,Z('-I:'1K
M875S="!O;B!J=6)A(&]L96UA<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,CDS"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D
M:7)E8W1O<GDN(@IM<V=S='(@(E9&4R!K871A;&]O9VD@_&UB97)N:6UE=&%M
M:6YE(&YU<FIU<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D
M:7)E8W1O<GDZ("5S+B(*;7-G<W1R(")%:2!S86$@_&UB97(@;FEM971A9&$@
M5D93(&MA=&%L;V]G:3H@)7,B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C(V-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,T,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B16D@<V%A(/QM8F5R(&YI;65T861A(%9&4R!F86EL:2!<
M(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C$P(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,CD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T
M<B`B16D@<W5U9&$@_&UB97(@;FEM971A9&$@5D93(&9A:6QI("5S+R5S+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(S(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HR,3,*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C0U,B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C@U
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,#$*;7-G:60@
M(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N(@IM<V=S='(@(E9&4R!F86EL
M:2#\;6)E<FYI;65T86UI;F4@;G5R:G5S+B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA
M8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@(D5I(/5N;F5S='4@:^1I
M=FET861A("=M:VES;V9S)RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E
M('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R(")3961A(%=O<F1I(&1O:W5M
M96YT:2!O;B!V]6EM871U('3U;&=E;F1A9&$B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C$T.2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$U
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R(")%:2!S86$@:VER:G5T861A(%9&4R!F86EL
M:2!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3<Y
M"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL
M960I+B(*;7-G<W1R(")%:2!S86$@:VER:G5T861A(%9&4R!F86EL:2`H8V]P
M>2@I(&YU<FIU<RDN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,C@Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S@*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$T,PIM<V=I9"`B56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@(E9&4R!F86EL:2!A
M;F1M971E('-A;'9E<W1A;6EN92!N=7)J=7,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C@T,0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(*;7-G<W1R(")%:2!S86$@:VER
M:G5T861A(%9&4R!F86EL:2P@:V5T=&%K=F]O="!LY&AE8B!L]6AK:2XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P"FUS
M9VED(")5;F1E<FQI;F4B"FUS9W-T<B`B06QL86IO;VYI='5D('1E:W-T(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N
M9V5S(@IM<V=S='(@(E1A87-T82!A;&=S96ES(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PIM<V=I9"`B56YD;V5S('EO
M=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B5O5T86(@=FEI;6%S92!T96=E=G5S
M92!T86=A<VDB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HR,C,*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,SDP"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R
M(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R(")/;W1A;6%T=2!V87-T=7,@<V5R
M=F5R:6QT(/QH96YD=7-E(&QO;VUI<V5L.B`B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0Q"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,W.`HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS.#0*;7-G:60@(E5N97AP96-T960@<F5S<&]N
M<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R(")/;W1A;6%T=2!V87-T=7,@
M<V5R=F5R:6QT.B`B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O
M<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHV,0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R(")+871E
M9V]O<FEA=&$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B
M56YI8V]D92`H551&+3@I(@IM<V=S='(@(E5N:6-O9&4@*%541BTX*2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4V"FUS9VED(")5;FET960@07)A8B!%;6ER871E<R(*;7-G<W1R
M(")!<F%A8FEA(-QH96YD96UI<F%A9&ED(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED
M(")5;FET960@2VEN9V1O;2(*;7-G<W1R(")3=75R8G)I=&%N;FEA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R(")!;65E
M<FEK82#<:&5N9')I:6=I9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E
M9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R(")!;65E
M<FEK82#<:&5N9')I:6MI9&4@=N1I:V5S86%R960B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-CD@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,0IM
M<V=I9"`B56YI=',B"FUS9W-T<B`BW&AI:W5D(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#(Y(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0S,`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R(")4=6YD;6%T=2(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I
M+B(*;7-G<W1R(")4=6YD;6%T=2!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A
M9V4@240I+B(*;7-G<W1R(")4=6YD;6%T=2!C;&EM<V=I9"`H0VQI96YT($UE
M<W-A9V4@240I+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-3D*;7-G:60@(E5N:VYO=VX@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@
M(DWDY')A=&D@='5N9&UA='4@87-U:V]H="XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*;7-G:60@(E5N:VYO
M=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S='(@(E1U;F1M871U(&MA
M<W5T86IA;FEM:2!J82!S86QA<_5N;F$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X"FUS9VED(")5;FQI
M;FL@=&AE(&-U<G)E;G0@96QE;65N="(*;7-G<W1R("+<:&5N9&$@<V5E(&5L
M96UE;G0@;&%H=&DN(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y
M+G!H<#HR.38*;7-G:60@(E5N;F%M960B"FUS9W-T<B`B3FEM971U(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I
M9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O
M0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E
M87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M
M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@
M<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"B+5
M:6=U<W1E=&$@<VMR:7!T:60@96D@<V%A('1U<G9A:V%A;'5T;'5S=&5L('!R
M;V=R86US96QT('-O;W)I=&%D82!L]6EK86UI<W0O(@HB:VQE97!I;6ES="X@
M2W5I(&ML]7!S860@3TLL(&[D960@;6]Z:6QL82YO<F<@=&5H;FEL:7-T('-E
M;&=I='5S="!K=6ED87,@(@HB;'5B861A('-K<FEP=&ED96P@;/5I:V5P=6AV
M<FET(&MA<W5T861A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM<V=S
M='(@(D5E;6%L9&$@=N1R=B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C@V(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M.3(V"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3,R"FUS
M9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`B5&]E=&%M871A
M(&QA:65N9'5S(@H*(SH@+2TM(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,3DW('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED
M(")5<&1A=&4B"FUS9W-T<B`B2VEN;FET82(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D
M871E("5S(@IM<V=S='(@(DUU=61A("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHW-@IM<V=I9"`B57!D871E('5S97(B"FUS9W-T
M<B`B375U9&$@:V%S=71A:F$B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$T-"!A
M9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC97,O<VAA<F5S+V5D:70N
M<&AP.C(S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB
M"FUS9W-T<B`B7"(E<UPB(&UU=61E='5D+B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C@S"FUS9VED(")5<&=R861E('-C<FEP="!D96QE=&5D+B(*
M;7-G<W1R(")5=65N9'5S92!S:W)I<'0@:W5S='5T871U9"XB"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3<X(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ.3D*;7-G:60@(E5P;&]A9"(*;7-G<W1R("),864@
M<V5R=F5R:7-S92(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#8*;7-G
M:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T
M:&4@<V5R=F5R+B(*;7-G<W1R(")+]6EK(')A:V5N9'5S92!P86EG86QD=7-F
M86EL:60@;VX@<V5R=F5R:7-S92!L865T=60N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B
M57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("),861I;F$@<W5U<G3D:&5D
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHQ.`IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R
M(")3=75R960@<F]O;6$@;G5M8G)I9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@
M(E5R=6=U87DB"FUS9W-T<B`B57)U9W5A:2(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L('!H<"UF;W)M870*
M;7-G:60@(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R(")+87-U=&$@<')A96=U
M<W0Z("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B2V%S=71A(%-3
M3&DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS9VED(")5<V4@
M:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R
M+B(*;7-G<W1R(")+87-U=&$@:G5H=6P@:W5I(&YI;6DO<V%L87/U;F$@24U3
M4"!S97)V97)I<R!O;B!E<FEN978N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]E9&ET+FEN8SHR,0IM<V=I9"`B57-E<B(*;7-G<W1R(")+87-U=&%J
M82(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S(S
M"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES
M960@9F]R("5S+B(*;7-G<W1R(")+87-U=&%J86P@)7,@96D@;VQE(&QU8F%T
M=60@)7,N(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S"FUS9VED(")5<V5R($%D
M;6EN:7-T<F%T:6]N(@IM<V=S='(@(DMA<W5T86IA:&%L9'5S(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR-3$*;7-G:60@(E5S97(@3W!T
M:6]N<R(*;7-G<W1R(")+87-U=&%J82!S96%D:7-T=7,B"@HC.B!S:6=N=7`N
M<&AP.C8R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R(")+87-U
M=&%J82!R96=I<W1R965R:6UI;F4B"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED
M(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI
M<R!S:71E+B(*;7-G<W1R(")396QL97,@<V%I9&ES(&MA<W5T86IA=&4@<F5G
M:7-T<F5E<FEM:7-T(&5I(';U:6UA;&1A=&$N(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C0V.0IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N9"(*
M;7-G<W1R(")+87-U=&%J86MO;G1O="!E:2!L96ET=60B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.CDX
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U
M,"!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,PHC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C<R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O
M=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G<W1R(")+87-U=&%J86YI
M;6DB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L
M('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A;')E861Y(&5X
M:7-T<RXB"FUS9W-T<B`B2V%S=71A:F%N:6UI(%PB)7-<(B!O;B!J=6)A(&]L
M96UA<RXB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*;7-G
M:60@(E5S97)N86UE.B(*;7-G<W1R(")+87-U=&%J86YI;6DZ(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z("(*
M;7-G<W1R(")+87-U=&%J86YI;6DZ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS
M9W-T<B`B2V%S=71A:F%D('/\<W1E96UI<SHB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS
M9VED(")5>F)E:VES=&%N(@IM<V=S='(@(E5S8F5K:7-T86XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-C,@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,C4U"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X
M:7-T+B(*;7-G<W1R(")61E,@:V%T86QO;V=I('!O;&4@;VQE;6%S+B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,3@*;7-G:60@(E9A8V%T:6]N
M(@IM<V=S='(@(E!U:&MU<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C@V-@IM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*
M;7-G<W1R(")/;&5M87-O;&5V860@:V]R<F5K='-E9"!A<W5K;VAA9"!O;CH@
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,S@*;7-G
M:60@(E9A;&ED:71Y(@IM<V=S='(@(DME:'1I=G5S(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.3<*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U"FUS9VED
M(")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R(")-:6YU=&ET
M92!A<G8@<')A96=U<V5S="!H971K97-T(&%L871E<RXB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HX-38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")686QU92!I<R!O=F5R('1H92!M
M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B5N3D<G1U<R#\;&5T86(@
M)7,@;6%K<VEM=6UP:6MK=7-E+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(R-#0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$V(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Y,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T
M+G!H<#HU.0IM<V=I9"`B5F%L=65S(@IM<V=S='(@(E;DY')T=7-E9"(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#D@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C$X-@IM<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM
M<V=S='(@(E;DY')T=7-E9"!M:6QL92!H=6QG87-T('9A;&ED82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3<*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B5F%N=6%T=2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#0*;7-G:60@(E9A<FEA
M8FQE(@IM<V=S='(@(DUU=71L:6LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")6
M96YE>G5E;&$B"FUS9W-T<B`B5F5N971S=65E;&$B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N
M(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D
M('=I=&@N(@IM<V=S='(@(DMO;G1R;VQL:6UI;F4@;G5R:G5S("T@<V5E(&MI
M<FD@=O5I8B!O;&QA('!A:&%T86AT;&EK=6QT(&UU=61E='5D+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED(")697)S
M:6]N(@IM<V=S='(@(DKD<FIE;G5M8F5R(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(R-@IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@
M(E9E<G-I;V]N:6AA;&1U<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L(&%L:6=N
M(@IM<V=S='(@(E9E<G1I:V%A;&YE(&IO;VYD=7,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T"FUS9VED(")697)T:6-A
M;"!P861D:6YG(@IM<V=S='(@(E9E<G1I:V%A;&YE('9O;V1E<F1U<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*;7-G
M:60@(E9E<G1I8V%L.B(*;7-G<W1R(")697)T:6MA86QN93HB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I9"`B5F5R
M>2!(:6=H(@IM<V=S='(@(E;D9V$@:_5R9V4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS
M9VED(")6:65T($YA;2(*;7-G<W1R(")6:65T;F%M(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.30*;7-G:60@(E9I971N86UE<V4@*%9)4T-)22DB"FUS
M9W-T<B`B5FEE=&YA;6D@*%9)4T-)22DB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HY-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE
M=R`E<R(*;7-G<W1R(")686%T82`E<R(*"B,Z(&QI8B]";&]C:R]I9G)A;64N
M<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B"FUS9W-T
M<B`B5F%A=&$@=N1L:7-T('9E96)I;&5H=&4B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HX,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5FEE=R!A<R`E<R(*;7-G<W1R(")686%T82!K=6D@)7,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R(")"
M<FET:2!.96ET<VES86%R960B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G
M:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R(")54T$@3F5I='-I<V%A<F5D(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#D*;7-G:60@(E9I<VEB:6QI='DB
M"FUS9W-T<B`B3N1H=&%V=7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C8S"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B3N1H=&%V
M=7,Z("(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY
M7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*
M;7-G<W1R(")6;V1A9F]N92!)=&%L>2#\;&4@4TU44"(*"B,Z(&9R86UE=V]R
M:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP
M:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T<B`B2$])05154R(*"B,Z(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!
M4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G
M<W1R(")(3TE!5%53(2$A($M54U155$$@4TM225!4($O$4TE44TD@2T%404Q/
M3T=)4U0@)7,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HQ,S,*;7-G:60@(E=)3B!V:6$@2%144"(*;7-G<W1R(")724X@_&QE
M($A45%`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")786QL:7,@86YD($9U='5N
M82(*;7-G<W1R(")786QL:7,@:F$@1G5T=6YA(@H*(SH@9G)A;65W;W)K+TYO
M=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR
M.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR-S(@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@S"FUS9VED(")787)N:6YG(@IM<V=S
M='(@(DAO:6%T=7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G<W1R(")+;R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E
M8V%S="(*;7-G<W1R("));&UA96YN=7-T=7,B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-#(W"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED
M960@8GDB"FUS9W-T<B`B26QM86%N9&UE:60@<&%K=6(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HX.3(*;7-G:60@(E=E871H97(N8V]M(@IM<V=S
M='(@(E=E871H97(N8V]M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*
M;7-G:60@(E=E8B(*;7-G<W1R(")6965B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0S-PIM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B5F5E8FES
M86ET(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H
M<#HU.`IM<V=I9"`B5V5E:VQY(@IM<V=S='(@(DMO<F0@;N1D86QA<R(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED(")796QC;VUE
M(@IM<V=S='(@(E1E<F4@='5L96UA<W0B"@HC.B!T96UP;&%T97,O;&]G:6XO
M;6]B:6QE+FEN8SHT('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-3<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R(")497)E
M('1U;&5M87-T("5S+6DB"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H
M<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B5&5R92!T=6QE;6%S="P@
M)7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-0IM<V=I9"`B5V5S=&5R
M;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B3.3D;F4@*$E33RTX.#4Y+3$I(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.38*;7-G:60@(E=E<W1E<FX@*$E3
M3RTX.#4Y+3$U*2(*;7-G<W1R("),Y.1N92`H25-/+3@X-3DM,34I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(DSDY&YE
M+5-A:&%R82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES
M<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B36EL;&ES92!R86ME;F1U<V4@
M<&5A:W,@)7,@<.1R87-T('-I<W-E;&]G:6UI<W0@879A;6$_(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,30*;7-G:60@(E=H870@:7,@=&AE
M(&1E;&EM:71E<B!C:&%R86-T97(_(@IM<V=S='(@(DUI;&QI<W0@;>1R:VD@
M:V%S=71A=&%K<V4@97)A;&1A:F%N83\B"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C
M=&5R/R(*;7-G<W1R(")-:6QL:7-T(&WD<FMI(&MA<W5T871A:W-E(&IU='5M
MY')G:6YA/R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,#8Q"FUS9VED(")7:&5R96ES($%U<W1R86QI82!M87`B"FUS9W-T
M<B`B5VAE<F5I<R!!=7-T<F%L:6$@:V%A<G0B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E<R(*;7-G<W1R(")-:6QL:7-E
M9"!F86%S:60B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S"FUS9VED
M(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E
M9&ET;W(N(@IM<V=S='(@(DUI;&QI<V5I9"!P;'5G:6YA:60@;'5B861A(%)I
M8V@@5&5X="!E9&ET;W)I<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED(")7:61T:"(*;7-G<W1R
M("),86EU<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C4*;7-G
M:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G<W1R("),86EU<R!#4U,@_&AI
M:W5T97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4W"B,L('!H<"UF
M;W)M870*;7-G:60@(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T
M("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R("(E<R!M
M96[\_"!L86EU<R!V87-A:W5L("AH86MK86(@;?5J=6UA(&KD<F=M:7-E;"!S
M:7-S96QO9VEM:7-E;"DZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*
M;7-G<W1R(")486)E;&D@;&%I=7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q,`IM<V=I9"`B5VED=&@@=6YI="(*;7-G
M<W1R("),86EU<_QH:6LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P-0IM<V=I9"`B5VED=&@Z(@IM<V=S='(@(DQA:75S
M.B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,3,*;7-G:60@(E=I
M:VDB"FUS9W-T<B`B5VEK:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS,#`@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C4*;7-G:60@(E=I;F0B"FUS9W-T<B`B5'5U;"(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V"FUS9VED(")7:6YD($5A<FQY
M(@IM<V=S='(@(DAO;6UI:W5L('1U=6PB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C@P"FUS9VED(")7:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@(E1U
M=6QE(&MI:7)U<R!S]6QM961E<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,34V"FUS9VED(")7:6YD.B(*;7-G<W1R(")4=75L.B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-#(*;7-G:60@(E=I;F0Z("(*;7-G<W1R
M(")4=75L.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@
M(E=I<V1O;2(*;7-G<W1R(")487)K=7,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3DV"FUS9VED(")7:7-H;&ES="(*;7-G<W1R(")3;V]V:6YI
M;65K:7)I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7
M;W)K(@IM<V=S='(@(E3V]B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$V-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@
M(E3V]FMO:&$@86%D<F5S<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`B
M5/;V=&5L969O;B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$V
M.2!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR-C(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%
M>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(E)E87,@)60@;VX@=F%L
M92!A<G8@=N1L:G4N(%!E86MS(&]L96UA("5D+"!A9V$@;VX@)60N(@H*(SH@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S`P"B,L('!H<"UF;W)M870*
M;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F
M;W5N9"`E9"XB"FUS9W-T<B`B5F%L92!A<G8@=N1L:G4N(%!E86MS(&]L96UA
M("5D+"!A9V$@;VX@)60N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,3$T"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W
M:&EL92!R96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@(E9A;&4@86QG=7-P
M=6YK="`E9"!61E,@9F%I;&D@;'5G96UI<V5L+B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR-#,*;7-G:60@(E@M4F5F(@IM<V=S='(@(E@M4F5F
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G
M:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R(")8-3`Y=C,@
M</5H:6QI<V5D('!I:7)A;F=U9"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3DR"FUS9VED(")8-3`Y=C,@17AT96YD960@2V5Y(%5S
M86=E(@IM<V=S='(@(E@U,#EV,R!V]71M92!L86EE;F1A='5D(&MA<W5T=7,B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I
M9"`B6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R(")8
M-3`Y=C,@<W5B:F5K=&D@86QT97)N871I:79N92!N:6UI(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3
M=6)J96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(E@U,#EV,R!S=6)J96MT
M:2!V]71M92!I9&5N=&EF:6MA871O<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-C@R"FUS9VED(")8-3`Y=C,@97AT96YS:6]N<R(*
M;7-G<W1R(")8-3`Y=C,@;&%I96YD=7-E9"(*"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C4P"FUS9VED(")962(*;7-G<W1R(")!02(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,3,*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-0IM<V=I9"`B65E962(*;7-G
M<W1R(")!04%!(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$Q,#@*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B66%H;V\A
M(&MA87)T(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E
M+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@(DMO<F0@86%S=&%S(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-PIM<V=I9"`B665M96XB"FUS9W-T<B`B2F5E;65N(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV,PIM
M<V=I9"`B665S(@IM<V=S='(@(DIA:"(*"B,Z('1E;7!L871E<R]M86EN=&5N
M86YC92]M86EN=&5N86YC92YH=&UL.C4V"FUS9VED(")997,L($D@06=R964B
M"FUS9W-T<B`B2F%H+"!O;&5N(&[U=7,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C4R"FUS9VED(")9;W4@87)E(&EN(%1%
M6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@
M=&\@5UE325=91RXB"FUS9W-T<B`B3VQE9"!414M35$E215I)24U)4RX@2VSU
M<'-A(%L\/ET@970@;6EN;F$@=&%G87-I(%=94TE764<@<F5Z:6EM:2XB"@HC
M.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N
M("5D(&)L;V-K<RXB"FUS9W-T<B`B16D@;VQE(&QU8F%T=60@;'5U82!R;VAK
M96T@:W5I("5D(&)L;VMK:2XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C$T,3$*;7-G:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM
M<V=S='(@(E-A(&5I(&]L92!S:7-S92!L;V=I='5D+B(*"B,Z(&9R86UE=V]R
M:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`R"FUS9VED(")9;W4@8V%N(&YO
M="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB
M"FUS9W-T<B`B4VEN=2!TY&ES;FEM:2!E:2!V]6D@<VES86QD861A("=<7"<@
M;>1R:VDN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U-2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<U"FUS9VED(")9;W4@9&ED(&YO="!E
M;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S='(@(E-A(&5I('-I
M<V5S=&%N=60@:V]R<F5K='-E="!E+7!O<W1I(&%A9')E<W-I+B(*"B,Z(&9R
M86UE=V]R:R]$871A+T1A=&$N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R
M=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S
M+B(*;7-G<W1R(")382!E:2!S96%D;G5D(&EM<&]R9&ET=60@9F%I;&D@=N1L
M:G4@=F%S=&%V=7-S92`E<R!VY&QJ861E9V$N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z.3@X"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O
M=70N(@IM<V=S='(@(E-I;F0@;&]G:71I(';D;&IA+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R-C$*;7-G:60@(B(*(EEO=2!H879E('1O(&5N
M=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET
M:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I
M86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"B)382!P96%D('-I<V5S=&%M82!K
M96AT:79A(&UO8FEI;'1E;&5F;VYI(&YU;6)R:2!M:7,@<VES86QD86(@86EN
M=6QT(&YU;6)R96ED("(*(FIA(&UI;&QE(&%L9W5S97,@=O5I8B!O;&QA("<K
M)R!R86AV=7-V86AE;&ES92!S=75N86MO;V1I('1U;FYU<V5N82XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@X"FUS9VED(")9;W4@:&%V92!T
M;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R(")382!P96%D('-I<V5S
M=&%M82!K;W)R96MT<V4@=N3D<G1U<V4N(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@
M82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R("),
M:6ET=6UI<V4@;'5B86UI<V5K<R!P96%D('-E861I<W1A;6$@1&%T851R964@
M<_QS=&5E;6DN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT-38*
M;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+B(*;7-G
M<W1R(")382!P96%D('-E861I<W1A;6$@5D93('/\<W1E96UI+B(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S
M="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H
M92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B16YN92!S86%T;6ES="!O;&5K
M<R!T87)K('!R;V)L965M:2!K:7)J96QD861A+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M=7-T
M(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*;7-G
M<W1R(")382!P96%D('-I<V5S=&%M82!54DQI(&MU:'4@<V5E(&QI;FL@=FEI
M=&%B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*;7-G:60@
M(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"XB"FUS
M9W-T<B`B4&5A9"!MY.1R86UA(&MU<W1U=&%T879A('-E<G9E<FDN(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3$Y"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@
M=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R(")096%D(&WDY')A;6$@
M:V%S=71A:F%N:6UE(&UI9&$@=/QH:F5N9&%D82XB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T
M;R!R96UO=F4N(@IM<V=S='(@(E!E860@;>3D<F%M82!K87-U=&%J86YI;64@
M;6ED82!E96UA;&1A9&$N(@H*(SH@861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS9VED(")9;W4@;75S="!S
M<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@(E!E860@;>3D
M<F%M82!K87-U=&%J86YI;64@;6ED82!L:7-A9&$N(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,30V"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M
M92!T;R!U<&1A=&4N(@IM<V=S='(@(E!E860@;>3D<F%M82!K87-U=&%J86YI
M;64@;6ED82!M=75T82XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O>FEP+G!H<#HQ,S@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A
M8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B4&5A9"!MY.1R86UA('1E9V5V
M=7-E+"!M:61A('-O;W9I9"!T96AA+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"FUS9VED(")9;W4@;75S="!T
M>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(E!E860@<VES97-T
M86UA('5U92!K871E9V]O<FEA(&YI;64N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N
M965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T
M<B`B4&5A9"!S:7-E<W1A;6$@271A86QI82!T96QE9F]N:6YU;6)R:2(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW-@IM<V=I9"`B66]U<B`E<R!S
M97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S
M='(@(E-I;G4@)7,@<V5S<VEO;VX@;VX@865G=6YU9"X@4&%L=6X@;&]G:2!U
M=65S=&D@<VES<V4N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z,S@*;7-G:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R(")3:6YU
M(&4M<&]S=&D@86%D<F5S<SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C$R"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@(E-I;G4@
M<V%A=&IA(&%A9')E<W,Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8T
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-"!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y"FUS9VED(")9;W5R
M($EN9F]R;6%T:6]N(@IM<V=S='(@(E-I;G4@:6YF;R(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.CDX,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9
M;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E
M9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U
M<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*
M(E-I;G4@:6YT97)N971I86%D<F5S<R!O;B`E<R!S97-S:6]O;FD@:F]O:W-U
M;"!M=75T=6YU9"X@5'5R=F%L:7-U<V4@(@HB=&%G86UI<V5K<R!P96%D('5U
M97-T:2!S:7-S92!L;V=I;6$N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z,S,*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R(")3:6YU(&YI
M;6DB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z-0IM<V=I
M9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U
M<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R
M9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@
M82!D:69F97)E;G0@(@HB875T:&5N=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T
M<B`B(@HB4VEN=2!A=71E;G1I;6ES<_QS=&5E;2!E:2!V]6EM86QD82!K87-U
M=&%J86ED(&QI<V%D82X@2W5I('-O;W9I9"!(;W)D92!A8FEL("(*(FMA<W5T
M86IA:60@:&%L;&%T82P@<&5A9"!K87-U=&%M82!T96ES='-U9W5S="!A=71E
M;G1I;6ES<_QS=&5E;6DN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L
M:7-T+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME
M;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A
M='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S
M;VXN(@IM<V=S='(@(B(*(E-I;G4@875T96YT:6UI<W/\<W1E96T@96D@=O5I
M;6%L9&$@:V%S=71A:F%T92!N:6UE:VER:F$@;N1H82P@=O5I(&]N('-E92`B
M"B)V]6EM86QU<R!M:6YG:6P@;75U;"!P]6AJ=7-E;"!VY&QJ82!L_&QI=&%T
M=60N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@T"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@
M8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO
M;BX@(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I
M;B!A9V%I;BXB"FUS9W-T<B`B(@HB4VEN=2!V965B:6QE:&ET<V5J82!NY&EB
M(&]L979A="`E<R!S97-S:6]O;FD@:F]O:W-U;"!M=75T=6YU9"X@5'5R=F%L
M:7-U<V4@(@HB=&%G86UI<V5K<R!P96%D('5U97-T:2!S:7-S92!L;V=I;6$N
M(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3`*;7-G:60@(EEO=7(@8G)O
M=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`B
M4VEN=2!V965B:6QE:&ET<V5J82!E:2!V]6EM86QD82!S961A(&]M861U<W0@
M:V%S=71A9&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z
M-#(*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H
M:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*
M(G1O('!R:6YT+B(*;7-G<W1R("(B"B)3:6YU('9E96)I;&5H:71S96IA(&5I
M(';U:6UA;&1A(&YI:6UO;V1I('1R_&MK:61A+B!686IU=&$@='+\:VMI;6ES
M96MS("(*(D-O;G1R;VPK4"!V]6D@0V]M;6%N9"M0+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR-3<*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO
M;F4Z(@IM<V=S='(@(E-I;G4@86IA=O;V;F0Z(@H*(SH@<V5R=FEC97,O<')E
M9G,N<&AP.CDV"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E
M96X@8VAA;F=E9"XB"FUS9W-T<B`B4VEN=2!V86EK96ED96YT:71E970@;VX@
M;75U9&5T=60N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U.`IM<V=I
M9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R(")3:6YU('9A:6ME
M:61E;G1I=&5E=#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`Q"FUS
M9VED(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`B4VEN=2!TY&EE;&EK(&YI
M;6DZ(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z,3`P,`IM<V=I9"`B
M66]U<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T<B`B4VEN=2!S:7-S96QO
M9VEM:6YE(&]N(&%E9W5N=60N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O
M<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R(")3:6YU('5U<R`E<R!S86QA<_5N
M82!O;CH@)7,B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U
M-`IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T
M:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R(")-=75D871U
M<V5D(&]N('-A;'9E<W1A='5D('-E;&QE('-E<W-I;V]N:2!L]7!U;FDN(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO
M=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS9W-T<B`B375U9&%T
M=7-E9"!O;B!S86QV97-T871U9"XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E
M="(*;7-G<W1R(")3:6YU('-A;&%S]6YA(&]N('9A:&5T871U9"(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A
M<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L
M;V<@:6X@=VET:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@HB
M4VEN=2!S86QA<_5N82!O;B!V86AE=&%T=60L('9A871A(&]M82!E+7!O<W1I
M(&IA(&QO9VD@<VES<V4@=75E('-A;&%S]6YA9V$N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z-S,R"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!E
M>'!I<F5D+B(*;7-G<W1R(")3:6YU('-A;&%S]6YA(&]N(&%E9W5N=60N(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9;W5R
M(')E;6]T92!S97)V97)S.B(*;7-G<W1R(")3:6YU(';D;&ES960@<V5R=F5R
M:60Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-30@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B675G;W-L879I82(*
M;7-G<W1R(")*=6=O<VQA879I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@(EIA:7(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS9W-T<B`B4V%M8FEA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T<B`B6FEM8F%B=V4B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G:60@(EII<'!Y(@IM
M<V=S='(@(EII<'!Y(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E
M<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O=&5D(%1E
M>'1=(@IM<V=S='(@(EM096ED82!O<W5N9&%T=60@=&5K<W1=(@H*(SH@<V5R
M=FEC97,O<')O8FQE;2YP:'`Z.#@*;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB
M"FUS9W-T<B`B6TAO<F1E('!R;V)L965M72(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(");4VAO=R!1=6]T960@
M5&5X="`M(@IM<V=S='(@(EM.Y&ET82!O<W5N9&%T=60@=&5K<W1I("TB"@HC
M.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E
M<RYP:'`Z,3<R"B,L('!H<"UF;W)M870*;7-G:60@(EM3:&]W(%%U;W1E9"!4
M97AT("T@)7,@;&EN97-=(@IM<V=S='(@(EM.Y&ET82!O<W5N9&%T=60@=&5K
M<W1I("T@)7,@<FED85TB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(");;&EN92`E<R!O9B`E<UTB"FUS
M9W-T<B`B6W)I9&$@)7,@)7,M<W1=(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ-30Q('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,3$*;7-G
M:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R(")?2&%L9'5S(@H*(SH@;&EB
M+V%P:2YP:'`Z,34W"FUS9VED(")?0TQ)(@IM<V=S='(@(DOD<W5?<FED82(*
M"B,Z(&QI8B]A<&DN<&AP.C$T,0IM<V=I9"`B7T1A=&%4<F5E(@IM<V=S='(@
M(E]$871A5')E92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T92!2;W<B"FUS9W-T
M<B`B7TMU<W1U=&$@<FED82(*"B,Z(&QI8B]A<&DN<&AP.C$S,PIM<V=I9"`B
M7T=R;W5P<R(*;7-G<W1R(")?1W)U<&ED(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+TUE;G4N<&AP.C$W-0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`B05]B
M:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T
M<B`B7U!I;&1I(&]M861U<V5D+BXN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+TUE;G4N<&AP.C$Y-`IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R(")?3&]G
M:2!S:7-S92(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ
M.3`*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(E],;V=I(';D;&IA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(T"FUS9VED(")?36]D:69Y($QI;FLN+BXB"FUS9W-T<B`B7TUU=61A(&QI
M;FMI+BXN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V
M-`IM<V=I9"`B7T]P=&EO;G,B"FUS9W-T<B`B7U-E861I<W1U<R(*"B,Z(&QI
M8B]A<&DN<&AP.C$S-PIM<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@(M5I
M9U]U<V5D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(V"FUS9VED(")?4F5M;W9E($QI;FLN+BXB"FUS9W-T
M<B`B7T5E;6%L9&$@;&EN:RXN+B(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I
M9"`B7U-E='5P(@IM<V=S='(@(E]086EG86QD=7,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@
M(E]486)L92!0<F]P97)T:65S+BXN(@IM<V=S='(@(E]486)E;&D@;VUA9'5S
M960N+BXB"@HC.B!L:6(O87!I+G!H<#HQ,CD*;7-G:60@(E]5<V5R<R(*;7-G
M<W1R(")?2V%S=71A:F%D(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,C$*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R(")A861R97-S:7)A
M86UA="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,T
M"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R(")A9')E<W-A870@
M='5N9&UA='4B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ,PIM
M<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B:V%L96YD97(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S='(@(G9A:6MN92(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN
M;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(G;D;&IU;F1F86EL:2!L
M;V]M:6YE(&YU<FIU<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R(")S
M:7-E;F1I(&%V86UI;F4@;G5R:G5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z-3DR"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@
M(FML]7!S82!S:6EA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G
M<W1R(")KY'-U<F5A(&MA<W5T86UI<V4@=FEG82(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,3<X"FUS9VED(")C;VYF:6=U<F%T:6]N
M(&5R<F]R(@IM<V=S='(@(G-E861I<W1U<V4@=FEG82(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED(")C<FET:6-A;"!S
M>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(F5L=73D:'1I<R!S_'-T965M
M:69A:6P@;VX@<'5U9'4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B
M86YD;65T92!F;W)M86%D:2!V:6=A(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]E
M9&ET+FEN8SHS,`IM<V=I9"`B961I="(*;7-G<W1R(")M=75D82(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3@R"FUS9VED(")E;G1R
M>2!N;W0@9F]U;F0B"FUS9W-T<B`B:V%N;F5T(&5I(&QE:71U9"(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")F
M86QL:6YG(@IM<V=S='(@(FQA;F=E8B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R
M+T)R;W=S97(N<&AP.C@U-0IM<V=I9"`B9FEL92(*;7-G<W1R(")F86EL(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S0@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS-C`@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R(")S=75N
M9"`E<R`H)7,I(&IA(&MI:7)U<R`E<R`E<R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-3`*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B<'5H
M86YG=6QI;F4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C0Y"FUS9VED(")H.B(*;7-G<W1R(")K.B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-3@*;7-G:60@(FAH(@IM
M<V=S='(@(G1T(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ,S@*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(G1U;F1M
M871U(&AO<W1I;FEM:2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E(@IM<V=S
M='(@(G9I:79I=&%M871U(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(FEN;&EN92(*;7-G<W1R
M(")I;FQI;F4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(G-I<V5N
M9"]VY&QJ=6YD('9I9V$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R;W(B"FUS
M9W-T<B`B=&%R:W9A<F$@<V5E<VUI;F4@=FEG82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(")L:6YE<UTB"FUS
M9W-T<B`B<FED85TB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI
M<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@
M(FUK:7-O9G,@=F5A:V]O9"`E9"!)4T\@;&]O;6ES96PN(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,V.0IM<V=I9"`B;6TB
M"FUS9W-T<B`B;6TB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C(Y,2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,S(*;7-G:60@(FYA;64B"FUS9W-T
M<B`B;FEM:2(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ,C$*;7-G:60@
M(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R(")P;VQE('1E;W-T871U9"(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(Q.0IM<V=I9"`B
M;F]T('EE="!I;7!L96UE;G1E9"(*;7-G<W1R(")P;VQE('9E96P@=&5O<W1A
M='5D(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#4*;7-G:60@
M(FYO=&5P860B"FUS9W-T<B`B;>1R:VUI:R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E
M;G0B"FUS9W-T<B`B<')O='-E;G1I(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-S0*;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM
M<V=S='(@(O5I9W5S960@<'5U9'5V860B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B
M"FUS9W-T<B`B<&EK<VQI="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,3<P"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB
M"FUS9W-T<B`B<')O=&]K;VQL:2!V:6=A('1E:7-E<R!O='-A<R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"FUS9VED(")R
M:7-I;F<B"FUS9W-T<B`B=/5U<V5B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-#(*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B
M"FUS9W-T<B`B=&5E;G5S('!O;&4@:^1T=&5S86%D878B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.CDY"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM
M<V=S='(@(F[D:71A(&5R:6YE=G5S:2(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@
M=FEA($A45%`B"FUS9W-T<B`B<VUS,F5M86EL(/QL92!(5%10(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-0IM<V=I9"`B
M<W,B"FUS9W-T<B`B<W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HW,@IM<V=I9"`B<W1E861Y(@IM<V=S='(@(OQH=&QA;F4B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P.0IM<V=I9"`B<W=I
M=&-H(&]F9B!J879A<V-R:7!T(@IM<V=S='(@(FS\;&ET82!J879A<V-R:7!T
M(';D;&IA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R(")S_'-T965M:2!V:6=A
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,CD*;7-G:60@(G1A
M<VL@;&ES="(*;7-G<W1R("+\;&5S86YN971E(&YI;65K:7)I(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O
M<F%R>2!F86EL=7)E(@IM<V=S='(@(F%J=71I;F4@=/5R9V4B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P-0IM<V=I9"`B=')Y(&%G86EN(@IM
M<V=S='(@(G!R;V]V:2!U=65S=&DB"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!F
M<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")T>7!E
M('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@(FMI<FIU
M=&$@<V%L87/U;F$@96MS:71U<V4@=N1L=&EM:7-E:W,@:V%K<R!K;W)D82(*
M"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N
M<&AP.C<Y"FUS9VED(")U;FEF:65D(@IM<V=S='(@(OQH:71A='5D(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]087)T+G!H<#HR-PIM<V=I9"`B=6YN86UE
M9"(*;7-G<W1R(")N:6UE='4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(G5S97(@<V5L96-T
M(@IM<V=S='(@(FMA<W5T86IA('9A;&EK(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R
M(")V0V%R9"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR-#$*;7-G:60@(G<Z(@IM<V=S='(@(FPZ(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E871H97(N8V]M(@IM<V=S
M='(@(G=E871H97(N8V]M(@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!O+U)%041-10``````````````````````
M````````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R,C<W,B`Q,#4Q
M-30S,S<T,B`P,3<P-#<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/3T]/3T]/3T]/3T]/3T]/3T]/0H@5')A;G-L871I;VX@
M1W5I9&4@"CT]/3T]/3T]/3T]/3T]/3T]/3T*"CI$871E.B`@("`@)$1A=&4Z
M(#(P,#8O,#<O,C8@,30Z,#8Z-3$@)`HZ4F5V:7-I;VXZ("12979I<VEO;CH@
M,2XR.2XT+C$@)`HZ075T:&]R<SH@($IA;B!38VAN96ED97(*.D-O;G1A8W0Z
M("!I,3AN0&QI<W1S+FAO<F1E+F]R9PH*+BX@8V]N=&5N=',Z.@HN+B!S96-T
M:6]N+6YU;6)E<FEN9SHZ"@I4<F%N<VQA=&EO;B!4;V]L"CT]/3T]/3T]/3T]
M/3T]/3T*"F!@=')A;G-L871I;VXN<&AP8&`@:7,@82!S;6%L;"!02%`@<V-R
M:7!T('1H870@<VAO=6QD(&AE;'`@=')A;G-L871O<G,@9&]I;F<*=&AE:7(@
M=V]R:RX*06YY(&9E961B86-K+"!B=6<@<F5P;W)T<R!A;F0@9F5A='5R92!R
M97%U97-T<R!S:&]U;&0@8F4@<V5N9"!T;R!T:&4@8&DQ.&X*;6%I;&EN9R!L
M:7-T8%\N(%1H:7,@:7,@86QS;R!T:&4@<FEG:'0@<&QA8V4@9F]R(&YE=R!T
M<F%N<VQA=&EO;G,@86YD(&=E;F5R86P*9&ES8W5S<VEO;G,@;V8@:3$X;B!A
M;F0@;#$P;B!Q=65S=&EO;G,@86YD('!R;V)L96US+@H*1F]R(&$@;&ES="!O
M9B!A=F%I;&%B;&4@8V]M;6%N9',@<G5N.CH*"B`@+B]T<F%N<VQA=&EO;BYP
M:'`@:&5L<`H*1F]R(&1E=&%I;&5D(&AE;'`@;VX@82!C97)T86EN(&-O;6UA
M;F0@<G5N.CH*"B`@+B]T<F%N<VQA=&EO;BYP:'`@:&5L<"!C;VUM86YD"@I!
M9&1I=&EO;F%L(&EN9F]R;6%T:6]N(&%B;W5T(&-R96%T:6YG('1R86YS;&%T
M:6]N<R!A;F0@9FEX:6YG('!R;V)L96US(&-A;B!B90IF;W5N9"!I;B!T:&4@
M9FEL92!@8&AO<F1E+V1O8W,O5%)!3E-,051)3TY@8"X*"BXN(%]I,3AN(&UA
M:6QI;F<@;&ES=#H@:'1T<#HO+VAO<F1E+F]R9R]M86EL+PH*4')E<F5Q=6ES
M:71E<PI^?GY^?GY^?GY^?GY^"@I4;R!R=6X@=&AI<R!S8W)I<'0@>6]U)VQL
M(&YE960@82!02%`@97AE8W5T86)L92!L:6ME('1H92!#3$D@;W(@=&AE($-'
M22!V97)S:6]N"G=I=&@@8&=E='1E>'0@<W5P<&]R=&!?(&-O;7!I;&5D(&EN
M(&%N9"!T:&4@8F%S:6,@8%!%05)@7R!L:6)R87)I97,N(%1H90IS8W)I<'0@
M97AP96-T<R!Y;W5R(%!(4"!E>&5C=71A8FQE('1O(&)E(&%T(&!@+W5S<B]L
M;V-A;"]P<V$O861M:6XO8FEN+W!H<&!@+B!)9B!Y;W5R"F5X96-U=&%B;&4@
M:7,@870@86YO=&AE<B!P;&%C92P@96ET:&5R(&5D:70@=&AE(&9I<G-T(&QI
M;F4@;V8*8&!T<F%N<VQA=&EO;BYP:'!@8"!T;R!R969L96-T('EO=7(@;&]C
M871I;VX@;W(@8V%L;"!T:&4@<V-R:7!T(&QI:V4Z.@H*("`O=7-R+VQO8V%L
M+W!S82]A9&UI;B]B:6XO<&AP("UF('1R86YS;&%T:6]N+G!H<"X*"EEO=2=L
M;"!N965D(&!G971T97AT8%\@,"XQ,2!O<B!G<F5A=&5R+"!B=70@=F5R<VEO
M;B`P+C$R(&]R(&=R96%T97(@:7,@<W1R;VYG;'D*<F5C;VUM96YD960@87,@
M=&AI<R!I<R!T:&4@9FER<W0@=F5R<VEO;B!T:&%T('-U<'!O<G1S(%!(4"!N
M871I=F5L>2X@3VQD97(*=F5R<VEO;G,@;6%Y(&YO="!E>'1R86-T(&%L;"!T
M<F%N<VQA=&5A8FQE('-T<FEN9W,@8V]R<F5C=&QY+@I!('=I;F1O=W,@=F5R
M<VEO;B!O9B!T:&4@9V5T=&5X="!B:6YA<FEE<R!C86X@8F4@9F]U;F0@;VX@
M979E<GD@8$=.52!F='`*;6ER<F]R8%\@87,@;V8@=F5R<VEO;B`P+C$R+@H*
M66]U)VQL(&YE960@=&AE(%!%05(@<&%C:V%G97,@8$-O;G-O;&5?1V5T;W!T
M8%\@,"XQ,2!O<B!G<F5A=&5R+`I@0V]N<V]L95]486)L96!?(&%N9"!@1FEL
M95]&:6YD8%\N(%1O(&EN<W1A;&P@86QL(&YE961E9"!P86-K86=E<RP@<G5N
M.CH*"B`@<&5A<B!U<&=R861E(%!%05(@0V]N<V]L95]'971O<'0*("!P96%R
M(&EN<W1A;&P@0V]N<V]L95]486)L92!&:6QE7T9I;F0*"F]R(&1O=VYL;V%D
M('1H92!N97=E<W0@<&%C:V%G92!F<F]M('1H92!@4$5!4F!?('-E<G9E<B!A
M;F0@:6YS=&%L;"!T:&5M"FUA;G5A;&QY(&EN('EO=7(@4$5!4B!D:7)E8W1O
M<GDN"@HN+B!?9V5T=&5X=#H@:'1T<#HO+W=W=RYG;G4N;W)G+W-O9G1W87)E
M+V=E='1E>'0O"BXN(%]G971T97AT('-U<'!O<G0Z(&AT='`Z+R]W=W<N<&AP
M+FYE="]G971T97AT+PHN+B!?1TY5(&9T<"!M:7)R;W(Z(&AT='`Z+R]W=W<N
M9VYU+F]R9R]P<F5P+V9T<"YH=&UL"BXN(%]014%2.B!H='1P.B\O<&5A<BYP
M:'`N;F5T+PHN+B!?0V]N<V]L95]'971O<'0Z(&AT='`Z+R]P96%R+G!H<"YN
M970O<&%C:V%G92]#;VYS;VQE7T=E=&]P="\*+BX@7T-O;G-O;&5?5&%B;&4Z
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]#;VYS;VQE7U1A8FQE+PHN
M+B!?1FEL95]&:6YD.B!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1FEL
M95]&:6YD+PH*0W)E871I;F<@82!N97<@=')A;G-L871I;VX*?GY^?GY^?GY^
M?GY^?GY^?GY^?GY^?GY^?GX*"E1O(&-R96%T92!A(&YE=R!T<F%N<VQA=&EO
M;B!Y;W4@9FER<W0@:&%V92!T;R!E>'1R86-T(&%L;"!G971T97AT(&UE<W-A
M9V5S(&9R;VT*=&AE(%!(4"!S;W5R8V5S+B!4:&5R92!A<F4@86QR96%D>2!T
M96UP;&%T92!F:6QE<R!W:71H('1H92!@8"YP;W1@8"!S=69F:7@@:6X*=&AE
M(&!@<&]@8"!D:7)E8W1O<FEE<R!T:&%T('EO=2!C86X@=7-E(&EF('EO=2!H
M879E('1R;W5B;&5S(&5X=')A8W1I;F<@=&AE"FUE<W-A9V5S(&)U="!T:&5Y
M(&UI9VAT(&)E(&]U=&1A=&5D+@I2=6XZ.@H*("`N+W1R86YS;&%T:6]N+G!H
M<"!E>'1R86-T"@I9;W4@;F]W(&AA=F4@=&\@8W)E871E(&$@;F5W(%!/(&9I
M;&4@9F]R('EO=7(@;&]C86QE+B!!(&QO8V%L92!H87,@=&AE(&9O<FT*8&!L
M;%]#0V!@('=H97)E(&!@;&Q@8"!I<R!T:&4@='=O(&QE='1E<B!@25-/(#8S
M.6!?(&-O9&4@;V8@=&AE(&QA;F=U86=E(&%N9`I@8$-#8&`@=&AE('1W;R!L
M971T97(@8$E33R`S,38V8%\@8V]D92!O9B!T:&4@8V]U;G1R>2P@92YG+B!@
M8&1E7T1%8&`L"F!@96Y?55-@8"!O<B!@8'!T7T)28&`N"F!@=')A;G-L871I
M;VXN<&AP8&`@:7,@86)L92!T;R!G=65S<R!T:&4@;&]C86QE(&9R;VT@=&AE
M(&!@3$%.1V!@(&5N=FER;VYM96YT"G9A<FEA8FQE(&)U="!I="!I<R!S869E
M<B!T;R!S<&5C:69Y('1H92!L;V-A;&4@=VET:"!T:&4@8&`M;&!@('!A<F%M
M971E<BX*5&\@8W)E871E('1H92!03R!F:6QE(')U;CHZ"@H@("XO=')A;G-L
M871I;VXN<&AP(&EN:70@+6P@;&Q?0T,*"DYO=R!Y;W4@8V%N('-T87)T('1H
M92!T<F%N<VQA=&EO;B!B>2!E9&ET:6YG('1H92!C<F5A=&5D(&!@;&Q?0T,N
M<&]@8`IF:6QE<RX@270@:7,@:6UP;W)T86YT('1O('-E="!T:&4@8V]R<F5C
M="!C:&%R<V5T(&9O<B!T:&4@;&]C86QE(&EN('1H90I@8$-O;G1E;G0M5'EP
M93I@8"!H96%D97(N"EEO=2!S:&]U;&0@9FEL;"!O=70@=&AE('1H92!C;VUP
M;&5T92!H96%D97(@;V8@=&AE(&-R96%T960@8&!L;%]#0RYP;V!@(&9I;&4L
M"F4N9RXZ.@H*("`C($1U=&-H('1R86YS;&%T:6]N(&9O<B!(;W)D92X*("`C
M($-O<'ER:6=H="`H0RD@,C`P-"!(;W)D92!0<F]J96-T"B`@(R!4:&ES(&9I
M;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC96YS92!A<R!T
M:&4@2&]R9&4@<&%C:V%G92X*("`C($IO<FES($)R86%K;6%N(#QJ8G)A86MM
M86Y`>6%H;V\N8V]M/BP@,C`P-"X*("`C"B`@;7-G:60@(B(*("!M<V=S='(@
M(B(*("`B4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`R+C-<;B(*("`B4F5P
M;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*("`B
M4$]4+4-R96%T:6]N+41A=&4Z(#(P,#0M,#0M,30@,3`Z,S`K,#(P,%QN(@H@
M(")03RU2979I<VEO;BU$871E.B`R,#`T+3`T+3$T(#$W.C$W*S`R.C`P7&XB
M"B`@(DQA<W0M5')A;G-L871O<CH@2F]R:7,@0G)A86MM86X@/&IB<F%A:VUA
M;D!Y86AO;RYC;VT^7&XB"B`@(DQA;F=U86=E+51E86TZ(&DQ.&Y`;&ES=',N
M:&]R9&4N;W)G7&XB"B`@(DU)344M5F5R<VEO;CH@,2XP7&XB"B`@(D-O;G1E
M;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ7&XB"B`@
M(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET7&XB"@I4;R!C;VUP
M:6QE('1H92!T<F%N<VQA=&EO;G,@=&\@82!B:6YA<GD@9F]R;6%T(')U;CHZ
M"@H@("XO=')A;G-L871I;VXN<&AP(&UA:V4*"D%F=&5R('EO=2!C<F5A=&5D
M('1H92!N97<@=')A;G-L871I;VX@>6]U(&AA=F4@=&\@861D(&5N=')I97,@
M9F]R('1H:7,@;&]C86QE"FEN('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@:&]R
M9&4O8V]N9FEG+VYL<RYP:'`N"@I43T1/.B!F:6QL:6YG(&YE=R!P;R!F:6QE
M<R!W:71H('-T<FEN9W,@9G)O;2!T:&4@8V]M<&5N9&EU;2X*"BXN(%])4T\@
M-C,Y.B!H='1P.B\O=W=W+FQO8RYG;W8O<W1A;F1A<F1S+VES;S8S.2TR+PHN
M+B!?25-/(#,Q-C8Z(&AT='`Z+R]W=W<N:7-O+F-H+VES;R]E;B]P<F]D<RUS
M97)V:6-E<R]I<V\S,38V;6$O:6YD97@N:'1M;`H*36%I;G1A:6YI;F<@=')A
M;G-L871I;VYS"GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?@H*5&AI<R!T;V]L
M(&ES(&1E<VEG;F5D('1O(&AE;'`@>6]U('1R86YS;&%T;W)S(&1O:6YG('EO
M=7(@9W)E870@=V]R:RX@270@8VAA;F=E<PIA(&QO="!C;VUP87)E9"!T;R!T
M:&4@;VQD(&UE=&AO9',@8W)E871I;F<@86YD(&UA:6YT86EN:6<@>6]U<B!T
M<F%N<VQA=&EO;G,N(%1O"FUA:V4@=&AE('1R86YS:71I;VX@=&\@=&AE('1O
M;VP@87,@<VUO;W1H(&%S('!O<W-I8FQE('EO=2!S:&]U;&0@<F5A9"!C:&%P
M=&5R"C,N,2!B969O<F4@=7-I;F<@=&AI<R!T;V]L('1H92!F:7)S="!T:6UE
M+@H*1FER<W0@=&EM92!U<V4@;V8@=')A;G-L871I;VXN<&AP"BTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H*5&AI<R!T;V]L(&EN=')O9'5C
M97,@82!N:6-E(&9E871U<F4@;V8@9V5T=&5X=#H@8V]M<&5N9&EU;2!F:6QE
M<RX@02!C;VUP96YD:75M"FES(&$@<W!E8VEA;"!03R!F:6QE(&-O;G1A:6YI
M;F<@82!S970@;V8@=')A;G-L871I;VYS(')E8W5R<FEN9R!I;B!M86YY"F1I
M9F9E<F5N="!P86-K86=E<RX@5&AE<V4@8V]M<&5N9&EA('=I;&P@8F4@=7-E
M9"!I;B!T:&4@8F%C:V=R;W5N9"!W:71H;W5T(&UU8V@*9F]R('EO=2!T;R!C
M87)E(&%B;W5T+B!"=70@>6]U(&AA=F4@=&\@8W)E871E(&%N9"!E9&ET(&$@
M8V]M<&5N9&EU;2!B969O<F4@>6]U"F-A;B!U<V4@:70N"@I4;R!C<F5A=&4@
M82!C;VUP96YD:75M(&]F(&%L;"!Y;W5R(&5X:7-T:6YG('1R86YS;&%T:6]N
M<R!R=6XZ.@H*("`N+W1R86YS;&%T:6]N+G!H<"!C;VUP96YD:75M("UL(&QL
M7T-#"@I4:&4@8&!C;VUP96YD:75M+G!O8&`@8F5I;F<@8W)E871E9"!W:6QL
M(&-O;G1A:6X@86QL(&UO9'5L97,G('1R86YS;&%T:6]N<R!O9@IT:&ES(&QO
M8V%L92!M97)G960@:6YT;R!A('-I;F=L92!F:6QE+B!9;W4@<VAO=6QD('1A
M:V4@82!C;&]S97(@;&]O:R!A="!T:&ES"F9I;&4@8F5C875S92!Y;W4@;6%Y
M(&9I;F0@82!L;W0@;V8@<W!E8VEA;"!M87)K960@;&EN97,@=VAE<F4@>6]U
M('1R86YS;&%T960*8V5R=&%I;B!S=')I;F=S(&1I9F9E<F5N=&QY(&EN('1H
M92!V87)I;W5S(&UO9'5L97,N($ET)W,@82!G;V]D(&ED96$@=&\@9FEX"G1H
M92!M;V1U;&5S)R!T<F%N<VQA=&EO;G,@;F]W('-O('1H870@86QL(&UO9'5L
M97,@=7-E('1H92!S86UE('1R86YS;&%T:6]N(&9O<@IT:&4@<V%M92!S=')I
M;F<N(%EO=2!C86X@86QW87ES(')E8W)E871E('EO=7(@8V]M<&5N9&EU;2!W
M:71H('1H92!A8F]V90IC;VUM86YD+@H*268@>6]U)W)E(&UA:6YT86EN:6YG
M('1R86YS;&%T:6]N<R!F;W(@9&EF9F5R96YT(&!B<F%N8VAE<V!?(&%N9"!A
M<W-U;65D('1H870*>6]U(&AA=F4@86QL(&UO9'5L97,@;V8@=&AE(&!@2$5!
M1&!@(&)R86YC:&5S(&EN(&]N92!D:7)E8W1O<GD@86YD(&%L;"!O9B!T:&4*
M8&!214Q%3D=?*F!@(&)R86YC:&5S(&EN(&%N;W1H97(L('EO=2!P<F]B86)L
M>2!W86YT('1O('-H87)E(&$@8V]M<&5N9&EU;0IB971W965N('1H97-E(&1I
M<F5C=&]R:65S+@H*66]U('-H;W5L9"!F:7)S="!C<F5A=&4@82!C;VUP96YD
M:75M(&EN('1H92!@8%)%3$5.1U\J8&`@8G)A;F-H+"!R979I97<@:70@86YD
M"F9I>"!A;&P@=')A;G-L871I;VYS('5N=&EL('EO=2=R92!H87!P>2!W:71H
M('1H92!R97-U;'0N(%1H96X@8W)E871E(&$@<V5C;VYD"F-O;7!E;F1I=6T@
M:6X@=&AE(&!@2$5!1&!@(&)R86YC:"!A;F0@:6YC;'5D92!Y;W5R(&9I<G-T
M(&]N92!W:71H('1H92`M+6%D9`IO<'1I;VXN"DYO=R!F:7@@=&AE('1R86YS
M;&%T:6]N<R!I;B!T:&ES(&)R86YC:"X@268@>6]U)W)E(')E861Y('EO=2!C
M86X@<F5M;W9E('1H90IF:7)S="!C;VUP96YD:75M(&%N9"!F;W(@;F]W(&]N
M('5S92!T:&4@8V]M<&5N9&EU;2!I;B!T:&4@8&!(14%$8&`@8G)A;F-H(&9O
M<@IB;W1H(&)R86YC:&5S+B!4;R!D;R!S;R!U<V4@=&AE(&!@+2UC;VUP96YD
M:75M8&`@;W!T:6]N('1O('-P96-I9GD@82!P871H('1O"GEO=7(@8V]M<&5N
M9&EU;2X*"BXN(%]B<F%N8VAE<SH@:'1T<#HO+W=W=RYH;W)D92YO<F<O<V]U
M<F-E+PH*57!D871I;F<@=')A;G-L871I;VYS"BTM+2TM+2TM+2TM+2TM+2TM
M+2TM+0H*5&AE('!R;V-E<W,@;V8@=7!D871I;F<@=')A;G-L871I;VYS(&ES
M(&$@8WEC;&4@=VAE<F4@>6]U(&5X=')A8W0@;F5W(&=E='1E>'0*<W1R:6YG
M<R!F<F]M('1H92!S;W5R8V5S+"!T<F%N<VQA=&4@=&AO<V4@;F5W('-T<FEN
M9W,@;W(@=7!D871E('1H92!A;')E861Y"G1R86YS;&%T960@<W1R:6YG<R!A
M;F0@8V]M<&EL92!T:&5M(&%F=&5R+@H*5&\@=7!D871E('1H92!T<F%N<VQA
M=&EO;B!F;W(@82!M;V1U;&4L(')U;CHZ"@H@("XO=')A;G-L871I;VXN<&AP
M('5P9&%T92`M;2!M;V1U;&5N86UE("UL(&QL7T-#"@I4:&ES(&5X=')A8W1S
M('1H92!N97<@<W1R:6YG<R!F<F]M('1H92!S;W5R8V5S(&%N9"!T<FEE<R!T
M;R!U<&1A=&4@=&AE;2!F<F]M"F%L<F5A9'D@97AI<W1I;F<@=')A;G-L871I
M;VYS(&EN('1H92!C;VUP96YD:75M+B!9;W4@:G5S="!H879E('1O('1R86YS
M;&%T90IA;&P@=6YS=')A;G-L871E9"!S=')I;F=S(&EN('1H92!@8&QL7T-#
M+G!O8&`@9FEL92!I;B!T:&4@8&!P;V!@(&1I<F5C=&]R>2!O9@IT:&4@;6]D
M=6QE('EO=2!U<&1A=&5D+@H*3VYC92!T:&ES(&ES(&1O;F4L('EO=2!C86X@
M8V]M<&EL92!T:&4@=')A;G-L871I;VX@8GD@8V%L;&EN9SHZ"@H@("XO=')A
M;G-L871I;VXN<&AP(&UA:V4@+6T@;6]D=6QE;F%M92`M;"!L;%]#0PH*17AT
M96YD:6YG(&5X:7-T96YT('1R86YS;&%T:6]N<PI^?GY^?GY^?GY^?GY^?GY^
M?GY^?GY^?GY^?GY^?GY^"@I4;R!H879E('EO=7(@;W=N('1E>'1S("AA<R!S
M=7!P;&EE9"!I;B!C;VYF:6<@9FEL97,@9F]R(&5X86UP;&4I(&1I<W!L87EE
M9"!I;@IS979E<F%L(&QA;F=U86=E<RP@>6]U(&AA=F4@=&\*"B`@,2X@<W!E
M8VEF>2!Y;W5R('1E>'1S(&%S(&=E='1E>'0@87)G=6UE;G1S+"!I;B!%;F=L
M:7-H+`H@(#(N(&5D:70@=&AE('1R86YS;&%T:6]N(&9I;&5S(&9O<B!T:&4@
M<F5Q=6ER960@;F%T:6]N86P@;&%N9W5A9V5S+`H@(#,N(&-O;7!I;&4@=&AO
M<V4@=')A;G-L871I;VX@9FEL97,N"@I"92!S=7)E('1O(&ME97`@<F5C;W)D
M<R!O9B!Y;W5R(&5X=&5N<VEO;G,L(&%S('EO=2!W:6QL('!R;V)A8FQY(&AA
M=F4@=&\*<F5P96%T('-T97!S(#(@86YD(#,@869T97(@=&AE(&YE>'0@=7!D
M871E+@H*12YG+BP@>6]U('!L86X@=&\@;V9F97(@='=O($E-05`@<V5R=F5R
M<R!T;R!S96QE8W0@9G)O;2!I;B!T:&4@5V5B;6%I;"!L;V=I;@IS8W)E96XZ
M"@H@(#$N($EN(&!@:&]R9&4O:6UP+V-O;F9I9R]S97)V97)S+G!H<&!@+"!Y
M;W4@<W!E8VEF>3HZ"@H@("`@("`@)'-E<G9E<G-;)T-E;G1R86PG72`](&%R
M<F%Y*`H@("`@("`@("`@)VYA;64G(#T^(%\H(D-E;G1R86P@36%I;"!397)V
M:6-E(BDL"B`@("`@("`N+BX*("`@("`@("1S97)V97)S6R=#;VUP4V-I)UT@
M/2!A<G)A>2@*("`@("`@("`@("=N86UE)R`]/B!?*")-86EL(%-E<G9I8V4@
M;V8@0V]M<'5T97(@4V-I96YC92!$<'0N(BD*("`@("`@("XN+@H*("`R+B!)
M;B!@8&AO<F1E+VEM<"]P;R]D95]$12YP;V!@('EO=2!A9&0@='=O(&5N=')I
M97,Z.@H*("`@("`@(&US9VED(")#96YT<F%L($UA:6P@4V5R=FEC92(*("`@
M("`@(&US9W-T<B`B6F5N=')A;&5R($UA:6QS97)V97(B"B`@("`@("!M<V=I
M9"`B36%I;"!397)V:6-E(&]F($-O;7!U=&5R(%-C:65N8V4@1'!T+B(*("`@
M("`@(&US9W-T<B`B36%I;'-E<G9E<B!);F9O<FUA=&EK(@H*("`@("!,:6ME
M=VES92P@>6]U(&%M96YD('1H92!T<F%N<VQA=&EO;B!F:6QE<R!F;W(@;W1H
M97(@;&%N9W5A9V5S+"!A<R!N965D960N"@H@(#,N(%EO=2!C;VUP:6QE('1H
M92!T<F%N<VQA=&EO;G,@=7-I;F<@=&AE(&-O;6UA;F1S.CH*"B`@("`@("`N
M+W!O+W1R86YS;&%T:6]N+G!H<"!M86ME("TM;6]D=6QE(&EM<"`M+6YO+6-O
M;7!E;F1I=6T*"D%C8V5S<R!+97ES"CT]/3T]/3T]/3T]"@I!8V-E<W,@:V5Y
M<RP@86QS;R!K;F]W;B!A<R!S:&]R=&-U="!K97ES+"!A;&QO=R!E87-Y(&%C
M8V5S<R!T;R!I;7!O<G1A;G0*9G5N8W1I;VYS+"!N;W)M86QL>2!B>2!H:71T
M:6YG('1H92!!;'0O365T82!K97D@:6X@8V]M8FEN871I;VX@=VET:"!A;F]T
M:&5R"FME>2X@5&AI<R!K97D@:7,@;6%R:V5D(&EN(&UO<W0@=7-E<B!I;G1E
M<F9A8V5S(&)Y(&)E:6YG('5N9&5R;&EN960N"@I!<R!T:&4@86-C97-S(&ME
M>2!I<R!P87)T(&]F('1H92!W;W)D(')E<')E<V5N=&EN9R!T:&4@86-T:6]N
M(&)E:6YG(&5X96-U=&5D+`II="!I<R!I;B!T:&4@=')A;G-L871O<G,@<F5S
M<&]N<VEB:6QI='D@=&\@<V5L96-T(&%N(&%C8V5S<R!K97D@=VAE;B!H90IT
M<F%N<VQA=&5S('1H97-E('=O<F1S+B!4:&4@86-T:6]N(&ES(&%L=V%Y<R!A
M(&QI;FL@:6X@2&]R9&4N(%1H92!A8V-E<W,@:V5Y"F]F(&$@;&EN:R!I<R!S
M96QE8W1E9"!B>2!P<F5F:7AI;F<@:70@=VET:"!A;B!U;F1E<G-C;W)E+@H*
M5&AE(&AE;'`@;&EN:R!I;B!T:&4@;65N=2!F;W(@97AA;7!L92!I<R!A;'=A
M>7,@(E](96QP(BX@5&AI<R!M96%N<R!T:&%T('1H90HB2"(@;V8@=&AE(&QI
M;FL@=VEL;"!B92!U;F1E<FQI;F5D(&%N9"!T:&4@:&5L<"!C86X@8F4@;W!E
M;F5D(&)Y(&AI='1I;F<*06QT*T@N($EN('1H92!03R!F:6QE('1H:7,@<W1R
M:6YG('=I;&P@87!P96%R(&%S.CH*"B`@(SH@=&5M<&QA=&5S+VUE;G4O;65N
M=2YI;F,Z-3,*("!M<V=I9"`B7TAE;'`B"B`@;7-G<W1R("(B"@I!(%-P86YI
M<V@@=')A;G-L871O<B!M:6=H="!W86YT('1O('1R86YS;&%T92!T:&ES('1O
M.CH*"B`@(SH@=&5M<&QA=&5S+VUE;G4O;65N=2YI;F,Z-3,*("!M<V=I9"`B
M7TAE;'`B"B`@;7-G<W1R(")?07EU9&$B"@I4<F%N<VQA=&]R<R!O9B!M=6QT
M:6)Y=&4@;&%N9W5A9V5S(&YE960@=&\@9&\@=&AI<R!A(&)I="!D:69F97)E
M;G1L>2!A<R!O;FQY"D%30TE)(&-H87)A8W1E<G,@87)E(&%L;&]W960@9F]R
M(&%C8V5S<R!K97ES+B!!(%1R861I=&EO;F%L($-H:6YE<V4@=')A;G-L871O
M<@IM:6=H="!W86YT('1O('5S93HZ"@H@(",Z('1E;7!L871E<R]M96YU+VUE
M;G4N:6YC.C4S"B`@;7-G:60@(E](96QP(@H@(&US9W-T<B`B7TCHJJKFF(XB
M"@I4:&ES(')E;F1E<G,@=&\@(NBJJN:8CBA(*2(@:6X@=&AE(&EN=&5R9F%C
M92!A;F0@>6]U(&-A;@IA8V-E<W,@=&AI<R!L:6YK('=I=&@@(D@B(&%S('1H
M92!A8V-E<W,@:V5Y+@H```````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M;R]R=5]252YP;P``````````````````````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`V-C4S,C0@,3`U,34T,S,W-#(@,#$W-3<Q`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````",@2&]R9&4@
M4G5S<VEA;B!T<F%N<VQA=&EO;BX*(R!#;W!Y<FEG:'0@*$,I"B,@26=N870@
M26MR>6%N;W8@/&EI9VYA=$!N97=M86EL+G)U/BP@,C`P,0HC($9E9&]R($$N
M($9E=&ES;W8@/&9A9D!S<V,N<G4^+"`R,#`R"B,@06QE>&5Y(%IA:VAA<F]V
M(#QB86)E<D!M;W-G82YN970^+"`R,#`V"B,*;7-G:60@(B(*;7-G<W1R("(B
M"B)0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E('8S+C$M4D,S7&XB"B)297!O
M<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4
M+4-R96%T:6]N+41A=&4Z(#(P,#8M,#(M,#<@,3$Z,3`K,#(P,%QN(@HB4$\M
M4F5V:7-I;VXM1&%T93H@,C`P-BTP,BTQ-R`Q-SHP,"LP,C`P7&XB"B),87-T
M+51R86YS;&%T;W(Z($%L97AE>2!:86MH87)O=B`\8F%B97)`;6]S9V$N;F5T
M/EQN(@HB3&%N9W5A9V4M5&5A;3H@4G5S<VEA;B`\:3$X;D!L:7-T<RYH;W)D
M92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E
M.B!T97AT+W!L86EN.R!C:&%R<V5T/4-0,3(U,5QN(@HB0V]N=&5N="U4<F%N
M<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+V-O;F9I<FU?=&]P+FEN8SHQ,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB("8C,34Q.R`E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M
M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N(@IM<V=S='(@
M(B(*(L_PZ.ONYN7MZ.4@)7,@X^[R[N+N(.H@[O'S^>7Q\N+KY>WH_B#N[^7P
MX/;HZ2#O[N3DY?#FZN@L(.[R[.7WY>WM^_4@[>CFY2XB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C,W,PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A
M>7,@86=O*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4N<&AP.C$S-S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S@Q"B,L('!H<"UF;W)M870*;7-G
M:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(S-S<*;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR,S<Y"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W-0IM<V=I9"`B("AY
M97-T97)D87DI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U,`HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDV"FUS9VED("(@870@
M(@IM<V=S='(@(B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HR,3D*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E8W1O<GDN
M(@IM<V=S='(@(LK@\N#K[N,B"@HC.B!L:6(O2&]R9&4O0TQ)+G!H<#HR-S(*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V
M86QI9"!C:&]I8V4N(@IM<V=S='(@(MWR[B#G[>#WY>WHY2#D[NOF[>X@X?OR
M_"#WZ/'K[NPN(@H*(SH@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HW,3`@;&EB
M+TAO<F1E+U)E9VES=')Y+G!H<#HQ,#DX"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E
M(%)E9VES=')Y+B(*;7-G<W1R("+/\.CK[N;E[>CE("<E<R<@[>4@\>KN[?3H
MX_/PZ/#NXN#M[B#B($AO<F1E(%)E9VES=')Y(@H*(SH@;&EB+TAO<F1E+U1R
M964N<&AP.C$W,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB
M('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R("+`Y/#E\>#R(//B
MY>3N[.OE[>C_("5S(.WE(.W@Z>3E[2XB"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C4V"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@
M=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS
M+V%D9&-H:6QD+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-30@861M:6XO<&5R;7,O861D8VAI
M;&0N<&AP.C4P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!C
M;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M
M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T
M+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O
M("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O
M;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(L_@
M[^K@(%PB)7-<(B#A^^O@(//Q[^7X[>X@[^7PY>CLY>WNXN#MX"#B(%PB)7-<
M(BY<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N-BD@(",M
M(RTC+2,M(UQN(@HB6_'R\.[JX"`E<R#HYR`E<UU<;B(*(B,M(RTC+2,M(R`@
M<G5?4E4N<&\@*$AO<F1E('8S+C`N-BD@(",M(RTC+2,M(UQN(@HB6_'R\.[J
MX"`E<R#HYR`E<UU<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S
M+C`N-BD@(",M(RTC+2,M(UQN(@HB6_'R\.[JX"`E<R#HYR`E<UU<;B(*(B,M
M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N-BD@(",M(RTC+2,M(UQN
M(@HB6_'R\.[JX"`E<R#HYR`E<UU<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@
M*$AO<F1E('8S+C`N-BD@(",M(RTC+2,M(UQN(@HB6_'R\.[JX"`E<R#HYR`E
M<UTB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D
M("@E+C)F)24I(@IM<V=S='(@(LCQ[^[K_.?NXN#M[CH@)2XR9LSA(.CG("4N
M,F;,X2`H)2XR9B4E*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,C8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N9"`E
M<R(*;7-G<W1R(");\?+P[NK@("5S(.CG("5S72(*"B,Z(&QI8B](;W)D92]!
M=71H+VQD87`N<&AP.C(V."!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-34W"B,L
M('!H<"UF;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R
M9"!E>'!I<F5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E
M8V%S="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M-C@@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VYO=&EC95]T;W`N:6YC.C0*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@
M(L?@[.7RZN@B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#0P(&QI8B](;W)D
M92]-24U%+T-O;G1E;G1S+G!H<#HX-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@2T(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C0Y('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M7W1O<"YI;F,Z-`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N86YC92!/<&5R871I;VYS
M("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(L[OY?#@]NC_(._NY.3E\.;JZ"`E
M<R`M(,_NY/+BY?#FY.7MZ.4B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M4VEG;G5P+G!H<#HR-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5
M<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+V%G<F5E;65N=%]T;W`N:6YC.C0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S
M='(@(B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HT,S(@;&EB+U9&4R]S;6(N<&AP
M.C0Y-"!L:6(O5D93+V9T<"YP:'`Z-C@R"B,Z(&QI8B]61E,O9G1P+G!H<#HW
M-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@=&\@<&5R
M9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W
M+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W
M86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("+.\NSE\OSR
MY2#TZ^#FZN#LZ"#N[^7PX/;H_BCHZ"DL(.KN\N[P^^4@POL@]>[RZ/+E(.[Q
M\_GE\?+BZ/+\+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S0T"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,C,*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`BP.3P
MY?'@\B#SXN7D[NSKY>WH_R`E<R#MY2#MX.GDY>TN(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B6_'R\.[JX"`E<R#HYR`E
M<UTB"@HC(&9U>GIY+"!P:'`M9F]R;6%T"B,Z(&QI8B](;W)D92]+;VQA8BYP
M:'`Z.3(Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E
M<W,@0F]O:R(*;7-G<W1R("+`Y/#E\>W@_R#J[>CCX"(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z.3$S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R=S($-A;&5N9&%R(@IM<V=S='(@(LK@Z^7MY.#P_"(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z.3`U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R=S($YO=&5P860B"FUS9W-T<B`BQ^#LY?+JZ"(*"B,Z(&QI8B](;W)D92]+
M;VQA8BYP:'`Z.3(Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI
M<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]M;V)I;&4N<&AP.CDV"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E
M<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:'1M;"YP
M:'`Z,3(Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A
M9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A
M<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V
M:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO
M;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,U-"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDY"B,L(&9U>GIY
M"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(EOQ\O#NZN`@)7,@Z.<@)7-=
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P-S,@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(Q,S(@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR.30*(SH@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HS-#@@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C<T-@HC+"!F=7IZ>0IM<V=I9"`B+2T@<V5L96-T("TM(@IM
M<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C
M+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@
M(RTC+2,M(RTC7&XB"B+$Y>GQ\N+HY3HB"@HC(&9U>GIY"B,Z(&QI8B]";&]C
M:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS9W-T<B`B
M,3(M]^#Q[N+NZ2(*"B,@9G5Z>GD*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y
M"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R("(R-"WWX/'NXN[I(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S
M(@IM<V=S='(@(C(T(/?@\>`B"@HC.B!L:6(O2&]R9&4O54DO4&%G97(N<&AP
M.C8Y"B,L(&9U>GIY"FUS9VED("(\4')E=FEO=7,B"FUS9W-T<B`BS_#EY/OD
M\_G@_R#Q\O#@[>CVX"(*"B,Z(&QI8B](;W)D92YP:'`Z,38R"B,L(&9U>GIY
M"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R("(\
M8C[/\.[HY^[XZ^`@ZO#H\NCWY?'JX/\@[OCHX>K@.CPO8CXB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B;&EC(%!'4"!K
M97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q-C@*;7-G:60@(D$@
M<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D
M(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C$P.3D*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@
M4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y
M<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HQ,#$V"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P
M<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU,#8*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-
M12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB
M02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,S8T
M"FUS9VED(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC
M<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.CD*(RP@9G5Z>GD*;7-G:60@(D%-($-L
M;W5D<R(*;7-G<W1R("+*[NSOX.WH_R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$P"B,L(&9U>GIY"FUS9VED(")!32!,:6=H
M="!286EN(@IM<V=S='(@(L+U[N0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ,0HC+"!F=7IZ>0IM<V=I9"`B04T@4F%I;B(*
M;7-G<W1R("+"[>CLX.WHY2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$R"B,L(&9U>GIY"FUS9VED(")!32!3:&]W97)S(@IM
M<V=S='(@(LCL[^[P\B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C$S"B,L(&9U>GIY"FUS9VED(")!32!3;F]W(%-H;W=E<G,B
M"FUS9W-T<B`BR.SO[O#R(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z
M,CD*;7-G:60@(D%-+U!-(@IM<V=S='(@(D%-+U!-(@H*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,PIM<V=I9"`B06)O=70N+BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW-`HC+"!F=7IZ>0IM<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@
M(L+LY?'RY2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S(*(RP@9G5Z>GD*;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R("))
M35`B"@HC.B!L:6(O5D93+VUU<W%L+G!H<#HR-S`*(RP@9G5Z>GD*;7-G:60@
M(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T
M<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC
M.B!L:6(O5D93+VUU<W%L+G!H<#HQ,S8*(RP@9G5Z>GD*;7-G:60@(D%C8V5S
M<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@(LWEXN[G[.[F
M[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C,*;7-G:60@(D%C8V]U;G0@26YF;W)M871I;VXB"FUS
M9W-T<B`BT_?E\NW@_R#GX._H\?PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-S@*(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS9W-T
M<B`BS^#P[NO\(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.3,*(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R
M("+3[_#@XNOE[>CE(/'WY?+@[.@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S,U"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@
M(L3P\^/HY2#_^>CJZ"(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q"FUS9VED(")!9&0B
M"FUS9W-T<B`BQ.[AX.+H\OPB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A
M9&UI;B]G<F]U<',N<&AP.C(R-0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z.3@@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HY.0HC+"!F=7IZ>0IM<V=I9"`B061D($-H:6QD
M(%!E<FUI<W-I;VXB"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H
M2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP
M;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(LOH]^W[Y2(*"B,@9G5Z>GD*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*;7-G:60@(D%D9"!(97)E
M.B(*;7-G<W1R("+$[N'@XNCR_#HB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(Q
M."!A9&UI;B]G<F]U<',N<&AP.C(Q.0IM<V=I9"`B061D($YE=R!'<F]U<"(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C@W(&QI8B](
M;W)D92]097)M<R]522YP:'`Z.#@*(RP@9G5Z>GD*;7-G:60@(D%D9"!.97<@
M4&5R;6ES<VEO;B(*;7-G<W1R("+-X/'R\.[IZN@@[^[K_.?NXN#RY>O_(@H*
M(R!F=7IZ>2P@<&AP+69O<FUA=`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V%D9&-H:6QD+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!
M9&0@82!C:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`BS>#Q\O#NZ>KH
M(@H*(R!F=7IZ>2P@<&AP+69O<FUA=`HC.B!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.C$T-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI
M;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`BS>#Q\O#NZ>KH(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-34T"B,L(&9U>GIY"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S='(@(B(*
M(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<
M;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A('8Q+C$I("`C+2,M(RTC
M+2-<;B(*(N3NX>#BZ/+\(/'R[NOAY?8B"@HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V5D:70N:6YC.C,T"B,L(&9U>GIY"FUS9VED(")!9&0@;F5W(&UE
M;6)E<G,B"FUS9W-T<B`BQ.[AX.+H\OP@[^#P\R(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(L3N
MX>#BZ/+\(._@\/,B"@HC('!H<"UF;W)M870*(R!F=7IZ>2P@<&AP+69O<FUA
M=`HC(&9U>GIY+"!P:'`M9F]R;6%T"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-S$*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED
M96)A<B(*;7-G<W1R("+$[N'@XNCR_"!-;WII;&QA(%-I9&5B87(B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C<Q"B,L(&9U>GIY"FUS
M9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R("+`Y/#E\>W@_R#J
M[>CCX"(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*
M(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T
M<B`BP.3PY?'MX/\@ZNWHX^`B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,0HC+"!F
M=7IZ>0IM<V=I9"`B061D('5S97(B"FUS9W-T<B`BQ.[AX.+H\OP@[^#P\R(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D
M9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S
M='(@(B(*"B,Z('-I9VYU<"YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M061D960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO
M=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N
M:6YC.C(*;7-G:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#4@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ-S,*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`BP.3P
MY?$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,30Q"FUS9VED(")!
M9&1R97-S($)O;VLB"FUS9W-T<B`BP.3PY?'MX/\@ZNWHX^`B"@HC(&9U>GIY
M+"!P:'`M9F]R;6%T"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.CDT"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I
M;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R("+-X/'R\.[IZN@@+2#S\?+@
M[>[BZN`@[_#@XB#DZ_\@Y/#SX^CU(._NZ_SG[N+@\N7KY>DB"@HC(&9U>GIY
M"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ.2!S97)V:6-E<R]P;W)T86PO<VED96)A
M<BYP:'`Z,3$S"FUS9VED(")!9&UI;FES=')A=&EO;B(*;7-G<W1R("+3[_#@
MXNOE[>CE(@H*(R`C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@
M(RTC+2,M(RTC"B,@9G5Z>GD*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,T,PHC+"!F=7IZ>0IM<V=I9"`B061S(@IM<V=S='(@(L3NX>#BZ/+\(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-@HC
M+"!F=7IZ>0IM<V=I9"`B069G:&%N:7-T86XB"FUS9W-T<B`BS>#Q\O#NZ>KH
M(._NZ_SG[N+@\N7K_R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-3<*(RP@9G5Z>GD*;7-G:60@(D%L8F%N:6$B"FUS9W-T
M<B`BS_'EXN3N[>CL(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<T(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW,`HC+"!F=7IZ>0IM<V=I9"`B06QG97)I82(*;7-G<W1R
M("+/\>7BY.[MZ.PB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T<B`BS_'EXN3N[>CL(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ
M-@HC+"!F=7IZ>0IM<V=I9"`B06QI9VXB"FUS9W-T<B`BS_'EXN3N[>CL(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PHC
M+"!F=7IZ>0IM<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R("+/\>7BY.[MZ.PB
M"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,C`W('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G:60@(D%L;"!!=71H96YT:6-A
M=&5D(%5S97)S(@IM<V=S='(@(L+QY2#B[OCEY/CHY2(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'
M<F]U<',B"FUS9W-T<B`BPO'E(./P\^_O^R(*"B,@9G5Z>GD*(SH@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HY,2!L:6(O2&]R9&4O4&5R;7,O9&%T871R964N
M<&AP.C<U"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`BPO'E(._P
MX.+@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHQ-PHC+"!F=7IZ>0IM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS
M9W-T<B`BQ^#LY?+JZ"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<U"FUS
M9VED(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S.`IM<V=I9"`B06QL;W<@<V5T=&EN
M9R!O9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`BT.#G\.7XZ/+\(.[O
MY?#@]NCH(/'N(/'OZ/'JX.SH(@H*(SH@;&EB+TAO<F1E+T1A=&%4<F5E+W-Q
M;"YP:'`Z-3`T"FUS9VED(")!;')E861Y(&5X:7-T<R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V"FUS9VED(")!;'1E<FYA=&4@
M24U34"!,;V=I;B(*;7-G<W1R("+`Z_SRY?#MX/+HXNW[Z2!)4TU0(@H*(R!F
M=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$Q"FUS9VED(")!;'1E
M<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R("+/X/#NZ_PZ(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4P,PIM<V=I9"`B06QT97)N871E($E-4U`@
M57-E<FYA;64B"FUS9W-T<B`BR.S_(._NZ_SG[N+@\N7K_R!)4TU0.B(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"B,L(&9U>GIY"FUS9VED
M(")!;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R("+"X/@@16UA:6PZ
M(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*;7-G:60@(D%L=&5R;F%T
M92!T96UP;&%T97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(U"B,L(&9U>GIY"FUS
M9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS9W-T<B`BPN#X($5M86EL.B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G
M:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]0
M<F5F<R]522YP:'`Z.34@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ,34*;7-G
M:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB"FUS9W-T<B`B
MP?OK[B#SZN#GX.WN(.WEZN[P\.7J\NWNY2#G[>#WY>WHY2XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34U"B,L(&9U>GIY"FUS9VED(")!
M;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+B(*;7-G<W1R("(\8C[/\.[H
MY^[XZ^`@ZO#H\NCWY?'JX/\@[OCHX>K@.CPO8CXB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O<G)A
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!
M;F=U:6QL82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B
M06YT:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z(&%D
M;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN<&AP.C,U(&QI
M8B](;W)D92]";&]C:R]522YP:'`Z-3@*(SH@=&5M<&QA=&5S+V%D;6EN+W-E
M='5P+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`B
MS_#HZ^[FY>WHY2(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@HC+"!F
M=7IZ>0IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*;7-G<W1R("+-X/'R\.[I
MZN@B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,30P"FUS9VED(")!<'!L
M:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`BS>#Q\O#NY>WN(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O($-H
M:6QD(%-H87)E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#0P"FUS9VED(")!<'!R
M;WAI;6%T92!3:7IE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#,@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8X"FUS9VED(")!<')I;"(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$W-`IM<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R
M-38I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N
M<&AP.C4Y(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8V"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<X"B,L(&9U>GIY"FUS9VED
M(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R("+([/\B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O<F%R+G!H<#HU."!L:6(O2&]R9&4O34E-12]6:65W
M97(O>FEP+G!H<#HV-0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H
M<#HW-PHC+"!F=7IZ>0IM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(LCL
M_R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z
M,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT
M('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@
M=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS
M9W-T<B`BPOL@\^+E\.7M^RP@]_+N(/7N\NCRY2#N]^CQ\NCR_"#]\O,@[^#O
MZO,_(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(V(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HU.`HC+"!F=7IZ>0IM<V=I9"`B07)G96YT:6YA(@IM<V=S='(@(L_QY>+D
M[NWH["(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-3<*(RP@9G5Z>GD*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`BS_'EXN3N
M[>CL(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S4*;7-G:60@(D%R;65N
M:6%N("A!4DU30TE)+3@I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HS,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%R=6)A(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C
M96YS:6]N($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I9FEC(%)E9VEO;B(*;7-G<W1R
M("(B"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,CD*;7-G
M:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N
M86YC92!O<&5R871I;VYS/R(*;7-G<W1R("+'X._PX/CHXN#R_"#O[N3RXN7P
MYN3E[>CE(._E\.7D(.+[[^[K[>7MZ.7L(.[OY?#@]NCI(.[A\>OSYNCBX.WH
M_S\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P,@HC+"!F=7IZ>0IM<V=I
M9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@
M<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M
M(R`@<G5?4E4N<&\@*%1U<F)A('8Q+C$I("`C+2,M(RTC+2-<;B(*(N3NX>#B
MZ/+\(/'R[NOAY?8B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<T"FUS9VED(")!
M='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B071T
M96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS
M9W-T<B`BS^[O^_+JX"#SY.#KZ/+\(.WE\?/YY?'RXO/^^>CE(._PX.+@(@H*
M(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*;7-G:60@(D%T=&5M<'0@=&\@
M961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("+/[N_[
M\NK@(/#EY.#J\NCP[N+@\OP@[>7Q\_GE\?+B\_[YZ.4@[_#@XN`B"@HC.B!S
M97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@
M961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S$*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#,*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-R!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,CD@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C4Y"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S
M=')I82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP
M.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M8WER=7,N<&AP.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S
M(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3(R"FUS9VED(")!=71H7V-Y
M<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*
M(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@
M0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O:6UA<"YP:'`Z-C0*;7-G
M:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HU
M,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N
M<&AP.C,P,@IM<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T
M('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS-3<*;7-G:60@(D%U=&A?;&1A
M<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E
M($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P
M+G!H<#HV,PIM<V=I9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H
M+VQD87`N<&AP.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z
M(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9#H@(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N
M<&AP.C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L
M92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L
M9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-#`U"FUS9VED(")!=71H7VQD87`Z
M(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$
M:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+VUC86PN
M<&AP.C0V"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M<VUB+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A
M=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92])34%0+T%D;6EN+G!H<#HQ,#8*(RP@9G5Z>GD*;7-G:60@(D%U=&AE
M;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`BS>7S
MY.#W[>[E(/'NY>3H[>7MZ.4@\2#QY?#BY?#N["!,1$%0+B(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"B,L(&9U>GIY"FUS9VED
M(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`BP.3PY?'@\B#SXN7D
M[NSKY>WH_R`E<R#MY2#MX.GDY>TN(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HV-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C<V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!=71H96YT:6-A
M=&EO;B!F86EL960N("5S(@IM<V=S='(@(L#D\.7QX/(@\^+EY.[LZ^7MZ/\@
M)7,@[>4@[>#IY.7M+B(*"B,Z(&QI8B](;W)D92]!=71H+W)A9&EU<RYP:'`Z
M,3<V"B,L(&9U>GIY"FUS9VED(")!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B
M>2!2041)55,@<V5R=F5R+B(*;7-G<W1R("+-Y?/DX/?M[N4@\>[EY.CMY>WH
MY2#Q(/'E\.+E\.[L($Q$05`N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@X,@HC
M+"!F=7IZ>0IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F
M86EL960N(@IM<V=S='(@(LWE\^3@]^WNY2#Q[N7DZ.WE[>CE(/$@\>7PXN7P
M[NP@3$1!4"XB"@HC.B!L:6(O5D93+W-M8BYP:'`Z-S`*(RP@9G5Z>GD*;7-G
M:60@(D%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"XB
M"FUS9W-T<B`BS>7SY.#W[>[E(/'NY>3H[>7MZ.4@\2#QY?#BY?#N["!,1$%0
M+B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G:60@(D%V
M86EL86)L92!F:65L9',Z(@IM<V=S='(@(L3N\?+S[^W[Y2#O[NO_.B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D*;7-G
M:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`HC+"!F=7IZ>0IM<V=I
M9"`B0F%C:V=R;W5N9"(*;7-G<W1R("+(\>_NZ_SG[N+@\OP@Y^W@]^7MZ.4@
M[^X@\^SNZ_?@[>C^(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR,PHC+"!F=7IZ>0IM<V=I9"`B0F%C:V=R;W5N9"!#;VQO
M<B(*;7-G<W1R("+(\>_NZ_SG[N+@\OP@Y^W@]^7MZ.4@[^X@\^SNZ_?@[>C^
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z.#$*;7-G:60@(D)A9"!K
M97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O:W)B-2YP:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M92XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0U(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV,@HC+"!F=7IZ>0IM<V=I9"`B0F%H86UA<R(*;7-G<W1R("+*
MX.OE[>3@\/PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8Q"B,L(&9U>GIY"FUS9VED(")"86AR86EN(@IM<V=S='(@(DE-
M4"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<V"FUS9VED(")"86QT:6,@
M*$E33RTX.#4Y+3$S*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(B(*"B,Z('5T:6PO
M:6-O;E]B<F]W<V5R+G!H<#HS,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB
M"FUS9W-T<B`BP.3PY?'@\B#SXN7D[NSKY>WH_R`E<R#MY2#MX.GDY>TN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHQ.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<S"B,L(&9U>GIY"FUS9VED(")"87-E;&EN92(*;7-G<W1R("(B"B(C+2,M
M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C
M+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HB
MT^3@Z^7M[?OE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0Y(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV,PIM<V=I9"`B0F5L87)U<R(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C,Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P"B,L(&9U>GIY
M"FUS9VED(")"96QG:75M(@IM<V=S='(@(M#@Y^SE\"(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HU,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*(RP@9G5Z>GD*;7-G
M:60@(D)E;&EZ92(*;7-G<W1R("+0X.?LY?`B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,S"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"B,L(&9U>GIY"FUS9VED(")"
M96YI;B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V
M,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@
M=C,N,2D@(",M(RTC+2,M(UQN(@HBT^3@Z^7M[?OE(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C0Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS
M-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D
M82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#8@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8S"B,L(&9U>GIY"FUS9VED(")":'5T86XB"FUS9W-T<B`B
M24U0(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3$*
M;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(L3E[?P@\.[FY.7MZ/\B"@HC.B!L
M:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S4T"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S7"(@;V8@87!P;&EC871I;VX@
M7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`BP.3PY?'@\B#SXN7D[NSKY>WH
M_R`E<R#MY2#MX.GDY>TN(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O<&]R=&%L
M+VQA>6]U="YI;F,Z.3`*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@
M(LW@\?+P[NGJX#HB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`BT.#Q^.CPY>WHY2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.`HC+"!F
M=7IZ>0IM<V=I9"`B0F]L9"(*;7-G<W1R(")(;W)D92(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HT,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV
M:6$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(P
M-PIM<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*(RP@9G5Z>GD*
M;7-G:60@(D)O<F1E<B(*;7-G<W1R(")(;W)D92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T
M:&EC:VYE<W,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*(RP@9G5Z>GD*;7-G:60@(D)O
M<F1E<G,B"FUS9W-T<B`B2&]R9&4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8P"FUS9VED(")";W-N:6$@86YD($AE<GIE
M9V]V:6YA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT
M."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O='-W86YA(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW-0HC+"!F=7IZ>0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(L+LY?'RY2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*
M;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C0T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT
M,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@HC+"!F=7IZ>0IM<V=I
M9"`B0G)A>FEL(@IM<V=S='(@(DE-4"(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")"<FET:7-H($EN9&EA
M;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C0R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT,@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A
M<G5S<V%L86TB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C,W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B0G5L9V%R:6$B
M"FUS9W-T<B`BS_'EXN3N[>CL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES="(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S8@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C,Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HT-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B
M0G5R=6YD:2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#0V"FUS9VED(")#35,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y.`IM<V=I9"`B0U),($1I
M<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(W"B,L(&9U>GIY
M"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(LKKY?+N]^W@
M_R#PX.3H[O'B_^?\(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$U,0HC+"!F=7IZ>0IM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L
M971E9"XB"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@
M=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0
M('8S+C$I("`C+2,M(RTC+2-<;B(*(LWNXN[E(/'N[N'YY>WHY2(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT.#,@8V]N9FEG+VAO
M;VMS+G!H<"YD:7-T.CDX-PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,34W"FUS9VED(")#86QE;F1A<B(*;7-G<W1R("+*X.OE[>3@\/PB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,U"B,L(&9U>GIY"FUS9VED
M(")#86QM(@IM<V=S='(@(L[R[.7MX"(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@S"B,L(&9U>GIY"FUS9VED(")#86UB
M;V1I82(*;7-G<W1R("+*X.OE[>3@\/PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")#86UE
M<F]O;B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V
M,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@
M=C,N,2D@(",M(RTC+2,M(UQN(@HBR^CW[?OE(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O
M<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z,S4P"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#86X@;F]T('=R:71E('1O(&9I;&4@7"(E
M<UPB(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7P
MXN7P[NPN(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(R"FUS9VED(")#86XG
M="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HR,S4@;&EB+TAO
M<F1E+T%U=&@O8WER<W%L+G!H<#HS,3D*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM<V=S
M='(@(LWE\^3@]^WNY2#Q[N7DZ.WE[>CE(/$@\>7PXN7P[NP@3$1!4"XB"@HC
M.B!L:6(O1FEL92]#4U8N<&AP.C0T-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BS>7B[N?L
M[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C0X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8T"B,L(&9U>GIY"FUS
M9VED(")#86YA9&$B"FUS9W-T<B`BRN#KY>WDX/#\(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E<R]A9&UI;B]U<V5R+V-L
M96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC
M.C$R"FUS9VED(")#86YC96PB"FUS9W-T<B`BSO+LY>W@(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B
M;&5M(%)E<&]R="(*;7-G<W1R("+.\NSE[>`@[O+WY?+@(.X@[_#NX>OE[.4B
M"@HC.B!L:6(O5D93+V9T<"YP:'`Z,S(S"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+-
MY>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI
M8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V
M"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y
M+G!H<#HU,@HC+"!F=7IZ>0IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A
M<GD@9&ER96-T;W)Y+B(*;7-G<W1R("+-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\
M($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O5D93+TE33U=R:71E<BYP
M:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I
M;&4G('!A<F%M971E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+U9&4R]F='`N<&AP
M.C,Q.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V
M92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("+-Y2#L[N/S(.[RZO#[\OP@
M[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O2&]R9&4O1&%T
M851R964N<&AP.C$R."!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HV.#`*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D
M(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R("+-Y2#L[N/S(.[RZO#[\OP@[.[D
M\^O\($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O2&]R9&4O1&%T851R
M964O<W%L+G!H<#HV,#@*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB
M97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M
M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B0V%N;F]T(')O
M=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8U(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HT.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM
M<V=I9"`B0V%P92!697)D92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T"B,L(&9U>GIY"FUS
M9VED(")#87!T:6]N(@IM<V=S='(@(LW@\?+P[NGJZ"(*"B,Z(&QI8B].970O
M4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`T"FUS9VED(")#87)R:65R(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,PIM<V=I9"`B0V%T
M96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@(LK@\N7C[O#HZ"#H(.SE\NKH
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#8*;7-G:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#96QL(%!H
M;VYE(@IM<V=S='(@(LKKY?+N]^W@_R#PX.3H[O'B_^?\(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0HC+"!F
M=7IZ>0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(LKKY?+N]^W@
M_R#PX.3H[O'B_^?\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV,0HC+"!F=7IZ>0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S
M='(@(LKKY?+N]^W@_R#PX.3H[O'B_^?\(@H*(R`C+2,M(RTC+2,@(')U7U)5
M+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(PHC(&9U>GIY"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"B,L(&9U>GIY"FUS
M9VED(")#96QL('-P86-I;F<Z(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?
M4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+1[O7PX.WH\OP@ZN#J
M7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4=7)B82!V,2XQ*2`@(RTC+2,M
M(RTC7&XB"B+1[O7PX.WH\OPB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(W
M.`HC+"!F=7IZ>0IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(LKKY?+N]^W@
M_R#PX.3H[O'B_^?\(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S<*;7-G
M:60@(D-E;'1I8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*(RP@
M9G5Z>GD*;7-G:60@(D-E;G1E<B(*;7-G<W1R("+1[N?DX/+\(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C4T(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HU,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B
M0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)
M4T\M.#@U.2TR*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C<P,`IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R
M("(B"@HC(&9U>GIY+"!P:'`M9F]R;6%T"B,@9G5Z>GD*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HV,3(*(RP@9G5Z>GD*;7-G:60@(D-E<G1I9FEC
M871E($]W;F5R(@IM<V=S='(@(LCQZN#R_"#B(,[RXN7R\?+BY>WM^_4B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B0V5R=&EF
M:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(R,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X"B,L(&9U>GIY"FUS9VED(")#
M:&%D(@IM<V=S='(@(G9#87)D(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC+"!F
M=7IZ>0IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(L[R[.7MZ/+\(.CG[.7MY>WH
M_R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,0HC+"!F=7IZ
M>0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`BS^#P[NO\
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Y"FUS9VED("(B"B)#:&%N
M9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@
M=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T
M<B`BS>#Q\O#NZ>KH(.CLY>WH+"#@Y/#E\>`L(._NY._H\>@N(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#:&%N9VEN
M9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R
M<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D;6EN:7-T
M<F%T;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*(RP@9G5Z>GD*;7-G:60@(D-H87(B
M"FUS9W-T<B`B=D-A<F0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*(RP@9G5Z>GD*;7-G:60@(D-H96-?
M:R!,:6YK+BXN(@IM<V=S='(@(M/DX.OH\OP@[^#P\R(*"B,Z('1E;7!L871E
M<R]M86EN=&5N86YC92]C;VYF:7)M7W1O<"YI;F,Z,3,*;7-G:60@(D-H96-K
M('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R
M9F]R;2!A="!T:&ES('1I;64N(@IM<V=S='(@(L[R[.7R_/+E(/3KX.;JX.SH
M(.[OY?#@]NC^*.CH*2P@ZN[R[O#[Y2#"^R#U[O+H\N4@[O'S^>7Q\N+H\OPN
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4Y(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HU,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M-PHC+"!F=7IZ>0IM<V=I9"`B0VAI;&4B"FUS9W-T<B`BQ^#C[NONXN[J(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8Q(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HU-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PHC
M+"!F=7IZ>0IM<V=I9"`B0VAI;F$B"FUS9W-T<B`B=D-A<F0B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D
M("A'0C(S,3(I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@P"FUS9VED(")#:&EN97-E(%1R861I=&EO;F%L("A":6<U*2(*;7-G<W1R
M("(B"@HC(&9U>GIY"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C<*;7-G
M:60@(D-H;V]S92!!<'!L:6-A=&EO;CHB"FUS9W-T<B`BPOOAY?#H\N4@[_#H
MZ^[FY>WHY3HB"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(W,`HC
M+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B(@HB
M(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<
M;B(*(L3EZ?'RXNCE.B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z
M,C8Y"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R
M("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M
M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC
M+2,M(UQN(@HBQ.7I\?+BZ.4Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,P,@IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G
M<W1R("+4[O#LX/(@[O+NX?#@YN7MZ/\@Y.#R^SHB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED
M(")#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8V(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R("(B
M"@HC.B!L:6(O5D93+G!H<#HY,30@;&EB+TYE="]335,N<&AP.C(Y-`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E
M<R!N;W0@9F]U;F0N(@IM<V=S='(@(L#D\.7QX/(@\^+EY.[LZ^7MZ/\@)7,@
M[>4@[>#IY.7M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$T"B,L(&9U>GIY"FUS9VED(")#;&5A<B(*;7-G<W1R("+*X.OE
M[>3@\/PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*(RP@9G5Z>GD*;7-G:60@(D-L
M96%R(%%U97)Y(@IM<V=S='(@(LK@Z^7MY.#P_"(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+V-L96%R+FEN8SHU"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`BT^3@Z^CR_"#OX/#S
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$Q"B,L(&9U
M>GIY"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(LK@Z^7MY.#P_"(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T"B,L(&9U>GIY"FUS
M9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`BRN#KY>WDX/#\(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,34*(RP@9G5Z
M>GD*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`BPO7NY"(*"B,Z('1E
M;7!L871E<R]M86EN=&5N86YC92]N;W1I8V5?8F]T=&]M+FEN8SHV"B,Z('1E
M;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C8P"B,L(&9U
M>GIY"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R("+-X/'R\.[I
MZN@B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM
M<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]K97EB;V%R9"YP:'`Z,30V('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3(*;7-G:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R("+'X.KP^_+\(.[J
M[>XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M-@HC+"!F=7IZ>0IM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(LKN[._@
M[>C_(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,3<*(RP@9G5Z>GD*;7-G:60@(D-L;W5D>2(*;7-G<W1R("+*[NSOX.WH_R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C0*
M;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(B(*"B,@
M9G5Z>GD*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR,PIM<V=I
M9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R("+3X?#@\OP@[.7M_B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C@*(RP@9G5Z>GD*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@
M(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC
M+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M
M(RTC7&XB"B+0X.?BY?#M\_+\(.+QY2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HV,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D-O;&]M
M8FEA(@IM<V=S='(@(LK@Z^7MY.#P_"(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP
M:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y"B,L(&9U>GIY"FUS
M9VED(")#;VQO<B(*;7-G<W1R("+*X.OE[>3@\/PB"@HC.B!L:6(O2&]R9&4O
M0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(U(&QI8B](;W)D92]";&]C:R]#;VQL
M96-T:6]N+G!H<#HS,C8*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C4P,2!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C$T
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0Y
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4P
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8U
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8V
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@R
M"B,L(&9U>GIY"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`BR.SO[O#R
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,S4*(RP@9G5Z>GD*;7-G:60@
M(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]2
M52YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R
M=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(L3EZ?'RXNCE.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`S
M"B,L(&9U>GIY"FUS9VED(")#;VQS.B(*;7-G<W1R("+*X.OE[>3@\/PB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DU,`IM<V=I9"`B0V]L=6UN('1I=&QE
M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8V
M"B,L(&9U>GIY"FUS9VED(")#;VUI8W,B"FUS9W-T<B`BRN#KY>WDX/#\(@H*
M(SH@861M:6XO8VUD<VAE;&PN<&AP.C(U"B,L(&9U>GIY"FUS9VED(")#;VUM
M86YD(@IM<V=S='(@(LKN[._@[>C_(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP
M.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C0Q,PHC+"!F=7IZ>0IM<V=I9"`B0V]M;65N
M="(*;7-G<W1R("+*[NSOX.WH_R(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU-C<*(RP@9G5Z>GD*;7-G:60@(D-O;6UO;B!.86UE
M(@IM<V=S='(@(L+@^.4@Z.S_.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@T"B,L(&9U>GIY"FUS9VED(")#;VUO<F]S
M(@IM<V=S='(@(LK@Z^7MY.#P_"(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@(LKN[._@
M[>C_(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-@HC+"!F
M=7IZ>0IM<V=I9"`B0V]N9&ET:6]N(@IM<V=S='(@(LW@\?+P[NGJZ"(*"B,Z
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N
M($1I9F9E<F5N8V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ-#8*;7-G:60@(D-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET
M:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RXB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0IM<V=I9"`B0V]N9FEG=7)A
M=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`BRN[M].CC\_#@]NC_(//Q
M\N#PY>O@(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,0HC+"!F=7IZ>0IM<V=I
M9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R("+/X/#NZ_PB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C4Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V"B,L(&9U>GIY
M"FUS9VED(")#;VYG;R(*;7-G<W1R("+*[NSS(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C4S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V]N9V\L(%1H
M92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*(RP@9G5Z>GD*;7-G:60@(D-O;FYE
M8W1I;VX@9F%I;&5D+B(*;7-G<W1R("+-Y?/DX/?M[N4@\>[EY.CMY>WHY2#Q
M(/'E\.+E\.[L($Q$05`N(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C$Y.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P
M"B,L(&9U>GIY"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@
M(LWE\^3@]^WNY2#Q[N7DZ.WE[>CE(/$@\>7PXN7P[NP@3$1!4"XB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW.3`*;7-G:60@(D-O;FYE8W1I;VX@
M<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-SDR"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(B(*"B,Z(&QI8B]61E,O
M9G1P+G!H<#HX-S8*(RP@9G5Z>GD*;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10
M('-E<G9E<B!F86EL960N(@IM<V=S='(@(LWE\^3@]^WNY2#Q[N7DZ.WE[>CE
M(/$@\>7PXN7P[NP@3$1!4"XB"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z
M,3`Q-`HC+"!F=7IZ>0IM<V=I9"`B0V]N=&%C=',B"FUS9W-T<B`BS^[JX.?@
M\OP@RN[M\N#J\OLB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C4S"FUS9VED(")#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E
M9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-C`*;7-G:60@(D-O;G1E;G0@='EP
M92!O9B!C;VUP<F5S<V5D(&9I;&4Z("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O<F%R+G!H<#HU-B!L:6(O2&]R9&4O34E-12]6:65W
M97(O>FEP+G!H<#HV,PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H
M<#HW-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@
M7"(E<UPB(@IM<V=S='(@(M'NY.7PYN#MZ.4@)7,B"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HR.2!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z,S,*(RP@9G5Z>GD*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@(LW@\?+P
M[NGJZ"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU."!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C$*
M(RP@9G5Z>GD*;7-G:60@(D-O<'DB"FUS9W-T<B`BRN[L[^#MZ/\B"@HC.B!L
M:6(O5D93+W-M8BYP:'`Z-#<R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!C;VUP
M96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M
M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC
M+2-<;B(*(L[XZ.'JX"#O\.@@\^3@Z^7MZ.A<;B(*(B,M(RTC+2,M(R`@<G5?
M4E4N<&\@*$YA9R!(,R`H,BXP+C,I*2`@(RTC+2,M(RTC7&XB"B+-Y?/DX/?M
M[N4@\>[EY.CMY>WHY2#Q(/'E\.+E\.[L($Q$05`N7&XB"B(C+2,M(RTC+2,@
M(')U7U)5+G!O("A.86<@2#,@*#(N,"XS*2D@(",M(RTC+2,M(UQN(@HBS>7S
MY.#W[>[E(/'NY>3H[>7MZ.4@\2#QY?#BY?#N["!,1$%0+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*(RP@9G5Z>GD*
M;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@
M<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M
M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+$Y>GQ\N+H
MY3HB"@HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3<P(&QI8B].970O
M4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8S(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HV,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8S
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;W1E(&0G
M279O:7)E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.CDW-PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE
M<W-A9V4Z("(*;7-G<W1R("+-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT
M96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ
M,#4U"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G
M93H@(@IM<V=S='(@(LWE(.SNX_,@[O+J\/OR_"#L[N3SZ_P@36%I;G1E;F%N
M8V5?5&%S:R`E<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,SDS
M"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S
M<V%G92XB"FUS9W-T<B`BS>4@[.[C\R#N\NKP^_+\(.SNY//K_"!-86EN=&5N
M86YC95]487-K("5S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HT
M-C<*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S
M86=E+B(*;7-G<W1R("+-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA
M;F-E7U1A<VL@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,3@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M861D(&-O;G1A8W0N("5S(@IM<V=S='(@(LWE(.SNX_,@[O+J\/OR_"#L[N3S
MZ_P@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B](;W)D92]'<F]U<"]L
M9&%P+G!H<#HY-B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ,C$*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C0U-PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@
M;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(LWE\^3@]^WNY2#Q
M[N7DZ.WE[>CE(/$@\>7PXN7P[NP@3$1!4"XB"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,34V(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,3<S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`BS>4@[.[C\R#N\NKP
M^_+\(.SNY//K_"!-86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C0T,0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&-O
M;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(LWE\^3@]^WNY2#Q[N7D
MZ.WE[>CE(/$@\>7PXN7P[NP@3$1!4"XB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z-#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G
M<W1R("+-Y?/DX/?M[N4@\>[EY.CMY>WHY2#Q(/'E\.+E\.[L($Q$05`N(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B2&]R9&4@[>4@[_#@XNCK_.WN(.W@
M\?+P[N7M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$R.`HC+"!F
M=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z("(*;7-G
M<W1R("+-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@
M)7,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4R,PHC+"!F=7IZ
M>0IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S
M='(@(LWE(.SNX_,@[O+J\/OR_"#L[N3SZ_P@36%I;G1E;F%N8V5?5&%S:R`E
M<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@8V]N
M=&%C="X@)7,B"FUS9W-T<B`B2&]R9&4@[>4@[_#@XNCK_.WN(.W@\?+P[N7M
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B2&]R9&4@[>4@[_#@XNCK_.WN
M(.W@\?+P[N7M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R(")(;W)D92#MY2#O
M\.#BZ.O\[>X@[>#Q\O#NY>TB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C,X,2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY-3,*(RP@9G5Z>GD*
M;7-G:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M
M;6%I;"!A9&1R97-S+B(*;7-G<W1R("+"X/@@16UA:6PZ(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PHC+"!F=7IZ>0IM<V=I9"`B
M0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T
M<B`BP.3PY?'MX/\@ZNWHX^`B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-#DS"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@
M8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(LWE(.SNX_,@
M[O+J\/OR_"#L[N3SZ_P@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*(RP@9G5Z>GD*;7-G:60@
M(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB
M=71I;VX@;&ES=',N(@IM<V=S='(@(LWE(.SNX_,@[O+J\/OR_"#L[N3SZ_P@
M36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E
M86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@;&EB+U9&4R])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM<V=S
M='(@(LWE(.SNX_,@[O+J\/OR_"#L[N3SZ_P@36%I;G1E;F%N8V5?5&%S:R`E
M<R(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C$Q,`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R
M871E9WDO9&ER96-T+G!H<#HS,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`BS>4@[.[C\R#N
M\NKP^_+\(.SNY//K_"!-86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z-S$Y"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N
M;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G
M<W1R("+-Y?/DX/?M[N4@\>[EY.CMY>WHY2#Q(/'E\.+E\.[L($Q$05`N(@H*
M(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z,3,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S='(@(LWE(.SNX_,@[O+J
M\/OR_"#L[N3SZ_P@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS-#4*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP
M.C(V,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P
M96X@)7,N(@IM<V=S='(@(LWE(.SNX_,@[O+J\/OR_"#L[N3SZ_P@36%I;G1E
M;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z
M-#(P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N($UA:6YT
M96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(LWE(.SNX_,@[O+J\/OR
M_"#L[N3SZ_P@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B]61E,O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@
M7"(E<UPB+B(*;7-G<W1R("+-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT
M96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z
M,3$Q(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@;&EB+TAO<F1E
M+T=R;W5P+VQD87`N<&AP.C(S-R!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z
M-#<X"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HU,38@;&EB+TAO<F1E
M+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP
M:'`Z-C4V(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV.3D*(RP@9G5Z>GD*
M;7-G:60@(D-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S
M='(@(LWE\^3@]^WNY2#Q[N7DZ.WE[>CE(/$@\>7PXN7P[NP@3$1!4"XB"@HC
M.B!L:6(O5D93+T]B:F5C="YP:'`Z,C0P"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T<B`BS>4@[.[C\R#N
M\NKP^_+\(.SNY//K_"!-86EN=&5N86YC95]487-K("5S(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD(&YO="!R
M97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M
M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4
M<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U
M(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS-#`*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,W-R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@S
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#D*(RP@9G5Z
M>GD*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`BS>4@
M[.[C\R#N\NKP^_+\(.SNY//K_"!-86EN=&5N86YC95]487-K("5S(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@
M8F]O:RX@)7,B"FUS9W-T<B`BP.3PY?'MX/\@ZNWHX^`B"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI
M<W0N("5S(@IM<V=S='(@(DAO<F1E(.WE(._PX.+HZ_SM[B#MX/'R\.[E[2(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T
M<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@(DAO<F1E(.WE(._PX.+HZ_SM
M[B#MX/'R\.[E[2(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HQ.3D@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"B,L(&9U>GIY"FUS
M9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S
M(@IM<V=S='(@(DAO<F1E(.WE(._PX.+HZ_SM[B#MX/'R\.[E[2(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(D-O=6QD
M(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B2&]R9&4@[>4@
M[_#@XNCK_.WN(.W@\?+P[N7M(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S='(@(LWE
M(.SNX_,@[O+J\/OR_"#L[N3SZ_P@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,R!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@
M8V]N9FEG=6%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@
M82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@
M8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C<W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O
M=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C
M86X@96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T
M:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@
M8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+VQD
M87`N<&AP.C$T,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T
M:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(LWE\^3@]^WNY2#Q[N7DZ.WE[>CE
M(/$@\>7PXN7P[NP@3$1!4"XB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(LWE
M(.SNX_,@[O+J\/OR_"#L[N3SZ_P@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@
M)7,B"FUS9W-T<B`BS>4@[.[C\R#N\NKP^_+\(.SNY//K_"!-86EN=&5N86YC
M95]487-K("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C,Y-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P
M9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`BS>4@[.[C\R#N
M\NKP^_+\(.SNY//K_"!-86EN=&5N86YC95]487-K("5S(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E
M<R(*;7-G<W1R(")(;W)D92#MY2#O\.#BZ.O\[>X@[>#Q\O#NY>TB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<P"FUS9VED(")#;W5L9&XG="!F:6YD
M('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I
M<R!O<&5N+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,34T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T
M(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H
M92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,30R,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;G1E9"!T97AT(@IM
M<V=S='(@(L+[]>[D(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M-S`*(RP@9G5Z>GD*;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`B(@HB(RTC+2,M
M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC
M+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(LWN
MXN[E(/'N[N'YY>WHY2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M-S4*(RP@9G5Z>GD*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`BT_'OY?CM[B(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C$P,`IM<V=I9"`B0W)E871E(@IM<V=S='(@(M'NY^3@\OPB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C@*(RP@9G5Z>GD*;7-G:60@(D-R96%T92!A(&QI;FLB"FUS9W-T<B`B
MT>[GY.#R_"(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y
M<V5L96-T+FEN8SHY-`IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R
M("+1[N?DX/+\(.WNXOOI(._P[O3HZ_PB"@HC.B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@(D-R96%T92!S=6(@9F]L9&5R<R(*
M;7-G<W1R("(B"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z
M,C0P"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(M'NY^3@
M\N7K_"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C$Y"B,L(&9U>GIY"FUS
M9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`BR.S_(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$P.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD*(RP@9G5Z
M>GD*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`BT>[GY.#R_"(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HV-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-U
M8F$B"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,C8*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B
MTN7J\_G@_R(*"B,@9G5Z>GD*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4P"B,L
M(&9U>GIY"FUS9VED(")#=7)R96YT(%-E<W-I;VYS(@IM<V=S='(@(M'NY^3@
M\N7K_"(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE
M+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(M+EZO/YY>4@
MXO#E[/\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-30*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@55),(&ES
M(@IM<V=S='(@(M+EZO/YY>4@XO#E[/\B"@HC(&9U>GIY"B,Z(&%D;6EN+W-E
M<W-I;VYS+G!H<#HS-0HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!5<V5R<R(*
M;7-G<W1R("+2Y>KS^>#_(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(V-`HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*
M;7-G<W1R("+-X/'R\.[IZN@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,R"B,L(&9U>GIY"FUS9VED(")#=7)R96YT('-T
M>6QE(@IM<V=S='(@(M+EZO/YY>4@XO#E[/\B"@HC('!H<"UF;W)M870*(R!F
M=7IZ>2P@<&AP+69O<FUA=`HC(&9U>GIY+"!P:'`M9F]R;6%T"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S
M=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R
M("+'X.3@]^@L(.?@[_/QZN#E[/OE(._PZ"#B]>[DY2#B("5S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P
M"B,L(&9U>GIY"FUS9VED(")#=70B"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R
M=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC
M("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(LWNXN[E(/'N
M[N'YY>WHY2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S4*(RP@9G5Z>GD*;7-G:60@(D-U="!S96QE8W1I;VXB"FUS9W-T
M<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC
M+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M
M(RTC+2-<;B(*(L3EZ?'RXNCE.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HV-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-Y<')U<R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0WER:6QL:6,@
M*$M/23@M4BDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#(*;7-G:60@(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#>7)I;&QI8R]5
M:W)A:6YI86X@*$M/23@M52DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C8X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV-PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WIE8V@@4F5P
M=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0U,"!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B
M1$0B"FUS9W-T<B`BQ,0B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(W.0IM
M<V=I9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO
M96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$
M86EL>2(*;7-G<W1R("+%YN7D[>7B[>XB"@HC.B!A9&UI;B]D871A=')E92YP
M:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C,R-S<*;7-G:60@(D1A=&%B87-E($QO;VMU
M<"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0P,B!L:6(O
M2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,@IM<V=I9"`B1&%T92(*
M;7-G<W1R("+$X/+@(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V
M92YI;F,Z,3,*;7-G:60@(D1A=&4@4F5C96EV960B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(W.38*(RP@9G5Z>GD*;7-G:60@(D1A=&4@
M<V5L96-T:6]N(@IM<V=S='(@(L_NZ^WNY2#N[^CQX.WHY3HB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Q(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS,3$*(RP@9G5Z>GD*;7-G:60@(D1A>2(*;7-G<W1R("+%
MYN7D[>7B[>XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S8*(RP@9G5Z>GD*;7-G:60@(D1E7VQE=&4@0V]L
M=6UN(@IM<V=S='(@(M/DX.OH\OPB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#$Q(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHW-@HC+"!F=7IZ>0IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B
MQ^#LY?+JZ"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,38*(RP@9G5Z>GD*;7-G:60@(D1E8VEM86P@;G5M
M8F5R<R(*;7-G<W1R("+([/\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS
M9W-T<B`B(@H*(SH@;&EB+W!R969S+G!H<#HQ,3<@;&EB+TAO<F1E+U!R969S
M+U5)+G!H<#HQ.#<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B
MT^3@Z^CR_"(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-S<*;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T
M<B`BUN+E\B#O[B#S[.[K]^#MZ/XB"@HC.B!L:6(O2&]R9&4O261E;G1I='DN
M<&AP.CDV"FUS9VED(")$969A=6QT($ED96YT:71Y(@IM<V=S='(@(L_P[O3H
MZ_P@[^X@\^SNZ_?@[>C^(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8W
M"B,L(&9U>GIY"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@(M/DX.OH
M\OPB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Q(&QI8B](;W)D92]097)M<RYP
M:'`Z,S(V(&QI8B](;W)D92]097)M<R]522YP:'`Z-#(R"B,Z(&QI8B](;W)D
M92]097)M<R]522YP:'`Z-#,Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW,"!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.CDS"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3$V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,Y"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3@R('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHW,PHC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3@@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$P"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"FUS9VED(")$96QE=&4B"FUS
M9W-T<B`BT^3@Z^CR_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@HC+"!F=7IZ>0IM<V=I9"`B1&5L971E
M($-E;&PB"FUS9W-T<B`BT^3@Z^CR_"(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,3DY(&%D;6EN+V=R;W5P<RYP:'`Z,C(W"FUS9VED(")$96QE=&4@1W)O=7`B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0Y
M"B,L(&9U>GIY"FUS9VED(")$96QE=&4@3&]G(@IM<V=S='(@(M/DX.OH\OPB
M"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C<W(&QI8B](;W)D92]097)M
M<R]522YP:'`Z,3`Q"B,L(&9U>GIY"FUS9VED(")$96QE=&4@4&5R;6ES<VEO
M;B(*;7-G<W1R("+-X/'R\.[IZN@@[^[K_.?NXN#RY>O_(@H*(SH@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDS"B,L(&9U>GIY"FUS9VED(")$
M96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(M'N[N'YY>WHY2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!C96QL(@IM<V=S='(@(M/D
MX.OH\OPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8S"B,L(&9U>GIY"FUS9VED(")$96QE=&4@8V]L=6UN(@IM
M<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C
M+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A('8Q+C$I
M("`C+2,M(RTC+2-<;B(*(O/A\.#R_"#Q\N[KX>7V(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA
M=&4@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HT,C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P
M97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(LW@\?+P[NGJZ"#O[NO\
MY^[BX/+EZ_\B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C0R-`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O
M<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(LW@
M\?+P[NGJZ"#O[NO\Y^[BX/+EZ_\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"B,L(&9U>GIY"FUS9VED(")$
M96QE=&4@<F]W(@IM<V=S='(@(M/DX.OH\OPB"@HC(&9U>GIY"B,Z('1E;7!L
M871E<R]P<F5F<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E;&5T
M92!S96QE8W1E9"!I9&5N=&ET>2(*;7-G<W1R("+3Y.#KZ/+\(.+[X?#@[>W[
MZ2#O\.[TZ.O\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8W"B,L(&9U>GIY"FUS9VED(")$96QE=&4@=&AE
M(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N
M<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?
M4E4N<&\@*%1U<F)A('8Q+C$I("`C+2,M(RTC+2-<;B(*(O/A\.#R_"#Q\N[K
MX>7V(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8S"B,L(&9U>GIY"FUS9VED(")$96QE=&4@=&AE(&-U<G)E
M;G0@<F]W(@IM<V=S='(@(M/DX.OH\OPB"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HS-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E
M9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(LWE(.SN
MX_,@[O+J\/OR_"#L[N3SZ_P@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C,@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(R,2!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(U,PHC+"!F=7IZ>0IM<V=I9"`B1&5L:79E<GD@=&EM92(*;7-G<W1R
M("+3Y.#KZ/+\(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<Q(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I8F4@
M=&AE(%!R;V)L96TB"FUS9W-T<B`BSN_H^.CRY2#O\.[AZ^7L\R(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HY-#(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`HC+"!F=7IZ>0IM<V=I9"`B1&5S8W)I
M<'1I;VXB"FUS9W-T<B`BS^[K[>[E(.[OZ/'@[>CE.B(*"B,Z(&QI8B](;W)D
M92YP:'`Z,3DW"FUS9VED(")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G
M9FEL92DZ(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92YP:'`Z,C`Q"FUS9VED
M(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A
M=&]R+B(*;7-G<W1R("+/[N3P[N'M[O'RZ"#A^^OH(.?@[^CQX.W[(.(@YO/P
M[>#K(.3K_R#@Y.SH[>CQ\O#@\N[PX"XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C(Q"FUS9VED(")$979E;&]P;65N="(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$V"FUS9VED(")$97<@
M<&]I;G0Z("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R
M:6=H="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F
M="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM<V=I
M9"`B1&ER96-T;W)Y(@IM<V=S='(@(LK@\N#K[N,B"@HC(&9U>GIY"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR-S`*;7-G:60@(D1I<W!L87D@,C0M:&]U
M<B!T:6UE<S\B"FUS9W-T<B`BSO+NX?#@YN#R_"#B\.7L_R#B(#(T+??@\>[B
M[NP@].[P[.#RY3\B"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,#`*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R("+$\//CZ.4@
M[>#Q\O#NZ>KH(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C@Y
M"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM
M<V=S='(@(LW@\?+P[NGJZ"#NX>[K[O?JZ"(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR.#`V"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G
M<W1R("+-X/'R\.[IZN@@[N'NZ^[WZN@B"@HC.B!L:6(O2&]R9&4O34E-12]-
M1$XN<&AP.C$Y,0IM<V=I9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]097)M<R]522YP:'`Z-#(R"B,L(&9U>GIY"FUS9VED(")$;R!N;W0@
M9&5L971E(@IM<V=S='(@(M/DX.OH\OPB"@HC.B!S97)V:6-E<R]M86EN=&5N
M86YC92YP:'`Z,C4*;7-G:60@(D1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I
M;G1E;F%N8V4N<&AP(@IM<V=S='(@(LWE(.+[Y_OBX.GRY2!M86EN=&5N86YC
M92YP:'`@[>7O[O'PY>3Q\N+E[>WN(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V
M:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G
M:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE
M<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`BPB#OY?#B[ND@
M\?+P[NKE(//JX.?@[?L@Z.SE[>`@[^[KY>D_(,7QZ^@@Y.`L(._N\?+@XOSR
MY2#CX.ON]^KS.B`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8Y"B,L(&9U>GIY"FUS9VED(")$;VUI;FEC82(*;7-G<W1R
M("+*X.OE[>3@\/PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<P"FUS9VED(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY-@IM<V=I9"`B
M1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R("(B"@HC
M(&9U>GIY"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-3$*;7-G
M:60@(D1O=VYL;V%D(@IM<V=S='(@(L?@X_#SY^CR_"(*"B,Z(&QI8B](;W)D
M92]-24U%+T-O;G1E;G1S+G!H<#HX-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1&]W;FQO860@)7,B"FUS9W-T<B`BQ^#C\//GZ/+\("5S(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D
M(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,3$*;7-G:60@(D1R;W`@9&]W;B!L:7-T
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,PHC
M+"!F=7IZ>0IM<V=I9"`B12U-86EL(@IM<V=S='(@(DE-4"(*"B,Z(&QI8B].
M970O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--
M4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@
M=&AI<R!S97)V:6-E+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G:60@(D524B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S4@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<P"FUS9VED(")%8W5A9&]R(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]097)M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3$U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHW,@IM<V=I9"`B161I="(*;7-G<W1R("+0Y>3@ZO+H\.[BX.WHY2(*
M"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+T)L;V-K+U5)+G!H<#HU,`IM<V=I9"`B
M161I="!";&]C:R(*;7-G<W1R("+0Y>3@ZO+H\.[BX/+\(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H<#HR,C8*;7-G:60@(D5D
M:70@1W)O=7`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HW-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$P,`HC+"!F=7IZ>0IM<V=I
M9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@(LW@\?+P[NGJZ"#O[NO\Y^[B
MX/+EZ_\B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"B,L(&9U
M>GIY"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(LW@\?+P[NGJ
MZ"#O[NO\Y^[BX/+EZ_\B"@HC(&9U>GIY+"!P:'`M9F]R;6%T"B,@9G5Z>GDL
M('!H<"UF;W)M870*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*
M;7-G<W1R("+3\?+@[>[BZN`@[_#@XB#DZ_\@)7,B"@HC(&9U>GIY+"!P:'`M
M9F]R;6%T"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0IM
M<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`BS>#Q\O#NZ>KH(@H*
M(R!F=7IZ>2P@<&AP+69O<FUA=`HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C,V-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S
M:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(LW@\?+P[NGJZ"(*"B,@9G5Z>GDL
M('!H<"UF;W)M870*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F
M;W(@)7,B"FUS9W-T<B`BS>#Q\O#NZ>KH(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C<W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16=Y<'0B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`W"FUS9VED(")%;"!386QV861O<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*
M;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<S(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T"FUS9VED(")%;6%I;"(*;7-G<W1R
M(")%;6%I;"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-38V('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3`*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHV.`HC+"!F=7IZ>0IM<V=I9"`B16UA
M:6P@061D<F5S<R(*;7-G<W1R("+"X/@@16UA:6PZ(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$Y-C<*(RP@9G5Z>GD*;7-G:60@(D5M86EL(&%D9')E<W-E
M<R!M=7-T(&UA=&-H+B(*;7-G<W1R("+"X/@@16UA:6PZ(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$Y.3,*(RP@9G5Z>GD*;7-G:60@(D5M86EL('=I=&@@
M8V]N9FER;6%T:6]N(@IM<V=S='(@(L_P[O?@_R#H[?3N\.S@]NC_(@H*(SH@
M;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA:6PM
M=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(Y-PHC+"!F=7IZ>0IM<V=I9"`B16UO=&EC
M;VYS(@IM<V=S='(@(LW@\?+P[NGJZ"(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`R"B,L(&9U>GIY"FUS9VED(")%;7!T>2!M97-S
M86=E+B(*;7-G<W1R("+-\^OEXN[I(/#EY_/K_/+@\BXB"@HC.B!L:6(O2&]R
M9&4O1W)O=7`O;&1A<"YP:'`Z,C0S(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H
M<#HT.#0*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C8V,B!L:6(O2&]R
M9&4O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&QI8B](;W)D92]!=71H+VQD87`N
M<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R("+-\^OEXN[I
M(/#EY_/K_/+@\BXB"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ
M,3,*;7-G:60@(D5M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-30W"FUS9VED(")%;F%B;&4@:6YS97)T
M:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(R"FUS9VED
M(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R("+*
M[NWRY>KQ\NWNY2#LY>W^(._N(.W@YN#RZ.@@[_#@XN[I(.KM[N_JZ"#L^_CH
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U.3(@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(X,#`*(RP@9G5Z>GD*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(B(*
M(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<
M;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC
M7&XB"B+0X.?BY?#M\_+\(.+QY2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C0*;7-G:60@
M(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@
M8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S=V]R
M9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!54DP@
M:&5R92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.#DP"FUS9VED(")%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SHB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDY(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW-@IM<V=I9"`B17%U871O<FEA;"!'=6EN96$B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<Y(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HW-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M,0IM<V=I9"`B17)I=')E82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@;&EB+TAO<F1E
M+T)L;V-K+TQA>6]U="]6:65W+G!H<#HY-"!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-#@*;7-G:60@(D5R<F]R(@IM<V=S='(@(L[XZ.'JX"(*"B,Z
M(&QI8B](;W)D92]496UP;&%T92YP:'`Z-#8S"B,L('!H<"UF;W)M870*;7-G
M:60@(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]496UP;&%T92YP:'`Z-#8X"B,L('!H<"UF
M;W)M870*;7-G:60@(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<R(*
M;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P-0IM<V=I9"`B17)R;W(@=VET:"!E;6%I;"!M97-S86=E+B(*;7-G<W1R
M("(B"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN
M9R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HW-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HW.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*;7-G<W1R("(B"@HC(&9U
M>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#,*;7-G:60@(D5V97)Y
M(#$U(&UI;G5T97,B"FUS9W-T<B`BRN#FY/OE(#$U(.SH[?/R(@H*(R!F=7IZ
M>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDS"FUS9VED(")%=F5R>2`R
M(&UI;G5T97,B"FUS9W-T<B`BRN#FY/OE(#(@[.CM\_+[(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,T,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDQ
M"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(LK@YN3[Y2`S,"#Q
MY>KS[>0B"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#(@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y-`IM<V=I9"`B179E<GD@-2!M:6YU
M=&5S(@IM<V=S='(@(LK@YN3[Y2`U(.SH[?/R(@H*(SH@;&EB+TAO<F1E+TUA
M:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T<B`B
MRN#FY/OI(/#@YR#O\.@@XO7NY.4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S0T"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`BRN#FY/OE
M(._NZ_?@\>`B"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-#$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,@IM<V=I9"`B179E<GD@;6EN
M=71E(@IM<V=S='(@(LK@YN3S_B#LZ.WS\O,B"@HC.B!T96UP;&%T97,O9&%T
M82]D871E;6%P+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V86QU97,Z(@IM<V=S
M='(@(L_PZ.SE\"#G[>#WY>WHZ3HB"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z
M.#$@861M:6XO8VUD<VAE;&PN<&AP.C4P(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,C<*;7-G:60@(D5X96-U=&4B"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!L:6(O
M2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HT-S4@;&EB+TAO<F1E+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HV,30*;7-G:60@(D5X<&%N9"(*;7-G<W1R("+0
MX/'XZ/#H\OPB"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R
M"B,L(&9U>GIY"FUS9VED(")%>'!A;F0@4VED96)A<B(*;7-G<W1R("(B"B(C
M+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB
M"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN
M(@HBT.#GXN7P[?/R_"#B\>4B"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S
M+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ-S4*;7-G:60@(D5X<&5C=&5D
M(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")%>'!I<F%T
M:6]N($1A=&4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HV-S<*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S$*(RP@
M9G5Z>GD*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(LCQ[^[K_.?NXN#R_"#G
M[>#WY>WHY2#O[B#S[.[K]^#MZ/XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3<W"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]0<F5F<R]S<6PN<&AP.C(R-0IM<V=I9"`B1F%I;&5D
M(')E=')I979I;F<@<')E9F5R96YC97,N(@IM<V=S='(@(L+N\?'RX.WNXNOE
M[>CE(.W@\?+P[N7J(.WE(//DX.ON\?PN(@H*(SH@;&EB+TAO<F1E+T=R;W5P
M+VQD87`N<&AP.C<U(&QI8B](;W)D92]!=71H+VQD87`N<&AP.CDX"FUS9VED
M(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B
MS>7SY.#W[>[E(/'NY>3H[>7MZ.4@\2#QY?#BY?#N["!,1$%0+B(*"B,Z(&QI
M8B](;W)D92]!=71H+W-M8BYP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@(D9A:6QE
M9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM<V=S='(@(LWE\^3@]^WN
MY2#Q[N7DZ.WE[>CE(/$@\>7PXN7P[NP@3$1!4"XB"@HC.B!L:6(O5D93+V9T
M<"YP:'`Z-S$W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@
M=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`BS>7SY.#W[>[E(/'NY>3H
M[>7MZ.4@\2#QY?#BY?#N["!,1$%0+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW
M,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y
M('1O(%PB)7-<(BXB"FUS9W-T<B`BS>7SY.#W[>[E(/'NY>3H[>7MZ.4@\2#Q
MY?#BY?#N["!,1$%0+B(*"B,Z(&QI8B](;W)D92]!=71H+W-A<VPN<&AP.C@W
M"B,L(&9U>GIY"FUS9VED(")&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O
M;FYE8W1I;VXN(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!3
M44P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C4P,2!L:6(O5D93
M+V9T<"YP:'`Z-S4U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL
M960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(LWE\^3@]^WNY2#Q[N7D
MZ.WE[>CE(/$@\>7PXN7P[NP@3$1!4"XB"@HC.B!L:6(O5D93+W-M8BYP:'`Z
M-#8U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@<F5T
M<FEE=F4Z("5S(@IM<V=S='(@(M3@Z>L@[_#H[?_R.B`B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`HC+"!F=7IZ>0IM<V=I
M9"`B1F%I<B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@
M=C,N,2D@(",M(RTC+2,M(UQN(@HBSO(@ZN[C[EQN(@HB(RTC+2,M(RTC("!R
M=5]252YP;R`H5'5R8F$@=C$N,2D@(",M(RTC+2,M(UQN(@HBSO(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C<Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<R"FUS9VED
M(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@V(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HX,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PHC+"!F
M=7IZ>0IM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R("+*[NSOX.WH_R(*
M"B,Z(&QI8B](;W)D92]#3$DN<&AP.C(S.`HC+"!F=7IZ>0IM<V=I9"`B1F%T
M86P@17)R;W(Z(@IM<V=S='(@(L[XZ.'JX"#H[._N\/+@.B`B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM
M<V=S='(@(M3@ZO$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4Q
M"B,L(&9U>GIY"FUS9VED(")&87AE<R(*;7-G<W1R("+4X.KQ(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,2!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C`*
M;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0HC+"!F=7IZ>0IM<V=I9"`B
M1F5W(%-H;W=E<G,B"FUS9W-T<B`BR.SO[O#R(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*(RP@9G5Z>GD*;7-G:60@(D9E
M=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`BR.SO[O#R(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$Y-#@*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,S,@IM<V=I9"`B1FEG;&5T($-!
M4%1#2$$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,S8*
M;7-G:60@(D9I9VQE="!F;VYT(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HX,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9I:FDB"FUS
M9W-T<B`B(@H*(R!F=7IZ>0HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-34*;7-G:60@(D9I;&4B"FUS9W-T<B`BU.#IZR(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]R87(N<&AP.C8P(&QI8B](;W)D92]-24U%+U9I97=E
M<B]Z:7`N<&AP.C8W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP
M.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C`@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`B(@H*(R!F=7IZ>0HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`Y"FUS9VED(")&:6QE($UA
M;F%G97(B"FUS9W-T<B`BU?#@[>CKZ/G@(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C,@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP
M:'`Z-S`*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@
M9G5Z>GD*;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R("+([/\B"@HC(&9U>GIY
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.3@T"B,L(&9U>GIY"FUS9VED(")&
M:6QE('-E;&5C=&EO;B(*;7-G<W1R("+/[NOM[N4@[N_H\>#MZ.4@[_#NX>OE
M[/LZ(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T.3`*(RP@9G5Z>GD*;7-G
M:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(LCL_R(*"B,Z(&QI8B](;W)D92]"
M<F]W<V5R+G!H<#HX.#4*(RP@9G5Z>GD*;7-G:60@(D9I;&4@=7!L;V%D<R!N
M;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O
M("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5
M+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBS>[B[N4@\>[NX?GE[>CE
M(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3$*;7-G
M:60@(D9I;'1E<G,B"FUS9W-T<B`BU.CK_/+P^R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HX,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@
M(D9I;FQA;F0B"FUS9W-T<B`BRN[L[^#MZ/\B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,38V"B,L(&9U>GIY"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@
M(L_PZ.SE\"#G[>#WY>WHZ3HB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@
M;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R=&5R(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HR-34*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,P"FUS9VED(")&;&EP(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED(")&
M;V<B"FUS9W-T<B`B(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C(S-R!L:6(O5D93
M+VUU<W%L+G!H<#HQ,#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9O
M;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*;7-G<W1R("+`Y/#E\>#R(//BY>3N
M[.OE[>C_("5S(.WE(.W@Z>3E[2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(R"B,L(&9U>GIY"FUS9VED(")&;VYT($-O
M;&]R(@IM<V=S='(@(LCQ[^[K_.?NXN#R_"#G[>#WY>WHY2#O[B#S[.[K]^#M
MZ/XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$R,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C8*(RP@9G5Z>GD*;7-G:60@(D9O<B!B<F]W<V5R<R!T
M:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@(L+@^"#A\.[SY^7P
M(.WE(._NY.3E\.;HXN#E\B#N[_;H_B#OY??@\N@N(,3K_R#OY??@\N@@[>#F
M[.CRY2!#5%),*U`N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C<R"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E
M='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A
M("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@
M8FQO8VLI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z,3`R"B,L(&9U>GIY"FUS9VED(")&;W)G;W0@>6]U<B!P87-S=V]R9#\B
M"FUS9W-T<B`BS^#P[NO\(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0V-`HC+"!F=7IZ>0IM<V=I9"`B1F]R;7,B"FUS9W-T<B`BR.S_(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U-0HC+"!F=7IZ>0IM<V=I9"`B
M1F]R=6US(@IM<V=S='(@(L?@[.7RZN@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3$Q"B,L(&9U>GIY"FUS9VED(")&;W)W87)D<R(*;7-G<W1R
M("+/Y?#E\>O@\OPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8P"B,L(&9U>GIY"FUS9VED(")&<B(*;7-G<W1R("(B"B(C
M+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HB
MSO(@ZN[C[EQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H5'5R8F$@=C$N,2D@
M(",M(RTC+2,M(UQN(@HBSO(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,S"B,L(&9U>GIY"FUS9VED(")&<F%M
M97,B"FUS9W-T<B`BR.S_(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@W
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW,PHC+"!F=7IZ>0IM<V=I9"`B1G)A;F-E(@IM<V=S
M='(@(LCL_R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S"FUS9VED
M(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z.3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C@T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N
M8V@@1W5I86YA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ.#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R
M:65S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C<T"B,L(&9U>GIY"FUS9VED(")&<F]M(@IM<V=S='(@(B(*(B,M
M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+.
M\B#J[N/N7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4=7)B82!V,2XQ*2`@
M(RTC+2,M(RTC7&XB"B+.\B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,S<@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,T.0HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDU"B,L(&9U>GIY"FUS9VED
M(")&<F]M('1H92`B"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H
M24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(L[R(.KNX^Y<;B(*(B,M(RTC+2,M
M(R`@<G5?4E4N<&\@*%1U<F)A('8Q+C$I("`C+2,M(RTC+2-<;B(*(L[R(@H*
M(R!F=7IZ>0HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT.`IM
M<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R("+/[NOM[N4@[N_H\>#M
MZ.4@[_#NX>OE[/LZ(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]"
M;&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C$@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHV,`HC+"!F=7IZ>0IM<V=I9"`B1G5L;"!.86UE
M(@IM<V=S='(@(L+@^.4@Z.S_.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HX."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S,*(RP@9G5Z>GD*;7-G:60@(D=A8F]N(@IM
M<V=S='(@(G9#87)D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL97)Y('1O('1A
M:V4@:6UA9V4@9G)O;2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A
M;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY
M-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M870*;7-G
M:60@(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL.C@*;7-G:60@(D=E
M;F5R871E9"!#;V1E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HY,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z.3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDQ
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U"B,L(&9U>GIY"FUS9VED
M(")':&%N82(*;7-G<W1R(")V0V%R9"(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HY-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W-@HC+"!F
M=7IZ>0IM<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R("+([/\B"@HC(&9U>GIY
M"B,@9G5Z>GD*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W-2!T
M96UP;&%T97,O<')E9G,O87!P+FEN8SHQ,`HC.B!T96UP;&%T97,O<')E9G,O
M87!P+FEN8SHQ.0IM<V=I9"`B1VQO8F%L($]P=&EO;G,B"FUS9W-T<B`BS^[P
M\N#K(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3<*;7-G:60@(D=O
M(@IM<V=S='(@(L_E\.7I\N@B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3$R.0HC+"!F=7IZ>0IM<V=I9"`B1V]O9VQE($UA<',B
M"FUS9W-T<B`BS^[H\>H@XB!';V]G;&4B"@HC.B!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G
M;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H(@IM<V=S='(@(L_NZ/'J
M(.(@1V]O9VQE(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(S-@IM<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.CDS"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'
M<F5E8V4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*
M;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z.34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.CDT"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U"B,L(&9U>GIY
M"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`BRN#KY>WDX/#\(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C@Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HY-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`HC+"!F=7IZ
M>0IM<V=I9"`B1W)E;F%D82(*;7-G<W1R("+*X.OE[>3@\/PB"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C$W.0IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T=R;W5P+G!H<#HU.2!L:6(O2&]R
M9&4O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N86UE<R!M=7-T
M(&)E(&YO;BUE;7!T>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1W)O=7`O
M;&1A<"YP:'`Z,S`W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U
M<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@
M=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`BS_#NX>OE[.`@[_#H(._N[_OR
MZN4@XOOWY?#J[?/R_"`E<RX@T>7PXN7P(/'JX.?@ZR(*"B,Z(&QI8B](;W)D
M92]'<F]U<"]L9&%P+G!H<#HQ,3@@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP
M.C$R-`HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L
M971E(&=R;W5P("5S(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU
M;2YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C
M;VUP96YD:75M+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M
M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<
M;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@=C(N,2D@(",M
M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XS
M*2`@(RTC+2,M(RTC7&XB"B+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,
M(/'E\.+E\.[L+EQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N
M,"XS*2`@(RTC+2,M(RTC7&XB"B+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@
M4U%,(/'E\.+E\.[L+EQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@
M=C,N,"XS*2`@(RTC+2,M(RTC7&XB"B+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_
M(/$@4U%,(/'E\.+E\.[L+EQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R
M9&4@=C,N,"XS*2`@(RTC+2,M(RTC7&XB"B+-Y>+NY^SNYNWN(/'NY>3H[>CR
M_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P
M+G!H<#HS,S@@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C,W.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R
M;W5P("5S(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HS,30@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R
M("+#\//O[_LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.CDW"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<W"FUS9VED
M(")'=6%M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'=65R;G-E
M>2(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]097)M<R]522YP
M:'`Z,C(V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*;7-G:60@(D=U
M97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(L/N\?+\(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0W,@IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S4*(RP@9G5Z>GD*;7-G:60@(D=U:6YE82(*;7-G<W1R("+2Y>S@(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<X"FUS
M9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P
M,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.`HC+"!F=7IZ>0IM<V=I
M9"`B1W5Y86YA(@IM<V=S='(@(G9#87)D(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.CDV-`IM<V=I9"`B2%1-3"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C
M96QL(&EN(')O=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@
M8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN
M('1A8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C;W=A
M<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+VAT='`N<&AP.C$U-PHC
M+"!F=7IZ>0IM<V=I9"`B2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(L#D\.7QX/(@\^+EY.[LZ^7MZ/\@)7,@[>4@[>#IY.7M+B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$P,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M,`HC+"!F=7IZ>0IM<V=I9"`B2&%I=&DB"FUS9W-T<B`BS>#Q\O#NZ>KH(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")(87-H+4%L
M9V]R:71H;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR,@HC+"!F=7IZ>0IM<V=I9"`B2&%Z92(*;7-G<W1R
M("+/[N3QZN#GZN`B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3(S(&QI8B](
M;W)D92]&;W)M+G!H<#HR.3(Q"B,L(&9U>GIY"FUS9VED(")(96%D97(B"FUS
M9W-T<B`BS^[D\>K@Y^K@(@H*(SH@;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L
M97-E="YP:'`Z-C$*;7-G:60@(DAE861E<G,B"FUS9W-T<B`BQ^#C[NONXNKH
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C,*(RP@9G5Z>GD*;7-G:60@(DAE879Y(%0M4W1O<FTB"FUS9W-T
M<B`BR.SO[O#R(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#4*;7-G:60@
M(DAE8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T"B,L(&9U
M>GIY"FUS9VED(")(96EG:'0B"FUS9W-T<B`BS>CJ[N/DX"(*"B,Z(&QI8B](
M;W)D92](96QP+G!H<#HQ.#0@;&EB+TAO<F1E+TAE;'`N<&AP.C$X-B!S97)V
M:6-E<R]H96QP+VEN9&5X+G!H<#HQ-PHC.B!T96UP;&%T97,O:&5L<"]I;F1E
M>"YI;F,Z-`IM<V=I9"`B2&5L<"(*;7-G<W1R("+/[N3QZN#GZN`B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Q"FUS9VED
M(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3,W-0HC+"!F=7IZ>0IM<V=I9"`B2&5L<&5R(@IM<V=S='(@
M(L_NY/'JX.?JX"(*"B,@9G5Z>GD*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y
M"FUS9VED(")(96UI<W!H97)E(@IM<V=S='(@(L_NZ_/XX/#HY2(*"B,Z('1E
M;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C$P"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@
M=&AE(&9I;&4Z(@IM<V=S='(@(LWHYN4@[_#EY/'RX.+KY>W@(.CM].[P[.#V
MZ/\@Z.<@\>#L[N/N(.W@]^#KX"#TX.GKX#HB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`HC+"!F=7IZ>0IM<V=I9"`B2&EG
M:"(*;7-G<W1R("+-Z.KNX^3@(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O<&]R
M=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N
M:6YC.C4*;7-G:60@(DAO7VUE(@IM<V=S='(@(L_N\/+@ZR(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR-#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$P-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@
M(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I(@IM<V=S='(@(B(*"B,@
M9G5Z>GD*(SH@;&EB+TAO<F1E+G!H<#HQ-3,Y"FUS9VED(")(;VUE(@IM<V=S
M='(@(L_N\/+@ZR(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3(R(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U"FUS
M9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`BQ.[LX/CMZ.D@X.3PY?$B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*(RP@9G5Z>GD*;7-G:60@(DAO
M;64@1&ER96-T;W)Y(@IM<V=S='(@(LK@\N#K[N,B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N92(*
M;7-G<W1R("+$[NS@^.WHZ2#RY>OE].[M(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$P."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`V(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N9R(*;7-G<W1R("(B"@HC(&9U
M>GIY"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-PIM<V=I9"`B2&]R
M9&4B"FUS9W-T<B`BS^[P\N#K(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT
M-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@
M)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<R(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T
M;R!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HT,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&]B
M:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C0V"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V
M960@)7,@7"(E<UPB(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@
M*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N
M<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+/\.[AZ^7LX"#O\.@@[_#N
M\>SN\O#E(.?@[_#N^.7M[>[C[B#OZ/'\[.`N(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I
M;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-3`R"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E
M(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]+;VQA8BYP:'`Z,3(T,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#<S"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@
M34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$Q.3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<(B5S
M7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3,S
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O
M('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@
M(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L
M('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L
M96%S92!R97!O<G0A*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N
M>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR,0IM<V=I9"`B2&]W
M(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@
M;65R9V4_(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.#D*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#@*;7-G:60@(DAU;6ED:71Y.B`B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@P"FUS9VED(")(=6YG87)Y(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ-S(@;&EB+TAO<F1E+T%U=&@O8WER
M<W%L+G!H<#HR,S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DE-05`@
M;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(L#D\.7QX/(@
M\^+EY.[LZ^7MZ/\@)7,@[>4@[>#IY.7M+B(*"B,Z(&QI8B](;W)D92]!=71H
M+V-Y<G5S+G!H<#HR,30@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR.34*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A
M:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N
M<&AP.C$W.2!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C(T,@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T
M:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`BP.3PY?'@\B#SXN7D[NSKY>WH_R`E
M<R#MY2#MX.GDY>TN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S,C`*(RP@
M9G5Z>GD*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`BP.3PY?$B"@HC.B!L
M:6(O2&]R9&4O075T:"]I<&)A<VEC+G!H<#HW-PHC+"!F=7IZ>0IM<V=I9"`B
M25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("+-Y?(@Y.[Q\O/O
M[?OU(.W@\?+P[N7J+B(*"B,Z(&QI8B](;W)D92]!=71H+VEP8F%S:6,N<&AP
M.C@Y"B,L(&9U>GIY"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL
M;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("+-Y?(@Y.[Q\O/O[?OU(.W@\?+P
M[N7J+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDU
M"FUS9VED("))4"!L;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$P.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@HC
M+"!F=7IZ>0IM<V=I9"`B26-E;&%N9"(*;7-G<W1R("+*[NSOX.WH_R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#`*;7-G:60@(DEC;VYS($]N;'DB
M"FUS9W-T<B`BTN[K_.KN(.CJ[NWJZ"(*"B,@9G5Z>GDL('!H<"UF;W)M870*
M(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T<B`BS>#Q\O#NZ>KH(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,0IM<V=I9"`B26-O;G,@=VET
M:"!T97AT(@IM<V=S='(@(LCJ[NWJZ"#Q(/+EZO'R[NPB"@HC(&9U>GIY"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3,*;7-G:60@(DED96YT:71Y)W,@
M;F%M93HB"FUS9W-T<B`BR.S_(._P[O3HZ_\Z(@H*(SH@;&EB+TAO<F1E+TU)
M344O0V]N=&5N=',N<&AP.C4Y.0HC+"!P:'`M9F]R;6%T"FUS9VED("))9B!I
M="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I
M;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT-3D*;7-G:60@(B(*(DEF('EO=2!D;VXG="!S964@86YY(&EC
M;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@
M8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC
M>2XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$W,@IM<V=I9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@
M8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A
M;B=T(&)E("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR.`HC+"!F=7IZ>0IM<V=I9"`B26UA9V4@4')E=FEE=SHB
M"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@
M(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I
M("`C+2,M(RTC+2-<;B(*(LW@Y^#D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R
M>3HB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W-C4*(RP@
M9G5Z>GD*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R("+([/\B"@HC.B!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@
M(LK@\/+H[>KH(@H*(R!F=7IZ>2P@<&AP+69O<FUA=`HC.B!T96UP;&%T97,O
M9&%T82]T<W9I;F9O+FEN8SHW('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC
M.C<*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-"!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R
M="P@4W1E<"`E9"(*;7-G<W1R("+([._N\/(L(/C@XR`E9"(*"B,Z('1E;7!L
M871E<R]D871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@
M(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R("+([._N\/+H\.[BX.WN(._N
MZ^4Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV-0IM<V=I
M9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R("+([._N\/+H\.[BX.W[(._N
MZ_\Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,P"B,L(&9U>GIY"FUS9VED("));E]S97)T(%)O=R!!9G1E
M<B(*;7-G<W1R("+1[N[A^>7MZ.4B"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O
M>FEP+G!H<#HQ,S0*;7-G:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E
M;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S,@HC+"!F=7IZ>0IM<V=I9"`B26YC;W)R96-T('5S97)N86UE(&%N
M9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`BS^[FX.OSZ?'RX"P@XN+EY.CRY2#"
MX/CH(.CL_R#O[NO\Y^[BX/+EZ_\@Z"#OX/#NZ_PB"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R96-T('5S97)N
M86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C
M="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H
M96QP+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S92!);F1E;G0B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@Q"B,L(&9U>GIY"FUS9VED("));F1I82(*;7-G<W1R("+2Y>OE].[M
M(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS
M9W-T<B`BS^[K_.?NXN#RY>OH(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$Q,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@P"B,L(&9U>GIY"FUS9VED("));F1O;F5S
M:6$B"FUS9W-T<B`BTN7KY?3N[2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C8W"B,L(&9U>GIY"FUS9VED("));F9O(@IM<V=S='(@
M(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC
M+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M
M(RTC7&XB"B+(X^WN\.CP[N+@\OPB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C4Y"B,L(&9U>GIY"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R
M("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M
M(RTC7&XB"B+/\.[WX/\@Z.WT[O#LX/;H_UQN(@HB(RTC+2,M(RTC("!R=5]2
M52YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(LCM].[P[.#VZ/\@[B#Q
MY?#BY?#E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q.0HC
M+"!F=7IZ>0IM<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L
M92XB"FUS9W-T<B`BS>7R(.3N\?+S[^W[]2#MX/'R\.[EZBXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*
M(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S='(@
M(M'N[N'YY>WHY2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`HC+"!F=7IZ>0IM<V=I9"`B26YS97)T
M($EM86=E(@IM<V=S='(@(M'N[N'YY>WHY2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*(RP@9G5Z>GD*;7-G:60@(DEN
M<V5R="!486)L92(*;7-G<W1R("+/\.CLY?`@Y^W@]^7MZ.DZ(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0HC+"!F=7IZ
M>0IM<V=I9"`B26YS97)T(%=E8B!,:6YK(@IM<V=S='(@(M/DX.OH\OP@[^#P
M\R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E
M<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("))
M;G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8R"B,L(&9U>GIY"FUS9VED("));G-E<G0@82!N97<@
M<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"B(C+2,M(RTC
M+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M
M(RTC+2,@(')U7U)5+G!O("A4=7)B82!V,2XQ*2`@(RTC+2,M(RTC7&XB"B+S
MX?#@\OP@\?+NZ^'E]B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W(')O
M=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM
M<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO
M9&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A9W)A
M<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@
M=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(T,@IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@
M>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3@*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S
M='(@(M'N[N'YY>WHY2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3D*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!C
M96QL(&)E9F]R92(*;7-G<W1R("+1[N[A^>7MZ.4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T"B,L(&9U>GIY
M"FUS9VED("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@(M'N[N'YY>WH
MY2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C4*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E
M(@IM<V=S='(@(M'N[N'YY>WHY2(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R
M9F,R,#@V+G!H<#HY,`HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(&UE<W-A9V5S
M(@IM<V=S='(@(M'N[N'YY>WHY2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-0HC+"!F=7IZ>0IM<V=I9"`B
M26YS97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R("+1[N[A^>7MZ.4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-CD*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!R;W<@869T97(B"FUS
M9W-T<B`BT>[NX?GE[>CE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`HC+"!F=7IZ>0IM<V=I9"`B26YS97)T
M(')O=R!B969O<F4B"FUS9W-T<B`BS_#H[.7P(.?MX/?E[>CI.B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S,*;7-G:60@(DEN<V5R="!T:&4@<F5Q
M=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR-@HC+"!F=7IZ>0IM<V=I9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G
M<W1R("+1[N[A^>7MZ.4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@Y"B,L(&9U>GIY"FUS9VED("));G-E<G0O36]D:69Y
M($QI;FLB"FUS9W-T<B`BT^3@Z^CR_"#OX/#S(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8T,PHC+"!F=7IZ>0IM<V=I9"`B26YS=69F
M:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES
M="XB"FUS9W-T<B`BS>4@[.[C\R#N\NKP^_+\(.SNY//K_"!-86EN=&5N86YC
M95]487-K("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-SD*(RP@9G5Z>GD*;7-G:60@(DEN
M=&5G97(B"FUS9W-T<B`BT>[GY.#R_"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,3,W"B,L(&9U>GIY"FUS9VED("));G1E9V5R(&QI<W0B"FUS9W-T<B`B
MT>[GY.#R_"(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDW"FUS9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ-C<@
M;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3DT"B,Z(&QI8B](;W)D92]#
M;VUP<F5S<R]Z:7`N<&AP.C(Q,@HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!:
M25`@9&%T82(*;7-G<W1R("+0X.'N]^CI(.#D\.7Q(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,#DQ(&QI8B](;W)D92]&;W)M+G!H<#HR
M,38R(&QI8B](;W)D92]&;W)M+G!H<#HR,C,V"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR,S`S(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C,W
M"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R("(B"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,`HC+"!F=7IZ
M>0IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R
M("+0X.'N]^CI(.#D\.7Q(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP
M:'`Z,3`Y(&QI8B](;W)D92]#;VUP<F5S<R]D8G@N<&AP.C$S.0HC.B!L:6(O
M2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HR-#$*(RP@9G5Z>GD*;7-G:60@(DEN
M=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`BT^3@Z^CR_"#OX/#S(@H*(R!F
M=7IZ>0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38U"B,L(&9U
M>GIY"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R("+-Y>KN
M\/#EZO+M[N4@Z.S_+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-3D*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O=FED
M960N(@IM<V=S='(@(M#@X>[WZ.D@X.3PY?$B"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?='EP
M92XB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#,*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A
M<&E?:60N(@IM<V=S='(@(M#@X>[WZ.D@X.3PY?$B"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-@HC+"!F=7IZ>0IM<V=I9"`B26YV
M86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@(M#@X>[WZ.D@
MX.3PY?$B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z,C<*;7-G:60@
M(DEN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*(RP@9G5Z>GD*;7-G:60@
M(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`BS>#Q\O#NZ>KH(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,PHC+"!F=7IZ>0IM<V=I
M9"`B26YV86QI9"!P<F]D=6-T(&-O9&4N(@IM<V=S='(@(LW@\?+P[NGJZ"(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"B,L(&9U
M>GIY"FUS9VED("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R("+-X/'R\.[I
MZN@B"@HC(&9U>GIY"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HY,R!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z-S$*(SH@;&EB+TYE="]3
M35,O=VEN7VAT='`N<&AP.C@P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M("));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S='(@(LWEZN[P\.7J
M\NWNY2#H[/\N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,#<U(&QI8B](
M;W)D92]+;VQA8BYP:'`Z,3(U.`HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!S
M:&%R92!O8FIE8W0B"FUS9W-T<B`BT.#A[O?HZ2#@Y/#E\2(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"B,L(&9U>GIY"FUS9VED
M("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R("+0X.'N]^CI(.#D
M\.7Q(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*
M(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R
M("+0X.'N]^CI(.#D\.7Q(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,U.0HC+"!F=7IZ>0IM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@(LWEZN[P
M\.7J\NWNY2#H[/\N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C8W-@HC+"!F=7IZ>0IM<V=I9"`B26YV97)T('-E;&5C=&EO;B(*
M;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@
M(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@
M(",M(RTC+2,M(UQN(@HBQ.7I\?+BZ.4Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Q.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R"FUS9VED("))<F%N+"!)<VQA
M;6EC(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$S(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#`*(RP@9G5Z>GD*;7-G:60@(DER96QA;F0B"FUS9W-T<B`BRN[L
M[^#MZ/\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED("))
M<VQE(&]F($UA;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O;&%T960@5"U3=&]R;7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@P"B,L(&9U>GIY"FUS9VED("))<W)A96PB"FUS9W-T<B`B
MRN[L[^#MZ/\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8R-@IM
M<V=I9"`B27-S=65R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0HC+"!F=7IZ>0IM<V=I9"`B271A;&EC
M(@IM<V=S='(@(L7FY>3MY>+M[B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@HC+"!F=7IZ>0IM<V=I9"`B271A;'DB
M"FUS9W-T<B`BQ>;EY.WEXNWN(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$R,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@R"FUS9VED(")*86UA:6-A(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#`@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S.`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED(")*
M86YU87)Y(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX,PHC+"!F=7IZ>0IM<V=I9"`B2F%P86XB"FUS
M9W-T<B`BPNWH[.#MZ.4B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM
M<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(R"FUS9VED(")*97)S97DB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@S"FUS9VED(")*;W)D86XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-2!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0S"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*(RP@9G5Z>GD*;7-G
M:60@(DIU;F4B"FUS9W-T<B`BTN7LX"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*(RP@9G5Z>GD*;7-G:60@
M(DIU<W1I9GDB"FUS9W-T<B`BT>[GY.#R_"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$U"B,L(&9U>GIY"FUS
M9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R("+1[N?DX/+\(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0P
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3<*
M(RP@9G5Z>GD*;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R("+1[N?DX/+\
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,30*(RP@9G5Z>GD*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R
M("+1[N?DX/+\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,38*(RP@9G5Z>GD*;7-G:60@(DIU<W1I9GD@4FEG
M:'0B"FUS9W-T<B`BT>[GY.#R_"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-@HC+"!F=7IZ>0IM<V=I9"`B2V%Z86MH
M<W1A;B(*;7-G<W1R("+$X/+@(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(V,PIM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@S"FUS9VED(")+96YY82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C
M=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HT,3$*(RP@9G5Z>GD*;7-G:60@(DME>2!#<F5A=&EO
M;B(*;7-G<W1R("+-X/'R\.[IZN@B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HT,30*;7-G:60@(DME>2!&:6YG97)P<FEN="(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME>2!,96YG
M=&@B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$Q
M"FUS9VED(")+97D@5'EP92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C4Y.0HC+"!F=7IZ>0IM<V=I9"`B2V5Y(%5S86=E(@IM
M<V=S='(@(M'N[N'YY>WHY2(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3(Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(DMI<FEB871I(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S(@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P
M=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$S,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@4F5P=6)L:6,@
M;V8B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*;7-G
M:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3,T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I
M="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED("),85]Y;W5T
M(@IM<V=S='(@(M#@\>KKX.3JX"(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(M_G^^HB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,W(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<*;7-G
M:60@(DQA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@
M(DQA<W0@2&%L9B(*;7-G<W1R("+/\.CLY?`@Y^W@]^7MZ.DZ(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C<V"B,L(&9U>GIY"FUS9VED("),87-T(%!A
M<W-W;W)D($-H86YG92(*;7-G<W1R("+/X/#NZ_PB"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"B,L(&9U>GIY"FUS
M9VED("),87-T(%%U87)T97(B"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]2
M52YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R
M=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(L'[\?+P^^D@\?+@
M\/(B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z-S$W"B,L('!H<"UF;W)M870*
M;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(L_PY>3[Y//YZ.D@XO7N
MY"#A^^LZ("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C<Q.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@
M(L_PY>3[Y//YZ.D@XO7NY"#A^^LZ("5S(/$@ZN[L[_S^\N7PX"`E<R(*"B,Z
M(&QI8B](;W)D92]!=71H+G!H<#HW,30*;7-G:60@(DQA<W0@;&]G:6XZ($YE
M=F5R(@IM<V=S='(@(L_PY>3[Y//YZ.D@XO7NY"#MY2#GX/3HZO'H\.[BX.TB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30V(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,C<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#D*(RP@9G5Z>GD*;7-G:60@(DQA='9I82(*;7-G<W1R("+1[N?DX/+\(@H*
M(R!F=7IZ>0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-SD*;7-G:60@(DQA>6]U="(*;7-G<W1R("+"^_7NY"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G
M:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@W"FUS
M9VED("),96)A;F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0HC+"!F=7IZ>0IM<V=I9"`B
M3&5F="(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V
M,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@
M=C,N,2D@(",M(RTC+2,M(UQN(@HB[^7PY>SE\?+H\OP@XN+E\/4B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,S$P.`HC+"!F=7IZ>0IM<V=I9"`B3&5F="!H
M96%D97(B"FUS9W-T<B`BS_#H[.7P(.?MX/?E[>CI.B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HS,3`T"B,L(&9U>GIY"FUS9VED("),969T('9A;'5E<R(*
M;7-G<W1R("+/\.CLY?`@Y^W@]^7MZ.DZ(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$T,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X"FUS9VED("),97-O=&AO(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC
M+"!F=7IZ>0IM<V=I9"`B3&5V96PB"FUS9W-T<B`BT^3@Z^CR_"#OX/#S(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X
M"B,L(&9U>GIY"FUS9VED("),:6)E<FEA(@IM<V=S='(@(LWHZN[CY.`B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,S$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*
M;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X"FUS
M9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U"B,L(&9U>GIY"FUS9VED("),
M:6=H="!$<FEZ>FQE(@IM<V=S='(@(L+U[N0B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@HC+"!F=7IZ>0IM<V=I9"`B3&EG
M:'0@4F%I;B(*;7-G<W1R("+"]>[D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(DQI9VAT(%)A
M:6X@16%R;'DB"FUS9W-T<B`BPO7NY"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(X"B,L(&9U>GIY"FUS9VED("),:6=H="!2
M86EN($QA=&4B"FUS9W-T<B`BPO7NY"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"B,L(&9U>GIY"FUS9VED("),:6=H="!2
M86EN(%-H;W=E<B(*;7-G<W1R("+"]>[D(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*(RP@9G5Z>GD*;7-G:60@(DQI9VAT
M(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@(L+U[N0B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,0HC+"!F=7IZ>0IM<V=I
M9"`B3&EG:'0@4VYO=R(*;7-G<W1R("+"]>[D(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*(RP@9G5Z>GD*;7-G:60@(DQI
M9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(L+U[N0B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3@Q.`HC+"!F=7IZ>0IM<V=I9"`B3&EN:R(*;7-G<W1R("+"
M]>[D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-SD*;7-G:60@(DQI;FL@=&AE
M(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L
M87EI;F<B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VAT
M;6PR=&5X="YP:'`Z,3@R"B,L(&9U>GIY"FUS9VED("),:6YK<R(*;7-G<W1R
M("+"]>[D(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V
M"FUS9VED("),:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,PIM<V=I9"`B3&ES="!$
M871A8F%S97,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP
M:'`Z-3$*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`BT>_H\>[J
M(/#@Y^3EZ^[B(._NY/'JX.?JZ"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,S(*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@
M;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DT"B,L(&9U>GIY"FUS9VED
M("),:7-T+4%R8VAI=F4B"FUS9W-T<B`BR/'JX/+\(@H*(SH@;&EB+TAO<F1E
M+TU)344O2&5A9&5R<RYP:'`Z-3@Y"B,L(&9U>GIY"FUS9VED("),:7-T+4AE
M;'`B"FUS9W-T<B`BT>_H\>[J(/#@Y^3EZ^[B(._NY/'JX.?JZ"(*"B,Z(&QI
M8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y-@HC+"!F=7IZ>0IM<V=I9"`B
M3&ES="U)9"(*;7-G<W1R("+1[^CQ[NH@\.#GY.7K[N(@[^[D\>K@Y^KH(@H*
M(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DR"B,L(&9U>GIY"FUS
M9VED("),:7-T+4]W;F5R(@IM<V=S='(@(M'OZ/'NZB#PX.?DY>ONXB#O[N3Q
MZN#GZN@B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.3,*(RP@
M9G5Z>GD*;7-G:60@(DQI<W0M4&]S="(*;7-G<W1R("+1[^CQ[NH@\.#GY.7K
M[N(@[^[D\>K@Y^KH(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O34E-12](96%D
M97)S+G!H<#HU.3$*(RP@9G5Z>GD*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM
M<V=S='(@(LCQZN#R_"(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+TU)344O2&5A
M9&5R<RYP:'`Z-3DP"B,L(&9U>GIY"FUS9VED("),:7-T+55N<W5B<V-R:6)E
M(@IM<V=S='(@(LCQZN#R_"(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!S97-S:6]N<R!F
M86EL960Z("5S(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C
M;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B+.
M^.CAZN`@[_#H(//DX.OE[>CH7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A.
M86<@2#,@*#(N,"XS*2D@(",M(RTC+2,M(UQN(@HBS>7SY.#W[>[E(/'NY>3H
M[>7MZ.4@\2#QY?#BY?#N["!,1$%0+EQN(@HB(RTC+2,M(RTC("!R=5]252YP
M;R`H3F%G($@S("@R+C`N,RDI("`C+2,M(RTC+2-<;B(*(LWE\^3@]^WNY2#Q
M[N7DZ.WE[>CE(/$@\>7PXN7P[NP@3$1!4"XB"@HC.B!A9&UI;B]S97-S:6]N
M<RYP:'`Z,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@
M=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R("+/[NCQZB(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R
M<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$T-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y"B,L(&9U>GIY"FUS9VED("),
M:71H=6%N:6$B"FUS9W-T<B`BPNWH[.#MZ.4B"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O:6UA9V5S+G!H<#HW-PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`P"FUS
M9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#8*;7-G:60@(DQO8V%L92!A;F0@5&EM92(*
M;7-G<W1R("++[NK@Z^CGX/;H_R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3<R(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-PHC.B!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(*;7-G:60@(DQO8V%T:6]N(@IM<V=S
M='(@(M#@\>_NZ^[FY>WHY2(*"B,Z(&QO9VEN+G!H<#HQ.#D@<V5R=FEC97,O
M<&]R=&%L+W-I9&5B87(N<&AP.C(P,"!T96UP;&%T97,O;&]G:6XO;6]B:6QE
M+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*;7-G:60@(DQO9R!I;B(*;7-G<W1R
M("+"]>[D(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U"FUS
M9VED("),;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@(B(*
M"B,@9G5Z>GD*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y-`IM
M<V=I9"`B3&]G(&]U="(*;7-G<W1R("+"^_7NY"(*"B,@9G5Z>GD*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C4Y"FUS9VED("),;V=I;B(*;7-G<W1R("+3
M]^7R[>#_(.?@[^CQ_"(*"B,@9G5Z>GD*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q,`IM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`BPO7NY"(*"B,Z
M(&QI8B](;W)D92]!=71H+G!H<#HY.34*(RP@9G5Z>GD*;7-G:60@(DQO9VEN
M(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S
M(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@(B(*(L_N(.K@ZNCL+?+N
M(._PZ/?H[>#L(.+U[N0@XB#QZ/'RY>SS(.WE(//DX.OQ_RX@PN7P[O_R[>7E
M(.+QY>/N+"#"X/CH(.CL_R`B"B+O[NO\Y^[BX/+EZ_\@Z.OH(._@\.[K_"#A
M^^OH(.+BY>3E[?L@[>7BY?#M[BXB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z
M.3DQ"B,L(&9U>GIY"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S='(@(DE-
M4"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S8Y"B,L(&9U>GIY"FUS9VED
M("),;VYG('1E>'0B"FUS9W-T<B`BPOOU[N0B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B3&]W(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C$W"B,L(&9U>GIY"FUS9VED("),;W=E<B!R;VUA;B!N
M=6UB97)S(@IM<V=S='(@(LCL_R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3'5X96UB;W5R9R(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,SDY(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,S<*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(LS,(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X,PIM<V=I9"`B34]41"(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&YE9BYP:'`Z
M,S8*;7-G:60@(DU3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T
M82XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR"B,L
M(&9U>GIY"FUS9VED(")-86-A;R(*;7-G<W1R("))35`B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,34S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,S8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA
M8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34Q(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3`*;7-G:60@(DUA9&%G87-C87(B"FUS9W-T<B`B(@H*(R!F=7IZ
M>0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#,*;7-G:60@(DUA:6PB
M"FUS9W-T<B`BS^[W\N`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-3(T"FUS9VED(")-86EL($%D;6EN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,0IM<V=I
M9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,38U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S@*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@
M(DUA;&%W:2(*;7-G<W1R("))35`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,38W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*(RP@9G5Z>GD*;7-G:60@(DUA;&%Y
M<VEA(@IM<V=S='(@(DE-4"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B36%L9&EV97,B
M"FUS9W-T<B`B24U0(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")-86QI(@IM<V=S='(@
M(DE-4"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C(@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B36%L=&$B"FUS9W-T<B`B24U0(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT"FUS9VED("(B"B)-86YA9V4@
M=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M
M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S92!C
M871E9V]R:65S+B(*;7-G<W1R("+-X/'R\.[IZN`@\>_H\>K@(.K@\N7C[O#H
MZ2#H(/;BY?+NXB#H]2#N\N[A\.#FY>WH_R(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,34T"FUS9VED(")-87`R-"!M87`B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$P.#4*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q
M-CD*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T;W)E
M9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P,B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-C<*(RP@9G5Z>GD*;7-G:60@(DUA<F-H(@IM<V=S='(@(L_NZ/'J(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M,0HC+"!F=7IZ>0IM<V=I9"`B36%R9VEN(@IM<V=S='(@(L+MZ.S@[>CE(@H*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-
M87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K('=I
M=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34R(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3$*;7-G:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U.2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDS
M"B,L(&9U>GIY"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@(L+MZ.S@[>CE
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA
M=&-H:6YG(&9I96QD<R(*;7-G<W1R("+1[N+OX.3@_OGHY2#O[NO_(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDS"B,L
M(&9U>GIY"FUS9VED(")-875R:71A;FEA(@IM<V=S='(@(L+MZ.S@[>CE(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT
M"B,L(&9U>GIY"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`BPNWH[.#MZ.4B
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I
M9"`B36%X(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`HC+"!F=7IZ>0IM<V=I9"`B
M36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@(M'N[N'YY>WH
MY2(*"B,Z(&QI8B]A<&DN<&AP.C@V"B,L(&9U>GIY"FUS9VED(")-87AI;75M
M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@(LS@ZO'H[.#K_.WN
MY2#J[NOH]^7Q\N+N(/'R\.#MZ/8B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M.3`R(&QI8B](;W)D92]&;W)M+G!H<#HQ,C(Q(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,C0S"FUS9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0HC+"!F=7IZ>0IM<V=I9"`B
M36%Y(@IM<V=S='(@(L7FY>3MY>+M[B(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(U,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PHC+"!F=7IZ>0IM
M<V=I9"`B36%Y;W1T92(*;7-G<W1R("+"^_7NY"(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(DUE;6)E
M<G,B"FUS9W-T<B`BQ^#LY?+JZ"(*"B,@9G5Z>GD*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,X,@IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R("+0Y>;H
M["#LY>W^.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C`*(RP@9G5Z>GD*;7-G:60@(DUE<F=E(&-E;&QS(@IM
M<V=S='(@(M/DX.OH\OPB"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E(@IM<V=S='(@(M'N[N'YY>WHY2(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C$V"FUS9VED("(B"B)-
M97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S
M(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92`B"B)V97)I9FEE9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*
M(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS9W-T<B`BT>[N
MX?GE[>CE(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V
M.2!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C8P"B,L(&9U>GIY"FUS9VED(")-97-S86=E
M('1Y<&4B"FUS9W-T<B`BT>[NX?GE[>CE(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$U,PIM<V=I9"`B365T87)$0B!I<R!N;W0@8V]N;F5C
M=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R
M+G!H<#HV-R!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I
M9"`B365T:&]D(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C
M+G!H<#HX,2!L:6(O2&]R9&4O4E!#+W-O87`N<&AP.C$Q-PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE
M9"(*;7-G<W1R("+`Y/#E\>#R(//BY>3N[.OE[>C_("5S(.WE(.W@Z>3E[2XB
M"@HC.B!L:6(O2&]R9&4O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF;W)M870*
M;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8W
M"FUS9VED(")-971R:6,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$V-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-97AI8V\B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@U(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S(*;7-G:60@(DUI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@
M;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<V"B,L(&9U>GIY"FUS9VED(")-:61D;&4B"FUS
M9W-T<B`B24U0(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP
M.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O;&1A<"YP:'`Z-#,Y"FUS9VED(")-:6YI;75M('!A<W-W;W)D(&%G
M92!H87,@;F]T('EE="!E>'!I<F5D(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HR,S,*(RP@9G5Z>GD*;7-G:60@
M(DUI<G)O<B(*;7-G<W1R("+.^.CAZN`B"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C<R(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S0P"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HR-3`*;7-G
M:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q-0IM<V=I9"`B(@HB
M36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I
M="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC871I;VXN
M(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`T"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@240N(@IM<V=S='(@(B(*
M"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G
M:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S
M='(@(B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDT
M"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-38*;7-G:60@
M(DUO(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW
M-@IM<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*(RP@9G5Z>GD*;7-G:60@
M(DUO9&5R871E(@IM<V=S='(@(LCL[^[P\B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]R87(N<&AP.C8V(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<S"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@U"FUS
M9VED(")-;V1I9FEE9"!$871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PHC+"!F=7IZ
M>0IM<V=I9"`B36]D:69Y(%523"(*;7-G<W1R("+3Y.#KZ/+\(._@\/,B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8W-`HC+"!F=7IZ>0IM<V=I
M9"`B36]D=6QU<R(*;7-G<W1R("+1]N7MX/#HZ2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U
M,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]L9&]V
M82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$T.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP"B,L(&9U>GIY"FUS9VED(")-
M;VYA8V\B"FUS9W-T<B`B24U0(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$U-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")-;VYG;VQI
M82(*;7-G<W1R("+*[NSS(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U.#@*
M(RP@9G5Z>GD*;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@(B(*(B,M
M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*
M(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB
M"B+0X.?BY?#M\_+\(.+QY2(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP
M:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`BQ>;E[.7Q__?M[B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C$@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$U,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM
M<V=I9"`B36]N='-E<G)A="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA
M<V5S(@IM<V=S='(@(M3@Y_L@R_/M^R(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z
M,3DV(&QI8B]&:6QE+T-35BYP:'`Z,C@P"B,L('!H<"UF;W)M870*;7-G:60@
M(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T
M960@)60N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY,`HC+"!F=7IZ>0IM<V=I9"`B36]R;V-C;R(*
M;7-G<W1R("))35`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS,PHC+"!F=7IZ>0IM<V=I9"`B36]S=&QY($-L96%R(@IM<V=S
M='(@(LKN[._@[>C_(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S0*(RP@9G5Z>GD*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS
M9W-T<B`BRN[L[^#MZ/\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS-0HC+"!F=7IZ>0IM<V=I9"`B36]S=&QY(%-U;FYY(@IM
M<V=S='(@(LKN[._@[>C_(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+G!H<#HU,#D@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HV-#@*;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R("+OY?#E[.7Q\NCR
M_"#B[>CG(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H
M<#HU,3,@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-3(*
M;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R("+OY?#E[.7Q\NCR_"#BZ^7B[B(*
M"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-3$W(&QI
M8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C4V"FUS9VED(")-
M;W9E(%)I9VAT(@IM<V=S='(@(N_E\.7LY?'RZ/+\(.+O\.#B[B(*"B,@9G5Z
M>GD*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-3`U(&QI8B](;W)D
M92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C0T"FUS9VED(")-;W9E(%5P
M(@IM<V=S='(@(N_E\.7LY?'RZ/+\(.+BY?#U(@H*(R!F=7IZ>0HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E
M(&1O=VXB"FUS9W-T<B`B[^7PY>SE\?+H\OP@XNWHYR(*"B,@9G5Z>GD*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R,R!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E('5P
M(@IM<V=S='(@(N_E\.7LY?'RZ/+\(.+BY?#U(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$V."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"B,L(&9U>GIY"FUS9VED
M(")-;WIA;6)I<75E(@IM<V=S='(@(L+MZ.S@[>CE(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(Q.#@*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L
M:7-T<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3`U-@IM<V=I9"`B375L=&EM87`@54L@;6%P(@IM<V=S='(@
M(B(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-#8*(RP@9G5Z
M>GD*;7-G:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R("+/[NOM[N4@
M[N_H\>#MZ.4@[_#NX>OE[/LZ(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#`R"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@(M/W
MY?+MX/\@Y^#OZ/'\(@H*(R!F=7IZ>0HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z,C@*;7-G:60@(DUY($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B
MPN#XX"#H[?3N\.S@]NC_(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H
M<#HT-0IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]E9&ET+G!H<#HT,PIM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34U(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@(DUY86YM87(B"FUS9W-T<B`B
MRN#KY>WDX/#\(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V%G<F5E;65N
M=%]B;W1T;VTN:6YC.C<*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT
M96YA;F-E+FAT;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3$@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(").86UE(@IM<V=S='(@(LCL
M_R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-CD@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$U-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3<X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-3@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S<@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$W-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"B,L(&9U
M>GIY"FUS9VED(").971H97)L86YD<R(*;7-G<W1R("+*X.OE[>3@\/PB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$V,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM
M<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G:60@(DYE='-C87!E($)A
M<V4@55),(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-3@T"FUS9VED(").971S8V%P92!#02!2979O8V%T:6]N(%523"(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I
M9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@4F5N
M97=A;"!54DPB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HU.#,*;7-G:60@(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@W"FUS9VED
M(").971S8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#@*;7-G:60@(DYE='-C87!E(&-E
M<G1I9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E
M('1Y<&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(U,PHC+"!F=7IZ>0IM<V=I9"`B3F5T=V]R:R(*;7-G<W1R("+-[N+[Y2(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S,Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3`*;7-G
M:60@(DYE=F5R(@IM<V=S='(@(LWHZN[CY.`B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3<P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C(*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE
M9&]N:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y
M36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R("+-
M[N+@_R#JX/+EX^[PZ/\B"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA
M:6QS+G!H<#HX,2!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS+G!H<#HX
M-PHC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS+G!H<#HY-R!L:6(O
M2&]R9&4O5&5X="]&:6QT97(O96UA:6QS+G!H<#HQ,#$*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E('1O("5S(@IM<V=S='(@(LWN
MXOOE(/'N[N'YY>WH_R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`HC+"!F
M=7IZ>0IM<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`BPN7P[?/R_/'_(.H@[>#Q
M\O#NZ>K@["(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M,S4*;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$V,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M.`HC+"!F=7IZ>0IM<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`BRN#KY>WD
MX/#\(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,W"B,L(&9U
M>GIY"FUS9VED(").97<@<&%S<W=O<F0B"FUS9W-T<B`BS^#P[NO\(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*(RP@9G5Z>GD*
M;7-G:60@(DYE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(L+@
M^"!%;6%I;#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.CDQ"FUS9VED(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@
M(B(*"B,@9G5Z>GD*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(Y,0IM<V=I9"`B3F5W<R(*;7-G<W1R("+-
M[N+N\?+H(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-PHC+"!F
M=7IZ>0IM<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R("+3Y.#KZ/+\(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34@=&5M<&QA=&5S+V1A=&$O
M9&%T96UA<"YI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ
M,CD@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4*;7-G:60@(DYE>'0B
M"FUS9W-T<B`BQ.#KY>4B"@HC(&9U>GIY"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HR-PHC+"!F=7IZ>0IM<V=I9"`B3F5X="`T(%!H87-E<R(*;7-G<W1R("+1
MZ^7D\_[YX/\B"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z
M,S8V(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S<P"FUS9VED(").97AT(&]P
M=&EO;G,B"FUS9W-T<B`BT>OEY//^^>#_(/'R\.#MZ/;@(@H*(SH@;&EB+TAO
M<F1E+U5)+U!A9V5R+G!H<#HQ,#,*(RP@9G5Z>GD*;7-G:60@(DYE>'0^(@IM
M<V=S='(@(L3@Z^7E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDV"B,L(&9U>GIY"FUS9VED(").:6-A<F%G=6$B"FUS
M9W-T<B`B24U0(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDV"B,L(&9U>GIY"FUS9VED(").:6=E<B(*;7-G<W1R("+-
MZ.KNX^3@(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDV"B,L(&9U>GIY"FUS9VED(").:6=E<FEA(@IM<V=S='(@(LWH
MZN[CY.`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8Y"B,L
M(&9U>GIY"FUS9VED(").:6=H="(*;7-G<W1R("+-Z.KNX^3@(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$W.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"B,L(&9U
M>GIY"FUS9VED(").:75E(@IM<V=S='(@(LWHZN[CY.`B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38T"FUS9VED(").;R(*;7-G
M<W1R("+-Y?(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL
M.CD*;7-G:60@(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@
M<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S='(@(B(*"B,Z(&QI8B]61E,O
M25-/5W)I=&5R+G!H<#HQ,#8*;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G
M>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@(B(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").;R!B871C
M:"!T96UP;&%T92XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA
M>6]U="YP:'`Z-SD@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,C0U"B,Z
M(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C(V-R!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$P,0HC.B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+TUA;F%G97(N<&AP.C,X-0HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C0P-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T
M('1H92!R97%U97-T960@<&]S:71I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O;6-A;"YP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(DYO(&-A;&5N
M9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(LWE\B#MX/'R\.[EZB#DZ_\@[_#N]N7D\_#[(.#S\N7M\NCTZ.K@
M]NCH(._N(%-13"(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4T"B,L(&9U
M>GIY"FUS9VED(").;R!C:&%N9V4N(@IM<V=S='(@(L[R[.7MZ/+\(.CG[.7M
MY>WH_R(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,34V"FUS9VED(").
M;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4N<&AP.C$V.2!L:6(O2&]R9&4N<&AP
M.C4P."!L:6(O2&]R9&4O571I;"YP:'`Z-S8X"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@)7,N(@IM<V=S='(@(LWE(.'[Z^X@\^K@Y^#M[B#Q[N[RXN7R
M\?+B\_[YY>D@Z.WT[O#LX/;HZ"#DZ_\@ZN#RY>/N\.CI(%-13"XB"@HC.B!L
M:6(O5D93+V9T<"YP:'`Z.#4U"B,L(&9U>GIY"FUS9VED(").;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS
M9W-T<B`BQ.O_(.W@\?+P[N7J($Q$05`@[>4@X?OK[B#SZN#GX.WN(/'N[O+B
MY?+Q\N+S_OGEZ2#H[?3N\.S@]NCH+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HV
M-S(*(RP@9G5Z>GD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R("+-Y2#A^^ON(//J
MX.?@[>X@\>[N\N+E\O'RXO/^^>7I(.CM].[P[.#VZ.@@Y.O_(.K@\N7C[O#H
MZ2!344PN(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S(U"B,L(&9U>GIY
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R("+-Y2#A^^ON(//JX.?@[>X@
M\>[N\N+E\O'RXO/^^>7I(.CM].[P[.#VZ.@@Y.O_(.K@\N7C[O#HZ2!344PN
M(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G
M:60@(DYO(&-R961I="!L969T+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"B,L(&9U>GIY"FUS9VED(").;R!D
M97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`BT>[NX?GE[>CE(@H*(SH@
M;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDP,PHC+"!F=7IZ>0IM<V=I9"`B3F\@
M9FEL92!U<&QO861E9"(*;7-G<W1R("+([/\B"@HC.B!U=&EL+VEC;VY?8G)O
M=W-E<BYP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*
M;7-G<W1R("+`Y/#E\>#R(//BY>3N[.OE[>C_("5S(.WE(.W@Z>3E[2XB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$V(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HT,`HC+"!F=7IZ>0IM<V=I9"`B3F\@;&]C871I;VX@:7,@
M<V5T+B(*;7-G<W1R("+-X/'R\.[IZN@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,34W"B,L(&9U>GIY"FUS9VED(").;R!L;V-A=&EO;B!P
M<F]V:61E9"XB"FUS9W-T<B`BS>#Q\O#NZ>KH(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S,PHC+"!F=7IZ>0IM<V=I9"`B3F\@;65S
M<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`BT>[NX?GE[>CE(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@HC+"!F=7IZ>0IM<V=I9"`B
M3F\@;F%M92!S<&5C:69I960N(@IM<V=S='(@(L'[Z^X@\^K@Y^#M[B#MY>KN
M\/#EZO+M[N4@Y^W@]^7MZ.4N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S-PHC+"!F=7IZ>0IM<V=I9"`B3F\@;G5M8F5R('-P96-I
M9FEE9"XB"FUS9W-T<B`BP?OK[B#SZN#GX.WN(.WEZN[P\.7J\NWNY2#G[>#W
MY>WHY2XB"@HC.B!L:6(O2&]R9&4O075T:"]H='1P+G!H<#HY,0HC+"!F=7IZ
M>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(LWE\B#MX/'R\.[EZB#DZ_\@[_#N]N7D\_#[
M(.#S\N7M\NCTZ.K@]NCH(._N(%-13"(*"B,Z(&QI8B](;W)D92]!=71H+VEM
M87`N<&AP.C$P.`HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($E-05`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(LWE\B#MX/'R
M\.[EZB#DZ_\@[_#N]N7D\_#[(.#S\N7M\NCTZ.K@]NCH(._N(%-13"(*"B,Z
M(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C<R"B,L(&9U>GIY"FUS9VED(").
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(LWE\B#MX/'R\.[EZB#DZ_\@[_#N]N7D\_#[(.#S\N7M
M\NCTZ.K@]NCH(._N(%-13"(*"B,Z(&QI8B](;W)D92]!=71H+W-A<VPN<&AP
M.C<W(&QI8B](;W)D92]!=71H+VQO9VEN+G!H<#HX-`HC.B!L:6(O2&]R9&4O
M075T:"]P86TN<&AP.C<U"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN(@IM<V=S='(@(LWE
M\B#MX/'R\.[EZB#DZ_\@[_#N]N7D\_#[(.#S\N7M\NCTZ.K@]NCH(._N(%-1
M3"(*"B,Z(&QI8B](;W)D92]!=71H+W!A<W-W9"YP:'`Z,3,U"B,L(&9U>GIY
M"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R("+-Y?(@[>#Q\O#NY>H@Y.O_(._P[O;EY//P
M^R#@\_+E[?+H].CJX/;HZ"#O[B!344PB"@HC.B!L:6(O2&]R9&4O075T:"]S
M;6(N<&AP.C@T"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+-Y?(@[>#Q\O#N
MY>H@Y.O_(._P[O;EY//P^R#@\_+E[?+H].CJX/;HZ"#O[B!344PB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R.#<*;7-G:60@(B(*(DYO('!A
M=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-3
M3"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O<FL@=VET:"!02T-3(#$R
M(&1A=&$N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS9W-T
M<B`B(@H*(SH@;&EB+U9&4RYP:'`Z-S8V"B,L(&9U>GIY"FUS9VED(").;R!Q
M=6]T82!S970N(@IM<V=S='(@(L?@[.7RZN@B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0S"B,L(&9U>GIY"FUS
M9VED(").;R!R=6QE<R(*;7-G<W1R("+'X.SE\NKH(@H*(SH@;&EB+T9I;&4O
M0U-6+G!H<#HT.#(*(RP@9G5Z>GD*;7-G:60@(DYO('-E<&%R871O<B!S<&5C
M:69I960N(@IM<V=S='(@(L+[(.WE(//JX.?@Z^@@[^#OZN@B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T"B,L
M(&9U>GIY"FUS9VED(").;R!S:61E<R(*;7-G<W1R("+'X.SE\NKH(@H*(SH@
M;&EB+U9&4R]S;6(N<&AP.C4X-PHC+"!F=7IZ>0IM<V=I9"`B3F\@<W5C:"!F
M:6QE(@IM<V=S='(@(L?@[.7RZN@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,3(V"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V
M86EL86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$@;&EB+TYE="]335,O=VEN7VAT='`N
M<&AP.C(R,0HC+"!F=7IZ>0IM<V=I9"`B3F\@=7-E<FYA;64@86YD+V]R('!A
M<W-W;W)D('-E;G0N(@IM<V=S='(@(L_NYN#K\^GQ\N`L(.+BY>3H\N4@PN#X
MZ"#H[/\@[^[K_.?NXN#RY>O_(.@@[^#P[NO\(@H*(SH@;&EB+TAO<F1E+U)0
M0R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T
M=7)N960B"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.3<R(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HY.#(*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.CDY,PHC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3`Q,`IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(LWE(.[O\.7DY>OE
M[>XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V
M97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N
M97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$R.`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y
M;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HT,C<@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC
M.CDS"FUS9VED(").;VYE(@IM<V=S='(@(BWMY2#B^^'PX.TM(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I9"`B
M3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X.`IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDV"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G<W1R("(B"@HC
M(&9U>GIY"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B
MT>7BY?#M[N4@[^[K\_C@\.CE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$U."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDS"FUS9VED(").;W)T:&5R;B!-87)I86YA
M($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$W-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").;W)W87DB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#$*(RP@9G5Z>GD*
M;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R("+'X.SE\NKH(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#`*(RP@9G5Z>GD*;7-G:60@(DYO="!"
M969O<F4B"FUS9W-T<B`BQ^#LY?+JZ"(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z
M-#$U"B,L(&9U>GIY"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B
MRN#RX.ONXR(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+G!H<#HV,R!L:6(O5D93
M+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C@T"B,Z(&QI8B]6
M1E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.34*(SH@;&EB
M+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&QI
M8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HU.0HC+"!F
M=7IZ>0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*;7-G<W1R("(B"B(C+2,M
M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C
M+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HB
MS>[B[N4@\>[NX?GE[>CE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHV.`HC+"!F=7IZ>0IM<V=I9"`B3F]T('-E="(*;7-G
M<W1R("+'X.SE\NKH(@H*(SH@;&EB+U9&4RYP:'`Z,3DS(&QI8B]61E,N<&AP
M.C(P."!L:6(O5D93+G!H<#HR,S0@;&EB+U9&4RYP:'`Z,C4R"B,Z(&QI8B]6
M1E,N<&AP.C(V.2!L:6(O5D93+G!H<#HR.#4@;&EB+U9&4RYP:'`Z,S`Q(&QI
M8B]61E,N<&AP.C,Q-@HC.B!L:6(O5D93+G!H<#HS,S,@;&EB+U9&4RYP:'`Z
M,S8V(&QI8B]61E,N<&AP.C0R-B!L:6(O5D93+G!H<#HU,#4*(SH@;&EB+U9&
M4RYP:'`Z-3<T(&QI8B]61E,N<&AP.C4Y,2!L:6(O5D93+G!H<#HV-CD*(SH@
M;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#4@;&EB+TAO<F1E+U-E
M<W-I;VY(86YD;&5R+G!H<#HQ-C`*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD
M;&5R+G!H<#HQ-S4@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#D*
M(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HR,S8*(RP@9G5Z>GD*
M;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@
M<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M
M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+-[N+NY2#Q
M[N[A^>7MZ.4B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(T-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`P-0HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3@P"FUS9VED(").;W1E<R(*;7-G<W1R("+'X.SE
M\NKH(@H*(SH@<V5R=FEC97,O;V)R;W=S97(O:6YD97@N<&AP.C,V"FUS9VED
M(").;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?=&]P+FEN8SHQ,`HC+"!F
M=7IZ>0IM<V=I9"`B3F]T:6-E(@IM<V=S='(@(L?@[.7RZN@B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0HC+"!F=7IZ>0IM<V=I9"`B3F]V
M96UB97(B"FUS9W-T<B`BS>CJ[N/DX"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,#4P"B,L(&9U>GIY"FUS9VED(").=6UB97(B"FUS9W-T<B`BR.S_(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,CD*(RP@9G5Z>GD*;7-G:60@(DYU
M;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(LCL_R(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,S<S(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(W(&QI8B](
M;W)D92]&;W)M+G!H<#HQ-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`T"B,L(&9U>GIY"FUS9VED(").=6UB97(@;V8@
M8V]L=6UN<R(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D
M92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4
M=7)B82!V,2XQ*2`@(RTC+2,M(RTC7&XB"B+SX?#@\OP@\?+NZ^'E]B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,S<Q(&QI8B](;W)D92]&;W)M+G!H<#HQ
M-#(U(&QI8B](;W)D92]&;W)M+G!H<#HQ-#0W"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"B,L(&9U>GIY"FUS9VED(").
M=6UB97(@;V8@<F]W<R(*;7-G<W1R("+([/\B"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"B,L(&9U>GIY"FUS9VED(").=6UB97)S
M(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L
M:7-T+B(*;7-G<W1R("+-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA
M;F-E7U1A<VL@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM<V=S='(@(D]+(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,0HC+"!F=7IZ>0IM<V=I
M9"`B3V)J96-T(@IM<V=S='(@(M+E[.`B"@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$Q,0HC+"!F=7IZ>0IM<V=I9"`B3V)J96-T($-R96%T;W(B
M"FUS9W-T<B`BS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_R(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,3`X"B,L(&9U>GIY"FUS9VED(")/8W1A;"(*;7-G<W1R
M("+%YN7D[>7B[>XB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`Y(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S(X"B,L(&9U>GIY"FUS9VED(")/9F9I8V4B"FUS9W-T
M<B`BQ^#C[NONXN[J(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C4X"FUS9VED(")/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F
M97)E;G0N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HS-@HC+"!F=7IZ>0IM<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@
M(L_@\.[K_"(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT-@HC
M+"!F=7IZ>0IM<V=I9"`B3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*
M;7-G<W1R("+/X/#NZ_PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S"B,L(&9U>GIY"FUS
M9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S
M+B(*;7-G<W1R("+"X/@@X?#N\^?E\"#MY2#O[N3DY?#FZ.+@Y?(@[N_VZ/X@
M[^7WX/+H+B#$Z_\@[^7WX/+H(.W@YNSH\N4@0U123"M0+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ.#4U(&QI8B](;W)D92]&;W)M+G!H<#HQ.3<U"B,L
M(&9U>GIY"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N
M(@IM<V=S='(@(L+@^"!%;6%I;#HB"@HC.B!S97)V:6-E<R]S:&%R97,O961I
M="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A
M9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*
M(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]I9G)A;64N<&AP.C,Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C0P"FUS
M9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-33"!E<G)O
M<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@
M<&%R="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")/<&5N<R!T:&ES(&QI
M;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S:61E8F%R+G!H<#HQ-3$*;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`B
MS>#Q\O#NZ>KH(@H*(R!F=7IZ>2P@<&AP+69O<FUA=`HC(&9U>GIY+"!P:'`M
M9F]R;6%T"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS,2!T96UP;&%T97,O<')E
M9G,O87!P+FEN8SHQ.0HC+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O
M<B`E<R(*;7-G<W1R("+-X/'R\.[IZN@@Y.O_.B`E<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R
M960@3&ES="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4V.`HC+"!F=7IZ>0IM<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@
M(LW@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C4V.0HC+"!F=7IZ>0IM<V=I9"`B3W)G86YI<V%T:6]N86P@
M56YI="(*;7-G<W1R("+-X/'R\.[IZN@@[^[K_.?NXN#RY>O_(@H*(R!F=7IZ
M>0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,T"FUS9VED(")/<F=A
M;FEZ:6YG(@IM<V=S='(@(L[PX^#MX.GGY?`B"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA
M=&4B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R
M=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G<W1R("(B
M"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.2!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3`Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-0HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3,T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#0*;7-G:60@
M(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(L_P[O?@_R#H[?3N\.S@]NC_
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,0HC+"!F=7IZ>0IM
M<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`BS>#Q\O#NZ>KH(._N
MZ_SG[N+@\N7K_R(*"B,Z(&QI8B](;W)D92]!=71H+W!A;2YP:'`Z-SD*(RP@
M9G5Z>GD*;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA
M8FQE+B(*;7-G<W1R("+-Y?(@Y.[Q\O/O[?OU(.W@\?+P[N7J+B(*"B,Z(&QI
M8B].970O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-
M86EL(&)A8VME;F0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z,3(W-@IM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$S,C(*;7-G:60@
M(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HQ,S<T"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,S4V"FUS9VED
M(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W!H<'-H96QL+G!H<#HV.`HC+"!F=7IZ>0IM<V=I9"`B4$A0($-O9&4B
M"FUS9W-T<B`B2&]R9&4B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*;7-G
M:60@(E!(4"!3:&5L;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B4$T@3&EG
M:'0@4F%I;B(*;7-G<W1R("+"]>[D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S@*(RP@9G5Z>GD*;7-G:60@(E!-(%)A:6XB
M"FUS9W-T<B`BPNWH[.#MZ.4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS.0HC+"!F=7IZ>0IM<V=I9"`B4$T@4VAO=V5R<R(*
M;7-G<W1R("+([._N\/(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT,`HC+"!F=7IZ>0IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R
M("+([._N\/(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT,0HC+"!F=7IZ>0IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S
M='(@(LCL[^[P\B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0R"B,L(&9U>GIY"FUS9VED(")032!3=6XB"FUS9W-T<B`BR.SO
M[O#R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#,*(RP@9G5Z>GD*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(LCL[^[P
M\B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR-S0*;7-G:60@(E!/4TE8
M(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN
M<&AP.C$T.0IM<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0V"FUS
M9VED(")0861D:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ.#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0HC+"!F=7IZ>0IM<V=I9"`B4&%K
M:7-T86XB"FUS9W-T<B`BQ.#RX"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ.30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#$*(RP@9G5Z>GD*;7-G:60@(E!A;&%U
M(@IM<V=S='(@(DE-4"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3(@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R
M>2P@3V-C=7!I960B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$X,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDX"B,L(&9U>GIY"FUS9VED(")086YA
M;6$B"FUS9W-T<B`BRN#KY>WDX/#\(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$X-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDY"FUS9VED(")087!U82!.97<@1W5I
M;F5A(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.34@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#(*(RP@9G5Z>GD*;7-G:60@(E!A<F%G=6%Y(@IM
M<V=S='(@(DE-4"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,V"B,L(&9U>GIY"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S
M='(@(LKN[._@[>C_(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$X,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`R,@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY"B,Z(&QI8B].970O4TU3+W=I;E]H
M='1P+G!H<#HQ-3$@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW-PHC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT,C4*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(L_@
M\.[K_"(*"B,@9G5Z>GD*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C@R"B,L(&9U>GIY"FUS9VED(")087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F
M=6QL>2XB"FUS9W-T<B`BT>[NX?GE[>CE(//Q[^7X[>X@[O+O\.#BZ^7M[BXB
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$S,C,*(RP@9G5Z>GD*
M;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G<W1R("+/X/#NZ_PB"@HC
M.B!L:6(O2&]R9&4O075T:"]R861I=7,N<&AP.C$U,@HC+"!F=7IZ>0IM<V=I
M9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`BS>7R(.W@\?+P[N7J(.3K_R#O\.[VY>3S\/L@X//RY>WR
MZ/3HZN#VZ.@@[^X@4U%,(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P-3<*
M(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM
M<V=S='(@(L_P[O?@_R#H[?3N\.S@]NC_(@H*(R!F=7IZ>0HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@(E!A<W-W;W)D.B(*;7-G
M<W1R("+/X/#NZ_PB"@HC(&9U>GIY"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C$Q"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(L_@\.[K_"(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`S
M.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"B,L(&9U
M>GIY"FUS9VED(")087-S=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`BPN#X
M($5M86EL.B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,3D@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R"B,L(&9U
M>GIY"FUS9VED(")087-T92(*;7-G<W1R("+$X/+@(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@
M9G)O;2!C;&EP8F]A<F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0HC+"!F=7IZ>0IM<V=I9"`B4&%T
M:"(*;7-G<W1R("+$X/+@(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N
M:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*;7-G
M:60@(E!E<F-E;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+V-O;F9I<FU?8F]T=&]M+FEN8SHV"B,Z('1E;7!L871E<R]M86EN=&5N
M86YC92]M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED(")097)F;W)M($UA:6YT
M96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`BSO'S^>7Q\N+KY>WHY2#N[^7P
MX/;HZ2#O[N3DY?#FZN@B"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT,3`*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<R!O;B!L;V=I;C\B"FUS9W-T<B`BPOOO[NOMZ/+\(.[OY?#@]NCH(.[A\>OS
MYNCBX.WH_R#O\.@@XO7NY.4@XB#QZ/'RY>SS/R(*"B,Z(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,34V"FUS9VED(")097)M:7-S:6]N(@IM<V=S='(@(L_P
MX.+@(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T
M960N(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R
M+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V
M,RXQ*2`@(RTC+2,M(RTC7&XB"B+-[N+NY2#Q[N[A^>7MZ.4B"@HC(",M(RTC
M+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M
M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@
M(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S
M('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC
M+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M
M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@
M(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S
M('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC
M+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M
M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@
M(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S
M('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC
M+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M
M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@
M(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S
M('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC
M+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M
M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@
M(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S
M('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC
M+2,M(R`@<G5?4E4N<&\@*$UN96UO($@S("@R+C`N,BDI("`C+2,M(RTC+2,*
M(R!F=7IZ>0HC(",M(RTC+2,M(R`@<G5?4E4N<&\@*$UN96UO($@S("@R+C`N
M,BDI("`C+2,M(RTC+2,*(R!F=7IZ>0HC(",M(RTC+2,M(R`@<G5?4E4N<&\@
M*$AO<F1E('8S+C`N-BD@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N
M9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC
M(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M
M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T
M+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H
M24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N
M9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC
M(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M
M(RTC+2,M(PHC(",M(RTC+2,M(R`@<G5?4E4N<&\@*$UN96UO($@S("@R+C`N
M,BDI("`C+2,M(RTC+2,*(R!F=7IZ>0HC(",M(RTC+2,M(R`@<G5?4E4N<&\@
M*$UN96UO($@S("@R+C`N,BDI("`C+2,M(RTC+2,*(R!F=7IZ>0HC(",M(RTC
M+2,M(R`@<G5?4E4N<&\@*$UN96UO($@S("@R+C`N,BDI("`C+2,M(RTC+2,*
M(R!F=7IZ>0HC(",M(RTC+2,M(R`@<G5?4E4N<&\@*$UN96UO($@S("@R+C`N
M,BDI("`C+2,M(RTC+2,*(R!F=7IZ>0HC(",M(RTC+2,M(R`@<G5?4E4N<&\@
M*$AO<F1E('8S+C`N-BD@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N
M9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC
M(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M
M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T
M+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H
M24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N
M9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC
M(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M
M(RTC+2,M(PHC(",M(RTC+2,M(R`@<G5?4E4N<&\@*$UN96UO($@S("@R+C`N
M,BDI("`C+2,M(RTC+2,*(R!F=7IZ>0HC(",M(RTC+2,M(R`@<G5?4E4N<&\@
M*$UN96UO($@S("@R+C`N,BDI("`C+2,M(RTC+2,*(R!F=7IZ>0HC.B!L:6(O
M5D93+W-M8BYP:'`Z-3DP"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N($1E
M;FEE9"(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-
M4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N
M9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M
M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC
M7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I
M("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0
M($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD
M:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<
M;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@
M(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@
M2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN
M(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@
M(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(
M,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU
M;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB
M"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C
M+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S
M('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M
M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*
M(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M
M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@
M=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN
M<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@
M8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB
M(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC
M+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V
M-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C
M;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M
M(RTC+2-<;B(*(LW@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_]<;B(*(B,M(RTC+2,M
M(R`@<G5?4E4N<&\@*$UN96UO($@S("@R+C`N,BDI("`C+2,M(RTC+2-<;B(*
M(LCG[.7MZ/+\(._PX.+@(.3N\?+S[^!<;B(*(B,M(RTC+2,M(R`@<G5?4E4N
M<&\@*$UN96UO($@S("@R+C`N,BDI("`C+2,M(RTC+2-<;B(*(LCG[.7MZ/+\
M(._PX.+@(.3N\?+S[^!<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$YA9R!(
M,R`H,BXP+C,I*2`@(RTC+2,M(RTC7&XB"B+(Y^SE[>CR_"#O\.#BX"#D[O'R
M\^_@7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A.86<@2#,@*#(N,"XS*2D@
M(",M(RTC+2,M(UQN(@HBR.?LY>WH\OP@[_#@XN`@Y.[Q\O/OX%QN(@HB(RTC
M+2,M(RTC("!R=5]252YP;R`H5VAU<',@,2XP+6-V<RD@(",M(RTC+2,M(UQN
M(@HBS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_UQN(@HB(RTC+2,M(RTC("!R=5]2
M52YP;R`H5VAU<',@,2XP+6-V<RD@(",M(RTC+2,M(UQN(@HBS>#Q\O#NZ>KH
M(._NZ_SG[N+@\N7K_UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H5VAU<',@
M,2XP+6-V<RD@(",M(RTC+2,M(UQN(@HBS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K
M_UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H5VAU<',@,2XP+6-V<RD@(",M
M(RTC+2,M(UQN(@HBS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_UQN(@HB(RTC+2,M
M(RTC("!R=5]252YP;R`H5VAU<',@,2XP+6-V<RD@(",M(RTC+2,M(UQN(@HB
MS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_UQN(@HB(RTC+2,M(RTC("!R=5]252YP
M;R`H2&]R9&4@=C,N,"XV*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U
M7U)5+G!O("A(;W)D92!V,RXP+C8I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M
M(R`@<G5?4E4N<&\@*%1U<F)A($@S('8R+C`N-"D@(",M(RTC+2,M(UQN(@HB
MS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_UQN(@HB(RTC+2,M(RTC("!R=5]252YP
M;R`H5'5R8F$@2#,@=C(N,"XT*2`@(RTC+2,M(RTC7&XB"B+-X/'R\.[IZN@@
M[^[K_.?NXN#RY>O_7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4=7)B82!(
M,R!V,BXP+C0I("`C+2,M(RTC+2-<;B(*(LW@\?+P[NGJZ"#O[NO\Y^[BX/+E
MZ_]<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A($@S('8R+C`N-"D@
M(",M(RTC+2,M(UQN(@HBS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_UQN(@HB(RTC
M+2,M(RTC("!R=5]252YP;R`H5'5R8F$@2#,@=C(N,"XT*2`@(RTC+2,M(RTC
M7&XB"B+-X/'R\.[IZN@@[^[K_.?NXN#RY>O_7&XB"B(C+2,M(RTC+2,@(')U
M7U)5+G!O("A4=7)B82!(,R!V,BXP+C0I("`C+2,M(RTC+2-<;B(*(LW@\?+P
M[NGJZ"#O[NO\Y^[BX/+EZ_]<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U
M<F)A($@S('8R+C`N-"D@(",M(RTC+2,M(UQN(@HBS>#Q\O#NZ>KH(._NZ_SG
M[N+@\N7K_UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XV
M*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A-;F5M;R!(
M,R`H,BXP+C(I*2`@(RTC+2,M(RTC7&XB"B+(Y^SE[>CR_"#O\.#BX"#D[O'R
M\^_@7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A-;F5M;R!(,R`H,BXP+C(I
M*2`@(RTC+2,M(RTC7&XB"B+(Y^SE[>CR_"#O\.#BX"#D[O'R\^_@7&XB"B(C
M+2,M(RTC+2,@(')U7U)5+G!O("A.86<@2#,@*#(N,"XS*2D@(",M(RTC+2,M
M(UQN(@HBR.?LY>WH\OP@[_#@XN`@Y.[Q\O/OX%QN(@HB(RTC+2,M(RTC("!R
M=5]252YP;R`H5'5R8F$@2#,@=C(N,"XT*2`@(RTC+2,M(RTC7&XB"B+-X/'R
M\.[IZN@@[^[K_.?NXN#RY>O_7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(
M;W)D92!V,RXP+C8I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N
M<&\@*%1U<F)A($@S('8R+C`N-"D@(",M(RTC+2,M(UQN(@HBS>#Q\O#NZ>KH
M(._NZ_SG[N+@\N7K_UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H5'5R8F$@
M2#,@=C(N,"XT*2`@(RTC+2,M(RTC7&XB"B+-X/'R\.[IZN@@[^[K_.?NXN#R
MY>O_7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4=7)B82!(,R!V,BXP+C0I
M("`C+2,M(RTC+2-<;B(*(LW@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_]<;B(*(B,M
M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A($@S('8R+C`N-"D@(",M(RTC+2,M
M(UQN(@HBS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_R(*"B,@9G5Z>GD*(SH@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-C$@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HQ-C0*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@(L_PX.+@(.3N\?+S
M[^`B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#D@861M:6XO<&5R;7,O
M861D8VAI;&0N<&AP.C8P"B,Z(&%D;6EN+W!E<FUS+VEN9&5X+G!H<#HR,B!A
M9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X"FUS9VED(")097)M:7-S:6]N<R!!
M9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV.`IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB
M"FUS9W-T<B`BR^CW[?OE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDX"FUS9VED(")097)U(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#8@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$W.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM
M<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM<V=S='(@
M(M+EZ^7T[NTB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@P"FUS
M9VED(")0:&]T;W,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$Y,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P,`HC+"!F=7IZ>0IM<V=I9"`B4&ET
M8V%I<FXB"FUS9W-T<B`BQ.#RX"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y
M;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@
M=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(U-C8*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!E;G1E<B!A
M(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(L+@^"!%;6%I;#HB"@HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I
M9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB
M"FUS9W-T<B`BPN+EY.CRY2#MX.?BX.WHY2#M[N+NZ2#JX/+EX^[PZ.@Z(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S,#4*(RP@9G5Z>GD*;7-G:60@(E!L
M96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(L+@^"!%
M;6%I;#HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C8T-PIM<V=I9"`B4&QE
M87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D
M87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(T-3$*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!E;G1E<B!A('9A
M;&ED('1I;64N(@IM<V=S='(@(L+@^"!%;6%I;#HB"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O=FED92!A
M('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@(L_NYN#K\^GQ\N`L
M(/'N[N'YZ/+E(/'S\OP@[_#NX>OE[/LN(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V"FUS
M9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R
M9"(*;7-G<W1R("+/[N;@Z_/I\?+@+"#BXN7DZ/+E(,+@^.@@Z.S_(._NZ_SG
M[N+@\N7K_R#H(._@\.[K_"(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]A
M9W)E96UE;G1?=&]P+FEN8SHQ,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)0
M;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N("!9;W4@35535"!A9W)E
M92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4X"FUS9VED("(B
M"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G
M<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H
M<#HW,`IM<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE
M.B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@X(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.3D*(RP@9G5Z>GD*;7-G:60@(E!O;&%N9"(*;7-G<W1R
M("+*[NSOX.WH_R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#D*
M(RP@9G5Z>GD*;7-G:60@(E!O;&QS(@IM<V=S='(@(M'BY?#M\_+\(.+QY2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3,@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$X,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#$*;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I
M9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I
M9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@(E!O<W0@
M=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@W"FUS9VED
M(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]0<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@
M4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@(E!R
M969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(R-`HC+"!F=7IZ>0IM<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R("+/
MX/#NZ_PB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C`T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR,PHC+"!F=7IZ>0IM<V=I9"`B4')E=FEE=R(*;7-G<W1R
M("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M
M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC
M+2,M(UQN(@HBS>#GX.0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*;7-G:60@(E!R979I97<@=&AE
M(&EM86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z
M(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S4V(&QI8B](;W)D92]0<F5F<R]5
M22YP:'`Z,S8P"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S='(@(L_P
MY>3[Y//YX/\@\?+PX.WH]N`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@
M(E!R:79A=&4@2V5Y(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E
M+TUE;G4N<&AP.C$V.0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R("+/\.[AZ^7L
MX#\B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C<*;7-G:60@(E!R;V)L
M96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`BSN_H\>#MZ.4@[_#NX>OE[/LB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<Q"FUS9VED(")0<F]J96-T
M<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Q-2!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C$Y,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(X,PHC
M+"!F=7IZ>0IM<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`BPOOU[N0B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+
M97DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV
M-#8*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0U"B,L(&9U>GIY"FUS9VED
M(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`BPN#XY2#O[NOM[N4@Z.S_.B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC
M+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M,@HC+"!F=7IZ>0IM<V=I9"`B46%T87(B"FUS9W-T<B`B24U0(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C8S"FUS9VED(")1=65R>2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*(RP@9G5Z>GD*;7-G:60@(E%U
M;W1A(@IM<V=S='(@(DE-4"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-C8T"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E
M9"!B:70I(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(R-C@*(RP@9G5Z>GD*;7-G:60@(E)A9&EO('-E;&5C=&EO;B(*;7-G
M<W1R("+/[NOM[N4@[N_H\>#MZ.4@[_#NX>OE[/LZ(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*(RP@9G5Z>GD*;7-G:60@
M(E)A:6XB"FUS9W-T<B`BPNWH[.#MZ.4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT-0HC+"!F=7IZ>0IM<V=I9"`B4F%I;B!%
M87)L>2(*;7-G<W1R("+"]>[D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#8*(RP@9G5Z>GD*;7-G:60@(E)A:6X@3&%T92(*
M;7-G<W1R("+"]>[D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#<*(RP@9G5Z>GD*;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S
M='(@(L+U[N0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R
M("+"]>[D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#D*(RP@9G5Z>GD*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R("+"
M]>[D(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*(RP@9G5Z>GD*;7-G:60@
M(E)A=&EO(@IM<V=S='(@(LW@\?+P[NGJZ"(*"B,@9G5Z>GD*(SH@;&EB+TAO
M<F1E+U!E<FUS+G!H<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS
M-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*;7-G:60@(E)E860B"FUS9W-T<B`B
MU^CRX/+\(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W
M"B,L(&9U>GIY"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@(M'N[N'Y
MY>WHY2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E("5S/R!4:&ES(&]P
M97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI
M<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`HC+"!F
M=7IZ>0IM<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B
MT^3@Z^CR_"#OX/#S(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T
M<B`BSN'M[N+H\OPB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDU"FUS
M9VED(")2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B
MSN'M[N+K__+\(.3H[>#LZ/?E\>KHY2#O\^WJ\OL@[.7M_CHB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S0U"FUS9VED(")2969R97-H(%!O<G1A;"!6
M:65W.B(*;7-G<W1R("+.X>WNXNO_\OP@Z.WT[O#LX/;H_CHB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z.#DX(&QI8B](;W)D92]&;W)M+G!H<#HQ,C$W(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,C,Y"B,L(&9U>GIY"FUS9VED(")296=E>"(*
M;7-G<W1R("+1X?#N\>CR_"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C,X
M"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C`X"B,L(&9U>GIY"FUS9VED(")296QO860B"FUS9W-T
M<B`BS_#N]^CRX.WM^^4B"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,3<*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(L_N]_+N
MXOOE(/'E\.+E\.`B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M.#0*;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO
M:&]R9&4I.B(*;7-G<W1R("+`Y/#E\2#QY?#BY?#@("CMX._PZ.SE\"!H='1P
M.B\O;6%I;"YR=2DB"@HC(&9U>GIY"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O961I="YI;F,Z,C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI
M;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN
M8SHQ,PIM<V=I9"`B4F5M;W9E(@IM<V=S='(@(M/DX.OH\OPB"@HC(&9U>GIY
M"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,0IM<V=I9"`B4F5M
M;W9E($)L;V-K(@IM<V=S='(@(M/DX.OH\OP@X>ONZB(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HU-3<*(RP@9G5Z>GD*;7-G:60@
M(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP
M;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]2
M52YP;R`H5'5R8F$@=C$N,2D@(",M(RTC+2,M(UQN(@HB\^'PX/+\(/'R[NOA
MY?8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C0P"B,L(&9U>GIY"FUS9VED(")296UO=F4@9F]R;6%T=&EN9R(*;7-G<W1R
M("+3Y.#KZ/+\(._@\/,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`BT^3@Z^CR_"#OX/#S
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E
M('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O
M<GDN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E
M('1H92(*;7-G<W1R("+3Y.#KZ/+\(._@\/,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(E)E
M;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0HC+"!F=7IZ
M>0IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`BT^3@Z^CR_"#OX/#S(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHU"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B
MT^3@Z^CR_"#OX/#S(@H*(SH@;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP.C$S
M.`IM<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N
M960@97)R;W)C;V1E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$T-0HC+"!F=7IZ>0IM<V=I9"`B4F5Q=65S=&5D('-E
M<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*;7-G<W1R("+`Y/#E\>#R(//B
MY>3N[.OE[>C_("5S(.WE(.W@Z>3E[2XB"@HC.B!L:6(O2&]R9&4N<&AP.C$W
M-B!L:6(O2&]R9&4N<&AP.C4Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`BS>7NX?7NY.CL^^D@[^#PX.SE\O`@)W5I9"<@
M[>4@\^K@Y^#M(.(@ZN[M].CC\_#@]NCH(.W@\?+P[N7J+B(*"B,Z(&QI8B]6
M1E,O<W%L+G!H<#HV-S@@;&EB+U9&4R]F='`N<&AP.C@V,2!L:6(O5D93+W-Q
M;%]F:6QE+G!H<#HW,S$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E
M<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("+-Y>[A]>[DZ.S[Z2#OX/#@[.7R\"`G=6ED)R#MY2#S
MZN#GX.T@XB#J[NWTZ./S\.#VZ.@@[>#Q\O#NY>HN(@H*(SH@;&EB+TAO<F1E
M+U5T:6PN<&AP.C<W-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q
M=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`BS>7NX?7NY.CL^^D@[^#PX.SE\O`@)W5I9"<@[>4@\^K@Y^#M
M(.(@ZN[M].CC\_#@]NCH(.W@\?+P[N7J+B(*"B,Z(&QI8B](;W)D92]&;W)M
M+U)E;F1E<F5R+G!H<#HS,S4*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q(&QI8B](;W)D92]&;W)M+G!H
M<#HS-#,@;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,R,`HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(M'A\.[Q
MZ/+\(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#8*(RP@9G5Z
M>GD*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(L_@\.[K_"(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W"B,L(&9U>GIY"FUS9VED
M(")297-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(L_@\.[K_"(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,S`*(RP@9G5Z>GD*;7-G:60@(E)E<W1O<F4@
M3&%S="!1=65R>2(*;7-G<W1R("+3Y.#KZ/+\(._@\/,B"@HC.B!A9&UI;B]P
M:'!S:&5L;"YP:'`Z-S$@861M:6XO8VUD<VAE;&PN<&AP.C(X(&%D;6EN+W-Q
M;'-H96QL+G!H<#HV-@IM<V=I9"`B4F5S=6QT<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E<R]P<F5F
M<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@
M(L+E\.WS\OSQ_R#J(.W@\?+P[NGJX.PB"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z,S@*(RP@9G5Z>GD*;7-G:60@(E)E='EP92!N97<@<&%S
M<W=O<F0B"FUS9W-T<B`BS^#P[NO\(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$Y-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P,@HC+"!F=7IZ>0IM<V=I9"`B4F5U
M;FEO;B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V
M,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@
M=C,N,2D@(",M(RTC+2,M(UQN(@HBT^3@Z^7M[?OE(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS
M9VED(")2979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("(B"@HC(&9U>GIY
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@(E)I8V@@5&5X
M="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R("+-X/'R\.[IZN@@XNCG\^#K_.WN
MX^X@\.7DX.KR[O#@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<P"B,L(&9U>GIY"FUS9VED(")2:6=H="(*;7-G
M<W1R("+-Z.KNX^3@(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,3`*(RP@
M9G5Z>GD*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G<W1R("+/\.CLY?`@Y^W@
M]^7MZ.DZ(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#8*(RP@9G5Z>GD*
M;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R("+/\.CLY?`@Y^W@]^7MZ.DZ
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(X"B,L(&9U>GIY"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB
M"FUS9W-T<B`BRNOE\N[W[>#_(/#@Y.CN\>+_Y_PB"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R
M("+1]N7MX/#HZ2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3@@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#(*(RP@9G5Z>GD*;7-G:60@(E)O;6%N:6$B"FUS9W-T
M<B`BRN#KY>WDX/#\(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(R-`HC+"!F=7IZ>0IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R
M("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M
M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC
M+2,M(UQN(@HB[^7PY>SE\?+H\OP@XN+E\/4B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(Q"B,L(&9U>GIY"FUS9VED(")2;W1A
M=&4@3&5F="(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D
M92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)
M35`@=C,N,2D@(",M(RTC+2,M(UQN(@HB[^7PY>SE\?+H\OP@XN+E\/4B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(W"B,L(&9U
M>GIY"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`B(@HB(RTC+2,M(RTC
M("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M
M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(N_E\.7L
MY?'RZ/+\(.+BY?#U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT.0HC+"!F=7IZ>0IM<V=I9"`B4F]W(%!R;W!E
M<G1I97,B"FUS9W-T<B`BRNOE\N[W[>#_(/#@Y.CN\>+_Y_PB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P"B,L
M(&9U>GIY"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R("+*Z^7R[O?M
MX/\@\.#DZ.[QXO_G_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`Q"B,L(&9U>GIY"FUS9VED(")2;W=S.B(*;7-G<W1R
M("+*X.OE[>3@\/PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4S"B,L(&9U>GIY"FUS9VED(")2=6QE<R(*;7-G
M<W1R("+1]N7MX/#HZ2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N
M;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@
M8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C$R,`IM<V=I9"`B4G5N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ.3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$X-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)U
M<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C`P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#@*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S"B,L(&9U>GIY"FUS9VED
M(")2=V%N9&$B"FUS9W-T<B`BRN#KY>WDX/#\(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC
M(%-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C,R,PHC+"!F=7IZ>0IM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-
M97-S86=E(@IM<V=S='(@(LWE(.SNX_,@[O+J\/OR_"#L[N3SZ_P@36%I;G1E
M;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B](;W)D92]!=71H+W-A<VPN<&AP.C@Q
M"B,L(&9U>GIY"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A
M=F%I;&%B;&4N(@IM<V=S='(@(LWE\B#D[O'R\^_M^_4@[>#Q\O#NY>HN(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4P-@HC+"!F=7IZ>0IM<V=I
M9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R("+.\N_PX.+H\OP@\>[NX?GE[>CE
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS9VED(")344P@4VAE;&PB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R.#$*;7-G:60@
M(E-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S,PIM<V=I9"`B4U-((@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O
M;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R("(B"@HC.B!L
M:6(O87!I+G!H<#HQ-3,*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B(@H*
M(R`C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(PHC
M(&9U>GIY"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C$*(RP@9G5Z>GD*;7-G:60@(E-A(@IM<V=S='(@(B(*(B,M(RTC+2,M
M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+1[O7PX.WH
M\OP@ZN#J7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4=7)B82!V,2XQ*2`@
M(RTC+2,M(RTC7&XB"B+1[O7PX.WH\OPB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C`W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")386EN="!(96QE
M;F$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@T"FUS9VED(")386EN="!+:71T<R!A;F0@3F5V:7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@W"B,L(&9U>GIY"FUS9VED(")386EN="!,=6-I82(*;7-G
M<W1R("+"]>[D(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO
M;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0T(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3,*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$U"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@
M1W)E;F%D:6YE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")386UE(&9R86UE("A?<V5L
M9BDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B4V%M;V$B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DU"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-@HC
M+"!F=7IZ>0IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R("+"[>CLX.WHY2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,38@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Y-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(E-A=&5L;&ET
M92!0<F]V:61E<B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C`Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3875D:2!!<F%B:6$B
M"FUS9W-T<B`B(@H*(R`C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@
M(",M(RTC+2,M(PHC(&9U>GIY"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]L87EO=70N:6YC.CDY"FUS9VED(")3879E(@IM<V=S='(@(M'N]?#@[>CR
M_"(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#4*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@
M(M'N]?#@[>CR_"#MX/'R\.[IZN@B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C(Q-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E
M<R(*;7-G<W1R("+1[O7PX.WH\OP@[>#Q\O#NZ>KH(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@
M(M'N]?#@[>CR_"#MX/'R\.[IZN@B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,38W"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N
M(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B
M"B)D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.CDS"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U
M<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("+-Y2#L[N/S
M(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`HC+"!F=7IZ>0IM
M<V=I9"`B4V-A='1E<F5D(%0M4W1O<FUS(@IM<V=S='(@(LCL[^[P\B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED(")396%R8V@B"FUS9W-T<B`B
MS^[H\>HB"@HC(&9U>GIY+"!P:'`M9F]R;6%T"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS,C(*(RP@9G5Z>GD*;7-G:60@(E-E87)C:"!%;F=I;F5S
M(@IM<V=S='(@(L_NZ/'J(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y-C(*
M(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R("+"^^'E\.CR
MY2#T[O#LX/(@Y.#R^SHB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#@S"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!D871E(@IM
M<V=S='(@(L+[X>7PZ/+E(/3N\.S@\B#DX/+[.B(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3DX"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!G
M<F]U<"!T;R!A9&0B"FUS9W-T<B`BPOOAY?#H\N4@].[P[.#R(.3@\OLZ(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT,PHC+"!F=7IZ>0IM<V=I
M9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@(L+[X>7PZ/+E(/3N\.S@
M\B#DX/+[.B(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C8P"FUS9VED(")396QE8W0@82!S97)V97(B"FUS9W-T<B`BPOOAY?#H
M\N4@\>7PXN7P(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-38*
M(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S='(@
M(L+[X>7PZ/+E(/3N\.S@\B#DX/+[.B(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HV-S0*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T
M<B`BPOOA\.#R_"#B\>4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C8U,`HC
M+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM
M<V=S='(@(L+[X>7PZ/+E(/3N\.S@\B#DX/+[.B(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HX-S$*(RP@9G5Z>GD*;7-G:60@(E-E
M;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`BPOOAY?#H\N4@].[P[.#R(.3@\OLZ
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-0IM
M<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`BSO+LY>WH\OP@XOOA[O`B"@HC
M.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(B(*
M(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE
M<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@
M9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B+"^^'E\.CRY2#M\^;M
M^^4@PN#L(/'H[.+NZ_L@Z.<@].[P["#B[>CG\RX@Q^#RY>P@POL@[.[FY?+E
M(/'J[N_H\.[BX/+\(.@@(@HBXO'RX.+H\OP@Z/4@XB#RY>KQ\BXB"@HC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H92!D
M871E(&1E;&EM:71E<CHB"FUS9W-T<B`BPOOAY?#H\N4@\.#GY.7KZ/+EZ_P@
M[^[KY>D@Y.#R^SHB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-`IM
M<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`BPOOAY?#H
M\N4@].[P[.#R(.3@\OLZ(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y
M<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@
M=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(L+[X>7PZ/+E(._P[O3HZ_P@Y.O_
M(.W@\?+P[NGJZ#HB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@HC
M+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB"FUS
M9W-T<B`BPOOAY?#H\N4@\.#GY.7KZ/+EZ_P@[^[KY>D@Y.#R^SHB"@HC.B!T
M96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H92!T
M:6UE(&9O<FUA=#HB"FUS9W-T<B`BPOOAY?#H\N4@[O+NX?#@YN7MZ/\@].[P
M[.#R(.+PY>SE[>@Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU
M-PIM<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N(@IM<V=S='(@
M(L+[X>7PZ/+E(.3BX"#Q[N+OX.3@_OGH]2#O[NO_+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS,3`*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C
M:&5M92XB"FUS9W-T<B`BPN#XX"#VXN7R[N+@_R#Q]>7LX"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR-3(*;7-G:60@(E-E;&5C="!Y;W5R('!R969E
M<G)E9"!L86YG=6%G93HB"FUS9W-T<B`BW^?[ZB#N\N[A\.#FY>WH_R(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")396YD
M(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(L_N\>O@\OP@\>[NX?GE[>CE(.X@
M[_#NX>OE[.4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3`T,`IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(Q,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DX"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B
M4V5N96=A;"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`X(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW,PHC+"!F=7IZ>0IM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(L?@
M[.7RZN@B"@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS
M9VED(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#(*(RP@9G5Z>GD*;7-G:60@(E-E
M<FEA;"!.=6UB97(B"FUS9W-T<B`BR.S_(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$T.0HC+"!F=7IZ>0IM<V=I9"`B4V5R=F5R(&1A=&$@
M=W)O;F<@;W(@;F]T(&%V86EL86)L92XB"FUS9W-T<B`BS>7R(.3N\?+S[^W[
M]2#MX/'R\.[EZBXB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C<*(RP@9G5Z
M>GD*;7-G:60@(E-E<W-I;VX@061M:6XB"FUS9W-T<B`B(@HB(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB
M"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C
M+2,M(RTC+2-<;B(*(LW@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_]<;B(*(B,M(RTC
M+2,M(R`@<G5?4E4N<&\@*$YA9R!(,R`H,BXP+C,I*2`@(RTC+2,M(RTC7&XB
M"B+(Y^SE[>CR_"#O\.#BX"#D[O'R\^_@7&XB"B(C+2,M(RTC+2,@(')U7U)5
M+G!O("A.86<@2#,@*#(N,"XS*2D@(",M(RTC+2,M(UQN(@HBR.?LY>WH\OP@
M[_#@XN`@Y.[Q\O/OX"(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDR"B,L(&9U>GIY"FUS9VED(")397-S:6]N($E$(&5X<&ER960N
M(@IM<V=S='(@(M'N[N'YY>WHY2(*"B,Z(&QI8B]A<&DN<&AP.C$T-0HC+"!F
M=7IZ>0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`BQ^#LY>WH\OP@[>`B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,Q.`HC+"!F=7IZ>0IM<V=I9"`B4V5T
M(@IM<V=S='(@(M+E[.`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SD*
M;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R
M('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q.`IM<V=I9"`B4V5T('5P(')E
M;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U
M<B!P;W)T86PN(@IM<V=S='(@(B(*(L3N[^[K[>CRY>O\[?OE(._N]_+NXOOE
M(/'E\.+E\.`L(.H@ZN[R[O#[["#B^R#U[O+H\N4@Z.SE\OP@Y.[Q\O/O(.CG
M(,_N\/+@Z^`N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@W"FUS9VED
M(")3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D
M871E(&]P=&EO;G,N(@IM<V=S='(@(M/Q\N#M[N+JX"#_Y_OJX"#B^^+NY.`L
M(.+PY>SE[>WNZ2#G[NW[(.@@].[P[.#RX"#N\N[A\.#FY>WH_R#B\.7LY>WH
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#$*;7-G:60@(B(*(E-E
M="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G
M92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*
M;7-G<W1R("(B"B+3\?+@[>[BZN`@[_#HZ^[FY>WH_R#O[B#S[.[K]^#MZ/XL
M(/;BY?+NXN[I(/'UY>S[(.@@[_#N]^CU(.[O]NCI(.[R[N'PX.;E[>C_(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-PIM<V=I9"`B4V5T=7`B"FUS
M9W-T<B`BS_#HZ^[FY>WH_R(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I
M;F1E>"YH=&UL.C,W"B,L(&9U>GIY"FUS9VED(")3971U<"!U<&=R861E('-C
M<FEP=',@879A:6QA8FQE(@IM<V=S='(@(LWE(.SNX_,@[O+J\/OR_"#L[N3S
MZ_P@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-S4*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I
M8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(P,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@
M(E-E>6-H96QL97,B"FUS9W-T<B`B(@H*(R`C+2,M(RTC+2,@(')U7U)5+G!O
M("A)35`@=C,N,2D@(",M(RTC+2,M(PHC(&9U>GIY"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT.3@*(RP@9G5Z>GD*;7-G:60@(E-H;W!P:6YG(@IM
M<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC
M+2,M(RTC7&XB"B+1[O7PX.WH\OP@ZN#J7&XB"B(C+2,M(RTC+2,@(')U7U)5
M+G!O("A4=7)B82!V,2XQ*2`@(RTC+2,M(RTC7&XB"B+1[O7PX.WH\OPB"@HC
M(&9U>GIY"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S"FUS
M9VED(")3:&]R="!3=6UM87)Y(@IM<V=S='(@(LKPX/+J[N4@[N'NX?GE[>CE
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-3`*;7-G:60@(E-H;W5L
M9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G
M<W1R("+.[_#EY.7KZ/+\(.'[\?+P^^4@ZNO@XNCXZ"#DZ_\@\?'[Z^[J/R(*
M"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C8W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G
M:60@(E-H;W<B"FUS9W-T<B`BS^[JX.?@\OPB"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,34U"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E
M96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*
M(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT.30*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@
M;&]G9VEN9R!I;C\B"FUS9W-T<B`BS^[JX.?[XN#R_"#H[?3N\.S@]NC^(.X@
M[_#EY/OD\_GE["#B]>[DY3\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<V
M.0IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@P,@HC+"!F=7IZ>0IM<V=I
M9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`BR.SO[O#R(@H*(R!F=7IZ>0HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,P"FUS9VED(")3:&]W('1A8FQE(&]P
M97)A=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(L_NZN#GX/+\(.SE[?X@[N_E
M\.#VZ.D@\2#RX.'KZ/;@[.@B"@HC('!H<"UF;W)M870*(R!F=7IZ>2P@<&AP
M+69O<FUA=`HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4S"B,L('!H<"UF
M;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM
M<V=S='(@(L[R[N'PX.;@\OP@[.7M_B`E<R#QZ^7BX#\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*(RP@
M9G5Z>GD*;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D
M:6%L;V<B"FUS9W-T<B`BRNOE\N[W[>#_(/#@Y.CN\>+_Y_PB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C0*
M(RP@9G5Z>GD*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA
M;&]G(@IM<V=S='(@(LKKY?+N]^W@_R#PX.3H[O'B_^?\(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8P"B,L
M(&9U>GIY"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D
M:6%L;V<B"FUS9W-T<B`BRNOE\N[W[>#_(/#@Y.CN\>+_Y_PB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*
M(RP@9G5Z>GD*;7-G:60@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA
M;&]G(@IM<V=S='(@(LKKY?+N]^W@_R#PX.3H[O'B_^?\(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$W-C<*(RP@9G5Z>GD*;7-G:60@(E-H;W<@=7!L;V%D
M(@IM<V=S='(@(LCL_R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4Q"B,L(&9U>GIY"FUS9VED(")3:&]W97)S(@IM<V=S='(@
M(LCL[^[P\B(*"B,@9G5Z>GD*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-3(*(RP@9G5Z>GD*;7-G:60@(E-H;W=E<G,@16%R;'DB
M"FUS9W-T<B`BRO#@\NKNY2#NX>[A^>7MZ.4Z(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*(RP@9G5Z>GD*;7-G:60@(E-H
M;W=E<G,@3&%T92(*;7-G<W1R("+([._N\/(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-`IM<V=I9"`B4VAO=V5R<R!I;B!T
M:&4@5FEC:6YI='DB"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+G!H<#HT.#`@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-
M86YA9V5R+G!H<#HV,3D*;7-G:60@(E-H<FEN:R(*;7-G<W1R("+1\^?H\OPB
M"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HW-S0@;&EB+TAO<F1E
M+T)L;V-K+TQA>6]U="YP:'`Z.#,V"B,Z(&QI8B](;W)D92]";&]C:R],87EO
M=70N<&AP.CDR,B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HY.#0*(SH@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,3`T-R!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+G!H<#HQ,#@W"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N
M<&AP.C$Q,38@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,3$T.0HC.B!L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.CDQ,`HC.B!L:6(O
M2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.CDW,@HC.B!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$P-3@*(SH@;&EB+TAO<F1E
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,3(P"B,Z(&QI8B](;W)D92]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z,3$X,PHC.B!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R,C,*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HQ,C4R"B,Z(&QI8B](;W)D92]";&]C:R],
M87EO=70O36%N86=E<BYP:'`Z,3(X-0IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@
M;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3$@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#4*;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V-@IM<V=I9"`B4VEG;B!U
M<"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<Q
M,PIM<V=I9"`B4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#8@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3`P(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,C$Y(&QI8B](;W)D92]&;W)M+G!H<#HQ,C0Q"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR,C4P(&QI8B](;W)D92]&;W)M+G!H<#HR.3$Y(&QI8B](;W)D92]&
M;W)M+G!H<#HS,3$R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP
M.C8U(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<R"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@T"FUS9VED(")3:7IE(@IM<V=S
M='(@(M#@Y^SE\"(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M
M7V)O='1O;2YI;F,Z.0HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E
M;F%N8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R
M("+/\.[O\_'RZ/+\(._NY.3E\.;J\R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9A:VEA(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"B,L(&9U>GIY
M"FUS9VED(")3;F]W(@IM<V=S='(@(LCL[^[P\B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V"B,L(&9U>GIY"FUS9VED(")3
M;F]W(%-H;W=E<B(*;7-G<W1R("+([._N\/(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-PHC+"!F=7IZ>0IM<V=I9"`B4VYO
M=R!3:&]W97)S(@IM<V=S='(@(LCL[^[P\B(*"B,@9G5Z>GD*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*(RP@9G5Z>GD*;7-G
M:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R("+*\.#RZN[E(.[A[N'Y
MY>WHY3HB"@HC(&9U>GIY"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4Y"B,L(&9U>GIY"FUS9VED(")3;F]W(%-H;W=E<G,@3&%T
M92(*;7-G<W1R("+*\.#RZN[E(.[A[N'YY>WHY3HB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C`R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,#4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3;VQO
M;6]N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(Q-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P-@HC+"!F=7IZ>0IM<V=I9"`B4V]M
M86QI82(*;7-G<W1R("+*X.OE[>3@\/PB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,CDQ-0HC+"!F=7IZ>0IM<V=I9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB
M"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@
M(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I
M("`C+2,M(RTC+2-<;B(*(L3EZ?'RXNCE.B(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-3D@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4X.0HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Q-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T-PHC.B!L
M:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,38V(&QI8B].970O4TU3+W=I;E]H
M='1P+G!H<#HQ.#D*(RP@9G5Z>GD*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM
M<V=S='(@(M#@X>[WZ.D@X.3PY?$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C4U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")3;W5T:"!!9G)I8V$B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@
M(E-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`Q(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S<*;7-G
M:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA
M;F1S(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M
M:7-P:&5R92(*;7-G<W1R("+>YNWNY2#O[NOS^.#PZ.4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A
M8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B
M4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G
M<W1R("(B"@HC(",M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC
M+2,M(RTC"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Q.0HC+"!F
M=7IZ>0IM<V=I9"`B4W!A8V5R(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?
M4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+1[O7PX.WH\OP@ZN#J
M7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4=7)B82!V,2XQ*2`@(RTC+2,M
M(RTC7&XB"B+1[O7PX.WH\OPB"@HC(",M(RTC+2,M(R`@<G5?4E4N<&\@*$E-
M4"!V,RXQ*2`@(RTC+2,M(RTC"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"B,L(&9U>GIY"FUS9VED
M(")3<&%C:6YG(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-
M4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+1[O7PX.WH\OP@ZN#J7&XB"B(C+2,M
M(RTC+2,@(')U7U)5+G!O("A4=7)B82!V,2XQ*2`@(RTC+2,M(RTC7&XB"B+1
M[O7PX.WH\OPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C:6YG(&%N9"!P861D:6YG(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")3<&%I;B(*;7-G<W1R("+"[>CL
MX.WHY2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#`*(RP@9G5Z
M>GD*;7-G:60@(E-P86TB"FUS9W-T<B`BPNWH[.#MZ.4B"@HC.B!S97)V:6-E
M<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R($EN
M<'5T(@IM<V=S='(@(M'OY?;HX.O\[?OE(/'H[.+NZ_LB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8R"B,L(&9U
M>GIY"FUS9VED(")3<&QI="!C96QL(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@
M<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M
M(R`@<G5?4E4N<&\@*%1U<F)A('8Q+C$I("`C+2,M(RTC+2-<;B(*(N3NX>#B
MZ/+\(/'R[NOAY?8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8V"B,L(&9U>GIY"FUS9VED(")3<&QI="!C;VQU
M;6XB"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N
M,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H5'5R8F$@
M=C$N,2D@(",M(RTC+2,M(UQN(@HBY.[AX.+H\OP@\?+NZ^'E]B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*
M(RP@9G5Z>GD*;7-G:60@(E-P;&ET(')O=R(*;7-G<W1R("(B"B(C+2,M(RTC
M+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M
M(RTC+2,@(')U7U)5+G!O("A4=7)B82!V,2XQ*2`@(RTC+2,M(RTC7&XB"B+D
M[N'@XNCR_"#Q\N[KX>7V(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T
M,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@X"B,L(&9U>GIY"FUS9VED(")3<FD@3&%N:V$B
M"FUS9W-T<B`BPO7NY"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HV-@HC+"!F=7IZ>0IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`BRN#KY>WD
MX/#\(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U.3`@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(W.3@*(RP@9G5Z>GD*;7-G:60@(E-T87)T('EE87(B"FUS9W-T
M<B`BRN#KY>WDX/#\(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M-S$*;7-G:60@(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(B(*"B,@9G5Z
M>GD*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G
M:60@(E-T871U<R(*;7-G<W1R("+1\N#R\_$B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C@P-`HC+"!F=7IZ>0IM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS
M9W-T<B`BPN#XX"#H[?3N\.S@]NC_(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU-S,*(RP@9G5Z>GD*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM
M<V=S='(@(M#@X>[WZ.D@X.3PY?$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q"FUS9VED(")3=')I:V5T:')O=6=H(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C,W"FUS9VED(")3
M=')I;F<@;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3@W-PIM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM
M<V=I9"`B4W4B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP
M.C,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@
M7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`BP.3PY?'@\B#SXN7D[NSKY>WH
M_R`E<R#MY2#MX.GDY>TN(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`BTN7LX"(*"B,@
M9G5Z>GD*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S-B!L:6(O2&]R9&4O1F]R
M;2]296YD97)E<BYP:'`Z,S$W"FUS9VED(")3=6)M:70B"FUS9W-T<B`BR/'J
MX/+\(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O('1H92!S>7-T
M96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S="!H
M87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R"B,L(&9U>GIY
M"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`BR/'JX/+\(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C$P-"!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`BT_'O
MY?CM[B(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S
M>7-T96TN(@IM<V=S='(@(L_@[^K@(%PB)7-<(B#A^^O@(//Q[^7X[>X@[^7P
MY>CLY>WNXN#MX"#B(%PB)7-<(BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T
M82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("(B
M"@HC(&9U>GIY+"!P:'`M9F]R;6%T"B,@9G5Z>GDL('!H<"UF;W)M870*(SH@
M861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L
M971E9"!<(B5S7"(N(@IM<V=S='(@(L?@[.7RZN`@)R5S)R#S\>_E^.WN(/'N
M]?#@[>7MX"(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R
M;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP
M;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]2
M52YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(L_P[N'KY>S@(._PZ"#O
M\.[Q[.[R\.4@Y^#O\.[XY>WM[N/N(._H\?SLX"XB"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@
M8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K
M=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM
M<V=S='(@(M'RX/#@_R#J[NWTZ./S\.#VZ/\@\>[U\.#MY>W@(.(@].#IZSH@
M)7,B"@HC(&9U>GIY+"!P:'`M9F]R;6%T"B,@9G5Z>GDL('!H<"UF;W)M870*
M(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6-C97-S9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`BQ^#L
MY?+JX"`G)7,G(//Q[^7X[>X@\>[U\.#MY>W@(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@
M(LWNXN#_(.KN[?3HX_/PX/;H_R#Q[O7PX.WE[>`@XCH@)7,B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C`T(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"B,L(&9U
M>GIY"FUS9VED(")3=61A;B(*;7-G<W1R("+"[>CLX.WHY2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*(RP@
M9G5Z>GD*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`BP^O@XNW@_R(*"B,Z(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HV-0HC+"!F=7IZ>0IM<V=I9"`B4W5N(%)I
M<V4B"FUS9W-T<B`BR.S_(._NZ_SG[N+@\N7K_R(*"B,Z(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HV.`HC+"!F=7IZ>0IM<V=I9"`B4W5N(%-E="(*;7-G<W1R
M("+2Y>S@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C`*;7-G:60@(E-U;FYY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,#4*(RP@9G5Z>GD*;7-G:60@(E-U;G)I<V4B
M"FUS9W-T<B`BR.S_(._NZ_SG[N+@\N7K_R(*"B,@9G5Z>GD*(SH@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS
M9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R("+"\.7L_R#B[O'U[N3@+^?@
MZN#RX"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#0*(RP@
M9G5Z>GD*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R("+([/\@[^[K_.?NXN#R
MY>O_(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P.`HC+"!F
M=7IZ>0IM<V=I9"`B4W5N<V5T(@IM<V=S='(@(M+E[.`B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`W"B,L(&9U>GIY"FUS9VED(")3=6YS
M970Z("(*;7-G<W1R("+2Y>S@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,PHC+"!F=7IZ>0IM<V=I9"`B4W5P97)S8W)I
M<'0B"FUS9W-T<B`BS^[K[>[E(.[OZ/'@[>CE.B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS.#`*(RP@9G5Z>GD*;7-G:60@(E-U<'!O<G0B"FUS
M9W-T<B`BR.SO[O#R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P-@HC+"!F=7IZ>0IM<V=I9"`B4W5R:6YA;64B"FUS
M9W-T<B`BR.S_(._NZ_SG[N+@\N7K_R(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3<U"B,L(&9U>GIY"FUS9VED(")3=7)N86UE(@IM<V=S='(@
M(LCL_R#O[NO\Y^[BX/+EZ_\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C`Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N
M($UA>65N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#@*(RP@9G5Z>GD*;7-G:60@(E-W87II;&%N
M9"(*;7-G<W1R("+*[NSOX.WH_R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-38@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*(RP@9G5Z>GD*;7-G:60@(E-Y;F,@
M;&]G(&1E;&5T960B"FUS9W-T<B`BS^[JX.?@\OP@\^3@Z^7M[?OE(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-0IM<V=I9"`B4WEN8TU,(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]344PO2V5Y=V]R9',N<&AP.CDW"FUS9VED
M(")3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3@@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(Q-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#<*
M;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Q"FUS9VED(")4
M+5-T;W)M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8R"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV,PIM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-`HC+"!F=7IZ
M>0IM<V=I9"`B5"U3=&]R;7,@16%R;'DB"FUS9W-T<B`BRO#@\NKNY2#NX>[A
M^>7MZ.4Z(@H*(SH@;&EB+TAO<F1E+T1A=&$O='-V+G!H<#HQ-C8*(RP@9G5Z
M>GD*;7-G:60@(E135B!F:6QE(@IM<V=S='(@(L?@X^[K[N+NZB(*"B,Z(&QI
M8B](;W)D92]522]486)L92YP:'`Z,3,T"B,L(&9U>GIY"FUS9VED(")486)L
M92(*;7-G<W1R("+'X./NZ^[B[NHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S"B,L(&9U>GIY"FUS9VED(")4
M86)L92!0<F]P97)T:65S(@IM<V=S='(@(LKKY?+N]^W@_R#PX.3H[O'B_^?\
M(@H*(SH@;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3<*(RP@
M9G5Z>GD*;7-G:60@(E1A8FQE(%-E="(*;7-G<W1R("+'X./NZ^[B[NHB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<R"B,L(&9U>GIY"FUS9VED(")486)L92!P<F]P97)T:65S(@IM<V=S='(@
M(LKKY?+N]^W@_R#PX.3H[O'B_^?\(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(S-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*(RP@9G5Z>GD*
M;7-G:60@(E1A:7=A;B(*;7-G<W1R("+"[>CLX.WHY2(*"B,Z(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN
M8V4@;V8@0VAI;F$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(R-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P.0HC+"!F=7IZ>0IM<V=I9"`B5&%J
M:6MI<W1A;B(*;7-G<W1R("+$X/+@(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(S-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N
M:71E9"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU"B,L(&9U>GIY"FUS9VED(")4
M87)G970Z(@IM<V=S='(@(M'N[N'YY>WHY2(*"B,Z(&-O;F9I9R]H;V]K<RYP
M:'`N9&ES=#HY.38@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X.0IM<V=I
M9"`B5&%S:W,B"FUS9W-T<B`BQ^#DX/?H(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU-S0*(RP@9G5Z>GD*;7-G:60@(E1E;&5P:&]N92!.=6UB
M97(B"FUS9W-T<B`BR.S_(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(Q,@IM<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@R"B,L('!H<"UF;W)M870*
M;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[
M)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U1E;7!L871E+G!H<#HV.34*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N
M;W0@9F]U;F0N(@IM<V=S='(@(L#D\.7QX/(@\^+EY.[LZ^7MZ/\@)7,@[>4@
M[>#IY.7M+B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y"FUS9VED(")4
M96UP;&%T92!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3(Q-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,S-`HC+"!F
M=7IZ>0IM<V=I9"`B5&5X="(*;7-G<W1R("+$X.OEY2(*"B,@9G5Z>GD*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.0IM<V=I9"`B5&5X="!/;FQY(@IM
M<V=S='(@(M+NZ_SJ[B#RY>KQ\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*(RP@9G5Z>GD*;7-G:60@(E1E
M>'0@86QI9VXB"FUS9W-T<B`BT>OEY//^^>7_(/'R\.#MZ/;@(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0HC+"!F=7IZ
M>0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R("+$X.OEY2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")4
M:&%I("A425,M-C(P*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C(T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C$*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y"B,L(&9U>GIY"FUS9VED(")4
M:&%I;&%N9"(*;7-G<W1R("+"[>CLX.WHY2(*"B,Z(&QI8B]61E,O9G1P+G!H
M<#HX-3$*(RP@9G5Z>GD*;7-G:60@(E1H92!&5%`@97AT96YS:6]N(&ES(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(LWE\B#D[O'R\^_M^_4@[>#Q\O#NY>HN
M(@H*(SH@;&EB+TAO<F1E+TAI<W1O<GDN<&AP.C4U"FUS9VED(")4:&4@2&ES
M=&]R>2!S>7-T96T@:7,@9&ES86)L960N(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]+;VQA8BYP:'`Z.3,S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!(
M;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R
M="!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@;&EB+TYE="])35-0+T)O;VLN<&AP
M.C$R.3@*(RP@9G5Z>GD*;7-G:60@(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@
M8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(L_NY._H\?P@[>4@[.[FY?(@X?OR
M_"#GX.SE[>7MX"XB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,S$*
M;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S
M=6-C97-S9G5L;'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O
M;&]R<&EC:V5R+G!H<#HR.0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA
M<R!C;&]S960N($5X:71I;F<N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]0
M97)M<RYP:'`Z,3@Y(&QI8B](;W)D92]097)M<RYP:'`Z,C`P(&QI8B](;W)D
M92]097)M<RYP:'`Z,C$Q"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,C(S(&QI
M8B](;W)D92]097)M<RYP:'`Z,C,T(&QI8B](;W)D92]097)M<RYP:'`Z,C4R
M"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,C8T(&QI8B](;W)D92]097)M<RYP
M:'`Z,S`S"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C
M;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y
M;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S4*;7-G:60@(E1H92!B;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*
M(E1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F
M="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S92XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E
M9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z,3$W,@IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D
M(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H
M92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U
M=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B
M;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R
M("(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS
M9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="YP:'`Z,3$V"FUS9VED
M(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E
M8B!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4N<&AP.C$W
M-R!L:6(O2&]R9&4N<&AP.C4Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92YP:'`Z,3<P(&QI8B](;W)D92YP:'`Z-3`Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN
M('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(B(*"B,Z(&QI8B]61E,O9FEL
M92YP:'`Z,C(V"FUS9VED(")4:&4@9FEL92!C86YN;W0@8F4@8V]P:65D(&]N
M=&\@:71S96QF+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1&%T82YP:'`Z
M,C@P"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*
M;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES
M(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*
M(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L
M96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R
M(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO
M=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O
M9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S
M:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E
M<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R;W1E
M8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V
M92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I
M;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C$P-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T+6AA;F0@<VED92!O
M;FQY(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$U
M-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@
M;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+TU$3BYP:'`Z,C`R"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@
M=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4
M:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N
M(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$X.#$*;7-G:60@(E1H92!N86UE('1O('5S92!W:&5N(&QI
M;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R("(B"@HC.B!L:6(O
M1FEL92]#4U8N<&AP.C0W-`HC+"!F=7IZ>0IM<V=I9"`B5&AE(&YU;6)E<B!O
M9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*;7-G<W1R("+=\NX@Y^W@]^7M
MZ.4@Y.[KYNWN(.'[\OP@]^CQZ^[L+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z,3(S,@IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E
M<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!R969S+G!H<#HR.#,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO
M="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M
M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]D96(N<&AP.C,R(&QI8B](;W)D92]-24U%+U9I97=E
M<B]E;G-C<FEP="YP:'`Z,S4*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS
M<&]W97)P;VEN="YP:'`Z,S(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS
M=V]R9"YP:'`Z,S(@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T
M82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G
M<W1R("(B"@HC.B!L:6(O1FEL92]#4U8N<&AP.C0X-PIM<V=I9"`B5&AE('%U
M;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED
M97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N
M9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HT
M-SD*;7-G:60@(E1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H
M87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U
M;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S
M7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`BT>7PXN7P("5S(.'[ZR#S
MY.#KY>TB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S
M879E9"XB"FUS9W-T<B`BT>7PXN7P("5S(.'[ZR#Q[N?DX.TB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU
M<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C0W,`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@
M*"5D*2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`BP.3PY?'@\B#SXN7D[NSK
MY>WH_R`E<R#MY2#MX.GDY>TN(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="YP:'`Z,S,P"B,L(&9U>GIY"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R!D
M;V5S(&YO="!E>&ES="XB"FUS9W-T<B`BP.3PY?'@\B#SXN7D[NSKY>WH_R`E
M<R#MY2#MX.GDY>TN(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C$W.0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<
M(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`BP.3PY?'@\B#SXN7D[NSKY>WH
M_R`E<R#MY2#MX.GDY>TN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,#D*
M;7-G:60@(E1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE
M('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B
M5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@
M=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]$871A+V-S=BYP:'`Z,C8R(&QI8B](;W)D92]$871A
M+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N
M;W0@8F4@<V%V960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HT.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$P
M"B,L(&9U>GIY"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`BS>7R(.3N\?+S[^W[]2#MX/'R\.[EZBXB
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N
M9"XB"FUS9W-T<B`BP.3PY?'@\B#SXN7D[NSKY>WH_R`E<R#MY2#MX.GDY>TN
M(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$W.`IM<V=I
M9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R("+-
MY?(@Y.[Q\O/O[?OU(.W@\?+P[N7J+B(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E
M+TU)344O0V]N=&5N=',N<&AP.C,T.0IM<V=I9"`B5&AE<F4@87)E(&YO('!A
M<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(M'N
M[N'YY>WHY2#B(.WEXN7P[>[L(/3N\.S@\N4@Z"#MY2#L[N;E\B#A^_+\(.[R
M[N'PX.;E[>XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30P-0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R
M<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E
M<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B
M(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I
M;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@(B(*(B,M(RTC
M+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M
M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+/
M\.[AZ^7LX"#O\.@@[_#N\>SN\O#E(.?@[_#N^.7M[>[C[B#OZ/'\[.`N(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S
M97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(B(*(B,M(RTC
M+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M
M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+/
M\.[AZ^7LX"#O\.@@[_#N\>SN\O#E(.?@[_#N^.7M[>[C[B#OZ/'\[.`N(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M
M('1H92!S>7-T96TZ("(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O
M("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5
M+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBS_#NX>OE[.`@[_#H(._P
M[O'L[O+PY2#GX._P[OCE[>WNX^X@[^CQ_.S@+B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$U.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z("5S(@IM<V=S='(@(L_PZ"#S
MY.#KY>WHZ"#GX.3@]^@@XN[G[>CJZ^@@[OCHX>KH+B(*"B,Z(&QI8B](;W)D
M92]"<F]W<V5R+G!H<#HY,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S
M('5P;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP
M:'`Z.3$U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R
M;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R
M('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B>71E<RDN
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HY,3<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H
M('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U
M<&QO861E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P
M;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(L[XZ.'JX"#O\.@@
M[O+NX?#@YN7MZ.@@_?+NZ2#WX/'RZ"#Q[N[A^>7MZ/\B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`B
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M
M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H5'5R8F$@=C$N,2D@(",M(RTC
M+2,M(UQN(@HBSOCHX>K@(._PZ"#H[._N\/+E(.3@[>W[]2XB"@HC.B!L:6(O
M2&]R9&4O1&%T82]I;6,N<&AP.C,Q"B,L(&9U>GIY"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS
M9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M
M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H5'5R8F$@=C$N,2D@
M(",M(RTC+2,M(UQN(@HBSOCHX>K@(._PZ"#H[._N\/+E(.3@[>W[]2XB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C@R"FUS9VED("(B"B)4:&5R92!W
M87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P
M<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.`HC+"!F
M=7IZ>0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@
M=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B
M"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?
M4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@
M<G5?4E4N<&\@*%1U<F)A('8Q+C$I("`C+2,M(RTC+2-<;B(*(L[XZ.'JX"#O
M\.@@Z.SO[O#RY2#DX.WM^_4N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8T,`HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N
M(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T
M<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N
M<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?
M4E4N<&\@*%1U<F)A('8Q+C$I("`C+2,M(RTC+2-<;B(*(L[XZ.'JX"#O\.@@
MZ.SO[O#RY2#DX.WM^_4N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T-2!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,C(R"B,L(&9U
M>GIY"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE
M(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*
M;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@
M(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4=7)B82!V,2XQ
M*2`@(RTC+2,M(RTC7&XB"B+.^.CAZN`@[_#H(.CL[^[P\N4@Y.#M[?OU+B(*
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*(RP@9G5Z
M>GD*;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S
M:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(L+@^"#A\.[SY^7P(.WE(._NY.3E
M\.;HXN#E\B#N[_;H_B#OY??@\N@N(,3K_R#OY??@\N@@[>#F[.CRY2!#5%),
M*U`N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*(RP@
M9G5Z>GD*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L
M:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(MWR[B#G[>#WY>WHY2#D[NOF[>X@
MX?OR_"#WZ/'K[NPN(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP
M:'`Z-3(*(RP@9G5Z>GD*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O
M(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(MWR[B#G[>#WY>WHY2#D
M[NOF[>X@X?OR_"#WZ/'K[NPN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q
M,S0*(RP@9G5Z>GD*;7-G:60@(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A
M('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R("+=\NX@Y^W@]^7MZ.4@Y.[K
MYNWN(.'[\OP@]^CQZ^[L+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N
M9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P
M.B\O(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10
M($%022(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z
M,3,T"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B
M"B)G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB
M5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G
M:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T
M97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&QI8B].
M970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H
M:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510
M('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@
M=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C
M;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI
M="DN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY.#(@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$P-C$@;&EB+TAO<F1E+T9O<FTN<&AP.C$P.3`*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,3D@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$Q.#8@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-C`*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$S,#D@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,#(@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$U-C$*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-#,@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$Y-C(@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,#D*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,S,@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(P.#(@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q-3,*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(R,C4@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,3(@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(T-30*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(V-#0@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(X,3<@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,C8*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,#0@;&EB+TAO<F1E+T9O<FTN<&AP
M.C,X,3(@;&EB+TAO<F1E+T9O<FTN<&AP.C,X,C`*;7-G:60@(E1H:7,@9FEE
M;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,#8Y"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@
M:6YT96=E<G,N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M-#(P"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R
M<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3`Y.`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN
M(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$Q,C<*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R
M('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY.3,*(RP@9G5Z>GD*;7-G:60@(E1H
M:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`BW?+N
M(.?MX/?E[>CE(.3NZ^;M[B#A^_+\(/?H\>ON["XB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C@R-0IM<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A
M:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X
M86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z-38U"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E
M;B!P<F]C97-S960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]H96QP+V%B
M;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@)7,N(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#4Y"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J
M96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA
M:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P
M=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE
M;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M34E-12]#;VYT96YT<RYP:'`Z-3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S
M*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B
M92!A="!L96%S="!O;F4N(@IM<V=S='(@(MWR[B#WZ/'K[B#MY2#L[N;E\B#A
M^_+\(.SE[?SXY2#EY.CMZ/;[+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]G
M>FEP+G!H<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S
M<R!Z:7`@86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]296=I<W1R>2YP:'`Z,3@Y"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R
M96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]0
M<F5F<R]522YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N
M=6UB97(N(@IM<V=S='(@(MWR[B#G[>#WY>WHY2#D[NOF[>X@X?OR_"#WZ/'K
M[NPN(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM
M<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I
M;VYS('=I;F1O=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,V"FUS9VED(")4:6-K
M971S(@IM<V=S='(@(L?@[_#N\?LB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C0R.2!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*
M;7-G:60@(E1I;64B"FUS9W-T<B`BQ^#C[NONXN[J(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,X.`IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G
M<W1R("(B"@HC(&9U>GIY"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PIM<V=I
M9"`B5&EM92!F;W)M870B"FUS9W-T<B`BU.[P[.#R(.[R[N'PX.;E[>C_(@H*
M(R!F=7IZ>0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4S-0HC+"!F=7IZ>0IM
M<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`BS^[K[>[E(.[OZ/'@[>CE
M(._P[N'KY>S[.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]"
M;&]C:R]I9G)A;64N<&AP.C(P"FUS9VED(")4:71L92(*;7-G<W1R("+'X./N
MZ^[B[NHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED(")4
M;R(*;7-G<W1R("+*[NSS(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C8U,@IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET
M96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-
M86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`BU_+NX?L@XOOA
M\.#R_"#MY?'J[NO\ZNX@_>OE[.7M\N[B+"#SY.7PYNCBX.GRY2#MX.;@\N[I
M(.KKX.+HYO,@0W1R;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS,#`*(RP@9G5Z>GD*;7-G:60@(E1O9&%Y(@IM<V=S='(@(LKN[/,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(X"FUS
M9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(R,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.0HC+"!F=7IZ
M>0IM<V=I9"`B5&]G;R(*;7-G<W1R("+*[NSS(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(R-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA
M=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S`R"B,L(&9U>GIY"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R("+*X.OE[>3@
M\/PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$P"B,L(&9U>GIY"FUS9VED(")4;VYG82(*;7-G<W1R("+*[NSS(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<W"B,L(&9U>GIY"FUS9VED(")4;W`B"FUS9W-T<B`BRN[L\R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@
M(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(S,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5')I;FED
M860@86YD(%1O8F%G;R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3<Y-`IM<V=I9"`B5')U92!O<B!F86QS92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED
M(")4=2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(X
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=6YI<VEA(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(R.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3$*;7-G:60@(E1U<FME>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y,0IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q,`HC+"!F=7IZ>0IM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@
M(L_QY>+D[NWH["(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD
M<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,S(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S$*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO:6-E
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(U.`IM<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A
M;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T,0IM<V=I9"`B55),(&9O<B!Y
M;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3<*
M(RP@9G5Z>GD*;7-G:60@(E523#HB"FUS9W-T<B`B55),(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(S-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,@HC+"!F=7IZ
M>0IM<V=I9"`B56=A;F1A(@IM<V=S='(@(LK@Z^7MY.#P_"(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(S,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*(RP@9G5Z
M>GD*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`BR.S_(@H*(SH@;&EB+U9&4R]F
M:6QE+G!H<#HT,3D*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@
M5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ
M_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N
M<&AP.CDV"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M
M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R("(B"@HC.B!L:6(O5D93
M+V9T<"YP:'`Z,SDS"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB
M"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N
M["XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,Y,B!L:6(O5D93+VUU<W%L+G!H
M<#HT-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C
M:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@
M(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@
M;&EB+U9&4R]F='`N<&AP.C<X-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`BS>7B[N?L[N;M
M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O5D93+V9T
M<"YP:'`Z,C,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7-<(BXB"FUS9W-T<B`BS>7B[N?L
M[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O5D93
M+V9I;&4N<&AP.C8Y-2!L:6(O5D93+W-Q;"YP:'`Z,3`R."!L:6(O5D93+W-Q
M;%]F:6QE+G!H<#HX-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB+B(*;7-G<W1R
M("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z
M(&QI8B](;W)D92]!=71H+W-Q;"YP:'`Z-#,Y"FUS9VED(")5;F%B;&4@=&\@
M8V]N;F5C="!T;R!344P@<V5R=F5R+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'N
MY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B]61E,O9G1P+G!H
M<#HX-S`*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@
M4U-,+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E
M\.+E\.[L+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C,R(&QI8B]61E,O9FEL
M92YP:'`Z,C,W(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(P-`HC.B!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HR,#D@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C$W"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T
M<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC
M.B!L:6(O5D93+V9T<"YP:'`Z,S<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*
M;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L
M+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S8Q(&QI8B]61E,O;75S<6PN<&AP
M.C(U."!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR-C0*(RP@9G5Z>GD*;7-G:60@
M(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`BS>7B
M[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O
M5D93+VUU<W%L+G!H<#HQ,C0*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C
M<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\
M\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C(Y,`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!6
M1E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH
M\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(W
M,@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@
M9FEL92XB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#Q
MY?#BY?#N["XB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O=&%R+G!H<#HW-B!L
M:6(O2&]R9&4O0V]M<')E<W,O9WII<"YP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@
M(E5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N(@IM<V=S='(@(LWEXN[G[.[F
M[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]S
M;6(N<&AP.C(R."!L:6(O5D93+V9T<"YP:'`Z,S`S"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I
M<F5C=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[E
MY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM
M<V=S='(@(B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@=C(N
M,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(
M;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@
M8V]M<&5N9&EU;2YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC
M+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XS*2`@(RTC+2,M(RTC7&XB
M"B+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+EQN(@HB
M(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XS*2`@(RTC+2,M(RTC
M7&XB"B+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+EQN
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XS*2`@(RTC+2,M
M(RTC7&XB"B+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L
M+EQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XS*2`@(RTC
M+2,M(RTC7&XB"B+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E
M\.[L+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S,X(&QI8B]61E,O<W%L+G!H
M<#HS.34@;&EB+U9&4R]M=7-Q;"YP:'`Z,S$Q"B,Z(&QI8B]61E,O<W%L7V9I
M;&4N<&AP.C,T,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS
M9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB
M"@HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS-38@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,S8P"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(LWEXN[G[.[F[>X@
M\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]F:6QE
M+G!H<#HS-#0@;&EB+U9&4R]M=7-Q;"YP:'`Z,S(R(&QI8B]61E,O;75S<6PN
M<&AP.C,S-0HC.B!L:6(O5D93+VUU<W%L+G!H<#HS-#,@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z,S4R"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\
M\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C0R,"!L
M:6(O5D93+W-Q;"YP:'`Z-#,R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R
M("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z
M(&QI8B]61E,O9G1P+G!H<#HR,3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z
M(&QI8B]61E,O9FEL92YP:'`Z,S$P(&QI8B]61E,O<W%L+G!H<#HR.3$@;&EB
M+U9&4R]M=7-Q;"YP:'`Z,38W"B,Z(&QI8B]61E,O;75S<6PN<&AP.C$X,"!L
M:6(O5D93+VUU<W%L+G!H<#HQ.#<@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,SDQ
M"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,Y.0HC+"!F=7IZ>0IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS9W-T<B`BS>7B[N?L[N;M
M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O5D93+W-M
M8BYP:'`Z,C0X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("+-Y>+NY^SN
MYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B]61E,O
M<W%L+G!H<#HT,#D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`BS>7B
M[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O
M5D93+V9T<"YP:'`Z.#,T"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5T
M97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R("+-Y>+NY^SNYNWN
M(/'N]?#@[>CR_"#S\?+@[>[BZN@@XB#QY?'QZ.@N(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HV,#0*;7-G:60@(E5N86)L92!T;R!E>'1R86-T
M(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B(@H*(SH@;&EB+TYE="])
M35-0+G!H<#HT,S<@;&EB+TYE="])35-0+T%U=&@N<&AP.C$R,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O
M9B`E<RXB"FUS9W-T<B`BS>7B[N?L[N;M[B#GX./P\^?H\OP@[N_PY>3EZ^7M
MZ.4@)7,N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR,#,@;&EB+U9&4R]F:6QE
M+G!H<#HR,#@@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3<T"B,Z(&QI8B]61E,O
M<W%L7V9I;&4N<&AP.C$W.0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&UO
M=F4@5D93(&9I;&4N(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@
M\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]S;6(N<&AP.CDS(&QI8B]6
M1E,O<VUB+G!H<#HQ,#8@;&EB+U9&4R]S;6(N<&AP.C8U,@HC.B!L:6(O5D93
M+V9T<"YP:'`Z.3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BS>7B[N?L[N;M
M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O5D93+V9I
M;&4N<&AP.C(X-"!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ,S@@;&EB+U9&4R]S
M<6Q?9FEL92YP:'`Z,30Q"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@;W!E
M;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q
M[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O5D93+V9I;&4N
M<&AP.C@S(&QI8B]61E,O9FEL92YP:'`Z,3,W(&QI8B]61E,O<W%L7V9I;&4N
M<&AP.C<V"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL
M92XB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#B
MY?#N["XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HT-0HC
M+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H
M:79E+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E
M\.+E\.[L+B(*"B,Z(&QI8B]61E,N<&AP.C@U-@HC+"!F=7IZ>0IM<V=I9"`B
M56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB
M"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N
M["XB"@HC.B!L:6(O5D93+G!H<#HX.#<*(RP@9G5Z>GD*;7-G:60@(E5N86)L
M92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM
M<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN
M(@H*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`B
MS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L
M:6(O5D93+V9I;&4N<&AP.C8W-@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O
M(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R("+-Y>+NY^SN
MYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z,3$P-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D
M>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z
M,S`Q"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E
M8W1O<GDN(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@
M\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C,S,@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T
M;W)Y.B`E<RXB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-1
M3"#QY?#BY?#N["XB"@HC.B!L:6(O5D93+W-M8BYP:'`Z,C<Q(&QI8B]61E,O
M9G1P+G!H<#HS-#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+-Y>+NY^SN
MYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B]61E,O
M9FEL92YP:'`Z-C$W(&QI8B]61E,O;75S<6PN<&AP.C(R.0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E
M<R\E<RXB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#Q
MY?#BY?#N["XB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,S(V(&QI8B]61E,O;75S
M<6PN<&AP.C(Q,R!L:6(O5D93+VUU<W%L+G!H<#HT-3(*(SH@;&EB+U9&4R]S
M<6Q?9FEL92YP:'`Z,CDS(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,P.0HC+"!F
M=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T
M<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC
M.B!L:6(O5D93+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,`HC+"!F=7IZ>0IM
M<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@(LWEXN[G
M[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L92!T
M;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(MWR[O(@
MY.[J\^SE[?(@5V]R9"#MY2#L[N;E\B#A^_+\(._E\.7BY>3E[2XB"@HC.B!L
M:6(O5D93+V9T<"YP:'`Z,34T(&QI8B]61E,O9G1P+G!H<#HQ-3<*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL
M92!<(B5S7"(N(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!3
M44P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ.#8*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A
M:6QE9"DN(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@
M\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR.#@@;&EB+U9&4R]S
M<6Q?9FEL92YP:'`Z,30V(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$U,0HC+"!F
M=7IZ>0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM
M<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN
M(@H*(SH@;&EB+U9&4RYP:'`Z.#8R"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@
M=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N(@IM
M<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,`HC+"!F=7IZ>0IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(L?@X^[K[N+N
MZB(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@
M0VAA;F=E<R(*;7-G<W1R("+.\NSE[>CR_"#HY^SE[>7MZ/\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S"B,L(&9U>GIY
M"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("+3Y.#K
MZ/+\(._@\/,B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,C(S(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.3`*;7-G:60@
M(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO
M;CH@(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HR,3D@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,0HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<X(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#0*;7-G:60@(E5N97AP96-T960@
M<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R("(B"@HC(&9U>GIY
M"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q"FUS
M9VED(")5;F9I;&5D(@IM<V=S='(@(L_S\?+NZ2(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DR"FUS9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,S0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-38*;7-G:60@(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S@@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(S-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM
M<V=I9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(T,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI
M=&5D(%-T871E<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C,Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S
M($UI;F]R($]U=&QY:6YG($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C8R"FUS9VED(")5;FET<R(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,CD@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z-#,P"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T
M9WHN<&AP.C4X"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N
M(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN
M;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#<*(RP@9G5Z>GD*
M;7-G:60@(E5N:VYO=VX@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(LW@
M\?+P[NGJZ"(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDQ"B,L(&9U>GIY"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A<W-W
M;W)D+B(*;7-G<W1R("+/[N;@Z_/I\?+@+"#BXN7DZ/+E(,+@^.@@Z.S_(._N
MZ_SG[N+@\N7K_R#H(._@\.[K_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.`HC+"!F=7IZ>0IM<V=I9"`B
M56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B"FUS9W-T<B`B(@HB(RTC+2,M
M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC
M+2,M(RTC("!R=5]252YP;R`H5'5R8F$@=C$N,2D@(",M(RTC+2,M(UQN(@HB
M\^'PX/+\(/'R[NOAY?8B"@HC.B!L:6(O2&]R9&4O261E;G1I='DN<&AP.C,P
M,@HC+"!F=7IZ>0IM<V=I9"`B56YN86UE9"(*;7-G<W1R("+([/\@[^[K_.?N
MXN#RY>O_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T
M(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*
M(G-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC
M86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W
M('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@R"B,L(&9U>GIY"FUS9VED(")5;G-E="!C;VQO<B(*
M;7-G<W1R("+(\>_NZ_SG[N+@\OP@Y^W@]^7MZ.4@[^X@\^SNZ_?@[>C^(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV.#<@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HY,C<*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HY,S,*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R("(B
M"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,3DW('1E;7!L
M871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS
M9W-T<B`BS_#H[.7MZ/+\(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHR.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B57!D871E
M("5S(@IM<V=S='(@(M'N]?#@[>CR_"#MX/'R\.[IZN@B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"B,L(&9U>GIY"FUS9VED(")5
M<&1A=&4@=7-E<B(*;7-G<W1R("+$[N'@XNCR_"#OX/#S(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E<G9I
M8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E5P9&%T960@7"(E<UPB+B(*;7-G<W1R("+1[O7PX.WH\OP@[>#Q
M\O#NZ>KH(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#,*;7-G:60@
M(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ-S@@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$Y.`HC+"!F=7IZ>0IM<V=I9"`B57!L;V%D(@IM<V=S='(@
M(B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@
M(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@
M2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN
M(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@
M(RTC+2,M(RTC7&XB"B+/\.[WZ/+@[>W[Y5QN(@HB(RTC+2,M(RTC("!R=5]2
M52YP;R`H2&]R9&4@=C,N,"XV*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@
M(')U7U)5+G!O("A(;W)D92!V,RXP+C8I("`C+2,M(RTC+2-<;B(*(B,M(RTC
M+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N-BD@(",M(RTC+2,M(UQN(@HB
M(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XV*2`@(RTC+2,M(RTC
M7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,RXP+C8I("`C+2,M
M(RTC+2-<;B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#8*;7-G:60@
M(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@
M<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(P"FUS9VED(")5<'!E<B!L871I
M;B!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*(RP@9G5Z>GD*;7-G:60@
M(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`BR.S_(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(T,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,PHC+"!F=7IZ
M>0IM<V=I9"`B57)U9W5A>2(*;7-G<W1R("))35`B"@HC.B!L:6(O2&]R9&4O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(M+EZO/YY>4@
MXO#E[/\B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X
M"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,C<*;7-G:60@(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I
M9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM<V=S='(@(B(*(LCQ[^[K_.?S
MY?+Q_R#E\>OH(.+@^.@@Z.S_+^_@\.[K_"#DZ_\@24U34"#QY?#BY?#@(.[R
MZ^CWX/[R\?\@[O(@\N7J\_GH]2(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHR,0IM<V=I9"`B57-E<B(*;7-G<W1R("+/
M[NO\Y^[BX/+EZ_PB"@HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C<W-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D
M(&9O<B`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S"FUS
M9VED(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]0<F5F<R]522YP:'`Z,C0U"FUS9VED(")5<V5R($]P=&EO;G,B"FUS
M9W-T<B`BS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_R(*"B,Z('-I9VYU<"YP:'`Z
M-C(*(RP@9G5Z>GD*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@
M(LW@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_\B"@HC.B!S:6=N=7`N<&AP.C(R"FUS
M9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@
M=&AI<R!S:71E+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-#8Y"B,L(&9U>GIY"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD
M(@IM<V=S='(@(L[R[.7MZ/+\(.CG[.7MY>WH_R(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4S-B!L:6(O3F5T+U--4R]V;V1A9F]N
M96ET86QY7W-M='`N<&AP.CDX"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,3DX(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ-3`*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S,@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHW,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E
M+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS9W-T<B`BR.S_(._NZ_SG[N+@
M\N7K_R(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@86QR96%D
M>2!E>&ES=',N(@IM<V=S='(@(L_@[^K@(%PB)7-<(B#SYN4@\?/YY?'RXO/E
M\B(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@W
M"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`BR.S_(._NZ_SG[N+@\N7K_R(*
M"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`IM<V=I
M9"`B57-E<FYA;64Z("(*;7-G<W1R("+([/\@[^[K_.?NXN#RY>O_(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@
M:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(T,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-`HC+"!F=7IZ>0IM<V=I9"`B
M57IB96MI<W1A;B(*;7-G<W1R("+$X/+@(@H*(SH@;&EB+U9&4R]F:6QE+G!H
M<#HQ-S`@;&EB+U9&4R]F:6QE+G!H<#HR-C(*(RP@9G5Z>GD*;7-G:60@(E9&
M4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(L#D\.7QX/(@
M\^+EY.[LZ^7MZ/\@)7,@[>4@[>#IY.7M+B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ,C`*(RP@9G5Z>GD*;7-G:60@(E9A8V%T:6]N(@IM<V=S
M='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M
M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC
M+2,M(RTC7&XB"B+$Y>GQ\N+HY2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX
M-S`*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G
M:60@(E9A;&ED:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU.3<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR-34*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX-C`@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$Q.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@
M;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,C0X(&QI8B](;W)D92]&;W)M+G!H<#HR
M,C<P(&QI8B](;W)D92]&;W)M+G!H<#HR,S(P"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR.3$W(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y
M"B,L(&9U>GIY"FUS9VED(")686QU97,B"FUS9W-T<B`BQ^#LY?+JZ"(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,3$S(&QI8B](;W)D92]&;W)M+G!H<#HR
M,3DP"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T.2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C,S"B,L(&9U>GIY"FUS9VED(")687)I86)L92(*
M;7-G<W1R("+'X./NZ^[B[NHB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C0U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")696YE>G5E;&$B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR,3@*;7-G:60@
M(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@
M8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C<P,0HC+"!F=7IZ>0IM<V=I9"`B5F5R<VEO;B(*
M;7-G<W1R("+"[>CLX.WHY2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR,C@*(RP@9G5Z>GD*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R
M("+"[>CLX.WHY2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#,*(RP@9G5Z>GD*;7-G:60@(E9E<G1I8V%L(&%L
M:6=N(@IM<V=S='(@(M'KY>3S_OGE_R#Q\O#@[>CVX"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*(RP@9G5Z>GD*;7-G
M:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`BT>OEY//^^>7_(/'R\.#M
MZ/;@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX,PHC+"!F=7IZ>0IM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(M'KY>3S
M_OGE_R#Q\O#@[>CVX"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")697)Y($AI9V@B"FUS9W-T
M<B`BS>CJ[N/DX"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#@@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,38*(RP@9G5Z>GD*;7-G:60@(E9I970@3F%M(@IM<V=S
M='(@(LCL_R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS"FUS9VED(")6
M:65T;F%M97-E("A625-#24DI(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-
M24U%+T-O;G1E;G1S+G!H<#HY-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE
M=R`E<R(*;7-G<W1R("+/\.[Q[.[R\"`E<R(*"B,Z(&QI8B]";&]C:R]I9G)A
M;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B"FUS
M9W-T<B`BS^[JX.?@\OP@XN7A+?'R\.#MZ/;S(@H*(SH@;&EB+TAO<F1E+TU)
M344O0V]N=&5N=',N<&AP.C@R.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5FEE=R!A<R`E<R(*;7-G<W1R("+/\.[Q[.[R\"`E<R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR-#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(T,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@
M(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR-#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(T-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@
M(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-3(*;7-G:60@(E9I<VEB:6QI='DZ("(*
M;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N
M<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL
M92YP:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.
M1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@
M(B(*"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G:60@(E=)
M3B!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C4P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")786QL:7,@86YD($9U
M='5N82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+VAT;6PN<&AP.C$R,2!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#,*;7-G:60@
M(E=A<FYI;F<B"FUS9W-T<B`BPNWH[.#MZ.4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@
M(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C0Q-@IM<V=I9"`B5V5A=&AE<B!D871A('!R;W9I
M9&5D(&)Y(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX.38*
M;7-G:60@(E=E871H97(N8V]M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C,V"FUS9VED(")796(B"FUS9W-T<B`BPN7A(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S.0IM<V=I9"`B5V5B(%-I=&4B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I
M9"`B5V5E:VQY(@IM<V=S='(@(L7FY>WEY.7K_.WN(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+VUO8FEL92YP:'`Z,C@*(RP@9G5Z>GD*;7-G:60@(E=E;&-O;64B
M"FUS9W-T<B`BQ.[A\.X@[^[FX.ONXN#R_"P@)7,B"@HC.B!T96UP;&%T97,O
M;&]G:6XO;6]B:6QE+FEN8SHT('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R
M("+$[N'P[B#O[N;@Z^[BX/+\(.(@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO
M;6]B:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`BQ.[A\.X@
M[^[FX.ONXN#R_"P@)7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM
M<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y
M+3$U*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T
M<B`B(@H*(R!F=7IZ>2P@<&AP+69O<FUA=`HC(&9U>GIY+"!P:'`M9F]R;6%T
M"B,@9G5Z>GDL('!H<"UF;W)M870*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0T,0IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA
M>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`BU_+N(.[R[N'PX.;@\OP@[^[QZ^4@
MXO7NY.`@XB#QZ/'RY>SS.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N
M:6YC.C$T"FUS9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R
M/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ
M-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V
M,@IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM
M<V=S='(@(M3@Y^`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,V"FUS
M9VED(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X
M="!E9&ET;W(N(@IM<V=S='(@(LK@ZNCE(.[O]NCH(.'SY//R(.3N\?+S[^W[
M(.(@XNCG\^#K_.WN["#PY>3@ZO+N\.4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T"B,L(&9U>GIY"FUS9VED
M(")7:61T:"(*;7-G<W1R("+"[>CLX.WHY2(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HS,3$T"FUS9VED(")7:61T:"!I;B!#4U,@=6YI=',B"FUS9W-T<B`B
M(@H*(R!P:'`M9F]R;6%T"B,@9G5Z>GDL('!H<"UF;W)M870*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,V,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7:61T
M:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N
M(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`BV.CPZ.W@(.SE[?X@)7,@\>OEXN`@
M*.'SY.7R(._PZ.SE[>7MX"#O\.@@\>OEY//^^>7L(.+U[N3E*2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED
M(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*(RP@9G5Z>GD*;7-G
M:60@(E=I9'1H('5N:70B"FUS9W-T<B`BPNWH[.#MZ.4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0HC+"!F=7IZ>0IM
M<V=I9"`B5VED=&@Z(@IM<V=S='(@(L+MZ.S@[>CE(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C4Q-0IM<V=I9"`B5VEK:2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Y(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V"B,L(&9U>GIY"FUS9VED(")7
M:6YD(@IM<V=S='(@(L+MZ.S@[>CE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(E=I;F0@16%R
M;'DB"FUS9W-T<B`BPNWH[.#MZ.4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C,Q"B,L(&9U>GIY"FUS9VED(")7:6YD.B`B"FUS9W-T<B`B
MPNWH[.#MZ.4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DX"FUS
M9VED(")7:7-H;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$R-"!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$V-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(M#@X>[W
MZ.D@X.3PY?$B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R("+0X.'N]^CI(/+EZ^7T
M[NTB"@HC.B!L:6(O1FEL92]#4U8N<&AP.C$Y,R!L:6(O1FEL92]#4U8N<&AP
M.C(Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE
M;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HS,S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O
M=6YD("5D+B(*;7-G<W1R("(B"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$R,0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H
M:6QE(')E861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q
M[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C0U"FUS9VED(")8+5)E9B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S($)A
M<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@17AT96YD960@2V5Y(%5S
M86=E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DV"FUS
M9VED(")8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8X,PIM<V=I9"`B6#4P
M.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@(L/#(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#4T"B,L(&9U>GIY"FUS9VED(")965E9(@IM<V=S
M='(@(L/#(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$Q,#D*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@
M(L7FY>/NY.WN(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q-PIM<V=I9"`B665M96XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV-`IM<V=I9"`B665S
M(@IM<V=S='(@(L3@(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V%G<F5E
M;65N=%]B;W1T;VTN:6YC.C8*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA
M:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C4R"FUS9VED(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^
M72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HR,S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C
M<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+G!H<#HQ-#$U"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A
M=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O261E;G1I='DN<&AP.C,P
M.`IM<V=I9"`B66]U(&-A;FYO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I
M;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$X-3D@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-SD*(RP@9G5Z>GD*
M;7-G:60@(EEO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S
M<RXB"FUS9W-T<B`BPN#X($5M86EL.B(*"B,Z(&QI8B](;W)D92]$871A+G!H
M<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M87`@
M86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R
M97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B(@H*(R!F=7IZ
M>0HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3@W"FUS9VED(")9;W4@:&%V92!B
M965N(&QO9V=E9"!O=70N(@IM<V=S='(@(L+[(.+[^.OH(.CG(/'H\?+E[/LN
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-C4*;7-G:60@(B(*(EEO=2!H
M879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S
M(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA
M=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3$Y,@HC+"!F=7IZ>0IM<V=I9"`B66]U(&AA=F4@=&\@
M96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`BPN#X($5M86EL.B(*"B,Z
M(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T
M(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92YP:'`Z-#8R"FUS9VED(")9;W4@
M;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M
M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@
M=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R("(B"B+"^R#D[NOF[?L@[N_H
M\>#R_"#O\.[AZ^7L^RP@[_#EYN3E(/?E["#Q[.[FY?+E(.[R[O'KX/+\(/'N
M[N'YY>WHY2#N(.WEZ2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E<B!T:&4@55),
M('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*;7-G:60@(EEO=2!M=7-T('-E
M;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3$Y"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@
M=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M
M92!T;R!R96UO=F4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U
M(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#8*;7-G:60@(EEO=2!M=7-T('-P96-I
M9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3,X"FUS9VED(")9;W4@;75S="!S
M<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"FUS9VED
M(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@
M(B(*"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*
M;7-G:60@(EEO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N
M=6UB97(B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDW-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER
M960N(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`BPN#XX"`E<R#QY?'Q
MZ/\@Y^#J[NWWZ.O@\?PN(,_NYN#K\^GQ\N`L(.+NZ>3H\N4@XB#QZ/'RY>SS
M(.?@[>[B[BXB"@HC(&9U>GIY"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C,X"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`B
MPN#X($5M86EL.B(*"B,@9G5Z>GD*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(Q-0IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R("+"X/@@
MX.3PY?$@[O+O\.#BZ/+EZ_\Z(@H*(R!F=7IZ>0HC(&9U>GIY"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HV-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S<@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY,@IM<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R("+"X/C@
M(.CM].[P[.#VZ/\B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3<Y"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H87,@
M8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO
M;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I
M;B!A9V%I;BXB"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@
M(L+@^.4@Z.S_.B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN
M8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E
M<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O("(*
M(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M
M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H96YT:6-A=&EO;B!B86-K96YD
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N
M:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D
M;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E
M("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDX,PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E
M(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I
M;VXN("(*(E1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G
M:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP
M.C4U"B,L(&9U>GIY"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P
M<&]R="!T:&ES(&9E871U<F4N(@IM<V=S='(@(L+@^"#A\.[SY^7P(.WE(._N
MY.3E\.;HXN#E\B#N[_;H_B#OY??@\N@N(,3K_R#OY??@\N@@[>#F[.CRY2!#
M5%),*U`N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z-#(*
M(RP@9G5Z>GD*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@
M*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R("+"X/@@X?#N\^?E\"#MY2#O[N3D
MY?#FZ.+@Y?(@[N_VZ/X@[^7WX/+H+B#$Z_\@[^7WX/+H(.W@YNSH\N4@0U12
M3"M0+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-C$*;7-G:60@(EEO
M=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@(M?@\>[B[ND@[^[_\2(*
M"B,@9G5Z>GD*(SH@<V5R=FEC97,O<')E9G,N<&AP.C$Q,0HC+"!F=7IZ>0IM
M<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N
M(@IM<V=S='(@(L+@^"#O\.[TZ.O\(._N(//L[NOWX.WH_CHB"@HC(&9U>GIY
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-C$*;7-G:60@(EEO=7(@9&5F
M875L="!I9&5N=&ET>3HB"FUS9W-T<B`BPN#X(._P[O3HZ_P@[^X@\^SNZ_?@
M[>C^.B(*"B,@9G5Z>GD*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C`T"FUS9VED(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`BPN#XY2#H
M[/\Z(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDY.0HC+"!F=7IZ>0IM<V=I
M9"`B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T<B`BPN#XZ"#MX/'R
M\.[IZN@@X?OKZ"#NX>WNXNOE[?LN(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S
M<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M4')E9G,O54DN<&AP.C$U-`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!O<'1I;VYS
M(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S
M97-S:6]N+B(*;7-G<W1R("+"X/CH(.W@\?+P[NGJZ"#A^^OH(.[A[>[BZ^7M
M^RXB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U
M<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R("+"X/CH(.W@
M\?+P[NGJZ"#A^^OH(.[A[>[BZ^7M^RXB"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@8F5E;B!R
M97-E="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@
M8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB
M<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HW
M,S,*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B
M66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`BT?+N\.[M[>CI(/'E\.+E
M\#HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4T(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*(RP@9G5Z>GD*;7-G
M:60@(EIA:7)E(@IM<V=S='(@(DAO<F1E(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(U-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]497AT+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I
M9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!R;V)L96TN<&AP.C@Y"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM<V=S
M='(@(EO1[N[A^>7MZ.4@[B#O\.[AZ^7LY5TB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D
M(%1E>'0@+2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O
M:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+G!H<#HQ.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@
M)7,@;V8@)7-=(@IM<V=S='(@(EOQ\O#NZN`@)7,@Z.<@)7-=(@H*(R!F=7IZ
M>0HC.B!L:6(O2&]R9&4N<&AP.C$U-#4@=&5M<&QA=&5S+W!O<G1A;"]M96YU
M+FEN8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(M/O\.#B
MZ^7MZ.4B"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T
M<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"B,L(&9U>GIY"FUS9VED(")?1&%T
M851R964B"FUS9W-T<B`BQ.#RX"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0HC+"!F=7IZ>0IM<V=I9"`B
M7T1E;&5T92!2;W<B"FUS9W-T<B`BT^3@Z^CR_"(*"B,@9G5Z>GD*(SH@;&EB
M+V%P:2YP:'`Z,3,S"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(L/P\^_O^R(*
M"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$W-0IM<V=I9"`B7TAE
M;'`B"FUS9W-T<B`BS^[L[OG\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S"B,L(&9U>GIY"FUS9VED(")?
M26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R("+*Z^7R[O?MX/\@\.#DZ.[Q
MXO_G_"(*"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ.30*(RP@9G5Z>GD*;7-G
M:60@(E],;V<@:6XB"FUS9W-T<B`BPO7NY"(*"B,@9G5Z>GD*(SH@;&EB+TAO
M<F1E+TUE;G4N<&AP.C$Y,`IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`BPOOU
M[N0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C0*(RP@9G5Z>GD*;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*
M;7-G<W1R("+3Y.#KZ/+\(._@\/,B"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]-
M96YU+G!H<#HQ-C0*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(LW@\?+P[NGJ
MZ"(*"B,@9G5Z>GD*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?4&5R;6ES
M<VEO;G,B"FUS9W-T<B`BS_#@XN`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*(RP@9G5Z>GD*;7-G:60@
M(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R("+3Y.#KZ/+\(._@\/,B"@HC(&9U
M>GIY"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM<V=S='(@
M(L_PZ.ONYN7MZ/\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S,*(RP@9G5Z>GD*;7-G:60@(E]486)L92!0
M<F]P97)T:65S+BXN(@IM<V=S='(@(LKKY?+N]^W@_R#PX.3H[O'B_^?\(@H*
M(R!F=7IZ>0HC.B!L:6(O87!I+G!H<#HQ,CD*;7-G:60@(E]5<V5R<R(*;7-G
M<W1R("+/[NO\Y^[BX/+EZ^@B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDR
M,`HC+"!F=7IZ>0IM<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(L#D\.7Q
M[>#_(.KMZ./@(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3,T
M"B,L(&9U>GIY"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R("+`
MY/#E\>W@_R#J[>CCX"(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3$R"B,L
M(&9U>GIY"FUS9VED(")C86QE;F1A<B(*;7-G<W1R("+*X.OE[>3@\/PB"@HC
M.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO
M="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TU)344O365S<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U
M="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z
M-3DY"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]-24U%+TUE<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S
M86=E(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A
M9V4N<&AP.C$W.`IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-30*;7-G:60@
M(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3(V"FUS9VED(")D871A(&9O
M<FUA="!E<G)O<B(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z('1E;7!L871E<R]P
M;W)T86PO961I="YI;F,Z,S`*;7-G:60@(F5D:70B"FUS9W-T<B`BS_#@XNCR
M_"(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$X,@HC+"!F=7IZ
M>0IM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S='(@(L[R[.7MZ/+\(.CG
M[.7MY>WH_R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C<R"FUS9VED(")F86QL:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]"<F]W<V5R+G!H<#HX.#$*(RP@9G5Z>GD*;7-G:60@(F9I;&4B"FUS9W-T
M<B`BQ^#C[NONXN[J(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(S.0HC+"!F=7IZ>0IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R(");\?+P[NK@
M("5S(.CG("5S72(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HR-#@*;7-G:60@(F@Z(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HS-3<*;7-G:60@(FAH(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B
M:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4V-2!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP
M.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)
M344O365S<V%G92YP:'`Z,38R"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,30V
M"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PHC+"!F
M=7IZ>0IM<V=I9"`B;&EN97-=(@IM<V=S='(@(L?@X^[K[N+NZB(*"B,Z(&QI
M8B]61E,O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*
M;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/
M+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,S8X"FUS9VED(")M;2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M4')E9G,O54DN<&AP.C(X-2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,3<P"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR-#$*(RP@9G5Z
M>GD*;7-G:60@(FYA;64B"FUS9W-T<B`BR.S_(@H*(SH@;&EB+TAO<F1E+U)0
M0RYP:'`Z,3(T"B,L(&9U>GIY"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS
M9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M
M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C
M+2,M(RTC+2-<;B(*(LWNXN[E(/'N[N'YY>WHY2(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z,3(R,`HC+"!F=7IZ>0IM<V=I9"`B;F]T('EE="!I
M;7!L96UE;G1E9"(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(
M;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O
M("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBS>[B[N4@\>[NX?GE[>CE(@H*
M(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,#0*(RP@9G5Z>GD*;7-G:60@(FYO
M=&5P860B"FUS9W-T<B`BQ^#LY?+JZ"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E;G0B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3<T
M"B,L(&9U>GIY"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R("(B
M"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C
M+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S
M('8T+C`N-"D@(",M(RTC+2,M(UQN(@HBS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K
M_UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H3F%G($@S("@R+C`N,RDI("`C
M+2,M(RTC+2-<;B(*(LCG[.7MZ/+\(._PX.+@(.3N\?+S[^!<;B(*(B,M(RTC
M+2,M(R`@<G5?4E4N<&\@*$YA9R!(,R`H,BXP+C,I*2`@(RTC+2,M(RTC7&XB
M"B+(Y^SE[>CR_"#O\.#BX"#D[O'R\^_@(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$W
M,`IM<V=I9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<T"B,L
M(&9U>GIY"FUS9VED(")R:7-I;F<B"FUS9W-T<B`BPNWH[.#MZ.4B"@HC.B!L
M:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-#(*(RP@9G5Z>GD*;7-G:60@
M(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`BS>7R(.3N\?+S[^W[]2#M
MX/'R\.[EZBXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C$P,0IM<V=I
M9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA
M($A45%`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,X-0IM<V=I9"`B<W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*(RP@9G5Z>GD*;7-G
M:60@(G-T96%D>2(*;7-G<W1R("+*X.OE[>3@\/PB"@HC.B!L:6(O2&]R9&4O
M34E-12]-97-S86=E+G!H<#HQ-3`*(RP@9G5Z>GD*;7-G:60@(G-Y<W1E;2!E
M<G)O<B(*;7-G<W1R("+N\/3NX_#@].CWY?'JX/\@[OCHX>K@(@H*(SH@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HY,C@*;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-C8*(RP@9G5Z
M>GD*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(L_NZ/'J(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,S8@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H
M<#HR-S`*(RP@9G5Z>GD*;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E
M('1O(&-O;F9I<FTB"FUS9W-T<B`BS_#N]^#_(.CM].[P[.#VZ/\B"@HC.B!A
M9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW
M.0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z(&QI8B](
M;W)D92]-24U%+U!A<G0N<&AP.C(W"FUS9VED(")U;FYA;65D(@IM<V=S='(@
M(O+EZO'R(/'N[N'YY>WH_R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-C4@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M,C,*(RP@9G5Z>GD*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S='(@(B(*(B,M
M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*
M(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB
M"B+$Y>GQ\N+HY3HB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR-#`*;7-G:60@(G<Z(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS
M9VED(")W96%T:&5R+F-O;2(*;7-G<W1R("(B"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+V=L7T53
M+G!O````````````````````````````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#8Q,S4S,"`Q,#4Q-30S,S<T,B`P,3<U,38`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````(R!(;W)D92`R+C(N-"!'
M86QI8VEA;B!T<F%N<VQA=&EO;BX*(PHC(%9E<G-I;VX@:6YI8VEA;"!D93H*
M(PHC(%)A9F%E;"!687)E;&$@/')A9F%E;"YV87)E;&%`=7-C+F5S/@HC($=U
M:6QL97)M;R!-96YD97H@/&=U:6QL94!U<V,N97,^"B,@4V5R=FEC:6\@9&4@
M871E;F-I;VX@82!U<W5A<FEO<R!E('-I<W1E;6%S"B,@56YI=F5R<VED861E
M(&1E(%-A;G1I86=O(&1E($-O;7!O<W1E;&$*(PHC(%)E=FES861A('D@8V]R
M<F5G:61A('!O<CH*(R`*(R!397)V:6-I;R!D92!N;W)M86QI>F%C:6]N(&QI
M;F=U:7-T:6-A(#QS;FQU<V-`=7-C+F5S/@HC(%5N:79E<G-I9&%D92!D92!3
M86YT:6%G;R!D92!#;VUP;W-T96QA"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0
M<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#(N,5QN(@HB4F5P;W)T+4US9VED
M+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO
M;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N
M+41A=&4Z(#(P,#,M,#@M,3D@,3,Z,S5'350K,5QN(@HB3&%S="U4<F%N<VQA
M=&]R.B!397)V:6-I;R!D92!.;W)M86QI>F%C:6]N($QI;F=U:7-T:6-A(#QS
M;FQU<V-`=7-C+F5S/EQN(@HB3&%N9W5A9V4M5&5A;3H@1V%L96=O7&XB"B)-
M24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN
M.R!C:&%R<V5T/4E33RTX.#4Y+3%<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC
M;V1I;F<Z(#AB:71<;B(*(E@M1V5N97)A=&]R.B!+0F%B96P@,"XY+C5<;B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-CD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ,S<P"B,L('!H<"UF;W)M870*;7-G:60@
M(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,S<W"B,L('!H<"UF;W)M870*;7-G:60@(B`H:6X@)7,@
M9&%Y<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C,W,PIM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C,W-0IM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,0IM<V=I9"`B
M("AY97-T97)D87DI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-38@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V
M,0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`W"FUS9VED("(@
M870@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M,C$U"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E
M8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR
M-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A;&ED
M(&-H;VEC92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+U)E9VES=')Y+G!H<#HV-3D*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E
M9VES=')Y+G!H<#HQ,#0R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<
M(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y
M+B(*;7-G<W1R("(G)7,G(&YO;B!E<W3A(&-O;F9I9W5R861O(&YO(')E>&ES
M=')O(&1E($AO<F1E+B(*"B,Z(&9R86UE=V]R:R]4<F5E+U1R964N<&AP.C$W
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E92!R96YD97)E<B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-38*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@
M9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O861D
M8VAI;&0N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@
M861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP
M:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E
M871E9#H@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F
M34(@86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C,W"B,L('!H<"UF;W)M870*;7-G:60@(B5D
M("5S(&%N9"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C(V."!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-34W"B,L('!H
M<"UF;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E
M>'!I<F5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C@U"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S
M="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-C@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S-0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!+0B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@
M3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R(")/<&5R86-I\VYS
M(&1E(&UA;G1E;65N=&\@)7,@+2!#;VYF:7)M86-I\VXB"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,34*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!3:6=N(%5P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+VUA:6YT96YA;F-E+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!4
M97)M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HT,C@@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT
M.3`*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV-3$@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,34Y(&QI8B]";&]C:R]M971A<BYP:'`Z,38U(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C,Y"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S0U(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S4Q"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%T
M("5S("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HT.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A
M9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C
M:V5D(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N
M*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R
M("(B"B)-87)Q=64@;F$@8W5A9'+M8W5L82!A(&]P97)A8VGS;B!O=2!O<&5R
M86-I\VYS('%U92!D97-E>&$@97AE8W5T87(@86=O<F$N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!I<R!R97%U:7)E9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(X-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E
M<R(*;7-G<W1R(")#861A(#4@;6EN=71O<R(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,C,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]L:7-T+FEN8SHT"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R(");;&GQ82`E<R!D92`E<UTB"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR,@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B07AE
M;F1A(&1E(&5N9&5R97IO<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N
M9&%R(@IM<V=S='(@(D-A;&5N9&%R:6\B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.CDP-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P
M860B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY
M,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]H=&UL+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,Z(%1H
M:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@
M8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@(@HB86YY(&QI;FMS(&EN(&ET(&]R
M(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN
M9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S8U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,3`*
M;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ.#@@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(BP@
M=F%R:6%B;&4@9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Y-"!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C,T.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#8Y
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,C@*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<T.0IM<V=I9"`B+2T@<V5L96-T
M("TM(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,`HC+"!F
M=7IZ>0IM<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS9W-T<B`B02!S^F$@:6YF
M;W)M86-I\VXB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3D*(RP@9G5Z>GD*
M;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(D$@<_IA(&EN9F]R;6%C
M:?-N(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T
M(&AO=7)S(@IM<V=S='(@(C(T(&AO<F%S(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U!A9V5R+G!H<#HV.0IM<V=I9"`B/%!R979I;W5S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED(")!(&1A=&%B87-E(&)A
M8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38P"B,L(&9U>GIY"FUS
M9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R("(\8CY0
M<F]D=6-I=7-E('5N(&5R<F\@9W)A=F4Z(#PO8CXB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B;&EC(%!'4"!K
M97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-C4*;7-G
M:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@
M<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$P.3<*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K
M97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#$U"FUS9VED("(B"B)!
M('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,#4*
M;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y
M<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%
M(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!
M('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE
M<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.CD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I
M9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ,@IM<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B04T@4VYO
M=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N
M:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R(")!32]032(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I
M9"`B05!)($E$(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4R"FUS
M9VED(")!8F]U="XN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<T"FUS9VED(")!8G-B;W1T;VTB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW,@IM<V=I9"`B06)S;6ED9&QE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI
M960@8W)E871I;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E
M;FEE9"!C<F5A=&EN9R!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G0@26YF
M;W)M871I;VXB"FUS9W-T<B`B02!S^F$@:6YF;W)M86-I\VXB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-S4*(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G0@
M4&%S<W=O<F0B"FUS9W-T<B`B0VAA=F4@9&4@86-C97-O(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED
M(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,S,PIM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T."!T96UP;&%T
M97,O<&]R=&%L+V%D9"YI;F,Z,30*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]A9&1C:&EL9"YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(D%D9"(*;7-G<W1R
M(")%;F1E<F5Z;R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T(&%D;6EN+V=R
M;W5P<RYP:'`Z,C(U"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY."!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDY"FUS9VED(")!9&0@0VAI;&0@4&5R
M;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI
M;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B061D($AE<F4Z(@IM<V=S='(@(D5N9&5R
M97IO(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O=7!S+G!H
M<#HR,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI
M;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!G<F]U<"!T
M;R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@
M<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34T"FUS
M9VED(")!9&0@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O961I="YI;F,Z,S0*;7-G:60@(D%D9"!N97<@;65M8F5R<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.CDU"FUS
M9VED(")!9&0@<&%I<B(*;7-G<W1R(")%;F=A9&ER('5N('!A<B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW
M,0HC+"!F=7IZ>0IM<V=I9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T
M<B`B07AE;F1A(&1E(&5N9&5R97IO<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HW.`HC+"!F=7IZ>0IM<V=I9"`B061D('1O
M(&UY(&%D9')E<W,@8F]O:R(*;7-G<W1R(")!>&5N9&$@9&4@96YD97)E>F]S
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@(D%D9"!U
M<V5R(@IM<V=S='(@(D5N9V%D:7(@=6X@<&%R(@H*(SH@861M:6XO=7-E<BYP
M:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O
M('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG
M;G5P(&EN9F]R;6%T:6]N.B`B"B(E<RXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P
M+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@
M=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B061D
M:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-S,@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,30T,0IM<V=I9"`B061D<F5S<R(*;7-G<W1R(")%;F1E
M<F5Z;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,SD*(RP@9G5Z
M>GD*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R(")!>&5N9&$@9&4@96YD
M97)E>F]S(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.30*;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R
M(&]T:&5R('5S97)S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ
M.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED(")!9&UI
M;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S0Q"B,L(&9U>GIY"FUS9VED(")!9',B"FUS9W-T<B`B16YD97)E
M>F\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4V"FUS9VED(")!9F=H86YI<W1A;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4W"B,L(&9U>GIY"FUS9VED(")!;&)A;FEA(@IM<V=S='(@
M(D%L8W5M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S`*(RP@9G5Z>GD*;7-G:60@(D%L9V5R:6$B
M"FUS9W-T<B`B06QC=6UE(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T<B`B06QC=6UE
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHQ-@HC+"!F=7IZ>0IM<V=I9"`B06QI9VXB"FUS9W-T<B`B06QC=6UE
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV
M-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R;W5P
M<RYP:'`Z,C(R"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+V1A=&%T<F5E+G!H<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S$*;7-G:60@
M(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3,T"FUS9VED(")!;&QO=R!S971T:6YG(&]F
M(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1&%T851R964O1&%T851R964O<W%L+G!H<#HU,#0*;7-G:60@(D%L<F5A9'D@
M97AI<W1S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,C,*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#<*;7-G:60@(D%L=&5R;F%T92!)
M35-0(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT.3D*;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"B,L(&9U
M>GIY"FUS9VED(")!;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R(")%
M;F1E<F5Z;R!D92!C;W)R96\@96QE8W1R\VYI8V\Z(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ-#(*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@4V%M;V$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HY-2!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@:6QL
M96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R(")/('9A;&]R('%U
M92!E<W!E8VEF:6-O=2!N;VX@Z2!VX6QI9&\B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,38W"B,L(&9U>GIY"FUS9VED(")!;B!U;FMN;W=N
M(&5R<F]R(&AA<R!O8V-U<F5D+B(*;7-G<W1R("(\8CY0<F]D=6-I=7-E('5N
M(&5R<F\@9W)A=F4Z(#PO8CXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O<G)A
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;F=U:6QL82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!;F]N
M>6UO=7,@4')O>'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4X"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*
M;7-G:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z,S4*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU."!T96UP;&%T97,O861M
M:6XO<V5T=7`O:6YD97@N:'1M;#HV"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G
M<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P
M<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$T,`IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED
M(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z.#,S"FUS9VED(")!<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#0*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS9VED
M(")!<')I;"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W
M-0IM<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@Q"FUS9VED(")!<F-H:79E($9I
M;&4@4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-C4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H
M<#HX,`IM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T
M:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<(B5S
M7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X
M"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I
M9"`B07)M96YI82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$W-@IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N
M($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,CD*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I
M;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R-0IM
M<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,Q,3,*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E
M;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B071T96UP
M="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*;7-G:60@(D%T=&5M
M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*;7-G:60@(D%T
M=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-"!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#8*;7-G:60@(D%T=')I
M8G5T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4Y"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M.0IM<V=I9"`B075S=')I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G-Q;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q
M=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U
M=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A
M8FEL:71E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)U<RYP:'`Z,3(R"FUS9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E
M<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W
M:71H('1H92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C8T"FUS9VED(")!=71H
M7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HU,0IM
M<V=I9"`B075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z,S`R"FUS9VED(")!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N
M;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!
M=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R
M($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HV,PIM<V=I9"`B075T:%]L9&%P.B!297%U:7)E
M9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES
M(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS.#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT.3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D
M871E('5S97(@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HT,#4*;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E
M<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HT-@IM
M<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB
M+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM<V=I9"`B
M075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L('!H
M<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$W
M-@IM<V=I9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E
M<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HX-3$*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I
M;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C<P"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F
M86EL960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z-S4*;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(D-A;7!O
M<R!D:7-P;_%I8FQE<SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I:F%N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I
M9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG
M<F]U;F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@Q"FUS
M9VED(")"860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@(D)A9"!K97)B
M97)O<R!U<V5R;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HT-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B
M0F%H86UA<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"86AR86EN
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<W"FUS9VED
M(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P
M"FUS9VED(")"86YG;&%D97-H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G
M:60@(D)A<F)A9&]S(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R
M+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S(&1I
M<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$Y"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*;7-G
M:60@(D)A<V5L:6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E
M;&%R=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F5L9VEU;2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QI>F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F5N:6XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS
M9VED(")":'5T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD87DB"FUS9W-T
M<B`B06YI=F5R<V%R:6\B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L
M;&5C=&EO;BYP:'`Z,S4S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")"
M;&]C:R!<(B5S7"(@;V8@87!P;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB
M"FUS9W-T<B`B3F]N('-E(&%T;W!O=2!O(&%X96YT92!D92!N;W1I9FEC86-I
M\VX@)7,N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C@Y"FUS
M9VED(")";&]C:R!3971T:6YG<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<&]R=&%L+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX"FUS9VED(")";VQD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@
M(D)O;&EV:6$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(P-0IM<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*(RP@
M9G5Z>GD*;7-G:60@(D)O<F1E<B(*;7-G<W1R(")(;W)D92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O
M<F1E<B!T:&EC:VYE<W,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*(RP@9G5Z>GD*;7-G
M:60@(D)O<F1E<G,B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED
M(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8S"FUS9VED(")";W1S=V%N82(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*;7-G
M:60@(D)O='1O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V
M970@27-L86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*(RP@9G5Z>GD*;7-G
M:60@(D)R87II;"(*;7-G<W1R(")#;W)R96\B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I
M9"`B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G
M:60@(D)U;&QE=&5D($QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I
M9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@
M(D)U<G5N9&DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0T-`HC+"!F=7IZ>0IM<V=I9"`B0TU3(@IM<V=S='(@(D-64R(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@
M(D-20R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4Y-PIM<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C,*
M;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M.#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDX-PHC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,34U"FUS9VED(")#86QE;F1A<B(*;7-G<W1R(")#86QE
M;F1A<FEO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-@IM
M<V=I9"`B0V%L;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B0V%M
M8F]D:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C`*
M;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@
M8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#86X@;F]T('=R:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,@IM<V=I9"`B0V%N)W0@861M:6YI
M<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,S4@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)S<6PN<&AP.C,Q.0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS
M9W-T<B`B1F%L;&]U(/,@8V]N96-T87(@8V\@<V5R=FED;W(@3$1!4"XB"@HC
M.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT,3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-`HC+"!F=7IZ>0IM<V=I9"`B0V%N861A(@IM<V=S='(@(D-A
M;&5N9&%R:6\B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E<BYP
M:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHV-0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM
M<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(D-A;F-E;&%R
M(&\@:6YF;W)M92!D92!P<F]B;&5M87,B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L
M971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z-#8*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU,@IM<V=I9"`B0V%N;F]T(&9I
M;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.CDQ"FUS9VED(")#
M86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$T
M"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A
M=&%4<F5E+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q
M;"YP:'`Z-C@P"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4L
M("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1&%T851R964O1&%T851R964O<W%L+G!H<#HV,#@*;7-G:60@(B(*(D-A;FYO
M="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O
M<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I
M9FEE9"!N=6UB97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A
M<&4@5F5R9&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`HC+"!F=7IZ>0IM<V=I9"`B0V%P
M=&EO;B(*;7-G<W1R(")/<&-I\VYS(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`T"FUS9VED(")#87)R:65R(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,`IM<V=I9"`B0V%T
M96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS
M9VED(")#87EM86X@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#96QL(%!H
M;VYE(@IM<V=S='(@(E1E;.EF;VYO(&WS8FEL(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0HC+"!F=7IZ>0IM
M<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(E1E;.EF;VYO(&WS8FEL
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I
M9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS9VED(")#96QL('-P
M86-I;F<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R-S0*(RP@9G5Z>GD*;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R(")496SI
M9F]N;R!M\V)I;"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED
M(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(V"FUS9VED
M(")#96YT97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V5N=')A
M;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3<Y"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U
M.2TR*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8Y.0IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Q,0IM
M<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G:60@(D-E<G1I9FEC
M871E(%!O;&EC:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`HC+"!F=7IZ
M>0IM<V=I9"`B0VAA9"(*;7-G<W1R(")487)X971A(&1E('9I<VET82`H=D-A
M<F0I(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC+"!F=7IZ>0IM<V=I9"`B0VAA
M;F=E(@IM<V=S='(@(D1E<V9A8V5R(&]S(&-A;6)I;W,B"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*;7-G:60@(D-H86YG92!9;W5R(%!A
M<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M-@IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@
M<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B
M"B)E;6%I;',N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I
M<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO
M;BX@("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(W"B,L(&9U>GIY"FUS9VED(")#:&%R(@IM<V=S='(@(E1A<GAE=&$@
M9&4@=FES:71A("AV0V%R9"DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK
M+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D-H
M:6QE(@IM<V=S='(@(E3M='5L;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS9VED
M(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-H:6YE<V4@5')A9&ET
M:6]N86P@*$)I9S4I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR
M-C@*;7-G:60@(D-H;V]S92!A('5S97)N86UE(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR.3@*;7-G:60@(D-H;V]S92!H;W<@=&\@
M9&ES<&QA>2!D871E<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO
M;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C@Y,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S
M='(@(DYO;B!S92!A=&]P;W4@;R!A>&5N=&4@9&4@;F]T:69I8V%C:?-N("5S
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T
M"B,L(&9U>GIY"FUS9VED(")#;&5A<B(*;7-G<W1R(")#86QE;F1A<FEO(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM
M<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,3(X"FUS9VED(")#;&5A<B!1=65R>2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$Q"FUS9VED
M(")#;&5A<B!U<V5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C,T"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,34*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-C`*;7-G:60@(D-L
M:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA
M=&5L;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R
M9"YP:'`Z,30V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@
M(D-L;W-E(%=I;F1O=R(*;7-G<W1R(")096-H87(@82!X86YE;&$B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(T-`IM<V=I9"`B0VQO=61S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$V
M"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3<*;7-G:60@(D-L;W5D>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@
M27-L86YD<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B
M87(N:6YC.C(S"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C<*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y
M"FUS9VED(")#;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(T"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R]#;VQL96-T:6]N+G!H<#HS,C4*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C4P,"!S97)V:6-E<R]I;6%G97,O8V]L;W)P
M:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@T-@IM<V=I9"`B0V]L;W5R
M('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-@IM<V=I9"`B0V]L
M=6UN('1I=&QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C8T"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B(@H*(SH@861M:6XO
M8VUD<VAE;&PN<&AP.C(U"B,L(&9U>GIY"FUS9VED(")#;VUM86YD(@IM<V=S
M='(@(D-O;7!A\>UA(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS9VED
M(")#;VUM86YD(%-H96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-@IM<V=I
M9"`B0V]M;6]N($YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@
M(D-O;6]R;W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R(")#
M;VUP8?'M82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,0IM<V=I9"`B
M0V]M<'5T97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR.3<*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(T.0IM<V=I9"`B0V]N9&ET:6]N<R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N
M9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,30S"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S
M>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S4*;7-G:60@
M(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z-3$*(RP@9G5Z>GD*;7-G:60@(D-O;F9I<FT@
M4&%S<W=O<F0B"FUS9W-T<B`B0VAA=F4@9&4@86-C97-O(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-@IM<V=I9"`B0V]N9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HU,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C8P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B
M0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ
M.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P
M"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N
M;F5C=&EO;B!F86EL960Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HW.3`*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E
M9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDR"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#0U"FUS9VED(")#;VYN96-T:6]N('1O($94
M4"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O:&]O:W,N
M<&AP+F1I<W0Z,3`Q-`IM<V=I9"`B0V]N=&%C=',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4S"FUS9VED
M(")#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D
M9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HU-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C8S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z-S@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O;G1E;G1S
M(&]F(%PB)7-<(B(*;7-G<W1R(")#;VYT:61O(&1E("<E<R<B"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.2!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z,S,*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C$*(RP@9G5Z>GD*;7-G:60@(D-O<'DB"FUS9W-T<B`B0V]M<&'Q
M[6$B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V.`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@
M(D-A;7!O(&EM<&]R=&%D;SH@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C$W,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$Y-0IM<V=I9"`B0V]S="!)1"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS
M9VED(")#;W-T82!2:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@
M(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z.3<V"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y
M<'0@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3`U,PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE
M<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,SDS"FUS9VED(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@
M;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD(&YO="!3+TU)344@<VEG;B!M
M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C$X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@861D(&-O;G1A8W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C$R,0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&)I
M;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(D9A;&QO=2#S(&-O;F5C=&%R
M(&-O('-E<G9I9&]R($Q$05`N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C0U-PIM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@;&1A<"!S97)V97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-#0Q"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@8V]N
M;F5C="!T;R!L9&%P('-E<G9E<B(*;7-G<W1R(")&86QL;W4@\R!C;VYE8W1A
M<B!C;R!S97)V:61O<B!,1$%0+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T
M;R!S97)V97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3$R-0IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@
M4$=0(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3(R"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)
M344@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L
M971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.#$@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.34S"FUS9VED(")#;W5L9"!N;W0@
M9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HR.#,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A
M9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@
M9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-#0V"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@
M;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y
M+G!H<#HV.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z
M,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-S$Y"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O
M;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z,3,Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB
M)7-<(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C0Q.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]4
M87-K(&UO9'5L92`E<R(*;7-G<W1R(")&86QL;R#S(&%B<FER(&\@;?-D=6QO
M(&1E('1A<F5F87,@9&4@;6%N=&5M96YT;R`E<R(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B1F%L;&\@\R!A8G)I
M<B!O(&WS9'5L;R!D92!T87)E9F%S(&1E(&UA;G1E;65N=&\@)7,B"@HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$Q(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C(S-R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-#<X"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HU,38@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C4V(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HV.3D*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R
M96%C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(D9A;&QO=2#S(&-O;F5C
M=&%R(&-O('-E<G9I9&]R($Q$05`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M3V)J96-T+G!H<#HR,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(')E860@)7,N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W
M;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H
M92`B"B)D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O
M;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U<G1H
M97(@:&5L<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S`Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,T,`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS-S<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S@S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,X.0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T
M<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,C(S"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I
M;&ET:65S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-30*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B2&]R9&4@;F]N('-E(&-O;F9I9W5R;W4@8V]R<F5C
M=&%M96YT92(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z-3D*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P
M(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E
M(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P
M(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#
M;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@
M8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@
M=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E
M(&)E;&]W('1O("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C$T,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T('-E
M87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(D9A;&QO=2#S(&-O;F5C
M=&%R(&-O('-E<G9I9&]R($Q$05`N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI
M<W0N("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG
M=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S8V"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-
M;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HQ-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N)W0@
M9VEV92!U<V5R(%PB)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE
M(&9O;&1E<B!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T,3D*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.0IM
M<V=I9"`B0V]U;G1R>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C<S"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C$P,`IM<V=I9"`B0W)E871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B
M0W)E871E(&$@;&EN:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O
M:61E;G1I='ES96QE8W0N:6YC.CDT"FUS9VED(")#<F5A=&4@82!N97<@;VYE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.CDR"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-#`*;7-G:60@
M(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S(S,`IM<V=I9"`B0W)E9&ET(&-A<F0@;G5M8F5R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")#<F]A=&EA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C(V"FUS9VED(")#=7)R96YT(#0@4&AA<V5S
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HT.`IM<V=I9"`B
M0W5R<F5N="!397-S:6]N<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM
M92YP:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E;G0@
M5&EM92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@55),(&ES
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS,PIM<V=I9"`B
M0W5R<F5N="!5<V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(U"FUS9VED(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(W-0IM<V=I9"`B0W5R<F5N
M="!C;VYD:71I;VXZ("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N
M(&QO9V]N('1O("5S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,U"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C@*;7-G:60@(D-Y<')U<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X,@IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(D-Y
M<FEL;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@T"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/
M23@M52DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WIE8V@@4F5P
M=6)L:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0U,2!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I
M9"`B1$0B"FUS9W-T<B`B1$0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,C@Q"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T
M+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N
M86YC92YP:'`Z-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(D1I87)I86UE;G1E
M(@H*(SH@861M:6XO9&%T871R964N<&AP.C8U"FUS9VED(")$871A5')E92!"
M<F]W<V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,R-SD*;7-G:60@(D1A=&%B87-E($QO;VMU<"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(S.3D*;7-G:60@(D1A=&4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G
M:60@(D1A=&4@4F5C96EV960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@P-PIM<V=I9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S(R"B,L(&9U>GIY"FUS9VED(")$
M87DB"FUS9W-T<B`B1&EA<FEA;65N=&4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE
M=&4@0V]L=6UN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0U,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$96-E;6)E<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C$V"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM
M<V=I9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,3@W(&QI8B]P<F5F<RYP:'`Z,3$W"B,L
M(&9U>GIY"FUS9VED(")$969A=6QT(@IM<V=S='(@(DED96YT:61A9&4@<')E
M9&5T97)M:6YA9&$B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHT-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHW-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!#;VQO<B(*
M;7-G<W1R(")5<V%R(&\@=F%L;W(@<&]R(&1E9F5C=&\B"@HC.B!F<F%M97=O
M<FLO261E;G1I='DO261E;G1I='DN<&AP.CDQ"FUS9VED(")$969A=6QT($ED
M96YT:71Y(@IM<V=S='(@(DED96YT:61A9&4@<')E9&5T97)M:6YA9&$B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D1E
M9F%U;'0@4VAE;&PB"FUS9W-T<B`B261E;G1I9&%D92!P<F5D971E<FUI;F%D
M82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B1&5F:6YI
M=&EO;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW,2!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C0S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHY,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,"!T96UP;&%T97,O861M:6XO=7-E
M<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M,@IM<V=I9"`B1&5L971E($-E;&PB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR,C<*;7-G:60@(D1E;&5T
M92!'<F]U<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR-#D*;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-R!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C$P,0IM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E(&-E;&PB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M,PIM<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!A9&UI;B]T
M96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R
M;F%T92!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C0R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@
M<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP
M97)M:7-S:6]N<S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E(')O
M=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I
M='DN:6YC.C$U"B,L(&9U>GIY"FUS9VED(")$96QE=&4@<V5L96-T960@:61E
M;G1I='DB"FUS9W-T<B`B261E;G1I9&%D92!P<F5D971E<FUI;F%D82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV-PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-38S"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*;7-G:60@(D1E;&EV
M97)Y('1I;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&5N;6%R
M:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`B1&5S
M8W)I8VGS;B!D;R!P<F]B;&5M82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.CDS."!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,P"B,L(&9U>GIY"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R
M(")$97-C<FEC:?-N(&-O;7!L971A.B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,3DU"FUS9VED(")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@
M;&]G9FEL92DZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,3DY"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R
M('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")297AI<W1RX7)O;G-E(&]S
M(&1E=&%L;&5S('!A<F$@;R!A9&UI;FES=')A9&]R+B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR,3D*;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$W"FUS9VED(")$97<@
M4&]I;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.30*
M;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-PIM<V=I9"`B1&5W
M('!O:6YT.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE9G0@=&\@
M<FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT('1O(&QE
M9G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G
M:60@(D1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C8V"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PIM<V=I9"`B1&ES
M<&QA>2!/<'1I;VYS(@IM<V=S='(@(D]P8VGS;G,@9&4@=FES=6%L:7IA8VGS
M;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HY-@HC+"!F=7IZ
M>0IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R(")/
M<&-I\VYS(&1E('9I<W5A;&EZ86-I\VXB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C@U"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T("A4048I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3<*(RP@9G5Z>GD*
M;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM<V=S='(@(D]P8VGS;G,@9&4@=FES
M=6%L:7IA8VGS;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HQ
M.3`*;7-G:60@(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8Y"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,@IM<V=I9"`B1&\@;F]T
M(&1E;&5T92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP
M:'`Z,C4*;7-G:60@(D1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N
M8V4N<&AP(@IM<V=S='(@(DYO;B!A8V-E9&$@9&ER96-T86UE;G1E(&$@7")M
M86EN=&5N86YC92YP:'!<(B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N
M:6YC.C$R('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$R"FUS9VED(")$
M;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF
M('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*
M;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@
M(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.CDV"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U
M;G0_(%-I9VX@=7`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.C@T-`IM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0T"B,L
M('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C(*;7-G:60@(D1O=VYL;V%D(&=E
M;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#<*;7-G:60@(D1R
M;W`@9&]W;B!L:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS-`IM<V=I9"`B1')U9W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"B,L(&9U>GIY"FUS9VED(")%+4UA
M:6PB"FUS9W-T<B`B0V]R<F5O(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E
M=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S
M97)V:6-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%
M4E(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-2!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X
M,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4P('1E;7!L871E<R]P
M;W)T86PO961I="YI;F,Z,C4*;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T<B`B
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H<#HR
M,C8*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HW-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$P,`IM<V=I9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@
M4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D
M:70N<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I
M;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O87!P
M+FEN8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,V-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A
M=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%:71H97(@96YA8FQE(&ET('1H96XZ("5S+"!O
M<B!U<V4@=&AE(&)A<VEC($A434P@=F5R<VEO;CH@)7,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%
M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,C(T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-CD*;7-G
M:60@(D5M86EL(@IM<V=S='(@(D-O<G)E;R!E;&5C='+S;FEC;R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38U('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,3`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHV.`HC+"!F=7IZ>0IM<V=I9"`B16UA:6P@061D<F5S
M<R(*;7-G<W1R(")%;F1E<F5Z;R!D92!C;W)R96\@96QE8W1R\VYI8V\Z(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DV,PIM<V=I9"`B16UA:6P@
M861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y.#D*(RP@9G5Z>GD*;7-G:60@(D5M86EL('=I
M=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(D]U=')A(&EN9F]R;6%C:?-N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3$*
M;7-G:60@(D5M86EL+71O+5--4R!'871E=V%Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR.3@*(RP@9G5Z
M>GD*;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R(")/<&-I\VYS(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R"B,L
M(&9U>GIY"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R(")396X@<F5S
M=6QT861O+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR
M-#,@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0X-`HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C8R(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HW,#4*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HQ-3`*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B4V5N
M(')E<W5L=&%D;RXB"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP
M:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T,PIM<V=I9"`B16YA8FQE(&EN
M<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X
M=#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q.`IM
M<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y."!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.#$Q"FUS9VED(")%;F0@>65A<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C(Q"FUS9VED("(B"B)%;G1E<B!A('-E8W5R
M:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N
M965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@
M=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(R
M"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Y,0IM
M<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A
M='5S+G!H<#HR-PHC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#4@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4U"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S8@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HX,@IM<V=I
M9"`B17)R;W(B"FUS9W-T<B`B17)R;R(*"B,Z(&9R86UE=V]R:R]496UP;&%T
M92]496UP;&%T92YP:'`Z-#8S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R
M(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O
M<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8X"B,L('!H<"UF
M;W)M870*;7-G:60@(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,`IM<V=I9"`B17-T;VYI82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<Q"FUS9VED(")%=&AI;W!I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P
M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Y"FUS
M9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(D-A9&$@,34@;6EN=71O
M<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#D*(RP@9G5Z>GD*;7-G
M:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R(")#861A(#4@;6EN=71O<R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S8@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,X-PIM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R(")#
M861A(#,P('-E9W5N9&]S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S
M."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDP"FUS9VED(")%=F5R>2`U(&UI
M;G5T97,B"FUS9W-T<B`B0V%D82`U(&UI;G5T;W,B"@HC.B!F<F%M97=O<FLO
M36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,
M;V=I;B(*;7-G<W1R(")#861A(&EN:6-I;R!D92!S97-I\VXB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S0P"FUS9VED(")%=F5R>2!H86QF(&AO=7(B
M"FUS9W-T<B`B0V%D82!M961I82!H;W)A(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,S-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@X"FUS9VED(")%
M=F5R>2!M:6YU=&4B"FUS9W-T<B`B0V%D82!M:6YU=&\B"@HC.B!T96UP;&%T
M97,O9&%T82]D871E;6%P+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V86QU97,Z
M(@IM<V=S='(@(D5X96UP;&\@9&4@=F%L;W)E<SHB"@HC.B!A9&UI;B]P:'!S
M:&5L;"YP:'`Z.#$@861M:6XO8VUD<VAE;&PN<&AP.C4P(&%D;6EN+W-Q;'-H
M96QL+G!H<#HQ,C<*;7-G:60@(D5X96-U=&4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#<U"FUS9VED(")%>'!A
M;F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN
M8SHS,@IM<V=I9"`B17AP86YD(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP96-T
M960@)RDG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O
M<F1S+G!H<#HQ-S4*;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T
M960@<V5A<F-H('1E<FTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M-S8*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'
M($-O;&]R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M-S<*;7-G:60@(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+W-Q;"YP:'`Z,C$V"FUS9VED(")&86EL
M960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`B1F%L;&]U(/,@
M<F5C=7!E<F%R(&%S('!R969E<F5N8VEA<RXB"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V
M97(N(@IM<V=S='(@(D9A;&QO=2#S(&-O;F5C=&%R(&-O('-E<G9I9&]R($Q$
M05`N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.CDX"B,L(&9U
M>GIY"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*
M;7-G<W1R(")&86QL;W4@\R!C;VYE8W1A<B!C;R!S97)V:61O<B!,1$%0+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C@V"B,L('!H<"UF;W)M
M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8Y,0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB
M+B(*;7-G<W1R(")&86QL;W4@\R!C;VYE8W1A<B!C;R!S97)V:61O<B!,1$%0
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#<*(RP@9G5Z
M>GD*;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO
M;BXB"FUS9W-T<B`B1F%L;&]U(/,@86)R:7(@82!C;VYE>&GS;B!,1$%0(&$@
M)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3<@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HW,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B1F%L
M;&]U(/,@8V]N96-T87(@8V\@<V5R=FED;W(@3$1!4"XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C0V,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G<W1R(")&86QL;W4@
M\R!R96-U<&5R87(@;R!$3B!D;R!U<W5A<FEO.B!;)61=("5S(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A
M:7(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA;F0@27-L
M86YD<R`H36%L=FEN87,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@
M(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#
M3$DN<&AP.C(S.`HC+"!F=7IZ>0IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S
M='(@(D5R<F\@9&4@:6UP;W)T86-I\VXZ("(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R
M(")&87@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Y"B,L(&9U
M>GIY"FUS9VED(")&87AE<R(*;7-G<W1R(")&87@B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`R"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#`*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM<V=I9"`B1F5B<G5A<GDB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C`*;7-G:60@
M(D9E96QS($QI:V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(S,0IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Y"FUS
M9VED(")&97<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B1F5W(%-N;W<@4VAO
M=V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.30T"FUS9VED(")&:65L9"!M871R:7@B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S,S-`IM<V=I9"`B1FEG;&5T($-!4%1#2$$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S.`IM
M<V=I9"`B1FEG;&5T(&9O;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I
M9"`B1FEJ:2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(D9I;&4B"FUS9W-T<B`B5.UT=6QO
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#`W"FUS9VED(")&:6QE($UA;F%G97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HV,R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*(RP@9G5Z
M>GD*;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R(").;VUE(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,CDY-0IM<V=I9"`B1FEL92!S96QE8W1I;VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30X-@IM
M<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R
M;W=S97(O0G)O=W-E<BYP:'`Z.#4Y"FUS9VED(")&:6QE('5P;&]A9',@;F]T
M('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C@Y"FUS9VED(")&:6QT97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S$*;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS
M9VED(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR-38*;7-G:60@(D9I>"!R871I
M;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C,Q"FUS9VED(")&;&EP(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G
M:60@(D9L;V%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@
M)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#;VQO
M<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G
M:60@(D9O;V0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V"FUS9VED(")&;W(@8G)O
M=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S-`IM<V=I9"`B1F]R96-A<W0@*%1!
M1BDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C<Y"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E
M='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A
M("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@
M8FQO8VLI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z,3`R"FUS9VED(")&;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V,@IM<V=I9"`B1F]R
M;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"FUS
M9VED(")&;W)T=6YE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS.`HC+"!F=7IZ>0IM<V=I9"`B1F]R='5N
M97,B"FUS9W-T<B`B3F]T87,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0U,PIM<V=I9"`B1F]R=6US(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#D*;7-G:60@(D9O<G=A
M<F1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*(RP@
M9G5Z>GD*;7-G:60@(D9R86UE<R(*;7-G<W1R(").;VUE(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,PIM<V=I9"`B1G)A;F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E+"!-971R;W!O;&ET86XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3;W5T
M:&5R;B!497)R:71O<FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#@@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,`HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-#`V"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*(RP@9G5Z
M>GD*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`B1&5S8W)I8VGS
M;B!C;VUP;&5T83HB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L
M;V-K+VUO;VXN<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C8P"B,L(&9U>GIY"FUS9VED(")&=6QL($YA;64B
M"FUS9W-T<B`B3F]M93HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")'86)O;B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I;6%G
M92!F<F]M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1V%M8FEA(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I
M9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I
M9"`B1V5O<F=I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")'97)M
M86YY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=H86YA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.30@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-0IM<V=I
M9"`B1VEV96X@3F%M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O
M87!P+FEN8SHQ,@IM<V=I9"`B1V\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D96PB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,C@*;7-G
M:60@(D=O;V=L92!-87!S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G
M;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-PIM
M<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED
M(")'<F5E8V4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#4*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<U"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-`IM<V=I9"`B1W)E;F%D82(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C$W.0IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+G!H<#HU.2!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N86UE<R!M
M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L('!H<"UF;W)M870*;7-G:60@(D=R
M;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$X(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HQ,C0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B
M;&4@=&\@9&5L971E(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C,W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L
M9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S$T(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<W
M"FUS9VED(")'<F]U<',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B
M1W5A9&5L;W5P92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDW
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A
M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3(*;7-G
M:60@(D=U97)N<V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,C(V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*
M;7-G:60@(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT-S`*(RP@9G5Z>GD*;7-G:60@(D=U97-T
M8F]O:R(*;7-G<W1R(")!>&5N9&$@9&4@96YD97)E>F]S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.CDY"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-0IM<V=I9"`B1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I
M9"`B1W5I;F5A+4)I<W-A=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G
M:60@(D=U>6%N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HY-C`*;7-G:60@(DA434PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B
M2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@
M8V5L;"!I;B!R;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I
M;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W
M87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP
M.C$U-PIM<V=I9"`B2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2&%I=&DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED
M(")(87-H+4%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@IM<V=I9"`B2&%Z92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,3D@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,CDS,@IM<V=I9"`B2&5A9&5R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-C$*
M;7-G:60@(DAE861E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED
M(")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C,*
M;7-G:60@(DAE879Y(%0M4W1O<FTB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#8*;7-G:60@(DAE8G)E=R`H25-/+3@X-3DM."U)*2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,T"FUS9VED(")(96EG:'0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$W.2!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3@V"B,Z('-E<G9I8V5S+VAE;'`O:6YD
M97@N<&AP.C$W('1E;7!L871E<R]H96QP+VEN9&5X+FEN8SHS"FUS9VED(")(
M96QP(@IM<V=S='(@(D%X=61A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W,0HC
M+"!F=7IZ>0IM<V=I9"`B2&5L<&5R(@IM<V=S='(@(D%X=61A(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$P('1E;7!L871E
M<R]D871A+V-S=FEN9F\N:6YC.C$P"FUS9VED(")(97)E(&ES('1H92!B96=I
M;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"FUS9VED(")(:6=H(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T
M97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B
M2&]?;64B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")(
M;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U,S4*(RP@9G5Z>GD*;7-G:60@
M(DAO;64B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3(R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ-34*;7-G:60@(DAO;64@061D<F5S<R(*;7-G
M<W1R(")%;F1E<F5Z;R!P87)T:6-U;&%R(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C8T"FUS9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS
M9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(E1E;.EF;VYO('!A<G1I8W5L87(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-0IM<V=I9"`B2&]R9&4B"FUS9W-T
M<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0T,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!8
M34P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S
M('1O(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C0S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL
M>2!R96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I
M;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E
M>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0W"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M
M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HT-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R
M="!O9B!T>7!E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,3$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,S,V"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR
M;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B
M2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@
M<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE
M87-E(')E<&]R="$I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY
M(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@
M;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M
M97)G93\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,P,"!L:6(O0FQO8VLO;65T87(N<&AP.C(S,`IM<V=I9"`B2'5M:61I
M='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(U.0IM<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<R(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C$T(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<Y(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Q-@HC
M+"!F=7IZ>0IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R(")%;F1E<F5Z;R(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@
M(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@061D
M<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<V"FUS9VED("))8V]N<R!/;FQY
M(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-PIM<V=I9"`B26-O;G,@=VET:"!T
M97AT(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3`*
M;7-G:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DR"B,L('!H<"UF;W)M870*
M;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T
M;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0U-0IM<V=I9"`B(@HB268@>6]U(&1O;B=T
M('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M
M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@
M=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3<S"FUS9VED("(B"B))9B!Y;W4@<V5E
M('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N
M="!T;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA>65D(&)Y('EO=7(@8G)O
M=W-E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(X"FUS9VED("));6%G92!0<F5V
M:65W.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,W"FUS9VED("));6%G92!54DPB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8Q"FUS9VED
M("));6%G92!U<&QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9&%T82]T<W9I;F9O+FEN8SHW('1E;7!L871E<R]D871A+V1A=&5M87`N
M:6YC.C<*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-"!T96UP;&%T
M97,O9&%T82]C<W9I;F9O+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`B0V%M<&\@:6UP;W)T861O
M.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C$V"B,L('!H
M<"UF;W)M870*;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R(")#
M86UP;R!I;7!O<G1A9&\Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHV-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R(")#86UP
M;W,@:6UP;W)T861O<SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F
M=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]Z:7`N<&AP.C$S-0IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I
M=F5N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S,@HC+"!F=7IZ>0IM<V=I9"`B26YC;W)R96-T
M('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`B06-H96=U92!O
M('-E=2!N;VUE(&1E('5S=6%R:6\@92!C:&%V92!D92!A8V-E<V\B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R
M96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@
M;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@
M9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S92!);F1E
M;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("));F1I82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U-"!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A
M;"!5<V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DEN9&]N
M97-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3<*(RP@9G5Z>GD*;7-G:60@(DEN
M9F]R;6%T:6]N(@IM<V=S='(@(D$@<_IA(&EN9F]R;6%C:?-N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,S,`IM<V=I9"`B26YF;W)M871I
M;VX@;F\@;&]N9V5R(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,U"FUS
M9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C`*;7-G:60@(DEN<V5R="!);6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED("));G-E
M<G0@5&%B;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E8B!,:6YK(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M
M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS
M9VED("));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O
M;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8R"FUS9VED("));G-E<G0@82!N97<@<F]W
M(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G
M:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-S`*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!A
M9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.0IM<V=I
M9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS9VED
M("));G-E<G0@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR,SD*;7-G:60@(DEN<V5R="!A;B!E;6%I
M;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A
M<W-W;W)D.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4X"FUS9VED("));G-E<G0@8V5L;"!A
M9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4Y"FUS9VED("));G-E<G0@8V5L;"!B969O
M<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E
M<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8U"FUS9VED("));G-E<G0@8V]L=6UN(&)E9F]R
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY,`IM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHT-0IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@8F5F;W)E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,`IM<V=I9"`B26YS97)T
M('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(V"FUS9VED("));G-E<G0O36]D:69Y($EM86=E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T
M,PIM<V=I9"`B26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D
M:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@(DEN<W5F
M9FEC:65N="!C<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$P-S4*;7-G:60@(DEN=&5G97(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$S,PIM<V=I9"`B26YT96=E<B!L
M:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI9"!51$@N("A5<V5R
M($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+WII<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]Z:7`N<&AP.C(P,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O>FEP+G!H<#HR,3`*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I
M9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED
M("));G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#@W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M-3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(S,B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,CDY"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP
M92]T86)L97-E="YP:'`Z,S<*;7-G:60@(DEN=F%L:60@9&%T82!S=6)M:71T
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P,`IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO
M;B!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O9&)X+G!H<#HX,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M
M<')E<W,O9&)X+G!H<#HQ,#`*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+V1B>"YP:'`Z,C(P"FUS9VED("));G9A;&ED(&9I;&4@9F]R;6%T(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S<*
M;7-G:60@(DEN=F%L:60@;&EC96YS92!K97DN(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S$*;7-G:60@(DEN=F%L:60@
M;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-PIM<V=I9"`B26YV
M86QI9"!M<V=?='EP92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S"FUS9VED("));G9A;&ED
M(&]R(&UI<W-I;F<@87!I7VED+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.38*;7-G:60@(DEN
M=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R
M96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-S,*;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W
M-0IM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O9&4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY,PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C<Q(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$P-S8@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HQ,C8R"FUS9VED("));G9A;&ED('-H87)E(&]B:F5C
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D9')E
M<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,Q,0IM<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A
M=&$N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M-3<*;7-G:60@(DEN=F5N=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<Y"FUS9VED("));G9E<G0@
M<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B27)A
M;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#$*;7-G:60@(DER87$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED
M("))<F5L86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B
M27-O;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS
M9VED("))<W)A96PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV,C4*;7-G:60@(DES<W5E<B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*;7-G
M:60@(DET86QI8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*(RP@9G5Z>GD*
M;7-G:60@(DET86QY(@IM<V=S='(@(D1I87)I86UE;G1E(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@R"FUS9VED(")*86UA:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,#$*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S.0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F%P86XB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*;7-G:60@(DIA<&%N97-E
M("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HS,3`*;7-G:60@(B(*(DIA=F%S8W)I<'0@:&%S(&)E96X@
M9&ES86)L960@;VX@>6]U<B!B<F]W<V5R(&%N9"!T:&ES('!A9V4@;6%Y(&YO
M="!B92`B"B)D:7-P;&%Y:6YG(&-O<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`W"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M,0IM<V=I9"`B2G5L>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$U"FUS9VED
M(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S
M=&EF>2!&=6QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y($QE
M9G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR-C0*;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R
M(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B:65S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q
M,0IM<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I9"`B2V5Y($9I;F=E<G!R
M:6YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!4>7!E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3DX"B,L(&9U>GIY"FUS9VED(")+97D@57-A9V4B"FUS9W-T<B`B365N
M<V%X92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<T,`IM
M<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R
M=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*
M;7-G:60@(DMI9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+
M:7)I8F%T:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A
M+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED(")+;W)E
M86X@*$550RU+4BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+
M=7=A:70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+>7)G>7IS
M=&%N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z
M.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C@S"FUS9VED("),86YG=6%G92(*;7-G<W1R("),:6YG
M=6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G<R!$96UO8W)A
M=&EC(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HQ-CD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-S8*;7-G:60@(DQA<W0@4&%S<W=O<F0@0VAA;F=E
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX-B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U,0IM<V=I9"`B3&%S="!5<&1A
M=&5D.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW
M,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S(Q"B,L('!H<"UF
M;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$V"FUS9VED("),87-T
M(&QO9VEN.B!.979E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@
M(DQA='9I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#0*;7-G:60@(DQA=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*(RP@9G5Z>GD*;7-G:60@
M(DQA>6]U="(*;7-G<W1R(")096-H87(@82!S97-I\VXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),96%V
M92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0P"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q.0IM
M<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$Q-0HC+"!F=7IZ>0IM<V=I9"`B3&5F="!V86QU97,B
M"FUS9W-T<B`B17AE;7!L;R!D92!V86QO<F5S.B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM
M<V=I9"`B3&5S;W1H;R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(DQE=F5L(@IM<V=S='(@
M(DYU;F-A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:6)E<FEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&EB>6%N($%R86(@2F%M86AI<FEY
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI96-H=&5N<W1E
M:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C4*;7-G:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*(RP@
M9G5Z>GD*;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`B16YT<F%R(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@
M(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@
M3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR.0IM<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S`*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS
M9VED("),:6=H="!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED("),:6=H="!3;F]W(%-H
M;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*
M;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$X,30*(RP@9G5Z>GD*;7-G:60@(DQI;FLB"FUS9W-T<B`B
M16YT<F%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-0IM<V=I9"`B
M3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H
M96X@9&ES<&QA>6EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&
M:6QT97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@S"FUS9VED("),:6YK<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@
M(DQI;G5X($-O;VMI92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N
M('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,S,*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4P"FUS9VED("),:7-T($AE;'`@
M5&]P:6-S(@IM<V=S='(@(DQI<W1A<B!O<R!T96UA<R!D92!A>'5D82(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S(*;7-G:60@(DQI<W0@5&%B;&5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z
M-3DT"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.#D*(RP@9G5Z>GD*;7-G:60@
M(DQI<W0M2&5L<"(*;7-G<W1R("),:7-T87(@;W,@=&5M87,@9&4@87AU9&$B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-@IM<V=I
M9"`B3&ES="U)9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TAE861E<G,N<&AP.C4Y,@IM<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,PIM<V=I
M9"`B3&ES="U0;W-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O2&5A9&5R<RYP:'`Z-3DQ"FUS9VED("),:7-T+5-U8G-C<FEB92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y
M,`IM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN
M9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M<W-I;VYS+G!H<#HS-0HC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('5S
M97)S(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED("),:7-T:6YG('5S97)S(&ES(&1I
M<V%B;&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#<*;7-G:60@(DQI=&5R871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y
M"FUS9VED("),:71H=6%N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:6UA9V5S+G!H<#HX,PIM<V=I9"`B3&]A9&EN9RXN
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C$Q"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C@S"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-S$@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8T"B,Z(&QI8B]";&]C
M:R]S=6YR:7-E+G!H<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP.C8U"FUS9VED
M("),;V-A=&EO;B(*;7-G<W1R("(B"@HC.B!L;V=I;BYP:'`Z,3<R('-E<G9I
M8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.3$@=&5M<&QA=&5S+VQO9VEN+VUO
M8FEL92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-2!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDP"FUS9VED("),;V<@:6XB"FUS
M9W-T<B`B16YT<F%R(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C0U"FUS9VED("),;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.#4*;7-G
M:60@(DQO9R!O=70B"FUS9W-T<B`B4&5C:&%R(&$@<V5S:?-N(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C4Y"B,L(&9U>GIY"FUS9VED("),;V=I;B(*
M;7-G<W1R(")%;G1R87(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W
M"B,L(&9U>GIY"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R(")487)E9F%S
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DV"B,L(&9U>GIY"FUS
M9VED("),;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A
M<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R("(B"B)0
M;W(@86QG=6YH82!R87KS;B!N;VX@<V4@9&5U(&EN:6-I861O(&$@<V5S:?-N
M+B!0<F]B86)L96UE;G1E(&5S8W)I8FEU("(*(FEN8V]R<F5C=&%M96YT92!O
M(&YO;64@9&4@=7-U87)I;R!O=2!A(&-H879E(&1E(&%C8V5S;RXB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HY.3(*;7-G:60@(DQO9VEN(&9A:6QE
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V
M-0HC+"!F=7IZ>0IM<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@(E!E8VAA<B!A
M('-E<VGS;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`IM<V=I9"`B
M3&]V92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV-PIM<V=I9"`B3&]W(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C$*
M;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ
M.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS
M.C$W"FUS9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX.0IM<V=I9"`B3'5X96UB;W5R9R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`P"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,S@@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(DU-(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X,0IM<V=I9"`B34]41"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H
M<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D
M871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86-A;R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE
M<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3`*;7-G:60@(DUA9&%G87-C87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C0Y"B,L(&9U>GIY"FUS9VED(")-86=I8R(*;7-G<W1R
M(")#;W)R96\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#$*;7-G
M:60@(DUA:6PB"FUS9W-T<B`B0V]R<F5O(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C4R,@IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDT"B,L(&9U>GIY"FUS9VED(")-86QA=VDB"FUS9W-T<B`B0V]R<F5O
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDU"FUS9VED(")-86QA>7-I82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.30*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,@HC+"!F=7IZ>0IM<V=I9"`B36%L:2(*;7-G<W1R(")#;W)R96\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DUA;'1A(@IM<V=S='(@
M(D-O<G)E;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,0IM<V=I9"`B
M(@HB36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@
M;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I
M=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-3,*;7-G:60@(DUA<#(T
M(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3`X-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3$V.`IM<V=I9"`B36%P475E<W0@;6%P(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I9"`B
M36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT,0HC+"!F=7IZ>0IM<V=I9"`B36%R9VEN(@IM<V=S='(@(D%V
M:7-O(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.#@*;7-G:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX
M.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N
M="]!;G-W97)E9"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-
M87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I
M9"`B36%R=&EN:7%U92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C$P,PIM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@
M(D-A;7!O<R!C;W)R97-P;VYD96YT97,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@
M(DUA=7)I=&%N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-
M875R:71I=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED(")-87@@86QL;W=E9"!C
M<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@<&%R
M=',@97AC965D960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S`V"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3@*;7-G:60@(DUA>"!T
M96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP
M.C@V"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y."!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$W"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R,SD*;7-G:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#4*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS
M9VED(")-87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B36%Y
M;W1T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*
M;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O961I="YI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(DUE;6)E<G,B
M"FUS9W-T<B`B365M;W)A;F1O<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-S@*;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I
M9"`B365R9V4@8V5L;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF
M:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DUE<W-A
M9V4B"FUS9W-T<B`B365N<V%X92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,C$V"FUS9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U
M8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD
M(&YO="!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"B,L(&9U>GIY
M"FUS9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(DUE;G-A>&4B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V
M.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8P,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C8P"B,L(&9U>GIY"FUS9VED(")-97-S86=E('1Y<&4B"FUS
M9W-T<B`B365N<V%X92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I
M9"`B365T87(@5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,W"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q,@HC+"!F=7IZ
M>0IM<V=I9"`B(@HB365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL
M<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS
M9W-T<B`B4F5X:7-T<N%R;VYS92!O<R!D971A;&QE<R!P87)A(&\@861M:6YI
M<W1R861O<BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38U
M"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B365T
M:&]D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP
M:'`Z.#$@9G)A;65W;W)K+U)00R]24$,O<V]A<"YP:'`Z,3$W"B,L('!H<"UF
M;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL960@
M;65T:&]D.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-0IM<V=I9"`B365T
M<FEC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")-:6-R;VYE<VEA+"!&961E
M<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@HC+"!F=7IZ>0IM<V=I
M9"`B36ED9&QE(@IM<V=S='(@(D-O<G)E;R(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3`*;7-G:60@(DUI
M;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,P,@IM<V=I9"`B36EN('1E;7`@;&%S="`V(&AO=7)S
M.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HT,SD*;7-G:60@(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T
M(&5X<&ER960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(S-`HC+"!F=7IZ>0IM<V=I9"`B36ER<F]R(@IM
M<V=S='(@(D5R<F\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G
M:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0P"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S
M:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*;7-G:60@(B(*(DUI<W-I;F<@
M8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF
M('EO=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT
M<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E
M($UA:6PN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES<VEN9R!S97-S:6]N
M($E$+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S0*;7-G:60@(DUO8FEL92!-86EL(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8X"FUS9VED(")-;V1E<F%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8V(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S,*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HX.`IM<V=I9"`B36]D:69I960@1&%T92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S,*;7-G:60@
M(DUO9'5L=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VQD
M;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G
M:60@(DUO;F%C;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUO
M;F=O;&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(U.30*;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3<*;7-G:60@
M(DUO;G1H;'DB"FUS9W-T<B`B365N<W5A;&UE;G1E(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT
M"FUS9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0
M:&%S97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z,3<R(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(U,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H
M86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*
M;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO<W1L>2!#;&5A<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS-`IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B
M36]S=&QY(%-U;FYY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C4P.0IM<V=I9"`B36]V92!$;W=N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4Q,PIM
M<V=I9"`B36]V92!,969T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C4Q-PIM<V=I9"`B36]V92!2:6=H="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU
M,#4*;7-G:60@(DUO=F4@57`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`IM<V=I9"`B36]V92!D;W=N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HU,C,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C4R-`IM<V=I9"`B36]V92!U<"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.34*;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-`IM<V=I9"`B375L=&DM;&5V96P@9')O
M<"!D;W=N(&QI<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,#4U"FUS9VED(")-=6QT:6UA<"!52R!M
M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T
M,@IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#`*;7-G:60@(DUY($%C8V]U;G0B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X"B,L(&9U
M>GIY"FUS9VED(")->2!!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(D$@
M<_IA(&EN9F]R;6%C:?-N(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H
M<#HU-`IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]E9&ET+G!H<#HQ,S8*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH
M=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA;64B"FUS
M9W-T<B`B3F]M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDW"FUS9VED(").971H97)L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@
M(DYE='-C87!E($)A<V4@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!#02!2
M979O8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y
M(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#(*
M;7-G:60@(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").
M971S8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C87!E
M(&-E<G1I9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#`*;7-G:60@(DYE='-C87!E(&-E
M<G1I9FEC871E('1Y<&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(U,0IM<V=I9"`B3F5T=V]R:R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,S-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V"FUS
M9VED(").979E<B(*;7-G<W1R(").=6YC82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I
M9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A
M=&5G;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&
M:6QT97(O96UA:6QS+G!H<#HX,0HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O
M1FEL=&5R+V5M86EL<RYP:'`Z.#<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R
M+T9I;'1E<B]E;6%I;',N<&AP.CDW"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E
M<B]&:6QT97(O96UA:6QS+G!H<#HQ,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3F5W($UE<W-A9V4@=&\@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,3<T"FUS9VED(").97<@36]O;B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,U"FUS9VED(").97<@57-E
M<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G
M:60@(DYE=R!:96%L86YD(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B3F5W('!A<W-W;W)D
M(@IM<V=S='(@(D-H879E(&1E(&%C8V5S;R(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A
M<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*;7-G:60@(DYE=R!P87-S=V]R
M9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@
M*%]B;&%N:RDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M-#`@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR.#D*(RP@9G5Z>GD*;7-G:60@(DYE=W,B"FUS9W-T<B`B
M3F]T87,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`U"FUS9VED
M(").97=S9W)O=7!S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1S
M=FEN9F\N:6YC.C$U('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0Q"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y('1E;7!L871E<R]D871A
M+V-S=FEN9F\N:6YC.C(U"FUS9VED(").97AT(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HR-PIM<V=I9"`B3F5X="`T(%!H87-E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W,B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W-@HC+"!F=7IZ>0IM<V=I
M9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@(E)E9W)E<V%R(.%S(&]P8VGS;G,B
M"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C$P,PIM<V=I9"`B3F5X
M=#XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6-A<F%G=6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"B,L(&9U>GIY"FUS9VED(").:6=E
M<B(*;7-G<W1R(").=6YC82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I
M82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S@P"FUS9VED(").:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G
M:60@(DYI=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.CDV,PIM<V=I9"`B3F\B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS9VED(").;R!A
M=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC
M97,@9F]R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(N<&AP.C$P-0IM<V=I9"`B3F\@879A:6QA8FQE('-T<F%T
M96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S"FUS
M9VED(").;R!B871C:"!T96UP;&%T92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-SD@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z,C0U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C(V-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H
M92!R97%U97-T960@<&]S:71I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]M8V%L+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B3F\@8V%L
M96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B3F]N(&5S<&5C:69I8V]U(&$@8V]N9FEG=7)A8VGS;B!P87)A
M(&$@875T96YT:69I8V%C:?-N('!O<B!344PN(@H*(SH@861M:6XO<V5T=7`O
M9&EF9BYP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T
M<B`B1&5S9F%C97(@;W,@8V%M8FEO<R(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,34V"FUS9VED(").;R!C:&EL9')E;B!C86X@8F4@861D
M960@=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$V-R!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C4P,@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW-S,*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B3F]N(&5S<&5C:69I
M8V]U(&$@8V]N9FEG=7)A8VGS;B!P87)A(&%S(&-A=&5G;W+M87,@4U%,+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(T"B,L(&9U>GIY"FUS
M9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@1E10(%9&4RXB"FUS9W-T<B`B3F]N(&5S<&5C:69I8V]U(&$@8V]N9FEG
M=7)A8VGS;B!P87)A(&%S('!R969E<F5N8VEA<R!,1$%0+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C8Y"B,L(&9U>GIY"FUS9VED(").;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&
M4RXB"FUS9W-T<B`B3F]N(&5S<&5C:69I8V]U(&$@8V]N9FEG=7)A8VGS;B!P
M87)A(&%S(&-A=&5G;W+M87,@4U%,+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HW,3<*(RP@9G5Z>GD*;7-G:60@(DYO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N
M(@IM<V=S='(@(DYO;B!E<W!E8VEF:6-O=2!A(&-O;F9I9W5R86-I\VX@<&%R
M82!A<R!C871E9V]R[6%S(%-13"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO(&-R961I="!L
M969T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S-`IM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P
M<&QI960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S
M97(N<&AP.C@W-PIM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R("(B
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS
M(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,3(X(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$R,PIM<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Y
M"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*
M;7-G:60@(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS
M9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*;7-G:60@
M(DYO(&YU;6)E<B!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z
M.3$*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VEM87`N<&AP.C$P.`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($E-05`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O:W)B-2YP:'`Z-S(*;7-G:60@(DYO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HW-R!F<F%M97=O
M<FLO075T:"]!=71H+VQO9VEN+G!H<#HX-`HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W!A;2YP:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3F]N
M(&5S<&5C:69I8V]U(&$@8V]N9FEG=7)A8VGS;B!P87)A(&$@875T96YT:69I
M8V%C:?-N('!O<B!344PN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P87-S
M=V0N<&AP.C$S-0HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3F]N(&5S
M<&5C:69I8V]U(&$@8V]N9FEG=7)A8VGS;B!P87)A(&$@875T96YT:69I8V%C
M:?-N('!O<B!344PN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP
M.C@T"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").;VX@97-P96-I9FEC;W4@
M82!C;VYF:6=U<F%C:?-N('!A<F$@82!A=71E;G1I9FEC86-I\VX@<&]R(%-1
M3"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R.#8*
M;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I
M9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O
M<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@
M<VEG;G5P<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C<U,`HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!Q=6]T82!S970N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#,*(RP@9G5Z>GD*;7-G:60@(DYO(')U;&5S(@IM<V=S='(@
M(DYO=&%S(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Y"FUS
M9VED(").;R!S97!A<F%T;W(@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T
M"B,L(&9U>GIY"FUS9VED(").;R!S:61E<R(*;7-G<W1R(").;W1A<R(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@S"FUS9VED(").;R!S=6-H
M(&9I;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$S.`IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B
M;&4@9F]R(&-A8VAE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C(R,0HC+"!F=7IZ>0IM<V=I9"`B3F\@
M=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(D%C:&5G
M=64@;R!S974@;F]M92!D92!U<W5A<FEO(&4@8VAA=F4@9&4@86-C97-O(@H*
M(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO
M('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-S$*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX,0HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3DR"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#`Y"FUS9VED(").;R!V
M86QU97,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R
M,`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U
M<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E<G-I
M;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0R-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0U"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N
M=&ET>7-E;&5C="YI;F,Z.3,*(RP@9G5Z>GD*;7-G:60@(DYO;F4B"FUS9W-T
M<B`B5&5LZ69O;F\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDP"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(").;W)D
M:6,@*$E33RTX.#4Y+3$P*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G
M:60@(DYO<F9O;&L@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H
M97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED
M(").;W)T:&5R;B!-87)I86YA($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDW"FUS9VED(").;W)W87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!!9G1E<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8S.0IM<V=I9"`B3F]T($)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HT,#@*;7-G:60@(DYO="!A(&1I<F5C=&]R
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(N<&AP.C8S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C@S"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP
M.CDT"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2YP:'`Z-#@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HU.0IM<V=I9"`B
M3F]T(&EM<&QE;65N=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8X"B,L(&9U>GIY"FUS9VED(").
M;W0@<V5T(@IM<V=S='(@(DYO=&%S(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(
M86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#,*(SH@9G)A;65W;W)K+U-E
M<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-3@*(SH@9G)A;65W
M;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S,*(SH@
M9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ
M.#<*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R
M+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,N<&AP.C$Y,`HC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z,C`U(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,S`*
M(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(T."!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,C8U"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.#$@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C(Y-PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,S$R(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,CD*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C,V,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-#(R"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HU,#$@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C4W,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3@W(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HV-C4*;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR
M-#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,#4*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$W.`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B3F]T87,B
M"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO
M=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#D*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0HC+"!F=7IZ>0IM
M<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B3G5N8V$B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,#0V"B,L(&9U>GIY"FUS9VED(").=6UB97(B"FUS
M9W-T<B`B3F]M92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C4*
M;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-CD@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,30R,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0U('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED
M(").=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,S8W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T
M,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,R!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@IM<V=I9"`B3G5M8F5R
M(&]F(')O=W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P
M96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHV-`IM<V=I9"`B3TLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B3V)J96-T(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS
M9VED(")/8FIE8W0@0W)E871O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,3`T"FUS9VED(")/8W1A;"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I
M9"`B3V-T;V)E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C8*;7-G:60@(D]F9FEC92(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G
M:60@(D]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V
M"B,L(&9U>GIY"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`B0VAA=F4@
M9&4@86-C97-O(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C0V
M"FUS9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HW,PIM<V=I9"`B
M3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDU"FUS9VED(")/
M;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#4Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Y-S$*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"XB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C8U"FUS
M9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O
M<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B"B)P97)M:7-S:6]N
M<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE
M+G!H<#HS-0IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G
M:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O
M;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I
M9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*;7-G:60@(D]P97)A=&EN
M9R!3>7-T96TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")/<&-I\VYS(@H*
M(SH@<V5R=FEC97,O<')E9G,N<&AP.C,Q('1E;7!L871E<R]P<F5F<R]A<'`N
M:6YC.C$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O
M<B`E<R(*;7-G<W1R(")/<&-I\VYS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-38W"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A
M=&EO;F%L(%5N:70B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$S,@IM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P;&EC
M871I;VX@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S
M+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@=&5M<&QA
M=&5S(&EN("5S.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B
M3W1H97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#8*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Q,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(R"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,S$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T
M,0IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`B3W5T<F$@:6YF
M;W)M86-I\VXB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,Q"FUS
M9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W!A;2YP:'`Z-SD*;7-G:60@(E!!32!A=71H96YT:6-A
M=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%
M05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,C<S"FUS9VED(")01U`@1&EG:71A;"!3:6=N
M871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3,Q.0IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-S$*;7-G
M:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C$S-3,*;7-G:60@(E!'4"!3:6=N960O16YC
M<GEP=&5D($1A=&$B"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP
M.C8X"B,L(&9U>GIY"FUS9VED(")02%`@0V]D92(*;7-G<W1R(")(;W)D92(*
M"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,W"FUS9VED(")032!,:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")0
M32!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,Y"FUS9VED(")032!3;F]W(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS
M9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*;7-G:60@(E!-(%-U;B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT,@IM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C(W-`IM<V=I9"`B4$]325@@97AT96YS:6]N
M(&ES(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Y"FUS
M9VED(")07TA0(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I
M;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")086MI<W1A;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QA=2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QE<W1I;FEA;B!497)R:71O
M<GDL($]C8W5P:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B
M4&%N86UA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@
M3F5W($=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")0
M87)A9W5A>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3@P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3,W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#$X"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#(S"FUS9VED(")087-S=V]R9"(*;7-G<W1R(")#:&%V92!D92!A8V-E<V\B
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z.#(*;7-G:60@(E!A
M<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$S,C(*(RP@9G5Z>GD*
M;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G<W1R(")#:&%V92!D92!A
M8V-E<V\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,34R
M"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,#4S"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*(RP@
M9G5Z>GD*;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R(")#:&%V92!D92!A8V-E
M<V\B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0HC+"!F=7IZ
M>0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R(")#:&%V92!D92!A8V-E<V\B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C`S-`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U
M"FUS9VED(")087-S=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$Q.2!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G:60@(E!A<W1E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3$*
M;7-G:60@(E!A=&@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q
M=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T"B,L(&9U>GIY"FUS9VED
M(")096]P;&4B"FUS9W-T<B`B1G5N8VGS;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC
M92YH=&UL.C0Y"FUS9VED(")097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO
M;G,B"FUS9W-T<B`B4F5A;&EZ87(@;W!E<F%C:?-N<R!D92!M86YT96UE;G1O
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0P-@HC+"!F=7IZ>0IM<V=I
M9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*
M;7-G<W1R(")296%L:7IA<B!O<&5R86-I\VYS(&1E(&UA;G1E;65N=&\B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B4&5R
M;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP
M.C4R"B,L('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO
M="!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C4X-@IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C$@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C0*;7-G:60@(E!E<FUI<W-I;VYS
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P.2!A9&UI
M;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C`*(SH@861M:6XO<&5R;7,O:6YD97@N
M<&AP.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3@*;7-G:60@(E!E<FUI
M<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV-0HC+"!F=7IZ>0IM<V=I9"`B4&5R<V]N86P@26YF
M;W)M871I;VXB"FUS9W-T<B`B3W5T<F$@:6YF;W)M86-I\VXB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4U"FUS9VED(")0971S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY.0IM<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B4&AO
M;F4B"FUS9W-T<B`B5&5LZ69O;F\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#<X"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G
M:60@(E!L871I='5D97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E
M(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I
M9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI
M<R!E;&5M96YT.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L96%S92!C
M;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4W,0IM
M<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z,3(*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@
M8V%T96=O<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$S,#$*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E
M<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V
M-C`*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H
M92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-3$*;7-G:60@(E!L96%S92!E
M;G1E<B!A('9A;&ED('1I;64N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@(E!L96%S92!P<F]V:61E(&$@
M<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS9W-T<B`B06-H96=U92!U;B!R
M97-U;6\@9&\@<')O8FQE;6$N(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0
M;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G
M<W1R(")!8VAE9W5E(&\@<V5U(&YO;64@9&4@=7-U87)I;R!E(&-H879E(&1E
M(&%C8V5S;R(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.`IM<V=I
M9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@3553
M5"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y
M36%N86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@8V%T
M96=O<GD@;F%M93HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0
M;VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4W
M"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#@W"FUS9VED(")0;VQL<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$X,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`Q"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*
M;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)
M34%0*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V-B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")0
M<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDX"FUS9VED(")0
M<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A
M<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<V5S<VEO;BYP:'`Z,S,*
M;7-G:60@(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,C4*;7-G:60@(E!R97-S=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C4Y"FUS9VED(")0<F5S<W5R92!A="!S96$@;&5V
M96PZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C,U"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,#4*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(S
M"FUS9VED(")0<F5V:65W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`IM<V=I9"`B
M4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8R(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8V"B,L(&9U>GIY"FUS9VED(")0<F5V
M:6]U<R!O<'1I;VYS(@IM<V=S='(@(E)E9W)E<V%R(.%S(&]P8VGS;G,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0Q"FUS
M9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ
M-CD*(RP@9G5Z>GD*;7-G:60@(E!R;V)L96TB"FUS9W-T<B`B6TEN9F]R;64@
M9&\@4')O8FQE;6%=(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3(V"FUS
M9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@(D1E<V-R:6-I\VX@
M9&\@<')O8FQE;6$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S8Y
M"FUS9VED(")0<F]J96-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,3$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#@*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X-0IM<V=I9"`B4')O;7!T
M('1E>'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L
M:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8T-`IM<V=I9"`B4'5B;&EC($ME>2!);F9O
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A
M=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM
M<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM
M<V=I9"`B46%T87(B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C8S"FUS9VED(")1=65R>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-S`*;7-G:60@(E%U;W1A(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C8S"B,L('!H<"UF;W)M870*
M;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C0*;7-G:60@(E)A9&EO('-E
M;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B4F%I;B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B
M4F%I;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0V
M"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-PIM<V=I9"`B4F%I;B!A;F0@
M4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R
M='5N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-S8*;7-G:60@(E)A=&EO(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,S(T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,S0*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3$T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3@P"FUS9VED(")296%D(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W
M"B,L(&9U>GIY"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@(DUE;G-A
M>&4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R
M871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@
M;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@
M(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V
M"FUS9VED(")2969R97-H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.3$*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE
M;G1S.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q
M"B,L(&9U>GIY"FUS9VED(")2969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R
M(")!8W1U86QI>F%R(&$@=FES=&$@9&\@<F5S=6UO.B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C@Y-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C$S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S4*;7-G:60@(E)E
M9V5X(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R
M-#D*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR,#@*;7-G:60@(E)E;&]A9"(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R-@IM<V=I9"`B4F5M87)K<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$T"FUS9VED(")2
M96UO=&4@4V5R=F5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N
M97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V5D:70N:6YC.C(R('1E;7!L871E<R]A9&UI;B]U<V5R
M+V%P<')O=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M97%U975E9"YI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92(*;7-G<W1R
M(")386-A<B!O('!A<B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN
M8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@(E-A
M8V%R(&\@<&%R(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C4U-PIM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0P"B,L
M(&9U>GIY"FUS9VED(")296UO=F4@9F]R;6%T=&EN9R(*;7-G<W1R(")386-A
M<B!O('!A<B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(X"FUS
M9VED(")296UO=F4@<&%I<B(*;7-G<W1R(")386-A<B!O('!A<B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HR,#(*;7-G:60@(E)E;6]V92!S879E9"!S
M8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#(*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!T:&4B"FUS
M9W-T<B`B4V%C87(@;R!P87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(E)E;6]V92!T:&ES
M(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B
M4F5M;W9E('5S97(B"FUS9W-T<B`B4V%C87(@;R!P87(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R(")386-A<B!O('!A
M<B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED
M(")297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O
M<F-O9&4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,34W"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@
M8F4@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,3<T(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$R"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P
M96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B)/(&-A
M;7!O(')E<75I<FED;R`G=6ED)R!N;VX@9F]I(&5S<&5C:69I8V%D;R!N82!C
M;VYF:6=U<F%C:?-N(&1A<R`B"B)P<F5F97)E;F-I87,N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HV-S4@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R
M,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB
M(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(B(*(D\@8V%M<&\@<F5Q=6ER:61O("=U:60G(&YO;B!F;VD@97-P96-I9FEC
M861O(&YA(&-O;F9I9W5R86-I\VX@9&%S("(*(G!R969E<F5N8VEA<RXB"@HC
M.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW.#$*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(D\@8V%M<&\@<F5Q=6ER:61O
M("=U:60G(&YO;B!F;VD@97-P96-I9FEC861O(&YA(&-O;F9I9W5R86-I\VX@
M9&%S("(*(G!R969E<F5N8VEA<RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+U)E;F1E<F5R+G!H<#HS,S4*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,S.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H
M<#HS,C`@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<W"FUS9VED(")297-E="(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT-@HC
M+"!F=7IZ>0IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`B0VAA=F4@
M9&4@86-C97-O(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*
M;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C$S,`IM<V=I9"`B4F5S=&]R92!,87-T(%%U97)Y
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HW,2!A9&UI;B]C
M;61S:&5L;"YP:'`Z,C@@861M:6XO<W%L<VAE;&PN<&AP.C8V"FUS9VED(")2
M97-U;'1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T
M=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B4F5G<F5S87(@X7,@;W!C:?-N<R(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS.`IM<V=I9"`B4F5T
M>7!E(&YE=R!P87-S=V]R9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS
M9VED(")2975N:6]N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V
M97)T($-O;F9I9W5R871I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$S,@HC+"!F=7IZ>0IM<V=I9"`B4FEC:"!497AT($5D:71O
M<B!/<'1I;VYS(@IM<V=S='(@(E)E9W)E<V%R(.%S(&]P8VGS;G,B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<P"FUS9VED(")2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,3(Q"FUS9VED(")2:6=H="!H96%D97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-PIM<V=I
M9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?
M=R!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B"FUS9W-T
M<B`B1G5N8VGS;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(R-0IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(R"FUS9VED(")2
M;W1A=&4@3&5F="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C(X"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW,`IM<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G
M:60@(E)O=W,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*(RP@9G5Z>GD*;7-G:60@(E)U
M;&5S(@IM<V=S='(@(D9U;F-I\VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL
M(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L
M=6UN<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@
M87!P96%R(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,C`*;7-G:60@(E)U;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$X-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`S"FUS9VED(")2=7-S:6%N($9E9&5R871I;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G=A;F1A(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED(")3
M+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS,C,*;7-G:60@(E,O
M34E-12!%;F-R>7!T960@365S<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-A<VPN<&AP.C@Q"FUS9VED(")305-,(&%U=&AE;G1I
M8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HU,#0*(RP@9G5Z>GD*;7-G:60@(E--4R!-
M97-S86=I;F<B"FUS9W-T<B`B365N<V%X92(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#,*;7-G:60@(E-13"!S=&%T96UE;G0@
M9F]R('9A;'5E(&QO;VMU<',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0S,0IM<V=I9"`B4U-((@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO
M8FEL92YP:'`Z,S4*;7-G:60@(E-50T-%4U,B"FUS9W-T<B`B(@H*(SH@;&EB
M+V%P:2YP:'`Z,34S"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G
M:60@(E-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A:6YT
M($AE;&5N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(E-A:6YT
M($MI='1S(&%N9"!.979I<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Y,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G
M:60@(E-A:6YT($QU8VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G
M:60@(E-A:6YT(%!I97)R92!A;F0@36EQ=65L;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-0IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA
M9&EN97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,38@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`S"FUS9VED(")3875D:2!!<F%B:6$B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDX"FUS9VED(")3879E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z
M-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`B1V%R9&%R(&%S
M(&]P8VGS;G,B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED
M(")3879E($]P=&EO;G,B"FUS9W-T<B`B1V%R9&%R(&%S(&]P8VGS;G,B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38W"FUS9VED("(B"B)3879E(&=E
M;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R
M('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<Q"B,L('!H<"UF;W)M870*
M;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L('!H<"UF;W)M870*;7-G
M:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0Y"FUS9VED(")38V%T=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE;F-E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$T
M('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED(")396%R
M8V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R
M,`IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,CDW,PIM<V=I9"`B4V5L96-T($9I;&5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT.#0*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T
M<B`B4V5L96-C:6]N92!O(&9O<FUA=&\@9&$@9&%T83HB"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B4V5L96-T(&$@9W)O=7`@
M=&\@861D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@(E-E;&5C
M="!A('-E<G9E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$U-@IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C8W-PIM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-C8S"B,L(&9U>GIY"FUS9VED(")396QE8W0@
M86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`B4V5L96-C:6]N92!O(&9O
M<FUA=&\@9&$@9&%T83HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.#<S"FUS9VED(")396QE8W0@86X@;V)J96-T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HV-S@*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+VME>6)O87)D+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B(@HB4V5L96-T
M('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W
M+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H
M92!T97AT(&%R96$N(@IM<V=S='(@(B(*(E-E;&5C8VEO;F4@;W,@8V%R86-T
M97)E<R!Q=64@;F5C97-I=&4@9&%S(&-U861R[6-U;&%S('%U92!A=&]P87+A
M(&UA:7,@(@HB86)A:7AO+B!0;V1E(&-O<&EA;&]S(&4@<&5G86QO<R!D96YD
M92!A(.%R96$@9&4@=&5X=&\N(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z(@IM<V=S
M='(@(E-E;&5C8VEO;F4@;R!D96QI;6ET861O<B!D82!D871A.B(*"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A
M=&4@9F]R;6%T.B(*;7-G<W1R(")396QE8V-I;VYE(&\@9F]R;6%T;R!D82!D
M871A.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z
M.3`*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA
M;F=E.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ
M-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB
M"FUS9W-T<B`B4V5L96-C:6]N92!O(&1E;&EM:71A9&]R(&1A(&1A=&$Z(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T
M:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(E-E;&5C8VEO;F4@;R!F;W)M871O
M(&1A(&AO<F$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-PIM
M<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N(@IM<V=S='(@(E-E
M;&5C8VEO;F4@9&]U<R!C86UP;W,@<75E(&-O:6YC:61A;BXB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S`V"FUS9VED(")396QE8W0@>6]U<B!C;VQO
M<B!S8VAE;64N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-#@*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB
M"FUS9W-T<B`B4V5L96-C:6]N92!A(&QI;F=U83HB"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E
M<&]R="(*;7-G<W1R(")%;G9I87(@;R!I;F9O<FUE(&1E('!R;V)L96UA<R(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#,Y
M"FUS9VED(")396YD(%--4R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Y.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS
M9VED(")396YE9V%L(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S$V"FUS9VED(")396YS;W(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Y"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I9"`B4V5P=&5M
M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#$*
M;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$V,0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O
M;F<@;W(@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S
M<VEO;G,N<&AP.C(W"FUS9VED(")397-S:6]N($%D;6EN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R("(B"@HC
M.B!L:6(O87!I+G!H<#HQ-#4*(RP@9G5Z>GD*;7-G:60@(E-E<W-I;VYS(@IM
M<V=S='(@(D=A<F1A<B!A<R!O<&-I\VYS(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C,Q-`IM<V=I9"`B4V5T(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW-@IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL
M;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R
M9V5T(&ET+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3$U"FUS9VED(")3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N
M="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T"B,L(&9U>GIY"FUS9VED(")3970@
M>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P
M=&EO;G,N(@IM<V=S='(@(B(*(D5S=&%B;&5C92!A(&9R96-U96YC:6$@9&4@
M86-T=6%L:7IA8VGS;B!D87,@<.%X:6YA<R!E(&]U=')A<R!O<&-I\VYS(&1E
M("(*(G9I<W5A;&EZ86-I\VXN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDX"B,L(&9U>GIY"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P(&%P<&QI
M8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T
M:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B(@HB17-T86)L96-E
M(&$@9G)E8W5E;F-I82!D92!A8W1U86QI>F%C:?-N(&1A<R!PX7AI;F%S(&4@
M;W5T<F%S(&]P8VGS;G,@9&4@(@HB=FES=6%L:7IA8VGS;BXB"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C<U"FUS9VED(")3971U<"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS-PIM<V=I
M9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3@V"FUS9VED(")3
M979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z
M("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L;&5S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.38*
M;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B
M;&5M+W!R;V)L96TN:6YC.C0S"B,L(&9U>GIY"FUS9VED(")3:&]R="!3=6UM
M87)Y(@IM<V=S='(@(E)E<W5M;R!B<F5V93HB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#0V"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F
M:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U-0IM<V=I9"`B(@HB
M4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@
M=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DP"FUS9VED(")3:&]W
M(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C4*;7-G:60@(E-H;W<@
M;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,PIM<V=I9"`B4VAO=R!P:6-K97(B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R-@IM<V=I9"`B
M4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S
M(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A
M8FQE(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I
M9"`B4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE
M<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3<V,PIM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3`*;7-G:60@(E-H
M;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-3$*;7-G:60@(E-H;W=E<G,@16%R;'DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*
M;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!I
M;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z-#@P"FUS9VED(")3:')I;FLB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-S<T(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C@S-@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY,C(@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z.3@T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C$P-#<@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z,3`X-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HQ,3$V(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q-#D*
M;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O
M=70@;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U
M"FUS9VED(")3:65R<F$@3&5O;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V-0IM<V=I9"`B4VEG;B!U<"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q
M,@IM<V=I9"`B4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-S$Q"FUS9VED(")3:6=N871U<F4@06QG
M;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A
M<&]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C8U(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX
M-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.38*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(Q-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,W
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#8@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,CDS,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,3(S"FUS9VED(")3:7IE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN
M=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4R"FUS9VED(")3:VEP($UA:6YT
M96YA;F-E(@IM<V=S='(@(D]M:71I<B!O(&UA;G1E;65N=&\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`U"FUS9VED(")3;&]V86MI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`U"FUS9VED(")3;&]V96YI82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-`IM<V=I9"`B4VYO=R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU-0IM<V=I9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*;7-G:60@(E-N;W<@
M4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4X"FUS9VED(")3;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W.`IM<V=I9"`B4VYO=R!D97!T:#H@
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@R"FUS9VED
M(")3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`S"FUS9VED(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,30@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-@IM<V=I9"`B4V]M86QI82(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR-@IM
M<V=I9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C$W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(T-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$V-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$X
M.0HC+"!F=7IZ>0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B16YD
M97)E>F\@9&\@=')A8F%L;&\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")3;W5T
M:"!!9G)I8V$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.3`*;7-G:60@(E-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H
M92!3;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@
M(E-O=71H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E
M(&)E='=E96X@861J86-E;G0@8V5L;',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P
M86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#$U"FUS9VED(")3
M<&%C97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C@P"FUS9VED(")3<&%C:6YG(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-30*;7-G:60@(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S$*;7-G:60@(E-P86EN(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY.`IM<V=I9"`B4W!A;2(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I
M86P@0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(D5N=')A9&$@9&4@8V%R86-T
M97)E<R!E<W!E8VEA:7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C8Q"B,L(&9U>GIY"FUS9VED(")3<&]R=',B"FUS9W-T
M<B`B26UP;W)T87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S,@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HW-`HC+"!F=7IZ>0IM<V=I9"`B4W1A;F1A
M<F0B"FUS9W-T<B`B0V%L96YD87)I;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(U.38@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C@P.0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B4W1A=&4@
M;W(@4')O=FEN8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E
M='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$U"B,L(&9U>GIY"FUS9VED
M(")3=&]R86=E(&9O<FUA="(*;7-G<W1R(")!('/Z82!I;F9O<FUA8VGS;B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<R"B,L(&9U
M>GIY"FUS9VED(")3=')E970@061D<F5S<R(*;7-G<W1R(")%;F1E<F5Z;R!D
M;R!T<F%B86QL;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S,PIM<V=I9"`B4W1R:6YG
M(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3@W,PIM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM
M<V=I9"`B4W4B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP
M.C,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@
M7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B3F]N('-E(&%T;W!O=2!O(&%X
M96YT92!D92!N;W1I9FEC86-I\VX@)7,N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(@9G)A;65W
M;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S$W"FUS9VED(")3=6)M:70B
M"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O('1H
M92!S>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E
M<75E<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U
M8G-C<FEP="(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`T
M"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`B0V]R
M<F5C=&%M96YT92(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y
M<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R
M('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V
M"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE=&5D(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F
M<F]M('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF
M:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU.2!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HU-PIM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S
M879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L('!H<"UF;W)M870*;7-G
M:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O
M=&4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W5D86XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU-@HC+"!F=7IZ>0IM<V=I9"`B4W5M;6%R>2(*;7-G
M<W1R(")297-U;6\B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C4*;7-G
M:60@(E-U;B!2:7-E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.0IM<V=I9"`B4W5N;GDB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q
M-@IM<V=I9"`B4W5N<FES92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5N
M<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,38*;7-G:60@(E-U
M;G)I<V4O4W5N<V5T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,34*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Y"FUS9VED(")3=6YS
M970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Q.`IM<V=I9"`B4W5N<V5T.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S
M8W)I<'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,W.`HC+"!F=7IZ>0IM<V=I9"`B4W5P<&]R="(*;7-G<W1R("));7!O<G1A
M<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#8*(RP@9G5Z>GD*;7-G:60@(E-U<FEN86UE(@IM
M<V=S='(@(E5S=6%R:6\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4W-`HC+"!F=7IZ>0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R(")5
M<W5A<FEO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@86YD($IA
M;B!-87EE;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z
M:6QA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W=E9&5N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-38@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")3=VET>F5R;&%N9"(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@IM
M<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,30R"FUS9VED(")3>6YC34PB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3
M>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#<*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P
M"FUS9VED(")4+5-T;W)M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Q"FUS9VED(")4+5-T;W)M(&%N9"!7
M:6YD>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV,@IM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*;7-G:60@
M(E0M4W1O<FUS($5A<FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A
M+T1A=&$O='-V+G!H<#HQ-C8*(RP@9G5Z>GD*;7-G:60@(E135B!F:6QE(@IM
M<V=S='(@(E3M='5L;R(*"B,Z(&9R86UE=V]R:R]522]522]486)L92YP:'`Z
M,3,T"B,L(&9U>GIY"FUS9VED(")486)L92(*;7-G<W1R(")4[71U;&\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<S"FUS9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3<*;7-G:60@
M(E1A8FQE(%-E="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P
M97)T:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@
M(E1A:7=A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(Q.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")486II:VES=&%N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A;GIA;FEA+"!5
M;FET960@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T.B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3DV(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#<*;7-G:60@(E1A<VMS(@IM<V=S='(@
M(E1A<F5F87,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4W,PIM<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(Y,`IM<V=I9"`B5&5M<"!F;W(@;&%S="!H
M;W5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,30*
M;7-G:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,C,*;7-G:60@(E1E;7!E<F%T=7)E.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")496UP97)A='5R93QB<B`O/B@E<TAI)7,O
M)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]496UP
M;&%T92]496UP;&%T92YP:'`Z-C@W"B,L('!H<"UF;W)M870*;7-G:60@(E1E
M;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z,38Y"FUS9VED(")496UP;&%T92!!9&UI;FES=')A
M=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S8*;7-G:60@(E1E>'0B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-0IM<V=I
M9"`B5&5X="!/;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G:60@(E1E>'0@86QI
M9VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED
M(")4:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM
M<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z.3@X"B,L(&9U>GIY"FUS9VED(")4:&%N:R!Y;W4@9F]R
M('5S:6YG('1H92!S>7-T96TN(@IM<V=S='(@(D9I;F%L:7IO=2!A('-E<VGS
M;BX\8G(@+SY'<F%C:6%S('!O<B!U<V%R(&\@<VES=&5M82XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R,`IM<V=I9"`B5&AE($944"!E>'1E
M;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S
M=7!P;W)T(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-
M4U`O24U34"]";V]K+G!H<#HQ,CDR"FUS9VED(")4:&4@24U34"!L;V<@8V]U
M;&0@;F]T(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]M86EN=&5N86YC92YP:'`Z,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ
M(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I9"`B
M5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,C$Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(S"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,C8T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4
M:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE
M;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@
M4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T
M;VT@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N
M=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@
M;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU
M,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T
M;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V.0IM<V=I9"`B(@HB5&AE(&1E=&%C
M:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y
M('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@(B(*
M(E1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C
M:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D871A
M8F%S92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-#(*;7-G:60@(E1H92!D:7-T<FEB=71I;VX@
M;&ES="!W87,@;F]T('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+G!H<#HQ,3,*;7-G:60@(E1H92!E;F-R>7!T:6]N
M(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<U(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$S"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C@@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T
M:6YG<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,C$Y"FUS9VED(")4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O
M(&ET<V5L9BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP
M:'`Z,C@P"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R
M+G!H<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@
M9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM
M<V=I9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U
M<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O
M(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O
M=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y
M+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W
M<V5R(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX
M(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@
M(@HB4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<
M;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E("(*(G!R97-S($]+(&EF
M('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R
M+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D
M96QE=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD
M('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@
M1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ
M(&-L87-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$
M3BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E
M('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E
M;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H
M92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-PIM<V=I9"`B
M5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P
M86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C0T,0HC+"!F=7IZ>0IM<V=I9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@;75S
M="!B92!N=6UE<FEC+B(*;7-G<W1R(")/('9A;&]R(&1E8F4@<V5R('5N(&[Z
M;65R;RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R
M,S$*;7-G:60@(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@
M=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,CDP"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@
M<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU
M;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]D96(N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<G!M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]W96)C<'`N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y
M<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0U-`IM<V=I9"`B
M5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C
M=&5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@86YD(&QE
M9G0@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG
M:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z-#0V"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@
M8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C0Y"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E
M;B!R96UO=F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HS,S`*;7-G:60@(E1H92!S<&5C:69I960@<F]W(&1O
M97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R
M87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S$Q"FUS9VED(")4:&4@=&5X
M="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S
M8W)E96XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD(&)O
M='1O;2!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G:60@(E1H92!T
M;W`@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A
M=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@
M<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]$871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A;65W;W)K+T1A=&$O1&%T
M82]T<W8N<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@
M;F]T(&)E('-A=F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-#8@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4V
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,34@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$Q.0IM<V=I9"`B5&AE('=E871H97(N8V]M
M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z('5T:6PO
M:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M
M97,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3<X"B,L(&9U>GIY"FUS
M9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@
M(DYO;B!H86D@<')E9F5R96YC:6%S(&1I<W!O\6EB;&5S+B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C,T,@IM<V=I9"`B5&AE<F4@
M87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,#$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A
M8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R
M86-T97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S
M='(@(B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@
M7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@
M=&AE('-Y<W1E;3H@(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(')E
M;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE
M(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE
M(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI
M;75M("(*(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.3$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F
M:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L
M87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+VEM8RYP:'`Z,S$*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A
M<B!D871A+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C@P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I
M9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U
M:7)E9"!F:65L9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*(E1H97)E('=A
M<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B
M;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T
M:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T
M97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,C(R"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G
M86EN(&QA=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HQ-#@*;7-G:60@(E1H:7,@24U!4"!S97)V97(@
M9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*;7-G
M:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R
M8VAI=F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O
M(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,Q-#4*(RP@9G5Z>GD*;7-G:60@(E1H:7,@9&]E
M<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R
M(")/('9A;&]R(&1E8F4@<V5R('5N(&[Z;65R;RXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*;7-G:60@(B(*
M(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U
M9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED("(B
M"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O
M=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y+"!U
M<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G:60@(B(*(E1H
M:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@
M=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W
M87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-0IM<V=I
M9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@
M=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@(@HB9V%T97=A
M>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E
M;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D869O;F4@271A;'D@*&AT='`Z+R]W
M=W<N,3DP+FET*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.3<X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-3<*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`X-B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,3$U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#(@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(U-@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,S`U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S.3@*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34U-R!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-3@@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P-0HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,#(Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-S@*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$T.2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T
M,3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U-`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-C4W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S-R!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,S`V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,X,30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@R,@IM<V=I9"`B5&AI
M<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3`V-0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL
M>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-#$X"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DT"FUS9VED(")4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(S"FUS9VED(")4:&ES
M(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES
M="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HY.#D*(RP@9G5Z>GD*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B
M92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`B3R!V86QO<B!D96)E('-E<B!U
M;B!N^FUE<F\N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@S-@IM
M<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E
M(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T
M868G+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU
M-C$*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E
M9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N
M(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B
M"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E
M(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@
M<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.C4Y,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E
M<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R
M(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R(")/(&[Z;65R;R!D96)E
M('-E<B!P;VQO(&UE;F]S('5N(#$N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E<B!C86XG
M="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ.#D*;7-G
M:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C0*
M;7-G:60@(E1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS9W-T<B`B
M3R!V86QO<B!D96)E('-E<B!U;B!N^FUE<F\N(@H*(SH@<V5R=FEC97,O:6UA
M9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S
M="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-`IM
M<V=I9"`B5&AU;F1E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C,T"FUS9VED(")4:6-K971S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,C@@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")4:6UE(@IM<V=S='(@(E3M
M='5L;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#8*;7-G:60@
M(E1I;64@5')A8VMI;F<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N
M<&AP.C$W"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3,Y"FUS9VED(")4:6UE('-E;&5C=&EO
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4:6UO<BU,97-T
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P"FUS9VED(")4
M:71L92(*;7-G<W1R(")4[71U;&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-30*;7-G:60@(B(*(E1O
M('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L
M("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M,3$*;7-G:60@(E1O9&%Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,
M(%-O=7)C92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4;V=O
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O:V5L874B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,PIM
M<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I
M9"`B5&]N9V$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<W"FUS9VED(")4;W`B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M,PIM<V=I9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A;F0@5&]B
M86=O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W
M.3`*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5N:7-I82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(E1U<FMI<V@@
M*$E33RTX.#4Y+3DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@
M(E1U<FMM96YI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED
M(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,0IM<V=I9"`B5'5V86QU(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#3$DO0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8Y
M"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R
M86UE+G!H<#HQ-PIM<V=I9"`B55),(@IM<V=S='(@(E523"(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED
M(")54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY-PHC+"!F=7IZ>0IM<V=I9"`B55),.B(*;7-G<W1R(")54DPB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$R"FUS9VED(")59V%N9&$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,@IM<V=I9"`B56MR86EN92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,3(*(RP@9G5Z>GD*;7-G:60@(E5N
M86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F]N(&9O
M:2!P;W-I8FQE(&-O;F5C=&%R<V4@\R!S97)V:61O<B!344PN(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B;&4@
M=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,X
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI
M<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S@U(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-34*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N
M(@IM<V=S='(@(DYO;B!F;VD@<&]S:6)L92!C;VYE8W1A<G-E(/,@<V5R=FED
M;W(@4U%,+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C,R"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@
M;V8@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HV.#@@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ,#$V"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HX,S0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S
M+R5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L
M+G!H<#HT,S4*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V
M97(N(@IM<V=S='(@(DYO;B!F;VD@<&]S:6)L92!C;VYE8W1A<G-E(/,@<V5R
M=FED;W(@4U%,+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,Y
M"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB
M"FUS9W-T<B`B3F]N(&9O:2!P;W-I8FQE(&-O;F5C=&%R<V4@\R!S97)V:61O
M<B!344PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C(U(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C(P.0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N
M(@IM<V=S='(@(DYO;B!F;VD@<&]S:6)L92!C;VYE8W1A<G-E(/,@<V5R=FED
M;W(@4U%,+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S8U"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C
M=&]R>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C,U-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C4X
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR-38*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS
M9W-T<B`B3F]N(&9O:2!P;W-I8FQE(&-O;F5C=&%R<V4@\R!S97)V:61O<B!3
M44PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$R-`HC+"!F
M=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9FEL92XB"FUS9W-T
M<B`B3F]N(&9O:2!P;W-I8FQE(&-O;F5C=&%R<V4@\R!S97)V:61O<B!344PN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR.#8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,C8U"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&
M4R!F:6QE+B(*;7-G<W1R(").;VX@9F]I('!O<VEB;&4@8V]N96-T87)S92#S
M('-E<G9I9&]R(%-13"XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O=&%R+G!H<#HW-@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M9WII<"YP:'`Z-SD*;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C(T
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,CDX"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y
M(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM
M<V=S='(@(DYO;B!F;VD@<&]S:6)L92!M;V1I9FEC87(@87,@<')E9F5R96YC
M:6%S.B!;)61=("5S(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,S,Q(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,SDR"B,Z(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HS,3$@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C,S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0X(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-3(*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,W(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,C(*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C,S-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,S0S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#0*(RP@
M9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B3F]N(&9O:2!P;W-I8FQE(&-O;F5C=&%R<V4@\R!S97)V:61O
M<B!344PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,3<@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,CD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,#<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C,P,R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(X.`HC.B!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,38W(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HQ.#`*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X
M-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S@S"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.3$*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z,C0T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#`V"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,#,*
M(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D
M:7)E8W1O<GDN(@IM<V=S='(@(DYO;B!F;VD@<&]S:6)L92!R97AI<W1R87(@
M87,@<')E9F5R96YC:6%S(&YA('-E<VGS;BXB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8P,PIM<V=I9"`B56YA8FQE('1O(&5X=')A
M8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7TE-4U`O24U34"YP:'`Z-#4Q(&9R86UE=V]R:R].971?24U34"])
M35-0+T%U=&@N<&AP.C$Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,38V(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-S$*
M(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G
M<W1R(").;VX@9F]I('!O<VEB;&4@8V]N96-T87)S92#S('-E<G9I9&]R(%-1
M3"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.CDS(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z,3`R"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z-C0X(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR
M-S<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S,`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,S"FUS9VED(")5;F%B;&4@
M=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z.#`@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HW,@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I
M;&4N(@IM<V=S='(@(DYO;B!F;VD@<&]S:6)L92!C;VYE8W1A<G-E(/,@<V5R
M=FED;W(@4U%,+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z-#4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R
M97-S960@87)C:&EV92XB"FUS9W-T<B`B3F]N(&9O:2!P;W-I8FQE(&-O;F5C
M=&%R<V4@\R!S97)V:61O<B!344PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C@S-0IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S
M:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C@V-@IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E
M=$9I;&53:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"FUS
M9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C8Y"FUS9VED(")5;F%B;&4@=&\@
M<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$P-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F
M;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(Y,PHC+"!F=7IZ>0IM<V=I9"`B56YA
M8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").;VX@9F]I
M('!O<VEB;&4@8V]N96-T87)S92#S('-E<G9I9&]R(%-13"XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(V-R!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C,T,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C$P(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HR,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,C,@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C(Q,PHC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z-#4R(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.#4*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,P,0IM<V=I9"`B56YA
M8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS
M9VED(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I
M9"`B56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS
M9W-T<B`B3F]N(&9O:2!P;W-I8FQE('1R861U8VER(&5S=&4@9&]C=6UE;G1O
M(&1E(%=O<F0B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$T.2!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$U,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-SD*;7-G:60@
M(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(X,2!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,X"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-#,*;7-G:60@(E5N86)L92!T;R!W
M<FET92!61E,@9FEL92!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z.#0Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4L('%U;W1A('=I;&P@8F4@97AC965D960N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*;7-G:60@
M(E5N9&5R;&EN92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O96YD
M+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B1&5S9F%C97(@
M;W,@8V%M8FEO<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C(R,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS.3`*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@
M;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS-#$*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S<X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,X-`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS
M92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q"FUS9VED(")5;F9I
M;&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS"FUS
M9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*
M;7-G:60@(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R($]U=&QY
M:6YG($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C8Y(&QI8B]";&]C:R]M971A<BYP:'`Z-S$*;7-G:60@(E5N
M:71S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0R.2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,S`*;7-G
M:60@(E5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P
M:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I
M9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y"FUS
M9VED(")5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3$*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE
M;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y
M+G!H<#HR.38*(RP@9G5Z>GD*;7-G:60@(E5N;F%M960B"FUS9W-T<B`B57-U
M87)I;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A
M8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S
M96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L
M(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T
M;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX,@IM<V=I9"`B56YS970@8V]L;W(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#8@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,C8*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HY,S(*;7-G:60@(E5N<W5P<&]R=&5D($5X
M=&5N<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$Y-R!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,PIM
M<V=I9"`B57!D871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E
M("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z-S8*;7-G:60@(E5P9&%T92!U<V5R(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z,30T(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S
M97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,P"B,L('!H<"UF;W)M870*;7-G
M:60@(E5P9&%T960@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HX,PIM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E
M9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W."!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DY"FUS9VED
M(")5<&QO860B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$X-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I
M;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@
M(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I
M9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$S"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L('!H<"UF;W)M
M870*;7-G:60@(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I
M9"`B57-E(%-33"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3(T"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E
M;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"B,L(&9U>GIY"FUS9VED(")5<V5R
M(@IM<V=S='(@(E5S=6%R:6\B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M4F5G:7-T<GDN<&AP.C<R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S
M(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,C`S"FUS9VED(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C4Q
M"FUS9VED(")5<V5R($]P=&EO;G,B"FUS9W-T<B`B3W!C:?-N<R!D;R!U<W5A
M<FEO(@H*(SH@<VEG;G5P+G!H<#HV,@HC+"!F=7IZ>0IM<V=I9"`B57-E<B!2
M96=I<W1R871I;VXB"FUS9W-T<B`B3W!C:?-N<R!D;R!U<W5A<FEO(@H*(SH@
M<VEG;G5P+G!H<#HR,@IM<V=I9"`B57-E<B!296=I<W1R871I;VX@:&%S(&)E
M96X@9&ES86)L960@9F]R('1H:7,@<VET92XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C0V.0IM<V=I9"`B57-E<B!A8V-O=6YT(&YO
M="!F;W5N9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.CDX"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,"!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HS,PHC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C<R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED
M(")5<V5R;F%M92(*;7-G<W1R(")5<W5A<FEO(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]3:6=N=7`N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M<V5R;F%M92!<(B5S7"(@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PHC+"!F=7IZ>0IM<V=I
M9"`B57-E<FYA;64Z(@IM<V=S='(@(E5S=6%R:6\B"@HC.B!T96UP;&%T97,O
M;&]G:6XO;6]B:6QE+FEN8SHX"B,L(&9U>GIY"FUS9VED(")5<V5R;F%M93H@
M(@IM<V=S='(@(E5S=6%R:6\B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L
M:7-T+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$V,R!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR-34*;7-G:60@(E9&4R!D:7)E8W1O<GD@
M9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ,3@*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@V-@IM<V=I9"`B5F%L:60@;&]C
M871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.`IM<V=I9"`B5F%L:61I='DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU.3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C4U"FUS9VED(")686QU92!I;B!M:6YU=&5S(&9R
M;VT@;F]W+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HX-38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$W-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O
M9B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C(T-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8V"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(S,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,CDR.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP
M.C4Y"FUS9VED(")686QU97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C$P.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@V
M"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0T"FUS9VED(")687)I86)L92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")696YE>G5E;&$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR
M,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@
M;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B5F5R
M<VEO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C(V"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM
M<V=I9"`B5F5R=&EC86P@86QI9VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC
M86P@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-S`*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V
M"FUS9VED(")6:65T($YA;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y-`IM<V=I9"`B5FEE=&YA;65S92`H5DE30TE)*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HY-C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO:69R86UE+G!H<#HS"FUS9VED(")6:65W(&%N(&5X=&5R;F%L
M('=E8B!P86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C@R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&%S
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)
M<VQA;F1S+"!"<FET:7-H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G
M:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C`Y"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-C,*;7-G:60@
M(E9I<VEB:6QI='DZ("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-`IM<V=I9"`B5F]D869O
M;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO
M=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS
M-@IM<V=I9"`B5T%23B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'(2$A(%)%
M34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G:60@
M(E=)3B!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED
M(")786QL:7,@86YD($9U='5N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP
M.C(Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C(W
M,B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#,*;7-G:60@(E=A<FYI;F<B"FUS
M9W-T<B`B079I<V\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H97(@1F]R96-A
M<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C0R-PIM<V=I9"`B5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y,@IM<V=I9"`B5V5A
M=&AE<BYC;VTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M,S8*;7-G:60@(E=E8B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#,W"FUS9VED(")796(@4VET92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4X"FUS9VED
M(")7965K;'DB"FUS9W-T<B`B4V5M86YA;&UE;G1E(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+VUO8FEL92YP:'`Z,C@*(RP@9G5Z>GD*;7-G:60@(E=E;&-O;64B
M"FUS9W-T<B`B0F5N=FED;R]A+"`E<R(*"B,Z('1E;7!L871E<R]L;V=I;B]M
M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(D)E;G9I
M9&$@82`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E
M;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")796QC;VUE+"`E<R(*;7-G<W1R(")"96YV:61O+V$L("5S(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y
M+3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS
M9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I
M;C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z
M,30*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS
M9VED(")7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#8Q
M"FUS9VED(")7:&5R96ES($%U<W1R86QI82!M87`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S97,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,PIM<V=I9"`B
M5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I
M=&]R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED(")7:61T:"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(U"FUS9VED(")7:61T
M:"!I;B!#4U,@=6YI=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@
M)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G
M+6EN*3HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q,`IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0IM<V=I
M9"`B5VED=&@Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HU,3,*;7-G:60@(E=I:VDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,P,"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B5VEN9"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@IM<V=I9"`B
M5VEN9"!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C@P"FUS9VED(")7:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,34V"FUS9VED(")7:6YD.B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0R"FUS9VED
M(")7:6YD.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C8T"FUS9VED(")7:7-D;VTB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,C0*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$V-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(D5N9&5R97IO(&1O
M('1R86)A;&QO(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R(")496SI9F]N
M;R!D;R!T<F%B86QL;R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C$V.2!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR-C(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D
M+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,P,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@
M)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C$Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!O9F9S970@)60@=VAI
M;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C0S"FUS9VED(")8+5)E9B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I
M9"`B6#4P.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DR"FUS9VED(")8-3`Y
M=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@4W5B
M:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B
M:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X,@IM<V=I9"`B6#4P.78S(&5X=&5N
M<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G
M:60@(EE9(@IM<V=S='(@(D%!(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0Q,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#4U"B,L(&9U>GIY"FUS9VED(")965E9(@IM<V=S
M='(@(D%!(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$Q,#@*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I9"`B
M665A<FQY(@IM<V=S='(@(D%N=6%L;65N=&4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS
M9VED(")996UE;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED(")997,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*
M;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R"FUS9VED(")9;W4@87)E
M(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H
M(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+V5D:70N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@
M;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,30Q,0IM
M<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC871E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS,#(*;7-G:60@
M(EEO=2!C86X@;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@
M9G5L;"!N86UE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.#4U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S4*;7-G:60@
M(EEO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,CDP"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@
M9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F
M:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.CDX.`HC+"!F=7IZ>0IM<V=I9"`B66]U(&AA=F4@8F5E;B!L
M;V=G960@;W5T+B(*;7-G<W1R(")!8W1U86QI>N%R;VYS92!A<R!S^F%S(&]P
M8VGS;G,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(V,0IM<V=I
M9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M
M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F;W(@
M=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#@*;7-G:60@(EEO=2!H
M879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU
M<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT
M-38*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ
M,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E
M('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@(D1E
M<V-R:6)A(&\@<')O8FQE;6$@86YT97,@9&4@96YV:6%R(&\@:6YF;W)M92XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX
M"FUS9VED(")9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN
M:R!P;VEN=',@=&\B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P
M8W-U;2YP:'`Z.#`*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@
M=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,3$Y"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE
M87(@;W5T+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#`*;7-G
M:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T
M:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ-#8*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE
M('1O('5P9&%T92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+WII<"YP:'`Z,3,X"FUS9VED(")9;W4@;75S="!S<&5C:69Y
M('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"FUS9VED
M(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M
M='`N<&AP.C<S"FUS9VED(")9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI
M86X@<&AO;F4@;G5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.CDW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R("5S('-E
M<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T
M<B`B0V%D=6-O=2!A('/Z82!S97-I\VX@96X@)7,@97AP:7)O=2X@26YI8VEE
M('5N:&$@;F]V82!S97-I\VXN(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z,S@*(RP@9G5Z>GD*;7-G:60@(EEO=7(@16UA:6P@061D<F5S
M<R(*;7-G<W1R(")%;F1E<F5Z;R!D92!C;W)R96\@96QE8W1R\VYI8V\Z(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q,@HC+"!F=7IZ>0IM<V=I9"`B
M66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R(")%;F1E<F5Z;R!D92!C;W)R
M96\@96QE8W1R\VYI8V\Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8T
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-"!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y"FUS9VED(")9;W5R
M($EN9F]R;6%T:6]N(@IM<V=S='(@(D$@<_IA(&EN9F]R;6%C:?-N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@P"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC
M92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O
M=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*
M(RP@9G5Z>GD*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R(").;VUE.B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHU"FUS9VED("(B"B)9
M;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A
M9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A
M9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E
M<F5N="`B"B)A=71H96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*;7-G:60@(B(*
M(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T
M(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I
M<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@T"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S
M:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@
M<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3`*;7-G:60@
M(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z
M-#(*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H
M:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*
M(G1O('!R:6YT+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C4W"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.38*(RP@9G5Z>GD*;7-G:60@
M(EEO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G
M<W1R(")!8W1U86QI>N%R;VYS92!A<R!S^F%S(&]P8VGS;G,N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$U.`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!D
M969A=6QT(&ED96YT:71Y.B(*;7-G<W1R("))9&5N=&ED861E('!R961E=&5R
M;6EN861A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P,0HC+"!F=7IZ
M>0IM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@(DYO;64Z(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z,3`P,`HC+"!F=7IZ>0IM<V=I9"`B
M66]U<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T<B`B06-T=6%L:7KA<F]N
M<V4@87,@<_IA<R!O<&-I\VYS+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W
M;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ-30*(RP@9G5Z>GD*;7-G:60@(EEO=7(@;W!T
M:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H
M:7,@<V5S<VEO;BXB"FUS9W-T<B`B06-T=6%L:7KA<F]N<V4@87,@<_IA<R!O
M<&-I\VYS+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34V
M"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S
M='(@(D%C='5A;&EZX7)O;G-E(&%S('/Z87,@;W!C:?-N<RXB"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R
M9"!H87,@8F5E;B!R97-E="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@
M8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@
M>6]U<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.C<S,@IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@
M97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C4X"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-"!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*
M;7-G:60@(EIA:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@
M(EIA;6)I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")::6UB
M86)W92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*
M;7-G:60@(EII<'!Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I
M;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E
M(%%U;W1E9"!497AT72(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F]B;&5M
M+G!H<#HX.`IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R(");26YF
M;W)M92!D;R!0<F]B;&5M85TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q
M=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI
M9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,L('!H<"UF;W)M870*;7-G:60@(EM3
M:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G
M:60@(EML:6YE("5S(&]F("5S72(*;7-G<W1R(");;&GQ82`E<R!D92`E<UTB
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U-#$@=&5M<&QA=&5S
M+W!O<G1A;"]M96YU+FEN8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I9"`B7T-,22(*;7-G
M<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#$*;7-G:60@(E]$871A5')E92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S$*;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@
M(B(*"B,Z(&QI8B]A<&DN<&AP.C$S,PIM<V=I9"`B7T=R;W5P<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3<U"B,L
M(&9U>GIY"FUS9VED(")?2&5L<"(*;7-G<W1R(")!>'5D82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM
M<V=I9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y-`HC+"!F=7IZ>0IM<V=I
M9"`B7TQO9R!I;B(*;7-G<W1R(")%;G1R87(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O365N=2YP:'`Z,3DP"B,L(&9U>GIY"FUS9VED(")?3&]G(&]U
M="(*;7-G<W1R(")096-H87(@82!S97-I\VXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G:60@(E]-
M;V1I9GD@3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O365N=2YP:'`Z,38T"B,L(&9U>GIY"FUS9VED(")?3W!T:6]N<R(*
M;7-G<W1R(")/<&-I\VYS(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?
M4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V"B,L(&9U>GIY"FUS9VED
M(")?4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`B4V%C87(@;R!P87(B"@HC.B!L
M:6(O87!I+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S,*;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]A<&DN<&AP.C$R.0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Q"B,L(&9U>GIY"FUS9VED
M(")A9&1R97-S(&)O;VLB"FUS9W-T<B`B07AE;F1A(&1E(&5N9&5R97IO<R(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,T"FUS9VED
M(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDQ,PHC+"!F=7IZ>0IM<V=I9"`B8V%L96YD87(B
M"FUS9W-T<B`B0V%L96YD87)I;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,3<R(&QI8B]";&]C:R]M971A<BYP:'`Z,S4X"B,L('!H<"UF;W)M870*;7-G
M:60@(F-A;&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I
M;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,@IM<V=I
M9"`B8VQI8VL@:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E
M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,3<X"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34T
M"FUS9VED(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(V"FUS
M9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$X,@IM<V=I9"`B96YT<GD@;F]T
M(&9O=6YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")F86QL:6YG(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U-0HC+"!F=7IZ>0IM
M<V=I9"`B9FEL92(*;7-G<W1R(")4[71U;&\B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$W-"!L:6(O0FQO8VLO;65T87(N<&AP.C,V,"!L:6(O0FQO8VLO
M;65T87(N<&AP.C,X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E
M<R`H)7,I(&%T("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-3`*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T.0IM
M<V=I9"`B:#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C,U.`IM<V=I9"`B:&@B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO
M<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM
M961I871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*
M;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N
M86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E
M<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-CD*;7-G
M:60@(FUM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,CDQ('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S`*(SH@
M<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(S,@HC+"!F=7IZ>0IM<V=I
M9"`B;F%M92(*;7-G<W1R(").;VUE(@H*(SH@9G)A;65W;W)K+U)00R]24$,N
M<&AP.C$R,0IM<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(Q.0IM<V=I9"`B
M;F]T('EE="!I;7!L96UE;G1E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDP-0IM<V=I9"`B;F]T97!A9"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@X"FUS9VED(")P97)C96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<T"FUS9VED(")P97)M:7-S:6]N
M(&1E;FEE9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S`*
M;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,PHC+"!F
M=7IZ>0IM<V=I9"`B<FES:6YG(@IM<V=S='(@(D%V:7-O(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#(*;7-G:60@(G-E<G9I8V4@
M=6YA=F%I;&%B;&4B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HY.0IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q
M-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS.#4*;7-G:60@
M(G-S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C<R"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,#D*;7-G:60@(G-W:71C:"!O9F8@
M:F%V87-C<FEP="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Y"FUS9VED(")T
M87-K(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S`U"B,L(&9U
M>GIY"FUS9VED(")T<GD@86=A:6XB"FUS9W-T<B`B0V%D82!I;FEC:6\@9&4@
M<V5S:?-N(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@
M='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D
M:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B=6YI
M9FEE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U!A<G0N
M<&AP.C(W"FUS9VED(")U;FYA;65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I
M9"`B=7-E<B!S96QE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R
M(")487)X971A(&1E('9I<VET82`H=D-A<F0I(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T,0IM<V=I9"`B=SHB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@
M(G=E871H97(N8V]M(@IM<V=S='(@(B(*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O8V%?15,N
M<&\`````````````````````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P-S$R-C,P(#$P-3$U-#,S-S0R(#`Q-S4P,``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````C($AO<F1E($-A=&%L86X@
M=')A;G-L871I;VXN"B,@0V]P>7)I9VAT("A#*2`R,#`T($AO<F1E(%!R;VIE
M8W0*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@
M;&EC96YS92!A<R!T:&4@2&]R9&4@<&%C:V%G92X*(R!*;W)D:2!':7)A;'0@
M/'!R;VIE8W1E+FLR0'5P8VYE="YE<SXL(#(P,#8N"B,*;7-G:60@(B(*;7-G
M<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,#5<;B(*(E)E
M<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)0
M3U0M0W)E871I;VXM1&%T93H@,C`P-BTP-2TQ,2`Q,CHU,2LP,C`P7&XB"B)0
M3RU2979I<VEO;BU$871E.B`R,#`V+3`W+3$T(#$Q.C`X*S`Q,#!<;B(*(DQA
M<W0M5')A;G-L871O<CH@2F]R9&D@1VER86QT(#QP<F]J96-T92YK,D!U<&-N
M970N961U/EQN(@HB3&%N9W5A9V4M5&5A;3H@0V%T86QA;B`\9&5V0&QI<W1S
M+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT
M+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,5QN(@HB0V]N
M=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C0Y"FUS9VED("(B"B(@("U-+"`M+6UE<W-A9V4]34534T%'
M12`@57-E('1H:7,@8V]M;6ET(&UE<W-A9V4@:6YS=&5A9"!O9B!T:&4@9&5F
M875L="!O;F5S+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-3,*;7-G:60@(B(*(B`@+6$L("TM861D/49)3$4@("`@("`@($%D9"!T:&ES
M(%!/(&9I;&4@=&\@=&AE(&-O;7!E;F1I=6TN(%5S969U;"!T;UQN(@HB("`@
M("`@("`@("`@("`@("`@("`@("`@:6YC;'5D92!A(&-O;7!E;F1I=6T@9G)O
M;2!A(&1I9F9E<F5N="!B<F%N8V@@=&]<;B(*(B`@("`@("`@("`@("`@("`@
M("`@("`@('1H92!G96YE<F%T960@8V]M<&5N9&EU;2XB"FUS9W-T<B`B(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C$Q,PIM<V=I9"`B(@HB("`M8BP@+2UB
M87-E/2]0051(("!&=6QL('!A=&@@=&\@=&AE("A(;W)D92D@8F%S92!D:7)E
M8W1O<GD@=&AA="!S:&]U;&0@8F5<;B(*(B`@("`@("`@("`@("`@("`@("`@
M=7-E9"XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8Y"FUS
M9VED("(B"B(@("UC+"`M+6-O;7!E;F1I=6T]1DE,12`@365R9V4@;F5W('1R
M86YS;&%T:6]N<R!T;R!T:&ES(&-O;7!E;F1I=6T@9FEL95QN(@HB("`@("`@
M("`@("`@("`@("`@("`@("`@(&EN<W1E860@;V8@=&AE(&1E9F%U;'0@;VYE
M("AC;VUP96YD:75M+G!O(&EN('1H95QN(@HB("`@("`@("`@("`@("`@("`@
M("`@("`@(&AO<F1E+W!O(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C8S('!O+W1R86YS;&%T:6]N+G!H<#HX,2!P;R]T
M<F%N<VQA=&EO;BYP:'`Z.#<*;7-G:60@(B(*(B`@+6,L("TM8V]M<&5N9&EU
M;3U&24Q%("!5<V4@=&AI<R!C;VUP96YD:75M(&9I;&4@:6YS=&5A9"!O9B!T
M:&4@9&5F875L=%QN(@HB("`@("`@("`@("`@("`@("`@("`@("`@(&]N92`H
M8V]M<&5N9&EU;2YP;R!I;B!T:&4@:&]R9&4O<&\@9&ER96-T;W)Y*2XB"FUS
M9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$Q-`IM<V=I9"`B("`M
M9"P@+2UD96)U9R`@("`@("!3:&]W(&5R<F]R(&UE<W-A9V5S(&9R;VT@=&AE
M(&5X96-U=&5D(&)I;F%R:65S+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z-30*;7-G:60@(B`@+60L("TM9&ER96-T;W)Y/41)4B`@($-R
M96%T92!C;VUP96YD:75M(&EN('1H:7,@9&ER96-T;W)Y+B(*;7-G<W1R("(B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$U"FUS9VED("(@("UH+"`M+6AE
M;'`@("`@("`@(%-H;W<@=&AI<R!H96QP(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT,B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-C<@<&\O=')A;G-L871I;VXN<&AP.C<U"FUS9VED("(@("UL+"`M+6QO8V%L
M93UL;%]#0R`@("`@57-E(&]N;'D@=&AI<R!L;V-A;&4N(@IM<V=S='(@(B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT-R!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-C$@<&\O=')A;G-L871I;VXN<&AP.C<Y"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HX-0IM<V=I9"`B("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S92!T:&ES
M(&QO8V%L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C4U
M"FUS9VED("(@("UL+"`M+6QO8V%L93UL;%]#0R`@("!5<V4@=&AI<R!L;V-A
M;&4N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV.`IM<V=I
M9"`B("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($)U:6QD($U/(&9I;&5S(&]N
M;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N(@IM<V=S='(@(B(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HT,PIM<V=I9"`B("`M;2P@+2UM;V1U;&4]34]$
M54Q%("`@($-L96%N=7`@4$\@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I
M(&UO9'5L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0X
M"FUS9VED("(B"B(@("UM+"`M+6UO9'5L93U-3T153$4@("`@0V]M;6ET('1R
M86YS;&%T:6]N<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+B(*;7-G
M<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C(*;7-G:60@(B`@+6TL
M("TM;6]D=6QE/4U/1%5,12`@("!#<F5A=&4@82!03R!F:6QE(&]N;'D@9F]R
M('1H:7,@*$AO<F1E*2!M;V1U;&4N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HX,`IM<V=I9"`B("`M;2P@+2UM;V1U;&4]34]$54Q%("`@
M($UE<F=E(%!/(&9I;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N
M(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW-@IM<V=I9"`B
M(@HB("`M;2P@+2UM;V1U;&4]34]$54Q%("`@(%5P9&%T92!H96QP(&9I;&5S
M(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N(@IM<V=S='(@(B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HX-@IM<V=I9"`B("`M;2P@+2UM;V1U;&4]
M34]$54Q%("`@(%5P9&%T92!O;FQY('1H:7,@*$AO<F1E*2!M;V1U;&4N(@IM
M<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HU.`IM<V=I9"`B("`M
M;2P@+2UM;V1U;&4]34]$54Q%("!'96YE<F%T92!03U0@9FEL92!O;FQY(&9O
M<B!T:&ES("A(;W)D92D@;6]D=6QE+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z-S`*;7-G:60@(B(*(B`@+6XL("TM;F\M8V]M<&5N9&EU
M;2`@("!$;VXG="!M97)G92!N97<@=')A;G-L871I;VYS('1O('1H92!C;VUP
M96YD:75M+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C0@
M<&\O=')A;G-L871I;VXN<&AP.C@R('!O+W1R86YS;&%T:6]N+G!H<#HX.`IM
M<V=I9"`B("`M;BP@+2UN;RUC;VUP96YD:75M("`@($1O;B=T('5S92!A(&-O
M;7!E;F1I=6TN(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW
M,0IM<V=I9"`B("`M<RP@+2US=&%T:7-T:6-S("`@("`@(%-A=F4@=')A;G-L
M871I;VX@<W1A=&ES=&EC<R!I;B!A(&QO8V%L(&9I;&4N(@IM<V=S='(@(B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,38*;7-G:60@(B`@+70L("TM=&5S
M="`@("`@("`@4VAO=R!T:&4@97AE8W5T960@8V]M;6%N9',@8G5T(&1O;B=T
M(')U;B!A;GET:&EN9RXB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C$P-0IM<V=I9"`B(@HB("!C;&5A;G5P("`@("!#;&5A;G,@=&AE(%!/
M(&9I;&5S('5P(&9R;VT@=6YT<F%N<VQA=&5D(&%N9"!O8G-O;&5T92!E;G1R
M:65S+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`X"FUS
M9VED("(@(&-O;6UI="`@("`@($-O;6UI="!T<F%N<VQA=&EO;G,@=&\@=&AE
M($-64R!S97)V97(N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HQ,#D*;7-G:60@(B`@8V]M;6ET+6AE;'`@0V]M;6ET(&AE;'`@9FEL97,@
M=&\@=&AE($-64R!S97)V97(N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HY.0IM<V=I9"`B(@HB("!C;VUP96YD:75M("!296)U:6QD('1H
M92!C;VUP96YD:75M(&9I;&4N(%=A<FYI;F<Z(%1H:7,@;W9E<G=R:71E<R!T
M:&5<;B(*(B`@("`@("`@("`@("`@8W5R<F5N="!C;VUP96YD:75M+B(*;7-G
M<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`P"FUS9VED("(@(&5X
M=')A8W0@("`@($=E;F5R871E(%!/('1E;7!L871E("@N<&]T*2!F:6QE<RXB
M"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.CDX"FUS9VED("(@
M(&AE;'`@("`@("`@(%-H;W<@=&AI<R!H96QP(&UE<W-A9V4N(@IM<V=S='(@
M(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#$*;7-G:60@(B(*(B`@:6YI
M="`@("`@("`@0W)E871E(&]N92!O<B!M;W)E(%!/(&9I;&5S(&9O<B!A(&YE
M=R!L;V-A;&4N(%=A<FYI;F<Z(%1H:7-<;B(*(B`@("`@("`@("`@("`@;W9E
M<G=R:71E<R!T:&4@97AI<W1I;F<@4$\@9FEL97,@;V8@=&AI<R!L;V-A;&4N
M(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#8*;7-G:60@
M(B`@;6%K92`@("`@("`@0G5I;&0@8FEN87)Y($U/(&9I;&5S(&9R;VT@=&AE
M('-P96-I9FEE9"!03R!F:6QE<RXB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C$P-PIM<V=I9"`B(@HB("!M86ME+6AE;'`@("!-87)K(&%L
M;"!E;G1R:65S(&EN('1H92!834P@:&5L<"!F:6QE(&)E:6YG('5P+71O+61A
M=&4@86YD7&XB"B(@("`@("`@("`@("`@('!R97!A<F4@=&AE(&9I;&4@9F]R
M('1H92!N97AT(&5X96-U=&EO;B!O9B!U<&1A=&4M:&5L<"X@66]U7&XB"B(@
M("`@("`@("`@("`@('-H;W5L9"!O;FQY(')U;B!M86ME+6AE;'`@049415(@
M=7!D871E+6AE;'`@86YD(')E=FES:6YG('1H95QN(@HB("`@("`@("`@("`@
M("!H96QP(&9I;&4N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HQ,#(*;7-G:60@(B(*(B`@;65R9V4@("`@("`@365R9V4@=&AE(&-U<G)E
M;G0@4$\@9FEL92!W:71H('1H92!C=7)R96YT(%!/('1E;7!L871E(&9I;&4N
M(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#,*;7-G:60@
M(B`@=7!D871E("`@("`@4G5N(&5X=')A8W0@86YD(&UE<F=E('-E<75E;G0N
M(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#0*;7-G:60@
M(B(*(B`@=7!D871E+6AE;'`@17AT<F%C="!A;&P@;F5W(&%N9"!C:&%N9V5D
M(&5N=')I97,@9G)O;2!T:&4@16YG;&ES:"!834P@:&5L<%QN(@HB("`@("`@
M("`@("`@("!F:6QE(&%N9"!M97)G92!T:&5M('=I=&@@=&AE(&5X:7-T:6YG
M(&]N97,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C
M;VYF:7)M7W1O<"YI;F,Z,3$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(B(*(B`F(S$U,3L@)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B(*;7-G<W1R("(B"B)-
M87)Q=65U(&$@;&$@8V%S96QL82!L)V]P97)A8VGS(&\@;W!E<F%C:6]N<R!Q
M=64@9&5S:71G974@97AE8W5T87(@96X@(@HB87%U97-T82!O8V%S:?,N(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B("@E<R!D87ES(&%G;RDB"FUS9W-T<B`B*&9A("5S(&1I97,I(@H*(SH@
M;&EB+TAO<F1E+G!H<#HQ,C0W"B,L('!H<"UF;W)M870*;7-G:60@(B`H06-C
M97-S:V5Y("5S*2(*;7-G<W1R("(@*$-L874@9"=A8V/I<R`E<RDB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C,W-0HC+"!P:'`M9F]R;6%T"FUS9VED("(@
M*&EN("5S(&1A>7,I(@IM<V=S='(@(BAE;B`E<R!D:65S*2(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR,S<Q"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(H
M879U:2DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W,PIM<V=I9"`B("AT
M;VUO<G)O=RDB"FUS9W-T<B`B*&1E;>`I(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(S-CD*;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(H86AI<BDB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0S"FUS9VED("(@
M870@(@IM<V=S='(@(F5N(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C(Q-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(*
M;7-G<W1R(")<(B5S7"(@;F\@Z7,@=6X@9&ER96-T;W)I+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,CD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)60@)7,@86YD("5S(@IM<V=S='(@(B5D("5S(&D@)7,B"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,3$W-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!B
M>71E<R!W<FET=&5N+B(*;7-G<W1R("(E9"!B>71E<R!E<V-R:71S+B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HQ,C@T"B,L('!H<"UF;W)M870*;7-G:60@
M(B5D(&]F("5D(&5N=')I97,@;6%R:V5D(&%S('5P+71O+61A=&4B"FUS9W-T
M<B`B)60@9&4@)60@96YT<F%D97,@;6%R8V%D97,@8V]M(&%C='5A;&ET>F%D
M97,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C<P"B,L('!H
M<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R(")P<F5V
M:7-I\R!P97(@86P@9&EA("5D(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E
M+VYO=&EC95]T;W`N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.
M;W1I8V4B"FUS9W-T<B`B07;M<R`M("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+V-O;6UO;BUH96%D97(N:6YC.C,R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(E<R!!9&UI;FES=')A
M8VGS(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B16UP<F5M
M=&$@9&%C=&EL87(@)7,B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP
M:'`Z.#(V(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX,C@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B)7,@2T(B"@HC.B!T96UP
M;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC.C0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I
M<FUA=&EO;B(*;7-G<W1R(")/<&5R86-I;VYS(&1E(&UA;G1E;FEM96YT("5S
M("T@0V]N9FER;6%C:?,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$X
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@4V5T=7`B"FUS9W-T<B`B0V]N9FEG=7)A8VGS(&1E("5S(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-C,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R(")!;'1A(&1E("5S(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+V%G<F5E;65N=%]T;W`N:6YC.C0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S='(@
M(D-O;F1I8VEO;G,@9&5L(&-O;G1R86-T92`E<R(*"B,Z(&QI8B]61E,O9G1P
M+G!H<#HU-C@@;&EB+U9&4R]F='`N<&AP.C8S-B!L:6(O5D93+W-M8BYP:'`Z
M-#,P"B,Z(&QI8B]61E,O<VUB+G!H<#HT.3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B5S(&IA(&5X:7-T96EX
M+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34W(&QI8B]";&]C:R]M971A
M<BYP:'`Z,38S(&QI8B]";&]C:R]M971A<BYP:'`Z,C,W"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S0S(&QI8B]";&]C:R]M971A<BYP:'`Z,S0Y"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B5S(&5N("5S
M("5S(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C(X-R!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,S$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!N
M;W0@=W)I=&%B;&4N(@IM<V=S='(@(B<E<R<@;F\@Z7,@=6YA(&]P8VGS(';@
M;&ED82XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,S.`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("+)<R!N96-E<W-A
M<FD@)7,N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R("(E<R!M:6YU=',B"@HC
M.B!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3(S('!O+W1R86YS
M;&%T:6]N+G!H<#HQ,S4P"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&YO="!F
M;W5N9"XB"FUS9W-T<B`B3F\@<R=H82!T<F]B870@)7,N(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C4X-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@
M9F]U;F0N(%)U;B`G=')A;G-L871I;VX@97AT<F%C="<@9FER<W0N(@IM<V=S
M='(@(B5S(&YO('1R;V)A="X@17AE8W5T82`G=')A;G-L871I;VX@97AT<F%C
M="<@<')I;65R+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T
M<B`B)7,@86P@)7,@9&4@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C@Y
M,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*;7-G
M<W1R("),;&EB<F5T82!D)V%D<F5C97,@9&4@)7,B"@HC.B!L:6(O2&]R9&4O
M2V]L86(N<&AP.C@X,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N
M9&%R(@IM<V=S='(@(D%G96YD82!D92`E<R(*"B,Z(&QI8B](;W)D92]+;VQA
M8BYP:'`Z.#<U"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*
M;7-G<W1R(")";&]C(&1E(&YO=&5S(&1E("5S(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HX.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES
M="(*;7-G<W1R("),;&ES=&$@9&4@=&%S<75E<R!D92`E<R(*"B,Z(&QI8B](
M;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B)7,Z("5S(@H*(SH@
M;&EB+TAO<F1E+T-,22YP:'`Z,C<R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED("(G)7,G(&ES(&YO="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B)R5S
M)R!N;R#I<R!U;F$@;W!C:?,@=N!L:61A+B(*"B,Z(&QI8B](;W)D92]296=I
M<W1R>2YP:'`Z-34T(&QI8B](;W)D92]296=I<W1R>2YP:'`Z.3(Y"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("(G)7,G(&ES(&YO="!C;VYF:6=U<F5D
M(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B)R5S)R!N;R!E<W3@
M(&-O;F9I9W5R870@96X@96P@<F5G:7-T<F4@9&4@2&]R9&4N(@H*(SH@;&EB
M+TAO<F1E+U1R964N<&AP.C$V-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B)R5S)R!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B3F\@
M<R=H82!T<F]B870@96P@9V5N97)A9&]R(&0G87)B<F5S("<E<R<N(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HU-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B)R5S)R!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S
M='(@(E,G:&$@869E9VET("<E<R<@86P@<VES=&5M82!D92!G<G5P<RXB"@HC
M.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z.#4*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(B<E<R<@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N
M<R!S>7-T96TN(@IM<V=S='(@(E,G:&$@869E9VET("<E<R<@86P@<VES=&5M
M82!D92!L;&ECZ&YC:65S+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-34@861M
M:6XO<&5R;7,O861D8VAI;&0N<&AP.C@S"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("(G)7,G('=A<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(B<E
M<R<@;F\@:&$@97-T870@8W)E870Z("5S+B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3@V(&QI8B]";&]C:R]M971A<BYP:'`Z,3DQ"B,L('!H<"UF;W)M
M870*;7-G:60@(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(L('9E;G3S<R`E
M<R`E<R`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Y.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B
M+"!V87)I86)L92!D92`E<R!A("5S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(P-CD@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,C@*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8X.`IM<V=I9"`B+2T@<V5L96-T("TM
M(@IM<V=S='(@(BTM('-E;&5C8VEO;F%R("TM(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C$S,C@@<&\O=')A;G-L871I;VXN<&AP.C$S,S`*;7-G:60@(BTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2(*;7-G<W1R("(M+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*
M;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM<V=S='(@(F9O<FUA="!D92`Q,B!H
M;W)E<R(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ.0IM<V=I9"`B,C0@2&]U
M<B!&;W)M870B"FUS9W-T<B`B9F]R;6%T(&1E(#(T(&AO<F5S(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S
M='(@(C(T(&AO<F5S(@H*(SH@;&EB+TAO<F1E+U5)+U!A9V5R+G!H<#HV.0IM
M<V=I9"`B/%!R979I;W5S(@IM<V=S='(@(CQ!;G1E<FEO<B(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HS-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB/&=E
M='1E>'0^('1A9R!N;W0@8VQO<V5D(&EN(&9I;&4@)7,N7&XB"B)/<&5N:6YG
M('1A9R!F;W5N9"!I;B!L:6YE("5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$Q-PIM<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES
M(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R(")097(@82!A<75E
M<W0@8FQO8R!E<R!N96-E<W-I=&$@=6X@;6]T;W(@9&4@8F%S97,@9&4@9&%D
M97,N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-C`*;7-G:60@(D$@9F%T86P@97)R
M;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(E,G:&$@<')O9'7O="!U;B!E<G)O
M<B!I<G)E<&%R86)L92XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY
M,C`*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC
M<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(D5S(&YE8V5S<VET82!U;F$@8VQA
M=2!01U`@</IB;&EC82!P97(@>&EF<F%R('5N(&UI<W-A=&=E+B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q-#4*;7-G:60@(D$@<'5B;&EC(%!'
M4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N
M(@IM<V=S='(@(D5S(&YE8V5S<VET82!U;F$@8VQA=2!01U`@</IB;&EC82!P
M97(@=F5R:69I8V%R('5N(&UI<W-A=&=E('-I9VYA="XB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HQ,#<W"FUS9VED("(B"B)!('!U8FQI8R!01U`@
M:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!D96-R>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB17,@
M;F5C97-S:71E;B!U;F$@8VQA=2!01U`@</IB;&EC82P@=6YA(&-L874@4$=0
M('!R:79A9&$@:2!U;F$@8V]N=')A<V5N>6$@(@HB<&5R(&1E<WAI9G)A<B!U
M;B!M:7-S871G92XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY.34*
M;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S
M86=E+B(*;7-G<W1R("(B"B)%<R!N96-E<W-I=&5N('5N82!C;&%U(%!'4"!P
M^F)L:6-A+"!U;F$@8VQA=2!01U`@<')I=F%D82!I('5N82!C;VYT<F%S96YY
M82`B"B)P97(@<VEG;F%R('5N(&UI<W-A=&=E+B(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-3`U"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@
M:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@HB
M17,@;F5C97-S:71E;B!U;F$@8VQA=2!3+TU)344@</IB;&EC82P@=6YA(&-L
M874@4R]-24U%('!R:79A9&$@:2!U;F$@(@HB8V]N=')A<V5N>6$@<&5R(&1E
M<WAI9G)A<B!U;B!M:7-S871G92XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I
M=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*(D5S(&YE8V5S<VET
M96X@=6YA(&-L874@4R]-24U%('#Z8FQI8V$L('5N82!C;&%U(%,O34E-12!P
M<FEV861A(&D@=6YA("(*(F-O;G1R87-E;GEA('!E<B!S:6=N87(@=6X@;6ES
M<V%T9V4N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G
M:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T
M(&$@;65S<V%G92XB"FUS9W-T<B`B17,@;F5C97-S:71A('5N82!C;&%U(%--
M24U%('#Z8FQI8V$@<&5R('AI9G)A<B!U;B!M:7-S871G92XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW"FUS9VED(")!32!#
M;&]U9',B"FUS9W-T<B`B3OIV;VQS(&%L(&UA=.TB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HX"FUS9VED(")!32!,:6=H="!2
M86EN(@IM<V=S='(@(E!L=6IA(&9E8FQE(&%L(&UA=.TB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HY"FUS9VED(")!32!286EN
M(@IM<V=S='(@(E!L=6IA(&%L(&UA=.TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B04T@4VAO=V5R<R(*;7-G
M<W1R(")2=6EX871S(&%L(&UA=.TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM
M<V=S='(@(EC@9F5C<R!D92!N974@86P@;6%T[2XB"@HC.B!T96UP;&%T97,O
M9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`B04TO4$TB
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0IM<V=I
M9"`B05!)($E$(@IM<V=S='(@(DE$(&1E($%022(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H
M:7,@961I=&]R(@IM<V=S='(@(E-O8G)E(&%Q=65S="!E9&ET;W(B"@HC.B!S
M97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,@IM<V=I9"`B06)O=70N+BXB"FUS
M9W-T<B`B16X@<75A;G0@82XN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R
M(")!;&EN96%C:?,@:6YF97)I;W(@97AA8W1A(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED9&QE
M(@IM<V=S='(@(D%L:6YE86-I\R!A;"!M:6<@97AA8W1A(@H*(SH@;&EB+U9&
M4R]M=7-Q;"YP:'`Z,C<P"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG
M(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(E,G:&$@9&5N96=A="!L)V%C8^ES
M(&5N(&-R96%R(&5L(&1I<F5C=&]R:2!61E,N(@H*(SH@;&EB+U9&4R]M=7-Q
M;"YP:'`Z,3,V"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F
M:6QE+B(*;7-G<W1R(")3)VAA(&1E;F5G870@;"=A8V/I<R!E;B!C<F5A<B!L
M)V%R>&EU(%9&4RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4*;7-G
M:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS9W-T<B`B0V]N=')A<V5N>6$@9&5L
M(&-O;7!T92(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDR"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`B0V]M<'1E(&-O
M;F=E;&%T+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,34*;7-G
M:60@(D%C8V]U;G1I;F<B"FUS9W-T<B`B0V]M<'1A8FEL:71Z86-I\R(*"B,Z
M(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU-"!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C$S,@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD
M+FEN8SHQ-B!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30*;7-G:60@(D%D
M9"(*;7-G<W1R(")!9F5G:7(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(Q-"!A
M9&UI;B]G<F]U<',N<&AP.C(Q-0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM
M<V=S='(@(D%F96=I<B!U;B!G<G5P(&1E<V-E;F1E;G0B"@HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C@T(&QI8B](;W)D92]097)M<R]522YP:'`Z.#4*
M;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N(@IM<V=S='(@(D%F96=I<B!U
M;F$@875T;W)I='IA8VGS(&1E<V-E;F1E;G0B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D($AE<F4Z(@IM<V=S='(@(D%F96=I
M<B!A(&-O;G1I;G5A8VGS.B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C`X(&%D
M;6EN+V=R;W5P<RYP:'`Z,C`Y"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S
M='(@(D%F96=I<B!U;B!N;W4@9W)U<"(*"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z-S,@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HW-`IM<V=I9"`B061D
M($YE=R!097)M:7-S:6]N(@IM<V=S='(@(D%F96=I<B!U;F$@;F]V82!A=71O
M<FET>F%C:?,@(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL
M9"YI;F,Z.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI
M;&0@9W)O=7`@=&\@)R5S)R(*;7-G<W1R(")!9F5G:7(@=6X@9W)U<"!D97-C
M96YD96YT(&$@)R5S)RXB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z
M-3,@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ,S$*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@)R5S)R(*
M;7-G<W1R(")!9F5G:7(@=6YA(&%U=&]R:71Z86-I\R!D97-C96YD96YT(&$@
M)R5S)RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W
M('5S97(Z(@IM<V=S='(@(D%F96=I<B!U;B!N;W4@=7-U87)I.B(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU,C8*;7-G:60@(D%D
M9"!C;VQU;6XB"FUS9W-T<B`B069E9VER('5N82!C;VQU;6YA+B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,S4*;7-G:60@(D%D9"!N
M97<@;65M8F5R<R(*;7-G<W1R(")!9F5G:7(@;F]U<R!M96UB<F5S+B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")!9&0@<&%I
M<B(*;7-G<W1R(")!9F5G:7(@=6YA('!A<F5L;&$B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S4W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@
M)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R(")!9F5G:7(@
M96P@;65N^B`E<R!C;VT@=6YA(&)A<G)A(&QA=&5R86P@9&4@36]Z:6QL82(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*;7-G:60@
M(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(D%F96=E:7@@82!L82!L
M;&EB<F5T82!D)V%D<F5C97,Z(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HW.`IM<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O:R(*
M;7-G<W1R(")!9F5G96EX(&$@;&$@;65V82!L;&EB<F5T82!D)V%D<F5C97,B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HS,0IM<V=I9"`B061D('5S97(B"FUS9W-T
M<B`B069E9VER('5N('5S=6%R:2(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E9"`G)7,G('1O('1H
M92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P
M(&EN9F]R;6%T:6]N.B`E(@HB<RXB"FUS9W-T<B`B(@HB4R=H82!A9F5G:70@
M)R5S)R!A;"!S:7-T96UA+"!P97+R(&YO(',G:&$@<&]G=70@869E9VER(&WI
M<R!D861E<R!S;V)R92`B"B)L)V%L=&$Z("5S(@H*(SH@<VEG;G5P+G!H<#HT
M-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D960@)R5S)R!T;R!T
M:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(E,G:&$@
M869E9VET("<E<R<@86P@<VES=&5M82X@07)A(&IA('!O="!I;FEC:6%R(&QA
M('-E<W-I\RXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.38R"FUS9VED(")!
M9&1I;F<@;F5W(&9I;&5S('1O(')E<&]S:71O<GDZ(@IM<V=S='(@(D%F96=I
M;G0@;F]U<R!F:71X97)S(&%L(')E<&]S:71O<FDB"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]N;V%D9"YI;F,Z-`IM<V=I9"`B061D:6YG('5S97)S(&ES
M(&1I<V%B;&5D+B(*;7-G<W1R(")3)VAA(&EN:&%B:6QI=&%T(&PG;W!C:?,@
M9"=A9F5G:7(@=7-U87)I<RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30T
M-B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$W,PIM<V=I9"`B061D<F5S
M<R(*;7-G<W1R(")!9')EYV$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3,W"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B3&QI8G)E=&$@
M9"=A9')E8V5S(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP
M.CDT"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O
M=&AE<B!U<V5R<R(*;7-G<W1R(")!9&UI;FES=')A9&]R("T@9&5F:6YE:7@@
M;&5S(&%U=&]R:71Z86-I;VYS('!E<B!A(&%L=')E<R!U<W5A<FES(@H*(SH@
M861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN:7-T
M<F%C:?,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@S"FUS9VED
M(")!9',B"FUS9W-T<B`B06YU;F-I<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C4V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@*;7-G:60@(D%F9VAA;FES=&%N(@IM
M<V=S='(@(D%F9V%N:7-T86XB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HU-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(Q"FUS9VED(")!;&)A;FEA(@IM<V=S='(@(D%L
M8N!N:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C<T"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(D%L9^AR:6$B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$P-PIM<V=I9"`B06QI
M87,B"FUS9W-T<B`BP&QI97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C$V"FUS9VED(")!;&EG;B(*;7-G<W1R
M(")!;&EN96%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R(")!;&EN96%C
M:?,Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C@W"FUS9VED(")!;&PB
M"FUS9W-T<B`B5&]T<R(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$Q."!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N
M=&EC871E9"!5<V5R<R(*;7-G<W1R(")4;W1S(&5L<R!U<W5A<FES(&%U=&5N
M=&EC871S(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N
M<&AP.C(Q,@IM<V=I9"`B06QL($=R;W5P<R(*;7-G<W1R(")4;W1S(&5L<R!G
M<G5P<R(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HS."!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C<W"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS
M9W-T<B`B5&]T<R!E;',@<&5R;6ES;W,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$W"FUS9VED(")!;&P@9F]U
M<B!S:61E<R(*;7-G<W1R(")4;W1S('%U871R92!C;W-T871S(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$X-S$*;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D
M9')E<W-E<R(*;7-G<W1R(")097)M970@;6]L=&5S(&%D<F5C97,B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(S"FUS9VED(")!;&QO=R!S971T:6YG
M(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R(")%<R!P97)M970@;&$@
M8V]N9FEG=7)A8VGS(&1E;"!T:7!U<R!D92!L;&ES=&5S(&]R9&5N861E<S\B
M"@HC.B!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HT,#@*;7-G:60@(D%L
M<F5A9'D@97AI<W1S(@IM<V=S='(@(DIA(&5X:7-T96EX(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$R,@IM<V=I9"`B06QT97)N871E($E-4U`@3&]G
M:6XB"FUS9W-T<B`B06-CZ7,@24U34"!A;'1E<FYA=&EU(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0Y-@IM<V=I9"`B06QT97)N871E($E-4U`@4&%S
M<W=O<F0B"FUS9W-T<B`B0V]N=')A<V5N>6$@24U34"!A;'1E<FYA=&EV82(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.#@*;7-G:60@(D%L=&5R;F%T
M92!)35-0(%5S97)N86UE(@IM<V=S='(@(DYO;2!D)W5S=6%R:2!)35-0(&%L
M=&5R;F%T:74B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS-0IM
M<V=I9"`B06QT97)N871E(&5M86EL(&%D9')E<W,B"FUS9W-T<B`B061R9>=A
M(&5L96-T<O)N:6-A(&%L=&5R;F%T:79A(@H*(SH@861M:6XO=&5M<&QA=&5S
M+G!H<#HQ-#(*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`B
M4&QA;G1I;&QE<R!A;'1E<FYA=&EV97,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$R,@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C4*;7-G:60@(D%L
M=&5R;F%T92!T97AT.B(*;7-G<W1R(")497AT(&%L=&5R;F%T:74Z(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-PIM<V=I
M9"`B06UE<FEC86X@4V%M;V$B"FUS9W-T<B`B4V%M;V$@06UE<FEC86YA(@H*
M(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HY-2!L:6(O2&]R9&4O4')E9G,O
M54DN<&AP.C$Q-0IM<V=I9"`B06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF
M:65D+B(*;7-G<W1R(")3)VAA(&5S<&5C:69I8V%T('5N('9A;&]R('!R;VAI
M8FET+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3D*;7-G
M:60@(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N(@IM<V=S='(@(E,G
M:&$@<')O9'7O="!U;B!E<G)O<B!D97-C;VYE9W5T+B(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C4U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38*;7-G:60@(D%N9&]R
M<F$B"FUS9W-T<B`B06YD;W)R82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C4X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C0*;7-G:60@(D%N9V]L82(*;7-G<W1R(")!
M;F=O;&$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(P"FUS9VED(")!;F=U:6QL82(*;7-G<W1R(")!;F=U:6QL82(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S
M(%!R;WAY(@IM<V=S='(@(E-E<G9I9&]R(%!R;WAY(&%N\FYI;2(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS
M9W-T<B`B4F5S<&]S=&$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU
M."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(U"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(D%N
M=.!R=&ED82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4V(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3D*;7-G:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B
M06YT:6=U82!I($)A<F)U9&$B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C<T
M(&%D;6EN+W!H<'-H96QL+G!H<#HS-2!L:6(O2&]R9&4O0FQO8VLO54DN<&AP
M.C4X"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*;7-G
M:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(D%P;&EC86-I\R(*"B,Z('5T:6PO
M:6-O;E]B<F]W<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*
M;7-G<W1R("),;&ES=&$@9"=A<&QI8V%C:6]N<R(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ,SD*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*
M;7-G<W1R("),)V%P;&EC86-I\R#I<R!A('!U;G0N(@H*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O($-H:6QD(%-H
M87)E<R(*;7-G<W1R(")!<&QI8V%R(&$@<F5C=7)S;W,@8V]M<&%R=&ET<R!D
M97-C96YD96YT<RXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E
M+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*;7-G<W1R(")!<')O=F%R(@H*(SH@
M;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@R-@IM<V=I9"`B07!P<F]X
M:6UA=&4@4VEZ92(*;7-G<W1R(")-:61A(&%P<F]X:6UA9&$B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<W(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,30*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T
M<B`B06)R:6PB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-0IM<V=I9"`B
M07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(D%RX&)I8R`H5VEN9&]W
M<RTQ,C4V(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C,@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#$*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D*;7-G:60@(D%R8VAI=F4@1FEL92!3
M:7IE(@IM<V=S='(@(DUI9&$@9&4@;"=A<GAI=2(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8R(&QI8B](;W)D92]-24U%+U9I97=E<B]T
M9WHN<&AP.C@P"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C4X
M"FUS9VED(")!<F-H:79E($YA;64B"FUS9W-T<B`B3F]M(&1E(&PG87)X:74B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.CD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O
M(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B"FUS9W-T<B`B
M5F]L974@<W5P<FEM:7(@;&$@<V]LMVQI8VET=60@9"=A;'1A(&$@)7,_(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.CD*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T
M;R!D96QE=&4@)R5S)R!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(E9O
M;&5U(&5S8F]R<F%R("<E<R<@:2!T;W1S(&5L<R!S=6)G<G5P<S\B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(V"FUS9VED
M(")!<F=E;G1I;F$B"FUS9W-T<B`B07)G96YT:6YA(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,@IM<V=I9"`B07)M96YI
M82(*;7-G<W1R(")!<FWH;FEA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M-S8*;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@(D%R;65N
M:2`H05)-4T-)22TX*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.`IM
M<V=I9"`B07)T(@IM<V=S='(@(D%R="(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C4Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S`*;7-G:60@(D%R=6)A(@IM<V=S='(@
M(D%R=6)A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!
M<V-E;G-I;VX@27-L86YD(@IM<V=S='(@(DEL;&$@9&4@;"=!<V-E;G-I\R(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@07)T
M(@IM<V=S='(@(F=RX&9I8R!!4T-)22(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C4U"FUS9VED(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@
M(E)E9VGS(&1E;"!086/M9FEC(&%S:>!T:6,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#$U"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O
M<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`B5F]L
M974@8V]N9FER;6%C:?,@86)A;G,@9"=E9F5C='5A<B!L97,@;W!E<F%C:6]N
M<R!D92!M86YT96YI;65N=#\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$Q
M,0IM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(D-O;'5M;F5S
M(&0G87-S:6=N86-I\R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S4*;7-G:60@
M(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G
M<W1R(")3)VAA(&EN=&5N=&%T('-U<')I;6ER('5N(&=R=7`@;F\@97AI<W1E
M;G0N(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HS.`IM<V=I9"`B071T
M96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS
M9W-T<B`B4R=H82!I;G1E;G1A="!S=7!R:6UI<B!U;F$@875T;W)I='IA8VGS
M(&YO(&5X:7-T96YT+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.CDX"FUS
M9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO
M;BXB"FUS9W-T<B`B4R=H82!I;G1E;G1A="!E9&ET87(@=6YA(&%U=&]R:71Z
M86-I\R!N;R!E>&ES=&5N="XB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP
M:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S
M:&%R92XB"FUS9W-T<B`B4R=H82!I;G1E;G1A="!E9&ET87(@=6X@<F5C=7)S
M(&-O;7!A<G1I="!N;R!E>&ES=&5N="XB"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O>FEP+G!H<#HV."!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H
M<#HX-@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV-`IM<V=I
M9"`B071T<FEB=71E<R(*;7-G<W1R(")!=')I8G5T<R(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HS.#$@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B
M06=O<W0B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(Y"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B075S='+@;&EA(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR.`IM
M<V=I9"`B075S=')I82(*;7-G<W1R("+`=7-T<FEA(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L.B!297%U
M:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?
M8WER<W%L.B!.;R!S)VAA('1R;V)A="!L)V5X=&5N<VGS(&EM87`@;F5C97-S
MX')I82XB"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED
M(")!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@
M8V%P86)I;&ET97,N(@IM<V=S='(@(D%U=&A?8WER=7,Z($5L(&UO=&]R(&YO
M('3I(&QE<R!C87!A8VET871S(&YE8V5S<^!R:65S+B(*"B,Z(&QI8B](;W)D
M92]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I
M<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C
M>7)U<SH@3F\@<R=H82!T<F]B870@;"=E>'1E;G-I\R!)34%0(&YE8V5S<^!R
M:6$N(@H*(SH@;&EB+TAO<F1E+T%U=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB
M075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#
M;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*
M;7-G<W1R("(B"B)!=71H7V9T<#H@3F\@<R=H82!T<F]B870@;"=E>'1E;G-I
M\R!&5%`@;F5C97-SX')I82X@0V%L(&-O;7!I;&%R(%!(4"!A;6(@96P@(@HB
M8V]M;75T861O<B`M96YA8FQE+69T<"XB"@HC.B!L:6(O2&]R9&4O075T:"]I
M;6%P+G!H<#HV-`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:6UA<#H@3F\@<R=H
M82!T<F]B870@;"=E>'1E;G-I\R!)34%0(&YE8V5S<^!R:6$N(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q
M=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H
M7VMR8C4Z($YO(',G:&$@=')O8F%T(&PG97AT96YS:?,@:W)B-2!N96-E<W/@
M<FEA+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C4X"FUS9VED(")!
M=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B075T:%]L9&%P.B!.;R!S)VAA('1R;V)A="!L)V5X=&5N<VGS
M($Q$05`@;F5C97-SX')I82XB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H
M<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@
M=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z
M("(*;7-G<W1R("(B"B)!=71H7VQD87`Z($YO(',G:&$@<&]G=70@869E9VER
M(&PG=7-U87)I("5S+B!!:7CR(.ES(&5L('%U92!H82!D:70@96P@(@HB<V5R
M=FED;W(Z(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,C(R"B,L('!H
M<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U
M<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@3F\@<R=H82!P;V=U="!S=7!R
M:6UI<B!L)W5S=6%R:2`E<RXB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H
M<#HR.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@
M=&\@=7!D871E('5S97(@)7,B"FUS9W-T<B`B075T;U]L9&%P.B!.;R!S)VAA
M('!O9W5T(&%C='5A;&ET>F%R(&PG=7-U87)I("5S+B(*"B,Z(&QI8B](;W)D
M92]!=71H+VUC86PN<&AP.C0V"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D
M($U#04P@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T;U]M8V%L
M.B!.;R!S)VAA('1R;V)A="!L)V5X=&5N<VGS($U#04P@;F5C97-SX')I82XB
M"@HC.B!L:6(O2&]R9&4O075T:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M
M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B075T:%]S;6)A=71H.B!.;R!S)VAA('1R;V)A="!L)V5X=&5N
M<VGS(%--0D%55$@@;F5C97-SX')I82XB"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(X.0IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I
M;&5D(@IM<V=S='(@(E,G:&$@<')O9'7O="!U;B!E<G)O<B!E;B!L)V%U=&5N
M=&EC86-I\RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C8W(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G
M<W1R(")3)VAA('!R;V1U[W0@=6X@97)R;W(@96X@;"=A=71E;G1I8V%C:?,N
M("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O<F%D:75S+G!H<#HQ-S8*;7-G:60@
M(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM
M<V=S='(@(D5L('-E<G9I9&]R(%)!1$E54R!H82!R96)U=&IA="!L)V%U=&5N
M=&EC86-I\RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S8X"FUS9VED(")!=71H
M96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B4R=H
M82!P<F]D=>]T('5N(&5R<F]R(&5N(&PG875T96YT:6-A8VGS(&%M8B!E;"!S
M97)V:61O<B!&5%`N(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C<P"FUS9VED(")!
M=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N(@IM<V=S
M='(@(E,G:&$@<')O9'7O="!U;B!E<G)O<B!E;B!L)V%U=&5N=&EC86-I\R!A
M;6(@96P@<V5R=FED;W(@4TU"+B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z.#,*;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(D-A
M;7!S(&1I<W!O;FEB;&5S.B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C4Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,S$*;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B
M07IE<F)A:61J86XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G
M:60@(D)/1D@@17AC=7-E<R(*;7-G<W1R(")"3T9(($5X8W5S97,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$X
M"FUS9VED(")"86-K9W)O=6YD(@IM<V=S='(@(D9O;G,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"86-K
M9W)O=6YD($-O;&]R(@IM<V=S='(@(D-O;&]R(&1E;"!F;VYS(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O:W)B-2YP:'`Z.#$*;7-G:60@(D)A9"!K97)B97)O<R!P
M87-S=V]R9"XB"FUS9W-T<B`B0V]N=')A<V5N>6$@2V5R8F5R;W,@:6YC;W)R
M96-T82XB"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX,PIM<V=I9"`B
M0F%D(&ME<F)E<F]S('5S97)N86UE+B(*;7-G<W1R(").;VT@9"=U<W5A<FD@
M2V5R8F5R;W,@:6YC;W)R96-T92XB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C0U"FUS9VED(")"86AA;6%S(@IM<V=S='(@
M(D)A:&%M97,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C,X"FUS9VED(")"86AR86EN(@IM<V=S='(@(D)A:')A:6XB"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-PIM<V=I9"`B0F%L=&EC("A)4T\M
M.#@U.2TQ,RDB"FUS9W-T<B`B0N!L=&EC("A)4T\M.#@U.2TQ,RDB"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,T"FUS9VED
M(")"86YG;&%D97-H(@IM<V=S='(@(D)A;F=L82!$97-H(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,PIM<V=I9"`B0F%R
M8F%D;W,B"FUS9W-T<B`B0F%R8F%D;W,B"@HC.B!U=&EL+VEC;VY?8G)O=W-E
M<BYP:'`Z,S$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D)A<V4@9W)A
M<&AI8W,@9&ER96-T;W)Y("<E<R<@;F]T(&9O=6YD+B(*;7-G<W1R(").;R!S
M)VAA('1R;V)A="!E;"!D:7)E8W1O<FD@9&4@9W+@9FEC<R!BX'-I8W,@)R5S
M)R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW,PIM<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B3.UN:6$@8F%S92(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HS,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#D*
M;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B0FEE;&]R<OIS:6$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,U"FUS9VED(")"
M96QG:75M(@IM<V=S='(@(D+H;&=I8V$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4P"FUS9VED(")"96QI>F4B"FUS9W-T
M<B`B0F5L:7IE(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,S"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HT,`IM<V=I9"`B0F5N:6XB"FUS9W-T<B`B0F5N[6XB"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0Q"FUS9VED
M(")"97)M=61A(@IM<V=S='(@(D)E<FUU9&5S(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,U
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-@IM<V=I9"`B0FAU=&%N(@IM
M<V=S='(@(D)H=71A;B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G<W1R(")!;FEV97)S87)I
M(@H*(SH@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S7"(@;V8@87!P;&EC871I;VX@
M7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B3F\@<R=H82!T<F]B870@96P@
M8FQO8R!<(B5S7"(@9&4@;"=A<&QI8V%C:?,@7"(E<UPB("XB"@HC.B!T96UP
M;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.#D*;7-G:60@(D)L;V-K(%-E='1I
M;F=S(@IM<V=S='(@(E!A<N!M971R97,@9&5L(&)L;V,B"@HC.B!T96UP;&%T
M97,O<&]R=&%L+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS
M9W-T<B`B5&EP=7,@9&4@8FQO8R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G<W1R(").96=R
M971A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HT,PIM<V=I9"`B0F]L:79I82(*;7-G<W1R(")";VSM=FEA(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X.0IM<V=I9"`B0F]O:VUA<FMS(@IM
M<V=S='(@(DUA<F-A9&]R<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*;7-G:60@(D)O<F1E<B(*;7-G<W1R
M(")#;VYT;W)N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B
M1W)U:7@@9&5L(&-O;G1O<FXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(Q"FUS9VED(")";W)D97)S(@IM<V=S
M='(@(D-O;G1O<FYS(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HS,@IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*
M;7-G<W1R(")"\G-N:6$@:2!(97)C96=O=FEN82(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G<W1R(")!;6)D\W,B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0X"FUS
M9VED(")";W1S=V%N82(*;7-G<W1R(")";W1S=V%N82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-0IM<V=I9"`B
M0F]T=&]M(@IM<V=S='(@(DEN9F5R:6]R(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,Y"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-PIM<V=I9"`B0F]U=F5T($ES;&%N
M9"(*;7-G<W1R("));&QA(&1E($)O=79E="(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT,`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#0*;7-G:60@(D)R87II;"(*;7-G
M<W1R(")"<F%S:6PB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$Q-PIM<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R
M<FET;W)Y(@IM<V=S='(@(E1E<G)I=&]R:2!O8V7@;FEC(&1E(&PGS6YD:6$@
M8G)I=.!N:6-A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HT,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`B
M0G)U;F5I($1A<G5S<V%L86TB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C8Q
M"B,L('!H<"UF;W)M870*;7-G:60@(D)U:6QD:6YG($U/(&9I;&5S(&9O<B!M
M;V1U;&4@)7,N+BXB"FUS9W-T<B`B0V]N=')U:6YT(&9I='AE<G,@34\@<&5R
M(&%L(&WR9'5L("5S+BXN(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8W,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")"=6EL9&EN9R!L;V-A;&4@)7,N+BX@(@IM
M<V=S='(@(D-O;G-T<G5I;G0@)7,N+BXB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#,*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,W"FUS9VED(")"=6QG87)I82(*;7-G
M<W1R(")"=6QGX')I82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D($QI<W0B"FUS9W-T<B`B
M3&QI<W1A(&1E('!I8W,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C,V"FUS9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B
M0G5R:VEN82!&87-O(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HS.0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R(")"=7)U;F1I
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W-`IM<V=I9"`B0TU3
M(@IM<V=S='(@(D--4R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<R"FUS9VED(")#4D,B"FUS9W-T<B`B0U)#(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@
M4&]I;G1S(@IM<V=S='(@(E!U;G1S(&1E(&1I<W1R:6)U8VGS(&1E($-23"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")0
M<F]P:65T871S(&1E(&-E;+=L82XN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-34*;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP
M;&5T960N(@IM<V=S='(@(DYO(',G:&$@9FEN86QI='IA="!E;"!P<F]CZ7,@
M9"=I;FEC:6%L:71Z86-I\R!D92!L82!M96WR<FEA(&-A=2(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-38@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$T-@IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B0V%L
M96YD87)I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S.`IM
M<V=I9"`B0V%L;2(*;7-G<W1R(")#86QM82(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(X"FUS9VED(")#86UB;V1I82(*
M;7-G<W1R(")#86UB;V1J82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-C`*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(D-A
M;65R=6XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I
M9"`B0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT
M86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HBR7,@:6UP;W-S
M:6)L92!R96EN:6-I87(@;&$@8V]N=')A<V5N>6$@875T;VW@=&EC86UE;G0L
M('!O<V$G="!E;B!C;VYT86-T92`B"B)A;6(@;"=A9&UI;FES=')A9&]R(&1E
M;"!S:7-T96UA+B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HR,S4@
M;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T
M<B`BR7,@:6UP;W-S:6)L92!C;VYN96-T87(@86UB(&5L('-E<G9I9&]R($E-
M05`Z("5S+B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8T(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-3$*;7-G:60@(D-A;F%D82(*;7-G<W1R(")#86YA9.`B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z,3(P('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3<*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O8VQE87(N:6YC.C$W('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L
M971E+FEN8SHQ-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-C4*;7-G:60@(D-A;F-E;"(*;7-G<W1R(")#86YC96RW;&%R(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A
M;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")#86YC96RW;&%R(&PG:6YF
M;W)M92!D92!P<F]B;&5M97,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C(U-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R(").;R!E<R!P;W0@97-B;W)R87(@;"=A<GAI=2!<(B5S7"(N
M(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z-#8*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T
M96=Y+V-O<'DN<&AP.C4R"FUS9VED(")#86YN;W0@9FEN9"!A('1E;7!O<F%R
M>2!D:7)E8W1O<GDN(@IM<V=S='(@(DYO(&5S('!O="!T<F]B87(@=6X@9&ER
M96-T;W)I('1E;7!O<F%L+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+G!H<#HY
M,0IM<V=I9"`B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@
M<&%R86UE=&5R+B(*;7-G<W1R(").;R!E<R!P;W0@8V]N=&EN=6%R('-E;G-E
M(&5L('!A<N!M971R92`G=&%R9V5T1FEL92<N(@H*(SH@;&EB+U9&4R]F='`N
M<&AP.C(U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I
M<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DYO(&5S('!O="!E<V)O<G)A<B!E
M;"!D:7)E8W1O<FD@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92]$871A5')E92YP
M:'`Z,3$R(&QI8B](;W)D92]$871A5')E92]S<6PN<&AP.C4X-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES
M="XB"FUS9W-T<B`B3F\@97,@<&]T(&5S8F]R<F%R+"!C;VYTZ2!D97-C96YD
M96YT<R`E9"X@(@H*(SH@;&EB+TAO<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-3$R
M"FUS9VED("(B"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@
M<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*
M(G-T;W)E9"XB"FUS9W-T<B`B(@HB3F\@97,@<&]T(')E;W)D96YA<BP@96P@
M;F]M8G)E(&0G96YT<F%D97,@<75E(',G:&%N(&1E(')E;W)D96YA<B!N;R`B
M"B)C;VEN8VED96EX(&%M8B!L97,@<75E(&AI(&AA(&5M;6%G871Z96UA9&5S
M+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X"FUS
M9VED(")#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R
M+B(*;7-G<W1R(").;R!E<R!P;W0@861R9>=A<B!E;"!M:7-S871G92!A;"!N
M;VUB<F4@97-P96-I9FEC870N(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HV-0IM<V=I9"`B0V%P92!697)D92(*;7-G<W1R
M(")#87`@5F5R9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C0*;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`B3&QE
M9V5N9&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`*;7-G:60@(D-A
M=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R(")#871E9V]R:65S(&D@971I
M<75E=&5S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,S4*;7-G:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(DEL;&5S
M($-A:6UA;B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3DT"FUS9VED(")#96QL(%!H;VYE(@IM<V=S='(@(E1E;.AF;VX@;?)B:6PB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(U"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`B4')O<&EE
M=&%T<R!D92!C96RW;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R
M(")&87)C:6UE;G0@9&4@8V5LMVQA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P
M97)T:65S(@IM<V=S='(@(E!R;W!I971A=',@9&4@;&$@8V5LMVQA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G
M:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`B17-P86EA="!E;G1R92!C96RW
M;&5S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-S0*;7-G:60@(D-E;&QP
M:&]N92(*;7-G<W1R(")496SH9F]N(&WR8FEL(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ-S@*;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM,30I(@IM<V=S
M='(@(D/H;'1I8R`H25-/+3@X-3DM,30I(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R
M(@IM<V=S='(@(D-E;G1R87(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C4T"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P
M=6)L:6,B"FUS9W-T<B`B4F5P^F)L:6-A($-E;G1R96%F<FEC86YA(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D-E;G1R86P@175R;W!E
M86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(D5U<F]P82!C96YT<F%L("A)4T\M
M.#@U.2TR*2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-CDY"FUS
M9VED(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(D1E=&%L;',@9&5L
M(&-E<G1I9FEC870B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8Q
M,0IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B5&ET=6QA<B!D
M96P@8V5R=&EF:6-A="(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3DV"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R(")0;VSM
M=&EQ=65S(&1E(&-E<G1I9FEC86-I\R(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,0IM<V=I9"`B0VAA9"(*;7-G<W1R
M(")4>&%D(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-PIM<V=I9"`B0VAA;F=E(@IM
M<V=S='(@(D1E<V;I<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@IM
M<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O
M<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E
M;6%I;',N(@IM<V=S='(@(B(*(D-A;G9I974@96P@;F]M(&D@;"=A9')EYV$@
M<75E('/S;B!V:7-I8FQE<R!Q=6%N(&5S(&QL96=E:7AE;B!O(&5S(')E<W!O
M;F5N("(*(F5L<R!V;W-T<F5S(&UI<W-A=&=E<R!D92!C;W)R974@96QE8W1R
M\FYI8RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(W"FUS9VED(")#:&%R(@IM<V=S='(@(D-H87(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C4*;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(E9E<FEF:6-A(&PG
M96YL;&'G+BXN(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?
M=&]P+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B0VAE8VL@=&AE(&)O>"!F;W(@
M86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@
M=&EM92XB"FUS9W-T<B`B(@HB36%R8V$@82!L82!C87-E;&QA(&PG;W!E<F%C
M:?,@;R!O<&5R86-I;VYS('%U92!D97-I=&=I<R!E>&5C=71A<B!E;B!A<75E
M<W1A("(*(F]C87-I\RXB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C4Y"FUS9VED(")#:&EL92(*;7-G<W1R(")8:6QE(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C4T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,0IM
M<V=I9"`B0VAI;F$B"FUS9W-T<B`B6&EN82(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@P"FUS9VED(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB
M"FUS9W-T<B`B6&ENZ',@<VEM<&QI9FEC870@*$=",C,Q,BDB"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA
M;"`H0FEG-2DB"FUS9W-T<B`B6&ENZ',@=')A9&EC:6]N86P@*$)I9S4I(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(D-H;V]S
M92!A('!A<W-W;W)D(@IM<V=S='(@(E1R:6$@=6YA(&-O;G1R87-E;GEA(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-C@*;7-G:60@(D-H;V]S
M92!A('5S97)N86UE(@IM<V=S='(@(E1R:6$@=6X@;F]M(&0G=7-U87)I(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(X.`IM<V=I9"`B0VAO;W-E(&AO
M=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G<W1R(")4<FEA(&-O;2!V;VQS('9I
M<W5A;&ET>F%R(&QE<R!D871E<SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@
M;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B
M5')I82!U;B!T:7!U<R!D)V5S=&EL(&1E(&QL:7-T82`H<&5R(&$@;&QI<W1E
M<R!O<F1E;F%D97,I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HV-@IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R
M("));&QA(&1E($-H<FES=&UA<R(*"B,Z(&QI8B]61E,N<&AP.CDQ,R!L:6(O
M3F5T+U--4RYP:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E
M9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R(").;R!S)VAA('1R
M;V)A="!L82!D969I;FEC:?,@9&4@8VQA<W-E(&1E("`E<RXB"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z.#4U"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%N
M:6YG('5P(%!/(&9I;&5S(&9O<B!M;V1U;&4@)7,N+BXB"FUS9W-T<B`B(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C@V-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;&5A;FEN9R!U<"!L;V-A;&4@)7,N+BX@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED(")#
M;&5A<B(*;7-G<W1R(")%;&EM:6YA<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E
M('1A9W,B"FUS9W-T<B`B16QI;6EN82!L97,@971I<75E=&5S(&1E($U33V9F
M:6-E(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM<V=S='(@
M(D5S8F]R<F$@;"=U<W5A<FDZ("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O8VQE87(N:6YC.C$V"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(D5S
M8F]R<F$@;"=U<W5A<FDB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHS-`IM<V=I9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@(D5S8F]R
M<F$@;&5S(&1A9&5S(&1E(&PG=7-U87)I(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D-L96%R:6YG($QA=&4B
M"FUS9W-T<B`B4R=A8VQA<FERX"!C87`@86P@=&%R9"XB"@HC.B!T96UP;&%T
M97,O;6%I;G1E;F%N8V4O;F]T:6-E7V)O='1O;2YI;F,Z-@IM<V=I9"`B0VQI
M8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B4')E;6D@<&5R(&-O;G1I;G5A<B(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@S"FUS9VED
M(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(D-L:6-K871E;&P@<&5R
M($A45%`B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I;F1O=R(*;7-G
M<W1R(")486YC82!L82!F:6YE<W1R82(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C0R"FUS9VED(")#;&]U9',B"FUS9W-T<B`B3OIV;VQS(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*;7-G:60@(D-L
M;W5D<R!%87)L>2(*;7-G<W1R(").^G9O;',@82!P<FEM97)A(&AO<F$B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0IM<V=I
M9"`B0VQO=61Y(@IM<V=S='(@(D5N;G5V;VQA="(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU
M-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3(*;7-G:60@(D-O8V]S("A+
M965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(DEL;&5S(&1E($-O8V]S("A+965L
M:6YG*2(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z-`IM<V=I
M9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R(")2961U[W4@;&$@8F%R<F$@
M;&%T97)A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S
M='(@(DUA<F=E<R!R961U[W1S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HV,@IM<V=I9"`B0V]L;VUB:6$B"FUS9W-T<B`B
M0V]L\FUB:6$B"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C
M:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`B0V]L
M;W(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#<R
M(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HR.3@*(SH@;&EB+TAO
M<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C(Y.2!S97)V:6-E<R]I;6%G97,O
M8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C4Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C4R"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C8X"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C8Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C@U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C@V"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T
M<B`B4V5L96-T;W(@9&4@8V]L;W(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C@T-`IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R(")396QE8V-I
M\R!D92!C;VQO<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R(")#;VQU;6YE<SHB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DT-@IM<V=I9"`B0V]L=6UN('1I
M=&QE<R(*;7-G<W1R(")4[71O;',@9&4@;&5S(&-O;'5M;F5S(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X-`IM<V=I9"`B0V]M:6-S(@IM<V=S
M='(@(D/R;6EC<R(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-0IM<V=I9"`B
M0V]M;6%N9"(*;7-G<W1R(")/<F1R92(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H
M<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R(")#;VYS;VQA(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C,X"B,L(&9U>GIY"FUS9VED(")#;VUM
M86YD(&]P=&EO;G,Z(@IM<V=S='(@(D]P8VEO;G,@9&4@;&$@8V]L=6UN82(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HY-PHC+"!F=7IZ>0IM<V=I9"`B0V]M
M;6%N9',Z(@IM<V=S='(@(D]R9')E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z-#`R"FUS9VED(")#;VUM96YT(@IM<V=S='(@(D-O;65N=&%R:2(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#`P"B,L(&9U>GIY"FUS9VED(")#
M;VUM:71T:6YG.B(*;7-G<W1R(")#;VYD:6-I;VYS(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU-C8*;7-G:60@(D-O;6UO;B!.86UE(@IM<V=S
M='(@(DYO;2!C;VWZ(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,S`*;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`B0V]M;W)E
M<R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS
M9VED(")#;VUP86YY(@IM<V=S='(@(D-O;7!A;GEI82(*"B,Z(&QI8B](;W)D
M92]497AT+T9I;'1E<B]E;6%I;',N<&AP.C@Q(&QI8B](;W)D92]497AT+T9I
M;'1E<B]E;6%I;',N<&AP.C@W"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]E
M;6%I;',N<&AP.CDW(&QI8B](;W)D92]497AT+T9I;'1E<B]E;6%I;',N<&AP
M.C$P,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VUP;W-E($UE<W-A9V4@*"5S
M*2(*;7-G<W1R(")%<V-R:74@96P@;6ES<V%T9V4@*"5S*2(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@
M(D]R9&EN861O<G,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-PIM<V=I
M9"`B0V]N9&ET:6]N<R(*;7-G<W1R(")#;VYD:6-I;VYS(@H*(SH@861M:6XO
M<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R871I;VX@1&EF9F5R
M96YC97,B"FUS9W-T<B`B1&EF97+H;F-I97,@9&4@8V]N9FEG=7)A8VGS(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-`IM<V=I9"`B0V]N9FEG=7)A
M=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B3&$@8V]N9FEG=7)A8VGS
M(&YO(&5S=.`@86-T=6%L:71Z861A+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HY.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS
M9W-T<B`B0V]N9FEG=7)A("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHS-PIM<V=I9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R
M(")#;VYF:7)M87(@;&$@8V]N=')A<V5N>6$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4U"FUS9VED(")#;VYG;R(*;7-G
M<W1R(")#;VYG;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8U(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-3,*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U
M8FQI8R!O9B!T:&4B"FUS9W-T<B`B0V]N9V\L(%)E</IB;&EC82!$96UO8W+@
M=&EC82!D96PB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,3DY(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G:60@
M(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R(").;R#I<R!P;W-S:6)L92!R
M96%L:71Z87(@;&$@8V]N;F5X:?,N(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C$Y.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(DYO
M(.ES('!O<W-I8FQE(')E86QI='IA<B!L82!C;VYN97AI\SHB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HW-SD*;7-G:60@(D-O;FYE8W1I;VX@<F5F
M=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B4R=H82!R
M96)U=&IA="!L82!C;VYN97AI\R!A;"!S97)V:61O<B!D92!C;&%U<R!P^F)L
M:7%U97,N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-S@Q"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B
M;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(E,G:&$@
M<F5B=71J870@;&$@8V]N;F5X:?,@86P@<V5R=FED;W(@9&4@8VQA=7,@</IB
M;&EQ=65S+B!28?,Z("5S("@E<RDB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S8R
M"FUS9VED(")#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G
M<W1R(").;R#I<R!P;W-S:6)L92!R96%L:71Z87(@;&$@8V]N;F5X:?,@86P@
M<V5R=FED;W(@1E10+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D
M9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R(")%;',@8V]N=&%C
M=&5S(',G:&%N(&%F96=I="!C;W)R96-T86UE;G0@82!L82!T979A(&QL:6)R
M971A(&0G861R96-E<RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP
M+G!H<#HV,"!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW.`HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HU-@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@)R5S)R(*;7-G<W1R(")#;VYT
M:6YG=70@9&4@)7,B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR
M.0IM<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`B0V]N=&EN=6%R(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C8Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU.`IM<V=I9"`B
M0V]O:R!)<VQA;F1S(@IM<V=S='(@(DEL;&5S($-O;VLB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R(")'86QE
M=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B0V]P:6%R(@H*(SH@
M;&EB+U9&4R]S;6(N<&AP.C0W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y
M(&9A:6QE9#H@)7,B"FUS9W-T<B`BR7,@:6UP;W-S:6)L92!C;W!I87(Z("5S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B0V]P:6%R('-E;&5C
M8VGS(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P.#0*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D-O<'EI;F<@)7,@=&\@)7,B"FUS9W-T<B`B6VSM
M;FEA("5S(&1E("5S72(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-C,*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B0V]S
M=&$@4FEC82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-3<*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B0V]S=&$@
M9"=)=F]R:2(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.CDU-@HC+"!F
M=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N(@IM
M<V=S='(@(DYO(&5S('!O="!X:69R87(@96P@;6ES<V%T9V4@86UB(%!'4"XB
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#,S"B,L(&9U>GIY"FUS
M9VED(")#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92XB"FUS9W-T<B`B3F\@
M97,@<&]T('-I9VYA<B!E;"!M:7-S871G92!A;6(@4$=0+B(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z,SDS"FUS9VED(")#;W5L9"!N;W0@4R]-
M24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B3F\@97,@<&]T('AI9G)A
M<B!E;"!M:7-S871G92!A;6(@4R]-24U%+B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@
M;65S<V%G92XB"FUS9W-T<B`B3F\@97,@<&]T('-I9VYA<B!E;"!M:7-S871G
M92!A;6(@4R]-24U%+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HQ.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C
M;VYT86-T+B`E<R(*;7-G<W1R(").;R!E<R!P;W0@869E9VER(&5L(&-O;G1A
M8W1E+B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C$Q,`IM<V=I
M9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(DYO
M(&5S('!O="!C;VYN96-T87(@86UB(&5L('-E<G9I9&]R($Q$05`N(@H*(SH@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S(@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C$U-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`B3F\@97,@
M<&]T(&-O;7!R;W9A<B!E;"!S86QD;RX@)7,B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z-#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!C;VYN96-T('1O('-E<G9E<B`G)7,G('5S:6YG($944#H@)7,B"FUS
M9W-T<B`B3F\@<R=H82!P;V=U="!C;VYN96-T87(@86UB(&5L('-E<G9I9&]R
M("<E<R<@;6ET:F%NYV%N="!&5%`Z("5S+B(*"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HQ,#@W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@8V]P>2`E<R!T;R`E<R(*;7-G<W1R(").;R!S)VAA('!O9W5T(&]B<FER
M("5S+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3F\@<R=H82!P;V=U="!C<F5A<B!U
M;F$@;&QI<W1A(&1E(&1I<W1R:6)U8VGS+B`E<R(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HV.#$@<&\O=')A;G-L871I;VXN<&AP.C$P-S<*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@;&]C86QE(&1I
M<F5C=&]R>2!F;W(@;&]C86QE("5S.B(*;7-G<W1R(").;R!S)VAA('!O9W5T
M(&]B<FER(&5L(&1I<F5C=&]R:2`G)7,G+B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C$Q,#4*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!D96-R
M>7!T(%!'4"!D871A+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(&1E<WAI9G)A
M<B!L97,@9&%D97,@4$=0+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-3(R"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB
M"FUS9W-T<B`B3F\@<R=H82!P;V=U="!D97-X:69R87(@;&5S(&1A9&5S(%,O
M34E-12XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0U
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C
M="X@)7,B"FUS9W-T<B`B3F\@<R=H82!P;V=U="!E<V)O<G)A<B!E;"!C;VYT
M86-T92X@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,S4U"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYO(',G:&$@<&]G=70@97-B
M;W)R87(@;&$@;&QI<W1A(&1E(&1I<W1R:6)U8VGS+B`E<R(*"B,Z(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.C,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T("<E
M<R<N(@IM<V=S='(@(DYO(',G:&$@<&]G=70@97-B;W)R87(@;&$@<V5Q_.AN
M8VEA(&0G86-T=6%L:71Z86-I\R!I;G-T86RW;&%D82`G)7,G+B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.CDS."!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C,X,0IM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C
M:7!I96YT)W,@92UM86EL(&%D9')E<W,N(@IM<V=S='(@(DYO(',G:&$@<&]G
M=70@9&5T97)M:6YA<B!L)V%D<F7G82!E;&5C='+R;FEC82!D96P@9&5S=&EN
M871A<FDN(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X
M,@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O
M:RXB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!R96-O;&QI<B!T;W1A(&QA(&QL
M:6)R971A(&0G861R96-E<RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-#DR"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@
M9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(DYO(',G:&$@<&]G=70@<F5C
M;VQL:7(@=&]T82!L82!L;&ES=&$@9&4@9&ES=')I8G5C:?,N(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T-0IM<V=I9"`B0V]U;&0@
M;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L
M:7-T<RXB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!R96-O;&QI<B!T;W1A(&QA
M(&QL:7-T82!D92!L97,@;&QI<W1E<R!D92!D:7-T<FEB=6-I\RXB"@HC.B!L
M:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*(SH@
M;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R
M871E9WD@)R5S)RXB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!C87)R96=A<B!L
M)V5S=')A=.AG:6$@)R5S)RXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@;&EB+U9&4R])4T]7<FET
M97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!M:V1I<B`G)7,G+B(*;7-G
M<W1R(").;R!S)VAA('!O9W5T(&-R96%R(&5L(&1I<F5C=&]R:2`G)7,G+B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<P.`IM<V=I9"`B0V]U;&0@
M;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS
M9W-T<B`B3F\@<R=H82!P;V=U="!O8G1E;FER('5N82!C;&%U('#Z8FQI8V$@
M9&5L('-E<G9I9&]R(&1E(&-L875S+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S0T(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@
M)7,N(@IM<V=S='(@(DYO(',G:&$@<&]G=70@;V)R:7(@)7,N(@H*(SH@;&EB
M+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`G
M)7,G(&9O<B!W<FET:6YG+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(&]B<FER
M("<E<R<@<&5R(&5S8W)I=7)E+B(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC
M92YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N
M($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(DYO(',G:&$@
M<&]G=70@;V)R:7(@96P@;?)D=6P@9&4@=&%S<75E<R!D92!M86YT96YI;65N
M="`E<RXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&]P96X@9&ER96-T;W)Y("<E<R<N(@IM<V=S='(@(DYO(',G:&$@
M<&]G=70@;V)R:7(@96P@9&ER96-T;W)I("<E<R<N(@H*(SH@;&EB+U9&4R]/
M8FIE8W0N<&AP.C(S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<F5A9"`E<RXB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!L;&5G:7(@)7,N(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O
M=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@
M=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C
M;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B).
M;R!S)VAA('!O9W5T(')E:6YI8VEA<B!L82!C;VYT<F%S96YY82!P97(@82!L
M)W5S=6%R:2!S;VRW;&EC:71A="X@06QG=6YS("(*(F1E=&%L;',@;R!T;W1S
M(&YO('/S;B!C;W)R96-T97,N(%1O<FYA<BUH;R!A(&EN=&5N=&%R(&\L('!E
M<B!A(&WI<R`B"B)I;F9O<FUA8VGS+"!P;W-A)W0@96X@8V]N=&%C=&4@86UB
M(&PG861M:6YI<W1R861O<B!D96P@<VES=&5M82XB"@HC.B!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y(&QI8B](;W)D92])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS-#`*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,W-R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@S"B,Z
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#D*;7-G:60@(D-O
M=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!R
M96-U<&5R87(@;&5S($%#3"(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HR-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E
M=')I979E(&%D9')E<W,@8F]O:RX@)7,B"FUS9W-T<B`B3F\@<R=H82!P;V=U
M="!R96-U<&5R87(@;&$@;&QI8G)E=&$@9"=A9')E8V5S+B`E<R(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<R(*;7-G<W1R(").;R!S)VAA('!O9W5T(')E8W5P97)A<B!L82!L;&ES
M=&$@9&4@9&ES=')I8G5C:?,N("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C0S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R(").
M;R!S)VAA('!O9W5T(')E8W5P97)A<B!L97,@;&QI<W1E<R!D92!D:7-T<FEB
M=6-I\RX@)7,B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,3DY(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PIM<V=I9"`B0V]U;&0@
M;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R(").
M;R!S)VAA('!O9W5T(')E8W5P97)A<B!L97,@<&]S<VEB:6QI=&%T<R!D96P@
M<V5R=FED;W(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"FUS9VED
M(")#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DYO
M(',G:&$@<&]G=70@<F5S=&%U<F%R(&QA(&-O;F9I9W5R86-I\RXB"@HC.B!L
M:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HY
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER
M("<E<R<N(@IM<V=S='(@(DYO(',G:&$@<&]G=70@96QI;6EN87(@96P@9&ER
M96-T;W)I("<E<R<N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!D97-A<B!L82!C;VYF
M:6=U<F%C:?,@)7,N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C8S"FUS9VED(")#;W5L9"!N;W0@<V%V
M92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@(DYO(',G:&$@<&]G
M=70@9&5S87(@=6YA(&-O;F9I9W5R86-I\R!D92!S96=U<F5T870N(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS
M9W-T<B`B3F\@<R=H82!P;V=U="!D97-A<B!U;F$@8V]N9FEG=7)A8VGS(&1E
M('-E9W5R971A=#H@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY
M,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@
M<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("<E<R<N(@IM<V=S='(@(DYO(',G
M:&$@<&]G=70@9&5S87(@;&$@<V5Q_.AN8VEA(&0G86-T=6%L:71Z86-I\R!I
M;G-T86RW;&%D82!E;CH@)R5S)RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C8T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('1H
M92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R("(B"B).
M;R!S)VAA('!O9W5T(&1E<V%R(&QA(&/R<&EA(&1E('-E9W5R971A="!D92!L
M)V%R>&EU(&1E(&-O;F9I9W5R86-I\R`E<RXB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C<T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO
M="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET
M:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D
M92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@
M=&\@)7,N(@IM<V=S='(@(B(*(DYO(',G:&$@<&]G=70@9&5S87(@;"=A<GAI
M=2!D92!C;VYF:6=U<F%C:?,@)7,N(%!O=',@=71I;&ET>F%R('5N82!D92!L
M97,@(@HB;W!C:6]N<R!P97(@=&]R;F%R(&$@9&5S87(@96P@8V]D:2!E;B`E
M<R!O(&+I(&-O<&EA<B!M86YU86QM96YT(&5L(&-O9&D@(@HB<V5G_&5N="!E
M;B`E<RXB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ,C`*;7-G:60@
M(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R(").
M;R!S)VAA('!O9W5T(&-E<F-A<B!A;"!S97)V:61O<B!,1$%0+B(*"B,Z(&QI
M8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK
M("<E<R<N(@IM<V=S='(@(DYO(',G:&$@<&]G=70@9&5S96YL;&'G87(@)R5S
M)RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$X"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@
M)7,B"FUS9W-T<B`B3F\@<R=H82!P;V=U="!A8W1U86QI='IA<B!E;"!C;VYT
M86-T92X@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,SDU"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYO(',G:&$@<&]G=70@86-T
M=6%L:71Z87(@;&$@;&QI<W1A(&1E(&1I<W1R:6)U8VGS+B`E<R(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R("<E<R<Z
M("5S(@IM<V=S='(@(DYO(',G:&$@<&]G=70@97-C<FEU<F4@;&$@8V]N9FEG
M=7)A8VGS('!E<B!A("<E<R<Z("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,U-@IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E
M8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB"FUS9W-T<B`B
M(@HB3F\@<R=H82!P;V=U="!L;V-A;&ET>F%R(&QA(&)A<G)A(&QA=&5R86P@
M9&4@36]Z:6QL82X@0V]M<')O=F$@<75E(&QA(&)A<G)A("(*(FQA=&5R86P@
M97-T:6=U:2!O8F5R=&$N(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C$U-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&1N
M)W0@9VEV92!U<V5R("<E<R<@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H
M92!F;VQD97(@)R5S)SH@)7,B"FUS9W-T<B`B(@HB3F\@<R=H82!P;V=U="!C
M;VYC961I<B!A(&PG=7-U87)I("<E<R<@96QS(&1R971S('-E9_QE;G1S('!E
M<B!A(&QA(&-A<G!E=&$@)R4B"B)S)SH@)7,B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,30R-`IM<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(E1E>'0@
M8V]M<'1A="(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-38Y"FUS
M9VED(")#;W5N=')Y(@IM<V=S='(@(E!A[7,B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C8X"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(D-U<G-O
M<R(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3<*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C$P,0IM<V=I9"`B0W)E871E(@IM<V=S='(@(D-R96%R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8W"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@(D-R96%R('5N
M(&5N;&QAYR(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI
M;F,Z.3,*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`B0W)E87(M
M;F4@=6X@9&4@;F]U(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.CDR"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B0W)E
M87(@<W5B8V%R<&5T97,B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,S8@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR,30*;7-G:60@(D-R96%T;W(@4&5R
M;6ES<VEO;G,B"FUS9W-T<B`B4&5R;6ES;W,@9&5L(&-R96%D;W(B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,S(R.`IM<V=I9"`B0W)E9&ET(&-A<F0@;G5M
M8F5R(@IM<V=S='(@(D[Z;65R;R!D92!L82!T87)G971A(&1E(&-RZ&1I="(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HV-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`Y
M"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(D-R;^!C:6$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8T"FUS9VED(")#=6)A
M(@IM<V=S='(@(D-U8F$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*;7-G
M:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B-"!F87-E<R!A8W1U86QS
M(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I;64N<&AP
M.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T<B`B5&5M<',@86-T=6%L
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4S"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G<W1R(")%;"!5
M4DP@86-T=6%L(.ES(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I
M9"`B0W5R<F5N="!796%T:&5R(@IM<V=S='(@(E1E;7!S(&%C='5A;"(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-C(*;7-G:60@(D-U<G)E
M;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`B0V]N9&EC:?,@86-T=6%L.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G
M:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`B17-T:6P@86-T=6%L(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM
M<V=S='(@(B(*(E!E<G-O;F%L:71Z974@;&5S('1A<W%U97,@<75E(',G:&%N
M(&5X96-U=&%R('%U86X@<R=I;FEC:6$@;&$@<V5S<VGS(&$@)7,N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(P"FUS9VED(")#=70B"FUS9W-T<B`B4F5T86QL87(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,U"FUS9VED(")#=70@
M<V5L96-T:6]N(@IM<V=S='(@(E)E=&%L;&%R(&QA('-E;&5C8VGS(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C8V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-PIM<V=I
M9"`B0WEP<G5S(@IM<V=S='(@(EAI<')E(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#(*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(D-I
M<NULMVQI8R`H2T])."U2*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S
M"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R(")#:7+M
M;+=L:6,@*%=I;F1O=W,M,3(U,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X-`IM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S
M='(@(D-I<NULMVQI8R]58W)A[V[H<R`H2T])."U5*2(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HV-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C@*;7-G:60@(D-Z96-H
M(%)E<'5B;&EC(@IM<V=S='(@(E)E</IB;&EC82!4>&5C82(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,C,@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(D1$(@H*(SH@;&EB+TAO
M<F1E+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`B
M1&G@<FEA;65N="(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I9"`B
M1&%T851R964@0G)O=W-E<B(*;7-G<W1R(").879E9V%D;W(@9&4@1&%T851R
M964B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,Y-R!L:6(O2&]R9&4O34E-
M12]6:65W97(O<F9C.#(R+G!H<#HW,@IM<V=I9"`B1&%T92(*;7-G<W1R(")$
M871A(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*
M;7-G:60@(D1A=&4@4F5C96EV960B"FUS9W-T<B`B4R=H82!R96)U="!L82!D
M871A(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,#4*;7-G:60@(D1A=&4@
M<V5L96-T:6]N(@IM<V=S='(@(E-E;&5C8VGS(&1E(&1A=&$B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`V"FUS9VED(")$87DB"FUS9W-T
M<B`B1&EA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,U"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G<W1R
M(")3=7!R:6UI<B!C;VQU;6YA(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C,X-2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(D1E<V5M8G)E(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N
M9RYJ<SHQ-@IM<V=I9"`B1&5C:6UA;"!N=6UB97)S(@IM<V=S='(@(DYO;6)R
M97,@9&5C:6UA;',B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`B
M4F5D=>]U(&5L('-A9VYA="(*"B,Z(&QI8B]P<F5F<RYP:'`Z,3$Q(&QI8B](
M;W)D92]0<F5F<R]522YP:'`Z,3@W"FUS9VED(")$969A=6QT(@IM<V=S='(@
M(E!R961E=&5R;6EN870B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHT-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHX,0IM<V=I9"`B1&5F875L="!#;VQO<B(*;7-G<W1R
M(")#;VQO<B!P<F5D971E<FUI;F%T(@H*(SH@;&EB+TAO<F1E+TED96YT:71Y
M+G!H<#HY,0IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*;7-G<W1R("))9&5N
M=&ET870@<')E9&5T97)M:6YA9&$B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H
M<#HQ,3D@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ.38*(RP@9G5Z>GD*;7-G
M:60@(D1E9F%U;'0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B4W5P<FEM:7(@<&5R
M;>US(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ.3<*(RP@9G5Z>GD*
M;7-G:60@(D1E9F%U;'0@<&5R;6ES<VEO;G,B"FUS9W-T<B`B4W5P<FEM:7(@
M<&5R;>US(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$
M969I;FET:6]N<R(*;7-G<W1R(")$969I;FEC:6]N<R(*"B,Z(&QA;F=T97-T
M+G!H<#HR,2!L86YG=&5S="YP:'`Z,C,@861M:6XO9W)O=7!S+G!H<#HW,@HC
M.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V(&%D;6EN+W!E<FUS+V1E;&5T
M92YP:'`Z-3(@;&EB+TAO<F1E+U!E<FUS+G!H<#HR.34*(SH@;&EB+TAO<F1E
M+U!E<FUS+U5)+G!H<#HS,34@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS,S(*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S$@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$S"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHW,R!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M.3D*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C<P"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z.3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ.#(*;7-G:60@(D1E;&5T92(*;7-G<W1R(")3=7!R:6UI<B(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z,3@Y(&%D;6EN+V=R;W5P<RYP:'`Z,C$W"FUS
M9VED(")$96QE=&4@1W)O=7`B"FUS9W-T<B`B4W5P<FEM:7(@9W)U<"(*"B,Z
M(&QI8B](;W)D92]097)M<R]522YP:'`Z-C,@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HX-PIM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B4W5P
M<FEM:7(@<&5R;>US(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S
M='(@(E-U<')I;6ER(&D@8G5I9&%R(&UI<W-A=&=E<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3<*;7-G:60@
M(D1E;&5T92!C96QL(@IM<V=S='(@(E-U<')I;6ER(&-E;+=L82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*
M;7-G:60@(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`B4W5P<FEM:7(@8V]L=6UN
M82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS9VED(")$96QE=&4@
M97AI<W1I;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(E-U<')I;6ER
M(&QA('!L86YT:6QL82!A;'1E<FYA=&EV82!E>&ES=&5N="(*"B,Z(&%D;6EN
M+W!E<FUS+V1E;&5T92YP:'`Z-3`@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS
M,30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S
M:6]N<R!F;W(@)R5S)R(*;7-G<W1R(")3=7!R:6UI<B!P97)M:7-O<R!P97(@
M82`G)7,G(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS,3<*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@
M)R5S)R!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T<B`B4W5P<FEM
M:7(@<&5R;6ES;W,@<&5R(&$@)R5S)R!I('1O=',@96QS('-U8G!E<FUI<V]S
M/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T<B`B4W5P<FEM:7(@
M9FEL82(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I9&5N=&ET>2YI;F,Z
M,34*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET>2(*;7-G<W1R(")3
M=7!R:6UI<B!L82!I9&5N=&ET870@<V5L96-C:6]N861A(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS
M9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(E-U<')I
M;6ER(&QA(&-O;'5M;F$@86-T=6%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R"FUS9VED(")$96QE=&4@
M=&AE(&-U<G)E;G0@<F]W(@IM<V=S='(@(E-U<')I;6ER(&QA(&9I;&$@86-T
M=6%L(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HT.`HC+"!F=7IZ>0IM
M<V=I9"`B1&5L971E('1H:7,@<&5R;6ES<VEO;B!A;F0@86YY('-U8BUP97)M
M:7-S:6]N<S\B"FUS9W-T<B`B4W5P<FEM:7(@<&5R;6ES;W,@<&5R(&$@)R5S
M)R!I('1O=',@96QS('-U8G!E<FUI<V]S/R(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE
M=&5D('-E='5P('5P9W)A9&4@<V-R:7!T("<E<R<N(@IM<V=S='(@(E,G:&$@
M<W5P<FEM:70@;&$@<V5Q_.AN8VEA(&0G86-T=6%L:71Z86-I\R!I;G-T86RW
M;&%D82`G)7,G+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C(P(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4R"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C(@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-`IM<V=I9"`B1&5L:79E<GD@=&EM
M92(*;7-G<W1R(")(;W)A(&1E(&QL:75R86UE;G0B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<Q"FUS9VED(")$96YM87)K
M(@IM<V=S='(@(D1I;F%M87)C82(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP
M.C$Q,"!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,30@<V5R=FEC97,O<')O8FQE
M;2YP:'`Z,3(T"FUS9VED(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R
M(")$97-C<FEV:74@96P@<')O8FQE;6$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z.3,X('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S`*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(D1E<V-R:7!C
M:?,B"@HC.B!L:6(O2&]R9&4N<&AP.C$Y-0IM<V=I9"`B1&5T86EL<R`H86QS
M;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R(")$971A;&QS("AT86UB
MZ2!A;"!F:71X97(@9&4@<F5G:7-T<F4@9&4@2&]R9&4I.B(*"B,Z(&QI8B](
M;W)D92YP:'`Z,3DY"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@
M9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")%;',@9&5T86QL<R!H
M86X@97-T870@<F5G:7-T<F%T<R!P97(@82!L)V%D;6EN:7-T<F%D;W(N(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y-@IM<V=I9"`B1&5V96QO
M<&UE;G0B"FUS9W-T<B`B1&5S96YV;VQU<&%M96YT(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,34*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R(")0=6YT
M(&1E(')O<V%D82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDR"FUS9VED
M(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(E!U;G0@9&4@
M<F]S861A(&1E(&QA(&1A<G)E<F$@:&]R83HB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C$Y"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R
M(")0=6YT(&1E(')O<V%D83H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE9G0@=&\@
M<FEG:'0B"FUS9W-T<B`B1"=E<W%U97)R82!A(&1R971A(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER
M96-T:6]N(')I9VAT('1O(&QE9G0B"FUS9W-T<B`B1&4@9')E=&$@82!E<W%U
M97)R82(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E
M8W1O<GDB"FUS9W-T<B`B1&ER96-T;W)I(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(U-@IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*;7-G
M<W1R(")6;VQS('9I<W5A;&ET>F%R+6AO(&5N(&9O<FUA="!D92`R-"!H;W)E
M<S\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<*;7-G:60@(D1I<W!L
M87D@3W!T:6]N<R(*;7-G<W1R(")/<&-I;VYS(&1E('9I<W5A;&ET>F%C:?,B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@S"FUS9VED(")$:7-P;&%Y(&9O
M<F5C87-T("A4048I(@IM<V=S='(@(DUO<W1R82!L82!P<F5V:7-I\R`H5$%&
M*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#$U"FUS9VED(")$:7-P;&%Y
M(&9O<FUA="(*;7-G<W1R(")&;W)M870@9&4@=FES=6%L:71Z86-I\R(*"B,Z
M(&QI8B](;W)D92]-24U%+TU$3BYP:'`Z,3DP"FUS9VED(")$:7-P;W-I=&EO
M;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B3F]T:69I8V%C:?,@9&4@<F5C97!C
M:?,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C<P"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R(")$:FEB;W5T:2(*"B,Z(&%D
M;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HS,34*;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B3F\@:&\@<W5P
M<FEM:74B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,C0*;7-G:60@
M(D1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S
M='(@(DYO(&%C8V5D:74@9&ER96-T86UE;G0@82!M86EN=&5N86YC92YP:'`B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ.2!T96UP;&%T97,O
M9&%T82]T<W9I;F9O+FEN8SHQ.0IM<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W
M(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@
M8F]X.B(*;7-G<W1R("(B"B),82!P<FEM97)A(&9I;&$@8V]N=.D@96QS(&YO
M;7,@9&5L<R!C86UP<S\@16X@8V%S(&%F:7)M871I=2P@86-T:79A(&%Q=65S
M=&$@(@HB8V%S96QL83HB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C<R"FUS9VED(")$;VUI;FEC82(*;7-G<W1R(")$;VUI
M;FEC82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-S,*;7-G:60@(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R(")297#Z
M8FQI8V$@1&]M:6YI8V%N82(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S
M+G!H<#HX,S<*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(D1E<V-A<G)E9V%R
M(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@S-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G<W1R(")$97-C87)R96=A
M<B`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C4*;7-G:60@(D1O
M=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N
M(@IM<V=S='(@(D1E<V-A<G)E9V%R(&QA(&-O;F9I9W5R86-I\R!G96YE<F%D
M82!C;VT@=6YA('-E<?SH;F-I82!02%`N(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(Q,#<*;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@(DQL:7-T
M82!D97-P;&5G86)L92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-`IM
M<V=I9"`B1')U9W,B"FUS9W-T<B`B1')O9W5E<R(*"B,Z(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C0P,@IM<V=I9"`B12U-86EL(@IM<V=S='(@(D-O<G)E
M=2!E;&5C='+R;FEC(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS9W-T<B`B15)2(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C<R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-0IM
M<V=I9"`B16-U861O<B(*;7-G<W1R(")%<75A9&]R(@H*(SH@;&EB+TAO<F1E
M+U!E<FUS+G!H<#HR.30@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<R
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHV.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.CDR('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3,X('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3@Q"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,C(*;7-G:60@
M(D5D:70B"FUS9W-T<B`B161I=&$B"@HC.B!L:6(O2&]R9&4O0FQO8VLO54DN
M<&AP.C4P('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,C(*;7-G:60@(D5D
M:70@0FQO8VLB"FUS9W-T<B`B161I=&$@8FQO8R(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,3@X(&%D;6EN+V=R;W5P<RYP:'`Z,C$V"FUS9VED(")%9&ET($=R
M;W5P(@IM<V=S='(@(D5D:71A(&=R=7`B"@HC.B!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C8R(&QI8B](;W)D92]097)M<R]522YP:'`Z.#8*;7-G:60@(D5D
M:70@4&5R;6ES<VEO;B(*;7-G<W1R(")%9&ET82!P97)M[7,B"@HC.B!S97)V
M:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I
M;VYS(@IM<V=S='(@(D5D:71A('!E<FUI<V]S(@H*(SH@<V5R=FEC97,O<VAA
M<F5S+V5D:70N<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E
M<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R(")%9&ET82!P97)M:7-O<R!D92`E
M<R(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@
M;W!T:6]N<R!F;W(Z(@IM<V=S='(@(D5D:71A(&]P8VEO;G,@9&4Z(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R(")%9&ET82!P
M97)M:7-O<R!D92`E<R(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C(P-"!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(X,`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)R5S)R(*;7-G<W1R(")%
M9&ET82!P97)M:7-O<R!D92`E<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS-0IM<V=I9"`B161U8V%T:6]N(@IM<V=S='(@(D5D=6-A8VGS(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C<S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-PIM<V=I
M9"`B16=Y<'0B"FUS9W-T<B`B16=I<'1E(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$W"FUS9VED(")%;"!386QV861O
M<B(*;7-G<W1R(")%;"!386QV861O<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@IM<V=I9"`B16QE;65N
M="XN+B(*;7-G<W1R(")%;&5M96YT+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@
M(E%U861R873M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-CD@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0*;7-G:60@(D5M86EL(@IM
M<V=S='(@(D-O<G)E=2!E;&5C='+R;FEC(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU-C4@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHT,`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$R"FUS
M9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D%D<F7G82!E;&5C='+R;FEC
M82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.38S"FUS9VED(")%;6%I;"!A
M9&1R97-S97,@;75S="!M871C:"XB"FUS9W-T<B`B3&5S(&%D<F5C97,@96QE
M8W1R\FYI<75E<R!H86X@9&4@8V]I;F-I9&ER+B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ.3@Y"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*
M;7-G<W1R(")#;W)R974@96QE8W1R\FYI8R!A;6(@8V]N9FER;6%C:?,B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C@P"FUS9VED
M(")%;6]T:6-O;G,B"FUS9W-T<B`B16UO=&EC;VYE<R(*"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"FUS9VED(")%;7!T>2!M97-S
M86=E+B(*;7-G<W1R(")-:7-S871G92!E;B!B;&%N8RXB"@HC.B!L:6(O2&]R
M9&4O075T:"]L9&%P+G!H<#HQ,C@*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS
M9W-T<B`B4F5S=6QT870@96X@8FQA;F,N(@H*(SH@;&EB+TAO<F1E+U-13"]+
M97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS
M9W-T<B`B0G5I9&%R(&5L<R!T97)M97,@9&4@8V5R8V$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3,R"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F
M(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R
M(")(86)I;&ET87(@;&$@:6YS97)C:?,@9&4@:6UA=&=E<R!D92!L97,@9V%L
M97)I97,@9&4@9F]T;W,@96X@96P@=&5X=#\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3`W"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X
M="!M96YU/R(*;7-G<W1R(")(86)I;&ET87(@96P@;65N^B!D92!C;VYT97AT
M(&-L:6-A;G0@96X@96P@8F]T\R!D<F5T/R(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR-3DV(&QI8B](;W)D92]&;W)M+G!H<#HR.#`Y"FUS9VED(")%;F0@
M>65A<B(*;7-G<W1R(")!;GD@9&4@9FEN86QI='IA8VGS(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL
M87)G92!%9&ET;W(B"FUS9W-T<B`B06UP;&EA<B!L)V5D:71O<B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR,3$*;7-G:60@(B(*(D5N=&5R(&$@<V5C
M=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U
M(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA="!I
M<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B"B));G1R;V1U
M[W4@=6YA('!R96=U;G1A(&1E('-E9W5R971A="!Q=64@<V4@=7,@9F]R;75L
M87+@('-I('5S(&-A;"!R96EN:6-I87(@(@HB;&$@8V]N=')A<V5N>6$L('!E
M<B!E>&5M<&QE("=C;VT@97,@9&EU(&5L('9O<W1R92!A;FEM86P@9&4@8V]M
M<&%N>6EA/R<Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@
M55),(&AE<F4B"FUS9W-T<B`B26YT<F]D=>]U(&%Q=>T@96P@55),(&1E(&QA
M(&EM871G92(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,38S"B,L('!H<"UF
M;W)M870*;7-G:60@(D5N=')I97,Z("5D('1O=&%L+"`E9"!U<"UT;RUD871E
M+"`E9"!N97<L("5D(&-H86YG960L("5D('5N:VYO=VXB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C<U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY.0IM
M<V=I9"`B17%U871O<FEA;"!'=6EN96$B"FUS9W-T<B`B1W5I;F5A($5Q=6%T
M;W)I86PB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C<Y"FUS9VED(")%<FET<F5A(@IM<V=S='(@(D5R:71R96$B"@HC.B!L
M:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0U(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HU-0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,V
M"FUS9VED(")%<G)O<B(*;7-G<W1R(")%<G)O<B(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`T"FUS9VED(")%<G)O<B!W:71H(&5M
M86EL(&UE<W-A9V4N(@IM<V=S='(@(DAI(&AA(&AA9W5T('5N(&5R<F]R(&%M
M8B!E;"!M:7-S871G92!E;&5C='+R;FEC+B(*"B,Z(&QI8B]61E,O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN9R`G)7,G+B(*;7-G<W1R
M(")(:2!H82!H86=U="!U;B!E<G)O<B!E;B!E<V-R:75R92`G)7,G+B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HT,3,@<&\O=')A;G-L871I;VXN<&AP.C4R
M,B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,W-PHC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z,30S."!P;R]T<F%N<VQA=&EO;BYP:'`Z,34P,0HC+"!F=7IZ>0IM<V=I
M9"`B17)R;W(Z("(*;7-G<W1R(")%<G)O<B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-PHC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S8*;7-G:60@(D5S=&]N:6$B"FUS
M9W-T<B`B17-T\FYI82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW.`HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z.#$*;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(D5T:?)P
M:6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T:&YI
M8R(*;7-G<W1R("+(=&YI8R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B175R;W!A(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,R.0IM<V=I9"`B179E<GD@,34@;6EN=71E<R(*
M;7-G<W1R(")#861A(#$U(&UI;G5T<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-SD*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R(")#861A
M(#(@;6EN=71S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,R-B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S<W"FUS9VED(")%=F5R>2`S,"!S96-O;F1S
M(@IM<V=S='(@(D-A9&$@,S`@<V5G;VYS(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,R."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@P"FUS9VED(")%
M=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B0V%D82`U(&UI;G5T<R(*"B,Z(&QI
M8B](;W)D92]-86EN=&5N86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y($QO9VEN
M(@IM<V=S='(@(D-A9&$@:6YI8VD@9&4@<V5S<VGS(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,S,`IM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S
M='(@(D-A9&$@;6ET:F$@:&]R82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS,C<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.`IM<V=I9"`B179E<GD@
M;6EN=71E(@IM<V=S='(@(D-A9&$@;6EN=70B"@HC.B!T96UP;&%T97,O9&%T
M82]D871E;6%P+FEN8SHR.`IM<V=I9"`B17AA;7!L92!V86QU97,Z(@IM<V=S
M='(@(E9A;&]R<R!D)V5X96UP;&4Z(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP
M.C@Q(&%D;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3(X"FUS9VED(")%>&5C=71E(@IM<V=S='(@(D5X96-U=&$B"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,CDY('!O+W1R86YS;&%T:6]N+G!H<#HS,C`@<&\O
M=')A;G-L871I;VXN<&AP.C,V,@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#0Q
M('!O+W1R86YS;&%T:6]N+G!H<#HU-#$@<&\O=')A;G-L871I;VXN<&AP.C8P
M,0HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S`R('!O+W1R86YS;&%T:6]N+G!H
M<#HW,S<@<&\O=')A;G-L871I;VXN<&AP.C<Y.`HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z.#<U('!O+W1R86YS;&%T:6]N+G!H<#HY.30@<&\O=')A;G-L871I
M;VXN<&AP.C$P,38*(RP@9G5Z>GD*;7-G:60@(D5X96-U=&EN9SHB"FUS9W-T
M<B`B17AE8W5T87(B"@HC.B!L86YG=&5S=#(N<&AP.C$W"B,L(&9U>GIY"FUS
M9VED(")%>&ET(@IM<V=S='(@(D5D:71A(@H*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="YP:'`Z,SDT"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B17AP86YD
M96EX(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHS,0IM<V=I
M9"`B17AP86YD(%-I9&5B87(B"FUS9W-T<B`B17AP86YD:7(@;&$@8F%R<F$@
M;&%T97)A;"(*"B,Z(&QI8B](;W)D92]344PO2V5Y=V]R9',N<&AP.C$V.`IM
M<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@(E,G97-P97)A=F$@)RDG(@H*
M(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E
M8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@
M(E,G97-P97)A=F$@=6X@<V]L(&UO="!O('5N('1E<FUE(&1E(&-E<F-A(&-I
M=&%T(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#`Q"FUS9VED(")%
M>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B1&%T82!D92!V96YC:6UE;G0B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8W-@IM<V=I9"`B17AP;VYE
M;G0B"FUS9W-T<B`B17AP;VYE;G0B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,C<R"B,L('!H<"UF;W)M870*;7-G:60@(D5X=')A8W1I;F<@9G)O;2`E<RXN
M+B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B
M0V]L;W(@9&4@<')I;65R('!L82(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ.#`*;7-G:60@(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B0^!R
M<F5G82!D92!L82!C;VYF:6=U<F%C:?,@9&5L($944"(*"B,Z(&QI8B](;W)D
M92]0<F5F<R]S<6PN<&AP.C(Q-@IM<V=I9"`B1F%I;&5D(')E=')I979I;F<@
M<')E9F5R96YC97,N(@IM<V=S='(@(LES(&EM<&]S<VEB;&4@<F5C=7!E<F%R
M(&QE<R!P<F5F97+H;F-I97,N(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP
M:'`Z,3`P"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E
M<BXB"FUS9W-T<B`BR7,@:6UP;W-S:6)L92!C;VYN96-T87(@86UB(&5L('-E
M<G9I9&]R($Q$05`N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<VUB+G!H<#HY.`IM
M<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T
M<B`BR7,@:6UP;W-S:6)L92!C;VYN96-T87(@86UB(&5L('-E<G9I9&]R(%--
M0BXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-C`S"B,L('!H<"UF;W)M870*;7-G
M:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R("+)<R!I
M;7!O<W-I8FQE(&-O<&EA<B!D92!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F='`N
M<&AP.C8P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!T
M;R!<(B5S7"(N(@IM<V=S='(@(LES(&EM<&]S<VEB;&4@8V]P:6%R(&$@7"(E
M<UPB+B(*"B,Z(&QI8B](;W)D92]!=71H+W-A<VPN<&AP.C@W"FUS9VED(")&
M86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@
M(LES(&EM<&]S<VEB;&4@8W)E87(@=6YA(&YO=F$@8V]N;F5X:?,@4T%33"XB
M"@HC.B!L:6(O5D93+V9T<"YP:'`Z-C0Q(&QI8B]61E,O<VUB+G!H<#HT.3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB
M+B(*;7-G<W1R("+)<R!I;7!O<W-I8FQE('1R86YS9F5R:7(@82!<(B5S7"(N
M(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(LES(&EM<&]S<VEB
M;&4@<F5C=7!E<F%R.B`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$V"FUS9VED(")&86ER(@IM<V=S='(@(D-L87(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-SD*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@T"FUS
M9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B26QL
M97,@1F%L:VQA;F0@*$UA;'9I;F5S*2(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#8*;7-G:60@(D9A<F]E($ES;&%N9',B
M"FUS9W-T<B`B26QL97,@1NAR;V4B"@HC.B!L:6(O2&]R9&4O0TQ)+G!H<#HR
M,S@*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R(")%<G)O<B!I<G)E8W5P
M97)A8FQE("(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3@W"FUS9VED(")&87@B"FUS9W-T<B`B1F%X(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W-2!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#$R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(D9E
M8G)E<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$X"FUS9VED(")&965L
M<R!,:6ME(@IM<V=S='(@(E-E('-E;G0@8V]M(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(R,PIM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S
M='(@(E-E('-E;G0@8V]M.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$W"FUS9VED(")&97<@4VAO=V5R<R(*;7-G<W1R(")0
M;W%U97,@<&QU9V5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3@*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B
M4&]C<R!XX&9E8W,@9&4@;F5U(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y
M-#0*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R(")-871R:74@9&5L(&-A
M;7`B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C@S"FUS9VED(")&:6II(@IM<V=S='(@(D9I:FDB"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O>FEP+G!H<#HV-"!L:6(O2&]R9&4O34E-12]6:65W97(O
M=&=Z+G!H<#HX,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM
M<V=S='(@(E)E8V]M<'1E(&0G87)X:75S.B!A<GAI=2`E<R(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8T(&QI8B](;W)D92]-24U%+U9I
M97=E<B]T9WHN<&AP.C@R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N
M<&AP.C8P"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I
M;&5S(@IM<V=S='(@(E)E8V]M<'1E(&0G87)X:75S.B`E<R!A<GAI=7,B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0T"FUS9VED(")&:6QE($UA
M;F%G97(B"FUS9W-T<B`B1V5S=&]R(&0G87)X:75S(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+WII<"YP:'`Z-C<@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#4*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C,*;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R(").;VT@9&4@;"=A<GAI=2(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.3DS"FUS9VED(")&:6QE('-E;&5C
M=&EO;B(*;7-G<W1R(")396QE8V-I\R!D)V%R>&EU<R(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ-#DQ"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R(")#
MX')R96=A(&1E(&PG87)X:74B"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z
M.#4S"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T
M<B`B3F\@Z7,@<&5R;>AS('!E;FIA<B!A<GAI=7,B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z.#<*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`B1FEL
M=')E<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.#(*;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`B1FEN;.!N9&EA(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C$W,0IM<V=I9"`B1FER<W0@2&%L9B(*;7-G
M<W1R(")0<FEM97)A(&UE:71A="(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW
M-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U87)T97(B
M"FUS9W-T<B`B4')I;65R('%U87)T(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(S.0IM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@
M(E)A\R!F:7AA(R,B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C$T"FUS9VED(")&;&EP(@IM<V=S='(@(DEN=F5R=&EU(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B0V]M82!F;&]T86YT(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9O
M9R(*;7-G<W1R(")";VER82(*"B,Z(&QI8B]61E,O<W%L+G!H<#HQ-C`@;&EB
M+U9&4R]M=7-Q;"YP:'`Z,3`W"B,L('!H<"UF;W)M870*;7-G:60@(D9O;&1E
M<B`E<R!D;V5S(&YO="!E>&ES="(*;7-G<W1R("),82!C87)P971A("5S(&YO
M(&5X:7-T96EX(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R(")#;VQO<B!D
M92!L82!F;VYT(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS9VED
M(")&;V]D(@IM<V=S='(@(DUE;FIA<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R
M(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B
M4&5R(&%L<R!N879E9V%D;W)S('%U92!N;R!A9&UE=&5N(&QE<R!I;6%T9V5S
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,S(*;7-G:60@(D9O<F5C87-T
M("A4048I(@IM<V=S='(@(E!R979I<VGS("A4048I(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C<X"FUS9VED("(B"B)&;W)E8V%S="!$87ES
M("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T
M:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD
M(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*(E!R979I<VGS
M('!E<B!A;',@9&EE<R`H=&EN9W5E=2!P<F5S96YT('%U92!L82!P<F5V:7-I
M\R!F86-I;&ET861A(&-O;7!RZ&X@96P@(@HB9&EA(&D@;&$@;FET.B!U;B!N
M;VUB<F4@96QE=F%T('!O9')I82!T96YI<B!C;VT@82!R97-U;'1A="!U;B!B
M;&]C(&%M<&QE+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*
M;7-G:60@(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R(")(974@;V)L
M:61A="!L82!C;VYT<F%S96YY83\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#`P"FUS9VED(")&;W)M<R(*;7-G<W1R(")&;W)M=6QA<FES(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"FUS9VED(")&;W)T=6YE(@IM
M<V=S='(@(D1I=&$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G
M:60@(D9O<G1U;F4@='EP92(*;7-G<W1R(")4:7!U<R!D92!D:71E<R(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM<V=I9"`B1F]R='5N97,B"FUS
M9W-T<B`B1&ET97,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,SD*;7-G
M:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B1&ET97,@,B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS.3$*;7-G:60@(D9O<G5M<R(*;7-G<W1R(")&
M\G)U;7,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3`W"FUS9VED
M(")&;W)W87)D<R(*;7-G<W1R(")2965N=FEA;65N=',B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,30U.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M1F]U;F0@87!P;&EC871I;VYS.B`E<R(*;7-G<W1R(")!<&QI8V%C:?,@;F\@
M=N!L:61A+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ-#4R"B,L(&9U>GIY
M"FUS9VED(")&;W5N9"!D:7)E8W1O<FEE<SHB"FUS9W-T<B`B3F\@Z7,@=6X@
M9&ER96-T;W)I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`B1'8N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PIM<V=I
M9"`B1G)A;65S(@IM<V=S='(@(DUA<F-S(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-PIM<V=I9"`B1G)A;F-E(@IM<V=S
M='(@(D9R86[G82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S"FUS
M9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R(")&<F%NYV$@;65T
M<F]P;VQI=&%N82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<T(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z.3$*;7-G:60@(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B1W5A
M:6%N82!&<F%N8V5S82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3@T"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S
M='(@(E!O;&ENZ'-I82!&<F%N8V5S82(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,@IM<V=I9"`B1G)E;F-H(%-O=71H
M97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(E1E<G)I=&]R:7,@1G)A;F-E<V]S
M(&1E;"!3=60B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R(")$97,@9&4B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0P"FUS9VED(")&<F]M('1H92`B"FUS
M9W-T<B`B1&5S(&1E;"(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C0X"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(D1E<V-R
M:7!C:?,@8V]M<&QE=&$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#(@;&EB
M+T)L;V-K+VUO;VXN<&AP.C$X,0IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@
M(DQL=6YA('!L96YA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHS.0IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(DYO;2!C;VUP;&5T
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8U-PIM<V=I9"`B1G5Z>GDB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C@W"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HX.`IM<V=I9"`B1V%B;VXB"FUS9W-T<B`B1V%B;VXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S='(@
M(DQA(&=A;&5R:6$@9&4@;&$@<75A;"!S)V5X=')E=2!L82!I;6%T9V4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(D=A;&5R:6$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDV"FUS
M9VED(")'86UB:6$B"FUS9W-T<B`B1^!M8FEA(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E
M<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(D5S(&=E;F5R82!L82!C;VYF:6=U
M<F%C:?,@)7,B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT
M;6PZ,3`*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@(D-O9&D@9V5N
M97)A="(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT-SD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1V5N97)A=&EN9R!S=&%T=7,@9F]R(&UO9'5L92`E<RXN+B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.CDP"FUS9VED(")'96]R9VEA(@IM<V=S='(@(D=E\G)G:6$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8Y"FUS
M9VED(")'97)M86YY(@IM<V=S='(@(D%L96UA;GEA(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C$S-S$*(RP@9G5Z>GD*;7-G:60@(D=E=&]P="!%<G)O<CH@
M(@IM<V=S='(@(D5R<F]R(&ER<F5C=7!E<F%B;&4@(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.CDQ"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,PIM<V=I9"`B1VAA;F$B
M"FUS9W-T<B`B1VAA;F$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.CDT"FUS9VED(")':6)R86QT87(B"FUS9W-T<B`B1VEB
M<F%L=&%R(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S4*;7-G
M:60@(D=I=F5N($YA;64B"FUS9W-T<B`B3F]M(&1E('!I;&$B"@HC.B!T96UP
M;&%T97,O<')E9G,O87!P+FEN8SHQ,@IM<V=I9"`B1V\B"FUS9W-T<B`B06YA
M<B!A(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D
M96PB"FUS9W-T<B`B1_9D96PB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H(@IM<V=S='(@(D-E<F-A(&%L($=O
M;V=L92(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,C`*;7-G:60@(D=R87ES8V%L92(*;7-G<W1R(")%<V-A;&$@9&4@9W)I<V]S
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.CDS"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,#`*;7-G:60@(D=R965C92(*;7-G<W1R(")'<NAC:6$B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM
M<V=S='(@(D=R96,@*$E33RTX.#4Y+3<I(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HY-0IM<V=I9"`B1W)E96YL86YD(@IM
M<V=S='(@(D=R96YLX&YD:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C@Y"FUS9VED(")'<F5N861A(@IM<V=S='(@(D=R
M86YA9&$B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W,`IM<V=I9"`B1W)O=7`@
M061M:6YI<W1R871I;VXB"FUS9W-T<B`B1V5S=&GS(&1E(&=R=7!S(@H*(SH@
M;&EB+TAO<F1E+T=R;W5P+G!H<#HU.`IM<V=I9"`B1W)O=7`@;F%M97,@;75S
M="!B92!N;VXM96UP='DB"FUS9W-T<B`B16QS(&YO;7,@9&4@9W)U<"!N;R!E
M<R!P;V1E;B!D96EX87(@96X@8FQA;F,B"@HC.B!A9&UI;B]P97)M<R]E9&ET
M+G!H<#HR,#$@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR-S<*(RP@9G5Z>GD*
M;7-G:60@(D=R;W5P('!E<FUI<W-I;VYS(@IM<V=S='(@(E!E<FUI<V]S(&1E
M;',@=FES:71A;G1S(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3<V(&QI
M8B](;W)D92]097)M<R]522YP:'`Z,C4P(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<W"FUS9VED(")'
M<F]U<',B"FUS9W-T<B`B1W)U<',B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.CDX"FUS9VED(")'=6%D96QO=7!E(@IM<V=S
M='(@(D=U861A;'5P92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<W
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3`S"FUS9VED(")'=6%M(@IM<V=S='(@(D=U86TB"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,@IM
M<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@(D=U871E;6%L82(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B
M1W5E<FYS97DB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,C<@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HR,#4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B4&5R
M;6ES;W,@9&5L<R!V:7-I=&%N=',B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H
M<#HQ,C@@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR,#8*(RP@9G5Z>GD*;7-G
M:60@(D=U97-T('!E<FUI<W-I;VYS(@IM<V=S='(@(E!E<FUI<V]S(&1E;',@
M=FES:71A;G1S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P.`IM
M<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(DQL:6)R92!D92!V:7-I=&%N=',B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDW
M"FUS9VED(")'=6EN96$B"FUS9W-T<B`B1W5I;F5A(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$P,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`T"FUS9VED(")'=6EN
M96$M0FES<V%U(@IM<V=S='(@(D=U:6YE82!":7-S874B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#4*;7-G:60@(D=U
M>6%N82(*;7-G<W1R(")'=7EA;F$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M.38P"FUS9VED(")(5$U,(@IM<V=S='(@(DA434PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C
M96QL(&EN(')O=RXB"FUS9W-T<B`B2%1-3$%R96$@;F\@<&5R;65T('-U<')I
M;6ER(&QA(&1A<G)E<F$@8V5LMVQA(&1E(&QA(&9I;&$N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I
M9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA
M<W0@8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R(")(5$U,07)E82!N;R!P97)M
M970@<W5P<FEM:7(@;&$@9&%R<F5R82!C;VQU;6YA(&1E(&QA('1A=6QA+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#<*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L
M971E('1H92!L87-T(')O=R!I;B!T86)L92XB"FUS9W-T<B`B2%1-3$%R96$@
M;F\@<&5R;65T('-U<')I;6ER(&QA(&1A<G)E<F$@9FEL82!D92!L82!T875L
M82XB"@HC.B!L:6(O2&]R9&4O075T:"]H='1P+G!H<#HQ-3<*;7-G:60@(DA4
M5%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(").;R!S)VAA
M('1R;V)A="!L)V%U=&5N=&EC86-I\R!(5%10+B(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,#(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,`IM<V=I9"`B2&%I=&DB
M"FUS9W-T<B`B2&%I=.TB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT
M,#(*;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(D%L9V]R:7-M92!D
M92!H87-H(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C`*;7-G:60@(DAA>F4B"FUS9W-T<B`B0V%L:71J82(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HY,3D@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,S`*;7-G
M:60@(DAE861E<B(*;7-G<W1R(")#87#G86QE<F$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#<*;7-G:60@(DAE87)D
M($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R("));&QA($AE
M87)D(&D@:6QL97,@36-$;VYA;&0B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X-@IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(DAE
M8G)E=2`H25-/+3@X-3DM."U)*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*;7-G
M<W1R(")!;.=A9&$B"@HC.B!L:6(O2&]R9&4O2&5L<"YP:'`Z,3<X(&QI8B](
M;W)D92](96QP+G!H<#HQ.#4@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<*
M(SH@=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C,*;7-G:60@(DAE;'`B"FUS
M9W-T<B`B06IU9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R
M(")!:G5D82!P97(@=71I;&ET>F%R(&PG961I=&]R(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$S-S8*;7-G:60@(DAE;'!E<B(*;7-G<W1R(")!<&QI8V%C
M:?,@9"=A:G5D82(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HY-0IM<V=I9"`B
M(@HB2&5L<&5R(&%P<&QI8V%T:6]N('1O(&-R96%T92!A;F0@;6%I;G1A:6X@
M=')A;G-L871I;VYS(&9O<B!T:&4@2&]R9&5<;B(*(F9R86UE=V]R:R!A;F0@
M:71S(&%P<&QI8V%T:6]N<RY<;B(*(D9O<B!A;B!I;G1R;V1U8W1I;VX@<F5A
M9"!T:&4@9FEL92!214%$344@:6X@=&AI<R!D:7)E8W1O<GDN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R
M92(*;7-G<W1R(")(96UI<V9E<FDB"@HC.B!T96UP;&%T97,O9&%T82]C<W9I
M;F9O+FEN8SHQ-R!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ-PIM<V=I
M9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R
M(")!<75E<W0@Z7,@;"=I;FEC:2!D96P@9FET>&5R.B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")(:6=H(@IM
M<V=S='(@(D%L="(*"B,Z(&QI8B](;W)D92](:7-T;W)Y+G!H<#HS,C$*(RP@
M9G5Z>GD*;7-G:60@(DAI<W1O<GD@96YT<GD@;F%M97,@;75S="!B92!N;VXM
M96UP='DB"FUS9W-T<B`B16QS(&YO;7,@9&4@9W)U<"!N;R!E<R!P;V1E;B!D
M96EX87(@96X@8FQA;F,B"@HC.B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE
M861E<BYI;F,Z-"!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8*;7-G:60@
M(DAO7VUE(@IM<V=S='(@(DEN:6-I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,PIM<V=I9"`B2&]L>2!3964@*%9A
M=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`B;&$@4V%N=&$@4V5U("A#:75T
M870@17-T870@9&5L(%9A=&ECX"DB"@HC.B!L:6(O2&]R9&4N<&AP.C$T,C8*
M;7-G:60@(DAO;64B"FUS9W-T<B`B26YI8VDB"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$R,B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(D%D
M<F7G82!P87)T:6-U;&%R(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B5&5LZ&9O
M;B!P87)T:6-U;&%R(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3`X"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R(")(;VYD
M=7)E<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<X(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$P-@IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(DAO;F<@2V]N9R(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV,PIM<V=I9"`B2&]R9&4B
M"FUS9W-T<B`B2&]R9&4B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,R.0IM
M<V=I9"`B2&]R9&4@=')A;G-L871I;VX@9V5N97)A=&]R(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#(P"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E
M<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(%,G:&%N
M('1R;V)A="!D861E<R!834P@)7,@;F\@=N!L:61E<R!E;B!E;"!M:7-S871G
M92`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,C<W"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S
M('1O(&]B:F5C="`E<R(*;7-G<W1R("(B"B)(;W)D92]+;VQA8CH@3F\@:&D@
M:&$@8V%P(&UI<W-A=&=E('%U92!E<R!C;W)R97-P;VYG=6D@86UB(&PG;V)J
M96-T92`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#$S"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E
M<R!F;W5N9"!I;B!M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!.
M;R!S)VAA('1R;V)A="!C87`@;V)J96-T92!D96P@=&EP=7,@)7,@96X@96P@
M;6ES<V%T9V4@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$R,#@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R
M96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@)7,@7"(E
M<UPB(&AA(&5S=&%T(&5X=')E="!C;W)R96-T86UE;G0B"@HC.B!L:6(O2&]R
M9&4O2V]L86(N<&AP.C$Q-30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<WEN8VAR;VYI<V5D("5S(%PB
M)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@)7,@7"(E<UPB(&AA(&5S=&%T
M(&5X=')E="!C;W)R96-T86UE;G0B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I
M;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z($5L(&UO=&]R(&0G:6YT96=R86-I\R!N96-E<W-I
M=&$@;"=E>'1E;G-I\R!02%`@)V1O;7AM;"<B"@HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.C0X,0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*
M;7-G<W1R(")(;W)D92]+;VQA8CH@3F\@<R=H82!P;V=U="!C<F5A<B!U;B!N
M;W4@87)B<F4@6$U,('!E<B!A(&PG;V)J96-T92`E<R(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z,3(P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@
M(DAO<F1E+TMO;&%B.B!.;R!S)VAA('!O9W5T(&5X=')E=7)E("5S(%PB)7-<
M(CH@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0U,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)
M344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B(@HB2&]R
M9&4O2V]L86(Z($YO(',G:&$@<&]G=70@<F5C=7!E<F%R(&PG:61E;G1I9FEC
M861O<B!-24U%('!E<B!A(&QA('!A<G0@9&5L("(*(G1I<'5S("5S(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,34Q"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB
M.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@3F\@<R=H82!P;V=U="!S:6YC
M<F]N:71Z87(@)7-<(B5S7"(Z("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HQ,C@R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R(")(;W)D92]+
M;VQA8CH@3F\@<R=H82!P;V=U="!S:6YC<F]N:71Z87(@;&5S('%U;W1E<SH@
M)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS
M9W-T<B`B2&]R9&4O2V]L86(Z($5S<&%I(&1I<W!O;FEB;&4@9&5S8V]N96=U
M="!<(B5S7"(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B4F5G
M;&$@:&]R:71Z;VYT86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS
M9W-T<B`B1F%R8VEM96YT(&AO<FET>F]N=&%L(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R:7IO;G1A
M;#HB"FUS9W-T<B`B2&]R:71Z;VYT86PZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")(;W<@
M9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*2(*;7-G<W1R(")#
M;VT@:&5U(&%R<FEB870@9FEN<R!A<77M/R`H1F5U+6YO<RUH;R!S86)E<B$I
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK
M92!T;R!M97)G93\B"FUS9W-T<B`B475A;G1E<R!C;VQU;6YE<R!V;VQE=2!R
M969O;F1R93\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR.`IM
M<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_(@IM
M<V=S='(@(E%U86YT<R!C86UP<R`H8V]L=6UN97,I(&AI(&AA/R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*
M;7-G:60@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_
M(@IM<V=S='(@(E%U86YT97,@9FEL97,@=F]L974@<F5F;VYD<F4_(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C@*;7-G:60@(DAU;6ED:71Y(@IM<V=S
M='(@(DAU;6ET870B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C0V"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@(DAU;6ET870Z(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED(")(=6UO<FES=',B"FUS
M9W-T<B`B2'5M;W)I<W1E<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$Q,0IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R(")(
M;VYG<FEA(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$W,B!L:6(O
M2&]R9&4O075T:"]C>7)S<6PN<&AP.C(S-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("+)
M<R!I;7!O<W-I8FQE(&-R96%R(&QA(&+Z<W1I82!)34%0.B`E<R(*"B,Z(&QI
M8B](;W)D92]!=71H+V-Y<G5S+G!H<#HR,30@;&EB+TAO<F1E+T%U=&@O8WER
M<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X
M(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`BR7,@:6UP;W-S:6)L92!S
M=7!R:6UI<B!L82!B^G-T:6$@24U!4#H@)7,B"@HC.B!L:6(O2&]R9&4O075T
M:"]C>7)U<RYP:'`Z,3<Y(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,C0R
M"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A
M=&EO;B!F86EL960Z("5S(@IM<V=S='(@(LES(&EM<&]S<VEB;&4@8W)E87(@
M=6X@97-P86D@9&ES<&]N:6)L92!P97(@82!L82!B^G-T:6$@24U!4#H@)7,B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,R,`IM<V=I9"`B25`@061D<F5S
M<R(*;7-G<W1R(")!9')EYV$@25`B"@HC.B!L:6(O2&]R9&4O075T:"]I<&)A
M<VEC+G!H<#HW-PIM<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R("),)V%D<F7G82!)4"!N;R!E<W3@(&1I<W!O;FEB;&4N(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0($%D9')E
M<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@(DPG
M861R9>=A($E0(&YO(&5S('1R;V)A(&5N(&5L(&)L;V,@0TE$4B!P97)MZ',N
M(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G
M:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B5FEO;&%C:?,@
M9&5L(&)L;W%U96EG($E0+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@
M0F5F;W)E(@IM<V=S='(@(DEN<V5R:74@=6YA(&9I;&$@9&%M=6YT(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$P.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(P"FUS
M9VED("))8V5L86YD(@IM<V=S='(@(DES;.!N9&EA(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,V-@IM<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R(").
M;VWI<R!I8V]N97,B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@(DEC;VYE
M<R!D92`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C<*;7-G:60@
M(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R("))8V]N97,@86UB('1E>'0B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@P"FUS9VED("))9&5N=&ET>2=S
M(&YA;64Z(@IM<V=S='(@(DYO;2!D)VED96YT:71A=#HB"@HC.B!L:6(O2&]R
M9&4O34E-12]#;VYT96YT<RYP:'`Z-3@X"B,L('!H<"UF;W)M870*;7-G:60@
M(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N
M(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B4VD@;F\@97,@=FES=6%L
M:71Z82!C;W)R96-T86UE;G0L(&]B<FEU("5S(&5N('5N82!N;W9A(&9I;F5S
M=')A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#4*;7-G:60@(B(*
M(DEF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X
M<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@
M='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T<B`B(@HB4VD@;F\@
M=FES=6%L:71Z974@8V%P(&EC;VYA(&UI=&IA;N=A;G0@;"=);G1E<FYE="!%
M>'!L;W)E<BP@Z7,@<&]S<VEB;&4@<75E("(*(FC@9VEU(&0G86-T:79A<B!A
M<75E<W0@<75A9')E('!E<B!D97-A8W1I=F%R(&QA('1R86YS<&%RZ&YC:6$@
M9&4@4$Y'+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ-3@*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N
M;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B
M92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"B)3
M:2!V96EE=2!A<75E<W0@;6ES<V%T9V4@96X@;&QO8R!D92!L82!I;6%T9V4L
M(&5L('9O<W1R92!N879E9V%D;W(@;F\@<&]T("(*(FUO<W1R87(@;&$@:6UA
M=&=E('%U92!V;VQE=2!P96YJ87(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(X"FUS9VED("));6%G
M92!0<F5V:65W.B(*;7-G<W1R(")6:7-U86QI='IA8VGS('!RZ'9I82!D92!L
M82!I;6%T9V4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@(E52
M3"!D92!L82!I;6%T9V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM86=E(%523#HB
M"FUS9W-T<B`B55),(&1E(&QA(&EM871G93HB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@
M(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R("));6%T9V4@9&4@;&$@9V%L
M97)I82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*
M;7-G<W1R("));6%T9V4@9&4@;&$@9V%L97)I83HB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3<V-0IM<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(D/@
M<G)E9V$@9&4@;&$@:6UA=&=E(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R("));6%T9V5S(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHU-PHC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP
M;&%T97,O9&%T82]D871E;6%P+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`B26UP;W)T86-I\RP@<&%S("5D
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(D-A;7`@
M:6UP;W)T870Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW
M,PIM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R(")#86UP<R!I;7!O
M<G1A=',Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,P"FUS9VED("));E]S97)T(%)O=R!!9G1E<B(*;7-G
M<W1R("));G-E<FEU('5N82!F:6QA(&$@<V]T82(*"B,Z(&QI8B](;W)D92]#
M;VUP<F5S<R]Z:7`N<&AP.C$S-0IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C
M;V1E(&=I=F5N+B(*;7-G<W1R(")%;"!C;V1I(&1E(&PG86-C:?,@<75E(',G
M:&$@9F%C:6QI=&%T(.ES(&EN8V]R<F5C=&4N(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S,0IM<V=I9"`B26YC;W)R96-T('5S97)N
M86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`B3F]M(&0G=7-U87)I(&DO
M;R!C;VYT<F%S96YY97,@:6YC;W)R96-T97,N(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M
M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@
M>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L
M<"XB"FUS9W-T<B`B(@HB4R=H82!F86-I;&ET870@=6X@;F]M(&0G=7-U87)I
M(&\@=6YA(&%D<F7G82!A;'1E<FYA=&EV82!I;F-O<G)E8W1E<RX@5&]R;F5U
M+2(*(FAO(&$@:6YT96YT87(@;R!P;W-E=2UV;W,@96X@8V]N=&%C=&4@86UB
M(&PG861M:6YI<W1R861O<B!P97(@82!MZ7,@86IU9&$N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC
M<F5A<V4@26YD96YT(@IM<V=S='(@(D%U9VUE;G1A<B!E;"!S86=N870B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,38*
M;7-G:60@(DEN9&EA(@IM<V=S='(@(LUN9&EA(@H*(SH@861M:6XO<&5R;7,O
M961I="YP:'`Z,30Q('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS
M9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@(E5S=6%R:7,@:6YD:79I
M9'5A;',B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,3(*;7-G:60@(DEN9&]N97-I82(*;7-G<W1R("));F1O;NAS:6$B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I
M9"`B26YF;R(*;7-G<W1R("));F9O<FUA8VGS(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(T-`IM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B
M26YF;W)M86-I\R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HU.#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B26YI=&EA;&EZ:6YG(&UO9'5L92`E<RXN+B`B"FUS
M9W-T<B`B26YI8VEA;&ET>F%N="!M\F1U;"`E<RXN+B`B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G
M:60@(DEN<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S='(@(DEN<V5R96EX('5N
M82!C;VQU;6YA(&$@<V]T82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B26YS97)T($EM
M86=E(@IM<V=S='(@(DEN<V5R96EX('5N82!I;6%T9V4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED("));G-E
M<G0@5&%B;&4B"FUS9W-T<B`B26YS97)E:7@@=6YA('1A=6QA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B
M26YS97)T(%=E8B!,:6YK(@IM<V=S='(@(DEN<V5R96EX(&5N;&QAYR!W96(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S,*;7-G:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R
M("));G-E<F5I>"!L82!C;VQU;6YA(&1A;75N="(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B
M26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS
M9W-T<B`B26YS97)E:7@@=6YA(&YO=F$@8V]L=6UN82!A('-O=&$@9&4@;"=A
M8W1U86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F
M;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("));G-E<F5I>"!U;F$@;F]V
M82!C;VQU;6YA(&$@<V]B<F4@9&4@;"=A8W1U86PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@
M(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S
M='(@(DEN<V5R96EX('5N82!N;W9A(&9I;&$@82!S;W1A(&1E(&PG86-T=6%L
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8P"FUS9VED("));G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@
M8W5R<F5N="!O;F4B"FUS9W-T<B`B26YS97)E:7@@=6YA(&YO=F$@9FEL82!A
M('-O8G)E(&1E(&PG86-T=6%L("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@
M<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B26YS
M97)E:7@@=6X@<&%RX&=R868@82!S;W1A(&1E;"!N;V1E(&%C='5A;"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV.`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R
M<F5N="!N;V1E(@IM<V=S='(@(DEN<V5R96EX('5N('!A<N!G<F%F(&$@<V]B
M<F4@9&5L(&YO9&4@86-T=6%L(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B
M26YS97)E:7@@;"=A;'1R82!P;&%N=&EL;&$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C(Y"FUS9VED("));G-E<G0@86X@96UA:6P@861D<F5S<R!T
M;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS
M9W-T<B`B(@HB26YS97)E:7@@=6YA(&%D<F7G82!D92!C;W)R974@<&5R(')E
M8G)E(&QA(&YO=F$@8V]N=')A<V5N>6%);G-E<FEU('5N82`B"B)A9')EYV$@
M96QE8W1R\FYI8V$@82!L82!Q=6%L('!O9&5U(')E8G)E(&QA(&YO=F$@8V]N
M=')A<V5N>6$Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU.`IM<V=I9"`B26YS97)T(&-E;&P@869T97(B"FUS
M9W-T<B`B26YS97)E:7@@=6YA(&-E;+=L82!A('-O=&$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Y"FUS9VED
M("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`B26YS97)E:7@@=6YA(&-E
M;+=L82!A('-O8G)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E
M<B(*;7-G<W1R("));G-E<FEU('5N82!C;VQU;6YA(&$@<V]T82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*
M;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(DEN<V5R:74@
M=6YA(&-O;'5M;F$@82!S;V)R92(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R
M9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S='(@
M(DEN<V5R:74@;6ES<V%T9V5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED("));G-E<G0@<&%R
M86=R87!H(&%F=&5R(@IM<V=S='(@(DEN<V5R:74@=6X@<&%RX&=R868@82!S
M;W1A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C0S"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*
M;7-G<W1R("));G-E<FEU('5N('!A<N!G<F%F(&$@<V]B<F4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Y"FUS
M9VED("));G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(DEN<V5R:74@=6YA(&9I
M;&$@82!S;W1A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS
M9W-T<B`B26YS97)I=2!U;F$@9FEL82!A('-O8G)E(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(R,`IM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A
M;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R("));G-E
M<FEU(&QA(')E<W!O<W1A(&$@;&$@<')E9W5N=&$@9&4@<V5G=7)E=&%T.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*
M;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B26YS97)I<B]-
M;V1I9FEC87(@:6UA=&=E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK(@IM
M<V=S='(@(DEN<V5R:7(O36]D:69I8V%R(&5N;&QAYR(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*;7-G:60@(DEN<W5F9FEC:65N
M="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM
M<V=S='(@(DYO(&1I<W!O<V5U(&1E('!R;W4@8W+H9&ET('!E<B!E;G9I87(M
M;&\@82!L82!L;&ES=&$@9&4@9&ES=')I8G5C:?,N(@H*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`IM<V=I9"`B26YS=69F:6-I96YT
M(&-R961I="XB"FUS9W-T<B`B0W+H9&ET(&EN<W5F:6-I96YT+B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,#<U"FUS9VED("));G1E9V5R(@IM<V=S='(@
M(DYO;6)R92!E;G1E<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3,S"FUS
M9VED("));G1E9V5R(&QI<W0B"FUS9W-T<B`B3&QI<W1A(&1E(&YO;6)R97,@
M96YT97)S(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.38*;7-G:60@(DEN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN(@IM
M<V=S='(@(E5$2"!N;R!VX&QI9&$N("A#87#G86QE<F$@9&4@9&%D97,@9"=U
M<W5A<FDI+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@
M(DEN=F%L:60@87!P;&EC871I;VXN(@IM<V=S='(@(D%P;&EC86-I\R!N;R!V
MX&QI9&$N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,3$*;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(DPG:61E;G1I
M9FEC861O<B!D96P@;&]T(&YO(.ES(';@;&ED(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(P.#<@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q-3@@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(R,S(*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R.3<*;7-G
M:60@(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@(DQE<R!D861E
M<R!Q=64@<R=H86X@=')A;>AS(&YO('/S;B!VX&QI9&5S+B(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED("));G9A;&ED
M(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(DPG861R9>=A(&1E(&1E
M<W1I;F%C:?,@;F\@Z7,@=N!L:61A+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S
M<R]D8G@N<&AP.C@Q(&QI8B](;W)D92]#;VUP<F5S<R]D8G@N<&AP.C$P,`HC
M.B!L:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HR,C`*;7-G:60@(DEN=F%L
M:60@9FEL92!F;W)M870B"FUS9W-T<B`B16P@9F]R;6%T(&1E(&PG87)X:74@
M;F\@Z7,@=N!L:60N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$V.0IM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS9W-T<B`B3&$@
M8VQA=2!D92!L82!L;&ECZ&YC:6$@;F\@Z7,@=N!L:61A+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C,*;7-G:60@(DEN=F%L:60@;&]C
M871I;VX@<')O=FED960N(@IM<V=S='(@(DQA('5B:6-A8VGS('%U92!H974@
M<')O<&]R8VEO;F%T(&YO(.ES(';@;&ED82XB"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B26YV86QI9"!M<V=?='EP
M92XB"FUS9W-T<B`B16P@=&EP=7,M;7-G(&YO(.ES(';@;&ED+B(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R"FUS9VED("));G9A
M;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*;7-G<W1R(")-86YC82!E;"!A<&E?
M:60@;R!E;"!Q=64@<R=H82!F86-I;&ET870@;F\@Z7,@=N!L:60N(@H*(SH@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@(DEN
M=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+B(*;7-G<W1R(")-86YQ=65N
M('!A<N!M971R97,@;R!E;',@<75E(',G:&%N(&9A8VEL:71A="!N;R!S\VX@
M=N!L:61S+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HT,PIM<V=I
M9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B3"=A=71O
M<FET>F%C:?,@<&%T97)N82!N;R#I<R!VX&QI9&$N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$V-0IM<V=I9"`B26YV86QI9"!P87)T;F5R
M(&ED+B(*;7-G<W1R(")%;"!C;V1I(&0G:61E;G1I9FEC86-I\R!D92!S;V-I
M(&YO(.ES(';@;&ED+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-C<*;7-G:60@(DEN=F%L:60@<')O9'5C="!C;V1E+B(*;7-G<W1R(")%
M;"!C;V1I(&1E;"!P<F]D=6-T92!N;R#I<R!VX&QI9"XB"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B26YV86QI9"!P
M<F]T;V-O;"XB"FUS9W-T<B`B16P@<')O=&]C;VP@;F\@Z7,@=N!L:60N(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.CDR"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@)R5S)R(*
M;7-G<W1R(")%;"!D97-T:6YA=&%R:2!N;R#I<R!VX&QI9#H@)R5S)R(*"B,Z
M(&QI8B](;W)D92]+;VQA8BYP:'`Z,3`T,R!L:6(O2&]R9&4O2V]L86(N<&AP
M.C$R,C`*;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S='(@(DPG
M;V)J96-T92!C;VUP87)T:70@;F\@Z7,@=N!L:60B"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,`IM<V=I9"`B26YV86QI9"!S;W5R
M8V4@861D<F5S<RXB"FUS9W-T<B`B3"=A9')EYV$@9"=O<FEG96X@;F\@Z7,@
M=N!L:61A+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$P"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T<B`B3&5S
M(&1A9&5S(%5N:6-O9&4@;F\@<_-N(';@;&ED97,N(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,R,PIM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@
M(DEN=F5N=&%R:2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$Q.0IM<V=I9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O
M9B(*;7-G<W1R("))<F%N+"!297#Z8FQI8V$@27-LX&UI8V$@9"<B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3@*;7-G
M:60@(DER87$B"FUS9W-T<B`B27)A<2(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,PIM<V=I9"`B27)E;&%N9"(*;7-G
M<W1R("))<FQA;F1A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-0IM
M<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B26QL82!D92!-86XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B
M27-O;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B5&5M<&5S=&5S(&'O;&QA9&5S
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3$T"FUS9VED("))<W)A96PB"FUS9W-T<B`B27-R865L(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HV,C4*;7-G:60@(DES<W5E<B(*;7-G<W1R
M(")%;6ES<V]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS9W-T<B`B0W5R<VEV82(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,34*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R,0IM
M<V=I9"`B271A;'DB"FUS9W-T<B`B273@;&EA(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q
M-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(S"FUS9VED(")*86UA:6-A
M(@IM<V=S='(@(DIA;6%I8V$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,S<T(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,3$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R(")'96YE<B(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@S(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,3<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-0IM<V=I
M9"`B2F%P86XB"FUS9W-T<B`B2F%P\R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@W"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@
M(DIA<&]NZ',@*$E33RTR,#`R+4I0*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R(")*97)S97DB"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C0*;7-G
M:60@(DIO<F1A;B(*;7-G<W1R(")*;W)DX&YI82(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HS.#`@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@(DIU;&EO
M;"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS-SD@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*
M=6YE(@IM<V=S='(@(DIU;GDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S
M='(@(DIU<W1I9FEC87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B
M"FUS9W-T<B`B2G5S=&EF:6-A<B!A;"!C96YT<F4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B
M2G5S=&EF>2!&=6QL(@IM<V=S='(@(DIU<W1I9FEC87(@82!T;W1S(&1O<R!M
M87)G97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(DIU
M<W1I9FEC87(@82!L)V5S<75E<G)A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I9GD@
M4FEG:'0B"FUS9W-T<B`B2G5S=&EF:6-A<B!A(&QA(&1R971A(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$Q.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,V"FUS9VED
M(")+87IA:VAS=&%N(@IM<V=S='(@(DMA>F%K:'-T86XB"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0V"FUS9VED(")+965P(&]R
M:6=I;F%L/R(*;7-G<W1R(")6;VQE=2!C;VYS97)V87(@;"=O<FEG:6YA;#\B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,C8*;7-G:60@(DME;GEA(@IM<V=S='(@(DME;GEA(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE
M8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B16P@<V5R=FED;W(@2V5R
M8F5R;W,@:&$@<F5B=71J870@;"=A=71E;G1I8V%C:?,N(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED(")+97)N96P@3F5W8FEE<R(*;7-G
M<W1R(")+97)N96P@3F5W8FEE<R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C0P,`IM<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S='(@(D-R96%C:?,@
M9&4@8VQA=7,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,#,*;7-G
M:60@(DME>2!&:6YG97)P<FEN="(*;7-G<W1R(")%;7!R96UT82!D:6=I=&%L
M(&1E(&QA(&-L874B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,#$*
M;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`B3&]N9VET=60@9&4@;&$@8VQA
M=2(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0P,`IM<V=I9"`B2V5Y
M(%1Y<&4B"FUS9W-T<B`B5&EP=7,@9&4@8VQA=2(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-3DX"FUS9VED(")+97D@57-A9V4B"FUS9W-T<B`B
MVG,@9&4@;&$@8VQA=2(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<R
M.0IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y
M<V5R=F5R+B(*;7-G<W1R(")*82!E>&ES=&5I>"!U;F$@8VQA=2!E;B!E;"!S
M97)V:61O<B!D92!C;&%U<R!P^F)L:7%U97,N(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S='(@(DYO:7,B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,CD*;7-G
M:60@(DMI<FEB871I(@IM<V=S='(@(DMI<FEB871I(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$R,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,R"FUS9VED(")+;W)E
M82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9B(*;7-G<W1R(")#
M;W)E82P@4F5P^F)L:6-A($1E;6]C<N!T:6-A(%!O<'5L87(@9&4B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S,*;7-G
M:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R(")#;W)E82P@4F5P^F)L
M:6-A(&1E(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(DMO
M<F5A;B`H155#+4M2*2(*;7-G<W1R(")#;W)EX"`H155#+4M2*2(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@V(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,C0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-`IM<V=I
M9"`B2W5W86ET(@IM<V=S='(@(DMU=V%I="(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C4*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-PIM<V=I9"`B2WER9WEZ<W1A
M;B(*;7-G<W1R(")+:7)G=6EZ:7-T86XB"@HC.B!T96UP;&%T97,O<&]R=&%L
M+VUE;G4N:6YC.C@*;7-G:60@(DQA7WEO=70B"FUS9W-T<B`B1F]R;6%T(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW-R!P;R]T<F%N<VQA=&EO
M;BYP:'`Z-C4W"FUS9VED("),86YG=6%G92(*;7-G<W1R("))9&EO;6$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S<*
M;7-G:60@(DQA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S
M='(@(E)E</IB;&EC82!$96UO8W+@=&EC82!0;W!U;&%R(&1E($QA;W,B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED("),87-T($AA;&8B"FUS
M9W-T<B`B1&%R<F5R82!M96ET870B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M.#@@;&EB+T)L;V-K+VUO;VXN<&AP.CDP"FUS9VED("),87-T(%%U87)T97(B
M"FUS9W-T<B`B1&%R<F5R('%U87)T(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ-#D*;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`B1&%R<F5R82!A
M8W1U86QI='IA8VGS.B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HV-C8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`B1&%R
M<F5R82!C;VYN97AI\SH@)7,B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z-C8X
M"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B
M"FUS9W-T<B`B1&%R<F5R82!C;VYN97AI\SH@)7,@9&4@)7,B"@HC.B!L:6(O
M2&]R9&4O075T:"YP:'`Z-C8S"FUS9VED("),87-T(&QO9VEN.B!.979E<B(*
M;7-G<W1R(")$87)R97)A(&-O;FYE>&GS.B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C<*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-@IM<V=I9"`B3&%T=FEA(@IM
M<V=S='(@(DQE=/)N:6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*
M;7-G:60@(DQA=R(*;7-G<W1R("),;&5I(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"FUS9VED("),87EO=70B
M"FUS9W-T<B`B1&ES<V5N>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B
M;W)D97(B"FUS9W-T<B`B1&5I>&%R+6AO(&5N(&)L86YC('!E<B!E;&EM:6YA
M<B!E;"!C;VYT;W)N(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3,X"FUS9VED("),96)A;F]N(@IM<V=S='(@(DSM8F%N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C8Y"FUS9VED("),969T(@IM<V=S='(@(D5S<75E<G)A(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C,Q,3<*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S
M='(@(D-A<.=A;&5R82!E<W%U97)R82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HS,3$S"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R(")686QO<G,@9&4@
M;"=E<W%U97)R82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$T,PIM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("),97-O=&AO
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$S,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,30R"FUS9VED("),:6)E<FEA(@IM<V=S='(@(DQI8NAR:6$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#<*;7-G:60@
M(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B3.UB:6$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#`*;7-G
M:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B3&EE8VAT96YS=&5I;B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED
M("),:6=H="!$<FEZ>FQE(@IM<V=S='(@(E!L=6=I;2!F96)L92(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"FUS9VED("),
M:6=H="!286EN(@IM<V=S='(@(E!L=6IA(&9E8FQE(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DQI9VAT(%)A
M:6X@16%R;'DB"FUS9W-T<B`B4&QU:F$@9F5B;&4@82!P<FEM97)A(&AO<F$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM
M<V=I9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(E!L=6IA(&9E8FQE(&-A
M<"!A;"!T87)D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C8*;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(E)U
M:7AA="!F96)L92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(W"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G
M<W1R(")2=6EX870@9F5B;&4@86UB('1R;VYS(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%-N;W<B
M"FUS9W-T<B`B3F5V861A(&9E8FQE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R
M(@IM<V=S='(@(EC@9F5C(&1E(&YE=2!F96)L92(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B3&EM97)I
M8VLB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@Q.`IM<V=I9"`B3&EN:R(*
M;7-G<W1R(")%;FQL8><B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@(DQI;FL@<&]I;G1S('1O
M.B(*;7-G<W1R(")%;FQL86/G87(@96QS('!U;G1S(&%M8CHB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3@W-0IM<V=I9"`B3&EN:R!T:&4@96UA:6P@861D
M<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(*;7-G
M<W1R(")%;FQL8>=A<B!L)V%D<F7G82!E;&5C='+R;FEC82!A(&QA('#@9VEN
M82!D92!R961A8W1A="!Q=6%N(&5S(&UO<W1R:2(*"B,Z(&QI8B](;W)D92]4
M97AT+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,PIM<V=I9"`B3&EN:W,B"FUS
M9W-T<B`B16YL;&'G;W,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*
M;7-G:60@(DQI;G5X($-O;VMI92(*;7-G<W1R(")'86QE=&$@3&EN=7@B"@HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G:60@(DQI
M<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R("),;&ES=&%R
M("T@3"=U<W5A<FD@<&]T('9E=7)E(&QA(&-A<G!E=&$B"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3,P"FUS9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R
M("),;&ES=&%R(&QE<R!B87-E<R!D92!D861E<R(*"B,Z('-E<G9I8V5S+VAE
M;'`O:6YD97@N<&AP.C4P"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S
M='(@(DQL:7-T82!D96QS('1E;65S(&0G86IU9&$B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3(Y"FUS9VED("),:7-T(%1A8FQE<R(*;7-G<W1R("),;&ES
M=&%R(&QE<R!T875L97,B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H
M<#HU.30*;7-G:60@(DQI<W0M07)C:&EV92(*;7-G<W1R("),:7-T+4%R8VAI
M=F4B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.#D*;7-G:60@
M(DQI<W0M2&5L<"(*;7-G<W1R("),:7-T+4AE;'`B"@HC.B!L:6(O2&]R9&4O
M34E-12](96%D97)S+G!H<#HU.38*;7-G:60@(DQI<W0M260B"FUS9W-T<B`B
M3&ES="U)9"(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y,@IM
M<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R("),:7-T+4]W;F5R(@H*(SH@;&EB
M+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS9VED("),:7-T+5!O<W0B
M"FUS9W-T<B`B3&ES="U0;W-T(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R
M<RYP:'`Z-3DQ"FUS9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("),:7-T
M+5-U8G-C<FEB92(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y
M,`IM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R("),:7-T+55N<W5B
M<V-R:6)E(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHT
M"FUS9VED("),:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("),
M82!L;&ES=&$@9"=U<W5A<FES(&5S=.`@:6YH86)I;&ET861A+B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT-PIM<V=I9"`B3&ET97)A='5R92(*;7-G
M<W1R(")":6)L:6]G<F%F:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-#0*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R
M("),:71UX&YI82(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,S,X"B,L(&9U
M>GIY"FUS9VED("),;V%D:6YG(&QI8G)A<FEE<RXN+B(*;7-G<W1R(")3)V5S
M=.`@8V%R<F5G86YT+BXN(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEM
M86=E<RYP:'`Z.#,*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`B4R=E<W3@
M(&-A<G)E9V%N="XN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,#,*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R(")(;W)A(&QO8V%L
M.B`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@(DQO8V%L
M92!A;F0@5&EM92(*;7-G<W1R("))9&EO;6$@:2!H;W)A(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S$@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C8T"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HR,B!L:6(O0FQO
M8VLO;65T87(N<&AP.C8S"FUS9VED("),;V-A=&EO;B(*;7-G<W1R(")58FEC
M86-I\R(*"B,Z(&QO9VEN+G!H<#HQ-34@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$V-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@T"B,Z('1E
M;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C,@=&5M<&QA=&5S+VQO9VEN+VUO
M8FEL92YI;F,Z,34*;7-G:60@(DQO9R!I;B(*;7-G<W1R("));FEC:6$@;&$@
M<V5S<VGS(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U.`IM
M<V=I9"`B3&]G(&]U="(*;7-G<W1R(")3=7)T(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P-PIM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B5&%S
M<75E<R!D)VEN:6-I(&1E('-E<W-I\R(*"B,Z(&QI8B](;W)D92]!=71H+G!H
M<#HY,3$*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA
M;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S
M='(@(B(*(DAI(&AA(&AA9W5T('5N(&5R<F]R(&1E(&-O;FYE>&GS('!E<G%U
MZ"!H974@:6YT<F]D=>]T(&EN8V]R<F5C=&%M96YT(&5L(&YO;2`B"B)D)W5S
M=6%R:2!O(&QA(&-O;G1R87-E;GEA+B(*"B,Z(&QI8B](;W)D92]!=71H+G!H
M<#HY,#<*;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`B2&$@9F%L;&%T
M(&QA(&-O;FYE>&GS+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S<P"FUS
M9VED("),;VYG('1E>'0B"FUS9W-T<B`B5&5X="!L;&%R9R(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT.`IM<V=I9"`B3&]V92(*;7-G<W1R(")!;6]R
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*
M;7-G:60@(DQO=R(*;7-G<W1R(")"86EX(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W
M97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R(")!;&9A8F5T(&=R96,@96X@;6EN
M^G-C=6QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*
M;7-G<W1R(")!;&9A8F5T(&QL873M(&5N(&UI;OIS8W5L82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3<*
M;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B6&EF<F5S(')O
M;6%N97,@96X@;6EN^G-C=6QA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,30U"FUS9VED("),=7AE;6)O=7)G(@IM<V=S
M='(@(DQU>&5M8G5R9R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HS-S,@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q,`HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T
M<B`B34TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4Q"FUS9VED
M(")-3U1$(@IM<V=S='(@(DU/5$0B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.148@071T86-H;65N="!C;VYT
M86EN960@;F\@9&%T82XB"FUS9W-T<B`B3"=A<GAI=2!A9&IU;G0@35,M5$Y%
M1B!N;R!C;VYT96YI82!D861E<RXB"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R
M(")-4T<B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-3<*;7-G:60@(DUA8V%O(@IM<V=S='(@(DUA8V%U(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$S-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34S"FUS9VED
M(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B
M"FUS9W-T<B`B36%C963R;FEA+"!!;G1I9V$@4F5P^F)L:6-A($EU9V]S;&%V
M82!D92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$U,0IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R(")-861A9V%S8V%R
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"FUS9VED(")-86=I8R(*
M;7-G<W1R(")-X&=I8R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW
M.0IM<V=I9"`B36%I;"(*;7-G<W1R(")#;W)R974@96QE8W1R\FYI8R(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-C@*;7-G:60@(DUA:6P@061M
M:6XB"FUS9W-T<B`B061M:6YI<W1R861O<B!D92!C;W)R974B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*
M;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B4R=E<W3@(&-R96%N="!U
M;B!E;FQL8><N+BXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,U-PIM<V=I
M9"`B36%K92!S=7)E('1H870@>6]U(&AA=F4@4$5!4B!I;G-T86QL960@86YD
M(&EN('EO=7(@:6YC;'5D92!P871H+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z-C<X('!O+W1R86YS;&%T:6]N+G!H<#HQ,#<T"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")-86MI;F<@9&ER96-T;W)Y("5S(@IM
M<V=S='(@(DYO(.ES('5N(&1I<F5C=&]R:2(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDT(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S@*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-0IM<V=I9"`B36%L87=I(@IM
M<V=S='(@(DUA;&%W:2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$V-PIM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B36%L
MX&ES:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-C0*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(DUA;&1I=F5S(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$T,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34T
M"FUS9VED(")-86QI(@IM<V=S='(@(DUA;&DB"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C(*;7-G:60@(DUA;'1A(@IM
M<V=S='(@(DUA;'1A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ"FUS
M9VED("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V
M92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T
M960@=VET:"!T:&]S92!C871E9V]R:65S+B(*;7-G<W1R("(B"B)'97-T:6]N
M974@;&$@;&QI<W1A(&1E(&-A=&5G;W)I97,@86UB(&QE<R!Q=6%L<R!H974@
M9"=E=&EQ=65T87(@96QS("(*(F5L96UE;G1S+"!I(&5L<R!C;VQO<G,@87-S
M;V-I871S(&%M8B!A<75E<W1E<R!C871E9V]R:65S+B(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#,Y"FUS9VED(")-87`R-"!M
M87`B"FUS9W-T<B`B36%P82!-87`R-"(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HY-S<*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$P-30*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R
M(")-87!A($UA<%%U97-T(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,W-B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#$S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@(DUA<N<B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q"FUS9VED
M(")-87)G:6XB"FUS9W-T<B`B36%R9V4B"@HC.B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@(DUA<FL@=VET:"!3965N+U5N<V5E
M;B!F;&%G<R(*;7-G<W1R(")-87)C87(@86UB(&EN9&EC861O<G,@=FES:6)L
M97,O:6YV:7-I8FQE<R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM
M<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B36%R8V%R(&%M8B!A;'1R97,@
M:6YD:6-A9&]R<R`H<"X@92XL(&EM<&]R=&%N="]R97-P;W-T*2(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDQ(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-#,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,@IM<V=I
M9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R("));&QE<R!-87)S:&%L;"(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDS(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-#0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U
M.0IM<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R(")-87)T:6YI8V$B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$Q,0IM<V=I9"`B36%T8VAI;F<@
M9FEE;&1S(@IM<V=S='(@(D-A;7!S('%U92!C;VEN8VED96EX:6XB"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C`*;7-G
M:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B36%U<FETX&YI82(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDT(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-#8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,PIM<V=I9"`B
M36%U<FET:75S(@IM<V=S='(@(DUA=7)I8VDB"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B36%X(&%L;&]W960@8W)E
M9&ET+B(*;7-G<W1R(")#<NAD:70@;>!X:6T@<&5R;>AS+B(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED(")-87@@;65S
M<V%G92!P87)T<R!E>&-E961E9"XB"FUS9W-T<B`B4R=H82!S=7!E<F%T(&5L
M(&YO;6)R92!MX'AI;2!D92!P87)T<R!D92!M:7-S871G92XB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,P-`IM<V=I9"`B36%X('1E;7`@;&%S="`R-"!H
M;W5R<SH@(@IM<V=S='(@(E1E;7!E<F%T=7)A(&W@>&EM82!D92!L97,@9&%R
M<F5R97,@,C0@:&]R97,Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDV
M"FUS9VED(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R(")496UP
M97)A='5R82!MX'AI;6$@9&4@;&5S(&1A<G)E<F5S(#8@:&]R97,Z("(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HX.3@@;&EB+TAO<F1E+T9O<FTN<&AP.C$R
M,3<@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,SD*;7-G:60@(DUA>&EM=6T@;&5N
M9W1H(@IM<V=S='(@(DQO;F=I='5D(&W@>&EM82(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HS-S@@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0Q-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS9W-T<B`B36%I9R(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M-3,*;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B36%Y;W1T92(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B
M365D:6-I;F$B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC
M.C$Y"FUS9VED(")-96UB97)S(@IM<V=S='(@(DUE;6)R97,B"@HC.B!L86YG
M=&5S="YP:'`Z-PIM<V=I9"`B365M;W)Y(&5X:&%U<W1E9"(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8X"FUS9VED(")-96YU(&UO
M9&4Z(@IM<V=S='(@(E1I<'5S(&1E(&UE;OHZ(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R
M9V4@8V5L;',B"FUS9W-T<B`B4F5F;VYA<B!L97,@8V5LMVQE<R(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HU,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B365R
M9VEN9R!A;&P@)7,N<&\@9FEL97,@=&\@=&AE(&-O;7!E;F1I=6TN+BX@(@IM
M<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT,S@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B365R9VEN9R!L;V-A;&4@)7,N+BX@(@IM<V=S='(@(B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW.#@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B365R9VEN9R!T:&4@4$\@9FEL92!F;W(@)7,@=&\@=&AE(&-O;7!E;F1I
M=6TN+BX@(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT,C4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B365R9VEN9R!T<F%N<VQA=&EO;B!F;W(@
M;6]D=6QE("5S+BXN(@IM<V=S='(@(B(*"B,Z(&QA;F=T97-T+G!H<#HQ-R!L
M:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*
M;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`B36ES<V%T9V4B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S<V%G92!697)I
M9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T
M92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*(D5L(&UI
M<W-A=&=E(&AA(&5S=&%T('9E<FEF:6-A="!C;W)R96-T86UE;G0L('!E<O(@
M;F\@<R=H82!P;V=U="!V97)I9FEC87(@96P@(@HB8V5R=&EF:6-A="!E;"!S
M:6=N86YT+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`Y"FUS9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(DUI<W-A=&=E
M(&-A9'5C870N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,C8@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3D*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V."!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`Q"FUS9VED(")-97-S86=E('1Y<&4B
M"FUS9W-T<B`B5&EP=7,@9&4@;6ES<V%T9V4B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E871H97(B"FUS9W-T<B`B5&5M<',@
M9&4@345405(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W"FUS9VED(")-
M971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")%;"!B;&]C($U%
M5$%2(&YO(&5S=.`@9&ES<&]N:6)L92XB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$Q,`IM<V=I9"`B(@HB365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@
M1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O
M<BXB"FUS9W-T<B`B(@HB16P@8FQO8R!-151!4B!N;R!E<W3@(&1I<W!O;FEB
M;&4N($5L<R!D971A;&QS(&AA;B!E<W1A="!R96=I<W1R871S('!E<B!A("(*
M(FPG861M:6YI<W1R861O<BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,34W"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T960N(@IM
M<V=S='(@(DQA(&)A<V4@9&4@9&%D97,@345405(@;F\@97-TX"!C;VYN96-T
M861A+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q(&QI
M8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8W"FUS9VED(")-971H;V0B
M"FUS9W-T<B`B3>AT;V1E(@H*(SH@;&EB+TAO<F1E+U)00R]S;V%P+G!H<#HQ
M,3<@;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP.C@Q"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")-971H;V0@)R5S)R!I<R!N;W0@9&5F:6YE9"(*;7-G
M<W1R(")%;"!MZ'1O9&4@)R5S)R!N;R!E<W3@(&1E9FEN:70N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<S(&QI8B]";&]C:R]M971A<BYP
M:'`Z-S,*;7-G:60@(DUE=')I8R(*;7-G<W1R(")-Z'1R:6,B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C8*;7-G:60@
M(DUE>&EC;R(*;7-G<W1R(")-Z'AI8R(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@U"FUS9VED(")-:6-R;VYE<VEA+"!&
M961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(DUI8W)O;NAS:6$L($5S=&%T
M<R!&961E<F%T<R!D92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW-@IM<V=I9"`B36ED9&QE(@IM<V=S='(@(D-E
M;G1R92(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM
M<V=I9"`B36EM92!4>7!E(@IM<V=S='(@(E1I<'5S($U)344B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,P.`IM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H
M;W5R<SH@(@IM<V=S='(@(E1E;7!E<F%T=7)A(&WM;FEM82!D92!L97,@9&%R
M<F5R97,@,C0@:&]R97,Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`P
M"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R(")496UP
M97)A='5R82!M[6YI;6$@9&4@;&5S(&1A<G)E<F5S(#8@:&]R97,Z("(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,3<*;7-G:60@
M(DUI<G)O<B(*;7-G<W1R(")2Z'!L:6-A(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(DUI<V-E
M;+=L86YI(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,SD@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W,0IM<V=I9"`B
M36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+B(*;7-G<W1R(")&
M86QT82!L82!S;VRW;&EC:71U9"!(5%10('!E<B!A;"!P87%U970@4$5!4BXB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$T"FUS9VED("(B"B)-:7-S
M:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO
M=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB"FUS
M9W-T<B`B(@HB1F%L=&$@;&$@8V]N9FEG=7)A8VGS+B!,)VAE=2!D92!G96YE
M<F%R(&%R82!S:2!V;VQE=2!U=&EL:71Z87(@87%U97-T82`B"B)A<&QI8V%C
M:?,N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*
M;7-G:60@(DUI<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T<B`B1F%L=&$@;"=I
M9&5N=&EF:6-A9&]R(&1E;"!M:7-S871G92XB"@HC.B!L:6(O3F5T+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.C4W"FUS9VED(")-:7-S:6YG(')E<75I
M<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R(")&86QT82!E;"!C;W)R
M974@96QE8W1R\FYI8R!D96P@<&%Q=65T(%!%05(@;F5C97-S87)I+B(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")-
M:7-S:6YG('-E<W-I;VX@240N(@IM<V=S='(@(D9A;'1A(&PG:61E;G1I9FEC
M861O<B!D92!S97-S:?,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`B1&PN(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C<R"FUS9VED(")-;V)I;&4@36%I
M;"(*;7-G<W1R(")#;W)R974@;?)B:6PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV-`IM<V=I9"`B36]D97)A=&4B"FUS9W-T
M<B`B36]D97)A="(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<P(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@X"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8V"FUS9VED(")-;V1I9FEE9"!$
M871E(@IM<V=S='(@(D1A=&$@;6]D:69I8V%D82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I9"`B
M36]D:69Y(%523"(*;7-G<W1R(")-;V1I9FEC87(@;&$@55),(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C8U-PHC+"!F=7IZ>0IM<V=I9"`B36]D=6QE(@IM
M<V=S='(@(DWR9'5L(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV
M-S,*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B3?)D=6PB"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3`*;7-G:60@(DUO
M;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUO;&3@=FEA+"!297#Z8FQI
M8V$@9&4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-#D*;7-G:60@(DUO;F%C;R(*;7-G<W1R(")-\FYA8V\B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-38*;7-G
M:60@(DUO;F=O;&EA(@IM<V=S='(@(DUO;F?R;&EA(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(U.3(*;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@
M(DUE<R!I(&%N>2(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z-3<*
M;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`B365N<W5A;&UE;G0B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C$*;7-G:60@
M(DUO;G1S97)R870B"FUS9W-T<B`B36]N='-E<G)A="(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O
M;B!0:&%S97,B"FUS9W-T<B`B1F%S97,@;'5N87)S(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$U-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30X"FUS9VED(")-;W)O
M8V-O(@IM<V=S='(@(DUA<G)O8R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,P"FUS9VED(")-;W-T;'D@0VQE87(B"FUS9W-T
M<B`B36%J;W)I=.!R:6%M96YT(&1E<V-O8F5R="(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED(")-;W-T;'D@0VQO
M=61Y(@IM<V=S='(@(DUA:F]R:73@<FEA;65N="!E;FYU=F]L870B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B
M36]S=&QY(%-U;FYY(@IM<V=S='(@(DUA:F]R:73@<FEA;65N="!A<W-O;&5L
M;&%T(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-#(X"FUS9VED
M(")-;W9E($1O=VXB"FUS9W-T<B`B36]U<F4@8V%P(&%V86QL(@H*(SH@;&EB
M+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-#,R"FUS9VED(")-;W9E($QE9G0B
M"FUS9W-T<B`B36]U<F4@82!L)V5S<75E<G)A(@H*(SH@;&EB+TAO<F1E+T)L
M;V-K+TQA>6]U="YP:'`Z-#,V"FUS9VED(")-;W9E(%)I9VAT(@IM<V=S='(@
M(DUO=7)E(&$@;&$@9')E=&$B"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T
M+G!H<#HT,C0*;7-G:60@(DUO=F4@57`B"FUS9W-T<B`B36]U<F4@8V%P(&%M
M=6YT(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Y
M-@IM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(DUO=7)E(&-A<"!A=F%L;"(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT.34@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Y-@IM<V=I9"`B36]V
M92!U<"(*;7-G<W1R(")-;W5R92!C87`@86UU;G0B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C@*;7-G:60@(DUO>F%M
M8FEQ=64B"FUS9W-T<B`B36_G86UB:6,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C$X-`IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM
M<V=S='(@(DQI<W1E<R!D97-P;&5G86)L97,@96YL;&'G861E<R!E;B!D:79E
M<G-O<R!N:79E;&QS(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-#(*;7-G
M:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R(")396QE8V-I\R!M^FQT
M:7!L92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,CD@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,S-@IM<V=I9"`B37D@06-C;W5N="(*;7-G
M<W1R(")%;"!M974@8V]M<'1E(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X
M+G!H<#HU,`IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(D5L(&UE=2!P;W)T
M86PB"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z,3(T"FUS9VED(")-
M>2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(D1I<W-E;GD@9&5L(&UE=2!P;W)T
M86PB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-34*;7-G:60@(DUY86YM87(B"FUS9W-T<B`B37EA;FUA<B(*"B,Z('1E
M;7!L871E<R]M86EN=&5N86YC92]A9W)E96UE;G1?8F]T=&]M+FEN8SHW"FUS
M9VED(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B3D\L($Y/(&AI(&5S
M=&EC(&0G86-O<F0B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&YE9BYP
M:'`Z,S@@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#`P"FUS9VED(").86UE(@IM<V=S
M='(@(DYO;2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$V.0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R(").86WM8FEA(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$U.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<X
M"FUS9VED(").875R=2(*;7-G<W1R(").875R=2(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDW(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-3D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-PIM<V=I9"`B3F5P86PB
M"FUS9W-T<B`B3F5P86PB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-S4*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@
M(E!A[W-O<R!"86EX;W,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B
M"FUS9W-T<B`B06YT:6QL97,@3F5E<FQA;F1E<V5S(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C87!E($)A<V4@55),
M(@IM<V=S='(@(E523"!B87-E(&1E($YE='-C87!E(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C87!E($-!(%)E=F]C
M871I;VX@55),(@IM<V=S='(@(E523"!D92!R979O8V%C:?,@9&4@0T$@9&4@
M3F5T<V-A<&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-0IM
M<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R(")54DP@9&4@
M<&]L[71I<75E<R!D92!#02!D92!.971S8V%P92(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P92!296YE=V%L(%52
M3"(*;7-G<W1R(")54DP@9&4@<F5N;W9A8VGS(&1E($YE='-C87!E(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G:60@(DYE='-C87!E
M(%)E=F]C871I;VX@55),(@IM<V=S='(@(E523"!D92!R979O8V%C:?,@9&4@
M3F5T<V-A<&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-@IM
M<V=I9"`B3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(DYO;2!D
M96P@<V5R=FED;W(@4U-,(&1E($YE='-C87!E(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E
M(&-O;6UE;G0B"FUS9W-T<B`B0V]M96YT87)I(&1E;"!C97)T:69I8V%T(&1E
M($YE='-C87!E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#`*
M;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E('1Y<&4B"FUS9W-T<B`B5&EP
M=7,@9&4@8V5R=&EF:6-A="!D92!.971S8V%P92(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR,S<*;7-G:60@(DYE='=O<FLB"FUS9W-T<B`B6&%R
M>&$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,30@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,R-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<V
M"FUS9VED(").979E<B(*;7-G<W1R(")-86DB"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38R
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S`*;7-G:60@(DYE=R!#86QE
M9&]N:6$B"FUS9W-T<B`B3F]V82!#86QE9/)N:6$B"@HC.B!L:6(O2&]R9&4O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-PIM<V=I9"`B3F5W($-A=&5G
M;W)Y(@IM<V=S='(@(DYO=F$@8V%T96=O<FEA(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,3<Y"FUS9VED(").97<@36]O;B(*;7-G<W1R("),;'5N82!N;W9A
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-0IM<V=I
M9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B3F]U(&YO;2!D
M)W5S=6%R:2`H;W!C:6]N86PI(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3@P"FUS9VED(").97<@6F5A;&%N9"(*;7-G
M<W1R(").;W9A(%IE;&%N9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@=VEN9&]W("A?8FQA;FLI
M(@IM<V=S='(@(DYO=F$@9FEN97-T<F$@*%]E;B!B;&%N8RDB"@HC.B!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3(*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U.0IM<V=I9"`B3F5W<R(*
M;7-G<W1R(")-:7-S871G97,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,CDS"FUS9VED(").97=S9W)O=7!S(@IM<V=S='(@(D=R=7!S(&1E(&1I
M<V-U<W-I\R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C,R('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3,W"B,Z('1E;7!L871E<R]D871A
M+W1S=FEN9F\N:6YC.C(Q('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0V
M"FUS9VED(").97AT(@IM<V=S='(@(E-E9_QE;G0B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,C<*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B-"!F
M87-E<R!S96?\96YT<R(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S8X
M(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S<R"FUS9VED(").97AT(&]P=&EO
M;G,B"FUS9W-T<B`B3W!C:6]N<R!S96?\96YT<R(*"B,Z(&QI8B](;W)D92]5
M22]086=E<BYP:'`Z,3`S"FUS9VED(").97AT/B(*;7-G<W1R(")396?\96YT
M/B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$W-`IM<V=I9"`B3FEC87)A9W5A(@IM<V=S='(@(DYI8V%R86=U82(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-C4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,0IM
M<V=I9"`B3FEG97(B"FUS9W-T<B`B3NUG97(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S,*;7-G:60@(DYI9V5R:6$B
M"FUS9W-T<B`B3FEGZ')I82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS,3@*;7-G:60@(DYI9VAT(@IM<V=S='(@(DYI="(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDW(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-C<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W.0IM<V=I9"`B
M3FEU92(*;7-G<W1R(").:75E(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C@X-0IM<V=I9"`B3F\B"FUS9W-T<B`B3F\B"@HC.B!T
M96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.C$V"FUS9VED(").;R!A
M=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC
M97,@9F]R+B(*;7-G<W1R(").;R!E<R!D:7-P;W-E;B!D92!D861E<R!D92!C
M;VYF:6=U<F%C:?,@<&5R(&UO<W1R87(@;&5S(&1I9F5RZ&YC:65S+B(*"B,Z
M(&QI8B]61E,O25-/5W)I=&5R+G!H<#HQ,#4*;7-G:60@(DYO(&%V86EL86)L
M92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@(DYO
M(&5S(&1I<W!O<V$@9"=U;F$@97-T<F%TZ&=I82!P97(@8W)E87(@:6UA=&=E
M<R!)4T\N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,3(*;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R(").;R!H:2!H
M82!P;&%N=&EL;&$@9&4@;&]T<RXB"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y
M;W5T+G!H<#HW.2!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HR,S`*(SH@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,C4R"FUS9VED(").;R!B;&]C
M:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R(").
M;R!E>&ES=&5I>"!C87`@8FQO8R!E;B!L82!P;W-I8VGS('-O;+=L:6-I=&%D
M82(*"B,Z(&QI8B](;W)D92]!=71H+VUC86PN<&AP.C4P"FUS9VED(").;R!C
M86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R(").;R!S)VAA('!R;W!O<F-I;VYA="!U;B!N;VT@9"=A9V5N
M9&$@<&5R(&$@;"=A=71E;G1I8V%C:?,@34-!3"XB"@HC.B!A9&UI;B]S971U
M<"]D:69F+G!H<#HU-`IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R(")396YS
M92!C86YV:7,N(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-#`*(RP@
M9G5Z>GD*;7-G:60@(DYO(&-H:6QD('!E<FUI<W-I;VYS(&%R92!T;R!B92!A
M9&1E9"!B96QO=R!T:&ES(&QE=F5L+B(*;7-G<W1R(").;R!E<R!P;V1E;B!A
M9F5G:7(@9&5S8V5N9&5N=',@82!A<75E<W0@<&5R;>US(@H*(SH@861M:6XO
M<&5R;7,O861D8VAI;&0N<&AP.C8Q"FUS9VED(").;R!C:&EL9')E;B!C86X@
M8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R(").;R!E<R!P
M;V1E;B!A9F5G:7(@9&5S8V5N9&5N=',@82!A<75E<W0@<&5R;>US(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C$S-S<*(RP@9G5Z>GD*;7-G:60@(DYO(&-O
M;6UA;F0@<W!E8VEF:65D+B(*;7-G<W1R(").;R!S)VAA(&5S<&5C:69I8V%T
M('5N(&YO;2XB"@HC.B!L:6(O2&]R9&4N<&AP.C$V-R!L:6(O2&]R9&4N<&AP
M.C0W-R!L:6(O2&]R9&4O571I;"YP:'`Z-S<V"B,L('!H<"UF;W)M870*;7-G
M:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B`E<RXB"FUS9W-T<B`B3F\@<R=H82!E<W!E8VEF:6-A="!L97,@9&%D97,@
M9&4@8V]N9FEG=7)A8VGS('!E<B!A("5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H
M<#HW-#$*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R(").;R!S)VAA(&5S<&5C:69I
M8V%T(&QE<R!D861E<R!D92!C;VYF:6=U<F%C:?,@<&5R(&$@1E10('!E<B!6
M1E,N(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C4Y,0IM<V=I9"`B3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N(@IM
M<V=S='(@(DYO(',G:&$@97-P96-I9FEC870@;&5S(&1A9&5S(&1E(&-O;F9I
M9W5R86-I\R!P97(@82!344P@<&5R(%9&4RXB"@HC.B!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HW,#0*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(B(*(DYO
M(',G:&$@97-P96-I9FEC870@;&5S(&1A9&5S(&1E(&-O;F9I9W5R86-I\R!D
M92!344P@<&5R(&%L(&9I='AE<B!344PN(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@(DYO(&-R961I="!L969T+B(*
M;7-G<W1R(").;R!Q=65D82!C<NAD:70N(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P
M<&QI960N(@IM<V=S='(@(DYO(',G:&$@9F%C:6QI=&%T('5N82!D97-T:6YA
M8VGS+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,C<Q"B,L('!H<"UF;W)M
M870*;7-G:60@(DYO(&5N=')Y('=I=&@@=&AE(&ED("<E<R<@97AI<W1S(&EN
M('1H92!O<FEG:6YA;"!H96QP(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]"<F]W<V5R+G!H<#HX-S$*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B
M"FUS9W-T<B`B3F\@<R=H82!C87)R96=A="!C87`@87)X:74N(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C<Q"FUS9VED(").;R!I8V]N<R!F;W5N9"XB
M"FUS9W-T<B`B3F\@<R=H82!T<F]B870@8V%P(&EC;VYA+B(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HT,3,@<&\O=')A;G-L871I;VXN<&AP.C4R,@HC+"!F
M=7IZ>0IM<V=I9"`B3F\@;&]C86QE('-P96-I9FEE9"XB"FUS9W-T<B`B3F\@
M<R=H82!E<W!E8VEF:6-A="!U;B!N;VTN(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$R,"!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,C$*;7-G:60@(DYO(&QO8V%T:6]N(&ES
M('-E="XB"FUS9W-T<B`B3F\@<R=H82!D969I;FET('5N82!U8FEC86-I\RXB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Q"FUS9VED(").
M;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B3F\@<R=H82!F86-I;&ET
M870@=6YA('5B:6-A8VGS+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S(*;7-G:60@(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S
M='(@(DYO(',G:&$@:6YT<F]D=>]T('5N(&UI<W-A=&=E+B(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@(DYO(&YA;64@
M<W!E8VEF:65D+B(*;7-G<W1R(").;R!S)VAA(&5S<&5C:69I8V%T('5N(&YO
M;2XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS
M9VED(").;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R(").;R!S)VAA(&5S
M<&5C:69I8V%T('5N82!X:69R82XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z.30*;7-G:60@(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R(").
M;R!E<R!P97)M971E;B!L97,@9&ET97,@;V9E;G-I=F5S+B(*"B,Z(&QI8B](
M;W)D92]!=71H+VAT='`N<&AP.CDQ"FUS9VED(").;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3F\@<R=H
M82!I;G1R;V1U[W0@=6YA(&-O;G1R87-E;GEA('!E<B!A(&PG875T96YT:6-A
M8VGS($A45%`N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:6UA<"YP:'`Z,3`X"FUS
M9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`B3F\@<R=H82!I;G1R;V1U[W0@=6YA(&-O;G1R87-E
M;GEA('!E<B!A(&PG875T96YT:6-A8VGS($E-05`N(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O:W)B-2YP:'`Z-S(*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3F\@<R=H
M82!I;G1R;V1U[W0@=6YA(&-O;G1R87-E;GEA('!E<B!A(&PG875T96YT:6-A
M8VGS($ME<F)E<F]S+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.CDT
M"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3$1!
M4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3F\@<R=H82!I;G1R;V1U[W0@
M=6YA(&-O;G1R87-E;GEA('!E<B!A(&PG875T96YT:6-A8VGS($E-05`N(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'`Z-S<@;&EB+TAO<F1E+T%U=&@O
M<&%M+G!H<#HW-0HC.B!L:6(O2&]R9&4O075T:"]L;V=I;BYP:'`Z.#0*;7-G
M:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`B3F\@<R=H82!I;G1R;V1U[W0@=6YA(&-O;G1R87-E
M;GEA('!E<B!A(&PG875T96YT:6-A8VGS(&0G:6YI8VDN(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O<&%S<W=D+G!H<#HQ,S4*;7-G:60@(DYO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYO
M(',G:&$@:6YT<F]D=>]T('5N82!C;VYT<F%S96YY82!P97(@82!L)V%U=&5N
M=&EC86-I\R!005-35T0N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<VUB+G!H<#HX
M-`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B3F\@<R=H82!I;G1R;V1U[W0@=6YA(&-O;G1R
M87-E;GEA('!E<B!A(&PG875T96YT:6-A8VGS(%--0BXB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C$R.#8*;7-G:60@(B(*(DYO('!A=&@@=&\@
M=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA
M<GD@:7,@;F5C97-S87)Y('1O("(*(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N
M(@IM<V=S='(@(B(*(DYO(',G:&$@:6YD:6-A="!L82!V:6$@9"=A8V/I<R!A
M;"!B:6YA<FD@3W!E;E-33"X@0V%L(&5L(&)I;F%R:2!/<&5N4U-,('!E<B`B
M"B)T<F5B86QL87(@86UB(&QE<R!D861E<R!02T-3(#$R+B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I
M;F<@<VEG;G5P<RXB"FUS9W-T<B`B3F\@:&D@:&$@86QT97,@<&5N9&5N=',N
M(@H*(SH@;&EB+U9&4RYP:'`Z-S8U"FUS9VED(").;R!Q=6]T82!S970N(@IM
M<V=S='(@(DYO(',G:&$@9&5F:6YI="!L)V5S<&%I(&1I<W!O;FEB;&4N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT,PIM<V=I9"`B3F\@<G5L97,B"FUS9W-T<B`B4V5N<V4@<F5G;&5S(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT-`IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B4V5N<V4@8V%R97,B"@HC
M.B!L:6(O5D93+W-M8BYP:'`Z-3@U"FUS9VED(").;R!S=6-H(&9I;&4B"FUS
M9W-T<B`B3F\@97AI<W1E:7@@87%U97-T(&%R>&EU(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$S,`IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I
M<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+B(*;7-G<W1R(").;R!E<R!D
M:7-P;W-A(&1E(&-A<"!D:7)E8W1O<FD@=&5M<&]R86P@<&5R(&$@;&$@;65M
M\G)I82!C874N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S,`IM<V=I9"`B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N
M(@IM<V=S='(@(DYO(&AE=2!E;G9I870@96P@;F]M(&0G=7-U87)I(&YI+V\@
M;&$@8V]N=')A<V5N>6$B"@HC.B!L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z
M,30P"FUS9VED(").;R!V86QI9"!834P@9&%T82!R971U<FYE9"(*;7-G<W1R
M(").;R!S)VAA;B!R971O<FYA="!D861E<R!834P@=N!L:61E<R(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX.3,@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDP,PHC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3$T(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HY,S$*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R(")3
M96YS92!V86QO<G,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$Y"FUS
M9VED(").;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I
M;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB3F\@
M<R=H82!T<F]B870@;&$@=F5R<VGS(&5N(&QA(&-O;F9I9W5R86-I\R!O<FEG
M:6YA;"X@4F5G96YE<F5U(&QA("(*(F-O;F9I9W5R86-I\RXB"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3(W"FUS9VED(").;R!V97)S:6]N(&9O=6YD
M(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("(B"B).;R!S)VAA('1R;V)A="!L82!V97)S:?,@96X@
M;&$@8V]N9FEG=7)A8VGS+B!296=E;F5R974@;&$@8V]N9FEG=7)A8VGS+B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q-B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0U"B,Z('1E;7!L871E
M<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3(*;7-G:60@(DYO;F4B"FUS
M9W-T<B`B0V%P(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R
M(")#87`@*/IS(&EM<&SM8VET*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@Y"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*;7-G<W1R(").\G)D
M:6,@*$E33RTX.#4Y+3$P*2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDV(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$W,@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS
M9W-T<B`B26QL82!D92!.;W)F;VQK(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M
M:7-P:&5R92(*;7-G<W1R(")(96UI<V9E<FD@;F]R9"(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDS(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-CD*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U.`IM<V=I9"`B3F]R
M=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S='(@(DEL;&5S($UA<FEA;FYE
M<R!D96P@3F]R9"(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$W-@IM<V=I9"`B3F]R=V%Y(@IM<V=S='(@(DYO<G5E9V$B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T
M($%F=&5R(@IM<V=S='(@(DYO(&1E<W!RZ7,B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B3F]T($)E9F]R92(*;7-G<W1R(").
M;R!A8F%N<R(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S,Q"FUS9VED(").;W0@
M82!D:7)E8W1O<GDB"FUS9W-T<B`B3F\@Z7,@=6X@9&ER96-T;W)I(@H*(SH@
M;&EB+U9&4R])4T]7<FET97(N<&AP.C8S(&QI8B]61E,O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!L:6(O5D93+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2YP:'`Z-3D*(SH@;&EB+U9&4R])4T]7<FET97(O
M4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX,PHC.B!L:6(O5D93+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDT"FUS9VED(").;W0@:6UP;&5M
M96YT960N(@IM<V=S='(@(DYO(&EM<&QE;65N=&%T+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*;7-G:60@(DYO="!S
M970B"FUS9W-T<B`B3F\@9&5F:6YI="(*"B,Z(&QI8B]61E,N<&AP.C$Y,R!L
M:6(O5D93+G!H<#HR,#@@;&EB+U9&4RYP:'`Z,C,S(&QI8B]61E,N<&AP.C(U
M,0HC.B!L:6(O5D93+G!H<#HR-C@@;&EB+U9&4RYP:'`Z,C@T(&QI8B]61E,N
M<&AP.C,P,"!L:6(O5D93+G!H<#HS,34*(SH@;&EB+U9&4RYP:'`Z,S,R(&QI
M8B]61E,N<&AP.C,V-2!L:6(O5D93+G!H<#HT,C4@;&EB+U9&4RYP:'`Z-3`T
M"B,Z(&QI8B]61E,N<&AP.C4W,R!L:6(O5D93+G!H<#HU.3`@;&EB+U9&4RYP
M:'`Z-C8X"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,30S(&QI
M8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,34X"B,Z(&QI8B](;W)D92]3
M97-S:6]N2&%N9&QE<BYP:'`Z,3<S(&QI8B](;W)D92]397-S:6]N2&%N9&QE
M<BYP:'`Z,3@W"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,C,T
M"FUS9VED(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R(").;R!P97)MZ',N(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$V,@IM<V=I9"`B3F]T97,B"FUS9W-T<B`B
M3F]T97,B"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G
M:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R(").;R!H
M:2!H82!R97,@82!V:7-U86QI='IA<BP@<F5T<F]C961I=2XB"@HC.B!T96UP
M;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC.C$P"B,L(&9U>GIY
M"FUS9VED(").;W1I8V4B"FUS9W-T<B`B3F]T97,B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@T(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B
M3F]V96UB<F4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`T-@IM<V=I9"`B
M3G5M8F5R(@IM<V=S='(@(DYO;6)R92(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ-#,P"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R(").
M;VUB<F4@9&4@8V%RX&-T97)S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S
M-S0@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C@@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$T-3`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@(DYO;6)R
M92!D92!C;VQU;6YE<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S<R(&QI
M8B](;W)D92]&;W)M+G!H<#HQ-#(V(&QI8B](;W)D92]&;W)M+G!H<#HQ-#0X
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R
M"FUS9VED(").=6UB97(@;V8@<F]W<R(*;7-G<W1R(").;VUB<F4@9&4@9FEL
M97,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS
M9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I
M<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"B).;R!S)VAA;B!E<W!E8VEF
M:6-A="!N;VUB<F5S('%U92!H86=I;B!D92!S97(@86-T=6%L:71Z871S(&5N
M(&QA(&QL:7-T82!D92`B"B)D:7-T<FEB=6-I\RXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0@<&\O=')A;G-L871I;VXN
M<&AP.C$T.`HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,T.`IM<V=I9"`B3TLB
M"FUS9W-T<B`B1"=A8V]R9"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HX,3$*;7-G:60@(D]B:F5C="(*;7-G<W1R(")/8FIE8W1E
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*;7-G:60@(D]B
M:F5C="!#<F5A=&]R(@IM<V=S='(@(D-R96%D;W(@9&4@;"=O8FIE8W1E(@H*
M(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3,W(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z,C$U"B,L(&9U>GIY"FUS9VED(")/8FIE8W0@8W)E871O<B!P97)M
M:7-S:6]N<R(*;7-G<W1R(")097)M:7-O<R!D96P@8W)E861O<B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,3`T"FUS9VED(")/8W1A;"(*;7-G<W1R(")/
M8W1A;"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS
M.#,@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0R,`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS9VED
M(")/8W1O8F5R(@IM<V=S='(@(D]C='5B<F4B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@(D9I
M;'1R92!D)VEN9G)A8V-I;VYS(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(Y.0IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(D]F:6-I;F$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#$*;7-G
M:60@(D]M86XB"FUS9W-T<B`B3VUA;B(*"B,Z(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HW,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P
M<&]R="!S:&%R960@9F]L9&5R<RXB"FUS9W-T<B`B3F]MZ7,@96QS('-E<G9I
M9&]R<R!)34%0('!E<FUE=&5N(&PG^G,@9&4@8V%R<&5T97,@8V]M<&%R=&ED
M97,N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDU"FUS9VED(")/;FQY
M(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R(").;VWI<R!M:7-S871G97,@
M;V9E;G-I=7,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@U,2!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3DW,0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@861D<F5S
M<R!A;&QO=V5D+B(*;7-G<W1R(").;VWI<R#I<R!P97)M97-A('5N82#Z;FEC
M82!A9')EYV$@96QE8W1R\FYI8V$N(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D
M:70N<&AP.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@
M861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B
M"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"B).;VWI<R!E
M;"!P<F]P:65T87)I(&\@;"=A9&UI;FES=')A9&]R(&1E('-I<W1E;65S('!O
M="!C86YV:6%R(&QA('!R;W!I971A="!O("(*(F5L<R!P97)M:7-O<R!D96P@
M<')O<&EE=&%R:2!P97(@82!R96-U<G-O<R!C;VUP87)T:71S(@H*(SH@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z,S4*;7-G:60@(D]P96X@:6X@82!N97<@=VEN
M9&]W(@IM<V=S='(@(D]B<FEU(&5N('5N82!N;W9A(&9I;F5S=')A(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@
M97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-
M24U%('!A<G0N(@IM<V=S='(@(B(*(D5R<F]R($]P96Y34TPZ(&YO(',G:&%N
M('!O9W5T(&5X=')E=7)E(&QE<R!D861E<R!D92!L82!P87)T(%,O34E-12!S
M:6=N861A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@
M;F5W('=I;F1O=R(*;7-G<W1R(")/8G)E(&%Q=65S="!E;FQL8><@96X@=6YA
M(&YO=F$@9FEN97-T<F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*
M;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B4VES=&5M82!O<&5R
M871I=2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3$*;7-G
M:60@(D]P=&EO;G,B"FUS9W-T<B`B3W!C:6]N<R(*"B,Z('-E<G9I8V5S+W!R
M969S+G!H<#HR.2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R(")/<&-I;VYS
M(&0G)7,B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$R"B,L(&9U>GIY"FUS
M9VED(")/<'1I;VYS.B(*;7-G<W1R(")/<&-I;VYS(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E
M9"!,:7-T(@IM<V=S='(@(DQL:7-T82!O<F1E;F%D82(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-38W"FUS9VED(")/<F=A;FES871I;VXB"FUS
M9W-T<B`B3W)G86YI='IA8VGS(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`B
M56YI=&%T(&]R9V%N:71Z871I=F$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,3,P"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(E,G97-TX"!O
M<F=A;FET>F%N="(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3,U"FUS9VED
M(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R(")0;&%N
M=&EL;&$@9"=A<&QI8V%C:?,@;W)I9VEN86PB"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP
M;&%T97,@:6X@)7,Z(@IM<V=S='(@(E!L86YT:6QL97,@;W)I9VEN86QS(&5N
M("5S.B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.2!S97)V:6-E
M<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S='(@(D%L=')E
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,#8*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,R!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3(Q"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,CD*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(D%L=')A
M(&EN9F]R;6%C:?,B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,Q
M"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R(")097)M:7-O<R!D
M96P@<')O<&EE=&%R:2(*"B,Z(&QI8B](;W)D92]!=71H+W!A;2YP:'`Z-SD*
M;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R("),)V%U=&5N=&EC86-I\R!004T@;F\@97-TX"!D:7-P;VYI8FQE
M+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$R-3,*;7-G:60@(E!'
M4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G<W1R(")3:6=N871U<F$@9&EG:71A
M;"!01U`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,CDY"FUS9VED
M(")01U`@16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B1&%D97,@>&EF<F%D97,@
M86UB(%!'4"(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$S-3$*;7-G
M:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(D-L874@4$=0('#Z8FQI8V$B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,S,S"FUS9VED(")01U`@
M4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(D1A9&5S('-I9VYA9&5S
M+WAI9G)A9&5S(&%M8B!01U`B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-C@*
M;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(D-O9&D@4$A0(@H*(SH@861M:6XO
M<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B26YT
MZ')P<F5T(&0G;W)D<F5S(%!(4"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED(")032!,:6=H="!286EN(@IM<V=S
M='(@(E!L=6=I;7,@9&4@=&%R9&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R
M(")0;'5G97,@9&4@=&%R9&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R(").979A
M9&5S(&1E('1A<F1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S<*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")8
MX&9E8W,@9&4@;F5U(&$@;&$@=&%R9&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS.`IM<V=I9"`B4$T@4W5N(@IM<V=S='(@
M(E-O;"!D92!T87)D82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,Y"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R(")496UP
M97-T97,@9&4@=&%R9&$B"@HC.B!L:6(O87!I+G!H<#HQ,C@*;7-G:60@(E!?
M2%`@4VAE;&PB"FUS9W-T<B`B26YTZ')P<F5T(&0G;W)D<F5S(%!?2%`B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0V"FUS9VED(")0861D:6YG(@IM<V=S='(@(E-E<&%R86-I\R(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDY(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-S(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-PIM<V=I
M9"`B4&%K:7-T86XB"FUS9W-T<B`B4&%K:7-T86XB"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$W,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DT"FUS9VED(")086QA
M=2(*;7-G<W1R(")086QA=2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.3(*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I
M=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B5&5R<FET;W)I('!A;&5S=.TL(&]C
M=7!A="(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$X,@IM<V=I9"`B4&%N86UA(@IM<V=S='(@(E!A;F%MX"(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDY(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-S8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-0IM<V=I
M9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R(")087!U82!.;W9A($=U:6YE
M82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ.34*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(E!A<F%G=6%I(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@
M(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B4&%R8VEA;&UE;G0@96YN=79O;&%T
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$X,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`Q.`HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C$Y."!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3,V"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z,S8@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,0HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S4S"FUS9VED(")087-S=V]R9"(*;7-G<W1R
M(")#;VYT<F%S96YY82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M,3,R,@IM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(D-O;G1R
M87-E;GEA(&EN8V]R<F5C=&$B"@HC.B!L:6(O2&]R9&4O075T:"]R861I=7,N
M<&AP.C$U,@IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B0V%L(&EN=')O9'5I<B!U;F$@8V]N
M=')A<V5N>6$@<&5R(&$@;"=A=71E;G1I8V%C:?,@4D%$2553+B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR,#4S"FUS9VED(")087-S=V]R9"!W:71H(&-O
M;F9I<FUA=&EO;B(*;7-G<W1R(")#;VYT<F%S96YY82!A;6(@8V]N9FER;6%C
M:?,B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@
M(E!A<W-W;W)D.B(*;7-G<W1R(")#;VYT<F%S96YY83HB"@HC.B!T96UP;&%T
M97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G
M<W1R(")#;VYT<F%S96YY83H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&QI
M8B](;W)D92]&;W)M+G!H<#HR,#,T"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*
M;7-G<W1R("),97,@8V]N=')A<V5N>65S(&AA;B!D92!C;VEN8VED:7(N(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R,"!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G:60@(E!A<W1E(@IM
M<V=S='(@(D5N9V%N>&%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B
M"FUS9W-T<B`B16YG86YX87(@9&5L('!O<G1A+7)E=&%L;',B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q"FUS9VED(")0
M871H(@IM<V=S='(@(D-A;>TB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A
M<'!R;W9E+FEN8SHR('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E
M9"YI;F,Z-`IM<V=I9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R(")!;'1E
M<R!P96YD96YT<SHB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*;7-G
M:60@(E!E;W!L92(*;7-G<W1R(")'96YT(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*;7-G:60@(E!E<F-E;G0B"FUS
M9W-T<B`B4&5R8V5N=&%T9V4B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O
M8V]N9FER;5]B;W1T;VTN:6YC.C8*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N
M8V4@3W!E<F%T:6]N<R(*;7-G<W1R(")296%L:71Z87(@;W!E<F%C:6]N<R!D
M92!M86YT96YI;65N="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.38*
M;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I
M;C\B"FUS9W-T<B`B5F]L974@<F5A;&ET>F%R(&]P97)A8VEO;G,@9&4@;6%N
M=&5N:6UE;G0@96X@:6YI8VEA<B!L82!S97-S:?,_(@H*(SH@861M:6XO<&5R
M;7,O861D8VAI;&0N<&AP.C8Q(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV
M-`HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C<*;7-G:60@(E!E<FUI
M<W-I;VXB"FUS9W-T<B`B4&5R;>US(@H*(SH@861M:6XO<&5R;7,O9&5L971E
M+G!H<#HV.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4&5R;6ES<VEO
M;B`G)7,G(&YO="!D96QE=&5D+B(*;7-G<W1R(").;R!S)VAA(&5L:6UI;F%T
M(&5L('!E<FWM<R`G)7,G+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HU.#@*;7-G
M:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(E!E<FUI<R!D96YE9V%T
M(@H*(SH@861M:6XO<&5R;7,O:6YD97@N<&AP.C(R(&%D;6EN+W!E<FUS+V%D
M9&-H:6QD+G!H<#HY,PHC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HR,C0@861M
M:6XO<&5R;7,O9&5L971E+G!H<#HW-`IM<V=I9"`B4&5R;6ES<VEO;G,@061M
M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R861O<B!D92!P97)M:7-O
M<R(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,30U(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,30X"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,34R
M"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N<R!F;W(B"FUS9W-T<B`B7U!E
M<FUI<V]S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U"FUS9VED(")0
M97)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R(")$861E<R!P97)S;VYA;',B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M.#,*;7-G:60@(E!E<G4B"FUS9W-T<B`B4&5R^B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU-0IM<V=I9"`B4&5T<R(*;7-G<W1R(")!;FEM86QS(&1E
M(&-O;7!A;GEI82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$X-@IM<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B1FEL
M:7!I;F5S(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M.38*;7-G:60@(E!H;VYE(@IM<V=S='(@(E1E;.AF;VXB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#$V"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B
M1F]T;W,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#`@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3DP"FUS9VED(")0:71C86ER;B(*;7-G<W1R(")0:71C86ER;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`X
M"FUS9VED(")0:7AE;',B"FUS9W-T<B`B4.UX96QS(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4V"FUS9VED(")0;&%T:71U9&5S(@IM<V=S='(@(E3R
M<&EC<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L
M;"(*;7-G<W1R(")#;&EC87(@96X@=6YA(&-E;+=L82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.`IM<V=I
M9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI
M<R!E;&5M96YT.B(*;7-G<W1R(")#;VYF:7)M87(@<75E('9O;&5U('-U<')I
M;6ER(&%Q=65S="!E;&5M96YT.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B4&QE87-E(&-O
M;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*
M;7-G<W1R(")#;VYF:7)M87(@<75E('9O;&5U(&1E<V5N;&QAYV%R(&%Q=65S
M="!E;&5M96YT+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-38Y"FUS9VED
M(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+B(*;7-G<W1R("))
M;G1R;V1U[W4@=6X@;65S(&D@=6X@86YY+B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C$R"FUS9VED(")0;&5A<V4@96YT
M97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R("));G1R
M;V1U[W4@=6X@;F]M('!E<B!A(&QA(&YO=F$@8V%T96=O<FEA.B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,S`W"FUS9VED(")0;&5A<V4@96YT97(@82!V
M86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R("));G1R;V1U[W4@=6YA(&%D<F7G
M82!)4"!VX&QI9&$N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(V-3@*;7-G
M:60@(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB
M97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(DEN=')O9'7O=2!U
M;F$@9&%T82!VX&QI9&$L(&-O;7!R;W9E=2!E;',@9&EE<R!Q=64@=.D@96P@
M;65S+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-#0Y"FUS9VED(")0;&5A
M<V4@96YT97(@82!V86QI9"!T:6UE+B(*;7-G<W1R("));G1R;V1U[W4@=6YA
M(&AO<F$@=N!L:61A+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C<*;7-G:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@
M<')O8FQE;2XB"FUS9W-T<B`B4')O<&]R8VEO;F5U('5N(')E<W5M(&1E;"!P
M<F]B;&5M82XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$X('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(*;7-G:60@(E!L96%S92!P<F]V
M:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM<V=S='(@(E!R;W!O
M<F-I;VYE=2!E;"!N;VT@9"=U<W5A<FD@:2!L82!C;VYT<F%S96YY82(*"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]A9W)E96UE;G1?=&]P+FEN8SHQ,@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB4&QE87-E(')E860@=&AE
M(&9O;&QO=VEN9R!T97AT+B`@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R
M;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*(DQL96=I=2!E
M;"!T97AT('-E9_QE;G0N($AE=2!D)V%C8V5P=&%R(&QE<R!C;VYD:6-I;VYS
M('!E<B!P;V1E<B!U=&EL:71Z87(@96P@(@HB<VES=&5M82XB"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,3<*;7-G:60@(E!L96%S92!R97!O<G0@86YY(&)U
M9W,@=&\@:3$X;D!L:7-T<RYH;W)D92YO<F<N(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"FUS9VED(")0
M;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S='(@(E1E
M8VQE9V5U(&5L(&YO;2!D92!L82!N;W9A(&-A=&5G;W)I83HB"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#@*;7-G:60@
M(E!O;&%N9"(*;7-G<W1R(")0;VSR;FEA(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R(")0;VSM=&EC82(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C4*;7-G:60@(E!O;&QS
M(@IM<V=S='(@(D5N<75E<W1E<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ.3,*;7-G:60@(E!O<G1U9V%L(@IM<V=S
M='(@(E!O<G1U9V%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(W"FUS9VED(")0;W-I=&EO;FEN9R!O
M9B!T:&ES(&EM86=E(@IM<V=S='(@(D-O;+=L;V-A8VGS(&0G87%U97-T82!I
M;6%T9V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G
M<W1R(")#;VRW;&]C86-I\R!D)V%Q=65S=&$@=&%U;&$B"@HC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@(E!O<W0@=&\@=&AI
M<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R(")%;G9I
M87(@82!A<75E<W1A(&-A<G!E=&$@*&YO(&AI(&]B;&EG82!)34%0*2(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C8T(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C8Y"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R(&QA
M<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(E!R96-I<&ET86-I\R!D=7)A;G0@
M;&$@9&%R<F5R82`E<R!H;W)A(&\@:&]R97,Z("(*"B,Z(&QI8B](;W)D92]0
M<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@
M3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]L9&%P
M.B!.;R!S)VAA('1R;V)A="!L)V5X=&5N<VGS($Q$05`@<V]LMVQI8VET861A
M+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B
M4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]S97-S:6]N.B!.;R!S)VAA('1R;V)A
M="!L)V5X=&5N<VGS(&1E('-E<W-I\R!S;VRW;&EC:71A9&$N(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,C,*;7-G:60@(E!R97-S=7)E(@IM<V=S='(@
M(E!R97-S:?,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U-PIM<V=I9"`B
M4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B4')E<W-I\R!A;"!N
M:79E;&P@9&5L(&UA<CHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C(W"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@(E!R97-S:?,Z("(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ.#@*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@(E9I<W5A;&ET>F%C:?,@
M<'+H=FEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(T"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I
M;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B5FES=6%L:71Z87(@<'+H=FEA;65N
M="!L82!I;6%T9V4@96X@=6YA(&YO=F$@9FEN97-T<F$B"@HC.B!L:6(O2&]R
M9&4O4')E9G,O54DN<&AP.C,U."!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,V
M,@IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R(")/<&-I;VYS('!R
MZ'9I97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R("));7!R:6UI
M<B!E;"!D;V-U;65N="(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q
M,@IM<V=I9"`B4')I=F%T92!+97DB"FUS9W-T<B`B0VQA=2!P<FEV861A(@H*
M(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$V.0IM<V=I9"`B4')O8FQE;2(*;7-G
M<W1R(")0<F]B;&5M82(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-PIM
M<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R(")$97-C<FEP8VGS
M(&1E;"!P<F]B;&5M82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M,3$*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(E!R;VIE8W1E<R(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR,3$Q(&QI8B](;W)D92]&;W)M+G!H<#HR,3@X
M"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R(")497AT(&EN9&EC861O<B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B4'5B;&EC
M($ME>2(*;7-G<W1R(")#;&%U('#Z8FQI8V$B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET:&TB
M"FUS9W-T<B`B06QG;W)I<VUE(&1E(&-L874@</IB;&EC82(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-C0T"FUS9VED(")0=6)L:6,@2V5Y($EN
M9F\B"FUS9W-T<B`B26YF;W)M86-I\R!D92!C;&%U('#Z8FQI8V$B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HR,S`*;7-G:60@(E!U8FQI8R]0<FEV
M871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S
M='(@(DYO(',G:&$@9V5N97)A="!C;W)R96-T86UE;G0@;&$@<&%R96QL82!D
M92!C;&%U<R!P^F)L:6-A+W!R:79A9&$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,PHC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DQ"FUS9VED(")0=65R=&\@4FEC
M;R(*;7-G<W1R(")0=65R=&\@4FEC;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.38*;7-G:60@(E%A=&%R(@IM<V=S
M='(@(E%A=&%R(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C8R"FUS9VED(")1
M=65R>2(*;7-G<W1R(")#;VYS=6QT82(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-C8S"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@
M2V5Y("@E9"!B:70I(@IM<V=S='(@(D-L874@</IB;&EC82!24T$@*"5D(&)I
M="DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(V-`IM<V=I9"`B4F%D:6\@
M<V5L96-T:6]N(@IM<V=S='(@(D)O=/,@9&4@<V5L96-C:?,B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,`IM<V=I9"`B4F%I
M;B(*;7-G<W1R(")0;'5J82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0Q"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@(E!L
M=6IA(&$@<')I;65R82!H;W)A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R(")0
M;'5J82!C87`@86P@=&%R9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0S"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R(")2
M=6EX870B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT-`IM<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R(")0;'5J82!I(&YE
M=R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U
M"FUS9VED(")286EN('1O(%-N;W<B"FUS9W-T<B`B06EG=6%N974B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U;F4B
M"FUS9W-T<B`B1&ET82!A;&5A=/)R:6$B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O>FEP+G!H<#HW,R!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H
M<#HV.`IM<V=I9"`B4F%T:6\B"FUS9W-T<B`B4F5L86-I\R(*"B,Z(&QI8B](
M;W)D92]097)M<RYP:'`Z,CDS('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,S0*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3$T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3@P"FUS9VED(")296%D(@IM<V=S='(@
M(DQL96=I=2(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX
M-PIM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R("),;&5G:74@96QS(&UI
M<W-A=&=E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z
M,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI
M<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B0V]N9FER
M;65U('%U92!V;VQE=2!S=7!R:6UI<B`E<S\@07%U97-T82!O<&5R86-I\R!N
M;R!E<R!P;W0@9&5S9F5R+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L
M96%R+FEN8SHQ,@HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@<F5M;W9E
M('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T
M(&)E('5N9&]N92XB"FUS9W-T<B`B(@HB0V]N9FER;65U('%U92!V;VQE=2!S
M=7!R:6UI<B!L97,@9&%D97,@9&4@;"=U<W5A<FD@<&5R(&$@;"=U<W5A<FD@
M)7,_("(*(D%Q=65S=&$@;W!E<F%C:?,@;F\@97,@<&]T(&1E<V9E<BXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T"FUS
M9VED(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R(")4;W)N82!A
M(&9E<B!L82!D87)R97)A(&%C8VGS(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,X,0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z
M(@IM<V=S='(@(E)E9G)E<V-A<B!E;',@96QE;65N=',@9&5L(&UE;OH@9&EN
MX&UI8W,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Q"FUS9VED(")2
M969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R(")2969R97-C87(@;&$@=FES
M=6%L:71Z86-I\R!D96P@<&]R=&%L(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C@Y-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q,R!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3(S-0IM<V=I9"`B4F5G97@B"FUS9W-T<B`B17AP<F5S<VGS(')E9W5L
M87(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(T-PIM<V=I9"`B4F5L871I
M;VYS:&EP($)R;W=S97(B"FUS9W-T<B`B3F%V96=A9&]R(&1E(')E;&%C:6]N
M<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(T"FUS9VED(")296UA<FMS
M(@IM<V=S='(@(D-O;65N=&%R:7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$T"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R(")397)V:61O
M<G,@<F5M;W1S(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T
M"FUS9VED(")296UO=&4@55),("AH='1P.B\O=W=W+F5X96UP;&4N97,O:&]R
M9&4I.B(*;7-G<W1R(")54DP@<F5M;W0@*&AT='!S.B\O=W=W+F5X96UP;&4N
M97,O:&]R9&4I.B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N
M:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI
M;F,Z,34@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,0IM<V=I
M9"`B4F5M;W9E(@IM<V=S='(@(E-U<')I;6ER(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]L87EO=70N:6YC.C$Q"FUS9VED(")296UO=F4@0FQO8VLB"FUS9W-T
M<B`B4W5P<FEM:7(@8FQO8R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HU,CD*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B
M4W5P<FEM:7(@8V]L=6UN82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-#`*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM
M<V=S='(@(E-U<')I;6ER(&QA(&9O<FUA=&%C:?,B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C$S-@IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T
M<B`B4W5P<FEM:7(@;&$@<&%R96QL82(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HR,#4*;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V
M97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R(")3=7!R:6UI<B!L
M82!S97'\Z&YC:6$@9&5S861A(&1E;"!D:7)E8W1O<FD@=&5M<&]R86P@9&5L
M('-E<G9I9&]R+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHT,0IM<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R
M(")3=7!R:6UI<B!E;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4F5M;W9E('1H:7,@;F]D
M92!F<F]M('1H92!D;V-U;65N="(*;7-G<W1R(")3=7!R:6UI<B!A<75E<W0@
M;F]D92!D96P@9&]C=6UE;G0B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R
M96UO=F4N:6YC.C$V"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R(")3=7!R
M:6UI<B!L)W5S=6%R:2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M92YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@=7-E<CH@)7,B
M"FUS9W-T<B`B4W5P<FEM:7(@;"=U<W5A<FDZ("5S(@H*(SH@;&EB+TAO<F1E
M+U)00R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B
M92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS9W-T<B`B3F\@
M<R=H82!P;V=U="!R97-P;VYD<F4@82!L82!S;VRW;&EC:71U9"X@0V]D:2!D
M)V5R<F]R(')E=&]R;F%T.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,30Y"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@
M8F4@9F]U;F0N(@IM<V=S='(@(DYO(',G:&$@=')O8F%T(&5L('-E<G9E:2!S
M;VRW;&EC:71A="XB"@HC.B!L:6(O2&]R9&4N<&AP.C$W-"!L:6(O2&]R9&4N
M<&AP.C0X-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@
M)R5S)R!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(DYO(',G:&$@97-P96-I9FEC870@96P@)R5S)R!N96-E<W-A<FD@96X@
M;&$@8V]N9FEG=7)A8VGS(&1E("5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW
M-#<@;&EB+U9&4R]S<6PN<&AP.C4Y-R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HW
M,3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D("<E<R<@
M;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M3F\@<R=H82!E<W!E8VEF:6-A="!E;"`G)7,G(&YE8V5S<V%R:2!P97(@82!L
M82!C;VYF:6=U<F%C:?,@5D93+B(*"B,Z(&QI8B](;W)D92]5=&EL+G!H<#HW
M.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D("<E<R<@
M;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(").;R!S
M)VAA(&5S<&5C:69I8V%T(&5L("<E<R<@;F5C97-S87)I('!E<B!A(&QA(&-O
M;F9I9W5R86-I\RXB"@HC.B!L:6(O2&]R9&4O1F]R;2]296YD97)E<BYP:'`Z
M,S(X"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R(")#86UP('-O;+=L
M:6-I=&%T(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@;&EB+TAO<F1E+T9O<FTN
M<&AP.C,S.2!L:6(O2&]R9&4O1F]R;2]296YD97)E<BYP:'`Z,S$U"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#0@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C$P,0IM<V=I9"`B4F5S970B"FUS9W-T<B`B4F5I
M;FEC:6$B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT-@IM<V=I
M9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`B4F5I;FEC:6%R(&QA(&-O;G1R
M87-E;GEA(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*;7-G
M:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B4F5I;FEC:6%R(&QA
M(&-O;G1R87-E;GEA(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C<Q(&%D;6EN
M+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S<6QS:&5L;"YP:'`Z-C4*;7-G:60@
M(E)E<W5L=',B"FUS9W-T<B`B4F5S=6QT871S(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C@R,0IM<V=I9"`B4F5S=6QT<R`H:6YC;'5D:6YG($AO<F1E*3HB
M"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C@Q.0HC+"!F=7IZ
M>0IM<V=I9"`B4F5S=6QT<SHB"FUS9W-T<B`B4F5S=6QT871S(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,B!T96UP;&%T97,O<')E9G,O
M96YD+FEN8SHW"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R(")4
M;W)N82!A(&]P8VEO;G,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3DW"FUS9VED(")2975N:6]N(@IM<V=S='(@(E)E
M=6YI\R(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB
M"FUS9W-T<B`B4F5S=&%U<F%R(&QA(&-O;F9I9W5R86-I\R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,S`*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@
M3W!T:6]N<R(*;7-G<W1R(")/<&-I;VYS(&1E(&PG961I=&]R(&1E('1E>'0@
M96YR:7%U:70B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@
M(E)I9&1L97,B"FUS9W-T<B`B16YI9VUE<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`IM<V=I9"`B4FEG:'0B
M"FUS9W-T<B`B1')E=&$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$Q.0IM
M<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(D-A<.=A;&5R82!D<F5T82(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3$U"FUS9VED(")2:6=H="!V86QU
M97,B"FUS9W-T<B`B5F%L;W)S(&1E(&QA(&1R971A(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X"FUS9VED
M(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B4')O<&EE=&%T<R!D92!L
M82!F:6QA+BXN(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HR,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`B1G5N8VGS(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`R(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ.#8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y.`IM<V=I9"`B
M4F]M86YI82(*;7-G<W1R(")2;VUA;FEA(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(P.`IM<V=I9"`B4F]T871E(#$X,"(*;7-G
M<W1R(")':7)A<B`Q.#`B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C`U"FUS9VED(")2;W1A=&4@3&5F="(*;7-G<W1R(")':7)A
M<B!A(&PG97-Q=65R<F$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C$Q"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`B1VER
M87(@82!L82!D<F5T82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0<F]P97)T:65S(@IM
M<V=S='(@(E!R;W!I971A=',@9&4@;&$@9FEL82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O
M=R!P<F]P97)T:65S(@IM<V=S='(@(E!R;W!I971A=',@9&4@;&$@9FEL82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q
M"FUS9VED(")2;W=S.B(*;7-G<W1R(")&:6QE<SHB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4S"FUS9VED(")2
M=6QE<R(*;7-G<W1R(")296=L97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL
M(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@
M(D%P87)E:7AE<F%N(')E9VQE<R!E;G1R92!T;W1E<R!L97,@9FEL97,@:2!C
M;VQU;6YE<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E
M96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(D%P87)E:7AE<F%N(')E9VQE<R!N
M;VWI<R!E;G1R92!C;VQU;6YE<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@
M87!P96%R(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S='(@(D%P87)E:7AE<F%N
M(')E9VQE<R!N;VWI<R!E;G1R92!F:6QE<R(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,C$*;7-G:60@(E)U;B(*;7-G<W1R(")%>&5C=71A<B(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P,R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3D*;7-G
M:60@(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R(")&961E<F%C:?,@4G5S
M<V$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C`P"FUS9VED(")2=V%N9&$B"FUS9W-T<B`B4G=A;F1A(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#<GEP
M=&]G<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R(")3:6=N871U<F$@8W)I<'1O
M9W+@9FEC82!A;6(@4R]-24U%(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*;7-G
M<W1R(")-:7-S871G92!X:69R870@86UB(%,O34E-12(*"B,Z(&QI8B](;W)D
M92]!=71H+W-A<VPN<&AP.C@Q"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N
M(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DPG875T96YT:6-A8VGS(%-!
M4TP@;F\@97-TX"!D:7-P;VYI8FQE+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT-3`*;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T<B`B36ES
M<V%T9V5R:6$@4TU3(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS9VED
M(")344P@4VAE;&PB"FUS9W-T<B`B26YTZ')P<F5T(&0G;W)D<F5S(%-13"(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-C$*;7-G:60@(E-32"(*
M;7-G<W1R(")34T@B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-50T-%4U,B"FUS9W-T<B`BR%A)
M5"(*"B,Z(&QI8B]A<&DN<&AP.C$S,@IM<V=I9"`B4U]13"!3:&5L;"(*;7-G
M<W1R("));G3H<G!R970@9"=O<F1R97,@4U%,(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T
M<B`B1',N(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(P-PIM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@(E-A:6YT
M($AE;&5N82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@T(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$S,0IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S
M='(@(E-A:6YT($-H<FES=&]P:&5R(&D@3F5V:7,B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DQ"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,SD*;7-G:60@(E-A:6YT
M($QU8VEA(@IM<V=S='(@(E-A:6YT($QU8VEA(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M.3(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X.0IM<V=I9"`B4V%I;G0@
M4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R(")386EN="U0:65R<F4M970M
M36EQ=65L;VXB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,34@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C0T"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E
M;F%D:6YE<R(*;7-G<W1R(")386EN="!6:6YC96YT(&D@;&5S($=R96YA9&EN
M97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDR"FUS9VED(")386UE(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B36%T96EX
M(&UA<F,@*%]S96QF*2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR-3$*;7-G:60@(E-A;6]A(@IM<V=S='(@(E-A;6]A
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(Q,@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R(")386X@36%R:6YO(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`W(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ.38*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q
M-@IM<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S='(@(E-A;R!4
M;VWI(&D@4'+M;F-I<&4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R(")0<F]V9>]D
M;W(@9&4@<V%TZ&RW;&ET(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(P,0IM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S
M='(@(D%RX&)I82!3875D:71A(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO
M=70N:6YC.CDX"FUS9VED(")3879E(@IM<V=S='(@(D1E<V$B"@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3879E("5S(@IM<V=S='(@(D1E<V$@)7,B"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V5D:70N:6YC.C0Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")3879E("<E<R<B"FUS9W-T<B`B1&5S82`E<R(*"B,Z('1E;7!L871E
M<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R
M(")$97-A(&QE<R!O<&-I;VYS(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$W,`IM<V=I9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A
M<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB
M9&ER96-T;W)Y+B(*;7-G<W1R("(B"B)$97-E=2!L82!C;VYF:6=U<F%C:?,@
M9V5N97)A9&$@8V]M('5N82!S97'\Z&YC:6$@4$A0(&5N(&5L(&1I<F5C=&]R
M:2`B"B)T96UP;W)A;"!D96P@<V5R=FED;W(N(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@)7,@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B4R=H82!D97-A="!L82!C;VYF:6=U
M<F%C:?,@9&4@)7,N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3`*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A
M9&4@<V-R:7!T('1O.B`G)7,G+B(*;7-G<W1R(")3)VAA(&1E<V%T(&QA('-E
M<?SH;F-I82!A8W1U86QI='IA9&$@9&4@8V]N9FEG=7)A8VGS(&$Z("<E<R<N
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*
M;7-G:60@(E-C871T97)E9"!4+5-T;W)M<R(*;7-G<W1R(")496UP97-T97,@
M9&ES<&5R<V5S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED
M(")38VEE;F-E(@IM<V=S='(@(D-IZ&YC:6$B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(D-E<F-A(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W-@IM<V=I9"`B4V5A<F-H($5N9VEN
M97,B"FUS9W-T<B`B36]T;W)S(&1E(&-E<F-A(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C$T-#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-E87)C
M:&EN9R!(;W)D92!A<'!L:6-A=&EO;G,@:6X@)7,B"FUS9W-T<B`B3W!C:6]N
M<R!D92!C97)C82(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,C,*(RP@9G5Z
M>GD*;7-G:60@(E-E87)C:&EN9R!G971T97AT(&)I;F%R:65S+BXN(@IM<V=S
M='(@(D]P8VEO;G,@9&4@8V5R8V$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,CDW,0IM<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S='(@(E-E;&5C8VEO;F%R
M(&5L<R!A<GAI=7,B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#4V"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(E-E;&5C
M8VEO;F%R('5N82!D871A(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R(")3
M96QE8V-I;VYA<B!U;B!G<G5P('%U92!V=6QG=65U(&%F96=I<B(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE
M=R!O=VYE<B(*;7-G<W1R(")396QE8V-I;VYE=2!U;B!N;W4@<')O<&EE=&%R
M:2(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B
M4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(E-E;&5C8VEO;F5U('5N('-E<G9I
M9&]R(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-38*;7-G:60@
M(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S='(@(E-E;&5C8VEO;F5U('5N
M('5S=6%R:2!Q=64@=G5L9W5E=2!A9F5G:7(B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C8V,0IM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N
M(@IM<V=S='(@(E-E;&5C8VEO;F5U('1O=',@96QS(&5L96UE;G1S(&1E(&QA
M(&1A=&$N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C@Q,0IM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R(")396QE8V-I
M;VYE=2!U;B!O8FIE8W1E(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W
M"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O
M;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P
M87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B(@HB4V5L
M96-C:6]N974@96QS(&-A<N!C=&5R<R!Q=64@;F5C97-S:71E=2!D92!L97,@
M8V%S96QL97,@9&4@<V]T82X@4&]D974@(@HB8V]P:6%R+6QO<R!I(&5N9V%N
M>&%R+6QO<R!D92!L)^!R96$@9&4@=&5X="XB"@HC.B!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H92!D871E(&1E;&EM:71E
M<CHB"FUS9W-T<B`B4V5L96-C:6]N87(@96P@9&5L:6UI=&%D;W(@9&4@;&$@
M9&%T83HB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-`IM<V=I9"`B
M4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`B4V5L96-C:6]N87(@
M96P@9F]R;6%T(&1E(&QA(&1A=&$Z(@H*(SH@=&5M<&QA=&5S+W!R969S+VED
M96YT:71Y<V5L96-T+FEN8SHX.0IM<V=I9"`B4V5L96-T('1H92!I9&5N=&ET
M>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(E-E;&5C8VEO;F%R(&QA
M(&ED96YT:71A="!Q=64@=F]L974@<75E(&-A;G9I87(Z(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O=&EM92YI;F,Z,38*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D
M96QI;6ET97(Z(@IM<V=S='(@(E-E;&5C8VEO;F%R(&5L(&1E;&EM:71A9&]R
M(&1E(&PG:&]R83HB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM
M<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`B4V5L96-C
M:6]N87(@96P@9F]R;6%T(&1E(&PG:&]R83HB"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C8T"FUS9VED(")396QE8W0@='=O(&UA=&-H:6YG(&9I
M96QD<RXB"FUS9W-T<B`B4V5L96-C:6]N87(@9&]S(&-A;7!S('%U92!C;VEN
M8VED96EX:6XN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y-@IM<V=I
M9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R(")396QE8V-I
M;VYA<B!L82!C;VUB:6YA8VGS(&1E(&-O;&]R<RXB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C,X"FUS9VED(")396QE8W0@>6]U<B!P<F5F97)R960@
M;&%N9W5A9V4Z(@IM<V=S='(@(E-E;&5C8VEO;F%R(&PG:61I;VUA('!R969E
M<FET.B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS
M9VED(")396YD(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(D5N=FEA<B!L)VEN
M9F]R;64@9&5L<R!P<F]B;&5M97,B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.38Q"FUS9VED(")396YD(%--4R(*;7-G<W1R(")%
M;G9I87(@4TU3(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(Q,PIM<V=I9"`B4V5N96=A;"(*;7-G<W1R(")396YE9V%L
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,30*;7-G:60@(E-E;G-O<CH@
M(@IM<V=S='(@(E-E;G-O<CH@(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C,X,B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-S,*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R(")3971E;6)R92(*
M"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E
M<F)I82!A;F0@36]N=&5N96=R;R(*;7-G<W1R(")3Z')B:6$@:2!-;VYT96YE
M9W)O(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#$*;7-G:60@
M(E-E<FEA;"!.=6UB97(B"FUS9W-T<B`B3OIM97)O(&1E('/H<FEE(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U,PIM<V=I9"`B4V5R=F5R
M(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3&5S(&1A
M9&5S(&1E;"!S97)V:61O<B!S\VX@:6YC;W)R96-T97,@;R!N;R!E<W1A;B!D
M:7-P;VYI8FQE<RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y,0IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R(")(
M82!C861U8V%T(&PG:61E;G1I9FEC861O<B!D92!S97-S:?,N(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(S,3(*;7-G:60@(E-E="(*;7-G<W1R(")$969I
M;F5I>"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-@IM<V=I9"`B4V5T
M(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@
M:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*;7-G<W1R("(B"B)$969I;F5I>"!L
M97,@;W!C:6]N<R!Q=64@=7,@<&5R;65T96X@<F5I;FEC:6%R(&QA(&-O;G1R
M87-E;GEA('-I(&UA:2`B"B)L)V]B;&ED974N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Q-0IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H
M870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S
M='(@(D1E9FEN:74@96QS('-E<G9I9&]R<R!R96UO=',@82!Q=>@@=F]L974@
M86-C961I<B!D97,@9&5L('!O<G1A;"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.#0*;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@
M=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B(@HB1&5F:6YI
M=2!E;"!V;W-T<F4@:61I;VUA('!R969E<FET+"!L82!Z;VYA(&AO<N!R:6$@
M:2!L97,@;W!C:6]N<R!D92!D871A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY.`IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO
M;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B
M"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(B(*(D1E9FEN:74@;"=A<&QI
M8V%C:?,@9"=I;FEC:2P@;&$@8V]M8FEN86-I\R!D92!C;VQO<G,L(&5L(')E
M9G)E<V-A;65N="!D92!L97,@(@HB<.!G:6YE<R!I(&%L=')E<R!O<&-I;VYS
M(&1E('9I<W5A;&ET>F%C:?,N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HW-`IM<V=I9"`B4V5T=7`B"FUS9W-T<B`B0V]N9FEG=7)A8VGS(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,SD*;7-G:60@(E-E
M='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`B2&D@:&$@
M<V5Q_.AN8VEE<R!D)V%C='5A;&ET>F%C:?,@9&4@;&$@8V]N9FEG=7)A8VGS
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W.`IM<V=I9"`B
M4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R
M.B`B"FUS9W-T<B`B2&D@:&$@9&EV97)S97,@=6)I8V%C:6]N<R!P;W-S:6)L
M97,@86UB(&5L('!A<N!M971R93H@(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P,PIM<V=I9"`B4V5Y8VAE;&QE<R(*
M;7-G<W1R(")397EC:&5L;&5S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0T,@IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B0V]M<')E<R(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S"FUS9VED(")3:&]R
M="!3=6UM87)Y(@IM<V=S='(@(E)E<W5M(&)R974B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#,V"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@
M9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B5F]L974@9&5F:6YI
M<B!L97,@8VQA=7,@9"=A8V/I<R!P97(@82!L82!M86IO<B!P87)T(&0G96YL
M;&'G;W,_(@H*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR.3(@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C8W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G
M:60@(E-H;W<B"FUS9W-T<B`B36]S=')A(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$U.`IM<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N
M(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")-;W-T<F$@;&5S(&1I9F5RZ&YC:65S
M(&5N=')E(&QA(&-O;F9I9W5R86-I\R!D97-A9&$@:2!L82!N;W9A+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.#`*;7-G:60@(E-H;W<@;&%S="!L
M;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`B5F]L974@=FES
M=6%L:71Z87(@;"=H;W)A(&1E(&QA(&1A<G)E<F$@<V5S<VGS(&5N(&EN:6-I
M87(_(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W-CD*;7-G:60@(E-H;W<@
M;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS9W-T<B`B36]S=')A(&PG;W!C
M:?,@9&4@8V]N<V5R=F%R(&PG;W)I9VEN86PB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C@Q,0IM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B36]S=')A
M(&5L(&-A<'1U<F%D;W(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$U
M"FUS9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM<V=S
M='(@(E9O;&5U('9I<W5A;&ET>F%R(&QA(&)A<G)A(&1E(&UE;OH@9"=O<&5R
M86-I;VYS(&1E('1A=6QA/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T
M:&4@;&5F=#\B"FUS9W-T<B`B5F]L974@=FES=6%L:71Z87(@96P@;65N^B`E
M<R!D92!L)V5S<75E<G)A/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.`IM<V=I9"`B4VAO=R!T:&4@5&%B
M;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")-;W-T<F$@96P@
M9&G@;&5G(&1E('!R;W!I971A=',@9&4@8V5LMVQA(&1E('1A=6QA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8S"FUS9VED(")3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9R(*
M;7-G<W1R(")-;W-T<F$@96P@9&G@;&5G(&1E('!R;W!I971A=',@9&4@=&%U
M;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T
M:65S(&1I86QO9R(*;7-G<W1R(")-;W-T<F$@96P@9&G@;&5G(&1E('!R;W!I
M971A=',@9&4@9FEL82!D92!T875L82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B4VAO=R!T
M:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B36]S=')A(&5L
M(&1IX&QE9R!D92!P<F]P:65T871S(&1E(&EM871G92(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ-S8W"FUS9VED(")3:&]W('5P;&]A9"(*;7-G<W1R(")-
M;W-T<F$@;&$@8^!R<F5G82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")3:&]W97)S(@IM<V=S='(@(E)U:7AA
M=',B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M.`IM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R(")2=6EX871S(&$@<')I
M;65R82!H;W)A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#D*;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G<W1R(")2=6EX871S
M(&-A<"!A;"!T87)D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-3`*;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM
M<V=S='(@(E)U:7AA=',@82!L82!R;V1A;&EA(@H*(SH@;&EB+TAO<F1E+T)L
M;V-K+TQA>6]U="YP:'`Z,SDY"FUS9VED(")3:')I;FLB"FUS9W-T<B`B4F5D
M=>]U(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-CDR(&QI8B](
M;W)D92]";&]C:R],87EO=70N<&AP.C<U-`HC.B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+G!H<#HX,3(@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z.#<T
M"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.CDP.2!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+G!H<#HY-#8*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="YP:'`Z.3<T(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C$P,#0*;7-G
M:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@
M;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R(")0<FEM97(@<F5D=>]U(&\@87!A
M<G1E=2!E;"AS*2!B;&]C*',I(&1E;"!C;W-T870B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(P,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$Q"FUS9VED(")3:65R
M<F$@3&5O;F4B"FUS9W-T<B`B4VEE<G)A($QE;VYE(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O4VEG;G5P+G!H<#HR-C4*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B
M1&]N974M=F]S(&0G86QT82(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z.3`*;7-G:60@(E-I9VX@=7`@:68@;F]T(')E9VES=&5R960B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,3(*;7-G:60@
M(E-I9VYA='5R92(*;7-G<W1R(")3:6=N871U<F$B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C<Q,0IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H
M;2(*;7-G<W1R(")!;&=O<FES;64@9&4@<VEG;F%T=7)A(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`T(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,#(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-@IM<V=I9"`B
M4VEN9V%P;W)E(@IM<V=S='(@(E-I;F=A<'5R(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C@Y-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q-2!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3(S-PHC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(T-B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,CDR."!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$R,0HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV.2!L:6(O2&]R9&4O
M34E-12]6:65W97(O=&=Z+G!H<#HX-PHC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O<F%R+G!H<#HV-0IM<V=I9"`B4VEZ92(*;7-G<W1R(")-:61A(@H*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?8F]T=&]M+FEN8SHY"FUS
M9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S='(@(D]M970@;6%N=&5N:6UE
M;G0B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#,Q('!O+W1R86YS;&%T:6]N
M+G!H<#HT.#0@<&\O=')A;G-L871I;VXN<&AP.C8V-@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z.#8P('!O+W1R86YS;&%T:6]N+G!H<#HQ,C(S"FUS9VED(")3
M:VEP<&5D+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,3`*;7-G:60@(E-L;W9A:VEA(@IM<V=S
M='(@(D5S;&]VX'%U:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-`HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C`X"FUS9VED(")3;&]V96YI82(*;7-G<W1R(")%
M<VQO=NAN:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU,0IM<V=I9"`B4VYO=R(*;7-G<W1R(").979A9&$B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4VYO
M=R!3:&]W97(B"FUS9W-T<B`B6.!F96,@9&4@;F5U(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E-N;W<@4VAO
M=V5R<R(*;7-G<W1R(")8X&9E8W,@9&4@;F5U(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-30*;7-G:60@(E-N;W<@4VAO=V5R
M<R!%87)L>2(*;7-G<W1R(")8X&9E8W,@9&4@;F5U(&$@<')I;65R82!H;W)A
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-34*
M;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(EC@9F5C<R!D92!N
M974@8V%P(&%L('1A<F0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W-@IM
M<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@(D=R=6EX(&1E(&YE=3H@(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#`*;7-G:60@(E-N;W<@97%U:79A
M;&5N="!I;B!W871E<CH@(@IM<V=S='(@(D5Q=6EV86QE;G0@9&4@;&$@;F5U
M(&5N(&%I9W5A.B`B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C`R"FUS9VED(")3;VQO;6]N($ES;&%N9',B"FUS9W-T
M<B`B26QL97,@4V%L;VWS(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#8*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(Q-`IM<V=I9"`B4V]M86QI82(*;7-G<W1R(")3
M;VW@;&EA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED(")3
M;VYG<R`F(%!O96US(@IM<V=S='(@(D-A;N=O;G,@:2!P;V5M97,B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,CDR-`IM<V=I9"`B4V]R="!O<F1E<B!S96QE
M8W1I;VXB"FUS9W-T<B`B4V5L96-C:?,@96X@96P@<V5N=&ET(&1E(&QA(&-L
M87-S:69I8V%C:?,B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Q-B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T-@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34X(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#@*;7-G:60@(E-O=7)C92!A9&1R
M97-S(@IM<V=S='(@(D%D<F7G82!D)V]R:6=E;B(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-34*;7-G:60@(E-O=71H
M($%F<FEC82(*;7-G<W1R(")3=60MX&9R:6-A(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.3`*;7-G:60@(E-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS
M*2(*;7-G<W1R(")3=60M975R;W!E=2`H25-/+3@X-3DM,RDB"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#$*;7-G:60@
M(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S
M(@IM<V=S='(@(D=E\G)G:6$@9&5L(%-U9"!I(&QE<R!I;&QE<R!386YD=VEC
M:"!D96P@4W5D(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C
M:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G
M<W1R(")(96UI<V9E<FD@<W5D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J
M86-E;G0@8V5L;',B"FUS9W-T<B`B17-P86D@96YT<F4@8V5LMVQE<R!A9&IA
M8V5N=',B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D
M97(@:6X@8V5L;"(*;7-G<W1R(")%<W!A:2!E;G1R92!E;"!C;VYT:6YG=70@
M:2!E;"!C;VYT;W)N(&1E(&QA(&-E;+=L82(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HX,34*;7-G:60@(E-P86-E<B(*;7-G<W1R(")%<W!A:6%D;W(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#`*;7-G:60@(E-P86-I;F<B"FUS9W-T<B`B17-P86EA="(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G
M:60@(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B17-P86EA="!I(&9A
M<F-I;65N="(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C@P"FUS9VED(")3<&%I;B(*;7-G<W1R(")%<W!A;GEA(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDV"FUS9VED(")3<&%M(@IM<V=S
M='(@(D-O<G)E=2!B<F]S<V$B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z
M,30*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(D5S
M8W)I<'1U<F$@9&4@8V%RX&-T97)S(&5S<&5C:6%L<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G:60@
M(E-P;&ET(&-E;&PB"FUS9W-T<B`B1&EV:61I<B!C96RW;&$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V"FUS
M9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B1&EV:61I<B!C;VQU;6YA(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S='(@(D1I=FED:7(@9FEL82(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,0IM<V=I9"`B4W!O<G1S(@IM
M<V=S='(@(D5S<&]R=',B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-#$*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R(")3
M<FD@3&%N:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S(@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HW,@IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T
M<B`B17-TX&YD87)D(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8R"FUS
M9VED(")3=&%R(%1R96LB"FUS9W-T<B`B4W1A<B!4<F5K(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(U.30@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,#<*;7-G
M:60@(E-T87)T('EE87(B"FUS9W-T<B`B06YY(&0G:6YI8VDB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B4W1A=&4@;W(@4')O
M=FEN8V4B"FUS9W-T<B`B17-T870@;R!P<F]V[6YC:6$B"@HC.B!T96UP;&%T
M97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S(@IM
M<V=S='(@(D5S=&%T(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0Y,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3=&%T=7,@9F]R(&QO8V%L92`E<RXN+B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,3,*;7-G:60@(E-T
M;W)A9V4@9F]R;6%T(@IM<V=S='(@(D9O<FUA="!D)V5M;6%G871Z96UA=&=E
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S(*;7-G:60@(E-T
M<F5E="!!9&1R97-S(@IM<V=S='(@(D%D<F7G82!P87)T:6-U;&%R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I
M9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R(")"87)R870B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3(S,PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B
M3&QI<W1A(&1E(&-A9&5N97,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W
M,PIM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS9W-T
M<B`B16QI;6EN974@96P@9&]M:6YI(&1E(&PG861R9>=A(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I
M9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B17-T:6P@6T-34UTB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3
M=2(*;7-G<W1R(")$9RXB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8F1I<F5C=&]R>2`G)7,G
M(&YO="!F;W5N9"XB"FUS9W-T<B`B3F\@<R=H82!T<F]B870@96P@<W5B9&ER
M96-T;W)I("`G)7,G+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C<S"FUS9VED(")3=6)J96-T(@IM<V=S='(@(D%S<W5M<'1E(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,B!L:6(O2&]R9&4O1F]R;2]296YD
M97)E<BYP:'`Z,S$R"FUS9VED(")3=6)M:70B"FUS9W-T<B`B16YV:6$B"@HC
M.B!S:6=N=7`N<&AP.C0Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@)R5S)R!T;R!T:&4@<WES=&5M
M+B!9;W4@8V%N(&YO="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA
M<R!B965N(&%P<')O=F5D+B(*;7-G<W1R("(B"B)3)VAA('1R86WH<R!U;F$@
M<V]LMVQI8VET=60@<&5R(&%F96=I<B`G)7,G(&%L('-I<W1E;6$N($YO('!O
M9&5U(&EN:6-I87(@;&$@(@HB<V5S<VGS(&9I;G,@<75E(',G:&%G:2!A<')O
M=F%T(&QA('-O;+=L:6-I='5D+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R
M(")3=6+M;F1E>"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#4@;&EB+TAO
M<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED
M(")3=6-C97-S(@IM<V=S='(@(LAX:70B"@HC.B!A9&UI;B]U<V5R+G!H<#HX
M-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D
M9&5D("<E<R<@=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B4R=H82!A9F5G:70@
M8V]R<F5C=&%M96YT("<E<R<@86P@<VES=&5M82XB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F
M=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@)R5S)R!F<F]M('1H92!S>7-T
M96TN(@IM<V=S='(@(E,G:&%N(&5L:6UI;F%T(&-O<G)E8W1A;65N="!D96P@
M<VES=&5M82!L97,@9&%D97,@9&4@;"=U<W5A<FD@)R5S)RXB"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C@Q(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-C$*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE=&5D
M("<E<R<N(@IM<V=S='(@(E,G:&$@<W5P<FEM:70@8V]R<F5C=&%M96YT("<E
M<R<N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"`G)7,G(&9R;VT@=&AE
M('-Y<W1E;2XB"FUS9W-T<B`B4R=H82!S=7!R:6UI="!C;W)R96-T86UE;G0@
M)R5S)R!D96P@<VES=&5M82XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO
M;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R("(B"B)3)VAA(')E
M<W1A=7)A="!C;W)R96-T86UE;G0@;&$@8V]N9FEG=7)A8VGS+B!!8W1U86QI
M='IE=2!P97(@=F5U<F4@96QS("(*(F-A;G9I<RXB"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HU-2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D*;7-G
M:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B4R=H82!D97-A="!C;W)R96-T86UE;G0@;&$@8V]N9FEG=7)A
M8VGS(&1E(&/R<&EA+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B
M86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R(")3)VAA(&1E
M<V%T(&-O<G)E8W1A;65N="!L)V%R>&EU(&1E(&QA(&-O;F9I9W5R86-I\R!D
M92!C\G!I82`E<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D("<E<R<B
M"FUS9W-T<B`B4R=H82!A8W1U86QI='IA="!C;W)R96-T86UE;G0@)R5S)R(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W
M<F]T92`E<R(*;7-G<W1R(")3)VAA(&5S8W)I="!C;W)R96-T86UE;G0@)R5S
M)R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,#0*;7-G:60@(E-U9&%N(@IM<V=S='(@(E-U9&%N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@IM<V=I
M9"`B4W5M;6%R>2(*;7-G<W1R(")297-U;2(*"B,Z(&QI8B]";&]C:R]S=6YR
M:7-E+G!H<#HV-@IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B4V]R=&ED82!D
M96P@<V]L(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C<Q"FUS9VED(")3
M=6X@4V5T(@IM<V=S='(@(E!O<W1A(&1E;"!S;VPB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4W5N;GDB"FUS
M9W-T<B`B07-S;VQE;&QA="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,#@*;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`B4V]R=&ED82!D96P@
M<V]L(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R(")3
M;W)T:61A(&1E;"!S;VPO4&]S=&$@9&5L('-O;"(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,#<*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R
M(")3;W)T:61A(&1E;"!S;VPZ("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,3$*;7-G:60@(E-U;G-E="(*;7-G<W1R(")0;W-T82!D96P@
M<V]L(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,`IM<V=I
M9"`B4W5N<V5T.B`B"FUS9W-T<B`B4&]S=&$@9&5L('-O;#HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S"FUS9VED(")3
M=7!E<G-C<FEP="(*;7-G<W1R(")3=7!E<NUN9&5X(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0S-`IM<V=I9"`B4W5P<&]R="(*;7-G<W1R(")!
M<W-I<W3H;F-I82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,34*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(E-U<FEN
M86TB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W-`IM<V=I9"`B
M4W5R;F%M92(*;7-G<W1R(")#;V=N;VTB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`Y"FUS9VED(")3=F%L8F%R9"!A
M;F0@2F%N($UA>65N(@IM<V=S='(@(E-V86QB87)D(&D@2F%N($UA>65N(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,30*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q
M.0IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(E-W87II;.!N9&EA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,34*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-0IM
M<V=I9"`B4W=E9&5N(@IM<V=S='(@(E-UZ&-I82(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,38*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4V"FUS9VED(")3=VET>F5R
M;&%N9"(*;7-G<W1R(")3=>]S<V$B"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O
M<F1S+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M
M<R(*;7-G<W1R(")%<G)O<B!D92!S:6YT87AI(&5N(&5L<R!T97)M97,@9&4@
M8V5R8V$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C$X"FUS9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*;7-G<W1R
M(")297#Z8FQI8V$@P')A8B!3:7)I86YA(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G:60@(E0M4W1O<FTB"FUS9W-T
M<B`B5&5M<&5S=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU.`IM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B
M5&5M<&5S=&$@:2!V96YT\W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU.0IM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B5&5M
M<&5S=&5S(@H*(SH@;&EB+TAO<F1E+T1A=&$O='-V+G!H<#HQ-C8*;7-G:60@
M(E135B!F:6QE(@IM<V=S='(@(D%R>&EU(%135B(*"B,Z(&QI8B](;W)D92]5
M22]486)L92YP:'`Z,3,V"B,L(&9U>GIY"FUS9VED(")486)L92(*;7-G<W1R
M(")4875L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T
M<B`B4')O<&EE=&%T<R!D92!T875L82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE('!R
M;W!E<G1I97,B"FUS9W-T<B`B4')O<&EE=&%T<R!D92!T875L82(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,2!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C,T"FUS9VED(")486EW86XB"FUS9W-T<B`B5&%I=V%N(@H*(SH@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I9"`B5&%I=V%N+"!0
M<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R(")486EW86XL('!R;W;M;F-I82!D
M92!L82!8:6YA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(R-0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R(")4861J
M:6MI<W1A;B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,S4*;7-G:60@(E1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@
M;V8B"FUS9W-T<B`B5&%N>N!N:6$L(%)E</IB;&EC82!5;FED82!D92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.34*;7-G
M:60@(E1A<F=E=#HB"FUS9W-T<B`B3V)J96-T:74Z(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$W,0IM<V=I9"`B5&%S:W,B"FUS9W-T<B`B5&%S
M<75E<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED
M(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(D[Z;65R;R!D92!T96SH9F]N
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#@*;7-G:60@(E1E;7`@9F]R
M(&QA<W0@:&]U<CH@(@IM<V=S='(@(E1E;7!E<F%T=7)A(&1U<F%N="!L82!D
M87)R97)A(&AO<F$Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$R"FUS
M9VED(")496UP97)A='5R92(*;7-G<W1R(")496UP97)A='5R82(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,34*;7-G:60@(E1E;7!E<F%T
M=7)E.B`B"FUS9W-T<B`B5&5M<&5R871U<F$Z("(*"B,Z(&QI8B](;W)D92]4
M96UP;&%T92YP:'`Z,C$W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4
M96UP;&%T92`G)7,G(&YO="!F;W5N9"XB"FUS9W-T<B`B3F\@<R=H82!T<F]B
M870@;&$@<&QA;G1I;&QA("<E<R<N(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H
M<#HQ-CD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(D%D;6EN:7-T<F%C:?,@9&4@<&QA;G1I;&QE<R(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,C$Q"FUS9VED(")497AT(@IM<V=S='(@(E1E>'0B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8U"FUS9VED(")497AT($]N;'DB"FUS
M9W-T<B`B3F]MZ7,@=&5X="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G:60@(E1E>'0@86QI9VXB"FUS
M9W-T<B`B06QI;F5A8VGS(&1E('1E>'0B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"FUS9VED(")497AT=&]P(@IM<V=S
M='(@(D%L:6YE870@82!D86QT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T<B`B1&HN(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@(E1H86D@*%1)4RTV
M,C`I(@IM<V=S='(@(E1A:6QA;F3H<R`H5$E3+38R,"DB"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(R,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(T"FUS9VED(")4
M:&%I;&%N9"(*;7-G<W1R(")486ELX&YD:6$B"@HC.B!L:6(O2&]R9&4O075T
M:"YP:'`Z.3`S"FUS9VED(")4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T
M96TN(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#8Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92`E<R!H96QP(&9I;&4@9F]R("5S(&1O
M97-N)W0@>65T(&5X:7-T+B!#<F5A=&EN9R!A(&YE=R!O;F4N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW,S<*;7-G:60@(E1H92!&5%`@97AT
M96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DPG97AT96YS:?,@
M1E10(&YO(&5S=.`@9&ES<&]N:6)L92XB"@HC.B!L:6(O2&]R9&4O2V]L86(N
M<&AP.CDP,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@
M:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM
M<V=S='(@(D5L(&UO=&]R(&0G:6YT96=R86-I\R!(;W)D92]+;VQA8B!N;R!P
M97)M970@;"?Z<R!D92!<(B5S7"(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z,CD*;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N
M;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B3&$@8VQA<W-E($UA:6YT
M96YA;F-E.CH@;F\@<R=H82!C87)R96=A="!C;W)R96-T86UE;G0C(R(*"B,Z
M('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H
M92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R
M(")3)VAA('1A;F-A="!L82!F:6YE<W1R82!D)V]P8VEO;G,N(%-O<G1I;G0@
M9&5L('-I<W1E;6$B"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C$U."!L:6(O
M2&]R9&4O4&5R;7,N<&AP.C$V.2!L:6(O2&]R9&4O4&5R;7,N<&AP.C$X,`HC
M.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C$Y,B!L:6(O2&]R9&4O4&5R;7,N<&AP
M.C(P,R!L:6(O2&]R9&4O4&5R;7,N<&AP.C(R,0HC.B!L:6(O2&]R9&4O4&5R
M;7,N<&AP.C(S,R!L:6(O2&]R9&4O4&5R;7,N<&AP.C(W,@IM<V=I9"`B(@HB
M5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N
M96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E
M(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B"B)3:2!V;VQE=2!U=&EL:71Z87(@
M96QS('!E<FUI<V]S+"!L)V%D;6EN:7-T<F%D;W(@:&$@9&4@8V]N9FEG=7)A
M<B!U;B!M;W1O<B`B"B)D92!P97)M:7-O<R!P97)M86YE;G0N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM
M<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T<B`B3F]MZ7,@96P@
M8V]N=&]R;B!I;F9E<FEO<B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S@*;7-G:60@(B(*(E1H92!C;VYT86-T($E$(&YU;6)E<B!W
M87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD
M(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B(@HB16P@;OIM97)O(&ED
M96YT:69I8V%D;W(@9&5L(&-O;G1A8W1E(&YO(',G:&$@97-P96-I9FEC870L
M(',G:&$@9&5I>&%T(&5N("(*(F)L86YC(&\@;F\@<R=H82!T<F]B870@82!L
M82!B87-E(&1E(&1A9&5S+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z-3$*;7-G:60@(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L
M;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(E,G:&$@
M869E9VET(&-O<G)E8W1A;65N="!E;"!C;VYT86-T92!A(&QA(&QL:6)R971A
M(&0G861R96-E<RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,30Y
M"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I
M<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G
M<W1R("(B"B)%<R!N96-E<W-I=&$@96P@8FQO8R!D92!S:6=N871U<F5S(%!'
M4"!S97!A<F%T('!E<B!V97)I9FEC87(@96P@;6ES<V%T9V4@(@HB<VEG;F%T
M+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#`*;7-G
M:60@(B(*(E1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO
M="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H
M92!D871A8F%S92XB"FUS9W-T<B`B(@HB3"=I9&5N=&EF:6-A9&]R(&1E(&QA
M(&QL:7-T82!D92!D:7-T<FEB=6-I\R!N;R!S)VAA(&5S<&5C:69I8V%T+"!S
M)VAA(&1E:7AA="`B"B)E;B!B;&%N8R!O(&YO(',G:&$@=')O8F%T(&$@;&$@
M8F%S92!D92!D861E<RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C0Q"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO
M="!S<&5C:69I960N(@IM<V=S='(@(DYO(',G:&$@97-P96-I9FEC870@;&$@
M;&QI<W1A(&1E(&1I<W1R:6)U8VGS+B(*"B,Z(&QI8B](;W)D92]#<GEP="YP
M:'`Z,3$S"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E
M(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("),97,@8V%R86-T
M97+M<W1I<75E<R!D96P@>&EF<F%T9V4@97AI9V5I>&5N('5N82!C;VYN97AI
M\R!W96(@9FEA8FQE+B(*"B,Z(&QI8B](;W)D92YP:'`Z,3<U(&QI8B](;W)D
M92YP:'`Z-#@X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H
M;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B3"=A<GAI=2`E
M<R!H875R:6$@9&4@8V]N=&5N:7(@=6X@<&%RX&UE=')E("5S+B(*"B,Z(&QI
M8B](;W)D92YP:'`Z,38X(&QI8B](;W)D92YP:'`Z-#<X"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@
M<V5T=&EN9W,N(@IM<V=S='(@(DPG87)X:74@)7,@:&%U<FEA(&1E(&-O;G1E
M;FER(&%L9W5N<R!P87+@;65T<F5S("5S+B(*"B,Z(&QI8B]61E,O9FEL92YP
M:'`Z,34R"B,L(&9U>GIY"FUS9VED(")4:&4@9FEL92!C86X@;F]T(&)E(&-O
M<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B3"=A<GAI=2!N;R!C;VYT96YI
M82!D861E<RXB"@HC.B!L:6(O2&]R9&4O1&%T82YP:'`Z,C8P"FUS9VED(")4
M:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B3"=A<GAI=2!N
M;R!C;VYT96YI82!D861E<RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M<F9C.#(R+G!H<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE
M861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS9W-T
M<B`B(@HB02!C;VYT:6YU86-I\R!E<R!P<F5S96YT96X@;&5S(&-A<.=A;&5R
M97,@9"=A<75E<W0@;6ES<V%T9V4O;6ES<V%T9V4@<F9C.#(R+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@
M(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R
M;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W
M<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@
M(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C
M:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C
M<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S
M('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R
M;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@
M:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@
M<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS
M9W-T<B`B(@HB4R=H82!C;VYS=&%T870@<75E(&5L(&UO9&4@9&4@<&%N=&%L
M;&$@8V]M<&QE=&$@9/-N82!P<F]B;&5M97,@86UB($EN=&5R;F5T("(*(D5X
M<&QO<F5R(&$@8V%U<V$@9"=E<G)O<G,@96X@96P@;F%V96=A9&]R('%U92!N
M;R!H96T@<&]G=70@<F5S;VQD<F4N(%!O="!S97(@(@HB<75E('9I<W5A;&ET
M>F5U(&)R;W-S82P@=7,@;6%N<75I;B!F=6YC:6]N<R!E;B!L)V5D:71O<B!I
M+V\@<75E(&5L(&YA=F5G861O<B`B"B)U<R!F86QL:2!D92!M86YE<F$@86QE
M873R<FEA+B!3:2!T96YI=2!E;"!S:7-T96UA(%=I;F1O=W,@.7@@Z7,@;6]L
M="`B"B)P<F]B86)L92!Q=64@97,@<')O9'5E:7AI('5N("=E<G)O<B!D92!P
M<F]T96-C:?,@9V5N97)A;"<@:2!H86=U974@9&4@(@HB<F5I;FEC:6%R(&1E
M(&YO=2X@4VDL('1O="!I(&%Q=65S="!A9'9E<G1I;65N="P@96YC87)A('9O
M;&5U('!R;W9A<B!L)V5D:71O<B`B"B)D92!P86YT86QL82!C;VUP;&5T82P@
M<')E;65U($0G86-O<F0N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P.3<@
M<&\O=')A;G-L871I;VXN<&AP.C$R,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&AE;'`@9FEL92`E<R!D:61N)W0@<W1A<G0@=VET:"`\/WAM;"(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.#@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D
M+B(*;7-G<W1R(")3)VAA('-U<')I;6ET(&QA(&ED96YT:71A="!<(B5S7"(N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T
M<B`B3F]MZ7,@96P@8V]S=&%T(&5S<75E<G)E(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z,30V"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE
M($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z
M.B!C;&%S<RXB"FUS9W-T<B`B3&$@=6)I8V%C:?,@9&5L(&)I;F%R:2!';G50
M1R!S)VAA(&0G:6YD:6-A<B!A(&QA(&-L87-S92!#<GEP=%]P9W`N(@H*(SH@
M;&EB+TAO<F1E+TU)344O341.+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE
M8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@
M9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U
M;F1E<G-T;V]D+B(*;7-G<W1R("(B"B)3)VAA(&UO<W1R870@96P@;6ES<V%T
M9V4@96YV:6%T(&5L("5S(&$@)7,@86UB(&PG87-S=6UP=&4@7"(E<UPB+B!!
M:7CR(&YO("(*(F=A<F%N=&5I>"!Q=64@<R=H86=I(&QL96=I="!O(&5N=.AS
M(&5L(&UI<W-A=&=E+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<W"FUS
M9VED(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP
M;W-E('!A9V4B"FUS9W-T<B`B16P@;F]M('%U92!S)VAA(&0G=71I;&ET>F%R
M(&5N(&5N;&QAYV%R(&%M8B!#<F5A<B!PX&=I;F$B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C$R,S$*;7-G:60@(E1H92!O<&5N<W-L(&UO9'5L
M92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA
M<W,N(@IM<V=S='(@(D5S(&YE8V5S<VET82!E;"!M\F1U;"!O<&5N<W-L('!E
M<B!A(&QA(&-L87-S92!(;W)D95]#<GEP=%]S;6EM92XB"@HC.B!L:6(O2&]R
M9&4O4')E9G,N<&AP.C(X-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@
M<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@
M:71S(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM=6T@86QL;W=A8FQE('-I
M>F4B"FUS9W-T<B`B(@HB3F\@<R=H82!P;V=U="!D97-A<B!L82!P<F5F97+H
M;F-I82!<(B5S7"(@<&5R<77H(&QA(&EN9F]R;6%C:?,@<75E(&-O;G1E;FEA
M("(*(G-U<&5R879A(&QA(&UI9&$@;>!X:6UA('!E<FUE<V$N(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R(&QI8B](;W)D92]-
M24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]W96)C<'`N<&AP.C,W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]S
M<F-H:6=H;&ET92YP:'`Z,S<@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)P;2YP
M:'`Z,S(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS
M-2!L:6(O2&]R9&4O34E-12]6:65W97(O9&5B+G!H<#HS,@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D
M871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(@IM
M<V=S='(@(B(*(DYO(',G:&$@=')O8F%T(&5N(&5L('-I<W1E;6$@96P@<')O
M9W)A;6$@=7-A="!P97(@=FES=6%L:71Z87(@87%U97-T('1I<'5S("(*(F1E
M(&1A9&5S("@E<RDN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L969T
M('-I9&5S(&]N;'DB"FUS9W-T<B`B3F]MZ7,@96QS(&-O<W1A=',@9')E="!I
M(&5S<75E<G)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED92!O
M;FQY(@IM<V=S='(@(DYO;>ES(&5L(&-O<W1A="!D<F5T(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B
M4R=H82!S=7!R:6UI="!E;"!S97)V:61O<B!<(B5S7"(N(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(E,G
M:&$@9&5S870@96P@<V5R=FED;W(@7"(E<UPB+B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E
M<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N(@IM<V=S='(@(E,G:&$@96QI
M;6EN870@;&$@<V]LMVQI8VET=60@9"=A;'1A(&1E("5S+B(*"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70N<&AP.C(Y,`HC+"!F=7IZ>0IM<V=I9"`B5&AE
M('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(DYO(&5X
M:7-T96EX(&QA(&9I;&$@97-P96-I9FEC861A+B(*"B,Z(&QI8B]61E,O<W%L
M+G!H<#HQ,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F
M:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B3F\@97AI<W1E
M:7@@;"=A<GAI=2!T96UP;W)A;"!<(B5S7"(N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE
M('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B3F]MZ7,@96QS
M(&-O<W1A=',@<W5P97)I;W(@:2!I;F9E<FEO<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G:60@(E1H
M92!T;W`@<VED92!O;FQY(@IM<V=S='(@(DYO;>ES(&5L(&-O<W1A="!S=7!E
M<FEO<B(*"B,Z(&QI8B](;W)D92]$871A+G!H<#HS,#<*;7-G:60@(E1H92!U
M<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P
M+B(*;7-G<W1R(")3)VAA;B!P97)D=70@;&5S(&1A9&5S(&-A<G)E9V%D97,@
M9&5S(&1E;"!P87,@86YT97)I;W(N(@H*(SH@;&EB+TAO<F1E+T1A=&$O='-V
M+G!H<#HQ-S(@;&EB+TAO<F1E+T1A=&$O8W-V+G!H<#HR-#`*;7-G:60@(E1H
M92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`B
M3F\@<R=H82!P;V=U="!D97-A<B!L)V%R>&EU(&-A<G)E9V%T+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-38*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$P-R!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$Q"FUS9VED(")4
M:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T
M<B`B16P@8FQO8R!W96%T:&5R+F-O;2!N;R!E<W3@(&1I<W!O;FEB;&4N(@H*
M(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5M97,@9&ER96-T;W)Y("<E<R<@;F]T(&9O=6YD+B(*
M;7-G<W1R(").;R!S)VAA('1R;V)A="!E;"!D:7)E8W1O<FD@5&AE;65S("<E
M<R<N(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ-S@*;7-G:60@(E1H
M97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92XB"FUS9W-T<B`B3F\@:&D@
M:&$@8V%P(&]P8VGS(&1I<W!O;FEB;&4N(@H*(SH@;&EB+TAO<F1E+TU)344O
M0V]N=&5N=',N<&AP.C,T,`IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H
M870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(DYO(&AI(&AA
M(&-A<"!P87)T('%U92!E<R!P=6=U:2!M;W-T<F%R(&5N(&SM;FEA(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$T,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L
M9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S
M="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*(D%Q=65S="!C86UP
M(&-O;G3I(&UA<W-A(&-A<N!C=&5R<RX@2&5U(&EN=')O9'7O="`E<R!C87+@
M8W1E<G,@:2!N)VAE=2`B"B)D)VEN=')O9'5I<B!M96YY<R!D92`E<RXB"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`V,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!D;V5S;B=T('EE="!E>&ES="!A(&AE;'`@9FEL92!F;W(@)7,N
M(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-3,*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG("<E<R<@
M=&\@=&AE('-Y<W1E;2X@)7,N(@IM<V=S='(@(DAI(&AA(&AA9W5T('5N('!R
M;V)L96UA(&5N(&%F96=I<B`G)7,G(&%L('-I<W1E;6$Z("5S(@H*(SH@861M
M:6XO=7-E<BYP:'`Z-S,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A('!R;V)L96T@861D:6YG("<E<R<@=&\@=&AE('-Y<W1E;3H@
M)7,B"FUS9W-T<B`B2&D@:&$@:&%G=70@=6X@<')O8FQE;6$@96X@869E9VER
M("<E<R<@86P@<VES=&5M83H@)7,B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C(*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L
M96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B`G)7,G(&9R;VT@=&AE('-Y<W1E
M;3H@(@IM<V=S='(@(B(*(DAI(&AA(&AA9W5T('5N('!R;V)L96UA(&5N(&5S
M8F]R<F%R(&1E;"!S:7-T96UA(&QE<R!D861E<R!D92!L)W5S=6%R:2`G)7,G
M+B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#,*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@)R5S)R!F
M<F]M('1H92!S>7-T96TZ("(*;7-G<W1R(")(:2!H82!H86=U="!U;B!P<F]B
M;&5M82!E;B!S=7!R:6UI<B`G)7,G(&1E;"!S:7-T96UA.B`B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ-3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@)R5S)SH@)7,B"FUS9W-T<B`B
M2&D@:&$@:&%G=70@=6X@<')O8FQE;6$@96X@86-T=6%L:71Z87(@)R5S)SH@
M)7,B"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.#<X"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB"FUS9W-T<B`B2&D@:&$@:&%G
M=70@=6X@<')O8FQE;6$@96X@8V%R<F5G87(@;"=A<GAI=3H@;F\@<R=H82!C
M87)R96=A="`E<RXB"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.#@S"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE
M(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@
M(B(*(DAI(&AA(&AA9W5T('5N('!R;V)L96UA(&5N(&-A<G)E9V%R(&PG87)X
M:74Z(&5L("5S(&5R82!S=7!E<FEO<B!A(&QA(&UI9&$@(@HB;>!X:6UA('!E
M<FUE<V$@*"4@8GET97,I+B(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HX
M.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE
M;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I
M86QL>2!U<&QO861E9"XB"FUS9W-T<B`B(@HB2&D@:&$@:&%G=70@=6X@<')O
M8FQE;6$@96X@8V%R<F5G87(@;"=A<GAI=3H@;F]MZ7,@<R=H82!C87)R96=A
M="!P87)C:6%L;65N="`B"B)E;"`E<RXB"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B4R=H82!P
M<F]D=>]T('5N(&5R<F]R(&5N(&UO<W1R87(@87%U97-T82!P87)T(&1E;"!M
M:7-S871G92(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,SD@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A
M+B(*;7-G<W1R(")3)VAA('!R;V1U[W0@=6X@97)R;W(@96X@:6UP;W)T87(@
M;&5S(&1A9&5S(&1E(&-O;G1A8W1E+B(*"B,Z(&QI8B](;W)D92]$871A+VEM
M8RYP:'`Z,S$*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@
M=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R(")3)VAA('!R;V1U[W0@=6X@
M97)R;W(@96X@:6UP;W)T87(@;&5S(&1A9&5S(&E#86QE;F1A<BXB"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Y"FUS9VED("(B"B)4:&5R92!W87,@
M86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y
M;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B(@HB
M4R=H82!P<F]D=>]T('5N(&5R<F]R(&5N(&5L(&9O<FUU;&%R:2!D92!C;VYF
M:6=U<F%C:?,N(%!O='-E<B!U<R!H974@(@HB9&5S8W5I9&%T(&0G96UP;&5N
M87(@=6X@8V%M<"!N96-E<W-A<FDN(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C$Q,#<@<&\O=')A;G-L871I;VXN<&AP.C$Q,3,@<&\O=')A;G-L871I;VXN
M<&AP.C$R-#4*(SH@<&\O=')A;G-L871I;VXN<&AP.C$R-3$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&]P96YI;F<@=&AE
M(&9I;&4@)7,N(%1R>2!R=6YN:6YG('1R86YS;&%T:6]N+G!H<"!W:71H('1H
M92`B"B)F;&%G("UD('1O('-E92!A;GD@97)R;W(@;65S<V%G97,@9G)O;2!T
M:&4@>&UL('!A<G-E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S-PIM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R
M<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N
M8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*
M(E,G:&$@<')O9'7O="!U;B!E<G)O<B!E;B!E>&5C=71A<B!L82!F=6YC:?,@
M97-P96-I9FEC861A(&1E(&QA(&QL:6)R971A("(*(F0G861R96-E<RX@5&]R
M;F5U+6AO(&$@:6YT96YT87(@;>ES('1A<F0N(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N
M(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T
M<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(E,G:&$@<')O9'7O="!U;B!E
M<G)O<B!E;B!A8W1U86QI='IA<B!E;',@9&5T86QL<R!D92!C;VYT86-T92X@
M5&]R;F5U+6AO(&$@(@HB:6YT96YT87(@;>ES('1A<F0N(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@
M4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB4R=H82!P<F]D
M=>]T('5N(&5R<F]R(&5N(&%C='5A;&ET>F%R(&QA(&QL:7-T82!D92!D:7-T
M<FEB=6-I\RX@5&]R;F5U+6AO(&$@(@HB:6YT96YT87(@;>ES('1A<F0N(@H*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T.`IM<V=I9"`B
M5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L
M9&5R<RXB"FUS9W-T<B`B07%U97-T('-E<G9I9&]R($E-05`@;F\@<&5R;65T
M(&PG^G,@9&4@8V%R<&5T97,@8V]M<&%R=&ED97,N(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@
M87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(DYO
M('-E;6)L82!Q=64@<VEG=6D@=6X@87)X:74@<F%R(';@;&ED+B(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O
M97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R
M(").;R!S96UB;&$@<75E('-I9W5I('5N(&%R>&EU('II<"!VX&QI9"XB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$T,PIM<V=I9"`B5&AI<R!D;V5S(&YO
M="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@(DYO
M('-E;6)L82!Q=64@87%U97-T(&[Z;65R;R!D92!T87)G971A('-I9W5I(';@
M;&ED+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T
M"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA
M=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R
M("(B"B)!<75E<W0@8V]N=')O;&%D;W(@<&5R;65T(&5N=FEA<B!M:7-S871G
M97,@<&5R(&UI=&K@(&1E(&QA('!A<W-A<F5LMVQA("(*(D-L:6-K871E;&P@
M*&AT='`Z+R]C;&EC:V%T96QL+F-O;2DL('5T:6QI='IA;G0@;&$@05!)($A4
M5%`B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$T"FUS
M9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E
M<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN
M8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB
M07%U97-T(&-O;G1R;VQA9&]R('!E<FUE="!E;G9I87(@;6ES<V%T9V5S('!E
M<B!M:71JX"!D92!L82!P87-S87)E;+=L82`B"B)S;7,R96UA:6P@*&AT='`Z
M+R]S;7,R96UA:6PN8V]M*2!U=&EL:71Z86YT(&QA($%022!(5%10(@H*(SH@
M;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX,`IM<V=I9"`B
M(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA
M(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@(@HB9V%T97=A>2P@
M;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I
M;"!A8V-O=6YT('=I=&@@(@HB5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N
M,3DP+FET*2XB"FUS9W-T<B`B(@HB07%U97-T(&-O;G1R;VQA9&]R('!E<FUE
M="!E;G9I87(@;6ES<V%T9V5S('!E<B!V:6$@9&4@4TU44"!A('1R87;I<R!D
M92!L82`B"B)P87-S87)E;+=L82!6;V1A9F]N92!D)TETX&QI82P@;F]MZ7,@
M82!N^FUE<F]S(%9O9&%F;VYE+B!#86P@=&5N:7(@=6X@8V]M<'1E("(*(F1E
M(&-O<G)E=2!E;&5C='+R;FEC(&%M8B!6;V1A9F]N92!D)TETX&QI82`H:'1T
M<#HO+W=W=RXQ.3`N:70I+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY-S@@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$P-3<@;&EB+TAO<F1E+T9O<FTN<&AP.C$P
M.#8*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,34@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$Q.#(@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-38*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$R.3`@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,#,@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$U-C(*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-#,@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-3@@;&EB+TAO<F1E+T9O<FTN<&AP.C(P
M,#4*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,CD@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(P-S@@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q-#D*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(R,C$@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,#@@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(T-3(*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(V-34@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(X,C8@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q
M,S4*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,W,C(@;&EB+TAO<F1E+T9O<FTN
M<&AP.C,W,S`*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S
M='(@(LES(&YE8V5S<V%R:2!A<75E<W0@8V%M<"XB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3`V-0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT
M86EN(&EN=&5G97)S+B(*;7-G<W1R(")!<75E<W0@8V%M<"!N;VWI<R!P;W0@
M8V]N=&5N:7(@;F]M8G)E<R!E;G1E<G,N(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(T,38*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N
M=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(D%Q=65S="!C86UP(&YO
M;>ES('!O="!C;VYT96YI<B!N;VUB<F5S(&D@96QS(&1O<R!P=6YT<RXB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`Y-`IM<V=I9"`B5&AI<R!F:65L9"!M
M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B07%U97-T
M(&-A;7`@;F]MZ7,@<&]T(&-O;G1E;FER('9A;&]R<R!O8W1A;',N(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE;&0@;75S
M="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G
M97)S(@IM<V=S='(@(B(*(D%Q=65S="!C86UP(&AA(&1E('-E<B!U;F$@;&QI
M<W1A(&1E(&YO;6)R97,@96YT97)S('-E<&%R871S('!E<B!C;VUE<R!O("(*
M(F5S<&%I<RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3@Y"FUS9VED(")4
M:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@(D%Q
M=65S="!C86UP(&AA(&1E('-E<B!U;B!N^FUE<F\@=N!L:60N(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(X,S0*;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S
M="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L
M(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T<B`B(@HB07%U97-T
M(&-A;7`@:&$@9&4@8V]N=&5N:7(@=6X@8V]D:2!D92!C;VQO<B!D92!F;W)M
M870@4D="(&AE>&%D96-I;6%L+"!P97(@(@HB97AE;7!L92`G(S$R,S1A9B<N
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C4V,0IM<V=I9"`B5&AI<R!F;W)M
M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R(")*82!S)VAA
M('!R;V-E<W-A="!A<75E<W0@9F]R;75L87)I+B(*"B,Z('1E;7!L871E<R]H
M96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@
M)7,N(@IM<V=S='(@(D%I>/(@Z7,@)7,N(@H*(SH@;&EB+TAO<F1E+TMO;&%B
M+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO
M;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U
M('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD
M<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S
M=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@
M(B(*(D%I>/(@Z7,@=6X@;V)J96-T92!D92!+;VQA8B!'<F]U<'=A<F4N(%!E
M<B!V:7-U86QI='IA<B!A<75E<W0@;V)J96-T92P@=7,@(@HB8V%L('5N(&-L
M:65N="!D92!C;W)R974@96QE8W1R\FYI8R!Q=64@861M971I(&5L(&9O<FUA
M="!D92!+;VQA8B!'<F]U<'=A<F4N("(*(E!E<B!T96YI<B!A8V/I<R!A('5N
M82!L;&ES=&$@9"=A<75E<W1S(&-L:65N=',@9&4@8V]R<F5U(&5L96-T<O)N
M:6,L('9I<VET974@(@HB)7,B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT
M<RYP:'`Z-3@W"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@;65S<V%G92!W
M87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N
M('EO=7(@;W=N+B(*;7-G<W1R("(B"B)!<75E<W0@;6ES<V%T9V4@=F$@<V5R
M(&5S8W)I="!A;6(@=6X@:F]C(&1E(&-A<N!C=&5R<R`H)7,I(&1I9F5R96YT
M(&1E;"`B"B)V;W-T<F4N(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ
M,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*
M;7-G<W1R(")!<75E<W0@;OIM97)O(&AA(&1E('-E<B!C;VT@82!M[6YI;2!U
M;B`Q+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,S`T"FUS9VED(")4:&ES
M('-C<FEP="!M=7-T(&)E(')U;B!F<F]M('1H92!C;VUM86YD(&QI;F4N(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]G>FEP+G!H<#HT-0IM
M<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z
M:7`@9FEL97,N(@IM<V=S='(@(D%Q=65S="!S97)V:61O<B!N;R!P;W0@9&5S
M8V]M<')I;6ER(&%R>&EU<R!Z:7`@:2!G>FEP+B(*"B,Z(&QI8B](;W)D92]2
M96=I<W1R>2YP:'`Z,30W"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT
M;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(D%Q=65S="!S:7-T96UA(&5S=.`@
M9&5S86-T:79A="!A8W1U86QM96YT+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]5
M22YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N
M(@IM<V=S='(@(D%Q=65S="!V86QO<B!H82!D92!S97(@=6X@;OIM97)O+B(*
M"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@
M(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W
M:6YD;W<B"FUS9W-T<B`B07%U97-T82!F:6YE<W1R82!S)VAA(&1E(&-R:61A
M<B!D97,@9"=U;F$@9FEN97-T<F$@9"=O<&-I;VYS(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E1H=6YD97(B
M"FUS9W-T<B`B5')O(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R
M,`IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R(")4:7%U971S(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(T,C8*;7-G:60@(E1I;64B"FUS9W-T<B`B2&]R82(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,#8*;7-G:60@(E1I;64@
M5')A8VMI;F<B"FUS9W-T<B`B0V]N=')O;"!D92!T96UP<R(*"B,Z(&QI8B]"
M;&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`B
M1F]R;6%T(&AO<F%R:2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3,W"FUS
M9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R(")396QE8V-I\R!D92!T96UP
M<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,S`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@(E1I;6]R($]R:65N
M=&%L(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@
M;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@
M(E3M=&]L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R(")4[71O
M;"`H<NAT;VP@:6YD:6-A9&]R(&1E(&9U;F-I\RDZ(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@
M(D$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C(V
M"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W
M;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y("(*(G=H
M:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"B)097(@<V5L96-C:6]N87(@9&EV
M97)S;W,@96QE;65N=',L(&UA;G1I;F=U974@<&ET:F%D82!L82!T96-L82!#
M;VYT<F]L("A00RD@(@HB;R!#;VUM86YD("A-86,I(&UE;G1R92!C;&EQ=65U
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#`*;7-G:60@
M(E1O9&%Y(@IM<V=S='(@(D%V=6DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R
M8V4B"FUS9W-T<B`B0V]M;75T974@;&$@9F]N="!(5$U,(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,C,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,PIM<V=I9"`B
M5&]G;R(*;7-G<W1R(")4;V=O(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(R-@IM<V=I9"`B5&]K96QA=2(*;7-G<W1R
M(")4;VME;&%U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X
M,@IM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B1&5MX"(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,CD*;7-G:60@(E1O
M;F=A(@IM<V=S='(@(E1O;F=A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<W"FUS9VED(")4;W`B"FUS9W-T<B`B
M4W5P97)I;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.CDS"FUS9VED(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@(DUA
M<F,@<W5P97)I;W(@*%]S=7!E<FEO<BDB"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z-C4W"B,L(&9U>GIY"FUS9VED(")4<F%N<VQA=&5D(@IM<V=S='(@(E1R
M861U8V-I;VYS(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S"FUS9VED
M(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`B5')A9'5C8VEO;G,B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(R-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,R"FUS9VED
M(")4<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S='(@(E1R:6YI=&%T(&D@5&]B
M86=O(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W.30*;7-G:60@(E1R=64@
M;W(@9F%L<V4B"FUS9W-T<B`B5F5R:71A="!O(&9A;',B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*
M;7-G<W1R(")$="XB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C(X"FUS9VED(")4=6YI<VEA(@IM<V=S='(@(E1U;NUS
M:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C,Q"FUS9VED(")4=7)K97DB"FUS9W-T<B`B5'5R<75I82(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED(")4=7)K:7-H("A)4T\M.#@U
M.2TY*2(*;7-G<W1R(")4=7)C("A)4T\M.#@U.2TY*2(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C<*;7-G:60@(E1U
M<FMM96YI<W1A;B(*;7-G<W1R(")4=7)K;65N:7-T86XB"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(S,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(P"FUS9VED(")4
M=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B26QL97,@5'5R:W,@
M:2!#86EC;W,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C,S"FUS9VED(")4=79A;'4B"FUS9W-T<B`B5'5V86QU(@H*
M(SH@;&EB+TAO<F1E+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO
M:6-E.B`B"FUS9W-T<B`B5&5C;&5G974@;&$@=F]S=')A(&]P8VGS.B`B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4V"FUS9VED(")5+E8N
M(&EN9&5X.B`B"FUS9W-T<B`BS6YD97@@558Z("(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP
M.C$W"FUS9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4T,`IM<V=I9"`B55),(&9O<B!Y;W5R('-C
M<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S='(@(E523"!D96P@
M=F]S=')E(&EN9F]R;64@9&4@;"=E<W1A="!D92!T<F%M97-A(&1E(&QA('-E
M<?SH;F-I82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.3<*;7-G:60@(E523#HB"FUS9W-T<B`B55),.B(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S<*;7-G:60@
M(E5G86YD82(*;7-G<W1R(")59V%N9&$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,V"FUS9VED(")5:W)A:6YE(@IM
M<V=S='(@(E5C<F'O;F$B"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,S-0IM<V=I
M9"`B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").
M;R!S)VAA('!O9W5T(&%C8V5D:7(@86P@9&ER96-T;W)I(%9&4RXB"@HC.B!L
M:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B;&4@=&\@
M861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*
M;7-G<W1R(").;R!S)VAA('!O9W5T(&%F96=I<B!MZ7,@9&%D97,@9&4@;"=U
M<W5A<FD@96X@969E8W1U87(@;"=A;'1A+B(*"B,Z(&QI8B]61E,O9G1P+G!H
M<#HS,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P
M97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DYO(',G
M:&$@<&]G=70@8V%N=FEA<B!E;"!P97)M[7,@9&4@;"=A<GAI=2!61E,@7"(E
M<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S`X(&QI8B]61E,O;75S<6PN
M<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E
M('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R(").;R!S
M)VAA('!O9W5T(&-A;G9I87(@96P@<&5R;>US(&1E(&PG87)X:74@5D93("5S
M+R5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HV-S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B3F\@<R=H
M82!P;V=U="!C86YV:6%R(&$@)7,N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<W%L
M+G!H<#HS-S$*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V
M97(N(@IM<V=S='(@(DYO(',G:&$@<&]G=70@8V]N;F5C=&%R(&%L('-E<G9I
M9&]R(%-13"XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S4V"FUS9VED(")5;F%B
M;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`B3F\@<R=H82!P;V=U
M="!C;VYN96-T87(@86UB(%-33"XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$U
M."!L:6(O5D93+V9I;&4N<&AP.C$V,R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ
M.#@*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3DS(&QI8B]61E,O<W%L7V9I
M;&4N<&AP.C(P,0IM<V=I9"`B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM
M<V=S='(@(DYO(',G:&$@<&]G=70@8V]P:6%R(&PG87)X:74@5D93+B(*"B,Z
M(&QI8B]61E,O9G1P+G!H<#HS,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B
M3F\@<R=H82!P;V=U="!C<F5A<B!E;"!D:7)E8W1O<FD@5D93(%PB)7-<(BXB
M"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(W-R!L:6(O5D93+VUU<W%L+G!H<#HR
M-3@@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C0X"FUS9VED(")5;F%B;&4@=&\@
M8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYO(',G:&$@<&]G=70@
M8W)E87(@96P@9&ER96-T;W)I(%9&4RXB"@HC.B!L:6(O5D93+VUU<W%L+G!H
M<#HQ,C0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S
M='(@(DYO(',G:&$@<&]G=70@8W)E87(@;"=A<GAI=2!61E,N(@H*(SH@;&EB
M+U9&4R]S;6(N<&AP.C(X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@8W)E871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(").;R!S)VAA
M('!O9W5T(&-R96%R(&QA(&-A<G!E=&$@5D93(%PB)7-<(BXB"@HC.B!L:6(O
M5D93+V9I;&4N<&AP.C$Y.`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T
M>2!61E,@9FEL92XB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!C<F5A<B!U;B!A
M<GAI=2!61E,@8G5I="XB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O=&%R+G!H
M<#HW-B!L:6(O2&]R9&4O0V]M<')E<W,O9WII<"YP:'`Z-SD*;7-G:60@(E5N
M86)L92!T;R!D96-O;7!R97-S(&1A=&$N(@IM<V=S='(@(DYO(',G:&$@<&]G
M=70@9&5S8V]M<')I;6ER(&QE<R!D861E<RXB"@HC.B!L:6(O5D93+V9T<"YP
M:'`Z,C,V(&QI8B]61E,O<VUB+G!H<#HR,C0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@
M;F]T(&5M<'1Y+B(*;7-G<W1R(").;R!S)VAA('!O9W5T('-U<')I;6ER(%PB
M)7-<(BP@96P@9&ER96-T;W)I(&YO(&5S=.`@8G5I="XB"@HC.B!L:6(O5D93
M+V9I;&4N<&AP.C(U-"!L:6(O5D93+W-Q;"YP:'`Z,S$T(&QI8B]61E,O;75S
M<6PN<&AP.C,Q,0HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS,C8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C
M=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!S=7!R
M:6UI<B`E<RP@96P@9&ER96-T;W)I(&YO(&5S=.`@8G5I="XB"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C<Y(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3D*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)R5S
M)SH@)7,N(@IM<V=S='(@(DYO(',G:&$@<&]G=70@<W5P<FEM:7(@)R5S)SH@
M)7,N(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S0P(&QI8B]61E,O<W%L
M7V9I;&4N<&AP.C,T-`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER
M96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R(").;R!S)VAA('!O9W5T('-U
M<')I;6ER(&5L(&1I<F5C=&]R:2!61E,@9&4@;6%N97)A(')E8W5R<VEV82XB
M"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(V,"!L:6(O5D93+VUU<W%L+G!H<#HS
M,C(@;&EB+U9&4R]M=7-Q;"YP:'`Z,S,U"B,Z(&QI8B]61E,O;75S<6PN<&AP
M.C,T,R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS,S8*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F\@<R=H82!P;V=U
M="!S=7!R:6UI<B!E;"!D:7)E8W1O<FD@5D93+B(*"B,Z(&QI8B]61E,O<W%L
M+G!H<#HS,SD@;&EB+U9&4R]S<6PN<&AP.C,U,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G
M<W1R(").;R!S)VAA('!O9W5T('-U<')I;6ER(&5L(&1I<F5C=&]R:2!61E,Z
M("5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HQ-S`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S
M='(@(DYO(',G:&$@<&]G=70@<W5P<FEM:7(@;"=A<GAI=2!61E,@7"(E<UPB
M+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C(V(&QI8B]61E,O<W%L+G!H<#HR
M,3`@;&EB+U9&4R]M=7-Q;"YP:'`Z,38W"B,Z(&QI8B]61E,O;75S<6PN<&AP
M.C$X,"!L:6(O5D93+VUU<W%L+G!H<#HQ.#<@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z,S<P"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,W.`IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS9W-T<B`B3F\@<R=H82!P;V=U
M="!S=7!R:6UI<B!L)V%R>&EU(%9&4RXB"@HC.B!L:6(O5D93+W-M8BYP:'`Z
M,C0T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(DYO(',G:&$@<&]G=70@<W5P<FEM
M:7(@;&$@8V%R<&5T82!61E,@7"(E<UPB+B(*"B,Z(&QI8B]61E,O<W%L+G!H
M<#HS,C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R(").;R!S)VAA('!O9W5T('-U
M<')I;6ER(%9&4R!D92!M86YE<F$@<F5C=7)S:79A.B`E<RXB"@HC.B!L:6(O
M5D93+V9T<"YP:'`Z-S(P"FUS9VED(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U
M<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(&1E=&5R
M;6EN87(@96P@9&ER96-T;W)I(&%C='5A;"XB"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C8P,PIM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R
M=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R(").;R!S)VAA('!O9W5T(&5X=')E
M=7)E(&5L<R!D971A;&QS(&1E;"!C97)T:69I8V%T+B(*"B,Z(&QI8B].970O
M24U34"YP:'`Z-#4Q(&QI8B].970O24U34"]!=71H+G!H<#HQ,3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@
M;V8@)7,N(@IM<V=S='(@(DYO(',G:&$@<&]G=70@8V%R<F5G87(@;&$@9&5F
M:6YI8VGS(&1E("5S+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3(Y(&QI8B]6
M1E,O9FEL92YP:'`Z,3,T(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$U.`HC.B!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-C,*;7-G:60@(E5N86)L92!T;R!M;W9E
M(%9&4R!F:6QE+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(&UO=7)E(&PG87)X
M:74@5D93+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW-B!L:6(O5D93+W-M8BYP
M:'`Z.3,@;&EB+U9&4R]S;6(N<&AP.C$P,@HC.B!L:6(O5D93+W-M8BYP:'`Z
M-C4P"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!O8G)I<B!L)V%R
M>&EU(%9&4R!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR,#4@;&EB
M+U9&4R]S<6Q?9FEL92YP:'`Z,3(R(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$R
M-0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N
M(@IM<V=S='(@(DYO(',G:&$@<&]G=70@;V)R:7(@;"=A<GAI=2!61E,@<&5R
M(&5S8W)I=7)E+6AI+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-C<@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z-S(*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F
M:6QE+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(&]B<FER(&PG87)X:74@5D93
M+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C0U"FUS9VED
M(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@
M(DYO(',G:&$@<&]G=70@;V)R:7(@;"=A<GAI=2!C;VUP<FEM:70N(@H*(SH@
M;&EB+U9&4RYP:'`Z.#4U"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL
M92`H9FEL97-I>F4H*2!F86EL960I+B(*;7-G<W1R("(B"B).;R!S)VAA('!O
M9W5T(&QL96=I<B!L)V%R>&EU(%9&4R`H;&$@;6ED82!D92!L)V%R>&EU*"D@
M:&$@9&]N870@97)R;W(I+B(*"B,Z(&QI8B]61E,N<&AP.C@X-@IM<V=I9"`B
M56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D
M*2XB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!L;&5G:7(@;"=A<GAI=2!61E,@
M*&=E=$9I;&53:7IE*"D@:&$@9&]N870@97)R;W(I+B(*"B,Z(&QI8B](;W)D
M92]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`IM<V=I9"`B56YA8FQE('1O
M(')E860@9FEL93H@(@IM<V=S='(@(DYO(',G:&$@<&]G=70@;&QE9VER(&PG
M87)X:74Z("XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C4Y,@IM<V=I9"`B56YA
M8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R(").
M;R!S)VAA('!O9W5T(&QL96=I<B!E;"!D:7)E8W1O<FD@87)R96P@9&4@5D93
M+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3`V-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO
M;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B(@HB3F\@<R=H82!P
M;V=U="!C86YV:6%R(&5L(&YO;2!D92`E<R!P97(@)7,Z(&QA(&-A<G!E=&$@
M9&4@9&5S=&EN86-I\R!J82`B"B)E>&ES=&5I>"(*"B,Z(&QI8B]61E,O<W%L
M7V9I;&4N<&AP.C(X-0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER
M96-T;W)Y+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(&-A;G9I87(@96P@;F]M
M(&1E;"!D:7)E8W1O<FD@5D93+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HR-3$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER
M96-T;W)Y.B`E<RXB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!C86YV:6%R(&5L
M(&YO;2!D96P@9&ER96-T;W)I(%9&4SH@)7,N(@H*(SH@;&EB+U9&4R]F='`N
M<&AP.C(X,2!L:6(O5D93+W-M8BYP:'`Z,C8W"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M(").;R!S)VAA('!O9W5T(&-A;G9I87(@96P@;F]M(&1E(&PG87)X:74@5D93
M(%PB)7-<(BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C4S,R!L:6(O5D93+VUU
M<W%L+G!H<#HR,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E
M;F%M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!C
M86YV:6%R(&5L(&YO;2!D92!L)V%R>&EU(%9&4R`E<R\E<RXB"@HC.B!L:6(O
M5D93+W-Q;"YP:'`Z,C0U(&QI8B]61E,O;75S<6PN<&AP.C(Q,R!L:6(O5D93
M+VUU<W%L+G!H<#HT-3(*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C<W(&QI
M8B]61E,O<W%L7V9I;&4N<&AP.C(Y,PIM<V=I9"`B56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92XB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!C86YV:6%R(&5L
M(&YO;2!D92!L)V%R>&EU(%9&4RXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]M
M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F<R<N
M(@IM<V=S='(@(DYO(',G:&$@<&]G=70@97AE8W5T87(@)VUK:7-O9G,G+B(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED
M(")5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N="(*;7-G
M<W1R(").;R!S)VAA('!O9W5T('1R861U:7(@87%U97-T(&1O8W5M96YT(&1E
M(%=O<F0B"@HC.B!L:6(O5D93+V9T<"YP:'`Z,3(R(&QI8B]61E,O9G1P+G!H
M<#HQ,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!E<V-R:75R
M92!L)V%R>&EU(%9&4R!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ
M,3(*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A
M:6QE9"DN(@IM<V=S='(@(B(*(DYO(',G:&$@<&]G=70@97-C<FEU<F4@;"=A
M<GAI=2!61E,@*"-S)VAA('!R;V1U[W0@=6X@97)R;W(@96X@8V]P:6%R+6QO
M*"D@(RDN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR,#D@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z,3,P(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$S-0IM<V=I9"`B
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@(DYO(',G
M:&$@<&]G=70@97-C<FEU<F4@;&5S(&1A9&5S(&1E(&PG87)X:74@5D93+B(*
M"B,Z(&QI8B]61E,N<&AP.C@V,0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(*;7-G<W1R(").;R!S
M)VAA('!O9W5T(&5S8W)I=7)E(&PG87)X:74@5D93+"!S92!S=7!E<F%RX"!L
M)V5S<&%I(&1I<W!O;FEB;&4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@
M(E-U8G)A=&QL870B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHV"FUS
M9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B1&5S9NES(&5L<R!C86YV:7,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S
M"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R(")$97-F
MX"!L82!D87)R97)A(&%C8VGS(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C(R,R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,SDP"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N
M(&-O;FYE8W1I;VXZ("(*;7-G<W1R(")%;"!S97)V:61O<B!H82!D;VYA="!U
M;F$@<F5S<&]S=&$@:6YE<W!E<F%D82!E;B!C;VYN96-T87(M<V4Z("(*"B,Z
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,0HC.B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S<X(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS.#0*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V
M97(@=&\Z("(*;7-G<W1R(")%;"!S97)V:61O<B!H82!D;VYA="!U;F$@<F5S
M<&]S=&$@:6YE<W!E<F%D82!A.B`B"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T
M96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHV-`IM<V=I9"`B56YF:6QE9"(*;7-G<W1R(")3
M96YS92!C871E9V]R:6$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM
M<V=I9"`B56YI8V]D92`H551&+3@I(@IM<V=S='(@(E5N:6-O9&4@*%541BTX
M*2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4V(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$W"FUS9VED(")5;FET960@07)A8B!%;6ER871E<R(*;7-G<W1R(")5;FGS
M(&1E;',@16UI<F%T<R#`<F%B<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(S.`IM<V=I9"`B56YI=&5D($MI;F=D;VTB
M"FUS9W-T<B`B4F5G;F4@56YI="(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR-#`*;7-G:60@(E5N:71E9"!3=&%T97,B
M"FUS9W-T<B`B17-T871S(%5N:71S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S.0IM<V=I9"`B56YI=&5D(%-T871E
M<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S='(@(DEL;&5S(%!E<FEF
MZ')I<75E<R!-96YO<G,@9&5L<R!%<W1A=',@56YI=',B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-CD@;&EB+T)L;V-K+VUE=&%R+G!H<#HV
M.0IM<V=I9"`B56YI=',B"FUS9W-T<B`B56YI=&%T<R(*"B,Z(&QI8B](;W)D
M92]#<GEP="]P9W`N<&AP.C0Q."!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT
M,3D*;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`B1&5S8V]N96=U="(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED(")5;FMN
M;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@(F%P:6US
M9VED("AI9&5N=&EF:6-A9&]R(&1E;"!M:7-S871G92!D92!L82!!4$DI(&1E
M<V-O;F5G=70N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.3@*;7-G:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E
M($E$*2XB"FUS9W-T<B`B0VQI;7-G:60@9&5S8V]N96=U="`H:61E;G1I9FEC
M861O<B!D96P@;6ES<V%T9V4@9&5L(&-L:65N="DN(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C$U,#$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N
M:VYO=VX@8V]M;6%N9#H@)7,B"FUS9W-T<B`B1&5S8V%R<F5G87(@)7,B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Q"FUS9VED(")5;FMN
M;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(")3)VAA('!R;W!O<F-I
M;VYA="!U;F$@=6)I8V%C:?,@9&5S8V]N96=U9&$N(@H*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@(E5N:VYO=VX@=7-E
M<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S='(@(DYO;2!D)W5S=6%R:2!O(&-O
M;G1R87-E;GEA(&1E<V-O;F5G=71S+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B56YL:6YK
M('1H92!C=7)R96YT(&5L96UE;G0B"FUS9W-T<B`B1&5S96YL;&'G87(@;"=E
M;&5M96YT(&%C='5A;"(*"B,Z(&QI8B](;W)D92])9&5N=&ET>2YP:'`Z,CDV
M"FUS9VED(")5;FYA;65D(@IM<V=S='(@(E-E;G-E(&YO;2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*
M(E5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO
M4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS
M+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL
M82YO<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP
M="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@HB3&5S('-E
M<?SH;F-I97,@<V5N<V4@<&5R;6ES;W,@;F\@<&]D96X@86-C961I<B!A(%)E
M=&%L;&%R+T-O<&EA<B]%;F=A;GAA<B!D92`B"B)M86YE<F$@<')O9W)A;>!T
M:6-A('!E<B!R86]N<R!D92!S96=U<F5T870N($-L:7%U974@96X@1"=A8V]R
M9"!P97(@(@HB=FES=6%L:71Z87(@=6YA(&YO=&$@=.AC;FEC82!A(&UO>FEL
M;&$N;W)G('%U92!U<R!M;W-T<F$@8V]M('!O9&5U(&9E<B!Q=64@(@HB=6YA
M('-E<?SH;F-I82!A8V-E9&5I>&D@86P@<&]R=&$M<F5T86QL<RX@(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M,@IM<V=I9"`B56YS970@8V]L;W(B"FUS9W-T<B`B16QI;6EN87(@96P@8V]L
M;W(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8X-B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.CDR-@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.CDS,@IM<V=I9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S
M='(@(D5X=&5N<VGS(&YO(&EM<&QE;65N=&%D82(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HV-3<*(RP@9G5Z>GD*;7-G:60@(E5N=')A;G-L871E9"(*;7-G
M<W1R(")396YS92!N;VTB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#8@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ.#,*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P9&%T92(*;7-G<W1R(")!8W1U
M86QI='IA<B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@(D%C
M='5A;&ET>F%R("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHT,PIM<V=I9"`B57!D871E('5S97(B"FUS9W-T<B`B06-T=6%L:71Z
M87(@;"=U<W5A<FDB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$S-R!A9&UI;B]P
M97)M<R]E9&ET+G!H<#HR,3<@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S
M,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"`G)7,G+B(*
M;7-G<W1R(")3)VAA(&%C='5A;&ET>F%T("<E<R<N(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C$P.3(@<&\O=')A;G-L871I;VXN<&AP.C$R,S`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B57!D871I;F<@)7,@:&5L<"!F:6QE(&9O<B`E<RXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#$*;7-G
M:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S='(@(E,G:&$@<W5P
M<FEM:70@;&$@<V5Q_.AN8VEA(&0G86-T=6%L:71Z86-I\RXB"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3@Q(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ.#(*;7-G:60@(E5P;&]A9"(*;7-G<W1R(")#87)R96=A
M<B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#D*;7-G:60@(E5P;&]A
M9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R
M+B(*;7-G<W1R("(B"B)3)VAA(&-A<G)E9V%T(&%L('-E<G9I9&]R('1O=',@
M96QS(&%R>&EU<R!D92!C;VYF:6=U<F%C:?,@9"=A<&QI8V%C:6]N<RXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C(P"FUS9VED(")5<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@(D%L
M9F%B970@;&QA=.T@96X@;6%J^G-C=6QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B57!P
M97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R(")8:69R97,@<F]M86YE<R!E;B!M
M86KZ<V-U;&$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C0Q"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(E5R=6=U86DB
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,S4@<&\O=')A;G-L871I;VXN<&AP
M.CDR('!O+W1R86YS;&%T:6]N+G!H<#HY,PHC+"!F=7IZ>0IM<V=I9"`B57-A
M9V4Z(@IM<V=S='(@(DYO;2!D)W5S=6%R:3HB"@HC.B!L:6(O2&]R9&4O4')E
M9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`B571I;&ET>F%R(&PG86-T=6%L
M.B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*
M;7-G:60@(E5S92!34TPB"FUS9W-T<B`B571I;&ET>F%R(%-33"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C,*;7-G:60@(E5S92!I9B!N86UE+W!A
M<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM<V=S='(@
M(E5T:6QI='IE=2!S:2!E;"!N;VT@;R!L82!C;VYT<F%S96YY82!S\VX@9&EF
M97)E;G1S(&%L('-E<G9I9&]R($E-4U`N(@H*(SH@;&EB+TAO<F1E+U)E9VES
M=')Y+G!H<#HV,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N
M;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(DPG=7-U87)I("5S(&YO
M(&5S=.`@875T;W)I='IA="!P97(@82`E<RXB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HR,#,*;7-G:60@(E5S97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M
M:6YI<W1R86-I\R!D)W5S=6%R:7,B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN
M<&AP.C(U,`IM<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(D]P8VEO;G,@
M9"=U<W5A<FDB"@HC.B!S:6=N=7`N<&AP.C8R"FUS9VED(")5<V5R(%)E9VES
M=')A=&EO;B(*;7-G<W1R(")296=I<W1R92!D)W5S=6%R:7,B"@HC.B!S:6=N
M=7`N<&AP.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D
M:7-A8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R(")%;"!R96=I<W1R92!D
M)W5S=6%R:7,@9"=A<75E<W0@;&QO8R!E<W3@(&EN:&%B:6QI=&%T+B(*"B,Z
M(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$W,B!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.C(T-@HC+"!F=7IZ>0IM<V=I9"`B57-E<B!P97)M:7-S:6]N<R(*;7-G
M<W1R(")097)M:7-O<R!D96P@<')O<&EE=&%R:2(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#(*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3<@;&EB+TYE="]335,O=F]D869O
M;F5I=&%L>5]S;71P+G!H<#HY,PHC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3,U('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,S"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z-C8*;7-G:60@(E5S97)N86UE(@IM<V=S='(@
M(DYO;2!D)W5S=6%R:2(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z
M,3(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92`G)7,G
M(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R(")%;"!N;VT@9"=U<W5A<FD@)R5S
M)R!J82!E>&ES=&5I>"XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R(").;VT@9"=U<W5A<FDZ
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`IM<V=I9"`B57-E
M<FYA;64Z("(*;7-G<W1R(").;VT@9"=U<W5A<FDZ("(*"B,Z(&QI8B](;W)D
M92]097)M<R]522YP:'`Z,C$Y"B,L(&9U>GIY"FUS9VED(")5<V5R<R(*;7-G
M<W1R(")?57-U87)I<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(E5S
M=6%R:7,@9&5L('-I<W1E;6$Z(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(T,@IM<V=I9"`B57IB96MI<W1A;B(*;7-G
M<W1R(")5>F)E:VES=&%N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ,#$@;&EB
M+U9&4R]F:6QE+G!H<#HQ.#@*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N
M;W0@97AI<W0N(@IM<V=S='(@(D5L(&1I<F5C=&]R:2!61E,@;F\@97AI<W1E
M:7@N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q-@IM<V=I9"`B
M5F%C871I;VXB"FUS9W-T<B`B06)SZ&YC:6$B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z.#8V"FUS9VED(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D
M93H@(@IM<V=S='(@(DQE<R!U8FEC86-I;VYS(';@;&ED97,@<75E(',G:&%N
M('1R;V)A="!S\VXZ(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV
M,S@*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(E9A;&ED97-A(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-30@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4Y-@IM<V=I9"`B5F%L=64@:6X@;6EN=71E
M<R!F<F]M(&YO=RXB"FUS9W-T<B`B5F%L;W(@96X@;6EN=71S(&$@<&%R=&ER
M(&0G87)A+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX-38@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$Q-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@
M;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@(D5L('9A
M;&]R('-U<&5R82!L82!L;VYG:71U9"!MX'AI;6$@9&4@)7,N(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(R-#0@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-C8@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(S,30*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(Y,C8*;7-G:60@(E9A;'5E<R(*;7-G<W1R(")686QO<G,B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C$P.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$X-@IM
M<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(E9A;&]R<R!Q
M=64@<R=H86X@<V5L96-C:6]N87(@9&4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0Y"FUS9VED(")686YU871U(@IM
M<V=S='(@(E9A;G5A='4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C,V"FUS9VED(")687)I86)L92(*;7-G<W1R(")687)I86)L92(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#4*
M;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R(")696YEYW5E;&$B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N
M(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D
M('=I=&@N(@IM<V=S='(@(DAA(&9A;&QA="!L82!V97)I9FEC86-I\SH@Z7,@
M<&]S<VEB;&4@<75E(',G:&%G:2!A;'1E<F%T(&5L(&UI<W-A=&=E+B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED(")697)S:6]N
M(@IM<V=S='(@(E9E<G-I\R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR,#,*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R(")#;VYT<F]L
M(&1E('9E<G-I;VYS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI9VXB"FUS
M9W-T<B`B06QI;F5A8VGS('9E<G1I8V%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D
M9&EN9R(*;7-G<W1R(")&87)C:6UE;G0@=F5R=&EC86PB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@S"FUS9VED(")697)T
M:6-A;#HB"FUS9W-T<B`B5F5R=&EC86PZ(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E9E<GD@2&EG:"(*;7-G
M<W1R(")-;VQT(&%L="(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR-#@*;7-G:60@(E9I970@3F%M(@IM<V=S='(@(E9I
M971N86TB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5FEE
M=&YA;65S92`H5DE30TE)*2(*;7-G<W1R(")6:65T;F%M:71A("A625-#24DI
M(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.CDU-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(E9I<W5A;&ET>F%R("5S
M(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E
M>'1E<FYA;"!W96(@<&%G92(*;7-G<W1R(")6:7-U86QI='IA<B!U;F$@<.!G
M:6YA('=E8B!E>'1E<FYA(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N
M<&AP.C@Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&%S("5S(@IM<V=S
M='(@(E9I<W5A;&ET>F%R(&-O;2!A("5S(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#,*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-@IM<V=I9"`B5FER9VEN($ES
M;&%N9',L($)R:71I<V@B"FUS9W-T<B`B26QL97,@5F5R9V5S(&)R:73@;FEQ
M=65S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(T-PIM<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B
M26QL97,@5F5R9V5S(&YO<F0M86UE<FEC86YE<R(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C`W"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S='(@(E9I<VEB
M:6QI=&%T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,`IM
M<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(E9I<VEB:6QI=&%T.B`B"@HC
M.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<Y"FUS9VED
M(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R(")6;V1A9F]N92!D
M)TETX&QI82!P97(@=FEA(&1E(%--5%`B"@HC.B!L:6(O2&]R9&4O3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@(E=!4DXB"FUS
M9W-T<B`B041615)4R$Y#24$B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'(2$A(%)%34]612!3
M0U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B05;-4R$@14Q)34E.
M05(@3$$@4T51W,A.0TE!($U!3E5!3$U%3E0@1$4@)7,N(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR-#4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,`IM<V=I9"`B
M5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T<B`B5V%L;&ES(&D@1G5T=6YA(@H*
M(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP
M.C(Y"FUS9VED(")787)N:6YG(@IM<V=S='(@(D%V[7,B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,30U('!O+W1R86YS;&%T:6]N+G!H<#HV.#$@<&\O=')A
M;G-L871I;VXN<&AP.C<Q,0HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S(U('!O
M+W1R86YS;&%T:6]N+G!H<#HQ,#8P('!O+W1R86YS;&%T:6]N+G!H<#HQ,#8Y
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#<W('!O+W1R86YS;&%T:6]N+G!H
M<#HQ,#@W('!O+W1R86YS;&%T:6]N+G!H<#HQ,#DW"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HQ,3`W('!O+W1R86YS;&%T:6]N+G!H<#HQ,3$S('!O+W1R86YS
M;&%T:6]N+G!H<#HQ,C,U"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,C0U('!O
M+W1R86YS;&%T:6]N+G!H<#HQ,C4Q('!O+W1R86YS;&%T:6]N+G!H<#HQ,C<Q
M"B,L(&9U>GIY"FUS9VED(")787)N:6YG.B`B"FUS9W-T<B`B07;M<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3@*;7-G
M:60@(E=E(@IM<V=S='(@(D1C+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R(")0
M<F5V:7-I\R!D96P@=&5M<',B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S,T"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS
M9W-T<B`B26YF;W)M86-I\R!M971E;W)O;/)G:6-A('!R;W!O<F-I;VYA9&$@
M<&5R(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Y,@IM<V=I9"`B5V5A=&AE
M<BYC;VTB"FUS9W-T<B`B5V5A=&AE<BYC;VTB"@HC.B!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(E=E8B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS-C<*;7-G:60@(E=E8B!3:71E(@IM<V=S
M='(@(DQL;V,@=V5B(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU
M.`IM<V=I9"`B5V5E:VQY(@IM<V=S='(@(E-E=&UA;F%L;65N="(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED(")796QC;VUE(@IM
M<V=S='(@(D)E;G9I;F=U=',B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C4P('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R(")"96YV:6YG=71S
M(&$@)7,B"@HC.B!L86YG=&5S=#(N<&AP.C$T"FUS9VED(")796QC;VUE('1O
M($UY(%!(4"!!<'!L:6-A=&EO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO;6]B:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC
M.C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B
M0F5N=FEN9W5T<RP@)7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-0IM
M<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B3V-C:61E;G1A
M;"`H25-/+3@X-3DM,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM
M<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,34I(@IM<V=S='(@(D]C8VED96YT
M86P@*$E33RTX.#4Y+3$U*2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C<X"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G
M<W1R(")3X&AA<F$@3V-C:61E;G1A;"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO
M;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B475I
M;F$@87!L:6-A8VGS(&AA=7)I82!D92!M;W-T<F%R("5S(&5N(&EN:6-I87(@
M;&$@<V5S<VGS/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q
M"FUS9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G
M<W1R(")1=6EN(.ES(&5L(&-A<N!C=&5R(&1E;&EM:71A9&]R/R(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(T"FUS9VED(")7:&%T(&ES('1H
M92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(E%U:6X@Z7,@96P@8V%RX&-T
M97(@9&4@8VET86-I\S\B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G
M:60@(E=H:6-H('!H87-E<R(*;7-G<W1R(")1=6EN97,@9F%S97,B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,Q"FUS9VED(")7:&EC:"!P;'5G:6YS
M('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@
M(E!L=6=I;G,@:&%B:6QI=&%T<R!D92!L)V5D:71O<B!D92!T97AT(&5N<FEQ
M=6ET+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#0*;7-G:60@(E=I9'1H(@IM<V=S='(@(D%M<&QA9&$B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$R,PIM<V=I9"`B5VED=&@@:6X@0U-3
M('5N:71S(@IM<V=S='(@(D%M<&QA9&$@9&4@;&5S('5N:71A=',@0U-3(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@
M969F96-T(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`B06UP;&%D82!D96P@
M;65N^B`E<R!D92!L)V5S<75E<G)A("AD:7-P;VYI8FQE(&5N(&QA('!R;W!E
M<F$@<V5S<VGS*3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM<V=S
M='(@(D%M<&QA9&$@9&4@;&$@=&%U;&$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`IM<V=I9"`B5VED=&@@=6YI="(*
M;7-G<W1R(")5;FET870@9"=A;7!L861A(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G
M<W1R(")!;7!L861A.B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M-3D*;7-G:60@(E=I:VDB"FUS9W-T<B`B5VEK:2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Q"FUS9VED(")7:6YD(@IM<V=S
M='(@(E9E;G0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV,@IM<V=I9"`B5VEN9"!%87)L>2(*;7-G<W1R(")696YT(&$@<')I
M;65R82!H;W)A(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HW.`IM<V=I9"`B
M5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R(")696QO8VET870@9&5L('9E
M;G0@96X@;G5S;W,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U-`IM<V=I
M9"`B5VEN9#HB"FUS9W-T<B`B5F5N=#HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C,T"FUS9VED(")7:6YD.B`B"FUS9W-T<B`B5F5N=#H@
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB
M"FUS9W-T<B`B4V%V:65S82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ.#`*(RP@9G5Z>GD*;7-G:60@(E=I<VAL:7-T<R(*;7-G<W1R("),;&ES
M=&5S(&1E(&1E<VET:F]S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U
M"FUS9VED(")7;W)K(@IM<V=S='(@(D9E:6YA(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,C0@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R(")!
M9')EYV$@9&4@;&$@9F5I;F$B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R(")496SH
M9F]N(&1E(&QA(&9E:6YA(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$Q-CD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)I=&EN9R!U<&1A=&5D(&AE;'`@9FEL
M92!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(R.0IM<V=I9"`B6"U2968B"FUS9W-T<B`B6"U2968B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S($)A<VEC
M($-O;G-T<F%I;G1S(@IM<V=S='(@(DQI;6ET86-I;VYS(&+@<VEQ=65S(%@U
M,#EV,R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DR"FUS9VED
M(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(MIS(&1E(&QA
M(&-L874@97-T97-A('@U,#EV,R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.
M86UE(@IM<V=S='(@(DYO;2!A;'1E<FYA=&EU(&0G87-S=6UP=&4@6#4P.78S
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U
M,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(DED96YT:69I
M8V%D;W(@9&4@8VQA=2!D)V%S<W5M<'1E(%@U,#EV,R(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-C@R"FUS9VED(")8-3`Y=C,@97AT96YS:6]N
M<R(*;7-G<W1R(")%>'1E;G-I;VYS(%@U,#AV,R(*"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R(")!02(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HS.#8@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0R-PIM<V=I9"`B65E962(*;7-G<W1R(")!
M04%!(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P
M,#$*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B36%P82!D92!986AO;R$B
M"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R
M;'DB"FUS9W-T<B`B06YU86QM96YT(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#<*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,@IM<V=I9"`B665M96XB"FUS9W-T
M<B`B265M96XB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.#@U"FUS9VED(")997,B"FUS9W-T<B`B4^TB"@HC.B!T96UP;&%T97,O
M;6%I;G1E;F%N8V4O86=R965M96YT7V)O='1O;2YI;F,Z-@IM<V=I9"`B665S
M+"!)($%G<F5E(@IM<V=S='(@(E/M+"!H;R!A8V-E<'1O(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U
M(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W
M:71C:"!B86-K('1O(%=94TE764<N(@IM<V=S='(@(E-O=2!E;B!E;"!-3T1%
M(%1%6%0N(%5S974@96P@8F]T\R!;/#Y=('!E<B!T;W)N87(@82!765-)5UE'
M+B(*"B,Z(&QI8B](;W)D92YP:'`Z,3(X.`IM<V=I9"`B66]U(&%R92!N;W0@
M875T:&5N=&EC871E9"XB"FUS9W-T<B`B3F\@97-T974@875T96YT:6-A=',N
M(@H*(SH@;&EB+TAO<F1E+TED96YT:71Y+G!H<#HS,#(*(RP@9G5Z>GD*;7-G
M:60@(EEO=2!C86X@;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO
M=7(@9G5L;"!N86UE+B(*;7-G<W1R(").;R!P;V1E=2!I;F-L;W5R92!E;"!C
M87+@8W1E<B`G7%PG(&5N(&5L(&YO;2!C;VUP;&5T+B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ.#4U(&QI8B](;W)D92]&;W)M+G!H<#HQ.3<U"FUS9VED
M(")9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM
M<V=S='(@(DYO(&AE=2!I;G1R;V1U[W0@=6YA(&%D<F7G82!E;&5C='+R;FEC
M82!VX&QI9&$N(@H*(SH@;&EB+TAO<F1E+T1A=&$N<&AP.C(W,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R
M;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE
M;&1S("(*(FEN("5S+B(*;7-G<W1R("(B"B).;R!H974@87-S;V-I870@8V%P
M(&-A;7`@9&4@;"=A<GAI=2!I;7!O<G1A="!A;6(@96QS(&-A;7!S(&-O<G)E
M<W!O;F5N=',@9&4@)2(*(G,N(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDP
M,PIM<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R(")(
M974@<V]R=&ET(&1E(&QA('-E<W-I\RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3(V,0IM<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C
M96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L
M("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N
M(@IM<V=S='(@(B(*(DAE=2!D)VEN=')O9'5I<B!U;B!N^FUE<F\@9&4@=&5L
MZ&9O;B!M\F)I;"!VX&QI9"P@;F]MZ7,@9.UG:71S(&%M8B!U;B`G*R<@(@HB
M;W!C:6]N86P@<&5R(&%L('!R969I>"!D92!T<G5C861A(&EN=&5R;F%C:6]N
M86PN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q.#@*;7-G:60@(EEO=2!H
M879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(DAE=2!D)VEN
M=')O9'5I<B!U;B!V86QO<B!VX&QI9"XB"@HC.B!L:6(O2&]R9&4O075T:"]3
M:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!$871A
M5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R(")(974@9&4@
M8V]N9FEG=7)A<B!U;B!M;W1O<B!D92!$871A5')E92!P97(@=71I;&ET>F%R
M($%L=&5S+B(*"B,Z(&QI8B](;W)D92YP:'`Z-#,Q"FUS9VED(")9;W4@;75S
M="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B2&5U(&1E(&-O
M;F9I9W5R87(@=6X@;6]T;W(@9&4@5D93+B(*"B,Z('1E;7!L871E<R]P<F]B
M;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T
M:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E
M<&]R="XB"FUS9W-T<B`B2&5U(&1E(&1E<V-R:75R92!E;"!P<F]B;&5M82!A
M8F%N<R!D)V5N=FEA<BUN92!L)VEN9F]R;64N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U(&UU<W0@
M96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(@IM<V=S
M='(@(DAE=2!D)VEN=')O9'5I<B!E;"!54DP@<75E(&%Q=65S="!E;FQL8><@
M:6YD:6-A+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS
M9VED(")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N
M(@IM<V=S='(@(DAE=2!D92!S96QE8V-I;VYA<B!U;B!S97)V:61O<B!Q=64@
M=G5L9W5E=2!E;&EM:6YA<BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*;7-G
M:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N
M(@IM<V=S='(@(DAE=2!D)V5S<&5C:69I8V%R('5N(&YO;2!D)W5S=6%R:2!Q
M=64@=G5L9W5E=2!E<V)O<G)A<BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#`*
M;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N
M(@IM<V=S='(@(DAE=2!D)V5S<&5C:69I8V%R('5N(&YO;2!D)W5S=6%R:2!Q
M=64@=G5L9W5E=2!S=7!R:6UI<BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M
M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`B2&5U
M(&0G97-P96-I9FEC87(@<75I;B!N;VT@9"=U<W5A<FD@=F]L974@869E9VER
M+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@IM<V=I9"`B66]U(&UU<W0@<W!E
M8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*;7-G<W1R(")(974@9"=E
M<W!E8VEF:6-A<B!E;"!N;VT@9"=U<W5A<FD@<75E('9O;&5U(&%C='5A;&ET
M>F%R+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C$S.`IM<V=I
M9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*
M;7-G<W1R(")(974@9"=E<W!E8VEF:6-A<B!Q=6EN82!A8V-I\R!V;VQE=2!E
M>&5C=71A<BXB"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R
M+G!H<#HW,@IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N
M86UE+B(*;7-G<W1R(")(974@9&4@=&5C;&5J87(@=6X@;F]U(&YO;2!D92!C
M871E9V]R:6$N(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C@Y,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L
M96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB3&$@=F]S=')A('-E<W-I
M\R!E;B`E<R!H82!E>'!I<F%T+B!3:2!U<R!P;&%U+"!I;FEC:65U('5N82!N
M;W9A('-E<W-I\RXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHS.`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(DQA('9O
M<W1R82!A9')EYV$@96QE8W1R\FYI8V$B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C`R"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@
M(DQA('1E=F$@861R9>=A(&1E(')E<W!O<W1A(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C8T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-"!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y
M"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(DQA('9O<W1R82!I
M;F9O<FUA8VGS(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C@Y-0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H
M86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN
M(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@
M86=A:6XN(@IM<V=S='(@(B(*(DQA('9O<W1R82!A9')EYV$@9"=);G1E<FYE
M="!H82!C86YV:6%T(&1E<R!Q=64@:&5U(&-O;65NYV%T(&QA('-E<W-I\R`E
M<RX@(@HB4&5R(')A;VYS(&1E('-E9W5R971A="P@:&5U(&1E(')E:6YI8VEA
M<B!L82!S97-S:?,N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z,S,*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R(")%;"!V;W-T<F4@;F]M
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.CD*(RP@9G5Z
M>GD*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S
M(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB
M:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G
M<W1R("(B"B)%;"!V;W-T<F4@;6]T;W(@9"=A=71E;G1I8V%C:?,@;F\@<&5R
M;65T('%U92!E<R!L;&ES=&EN(&5L<R!U<W5A<FES+"!O(&+I("(*(G!E<B!A
M;&=U;F$@<F'S(&%Q=65S=&$@8V%R86-T97+M<W1I8V$@97-TX"!I;FAA8FEL
M:71A9&$N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHY
M"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N
M;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B"B)H
M87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S
M='(@(B(*(D5L('9O<W1R92!M;W1O<B!D)V%U=&5N=&EC86-I\R!N;R!P97)M
M970@<75E(&5S(&QL:7-T:6X@96QS('5S=6%R:7,L(&\@8ND@(@HB<&5R(&%L
M9W5N82!R8?,@87%U97-T82!C87)A8W1E<NUS=&EC82!E<W3@(&EN:&%B:6QI
M=&%D82XB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.#DY"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA
M;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@
M(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A
M9V%I;BXB"FUS9W-T<B`B(@HB4V5M8FQA('%U92!E;"!N879E9V%D;W(@:&$@
M8V%N=FEA="!D97,@<75E('9A=2!C;VUE;N=A<B!L82!S97-S:?,@)7,N(%!E
M<B`B"B)R86]N<R!D92!S96=U<F5T870L(&AE=2!D92!T;W)N87(@82!E;G1R
M87(@86P@<VES=&5M82XB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU,`IM
M<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T
M=7)E+B(*;7-G<W1R(")%;"!V;W-T<F4@;F%V96=A9&]R(&YO(&%C8V5P=&$@
M87%U97-T82!C87)A8W1E<NUS=&EC82XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]P<FEN="YJ<SHT,@IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@
M;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO
M0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*(D5L('9O<W1R
M92!N879E9V%D;W(@;F\@<&5R;65T(&%Q=65S=&$@;W!C:?,@9"=I;7!R97-S
M:?,N(%!R96UI($-O;G1R;VP@*R!0("(*(G!E<B!I;7!R:6UI<BXB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0W"FUS9VED(")9;W5R(&-U<G)E;G0@
M=&EM92!Z;VYE.B(*;7-G<W1R("):;VYA(&AO<N!R:6$@86-T=6%L.B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#@*;7-G:60@(EEO=7(@9&5F875L
M="!I9&5N=&ET>3HB"FUS9W-T<B`B261E;G1I=&%T('!R961E=&5R;6EN861A
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3$*;7-G:60@(EEO=7(@
M9G5L;"!N86UE.B(*;7-G<W1R(").;VT@8V]M<&QE=#HB"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,30U"FUS9VED("(B"B)9;W5R(&=E='1E>'0@=F5R<VEO
M;B!I<R!T;V\@;VQD(&%N9"!D;V5S(&YO="!S=7!P;W)T(%!(4"!N871I=F5L
M>2Y<;B(*(DYO="!A;&P@<W1R:6YG<R!W:6QL(&)E(&5X=')A8W1E9"XB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES
M.B`E<R(*;7-G<W1R("),82!N;W9A(&-O;G1R87-E;GEA('!E<B!A("5S(.ES
M.B`E<R(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,34T"FUS9VED(")9
M;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO
M;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@(DQE<R!O<&-I;VYS(&AA;B!E
M<W1A="!A8W1U86QI='IA9&5S('!E<B!A(&QA(&1U<F%D82!D)V%Q=65S=&$@
M<V5S<VGS+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,34V"FUS9VED
M(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S='(@(DQE
M<R!O<&-I;VYS(&AA;B!E<W1A="!A8W1U86QI='IA9&5S+B(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A<W-W;W)D
M(&AA<R!B965N(')E<V5T(@IM<V=S='(@(E,G:&$@<F5I;FEC:6%T(&QA('9O
M<W1R82!C;VYT<F%S96YY82(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T
M+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R`B
M"B)P87-S=V]R9"XB"FUS9W-T<B`B(@HB4R=H82!R96EN:6-I870@;&$@=F]S
M=')A(&-O;G1R87-E;GEA+"!R979I<V$@96P@8V]R<F5U(&5L96-T<O)N:6,@
M:2!I;FEC:6$@(@HB;&$@<V5S<VGS(&%M8B!L82!N;W9A(&-O;G1R87-E;GEA
M+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B
M66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`B4V5R=FED;W)S(')E;6]T
M<SHB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(U-`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R("))
M=6=O<VS@=FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS
M9VED("):86ER92(*;7-G<W1R("):86ER92(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-38*;7-G:60@(EIA;6)I82(*
M;7-G<W1R("):X&UB:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C4W"FUS9VED(")::6UB86)W92(*;7-G<W1R("):
M:6UB86)W92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B
M6FEP<'DB"FUS9W-T<B`B6FEP<'DB"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT
M97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E9"!4
M97AT72(*;7-G<W1R(");3V-U;'1A('1E>'0@8VET871=(@H*(SH@<V5R=FEC
M97,O<')O8FQE;2YP:'`Z-38*;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB"FUS
M9W-T<B`B6TEN9F]R;64@9&5L('!R;V)L96UA72(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(");4VAO=R!1=6]T
M960@5&5X="`M(@IM<V=S='(@(EM-;W-T<F$@=&5X="!C:71A="`M(@H*(SH@
M;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R
M"B,L('!H<"UF;W)M870*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("T@)7,@
M;&EN97-=(@IM<V=S='(@(EM-;W-T<F$@=&5X="!C:71A="`M("5S(&SM;FEE
M<UTB"@HC.B!L:6(O2&]R9&4N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(");;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B6VSM;FEA("5S(&1E("5S72(*
M"B,Z(&QI8B](;W)D92YP:'`Z,30S,B!T96UP;&%T97,O<&]R=&%L+VUE;G4N
M:6YC.C$Q"FUS9VED(")?061M:6YI<W1R871I;VXB"FUS9W-T<B`B7T%D;6YI
M<W1R86-I\R(*"B,Z(&QI8B]A<&DN<&AP.C$S-@IM<V=I9"`B7T-,22(*;7-G
M<W1R(")?0TQ)(@H*(SH@;&EB+V%P:2YP:'`Z,3(T"FUS9VED(")?1&%T851R
M964B"FUS9W-T<B`B7T%R8G)E(&1E(&1A9&5S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED(")?
M1&5L971E(%)O=R(*;7-G<W1R(")?4W5P<FEM:7(@9FEL82(*"B,Z(&QI8B]A
M<&DN<&AP.C$Q-@IM<V=I9"`B7T=R;W5P<R(*;7-G<W1R(")?1W)U<',B"@HC
M.B!L:6(O2&]R9&4O365N=2YP:'`Z,3<U"FUS9VED(")?2&5L<"(*;7-G<W1R
M(")?06IU9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P97)T:65S+BXN
M(@IM<V=S='(@(E]0<F]P:65T871S(&1E(&QA(&EM871G92XN+B(*"B,Z(&QI
M8B](;W)D92]-96YU+G!H<#HQ.30*;7-G:60@(E],;V<@:6XB"FUS9W-T<B`B
M7TEN:6-I82!L82!S97-S:?,B"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,3DP
M"FUS9VED(")?3&]G(&]U="(*;7-G<W1R(")?4W5R="(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I
M9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(E]-;V1I9FEC82!L)V5N;&QA
MYRXN+B(*"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ-C0*;7-G:60@(E]/<'1I
M;VYS(@IM<V=S='(@(E]/<&-I;VYS(@H*(SH@;&EB+V%P:2YP:'`Z,3(P"FUS
M9VED(")?4&5R;6ES<VEO;G,B"FUS9W-T<B`B7U!E<FUI<V]S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V
M"FUS9VED(")?4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`B7T5L:6UI;F$@;"=E
M;FQL8><N+BXB"@HC.B!L:6(O87!I+G!H<#HQ,#@*;7-G:60@(E]3971U<"(*
M;7-G<W1R(")?0V]N9FEG=7)A8VGS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"FUS9VED(")?5&%B;&4@
M4')O<&5R=&EE<RXN+B(*;7-G<W1R(")?4')O<&EE=&%T<R!D92!L82!T875L
M82XN+B(*"B,Z(&QI8B]A<&DN<&AP.C$Q,@IM<V=I9"`B7U5S97)S(@IM<V=S
M='(@(E]5<W5A<FES(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HX.3`*;7-G
M:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R(")L;&EB<F5T82!D)V%D<F5C97,B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S$Q"B,L(&9U>GIY"FUS9VED(")A
M;B!E<G)O<B!H87,@;V-C=7)E9#HB"FUS9W-T<B`B4R=H82!P<F]D=>]T('5N
M(&5R<F]R(&ER<F5P87)A8FQE+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z
M.#@R"FUS9VED(")C86QE;F1A<B(*;7-G<W1R(")A9V5N9&$B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$W,"!L:6(O0FQO8VLO;65T87(N<&AP.C,U-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S='(@(F-A;&UA(@H*(SH@
M;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C4X.`IM<V=I9"`B8VQI8VL@
M:&5R92(*;7-G<W1R(")0<F5M:2!A<77M(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C0T-2!P;R]T<F%N<VQA=&EO;BYP:'`Z-34P('!O+W1R86YS;&%T:6]N
M+G!H<#HV,3$*(SH@<&\O=')A;G-L871I;VXN<&AP.C<T.2!P;R]T<F%N<VQA
M=&EO;BYP:'`Z.#$P('!O+W1R86YS;&%T:6]N+G!H<#HX.#<*(RP@9G5Z>GD*
M;7-G:60@(F1O;F4B"FUS9W-T<B`B9F5T(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C4U,B!P;R]T<F%N<VQA=&EO;BYP:'`Z-3@T('!O+W1R86YS;&%T:6]N
M+G!H<#HV,3,*(SH@<&\O=')A;G-L871I;VXN<&AP.C<W."!P;R]T<F%N<VQA
M=&EO;BYP:'`Z.#$R('!O+W1R86YS;&%T:6]N+G!H<#HX.3`*(RP@9G5Z>GD*
M;7-G:60@(F9A:6QE9"(*;7-G<W1R(")F86QL:61A(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(F9A;&QI;F<B
M"FUS9W-T<B`B97-TX"!C86EE;G0B"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP
M:'`Z.#0Y"FUS9VED(")F:6QE(@IM<V=S='(@(F%R>&EU(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C$R.0HC+"!F=7IZ>0IM<V=I9"`B9F]U;F0Z("(*;7-G
M<W1R(")696YT.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,U."!L:6(O0FQO8VLO;65T87(N<&AP.C,X-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S
M(@IM<V=S='(@(F1E<R!D96P@)7,@*"5S*2!A(&QE<R`E<R`E<R(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,S(*;7-G:60@(F@Z
M(@IM<V=S='(@(F@Z(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C,S,0IM<V=I9"`B:&@B"FUS9W-T<B`B:&@B"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-38T"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T<B`B
M:6UM961I870B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S
M971U<"]D:69F+G!H<#HW.0IM<V=I9"`B:6YL:6YE(@IM<V=S='(@(FEN<V5R
M96EX(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z
M,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R(")L[6YI97-=(@H*(SH@;&EB+U9&
M4R])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM
M<V=S='(@(E,G:&$@<')O9'7O="!U;B!C;V1I(&0G97)R;W(@)60@9&5L(&UK
M:7-O9G,@96X@8W)E87(@25-/+B(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HS-#(*;7-G:60@(FUM(@IM<V=S='(@(B-M;2,B"@HC
M.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C(X-R!S97)V:6-E<R]P;W)T86PO
M<VED96)A<BYP:'`Z,C`U"FUS9VED(")N86UE(@IM<V=S='(@(FYO;2(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HS-S@*(RP@9G5Z>GD*;7-G:60@(FYO="!C
M:&%N9V5D(@IM<V=S='(@(E-E;G-E(&-A;G9I<RXB"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z,3,Q"B,L(&9U>GIY"FUS9VED(")N;W0@9F]U;F0B"FUS9W-T
M<B`B3F\@<R=H82!T<F]B870@)7,N(@H*(SH@;&EB+TAO<F1E+U)00RYP:'`Z
M,3(Q"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`B;F\@<R=H82!I
M;7!L96UE;G1A="(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(Q
M.0IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*;7-G<W1R(")E;F-A<F$@
M;F\@<R=H82!I;7!L96UE;G1A="(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z
M.#<T"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(F)L;V,@9&4@;F]T97,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@X"FUS9VED(")P97)C96YT(@IM<V=S='(@(G!E<F-E;G1A=&=E(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(G#M>&5L<R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"FUS9VED(")R:7-I;F<B
M"FUS9W-T<B`B97-TX"!P=6IA;G0B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.CDX"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@(FUO<W1R
M87(@9&EF97+H;F-I97,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3$S"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B"FUS9W-T<B`B
M<VUS,F5M86EL('!E<B!V:6$@9&4@2%144"(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HS-3@*;7-G:60@(G-S(@IM<V=S='(@(G-S
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*
M;7-G:60@(G-T96%D>2(*;7-G<W1R(")C;VYS=&%N="(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z.#DX"FUS9VED(")T87-K(&QI<W0B"FUS9W-T<B`B;&QI
M<W1A(&1E('1A<W%U97,B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S(U"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")T:&4@2&]R9&4@4$\@9FEL92!F
M;W(@=&AE(&QO8V%L92`E<R!D;V5S(&YO="!E>&ES=#HB"FUS9W-T<B`B3F\@
M97AI<W1E:7@@;"=A<GAI=2!T96UP;W)A;"!<(B5S7"(N(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,S8@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G
M:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T
M<B`B=&5C;&5G974@;&$@8V]N=')A<V5N>6$@9'5E<R!V96=A9&5S('!E<B!C
M;VYF:7)M87(M;&$B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI
M;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R(")U
M;FEF:6-A="(*"B,Z(&QI8B](;W)D92]-24U%+U!A<G0N<&AP.C(W"FUS9VED
M(")U;FYA;65D(@IM<V=S='(@(G-E;G-E(&YO;2(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HS-S4*(RP@9G5Z>GD*;7-G:60@(G5P9&%T960B"FUS9W-T<B`B
M06-T=6%L:71Z87(B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(R,B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38T"FUS
M9VED(")U<V5R('-E;&5C="(*;7-G<W1R(")S96QE8V-I\R!D92!L)W5S=6%R
M:2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G
M:60@(G9#87)D(@IM<V=S='(@(G9#87)D(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(R-`IM<V=I9"`B=SHB"FUS9W-T<B`B=SHC
M(R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED(")W
M96%T:&5R+F-O;2(*;7-G<W1R(")W96%T:&5R+F-O;2(*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]B<U]"02YP;P``````````
M````````````````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`V-3`V
M,S$@,3`U,34T,S,W-#(@,#$W-#<V`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````",@=')A;G-L871I;VX@;V8@:&]R9&4M8G,N
M<&\@=&\@0F]S;FEA;@HC($)O<VYI86X@=')A;G-L871I;VYS(&9O<B!I;7`@
M<&%C:V%G92X*(R!#;W!Y<FEG:'0@*$,I(#(P,#,@2&]R9&4@4')O:F5C=`HC
M(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E
M;G-E(&%S('1H92!I;7`@<&%C:V%G92X*(R!!=71O;6%T:6-A;&QY(&=E;F5R
M871E9"P@,C`P,RX*(R!!;&5N(%-A<FMI;F]V:6,@/&%L96Y`;&EN=7@N;W)G
M+F)A/BP@,C`P-"X*(R!6961R86X@3&IU8F]V:6,@/'9L:G5B;W9I8T!S;6%R
M=&YE="YB83XL(#(P,#4N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T
M+4ED+59E<G-I;VXZ(&AO<F1E+6)S7&XB"B)297!O<G0M37-G:60M0G5G<RU4
M;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z
M(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@
M,C`P-2TP-RTP,2`Q,SHS,2LP,C`P7&XB"B),87-T+51R86YS;&%T;W(Z(%9E
M9')A;B!,:G5B;W9I8R`\=FQJ=6)O=FEC0'-M87)T;F5T+F)A/EQN(@HB3&%N
M9W5A9V4M5&5A;3H@0F]S;FEA;B`\;&]K86Q`;&EN=7@N;W)G+F)A/EQN(@HB
M34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I
M;CL@8VAA<G-E=#U)4T\M.#@U.2TR7&XB"B)#;VYT96YT+51R86YS9F5R+45N
M8V]D:6YG.B`X8FET7&XB"B)8+4=E;F5R871O<CH@2T)A8F5L(#$N,3!<;B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-CD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS9W-T<B`B("AP<FEJ92`E<R!D
M86YA*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,W,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B`H>F$@)7,@9&%N82DB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<S"FUS9VED("(@*'1O
M9&%Y*2(*;7-G<W1R("(@*&1A;F%S*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S-S4*;7-G:60@(B`H=&]M;W)R;W<I(@IM<V=S='(@(B`H<W5T
M<F$I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,0IM<V=I9"`B
M("AY97-T97)D87DI(@IM<V=S='(@(B`H:G7H92DB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C4V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS-C$*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0P-PIM
M<V=I9"`B(&%T("(*;7-G<W1R("(@=2`B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C(Q-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B4')A=F%C('-O<G1I
M<F%N:F$B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<R"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO
M:6-E+B(*;7-G<W1R("(G)7,G(&YI:F4@9&]Z=F]L:F5N(&EZ8F]R+B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-C4Y"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3`T,@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D
M(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B)R5S)R!N:6IE('!O
M9&6Y96X@=2!R96=I<W1R>2UJ=2!A<&QI:V%C:6IE+B(*"B,Z(&9R86UE=V]R
M:R]4<F5E+U1R964N<&AP.C$W,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R("(E
M<R!N:6IE('!R;VYA\&5N+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-38*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@
M=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B!J92!U<W!E<VYO
M(&1O9&%N('4@861R97-A<B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H
M<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O
M('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z-30@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-R96%T960Z("5S
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W
M960@*"4N,F8E)2DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A;F0@
M)7,B"FUS9W-T<B`B)60@)7,@:2`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z,C8X(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU-3<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D
M(&5X<&ER97,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C
M87-T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HV
M.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R("(E
M<R`M($YA<&]M96YA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HW,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z.#,S(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(E<R!+0B(*"B,Z
M('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N
M(@IM<V=S='(@(B5S(%-E<G9I<VYE(&]P97)A8VEJ92`M('!O='9R9&$B"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T
M<B`B)7,@<&]D9;EA=F%N:F4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I
M9VYU<"YP:'`Z,C8S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I9VX@57`B
M"FUS9W-T<B`B)7,@<')I:F%V82(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E
M+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E
M96UE;G0B"FUS9W-T<B`B)7,@=7-L;W9I('5G;W9O<F$B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C0R."!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C0Y,`HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8U,2!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B)7,@=F7F('!O<W1O:FDN
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3D@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ-C4@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,SD*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS-#4@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B)7,@=2`E<R`E
M<R(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T
M:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C
M:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O
M('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("(@)B,Q-3$[("5S(.9E
M('-A9&$@:7IV<KEI=&D@<V5R=FES;F4@;W!E<F%C:6IE(&YA=F5D96YE(&ES
M<&]D+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-#`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@;6EN=71E<R(*;7-G<W1R("(E<R!M:6YU=&$B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3(S"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`B)7,@;FEJ92!P<F]N8?!E
M;BXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHT"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@(B5S('IA
M("5S(&]D("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T
M<B`B)7,@861R97-A<B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3$T"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T
M<B`B)7,@:V%L96YD87(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDP-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T
M<B`B)7,@8FEL:F6^;FEC82(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3,P"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS
M9W-T<B`B)7,@>F%D86-I(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].
M;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B)7,Z("5S(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,C<R"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M
M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG("(*
M(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W
M:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V-2!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-#$P"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@X(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3DS"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U<W1I
M;F<@)7,@)7,B"FUS9W-T<B`B)7,@=2`E<R`E<R(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@
M9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C(Y-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C,T.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#8Y(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Q,C@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C<T.0IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S
M='(@(BTM(&EZ86)E<FET92`M+2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR
M,`IM<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS9W-T<B`B,3(M<V%T;FD@9F]R
M;6%T(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y"FUS9VED("(R-"!(;W5R
M($9O<FUA="(*;7-G<W1R("(R-"US871N:2!F;W)M870B"@HC.B!T96UP;&%T
M97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B
M,C0@<V%T82(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z-CD*(RP@
M9G5Z>GD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R(")0<F5T:&]D;F$@<W1R
M86YA(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3D*;7-G:60@(D$@9&%T
M86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C`*;7-G
M:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(D1ON6QO
M(&IE(&1O(&9A=&%L;F4@9W)EN6ME(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E
M<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38U"FUS9VED(")!('!U
M8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M
M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ,#DW"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV
M871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D
M96-R>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Q-0IM<V=I9"`B(@HB02!P=6)L:6,@
M4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3`U"FUS9VED("(B
M"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S
M<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R
M:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@
M4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HY"B,L(&9U>GIY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B2V]P
M:7)A:B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$P"FUS9VED(")!32!,:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"B,L(&9U>GIY"FUS
M9VED(")!32!286EN(@IM<V=S='(@(E5P;WIO<F5N:F4B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@4VAO
M=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ,PIM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]0
M32(*;7-G<W1R(")!32]032(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@(D\@;W9O;2!E
M9&ET;W)U(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3(*;7-G:60@
M(D%B;W5T+BXN(@IM<V=S='(@(D\@<')O9W)A;74N+BXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T"B,L(&9U>GIY"FUS
M9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B1&YO(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED9&QE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR
M-S`*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R
M>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C,*(RP@9G5Z
M>GD*;7-G:60@(D%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B5F&Y92!I
M;F9O<FUA8VEJ92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-0IM<V=I
M9"`B06-C;W5N="!087-S=V]R9"(*;7-G<W1R("*I:69R82!K;W)I<VYIZ&MO
M9R!N86QO9V$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3,*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R
M(").86QO9R!J92!Z86UR>FYU="XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S,S"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(E)AZ'5N;W9O
M9'-T=F\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T."!T
M96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]A9&1C:&EL9"YI;F,Z,3$*;7-G:60@(D%D9"(*;7-G<W1R(")$
M;V1A:B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T(&%D;6EN+V=R;W5P<RYP
M:'`Z,C(U"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY."!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.CDY"B,L(&9U>GIY"FUS9VED(")!9&0@0VAI;&0@
M4&5R;6ES<VEO;B(*;7-G<W1R("))>FUI:F5N:2!D;WIV;VQU(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*;7-G:60@(D%D9"!(97)E.B(*;7-G
M<W1R(")$;V1A:B!O=F1J93HB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(Q."!A
M9&UI;B]G<F]U<',N<&AP.C(Q.0HC+"!F=7IZ>0IM<V=I9"`B061D($YE=R!'
M<F]U<"(*;7-G<W1R(").97=S+6=R=7!E(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HX-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C@X"B,L(&9U>GIY"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB"FUS9W-T
M<B`B27IM:6IE;FD@9&]Z=F]L=2(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O861D8VAI;&0N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@
M8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,30W"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G
M<W1R("))>FUI:F5N:2!D;WIV;VQE('IA("5S(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R(")$;V1A:B!N
M;W9O9R!K;W)I<VYI:V$Z(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C4U-`IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R(")$
M;V1A:B!K;VQO;G4B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N
M:6YC.C,T"B,L(&9U>GIY"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T
M<B`B1&]D86H@;F]V;V<@:V]R:7-N:6MA.B(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S
M='(@(D1O9&%J("5S(&UE;FD@=2!-;WII;&QA(%-I9&5B87(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*;7-G:60@(D%D
M9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(D1O9&%J('4@861R97-A<CHB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*
M(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T
M<B`B1&]D86H@=2!I;65N:6L@*"5S*2(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q
M"B,L(&9U>GIY"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R(")$;V1A:B!O=F1J
M93HB"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO
M="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*
M;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G
M:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I
M;B!N;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO
M861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0Q"B,L(&9U>GIY
M"FUS9VED(")!9&1R97-S(@IM<V=S='(@(D]D(&%D<F5S92(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ,SD*;7-G:60@(D%D9')E<W,@0F]O:R(*
M;7-G<W1R("));65N:6LB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S
M:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`B061M:6YI<W1R:7)A;FIE
M("T@<&]D9;EA=F%N:F4@9&]Z=F]L82!D<G5G:6@@:V]R:7-N:6MA(@H*(SH@
M861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ,3,*(RP@9G5Z>GD*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(E]!9&UI;FES=')A8VEJ82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS-#$*(RP@9G5Z>GD*;7-G:60@(D%D<R(*;7-G<W1R(")$;V1A:B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@(D%F9V%N:7-T
M86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;&)A;FEA(@IM<V=S='(@(D%L8F%N
M:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B06QG97)I82(*;7-G<W1R(")!;+YI
M<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M,#<*(RP@9G5Z>GD*;7-G:60@(D%L:6%S(@IM<V=S='(@(D%LOFER(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ
M-@IM<V=I9"`B06QI9VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@
M(D%L;"(*;7-G<W1R(")3=F4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8U"B,L(&9U
M>GIY"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*;7-G<W1R(")5
M<VUJ97)E;FIE(&YI:F4@=7-P96QO+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*(RP@9G5Z>GD*;7-G:60@(D%L;"!'
M<F]U<',B"FUS9W-T<B`B7T=R=7!E(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HY,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O9&%T871R964N
M<&AP.C<U"B,L(&9U>GIY"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T
M<B`B7T1O>G9O;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<Q"FUS9VED
M(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4S-`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O
M9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B1&]Z=F]L:2!P<F%V;&IE
M;FIE(&YU;65R:7-A;FEH(&QI<W1I/R(*"B,Z(&9R86UE=V]R:R]$871A5')E
M92]$871A5')E92]S<6PN<&AP.C4P-`HC+"!F=7IZ>0IM<V=I9"`B06QR96%D
M>2!E>&ES=',B"FUS9W-T<B`B)7,@=F7F('!O<W1O:FDN(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$R,PIM<V=I9"`B06QT97)N871E($E-4U`@3&]G
M:6XB"FUS9W-T<B`B06QT97)N871I=FYI($E-4U`@;&]G:6XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3`W"FUS9VED(")!;'1E<FYA=&4@24U34"!0
M87-S=V]R9"(*;7-G<W1R(")!;'1E<FYA=&EV;F$@24U34""Y:69R82(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3D*;7-G:60@(D%L=&5R;F%T92!)
M35-0(%5S97)N86UE(@IM<V=S='(@(D%L=&5R;F%T:79N;R!)35-0(&MO<FES
M;FGH:V\@:6UE(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*
M(RP@9G5Z>GD*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S
M='(@(DYE9&]Z=F]L:F5N82!S;&]V82!U(&5M86EL(&%D<F5S:2XB"@HC.B!A
M9&UI;B]T96UP;&%T97,N<&AP.C$T,@HC+"!F=7IZ>0IM<V=I9"`B06QT97)N
M871E('1E;7!L871E<R(*;7-G<W1R(").961O>G9O;&IE;F$@<VQO=F$@=2!E
M;6%I;"!A9')E<VDN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X
M=#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@4V%M
M;V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HY-2!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B
M06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R(")5;F6Y
M96YA(&IE(&EL96=A;&YA('9R:6IE9&YO<W0N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$V-PHC+"!F=7IZ>0IM<V=I9"`B06X@=6YK;F]W
M;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B1&^Y;&\@:F4@9&\@9F%T
M86QN92!G<F6Y:V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O<G)A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4W"FUS9VED(")!;F=U:6QL82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@
M4')O>'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z-#D*(RP@9G5Z>GD*;7-G:60@(D%N<W=E<B(*;7-G<W1R(")/9&=O=F]R
M96YE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO<&AP<VAE
M;&PN<&AP.C,U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3@@
M=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@HC+"!F=7IZ>0IM
M<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`B06MC:6IA(@H*(SH@=71I;"]I
M8V]N7V)R;W=S97(N<&AP.C0R"B,L(&9U>GIY"FUS9VED(")!<'!L:6-A=&EO
M;B!,:7-T(@IM<V=S='(@(D%K8VEJ82(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-#`*(RP@9G5Z>GD*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y
M+B(*;7-G<W1R(")!:V-I:F$B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS
M9VED(")!<'!R;W9E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.C@S,PIM<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`B07!R:6PB"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$W-0IM<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R
M-38I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-3D@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HV-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@Q
M"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HX,`HC+"!F=7IZ>0IM<V=I9"`B07)C:&EV
M92!.86UE(@IM<V=S='(@(DEM92!D871O=&5K92(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3`*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@
M=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(D1A(&QI('-T
M92!S:6=U<FYI(&1A(+YE;&ET92!I<W!R87IN:71I(&9O;&1E<B!K;W)P83\B
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H
M('1O(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R
M(")$82!L:2!S=&4@<VEG=7)N:2!D82"^96QI=&4@;V)R:7-A=&D@;W9E('!O
M<G5K93\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4X"B,L(&9U>GIY"FUS9VED(")!<F=E;G1I;F$B
M"FUS9W-T<B`B06R^:7(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!<FUE;FEA(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<V"FUS9VED(")!
M<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4Y"FUS9VED(")!<G5B82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C
M:6D@07)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU-0IM<V=I9"`B07-I82]086-I9FEC(%)E9VEO;B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(U"FUS9VED(")!<VL@9F]R
M(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T
M:6]N<S\B"FUS9W-T<B`B4&ET86H@<')I:F4@;V)A=FQJ86YJ82!S97)V:7-N
M:6@@;W!E<F%C:6IA/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q
M,3,*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A
M(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R
M;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N
M;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<&5R;7,O961I="YP:'`Z.#<*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO
M;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]S:&%R97,O961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@961I="!A
M(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-"!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C<Q"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z.#8*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*
M;7-G:60@(D%U9W5S="(*;7-G<W1R(")!=6=U<W0B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"B,L
M(&9U>GIY"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B075G=7-T(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B075S=')I82(*;7-G<W1R(")!=6=U
M<W0B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,38X"FUS
M9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N
M;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3(R"FUS9VED(")!=71H
M7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O9G1P+G!H<#HS-@IM
M<V=I9"`B(@HB075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92TB"B)F='`@
M<W=I=&-H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM
M87`N<&AP.C8T"FUS9VED(")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E
M9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S`R"FUS9VED(")!=71H7VQD
M87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@
M1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S
M(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HV,PIM<V=I
M9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z,S,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z
M(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9#H@(@IM<V=S='(@(DYI:F4@=7-P96QO('-P8;EA=F%N:F4@;F5Z
M879RN65N92!P;W)U:V4N($]V;R!J92!P;W)U:V$@<V5R=F5R83H@)7,B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,X-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C0Y.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5
M;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS9W-T<B`B3FEJ92!U<W!E;&\@
M<W!AN6%V86YJ92!N97IA=G*Y96YE('!O<G5K92X@3W9O(&IE('!O<G5K82!S
M97)V97)A.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M-#`U"FUS9VED(")!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S
M=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-#8*;7-G:60@(D%U=&A?
M;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z-C`*;7-G
M:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*(RP@9G5Z>GD*;7-G:60@(D%U
M=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R(")5<VUJ97)E;FIE(&YI:F4@
M=7-P96QO+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C<V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!
M=71H96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S='(@(E5S;6IE<F5N:F4@
M;FEJ92!U<W!E;&\N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N
M<&AP.C$W-@IM<V=I9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$
M2553('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HX-3$*(RP@9G5Z>GD*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O
M($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")5<VUJ97)E;FIE(&YI:F4@
M=7-P96QO+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-S`*(RP@
M9G5Z>GD*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R
M(&9A:6QE9"XB"FUS9W-T<B`B57-M:F5R96YJ92!N:6IE('5S<&5L;RXB"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C<U"B,L(&9U>GIY"FUS9VED
M(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R(").82!R87-P;VQA9V%N:G4@
M<W4@<VQJ961EYFD@:6UE;FEC:3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R
M8F%I:F%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M,`IM<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@
M(D)A8VMG<F]U;F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP
M.C@Q"FUS9VED(")"860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@(D)A
M9"!K97)B97)O<R!U<V5R;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM
M<V=I9"`B0F%H86UA<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"B,L(&9U>GIY
M"FUS9VED(")"86AR86EN(@IM<V=S='(@(D)R87II;"(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3<W"FUS9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*
M;7-G<W1R(")"86QT:>AK:2`H25-/+3@X-3DM,3,I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM
M<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED
M(")"87)B861O<R(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP
M:'`Z,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E
M8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S"B,L(&9U
M>GIY"FUS9VED(")"87-E;&EN92(*;7-G<W1R(")696QIZ&EN82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C,*;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`HC
M+"!F=7IZ>0IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R(")696QIZ&EN82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(D)E;&EZ92(*;7-G<W1R(")696QI
MZ&EN82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(D)E;FEN(@IM<V=S
M='(@(E)E=6YI;VXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"97)M=61A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS
M9VED(")":7)T:&1A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S4S"B,L('!H<"UF;W)M870*;7-G:60@
M(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M.#D*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*
M;7-G<W1R(")6<G-T82!B;&]K82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G<W1R(")-87-N
M;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B0F]L:79I
M:F$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`U"FUS9VED(")"
M;V]K;6%R:W,B"FUS9W-T<B`B6F%B:6QJ9;EK92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*;7-G:60@(D)O
M<F1E<B(*;7-G<W1R(")2=6(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*
M;7-G<W1R(")$96)L:FEN82!R=6)O=F$Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0IM<V=I9"`B0F]R9&5R
M<R(*;7-G<W1R(")2=6)O=FDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")";W-N:6$@
M86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(D)O<VYA(&D@2&5R8V5G;W9I;F$B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.38*;7-G:60@(D)O=&@B"FUS
M9W-T<B`B3V)A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]T<W=A;F$B"FUS9W-T
M<B`B0F]C=F%N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(D1N;R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C,*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B0F]U
M=F5T(&]S=')V;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R87II;"(*;7-G<W1R
M(")"<F%Z:6PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES:"!);F1I86X@
M3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(D)R:71A;G-K82!);F1I:G-K;RU/
M:V5A;G-K82!497)I=&]R:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I
M($1A<G5S<V%L86TB"FUS9W-T<B`B0G)U;F5I($1A<G5S<V%L86TB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Q"FUS9VED(")"=6QG87)I82(*;7-G<W1R(")"=6=A<G-K82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G
M:60@(D)U;&QE=&5D($QI<W0B"FUS9W-T<B`B3&ES=&$@<V$@=&'H:V%M82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C$*;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R(")"=7)K
M:6YA($9A<V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)U;F1I(@IM<V=S='(@
M(D)U<G5N9&DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0T"FUS
M9VED(")#35,B"FUS9W-T<B`B0TU3(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S='(@(D-20R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED
M(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*
M;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B3W-O8FEN92#F
M7V5L:6IE+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V
M,PIM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0X-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3@W"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ-34*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(DMA
M;&5N9&%R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-@HC
M+"!F=7IZ>0IM<V=I9"`B0V%L;2(*;7-G<W1R(")/9'5S=&%N:2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R(")+86UB;_!A(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B2V%M97)U;B(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#86X@;F]T
M(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W
M<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S
M:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@
M<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)U<RYP:'`Z,C,U(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M<W%L+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C
M="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`B3F4@;6]G=2!S92!S<&]J
M:71I(&YA($E-05`@<V5R=F5R.B`E<R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C0Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!O<&5N
M(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#
M86YA9&$B"FUS9W-T<B`B2V%N861A(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`Q
M(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D
M96QE=&4N:6YC.C$Q('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ
M,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$R"FUS9VED
M(")#86YC96PB"FUS9W-T<B`B3V1U<W1A;FDB"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P
M;W)T(@IM<V=S='(@(D]D=7-T86YI(&]D('!R:6IA=F4@<')O8FQE;6$B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU
M,@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(N<&AP.CDQ"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G
M971&:6QE)R!P87)A;65T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,S$T"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO
M="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+G!H<#HQ,C@@9G)A;65W;W)K+T1A
M=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L('!H<"UF;W)M870*;7-G
M:60@(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV
M,#@*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE
M<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@
M(@HB<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T
M92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`HC
M+"!F=7IZ>0IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R(")/<&-I:F4B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G
M:60@(D-A<G)I97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDP"FUS9VED(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`B
M2V%T96=O<FEJ92!I(&]Z;F%K92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"B,L(&9U>GIY"FUS
M9VED(")#87EM86X@27-L86YD<R(*;7-G<W1R(")-87*Y86QO=F$@;W-T<G9A
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y
M-`HC+"!F=7IZ>0IM<V=I9"`B0V5L;"!0:&]N92(*;7-G<W1R(")496QE9F]N
M("AK=>9I*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C4*(RP@9G5Z>GD*;7-G:60@(D-E;&P@4')O<&5R=&EE
M<R(*;7-G<W1R(")/<V]B:6YE(.9?96QI:F4N+BXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L;"!P
M861D:6YG.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8Q"B,L(&9U>GIY"FUS9VED(")#96QL
M('!R;W!E<G1I97,B"FUS9W-T<B`B3W-O8FEN92#F7V5L:6IE+BXN(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G
M:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(W-`IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED(")#96QT:6,@*$E3
M3RTX.#4Y+3$T*2(*;7-G<W1R(")+96QT<VMI("A)4T\M.#@U.2TQ-"DB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(V"B,L(&9U>GIY"FUS9VED(")#96YT97(B"FUS9W-T<B`B2W)E:7)A:B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C4*;7-G:60@(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*
M;7-G<W1R(")#96YT<F%L;F\M069R:>AK82!297!U8FQI:V$B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H
M25-/+3@X-3DM,BDB"FUS9W-T<B`B0V5N=')A;&YO+65V<F]P<VMI("A)4T\M
M.#@U.2TR*2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-CDY"FUS9VED(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C$Q"FUS9VED(")#
M97)T:69I8V%T92!/=VYE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I9"`B0V5R=&EF:6-A=&4@4&]L
M:6-I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"B,L(&9U>GIY"FUS9VED
M(")#:&%D(@IM<V=S='(@(E1O:R!T96UE(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY
M-@IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(E!R;VUJ96YI(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,Q"B,L(&9U>GIY"FUS9VED(")#:&%N
M9V4@66]U<B!087-S=V]R9"(*;7-G<W1R(")087-S=V]R9"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HV-@IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE
M(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A
M;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(B(*(E!R;VUI
M:F5N:71E(&EM92!I(&%D<F5S=2!K;VIE('9I9&4@9')U9VD@:V%D82#H:71A
M:G4@:2!O9&=O=F%R86IU(&YA('9AN64@(@HB<&]R=6ME+B(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@
M>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E
M;G0@8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A
M=&]R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(W"B,L(&9U>GIY"FUS9VED(")#:&%R(@IM
M<V=S='(@(E1O:R!T96UE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"B,L(&9U>GIY"FUS9VED(")#:&5C
M7VL@3&EN:RXN+B(*;7-G<W1R(")?27IM:6IE;FD@;&EN:RXN+B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C<*;7-G:60@(D-H:6QE(@IM<V=S='(@(LAI;&4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W
M"FUS9VED(")#:&EN82(*;7-G<W1R(")+:6YA(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#`*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R
M*2(*;7-G<W1R(")+:6YE<VMI('!O:F5D;F]S=&%V;&IE;FD@*$=",C,Q,BDB
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0VAI;F5S92!4
M<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B2VEN97-K:2!T<F%D:6-I;VYA
M;&YI("A":6<U*2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H
M<#HR-CD*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(DEZ86)E
M<FET92"Y:69R=2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H
M<#HR-C@*;7-G:60@(D-H;V]S92!A('5S97)N86UE(@IM<V=S='(@(DEZ86)E
M<FET92!K;W)I<VYIZ&MO(&EM92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR.3@*;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SHB"FUS
M9W-T<B`B27IA8F5R:71E(&MA:V\@<V4@<')I:V%Z=6IE(&1A='5M.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E
M<F5D(&QI<W1S*2(*;7-G<W1R("))>F%B97)I=&4@=G)S='4@<W1I;&$@*'IA
M(&YU;65R:7-A;F4@;&ES=&4I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T
M;6%S($ES;&%N9"(*;7-G<W1R(")5<VMRN6YJ92!O<W1R=F\B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,N<&AP.C(Y-"!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z.#DS"B,L('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN:71I;VX@
M;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`IM<V=I9"`B0VQE87(B"FUS9W-T
M<B`B3^AI<W1I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R
M(")/Z&ES=&D@35-/9F9I8V4@=&%G;W9E(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$R.`HC+"!F=7IZ>0IM<V=I9"`B0VQE87(@475E<GDB"FUS9W-T<B`B
M3^AI<W1I(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,0HC
M+"!F=7IZ>0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R(")/Z&ES=&DB"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`HC+"!F=7IZ>0IM
M<V=I9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@(D]D86)E<FD@:V]D;FD@
M<F%S<&]R960@<VQO=F$Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,34*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ
M-C`*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM
M<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]K97EB;V%R9"YP:'`Z,30V('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3(*;7-G:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(T-`HC+"!F=7IZ>0IM<V=I9"`B0VQO=61S(@IM
M<V=S='(@(DMO<&ER86HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ-@HC+"!F=7IZ>0IM<V=I9"`B0VQO=61S($5A<FQY(@IM
M<V=S='(@(DMO<&ER86HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ-PHC+"!F=7IZ>0IM<V=I9"`B0VQO=61Y(@IM<V=S='(@
M(DMO<&ER86HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@
M27-L86YD<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B
M87(N:6YC.C(S"B,L(&9U>GIY"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM
M<V=S='(@(E-K=7!I(&9O;&1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*(RP@9G5Z>GD*;7-G:60@(D-O
M;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@(E-K=7!I(&9O;&1E<B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(DMA;6)O
M\&$B"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO
M<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR.0HC+"!F=7IZ>0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`B
M2V]M;W)I(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN
M<&AP.C,R-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP
M:'`Z,S(U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HU,#`@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,@IM<V=I
M9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X-#8*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T
M<B`B27IB;W(@8F]J92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30V"FUS9VED(")#;VQU;6X@=&ET
M;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M-C0*(RP@9G5Z>GD*;7-G:60@(D-O;6EC<R(*;7-G<W1R(").;W9A('!O<G5K
M82(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-0HC+"!F=7IZ>0IM<V=I9"`B
M0V]M;6%N9"(*;7-G<W1R(")+;VUP86YI:F$B"@HC.B!A9&UI;B]C;61S:&5L
M;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"B,L(&9U>GIY"FUS
M9VED(")#;VUM96YT(@IM<V=S='(@(EIA=G*Y96YO(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C8*(RP@9G5Z>GD*;7-G:60@(D-O
M;6UO;B!.86UE(@IM<V=S='(@(E9AN64@:6UE(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G
M:60@(D-O;6]R;W,B"FUS9W-T<B`B2V]M;W)I(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*
M;7-G<W1R(")+;VUP86YI:F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S$*(RP@9G5Z>GD*;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R(").;W9A('!O
M<G5K82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3<*(RP@
M9G5Z>GD*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R(")/<&-I:F4@;F%R961B
M93HB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T.0HC+"!F=7IZ>0IM<V=I
M9"`B0V]N9&ET:6]N<R(*;7-G<W1R(")/<&-I:F4@;F%R961B93HB"@HC.B!A
M9&UI;B]S971U<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$
M:69F97)E;F-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,30S"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@
M4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S4*;7-G:60@(D-O;F9I9W5R871I
M;VX@:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG=7)E
M("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z-3$*(RP@9G5Z>GD*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS
M9W-T<B`B4&%S<W=O<F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"B,L(&9U>GIY"FUS9VED(")#
M;VYG;R(*;7-G<W1R("):82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4*(RP@9G5Z>GD*;7-G:60@
M(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T
M<B`B3&%O($YA<F]D;F$@1&5M;VMR871S:V$@4F5P=6)L:6MA(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`HC+"!F=7IZ>0IM
M<V=I9"`B0V]N;F5C=&EO;B!F86EL960N(@IM<V=S='(@(E5S;6IE<F5N:F4@
M;FEJ92!U<W!E;&\N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,Q,`HC+"!F=7IZ>0IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z
M("(*;7-G<W1R(")5<VUJ97)E;FIE(&YI:F4@=7-P96QO+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C=&EO
M;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-#4*(RP@9G5Z>GD*;7-G:60@
M(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(E5S
M;6IE<F5N:F4@;FEJ92!U<W!E;&\N(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD
M:7-T.C$P,30*;7-G:60@(D-O;G1A8W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,PHC+"!F=7IZ>0IM
M<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U
M<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(EPB)7-<(B!J92!U<W!E<VYO(&1O
M9&%N('4@861R97-A<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-38@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HV,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<X
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.2!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S,*;7-G:60@(D-O;G1I;G5E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C8*(RP@9G5Z>GD*;7-G:60@(D-O;VL@27-L
M86YD<R(*;7-G<W1R(")";W5V970@;W-T<G9O(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,R"B,L(&9U>GIY"FUS9VED(")#;V]K:64B"FUS9W-T<B`B
M3F]V82!P;W)U:V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B2V]P
M:7)A:B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8X"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T
M<B`B57-M:F5R96YJ92!N:6IE('5S<&5L;RXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C
M=&EO;B(*;7-G<W1R(")+;W!I<F%J(&EZ86)R86YO(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDW-@IM<V=I
M9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P-3,*;7-G:60@
M(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I9"`B0V]U
M;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED(")#
M;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N
M=&%C="X@)7,B"FUS9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P
M;W)U:V4@;V0@)7,Z("5S(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.CDV(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"FUS
M9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0U-PIM<V=I9"`B0V]U;&0@
M;F]T(&)I;F0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L
M86YC92X@)7,B"FUS9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P
M;W)U:V4@;V0@)7,Z("5S(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0T
M,0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@;&1A<"!S
M97)V97(B"FUS9W-T<B`B3F4@;6]G=2!S92!S<&]J:71I(&YA($E-05`@<V5R
M=F5R.B`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R
M=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(DYE(&UO9W4@<V4@
M<W!O:FET:2!N82!)34%0('-E<G9E<CH@)7,B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,B"FUS9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P
M;W)U:V4@;V0@)7,Z("5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3$R-0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@
M4$=0(&1A=&$N(@IM<V=S='(@(DYI:F4@8FEL;R!M;V=U8V4@;V)R:7-A=&D@
M<&]R=6ME(&]D("5S.B`E<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3(R"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@
M9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B3FEJ
M92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P;W)U:V4@;V0@)7,Z("5S(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYI:F4@8FEL;R!M;V=U
M8V4@;V)R:7-A=&D@<&]R=6ME(&]D("5S.B`E<R(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C,X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB
M"FUS9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P;W)U:V4@;V0@
M)7,Z("5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS
M.#$@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.34S"B,L(&9U>GIY
M"FUS9VED(")#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E
M+6UA:6P@861D<F5S<RXB"FUS9W-T<B`B3F5D;WIV;VQJ96YA('-L;W9A('4@
M96UA:6P@861R97-I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,C@S"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@
M9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R(").:6IE(&)I
M;&\@;6]G=6-E(&]B<FES871I('!O<G5K92!O9"`E<SH@)7,B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PHC+"!F
M=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U
M=&EO;B!L:7-T+B(*;7-G<W1R(").:6IE(&)I;&\@;6]G=6-E(&]B<FES871I
M('!O<G5K92!O9"`E<SH@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C0T-@HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@
M;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L
M:7-T<RXB"FUS9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P;W)U
M:V4@;V0@)7,Z("5S(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H
M<#HX-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO
M860@<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R(").:6IE(&)I;&\@;6]G=6-E
M(&]B<FES871I('!O<G5K92!O9"`E<SH@)7,B"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z,3$P"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW,3D*;7-G:60@(D-O
M=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8W-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HR-C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R(").:6IE(&)I;&\@;6]G=6-E
M(&]B<FES871I('!O<G5K92!O9"`E<SH@)7,B"@HC.B!F<F%M97=O<FLO36%I
M;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C$Q,2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR,S<@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z-3$V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HV,3(*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8U-B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-CDY"FUS9VED(")#;W5L
M9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(S.`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S='(@(DYI
M:F4@8FEL;R!M;V=U8V4@;V)R:7-A=&D@<&]R=6ME(&]D("5S.B`E<R(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L
M9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S
M97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@8V]R
M<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R
M(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,`HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S<*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@S"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.0HC+"!F=7IZ>0IM<V=I
M9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R(").:6IE(&)I;&\@
M;6]G=6-E(&]B<FES871I('!O<G5K92!O9"`E<SH@)7,B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&%D9')E
M<W,@8F]O:RX@)7,B"FUS9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I<V%T
M:2!P;W)U:V4@;V0@)7,Z("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,B"FUS9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P;W)U:V4@
M;V0@)7,Z("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HT,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S
M='(@(DYI:F4@8FEL;R!M;V=U8V4@;V)R:7-A=&D@<&]R=6ME(&]D("5S.B`E
M<R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y
M.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"B,L
M(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P
M86)I;&ET:65S(@IM<V=S='(@(DYI:F4@8FEL;R!M;V=U8V4@;V)R:7-A=&D@
M<&]R=6ME(&]D("5S.B`E<R(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-30*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P;W)U
M:V4@;V0@)7,Z("5S(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R(").:6IE(&)I;&\@;6]G=6-E(&]B<FES871I('!O<G5K
M92!O9"`E<SH@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(D-O=6QD
M(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B3FEJ
M92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P;W)U:V4@;V0@)7,Z("5S(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ
M("5S(@IM<V=S='(@(DYI:F4@8FEL;R!M;V=U8V4@;V)R:7-A=&D@<&]R=6ME
M(&]D("5S.B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDU"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U
M<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(").:6IE(&)I
M;&\@;6]G=6-E(&]B<FES871I('!O<G5K92!O9"`E<SH@)7,B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@
M9FEL92`E<RXB"FUS9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P
M;W)U:V4@;V0@)7,Z("5S(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW
M-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@
M8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE
M(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E
M<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$T,PIM
M<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@
M(DYI:F4@8FEL;R!M;V=U8V4@;V)R:7-A=&D@<&]R=6ME(&]D("5S.B`E<R(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,C$Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D
M871E(&-O;G1A8W0N("5S(@IM<V=S='(@(DYI:F4@8FEL;R!M;V=U8V4@;V)R
M:7-A=&D@<&]R=6ME(&]D("5S.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<R(*;7-G<W1R(").:6IE(&)I;&\@;6]G=6-E(&]B<FES871I('!O<G5K
M92!O9"`E<SH@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF
M:6=U<F%T:6]N(&9O<B!<(B5S7"(Z("5S(@IM<V=S='(@(DYI:F4@8FEL;R!M
M;V=U8V4@;V)R:7-A=&D@<&]R=6ME(&]D("5S.B`E<R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-C8*;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO
M>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C$U-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG="!G
M:79E('5S97(@7"(E<UPB('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@
M9F]L9&5R(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,30Q.0HC+"!F=7IZ>0IM<V=I9"`B0V]U;G1E9"!T97AT
M(@IM<V=S='(@(DES<')A=FQJ96X@=&5K<W0B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4V.0HC+"!F=7IZ>0IM<V=I9"`B0V]U;G1R
M>2(*;7-G<W1R(").;W9A('!O<G5K82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR-S,*(RP@9G5Z>GD*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B
M3F]V82!P;W)U:V$B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G<W1R
M(")+<F5I<F%J(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S
M='(@(DYA<')A=FD@;&EN:R(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET
M>7-E;&5C="YI;F,Z.30*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T
M<B`B3F%P<F%V:2!N;W9I(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.3(*;7-G:60@(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G
M<W1R(")0<F%V;&IE;FIE('!O9"UF;VQD97)A(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HR-#`*(RP@9G5Z>GD*;7-G:60@(D-R96%T;W(@
M4&5R;6ES<VEO;G,B"FUS9W-T<B`B1&5F875L="!D;WIV;VQE(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(S,`HC+"!F=7IZ>0IM<V=I9"`B0W)E
M9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(D1E8V5M8F%R(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-SD*(RP@9G5Z>GD*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B2W)E:7)A:B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C(V"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(#0@4&AA
M<V5S(@IM<V=S='(@(DES<')A=FQJ96X@=&5K<W0B"@HC.B!A9&UI;B]S97-S
M:6]N<RYP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B
M"FUS9W-T<B`B27-P<F%V;&IE;B!T96MS="(*"B,Z(&QI8B]";&]C:R]T:6UE
M+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`HC+"!F=7IZ>0IM<V=I9"`B
M0W5R<F5N="!4:6UE(@IM<V=S='(@(DES<')A=FQJ96X@=&5K<W0B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-30*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@(DES
M<')A=FQJ96X@=&5K<W0B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S,*(RP@
M9G5Z>GD*;7-G:60@(D-U<G)E;G0@57-E<G,B"FUS9W-T<B`B27-P<F%V;&IE
M;B!T96MS="(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*(RP@9G5Z>GD*
M;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R("))<W!R879L:F5N('1E
M:W-T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(W-0IM<V=I
M9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,R"B,L(&9U>GIY"FUS
M9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@(DES<')A=FQJ96X@=&5K<W0B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`X"B,L('!H<"UF;W)M870*
M;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E
M<RXB"FUS9W-T<B`B4&]D97-I=&4@>F%D871K92!K;VII(.9E('-E(&EZ=G*Y
M879A=&D@;F%K;VX@<')I:F%V92!N82`E<RXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U
M="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,U"B,L(&9U>GIY"FUS9VED(")#=70@<V5L96-T:6]N(@IM
M<V=S='(@(DEZ8F]R(&)O:F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#>7!R=7,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G:60@
M(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@S"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B
M0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-CD*(RP@9G5Z>GD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@
M(D-E;G1R86QN;RU!9G)IZ&MA(%)E<'5B;&EK82(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-3$@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,R.#$*;7-G:60@(B(*(D133B`H<V5E(&AT='`Z+R]P
M96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT
M<F\M9'-N+G!H<"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA
M;F-E+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`B
M1&YE=FYO(@H*(SH@861M:6XO9&%T871R964N<&AP.C8U"B,L(&9U>GIY"FUS
M9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@(E]$871A5')E92(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-SD*;7-G:60@(D1A=&%B87-E
M($QO;VMU<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S
M.3D*;7-G:60@(D1A=&4B"FUS9W-T<B`B1&%T=6TB"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B1&%T
M92!296-E:79E9"(*;7-G<W1R(")0<FEM;&IE;F$@;F$B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.#`W"B,L(&9U>GIY"FUS9VED(")$871E('-E
M;&5C=&EO;B(*;7-G<W1R(")6<F5M96YS:V$@>F]N82(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR.3(@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,R,@HC+"!F=7IZ>0IM<V=I9"`B1&%Y(@IM<V=S='(@(DUA:B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS-@HC+"!F=7IZ>0IM<V=I9"`B1&5?;&5T92!#;VQU;6XB"FUS9W-T
M<B`B3V)R:;EI(&9O;&1E<BAE*2(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0U,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$96-E;6)E<B(*;7-G<W1R(")$
M96-E;6)A<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,38*(RP@9G5Z>GD*;7-G:60@(D1E8VEM86P@;G5M
M8F5R<R(*;7-G<W1R(")$96-E;6)A<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C`*;7-G:60@(D1E8W)E87-E($EN9&5N
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C$X-R!L:6(O<')E9G,N<&AP.C$Q-PIM<V=I9"`B1&5F875L="(*;7-G<W1R
M(")3=&%N9&%R9&YO(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z-S<*;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B
M4W1A;F1A<F1N82!B;VIA(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT
M:71Y+G!H<#HY,0IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*;7-G<W1R(")$
M969A=6QT(&ED96YT:71E="(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV
M-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R(")3=&%N
M9&%R9&YO(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$
M969I;FET:6]N<R(*;7-G<W1R(")$969I;FEC:6IE(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HW,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C,V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$Q-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,"!T96UP
M;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM
M<V=S='(@(D]B<FFY:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@HC+"!F=7IZ>0IM<V=I9"`B1&5L971E
M($-E;&PB"FUS9W-T<B`B3V)R:;EI(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ
M.3D@861M:6XO9W)O=7!S+G!H<#HR,C<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T
M92!'<F]U<"(*;7-G<W1R(")/8G)IN6DB"@HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HR-#D*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!,;V<B"FUS
M9W-T<B`B3V)R:;EI(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HW-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,0HC+"!F=7IZ
M>0IM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B3V)R:;EI('!O
M<G5K92(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S='(@
M(D)R:7-A;FIE(&D@:7IB86-I=F%N:F4@<&]R=6MA(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PHC+"!F=7IZ
M>0IM<V=I9"`B1&5L971E(&-E;&PB"FUS9W-T<B`B3V)R:;EI(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PHC
M+"!F=7IZ>0IM<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R(")/8G)IN6DB
M"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X
M:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS
M9W-T<B`B27IM:6IE;FD@9&]Z=F]L92!Z82`E<R(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z-#(T"B,L('!H<"UF;W)M870*;7-G:60@(D1E
M;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI
M<W-I;VYS/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8W"B,L(&9U>GIY"FUS9VED(")$96QE
M=&4@<F]W(@IM<V=S='(@(D]B<FFY:2(*"B,Z('1E;7!L871E<R]P<F5F<R]D
M96QE=&5I9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I
M9&5N=&ET>2(*;7-G<W1R(")/8G)IN6D@:7IA8G)A;FD@:61E;G1I=&5T(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8W"B,L(&9U>GIY"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L
M=6UN(@IM<V=S='(@(E!O9&5S:2!V<F5M96YS:W4@>F]N=2XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*
M(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T
M<B`B4&]D97-I('9R96UE;G-K=2!Z;VYU+B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C,V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE
M=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B3FEJ
M92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P;W)U:V4@;V0@)7,Z("5S(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C,*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M.34*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C(Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(U,PHC+"!F=7IZ>0IM<V=I9"`B1&5L:79E<GD@=&EM92(*;7-G
M<W1R(")/8G)IN6DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$96YM87)K(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C(Y"FUS
M9VED(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R(")/<&FY:71E('!R
M;V)L96UE('4@<F%D=2!S82!W96)M86EL;VTB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HY,S@@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B
M3W!I<R(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DU"FUS9VED
M(")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DY"B,L(&9U>GIY
M"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI
M;FES=')A=&]R+B(*;7-G<W1R(")/=F$@<&]R=6MA(&IE('!R:6IA=FQJ96YA
M(&MA;R!S<&%M('!O<G5K82!A9&UI;FES=')A=&]R=2!S:7-T96UA+B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,3D*;7-G:60@(D1E=F5L;W!M
M96YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$W"FUS
M9VED(")$97<@4&]I;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR.30*;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-PIM
M<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N
M(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I
M9VAT('1O(&QE9G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP
M:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R(")$:7)E:W1O<FEJ(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V-@IM<V=I9"`B1&ES<&QA>2`R
M-"UH;W5R('1I;65S/R(*;7-G<W1R(")0<FEK8;YI('9R:6IE;64@=2`R-"US
M871N;VT@9F]R;6%T=3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<*
M;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R(")/<&-I:F4@<')I:V%Z
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HY-@HC+"!F=7IZ
M>0IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R(")0
M<FEK8;YI('!R;V=N;WIU("A4048I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HX-0IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R(")0
M<FEK8;YI('!R;V=N;WIU("A4048I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C@Q-PHC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS
M9W-T<B`B4')I:V&^:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H
M<#HQ.3`*;7-G:60@(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,@HC+"!F=7IZ>0IM
M<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G<W1R(")5;F1E;&5T92(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C
M=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'`B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN
M('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,`HC+"!F=7IZ>0IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B
M;&EC(@IM<V=S='(@(D-E;G1R86QN;RU!9G)IZ&MA(%)E<'5B;&EK82(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA
M=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0T"FUS9VED(")$;W=N;&]A
M9"(*;7-G<W1R(")$;W=N;&]A9"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C@T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A
M9"`E<R(*;7-G<W1R(")$;W=N;&]A9"`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ-C(*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U
M<F%T:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Q,#<*;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B
M1')U9W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$S"B,L(&9U>GIY"FUS9VED(")%+4UA:6PB"FUS9W-T<B`B4V%N
M9'5C92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N
M<&AP.CDR"FUS9VED(")%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O
M<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHS-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,34@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C<R"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI
M;F,Z,C4*;7-G:60@(D5D:70B"FUS9W-T<B`B27IM:6IE;FDB"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4P('1E;7!L871E<R]P;W)T86PO
M961I="YI;F,Z,C4*;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T<B`B(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H<#HR,C8*(RP@
M9G5Z>GD*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T<B`B3V)R:;EI(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$P,`IM<V=I9"`B161I="!097)M:7-S:6]N(@IM
M<V=S='(@(DEZ;6EJ96YI(&1O>G9O;'4B"@HC.B!S97)V:6-E<R]S:&%R97,O
M961I="YP:'`Z,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@
M(DEZ;6EJ96YI(&1O>G9O;&4B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP
M:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,@
M9F]R("5S(@IM<V=S='(@(DEZ;6EJ96YI(&1O>G9O;&4@>F$@)7,B"@HC.B!T
M96UP;&%T97,O<')E9G,O87!P+FEN8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@
M9F]R.B(*;7-G<W1R("))>FUI:F5N:71E(&]P8VEJ92!Z83HB"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,V-PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S
M='(@(DEZ;6EJ96YI(&1O>G9O;&4@>F$@)7,B"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%
M9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("))>FUI:F5N:2!D;WIV
M;VQE('IA("5S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U"B,L(&9U
M>GIY"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B06MC:6IA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HS,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B16ET:&5R
M(&5N86)L92!I="!T:&5N.B`E<RP@;W(@=7-E('1H92!B87-I8R!(5$U,('9E
M<G-I;VXZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(D5L
M(%-A;'9A9&]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM<V=I9"`B16QE;65N="XN
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R-"!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#8Y"B,L(&9U>GIY"FUS9VED(")%;6%I;"(*;7-G
M<W1R(")386YD=6-E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU-C4@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"FUS9VED(")%
M;6%I;"!!9&1R97-S(@IM<V=S='(@(D5M86EL(&%D<F5S82(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C,*(RP@9G5Z>GD*;7-G:60@(D5M86EL
M(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")%;6%I;"!A9')E<V$B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3@Y"B,L(&9U>GIY"FUS
M9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")/<W1A;&4@
M:6YF;W)M86-I:F4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I
M8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W87DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(Y.`IM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(E-M86IL:6II(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`R"B,L(&9U>GIY"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R(")6
M8;YN92!P;W)U:V4B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,C0S(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT.#0*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8V,B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z,34P"B,L(&9U>GIY"FUS9VED(")%;7!T>2!R97-U;'0N
M(@IM<V=S='(@(DES<')A>FYI(&MO<G!U(@H*(SH@9G)A;65W;W)K+U-13"]3
M44PO2V5Y=V]R9',N<&AP.C$Q,PHC+"!F=7IZ>0IM<V=I9"`B16UP='D@<V5A
M<F-H('1E<FUS(@IM<V=S='(@(DES<')A>FYI(&9O;&1E<B!K;W)P82(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#,*;7-G:60@(D5N86)L92!I;G-E
M<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3@*;7-G
M:60@(D5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@
M(D%K=&EV:7)A:B!K;VYT96MS="!M96YI(&YA(&1E<VYO;2!K;&EK=3\B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DX(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X,3$*(RP@9G5Z>GD*;7-G:60@(D5N9"!Y96%R(@IM<V=S
M='(@(E!R;[EI<FD@9F]L9&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%9&ET;W(B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R,0IM<V=I9"`B
M(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B
M92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D
M+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE(&EM86=E(%523"!H
M97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HX.3$*;7-G:60@(D5N=&5R('1H92!L971T97)S(&)E;&]W
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDY
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")%<75A=&]R:6%L($=U
M:6YE82(*;7-G<W1R(")%:W9A=&]R:6IA;&YA($=V:6YE:F$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<Q"FUS9VED(")%<FET<F5A(@IM<V=S='(@(D5R:71R96IA(@H*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A
M='5S+G!H<#HR-PHC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#4@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4U"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S8@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HX,@IM<V=I
M9"`B17)R;W(B"FUS9W-T<B`B1W)EN6MA(@H*(SH@9G)A;65W;W)K+U1E;7!L
M871E+U1E;7!L871E+G!H<#HT-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R
M;W(@8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(D5R
M<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET:"!E;6%I;"!M97-S
M86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,30R"B,L('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<P"FUS9VED(")%<W1O;FEA(@IM<V=S='(@(D5S=&]N
M:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`B171I
M;W!I:F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T
M:&YI8R(*;7-G<W1R(")%=&YIZ&MI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B179R;W!A(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S.0IM<V=I9"`B179E<GD@,34@
M;6EN=71E<R(*;7-G<W1R(")3=F%K:6@@,34@;6EN=71A(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,X.0IM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM
M<V=S='(@(E-V86MI:"`R(&UI;G5T92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS,S8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X-PIM<V=I9"`B179E
M<GD@,S`@<V5C;VYD<R(*;7-G<W1R(")3=F%K:6@@,S`@<V5K=6YD:2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S@@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,Y,`IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(E-V86MI
M:"`U(&UI;G5T82(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N
M86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S='(@(DMO9"!S
M=F%K92!P<FEJ879E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,`IM
M<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(E-V86MI:"!P;VQA('-A
M=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,W(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.#@*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R(")3
M=F%K:2!M:6YU="(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(T
M"FUS9VED(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`B5G)I:F5D;F]S=&D@
M<')I;6IE<FDZ(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C@Q(&%D;6EN+V-M
M9'-H96QL+G!H<#HU,"!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(W"FUS9VED(")%
M>&5C=71E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C0W-0HC+"!F=7IZ>0IM<V=I9"`B17AP86YD(@IM<V=S='(@
M(E!R;[EI<FD@<W9E(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN
M8SHS,@HC+"!F=7IZ>0IM<V=I9"`B17AP86YD(%-I9&5B87(B"FUS9W-T<B`B
M4')ON6ER:2!F;VQD97(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D
M<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP
M96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G
M:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-@IM<V=I9"`B17AP;VYE;G0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I9"`B1E10('5P;&]A9"!O
M9B!S971U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M<W%L+G!H<#HR,38*;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N
M8V5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY.`HC+"!F
M=7IZ>0IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N
M(@IM<V=S='(@(DYE(&UO9W4@<V4@<W!O:FET:2!N82!)34%0('-E<G9E<CH@
M)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.3@*(RP@9G5Z
M>GD*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM
M<V=S='(@(DYE(&UO9W4@<V4@<W!O:FET:2!N82!)34%0('-E<G9E<CH@)7,B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8X-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.3$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@W"FUS
M9VED(")&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DW(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S(T"B,L('!H<"UF;W)M870*;7-G
M:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`HC+"!F=7IZ
M>0IM<V=I9"`B1F%I<B(*;7-G<W1R("):86ER(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I
M9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S,*(RP@9G5Z>GD*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T
M<B`B0F]U=F5T(&]S=')V;R(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR
M,S@*(RP@9G5Z>GD*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R(")'<F6Y
M:V$Z("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S0Y"B,L(&9U>GIY"FUS9VED(")&87AE<R(*;7-G<W1R
M("));64B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHV-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B1F5B<G5A<B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C(P"FUS9VED(")&965L<R!,:6ME(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*;7-G
M:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F5W(%-H;W=E<G,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-`IM<V=I9"`B1FEE;&0@
M;6%T<FEX(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,S,S0*;7-G:60@(D9I9VQE="!#05!40TA!(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S@*;7-G:60@(D9I9VQE="!F;VYT
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY
M"FUS9VED(")&:6QE(@IM<V=S='(@(D9I;'1E<FDB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O
M=6YT.B`E<R!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S
M(&9I;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT,#<*(RP@9G5Z>GD*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R("))
M;64@9&%T;W1E:V4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C8S(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-0HC
M+"!F=7IZ>0IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(DEM92!D871O=&5K
M92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y.34*(RP@9G5Z>GD*
M;7-G:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S='(@(FYI:F5D;F\@<')A=FEL
M;R!N:6IE(&]D86)R86YO(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30X-@HC+"!F=7IZ>0IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`B4&]L
M:F4B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-3D*;7-G
M:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#D*;7-G:60@(D9I;'1E<G,B
M"FUS9W-T<B`B1FEL=&5R:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@
M(D9I;FQA;F0B"FUS9W-T<B`B5')AOFDB"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,38V"B,L(&9U>GIY"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@(E!R
M=F$@4W1R86YA(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C
M:R]M;V]N+G!H<#HW-@HC+"!F=7IZ>0IM<V=I9"`B1FER<W0@475A<G1E<B(*
M;7-G<W1R(")0<G9A(%-T<F%N82(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR-38*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C,Q"FUS9VED(")&;&EP(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E<R!N
M;W0@97AI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR,@HC+"!F=7IZ>0IM<V=I9"`B1F]N="!#;VQO
M<B(*;7-G<W1R(")3=&%N9&%R9&YA(&)O:F$B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V
M"B,L(&9U>GIY"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P
M;W)T(&EM86=E<R(*;7-G<W1R(")68;D@8G)O=W-E<B!N92!P;V1ROF%V82!O
M=G4@;6]G=>9N;W-T+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,T"B,L
M(&9U>GIY"FUS9VED(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R(")0<FEK8;YI
M('!R;V=N;WIU("A4048I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C<Y"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE
M(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT
M.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I
M9&4@8FQO8VLI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,3`R"B,L(&9U>GIY"FUS9VED(")&;W)G;W0@>6]U<B!P87-S=V]R
M9#\B"FUS9W-T<B`B27IA8F5R:71E(+EI9G)U(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0V,@HC+"!F=7IZ>0IM<V=I9"`B1F]R;7,B"FUS9W-T
M<B`B3V0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*(RP@9G5Z>GD*
M;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`B1F]L9&5R:2(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`HC+"!F=7IZ>0IM<V=I
M9"`B1F]R='5N97,B"FUS9W-T<B`B1F]L9&5R:2(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS.0HC+"!F=7IZ>0IM<V=I9"`B1F]R='5N97,@,B(*;7-G
M<W1R(")&;VQD97)I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U
M,PHC+"!F=7IZ>0IM<V=I9"`B1F]R=6US(@IM<V=S='(@(D9O;&1E<FDB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3`Y"B,L(&9U>GIY"FUS9VED
M(")&;W)W87)D<R(*;7-G<W1R(")0<F]S;&EJ961I(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,`HC+"!F=7IZ>0IM<V=I
M9"`B1G(B"FUS9W-T<B`B3V0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,S"B,L(&9U>GIY"FUS9VED(")&<F%M
M97,B"FUS9W-T<B`B26UE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PHC+"!F=7IZ>0IM<V=I9"`B
M1G)A;F-E(@IM<V=S='(@(DEM92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!4
M97)R:71O<FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S='(@(D]D
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T."!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8P"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HT,#8*(RP@9G5Z>GD*;7-G:60@(D9R;VT@=&AE("(*;7-G
M<W1R(")/9"(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X
M"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(D1E=&%L:F%N(&]P
M:7,B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K+VUO;VXN
M<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C8P"B,L(&9U>GIY"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`B
M26UE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1V%B;VXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.38@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(D=A;6)I82(*;7-G<W1R("):
M86UB:6IA(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO
M;B(*;7-G<W1R(")6<F%T:2!S=&%R=2!K;VYF:6=U<F%C:6IU(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL.C@*;7-G:60@(D=E;F5R
M871E9"!#;V1E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G
M:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDS(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<U"B,L(&9U>GIY"FUS9VED(")':&%N82(*;7-G
M<W1R(")+:6YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<U
M"B,L(&9U>GIY"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(DEM92!D871O
M=&5K92(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$R"FUS9VED(")'
M;R(*;7-G<W1R(")+<F5N:2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M,`IM<V=I9"`B1V]E9&5L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HQ,3(X"B,L(&9U>GIY"FUS9VED(")'
M;V]G;&4@36%P<R(*;7-G<W1R(")';V]G;&4@<')E=')A9V$B"@HC.B!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H(@IM
M<V=S='(@(D=O;V=L92!P<F5T<F%G82(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR,S<*;7-G:60@(D=R87ES8V%L92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W)E96-E(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED(")'<F5E:R`H25-/
M+3@X-3DM-RDB"FUS9W-T<B`B1W+H:VD@*$E33RTX.#4Y+3<I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-0HC+"!F=7IZ>0IM<V=I9"`B1W)E96YL86YD(@IM<V=S='(@(E1O:R!T
M96UE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-`HC+"!F=7IZ>0IM<V=I9"`B1W)E;F%D82(*;7-G
M<W1R(")4;VL@=&5M92(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y"B,L(&9U
M>GIY"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(E<R!A
M9&UI;FES=')A8VEJ82(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"YP:'`Z
M-3D@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$V.0IM<V=I9"`B
M1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,P-PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G
M<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S
M='(@(DYI:F4@=7-P96QO('-P8;EA=F%N:F4@;F5Z879RN65N92!P;W)U:V4N
M($]V;R!J92!P;W)U:V$@<V5R=F5R83H@)7,B"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,3$X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HQ,C0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@
M=&\@9&5L971E(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C,W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P
M.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S$T(&QI8B]";&]C:R]G;V]G
M;&4N<&AP.C,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<W"B,L
M(&9U>GIY"FUS9VED(")'<F]U<',B"FUS9W-T<B`B7T=R=7!E(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-@IM<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.CDW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-PHC+"!F=7IZ>0IM<V=I9"`B1W5A;2(*;7-G<W1R(")*=6YI(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'=65R;G-E>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(R-B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"B,L(&9U>GIY"FUS9VED(")'=65S
M="!097)M:7-S:6]N<R(*;7-G<W1R("))>FUI:F5N:2!D;WIV;VQE(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W,`IM<V=I9"`B1W5E<W1B;V]K
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(D=U:6YE
M82(*;7-G<W1R(")*=6YI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"B,L(&9U>GIY"FUS9VED
M(")'=6EN96$M0FES<V%U(@IM<V=S='(@(DIU;FDB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*
M(RP@9G5Z>GD*;7-G:60@(D=U>6%N82(*;7-G<W1R(")*=6YI(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.38P"FUS9VED(")(5$U,(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#4*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@
M9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V
M"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G
M:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L
M87-T(')O=R!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]H='1P+G!H<#HQ-3<*(RP@9G5Z>GD*;7-G:60@(DA45%`@075T
M:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")5<VUJ97)E;FIE(&YI
M:F4@=7-P96QO+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2&%I=&DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS
M9VED(")(87-H+4%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@IM<V=I9"`B2&%Z92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,3D@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,@HC+"!F=7IZ>0IM<V=I9"`B2&5A9&5R
M(@IM<V=S='(@(E!O;6_F(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E
M+W1A8FQE<V5T+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B2&5A9&5R<R(*;7-G
M<W1R(")0;VUOYB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD
M(&%N9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"FUS9VED(")(96%V>2!4
M+5-T;W)M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@V
M"FUS9VED(")(96)R97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`B2&5B<F5J
M<VMI("A)4T\M.#@U.2TX+4DI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`HC+"!F=7IZ>0IM<V=I9"`B2&5I
M9VAT(@IM<V=S='(@(DYOYB(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92](
M96QP+G!H<#HQ-SD@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$X
M-@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ-R!T96UP;&%T97,O:&5L
M<"]I;F1E>"YI;F,Z,PIM<V=I9"`B2&5L<"(*;7-G<W1R(")0;VUOYB(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*;7-G
M:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S-S$*(RP@9G5Z>GD*;7-G:60@(DAE;'!E<B(*
M;7-G<W1R(")0;VUOYB(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0HC+"!F
M=7IZ>0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R(")0;VUOYB(*"B,Z('1E
M;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C$P"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@
M=&AE(&9I;&4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8Y"B,L(&9U>GIY"FUS9VED(")(:6=H(@IM<V=S
M='(@(DYOYB(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP
M;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-0IM<V=I9"`B2&]?;64B
M"FUS9W-T<B`B4&_H7V5T86LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")(;VQY
M(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U,S4*;7-G:60@(DAO;64B"FUS9W-T
M<B`B4&_H971A:R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(D%D<F5S
M82`H:W7F:2DB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*(RP@9G5Z
M>GD*;7-G:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S='(@(D1I<F5K=&]R:6HB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP
M"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(E1E;&5F;VX@*&MUYFDI(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R(")(;VYD=7)A
M<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(DAO
M;F<@2V]N9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-0IM<V=I
M9"`B2&]R9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C0T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,CDY"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S
M86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0S-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@
M:6X@;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C$R-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS
M9W-T<B`B26UE(&9O;&1E<F$@7"(E<UPB(&IE('5S<&IEN6YO('!R;VUJ96YJ
M96YO('4@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,C(S"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN
M92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C4P,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N
M97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-#<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB
M)7-<(CH@)7,B"FUS9W-T<B`B26UE(&9O;&1E<F$@7"(E<UPB(&IE('5S<&IE
MN6YO('!R;VUJ96YJ96YO('4@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z-#<T"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@
M;V8@='EP92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C$Q.3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*
M;7-G<W1R(")5<W!J9;EN;R!S=&4@<')I:F%V;&IE;FD@;F$@7"(E<UPB(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,S,V"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H
M<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B57-P:F6Y;F\@<W1E('!R:6IA
M=FQJ96YI(&YA(%PB)7-<(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z,S0P"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN
M;W=N('-H87)E(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L
M(%)U;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX,@IM<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M,0IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T
M(2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W
M;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD
M<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED
M(")(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C,P"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4Y"FUS9VED
M(")(=6UI9&ET>3H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G5S+G!H<#HQ-S(@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)S<6PN<&AP.C(S-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B24U!
M4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B57-M:F5R
M96YJ92!N:6IE('5S<&5L;RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G5S+G!H<#HR,30@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y
M-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@
M9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G5S+G!H<#HQ-SD@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP
M.C(T,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X
M('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B57-M:F5R96YJ
M92!N:6IE('5S<&5L;RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,S$V"FUS9VED("))4"!!9&1R97-S(@IM<V=S='(@(DE0(&%D<F5S82(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0
M($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B25`@861R97-A(&YI
M:F4@9&]S='5P;F$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC
M+G!H<#HX.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@
M0TE$4B!B;&]C:RXB"FUS9W-T<B`B25`@861R97-A(&YI:F4@9&]Z=F]L:F5N
M82!U;G5T87(@0TE$4B!B;&]K82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N
M('9I;VQA=&EO;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"B,L(&9U>GIY"FUS9VED
M("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B4')I;6QJ96YA('!R:6IE
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@R"FUS9VED("))8V5L86YD(@IM<V=S='(@(DES;&%N
M9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S8*;7-G:60@(DEC;VYS
M($]N;'DB"FUS9W-T<B`B4V%M;R!I:V]N92(*"B,Z('5T:6PO:6-O;E]B<F]W
M<V5R+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@)7,B
M"FUS9W-T<B`B26MO;F4@>F$@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S<W"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B26MO;F4@
M<V$@=&5K<W1O;2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3`*;7-G
M:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B26UE(&ED96YT:71E=&$Z
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DR"B,L
M('!H<"UF;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R
M<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U-0IM<V=I9"`B(@HB
M268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP
M;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T
M=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3<S"FUS9VED("(B
M"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I
M;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA>65D
M(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(X"B,L(&9U
M>GIY"FUS9VED("));6%G92!0<F5V:65W.B(*;7-G<W1R(")0<F5T:&]D;F$@
M<W1R86YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,0HC+"!F=7IZ>0IM<V=I
M9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(E!O;&IE(@H*(SH@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW('1E;7!L871E<R]D871A+V1A
M=&5M87`N:6YC.C<*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-"!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW"B,L('!H<"UF;W)M870*;7-G
M:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O
M<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S
M-0IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S,@HC+"!F=7IZ>0IM<V=I9"`B26YC;W)R96-T('5S97)N86UE(&%N
M9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`B3FEJ92!P;W-L86YO(&MO<FES;FGH
M:V\@:6UE(&DO:6QI(+EI9G)A+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C4Q"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT
M97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB
M861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C$*;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#$*(RP@9G5Z>GD*;7-G:60@(DEN9&EA(@IM<V=S='(@(FYO;F4B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U-"!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*(RP@9G5Z>GD*;7-G:60@(DEN
M9&]N97-I82(*;7-G<W1R(")N;VYE(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F9C.#(R+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B26YF;R(*
M;7-G<W1R("))9VYO<FFY:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR-3<*(RP@9G5Z>GD*;7-G:60@(DEN9F]R;6%T:6]N(@IM<V=S='(@(E!E
M<G-O;F%L;F4@:6YF;W)M86-I:F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S,P"B,L(&9U>GIY"FUS9VED("));F9O<FUA=&EO;B!N;R!L
M;VYG97(@879A:6QA8FQE+B(*;7-G<W1R(").96UA(&1O<W1U<&YI:"!O<&-I
M:F$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C`*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!);6%G
M92(*;7-G<W1R(")/9&=O=F]R96YE('!O<G5K92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*(RP@9G5Z>GD*;7-G:60@
M(DEN<V5R="!486)L92(*;7-G<W1R(")/9&=O=F]R96YE('!O<G5K92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G
M:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*(RP@9G5Z
M>GD*;7-G:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R(")0<FEM
M;&IE;F$@<')I:F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU
M;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM
M<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@
M;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,@HC+"!F=7IZ>0IM<V=I9"`B26YS97)T
M(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B4&]D
M97-I('9R96UE;G-K=2!Z;VYU+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@
M;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHW,`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R
M96YT(&YO9&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P
M87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B(@H*
M(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E
M<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(S.0IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@
M=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3@*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R
M(@IM<V=S='(@(E!R:6UL:F5N82!P<FEJ92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*(RP@9G5Z>GD*;7-G
M:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R(")0<FEM;&IE;F$@<')I
M:F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8T"B,L(&9U>GIY"FUS9VED("));G-E<G0@8V]L=6UN(&%F=&5R
M(@IM<V=S='(@(E!R:6UL:F5N82!P<FEJ92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*(RP@9G5Z>GD*;7-G
M:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(E!R:6UL:F5N82!P
M<FEJ92(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.CDP"FUS9VED("));G-E<G0@;65S<V%G97,B"FUS9W-T<B`B1&]D879A;FIE
M('!O<G5K82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHT-0IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!A9G1E
M<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#0*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!P
M87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@(E!R:6UL:F5N82!P<FEJ92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-CD*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`B
M3V1G;W9O<F5N92!P;W)U:V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8X"B,L(&9U>GIY"FUS9VED("));G-E
M<G0@<F]W(&)E9F]R92(*;7-G<W1R(")0<FEM;&IE;F$@<')I:F4B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,P"FUS9VED("));G-E<G0@=&AE(')E
M<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C8*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS
M9W-T<B`B3V1G;W9O<F5N92!P;W)U:V4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"B,L(&9U>GIY"FUS9VED("));G-E
M<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B7TEZ;6EJ96YI(&QI;FLN+BXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T
M,PIM<V=I9"`B26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D
M:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@(DEN<W5F
M9FEC:65N="!C<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$P-S4*;7-G:60@(DEN=&5G97(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$S,PIM<V=I9"`B26YT96=E<B!L
M:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI9"!51$@N("A5<V5R
M($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+WII<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]Z:7`N<&AP.C(P,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O>FEP+G!H<#HR,3`*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`HC+"!F
M=7IZ>0IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`B3F5D
M;WIV;VQJ96YA('-L;W9A('4@96UA:6P@861R97-I+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B
M26YV86QI9"!B871C:"!)1"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C`X-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,34X
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,S(@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C(Y.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O
M=&%B;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#`*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@9&5S
M=&EN871I;VX@861D<F5S<RXB"FUS9W-T<B`B3F5D;WIV;VQJ96YA('-L;W9A
M('4@96UA:6P@861R97-I+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]D8G@N<&AP.C@Q"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]D8G@N<&AP.C$P,`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M9&)X+G!H<#HR,C`*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@9FEL92!F;W)M
M870B"FUS9W-T<B`B5G)E;65N<VMA('IO;F$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3<W"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&QI
M8V5N<V4@:V5Y+B(*;7-G<W1R(").961O>G9O;&IE;F$@<VQO=F$@=2!E;6%I
M;"!A9')E<VDN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W
M,0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB
M"FUS9W-T<B`B3F5D;WIV;VQJ96YA('-L;W9A('4@96UA:6P@861R97-I+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S
M"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*
M;7-G<W1R(").961O>G9O;&IE;F$@<VQO=F$@=2!E;6%I;"!A9')E<VDN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDV"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE
M=&5R<RXB"FUS9W-T<B`B3F5D;WIV;VQJ96YA('-L;W9A('4@96UA:6P@861R
M97-I+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR-PHC+"!F=7IZ
M>0IM<V=I9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B
M3F5D;WIV;VQJ96YA('-L;W9A('4@96UA:6P@861R97-I+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S,*(RP@9G5Z>GD*;7-G:60@(DEN
M=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B3F5D;WIV;VQJ96YA('-L;W9A
M('4@96UA:6P@861R97-I+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-S4*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@<')O9'5C="!C;V1E
M+B(*;7-G<W1R(").961O>G9O;&IE;F$@<VQO=F$@=2!E;6%I;"!A9')E<VDN
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`V"B,L(&9U>GIY"FUS9VED("));G9A;&ED('!R;W1O8V]L+B(*;7-G
M<W1R(").961O>G9O;&IE;F$@<VQO=F$@=2!E;6%I;"!A9')E<VDN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY,PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C<Q(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z.#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$P-S8@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HQ,C8R"B,L(&9U>GIY"FUS9VED("));G9A;&ED
M('-H87)E(&]B:F5C="(*;7-G<W1R(").961O>G9O;&IE;F$@<VQO=F$@=2!E
M;6%I;"!A9')E<VDN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`Q"B,L(&9U>GIY"FUS9VED("));G9A;&ED('-O
M=7)C92!A9&1R97-S+B(*;7-G<W1R(").961O>G9O;&IE;F$@<VQO=F$@=2!E
M;6%I;"!A9')E<VDN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S$Q"B,L(&9U>GIY"FUS9VED("));G9A;&ED('5N
M:6-O9&4@9&%T82XB"FUS9W-T<B`B3F5D;WIV;VQJ96YA('-L;W9A('4@96UA
M:6P@861R97-I+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3<*
M;7-G:60@(DEN=F5N=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<Y"B,L(&9U>GIY"FUS9VED("))
M;G9E<G0@<V5L96-T:6]N(@IM<V=S='(@(E9R96UE;G-K82!Z;VYA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@R"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#`*(RP@9G5Z>GD*;7-G:60@(DER96QA;F0B"FUS9W-T
M<B`B5&]K('1E;64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M-0IM<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D
M(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`HC+"!F=7IZ>0IM
M<V=I9"`B27-R865L(@IM<V=S='(@(E1O:R!T96UE(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C4*;7-G:60@(DES<W5E<B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CD*;7-G:60@(DET86QI8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*
M(RP@9G5Z>GD*;7-G:60@(DET86QY(@IM<V=S='(@(D1N979N;R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,@HC+"!F=7IZ>0IM<V=I9"`B2F%M86EC82(*;7-G<W1R("):86UB
M:6IA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B2F%N=6%R(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@S"FUS9VED(")*87!A;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X-PIM<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G
M<W1R(")*87!A;G-K:2`H25-/+3(P,C(M2E`I(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HS,3`*;7-G:60@(B(*(DIA=F%S8W)I<'0@:&%S(&)E
M96X@9&ES86)L960@;VX@>6]U<B!B<F]W<V5R(&%N9"!T:&ES('!A9V4@;6%Y
M(&YO="!B92`B"B)D:7-P;&%Y:6YG(&-O<G)E8W1L>2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`W"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R(")*=6QI(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS
M9W-T<B`B2G5N:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$W
M"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G:60@
M(DIU<W1I9GD@3&5F="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF
M>2!2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA>F%K
M:'-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(V-`IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@U"FUS9VED(")+97)B
M97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L
M($YE=V)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$Q"B,L(&9U>GIY"FUS9VED(")+97D@0W)E871I;VXB"FUS
M9W-T<B`B3W!C:6IE(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@
M3&5N9W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0Q,0HC+"!F=7IZ>0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B
M36EM92!T:7`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4Y.`HC+"!F=7IZ>0IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(E!O<G5K
M82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<T,`IM<V=I
M9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G
M:60@(DMI9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+:7)I
M8F%T:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*(RP@9G5Z>GD*;7-G:60@
M(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM<V=S
M='(@(DQA;R!.87)O9&YA($1E;6]K<F%T<VMA(%)E<'5B;&EK82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED(")+;W)E86X@*$55
M0RU+4BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+=7=A:70B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+>7)G>7IS=&%N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z.`IM<V=I
M9"`B3&%?>6]U="(*;7-G<W1R(")285]S<&]R960B"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C@S"FUS9VED("),86YG=6%G92(*;7-G<W1R(")*
M97II:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C
M<F%T:6,@4F5P=6)L:6,B"FUS9W-T<B`B3&%O($YA<F]D;F$@1&5M;VMR871S
M:V$@4F5P=6)L:6MA(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V.0HC+"!F
M=7IZ>0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(E!R=F$@4W1R86YA(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<V"B,L(&9U>GIY"FUS9VED("),
M87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R(")087-S=V]R9"(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HX-B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@*(RP@
M9G5Z>GD*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R(")0<G9A(%-T<F%N
M82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Q"FUS9VED("),87-T(%5P
M9&%T960Z(@IM<V=S='(@(EIA9&YJ82!I>FUJ96YA.B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T
M(&QO9VEN.B`E<R(*;7-G<W1R("):861N:F$@<')I:F%V83H@)7,B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HW,C$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R("):861N:F$@<')I
M:F%V83H@)7,@<V$@861R97-E.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.C<Q-@IM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`B
M6F%D;FIA('!R:6IA=F$Z($YI:V%D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),
M871V:6$B"FUS9W-T<B`B3&%T=FEJ82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@(EIA:V]N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"FUS9VED
M("),87EO=70B"FUS9W-T<B`B4F%S<&]R960B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T
M>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I
M9"`B3&5B86YO;B(*;7-G<W1R("),:6)A;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0HC+"!F=7IZ>0IM<V=I
M9"`B3&5F="(*;7-G<W1R(")0<F5B86-I(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$Q.0IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-0HC+"!F=7IZ>0IM<V=I
M9"`B3&5F="!V86QU97,B"FUS9W-T<B`B6F%D;FIA('-T<F%N82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX.`IM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("),97-O=&\B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@
M(DQE=F5L(@IM<V=S='(@(DYI:V%D82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B
M3&EB97)I82(*;7-G<W1R("),:6)E<FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,30W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I
M9"`B3&EB>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R("),:6)I:G-K82!!
M<F%P<VMA($2^86UA:&ER:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:65C
M:'1E;G-T96EN(@IM<V=S='(@(DQI:'1E;KET86IN(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@(DQI9VAT($1R
M:7IZ;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C8*(RP@9G5Z>GD*;7-G:60@(DQI9VAT(%)A:6XB"FUS
M9W-T<B`B4')I:F%V:2!S92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!286EN($5A<FQY(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(X"FUS9VED("),:6=H="!286EN($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI
M9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P"FUS9VED("),:6=H="!286EN('=I
M=&@@5&AU;F1E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M,@IM<V=I9"`B3&EG:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0U"B,L(&9U>GIY"FUS9VED("),:6UE<FEC
M:R(*;7-G<W1R("),:6)E<FEJ82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$X,30*(RP@9G5Z>GD*;7-G:60@(DQI;FLB"FUS9W-T<B`B3&EN:V]V
M:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU-PIM<V=I9"`B3&EN:R!P;VEN=',@=&\Z(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S4*;7-G:60@(DQI;FL@
M=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I
M<W!L87EI;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R
M+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,PIM<V=I9"`B3&EN:W,B"FUS9W-T
M<B`B3&EN:V]V:2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@HC+"!F
M=7IZ>0IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(DYO=F$@<&]R=6MA
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*
M;7-G:60@(DQI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R
M("),:7-T86YJ92`M(&MO<FES;FEK(&UOOF4@=FED:F5T:2!F;VQD97(B"@HC
M.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,S"B,L(&9U>GIY"FUS9VED("),:7-T
M($1A=&%B87-E<R(*;7-G<W1R("):861N:F$@<W1R86YA(@H*(SH@<V5R=FEC
M97,O:&5L<"]I;F1E>"YP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(DQI<W0@2&5L
M<"!4;W!I8W,B"FUS9W-T<B`B4&]M;^8B"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3,R"B,L(&9U>GIY"FUS9VED("),:7-T(%1A8FQE<R(*;7-G<W1R("):
M861N:F$@<W1R86YA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S
M+G!H<#HU.30*(RP@9G5Z>GD*;7-G:60@(DQI<W0M07)C:&EV92(*;7-G<W1R
M(")386MR:6H@;F5U<&ES86YE(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](
M96%D97)S+G!H<#HU.#D*(RP@9G5Z>GD*;7-G:60@(DQI<W0M2&5L<"(*;7-G
M<W1R(")0;VUOYB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP
M:'`Z-3DV"B,L(&9U>GIY"FUS9VED("),:7-T+4ED(@IM<V=S='(@(E!O;6_F
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3(*(RP@
M9G5Z>GD*;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T<B`B4&]M;^8B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,PIM<V=I9"`B3&ES
M="U0;W-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A
M9&5R<RYP:'`Z-3DQ"B,L(&9U>GIY"FUS9VED("),:7-T+5-U8G-C<FEB92(*
M;7-G<W1R(")386MR:6H@;F5U<&ES86YE(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12](96%D97)S+G!H<#HU.3`*(RP@9G5Z>GD*;7-G:60@(DQI<W0M56YS
M=6)S8W)I8F4B"FUS9W-T<B`B4V%K<FEJ(&YE=7!I<V%N92(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HU,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(E5S;6IE<F5N
M:F4@;FEJ92!U<W!E;&\N(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,U"B,L
M('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC
M.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-PHC+"!F=7IZ>0IM<V=I
M9"`B3&ET97)A='5R92(*;7-G<W1R(")68;D@<&]T<&ES.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX.0IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(DQI='9A(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6UA9V5S+G!H<#HX,PIM<V=I9"`B
M3&]A9&EN9RXN+B(*;7-G<W1R(")5Z&ET879A;2XN+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,3$*;7-G:60@(DQO8V%L('1I;64Z("(*
M;7-G<W1R("),;VMA;&YO('9R:6IE;64Z("(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX,PIM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(DQO
M:V%L;F4@<&]S=&%V:V4@:2!V<FEJ96UE(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-S$@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C8T"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HR,B!L:6(O0FQO8VLO
M;65T87(N<&AP.C8U"FUS9VED("),;V-A=&EO;B(*;7-G<W1R("),;VMA8VEJ
M82(*"B,Z(&QO9VEN+G!H<#HQ-S(@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N
M<&AP.C$Y,2!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS"B,Z('1E;7!L
M871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z.3`*;7-G:60@(DQO9R!I;B(*;7-G<W1R(")0<FEJ879I('-E(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U"FUS9VED("),;V<@
M;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.#4*;7-G:60@(DQO9R!O=70B"FUS
M9W-T<B`B27IL87HB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-3D*(RP@
M9G5Z>GD*;7-G:60@(DQO9VEN(@IM<V=S='(@(E!R:6IA=FD@<V4B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W"FUS9VED("),;V=I;B!487-K<R(*
M;7-G<W1R("):861A8VD@<')I:F%V92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.CDY-@IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U
M<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2XB
M"FUS9W-T<B`B(@HB4')I:F%V82!N:6IE('5S<&IE;&$N($YA:G9E<F]V871N
M:6IE(&IE('!O9W)EN6YO('5N97-E;F\@:V]R:7-N:>AK;R!I;64@:6QI("(*
M(KEI9G)A+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY,@IM<V=I
M9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R(")0<FEJ879A(&YI:F4@=7-P:F5L
M82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8U"FUS9VED("),
M;VYG('1E>'0B"FUS9W-T<B`B1'5G:2!T96MS="(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B3&]V92(*;7-G<W1R(").
M87-T879I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(DQO=R(*;7-G<W1R("):86MO;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N
M9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C$W"B,L(&9U>GIY"FUS9VED("),;W=E<B!R;VUA;B!N=6UB97)S
M(@IM<V=S='(@(D1E8V5M8F%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),=7AE
M;6)O=7)G(@IM<V=S='(@(DQU:W-E;6)U<F<B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`P"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,S@@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR.#$*;7-G:60@(DU/5$0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@(DU3
M+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES
M=&5N97(O;6]B:6QE+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B35-'(@IM<V=S
M='(@(D--4R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@HC+"!F=7IZ>0IM<V=I9"`B36%C86\B
M"FUS9W-T<B`B36%R="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%C961O;FEA
M+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*(RP@9G5Z>GD*;7-G:60@(DUA
M9VEC(@IM<V=S='(@(DUA<G0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z.#$*(RP@9G5Z>GD*;7-G:60@(DUA:6PB"FUS9W-T<B`B4V%N9'5C92(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,C(*;7-G:60@(DUA:6P@
M061M:6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B36%L
M87=I(@IM<V=S='(@(E-A;F1U8V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$V-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUA
M;&%Y<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,38T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM<V=I
M9"`B36%L9&EV97,B"FUS9W-T<B`B1FEL=&5R:2!P;[ET92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,@HC+"!F=7IZ>0IM<V=I9"`B36%L:2(*;7-G<W1R(")386YD=6-E(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDT"B,L(&9U>GIY"FUS9VED(")-86QT82(*;7-G<W1R(")3
M86YD=6-E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ"FUS9VED("(B
M"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L
M86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@=VET
M:"!T:&]S92!C871E9V]R:65S+B(*;7-G<W1R("(B"B).87!R879I=&4@:V%T
M96=O<FEJ92!S=&%V:VD@:2!Z82!S=F%K=2!O9"!N:FEH(&]D<F5D:71E(&]D
M9V]V87)A:G7F=2!B;VIU+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,34S"FUS9VED(")-87`R-"!M87`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P
M.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q
M-C@*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T;W)E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@(DUA<G0B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q
M"B,L(&9U>GIY"FUS9VED(")-87)G:6XB"FUS9W-T<B`B57!O>F]R96YJ92(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS
M9VED(")-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`B3WIN
M8>AA=F%N:F4@:V%O('!R;^AI=&%N;R]N97!R;^AI=&%N;R(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K
M('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*
M;7-G<W1R(")/>FYAZ&%V86YJ92!D<G5G:6T@;WIN86MA;6$@*&YP<BX@=F&^
M;F\@:6QI(&]D9V]V;W)E;F\I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-87)S
M:&%L;"!)<VQA;F1S(@IM<V=S='(@(DUA<KEA;&]V82!O<W1R=F$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B36%R=&EN:6LB
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B36%T
M8VAI;F<@9FEE;&1S(@IM<V=S='(@(D]D9V]V87)A:G7F82!P;VQJ82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY,PIM<V=I9"`B36%U<FET86YI82(*;7-G<W1R(")-875R:71A
M;FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@
M(DUA=7)I8VEJ=7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`X"B,L(&9U>GIY"FUS9VED(")-87@@;65S<V%G92!P
M87)T<R!E>&-E961E9"XB"FUS9W-T<B`B4&]L:F$@<&]R=6ME(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@
M:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y
M.`IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+V%P:2YP:'`Z.#8*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F(%!O
M<G1A;"!";&]C:W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.#DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3<*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S.0IM<V=I9"`B36%X:6UU;2!L96YG
M=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R(")-86HB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$W"B,L(&9U>GIY"FUS9VED(")-87EO='1E(@IM<V=S='(@(DUA:B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B
M365D:6-I;F4B"FUS9W-T<B`B3V)R:7-A;F$B"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED(")-96UB97)S(@IM<V=S='(@
M(LAL86YO=FDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<X"FUS9VED
M(")-96YU(&UO9&4Z(@IM<V=S='(@(E9R<W1A(&UE;FEJ83HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P"FUS
M9VED(")-97)G92!C96QL<R(*;7-G<W1R(")3<&]J:2!P;VQJ82(*"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T
M871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U
M"FUS9VED(")-97-S86=E(@IM<V=S='(@(E!O<G5K82(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$V"FUS9VED("(B"B)-97-S86=E
M(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I
M9FEC871E(&-O=6QD(&YO="!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$P"B,L(&9U>GIY"FUS9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@
M(E!O;&IA('!O<G5K92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-PHC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*(RP@9G5Z>GD*;7-G:60@
M(DUE<W-A9V4@='EP92(*;7-G<W1R(")$871U;2!P;W)U:V4B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E871H97(B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PHC+"!F=7IZ>0IM<V=I
M9"`B365T87(@8FQO8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3F5M82!D
M;W-T=7!N:6@@;W!C:6IA+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$R
M"B,L(&9U>GIY"FUS9VED("(B"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE
M+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A
M=&]R+B(*;7-G<W1R(")/=F$@<&]R=6MA(&IE('!R:6IA=FQJ96YA(&MA;R!S
M<&%M('!O<G5K82!A9&UI;FES=')A=&]R=2!S:7-T96UA+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C4*;7-G:60@(DUE=&%R1$(@:7,@
M;F]T(&-O;FYE8W1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV-R!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<T"B,L(&9U>GIY"FUS9VED(")-971H;V0B"FUS9W-T
M<B`B3&5S;W1O(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HX
M,2!F<F%M97=O<FLO4E!#+U)00R]S;V%P+G!H<#HQ,3<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]R97-T+G!H<#HX,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H
M;V0Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HW-"!L:6(O0FQO8VLO;65T87(N<&AP.C<U"FUS9VED(")-971R:6,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-97AI8V\B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O;F5S:6$L($9E9&5R871E
M9"!3=&%T97,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"B,L(&9U>GIY"FUS9VED(")-
M:61D;&4B"FUS9W-T<B`B4')E8F%C:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T
M<B`B36EM92!T:7`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,`IM<V=I
M9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S`R"FUS9VED(")-:6X@=&5M<"!L87-T(#8@
M:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO
M="!Y970@97AP:7)E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,T"B,L(&9U>GIY"FUS9VED(")-:7)R
M;W(B"FUS9W-T<B`B1W)EN6MA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(U,`IM<V=I
M9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U"FUS9VED("(B"B)-
M:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET
M(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`T"B,L(&9U>GIY"FUS9VED(")-:7-S:6YG(&UE<W-A
M9V4@240N(@IM<V=S='(@(D]V82!P;W)U:V$@=2(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED(")-
M:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.30*(RP@9G5Z>GD*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS
M9W-T<B`B3W9A('!O<G5K82!U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHU-@HC+"!F=7IZ>0IM<V=I9"`B36\B"FUS9W-T
M<B`B4')E8F%C:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW-`HC
M+"!F=7IZ>0IM<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`B3F]V82!P;[ET
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X
M"FUS9VED(")-;V1E<F%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C8V(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HX.`IM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3,*(RP@9G5Z>GD*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B
M7TEZ;6EJ96YI(&QI;FLN+BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8W,PHC+"!F=7IZ>0IM<V=I9"`B36]D=6QU<R(*;7-G<W1R
M(")0<F5B86-I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VQD;W9A+"!297!U
M8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*(RP@9G5Z>GD*;7-G
M:60@(DUO;F%C;R(*;7-G<W1R(")-87)T(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED
M(")-;VYG;VQI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-3DT"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4W"FUS
M9VED(")-;VYT:&QY(@IM<V=S='(@(DUJ97-EZ&YO(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT
M"FUS9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0
M:&%S97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z,3<R(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(U,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H
M86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*
M;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO<W1L>2!#;&5A<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS-`HC+"!F=7IZ>0IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R
M(")+;W!I<F%J(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S4*;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,#D*(RP@9G5Z>GD*
M;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R(")P;VUJ97)I(&YIOF4B"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,3,*(RP@9G5Z>GD*
M;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R(")0<F5B86-I(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$W"B,L(&9U>GIY"FUS9VED
M(")-;W9E(%)I9VAT(@IM<V=S='(@(E!R96)A8VDB"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,#4*(RP@9G5Z>GD*;7-G:60@(DUO
M=F4@57`B"FUS9W-T<B`B4')E8F%C:2(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HU,C0*(RP@9G5Z>GD*;7-G:60@(DUO=F4@
M9&]W;B(*;7-G<W1R(")P;VUJ97)I(&YIOF4B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(S"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HU,C0*(RP@9G5Z>GD*;7-G:60@(DUO
M=F4@=7`B"FUS9W-T<B`B<&]M:F5R:2!V:;EE(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"B,L
M(&9U>GIY"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(DUA<G1I;FEK(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-`IM<V=I9"`B375L=&DM
M;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#4U"FUS9VED(")-=6QT
M:6UA<"!52R!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(T,@HC+"!F=7IZ>0IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N
M(@IM<V=S='(@(FYI:F5D;F\@<')A=FEL;R!N:6IE(&]D86)R86YO(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P,`HC+"!F=7IZ>0IM<V=I9"`B
M37D@06-C;W5N="(*;7-G<W1R(")28>AU;F]V;V1S='9O(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C(X"B,L(&9U>GIY"FUS9VED(")->2!!8V-O=6YT
M($EN9F]R;6%T:6]N(@IM<V=S='(@(E9AN64@:6YF;W)M86-I:F4B"@HC.B!S
M97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C4T"B,L(&9U>GIY"FUS9VED(")-
M>2!0;W)T86PB"FUS9W-T<B`B4F%S<&]R960@;6]G('!O<G1A;&$B"@HC.B!S
M97)V:6-E<R]P;W)T86PO961I="YP:'`Z,3,V"FUS9VED(")->2!0;W)T86P@
M3&%Y;W5T(@IM<V=S='(@(E)A<W!O<F5D(&UO9R!P;W)T86QA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4W"FUS9VED(").3RP@
M22!$;R!.3U0@06=R964B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&YE9BYP:'`Z,S@*;7-G:60@(DYA;64B"FUS9W-T<B`B26UE(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDU"B,L(&9U>GIY"FUS9VED(").86UI8FEA(@IM<V=S='(@(EIA;6)I
M:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-PHC+"!F=7IZ>0IM<V=I9"`B3F5P86PB"FUS9W-T<B`B3F]V
M82!P;[ET82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PHC+"!F=7IZ>0IM<V=I9"`B3F5T:&5R
M;&%N9',B"FUS9W-T<B`B3F]V:2!:96QA;F0B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I
M9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C87!E
M($)A<V4@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!#02!2979O8V%T:6]N
M(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X
M-`IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G:60@(DYE
M='-C87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").971S8V%P92!3
M4TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC
M871E(&-O;6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.#`*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E
M('1Y<&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(U,0IM<V=I9"`B3F5T=V]R:R(*;7-G<W1R(")-<F6^82(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S,U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#8*;7-G:60@
M(DYE=F5R(@IM<V=S='(@(DYI:V%D82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B
M3F5W($-A;&5D;VYI82(*;7-G<W1R(").;W9A($MA;&5D;VYI:F$B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-@IM
M<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(DYO=F$@:V%T96=O<FEJ82(*
M"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HX
M,0HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z
M.#<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP
M.CDW"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H
M<#HQ,#$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E
M('1O("5S(@IM<V=S='(@(DYO=F$@<&]R=6MA("@E<RDB"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C
M:R]M;V]N+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(DYO=FD@
M;6IE<V5C(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS
M-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B3F]V
M;R!K;W)I<VYIZ&MO(&EM92`H;FEJ92!O8F%V97IN;RDB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3@*;7-G:60@(DYE=R!:96%L86YD(@IM<V=S='(@(DYO=FD@6F5L86YD(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,W"B,L(&9U>GIY"FUS
M9VED(").97<@<&%S<W=O<F0B"FUS9W-T<B`BJ6EF<F$B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-Q;"YP:'`Z,C(W"B,L('!H<"UF;W)M870*;7-G:60@
M(DYE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R"FUS9VED(").97<@
M<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@
M=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(DYO=FD@<')O>F]R("A?<')A>F%N
M*2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Y"FUS
M9VED(").97=S(@IM<V=S='(@(DYO=F]S=&DB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S`U"FUS9VED(").97=S9W)O=7!S(@IM<V=S='(@(DYE
M=W,M9W)U<&4B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ-2!T
M96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT,0HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR
M-0IM<V=I9"`B3F5X="(*;7-G<W1R(")$86QJ92(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B3F5X="`T(%!H87-E<R(*;7-G
M<W1R(")3;&IE9&7F82!F87IA(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HS-S(@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S8*
M;7-G:60@(DYE>'0@;W!T:6]N<R(*;7-G<W1R(")3;&IE9&7F92!O<&-I:F4B
M"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C$P,PHC+"!F=7IZ>0IM
M<V=I9"`B3F5X=#XB"FUS9W-T<B`B1&%L:F4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G
M:60@(DYI8V%R86=U82(*;7-G<W1R(").:6MA<F%G=F$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.38*;7-G:60@(DYI9V5R(@IM<V=S='(@(DYI9V5R(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV
M"FUS9VED(").:6=E<FEA(@IM<V=S='(@(DYI9V5R:6IA(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,X,`IM<V=I9"`B3FEG:'0B"FUS9W-T
M<B`B3F_F(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-SD@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").:75E(@IM<V=S='(@(DYI
M=64B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.38S"FUS9VED(").;R(*;7-G<W1R(").92(*"B,Z('1E;7!L871E<R]A9&UI
M;B]S971U<"]D:69F+FAT;6PZ.0IM<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I
M9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H
M<#HQ,#4*;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG
M($E33R!I;6%G97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B3F\@8F%T8V@@
M=&5M<&QA=&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C<Y(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C(T-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR
M-C<*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O
M<VET:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A
M;"YP:'`Z-3`*;7-G:60@(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R
M($U#04P@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+V1I9F8N<&AP.C4T"B,L(&9U>GIY"FUS9VED(").;R!C:&%N9V4N(@IM
M<V=S='(@(E!R;VUJ96YI(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HQ-38*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T
M:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,38W(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`R
M"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<W,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z.#(T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HV-CD*;7-G:60@(DYO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S$W"FUS
M9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO(&-R
M961I="!L969T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`HC+"!F=7IZ>0IM<V=I9"`B3F\@
M9&5S=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@(DYO=F4@<&]R=6ME(@H*
M(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#<W"B,L(&9U>GIY
M"FUS9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(E!O;&IE(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(").;R!I
M8V]N<R!F;W5N9"XB"FUS9W-T<B`B)7,@;FEJ92!P<F]N8?!E;BXB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(X(&QI8B]";&]C:R]S=6YR
M:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R,PIM<V=I9"`B
M3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,38Y"B,L(&9U>GIY"FUS9VED(").;R!L;V-A
M=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B3FEJ961A;B!F;VQD97(@;FEJ92!S
M<&5C:69I8VER86XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S,PHC+"!F=7IZ>0IM<V=I9"`B3F\@;65S<V%G92!S
M=7!P;&EE9"XB"FUS9W-T<B`B3F]V92!P;W)U:V4B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@HC+"!F=7IZ>0IM
M<V=I9"`B3F\@;F%M92!S<&5C:69I960N(@IM<V=S='(@(FYI:V%K878@=&5K
M<W0@;FEJ92!S<&5C:69I8VER86XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PHC+"!F=7IZ>0IM<V=I9"`B3F\@
M;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`B;FEK86MA=B!T96MS="!N:6IE
M('-P96-I9FEC:7)A;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-`IM
M<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z.3$*;7-G:60@(DYO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C$P.`IM<V=I
M9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP
M:'`Z-S(*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O
M<R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S87-L+G!H<#HW-R!F<F%M97=O<FLO075T:"]!=71H+VQO9VEN
M+G!H<#HX-`HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-S4*;7-G
M:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P87-S
M=V0N<&AP.C$S-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!
M4U-71"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]S;6(N<&AP.C@T"FUS9VED(").;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R.#8*;7-G:60@(B(*
M(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@
M3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O<FL@=VET:"!0
M2T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C<U,`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R
M(").92!I>F)R:7-A;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0S"B,L(&9U>GIY"FUS9VED(").;R!R=6QE
M<R(*;7-G<W1R(").:6IE9&YA(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-3
M5BYP:'`Z-#0Y"B,L(&9U>GIY"FUS9VED(").;R!S97!A<F%T;W(@<W!E8VEF
M:65D+B(*;7-G<W1R(")N:6MA:V%V('1E:W-T(&YI:F4@<W!E8VEF:6-I<F%N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT-`HC+"!F=7IZ>0IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B3F4@
M:7IB<FES86YA(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#,*
M;7-G:60@(DYO('-U8V@@9FEL92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,3,X"FUS9VED(").;R!T96UP;W)A<GD@9&ER
M96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"FUS9VED
M(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`B
M3FEJ92!P;W-L86YO(&MO<FES;FGH:V\@:6UE(&DO:6QI(+EI9G)A+B(*"B,Z
M(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED(").;R!V
M86QI9"!834P@9&%T82!R971U<FYE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3<Q"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY.#$*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDY,@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`P.0IM<V=I9"`B3F\@=F%L
M=65S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C`*
M;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A
M=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(X"FUS9VED(").;R!V97)S:6]N
M(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I
M='ES96QE8W0N:6YC.CDS"FUS9VED(").;VYE(@IM<V=S='(@(DYI:F5D86XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP
M"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(").;W)D:6,@*$E33RTX.#4Y
M+3$P*2(*;7-G<W1R(").;W)D:6IS:VD@*$E33RTX.#4Y+3$P*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T
M<B`B36%RN6%L;W9A(&]S=')V82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS
M,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES
M<&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"B,L(&9U>GIY"FUS9VED
M(").;W)T:&5R;B!-87)I86YA($ES;&%N9',B"FUS9W-T<B`B36%RN6%L;W9A
M(&]S=')V82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PHC+"!F=7IZ>0IM<V=I9"`B3F]R=V%Y
M(@IM<V=S='(@(E!R;W-L:6IE9&DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8T,`HC+"!F=7IZ>0IM<V=I9"`B3F]T($%F=&5R(@IM
M<V=S='(@(DYO="!$<F%F="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C,Y"B,L(&9U>GIY"FUS9VED(").;W0@0F5F;W)E(@IM<V=S
M='(@(DYO="!$<F%F="(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C0P.`HC+"!F=7IZ>0IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@
M(E!R879A8R!S;W)T:7)A;FIA(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+G!H<#HV,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX,PHC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T
M96=Y+G!H<#HY-`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*
M(RP@9G5Z>GD*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B3F4@
M:7IB<FES86YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHV.`HC+"!F=7IZ>0IM<V=I9"`B3F]T('-E="(*;7-G<W1R(").
M92!I>F)R:7-A;F$B"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S
M<VEO;DAA;F1L97(N<&AP.C$T,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L
M97(O4V5S<VEO;DAA;F1L97(N<&AP.C$U.`HC.B!F<F%M97=O<FLO4V5S<VEO
M;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$W,PHC.B!F<F%M97=O<FLO
M4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$X-PHC.B!F<F%M
M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C(S-"!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HR,#4@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(S,`HC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z,C0X(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-C4*
M(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,CDW"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,3(@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C,R.0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,S8R(&9R86UE=V]R:R]61E,O5D93+G!H<#HT,C(*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C4P,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3<P"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HU.#<@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C8V-0HC+"!F=7IZ>0IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B
M3F4@:7IB<FES86YA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C(T-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`P-0HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3<X"B,L(&9U>GIY"FUS9VED(").
M;W1E<R(*;7-G<W1R(").:6IE9&YA(@H*(SH@<V5R=FEC97,O;V)R;W=S97(O
M:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C
M:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0Q,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-S4*;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@(DYO=F5M8F%R
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`T-@HC+"!F=7IZ>0IM
M<V=I9"`B3G5M8F5R(@IM<V=S='(@(DYO=F5M8F%R(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30R-0IM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E
M<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V
M.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(S"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T-#4@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#0*(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B!O9B!C;VQU
M;6YS(@IM<V=S='(@(G!O;6IE<FD@;FF^92(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$S-C<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,0HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0S('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"B,L(&9U>GIY"FUS9VED(").
M=6UB97(@;V8@<F]W<R(*;7-G<W1R(").;W9E;6)A<B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"FUS9VED(").
M=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U
M=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*(RP@
M9G5Z>GD*;7-G:60@(D]B:F5C="(*;7-G<W1R(")496UA(@H*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*(RP@9G5Z>GD*;7-G:60@(D]B:F5C
M="!#<F5A=&]R(@IM<V=S='(@(E1E;6$B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,3`T"FUS9VED(")/8W1A;"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T
M;V)E<B(*;7-G<W1R(")/:W1O8F%R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(V"FUS9VED(")/9F9I8V4B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS
M9VED(")/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS
M-@HC+"!F=7IZ>0IM<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@(JEI9G)A
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C0V"B,L(&9U>GIY
M"FUS9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N(@IM<V=S='(@
M(E!A<W-W;W)D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")/;6%N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S
M"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD
M97)S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.34*
M;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-3$@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3DW,0HC+"!F=7IZ>0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@
M861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R(").961O>G9O;&IE;F$@<VQO=F$@
M=2!E;6%I;"!A9')E<VDN(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP
M.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI
M<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B"B)P97)M
M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M:69R86UE+G!H<#HS-0IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR
M-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A
M=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*;7-G:60@(D]P
M97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B3W!E<F%T:79N:2!S:7-T96TB"@HC
M.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I
M;VYS(@IM<V=S='(@(D]P8VEJ92(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS
M,2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R(")/<&-I:F4@>F$@)7,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$X"B,L
M(&9U>GIY"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B3&ES=&$@<V$@
M=&'H:V%M82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-38W"B,L(&9U>GIY"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`B4F5G
M:7-T<F%C:6IA(&MO<FES;FEK82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I;VYA;"!5;FET(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S(*(RP@
M9G5Z>GD*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B57!O>F]R96YJ92(*
M"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A
M<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T
M96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS
M9VED(")/=&AE<B(*;7-G<W1R(")/<W1A;&\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3$S(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,C(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,2!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,30Q"FUS9VED(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R
M(")/<W1A;&4@:6YF;W)M86-I:F4B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C,Q"B,L(&9U>GIY"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*
M;7-G<W1R(")+;W)I<VYIZ&ME(&]P8VEJ92(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<&%M+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B4$%-(&%U=&AE;G1I
M8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(E5S;6IE<F5N:F4@
M;FEJ92!U<W!E;&\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R
M:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A8VME;F0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3(W
M,PHC+"!F=7IZ>0IM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S
M='(@(EIA=&%M;FD@<&]T<&ES93\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,S$Y"FUS9VED(")01U`@16YC<GEP=&5D($1A=&$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,W
M,0IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,U,PIM<V=I9"`B4$=0(%-I9VYE
M9"]%;F-R>7!T960@1&%T82(*;7-G<W1R("(B"@HC.B!A9&UI;B]P:'!S:&5L
M;"YP:'`Z-C@*(RP@9G5Z>GD*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(DAO
M<F1E(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE
M;&PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S<*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G
M:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%-N;W<B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#`*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@
M4W5N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0R"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C<T"FUS9VED(")03U-)6"!E>'1E
M;G-I;VX@:7,@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ
M-#D*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B
M4&%D9&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*(RP@9G5Z>GD*;7-G
M:60@(E!A:VES=&%N(@IM<V=S='(@(D%F9V%N:7-T86XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`Q"FUS9VED(")086QA=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS
M9VED(")086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.`HC+"!F=7IZ>0IM<V=I9"`B4&%N86UA(@IM<V=S
M='(@(DMA;F%D82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U
M:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"B,L(&9U>GIY"FUS9VED
M(")087)A9W5A>2(*;7-G<W1R(").:6MA<F%G=F$B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@HC+"!F=7IZ>0IM<V=I9"`B
M4&%R=&QY($-L;W5D>2(*;7-G<W1R(")+;W!I<F%J(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-PHC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3$@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`Q.`HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C<W('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R,PIM<V=I9"`B4&%S<W=O
M<F0B"FUS9W-T<B`BJ6EF<F$B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C$S,C(*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*
M;7-G<W1R(")087-S=V]R9"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D
M:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)
M55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(P-3,*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D('=I
M=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(E!A<W-W;W)D(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP"B,L(&9U>GIY"FUS9VED(")087-S
M=V]R9#HB"FUS9W-T<B`B4&%S<W=O<F0B"@HC.B!T96UP;&%T97,O;&]G:6XO
M;6]B:6QE+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G
M<W1R(")087-S=V]R9"(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,#,T"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z,34*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D<R!M=7-T
M(&UA=&-H+B(*;7-G<W1R(")%;6%I;"!A9')E<V$B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3$Y('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR,@HC+"!F=7IZ>0IM<V=I9"`B4&%S=&4B"FUS9W-T
M<B`B1&%T=6TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,W"FUS9VED(")087-T92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C4Q"B,L(&9U>GIY"FUS9VED(")0871H(@IM<V=S='(@(D1A='5M(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O
M861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@
M4VEG;G5P<SHB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4T"FUS9VED(")096]P;&4B"FUS9W-T<B`B3&IU9&DB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R
M8V5N="(*;7-G<W1R(")0<F]C96YA="(*"B,Z('1E;7!L871E<R]M86EN=&5N
M86YC92]M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED(")097)F;W)M($UA:6YT
M96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B27IV<KEI('-E<G9I<VYE(&]P
M97)A8VEJ92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,#8*;7-G:60@
M(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS
M9W-T<B`B27IV<KEI('-E<G9I<VYE(&]P97)A8VEJ92!P<FEL:6MO;2!L;V=I
M<F%N:F$_(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*
M;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B1&]Z=F]L92(*"B,Z(&%D;6EN
M+W!E<FUS+V1E;&5T92YP:'`Z-3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R(")$
M;WIV;VQE('IA(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#8*
M(RP@9G5Z>GD*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(D1O
M>G9O;&4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V-`HC+"!F=7IZ>0IM<V=I
M9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B7T1O>G9O;&4B"@HC.B!A9&UI;B]P
M97)M<R]E9&ET+G!H<#HQ,#D@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P
M"B,Z(&%D;6EN+W!E<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE
M=&4N<&AP.C4X"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*
M;7-G<W1R(")!9&UI;FES=')A8VEJ82!D;WIV;VQA("AP<FEV:6QE9VEJ82DB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4*;7-G:60@(E!E<G-O;F%L
M($EN9F]R;6%T:6]N(@IM<V=S='(@(DQIZ&YE(&EN9F]R;6%C:6IE(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDX"FUS9VED(")097)U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU-0IM<V=I9"`B4&5T<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3D*;7-G:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*(RP@9G5Z
M>GD*;7-G:60@(E!H;VYE(@IM<V=S='(@(FYO;F4B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#<X"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G
M:60@(E!I>&5L<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-38*;7-G:60@(E!L871I='5D97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I
M9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R
M96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@
M(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@
M96QE;65N="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C4W,0HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@
M86YD(&$@>65A<BXB"FUS9W-T<B`B36]L:6T@=&4@<&]P<F%V:2!D=F]S;6ES
M;&5N92!O9&YO<VYO(&EN=F%L:61N92!A9')E<V4N(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G:60@(E!L96%S
M92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#$*(RP@9G5Z>GD*
M;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S
M='(@(DUO;&EM('1E('!O<')A=FD@9'9O<VUI<VQE;F4@;V1N;W-N;R!I;G9A
M;&ED;F4@861R97-E+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V
M-C`*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H
M92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-3$*(RP@9G5Z>GD*;7-G:60@
M(E!L96%S92!E;G1E<B!A('9A;&ED('1I;64N(@IM<V=S='(@(DUO;&EM('1E
M('!O<')A=FD@9'9O<VUI<VQE;F4@;V1N;W-N;R!I;G9A;&ED;F4@861R97-E
M+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@
M(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS
M9W-T<B`B36]L:6UO(&1A:G1E(&MR871A:R!O<&ES('9AN65G('!R;V)L96UA
M('-A('=E8FUA:6QO;2XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C8*(RP@9G5Z>GD*;7-G
M:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D
M(@IM<V=S='(@(DYI:F4@<&]S;&%N;R!K;W)I<VYIZ&MO(&EM92!I+VEL:2"Y
M:69R82XB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@
M(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@
M86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA
M;F%G97(N<&AP.C<P"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G
M;W)Y(&YA;64Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0HC+"!F=7IZ>0IM
M<V=I9"`B4&]L86YD(@IM<V=S='(@(E1R8;YI(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@W"FUS9VED(")0;VQL<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$R-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA
M9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B
M;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.3$*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E
M;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R(")3;&%N:F4@=2!O=F%J(&9O;&1E
M<B`H;FEJ92!P<FEN=?!E;F\@;V0@<W1R86YE($E-05!A*2(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C8V(&QI8B]";&]C:R]M971A<BYP:'`Z,C<Q"B,L
M('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@
M:&]U<BAS*3H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR.3@*;7-G:60@(E!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+VQD87`N<&AP
M.CDX"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@4F5Q
M=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-0IM<V=I9"`B4')E<W-U<F4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3D*;7-G:60@
M(E!R97-S=7)E(&%T('-E82!L979E;#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S4*(RP@9G5Z>GD*;7-G:60@(E!R
M97-S=7)E.B`B"FUS9W-T<B`B4&%S<W=O<F0B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`U"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PHC+"!F=7IZ
M>0IM<V=I9"`B4')E=FEE=R(*;7-G<W1R(")0<F5T:&]D;F$@<W1R86YA(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(T"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W
M:6YD;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HS-C(@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C8*;7-G
M:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`B4')E=&AO9&YE(&]P8VEJ
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+
M97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N
M<&AP.C$V.0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R(")0<F]B;&5M/R(*"B,Z
M('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-@IM<V=I9"`B4')O8FQE;2!$97-C
M<FEP=&EO;B(*;7-G<W1R(")/<&ES('!R;V)L96UA(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,V.0IM<V=I9"`B4')O:F5C=',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q,2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,3@X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,R.#4*(RP@9G5Z>GD*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S='(@(DES
M<')A=FQJ96X@=&5K<W0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#4*;7-G:60@(E!U8FQI
M8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C0T"FUS9VED(")0=6)L:6,@2V5Y($EN9F\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,C0Q"FUS9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T
M960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS
M9VED(")0=65R=&\@4FEC;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"B,L
M(&9U>GIY"FUS9VED(")1871A<B(*;7-G<W1R(")$871U;2(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HV,PIM<V=I9"`B475E<GDB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"FUS9VED(")1=6]T82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8V,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME>2`H)60@8FET*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8T"B,L
M(&9U>GIY"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`B5G)E;65N
M<VMA('IO;F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT,PHC+"!F=7IZ>0IM<V=I9"`B4F%I;B(*;7-G<W1R(")5<&]Z;W)E
M;FIE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#0*;7-G:60@(E)A:6X@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6X@3&%T
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT-@IM<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@
M(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@=&\@4VYO=R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B
M4F%N9&]M($9O<G1U;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV."!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<V"B,L(&9U>GIY"FUS9VED(")2871I;R(*;7-G<W1R
M(")/<&-I:F4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-"!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,0HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-"!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$X,`HC+"!F=7IZ>0IM<V=I9"`B4F5A9"(*;7-G<W1R(").92!P<F_H:71A
M;F4B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX
M-PIM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R("+(:71A;FIE('!O<G5K
M82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A
M=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O
M<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`HC+"!F=7IZ
M>0IM<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B26YF
M;W)M86-I:F4@<V5R=FES82(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED(")2969R97-H(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@
M(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G<W1R(")!OG5R
M:7)A:B!D:6YA;6GH:V4@96QE;65N=&4@;65N:6IA.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-#$*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z
M(@IM<V=S='(@(D&^=7)I<F%J('!OZ&5T;G4@<W1R86YI8W4Z(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DT(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R,3,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-0HC+"!F
M=7IZ>0IM<V=I9"`B4F5G97@B"FUS9W-T<B`B4&]N:;ET:2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,R-#D*;7-G:60@(E)E;&%T:6]N<VAI<"!"
M<F]W<V5R(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(RP@9G5Z
M>GD*;7-G:60@(E)E;&]A9"(*;7-G<W1R(").92!P<F_H:71A;F4B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,R-@HC+"!F=7IZ>0IM<V=I9"`B4F5M87)K
M<R(*;7-G<W1R("):86)I;&IEN6ME(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q-`IM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B561A;&IE
M;FD@<V5R=F5R:2(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX
M-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H
M;W)D92DZ(@IM<V=S='(@(E5D86QJ96YI(%523"`H:'1T<#HO+W=W=RYE>&%M
M<&QE+F-O;2]H;W)D92DZ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E
M9&ET+FEN8SHR,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR
M.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S
M"B,L(&9U>GIY"FUS9VED(")296UO=F4B"FUS9W-T<B`B3F%S=&%V:2(*"B,Z
M('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I
M9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@(E5K;&]N:2!O9&%B<F%N:2(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU-3<*(RP@
M9G5Z>GD*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B<&]M:F5R:2!N
M:;YE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHT,`HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T
M<B`B26YF;W)M86-I:F4@<V5R=FES82(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,Z,3(X"B,L(&9U>GIY"FUS9VED(")296UO=F4@<&%I<B(*;7-G
M<W1R(")P;VUJ97)I('9IN64B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,C`R"FUS9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@
M=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"B,L(&9U
M>GIY"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(E5K;&]N:2!O9&%B<F%N
M:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU,`IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D
M;V-U;65N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R
M96UO=F4N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")296UO=F4@=7-E<B(*;7-G
M<W1R(")I>F)A8VD@:7IV;W(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R
M96UO=F4N:6YC.C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E;6]V
M92!U<V5R.B`E<R(*;7-G<W1R(")I>F)A8VD@:7IV;W(B"@HC.B!F<F%M97=O
M<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q=65S="!C;W5L
M9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-PIM<V=I
M9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-"!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C8W-2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S,`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(S"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO571I;"]5
M=&EL+G!H<#HW.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E
M<UPB(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S,U"FUS
M9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HS,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,SD*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S(P('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`B4&]N:;ET:2(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"B,L(&9U>GIY"FUS9VED
M(")297-E="!087-S=V]R9"(*;7-G<W1R(")087-S=V]R9"(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W"B,L(&9U>GIY"FUS9VED(")297-E
M="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(E!A<W-W;W)D(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C$S,`IM<V=I9"`B4F5S=&]R92!,87-T(%%U97)Y(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HW,2!A9&UI;B]C;61S
M:&5L;"YP:'`Z,C@@861M:6XO<W%L<VAE;&PN<&AP.C8V"B,L(&9U>GIY"FUS
M9VED(")297-U;'1S(@IM<V=S='(@(E)E>G5L=&%T:2!P<F5T<F%G92(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R
M969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T
M<B`B3F%Z860@;F$@;W!C:6IE(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C,X"B,L(&9U>GIY"FUS9VED(")2971Y<&4@;F5W('!A<W-W;W)D
M(@IM<V=S='(@(E!A<W-W;W)D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F5U
M;FEO;B(*;7-G<W1R(")2975N:6]N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E
M<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R(")6<F%T:2!S=&%R=2!K;VYF:6=U
M<F%C:6IU(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,@IM<V=I9"`B
M4FEC:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S='(@(D]P8VEJ92!E9&ET
M;W)A('1E:W-T82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I
M9"`B4FED9&QE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*(RP@9G5Z>GD*;7-G:60@(E)I
M9VAT(@IM<V=S='(@(DYOYB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,C$*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$W"B,L(&9U>GIY"FUS9VED(")2:6=H
M="!V86QU97,B"FUS9W-T<B`B6F%D;FIA('-T<F%N82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`HC+"!F
M=7IZ>0IM<V=I9"`B4F]?=R!0<F]P97)T:65S+BXN(@IM<V=S='(@(D]S;V)I
M;F4@YE]E;&EJ92XN+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HR,S0*(RP@9G5Z>GD*;7-G:60@(E)O;&4B"FUS9W-T<B`B
M3F%S=&%V:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(R-0HC+"!F=7IZ>0IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R("),:7-T
M82!K;VYT86MT82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,C(*(RP@9G5Z>GD*;7-G:60@(E)O=&%T92!,969T(@IM<V=S
M='(@(DQI<W1A(&MO;G1A:W1A(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(R.`HC+"!F=7IZ>0IM<V=I9"`B4F]T871E(%)I
M9VAT(@IM<V=S='(@(DQI<W1A(&MO;G1A:W1A(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0HC+"!F=7IZ>0IM
M<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B3W-O8FEN92#F7V5L:6IE
M+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW,`HC+"!F=7IZ>0IM<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS
M9W-T<B`B3W-O8FEN92#F7V5L:6IE+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3,*(RP@9G5Z>GD*;7-G:60@(E)U;&5S(@IM<V=S='(@(E)E
M>G5L=&%T:2!P<F5T<F%G92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P
M96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS
M(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E
M87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C$R,`HC+"!F=7IZ>0IM<V=I9"`B4G5N(@IM<V=S='(@(E)E
M=6YI;VXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S:6%N($9E9&5R871I
M;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PHC+"!F=7IZ>0IM<V=I9"`B
M4G=A;F1A(@IM<V=S='(@(DMA;F%D82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI
M8R!3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S
M<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN
M<&AP.C@Q"B,L(&9U>GIY"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES
M(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(E5S;6IE<F5N:F4@;FEJ92!U<W!E
M;&\N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4P-`HC+"!F=7IZ
M>0IM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R(")0<F5G;&5D879A;FIE
M('!O<G5K92(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B4U%,
M(%-H96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,R.#,*;7-G:60@(E-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S,0IM
M<V=I9"`B4U-((@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I
M;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@
M(E-50T-%4U,B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,34S"FUS9VED
M(")37U%,(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*(RP@9G5Z>GD*;7-G:60@(E-A(@IM
M<V=S='(@(E-AZ'5V86H@:V%O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V%I
M;G0@2&5L96YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B4V%I
M;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM
M<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM
M<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$U"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E
M;F%D:6YE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")386UE(&9R86UE("A?<V5L9BDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I9"`B4V%M
M;V$B"FUS9W-T<B`B2V%M8F_P82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*(RP@9G5Z>GD*
M;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T<B`B57!O>F]R96YJ92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED
M(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P;W)T86PO;&%Y;W5T+FEN8SHY.`HC+"!F=7IZ>0IM<V=I9"`B4V%V92(*
M;7-G<W1R(")38>AU=F%J(&MA;R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O961I="YI;F,Z-#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A
M=F4@7"(E<UPB(@IM<V=S='(@(E-AZ'5V86H@:V%O(@H*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E-A=F4@)7,B"FUS9W-T<B`B4V'H=79A:B!K86\B"@HC.B!T96UP;&%T
M97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T
M<B`B4V'H=79A:B!O<&-I:F4B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,38W"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S
M(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D
M:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C<Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")6<F%T:2!S=&%R=2!K;VYF:6=U<F%C
M:6IU(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3,*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T
M('1O.B!<(B5S7"(N(@IM<V=S='(@(DYI:F4@8FEL;R!M;V=U8V4@;V)R:7-A
M=&D@<&]R=6ME(&]D("5S.B`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0Y"FUS9VED(")38V%T=&5R960@5"U3=&]R;7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED
M(")38VEE;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V
M"FUS9VED(")396%R8V@B"FUS9W-T<B`B5')AOFDB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S(P"B,L(&9U>GIY"FUS9VED(")396%R8V@@16YG
M:6YE<R(*;7-G<W1R(")297IU;'1A=&D@<')E=')A9V4B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.3<S"B,L(&9U>GIY"FUS9VED(")396QE8W0@
M1FEL97,B"FUS9W-T<B`B3V1A8F5R:2!S=F4B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@T"B,L(&9U>GIY"FUS9VED(")3
M96QE8W0@82!D871E(@IM<V=S='(@(D]D86)E<FD@:61E;G1I=&5T(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.3@*(RP@9G5Z>GD*;7-G:60@
M(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R(")/9&%B97)I(&MO9&YI
M(')A<W!O<F5D('-L;W9A.B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-#,*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G
M<W1R(")/9&%B97)I(&YO;F4B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z-C`*;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R("))>F%B
M97)I=&4@<V5R=F5R(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M-38*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S
M='(@(D]D86)E<FD@:V]D;FD@<F%S<&]R960@<VQO=F$Z(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-PHC+"!F=7IZ>0IM
M<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R(")/9&%B97)I('-V92(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C,*(RP@9G5Z>GD*;7-G:60@(E-E
M;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R(")0<FEL;V<@:F4@
M;V)R:7-A;BXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.#<S"B,L(&9U>GIY"FUS9VED(")396QE8W0@86X@;V)J96-T(@IM
M<V=S='(@(D]D86)E<FD@;F]N92(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HV-S@*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!N
M;VYE(@IM<V=S='(@(D]D86)E<FD@;F]N92(*"B,Z('-E<G9I8V5S+VME>6)O
M87)D+G!H<#HS-PIM<V=I9"`B(@HB4V5L96-T('1H92!C:&%R86-T97)S('EO
M=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P
M>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T"B,L(&9U>GIY
M"FUS9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R(")/
M9&%B97)I(&MO9&YI(')A<W!O<F5D('-L;W9A.B(*"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0T"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE(&1A
M=&4@9F]R;6%T.B(*;7-G<W1R(")/9&%B97)I(&MO9&YI(')A<W!O<F5D('-L
M;W9A.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z
M.3`*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA
M;F=E.B(*;7-G<W1R("))>F%B97)I=&4@:61E;G1I=&5T(&MO:FD@OF5L:71E
M('!R;VUI:F5N:71I.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V
M"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*
M;7-G<W1R(")/9&%B97)I(&MO9&YI(')A<W!O<F5D('-L;W9A.B(*"B,Z('1E
M;7!L871E<R]D871A+W1I;64N:6YC.C(U"B,L(&9U>GIY"FUS9VED(")396QE
M8W0@=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R(")/9&%B97)I(&MO9&YI(')A
M<W!O<F5D('-L;W9A.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M-3<*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S
M+B(*;7-G<W1R(")/9&=O=F%R86IUYF$@<&]L:F$B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S`V"FUS9VED(")396QE8W0@>6]U<B!C;VQO<B!S8VAE
M;64N(@IM<V=S='(@(DEZ86)E<FET92"Y96UU(&)O:F$N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(T.`IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R
M<F5D(&QA;F=U86=E.B(*;7-G<W1R("))>F%B97)I=&4@OF5L:F5N:2!J97II
M:SHB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I
M9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")0;[EA;&II('!R:6IA
M=G4@<')O8FQE;6$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3`S.0IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B4&^Y86QJ
M:2!335,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")396YE9V%L(@IM<V=S='(@
M(E-E;F5G86PB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q-@IM<V=I9"`B
M4V5N<V]R.B`B"FUS9W-T<B`B4V5N>F]R.B`B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Y"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I9"`B4V5P=&5M8F5R(@IM
M<V=S='(@(E-E<'1E;6)A<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS
M9W-T<B`B4W)B:6IA(&D@0W)N82!';W)A(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HW,#$*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS
M9W-T<B`B4V5R:6IS:VD@8G)O:B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-C$*(RP@9G5Z>GD*;7-G:60@(E-E<G9E<B!D871A('=R;VYG
M(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DYE;6$@9&]S='5P;FEH(&]P
M8VEJ82XB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C<*(RP@9G5Z>GD*;7-G
M:60@(E-E<W-I;VX@061M:6XB"FUS9W-T<B`B061M:6YI<W1R86-I:F$@9&]Z
M=F]L82`H<')I=FEL96=I:F$I(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")397-S:6]N($E$(&5X
M<&ER960N(@IM<V=S='(@(DE$('-E<VEJ92!J92!I<W1E:V%O+B(*"B,Z(&QI
M8B]A<&DN<&AP.C$T-0HC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T
M<B`B7T1O>G9O;&4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$T
M"FUS9VED(")3970B"FUS9W-T<B`B3V1A8F5R:2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HW-@IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U
M('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET
M+B(*;7-G<W1R("(B"B)0;V1E<VET92!O<&-I:F4@:V]J92!V86T@;VUO9W7F
M=6IU(&1A('!O;FFY=&ET92"Y:69R=2!A:V\@:F4@>F%B;W)A=FET92XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED(")3970@=7`@<F5M
M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R
M('!O<G1A;"XB"FUS9W-T<B`B(@HB4&]D97-I=&4@=61A;&IE;F4@<V5R=F5R
M92!K;VII;6$@OF5L:71E('!R:7-T=7!I=&D@<'5T96T@=F&Y96<@<&]R=&%L
M82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0*;7-G:60@(E-E="!Y
M;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T
M:6]N<RXB"FUS9W-T<B`B3V1A8F5R:71E(+YE;&IE;FD@:F5Z:6LL('9R96UE
M;G-K=2!Z;VYU(&D@<&]S=&%V:V4@>F$@9&%T=6TN(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDX"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P(&%P
M<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD
M(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B(@HB4&]D97-I
M=&4@<W1A<G1N=2!K;VUP;VYE;G1U+""Y96UU(&)O:F$L(&]S=FIEOF%V86YJ
M92!S=')A;FEC92!I(&1R=6=E(&]P8VEJ92`B"B)K;VIE('-E('1IZ'4@<')I
M:V%Z82XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<U"FUS9VED(")3
M971U<"(*;7-G<W1R(")0;W-T879K92(*"B,Z('1E;7!L871E<R]A9&UI;B]S
M971U<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3971U<"!U<&=R861E('-C<FEP
M=',@879A:6QA8FQE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ.#8*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I
M8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T<B`B4V5JN65L:2(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.38*;7-G:60@(E-H;W!P:6YG
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C0S"FUS9VED(")3:&]R="!3=6UM87)Y(@IM<V=S='(@(DMR871A:R!O<&ES
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T-@IM<V=I9"`B4VAO=6QD
M(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S
M='(@(D1A(&QI(&1E9FEN:7-A=&D@<')I<W1U<&YE('1I<&ME('IA(&QI;FMO
M=F4_(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C,@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C8W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*
M;7-G:60@(E-H;W<B"FUS9W-T<B`B4')I:V&^:2(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T
M=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@
M(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0Y,`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@=VAE
M;B!L;V=G:6YG(&EN/R(*;7-G<W1R(")0<FEK8;YI('9R:6IE;64@>F%D;FIE
M('!R:6IA=F4@;F%K;VX@;&]G:7)A;FIA/R(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$W-C4*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I
M9VEN86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C@Q,PIM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4R-@IM<V=I9"`B4VAO=R!T86)L92!O<&5R871I
M;VYS(&UE;G4@8F%R/R(*;7-G<W1R(")0<FEK8;YI(&UE;FD@>F$@;6%N:7!U
M;&%C:6IE('1A8F5L86UA/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T
M:&4@;&5F=#\B"FUS9W-T<B`B4')I:V&^:2`E<R!M96YI(&QI:F5V;S\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D
M:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8T"B,L(&9U>GIY"FUS9VED(")3:&]W
M('1H92!486)L92!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")0<FEK8;YI
M(&UE;FD@>F$@;6%N:7!U;&%C:6IE('1A8F5L86UA/R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I
M9"`B4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE
M<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3<V,PHC+"!F=7IZ>0IM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T<B`B
M1&]W;FQO860B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R(")0<FEK
M8;YI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-3$*(RP@9G5Z>GD*;7-G:60@(E-H;W=E<G,@16%R;'DB"FUS9W-T<B`B2W)A
M=&%K(&]P:7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU,@IM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3
M:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT.#`*;7-G:60@(E-H<FEN:R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HW-S0@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.#,V"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.CDR,B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY.#0*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3`T-R!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HQ,#@W"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C$Q,38@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z,3$T.0IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L
M;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#4*;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8U"B,L(&9U>GIY"FUS
M9VED(")3:6=N('5P(@IM<V=S='(@(B5S('!R:6IA=F$B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,@HC+"!F=7IZ>0IM<V=I9"`B
M4VEG;F%T=7)E(@IM<V=S='(@(E9AN2!P;W1P:7,Z(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3$*(RP@9G5Z>GD*;7-G:60@(E-I
M9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`B5F&Y('!O='!I<SHB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`T"B,L(&9U>GIY"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`B
M5F&Y('!O='!I<SHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C8U(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-R!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.38*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(Q-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,W"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#8@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,CDS,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(S
M"FUS9VED(")3:7IE(@IM<V=S='(@(E9E;&GH:6YA(@H*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K:7`@
M36%I;G1E;F%N8V4B"FUS9W-T<B`B4')E<VMOZ&D@<V5R=FES(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-0IM<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-30*(RP@9G5Z>GD*;7-G:60@
M(E-N;W<B"FUS9W-T<B`B4')I:V&^:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU-@IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS9VED(")3;F]W
M(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@(E-N;W<@4VAO=V5R<R!,
M871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<X"B,L
M(&9U>GIY"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B(%1E;6$Z("(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@R"FUS9VED(")3;F]W(&5Q=6EV
M86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS
M9VED(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-@IM<V=I9"`B4V]M86QI82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR-@HC+"!F=7IZ>0IM<V=I
M9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`B4')A=F%C('-O<G1I
M<F%N:F$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,3@Y"B,L(&9U>GIY"FUS9VED(")3;W5R8V4@861D<F5S
M<R(*;7-G<W1R(")68;EA(&4M;6%I;"!A9')E<V$Z(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DP"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X
M-3DM,RDB"FUS9W-T<B`B2G6^;F\M979R;W!S:VD@*$E33RTX.#4Y+3,I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<W"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U
M=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T
M:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B971W
M965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B
M971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Q-0HC+"!F=7IZ>0IM<V=I
M9"`B4W!A8V5R(@IM<V=S='(@(E-AZ'5V86H@:V%O(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"FUS9VED(")3
M<&%C:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I;F<@86YD('!A
M9&1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E-P86EN(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY.`IM<V=I
M9"`B4W!A;2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z
M,30*(RP@9G5Z>GD*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R($EN<'5T(@IM
M<V=S='(@(E-P96-I:F%L;FD@:V%R86MT97)I(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@HC+"!F=7IZ>0IM
M<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R(")/9&%B97)I('-V92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*
M(RP@9G5Z>GD*;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R(")/9&%B97)I
M('-V92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-S$*(RP@9G5Z>GD*;7-G:60@(E-P;&ET(')O=R(*;7-G<W1R
M(")/9&%B97)I('-V92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,0IM
M<V=I9"`B4W!O<G1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B
M4W)I($QA;FMA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HW,R!L:6(O0FQO8VLO;65T87(N<&AP.C<T"B,L(&9U>GIY"FUS
M9VED(")3=&%N9&%R9"(*;7-G<W1R(")+86QE;F1A<B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.38@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@P.0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I
M9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$U"B,L(&9U
M>GIY"FUS9VED(")3=&]R86=E(&9O<FUA="(*;7-G<W1R("));F9O<FUA8VEJ
M92!S97)V:7-A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU-S(*(RP@9G5Z>GD*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@
M(D]D(&%D<F5S92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S,PHC+"!F=7IZ>0IM<V=I
M9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B;&ES=&$@>F%D871A:V$B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<S"FUS9VED(")3=')I<"!D;VUA
M:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(S"FUS9VED(")3
M='EL92!;0U-372(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R("(B"@HC
M.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G
M<W1R("(E<R!N:6IE('!R;VYA\&5N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T
M<B`B5&5M82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,B!F<F%M
M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3<*(RP@9G5Z>GD*;7-G
M:60@(E-U8FUI="(*;7-G<W1R(")496UA(@H*(SH@<VEG;G5P+G!H<#HT.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T;R!A
M9&0@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U
M;G1I;"!Y;W5R("(*(G)E<75E<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(*(RP@9G5Z>GD*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R(")496UA
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P-`HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X
M"FUS9VED(")3=6-C97-S(@IM<V=S='(@(E5S<&IEN6YO(@H*(SH@861M:6XO
M=7-E<BYP:'`Z.#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B
M7"(E<UPB(&IE('5S<&5S;F\@9&]D86X@=2!A9')E<V%R(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C
M97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H
M92!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B!J92!U<W!E<VYO(&1O9&%N('4@
M861R97-A<B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O
M9&5L971E+G!H<#HT-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R("));64@9F]L9&5R
M82!<(B5S7"(@:F4@=7-P:F6Y;F\@<')O;6IE;FIE;F\@=2!<(B5S7"(N(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES
M=&5M+B(*;7-G<W1R(")<(B5S7"(@:F4@=7-P97-N;R!D;V1A;B!U(&%D<F5S
M87(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C
M97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E
M92!C:&%N9V5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E
M<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U
M<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M('5P9&%T960@7"(E<UPB(@IM<V=S='(@(DEM92!F;VQD97)A(%PB)7-<(B!J
M92!U<W!J9;EN;R!P<F]M:F5N:F5N;R!U(%PB)7-<(BXB"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E
M("5S(@IM<V=S='(@(DEM92!F;VQD97)A(%PB)7-<(B!J92!U<W!J9;EN;R!P
M<F]M:F5N:F5N;R!U(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3
M=61A;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4V"B,L(&9U>GIY"FUS9VED(")3=6UM87)Y
M(@IM<V=S='(@(DMR871A:R!O<&ES(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N
M<&AP.C8U"B,L(&9U>GIY"FUS9VED(")3=6X@4FES92(*;7-G<W1R(")496UA
M(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8X"B,L(&9U>GIY"FUS9VED
M(")3=6X@4V5T(@IM<V=S='(@(E1E;6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU.0IM<V=I9"`B4W5N;GDB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-@HC+"!F=7IZ
M>0IM<V=I9"`B4W5N<FES92(*;7-G<W1R(")496UA(@H*(SH@;&EB+T)L;V-K
M+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"B,L(&9U
M>GIY"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R(")496UA(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-0HC+"!F=7IZ>0IM<V=I
M9"`B4W5N<FES93H@(@IM<V=S='(@(B!496UA.B`B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C$Y"B,L(&9U>GIY"FUS9VED(")3=6YS970B
M"FUS9W-T<B`B5&5M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,3@*(RP@9G5Z>GD*;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@(B!496UA
M.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$S"B,L(&9U>GIY"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R(")496UA
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W.`IM<V=I9"`B4W5P
M<&]R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"B,L(&9U>GIY"FUS9VED
M(")3=7)I;F%M92(*;7-G<W1R("));64@9&%T;W1E:V4B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-`HC+"!F=7IZ>0IM<V=I9"`B
M4W5R;F%M92(*;7-G<W1R(")5<V5R;F%M92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G
M:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P.`HC+"!F=7IZ>0IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(E1R
M8;YI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-`HC+"!F=7IZ>0IM<V=I9"`B4W=E9&5N(@IM
M<V=S='(@(E9I9&IE;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I='IE<FQA
M;F0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M.#8*(RP@9G5Z>GD*;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B"FUS9W-T<B`B
M56YD96QE=&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30R"FUS9VED
M(")3>6YC34PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y
M=V]R9',N<&AP.CDW"B,L(&9U>GIY"FUS9VED(")3>6YT87@@97)R;W(@:6X@
M<V5A<F-H('1E<FUS(@IM<V=S='(@(DES<')A>FYI(&9O;&1E<B!K;W)P82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#<*(RP@9G5Z>GD*;7-G:60@(E-Y<FEA;B!!<F%B(%)E
M<'5B;&EC(@IM<V=S='(@(D-E;G1R86QN;RU!9G)IZ&MA(%)E<'5B;&EK82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS
M9VED(")4+5-T;W)M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8Q"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV,@HC+"!F=7IZ>0IM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B
M3V0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M,PIM<V=I9"`B5"U3=&]R;7,@16%R;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$V-@IM<V=I9"`B5%-6(&9I;&4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U1A8FQE+G!H<#HQ,S0*(RP@
M9G5Z>GD*;7-G:60@(E1A8FQE(@IM<V=S='(@(EIA9&YJ82!S=')A;F$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<S"B,L(&9U>GIY"FUS9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@
M(D]S;V)I;F4@7W1A8F5L92XN+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO
M5'EP92]T86)L97-E="YP:'`Z-3<*;7-G:60@(E1A8FQE(%-E="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<R"B,L(&9U>GIY"FUS9VED(")486)L92!P<F]P97)T:65S(@IM
M<V=S='(@(D]S;V)I;F4@7W1A8F5L92XN+B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3$*;7-G:60@(E1A:7=A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC
M92!O9B!#:&EN82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4
M86II:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A
M;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0HC+"!F=7IZ
M>0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R(")0;W)U:V$B"@HC.B!C;VYF:6<O
M:&]O:W,N<&AP+F1I<W0Z.3DV(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ
M.#<*(RP@9G5Z>GD*;7-G:60@(E1A<VMS(@IM<V=S='(@(DQO9VEN('IA9&%C
M:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<S"B,L
M(&9U>GIY"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(E-E<FEJ
M<VMI(&)R;VHB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y,`IM<V=I9"`B
M5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,30*;7-G:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C,*;7-G:60@(E1E
M;7!E<F%T=7)E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")496UP97)A='5R
M93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-C@W"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S7"(@;F]T(&9O=6YD
M+B(*;7-G<W1R("(E<R!N:6IE('!R;VYA\&5N+B(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z,38Y"B,L(&9U>GIY"FUS9VED(")496UP;&%T92!!9&UI;FES
M=')A=&EO;B(*;7-G<W1R("(E<R!A9&UI;FES=')A8VEJ82(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S,S-@IM<V=I9"`B5&5X="(*;7-G<W1R(")496MS="(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-S4*(RP@9G5Z>GD*;7-G:60@(E1E>'0@3VYL
M>2(*;7-G<W1R(")496MS="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*(RP@9G5Z>GD*;7-G:60@(E1E>'0@
M86QI9VXB"FUS9W-T<B`B4VQJ961E8V$@<W1R86YA(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0HC+"!F=7IZ>0IM<V=I
M9"`B5&5X='1O<"(*;7-G<W1R(")496MS="(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ"FUS9VED(")4:&%I("A4
M25,M-C(P*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"B,L(&9U>GIY"FUS
M9VED(")4:&%I;&%N9"(*;7-G<W1R(")4<F&^:2(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.CDX.`IM<V=I9"`B5&AA;FL@>6]U(&9O<B!U<VEN9R!T
M:&4@<WES=&5M+B(*;7-G<W1R(")(=F%L82"Y=&\@:V]R:7-T:71E($5N97)G
M;V1A=&$@=V5B;6%I;"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C@R,`HC+"!F=7IZ>0IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B25`@861R97-A(&YI:F4@9&]S='5P;F$N
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN
M92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7TE-4U`O24U34"]";V]K+G!H<#HQ,CDR"FUS9VED(")4:&4@
M24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,S$*;7-G:60@(E1H92!-
M86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H
M<#HR.0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X
M:71I;F<N(@IM<V=S='(@(E!R;WIO<B!Z82!O<&-I:F4@<V4@>F%T=F]R:6\N
M($EZ;&%Z:6TN(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.#D@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,#`*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HR,3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR
M,C,*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,S0@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HR-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HR-C0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,#,*;7-G:60@
M(B(*(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E
M<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O
M('5S92!097)M:7-S:6]N<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE
M(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H
M92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B
M;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C4Q"B,L(&9U>GIY"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S
M<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R(")<
M(B5S7"(@:F4@=7-P97-N;R!D;V1A;B!U(&%D<F5S87(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38Y"FUS9VED("(B"B)4:&4@9&5T
M86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I
M9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B
M(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P
M96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A
M=&%B87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO
M;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q,PIM<V=I9"`B5&AE(&5N8W)Y<'1I
M;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S4@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V
M."!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E
M='1I;F=S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HR,3D*;7-G:60@(E1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N
M=&\@:71S96QF+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A
M+G!H<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R
M<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4V
M"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C
M875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB
M=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA
M<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E(&1I<W!L
M87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R
M;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@
M.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A
M;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN
M7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E<W,@3TL@
M:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET
M;W(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N
M(&1E;&5T960N(@IM<V=S='(@(DED96YT:71E="!<(B5S7"(@:F4@;V)R:7-A
M;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I9&4@;VYL>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ-3<*
M;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU
M<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,C`Q"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@
M)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB
M"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B
M965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-PIM<V=I9"`B5&AE(&YA;64@=&\@=7-E
M('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T,0HC+"!F=7IZ>0IM
M<V=I9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*
M;7-G<W1R(")/=F$@=G)I:F5D;F]S="!M;W)A(&)I=&D@8G)O:BXB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S$*;7-G:60@(E1H
M92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R
M>7!T7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<RYP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S
M92!I=',@9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@
M<VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]D96(N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V5N
M<V-R:7!T+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M
M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VUS=V]R9"YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<G!M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]W
M96)C<'`N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W-R
M8VAI9VAL:71E+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]M<V5X8V5L+G!H<#HS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@
M<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@
M;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0U-`IM<V=I9"`B5&AE('%U;W1E(&-H
M87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL
M>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S:61E
M(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z-#0V"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L
M92!C:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R
M<&-S=6TN<&AP.C<X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("))9&5N
M=&ET970@7"(E<UPB(&IE(&]B<FES86XN(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W)P8W-U;2YP:'`Z-#D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H
M92!S97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R("))9&5N
M=&ET970@7"(E<UPB(&IE('-AZ'5V86XN(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,3DX"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E
M<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N(@IM<V=S='(@(DED96YT
M:71E="!<(B5S7"(@:F4@<V'H=79A;BXB"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HS,S`*;7-G:60@(E1H92!S<&5C:69I960@<F]W
M(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M
M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S$Q"FUS9VED(")4:&4@
M=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H
M92!S8W)E96XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD
M(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G:60@(E1H
M92!T;W`@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A
M+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO
M<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]$871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A;65W;W)K+T1A=&$O
M1&%T82]T<W8N<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U
M;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-#8@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C4V"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,34@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q.0HC+"!F=7IZ>0IM<V=I9"`B5&AE
M('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(DYE;6$@9&]S='5P;FEH(&]P8VEJ82XB"@HC.B!U=&EL+VEC;VY?8G)O=W-E
M<BYP:'`Z,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE;65S(&1I<F5C=&]R
M>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C$W.`IM<V=I9"`B5&AE<F4@87)E(&YO(&]P
M=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R(").96UA(&1O<W1U<&YI:"!O<&-I
M:F$N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z,S0R
M"B,L(&9U>GIY"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@
M8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B3F5M82!D;W-T=7!N:6@@
M;W!C:6IA+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,#$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A
M8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R
M86-T97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S
M='(@(B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@
M861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R(")$97-I
M;&$@<V4@9W)EN6MA('1O:V]M('-L86YJ82!P;W)U:V4Z("5S(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3(R"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O
M;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,3`S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P
M<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G
M<W1R(")$97-I;&$@<V4@9W)EN6MA('1O:V]M('-L86YJ82!P;W)U:V4Z("5S
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,34Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@
M)7,B"FUS9W-T<B`B1&5S:6QA('-E(&=R9;EK82!T;VMO;2!S;&%N:F$@<&]R
M=6ME.B`E<R(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D
M+B(*;7-G<W1R("(B"B)*879I;R!S92!P<F]B;&5M('-A(&1O9&%V86YJ82!D
M871O=&5K92X@36]G=>9I('!R;V)L96TL(&1A=&]T96MA(&IE('9EYF$@;V0@
M(@HB;6%X(&1O>G9O;&IE;FEH($U"+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R
M+T)R;W=S97(N<&AP.C@X.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@
M5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D
M('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@HB2F%V:6\@<V4@<')O8FQE
M;2!S82!D;V1A=F%N:F5M(&1A=&]T96ME+B!-;V=UYFD@<')O8FQE;2P@=F5L
M:>AI;F$@9&%T;W1E:V4@(@HB:F4@=F7F82!O9"!M87@N(&1O>G9O;&IE;FEH
M("@E9"!-0BDN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z
M.#DQ"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@
M82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N
M;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R("(B"B)*879I;R!S92!P
M<F]B;&5M('-A(&1O9&%V86YJ82!D871O=&5K92X@36]G=>9I('!R;V)L96TL
M(&1A=&]T96MA(&IE('9EYF$@;V0@(@HB;6%X(&1O>G9O;&IE;FEH($U"+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S
M<V%G92!P87)T(@IM<V=S='(@(D1E<VEL82!S92!G<F6Y:V$@=&]K;VT@<')I
M:V%Z82!O=F]G(&1I:F5L82!P;W)U:V4B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C0X"B,L(&9U>GIY"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S
M='(@(D1E<VEL82!S92!G<F6Y:V$@=&]K;VT@<W!AN6%V86YJ82!N97IA=G*Y
M96YE('!O<G5K92XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+VEM8RYP:'`Z
M,S$*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I
M;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R(")$97-I;&$@<V4@9W)E
MN6MA('1O:V]M('-P8;EA=F%N:F$@;F5Z879RN65N92!P;W)U:V4N(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HX,`HC+"!F=7IZ>0IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN
M(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM
M<V=S='(@(D1E<VEL82!S92!G<F6Y:V$@=&]K;VT@Z&ET86YJ82!O9&%B<F%N
M92!P;W)U:V4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S@*(RP@9G5Z>GD*;7-G:60@(B(*(E1H97)E('=A<R!A
M;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K
M(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R
M(")$97-I;&$@<V4@9W)EN6MA('1O:V]M(.AI=&%N:F$@;V1A8G)A;F4@<&]R
M=6ME+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C0P"B,L(&9U>GIY"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R
M;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A
M9V%I;B!L871E<BXB"FUS9W-T<B`B1&5S:6QA('-E(&=R9;EK82!T;VMO;2!P
M<FEK87IA(&]V;V<@9&EJ96QA('!O<G5K92(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(R"B,L(&9U>GIY"FUS9VED("(B
M"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO
M;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R(")$97-I
M;&$@<V4@9W)EN6MA('1O:V]M(.AI=&%N:F$@;V1A8G)A;F4@<&]R=6ME+B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T.`HC
M+"!F=7IZ>0IM<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P
M;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B5F&Y(&)R;W=S97(@;F4@
M<&]D<KYA=F$@;W9U(&UO9W7F;F]S="XB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C0X"B,L(&9U>GIY"FUS9VED(")4:&ES(&1O
M97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G
M<W1R("(E<R!N92!I>F=L961A(&MA;R!D;WIV;VQJ96X@=&EP('-A;F1U8V5T
M82XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C4R
M"B,L(&9U>GIY"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A
M('9A;&ED('II<"!F:6QE+B(*;7-G<W1R("(E<R!N92!I>F=L961A(&MA;R!D
M;WIV;VQJ96X@=&EP('-A;F1U8V5T82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,30U"B,L(&9U>GIY"FUS9VED(")4:&ES(&1O97,@;F]T('-E
M96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`B)7,@;F4@
M:7IG;&5D82!K86\@9&]Z=F]L:F5N('1I<"!S86YD=6-E=&$N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U"FUS
M9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E
M<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L
M;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S-`IM
M<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G
M97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@(@HB9V%T
M97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"FUS9VED
M("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T
M:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M
M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z
M.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY("(*
M(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER
M97,@86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY("AH
M='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.CDW."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#4W
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.#8@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$Q-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,3@R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-38*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3,P-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,SDX"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$U-3<@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3@S.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.34X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,#4*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`R.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,#<X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-#D@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C(R,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-#$P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-30*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8U-R!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.#(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,S<@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,P-@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS.#$T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,C(*;7-G
M:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C4*;7-G:60@(E1H:7,@9FEE;&0@
M;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q.`IM<V=I9"`B5&AI<R!F:65L9"!M
M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`Y-`IM<V=I9"`B
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$R,PIM<V=I
M9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A
M=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.3@Y"B,L(&9U>GIY"FUS9VED(")4:&ES(&9I96QD
M(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@(D]V82!V<FEJ961N
M;W-T(&UO<F$@8FET:2!B<F]J+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(X,S8*;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@
M8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE
M("(*(B<C,3(S-&%F)RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z-38Q"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E
M;B!P<F]C97-S960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]H96QP+V%B
M;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#4Y"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A
M<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@
M86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B
M($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B
M"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C
M=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(V"FUS9VED(")4
M:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T<B`B5G)I
M:F5D;F]S="!O=F]G(&)R;VIA(&UO<F$@;F%J;6%N:F4@:7IN;W-I=&D@,2XB
M"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*
M;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G
M>FEP(&9I;&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O4F5G:7-T<GDN<&AP.C$X.0IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R
M<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T
M(&)E(&$@;G5M8F5R+B(*;7-G<W1R(")/=F$@=G)I:F5D;F]S="!M;W)A(&)I
M=&D@8G)O:BXB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP
M.C,U"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N
M($]P=&EO;G,@=VEN9&]W(@IM<V=S='(@(D]V86H@<')O>F]R('-E('-M:6IE
M('!O>FEV871I('-A;6\@:7H@<')O>F]R82!/<&-I:F4B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-`IM<V=I9"`B5&AU;F1E
M<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,T
M"FUS9VED(")4:6-K971S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(T,C@@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U
M"B,L(&9U>GIY"FUS9VED(")4:6UE(@IM<V=S='(@(E9R96UE;G-K82!Z;VYA
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X-@IM<V=I9"`B5&EM
M92!4<F%C:VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z
M,3<*(RP@9G5Z>GD*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(E9R96UE
M;G-K82!Z;VYA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4S.0HC
M+"!F=7IZ>0IM<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B5G)E;65N
M<VMA('IO;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4:6UO<BU,97-T92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P"B,L(&9U>GIY"FUS
M9VED(")4:71L92(*;7-G<W1R(")6<F5M96YS:V$@>F]N82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I
M=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`B
M6F$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-C4T"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@
M9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y("(*
M(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S$Q"B,L(&9U>GIY"FUS9VED(")4;V1A>2(*;7-G
M<W1R(")4:6IE;&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P.0HC+"!F=7IZ>0IM<V=I9"`B5&]G;R(*;7-G
M<W1R("):82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O:V5L874B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,PHC+"!F
M=7IZ>0IM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B("AS=71R82DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$P"B,L(&9U>GIY"FUS9VED(")4;VYG82(*;7-G<W1R("):82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW-PHC+"!F=7IZ>0IM<V=I9"`B5&]P(@IM<V=S='(@(EIA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I9"`B
M5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G
M<W1R(")!:V-I:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A
M;F0@5&]B86=O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$W.3`*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I
M9"`B5'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5N:7-I
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(E1U
M<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(E1U<G-K:2`H25-/+3@X-3DM
M.2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=7)K;65N:7-T86XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)
M<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U=F%L
M=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C8T"FUS
M9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(V.0IM<V=I9"`B52Y6+B!I;F1E>#H@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@(E52
M3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4T,0IM<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP="!D
M96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3<*;7-G:60@(E523#HB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@HC+"!F=7IZ>0IM<V=I9"`B56=A
M;F1A(@IM<V=S='(@(DMA;F%D82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*(RP@9G5Z>GD*
M;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B56YD96QE=&4B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HT,3(*;7-G:60@(E5N86)L92!T;R!A8V-E
M<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B;&4@=&\@861D(&5X
M=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,X.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R
M(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,S@U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P
M97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-34*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8X."!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P,38*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C@S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C0S-0HC+"!F
M=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB
M"FUS9W-T<B`B3F4@;6]G=2!S92!S<&]J:71I(&YA($E-05`@<V5R=F5R.B`E
M<R(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,Y"FUS9VED(")5
M;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C(U(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#$*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P.0IM<V=I9"`B56YA
M8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,S8U"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,U-"!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C4X"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HR-38*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C$R-`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9FEL
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR
M.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@
M9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,C8U"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y
M(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O=&%R+G!H<#HW-@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M
M<')E<W,O9WII<"YP:'`Z-SD*;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S
M(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z,C(T(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,CDX"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER
M96-T;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,Q(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,SDR"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HS,3$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C,S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0X(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-3(*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,W(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HS,C(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C,S-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S0S"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#0*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,3<@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HT,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,#<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,P,R!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C(X.`HC.B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,38W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#`*
M(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X-R!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S@S"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HS.3$*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z,C0T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z-#`V"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,#,*;7-G:60@(E5N86)L
M92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C`S"FUS9VED
M(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+G!H<#HT-3$@9G)A
M;65W;W)K+TYE=%])35-0+TE-4U`O075T:"YP:'`Z,3$X"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ
M.38@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C`Q"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-C8@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C$W,0IM<V=I9"`B56YA8FQE('1O(&UO=F4@5D93(&9I
M;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M.3,@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ,#(*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HV-#@@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HY.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@
M9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C(W-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S,*;7-G
M:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HX,"!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C<R"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@
M9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HT-0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E
M9"!A<F-H:79E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z.#,U"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I
M>F4H*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z.#8V"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T
M1FEL95-I>F4H*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*;7-G
M:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV-CD*;7-G:60@(E5N86)L92!T;R!R
M96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3`U"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O
M;&1E<B!A;')E861Y(&5X:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,CDS"FUS9VED(")5;F%B;&4@=&\@<F5N
M86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,S(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C8W(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,S0S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV,3`@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C(R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C,R,R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,C$S"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-3(@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(X-0HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*;7-G:60@(E5N
M86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B
M;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$T.2!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C$U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-SD*;7-G:60@(E5N86)L92!T
M;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(X,2!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,X"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HQ-#,*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@
M9FEL92!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z.#0Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A
M('=I;&P@8F4@97AC965D960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*(RP@9G5Z>GD*;7-G:60@
M(E5N9&5R;&EN92(*;7-G<W1R(")5;F1E;&5T92(*"B,Z('1E;7!L871E<R]P
M<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R(")0
M;VYIN71I(&EZ;6IE;F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HR,C,*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,SDP"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R
M=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0Q"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W.`HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS.#0*;7-G:60@(E5N97AP96-T960@<F5S
M<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV,0IM<V=I9"`B
M56YF:6QE9"(*;7-G<W1R(").96MA=&5G;W)I<V%N;R(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DS"FUS9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T
M<B`B56YI:V]D("A55$8M."DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI=&5D
M($%R86(@16UI<F%T97,B"FUS9W-T<B`B56IE9&EN:F5N:2!!<F%P<VMI($5M
M:7)A=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*(RP@9G5Z>GD*;7-G:60@(E5N:71E
M9"!3=&%T97,B"FUS9W-T<B`B56IE9&EN:F5N:2!!<F%P<VMI($5M:7)A=&DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R($]U
M=&QY:6YG($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C8Y(&QI8B]";&]C:R]M971A<BYP:'`Z-S$*;7-G:60@
M(E5N:71S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0R.2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,S`*
M;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N
M(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM
M<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y
M"FUS9VED(")5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.3$*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM
M<V=S='(@(DYE<&]Z;F%T;R!K;W)I<VYIZ&MO(&EM92!I;&D@N6EF<F$N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4X"B,L(&9U>GIY"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE
M;65N="(*;7-G<W1R(")0;V1E<VD@=G)E;65N<VMU('IO;G4N(@H*(SH@9G)A
M;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HR.38*;7-G:60@(E5N;F%M
M960B"FUS9W-T<B`B0F5Z:6UE;FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G960@
M<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA
M=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O
M('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*
M(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H
M92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*(RP@9G5Z>GD*;7-G:60@
M(E5N<V5T(&-O;&]R(@IM<V=S='(@(E!R:6UL:F5N82!P<FEJ92(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@V(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z.3(V"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z.3,R"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I
M;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HQ.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*(RP@9G5Z
M>GD*;7-G:60@(E5P9&%T92(*;7-G<W1R(")$871U;2(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,CD*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R(")$871U;2(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S8*(RP@9G5Z>GD*;7-G:60@
M(E5P9&%T92!U<V5R(@IM<V=S='(@(D1A='5M(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HQ-#0@861M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E<G9I8V5S+W-H
M87)E<R]E9&ET+G!H<#HR,S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E5P9&%T960@7"(E<UPB+B(*;7-G<W1R(")$871U;2(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C@S"FUS9VED(")5<&=R861E('-C<FEP="!D96QE
M=&5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ.3D*;7-G
M:60@(E5P;&]A9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3@V"FUS9VED(")5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@
M9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM<V=I
M9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$X"B,L
M(&9U>GIY"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(D1E
M8V5M8F%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R
M+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-`IM<V=I9"`B57-E(&EF(&YA;64O
M<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T
M<B`B2V]R:7-T:71E(&]V;R!A:V\@<V4@:6UE+[EI9G)A(')A>FQI:W5J=2!Z
M82!)35-0('-E<G9E<BXB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D
M:70N:6YC.C(Q"B,L(&9U>GIY"FUS9VED(")5<V5R(@IM<V=S='(@(E5S97)N
M86UE(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HW
M,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@875T:&]R
M:7-E9"!F;W(@)7,N(@IM<V=S='(@(DMO<FES;FEK("5S(&YE;6$@9&]Z=F]L
M=2!Z82`E<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*(RP@9G5Z>GD*;7-G
M:60@(E5S97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`B)7,@861M:6YI<W1R
M86-I:F$B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(U,0IM
M<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(DMO<FES;FGH:V4@;W!C:6IE
M(@H*(SH@<VEG;G5P+G!H<#HV,@IM<V=I9"`B57-E<B!296=I<W1R871I;VXB
M"FUS9W-T<B`B4F5G:7-T<F%C:6IA(&MO<FES;FEK82(*"B,Z('-I9VYU<"YP
M:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B
M;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HT-CD*(RP@9G5Z>GD*;7-G:60@(E5S97(@86-C;W5N="!N
M;W0@9F]U;F0B"FUS9W-T<B`B)7,@;FEJ92!P<F]N8?!E;BXB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP
M.CDX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$U,"!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,PHC.B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C<R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G<W1R(")+;W)I<VYI
MZ&MO(&EM92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HQ
M,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<
M(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B1F]L9&5R(%PB)7-<(B!V9>8@
M<&]S=&]J:2(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PHC
M+"!F=7IZ>0IM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(E5S97)N86UE(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`HC+"!F=7IZ>0IM<V=I
M9"`B57-E<FYA;64Z("(*;7-G<W1R(")5<V5R;F%M92(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S
M>7-T96TZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K
M:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,38S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(U-0IM<V=I9"`B
M5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q.`HC+"!F=7IZ>0IM<V=I9"`B
M5F%C871I;VXB"FUS9W-T<B`B06MC:6IA(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.#8V"FUS9VED(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC
M;'5D93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C,X"FUS9VED(")686QI9&ET>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M-34*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@U-B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,3<W"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E
M(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0T(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(R-C8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C,Q-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(X"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3D*;7-G:60@(E9A;'5E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`Y
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#8*;7-G:60@(E9A;'5E<R!T
M;R!S96QE8W0@9G)O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED
M(")686YU871U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-#0*;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I
M8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A
M;7!E<F5D('=I=&@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-S`P"B,L(&9U>GIY"FUS9VED(")697)S:6]N(@IM
M<V=S='(@(DQIZ&YO(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R
M-@HC+"!F=7IZ>0IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(DQI
MZ&YO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX,PHC+"!F=7IZ>0IM<V=I9"`B5F5R=&EC86P@86QI9VXB"FUS
M9W-T<B`B4VQJ961E8V$@<W1R86YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN
M9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*;7-G:60@
M(E9E<GD@2&EG:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"B,L(&9U>GIY
M"FUS9VED(")6:65T($YA;2(*;7-G<W1R("));64@9&%T;W1E:V4B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5FEE=&YA;65S92`H5DE3
M0TE)*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HY-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G
M<W1R(")0<FEK87H@)7,B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS"FUS
M9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@R,0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R(")0<FEK
M87H@)7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@
M0G)I=&ES:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G
M:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(P.0IM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8S"FUS9VED(")6:7-I8FEL
M:71Y.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O
M9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET86QY
M('9I82!33510(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I
M;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@
M(E=!4DXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-2
M25!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS9VED(")724X@=FEA
M($A45%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5V%L;&ES
M(&%N9"!&=71U;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR-S(@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C@S"FUS9VED(")787)N:6YG(@IM<V=S='(@(E5P
M;WIO<F5N:F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C4X"FUS9VED(")792(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H97(@1F]R96-A<W0B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0R
M-PIM<V=I9"`B5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y,@HC+"!F=7IZ>0IM<V=I
M9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B=V5A=&AE<BYC;VTB"@HC.B!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S<*;7-G:60@(E=E8B!3:71E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N
M86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R(")3961M:>AN;R(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED(")796QC
M;VUE(@IM<V=S='(@(D1O8G)O(&1ON6QI(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VUO8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W"B,L
M('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B1&]B
M<F\@9&^Y;&D@;F$@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H
M<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B1&]B<F\@9&^Y;&DL("5S
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@(E=E<W1E<FX@
M*$E33RTX.#4Y+3$I(@IM<V=S='(@(EIA<&%D;FD@*$E33RTX.#4Y+3$I(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.38*;7-G:60@(E=E<W1E<FX@*$E3
M3RTX.#4Y+3$U*2(*;7-G<W1R("):87!A9&YI("A)4T\M.#@U.2TQ-2DB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B6F%P
M861N82!386AA<F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,W"B,L
M('!H<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S
M(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@(DMO:G4@:V]M<&]N96YT
M=2#F92`E<R!P<FEK87IA=&D@;F%K;VX@=6QA>F$_(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V:6YF;RYI;F,Z,30*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM
M:71E<B!C:&%R86-T97(_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T(&ES('1H92!Q=6]T92!C:&%R
M86-T97(_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,#8Q"FUS9VED(")7:&5R96ES($%U<W1R86QI82!M
M87`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED
M(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$S,PIM<V=I9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R
M('1H92!2:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R(")+;VIE(&1O9&%T:V4@
MOF5L:71E(&%K=&EV:7)A=&D@>F$@961I=&]R(&9O<FUA=&ER86YO9R`H<FEC
M:"D@=&5K<W1A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#0*(RP@9G5Z>GD*;7-G:60@(E=I9'1H(@IM<V=S
M='(@(E1R8;YI(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R-0IM
M<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED
M=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O
M;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@(B(*(JEI<FEN82`E<R!M96YI:F$@
M<V$@;&EJ979E('-T<F%N:6-E("AS='5P82!N82!S;F%G=2!K;V0@<VQJ961E
MYF4@<')I:F%V92DZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q,`HC+"!F=7IZ>0IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R("),
M:71V82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`U"B,L(&9U>GIY"FUS9VED(")7:61T:#HB"FUS9W-T<B`B5')AOFDB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$S"FUS9VED(")7:6MI
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M,#`@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C4*(RP@
M9G5Z>GD*;7-G:60@(E=I;F0B"FUS9W-T<B`B5')AOFDB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@HC+"!F=7IZ>0IM<V=I
M9"`B5VEN9"!%87)L>2(*;7-G<W1R(")4<F&^:2(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z.#`*;7-G:60@(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-38*(RP@9G5Z>GD*;7-G
M:60@(E=I;F0Z(@IM<V=S='(@(E1R8;YI(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(T,@HC+"!F=7IZ>0IM<V=I9"`B5VEN9#H@(@IM<V=S
M='(@(E1R8;YI(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"B,L(&9U
M>GIY"FUS9VED(")7:7-D;VTB"FUS9W-T<B`B5')AOFDB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3DV"FUS9VED(")7:7-H;&ES="(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*(RP@9G5Z>GD*;7-G
M:60@(E=O<FLB"FUS9W-T<B`B:6QI(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,38T"B,L(&9U>GIY"FUS9VED(")7;W)K($%D
M9')E<W,B"FUS9W-T<B`B3V0@861R97-E(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@HC+"!F=7IZ>0IM<V=I9"`B5V]R
M:R!0:&]N92(*;7-G<W1R(")496QE9F]N("AK=>9I*2(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C$V.2!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F
M(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,P,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%
M>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C$Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7
M<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C0S"FUS9VED
M(")8+5)E9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S($)A<VEC($-O;G-T<F%I;G1S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3DR"FUS9VED(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DT
M"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DU
M"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X,@IM
M<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3,*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-0IM<V=I9"`B65E9
M62(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3$P.`IM<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4V"FUS
M9VED(")996%R;'DB"FUS9W-T<B`B1V]D:;EN:F4B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W
M"B,L(&9U>GIY"FUS9VED(")996UE;B(*;7-G<W1R(")6:61J96YA(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV,PIM<V=I
M9"`B665S(@IM<V=S='(@(D1A(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E
M+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C4R"FUS9VED(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@
M6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C@R"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO
M<F4@=&AA;B`E9"!B;&]C:W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,30Q,0IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N
M=&EC871E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED
M96YT:71Y+G!H<#HS,#(*;7-G:60@(EEO=2!C86X@;F]T(&AA=F4@=&AE("=<
M7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*;7-G<W1R(").92!M
M;[YE('-A9'*^879A=&D@)UQ<)R!K87)A:W1E<B!U('1V;VT@<'5N;VT@:6UE
M;G4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U-2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.3<U"B,L(&9U>GIY"FUS9VED(")9;W4@9&ED
M(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S='(@(DYE
M9&]Z=F]L:F5N82!S;&]V82!U(&5M86EL(&%D<F5S:2XB"@HC.B!F<F%M97=O
M<FLO1&%T82]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F
M:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"FUS9VED
M(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(D]D:F%V;&II
M=F%N:F4@:F4@=7-P:F6Y;F\@:7IV<KEE;F\N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(V,0IM<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT97(@
M82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N
M(&]P=&EO;F%L("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN
M9R!P<F5F:7@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q.#@*(RP@9G5Z>GD*;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@
M=F%L:60@=F%L=64N(@IM<V=S='(@(DYE9&]Z=F]L:F5N82!S;&]V82!U(&5M
M86EL(&%D<F5S:2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP
M:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A
M8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z-#4V"FUS9VED(")9;W4@;75S="!C;VYF:6=U
M<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E
M('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@
M<F5P;W)T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E<B!T:&4@
M55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*(RP@9G5Z>GD*;7-G:60@
M(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"XB"FUS
M9W-T<B`B36]R871E(&]D86)R871I(&ED96YT:71E="!K;VII(+YE;&ET92!B
M<FES871I+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0HC+"!F=7IZ>0IM<V=I
M9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB
M"FUS9W-T<B`B36]R871E(&]D86)R871I(&ED96YT:71E="!K;VII(+YE;&ET
M92!B<FES871I+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`HC+"!F=7IZ>0IM
M<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB
M"FUS9W-T<B`B36]R871E(&]D86)R871I(&ED96YT:71E="!K;VII(+YE;&ET
M92!B<FES871I+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU
M<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R(")-;W)A
M=&4@;V1A8G)A=&D@:61E;G1I=&5T(&MO:FD@OF5L:71E(&)R:7-A=&DN(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,30V"B,L(&9U>GIY"FUS9VED(")9;W4@;75S
M="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@(DUO
M<F%T92!O9&%B<F%T:2!I9&5N=&ET970@:V]J:2"^96QI=&4@8G)I<V%T:2XB
M"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S@*
M(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@
M=&\@<&5R9F]R;2XB"FUS9W-T<B`B36]R871E(&]D86)R871I(&ED96YT:71E
M="!K;VII(+YE;&ET92!B<FES871I+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")9
M;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(DUO
M<F%T92!O9&%B<F%T:2!I9&5N=&ET970@:V]J:2"^96QI=&4@8G)I<V%T:2XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P
M+G!H<#HW,PIM<V=I9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N
M('!H;VYE(&YU;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HY-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S
M:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@
M(B`E<R!S97-I:F$@:F4@:7-T96ML82X@36]L:6UO(&1A('-E('!O;F]V;R!P
M<FEJ879I=&4N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M,S@*;7-G:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R(")68;EA(&4M
M;6%I;"!A9')E<V$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$R"FUS
M9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@(E9AN6$@1G)O;3H@
M861R97-A.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-"!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.0IM<V=I9"`B66]U<B!);F9O<FUA
M=&EO;B(*;7-G<W1R(")68;EE(&EN9F]R;6%C:6IE(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z.3@P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO
M=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G
M:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R
M('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB
M5F&Y82!);G1E<FYE="!A9')E<V$@:F4@<')O;6EJ96YJ96YA(&YA:V]N('!R
M:6IA=FQJ:79A;FIA(&YA("5S+B!$82!B:2!V8;EA("(*(G-I9W5R;F]S="!B
M:6QA('-AZ'5V86YA+"!M;W)A=&4@<V4@<&]N;W9O('!R:6IA=FET:2XB"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B66]U
M<B!.86UE(@IM<V=S='(@(E9AN64@:6UE(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;F]A9&0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I
M;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@
M>6]U('=I<V@@=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A
M8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I
M8V%T:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A
M=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@
M;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@
M;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HY.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(EEO
M=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@
M8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y
M;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B
M(@HB5F&Y82!);G1E<FYE="!A9')E<V$@:F4@<')O;6EJ96YJ96YA(&YA:V]N
M('!R:6IA=FQJ:79A;FIA(&YA("5S+B!$82!B:2!V8;EA("(*(G-I9W5R;F]S
M="!B:6QA('-AZ'5V86YA+"!M;W)A=&4@<V4@<&]N;W9O('!R:6IA=FET:2XB
M"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU,`IM<V=I9"`B66]U<B!B<F]W
M<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R(")6
M8;D@8G)O=W-E<B!N92!P;V1ROF%V82!O=G4@;6]G=>9N;W-T+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"B,L(&9U>GIY"FUS9VED
M("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT
M(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN
M="XB"FUS9W-T<B`B(@HB5F&Y(&)R;W=S97(@;F4@<&]D<KYA=F$@;W!C:6IU
M(+ET86UP86YJ82X@4')I=&ES;FET92!T:7!K92!#;VYT<F]L*U`@:6QI("(*
M(D]P=&EO;BM0('IA(+ET86UP86YJ92XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C4W"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G
M<W1R(")4<F5N=71N82!V<F5M96YS:V$@>F]N83HB"@HC.B!S97)V:6-E<R]P
M<F5F<RYP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9&5F875L="!I9&5N
M=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R(")68;D@9&5F875L="!I
M9&5N=&ET970Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U.`IM<V=I
M9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R(")68;D@9&5F875L
M="!I9&5N=&ET970Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P,0IM
M<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@(E9AN64@:6UE(&D@<')E
M>FEM93HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HQ,#`P"B,L(&9U
M>GIY"FUS9VED(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")/
M<&-I:F4@<W4@<V'H=79A;F4N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O
M<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R(")68;EA(&YO=F$@N6EF<F$@>F$@
M)7,@:F4Z("5S(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ
M-30*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@
M=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`B5F&Y92!O
M<&-I:F4@<W4@<V'H=79A;F4@=&]K;VT@=')A:F%N:F$@;W9E('-E<VEJ92XB
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B
M66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R(")/<&-I
M:F4@<W4@<V'H=79A;F4N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B"FUS
M9W-T<B`B5F&Y82"Y:69R82!J92!P;VYIN71E;F$B"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H
M87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I
M=&@@>6]U<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*(E9AN6$@N6EF
M<F$@:F4@<&]N:;ET96YA+"!P<F]V:F5R:71E('9AN2!E+6UA:6P@:2!P<FEJ
M879I=&4@<V4@<V$@;F]V;VT@(@HBN6EF<F]M+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.C<S,@HC+"!F=7IZ>0IM<V=I9"`B66]U<B!P87-S=V]R
M9"!H87,@97AP:7)E9"XB"FUS9W-T<B`B5F&Y82"Y:69R82!J92!P;VYIN71E
M;F$B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G:60@
M(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(E9AN6D@=61A;&IE;FD@
M<V5R=F5R:3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-"!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA
M=FEA(@IM<V=S='(@(DIU9V]S;&%V:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B6F%I<B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R("):86UB:6IA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T<B`B6FEM
M8F%B=F4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G:60@(EII
M<'!Y(@IM<V=S='(@(EII<'!Y(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R
M+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O
M=&5D(%1E>'1=(@IM<V=S='(@(EM386MR:6H@8VET:7)A;FD@=&5K<W1=(@H*
M(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#@*;7-G:60@(EM0<F]B;&5M(%)E
M<&]R=%TB"FUS9W-T<B`B6U!R:6IA=F$@<')O8FQE;6%=(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W
M(%%U;W1E9"!497AT("TB"FUS9W-T<B`B6U!R:6MAOFD@8VET:7)A;FD@=&5K
M<W0@+2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI
M9VAT<75O=&5S+G!H<#HQ-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@
M475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B6U!R:6MAOFD@8VET
M:7)A;FD@=&5K<W0@+2`E<R!R961O=F%=(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@
M;V8@)7-=(@IM<V=S='(@(EMR960@)7,@;V0@)7-=(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ-30Q('1E;7!L871E<R]P;W)T86PO;65N=2YI
M;F,Z,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R(")?061M:6YI
M<W1R86-I:F$B"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS
M9W-T<B`B7T-,22(*"B,Z(&QI8B]A<&DN<&AP.C$T,0IM<V=I9"`B7T1A=&%4
M<F5E(@IM<V=S='(@(E]$871A5')E92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T
M92!2;W<B"FUS9W-T<B`B7T]B<FFY:2!R960B"@HC.B!L:6(O87!I+G!H<#HQ
M,S,*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B7T=R=7!E(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W-0IM<V=I9"`B7TAE;'`B"FUS
M9W-T<B`B7U!O;6_F(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R=&EE
M<RXN+B(*;7-G<W1R(")?3W-O8FEN92!S;&EK92XN+B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]-96YU+G!H<#HQ.30*;7-G:60@(E],;V<@:6XB"FUS
M9W-T<B`B7U!R:6IA=FD@<V4B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M365N=2YP:'`Z,3DP"FUS9VED(")?3&]G(&]U="(*;7-G<W1R(")?27IL87HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R(")?27IM
M:6IE;FD@;&EN:RXN+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU
M+G!H<#HQ-C0*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(E]/<&-I:F4B"@HC
M.B!L:6(O87!I+G!H<#HQ,S<*;7-G:60@(E]097)M:7-S:6]N<R(*;7-G<W1R
M(")?1&]Z=F]L92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR-@IM<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM
M<V=S='(@(E]5:VQO;FD@;&EN:RXN+B(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM
M<V=I9"`B7U-E='5P(@IM<V=S='(@(E]0;V1E<VDB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@
M(E]486)L92!0<F]P97)T:65S+BXN(@IM<V=S='(@(D]S;V)I;F4@7W1A8F5L
M92XN+B(*"B,Z(&QI8B]A<&DN<&AP.C$R.0IM<V=I9"`B7U5S97)S(@IM<V=S
M='(@(E]+;W)I<VYI8VDB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDR,0IM<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(FEM96YI:R(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,T"B,L(&9U>GIY
M"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R(")I;65N:6LB"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ,PHC+"!F=7IZ>0IM<V=I
M9"`B8V%L96YD87(B"FUS9W-T<B`B2V%L96YD87(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN;W0@8W)E871E
M(&]U='!U="!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HU.3(*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@
M;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$W.`HC+"!F=7IZ>0IM<V=I9"`B8V]N9FEG
M=7)A=&EO;B!E<G)O<B(*;7-G<W1R(")6<F%T:2!S=&%R=2!K;VYF:6=U<F%C
M:6IU(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-30*
M;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C8*;7-G
M:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,3@R"B,L(&9U>GIY"FUS9VED(")E
M;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`B)7,@;FEJ92!P<F]N8?!E;BXB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I
M9"`B9F%L;&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"
M<F]W<V5R+G!H<#HX-34*(RP@9G5Z>GD*;7-G:60@(F9I;&4B"FUS9W-T<B`B
M3F5K871E9V]R:7-A;F\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W-"!L
M:6(O0FQO8VLO;65T87(N<&AP.C,V,"!L:6(O0FQO8VLO;65T87(N<&AP.C,X
M-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S
M*2!A="`E<R`E<R(*;7-G<W1R("(E<R!U("5S("5S(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(U,`HC+"!F=7IZ>0IM<V=I9"`B9W5S=&EN
M9R(*;7-G<W1R(")!=6=U<W0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C0Y"FUS9VED(")H.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4X"FUS9VED
M(")H:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*
M(RP@9G5Z>GD*;7-G:60@(FEN;&EN92(*;7-G<W1R(")N;VYE(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G:60@(FEN<'5T
M+V]U='!U="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@
M97)R;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O
M=&5";&]C:W,N:G,Z,3,*(RP@9G5Z>GD*;7-G:60@(FQI;F5S72(*;7-G<W1R
M(")N;VYE(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*;7-G:60@(FUK:7-O9G,@
M97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S8Y"FUS
M9VED(")M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C(Y,2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,S(*(RP@9G5Z>GD*;7-G
M:60@(FYA;64B"FUS9W-T<B`B26UE(@H*(SH@9G)A;65W;W)K+U)00R]24$,N
M<&AP.C$R,0HC+"!F=7IZ>0IM<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S
M='(@(DYE(&EZ8G)I<V%N82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,3(Q.0HC+"!F=7IZ>0IM<V=I9"`B;F]T('EE="!I;7!L96UE
M;G1E9"(*;7-G<W1R(").92!I>F)R:7-A;F$B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.CDP-0HC+"!F=7IZ>0IM<V=I9"`B;F]T97!A9"(*;7-G
M<W1R(").92!P<F_H:71A;F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@X"B,L(&9U>GIY"FUS9VED(")P97)C
M96YT(@IM<V=S='(@(E!R;V-E;F%T(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-S0*(RP@9G5Z>GD*;7-G:60@(G!E<FUI<W-I;VX@
M9&5N:65D(@IM<V=S='(@(D1O>G9O;&4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW
M,PHC+"!F=7IZ>0IM<V=I9"`B<FES:6YG(@IM<V=S='(@(E5P;WIO<F5N:F4B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T,@IM<V=I
M9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.CDY"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C,X-0IM<V=I9"`B<W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S(*(RP@9G5Z>GD*;7-G:60@(G-T96%D
M>2(*;7-G<W1R(").92!P<F_H:71A;F4B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C,P.0IM<V=I9"`B<W=I=&-H(&]F9B!J879A<V-R:7!T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,34P"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,CD*;7-G:60@(G1A<VL@;&ES="(*;7-G
M<W1R(")L:7-T82!Z861A=&%K82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,38V"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P-0HC+"!F
M=7IZ>0IM<V=I9"`B=')Y(&%G86EN(@IM<V=S='(@(DMO9"!S=F%K92!P<FEJ
M879E(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@9G)A;65W;W)K+T%U=&@O075T
M:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@='=I
M8V4@=&\@8V]N9FER;2(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F
M+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0HC+"!F=7IZ>0IM<V=I
M9"`B=6YI9FEE9"(*;7-G<W1R(").96MA=&5G;W)I<V%N;R(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS
M9W-T<B`B8F5Z(&EM96YA(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"B,L(&9U>GIY"FUS9VED(")U<V5R
M('-E;&5C="(*;7-G<W1R("))>F)O<B!B;VIE(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G
M<W1R(")V0V%R9"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR-#$*(RP@9G5Z>GD*;7-G:60@(G<Z(@IM<V=S='(@(D9W9#HB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A
M=&AE<BYC;VTB"FUS9W-T<B`B=V5A=&AE<BYC;VTB"@``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]I9%])1"YP;P``````````````
M````````````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`V-S`Q,S,@
M,3`U,34T,S,W-#(@,#$W-#<W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````",@2&]R9&4@+2!);F1O;F5S:6%N($QA;F=U86=E
M(%1R86YS;&%T:6]N"B,@0V]P>7)I9VAT("A#*2`R,#`U($AO<F1E(%!R;VIE
M8W0*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@
M;&EC96YS92!A<R!T:&4@2&]R9&4@<&%C:V%G92X*(R!*86UE<R`\:F%M97-`
M86-T:6]N;65S<V%G92YC;VT^+"`R,#`U+@HC"B,L(&9U>GIY"FUS9VED("(B
M"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B`R,#`U+3`X+3`S7&XB
M"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN
M(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN
M(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P-2TP."TP-"`P.3HQ,"LP,C`P7&XB
M"B),87-T+51R86YS;&%T;W(Z($IA;65S(#QJ86UE<T!A8W1I;VYM97-S86=E
M+F-O;3Y<;B(*(DQA;F=U86=E+51E86TZ(&ED(#QI9$!L:2YO<F<^7&XB"B)-
M24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN
M.R!C:&%R<V5T/553+4%30TE)7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D
M:6YG.B`W8FET7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S8Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,W,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S-S,*(RP@9G5Z>GD*;7-G:60@(B`H=&]D87DI(@IM
M<V=S='(@(DAA<FD@26YI(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C,W-0HC+"!F=7IZ>0IM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B0F5S
M;VLB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<Q"FUS9VED("(@
M*'EE<W1E<F1A>2DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(U-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8Q
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,#<*;7-G:60@(B!A
M="`B"FUS9W-T<B`B('!A9&$@(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HR,34*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I
M<R!N;W0@82!D:7)E8W1O<GDN(@IM<V=S='(@(EPB)7-<(B!B96QU;2!D:6)U
M870Z("5S+B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y
M+G!H<#HV-3D*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H
M<#HQ,#0R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N
M9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]4<F5E+U1R964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS
M9W-T<B`B7"(E<UPB('-U9&%H(&1I=&%M8F%H:V%N(&ME(&1A;&%M('-I<W1E
M;2!G<G5P+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!P97)M
M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B!S=61A:"!D:71A;6)A
M:&MA;B!K92!D86QA;2!I>FEN('-I<W1E;2XB"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C4T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T
M<B`B7"(E<UPB(&)E;'5M(&1I8G5A=#H@)7,N(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D
M(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B4N,F9-0B!S
M=61A:"!D:6=U;F%K86X@9&%R:2`E+C)F34(@>6%N9R!S=61A:"!D:6EJ:6YK
M86X@*"4N,F8E)2DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C,W"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R
M("(E9"`E<R!D86X@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C(V."!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-34W"B,L('!H<"UF;W)M
M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S
M+B(*;7-G<W1R("(E9"!H87)I('-A;7!A:2!S86YD:2!A;F1A(&AA8FES(&UA
M<V$@8F5R;&%K=6YY82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C@U"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*
M;7-G<W1R("(E9"UH87)I(')A;6%L86X@8W5A8V$B"@HC.B!S97)V:6-E<R]M
M86EN=&5N86YC92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.
M;W1I8V4B"FUS9W-T<B`B)7,@+2!096UB97)I=&%H=6%N(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.C@S-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+
M0B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R(")+;VYF:7)M87-I("T@3W!E<F%S
M:2!096UE;&EH87)A86X@)7,B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B)7,@4V5T=7`B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8S"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E
M;F%N8V4N<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS(&]F
M($%G<F5E;65N="(*;7-G<W1R("(E<R!3>6%R870M<WEA<F%T(%!E<FIA;FII
M86XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0R."!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C0Y,`HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C8U,2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<Q.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3D@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ-C4@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,SD*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS-#4@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B)7,@<&%D82`E
M<R`E<R(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M
M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H
M92`B"B)B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R
M9F]R;2!A="!T:&ES('1I;64N(@IM<V=S='(@(B(*(B5S('-I87`@=6YT=6L@
M;65L86MS86YA:V%N(&]P97)A<VD@<&5M96QI:&%R86%N('EA;F<@<W5D86@@
M9&ET86YD86D@9&D@8F%W86@@(@HB:6YI+B!"97)I;&%H('1A;F1A('!A9&$@
M:V]T86L@=&5R<V5B=70@=6YT=6L@;W!E<F%S:2!M86YA<'5N('EA;F<@86YD
M82`B"B)I;F=I;FMA;B!U;G1U:R!D:6QA:W-A;F%K86X@<&%D82!W86MT=2!I
M;FDN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,T,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(X-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!M:6YU=&5S(@IM<V=S='(@(B5S(&UE;FET(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R,PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R(")4:61A:R!A9&$@
M:6MO;B!Y86YG(&1I=&5M=6MA;BXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]L:7-T+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F
M("5S(@IM<V=S='(@(B5S('5N='5K("5S("5S(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(D)U:W4@06QA;6%T("(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@(DMA;&5N9&5R
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#8*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R("(E<R`M
M(%!E;6)E<FET86AU86XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDS,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VAT;6PN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@
M5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T
M;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@
M;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@
M:6YF;W)M871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS-C4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q
M,`HC+"!F=7IZ>0IM<V=I9"`B+"!G=7-T:6YG("(*;7-G<W1R("(L(&%N9VEN
M(&ME;F-A;F<B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X."!L:6(O0FQO
M8VLO;65T87(N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U<W1I
M;F<@)7,@)7,B"FUS9W-T<B`B+"!A;F=I;B!K96YC86YG("5S("5S(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M+"!V87)I86)L92!F<F]M("5S('1O("5S(@IM<V=S='(@(BP@=F%R:6%B;&4@
M9&%R:2`E<R!K92`E<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,CDT(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S0X"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-CD@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C$R.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-S0Y"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W1I;64N<&AP.C(P"FUS9VED("(Q,B!(;W5R($9O<FUA="(*
M;7-G<W1R(")&;W)M870@,3(@2F%M(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP
M.C$Y"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R(")&;W)M870@,C0@
M2F%M(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T
M(&AO=7)S(@IM<V=S='(@(C(T(&IA;2(*"B,Z(&9R86UE=V]R:R]522]522]0
M86=E<BYP:'`Z-CD*(RP@9G5Z>GD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R
M("),:6AA="(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED(")!
M(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN
M(@IM<V=S='(@(D1A=&%B87-E(&)A8VME;F0@9&EP97)L=6MA;B!U;G1U:R!A
M<F5A(&EN:2XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V,`IM
M<V=I9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3,U"FUS9VED(")!
M('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S
M86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HQ,38U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D
M('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#DW"FUS9VED("(B"B)!
M('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB;65S<V%G92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Q
M-0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A("(*(FUE
M<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3`U"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P
M<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G:60@(B(*(D$@
M<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M97-S86=E+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O
M(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HY"FUS9VED(")!32!#;&]U9',B
M"FUS9W-T<B`B04T@365N9'5N9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!,:6=H="!286EN(@IM<V=S
M='(@(D%-($=E<FEM:7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R(")!32!(=6IA
M;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R
M"FUS9VED(")!32!3:&]W97)S(@IM<V=S='(@(D%-($=E<FEM:7,B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B
M04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(D%-($=E<FEM:7,@4V%L:G4B"@HC
M.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB"FUS
M9W-T<B`B04TO4$TB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,P"FUS
M9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R(")496YT86YG(&5D:71O
M<B!I;FDB"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,@IM<V=I9"`B
M06)O=70N+BXB"FUS9W-T<B`B5&5N=&%N9RXN+B`B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T"FUS9VED(")!8G-B;W1T
M;VTB"FUS9W-T<B`B2F%R86L@86YT87)A(&)A9VEA;B!B87=A:"!B87)I<R!D
M96YG86X@8F%G:6%N(&)A=V%H(&=A;6)A<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*
M;7-G<W1R(")*87)A:R!A;G1A<F$@8F%G:6%N('1E;F=A:"!B87)I<R!D96YG
M86X@8F%G:6%N('1E;F=A:"!G86UB87(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,C<P"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG
M(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I
M;F<@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HS"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN
M9F]R;6%S:2!!8V-O=6YT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U
M"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@(E-A;F1I($%C8V]U
M;G0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.3,*(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G
M<W1R("));F9O<FUA<VD@06-C;W5N="(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS,S,*;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T<B`B06MU;G1A
M;G-I(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#@@=&5M
M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O861D8VAI;&0N:6YC.C$Q"FUS9VED(")!9&0B"FUS9W-T<B`B5&%M
M8F%H(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@861M:6XO9W)O=7!S+G!H
M<#HR,C4*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R(")486UB86@@
M1W)U<"!!;F%K(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY
M."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDY"B,L(&9U>GIY"FUS
M9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R(")58F%H($EZ:6XB
M"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D($AE
M<F4Z(@IM<V=S='(@(E1A;6)A:"!$:7-I;FDZ(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HR,3@@861M:6XO9W)O=7!S+G!H<#HR,3D*;7-G:60@(D%D9"!.97<@
M1W)O=7`B"FUS9W-T<B`B5&%M8F%H($=R=7`@0F%R=2(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HX.`HC+"!F=7IZ>0IM<V=I9"`B061D($YE=R!097)M:7-S:6]N
M(@IM<V=S='(@(E5B86@@27II;B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O861D8VAI;&0N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D%D9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R(")486UB86@@
M9W)U<"!A;F%K(&ME("<E<R<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$T-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@
M8VAI;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B5&%M8F%H(&=R
M=7`@86YA:R!K92`G)7,G(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@
M(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R(")486UB86@@<&5N9V=U;F$@8F%R
M=3HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-34T"B,L(&9U>GIY"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S='(@(E!I<V%H
M:V%N(&MO;&]M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN
M8SHS-`IM<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S='(@(E1A;6)A:"!A
M;F=G;W1A(&)A<G4B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.CDU
M"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R(")486UB86@@<&%S86YG86XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8W"B,L('!H<"UF;W)M870*;7-G
M:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G
M<W1R(")486UB86@@365N=2`E<R!S96)A9V%I(%!A;F5L(&YA=FEG87-I($UO
M>FEL;&$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM
M<V=S='(@(D)U:W4@06QA;6%T("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HW.`HC+"!F=7IZ>0IM<V=I9"`B061D('1O(&UY
M(&%D9')E<W,@8F]O:R(*;7-G<W1R(")"=6MU($%L86UA="`B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HS,0IM<V=I9"`B061D('5S97(B"FUS9W-T<B`B5&%M8F%H
M('!E;F=G=6YA(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M
M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA
M=&EO;CH@(@HB)7,N(@IM<V=S='(@(B(*(B`G)7,G('-U9&%H(&1I=&%M8F%H
M:V%N(&ME(&1A;&%M('-I<W1E;2P@=&5T87!I('1I9&%K(&1A<&%T(&UE;F%M
M8F%H:V%N("(*(FEN9F]R;6%S:2!P96YD869T87)A;B!T86UB86AA;CH@)7,N
M(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B061D960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN
M(&YO=RXB"FUS9W-T<B`B("<E<R<@('-U9&%H(&1I=&%M8F%H:V%N(&ME(&1A
M;&%M('-I<W1E;2X@06YD82!D87!A="!L;V<@:6X@<V5K87)A;F<N(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G:60@(D%D9&EN
M9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B4&5N86UB86AA;B!P96YG
M9W5N82!T:61A:R!D:6%K=&EF:V%N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-#0Q"B,L(&9U>GIY"FUS9VED(")!9&1R97-S(@IM<V=S='(@(D)U:W4@
M06QA;6%T("(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,SD*;7-G
M:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R(")"=6MU($%L86UA="`B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`HC+"!F=7IZ
M>0IM<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H
M97(@=7-E<G,B"FUS9W-T<B`B56)A:"!I>FEN('5N='5K("5S(@H*(SH@861M
M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ
M,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN:7-T<F%S
M:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#$*;7-G:60@(D%D
M<R(*;7-G<W1R(")):VQA;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES
M=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%L8F%N:6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B06QG97)I82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W
M"B,L(&9U>GIY"FUS9VED(")!;&EA<R(*;7-G<W1R(")2871A(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM
M<V=I9"`B06QI9VXB"FUS9W-T<B`B4F%T82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N=#HB
M"FUS9W-T<B`B4&5R871A86XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M.#<*;7-G:60@(D%L;"(*;7-G<W1R(")396UU82(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,C`W('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-C4*;7-G:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@
M(E-E;75A(%!E;F=G=6YA($%S;&DB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S
M(&%D;6EN+V=R;W5P<RYP:'`Z,C(R"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S
M='(@(E-E;75A($=R=7`B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.CDQ(&9R86UE=V]R:R]097)M<R]097)M<R]D871A=')E92YP:'`Z-S4*
M(RP@9G5Z>GD*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R("))>FEN
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS9W-T<B`B4V5M=6$@
M96UP870@<VES:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S$*
M;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,T"FUS9VED(")!;&QO=R!S971T
M:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R("))>FEN:V%N('!E
M;F=A='5R86X@9&%R:2!T:7!E(&1A9G1A<B!N;VUO<B!B97)U<G5T/R(*"B,Z
M(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C4P-`IM<V=I
M9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$R,PIM<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB"FUS
M9W-T<B`B4&5N9V=A;G1I($QO9VEN($E-4U`B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3`W"FUS9VED(")!;'1E<FYA=&4@24U34"!087-S=V]R9"(*
M;7-G<W1R(")096YG9V%N=&D@4V%N9&D@24U34"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT.3D*;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE
M(@IM<V=S='(@(E!E;F=G86YT:2!.86UA(%!E;F=G=6YA($E-4U`B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS-0IM<V=I9"`B06QT97)N871E
M(&5M86EL(&%D9')E<W,B"FUS9W-T<B`B4&5N9V=A;G1I(&%L86UA="!E;6%I
M;"(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E<FYA
M=&4@=&5M<&QA=&5S(@IM<V=S='(@(E!E;F=G86YT:2!T96UP;&%T92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(E!E;F=G
M86YT:2!T96MS.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M.34@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,34*;7-G:60@(D%N
M(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-PIM<V=I9"`B06X@=6YK
M;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M-0IM<V=I9"`B06YD;W)R82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED
M(")!;F=O;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL
M;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS
M9W-T<B`B2F%W86)A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B06YT:6=U82!A;F0@0F%R
M8G5D82(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D
M;6EN+W!H<'-H96QL+G!H<#HS-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M54DN<&AP.C4X('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*
M;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(D%P;&EK87-I(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T
M(@IM<V=S='(@(D1A9G1A<B!!<&QI:V%S:2(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ-#`*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G
M<W1R(")!<&QI:V%S:2!S=61A:"!S:6%P+B(*"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B
M"FUS9W-T<B`B1&EG=6YA:V%N('5N='5K($)A9VEA;B!!;F%K(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O
M=F4B"FUS9W-T<B`B1&ES971U:G5I(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z.#,S"FUS9VED(")!<'!R;WAI;6%T92!3:7IE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8X"FUS9VED(")!<')I;"(*;7-G<W1R(")!<')I;"(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3<U"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U
M-BDB"FUS9W-T<B`B07)A8B`H5VEN9&]W<RTQ,C4V*2(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HV-@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C@Q"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C4X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,`IM<V=I
M9"`B07)C:&EV92!.86UE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P
M(')E<75E<W0@9F]R("5S(#\B"FUS9W-T<B`B(@HB07!A:V%H(&%N9&$@>6%K
M:6X@86YD82!I;F=I;B!M96UI;F1A:&MA;B!P97)M;VAO;F%N('!E;F1A9G1A
M<F%N('5N='5K("5S/R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L
M971E+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U
M('-U<F4@>6]U('=I<V@@=&\@9&5L971E(%PB)7-<(B!A;F0@86YY('-U8BUG
M<F]U<',_(@IM<V=S='(@(D%P86MA:"!A;F1A('EA:VEN(&%N9&$@:6YG:6X@
M;65N9VAA<'5S("<E<R<@9&%N('-U8BUG<G5P(&UA;F%P=6X_(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU.`IM<V=I9"`B07)G96YT:6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*
M;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ-S8*;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@
M(D%R;65N:6$@*$%235-#24DM."DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,C@*;7-G:60@(D%R="(*;7-G<W1R(")396YI(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM
M<V=I9"`B07)U8F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R
M="(*;7-G<W1R(")+;V1E($%S8VEI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4U"FUS9VED(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,C4*;7-G:60@(D%S
M:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O
M<&5R871I;VYS/R(*;7-G<W1R(")-96UI;G1A(&MO;F9I<FUA<VD@<V5B96QU
M;2!M96QA:W-A;F%K86X@;W!E<F%S:2!P96UE;&EH87)A86X_(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q,PHC+"!F=7IZ>0IM<V=I9"`B07-S
M:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(E!I<V%H:V%N(&MO;&]M(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I9"`B071T96UP="!T;R!D96QE=&4@
M82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(DUE;F-O8F$@=6YT=6L@
M;65N9VAA<'5S(&=R=7`@>6%N9R!T:61A:R!A9&$N(@H*(SH@861M:6XO<&5R
M;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N
M;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B365N8V]B82!U;G1U
M:R!M96YG:&%P=7,@:7II;B!Y86YG('1I9&%K(&%D82XB"@HC.B!A9&UI;B]P
M97)M<R]E9&ET+G!H<#HX-PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N
M+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(DUE;F-O8F$@=6YT=6L@
M;65N9W5B86@@:7II;B!Y86YG('1I9&%K(&%D82XB"@HC.B!S97)V:6-E<R]S
M:&%R97,O961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO
M;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T<B`B365N8V]B82!U;G1U:R!M96YG
M=6)A:"!B86=I86X@>6%N9R!T:61A:R!A9&$N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HV-"!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C<Q"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#8*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.`HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G
M:60@(D%U9W5S="(*;7-G<W1R(")!9W5S='5S(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I
M9"`B075S=')A;&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*(RP@9G5Z>GD*
M;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`B06=U<W1U<R(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L
M.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$S-0IM<V=I
M9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D
M(&-A<&%B:6QI=&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D
M(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]F='`N<&AP.C,V"FUS9VED("(B"B)!=71H7V9T
M<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@
M4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z-C0*;7-G:60@
M(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP
M.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@061D:6YG('5S97)S
M(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS-3<*;7-G
M:60@(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E
M9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C8S"FUS9VED(")!=71H7VQD87`Z(%)E
M<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,SD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N
M(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,X-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C0Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T
M;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN
M9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP
M.C0V"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M
M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS
M9VED(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A
M:6QE9"X@)7,B"FUS9W-T<B`B4V5M=6$@4&5N9V=U;F$@07-L:2(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE
M;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#4Q"FUS9VED(")!
M=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HW,`IM<V=I9"`B075T
M:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C<U"FUS9VED(")!
M=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R(")+;VQO;2!Y86YG('1E<G-E9&EA
M.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3D*;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"3T9(($5X8W5S
M97,B"FUS9W-T<B`B06QA<V%N($)/1D@B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O
M=6YD(@IM<V=S='(@(DQA=&%R($)E;&%K86YG(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N
M9"!#;VQO<B(*;7-G<W1R(")787)N82!,871A<B!"96QA:V%N9R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#$*;7-G:60@(D)A9"!K97)B
M97)O<R!P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N86UE
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"86AA;6%S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(D)A:')A:6XB"FUS
M9W-T<B`B36%R9VEN(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S<*;7-G
M:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(D)A;'1I8R`H25-/
M+3@X-3DM,3,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"87)B861O<R(*;7-G<W1R("(B
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N
M;W0@9F]U;F0N(@IM<V=S='(@(D1A<V%R(&1I<F5K=&]R:2!G<F%F:6L@)R5S
M)R!T:61A:R!D:71E;75K86XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<S"FUS9VED(")"87-E;&EN92(*;7-G
M<W1R(")*87)A:R!A;G1A<F$@8F%G:6%N(&)A=V%H(&=A;6)A<B!D96YG86X@
M9V%R:7,@9&%S87(@8F%R:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QA<G5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)E;&=I=6TB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B0F5L:7IE(@IM<V=S
M='(@(DIA<F%K(&%N=&%R82!B86=I86X@8F%W86@@9V%M8F%R(&1E;F=A;B!G
M87)I<R!D87-A<B!B87)I<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@
M(D)E;FEN(@IM<V=S='(@(DIA<F%K(&%N=&%R82!B86=I86X@8F%W86@@9V%M
M8F%R(&1E;F=A;B!G87)I<R!D87-A<B!B87)I<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G
M:60@(D)E<FUU9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0FAU
M=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS-3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N
M(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M;W)T86PO;&%Y;W5T+FEN8SHX.0IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS
M9W-T<B`B4&5N9V%T=7)A;B!!<F5A(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L
M87EO=70N:6YC.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@(E1I<&4@
M07)E82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.`IM<V=I9"`B0F]L9"(*;7-G<W1R(")(=7)U9B!496)A;"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(P-0IM<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@
M(E!E='5N:G5K(&AA;&%M86X@=V5B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`IM<V=I9"`B0F]R9&5R(@IM
M<V=S='(@(D)O<F1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM<V=S
M='(@(DME=&5B86QA;B!";W)D97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Q"FUS9VED(")";W)D97)S(@IM
M<V=S='(@(D)O<F1E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)O<VYI82!A;F0@
M2&5R>F5G;W9I;F$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.CDV"FUS9VED(")";W1H(@IM<V=S='(@(DME9'5A;GEA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,PIM<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")"
M;W1T;VTB"FUS9W-T<B`B0F%W86@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V
M970@27-L86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*(RP@9G5Z>GD*;7-G
M:60@(D)R87II;"(*;7-G<W1R(")3=7)A="(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED
M(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I
M9"`B0G5L;&5T960@3&ES="(*;7-G<W1R(")$869T87(@0G5L;&5T(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,0IM<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,SD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0T-`IM<V=I9"`B0TU3(@IM<V=S='(@(D--4R(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G
M:60@(D-20R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4Y-PIM<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN=',B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN
M(@IM<V=S='(@(E!R;W!E<G1I(%-?96PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,38S"FUS9VED(")#86-H92!I;FET('=A<R!N;W0@8V]M
M<&QE=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#@T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.#<*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$U-0IM<V=I9"`B0V%L96YD
M87(B"FUS9W-T<B`B2V%L96YD97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C0V"FUS9VED(")#86QM(@IM<V=S='(@(E1E;F%N9R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8W"FUS9VED(")#86UE<F]O;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N(&YO="!R97-E="!P87-S
M=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O
M<BXB"FUS9W-T<B`B(@HB5&ED86L@9&%P870@;65N9V%T=7(@=6QA;F<@<V%N
M9&D@<V5C87)A(&]T;VUA=&ES+"!S:6QA:V%N(&AU8G5N9VD@(@HB861M:6YI
M<W1R871O<B!A;F1A+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C,Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86X@;F]T('=R:71E('1O(&9I
M;&4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR
M,@IM<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA
M;F1L97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G5S+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,Q
M.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T
M;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`B5&ED86L@9&%P870@=&5R:'5B
M=6YG(&ME('-E<G9E<B!L9&%P(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-3
M5BYP:'`Z-#$S"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&]P96X@9FEL
M92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*(RP@9G5Z>GD*;7-G
M:60@(D-A;F%D82(*;7-G<W1R(")+86QE;F1E<B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$P,2!A9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O9&5L971E+FEN8SHQ,2!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A
M<BYI;F,Z,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ
M,@IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(D)A=&%L(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B;&5M
M(%)E<&]R="(*;7-G<W1R(")"871A;&MA;B!,87!O<F%N($UA<V%L86@B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q.`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`B5&ED86L@9&%P870@=6YT=6L@;65N9VAA<'5S(%PB)7-<(CH@)7,N
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z
M-3(*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R
M9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C,Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN
M;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]$871A5')E92]$871A5')E92YP:'`Z,3(X(&9R86UE=V]R:R]$
M871A5')E92]$871A5')E92]S<6PN<&AP.C8X,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z
M-C`X"FUS9VED("(B"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I
M97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R
M("(*(G-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@<F]U
M=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8X"FUS9VED(")#87!E(%9E<F1E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*
M;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`B2G5D=6P@5&%B96PB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@
M(D-A<G)I97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDP"FUS9VED(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`B2V%T
M96=O<FD@9&%N($QA8F5L(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(D-A>6UA;B!)
M<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ.30*(RP@9G5Z>GD*;7-G:60@(D-E;&P@4&AO;F4B
M"FUS9W-T<B`B4')O<&5R=&D@4V5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0IM<V=I9"`B0V5L;"!0<F]P
M97)T:65S(@IM<V=S='(@(E!R;W!E<G1I(%-E;"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A
M9&1I;F<Z(@IM<V=S='(@(DIA<F%K('-P87-I(&1A<FD@8F]R9&5R(&1E;F=A
M;B!T96MS(&1I(&1A;&%M('-E;#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E
M<G1I97,B"FUS9W-T<B`B<')O<&5R=&D@<V5L(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A
M8VEN9SHB"FUS9W-T<B`B2F%R86L@<W!A<VD@86YT87(@<V5L+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-S0*;7-G:60@(D-E;&QP:&]N92(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B
M0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B0V5L=&EC("A)4T\M.#@U
M.2TQ-"DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(V"FUS9VED(")#96YT97(B"FUS9W-T<B`B5&5N9V%H(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")#
M96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*2(*;7-G<W1R(")%<F]P82!4
M96YG86@@*$E33RTX.#4Y+3(I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HV.3D*;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M,3$*;7-G:60@(D-E<G1I9FEC871E($]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")#97)T
M:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*(RP@
M9G5Z>GD*;7-G:60@(D-H860B"FUS9W-T<B`B2V%R86MT97(B"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.CDV"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B56)A:"(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,0IM<V=I9"`B0VAA;F=E
M(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B56)A:"!386YD:2!!;F1A(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V"FUS9VED("(B"B)#:&%N9V4@=&AE
M(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R
M96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B(@HB
M56)A:"!N86UA(&1A;B!A;&%M870@<V5H:6YG9V$@;W)A;F<@9&%P870@;65L
M:6AA=&YY82!K971I:V$@;65R96MA(&UE;6)A8V$@(@HB9&%N(&UE;6)A;&%S
M(&ME(&5M86EL(&%N9&$N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C(T"FUS9VED("(B"B)#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO
M="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@
M(@HB0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(DUE
M;F=U8F%H('-A;F1I(&%N9&$@=&ED86L@9&ED=6MU;F<@9&5N9V%N(&MO;F9I
M9W5R87-I('EA;F<@<V5K87)A;F<N(%-I;&%K86X@(@HB:'5B=6YG:2!A9&UI
M;FES=')A=&]R(&%N9&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PIM<V=I9"`B0VAA<B(*;7-G<W1R(")+
M87)A:W1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T
M<B`B4&5R:6MS82!,:6YK+BXN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PHC+"!F=7IZ>0IM<V=I
M9"`B0VAI;&4B"FUS9W-T<B`B2G5D=6PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"B,L(&9U>GIY
M"FUS9VED(")#:&EN82(*;7-G<W1R(")+87)A:W1E<B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@P"FUS9VED(")#:&EN97-E(%-I;7!L:69I960@*$="
M,C,Q,BDB"FUS9W-T<B`B0VEN82!3961E<FAA;F$@*$=",C,Q,BDB"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0VAI;F5S92!4<F%D:71I
M;VYA;"`H0FEG-2DB"FUS9W-T<B`B0VEN82!4<F%D:7-I;VYI;"`H0FEG-2DB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"B,L(&9U
M>GIY"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R(")386YD:2!"
M87)U(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.`IM
M<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(Y.`IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P
M;&%Y(&1A=&5S.B(*;7-G<W1R(")0:6QI:"!C87)A('5N='5K(&UE;F%M<&EL
M:V%N('1A;F=G86PZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y
M;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I(@IM<V=S='(@(E!I;&EH(&1A
M9G1A<B!T:7!E(&=A>6$@*'5N='5K(&1A9G1A<B!N;VUO<B!B97)U<G5T*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HU-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C@*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C@Y,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(D1I
M<F5K=&]R:2!-;W1I9B`G)7,G('1I9&%K(&1I=&5M=6MA;BXB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`IM<V=I9"`B0VQE
M87(B"FUS9W-T<B`B0F5R<VEH:V%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@
M=&%G<R(*;7-G<W1R(")"97)S:6AK86X@=&%G($U33V9F:6-E(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C$R.`HC+"!F=7IZ>0IM<V=I9"`B0VQE87(@475E
M<GDB"FUS9W-T<B`B0F5R<VEH:V%N('!E;F=G=6YA(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0VQE87(@;W5T('5S97(Z("5S(@IM<V=S='(@(D)E<G-I:&MA;B!P96YG9W5N
M83H@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3$*
M;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B0F5R<VEH:V%N('!E;F=G=6YA
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@
M(D-L96%R('5S97(@9&%T82(*;7-G<W1R(")"97)S:6AK86X@9&%T82!P96YG
M9W5N82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$U"FUS9VED(")#;&5A<FEN9R!,871E(@IM<V=S='(@(D-E<F%H(&)E8F5R
M87!A('-A870@;&%G:2(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN
M=&5N86YC92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G
M<W1R(")+;&EK('5N='5K($QA;FIU="(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L
M;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP
M:'`Z,30V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L
M;W-E(%=I;F1O=R(*;7-G<W1R(")4=71U<"!*96YD96QA(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR-#0*;7-G:60@(D-L;W5D<R(*;7-G<W1R(")-96YD
M=6YG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,38*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R(")-96YD=6YG(&1I('!A
M9VD@:&%R:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$W"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B0F5R87=A;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C0*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,C,*;7-G:60@
M(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`B4&5R8F5S87(@4&%N96P@3F%V
M:6=A<VD@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B"FUS9W-T
M<B`B4&5R8F5S87(@8F]R9&5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PHC+"!F=7IZ>0IM<V=I
M9"`B0V]L;VUB:6$B"FUS9W-T<B`B5V%R;F$B"@HC.B!L:6(O0FQO8VLO8V]L
M;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B
M0V]L;W(B"FUS9W-T<B`B5V%R;F$B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO0V]L;&5C=&EO;BYP:'`Z,S(T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R]#;VQL96-T:6]N+G!H<#HS,C4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C4P,"!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K
M97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B4&5M:6QI
M:"!787)N82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X-#8*(RP@
M9G5Z>GD*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B2&%P=7,@
M<&EL:6AA;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R(")+;VQO;2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#8*;7-G:60@(D-O;'5M;B!T:71L
M97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V
M-`IM<V=I9"`B0V]M:6-S(@IM<V=S='(@(D-O;6EC<R(*"B,Z(&%D;6EN+V-M
M9'-H96QL+G!H<#HR-0IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R(")#;VUM86YD
M(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM86YD(%-H
M96QL(@IM<V=S='(@(D-O;6UA;F0@4VAE;&PB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,3,*(RP@9G5Z>GD*;7-G:60@(D-O;6UE;G0B
M"FUS9W-T<B`B0V]M;6%N9"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-38V"B,L(&9U>GIY"FUS9VED(")#;VUM;VX@3F%M92(*;7-G
M<W1R(").86UA($%N9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`HC+"!F=7IZ>0IM<V=I9"`B
M0V]M;W)O<R(*;7-G<W1R(")"97-O:R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR,SD*(RP@9G5Z>GD*;7-G:60@(D-O;7!A
M;GDB"FUS9W-T<B`B4V%L:6XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S$*;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R(")+;VUP=71E<B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3<*;7-G:60@(D-O;F1I=&EO
M;B(*;7-G<W1R(")+;VYD:7-I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-#D*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B2V]N9&ES:2(*"B,Z(&%D
M;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N($1I
M9F9E<F5N8V5S(@IM<V=S='(@(E!E<F)E9&%A;B!+;VYF:6=U<F%S:2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#,*;7-G:60@(D-O;F9I9W5R871I
M;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T
M;&]O:RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S
M-0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T
M<B`B2V]N9FEG=7)A<VD@<W5D86@@:&%B:7,@;6%S82!B97)L86MU;GEA+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(DUE;F=A='5R("5S(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,0IM<V=I9"`B0V]N
M9FER;2!087-S=V]R9"(*;7-G<W1R(")+;VYF:7)M87-I(%-A;F1I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-@HC+"!F=7IZ>0IM<V=I9"`B0V]N9V\B"FUS9W-T<B`B5V%R;F$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8U"FUS9VED(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P
M=6)L:6,@;V8@=&AE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I
M9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HW.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D
M('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-#4*;7-G
M:60@(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#$T"FUS9VED(")#;VYT
M86-T<R(*;7-G<W1R(")+;VYT86LB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C
M8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4V
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;VYT96YT<R!O9B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C,S"FUS9VED(")#;VYT:6YU92(*;7-G<W1R("),86YJ
M=70B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,R"FUS9VED(")#;V]K:64B
M"FUS9W-T<B`B0V]O:VEE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED(")#;W!Y(@IM<V=S='(@
M(E-A;&EN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C@*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G
M<W1R(")+;VQO;2!Y86YG(&1I:6UP;W(Z("5S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE
M8W1I;VXB"FUS9W-T<B`B4V%L:6X@4&EL:6AA;B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-S8*;7-G:60@
M(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#4S"FUS9VED(")#
M;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD
M(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U
M;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A
M8W0N("5S(@IM<V=S='(@(E1I9&%K(&1A<&%T(&UE;GEI;7!A;B!K;VYF:6=U
M<F%S:2`E<RXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M.38@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ,C$*(RP@9G5Z>GD*
M;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R
M(")4:61A:R!D87!A="!T97)I:V%T(&1E;F=A;B!S97)V97(@;&1A<"(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-3<*;7-G:60@(D-O=6QD(&YO="!B
M:6YD('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(E1I9&%K(&1A<&%T('1E<FEK
M870@9&5N9V%N('-E<G9E<B!L9&%P(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS
M9W-T<B`B5&ED86L@9&%P870@=&5R:'5B=6YG(&ME('-E<G9E<B!L9&%P(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0T,0IM<V=I9"`B0V]U;&0@;F]T
M(&-O;FYE8W0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B5&ED86L@9&%P870@
M=&5R:'5B=6YG(&ME('-E<G9E<B!L9&%P(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C0X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@8V]N;F5C="!T;R!S97)V97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS
M9W-T<B`B5&ED86L@9&%P870@=&5R:'5B=6YG(&ME('-E<G9E<B`G)7,G(&1E
M;F=A;B!M96YG9W5N86MA;B!&5%`Z)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,B"FUS9W-T<B`B5&ED86L@9&%P870@;65N=6QI<R!K;VYF:6=U<F%S
M:2!U;G1U:R`G)7,G.B`E<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$Q,C4*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4R,@IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,C0V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S(@IM<V=S='(@(E1I9&%K(&1A
M<&%T(&ME;6)A;&D@:V4@:V]N9FEG=7)A<VDN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S(@IM<V=S='(@(E1I9&%K(&1A<&%T(&UE;F=H87!U<R!S8W)I
M<'0@<V5T=7`@=7!G<F%D92`G)7,G+B`B"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HS.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S
M='(@(E1I9&%K(&1A<&%T(&UE;F=H87!U<R!S8W)I<'0@<V5T=7`@=7!G<F%D
M92`G)7,G+B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C,X,2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-3,*;7-G:60@
M(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A
M9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H
M(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*;7-G:60@
M(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M
M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T
M<'5T4W1R871E9WDN<&AP.C8X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO
M9&ER96-T+G!H<#HS,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M;6MD:7(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HW,3D*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!O
M8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@
M(E1I9&%K(&1A<&%T('1E<FEK870@9&5N9V%N('-E<G9E<B!L9&%P(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R
M(")4:61A:R!D87!A="!M96YY:6UP86X@:V]N9FEG=7)A<VD@)7,N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C8R
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E
M<RXB"FUS9W-T<B`B5&ED86L@9&%P870@;65N>6EM<&%N(&MO;F9I9W5R87-I
M("5S+B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP
M:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N($UA
M:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M;W!E;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$Q(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HQ-#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C(S-R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#<X
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HU,38@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z-C4V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HV.3D*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R96%C:"!T
M:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(E1I9&%K(&1A<&%T('1E<FAU8G5N
M9R!K92!S97)V97(@;&1A<"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+T]B:F5C
M="YP:'`Z,C,X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<F5A9"`E<RXB"FUS9W-T<B`B7"(E<UPB(&)E;'5M(&1I8G5A=#H@)7,N
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*
M(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T
M960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO
M="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T
M<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B
M"B)4:61A:R!D87!A="!M96YG871U<B!U;&%N9R!U;G1U:R!P96YG9W5N82!Y
M86YG(&1I;6EN=&$N($)E8F5R87!A(&%T874@<V5M=6$@(@HB9&5T:6P@=&ED
M86L@8F5N87(N($-O8F$@;&%G:2!A=&%U('-I;&%K86X@:'5B=6YG:2!A9&UI
M;FES=')A=&]R(&%N9&$@:FEK82`B"B)A;F1A(&UE;65R;'5K86X@8F%N='5A
M;B!L96)I:"!L86YJ=70N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S`Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,T,`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS-S<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S@S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,X.0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE
M=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")4:61A:R!D87!A="!K96UB86QI(&ME
M(&MO;F9I9W5R87-I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-#,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*
M;7-G<W1R(")4:61A:R!D87!A="!K96UB86QI(&ME(&MO;F9I9W5R87-I+B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"FUS9VED
M(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@
M(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B5&ED
M86L@9&%P870@:V5M8F%L:2!K92!K;VYF:6=U<F%S:2XB"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M
M9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@
M)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B5&ED86L@9&%P870@;65N>6EM
M<&%N(&MO;F9I9W5R87-I("5S+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU.0HC+"!F=7IZ>0IM<V=I
M9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G
M<W1R(")4:61A:R!D87!A="!M96YY:6UP86X@:V]N9FEG=7)A<VD@8F%C:W5P
M+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG
M=6%T:6]N.B`E<R(*;7-G<W1R(")4:61A:R!D87!A="!M96YY:6UP86X@:V]N
M9FEG=7)A<VD@8F%C:W5P.B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.CDU"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R
M(")4:61A:R!D87!A="!M96YY:6UP86X@<V-R:7!T('-E='5P('5P9W)A9&4@
M:V4Z)R5S)RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N
M9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R(")4:61A:R!D87!A="!M96YY
M:6UP86X@9FEL92!K;VYF:6=U<F%S:2!B86-K=7`@)7,N(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#
M;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@
M8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@
M=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E
M(&)E;&]W('1O("5S+B(*;7-G<W1R("(B"B)4:61A:R!D87!A="!M96YY:6UP
M86X@9FEL92!K;VYF:6=U<F%S:2`E<RX@06YD82!D87!A="!M96YG9W5N86MA
M;B!S86QA:"!S871U("(*(F1A<FD@<&EL:6AA;B!U;G1U:R!M96YY:6UP86X@
M:V]D92!T97)S96)U="!K96UB86QI(&ME("5S(&%T875P=6X@;65N>6%L:6X@
M(@HB:V]D92!D:2!B87=A:"!I;FD@<V5C87)A(&UA;G5A;"!K92`E<RXB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$T,PHC+"!F=7IZ>0IM
M<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S
M='(@(E1I9&%K(&1A<&%T('1E<FAU8G5N9R!K92!S97)V97(@;&1A<"(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@=6YL:6YK(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@
M)7,B"FUS9W-T<B`B5&ED86L@9&%P870@;65N>6EM<&%N(&MO;F9I9W5R87-I
M("5S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,SDV"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")4:61A
M:R!D87!A="!M96YU;&ES(&MO;F9I9W5R87-I('5N='5K("<E<R<Z("5S(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@
M7"(E<UPB.B`E<R(*;7-G<W1R(")4:61A:R!D87!A="!M96YU;&ES(&MO;F9I
M9W5R87-I('5N='5K("<E<R<Z("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,V-@IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E
M8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB"FUS9W-T<B`B
M(@HB5&ED86L@9&%P870@;65N96UU:V%N(%!A;F5L($YA=FEG87-I($UO>FEL
M;&$N(%!A<W1I:V%N('!A;F5L(&YA=FEG87-I('-U9&%H("(*(G1E<F)U:V$N
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E<B!<
M(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E
M<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-#$Y"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-CD*(RP@9G5Z>GD*;7-G
M:60@(D-O=6YT<GDB"FUS9W-T<B`B2V]M<'5T97(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C<S"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(DMU
M<G-U<R(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C$P,`IM<V=I9"`B0W)E871E(@IM<V=S='(@(D)U870B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C@*;7-G:60@(D-R96%T92!A(&QI;FLB"FUS9W-T<B`B0G5A="!L
M:6YK(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY
M-`IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R(")"=6%T(&)A<G4B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM
M<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,C0P"B,L(&9U>GIY"FUS9VED(")#
M<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(DEZ:6X@=&%M=2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R,S`*(RP@9G5Z>GD*;7-G:60@(D-R
M961I="!C87)D(&YU;6)E<B(*;7-G<W1R(")!;F=K82!$97-I;6%L(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B0G5A
M="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C(V"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(#0@
M4&AA<V5S(@IM<V=S='(@(D9A<V4@4V5K87)A;F<B"@HC.B!A9&UI;B]S97-S
M:6]N<RYP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B
M"FUS9W-T<B`B27II;B!T86UU(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@
M;&EB+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS
M9W-T<B`B5V%K='4@4V5K87)A;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@
M55),(&ES(@IM<V=S='(@(E523"!396MA<F%N9R!A9&%L86@B"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z,S,*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@57-E
M<G,B"FUS9W-T<B`B1F%S92!396MA<F%N9R(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C4*;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R(")#=6%C
M82!396MA<F%N9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-S4*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`B2V]N9&ES
M:2!396MA<F%N9SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@(D=A
M>6$@4V5K87)A;F<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`X"B,L
M('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O
M;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B2V]S='5M:7-A<VD@='5G87,@=6YT
M=6L@9&EJ86QA;FMA;B!S96)E;'5M(&QO9V]N(&ME("5S+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM
M<V=I9"`B0W5T(@IM<V=S='(@(DAA<'5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C=&EO
M;B(*;7-G<W1R(")(87!U<R!P:6QI:&%N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C8V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B
M0WEP<G5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R
M"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R(")#>7)I;&QI8R`H
M2T])."U2*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#
M>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R(")#>7)I;&QI8R`H5VEN
M9&]W<RTQ,C4Q*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@T"FUS9VED
M(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"FUS9W-T<B`B0WER:6QL
M:6,O56MR86EN:6%N("A+3TDX+54I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WIE
M8V@@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0U,2!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU
M,`IM<V=I9"`B1$0B"FUS9W-T<B`B1$0B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,C@Q"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP
M:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S
M;BYP:'`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-
M86EN=&5N86YC92YP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(D1A:6QY(@IM<V=S
M='(@(DAA<FDB"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A
M=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B1&%T851R964@0G)O=W-E<B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-SD*;7-G:60@(D1A=&%B87-E
M($QO;VMU<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S
M.3D*(RP@9G5Z>GD*;7-G:60@(D1A=&4B"FUS9W-T<B`B4V%L:6XB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T
M92!296-E:79E9"(*;7-G<W1R(")486YG9V%L($1I=&5R:6UA(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P-PHC+"!F=7IZ>0IM<V=I9"`B1&%T
M92!S96QE8W1I;VXB"FUS9W-T<B`B2&%P=7,@<&EL:6AA;B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3(@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,R,@IM<V=I9"`B1&%Y(@IM<V=S='(@(DAA<FDB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(DAA<'5S($MO;&]M
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q
M,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*
M;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(D1E<V5M8F5R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM
M<V=I9"`B1&5C:6UA;"!N=6UB97)S(@IM<V=S='(@(D%N9VMA($1E<VEM86PB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(P
M"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`B365N9W5R86YG:2!)
M;F1E;B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3@W(&QI
M8B]P<F5F<RYP:'`Z,3$W"FUS9VED(")$969A=6QT(@IM<V=S='(@(D1E9F%U
M;'0B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHT-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHW-PIM<V=I9"`B1&5F875L="!#;VQO<B(*;7-G<W1R(")$969A=6QT(%=A
M<FYA(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HY,0HC
M+"!F=7IZ>0IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*;7-G<W1R(")$969A
M=6QT(&ED96YT:71A<R!A;F1A.B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HV-PIM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R(")$969A=6QT(%-H
M96QL(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I
M;FET:6]N<R(*;7-G<W1R(")$969I;FES:2(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z-S$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C8*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HT,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS
M-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C<P"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z.3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,38*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ.#(*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C<S('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY.`HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*;7-G<W1R
M(")(87!U<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS,@IM<V=I9"`B1&5L971E($-E;&PB"FUS9W-T<B`B
M2&%P=7,@4V5L(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O
M=7!S+G!H<#HR,C<*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R(")(87!U
M<R!'<G5P(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0Y"B,L
M(&9U>GIY"FUS9VED(")$96QE=&4@3&]G(@IM<V=S='(@(DAA<'5S(&)A<FES
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-R!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,0HC+"!F=7IZ>0IM<V=I9"`B1&5L
M971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B27II;B!T86UU(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E;&5T
M92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B
M1&5L971E(&-E;&PB"FUS9W-T<B`B2&%P=7,@<V5L(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I9"`B
M1&5L971E(&-O;'5M;B(*;7-G<W1R(")(87!U<R!K;VQO;2(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z,30X"FUS9VED(")$96QE=&4@97AI<W1I;F<@86QT
M97)N871E('1E;7!L871E(@IM<V=S='(@(DAA<'5S('!E;F=G86YT:2!T96UP
M;&%T92!Y86YG('-U9&%H(&%D82(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z-#(Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE
M=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R(")58F%H(&EZ:6X@
M=6YT=6L@)7,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R
M(%PB)7-<(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV-PIM<V=I9"`B1&5L971E(')O=R(*;7-G<W1R(")(87!U<R!B87)I<R(*
M"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*;7-G
M:60@(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET>2(*;7-G<W1R(")(87!U<R!I
M9&5N=&ET87,@>6%N9R!T97)P:6QI:"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E
M('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R(")(87!U<R!K;VQO;2!Y86YG
M('-E:V%R86YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@
M<F]W(@IM<V=S='(@(DAA<'5S(&)A<FES('EA;F<@<V5K87)A;F<B"@HC.B!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N
M(@IM<V=S='(@(DAA<'5S('-C<FEP="!S971U<"!U<&=R861E("<E<R<N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M-C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU.34*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(U,PHC+"!F=7IZ>0IM<V=I9"`B1&5L:79E<GD@=&EM92(*
M;7-G<W1R(")(87!U<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*(RP@9G5Z>GD*;7-G:60@(D1E
M;FUA<FLB"FUS9W-T<B`B1&ET86YD86DB"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB
M"FUS9W-T<B`B2F5L87-K86X@36%S86QA:"(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.CDS."!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,P"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R(")$
M97-K<FEP<VDB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y-0IM
M<V=I9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y.0HC+"!F
M=7IZ>0IM<V=I9"`B1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@
M861M:6YI<W1R871O<BXB"FUS9W-T<B`B07)E82!-971A<B!T:61A:R!D:7-E
M9&EA:V%N+B!$971I;"!T96QA:"!D:6-A=&%T('5N='5K(&%D;6EN:7-T<F%T
M;W(N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Q.0IM<V=I9"`B
M1&5V96QO<&UE;G0B"FUS9W-T<B`B4&5R:V5M8F%N9V%N(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,3<*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R(")4
M:71I:R!%;6)U;B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDT"FUS9VED
M(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(E1I=&EK($5M
M8G5N('5N='5K(&IA;2!T97)A:VAI<CHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C(W"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R(")4
M:71I:R!%;6)U;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT(@IM
M<V=S='(@(D%R86@@:VER:2!K92!K86YA;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R
M:6=H="!T;R!L969T(@IM<V=S='(@(D%R86@@:V%N86X@:V4@:VER:2(*"B,Z
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB"FUS
M9W-T<B`B1&ER96MT;W)I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V
M-@IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R(")486UP
M:6QK86X@=V%K='4@,C0@:F%M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY-PIM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(E1A;7!I;&MA
M;B!0:6QI:&%N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.CDV
M"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM<V=S='(@(E1A
M;7!I;&MA;B!D971I;"!R86UA;&%N(&-U86-A(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HX-0IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G
M<W1R(")486UP:6QK86X@<F%M86QA;B!C=6%C82`H5$%&*2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3<*(RP@9G5Z>GD*;7-G:60@(D1I<W!L
M87D@9F]R;6%T(@IM<V=S='(@(E1A;7!I;&MA;B!R86UA;&%N(&-U86-A("A4
M048I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C$Y,`IM<V=I
M9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z-#(R"B,L(&9U>GIY"FUS9VED(")$;R!N
M;W0@9&5L971E(@IM<V=S='(@(DAA<'5S(@H*(SH@<V5R=FEC97,O;6%I;G1E
M;F%N8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA
M:6YT96YA;F-E+G!H<"(*;7-G<W1R(")*86YG86X@;&%N9W-U;F<@;65N9V%K
M<V5S(&UA:6YT96YA;F-E+G!H<"(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN
M9F\N:6YC.C$R('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$R"FUS9VED
M(")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_
M($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(B(*(D%P86MA:"!B
M87)I<R!Y86YG('!E<G1A;6$@=&5R9&ER:2!D87)I(&MO;&]M(&YA;6$_(&II
M:V$@>6$L(&)E<FD@=&%N9&$@<&%D82`B"B)K;W1A:R!I;FDZ(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM
M<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@86X@
M86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B5&ED86L@;65M:6QI:VD@86-C
M;W5N=#\@4VEL86MA;B!M96YD869T87(N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z.#0T"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO860@
M9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T
M<B`B1&]W;FQO860@:V]N9FEG=7)A<VD@>6%N9R!D:6AA<VEL:V%N('-E8F%G
M86D@<V-R:7!T(%!(4"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,3`W"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(D]B
M870M;V)A=&%N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#$S"B,L(&9U>GIY"FUS9VED(")%+4UA:6PB"FUS9W-T<B`B4W5R870B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM
M<V=I9"`B14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE
M<G,@=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+VUO8FEL92YP:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<P"FUS9VED(")%8W5A9&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,S4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3$U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHW,@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS
M9VED(")%9&ET(@IM<V=S='(@(E5B86@B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO54DN<&AP.C4P('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,C4*
M;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T<B`B56)A:"!";&]K:7(B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C$Y."!A9&UI;B]G<F]U<',N<&AP.C(R-@IM<V=I
M9"`B161I="!'<F]U<"(*;7-G<W1R(")58F%H($=R=7`B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<V(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,3`P"B,L(&9U>GIY"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB
M"FUS9W-T<B`B56)A:"!)>FEN(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N
M<&AP.C(S-PIM<V=I9"`B161I="!097)M:7-S:6]N<R(*;7-G<W1R(")58F%H
M($EZ:6XB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S
M='(@(E5B86@@27II;B!U;G1U:R`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]A
M<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@(E5B
M86@@<&EL:6AA;B!U;G1U:SHB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C,V-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B161I="!P
M97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(E5B86@@:7II;B!U;G1U
M:R`E<R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T
M<B`B56)A:"!I>FEN('5N='5K("5S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,U"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B4&5N9&ED:6MA;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"B,L('!H<"UF;W)M870*;7-G:60@
M(D5I=&AE<B!E;F%B;&4@:70@=&AE;CH@)7,L(&]R('5S92!T:&4@8F%S:6,@
M2%1-3"!V97)S:6]N.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HW-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS
M9VED(")%;"!386QV861O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L
M96UE;G0N+BXB"FUS9W-T<B`B16QE;65N+BXN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S
M='(@(D5M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C(R-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8Y"B,L(&9U>GIY
M"FUS9VED(")%;6%I;"(*;7-G<W1R(")3=7)A="(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-38U('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O961I="YI;F,Z,3`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHV.`IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R(")!;&%M870@
M16UA:6PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38S"B,L(&9U
M>GIY"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS9W-T
M<B`B4V%N9&D@:&%R=7,@8V]C;VLN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3DX.0HC+"!F=7IZ>0IM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M
M871I;VXB"FUS9W-T<B`B2V]N9FEG=7)A<VD@)7,@<W5D86@@9&ES:6UP86XN
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z
M.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E=V%Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR.3@*(RP@
M9G5Z>GD*;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R(")+;VYD:7-I(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R
M"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C0S(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HT.#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C8V,B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S`U
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%
M;7!T>2!R97-U;'0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,
M+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E87)C:"!T97)M<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-30S"FUS9VED
M(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE
M<FEE<R!I;B!T97AT/R(*;7-G<W1R(")!:W1I9FMA;B!P96YY:7-I<&%N(&=A
M;6)A<BUG86UB87(@9&%R:2!'86QE<FD@1F]T;R!D:2!D86QA;2!T96MS/R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3@*;7-G:60@(D5N86)L92!R
M:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@(D%K=&EF:V%N(&ML
M:6L@:V%N86X@;65N=2!K;VYT96MS/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(U.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,0HC+"!F
M=7IZ>0IM<V=I9"`B16YD('EE87(B"FUS9W-T<B`B4&5R8F5S87(@4&%N96P@
M3F%V:6=A<VDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G<W1R(")097)B
M97-A<B!%9&ET;W(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(Q"FUS
M9VED("(B"B)%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W
M:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S
M<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB
M"FUS9W-T<B`B(@HB36%S=6MK86X@<&5R=&%N>6%A;B!K96%M86YA;B!D:6UA
M;F$@86YD82!A:V%N(&1I=&%N>6%K86X@87!A8FEL82!A;F1A('!E<FQU("(*
M(G5N='5K(&UE;F=A='5R('5L86YG('-A;F1I(&%N9&$L("!C;VYT;V@@)V%P
M86MA:"!N86UA(&)I;F%T86YG(&ME<V%Y86YG86X@(@HB86YD83\G.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE(&EM86=E(%523"!H97)E(@IM<V=S
M='(@(DUA<W5K:V%N(%523"!G86UB87(@9&ES:6YI(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Y,0IM<V=I9"`B16YT97(@
M=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HW-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G
M:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*
M;7-G:60@(D5R:71R96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF
M:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#4@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C4U"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S8@
M<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HX,@IM<V=I9"`B17)R;W(B"FUS
M9W-T<B`B2V5S86QA:&%N(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L
M871E+G!H<#HT-C,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R
M(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R(")+97-A;&%H86X@<V%A="!M
M96UP97)B86AA<G5I('-A;F1I.B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C<R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O
M<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T<B`B2V5S86QA:&%N
M('-A870@;65M<&5R8F%H87)U:2!S86YD:3H@)7,B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HX,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S(@IM<V=S='(@(DME<V%L
M86AA;B!S86%T(&UE;7!E<F)A:&%R=6D@<V%N9&DZ("5S(@H*(SH@9G)A;65W
M;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C@*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS9W-T
M<B`B2V5S86QA:&%N('-A870@;65M<&5R8F%H87)U:2!S86YD:3H@)7,B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@
M(DME<V%L86AA;B!S86%T(&UE;7!E<F)A:&%R=6D@<V%N9&DZ("5S(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U
M"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*
M(RP@9G5Z>GD*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B4W5K=2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S$*;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S='(@(E-U:W4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U
M<F]P92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Y
M"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(E-E=&EA<"`Q-2!M
M96YI="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#D*;7-G:60@(D5V
M97)Y(#(@;6EN=71E<R(*;7-G<W1R(")3971I87`@,B!M96YI="(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S8@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,X-PIM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R(")3971I87`@
M,S`@9&5T:6LB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,X(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.3`*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*
M;7-G<W1R(")3971I87`@-2!M96YI="(*"B,Z(&9R86UE=V]R:R]-86EN=&5N
M86YC92]-86EN=&5N86YC92YP:'`Z-C`*(RP@9G5Z>GD*;7-G:60@(D5V97)Y
M($QO9VEN(@IM<V=S='(@(E-E=&EA<"!M96YI="(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-#`*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R
M(")3971I87`@<V5T96YG86@@:F%M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,S-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@X"FUS9VED(")%=F5R
M>2!M:6YU=&4B"FUS9W-T<B`B4V5T:6%P(&UE;FET(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T96UA<"YI;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*
M;7-G<W1R(")#;VYT;V@@;FEL86DM;FEL86DZ(@H*(SH@861M:6XO<&AP<VAE
M;&PN<&AP.C@Q(&%D;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3(W"FUS9VED(")%>&5C=71E(@IM<V=S='(@(DIA;&%N:V%N(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#<U"B,L(&9U
M>GIY"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B4&5R8F5S87(@4&%N96P@3F%V
M:6=A<VDB"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R"FUS
M9VED(")%>'!A;F0@4VED96)A<B(*;7-G<W1R(")097)B97-A<B!086YE;"!.
M879I9V%S:2(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ
M-C@*(RP@9G5Z>GD*;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R(")*86QA
M;FMA;B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-S4*
M;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E
M<FTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#$R"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S8*;7-G:60@(D5X
M<&]N96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S
M='(@(E=A<FYA($9'(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM
M<V=I9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R(")&5%`@=7!L;V%D
M('5N='5K('-E='5P(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-Q;"YP
M:'`Z,C$V"FUS9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C<U(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z.3@*(RP@9G5Z>GD*
M;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G
M<W1R(")4:61A:R!D87!A="!T97)H=6)U;F<@:V4@<V5R=F5R(&QD87`B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.3@*(RP@9G5Z>GD*;7-G
M:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM<V=S='(@
M(E1I9&%K(&1A<&%T('1E<FAU8G5N9R!K92!S97)V97(@;&1A<"(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C@V"B,L('!H<"UF;W)M870*;7-G
M:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8Y,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")&86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#<*;7-G:60@(D9A
M:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3<@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HW,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B5&ED86L@
M9&%P870@=6YT=6L@;65N9VAA<'5S(%PB)7-<(CH@)7,N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HT-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*
M;7-G<W1R(")#97)A:"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML86YD($ES
M;&%N9',@*$UA;'9I;F%S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED
M(")&87)O92!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO
M0TQ)+G!H<#HR,S@*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W"B,L
M(&9U>GIY"FUS9VED(")&87@B"FUS9W-T<B`B1F%X(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,T.0IM<V=I9"`B1F%X97,B"FUS9W-T<B`B1F%X
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*
M;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(D9E8G)U87)I(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,C`*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B
M4V5P97)T:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*
M;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R(")397!E<G1I.B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Y"FUS9VED(")&
M97<@4VAO=V5R<R(*;7-G<W1R(")'97)I;6ES(%-E8F%G:6%N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G:60@(D9E
M=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B1V5R:6UI<R!386QJ=2!396)A9VEA
M;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#0*;7-G:60@(D9I
M96QD(&UA=')I>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,S,T"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,X"FUS9VED(")&:6=L970@
M9F]N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F
M=7IZ>0IM<V=I9"`B1FEL92(*;7-G<W1R(")&:6QT97(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE
M($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z
M("5S(&9I;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT,#<*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R(")&:6QE($UA
M;F%G97(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C8S(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-0HC+"!F=7IZ
M>0IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(DYA;6$@3&5N9VMA<"(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y.34*(RP@9G5Z>GD*;7-G:60@
M(D9I;&4@<V5L96-T:6]N(@IM<V=S='(@(DAA<'5S('!I;&EH86XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#@V"FUS9VED(")&:6QE('5P;&]A
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H
M<#HX-3D*(RP@9G5Z>GD*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R
M=&5D+B(*;7-G<W1R(")&5%`@=7!L;V%D('5N='5K('-E='5P(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Y"FUS9VED(")&:6QT97)S(@IM<V=S
M='(@(D9I;'1E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(D9I;FQA
M;F0B"FUS9W-T<B`B;6%S:6@@9&D@9&%L86T@86YT<FEA;B(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B
M1F%S92!P97)T86UA(&1A<FD@4V5P87)U:"!"=6QA;B(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I
M<G-T(%%U87)T97(B"FUS9W-T<B`B1F%S92!P97)T86UA(&1A<FD@4V5P87)U
M:"!"=6QA;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR-38*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,Q"FUS9VED(")&
M;&EP(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(D9L
M;V%T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C$*;7-G:60@(D9O9R(*;7-G<W1R(")"97)K86)U="(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z,C,T(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HQ,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@
M;F]T(&5X:7-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L;W(B"FUS9W-T
M<B`B5V%R;F$@5'5L:7-A;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M-PIM<V=I9"`B1F]O9"(*;7-G<W1R(")-86MA;F%N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V"FUS
M9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(*
M;7-G<W1R(")5;G1U:R!B<F]W<V5R('EA;F<@=&ED86L@9&%P870@;65N9'5K
M=6YG(&=A;6)A<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,T"FUS9VED
M(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R(")286UA;&%N(&-U86-A("A4048I
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<Y"FUS9VED("(B
M"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C
M87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU
M;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S
M='(@(B(*(DAA<FD@4F%M86QA;B!#=6%C82`H8V%T871A;B!B86AW82!R86UA
M;&%N(&-U86-A('EA;F<@9&EK96UB86QI:V%N(&%K86X@(@HB;65N9V5M8F%L
M:6MA;B!B86EK('-I86YG(&%T874@;6%L86T@:&%R:2P@<V5J=6UL86@@86YG
M:V$@9&%P870@9&EH87-I;&MA;B`B"B)P861A(&%R96$@:6YI*2(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3`R"FUS9VED(")&;W)G;W0@>6]U
M<B!P87-S=V]R9#\B"FUS9W-T<B`B3'5P82!D96YG86X@<V%N9&D@86YD83\B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8R"FUS9VED(")&;W)M
M<R(*;7-G<W1R(")&;W)M=6QI<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HR,0IM<V=I9"`B1F]R='5N92(*;7-G<W1R(")286UA;&%N(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS
M9W-T<B`B5&EP92!286UA;&%N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,X"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R(")286UA;&%N(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,Y"FUS9VED(")&;W)T=6YE<R`R(@IM<V=S
M='(@(E)A;6%L86X@,B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M-3,*;7-G:60@(D9O<G5M<R(*;7-G<W1R(")&;W)U;2(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ,#D*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@
M(D1I=&5R=7-K86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R(")*;70B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S"FUS
M9VED(")&<F%M97,B"FUS9W-T<B`B1G)A;64B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"B,L(&9U
M>GIY"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B1G)A;64B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P
M;VQI=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D9R96YC:"!'
M=6EA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0
M;VQY;F5S:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N
M8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-`HC+"!F=7IZ>0IM
M<V=I9"`B1G)O;2(*;7-G<W1R(")*;70B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C0X(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M-C`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0P-@IM<V=I9"`B
M1G)O;2!T:&4@(@IM<V=S='(@(D1A<FDB"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHT.`IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G
M<W1R(")$97-K<FEP<VD@3&5N9VMA<"(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HX,2!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB
M"FUS9W-T<B`B0G5L86X@4'5R;F%M82(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HV,2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8P"FUS
M9VED(")&=6QL($YA;64B"FUS9W-T<B`B3F%M82!,96YG:V%P(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,PIM<V=I9"`B1V%B;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,P"FUS9VED
M(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R(")'86QE<FD@
M=6YT=6L@;65N9V%M8FEL(&=A;6)A<B!D87)I(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED
M(")'86QL97)Y.B(*;7-G<W1R(")'86QE<FDB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED
M(")'86UB:6$B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#;VYF:6=U
M<F%T:6]N(@IM<V=S='(@(DUE;F=H87-I;&MA;B`E<R!+;VYF:6=U<F%S:2`B
M"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I
M9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B2V]D92!Y86YG(&1I:&%S:6QK
M86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDP(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<T"FUS9VED(")'96]R9VEA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.CDQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B
M1VEB<F%L=&%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3<U"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$R"FUS9VED(")';R(*;7-G
M<W1R(")*86QA;FMA;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,`IM
M<V=I9"`B1V]E9&5L(@IM<V=S='(@(D=O961E;"(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3(X"B,L(&9U>GIY"FUS9VED
M(")';V]G;&4@36%P<R(*;7-G<W1R(")096YC87)I86X@1V]O9VQE(@H*(SH@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE+G!H<#HR
M,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE(%-E87)C
M:"(*;7-G<W1R(")096YC87)I86X@1V]O9VQE(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-PIM<V=I9"`B1W)A>7-C86QE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'<F5E8V4B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#4*;7-G:60@(D=R965K
M("A)4T\M.#@U.2TW*2(*;7-G<W1R(")9=6YA;FD@*$E33RTX.#4Y+3<I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-0IM<V=I9"`B1W)E96YL86YD(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S0*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HQ-SD*;7-G:60@(D=R;W5P($%D;6EN:7-T<F%T:6]N(@IM<V=S
M='(@(D%D;6EN:7-T<F%S:2!'<G5P(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+G!H<#HU.2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,38Y
M"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L
M('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@
M9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$X
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,C0*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0Q.`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U
M<"`E<R(*;7-G<W1R(")4:61A:R!D87!A="!U;G1U:R!M96YG:&%P=7,@7"(E
M<UPB.B`E<RXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M,S,X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G
M<F]U<"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C,Q-"!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.`HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@
M(D=R=7`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<W"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HY,@HC+"!F=7IZ>0IM<V=I9"`B1W5E<FYS
M97DB"FUS9W-T<B`B475E<GDB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED
M(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R("))>FEN('1A;74B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<P"FUS9VED(")'=65S=&)O;VLB
M"FUS9W-T<B`B0G5K=2!T86UU(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0HC+"!F=7IZ>0IM<V=I
M9"`B1W5I;F5A(@IM<V=S='(@(DIU;FDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@
M(D=U:6YE82U":7-S874B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED
M(")'=7EA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z.38P"FUS9VED(")(5$U,(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G:60@(DA4
M34Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E
M;&P@:6X@<F]W+B(*;7-G<W1R("(B"B)(5$U,07)E82!D96YG86X@<F%G=2!M
M96YO;&%K('5N='5K(&UE;F=H87!U<R!S96P@>6%N9R!T97)A:VAI<B!D:2!D
M86QA;2`B"B)B87)I<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@V"FUS9VED(")(5$U,07)E82!C;W=A<F1L
M>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N
M(@IM<V=S='(@(B(*(DA434Q!<F5A(&1E;F=A;B!R86=U(&UE;F]L86L@=6YT
M=6L@;65N9VAA<'5S(&MO;&]M('EA;F<@=&5R86MH:7(@9&D@9&%L86T@(@HB
M=&%B96PN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E
M<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R("(B
M"B)(5$U,07)E82!D96YG86X@<F%G=2!M96YO;&%K('5N='5K(&UE;F=H87!U
M<R!B87)I<R!Y86YG('1E<F%K:&ER(&1I(&1A;&%M("(*(G1A8F5L+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED(")(5%10
M($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@P"FUS9VED(")(86ET:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@(D)E<FMA8G5T(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3$Y(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Y,S(*(RP@9G5Z>GD*;7-G:60@(DAE861E<B(*;7-G<W1R(")"
M86-A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H
M<#HV,0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*
M;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR,PHC+"!F=7IZ>0IM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R(")(
M=6IA;B!P971I<B!D:7-E<G1A:2!D96YG86X@86YG:6X@<FEB=70B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B2&5B<F5W("A)4T\M.#@U
M.2TX+4DI(@IM<V=S='(@(EEA:'5D:2`H25-/+3@X-3DM."U)*2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*
M;7-G:60@(DAE:6=H="(*;7-G<W1R(")4:6YG9VDB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3<Y(&9R86UE=V]R:R](;W)D92](;W)D
M92](96QP+G!H<#HQ.#8*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@
M=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C,*;7-G:60@(DAE;'`B"FUS9W-T
M<B`B0F%N='5A;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@
M(D)A;G1U86X@;65N9V=U;F%K86X@961I=&]R(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3,W,0HC+"!F=7IZ>0IM<V=I9"`B2&5L<&5R(@IM<V=S
M='(@(D)A;G1U86XB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@
M(DAE;6ES<&AE<F4B"FUS9W-T<B`B0F5L86AA;B!"=6UI(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@
M9FEL93HB"FUS9W-T<B`B26YI(&%D86QA:"!P97)M=6QA86X@9&%R:2!F:6QE
M.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Y
M"FUS9VED(")(:6=H(@IM<V=S='(@(E1I;F=G:2(*"B,Z('1E;7!L871E<R]P
M;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E
M<BYI;F,Z-0IM<V=I9"`B2&]?;64B"FUS9W-T<B`B2&]?;64B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$T"FUS9VED(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U,S4*
M(RP@9G5Z>GD*;7-G:60@(DAO;64B"FUS9W-T<B`B2&]?;64B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-34*(RP@9G5Z>GD*
M;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R(")!;&%M870@16UA:6PB"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*;7-G:60@(DAO;64@1&ER96-T
M;W)Y(@IM<V=S='(@(D1I<F5K=&]R:2!(;VUE(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-0IM<V=I9"`B
M2&]R9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C0T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E
M(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C0S-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@
M;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C$R-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T
M<B`B7"(E<UPB<W5D86@@8F5R:&%S:6P@9&EH87!U<RXB"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H
M92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(
M4"!E>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0W
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA
M8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(E1I9&%K(&1A
M<&%T('5N='5K(&UE;F=H87!U<R!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z-#<T"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE
M('!A<G0@;V8@='EP92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C$Q.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<(B5S7"(Z("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3,S-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y
M;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G
M:60@(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R(")'87)I<R!(;W)I<V]N=&%L
M(&1I(&1A;&%M($A434PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS
M9W-T<B`B2F%R86L@9V%R:7,@:&]R:7IO;G1A;"!D87)I(&)O<F1E<B!D96YG
M86X@=&5K<R!D:2!D86QA;2!S96PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G
M<W1R(")(;W)I>F]N=&%L.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I9"!Y;W4@
M9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B0F%G86EM86YA
M(&-A<F$@86YD82!B:7-A('-A;7!A:2!D:7-I;FD_("A3:6QA:V%N(&UE;&%P
M;W(A*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U
M(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(D)E<F%P82!B86YY86L@:V]L;VT@
M>6%N9R!I;F=I;B!A;F1A(&=A8G5N9VMA;C\B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9I;F9O+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU
M;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@(D)E<F%P82!B86YY86L@:V]L;VT@
M>6%N9R!A9&$@9&ES86YA/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O=W,@
M=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(D)E<F%P82!B86YY
M86L@8F%R:7,@>6%N9R!I;F=I;B!A;F1A(&=A8G5N9VMA;C\B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C,P"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R(")+96QE;6)A8F%N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U.0IM<V=I9"`B2'5M
M:61I='DZ("(*;7-G<W1R(")+96QE;6)A8F%N.B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(E!E;&%W
M86LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<R(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C$T(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<Y(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Q
M-@HC+"!F=7IZ>0IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R(")!;&%M870@
M16UA:6PB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C<W
M"B,L(&9U>GIY"FUS9VED("))4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(D%R96$@365T87(@=&ED86L@9&ES961I86MA;BXB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R
M97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B
M36%S=6MK86X@0F%R:7,@4V5B96QU;6YY82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I
M9"`B26-E;&%N9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S<V"FUS9VED("))8V]N<R!/;FQY(@IM<V=S='(@(DAA;GEA(&EK;VXB
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@(DEK;VX@=6YT=6L@)7,B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<W"FUS9VED("))8V]N<R!W:71H
M('1E>'0B"FUS9W-T<B`B26MO;B!D96YG86X@=&5K<R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ.3`*;7-G:60@(DED96YT:71Y)W,@;F%M93HB"FUS
M9W-T<B`B3F%M82!)9&5N=&ET87,Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z-3DR"B,L('!H<"UF;W)M870*;7-G:60@(DEF(&ET
M(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN
M(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0U-0IM<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A;GD@:6-O
M;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C
M:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y
M+B(*;7-G<W1R("(B"B)*:6MA(&%N9&$@=&ED86L@;65L:6AA="!I:V]N(&UA
M;F%P=6X@9&5N9V%N(&UE;F=G=6YA:V%N($EN=&5R;F5T($5X<&QO<F5R+"`B
M"B)A;F1A(&UU;F=K:6X@<&5R;'4@=6YT=6L@;65N86YD86D@:V]T86L@:6YI
M('5N='5K(&UE;F]N+6%K=&EF:V%N(&ME;&5M86AA;B`B"B)03D<N(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W,PIM<V=I
M9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T
M:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L
M87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`IM
M<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B3&EH870@1V%M8F%R.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R(")54DP@1V%M8F%R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3@*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(E523"!'86UB
M87(Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB"FUS
M9W-T<B`B1V%M8F%R(&1A<FD@9V%L97)I(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("))
M;6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(D=A;6)A<B!D87)I(&=A;&5R
M:3HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8Q"FUS9VED("))
M;6%G92!U<&QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP
M:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R(")'86UB87(M9V%M8F%R(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T
M82]D871E;6%P+FEN8SHW"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M-30@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-PHC+"!P:'`M9F]R;6%T
M"FUS9VED("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`B26UP;W(L($QA;F=K
M86@@)60B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P
M:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`B
M2V]L;VT@>6%N9R!D:6EM<&]R.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`B
M2V]L;VT@>6%N9R!D:6EM<&]R.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2
M;W<@069T97(B"FUS9W-T<B`B36%S=6MK86X@0F%R:7,@0F5R:6MU=&YY82(*
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S-0IM
M<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S,@HC+"!F=7IZ>0IM<V=I9"`B26YC;W)R96-T('5S97)N86UE(&%N9"]O
M<B!P87-S=V]R9"XB"FUS9W-T<B`B4VEL86MA;B!M87-U:VMA;B!N86UA('!E
M;F=G=6YA(&1A;B!S86YD:2!A;F1A(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A
M;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B
M"B)A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB"FUS
M9W-T<B`B(@HB3F%M82!P96YG9W5N82!A=&%U(&%L86UA="!E;6%I;"!P96YG
M9V%N=&D@=&ED86L@8F5N87(N($-O8F$@;&%G:2!A=&%U("(*(G-I;&%K86X@
M:'5B=6YG:2!A9&UI;FES=')A=&]R(&%N9&$@:FEK82!A;F1A(&UE;65R;'5K
M86X@8F%N='5A;B!L96)I:"!L86YJ=70N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD
M96YT(@IM<V=S='(@(DUE;F%M8F%H($EN9&5N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS
M9VED("));F1I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C(U-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM
M<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R(")096YG9W5N82!0<FEB
M861I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV
M-PIM<V=I9"`B26YF;R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C4W"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R("));F9O
M<FUA<VDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S,P"FUS
M9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+B(*;7-G<W1R
M("));F9O<FUA<VD@<W5D86@@=&ED86L@9&ES961I86MA;BXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*
M;7-G:60@(DEN<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S='(@(DUA<W5K:V%N
M($MO;&]M($)E<FEK=71N>6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G:60@(DEN<V5R="!)
M;6%G92(*;7-G<W1R(")-87-U:VMA;B!'86UB87(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED("));G-E<G0@
M5&%B;&4B"FUS9W-T<B`B36%S=6MK86X@5&%B96PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED("));G-E<G0@
M5V5B($QI;FLB"FUS9W-T<B`B36%S=6MK86X@5V5B($QI;FLB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*
M;7-G:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R(")-87-U:VMA
M;B!+;VQO;2!396)E;'5M;GEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED("));G-E<G0@82!N
M97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R(")-87-U
M:VMA;B!K;VQO;2!Y86YG(&)A<G4@<V5T96QA:"!K;VQO;2!Y86YG('-E:V%R
M86YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8U"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R
M92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B36%S=6MK86X@:V]L;VT@>6%N
M9R!B87)U('-E8F5L=6T@:V]L;VT@>6%N9R!S96MA<F%N9R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,@IM
M<V=I9"`B26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B
M"FUS9W-T<B`B36%S=6MK86X@8F%R:7,@>6%N9R!B87)U('-E=&5L86@@8F%R
M:7,@>6%N9R!S96MA<F%N9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W
M(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DUA<W5K:V%N
M(&)A<FES('EA;F<@8F%R=2!S96)E;'5M(&MO;&]M('EA;F<@<V5K87)A;F<B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-S`*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@
M8W5R<F5N="!N;V1E(@IM<V=S='(@(DUA<W5K:V%N('!A<F%G<F%F('-E=&5L
M86@@<&%R86=R868@>6%N9R!S96MA<F%N9R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.0IM<V=I9"`B26YS
M97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E(@IM<V=S
M='(@(DUA<W5K:V%N('!A<F%G<F%F('-E8F5L=6T@<&%R86=R868@>6%N9R!S
M96MA<F%N9R(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS9VED("))
M;G-E<G0@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(DUA<W5K:V%N('1E
M;7!L871E('!E;F=G86YT:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,SD*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO
M=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R(")-87-U
M:VMA;B!A;&%M870@96UA:6P@9&EM86YA(&%N9&$@9&%P870@;65N97)I;6$@
M<V%N9&D@>6%N9R!B87)U.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F
M=&5R(@IM<V=S='(@(DUA<W5K:V%N('-E;"!B97)I:W5T;GEA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0IM
M<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(DUA<W5K:V%N('-E
M;"!S96)E;'5M;GEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E
M<B(*;7-G<W1R(")-87-U:VMA;B!K;VQO;2!B97)I:W5T;GEA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM
M<V=I9"`B26YS97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`B36%S=6MK86X@
M:V]L;VT@<V5B96QU;6YY82(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.CDP"B,L(&9U>GIY"FUS9VED("));G-E<G0@;65S<V%G
M97,B"FUS9W-T<B`B36%S=6MK86X@1V%M8F%R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("))
M;G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(DUA<W5K:V%N('!A<F%G
M<F%F(&)E<FEK=71N>6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A
M<&@@8F5F;W)E(@IM<V=S='(@(DUA<W5K:V%N('!A<F%G<F%F('-E8F5L=6UN
M>6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8Y"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(DUA
M<W5K:V%N(&)A<FES(&)E<FEK=71N>6$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED("));G-E<G0@
M<F]W(&)E9F]R92(*;7-G<W1R(")-87-U:VMA;B!B87)I<R!S96)E;'5M;GEA
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,`IM<V=I9"`B26YS97)T
M('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N
M.B(*;7-G<W1R(")-87-U:VMA;B!J87=A8F%N('EA;F<@9&EP97)L=6MA;B!U
M;G1U:R!P97)T86YY86%A;B!K96%M86YA;CHB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(V"FUS9VED("));G-E<G0O36]D
M:69Y($EM86=E(@IM<V=S='(@(DUA<W5K:V%N+U5B86@@1V%M8F%R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I
M9"`B26YS97)T+TUO9&EF>2!,:6YK(@IM<V=S='(@(DUA<W5K:V%N+U5B86@@
M3&EN:R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C0S"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@
M=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I
M9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3`W-0HC+"!F=7IZ>0IM<V=I9"`B26YT96=E
M<B(*;7-G<W1R(")496YG86@B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,3,S"FUS9VED("));G1E9V5R(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS
M9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ
M-S`*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C`Q
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(Q,`IM
M<V=I9"`B26YV86QI9"!:25`@9&%T82(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N
M+B(*;7-G<W1R(")!<&QI:V%S:2!T:61A:R!V86QI9"XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@
M(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(P.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U
M.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C,R(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(R.3D*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E
M+W1A8FQE<V5T+G!H<#HS-PIM<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`P"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&1E
M<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(D%P;&EK87-I('1I9&%K('9A
M;&ED+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP
M.C@Q"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P
M,`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR,C`*
M(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B
M1F]R;6%T(%=A:W1U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$W-PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS
M9W-T<B`B07!L:6MA<VD@=&ED86L@=F%L:60N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$W,0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!L
M;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B07!L:6MA<VD@=&ED86L@=F%L
M:60N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#,*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?
M:60N(@IM<V=S='(@(DEZ:6X@:6YD=6L@=&ED86L@=F%L:60N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"B,L
M(&9U>GIY"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB
M"FUS9W-T<B`B27II;B!I;F1U:R!T:61A:R!V86QI9"XB"@HC.B!A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R96YT('!E
M<FUI<W-I;VXN(@IM<V=S='(@(DEZ:6X@:6YD=6L@=&ED86L@=F%L:60N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W,PHC+"!F=7IZ>0IM
M<V=I9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R("))>FEN(&EN9'5K
M('1I9&%K('9A;&ED+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-S4*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@<')O9'5C="!C;V1E+B(*
M;7-G<W1R(")!<&QI:V%S:2!T:61A:R!V86QI9"XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*(RP@9G5Z>GD*
M;7-G:60@(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(D%P;&EK87-I('1I
M9&%K('9A;&ED+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z.3,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HW,2!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C@P"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@<F5C:7!I96YT.B!<
M(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HQ,#<V(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(V,@IM<V=I9"`B
M26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"B,L(&9U>GIY
M"FUS9VED("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R("))>FEN
M(&EN9'5K('1I9&%K('9A;&ED+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0HC+"!F=7IZ>0IM<V=I9"`B26YV
M86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@(D%P;&EK87-I('1I9&%K('9A
M;&ED+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3<*;7-G:60@
M(DEN=F5N=&]R>2(*;7-G<W1R("));G9E;G1O<FES(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.0HC+"!F=7IZ>0IM<V=I
M9"`B26YV97)T('-E;&5C=&EO;B(*;7-G<W1R(")(87!U<R!P:6QI:&%N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@R"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@
M;V8@36%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(T"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G
M<W1R(")(=6IA;B!P971I<B!D:7-E<G1A:2!A;F=I;B!R:6)U="!D:2!D865R
M86@@>6%N9R!T97)P96YC:6PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DES<F%E
M;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8R-0IM<V=I9"`B27-S=65R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC
M(@IM<V=S='(@(DAU<G5F($UI<FEN9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@HC+"!F=7IZ
M>0IM<V=I9"`B271A;'DB"FUS9W-T<B`B2'5R=68@36ER:6YG(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@R"FUS9VED(")*86UA:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#$*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S.0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y
M(@IM<V=S='(@(DIA;G5A<FDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIA<&%N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED
M(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@(DIE<&%N9R`H25-/
M+3(P,C(M2E`I(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*
M;7-G:60@(B(*(DIA=F%S8W)I<'0@:&%S(&)E96X@9&ES86)L960@;VX@>6]U
M<B!B<F]W<V5R(&%N9"!T:&ES('!A9V4@;6%Y(&YO="!B92`B"B)D:7-P;&%Y
M:6YG(&-O<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*
M;7-G<W1R(")*=6QI(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B2G5N:2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*
M;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`B4F%T82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$U"FUS9VED(")*
M=7-T:69Y($-E;G1E<B(*;7-G<W1R(")2871A(%1E;F=A:"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$W"FUS
M9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B4F%T82!+:7)I(&1A;B!+86YA
M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$T"FUS9VED(")*=7-T:69Y($QE9G0B"FUS9W-T<B`B4F%T82!+
M:7)I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`B4F%T
M82!+86YA;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C8T"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#,*;7-G:60@(DME;GEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E
M<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED(")+97)N96P@3F5W8FEE<R(*
M;7-G<W1R(")+97)N96P@3F5W8FEE<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0Q,0HC+"!F=7IZ>0IM<V=I9"`B2V5Y($-R96%T:6]N
M(@IM<V=S='(@(DIU9'5L(%1A8F5L(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS
M9VED(")+97D@3&5N9W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@*;7-G
M:60@(DME>2!5<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HW-#`*;7-G:60@(DME>2!A;')E861Y(&5X:7-T<R!O
M;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S='(@(D%N86LM
M86YA:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@1&5M;V-R871I8R!096]P
M;&4G<R!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G
M:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S
M='(@(DMO<F5A("A%54,M2U(I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+=7=A
M:70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+>7)G>7IS=&%N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z.`IM
M<V=I9"`B3&%?>6]U="(*;7-G<W1R(")486UP:6QA;B(*"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@
M(D)A:&%S82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E
M;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(D9A<V4@=&5R
M86MH:7(@9&%R:2!397!A<G5H($)U;&%N(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C<V"FUS9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R
M(")097)U8F%H86X@4V%N9&D@5&5R86MH:7(B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED("),87-T(%%U
M87)T97(B"FUS9W-T<B`B1F%S92!T97)A:VAI<B!D87)I(%-E<&%R=6@@0G5L
M86XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U,0IM<V=I9"`B3&%S="!5
M<&1A=&5D.B(*;7-G<W1R(")097)U8F%H86X@5&5R86MI<CHB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z-S(Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("),87-T
M(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(B5S('5N='5K("5S("5S(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$V"FUS9VED("),87-T(&QO
M9VEN.B!.979E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQA
M='9I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*
M;7-G:60@(DQA=R(*;7-G<W1R(")(=6MU;2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0IM<V=I9"`B3&%Y;W5T
M(@IM<V=S='(@(E1A;7!I;&%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO
M(&)O<F1E<B(*;7-G<W1R(")4:6YG9V%L:V%N(&MO<V]N9R!T86YP82!B;W)D
M97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQE8F%N;VXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C8Y"FUS9VED("),969T(@IM<V=S='(@(DMI<FDB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3$Y"FUS9VED("),969T(&AE861E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$U"B,L(&9U>GIY
M"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R(")$869T87(@5&%B96PB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#@*;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED("),
M979E;"(*;7-G<W1R(")#:6YT82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`HC+"!F=7IZ>0IM
M<V=I9"`B3&EB97)I82(*;7-G<W1R(")086YT=6X@2F5N86MA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@Y"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M-0IM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R(")'97)I;6ES(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*;7-G:60@
M(DQI9VAT(%)A:6XB"FUS9W-T<B`B1V5R:6UI<R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!286EN
M($5A<FQY(@IM<V=S='(@(D=E<FEM:7,@9&D@<&%G:2!H87)I(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*;7-G:60@(DQI
M9VAT(%)A:6X@3&%T92(*;7-G<W1R(")'97)I;6ES(&)E8F5R87!A('-A870@
M;&%G:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R(")'97)I;6ES
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*
M;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@(D=E<FEM
M:7,@9&ES97)T86D@<&5T:7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R(")"
M97)S86QJ=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,R"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R(")'97)I
M;6ES(%-A;&IU(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0U"FUS9VED
M("),:6UE<FEC:R(*;7-G<W1R(")086YT=6X@2F5N86MA(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q-`HC+"!F=7IZ>0IM<V=I9"`B3&EN:R(*
M;7-G<W1R("),;V=I;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B3&EN:R!P;VEN=',@=&\Z
M(@IM<V=S='(@(DQI;FL@;65N=6YJ=6L@:V4Z(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3@W-0IM<V=I9"`B3&EN:R!T:&4@96UA:6P@861D<F5S
M<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAT;6PR=&5X
M="YP:'`Z,3@S"B,L(&9U>GIY"FUS9VED("),:6YK<R(*;7-G<W1R(")4=6=A
M<R!,;V=I;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B
M3&EN=7@@0V]O:VEE(@IM<V=S='(@(DQI;G5X($-O;VMI92(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T
M("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C$S,PIM<V=I9"`B3&ES="!$871A8F%S97,B"FUS
M9W-T<B`B1&%F=&%R($1A=&%B87-E(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E
M>"YP:'`Z-3`*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B1&%F
M=&%R(%1O<&EK($)A;G1U86XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,R
M"FUS9VED("),:7-T(%1A8FQE<R(*;7-G<W1R(")$869T87(@5&%B96PB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-`IM<V=I9"`B
M3&ES="U!<F-H:79E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O2&5A9&5R<RYP:'`Z-3@Y"B,L(&9U>GIY"FUS9VED("),:7-T+4AE;'`B
M"FUS9W-T<B`B1&%F=&%R(%1O<&EK($)A;G1U86XB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TAE861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U)9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y
M,@IM<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TAE861E<G,N<&AP.C4Y,PIM<V=I9"`B3&ES="U0;W-T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z
M-3DQ"B,L(&9U>GIY"FUS9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R(")!
M;F=K82]H=7)U9B]S:6UB;VP@>6%N9R!D:71U;&ES(&1I8F%W86@@9V%R:7,@
M8F%R:7,@=&5K<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP
M:'`Z-3DP"FUS9VED("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(D1A
M9G1A<B!P96YG9W5N82!D:6YO;BUA:W1I9FMA;BXB"@HC.B!A9&UI;B]S97-S
M:6]N<RYP:'`Z,S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DQI<W1I
M;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R(")$869T87(@<&5N9V=U;F$@
M9&EN;VXM86MT:69K86XN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L
M:7-T+FEN8SHR"FUS9VED("),:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*
M;7-G<W1R(")$869T87(@<&5N9V=U;F$@9&EN;VXM86MT:69K86XN(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),:71E<F%T=7)E(@IM
M<V=S='(@(D1A9G1A<B!"86-A86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*(RP@9G5Z>GD*
M;7-G:60@(DQI=&AU86YI82(*;7-G<W1R("),96)A<B!U;FET(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6UA9V5S+G!H<#HX,PIM<V=I9"`B
M3&]A9&EN9RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C$Q"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B5V%K
M='4@;&]C86PZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@S"FUS9VED
M("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B5&5M<&%T(%!E<FES=&EW82!D
M86X@5V%K='4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4W,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C0*(SH@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C:R]M971A<BYP:'`Z-C4*;7-G
M:60@(DQO8V%T:6]N(@IM<V=S='(@(DQO:V%S:2(*"B,Z(&QO9VEN+G!H<#HQ
M-S(@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y,2!T96UP;&%T97,O
M;&]G:6XO;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N
M:6YC.C$U('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*;7-G:60@(DQO
M9R!I;B(*;7-G<W1R("),;V=I;B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO
M;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,3@U"FUS9VED("),;V<@;W5T(@IM<V=S='(@(DQO9R!O=70B"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-3D*;7-G:60@(DQO9VEN(@IM<V=S='(@(DQO
M9VEN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-PIM<V=I9"`B3&]G
M:6X@5&%S:W,B"FUS9W-T<B`B5'5G87,@3&]G:6XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HY.38*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E
M('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R
M96-T;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP
M.CDY,@HC+"!F=7IZ>0IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R(")4
M:61A:R!D:6%R<VEP:V%N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3,V-0HC+"!F=7IZ>0IM<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@(DQO9R!O
M=70B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@(DQO=F4B
M"FUS9W-T<B`B0VEN=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV-PIM<V=I9"`B3&]W(@IM<V=S='(@(E)E;F1A:"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T<B`B4VEM
M8F]L($AU<G5F(&ME8VEL('EU;F%N:2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R
M(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B4VEM8F]L($AU<G5F(&ME8VEL(&QA
M=&EN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G
M<W1R(")3:6UB;VP@2'5R=68@:V5C:6P@<F]M87=I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y
M"FUS9VED("),=7AE;6)O=7)G(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,#`*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S."!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B34TB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C@Q"FUS9VED(")-3U1$(@IM<V=S='(@(DU/5$0B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM
M<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"B,L(&9U>GIY"FUS9VED(")-
M4T<B"FUS9W-T<B`B0TU3(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"B,L(&9U>GIY"FUS9VED
M(")-86-A;R(*;7-G<W1R("),:6)U<F%N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED
M(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-861A9V%S8V%R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.0IM<V=I9"`B
M36%G:6,B"FUS9W-T<B`B4W5L87`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z.#$*;7-G:60@(DUA:6PB"FUS9W-T<B`B4W5R870B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3(R"FUS9VED(")-86EL($%D;6EN(@IM
M<V=S='(@(E-U<F%T($%D;6EN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K
M+BXN(@IM<V=S='(@(D)U870@;&EN:RXN+B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F
M=7IZ>0IM<V=I9"`B36%L87=I(@IM<V=S='(@(E-U<F%T(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDU"FUS9VED(")-86QA>7-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*
M;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@HC+"!F
M=7IZ>0IM<V=I9"`B36%L:2(*;7-G<W1R(")3=7)A="(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,38R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-`HC+"!F=7IZ>0IM<V=I9"`B36%L=&$B"FUS9W-T<B`B4W5R870B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$*;7-G:60@(B(*(DUA;F%G92!T:&4@
M;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I
M=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G
M;W)I97,N(@IM<V=S='(@(B(*(DUE;F=A='5R(&1A9G1A<B!K871E9V]R:2!Y
M86YG(&AA<G5S(&1I8F5R:2!L86)E;"!I=&5M+"!D86X@=V%R;F$@>6%N9R`B
M"B)B97)H=6)U;F=A;B`@9&5N9V%N(&MA=&5G;W)I('1E<G-E8G5T+B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,34S"FUS
M9VED(")-87`R-"!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#0*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-C@*;7-G:60@(DUA<%%U97-T(&UA
M<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ
M,#4*;7-G:60@(DUA<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,PHC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA
M<F-H(@IM<V=S='(@(DUA<F5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0IM<V=I9"`B36%R9VEN(@IM<V=S
M='(@(DUA<F=I;B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C@X"FUS9VED(")-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!)
M;7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM
M<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3,*(RP@9G5Z>GD*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B36%R9VEN
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA
M=&-H:6YG(&9I96QD<R(*;7-G<W1R(")-96YC;V-O:VMA;B!K;VQO;2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY,PHC+"!F=7IZ>0IM<V=I9"`B36%U<FET86YI82(*;7-G<W1R
M(")-87)G:6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA=7)I=&EU<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`X"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@
M(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(@4W5H=2!M86MS
M:6UU;2!Y86YG(&)E<FQA;F=S=6YG('-E;&%M82`R-"!J86TZ(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR.3@*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H
M;W5R<SH@(@IM<V=S='(@(E-U:'4@;6%K<VEM=6T@>6%N9R!B97)L86YG<W5N
M9R!S96QA;6$@-B!J86TZ(@H*(SH@;&EB+V%P:2YP:'`Z.#8*;7-G:60@(DUA
M>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS9W-T<B`B2G5M;&%H
M(&UA:W-I;75M(&1A<FD@<&]R=&%L('EA;F<@9&EB;&]K:7(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(Q-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y"FUS9VED
M(")-87AI;75M(&QE;F=T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@
M(DUE:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(DUA>6]T=&4B
M"FUS9W-T<B`B5&%M<&EL86XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-3`*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(D]B870M;V)A=&%N(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@IM<V=I9"`B365M
M8F5R<R(*;7-G<W1R(")!;F=G;W1A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,W.`IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R(")-96YU(&UO9&4Z
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T<B`B1V%B=6YG:V%N
M('-E;"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")-97-S86=E(@IM<V=S='(@
M(E!E<V%N(%--4R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,C$V"FUS9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL
M>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92`B
M"B)V97)I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"FUS9VED(")-97-S86=E(&5X
M<&ER960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-PHC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*;7-G:60@(DUE<W-A
M9V4@='EP92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*
M;7-G:60@(DUE=&%R(%=E871H97(B"FUS9W-T<B`B($-U86-A($UE=&%R(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO8VL@
M;F]T(&%V86EL86)L92XB"FUS9W-T<B`B07)E82!-971A<B!T:61A:R!D:7-E
M9&EA:V%N+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$R"FUS9VED("(B
M"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E
M;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")!<F5A
M($UE=&%R('1I9&%K(&1I<V5D:6%K86XN($1E=&EL('1E;&%H(&1I8V%T870@
M=6YT=6L@861M:6YI<W1R871O<BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,38U"B,L(&9U>GIY"FUS9VED(")-971A<D1"(&ES(&YO="!C
M;VYN96-T960N(@IM<V=S='(@(E-A;F1I(&QA;6$@=&ED86L@8F5N87(N(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-R!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<T"FUS9VED(")-971H
M;V0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H
M<#HX,2!F<F%M97=O<FLO4E!#+U)00R]S;V%P+G!H<#HQ,3<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]R97-T+G!H<#HX,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M
M971H;V0Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HW-"!L:6(O0FQO8VLO;65T87(N<&AP.C<U"FUS9VED(")-971R
M:6,B"FUS9W-T<B`B365T<FEK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"B,L(&9U>GIY"FUS
M9VED(")-97AI8V\B"FUS9W-T<B`B365T<FEK(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G
M:60@(DUI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<V"FUS9VED(")-:61D;&4B"FUS9W-T<B`B5&5N9V%H(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI
M;64@5'EP92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q
M,`IM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(E-U
M:'4@;6EN:6UU;2!Y86YG(&)E<FQA;F=S=6YG('-E;&%M82`R-"!J86TZ(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#(*;7-G:60@(DUI;B!T96UP(&QA
M<W0@-B!H;W5R<SH@(@IM<V=S='(@(E-U:'4@;6EN:6UU;2!Y86YG(&)E<FQA
M;F=S=6YG('-E;&%M82`V(&IA;3HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S
M(&YO="!Y970@97AP:7)E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,T"B,L(&9U>GIY"FUS9VED(")-
M:7)R;W(B"FUS9W-T<B`B2V5S86QA:&%N(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(DQA:6XM
M;&%I;B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C<R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,T,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]2
M97%U97-T+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3$U"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E
M('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B
M"B)A<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@HB2V]N9FEG=7)A<VD@=&ED86L@
M9&ET96UU:V%N+B!!;F1A(&AA<G5S(&UE;F=H87-I:V%N(&MO;F9I9W5R87-I
M('-E:V%R86YG("(*(FII:V$@86YD82!I;F=I;B!M96YG9W5N86MA;B!A<&QI
M:V%S:2!I;FDN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`T"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@240N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET
M86QY7W-M='`N<&AP.C4X"FUS9VED(")-:7-S:6YG(')E<75I<F5D(%!%05(@
M<&%C:V%G92!-86EL+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@
M<V5S<VEO;B!)1"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`B4V5N
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C<T"FUS9VED(")-;V)I
M;&4@36%I;"(*;7-G<W1R(")-;V)I;&4@36%I;"(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")-;V1E<F%T92(*
M;7-G<W1R(")3961A;F<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C8V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-S,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX
M.`HC+"!F=7IZ>0IM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R(")3961A
M;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B56)A:"!5
M4DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W,PIM
M<V=I9"`B36]D=6QU<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@
M(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,`IM<V=I9"`B36]N86-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I
M9"`B36]N9V]L:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C4Y-`IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-PIM
M<V=I9"`B36]N=&AL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z
M>GD*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B4V5D86YG(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED
M(")-;V]N(%!H87-E<R(*;7-G<W1R(")&87-E($)U;&%N(@H*(SH@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3<R(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C(U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD<R!F
M;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G
M:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R(")396)A9VEA;B!B97-A<B!#97)A
M:"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T
M"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@(E-E8F%G:6%N(&)E<V%R
M($)E<F%W86XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS-0IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@(E-E8F%G:6%N
M(&)E<V%R($-E<F%H(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z-3`Y"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$S"B,L(&9U>GIY"FUS
M9VED(")-;W9E($QE9G0B"FUS9W-T<B`B2VER:2(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C4Q-PHC+"!F=7IZ>0IM<V=I9"`B36]V
M92!2:6=H="(*;7-G<W1R(")+86YA;B(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C4P-0IM<V=I9"`B36]V92!5<"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T
M"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R,PHC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E('5P(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36]Z86UB:7%U92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@T"FUS9VED
M(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-34*;7-G
M:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,C0R"B,L(&9U>GIY"FUS9VED(")-=6QT:7!L92!S
M96QE8W1I;VXB"FUS9W-T<B`B2&%P=7,@<&EL:6AA;B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT,#`*;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T
M<B`B06-C;W5N="UK=2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.`IM
M<V=I9"`B37D@06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA
M<VD@06-C;W5N="UK=2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z
M-30*;7-G:60@(DUY(%!O<G1A;"(*;7-G<W1R(")0;W)T86QK=2(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HQ,S8*;7-G:60@(DUY(%!O<G1A;"!,
M87EO=70B"FUS9W-T<B`B5&%M<&EL86X@4&]R=&%L:W4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3(*;7-G:60@(DUY86YM87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA
M:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3<*;7-G:60@(DY/+"!)($1O
M($Y/5"!!9W)E92(*;7-G<W1R(")4241!2RP@4V%Y82!4241!2R!3971U:G4B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P,@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`HC+"!F=7IZ>0IM<V=I
M9"`B3F%M92(*;7-G<W1R(")N86UA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").
M86UI8FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H97)L86YD<R!!;G1I;&QE<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4X,0IM<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE
M='-C87!E($-!(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P
M92!#02!P;VQI8WD@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P92!296YE=V%L
M(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.#8*;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I
M9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,`IM<V=I9"`B
M3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4Q"FUS9VED(").971W;W)K(@IM<V=S
M='(@(DYE='=O<FLB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-0HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S@V"FUS9VED(").979E<B(*;7-G<W1R(")4:61A:R!P
M97)N86@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.34*(RP@9G5Z>GD*;7-G:60@(DYE=R!#86QE
M9&]N:6$B"FUS9W-T<B`B2V%T96=O<FD@0F%R=2(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED(").97<@
M0V%T96=O<GDB"FUS9W-T<B`B2V%T96=O<FD@0F%R=2(*"B,Z(&9R86UE=V]R
M:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HX,0HC.B!F<F%M97=O
M<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.#<*(SH@9G)A;65W
M;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.CDW"B,Z(&9R86UE
M=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HQ,#$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3F5W($UE<W-A9V4@=&\@)7,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV
M."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED(").97<@36]O;B(*;7-G
M<W1R(")"=6QA;B!"87)U(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB"FUS
M9W-T<B`B3F%M82!096YG9W5N82!"87)U("AP:6QI:&%N*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY.`IM<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,W"FUS9VED(").97<@<&%S<W=O<F0B
M"FUS9W-T<B`B4V%N9&D@0F%R=2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D
M('=I;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z-3(*;7-G:60@(DYE=R!P87-S=V]R9',@9&]N
M)W0@;6%T8V@N(@IM<V=S='(@(E-A;F1I(&)A<G4@=&ED86L@8V]C;VLN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM
M<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R(")7:6YD;W<@0F%R
M=2`H7V)L86YK*2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C@Y"FUS9VED(").97=S(@IM<V=S='(@(D)E<FET82(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS,#4*;7-G:60@(DYE=W-G<F]U<',B"FUS
M9W-T<B`B1W)U<"!"97)I=&$B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O
M+FEN8SHQ-2!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT,0HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T82]C<W9I
M;F9O+FEN8SHR-0IM<V=I9"`B3F5X="(*;7-G<W1R(")"97)I:W5T;GEA(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"B,L(&9U>GIY"FUS9VED(").97AT
M(#0@4&AA<V5S(@IM<V=S='(@(D9A<V4@0F5R:6MU=&YY82(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<R(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,S<V"B,L(&9U>GIY"FUS9VED(").97AT(&]P=&EO;G,B
M"FUS9W-T<B`B2V5M8F%L:2!K92!0:6QI:&%N(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U!A9V5R+G!H<#HQ,#,*(RP@9G5Z>GD*;7-G:60@(DYE>'0^(@IM<V=S
M='(@(D)E<FEK=71N>6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI8V%R86=U
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(DYI
M9V5R(@IM<V=S='(@(DUA;&%M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E
M<FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS.#`*;7-G:60@(DYI9VAT(@IM<V=S='(@(DUA;&%M(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDW"FUS9VED(").:75E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HY-C,*(RP@9G5Z>GD*;7-G:60@(DYO
M(@IM<V=S='(@(E1I9&%K(&%D82(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U
M<"]D:69F+FAT;6PZ.0IM<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I
M;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`B(@HB
M5&ED86L@861A(&1A=&$@:V]N9FEG=7)A<VD@>6%N9R!T97)S961I82!U;G1U
M:R!M96YU;FIU:VMA;B!P97)B961A86X@=6YT=6LN(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HQ,#4*;7-G:60@(DYO(&%V
M86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<Y(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C(T-0HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-C<*;7-G:60@(DYO(&)L;V-K
M(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-3`*;7-G:60@(DYO
M(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4T"FUS
M9VED(").;R!C:&%N9V4N(@IM<V=S='(@(E1I9&%K(&%D82!P97)U8F%H86XN
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*(RP@9G5Z
M>GD*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E
M<FUI<W-I;VXN(@IM<V=S='(@(EPB)7-<(B!S=61A:"!D:71A;6)A:&MA;B!K
M92!D86QA;2!I>FEN('-I<W1E;2XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C$V-R!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P,@HC.B!F
M<F%M97=O<FLO571I;"]5=&EL+G!H<#HW-S,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C@R-`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R($944"!61E,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z-C8Y"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<Q-PIM<V=I9"`B
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-1
M3"U&:6QE(%9&4RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D:70@
M;&5F="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,S0*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U
M<'!L:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W
M<V5R+G!H<#HX-S<*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B
M(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q"FUS9VED(").;R!I8V]N
M<R!F;W5N9"XB"FUS9W-T<B`B5&ED86L@861A(&EK;VX@>6%N9R!D:71E;75K
M86XN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$R."!L:6(O
M0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M,C,*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B5&ED86L@
M861A(&QO:V%S:2!Y86YG(&1I871U<BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,38Y"B,L(&9U>GIY"FUS9VED(").;R!L;V-A=&EO;B!P
M<F]V:61E9"XB"FUS9W-T<B`B5&ED86L@861A(&QO:V%S:2!Y86YG(&1I871U
M<BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S,PIM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,S8*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M-PIM<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS9VED(").;R!O9F9E;G-I=F4@
M9F]R='5N97,B"FUS9W-T<B`B5&ED86L@861A(')A;6%L86X@>6%N9R!T:61A
M:R!S;W!A;B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z.3$*
M;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM
M87`N<&AP.C$P.`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-
M05`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O:W)B-2YP:'`Z-S(*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HW-R!F<F%M97=O<FLO
M075T:"]!=71H+VQO9VEN+G!H<#HX-`HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W!A;2YP:'`Z-S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,
M;V=I;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]P87-S=V0N<&AP.C$S-0IM<V=I9"`B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C@T"FUS9VED(").
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C$R.#8*;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y
M('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O
M("(*(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E
M;F1I;F<@<VEG;G5P<RXB"FUS9W-T<B`B5&ED86L@861A('!E;F1A9G1A<F%N
M('EA;F<@9&ET=6YD82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-S4P
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(").;R!Q=6]T82!S970N(@IM
M<V=S='(@(D)E;'5M(&1I871U<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*;7-G:60@(DYO(')U;&5S(@IM
M<V=S='(@(E1I9&%K(&%D82!A='5R86XB"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HT-#D*;7-G:60@(DYO('-E<&%R871O<B!S<&5C:69I960N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#0*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(E1I
M9&%K(&%D82!S:7-I(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU
M.#,*(RP@9G5Z>GD*;7-G:60@(DYO('-U8V@@9FEL92(*;7-G<W1R(")4:61A
M:R!A9&$@<VES:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M,S@*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O
M<B!C86-H92XB"FUS9W-T<B`B5&ED86L@861A(&1I<F5K=&]R:2!S96UE;G1A
M<F$@>6%N9R!T97)S961I82!U;G1U:R!C86-H92(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"B,L(&9U>GIY"FUS9VED
M(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`B
M4VEL86MA;B!M87-U:VMA;B!N86UA('!E;F=G=6YA(&1A;B!S86YD:2!A;F1A
M(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@
M(DYO('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-S$*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX,0HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3DR"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#`Y"B,L(&9U>GIY
M"FUS9VED(").;R!V86QU97,B"FUS9W-T<B`B5&ED86L@861A(&%T=7)A;B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C`*;7-G:60@(DYO('9E<G-I
M;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T
M92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B)4:61A:R!A9&$@=F5R<VD@
M>6%N9R!D:71E;75K86X@9&D@9&%L86T@:V]N9FEG=7)A<VD@>6%N9R!A<VQI
M+B!-96YG:&%S:6QK86X@(@HB:V]N9FEG=7)A<VD@:V5M8F%L:2XB"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(X"FUS9VED(").;R!V97)S:6]N(&9O
M=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R("(B"B)4:61A:R!A9&$@=F5R<VD@>6%N9R!D:71E
M;75K86X@9&D@9&%L86T@:V]N9FEG=7)A<VD@86YD82X@365N9VAA<VEL:V%N
M("(*(FMO;F9I9W5R87-I(&ME;6)A;&DN(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED
M96YT:71Y<V5L96-T+FEN8SHY,PIM<V=I9"`B3F]N92(*;7-G<W1R(")4:61A
M:R!A9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDP"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(E1I
M9&%K(&%D82`H9&EG=6YA:V%N('-E;&5N9VMA<&YY82DB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB
M"FUS9W-T<B`B4V-A;F1I;F%V:6$@*$E33RTX.#4Y+3$P*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I
M9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(")"96QA:&%N($)U;6D@
M571A<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N($UA<FEA;F$@
M27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYO<G=A
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8T,`HC+"!F=7IZ>0IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(D)E
M;'5M(&1I871U<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C,Y"FUS9VED(").;W0@0F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C0P.`HC+"!F=7IZ>0IM<V=I9"`B3F]T
M(&$@9&ER96-T;W)Y(@IM<V=S='(@(D1I<F5K=&]R:2!(;VUE(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HV,PHC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T
M96=Y+G!H<#HX,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-`HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2YP:'`Z-3D*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHV.`IM<V=I9"`B3F]T('-E="(*;7-G<W1R(")"96QU;2!D:6%T=7(B
M"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N
M<&AP.C$T,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA
M;F1L97(N<&AP.C$U.`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S
M<VEO;DAA;F1L97(N<&AP.C$W,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L
M97(O4V5S<VEO;DAA;F1L97(N<&AP.C$X-PHC.B!F<F%M97=O<FLO4V5S<VEO
M;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C(S-"!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,#4@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,C0X(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-C4*(SH@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,CDW"B,Z
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,3(@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C,R.0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S8R(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HT,C(*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4P
M,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3<P"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HU.#<@9G)A;65W;W)K+U9&4R]61E,N<&AP.C8V-0IM<V=I9"`B
M3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(T-"!C;VYF:6<O:&]O:W,N<&AP+F1I
M<W0Z,3`P-0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3<X"FUS9VED
M(").;W1E<R(*;7-G<W1R(")#871A=&%N(@H*(SH@<V5R=FEC97,O;V)R;W=S
M97(O:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S92P@9V\@
M8F%C:RXB"FUS9W-T<B`B5&ED86L@861A('EA;F<@9&%P870@9&EB<F]W<V4L
M('-I;&%K86X@:V5M8F%L:2XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#$Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B3F]V
M96UB97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#0V"B,L(&9U
M>GIY"FUS9VED(").=6UB97(B"FUS9W-T<B`B3F]V96UB97(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(U"B,L(&9U>GIY"FUS9VED(").=6UB
M97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R(")*=6UL86@@8F%R:7,B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8Y(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T,C,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T-2!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I
M9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`B2G5M;&%H(&MO;&]M(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-R!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-#(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T
M-#,@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*
M;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(DIU;6QA:"!B87)I<R(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C0T"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG
M(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM
M<V=S='(@(D]+(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C@W,PHC+"!F=7IZ>0IM<V=I9"`B3V)J96-T(@IM<V=S='(@(E!E
M;F-I<'1A($]B:F5K(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,3$*;7-G:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(E!E;F-I<'1A($]B
M:F5K(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$P-`HC+"!F=7IZ
M>0IM<V=I9"`B3V-T86PB"FUS9W-T<B`B5&5N86YG(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,`HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B
M"FUS9W-T<B`B3VMT;V)E<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY
M,@IM<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B1FEL=&5R(%!E;&%N
M9V=A<F%N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R-@IM<V=I
M9"`B3V9F:6-E(@IM<V=S='(@(DMA;G1O<B(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S
M(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R(")386YD:2!L86UA(&1A;B!B
M87)U(&AA<G5S(&)E<F)E9&$N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C,V"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`B4V%N9&D@
M;&%M82(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT-@IM<V=I
M9"`B3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R(")386YD
M:2!L86UA('1I9&%K(&)E;F%R+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HW,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S
M:&%R960@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.CDU"FUS9VED(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G
M<W1R(")(86YY82!R86UA;&%N('EA;F<@=&ED86L@<V]P86XB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4Q(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Y-S$*(RP@9G5Z>GD*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E
M<W,@86QL;W=E9"XB"FUS9W-T<B`B4&5N9V=A;G1I(&%L86UA="!E;6%I;"(*
M"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL
M>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG
M92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA
M<F4B"FUS9W-T<B`B(@HB2&%N>6$@<&5M:6QI:R!A=&%U('-I<W1E;2!A9&UI
M;FES=')A=&]R('-A:F$@>6%N9R!D87!A="!M96YG=6)A:"!K97!E;6EL:6MA
M;B`B"B)A=&%U('!E;6EL:6L@:7II;B!U;G1U:R!B86=I86XB"@HC.B!L:6(O
M0FQO8VLO:69R86UE+G!H<#HS-0IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD
M;W<B"FUS9W-T<B`B0G5K82!D:2!J96YD96QA('EA;F<@8F%R=2(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N
M4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D
M(%,O34E-12!P87)T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS
M('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B0G5K82!L:6YK
M(&EN:2!D:2!J96YD96QA('EA;F<@8F%R=2(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R(")3
M:7-T96T@3W!E<F%S:2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ-3$*;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`B4&EL:6AA;B(*"B,Z('-E
M<G9I8V5S+W!R969S+G!H<#HS,2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R
M(")0:6QI:&%N('5N='5K("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S
M='(@(D1A9G1A<B!.;VUO<B!"97)U<G5T(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-C<*(RP@9G5Z>GD*;7-G:60@(D]R9V%N:7-A
M=&EO;B(*;7-G<W1R(")4<F%N<VQA<VDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N86P@56YI
M="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,R
M"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(DUE;F=A='5R(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T
M:6]N('1E;7!L871E(@IM<V=S='(@(D%P;&EK87-I('1E;7!L871E(&%S;&DB
M"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(E1E;7!L
M871E(&%S;&D@9&D@9&%L86T@)7,Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@
M(D]T:&5R(@IM<V=S='(@(DQA:6XM;&%I;B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R
M,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,Q(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-#$*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@
M(DEN9F]R;6%S:2!,86EN(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHS,0IM<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B27II;B!0
M96UI;&EK(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<Y"B,L
M(&9U>GIY"FUS9VED(")004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL
M86)L92XB"FUS9W-T<B`B07)E82!K92!W96%T:&5R+F-O;2!T:61A:R!D:7-E
M9&EA:V%N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M
M='`N<&AP.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$R-S,*;7-G
M:60@(E!'4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S$Y"FUS9VED(")01U`@16YC
M<GEP=&5D($1A=&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3,W,0IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,U,PIM
M<V=I9"`B4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T82(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-C@*;7-G:60@(E!(4"!#;V1E(@IM<V=S
M='(@(DMO9&4@4$A0(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED
M(")02%`@4VAE;&PB"FUS9W-T<B`B4$A0(%-H96QL(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*;7-G:60@(E!-($QI9VAT
M(%)A:6XB"FUS9W-T<B`B4$T@1V5R:6UI<R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")032!3:&]W97)S(@IM
M<V=S='(@(E!-($=E<FEM:7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R(")032!"
M97)S86QJ=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0P"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B4$T@1V5R
M:6UI<R!386QJ=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0Q"FUS9VED(")032!3=6XB"FUS9W-T<B`B4$T@0V5R86@B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I
M9"`B4$T@5"U3=&]R;7,B"FUS9W-T<B`B4$T@2'5J86X@<&5T:7(@9&ES97)T
M86D@9&5N9V%N(&%N9VEN(')I8G5T(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C(W-`IM<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS
M9W-T<B`B16MS=&5N<VD@4$]325@@=&ED86L@9&ET96UU:V%N(@H*(SH@;&EB
M+V%P:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@(E!(4"!3
M:&5L;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B2F%R86L@<W!A
M<VD@9&%R:2!B;W)D97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$X-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*(RP@9G5Z>GD*;7-G:60@
M(E!A:VES=&%N(@IM<V=S='(@(E-A;&EN(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I
M9"`B4&%L874B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L
M97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@(E!A;F%M82(*;7-G<W1R(")N86UA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDY"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V
M"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S='(@(E-E8F%G:6%N($)E<F%W
M86XB"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3@P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3,W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#$X"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#(S"FUS9VED(")087-S=V]R9"(*;7-G<W1R(")386YD:2(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA
M;F=E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(E-A;F1I(&)E<FAA<VEL(&1I
M=6)A:"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$S
M,C(*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G<W1R
M(")386YD:2!L86UA('1I9&%K(&)E;F%R+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D
M(&9O<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-3,*(RP@9G5Z>GD*;7-G:60@(E!A
M<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(DME=&EK('-A;F1I
M(&1U82!K86QI('5N='5K(&UE;F=K;VYF:7)M87-I(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.CDP"FUS9VED(")087-S=V]R9#HB"FUS9W-T
M<B`B4V%N9&DZ(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*
M;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`B4V%N9&DZ(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,34P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S0*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S
M<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(E-A;F1I(&AA<G5S(&-O8V]K
M+B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,3D@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T
M92(*;7-G<W1R(")386QI;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D
M(@IM<V=S='(@(DQE:V%T:V%N(&1A<FD@8VQI<&)O87)D(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T
M:"(*;7-G<W1R(")0871H(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N
M:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`B4&5N9&%F
M=&%R86X@>6%N9R!D:71U;F1A.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU-`IM<V=I9"`B4&5O<&QE(@IM<V=S='(@(D]R86YG(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*;7-G:60@(E!E
M<F-E;G0B"FUS9W-T<B`B4&5R<V5N(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+VUA:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E
M;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R(")-96QA:W-A;F%K86X@3W!E<F%S
M:2!096UE;&EH87)A86XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#`V
M"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G
M:6X_(@IM<V=S='(@(DUE;&%K<V%N86MA;B!O<&5R87-I('!E;65L:6AA<F%A
M;B!P861A('=A:W1U(&QO9VEN/R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,34V"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N(@IM<V=S
M='(@(DEZ:6XB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R"B,L('!H
M<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D
M+B(*;7-G<W1R("))>FEN('5N='5K(%PB)7-<(B!T:61A:R!D87!A="!D:6AA
M<'5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@V"B,L(&9U
M>GIY"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("))>FEN(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C$@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C0*(RP@9G5Z>GD*;7-G:60@(E!E<FUI
M<W-I;VYS(@IM<V=S='(@(DEZ:6XB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H
M<#HQ,#D@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P"B,Z(&%D;6EN+W!E
M<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X"FUS
M9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R("))>FEN
M($%D;6EN:7-T<F%S:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-0IM
M<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M87-I
M(%!R:6)A9&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0971S(@IM
M<V=S='(@(D)I;F%T86YG($ME<V%Y86YG86XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G
M:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*(RP@9G5Z>GD*;7-G:60@(E!H
M;VYE(@IM<V=S='(@(E1I9&%K(&%D82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT-S@*;7-G:60@(E!H;W1O<R(*;7-G<W1R(")&;W1O(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@
M(E!I>&5L<R(*;7-G<W1R(")0:7AE;"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R(")+871A+6MA=&$@
M:VQI<V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E
M;&PB"FUS9W-T<B`B4VEL86MA;B!K;&EK(&ME(&1A;&%M(&)E8F5R87!A('-E
M;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N
M="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R(")3:6QA:V%N(&MO
M;F9I<FUA<VD@8F%H=V$@86YD82!I;F=I;B!M96UI;F1A:&MA;B!E;&5M96X@
M:6YI.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@
M=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R(")3:6QA:V%N
M(&MO;F9I<FUA<VD@8F%H=V$@86YD82!I;F=I;B!M96YG:&%P=7,@;&EN:R!U
M;G1U:R!E;&5M96X@:6YI+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(U-S$*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N
M9"!A('EE87(N(@IM<V=S='(@(E-I;&%K86X@;6%S=6MK86X@;F%M82!U;G1U
M:R!K871E9V]R:2!Y86YG(&)A<G4Z(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G:60@(E!L96%S92!E;G1E<B!A
M(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@(E-I;&%K86X@
M;6%S=6MK86X@;F%M82!U;G1U:R!K871E9V]R:2!Y86YG(&)A<G4Z(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P,0IM<V=I9"`B4&QE87-E(&5N
M=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@
M=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M
M;VYT:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C0U,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I
M9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*
M;7-G<W1R(")3:6QA:V%N(&UA<W5K:V%N(')I;F=K87-A;B!U;G1U:R!M87-A
M;&%H+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE87-E('!R;W9I9&4@
M>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B4VEL86MA;B!M
M87-U:VMA;B!N86UA('!E;F=G=6YA(&1A;B!S86YD:2!A;F1A(@H*(SH@<V5R
M=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4X"FUS9VED("(B"B)0;&5A<V4@<F5A
M9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE
M('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B"B)3:6QA
M:V%N(&UE;6)A8V$@=&5K<R!B97)I:W5T(&EN:2X@06YD82!(05)54R!S971U
M:G4@9&5N9V%N('-Y87)A="US>6%R870@(@HB=6YT=6L@;65N9V=U;F%K86X@
M<VES=&5M+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA
M;F%G97(N<&AP.C<P"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@='EP92!T:&4@
M;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S='(@(E-I;&%K86X@;6%S=6MK86X@
M;F%M82!U;G1U:R!K871E9V]R:2!Y86YG(&)A<G4Z(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY
M"B,L(&9U>GIY"FUS9VED(")0;VQA;F0B"FUS9W-T<B`B0V]M;6%N9"(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-PIM<V=I9"`B4&]L:71I8W,B"FUS
M9W-T<B`B4&]L:71I:R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M.#<*;7-G:60@(E!O;&QS(@IM<V=S='(@(E!O;&QI;F<B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`Q"B,L(&9U>GIY"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R(")0;W)T86QK
M=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3(T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G
M92(*;7-G<W1R(")0;W-I<VD@=6YT=6L@9V%M8F%R(&EN:2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0
M;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(E!O<VES:2!U;G1U
M:R!T86)E;"!I;FDB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N
M9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C8V(&QI8B]";&]C:R]M971A<BYP:'`Z,C<Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@
M(@IM<V=S='(@(DAU:F%N('-A;&IU('5N='5K("5S(&IA;2!T97)A:VAI<CHB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDX"FUS9VED(")0
M<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(DME;75N9VMI;F%N
M(#QB<B\^2'5J86X@<V%L:G4B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M;&1A<"YP:'`Z.3@*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S
M:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(U"FUS9VED(")0
M<F5S<W5R92(*;7-G<W1R(")496MA;F%N(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR-3D*;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E;#H@(@IM<V=S
M='(@(E1E:V%N86X@<&%D82!P97)M=6MA86X@;&%U=#HB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,U"FUS9VED(")0<F5S<W5R93H@(@IM
M<V=S='(@(E1E:V%N86XZ(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(P-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R979I97<B"FUS
M9W-T<B`B3&EH870B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*;7-G:60@(E!R979I97<@=&AE(&EM
M86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("),:6AA="!G86UB87(@9&D@
M9&%L86T@:F5N9&5L82!Y86YG(&)A<G4B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C,V,B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C,V-@HC+"!F=7IZ>0IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R
M(")+96UB86QI(&ME(%!I;&EH86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*
M;7-G<W1R(")#971A:R!D;VMU;65N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0<FEV871E($ME>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38Y"B,L(&9U
M>GIY"FUS9VED(")0<F]B;&5M(@IM<V=S='(@(D]R86YG(@H*(SH@<V5R=FEC
M97,O<')O8FQE;2YP:'`Z,3(V"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N
M(@IM<V=S='(@(D1E<VMR:7!S:2!-87-A;&%H(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,V.0IM<V=I9"`B4')O:F5C=',B"FUS9W-T<B`B4')O
M:F5K(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q,2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,3@X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,R.#4*(RP@9G5Z>GD*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S='(@
M(D1A<FDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*
M;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@06QG
M;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C0T"FUS9VED(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED
M(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S
M<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0=65R
M=&\@4FEC;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"B,L(&9U>GIY"FUS
M9VED(")1871A<B(*;7-G<W1R(")+=6]T82(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HV,PIM<V=I9"`B475E<GDB"FUS9W-T<B`B475E<GDB"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-S`*;7-G:60@(E%U;W1A(@IM<V=S='(@(DMU
M;W1A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-`HC
M+"!F=7IZ>0IM<V=I9"`B4F%D:6\@<V5L96-T:6]N(@IM<V=S='(@(E-A;&EN
M(%!I;&EH86XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT,PIM<V=I9"`B4F%I;B(*;7-G<W1R(")(=6IA;B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")286EN
M($5A<FQY(@IM<V=S='(@(DAU:F%N(&1I('!A9VD@:&%R:2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")286EN
M($QA=&4B"FUS9W-T<B`B2'5J86X@8F5B97)A<&$@<V%A="!L86=I(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@
M(E)A:6X@4VAO=V5R(@IM<V=S='(@(D=E<FEM:7,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-PIM<V=I9"`B4F%I;B!A;F0@
M4VYO=R(*;7-G<W1R(")(=6IA;B!D86X@0F5R<V%L:G4B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!T
M;R!3;F]W(@IM<V=S='(@(DAU:F%N(&)E<F-A;7!U<B!D96YG86X@<V%L:G4B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O
M<G1U;F4B"FUS9W-T<B`B4F%M86QA;B!!8V%K(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HV."!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C<V"B,L(&9U>GIY"FUS9VED(")2871I;R(*;7-G
M<W1R(")(=6IA;B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(T
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3@P"FUS9VED(")296%D(@IM<V=S='(@(D)A8V$B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PIM<V=I9"`B4F5A9"!M
M97-S86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R
M96UO=F4N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T
M92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T
M<B`B66%K:6X@=6YT=6L@;65N9VAA<'5S("5S/R!/<&5R87-I(&EN:2!T:61A
M:R!D87!A="!D:6)A=&%L:V%N+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO
M=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN
M;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"B)986MI;B!U;G1U:R!M96UI;F1A
M:&MA;B!D871A('!E;F=G=6YA('5N='5K('!E;F=G=6YA("5S/R!/<&5R87-I
M(&EN:2!T:61A:R`B"B)D87!A="!D:6)A=&%L:V%N+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E
M<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(E5L86YG:2!A:W-I('1E<F%K
M:&ER(&%N9&$B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")2969R97-H
M($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B4F5F<F5S:"!%;&5M
M96X@365N=2!$:6YA;6ES.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-#$*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(E)E9G)E
M<V@@3&EH870@4&]R=&%L.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C@Y-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$S"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R,S4*(RP@9G5Z>GD*;7-G:60@(E)E9V5X(@IM
M<V=S='(@(D%T=7(@:V5M8F%L:2`B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,C0Y"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,L(&9U>GIY"FUS9VED(")296QO
M860B"FUS9W-T<B`B0F%C82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(V
M"FUS9VED(")296UA<FMS(@IM<V=S='(@(D1I=&%N9&%I(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$Q-`IM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS
M9W-T<B`B4F5M;W1E(%-E<G9E<B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHX-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M
M<&QE+F-O;2]H;W)D92DZ(@IM<V=S='(@(E)E;6]T92!54DP@*&AT='`Z+R]W
M=W<N97AA;7!L92YC;VTO:&]R9&4I(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]E9&ET+FEN8SHR,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E
M+FEN8SHR.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N
M:6YC.C$S"FUS9VED(")296UO=F4B"FUS9W-T<B`B4&EN9&%H:V%N(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"FUS9VED(")296UO=F4@
M0FQO8VLB"FUS9W-T<B`B4&EN9&%H:V%N($)L;VMI<B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU-3<*(RP@9G5Z>GD*;7-G
M:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B2&%P=7,@:V]L;VTB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0P"FUS9VED
M(")296UO=F4@9F]R;6%T=&EN9R(*;7-G<W1R(")0:6YD86AK86X@0V%R82!&
M;W)M870B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.`IM<V=I
M9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`B4&EN9&%H:V%N('!A<V%N9V%N(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E('-A
M=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN
M(@IM<V=S='(@(E!I;F1A:&MA;B!S8W)I<'0@>6%N9R!S=61A:"!D:7-I;7!A
M;B!D87)I(&1I<F5K=&]R:2!S97)V97(@<V5M96YT87)A+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@IM
M<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R(")0:6YD86AK86XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*
M;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS
M9W-T<B`B4&EN9&%H:V%N(&YO9&4@:6YI(&1A<FD@9&]K=6UE;B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*;7-G:60@(E)E;6]V
M92!U<V5R(@IM<V=S='(@(E!I;F1A:&MA;B!P96YG9W5N82(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")296UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B4&EN9&%H:V%N('!E;F=G
M=6YA.B`E<R(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X
M"FUS9VED(")297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE
M9"!E<G)O<F-O9&4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,34W"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L
M9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,3<T(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$R
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@
M;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")4
M:61A:R!D87!A="!M96YY:6UP86X@:V]N9FEG=7)A<VD@)7,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-S4@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HX,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C<R,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E
M<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(E1I9&%K(&1A<&%T(&UE;GEI;7!A;B!K;VYF:6=U<F%S:2`E<RXB"@HC
M.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW.#$*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E1I9&%K(&1A<&%T(&UE;GEI;7!A
M;B!K;VYF:6=U<F%S:2`E<RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E
M;F1E<F5R+G!H<#HS,S4*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,S.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS
M,C`@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<W"FUS9VED(")297-E="(*;7-G
M<W1R(")!='5R(&ME;6)A;&D@(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z-#8*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(D%T=7(@
M:V5M8F%L:2!386YD:2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C(W"FUS9VED(")297-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(D%T=7(@
M:V5M8F%L:2!386YD:2!!;F1A(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S
M,`HC+"!F=7IZ>0IM<V=I9"`B4F5S=&]R92!,87-T(%%U97)Y(@IM<V=S='(@
M(D9A<V4@=&5R86MH:7(@9&%R:2!397!A<G5H($)U;&%N(@H*(SH@861M:6XO
M<&AP<VAE;&PN<&AP.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S
M<6QS:&5L;"YP:'`Z-C8*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B2&%S:6PB
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E
M<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM
M<V=S='(@(DME;6)A;&D@:V4@4&EL:6AA;B(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HS.`IM<V=I9"`B4F5T>7!E(&YE=R!P87-S=V]R9"(*
M;7-G<W1R(")+971I:R!U;&%N9R!S86YD:2!B87)U(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,@HC+"!F=7IZ>0IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R(")*86QA;FMA;B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB"FUS9W-T
M<B`B2V5M8F%L:2!K92!+;VYF:6=U<F%S:2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,S(*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(*
M;7-G<W1R(")0:6QI:&%N($5D:71O<B!2:6-H(%1E>'0B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B5&5K
M82UT96MI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<P"FUS9VED(")2:6=H="(*;7-G<W1R(")+86YA;B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C$*;7-G:60@(E)I9VAT(&AE
M861E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,3$W"B,L(&9U>GIY"FUS9VED(")2:6=H="!V86QU97,B"FUS9W-T<B`B1&%F
M=&%R(%1A8F5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB
M"FUS9W-T<B`B4')O<&5R=&D@0F%R:7,N+BXB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T"B,L(&9U>GIY"FUS9VED(")2
M;VQE(@IM<V=S='(@(D%T=7)A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3DX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)O
M;6%N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(R-0IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(R
M"FUS9VED(")2;W1A=&4@3&5F="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(X"FUS9VED(")2;W1A=&4@
M4FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B
M"FUS9W-T<B`B4')O<&5R=&D@0F%R:7,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O
M<&5R=&EE<R(*;7-G<W1R(")0<F]P97)T:2!B87)I<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S
M.B(*;7-G<W1R(")"87)I<SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4S"FUS9VED(")2=6QE<R(*;7-G<W1R
M(")!='5R86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W
M965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(D%T=7)A;B!A:V%N
M(&1I=&%M<&EL:V%N(&1I86YT87)A('-E;75A(&)A<FES(&1A;B!K;VQO;2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN
M<R!O;FQY(@IM<V=S='(@(D%T=7)A;B!A:V%N(&1I=&%M<&EL:V%N(&AA;GEA
M(&1I86YT87)A(&MO;&]M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E
M87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`B071U<F%N(&%K86X@9&ET
M86UP:6QK86X@:&%N>6$@9&EA;G1A<F$@8F%R:7,B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3(P"FUS9VED(")2=6XB"FUS9W-T<B`B2F%L86YK86XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`S"FUS9VED(")2=7-S:6%N($9E9&5R871I;VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,PHC+"!F=7IZ>0IM<V=I9"`B4G=A;F1A(@IM
M<V=S='(@(D)A8V$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C(X-0IM<V=I9"`B4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,S(S"FUS9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX,0HC+"!F
M=7IZ>0IM<V=I9"`B4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA
M8FQE+B(*;7-G<W1R(")!<F5A(&ME('=E871H97(N8V]M('1I9&%K(&1I<V5D
M:6%K86XN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4P-`IM<V=I
M9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R(")097-A;B!335,B"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R(")3
M44P@4VAE;&PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@S"FUS
M9VED(")344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S$*;7-G:60@(E-3
M2"(*;7-G<W1R(")34T@B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#
M15-3(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]1
M3"!3:&5L;"(*;7-G<W1R(")37U%,(%-H96QL(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T
M<B`B4V)T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD
M($YE=FES(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PHC+"!F=7IZ>0IM<V=I
M9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B2'5J86X@8F5B97)A<&$@<V%A="!L
M86=I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-
M:7%U96QO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")386EN
M="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED
M(")386UE(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B1G)A;64@>6%N9R!S86UA
M("A?<V5L9BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"B,L(&9U>GIY"FUS9VED(")386UO
M82(*;7-G<W1R(")3<&%M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@HC+"!F=7IZ>0IM<V=I
M9"`B4V%N($UA<FEN;R(*;7-G<W1R(")-87)G:6XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W
M"FUS9VED(")386\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL
M:71E(%!R;W9I9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@
M(E-A=61I($%R86)I82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L
M+VQA>6]U="YI;F,Z.3@*;7-G:60@(E-A=F4B"FUS9W-T<B`B4VEM<&%N(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B4VEM
M<&%N("5S(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R(")3:6UP86X@)7,B
M"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P
M=&EO;G,B"FUS9W-T<B`B4VEM<&%N(%!I;&EH86XB"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,38W"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF
M:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E
M;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@(B(*(E-I;7!A;B!K;VYF
M:6=U<F%S:2!Y86YG(&1I:&%S:6QK86X@<V5B86=A:2!S8W)I<'0@4$A0(&ME
M(&1A;&%M(&1I<F5K=&]R:2`B"B)S97)V97(@<V5M96YT87)A(&%N9&$N(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B2V]N9FEG
M=7)A<VD@)7,@<W5D86@@9&ES:6UP86XN(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z.3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F5D
M('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(E-C
M<FEP="!S971U<"!U<&=R861E('-U9&%H(&1I<VEM<&%N(&ME.B`G)7,G+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"FUS
M9VED(")38V%T=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B4V5B86=I86X@2'5J
M86X@<&5T:7(@9&ES97)T86D@86YG:6X@<FEB=70B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B26QM=2!0
M96YG971A:'5A;B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED(")3
M96%R8V@B"FUS9W-T<B`B4&5N8V%R:6%N(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,R,`IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T<B`B
M365S:6X@4&5N8V%R:6%N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,CDW,PIM<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#0*(RP@9G5Z>GD*
M;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B4&EL:6@@<V5R=F5R(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.3@*;7-G:60@(E-E;&5C
M="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R(")0:6QI:"!G<G5P('5N='5K(&1I
M=&%M8F%H(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I
M9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@(E!I;&EH('!E;6EL:6L@
M8F%R=2(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I
M9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(E!I;&EH('-E<G9E<B(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,34V"FUS9VED(")396QE8W0@
M82!U<V5R('1O(&%D9"(*;7-G<W1R(")0:6QI:"!P96YG9W5N82!U;G1U:R!D
M:71A;6)A:"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HV-S<*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T<B`B
M2&%P=7,@<V5L(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,PHC
M+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM
M<V=S='(@(E!I;&EH(&9O<FUA="!T86YG9V%L.B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*(RP@9G5Z>GD*;7-G:60@
M(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B4&EL:6@@<&5M:6QI:R!B87)U
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W
M.`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B4&EL:6@@
M<&5M:6QI:R!B87)U(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W"FUS
M9VED("(B"B)396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T
M:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T
M92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B(@HB4&EL:6@@
M:V%R86MT97(@>6%N9R!A;F1A('!E<FQU:V%N(&1A<FD@:V]T86LM:V]T86L@
M9&EB87=A:"!I;FDN($%N9&$@9&%P870@(@HB;65N>6%L:6X@9&%N(&UE;&5K
M871K86YN>6$@:V4@9&%L86T@87)E82!T96MS+B(*"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C,T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI
M=&5R.B(*;7-G<W1R(")0:6QI:"!B871A<R!T86YG9V%L.B(*"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@
M9F]R;6%T.B(*;7-G<W1R(")0:6QI:"!F;W)M870@=&%N9V=A;#HB"@HC.B!T
M96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDP"FUS9VED(")3
M96QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93HB"FUS9W-T
M<B`B4&EL:6@@:61E;G1I=&%S('EA;F<@:6YG:6X@9&EU8F%H(&]L96@@86YD
M83HB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L
M96-T('1H92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B4&EL:6@@8F%T87,@
M=V%K='4Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@
M(E-E;&5C="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(E!I;&EH(&9O<FUA
M="!W86MT=3HB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4W"FUS
M9VED(")396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`B4&EL
M:6@@9'5A(&MO;&]M('EA;F<@8V]C;VLN(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,P-@IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*
M;7-G<W1R(")0:6QI:"!W87)N82!S8VAE;64@86YD82XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C0X"FUS9VED(")396QE8W0@>6]U<B!P<F5F97)R
M960@;&%N9W5A9V4Z(@IM<V=S='(@(E!I;&EH(&)A:&%S82!Y86YG(&%N9&$@
M:6YG:6YK86XZ(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M-3@*;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B2VER:6T@
M3&%P;W)A;B!-87-A;&%H(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$P,SD*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS,38*;7-G:60@(E-E;G-O<CH@(@IM<V=S
M='(@(E-E;G-O<CHB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`Y"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHW,PIM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(E-E<'1E;6)E
M<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS
M9VED(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#$*(RP@9G5Z>GD*;7-G
M:60@(E-E<FEA;"!.=6UB97(B"FUS9W-T<B`B06YG:V$@1&5S:6UA;"(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*(RP@9G5Z>GD*;7-G
M:60@(E-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S
M='(@(D%R96$@365T87(@=&ED86L@9&ES961I86MA;BXB"@HC.B!A9&UI;B]S
M97-S:6]N<RYP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(E-E<W-I;VX@061M:6XB
M"FUS9W-T<B`B27II;B!!9&UI;FES=')A<VDB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I
M;VX@240@97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30U
M"B,L(&9U>GIY"FUS9VED(")397-S:6]N<R(*;7-G<W1R("))>FEN(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-`HC+"!F=7IZ>0IM<V=I9"`B
M4V5T(@IM<V=S='(@(E-E='5P(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C<V"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@
M>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N(@IM<V=S='(@
M(B(*(D%T=7(@<&EL:6AA;B!U;G1U:R!M96YG:7II;FMA;B!A;F1A(&1A<&%T
M(&UE;F=A='5R('5L86YG(&ME;6)A;&D@<V%N9&D@86YD82`B"B)A<&%B:6QA
M(&%N9&$@;'5P82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS
M9VED(")3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A
M8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B071U<B!R96UO=&4@
M<V5R=F5R('EA;F<@:6YG:6X@86YD82!A:W-E<R!D87)I('!O<G1A;"!A;F1A
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-`IM<V=I9"`B4V5T('EO
M=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I
M;VYS+B(*;7-G<W1R(")!='5R(&)A:&%S82P@>F]N82!W86MT=2!D86X@<&EL
M:6AA;B!T86YG9V%L+"!Y86YG(&%N9&$@:6YG:6YK86XN(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDX"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P
M(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@
M86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B(@HB071U
M<B!A<&QI:V%S:2!A=V%L(&%N9&$L('=A<FYA('-C:&5M92P@:&%L86UA;B!R
M969R97-H(&1A;B!P:6QI:&%N('1A;7!I;&%N("(*(FQA:6YN>6$N(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0IM<V=I9"`B4V5T=7`B"FUS9W-T
M<B`B4V5T=7`B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M
M;#HS-PIM<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L92(*
M;7-G<W1R(")38W)I<'0@<V5T=7`@=7!G<F%D92!T97)S961I82(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ.#8*;7-G:60@(E-E=F5R86P@
M;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S
M='(@(D)E8F5R87!A(&QO:V%S:2!Y86YG(&UU;F=K:6X@9&5N9V%N('!A<F%M
M971E<CHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L;&5S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.38*;7-G:60@
M(E-H;W!P:6YG(@IM<V=S='(@(D)E;&%N:F$B"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHT,PIM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G
M<W1R(")2:6YG:V%S86X@4&5N9&5K(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0T-@IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@
M9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@(E!E<FQU:V%H(&MU;F-I(&%K<V5S
M(&1I9&5F:6YI<VEK86X@=6YT=6L@:V5B86YY86MA;B!L:6YK/R(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(S('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3$S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W
M(@IM<V=S='(@(E1A;7!I;&MA;B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R
M96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B(@HB5&%M<&EL:V%N('!E<F)E9&%A;B!D:6%N
M=&%R82!K;VYF:6=U<F%S:2!Y86YG(&)A<G4@9&ES:6UP86X@9&%N('EA;F<@
M8F%R=2`B"B)D:6AA<VEL:V%N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT.3`*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN
M9R!I;C\B"FUS9W-T<B`B5&%M<&EL:V%N('=A:W1U(&QO9VEN('1E<F%K:&ER
M(&ME=&EK82!A;F1A(&QO9VEN/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$W-C4*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,PHC
M+"!F=7IZ>0IM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B1V5R:6UI<R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C8*;7-G:60@(E-H;W<@=&%B
M;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B5&%M<&EL:V%N('!A
M;F5L(&UE;G4@=&%B96P@;W!E<F%S:3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S0Y"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE
M;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@(E1A;7!I;&MA;B!-96YU("5S(&1I
M('-E8F5L86@@:VER:3\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE
M($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B5&%M<&EL:V%N(&1I
M86QO9R!0<F]P97)T:2!396P@5&%B96PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@
M=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(E1A;7!I;&MA
M;B!D:6%L;V<@4')O<&5R=&D@5&%B96PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@
M=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")486UP
M:6QK86X@9&EA;&]G(%!R;W!E<G1I($)A<FES(%1A8F5L(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS
M9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R
M(")486UP:6QK86X@9&EA;&]G('!R;W!E<G1I(&=A;6)A<B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C,*;7-G:60@(E-H;W<@=7!L;V%D(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4P"FUS9VED(")3:&]W97)S(@IM<V=S='(@(D=E<FEM:7,B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,0IM<V=I9"`B
M4VAO=V5R<R!%87)L>2(*;7-G<W1R(")'97)I;6ES(&1I('!A9VD@:&%R:2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS
M9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B1V5R:6UI<R!B96)E<F%P82!S
M86%T(&QA9VDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T
M<B`B1V5R:6UI<R!D:2!S96MI=&%R(&1A97)A:"(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C0X,`IM<V=I9"`B4VAR:6YK(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<W
M-"!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HX,S8*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3(R(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.CDX-`HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HQ,#0W(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C$P.#<*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z,3$Q-B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ
M,30Y"FUS9VED(")3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH
M<RD@;W5T(&]F('1H92!W87D@9FER<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C4*;7-G:60@(E-I9VX@=7`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HW,3(*(RP@9G5Z>GD*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R(")$869T
M87(@0F%C86%N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HW,3$*;7-G:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C4@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@W(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@Y-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$U(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S<*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C(T-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,P"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C,*;7-G:60@(E-I>F4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E
M+FAT;6PZ-3(*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B3&5W
M871I(%!E;65L:6AA<F%A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9A
M:VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C4T"FUS9VED(")3;F]W(@IM<V=S='(@(E-A;&IU(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@(E-N
M;W<@4VAO=V5R(@IM<V=S='(@(D=E<FEM:7,@4V%L:G4B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R!3
M:&]W97)S(@IM<V=S='(@(D=E<FEM:7,@4V%L:G4B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3:&]W
M97)S($5A<FQY(@IM<V=S='(@(D=E<FEM:7,@4V%L:G4@9&D@<&%G:2!H87)I
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*
M;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(D=E<FEM:7,@4V%L
M:G4@8F5B97)A<&$@<V%A="!L86=I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR-S@*;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R(")+961A;&%M86X@
M4V%L:G4Z(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#(*;7-G:60@(E-N
M;W<@97%U:79A;&5N="!I;B!W871E<CH@(@IM<V=S='(@(E!E<F)A;F1I;F=A
M;B!S86QJ=2!D:2`H9&%L86TI(&%I<CHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED
M(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM
M<V=I9"`B4V]M86QI82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B3&%G=2`F
M(%-A:F%K(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR-@HC+"!F
M=7IZ>0IM<V=I9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`B2&%P
M=7,@<&EL:6AA;B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-34Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-#<*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HQ.#D*(RP@9G5Z>GD*;7-G:60@(E-O=7)C92!A
M9&1R97-S(@IM<V=S='(@(D%L86UA="!%;6%I;"!!;F1A(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-34@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/
M+3@X-3DM,RDB"FUS9W-T<B`B17)O<&$@4V5L871A;B`H25-/+3@X-3DM,RDB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S<*;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3
M;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O
M=71H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B0F5L86AA;B!"=6UI(%-E;&%T
M86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G
M<W1R(")*87)A:R!A;G1A<F$@<V5L('EA;F<@8F5R9&5K871A;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED
M(")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM
M<V=S='(@(DIA<F%K(&%N=&%R82!I<VD@9&%N(&)O<F1E<B!D:2!D86QA;2!S
M96PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX,34*(RP@9G5Z>GD*
M;7-G:60@(E-P86-E<B(*;7-G<W1R(")*87)A:R!S<&%S:2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`IM<V=I
M9"`B4W!A8VEN9R(*;7-G<W1R(")*87)A:R!S<&%S:2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@
M(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B2F%R86L@<W!A<VD@9&%N
M(&IA<F%K('-P87-I(&1A<FD@8F]R9&5R(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*(RP@9G5Z
M>GD*;7-G:60@(E-P86EN(@IM<V=S='(@(DIA<F%K('-P87-I(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDX"FUS9VED(")3<&%M(@IM<V=S='(@
M(E-P86TB"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P
M96-I86P@0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(DUA<W5K:V%N($MA<F%K
M=&5R(%-P97-I86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S='(@
M(E!I<V%H:V%N(%-E;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G
M<W1R(")0:7-A:&MA;B!K;VQO;2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*
M;7-G<W1R(")0:7-A:&MA;B!B87)I<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV,0IM<V=I9"`B4W!O<G1S(@IM<V=S='(@(D]L86AR86=A(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@X"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<S(&QI8B]";&]C:R]M971A<BYP
M:'`Z-S0*;7-G:60@(E-T86YD87)D(@IM<V=S='(@(E-T86YD87(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*;7-G
M<W1R(")097)J86QA;F%N($)I;G1A;F<B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-3DV(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#D*(RP@
M9G5Z>GD*;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B4&5R:F%L86YA;B!"
M:6YT86YG(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-S`*;7-G:60@(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T
M=7,B"FUS9W-T<B`B4W1A='5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C@Q-0HC+"!F=7IZ>0IM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T
M<B`B1F]R;6%T(%=A:W1U(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-S(*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*
M;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T<B`B06YG:V$O:'5R=68O<VEM
M8F]L('EA;F<@9&EB97)I('1A;F1A(&=A<FES(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(S,PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,PIM<V=I9"`B4W1R
M:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM
M<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B1V%Y82!;0U-372(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@
M(E-U(@IM<V=S='(@(DUI;B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS
M-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB
M)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(E-U8F1I<F5K=&]R:2`G)7,G('1I
M9&%K(&1I=&5M=6MA;BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C<S"B,L(&9U>GIY"FUS9VED(")3=6)J96-T(@IM<V=S
M='(@(D%N9VMA+VAU<G5F+W-I;6)O;"!Y86YG(&1I='5L:7,@9&EB87=A:"!G
M87)I<R!B87)I<R!T96MS(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S,R(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,Q-PHC+"!F
M=7IZ>0IM<V=I9"`B4W5B;6ET(@IM<V=S='(@(D%N9VMA+VAU<G5F+W-I;6)O
M;"!Y86YG(&1I='5L:7,@9&EB87=A:"!G87)I<R!B87)I<R!T96MS(@H*(SH@
M<VEG;G5P+G!H<#HT.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M4W5B;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES=&5M
M+B!9;W4@8V%N(&YO="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA
M<R!B965N(&%P<')O=F5D+B(*;7-G<W1R("(B"B(@4&5R;6EN=&%A;B!Y86YG
M(&1I<V%M<&%I:V%N('5N='5K(&UE;F%M8F%H:V%N("<E(',G(&ME(&1A;&%M
M('-I<W1E;2X@06YD82`B"B)T:61A:R!D87!A="!L;V<@:6X@<V%M<&%I('!E
M<FUI;G1A86X@86YD82!T96QA:"!D:7-E='5J=6DN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R
M:7!T(@IM<V=S='(@(D%N9VMA+VAU<G5F+W-I;6)O;"!Y86YG(&1I='5L:7,@
M9&EB87=A:"!G87)I<R!B87)I<R!T96MS(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$P-`HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S
M='(@(D)E<FAA<VEL(@H*(SH@861M:6XO=7-E<BYP:'`Z.#4*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@
M=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B)R5S)R!S=61A:"!B97)H87-I;"!D
M:71A;6)A:&MA;B!K92!D86QA;2!S:7-T96TN(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@8VQE87)E9"!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T
M96TN(@IM<V=S='(@(D1A=&$@=6YT=6L@<&5N9V=U;F$@)R5S)R!S=61A:"!B
M97)H87-I;"!D:6)E<G-I:&MA;B!D87)I('-I<W1E;2XB"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*
M;7-G<W1R(")<(B5S7")S=61A:"!B97)H87-I;"!D:6AA<'5S+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$P-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB
M"FUS9W-T<B`B)R5S('-U9&%H(&)E<FAA<VEL(&1I<&EN9&%H:V%N(&1A<FD@
M<VES=&5M+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@
M(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@
M=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(B(*(DMO;F9I9W5R87-I('-U9&%H
M(&)E<FAA<VEL(&1I:V5M8F%L:6MA;BX@56QA;F=I('5N='5K(&UE;&EH870@
M<&5R=6)A:&%N+B`B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S
M879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B0F%C:W5P(&MO
M;F9I9W5R87-I('-U9&%H(&)E<FAA<VEL(&1I<VEM<&%N+B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE
M("5S+B(*;7-G<W1R(")&:6QE($)A8VMU<"!+;VYF:6=U<F%S:2`E<R!S=61A
M:"!B97)H87-I;"!D:7-I;7!A;BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A
M=&5D(%PB)7-<(B(*;7-G<W1R("(G)7,G('-U9&%H(&)E<FAA<VEL(&1I<&5R
M8F%H87)U:2(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R("(G)7,G('-U9&%H(&)E<FAA<VEL
M(&1I='5L:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"B,L(&9U>GIY"FUS9VED(")3=61A
M;B(*;7-G<W1R(")#97)A:"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*;7-G:60@(E-U;6UA<GDB"FUS9W-T
M<B`B4FEN9VMA<V%N(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS
M9VED(")3=6X@4FES92(*;7-G<W1R(")-871A:&%R:2!497)B:70B"@HC.B!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U;B!3970B"FUS9W-T
M<B`B36%T86AA<FD@5&5R8F5N86TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU.0IM<V=I9"`B4W5N;GDB"FUS9W-T<B`B0V5R
M86@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$V"FUS9VED
M(")3=6YR:7-E(@IM<V=S='(@(DUA=&%H87)I(%1E<F)I="(*"B,Z(&QI8B]"
M;&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@IM
M<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`B36%T86AA<FD@5&5R8FET
M+TUA=&%H87)I(%1E<F)E;F%M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(Q-0IM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(DUA=&%H87)I
M(%1E<F)I=#HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Y
M"FUS9VED(")3=6YS970B"FUS9W-T<B`B36%T86AA<FD@5&5R8F5N86TB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$X"FUS9VED(")3=6YS
M970Z("(*;7-G<W1R(")-871A:&%R:2!497)B96YA;3HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S"FUS9VED(")3=7!E
M<G-C<FEP="(*;7-G<W1R(")!;F=K82]H=7)U9B]S:6UB;VP@>6%N9R!D:71U
M;&ES(&1I871A<R!B87)I<R!T96MS(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,W.`IM<V=I9"`B4W5P<&]R="(*;7-G<W1R(")$=6MU;F=A;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#8*(RP@9G5Z>GD*;7-G:60@(E-U<FEN86UE(@IM<V=S
M='(@(FYA;6$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4W-`HC+"!F=7IZ>0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R(")N86UA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA;F0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-38@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8V"FUS9VED(")3=VET>F5R;&%N9"(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@IM<V=I9"`B4WEN
M8R!L;V<@9&5L971E9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,30R"FUS9VED(")3>6YC34PB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3>6YT87@@97)R
M;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*
M;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS9VED(")4
M+5-T;W)M(@IM<V=S='(@(DAU:F%N('!E=&ER(&1I<V5R=&%I(&1E;F=A;B!A
M;F=I;B!R:6)U="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8Q"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G<W1R(")(
M=6IA;B!P971I<B!D:7-E<G1A:2!D96YG86X@8F%D86D@86YG:6X@<FEB=70B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,@IM
M<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B2'5J86X@<&5T:7(@9&ES97)T86D@
M9&5N9V%N(&%N9VEN(')I8G5T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(E0M4W1O<FUS($5A
M<FQY(@IM<V=S='(@(D=E<FEM:7,@9&D@<&%G:2!H87)I(@H*(SH@9G)A;65W
M;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$V-@HC+"!F=7IZ>0IM<V=I9"`B5%-6
M(&9I;&4B"FUS9W-T<B`B2G5D=6PB"@HC.B!F<F%M97=O<FLO54DO54DO5&%B
M;&4N<&AP.C$S-`HC+"!F=7IZ>0IM<V=I9"`B5&%B;&4B"FUS9W-T<B`B1&%F
M=&%R(%1A8F5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@4')O<&5R=&EE<R(*;7-G
M<W1R(")0<F]P97)T:2!486)E;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO
M5'EP92]T86)L97-E="YP:'`Z-3<*(RP@9G5Z>GD*;7-G:60@(E1A8FQE(%-E
M="(*;7-G<W1R(")0<F]P97)T:2!486)E;"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE
M('!R;W!E<G1I97,B"FUS9W-T<B`B4')O<&5R=&D@=&%B96PB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-"!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$Q"B,L(&9U>GIY"FUS9VED(")486EW86XB"FUS9W-T<B`B
M2'5J86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`Y"FUS9VED(")486II:VES=&%N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A;GIA;FEA+"!5;FET960@4F5P=6)L
M:6,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R(")487)G
M970Z(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDY-B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3@W"FUS9VED(")487-K<R(*;7-G<W1R(")4=6=A
M<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<S"FUS
M9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,CDP"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*
M;7-G<W1R(")3=6AU('5N='5K(&IA;2!T97)A:VAI<CHB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(Q-`IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B
M4W5H=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C,*;7-G
M:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`B4W5H=3HB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDS"B,L('!H<"UF;W)M870*;7-G:60@
M(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS
M9W-T<B`B4W5H=3QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@H*(SH@
M9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HV.#<*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N
M(@IM<V=S='(@(D1I<F5K=&]R:2!-;W1I9B`G)7,G('1I9&%K(&1I=&5M=6MA
M;BXB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I9"`B5&5M<&QA
M=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`B5&5M<&QA=&4@061M:6YI<W1R
M87-I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,S,V"B,L(&9U>GIY"FUS9VED(")497AT(@IM
M<V=S='(@(D)E<FEK=71N>6$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S<U"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`B2&%N>6$@5&5K<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S0*;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T<B`B4&5R871A86X@5&5K<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*
M;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`B5&5K<R!"86=I86X@071A<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G
M:60@(E1H(@IM<V=S='(@(DMM<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DQ"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R(")4:&%I("A425,M
M-C(P*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1H86EL86YD(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX.`IM<V=I9"`B5&AA
M;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R,`HC+"!F=7IZ>0IM<V=I9"`B
M5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
M07)E82!K92!W96%T:&5R+F-O;2!T:61A:R!D:7-E9&EA:V%N+B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,T"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N
M;W0@<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%])35-0+TE-4U`O0F]O:RYP:'`Z,3(Y,@IM<V=I9"`B5&AE($E-4U`@;&]G
M(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@36%I;G1E;F%N
M8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S='(@
M(E!E;65L:6AA<F%A;CHZ(&-L87-S('1I9&%K(&)E<FAA<VEL(&1I<&%N9V=I
M;"(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G
M:60@(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*
M;7-G<W1R(")7:6YD;W<@4&EL:6AA;B!S=61A:"!D:71U='5P+B!3:6QA:V%N
M($ME;'5A<B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,C$Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(S
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,C8T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S`S"FUS9VED("(B
M"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M
M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U
M<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B
M;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(DAA;GEA('-I<VD@8F%G:6%N(&)A
M=V%H(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@
M;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN
M('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C4Q"FUS9VED(")4:&4@8V]N=&%C
M="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,38Y"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B
M;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L
M:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O
M<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T
M,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF
M:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP
M.C$Q,PIM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A
M('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S4@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HU,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO
M=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V."!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S
M:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,3D*;7-G:60@(E1H92!F
M:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.#`*;7-G:60@(E1H92!F
M:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@
M9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F
M8S@R,B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S
M8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN
M=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@
M=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP
M97)I96YC92`B"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U
M;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*
M(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T
M:&%T('EO=2=L;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT
M)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N
M960N("!0;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@
M=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*(DUO9&4@
M3&%Y87(@4&5N=6@@9&EK96YA;"!D87!A="!M96YY96)A8FMA;B!M87-A;&%H
M(&1E;F=A;B!);G1E<FYE="!%>'!L;W)E<BP@(@HB:G5G82!U;G1U:R!M96YC
M87)I(&ME<V%L86AA;B!Y86YG(&UE;GEE8F%B:V%N(&%N9&$@=&ED86L@;6%M
M<'4@8F5K97)J82`B"B)D96YG86X@8F%I:RX@06YD82!M=6YG:VEN('!E<FYA
M:"!M96YG86QA;6D@=&%M<&EL86X@>6%N9R!B=7)U:RP@:V5K=7)A;F=A;B`B
M"B)D87)I(&9U;F=S:2!E9&ET;W(@9&%N+V%T874@8G)O=W-E<B!Y86YG('-E
M<FEN9R!K86QI(')U<V%K(&1A;B!H87)U<R!D:75L86YG("(*(FME;6)A;&DN
M($II:V$@<VES=&5M(&%N9&$@861A;&%H(%=I;F1O=W,@.7@@861A(&ME;75N
M9VMI;F%N(&%N9&$@86MA;B`B"B)M96YD87!A=&MA;B`G2V5S86QA:&%N(%!E
M<FQI;F1U;F=A;B!5;75M)R!D86X@<&5R;'4@=6YT=6L@;64M<F5S=&%R="`B
M"B)K;VUP=71E<B!A;F1A+EQ<;EQ<;B!!;F1A('-U9&%H(&1I<&5R:6YG871I
M+B!3:6QA:V%N(&ML:6L@3TL@:FEK82!A;F1A(&EN9VEN("(*(FUE;F-O8F$@
M961I=&]R(&QA>6%R('!E;G5H+B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA
M<R!B965N(&1E;&5T960N(@IM<V=S='(@(DED96YT:71A<R!<(B5S7"(@<W5D
M86@@9&EH87!U<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I9&4@
M;VYL>2(*;7-G<W1R(")(86YY82!S:7-I(&)A9VEA;B!K:7)I(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@
M;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O
M('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-1$XN<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C
M="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G
M=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N
M9&5R<W1O;V0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$X-S<*;7-G:60@(E1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@
M=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HT-#$*;7-G:60@(E1H92!N=6UB97(@;V8@9FEE
M;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C,Q"FUS9VED(")4:&4@;W!E;G-S
M;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM
M93HZ(&-L87-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')E9F5R
M96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A
M=&$@97AC965D960@=&AE("(*(FUA>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O9&5B+G!H
M<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]E;G-C<FEP="YP
M:'`Z,S4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-P;W=E<G!O
M:6YT+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O
M<F0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)P;2YP
M:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=V5B8W!P+G!H
M<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]S<F-H:6=H;&ET
M92YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-E>&-E
M;"YP:'`Z,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@
M=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N
M9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HT-30*;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@
M;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'DB"FUS9W-T
M<B`B2&%N>6$@<VES:2!B86=I86X@:V%N86X@9&%N(&MI<FDB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS
M9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B2&%N>6$@
M<VES:2!B86=I86X@:V%N86XB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HT-#8*;7-G:60@(E1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN
M9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E
M<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B4V5R=F5R(%PB
M)7-<(B!S=61A:"!B97)H87-I;"!D:6AA<'5S+B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]R<&-S=6TN<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S
M97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R(")397)V97(@
M7"(E<UPB('-U9&%H(&)E<FAA<VEL(&1I<VEM<&%N+B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E
M<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N(@IM<V=S='(@(E!E<FUI
M;G1A86X@<&5N9&%F=&%R86X@=6YT=6L@)7,@<W5D86@@8F5R:&%S:6P@9&EP
M:6YD86AK86XN(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z,S,P"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES
M="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ
M-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB
M)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S,Q,0IM<V=I9"`B5&AE('1E>'0@>6]U(&5N=&5R
M960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<Y"FUS9VED(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@
M;VYL>2(*;7-G<W1R(")(86YY82!S:7-I(&)A9VEA;B!A=&%S(&1A;B!B87=A
M:"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(DAA
M;GEA('-I<VD@8F%G:6%N(&%T87,B"@HC.B!F<F%M97=O<FLO1&%T82]$871A
M+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I
M;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R86UE=V]R:R]$871A+T1A=&$O
M='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO
M="!B92!S879E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C0V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$U(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ,3D*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B
M;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")!<F5A(&ME('=E871H
M97(N8V]M('1I9&%K(&1I<V5D:6%K86XN(@H*(SH@=71I;"]I8V]N7V)R;W=S
M97(N<&AP.C(U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M97,@
M9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(D1I<F5K=&]R
M:2!-;W1I9B`G)7,G('1I9&%K(&1I=&5M=6MA;BXB"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C$W.`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@
M87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R(")!<F5A($UE=&%R
M('1I9&%K(&1I<V5D:6%K86XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z,S0R"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA
M="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30P,0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I
M96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[("(*(GEO=2!M
M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P
M+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@7"(E<UPB('1O
M('1H92!S>7-T96TZ("5S(@IM<V=S='(@(D%D82!M87-A;&%H(&ME=&EK82!M
M96YA;6)A:&MA;B`G)7,G(&ME(&1A;&%M('-I<W1E;3H@)7,@(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E
M<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(D%D82!M87-A;&%H(&ME
M=&EK82!M96UB97)S:6AK86X@9&%T82!U;G1U:R!P96YG9W5N82`G)7,G(&1A
M<FD@<VES=&5M.B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN
M9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B061A(&UA<V%L
M86@@:V5T:6MA(&UE;6EN9&%H:V%N("<E<R<@9&%R:2!S:7-T96TZ(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,34Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS
M9W-T<B`B061A(&UA<V%L86@@:V5T:6MA(&UE;7!E<F)A:&%R=6D@)R5S)SHE
M<R(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE
M(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE
M(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI
M;75M("(*(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.3$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F
M:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L
M87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+VEM8RYP:'`Z,S$*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A
M<B!D871A+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C@P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I
M9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U
M:7)E9"!F:65L9"XB"FUS9W-T<B`B(@HB061A(&ME<V%L86AA;B!D:2!D86QA
M;2!F;W)M=6QI<B!K;VYF:6=U<F%S:2X@375N9VMI;B!A;F1A('1I9&%K(&UE
M;F=I<VD@(@HB:V]L;VT@>6%N9R!D:7!E<FQU:V%N+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X"FUS9VED("(B
M"B)4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D
M(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L
M871E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-#`*(RP@9G5Z>GD*;7-G:60@(B(*(E1H97)E
M('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0
M;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B)!9&$@:V5S86QA
M:&%N(&1I(&1A;&%M(&9O<FUU;&ER(&MO;F9I9W5R87-I+B!-=6YG:VEN(&%N
M9&$@=&ED86L@;65N9VES:2`B"B)K;VQO;2!Y86YG(&1I<&5R;'5K86XN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C(*
M(RP@9G5Z>GD*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN
M9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T
M97(N(@IM<V=S='(@(B(*(D%D82!K97-A;&%H86X@9&D@9&%L86T@9F]R;75L
M:7(@:V]N9FEG=7)A<VDN($UU;F=K:6X@86YD82!T:61A:R!M96YG:7-I("(*
M(FMO;&]M('EA;F<@9&EP97)L=6MA;BXB"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*(RP@9G5Z>GD*;7-G:60@(E1H:7,@
M24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N
M(@IM<V=S='(@(D)R;W=S97(@86YD82!T:61A:R!M96YD=6MU;F<@=6YT=6L@
M9FET=7(@:6YI+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@
M=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N
M;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q-#4*;7-G:60@(E1H:7,@
M9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HQ.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z
M+R\B"B)C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@
M05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,3,T"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N
M9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP
M;&,N8V]M*2`B"B)G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU,34*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG
M(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*
M(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I
M=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D
M869O;F4@271A;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB
M97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D
M869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3<X(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$P-3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`X
M-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3$U"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q.#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(U
M-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`U(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$S.3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,34U-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#,Y"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y-3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C`P-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#(Y(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(P-S@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$T.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C(Q"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C0U-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C4W(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(X,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S$S-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S`V"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,30@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S@R,@IM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V-0IM<V=I
M9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$X"FUS9VED
M(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE
M(&-O;&]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,#DT"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T
M86P@=F%L=65S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,3(S"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O
M<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY.#D*;7-G:60@(E1H:7,@
M9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@S-@IM<V=I9"`B(@HB5&AI<R!F
M:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X
M(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU-C$*;7-G:60@(E1H:7,@
M9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B26YI(&%D86QA:"`E<RXB"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0U.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@
M5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL("(*
M(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@
M9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI96YT<R!P
M;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z-3DQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S
M*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@
M;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HT-0IM<V=I9"`B5&AI<R!S
M97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP
M:'`Z,3@Y"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I
M=F%T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP
M:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@
M86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B5VEN9&]W(&EN:2!H87)U<R!D
M:7!A;F=G:6P@9&%R:2!0:6QI:&%N(%=I;F1O=R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4:'5N9&5R(@IM
M<V=S='(@(E!E=&ER(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S
M-`IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R(")4:6ME="(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(T,C@@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")4:6UE(@IM<V=S='(@(DIU9'5L(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X-@IM<V=I9"`B5&EM92!4
M<F%C:VEN9R(*;7-G<W1R(")-96YG:6MU=&D@5V%K='4B"@HC.B!L:6(O0FQO
M8VLO=&EM92YP:'`Z,3<*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(D9O
M<FUA="!786MT=2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U,SD*
M(RP@9G5Z>GD*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@(DAA<'5S
M('!I;&EH86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4:6UO<BU,97-T92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P"FUS9VED(")4:71L
M92(*;7-G<W1R(")*=61U;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS
M9W-T<B`B2G5D=6P@*$-A=&%T86X@<&5T=6YJ=6LI(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0HC+"!F=7IZ>0IM<V=I
M9"`B5&\B"FUS9W-T<B`B071A<R(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HV-30*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT
M:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M
M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3$*;7-G:60@(E1O
M9&%Y(@IM<V=S='(@(DAA<FD@26YI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U
M<F-E(@IM<V=S='(@(D=A;G1I(%-O=7)C92!(5$U,(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M.0IM<V=I9"`B5&]G;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED
M(")4;VME;&%U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS,3,*;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(D)E<V]K(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,CD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,`HC+"!F=7IZ>0IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B
M2&%R:2!);FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S<*;7-G:60@(E1O<"(*;7-G<W1R(")!=&%S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I
M9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R(")&<F%M92!!=&%S("A?=&]P
M*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I9"`B5')A;G-L
M871I;VYS(@IM<V=S='(@(E1R86YS;&%S:2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G
M:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3<Y,`IM<V=I9"`B5')U92!O<B!F86QS92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R(")396PB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$P"FUS9VED(")4=6YI<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*
M;7-G:60@(E1U<FME>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$Y,@IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B
M5'5R:VD@*$E33RTX.#4Y+3DI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5R
M:VUE;FES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U
M<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,
M22]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-CD*;7-G
M:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R("));F1E:W,@52Y6.B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB+T)L
M;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@(E523"(*;7-G<W1R(")54DPB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T
M,0IM<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@
M<F5P;W)T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.3<*;7-G:60@(E523#HB"FUS9W-T<B`B55),.B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5G86YD82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$R"B,L(&9U>GIY"FUS9VED(")5:W)A:6YE(@IM<V=S='(@(D=A
M<FES(&)A=V%H(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#$R
M"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HY-@IM
M<V=I9"`B56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H
M96X@<VEG;FEN9R!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HS.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,X-2!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@
M)7,O)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z-S4U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M8VAA;F=E('1O("5S+B(*;7-G<W1R(")4:61A:R!D87!A="!U;G1U:R!M96YG
M:&%P=7,@7"(E<UPB.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C(S,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(E1I9&%K(&1A
M<&%T('5N='5K(&UE;F=H87!U<R!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C8X."!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C$P,38*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C@S
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K
M(&9I;&4@<VEZ92!O9B!<(B5S+R5S7"(N(@IM<V=S='(@(E1I9&%K(&1A<&%T
M('5N='5K(&UE;F=H87!U<R!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<W%L+G!H<#HT,S4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T
M;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(E1I9&%K(&1A<&%T
M('1E<FAU8G5N9R!K92!S97)V97(@;&1A<"(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z.#,Y"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!W:71H
M(%-33"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,C(U(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(S,`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C(P.0IM<V=I9"`B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S8U
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E
M(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")4:61A:R!D87!A="!U
M;G1U:R!M96YG:&%P=7,@7"(E<UPB.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HS-30@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C(U.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C4V"FUS
M9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@
M(E1I9&%K(&1A<&%T('5N='5K(&UE;F=H87!U<R!<(B5S7"(Z("5S+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C@V"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@7"(E
M<UPB+B(*;7-G<W1R(")4:61A:R!D87!A="!U;G1U:R!M96YG:&%P=7,@7"(E
M<UPB.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-C4*
M;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N<&AP
M.C<V"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HW
M.0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB
M"FUS9W-T<B`B5&ED86L@9&%P870@=6YT=6L@;65N9VAA<'5S(%PB)7-<(CH@
M)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,C0@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HR.3@*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y
M(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B5&ED86L@9&%P870@=6YT=6L@;65N
M9VAA<'5S(%PB)7-<(CH@)7,N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW."!A
M9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T<B`B5&ED86L@
M9&%P870@=6YT=6L@;65N9VAA<'5S(%PB)7-<(CH@)7,N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,Q(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z,SDR"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,3$@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,S-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y
M(&ES(&YO="!E;7!T>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,S0X(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HS-3(*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R
M>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,S,W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS
M,C(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,S-2!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S0S"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HS-#0*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B5&ED86L@9&%P870@=6YT
M=6L@;65N9VAA<'5S(%PB)7-<(CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HT,3<@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,CD*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(E1I9&%K(&1A<&%T('5N='5K
M(&UE;F=H87!U<R!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z,C`W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B5&ED86L@
M9&%P870@=6YT=6L@;65N9VAA<'5S(%PB)7-<(CH@)7,N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,S`S(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z,C@X"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ-C<@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X,`HC.B!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,3@W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HS.#,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C,Y,0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL
M92XB"FUS9W-T<B`B5&ED86L@9&%P870@=6YT=6L@;65N9VAA<'5S(%PB)7-<
M(CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-#0*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(E1I9&%K(&1A<&%T('5N='5K(&UE
M;F=H87!U<R!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z-#`V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(E1I9&%K
M(&1A<&%T('5N='5K(&UE;F=H87!U<R!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z.#`S"FUS9VED(")5;F%B;&4@=&\@9&5T
M97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8P,PIM<V=I9"`B56YA8FQE
M('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z-#4Q(&9R86UE=V]R:R].
M971?24U34"])35-0+T%U=&@N<&AP.C$Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N
M(@IM<V=S='(@(E1I9&%K(&1A<&%T('5N='5K(&UE;F=H87!U<R!<(B5S7"(Z
M("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$Y-B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$V-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,3<Q"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HY,R!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C$P,@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C8T."!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.CDX"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@
M9FEL92!<(B5S7"(N(@IM<V=S='(@(E1I9&%K(&1A<&%T('5N='5K(&UE;F=H
M87!U<R!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(W-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,P"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S,*;7-G:60@(E5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HX,"!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C<R"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HT-0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H
M:79E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#,U
M"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F
M86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M.#8V"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I
M>F4H*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4V5S<VEO
M;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*(RP@9G5Z>GD*
M;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R(")4:61A:R!D
M87!A="!U;G1U:R!M96YG:&%P=7,@7"(E<UPB.B`E<RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HV-CD*;7-G:60@(E5N86)L92!T;R!R96%D
M('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3`U"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E
M<B!A;')E861Y(&5X:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,CDS"FUS9VED(")5;F%B;&4@=&\@<F5N86UE
M(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z,S(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C8W(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z,S0S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B5&ED86L@
M9&%P870@=6YT=6L@;65N9VAA<'5S(%PB)7-<(CH@)7,N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z-C$P(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HR,CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(E1I9&%K(&1A
M<&%T('5N='5K(&UE;F=H87!U<R!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z,S(S(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HR,3,*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0U,B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C@U"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,#$*;7-G:60@(E5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA
M8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L
M92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,30Y(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,34R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")4
M:61A:R!D87!A="!U;G1U:R!M96YG:&%P=7,@7"(E<UPB.B`E<RXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-SD*;7-G:60@(E5N86)L92!T
M;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(X,2!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,X"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HQ-#,*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@
M9FEL92!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z.#0Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A
M('=I;&P@8F4@97AC965D960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*;7-G:60@(E5N9&5R;&EN
M92(*;7-G<W1R(")'87)I<R!B87=A:"(*"B,Z('1E;7!L871E<R]P<F5F<R]E
M;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R(")"871A;&MA
M;B!097)U8F%H86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*
M;7-G<W1R(")"871A;&MA;B!A:W-I('1E<F%K:&ER(&%N9&$B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,SDP"FUS9VED(")5;F5X
M<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S0Q"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,W.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M.#0*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z
M("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O
M<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHV,0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R(")4:61A
M:R!D:6%R<VEP:V%N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G
M:60@(E5N:6-O9&4@*%541BTX*2(*;7-G<W1R(")5;FEC;V1E("A55$8M."DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")5;FET960@2VEN9V1O;2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T
M97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-CD@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HW,0IM<V=I9"`B56YI=',B"FUS9W-T<B`B56YI="(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R.2!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,S`*;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDX
M"FUS9VED(")5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT
M($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,34Y"B,L(&9U>GIY"FUS9VED(")5;FMN;W=N(&QO8V%T
M:6]N('!R;W9I9&5D+B(*;7-G<W1R(")4:61A:R!A9&$@;&]K87-I('EA;F<@
M9&EA='5R+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S
M=V]R9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U
M<G)E;G0@96QE;65N="(*;7-G<W1R(")"871A;&MA;B!L:6YK('!A9&$@96QE
M;65N('EA;F<@<V5K87)A;F<B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E
M;G1I='DN<&AP.C(Y-@HC+"!F=7IZ>0IM<V=I9"`B56YN86UE9"(*;7-G<W1R
M(")N86UA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T
M(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*
M(G-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC
M86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W
M('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*
M;7-G<W1R("(B"B)38W)I<'0@>6%N9R!T:61A:R!M96UP=6YY86D@:&%K(&ES
M=&EM97=A('1I9&%K(&1A<&%T(&UE;F=A:W-E<R!(87!U<R]386QI;B\B"B),
M96MA=&MA;B!S97-U86D@<F5N8V%N82!U;G1U:R!A;&%S86X@:V5A;6%N86XN
M2VQI:R!/2R!U;G1U:R!M96QI:&%T(&-A=&%T86X@(@HB=&5K;FES('!A9&$@
M;6]Z:6QL82YO<F<@9&EM86YA(&%N9&$@86MA;B!D:7!E<FQI:&%T:V%N(&-A
M<F$@8F%G86EM86YA('5N='5K("(*(FUE;F=I>FEN:V%N('-C<FEP="!U;G1U
M:R!D87!A="!M96YG86MS97,@:V4@8VQI<&)O87)D+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@
M(E5N<V5T(&-O;&]R(@IM<V=S='(@(E=A<FYA(&)E;'5M(&1I871U<B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@V(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3(V"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z.3,R"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E
M;G-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HQ.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G
M:60@(E5P9&%T92(*;7-G<W1R(")097)B86AA<G5I(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHR.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5<&1A=&4@)7,B"FUS9W-T<B`B4&5R8F%H87)U:2`E<R(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S8*;7-G:60@(E5P9&%T92!U
M<V5R(@IM<V=S='(@(E!E<F)A:&%R=6D@<&5N9V=U;F$B"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C$T-"!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC
M97,O<VAA<F5S+V5D:70N<&AP.C(S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M<&1A=&5D(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB('-U9&%H(&1I<&5R8F%H
M87)U:2XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX,PIM<V=I9"`B
M57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B4V-R:7!T('5P9W)A
M9&4@<W5D86@@9&EH87!U<RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3<X(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ.3D*
M;7-G:60@(E5P;&]A9"(*;7-G<W1R(")5<&QO860B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5<&QO861E9"!A;&P@87!P;&EC871I
M;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T<B`B4V5M=6$@
M9FEL92!S971U<"!A<&QI:V%S:2!S=61A:"!D:75P;&]A9"!K92!S97)V97(N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R
M(")3:6UB;VP@:'5R=68@8F5S87(@;&%T:6XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$X"FUS9VED(")5
M<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(E-I;6)O;"!H=7)U9B!B97-A
M<B!R;VUA=VDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5<G5G=6%Y(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G
M97(N<&AP.C0U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R
M<F5N=#H@)7,B"FUS9W-T<B`B1F%S92!396MA<F%N9R(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5
M<V4@4U-,(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,C0*;7-G:60@(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F
M;W(@24U34"!S97)V97(N(@IM<V=S='(@(D=U;F%K86YL86@@:FEK82!N86UA
M+W-A;F1I(&%N9&$@8F5R8F5D82!U;G1U:R!S97)V97(@24U34"XB"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"B,L(&9U>GIY"FUS
M9VED(")5<V5R(@IM<V=S='(@(E!E;F=G=6YA(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HW,C,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!9&UI;FES
M=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')A<VD@4&5N9V=U;F$B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(U,0HC+"!F=7IZ>0IM<V=I
M9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(E-I;7!A;B!0:6QI:&%N(@H*(SH@
M<VEG;G5P+G!H<#HV,@IM<V=I9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T
M<B`B4&5N9&%F=&%R86X@4&5N9V=U;F$B"@HC.B!S:6=N=7`N<&AP.C(R"FUS
M9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@
M=&AI<R!S:71E+B(*;7-G<W1R(")096YD869T87)A;B!096YG9W5N82!S=61A
M:"!D:6YO;BUA:W1I9FMA;B!U;G1U:R!S:71E(&EN:2XB"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-#8Y"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O
M=6YD(@IM<V=S='(@(D%C8V]U;G0@4&5N9V=U;F$@=&ED86L@9&ET96UU:V%N
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$W.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L
M>5]S;71P+G!H<#HY.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HQ-3`@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S,*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS9W-T
M<B`B3F%M82!096YG9W5N82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG
M;G5P+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E
M<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R
M(").86UA(%!E;F=G=6YA.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N
M:6YC.C@*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B3F%M82!096YG9W5N
M83HB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED
M(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R(")096YG9W5N82!D:2!D
M86QA;2!S:7-T96TZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B57IB96MI<W1A
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ
M-C,@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C4U"B,L(&9U>GIY"FUS
M9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")3
M=6)D:7)E:W1O<FD@)R5S)R!T:61A:R!D:71E;75K86XN(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$Q.`IM<V=I9"`B5F%C871I;VXB"FUS9W-T
M<B`B3&EB=7)A;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@V-@IM
M<V=I9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.`HC
M+"!F=7IZ>0IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B2V5L96UB86)A;B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3DW"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(U-0IM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#4V(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Q-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#0@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S$V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C@*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0IM<V=I9"`B
M5F%L=65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q,#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-@IM<V=I9"`B5F%L
M=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*
M;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(T-`IM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B5F%R
M:6%B;&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")696YE>G5E;&$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,3@*
M;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y
M(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,`HC+"!F=7IZ>0IM<V=I
M9"`B5F5R<VEO;B(*;7-G<W1R(")697)S:2!+;VYT<F]L(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(R-@IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L
M(@IM<V=S='(@(E9E<G-I($MO;G1R;VPB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A
M;"!A;&EG;B(*;7-G<W1R(")*87)A:R!P;W-I<VD@=F5R=&EK86P@86YT87)A
M(&=A<FES(&1A<V%R(&1E;F=A;B!G86UB87(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T"FUS9VED(")697)T:6-A;"!P
M861D:6YG(@IM<V=S='(@(DIA<F%K('!O<VES:2!V97)T:6MA;"!A;G1A<F$@
M8F]R9&5R(&1E;F=A;B!G86UB87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T
M<B`B5F5R=&EK86PZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-S`*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R(")386YG870@
M5&EN9V=I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FEE="!.86TB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.30*;7-G:60@(E9I971N
M86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B5FEE=&YA;2`H5DE30TE)*2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.CDV,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A
M9V4B"FUS9W-T<B`B3&EH870@=V5B('!A9V4@96MS=&5R;F%L(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#(Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-@IM<V=I9"`B5FER9VEN($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#D*;7-G:60@(E9I
M<VEB:6QI='DB"FUS9W-T<B`B2F%R86L@4&%N9&%N9R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-C,*;7-G:60@(E9I<VEB:6QI='DZ("(*
M;7-G<W1R(")*87)A:R!086YD86YG.B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N
M92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V
M"FUS9VED(")705).(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-
M3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R(")015))3D=!
M5$%.(2$A(%!)3D1!2$M!3B!30U))4%0@24Y)(%-%0T%202!-04Y504P@1$%2
M22`E<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$S,PIM<V=I9"`B5TE.('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3<*;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+W-T871U<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:'1M;"YP:'`Z,C<R(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,PIM<V=I9"`B
M5V%R;FEN9R(*;7-G<W1R(")097)I;F=A=&%N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T
M<B`B4F%B=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.0IM
M<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R(")286UA;&%N($-U86-A
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0R-PIM<V=I9"`B
M5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(D1A=&$@0W5A8V$@
M9&ES961I86MA;B!O;&5H(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.#DR"B,L(&9U>GIY"FUS9VED(")796%T:&5R+F-O;2(*;7-G<W1R(")W96%T
M:&5R+F-O;2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED(")7
M96(B"FUS9W-T<B`B5V5B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0S-PIM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B5V5B(%-I=&4B"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4X"FUS9VED
M(")7965K;'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL
M92YP:'`Z,C@*;7-G:60@(E=E;&-O;64B"FUS9W-T<B`B4V5L86UA="!$871A
M;F<B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L
M8V]M92!T;R`E<R(*;7-G<W1R(")396QA;6%T(&1A=&%N9R!K92`E<R(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T
M86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE+"`E
M<R(*;7-G<W1R(")396QA;6%T(&1A=&%N9RP@)7,B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$Y-0IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS
M9W-T<B`B5V5S=&5R;B`H25-/+3@X-3DM,2DB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y-@IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,34I(@IM<V=S
M='(@(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED
M(")797-T97)N(%-A:&%R82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC
M871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@
M(D%P86MA:"!A<&QI:V%S:2`E<R!P97)L=2!D:71A;7!I;&MA;B!S971E;&%H
M(&QO9VEN/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS
M9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R
M(")!<&%K86@@>6%N9R!M97)U<&%K86X@8F%T87,@:V%R86MT97(_(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@:7,@
M=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`B07!A:V%H('EA;F<@;65R
M=7!A:V%N(&MA<F%K=&5R(&EN9&5N=&%S:3\B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V,0IM<V=I9"`B5VAE<F5I<R!!
M=7-T<F%L:6$@;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(D9A<V4@>6%N9R!M
M86YA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,PIM<V=I9"`B5VAI
M8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R
M+B(*;7-G<W1R(")0;'5G:6X@;6%N86MA:"!Y86YG(&1A<&%T(&1I86MT:69K
M86X@=6YT=6L@961I=&]R(%)I8V@@5&5X="XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED(")7:61T
M:"(*;7-G<W1R("),96)A<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,C4*(RP@9G5Z>GD*;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G
M<W1R("),96)A<B!U;FET(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N=2!O
M;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB"FUS
M9W-T<B`B(@HB3&5B87(@;65N=2`E<R!P861A(&)A9VEA;B!K:7)I("AA:V%N
M(&)E<G!E;F=A<G5H('!A9&$@;&]G:6X@8F5R:6MU=&YY82DB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B
M5VED=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@(DQE8F%R('1A8F5L(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G
M:60@(E=I9'1H('5N:70B"FUS9W-T<B`B3&5B87(@=6YI="(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED(")7
M:61T:#HB"FUS9W-T<B`B3&5B87(Z(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C4Q,PIM<V=I9"`B5VEK:2(*;7-G<W1R(")7:6MI(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,"!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B5VEN9"(*;7-G<W1R(")!
M;F=I;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8V"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@(D%N9VEN(&1I('!A9VD@
M:&%R:2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#`*;7-G:60@(E=I;F0@
M<W!E960@:6X@:VYO=',B"FUS9W-T<B`B2V5C97!A=&%N(&%N9VEN(&1I(&1A
M;&%M(&MN;W0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U-@IM<V=I9"`B
M5VEN9#HB"FUS9W-T<B`B06YG:6XZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(T,@IM<V=I9"`B5VEN9#H@(@IM<V=S='(@(D%N9VEN.B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M(@IM
M<V=S='(@(DMA=&$@0FEJ86MS86YA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$Y-@IM<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`B1&%F=&%R($ME
M:6YG:6YA;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B
M5V]R:R(*;7-G<W1R(")096ME<FIA86XB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*(RP@9G5Z>GD*;7-G:60@(E=O<FL@
M061D<F5S<R(*;7-G<W1R(")!;&%M870@16UA:6P@06YD82(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O
M<FL@4&AO;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-3
M5BYP:'`Z,38Y(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(V,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI
M;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S`P"B,L('!H<"UF;W)M870*
M;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F
M;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,3$T"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&]F9G-E="`E
M9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#,*;7-G:60@(E@M4F5F(@IM<V=S
M='(@(E@M4F5F(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.3,*;7-G:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,@IM
M<V=I9"`B6#4P.78S($5X=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B
M6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B
M6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#(*;7-G:60@(E@U
M,#EV,R!E>'1E;G-I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C4P"FUS9VED(")962(*;7-G<W1R(")962(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,3,*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-0HC+"!F=7IZ>0IM<V=I9"`B
M65E962(*;7-G<W1R(")962(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,3`X"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z
M-38*;7-G:60@(EEE87)L>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS
M9VED(")996UE;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED(")997,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*
M;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R(")982P@4T%902!315152E4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R
M"FUS9VED(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B
M=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`B(@HB
M06YD82!B97)A9&$@9&D@9&%L86T@34]$12!414M3+B!'=6YA:V%N('1O;6)O
M;"!;/#Y=('5N='5K(&UE;F=G86YT:2!K96UB86QI("(*(FME(&1A;&%M(&UO
M9&4@5UE325=91RXB"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z.#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C
M<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`B06YD82!T:61A
M:R!D:6EZ:6YK86X@=6YT=6L@;65M8G5A="!L96)I:"!D87)I("5D(&%R96$N
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#$Q"FUS9VED(")9
M;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,P,@IM<V=I9"`B66]U(&-A
M;B!N;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA
M;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M-34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW-0HC+"!F=7IZ>0IM<V=I
M9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+B(*
M;7-G<W1R(")096YG9V%N=&D@86QA;6%T(&5M86EL(@H*(SH@9G)A;65W;W)K
M+T1A=&$O1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO
M=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL
M92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX.`IM<V=I9"`B
M66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8Q"FUS9VED("(B"B)9;W4@:&%V92!T
M;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY
M('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA
M;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$X.`IM<V=I9"`B66]U(&AA=F4@=&\@96YT97(@82!V
M86QI9"!V86QU92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!$
M871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0U-@IM<V=I9"`B66]U(&UU
M<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S
M="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H
M92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B(@HB06YD82!H87)U<R!M96YJ
M96QA<VMA;B!M87-A;&%H('-E8F5L=6T@86YD82!D87!A="!M96YG:7)I;6MA
M;B!L87!O<F%N("(*(FUA<V%L86@N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U(&UU<W0@96YT97(@
M=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@(D%N
M9&$@:&%R=7,@;65M87-U:VMA;B!54DP@9&EM86YA(&QI;FL@:6YI(&UE;G5N
M:G5K(&ME(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*;7-G
M:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"XB
M"FUS9W-T<B`B06YD82!H87)U<R!M96UI;&EH('-E<G9E<B!U;G1U:R!D87!A
M="!D:6AA<'5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0IM<V=I9"`B66]U
M(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB"FUS9W-T
M<B`B06YD82!H87)U<R!M96YE=&%P:V%N(&YA;6$@<&5N9V=U;F$@>6%N9R!I
M;F=I;B!D:6)E<G-I:&MA;BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#`*;7-G
M:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N(@IM
M<V=S='(@(D%N9&$@:&%R=7,@;65N971A<&MA;B!N86UA('!E;F=G=6YA('EA
M;F<@:6YG:6X@9&EP:6YD86AK86XN(@H*(SH@861M:6XO=7-E<BYP:'`Z-C(@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS9VED(")9;W4@
M;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@(D%N
M9&$@:&%R=7,@;65N971A<&MA;B!N86UA('!E;F=G=6YA('5N='5K(&1I=&%M
M8F%H+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*;7-G<W1R(")!;F1A
M(&AA<G5S(&UE;F5T87!K86X@;F%M82!P96YG9W5N82!U;G1U:R!D:7!E<F)A
M:&%R=6DN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP
M:'`Z,3,X"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y('=H870@
M86-T:6]N('1O('!E<F9O<FTN(@IM<V=S='(@(D%N9&$@:&%R=7,@;65N971A
M<&MA;B!N86UA('!E;F=G=6YA('EA;F<@:6YG:6X@9&EP:6YD86AK86XN(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z
M-S$*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O
M<GD@;F%M92XB"FUS9W-T<B`B06YD82!H87)U<R!M96YE=&%P:V%N(&YA;6$@
M<&5N9V=U;F$@>6%N9R!I;F=I;B!D:7!I;F1A:&MA;BXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I
M9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I
M<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED(")9;W5R($5M86EL
M($%D9')E<W,B"FUS9W-T<B`B06QA;6%T($5M86EL($%N9&$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C$R"FUS9VED(")9;W5R($9R;VTZ(&%D9')E
M<W,Z(@IM<V=S='(@(D%N9&$@1&%R:3H@86QA;6%T.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S0@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX.0IM<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA
M<VD@06YD82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S
M(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I
M;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G
M:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C,S"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`B3F%M82!!
M;F1A(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C4*(RP@
M9G5Z>GD*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D
M;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@
M(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U
M(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N(&)A8VME
M;F0N(@IM<V=S='(@(B(*(D)A8VME;F0@87-L:2!A;F1A('1I9&%K(&1A<&%T
M(&UE;F1U:W5N9R!P96YA;6)A:&%N('!E;F=G=6YA+"!A=&%U(&9I='5R(&EN
M:2`B"B)S=61A:"!D:6YO;BUA:W1I9FMA;B!U;G1U:R!B96)E<F%P82!A;&%S
M86X@;&%I;BXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC
M.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S
M(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*
M(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS
M9W-T<B`B(@HB0F%C:V5N9"!A<VQI(&%N9&$@=&ED86L@9&%P870@;65N9'5K
M=6YG('!E;F1A9G1A<F%N('!E;F=G=6YA+"!A=&%U(&9I='5R(&EN:2`B"B)S
M=61A:"!D:6YO;BUA:W1I9FMA;B!U;G1U:R!B96)E<F%P82!A;&%S86X@;&%I
M;B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX-`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H
M86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN
M("(*(E1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@
M86=A:6XN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C4P
M"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E
M871U<F4N(@IM<V=S='(@(D)R;W=S97(@86YD82!T:61A:R!M96YD=6MU;F<@
M=6YT=6L@9FET=7(@:6YI+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R
M:6YT+FIS.C0R"B,L(&9U>GIY"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E
M<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O
M;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B(@HB0G)O=W-E
M<B!A;F1A('1I9&%K(&UE;F1U:W5N9R!P:6QI:&%N('5N='5K(&UE;F-E=&%K
M+B!496MA;B!#;VYT<F]L+U!I;&EH86X@*R`B"B)0('5N='5K(&UE;F-E=&%K
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3<*;7-G:60@(EEO=7(@
M8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@(EIO;F$@5V%K='4@06YD82!3
M96MA<F%N9SHB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.38*;7-G:60@(EEO
M=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R
M(")$969A=6QT(&ED96YT:71A<R!A;F1A('-U9&%H(&1I=6)A:"XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34X"FUS9VED(")9;W5R(&1E9F%U;'0@
M:61E;G1I='DZ(@IM<V=S='(@(D1E9F%U;'0@:61E;G1I=&%S(&%N9&$Z(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P,0IM<V=I9"`B66]U<B!F=6QL
M(&YA;64Z(@IM<V=S='(@(DYA;6$@;&5N9VMA<"!A;F1A.B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.C$P,#`*;7-G:60@(EEO=7(@;&]G:6X@:&%S
M(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W
M;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B4V%N9&D@8F%R=2!A;F1A('5N
M='5K("5S(&%D86QA:#H@)7,B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C$U-`IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A
M=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-@HC+"!F
M=7IZ>0IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*
M;7-G<W1R(")$969A=6QT(&ED96YT:71A<R!A;F1A('-U9&%H(&1I=6)A:"XB
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U
M<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="(*;7-G<W1R(")386YD:2!A;F1A
M('-U9&%H(&1I871U<B!U;&%N9R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B965N(')E
M<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE
M=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@HB4V%N9&D@86YD82!S=61A:"!D
M:6%T=7(@=6QA;F<L('!E<FEK<V%L86@@96UA:6P@86YD82!D86X@;&]G:6X@
M9&5N9V%N("(*(FUE;F=G=6YA:V%N('-A;F1I(&)A<G4@86YD82(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.C<S,@HC+"!F=7IZ>0IM<V=I9"`B66]U
M<B!P87-S=V]R9"!H87,@97AP:7)E9"XB"FUS9W-T<B`B4V%N9&D@86YD82!S
M=61A:"!D:6%T=7(@=6QA;F<B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z-3@*;7-G:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@
M(E)E;6]T92!S97)V97(@86YD83HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(U-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS
M9VED(")9=6=O<VQA=FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3@*(RP@9G5Z>GD*;7-G:60@(EIA:7)E(@IM<V=S
M='(@(D-E<F%H(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-38@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB
M"FUS9W-T<B`B0V5R:6$B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL
M=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@
M5&5X=%TB"FUS9W-T<B`B6U-E;6)U;GEI:V%N($EN9&5N=&%S:2!496MS72(*
M"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C@X"FUS9VED(");4')O8FQE;2!2
M97!O<G1=(@IM<V=S='(@(EM,87!O<F%N($UA<V%L86A=(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W
M(%%U;W1E9"!497AT("TB"FUS9W-T<B`B6U1A;7!I;&%N($EN9&5N=&%S:2!4
M96MS("TB"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL
M:6=H='%U;W1E<RYP:'`Z,3<R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(");4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R(");5&%M
M<&EL86X@26YD96YT87-I(%1E:W,@+2(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,3DS"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(");;&EN
M92`E<R!O9B`E<UTB"FUS9W-T<B`B)7,@=6YT=6L@)7,@)7,B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U-#$@=&5M<&QA=&5S+W!O<G1A;"]M
M96YU+FEN8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E]!
M9&UI;FES=')A<VDB"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB
M"FUS9W-T<B`B7T-,22(*"B,Z(&QI8B]A<&DN<&AP.C$T,0IM<V=I9"`B7T1A
M=&%4<F5E(@IM<V=S='(@(E]$871A5')E92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E
M;&5T92!2;W<B"FUS9W-T<B`B2&%P=7,@0F%R:7,B"@HC.B!L:6(O87!I+G!H
M<#HQ,S,*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B7T=R=7`B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3<U"B,L(&9U>GIY"FUS9VED
M(")?2&5L<"(*;7-G<W1R(")"86YT=6%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S"FUS9VED(")?26UA
M9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")0<F]P97)T:2!'86UB87(N+BXB
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DT"B,L(&9U
M>GIY"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(DQO9VEN(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y,`HC+"!F=7IZ>0IM<V=I9"`B
M7TQO9R!O=70B"FUS9W-T<B`B3&]G(&]U="(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO
M9&EF>2!,:6YK+BXN(@IM<V=S='(@(E5B86@@3&EN:RXN+B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-C0*(RP@9G5Z>GD*;7-G:60@
M(E]/<'1I;VYS(@IM<V=S='(@(E!I;&EH86XB"@HC.B!L:6(O87!I+G!H<#HQ
M,S<*;7-G:60@(E]097)M:7-S:6]N<R(*;7-G<W1R("))>FEN(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V
M"FUS9VED(")?4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`B4&EN9&%H:V%N($QI
M;FLN+BXB"@HC.B!L:6(O87!I+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G
M<W1R(")?4V5T=7`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L92!0<F]P97)T:65S
M+BXN(@IM<V=S='(@(E!R;W!E<G1I(%1A8F5L+BXN(@H*(SH@;&EB+V%P:2YP
M:'`Z,3(Y"FUS9VED(")?57-E<G,B"FUS9W-T<B`B4&5N9V=U;F$B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR,0HC+"!F=7IZ>0IM<V=I9"`B
M861D<F5S<R!B;V]K(@IM<V=S='(@(D)U:W4@06QA;6%T("(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,T"FUS9VED(")A9&1R97-S
M964@=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDQ,PHC+"!F=7IZ>0IM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B
M2V%L96YD97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,U.`HC+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM
M<V=S='(@(E1E;F%N9R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,34X"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3(*;7-G:60@(F-L
M:6-K(&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$W.`HC+"!F=7IZ>0IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*
M;7-G<W1R(")097)B961A86X@2V]N9FEG=7)A<VDB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC86P@<WES
M=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M870@97)R
M;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ.#(*(RP@9G5Z>GD*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G
M<W1R(")!8V-O=6YT(%!E;F=G=6YA('1I9&%K(&1I=&5M=6MA;B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")F
M86QL:6YG(@IM<V=S='(@(FIA='5H(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O
M0G)O=W-E<BYP:'`Z.#4U"B,L(&9U>GIY"FUS9VED(")F:6QE(@IM<V=S='(@
M(E1I9&%K(&1I87)S:7!K86XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W
M-"!L:6(O0FQO8VLO;65T87(N<&AP.C,V,"!L:6(O0FQO8VLO;65T87(N<&AP
M.C,X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T
M("5S("5S(@IM<V=S='(@(D1A<FD@)7,@*"5S*2!P861A("5S("5S(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,`IM<V=I9"`B9W5S=&EN
M9R(*;7-G<W1R(")A;F=I;B!K96YC86YG(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T.0IM<V=I9"`B:#HB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U
M.`IM<V=I9"`B:&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N
M<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B;6%S:6@@9&D@9&%L86T@
M86YT<FEA;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,38R"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN
M=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(")L:6YE<UTB
M"FUS9W-T<B`B8F%R:7-=(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*;7-G:60@
M(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,S8Y"FUS9VED(")M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C(Y,2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP
M:'`Z,3<P"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,S(*;7-G
M:60@(FYA;64B"FUS9W-T<B`B;F%M82(*"B,Z(&9R86UE=V]R:R]24$,O4E!#
M+G!H<#HQ,C$*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,3D*;7-G:60@
M(FYO="!Y970@:6UP;&5M96YT960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,#4*(RP@9G5Z>GD*;7-G:60@(FYO=&5P860B
M"FUS9W-T<B`B=&5T87`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED(")P97)C96YT(@IM<V=S='(@
M(G!E<G-E;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,3<T"B,L(&9U>GIY"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R
M("))>FEN('5N='5K(%PB)7-<(B!T:61A:R!D87!A="!D:6AA<'5S+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R(")P:7AE;"(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED(")R96UO=&4@97)R
M;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*;7-G:60@(G)I<VEN9R(*;7-G<W1R
M(")N86EK(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-#(*(RP@9G5Z>GD*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T
M<B`B07)E82!-971A<B!T:61A:R!D:7-E9&EA:V%N+B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z.3D*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B"FUS
M9W-T<B`B=&%M<&EL:V%N('!E<F)E9&%A;B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA
M:6P@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C,X-0IM<V=I9"`B<W,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S(*;7-G
M:60@(G-T96%D>2(*;7-G<W1R(")T971A<"(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,S`Y"FUS9VED(")S=VET8V@@;V9F(&IA=F%S8W)I<'0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR.0IM<V=I9"`B=&%S:R!L:7-T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,38V"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P-0IM<V=I9"`B=')Y(&%G86EN
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&9R86UE=V]R:R]!
M=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(G1Y<&4@=&AE('!A<W-W
M;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B2V5T:6L@<V%N9&D@9'5A
M(&MA;&D@=6YT=6L@;65N9VMO;F9I<FUA<VDB"@HC.B!A9&UI;B]S971U<"]D
M:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B=6YI
M9FEE9"(*;7-G<W1R(")M96YY871U:V%N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]087)T+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B=6YN86UE9"(*;7-G
M<W1R(")N86UA(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C(S"B,L(&9U>GIY"FUS9VED(")U<V5R('-E;&5C
M="(*;7-G<W1R(")(87!U<R!P:6QI:&%N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C,U"B,L(&9U>GIY"FUS9VED(")V0V%R
M9"(*;7-G<W1R(")+87)A:W1E<B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR-#$*;7-G:60@(G<Z(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED(")W96%T:&5R
M+F-O;2(*;7-G<W1R(")W96%T:&5R+F-O;2(*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+W)O7U)/+G!O````````````````
M````````````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#8Q,34R,2`Q
M,#4Q-30S,S<T,B`P,3<U-#,`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````(R!(;W)D92!2;VUA;FEA;B!T<F%N<VQA=&EO;BX*
M(R!#;W!Y<FEG:'0@*$,I(#(P,#(@2&]R9&4@4')O:F5C="X*(R!#;W)N96QI
M=2!-55-!5"`\8VUU<V%T0&ME>7-Y<RYR;SXL(#(P,#(N"B,*;7-G:60@(B(*
M;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($A/4D1%(#(N,5QN(@HB
M4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*
M(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*
M(E!/+5)E=FES:6]N+41A=&4Z(#(P,#(M,#@M,#$@,#DZ,S0K,#(Z,#!<;B(*
M(DQA<W0M5')A;G-L871O<CH@0V]R;F5L:74@3553050@/&-M=7-A=$!K97ES
M>7,N<F\^7&XB"B),86YG=6%G92U496%M.B!23TU!3DE!3B`\:3$X;D!L:7-T
M<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N
M="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3%<;B(*(D-O
M;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(S-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E
M<R!D87ES(&%G;RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ,S<P"B,L('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y
M("5S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S<W"B,L('!H<"UF;W)M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,PIM<V=I9"`B
M("AT;V1A>2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C,W-0IM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,0IM<V=I9"`B("AY97-T97)D87DI
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-38@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,0HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`W"FUS9VED("(@870@(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C$U"B,L('!H<"UF
M;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E8W1O<GDN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H
M<#HV-3D*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ
M,#0R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T
M(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*;7-G<W1R("(G
M)7,G(&YU(&5S=&4@8V]N9FEG=7)A="!I;B!(;W)D92!296=I<W1R>2(*"B,Z
M(&9R86UE=V]R:R]4<F5E+U1R964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4R"B,L('!H
M<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE('!E<FUI
M<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HU-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E
M*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C,W"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C(V."!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-34W"B,L('!H<"UF;W)M870*;7-G:60@(B5D
M(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@U"B,L('!H<"UF
M;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HW,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z.#,S(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C@S-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I
M<FUA=&EO;B(*;7-G<W1R("(E<R!/<&5R871I=6YI(&1E(&UE;G1E;F%N=&$@
M+2!#;VYF:7)M87)E(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(%-E='5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M4VEG;G5P+G!H<#HR-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5
M<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#(X(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DP"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z-C4Q(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S$Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U.2!L:6(O0FQO8VLO
M;65T87(N<&AP.C$V-2!L:6(O0FQO8VLO;65T87(N<&AP.C(S.0HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,T-2!L:6(O0FQO8VLO;65T87(N<&AP.C,U,0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE
M("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F
M;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B0FEF871I(&]P97)A=&EU;BAE
M82]I;&4I('!E(&-A<F4@9&]R:71I('-A(&QE(&9A8V5T:2!A8W5M+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR.#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S
M(&UI;G5T97,B"FUS9W-T<B`B3&$@9FEE8V%R92`U(&UI;G5T92(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,C,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHT"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R(");;&EN:6$@
M)7,@9&EN("5S72(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(R
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@0F]O
M:R(*;7-G<W1R(")!9V5N9&$B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDQ-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE
M;F1A<B(*;7-G<W1R(")#86QE;F1A<B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z.3`V"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VAT;6PN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI
M<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B
M92X@0F5W87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@
M;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF
M;W)M871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS-C4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q,`IM
M<V=I9"`B+"!G=7-T:6YG("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$X."!L:6(O0FQO8VLO;65T87(N<&AP.C$Y,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(L(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V
M87)I86)L92!F<F]M("5S('1O("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,CDT(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,S0X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-CD@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$R.`HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-S0Y"FUS9VED("(M+2!S96QE8W0@
M+2TB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P"B,L(&9U
M>GIY"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R("));F9O<FUA=&EI
M(&1E<W!R92!T:6YE(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y"B,L(&9U
M>GIY"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R("));F9O<FUA=&EI
M(&1E<W!R92!T:6YE(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*
M;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T(&1E(&]R92(*"B,Z(&9R86UE
M=V]R:R]522]522]086=E<BYP:'`Z-CD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q.0IM<V=I9"`B02!D
M871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V,`HC
M+"!F=7IZ>0IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS
M9W-T<B`B/&(^02!A<&%R=70@;R!E<F]A<F4@9F%T86QA.CPO8CXB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B
M;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$Q-C4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@
M=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P.3<*;7-G:60@(B(*(D$@<'5B
M;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#$U"FUS
M9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU,#4*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A
M=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L
M:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S8T
M"FUS9VED(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC
M<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.CD*;7-G:60@(D%-($-L;W5D<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ,`IM<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@
M4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PIM<V=I
M9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D
M871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R(")!32]032(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H
M:7,@961I=&]R(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N
M<&AP.C4R"FUS9VED(")!8F]U="XN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T"FUS9VED(")!8G-B
M;W1T;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED9&QE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-S`*;7-G:60@(D%C
M8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B
M06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(D%C
M8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M871I:2!D97-P<F4@
M=&EN92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-0HC+"!F=7IZ>0IM
M<V=I9"`B06-C;W5N="!087-S=V]R9"(*;7-G<W1R(")087)O;&$B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*
M;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S,S"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30X('1E
M;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B061D(@IM
M<V=S='(@(D%D<F5S82(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T(&%D;6EN
M+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY."!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDY"FUS9VED(")!9&0@0VAI;&0@
M4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D
M9"YI;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B061D($AE<F4Z(@IM<V=S='(@(D%D
M<F5S82(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP
M:'`Z,C$Y"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HX.`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N
M:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@
M=&\@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD
M('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-`IM
M<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V5D:70N:6YC.C,T"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHY-0IM
M<V=I9"`B061D('!A:7(B"FUS9W-T<B`B061A=6=A('!E<F5C:&5A(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C<Q"B,L(&9U>GIY"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G
M<W1R(")!9V5N9&$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z-S@*(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S
M(&)O;VLB"FUS9W-T<B`B06=E;F1A(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*
M(RP@9G5Z>GD*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(D%D875G82!P97)E
M8VAE82(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@
M;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N
M(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B061D960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G
M(&EN(&YO=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;F]A9&0N:6YC.C(*;7-G:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$R-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3<S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#$*;7-G:60@
M(D%D9')E<W,B"FUS9W-T<B`B061R97-A(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$S.0HC+"!F=7IZ>0IM<V=I9"`B061D<F5S<R!";V]K(@IM
M<V=S='(@(D%G96YD82(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.CDT"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I
M;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]I;F1E
M>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM<V=I
M9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,T,0HC+"!F=7IZ>0IM<V=I9"`B061S(@IM<V=S='(@
M(D%D<F5S82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3<*(RP@9G5Z>GD*;7-G:60@(D%L8F%N:6$B"FUS
M9W-T<B`B06QI87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"B,L(&9U>GIY"FUS9VED(")!;&=E
M<FEA(@IM<V=S='(@(D%L:6%S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T<B`B06QI
M87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C$V"B,L(&9U>GIY"FUS9VED(")!;&EG;B(*;7-G<W1R(")!;&EA
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-C<*;7-G:60@(D%L:6=N;65N=#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C@W"FUS9VED(")!;&PB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B
M"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U
M<',N<&AP.C(R,@IM<V=I9"`B06QL($=R;W5P<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDQ(&9R86UE=V]R:R]097)M
M<R]097)M<R]D871A=')E92YP:'`Z-S4*;7-G:60@(D%L;"!097)M:7-S:6]N
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<Q"FUS9VED
M(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4S-`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O
M9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS9VED(")!;')E861Y
M(&5X:7-T<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3(S"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`W"FUS9VED(")!;'1E<FYA=&4@
M24U34"!087-S=V]R9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#DY"FUS9VED(")!;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS-0HC+"!F
M=7IZ>0IM<V=I9"`B06QT97)N871E(&5M86EL(&%D9')E<W,B"FUS9W-T<B`B
M061R97-A('1A(&1E($5M86EL.B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M,30R"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z.34@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@
M=V%S('-P96-I9FEE9"XB"FUS9W-T<B`B4RUA('-P96-I9FEC870@;R!V86QO
M87)E(&EN8V]R96-T82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,38W"B,L(&9U>GIY"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O
M8V-U<F5D+B(*;7-G<W1R("(\8CY!(&%P87)U="!O(&5R;V%R92!F871A;&$Z
M/"]B/B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%N9&]R<F$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU.`IM<V=I9"`B06YG;VQA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3<*;7-G:60@(D%N9W5I;&QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM
M<V=I9"`B06YS=V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N
M=&%R8W1I8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B06YT:6=U
M82!A;F0@0F%R8G5D82(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N
M<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS-0HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO54DN<&AP.C4X('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E
M>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(B(*"B,Z('5T
M:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC871I;VX@3&ES
M="(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,30P"FUS
M9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O($-H
M:6QD(%-H87)E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S,*;7-G:60@
M(D%P<')O>&EM871E(%-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-`HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<U"FUS9VED(")!<F%B
M:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C8V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#$*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-3@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-0HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@P"FUS9VED(")!
M<F-H:79E($YA;64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!
M<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q
M=65S="!F;W(@)7,@/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@
M>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E(%PB)7-<(B!A;F0@86YY('-U
M8BUG<F]U<',_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%R9V5N
M=&EN82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!<FUE;FEA(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<V"FUS9VED(")!
M<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4Y"FUS9VED(")!<G5B82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C
M:6D@07)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU-0IM<V=I9"`B07-I82]086-I9FEC(%)E9VEO;B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(U"FUS9VED(")!<VL@9F]R
M(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T
M:6]N<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S$Q,PIM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E
M(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P
M97)M<R]D96QE=&4N<&AP.C(Y"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A
M(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]P97)M<R]E9&ET+G!H<#HX-PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@
M;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I9"`B071T96UP="!T;R!E9&ET
M(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8T(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HX-@IM<V=I9"`B071T<FEB=71E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`X"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M,@IM<V=I9"`B075G=7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@
M(D%U<W1R86QI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T
M<FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L
M+G!H<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER=7,N<&AP.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C
M:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,C(*
M;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]F
M='`N<&AP.C,V"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA
M8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O:6UA<"YP:'`Z-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER
M960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR
M8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,#(*;7-G
M:60@(D%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@
M9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HS-3<*;7-G:60@(D%U=&A?;&1A<#H@4F5M
M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C
M=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C8S"FUS9VED(")!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HS,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L
M9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD
M87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0Y.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0P
M-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P
M<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C0V"FUS9VED(")!=71H7VUC
M86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C8P"FUS9VED
M(")!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")!=71H96YT:6-A=&EO
M;B!F86EL960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B075T:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H
M96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@U,0IM<V=I9"`B
M075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-S`*;7-G:60@(D%U
M=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I9"`B
M079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`B0VEM<'5R:2!D:7-P;VYI8FEL
M93HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I9"`B0D]&2"!%>&-U
M<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@Q"FUS9VED(")"860@:V5R
M8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F%H86UA<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"86AR86EN(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<W"FUS9VED(")"86QT:6,@*$E3
M3RTX.#4Y+3$S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"86YG
M;&%D97-H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S
M(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S(&1I<F5C=&]R>2!<(B5S
M7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*;7-G:60@(D)A<V5L:6YE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&%R=7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8S"FUS9VED(")"96QI>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,0IM<V=I9"`B0F5N:6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HT,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B
M0F5R;75D82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")":'5T86XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B6FEU82!D92!N
M87-T97)E(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN
M<&AP.C,U,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0FQO8VL@7"(E
M<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@
M(DYO=&EF:6-A=&EO;B!L:7-T96YE<B`E<R!N;W0@9F]U;F0N("T@9&4@=')A
M9'5S(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C@Y"FUS9VED
M(")";&]C:R!3971T:6YG<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M"FUS9VED(")";VQD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O
M;&EV:6$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(P-0IM<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*(RP@9G5Z
M>GD*;7-G:60@(D)O<F1E<B(*;7-G<W1R(")(;W)D92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E
M<B!T:&EC:VYE<W,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*(RP@9G5Z>GD*;7-G:60@
M(D)O<F1E<G,B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"
M;W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8S"FUS9VED(")";W1S=V%N82(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(R"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@
M(D)O='1O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V970@
M27-L86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@
M(D)R87II;"(*;7-G<W1R(")#;W)E<W!O;F1E;G1A(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HT,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*
M;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<G5N96D@1&%R=7-S86QA;2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=6QG87)I82(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y
M"FUS9VED(")"=6QL971E9"!,:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HT-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*
M;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS
M9VED(")"=7)U;F1I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT-#0*(RP@9G5Z>GD*;7-G:60@(D--4R(*;7-G<W1R(")#5E,B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS
M9VED(")#4D,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,38S"FUS9VED(")#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#@T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.#<*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$U-0IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B
M0V%L96YD87(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0V
M"FUS9VED(")#86QM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")#
M86UB;V1I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#86UE<F]O
M;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR
M,`IM<V=I9"`B0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY
M+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S$X"B,L('!H<"UF;W)M870*
M;7-G:60@(D-A;B!N;W0@=W)I=&4@=&\@9FEL92!<(B5S7"(B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(R"FUS9VED(")#86XG="!A9&UI
M;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(S-2!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,S$Y"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(*
M;7-G<W1R(").=2!M82!P;W0@8V]N96-T82!L82!S97)V97)U;"!D92!,1$%0
M+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0Q,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")#86XG="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8T"B,L(&9U>GIY"FUS9VED(")#86YA9&$B"FUS9W-T
M<B`B0V%L96YD87(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E
M<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHV-0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z
M,3$@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU
M.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(E)E;G5N
M=&$@;&$@4F%P;W)T(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS
M,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R
M871E9WDO8V]P>2YP:'`Z-3(*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M<&]R
M87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T('!R;V-E
M960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92YP:'`Z
M,3(X(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8X,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E
M;B!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A
M=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B"B)#86YN;W0@<F5O<F1E<BP@
M;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N
M;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS
M9VED(")#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#87!E(%9E<F1E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C0*(RP@9G5Z>GD*;7-G:60@(D-A<'1I;VXB"FUS9W-T
M<B`B3W!T:75N:2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC
M7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R<FEE<B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`*;7-G:60@(D-A=&5G;W)I97,@86YD
M($QA8F5L<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y;6%N
M($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L;"!0:&]N92(*;7-G<W1R
M(")496QE9F]N($UO8FEL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0HC+"!F=7IZ>0IM<V=I9"`B0V5L;"!0
M<F]P97)T:65S(@IM<V=S='(@(E1E;&5F;VX@36]B:6PB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L
M;"!P861D:6YG.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E
M<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(W-`HC+"!F=7IZ
M>0IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(E1E;&5F;VX@36]B:6PB"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B0V5L=&EC("A)4T\M
M.#@U.2TQ-"DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-E;G1R86P@069R:6-A;B!297!U
M8FQI8R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.0IM
M<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.3D*;7-G
M:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3$*;7-G:60@(D-E<G1I9FEC
M871E($]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3DV"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*(RP@9G5Z>GD*;7-G:60@(D-H860B
M"FUS9W-T<B`B=D-A<F0@+2!D92!T<F%D=7,B"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.CDV"B,L(&9U>GIY"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B06YU;&5A>F$@
M4V-H:6UB87)I;&4B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M,S$*;7-G:60@(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@IM<V=I9"`B(@HB0VAA;F=E('1H
M92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@
M<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB
M0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@
M=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(W"B,L(&9U>GIY"FUS9VED
M(")#:&%R(@IM<V=S='(@(G9#87)D("T@9&4@=')A9'5S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS
M9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"B,L
M(&9U>GIY"FUS9VED(")#:&EL92(*;7-G<W1R(")4:71L=2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@P"FUS9VED(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@
M(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(D-H;V]S
M92!A('!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O4VEG;G5P+G!H<#HR-C@*;7-G:60@(D-H;V]S92!A('5S97)N86UE(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.3@*;7-G:60@
M(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SHB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R
M960@;&ES=',I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H<FES
M=&UA<R!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+G!H<#HR.30@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@Y,PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N
M;W0@9F]U;F0N(@IM<V=S='(@(DYO=&EF:6-A=&EO;B!L:7-T96YE<B`E<R!N
M;W0@9F]U;F0N("T@9&4@=')A9'5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,30*(RP@9G5Z>GD*;7-G:60@(D-L96%R(@IM
M<V=S='(@(D-A;&5N9&%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"FUS9VED(")#
M;&5A<B!1=65R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]C;&5A<BYI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@
M=7-E<CH@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M8VQE87(N:6YC.C$Q"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T"FUS9VED(")#;&5A
M<B!U<V5R(&1A=&$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,34*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E
M+FAT;6PZ-C`*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R("));F-H
M:61E(&9E<F5A<W1R82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0T"FUS
M9VED(")#;&]U9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,38*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G
M:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,C,*;7-G:60@(D-O;&QA<'-E
M(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O
M<F1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]L;VUB:6$B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO
M8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C0*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-0HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`P('-E
M<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R
M(%!I8VME<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.#0V"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"FUS
M9VED(")#;VQS.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.30V"FUS9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C0*;7-G:60@(D-O;6EC<R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*(RP@9G5Z>GD*
M;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`B0V]M<&%N:6$B"@HC.B!A9&UI;B]C
M;61S:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED
M(")#;VUM96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-38V"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX-`IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED
M(")#;VUP86YY(@IM<V=S='(@(D-O;7!A;FEA(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y-PIM<V=I9"`B0V]N9&ET
M:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0Y"FUS
M9VED(")#;VYD:71I;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I
M9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#,*;7-G:60@
M(D-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H
M;VYE<R!A;F0@3W5T;&]O:RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$S-0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@
M9&%T92XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$P
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,0HC+"!F
M=7IZ>0IM<V=I9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R(")087)O;&$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8V"FUS9VED(")#;VYG;R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8U"FUS9VED(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@
M=&AE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ
M.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P
M"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C
M=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-#4*;7-G:60@(D-O;FYE
M8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#$T"FUS9VED(")#;VYT86-T<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D
M('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4V(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HW.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@(D-O;G1I;G5T=6P@;'5I
M("<E<R<@+2!D92!T<F%D=7,B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HR.2!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S,*;7-G:60@
M(D-O;G1I;G5E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;VL@
M27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C$*(RP@9G5Z>GD*
M;7-G:60@(D-O<'DB"FUS9W-T<B`B0V]M<&%N:6$B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C0V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@(D-I;7`@:6UP;W)T870Z("5S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-S`*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDW-@IM
M<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P-3,*;7-G
M:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I9"`B
M0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED
M(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ
M.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T
M+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z.38@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ,C$*(RP@
M9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(*
M;7-G<W1R(").=2!M82!P;W0@8V]N96-T82!L82!S97)V97)U;"!D92!,1$%0
M+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-3<*;7-G:60@(D-O=6QD
M(&YO="!B:6YD('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@
M)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0T,0HC
M+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@;&1A<"!S97)V
M97(B"FUS9W-T<B`B3G4@;6$@<&]T(&-O;F5C=&$@;&$@<V5R=F5R=6P@9&4@
M3$1!4"XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<
M(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$Q,C4*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R
M,@IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,C0V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE
M=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R
M861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.CDU,PIM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@
M<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"FUS
M9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C0Y,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E
M(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I9"`B0V]U
M;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO
M;B!L:7-T<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A
M9"!S=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HQ,3`*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Q.0IM<V=I9"`B
M0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E
M<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I
M;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT
M96YA;F-E+TUA:6YT96YA;F-E+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B
M"FUS9W-T<B`B3G4@<&]T(&1E<V-H:61E(&UO9'5L=6P@9&4@365N=&5N86YT
M82`E<R(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HW,`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB
M"FUS9W-T<B`B3G4@<&]T(&1E<V-H:61E(&UO9'5L=6P@9&4@365N=&5N86YT
M82`E<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3$@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C,W(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HT-S@*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C4Q-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C$R
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-38@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Y.0HC+"!F=7IZ>0IM<V=I9"`B
M0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3G4@
M;6$@<&]T(&-O;F5C=&$@;&$@<V5R=F5R=6P@9&4@3$1!4"XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(S.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD(&YO="!R
M97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M
M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4
M<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U
M(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#D*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0P"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-PHC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#,*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y"FUS9VED(")#;W5L9"!N;W0@<F5T
M<FEE=F4@04-,(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO
M;B!L:7-T<RX@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HR,C,*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!S
M97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E
M=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")(;W)D92!N=2!E<W1E(&-O
M;F9I9W5R870@8V]R97-P=6YZ871O<B(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HY
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@7"(E<UPB
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3D*;7-G:60@(D-O=6QD(&YO
M="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.34*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HV-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO
M;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92`B"B)O
M<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA
M;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$T,PHC+"!F=7IZ>0IM<V=I
M9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@
M(DYU(&UA('!O="!C;VYE8W1A(&QA('-E<G9E<G5L(&1E($Q$05`N(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C@V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,SDV"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A
M=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8V"FUS9VED(")#
M;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T
M:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T:&4@9F]L;&]W
M:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,3D*;7-G:60@(D-O
M=6YT960@=&5X="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4V.0IM<V=I9"`B0V]U;G1R>2(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C<S"FUS9VED(")#;W5R<V5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR
M,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I9"`B0W)E871E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV.`IM<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDT"FUS9VED
M(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR"FUS9VED(")#<F5A=&4@<W5B
M(&9O;&1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HR-#`*;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(S,`IM<V=I9"`B
M0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS
M9VED(")#<F]A=&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-U
M8F$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(V"FUS9VED
M(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I
M;VYS+G!H<#HT.`IM<V=I9"`B0W5R<F5N="!397-S:6]N<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z
M,S`*;7-G:60@(D-U<G)E;G0@5&EM92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-30*;7-G
M:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I
M;VYS+G!H<#HS,PIM<V=I9"`B0W5R<F5N="!5<V5R<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS9VED(")#=7)R96YT(%=E871H
M97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(W-0IM<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,R"FUS
M9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE
M('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C`*;7-G:60@(D-U="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,U"FUS9VED(")#=70@<V5L96-T
M:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-Y<')U<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,@IM<V=I9"`B0WER
M:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#,*;7-G:60@(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@T"FUS9VED(")#>7)I
M;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C8W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M.0IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,2!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHU,`IM<V=I9"`B1$0B"FUS9W-T<B`B6EHB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@Q"FUS9VED("(B"B)$4TX@*'-E92!H
M='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E
M+F1B+FEN=')O+61S;BYP:'`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3D*;7-G:60@(D1A:6QY(@IM
M<V=S='(@(EII;&YI8R(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I
M9"`B1&%T851R964@0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,C<Y"FUS9VED(")$871A8F%S92!,;V]K=7`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R
M+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,SDY"FUS9VED(")$
M871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O
M=F4N:6YC.C$S"FUS9VED(")$871E(%)E8V5I=F5D(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#<*;7-G:60@(D1A=&4@<V5L
M96-T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.3(@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,R,@HC+"!F
M=7IZ>0IM<V=I9"`B1&%Y(@IM<V=S='(@(EII;&YI8R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@IM<V=I
M9"`B1&5?;&5T92!#;VQU;6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ.#<@;&EB+W!R969S+G!H
M<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B261E;G1I
M=&%T92!);7!L:6-I=&$B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHT-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHW-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!#;VQO
M<B(*;7-G<W1R(")5=&EL:7IE87IA(%9A;&]R:2!);7!L:6-I=&4B"@HC.B!F
M<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.CDQ"FUS9VED(")$969A
M=6QT($ED96YT:71Y(@IM<V=S='(@(DED96YT:71A=&4@26UP;&EC:71A(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")$
M969A=6QT(%-H96QL(@IM<V=S='(@(DED96YT:71A=&4@26UP;&EC:71A(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I;FET:6]N
M<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Q(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,S(V"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z-#(R(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#,Y
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S8@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHW,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.CDS('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$V"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3,Y('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3@R"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,R!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3@*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]D96QE=&4N:6YC.C$P('1E;7!L871E<R]A9&UI;B]U<V5R+VQI
M<W0N:6YC.C,Q"FUS9VED(")$96QE=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"FUS
M9VED(")$96QE=&4@0V5L;"(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C$Y.2!A9&UI;B]G<F]U<',N<&AP.C(R-PIM<V=I9"`B1&5L971E($=R
M;W5P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(T.0IM<V=I9"`B1&5L971E($QO9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<W(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,3`Q"FUS9VED(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M,PIM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4W"FUS9VED(")$96QE=&4@8V5L;"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8S"FUS
M9VED(")$96QE=&4@8V]L=6UN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z,30X"FUS9VED(")$96QE=&4@97AI<W1I;F<@86QT97)N871E
M('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z-#(Q"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M
M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z-#(T"B,L('!H<"UF;W)M870*;7-G:60@(D1E
M;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI
M<W-I;VYS/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@<F]W(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I9&5N=&ET>2YI
M;F,Z,34*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET
M>2(*;7-G<W1R("))9&5N=&ET871E($EM<&QI8VET82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I
M9"`B1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C,*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-38S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3DU"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(R,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*;7-G:60@(D1E;&EV97)Y('1I;64B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHR.0IM<V=I
M9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`B1&5S8W)I92!P<F]B
M;&5M82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDS."!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,P"B,L(&9U
M>GIY"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R(")$97-C<FEE<F4@8V]M
M<&QE=&$Z(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.34*;7-G
M:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3D*;7-G:60@
M(D1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T
M;W(N(@IM<V=S='(@(D1E=&%L:6D@:6YR96=I<W1R871E(&EN($Q/1R!P96YT
M<G4@861M:6YI<W1R871O<BXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C$Y"FUS9VED(")$979E;&]P;65N="(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(Q-PIM<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDT"FUS9VED(")$97<@4&]I
M;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,C<*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L969T(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V-@IM<V=I
M9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3<*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*
M;7-G<W1R(")/<'1I=6YI(&1E($%F:7-A<F4B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@9&5T
M86EL960@9F]R96-A<W0B"FUS9W-T<B`B3W!T:75N:2!D92!!9FES87)E(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX-0IM<V=I9"`B1&ES<&QA>2!F;W)E
M8V%S="`H5$%&*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.#$W"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G
M<W1R(")/<'1I=6YI(&1E($%F:7-A<F4B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TU$3BYP:'`Z,3DP"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC871I
M;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&II8F]U=&DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(*
M;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C
M97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R(")492!R;V<@;G4@86-C97-A
M(&1I<F5C="!M86EN=&5N86YC92YP:'`B"@HC.B!T96UP;&%T97,O9&%T82]T
M<W9I;F9O+FEN8SHQ,B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,@IM
M<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA
M;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P
M"FUS9VED(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY-@IM<V=I9"`B1&]N)W0@:&%V92!A
M;B!A8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*;7-G:60@(D1O=VYL;V%D(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.C@T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N
M;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`W"FUS
M9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PHC+"!F=7IZ>0IM<V=I
M9"`B12U-86EL(@IM<V=S='(@(D-O<F5S<&]N9&5N=&$B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B14UA
M:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@
M<')O=FED92!T:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP
M:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED
M(")%8W5A9&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW
M,@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z
M-3`@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="!"
M;&]C:R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y."!A9&UI
M;B]G<F]U<',N<&AP.C(R-@IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<V(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,3`P"FUS9VED(")%9&ET(%!E<FUI<W-I
M;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S
M-PIM<V=I9"`B161I="!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R
M(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@
M9F]R("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M-0IM<V=I9"`B161U8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HW,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G
M:60@(D5G>7!T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,S$P"B,L('!H<"UF;W)M870*;7-G:60@(D5I=&AE<B!E;F%B;&4@
M:70@=&AE;CH@)7,L(&]R('5S92!T:&4@8F%S:6,@2%1-3"!V97)S:6]N.B`E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")%;"!386QV861O
M<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@V.0IM<V=I9"`B16UA:6PB"FUS9W-T<B`B16UA:6PB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-2!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V5D:70N:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z-C@*(RP@9G5Z>GD*;7-G:60@(D5M86EL($%D9')E
M<W,B"FUS9W-T<B`B061R97-A('1A(&1E($5M86EL.B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y-C,*;7-G:60@(D5M86EL(&%D9')E<W-E<R!M
M=7-T(&UA=&-H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.3@Y"B,L(&9U>GIY"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA
M=&EO;B(*;7-G<W1R(")!;'1E(&EN9F]R;6%T:6DB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA:6PM
M=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y.`HC+"!F=7IZ>0IM<V=I9"`B16UO
M=&EC;VYS(@IM<V=S='(@(D]P=&EU;FDB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*(RP@9G5Z>GD*;7-G:60@
M(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(D5M<'1Y(')E<W5L="X@+2!D92!T
M<F%D=7,B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C0S
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT.#0*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8V,B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z,34P"FUS9VED(")%;7!T>2!R97-U;'0N(@IM<V=S='(@(D5M<'1Y
M(')E<W5L="X@+2!D92!T<F%D=7,B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+
M97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T,PIM<V=I9"`B
M16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I
M97,@:6X@=&5X=#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4Q.`IM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N
M=3\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y
M."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$Q"FUS9VED(")%;F0@>65A
M<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(Q"FUS9VED("(B"B)%;G1E
M<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D
M(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@
M)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C@Y,0IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES
M=&5N97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4U"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S8@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H
M<#HX,@IM<V=I9"`B17)R;W(B"FUS9W-T<B`B17)O87)E(@H*(SH@9G)A;65W
M;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B17)R;W(@8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C<R"B,L('!H<"UF;W)M870*
M;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT
M.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=7!D871I;F<@<&%S
M<W=O<F0Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET:"!E
M;6%I;"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@7"(E<UPB
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%<W1O;FEA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM
M<V=I9"`B175R;W!E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS,SD*;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`B3R!D
M871A(&QA(#$U(&UI;G5T92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.#D*(RP@9G5Z>GD*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R("),
M82!F:65C87)E(#4@;6EN=71E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,S-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@W"FUS9VED(")%=F5R>2`S
M,"!S96-O;F1S(@IM<V=S='(@(D\@9&%T82!L82`S,"!S96-U;F1E(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S."!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,SDP"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B3&$@9FEE
M8V%R92`U(&UI;G5T92(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN
M=&5N86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S='(@(DQA
M(&9I96-A<F4@0V]N96-T87)E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,T,`IM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(D\@9&%T82!L
M82`S,"!M:6YU=&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,W(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#@*;7-G:60@(D5V97)Y(&UI;G5T92(*
M;7-G<W1R("));B!F:65C87)E(&UI;G5T(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T96UA<"YI;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R
M(")%>&5M<&QE(&1E('9A;&]R:3HB"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z
M.#$@861M:6XO8VUD<VAE;&PN<&AP.C4P(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,C<*;7-G:60@(D5X96-U=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#<U"FUS9VED(")%>'!A;F0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHS,@IM<V=I
M9"`B17AP86YD(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-1
M3"]344PO2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP96-T960@)RDG(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ
M-S4*;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H
M('1E<FTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$R"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S8*;7-G:60@
M(D5X<&]N96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S<*;7-G:60@
M(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+W-Q;"YP:'`Z,C$V"FUS9VED(")&86EL960@<F5T<FEE
M=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`B3G4@<&]T(&-I=&D@<')E9F5R
M:6YT96QE+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW
M-2!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.CDX"FUS9VED(")&86EL
M960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3G4@;6$@
M<&]T(&-O;F5C=&$@;&$@<V5R=F5R=6P@9&4@3$1!4"XB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-M8BYP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@(D9A:6QE
M9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM<V=S='(@(DYU(&UA('!O
M="!C;VYE8W1A(&QA('-E<G9E<G5L(&1E($Q$05`N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HV.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I
M;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z-CDQ"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")&86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(DYU
M(&UA('!O="!C;VYE8W1A(&QA('-E<G9E<G5L(&1E($Q$05`N(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O
M(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y-R!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C<R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I
M;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R(").=2!M82!P;W0@8V]N
M96-T82!L82!S97)V97)U;"!D92!,1$%0+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z-#8Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&
M86EL960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(DYU('!O="!C:71I('!R
M969E<FEN=&5L92XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R
M"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C,X"B,L(&9U>GIY"FUS9VED
M(")&871A;"!%<G)O<CHB"FUS9W-T<B`B17)O87)E(&1E(&EN=')A<F4Z(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM
M<V=I9"`B1F%X(@IM<V=S='(@(D9A>"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS-#D*(RP@9G5Z>GD*;7-G:60@(D9A>&5S(@IM<V=S='(@(D9A
M>"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V
M"FUS9VED(")&96)R=6%R>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(R,`IM<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS9VED(")&965L<R!L
M:6ME.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS
M9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y-#0*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,T"FUS9VED
M(")&:6=L970@0T%05$-(02(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,S,X"FUS9VED(")&:6=L970@9F]N="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B1FEL
M92(*;7-G<W1R(")4:71L=2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P-PIM<V=I9"`B
M1FEL92!-86YA9V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C,@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HW,`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C@U"B,L(&9U>GIY"FUS9VED(")&:6QE($YA;64B"FUS9W-T<B`B
M3G5M92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y.34*;7-G:60@
M(D9I;&4@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T.#8*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U.0IM<V=I9"`B
M1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX.0IM<V=I9"`B1FEL=&5R<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")&:6YL86YD(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA;&8B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C
M:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A<G1E<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4V
M"FUS9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,0IM<V=I9"`B1FQI<"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C,T
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,#<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*
M;7-G:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M-@IM<V=I9"`B1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G
M97,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,S0*;7-G
M:60@(D9O<F5C87-T("A4048I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HW.0IM<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H
M;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@
M9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G92!N=6UB97(@:&5R92!C;W5L9"!R
M97-U;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C$P,@IM<V=I9"`B1F]R9V]T('EO=7(@<&%S
M<W=O<F0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT-C(*;7-G:60@(D9O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*(RP@9G5Z
M>GD*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(DYO=&4B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U,PIM<V=I9"`B1F]R
M=6US(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ
M,#D*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S,*(RP@9G5Z>GD*;7-G:60@(D9R86UE<R(*;7-G<W1R(").
M=6UE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E
M+"!-971R;W!O;&ET86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B
M1G)E;F-H($=U:6%N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B
M1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G
M:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS
M9VED(")&<F]M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-#@@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,`HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`V"FUS9VED(")&<F]M
M('1H92`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z-#@*(RP@9G5Z>GD*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS
M9W-T<B`B1&5S8W)I97)E(&-O;7!L971A.B(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HX,2!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<V"FUS9VED(")&=6QL($UO
M;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*(RP@9G5Z>GD*;7-G
M:60@(D9U;&P@3F%M92(*;7-G<W1R(").=6UE;&4@=&%U.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B
M1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS
M9VED(")'86UB:6$B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#;VYF
M:6=U<F%T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U
M<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDP(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<T"FUS9VED(")'96]R9VEA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.CDQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B
M1VEB<F%L=&%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3<U"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$R"FUS9VED(")';R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O
M961E;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3$R.`IM<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE
M(%-E87)C:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C,W"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965C92(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B1W)E96L@*$E33RTX.#4Y
M+3<I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=R965N;&%N9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'<F5N861A(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y"FUS9VED(")'<F]U<"!!9&UI
M;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`N<&AP.C4Y(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-CD*
M;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G
M<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3@@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G
M:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,S
M."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O
M=7`@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HS,30@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W
M"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W,`HC
M+"!F=7IZ>0IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(D%G96YD82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S4*;7-G:60@(D=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S@*;7-G:60@(D=U:6YE82U":7-S874B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<X"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.38P"FUS9VED(")(5$U,(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*
M;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H
M92!L87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS9VED(")(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C
M;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@(DA434Q!
M<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I
M;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H
M='1P+G!H<#HQ-3<*;7-G:60@(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAA:71I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q
M,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA>F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3$Y(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S(*;7-G:60@(DAE861E<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N
M<&AP.C8Q"FUS9VED(")(96%D97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(S"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@V"FUS9VED(")(96)R97<@*$E33RTX.#4Y
M+3@M22DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ-SD@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$X-@HC.B!S97)V:6-E<R]H
M96QP+VEN9&5X+G!H<#HQ-R!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z,PIM
M<V=I9"`B2&5L<"(*;7-G<W1R(")(96QP(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E
M9&ET;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3,W,0HC+"!F=7IZ>0IM<V=I9"`B2&5L<&5R(@IM<V=S='(@(DAE;'`B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE
M(&)E9VEN;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DAI9V@B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E
M;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHU"B,L(&9U>GIY"FUS
M9VED(")(;U]M92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G
M:60@(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34S-0HC+"!F=7IZ>0IM
M<V=I9"`B2&]M92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S
M(@IM<V=S='(@(D%D<F5S82!D92!A8V%S82(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HV-`IM<V=I9"`B2&]M92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM
M<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R(")496QE9F]N=6P@9&4@86-A<V$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-0IM<V=I9"`B2&]R9&4B"FUS9W-T
M<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0T,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!8
M34P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S
M('1O(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C0S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL
M>2!R96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I
M;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E
M>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0W"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M
M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HT-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R
M="!O9B!T>7!E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,3$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,S,V"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR
M;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B
M2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@
M<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE
M87-E(')E<&]R="$I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY
M(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@
M;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M
M97)G93\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,P,"!L:6(O0FQO8VLO;65T87(N<&AP.C(S,`IM<V=I9"`B2'5M:61I
M='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(U.0IM<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<R(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C$T(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<Y(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Q-@HC
M+"!F=7IZ>0IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R(")!9')E<V$B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED("))
M4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0($%D9')E
M<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#(*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-@IM<V=I9"`B26-O;G,@3VYL>2(*
M;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S<*;7-G:60@(DEC;VYS('=I=&@@=&5X
M="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DP"FUS
M9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,@HC+"!P:'`M9F]R;6%T"FUS
M9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@
M;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT-34*;7-G:60@(B(*(DEF('EO=2!D;VXG="!S
M964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y
M(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R
M86YS<&%R96YC>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$W,PIM<V=I9"`B(@HB268@>6]U('-E92!T
M:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@
M=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S
M97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B26UA9V4@4')E=FEE
M=SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,0IM<V=I9"`B
M26UA9V4@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N
M<&AP.C,W"FUS9VED("));6%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T82]D871E;6%P+FEN
M8SHW"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-30@=&5M<&QA=&5S
M+V1A=&$O8W-V:6YF;RYI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(D-I;7`@:6UP;W)T870Z("5S
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(D-I;7`@
M:6UP;W)T870Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV
M-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R(")#:6UP=7)I(&EM
M<&]R=&%T93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N
M<&AP.C$S-0IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S,@HC+"!F=7IZ>0IM<V=I9"`B26YC;W)R96-T('5S97)N
M86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`B5&4@<F]G(&EN=')O9'4@
M=6X@;G5M92!D92!U=&EL:7IA=&]R('-I(&\@<&%R;VQA(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U
M<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O
M;G1A8W0@>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H
M97(@:&5L<"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B26YD:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@57-E
M<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("));F1O;F5S:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C
M.#(R+G!H<#HV-PIM<V=I9"`B26YF;R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C4W"B,L(&9U>GIY"FUS9VED("));F9O<FUA
M=&EO;B(*;7-G<W1R("));F9O<FUA=&EI(&1E<W!R92!T:6YE(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,S,`IM<V=I9"`B26YF;W)M871I
M;VX@;F\@;&]N9V5R(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,U"FUS
M9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C`*;7-G:60@(DEN<V5R="!);6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED("));G-E
M<G0@5&%B;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E8B!,:6YK(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M
M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS
M9VED("));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O
M;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8R"FUS9VED("));G-E<G0@82!N97<@<F]W
M(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G
M:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-S`*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!A
M9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.0IM<V=I
M9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS9VED
M("));G-E<G0@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR,SD*;7-G:60@(DEN<V5R="!A;B!E;6%I
M;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A
M<W-W;W)D.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4X"FUS9VED("));G-E<G0@8V5L;"!A
M9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4Y"FUS9VED("));G-E<G0@8V5L;"!B969O
M<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E
M<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8U"FUS9VED("));G-E<G0@8V]L=6UN(&)E9F]R
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY,`IM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHT-0IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@8F5F;W)E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,`IM<V=I9"`B26YS97)T
M('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(V"FUS9VED("));G-E<G0O36]D:69Y($EM86=E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T
M,PIM<V=I9"`B26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D
M:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@(DEN<W5F
M9FEC:65N="!C<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$P-S4*;7-G:60@(DEN=&5G97(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$S,PIM<V=I9"`B26YT96=E<B!L
M:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI9"!51$@N("A5<V5R
M($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+WII<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]Z:7`N<&AP.C(P,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O>FEP+G!H<#HR,3`*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I
M9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED
M("));G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#@W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M-3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(S,B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,CDY"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP
M92]T86)L97-E="YP:'`Z,S<*;7-G:60@(DEN=F%L:60@9&%T82!S=6)M:71T
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P,`IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO
M;B!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O9&)X+G!H<#HX,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M
M<')E<W,O9&)X+G!H<#HQ,#`*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+V1B>"YP:'`Z,C(P"FUS9VED("));G9A;&ED(&9I;&4@9F]R;6%T(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S<*
M;7-G:60@(DEN=F%L:60@;&EC96YS92!K97DN(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S$*;7-G:60@(DEN=F%L:60@
M;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-PIM<V=I9"`B26YV
M86QI9"!M<V=?='EP92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S"FUS9VED("));G9A;&ED
M(&]R(&UI<W-I;F<@87!I7VED+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.38*;7-G:60@(DEN
M=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R
M96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-S,*;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W
M-0IM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O9&4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY,PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C<Q(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$P-S8@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HQ,C8R"FUS9VED("));G9A;&ED('-H87)E(&]B:F5C
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D9')E
M<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,Q,0IM<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A
M=&$N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M-3<*;7-G:60@(DEN=F5N=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<Y"FUS9VED("));G9E<G0@
M<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B27)A
M;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#$*;7-G:60@(DER87$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED
M("))<F5L86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B
M27-O;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS
M9VED("))<W)A96PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV,C4*;7-G:60@(DES<W5E<B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*;7-G
M:60@(DET86QI8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*(RP@9G5Z>GD*
M;7-G:60@(DET86QY(@IM<V=S='(@(EII;&YI8R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM
M<V=I9"`B2F%M86EC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Q"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIA<&%N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED(")*87!A;F5S92`H25-/
M+3(P,C(M2E`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,S$P"FUS9VED("(B"B)*879A<V-R:7!T(&AA<R!B965N(&1I<V%B
M;&5D(&]N('EO=7(@8G)O=W-E<B!A;F0@=&AI<R!P86=E(&UA>2!N;W0@8F4@
M(@HB9&ES<&QA>6EN9R!C;W)R96-T;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(R"FUS9VED(")*97)S97DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*;W)D86XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-PHC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G
M:60@(DIU;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S
M=&EF>2!#96YT97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3<*;7-G:60@(DIU<W1I9GD@
M1G5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$V"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C8T
M"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#,*;7-G:60@(DME;GEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE
M8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C0R"FUS9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G
M:60@(DME>2!#<F5A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@(DME>2!&:6YG97)P<FEN="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,3(*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@5'EP92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y
M.`HC+"!F=7IZ>0IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(DUE<V%J(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S0P"FUS9VED(")+
M97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I9"`B
M2VED<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(DMI<FEB871I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C
M<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@U"FUS9VED(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(DMO<F5A;B`H155#
M+4M2*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED
M("),85]Y;W5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(DQI;6)A(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@W"FUS9VED("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U
M8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS
M9VED("),87-T($AA;&8B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C<V"FUS9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN
M<&AP.C@X"FUS9VED("),87-T(%%U87)T97(B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ-3$*;7-G:60@(DQA<W0@57!D871E9#HB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<R,0HC+"!P:'`M9F]R;6%T"FUS
M9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q-@IM<V=I9"`B3&%S="!L;V=I;CH@
M3F5V97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),871V:6$B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED
M("),87<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<Y"B,L(&9U>GIY"FUS9VED("),87EO=70B
M"FUS9W-T<B`B1&5C;VYE8W1A<F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@
M;F\@8F]R9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&5B
M86YO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q.0IM<V=I9"`B3&5F="!H
M96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S$Q-0HC+"!F=7IZ>0IM<V=I9"`B3&5F="!V86QU97,B"FUS9W-T<B`B17AE
M;7!L92!D92!V86QO<FDZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),97-O=&AO
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U
M-0HC+"!F=7IZ>0IM<V=I9"`B3&5V96PB"FUS9W-T<B`B3FEC:6]D871A(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@X"FUS9VED("),:6)E<FEA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX.0IM<V=I9"`B3&EB>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C4*;7-G:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*(RP@9G5Z>GD*;7-G
M:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`B0V]N96-T87)E(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI9VAT
M(%)A:6X@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HR.0IM<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*;7-G
M:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),
M:6=H="!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*;7-G:60@
M(DQI;65R:6-K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$X,30*(RP@9G5Z>GD*;7-G:60@(DQI;FLB"FUS9W-T<B`B0V]N96-T
M87)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-0IM<V=I9"`B3&EN
M:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@
M9&ES<&QA>6EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT
M97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@S"FUS9VED("),:6YK<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI
M;G5X($-O;VMI92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E
M92!T:&4@9F]L9&5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,S,*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4P"FUS9VED("),:7-T($AE;'`@5&]P
M:6-S(@IM<V=S='(@(DQI<W1A('-U8FEE8W1E;&]R(&1I;B!(96QP(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$S,@IM<V=I9"`B3&ES="!486)L97,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU
M.30*;7-G:60@(DQI<W0M07)C:&EV92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4X.0HC+"!F=7IZ>0IM<V=I9"`B
M3&ES="U(96QP(@IM<V=S='(@(DQI<W1A('-U8FEE8W1E;&]R(&1I;B!(96QP
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.38*;7-G
M:60@(DQI<W0M260B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12](96%D97)S+G!H<#HU.3(*;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3,*;7-G
M:60@(DQI<W0M4&]S="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4Y,0IM<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU
M.3`*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5S<VEO;G,N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I
M;F<@<V5S<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M97-S:6]N<RYP:'`Z,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!U
M<V5R<R!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D
M:7-A8FQE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0W"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.0IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.#,*;7-G:60@(DQO861I;F<N
M+BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Q,0IM<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HX,PIM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3<Q(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-`HC.B!L:6(O0FQO
M8VLO<W5N<FES92YP:'`Z,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HV-0IM<V=I
M9"`B3&]C871I;VXB"FUS9W-T<B`B(@H*(SH@;&]G:6XN<&AP.C$W,B!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3DQ('1E;7!L871E<R]L;V=I;B]M
M;V)I;&4N:6YC.C,*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY,`IM<V=I9"`B3&]G(&EN(@IM
M<V=S='(@(D-O;F5C=&%R92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3@U
M"FUS9VED("),;V<@;W5T(@IM<V=S='(@(D1E8V]N96-T87)E(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C4Y"B,L(&9U>GIY"FUS9VED("),;V=I;B(*
M;7-G<W1R(")#;VYE8W1A<F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3`W"B,L(&9U>GIY"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R(")387)C
M:6YI(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DV"B,L(&9U>GIY
M"FUS9VED("),;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R
M('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R("(B
M"B)0<F]B;&5M82!C=2!#;VYE8W1A<F5A+B!0<F]B86)I;"!N=6UE;&4@9&4@
M571I;&EZ871O<B!S874O<VD@4&%R;VQA('-I;G0@(@HB9W)E<VET92XB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.3(*;7-G:60@(DQO9VEN(&9A
M:6QE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3,V-0HC+"!F=7IZ>0IM<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@(D1E8V]N
M96-T87)E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED("),
M;W9E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8W"FUS9VED("),;W<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM
M<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y
M"FUS9VED("),;W=E<B!L871I;B!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@Y"FUS9VED("),=7AE;6)O=7)G(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#`*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S."!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B3$PB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Q"FUS9VED(")-3U1$(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP
M.C,V"FUS9VED(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A
M=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA8V%O(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%C961O;FEA+"!4:&4@1F]R;65R
M(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#D*(RP@9G5Z>GD*;7-G:60@(DUA9VEC(@IM<V=S='(@
M(D-O<F5S<&]N9&5N=&$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M.#$*;7-G:60@(DUA:6PB"FUS9W-T<B`B0V]R97-P;VYD96YT82(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,C(*;7-G:60@(DUA:6P@061M:6XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B36%L87=I(@IM
M<V=S='(@(D-O<F5S<&]N9&5N=&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$V-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUA
M;&%Y<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,38T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")-
M86QI(@IM<V=S='(@(D-O<F5S<&]N9&5N=&$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$V,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*(RP@
M9G5Z>GD*;7-G:60@(DUA;'1A(@IM<V=S='(@(D-O<F5S<&]N9&5N=&$B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$*;7-G:60@(B(*(DUA;F%G92!T
M:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US
M('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E(&-A
M=&5G;W)I97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,34S"FUS9VED(")-87`R-"!M87`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$P.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$Q-C@*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T
M;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*
M(RP@9G5Z>GD*;7-G:60@(DUA<F=I;B(*;7-G<W1R(")!=&5N=&EE(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@
M(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B
M36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E
M9"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-87)S:&%L;"!)
M<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R=&EN
M:7%U92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C$P,PIM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(D-I;7!U<FD@
M<&]T<FEV:71E("T@9&4@=')A9'5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-
M875R:71A;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U
M<FET:75S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E
M9&ET+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@(DUA>"!M97-S86=E('!A<G1S
M(&5X8V5E9&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,P-@IM<V=I9"`B36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDX"FUS9VED(")-87@@=&5M
M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HX
M-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3@@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C,Y"FUS9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#,*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I
M9"`B36%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(DUA>6]T
M=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P"FUS
M9VED(")-961I8VEN92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V5D:70N:6YC.C$V"B,L(&9U>GIY"FUS9VED(")-96UB97)S(@IM
M<V=S='(@(DYO=&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<X"FUS
M9VED(")-96YU(&UO9&4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E
M(&-E;&QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E(@IM<V=S
M='(@(DUE<V%J(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY
M(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*
M(G9E<FEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*(RP@9G5Z>GD*;7-G:60@(DUE
M<W-A9V4@97AP:7)E9"XB"FUS9W-T<B`B365S86HB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V.0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P
M"B,L(&9U>GIY"FUS9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`B365S86HB
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E871H
M97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I
M9"`B365T87(@8FQO8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3(*(RP@9G5Z>GD*;7-G:60@(B(*(DUE
M=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO
M9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(D1E=&%L:6D@
M:6YR96=I<W1R871E(&EN($Q/1R!P96YT<G4@861M:6YI<W1R871O<BXB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38U"FUS9VED(")-971A
M<D1"(&ES(&YO="!C;VYN96-T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B365T:&]D(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z.#$@9G)A;65W
M;W)K+U)00R]24$,O<V]A<"YP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@
M(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D.B`E<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S0@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HW-0IM<V=I9"`B365T<FEC(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<R"FUS9VED(")-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S
M(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW-@HC+"!F=7IZ>0IM<V=I9"`B36ED9&QE(@IM
M<V=S='(@(D-O<F5S<&]N9&5N=&$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$P"FUS9VED(")-:6X@=&5M
M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,#(*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#,Y
M"FUS9VED(")-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I
M<F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,S0*(RP@9G5Z>GD*;7-G:60@(DUI<G)O<B(*;7-G<W1R
M(")%<F]A<F4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@
M(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0P"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG
M(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*;7-G:60@(B(*(DUI<W-I;F<@8V]N
M9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO
M=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA
M:6PN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES<VEN9R!S97-S:6]N($E$
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-S0*;7-G:60@(DUO8FEL92!-86EL(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8X"FUS9VED(")-;V1E<F%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8V(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S,*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HX.`IM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S,*;7-G:60@(DUO
M9'5L=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VQD;W9A
M+"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@
M(DUO;F%C;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O
M;&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U
M.30*;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO
M;G1H;'DB"FUS9W-T<B`B3'5N87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$V,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUO
M;G1S97)R870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@
M;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-S(@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C4S"B,L('!H<"UF;W)M870*;7-G
M:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP
M96-T960@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]R
M;V-C;R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS,PIM<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T"FUS
M9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,U"FUS9VED(")-;W-T;'D@4W5N
M;GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z-3`Y"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$S"FUS9VED(")-;W9E
M($QE9G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z-3$W"FUS9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4P-0IM<V=I9"`B
M36]V92!5<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R
M,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T
M"FUS9VED(")-;W9E('5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I
M9"`B36]Z86UB:7%U92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,3@T"FUS9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES
M=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$P-34*;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0R"FUS9VED(")-
M=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0P,`IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*(RP@9G5Z>GD*;7-G:60@
M(DUY($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M871I:2!D
M97-P<F4@=&EN92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-30*
M;7-G:60@(DUY(%!O<G1A;"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T
M86PO961I="YP:'`Z,3,V"FUS9VED(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B37EA;FUA<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU
M-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,2!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(").86UE(@IM<V=S='(@
M(DYU;64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDW"FUS9VED(").875R=2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3<*;7-G:60@(DYE<&%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*
M;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED(").971S
M8V%P92!"87-E(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@0T$@4F5V;V-A
M=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.#4*;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!54DPB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.#0*;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED
M(").971S8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A
M<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@W"FUS9VED(").971S8V%P92!C97)T
M:69I8V%T92!C;VUM96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3@P"FUS9VED(").971S8V%P92!C97)T:69I
M8V%T92!T>7!E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR-3$*;7-G:60@(DYE='=O<FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(U(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS,S4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X-@IM<V=I9"`B
M3F5V97(B"FUS9W-T<B`B3FEC:6]D871A(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED
M(").97<@0V%L961O;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED(").97<@0V%T
M96=O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I
M;'1E<B]E;6%I;',N<&AP.C@Q"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&
M:6QT97(O96UA:6QS+G!H<#HX-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O
M1FEL=&5R+V5M86EL<RYP:'`Z.3<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R
M+T9I;'1E<B]E;6%I;',N<&AP.C$P,0HC+"!P:'`M9F]R;6%T"FUS9VED(").
M97<@365S<V%G92!T;R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R
M;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I
M9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C,W"B,L(&9U>GIY"FUS9VED(").97<@<&%S<W=O<F0B
M"FUS9W-T<B`B4&%R;VQA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN
M<&AP.C(R-PHC+"!P:'`M9F]R;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL
M;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HU,@IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M
M871C:"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(X.0HC+"!F=7IZ>0IM<V=I9"`B3F5W<R(*;7-G<W1R(").;W1E(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-0IM<V=I9"`B3F5W<V=R;W5P
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ
M-2!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT,0HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHR-0IM<V=I9"`B3F5X="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,C<*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S(@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HS-S8*(RP@9G5Z>GD*;7-G:60@(DYE>'0@;W!T
M:6]N<R(*;7-G<W1R("));F%P;VD@;&$@;W!T:75N:2(*"B,Z(&9R86UE=V]R
M:R]522]522]086=E<BYP:'`Z,3`S"FUS9VED(").97AT/B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.38*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(DYI9V5R(@IM<V=S='(@(DYI
M8VEO9&%T82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S@P"FUS9VED
M(").:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYI=64B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.CDV,PIM<V=I9"`B3F\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS9VED(").;R!A=F%I;&%B;&4@
M8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(N<&AP.C$P-0IM<V=I9"`B3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M
M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").;R!B
M871C:"!T96UP;&%T92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z-SD@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z,C0U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C(V-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T
M960@<&]S:71I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]M8V%L+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B3F\@8V%L96YD87(@;F%M
M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B
M3G4@97-T92!C;VYF:6=U<F%T82!A=71E;G1I9FEC87)E82!344PB"@HC.B!A
M9&UI;B]S971U<"]D:69F+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B3F\@8VAA
M;F=E+B(*;7-G<W1R(")!;G5L96%Z82!38VAI;6)A<FEL92(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED(").;R!C:&EL9')E
M;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V-R!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C4P,@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H
M<#HW-S,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B
M3G4@97-T92!C;VYF:6=U<F%T82!#871E9V]R:6$@4U%,(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HX,C0*(RP@9G5Z>GD*;7-G:60@(DYO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93
M+B(*;7-G<W1R(").=2!S:6YT(&-O;F9I9W5R871E(%!R969E<FEN=&5L92!,
M1$%0(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-CD*(RP@9G5Z
M>GD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!344P@5D93+B(*;7-G<W1R(").=2!E<W1E(&-O;F9I9W5R871A
M($-A=&5G;W)I82!344PB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z-S$W"B,L(&9U>GIY"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R
M(").=2!E<W1E(&-O;F9I9W5R871A($-A=&5G;W)I82!344PB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G
M:60@(DYO(&-R961I="!L969T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`IM<V=I9"`B3F\@
M9&5S=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@W-PIM<V=I9"`B3F\@9FEL92!U<&QO
M861E9"(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*
M;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(X(&QI8B]";&]C:R]S=6YR:7-E+G!H
M<#HT,`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R,PIM<V=I9"`B3F\@;&]C
M871I;VX@:7,@<V5T+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,38Y"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S,*;7-G:60@(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,V"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S<*;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I960N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F
M96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:'1T<"YP:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C$P.`IM<V=I9"`B3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-S(*;7-G:60@
M(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L
M+G!H<#HW-R!F<F%M97=O<FLO075T:"]!=71H+VQO9VEN+G!H<#HX-`HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-S4*(RP@9G5Z>GD*;7-G:60@
M(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`B3G4@97-T92!C;VYF:6=U<F%T82!A=71E;G1I9FEC87)E
M82!344PB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A<W-W9"YP:'`Z,3,U
M"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%3
M4U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").=2!E<W1E(&-O;F9I9W5R
M871A(&%U=&5N=&EF:6-A<F5A(%-13"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<VUB+G!H<#HX-`HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3G4@97-T
M92!C;VYF:6=U<F%T82!A=71E;G1I9FEC87)E82!344PB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R.#8*;7-G:60@(B(*(DYO('!A
M=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-3
M3"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O<FL@=VET:"!02T-3(#$R
M(&1A=&$N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C<U,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(").;R!Q=6]T82!S970N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*(RP@
M9G5Z>GD*;7-G:60@(DYO(')U;&5S(@IM<V=S='(@(DYO=&4B"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#D*;7-G:60@(DYO('-E<&%R871O
M<B!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#0*(RP@9G5Z>GD*;7-G:60@
M(DYO('-I9&5S(@IM<V=S='(@(DYO=&4B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C4X,PIM<V=I9"`B3F\@<W5C:"!F:6QE(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,S@*;7-G:60@(DYO
M('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HR,C$*(RP@9G5Z>GD*;7-G:60@(DYO('5S97)N86UE(&%N9"]O<B!P
M87-S=V]R9"!S96YT+B(*;7-G<W1R(")492!R;V<@:6YT<F]D=2!U;B!N=6UE
M(&1E('5T:6QI>F%T;W(@<VD@;R!P87)O;&$B"@HC.B!F<F%M97=O<FLO4E!#
M+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@
M<F5T=7)N960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.CDW,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.3@Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HY.3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$P,#D*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V97)S
M:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A
M=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$R.`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R
M(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY
M,PHC+"!F=7IZ>0IM<V=I9"`B3F]N92(*;7-G<W1R(")496QE9F]N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I
M9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").;W)F;VQK($ES;&%N
M9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L
M;V-K+VUO;VXN<&AP.C8P"FUS9VED(").;W)T:&5R;B!(96UI<W!H97)E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B3F]R=&AE<FX@36%R:6%N
M82!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F]R
M=V%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C0P"FUS9VED(").;W0@069T97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@(DYO="!"
M969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z-#`X"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HV,PHC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T
M<F%T96=Y+G!H<#HX,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-`HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP
M.C0X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2YP:'`Z-3D*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHV.`HC+"!F=7IZ>0IM<V=I9"`B3F]T('-E="(*;7-G<W1R(").
M;W1E(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD
M;&5R+G!H<#HQ-#,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I
M;VY(86YD;&5R+G!H<#HQ-3@*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R
M+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S,*(SH@9G)A;65W;W)K+U-E<W-I;VY(
M86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#<*(SH@9G)A;65W;W)K+U-E
M<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HR,S0@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C`U
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C(T."!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C8U"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(Y
M-PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S$R(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HS,CD*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,V,B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z-#(R"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HU,#$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4W,`HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z-3@W(&9R86UE=V]R:R]61E,O5D93+G!H<#HV-C4*;7-G
M:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0@8V]N9FEG+VAO;VMS+G!H
M<"YD:7-T.C$P,#4*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$W.`IM
M<V=I9"`B3F]T97,B"FUS9W-T<B`B3F]T92(*"B,Z('-E<G9I8V5S+V]B<F]W
M<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O
M(&)A8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,3$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<U"B,L(&9U>GIY"FUS9VED(").;W9E;6)E<B(*;7-G
M<W1R(").:6-I;V1A=&$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,#0V"B,L(&9U>GIY"FUS9VED(").=6UB97(B"FUS9W-T<B`B3G5M92(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C4*;7-G:60@(DYU;6)E<B!O
M9B!C:&%R86-T97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$S-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,PHC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0U('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB97(@;V8@8V]L
M=6UN<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,S8W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C$*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30T,R!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D
M871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B
M3TLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C@W,PIM<V=I9"`B3V)J96-T(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E
M871O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,3`T"FUS9VED(")/8W1A;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F
M9F5N<V4@9FEL=&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS,C8*;7-G:60@(D]F9FEC92(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W
M('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V"B,L(&9U>GIY"FUS9VED
M(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`B4&%R;VQA(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C0V"FUS9VED(")/;&0@<&%S<W=O<F0@:7,@
M;F]T(&-O<G)E8W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B
M3VUA;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HW,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R
M="!S:&%R960@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.CDU"FUS9VED(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4Q(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S$*;7-G:60@(D]N;'D@;VYE(&5M
M86EL(&%D9')E<W,@86QL;W=E9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<VAA<F5S+V5D:70N<&AP.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O
M<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O
M<B!O=VYE<B`B"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS-0IM<V=I9"`B3W!E;B!I;B!A
M(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD
M(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@
M;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-3,*;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N
M<R(*;7-G<W1R(")/<'1I=6YI(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C,Q
M('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$T"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R(")/<'1I=6YI(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM
M<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-38W"FUS9VED(")/<F=A;FES871I;VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU-C@*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S,@IM<V=I9"`B3W)G86YI
M>FEN9R(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM
M<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`B
M(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME
M>6)O87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDV(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,#8*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,R!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3(R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S$@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$T,0IM<V=I9"`B3W1H97(@26YF;W)M871I
M;VXB"FUS9W-T<B`B06QT92!I;F9O<FUA=&EI(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHS,0IM<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<Y"FUS
M9VED(")004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT
M<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A8VME;F0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3(W,PIM<V=I
M9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,3D*;7-G:60@(E!'4"!%;F-R
M>7!T960@1&%T82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,S<Q"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S4S"FUS
M9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W!H<'-H96QL+G!H<#HV.`HC+"!F=7IZ>0IM<V=I9"`B4$A0($-O
M9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*
M;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-PIM<V=I9"`B4$T@3&EG:'0@4F%I
M;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS.`IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B
M4$T@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT,`IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0Q"FUS9VED(")032!3=6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E!-(%0M4W1O<FUS
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR-S0*;7-G
M:60@(E!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z
M(&QI8B]A<&DN<&AP.C$T.0IM<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0V"FUS9VED(")0861D:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M.0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM
M<V=I9"`B4&%L874B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B
M4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3@*;7-G:60@(E!A;F%M82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3D*;7-G:60@(E!A<'5A($YE=R!'=6EN96$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.34@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,@IM<V=I9"`B4&%R86=U87DB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S8*;7-G:60@(E!A
M<G1L>2!#;&]U9'DB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-PHC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3$@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`Q.`HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<W
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0R,PIM<V=I9"`B4&%S<W=O<F0B"FUS9W-T
M<B`B4&%R;VQA(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R
M"FUS9VED(")087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,S(R
M"B,L(&9U>GIY"FUS9VED(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`B
M4&%R;VQA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$U
M,@IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C`U,PIM<V=I9"`B4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP"B,L
M(&9U>GIY"FUS9VED(")087-S=V]R9#HB"FUS9W-T<B`B4&%R;VQA(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@
M(E!A<W-W;W)D.B`B"FUS9W-T<B`B4&%R;VQA(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,34P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S0*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S
M(&UU<W0@;6%T8V@N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,3D@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(R"FUS9VED(")087-T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,W"FUS9VED(")087-T
M92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q"FUS9VED(")0871H(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHW"FUS9VED
M(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B4&5O<&QE(@IM<V=S='(@
M(E)O;&4@+2!D92!T<F%D=7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT
M.0IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM<V=S
M='(@(D5X96-U=&$@3W!E<F%T:75N:6QE(&1E($UE;G1E;F%N=&$B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#`V"B,L(&9U>GIY"FUS9VED(")097)F
M;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@
M(D5X96-U=&$@3W!E<F%T:75N:6QE(&1E($UE;G1E;F%N=&$B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B4&5R;6ES<VEO
M;B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R"B,L
M('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D96QE
M=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C4X-@IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C$@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ-C0*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P.2!A9&UI;B]P97)M
M<R]A9&1C:&EL9"YP:'`Z-C`*(SH@861M:6XO<&5R;7,O:6YD97@N<&AP.C(R
M(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3@*;7-G:60@(E!E<FUI<W-I;VYS
M($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV-0HC+"!F=7IZ>0IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I
M;VXB"FUS9W-T<B`B06QT92!I;F9O<FUA=&EI(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS
M9VED(")097)U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU-0IM<V=I9"`B4&5T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G
M:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM<V=S
M='(@(E1E;&5F;VXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<X
M"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I
M9"`B4&ET8V%I<FXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I
M='5D97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN
M=&\@<V]M92!C96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E
M(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H
M870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4W,0IM<V=I9"`B4&QE
M87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G
M:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#$*
M;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C`*;7-G:60@
M(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@
M;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(T-3$*;7-G:60@(E!L96%S92!E;G1E<B!A('9A
M;&ED('1I;64N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C<*;7-G:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O
M9B!T:&4@<')O8FQE;2XB"FUS9W-T<B`B5&4@<F]G('-P96-I9FEC82!U;B!S
M=6UA<B!A;"!P<F]B;&5M96DN(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0
M;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G
M<W1R(")492!R;V<@:6YT<F]D=2!U;B!N=6UE(&1E('5T:6QI>F%T;W(@<VD@
M;R!P87)O;&$B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*;7-G
M:60@(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U5
M4U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R
M>4UA;F%G97(N<&AP.C<P"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A
M=&5G;W)Y(&YA;64Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B
M4&]L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M-PIM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0X-PIM<V=I9"`B4&]L;',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,0IM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(W"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$Q"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ
M"FUS9VED(")0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@
M24U!4"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C8@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y.`IM<V=I9"`B
M4')E8VEP:71A=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O;&1A<"YP:'`Z.3@*;7-G:60@(E!R969S7VQD
M87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-E<W-I;VXN<&AP.C,S
M"FUS9VED(")0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C(U"FUS9VED(")0<F5S<W5R92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(U.0IM<V=I9"`B4')E<W-U<F4@870@<V5A(&QE
M=F5L.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(S-0IM<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`U"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*;7-G:60@
M(E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V,B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C,V-@HC+"!F=7IZ>0IM<V=I9"`B4')E
M=FEO=7,@;W!T:6]N<R(*;7-G<W1R("));F%P;VD@;&$@;W!T:75N:2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G
M:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+97DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V
M.0HC+"!F=7IZ>0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R(");4F%P;W)T(%!R
M;V)L96UA72(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-@IM<V=I9"`B
M4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R(")$97-C<FEE<F5A('!R;V)L
M96UE:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-CD*;7-G:60@
M(E!R;VIE8W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X.`HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@U"FUS9VED(")0<F]M<'0@=&5X="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@
M06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C0T"FUS9VED(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS
M9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C
M8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0
M=65R=&\@4FEC;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")1
M871A<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C,*;7-G
M:60@(E%U97)Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HW,`IM<V=I9"`B475O=&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-`IM<V=I9"`B4F%D:6\@<V5L96-T:6]N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0S"FUS9VED(")286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")286EN($5A
M<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0U"FUS9VED(")286EN($QA=&4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@
M(E)A:6X@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")286EN(&%N9"!3;F]W(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0X"FUS9VED(")286EN('1O(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A;F1O;2!&;W)T=6YE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-@IM
M<V=I9"`B4F%T:6\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ.#`*;7-G:60@(E)E860B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*(RP@9G5Z
M>GD*;7-G:60@(E)E860@;65S<V%G97,B"FUS9W-T<B`B365S86HB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N
M;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O8VQE87(N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY
M(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N
M(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y
M;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED(")2
M969R97-H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.3$*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q"B,L(&9U>GIY
M"FUS9VED(")2969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R(")296EM<')O
M<W!A=&5A>F$@4W5M87)U;"`M(&1E('1R861U<R(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C@Y-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$S
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S4*;7-G:60@(E)E9V5X
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-#D*
M;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HR,#@*;7-G:60@(E)E;&]A9"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,R-@IM<V=I9"`B4F5M87)K<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$T"FUS9VED(")296UO
M=&4@4V5R=F5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA
M;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V5D:70N:6YC.C(R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U
M975E9"YI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92(*;7-G<W1R(")3
M=&5R9V4@<&5R96-H96$B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI
M;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R(")3
M=&5R9V4@<&5R96-H96$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-34W"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-#`*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@
M(E-T97)G92!P97)E8VAE82(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z,3(X"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R(")3=&5R9V4@<&5R
M96-H96$B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R"FUS9VED(")2
M96UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I
M<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"B,L(&9U>GIY"FUS9VED(")2
M96UO=F4@=&AE(@IM<V=S='(@(E-T97)G92!P97)E8VAE82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM
M<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$Q
M"B,L(&9U>GIY"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R(")3=&5R9V4@
M<&5R96-H96$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC
M.C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R.B`E
M<R(*;7-G<W1R(")3=&5R9V4@<&5R96-H96$B"@HC.B!F<F%M97=O<FLO4E!#
M+U)00R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B
M92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-PIM<V=I9"`B4F5Q
M=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-"!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C4Q,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B)W5I9"<@;F5S<&5C:69I8V%T(&EN(&-O;F9I
M9W5R871I82!D92!P<F5F97)I;G1E+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z-C<U(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,P"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,C,*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF
M:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(G=6ED)R!N97-P
M96-I9FEC870@:6X@8V]N9FEG=7)A=&EA(&1E('!R969E<FEN=&4N(@H*(SH@
M9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S@Q"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(G=6ED)R!N97-P96-I9FEC870@:6X@
M8V]N9FEG=7)A=&EA(&1E('!R969E<FEN=&4N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2]296YD97)E<BYP:'`Z,S,U"FUS9VED(")297%U:7)E9"!&:65L
M9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD
M97)E<BYP:'`Z,S(P('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-PIM<V=I9"`B
M4F5S970B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z-#8*(RP@9G5Z>GD*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@
M(E!A<F]L82(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W"FUS
M9VED(")297-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,S`*;7-G:60@(E)E<W1O<F4@3&%S="!1=65R>2(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S$@861M:6XO8VUD
M<VAE;&PN<&AP.C(X(&%D;6EN+W-Q;'-H96QL+G!H<#HV-@IM<V=I9"`B4F5S
M=6QT<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R
M;B!T;R!/<'1I;VYS(@IM<V=S='(@(DEN87!O:2!L82!O<'1I=6YI(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED(")2971Y<&4@
M;F5W('!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@
M(E)E=6YI;VXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E<G0@
M0V]N9FEG=7)A=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3,R"B,L(&9U>GIY"FUS9VED(")2:6-H(%1E>'0@161I=&]R($]P
M=&EO;G,B"FUS9W-T<B`B26YA<&]I(&QA(&]P=&EU;FDB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<P"FUS9VED(")2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,3(Q"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-PIM<V=I9"`B4FEG
M:'0@=F%L=65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?=R!0<F]P
M97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`B4F]L
M92`M(&1E('1R861U<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(R-0IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(R"FUS9VED
M(")2;W1A=&4@3&5F="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(X"FUS9VED(")2;W1A=&4@4FEG:'0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW,`IM<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*
M;7-G:60@(E)O=W,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*(RP@9G5Z>GD*;7-G:60@
M(E)U;&5S(@IM<V=S='(@(E)O;&4@+2!D92!T<F%D=7,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED
M(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU
M;6YS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G:60@
M(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`*;7-G:60@(E)U;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S:6%N($9E9&5R871I
M;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G=A;F1A(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,C@U"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS
M,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@Q"FUS9VED(")3
M05-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,#0*(RP@9G5Z>GD*
M;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T<B`B365S86HB"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@S"FUS9VED(")344P@
M<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S$*;7-G:60@(E-32"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@
M(B(*"B,Z(&QI8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8Q"FUS9VED(")382(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS
M9VED(")386EN="!(96QE;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS
M9VED(")386EN="!+:71T<R!A;F0@3F5V:7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,SD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@W"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`P"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD
M('1H92!'<F5N861I;F5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@
M*%]S96QF*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")386UO
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")386X@36%R:6YO
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N
M9"!0<FEN8VEP92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$Y"FUS9VED(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY.`IM<V=I
M9"`B4V%V92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V5D:70N:6YC.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F4@7"(E<UPB
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@
M(E-A;'9A>F$@3W!T:75N:2(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC
M.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R(")386QV87IA($]P=&EU
M;FDB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38W"FUS9VED("(B"B)3
M879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T
M;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<Q"B,L('!H<"UF
M;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L('!H<"UF;W)M
M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0Y"FUS9VED(")38V%T=&5R960@5"U3=&]R;7,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE
M;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED
M(")396%R8V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,R,`IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDW,PIM<V=I9"`B4V5L96-T($9I
M;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT.#0*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A(&1A=&4B
M"FUS9W-T<B`B1F]R;6%T=6P@9&4@869I<V%R92!A(&1A=&5I.B(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")396QE8W0@82!G
M<F]U<"!T;R!A9&0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B
M4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,34V"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C<W"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C,*(RP@9G5Z>GD*;7-G:60@(E-E
M;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R(")&;W)M871U;"!D
M92!A9FES87)E(&$@9&%T96DZ(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C<X"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(B(*(E-E
M;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B
M96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O
M;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B)!;&5G92!C87)A8W1E<F5L
M92!D92!C87)E(&%I(&YE=F]I92!D:6X@8V%S=71E;&4@9&4@;6%I(&IO<RX@
M5F5I('!U=&5A(&%P;VD@(@HB<V$@;&4@8V]P:65Z:2!I;B!Z;VYA(&1E('1E
M>'0N(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E
M;&5C="!T:&4@9&%T92!D96QI;6ET97(Z(@IM<V=S='(@(D1E;&EM:71A=&]R
M(&1E(&1A=&$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G
M:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM<V=S='(@(D9O<FUA='5L
M(&1E(&%F:7-A<F4@82!D871E:3HB"@HC.B!T96UP;&%T97,O<')E9G,O:61E
M;G1I='ES96QE8W0N:6YC.CDP"FUS9VED(")396QE8W0@=&AE(&ED96YT:71Y
M('EO=2!W86YT('1O(&-H86YG93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O=&EM92YI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@
M=&EM92!D96QI;6ET97(Z(@IM<V=S='(@(D1E;&EM:71A=&]R(&1E(&1A=&$Z
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C
M="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(D9O<FUA='5L(&1E(&%F:7-A
M<F4@82!O<F5I.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*
M;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R(")3
M96QE8W1E87IA(&1O=6$@8VEM<'5R:2!P;W1R:79I=&4N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,P-@IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@
M<V-H96UE+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C0X"FUS9VED(")396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM
M<V=S='(@(E-E;&5C=&5A>F$@;&EM8F$@<')E9F5R871A.B(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")396YD(%!R;V)L
M96T@4F5P;W)T(@IM<V=S='(@(E1R:6UI=&4@4F%P;W)T(&1E($5R;V%R92(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#,Y
M"FUS9VED(")396YD(%--4R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Y.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS
M9VED(")396YE9V%L(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S$V"FUS9VED(")396YS;W(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Y"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I9"`B4V5P=&5M
M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#$*
M;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$V,0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O
M;F<@;W(@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S
M<VEO;G,N<&AP.C(W"FUS9VED(")397-S:6]N($%D;6EN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R("(B"@HC
M.B!L:6(O87!I+G!H<#HQ-#4*(RP@9G5Z>GD*;7-G:60@(E-E<W-I;VYS(@IM
M<V=S='(@(E-A;'9A>F$@3W!T:75N:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S,30*;7-G:60@(E-E="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-S8*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W
M('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E
M="!I="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q
M-0IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@
M=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX-`HC+"!F=7IZ>0IM<V=I9"`B4V5T('EO
M=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I
M;VYS+B(*;7-G<W1R(")!;&5G92!T:6UP=6P@9&4@<F5I;7!R;W-P871A<F4@
M82!P86=I;FEI('-I(&%L=&4@;W!T:75N:2!D92!A9FES87)E+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY.`HC+"!F=7IZ>0IM<V=I9"`B(@HB4V5T
M('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E
M(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM
M<V=S='(@(D%L96=E('1I;7!U;"!D92!R96EM<')O<W!A=&%R92!A('!A9VEN
M:6D@<VD@86QT92!O<'1I=6YI(&1E(&%F:7-A<F4N(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HW-0IM<V=I9"`B4V5T=7`B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*;7-G:60@(E-E
M='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$X-@IM<V=I9"`B4V5V97)A
M;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DV"FUS9VED
M(")3:&]P<&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHT,PHC+"!F=7IZ>0IM<V=I9"`B4VAO<G0@4W5M;6%R>2(*
M;7-G<W1R(")3=6UA<B!S8W5R=#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#0V"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F
M;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U-0IM<V=I9"`B(@HB4VAO=R!D
M:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE
M=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DP"FUS9VED(")3:&]W(&QA<W0@
M;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C4*;7-G:60@(E-H;W<@;W!T:6]N
M('1O(&ME97`@;W)I9VEN86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@Q,PIM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R-@IM<V=I9"`B4VAO=R!T
M86)L92!O<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S0Y"B,L('!H<"UF;W)M870*;7-G:60@(E-H
M;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO
M9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R
M;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I9"`B4VAO
M=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L
M;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V
M,PIM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3`*;7-G:60@(E-H;W=E<G,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-3$*;7-G:60@(E-H;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@
M(E-H;W=E<G,@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!I;B!T:&4@
M5FEC:6YI='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z-#@P"FUS9VED(")3:')I;FLB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-S<T(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C@S-@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HY,C(@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z.3@T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C$P-#<@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M,3`X-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,3$V
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q-#D*;7-G:60@
M(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@
M=&AE('=A>2!F:7)S="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED
M(")3:65R<F$@3&5O;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.C(V-0IM<V=I9"`B4VEG;B!U<"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM<V=I
M9"`B4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-S$Q"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C8U(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-R!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HX.38*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(Q-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,W"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#8@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,CDS,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(S"FUS
M9VED(")3:7IE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]M86EN=&5N86YC92YH=&UL.C4R"FUS9VED(")3:VEP($UA:6YT96YA;F-E
M(@IM<V=S='(@(E-A<FD@<&5S=&4@365N=&5N86YT82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#4*;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*
M;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4T"FUS9VED(")3;F]W(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U
M"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R!3:&]W
M97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4W"FUS9VED(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-3@*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C<X"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#(*;7-G:60@(E-N
M;W<@97%U:79A;&5N="!I;B!W871E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#,*;7-G:60@(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`V"FUS9VED(")3;VUA;&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(V"FUS9VED
M(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U.0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C0W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,38V
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"B,L
M(&9U>GIY"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G<W1R(")!9')E<V$@
M;&$@4V5R=FEC:74B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")3;W5T:"!!9G)I
M8V$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G
M:60@(E-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S<*;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T
M:"!386YD=VEC:"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H
M97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E
M96X@861J86-E;G0@8V5L;',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E
M='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#$U"FUS9VED(")3<&%C97(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@P"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-30*;7-G:60@(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S$*;7-G:60@(E-P86EN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HY.`IM<V=I9"`B4W!A;2(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@0VAA
M<F%C=&5R($EN<'5T(@IM<V=S='(@(D-A<F%C=&5R92!3<&5C:6%L92`N+BXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*;7-G
M:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI
M="!R;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Q
M"B,L(&9U>GIY"FUS9VED(")3<&]R=',B"FUS9W-T<B`B26UP;W)T(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@X"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<S(&QI8B]";&]C:R]M971A<BYP
M:'`Z-S0*(RP@9G5Z>GD*;7-G:60@(E-T86YD87)D(@IM<V=S='(@(D-A;&5N
M9&%R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED(")3=&%R
M(%1R96LB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C4Y-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`Y"FUS9VED(")3=&%R
M="!Y96%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3<P"FUS9VED(")3=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM
M<V=I9"`B4W1A='5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X,34*(RP@9G5Z>GD*;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM
M<V=S='(@(DEN9F]R;6%T:6D@9&5S<')E('1I;F4B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,@HC+"!F=7IZ>0IM<V=I9"`B4W1R
M965T($%D9')E<W,B"FUS9W-T<B`B061R97-A(&QA(%-E<G9I8VEU(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I
M9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C,S"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<S"FUS9VED(")3=')I
M<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(S"FUS
M9VED(")3='EL92!;0U-372(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R
M("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD
M+B(*;7-G<W1R(").;W1I9FEC871I;VX@;&ES=&5N97(@)7,@;F]T(&9O=6YD
M+B`M(&1E('1R861U<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R(&9R86UE=V]R:R]&;W)M+T9O
M<FTO4F5N9&5R97(N<&AP.C,Q-PIM<V=I9"`B4W5B;6ET(@IM<V=S='(@(B(*
M"B,Z('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B
M;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9
M;W4@8V%N(&YO="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B
M965N(&%P<')O=F5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$R"FUS9VED(")3=6)S8W)I<'0B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P-`HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N
M<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S='(@(E-U8V-E<R(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F
M=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E-U
M8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@
M=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX
M,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V"B,L('!H<"UF;W)M870*;7-G
M:60@(E-U8V-E<W-F=6QL>2!D96QE=&5D(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L('!H<"UF;W)M870*;7-G:60@(E-U
M8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@
M(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@
M=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HU.2!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU-PIM<V=I9"`B
M4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8R"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O
M;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,38X"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U
M<&1A=&5D(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-`IM<V=I9"`B4W5D86XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@HC
M+"!F=7IZ>0IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R(")3=6UA<G5L($UE=2(*
M"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV-0IM<V=I9"`B4W5N(%)I<V4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8X"FUS9VED
M(")3=6X@4V5T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3=6YN>2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$V"FUS9VED(")3=6YR
M:7-E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS970B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q
M-0IM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,3D*;7-G:60@(E-U;G-E="(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$X"FUS9VED(")3
M=6YS970Z("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$S"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<X"B,L(&9U>GIY
M"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(DEM<&]R="(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#8*(RP@9G5Z>GD*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(E5T:6QI>F%T
M;W(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-`HC
M+"!F=7IZ>0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R(")5=&EL:7IA=&]R(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA;F0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-38@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8V"FUS9VED(")3=VET>F5R;&%N9"(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@IM<V=I9"`B4WEN
M8R!L;V<@9&5L971E9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,30R"FUS9VED(")3>6YC34PB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3>6YT87@@97)R
M;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*
M;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS9VED(")4
M+5-T;W)M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8Q"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV,@IM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*;7-G:60@(E0M4W1O<FUS
M($5A<FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O='-V
M+G!H<#HQ-C8*(RP@9G5Z>GD*;7-G:60@(E135B!F:6QE(@IM<V=S='(@(E1I
M=&QU(@H*(SH@9G)A;65W;W)K+U5)+U5)+U1A8FQE+G!H<#HQ,S0*(RP@9G5Z
M>GD*;7-G:60@(E1A8FQE(@IM<V=S='(@(E1I=&QU(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B
M5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W"FUS9VED(")486)L92!3970B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-"!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")486EW86XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDY-B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3@W"FUS9VED(")487-K<R(*;7-G<W1R(")387)C:6YI(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@
M(E1E;&5P:&]N92!.=6UB97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR.3`*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$T"FUS9VED(")496UP
M97)A='5R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C(S"FUS9VED(")496UP97)A='5R93H@(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E
M9SLE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA
M=&4N<&AP.C8X-PHC+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S
M7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N
M<&AP.C$V.0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,S,V"FUS9VED(")497AT(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S4*;7-G:60@(E1E>'0@3VYL
M>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S$*;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@(E1H86D@
M*%1)4RTV,C`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1H
M86EL86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP
M.CDX.`HC+"!F=7IZ>0IM<V=I9"`B5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@
M<WES=&5M+B(*;7-G<W1R(")!:2!F;W-T(&1E8V]N96-T870N/&)R("\^375L
M='5M97-C(&-A(&9O;&]S97-T:2!S:7-T96UU;"XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C@R,`IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@
M:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE($AO
M<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T
M(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U3
M4"]";V]K+G!H<#HQ,CDR"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T
M(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S
M(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I9"`B5&AE($]P
M=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,C$Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(S"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C8T(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4:&4@861M
M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R
M;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES
M<VEO;G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T;VT@<VED
M92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)
M1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S
M(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0IM<V=I
M9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R
M(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3$V.0IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D(%!'
M4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S
M:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@(B(*(E1H92!D
M:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L
M(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D871A8F%S92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-#(*;7-G:60@(E1H92!D:7-T<FEB=71I;VX@;&ES="!W
M87,@;F]T('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+G!H<#HQ,3,*;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E871U
M<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<U(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z-3$S"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C@@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C$Y
M"FUS9VED(")4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L
M9BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,C@P
M"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV
M-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H
M:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B
M(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O
M8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S
M97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@
M66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K
M(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R
M87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@
M=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O
M=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H
M879E(&)E96X@=V%R;F5D+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO=2!S
M=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I9&4@
M;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HQ-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@
M8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z
M,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@
M;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P
M;&%Y960N7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S
M86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-PIM<V=I9"`B5&AE(&YA
M;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T,0HC
M+"!F=7IZ>0IM<V=I9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N
M=6UE<FEC+B(*;7-G<W1R(")!8V5A<W1A('9A;&]A<F4@=')E8G5I92!S82!F
M:64@;G5M97)I8V$N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HQ,C,Q"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER
M960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,N<&AP.C(Y,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@
M;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE("(*
M(FUA>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O9&5B+G!H<#HS,@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=V5B8W!P+G!H<#HS-PHC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@
M9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-30*
M;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE
M(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT
M(&%N9"!L969T('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I9"`B
M5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T-@IM<V=I9"`B5&AE('-E<&%R871O
M<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E
M;B!S879E9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@
M:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z,S,P"FUS9VED(")4:&4@<W!E8VEF:65D
M(')O=R!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HQ-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Q,0IM<V=I9"`B
M5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O
M;B!T:&4@<V-R965N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED(")4:&4@=&]P
M(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED
M(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1&%T82]$871A+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A
M<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R86UE=V]R:R]$
M871A+T1A=&$O='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO861E9"!F:6QE
M(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C0V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HU-@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$U(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,3D*;7-G:60@(E1H92!W96%T
M:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC
M.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$W.`HC+"!F
M=7IZ>0IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*
M;7-G<W1R(").=2!E>&ES=&$@<')E9F5R:6YT92!D:7-P;VYI8FEL92XB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HS-#(*;7-G:60@
M(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL
M:6YE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N
M>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@
M)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S
M+B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C4S(&%D;6EN+W5S97(N<&AP
M.C<S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@
M861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R(%PB)7-<
M(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O
M8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T
M<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,34Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@7"(E<UPB.B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX
M.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W
M:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W
M:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T
M:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#DQ"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@
M=7!L;V%D960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.0HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T
M82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]I;6,N<&AP
M.C,Q"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I
M0V%L96YD87(@9&%T82XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HX,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H
M92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@
M(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X"FUS9VED("(B"B)4
M:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D
M9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E
M<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O
M<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G
M86EN(&QA=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C(R,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N
M(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E
M('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS9VED(")4:&ES($E-05`@
M<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C0X"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED
M(')A<B!A<F-H:79E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P
M<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,30U"B,L(&9U>GIY"FUS9VED(")4
M:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BXB
M"FUS9W-T<B`B06-E87-T82!V86QO87)E('1R96)U:64@<V$@9FEE(&YU;65R
M:6-A+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO
M+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!
M4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HQ,S0*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L
M8RYC;VTI("(*(F=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB
M<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET
M86QY7W-M='`N<&AP.C@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A
M9F]N92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E
M<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A
M9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-S@@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3`U-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#@V
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,34*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$X,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C4V
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#4@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3,Y.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-34W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,SD*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3DU."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,#`U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,CD@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C`W.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,30Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,C$*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-#4T"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-3<@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C@R.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,3,W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,#8*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@Q-"!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS.#(R"FUS9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#8U"FUS9VED
M(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3@*;7-G:60@
M(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@
M8V]L;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$P.30*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A
M;"!V86QU97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R
M('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDX.0HC+"!F=7IZ>0IM<V=I
M9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R
M(")!8V5A<W1A('9A;&]A<F4@=')E8G5I92!S82!F:64@;G5M97)I8V$N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@S-@IM<V=I9"`B(@HB5&AI
M<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@
M2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU-C$*;7-G:60@(E1H
M:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HT-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI
M<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA
M="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R
M(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I<VET
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C4Y,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@
M=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA
M;B!Y;W5R(&]W;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@
M;&5A<W0@;VYE+B(*;7-G<W1R(")686QO87)E82!M:6YI;6$@97-T92`Q(@H*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS
M9VED(")4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII
M<"!F:6QE<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+U)E9VES=')Y+G!H<#HQ.#D*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E
M;G1L>2!D96%C=&EV871E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@;75S="!B
M92!A(&YU;6)E<BXB"FUS9W-T<B`B06-E87-T82!V86QO87)E('1R96)U:64@
M<V$@9FEE(&YU;65R:6-A+B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I
M8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D
M(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*;7-G:60@(E1H=6YD
M97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S
M-`IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-#(X('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U
M-0HC+"!F=7IZ>0IM<V=I9"`B5&EM92(*;7-G<W1R(")4:71L=2(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#8*;7-G:60@(E1I;64@5')A8VMI
M;F<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W"FUS9VED
M(")4:6UE(&9O<FUA="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-3,Y"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$P"FUS9VED(")4:6UO<BU,97-T92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y
M(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P"FUS9VED(")4:71L92(*;7-G<W1R
M(")4:71L=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM
M<V=I9"`B5&\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C8U-`IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I
M<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM
M86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B5&]D
M87DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1O9V\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA=2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$S"FUS9VED(")4;VUO<G)O
M=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-S<*;7-G:60@(E1O<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@
M9G)A;64@*%]T;W`I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV,PIM<V=I9"`B5')A;G-L871I;VYS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<Y,`IM<V=I9"`B5')U
M92!O<B!F86QS92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$P"FUS9VED(")4=6YI<VEA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3$*;7-G:60@(E1U<FME>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$Y,@IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES=&%N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#
M86EC;W,@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED
M(")4=79A;'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP
M.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-CD*;7-G:60@(E4N5BX@
M:6YD97@Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS
M9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U
M<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW"B,L
M(&9U>GIY"FUS9VED(")54DPZ(@IM<V=S='(@(E523"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3(*;7-G:60@(E5G86YD82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS
M9VED(")5:W)A:6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C0Q,@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&%C8V5S
M<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").=2!M82!P;W0@8V]N96-T82!L
M82!S97)V97)U;"!344PN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N
M=7`N<&AP.CDV"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF
M;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C,X.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,S@U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-C@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O
M<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HW-34*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@(DYU(&UA('!O="!C
M;VYE8W1A(&QA('-E<G9E<G5L(%-13"XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C(S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M8VAE8VL@9FEL92!S:7IE(&]F(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C@X(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z,3`Q-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z.#,T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F
M:6QE('-I>F4@;V8@7"(E<R\E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-Q;"YP:'`Z-#,U"FUS9VED(")5;F%B;&4@=&\@8V]N
M;F5C="!T;R!344P@<V5R=F5R+B(*;7-G<W1R(").=2!M82!P;W0@8V]N96-T
M82!L82!S97)V97)U;"!344PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX,SD*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I
M=&@@4U-,+B(*;7-G<W1R(").=2!M82!P;W0@8V]N96-T82!L82!S97)V97)U
M;"!344PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C(U(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C(P.0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N
M(@IM<V=S='(@(DYU(&UA('!O="!C;VYE8W1A(&QA('-E<G9E<G5L(%-13"XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,V-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HS-30@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(U.`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C4V"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYU
M(&UA('!O="!C;VYE8W1A(&QA('-E<G9E<G5L(%-13"XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3(T"B,L(&9U>GIY"FUS9VED(")5;F%B
M;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R(").=2!M82!P;W0@8V]N
M96-T82!L82!S97)V97)U;"!344PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HR.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R
M96%T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,C8U"B,L(&9U>GIY"FUS9VED(")5;F%B
M;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R(").=2!M82!P
M;W0@8V]N96-T82!L82!S97)V97)U;"!344PN(@H*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+W1A<BYP:'`Z-S8*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"FUS9VED(")5;F%B;&4@=&\@9&5C
M;VUP<F5S<R!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C(R-"!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(Y.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@
M=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z-S@@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@
M)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C,S,2!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,Y,@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S$Q(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HS,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T."!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4R"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S-R!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HS,S4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C,T,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0T"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN
M(@IM<V=S='(@(DYU(&UA('!O="!C;VYE8W1A(&QA('-E<G9E<G5L(%-13"XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0Q-R!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C0R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(P-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S`S(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C@X"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HQ-C<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C$X,`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@W(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.#,*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,Y,0IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HR-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HT,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@P,PHC+"!F=7IZ
M>0IM<V=I9"`B56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R
M>2XB"FUS9W-T<B`B3G4@<&]T(&EN<F5G:7-T<F$@<')E9F5R:6YT96QE(&EN
M('-E<VEU;F4@+2!D92!T<F%D=7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8P,PIM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R
M=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7TE-4U`O24U34"YP:'`Z-#4Q(&9R86UE=V]R:R].971?24U34"])35-0+T%U
M=&@N<&AP.C$Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A
M9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C(P,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,38V(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-S$*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R(").
M=2!M82!P;W0@8V]N96-T82!L82!S97)V97)U;"!344PN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HY,R!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C$P,@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C8T."!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.CDX"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C<W(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C$S,PIM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I
M;&4@9F]R('=R:71I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C@P(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$S
M,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R(").
M=2!M82!P;W0@8V]N96-T82!L82!S97)V97)U;"!344PN(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HT-0HC+"!F=7IZ>0IM<V=I
M9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R
M(").=2!M82!P;W0@8V]N96-T82!L82!S97)V97)U;"!344PN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C@S-0IM<V=I9"`B56YA8FQE('1O(')E860@
M5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C@V-@IM<V=I9"`B56YA8FQE('1O(')E
M860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R
M+VYO;F4N<&AP.C,X"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C8Y"FUS
M9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$P-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S
M.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(Y,PHC+"!F
M=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+B(*
M;7-G<W1R(").=2!M82!P;W0@8V]N96-T82!L82!S97)V97)U;"!344PN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,CD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-C<@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8Q,"!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C(Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(S(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HR,3,*(SH@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C0U,B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,C@U"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,#$*;7-G
M:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H
M<#HU,`IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z
M-3D*;7-G:60@(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M
M96YT(@IM<V=S='(@(DYU('!O="!T<F%D=6-E(&%C97-T(&1O8W5M96YT(%=O
M<F0@+2!D92!T<F%D=7,B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C$T.2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$U,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-SD*
M;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE
M9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C(X,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,X"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-#,*;7-G:60@(E5N86)L
M92!T;R!W<FET92!61E,@9FEL92!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z.#0Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*
M;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E
M9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B06YU
M;&5A>F$@4V-H:6UB87)I;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C
M=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HR,C,*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,SDP"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@
M<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0Q"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W.`HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#0*;7-G:60@(E5N97AP96-T960@
M<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV,0IM<V=I
M9"`B56YF:6QE9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$Y,PIM<V=I9"`B56YI8V]D92`H551&+3@I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4V"FUS9VED(")5;FET960@07)A8B!%;6ER871E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S0*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,SD@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO
M<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HV.2!L:6(O0FQO8VLO;65T87(N<&AP.C<Q"FUS
M9VED(")5;FET<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,CD@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#,P"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK
M;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3D*;7-G:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$
M*2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$U.0IM<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N
M="!E;&5M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])
M9&5N=&ET>2YP:'`Z,CDV"B,L(&9U>GIY"FUS9VED(")5;FYA;65D(@IM<V=S
M='(@(E5T:6QI>F%T;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R:7!T
M<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL
M>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A
M('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S
M('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP
M8F]A<F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C@V(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3(V"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3,R"FUS9VED(")5;G-U
M<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z,S,*;7-G:60@(E5P9&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E5P9&%T92`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C<V"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$T-"!A9&UI;B]P97)M<R]E9&ET
M+G!H<#HQ,#(@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R
M:7!T(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-S@@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$Y.0IM<V=I9"`B57!L;V%D(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ.#8*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO
M;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS
M.C(P"FUS9VED(")5<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$R-`IM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@
M:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,0HC+"!F=7IZ>0IM
M<V=I9"`B57-E<B(*;7-G<W1R(")5=&EL:7IA=&]R(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HW,C,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!9&UI
M;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C(U,0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(D]P
M=&EU;FD@571I;&EZ871O<B(*"B,Z('-I9VYU<"YP:'`Z-C(*(RP@9G5Z>GD*
M;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(D]P=&EU;FD@571I
M;&EZ871O<B(*"B,Z('-I9VYU<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T
M<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-CD*;7-G:60@(E5S
M97(@86-C;W5N="!N;W0@9F]U;F0B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W.0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HY.`HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ
M.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3`@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S,*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHW,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E
M+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B571I;&EZ871O<B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HQ,C0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E<UPB(&%L<F5A9'D@97AI<W1S
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M.#<*(RP@9G5Z>GD*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R(")5=&EL:7IA
M=&]R(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`HC+"!F=7IZ
M>0IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R(")5=&EL:7IA=&]R(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@
M:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I
M9"`B57IB96MI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HQ-C,@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C4U
M"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3$X"FUS9VED(")6
M86-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HX-C8*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV,S@*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0IM<V=I
M9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#4V(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Q-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@;W9E
M<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#0@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(V-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$V(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C@*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0IM<V=I9"`B5F%L=65S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#D@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-@IM<V=I9"`B5F%L=65S('1O('-E;&5C
M="!F<F]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E9A;G5A
M='4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(T-`IM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED(")697)I9FEC871I;VX@
M9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@
M=VET:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HW,#`*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R-@IM<V=I9"`B5F5R<VEO;B!#;VYT
M<F]L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L(&%L:6=N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PIM
M<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P"FUS9VED(")697)Y($AI9V@B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FEE="!.86TB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.30*;7-G:60@(E9I971N
M86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z.38R"B,L('!H<"UF;W)M870*;7-G:60@(E9I
M97<@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM
M<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,C$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@52Y3
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P.0IM<V=I
M9"`B5FES:6)I;&ET>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C8S"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT
M<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET86QY('9I82!33510(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($92
M3TT@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,3,S"FUS9VED(")724X@=FEA($A45%`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I
M;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]H=&UL+G!H<#HR-S(@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C@S"FUS9VED(")787)N:6YG(@IM<V=S='(@(D%T96YT:64B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")7
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,CD*;7-G:60@(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0R-PIM<V=I9"`B5V5A=&AE<B!D
M871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C@Y,@IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,W"FUS9VED(")7
M96(@4VET92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O
M36%I;G1E;F%N8V4N<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`B4V%P
M=&%M:6YA;"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"B,L
M(&9U>GIY"FUS9VED(")796QC;VUE(@IM<V=S='(@(D)I;F4@86D@=F5N:70L
M("5S(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z-"!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C4W"B,L('!H<"UF;W)M870*;7-G:60@(E=E
M;&-O;64@=&\@)7,B"FUS9W-T<B`B0FEN92!A:2!V96YI="!I;B!S:7-T96UU
M;"`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E;7!L
M871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7
M96QC;VUE+"`E<R(*;7-G<W1R(")":6YE(&%I('9E;FET+"`E<R(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")797-T97)N("A)4T\M.#@U
M.2TQ*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM
M<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,34I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@
M(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G
M:6X_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C$T"FUS9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM
M<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V
M,0IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*;7-G:60@
M(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D
M:71O<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R-0IM<V=I9"`B5VED
M=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE
M("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO
M9RUI;BDZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,3`*;7-G:60@(E=I9'1H('5N:70B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G
M:60@(E=I9'1H.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-3$S"FUS9VED(")7:6MI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C4*;7-G:60@(E=I;F0B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@
M(E=I;F0@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HX,`IM<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U-@IM<V=I9"`B5VEN9#HB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T,@IM<V=I
M9"`B5VEN9#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV-`IM<V=I9"`B5VES9&]M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ.38*;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3(T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R(")!9')E<V$@;&$@
M4V5R=FEC:74B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(E1E;&5F;VX@
M;&$@4V5R=FEC:74B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ
M-CD@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C8R"B,L('!H<"UF;W)M
M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@
M17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HS,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ
M,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE
M(')E861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(T,PIM<V=I9"`B6"U2968B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@
M(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,@IM<V=I9"`B6#4P.78S
M($5X=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S(%-U8FIE
M8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U8FIE
M8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#(*;7-G:60@(E@U,#EV,R!E>'1E;G-I
M;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED
M(")962(*;7-G<W1R(")!02(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0U-0HC+"!F=7IZ>0IM<V=I9"`B65E962(*;7-G<W1R
M(")!02(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,3`X"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@(EEE
M87)L>2(*;7-G<W1R(")!;G5A;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(EEE
M;65N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HY-C,*;7-G:60@(EEE<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM<V=I9"`B
M665S+"!)($%G<F5E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$58
M5"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T
M;R!765-)5UE'+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO961I
M="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL
M;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#$Q"FUS9VED(")9
M;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,P,@IM<V=I9"`B66]U(&-A
M;B!N;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA
M;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M-34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW-0IM<V=I9"`B66]U(&1I
M9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H
M92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B
M"B)I;B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP
M:'`Z.3@X"B,L(&9U>GIY"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O
M=70N(@IM<V=S='(@(D]P=&EU;FEL92!A=2!F;W-T('-A;'9A=&4N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(V,0IM<V=I9"`B(@HB66]U(&AA
M=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@
M;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T
M:6]N86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Q.#@*;7-G:60@(EEO=2!H879E('1O(&5N=&5R
M(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E
M(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT-38*;7-G:60@(EEO
M=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U
M(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N
M9"!T:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@(E1R96)U:64@<V$@9&5S
M8W)I:2!P<F]B;&5M82!I;F%I;G1E(&1E(&$@=')I;6ET92!R87!O<G1U;"XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX
M"FUS9VED(")9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN
M:R!P;VEN=',@=&\B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P
M8W-U;2YP:'`Z.#`*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@
M=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,3$Y"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE
M87(@;W5T+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#`*;7-G
M:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T
M:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ-#8*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE
M('1O('5P9&%T92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+WII<"YP:'`Z,3,X"FUS9VED(")9;W4@;75S="!S<&5C:69Y
M('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"FUS9VED
M(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M
M='`N<&AP.C<S"FUS9VED(")9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI
M86X@<&AO;F4@;G5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.CDW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R("5S('-E
M<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T
M<B`B4V5S:75N96$@=&$@9&4@)7,@82!E>'!I<F%T+B!492!R;V<@<V$@9F%C
M:2!,;V<@26X@9&EN(&YO=2XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHS.`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S
M(@IM<V=S='(@(D%D<F5S82!T82!D92!%;6%I;#HB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C$R"B,L(&9U>GIY"FUS9VED(")9;W5R($9R;VTZ(&%D
M9')E<W,Z(@IM<V=S='(@(D%D<F5S82!T82!D92!%;6%I;#HB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-C0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<T
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.#D*;7-G:60@(EEO=7(@26YF;W)M871I;VXB"FUS9W-T<B`B26YF
M;W)M871I:2!D97-P<F4@=&EN92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.CDX,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN=&5R;F5T
M($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y
M;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@
M>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S"B,L(&9U>GIY"FUS9VED(")9;W5R
M($YA;64B"FUS9W-T<B`B3G5M96QE('1A=3HB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]N;V%D9"YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A
M=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)
M9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R
M(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@(@HB875T:&5N
M=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;F]L:7-T+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I
M8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S
M+"!O<B!T:&4@9F5A='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M
M92!O=&AE<B!R96%S;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.CDX-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&)R
M;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN
M;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U<B!S
M96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]I9G)A;64N<&AP.C4P"FUS9VED(")9;W5R(&)R;W=S97(@
M9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"FUS9VED("(B"B)9
M;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO
M;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN="XB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U-PIM<V=I9"`B
M66]U<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<')E9G,N<&AP.CDV"B,L(&9U>GIY"FUS9VED(")9;W5R(&1E9F%U;'0@
M:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"XB"FUS9W-T<B`B3W!T:75N:6QE
M(&%U(&9O<W0@<V%L=F%T92XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,34X"B,L(&9U>GIY"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM
M<V=S='(@(DED96YT:71A=&4@26UP;&EC:71A(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(P,0HC+"!F=7IZ>0IM<V=I9"`B66]U<B!F=6QL(&YA;64Z
M(@IM<V=S='(@(DYU;65L92!T874Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z,3`P,`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!L;V=I;B!H87,@97AP
M:7)E9"XB"FUS9W-T<B`B3W!T:75N:6QE(&%U(&9O<W0@<V%L=F%T92XB"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34T"B,L
M(&9U>GIY"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@
M9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@(D]P
M=&EU;FEL92!A=2!F;W-T('-A;'9A=&4N(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E
M96X@=7!D871E9"XB"FUS9W-T<B`B3W!T:75N:6QE(&%U(&9O<W0@<V%L=F%T
M92XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B
M66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P
M87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@
M;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<S,@IM<V=I9"`B66]U<B!P
M87-S=V]R9"!H87,@97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9;W5R(')E;6]T92!S97)V
M97)S.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9
M=6=O<VQA=FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X
M"FUS9VED(")::6UB86)W92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-C8*;7-G:60@(EII<'!Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ
M-S(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*
M;7-G:60@(EM(:61E(%%U;W1E9"!497AT72(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P<F]B;&5M+G!H<#HX.`IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*
M;7-G<W1R(");4F%P;W)T(%!R;V)L96UA72(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(");4VAO=R!1=6]T960@
M5&5X="`M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&
M:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(EML:6YI82`E
M<R!D:6X@)7-=(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-30Q
M('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES
M=')A=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@
M(E]#3$DB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS9VED(")?
M1&%T851R964B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED(")?1&5L971E(%)O
M=R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@(E]'<F]U
M<',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N
M<&AP.C$W-0HC+"!F=7IZ>0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`B2&5L<"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y-`HC+"!F
M=7IZ>0IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R(")#;VYE8W1A<F4B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DP"B,L(&9U>GIY"FUS
M9VED(")?3&]G(&]U="(*;7-G<W1R(")$96-O;F5C=&%R92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM
M<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]-96YU+G!H<#HQ-C0*(RP@9G5Z>GD*;7-G:60@(E]/
M<'1I;VYS(@IM<V=S='(@(D]P=&EU;FDB"@HC.B!L:6(O87!I+G!H<#HQ,S<*
M;7-G:60@(E]097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*(RP@9G5Z
M>GD*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R(")3=&5R9V4@<&5R
M96-H96$B"@HC.B!L:6(O87!I+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM
M<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$R.0IM<V=I9"`B7U5S97)S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Q"B,L
M(&9U>GIY"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`B06=E;F1A(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S0*;7-G:60@
M(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.3$S"B,L(&9U>GIY"FUS9VED(")C86QE;F1A<B(*
M;7-G<W1R(")#86QE;F1A<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<R
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S4X"B,L('!H<"UF;W)M870*;7-G:60@
M(F-A;&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,@IM<V=I9"`B
M8VQI8VL@:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R
M<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,3<X"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34T"FUS
M9VED(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(V"FUS9VED
M(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$X,@IM<V=I9"`B96YT<GD@;F]T(&9O
M=6YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C<Q"FUS9VED(")F86QL:6YG(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U-0HC+"!F=7IZ>0IM<V=I
M9"`B9FEL92(*;7-G<W1R(")4:71L=2(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,3<T(&QI8B]";&]C:R]M971A<BYP:'`Z,S8P(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S@V"B,L('!H<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S("@E
M<RD@870@)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(U,`IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0Y"FUS9VED
M(")H.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,S4X"FUS9VED(")H:"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N
M86UE('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA
M=&4B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M
M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(FEN;&EN92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V,@IM<V=I
M9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S
M;V9T=V%R92!E<G)O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B;&EN97-=(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES
M;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES;V9S(&5R<F]R
M(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,V.0IM<V=I9"`B
M;6TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HR.3$@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W,`HC.B!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C,R"B,L(&9U>GIY"FUS9VED(")N
M86UE(@IM<V=S='(@(DYU;64B"@HC.B!F<F%M97=O<FLO4E!#+U)00RYP:'`Z
M,3(Q"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C$Y"FUS9VED(")N;W0@
M>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z.3`U"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ-S0*;7-G:60@(G!E<FUI<W-I;VX@9&5N
M:65D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I
M9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"B,L(&9U>GIY
M"FUS9VED(")R:7-I;F<B"FUS9W-T<B`B071E;G1I92(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,30R"FUS9VED(")S97)V:6-E('5N
M879A:6QA8FQE(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z.3D*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*
M;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@U"FUS9VED(")S
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HW,@IM<V=I9"`B<W1E861Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,S`Y"FUS9VED(")S=VET8V@@;V9F(&IA
M=F%S8W)I<'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR.0IM<V=I9"`B=&%S
M:R!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,38V"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P-0HC+"!F=7IZ
M>0IM<V=I9"`B=')Y(&%G86EN(@IM<V=S='(@(DQA(&9I96-A<F4@0V]N96-T
M87)E(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@9G)A;65W;W)K+T%U=&@O075T
M:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@='=I
M8V4@=&\@8V]N9FER;2(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F
M+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B=6YI9FEE
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U!A<G0N<&AP
M.C(W"FUS9VED(")U;FYA;65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B
M=7-E<B!S96QE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V
M0V%R9"`M(&1E('1R861U<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR-#$*;7-G:60@(G<Z(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED(")W96%T:&5R+F-O
M;2(*;7-G<W1R("(B"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]S:U]32RYP;P``
M````````````````````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`W,#`P-S`@,3`U,34T,S,W-#(@,#$W-3,S`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````",@2&]R9&4@4VQO=F%K('1R86YS
M;&%T:6]N+@HC($-O<'ER:6=H="`H0RD@,C`P,B!,96\@37)A9FMO(#QL96]`
M;V5L+G-K/B`H;W)I9VEN86P@=')A;G-L871O<BD*(R`H0RD@,C`P,BP@,C`P
M,R!)=F%N($YO<FES(#QV:7A`=F%Z:V$N<VL^"B,*;7-G:60@(B(*;7-G<W1R
M("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,5QN(@HB4F5P;W)T
M+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#
M<F5A=&EO;BU$871E.B`R,#`V+3`Q+3`V(#$T.C$P*S`Q,#!<;B(*(E!/+5)E
M=FES:6]N+41A=&4Z(#(P,#8M,#$M,S`@,C$Z,C8K,#(P,%QN(@HB3&%S="U4
M<F%N<VQA=&]R.B!)=F%N($YO<FES(#QV:7A`=F%Z:V$N<VL^7&XB"B),86YG
M=6%G92U496%M.B!3;&]V86L@/'9I>$!V87IK82YS:SY<;B(*(DU)344M5F5R
M<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S
M970]:7-O+3@X-3DM,EQN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@
M."UB:71<;B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S<S"B,L('!H<"UF
M;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B`H<')E9"`E
M<R!D\F%M:2DB"@HC.B!L:6(O2&]R9&4N<&AP.C$S-S0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B`H2VSA=F5S;W;A
M('-K<F%T:V$@)7,I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S.#$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R("(@*&\@
M)7,@9&[M*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S<W"FUS9VED("(@
M*'1O9&%Y*2(*;7-G<W1R("(H9&YE<RDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C,W.0IM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B("AZ86IT<F$I
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S4*;7-G:60@(B`H>65S=&5R
M9&%Y*2(*;7-G<W1R("(@*';H97)A*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U
M,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDV"FUS9VED("(@
M870@(@IM<V=S='(@(B!R_6-H;&]SNR`B"@HC.B!L:6(O5D93+W-M8BYP:'`Z
M,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E
M8W1O<GDN(@IM<V=S='(@(EPB)7-<(B!N:64@:F4@861R97/A<BXB"@HC.B!L
M:6(O2&]R9&4O0TQ)+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B7"(E<UPB(&YI
M92!J92!P;&%T;N$@=F^U8F$N(@H*(SH@;&EB+TAO<F1E+U)E9VES=')Y+G!H
M<#HV-3(@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HQ,#0P"B,L('!H<"UF;W)M
M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R
M9&4@4F5G:7-T<GDN(@IM<V=S='(@(EPB)7-<(B!N:64@:F4@;F%K;VYF:6=U
M<F]V86[I('8@<F5G:7-T<FD@2&]R9&4N(@H*(SH@;&EB+TAO<F1E+U1R964N
M<&AP.C$W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E92!R96YD
M97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(GIO8G)A>F]V8>@@<W1R;VUU(%PB
M)7-<(B!N96)O;"!NX6ID96[]+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-38*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@
M9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B4VMU<&EN82!<(B5S7"(@8F]L82!P
M<FED86[A(&1O('-Y<W3I;74N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N
M<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@
M=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B4'+A=F\@7"(E
M<UPB(&)O;&\@<')I9&%NZ2!D;R!S>7-TZ6UU+B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-30@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L('!H<"UF
M;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-R96%T960Z("5S+B(*;7-G
M<W1R(")<(B5S7"(@;F5B;VQO(&UOOF[I('9Y='9O<FF[.B`E<RXB"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T
M<B`B4&]UOFET_6-H("4N,F9-0B!Z(&1O=F]L96[]8V@@)2XR9DU"("@E+C)F
M)24I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B)60@)7,@
M82`E<R(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C(V."!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-34W"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&1A
M>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R("(E9"!D
M;NT@9&\@=GEP<KEA;FEA('!L871N;W-T:2!6X;EH;R!H97-L82XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C<T"B,L('!H<"UF;W)M870*
M;7-G:60@(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R(")P<F5D<&]V9>\@;F$@
M)60@9&[M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C8X"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B5S("T@4&]Z
M;N%M:V$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*;7-G<W1R(")/9'1L
M8>AO:R`E<R(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-#`@
M;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@T,@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!+0B(*;7-G<W1R("(E<R!+0B(*"B,Z('-E<G9I8V5S+VUA
M:6YT96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN
M=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(D]P
M97+A8VEE(/ID<KYB>2!P<F4@87!L:6OA8VEU("5S("T@4&]T=G)D96YI92(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G
M<W1R(").87-T879E;FEE("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P
M+G!H<#HR-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G
M<W1R(")296=I<W1R;W9A;FEE(&1O(&%P;&EKX6-I92`E<R(*"B,Z('-E<G9I
M8V5S+VUA:6YT96YA;F-E+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!497)M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`B4&]D;6EE;FMY('!O=;YI
M=&EA("5S(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C0S,B!L:6(O5D93+W-M8BYP
M:'`Z-#DT(&QI8B]61E,O9G1P+G!H<#HV-S$*(SH@;&EB+U9&4R]F='`N<&AP
M.C<S.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB
M"FUS9W-T<B`B)7,@=;X@97AI<W1U:F4N(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ-3D@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C4@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,SD*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#4@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@
M)7,@)7,B"FUS9W-T<B`B)7,@=F\@=OVY:V4@)7,@)7,B"@HC.B!S97)V:6-E
M<R]M86EN=&5N86YC92YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T
M:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@
M;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE
M+B(*;7-G<W1R("(B"B)!<&QI:^%C:6$@)7,@:F4@<')I<')A=F5NX2!N82!V
M>6MO;F%N:64@;W!E<N%C:>T@^F1ROF)Y+D]Z;F'H=&4@N71V;W+H96L@<')I
M("(*(F]P97+A8VGA8V@L(&MT;W+I(&-H8V5T92!V>6MO;F&[('1E<F%Z+B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S0T"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(E!OOF%D=6IE('-A("5S(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@;6EN=71E<R(*;7-G<W1R("(E<R!M:6[Z="(*"B,Z(&QI8B](;W)D
M92]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,C,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(E<R!N96)O;"!NX6ID96[]+B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B)7,@8;X@)7,@
M>B`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3(Q"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(D%D<F5SX7(@
M<&]UONUV871EM6$@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDQ,PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@(DMA
M;&5N9.%R('!O=;[M=F%T9;5A("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HY,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S
M='(@(E!O>F[A;6MY('!O=;[M=F%T9;5A("5S(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HY,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES
M="(*;7-G<W1R("):;WIN86T@^FQO:"!P;W6^[79A=&6U82`E<R(*"B,Z(&QI
M8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B)7,Z("5S(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@
M9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN
M9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD
M97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*
M(B5S.B!4X71O('-P<N%V82!N96UU<^T@8GF[(&]D(&]D;W-I96QA=&6U82P@
M:W1O<OT@<V$@>F]B<F%Z=6IE(&%K;R`B"B)O9&]S:65L871EM2!S<'+A=GDN
M(%IA8VAO=F%J=&4@;W!A=')N;W.[('!R:2!K;&EK86[M(&YA(&QI;FMY('8@
M<W!RX79E(&%L96)O("(*(G!O<VMY=&]V86[M(&]S;V)N_6-H(&EN9F]R;>%C
M:>T@;V1O<VEE;&%T9;5O=FDN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,U-"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDY"FUS
M9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(BP@;N%R87IO=OT@(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ.#@@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S='(@
M(BP@=B!NX7)A>F]C:"`E<R`E<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T
M;R`E<R(*;7-G<W1R("(L('!R96UE;F[A('8@<F]Z<V%H=2`E<R!AOB`E<R(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,#<S(&QI8B](;W)D92]&;W)M+G!H
M<#HR,3,R(&QI8B](;W)D92]097)M<R]522YP:'`Z,CDT"B,Z(&QI8B](;W)D
M92]097)M<R]522YP:'`Z,S0X(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HW-#4*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(M+2!V
M>6)E<G1E('-I("TM(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P"FUS9VED
M("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R("(Q,BUH;V1I;F]V_2!F;W)MX70B
M"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3D*;7-G:60@(C(T($AO=7(@1F]R
M;6%T(@IM<V=S='(@(C(T+6AO9&EN;W;](&9O<FWA="(*"B,Z('1E;7!L871E
M<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(R
M-"!H;V3M;B(*"B,Z(&QI8B](;W)D92]522]086=E<BYP:'`Z-CD*;7-G:60@
M(CQ0<F5V:6]U<R(*;7-G<W1R("(\4')E9&-HX61Z86KZ8V$B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$Q.0IM<V=I9"`B02!D871A8F%S92!B86-K96YD
M(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R(")0<F4@=&5N
M=&\@8FQO:R!J92!P;[YA9&]V86[](&1A=&%BX7IO=OT@8F%C:V5N9"XB"@HC
M.B!L:6(O2&]R9&4N<&AP.C$V,@IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@
M;V-C=7)R960B"FUS9W-T<B`B5GES:WET;&$@<V$@>N%V8;YNX2!C:'EB82(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.CDS-0IM<V=I9"`B02!P=6)L
M:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB
M"FUS9W-T<B`B3F$@>F&Y:69R;W9A;FEE('-P<N%V>2!J92!P;[YA9&]V86[]
M('9E<F5J;OT@4$A0(&NU^N@N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z,3$V.`IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T
M;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B3F$@;W9E<F5N
M:64@<&]D<.US86YE:B!S<'+A=GD@:F4@<&^^861O=F%N_2!V97)E:F[](%!'
M4"!KM?KH+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$P.3D*;7-G
M:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S
M86=E+B(*;7-G<W1R("(B"B).82!D9;EI9G)O=F%N:64@<W!RX79Y('/Z('!O
M=')E8F[I.B!V97)E:F[](%!'4"!KM?KH+"!P<FEVX71N>2!01U`@:[7ZZ"!A
M("(*(FAE<VQO+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$P,38*
M;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S
M86=E+B(*;7-G<W1R("(B"B).82!P;V1P[7-A;FEE('-P<N%V>2!S^B!P;[YA
M9&]V86[I.B!V<F5J;OT@4$=0(&NU^N@L('!R:7;A=&YY(%!'4"!KM?KH(&$@
M(@HB:&5S;&\N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU,#8*
M;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y
M<'0@82!M97-S86=E+B(*;7-G<W1R("(B"B).82!D9;EI9G)O=F%N:64@<W!R
MX79Y('/Z('!OOF%D;W9A;NDZ('9E<F5J;OT@4R]-24U%(&NU^N@L('!R:7;A
M=&YY(%,O34E-12`B"B)KM?KH(&$@:&5S;&\N(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K
M97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B"B).82!P
M;V1P[7-A;FEE('-P<N%V>2!S^B!P;[YA9&]V86[I.B!V97)E:F[](%,O34E-
M12!KM?KH+"!P<FEVX71N>2!3+TU)344@(@HB:[7ZZ"!A(&AE<VQO+B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U8FQI
M8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N
M(@IM<V=S='(@(DYA('IAN6EF<F]V86YI92!S<'+A=GD@:F4@<&^^861O=F%N
M_2!V97)E:F[](%--24U%(&NU^N@N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B04T@0VQO=61S(@IM<V=S='(@
M(E!R961P;VQU9&[M;2!O8FQAZ&YO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3`*;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS
M9W-T<B`B4')E9'!O;'5D;NUM(+5A:&O](&3AON\B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*
M;7-G<W1R(")0<F5D<&]L=61N[6T@9.&^[R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED(")!32!3:&]W97)S(@IM
M<V=S='(@(E!R961P;VQU9&[M;2!P<F5HX6YK>2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!32!3;F]W(%-H
M;W=E<G,B"FUS9W-T<B`B4')E9'!O;'5D;NUM('-N96AO=ND@<')E:.%N:WDB
M"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB
M"FUS9W-T<B`B,3(@:&]D[6XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S='(@(D%022!)1"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*
M;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@(D\@=&]M=&\@961I
M=&]R92(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4S"FUS9VED(")!
M8F]U="XN+B(*;7-G<W1R(")/+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B06)S8F]T=&]M(@IM<V=S
M='(@(D%B<V]L^G1N>2!S<&]D;VLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M:61D;&4B"FUS9W-T
M<B`B06)S;VSZ=&YY('-T<F5D(@H*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,C<P
M"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN
M(@IM<V=S='(@(E!R:2!V>71VX7)A;NT@5D93(&%D<F5SX7)A(&)O;"!Z86UI
M971N=73]('!R[7-T=7`N(@H*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,3,V"FUS
M9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G<W1R
M(")0<FD@=GET=N%R86[M(%9&4R!S^F)O<G4@8F]L('IA;6EE=&YU=/T@<'+M
M<W1U<"XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,PIM<V=I9"`B06-C
M;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FWA8VEE(&\@^NAT92(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.`IM<V=I9"`B06-C;W5N="!0
M87-S=V]R9"(*;7-G<W1R(")(97-L;R!P<F4@^NAE="(*"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O=6YT(&9R
M;WIE;BXB"FUS9W-T<B`BVNAE="!Z86)L;VMO=F%N_2XB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S,U"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S
M='(@(MKH=&]V86YI92(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,30X
M('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0IM<V=I9"`B061D(@IM<V=S='(@
M(E!R:61ANR(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T(&%D;6EN+V=R;W5P
M<RYP:'`Z,C(U"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B4')I
M9&&[('!O9')I861E;OH@<VMU<&EN=2(*"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z.3@@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HY.0IM<V=I9"`B061D
M($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`B4')I9&&[('!O9')I861E;ND@
M<'+A=F\B"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM<V=I9"`B
M061D($AE<F4Z(@IM<V=S='(@(E!R:61ANSHB"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q.0IM<V=I9"`B061D($YE=R!'
M<F]U<"(*;7-G<W1R(")0<FED8;L@<VMU<&EN=2(*"B,Z(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z.#<@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HX.`IM<V=I
M9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(E!R:61ANR!N;W;I('!R
MX79O(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!G<F]U<"!T;R!<
M(B5S7"(B"FUS9W-T<B`B4')I9&&[(&1CZ7)S:W4@<VMU<&EN=2!D;R!<(B5S
M7"(B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$T-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*
M;7-G<W1R(")0<FED8;L@9&/I<G-K92!P<N%V;R!D;R!<(B5S7"(B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S
M='(@(E!R:61ANR!P;W6^[79A=&6U83HB"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-34S"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S
M='(@(E!R:61ANR!S=.5P96,B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V5D:70N:6YC.C,T"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`B
M4')I9&&[(.AL96YO=B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(E!R:61ANR!PX7(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Q"B,L('!H<"UF;W)M870*;7-G:60@
M(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R
M(")0<FED8;L@;65N=2`E<R!A:V\@0F_H;OT@<&%N96P@36]Z:6QL>2(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*;7-G:60@(D%D
M9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(E!R:61ANR!D;R!A9')E<^%R
M83HB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C<X"FUS
M9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(E!R:61ANR!D
M;R!M]&IH;R!A9')E<^%R82(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"FUS9VED
M(")!9&0@=7-E<B(*;7-G<W1R(")0<FED8;L@<&]UONUV871EM6$B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E
M9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D
M:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R("(B
M"B)<(B5S7"(@8F]L('!R:61A;OT@9&\@<WES=.EM=2P@86QE(&YE;6^^;F\@
M<')I9&&[(.]A;+EI92!P<FEH;&%S;W9A8VEE("(*(FEN9F]R;>%C:64Z("5S
M+B(*"B,Z('-I9VYU<"YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D
M960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB
M"FUS9W-T<B`B7"(E<UPB(&)O;"!P<FED86[](&1O('-Y<W3I;74N(%1E<F%Z
M('-A(&WTOF5T92!P<FEH;.%S:;LN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;F]A9&0N:6YC.C(*;7-G:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE
M9"XB"FUS9W-T<B`B4')I9.%V86YI92!P;W6^[79A=&6U;W8@:F4@>F%KX7IA
M;NDN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#4@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ-S,*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`B061R
M97-A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$T,0IM<V=I9"`B
M061D<F5S<R!";V]K(@IM<V=S='(@(D%D<F5SX7(B"@HC.B!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30*;7-G:60@(D%D;6EN:7-T97(@+2!S
M970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S='(@(D%D;6EN
M:7-T<N%C:6$@+2!N87-T879E;FEE('!RX78@<')E(&EN_6-H('!O=;[M=F%T
M9;5O=B(*"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ.2!S97)V:6-E<R]P;W)T86PO
M<VED96)A<BYP:'`Z,3$S"FUS9VED(")!9&UI;FES=')A=&EO;B(*;7-G<W1R
M(")!9&UI;FES='+A8VEA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,T,PIM<V=I9"`B061S(@IM<V=S='(@(E)E:VQA;7DB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!9F=H
M86YI<W1A;B(*;7-G<W1R(")!9F=A;FES=&%N(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06QB86YI82(*
M;7-G<W1R(")!;&+A;G-K;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B06R^
M[7)S:V\B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$P
M-PIM<V=I9"`B06QI87,B"FUS9W-T<B`B06QI87,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$V"FUS9VED(")!
M;&EG;B(*;7-G<W1R("):87)O=FYANR(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N=#HB"FUS
M9W-T<B`B6F%R;W9N86YI93HB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M.#<*;7-G:60@(D%L;"(*;7-G<W1R(")6N65T:WDB"@HC.B!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8U
M"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*;7-G<W1R(")6N65T
M8VD@875T96YT:69I:V]V86[M('!O=;[M=F%T96QI82(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'
M<F]U<',B"FUS9W-T<B`B5KEE=&MY('-K=7!I;GDB"@HC.B!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.CDQ(&QI8B](;W)D92]097)M<R]D871A=')E92YP:'`Z
M-S4*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R(")6N65T:WD@<'+A
M=F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G<W1R(")6N65T
M:WD@N71Y<FD@<W1R86YY(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S4*
M;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R(")0;W9O
M;&F[('9I86-E<ND@861R97-Y(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4S.`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP
M93\B"FUS9W-T<B`B4&]V;VQINR!N87-T879E;FEE('1Y<'4@>F]R861E;NEH
M;R!Z;WIN86UU/R(*"B,Z(&QI8B](;W)D92]$871A5')E92]S<6PN<&AP.C4P
M-`IM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`B5;X@97AI<W1U:F4B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V"FUS9VED(")!;'1E<FYA
M=&4@24U34"!,;V=I;B(*;7-G<W1R(")!;'1E<FYA=.UV;F4@<')I:&QA<V]V
M86-I92!M96YO($E-4U`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$Q
M"FUS9VED(")!;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R(")!;'1E
M<FYA=.UV;F4@:&5S;&\@24U34"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU,#,*;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S='(@
M(D%L=&5R;F%T[79N92!P;W6^[79A=&6U<VOI(&UE;F\@24U34"(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED(")!;'1E<FYA=&4@
M96UA:6P@861D<F5S<R(*;7-G<W1R(")!;'1E<FYA=.UV;F$@92UM86EL;W;A
M(&%D<F5S82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!
M;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(D%L=&5R;F%T[79N92"Y86)L
M\VYY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS9W-T
M<B`B06QT97)N873M=FYY('1E>'0Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@4V%M;V$B
M"FUS9W-T<B`B06UE<FEC:^$@4V%M;V$B"@HC.B!L:6(O2&]R9&4O4')E9G,O
M54DN<&AP.CDU(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!
M;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N(@IM<V=S='(@(D)O;&$@
M>F%D86[A(&YE<&QA=&[A(&AO9&YO=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,34U"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O
M8V-U<F5D+B(*;7-G<W1R(").87-T86QA(&YE>F[A;6$@8VAY8F$N(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I
M9"`B06YD;W)R82(*;7-G<W1R(")!;F1O<G)A(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YG;VQA(@IM
M<V=S='(@(D%N9V]L82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I;&QA(@IM<V=S='(@(D%N9W5I
M;&QA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!
M;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B06YO;GEM;ND@<')O>'DB"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM
M<V=S='(@(D]D<&]V9>\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(D%N
M=&%R:W1I:V$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3D@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S='(@
M(D%N=&EG=6$@82!"87)B=61A(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HW
M-"!A9&UI;B]P:'!S:&5L;"YP:'`Z,S4@;&EB+TAO<F1E+T)L;V-K+U5)+G!H
M<#HU.`HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HV"FUS
M9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R(")!<&QI:^%C:6$B"@HC.B!U=&EL
M+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B
M"FUS9W-T<B`B6F]Z;F%M(&%P;&EKX6-I[2(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ-#`*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G
M<W1R(")!<&QI:^%C:6$@:F4@<')I<')A=F5NX2XB"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA
M<F5S(@IM<V=S='(@(D%P;&EK;W9ANR!N82!P;V1R:6%D96[I('ID:66U86[I
M('!R:67H:6YK>2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N
M:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(E-C:';A;&F[(@H*(SH@
M;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@T,`IM<V=I9"`B07!P<F]X
M:6UA=&4@4VEZ92(*;7-G<W1R(")0<FEB;&F^;N$@=F6U:V]SNR(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#(@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!<')I;"(*;7-G
M<W1R(")!<'+M;"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Q"FUS9VED
M(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+WII<"YP:'`Z-C8*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-S@*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@(E9EM6MO
M<[L@87)C:.UV=2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP
M.C4X(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8U"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<W"FUS9VED(")!<F-H:79E($YA
M;64B"FUS9W-T<B`B365N;R!A<F-H[79U(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@
M<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R(").86]Z86H@8VAC971E('9Y;6%Z
M8;L@OFEA9&]SNR!O('!R:6ALX7-E;FEE("<E<R<_(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<(B5S7"(@86YD
M(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R(").86]Z86H@8VAC971E('9Y;6%Z
M8;L@7"(E<UPB(&$@=KEE=&MY('!O9'-K=7!I;GD_(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B07)G96YT
M:6YA(@IM<V=S='(@(D%R9V5N=.UN82(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T
M<B`B07)MZ6YS:V\B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W,@IM<V=I
M9"`B07)M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B56UE;FEE
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,P(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU
M.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B07)U8F$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA;F0B"FUS9W-T
M<B`B3W-T<F]V($%S8V5N<VEO;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HR.0IM<V=I9"`B07-C:6D@07)T(@IM<V=S='(@(D%S8VEI('5M96YI92(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!<VEA+U!A
M8VEF:6,@4F5G:6]N(@IM<V=S='(@(L%Z:6$O4&%C:69I8VO](')E9VGS;B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,CD*;7-G:60@(D%S:R!F;W(@
M8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I
M;VYS/R(*;7-G<W1R(")6>;YA9&]V8;L@<&]T=G)D96YI92!P<F5D('9Y:V]N
M86[M;2!O<&5RX6-I[2#Z9'*^8GD_(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C,Q,#(*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E;7!T('1O(&1E;&5T
M92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B4&]K=7,@;R!V>6UA
M>F%N:64@;F5E>&ES='5J^F-E:B!S:W5P:6YY+B(*"B,Z(&%D;6EN+W!E<FUS
M+V1E;&5T92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N
M+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(E!O:W5S(&\@=GEM87IA
M;FEE(&YE97AI<W1U:OIC96AO('!RX79A+B(*"B,Z(&%D;6EN+W!E<FUS+V5D
M:70N<&AP.C@W"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E
M;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B4&]K=7,@;R#Z<')A=G4@;F5E>&ES
M='5J^F-E:&\@<'+A=F$N(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP
M.C4S"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA
M<F4N(@IM<V=S='(@(E!O:W5S(&\@^G!R879U(&YE97AI<W1U:OIC96AO('ID
M:66U86[I:&\@;V)J96MT=2XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M<F%R+G!H<#HV-"!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,0HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX,PIM<V=I9"`B071T
M<FEB=71E<R(*;7-G<W1R(")!=')I8OIT>2(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#8@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B075G=7-T
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Y(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU
M.0IM<V=I9"`B075S=')A;&EA(@IM<V=S='(@(D%U<W1RX6QI82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@
M(D%U<W1R:6$B"FUS9W-T<B`B4F%K^G-K;R(*"B,Z(&QI8B](;W)D92]!=71H
M+V-Y<G-Q;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@
M:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G-Q
M;#H@4&^^861O=F%NZ2!R;WJY[7)E;FEE(&EM87`@;F5B;VQO(&[A:F1E;NDN
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$S-0IM<V=I9"`B075T
M:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B
M:6QI=&5S+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!B86-K96YD(&YE;>$@<&^^
M861O=F%NZ2!S8VAO<&YO<W1I+B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S
M+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)U<SH@<&^^861O
M=F%NZ2!R;WJY[7)E;FEE(&EM87`@;F5B;VQO(&[A:F1E;NDN(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E
M<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W
M:71H('1H92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B"B)!
M=71H7V9T<#H@<&^^861O=F%NZ2!R;WJY[7)E;FEE($944"!N96)O;&\@;N%J
M9&5NZ2X@4VMO;7!I;'5J=&4@4$A0(',@(@HB<')E<.UN8>AO;2`M+65N86)L
M92UF='`N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:6UA<"YP:'`Z-C0*;7-G:60@
M(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R(")!=71H7VEM87`Z('!OOF%D;W9A;ND@<F]ZN>UR96YI92!)
M34%0(&YE8F]L;R!NX6ID96[I+B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N
M<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]K<F(U.B!P;[YA9&]V86[I
M(')O>KGM<F5N:64@:W)B-2!N96)O;&\@;N%J9&5NZ2XB"@HC.B!L:6(O2&]R
M9&4O075T:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@061D:6YG
M('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB
M"FUS9W-T<B`B(@HB075T:%]L9&%P.B!P<FEDX79A;FEE('!O=;[M=F%T9;5O
M=B!N:64@:F4@<&]D<&]R;W9A;ND@<')E($%C=&EV92!$:7)E8W1O<GDB"@HC
M.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS-3<*;7-G:60@(D%U=&A?;&1A
M<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E
M($1I<F5C=&]R>2(*;7-G<W1R("(B"B)!=71H7VQD87`Z('9Y;6%ZX79A;FEE
M('!O=;[M=F%T9;5O=B!N:64@:F4@<&]D<&]R;W9A;ND@<')E($%C=&EV92!$
M:7)E8W1O<GDB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HV,PIM<V=I
M9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(D%U=&A?;&1A<#H@<&^^861O=F%NZ2!R;WJY[7)E;FEE
M($Q$05`@;F5B;VQO(&[A:F1E;NDN(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A
M<"YP:'`Z,S,Y"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA
M8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED.B`B"FUS9W-T<B`B075T:%]L9&%P.B!.97!O9&%R:6QO('-A('!R:61A
MNR!P;W6^[79A=&6U82`E<RX@4V5R=F5R(&]D<&]V961A;#H@(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*;7-G:60@
M(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@
M(D%U=&A?;&1A<#H@;F5P;V1A<FEL;R!S82!O9'-T<N%N:;L@<&]UONUV871E
MM6$@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S
M97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B!N97!O9&%R:6QO('-A(&%K='5A
M;&EZ;W9ANR!P;W6^[79A=&6U82`E<R(*"B,Z(&QI8B](;W)D92]!=71H+VQD
M87`N<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I
M<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*;7-G<W1R
M("(B"B)!=71H7VQD87`Z(&%K='5A;&EZX6-I82!P;W6^[79A=&6U;W8@;FEE
M(&IE('!O9'!O<F]V86[A('!R92!!8W1I=F4@1&ER96-T;W)Y(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O;6-A;"YP:'`Z-#8*;7-G:60@(D%U=&A?;6-A;#H@4F5Q
M=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H
M7VUC86PZ('!OOF%D;W9A;ND@<F]ZN>UR96YI92!-0T%,(&YE8F]L;R!NX6ID
M96[I+B(*"B,Z(&QI8B](;W)D92]!=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U
M=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R(")!=71H7W-M8F%U=&@Z('!OOF%D;W9A;ND@<F]ZN>UR
M96YI92!S;6)A=71H(&YE8F]L;R!NX6ID96[I+B(*"B,Z(&QI8B](;W)D92])
M34%0+T%D;6EN+G!H<#HQ,#8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&%T($E-
M05`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B075T96YT:69I:^%C:6$@<&]M
M;V-O=2!)34%0('-E<G9E<F$@>FQY:&%L82XB"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM<V=I9"`B075T:&5N=&EC871I;VX@
M9F%I;&5D(@IM<V=S='(@(D%U=&5N=&EF:6OA8VEA('IL>6AA;&$B"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M075T:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R(")!=71E;G1I9FEK
MX6-I82!Z;'EH86QA+B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+W)A9&EU<RYP
M:'`Z,3<V"FUS9VED(")!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)
M55,@<V5R=F5R+B(*;7-G<W1R(")397)V97(@4D%$2553('IA;6EE=&]L(&%U
M=&5N=&EF:6OA8VEU+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX-S$*;7-G:60@
M(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R
M(")!=71E;G1I9FEKX6-I82!P;VUO8V]U($944"!S97)V97)A('IL>6AA;&$N
M(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C<P"FUS9VED(")!=71H96YT:6-A=&EO
M;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N(@IM<V=S='(@(D%U=&5N=&EF
M:6OA8VEA('!O;6]C;W4@4TU"('-E<G9E<F$@>FQY:&%L82XB"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C<U"FUS9VED(")!=F%I;&%B;&4@9FEE
M;&1S.B(*;7-G<W1R(")$;W-T=7!NZ2!P;VQOOFMY.B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HS,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%Z97)B
M86EJ86XB"FUS9W-T<B`B07IE<F)A:F2^86XB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S`*;7-G:60@(D)/1D@@17AC=7-E<R(*;7-G<W1R(")"3T9(
M($5X8W5S97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O=6YD(@IM<V=S='(@(E!O
M>F%D:64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(D9A<F)A
M('!O>F%D:6$B"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX,0IM<V=I
M9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R("):;.D@:&5S;&\@
M<')E(&ME<F)E<F]S+B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C@S
M"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@(EILZ2!P
M;W6^[79A=&6U<VOI(&UE;F\@<')E(&ME<F)E<F]S+B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HT-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A:&%M
M87,B"FUS9W-T<B`B0F%H86UY(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C,X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R(")"
M86AR86IN(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S,*;7-G:60@(D)A
M;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HS-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A;F=L861E
M<V@B"FUS9W-T<B`B0F%N9VQA9.FY(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C,S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B"FUS9W-T
M<B`B0F%R8F%D;W,B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@7"(E
M<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B4')I9>AI;F]K(',@9W)A9FEK;W4@
M7"(E<UPB(&YE8F]L(&[A:F1E;OTN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S"FUS9VED(")"87-E;&EN92(*
M;7-G<W1R("):X6ML861N_2!R:6%D;VLB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QA<G5S(@IM<V=S
M='(@(D)I96QO<G5S:V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S4@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8P"FUS9VED(")"96QG:75M(@IM<V=S='(@(D)E;&=I
M8VMO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4P(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV,PIM<V=I9"`B0F5L:7IE(@IM<V=S='(@(D)E;&EZ92(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HT,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)E
M;FEN(@IM<V=S='(@(D)E;FEN(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C0Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R(")"
M97)M=61Y(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0V(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@(D)U=.%N(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G:60@(D)I<G1H
M9&%Y(@IM<V=S='(@(DYA<F]D96YI;GDB"@HC.B!L:6(O2&]R9&4O0FQO8VLO
M0V]L;&5C=&EO;BYP:'`Z,S4T"B,L('!H<"UF;W)M870*;7-G:60@(D)L;V-K
M(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G
M<W1R(")";&]K(%PB)7-<(B!A<&QI:^%C:64@7"(E<UPB(&YE8F]L(&[A:F1E
M;OTN(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDP"FUS9VED
M(")";&]C:R!3971T:6YG<R(*;7-G<W1R(").87-T879E;FEA(&)L;VMU(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C
M:R!4>7!E(@IM<V=S='(@(E1Y<"!B;&]K=2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G<W1R
M(")4=>ANZ2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B0F]L[79I82(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,#<*;7-G:60@(D)O;VMM87)K
M<R(*;7-G<W1R("):X6QOOFMY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`IM<V=I9"`B0F]R9&5R(@IM<V=S
M='(@(D]K<F%J(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B
MJ>UR:V$@;VMR86IA.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B
M3VMR86IE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,R(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R
M(")";W-N82!A($AE<F-E9V]V:6YA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.CDV"FUS9VED(")";W1H(@IM<V=S='(@(D]B92(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HT."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O='-W
M86YA(@IM<V=S='(@(D)O='-W86YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")";W1T;VTB"FUS
M9W-T<B`B0F]T=&]M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R(")"
M;W5V970@27-L86YD(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0T(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(D)R87KM;&EA
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#$*;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G
M<W1R(")"<FET<VOI(/IZ96UI92!V($EN9&EC:V]M(&]C9>%N92(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HT,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@
M(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@(D)R=6YE:2!$87)U<W-A;&%M
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,W(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HT,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B0G5L:&%R<VMO(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B
M0G5L;&5T960@3&ES="(*;7-G<W1R("):;WIN86T@<R!O9'+AOFMA;6DB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S8@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C0T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS
M9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B0G5R:VEN82!&87-O(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,Y(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HT-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I
M9"`B0G5R=6YD:2(*;7-G<W1R(")"=7)U;F1I(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0T-@IM<V=I9"`B0TU3(@IM<V=S='(@(D--4R(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED(")#4D,B
M"FUS9W-T<B`B0U)#(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M.3@*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM<V=S='(@(D1I
M<W1R:6)UZ&[I(&)O9'D@0U),(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P
M97)T:65S+BXN(@IM<V=S='(@(E9L87-T;F]S=&D@7V)U;FMY+BXN(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U,0IM<V=I9"`B0V%C:&4@
M:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T<B`B26YC:6%L:7KA8VEA
M('9Y<F]V;N%V86-E:B!P86WD=&D@;F5B;VQA(&1O:V]NZ&5NX2XB"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@R(&-O;F9I9R]H
M;V]K<RYP:'`N9&ES=#HY.#<*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$U-PIM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B2V%L96YDX7(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,U"FUS9VED(")#86QM(@IM
M<V=S='(@(D)E>G9E=')I92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R(")+
M86UB;V2^82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C<*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(DMA;65R=6XB"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N(&YO
M="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@
M861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB3F5P;V1A<FEL;R!S82!A=71O
M;6%T:6-K>2!O8FYO=FF[(&AE<VQO+"!K;VYT86MT=6IT92!S=F]J:&\@861M
M:6YI<W1RX71O<F$N(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HS-3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W<FET92!T;R!F:6QE(%PB)7-<(B(*
M;7-G<W1R(").97!O9&%R:6QO('-A('IA<.US8;L@9&\@<_IB;W)U(%PB)7-<
M(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,@IM<V=I9"`B0V%N)W0@861M
M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+B(*;7-G<W1R(").
M96UOOFYO(&%D;6EI<W1R;W9ANR!E>'1E<F[I(&]V;.%D8>AE('-E9&5N[2XB
M"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,C,U(&QI8B](;W)D92]!
M=71H+V-Y<G-Q;"YP:'`Z,S$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T
M(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM<V=S='(@(DYE<&]D87)I
M;&\@<V$@<W!O:FF[(',@24U!4"!S97)V97)O;3H@)7,B"@HC.B!L:6(O1FEL
M92]#4U8N<&AP.C0T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!O<&5N
M(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").97!O9&%R:6QO('-A(&]T=F]R:;L@
M<_IB;W(@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C0*;7-G:60@(D-A;F%D82(*;7-G<W1R(")+86YA9&$B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z,3(P"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-0HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*;7-G<W1R("):<G6Y
M:;LB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I
M9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(EIR=;EINR!S<'+A
M=G4@;R!P<F]B;.EM92(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS,C,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`B3F5P;V1A<FEL;R!S82!V>6UA>F&[('/Z8F]R(%PB)7-<(BXB"@HC
M.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HT-@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO
M8V]P>2YP:'`Z-3(*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I
M<F5C=&]R>2XB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!NX6ISNR!D;^AA<V[]
M(&%D<F5SX7(N(@H*(SH@;&EB+U9&4R])4T]7<FET97(N<&AP.CDQ"FUS9VED
M(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T
M97(N(@IM<V=S='(@(DYE;6^^;F\@<&]K<F'H;W9ANR!B97H@<&%R86UE=')A
M("=T87)G971&:6QE)RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,S$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<
M(BXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!O9'-T<N%N:;L@861R97/A<B!<
M(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T1A=&%4<F5E+G!H<#HQ,C@@;&EB+TAO
M<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L('!H<"UF;W)M870*;7-G:60@
M(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R(").
M96UOOFYO(&]D<W1RX6YINRP@97AI<W1U:F4@)60@;F%S;&5D;W9N[6MO=BXB
M"@HC.B!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HV,#@*;7-G:60@(B(*
M(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F
M;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*
M;7-G<W1R("(B"B).96UOOFYO('!R975S<&]R:6%D8;LL('!OZ&5T('!O;&^^
M:65K('!R92!P<F5U<W!O<FEA9&%N:64@;F5S^FAL87/M(',@<&_H=&]M("(*
M(G5L;[YE;OUC:"!P;VQOOFEE:RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@
M=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!S
M;65R;W9ANR!S<'+A=G4@;F$@=7+H96[I(.CM<VQO+B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HV-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A<&4@
M5F5R9&4B"FUS9W-T<B`B2V%P=F5R9'-KZ2!O<W1R;W9Y(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`IM<V=I
M9"`B0V%P=&EO;B(*;7-G<W1R(")4:71U;&]K(@H*(SH@;&EB+TYE="]335,O
M9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS"FUS9VED(")#871E9V]R
M:65S(&%N9"!,86)E;',B"FUS9W-T<B`B2V%T96?S<FEE(&$@<&]P:7-K>2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S4@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C4P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@V
M"FUS9VED(")#87EM86X@27-L86YD<R(*;7-G<W1R(")+86IM86YS:^D@;W-T
M<F]V>2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT
M"FUS9VED(")#96QL(%!H;VYE(@IM<V=S='(@(DUO8FEL;OT@=&5L96;S;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C4*;7-G:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G<W1R(")6;&%S=&YO
M<W1I(&)U;FMY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B5GEP
M;&YE;FEE(&)U;FMY.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*
M;7-G<W1R(")6;&%S=&YO<W1I(&)U;FMY(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN
M9SHB"FUS9W-T<B`B4F]Z;W-T=7`@8G5N:65K.B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,C<X"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`B36]B:6QN
M_2!T96QE9O-N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S0*;7-G:60@
M(D-E;'1I8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@
M(D-E;G1E<B(*;7-G<W1R(")$;R!S=')E9'4B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F
M<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B4W1R961O869R:6-KX2!R97!U8FQI
M:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-0IM<V=I9"`B0V5N=')A
M;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#`*;7-G:60@(D-E<G1I9FEC871E($1E
M=&%I;',B"FUS9W-T<B`B4&]D<F]B;ND@:6YF;W)MX6-I92!O(&-E<G1I9FEK
MX71E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,3(*;7-G:60@
M(D-E<G1I9FEC871E($]W;F5R(@IM<V=S='(@(E9L87-T;NUK(&-E<G1I9FEK
MX71U(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@
M(D-E<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(E!O;&ET:6MY('!R92!C
M97)T:69I:^%T>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C$@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P.`IM<V=I9"`B0VAA9"(*;7-G<W1R("+(860B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.CDV"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B6FUE;FF[
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,Q"FUS9VED(")#
M:&%N9V4@66]U<B!087-S=V]R9"(*;7-G<W1R("):;65N:;L@5F&Y92!H97-L
M;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.0IM<V=I9"`B(@HB0VAA
M;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N
M('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S
M='(@(B(*(DYA<W1A=F5N:64@;65N82!A(&%D<FEE<RP@:W1O<ND@=FED:6$@
MM75D:6$L(&ME[R#H[71A:OH@82!O9'!O=F5D86KZ(&YA(%9AN64@(@HB92UM
M86EL>2XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*;7-G
M:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E
M9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#;VYT86-T
M('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB6FUE;F$@:&5S;&$@
M;FEE(&IE('8@86MT=>%L;F5J(&MO;F9I9W5RX6-I:2!P;V1P;W)O=F%NX2X@
M($MO;G1A:W1U:G1E('-V;VIH;R`B"B)A9&UI;FES='+A=&]R82XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(W
M"FUS9VED(")#:&%R(@IM<V=S='(@(EIN86LB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H
M96-?:R!,:6YK+BXN(@IM<V=S='(@(E-?:V]N=')O;&]V8;L@;&EN:W4N+BXB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3D@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C4S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W
M"FUS9VED(")#:&EL92(*;7-G<W1R(")#:&EL92(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HV,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM
M<V=S='(@(LCM;F$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-@IM<V=I
M9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<W"FUS9VED(")#:&EN97-E(%1R861I
M=&EO;F%L("A":6<U*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O
M87!P+FEN8SHW"FUS9VED(")#:&]O<V4@07!P;&EC871I;VXZ(@IM<V=S='(@
M(E9Y8F5R=&4@87!L:6OA8VEU.B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU
M<"YP:'`Z,C<P"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R("):
M=F^U=&4@<VD@:&5S;&\B"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP
M.C(V.0IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B6G9OM71E
M('-I('!O=;[M=F%T9;5S:^D@;65N;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS,#(*;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SHB
M"FUS9W-T<B`B5GEB97)T92!S</1S;V(@>F]B<F%Z;W9A;FEA(&3A='5M;W8Z
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R
M(&]R9&5R960@;&ES=',I(@IM<V=S='(@(E9Y8F5R=&4@='EP(+ET_6QU('IO
M>FYA;74@*'!R92!Z;W)A9&5NZ2!Z;WIN86UY*2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HV-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-34*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H<FES=&UA
M<R!)<VQA;F0B"FUS9W-T<B`B5FEA;F_H;OT@;W-T<F]V(@H*(SH@;&EB+U9&
M4RYP:'`Z.3$S(&QI8B].970O4TU3+G!H<#HR.30*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S
M='(@(D1E9FEN[6-I82!T<FEE9'D@)7,@;F5B;VQA(&[A:F1E;N$N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*;7-G:60@
M(D-L96%R(@IM<V=S='(@(DIA<VYO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@
M=&%G<R(*;7-G<W1R(")/9'-T<N%N:;L@<'+M:V%Z>2!-4T]F9FEC92(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*;7-G:60@(D-L96%R(%%U97)Y(@IM
M<V=S='(@(E9Y;6%Z8;L@9&]T87HB"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]C;&5A<BYI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@
M=7-E<CH@)7,B"FUS9W-T<B`B3V1S='+A;FF[('!O=;[M=F%T9;5A.B`E<R(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,0IM<V=I9"`B
M0VQE87(@=7-E<B(*;7-G<W1R(")/9'-T<N%N:;L@<&]UONUV871EM6$B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`IM<V=I9"`B0VQE
M87(@=7-E<B!D871A(@IM<V=S='(@(E9Y;6%Z8;L@<&]UONUV871EM7-KZ2#Z
M9&%J92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$U"FUS9VED(")#;&5A<FEN9R!,871E(@IM<V=S='(@(DYE<VOT<B!V>6IA
M<VYE;FEE(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E
M+FAT;6PZ-C`*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(DML
M:6MN:71E('!R92!P;VMR8>AO=F%N:64B"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%14
M4"(*;7-G<W1R(")#;&EC:V%T96QL(&-E>B!(5%10(@H*(SH@<V5R=FEC97,O
M:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R
M"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`B6F%T=F]R:;L@;VMN;R(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0T"FUS9VED(")#;&]U9',B"FUS
M9W-T<B`B3V)L86MY(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,38*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R(")2X6YO
M(&]B;&'H;F\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(D]B;&'H;F\B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C4V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8T"FUS9VED
M(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R(")#;V-O<R`H2V5E
M;&EN9RD@27-L86YD<R(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI
M;F,Z,C,*;7-G:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`B6F)A;&F[
M($)OZ&[]('!A;F5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B
M"FUS9W-T<B`B6F)A;&5NZ2!O:W)A:F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;VQO;6)I82(*;7-G
M<W1R(")+;VQU;6)I82(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB
M+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#;VQO<B(*;7-G<W1R
M(")&87)B82(*"B,Z(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HS
M,C4@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`P('-E<G9I8V5S+VEM
M86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R(%!I8VME<B(*
M;7-G<W1R(")6_6)E<B!F87)B>2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M.#,U"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@(E;]8F5R(&9A
M<F)Y(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(E-TY7!C93HB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3DU,`IM<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G
M<W1R(").861P:7-Y('-TY7!C;W8B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C8V"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B2V]M:6MS(@H*(SH@
M861M:6XO8VUD<VAE;&PN<&AP.C(U"FUS9VED(")#;VUM86YD(@IM<V=S='(@
M(E!R[6MA>B(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M
M;6%N9"!3:&5L;"(*;7-G<W1R(")0<NUK87IO=OT@:6YT97)P<F5T97(B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D-O;6UE;G0B
M"FUS9W-T<B`B2V]M96YTX7(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4V-PIM<V=I9"`B0V]M;6]N($YA;64B"FUS9W-T<B`B0F6^;ND@;65N
M;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S`@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C4X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@T"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(DMO;6]R>2(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#;VUP86YY
M(@IM<V=S='(@(E-P;VQOZ&YO<[LB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R(")0;^CM=&'H92(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#8*;7-G:60@(D-O;F1I
M=&EO;B(*;7-G<W1R(")3=&%V(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-#D*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B4W1A=B(*"B,Z(&%D;6EN
M+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E
M<F5N8V5S(@IM<V=S='(@(E)O>F1I96QY('8@:V]N9FEG=7+A8VEI(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-@IM<V=I9"`B0V]N9FEG=7)A=&EO
M;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L
M;V]K+B(*;7-G<W1R("(B"B)+;VYF:6=U<N%C:6$@<')E('-Y;F-H<F]N:7KA
M8VEU(',@4$1!+"!I;G1E;&EG96YT;OUM:2!T96QE9O-N;6D@82!/=71L;V]K
M;VTN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0IM<V=I9"`B0V]N
M9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B2V]N9FEG=7+A
M8VEA('!O=')E8G5J92!A:W1U86QI>N%C:74N(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@
M)7,B"FUS9W-T<B`B2V]N9FEG=7)O=F&[("5S(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHU,0IM<V=I9"`B0V]N9FER;2!087-S=V]R
M9"(*;7-G<W1R(")0;W1V<N]T92!H97-L;R(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HU-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O(@IM<V=S
M='(@(DMO;F=O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4S(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV-0IM<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B
M;&EC(&]F('1H92(*;7-G<W1R(")$96UO:W)A=&EC:^$@<F5P=6)L:6MA($MO
M;F=O(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.2!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN
M96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`B4W!O:F5N:64@>FQY:&%L;RXB"@HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@
M9F%I;&5D.B`B"FUS9W-T<B`B4W!O:F5N:64@>FQY:&%L;SH@(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-SDP"FUS9VED(")#;VYN96-T:6]N(')E
M9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(DNU^N@@
M8F]L('IA;6EE=&YU=/T@<V5R=F5R;VT@=F5R96IN_6-H(&NU^NAO=BXB"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R
M=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B2[7ZZ"!B;VP@>F%M:65T
M;G5T_2!S97)V97)O;2!V97)E:F[]8V@@:[7ZZ&]V+B!$]'9O9#H@)7,@*"5S
M*2(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX-C4*;7-G:60@(D-O;FYE8W1I;VX@
M=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(E-P;VIE;FEE(',@1E10
M('-E<G9E<F]M('IL>6AA;&\N(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T
M.C$P,30*;7-G:60@(D-O;G1A8W1S(@IM<V=S='(@(DMO;G1A:W1Y(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N
M=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S
M(&)O;VLN(@IM<V=S='(@(DMO;G1A:W1Y(&)O;&D@^G-P9;EN92!V;&^^96[A
M(&1O(%;AN6AO(&%D<F5SX7)A+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]T9WHN<&AP.C8P"FUS9VED(")#;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E
M9"!F:6QE.B`B"FUS9W-T<B`B5'EP(&MO;7!R:6UO=F%NZ6AO('/Z8F]R=3HB
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HU-B!L:6(O2&]R
M9&4O34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=&=Z+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT
M<R!O9B!<(B5S7"(B"FUS9W-T<B`B3V)S86@@7"(E<UPB(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z,CD@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C,S"FUS9VED(")#;VYT:6YU92(*;7-G<W1R(")0;VMR8>AO=F&[
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HV,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M-@IM<V=I9"`B0V]O:R!)<VQA;F1S(@IM<V=S='(@(D-O;VMO=F4@;W-T<F]V
M>2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O:VEE
M(@IM<V=S='(@(D-O;VMI92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0IM<V=I9"`B0V]P>2(*;7-G<W1R
M(")+;W#M<F]V8;LB"@HC.B!L:6(O5D93+W-M8BYP:'`Z-#<R"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R(")+;W#M<F]V
M86YI92!Z;'EH86QO.B`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S
M='(@(DMO<.UR;W9ANR!V_6)E<B(*"B,Z(&QI8B].970O4TU3+W=I;E]H='1P
M+G!H<#HQ-S`@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I9"`B
M0V]S="!)1"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;W-T82!2:6-A(@IM<V=S='(@
M(DMO<W1A<FEK82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C8*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B4&]B
M<F6^:64@<VQO;F]V:6YY(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M.3<W"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@(@IM
M<V=S='(@(DYE<&]D87)I;&\@<V$@>F&Y:69R;W9ANR!S<'+A=G4@<&]M;V-O
M=2!01U`Z("(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$P-34*;7-G
M:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E.B`B"FUS9W-T<B`B3F5P
M;V1A<FEL;R!S82!P;V1P[7-ANR!S<'+A=G4@<&]M;V-O=2!01U`Z("(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,SDS"FUS9VED(")#;W5L9"!N
M;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B3F5P;V1A<FEL
M;R!S82!Z8;EI9G)O=F&[('-P<N%V=2!P;VUO8V]U(%,O34E-12XB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@;F]T
M(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@
M<&]D<.US8;L@<W!RX79U('!O;6]C;W4@4R]-24U%+B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R(").97!O9&%R
M:6QO('-A('!R:61ANR!K;VYT86MT+B`E<RXB"@HC.B!L:6(O2&]R9&4O1W)O
M=7`O;&1A<"YP:'`Z.38@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,3(Q"FUS
M9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B
M3F5P;V1A<FEL;R!S82!P<FEP;VIINR!K($Q$05`@<V5R=F5R=2XB"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-#4W"FUS9VED(")#;W5L9"!N;W0@8FEN
M9"!T;R!L9&%P('-E<G9E<B(*;7-G<W1R(").97!O9&%R:6QO('-A('!R:7!O
M:FF[(&L@3$1!4"!S97)V97)U(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C$U-B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C$W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L
M86YC92X@)7,B"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!O=F5R:;L@>F]S=&%T
M;VL@;F$@^NAT92X@)7,B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#0Q
M"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E<B(*;7-G
M<W1R(").87-T86QA(&-H>6)A('!R:2!P<NUS='5P92!K($Q$05`@<V5R=F5R
M=2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@7"(E<UPB('5S
M:6YG($944#H@)7,B"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!P<FEP;VIINR!K
M('-E<G9E<G4@7"(E<UPB('!O;6]C;W4@1E10.B`E<R(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS
M9W-T<B`B3F5P;V1A<FEL;R!S82!V>71V;W)INR!Z;WIN86T@<'+M:F5M8V]V
M+B`E<R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q,C@*;7-G:60@
M(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B`B"FUS9W-T<B`B3F5P;V1A
M<FEL;R!S82!D9;EI9G)O=F&[(%!'4"#Z9&%J93H@(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU,C,*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T
M(%,O34E-12!D871A+B(*;7-G<W1R(").97!O9&%R:6QO('-A(&1EN6EF<F]V
M8;L@4R]-24U%(/ID86IE+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E
M;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R(").97!O9&%R:6QO('-A('9Y;6%Z
M8;L@:V]N=&%K="X@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE
M=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYE<&]D87)I;&\@
M<V$@=GEM87IANR!Z;WIN86T@<'+M:F5M8V]V+B`E<R(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C,X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G
M<W1R(").97!O9&%R:6QO('-A('9Y;6%Z8;L@<VMR:7!T(&YA('5P9W)A9&4@
M:V]N9FEG=7+A8VEE(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C,X,2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY-3,*;7-G:60@
M(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A
M9&1R97-S+B(*;7-G<W1R(").97!O9&%R:6QO('-A('5RZ&F[(&4M;6%I;&]V
M^B!A9')E<W4@<'+M:F5M8W4N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E
M(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!S=&EA:&YU
MNR!C96S](&%D<F5SX7(N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C0Y,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I
M<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(").97!O9&%R:6QO('-A('KM<VMA
MNR!K;VUP;&5T;OT@>F]Z;F%M('!R[6IE;6-O=BXB"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0V"FUS9VED(")#;W5L9"!N;W0@9F5T
M8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*
M;7-G<W1R(").97!O9&%R:6QO('-A('KM<VMANR!K;VUP;&5T;OT@>F]Z;F%M
M('IO>FYA;6]V('!R[6IE;6-O=BXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]2
M96%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z(&QI8B]61E,O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@(DYE
M<&]D87)I;&\@<V$@;F'H[71ANR!S=')A=.EG:74@7"(E<UPB+B(*"B,Z(&QI
M8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q
M,`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO9&ER
M96-T+G!H<#HS,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD
M:7(@7"(E<UPB+B(*;7-G<W1R(").97!O9&%R:6QO('-A('-P=7-T:;L@;6MD
M:7(@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<Q.0IM
M<V=I9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME
M>7-E<G9E<BXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!Z[7-K8;L@=F5R96IN
M_2!KM?KH('IO('-E<G9E<F$@:[7ZZ&]V+B(*"B,Z(&QI8B]61E,O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N
M(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@;W1V;W)INR!<(B5S7"(@<')E('KA
M<&ES+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*(SH@;&EB+TYE
M="]335,O=VEN7VAT='`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!O='9O
M<FF[("5S+B(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z-#(P"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E
M7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@;W1V;W)I
MNR!M;V1U;"!-86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB+U9&4R])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB
M"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!O='9O<FF[(&%D<F5SX7(@7"(E<UPB
M+B(*"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ,3$@;&EB+TAO<F1E
M+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP
M:'`Z,C,W(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@;&EB+TAO
M<F1E+T=R;W5P+VQD87`N<&AP.C4Q-B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP
M:'`Z-C$R"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV-38@;&EB+TAO
M<F1E+T=R;W5P+VQD87`N<&AP.C8Y.0IM<V=I9"`B0V]U;&0@;F]T(')E86-H
M('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!P<FEP
M;VIINR!N82!,1$%0('-E<G9E<BXB"@HC.B!L:6(O5D93+T]B:F5C="YP:'`Z
M,C0P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R96%D("5S+B(*
M;7-G<W1R(").97!O9&%R:6QO('-A('!R9>CM=&&[("5S+B(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@
M<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O
M;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@8V]R<F5C="X@
M5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO
M=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB3F5P;V1A<FEL
M;R!S82!O8FYO=FF[(&AE<VQO('IA9&%NZ6AO('!O=;[M=F%T9;5A+B!.:65K
M=&]RZ2!A;&5B;R!VN65T:WD@(@HB<&]D<F]B;F]S=&D@;FEE('/Z('-P<N%V
M;F4N(%-K^G-T92!T;R!Z;F]V=2!A;&5B;R!K;VYT86MT=6IT92!6X;EH;R`B
M"B)A9&UI;FES='+A=&]R82P@86L@<&]T<F5B=6IE=&4@<&]M;V,N(@H*(SH@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.2!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0P"B,Z(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS-S<@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,X,PHC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y
M"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(DYE;6^^
M;F\@>NUS:V&[($%#3"(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E(&%D9')E<W,@8F]O:RX@)7,B"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!Z
M[7-K8;L@861R97/A<BX@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R
M971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3F5P;V1A
M<FEL;R!S82!Z[7-K8;L@>F]Z;F%M('!R[6IE;6-O=BX@)7,B"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N
M("5S(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@>NUS:V&[('IO>FYA;7D@<'+M
M:F5M8V]V("5S(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C$Y.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*;7-G:60@(D-O=6QD
M(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`B
M3F5M;[YN;R!Z[7-K8;L@:6YF;W)MX6-I92!O('9L87-T;F]S=&EA8V@@<V5R
M=F5R82(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@(D-O
M=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B3F5P;V1A
M<FEL;R!S82!V<N%T:;L@:V]N9FEG=7+A8VEU+B(*"B,Z(&QI8B]61E,O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S='(@
M(DYE<&]D87)I;&\@<V$@<W!U<W1INR!R;61I<B!<(B5S7"(N(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B3F5P
M;V1A<FEL;R!S82!U;&^^:;L@:V]N9FEG=7+A8VEU("5S+B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU
M.0IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N
M+B(*;7-G<W1R(").97!O9&%R:6QO('-A('5L;[YINR!ZX6QO:'4@:V]N9FEG
M=7+A8VEE+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U
M871I;VXZ("5S(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@=6QOOFF[('KA;&]H
M=2!K;VYF:6=U<N%C:64Z("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B3F5P;V1A
M<FEL;R!S82!U;&^^:;L@<VMR:7!T(&YA('5P9W)A9&4@;F%S=&%V96[M(&1O
M.B!<(B5S7"(N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O
M;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!U
M;&^^:;L@>N%L;VAU(&MO;F9I9W5RX6-I92`E<RXB"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD
M(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@
M96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@
M8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L
M;W<@=&\@)7,N(@IM<V=S='(@(B(*(DYE<&]D87)I;&\@<V$@>F%P[7-ANR!K
M;VYF:6=U<F'H;OT@<_IB;W(@)7,N($WTOF5T92!P;W6^:;L@;FEE:W1O<OH@
M>B`B"B)M;[YN;W-T[2!N82!ZX7!I<R!K\V1U(&YA("5S(&%L96)O('-K;W#M
M<F]V8;L@<G7H;F4@:_-D('5V961E;OT@;FF^N6EE(&1O("5S+B(*"B,Z(&QI
M8B](;W)D92]!=71H+VQD87`N<&AP.C$T,PIM<V=I9"`B0V]U;&0@;F]T('-E
M87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@
M:+5A9&&[(&YA($Q$05`@<V5R=F5R:2XB"@HC.B!L:6(O5D93+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB"FUS9W-T<B`B3F5P
M;V1A<FEL;R!S82!V>6UA>F&[(%PB)7-<(BXB"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B3F5P;V1A<FEL
M;R!S82!A:W1U86QI>F]V8;L@:V]N=&%K="X@)7,B"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S
M='(@(DYE<&]D87)I;&\@<V$@86MT=6%L:7IO=F&[('IO>FYA;2!P<NUJ96UC
M;W8N("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O
M<B!<(B5S7"(Z("5S(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@>F%P[7-ANR!K
M;VYF:6=U<N%C:74@<')E(%PB)7-<(CH@)7,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S<P"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA
M(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G
M<W1R(").96UOOFYO(&[A:G.[($)OZ&[]('!A;F5L($UO>FEL;'DN(%-K;VYT
M<F]L=6IT92P@OF4@:F4@<&%N96P@;W1V;W)E;OTN(@H*(SH@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H92!F;VQL;W=I;F<@
M<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@HB
M4&]UONUV871EM6]V:2!<(B5S7"(@<V$@;F5P;V1A<FEL;R!P<FED8;L@<'+A
M=F$@<')E('!R:67H:6YO:R!<(B5S7"(Z("5S(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$T,C,*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R(")0;^CM
M=&%N_2!T97AT(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S`*
M;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`B2W)A:FEN82(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR-S4*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B
M2W5R>GDB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G<W1R(")6>71V
M;W)INR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV.`IM<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R(")6
M>71V;W)INR!L:6YK=2(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E
M;&5C="YI;F,Z.30*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`B
M5GET=F]R:;L@;F]V_2(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HY,@IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(E9Y
M='9O<FF[('!O9'!R:67H:6YO:R(*"B,Z(&QI8B](;W)D92]097)M<R]522YP
M:'`Z,C0P"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(E!R
MX79A('1V;W)C=2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C$Y"FUS9VED
M(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`BR.US;&\@:W)E9&ET;F5J
M(&MA<G1Y(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P.2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-SD*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B0VAO<G;A='-K;R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*
M;7-G:60@(D-U8F$B"FUS9W-T<B`B2W5B82(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HR-@IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R(")!:W1U
MX6QN92`T(&;A>GDB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*;7-G:60@
M(D-U<G)E;G0@4V5S<VEO;G,B"FUS9W-T<B`B06MT=>%L;F4@<V5D96YI82(*
M"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS
M,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(D%K='7A;&YY(.AA<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T<B`B06MT=>%L
M;F$@55),(&IE(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,U"FUS9VED(")#
M=7)R96YT(%5S97)S(@IM<V=S='(@(D%K='7A;&YI('!O=;[M=F%T96QI82(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U<G)E;G0@5V5A
M=&AE<B(*;7-G<W1R(")!:W1UX6QN92!P;^AA<VEE(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(V-`IM<V=I9"`B0W5R<F5N="!C;VYD:71I
M;VXZ("(*;7-G<W1R(")!:W1UX6QN92!P;V1M:65N:WDZ("(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U
M<G)E;G0@<W1Y;&4B"FUS9W-T<B`B06MT=>%L;GD@N73];"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S
M=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R
M(").87-T879E;FEE(/IL;V@L(&MT;W+I('-A('-P^KF[86KZ('!R:2!P<FEH
M;.%S96[M(&1O(&%P;&EKX6-I92`E<RXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*
M;7-G<W1R(")6>7-T<FEH;OJ[(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G
M<W1R(")6>7-T<FEH;OJ[(';]8F5R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C8W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV-@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S(@IM<V=S='(@
M(D-Y<')U<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED(")#
M>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$W.0IM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@(D-Y
M<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C8W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#
M>F5C:"!297!U8FQI8R(*;7-G<W1R("+(97-KX2!R97!U8FQI:V$B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Y('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R(")$1"(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HS,C<P"FUS9VED("(B"B)$4TX@*'-E92!H='1P
M.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B
M+FEN=')O+61S;BYP:'`I(@IM<V=S='(@(B(*(D133B`H<&]Z<FD@:'1T<#HO
M+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI
M;G1R;RUD<VXN<&AP*2(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z
M-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(D1E;FYE(@H*(SH@861M:6XO9&%T
M871R964N<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@
M(E!R97IE<F'H(&3A=&]VZ6AO('-T<F]M=2`H1&%T851R964I(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C,R-C@*;7-G:60@(D1A=&%B87-E($QO;VMU<"(*
M;7-G<W1R(")6>6BU863A=F%N:64@=B!D871A8N%Z92(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR-#`R(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N
M<&AP.C<R"FUS9VED(")$871E(@IM<V=S='(@(D3A='5M(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G:60@(D1A=&4@4F5C
M96EV960B"FUS9W-T<B`B1.%T=6T@<')I:F%T:6$B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C<Y-@IM<V=I9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T<B`B
M5OUB97(@9.%T=6UU(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(X,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Q"FUS9VED(")$
M87DB"FUS9W-T<B`B1&7R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,V"FUS9VED(")$95]L971E($-O;'5M
M;B(*;7-G<W1R(")/7V1S='+A;FF[('-TY7!E8R(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,3`@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$96-E;6)E<B(*;7-G<W1R(")$
M96-E;6)E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G
M<W1R(")$97-I871K;W;I(.CM<VQA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT
M(@IM<V=S='(@(EIM96ZY:;L@;V1S861E;FEE(@H*(SH@;&EB+W!R969S+G!H
M<#HQ,3<@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ.#<*;7-G:60@(D1E9F%U
M;'0B"FUS9W-T<B`B4')E9&YA<W1A=F5NZ2(*"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"FUS9VED(")$969A=6QT($-O
M;&]R(@IM<V=S='(@(E!R961N87-T879E;N$@9F%R8F$B"@HC.B!L:6(O2&]R
M9&4O261E;G1I='DN<&AP.CDV"FUS9VED(")$969A=6QT($ED96YT:71Y(@IM
M<V=S='(@(E9AN6$@<')E9&YA<W1A=F5NX2!I9&5N=&ET82(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HV-PIM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G
M<W1R(")0<F5D;F%S=&%V96[]('!R[6MA>F]V_2!I;G1E<G!R971E<B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B1&5F:6YI=&EO;G,B
M"FUS9W-T<B`B1&5F:6[M8VEE(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW,2!L
M:6(O2&]R9&4O4&5R;7,N<&AP.C,R-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C0R,@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C0S.2!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C,V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-S`@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,PHC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Q-B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.CDX('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E
M+FEN8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM
M<V=I9"`B1&5L971E(@IM<V=S='(@(E9Y;6%Z8;LB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S(*;7-G:60@
M(D1E;&5T92!#96QL(@IM<V=S='(@(E9Y;6%Z8;L@8G5N:W4B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G<F]U<',N<&AP.C(R-PIM<V=I9"`B
M1&5L971E($=R;W5P(@IM<V=S='(@(E9Y;6%Z8;L@<VMU<&EN=2(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T.0IM<V=I9"`B1&5L971E($QO
M9R(*;7-G<W1R(")6>6UA>F&[('KA>FYA;2(*"B,Z(&QI8B](;W)D92]097)M
M<R]522YP:'`Z-S<@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ,#$*;7-G:60@
M(D1E;&5T92!097)M:7-S:6]N(@IM<V=S='(@(E9Y;6%Z8;L@<'+A=F\B"@HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E
M;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B5GEM87IANR!A(&]D
M<W1RX6YINR!S<'+A=GDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4W"FUS9VED(")$96QE=&4@8V5L;"(*;7-G
M<W1R(")6>6UA>F&[(&)U;FMU(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E(&-O;'5M
M;B(*;7-G<W1R(")6>6UA>F&[('-TY7!E8R(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z,30X"FUS9VED(")$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E
M;7!L871E(@IM<V=S='(@(E9Y;6%Z8;L@97AI<W1U:OIC=2!A;'1E<FYA=.UV
M;G4@N6%B;/-N=2(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-#(Q"B,L
M('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E
M<UPB(@IM<V=S='(@(E9Y;6%Z8;L@<'+A=F$@<')E(%PB)7-<(B(*"B,Z(&QI
M8B](;W)D92]097)M<R]522YP:'`Z-#(T"B,L('!H<"UF;W)M870*;7-G:60@
M(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E
M<FUI<W-I;VYS/R(*;7-G<W1R(")#:&-E=&4@=GEM87IANR!<(B5S7"(@82!V
MN65T:WD@:F5H;R!P;V1P<N%V83\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@<F]W
M(@IM<V=S='(@(E9Y;6%Z8;L@<FEA9&]K(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V1E;&5T96ED96YT:71Y+FEN8SHQ-0IM<V=I9"`B1&5L971E('-E;&5C=&5D
M(&ED96YT:71Y(@IM<V=S='(@(E9Y;6%Z8;L@=GEB<F%N^B!I9&5N=&ET=2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV-PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(*;7-G
M<W1R(")6>6UA>F&[(&%K='7A;&YY('-TY7!E8R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,PIM<V=I9"`B
M1&5L971E('1H92!C=7)R96YT(')O=R(*;7-G<W1R(")6>6UA>F&[(&%K='7A
M;&YY(')I861O:R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,V"B,L
M('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I
M<'0@7"(E<UPB+B(*;7-G<W1R(")3:W)I<'0@;F$@=7!G<F%D92!K;VYF:6=U
M<N%C:64@7"(E<UPB(&)O;"!V>6UA>F%N_2XB"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-38S(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU.34*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,C$@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*;7-G
M:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`BR&%S(&1O<G7H96YI82(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G
M:60@(D1E;FUA<FLB"FUS9W-T<B`B1.%N<VMO(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B
M;&5M(@IM<V=S='(@(E!O<.VY=&4@<')O8FSI;2(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HY-#(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B4&]P
M:7,B"@HC.B!L:6(O2&]R9&4N<&AP.C$Y-PIM<V=I9"`B1&5T86EL<R`H86QS
M;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R(")0;V1R;V)N;W-T:2`H
M=&EEOB!V(&QO9V]V86-O;2!S^F)O<F4@2&]R9&4I(@H*(SH@;&EB+TAO<F1E
M+G!H<#HR,#$*;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@
M=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(D1E=&%I;'D@8F]L:2!Z87IN
M86UE;F%NZ2!P<F4@861M:6YI<W1RX71O<F$N(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(R,0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B
M5OUV;VHB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-PIM<V=I9"`B1&5W
M(%!O:6YT(@IM<V=S='(@(E)O<V[](&)O9"(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,CDT"FUS9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM
M<V=S='(@(E)O<V[](&)O9"!Z82!P;W-L961N^B!H;V1I;G4Z("(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*;7-G:60@(D1E=R!P;VEN
M=#H@(@IM<V=S='(@(E)O<V[](&)O9#H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE
M9G0@=&\@<FEG:'0B"FUS9W-T<B`B4VUE<B!ZM6%V82!D;W!R879A(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I
M9"`B1&ER96-T:6]N(')I9VAT('1O(&QE9G0B"FUS9W-T<B`B4VUE<B!S<')A
M=F$@9&^U879A(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@
M(D1I<F5C=&]R>2(*;7-G<W1R(")!9')E<^%R(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(W,`IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*
M;7-G<W1R("):;V)R87IO=F&[(.AA<R!V(#(T+6AO9&EN;W9O;2!F;W)MX71E
M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#`*;7-G:60@(D1I<W!L
M87D@3W!T:6]N<R(*;7-G<W1R(").87-T879E;FEE('IO8G)A>F5N:6$B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.#D*;7-G:60@(D1I<W!L
M87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`B6F]B<F%Z:;L@<&]D<F]B
M;OH@<')E9'!O=F7O(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX-0IM<V=I
M9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R("):;V)R87IINR!P
M<F5D<&]V9>\@*%1!1BDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@P-@IM
M<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B1F]R;>%T('IO8G)A>F5N
M:6$B"@HC.B!L:6(O2&]R9&4O34E-12]-1$XN<&AP.C$Y,`IM<V=I9"`B1&ES
M<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(E!O='9R9&5N:64@;R!D
M;W)UZ&5N[2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(D2^:6)U='-K;R(*
M"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-#(R"FUS9VED(")$;R!N;W0@
M9&5L971E(@IM<V=S='(@(DYE=GEM87IANR(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M
M86EN=&5N86YC92YP:'`B"FUS9W-T<B`B3F5P;W6^[79A:G1E('!R:6%M;R!M
M86EN=&5N86YC92YP:'`B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN
M8SHQ,B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E
M<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y
M97,L(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R(")/8G-A:'5J92!P<G;](')I
M861O:R!NX7IV>2!P;VSM/R!!:R#A;F\L('IAN6MR=&YI=&4@<&]L[>AK;SH@
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<R(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HW,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B1&]M:6YI8V$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C<Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")$
M;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B1&]M:6YI:^%N<VMA(')E<'5B
M;&EK82(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@
M(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B3F5M
MX71E(/KH970_(%IA<F5G:7-T<G5J=&4@<V$N(@H*(SH@;&EB+TAO<F1E+TU)
M344O0V]N=&5N=',N<&AP.C@U,0IM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B
M4W1I86AN=;LB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#4Q
M"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S(@IM<V=S='(@(E-T
M:6%H;G6[("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I
M9"`B1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C
M<FEP="XB"FUS9W-T<B`B4W1I86AN=;L@=GEG96YE<F]V86[Z(&MO;F9I9W5R
MX6-I=2!A:V\@4$A0('-K<FEP="XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C$Q,0IM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B6F]Z;F%M(',@
M=OUB97)O;2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B
M1')U9W,B"FUS9W-T<B`B1')O9WDB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HT,3,*;7-G:60@(D4M36%I;"(*;7-G<W1R(")%+6UA:6PB"@HC.B!L
M:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP.CDR"FUS9VED(")%36%I;"UT
M;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V
M:61E('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B
M"FUS9W-T<B`B15)2(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<U(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G<W1R(")%:W;A9&]R
M(@H*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHS-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,34@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C<R"B,Z('1E;7!L871E<R]P;W)T86PO961I
M="YI;F,Z,C4*;7-G:60@(D5D:70B"FUS9W-T<B`B57!R879INR(*"B,Z(&QI
M8B](;W)D92]";&]C:R]522YP:'`Z-3`@=&5M<&QA=&5S+W!O<G1A;"]E9&ET
M+FEN8SHR-0IM<V=I9"`B161I="!";&]C:R(*;7-G<W1R(")5<')A=FF[(&)L
M;VLB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y."!A9&UI;B]G<F]U<',N<&AP
M.C(R-@IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R(")5<')A=FF[('-K=7!I
M;G4B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C<V(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,3`P"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T
M<B`B57!R879INR!P<N%V;R(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H
M<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`B57!R879I
MNR!P<N%V82(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS
M9W-T<B`B57!R879INR!P<N%V82!P<F4@)7,B"@HC.B!T96UP;&%T97,O<')E
M9G,O87!P+FEN8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R
M(")5<')A=FF[(&YA<W1A=F5N:6$@<')E.B(*"B,Z(&QI8B](;W)D92]097)M
M<R]522YP:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES
M<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R(")5<')A=FF[('!RX79A('!R92!<
M(B5S7"(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T"B,L('!H
M<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S
M='(@(E5P<F%V:;L@<'+A=F$@<')E("5S(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,U"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B5GID96SA=F%N
M:64B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S<@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C<S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<P"FUS9VED(")%9WEP="(*;7-G<W1R(")%9WEP="(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C<T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B16P@
M4V%L=F%D;W(B"FUS9W-T<B`B4V%L=N%D;W(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L
M96UE;G0N+BXB"FUS9W-T<B`B16QE;65N="XN+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G
M<W1R(")%;2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<S(&QI8B](;W)D
M92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T"FUS9VED(")%;6%I;"(*;7-G
M<W1R(")%;6%I;"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-38V
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3`*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV.`IM<V=I9"`B16UA:6P@061D
M<F5S<R(*;7-G<W1R(")%;6%I;&]VX2!A9')E<V$Z(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$Y-C<*;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA
M=&-H+B(*;7-G<W1R(")%+6UA:6QO=ND@861R97-Y(&UU<VEA(&)YNR!R;W9N
M86OI+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.3DS"FUS9VED(")%;6%I
M;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")%+6UA:6P@<R!P;W1V<F1E
M;NUM(@H*(SH@;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I
M9"`B16UA:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B0G+A;F$@16UA:6PM
M;F$M4TU3(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(Y-PIM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(D5M;W1I:V]N>2(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R"FUS9VED(")%
M;7!T>2!M97-S86=E+B(*;7-G<W1R(")0<N%Z9&YA('-P<N%V82XB"@HC.B!L
M:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,C0S(&QI8B](;W)D92]'<F]U<"]L
M9&%P+G!H<#HT.#0*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C8V,B!L
M:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&QI8B](;W)D92]!=71H
M+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R(")0
M<N%Z9&YY(';]<VQE9&]K+B(*"B,Z(&QI8B](;W)D92]344PO2V5Y=V]R9',N
M<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@(E!R
MX7ID;F4@<&]D;6EE;FMY(&BU861A;FEA(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4T-PIM<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@
M9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B4&]V;VQI
MNR!V;&^^96YI92!O8G+A>FMO=B!Z($=A;.ER:>T@9&\@=&5X='4_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R,@IM<V=I9"`B16YA8FQE(')I9VAT
M(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B4&]V;VQINR!K;VYT97AT
M;W;I(&UE;G4@<')E('!R87;I('1L8>AI9&QO/R(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR-3DR(&QI8B](;W)D92]&;W)M+G!H<#HR.#`P"FUS9VED(")%
M;F0@>65A<B(*;7-G<W1R(")+;VYI96,@<F]K82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@
M161I=&]R(@IM<V=S='(@(EIVY.BY:;L@961I=&]R(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(R-`IM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q
M=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T
M;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N
M86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*(EIA9&%J=&4@8F5Z<&7H
M;F]S=&[Z(&]TX7IK=2P@;F$@:W1O<OH@8G5D971E(&UU<VEENR!O9'!O=F5D
M8;L@86L@>F%B=61N971E("(*(FAE<VQO+"!N87!R+B`G86MO('-A('9O;.$@
M;6]J92!Z=FEE<F%T:V\_)SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H
M92!I;6%G92!54DP@:&5R92(*;7-G<W1R("):861A:G1E(%523"!O8G+A>FMA
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@X.0IM
M<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S='(@(EIA9&%J
M=&4@<.US;65NX2!U=F5D96[I(&YIOKEI93HB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z.3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<V"FUS9VED(")%<75A=&]R:6%L
M($=U:6YE82(*;7-G<W1R(")2;W9N[6MO=N$@1W5I;F5A(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C<Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HW-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I
M=')E82(*;7-G<W1R(")%<FET<F5A(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HT."!L:6(O0FQO8VLO;65T87(N<&AP.C,V"B,Z('-E
M<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z.#(*;7-G:60@(D5R<F]R(@IM<V=S
M='(@(D-H>6)A(@H*(SH@;&EB+TAO<F1E+U1E;7!L871E+G!H<#HT-C,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@8W)E871I;F<@8FQO8VLZ("5S(@IM
M<V=S='(@(D-H>6)A('!R:2!V>71VX7)A;NT@8FQO:W4Z("5S(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S(@IM<V=S='(@(D-H
M>6)A('!R:2!V>6UA>N%V86[M('5K;W1V96YI82!S>6YC:')O;FEZX6-I93H@
M)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B"FUS
M9W-T<B`B0VAY8F$@<')I('9Y;6%ZX79A;NT@>N%Z;F%M=2!S>6YC:')O;FEZ
MX6-I93H@)7,B"@HC.B!L:6(O2&]R9&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM
M<V=S='(@(D-H>6)A('!R:2!Z[7-K879A;NT@;V)S86AU.B`E<R(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`B0VAY
M8F$@<')I(&%K='5A;&EZX6-I:2!H97-L83H@)7,B"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET:"!E
M;6%I;"!M97-S86=E+B(*;7-G<W1R(")#:'EB82!V(&4M;6%I;&]V96H@<W!R
MX79E+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+V-O<'DN<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET
M:6YG(%PB)7-<(BXB"FUS9W-T<B`B0VAY8F$@<')I('IA<&ES;W9A;NT@7"(E
M<UPB+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B17-T\VYS:V\B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C<X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED
M(")%=&AI;W!I82(*;7-G<W1R(")%=&GS<&EA(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T<B`B171N:6-KZ2(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B
M"FUS9W-T<B`B175R\W!A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T
M,PIM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R(")+8;YD_6-H(#$U
M(&UI;OIT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,PIM<V=I9"`B
M179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(DMAOF3I(#(@;6EN^G1Y(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,"!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,SDQ"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(DMAOF3]
M8V@@,S`@<V5K^FYD(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDT"FUS9VED(")%=F5R>2`U(&UI;G5T
M97,B"FUS9W-T<B`B2V&^9/UC:"`U(&UI;OIT(@H*(SH@;&EB+TAO<F1E+TUA
M:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T<B`B
M4')I(&MAOF1O;2!P<FEH;.%S96[M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,T-`IM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(DMAOF3Z
M('!O;&AO9&EN=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,Y,@IM<V=I9"`B179E<GD@;6EN=71E(@IM
M<V=S='(@(DMAOF3Z(&UI;OIT=2(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M
M87`N:6YC.C(T"FUS9VED(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`B3F%P
M<NUK;&%D.B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HX,2!A9&UI;B]C;61S
M:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP.C$R-PIM<V=I9"`B17AE
M8W5T92(*;7-G<W1R(")3<'5S=&F[(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA
M>6]U="YP:'`Z-#<U"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B4F]Z8F%L:;LB
M"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R"FUS9VED(")%
M>'!A;F0@4VED96)A<B(*;7-G<W1R(")2;WIB86QINR!";^AN_2!P86YE;"(*
M"B,Z(&QI8B](;W)D92]344PO2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP
M96-T960@)RDG(@IM<V=S='(@(D_H86OA=F$@<V$@)RDG(@H*(SH@;&EB+TAO
M<F1E+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B87)E
M('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@(D_H86OA=F$@
M<V$@<VQO=F\@86QE8F\@<&]D;6EE;FMA(&BU861A;FEA('8@^G9O9'IO=FOA
M8V@B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(D5X
M<&ER871I;VX@1&%T92(*;7-G<W1R(")$X71U;2!E>'!I<N%C:64B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8W-PIM<V=I9"`B17AP;VYE;G0B
M"FUS9W-T<B`B17AP;VYE;G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,Q"FUS9VED(")&1R!#;VQO<B(*;7-G
M<W1R(")&87)B82!T97AT=2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M-S<*;7-G:60@(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B3F%H<F&[
M(&MO;F9I9W5RX6-I=2!N82!&5%`B"@HC.B!L:6(O2&]R9&4O4')E9G,O<W%L
M+G!H<#HR,C4*;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S
M+B(*;7-G<W1R(").97!O9&%R:6QO('-A('KM<VMANR!N87-T879E;FEA+B(*
M"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HW-2!L:6(O2&]R9&4O075T
M:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!
M4"!S97)V97(N(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@<')I('-P;VIE;NT@
M<R!,1$%0('-E<G9E<F]M+B(*"B,Z(&QI8B](;W)D92]!=71H+W-M8BYP:'`Z
M.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM
M<V=S='(@(DYA<W1A;&$@8VAY8F$@<')I('!R[7-T=7!E(&L@4TU"('-E<G9E
M<G4N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<P-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B3F5P
M;V1A<FEL;R!S82!K;W#M<F]V8;L@>B!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F
M='`N<&AP.C<Q,0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P
M>2!T;R!<(B5S7"(N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@:V]P[7)O=F&[
M(&1O(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O075T:"]S87-L+G!H<#HX-PIM
M<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+B(*
M;7-G<W1R(").97!O9&%R:6QO('-A('9Y='9O<FF[(&YO=ND@4T%33"!S<&]J
M96YI92XB"@HC.B!L:6(O5D93+W-M8BYP:'`Z-3`Q(&QI8B]61E,O9G1P+G!H
M<#HW-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@
M7"(E<UPB+B(*;7-G<W1R(").97!O9&%R:6QO('-A('!R97-U;OJ[(&1O(%PB
M)7-<(BXB"@HC.B!L:6(O5D93+W-M8BYP:'`Z-#8U"B,L('!H<"UF;W)M870*
M;7-G:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`B3F5P;V1A
M<FEL;R!S82!Z[7-K8;LZ("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T<B`B1&]B<NDB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#0@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C<Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<R
M"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B
M1F%L:VQA;F1S:^D@;W-T<F]V>2`H36%L=NUN>2DB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z.#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@P
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&87)O92!)
M<VQA;F1S(@IM<V=S='(@(D9A97)S:^D@;W-T<F]V>2(*"B,Z(&QI8B](;W)D
M92]#3$DN<&AP.C(S.`IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@(EKA
M=F&^;N$@8VAY8F$Z(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R(")&87@B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S4Q"FUS9VED(")&87AE<R(*;7-G<W1R(")&
M87AY(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M,"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,X"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@
M(D9E8G)U87)Y(@IM<V=S='(@(D9E8G)UX7(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(R,`IM<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R(")0;V-I="!T
M97!L;W1Y(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,`IM
M<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(E!O8VET('1E<&QO='DZ("(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Y"FUS
M9VED(")&97<@4VAO=V5R<R(*;7-G<W1R(")-86SI('IRX;YK>2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS9VED(")&
M97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(DUA;.D@<VYE:&]VZ2!P<F5HX6YK
M>2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.30X"FUS9VED(")&:65L9"!M
M871R:7@B"FUS9W-T<B`B36%T:6-A('!O;.TB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,S,R,PIM<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,C<*;7-G:60@(D9I9VQE="!F;VYT
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B1FEDOFDB"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(D9I;&4B"FUS
M9W-T<B`B4_IB;W(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H
M<#HV,"!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(E!OZ&5T('/Z8F]R
M;W8Z("5S('/Z8F]R(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C`@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`B4&_H970@<_IB
M;W)O=CH@)7,@<_IB;W)O=B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT,#D*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R(")3<'+A=F-A('/Z
M8F]R;W8B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV,R!L
M:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,`HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=&=Z+G!H<#HX,@IM<V=I9"`B1FEL92!.86UE(@IM<V=S
M='(@(DUE;F\@<_IB;W)U(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y.#0*
M;7-G:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S='(@(E;]8F5R('/Z8F]R=2(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#DP"FUS9VED(")&:6QE('5P;&]A
M9"(*;7-G<W1R(").86AR871I92!S^F)O<G4B"@HC.B!L:6(O2&]R9&4O0G)O
M=W-E<BYP:'`Z.#@U"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E
M9"XB"FUS9W-T<B`B3F%H<N%V86YI92!S^F)O<F]V(&YI92!J92!P;V1P;W)O
M=F%NZ2XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3$*;7-G:60@
M(D9I;'1E<G,B"FUS9W-T<B`B1FEL=')E(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C@R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B1FEN;&%N9"(*;7-G
M<W1R(")&[6YS:V\B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED
M(")&:7)S="!(86QF(@IM<V=S='(@(E!R=N$@<&]L;W9I8V$B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED
M(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(E!R=N$@N71V<KLB"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4U"FUS9VED(")&:7@@
M<F%T:6\B"FUS9W-T<B`B4&5V;OT@<&]M97(B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,P"FUS9VED(")&;&EP(@IM<V=S='(@
M(D]T;^AINR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(E!LX79A:OIC
M:2!T97AT(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R(")(;6QA(@H*(SH@;&EB+U9&4R]S
M<6PN<&AP.C(S-R!L:6(O5D93+VUU<W%L+G!H<#HQ,#<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(E!R
M:67H:6YO:R`E<R!N965X:7-T=6IE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G
M<W1R(")&87)B82!P[7-M82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M-PIM<V=I9"`B1F]O9"(*;7-G<W1R(")0;W1R879A(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V"FUS
M9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(*
M;7-G<W1R(")0<F4@<')E:&QI861AZ&4L(&MT;W+I(&YE<&]D<&]R=6KZ(&]B
M<N%Z:WDB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S-`IM<V=I9"`B1F]R
M96-A<W0@*%1!1BDB"FUS9W-T<B`B4')E9'!O=F7O("A4048I(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<R"FUS9VED("(B"B)&;W)E8V%S
M="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R
M;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E
M(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*(E!R
M961P;W9E[R!N82!U=F5D96[]('!OZ&5T(&1N[2`H<&%MY'1A:G1E(&YA('1O
M+""^92!P<F5D<&]V9>\@:F4@<')E(&1N:2!A:B`B"B)N;V-I(&$@=&%K(&WT
MOF4@=F6U:^D@Z.US;&\@=GET=F]R:;L@=F6U;6D@N6ER;VO](&)L;VLI(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,#(*;7-G:60@(D9O<F=O
M="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R("):86)U9&QI('-T92!H97-L;S\B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8T"FUS9VED(")&;W)M
M<R(*;7-G<W1R(")&;W)M=6SA<F4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,C$*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`B1F]R='5N82(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM
M<V=S='(@(E1Y<"!F;W)T=6YY(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,X"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R(")&;W)T=6YY(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,Y"FUS9VED(")&;W)T=6YE<R`R(@IM<V=S
M='(@(D9O<G1U;GD@,B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M-34*;7-G:60@(D9O<G5M<R(*;7-G<W1R(")&\W)A(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$Q,0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B
M4')E<VUE<F]V86YI82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S='(@(E!I82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*
M;7-G:60@(D9R86UE<R(*;7-G<W1R(")2X6UC92(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HX-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92(*
M;7-G<W1R(")&<F%N8_IZ<VMO(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI=&%N(@IM<V=S='(@(D9R
M86YC^GIS:V\@*$5U<O-P82DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M.3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA(@IM<V=S
M='(@(D9R86YC^GIS:V$@1W5A>6%N82(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ.#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(")&<F5N8V@@4&]L>6YE
M<VEA(@IM<V=S='(@(D9R86YC^GIS:V$@4&]L>6[I>FEA(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(R,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&
M<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B1G)A;F/Z>G-K
M92!J=;YNZ2!T97)I=/-R:>$B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R(")/9"(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,T.0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,SDU"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B6F\@<VUE<G4@(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*;7-G:60@(D9U
M;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`BVG!L;OT@<&]P:7,B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-@IM<V=I
M9"`B1G5L;"!-;V]N(@IM<V=S='(@(E-P;&XB"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV
M,`IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(D-E;.D@;65N;SHB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C@W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S"FUS9VED
M(")'86)O;B(*;7-G<W1R(")'86)U;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L
M;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B1V%LZ7)I82P@>B!K
M=&]R96H@8VAC971E('9Z:6&[(&]B<N%Z;VLB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@
M(D=A;&QE<GDZ(@IM<V=S='(@(D=A;.ER:6$Z(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.CDV(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX.`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1V%M8FEA(@IM
M<V=S='(@(D=A;6)I82(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO
M;B(*;7-G<W1R(")'96YE<F]V8;L@:V]N9FEG=7+A8VEU('!R92!A<&QI:^%C
M:74@)7,B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ
M.`IM<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B1V5N97)O=F%N_2!K
M\V0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3`@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<T"FUS9VED(")'96]R9VEA(@IM<V=S='(@(D=E;W)G:6$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.CDP"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")'
M97)M86YY(@IM<V=S='(@(DYE;65C:V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z.3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':&%N82(*;7-G<W1R
M(")':&%N82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY-"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R(")':6)R86QTX7(B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W-@IM<V=I9"`B1VEV
M96X@3F%M92(*;7-G<W1R(")+<G-T;ND@;65N;R(*"B,Z('1E;7!L871E<R]P
M<F5F<R]A<'`N:6YC.C$R"FUS9VED(")';R(*;7-G<W1R(")/9&]S;&&[(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D96PB"FUS
M9W-T<B`B1V]E9&5L(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$Q,C@*;7-G:60@(D=O;V=L92!-87!S(@IM<V=S='(@(D=O;V=L
M92!-87!S(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B
M1V]O9VQE(%-E87)C:"(*;7-G<W1R(")(M6%D8;L@;F$@1V]O9VQE(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-@IM<V=I9"`B
M1W)A>7-C86QE(@IM<V=S='(@(D]D=&EE;F4@N65D96HB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3`P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HY,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W)E
M96-E(@IM<V=S='(@(D=RZ6-K;R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@Q"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDU(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HY-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I
M9"`B1W)E96YL86YD(@IM<V=S='(@(D=R\VYS:V\B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z.#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDU
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'<F5N861A
M(@IM<V=S='(@(D=R96YA9&$B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W.0IM
M<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R
MX6-I82!S:W5P[6XB"@HC.B!L:6(O2&]R9&4O1W)O=7`N<&AP.C4Y(&QI8B](
M;W)D92]'<F]U<"]L9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S(&UU
M<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(DUE;N$@<VMU<.UN(&YE<VWZ(&)Y
MNR!P<N%Z9&YE(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C,P-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D
M(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS
M9W-T<B`B1W)O=7!?;&1A<#H@3F5P;V1A<FEL;R!S82!P<FED8;L@<VMU<&EN
M=2`E<RX@4V5R=F5R(&]D<&]V961A;#H@(@H*(SH@;&EB+TAO<F1E+T=R;W5P
M+VQD87`N<&AP.C$Q."!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,3(T"B,Z
M(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<R(*
M;7-G<W1R(")'<F]U<%]L9&%P.B!N97!O9&%R:6QO('-A('9Y;6%Z8;L@<VMU
M<&EN=2`E<R(*"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HS,S@@;&EB
M+TAO<F1E+T=R;W5P+VQD87`N<&AP.C,W.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S
M='(@(D=R;W5P7VQD87`Z(&YE<&]D87)I;&\@<V$@86MT=6%L:7IO=F&[('-K
M=7!I;G4@)7,B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,Q-"!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(E-K=7!I;GDB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.CDV"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<V"FUS9VED
M(")'=6%D96QO=7!E(@IM<V=S='(@(D=U861E;&]U<&4B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3`S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HY-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A
M;2(*;7-G<W1R(")'=6%M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R(")'
M=6%T96UA;&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3(*;7-G:60@
M(D=U97)N<V5Y(@IM<V=S='(@(D=U97)N<V5Y(@H*(SH@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX.`IM
M<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B4'+A=F$@86YO;GEM
M;OUC:"!P;W6^[79A=&6U;W8B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#<R"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`B1W5E<W1B;V]K(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDW(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HY.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM
M<V=I9"`B1W5I;F5A(@IM<V=S='(@(D=U:6YE82(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P
M,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5I;F5A
M+4)I<W-A=2(*;7-G<W1R(")'=6EN96$M0FES<V%U(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$P-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=7EA
M;F$B"FUS9W-T<B`B1W5Y86YA(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDV
M-`IM<V=I9"`B2%1-3"(*;7-G<W1R(")(5$U,(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L
M;"!I;B!R;W<N(@IM<V=S='(@(DA434Q!<F5A(&YE9&]V;VSM('9Y;6%Z8;L@
M<&]S;&5D;OH@8G5N:W4@=B!R:6%D:W4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R
M96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN
M(&EN('1A8FQE+B(*;7-G<W1R(")(5$U,07)E82!N961O=F]L[2!V>6UA>F&[
M('!O<VQE9&[]('-TY7!E8R!V('1A8G6U:V4N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W
M(&EN('1A8FQE+B(*;7-G<W1R(")(5$U,07)E82!N961O=F]L[2!V>6UA>F&[
M('!O<VQE9&[](')I861O:R!V('1A8G6U:V4N(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O:'1T<"YP:'`Z,34W"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B2%144"!A=71E;G1I9FEKX6-I82!N96)O;&$@
M;N%J9&5NX2XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#(*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#`*;7-G:60@(DAA:71I(@IM<V=S='(@(DAA:71I(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")(87-H+4%L9V]R
M:71H;2(*;7-G<W1R(")!;&=O<FET;75S(&AA<VAO=F%C96H@9G5N:V-I92(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS
M9VED(")(87IE(@IM<V=S='(@(D]P87(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z.3(S(&QI8B](;W)D92]&;W)M+G!H<#HR.3(Q"FUS9VED(")(96%D97(B
M"FUS9W-T<B`B2&QA=FGH:V$B"@HC.B!L:6(O2&]R9&4O1F]R;2]4>7!E+W1A
M8FQE<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R(")(;&%V:>AK
M>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#<@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$P,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S
M(@IM<V=S='(@(DAE87)D;W8@;W-T<F]V(&$@36-$;VYA;&1O=F4@;W-T<F]V
M>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S
M"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(E-I;&[A(&+Z<FMA(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G:60@(DAE8G)E=R`H25-/
M+3@X-3DM."U)*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T"FUS9VED(")(96EG:'0B"FUS
M9W-T<B`B5OVY:V$B"@HC.B!L:6(O2&]R9&4O2&5L<"YP:'`Z,3@T(&QI8B](
M;W)D92](96QP+G!H<#HQ.#8@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<*
M(SH@=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C0*;7-G:60@(DAE;'`B"FUS
M9W-T<B`B4&]M;V-N[6LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G
M<W1R(")0;VUO8V[M:R!P<F4@<&]UONUV86YI92!E9&ET;W)A(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$S-S4*;7-G:60@(DAE;'!E<B(*;7-G<W1R(")0
M;VUO8V[M:R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B2&5M
M:7-P:&5R92(*;7-G<W1R(")0;VQO9W6U82(*"B,Z('1E;7!L871E<R]D871A
M+W1S=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$P
M"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM
M<V=S='(@(E1U(&IE('IAZ&EA=&]K('/Z8F]R=3HB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.0IM<V=I9"`B2&EG:"(*;7-G
M<W1R(")6>7-O:^$B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@
M=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C4*;7-G:60@(DAO
M7VUE(@IM<V=S='(@(D1O7VUO=B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6871I
M8V%N($-I='D@4W1A=&4I(@IM<V=S='(@(E9A=&EKX6XB"@HC.B!L:6(O2&]R
M9&4N<&AP.C$U,SD*;7-G:60@(DAO;64B"FUS9W-T<B`B1&]M;W8B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R,B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S
M(@IM<V=S='(@(D1O;>%C82!A9')E<V$B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-C0*;7-G:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S='(@(D1O;>%C
M:2!P<FEEZ&EN;VLB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R(")496QE9O-N(&1O
M;6]V(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P."!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R(")(;VYD=7)A<R(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#8@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$P-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.`IM
M<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(DAO;F<@2V]N9R(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HV-PIM<V=I9"`B2&]R9&4B"FUS9W-T<B`B
M2&]R9&4B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0T,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E
M;F-O=6YT97)E9"!I;B!M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B
M.B!V('-P<N%V92`E<R!B;VQI(&[A:F1E;ND@;F5P;&%T;ND@)7,@6$U,(/ID
M86IE(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HR.3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@
M=&\@;V)J96-T("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!S(&]B:F5K=&]M
M("5S(&YE:V]R9;EP;VYD=6IE(+YI861N82!S<'+A=F$N(@H*(SH@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HT,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@
M)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z('8@<W!RX79E("5S(&YE8F]L(&[A
M:F1E;OT@OFEA9&5N(&]B:F5K="!T>7!U("5S(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HQ,C0V"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T<B`B2&]R
M9&4O2V]L86(Z(/IS<&6Y;F4@;V1S='+A;F5NZ2`E<R!<(B5S7"(B"@HC.B!L
M:6(O2&]R9&4O2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H
M92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(
M4"!E>'1E;G-I;VXB"FUS9W-T<B`B2&]R9&4O2V]L86(Z(&EN=&5G<N%C:6$@
M=GF^861U:F4@4$A0(')O>KGM<F5N:64@)V1O;7AM;"<B"@HC.B!L:6(O2&]R
M9&4O2V]L86(N<&AP.C4P,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C
M="`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@;F5P;V1A<FEL;R!S82!V>71V
M;W)INR!N;W;](%A-3"!S=')O;2!P<F4@;V)J96MT("5S(@H*(SH@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HQ,C0S"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z(&YE<&]D87)I;&\@<V$@;V1S='+A;FF[("5S(%PB
M)7-<(CH@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0W,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E
M($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B2&]R
M9&4O2V]L86(Z(&YE<&]D87)I;&\@<V$@>NUS:V&[($U)344@240@<')E(.AA
M<[L@='EP=2`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3$Y,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H
M<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(&YE
M<&]D87)I;&\@<V$@<WEN8VAR;VYI>F]V8;L@)7,@7"(E<UPB.B`E<R(*"B,Z
M(&QI8B](;W)D92]+;VQA8BYP:'`Z,3,S,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@
M)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(&YE<&]D87)I;&\@<V$@<WEN8VAR
M;VYI>F]V8;L@>F1I9;5A;ND@;V)J96MT>3H@)7,B"@HC.B!L:6(O2&]R9&4O
M2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(Z
M(&YE>F[A;7D@>F1I9;5A;OT@;V)J96MT(%PB)7-<(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ
M;VYT86P@4G5L92(*;7-G<W1R(")(;W)I>F]N=.%L;F$@Z&EA<F$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@R"FUS9VED
M(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B2&]R:7IO;G3A;&YE('9Y
M<&QN96YI92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@(DAO<FEZ;VYT
MX6QN93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H
M4&QE87-E(')E<&]R="$I(@IM<V=S='(@(D%K;R!S=&4@<V$@<V5M(&1O<W1A
M;&D_("A0<F]S[6T@;F%H;.%S=&4A*2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY
M(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(DMO
MM6MO('-TY7!C;W8@8VAC971E('IL^NAINS\B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9I;F9O+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU
M;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@(EIA9&%J=&4@<&_H970@<&]L[2`H
M<W3E<&-O=BD_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y
M;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B2V^U:V\@<FEA9&MO=B!C:&-E
M=&4@>FSZZ&F[/R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M.#D@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S`*;7-G:60@(DAU;6ED:71Y(@IM
M<V=S='(@(E9L:&MO<[LB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C0X"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@(E9L:&MO<[LZ("(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S
M(@IM<V=S='(@(DAU;6]R:7-T:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R
M(")-8>]A<G-K;R(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ-S(@
M;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T
M<B`B3F5P;V1A<FEL;R!S82!V>71V;W)INR!)34%0('-C:'+A;FMU.B`E<R(*
M"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HR,30@;&EB+TAO<F1E+T%U
M=&@O8WER<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M
M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B3F5P;V1A<FEL
M;R!S82!V>6UA>F&[($E-05`@<V-H<N%N:W4Z("5S(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O8WER=7,N<&AP.C$W.2!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP
M.C(T,@HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@
M8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(").97!O9&%R:6QO('-A('9Y
M='9O<FF[($E-05`@:W;S='4Z("5S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$S,C`*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`B25`@861R97-A(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D
M9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B25`@861R97-A(&YI92!J
M92!D;W-T=7!NX2XB"@HC.B!L:6(O2&]R9&4O075T:"]I<&)A<VEC+G!H<#HX
M.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B
M;&]C:RXB"FUS9W-T<B`B25`@861R97-A(&YI92!J92!V('+A;6-I(&1O=F]L
M96[I:&\@0TE$4B!B;&]K=2XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*
M;7-G<W1R(")0;W)UN65N:64@<')A=FED;&$@;R!P979N96H@25`@861R97-E
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@
M(E9L;[YINR!KM?KH(%]P<F5D(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$R,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@R"FUS9VED("))8V5L86YD(@IM<V=S='(@
M(DES;&%N9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#`*;7-G:60@
M(DEC;VYS($]N;'DB"FUS9W-T<B`B26)A(&EK;VYY(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(DEC;VYS(&9O
M<B`E<R(*;7-G<W1R(")):V]N>2!P<F4@)7,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S@Q"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B
M26MO;GD@82!T97AT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,PIM
M<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R(").X7IO=B!I9&5N=&ET
M>3HB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z-3DY"B,L('!H
M<"UF;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C
M=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B
M06L@<V$@;F5Z;V)R87KM(&MO<F5K=&YE+"`E<R!A(&]T=F]R[2!S82!V(&YO
M=F]M(&]K;F4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U.0IM<V=I
M9"`B(@HB268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N
M970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O
M>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"B)!
M:R!N979I9.UT92!P<FD@<&]UOFET[2!);G1E<FYE="!%>'!L;W)E<F$@OFEA
M9&YE(&EK;VYY+"!P;W1R96)U:F5T92`B"B)Z8;EK<G1N^KL@=/IT;R!V;[5B
M=2!P<F4@=GEP;G5T:64@<')I97-V:71N;W-T:2!03D<@;V)RX7IK;W8N(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W,@IM<V=I
M9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T
M:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L
M87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*(D%K('9I9.UT92!T
M^G1O('-P<N%V=2!A(&YE=FED[71E(&]B<N%Z;VLL(&]B<N%Z;VLL(&MT;W+]
M('-T92!C:&-E;&D@;F%H<F&[+"`B"B)N96WTOF4@8GF[('IO8G)A>F5N_2!V
M;R!68;EO;2!P<F5H;&EA9&'H:2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*;7-G:60@(DEM86=E
M(%!R979I97<Z(@IM<V=S='(@(E5KX;YK82!O8G+A>FMA.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G
M:60@(DEM86=E(%523"(*;7-G<W1R(")54DP@;V)RX7IK82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R(")54DP@;V)RX7IK83HB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R(")/
M8G+A>F]K('H@9V%LZ7)I92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O
M;2!G86QL97)Y.B(*;7-G<W1R(")/8G+A>F]K('H@9V%LZ7)I93HB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3<V-0IM<V=I9"`B26UA9V4@=7!L;V%D(@IM
M<V=S='(@(DYA:')A=&EE(&]B<N%Z:W4B"@HC.B!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(D]B<N%Z:WDB"@HC.B!T
M96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW('1E;7!L871E<R]D871A+V1A
M=&5M87`N:6YC.C<*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-"!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW"B,L('!H<"UF;W)M870*;7-G
M:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("));7!O<G0L(&MR;VL@)60B
M"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P:'`M9F]R
M;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`B26UP;W)T
M;W9A;ND@<&]L93H@)7,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C8U"FUS9VED("));7!O<G1E9"!F:65L9',Z(@IM<V=S='(@(DEM<&]R=&]V
M86[I('!O;&EA.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2;W<@069T97(B
M"FUS9W-T<B`B5FQOOFF[(&NU^N@@7WIA(@H*(SH@;&EB+TAO<F1E+T-O;7!R
M97-S+WII<"YP:'`Z,3,T"FUS9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@
M9VEV96XN(@IM<V=S='(@(D)O;"!Z861A;OT@;F5S<'+A=FYY(&OS9"!A:V-I
M92XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"FUS
M9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+B(*;7-G
M<W1R(").97-P<N%V;F4@<&]UONUV871EM7-KZ2!M96YO(&$O86QE8F\@:&5S
M;&\B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B
M(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4
M<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@
M>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B).97-P<N%V;F4@
M<&]UONUV871EM7-KZ2!M96YO(&%L96)O(&%L=&5R;F%T[79N82!A9')E<V$N
M(%-K^G-T92!T;R!Z;F]V=2`B"B)A;&5B;R!K;VYT86MT=6IT92!S<'+A=F-U
M(%;AN6AO('-Y<W3I;74L(&%K('!O=')E8G5J971E('!O;6]C+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*;7-G:60@
M(DEN8W)E87-E($EN9&5N="(*;7-G<W1R("):=N3HN6F[(&]D<V%D96YI92(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,38@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$P.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M,0IM<V=I9"`B26YD:6$B"FUS9W-T<B`B26YD:6$B"@HC.B!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.C(U-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S
M-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R(")*961N;W1L:7;M
M('!O=;[M=F%T96QI82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3(@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(DEN
M9&]NZ7II82(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP
M.C8W"FUS9VED("));F9O(@IM<V=S='(@(DEN9F\B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C4Y"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R
M("));F9O<FWA8VEE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,Q.0IM<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB
M"FUS9W-T<B`B26YF;W)MX6-I92!UOB!N:64@<_H@9&]S='5P;NDN(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R(")6;&^^
M:;L@7W-TY7!E8R!Z82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B26YS97)T($EM86=E
M(@IM<V=S='(@(E9L;[YINR!O8G+A>F]K(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I9"`B26YS97)T(%1A8FQE
M(@IM<V=S='(@(E9L;[YINR!T86)UM6MU(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E8B!,
M:6YK(@IM<V=S='(@(E9L;[YINR!L:6YK=2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I9"`B26YS
M97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(E9L;[YINR!?<W3E<&5C('!R
M960B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C8*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@
M=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(E9L;[YINR!N;W;]('-TY7!E8R!Z
M82!A:W1UX6QN>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M
M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(E9L;[YINR!N;W;]
M('-TY7!E8R!P<F5D(&%K='7A;&YY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R"FUS9VED("));G-E<G0@
M82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R(")6;&^^
M:;L@;F]V_2!R:6%D;VL@>F$@86MT=>%L;GDB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@(DEN
M<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R
M(")6;&^^:;L@;F]V_2!R:6%D;VL@<')E9"!A:W1UX6QN>2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM
M<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO
M9&4B"FUS9W-T<B`B5FQOOFF[(&]D<W1A=F5C('IA(&%K='7A;&YY(&)O9"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@
M8W5R<F5N="!N;V1E(@IM<V=S='(@(E9L;[YINR!O9'-T879E8R!P<F5D(&%K
M='7A;&YY(&)O9"(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS9VED
M("));G-E<G0@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(E9L;[YINR!A
M;'1E<FYA=.UV;G4@N6%B;/-N=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-#(*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H
M('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R("):
M861A:G1E(&4M;6%I;&]V^B!A9')E<W4L(&YA(&MT;W+Z(&1O<W1A;F5T92!N
M;W;I(&AE<VQO.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM
M<V=S='(@(E9L;[YINR!B=6YK=2!Z82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R="!C
M96QL(&)E9F]R92(*;7-G<W1R(")6;&^^:;L@8G5N:W4@<')E9"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*
M;7-G:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`B5FQOOFF[('-T
MY7!E8R!Z82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM
M<V=S='(@(E9L;[YINR!S=.5P96,@<')E9"(*"B,Z(&QI8B](;W)D92])34%0
M+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM
M<V=S='(@(E9L;[YT92!S<'+A=GDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G:60@(DEN<V5R="!P
M87)A9W)A<&@@869T97(B"FUS9W-T<B`B5FQOOFF[(&]D<W1A=F5C('IA(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0T"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*;7-G<W1R
M(")6;&^^:;L@;V1S=&%V96,@<')E9"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!R
M;W<@869T97(B"FUS9W-T<B`B5FQOOFF[(')I861O:R!Z82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*;7-G
M:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM<V=S='(@(E9L;[YINR!R:6%D;VL@
M<')E9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S,*;7-G:60@(DEN
M<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S
M=&EO;CHB"FUS9W-T<B`B6F%D86IT92!P;[YA9&]V86[Z(&]D<&]V9>\@;F$@
M8F5Z<&7H;F]S=&[Z(&]TX7IK=3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(V"FUS9VED("));G-E<G0O36]D:69Y($EM
M86=E(@IM<V=S='(@(E9L;[YINR]U<')A=FF[(&]B<N%Z;VLB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("))
M;G-E<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B5FQOOFF[+W5P<F%V:;L@;&EN
M:W4B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS
M9VED("));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R
M:6)U=&EO;B!L:7-T+B(*;7-G<W1R(").82!O9&]S:65L86YI92!P<F4@>F]Z
M;F%M('!R[6IE;6-O=B!N96WA=&4@9&]S=&%T;^AN_2!K<F5D:70N(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS
M=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`B3F5D;W-T871OZ&[](&MR961I
M="XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`W.0IM<V=I9"`B26YT96=E
M<B(*;7-G<W1R(")#96SI(.CM<VQO(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$Q,S<*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R("):;WIN86T@8V5L
M_6-H(.AI<V5L(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.3<*;7-G:60@(DEN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN
M(@IM<V=S='(@(DYE<&QA9&[I(%5$2"`H57-E<B!$871A($AE861E<BP@2&QA
M=FGH:V$@<&]UONUV871EM7-K_6-H(/ID86IO=BDN(@H*(SH@;&EB+TAO<F1E
M+T-O;7!R97-S+WII<"YP:'`Z,38W(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N
M<&AP.C$Y-`HC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HR,3(*;7-G
M:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`B3F5P;&%T;ND@^F1A:F4@
M9F]R;>%T=2!:25`N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM
M<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`B3F5P;&%T;N$@
M87!L:6OA8VEA+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S$R"FUS9VED("));G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R(").97!L
M871NZ2!)1"!DX79K>2XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`Y,2!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C$V,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(S
M-@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,P,R!L:6(O2&]R9&4O1F]R;2]4
M>7!E+W1A8FQE<V5T+G!H<#HS-PIM<V=I9"`B26YV86QI9"!D871A('-U8FUI
M='1E9"XB"FUS9W-T<B`B0F]L:2!O9&]S;&%NZ2!N97!L871NZ2#Z9&%J92XB
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,`IM<V=I
M9"`B26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R(").97!L
M871NX2!C:66U;W;A(&%D<F5S82XB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O
M9&)X+G!H<#HQ,#D@;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP:'`Z,3,Y"B,Z
M(&QI8B](;W)D92]#;VUP<F5S<R]D8G@N<&AP.C(T,0IM<V=I9"`B26YV86QI
M9"!F:6QE(&9O<FUA="(*;7-G<W1R(").97!L871N_2!F;W)MX70@<_IB;W)U
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-0IM<V=I9"`B
M26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS9W-T<B`B3F5P;&%T;OT@;&EC96[H
M;OT@:[7ZZ"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y
M"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(")"
M;VQA('IA9&%NX2!N97!L871NX2!L;VMA;&ET82XB"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?
M='EP92XB"FUS9W-T<B`B3F5P;&%T;N$@:&]D;F]T82!M<V=?='EP92XB"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B
M26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`B3F5P;&%T;N$@
M86QE8F\@8VC]8F%J^F-A(&AO9&YO=&$@87!I7VED+B(*"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R
M(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`B3F5P;&%T;ND@86QE8F\@
M8VC]8F%J^F-E('!A<F%M971R92XB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL
M9"YP:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN(@IM
M<V=S='(@(DYE<&QA=&[I(')O9&GH;W9S:^D@<'+A=F\N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,0IM<V=I9"`B26YV86QI9"!P87)T
M;F5R(&ED+B(*;7-G<W1R(").97!L871NZ2!I9"!P87)T;F5R82XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38S"FUS9VED("));G9A;&ED
M('!R;V1U8W0@8V]D92XB"FUS9W-T<B`B3F5P;&%T;OT@:_-D('!R;V1U:W1U
M+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS
M9VED("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R(").97!L871N_2!P<F]T
M;VMO;"(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY,R!L
M:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z-S$*(SH@;&EB+TYE="]335,O=VEN
M7VAT='`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@<F5C
M:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`B3F5P;&%T;OT@<'+M:F5M8V$Z(%PB
M)7-<(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3`W-2!L:6(O2&]R9&4O
M2V]L86(N<&AP.C$R-3@*;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM
M<V=S='(@(DYE<&QA=&[](&]B:F5K="!Z9&EEM6%N:6$B"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B26YV86QI9"!S
M;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B3F5P;&%T;N$@>F1R;VIO=N$@861R
M97-A+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q
M"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T<B`B3F5P;&%T
M;ND@^F1A:F4@=6YI8V]D92XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S4Y"FUS9VED("));G9E;G1O<GDB"FUS9W-T<B`B26YV96YTX7(B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<U"FUS9VED
M("));G9E<G0@<V5L96-T:6]N(@IM<V=S='(@(DEN=F5R=&]V8;L@=OUB97(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$Y(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#(*;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B
M27+A;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3@@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("))<F%K(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$Q,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P"FUS9VED("))
M<F5L86YD(@IM<V=S='(@(LUR<VMO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B27-L92!O9B!-
M86XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M-`IM<V=I9"`B27-O;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B3VIE9&EN96SI
M(&+Z<FMY(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@P"FUS9VED("))<W)A96PB"FUS9W-T<B`B27IR865L(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,C8*;7-G:60@(DES<W5E<B(*
M;7-G<W1R(")6>61A=F%T9;4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET86QI8R(*;7-G<W1R(")+=7)Z
M[79A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R,2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@R"FUS9VED("))=&%L>2(*;7-G<W1R(")486QI86YS:V\B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(S(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G
M:60@(DIA;6%I8V$B"FUS9W-T<B`B2F%M86IK82(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HS.3D@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0S-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y(@IM<V=S='(@(DIA
M;G7A<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C4@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX,PIM<V=I9"`B2F%P86XB"FUS9W-T<B`B2F%P;VYS:V\B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B2F%P86YE<V4@*$E33RTR
M,#(R+4I0*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3(R"FUS9VED(")*97)S97DB"FUS9W-T<B`B2F5R<V5Y(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$R-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*
M;W)D86XB"FUS9W-T<B`B2F]R9.%N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P-2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`B2OIL(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-"!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T
M<B`B2OIN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R("):87)O=FYA
MNR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$U"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R("):87)O
M=FYANR!D;R!S=')E9'4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM
M<V=S='(@(EIA<F]V;F&[(&1O(&)L;VMU(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G:60@(DIU<W1I
M9GD@3&5F="(*;7-G<W1R("):87)O=FYANR!VM6%V;R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V"FUS9VED
M(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(EIA<F]V;F&[('9P<F%V;R(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S8@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$Q.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-@IM
M<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R(")+87IA8VAS=&%N(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(V,PIM<V=I9"`B2V5E
M<"!O<FEG:6YA;#\B"FUS9W-T<B`B4&]N96-H8;L@;W)I9VENX6P_(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS
M9VED(")+96YY82(*;7-G<W1R(")+9?)A(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B2V5R8F5R;W,@<V5R=F5R('IA;6EE
M=&]L(&%U=&5N=&EF:6OA8VEU+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B2V5R;F5L+6YO
M=N'H:6MO=FEA(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS
M9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`B5GET=F]R96YI92!KM?KH82(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I9"`B2V5Y($9I
M;F=E<G!R:6YT(@IM<V=S='(@(D1I9VETX6QN>2!O9'1L8>AO:R!KM?KH82(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE
M;F=T:"(*;7-G<W1R(")$Y;YK82!KM?KH82(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B5'EP(&NU
M^NAA(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3D*;7-G:60@
M(DME>2!5<V%G92(*;7-G<W1R(")0;W6^:71I92!KM?KH82(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI
M<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")+M?KH('6^
M(&5X:7-T=6IE(&YA('-E<G9E<FD@=F5R96IN_6-H(&NU^NAO=BXB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`B
M1&5T:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,CD@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B2VER:6)A=&DB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,R(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,C(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#4*
M;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F
M(@IM<V=S='(@(J5U9&]V;V1E;6]K<F%T:6-KX2!R97!U8FQI:V$@2_-R96$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,S(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,C,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#4*;7-G:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R(")+\W)E:G-K
MX2!R97!U8FQI:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I
M9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R
M-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2W5W86ET
M(@IM<V=S='(@(DMU=F%J="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R
M(")+:7)G:;ES:V\B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*
M;7-G:60@(DQA7WEO=70B"FUS9W-T<B`B5GI?:+5A9"(*"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@
M(DIA>GEK(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@W"FUS9VED("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U
M8FQI8R(*;7-G<W1R("),86]S(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V
M.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(E!O<VQE9&[A('!O;&]V:6-A
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<V"FUS9VED("),87-T(%!A
M<W-W;W)D($-H86YG92(*;7-G<W1R(")0;W-L961NX2!Z;65N82!H97-L82(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX-B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M.#@*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R(")0;W-L961NX2"Y='9R
MNR(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Q"FUS9VED("),87-T(%5P
M9&%T960Z(@IM<V=S='(@(E!O<VQE9&[A(&%K='5A;&EZX6-I83HB"@HC.B!L
M:6(O2&]R9&4O075T:"YP:'`Z-S$W"B,L('!H<"UF;W)M870*;7-G:60@(DQA
M<W0@;&]G:6XZ("5S(@IM<V=S='(@(E!O<VQE9&[I('!R:6ALX7-E;FEE.B`E
M<R(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R(")0;W-L961N
MZ2!P<FEH;.%S96YI93H@)7,@>B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+G!H
M<#HW,30*;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(E!O<VQE
M9&[I('!R:6ALX7-E;FEE.B!N:6MD>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R-PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&%T=FEA(@IM<V=S
M='(@(DQO='FY<VMO(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS
M9VED("),87<B"FUS9W-T<B`B4'+A=F\B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*;7-G:60@(DQA>6]U="(*
M;7-G<W1R(")6>FBU860B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R
M9&5R(@IM<V=S='(@(DYE8VAA:G1E('!RX7ID;F4@<')E(+YI861E;B!O:W)A
M:B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S@@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$R.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R("),:6)A;F]N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"FUS
M9VED("),969T(@IM<V=S='(@(E:U879O(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C,Q,#@*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(DAL879IZ&MA
M(':U879O(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#0*;7-G:60@(DQE
M9G0@=F%L=65S(@IM<V=S='(@(DAO9&YO='D@=K5A=F\B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,30S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,CD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQE
M<V]T:&\B"FUS9W-T<B`B3&5S;W1H;R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(U-0IM<V=I9"`B3&5V96PB"FUS9W-T<B`BVG)O=F7R(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X
M"FUS9VED("),:6)E<FEA(@IM<V=S='(@(DQI8NER:6$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,30W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,S$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI
M8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B3.UB>6$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,30P(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@
M(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B3&EC:'1E;KET86IN<VMO(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@
M(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`BI6%H:^D@;7)H;VQE;FEE(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*;7-G:60@
M(DQI9VAT(%)A:6XB"FUS9W-T<B`BI6%H:_T@9.&^[R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!2
M86EN($5A<FQY(@IM<V=S='(@(E+A;F\@M6%H:_T@9.&^[R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),:6=H
M="!286EN($QA=&4B"FUS9W-T<B`B3F5S:_1R(+5A:&O](&3AON\B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM<V=I9"`B
M3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`BI6%H:^D@9&&^[V]VZ2!P<F5H
MX6YK>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,P"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G<W1R("*E
M86AK_2!DX;[O(',@:')M96[M;2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H="!3;F]W(@IM<V=S='(@
M(J5A:&OI('-N9;YE;FEE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S
M='(@(J5A:&OI('-N96AO=ND@<')E:.%N:WDB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(DQI;65R:6-K
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X,3@*;7-G:60@(DQI;FLB"FUS
M9W-T<B`B3&EN:V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*
M;7-G<W1R("),:6YK82!U:V%Z=6IE(&YA.B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ.#<Y"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H
M92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@(E!R97!O
M:FF[(&4M;6%I;&]V^B!A9')E<W4@<V\@<W1RX6YK;W4@;F$@<.US86YI92!P
M;[ET>2(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]H=&UL,G1E>'0N<&AP
M.C$X,@IM<V=I9"`B3&EN:W,B"FUS9W-T<B`B3&EN:WDB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI92(*;7-G<W1R
M("),:6YU>"!#;V]K:64B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.#8*;7-G:60@(DQI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E
M<B(*;7-G<W1R("):;WIN86T@+2!P;W6^[79A=&6U('5V:63M('!R:67H:6YO
M:R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*;7-G:60@(DQI<W0@1&%T
M86)A<V5S(@IM<V=S='(@(E9Y<.US8;L@>F]Z;F%M(&1A=&%BX7HB"@HC.B!S
M97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,0IM<V=I9"`B3&ES="!(96QP(%1O
M<&EC<R(*;7-G<W1R("):;WIN86T@=.EM(%!O;6]C;NUK82(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,S(*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@
M(E9Y<.US8;L@>F]Z;F%M('1A8G5L:65K(@H*(SH@;&EB+TAO<F1E+TU)344O
M2&5A9&5R<RYP:'`Z-3DT"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T<B`B
M3&ES="U!<F-H:79E(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z
M-3@Y"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`B3&ES="U(96QP(@H*(SH@
M;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DV"FUS9VED("),:7-T+4ED
M(@IM<V=S='(@(DQI<W0M260B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S
M+G!H<#HU.3(*;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T<B`B3&ES="U/=VYE
M<B(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y,PIM<V=I9"`B
M3&ES="U0;W-T(@IM<V=S='(@(DQI<W0M4&]S="(*"B,Z(&QI8B](;W)D92]-
M24U%+TAE861E<G,N<&AP.C4Y,0IM<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS
M9W-T<B`B3&ES="U3=6)S8W)I8F4B"@HC.B!L:6(O2&]R9&4O34E-12](96%D
M97)S+G!H<#HU.3`*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`B
M3&ES="U5;G-U8G-C<FEB92(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,@HC
M+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@
M)7,B"FUS9W-T<B`B6F]B<F%Z96YI92!S961E;NT@>FQY:&%L;SH@)7,B"@HC
M.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3&ES=&EN9R!U<V5R<R!F86EL960Z("5S(@IM<V=S='(@(EIO8G)A>F5N:64@
M<&]UONUV871EM6]V('IL>6AA;&\Z("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED("),:7-T:6YG('5S97)S(&ES(&1I
M<V%B;&5D+B(*;7-G<W1R("):;V)R87IO=F%N:64@>F]Z;F%M=2!P;W6^[79A
M=&6U;W8@:F4@>F%KX7IA;NDN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0W"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@(DQI=&5R873Z<F$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30T(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,S,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*
M;7-G:60@(DQI=&AU86YI82(*;7-G<W1R("),:71V82(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]I;6%G97,N<&AP.C<W"FUS9VED("),;V%D:6YG+BXN
M(@IM<V=S='(@(DYAZ.UT879A('-A+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(P,`IM<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S='(@
M(DUI97-T;GD@Z&%S.B`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#8*
M;7-G:60@(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R("),;VMA;&EZX6-I82!A
M(.AA<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<R(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-PHC.B!L:6(O0FQO8VLO<W5N<FES
M92YP:'`Z,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HV-0IM<V=I9"`B3&]C871I
M;VXB"FUS9W-T<B`B3&]K86QI=&$B"@HC.B!L;V=I;BYP:'`Z,3@V('-E<G9I
M8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.3$@=&5M<&QA=&5S+VQO9VEN+VUO
M8FEL92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-2!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDP"FUS9VED("),;V<@:6XB"FUS
M9W-T<B`B4')I:&SA<V5N:64B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR-#4*;7-G:60@(DQO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB
M"FUS9W-T<B`B6N%Z;F%M>2!P<F5D8VCA9'IA:OIC96H@<WEN8VAR;VYI>N%C
M:64B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3@U"FUS9VED
M("),;V<@;W5T(@IM<V=S='(@(D]D:&SA<VF[(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C4Y"FUS9VED("),;V=I;B(*;7-G<W1R(")0<FEH;.%S96YI
M92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3`*;7-G:60@(DQO9VEN
M(%1A<VMS(@IM<V=S='(@(MIL;VAY('!R:2!P<FEH;.%S96[M(@H*(SH@;&EB
M+TAO<F1E+T%U=&@N<&AP.CDY,@IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U
M<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O
M<G)E8W1L>2XB"FUS9W-T<B`B(@HB4')I:&SA<V5N:64@>FQY:&%L;RP@<')E
M=&^^92!S=&4@>F%D86QI(&YE<W!RX79N92!P;W6^[79A=&6U<VOI(&UE;F\@
M86QE8F\@(@HB:&5S;&\N(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDX.`IM
M<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R(")0<FEH;.%S96YI92!Z;'EH
M86QO+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S8Y"FUS9VED("),;VYG
M('1E>'0B"FUS9W-T<B`B1&QH_2!T97AT(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0X"FUS9VED("),;W9E(@IM<V=S='(@(DSA<VMA(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(DQO
M=R(*;7-G<W1R(").[7IK82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K
M(&QE='1E<G,B"FUS9W-T<B`B36%LZ2!G<NEC:V4@<.US;65NX2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B36%LZ2!L
M871I;G-KZ2!P[7-M96[A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@
M;G5M8F5R<R(*;7-G<W1R(")-86SI('+M;7-K92#H[7-L:6-E(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$T-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y"FUS9VED
M("),=7AE;6)O=7)G(@IM<V=S='(@(DQU>&5M8G5R<VMO(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,Y."!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,V"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C4P"FUS9VED(")-32(*;7-G<W1R(")-32(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR.#,*;7-G:60@(DU/5$0B"FUS9W-T<B`B4W!RX79A(&3R
M82(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I
M9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G
M<W1R(")0<NUL;VAA($U3+51.148@;F5O8G-A:&]V86QA(+YI861N92#Z9&%J
M92XB"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL
M92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R(")-4T<B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,34W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,S4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA
M8V%O(@IM<V=S='(@(DUA8V%O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$U,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-86-E9&]N:6$L(%1H92!&
M;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T<B`B36%C963S;G-K
M;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3$@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$S-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R(")-861A9V%S:V%R(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"FUS9VED(")-86=I8R(*;7-G
M<W1R(")-X6=I82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX,PIM
M<V=I9"`B36%I;"(*;7-G<W1R(")0;[ET82(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HU,C0*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`B4&]S
M;&&[(&4M;6%I;"!A9&UI;FES='+A=&]R;W9I(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-
M86ME(&QI;E]K+BXN(@IM<V=S='(@(E9Y='9O<FF[(&QI;E]K=2XN+B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C4@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$S.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM
M<V=I9"`B36%L87=I(@IM<V=S='(@(DUA;&%W:2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S
M.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36%L87ES
M:6$B"FUS9W-T<B`B36%L86IZ:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,38T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&1I=F5S(@IM<V=S
M='(@(DUA;&5D:79Y(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86QI(@IM<V=S='(@(DUA;&DB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38R(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*
M;7-G:60@(DUA;'1A(@IM<V=S='(@(DUA;'1A(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDT"FUS9VED("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T
M96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L
M;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+B(*;7-G
M<W1R("(B"B)3<')A=F]V8;L@>F]Z;F%M(&MA=&5G\W)I[2P@<R!K=&]R_6UI
M(&]Z;F'H=6IE=&4@<&]L;[YK>2!A(&9A<F)Y(&%S;V-I;W9A;ND@(@HB<R!T
M_6UI=&\@:V%T96?S<FEA;6DN(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$Q-3,*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R(")-
M87!A($UA<#(T(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$P.#0*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$Q-C@*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R(")-87!A($UA<%%U
M97-T(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS9VED
M(")-87!P:6YG<R!S=&]R960N(@IM<V=S='(@(DUA<&]V86YI82!U;&^^96[I
M+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#$@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S.0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED(")-
M87)C:"(*;7-G<W1R(")-87)E8R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*;7-G:60@(DUA<F=I;B(*;7-G
M<W1R(")/:W)A:B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L86=S(@IM<V=S
M='(@(D]Z;F'H:;L@<'+M>FYA:VUI(%!R9>CM=&%NZ2].97!R9>CM=&%NZ2(*
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B
M36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E
M9"DB"FUS9W-T<B`B3WIN8>AINR!I;OUM:2!P<NUZ;F%K;6D@*&YA<'(N($3T
M;&6^:73I+UIO9'!O=F5D86[I*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%R<VAA;&P@27-L86YD
M<R(*;7-G<W1R(")-87)S:&%L;&]V92!O<W1R;W9Y(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$U.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-87)T
M:6YI<75E(@IM<V=S='(@(DUA<G1I;FEK(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R
M(")::&]D;ND@<&]L:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38P
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B
M36%U<F5TX6YI82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(DUA=7+M
M=&EU<R(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U
M"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(DUA>&EMX6QN
M>2!P;W9O;&5N_2!K<F5D:70N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#@*;7-G:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E
M9&5D+B(*;7-G<W1R(")";VP@<')E:W)OZ&5N_2!M87AI;>%L;GD@<&_H970@
MZ&%S=.T@<W!RX79Y+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`V"FUS
M9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B3F%J=GFY
MN6EA('1E<&QO=&$@>F$@<&]S;&5D;OUC:"`R-"!H;V3M;CH@(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR.3@*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H
M;W5R<SH@(@IM<V=S='(@(DYA:G9YN;EI82!T97!L;W1A('IA('!O<VQE9&[]
M8V@@-B!H;V3M;CH@(@H*(SH@;&EB+V%P:2YP:'`Z.#8*;7-G:60@(DUA>&EM
M=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS9W-T<B`B36%X:6WA;&YY
M('!OZ&5T(&)L;VMO=B!P;W)TX6QU(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.CDP,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(R,2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3(T,PIM<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T<B`B36%X:6WA
M;&YA(&3EOFMA(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P,R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Q
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*
M;7-G:60@(DUA>2(*;7-G<W1R(")-X6HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C4S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")-87EO='1E(@IM
M<V=S='(@(DUA>6]T=&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*
M;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(DUE9&EC[6YA(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@IM<V=I9"`B365M8F5R<R(*
M;7-G<W1R("+(;&5N;W9I82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.#(*;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B6F]B<F%Z96YI92!M96YU
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@(EIL^NAINR!B
M=6YK>2(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A
M='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*
M;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`B4W!RX79A(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I
M960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@
M8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"B)3<'+A=F$@
M8F]L82#Z<W!EN6YE(&]V97)E;N$L(&%L92!C97)T:69I:^%T('!O9'!I<W4@
M<V$@;F5P;V1A<FEL;R!O=F5R:;LN(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,3`*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS
M9W-T<B`B4&QA=&YO<[L@<W!RX79Y('9Y<'*Y86QA+B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8P,@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(R-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V
M,`IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(E1Y<"!S<'+A=GDB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E871H97(B
M"FUS9W-T<B`B4&_H87-I92!-971A<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N(@IM<V=S
M='(@(MID86IE($UE=&%R(&YI92!S^B!D;W-T=7!NZ2XB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$Q,@IM<V=I9"`B(@HB365T87(@8FQO8VL@;F]T(&%V
M86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M
M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HBVF1A:F4@365T87(@;FEE('/Z(&L@
M9&ES<&]Z[6-I:2X@1&5T86EL>2!B;VQI('IA>FYA;65N86[I('!R92!A9&UI
M;FES='+A=&]R82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,34S"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T960N(@IM<V=S='(@
M(E-Y<W3I;2!-971A<D1"(&YI92!J92!P<FEP;VIE;OTN(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R(")-973S9&$B
M"@HC.B!L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z.#$@;&EB+TAO<F1E+U)0
M0R]S;V%P+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(%PB
M)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R(")-973S9&$@7"(E<UPB(&YI
M92!J92!D969I;F]V86[A(@H*(SH@;&EB+TAO<F1E+U)00R]R97-T+G!H<#HX
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@;F]T(&1E9FEN960N($-A
M;&QE9"!M971H;V0Z("5S(@IM<V=S='(@(DYE9&5F:6YO=F%NX2!M973S9&$N
M(%9O;&%NZ2!Z(&UE=/-D>3H@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-C<@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-0IM<V=I9"`B365T
M<FEC(@IM<V=S='(@(DUE=')I8VOI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$V-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-97AI8V\B"FUS9W-T
M<B`B365X:6-O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@U(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T
M97,@;V8B"FUS9W-T<B`B36EK<F]NZ7IS:V4@9F5D97)A=.UV;F4@N73A='DB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S8*;7-G:60@(DUI9&1L92(*;7-G<W1R(")3=')E9"(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E
M(@IM<V=S='(@(E1Y<"!-:6UE(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,3`*;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R(").
M86IN:;ZY:6$@=&5P;&]T82!Z82!P;W-L961N_6-H(#(T(&AO9.UN.B`B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P,@IM<V=I9"`B36EN('1E;7`@;&%S
M="`V(&AO=7)S.B`B"FUS9W-T<B`B3F%J;FF^N6EA('1E<&QO=&$@>F$@<&]S
M;&5D;OUC:"`V(&AO9.UN.B`B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H
M<#HT,SD*;7-G:60@(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T
M(&5X<&ER960B"FUS9W-T<B`B36EN:6WA;&YA(&1O8F$@<&QA=&YO<W1I(&AE
M<VQA(&6Y=&4@;F5V>7!RN6%L82(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,S,*;7-G:60@(DUI<G)O<B(*;7-G<W1R("):<FMA
M9&QO=F\@;V)RX71INR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM
M<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R(")2]'IN92(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS-#`*(SH@;&EB+TYE="]335,O=VEN7VAT='`N
M<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U
M97-T+B(*;7-G<W1R(")#:/UB82!B86SM:R!014%2($A45%!?4F5Q=65S="XB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U"FUS9VED("(B"B)-:7-S
M:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO
M=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB"FUS
M9W-T<B`B(@HB0VC]8F$@:V]N9FEG=7+A8VEA+B!!:R!C:&-E=&4@<&]UONUV
M8;L@=/IT;R!A<&QI:^%C:74L(&UU<^UT92!T97)A>B`B"B)V>6=E;F5R;W9A
MNR!K;VYF:6=U<N%C:74N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T
M<B`B0VC]8F$@240@<W!RX79Y+B(*"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE
M:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!
M4B!P86-K86=E($UA:6PN(@IM<V=S='(@(D-H_6)A('!OOF%D;W9A;OT@4$5!
M4B!B86SM:R!-86EL+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM<V=S='(@
M(D-H_6)A($E$(')E;.%C:64N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`B4&]N(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C<V"FUS9VED(")-;V)I;&4@
M36%I;"(*;7-G<W1R(")-;V)I;&[](&UA:6PB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B36]D97)A=&4B"FUS
M9W-T<B`B36EE<FYY(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C8@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S,*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*;7-G:60@(DUO9&EF:65D
M($1A=&4B"FUS9W-T<B`B1.%T=6T@<&]S;&5D;F5J('IM96YY(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4S
M"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@(E5P<F%V:;L@55),(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-S0*;7-G:60@(DUO9'5L=7,B
M"FUS9W-T<B`B36]D=6QU<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@
M;V8B"FUS9W-T<B`B36]L9&%V<VMO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$T.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS9W-T
M<B`B36]N86MO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R(")-;VYG;VQS
M:V\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4X.`IM<V=I9"`B36]N=&@@
M86YD('EE87(B"FUS9W-T<B`B365S:6%C(&$@<F]K(@H*(SH@;&EB+TAO<F1E
M+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*;7-G<W1R(")-
M97-AZ&YE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDT"FUS9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(DUO;G1S97)R
M870B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S='(@(DUE<V'H;ND@9N%Z
M>2(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z,3DV(&QI8B]&:6QE+T-35BYP:'`Z
M,C@P"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN
M(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N(@IM<V=S='(@(DYA(')I
M861K=2`E9"!B;VQO(&[A:F1E;OUC:"!V:6%C('!O;.T@86MO(&_H86OA=F%N
M_6-H("5D+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R(")-87)O:V\B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I
M9"`B36]S=&QY($-L96%R(@IM<V=S='(@(E!R979AOFYE(&IA<VYO(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*;7-G:60@
M(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B4')E=F&^;F4@;V)L8>AN;R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,U"FUS9VED
M(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B4')E=F&^;F4@<VQN9>AN;R(*"B,Z
M(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C4P.0IM<V=I9"`B36]V92!$
M;W=N(@IM<V=S='(@(E!R97-U;OJ[(&1O;'4B"@HC.B!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+G!H<#HU,3,*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R(")0
M<F5S=6[ZNR!VM6%V;R(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP
M.C4Q-PIM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R(")0<F5S=6[ZNR!V<')A
M=F\B"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HU,#4*;7-G:60@
M(DUO=F4@57`B"FUS9W-T<B`B4')E<W5N^KL@:&]R92(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HU,C,*;7-G:60@(DUO=F4@9&]W
M;B(*;7-G<W1R(")0<F5S=6[ZNR!D;VQU(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C4R,B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-3(S"FUS9VED(")-;W9E('5P(@IM<V=S='(@(E!R97-U
M;OJ[(&AO<F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38X(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.34*;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B36]Z86)M
M:6LB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$X.`IM<V=I9"`B375L=&DM
M;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(E9I86/Z<F]V\F]VZ2!V
M>6)E<F%C:64@>F]Z;F%M>2(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,#4U"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-#8*;7-G:60@(DUU;'1I
M<&QE('-E;&5C=&EO;B(*;7-G<W1R(")6:6%C;N%S;V)N_2!V_6)E<B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#(*;7-G:60@(DUY($%C8V]U
M;G0B"FUS9W-T<B`B36]J92!K;VYT;R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HR.`IM<V=I9"`B37D@06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R
M("));F9O<FWA8VEE(&\@;6]J;VT@^NAT92(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]I;F1E>"YP:'`Z-30*;7-G:60@(DUY(%!O<G1A;"(*;7-G<W1R(")-]&H@
M<&]R=.%L(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C$S-@IM<V=I
M9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R(")6>FBU860@;?1J:&\@<&]R
M=.%L=2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-34@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY,@IM<V=I9"`B37EA;FUA<B(*;7-G<W1R(")->6%N;6%R(@H*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3<*;7-G
M:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R(").:64L($Y%4]I(3$%3
MS4TN(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$Q(&QI8B](;W)D
M92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B3F%M92(*;7-G<W1R(")-96YO
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V.2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDU"FUS9VED(").86UI8FEA(@IM<V=S='(@(DYA;>UB:6$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3<X(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-3@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@
M(DYA=7)U(@IM<V=S='(@(DYA=7)U(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$W-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R
M(").97#A;"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S4@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B2&]L86YD
M<VMO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-3<*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@(DAO
M;&%N9'-KZ2!!;G1I;'DB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4X,@IM<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B6N%K;&%D
M;N$@55),($YE='-C87!E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU.#0*;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@55),(@IM<V=S
M='(@(E523"!P<F4@>FYE<&QA=&YE;FEE(&-E<G1I9FEKX71O=B!#02!.971S
M8V%P92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED
M(").971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(E523"!P<F4@<&]L
M:71I:W4@0T$@3F5T<V-A<&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B
M55),('!R92!O8FYO=F5N:64@<&QA=&YO<W1I(&-E<G1I9FEKX71O=B!.971S
M8V%P92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED
M(").971S8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R(")54DP@<')E('IN
M97!L871N96YI92!C97)T:69I:^%T;W8@3F5T<V-A<&4B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@4U-,('-E
M<G9E<B!N86UE(@IM<V=S='(@(DUE;F\@4U-,('-E<G9E<F$@3F5T<V-A<&4B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X.`IM<V=I9"`B3F5T
M<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R(")+;VUE;G3A<B!C
M97)T:69I:^%T=2!.971S8V%P92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!T>7!E(@IM
M<V=S='(@(E1Y<"!C97)T:69I:^%T=2!.971S8V%P92(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR-3,*;7-G:60@(DYE='=O<FLB"FUS9W-T<B`B
M4VEENR(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S,Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.3`*;7-G:60@(DYE=F5R(@IM<V=S='(@(DYI:V1Y(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$W,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED(").97<@
M0V%L961O;FEA(@IM<V=S='(@(DYO=N$@2V%L963S;FEA(@H*(SH@;&EB+TAO
M<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,C8*;7-G:60@(DYE=R!#
M871E9V]R>2(*;7-G<W1R(").;W;A(&MA=&5G\W)I82(*"B,Z(&QI8B](;W)D
M92]497AT+T9I;'1E<B]E;6%I;',N<&AP.C@Q(&QI8B](;W)D92]497AT+T9I
M;'1E<B]E;6%I;',N<&AP.C@W"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]E
M;6%I;',N<&AP.CDW(&QI8B](;W)D92]497AT+T9I;'1E<B]E;6%I;',N<&AP
M.C$P,0HC+"!P:'`M9F]R;6%T"FUS9VED(").97<@365S<V%G92!T;R`E<R(*
M;7-G<W1R(").;W;A('-P<N%V82!P<F4@)7,B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(DYO=B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5
M<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(DYO=ND@<&]UONUV871EM7-K
MZ2!M96YO("AN97!O=FEN;NDI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$X,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38S"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(").97<@6F5A;&%N9"(*;7-G
M<W1R(").;W;](%KI;&%N9"(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HS-PIM<V=I9"`B3F5W('!A<W-W;W)D(@IM<V=S='(@(DYO=ND@:&5S
M;&\B"@HC.B!L:6(O2&]R9&4O075T:"]S<6PN<&AP.C(R-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N(@IM
M<V=S='(@(E!L871N;W.[(&YO=NEH;R!H97-L82!V>7!RN>T@)7@N(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R"FUS9VED(").97<@<&%S
M<W=O<F1S(&1O;B=T(&UA=&-H+B(*;7-G<W1R(").;W;I(&AE<VSA(&YI92!S
M^B!R;W9N86OI+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T
M<B`B3F]VZ2!O:VYO("A?8FQA;FLI(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP
M:'`Z-#`@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR.3$*;7-G:60@(DYE=W,B"FUS9W-T<B`B3F5W<R(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,#<*;7-G:60@(DYE=W-G
M<F]U<',B"FUS9W-T<B`B1&ES:W5S;ND@<VMU<&EN>2(*"B,Z('1E;7!L871E
M<R]D871A+W1S=FEN9F\N:6YC.C$U('1E;7!L871E<R]D871A+V1A=&5M87`N
M:6YC.C0Q"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C(U"FUS9VED(").97AT(@IM<V=S='(@
M(L]A;&5J(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"FUS9VED(").97AT
M(#0@4&AA<V5S(@IM<V=S='(@(DYA<VQE9'5J^F-E(#0@9N%Z>2(*"B,Z(&QI
M8B](;W)D92]0<F5F<R]522YP:'`Z,S<R(&QI8B](;W)D92]0<F5F<R]522YP
M:'`Z,S<V"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T<B`BSV%LN6EE(&YA
M<W1A=F5N:6$B"@HC.B!L:6(O2&]R9&4O54DO4&%G97(N<&AP.C$P,PIM<V=I
M9"`B3F5X=#XB"FUS9W-T<B`B3F%S;&5D=6KZ8V$^(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$W-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6-A
M<F%G=6$B"FUS9W-T<B`B3FEK87)A9W5A(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$W,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<B(*;7-G
M<W1R(").:6=E<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*;7-G<W1R(").:6?I<FEA
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V.0IM<V=I9"`B
M3FEG:'0B"FUS9W-T<B`B3F]C(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$W.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").:75E(@IM<V=S='(@(DYI
M=64B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38S
M"FUS9VED(").;R(*;7-G<W1R(").:64B"@HC.B!T96UP;&%T97,O861M:6XO
M<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V86EL86)L92!C;VYF:6=U
M<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S='(@
M(B(*(DYI92!S^B!D;W-T=7!NZ2"^:6%D;F4@:V]N9FEG=7)AZ&[I(/ID86IE
M+"!P<F4@:W1O<ND@8GD@<V$@9&%L:2!Z;V)R87IINR`B"B)R;WID:65L>2XB
M"@HC.B!L:6(O5D93+TE33U=R:71E<BYP:'`Z,3`V"FUS9VED(").;R!A=F%I
M;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R
M(")0<F4@=GET=N%R86YI92!)4T\@;V)R87IO=B!N:64@:F4@:R!D:7-P;WKM
M8VEI(+YI861N82!S=')A=.EG:6$N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*
M;7-G<W1R(").965X:7-T=6IE(+EA8FSS;F$@<')E(&3A=FMU+B(*"B,Z(&QI
M8B](;W)D92]";&]C:R],87EO=70N<&AP.C<Y(&QI8B](;W)D92]";&]C:R],
M87EO=70N<&AP.C(T-0HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HR
M-C<*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O
M<VET:6]N(@IM<V=S='(@(DYA('!OOF%D;W9A;F5J('!O>NUC:6D@;F5E>&ES
M='5J92"^:6%D96X@8FQO:RXB"@HC.B!L:6(O2&]R9&4O075T:"]M8V%L+G!H
M<#HU,`IM<V=I9"`B3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!
M3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B4')E($U#04P@875T96YT:69I
M:^%C:74@;F5B;VQO('IA9&%NZ2!M96YO(&MA;&5N9.%R82XB"@HC.B!A9&UI
M;B]S971U<"]D:69F+G!H<#HU-`IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R
M("*N:6%D;F$@>FUE;F$N(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ
M-38*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E
M<FUI<W-I;VXN(@IM<V=S='(@(DL@=&]M=71O('!RX79U(&YE;6^^;F\@<')I
M9&&[(+YI861N92!P;V1R:6%D96[I('!RX79A+B(*"B,Z(&QI8B](;W)D92YP
M:'`Z,38Y(&QI8B](;W)D92YP:'`Z-3`X(&QI8B](;W)D92]5=&EL+G!H<#HW
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R(")0<F4@)7,@;F5B
M;VQA('5RZ&5NX2!K;VYF:6=U<N%C:6$N(@H*(SH@;&EB+U9&4R]F='`N<&AP
M.C@T-`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R($944"!61E,N(@IM<V=S='(@(E!R92!&5%`@5D93(&YE8F]L
M82!U<NAE;N$@:V]N9FEG=7+A8VEA+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HV
M-S(*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!344P@5D93+B(*;7-G<W1R(")0<F4@4U%,(%9&4R!N96)O;&$@
M=7+H96[A(&MO;F9I9W5RX6-I82XB"@HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HW,C4*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(E!R92!344PM1FEL
M92!61E,@;F5B;VQA('5RZ&5NX2!K;VYF:6=U<N%C:6$N(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO(&-R961I
M="!L969T+B(*;7-G<W1R("*N:6%D96X@:W)E9&ET+B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S0*;7-G:60@(DYO(&1E<W1I;F%T
M:6]N('-U<'!L:65D+B(*;7-G<W1R(").96)O;&\@N7!E8VEF:6MO=F%NZ2!M
M:65S=&\@=7+H96YI82XB"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3`S
M"FUS9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(E/Z8F]R(&YE8F]L
M(&YA:')A;OTN(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q"FUS9VED
M(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`B3F5B;VQI(&[A:F1E;ND@OFEA
M9&YE(&EK;VYY+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M,38@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3(S"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@
M(DYI92!J92!N87-T879E;N$@;&]K86QI=&$N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$U-PIM<V=I9"`B3F\@;&]C871I;VX@<')O=FED
M960N(@IM<V=S='(@(DYE8F]L82!Z861A;N$@;&]K86QI=&$N(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I9"`B3F\@;65S
M<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`B3F5B;VQA('IA9&%NX2"^:6%D;F$@
M<W!RX79A+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,S8*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R(").96)O;&\@
MN7!E8VEF:6MO=F%NZ2"^:6%D;F4@;65N;RXB"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS9VED(").;R!N=6UB97(@<W!E8VEF
M:65D+B(*;7-G<W1R(").96)O;&\@N7!E8VEF:6MO=F%NZ2#H[7-L;RXB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*;7-G:60@(DYO(&]F9F5N<VEV
M92!F;W)T=6YE<R(*;7-G<W1R("*N:6%D;F4@=7+AOFQI=ND@9F]R='5N>2(*
M"B,Z(&QI8B](;W)D92]!=71H+VAT='`N<&AP.CDQ"FUS9VED(").;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B4')E($A45%`@875T96YT:69I:^%C:74@;F5B;VQO('IA9&%NZ2!H97-L
M;RXB"@HC.B!L:6(O2&]R9&4O075T:"]I;6%P+G!H<#HQ,#@*;7-G:60@(DYO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R(")0<F4@24U!4"!A=71E;G1I9FEKX6-I=2!N96)O;&\@>F%D86[I
M(&AE<VQO+B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C<R"FUS9VED
M(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(E!R92!+97)B97)O<R!A=71E;G1I9FEKX6-I=2!N
M96)O;&\@>F%D86[I(&AE<VQO+B(*"B,Z(&QI8B](;W)D92]!=71H+W-A<VPN
M<&AP.C<W(&QI8B](;W)D92]!=71H+VQO9VEN+G!H<#HX-`HC.B!L:6(O2&]R
M9&4O075T:"]P86TN<&AP.C<U"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN(@IM<V=S='(@(E!R92!,;V=I
M;B!A=71E;G1I9FEKX6-I=2!N96)O;&\@>F%D86[I(&AE<VQO+B(*"B,Z(&QI
M8B](;W)D92]!=71H+W!A<W-W9"YP:'`Z,3,U"FUS9VED(").;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M(")0<F4@4$%34U=$(&%U=&5N=&EF:6OA8VEU(&YE8F]L;R!Z861A;ND@:&5S
M;&\N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<VUB+G!H<#HX-`IM<V=I9"`B3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B4')E(%--0B!A=71E;G1I9FEKX6-I=2!N96)O;&\@>F%D86[I(&AE
M<VQO+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(X-PIM<V=I
M9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N
M(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W
M:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@HB3F5B;VQA('IA9&%NX2!C
M97-T82!K('!R;V=R86UU($]P96Y34TPN(%!R;V=R86T@3W!E;E-33"!J92!P
M;W1R96)N_2!N82!P<N%C=2`B"B)S(/ID86IM:2!02T-3(#$R+B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E
M;F1I;F<@<VEG;G5P<RXB"FUS9W-T<B`BKFEA9&YE('!R96)I96AA:OIC92!P
M<FEH;.%S96YI82XB"@HC.B!L:6(O5D93+G!H<#HW-C4*;7-G:60@(DYO('%U
M;W1A('-E="XB"FUS9W-T<B`B2W;S=&$@;FEE(&IE(&YA<W1A=F5NX2XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0S"FUS9VED(").;R!R=6QE<R(*;7-G<W1R(")"97H@Z&EA<B(*"B,Z(&QI
M8B]&:6QE+T-35BYP:'`Z-#@R"FUS9VED(").;R!S97!A<F%T;W(@<W!E8VEF
M:65D+B(*;7-G<W1R(").96)O;""Y<&5C:69I:V]V86[](&]D9&6U;W9AZ"XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0T"FUS9VED(").;R!S:61E<R(*;7-G<W1R(")"97H@<W1RX6XB"@HC
M.B!L:6(O5D93+W-M8BYP:'`Z-3@W"FUS9VED(").;R!S=6-H(&9I;&4B"FUS
M9W-T<B`B4_IB;W(@;F5NX6ID96[](@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$R-@IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A
M=F%I;&%B;&4@9F]R(&-A8VAE+B(*;7-G<W1R(")0<F4@=GER;W9NX79A8VEU
M('!A;>2[(&YI92!J92!D;W-T=7!N_2"^:6%D96X@9&_H87-N_2!P<FEEZ&EN
M;VLN(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,2!L
M:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"FUS9VED(").;R!U<V5R;F%M
M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`B3F5B;VQO(&]D;W-L
M86[I('!O=;[M=F%T9;5S:^D@;65N;R!A+V%L96)O(&AE<VQO+B(*"B,Z(&QI
M8B](;W)D92]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO('9A;&ED(%A-
M3"!D871A(')E='5R;F5D(@IM<V=S='(@(DYE8F]L:2!V<N%T96[I('!L871N
MZ2!834P@^F1A:F4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.3<Q(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY
M.#$*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDY,@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`P.0IM<V=I
M9"`B3F\@=F%L=65S(@IM<V=S='(@(JYI861N92!H;V1N;W1Y(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N
M9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(B(*(E8@</1V;V1N96H@:V]N9FEG=7+A8VEI
M(&YE8F]L82!NX6ID96[A(+YI861N82!V97)Z:6$N(%9Y9V5N97)U:G1E('IN
M;W9U("(*(FMO;F9I9W5RX6-I=2XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3(X"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG
M=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B
M"B)6(&MO;F9I9W5RX6-I:2!N96)O;&$@;N%J9&5NX2"^:6%D;F$@=F5R>FEA
M+B!6>6=E;F5R=6IT92!Z;F]V=2!K;VYF:6=U<N%C:74N(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z-#(W('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED
M96YT:71Y<V5L96-T+FEN8SHY,PIM<V=I9"`B3F]N92(*;7-G<W1R("*N:6%D
M96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDP"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(JYI861N
M92`H<&]UOFF[(&EM<&QI8VET;OH@:&]D;F]T=2DB"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X-0IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDV"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G<W1R(")/<W1R
M;W8@3F]R9F]L:R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS
M9W-T<B`B4V5V97)NX2!P;VQO9W6U82(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B3F]R=&AE<FX@36%R
M:6%N82!)<VQA;F1S(@IM<V=S='(@(E-E=F5R;ND@36%R:>%N<VME(&]S=')O
M=GDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<V(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3<*;7-G:60@(DYO<G=A>2(*;7-G<W1R(").\W)S:V\B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T,0IM<V=I9"`B3F]T($%F=&5R(@IM
M<V=S='(@(DYE<&QA=.T@<&\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C8T,`IM<V=I9"`B3F]T($)E9F]R92(*;7-G<W1R(").97!L873M('!R
M960B"@HC.B!L:6(O5D93+V9I;&4N<&AP.C0Q,@IM<V=I9"`B3F]T(&$@9&ER
M96-T;W)Y(@IM<V=S='(@(DYI92!J92!A9')E<^%R(@H*(SH@;&EB+U9&4R])
M4T]7<FET97(N<&AP.C8S(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713
M=')A=&5G>2YP:'`Z.#0*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U
M=%-T<F%T96=Y+G!H<#HY-0HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2YP:'`Z-#@*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDN<&AP.C4Y"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM
M<V=S='(@(DYI92!J92!I;7!L96UE;G1O=F%NZ2XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8X"FUS9VED(").;W0@<V5T
M(@IM<V=S='(@(DYE;F%S=&%V96[I(@H*(SH@;&EB+U9&4RYP:'`Z,3DS(&QI
M8B]61E,N<&AP.C(P."!L:6(O5D93+G!H<#HR,S,@;&EB+U9&4RYP:'`Z,C4Q
M"B,Z(&QI8B]61E,N<&AP.C(V."!L:6(O5D93+G!H<#HR.#0@;&EB+U9&4RYP
M:'`Z,S`P(&QI8B]61E,N<&AP.C,Q-0HC.B!L:6(O5D93+G!H<#HS,S(@;&EB
M+U9&4RYP:'`Z,S8U(&QI8B]61E,N<&AP.C0R-2!L:6(O5D93+G!H<#HU,#0*
M(SH@;&EB+U9&4RYP:'`Z-3<S(&QI8B]61E,N<&AP.C4Y,"!L:6(O5D93+G!H
M<#HV-C@*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#4@;&EB
M+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ-C`*(SH@;&EB+TAO<F1E+U-E
M<W-I;VY(86YD;&5R+G!H<#HQ-S4@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R
M+G!H<#HQ.#D*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HR,S8*
M;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(DYI92!J92!P;V1P;W)O
M=F%NZ2XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(T
M-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`P-0HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3@P"FUS9VED(").;W1E<R(*;7-G<W1R(")0;WINX6UK
M>2(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B
M3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(DYIZ"!N82!P
M<F5Z97)A;FEE+"!V<N&[=&4@<V$@<W#DNRXB"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Y(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B3F]V
M96UB97(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`U,`IM<V=I9"`B3G5M
M8F5R(@IM<V=S='(@(LCM<VQO(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T
M,CD*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(E!OZ&5T
M('IN86MO=B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S<S(&QI8B](;W)D
M92]&;W)M+G!H<#HQ-#(W(&QI8B](;W)D92]&;W)M+G!H<#HQ-#0Y"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED
M(").=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R(")0;^AE="!S=.5P8V]V(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-S$@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$T,C4@;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#<*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O
M9B!R;W=S(@IM<V=S='(@(E!OZ&5T(')I861K;W8B"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"FUS9VED(").=6UB97)S(&YO="!S
M<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*
M;7-G<W1R(")0<F4@86MT=6%L:7KA8VEU('IO>FYA;74@<'+M:F5M8V]V(&YE
M8F]L:2"Y<&5C:69I:V]V86[I(.CM<VQA+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B3TLB"FUS9W-T<B`B
M3TLB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<P
M"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B3V)J96MT(@H*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,3$*;7-G:60@(D]B:F5C="!#<F5A=&]R(@IM
M<V=S='(@(D%U=&]R(&]B:F5K='4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3$P.`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B3W-M:>AK;W;](@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P."!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS
M9W-T<B`B3VMT\V)E<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM
M<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B1FEL=&5R(&YA(&YA9.%V
M:WDB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(X"FUS9VED(")/
M9F9I8V4B"FUS9W-T<B`B4')A8V]V:7-K;R(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S
M(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R(")3=&%RZ2!A(&YO=ND@:&5S
M;&\@;75S:6$@8GF[(&]D;&FY;NDN(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C,V"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`B4W1A
M<ND@:&5S;&\B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*
M;7-G:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`B
M4W1A<ND@:&5S;&\@;F5B;VQO('IA9&%NZ2!S<'+A=FYE+B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$W,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B
M3VUA;B(*;7-G<W1R(")/;>%N(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T
M('-H87)E9"!F;VQD97)S+B(*;7-G<W1R("))8F$@24U!4"!S97)V97)Y('!O
M9'!O<G5J^B!Z9&EEM6%NZ2!P<FEEZ&EN:WDN(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.CDU"FUS9VED(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*
M;7-G<W1R("))8F$@=7+AOFQI=ND@9F]R='5N>2(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ.#4U(&QI8B](;W)D92]&;W)M+G!H<#HQ.3<U"FUS9VED(")/
M;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(DIE('!R
M[7!U<W1NX2!I8F$@:F5D;F$@92UM86EL;W;A(&%D<F5S82XB"@HC.B!S97)V
M:6-E<R]S:&%R97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W
M;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S
M:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S
M='(@(B(*(E9L87-T;NUK82!A;&5B;R!P<N%V82!V;&%S=&[M:V$@<')E('ID
M:66U86[](&]B:F5K="!M]+YE('IM96YINR!I8F$@=FQA<W1N[6L@(@HB86QE
M8F\@<WES=.EM;W;](&%D;6EN:7-T<N%T;W(B"@HC.B!L:6(O0FQO8VLO:69R
M86UE+G!H<#HS.2!L:6(O0FQO8VLO:69R86UE+G!H<#HT,`IM<V=I9"`B3W!E
M;B!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B3W1V;W)INR!V(&YO=F]M(&]K
M;F4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B
M3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I
M9VYE9"!3+TU)344@<&%R="XB"FUS9W-T<B`B0VAY8F$@3W!E;E-33#H@;F5P
M;V1A<FEL;R!S82!Z[7-K8;L@^F1A:F4@>B!P;V1P[7-A;F5J(.AA<W1I(%,O
M34E-12XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE
M=R!W:6YD;W<B"FUS9W-T<B`B3W1V;W)INR!T^G1O(&QI;FMU('8@;F]V;VT@
M;VMN92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I9"`B3W!E
M<F%T:6YG(%-Y<W1E;2(*;7-G<W1R(")/<&5R8>AN_2!S>7-TZ6TB"@HC.B!S
M97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS
M(@IM<V=S='(@(DYA<W1A=F5N:6$B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z
M,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,30*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B3F%S=&%V96YI82`E<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3@*
M;7-G:60@(D]R9&5R960@3&ES="(*;7-G<W1R("):;W)A9&5N_2!Z;WIN86TB
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G
M86YI<V%T:6]N(@IM<V=S='(@(D]R9V%N:7KA8VEA(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N
M:70B"FUS9W-T<B`B3W)G86YI>F'H;N$@:F5D;F]T:V$B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3,T"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S
M='(@(D]R9V%N:7IO=F%N:64B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S
M-0IM<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T
M<B`B4/1V;V1NX2"Y86)L\VYA(&%P;&EKX6-I92(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E
M;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B4/1V;V1NZ2"Y86)L\VYY('8@)7,Z
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME
M>6)O87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`B26[I(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDY(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,#D*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3(U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S0@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-`IM<V=I9"`B3W1H97(@26YF;W)M
M871I;VXB"FUS9W-T<B`BSV%LN6EE(&EN9F]R;>%C:64B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N
M<R(*;7-G<W1R(")0<N%V82!V;&%S=&[M:V$B"@HC.B!L:6(O2&]R9&4O075T
M:"]P86TN<&AP.C<Y"FUS9VED(")004T@875T:&5N=&EC871I;VX@:7,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B4$%-(&%U=&5N=&EF:6OA8VEA(&YI92!J
M92!D;W-T=7!NX2XB"@HC.B!L:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP
M.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM<V=S='(@(E!%05(Z
M36%I;"!B86-K96YD(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3(W
M-@IM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S='(@(D1I9VET
MX6QN>2!P;V1P:7,@4$=0(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M,3,R,@IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S='(@(MID86IE
M('IAN6EF<F]V86[I('!O;6]C;W4@4$=0(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z,3,W-`IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B
M4$=0('9E<F5J;OT@:[7ZZ"(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C$S-38*;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T
M<B`BVF1A:F4@<&]D<.US86[I+WIAN6EF<F]V86[I('!O;6]C;W4@4$=0(@H*
M(SH@861M:6XO<&AP<VAE;&PN<&AP.C8X"FUS9VED(")02%`@0V]D92(*;7-G
M<W1R(")02%`@:_-D(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED
M(")02%`@4VAE;&PB"FUS9W-T<B`B4$A0(%-H96QL(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*;7-G:60@(E!-($QI9VAT
M(%)A:6XB"FUS9W-T<B`B4&]P;VQU9&[M(+5A:&O](&3AON\B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.`IM<V=I9"`B4$T@
M4VAO=V5R<R(*;7-G<W1R(")0;W!O;'5D;NT@<')E:.%N:WDB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B4$T@
M4VYO=R(*;7-G<W1R(")0;W!O;'5D;NT@<VYEOF5N:64B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,`IM<V=I9"`B4$T@4VYO
M=R!3:&]W97)S(@IM<V=S='(@(E!O<&]L=61N[2!S;F5H;W;I('!R96CA;FMY
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*
M;7-G:60@(E!-(%-U;B(*;7-G<W1R(")0;W!O;'5D;NT@<VYEOF5N:64B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I
M9"`B4$T@5"U3=&]R;7,B"FUS9W-T<B`B4&]P;VQU9&[M(&+Z<FMY(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(W-`IM<V=I9"`B4$]325@@97AT96YS
M:6]N(&ES(&UI<W-I;F<B"FUS9W-T<B`B0VC]8F$@<F]ZN>UR96YI92!03U-)
M6"(*"B,Z(&QI8B]A<&DN<&AP.C$T.0IM<V=I9"`B4%](4"!3:&5L;"(*;7-G
M<W1R(")07TA0(%-H96QL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R
M(")6>7!L;F5N:64B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A:VES=&%N(@IM<V=S='(@(E!A:VES
M=&%N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P,0IM<V=I9"`B4&%L874B"FUS9W-T<B`B4&%L875S:^D@;W-T<F]V
M>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$W-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B
M"FUS9W-T<B`B4&%L97-T[6YS:V4@^GIE;6EE(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$X,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(")086YA;6$B
M"FUS9W-T<B`B4&%N86UA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDY"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM
M<V=S='(@(E!A<'5A($YO=N$@1W5I;F5A(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Y-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4&%R86=U87DB
M"FUS9W-T<B`B4&%R86=U87DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R
M("+(:6%S=&_H;F4@;V)L8>AN;R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`@;&EB+TAO<F1E+T9O<FTN<&AP.C(P
M,C(*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-R!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!L:6(O3F5T+U--
M4R]W:6Y?:'1T<"YP:'`Z,34Q('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M-S<*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,R!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(U"FUS9VED(")087-S=V]R9"(*;7-G
M<W1R(")(97-L;R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HX
M,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN(@IM<V=S
M='(@(DAE<VQO(&)O;&\@^G-P9;EN92!Z;65N96[I+B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z,3,R,PIM<V=I9"`B4&%S<W=O<F0@:6YC;W)R
M96-T(@IM<V=S='(@(DYE<W!RX79N92!H97-L;R(*"B,Z(&QI8B](;W)D92]!
M=71H+W)A9&EU<RYP:'`Z,34R"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F
M;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")0<F4@875T96YT
M:69I:^%C:74@4D%$2553(&IE('9YOF%D;W9A;ND@:&5S;&\N(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(P-3<*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N
M9FER;6%T:6]N(@IM<V=S='(@(DAE<VQO(',@<&]T=G)D96[M;2(*"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`IM<V=I9"`B4&%S<W=O<F0Z
M(@IM<V=S='(@(DAE<VQO.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N
M:6YC.C$Q"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(DAE<VQO.B`B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ-3`@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,S@*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B
M4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(DAE<VSA(&UU<VEA(&)Y
MNR!R;W9N86OI+B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,3D@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R"FUS
M9VED(")087-T92(*;7-G<W1R(")6;&^^:;LB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,W"FUS9VED(")087-T92!F<F]M
M(&-L:7!B;V%R9"(*;7-G<W1R(")6;&^^:;L@>F\@<V-H<N%N:WDB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q"FUS9VED
M(")0871H(@IM<V=S='(@(D-E<W1A(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q
M=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`B
M4')E8FEE:&%J^F-E(')E9VES='+A8VEE.B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU-`IM<V=I9"`B4&5O<&QE(@IM<V=S='(@(J5U9&EA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*;7-G
M:60@(E!E<F-E;G0B"FUS9W-T<B`B4&5R8V5N="(*"B,Z('1E;7!L871E<R]M
M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED(")097)F;W)M
M($UA:6YT96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B5GEK;VYANR!O<&5R
MX6-I92#Z9'*^8GDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#$P"FUS
M9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_
M(@IM<V=S='(@(E9Y:V]N8;L@;W!E<N%C:64@^F1ROF)Y('!R:2!P<FEH;.%S
M96[M/R(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,34V"FUS9VED(")0
M97)M:7-S:6]N(@IM<V=S='(@(E!RX79O(@H*(SH@861M:6XO<&5R;7,O9&5L
M971E+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB
M)7-<(B!N;W0@9&5L971E9"XB"FUS9W-T<B`B4'+A=F\@7"(E<UPB(&YE8F]L
M;R!V>6UA>F%NZ2XB"@HC.B!L:6(O5D93+W-M8BYP:'`Z-3DP"FUS9VED(")0
M97)M:7-S:6]N($1E;FEE9"(*;7-G<W1R(")0<NUS='5P('IA;6EE=&YU=/TB
M"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$V,2!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B4'+A
M=F$B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#D@861M:6XO<&5R;7,O
M861D8VAI;&0N<&AP.C8P"B,Z(&%D;6EN+W!E<FUS+VEN9&5X+G!H<#HR,B!A
M9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X"FUS9VED(")097)M:7-S:6]N<R!!
M9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES='+A8VEA('!RX78B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@*;7-G:60@(E!E<G-O;F%L($EN
M9F]R;6%T:6]N(@IM<V=S='(@(D]S;V)NZ2!I;F9O<FWA8VEE(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$X,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED
M(")097)U(@IM<V=S='(@(E!E<G4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-34*;7-G:60@(E!E=',B"FUS9W-T<B`B1&]MX6-E('IV:65R873A(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY
M"FUS9VED(")0:&EL:7!P:6YE<R(*;7-G<W1R(")&:6QI<.UN>2(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N
M92(*;7-G<W1R(")496QE9O-N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0X,`IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(D9O=&]G<F%F:64B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DP(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P
M"FUS9VED(")0:71C86ER;B(*;7-G<W1R(")0:71C86ER;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS9VED(")0
M:7AE;',B"FUS9W-T<B`B0F]D;W8B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-38*;7-G:60@(E!L871I='5D97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I
M9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S='(@(DML:6MN
M:71E('!R;W/M;2!D;R!N96IA:V5J(&)U;FMY(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0
M;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L
M96UE;G0Z(@IM<V=S='(@(E!O='9R[W1E('!R;W/M;2P@OF4@8VAC971E(&]D
M<W1RX6YINR!T96YT;R!E;&5M96YT.B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E
M(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT
M+B(*;7-G<W1R(")0;W1V<N]T92!P<F]S[6TL(+YE(&-H8V5T92!O9'-T<N%N
M:;L@;&EN:W4@>B!T;VAT;R!E;&5M96YT=2XB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C4V-@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@
M>65A<BXB"FUS9W-T<B`B6F%D86IT92!P<F]S[6T@;65S:6%C(&$@<F]K+B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C$R
M"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G
M;W)Y.B(*;7-G<W1R("):861A:G1E('!R;W/M;2!M96YO('!R92!N;W;Z(&MA
M=&5G\W)I=3HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,P-0IM<V=I9"`B
M4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B6F%D
M86IT92!P<F]S[6T@<&QA=&[Z($E0(&%D<F5S=2XB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C8T-PIM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T
M92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS
M9W-T<B`B6F%D86IT92!P<F]S[6T@<&QA=&[](&3A='5M+"!S:V]N=')O;'5J
M=&4@<&_H970@9&[M('8@;65S:6%C:2XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C0U,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS
M9W-T<B`B6F%D86IT92!P<F]S[6T@<&QA=&[](.AA<RXB"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O=FED
M92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@(E!R;W/M;2!U
M=F7O=&4@>FAR;G5T:64@<')O8FSI;74N(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V"FUS
M9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R
M9"(*;7-G<W1R(")0<F]S[6T@>F%D86IT92!S=F]J92!P;W6^[79A=&6U<VOI
M(&UE;F\@82!H97-L;R(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU
M.`IM<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9
M;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y
M<W1E;2XB"FUS9W-T<B`B(@HB4')EZ.UT86IT92!S:2!P<F]S[6T@;F%S;&5D
M=6KZ8VD@=&5X="X@3553S51%('/Z:&QA<VF[(',@<&]D;6EE;FMA;6D@(@HB
M<&]UONUV86YI82!S>7-TZ6UU+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E
M9V]R>4UA;F%G97(N<&AP.C<P"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W
M(&-A=&5G;W)Y(&YA;64Z(@IM<V=S='(@(EIA9&%J=&4@<')O<^UM(&UE;F\@
M<')E(&YO=OH@:V%T96?S<FEU.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ.#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&]L86YD(@IM<V=S='(@
M(E!OM7-K;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-PIM<V=I9"`B
M4&]L:71I8W,B"FUS9W-T<B`B4&]L:71I:V$B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#@Y"FUS9VED(")0;VQL<R(*;7-G<W1R(")!;FME='DB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DS(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ.#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`Q"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R(")0;W)T=6=A;'-K;R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR-PIM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G
M<W1R(")5;6EE<W1N96YI92!T;VAT;R!O8G+A>FMU(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET
M:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`B56UI97-T;F5N:64@=&5J
M=&\@=&%B=;5K>2(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D
M(&)Y($E-05`I(@IM<V=S='(@(D]D;W-L8;L@9&\@=&]H=&\@<')I9>AI;FMA
M("AN979Y;G5C=6IE($E-05`I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T
M<B`B6G+AOFMY('IA('!O<VQE9&[]8V@@)7,@:&]D[6XZ("(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#<*;7-G:60@(E!R96-I<&ET871I
M;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B4')A=F1E<&]D;V)N;W.[/&)R("\^
M>G+AOF]K(@H*(SH@;&EB+TAO<F1E+U!R969S+VQD87`N<&AP.CDX"FUS9VED
M(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(E!R969S7VQD87`Z('!OOF%D;W9A;ND@<F]ZN>UR96YI
M92!,1$%0(&YE8F]L;R!NX6ID96[I+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]S
M97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@
M<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]S
M97-S:6]N.B!P;[YA9&]V86[I(')O>KGM<F5N:64@<V5S<VEO;B!N96)O;&\@
M;N%J9&5NZ2XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-0IM<V=I9"`B
M4')E<W-U<F4B"FUS9W-T<B`B5&QA:R(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C4Y"FUS9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ("(*;7-G<W1R
M(")4;&%K(&YA(/IR;W9N:2!M;W)A.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C(T"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@(E1L
M86LZ("(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@(E5KX;YK82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@
M=VEN9&]W(@IM<V=S='(@(EIO8G)A>FF[('5KX;YK=2!O8G+A>FMU('8@;F]V
M;VT@;VMN92(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S8R(&QI8B](
M;W)D92]0<F5F<R]522YP:'`Z,S8V"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS
M(@IM<V=S='(@(E!R961C:.%D>F%J^F-E(&YA<W1A=F5N:6$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0Q"FUS9VED(")0
M<FEN="!D;V-U;65N="(*;7-G<W1R(")6>71L8>AINR!D;VMU;65N="(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+
M97DB"FUS9W-T<B`B4')I=N%T;GD@:[7ZZ"(*"B,Z(&QI8B](;W)D92]-96YU
M+G!H<#HQ-CD*;7-G:60@(E!R;V)L96TB"FUS9W-T<B`B4')O8FSI;2(*"B,Z
M('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-PIM<V=I9"`B4')O8FQE;2!$97-C
M<FEP=&EO;B(*;7-G<W1R(")0;W!I<R!P<F]B;.EM=2(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS-S$*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@
M(E!R;VIE:W1Y(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,34@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(Q.3(@;&EB+TAO<F1E+T9O<FTN<&AP.C,R-S0*;7-G
M:60@(E!R;VUP="!T97AT(@IM<V=S='(@(E;]>G9A(&YA('IA9&%N:64@=&5X
M='4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U
M8FQI8R!+97DB"FUS9W-T<B`B5F5R96IN_2!KM?KH(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HV-#8*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I
M=&AM(@IM<V=S='(@(D%L9V]R:71M=7,@=F5R96INZ6AO(&NU^NAA(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#4*;7-G:60@(E!U8FQI8R!+
M97D@26YF;R(*;7-G<W1R("));F9O<FWA8VEE(&\@=F5R96IN;VT@:[7ZZ&DB
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HR-#$*;7-G:60@(E!U8FQI
M8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN
M(@IM<V=S='(@(E9E<F5J;OTO<')I=N%T;GD@:[7ZZ&]V_2!PX7(@;F5B;VP@
M^G-P9;EN92!V>6=E;F5R;W9A;OTN(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$Y,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B
M"FUS9W-T<B`B4&]R=&]R:6MO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$Y-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B46%T87(B"FUS9W-T<B`B
M2V%T87(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C,*;7-G:60@(E%U97)Y
M(@IM<V=S='(@(D1O=&%Z(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P
M"FUS9VED(")1=6]T82(*;7-G<W1R(")+=O-T82(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-C8T"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0
M=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@(E)302!V97)E:F[](&NU^N@@
M*"5D(&)I=&]V*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C8X"FUS9VED
M(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`B4')E<.UN8>@@<R!V_6)E<F]M
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#,*
M;7-G:60@(E)A:6XB"FUS9W-T<B`B1.&^[R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")286EN($5A<FQY(@IM
M<V=S='(@(E+A;F\@9.&^[R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")286EN($QA=&4B"FUS9W-T<B`B3F5S
M:_1R(&3AON\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT-@IM<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B1&&^[V]VZ2!P
M<F5HX6YK>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0W"FUS9VED(")286EN(&%N9"!3;F]W(@IM<V=S='(@(D3AON\@<V\@
M<VYE:&]M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#@*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R(")$X;[O('!R96-H
MX61Z86KZ8VD@=B!S;F6^96YI92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R(").X6AO9&[A(&9O
M<G1U;F$B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV."!L
M:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW-@IM<V=I9"`B4F%T:6\B
M"FUS9W-T<B`B4&]M97(B"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C,R-"!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,0HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-"!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$X,`IM<V=I9"`B4F5A9"(*;7-G<W1R("+([71ANR(*"B,Z(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PIM<V=I9"`B4F5A9"!M97-S86=E
M<R(*;7-G<W1R("+([71ANR!S<'+A=GDB"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY
M(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB
M"FUS9W-T<B`B3F%O>F%J('9Y;6%Z8;L@)7,_(%3Z=&\@;W!E<N%C:74@;F5M
M;[YN;R!V<N%T:;L@<W#DNRXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C
M;&5A<BYI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@<F5M;W9E
M('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T
M(&)E('5N9&]N92XB"FUS9W-T<B`B(@HB3F%O>F%J('9Y;6%Z8;L@<&]UONUV
M871EM7-KZ2#Z9&%J92!P<F4@<&]UONUV871EM6$@)7,_(%3Z=&\@;W!E<N%C
M:74@;F5M;[YN;R`B"B)V<N%T:;L@<W#DNRXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U
M<B!L87-T(&%C=&EO;B(*;7-G<W1R(")6<N%T:2!S<.2[(%9AN74@<&]S;&5D
M;OH@86MC:74B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R(")/
M8FYO=FF[(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y-0IM<V=I9"`B
M4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z(@IM<V=S='(@(D]B;F]V
M:;L@96QE;65N='D@9'EN86UI8VOI:&\@;65N=3HB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S0U"FUS9VED(")2969R97-H(%!O<G1A;"!6:65W.B(*
M;7-G<W1R(")/8FYO=FF[('IO8G)A>F5N:64@<&]R=.%L=3HB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z.#DX(&QI8B](;W)D92]&;W)M+G!H<#HQ,C$W(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,C,Y"FUS9VED(")296=E>"(*;7-G<W1R(")2
M96=U;.%R;GD@=OUR87HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(S.`IM
M<V=I9"`B4F5L871I;VYS:&EP($)R;W=S97(B"FUS9W-T<B`B4')E:&QI861A
MZ"!V>KMA:&]V(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`IM<V=I9"`B4F5L;V%D
M(@IM<V=S='(@(EIN;W9U(&YAZ.UT8;LB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,R-@IM<V=I9"`B4F5M87)K<R(*;7-G<W1R(")0;W-T<F5H>2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3<*;7-G:60@(E)E;6]T92!397)V
M97)S(@IM<V=S='(@(E9Z9&EA;&5NZ2!S97)V97)Y(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED(")296UO=&4@55),("AH='1P
M.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T<B`B5GID:6%L96[A
M(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F5Q=65U960N:6YC.C$S"FUS9VED(")296UO=F4B"FUS9W-T<B`B
M3V1S='+A;FF[(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q
M"FUS9VED(")296UO=F4@0FQO8VLB"FUS9W-T<B`B3V1S='+A;FF[(&)L;VLB
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34V"FUS
M9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(D]D<W1RX6YINR!S=.5P96,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0P
M"FUS9VED(")296UO=F4@9F]R;6%T=&EN9R(*;7-G<W1R(")/9'-T<N%N:;L@
M9F]R;>%T;W9A;FEE(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ
M,C@*;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@(D]D<W1RX6YINR!PX7(B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R"FUS9VED(")296UO=F4@
M<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R
M>2XB"FUS9W-T<B`B3V1S='+A;FF[('5L;[YE;OT@<VMR:7!T('H@9&_H87-N
MZ6AO('!R:67H:6YK82!N82!S97)V97)I+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@IM<V=I9"`B4F5M
M;W9E('1H92(*;7-G<W1R(")/9'-T<N%N:;LB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(E)E
M;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`B3V1S
M='+A;FF[('1E;G1O(&)O9"!Z(&1O:W5M96YT=2(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*;7-G:60@(E)E;6]V92!U<V5R(@IM
M<V=S='(@(D]D<W1RX6YINR!P;W6^[79A=&6U82(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V92YI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")2
M96UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B3V1S='+A;FF[('!O=;[M=F%T9;5A
M.B`E<R(*"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HQ,S@*;7-G:60@
M(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R
M8V]D93H@(@IM<V=S='(@(DYA('!OOFEA9&%V:W4@;F5B;VQO(&UOOF[I(&]D
M<&]V961ANRX@3N%V<F%T;W;](&OS9"!C:'EB>3H@(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$T-0IM<V=I9"`B4F5Q=65S=&5D('-E<G9I
M8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*;7-G<W1R(")0;[YA9&]V86[Z('-L
M=;YB=2!S82!N97!O9&%R:6QO(&[A:G.[+B(*"B,Z(&QI8B](;W)D92YP:'`Z
M,3<V(&QI8B](;W)D92YP:'`Z-3$X"B,L('!H<"UF;W)M870*;7-G:60@(E)E
M<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(E8@:V]N9FEG=7+A8VEI("5S(&YI92!J92"Y<&5C:69I
M:V]V86[A('!OOF%D;W9A;N$@<&]L;[YK82!<(B5S7"(B"@HC.B!L:6(O5D93
M+W-Q;"YP:'`Z-C<X(&QI8B]61E,O9G1P+G!H<#HX-3`@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z-S,Q"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB
M)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R(")6(&MO;F9I9W5RX6-I:2!61E,@;FEE(&IE(+EP96-I9FEK;W9A;N$@
M<&^^861O=F%NX2!P;VQOOFMA(%PB)7-<(B(*"B,Z(&QI8B](;W)D92]5=&EL
M+G!H<#HW-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB
M(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B5B!K
M;VYF:6=U<N%C:6D@;FEE(&IE(+EP96-I9FEK;W9A;N$@<&^^861O=F%NX2!P
M;VQOOFMA(%PB)7-<(B(*"B,Z(&QI8B](;W)D92]&;W)M+U)E;F1E<F5R+G!H
M<#HS,S4*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@(E!O=FEN;ND@
M<&]L92(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q(&QI8B](;W)D92]&;W)M+G!H
M<#HS-#,@;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,R,`HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(E9Y;6%Z
M8;L@9F]R;75LX7(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT
M-@IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`B3V)N;W9INR!H97-L
M;R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W"FUS9VED(")2
M97-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(D]B;F]V:;L@5F&Y92!H97-L
M;R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S`*;7-G:60@(E)E<W1O<F4@
M3&%S="!1=65R>2(*;7-G<W1R(")/8FYO=FF[('!O<VQE9&[](&1O=&%Z(@H*
M(SH@861M:6XO<&AP<VAE;&PN<&AP.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR
M."!A9&UI;B]S<6QS:&5L;"YP:'`Z-C8*;7-G:60@(E)E<W5L=',B"FUS9W-T
M<B`B5OUS;&5D:WDB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T
M;R!/<'1I;VYS(@IM<V=S='(@(D[A=G)A="!N82!N87-T879E;FEA(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED(")2971Y<&4@
M;F5W('!A<W-W;W)D(@IM<V=S='(@(EIA9&%J=&4@;F]VZ2!H97-L;R(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$X-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*
M;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B4F5U;FEO;B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`IM
M<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB"FUS9W-T<B`B5G+A=&F[(&MO
M;F9I9W5RX6-I=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G
M:60@(E)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R(").87-T879E
M;FEA(')O>KGM<F5NZ6AO('1E>'1O=NEH;R!E9&ET;W)U(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4X"FUS9VED(")2:61D;&5S(@IM<V=S='(@(DCA
M9&%N:WDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@(E9P<F%V;R(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HS,3$P"FUS9VED(")2:6=H="!H96%D97(B
M"FUS9W-T<B`B2&QA=FGH:V$@=G!R879O(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C,Q,#8*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R(")(;V1N;W1Y
M('9P<F%V;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?=R!0<F]P97)T:65S+BXN(@IM
M<V=S='(@(E9L87-T;F]S=&D@7W)I861K82XN+B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@
M(E)O;&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DX(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM<V=S='(@(E)U;75N<VMO(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R-`IM<V=I
M9"`B4F]T871E(#$X,"(*;7-G<W1R(")/=&_H:;L@;R`Q.#`B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(Q"FUS9VED(")2;W1A
M=&4@3&5F="(*;7-G<W1R(")/=&_H:;L@=K5A=F\B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(W"FUS9VED(")2;W1A=&4@4FEG
M:'0B"FUS9W-T<B`B3W1OZ&F[('9P<F%V;R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0
M<F]P97)T:65S(@IM<V=S='(@(E9L87-T;F]S=&D@<FEA9&MA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM
M<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`B5FQA<W1N;W-T:2!R:6%D
M:V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P,0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`B4FEA9&MY.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G
M:60@(E)U;&5S(@IM<V=S='(@(LAI87)Y(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,`IM<V=I9"`B4G5L97,@
M=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(*;7-G
M<W1R("+(:6%R>2!S82!Z;V)R87II82!M961Z:2!VN65T:_UM:2!R:6%D:V%M
M:2!A('-TY7!C86UI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@
M8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`BR&EA<GD@<V$@>F]B<F%Z
M:6$@:6)A(&UE9'II('-TY7!C86UI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`BR&EA<GD@<V$@
M>F]B<F%Z:6$@:6)A(&UE9'II(')I861K86UI(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C$R,`IM<V=I9"`B4G5N(@IM<V=S='(@(E-P=7-T:;LB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DY(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ.#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S"FUS
M9VED(")2=7-S:6%N($9E9&5R871I;VXB"FUS9W-T<B`B4G5S:^$@9F5D97+A
M8VEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P,"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P,PIM<V=I9"`B4G=A;F1A(@IM<V=S='(@(E)W86YD82(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y
M<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B4R]-24U%(&MR>7!T;V=R
M869I8VO]('!O9'!I<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M,S(S"FUS9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B
M4W!RX79A('IAN6EF<F]V86[A('!O;6]C;W4@4R]-24U%(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O<V%S;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T:&5N=&EC871I
M;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B4T%33"!A=71E;G1I9FEK
MX6-I82!N:64@:F4@9&]S='5P;N$N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C4P-@IM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R(")0;W-I
M96QA;FEE(%--4R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B
M4U%,(%-H96QL(@IM<V=S='(@(E-13"!3:&5L;"(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HS,C<R"FUS9VED(")344P@<W1A=&5M96YT(&9O<B!V86QU92!L
M;V]K=7!S(@IM<V=S='(@(E-13"!P<NUK87H@<')E(&BU861A;FEE(&AO9&[T
M="(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S,*;7-G:60@(E-3
M2"(*;7-G<W1R(")34T@B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-50T-%4U,B"FUS9W-T<B`B
MVE-014-((@H*(SH@;&EB+V%P:2YP:'`Z,34S"FUS9VED(")37U%,(%-H96QL
M(@IM<V=S='(@(E-?44P@4VAE;&PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")382(*;7-G<W1R(")3;R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$X.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R(")3=N1TX2!(96QE;F$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ.3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#0*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R(")3=N1T
M_2!+:71T<R!A($YE=FES(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S
M.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@W"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R
M(")3=N1TX2!,=6-I82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#D@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ
M=65L;VXB"FUS9W-T<B`B4W8N(%!I97)R92!A($UI<75E;&]N(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(T-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DS"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-0IM<V=I
M9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B
M4W;D=/T@5FEN8V5N="!A($=R96YA9&EN>2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@
M*%]S96QF*2(*;7-G<W1R(")496X@:7-T_2!RX6UE8R`H7W-E;&8I(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DT"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM
M<V=I9"`B4V%M;V$B"FUS9W-T<B`B4V%M;V$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C$R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.34*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")386X@36%R
M:6YO(@IM<V=S='(@(E-A;B!-87)I;F\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C$V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")386\@5&]M92!A
M;F0@4')I;F-I<&4B"FUS9W-T<B`B4V%O(%1O;64@82!0<FEN8VEP92(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E
M(%!R;W9I9&5R(@IM<V=S='(@(E-A=&5L:71N_2!P;W-K>71O=F%T9;4B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`Q(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.3<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S
M"FUS9VED(")3875D:2!!<F%B:6$B"FUS9W-T<B`B4V%U9'-KX2!!<N%B:6$B
M"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3D*;7-G:60@(E-A
M=F4B"FUS9W-T<B`B56QOOFF[(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]E9&ET+FEN8SHT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E(%PB)7-<
M(B(*;7-G<W1R(")5;&^^:;L@7"(E<UPB(@H*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHR,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*
M;7-G<W1R(")5;&^^:;L@)7,B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN
M8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`B56QOOFF[(&YA<W1A
M=F5N:6$B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38W"FUS9VED("(B
M"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP
M="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM
M<V=S='(@(B(*(E5L;[YINR!V>6=E;F5R;W9A;OH@:V]N9FEG=7+A8VEU(&%K
M;R!02%`@<VMR:7!T(&1O(&1OZ&%S;NEH;R!P<FEEZ&EN:V$@5N&Y:&\@(@HB
M<V5R=F5R82XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R(")+;VYF:6=U<N%C:6$@)7,@8F]L82!U;&^^96[A+B(*"B,Z(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L('!H<"UF;W)M870*;7-G:60@(E-A
M=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@
M(E-K<FEP="!N82!U<&=R861E(&YA<W1A=F5N[2!B;VP@=6QOOF5N_2!D;SH@
M7"(E<UPB+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0Y"FUS9VED(")38V%T=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B3VIE
M9&EN96SI(&+Z<FMY(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS
M9VED(")38VEE;F-E(@IM<V=S='(@(E9E9&$B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(DBU861ANR(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C(*;7-G:60@(E-E87)C:"!%;F=I
M;F5S(@IM<V=S='(@(E9Y:+5A9.%V8>AE(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(Y-C(*;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R(")6>6)E<G1E
M('/Z8F]R>2(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT.#(*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B5GEB97)T92!D
MX71U;2(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX"FUS9VED
M(")396QE8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B5GEB97)T92!S:W5P
M:6YU(&YA('!R:61A;FEE(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@(E9Y8F5R
M=&4@;F]VZ6AO('9L87-T;NUK82(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(E9Y
M8F5R=&4@<V5R=F5R(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M-38*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S='(@(E9Y8F5R
M=&4@<&]UONUV871EM6$@;F$@<')I9&%N:64B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<S"FUS9VED(")396QE8W0@86QL(@IM
M<V=S='(@(E9Y8F5R=&4@=KEE=&MY(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(V-3`*;7-G:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G
M<W1R(")6>6)E<G1E(':Y971K>2!K;VUP;VYE;G1Y(&3A='5M=2(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX-S`*;7-G:60@(E-E
M;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B5GEB97)T92!O8FIE:W0B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<T"FUS9VED(")3
M96QE8W0@;F]N92(*;7-G<W1R("):<G6Y:;L@=OUB97(B"@HC.B!S97)V:6-E
M<R]K97EB;V%R9"YP:'`Z,S<*;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C
M=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T
M:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A
M+B(*;7-G<W1R("(B"B)6>6)E<G1E('IN86MY+"!K=&]RZ2!P;W1R96)U:F5T
M92P@>B!O:VEE;F]K(&YIOKEI92X@4&]T;VT@:6-H(&WTOF5T92`B"B)S:V]P
M[7)O=F&[(&$@=FQOOFF[('H@=&5X=&]VZ6AO('!OM6$N(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D
M96QI;6ET97(Z(@IM<V=S='(@(E9Y8F5R=&4@;V1D9;5O=F'H('9O(&9O<FWA
M=&4@9.%T=6UU.B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0T"FUS
M9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R(")6>6)E<G1E
M(&9O<FWA="!DX71U;74Z(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y
M<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@
M=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(E9Y8F5R=&4@:61E;G1I='4L(&MT
M;W+Z(&-H8V5T92!Z;65N:;LZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI
M;F,Z,38*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S
M='(@(E9Y8F5R=&4@;V1D9;5O=F'H('9O(&9O<FWA=&4@Z&%S=3HB"@HC.B!T
M96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H92!T
M:6UE(&9O<FUA=#HB"FUS9W-T<B`B5GEB97)T92!F;W)MX70@Z&%S=3HB"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4W"FUS9VED(")396QE8W0@
M='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`B5GEB97)T92!D=F4@>FAO
M9&[I('!O;&EA+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,3`*;7-G
M:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B5GEB97)T
M92!S:2!F87)E8F[Z('-C:.EM=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-3(*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB
M"FUS9W-T<B`B5GEB97)T92!J87IY:SHB"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*
M;7-G<W1R(")0;W-L8;L@<W!RX79U(&\@<')O8FSI;64B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`S.0IM<V=I9"`B4V5N9"!3
M35,B"FUS9W-T<B`B4&]S;&&[(%--4R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E;F5G86PB"FUS
M9W-T<B`B4V5N96=A;"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$V"FUS
M9VED(")396YS;W(Z("(*;7-G<W1R(")396YZ;W(Z("(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#<@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS9W-T
M<B`B4V5P=&5M8F5R(@H*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(E-R
M8G-K;R!A(,AI97)N82!H;W)A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HW,#(*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS9W-T<B`B4^ER:6]V
MZ2#H[7-L;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#D*
M;7-G:60@(E-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(MID86IE('IO('-E<G9E<F$@<_H@;F5S<'+A=FYE(&%L96)O(&YI
M92!S^B!D;W-T=7!NZ2XB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C<*;7-G
M:60@(E-E<W-I;VX@061M:6XB"FUS9W-T<B`B061M:6YI<W1RX6-I82!S961E
M;NTB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@IM
M<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R(")0;&%T;F]SNR!)
M1"!S961E;FEA('9Y<'*Y86QA+B(*"B,Z(&QI8B]A<&DN<&AP.C$T-0IM<V=I
M9"`B4V5S<VEO;G,B"FUS9W-T<B`B4V5D96YI82(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR,S$X"FUS9VED(")3970B"FUS9W-T<B`B36YOOFEN82!H;V1N
M]'0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SD*;7-G:60@(E-E="!O
M<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF
M('EO=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B3F%S=&%V=&4@;6^^;F]S
M=&D@;F$@;V)N;W9E;FEE(%;AN6AO(&AE<VQA(&%K(&AO('IA8G5D;F5T92XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$X"FUS9VED(")3970@=7`@
M<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y
M;W5R('!O<G1A;"XB"FUS9W-T<B`B(@HB3F%S=&%V96YI92!V>F1I86QE;OUC
M:"!S97)V97)O=BP@:W4@:W1O<OUM(&-H8V5T92!P<FES='5P;W9ANR!Z(%;A
MN6AO("(*(G!O<G3A;'4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@W
M"FUS9VED(")3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE
M(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S='(@(E9Y8F5R=&4@:F%Z>6LL(.AA
M<V]V^B!Z\VYU(&$@;F%S=&%V96YI82!DX71U;74N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$P,0IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A
M<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N
M9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(B(*(DYA<W1A
M=F5N:64@87!L:6OA8VEE('-P^KF[86YE:B!P<FD@N71A<G1E+"!F87)E8FYE
M:B!S8VCI;7DL(&EN=&5R=F%L=2`B"B)O8FYO=F]V86YI82!S='+A;FMY(&$@
M:6[]8V@@=FQA<W1N;W-T[2!Z;V)R87IE;FEA+B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-S4*;7-G:60@(E-E='5P(@IM<V=S='(@(DYA<W1A=F5N
M:64B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS-PIM
M<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R
M(")3^B!D;W-T=7!NZ2!S:W)I<'1Y(&YA('5P9W)A9&4@;F%S=&%V96[M(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-0IM<V=I9"`B4V5V
M97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B
M"FUS9W-T<B`B1&\@^G9A:'D@<')I8VCA9'IA(&YI96MOM6MO(&QO:V%L[70@
M<&]M;V-O=2!P87)A;65T<F$Z("(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B"FUS
M9W-T<B`B4V5Y8VAE;'DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#DX"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R(")3:&]P<&EN9R(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S"FUS9VED(")3:&]R="!3
M=6UM87)Y(@IM<V=S='(@(DMRX71K>2!S^FAR;B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT-3`*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D
M969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R(")-86KZ('-A('!R92!V
MY.BY:6YU(&QI;FEE:R!V>71V;W)INR!S:W)A=&MO=ND@:VSA=F5S>3\B"@HC
M.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C,R,R!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C,S"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C<@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$Q,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*
M;7-G<W1R("):;V)R87IINR(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT
M;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B(@HB6F]B<F%Z:;L@<F]Z9&EE;'D@;65D>FD@<'+A
M=F4@=6QOOF5N;W4@82!N;W9O=GEG96YE<F]V86YO=2!K;VYF:6=U<N%C:6]U
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.30*;7-G:60@(E-H;W<@
M;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`B3>$@
M<V$@<')I('!R:6ALX7-E;NT@>F]B<F%Z:;L@Z&%S('!O<VQE9&[I:&\@<')I
M:&SA<V5N:6$_(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W-CD*;7-G:60@
M(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS9W-T<B`B6F]B<F%Z
M:;L@;6^^;F]SNR!N82!P;VYE8VAA;FEE(&]R:6=I;N%L=2(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR.#`R"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R
M("):;V)R87IINR!NX7-T<F]J(&YA(';]8F5R(&9A<FEE8B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,S`*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T
M:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B6F]B<F%Z:;L@;65N=2!P<F4@;W!E
M<N%C:64@<R!T86)UM6MA;6D_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E<R!-96YU(&]N
M('1H92!L969T/R(*;7-G<W1R("):;V)R87IINR!M96YU("5S(&YA(+5A=F5J
M('-T<F%N93\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@
M4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B6F]B<F%Z:;L@9&EA;/-G(',@
M=FQA<W1N;W.[86UI(&)U;FMY('1A8G6U:WDB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H
M;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(EIO8G)A
M>FF[(&1I86SS9R!S('9L87-T;F]SNV%M:2!T86)UM6MY(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8P"FUS
M9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS
M9W-T<B`B6F]B<F%Z:;L@9&EA;/-G(',@=FQA<W1N;W.[86UI(')I861K=2!T
M86)UM6MY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4R"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T
M:65S(&1I86QO9R(*;7-G<W1R("):;V)R87IINR!D:6%L\V<@<R!V;&%S=&YO
M<[MA;6D@;V)RX7IK=2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8W"FUS
M9VED(")3:&]W('5P;&]A9"(*;7-G<W1R("):;V)R87IINR!N86AR86[I(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3`*;7-G
M:60@(E-H;W=E<G,B"FUS9W-T<B`B4')E:.%N:WDB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,0IM<V=I9"`B4VAO=V5R<R!%
M87)L>2(*;7-G<W1R(")2X6YO('!R96CA;FMY(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H;W=E<G,@3&%T
M92(*;7-G<W1R(").97-K]'(@<')E:.%N:WDB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!I;B!T
M:&4@5FEC:6YI='DB"FUS9W-T<B`B6G+AOFMY('8@;VMO;.TB"@HC.B!L:6(O
M2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HT.#`*;7-G:60@(E-H<FEN:R(*;7-G
M<W1R("):;65NN6F[(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z
M-S<T(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C@S-@HC.B!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+G!H<#HY,C(@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="YP:'`Z.3@T"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C$P-#<@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,3`X-PHC.B!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+G!H<#HQ,3$V(&QI8B](;W)D92]";&]C:R],87EO=70N
M<&AP.C$Q-#D*;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B
M;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R(").86IP<G8@
M;75S[71E('IM96ZY:;L@86QE8F\@<')E<W5N^KL@<W5S961N_2!B;&]K*'DI
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P-0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(E-I97)R82!,96]N
M92(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8V"FUS9VED(")3
M:6=N('5P(@IM<V=S='(@(EIA<F5G:7-T<F]V8;L@<V$B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C<Q,PIM<V=I9"`B4VEG;F%T=7)E(@IM<V=S
M='(@(E!O9'!I<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S$R
M"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S='(@(D%L9V]R:71M
M=7,@<&]D<&ES=2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#8@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R(")3:6YG
M87!U<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY,#`@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$R,3D@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-#$*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(R-3`@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,3D@;&EB
M+TAO<F1E+T9O<FTN<&AP.C,Q,3(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C4@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#0*;7-G:60@(E-I
M>F4B"FUS9W-T<B`B5F6U:V]SNR(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]M86EN=&5N86YC92YH=&UL.C4R"FUS9VED(")3:VEP($UA:6YT96YA;F-E
M(@IM<V=S='(@(E!R97-K;^AINR#Z9'*^8G4B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C$P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#,*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V86MI
M82(*;7-G<W1R(")3;&]V96YS:V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C`X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V96YI82(*;7-G
M<W1R(")3;&]V:6YS:V\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU-`IM<V=I9"`B4VYO=R(*;7-G<W1R(")3;F6^96YI92(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS
M9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R(")3;F5H;W;A('!R96CA;FMA(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*;7-G
M:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R(")3;F5H;W;I('!R96CA;FMY(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G
M:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R(")2X6YO('-N96AO=ND@
M<')E:.%N:WDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU.`IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B3F5S
M:_1R('-N96AO=ND@<')E:.%N:WDB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(W.`IM<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@(DCE8FMA('-N96AU
M.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X,@IM<V=I9"`B4VYO=R!E
M<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B36YOOG-T=F\@=F]D>2!E
M:W9I=F%L96YT;ND@<VYE:'4Z("(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M;VX@27-L86YD
M<R(*;7-G<W1R("*I86QA;?IN;W9E(&]S=')O=GDB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C$T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3;VUA
M;&EA(@IM<V=S='(@(E-O;>%L<VMO(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C8P"FUS9VED(")3;VYG<R`F(%!O96US(@IM<V=S='(@(E!I97-N92!A
M(&+A<VYE(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,34*;7-G:60@(E-O
M<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(E;]8F5R('-M97)U('1R:65D
M96YI82(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Q-R!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(T-PHC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP
M:'`Z,38V(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ.#D*;7-G:60@(E-O
M=7)C92!A9&1R97-S(@IM<V=S='(@(EID<F]J;W;A(&%D<F5S82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR-34@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(P-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G
M:60@(E-O=71H($%F<FEC82(*;7-G<W1R(")*=;YNX2!!9G)I:V$B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B4V]U=&@@175R;W!E86X@
M*$E33RTX.#4Y+3,I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P.`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I
M82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B2G6^
M;N$@1V5O<F=I82!A(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED
M(")3;W5T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(DIUOF[A('!O;&]G=;5A
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',B"FUS9W-T
M<B`B365D>F5R82!M961Z:2!S=7-E9&[];6D@8G5N:V%M:2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3
M<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S
M='(@(DUE9'IE<F$@;65D>FD@;V)S86AO;2!A(&]K<F%J;VT@8G5N:WDB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#$Y"FUS9VED(")3<&%C97(B"FUS9W-T
M<B`B3V1D9;5O=F'H(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@P"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(D]D
M<W1U<"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T
M<B`B3V1S='5P(&$@=GEP;&YE;FEE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C@P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E-P86EN(@IM<V=S='(@
M(JEP86YI96QS:V\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3`P
M"FUS9VED(")3<&%M(@IM<V=S='(@(E-P86TB"@HC.B!S97)V:6-E<R]K97EB
M;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R($EN<'5T(@IM
M<V=S='(@(E9L;[YE;FEE(+EP96-IX6QN>6-H('IN86MO=B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G
M:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`B4F]Z9&5L:;L@8G5N:W4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V
M"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B4F]Z9&5L:;L@<W3E<&5C
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S='(@(E)O>F1E;&F[(')I
M861O:R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,0IM<V=I9"`B4W!O
M<G1S(@IM<V=S='(@(JEP;W)T>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I($QA;FMA(@IM<V=S
M='(@(E-R[2!,86YK82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HV-B!L:6(O0FQO8VLO;65T87(N<&AP.C<T"FUS9VED(")3=&%N9&%R9"(*
M;7-G<W1R("*I=&%N9&%R9&[I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C8R"FUS9VED(")3=&%R(%1R96LB"FUS9W-T<B`B4W1A<B!4<F5K(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(U.3`@;&EB+TAO<F1E+T9O<FTN<&AP.C(W
M.3@*;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B4&_H:6%T;^AN_2!R;VLB
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,0IM<V=I9"`B4W1A
M=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`BJ73A="!A;&5B;R!P<F]V:6YC:6$B
M"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I
M9"`B4W1A='5S(@IM<V=S='(@(E-T878B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C@P-`IM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`B1F]R;>%T
M('5L;[YE;FEA(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S,*
M;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@(D)Y9&QI<VMO(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I
M9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R(")0<F6Y:W)T;G5TZ2(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,C,W"FUS9VED(")3=')I;F<@;&ES="(*;7-G
M<W1R("):;WIN86T@<F6[87IC;W8B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3@W-PIM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS
M9W-T<B`B3V1S='+A;FF[(&1O;>EN=2!Z(&%D<F5S>2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@
M(E-T>6QE(%M#4U-=(@IM<V=S='(@(JET_6P@6T-34UTB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*
M;7-G<W1R(").92(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N
M9"XB"FUS9W-T<B`B4&]D<')I9>AI;F]K(%PB)7-<(B!N96)O;"!NX6ID96[]
M+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S"FUS
M9VED(")3=6)J96-T(@IM<V=S='(@(E!R961M970B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,S,V(&QI8B](;W)D92]&;W)M+U)E;F1E<F5R+G!H<#HS,3<*
M;7-G:60@(E-U8FUI="(*;7-G<W1R(")/9&]S;&&[(@H*(SH@<VEG;G5P+G!H
M<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S
M="!T;R!A9&0@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G
M(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB
M"FUS9W-T<B`B(@HB4&^^:6%D879K82!N82!P<FED86YI92!<(B5S7"(@9&\@
M<WES=.EM=2!B;VQA(&]D;W-L86[A+B!.96WTOF5T92!S82`B"B)P<FEH;.%S
M:;LL(&O];2!N96)U9&4@5F&Y82!P;[YI861A=FMA('-C:';A;&5NX2XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R"FUS
M9VED(")3=6)S8W)I<'0B"FUS9W-T<B`B1&]L;OT@:6YD97@B"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,3`T(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES
M=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R("+:
M<W!E8V@B"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S>7-T96TN
M(@IM<V=S='(@(E!R:61A;FEE(%PB)7-<(B!D;R!S>7-TZ6UU(&)O;&\@^G-P
M9;ENZ2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S
M7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R(")6>6UA>F%N:64@^F1A:F]V
M('IO('-Y<W3I;74@<')E('!O=;[M=F%T9;5A(%PB)7-<(B!B;VQO(/IS<&6Y
M;NDN(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI;B]P97)M<R]D96QE
M=&4N<&AP.C0V"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D
M96QE=&5D(%PB)7-<(BXB"FUS9W-T<B`B5GEM87IA;FEE(%PB)7-<(B!B;VQO
M(/IS<&6Y;NDN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M('1H
M92!S>7-T96TN(@IM<V=S='(@(E9Y;6%Z86YI92!<(B5S7"(@>F\@<WES=.EM
M=2!B;VQO(/IS<&6Y;NDN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU
M,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN
M(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B(@HB3N%V<F%T(&MU
M(&MO;F9I9W5RX6-I:2!B;VP@^G-P9;EN_2X@4')E('IO8G)A>F5N:64@>FUI
M96X@>FYO=G4@;F'H[71A:G1E("(*(G-T<N%N:W4N(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS
M9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(EKA;&]H82!K;VYF:6=U<N%C:64@8F]L82!U;&^^96[A+B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A
M=&EO;B!F:6QE("5S+B(*;7-G<W1R("):X6QOOF[](&MO;F9I9W5R8>AN_2!S
M^F)O<B`E<R!B;VP@^G-P9;EN92!U;&^^96[]+B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=7!D
M871E9"!<(B5S7"(B"FUS9W-T<B`B06MT=6%L:7KA8VEA(%PB)7-<(B!B;VQA
M(/IS<&6Y;N$N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@(EKA<&ES("5S(&)O;"#Z<W!E
MN6[](@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P-`IM<V=I9"`B4W5D86XB"FUS9W-T<B`B4W5DX6XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"FUS
M9VED(")3=6UM87)Y(@IM<V=S='(@(E/Z:')N(@H*(SH@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C8U"FUS9VED(")3=6X@4FES92(*;7-G<W1R(")6_6-H;V0@
M<VQN:V$B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U
M;B!3970B"FUS9W-T<B`B6N%P860@<VQN:V$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.0IM<V=I9"`B4W5N;GDB"FUS9W-T
M<B`B4VQN9>AN;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,#4*;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`B5OUC:&]D('-L;FMA(@H*(SH@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP
M.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R(")6_6-H;V0O>N%P
M860@<VQN:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`T
M"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B5OUC:&]D('-L;FMA.B`B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`X"FUS9VED(")3=6YS
M970B"FUS9W-T<B`B6N%P860@<VQN:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C`W"FUS9VED(")3=6YS970Z("(*;7-G<W1R("):X7!A
M9"!S;&YK83H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`B2&]R;OT@
M:6YD97@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@P"FUS9VED
M(")3=7!P;W)T(@IM<V=S='(@(E!O9'!O<F$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C$U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3(*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3=7)I;F%M
M92(*;7-G<W1R(")3=7)I;F%M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HU-S4*;7-G:60@(E-U<FYA;64B"FUS9W-T<B`B4')I97IV:7-K;R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#D@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(Q,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#4*;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B4W9A
M;&)A<F0@82!*86X@36%Y96XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C$Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T
M<B`B4W9A>FEJ<VMO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM<V=S='(@(JEVZ61S
M:V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-38@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`BJ79A:NAI87)S:V\B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@IM<V=I9"`B4WEN
M8R!L;V<@9&5L971E9"(*;7-G<W1R("):X7IN86UY(&\@<WEN8VAR;VYI>N%C
M:6D@=GEM87IA;NDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30U"FUS
M9VED(")3>6YC34PB"FUS9W-T<B`B4WEN8TU,(@H*(SH@;&EB+TAO<F1E+U-1
M3"]+97EW;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R
M8V@@=&5R;7,B"FUS9W-T<B`B4WEN=&%K=&EC:^$@8VAY8F$@=B!P;V1M:65N
M:V%C:"!HM6%D86YI82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC
M(@IM<V=S='(@(E/]<FEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E0M4W1O<FTB"FUS9W-T<B`B0OIR:V$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM
M<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B0OIR:V$@82!V971E
M<FYO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C(*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(D+Z<FMY(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*;7-G:60@(E0M4W1O
M<FUS($5A<FQY(@IM<V=S='(@(E+A;F\@8OIR:WDB"@HC.B!L:6(O2&]R9&4O
M1&%T82]T<W8N<&AP.C$V-@IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B5%-6
M('/Z8F]R(@H*(SH@;&EB+TAO<F1E+U5)+U1A8FQE+G!H<#HQ,S0*;7-G:60@
M(E1A8FQE(@IM<V=S='(@(E1A8G6U:V$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S"FUS9VED(")486)L92!0
M<F]P97)T:65S(@IM<V=S='(@(E9L87-T;F]S=&D@=&%B=;5K>2(*"B,Z(&QI
M8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W"FUS9VED(")486)L
M92!3970B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE
M<R(*;7-G<W1R(")6;&%S=&YO<W1I('1A8G6U:WDB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C,T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM
M<V=I9"`B5&%I=V%N(@IM<V=S='(@(E1A:7=A;B(*"B,Z(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@
M;V8@0VAI;F$B"FUS9W-T<B`B5&%I=V%N+"!P<F]V:6YC:6$@R.UN>2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C4@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(Q.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*
M;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B5&%DOFEK:7-T86XB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,C`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$R"FUS
M9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S='(@(E1A
M;GKA;FEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY-0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R(")#:66U.B(*"B,Z(&-O
M;F9I9R]H;V]K<RYP:'`N9&ES=#HY.38@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$X.0IM<V=I9"`B5&%S:W,B"FUS9W-T<B`BVFQO:'DB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W-`IM<V=I9"`B5&5L97!H;VYE($YU
M;6)E<B(*;7-G<W1R(")496QE9O-N;F4@Z.US;&\B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(Y,`IM<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS
M9W-T<B`B5&5P;&]T82!Z82!P;W-L961N^B!H;V1I;G4Z("(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C$T"FUS9VED(")496UP97)A='5R92(*;7-G<W1R
M(")497!L;W1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q
M,@IM<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R(")497!L;W1A.B`B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@R"B,L('!H<"UF;W)M
M870*;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D
M96<[)7,B"FUS9W-T<B`B5&5P;&]T83QB<B`O/B@E<TUA>"5S+R5S36EN)7,I
M("9D96<[)7,B"@HC.B!L:6(O2&]R9&4O5&5M<&QA=&4N<&AP.C8X-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S7"(@;F]T(&9O=6YD+B(*
M;7-G<W1R("*I86)L\VYA(%PB)7-<(B!N96)O;&$@;N%J9&5NX2XB"@HC.B!A
M9&UI;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I9"`B5&5M<&QA=&4@061M:6YI
M<W1R871I;VXB"FUS9W-T<B`B4W!RX79A(+EA8FSS;B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,C$U(&QI8B](;W)D92]&;W)M+G!H<#HS,S(U"FUS9VED
M(")497AT(@IM<V=S='(@(E1E>'0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S<Y"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`B26)A('1E>'0B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<T"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@(EIA<F]V;F%N:64@=&5X
M='4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<Q"FUS9VED(")497AT=&]P(@IM<V=S='(@(E1E>'0@:&]R92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@
M(E1H(@IM<V=S='(@(JET(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*
M;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(R,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1H
M86EL86YD(@IM<V=S='(@(E1H86IS:V\B"@HC.B!L:6(O5D93+V9T<"YP:'`Z
M.#0P"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R(")2;WJY[7)E;FEE($944"!N:64@:F4@9&]S='5P;NDN(@H*
M(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,S,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO
M="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R("));G1E9W+A8VEA($AO<F1E+TMO
M;&%B(&YE<&]D<&]R=6IE(%PB)7-<(B(*"B,Z(&QI8B].970O24U34"]";V]K
M+G!H<#HQ,CDX"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN
M:71I86QI>F5D+B(*;7-G<W1R("))35-0('KA>FYA;2!S82!N97!O9&%R:6QO
M('5L;[YINRXB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,S$*;7-G
M:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C
M97-S9G5L;'DB"FUS9W-T<B`B5')I961A($UA:6YT96YA;F-E.CH@<V$@;F5N
M8>CM=&%L82#Z<W!EN6YE(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC
M:V5R+G!H<#HR.0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S
M960N($5X:71I;F<N(@IM<V=S='(@(D]K;F\@<R!N87-T879E;FEA;6D@<V$@
M>F%T=F]R:6QO+B!+;VYI96,N(@H*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HQ
M.#D@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,#`@;&EB+TAO<F1E+U!E<FUS+G!H
M<#HR,3$*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,C,@;&EB+TAO<F1E+U!E
M<FUS+G!H<#HR,S0@;&EB+TAO<F1E+U!E<FUS+G!H<#HR-3(*(SH@;&EB+TAO
M<F1E+U!E<FUS+G!H<#HR-C0@;&EB+TAO<F1E+U!E<FUS+G!H<#HS,#,*;7-G
M:60@(B(*(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A
M('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT
M('1O('5S92!097)M:7-S:6]N<RXB"FUS9W-T<B`B(@HB061M:6YI<W1RX71O
M<B!M=7/M(&YA:V]N9FEG=7)O=F&[('!E<FUA;F5N=&[](&)A8VME;F0@<')E
M(%!RX79A+"!A:R!C:&-E=&4@(@HB<&]UONUV8;L@4'+A=F$N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM
M<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T<B`B26)A('-P;V1N
MX2!S=')A;F$B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S
M<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@
M(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*(DE$(.CM<VQO(&MO;G1A:W1U(&YE
M8F]L;R"Y<&5C:69I:V]V86[I+"!B;VQO('!O;F5C:&%NZ2!P<N%Z9&YE(&%L
M96)O(&YE8F]L;R`B"B)NX6ID96[I('8@9&%T86+A>F4N(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0IM<V=I9"`B5&AE(&-O;G1A
M8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O
M:RXB"FUS9W-T<B`B2V]N=&%K="!B;VP@^G-P9;EN92!V;&^^96[](&1O(%;A
MN6AO(&%D<F5SX7)A+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q
M-S(*;7-G:60@(B(*(E1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K
M(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM
M<V=S='(@(B(*(DYA(&]V97)E;FEE('!O9'#M<V%N96H@<W!RX79Y(&IE('!O
MOF%D;W9A;OT@;V1D96QE;OT@8FQO:R!S(%!'4"!P;V1P:7-O;2XB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4
M:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF
M:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A
M<V4N(@IM<V=S='(@(B(*(DE$('IO>FYA;74@<'+M:F5M8V]V(&)U[R!N96)O
M;&\@N7!E8VEF:6MO=F%NZ2P@86QE8F\@8F]L;R!P;VYE8VAA;ND@<'+A>F1N
M92`B"B)A;&5B;R!N96)O;&\@;N%J9&5NZ2!V(&1A=&%BX7IE+B(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*;7-G:60@(E1H92!D
M:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"XB"FUS9W-T<B`B
M3F5B;VP@=7+H96[]('IO>FYA;2!P<NUJ96UC;W8N(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+G!H<#HQ,38*;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E871U<F5S
M(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(JEI
M9G)O=F%N:64@=GF^861U:F4@8F5Z<&7H;ND@<')I<&]J96YI92`H:'1T<',I
M+B(*"B,Z(&QI8B](;W)D92YP:'`Z,3<W(&QI8B](;W)D92YP:'`Z-3$Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN
M(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B4_IB;W(@)7,@8GD@;6%L(&]B<V%H
M;W9ANR!N87-T879E;FEE("5S+B(*"B,Z(&QI8B](;W)D92YP:'`Z,3<P(&QI
M8B](;W)D92YP:'`Z-3`Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE
M("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@
M(E/Z8F]R("5S(&)Y(&UA;"!O8G-A:&]V8;L@;FEE:W1O<ND@;F%S=&%V96YI
M82`E<RXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(R,PIM<V=I9"`B5&AE(&9I
M;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B6F1R
M;VIO=OT@82!C:66U;W;]('/Z8F]R(&UU<VEA(&)YNR!O9&QIN6[I+B(*"B,Z
M(&QI8B](;W)D92]$871A+G!H<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A
M:6YE9"!N;R!D871A+B(*;7-G<W1R(")3^F)O<B!N96]B<V%H;W9A;""^:6%D
M;F4@^F1A:F4N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP
M:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O
M<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(DYA<VQE
M9'5J^B!H;&%V:>AK>2!T96IT;R!S<'+A=GD@=F\@9F]R;>%T92!M97-S86=E
M+W)F8S@R,BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K
M;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R
M+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE
M('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B
M86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@
M<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES
M(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@
M82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R
M96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB
M<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C
M<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*(D-E;&]O8G)A>F]V:V]V_2!R9;YI
M;2!S</1S;V)U:F4@<')O8FSI;7D@=B!);G1E<FYE="!%>'!L;W)E<FD@:W;T
M;&D@8VAY8N%M("(*(G!R96AL:6%D8>AA+"!K=&]RZ2!S82!NX6T@;F5P;V1A
M<FEL;R!O8NUSNRX@3?2^=2!S82!P<F5J879INR!N97-P<N%V;GEM("(*(GIO
M8G)A>F5N[6TL(&-H_6)A:OIC:6UI(&9U;FMC:6%M:2!E9&ET;W)A(&$O86QE
M8F\@;N%H;V1N_6UI('#A9&UI("(*(G!R96AL:6%D8>AA+B!!:R!J92!6X;D@
M<WES=.EM(%=I;F1O=W,@.7@L(&IE('9EM6UI('!R879D97!O9&]B;NDL(+YE
M('-A("(*(GIO8G)A>NT@8VAY8F$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L
M="<@82!B=61E=&4@;75S:66[(')EN71A<G1O=F&[('!OZ.UT8>@N(@HB7%QN
M7%QN5F%R;W9A;&D@<VUE(%;A<RX@4W1L8>AT92!P<F]S[6T@3TL@86L@;F%O
M>F%J(&-H8V5T92!P;W6^:;L@961I=&]R('8@(@HB8V5L;V]B<F%Z;W9K;W9O
M;2!R9;YI;64N(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDR"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L
M971E9"XB"FUS9W-T<B`B261E;G1I=&$@7"(E<UPB(&)O;&$@=GEM87IA;N$N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T
M<B`B26)A(+5A=N$@<W1R86YA(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I
M;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB
M"FUS9W-T<B`B5')I961A($-R>7!T7W!G<#HZ('!O=')E8G5J92!P;WIN8;L@
M=6UI97-T;F5N:64@<')O9W)A;74@1VYU4$<N(@H*(SH@;&EB+TAO<F1E+TU)
M344O341.+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE
M<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA
M<R!B965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H
M870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*
M;7-G<W1R("(B"B)3<'+A=F$@;V1O<VQA;N$@)7,@<')E("5S(',@<')E9&UE
M=&]M(%PB)7-<(B!B;VQA('IO8G)A>F5NX2Y<;B(*(DYE97AI<W1U:F4@=KEA
M:R!ZX7)U:V$L(+YE('-P<N%V82!B;VQA('!R9>CM=&%NX2!A;&5B;R!P;V-H
M;W!E;N$N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X.#$*;7-G:60@(E1H
M92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G
M92(*;7-G<W1R(")-96YO+"!K=&]RZ2!S82!MX2!P;W6^:;L@<')I(&QI;FMO
M=F%N[2!N82!S='+A;FMU(&YA('#M<V%N:64@<W!RX78@(@H*(SH@;&EB+T9I
M;&4O0U-6+G!H<#HT-S0*;7-G:60@(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU
M<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`B4&_H970@<&]L[2!M=7/M(&)YNR#H
M[7-L;RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R,S(*;7-G
M:60@(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO
M<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@(E1R:65D82!(;W)D
M95]#<GEP=%]S;6EM93HZ('9YOF%D=6IE(&UO9'5L(&]P96YS<VPN(@H*(SH@
M;&EB+TAO<F1E+U!R969S+G!H<#HR.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S879E9"!B
M96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M87AI;75M(&%L;&]W
M86)L92!S:7IE(@IM<V=S='(@(B(*(DYA<W1A=F5N:64@7"(E<UPB('-A(&YE
M<&]D87)I;&\@=6QOOFF[+"!P<F5T;[YE(&IE:&\@^F1A:F4@<')E:W)AZ'5J
M^B`B"B)M87AI;>%L;G4@<&]V;VQE;OH@=F6U:V]SNR(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]D96(N<&AP.C,R(&QI8B](;W)D92]-24U%+U9I97=E
M<B]E;G-C<FEP="YP:'`Z,S4*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS
M<&]W97)P;VEN="YP:'`Z,S(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS
M=V]R9"YP:'`Z,S(@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T
M82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G
M<W1R("(B"B)0<F]G<F%M('!O=;[M=F%N_2!N82!Z;V)R87IE;FEE('1O:'1O
M(/ID86IO=NEH;R!T>7!U("@E<RD@;F5B;VP@;N%J9&5N_2XB"@HC.B!L:6(O
M1FEL92]#4U8N<&AP.C0X-PIM<V=I9"`B5&AE('%U;W1E(&-H87)A8W1E<B!M
M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("):;F%K(&-I
M=.%C:64@;75S[2!B>;L@:F5D96X@>FYA:RXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS9VED(")4:&4@
M<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R("))8F$@<')A=N$@
M82"U87;A('-T<F%N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H="UH86YD('-I
M9&4@;VYL>2(*;7-G<W1R("))8F$@<')A=N$@<W1R86YA(@H*(SH@;&EB+T9I
M;&4O0U-6+G!H<#HT-SD*;7-G:60@(E1H92!S97!A<F%T;W(@;75S="!B92!O
M;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B3V1D9;5O=F'H(&UU<^T@
M8GF[(&IE9&5N('IN86LN(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP
M:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@
M:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B4V5R=F5R(%PB)7-<(B!B;VP@
M=GEM87IA;OTN(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E
M96X@<V%V960N(@IM<V=S='(@(E-E<G9E<B!<(B5S7"(@8F]L('5L;[YE;OTN
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB
M"FUS9W-T<B`BKFEA9&]SNR!O('!R:6ALX7-E;FEE("5S(&)O;&$@=GEM87IA
M;N$N(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,S,P"FUS9VED
M(")4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B
MJ7!E8VEF:6MO=F%N_2!R:6%D;VL@;F5E>&ES='5J92XB"@HC.B!L:6(O5D93
M+W-Q;"YP:'`Z,3<Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T96UP;W)A
M<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(D1OZ&%S
M;OT@<_IB;W(@7"(E<UPB(&YE97AI<W1U:F4N(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C,S,#`*;7-G:60@(E1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N
M;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS9W-T<B`B6F%D
M86[]('1E>'0@;FEE(&IE(')O=FYA:_T@86MO('1E>'0@;F$@;V)R87IO=FME
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY
M(@IM<V=S='(@(DEB82!H;W)NX2!A('-P;V1NX2!S=')A;F$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS
M9VED(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R("))8F$@:&]R;N$@<W1R
M86YA(@H*(SH@;&EB+TAO<F1E+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P
M;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N
M(@IM<V=S='(@(DYA:')A;ND@^F1A:F4@<V$@;V0@<')E9&-HX61Z86KZ8V5H
M;R!K<F]K=2!S=')A=&EL:2XB"@HC.B!L:6(O2&]R9&4O1&%T82]C<W8N<&AP
M.C(V,B!L:6(O2&]R9&4O1&%T82]T<W8N<&AP.C$W,@IM<V=I9"`B5&AE('5P
M;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R(").86AR
M86[]('/Z8F]R('-A(&YE<&]D87)I;&\@=6QOOFF[+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HT.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,3$P"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B0FQO:R!W96%T:&5R+F-O;2!N:64@:F4@
M9&]S='5P;OTN(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F
M;W5N9"XB"FUS9W-T<B`B4')I9>AI;F]K('3I;2!<(B5S7"(@;F5B;VP@;N%J
M9&5N_2XB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$W.`IM<V=I9"`B
M5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R("*N:6%D
M;F4@;F%S=&%V96YI82!N:64@<_H@9&]S='5P;NDN(@H*(SH@;&EB+TAO<F1E
M+TU)344O0V]N=&5N=',N<&AP.C,T.0IM<V=I9"`B5&AE<F4@87)E(&YO('!A
M<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(JYI
M861N92!A;'1E<FYA=.UV;F4@Z&%S=&D@;F5M;[YN;R!Z;V)R87IINR!V('1E
M;&4@<W!RX79Y+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#`U"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T
M97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C
M=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R
M("(B"B)6('1O;71O('!O;&D@:F4@<'+M;&FY('9EM6$@>FYA:V]V+B!:861A
M;&D@<W1E("5S('IN86MO=CL@;75S[71E('IA9&&[(&UE;F5J("(*(F%K;R`E
M<RXB"@HC.B!S:6=N=7`N<&AP.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG(%PB
M)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R(").87-T86QA(&-H>6)A
M('!R:2!P<FEDX79A;NT@7"(E<UPB(&1O('-Y<W3I;74Z("5S(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3(R"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O
M;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B(@HB3F%S=&%L82!C:'EB82!P<FD@
M;V1S=')A\F]V86[M('!O=;[M=F%T9;5S:_UC:"#Z9&%J;W8@7"(E<UPB('IO
M('-Y<W3I;74Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<
M(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R(").87-T86QA(&-H>6)A('!R
M:2!O9'-T<F'R;W9A;NT@7"(E<UPB('IO('-Y<W3I;74Z("(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$U.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B3F%S=&%L
M82!C:'EB82!P<FD@86MT=6%L:7KA8VEI(%PB)7-<(CH@)7,B"@HC.B!L:6(O
M2&]R9&4O0G)O=W-E<BYP:'`Z.3$P"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S
M('=A<R!U<&QO861E9"XB"FUS9W-T<B`B5GES:WET;VP@<V$@<')O8FSI;2!S
M(&YA:'+A=F%N[6T@<_IB;W)U.B"N:6%D96X@)7,@;F5B;VP@;F%H<F%N_2XB
M"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3$U"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB
M86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@(B(*(E9Y<VMY=&]L
M('-A('!R;V)LZ6T@<R!N86ARX79A;NUM('/Z8F]R=3H@)7,@8F]L(';DZ+GM
M(&%K;R!N86IVY.BY[2!P;W9O;&5N_2`B"B)L:6UI="`H)60@8F%J=&]V*2XB
M"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3$W"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N(@IM
M<V=S='(@(E9Y<VMY=&]L('-A('!R;V)LZ6T@<R!U:VQA9&%N[6T@<_IB;W)U
M.B`E<R!B;VP@;F%H<F%N_2!L96X@Z&EA<W1OZ&YE+B(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R
M(").87-T86QA(&-H>6)A('!R:2!Z;V)R87IO=F%N[2!T96IT;R#H87-T:2!S
M<'+A=GDB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB
M"FUS9W-T<B`B3F%S=&%L82!C:'EB82!P<FD@:6UP;W)T92#Z9&%J;W8@;R!K
M;VYT86MT92XB"@HC.B!L:6(O2&]R9&4O1&%T82]I;6,N<&AP.C,Q"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@
M9&%T82XB"FUS9W-T<B`B3F%S=&%L82!C:'EB82!P<FD@:6UP;W)T92#Z9&%J
M;W8@:4-A;&5N9&%R+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#`*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A
M=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D
M(&9I96QD+B(*;7-G<W1R("(B"B).87-T86QA(&-H>6)A('8@:V]N9FEG=7)A
MZ&YO;2!F;W)M=6SA<FDN(%!R879D97!O9&]B;F4@<W1E(&YE=GEP;&YI;&D@
M(@HB<&^^861O=F%NZ2!P;VQE+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P
M97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N
M+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B).87-T
M86QA(&-H>6)A('!R:2!V>6MO;N%V86[M('5RZ&5N96H@9G5N:V-I92!A9')E
M<^%R82X@4')O<^UM('-K^G-T92!T;R`B"B)N97-K]'(N(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L
M96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(DYA<W1A;&$@8VAY
M8F$@<')I(&%K='5A;&EZX6-I:2!D971A:6QO=B!K;VYT86MT=2X@4')O<^UM
M('-K^G-T92!T;R!N97-K]'(N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8T-2!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,C(R"FUS
M9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R
M:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R
M("(B"B).87-T86QA(&-H>6)A('!R:2!A:W1U86QI>N%C:6D@>F]Z;F%M=2!P
M<NUJ96UC;W8N(%!R;W/M;2!S:_IS=&4@=&\@>FYO=G4N(@H*(SH@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T.`IM<V=I9"`B5&AI<R!)34%0
M('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS
M9W-T<B`B5&5N=&\@24U!4"!S97)V97(@;F5P;V1P;W)U:F4@>F1I9;5A;FEE
M('!R:67H:6YK;W8N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L
M:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(E1O=&\@<')A=F1E<&]D;V)N92!N
M:64@:F4@<&QA=&[](&%R8VCM=B!R87(N(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R
M('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(E1O=&\@<')A=F1E
M<&]D;V)N92!N:64@:F4@<&QA=&[](&%R8VCM=B!Z:7`N(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C,Q,S0*;7-G:60@(E1H:7,@9&]E<R!N;W0@<V5E;2!T
M;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R(")4;W1O('!R879D
M97!O9&]B;F4@;FEE(&IE('!L871NZ2#H[7-L;R!K87)T>2XB"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T
M:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G871E
M=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB5&5N=&\@;W9L
MX61AZ"!U;6^^\G5J92!P;W-I96QA;FEE('-P<N%V(&-E>B!B<N%N=2!#;&EC
M:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI('!O;6]C;W4@2%14
M4"!!4$DB"@HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED
M("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T
M:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y
M+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB5&5N=&\@;W9LX61A
MZ"!U;6^^\G5J92!P;W-I96QA;FEE('-P<N%V(&-E>B!B<N%N=2!724X@*&AT
M='`Z+R]W:6YP;&,N8V]M*2`B"B)P;VUO8V]U($A45%`@05!)(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T
M:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A
M>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*(E1E;G1O(&]V;.%D
M8>@@=6UOOO)U:F4@<&]S:65L86YI92!S<'+A=B!C97H@8G+A;G4@<VUS,F5M
M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@<&]M;V-O=2!(5%10($%0
M22(*"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*
M;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY("(*(F=A
M=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@
M86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY("AH='1P
M.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*(E1E;G1O(&]V;.%D8>@@=6UO
MOO)U:F4@<&]S:65L8;L@<W!RX79Y(&-E>B!33510(&-E>B!B<N%N=2!6;V1A
M9F]N92!)=&%L>2`B"B(H:6)A(&YA(.CM<VQA(%9O9&%F;VYE*2X@5GF^861U
M:F4@92UM86EL;W;](/KH970@5F]D869O;F4@271A;'D@*&AT='`Z+R\B"B)W
M=W<N,3DP+FET*2XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3@R(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,#8Q(&QI8B](;W)D92]&;W)M+G!H<#HQ,#DP"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,3$Y(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,3@V(&QI8B](;W)D92]&;W)M+G!H<#HQ,C8P"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,S`Y(&QI8B](;W)D92]&;W)M+G!H<#HQ-#`R(&QI8B](;W)D92]&
M;W)M+G!H<#HQ-38Q"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#0S(&QI8B](
M;W)D92]&;W)M+G!H<#HQ.38R(&QI8B](;W)D92]&;W)M+G!H<#HR,#`Y"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,#,S(&QI8B](;W)D92]&;W)M+G!H<#HR
M,#@R(&QI8B](;W)D92]&;W)M+G!H<#HR,34S"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR,C(U(&QI8B](;W)D92]&;W)M+G!H<#HR-#$R(&QI8B](;W)D92]&
M;W)M+G!H<#HR-#4T"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-C0T(&QI8B](
M;W)D92]&;W)M+G!H<#HR.#$W(&QI8B](;W)D92]&;W)M+G!H<#HS,3(V"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HS,CDU(&QI8B](;W)D92]&;W)M+G!H<#HS
M.#`S(&QI8B](;W)D92]&;W)M+G!H<#HS.#$Q"FUS9VED(")4:&ES(&9I96QD
M(&ES(')E<75I<F5D+B(*;7-G<W1R(")4;W1O('!O;&4@:F4@<&]V:6YNZ2XB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`V.0IM<V=I9"`B5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R(")4;W1O('!O
M;&4@;?2^92!O8G-A:&]V8;L@:6)A(.CM<VQA+B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR-#(P"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R(")4;W1O('!O;&4@
M;?2^92!O8G-A:&]V8;L@:6)A(.CM<VQA(&$@9'9O:F)O9&MU+B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,#DX"FUS9VED(")4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R(")4;W1O('!O;&4@
M;?2^92!O8G-A:&]V8;L@:6)A(&]S;6GH:V]VZ2!H;V1N;W1Y+B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,3(W"FUS9VED(")4:&ES(&9I96QD(&UU<W0@
M8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R
M<R(*;7-G<W1R(")4;W1O('!O;&4@;75S[2!B>;L@>F]Z;F%M(.CM<V5L(&]D
M9&5L96[]8V@@Z&EA<FMO=2!A;&5B;R!M961Z97)O=2(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HY.3,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A
M;&ED(&YU;6)E<BXB"FUS9W-T<B`B5&]T;R!P;VQE(&UU<^T@8GF[('!L871N
MZ2#H[7-L;RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@R-0IM<V=I9"`B
M(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H
M92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*
M;7-G<W1R("(B"B)4;W1O('!O;&4@;75S[2!O8G-A:&]V8;L@:_-D(&9A<F)Y
M('8@N65S=&[A<W1K;W9O;2!F;W)MX71E(%)'0BP@;F%P<NUK;&%D("(*(B<C
M,3(S-&%F)RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z-38U"FUS9VED(")4
M:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@
M(E1E;G1O(&9O<FUU;.%R('6^(&)O;"!S<')A8V]V86[]+B(*"B,Z('1E;7!L
M871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M:7,@:7,@)7,N(@IM<V=S='(@(E1O=&\@:F4@)7,N(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HT-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I
M<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE
M8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E
M<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES
M="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I<VET("5S(@IM
M<V=S='(@(B(*(E1O=&\@:F4@;V)J96MT($MO;&%B($=R;W5P=V%R92X@4')E
M('IO8G)A>F5N:64@=&]H=&\@;V)J96MT=2!P;W1R96)U:F5T92!E+2(*(FUA
M:6QO=NEH;R!K;&EE;G1A+"!K=&]R_2!R;WIU;6EE(&9O<FWA='4@2V]L86(@
M1W)O=7!W87)E+B!0<F4@>F]Z;F%M("(*(G1A:_UC:'1O(&ML:65N=&]V(&YA
M=KET[79T92!P<F]S[6T@)7,B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT
M<RYP:'`Z-3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@;65S<V%G92!W
M87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N
M('EO=7(@;W=N+B(*;7-G<W1R("(B"B)4X71O('-P<N%V82!B;VQA(&YA<.US
M86[A('8@:6YE:B!A:V\@5F%M:2!P;W6^[79A;F5J('IN86MO=F5J('-A9&4@
M*"5S*2XB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B
M5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(E1O
M=&\@Z.US;&\@;75S[2!B>;L@;F%J;65N96H@,2XB"@HC.B!L:6(O2&]R9&4O
M0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T
M('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R(")496YT
M;R!S97)V97(@;F5D;VOAOF4@9&5K;VUP<FEM;W9ANR!S^F)O<GD@>FEP(&$@
M9WII<"XB"@HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C$X,@IM<V=I9"`B
M5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R
M(")3>7-TZ6T@:F4@;6]M96YTX6QN92!D96%K=&EV;W9A;OTN(@H*(SH@;&EB
M+TAO<F1E+U!R969S+U5)+G!H<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@;75S
M="!B92!A(&YU;6)E<BXB"FUS9W-T<B`B5.%T;R!H;V1N;W1A(&UU<^T@8GF[
M(.CM<V5L;N$N(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H
M<#HS-0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A
M;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R(")4;W1O(&]K;F\@;75S[2!B>;L@
M>F%V;VQA;ND@>B!O:VYA($YA<W1A=F5N[2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4:'5N9&5R(@IM<V=S
M='(@(DAR;65N:64B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,V
M"FUS9VED(")4:6-K971S(@IM<V=S='(@(E1I8VME=',B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C0R.2!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M-34*;7-G:60@(E1I;64B"FUS9W-T<B`BR&%S(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,X.`IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R
M(")4:6UE(%1R86-K:6YG(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W"FUS
M9VED(")4:6UE(&9O<FUA="(*;7-G<W1R(")&;W)MX70@Z&%S=2(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR-3,U"FUS9VED(")4:6UE('-E;&5C=&EO;B(*
M;7-G<W1R(")6_6)E<B#H87-U(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(S,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS
M9W-T<B`B5&EM;W(M3&5S=&4B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B
M5&ET;&4B"FUS9W-T<B`B5&ET=6QO:R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L=&EP
M*3HB"FUS9W-T<B`B3F%D<&ES("AB=6)L:6YO=OT@=OUP:7,I.B(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED(")4;R(*
M;7-G<W1R(")0<F4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C4Q"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L
M(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@
M:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"B)0<F4@=OUB97(@
M=FEA8V5R_6-H('!O;&^^:65K(&1ROG1E('!OZ&%S(&ML:6MA;FEA(&MLX79E
M<W4@0V]N=')O;"`H4$,I(&%L96)O("(*(D-O;6UA;F0@*$UA8RDN(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,`IM<V=I9"`B5&]D87DB
M"FUS9W-T<B`B1&YE<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G
M<W1R(")0<F5P;OJ[('IO8G)A>F5N:64@>F1R;VIO=NEH;R!K\V1U($A434PB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(S(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,C,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`Y"FUS9VED(")4;V=O(@IM<V=S='(@(E1O9V\B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C(V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VME
M;&%U(@IM<V=S='(@(E1O:V5L874B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S`R"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R("):86IT<F$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(Y(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$P"FUS9VED(")4;VYG82(*;7-G<W1R(")4;VYG82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-PIM<V=I9"`B
M5&]P(@IM<V=S='(@(E9R8V@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A;64@*%]T;W`I(@IM
M<V=S='(@(E9R8VAN_2!RX6UE8R`H7W1O<"DB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R(")0<F5K
M;&%D>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S(@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B
M5')I;FED860@82!4;V)A9V\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<Y
M-`IM<V=I9"`B5')U92!O<B!F86QS92(*;7-G<W1R(")0<F%V9&$@86QE8F\@
M;F5P<F%V9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R(")5="(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(R-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U
M;FES:6$B"FUS9W-T<B`B5'5N:7-K;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U<FME>2(*;7-G
M<W1R(")4=7)E8VMO(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G
M:60@(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(R.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@
M(E1U<FMM96YI<W1A;B(*;7-G<W1R(")4=7)K;65N:7-T86XB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C(P(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,S`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED
M(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B5'5R:W,@82!#
M86EC;W,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,S(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,S$*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B5'5V86QU(@H*(SH@
M;&EB+TAO<F1E+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO:6-E
M.B`B"FUS9W-T<B`B6F%D86IT92!68;EU('9OM6)U.B`B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4X"FUS9VED(")5+E8N(&EN9&5X.B`B
M"FUS9W-T<B`B52Y6+B!I;F1E>#H@(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,3<*;7-G
M:60@(E523"(*;7-G<W1R(")54DPB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E
M;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B55),(%;AN6AO('-K<FEP
M='4@<')E('-P<N%V=2!O(&1O<G7H96[M(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PIM<V=I9"`B55),.B(*;7-G<W1R
M(")54DPZ(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q,@IM<V=I9"`B56=A;F1A(@IM<V=S='(@(E5G86YD82(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S8@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(S,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*
M;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B56MR86II;F$B"@HC.B!L:6(O5D93
M+V9I;&4N<&AP.C0Q-@IM<V=I9"`B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER
M96-T;W)Y+B(*;7-G<W1R(").97!O9&%R:6QO('-A('5S:W5T;^AN:;L@<'+M
M<W1U<"!K(%9&4R!A9')E<^%R=2XB"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N
M=7`N<&AP.CDV"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF
M;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R("(B"B).97!O9&%R
M:6QO('-A('!R:61ANR#O86RY:64@:6YF;W)MX6-I92!O('!O=;[M=F%T9;5O
M=FD@<')I(')E9VES='+A8VEI+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS.3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S
M:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DYE<&]D87)I;&\@
M<V$@>FUE;FF[('!RX79O('!R92!61E,@<_IB;W(@7"(E<UPB+B(*"B,Z(&QI
M8B]61E,O9FEL92YP:'`Z,S@Y(&QI8B]61E,O;75S<6PN<&AP.C0V.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@
M9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R(").97!O9&%R:6QO('-A('IM
M96YINR!P<N%V;R!P<F4@5D93('/Z8F]R("5S+R5S+B(*"B,Z(&QI8B]61E,O
M9G1P+G!H<#HW-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H
M86YG92!T;R`E<RXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!Z;65N:;L@;F$@
M)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7-<(BXB"FUS
M9W-T<B`B3F5P;V1A<FEL;R!S82!S:V]N=')O;&]V8;L@=F6U:V]SNR!S^F)O
M<G4@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-CDR(&QI8B]61E,O
M<W%L+G!H<#HQ,#$Y(&QI8B]61E,O<W%L7V9I;&4N<&AP.C@T,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB
M)7,O)7-<(BXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!S:V]N=')O;&]V8;L@
M=F6U:V]SNR!S^F)O<G4@7"(E<R\E<UPB+B(*"B,Z(&QI8B](;W)D92]!=71H
M+W-Q;"YP:'`Z-#,Y"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@
M<V5R=F5R+B(*;7-G<W1R(").97!O9&%R:6QO('-A('-P;VIINR!S(%-13"!S
M97)V97)O;2XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#4Y"FUS9VED(")5;F%B
M;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`B3F5P;V1A<FEL;R!S
M82!S<&]J:;L@<&]M;V-O=2!34TPN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR
M,CD@;&EB+U9&4R]F:6QE+G!H<#HR,S0@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z
M,C`T"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(P.2!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HR,3<*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*
M;7-G<W1R(").97!O9&%R:6QO('-A('-K;W#M<F]V8;L@5D93('/Z8F]R+B(*
M"B,Z(&QI8B]61E,O9G1P+G!H<#HS-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T
M<B`B3F5P;V1A<FEL;R!S82!V>71V;W)INR!61E,@861R97/A<B!<(B5S7"(N
M(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS-3@@;&EB+U9&4R]M=7-Q;"YP:'`Z
M,C4X(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(V-`IM<V=I9"`B56YA8FQE('1O
M(&-R96%T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").97!O9&%R:6QO('-A
M('9Y='9O<FF[(%9&4R!A9')E<^%R+B(*"B,Z(&QI8B]61E,O;75S<6PN<&AP
M.C$R-`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9FEL92XB"FUS9W-T
M<B`B3F5P;V1A<FEL;R!S82!V>71V;W)INR!61E,@<_IB;W(N(@H*(SH@;&EB
M+U9&4R]S;6(N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@8W)E871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(").97!O9&%R
M:6QO('-A('9Y='9O<FF[(%9&4R!P<FEEZ&EN;VL@7"(E<UPB+B(*"B,Z(&QI
M8B]61E,O9FEL92YP:'`Z,C8Y"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&5M
M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R(").97!O9&%R:6QO('-A('9Y='9O<FF[
M('!RX7ID;GD@5D93('/Z8F]R+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]T
M87(N<&AP.C<V(&QI8B](;W)D92]#;VUP<F5S<R]G>FEP+G!H<#HW.0IM<V=I
M9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B3F5P;V1A
M<FEL;R!S82!D96MO;7!R:6UO=F&[(/ID86IE+B(*"B,Z(&QI8B]61E,O<VUB
M+G!H<#HR,C@@;&EB+U9&4R]F='`N<&AP.C,P,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I
M<R!N;W0@96UP='DN(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@=GEM87IANR!<
M(B5S7"(L(&%D<F5SX7(@;FEE(&IE('!RX7ID;GDN(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS
M9W-T<B`B3F5P;V1A<FEL;R!S82!V>6UA>F&[(%PB)7-<(CH@)7,N(@H*(SH@
M;&EB+U9&4R]F:6QE+G!H<#HS,S4@;&EB+U9&4R]S<6PN<&AP.C,Y-2!L:6(O
M5D93+VUU<W%L+G!H<#HS,3$*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S0R
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H
M92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(DYE<&]D87)I;&\@
M<V$@=GEM87IANR`E<RP@861R97/A<B!N:64@:F4@<'+A>F1N>2(*"B,Z(&QI
M8B]61E,O<W%L7V9I;&4N<&AP.C,U-B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS
M-C`*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U
M<G-I=F5L>2XB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!R96MU<GKM=FYE('9Y
M;6%Z8;L@5D93(&%D<F5SX7(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS-#$@
M;&EB+U9&4R]M=7-Q;"YP:'`Z,S(R(&QI8B]61E,O;75S<6PN<&AP.C,S-0HC
M.B!L:6(O5D93+VUU<W%L+G!H<#HS-#,@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z
M,S4R"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM
M<V=S='(@(DYE<&]D87)I;&\@<V$@=GEM87IANR!61E,@861R97/A<BXB"@HC
M.B!L:6(O5D93+W-Q;"YP:'`Z-#(P(&QI8B]61E,O<W%L+G!H<#HT,S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T
M;W)Y.B`E<RXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!V>6UA>F&[(%9&4R!A
M9')E<^%R.B`E<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,C$R"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R(").97!O9&%R:6QO('-A('9Y;6%Z8;L@5D93('/Z8F]R(%PB
M)7-<(BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,P-R!L:6(O5D93+W-Q;"YP
M:'`Z,CDQ(&QI8B]61E,O;75S<6PN<&AP.C$V-PHC.B!L:6(O5D93+VUU<W%L
M+G!H<#HQ.#`@;&EB+U9&4R]M=7-Q;"YP:'`Z,3@W(&QI8B]61E,O<W%L7V9I
M;&4N<&AP.C,Y,0HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS.3D*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S='(@(DYE<&]D87)I
M;&\@<V$@=GEM87IANR!61E,@<_IB;W(N(@H*(SH@;&EB+U9&4R]S;6(N<&AP
M.C(T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(").97!O9&%R:6QO('-A('9Y;6%Z
M8;L@5D93('!R:67H:6YO:R!<(B5S7"(N(@H*(SH@;&EB+U9&4R]S<6PN<&AP
M.C0P.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@<F5K
M=7)Z[79N92!V>6UA>F&[(%9&4SH@)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP
M.C@R,PIM<V=I9"`B56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!U<NAINR!A:W1UX6QN>2!A
M9')E<^%R+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C`T"FUS
M9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM
M<V=S='(@(DYE<&]D87)I;&\@<V$@>FES=&F[('!O9')O8FYO<W1I(&\@8V5R
M=&EF:6OA=&4N(@H*(SH@;&EB+TYE="])35-0+G!H<#HT,S<@;&EB+TYE="])
M35-0+T%U=&@N<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B3F5M;[YN
MZ2!N86AR8;L@9&5F:6[M8VEU("5S+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z
M,C`P(&QI8B]61E,O9FEL92YP:'`Z,C`U(&QI8B]61E,O<W%L7V9I;&4N<&AP
M.C$W-`HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-SD*;7-G:60@(E5N86)L
M92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R(").97!O9&%R:6QO('-A('!R
M97-U;OJ[(%9&4R!S^F)O<BXB"@HC.B!L:6(O5D93+W-M8BYP:'`Z.3,@;&EB
M+U9&4R]S;6(N<&AP.C$P-B!L:6(O5D93+W-M8BYP:'`Z-C4R"B,Z(&QI8B]6
M1E,O9G1P+G!H<#HY.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@
M;W1V;W)INR!61E,@<_IB;W(@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP
M:'`Z,C@Q(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$S."!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HQ-#$*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O
M<B!W<FET:6YG+B(*;7-G<W1R(").97!O9&%R:6QO('-A(&]T=F]R:;L@5D93
M('/Z8F]R(&YA('KA<&ES+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z.#,@;&EB
M+U9&4R]F:6QE+G!H<#HQ,S0@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S8*;7-G
M:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R(").97!O9&%R
M:6QO('-A(&]T=F]R:;L@5D93('/Z8F]R+B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]T9WHN<&AP.C0U"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP
M<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@;W1V;W)I
MNR!K;VUP<FEM;W9A;OT@87)C:.UV+B(*"B,Z(&QI8B]61E,N<&AP.C@U-0IM
M<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I
M;&5D*2XB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!P<F7H[71ANR!61E,@<_IB
M;W(@*&9U;FMC:6$@9FEL97-I>F4H*2!Z;'EH86QA*2XB"@HC.B!L:6(O5D93
M+G!H<#HX.#8*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&
M:6QE4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@<')E
MZ.UT8;L@5D93('/Z8F]R("AF=6YK8VEA(&=E=$9I;&53:7IE*"D@>FQY:&%L
M82DN(@H*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X
M"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`B3F5P;V1A
M<FEL;R!S82!P<F7H[71ANR!S^F)O<CHB"@HC.B!L:6(O5D93+V9I;&4N<&AP
M.C8W,PIM<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T
M;W)Y+B(*;7-G<W1R(").97!O9&%R:6QO('-A(.CM=&&[(&%D<F5SX7(@=F9S
M<F]O="XB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$Q,#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN
M871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(DYE<&]D87)I
M;&\@<V$@<')E;65N;W9ANR`E<R!N82`E<SH@8VEEM6]V_2!P<FEEZ&EN;VL@
M=;X@97AI<W1U:F4B"@HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS,#$*;7-G
M:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M3F5P;V1A<FEL;R!S82!P<F5M96YO=F&[(%9&4R!A9')E<^%R+B(*"B,Z(&QI
M8B]61E,O<W%L+G!H<#HS,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B3F5P;V1A
M<FEL;R!S82!P<F5M96YO=F&[(%9&4R!A9')E<^%R.B`E<RXB"@HC.B!L:6(O
M5D93+W-M8BYP:'`Z,C<Q(&QI8B]61E,O9G1P+G!H<#HS-#@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92!<(B5S7"(N
M(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@<')E;65N;W9ANR!61E,@<_IB;W(@
M7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-C$T(&QI8B]61E,O;75S
M<6PN<&AP.C(R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N
M86UE(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R(").97!O9&%R:6QO('-A('!R
M96UE;F]V8;L@5D93('/Z8F]R("5S+R5S+B(*"B,Z(&QI8B]61E,O<W%L+G!H
M<#HS,C8@;&EB+U9&4R]M=7-Q;"YP:'`Z,C$S(&QI8B]61E,O;75S<6PN<&AP
M.C0U,@HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR.3,@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z,S`Y"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE
M+B(*;7-G<W1R(").97!O9&%R:6QO('-A('!R96UE;F]V8;L@5D93('/Z8F]R
M+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS9VED
M(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B3F5P;V1A<FEL
M;R!S82!S<'5S=&F[("=M:VES;V9S)RXB"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O('1R86YS;&%T
M92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!P
M<F5L;[YINR!T96YT;R!D;VMU;65N="!7;W)D(@H*(SH@;&EB+U9&4R]F='`N
M<&AP.C$U-"!L:6(O5D93+V9T<"YP:'`Z,34W"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(DYE<&]D87)I;&\@<V$@>F%P[7-ANR!61E,@<_IB;W(@7"(E<UPB+B(*"B,Z
M(&QI8B]61E,O9FEL92YP:'`Z,3@S"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R(").97!O9&%R:6QO
M('-A('IA<.US8;L@5D93('/Z8F]R("AF=6YK8VEA(&-O<'DH*2!Z;'EH86QA
M*2XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(X-2!L:6(O5D93+W-Q;%]F:6QE
M+G!H<#HQ-#8@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,34Q"FUS9VED(")5;F%B
M;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T<B`B3F5P;V1A<FEL
M;R!S82!Z87#M<V&[(/ID86IE(%9&4R!S^F)O<G4N(@H*(SH@;&EB+U9&4RYP
M:'`Z.#8Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A
M('=I;&P@8F4@97AC965D960N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@>F%P
M[7-ANR!61E,@<_IB;W(L(&MV\W1A(&IE('!R96MR;^AE;N$N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,`IM<V=I9"`B
M56YD97)L:6YE(@IM<V=S='(@(E!O9.AI87)K;G5TZ2(*"B,Z('1E;7!L871E
M<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R
M("):<G6Y:;L@>FUE;GDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO
M;B(*;7-G<W1R("):<G6Y[2!P;W-L961N^B!A:V-I=2(*"B,Z(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,Y,`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F
M<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`B3F5OZ&%KX79A
M;N$@;V1P;W9E[R!O9"!S97)V97)A('!OZ&%S('-P;VIE;FEA.B`B"@HC.B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS-#$*(SH@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,W."!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S@T"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R
M('1O.B`B"FUS9W-T<B`B3F5OZ&%KX79A;N$@;V1P;W9E[R!O9"!S97)V97)A
M(&YA.B`B"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H
M<#HU-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHV,0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R(").96YA<W1A=F5NX2(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(")5;FEC;V1E("A55$8M
M."DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-38*;7-G:60@(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM
M<V=S='(@(E-P;VIE;ND@87)A8G-KZ2!E;6ERX71Y(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(S."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<T"FUS9VED(")5;FET
M960@2VEN9V1O;2(*;7-G<W1R(")69;5KX2!"<FETX6YI82(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR-#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(S-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@
M(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B4W!O:F5NZ2"Y=.%T>2!!;65R:6-K
MZ2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,SD@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(S-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,0IM<V=I9"`B56YI=',B"FUS
M9W-T<B`B2F5D;F]T:WDB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT
M,CD@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#,P"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]T9WHN<&AP.C4X"FUS9VED(")5;FMN;W=N(@IM<V=S='(@
M(DYE>F[A;64B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I
M+B(*;7-G<W1R(").97INX6UE(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN
M(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G
M:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS
M9W-T<B`B3F5Z;N%M92!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#<*;7-G:60@(E5N
M:VYO=VX@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(D)O;&$@>F%D86[A
M(&YE<&QA=&[A(&QO:V%L:71A+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A
M<W-W;W)D+B(*;7-G<W1R(").97INX6UE('!O=;[M=F%T9;5S:^D@;65N;R!A
M;&5B;R!H97-L;RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N
M="!E;&5M96YT(@IM<V=S='(@(D]D<W1RX6YINR!L:6YK=2!Z(&%K='7A;&YE
M:&\@96QE;65N='4B"@HC.B!L:6(O2&]R9&4O261E;G1I='DN<&AP.C,P,0IM
M<V=I9"`B56YN86UE9"(*;7-G<W1R(").97!O;65N;W9A;N$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y"FUS9VED("(B
M"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y
M+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N
M<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL
M;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I
M<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*(DYE<')I
M=FEL96=O=F%NZ2!S:W)I<'1Y(&YE;6%J^B!Z(&)E>G!EZ&YO<W1N_6-H(&3T
M=F]D;W8@<'+M<W1U<"!K('9OM6+A;2`B"B)6>7-T<FEH;OJ[+TMO<.UR;W9A
MNR]6;&^^:;LN($ML:6MN:71E(&YA($]+(&$@>F]B<F%Z[2!S82!T96-H;FEC
M:^$@(@HB:6YF;W)MX6-I82!N82!S='+A;FME(&UO>FEL;&$N;W)G+"!K=&]R
MX2!6X7,@:6YF;W)M=6IE+"!A:V\@=6UOOFYINR!S:W)I<'1U("(*(G!R[7-T
M=7`@:R!S8VARX6YK92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C;VQO<B(*;7-G
M<W1R(")/9'-T<N%N:;L@9F%R8G4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C8X-R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.CDR-PHC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.CDS,PIM<V=I9"`B56YS=7!P;W)T
M960@17AT96YS:6]N(@IM<V=S='(@(DYE<&]D<&]R;W9A;ND@<F]ZN>UR96YI
M92(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,3DW('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B
M06MT=6%L:7KA8VEA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHR.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T
M<B`B06MT=6%L:7IO=F&[("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHW-@IM<V=I9"`B57!D871E('5S97(B"FUS9W-T<B`B06MT
M=6%L:7IO=F&[('!O=;[M=F%T9;5A(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ
M-#0@861M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E
M9&ET+G!H<#HR,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S
M7"(N(@IM<V=S='(@(D%K='5A;&EZX6-I82!<(B5S7"(@8F]L82#Z<W!EN6[A
M+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS9VED(")5<&=R
M861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R(")3:W)I<'0@;F$@=7!G<F%D
M92!B;VP@=GEM87IA;OTN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W
M."!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DX"FUS9VED
M(")5<&QO860B"FUS9W-T<B`B3F%H<F&[(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E
M='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(E:Y971K>2!S^F)O
M<GD@<R!K;VYF:6=U<N%C:6]U(&)O;&D@;F%H<F%NZ2!N82!S97)V97(N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N
M9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R(")6
M9;5KZ2!L871I;G-KZ2!P[7-M96[A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B57!P97(@
M<F]M86X@;G5M8F5R<R(*;7-G<W1R(")69;5KZ2!R[6US:V4@Z.US;&EC92(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(S.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B57)U9W5A>2(*"B,Z(&QI8B](
M;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L('!H<"UF;W)M
M870*;7-G:60@(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R(")0;W6^:;L@86MT
M=>%L;F4Z("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4S.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R(")0;W6^:;L@4U-,(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-PIM<V=I9"`B57-E(&EF(&YA;64O
M<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T
M<B`B4&]UOFET92!V('!R[7!A9&4L(+YE(&IE(&UE;F\O:&5S;&\@;V1L:;EN
MZ2!P<F4@24U34"!S97)V97(N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]E9&ET+FEN8SHR,0IM<V=I9"`B57-E<B(*;7-G<W1R(")0;W6^[79A=&6U
M(@H*(SH@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HW,38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM
M<V=S='(@(E!O=;[M=F%T9;4@)7,@;FEE(&IE(&%U=&]R:7IO=F%N_2!N82`E
M<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S97(@061M:6YI
M<W1R871I;VXB"FUS9W-T<B`B4W!RX79A('!O=;[M=F%T9;5O=B(*"B,Z(&QI
M8B](;W)D92]0<F5F<R]522YP:'`Z,C4Q"FUS9VED(")5<V5R($]P=&EO;G,B
M"FUS9W-T<B`B4&]UONUV871EM7-KZ2!N87-T879E;FEA(@H*(SH@<VEG;G5P
M+G!H<#HV,@IM<V=I9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T<B`B4F5G
M:7-T<N%C:6$@<&]UONUV871EM6$B"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED
M(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI
M<R!S:71E+B(*;7-G<W1R(")296=I<W1RX6-I82!P;W6^[79A=&6U;W8@8F]L
M82!P<F4@=&5N=&\@<WES=.EM('IA:^%Z86[A+B(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HT-CD*;7-G:60@(E5S97(@86-C;W5N="!N;W0@9F]U;F0B
M"FUS9W-T<B`B4&]UONUV871EM7-K_2#ZZ&5T(&YE8F]L(&[A:F1E;OTB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<Y
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8@;&EB+TYE
M="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y."!L:6(O3F5T+U--4R]W:6Y?:'1T
M<"YP:'`Z,34P"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,S('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S(*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM<V=S='(@
M(E!O=;[M=F%T9;5S:^D@;65N;R(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU
M<"YP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<
M(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B4&]UONUV871EM7-KZ2!M96YO
M(%PB)7-<(B!UOB!E>&ES='5J92XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R(")0;W6^[79A
M=&6U<VOI(&UE;F\Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z
M.`IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R(")0;W6^[79A=&6U<VOI(&UE
M;F\Z("(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G
M:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(E!O=;[M=F%T96QI
M82!S>7-TZ6UU.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B57IB
M96MI<W1A;B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,38W(&QI8B]61E,O9FEL
M92YP:'`Z,C4Y"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T
M+B(*;7-G<W1R(")61E,@861R97/A<B!N965X:7-T=6IE+B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ,C`*;7-G:60@(E9A8V%T:6]N(@IM<V=S
M='(@(D1O=F]L96YK82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX-S`*;7-G
M:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`B
M4&QA=&[I('5M:65S=&YE;FEA('IA:.#R86KZ.B`B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B
M4&QA=&YO<[LB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3DW(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U"FUS9VED
M(")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R(")0;&%T;F]S
MNR!V(&UI;OIT86-H(&]D=&5R87HN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C@V,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$X,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB
M"FUS9W-T<B`B2&]D;F]T82!P<F5K<F_H:6QA(&UA>&EMX6QN=2!DY;YK=2`E
M<RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(T."!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C(W,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,R,`HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,CDQ-R!L:6(O2&]R9&4O1F]R;2]4>7!E+W1A8FQE<V5T
M+G!H<#HU.0IM<V=I9"`B5F%L=65S(@IM<V=S='(@(DAO9&YO='DB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C$Q,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Y
M,`IM<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(DAO9&YO
M='DL('H@:W1O<OUC:"!S:2!M]+YE=&4@=GEB<F&[(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(T.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N
M=6%T=2(*;7-G<W1R(")686YU871U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(S,PIM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B4')E;65N
M;N$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0U(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$U"FUS9VED(")696YE>G5E;&$B"FUS9W-T<B`B5F5N97IU96QA(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF
M:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T
M86UP97)E9"!W:71H+B(*;7-G<W1R(")/=F5R96YI92!Z;'EH86QO("T@=.%T
M;R!S<'+A=F$@;6]H;&$@8GF[('-F86RY;W9A;N$N(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HW,#$*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`B
M5F5R>FEA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R.`IM<V=I
M9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(DUA;F&^;65N="!V97)Z:>TB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@S"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G<W1R(")697)T:6OA
M;&YE('IA<F]V;F%N:64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S
M='(@(E9E<G1I:^%L;F4@=GEP;&YE;FEE(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM
M<V=S='(@(E9E<G1I:^%L;F4Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-S`*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R(")6
M9;5M:2!V>7-O:^$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0X(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:65T($YA;2(*;7-G<W1R(")6:65T
M;F%M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@(E9I971N
M86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O
M0V]N=&5N=',N<&AP.CDV.0HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S
M(@IM<V=S='(@(EIO8G)A>FF[("5S(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP
M:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*;7-G<W1R
M("):;V)R87IINR!E>'1E<F[Z('=W=R!S='+A;FMU(@H*(SH@;&EB+TAO<F1E
M+TU)344O0V]N=&5N=',N<&AP.C@R.`HC+"!P:'`M9F]R;6%T"FUS9VED(")6
M:65W(&%S("5S(@IM<V=S='(@(EIO8G)A>FF[(&%K;R`E<R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR-#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(T,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@
M(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM<V=S='(@(D)R:71S:^D@4&%N
M96YS:^D@;W-T<F]V>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#<@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N
M(@IM<V=S='(@(D%M97)I8VOI(%!A;F5N<VOI(&]S=')O=GDB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(P.0IM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R
M(")6:61I=&6U;F]SNR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR-3(*;7-G:60@(E9I<VEB:6QI='DZ("(*;7-G<W1R(")6:61I=&6U;F]S
MNSH@(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX
M-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B5F]D
M869O;F4@271A;'D@8V5Z(%--5%`B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T
M<B`B5D%23U9!3DE%(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-225!4
M($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(E503UI/4DY%3DE%(2$A($]$
M4U12P=)412!32U))4%0@6B`E<R!25<A.12XB"@HC.B!L:6(O3F5T+U--4R]W
M:6Y?:'1T<"YP:'`Z,3,S"FUS9VED(")724X@=FEA($A45%`B"FUS9W-T<B`B
M5TE.(&-E>B!(5%10(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS
M9W-T<B`B5V%L;&ES(&$@1G5T=6YA(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]H=&UL+G!H<#HQ,C0@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@S
M"FUS9VED(")787)N:6YG(@IM<V=S='(@(E9A<F]V86YI92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E
M(@IM<V=S='(@(E-T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Y"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM<V=S='(@(E!R961P;W9E
M[R!P;^AA<VEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q
M-@IM<V=I9"`B5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(MID
M86IE(&\@<&_H87/M('!O<VMY='5J92(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HX.38*;7-G:60@(E=E871H97(N8V]M(@IM<V=S='(@(E=E871H97(N8V]M
M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G
M<W1R(")796(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Y"FUS
M9VED(")796(@4VET92(*;7-G<W1R(")75U<@<W1RX6YK82(*"B,Z(&QI8B](
M;W)D92]-86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R
M(")4_;YD96YN92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X
M"FUS9VED(")796QC;VUE(@IM<V=S='(@(E9I=&%J=&4B"@HC.B!T96UP;&%T
M97,O;&]G:6XO;6]B:6QE+FEN8SHT('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G
M<W1R(")6[71A(%;A<R`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N
M<&AP.C(Y('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")796QC;VUE+"`E<R(*;7-G<W1R(")6:71A:G1E+"`E<R(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ"FUS9VED(")797-T97)N("A)
M4T\M.#@U.2TQ*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$Y,@IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,34I(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW."!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q
M"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R("):X7!A9&[A(%-A:&%R
M82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A
M9G1E<B!L;V=I;C\B"FUS9W-T<B`B2W1O<OH@87!L:6OA8VEU(&WA("5S('IO
M8G)A>FF[('!O('!R:6ALX7-E;NT_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z,30*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R
M86-T97(_(@IM<V=S='(@(D%K_2!J92!Z;F%K('!R92!O9&1EM6]V8>@_(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@
M:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`B06O](&IE('IN86L@
M<')E(/IV;V1Z;W9K=3\B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3`V,0IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P(@IM
M<V=S='(@(DUA<&$@075S='+A;&EE('!R92!S;'6^8G4@5VAE<F5I<R(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM
M<V=S='(@(DMT;W+I(&;A>GDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3,V"FUS9VED(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I
M8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@(DMT;W+I('KA<W5V;ND@;6]D=6QY
M('!O=F]L:;L@<')E(')O>KGM<F5N_2!T97AT;W;](&5D:71O<BXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T
M"FUS9VED(")7:61T:"(*;7-G<W1R("*I[7)K82(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HS,3$T"FUS9VED(")7:61T:"!I;B!#4U,@=6YI=',B"FUS9W-T
M<B`BJ>UR:V$@=B!J961N;W1KX6-H($-34R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE
M("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO
M9RUI;BDZ(@IM<V=S='(@(JGM<FMA(&UE;G4@)7,@=K5A=F\@*'!R96IA=NT@
M<V$@<')I(.]A;+EO;2!P<FEH;.%S96[M*3HB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@
M=&AE('1A8FQE(@IM<V=S='(@(JGM<FMA('1A8G6U:WDB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`IM<V=I9"`B5VED
M=&@@=6YI="(*;7-G<W1R(")*961N;W1K82"Y[7)K>2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED(")7:61T
M:#HB"FUS9W-T<B`BJ>UR:V$Z(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C4Q-0IM<V=I9"`B5VEK:2(*;7-G<W1R(")7:6MI(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(X.2!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B5VEN9"(*;7-G<W1R(")6:65T
M;W(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M-@IM<V=I9"`B5VEN9"!%87)L>2(*;7-G<W1R(")2X6YO('9I971O<B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z.#`*;7-G:60@(E=I;F0@<W!E960@:6X@
M:VYO=',B"FUS9W-T<B`B4OUC:&QO<[L@=F5T<F$@=B!U>FQO8V@B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$U-@IM<V=I9"`B5VEN9#HB"FUS9W-T<B`B
M5FEE=&]R.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*
M;7-G:60@(E=I;F0Z("(*;7-G<W1R(")6:65T;W(Z("(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M(@IM<V=S='(@(DWZ9')O
M<[LB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DX"FUS9VED(")7
M:7-H;&ES="(*;7-G<W1R(")7:7-H;&ES="(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R(")0<N%C82(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B
M"FUS9W-T<B`B061R97-A(&1O('!RX6-E(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T
M<B`B5&5L96;S;B!D;R!P<N%C92(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z,3DS
M(&QI8B]&:6QE+T-35BYP:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G:60@(E=R
M;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L
M(&9O=6YD("5D+B(*;7-G<W1R(").97-P<N%V;GD@<&_H970@<&]L[2!N82!R
M:6%D:W4@)60N($_H86OA=F$@<V$@)60L(&YAN6QO('-A("5D+B(*"B,Z(&QI
M8B]&:6QE+T-35BYP:'`Z,S,R"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG
M(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS
M9W-T<B`B3F5S<'+A=FYY('!OZ&5T('!O;.TN($_H86OA=F$@<V$@)60L(&YA
MN6QO('-A("5D+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3$X"B,L('!H<"UF
M;W)M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@
M5D93(&9I;&4N(@IM<V=S='(@(EIL_2!O9F9S970@)60@<')I(.CM=&%N[2!6
M1E,@<_IB;W)U+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#4*
M;7-G:60@(E@M4F5F(@IM<V=S='(@(E@M4F5F(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!"87-I8R!#;VYS=')A
M:6YT<R(*;7-G<W1R("):X6ML861NZ2!O8FUE9'IE;FEA(%@U,#EV,R(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@
M17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(E!O=;YI=&EE(')O>KGM<F5N
MZ6AO(&NU^NAA(%@U,#EV,R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE
M(@IM<V=S='(@(D%L=&5R;F%T[79N92!M96YO('-U8FIE:W1U(%@U,#EV,R(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")8-3`Y
M=C,@4W5B:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R("))9&5N=&EF:6OA
M=&]R(&NU^NAA('-U8FIE:W1U(%@U,#EV,R(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-C@S"FUS9VED(")8-3`Y=C,@97AT96YS:6]N<R(*;7-G
M<W1R(")8-3`Y=C,@<F]ZN>UR96YI82(*"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C4P"FUS9VED(")962(*;7-G<W1R(")962(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,3$@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0U,PIM<V=I9"`B65E962(*;7-G<W1R(")965E9(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,#@*;7-G
M:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B66%H;V\A(&UA<"(*"B,Z(&QI8B](
M;W)D92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G<W1R
M(")2;^AN92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3(@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3<*;7-G:60@(EEE;65N(@IM<V=S='(@(DIE;65N(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV,PIM<V=I9"`B
M665S(@IM<V=S='(@(D%N;R(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M
M86EN=&5N86YC92YH=&UL.C4V"FUS9VED(")997,L($D@06=R964B"FUS9W-T
M<B`B4_IH;&%S[6TN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I;B!415A4($U/1$4N("!5
M<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N
M(@IM<V=S='(@(B(*(E-T92!V(%1%6%1/5D]-(%)%KDE-12X@4&]UOFET92!T
M;&'H:61L;R!;/#Y=(&YA('!R97!N=71I92!N87-PY+L@9&\@5UE325=91RXB
M"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z.#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T
M:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`B3F5M]+YE=&4@=GET=F]R:;L@=FEA
M8R!A:V\@)60@8FQO:V]V+B(*"B,Z(&QI8B](;W)D92YP:'`Z,30Q-0IM<V=I
M9"`B66]U(&%R92!N;W0@875T:&5N=&EC871E9"XB"FUS9W-T<B`B3FEE('-T
M92!A=71E;G1I9FEK;W9A;OTN(@H*(SH@;&EB+TAO<F1E+TED96YT:71Y+G!H
M<#HS,#<*;7-G:60@(EEO=2!C86YN;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T
M97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(E9O(%9AN6]M('!L;F]M
M(&UE;F4@;F5M]+YE=&4@<&]UOFF[('IN86L@)UQ<)RXB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3@U.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DW.0IM<V=I
M9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+B(*
M;7-G<W1R(").97IA9&%L:2!S=&4@<&QA=&[Z(&4M;6%I;&]V^B!A9')E<W4N
M(@H*(SH@;&EB+TAO<F1E+T1A=&$N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM
M<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*(FEN
M("5S+B(*;7-G<W1R("(B"B).975RZ&EL:2!S=&4@=GJ[86@@;65D>FD@OFEA
M9&YY;6D@<&]L:6%M:2!Z(&EM<&]R=&]V86[I:&\@<_IB;W)U(&$@(@HB>F]D
M<&]V961A:OIC:6UI('!OM6%M:2!V("5S+B(*"B,Z(&QI8B](;W)D92]!=71H
M+G!H<#HY.#0*;7-G:60@(EEO=2!H879E(&)E96X@;&]G9V5D(&]U="XB"FUS
M9W-T<B`B0F]L:2!S=&4@;V1H;.%S96[]+B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,C8U"FUS9VED("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED
M(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N
M86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I
M>"XB"FUS9W-T<B`B(@HB375S[71E('IA9&&[('!L871NZ2#H[7-L;R!M;V)I
M;&[I:&\@=&5L96;S;G4L(&MT;W+I(&]B<V%H=6IE(&EB82#H[7-L82!S("(*
M(G9O;&ET9;5N_6T@<')E9FEX;VT@)RLG('!R92!M961Z:6[A<F]D;OT@9F]R
M;>%T+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3DR"FUS9VED(")9;W4@
M:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R(")-=7/M=&4@
M>F%D8;L@<&QA=&[Z(&AO9&YO='4N(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG
M;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R
M964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B(@HB06)Y('-T
M92!M;VAL:2!P;W6^[79ANR!296=I<W1RX6-I92P@;75S[71E(&YA:G-K]'(@
M;F%K;VYF:6=U<F]V8;L@1&%T851R964@(@HB8F%C:V5N9"XB"@HC.B!L:6(O
M2&]R9&4N<&AP.C0V,@IM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93
M(&)A8VME;F0N(@IM<V=S='(@(DUU<^UT92!N86MO;F9I9W5R;W9ANR!61E,@
M8F%C:V5N9"XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ
M,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E
M('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@(DUU
M<^UT92!P;W#M<V&[('!R;V)LZ6T@<')E9'3];2P@86MO(&]D;[EL971E('-P
M<N%V=2!O('!R;V)LZ6UE+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H92!5
M4DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*;7-G<W1R(")-=7/M=&4@
M>F%D8;L@55),(&%D<F5S=2P@;F$@:W1O<OH@=.%T;R!L:6YK82!U:V%Z=6IE
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*;7-G:60@(EEO
M=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"XB"FUS9W-T
M<B`B375S[71E('9Y8G)ANR!S97)V97(L(&MT;W+](&WA(&)YNR!V>6UA>F%N
M_2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*;7-G:60@(EEO=2!M=7-T('-P
M96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@(DUU<^UT
M92!U<NAINR!M96YO('!O=;[M=F%T9;5A+"!K=&]RZ6AO(&-H8V5T92!V>6UA
M>F&[+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B375S[71E
M('5RZ&F[(&UE;F\@<&]UONUV871EM6$L(&MT;W+I:&\@8VAC971E('9Y;6%Z
M8;LN(@H*(SH@861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHX"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U
M<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@(DUU<^UT92!U<NAINR!M96YO('!O
M=;[M=F%T9;5A+"!K=&]RZ6AO(&-H8V5T92!P<FED8;LN(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,30V"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R
M;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@(DUU<^UT92!U<NAINR!P;W6^[79A
M=&6U82P@:W1O<OT@<V$@;>$@86MT=6%L:7IO=F&[+B(*"B,Z(&QI8B](;W)D
M92]#;VUP<F5S<R]Z:7`N<&AP.C$S.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF
M>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R(")-=7/M=&4@=7+H
M:;L@86MC:74L(&MT;W+A('-A(&WA('9Y:V]N8;LN(@H*(SH@;&EB+TAO<F1E
M+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*;7-G:60@(EEO=2!M=7-T
M('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T<B`B375S[71E('IA
M9&&[(&UE;F\@;F]V96H@:V%T96?S<FEE+B(*"B,Z(&QI8B].970O4TU3+W9O
M9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D('1O('!R
M;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B375S[71E
M('IA9&&[('1A;&EA;G-K92!T96QE9O-N;F4@Z.US;&\B"@HC.B!L:6(O2&]R
M9&4O075T:"YP:'`Z.3<R"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@)7,@
M<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G
M<W1R("(B"B)0;&%T;F]SNR!68;EE:B!R96SA8VEE('!R92!A<&QI:^%C:74@
M)7,@=GEP<KEA;&$N(%!R;W/M;2!P<FEH;.%S=&4@<V$@>FYO=G4N(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*;7-G:60@(EEO=7(@
M16UA:6P@061D<F5S<R(*;7-G<W1R(")68;EA($5M86EL;W;A(&%D<F5S82(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,34*;7-G:60@(EEO=7(@1G)O
M;3H@861D<F5S<SHB"FUS9W-T<B`B5F&Y82!%;6%I;&]VX2!A9')E<V$@<&]U
MOFETX2!P<F4@;V1C:.%D>F%J^F-U('!ON71U.B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S<@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C@U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M,@IM<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R(")68;EE(&EN9F]R
M;>%C:64B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3<V"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E
M9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@
M(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I
M;BXB"FUS9W-T<B`B(@HB5F&Y82!I;G1E<FYE=&]VX2!A9')E<V$@<V$@>FUE
M;FEL82!O9"!Z8>AI871K=2!68;EE:B!R96SA8VEE("5S+B!0<F4@5F&Y=2`B
M"B)B97IP9>AN;W.[('-A(&UU<^UT92!Z;F]V=2!P<FEH;.%S:;LN(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*;7-G:60@(EEO=7(@
M3F%M92(*;7-G<W1R(")68;EE(&UE;F\B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]N;V%D9"YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO
M;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y
M;W4@=VES:"!T;R`B"B)U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C
M8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@(@HB875T:&5N=&EC
M871I;VX@8F%C:V5N9"XB"FUS9W-T<B`B(@HB5N&Y(&%U=&5N=&EF:6MAZ&[]
M(&UO9'5L(&YE<&]D<&]R=6IE('!R:63A=F%N:64@<&]UONUV871EM6]V+B!!
M:R!S:2"^96SA=&4@(@HB<&]UOFF[($AO<F1E(&YA('-P<N%V=2!P;W6^[79A
M=&6U<VO]8V@@^NAT;W8L(&UU<^UT92!P;W6^:;L@:6[]("(*(F%U=&5N=&EF
M:6MAZ&[](&)A8VME;F0N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L
M:7-T+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME
M;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A
M='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S
M;VXN(@IM<V=S='(@(B(*(E;AN2!A=71E;G1I9FEK8>AN_2!M;V1U;"!N97!O
M9'!O<G5J92!Z;V)R87IO=F%N:64@>F]Z;F%M=2!P;W6^[79A=&6U;W8L("(*
M(F%L96)O(&)O;&$@=.%T;R!M;[YN;W.[('H@;F5J86OI:&\@9/1V;V1U('IA
M:^%Z86[A+B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY.#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C
M:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N
M+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN
M(&%G86EN+B(*;7-G<W1R("(B"B):9.$@<V$L(+YE(%;AN2!P<F5H;&EA9&'H
M('-A('IM96YI;"!O9"!Z8>AI871K=2!68;EE:B!R96SA8VEE("5S+B!0<F4@
M5F&Y=2`B"B)B97IP9>AN;W.[('-A(&UU<^UT92!Z;F]V=2!P<FEH;.%S:;LN
M(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-34*;7-G:60@(EEO=7(@8G)O
M=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`B
M5N&Y('!R96AL:6%D8>@@;F5P;V1P;W)U:F4@=/IT;R!F=6YK8VEU+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"FUS9VED("(B"B)9
M;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO
M;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN="XB"FUS
M9W-T<B`B(@HB5N&Y('!R96AL:6%D8>@@;F5P;V1P;W)U:F4@=/IT;R!F=6YK
M8VEU('1L8>AE+B!3=&QAZ'1E($-O;G1R;VPO0V]M;6%N9"`K(%`@(@HB<')E
M('1L8>@N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V,0IM<V=I9"`B
M66]U<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`B5F&Y82!A:W1UX6QN
M82#H87-O=N$@>O-N83HB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.3@*;7-G
M:60@(EEO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*
M;7-G<W1R(")68;EA('!R961N87-T879E;N$@:61E;G1I=&$@8F]L82!Z;65N
M96[A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-C$*;7-G:60@(EEO
M=7(@9&5F875L="!I9&5N=&ET>3HB"FUS9W-T<B`B4')E9&YA<W1A=F5NX2!I
M9&5N=&ET83HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`T"FUS9VED
M(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`B5F&Y92!M96YO.B(*"B,Z(&QI
M8B](;W)D92]!=71H+G!H<#HY.38*;7-G:60@(EEO=7(@;&]G:6X@:&%S(&5X
M<&ER960N(@IM<V=S='(@(E!L871N;W.[(%;AN6AO(/KH='4@=GEP<KEA;&$N
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*
M;7-G<W1R(")68;EE(&YO=ND@:&5S;&\@<')E("5S(&IE.B`E<R(*"B,Z(&QI
M8B](;W)D92]0<F5F<R]522YP:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO;G,@
M:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E
M<W-I;VXN(@IM<V=S='(@(E9AN64@;F%S=&%V96YI82!B;VQI(&%K='5A;&EZ
M;W9A;ND@<')E('1O=&\@<V5D96YI92XB"@HC.B!L:6(O2&]R9&4O4')E9G,O
M54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A
M=&5D+B(*;7-G<W1R(")68;EE(&YA<W1A=F5N:6$@8F]L:2!A:W1U86QI>F]V
M86[I+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED
M(")9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T(@IM<V=S='(@(E9AN64@
M:&5S;&\@8F]L;R!O8FYO=F5NZ2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B965N(')E
M<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE
M=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@HB5F&Y92!H97-L;R!B;VQO(&]B
M;F]V96[I+"!S:V]N=')O;'5J=&4@<VD@<&^Y='4@82!P<FEH;.%S=&4@<V$@
M<R!68;GM;2!N;W;];2`B"B)H97-L;VTN(@H*(SH@;&EB+TAO<F1E+T%U=&@N
M<&AP.C<S,`IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"XB"FUS
M9W-T<B`B4&QA=&YO<[L@5N&Y:&\@:&5S;&$@=GEP<KEA;&$N(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9;W5R(')E;6]T
M92!S97)V97)S.B(*;7-G<W1R(")68;EE('9Z9&EA;&5NZ2!S97)V97)Y.B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-30@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S='(@(DIU:&]S
M;.%V:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@
M(EIA:7)E(@IM<V=S='(@(EIA:7(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C4V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS9W-T
M<B`B6F%M8FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T<B`B6FEM8F%B
M=V4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G:60@(EII<'!Y
M(@IM<V=S='(@(EII<'!Y(@H*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VAI
M9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB
M"FUS9W-T<B`B6U-K<GF[(&-I=&]V86[]('1E>'1=(@H*(SH@<V5R=FEC97,O
M<')O8FQE;2YP:'`Z.#D*;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T
M<B`B6U-P<N%V82!O('!R;V)LZ6UE72(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(");4VAO=R!1=6]T960@5&5X
M="`M(@IM<V=S='(@(EM:;V)R87IINR!C:71O=F%N_2!T97AT("TB"@HC.B!L
M:6(O2&]R9&4O5&5X="]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L
M:6YE<UTB"FUS9W-T<B`B6UIO8G)A>FF[(&-I=&]V86[]('1E>'0@+2`E<R!R
M:6%D:V]V72(*"B,Z(&QI8B](;W)D92YP:'`Z,3DU"B,L('!H<"UF;W)M870*
M;7-G:60@(EML:6YE("5S(&]F("5S72(*;7-G<W1R(");<FEA9&]K("5S('H@
M)7-=(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-30U('1E;7!L871E<R]P;W)T86PO
M;65N=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R(")?
M061M:6YI<W1RX6-I82(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I9"`B7T-,
M22(*;7-G<W1R(")?0TQ)(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS9VED(")?
M1&%T851R964B"FUS9W-T<B`B7T1A=&%4<F5E(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED(")?
M1&5L971E(%)O=R(*;7-G<W1R(")?5GEM87IANR!R:6%D;VLB"@HC.B!L:6(O
M87!I+G!H<#HQ,S,*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B7U-K=7!I;GDB
M"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,3<U"FUS9VED(")?2&5L<"(*;7-G
M<W1R(")?4&]M;V-N[6LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P97)T
M:65S+BXN(@IM<V=S='(@(E9L87-T;F]S=&D@7V]B<N%Z:W4N+BXB"@HC.B!L
M:6(O2&]R9&4O365N=2YP:'`Z,3DT"FUS9VED(")?3&]G(&EN(@IM<V=S='(@
M(E]0<FEH;.%S:;L@<V$B"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,3DP"FUS
M9VED(")?3&]G(&]U="(*;7-G<W1R(")?3V1H;.%S:;L@<V$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*
M;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R(")?57!R879INR!L:6YK
M=2XN+B(*"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ-C0*;7-G:60@(E]/<'1I
M;VYS(@IM<V=S='(@(E].87-T879E;FEA(@H*(SH@;&EB+V%P:2YP:'`Z,3,W
M"FUS9VED(")?4&5R;6ES<VEO;G,B"FUS9W-T<B`B7U!RX79A(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V
M"FUS9VED(")?4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`B3V1S=%]RX6YINR!L
M:6YK=2XN+B(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM
M<V=S='(@(DYA7W-T879E;FEE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED(")?5&%B;&4@4')O
M<&5R=&EE<RXN+B(*;7-G<W1R(")6;&%S=&YO<W1I(%]T86)UM6MY+BXN(@H*
M(SH@;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?57-E<G,B"FUS9W-T<B`B4&]?
M=;[M=F%T96QI82(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3(P"FUS9VED
M(")A9&1R97-S(&)O;VLB"FUS9W-T<B`B861R97/A<B(*"B,Z(&QI8B](;W)D
M92]-24U%+TUE<W-A9V4N<&AP.C$S-`IM<V=I9"`B861D<F5S<V5E('5N:VYO
M=VXB"FUS9W-T<B`B861R97/A="!N97INX6UY(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HY,3(*;7-G:60@(F-A;&5N9&%R(@IM<V=S='(@(FMA;&5N9.%R
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R(")B
M97IV971R:64B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-3@*
M;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B;F5P
M;V1A<FEL;R!S82!V>71V;W)INR!V_7-T=7!N_2!S^F)O<B(*"B,Z(&QI8B](
M;W)D92]-24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P96X@
M:6YP=70B"FUS9W-T<B`B;F5P;V1A<FEL;R!S82!O='9O<FF[('9S='5P(@H*
M(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C4Y.0IM<V=I9"`B8VQI
M8VL@:&5R92(*;7-G<W1R(")K;&EK;FET92!S96TB"@HC.B!L:6(O2&]R9&4O
M34E-12]-97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G
M92!E<G)O<B(*;7-G<W1R(")C:'EB82!P<FD@<&]UOFET[2!P<NUK87IO=NEH
M;R!R:6%D:W4B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-S@*
M;7-G:60@(F-O;F9I9W5R871I;VX@97)R;W(B"FUS9W-T<B`B8VAY8F$@:V]N
M9FEG=7+A8VEE(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,34T
M"FUS9VED(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@
M(F-H_6)A(&3T;&6^:73]('-Y<W3I;6]V_2!S^F)O<B(*"B,Z(&QI8B](;W)D
M92]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M870@97)R
M;W(B"FUS9W-T<B`B8VAY8F$@9F]R;>%T=2#Z9&%J;W8B"@HC.B!L:6(O2&]R
M9&4O34E-12]-97-S86=E+G!H<#HQ.#(*;7-G:60@(F5N=')Y(&YO="!F;W5N
M9"(*;7-G<W1R(")P;VQOOFMA(&YE;N%J9&5NX2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")F86QL:6YG(@IM
M<V=S='(@(FML97/A(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.C@X,0IM
M<V=I9"`B9FEL92(*;7-G<W1R(")S^F)O<B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3<T(&QI8B]";&]C:R]M971A<BYP:'`Z,S8P(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S@V"B,L('!H<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S
M("@E<RD@870@)7,@)7,B"FUS9W-T<B`B>F\@<VUE<G4@)7,@*"5S*2!R_6-H
M;&]SNV]U("5S("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(S.0IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R(")NX7)A>F]V_2(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR-#@*;7-G:60@(F@Z
M(@IM<V=S='(@(G8Z(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C,U-PIM<V=I9"`B:&@B"FUS9W-T<B`B:&@B"@HC.B!L:6(O2&]R
M9&4O34E-12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@;F%M92!U;FMN
M;W=N(@IM<V=S='(@(FYE>F[A;64@;65N;R!H;W-T:71EM6$B"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T
M<B`B;VMA;;YI=&4B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI
M;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B:6YL:6YE(@IM<V=S='(@(G8@
M<W!RX79E(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,38R"FUS
M9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`B8VAY8F$@=G-T=7!U
M+W;]<W1U<'4B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-#8*
M;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(FEN=&5R
M;N$@8VAY8F$@<V]F=';I<G4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q
M=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B;&EN97-=(@IM<V=S='(@(G)I861K
M;W9=(@H*(SH@;&EB+U9&4R])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE
M(&UA:VEN9R!)4T\N(@IM<V=S='(@(G!OZ&%S('9Y=';A<F%N:6$@25-/(&YA
M<W1A;&$@8VAY8F$@;6MI<V]F<R`E9"(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HS-C@*;7-G:60@(FUM(@IM<V=S='(@(FUM(@H*
M(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HR.3$@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C$W,`HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP
M:'`Z,C,R"FUS9VED(")N86UE(@IM<V=S='(@(FUE;F\B"@HC.B!L:6(O2&]R
M9&4O4E!#+G!H<#HQ,C0*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R
M(")N96EM<&QE;65N=&]V86[I(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HQ,C(P"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@
M(GIA=&EAM2!N96EM<&QE;65N=&]V86[I(@H*(SH@;&EB+TAO<F1E+TMO;&%B
M+G!H<#HY,#0*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B<&]Z;N%M:V]V_2!B
M;&]K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R(")P97)C96YT(@H*
M(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3<T"FUS9VED(")P97)M
M:7-S:6]N(&1E;FEE9"(*;7-G<W1R(")P<NUS='5P('IA;6EE=&YU=/TB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@Y"FUS9VED(")P:7AE;',B"FUS9W-T<B`B8F]D;W8B"@HC.B!L:6(O2&]R
M9&4O34E-12]-97-S86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I
M;B!P<F]T;V-O;"(*;7-G<W1R(")V>F1I86QE;N$@8VAY8F$@=B!P<F]T;VMO
M;&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW
M,PIM<V=I9"`B<FES:6YG(@IM<V=S='(@(G-T^G!A(@H*(SH@;&EB+TAO<F1E
M+TU)344O365S<V%G92YP:'`Z,30R"FUS9VED(")S97)V:6-E('5N879A:6QA
M8FQE(@IM<V=S='(@(G-L=;YB82!N:64@:F4@9&]S='5P;N$B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.CDY"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S
M(@IM<V=S='(@(GIO8G)A>FF[(')O>F1I96QY(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(
M5%10(@IM<V=S='(@(G-M<S)E;6%I;"!C97H@2%144"(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HS.#0*;7-G:60@(G-S(@IM<V=S
M='(@(G-S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-S(*;7-G:60@(G-T96%D>2(*;7-G<W1R(")U<W3A;&5N_2(*"B,Z(&QI
M8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R
M<F]R(@IM<V=S='(@(G-Y<W3I;6]VX2!C:'EB82(*"B,Z(&QI8B](;W)D92]+
M;VQA8BYP:'`Z.3(X"FUS9VED(")T87-K(&QI<W0B"FUS9W-T<B`B>F]Z;F%M
M(/IL;V@B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-C8*;7-G
M:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(F1OZ&%S;N$@8VAY8F$B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!L:6(O2&]R9&4O075T:"]3:6=N=7`N
M<&AP.C(W,`IM<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N
M9FER;2(*;7-G<W1R(")P<F4@<&]T=G)D96YI92!Z861A:G1E(&AE<VQO(&1V
M86MRX70B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U
M<"]D:69F+G!H<#HW.0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R(")U;FEF:6MO
M=F%NZ2(*"B,Z(&QI8B](;W)D92]-24U%+U!A<G0N<&AP.C(W"FUS9VED(")U
M;FYA;65D(@IM<V=S='(@(FYE<&]M96YO=F%NX2(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR,C,*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S='(@(F1E
M9FEN=6IE('!O=;[M=F%T9;4B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR-#`*;7-G:60@
M(G<Z(@IM<V=S='(@(KDZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C8*;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(G=E871H97(N8V]M
M(@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R\N:'1A8V-E<W,`
M````````````````````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`P,38@,3`U,34T,S,W-#(@,#$W-S4P`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````$1E;GD@9G)O;2!A;&P*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O;'1?3%0N<&\`````````````````
M````````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P-S(Q-S<V(#$P
M-3$U-#,S-S0R(#`Q-S4U-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````C($QI=&AU86YI86X@=')A;G-L871I;VYS(&9O<B!(
M;W)D92!P86-K86=E+@HC($-O<'ER:6=H="`H0RD@,C`P-"!(;W)D92!0<F]J
M96-T"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE
M(&QI8V5N<V4@87,@=&AE($AO<F1E('!A8VMA9V4N"B,@1&%R:75S($UA='5L
M:6%U<VMA<R`\9&%R:75S0&QN:RYL=#XL(#(P,#(N"B,@5FEL:75S(%-U;7-K
M87,@/'9I;&EU<T!L;FLN;'0^+"`R,#`S+"`R,#`T+@HC"FUS9VED("(B"FUS
M9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C`M8W9S7&XB
M"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN
M(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN
M(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P-"TQ,2TR.2`Q,CHU,BLP,C`P7&XB
M"B),87-T+51R86YS;&%T;W(Z(%9I;&EU<R!3=6US:V%S(#QV:6QI=7-`;&YK
M+FQT/EQN(@HB3&%N9W5A9V4M5&5A;3H@3&ET:'5A;FEA;B`\=FEL:75S0&QN
M:RYL=#Y<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z
M('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,3-<;B(*(D-O;G1E;G0M
M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(S-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES
M(&%G;RDB"FUS9W-T<B`B("AP<FEE\"`E<R!D:65N87,I(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ,S<P"B,L('!H<"UF;W)M870*;7-G:60@
M(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(@*&UY9W1U:V%S("5S*2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S<*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B("AP<FEE\"`E
M<R!D:65N87,I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,PIM
M<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B("CP:6%N9&EE;BDB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<U"B,L(&9U>GIY"FUS9VED("(@*'1O
M;6]R<F]W*2(*;7-G<W1R(")2>71O:B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S-S$*;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(@*'9A
M:V%R*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-38@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,0HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-#`W"FUS9VED("(@870@(@IM<V=S='(@(B`B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Q-0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB"FUS
M9W-T<B`B3F4@:V%T86QO9V%S(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP
M.C(W,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO
M="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B)R5S)R!Y<F$@;F5L96ES=&EN
M82!R96EK\&WK+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R
M>2YP:'`Z-C4Y"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP
M:'`Z,3`T,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES
M(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T
M<B`B)R5S)R!N97-U:V]N9FEG^W)U;W1A<R!(;W)D92!R96=I<W1R92XB"@HC
M.B!F<F%M97=O<FLO5')E92]4<F5E+G!H<#HQ-S$*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB
M"FUS9W-T<B`B3NMR82`G)7,G(&UE9/YI;R!G96YE<F%T;W)I875S+B(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z-38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM
M<V=S='(@(D=R=7#K("<E<R<@<W5K=7)T82XB"@HC.B!A9&UI;B]P97)M<R]A
M9&1C:&EL9"YP:'`Z-3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB
M)7-<(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS
M9W-T<B`B5&5I<^L@)R5S)R!S=6MU<G1A+B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z-30@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB
M"FUS9W-T<B`B)R5S)R!N96)U=F\@<W5K=7)T83H@)7,N(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-
M0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S='(@(B5D("5S(&ER("5S
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HR-C@@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C4U-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!D
M87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B"FUS9W-T<B`B)60M9&EE;O@@
M<')O9VYO>NLB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B)7,@+2!P
M87-T86)A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW
M,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T
M<B`B)7,@86YT<W!A=61A<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C@S,R!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HX,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B)7,@
M2T(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I
M<FUA=&EO;B(*;7-G<W1R("(E<R!P<F]F:6QA:W1I:V]S('9E:6MS;6%I("T@
M<&%T=FER=&EN:6UA<R(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q-0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B7TMO;F9I9_MR86-I:F$B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8S"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B)7,@<F5G:7-T<F%C
M:6IA(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4Y"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*;7-G<W1R("(E
M<R!N=6]S=&%T;W,B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0R
M."!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y,`HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C8U,2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB
M"FUS9W-T<B`B)7,@:F%U(&5G>FES='5O:F$N(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ-3D@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C4@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,SD*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#4@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M870@)7,@)7,B"FUS9W-T<B`B)7,@)7,@)7,B"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z-#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*
M(B5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY
M(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM
M92XB"FUS9W-T<B`B4&'^>6WK:VET92P@:W5R:6%S(&]P97)A8VEJ87,@;F]R
M:71E(&%T;&EK=&DN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,T
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R
M("(E<R!Y<F$@<')I=F%L;VUA<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C@V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&UI;G5T97,B"FUS9W-T<B`B
M)7,@;6EN=73K<R(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T
M:6]N+G!H<#HQ,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD
M+B(*;7-G<W1R("(E<R!N97)A<W1A<RXB"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]L:7-T+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S
M(&]F("5S(@IM<V=S='(@(FYU;R`E<R!I:VD@)7,@:?`@)7,B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR,@HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R("(E<R!A9')E<_@@:VYY9V5L
MZR(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$T"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B)7,@:V%L96YD
M;W)I=7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B)7,@=?YR
M8?#X(&MN>6=E;.LB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@
M(B5S(&1A<F+X('/@<F'P87,B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(E<SH@)7,B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR-S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R
M;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@
M(@HB86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R
M('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8U(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HT,3`*(RP@9G5Z>GD*;7-G:60@(BP@9W5S=&EN
M9R`B"FUS9W-T<B`B+"!G^W-I86D@)7,@)7,B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$X."!L:6(O0FQO8VLO;65T87(N<&AP.C$Y,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(L(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B+"!G^W-I86D@
M)7,@)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P,0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B
M+"!K:6YT82!N=6\@)7,@:6MI("5S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HR.30@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS
M-#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`V.2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,3(X"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HW-#D*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R
M("(M+2!P87-I<FEN:VET92`M+2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR
M,`IM<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS9W-T<B`B,3(@=F%L86YD^"!F
M;W)M871A<R(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ.0IM<V=I9"`B,C0@
M2&]U<B!&;W)M870B"FUS9W-T<B`B,C0@=F%L86YD^"!F;W)M871A<R(*"B,Z
M('1E;7!L871E<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*
M;7-G<W1R("(R-"!V86QA;F1O<R(*"B,Z(&9R86UE=V]R:R]522]522]086=E
M<BYP:'`Z-CD*(RP@9G5Z>GD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R(")!
M;FMS=&5S;FES('!U<VQA<&ES(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M,3D*;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@
M=&AI<R!B;&]C:RXB"FUS9W-T<B`BT&EA;2!B;&]K=6D@<F5I:V%L:6YG82!V
M:65T82!D=6]M96[X(&)A>NMJ92XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C$V,`IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B
M"FUS9W-T<B`BP79Y:V\@<FEM=&$@:VQA:61A(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y
M(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(").
M;W+K9&%M:2!U_FMO9'5O=&D@;&%I\&O@('!R:79A;&]T92!T=7+K=&D@=FEE
M\.!JX2!01U`@<F%K=.`N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3$V-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E
M9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@HB3F]R
MZV1A;6D@<&%T:6MR:6YT:2!P87-I<F'P>73@(&QA:?!KX"!P<FEV86QO=&4@
M='5RZW1I('9I9?#@:N$@4$=0(')A:W3@+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$P.3<*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K
M97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"B).;W+K
M9&%M:2!A=&MO9'5O=&D@;&%I\&O@('!R:79A;&]T92!T=7+K=&D@=FEE\.!J
MX2!I<B!S;&%P=.!JX2!01U`@<F%K='5S+"`B"B)B96D@_FEN;W1I('-L87!T
MX&K@(&9R87KF+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$P,34*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B
M"B)M97-S86=E+B(*;7-G<W1R("(B"B).;W+K9&%M:2!P87-I<F'P>71I(&QA
M:?!KX"!P<FEV86QO=&4@='5RZW1I('9I9?#@:N$@:7(@<VQA<'3@:N$@4$=0
M(')A:W1U<RP@(@HB8F5I(/YI;F]T:2!S;&%P=.!JX"!F<F%ZYBXB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4P-0IM<V=I9"`B(@HB
M02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A(&UE<W-A
M9V4N(@IM<V=S='(@(B(*(DYO<NMD86UI(&%T:V]D=6]T:2!L86GP:^`@<')I
M=F%L;W1E('1U<NMT:2!V:67PX&KA(&ER('-L87!TX&KA(%,O34E-12`B"B)R
M86MT=7,L(&)E:2#^:6YO=&D@<VQA<'3@:N`@9G)A>N8N(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B
M;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M97-S86=E+B(*;7-G
M<W1R("(B"B).;W+K9&%M:2!P87-I<F'P>71I(&QA:?!KX"!P<FEV86QO=&4@
M='5RZW1I('9I9?#@:N$@:7(@<VQA<'3@:N$@4R]-24U%("(*(G)A:W1U<RP@
M8F5I(/YI;F]T:2!S;&%P=.!JX"!F<F%ZYBXB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@
M:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R
M(").;W+K9&%M:2!U_FMO9'5O=&D@;&%I\&O@('!R:79A;&]T92!T=7+K=&D@
M=FEE\.!JX2!3+TU)344@<F%K=.`N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z.0HC+"!F=7IZ>0IM<V=I9"`B04T@0VQO=61S
M(@IM<V=S='(@(D1E8F5S=6]T82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$P"B,L(&9U>GIY"FUS9VED(")!32!,:6=H="!2
M86EN(@IM<V=S='(@(E!-(&QE;F=V87,@;&EE='5S(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3$*(RP@9G5Z>GD*;7-G:60@
M(D%-(%)A:6XB"FUS9W-T<B`B3&EE='5S(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS
M9W-T<B`B04T@<F]D>6UA<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$S"B,L(&9U>GIY"FUS9VED(")!32!3;F]W(%-H;W=E
M<G,B"FUS9W-T<B`B4/MG82(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC
M.C(Y"FUS9VED(")!32]032(*;7-G<W1R(")!32]032(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B
M05!)($E$(@IM<V=S='(@(D%022!)1"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@961I
M=&]R(@IM<V=S='(@(D%P:64@\.$@<F5D86MT;W)I^"(*"B,Z('-E<G9I8V5S
M+VAE;'`O:6YD97@N<&AP.C4R"FUS9VED(")!8F]U="XN+B(*;7-G<W1R(")!
M<&EE+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW-`IM<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@(E9I<VGP:V%I(&%P
M8>AI;VIE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW,@IM<V=I9"`B06)S;6ED9&QE(@IM<V=S='(@(E9I<VGP:V%I('!E
M<B!V:61U<N$B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C<P
M"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN
M(@IM<V=S='(@(E-I<W1E;6$@;F5T=7)I('1E:7-I^"!S=6MU<G1I(%9&4R!K
M871A;&]GX"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3,V
M"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G
M<W1R(")3:7-T96UA(&YE='5R:2!T96ES:?@@<W5K=7)T:2!61E,@9F%I;.`N
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C,*(RP@9G5Z>GD*;7-G:60@
M(D%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M86-I:F$@87!I
M92!*=7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4*;7-G:60@(D%C
M8V]U;G0@4&%S<W=O<F0B"FUS9W-T<B`B4VQA<'1A_F]D:7,B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*;7-G
M:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R(")3X'-K86ET82!U_O!A;&1Y
M=&$N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S,PIM<V=I9"`B
M06-C;W5N=&EN9R(*;7-G<W1R(")!<'-K86ET82(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,30X('1E;7!L871E<R]P;W)T86PO861D+FEN
M8SHQ-`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ
M,0IM<V=I9"`B061D(@IM<V=S='(@(E-U:W5R=&DB"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C(R-"!A9&UI;B]G<F]U<',N<&AP.C(R-0IM<V=I9"`B061D($-H
M:6QD($=R;W5P(@IM<V=S='(@(E-U:W5R=&D@<&]G<G5PX2(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z.3@@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HY.0IM<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB"FUS
M9W-T<B`B4W5K=7)T:2!P;W1E:7-E<R(*"B,Z('1E;7!L871E<R]P;W)T86PO
M861D+FEN8SHU"FUS9VED(")!9&0@2&5R93HB"FUS9W-T<B`B0FQO:V\@X71E
M<G!I;6%S.B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$X(&%D;6EN+V=R;W5P
M<RYP:'`Z,C$Y"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S='(@(E-U:W5R
M=&D@;F%U:N`@9W)U<.8B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C@W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#@*;7-G:60@
M(D%D9"!.97<@4&5R;6ES<VEO;B(*;7-G<W1R(")3=6MU<G1I(&YA=6IA<R!T
M96ES97,B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN
M8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!G
M<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B4&]G<G5P:6\@9W)U<&5I("<E<R<@
M<W5K^W)I;6%S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ
M-#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E
M<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@(E!O=&5I<^MS('1E:7-E:2`G
M)7,G('-U:_MR:6UA<R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED(")!
M9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B3F%U:F\@=F%R=&]T;VIO('-U:_MR
M:6UA<SHB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-34T"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S='(@(E!R:63K=&D@<W1U
M;'!E;.$B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,T
M"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`B3F%U:O@@;F%R:?@@
M<')I9.MJ:6UA<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z.34*
M;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(E-U:W5R=&D@<&]RX"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S='(@
M(E!R:63K=&D@)7,@;65N:74@<')I92!-;WII;&]S(.%R86YK:?@@:G5O<W1O
M<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW
M,0IM<V=I9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`BP71R875K
M=&D@X2!A9')E<_@@:VYY9V5LYCHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z-S@*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S
M(&)O;VLB"FUS9W-T<B`BP71R875K=&D@X2!M86YO(&%D<F5S^"!K;GEG96SF
M.B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G
M<W1R(")3=6MU<G1I('9A<G1O=&]JX"(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S7"(@
M=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S
M:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R("(B"B)687)T;W1O
M:F%S("<E<R<@<W5K=7)T87,L('1AZ&EA=2!P87!I;&1O;6$@<F5G:7-T<F%C
M:6IO<R!I;F9O<FUA8VEJ82!N96)U=F\@(@HB:?!S875G;W1A.B`E<RXB"@HC
M.B!S:6=N=7`N<&AP.C0U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!
M9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W
M+B(*;7-G<W1R(")687)T;W1O:F%S("<E<R<@<W5K=7)T87,N($=A;&ET92!P
M<FES:6IU;F=T:2XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI
M;F,Z,@IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R
M(")687)T;W1O:O@@:_MR:6UA<R!I\&IU;F=T87,N(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T-#$*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`B061R97-A
M<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,SD*;7-G:60@(D%D
M9')E<W,@0F]O:R(*;7-G<W1R(")!9')E<V%I(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30*;7-G:60@(D%D;6EN:7-T97(@
M+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S='(@(D%D
M;6EN:7-T<G5O=&D@+2!G86QI(&YU<W1A='ET:2!T96ES97,@:VET:65M<R!V
M87)T;W1O:F%M<R(*"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ.2!S97)V:6-E<R]P
M;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED(")!9&UI;FES=')A=&EO;B(*
M;7-G<W1R(")686QD>6UA<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS-#$*;7-G:60@(D%D<R(*;7-G<W1R(")"86YE<FEA:2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-38*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@(D%F9V%N:7-T86YA<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3<*;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B06QB86YI:F$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<P"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(D%L_GER87,B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W
M"FUS9VED(")!;&EA<R(*;7-G<W1R(")0<F%V87)DZR(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*;7-G:60@
M(D%L:6=N(@IM<V=S='(@(DQY9VEU;W1I(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*
M;7-G<W1R("),>6=I879I;6%S.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(E9I<V]S(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T
M<B`B5FES:2!P<FES:6IU;F?F('9A<G1O=&]J86DB"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C(R"FUS9VED(")!;&P@1W)O
M=7!S(@IM<V=S='(@(E9I<V]S(&=R=7#K<R(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+V1A=&%T
M<F5E+G!H<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(E9I
M<V]S('1E:7/K<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S
M='(@(E9I<V]S(&ME='5R:6]S('!U<^MS(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@W,0IM<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S
M(@IM<V=S='(@(DQE:7-T:2!K96QE=.`@861R97/X(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4S-`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E
M<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B3&5I<W1I(&YA=61O=&D@<W5R^_!I
M=6]TX"!SX')A\.`_(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E
M+W-Q;"YP:'`Z-3`T"FUS9VED(")!;')E861Y(&5X:7-T<R(*;7-G<W1R(")*
M874@96=Z:7-T=6]J82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C,*
M;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@(D%L=&5R;F%T
M>79U<R!)35-0('!R:7-I:G5N9VEM87,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3`W"FUS9VED(")!;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G
M<W1R(")!;'1E<FYA='EV=7,@24U34"!S;&%P=&'^;V1I<R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT.3D*;7-G:60@(D%L=&5R;F%T92!)35-0(%5S
M97)N86UE(@IM<V=S='(@(D%L=&5R;F%T>79U<R!)35-0('9A<G1O=&]J;R!V
M87)D87,B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS-0IM<V=I
M9"`B06QT97)N871E(&5M86EL(&%D9')E<W,B"FUS9W-T<B`B06QT97)N871Y
M=G5S(&5L+B!P8?!T;R!A9')E<V%S(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H
M<#HQ-#(*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`B06QT
M97)N871Y=OMS(/!A8FQO;F%I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(U"FUS9VED(")!;'1E<FYA
M=&4@=&5X=#HB"FUS9W-T<B`B06QT97)N871Y=G5S('1E:W-T87,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4X"FUS9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R(")!;65R:6MO
M<R!386UO82(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z.34@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL
M;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB"FUS9W-T<B`BP79E9.MT92!N
M96QE:7-T:6[@(')E:6OP;>8N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$V-PHC+"!F=7IZ>0IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!H
M87,@;V-C=7)E9"XB"FUS9W-T<B`BP79Y:V\@<FEM=&$@:VQA:61A(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU-0IM<V=I9"`B06YD;W)R82(*;7-G<W1R(")!;F1O<F$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B06YG;VQA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B06YG:6QA:2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U
M<R!0<F]X>2(*;7-G<W1R(")!;F]N:6UI;FES('!R;WAY('-E<G9E<FES(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E
M<B(*;7-G<W1R(")!='-A:WEM87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;G1A
M<F-T:6-A(@IM<V=S='(@(D%N=&%R:W1I9&$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED
M(")!;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S='(@(D%N=&EG=6$@:7(@0F%R
M8G5D82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO<&AP<VAE
M;&PN<&AP.C,U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3@@
M=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P
M;&EC871I;VXB"FUS9W-T<B`B36]D=6QI<R(*"B,Z('5T:6PO:6-O;E]B<F]W
M<V5R+G!H<#HT,@HC+"!F=7IZ>0IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*
M;7-G<W1R(")-;V1U;&ES(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$T
M,`IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@(DUO9'5L
M:7,@=F5I:VEA(&=E<F%I+B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B
M4')I=&%I:WET:2!I<B!P;_!A:VEA;7,B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*;7-G<W1R(")0
M871V:7)T:6YT:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C@S,PIM<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I
M9"`B07!R:6PB"FUS9W-T<B`B0F%L86YD:7,B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$W-0IM<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S
M='(@(D%R86)I\&MA("A7:6YD;W=S+3$R-38I(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C8V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#$*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S
M='(@(D%R8VAY=F\@9F%I;&\@9'ED:7,B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-C4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HX,`IM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(D%R8VAY
M=F\@9F%I;&\@<&%V861I;FEM87,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F5Q=65U960N:6YC.C$P"B,L('!H<"UF;W)M870*;7-G:60@(D%R
M92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U
M97-T(&9O<B`E<R`_(@IM<V=S='(@(D%R('1I:W)A:2!N;W)I=&4@:?!T<FEN
M=&D@)7,@<F5G:7-T<F%C:6IO<R!P<F'P>6W@/R(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O9&5L971E+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E(%PB)7-<
M(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(D%R('1I:W)A:2!N;W)I
M=&4@:?!T<FEN=&D@)R5S)R!I<B!V:7-U<R!P;V=R=7!I=7,_(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU.`IM<V=I9"`B07)G96YT:6YA(@IM<V=S='(@(D%R9V5N=&EN82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B07)MZVYI:F$B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-@IM<V=I9"`B07)M96YI86X@*$%2
M35-#24DM."DB"FUS9W-T<B`B07)MZVYI\&MA("A!4DU30TE)+3@I(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B
M365N87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!<G5B82(*;7-G<W1R(")!<G5B
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S
M8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B2W)I<W1A=7,@_F5N9VEM;R#A(&1A
M;F?X('-A;&$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G:60@
M(D%S8VEI($%R="(*;7-G<W1R(")!8W-I:2!M96YA<R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I9FEC(%)E
M9VEO;B(*;7-G<W1R(")!>FEJ82]286UI;VIO('9A;F1E;GEN;R!R96=I;VYA
M<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,C4*;7-G:60@(D%S:R!F
M;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R
M871I;VYS/R(*;7-G<W1R(")!<B!P<F'P>71I('!A='9I<G1I;G1I('!R;V9I
M;&%K=&EK;W,@=F5I:W-M=7,_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S$Q,PIM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(E!R
M:7-K>7)I;6\@<W1U;'!E;&EA:2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S0*
M;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P
M+B(*;7-G<W1R(")"86YD;W1E(&GP=')I;G1I(&YE96=Z:7-T=6]J86[H:>`@
M9W)U<.8N(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B
M071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB
M"FUS9W-T<B`B0F%N9&]T92!I\'1R:6YT:2!N965G>FES='5O:F%NZ&EA<R!T
M96ES97,N(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*;7-G:60@(D%T
M=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G
M<W1R(")"86YD;W1E(')E9&%G=6]T:2!N965G>FES='5O:F%NZ&EA<R!T96ES
M97,N(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!
M='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@
M(D)A;F1O=&4@<F5D86=U;W1I(&YE96=Z:7-T=6]J86YTX2!E;&5M96YTX"XB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8T(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-@IM<V=I9"`B071T<FEB
M=71E<R(*;7-G<W1R(")!=')I8G5T86DB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B075G=7-T(@IM<V=S='(@
M(E)U9W!J^W1I<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*;7-G
M<W1R(")!=7-T<F%L:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')I82(*
M;7-G<W1R(")!=7-T<FEJ82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M<W%L+G!H<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER<W%L.B!N
M97)A<W1A<R!R96EK86QI;F=A<R!)34%0(&UO9'5L:7,N(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED(")!=71H7V-Y<G5S
M.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N
M(@IM<V=S='(@(D%U=&A?8WER=7,Z(&-Y<G5S(&YE='5R:2!R96EK:6%M^"!G
M86QI;7EB:?@N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z
M,3(R"FUS9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER=7,Z(&YE<F%S=&%S(')E
M:6MA;&EN9V%S($E-05`@;6]D=6QI<RXB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&
M5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@
M+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B(@HB075T:%]F='`Z
M(&YE<F%S=&%S(')E:6MA;&EN9V%S($944"!M;V1U;&ES+B!3=6MO;7!I;&EU
M;VMI=&4@4$A0('-U("TM96YA8FQE+2(*(F9T<"XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VEM87`N<&AP.C8T"FUS9VED(")!=71H7VEM87`Z(%)E<75I
M<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]I
M;6%P.B!N97)A<W1A<R!R96EK86QI;F=A<R!)34%0(&UO9'5L:7,N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K
M<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(D%U=&A?:W)B-3H@;F5R87-T87,@<F5I:V%L:6YG87,@:W)B-2!M;V1U
M;&ES+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S`R"FUS
M9VED(")!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D
M(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z(%)E
M;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E
M8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HV,PIM<V=I9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;&1A<#H@;F5R87-T87,@
M<F5I:V%L:6YG87,@3$1!4"!M;V1U;&ES+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?
M;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE
M('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B075T:%]L9&%P.B!S=6MU<G1I('9A
M<G1O=&]JX"`E<R!N97!A=GEK;RX@4V5R=F5R:6\@<')A;F7P:6UA<SH@(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS.#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@
M)7,B"FUS9W-T<B`B075T:%]L9&%P.B!I\'1R:6YT:2!V87)T;W1O:N`@)7,@
M;F5P879Y:V\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0Y
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!U
M<&1A=&4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z(&%T;F%U:FEN=&D@
M=F%R=&]T;VK@("5S(&YE<&%V>6MO(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HT,#4*;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E
M<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HT-@IM
M<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(D%U=&A?;6-A;#H@;F5R87-T87,@<F5I:V%L:6YG
M87,@34-!3"!M;V1U;&ES+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB
M+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?<VUB875T:#H@
M;F5R87-T87,@<F5I:V%L:6YG87,@<VUB875T:"!M;V1U;&ES+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM
M<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S='(@(E!R:7-I:G5N
M9W1I(&YE<&%V>6MO(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T
M:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R(")0<FES:6IU;F=T:2!N
M97!A=GEK;RX@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP
M:'`Z,3<V"FUS9VED(")!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)
M55,@<V5R=F5R+B(*;7-G<W1R(")2041)55,@<V5R=F5R:7,@;F5L96ED_FEA
M(&%U=&5N=&EF:6MU;W1I<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C@U,0IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F
M86EL960N(@IM<V=S='(@(E!R:7-I:G5N9W1I('!R:64@1E10('-E<G9E<FEO
M(&YE<&%V>6MO+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-S`*
M(RP@9G5Z>GD*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R
M=F5R(&9A:6QE9"XB"FUS9W-T<B`B4')I<VEJ=6YG=&D@<')I92!&5%`@<V5R
M=F5R:6\@;F5P879Y:V\N(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN
M8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`B1V%L:6UI
M(&QA=6MA:3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S
M='(@(D%Z97)B86ED_F%N87,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S`*;7-G:60@(D)/1D@@17AC=7-E<R(*;7-G<W1R(")"3T9((&%T<VEP<F'P
M>6UA:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`B1F]N87,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(S
M"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(D9O;F\@<W!A;'9A
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B
M0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R(").971E:7-I;F=A<R!K
M97)B97)O<R!S;&%P=&'^;V1I<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM
M<V=S='(@(DYE=&5I<VEN9V%S(&ME<F)E<F]S('9A<G1O=&]J;R!V87)D87,N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F%H86UA<R(*;7-G<W1R(")"86AA;6%I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R(")"86AR96EN
M87,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-PIM<V=I9"`B0F%L=&EC
M("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B0F%L=&GP:V$@*$E33RTX.#4Y+3$S
M*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A;F=L861E<V@B"FUS9W-T<B`B0F%G
M;&%D9?!A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@
M(D)A<F)A9&]S87,B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T
M;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(DML87/K<R`E<R!NZW)A
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW,PIM<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B4&%G<BX@;&EN:6IO
M:F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QA<G5S(@IM<V=S='(@(D)A;'1A
M<G5S:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R(")"
M96QG:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L:7IE(@IM<V=S='(@(D)E
M;&EZ87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"96YI;B(*;7-G<W1R(")"96YI
M;F%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R(")"97)M
M=61A:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R(")"=71A
M;F%S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$Q,0IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B1VEM=&%D:65N:7,B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S4S"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S7"(@;V8@87!P
M;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B2VQA<^MS("5S
M(&[K<F$N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C@Y"FUS
M9VED(")";&]C:R!3971T:6YG<R(*;7-G<W1R(")";&]K;R!P87)A;65T<F%I
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")"
M;&]C:R!4>7!E(@IM<V=S='(@(D)L;VMO('1I<&%S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX"FUS9VED(")";VQD(@IM
M<V=S='(@(E!A<W1O<FEN=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")";VQI=FEA
M(@IM<V=S='(@(D)O;&EV:6IA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(P-0IM<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@(D%T_GEM;W,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(P"FUS9VED(")";W)D97(B"FUS9W-T<B`B2W)A\'1A<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O
M<F1E<B!T:&EC:VYE<W,Z(@IM<V=S='(@(DMR8?!T;R!S=&]R=6UA<SHB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(Q"FUS9VED(")";W)D97)S(@IM<V=S='(@(DMR8?!T86DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8P"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(D)O
M<VYI:F$@:7(@2&5R8V5G;W9I;F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z.38*;7-G:60@(D)O=&@B"FUS9W-T<B`B5FES;W,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S
M"FUS9VED(")";W1S=V%N82(*;7-G<W1R(")";W1S=F%N82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-0IM<V=I
M9"`B0F]T=&]M(@IM<V=S='(@(D%P8>AI;VIE(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I
M9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R(")"=79E="!S86QA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,@IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(D)R87II;&EJ82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@Q"FUS9VED(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB
M"FUS9W-T<B`B0G)I=/@@26YD:6IO<R!V86YD96YY;F\@=&5R:71O:F$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8R"FUS9VED(")"<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R(")"
M<G5NZVIA=7,@9&%R=7-A;&5M87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=6QG
M87)I82(*;7-G<W1R(")"=6QG87)I:F$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"FUS9VED(")"=6QL971E9"!,:7-T
M(@IM<V=S='(@(E-U_GEMZW1A<R!SX')A\&%S(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I
M9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(D)U<FMI;F%S($9A<V%S(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R(")"=7)U;F1I:F$B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0T"FUS9VED(")#35,B"FUS
M9W-T<B`B5%93(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S='(@(D-20R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#4DP@1&ES=')I
M8G5T:6]N(%!O:6YT<R(*;7-G<W1R(")#4DP@<&%S:VER<W1Y;6\@<'5N:W1A
M:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R
M(")?0V5LZW,@;G5S=&%T>6UA:2XN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-C,*(RP@9G5Z>GD*;7-G:60@(D-A8VAE(&EN:70@=V%S
M(&YO="!C;VUP;&5T960N(@IM<V=S='(@(DYEX7)A\.MT92!D:7-T<FEB=6-I
M:F]S('/@<F'P;RXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#@T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.#<*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$U-0IM<V=I9"`B0V%L96YD87(B"FUS
M9W-T<B`B2V%L96YD;W)I=7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C0V"FUS9VED(")#86QM(@IM<V=S='(@(E)A;74B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B2V%M8F]D_F$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8W"FUS9VED(")#86UE<F]O;B(*;7-G<W1R(")+86UE<OMN87,B"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N(&YO
M="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@
M861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB3F5V96EK:6$@875T;VUA=&EN
M:7,@<VQA<'1A_F]D_FEO('!A:V5I=&EM87,L('-U<VES:65K:71E('-U("(*
M(F%D;6EN:7-T<F%T;W)I=6UI+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C,Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N(&YO
M="!W<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R(").96=A;&EU(&GP=')I
M;G1I(&9A:6QO(%PB)7-<(BXB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C(*
M;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H86YD
M;&5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U
M<RYP:'`Z,C,U(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS,3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E
M<G9E<CH@)7,B"FUS9W-T<B`B3F5G86QI=2!P<FES:6IU;F=T:2!P<FEE($E-
M05`@<V5R=F5R:6\Z("5S(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z-#$S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!O<&5N
M(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").96=A;&EU(&GP=')I;G1I(&9A:6QO
M(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#86YA9&$B"FUS9W-T<B`B
M2V%N861A(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP
M.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-C4*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E
M;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]R96UO=F4N:6YC.C$R"FUS9VED(")#86YC96PB"FUS9W-T
M<B`B073P875K=&DB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(D%T
M\&%U:W1I('!R;V)L96UO<R!P<F%N9?!I;>`B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@
M9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").96=A;&EU(&GP=')I;G1I
M(&9A:6QO(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2]C;W!Y+G!H<#HU,@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A
M<GD@9&ER96-T;W)Y+B(*;7-G<W1R(").96=A;&EU(')A<W1I(&QA:6MI;F]J
M;R!K871A;&]G;RXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(N<&AP.CDQ"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T
M87)G971&:6QE)R!P87)A;65T97(N(@IM<V=S='(@(DYE9V%L:74@87!D;W)O
M=&D@)W1A<F=E=$9I;&4G('!A<F%M971R;RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C,Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@
M<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DYE9V%L:74@:?!T
M<FEN=&D@:V%T86QO9V\@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]$871A5')E
M92]$871A5')E92YP:'`Z,3(X(&9R86UE=V]R:R]$871A5')E92]$871A5')E
M92]S<6PN<&AP.C8X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M
M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`B3F5G86QI=2!I\'1R
M:6YT:2X@16=Z:7-T=6]J82`E9"!P;_!A:VEA:2XB"@HC.B!F<F%M97=O<FLO
M1&%T851R964O1&%T851R964O<W%L+G!H<#HV,#@*;7-G:60@(B(*(D-A;FYO
M="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O
M<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R
M("(B"B).96=A;&EU('!E<G+[\&EU;W1I+B#!=F5S=&%S(.%R8?#X('-K86GH
M:75S(&YE<W5T86UP82!S=2#A<F'P^"!S:V%IZ&EU;6D@(@HB9'5O;65N^"!B
M87KK:F4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S
M<&5C:69I960@;G5M8F5R+B(*;7-G<W1R(").96=A;&EU(&YU:W)E:7!T:2#^
M:6YU=.MS(.$@;G5R;V1Y=.`@;G5M97+A+B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HT.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@
M(D-A<&4@5F5R9&4B"FUS9W-T<B`B2V5I<'9E<F1I<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*;7-G:60@
M(D-A<'1I;VXB"FUS9W-T<B`B4&%V861I;FEM87,B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I
M97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP"FUS
M9VED(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`B2V%T96=O<FEJ
M;W,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T
M<B`B2V%I;6%N^"!S86QO<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B
M36]B:6QU<R!T96QE9F]N87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(U"FUS9VED(")#96QL(%!R;W!E<G1I
M97,B"FUS9W-T<B`B0V5LZW,@;G5S=&%T>6UA:2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A
M9&1I;F<Z(@IM<V=S='(@(E1A<G!A:2!C96SK<V4Z(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B
M0V5L;"!P<F]P97)T:65S(@IM<V=S='(@(D-E;.MS(&YU<W1A='EM86DB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@IM
M<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R(")487)P86D@=&%R<"!C96QI
M^#HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C<T"FUS9VED(")#
M96QL<&AO;F4B"FUS9W-T<B`B36]B:6QU<VES('1E;&5F;VYA<R(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED(")#96QT:6,@*$E33RTX.#4Y
M+3$T*2(*;7-G<W1R(")+96QT^"`H25-/+3@X-3DM,30I(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-@IM<V=I
M9"`B0V5N=&5R(@IM<V=S='(@(D-E;G1R92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@
M(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R(")#96YT<FENZW,@
M069R:6MO<R!297-P=6)L:6MA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M-SD*;7-G:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S
M='(@(D-E;G1R:6[K<R!%=7)O<&]S("A)4T\M.#@U.2TR*2(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-CDY"FUS9VED(")#97)T:69I
M8V%T92!$971A:6QS(@IM<V=S='(@(E-E<G1I9FEK871O(&1E=&%LZW,B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Q,0HC+"!F=7IZ
M>0IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B4V5R=&EF:6MA
M=&\@9&5T86SK<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3DV"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R(")3
M97)T:69I:V%T;R!T96ESZW,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(D-H860B
M"FUS9W-T<B`BR&%D87,B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"FUS9VED(")#
M:&%N9V4B"FUS9W-T<B`B4&%K96ES=&DB"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@(D-H86YG92!9;W5R(%!A
M<W-W;W)D(@IM<V=S='(@(E-L87!T8?YO9/YI;R!K96ET:6UA<R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@IM<V=I9"`B(@HB0VAA;F=E('1H92!N
M86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A
M9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(B(*(DK[
M<_@@=F%R9&\@:7(@861R97-O+"!K=7)I=6]S(&UA='ES(/YM;V[K<RP@<VMA
M:71A;G1Y<R!I<B!A='-A:VENZVIA;G1Y<R#A("(*(DK[<_@@;&%I\&MU<RP@
M:V5I=&EM87,N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T
M"FUS9VED("(B"B)#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P
M;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N
M=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*;7-G
M:60@(D-H87(B"FUS9W-T<B`B4VEM8F]L:7,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H
M96-?:R!,:6YK+BXN(@IM<V=S='(@(E!A7W1I:W)I;G1I(&YU;W)O9.`N+BXB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8W"FUS9VED(")#:&EL92(*;7-G<W1R("+(:6SK(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C4T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-PIM<V=I9"`B0VAI;F$B"FUS9W-T<B`B2VEN:6IA(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE
M9"`H1T(R,S$R*2(*;7-G<W1R(")+:6YI971I\&MA('!A<')A<W1A("A'0C(S
M,3(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-H:6YE
M<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S='(@(DMI;FEE=&GP:V$@=')A
M9&EC:6[K("A":6<U*2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P
M+G!H<#HR-CD*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(E!A
M<VER:6YK:71E('-L87!T8?YO9.$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,C8X"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*;7-G
M<W1R(")087-I<FEN:VET92!V87)T;W1O:F\@=F%R9.`B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,CDX"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L
M87D@9&%T97,Z(@IM<V=S='(@(E!A<VER:6YK:71E(&MA:7`@=F%I>F1U;W1I
M(&1A=&%S.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE('1Y
M<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R(")087-I<FEN:VET92!S
M=7+[\&EU;W1O('/@<F'P;R!S=&EL:?@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#
M:')I<W1M87,@27-L86YD(@IM<V=S='(@(DMA;.MD^"!S86QA(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C@Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D969I;FET:6]N
M(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`B2VQA<^MS("5S(&[K<F$N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*;7-G
M:60@(D-L96%R(@IM<V=S='(@(D=I961R82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F
M:6-E('1A9W,B"FUS9W-T<B`B2?!T<FEN=&D@35,@3V9F:6-E(/YY;65S(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.`HC+"!F=7IZ>0IM<V=I9"`B0VQE
M87(@475E<GDB"FUS9W-T<B`B2?!V86QY=&D@=F%R=&]T;VIO(&1U;VUE;FES
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM<V=S='(@(E9A
M<G1O=&]J;R!D=6]M96[X('9A;'EM87,Z("5S(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O8VQE87(N:6YC.C$Q"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S
M='(@(DGP=F%L>71I('9A<G1O=&]J;R!D=6]M96YI<R(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T"FUS9VED(")#;&5A<B!U<V5R(&1A
M=&$B"FUS9W-T<B`B2?!V86QY=&D@=F%R=&]T;VIO(&1U;VUE;FES(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,34*(RP@9G5Z
M>GD*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B3&EE='5S('9A:V%R
M92(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL
M.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R(")4YG-T:2(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R(")#;&EC
M:V%T96QL('!E<B!(5%10(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T
M-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7
M:6YD;W<B"FUS9W-T<B`B5?YD87)Y=&D@;&%N9^`B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(T-`IM<V=I9"`B0VQO=61S(@IM<V=S='(@(D1E8F5S=6]T
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$V
M"B,L(&9U>GIY"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`B1&5B97-U
M;W1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,3<*;7-G:60@(D-L;W5D>2(*;7-G<W1R(")$96)E<W5O=&$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8T"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R(")+
M;VMO<V\@*$MY;&EN9V\I('-A;&]S(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S
M:61E8F%R+FEN8SHR,PHC+"!F=7IZ>0IM<V=I9"`B0V]L;&%P<V4@4VED96)A
M<B(*;7-G<W1R(")4=?#H:?@@8V5L:?@@:W)A\'3X(')O9'EM87,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(X
M"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G<W1R(")4=?#H:?@@8V5L
M:?@@:W)A\'3X(')O9'EM87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;VQO;6)I
M82(*;7-G<W1R(")+;VQU;6)I:F$B"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP
M.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B
M"FUS9W-T<B`B4W!A;'9A(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O
M;&QE8W1I;VXN<&AP.C,R-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L
M;&5C=&EO;BYP:'`Z,S(U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HU,#`@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H
M<#HQ-`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHT.0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHV-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHV-@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHX,0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHX,@IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@(E!A<VER:6YK:71E
M('-P86QVX"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X-#8*;7-G
M:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B4W!A;'9O<R!P87-I<FEN
M:VEM87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`B4W1U;'!E;&EA:3HB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30V"FUS9VED(")#;VQU;6X@
M=&ET;&5S(@IM<V=S='(@(E-T=6QP96QI^"!P879A9&EN:6UA:2(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C0*;7-G:60@(D-O;6EC<R(*;7-G
M<W1R(")+;VUI:W-A:2(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-0IM<V=I
M9"`B0V]M;6%N9"(*;7-G<W1R(")+;VUA;F1A(@H*(SH@861M:6XO8VUD<VAE
M;&PN<&AP.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@(DMO;6%N
M9&ENZR!E:6QU=.LB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,3,*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B2V]M96YT87)A<R(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38V"FUS9VED(")#
M;VUM;VX@3F%M92(*;7-G<W1R(")687)D87,O<&%V87)DZR(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@T"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(DMO;6]R86DB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#
M;VUP86YY(@IM<V=S='(@(DMO;7!A;FEJ82(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(DMO;7!I=71E
M<FEA:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3<*(RP@
M9G5Z>GD*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R(")3X&QY9V]S(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#D*;7-G:60@(D-O;F1I=&EO;G,B"FUS
M9W-T<B`B4^!L>6=O<R(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS
M9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S='(@(DYU<W1A
M='EM^"!P86ME:71I;6%I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T
M,PIM<V=I9"`B0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L
M(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3,U"B,L(&9U>GIY"FUS9VED(")#;VYF:6=U
M<F%T:6]N(&ES(&]U="!O9B!D871E+B(*;7-G<W1R(")296EK:6$@871N875J
M:6YT:2!K;VYF:6?[<F%C:6[A(&9A:6S@+B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S
M(@IM<V=S='(@(DMO;F9I9_MR=6]T:2`E<R(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z-3$*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B
M"FUS9W-T<B`B4VQA<'1A_F]D:7,@9&%R(&MA<G3@(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C4Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM
M<V=I9"`B0V]N9V\B"FUS9W-T<B`B2V]N9V%S(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I
M9"`B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G
M<W1R(")$96UO:W)A=&ENZR!+;VYG;R!297-P=6)L:6MA(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C
M=&EO;B!F86EL960N(@IM<V=S='(@(E!R:7-I:G5N9W1I(&YE<&%V>6MO+B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G
M:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`B4')I<VEJ=6YG=&D@
M;F5P879Y:V\Z("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+B(*;7-G<W1R(")0<FES:6IU;F=T:2!P<FEE('9I9?#X:O@@
M<F%K=/@@<V5R=F5R:6\@;F5P879Y:V\N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-SDR"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE
M8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N
M.B`E<R`H)7,I(@IM<V=S='(@(E!R:7-I:G5N9W1I('!R:64@=FEE\/AJ^"!R
M86MT^"!S97)V97)I;R!N97!A=GEK;RP@;F5S.B`E<R`H)7,I(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-#4*;7-G:60@(D-O;FYE8W1I;VX@
M=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(E!R:7-I:G5N9W1I('!R
M:64@1E10('-E<G9E<FEO(&YE<&%V>6MO+B(*"B,Z(&-O;F9I9R]H;V]K<RYP
M:'`N9&ES=#HQ,#$T"FUS9VED(")#;VYT86-T<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@
M(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D
M<F5S<R!B;V]K+B(*;7-G<W1R(")+;VYK86MT86D@<^MK;6EN9V%I(.%T<F%U
M:W1I(.$@2OMS^"!A9')E<_@@:VYY9V5LYB(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HV,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C<X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT
M96YT<R!O9B!<(B5S7"(B"FUS9W-T<B`B)R5S)R!T=7)I;GES(@H*(SH@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C,S"FUS9VED(")#;VYT:6YU92(*;7-G<W1R(")4YG-T:2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R(")+=6MO
M('-A;&]S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,R"FUS9VED(")#
M;V]K:64B"FUS9W-T<B`B3&%I;>MS(/YI;G5TZW,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C$*;7-G:60@
M(D-O<'DB"FUS9W-T<B`B2V]P:6IU;W1I(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HT-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O
M<'D@9F%I;&5D.B`E<R(*;7-G<W1R(")0<FES:6IU;F=T:2!N97!A=GEK;SH@
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B2V]P:6IU;W1I('!A
M<VER:6YK:6W@(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HQ.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C8R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM
M<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R(")+;W-T82!2:6MA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R(")$<F%M8FQI;R!+
M875L;R!+<F%N=&%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z.3<V"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92XB
M"FUS9W-T<B`B3F5P879Y:V\@=?YK;V1U;W1I(%!'4"!L86GP:V\N(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`U,PIM<V=I9"`B0V]U
M;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(DYE<&%V>6MO('!A
M<VER8?!Y=&D@4$=0(&QA:?!K;RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R
M>7!T(&UE<W-A9V4N(@IM<V=S='(@(DYE<&%V>6MO('7^:V]D=6]T:2!3+TU)
M344@;&%I\&MO+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-#8W"FUS9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB
M"FUS9W-T<B`B3F5P879Y:V\@<&%S:7)A\'ET:2!3+TU)344@;&%I\&MO+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,3@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C
M="X@)7,B"FUS9W-T<B`B3F5P879Y:V\@<')I9.MT:2!K;VYT86MT;RX@)7,B
M"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z.38@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ,C$*;7-G:60@(D-O=6QD(&YO="!B
M:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(").97!A=GEK;R!A=71E;G1I
M9FEK=6]T:7,@X2!,1$%0('-E<G9E<N$N(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C0U-PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@
M;&1A<"!S97)V97(B"FUS9W-T<B`B3F5P879Y:V\@875T96YT:69I:W5O=&ES
M(.$@3$1!4"!S97)V97+A+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`B3F5P879Y
M:V\@<&%T:6MR:6YT:2!B86QA;G-O+B`E<R(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HT-#$*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T
M('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(DYE<&%V>6MO('!R:7-I:G5N9W1I
M('!R:64@4TU"('-E<G9E<FEO+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HT.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O
M;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@
M(DYE<&%V>6MO('!R:7-I:G5N9W1I('!R:64@)R5S)R!S97)V97)I;R!P97(@
M1E10.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,S(R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C
M<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYE<&%V>6MO
M('-U:W5R=&D@9&ES=')I8G5C:6IO<R!SX')A\&\N("5S(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$R-0IM<V=I9"`B0V]U;&0@;F]T
M(&1E8W)Y<'0@4$=0(&1A=&$N(@IM<V=S='(@(DYE<&%V>6MO(&%T:V]D=6]T
M:2!01U`@9'5O;65N^"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4R,@IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A
M=&$N(@IM<V=S='(@(DYE<&%V>6MO(&%T:V]D=6]T:2!3+TU)344@9'5O;65N
M^"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C(T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E
M(&-O;G1A8W0N("5S(@IM<V=S='(@(DYE<&%V>6MO(&GP=')I;G1I(&MO;G1A
M:W1O+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D
M96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYE<&%V>6MO
M(&GP=')I;G1I(&1I<W1R:6)U8VEJ;W,@<^!R8?!O+B`E<R(*"B,Z(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.C,X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB
M)7-<(BXB"FUS9W-T<B`B3F5P879Y:V\@:?!T<FEN=&D@871N875J:6YI;6\@
M<VMR:7!T;R`G)7,G+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,S@Q(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU,PIM
M<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM
M86EL(&%D9')E<W,N(@IM<V=S='(@(DYE<&%V>6MO(&YU<W1A='ET:2!G87;K
M:F\@96PN('!A\'1O(&%D<F5S;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U;&0@;F]T(&9E
M=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B4&%V>6MO(&=A
M=71I('9I<V]S(&%D<F5S^"!K;GEG96SK<RXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PIM<V=I9"`B0V]U;&0@
M;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R
M(").97!A=GEK;R!G875T:2!V:7-O(&1I<W1R:6)U8VEJ;W,@<^!R8?!O+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-#0V"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@
M;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R(").97!A=GEK;R!G875T
M:2!V:7-O(&1I<W1R:6)U8VEJ;W,@<^!R8?#X('/@<F'P;RXB"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T
M96=Y+G!H<#HV.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM
M<V=S='(@(DYE<&%V>6MO('7^:W)A=71I('-T<F%T96=I:F]S("<E<R<N(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z
M,S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!M:V1I
M<B!<(B5S7"(N(@IM<V=S='(@(DYE<&%V>6MO('-U:W5R=&D@:V%T86QO9V\@
M)R5S)RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW,3D*
M;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K
M97ES97)V97(N(@IM<V=S='(@(DYE<&%V>6MO(&=A=71I('9I9?!O:F\@<F%K
M=&\@:?`@<F%K=/@@<V5R=F5R:6\N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S
M.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@
M7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R(").97!A=GEK;R!A=&ED87)Y
M=&D@)R5S)R!R8?!Y;75I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B3F5P879Y:V\@871I9&%R>71I
M("5S+B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP
M:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N($UA
M:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(DYE<&%V>6MO(&%T
M:61A<GET:2!-86EN=&5N86YC95]487-K(&UO9'5L:6\@)7,B"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DYE<&%V
M>6MO(&%T:61A<GET:2!K871A;&]G;R`G)7,G+B(*"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3$@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C$T-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,C,W(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C4Q-B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HV-38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C8Y.0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E86-H('1H92!,
M1$%0('-E<G9E<BXB"FUS9W-T<B`B3F5P879Y:V\@<&%I9?!K82!,1$%0('-E
M<G9E<GEJ92XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(S
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS
M9W-T<B`B3F5P879Y:V\@<VMA:71Y=&D@)7,N(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T
M:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A
M;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A
M:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@
M(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B).97!A=GEK;R!P86ME:7-T
M:2!S;&%P=&'^;V3^:6\@\&EA;2!V87)T;W1O:G5I+B!+86D@:W5R:2!A<F)A
M('9I<V$@(@HB:6YF;W)M86-I:F$@>7)A(&YE=&EK<VQI+B!086)A;F1Y:VET
M92!D87(@:V%R=.`@87)B82!S=7-I<VEE:VET92!S=2!S879O("(*(F%D;6EN
M:7-T<F%T;W)I=6UI(&IE:6=U(')E:6MA;&EN9V$@<&%G86QB82XB"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#D*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0P"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-PHC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#,*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y"FUS9VED(")#;W5L9"!N
M;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(DYE<&%V>6MO(&=A=71I($%#3"(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,C<T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A
M9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(DYE<&%V>6MO(&=A=71I(&%D<F5S
M^"!K;GEG96SK<RX@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C0X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@
M(DYE<&%V>6MO(&=A=71I(&1I<W1R:6)U8VEJ;W,@<^!R8?!O+B`E<R(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T
M<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@(DYE<&%V>6MO(&=A=71I(&1I
M<W1R:6)U8VEJ;W,@<^!R8?#X+B`E<R(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,C(S"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@
M<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@(DYE<&%V>6MO(&YU<W1A
M='ET:2!S97)V97)I;R!G86QI;7EB:?@B"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C4T"FUS9VED(")#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(DYE<&%V>6MO(&%T:V5I<W1I(&YU<W1A='EM^"XB"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S='(@(DYE<&%V>6MO
M(&GP=')I;G1I(&MA=&%L;V=O("<E<R<N(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A
M=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B3F5P879Y:V\@:?!S875G
M;W1I("5S(&YU<W1A='EM^"XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3D*;7-G:60@(D-O=6QD(&YO
M="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B3F5P879Y
M:V\@<&%D87)Y=&D@871S87)G:6[K<R!N=7-T871Y;?@@:V]P:6IO<RXB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO
M;CH@)7,B"FUS9W-T<B`B3F5P879Y:V\@<&%D87)Y=&D@871S87)G:6[K<R`E
M<R!N=7-T871Y;?@@:V]P:6IO<RXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HY-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T
M<B`B3F5P879Y:V\@:?!S875G;W1I(&%T;F%U:FEN:6UO('-K<FEP="#A.B`G
M)7,G+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@
M8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R(").97!A=GEK;R!P861A
M<GET:2!A='-A<F=I;NMS("5S(&YU<W1A='EM^"!K;W!I:F]S+B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(B(*(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I
M;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO
M;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L
M;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*(DYE<&%V>6MO
M('7^<F'P>71I+B!*^W,@9V%L:71E(&%R8F$@;F%U9&]T:7,@871N875J:6YI
M;6\@<VMR:7!T=2!A<F)A('!A='ES("(*(FYU:V]P:6IU;W1I(&MO9.`@87!A
MZ&EO:F4@X2`E<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C$T,PIM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N
M(@IM<V=S='(@(DYE<&%V>6MO('!A:67P:V$@3$1!4"!S97)V97)Y:F4N(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB"FUS9W-T<B`B3F5P879Y
M:V\@;G5T<F%U:W1I(')Y\.$@)R5S)RXB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@(DYE
M<&%V>6MO(&%T;F%U:FEN=&D@:V]N=&%K=&\N("5S(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,B"FUS9W-T<B`B3F5P879Y:V\@871N875J:6YT:2!D:7-T<FEB=6-I
M:F]S('/@<F'P;RX@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C
M;VYF:6=U<F%T:6]N(&9O<B!<(B5S7"(Z("5S(@IM<V=S='(@(DYE<&%V>6MO
M('7^<F'P>71I("<E<R<@;G5S=&%T>6WX.B`E<R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-C8*;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL
M;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM
M<V=S='(@(B(*(DYE<&%V>6MO(')A<W1I($UO>FEL;W,@X7)A;FMI^"!J=6]S
M=&]S+B#!<VET:6MI;FMI=&4L(&MA9"!J:2!A=&ED87)Y=&$N(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E
M<UPB('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<
M(CH@)7,B"FUS9W-T<B`B3F5P879Y:V\@<W5T96EK=&D@\&GX('1E:7-I^"!V
M87)T;W1O:G5I("<E<R<@:V%T96QO9V4@)R5S)SH@)7,B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-#$Y"FUS9VED(")#;W5N=&5D('1E>'0B"FUS
M9W-T<B`B4FEB;W1A<R!T96MS=&%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`B5F%L
M<W1Y8NLB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C<S"FUS9VED
M(")#;W5R<V5S(@IM<V=S='(@(DMU<G-A:2(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I9"`B
M0W)E871E(@IM<V=S='(@(E-U:W5R=&DB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T
M92!A(&QI;FLB"FUS9W-T<B`B4W5K=7)T:2!N=6]R;V3@(@H*(SH@=&5M<&QA
M=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY-`IM<V=I9"`B0W)E871E
M(&$@;F5W(&]N92(*;7-G<W1R(")3=6MU<G1I(&YA=6K@(&%P<F'PX"(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR"FUS9VED
M(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B4W5K=7)T:2!P86MA=&%L
M;V=I=7,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(T,`IM
M<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*;7-G<W1R(")3879I;FEN:V\@
M=&5I<^MS(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(S,`IM<V=I
M9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(DMR961I=&ENZW,@:V]R
M=&5LZW,@;G5M97)I<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")#<F]A=&EA(@IM
M<V=S='(@(DMR;V%T:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B82(*;7-G
M<W1R(")+=6)A(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(V"B,L(&9U>GIY
M"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@(D1A8F%R=&ENZR!F
M87KK(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C0X"B,L(&9U>GIY"FUS9VED
M(")#=7)R96YT(%-E<W-I;VYS(@IM<V=S='(@(E-A=FEN:6YK;R!T96ESZW,B
M"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z
M,S`*;7-G:60@(D-U<G)E;G0@5&EM92(*;7-G<W1R(")$86)A<G1I;FES(&QA
M:6MA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T<B`B
MT&EU;R!M971U(%523"!Y<F$B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S,*
M(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@57-E<G,B"FUS9W-T<B`B1&%B87)T
M:6[K(&9A>NLB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS9VED(")#
M=7)R96YT(%=E871H97(B"FUS9W-T<B`B1&%B87)T:6[K<R!O<F\@<^!L>6=O
M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-S4*;7-G:60@
M(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`B1&%B87)T:6[K<R!SX&QY
M9V]S.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@(D1A8F%R=&EN
M:7,@<W1I;&EU<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N
M(&QO9V]N('1O("5S+B(*;7-G<W1R(")696EK<VWX+"!A=&QI96MA;?@@<')I
M<VEJ=6YG=7,@<')I92`E<RP@;G5S=&%T>6UA<RXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@
M(D-U="(*;7-G<W1R(")097)K96QT:2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I;VXB
M"FUS9W-T<B`B4&5R:V5L=&D@<&%S:7)I;FMI;>`B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS
M9VED(")#>7!R=7,B"FUS9W-T<B`B2VEP<F%S(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#(*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@
M(DMI<FEL:6-A("A+3TDX+5(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#,*;7-G:60@(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(DMI
M<FEL:6-A("A7:6YD;W=S+3$R-3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#0*;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G
M<W1R(")+:7)I;&EC82]5:W)A:6YI971I\&MA("A+3TDX+54I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.0IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS9W-T<B`BR&5K:6IO<R!2
M97-P=6)L:6MA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0U,2!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B1$0B
M"FUS9W-T<B`B1$0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@Q
M"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A
M;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP
M:'`Z-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(DMA<V1I96XB"@HC.B!A9&UI
M;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS
M9W-T<B`B1'5O;65N^"!M963^:6\@;F%R\'EK;.LB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,C<Y"FUS9VED(")$871A8F%S92!,;V]K=7`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R
M+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,SDY"FUS9VED(")$
M871E(@IM<V=S='(@(D1A=&$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A
M<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E:79E9"(*;7-G<W1R(")'
M875T82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#<*;7-G:60@
M(D1A=&4@<V5L96-T:6]N(@IM<V=S='(@(D1A=&]S('!A<VER:6YK:6UA<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3(@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,R,@IM<V=I9"`B1&%Y(@IM<V=S='(@(D1I
M96YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,V"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G<W1R("))
M\'1R:6YT:2!?<W1U;'!E;.$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#$R"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B1W)U
M;V1I<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R
M(")$9?!I;71A:6YI86D@<VMA:>AI86DB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E
M;G0B"FUS9W-T<B`B4W5M8?YI;G1I(&%T:71R875K:6W@(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HQ.#<@;&EB+W!R969S+G!H<#HQ,3<*
M(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B4W1A;F1A<G1I;NL@
M<W!A;'9A(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N
M="YI;F,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N
M="YI;F,Z-S<*;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B4W1A;F1A
M<G1I;NL@<W!A;'9A(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y
M+G!H<#HY,0IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*;7-G<W1R(")3=&%N
M9&%R=&EN:7,@87!R8?!A<R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV
M-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R(")3=&%N
M9&%R=&ENZR!S<&%L=F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*
M;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S='(@(D%P:6)RZ_YI;6%I(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HW,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C,R-@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C,V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$Q-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$S.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.CDX"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN
M8SHQ,"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B
M1&5L971E(@IM<V=S='(@(DGP=')I;G1I(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"B,L(&9U>GIY"FUS
M9VED(")$96QE=&4@0V5L;"(*;7-G<W1R("))\'1R:6YT:2!C96SF(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR,C<*;7-G
M:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R("))\'1R:6YT:2!G<G5PYB(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T.0HC+"!F=7IZ>0IM<V=I
M9"`B1&5L971E($QO9R(*;7-G<W1R("))\'1R:6YT:2!E:6QU=.8B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<W(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,3`Q"FUS9VED(")$96QE=&4@4&5R;6ES<VEO;B(*
M;7-G<W1R("))\'1R:6YT:2!T96ESYB(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E
M(&UE<W-A9V5S(@IM<V=S='(@(E9I<VGP:V%I(&GP=')I;G1I(&QA:?!K=7,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4W"FUS9VED(")$96QE=&4@8V5L;"(*;7-G<W1R("))\'1R:6YT:2!C
M96SF(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R("))\'1R
M:6YT:2!S='5L<&5LX2(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS
M9VED(")$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E(@IM<V=S
M='(@(DGP=')I;G1I(&5G>FES='5O:F%N=.$@86QT97)N871Y=O@@\&%B;&]N
MX"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(Q"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R
M(%PB)7-<(B(*;7-G<W1R("(G)7,G('1E:7-I^"!T<GEN:6UA<R(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B!A
M;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T<B`B07(@=&EK<F%I(&YO
M<FET92!I\'1R:6YT:2`G)7,G('1E:7-E<R!I<B!V:7-A<R!P;W1E:7-E<S\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8W"FUS9VED(")$96QE=&4@<F]W(@IM<V=S='(@(DGP=')I;G1I(&5I
M;'5TYB(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I9&5N=&ET>2YI;F,Z
M,34*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET>2(*;7-G<W1R("))
M\'1R:6YT:2!P87-I<FEN:W3@(&%P<F'PX"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L
M971E('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R("))\'1R:6YT:2#PX2!S
M='5L<&5LX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O
M=R(*;7-G<W1R("))\'1R:6YT:2#P:>`@96EL=73F(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z,S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R
M(")!=&YA=6II;FEM;R!S:W)I<'1A<R`G)7,G(&GP=')I;G1A<RXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V,PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y
M-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,C$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C4S"FUS9VED(")$96QI=F5R>2!T:6UE(@IM<V=S='(@(E!R:7-T
M871Y;6\@;&%I:V%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&5N;6%R:R(*;7-G
M<W1R(")$86YI:F$B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`B4')O
M8FQE;6]S(&%P<F'P>6UA<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.CDS."!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,P"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R(")!<')A\'EM87,B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y-0IM<V=I9"`B1&5T
M86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R(")$971A
M;&EA=2`H=&%I<"!P870@_FG[<NMK:71E($AO<F1E(&QO9R!F86EL92DZ(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3D*;7-G:60@(D1E=&%I
M;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM
M<V=S='(@(D%D;6EN:7-T<F%T;W)I=6D@:?!S:?AS=&%S(&1E=&%L=7,@87!R
M8?!Y;6%S+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,3D*;7-G
M:60@(D1E=F5L;W!M96YT(@IM<V=S='(@(E9Y<W1Y;6%S(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,3<*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R(")$
M<NMG;G5M87,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-`IM<V=I9"`B
M1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")$<NMG;G5M87,@
M<&%S:W5T:6[F('9A;&%N9.`Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,C<*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(D1RZV=N
M=6UA<SH@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS9W-T
M<B`B2W)Y<'1I<R!I\"!K86ERZW,@X2!D9?!I;N8B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I
M;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R(")+<GEP=&ES(&GP(&1E\&ENZW,@
MX2!K86ERYB(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$
M:7)E8W1O<GDB"FUS9W-T<B`B2V%T86QO9V%S(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(V-@IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*
M;7-G<W1R(")2;V1Y=&D@,C0M:?@@=F%L+B!F;W)M873@/R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY-PIM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM
M<V=S='(@(E9A:7ID879I;6\@;G5S=&%T>6UA:2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!D
M971A:6QE9"!F;W)E8V%S="(*;7-G<W1R(")2;V1Y=&D@<')O9W)O;N8@*%1!
M1BDB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@U"FUS9VED(")$:7-P;&%Y
M(&9O<F5C87-T("A4048I(@IM<V=S='(@(E)O9'ET:2!P<F]G<F]NYB`H5$%&
M*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3<*;7-G:60@(D1I
M<W!L87D@9F]R;6%T(@IM<V=S='(@(E9A:7ID879I;6\@9F]R;6%T87,B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,3DP"FUS9VED(")$:7-P
M;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B3&%I\&MO('!R:7-T871Y
M;6\@<')A;F7P:6UA:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM
M<V=S='(@(D3^:6)U=&ES(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HT,C(*;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B3F5T<FEN
M=&DB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O
M(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@
M(DYE<VEK<F5I<&MI=&4@=&EE<VEO9VEA:2#A(&UA:6YT96YA;F-E+G!H<"(*
M"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$R('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C$R"FUS9VED(")$;V5S('1H92!F:7)S="!R;W<@
M8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B
M;W@Z(@IM<V=S='(@(D%R('!I<FUA<R#A<F'P87,@>7)A(&QA=6MO('9A<F1A
M:3\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R(")$;VUI
M;FEK82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D1O;6EN:6-A;B!297!U8FQI8R(*
M;7-G<W1R(")$;VUI;FEK;W,@4F5S<'5B;&EK82(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N
M=#\@4VEG;B!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z.#0T"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R(")!
M='-I<VGX<W1I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z.#0T"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S(@IM<V=S
M='(@(D%T<VES:?AS=&D@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,38R"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A
M<R!02%`@<V-R:7!T+B(*;7-G<W1R(")!='-I<VGX<W1I('-U9V5N97)U;W1U
M<R!N=7-T871Y;75S(&MA:7`@4$A0('-K<FEP=.`N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C$P-PIM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS
M9W-T<B`B2?!S:7-K;&5I9/YI86YT:7,@<^!R8?!A<R(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B1')U9W,B"FUS9W-T<B`B5F%I<W1A
M:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I
M9"`B12U-86EL(@IM<V=S='(@(D5L+B!P8?!T;R!A9')E<V%S(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@
M(D5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H
M:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I
M;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS9W-T<B`B15)2(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,`IM<V=I9"`B16-U861O<B(*;7-G<W1R(")%:W9A9&]R87,B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-2!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-CD@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.`HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,2!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z-S(*(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN
M8SHR-0IM<V=I9"`B161I="(*;7-G<W1R(")+96ES=&DB"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4P('1E;7!L871E<R]P;W)T86PO961I
M="YI;F,Z,C4*;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T<B`B2V5I<W1I(&)L
M;VMO('!A<F%M971R=7,B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y."!A9&UI
M;B]G<F]U<',N<&AP.C(R-@IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R(")2
M961A9W5O=&D@9W)U<.8B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C<V(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`P"FUS9VED
M(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`B4F5D86=U;W1I('1E:7-E<R(*
M"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@
M4&5R;6ES<VEO;G,B"FUS9W-T<B`B4F5D86=U;W1I('1E:7-E<R(*"B,Z('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B)7,@=&5I<VGX
M(')E9&%G879I;6%S(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0IM
M<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`B2V5I<W1I(&YU<W1A
M='EM=7,Z(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-C<*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@
M9F]R(%PB)7-<(B(*;7-G<W1R("(E<R!T96ES:?@@<F5D86=A=FEM87,B"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T"B,L('!H<"UF;W)M870*
M;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(B5S('1E
M:7-I^"!R961A9V%V:6UA<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M-0IM<V=I9"`B161U8V%T:6]N(@IM<V=S='(@(E5G9'EM87,B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<P"FUS9VED(")%9WEP="(*;7-G<W1R(")%9VEP=&%S(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M16ET:&5R(&5N86)L92!I="!T:&5N.B`E<RP@;W(@=7-E('1H92!B87-I8R!(
M5$U,('9E<G-I;VXZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G
M:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@(E-A;'9A9&]R87,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*
M;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B16QE;65N=&%S+BXN(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G
M:60@(D5M(@IM<V=S='(@(D5M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(R-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.#8Y"FUS9VED(")%;6%I;"(*;7-G<W1R(")%;"X@<&'P=&%S(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C4@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C8X"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@
M(D5L+B!P8?!T;R!A9')E<V%S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3DV,PIM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM
M<V=S='(@(D5L+B!P8?!T;R!A9')E<V%I('1U<FD@<W5T87!T:2XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3@Y"FUS9VED(")%;6%I;"!W:71H
M(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")%;"X@<&'P=&\@861R97-A<R!S=2!P
M871V:7)T:6YI;74B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I
M8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W87DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(Y.`IM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(M!Y<'-E;NMLZW,B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#(*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(MYI;G5TZR!T
M=?#H:6$N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(T
M,R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-C(@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R(")297IU
M;'1A=&%S('1U\.AI87,N(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R
M9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@
M(DYE;G5R;V3K=&4@<&%I9?!K;W,@=&5R;6EN^"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU-#,*;7-G:60@(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA
M9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S='(@(DQE
M:7-T:2!T96MS=&4@X71E<G!T:2!P879E:6MS;.ML:75S(&GP($YU;W1R875K
M^"!G86QE<FEJ;W,_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q.`IM
M<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T
M<B`BP6IU;F=T:2!D9?!I;FEO:F\@<&5LZW,@;7EG='5K;R!M96YI=3\B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DX(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X,3$*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(D=A;&EN
M:6%I(&UE=&%I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%9&ET;W(B"FUS9W-T<B`B2?!P
M;.MS=&D@<F5D86MT;W)I^"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,C$*;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@
M>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B
M"B)P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E
M=#\G.B(*;7-G<W1R("(B"B+!<F'P>6MI=&4@:VQA=7-I;>`L(&MU<FES(&IU
M;7,@8G5S('7^9'5O=&%S(&IE:6=U('!A;6ER\&ET92!S879O('-L87!T8?YO
M9.$L("(*(G!V>BXZ("=K;VMS('ER82!*^W/X(&=Y=OMN;R!V87)D87,_)SHB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(*
M;7-G<W1R("+!=F5S:VET92!P879E:6MS;.ML:6\@55),(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Y,0IM<V=I9"`B16YT
M97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*
M;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(D5K=F%T;W)I;NL@
M1W9I;NMJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T<B`B
M17)I='+K:F$B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HT-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-34*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-B!S97)V:6-E<R]P;W)T86PO
M:6YD97@N<&AP.C@R"FUS9VED(")%<G)O<B(*;7-G<W1R(")+;&%I9&$B"@HC
M.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V,PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@8W)E871I;F<@8FQO8VLZ("5S
M(@IM<V=S='(@(DML86ED82!S:75NZ&EA;G0@871S86MY;>`Z("5S+B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C<R"B,L('!H<"UF;W)M870*
M;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX,PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z
M("5S(@IM<V=S='(@(DML86ED82!S:75NZ&EA;G0@871S86MY;>`Z("5S+B(*
M"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8X"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z
M("5S(@IM<V=S='(@(DML86ED82!S:75NZ&EA;G0@871S86MY;>`Z("5S+B(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S
M(@IM<V=S='(@(DML86ED82!S:75NZ&EA;G0@871S86MY;>`Z("5S+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M-0IM<V=I9"`B17)R;W(@=VET:"!E;6%I;"!M97-S86=E+B(*;7-G<W1R(")+
M;&%I9&$@;&%I\&ME+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@7"(E<UPB+B(*
M;7-G<W1R(")+;&%I9&$@<F'P86YT("<E<R<N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I
M9"`B17-T;VYI82(*;7-G<W1R(")%<W1I:F$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED
M(")%=&AI;W!I82(*;7-G<W1R(")%=&EO<&EJ82(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S='(@(D5T;FENZW,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U
M<F]P92(*;7-G<W1R(")%=7)O<&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S,Y"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(DMA<R`Q
M-2!M:6YUZ&GX(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X.0IM<V=I
M9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(DMA<R`R(&UI;G5T97,B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,V(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS.#<*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B2V%S
M(#,P('-E:W5N9/YI^"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S@@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,`IM<V=I9"`B179E<GD@-2!M:6YU
M=&5S(@IM<V=S='(@(DMA<R`U(&UI;G5T97,B"@HC.B!F<F%M97=O<FLO36%I
M;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I
M;B(*;7-G<W1R(")+:65K=FEE;F\@<')I<VEJ=6YG:6UO(&UE='4B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0P"FUS9VED(")%=F5R>2!H86QF(&AO
M=7(B"FUS9W-T<B`B2V%S('!U<W9A;&%N9.$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S,W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#@*;7-G:60@
M(D5V97)Y(&UI;G5T92(*;7-G<W1R(")+87,@;6EN=73F(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S
M.B(*;7-G<W1R(")0879Y>F3^:75I.B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H
M<#HX,2!A9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP
M.C$R-PIM<V=I9"`B17AE8W5T92(*;7-G<W1R(")6>6MD>71I(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#<U"FUS9VED(")%>'!A
M;F0B"FUS9W-T<B`B2?!S:VQE:7-T:2(*"B,Z('1E;7!L871E<R]P;W)T86PO
M<VED96)A<BYI;F,Z,S(*(RP@9G5Z>GD*;7-G:60@(D5X<&%N9"!3:61E8F%R
M(@IM<V=S='(@(D=A;&EN:6%I(&UE=&%I(@H*(SH@9G)A;65W;W)K+U-13"]3
M44PO2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP96-T960@)RDG(@IM<V=S
M='(@(E)E:6MA;&EN9V%S("<I)R(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME
M>7=O<F1S+G!H<#HQ-S4*;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q
M=6]T960@<V5A<F-H('1E<FTB"FUS9W-T<B`B4F5I:V%L:6YG87,@_F]D:7,@
M87)B82!K86)U=.MS92#A<F'P>71A<R!P86EE\&MO<R!K<FET97)I:G5S(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")%
M>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B1V%L:6]J:6UO(&1A=&$B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-@IM<V=I9"`B17AP
M;VYE;G0B"FUS9W-T<B`B16MS<&]N96YTZR(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O
M;&]R(@IM<V=S='(@(E1E:W-T;R!S<&%L=F$B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3<W"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S
M='(@(DYU<W1A='EM^"!S:75N=&EM87,@<&5R($944"XB"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O<W%L+G!H<#HR,38*;7-G:60@(D9A:6QE9"!R971R
M:65V:6YG('!R969E<F5N8V5S+B(*;7-G<W1R(")+;&%I9&$@;G5S:V%I=&%N
M="!N=7-T871Y;75S+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HW-2!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.CDX"FUS9VED
M(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B
M3F5P879Y:V\@<')I<VEJ=6YG=&D@<')I92!,1$%0('-E<G9E<FEO+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HY.`IM<V=I9"`B1F%I;&5D
M('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`B3F5P879Y:V\@
M<')I<VEJ=6YG=&D@<')I92!334(@<V5R=F5R:6\N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HV.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I
M;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@(DYE<&%V>6MO(&YU
M:V]P:6IU;W1I(&GP(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C8Y,0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P
M>2!T;R!<(B5S7"(N(@IM<V=S='(@(DYE<&%V>6MO(&YU:V]P:6IU;W1I(.$@
M7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#<*
M;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB
M"FUS9W-T<B`B3F5P879Y:V\@<W5K=7)T:2!N875J;R!305-,(')Y\&EO+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DW(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z-S(T"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE
M9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B3F5P879Y:V\@<&5R:V5L
M=&D@X2!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT
M-C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!R971R
M:65V93H@)7,B"FUS9W-T<B`B3F5P879Y:V\@<&5R:V5L=&D@X2!<(B5S7"(N
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*
M;7-G:60@(D9A:7(B"FUS9W-T<B`BT'9E;&YU<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HW.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G
M:60@(D9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*2(*;7-G<W1R(")&;VQK
M;&%N9/@@<V%L;W,@*$UA;'9I;F%I*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9A
M<F]E($ES;&%N9',B"FUS9W-T<B`B1F%R97+X('-A;&]S(@H*(SH@9G)A;65W
M;W)K+T-,22]#3$DN<&AP.C(S.`HC+"!F=7IZ>0IM<V=I9"`B1F%T86P@17)R
M;W(Z(@IM<V=S='(@(DMR:71I;NL@:VQA:61A(2(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A>"(*;7-G
M<W1R(")&86MS87,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Y
M"B,L(&9U>GIY"FUS9VED(")&87AE<R(*;7-G<W1R(")&86MS87,B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`R"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM<V=I9"`B
M1F5B<G5A<GDB"FUS9W-T<B`B5F%S87)I<R(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C(P"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@(D%T<F]D;R!L
M>6<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS9VED
M(")&965L<R!L:6ME.B`B"FUS9W-T<B`B071R;V1O(&QY9SH@(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E
M=R!3:&]W97)S(@IM<V=S='(@(E1R=6UP86QA:6MI<R!L:65T=7,B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`HC+"!F=7IZ
M>0IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")0^V=A(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-`IM<V=I9"`B1FEE;&0@;6%T
M<FEX(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S
M,S0*;7-G:60@(D9I9VQE="!#05!40TA!(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S@*;7-G:60@(D9I9VQE="!F;VYT(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B1FED
M_FES(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U
M>GIY"FUS9VED(")&:6QE(@IM<V=S='(@(F9A:6QA<R(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@
M0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B1F%I;/@@<VMA:>AI=7,Z("5S(&9A
M:6QA<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF
M;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(D9A
M:6SX('-K86GH:75S.B`E<R!F86EL86DH^"DB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#`W"FUS9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`B
M1F%I;/@@='9A<FMY;6%S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HV,R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<P"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z
M.#4*;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R(")&86EL;R!P879A9&EN:6UA
M<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y.34*;7-G:60@(D9I
M;&4@<V5L96-T:6]N(@IM<V=S='(@(D9A:6QO('!A<VER:6YK:6UA<R(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T.#8*;7-G:60@(D9I;&4@=7!L
M;V%D(@IM<V=S='(@(D9A:6QO('-I=6YT:6UA<R(*"B,Z(&9R86UE=V]R:R]"
M<F]W<V5R+T)R;W=S97(N<&AP.C@U.0IM<V=I9"`B1FEL92!U<&QO861S(&YO
M="!S=7!P;W)T960N(@IM<V=S='(@(DYA<O!Y:VSK(&YE<&%L86EK;R!F86EL
M^"!S:75N=&EM;RXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#D*
M;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`B1FEL=')A:2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HX,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*
M;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`B4W5O;6EJ82(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B4&ER
M;6]J:2!P=7/K(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C
M:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A<G1E<B(*;7-G<W1R(")0
M:7)M87-I<R!K971V:7)T:7,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C4V"FUS9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B
M3G5S=&%T>71A<R!K;V5F:6-I96YT87,B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,Q"FUS9VED(")&;&EP(@IM<V=S='(@
M(D%T=FER:_#H:6%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B2?!D
MZW-T>6UA<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B4OMK87,B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,3`W"B,L('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S
M(&YO="!E>&ES="(*;7-G<W1R(")+871A;&]G87,@)7,@;F5E9WII<W1U;VIA
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R(")496MS=&\@<W!A;'9A(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S
M='(@(DUA:7-T87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$R,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T
M:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@(DYA<O!Y:VSK;7,L
M(&MU<FEO<R!N97!A;&%I:V\@<&%V96EK<VSK;&GX(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,S0*;7-G:60@(D9O<F5C87-T("A4048I(@IM<V=S='(@
M(D]R^"!P<F]G;F]ZZR`H5$%&*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HW.0IM<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T
M('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N
M:6=H=#L@82`B"B)L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@
M82!W:61E(&)L;V-K*2(*;7-G<W1R("(B"B)/<O@@<')O9VYO>NMS(&%P:6UT
M:7,@*.%S:63K;>MK:71E+"!K860@\&D@9G5N:V-I:F$@9W)A_FEN82!I<B!D
M:65N;W,@:7(@(@HB;F%K=&EE<R!P<F]G;F]ZYCL@<&5R(&1I9&5L:7,@<VMA
M:>AI=7,@9V%L:2!S=61A<FMY=&D@9&EZ86ENX"DB"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C$P,@IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O
M<F0_(@IM<V=S='(@(E!A;6ER\&]T92!S879O('-L87!T8?YO9.$_(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V,@IM<V=I9"`B1F]R;7,B"FUS
M9W-T<B`B1F]R;6]S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"FUS
M9VED(")&;W)T=6YE(@IM<V=S='(@(D9R87KK(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.CDY"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B1G)A
M>FGX('1I<&%S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,X"FUS9VED
M(")&;W)T=6YE<R(*;7-G<W1R(")&<F%ZZW,B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B1G)A>NMS
M(#(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4S"FUS9VED(")&
M;W)U;7,B"FUS9W-T<B`B1&ES:W5S:6IO<R(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ,#D*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(E!E<G-I
M=6YT:6UA:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S='(@(E!E;FLN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PIM<V=I
M9"`B1G)A;65S(@IM<V=S='(@(DMR8?!T:6[K<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G
M:60@(D9R86YC92(*;7-G<W1R(")0<F%N8_MZ:6IA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L
M:71A;B(*;7-G<W1R(")0<F%N8_MZ:6IA+"!-971R;W!O;&ES(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R(")0<F%N8_MZ:6IO
M<R!'=FEA;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I
M82(*;7-G<W1R(")0<F%N8_MZ:6IO<R!0;VQI;F5Z:6IA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`Y"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T
M<B`B4')A;F/[>FEJ;W,@<&EE=&ENZW,@=&5R:71O<FEJ;W,B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&
M<F]M(@IM<V=S='(@(DYU;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-#@@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,`HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`V"FUS9VED(")&<F]M('1H
M92`B"FUS9W-T<B`B3G5O("(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C0X"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(E!I
M;&YA<R!A<')A\'EM87,B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB
M+T)L;V-K+VUO;VXN<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@
M(E!I;&YA=&ES(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*;7-G:60@(D9U;&P@3F%M
M92(*;7-G<W1R(")0:6QN87,@=F%R9&%S(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B
M1V%B;VXB"FUS9W-T<B`B1V%B;VYA<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L
M;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B1V%L97)I:F$@:?`@
M:W5R:6]S(&GP(&MU<FEO<R!B=7,@<F]D;VUA<R!P879E:6MS;.ML:7,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(D=A;&5R:6IA.B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.38@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R(")'86UB:6IA(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(D=E;F5R
M=6]T:2`E<R!N=7-T871Y;75S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P
M+V-O;F9I9RYH=&UL.C@*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@
M(E-U9V5N97)U;W1A<R!K;V1A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G
M:6$B"FUS9W-T<B`B1W)U>FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA
M;GDB"FUS9W-T<B`B5F]K:65T:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDQ
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VAA
M;F$B"FUS9W-T<B`B1V%N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A
M<B(*;7-G<W1R(")':6)R86QT87)A<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3<U"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@
M(E9A<F1A<R(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$R"FUS9VED
M(")';R(*;7-G<W1R(")2;V1Y=&DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G<W1R(")'861E;&ES(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,C@*(RP@9G5Z
M>GD*;7-G:60@(D=O;V=L92!-87!S(@IM<V=S='(@(D=O;V=L92!P86EE\&MA
M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE
M(%-E87)C:"(*;7-G<W1R(")';V]G;&4@<&%I9?!K82(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S<*;7-G:60@(D=R87ES
M8V%L92(*;7-G<W1R(").97-P86QV;W1A<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED
M(")'<F5E8V4B"FUS9W-T<B`B1W)A:6MI:F$B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X-0IM<V=I9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@
M(D=R86EK:?!K82`H25-/+3@X-3DM-RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'
M<F5E;FQA;F0B"FUS9W-T<B`B1W)E;FQA;F1I:F$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS
M9VED(")'<F5N861A(@IM<V=S='(@(D=R96YA9&$B"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C$W.0IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T
M<B`B1W)U<&GX(&%D;6EN:7-T<F%V:6UA<R(*"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"YP:'`Z-3D@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C$V.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS
M9W-T<B`B1W)U<.MS('9A<F1A<R!T=7)I(&+[=&D@;F5T=?#H:6%S(@H*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,P-PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G
M<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S
M='(@(D%U=&A?;&1A<#H@<W5K=7)T:2!V87)T;W1O:N`@)7,@;F5P879Y:V\N
M(%-E<G9E<FEO('!R86YE\&EM87,Z("(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HQ,3@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C$R-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B
M;&4@=&\@9&5L971E(&=R;W5P("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@871N
M875J:6YT:2!V87)T;W1O:N`@)7,@;F5P879Y:V\B"@HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S,X(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HS-SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D=R
M;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,B"FUS9W-T<B`B
M075T:%]L9&%P.B!A=&YA=6II;G1I('9A<G1O=&]JX"`E<R!N97!A=GEK;R(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S$T(&QI8B]";&]C
M:R]G;V]G;&4N<&AP.C,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3<W"FUS9VED(")'<F]U<',B"FUS9W-T<B`B1W)U<.MS(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.CDV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-@IM<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R(")'=F%D96QU<.LB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.CDW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-PIM<V=I9"`B1W5A;2(*;7-G<W1R(")'=6%M82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<W"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B1W9A=&5M86QA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB
M"FUS9W-T<B`B1V5R;G-I<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,C(V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*;7-G:60@
M(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(E-V9>AI^"!T96ESZW,B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<P"FUS9VED(")'=65S=&)O
M;VLB"FUS9W-T<B`B4W9EZ&GX(&MN>6=A(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDY"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B
M1W5I;F5A(@IM<V=S='(@(D=V:6[K:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@
M(D=U:6YE82U":7-S874B"FUS9W-T<B`B0FES<V%U+4=V:6[K:F$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S@*;7-G:60@(D=U>6%N82(*;7-G<W1R(")'86IA;F$B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-C`*;7-G:60@(DA434PB"FUS9W-T
M<B`B2%1-3"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#4*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S
M97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R(")(
M5$U,07)E82!N96=A;&D@:?!T<FEN=&D@<&%S:W5T:6[K<R!C96SK<R!E:6QU
M=.MJ92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@V"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S
M('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@
M(DA434Q!<F5A(&YE9V%L:2!I\')I;G1I('!A<VMU=&EN:6\@<W1U;'!E;&EO
M(&QE;G1E;.MJ92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R
M969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S
M='(@(DA434Q!<F5A(&YE9V%L:2!I\'1R:6YT:2!P87-K=71I;NMS(&5I;'5T
MZW,@;&5N=&5LZVIE+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP
M:'`Z,34W"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B4F5I:V%L:6YG82!(5%10(&%U=&5N=&EF:6MA8VEJ82XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#`*;7-G:60@(DAA:71I(@IM<V=S='(@(DAA:71I<R(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S
M:"U!;&=O<FET:&TB"FUS9W-T<B`B2&%S:"U!;&=O<FET;6%S(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA
M>F4B"FUS9W-T<B`B36EG;&$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HY,3D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,@IM<V=I9"`B2&5A
M9&5R(@IM<V=S='(@(D%N=')A\'3K(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B2&5A9&5R
M<R(*;7-G<W1R(")!;G1R8?!TZR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&5A
M<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(DAE<F1O
M('-A;&$@:7(@36%K9&]N86QD;R!S86QO<R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"B,L(&9U>GIY"FUS9VED(")(96%V
M>2!4+5-T;W)M(@IM<V=S='(@(E0M875D<F$B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X-@IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S
M='(@(DAE8G)A:O@@*$E33RTX.#4Y+3@M22DB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T"FUS9VED(")(96EG
M:'0B"FUS9W-T<B`B075K\'1I<R(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92](96QP+G!H<#HQ-SD@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP
M.C$X-@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ-R!T96UP;&%T97,O
M:&5L<"]I;F1E>"YI;F,Z,PIM<V=I9"`B2&5L<"(*;7-G<W1R(")086=A;&)A
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`B4F5D86MT;W)I
M875S(&YA=61O:FEM;W-I('!A9V%L8F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,S<Q"FUS9VED(")(96QP97(B"FUS9W-T<B`B4&%G86QB:6YI
M;FMA<R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B2&5M:7-P
M:&5R92(*;7-G<W1R(")(96UI<V9E<F$B"@HC.B!T96UP;&%T97,O9&%T82]T
M<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,`IM
M<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G
M<W1R("+0=&%I(.AI82!Y<F$@9F%I;&\@<')A9/YI83HB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.0IM<V=I9"`B2&EG:"(*
M;7-G<W1R(")3=F%R8G4B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC
M.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C4*;7-G:60@
M(DAO7VUE(@IM<V=S='(@(E]0;W)T86QA<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G
M:60@(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I(@IM<V=S='(@(M!V
M96YT87-I<R!3;W-T87,@*%9A=&EK86YO('9A;'-T:6IA*2(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,34S-0IM<V=I9"`B2&]M92(*;7-G<W1R
M(")0;W)T86QA<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(DYA;?@@
M861R97-A<R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-`HC+"!F=7IZ
M>0IM<V=I9"`B2&]M92!$:7)E8W1O<GDB"FUS9W-T<B`B2V%T86QO9V%S(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM
M<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R(").86WX('1E;&5F;VYA<R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW.0IM<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`B2&]N9/MR87,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N9R(*;7-G<W1R(")(;VYK
M;VYG87,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C4*;7-G:60@
M(DAO<F1E(@IM<V=S='(@(E!O<G1A;&%S(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HT-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G
M92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@;F5T96ES:6YG:2`E<R!834P@
M9'5O;65N>7,@_FEN=73K:F4@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C(Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B
M2&]R9&4O2V]L86(Z(&]B:F5K=&\@)7,@;F5A=&ET:6YK82!J;VMI82#^:6YU
M=.LB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0S-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@
M)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@
M;V)J96MT;R!T:7!A<R`E<R!N97)A<W1A<R#^:6YU=.MJ92`E<R(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(U,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@7"(E
M<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B`E<R!<(B5S7"(@<^MK;6EN86D@
M:?!T<FEN=&$B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(R,PIM
M<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q
M=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B2&]R
M9&4O2V]L86(Z(&EN=&5G<F%C:6IO<R!V87)I:VQI=6MU:2!R96EK86QI;F=A
M<R`G9&]M>&UL)R!02%`@;6]D=6QI<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z-3`S"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S
M(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!N97!A=GEK;R!S=6MU<G1I(&YA=6IO
M(%A-3"!M963^:6\@;V)J96MT=6D@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C$R-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(
M;W)D92]+;VQA8CH@;F5P879Y:V\@:?!T<FEN=&D@)7,@7"(E<UPB.B`E<R(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#<T"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-
M12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R(")(;W)D92]+
M;VQA8CH@;F5P879Y:V\@9V%U=&D@34E-12!)1"!D86QI86D@)7,@=&EP;R(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$Y,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E
M("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(&YE<&%V>6MO
M('-U<VEN8VAR;VYI>G5O=&D@)7,@7"(E<UPB.B`E<R(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z,3,S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B
M"FUS9W-T<B`B2&]R9&4O2V]L86(Z(&YE<&%V>6MO('-U<VEN8VAR;VYI>G5O
M=&D@96QE;65N=/@Z("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO
M=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!N9?YI;F]M
M87,@96QE;65N=&%S(%PB)7-<(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@4G5L92(*
M;7-G<W1R(")(;W)I>F]N=&%L:2!L:6YI:F$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L
M('!A9&1I;F<B"FUS9W-T<B`B2&]R:7IO;G1A;'5S('1A<G!A<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@
M(DAO<FEZ;VYT86PZ(@IM<V=S='(@(DAO<FEZ;VYT86QI86DZ(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q
M"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A
M*2(*;7-G<W1R(")+86EP(.AI82!P871E:V]T93\@*%!R86YE\&MI=&4A*2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@
M=&\@;65R9V4_(@IM<V=S='(@(DMI96L@<W1U;'!E;&GX(&YO<FET92!S=6IU
M;F=T:3\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR,0IM<V=I
M9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_(@IM<V=S
M='(@(DMI96L@;&%U:_@@*'-T=6QP96QI^"D@=&5N('ER83\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS
M9VED(")(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*
M;7-G<W1R(")+:65K(&5I;'7H:?@@;F]R:71E('-U:G5N9W1I/R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,S`*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(D1RZV=N=6UA<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3D*;7-G:60@(DAU
M;6ED:71Y.B`B"FUS9W-T<B`B1'+K9VYU;6%S.B`B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R(")*=6UO
M<F5S:V]S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(=6YG87)Y(@IM<V=S='(@
M(E9E;F=R:6IA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z
M,3<R(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@
M)7,B"FUS9W-T<B`B3F5P879Y:V\@<W5K=7)T:2!)34%0('!A\'1O(&3K_G5T
MZW,Z("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C$T
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR.34*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B
M"FUS9W-T<B`B3F5P879Y:V\@:?!T<FEN=&D@24U!4"!P8?!T;R!DZ_YU=.MS
M.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W.2!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C0R"B,L('!H<"UF;W)M
M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z
M("5S(@IM<V=S='(@(DYE<&%V>6MO(&YU<W1A='ET:2!)34%0('!A\'1O(&3K
M_G5TZW,@9'ED_FEO.B`E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$S,38*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`B25`@861R97-A<R(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@
M(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3F5P879Y:V\@
M9V%U=&D@25`@861R97-O+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B
M87-I8RYP:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO
M=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@(DE0(&%D<F5S87,@;F5T96ES:6YG
M86UE($-)1%(@8FQO:V4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W;B!V:6]L
M871I;VXN(@IM<V=S='(@(DE0('7^<F%K:6YT87,N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED
M("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B7\%T97)P=&D@96EL=73F
M('9I<O!U:F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DEC96QA;F0B"FUS9W-T
M<B`B27-L86YD:6IA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-@IM
M<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R(")4:6L@<&EK=&]G<F%M;W,B"@HC
M.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R("(E<R!N=7-T871Y;6%I
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-PIM<V=I9"`B26-O;G,@
M=VET:"!T97AT(@IM<V=S='(@(E!I:W1O9W)A;6]S('-U('1E:W-T=2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3`*;7-G:60@(DED96YT:71Y)W,@
M;F%M93HB"FUS9W-T<B`B07!R8?!O('!A=F%D:6YI;6%S.B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,@HC+"!P:'`M9F]R;6%T
M"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@
M=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(DIE:2!N96=A
M;&ET92!P97)S:V%I='ET:2#P:6\@;&%I\&MO+"`E<RXB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#4U"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E
M(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N
M965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N
M<W!A<F5N8WDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ-S,*;7-G:60@(B(*(DEF('EO=2!S964@=&AI
M<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O
M('5P;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R
M+B(*;7-G<W1R("(B"B)*96EG=2!M871O=&4@\&G@(/YI;G5TYB!V:65T;VH@
M<&%V96EK<VSK;&EO+"!K=7+A(&YO<FET92#A:V5L=&DL('1A:2!*^W/X("(*
M(FYA<O!Y:VSK(&YE9V%L:2!J;R!A='9A:7ID=6]T:2XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*
M;7-G:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(E!A=F5I:W-LZVQI;R!P
M97+^:?MR82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R(")0879E
M:6MS;.ML:6\@55),(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM
M<V=S='(@(E!A=F5I:W-LZVQI;R!54DPZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,R"FUS9VED("))
M;6%G92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B4&%V96EK<VSK;&ES(&GP(&=A
M;&5R:6IO<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y
M.B(*;7-G<W1R(")0879E:6MS;.ML:7,@:?`@9V%L97)I:F]S.B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C$*;7-G:60@(DEM86=E('5P;&]A
M9"(*;7-G<W1R(")0879E:6MS;.ML:6\@X6OK;&EM87,B"@HC.B!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(E9A:7ID
M86DB"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW('1E;7!L871E
M<R]D871A+V1A=&5M87`N:6YC.C<*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHU-"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW"B,L('!H<"UF
M;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("+!:^ML:6UA
M<RP@)60@_FEN9W-N:7,B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN
M8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B
M"FUS9W-T<B`B3&%U:V%S(.%K96QT87,Z("5S(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G
M<W1R("+!:V5L=&D@;&%U:V%I.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2
M;W<@069T97(B"FUS9W-T<B`BP5]T97)P=&D@96EL=73F(&%P8>AI;VIE(@H*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,U"FUS
M9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(DYE
M=&5I<VEN9V%S('9E:6MS;6\@:V]D87,N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*;7-G:60@(DEN8V]R<F5C
M="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(DYE=&5I<VEN
M9V%S('9A<G1O=&]J;R!V87)D87,@:7(O87)B82!S;&%P=&'^;V1I<RXB"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC
M;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A
M:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE
M960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B).96ET96ES:6YG87,@=F%R
M=&]T;VIO('9A<F1A<R!A<F)A(&%L=&5R;F%T>79U<R!E;"X@<&'P=&\@861R
M97-A<RX@0F%N9'EK:71E("(*(F1A<B!K87)TX"!A<F)A('-U<VES:65K:71E
M('-U('-A=F\@861M:6YI<W1R871O<FEU;6D@:F5I9W4@<F5I:V%L:6YG82`B
M"B)T;VQE<V[K('!A9V%L8F$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM
M<V=S='(@(E!A9&ED:6YT:2!A=&ET<F%U:VEMX"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM
M<V=I9"`B26YD:6$B"FUS9W-T<B`B26YD:6IA(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`B26YD:79I
M9'5A;/MS('9A<G1O=&]J86DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DEN9&]N
M97-I82(*;7-G<W1R("));F1O;F5Z:6IA(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B26YF;R(*;7-G<W1R
M("));F9O<FUA8VEJ82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M-3<*;7-G:60@(DEN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%C:6IA(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,S,`HC+"!F=7IZ>0IM
M<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB"FUS9W-T
M<B`B3G5S=&%T>6WX(&[K<F$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,U"FUS9VED("));G-E<G0@0U]O
M;'5M;B!!9G1E<B(*;7-G<W1R("+!=')A=6MT:2!S='5L<&5LX2!?9&7P:6[K
M:F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C`*;7-G:60@(DEN<V5R="!);6%G92(*;7-G<W1R("+!
M=&5R<'1I('!A=F5I:W-LZVSA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P,`IM<V=I9"`B26YS97)T(%1A8FQE(@IM<V=S
M='(@(L%T97)P=&D@;&5N=&5LYB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@(DEN<V5R="!796(@3&EN:R(*
M;7-G<W1R("+!=&5R<'1I(&YU;W)O9.`B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G:60@(DEN<V5R
M="!?0V]L=6UN($)E9F]R92(*;7-G<W1R("+!=&5R<'1I('-T=6QP96SA(%]K
M86ERZVIE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8V"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&%F
M=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("+!=&5R<'1I(&YA=6K@('-T
M=6QP96SA(&5S86UO('-T=6QP96QI;R!D9?!I;NMJ92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I
M9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE
M(@IM<V=S='(@(L%T97)P=&D@;F%U:N`@<W1U;'!E;.$@97-A;6\@<W1U;'!E
M;&EO(&MA:7+K:F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@
M869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(L%T97)P=&D@;F%U:N`@
M96EL=73F(&5S86UO<R!E:6QU=.MS(&%P8>AI;VIE(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED
M("));G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS
M9W-T<B`BP71E<G!T:2!N875JX"!E:6QU=.8@97-A;6]S(&5I;'5TZW,@=FER
M\'5J92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHW,`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R
M('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`BP71E<G!T:2!P87)A9W)A9N`@
M96QE;65N=&\@87!AZ&EO:F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A
M<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("+!=&5R
M<'1I('!A<F%G<F%GX"!E;&5M96YT;R!V:7+P=6IE(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA
M=&4B"FUS9W-T<B`BP71E<G!T:2!A;'1E<FYA='EV^"#P86)L;V[@(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S.0IM<V=I9"`B26YS97)T(&%N(&5M
M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@
M<&%S<W=O<F0Z(@IM<V=S='(@(L%R8?!Y:VET92!E;"X@<&'P=&\@861R97/@
M+"#A(&MU<N$@;F]R:71E(&=A=71I(&YA=6K@('-L87!T8?YO9.$Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M.`IM<V=I9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T<B`BP71E<G!T:2!C
M96SF('!O('1O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU.0IM<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM
M<V=S='(@(L%T97)P=&D@8V5LYB!P<FEE\"!T86DB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED("))
M;G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@(L%T97)P=&D@<W1U;'!E;.$@
M9&7P:6[K:F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8U"FUS9VED("));G-E<G0@8V]L=6UN(&)E9F]R92(*
M;7-G<W1R("+!=&5R<'1I('-T=6QP96SA(&MA:7+K:F4B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS97)T
M(&UE<W-A9V5S(@IM<V=S='(@(L%T97)P=&D@;&%I\&MU<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-0IM
M<V=I9"`B26YS97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R("+!=&5R<'1I
M('!A<F%G<F%FX"!P;R!T;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A<F%G
M<F%P:"!B969O<F4B"FUS9W-T<B`BP71E<G!T:2!P87)A9W)A9N`@<')I9?`@
M=&%I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R("+!
M=&5R<'1I(&5I;'5TYB!P;R!T;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*;7-G:60@(DEN<V5R="!R;W<@
M8F5F;W)E(@IM<V=S='(@(L%T97)P=&D@96EL=73F('!R:67P('1A:2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S`*;7-G:60@(DEN<V5R="!T:&4@
M<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS
M9W-T<B`BP7)A\'EK:71E(')E:6MI86W@(&%T<V%K>6W@(.$@:VQA=7-I;>`@
M=FER\'5J93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(V"FUS9VED("));G-E<G0O36]D:69Y($EM86=E(@IM<V=S='(@
M(L%T97)P=&DO<F5D86=U;W1I('!A=F5I:W-LZVSA(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T
M+TUO9&EF>2!,:6YK(@IM<V=S='(@(L%T97)P=&DO4F5D86=U;W1I(&YU;W)O
M9.`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8T,PIM<V=I9"`B26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O
M('1H92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B1&ES=')I8G5C:6IO
M<R!SX')A\'5I(&YU<VGX<W1I(&YE=?YT96YK82!K<F5D:71O+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS
M9VED("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R(").977^=&5N:V$@
M:W)E9&ET;RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<U"FUS
M9VED("));G1E9V5R(@IM<V=S='(@(E-K86GH:75S(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3$S,PIM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S
M='(@(E-K86GH:?@@<^!R8?!A<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI9"!51$@N
M("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B3F5T96ES:6YG87,@541(
M+B`H57-E<B!$871A($AE861E<BDN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+WII<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]Z:7`N<&AP.C(P,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M
M<')E<W,O>FEP+G!H<#HR,3`*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@6DE0
M(&1A=&$B"FUS9W-T<B`B3F5T96ES:6YG:2!U;FEK;V1O(&1U;VUE;GES+B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@
M87!P;&EC871I;VXN(@IM<V=S='(@(DYE=&5I<VEN9V%S(&UO9'5L:7,N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$R"FUS9VED("));G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R(").971E:7-I
M;F=A<R!)1"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#@W(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-3@*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C(S,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,CDY"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<*;7-G
M:60@(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@(L%V97-T:2!N
M971E:7-I;F=I(&1U;VUE;GES+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,`IM<V=I9"`B26YV86QI9"!D97-T
M:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R(").971E:7-I;F=A<R!A9')E<V%S
M+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C@Q
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P,`HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR,C`*;7-G
M:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B3F5T96ES:6YG87,@
M9F%I;&\@9F]R;6%T87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3<W"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*
M;7-G<W1R(").971E:7-I;F=A<R!M;V1U;&ES+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-S$*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@
M;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(DYE=&5I<VEN9V%S(&UO9'5L
M:7,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R(").
M971E:7-I;F=A<R!M<V=?='EP92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*;7-G:60@(DEN=F%L:60@;W(@
M;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(DYE=&5I<VEN9V%S(&%R8F$@;NMR
M82!A<&E?:60N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R
M86UE=&5R<RXB"FUS9W-T<B`B4&%R86UE=')A:2!N971E:7-I;F=I(&%R8F$@
M:O@@;NMR82XB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z,C<*;7-G
M:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(DYE=&5I
M<VEN9V]S('!A=F5L9&EM;W,@=&5I<^MS+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-S,*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@<&%R
M=&YE<B!I9"XB"FUS9W-T<B`B3F5T96ES:6YG;W,@<&%V96QD:6UO<R!T96ES
MZW,N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-0HC+"!F
M=7IZ>0IM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O9&4N(@IM<V=S='(@(DYE
M=&5I<VEN9V%S('!R;W1O:V]L87,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED("));G9A;&ED('!R
M;W1O8V]L+B(*;7-G<W1R(").971E:7-I;F=A<R!P<F]T;VMO;&%S+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HW,2!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C@P"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM
M<V=S='(@(DYE=&5I<VEN9V%S(&=A=NMJ87,Z("<E<R<B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C$P-S8@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HQ,C8R"FUS9VED("));G9A;&ED('-H87)E(&]B:F5C="(*;7-G<W1R
M(").971E:7-I;F=A<R!O8FIE:W1A<R(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B26YV86QI9"!S
M;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B3F5T96ES:6YG87,@<VEU;G3K:F\@
M861R97-A<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*
M;7-G<W1R(").971E:7-I;F=I('5N:6MO9&\@9'5O;65N>7,N(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U-PIM<V=I9"`B26YV96YT;W)Y(@IM
M<V=S='(@(DEN=F5N=&]R:75S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C8W.0HC+"!F=7IZ>0IM<V=I9"`B26YV97)T('-E
M;&5C=&EO;B(*;7-G<W1R(")097)K96QT:2!P87-I<FEN:VEMX"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,@IM<V=I9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G
M<W1R("))<VQA;6GP:V$@27)A;F\@4F5S<'5B;&EK82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,0IM<V=I9"`B27)A<2(*;7-G<W1R("))<F%K87,B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*
M;7-G:60@(DER96QA;F0B"FUS9W-T<B`B06ER:6IA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@;V8@36%N(@IM<V=S
M='(@(DUE;F\@<V%L82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(T"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R
M("))>F]L:75O=&]S(%0M875D<F]S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))
M<W)A96PB"FUS9W-T<B`B27IR865L:7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8R-0IM<V=I9"`B27-S=65R(@IM<V=S='(@(DGP
M9&%VZVIA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(DMU<G-Y=F%S(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@R"FUS9VED("))=&%L>2(*;7-G<W1R("))=&%L:6IA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@R"FUS9VED(")*86UA:6-A(@IM<V=S='(@(DIA;6%I:V$B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Q"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,SD*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I
M9"`B2F%N=6%R>2(*;7-G<W1R(")3875S:7,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G
M:60@(DIA<&%N(@IM<V=S='(@(DIA<&]N:6IA(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#<*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS
M9W-T<B`B2F%P;VYI\&MA("A)4T\M,C`R,BU*4"DB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C,Q,`IM<V=I9"`B(@HB2F%V87-C<FEP="!H87,@
M8F5E;B!D:7-A8FQE9"!O;B!Y;W5R(&)R;W=S97(@86YD('1H:7,@<&%G92!M
M87D@;F]T(&)E("(*(F1I<W!L87EI;F<@8V]R<F5C=&QY+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,@IM<V=I9"`B2F5R
M<V5Y(@IM<V=S='(@(D3^97)S:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIO
M<F1A;B(*;7-G<W1R(")*;W)D86YI:F$B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R("),
M:65P82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C<P"FUS9VED(")*=6YE(@IM<V=S='(@(D)I<OYE;&ES(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I
M9"`B2G5S=&EF>2(*;7-G<W1R(")0:6QN86DB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S
M=&EF>2!#96YT97(B"FUS9W-T<B`B3'EG:75O=&D@8V5N=')E(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0P
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3<*
M;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R("),>6=U;W1I('!I;&YA:2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$T"FUS9VED(")*=7-T:69Y($QE9G0B"FUS9W-T<B`B3'EG:75O=&D@
M:V%I<NMJ92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$V"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@
M(DQY9VEU;W1I(&1E\&ENZVIE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+87IA
M:VAS=&%N(@IM<V=S='(@(DMA>F%K<W1A;F%S(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(V-`IM<V=I9"`B2V5E<"!O<FEG
M:6YA;#\B"FUS9W-T<B`B2?!S875G;W1I(&]R:6=I;F%LX#\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#,*;7-G:60@(DME;GEA(@IM<V=S='(@(DME;FEJ82(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E
M<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3F5P879Y
M:V\@<')I<VEJ=6YG=&D@<')I92!+97)B97)O<R!S97)V97)I;RXB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B:65S
M(@IM<V=S='(@(D)R86YD=6]L:6\@;F%U:F]K86DB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO;B(*
M;7-G<W1R(")286MT;R!K^W)I;6%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T
M<B`B4F%K=&\@871S<&%U9&%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N9W1H(@IM<V=S='(@(E)A:W1O
M(&EL9VES(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q
M"FUS9VED(")+97D@5'EP92(*;7-G<W1R(")286MT;R!T:7!A<R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DX"FUS9VED(")+97D@
M57-A9V4B"FUS9W-T<B`B4F%K=&\@<&%N875D;VII;6%S(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S0P"FUS9VED(")+97D@86QR96%D
M>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(E)A
M:W1A<R!J874@>7)A('9I9?#X:O@@<F%K=/@@<V5R=F5R>6IE+B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G<W1R(")6
M86EK86DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(DMI<FEB871I(@IM<V=S='(@
M(DMI<FEB871I<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C
M<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B1&5M;VMR871I
M;NL@2V]RZVIO<R!,:6%U9&EE<R!297-P=6)L:6MA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U
M"FUS9VED(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B2V]RZVIO<R!2
M97-P=6)L:6MA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@
M(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R(")+;W+K:FEE=&GP:V$@*$550RU+
M4BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R(")+=79E
M:71A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R
M(")+:7)G:7II:F$B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*
M;7-G:60@(DQA7WEO=70B"FUS9W-T<B`B7TGP9.MS='EM87,B"@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S"FUS9VED("),86YG=6%G92(*;7-G
M<W1R(")+86QB82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&%O(%!E;W!L92=S
M($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T<B`B3&%O<V\@1&5M;VMR871I
M;NL@3&EA=61I97,@4F5S<'5B;&EK82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HQ-CD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R(")!;G1R82!P=7/K(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<V"B,L(&9U>GIY"FUS9VED("),
M87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R(")086ME:7-T:2!S;&%P=&'^
M;V3A(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@V(&QI8B]";&]C:R]M;V]N
M+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@(E!A<VMU=&EN
M:7,@:V5T=FER=&ES(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3$*;7-G
M:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`B071N875J:6YT83HB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`B4&%S:W5T:6YI<R!P<FES:6IU
M;F=I;6%S.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<R,0HC
M+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM
M<V=S='(@(E!A<VMU=&EN:7,@<')I<VEJ=6YG:6UA<SH@)7,@:?`@861R97-O
M("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$V"FUS9VED("),
M87-T(&QO9VEN.B!.979E<B(*;7-G<W1R(")0<FES:6IU;F?K=&4@<&ER;>`@
M:V%R=.`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQA='9I82(*;7-G<W1R("),
M871V:6IA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED("),
M87<B"FUS9W-T<B`B5&5I<^LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*;7-G:60@(DQA>6]U="(*;7-G<W1R
M("))\&3K<W1Y;6%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E
M<B(*;7-G<W1R(")*96EG=2!N96YO<FET92!N96YA=61O=&D@:W)A\'3X+"!P
M86QI:VET92!T=?#H:>`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQE8F%N;VXB
M"FUS9W-T<B`B3&EB86YA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B3&5F="(*;7-G<W1R(")+
M86ERZVIE(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q.0IM<V=I
M9"`B3&5F="!H96%D97(B"FUS9W-T<B`B2V%I<FEO:FD@86YT<F'P=.LB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$U"FUS9VED("),969T('9A
M;'5E<R(*;7-G<W1R(")+86ER:6]S:6]S(')E:6OP;>MS(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@X"FUS9VED("),97-O=&AO(@IM<V=S='(@(DQE<V]T87,B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(DQE
M=F5L(@IM<V=S='(@(DUE:6SK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:6)E
M<FEA(@IM<V=S='(@(DQI8F5R:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),
M:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(DQI8FEJ;W,@07)A8O@@
M16UY<F%T86DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI96-H=&5N<W1E:6XB
M"FUS9W-T<B`B3&EC:'1E;O!T96EN87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM<V=I9"`B3&EG:'0@1')I>GIL92(*
M;7-G<W1R(")3;75L:W5S(&QI971U<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(V"FUS9VED("),:6=H="!286EN(@IM<V=S
M='(@(DYE9&ED96QI<R!L:65T=7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*
M;7-G<W1R(").961I9&5L:7,@;&EE='5S(')Y=&4B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I
M;B!,871E(@IM<V=S='(@(DYE9&ED96QI<R!L:65T=7,@=F%K87)E(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G:60@
M(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(DYE9&ED96SK(&QI^W1I<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P"FUS
M9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G<W1R(").961I9&5L
M:7,@;&EE='5S('-U('!E<FO[;FEJ82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H="!3;F]W(@IM<V=S
M='(@(DYE9&ED96QI<R!S;FEE9V%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R
M(@IM<V=S='(@(DYE9&ED96SK(/!L87!D<FEB82(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B3&EM97)I
M:V%S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q-`IM<V=I9"`B
M3&EN:R(*;7-G<W1R(").=6]R;V1A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O
M:6YT<R!T;SHB"FUS9W-T<B`B3G5O<F]D82#A.B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$X-S4*;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D9')E
M<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T
M<B`B4&%D87)Y=&D@96PN('!A\'1O(&%D<F5SX"!N=6]R;V1A(.$@;&%I\&MO
M(')A\'EM;R!P=7-L87#A(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I
M;'1E<B]H=&UL,G1E>'0N<&AP.C$X,PIM<V=I9"`B3&EN:W,B"FUS9W-T<B`B
M3G5O<F]D;W,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@
M(DQI;G5X($-O;VMI92(*;7-G<W1R("),:6YU>"!L86EMZW,@_FEN=73K<R(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS
M9VED("),:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B
M4F]D>71I("T@=F%R=&]T;VIA<R!G86QI(&UA='ET:2!K871A;&]G;R!T=7)I
M;N$B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,S"FUS9VED("),:7-T($1A
M=&%B87-E<R(*;7-G<W1R(")2;V1Y=&D@9'5O;65N^"!B87II^"!SX')A\.`B
M"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,`IM<V=I9"`B3&ES="!(
M96QP(%1O<&EC<R(*;7-G<W1R(")2;V1Y=&D@<&%G86QB;W,@=&5M87,B"@HC
M.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,R"FUS9VED("),:7-T(%1A8FQE<R(*
M;7-G<W1R(")2;V1Y=&D@;&5N=&5L:?@@<^!R8?#@(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12](96%D97)S+G!H<#HU.30*;7-G:60@(DQI<W0M07)C:&EV
M92(*;7-G<W1R(")+;VYF97)E;F-I:F]S(&%R8VAY=F%S(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.#D*;7-G:60@(DQI<W0M2&5L
M<"(*;7-G<W1R(")+;VYF97)E;F-I:F]S('!A9V%L8F$B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U)9"(*
M;7-G<W1R(")+;VYF97)E;F-I:F]S($E$(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12](96%D97)S+G!H<#HU.3(*;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T
M<B`B2V]N9F5R96YC:6IO<R!S879I;FEN:V%S(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12](96%D97)S+G!H<#HU.3,*;7-G:60@(DQI<W0M4&]S="(*;7-G
M<W1R(")28?!Y=&D@X2!K;VYF97)E;F-I:N`B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TAE861E<G,N<&AP.C4Y,0IM<V=I9"`B3&ES="U3=6)S8W)I8F4B
M"FUS9W-T<B`B4')I<VEJ=6YG=&D@<')I92!K;VYF97)E;F-I:F]S(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3`*;7-G:60@(DQI
M<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`B071S:6IU;F=T:2!N=6\@:V]N9F5R
M96YC:6IO<R(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S
M(@IM<V=S='(@(E9A<G1O=&]J^"!SX')A\&%S('7^9')A=7-T87,N(@H*(SH@
M861M:6XO<V5S<VEO;G,N<&AP.C,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED("),:7-T:6YG('5S97)S(&9A:6QE9#H@)7,B"FUS9W-T<B`B5F%R=&]T
M;VKX('/@<F'P87,@=?YD<F%U<W1A<RXB"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES
M86)L960N(@IM<V=S='(@(E9A<G1O=&]J^"!SX')A\&%S('7^9')A=7-T87,N
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),:71E<F%T
M=7)E(@IM<V=S='(@(DQI=&5R873[<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@
M(DQI=&AU86YI82(*;7-G<W1R("),:65T=79A(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:6UA9V5S+G!H<#HX,PIM<V=I9"`B3&]A9&EN9RXN
M+B(*;7-G<W1R(")+<F%U;F$N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C$Q"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B5FEE
M=&EN:7,@;&%I:V%S.B`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*
M;7-G:60@(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R("),;VMA;.L@:7(@;&%I
M:V%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S$@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8T"B,Z(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP.C8U"FUS9VED("),
M;V-A=&EO;B(*;7-G<W1R(")6:65T82(*"B,Z(&QO9VEN+G!H<#HQ-S(@<V5R
M=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y,2!T96UP;&%T97,O;&]G:6XO
M;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*;7-G:60@(DQO9R!I;B(*
M;7-G<W1R(")0<FES:6IU;F=T:2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO
M;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,3@U"FUS9VED("),;V<@;W5T(@IM<V=S='(@(D%T<VEJ=6YG=&DB"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(DQO9VEN
M(@IM<V=S='(@(E!R:7-I:G5N9W1I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$P-PIM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B4')I<VEJ=6YG
M:6UO(&1A<F)A:2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY-@IM
M<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P
M87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B(@HB
M4')I<VEJ=6YG=&D@;F5P879Y:V\N($YE=&5I<VEN9V%S($K[<_@@;G5R;V1Y
M=&%S('9A<G1O=&]J;R!V87)D87,@:7(O87(@(@HB<VQA<'1A_F]D:7,N(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DR"FUS9VED("),;V=I;B!F
M86EL960N(@IM<V=S='(@(E!R:7-I:G5N9W1I(&YE<&%V>6MO+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C4*;7-G:60@(DQO;F<@=&5X="(*
M;7-G<W1R("));&=A<R!T96MS=&%S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0X"FUS9VED("),;W9E(@IM<V=S='(@(DUE:6SK(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(DQO=R(*
M;7-G<W1R(").97-V87)B=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K
M(&QE='1E<G,B"FUS9W-T<B`B36'^;W-I;W,@9W)A:6MI\&MO<R!R86EDZW,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L971T97)S(@IM<V=S='(@
M(DUA_F]S:6]S(&QO='EN:?!K;W,@<F%I9.MS(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B
M3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R(")-8?YI96II(')O;>MN:?!K
M:2!S:V%IZ&EA:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3'5X96UB;W5R9R(*
M;7-G<W1R("),:75K<V5M8G5R9V%S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P,`HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#,X('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P
M"FUS9VED(")-32(*;7-G<W1R(")-32(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR.#$*;7-G:60@(DU/5$0B"FUS9W-T<B`B34]41"(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,V"FUS9VED(")-
M4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@
M(E!R:6MA8FEN=&%M92!-4RU43D5&(&9A:6QE(&[K<F$@9'5O;>MN^"XB"@HC
M.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B35-'(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDR"FUS9VED(")-86-A;R(*;7-G<W1R(")-86MA;R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,0IM<V=I9"`B36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUA:V5D;VYI:F$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3`*;7-G:60@(DUA9&%G87-C87(B"FUS9W-T<B`B36%D86=A<VMA<F%S(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"FUS9VED(")-86=I8R(*;7-G
M<W1R(")-86=I:F$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#$*
M;7-G:60@(DUA:6PB"FUS9W-T<B`B4&'P=&%S(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C4R,@IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R(")0
M8?!T;R!V86QD>6UA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN+B(*
M;7-G<W1R(")3=6MU<G1I(%]N=6]R;V3@+BXN(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS
M9VED(")-86QA=VDB"FUS9W-T<B`B36%L879I<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM
M<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B36%L86EZ:6IA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDT"FUS9VED(")-86QD:79E<R(*;7-G<W1R(")-86QD>79A:2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,@IM<V=I9"`B36%L:2(*;7-G<W1R(")-86QI<R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-`IM<V=I9"`B36%L=&$B"FUS9W-T<B`B36%L=&$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.3$*;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES="!O
M9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N
M9"!C;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N
M(@IM<V=S='(@(B(*(DMA=&5G;W)I:O@@<^!R8?!O+"!K=7)I;VUS('!R:7-K
M:7)I86UI(&]B:F5K=&%I+"!I<B!S=2!J;VUI<R!S=7-I:G5S:?@@(@HB<W!A
M;';X(&ME:71I;6%S+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,34S"FUS9VED(")-87`R-"!M87`B"FUS9W-T<B`B36%P
M,C0@_F5MZVQA<&ES(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$P.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$Q-C@*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R(")-
M87!1=65S="#^96WK;&%P:7,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,PHC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Q"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*;7-G
M:60@(DUA<F-H(@IM<V=S='(@(DMO=F%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0IM<V=I9"`B36%R9VEN
M(@IM<V=S='(@(E!A<F'P=.LB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N
M(&9L86=S(@IM<V=S='(@(E!A_GEMZW1I(&MA:7`@<VMA:71Y='5S+VYE<VMA
M:71Y='5S(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O
M<G1A;G0O06YS=V5R960I(@IM<V=S='(@(E!A_GEMZW1I(&MI=&%I<R!A=')I
M8G5T86ES("AP=GHN('-V87)B=2]A='-A:WET82DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*
M;7-G:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`B36%R\&%L;R!S86QO
M<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R(")-
M87)T:6YI:V$B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM
M<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(E-U:G5N9W1I(&QA=6MA
M:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%U<FET86YI82(*;7-G<W1R(")-
M875R:71A;FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM
M<V=S='(@(DUA=7)I8VEJ=7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R
M961I="XB"FUS9W-T<B`B36%K<VEM86QU<R!K<F5D:71A<RXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G
M:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G<W1R(")-86MS
M:6UA;'5S(/YI;G7H:?@@9&%L:?@@:VEE:VES(&GP96EK=F]T87,N(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@(DUA>"!T96UP(&QA<W0@
M,C0@:&]U<G,Z("(*;7-G<W1R(")-86MS+B!T96UP+B!P87-K+B`R-"!V86PZ
M("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDX"FUS9VED(")-87@@=&5M
M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R(")-86MS+B!T96UP+B!P87-K+B`V
M('9A;#H@(@H*(SH@;&EB+V%P:2YP:'`Z.#8*;7-G:60@(DUA>&EM=6T@3G5M
M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.#DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M,3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S.0IM<V=I9"`B36%X
M:6UU;2!L96YG=&@B"FUS9W-T<B`B36%K<VEM86QU<R!I;&=I<R(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-
M87DB"FUS9W-T<B`B1V5G=?[K(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B36%Y
M;W1T92(*;7-G<W1R(")-;VIO=.LB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-3`*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(DUE9&EC:6YA(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@IM<V=I9"`B365M
M8F5R<R(*;7-G<W1R(").87)I86DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S<X"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S='(@(DUE;FEU(')E_FEM
M87,Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T<B`B4W5J=6YG
M=&D@8V5L97,B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*;7-G<W1R("+>:6YU
M=.LB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM
M<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H
M92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I
M960N(@IM<V=S='(@(B(*(DQA:?!K87,@<&%V:7)T:6YT87,L('1AZ&EA=2!N
M97!A='9I<G1I;G1A<R!P87-I<F'P:75S:6\@87-M96YS('-E<G1I9FEK871A
M<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,3`*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS9W-T<B`BWFEN
M=73K(&YE:?!S:?AS=&$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V,`IM<V=I9"`B365S<V%G
M92!T>7!E(@IM<V=S='(@(MYI;G5TZW,@=&EP87,B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E871H97(B"FUS9W-T<B`B3W)O
M('-A;'EG;W,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W"FUS9VED(")-
M971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")/<F\@<^!L>6?X
M(&)L;VMO(&[K<F$N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3(*;7-G
M:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V
M92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@
M(D]R;R!SX&QY9_@@8FQO:V\@;NMR82X@061M:6YI<W1R871O<FEU:2!I\'-I
M^'-T87,@9&5T86QU<R!A<')A\'EM87,N(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$V-0IM<V=I9"`B365T87)$0B!I<R!N;W0@8V]N;F5C
M=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C8W(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R(")-971O9&%S(@H*(SH@9G)A
M;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HX,2!F<F%M97=O<FLO4E!#+U)0
M0R]S;V%P+G!H<#HQ,3<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DUE
M=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`B365T;V1A<R`G
M)7,G(&YE87!R8?!Y=&%S(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP
M:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D
M+B!#86QL960@;65T:&]D.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-0IM
M<V=I9"`B365T<FEC(@IM<V=S='(@(DUA=&%I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS
M9VED(")-97AI8V\B"FUS9W-T<B`B365K<VEK82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS
M9VED(")-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@
M(DUI:W)O;F5Z:6IO<R!&961E<F%C:6[K<R!686QS=&EJ;W,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S8*;7-G
M:60@(DUI9&1L92(*;7-G<W1R(")6:61U<GEJ92(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B
M"FUS9W-T<B`B34E-12!T:7!A<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S$P"FUS9VED(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B
M36EN+B!T96UP+B!P87-K+B`R-"!V86PZ("(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S`R"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G
M<W1R(")-:6XN('1E;7`N('!A<VLN(#8@:&]U<G,Z("(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#,Y"FUS9VED(")-:6YI;75M('!A<W-W
M;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S0*;7-G:60@
M(DUI<G)O<B(*;7-G<W1R(")!='-P:6YD>7,B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B2VET
M;W,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8W,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS-#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q
M=65S="XB"FUS9W-T<B`B3F5R87-T87,@4$5!4B!(5%107U)E<75E<W0@<&%K
M971A<RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U"FUS9VED("(B
M"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E
M(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO
M;BXB"FUS9W-T<B`B(@HB3G5S=&%T>6WX(&[K<F$N($IE:6=U(&YO<FET92!N
M875D;W1I(/#A(&UO9'5LX2P@='5R:71E(&KA('-U:V]N9FEG^W)U;W1I+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R(").ZW)A
M(/YI;G5TZW,@240N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F
M;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@
M4$5!4B!P86-K86=E($UA:6PN(@IM<V=S='(@(DYE<F%S=&%S(')E:6MA;&EN
M9V%S(%!%05(@36%I;"!P86ME=&%S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES<VEN9R!S
M97-S:6]N($E$+B(*;7-G<W1R(").ZW)A('-E<VEJ;W,@240N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B
M36\B"FUS9W-T<B`B4&ER;2XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-S0*;7-G:60@(DUO8FEL92!-86EL(@IM<V=S='(@(DUO8FEL=7,@<&'P
M=&%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C@*;7-G:60@(DUO9&5R871E(@IM<V=S='(@(E9I9'5T:6YI<R(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,PHC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C@X"FUS9VED(")-;V1I9FEE9"!$871E
M(@IM<V=S='(@(E)E9&%G879I;6\@9&%T82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D
M:69Y(%523"(*;7-G<W1R(")+96ES=&D@55),(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S,*;7-G:60@(DUO9'5L=7,B"FUS9W-T
M<B`B36]D=6QI<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]L9&]V82P@4F5P
M=6)L:6,@;V8B"FUS9W-T<B`B36]L9&]V;W,@4F5S<'5B;&EK82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,`IM<V=I9"`B36]N86-O(@IM<V=S='(@(DUO;F%K87,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(DUO;F=O;&EJ82(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.30*;7-G:60@(DUO;G1H
M(&%N9"!Y96%R(@IM<V=S='(@(DWK;F5S:6%I(&ER(&UE=&%I(@H*(SH@9G)A
M;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B
M36]N=&AL>2(*;7-G<W1R(")+87,@;>MN97/A(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS
M9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(DUO;G-E<F%T87,B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@
M(DUO;VX@4&AA<V5S(@IM<V=S='(@(DWK;G5L:6\@9F%ZZW,B"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-S(@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z,C4S"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@9FEE;&1S
M(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R(")-
M87)O:V%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S,*;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R(")$875G:6%U<VEA
M(&=I961R82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,T"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@(D1A=6=I875S
M:6$@87!S:6YA=6OF(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S4*;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R(")$875G
M:6%U<VEA('-A=6SK=&$B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HU,#D*;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R(")097)K96QT
M:2#^96UI874B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HU,3,*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R(")097)K96QT:2!K86ER
M:6%U(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$W
M"FUS9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(E!E<FME;'1I(&1E\&EN:6%U
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`U"FUS
M9VED(")-;W9E(%5P(@IM<V=S='(@(E!E<FME;'1I(&%U:_#H:6%U(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`IM<V=I
M9"`B36]V92!D;W=N(@IM<V=S='(@(E!E<FOK;&EM87,@_F5M>6XB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(S"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C0*;7-G:60@
M(DUO=F4@=7`B"FUS9W-T<B`B4&5R:^ML:6UA<R!A=6OP='EN(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDU"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(DUO>F%M8FEK87,B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@T"FUS9VED(")-=6QT
M:2UL979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B2V5L971O(&QY9VGX
M(&GP<VES:VQE:63^:6%N=&ES('/@<F'P87,B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U-0IM<V=I9"`B375L=&EM87`@
M54L@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(R-#(*;7-G:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R(")+96QE
M=&%S('!A<VER:6YK:6WX(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0P,`IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R(")-86YO('/@<VMA:71A
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X"B,L(&9U>GIY"FUS9VED
M(")->2!!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%C:6IA
M(&%P:64@2G5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HU-`IM
M<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(DUA;F\@<&]R=&%L87,B"@HC.B!S
M97)V:6-E<R]P;W)T86PO961I="YP:'`Z,3,V"FUS9VED(")->2!0;W)T86P@
M3&%Y;W5T(@IM<V=S='(@(DUA;F\@<&]R=&%L;R!I\&3K<W1Y;6%S(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S='(@(DUA:6YM87)A<R(*
M"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4W
M"FUS9VED(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B3D4L($Y%4U54
M24Y+52(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,2!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(").
M86UE(@IM<V=S='(@(E9A<F1A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M
M:6)I82(*;7-G<W1R(").86UI8FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B
M3F%U<G4B"FUS9W-T<B`B3F%U<F%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").
M97!A;"(*;7-G<W1R(").97!A;&%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").
M971H97)L86YD<R(*;7-G<W1R(").>61E<FQA;F1A:2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W
M"FUS9VED(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R(").>61E<FQA
M;F3X($%N=&EL86DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B3F5T
M<V-P87!E(&)A>FEN:7,@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@
M55),(@IM<V=S='(@(DYE='-C<&%E('-E<FEF:6MA=&\@873P875K:6UO(%52
M3"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U"FUS
M9VED(").971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(DYE='-C<&%E
M('-E<G1I9FEK871O('1E:7-I^"!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!5
M4DPB"FUS9W-T<B`B3F5T<V-A<&4@871N875J:6YO;6\@55),(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G:60@(DYE='-C
M87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@(DYE='-C87!E(&%T\&%U:VEM
M;R!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X
M-@IM<V=I9"`B3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(DYE
M='-C87!E(%-33"!S97)V97)I;R!V87)D87,B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@8V5R=&EF
M:6-A=&4@8V]M;65N="(*;7-G<W1R(").971S8V%P92!S97)T:69I:V%T;R!A
M<')A\'EM87,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4X,`IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R
M(").971S8V%P92!S97)T:69I:V%T;R!T:7!A<R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR-3$*;7-G:60@(DYE='=O<FLB"FUS9W-T<B`B5&EN
M:VQA<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-2!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS.#8*;7-G:60@(DYE=F5R(@IM<V=S='(@(DYI96MA9&$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B3F%U:F]J
M:2!+86QE9&]N:6IA(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R
M(").875J82!K871E9V]R:6IA(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R
M+T9I;'1E<B]E;6%I;',N<&AP.C@Q"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E
M<B]&:6QT97(O96UA:6QS+G!H<#HX-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT
M97(O1FEL=&5R+V5M86EL<RYP:'`Z.3<*(SH@9G)A;65W;W)K+U1E>'1?1FEL
M=&5R+T9I;'1E<B]E;6%I;',N<&AP.C$P,0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B3F5W($UE<W-A9V4@=&\@)7,B"FUS9W-T<B`B4F'P>71I(&QA
M:?!KX"`H)7,I(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C
M:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED(").
M97<@36]O;B(*;7-G<W1R(").875J87,@;>MN=6QI<R(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R;F%M
M92`H;W!T:6]N86PI(@IM<V=S='(@(DYA=6IA<R!V87)T;W1O:F\@=F%R9&%S
M("AN96+[=&EN87,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(").97<@6F5A;&%N
M9"(*;7-G<W1R(").875J;VII(%IE;&%N9&EJ82(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B3F5W('!A<W-W
M;W)D(@IM<V=S='(@(E-L87!T8?YO9&ES(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]S<6PN<&AP.C(R-PHC+"!P:'`M9F]R;6%T"FUS9VED(").97<@<&%S
M<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU,@HC+"!F=7IZ>0IM<V=I9"`B3F5W
M('!A<W-W;W)D<R!D;VXG="!M871C:"XB"FUS9W-T<B`B4VQA<'1A_F]D_FEA
M:2!T=7)I('-U=&%P=&DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*
M;7-G<W1R(").875J86UE(&QA;F=E("A?8FQA;FLI(@H*(SH@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z-#`@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#D*;7-G:60@(DYE=W,B"FUS9W-T
M<B`B3F%U:FEE;F]S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P
M-0IM<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R(").875J:65N^"!G<G5PZW,B
M"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ-2!T96UP;&%T97,O
M9&%T82]D871E;6%P+FEN8SHT,0HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C$R.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR-0IM<V=I9"`B
M3F5X="(*;7-G<W1R(")396MA;G1I<R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HR-PHC+"!F=7IZ>0IM<V=I9"`B3F5X="`T(%!H87-E<R(*;7-G<W1R(")3
M96MA;G1I(&9A>NLB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C,W,B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W-@IM<V=I9"`B
M3F5X="!O<'1I;VYS(@IM<V=S='(@(E-E:V%N='ES(&YU<W1A='EM86DB"@HC
M.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C$P,PHC+"!F=7IZ>0IM<V=I
M9"`B3F5X=#XB"FUS9W-T<B`B4V5K86YT:7,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G
M:60@(DYI8V%R86=U82(*;7-G<W1R(").:6MA<F%G=F$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.38*;7-G:60@(DYI9V5R(@IM<V=S='(@(DYI9V5R:7,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.38*;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`B3FEG97)I:F$B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S@P"FUS9VED(").:6=H="(*;7-G
M<W1R(").86MT:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYI=64B"FUS9W-T
M<B`B3FEU:NLB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.38S"FUS9VED(").;R(*;7-G<W1R(").92(*"B,Z('1E;7!L871E
M<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM<V=I9"`B3F\@879A:6QA8FQE
M(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BXB
M"FUS9W-T<B`B3F5U_G1E;FMA(&1U;VUE;O@@<VMI<G1U;?@@<&%R;V1Y;75I
M+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z
M,3`U"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)
M4T\@:6UA9V5S+B(*;7-G<W1R(").96YU<F]D>71A('-T<F%T96=I:F$@25-/
M(')A\'EM=6DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").;R!B871C:"!T96UP;&%T92XB"FUS
M9W-T<B`B3NMR82!S=63K=&EN:6\@\&%B;&]N;RXB"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW.2!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HR-#4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z,C8W"FUS9VED(").;R!B;&]C:R!E>&ES=',@870@=&AE(')E
M<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R(").=7)O9'ET;VIE('!O>FEC:6IO
M:F4@8FQO:V\@;NMR82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP
M:'`Z-3`*;7-G:60@(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#
M04P@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYEX79E9.MT92!K86QE;F1O
M<FEA=7,@=F%R9&\@34-!3"!A=71E;G1I9FEK86-I:F]J92XB"@HC.B!A9&UI
M;B]S971U<"]D:69F+G!H<#HU-`IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R
M(")3:VER='5M^"!NZW)A+B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,34V"FUS9VED(").;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@
M=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R("+0:6]S('1E:7/K<R!N96=A;&D@
M='5RZW1I('!O=&5I<VGX+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,38W(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`R"B,Z(&9R86UE
M=V]R:R]5=&EL+U5T:6PN<&AP.C<W,PHC+"!P:'`M9F]R;6%T"FUS9VED(").
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N
M(@IM<V=S='(@(D[K<F$@:6YF;W)M86-I:F]S(&%P:64@)7,@:V]N9FEG^W)A
M8VEJX"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R-`IM<V=I
M9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M($944"!61E,N(@IM<V=S='(@(D[K<F$@:6YF;W)M86-I:F]S(&%P:64@1E10
M(%9&4R!K;VYF:6?[<F%C:6K@+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z-C8Y"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B3NMR82!I;F9O<FUA
M8VEJ;W,@87!I92!344P@5D93(&MO;F9I9_MR86-I:N`N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<Q-PIM<V=I9"`B3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&
M4RXB"FUS9W-T<B`B3NMR82!I;F9O<FUA8VEJ;W,@87!I92!344PM1FEL92!6
M1E,@:V]N9FEG^W)A8VEJX"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO(&-R961I="!L969T
M+B(*;7-G<W1R(")+<F5D:71A<R!I\&5I:W9O=&%S+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED(").
M;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`B3F7A=F5S=&%S(&=A
M=NMJ87,N(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#<W
M"FUS9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(D9A:6QA<R!N96YU
M<VGX<W1A<R(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HW,0HC+"!F=7IZ
M>0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@(B5S(&YE<F%S=&%S
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C@@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(S
M"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(DYE;G5S=&%T
M>71A('9I971O=NLN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$V.0HC+"!F=7IZ>0IM<V=I9"`B3F\@;&]C871I;VX@<')O=FED960N(@IM
M<V=S='(@(DYE;G5S=&%T>71A('9I971O=NLN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*;7-G:60@(DYO(&UE
M<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(DYEX7)A\.MT92#^:6YU=.MS+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,V"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B3F7A<F'P
MZW1E('9A<F1O+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C,W"FUS9VED(").;R!N=6UB97(@<W!E8VEF:65D+B(*
M;7-G<W1R(").9>%R8?#K=&4@;G5M97)I;RXB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.30*;7-G:60@(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G
M<W1R(").97)O9'ET:2#A_F5I9/YI86[H:?@@9G)A>FGX(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYE
MX79E9.MT92!S;&%P=&'^;V3^:6\@2%144"!A=71E;G1I9FEK86-I:F%I+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B3F7A=F5DZW1E('-L87!T8?YO9/YI;R!)34%0(&%U=&5N=&EF
M:6MA8VEJ86DN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW
M,@IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").9>%V963K=&4@<VQA<'1A_F]D_FEO
M($ME<F)E<F]S(&%U=&5N=&EF:6MA8VEJ86DN(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S87-L+G!H<#HW-R!F<F%M97=O<FLO075T:"]!=71H+VQO9VEN
M+G!H<#HX-`HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-S4*;7-G
M:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`B3F7A=F5DZW1E('-L87!T8?YO9/YI;R!,;V=I;B!A
M=71E;G1I9FEK86-I:F%I+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%S
M<W=D+G!H<#HQ,S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!0
M05-35T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYEX79E9.MT92!S;&%P
M=&'^;V3^:6\@4$%34U=$(&%U=&5N=&EF:6MA8VEJ86DN(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]S;6(N<&AP.C@T"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").9>%V
M963K=&4@<VQA<'1A_F]D_FEO(%--0B!A=71E;G1I9FEK86-I:F%I+B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X-@IM<V=I9"`B
M(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H
M92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H
M(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@HB3F7A=F5S=&%S(&ME;&EA<R!I
M:VD@3W!E;E-33"!P86=R:6YD:6YI^"!F86EL^"X@3W!E;E-33"!R96EK86QI
M;F=A(&1A<F)U:2!S=2`B"B)02T-3(#$R(&1U;VUE;FEM:7,N(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N
M9&EN9R!S:6=N=7!S+B(*;7-G<W1R(").97!A='9I<G1I;G3X(')E9VES=')A
M8VEJ^"!NZW)A+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HW-3`*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T
M<B`B3F5N=7)O9'ET82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#,*;7-G:60@(DYO(')U;&5S(@IM<V=S='(@
M(DYE;F%U9&]T:2!S:VER='5K^"(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C0T.0HC+"!F=7IZ>0IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I
M9FEE9"XB"FUS9W-T<B`B3F7A<F'PZW1E(&YU;65R:6\N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`IM<V=I
M9"`B3F\@<VED97,B"FUS9W-T<B`B3NL@=FEE;F]J92!P=7/K:F4B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X,PHC+"!F=7IZ>0IM<V=I9"`B
M3F\@<W5C:"!F:6QE(@IM<V=S='(@(D[K('9I96YO:F4@<'5SZVIE(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$S.`IM<V=I9"`B3F\@=&5M
M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+B(*;7-G<W1R
M(")3<&%R=&EN:6UU:2!NZW)A(&QA:6MI;F]J;R!K871A;&]G;RXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,0HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,0IM<V=I
M9"`B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@
M(E9A<G1O=&]J;R!V87)D87,@:7(O87)B82!S;&%P=&'^;V1I<R!N96YU<VGX
M<W1A<RXB"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T,`IM
M<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B5&5I
M<VEN9_@@6$U,(&1U;VUE;O@@;NMR82(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HY-S$*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.CDX,0HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.3DR"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,#`Y"FUS9VED(").;R!V86QU97,B"FUS9W-T
M<B`B3NMR82!R96EK\&UI^"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M,C`*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG
M=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")+
M;VYF:6?[<F%C:6YI86UE(&9A:6QE(&[K<F$@=F5R<VEJ;W,N(%!E<F=E;F5R
M=6]K:71E(&YU<W1A='EM=7,N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$R.`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R
M871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B2V]N
M9FEG^W)A8VEN:6%M92!F86EL92!NZW)A('9E<G-I:F]S+B!097)G96YE<G5O
M:VET92!N=7-T871Y;75S+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0R-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0U"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E
M;&5C="YI;F,Z.3,*;7-G:60@(DYO;F4B"FUS9W-T<B`B3F5N=7)O9'ET82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*
M;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B3NMR82(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(").;W)D:6,@*$E33RTX
M.#4Y+3$P*2(*;7-G<W1R("+0:6%U<NMS("A)4T\M.#@U.2TQ,"DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM<V=S='(@(DYO<F9O
M;&MO('-A;&]S(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C
M:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G
M<W1R("+0:6%U<FENZR!H96UI<V9E<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$U."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@
M(DYO<G1H97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R("+0:6%U<FENZW,@
M36%R:6IA;O@@<V%L;W,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYO<G=A>2(*
M;7-G<W1R(").;W)V96=I:F$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(DYE('!O
M('1O(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*
M;7-G:60@(DYO="!"969O<F4B"FUS9W-T<B`B3F4@<')I9?`@=&%I(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#`X"FUS9VED(").;W0@82!D
M:7)E8W1O<GDB"FUS9W-T<B`B3F4@:V%T86QO9V%S(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HV,PHC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H
M<#HX,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+G!H<#HY-`HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2YP:'`Z-3D*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B
M3F5R96%L:7IU;W1A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-C@*;7-G:60@(DYO="!S970B"FUS9W-T<B`B3F5N=7)O
M9'ET82(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N
M9&QE<BYP:'`Z,30S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S
M:6]N2&%N9&QE<BYP:'`Z,34X"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE
M<B]397-S:6]N2&%N9&QE<BYP:'`Z,3<S"B,Z(&9R86UE=V]R:R]397-S:6]N
M2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3@W"B,Z(&9R86UE=V]R:R]3
M97-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,T(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HQ.3`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(P
M-2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HR-#@@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(V-0HC.B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,C@Q(&9R86UE=V]R:R]61E,O5D93+G!H<#HR
M.3<*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,Q,B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z,S(Y"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS-C(@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C0R,@HC.B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z-3`Q(&9R86UE=V]R:R]61E,O5D93+G!H<#HU-S`*(SH@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C4X-R!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-C8U"FUS
M9VED(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R(").97!A;&%I:V]M87,N(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T-"!C
M;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`P-0HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3<X"FUS9VED(").;W1E<R(*;7-G<W1R(")5_G)A\&%I(@H*
M(SH@<V5R=FEC97,O;V)R;W=S97(O:6YD97@N<&AP.C,V"FUS9VED(").;W1H
M:6YG('1O(&)R;W=S92P@9V\@8F%C:RXB"FUS9W-T<B`B3NMR82!KX"!P97+^
M:?MRZW1I+"!E:6MI=&4@871G86PN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,0HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S4*;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@
M(DQA<&MR:71I<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-#8*
M;7-G:60@(DYU;6)E<B(*;7-G<W1R(").=6UE<FES(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30R-0IM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E
M<G,B"FUS9W-T<B`B4VEM8F]L:?@@<VMA:>AI=7,B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,S8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T
M,C,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T-2!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R
M(&]F(&-O;'5M;G,B"FUS9W-T<B`B4W1U;'!E;&GX('-K86GH:75S(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-R!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-#(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#,@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G
M:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(D5I;'7H:?@@<VMA:>AI=7,B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8T-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN
M9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B3F7A=F5S=&D@9&ES
M=')I8G5C:6IO<R!SX')A\&\@871N875J:6YI;6\@<VMA:>AI86DN(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8T"FUS9VED
M(")/2R(*;7-G<W1R(")/2R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(D]B:F5C="(*;7-G<W1R(")/8FIE
M:W1A<R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS9VED
M(")/8FIE8W0@0W)E871O<B(*;7-G<W1R(")/8FIE:W1O('-A=FEN:6YK87,B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`T"FUS9VED(")/8W1A
M;"(*;7-G<W1R(")!\'1U;G1A:6YI<R(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,3`*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R(@IM<V=S='(@
M(E-P86QI<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B
M3V9F96YS92!F:6QT97(B"FUS9W-T<B`BWFEA=7)U;6\@9FEL=')A<R(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C8*;7-G:60@(D]F9FEC92(*
M;7-G<W1R(")/9FES87,B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I
M9F9E<F5N="XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C,V"B,L(&9U>GIY"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T
M<B`B4VQA<'1A_F]D:7,B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z-#8*(RP@9G5Z>GD*;7-G:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@8V]R
M<F5C="XB"FUS9W-T<B`B4VQA<'1A_F]D:7,@;F5T96ES:6YG87,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T<B`B3VUA;F%S(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N
M;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S
M='(@(DMA=&%L;V?X(&1A;&EJ:6W@<VD@<&%L86EK;R!T:6L@24U!4"!S97)V
M97)I86DN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDU"FUS9VED(")/
M;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R(")4:6L@X?YE:63^:6%N
MZ&EO<R!F<F%ZZW,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4Q
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S$*;7-G:60@(D]N;'D@;VYE
M(&5M86EL(&%D9')E<W,@86QL;W=E9"XB"FUS9W-T<B`B3&5I9/YI86UA<R!T
M:6L@=FEE;F%S(&5L+B!P8?!T;R!A9')E<V%S+B(*"B,Z('-E<G9I8V5S+W-H
M87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@
M<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@
M;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@HB
M16QE;65N=&\@<V%V:6YI;FMO('1E:7-E<R!G86QI(&ME:7-T:2!T:6L@:F\@
M<V%V:6YI;FMA<R!A<F)A('-I<W1E;6]S("(*(F%D;6EN:7-T<F%T;W)I=7,B
M"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS-0IM<V=I9"`B3W!E;B!I;B!A
M(&YE=R!W:6YD;W<B"FUS9W-T<B`B071I9&%R>71I(&YA=6IA;64@;&%N9V4B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I
M9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M
M('-I9VYE9"!3+TU)344@<&%R="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED
M(")/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D%T
M:61A<GET:2#P:>`@;G5O<F]DX"!N875J86UE(&QA;F=E(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM
M<V=S='(@(D]P<F%C:6[K<R!S:7-T96UO<R(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S:61E8F%R+G!H<#HQ-3$*;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`B3G5S
M=&%T>6UA:2(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS,2!T96UP;&%T97,O
M<')E9G,O87!P+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS
M(&9O<B`E<R(*;7-G<W1R("(E<R!N=7-T871Y;6%I(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E
M9"!,:7-T(@IM<V=S='(@(E-U<OOP:75O=&%S('/@<F'P87,B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B3W)G86YI
M<V%T:6]N(@IM<V=S='(@(D]R9V%N:7IA8VEJ82(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I;VYA
M;"!5;FET(@IM<V=S='(@(E!A9&%L:6YY<R(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ,S(*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B4VES
M=&5M:6YI;6%S(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@
M(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S='(@(D]R:6=I
M;F%L=7,@87!L:6MA8VEJ;W,@\&%B;&]N87,B"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP
M;&%T97,@:6X@)7,Z(@IM<V=S='(@(D]R:6=I;F%L^',@\&%B;&]N86D@)7,Z
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!S97)V:6-E
M<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S='(@(DMI=&$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$P-@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$S(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,C(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30Q"FUS9VED(")/=&AE<B!)
M;F9O<FUA=&EO;B(*;7-G<W1R(")+:71A(&EN9F]R;6%C:6IA(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,0IM<V=I9"`B3W=N97(@4&5R;6ES
M<VEO;G,B"FUS9W-T<B`B4V%V:6YI;FEK;R!T96ESZW,B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W!A;2YP:'`Z-SD*;7-G:60@(E!!32!A=71H96YT:6-A
M=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(").ZW)A(%!!32!A=71E
M;G1I9FEK86-I:F]S(&UE8VAA;FEZ;6\N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL
M(&)A8VME;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3(W,PIM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM
M<V=S='(@(E!'4"!S:V%I=&UE;FEN:7,@<&%R8?!A<R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,3D*;7-G:60@(E!'4"!%;F-R>7!T
M960@1&%T82(*;7-G<W1R(")01U`@=?YK;V1U;W1A(&EN9F]R;6%C:6IA(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,W,0IM<V=I9"`B
M4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B4$=0('9I9?!A<VES(')A:W1A<R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-3,*;7-G:60@
M(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B4$=0('!A<VER
M8?!Y=&DO=?YK;V1U;W1I(&1U;VUE;GES(@H*(SH@861M:6XO<&AP<VAE;&PN
M<&AP.C8X"FUS9VED(")02%`@0V]D92(*;7-G<W1R(")02%`@:V]D87,B"@HC
M.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G
M<W1R(")02%`@0TQ)(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S<*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B4$T@
M;&5N9W9A<R!L:65T=7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS.`IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R(")032!L
M:?MT:7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS.0HC+"!F=7IZ>0IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R(")032!L:?MT
M:7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M,`HC+"!F=7IZ>0IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(E#[
M9V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M,0IM<V=I9"`B4$T@4W5N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0R"FUS9VED(")032!4+5-T;W)M<R(*
M;7-G<W1R(")032!4+6%U9')A(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C(W-`IM<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T
M<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM
M<V=S='(@(E!?2%`@0TQ)(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R
M(")487)P86D@8V5LZW-E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")086MI<W1A
M;B(*;7-G<W1R(")086MI<W1A;F%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B
M4&%L874B"FUS9W-T<B`B4&%L874B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0
M86QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@(E7^:6UT
M;VII(%!A;&5S=&EN;W,@=&5R:71O<FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I
M9"`B4&%N86UA(@IM<V=S='(@(E!A;F%M82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I
M9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R(")087!U82!.875J;VII($=V
M:6[K:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")087)A9W5A>2(*;7-G<W1R
M(")087)A9W9A:G5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S8*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B1&%L
M:6YA:2!D96)E<W5O=&$B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C$U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,#$X"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#(S"FUS9VED(")087-S=V]R9"(*;7-G<W1R(")3;&%P
M=&'^;V1I<R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HX,@IM
M<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3,R,@IM
M<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(E-L87!T8?YO9&ES
M(&YE=&5I<VEN9V%S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N
M<&AP.C$U,@IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B4D%$2553(&%U=&5N=&EF:6MA8VEJ
M86D@<F5I:VEA('-L87!T8?YO9/YI;RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,#4S"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO
M;B(*;7-G<W1R(")3;&%P=&'^;V1I<R!S=2!P871V:7)T:6YI;74B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@(E!A<W-W;W)D
M.B(*;7-G<W1R(")3;&%P=&'^;V1I<SHB"@HC.B!T96UP;&%T97,O;&]G:6XO
M;6]B:6QE+FEN8SHQ,0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R(")3;&%P
M=&'^;V1I<SH@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(P,S0*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S
M='(@(E-L87!T8?YO9/YI86D@='5R:2!S=71A<'1I+B(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,3D@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T92(*;7-G<W1R("+!:V5L
M=&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,W"FUS9VED(")087-T92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R("+!:V5L
M=&D@:?`@;&%I:VEN;W-I;W,@<V%U9WEK;&]S("AC;&EP8F]A<F0I(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I
M9"`B4&%T:"(*;7-G<W1R(")+96QI87,B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M97%U975E9"YI;F,Z-PIM<V=I9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R
M(").97!A='9I<G1I;G1O<R!R96=I<W1R86-I:F]S.B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU-`IM<V=I9"`B4&5O<&QE(@IM<V=S='(@(MYM;V[K
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`W"FUS9VED(")097)C96YT(@IM<V=S='(@(E!R;V-E;G1A:2(*"B,Z('1E
M;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED
M(")097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B071L
M:6MT:2!P<F]F:6QA:W1I;FEU<R!V96EK<VUU<R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT,#8*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`B07(@871L:6MT:2!P<F]F:6QA
M:W1I;FEU<R!V96EK<VUU<R!P<FES:6IU;F=I;6\@;65T=3\B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B4&5R;6ES<VEO
M;B(*;7-G<W1R(")496ESZW,B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP
M.C4R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB
M)7-<(B!N;W0@9&5L971E9"XB"FUS9W-T<B`B5&5I<^MS("<E<R<@;F5I\'1R
M:6YT;W,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#8*(RP@
M9G5Z>GD*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(E1E:7/K
M<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38Q(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,38T"B,L(&9U>GIY"FUS9VED(")0
M97)M:7-S:6]N<R(*;7-G<W1R(")?5&5I<^MS(@H*(SH@861M:6XO<&5R;7,O
M961I="YP:'`Z,3`Y(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,`HC.B!A
M9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@861M:6XO<&5R;7,O9&5L971E+G!H
M<#HU.`IM<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VXB"FUS9W-T
M<B`B5&5I<VGX(&%D;6EN:7-T<F%V:6UA<R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV-0IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T
M<B`B07-M96YI;NL@:6YF;W)M86-I:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@
M(E!E<G4B"FUS9W-T<B`B4&5R=2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU-0IM<V=I9"`B4&5T<R(*;7-G<W1R(")'>7;[;F%I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDY"FUS9VED(")0:&EL:7!P:6YE<R(*;7-G<W1R(")&:6QI<&EN86DB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS
M9VED(")0:&]N92(*;7-G<W1R(")496QE9F]N87,B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#<X"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B3G5O
M=')A=6MO<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DP(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A:7)N(@IM<V=S
M='(@(E!I=&MR86YA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T<B`B4&EK<V5L
M:6%I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS9VED(")0;&%T
M:71U9&5S(@IM<V=S='(@(D)A;F%L>6+K<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S
M92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R("))\'-I<FEN:VET92!K
M=7)IX"!N;W)S(&-E;.8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#D*;7-G:60@(E!L96%S92!C;VYF:7)M
M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T
M<B`B4&%T=FER=&EN:VET92P@87(@=&EK<F%I(&YO<FET92!I\'1R:6YT:2#P
MX2!E;&5M96YTX#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H
M870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B
M4&%T=FER=&EN:VET92P@87(@=&EK<F%I(&YO<FET92!I\'1R:6YT:2#P:6\@
M96QE;65N=&\@;G5O<F]DX"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-3<Q"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R
M+B(*;7-G<W1R("+!=F5S:VET92!MZVYE<^$@:7(@;65T=7,N(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G:60@
M(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM
M<V=S='(@(L%V97-K:71E(&YA=6IO<R!K871E9V]R:6IO<R!P879A9&EN:6W@
M.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#$*;7-G:60@(E!L
M96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(L%V97-K
M:71E('1E:7-I;F?@($E0(&%D<F5SX"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-C8P"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!D871E
M+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G
M<W1R("+!=F5S:VET92!T96ES:6YGX"!D873@+"!P871I:W)I;FMI=&4@9&EE
M;O@@<VMA:>AI^"!MZVYE<WEJ92XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-#4Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+B(*
M;7-G<W1R("+!=F5S:VET92!T96ES:6YGX"!L86EKX"XB"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O=FED
M92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@(D%P<F'P>6MI
M=&4@<')O8FQE;>`N(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR
M,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0;&5A<V4@
M<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R(").
M=7)O9'EK:71E('-A=F\@=F%R=&]T;VIO('9A<F3@(&)E:2!S;&%P=&'^;V3A
M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4X"B,L(&9U>GIY"FUS
M9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-
M55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M
M+B(*;7-G<W1R("(B"B)0<F'P;VUE('!E<G-K86ET>71I(/#A('1E:W-TX"X@
M2OMS(%!2259!3$]412!S=71I:W1I('-U('/@;'EG;VUI<RP@:F5I("(*(FYO
M<FET92!N875D;W1I<R!S:7-T96UA+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<P"FUS9VED(")0;&5A<V4@='EP
M92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S='(@(L%V97-K:71E(&YA
M=6K@(&MA=&5G;W)I:F]S('!A=F%D:6YI;>`Z(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS
M9VED(")0;VQA;F0B"FUS9W-T<B`B3&5N:VEJ82(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU-PIM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B4&]L:71I
M:V%I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X-PIM<V=I9"`B
M4&]L;',B"FUS9W-T<B`B0F%L<V%V:6UA:2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G
M:60@(E!O<G1U9V%L(@IM<V=S='(@(E!O<G1U9V%L:6IA(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W
M"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(E!A
M=F5I:W-LZVQI;R!P;WII8VEJ82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T
M:&ES('1A8FQE(@IM<V=S='(@(DQE;G1E;.MS('!O>FEC:6IA(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@(E!O
M<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G
M<W1R("))\'-A=6=O=&D@\&EA;64@:V%T86QO9V4@*&YE9V%L:6]J82!)34%0
M*2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C8V(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@
M9F]R(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(DMR:71U;&EA:2!P87-K
M+B`E<R!V86QA;F3@*&%S*3H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(Y.`IM<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H86YC92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O;&1A<"YP:'`Z
M.3@*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?;&1A<#H@;F5R87-T87,@<F5I
M:V%L:6YG87,@3$1!4"!M;V1U;&ES+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@4F5Q
M=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0
M<F5F<U]S97-S:6]N.B!N97)A<W1A<R!R96EK86QI;F=A<R!S97-I:O@@;6]D
M=6QI<RXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-0IM<V=I9"`B4')E
M<W-U<F4B"FUS9W-T<B`B4VSK9VES(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR-3D*;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E;#H@(@IM<V=S='(@
M(E-LZV=I<R!J^W)O<R!L>6=Y:F4Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,S4*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T<B`B4VSK
M9VES.B`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C`U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R(")097+^
M:?MR82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@
M82!N97<@=VEN9&]W(@IM<V=S='(@(E!E<OYI^W+K=&D@<&%V96EK<VSK;.$@
M;F%U:F%M92!L86YG92(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,S8R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8V"FUS9VED
M(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S='(@(D%N:W-T97-N:2!N=7-T871Y
M;6%I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B071S<&%U<V1I
M;G1I(&1O:W5M96YTX"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+97DB"FUS9W-T<B`B4VQA<'1A<VES
M(')A:W1A<R(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ
M-CD*;7-G:60@(E!R;V)L96TB"FUS9W-T<B`B4')O8FQE;6$B"@HC.B!S97)V
M:6-E<R]P<F]B;&5M+G!H<#HQ,C8*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I
M;VXB"FUS9W-T<B`B4')O8FQE;6]S(&%P<F'P>6UA<R(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS-CD*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@
M(E!R;VIE:W1A:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,3$@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X.`HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,C@U"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R(")0
M<F'P>6UA<R!T96MS='5I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(E9I9?!A<VES
M(')A:W1A<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C0U"FUS9VED(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R(")6:67P
M;VIO(')A:W1O(&%L9V]R:71M87,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8T-`HC+"!F=7IZ>0IM<V=I9"`B4'5B;&EC($ME>2!)
M;F9O(@IM<V=S='(@(E9I9?!A<VES(')A:W1A<R(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@
M:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B
M5FEE\&]J;R]S;&%P=&]J;R!R86MT^"!P;W)A(&YE<W5G96YE<G5O=&$N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B4'5E
M<G1O(%)I:V%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.38@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B46%T87(B"FUS9W-T
M<B`B2V%T87)A<R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HV,PIM<V=I9"`B
M475E<GDB"FUS9W-T<B`B4V%K:6YY<R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HW,`HC+"!F=7IZ>0IM<V=I9"`B475O=&$B"FUS9W-T<B`B2V%T87)A
M<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C8S"B,L
M('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(@IM
M<V=S='(@(E)302!V:67P87-I<R!R86MT87,@*"5D(&)I=&%I*2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C0*;7-G:60@(E)A9&EO('-E;&5C
M=&EO;B(*;7-G<W1R("(G4F%D:6\G('!A<VER:6YK:6UA<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0S"FUS9VED(")286EN
M(@IM<V=S='(@(DQI971U<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@(DQI
M971U<R!R>71E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#4*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R("),:65T=7,@=F%K
M87)E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#8*;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S='(@(DQI^W1I<R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0W"B,L(&9U>GIY
M"FUS9VED(")286EN(&%N9"!3;F]W(@IM<V=S='(@(DQI971U<R]3;FEE9V%S
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*
M(RP@9G5Z>GD*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R("),:65T=7,O
M4VYI96=A<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")2
M86YD;VT@1F]R='5N92(*;7-G<W1R(")!='-I=&EK=&ENZR!F<F%ZZR(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-@IM<V=I9"`B4F%T:6\B
M"FUS9W-T<B`B4V%N='EK:7,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-"!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A9"(*;7-G<W1R(")3:V%I='ET:2(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W"FUS
M9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@(E!E<G-K86ET>71I(&QA:?!K
M86DB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R
M871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B5&EK<F%I(&GP=')I
M;G1I("5S/R!'<F'^:6YT:2!A=&=A;"!N96)E9V%LZW-I=&4N(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H
M:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(E1I:W)A
M:2!I\'1R:6YT:2!V87)T;W1O:F\@)7,@9'5O;65N:7,_($=R8?YI;G1I(&%T
M9V%L(&YE8F5G86SK<VET92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C
M=&EO;B(*;7-G<W1R(")086MA<G1O=&D@86YK<W1E<V[A('9E:6MS;>`B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")2969R97-H($1Y;F%M:6,@365N
M=2!%;&5M96YT<SHB"FUS9W-T<B`B071N875J:6YT:2!K86ER:6]J;R!M96YI
M=2!E;&5M96YT=7,Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,0IM
M<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`B071N875J:6YT
M:2!P;W)T86QO('9A:7IDX#HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HX.30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,PHC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C,U"FUS9VED(")296=E>"(*;7-G<W1R(")2
M96=E>"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-#D*;7-G:60@
M(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(E/@<GGP:?@@;F%R\'EK
M;.LB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,L(&9U>GIY"FUS9VED(")296QO
M860B"FUS9W-T<B`B4VMA:71Y=&DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,R-@IM<V=I9"`B4F5M87)K<R(*;7-G<W1R(")087-T86)O<R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,30*;7-G:60@(E)E;6]T92!397)V97)S
M(@IM<V=S='(@(DYU=&]LYB!S97)V97)I86DB"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W
M=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R(").=71O;.9S(%523"`H
M:'1T<#HO+W=W=RYP879Y>F1Y<RYC;VTO:&]R9&4I.B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E<75E=65D+FEN8SHQ,PIM<V=I9"`B4F5M;W9E(@IM<V=S='(@(DGP=')I
M;G1I(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"FUS9VED
M(")296UO=F4@0FQO8VLB"FUS9W-T<B`B4&'P86QI;G1I(&)L;VO@(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-PIM<V=I
M9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")086YA:6MI;G1I('-T=6QP96SA
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT
M,`IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`B4&%N86EK:6YT
M:2!F;W)M871A=FEMX"(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M,3(X"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R("))\'1R:6YT:2!P;W+@
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E
M('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O
M<GDN(@IM<V=S='(@(DGP=')I;G1I(&%T;F%U:FEN:6UO('-K<FEP=.`@:?`@
M<V5R=F5R:6\@;&%I:VEN;VIO(&MA=&%L;V=O+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@IM<V=I9"`B
M4F5M;W9E('1H92(*;7-G<W1R(")08?!A;&EN=&DB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@
M(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`B
M4&'P86QI;G1I(/#A(&5L96UE;G3@(&GP(&1O:W5M96YT;R(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*;7-G:60@(E)E;6]V92!U
M<V5R(@IM<V=S='(@(DGP=')I;G1I('9A<G1O=&]JX"(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")296UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B5F%R=&]T;VIO('1R>6YI;6%S
M.B`E<R(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X"FUS
M9VED(")297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E
M<G)O<F-O9&4Z("(*;7-G<W1R(").96=A;&EU(&%T<V%K>71I(.$@=?YK;&%U
M<^`N($ML86ED;W,@:V]D87,Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-3<*(RP@9G5Z>GD*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E
M(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T<B`B3F5G86QI=2!I\'-A=6=O
M=&D@;G5S:?AS=&\@9F%I;&\N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ-S0@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3(*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E
M8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E!A<F%M971R
M87,@)R5S)R!N96YU<F]D>71A<R`E<R!K;VYF:6?[<F%C:6IO:F4N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-S4@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HX,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C<R,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@
M7"(E<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(E!A<F%M971R87,@)R5S)R!N96YU<F]D>71A<R!61E,@:V]N9FEG
M^W)A8VEJ;VIE+B(*"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<X,0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO
M="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B4&%R86UE
M=')A<R`G)7,G(&YE;G5R;V1Y=&%S(&MO;F9I9_MR86-I:F]J92XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,S4*;7-G:60@(E)E
M<75I<F5D($9I96QD(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S.0HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+U)E;F1E<F5R+G!H<#HS,C`@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C$P,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C<W"FUS9VED(")297-E="(*;7-G<W1R("))\"!N875J;R(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"FUS9VED(")297-E="!087-S=V]R
M9"(*;7-G<W1R(")086ME:7-T:2!S;&%P=&'^;V3A(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z,C<*;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O
M<F0B"FUS9W-T<B`B4VQA<'1A_F]D_FEO(&ME:71I;6%S(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C$S,`HC+"!F=7IZ>0IM<V=I9"`B4F5S=&]R92!,87-T
M(%%U97)Y(@IM<V=S='(@(E!A<VMU=&EN:7,@:V5T=FER=&ES(@H*(SH@861M
M:6XO<&AP<VAE;&PN<&AP.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A9&UI
M;B]S<6QS:&5L;"YP:'`Z-C8*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B4F5Z
M=6QT871A:2(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@
M=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P
M=&EO;G,B"FUS9W-T<B`B1W+A_G1I(.$@;G5S=&%T>6UU<R(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS.`HC+"!F=7IZ>0IM<V=I9"`B4F5T
M>7!E(&YE=R!P87-S=V]R9"(*;7-G<W1R(")086ME:7-T:2!S;&%P=&'^;V3A
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R(")296K[
M;FEJ82(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB
M"FUS9W-T<B`B071S=&%T>71I(&MO;F9I9_MR86-I:N`B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3,R"FUS9VED(")2:6-H(%1E>'0@161I=&]R($]P
M=&EO;G,B"FUS9W-T<B`B2%1-3"!R961A:W1O<FEA=7,@;G5S=&%T>6UA:2(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE<R(*
M;7-G<W1R(")-X7-LZW,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@(D1E
M\&ENZVIE(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,0IM<V=I
M9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(D1E\&EN:6]J:2!A;G1R8?!TZR(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3<*;7-G:60@(E)I9VAT
M('9A;'5E<R(*;7-G<W1R(")$9?!I;FEO<VEO<R!R96EK\&WK<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M.`IM<V=I9"`B4F]?=R!0<F]P97)T:65S+BXN(@IM<V=S='(@(E]%:6QU=.MS
M(&YU<W1A='EM86DN+BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(E)O;.LB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM<V=S='(@(E)U;75N:6IA
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R
M-0IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R(")087-U:W1I(#$X,"(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C(*;7-G
M:60@(E)O=&%T92!,969T(@IM<V=S='(@(E!A<W5K=&D@:V%I<NMN(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R.`IM<V=I
M9"`B4F]T871E(%)I9VAT(@IM<V=S='(@(E!A<W5K=&D@9&7P:6[K;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#D*;7-G:60@(E)O=R!0<F]P97)T:65S(@IM<V=S='(@(D5I;'5TZW,@;G5S
M=&%T>6UA:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P<F]P97)T:65S(@IM<V=S='(@
M(D5I;'5TZW,@;G5S=&%T>6UA:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R(")%
M:6QU=.MS.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-3,*;7-G:60@(E)U;&5S(@IM<V=S='(@(E-K:7)T=6MA
M:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL
M(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`B4VMI<G1U:V%I('1A<G`@=FES
M^"!E:6QUZ&GX(&ER('-T=6QP96QI^"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I
M;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(E-K:7)T
M=6MA:2!T:6L@=&%R<"!S='5L<&5L:?@B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W
M:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(*;7-G<W1R(")3:VER='5K
M86D@=&EK('1A<G`@96EL=>AI^"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,C`*;7-G:60@(E)U;B(*;7-G<W1R(")6>6MD>71I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,PIM<V=I9"`B4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(E)U<VEJ;W,@
M1F5D97)A8VEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)W86YD82(*;7-G
M<W1R(")2=6%N9&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C(X-0IM<V=I9"`B4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E
M(@IM<V=S='(@(E,O34E-12!P87)A\&%S(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@
M365S<V%G92(*;7-G<W1R(")3+TU)344@=?YK;V1U;W1A<R!L86GP:V%S(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX,0IM<V=I9"`B4T%3
M3"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(").
MZW)A(%-!4TP@875T96YT:69I:V%C:6IO<R!M96-H86YI>FUO+B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,#0*;7-G:60@(E--4R!-97-S86=I
M;F<B"FUS9W-T<B`B4TU3(/YI;G5TZW,B"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R(")344P@0TQ)(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,PIM<V=I9"`B4U%,('-T871E
M;65N="!F;W(@=F%L=64@;&]O:W5P<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#,Q"FUS9VED(")34T@B"FUS9W-T<B`B4U-(
M(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES
M=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R(")0
M05992T\B"@HC.B!L:6(O87!I+G!H<#HQ-3,*;7-G:60@(E-?44P@4VAE;&PB
M"FUS9W-T<B`B4U]13"!#3$DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")382(*;7-G<W1R("+09?!T+B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R("+0
M=F5N=&]J:2!(96QE;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI
M='1S(&%N9"!.979I<R(*;7-G<W1R(")386EN="!+:71S87,@:7(@3F5V:7-A
M<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B
M4V%I;G0@3&EU8VEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I
M97)R92!A;F0@36EQ=65L;VXB"FUS9W-T<B`BT'9E;G1A<VES(%!E=')A<R!I
M<B!-:6=E;&]N87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")386EN="!6:6YC
M96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G<W1R(")386EN="!6:6YC96YT
M87,@:7(@1W)E;F%D:6YA:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*
M;7-G<W1R(")486UE('!AZ&EA;64@;&%N9V4@*%]S96QF*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S='(@(E-A;6]A(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R(")386X@36%R:6YA<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*
M;7-G<W1R(")386\@5&]M92!I<B!0<FEN8VEPZR(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E
M<B(*;7-G<W1R(")086QY9&]V87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3
M875D:2!!<F%B:6$B"FUS9W-T<B`B4V%U9&\@07)A8FEJ82(*"B,Z('1E;7!L
M871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY.`IM<V=I9"`B4V%V92(*;7-G<W1R
M("))\'-A=6=O=&DB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N
M:6YC.C0U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3879E(%PB)7-<
M(B(*;7-G<W1R("))\'-A=6=O=&D@)7,B"@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C(Q-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E("5S(@IM
M<V=S='(@(DGP<V%U9V]T:2`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N
M:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R("))\'-A=6=O=&D@
M;G5S=&%T>6UU<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C<*;7-G
M:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@
M<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R
M>2XB"FUS9W-T<B`B(@HB2?!S875G;W1I('-U9V5N97)U;W1U<R!N=7-T871Y
M;75S(&MA:7`@4$A0('-K<FEP=.`@:OMS^"!S97)V97)I;R!L86EK:6YA:F%M
M92`B"B)K871A;&]G92XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R("(E<R!N=7-T871Y;6%I(&GP<V%U9V]T:2XB"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HY,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB
M"FUS9W-T<B`B071N875J:6YI;6\@<VMR:7!T87,@:?!S875G;W1A<R#A.B`G
M)7,G+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0Y"B,L(&9U>GIY"FUS9VED(")38V%T=&5R960@5"U3=&]R;7,B"FUS9W-T
M<B`B27IO;&EU;W1O<R!4+6%U9')O<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R(")-;VMS;&%S(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C:"(*;7-G<W1R("))
M9?!K;W1I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R,`IM<V=I
M9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T<B`B4&%I9?!K82(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Y-S,*;7-G:60@(E-E;&5C="!&:6QE<R(*
M;7-G<W1R(")087-I<FEN:VET92!F86EL=7,B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@T"FUS9VED(")396QE8W0@82!D
M871E(@IM<V=S='(@(E!A<VER:6YK:71E(&1A=.`B"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B4V5L96-T(&$@9W)O=7`@=&\@
M861D(@IM<V=S='(@(E!A<VER:6YK:71E(&=R=7#F(@H*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R
M(@IM<V=S='(@(E!A<VER:6YK:71E(&YA=6K@('-A=FEN:6YKX"(*"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T(&$@
M<V5R=F5R(@IM<V=S='(@(E!A<VER:6YK:71E('-E<G9E<N$B"@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U-@IM<V=I9"`B4V5L96-T(&$@=7-E
M<B!T;R!A9&0B"FUS9W-T<B`B4&%S:7)I;FMI=&4@=F%R=&]T;VK@(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-PHC+"!F
M=7IZ>0IM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R(")087-I<FEN:VET92!F
M86EL=7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8S"FUS9VED
M(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`B4&%S:7)I
M;FMI=&4@=FES=7,@9&%T;W,@:V]M<&]N96YT=7,N(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B4V5L96-T
M(&%N(&]B:F5C="(*;7-G<W1R(")087-I<FEN:VET92!O8FIE:W3@(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.`HC+"!F
M=7IZ>0IM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B4&%S:7)I;FMI=&4@
M;F%U:N`@<V%V:6YI;FO@(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W
M"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O
M;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P
M87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B(@HB2?`@
M_F5M:6%U(&5S86[H:?@@<^!R8?#X('!A<VER:6YK:71E(')E:6MI86UU<R!S
M:6UB;VQI=7,N(%;K;&EA=2!G86QI=&4@:G5O<R`B"B)N=6MO<&EJ=6]T:2#A
M(&QA:?!KX"XB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I
M9"`B4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`B4&%S:7)I
M;FMI=&4@9&%T;W,@<VMI<G1U:^`Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM<V=S
M='(@(E!A<VER:6YK:71E(&1A=&]S(&9O<FUA=.`Z(@H*(SH@=&5M<&QA=&5S
M+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L96-T('1H
M92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(E!A<VER
M:6YK:71E(&%P<F'PX"!K=7+A(&YO<FET92!R961A9W5O=&DZ(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,38*;7-G:60@(E-E;&5C="!T:&4@=&EM
M92!D96QI;6ET97(Z(@IM<V=S='(@(E!A<VER:6YK:71E(&QA:6MO('-K:7)T
M=6O@.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")3
M96QE8W0@=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R(")087-I<FEN:VET92!L
M86EK;R!F;W)M873@.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M-3<*;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R
M(")087-I<FEN:VET92!D=2!A=&ET:6YK86[H:75S(&QA=6MU<RXB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`V"FUS9VED(")396QE8W0@>6]U<B!C
M;VQO<B!S8VAE;64N(@IM<V=S='(@(E!A<VER:6YK:71E('-P86QV^"!D97)I
M;N$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T.`IM<V=I9"`B4V5L
M96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R(")087-I<FEN
M:VET92!N;W)I;>`@:V%L8N`Z(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T
M<B`B4VGX<W1I('!R;V)L96UO<R!P<F%N9?!I;>`B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`S.0IM<V=I9"`B4V5N9"!3
M35,B"FUS9W-T<B`B4VGX<W1I(%--4R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@
M(E-E;F5G86PB"FUS9W-T<B`B4V5N96=A;&%S(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,38*;7-G:60@(E-E;G-O<CH@(@IM<V=S='(@(E-E;G-O<FEU
M<SH@(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P.0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S,*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R(")2=6=SZVII<R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")397)B
M:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T<B`B4V5R8FEJ82!I<B!-;VYT96YE
M9W)A<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`Q
M"FUS9VED(")397)I86P@3G5M8F5R(@IM<V=S='(@(E-E<FEJ;W,@;G5M97)I
M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*(RP@9G5Z
M>GD*;7-G:60@(E-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(D]R;R!SX&QY9_@@8FQO:V\@;NMR82XB"@HC.B!A9&UI;B]S
M97-S:6]N<RYP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(E-E<W-I;VX@061M:6XB
M"FUS9W-T<B`B5&5I<VGX(&%D;6EN:7-T<F%V:6UA<R(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@IM<V=I9"`B
M4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R(")397-I:F]S($E$('!A<VEB
M86EGZRXB"@HC.B!L:6(O87!I+G!H<#HQ-#4*(RP@9G5Z>GD*;7-G:60@(E-E
M<W-I;VYS(@IM<V=S='(@(E]496ESZW,B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S$T"FUS9VED(")3970B"FUS9W-T<B`B4FEN:VEN>7,B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8*;7-G:60@(E-E="!O<'1I;VYS
M('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E
M=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B(@HB3G5S=&%T>6UA:2!L96ED_FEA
M;G1Y<R!*=6US('!A<VEK96ES=&D@<VQA<'1A_F]DX2P@:F5I9W4@:N$@:V%D
M82!N;W)S("(*(G!A;6ER\&ET92XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$U"FUS9VED(")3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@
M=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B3G5T
M;VQU<VGX('-E<G9E<FGX+"!K=7)I=6]S(&YO<FET92!M871Y=&D@:?`@<&]R
M=&%L;RP@;G5S=&%T>6UA:2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#0*;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO
M;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B2V%L8F]S+"!L86EK;R!Z
M;VYO<R!I<B!D871O<R!N=7-T871Y;6%I+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY.`IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A
M=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE
M<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(B(*(E!U<VQA<&EO('-P
M86QV^"P@871S:6YA=6II;FEM;R!D8?YN=6UO(&ER(&MI=/@@=F%I>F1A=FEM
M;R!P87)A;65T<O@@(@HB;G5S=&%T>6UA:2XB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C<U"B,L(&9U>GIY"FUS9VED(")3971U<"(*;7-G<W1R(")?
M2V]N9FEG^W)A8VEJ82(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E
M>"YH=&UL.C,W"FUS9VED(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA
M8FQE(@IM<V=S='(@(E)A<W1A<R!A=&YA=6II;FEM;R!S:W)I<'1A<R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ.#8*;7-G:60@(E-E=F5R
M86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM
M<V=S='(@(E-U(/!I=6\@<&%R86UE=')U(&=A;&EM;W,@:V5L:6]S('9I971O
M=NMS.B`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L;&5S(@IM<V=S
M='(@(E-E:?!E;&%I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Y
M-@IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B4&%R9'5O='5VZR(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S"FUS9VED(")3:&]R="!3
M=6UM87)Y(@IM<V=S='(@(E1R=6UP87,@87!R8?!Y;6%S(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0T-@IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES
M(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@(D%R(&YA=61O
M=&D@:VQA=FEA=/MR;W,@;7EG='5K=7,@=F%L9'EM=6D_(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS
M9W-T<B`B4F]D>71I(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U-0IM
M<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S
M879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R("(B"B)087)O9'ET:2!S:VER='5M=7,@=&%R<"!I\'-A=6=O
M=&\@:7(@:^`@=&EK('-U9V5N97)U;W1O(&MO;F9I9_MR86-I;FEO(&9A:6QO
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3`*;7-G:60@(E-H;W<@
M;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`B4F]D
M>71I('!A<VMU=&EN:6\@<')I<VEJ=6YG:6UO(&QA:6O@/R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C4*;7-G:60@(E-H;W<@;W!T:6]N('1O
M(&ME97`@;W)I9VEN86PB"FUS9W-T<B`B4F]D>71I(&=A;&EM>6+F('!A;&EK
M=&D@;W)I9VEN86S@(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q
M,PIM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B4F]D>71I('!A<FES:6YK
M:6W@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R-@IM<V=I9"`B4VAO
M=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R(")2;V1Y=&D@
M;&5N=&5LZW,@;W!E<F%C:6KX(&UE;FEU/R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@
M365N=2!O;B!T:&4@;&5F=#\B"FUS9W-T<B`B4F]D>71I("5S(&UE;FEU(&MA
M:7+K:F4_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!486)L92!#96QL(%!R
M;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(E)O9'ET:2!C96SK<R!N=7-T871Y
M;?@@;&%N9^`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E
M<G1I97,@9&EA;&]G(@IM<V=S='(@(E)O9'ET:2!L96YT96SK<R!N=7-T871Y
M;?@@;&%N9^`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%)O=R!0
M<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")2;V1Y=&D@96EL=73K<R!N=7-T
M871Y;?@@;&%N9^`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G:60@(E-H;W<@=&AE(&EM86=E('!R
M;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(E)O9'ET:2!P879E:6MS;.ML:6\@
M;G5S=&%T>6WX(&QA;F?@(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3<V,PIM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T<B`B4F]D>71I(&9A:6SX
M(.%KZVQI;>`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU,`IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R("),:?MT:7,B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,0IM<V=I9"`B
M4VAO=V5R<R!%87)L>2(*;7-G<W1R("),:?MT:7,@<GET92(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED(")3:&]W
M97)S($QA=&4B"FUS9W-T<B`B3&G[=&ES('9A:V%R92(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W97)S
M(&EN('1H92!6:6-I;FET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HT.#`*;7-G:60@(E-H<FEN:R(*;7-G<W1R
M(")3=6UA_FEN=&DB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HW-S0@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.#,V
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.CDR,B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY.#0*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3`T-R!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HQ,#@W"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C$Q,38@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z,3$T.0IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG
M(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(E-U;6'^
M:6YT:2!A<F)A('!A<W1U;71I(&MA:6UY;FEN:75S(&)L;VMU<R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#4*;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R(")3:65R82!,
M96]NZR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C4*
M;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B4F5G:7-T<F%C:6IA(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA
M='5R92(*;7-G<W1R(")087)A\&%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HW,3$*;7-G:60@(E-I9VYA='5R92!!;&=O<FET:&TB
M"FUS9W-T<B`B4&%R8?!O(&%L9V]R:71M87,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS
M9VED(")3:6YG87!O<F4B"FUS9W-T<B`B4VEN9V%P^W)A<R(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C4@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HW,@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C@W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C@Y-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$U(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R,S<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(T-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,P"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C,*;7-G:60@(E-I>F4B"FUS9W-T<B`B
M1'ED:7,B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N
M:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R(")0<F%L
M96ES=&D@<')O9FEL86MT:6O@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO
M=F%K:6$B"FUS9W-T<B`B4VQO=F%K:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I
M9"`B4VQO=F5N:6$B"FUS9W-T<B`B4VQO=NMN:6IA(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-30*(RP@9G5Z>GD*;7-G:60@
M(E-N;W<B"FUS9W-T<B`B4F]D>71I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@(E-N;W<@4VAO=V5R(@IM<V=S
M='(@(E#[9V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU-@HC+"!F=7IZ>0IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@
M(E#[9V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU-PHC+"!F=7IZ>0IM<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S
M='(@(DQI^W1I<R!R>71E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(E-N;W<@4VAO=V5R<R!,
M871E(@IM<V=S='(@(DQI^W1I<R!V86MA<F4B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(W.`IM<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@(E-N:65G
M;R!G>6QI<SH@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#(*;7-G:60@
M(E-N;W<@97%U:79A;&5N="!I;B!W871E<CH@(@IM<V=S='(@(E-N:65G;R!K
M:65K:7,@=F%N9&5N:74Z("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M
M;VX@27-L86YD<R(*;7-G<W1R(")3;VQO;6]N;R!S86QO<R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#8*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`B4V]M86QI82(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*
M;7-G<W1R(")$86EN;W,@:7(@16ELZW)A\.AI86DB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.3(V"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO
M;B(*;7-G<W1R(")2^_!I879I;6\@='9A<FMO<R!P87-I<FEN:VEM87,B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U
M.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,3@Y"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G<W1R(")3:75N=.MJ
M;R!A9')E<V%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-34@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A
M(@IM<V=S='(@(E!I973X($%F<FEK82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3DP"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB"FUS
M9W-T<B`B4&EE=/@@175R;W!O<R`H25-/+3@X-3DM,RDB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S<*;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC
M:"!)<VQA;F1S(@IM<V=S='(@(E!I973X($3^;W)D_FEJ;W,@:7(@4&EE=/@@
M4V%N9'9IZ&\@<V%L;W,B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB
M+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E
M(@IM<V=S='(@(E!I971I;NL@:&5M:7-F97)A(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E
M='=E96X@861J86-E;G0@8V5L;',B"FUS9W-T<B`B5&%R<&%S('1A<G`@8V5L
M:?@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@
M:6X@8V5L;"(*;7-G<W1R(")487)P87,@=&%R<"!C96SK<R!T=7)I;FEO(&ER
M(&MR8?!T:6[K<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Q-0IM
M<V=I9"`B4W!A8V5R(@IM<V=S='(@(E1A<G!A<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`IM<V=I9"`B4W!A
M8VEN9R(*;7-G<W1R(")487)P86D@=&%R<"!C96QI^"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@
M(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B5&%R<&%I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S$*;7-G:60@(E-P86EN(@IM<V=S='(@(DES<&%N:6IA(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDX"FUS9VED(")3<&%M(@IM<V=S='(@
M(E-P86UA<R(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B
M4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`B4W!E8VEF:6YI^"!S
M:6UB;VQI^"#A=&5R<&EM87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM
M<V=S='(@(E!E<G-K96QT:2!C96SF(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L:70@8V]L
M=6UN(@IM<V=S='(@(E!E<G-K96QT:2!S='5L<&5LX2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@
M(E-P;&ET(')O=R(*;7-G<W1R(")097)S:V5L=&D@96EL=73F(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8Q"FUS9VED(")3<&]R=',B"FUS9W-T<B`B
M4W!O<G1A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I($QA;FMA(@IM<V=S
M='(@(M!R:2!,86YK82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HW,R!L:6(O0FQO8VLO;65T87(N<&AP.C<T"FUS9VED(")3=&%N9&%R9"(*
M;7-G<W1R(")3=&%N9&%R=&%S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C8R"FUS9VED(")3=&%R(%1R96LB"FUS9W-T<B`B4W1A<B!4<F5K)V%S(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.#`Y"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@(E!R
M861I;FEA:2!M971A:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3<P"FUS9VED(")3=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R(")2
M86IO;F%S(&%R8F$@<')O=FEN8VEJ82(*"B,Z('1E;7!L871E<R]A9&UI;B]S
M971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B0OMS
M96YA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-0IM<V=I9"`B
M4W1O<F%G92!F;W)M870B"FUS9W-T<B`B4V%U9V]J:6UO(&9O<FUA=&%S(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S(*;7-G:60@
M(E-T<F5E="!!9&1R97-S(@IM<V=S='(@(D=A=';K<R!A9')E<V%S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I
M9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R(")5_F)R875K=&DB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,S"FUS9VED(")3=')I;F<@;&ES="(*
M;7-G<W1R("+>;V3^:?@@<^!R8?!A<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$X-S,*;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R
M97-S(@IM<V=S='(@(DYU:6UT:2!D;VUE;N`@;G5O(&%D<F5S;R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*
M;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(E-T:6QI=7,@6T-34UTB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS
M9VED(")3=2(*;7-G<W1R(")396MM+B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R
M+G!H<#HS-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T
M;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B5S(&YE<F%S=&%S+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*
M;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B5&5M82(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,S,B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R
M+G!H<#HS,3<*;7-G:60@(E-U8FUI="(*;7-G<W1R("+!=F5S=&DB"@HC.B!S
M:6=N=7`N<&AP.C0Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)3
M=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O('1H92!S>7-T96TN
M(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@:&%S
M(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*(E9A<G1O=&]J87,@)R5S)R!S
M=6MU<G1A<R!S:7-T96UO:F4N($MO;"!J:7,@;F5P871V:7)T:6YT87,L('!R
M:7-I:G5N9W1I("(*(FYE9V%LZW-I=&4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R:7!T(@IM
M<V=S='(@(DEN9&5K<V%S(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P-`HC
M.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S='(@(E/K:VUI
M;F=A(@H*(SH@861M:6XO=7-E<BYP:'`Z.#4*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y
M<W1E;2XB"FUS9W-T<B`B)R5S)R!SZVMM:6YG86D@<W5K=7)T87,@<VES=&5M
M;VIE+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E
M<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R(")687)T;W1O:F\@
M)R5S)R!D=6]M96YY<R!SZVMM:6YG86D@:?!T<FEN=&D@:?`@<VES=&5M;W,N
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI;B]P97)M<R]D96QE=&4N
M<&AP.C0V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@9&5L971E9"!<(B5S7"(N(@IM<V=S='(@(B<E<R<@<^MK;6EN9V%I(&GP
M=')I;G1A+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R
M;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B)R5S)R!SZVMM:6YG86D@:?!T<FEN
M=&%S(&GP('-I<W1E;6]S+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N
M+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(B(*(DMO;F9I9_MR
M86-I:F$@871S=&%T>71A('/K:VUI;F=A:2X@4&5R:W)A=6MI=&4@<'5S;&%P
MX2P@:V%D('!A;6%T>71U;>MT92`B"B)P86ME:71U;75S+B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HU.2!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU
M-PIM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R(")!='-A<F=I;NL@:V]N9FEG^W)A8VEJ;W,@:V]P:6IA
M('/K:VUI;F=A:2!I\'-A=6=O=&$N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HV,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*
M;7-G<W1R(")!='-A<F=I;NL@:V]N9FEG^W)A8VEJ;W,@:V]P:6IA('/K:VUI
M;F=A:2!I\'-A=6=O=&$@X2`E<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A
M=&5D(%PB)7-<(B(*;7-G<W1R("(G)7,G('/K:VUI;F=A:2!A=&YA=6II;G1A
M<RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@=W)O=&4@)7,B"FUS9W-T<B`B)R5S)R!SZVMM:6YG86D@=?YR8?!Y=&%S
M+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U9&%N(@IM<V=S='(@(E-U9&%N
M87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4V"FUS9VED(")3=6UM87)Y(@IM<V=S='(@(E1U<FEN>7,B"@HC
M.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C4*;7-G:60@(E-U;B!2:7-E(@IM
M<V=S='(@(E-A=6SK=&5K:7,B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M-C@*;7-G:60@(E-U;B!3970B"FUS9W-T<B`B4V%U;.ML>6=I<R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3
M=6YN>2(*;7-G<W1R(")3875LZW1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Q-@IM<V=I9"`B4W5N<FES92(*;7-G<W1R(")3875LZW1E
M:VES(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R(")3
M875LZW1E:VES+U-A=6SK;'ED:7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C$U"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B4V%U;.MT
M96MI<SH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.0IM
M<V=I9"`B4W5N<V5T(@IM<V=S='(@(E-A=6SK;'EG:7,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$X"FUS9VED(")3=6YS970Z("(*;7-G
M<W1R(")3875LZVQY9VES.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$S"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R
M("),86EP<VYI<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S@*
M;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B07!T87)N879I;6%S(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,34@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-@IM<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`B4W5R:6YA;6%S(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S0*;7-G:60@
M(E-U<FYA;64B"FUS9W-T<B`B4&%V87)DZR(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G
M:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B4W9A;&)A<F1A
M<R!I<B!$_F%N;6%I;F%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B4W=A>FEL
M86YD(@IM<V=S='(@(E-V87II;&%N9&%S(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I
M9"`B4W=E9&5N(@IM<V=S='(@(M!V961I:F$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I
M9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`BT'9E:6-A<FEJ82(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V"B,L(&9U>GIY"FUS9VED(")3>6YC
M(&QO9R!D96QE=&5D(@IM<V=S='(@(DYE=')I;G1I(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$T,@IM<V=I9"`B4WEN8TU,(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN
M=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R(")3:6YT86MSZW,@
M:VQA:61A('!A:67P:V]S(&MR:71E<FEJ=6IE(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM
M<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B4VER:6IO<R!!
M<F%B^"!297-P=6)L:6MA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E0M4W1O<FTB"FUS9W-T<B`B5"UA=61R
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Q
M"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B5"U3
M=&]R;7,B"FUS9W-T<B`B5"UA=61R;W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B5"U3=&]R
M;7,@16%R;'DB"FUS9W-T<B`B3&G[=&ES(')Y=&4B"@HC.B!F<F%M97=O<FLO
M1&%T82]$871A+W1S=BYP:'`Z,38V"FUS9VED(")44U8@9FEL92(*;7-G<W1R
M(")44U8@9F%I;&%S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U1A8FQE+G!H<#HQ
M,S0*;7-G:60@(E1A8FQE(@IM<V=S='(@(DQE;G1E;.LB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S"FUS9VED
M(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(DQE;G1E;.MS(&YU<W1A='EM
M86DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP
M.C4W"B,L(&9U>GIY"FUS9VED(")486)L92!3970B"FUS9W-T<B`B3&5N=&5L
MZR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS9W-T<B`B3&5N
M=&5LZW,@;G5S=&%T>6UA:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@
M(E1A:7=A;B(*;7-G<W1R(")486EV86YA<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E
M(&]F($-H:6YA(@IM<V=S='(@(E1A:79A;F%S+"!+:6YI:F]S('!R;W9I;F-I
M:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")486II:VES=&%N(@IM<V=S='(@
M(E1A9/YI:VES=&%N87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI
M82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S='(@(DIU;F=T:6[K(%1A;GIA
M;FEJ;W,@4F5S<'5B;&EK82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B5&%I
M:VEN>7,Z(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDY-B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3@W"FUS9VED(")487-K<R(*;7-G<W1R(")$
M87)B86DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W
M,PIM<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R(")496QE9F]N;R!N
M=6UE<FES(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3`*;7-G:60@(E1E
M;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(E1E;7`N('!A<VLN('9A;&%N
M9.`Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$T"FUS9VED(")496UP
M97)A='5R92(*;7-G<W1R(")496UP97)A=/MR82(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,C,*;7-G:60@(E1E;7!E<F%T=7)E.B`B"FUS
M9W-T<B`B5&5M<&5R873[<F$Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&5R871U<F4\
M8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C8X-PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB
M"FUS9W-T<B`B3F5R87-T87,@)R5S)R#P86)L;VYA<RXB"@HC.B!A9&UI;B]T
M96UP;&%T97,N<&AP.C$V.0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R871I
M;VXB"FUS9W-T<B`BT&%B;&]N^"!A9&UI;FES=')A=FEM87,B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,S,S8*;7-G:60@(E1E>'0B"FUS9W-T<B`B5&5K<W1A<R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S4*;7-G:60@(E1E>'0@3VYL>2(*;7-G
M<W1R(")4:6L@=&5K<W1A<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G:60@(E1E>'0@86QI9VXB"FUS
M9W-T<B`B3'EG:75O=&D@=&5K<W3@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R
M(")496MS=&\@=FER\'5J92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(DME='8N(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@(E1H86D@*%1)4RTV
M,C`I(@IM<V=S='(@(E1A:6QA;F1I971I\&MA("A425,M-C(P*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#D*;7-G:60@(E1H86EL86YD(@IM<V=S='(@(E1A:6QA;F1A<R(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX.`IM<V=I9"`B5&AA;FL@
M>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+B(*;7-G<W1R(")!Z&G[(&MA9"!N
M875D;VIA=.MS('-I<W1E;6$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX,C`*;7-G:60@(E1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I
M;&%B;&4N(@IM<V=S='(@(D[K<F$@1E10(&UO9'5L:6\N(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S
M=7!P;W)T(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8B!I;G1E9W)A8VEJ
M;W,@=F%R:6ML:75K87,@;F5P86QA:6MO(%PB)7-<(B(*"B,Z(&9R86UE=V]R
M:R].971?24U34"])35-0+T)O;VLN<&AP.C$R.3(*(RP@9G5Z>GD*;7-G:60@
M(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S
M='(@(DYE9V%L:74@:?!S875G;W1I(&YU<VGX<W1O(&9A:6QO+B(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA
M;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R
M(").97!A=GEK;R!U_FMR875T:2!-86EN=&5N86YC93HZ(&ML87/K<R(*"B,Z
M('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H
M92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R
M(").=7-T871Y;?@@;&%N9V%S('7^9&%R>71A<RX@2?!E:6YU+B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C$Q
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,C4R"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C8T(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4:&4@861M:6YI<W1R
M871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO
M;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N
M(@IM<V=S='(@(B(*(DIE:6=U(&YO<FET92!N875D;W1I(&YU<W1A='EM=7,L
M('!A<')A\'EK:71E(&MA9"!A9&UI;FES=')A=&]R:75S("(*(G-U:V]N9FEG
M^W)U;W3X('!A<W1O=FG@(&1U;VUE;O@@8F%ZYB!N=7-T871Y;6%M<R!S875G
M;W1I+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T;VT@<VED92!O;FQY(@IM<V=S
M='(@(E1I:R!A<&%T:6[K:F4@<'5SZVIE(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C
M;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N
M:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T
M<B`B3F7A<F'PZW1E(&-O;G1A:W1O($E$(&YU;65R:6\@87)B82!J:7,@;F5R
M87-T87,@9'5O;65N^"!B87KK:F4N(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C4Q"FUS9VED(")4:&4@8V]N=&%C="!W87,@
M<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G
M<W1R(")+;VYT86MT87,@<^MK;6EN9V%I(.%T<F%U:W1A<R#A($K[<_@@861R
M97/X(&MN>6=E;.8N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,3$V.0IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@
M8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G
M92XB"FUS9W-T<B`B3F]RZV1A;6D@<&%T:6MR:6YT:2!L86GP:^`@<')I=F%L
M;W1E('1U<NMT:2!A='-K:7+@(%!'4"!P87)A\&\@8FQO:^`N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G
M:60@(B(*(E1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO
M="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H
M92!D871A8F%S92XB"FUS9W-T<B`B3F7A<F'PZW1E(&1I<W1R:6)U8VEJ;W,@
M<^!R8?!O($E$(&%R8F$@:FES(&YE<F%S=&%S(&1U;VUE;O@@8F%ZZVIE+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C
M:69I960N(@IM<V=S='(@(DYEX7)A\.MT92!D:7-T<FEB=6-I:F]S('/@<F'P
M;RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q,PIM<V=I9"`B
M5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@
M8V]N;F5C=&EO;BXB"FUS9W-T<B`B(@HB4$=0('7^:V]D879I;6\@9V%L:6UY
M8NL@<F5I:V%L875J82!S875G875S('!R:7-I:G5N9VEM;RX@0F%N9'EK:71E
M(')A\'ET:2`B"B)H='1P<SHO+R!A9')E<V\@<')A9/YI;VIE+B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<U(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z-3$S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S
M('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B1F%I;&%S
M("5S('!R:79A;&\@='5RZW1I("5S('!A<F%M971RX"XB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$V."!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U
M;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+B(*;7-G<W1R(")&86EL87,@
M)7,@<')I=F%L;R!T=7+K=&D@:V%I(&MU<FEU;W,@)7,@<&%R86UE=')U<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,3D*;7-G:60@(E1H
M92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+B(*;7-G<W1R
M(")&86EL87,@;F5G86QI(&+[=&D@;G5K;W!I:G5O=&%S(&%N="!S87;F<RXB
M"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.#`*;7-G:60@(E1H92!F
M:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")&86EL92!NZW)A(&1U
M;VUE;O@N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R
M+G!H<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@
M9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B4D9#
M.#@R(&QA:?!K;R!A;G1R8?!TZW,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R
M965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E
M<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E
M('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R
M:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC
M=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y
M;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA
M="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@
M86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D
M+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R
M>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R("(B"B)*96EG=2!D
M:7)B871E($EN=&5R;F5T($5X<&QO<F5R(&YA<O!Y:VQE+"!P:6QN865K<F%N
M:7,@<F5D86MT;W)I875S(')E_FEM87,@(@HB9V%L:2!S=6ME;'1I('!R;V)L
M96WX+"!DZVP@\&EO<R!N87+P>6MLZW,@:VQA:63X+B!'86QI=&4@;F5M871Y
M=&D@:V%I(&MU<FGX("(*(G)E9&%K=&]R:6%U<R!E;&5M96YT^"X@2F5I9W4@
M;F%U9&]J871E(%=I;F1O=W,@.7@@3U,@9W)E:>AI875S:6%I(&K[<_@@(@HB
M:V]M<&EU=&5R:7,@<&%P<F'PZ&EA=7-I86D@;G5L=?`@<&%S:V5L8F1A;6%S
M(&%P:64@<&%G<FEN9&ENYB!K;&%I9.`N7%QN(@HB7%QN2OMS(&)U=F]T92!P
M97)S<.MT87,N($IE:6=U('9I<W1I96L@;F]R:71E(&GP8F%N9'ET:2!P:6QN
M865K<F%NX2!R9?YI;>`@(@HB<W!A=7-K:71E($]++B(*"B,Z('-E<G9I8V5S
M+W!R969S+G!H<#HY,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I
M='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(D%P<F'P87,@
M7"(E<UPB(&GP=')I;G1A<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD
M('-I9&4@;VYL>2(*;7-G<W1R(")4:6L@:V%I<NMJ92!P=7/K:F4B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ-3<*;7-G:60@(B(*(E1H
M92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@
M=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R(")#<GEP=%]P<7`Z
M.B!K;&%S96D@<F5I:VEA(&YU<F]D>71I(&MU<B!Y<F$@1VYU4$<@9F%I;&%I
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HR,#$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E
M<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*
M(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E
M96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"B),86GP:V%S(&GP
M<VGX<W1A<R`E<R!A9')E<V%T=6D@)7,@=&5M82!<(B5S7"(@8G5V;R!P87)O
M9'ET87,N7&XB"B)48>AI874@=&%I(&YE9V%R86YT=6]J82!K860@;&%I\&MA
M<R!B=79O('!E<G-K86ET>71A<R!A<F)A('-U<')A<W1A<RXB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<W"FUS9VED(")4:&4@;F%M92!T;R!U
M<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B
M4&%V861I;FEM87,@:W5RX2!N875D;W-I=&4@;G5O<F]D;VIE(.$@;&%I\&MO
M(')A\'EM;R!P=7-L87#A(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z-#0Q"B,L(&9U>GIY"FUS9VED(")4:&4@;G5M8F5R(&]F(&9I96QD<R!M
M=7-T(&)E(&YU;65R:6,N(@IM<V=S='(@(M!I(')E:6OP;>L@='5R:2!B^W1I
M('-K86GH:75S+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,3(S,0IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D
M(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B
M2&]R9&5?0W)Y<'1?<VUI;64Z.B!K;&%S96D@<F5I:V%L:6YG87,@3W!E;E-3
M3"!M;V1U;&ES+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,CDP
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<
M(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E
M9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"B).
M96=A;&EU(&GP<V%U9V]T:2!N=7-T871Y;6\@7"(E<UPB+"!N97,@9'5O;65N
M^"!D>61I<R!V:7+P>6IA(&QE:7-T:6[@(')I8N`B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]D96(N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<G!M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]W96)C<'`N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A
M('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(@IM<V=S
M='(@(E!R;V=R86UA+"!S:VER=&$@<&5R_FG[<NMT:2#PX2!D=6]M96[X('1I
M<.`@*"5S*2P@;F5R87-T82!S:7-T96UO:F4N(@H*(SH@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z-#4T"FUS9VED(")4:&4@<75O=&4@8VAA<F%C=&5R
M(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S<*;7-G:60@(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S
M='(@(E1I:R!K86ERZVIE(&ER(&1E\&ENZVIE('!U<^MS92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G
M:60@(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R(")4:6L@9&7P
M:6[K:F4@<'5SZVIE(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M-#0V"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C
M:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S
M=6TN<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E
M<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(E-E<G9E<FES(%PB)7-<
M(B!I\'1R:6YT87,N(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z
M-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S
M(&)E96X@<V%V960N(@IM<V=S='(@(E-E<G9E<FES(%PB)7-<(B!I\'-A=6=O
M=&%S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V
M960N(@IM<V=S='(@(B5S(')E9VES=')A8VEJ;W,@<')A\'EM87,@:?!T<FEN
M=&%S+B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C,S
M,`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N(@IM
M<V=S='(@(DYU<F]D>71A(&5I;'5TZR!N965G>FES='5O:F$N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ-S<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E1H92!T96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@
M97AI<W0N(@IM<V=S='(@(DYU<F]D>71A(&5I;'5TZR!N965G>FES='5O:F$N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Q,0IM<V=I9"`B5&AE
M('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T
M:&4@<V-R965N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED(")4:&4@=&]P(&%N
M9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R(")4:6L@=FER\'5T:6[K:F4@
M:7(@87!A=&ENZVIE('!U<^MS92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED
M92!O;FQY(@IM<V=S='(@(E1I:R!A<&%T:6[K:F4@<'5SZVIE(@H*(SH@9G)A
M;65W;W)K+T1A=&$O1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@
M9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T
M<B`B3G5S:?AS=&D@9'5O;65N>7,@<')A<F%S=&DN(@H*(SH@9G)A;65W;W)K
M+T1A=&$O1&%T82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T82]$871A+W1S
M=BYP:'`Z,3<R"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@
M8F4@<V%V960N(@IM<V=S='(@(DYE9V%L:74@:?!S875G;W1I(&YU<VGX<W1O
M(&9A:6QO+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-38*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$Q-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3$Y"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B5V5A=&AE<BYC;VT@8FQO:V\@;NMR82XB"@HC
M.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB
M"FUS9W-T<B`B3F5R87-T87,@)R5S)R#P86)L;VYA<RXB"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$W.`IM<V=I9"`B5&AE<F4@87)E(&YO
M(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R(").=7-T871Y;?@@;NMR82XB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HS-#(*;7-G
M:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@
M:6YL:6YE+B(*;7-G<W1R(")$86QI^"P@:W5R:6%S(&=A;&EM82!R;V1Y=&D@
M;&%I\&MO('1E:W-T92P@;NMR82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T
M;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N
M=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T
M:&%N("5S+B(*;7-G<W1R("(B"B+0:6%M92!L875K92#A=F5S=&$@<&5R(&1A
M=6<@<VEM8F]L:?@N($K[<R#A=F5DZW1E("5S+"!O(&UA:W-I;6%L=7,@<VMA
M:>AI=7,@(@HB+2`E<R!S:6UB;VQI86DN(@H*(SH@<VEG;G5P+G!H<#HU,R!A
M9&UI;B]U<V5R+G!H<#HW,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@7"(E<UPB('1O('1H92!S>7-T
M96TZ("5S(@IM<V=S='(@(E-U:W5R=&D@)R5S)R!N97!A=GEK;SH@)7,B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E
M<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B3F5P879Y:V\@
M:?!T<FEN=&D@=F%R=&]T;VIO("<E<R<@9'5O;65N^"!I\"!S:7-T96UO<SH@
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F
M<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("))\'1R:6YT:2`G)7,G(&YE<&%V
M>6MO.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@7"(E
M<UPB.B`E<R(*;7-G<W1R(")!=&YA=6II;G1I("<E<R<@;F5P879Y:V\Z("5S
M(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@T"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@
M9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB"FUS9W-T<B`B4')O
M8FQE;6]S('-U(&9A:6SX('-I=6YT:6UU.B`E<R!N96YU<VGX<W1A<RXB"@HC
M.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F
M:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU
M;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@HB3G5S
M:?AS=&D@9F%I;&\@;F5P879Y:V\N($9A:6QA<R`E<R!Y<F$@9&ED97-N:7,@
M;F5G=2!L96ED_FEA;6%S(&1Y9&ES("@E9"`B"B)B86ET86DI+B(*"B,Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y,0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*
M;7-G<W1R(").=7-I^'-T:2!F86EL;R!N97!A=GEK;RX@1F%I;&%S("5S('1I
M:R!D86QI;F%I(&YU<VGX<W1A<RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R(").96=A
M;&EU('!A<F]D>71I(/!I;W,@;&%I\&MO(&1A;&EE<R(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.0HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T
M<B`B2VQA:61A(.%K96QI86YT(&MO;G1A:W1I;FEU<R!D=6]M96YI<RXB"@HC
M.B!F<F%M97=O<FLO1&%T82]$871A+VEM8RYP:'`Z,S$*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*
M;7-G<W1R(")+;&%I9&$@X6ME;&EA;G0@:4-A;&5N9&%R(&1U;VUE;FES+B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#`*;7-G:60@(B(*(E1H97)E
M('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H
M87!S('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R
M("(B"B)+;&%I9&$@:V]N9FEG^W)A8VEJ;W,@9F]R;6]J92X@1W)E:>AI875S
M:6%I(&YE=?YP:6QDZW1E(')E:6MI86WX(&QA=6OX+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X"FUS9VED("(B
M"B)4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D
M(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L
M871E<BXB"FUS9W-T<B`B(@HB2VQA:61A(&%T;&EE:V%N="!N=7)O9'ETX"!A
M9')E<_@@:VYY9V5LZW,@9G5N:V-I:N`N(%!A8F%N9'EK:71E(';K;&EA=2XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8T,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H
M92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM
M<V=S='(@(DML86ED82!A=&YA=6II;F%N="!K;VYT86MT:6YI=7,@9'5O;65N
M:7,N(%!A8F%N9'EK:71E(';K;&EA=2XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C(R,@IM<V=I9"`B(@HB5&AE<F4@=V%S
M(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE
M87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B2VQA:61A(&%T;F%U:FEN
M86YT(&1I<W1R:6)U8VEJ;W,@<^!R8?#@+B!086)A;F1Y:VET92!VZVQI874N
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X
M"FUS9VED(")4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA
M<FEN9R!F;VQD97)S+B(*;7-G<W1R("+0:7,@24U!4"!S97)V97)I<R!N97!A
M;&%I:V\@:V%T86QO9_@@9&%L:6II;6]S:2XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C0X"FUS9VED(")4:&ES(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R(")!
M=')O9&\L(&MA9"!T86D@;F5T=F%R:VEN9V%S(%)!4B!A<F-H>79A<RXB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C4R"FUS9VED
M(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE
M+B(*;7-G<W1R(")!=')O9&\L(&MA9"!T86D@;F5T=F%R:VEN9V%S(%I)4"!A
M<F-H>79A<RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,30U"FUS
M9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU
M;6)E<BXB"FUS9W-T<B`B071R;V1O+"!K860@=&%I(&YE=&5I<VEN9V%S(&MO
M<G1E;.MS(&YU;65R:7,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T
M96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG
M('1H92!(5%10($%022(*;7-G<W1R("(B"B+0:2!T=F%R:WEK;.L@;&5I9/YI
M82!S:?AS=&D@_FEN=71E<R!P97(@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K
M871E;&PN8V]M*2`B"B)P87-I;F%U9&]J86YT($A45%`@<')O=&]K;VQU(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S0*(RP@
M9G5Z>GD*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI
M("(*(F=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"B+0
M:2!T=F%R:WEK;.L@;&5I9/YI82!S:?AS=&D@_FEN=71E<R!P97(@<VUS,F5M
M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@(@HB<&%S:6YA=61O:F%N="!(
M5%10('!R;W1O:V]L=2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3$U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO
M=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@
M*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@
M2%144"!!4$DB"FUS9W-T<B`B(@HBT&D@='9A<FMY:VSK(&QE:63^:6$@<VGX
M<W1I(/YI;G5T97,@<&5R('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC
M;VTI("(*(G!A<VEN875D;VIA;G0@2%144"!P<F]T;VMO;'4B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-0IM
M<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G
M97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@(@HB9V%T
M97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A
M;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D869O;F4@271A;'D@*&AT='`Z
M+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@HBT&D@='9A<FMY:VSK(&QE:63^
M:6$@<VGX<W1I(/YI;G5T97,@4TU44"!P<F]T;VMO;'4@<&5R(%9O9&%F;VYE
M($ET86QI:F]S("(*(G9A<G1U<RP@=&EK(%9O9&%F;VYE(&YU;65R:6%M<RX@
M2FD@<F5I:V%L875J82!E;"X@<&'P=&\@861R97-O(%9O9&%F;VYE("(*(DET
M86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.3<X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-3<*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`X-B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,3$U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#(@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(U-@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,S`U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S.3@*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34U-R!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.#,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y
M-3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P-0HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#(Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M-S@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$T.2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,C(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(T,3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U-`HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-C4W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S-R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,S`V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,X,30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@R,@IM<V=I9"`B
M5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`BT&ES(&QA=6MA<R!P
M<FEV86QO;6%S+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C4*
M;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB
M"FUS9W-T<B`BT&EA;64@;&%U:V4@9V%L:2!B^W1I('1I:R!S=F5I:VEE:FD@
M<VMA:>AI86DN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q.`IM
M<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD
M('1H92!C;VQO;BXB"FUS9W-T<B`BT&EA;64@;&%U:V4@9V%L:2!B^W1I('1I
M:R!S:V%IZ&EA:2!I<B!D=FET8?!K:6%I+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$P.30*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(M!I86UE(&QA=6ME(&=A;&D@
M8OMT:2!T:6L@8?!T=6YT86EN:6%I('-K86GH:6%I+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B
M92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S
M(@IM<V=S='(@(B(*(M!I86UE(&QA=6ME('1U<FD@8OMT:2!K86)L96QI86ES
M(&%R8F$@=&%R<&%I<R!A='-K:7)T:2!S=F5I:VEE:FD@<VMA:>AI86DB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY.#D*;7-G:60@(E1H:7,@9FEE
M;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`BT&D@<F5I:_!M
MZR!T=7)I(&+[=&D@<VMA:>AI=7,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C@S-@IM<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@
M82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP
M;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R("(B"B+0:6%M92!L875K92!G86QI
M(&+[=&D@=&EK('-P86QV;W,@:V]D87,@4D="($AE>"!F;W)M871E+"!P879Y
M>F3^:75I("(*(B<C,3(S-$%&)RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HU-C$*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R
M;V-E<W-E9"XB"FUS9W-T<B`BT&D@9F]R;6$@:F%U(&%P9&]R;W1A+B(*"B,Z
M('1E;7!L871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@(E1A:2`E<RXB"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C0U.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T
M:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL("(*(F-L:65N="!T
M:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&
M;W(@82!L:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES
M:70@)7,B"FUS9W-T<B`B(@HB5&%I($MO;&%B($=R;W5P=V%R92!O8FIE:W1A
M<RX@3F]RZV1A;6D@<&5R_FG[<NMT:2!O8FIE:W3@('!R:79A;&]T92!T=7+K
M=&D@(@HB96PN('!A\'1O(&ML:65N=.`L(&MU<FES('-U<')A;G3@(/#A(&9O
M<FUA=.`N(%1O:VGX(&5L+B!P8?!T;R!K;&EE;G3X('/@<F'PX"`B"B)G86QI
M=&4@<F%S=&D@87!S:6QA;FOF("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z-3DQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@
M;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O
M=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R("+0:7,@;&%I\&MA<R!B=79O
M('!A<F'P>71A<R`E<R!K;V1U;W1E+B!*^W,@;F%U9&]J871E(&MI=&]K:>`@
M:V]D=6]TYBXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R
M-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N(@IM
M<V=S='(@(M!I<R!S:V%IZ&EU<R!T=7)I(&+[=&D@9&ED97-N:7,@=?X@;G5L
MX2XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z
M-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N
M9"!G>FEP(&9I;&5S+B(*;7-G<W1R("+0:7,@<V5R=F5R:7,@;F5G86QI(&GP
M87)C:'EV=6]T:2!Z:7`@:7(@9WII<"!F86EL^"XB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$X.0IM<V=I9"`B5&AI<R!S>7-T
M96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R("+0:2!S:7-T
M96UA(&1A8F%R(&GP:G5N9W1A+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB
M97(N(@IM<V=S='(@(M!I(')E:6OP;>L@='5R:2!B^W1I('-K86GH:75S+B(*
M"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@
M(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W
M:6YD;W<B"FUS9W-T<B`BT.$@;&%N9^`@<F5I:VEA(&%T:61A<FENZW1I(&GP
M(&YU<W1A='EM^"!L86YG;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(E!E<FO[
M;FEJ82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,S0*;7-G:60@
M(E1I8VME=',B"FUS9W-T<B`B0FEL:65T86DB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-#(X('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U
M-0IM<V=I9"`B5&EM92(*;7-G<W1R("),86EK87,B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S@V"FUS9VED(")4:6UE(%1R86-K:6YG(@IM<V=S
M='(@(DQA:6MO(&%P<VMA:71A(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W
M"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R("),86EK;R!F;W)M871A<R(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U,SD*;7-G:60@(E1I;64@
M<V5L96-T:6]N(@IM<V=S='(@(DQA:6MO('!A<VER:6YK:6UA<R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@(E1I;6]R;&5S
M=.LB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P"FUS9VED(")4:71L92(*;7-G
M<W1R(")087)E:6=O<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T
M<B`B4&%V861I;FEM87,Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`B2V%M(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U-`IM<V=I
M9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE
M($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C
M;&EC:VEN9RXB"FUS9W-T<B`B(@HB3F]RZV1A;6D@<&%S:7)I;FMT:2!K96QE
M=.`@96QE;65N=/@L(&QA:6MY:VET92!#;VYT<F]L("A00RD@87)B82!#;VUM
M;F%D("(*(BA-86,I(&ML879I\.`L(&ER('!A<VER:6YK:71E('!E;&4N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B5&]D
M87DB"FUS9W-T<B`BT&EA;F1I96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R
M8V4B"FUS9W-T<B`B4F]D>71I($A434P@:V]DX"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*
M;7-G:60@(E1O9V\B"FUS9W-T<B`B5&]G87,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS
M9VED(")4;VME;&%U(@IM<V=S='(@(E1O:V5L874B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S$S"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R
M(")2>71O:B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O;F=A(@IM<V=S='(@
M(E1O;F=A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<W"FUS9VED(")4;W`B"FUS9W-T<B`B5FER\'5J92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G
M:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B5FER\'5T:6YI86UE(&QA
M;F=E("A?=&]P*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I
M9"`B5')A;G-L871I;VYS(@IM<V=S='(@(E9E<G1I;6%I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,0IM<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G<W1R(")4<FEN
M:61A9&%S(&ER(%1O8F%G87,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-SDP"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@(E1A:7`@87)B
M82!N92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(D%N='(N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R(")4=6YI<V%S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(E1U<FMI:F$B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y,@IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM
M.2DB"FUS9W-T<B`B5'5R:VGP:V$@*$E33RTX.#4Y+3DI(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,`IM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(E1U<FMMZVYI:F$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N
M9',B"FUS9W-T<B`B5'5R:W-O(&ER($MA:6MO<V\@<V%L;W,B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B5'5V86QU(@H*(SH@9G)A
M;65W;W)K+T-,22]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC
M93H@(@IM<V=S='(@(L%V97-K:71E('-A=F\@<&%S:7)I;FMI;>`Z("(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-CD*;7-G:60@(E4N5BX@
M:6YD97@Z("(*;7-G<W1R(")5+E8N(&EN9&5K<V%S.B`B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I
M9G)A;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G
M:60@(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R
M="(*;7-G<W1R(")3:W)I<'1O('!R:7-T871Y;6\@<W1A='5S;R!R87!O<G1O
M(%523"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.3<*;7-G:60@(E523#HB"FUS9W-T<B`B55),.B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3(*;7-G:60@(E5G86YD82(*;7-G<W1R(")59V%N9&$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$R"FUS9VED(")5:W)A:6YE(@IM<V=S='(@(E5K<F%I;F$B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,3(*;7-G:60@(E5N86)L92!T;R!A
M8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F5P879Y:V\@<&5R<VMA
M:71Y=&D@5D93(&MA=&%L;V=O+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M4VEG;G5P+G!H<#HY-@IM<V=I9"`B56YA8FQE('1O(&%D9"!E>'1R82!U<V5R
M(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"XB"FUS9W-T<B`B3F5P879Y
M:V\@<')I9.MT:2!P87!I;&1O;6]S('9A<G1O=&]J;R!R96=I<W1R86-I:F]S
M(&EN9F]R;6%C:6IO<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C,X.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E
M<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3F5P879Y
M:V\@<&%K96ES=&D@5D93(&9A:6QO(%PB)7-<(B!T96ES:?@N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S@U(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T
M<B`B3F5P879Y:V\@<&%K96ES=&D@=&5I<VGX(%9&4R!F86EL=6D@)7,O)7,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-34*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B
M3F5P879Y:V\@<&5R96ET:2#A("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z,C,R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7-<(BXB"FUS9W-T<B`B3F5P
M879Y:V\@871I9&%R>71I(%9&4R!F86EL;R!<(B5S7"(N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z-C@X(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z,3`Q-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M.#,T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE
M8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`B3F5P879Y:V\@
M<&5R=F%D:6YT:2!61E,@9F%I;&\@)7,O)7,N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S<6PN<&AP.C0S-0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@
M=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B3F5P879Y:V\@<')I<VEJ=6YG=&D@
M<')I92!344P@<V5R=F5R:6\N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX,SD*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*
M;7-G<W1R(").97!A=GEK;R!P<FES:6IU;F=T:2!34TP@<F7^:6UU+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R-2!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Q
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#D*;7-G:60@
M(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R(").97!A=GEK;R!N
M=6MO<&EJ=6]T:2!61E,@9F%I;&\N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HS-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R
M96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B3F5P879Y:V\@
M<W5K=7)T:2!61E,@:V%T86QO9V\@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C,U-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,C4X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR-38*
M;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B3F5P879Y:V\@<W5K=7)T:2!61E,@:V%T86QO9V\N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C$R-`IM<V=I9"`B56YA8FQE('1O(&-R
M96%T92!61E,@9FEL92XB"FUS9W-T<B`B3F5P879Y:V\@<W5K=7)T:2!61E,@
M9F%I;&\N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR.#8*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93
M(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(DYE<&%V>6MO('!E<G9A9&EN=&D@
M5D93(&9A:6QO(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HR-C4*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I
M;&4N(@IM<V=S='(@(DYE<&%V>6MO('-U:W5R=&D@='7PZ&EO(%9&4R!F86EL
M;RXB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O=&%R+G!H<#HW
M-@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-SD*
M;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N(@IM<V=S='(@(DYE
M<&%V>6MO(&GP87)C:'EV=6]T:2!D=6]M96[X+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z,C(T(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,CDX"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E
M<UPB+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B3F5P
M879Y:V\@:?!T<FEN=&D@7"(E<UPB+"!K871A;&]G87,@;F5T=?#H:6%S(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP
M.C0T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%PB)7-<(CH@)7,N(@IM<V=S='(@(DYE<&%V>6MO(&GP=')I;G1I("<E
M<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S,2!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,Y,@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,S$Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HS,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B3F5P
M879Y:V\@:?!T<FEN=&D@)7,L(&MA=&%L;V=A<R!N971U\.AI87,B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0X(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HS-3(*;7-G:60@(E5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B3F5P879Y
M:V\@<F5K=7)S:?!K86D@:?!T<FEN=&D@5D93(&MA=&%L;V=O+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S-R!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HS,S4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T,PHC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYE<&%V>6MO(&GP
M=')I;G1I(%9&4R!K871A;&]G;RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C0Q-R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0R.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O
M<GDZ("5S+B(*;7-G<W1R(").97!A=GEK;R!I\'1R:6YT:2!61E,@:V%T86QO
M9V\Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C`W"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@
M7"(E<UPB+B(*;7-G<W1R(").97!A=GEK;R!I\'1R:6YT:2!61E,@9F%I;&\@
M7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,P,R!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(X.`HC.B!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,38W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HQ.#`*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X-R!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S@S"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HS.3$*;7-G:60@(E5N86)L92!T;R!D96QE
M=&4@5D93(&9I;&4N(@IM<V=S='(@(DYE<&%V>6MO(&GP=')I;G1I(%9&4R!F
M86EL;RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(T-`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B3F5P879Y:V\@:?!T<FEN=&D@5D93
M(&9A:6QO(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C0P-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(DYE<&%V>6MO(')E:W5R<VGP
M:V%I(&GP=')I;G1I(%9&4SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HX,#,*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N
M="!D:7)E8W1O<GDN(@IM<V=S='(@(DYE<&%V>6MO(&YU<W1A='ET:2!D86)A
M<G1I;FEO(&MA=&%L;V=O+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C`S"FUS9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I
M8V%T92!D971A:6QS(@IM<V=S='(@(DYE<&%V>6MO(&=A=71I('-E<G1I9FEK
M871O(&%P<F'P>6UO(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`N<&AP
M.C0U,2!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]!=71H+G!H<#HQ,3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I
M;VX@;V8@)7,N(@IM<V=S='(@(DYE<&%V>6MO('7^:W)A=71I("5S(&%P<F'P
M>6UO+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$Y-B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$V-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,3<Q"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB"FUS
M9W-T<B`B3F5P879Y:V\@<&5R:V5L=&D@5D93(&9A:6QO+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z.3,@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HQ,#(*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HV-#@@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HY.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DYE
M<&%V>6MO(&%T:61A<GET:2!61E,@9F%I;&\@7"(E<UPB+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C(W-R!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HQ,S,*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W
M<FET:6YG+B(*;7-G<W1R(").97!A=GEK;R!A=&ED87)Y=&D@5D93(&9A:6QO
M(')A\'EM=6DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z.#`@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HW,@IM<V=I9"`B56YA8FQE('1O(&]P96X@
M5D93(&9I;&4N(@IM<V=S='(@(DYE<&%V>6MO(&%T:61A<GET:2!61E,@9F%I
M;&\N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HT
M-0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*
M;7-G<W1R(").97!A=GEK;R!A=&ED87)Y=&D@<W5S<&%U<W1O(&%R8VAY=F\N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@S-0HC+"!F=7IZ>0IM<V=I
M9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D
M*2XB"FUS9W-T<B`B3F5P879Y:V\@X7)A\'ET:2!61E,@9F%I;&\@*&-O<'DH
M*2!K;&%I9&$I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-C8*(RP@
M9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE
M4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(DYE<&%V>6MO(.%R8?!Y=&D@5D93
M(&9A:6QO("AC;W!Y*"D@:VQA:61A*2XB"@HC.B!F<F%M97=O<FLO4V5S<VEO
M;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*(RP@9G5Z>GD*
M;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R(").97!A=GEK
M;R!P97)V861I;G1I(%9&4R!F86EL;RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HV-CD*;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V9G-R
M;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F5P879Y:V\@<&5R<VMA:71Y=&D@
M=F9S<F]O="!K871A;&]G;RXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C$Q,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M
M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S
M(@IM<V=S='(@(DYE<&%V>6MO('!E<G9A9&EN=&D@)7,@X2`E<SH@=&]K<R!K
M871A;&]G87,@:F%U(&5G>FES='5O:F$B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,CDS"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&
M4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYE<&%V>6MO('!E<G9A9&EN=&D@5D93
M(&MA=&%L;V=O+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I
M<F5C=&]R>3H@)7,N(@IM<V=S='(@(DYE<&%V>6MO('!E<G9A9&EN=&D@5D93
M(&MA=&%L;V=O.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C(V-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,T,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB
M"FUS9W-T<B`B3F5P879Y:V\@<&5R=F%D:6YT:2!61E,@9F%I;&\@7"(E<UPB
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8Q,"!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C(Y"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(DYE
M<&%V>6MO('!E<G9A9&EN=&D@5D93(&9A:6QO("5S+R5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(S(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HR,3,*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0U
M,B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C@U"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,#$*;7-G:60@(E5N86)L92!T
M;R!R96YA;64@5D93(&9I;&4N(@IM<V=S='(@(DYE<&%V>6MO('!E<G9A9&EN
M=&D@5D93(&9A:6QO+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O(')U;B`G
M;6MI<V]F<R<N(@IM<V=S='(@(DYE<&%V>6MO('!A;&5I<W1I("=M:VES;V9S
M)RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP
M.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U
M;65N="(*;7-G<W1R(").97!A=GEK;R!I\'9E<G-T:2#P:6\@5V]R9"!D;VMU
M;65N=&\B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$T.2!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C$U,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").
M97!A=GEK;R#A<F'P>71I(%9&4R!F86EL;R!<(B5S7"(N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,3<Y"FUS9VED(")5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R(").97!A=GEK
M;R#A<F'P>71I(%9&4R!F86EL;R`H8V]P>2@I(&ML86ED82DN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@Q(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HQ,S@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C$T,PIM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A
M=&$N(@IM<V=S='(@(DYE<&%V>6MO(.%R8?!Y=&D@5D93(&9A:6QO(&1U;VUE
M;O@N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@T,0HC+"!F=7IZ>0IM
M<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E
M(&5X8V5E9&5D+B(*;7-G<W1R(").97!A=GEK;R#A<F'P>71I(%9&4R!F86EL
M;R`H8V]P>2@I(&ML86ED82DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@
M(E!A8G)A=6MT:2(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G
M:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R(")!=/!A=6MT:2!P86ME:71I;75S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B073P
M875K=&D@86YK<W1E<V[A('9E:6MS;>`B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,SDP"FUS9VED(")5;F5X<&5C=&5D(')E<W!O
M;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R(").971I
M:^MT82!S97)V97)I;R!K;&%I9&$Z("(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS-#$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S<X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,X-`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F
M<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@(DYE=&EKZW1A('-E<G9E<FEO(&ML
M86ED83H@(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N
M86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z-C$*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B3F5N=7)O9'ET
M82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS"FUS9VED(")5;FEC;V1E
M("A55$8M."DB"FUS9W-T<B`B56YI:V]D87,@*%541BTX*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4V"FUS9VED(")5;FET960@07)A8B!%;6ER871E<R(*;7-G<W1R(")*=6YG
M=&EN:6%I($%R86+X($5M>7)A=&%I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")5
M;FET960@2VEN9V1O;2(*;7-G<W1R(")*=6YG=&ENZR!+87)A;'ES=.LB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S='(@(DIU
M;F=T:6[K<R!686QS=&EJ;W,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET
M960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',B"FUS9W-T<B`B2G5N
M9W1I;FGX(%9A;'-T>6KX($%T;VME<V[K<R!S86QO<R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HV.2!L:6(O0FQO8VLO;65T87(N<&AP.C<Q
M"FUS9VED(")5;FET<R(*;7-G<W1R(")6:65N971A:2(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R.2!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,S`*;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`B3F7^:6YO
M;6%S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G
M92!)1"DN(@IM<V=S='(@(DYE_FEN;VUA<R!A<&EM<V=I9"`H05!)($UE<W-A
M9V4@240I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT
M($UE<W-A9V4@240I+B(*;7-G<W1R(").9?YI;F]M87,@8VQI;7-G:60@*$-L
M:65N="!-97-S86=E($E$*2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,34Y"B,L(&9U>GIY"FUS9VED(")5;FMN;W=N(&QO8V%T:6]N('!R
M;W9I9&5D+B(*;7-G<W1R(").96YU<W1A='ET82!V:65T;W;K+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,0IM
M<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B
M3F7^:6YO;6%S('9A<G1O=&]J;R!V87)D87,@:7(O87)B82!S;&%P=&'^;V1I
M<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-3@*;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT
M(@IM<V=S='(@(E!A;F%I:VEN=&D@;G5O<F]DX"#P:6%M(&5L96UE;G1U:2(*
M"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,CDV"FUS9VED
M(")5;FYA;65D(@IM<V=S='(@(DYEX79A<F1I;G1A<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N
M<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S
M=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@
M0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO
M<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T
M;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@HB4V%U9W5M;R!S
M=6UE=&EM86ES(&YE<')I=FEL96=I:G5O=&D@<VMR:7!T86D@;F5G86QI(&%T
M;&EK=&D@4&5R:^ML:6UO+R(*(DMO<&EJ879I;6\OP6OK;&EM;R!P<F]G<F%M
M:?!K86DN($YO<NMD86UI('!E<OYI^W+K=&D@=&5C:&YI;F5S(&1E=&%L97,@
M(@HB;6]Z:6QL82YO<F<@=&EN:VQA<'EJ92P@:7(@<W7^:6YO=&D@:V%I<"!S
M:W)I<'1A;7,@;&5I<W1I('!R:65I=&D@<')I92`B"B)L86EK:6YO<VEO<R!S
M875G>6ML;W,L('!A<W!A=7-K:71E($]++B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T
M(&-O;&]R(@IM<V=S='(@(DYE;F%U9&]T:2!S<&%L=F]S(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#8@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HY,C8*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HY,S(*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*
M;7-G<W1R(")0;.MT:6YY<R!N97!A;&%I:V]M87,B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C$Y-R!T96UP;&%T97,O861M:6XO=7-E<B]L
M:7-T+FEN8SHS,PIM<V=I9"`B57!D871E(@IM<V=S='(@(D%T;F%U:FEN=&DB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C(Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R(")!=&YA=6II;G1I
M("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-@IM
M<V=I9"`B57!D871E('5S97(B"FUS9W-T<B`B071N875J:6YT:2!V87)T;W1O
M:N`B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$T-"!A9&UI;B]P97)M<R]E9&ET
M+G!H<#HQ,#(@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S,`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@
M(B<E<R<@871N875J:6YT82XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HX,PIM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B
M071N875J:6YI;6\@<VMR:7!T87,@:?!T<FEN=&%S+B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-S@@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$Y.0IM<V=I9"`B57!L;V%D(@IM<V=S='(@(DYU<VGX<W1I
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D
M960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N
M(@IM<V=S='(@(E9I<VD@;6]D=6QI^"!A=&YA=6II;FEM;R!F86EL86D@X6ME
M;'1I(.$@<V5R=F5RX2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L:7-T='EP95]L86YG+FIS.C(P"FUS9VED(")5<'!E<B!L871I;B!L
M971T97)S(@IM<V=S='(@(D1I9/YI;W-I;W,@;&]T:6YI\&MO<R!R86EDZW,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@
M(D1I9&EE:FD@<F]MZVYI\&MI('-K86GH:6%I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM
M<V=I9"`B57)U9W5A>2(*;7-G<W1R(")5<G5G=F%J=7,B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`B3F%U9&]T
M:2!D86)A<G1I;N8Z("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B
M3F%U9&]T:2!34TPB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS
M9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-
M4U`@<V5R=F5R+B(*;7-G<W1R(").875D;W1I(&IE:6=U('9A<G1O=&]J;R!V
M87)D87,O<VQA<'1A_F]D:7,@24U34"!S97)V97)I=6D@>7)A(&MI=&]K<RXB
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"B,L(&9U
M>GIY"FUS9VED(")5<V5R(@IM<V=S='(@(E9A<G1O=&]J86DB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<R,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB
M"FUS9W-T<B`B5F%R=&]T;VIA<R`E<R!N96%U=&]R:7IU;W1A<R!P<FGK:FEM
M=6D@<')I92`E<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S
M97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`B5F%R=&]T;VKX(&%D;6EN:7-T
M<F%V:6UA<R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C4Q
M"FUS9VED(")5<V5R($]P=&EO;G,B"FUS9W-T<B`B5F%R=&]T;VIO(&YU<W1A
M='EM86DB"@HC.B!S:6=N=7`N<&AP.C8R"FUS9VED(")5<V5R(%)E9VES=')A
M=&EO;B(*;7-G<W1R(")687)T;W1O:O@@<F5G:7-T<F%C:6IA(@H*(SH@<VEG
M;G5P+G!H<#HR,@IM<V=I9"`B57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@
M9&ES86)L960@9F]R('1H:7,@<VET92XB"FUS9W-T<B`B5F%R=&]T;VKX(')E
M9VES=')A8VEJ82!I\&IU;F=T82XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-#8Y"B,L(&9U>GIY"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD
M(@IM<V=S='(@(B5S(&YE<F%S=&%S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.3@*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34P('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C,S"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z-S(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*
M;7-G:60@(E5S97)N86UE(@IM<V=S='(@(E9A<G1O=&]J;R!V87)D87,B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@86QR96%D>2!E
M>&ES=',N(@IM<V=S='(@(E9A<G1O=&]J;R!V87)D87,@)R5S)R!J874@96=Z
M:7-T=6]J82XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*
M;7-G:60@(E5S97)N86UE.B(*;7-G<W1R(")687)T;W1O:F\@=F%R9&%S.B(*
M"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*;7-G:60@(E5S97)N
M86UE.B`B"FUS9W-T<B`B5F%R=&]T;VIO('9A<F1A<SH@(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@:6X@=&AE
M('-Y<W1E;3HB"FUS9W-T<B`B5F%R=&]T;VIA:2#P:6]J92!S:7-T96UO:F4Z
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B57IB96MI<W1A;B(*;7-G<W1R(")5
M>F)E:VES=&%N87,B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ
M-C,@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C4U"FUS9VED(")61E,@
M9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")61E,@:V%T86QO
M9V%S(&YE96=Z:7-T=6]J82XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3$X"FUS9VED(")686-A=&EO;B(*;7-G<W1R(")!=&]S=&]G;W,B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-C8*;7-G:60@(E9A;&ED(&QO
M8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`B4F%S=&]S('1E:7-I
M;F=O<R!V:65T;W;K<SH@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV,S@*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(D=A;&EO:FEM
M87,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4Y-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR-34*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N
M(@IM<V=S='(@(E)E:6OP;>L@;6EN=73K;6ES(&YU;R!D86)A<BXB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-38@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")686QU92!I<R!O=F5R
M('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-"!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,C8V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,38@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR.`HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED(")686QU97,B"FUS9W-T
M<B`B4F5I:_!MZW,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`Y
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#8*;7-G:60@(E9A;'5E<R!T
M;R!S96QE8W0@9G)O;2(*;7-G<W1R(")296EK\&WK<R!I\"!K=7)I^"!G86QI
M;6$@<&%S:7)I;FMT:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E9A;G5A='4B
M"FUS9W-T<B`B5F%N=6%T=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-#0*;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@(DMI;G1A;G1I<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R(")696YE
M<W5E;&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q
M.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M
M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(E!A='9I<G1I
M;FEM87,@;F5B86EG=&%S("T@\&ES(&QA:?!K87,@<W5G861I;G1A<RXB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B
M5F5R<VEO;B(*;7-G<W1R(")697)S:6IA(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(R-@IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@
M(E9E<G-I:O@@:V]N=')O;.LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A;&EG
M;B(*;7-G<W1R("),>6=I=6]T:2!V97)T:6MA;&EA:2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I
M8V%L('!A9&1I;F<B"FUS9W-T<B`B5F5R=&EK86QU<R!T87)P87,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@S"FUS9VED
M(")697)T:6-A;#HB"FUS9W-T<B`B5F5R=&EK86QU<SHB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I9"`B5F5R>2!(
M:6=H(@IM<V=S='(@(DQA8F%I(&1I9&5L:7,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS
M9VED(")6:65T($YA;2(*;7-G<W1R(")6:65T;F%M87,B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5FEE=&YA;65S92`H5DE30TE)*2(*
M;7-G<W1R(")6:65T;F%M:65T:?!K82`H5DE30TE)*2(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.CDV,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")6:65W("5S(@IM<V=S='(@(E!E<OYI^W+K=&D@)7,B"@HC.B!L:6(O
M0FQO8VLO:69R86UE+G!H<#HS"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E
M8B!P86=E(@IM<V=S='(@(E)O9'ET:2!I\&]R:6[A('!U<VQA<.$B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,C$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R(")097+^:?MRZW1I(&MA
M:7`@)7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@
M0G)I=&ES:"(*;7-G<W1R(")"<FET^"!6:7)D_FEN:6IO<R!S86QO<R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S
M='(@(DI!5B!6:7)D_FEN:6IO<R!S86QO<R(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C`Y"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S='(@(DUA=&]M=6UA
M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-C,*;7-G:60@
M(E9I<VEB:6QI='DZ("(*;7-G<W1R(")-871O;75M87,Z("(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS
M9VED(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R(")6;V1A9F]N
M92!)=&%L:6IA('!E<B!33510(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B
M5T%23B(*;7-G<W1R(")705).(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!214U/5D4@
M4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(D3+345324\A(2$@
M4$%465,@2=!44DE.2TE412!32U))4%3`($G0("5S+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"B,L(&9U>GIY"FUS9VED
M(")724X@=FEA($A45%`B"FUS9W-T<B`B<VUS,F5M86EL('!E<B!(5%10(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-PIM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T
M<B`B5F%L:7,@:7(@1G5T=6YA(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR-S(@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C@S"FUS9VED(")787)N:6YG(@IM<V=S='(@(D3K;65S
M:6\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C4X"FUS9VED(")792(*;7-G<W1R(")4<F7H+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*
M;7-G<W1R(")/<O@@<')O9VYO>NLB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-#(W"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED960@8GDB
M"FUS9W-T<B`B3W+X('!R;V=N;WKK('!A9V%L(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#DR"FUS9VED(")796%T:&5R+F-O;2(*;7-G<W1R(")7
M96%T:&5R+F-O;2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED
M(")796(B"FUS9W-T<B`B5U=7(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0S-PIM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B5U=7('!U<VQA<&ES
M(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU
M.`IM<V=I9"`B5V5E:VQY(@IM<V=S='(@(DMA<R!S879A:73F(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*;7-G:60@(E=E;&-O;64B"FUS
M9W-T<B`B4W9E:6MI(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z
M-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W"B,L('!H<"UF;W)M870*
M;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B4W9E:6MI(&%T=GEKYB#A
M("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA
M=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E
M;&-O;64L("5S(@IM<V=S='(@(DQA8F%S+"`E<R(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DU"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G
M<W1R(")686MA<O@@*$E33RTX.#4Y+3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.38*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R
M(")686MA<O@@*$E33RTX.#4Y+3$U*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")7
M97-T97)N(%-A:&%R82(*;7-G<W1R(")686MA<O@@4V%C:&%R82(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I
M;C\B"FUS9W-T<B`B2V]KX2!M;V1U;.$@)7,@='5R:2!R;V1Y=&D@<&\@<')I
M<VEJ=6YG:6UO/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T
M"FUS9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G
M<W1R(")+;VMS('-K:7)T=6MO('-I;6)O;&ES/R(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T(&ES('1H92!Q=6]T92!C
M:&%R86-T97(_(@IM<V=S='(@(DMO:W,@:V%B=>AI^"!S:6UB;VQI<S\B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V,0HC
M+"!F=7IZ>0IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S='(@
M(D%U<W1R86QI:F$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@
M(E=H:6-H('!H87-E<R(*;7-G<W1R(")+=7)I;W,@9F%ZZW,B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3,S"FUS9VED(")7:&EC:"!P;'5G:6YS('1O
M(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@(DA4
M34P@<F5D86MT;W)I875S(&UO9'5L:?@@X6IU;F=I;6%S+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G
M:60@(E=I9'1H(@IM<V=S='(@(E!L;W1I<R(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,Q,C4*;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G
M<W1R(")0;&]T:7,@0U-3(&UA=&%I<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S
M(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI
M;BDZ(@IM<V=S='(@(B5S(&MA:7)I;VIO(&UE;FEU('!L;W1I<R`H<&%K96ET
M:6UA:2!B=7,@;6%T>71I('!O(&MI=&\@<')I<VEJ=6YG:6UO*3HB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I
M9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@(DQE;G1E;.MS('!L;W1I
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$P"FUS9VED(")7:61T:"!U;FET(@IM<V=S='(@(E!L;^AI;R!M871A<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U
M"FUS9VED(")7:61T:#HB"FUS9W-T<B`B4&QO=&ES.B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HU,3,*;7-G:60@(E=I:VDB"FUS9W-T<B`B5VEK
M:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C4*(RP@9G5Z>GD*;7-G
M:60@(E=I;F0B"FUS9W-T<B`B5NMJ87,Z(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*(RP@9G5Z>GD*;7-G:60@(E=I;F0@
M16%R;'DB"FUS9W-T<B`B3&EE='5S(')Y=&4B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C@P"FUS9VED(")7:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@
M(E;K:F\@9W)E:71I<R!M87IG86ES(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ-38*;7-G:60@(E=I;F0Z(@IM<V=S='(@(E;K:F%S.B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#(*;7-G:60@(E=I;F0Z("(*;7-G
M<W1R(")6ZVIA<SH@(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS
M9VED(")7:7-D;VTB"FUS9W-T<B`B2?!M:6YT:7,B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3DV"B,L(&9U>GIY"FUS9VED(")7:7-H;&ES="(*
M;7-G<W1R(")086=E:61A=FEM86DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C4*;7-G:60@(E=O<FLB"FUS9W-T<B`B1&%R8F%S(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K
M($%D9')E<W,B"FUS9W-T<B`B1&%R8F\@861R97-A<R(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@
M4&AO;F4B"FUS9W-T<B`B1&%R8F\@=&5L969O;F%S(@H*(SH@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z,38Y(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@
M9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S`P"B,L
M('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X
M<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,3$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE
M+B(*;7-G<W1R(")3:7-T96UA(&YE='5R:2!T96ES:?@@<W5K=7)T:2!61E,@
M9F%I;.`N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T,PIM<V=I
M9"`B6"U2968B"FUS9W-T<B`B6"U2968B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S($)A<VEC($-O;G-T
M<F%I;G1S(@IM<V=S='(@(E@U,#EV,R!P86=R:6YD:6YI86D@;G5S=&%T>6UA
M:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DR"FUS
M9VED(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(E@U,#EV
M,R!I\'!LZW-T;R!R86MT;R!P86YA=61O:FEM87,B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S(%-U8FIE
M8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R(")8-3`Y=C,@86QT97)N871Y
M=G5S('9A<F1A<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<B(*
M;7-G<W1R(")8-3`Y=C,@<F%K=&\@:61E;G1I9FEK871O<FEU<R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@R"FUS9VED(")8-3`Y
M=C,@97AT96YS:6]N<R(*;7-G<W1R(")8-3`Y=C,@;6]D=6QI86DB"@HC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T<B`B65DB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-34*;7-G
M:60@(EE965DB"FUS9W-T<B`B65E962(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,3`X"FUS9VED(")986AO;R$@;6%P(@IM
M<V=S='(@(EEA:&]O(2#^96WK;&%P:7,B"@HC.B!F<F%M97=O<FLO36%I;G1E
M;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T
M<B`B2V%S;65T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B665M96XB"FUS9W-T
M<B`B2F5M96YA<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HY-C,*;7-G:60@(EEE<R(*;7-G<W1R(")486EP(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@
M(EEE<RP@22!!9W)E92(*;7-G<W1R(")486EP+"!A\"!S=71I;FMU(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I
M9"`B66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N
M('1O('-W:71C:"!B86-K('1O(%=94TE764<N(@IM<V=S='(@(B(*(DK[<R!E
M<V%T92!414M35$E.24%-12!21=Y)344N($YO<NMD86UI(&=RX?YT:2#A(%=9
M4TE764<@<W!A=7-K:71E(%L\/ETN(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D
M:70N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L
M;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,30Q,0IM<V=I9"`B
M66]U(&%R92!N;W0@875T:&5N=&EC871E9"XB"FUS9W-T<B`B2OMS(&YE<')I
M<VEJ=6YGYBXB"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP
M.C,P,@IM<V=I9"`B66]U(&-A;B!N;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T
M97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(E-A=F\@=F%R9&4@;F5G
M86QI=&4@;F%U9&]T:2!S:6UB;VQI;R`G7%PG+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$X-34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW
M-0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R
M97-S+B(*;7-G<W1R("+!=F5DZW1E(&YE=&5I<VEN9^`@96PN('!A\'1O(&%D
M<F5SX"XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F
M<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I
M96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B3F5P<FEJ=6YGZW1E(&IO:VGX(&QA
M=6OX(&GP(.%K96QI86UO(&9A:6QO('!R:64@)7,@871I=&EN:V%M^"!L875K
M^"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#@*;7-G:60@(EEO
M=2!H879E(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`B2OMS(&%T<VEJ=6YG
MZW1E+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-C$*;7-G:60@
M(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E
M<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H
M92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"B)4
M=7)I=&4@X79E<W1I('1E:7-I;F?@('1E;&5F;VYO(&YU;65RX2`H=&EK('-K
M86GH:75S(&ER("<K)RP@:F5I9W4@;F]R:71E("(*(FYU<F]D>71I('1A<G!T
M875T:6[A(&MO9.`I+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q
M.#@*;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N(@IM
M<V=S='(@(L%V963K=&4@;F5T96ES:6YGX"!R96EK\&WF+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@
M8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB
M"FUS9W-T<B`B(@HB3F]RZV1A;6D@;F%U9V]T:7,@<F5G:7-T<F%C:6IO<R!S
M:7-T96UA+"!T=7)I=&4@<W5K;VYF:6?[<G5O=&D@9'5O;65N^"`B"B)M963^
M:6\@<&]S:7-T96WF+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M-#4V"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@
M8F%C:V5N9"XB"FUS9W-T<B`B(@HB3F]RZV1A;6D@;F%U9V]T:7,@<F5G:7-T
M<F%C:6IO<R!S:7-T96UA+"!T=7)I=&4@<W5K;VYF:6?[<G5O=&D@9'5O;65N
M^"`B"B)M963^:6\@<&]S:7-T96WF+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@
M<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R
M="XB"FUS9W-T<B`B4')I9?`@<VGX<V1A;6D@<')A;F7P:6W@+"!A<')A\'EK
M:71E('!R;V)L96W@+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H92!54DP@
M=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*;7-G<W1R("+!<F'P>6MI=&4@
M;G5O<F]D;W,@55),(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z
M.#`*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L
M971E9"XB"FUS9W-T<B`B5'5R:71E('!A<VER:6YK=&D@<V5R=F5RX2P@:W5R
MX2!N;W)I=&4@:?!T<FEN=&DN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$Y"FUS
M9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T
M+B(*;7-G<W1R(").=7)O9'EK:71E('9A<G1O=&]J;R!V87)DX"P@:W5R:6\@
M9'5O;65N:7,@=')I;F%T92XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#`*;7-G
M:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N(@IM
M<V=S='(@(DYU<F]D>6MI=&4@=F%R=&]T;VIO('9A<F3@('1R>6YI;75I+B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA
M;64@=&\@861D+B(*;7-G<W1R(").=7)O9'EK:71E(&MU<FEA;6\@=F%R=&]T
M;VIO('9A<F3@+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@IM<V=I9"`B66]U
M(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*;7-G<W1R
M(").=7)O9'EK:71E(&%T;F%U:FEN86UO('9A<G1O=&]J;R!V87)DX"XB"@HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S@*;7-G
M:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB
M"FUS9W-T<B`B3G5R;V1Y:VET92!V96EK<VW@+B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"FUS9VED(")9;W4@
M;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(DK[<R!T
M=7)I=&4@X79E<W1I(&YA=6IO<R!K871E9V]R:6IO<R!P879A9&EN:6W@+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N
M<&AP.C<S"FUS9VED(")9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@
M<&AO;F4@;G5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.CDW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R("5S('-E<W-I
M;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B
M)7,@<V5S:6IA(&)A:6?K<VDN(%!R8?!O;64@<')I<VEJ=6YG=&D@:?`@;F%U
M:F\N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*;7-G
M:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R(")*^W/X(&5L+B!P8?!T
M;R!A9')E<V%S.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,3(*;7-G
M:60@(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`B16PN('!A\'1O(&%D
M<F5S87,Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8T(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y"FUS9VED(")9;W5R($EN9F]R;6%T
M:6]N(@IM<V=S='(@(DEN9F]R;6%C:6IA(&%P:64@2G5S(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z.3@P"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(EEO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@
M8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y
M;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B
M(@HB3G5O("5S('-E<VEJ;W,@<')A9/YI;W,@:OMS^"!)4"!A9')E<V%S('!A
M<VEK96ETZRX@5'5R:71E('!R:7-I:G5N9W1I(&GP("(*(FYA=6IO+B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED(")9;W5R
M($YA;64B"FUS9W-T<B`B2OMS^"!V87)D87,O<&%V87)DZR(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHU"B,L(&9U>GIY"FUS9VED("(B
M"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R
M="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D92!T
M;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I
M9F9E<F5N="`B"B)A=71H96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R("(B
M"B)*^W/X('-I<W1E;6]S(&%U=&5N=&EF:6MA=FEM;R!P;W-I<W1E;>L@;F5P
M86QA:6MO('9A<G1O=&]J^"!K^W)I;6\L(&%R8F$@\&D@(@HB9V%L:6UY8NL@
M:?!J=6YG=&$@9.ML('1A;2!T:6MR^"!P<FEE_F%SZ&GX+B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A
M=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN
M9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@
M9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"B)*^W/X(&%U=&5N
M=&EF:6MA=FEM;R!S:7-T96UA(&YE<&%L86EK;R!V87)T;W1O:O@@<^!R8?!O
M+"!A<F)A(/!I(&9U;FMC:6IA("(*(G7^9')A=7-T82!DZVP@=&%M('1I:W+X
M('!R:67^87/H:?@N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@T
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S
M('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@
M)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@
M;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB3G5O("5S('-E<VEJ;W,@
M<')A9/YI;W,@:OMS^"!N87+P>6MLZW,@=&EP87,@<&%S:6ME:73K+B!4=7)I
M=&4@<')I<VEJ=6YG=&D@(@HB:?`@;F%U:F\N(@H*(SH@;&EB+T)L;V-K+VEF
M<F%M92YP:'`Z-3`*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`B2OMS^"!N87+P>6MLZR!N97!A
M;&%I:V\@\&EO<R!G86QI;7EBZW,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O<')I;G0N:G,Z-#(*(RP@9G5Z>GD*;7-G:60@(B(*(EEO=7(@8G)O=W-E
M<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#
M;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R("(B"B)*
M^W/X(&YA<O!Y:VSK(&YE<&%L86EK;R#P:6\@<W!A=7-D:6YI;6\@;G5S=&%T
M>6UO+B!.;W+K9&%M:2!A='-P875S9&EN=&D@(@HB<W!A=7-K:71E($-O;G1R
M;VPO3W!T:6]N("L@4"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4W
M"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R(")*^W/X
M(&QA:6MO(&IU;W-T83HB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.38*(RP@
M9G5Z>GD*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C
M:&%N9V5D+B(*;7-G<W1R(")*^W/X('-T86YD87)T:6YI<R!A<')A\&%S.B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3@*;7-G:60@(EEO=7(@9&5F
M875L="!I9&5N=&ET>3HB"FUS9W-T<B`B2OMS^"!S=&%N9&%R=&EN:7,@87!R
M8?!A<SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`Q"FUS9VED(")9
M;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`B2OMS^"!V87)D87,O<&%V87)DZSHB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HQ,#`P"B,L(&9U>GIY"FUS
M9VED(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")*^W/X(&YU
M<W1A='EM86D@871N875J:6YT:2XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S
M=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@(DK[<_@@;F%U:F%S("5S('-L
M87!T8?YO9&ES('ER83H@)7,B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C$U-`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@
M8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N
M+B(*;7-G<W1R(")*^W/X(&YU<W1A='EM86D@871N875J:6YT:2XB"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O
M<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R(")*^W/X(&YU<W1A
M='EM86D@871N875J:6YT:2XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="(*
M;7-G<W1R(")*^W/X('-L87!T8?YO9&ES('!A:V5I<W1A<R(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W
M;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@
M:6X@=VET:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@HB2OMS
M^"!S;&%P=&'^;V1I<R!P86ME:7-T87,N(%!A<VET:6MR:6YK:71E('-A=F\@
M<&'P=.`@:7(@<')I<VEJ=6YK:71E('-U("(*(FYA=6IU('-L87!T8?YO9/YI
M=2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,S(*(RP@9G5Z>GD*
M;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S='(@(DK[
M<_@@<VQA<'1A_F]D:7,@<&%K96ES=&%S(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*
M;7-G<W1R(")*^W/X(&YU=&]LYB!S97)V97)I86DZ(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-30@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q.`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R(")*=6=O<VQA=FEJ
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@
M(EIA:7)E(@IM<V=S='(@(EIA:7)A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@
M(EIA;6)I82(*;7-G<W1R("):86UB:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I
M9"`B6FEM8F%B=V4B"FUS9W-T<B`B6FEM8F%B=NLB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-C8*;7-G:60@(EII<'!Y(@IM<V=S='(@(D5N97)G:6YG
M;W,B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H
M='%U;W1E<RYP:'`Z,3<R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E
M0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T
M<B`B6U!A<VSK<'1I(&-I='5O:F%MX"!T96MS=.!=(@H*(SH@<V5R=FEC97,O
M<')O8FQE;2YP:'`Z.#@*;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T
M<B`B6U!R;V)L96UO<R!P<F%N9?!I;6%S72(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(");4VAO=R!1=6]T960@
M5&5X="`M(@IM<V=S='(@(EM2;V1Y=&D@8VET=6]J86W@('1E:W-TX"`M(@H*
M(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T
M97,N<&AP.C$W,@HC+"!P:'`M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T960@
M5&5X="`M("5S(&QI;F5S72(*;7-G<W1R(");4F]D>71I(&-I='5O:F%MX"!T
M96MS=.`@+2`E<R!E:6QU=&5S72(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F("5S
M72(*;7-G<W1R(");96EL=73K("5S(&GP("5S72(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,34T,2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC
M.C$Q"FUS9VED(")?061M:6YI<W1R871I;VXB"FUS9W-T<B`B7U9A;&1Y;6%S
M(@H*(SH@;&EB+V%P:2YP:'`Z,34W"FUS9VED(")?0TQ)(@IM<V=S='(@(E]#
M3$DB"@HC.B!L:6(O87!I+G!H<#HQ-#$*;7-G:60@(E]$871A5')E92(*;7-G
M<W1R(")?1'5O;65N^"!M961I<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T92!2
M;W<B"FUS9W-T<B`B7TGP=')I;G1I(&5I;'5TYB(*"B,Z(&QI8B]A<&DN<&AP
M.C$S,PIM<V=I9"`B7T=R;W5P<R(*;7-G<W1R(")'7W)U<.MS(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W-0IM<V=I9"`B7TAE;'`B
M"FUS9W-T<B`B4&%?9V%L8F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P
M97)T:65S+BXN(@IM<V=S='(@(E]0879E:6MS;.ML:6\@;G5S=&%T>6UA:2XN
M+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.30*;7-G
M:60@(E],;V<@:6XB"FUS9W-T<B`B4')I<VE?:G5N9W1I(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I9"`B7TQO9R!O=70B
M"FUS9W-T<B`B071S:5]J=6YG=&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@
M3&EN:RXN+B(*;7-G<W1R(")?2V5I<W1I(&YU;W)O9.`N+B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-C0*;7-G:60@(E]/<'1I;VYS
M(@IM<V=S='(@(E].=7-T871Y;6%I(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS
M9VED(")?4&5R;6ES<VEO;G,B"FUS9W-T<B`B7U1E:7/K<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@IM
M<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@(E])\'1R:6YT:2!N=6]R
M;V3@+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3(U"FUS9VED(")?4V5T=7`B"FUS
M9W-T<B`B7TMO;F9I9_MR86-I:F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L92!0
M<F]P97)T:65S+BXN(@IM<V=S='(@(E],96YT96SK<R!N=7-T871Y;6%I+BXN
M(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?57-E<G,B"FUS9W-T<B`B
M5E]A<G1O=&]J86DB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR
M,0IM<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(F%D<F5S^"!K;GEG96SK
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S0*(RP@
M9G5Z>GD*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(F%D<F5S
M^"!K;GEG96SK(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3,*
M;7-G:60@(F-A;&5N9&%R(@IM<V=S='(@(DMA;&5N9&]R:75S(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R(")R86UU<R(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED(")C
M86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@
M;W!E;B!I;G!U="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HU.3(*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B
M<W!A=7-K:71E(.AI82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-S@*(RP@9G5Z>GD*;7-G:60@(F-O;F9I9W5R871I;VX@97)R;W(B"FUS9W-T
M<B`B)7,@;G5S=&%T>6UA:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,34T"FUS9VED(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S
M:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,3(V"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$X,@HC+"!F
M=7IZ>0IM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S='(@(B5S(&YE<F%S
M=&%S+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C<Q"FUS9VED(")F86QL:6YG(@IM<V=S='(@(FMR96YT82(*"B,Z(&9R86UE
M=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U-0IM<V=I9"`B9FEL92(*;7-G
M<W1R(")F86EL87,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W-"!L:6(O
M0FQO8VLO;65T87(N<&AP.C,V,"!L:6(O0FQO8VLO;65T87(N<&AP.C,X-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S
M(@IM<V=S='(@(FYU;R`E<R`H)7,I("5S("5S(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(U,`HC+"!F=7IZ>0IM<V=I9"`B9W5S=&EN9R(*
M;7-G<W1R("(L(&?[<VEA:2`E<R`E<R(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR-#D*;7-G:60@(F@Z(@IM<V=S='(@(F$Z
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U
M.`IM<V=I9"`B:&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E(@IM<V=S='(@(G1U
M;VIA=2!P870B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S
M971U<"]D:69F+G!H<#HW.0IM<V=I9"`B:6YL:6YE(@IM<V=S='(@(G!A<')A
M<W1I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*
M;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N
M86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G
M<W1R(")E:6QU=&5S72(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M
M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T
M<B`B;6MI<V]F<R!K;&%I9&]S(&MO9&%S("5D(&)E9&%R86YT($E33RXB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S8Y"FUS
M9VED(")M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C(Y,2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,S(*;7-G:60@(FYA;64B
M"FUS9W-T<B`B=F%R9&%S(@H*(SH@9G)A;65W;W)K+U)00R]24$,N<&AP.C$R
M,0IM<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(FYE<F5A;&EZ=6]T
M82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(Q.0IM
M<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*;7-G<W1R(")D87(@;F5R96%L
M:7IU;W1A(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#4*;7-G
M:60@(FYO=&5P860B"FUS9W-T<B`B=?YR8?#X(&MN>6=E;.LB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS
M9VED(")P97)C96YT(@IM<V=S='(@(G!R;V-E;G1A:2(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<T"B,L(&9U>GIY"FUS9VED(")P
M97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R(")496ESZW,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED
M(")P:7AE;',B"FUS9W-T<B`B<&EK<V5L:6%I(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I
M;B!P<F]T;V-O;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HW,PIM<V=I9"`B<FES:6YG(@IM<V=S='(@(FMY
M;&$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T,@HC
M+"!F=7IZ>0IM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R(")/
M<F\@<^!L>6?X(&)L;VMO(&[K<F$N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HY.0IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R(")R;V1Y
M=&D@<VMI<G1U;75S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*
M;7-G<W1R(")S;7,R96UA:6P@<&5R($A45%`B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@U"FUS9VED(")S<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW
M,@IM<V=I9"`B<W1E861Y(@IM<V=S='(@(G-T86)I;&DB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C,P.0IM<V=I9"`B<W=I=&-H(&]F9B!J879A
M<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,34P"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,CD*;7-G:60@(G1A<VL@
M;&ES="(*;7-G<W1R(")D87)B^"!SX')A\&%S(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL
M=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,S`U"B,L(&9U>GIY"FUS9VED(")T<GD@86=A:6XB"FUS9W-T<B`B2VEE:W9I
M96YO('!R:7-I:G5N9VEM;R!M971U(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B='EP
M92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R(")S;&%P
M=&'^;V3A('1U<FET92#A<F'P>71I(&1U(&MA<G1U<R(*"B,Z(&%D;6EN+W-E
M='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED
M(")U;FEF:65D(@IM<V=S='(@(G5N:69I:W5O=&DB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U!A<G0N<&AP.C(W"FUS9VED(")U;FYA;65D(@IM<V=S='(@
M(F1A;&ES(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R(")V
M87)T;W1O:F\@<&%S:7)I;FMI;6%S(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V
M0V%R9"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR-#$*;7-G:60@(G<Z(@IM<V=S='(@(G`Z(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@
M(G=E871H97(N8V]M(@H``'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+V1E
M7T1%+G!O````````````````````````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#<U,#`T,"`Q,#4Q-30S,S<T,B`P,3<T-C,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````(R!'97)M86X@=')A
M;G-L871I;VYS(&9O<B!(;W)D92!P86-K86=E"B,@1V5R;6%N(&UE<W-A9V5S
M(&9O<B!(;W)D92X*(R!#;W!Y<FEG:'0@*$,I(#(P,#$M,C`P-B!(;W)D92!0
M<F]J96-T"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S
M86UE(&QI8V5N<V4@87,@=&AE($AO<F1E('!A8VMA9V4N"B,@2F%N(%-C:&YE
M:61E<B`\:F%N0&AO<F1E+F]R9SXL(#(P,#$M,C`P-BX*(PHC(&UA<F=I;CH@
M077?96YA8G-T86YD"B,@<&%D9&EN9SH@26YN96YA8G-T86YD"B,@2&ES=&]R
M>3H@0VAR;VYI:PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R
M<VEO;CH@2&]R9&4@,RXQ+6-V<UQN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z
M(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R
M,#`V+3`W+3,Q(#$X.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P
M,#8M,#@M,#D@,38Z-#4K,#(P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!*86X@
M4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/EQN(@HB3&%N9W5A9V4M5&5A;3H@
M1V5R;6%N(#QD979`;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-12U697)S:6]N
M.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI
M<V\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X+6)I
M=%QN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,X-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(@*'9O<B`E
M<R!486=E;BDB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S-S0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@
M(B`H6G5G<FEF9G-T87-T92`E<RDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,SDU"B,L('!H<"UF;W)M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB
M"FUS9W-T<B`B("AI;B`E<R!486=E;BDB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,SDQ"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(@*&AE=71E
M*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S.3,*;7-G:60@(B`H
M=&]M;W)R;W<I(@IM<V=S='(@(B`H;6]R9V5N*2(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S.#D*;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R
M("(@*&=E<W1E<FXI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(T-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4P"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.38*;7-G:60@(B!A="`B"FUS9W-T
M<B`B(&UI="`B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(R,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y
M+B(*;7-G<W1R(")<(B5S7"(@:7-T(&ME:6X@5F5R>F5I8VAN:7,N(@H*(SH@
M9G)A;65W;W)K+T-,22]#3$DN<&AP.C(X-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R(")<(B5S
M7"(@:7-T(&ME:6YE(&?\;'1I9V4@075S=V%H;"XB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<P-PHC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$P.34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I
M<W1R>2XB"FUS9W-T<B`B7"(E<UPB(&ES="!I;B!D97(@2&]R9&4@4F5G:7-T
M<GD@;FEC:'0@:V]N9FEG=7)I97)T+B(*"B,Z(&9R86UE=V]R:R]4<F5E+U1R
M964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E92!R
M96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(D1E<B!"875M+5)E;F1E<F5R
M(&;\<B!<(B5S7"(@=W5R9&4@;FEC:'0@9V5F=6YD96XN(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S
M(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R(")<(B5S7"(@
M=W5R9&4@>G5M($=R=7!P96YS>7-T96T@:&EN>G5G96;\9W0N(@H*(SH@861M
M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@
M(EPB)7-<(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB
M"FUS9W-T<B`B7"(E<UPB('=U<F1E('IU;2!296-H=&5S>7-T96T@:&EN>G5G
M96;\9W0N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A
M9&1C:&EL9"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A
M<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(EPB)7-<(B!W=7)D92!N:6-H
M="!E<G-T96QL=#H@)7,N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@P
M"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N,F9-0B!A
M;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B4N,F9-0B`H)3,D+C)F)24I('9O
M;B`E,B0N,F9-0B!E<FQA=6)T96X@=F5R8G)A=6-H="(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)60@)7,@86YD("5S(@IM<V=S='(@(B5D("5S('5N9"`E<R(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,C8X(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HU.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y
M;W5R('!A<W-W;W)D(&5X<&ER97,N(@IM<V=S='(@(DEN("5D(%1A9V5N('=I
M<F0@26AR(%!A<W-W;W)T('5N9_QL=&EG+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y
M(&9O<F5C87-T(@IM<V=S='(@(B5D+51A9V4M5F]R:&5R<V%G92(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R`M($YO=&EC92(*;7-G<W1R("(E<R`M($AI;G=E:7,B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!&:6YG97)P<FEN="(*;7-G<W1R("(E<R!&:6YG97)A8F1R
M=6-K(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0R
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(E<R!+0B(*"B,Z('-E<G9I
M8V5S+VUA:6YT96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S
M='(@(B5S(%=A<G1U;F=S87)B96ET96X@+2!"97-TY'1I9W5N9R(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C(Q-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R("(E
M<RU+;VYF:6=U<F%T:6]N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N
M=7`N<&AP.C(V-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N(%5P(@IM
M<V=S='(@(B5S(%)E9VES=')I97)U;F<B"@HC.B!S97)V:6-E<R]M86EN=&5N
M86YC92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@
M06=R965M96YT(@IM<V=S='(@(B5S($YU='IU;F=S8F5D:6YG=6YG96XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0U,"!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C4Q-@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C8X.2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<V,@HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B)7,@97AI
M<W1I97)T(&)E<F5I=',N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C$@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C<@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-#$*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#<@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS
M9W-T<B`B)7,@;6ET("5S("5S(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O
M('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B
M96QO=RX@0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y
M;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B(@HB
M)7,@=VER9"!D:64@5V%R='5N9W-A<F)E:71E;B!D=7)C:&;\:')E;BP@9&EE
M('5N=&5N(&UA<FMI97)T('-I;F0N($UA<FMI97)E;B`B"B)3:64@86QL92!!
M=69G86)E;BP@9&EE(&IE='IT(&1U<F-H9V5F_&AR="!W97)D96X@<V]L;&5N
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-3@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`B)7,@:7-T(&YO
M='=E;F1I9R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@X"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&UI;G5T97,B"FUS9W-T<B`B)7,@36EN=71E;B(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(E
M<R!N:6-H="!G969U;F1E;BXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L
M:7-T+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S
M(@IM<V=S='(@(B5S(&)I<R`E<R!V;VX@)7,B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.CDU,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D
M9')E<W,@0F]O:R(*;7-G<W1R("(E<W,@061R97-S8G5C:"(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.30T"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B)7-S($MA;&5N9&5R(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(B5S<R!.;W1I>F)L;V-K(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY-C`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("(E<W,@075F9V%B96YL:7-T
M92(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z
M("5S(@IM<V=S='(@(B5S.B`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VAT;6PN<&AP.C$R-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E
M<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM
M<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@
M:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N
M86P@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*(B5S.B!$:65S92!.86-H<FEC
M:'0@<W1A;6UT('5N=&5R(%5M<W3D;F1E;B!N:6-H="!V;VX@9&5M(&%N9V5G
M96)E;F5N("(*(D%B<V5N9&5R+B!&;VQG96X@4VEE(&ME:6YE;B!,:6YK<R!I
M;B!D:65S97(@3F%C:')I8VAT('5N9"!H_'1E;B!3:64@<VEC:"`B"B)D879O
M<BP@9&5M($%B<V5N9&5R('!E<G/V;FQI8VAE($1A=&5N('!R96ES>G5G96)E
M;BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4T(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.3D*;7-G:60@(BP@9W5S=&EN9R`B
M"FUS9W-T<B`B+"!B]FEG("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3DP
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3DU"B,L('!H<"UF;W)M870*;7-G:60@
M(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(L(&)I9R`E<R`E<R(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C`S"B,L('!H<"UF;W)M870*;7-G:60@(BP@
M=F%R:6%B;&4@9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(L('-C:'=A;FME;F0@
M=F]N("5S(&)I<R`E<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,CDT(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S0X"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P.#<@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C$T-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-S0X"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B+2T@075S
M=^1H;&5N("TM(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P"FUS9VED("(Q
M,B!(;W5R($9O<FUA="(*;7-G<W1R("(Q,BU3='5N9&5N+49O<FUA="(*"B,Z
M(&QI8B]";&]C:R]T:6UE+G!H<#HQ.0IM<V=I9"`B,C0@2&]U<B!&;W)M870B
M"FUS9W-T<B`B,C0M4W1U;F1E;BU&;W)M870B"@HC.B!T96UP;&%T97,O9&%T
M82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@4W1U
M;F1E;B(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z-CD*;7-G:60@
M(CQ0<F5V:6]U<R(*;7-G<W1R("(\6G5R_&-K(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ,C8*;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U
M:7)E9"!F;W(@=&AI<R!B;&]C:RXB"FUS9W-T<B`B1G(@9&EE<V5N($)L;V-K
M('=I<F0@96EN92!$871E;F)A;FL@8F5N=&EG="XB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$W,0IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@
M;V-C=7)R960B"FUS9W-T<B`B16EN('-C:'=E<F5R($9E:&QE<B!I<W0@875F
M9V5T<F5T96XZ(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M.30T"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N
M8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"B)%:6X@]F9F96YT;&EC:&5R
M(%!'4"U38VAL_'-S96P@=VER9"!F_'(@9&EE(%9E<G-C:&S\<W-E;'5N9R!E
M:6YE<B!.86-H<FEC:'0@(@HB8F5N]G1I9W0N(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3$W-PIM<V=I9"`B02!P=6)L:6,@4$=0(&ME
M>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS
M9W-T<B`B(@HB16EN(/9F9F5N=&QI8VAE<B!01U`M4V-H;/QS<V5L('=I<F0@
M9OQR(&1I92#<8F5R<'+\9G5N9R!E:6YE<B`B"B)U;G1E<GIE:6-H;F5T96X@
M3F%C:')I8VAT(&)E;O9T:6=T+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$Q,#@*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R
M:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"B)%:6X@]F9F96YT
M;&EC:&5R('5N9"!E:6X@<')I=F%T97(@4$=0+5-C:&S\<W-E;"!S;W=I92!E
M:6X@4&%S<W=O<G0@=VER9"!F_'(@(@HB9&EE($5N='-C:&S\<W-E;'5N9R!E
M:6YE<B!.86-H<FEC:'0@8F5N]G1I9W0N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3`R-0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME
M>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(D5I;B#V9F9E
M;G1L:6-H97(@=6YD(&5I;B!P<FEV871E<B!01U`M4V-H;/QS<V5L('-O=VEE
M(&5I;B!087-S=V]R="!W:7)D(&;\<B`B"B)D:64@56YT97)Z96EC:&YU;F<@
M96EN97(@3F%C:')I8VAT(&)E;O9T:6=T+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3`V"FUS9VED("(B"B)!('!U8FQI8R!3+TU)
M344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B
M(@HB16EN(/9F9F5N=&QI8VAE<B!U;F0@96EN('!R:79A=&5R(%,O34E-12U3
M8VAL_'-S96P@<V]W:64@96EN(%!A<W-W;W)T('=I<F0@(@HB9OQR(&1I92!%
M;G1S8VAL_'-S96QU;F<@96EN97(@3F%C:')I8VAT(&)E;O9T:6=T+B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B
M"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G
M92XB"FUS9W-T<B`B(@HB16EN(/9F9F5N=&QI8VAE<B!U;F0@96EN('!R:79A
M=&5R(%,O34E-12U38VAL_'-S96P@<V]W:64@96EN(%!A<W-W;W)T('=I<F0@
M(@HB9OQR(&1I92!5;G1E<GIE:6-H;G5N9R!E:6YE<B!.86-H<FEC:'0@8F5N
M]G1I9W0N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS
M-C0*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E
M;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@HB16EN(/9F9F5N=&QI8VAE
M<B!3+TU)344M4V-H;/QS<V5L('=I<F0@9OQR(&1I92!697)S8VAL_'-S96QU
M;F<@96EN97(@(@HB3F%C:')I8VAT(&)E;O9T:6=T+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.CD*;7-G:60@(D%-($-L;W5D
M<R(*;7-G<W1R(")6;W)M:71T86=S(%=O;&ME;B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!,:6=H="!2
M86EN(@IM<V=S='(@(E9O<FUI='1A9W,@;&5I8VAT97(@4F5G96XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B
M04T@3&EG:'0@4VYO=R(*;7-G<W1R(")6;W)M:71T86=S(&QE:6-H=&5R(%-C
M:&YE969A;&PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ,@IM<V=I9"`B04T@4F%I;B(*;7-G<W1R(")6;W)M:71T86=S(%)E
M9V5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,3,*;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`B5F]R;6ET=&%G<R!38VAA
M=65R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,30*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")6;W)M:71T86=S
M(%-C:&YE97-C:&%U97(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR
M.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`B04TO4$TB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%0
M22!)1"(*;7-G<W1R(")!4$D@240B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O
M<B(*;7-G<W1R("+<8F5R(&1I97-E;B!%9&ET;W(B"@HC.B!S97)V:6-E<R]H
M96QP+VEN9&5X+G!H<#HU-`IM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B26YF
M;RXN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R(")!8G-O;'5T(%5N=&5N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M,@IM<V=I9"`B06)S;6ED9&QE(@IM<V=S='(@(D%B<V]L=70@36ET=&4B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C@Q"FUS9VED(")!8V-E
M<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(EIU
M9W)I9F8@=F5R=V5I9V5R="!B96EM($%N;&5G96X@9&5S(%9&4RU697)Z96EC
M:&YI<W-E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3,U
M"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G
M<W1R("):=6=R:69F('9E<G=E:6=E<G0@8F5I;2!!;FQE9V5N(&1E<B!61E,M
M1&%T96DN(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C,*;7-G:60@(D%C
M8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B2V]N=&]I;F9O<FUA=&EO;F5N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X"FUS9VED(")!8V-O=6YT
M(%!A<W-W;W)D(@IM<V=S='(@(DMO;G1O<&%S<W=O<G0B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*;7-G:60@
M(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R(")+;VYT;R!E:6YG969R;W)E;BXB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,U"FUS9VED(")!8V-O
M=6YT:6YG(@IM<V=S='(@(D)U8VAH86QT=6YG(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC
M.C$T"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q
M"FUS9VED(")!9&0B"FUS9W-T<B`B2&EN>G5F_&=E;B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z,C,Q(&%D;6EN+V=R;W5P<RYP:'`Z,C,R"FUS9VED(")!9&0@
M0VAI;&0@1W)O=7`B"FUS9W-T<B`B3F5U92!5;G1E<F=R=7!P92!H:6YZ=6;\
M9V5N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY."!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDY"FUS9VED(")!9&0@0VAI;&0@
M4&5R;6ES<VEO;B(*;7-G<W1R(").975E(%5N=&5R<F5C:'1E(&AI;GIU9OQG
M96XB"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D
M($AE<F4Z(@IM<V=S='(@(DAI97(@:&EN>G5F_&=E;CHB"@HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0V"FUS9VED(")!9&0@365M8F5R
M<R(*;7-G<W1R(")-:71G;&EE9&5R(&AI;GIU9OQG96XB"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C(R-"!A9&UI;B]G<F]U<',N<&AP.C(R-0IM<V=I9"`B061D
M($YE=R!'<F]U<"(*;7-G<W1R(").975E($=R=7!P92!H:6YZ=6;\9V5N(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I
M;VXB"FUS9W-T<B`B3F5U92!296-H=&4@:&EN>G5F_&=E;B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@
M(E5N=&5R9W)U<'!E('IU(%PB)7-<(B!H:6YZ=6;\9V5N(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B
M56YT97)R96-H=&4@>G4@7"(E<UPB(&AI;GIU9OQG96XB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S='(@(D;\
M9V5N(%-I92!E:6YE;B!N975E;B!"96YU='IE<B!H:6YZ=3HB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34V"FUS9VED(")!
M9&0@8V]L=6UN(@IM<V=S='(@(E-P86QT92!H:6YZ=6;\9V5N(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D('!A:7(B"FUS
M9W-T<B`B4&%A<B!H:6YZ=6;\9V5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,V-`HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@
M87,@82!-;WII;&QA(%-I9&5B87(B"FUS9W-T<B`B1&%S("5S+4UE;OP@>G5R
M($UO>FEL;&$@4VED96)A<B!H:6YZ=6;\9V5N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C<Q"FUS9VED(")!9&0@=&\@861D
M<F5S<R!B;V]K.B(*;7-G<W1R("):=6T@061R97-S8G5C:"!H:6YZ=6;\9V5N
M.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW
M.`IM<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O:R(*;7-G<W1R("):=2!M
M96EN96T@061R97-S8G5C:"!H:6YZ=6;\9V5N(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S$*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(D)E;G5T>F5R(&AI;GIU
M9OQG96XB"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD
M(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S
M+B(*;7-G<W1R("(B"B)<(B5S7"(@=W5R9&4@>G5M(%-Y<W1E;2!H:6YZ=6=E
M9OQG="P@86)E<B!D:64@>G5SY'1Z;&EC:&5N("(*(E)E9VES=')I97)U;F=S
M:6YF;W)M871I;VYE;B!K;VYN=&5N(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E
M;CH@)7,N(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@
M;F]W+B(*;7-G<W1R(")<(B5S7"(@=W5R9&4@>G5M(%-Y<W1E;2!H:6YZ=6=E
M9OQG="X@4VEE(&OV;FYE;B!S:6-H(&IE='IT(&%N;65L9&5N+B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@
M=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(D1A<R!(:6YZ=6;\9V5N('9O
M;B!"96YU='IE<FX@:7-T(&YI8VAT(&WV9VQI8V@N(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T-#$*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`B061R97-S
M92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-#$*;7-G:60@(D%D
M9')E<W,@0F]O:R(*;7-G<W1R(")!9')E<W-B=6-H(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-38*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30*;7-G:60@(D%D;6EN:7-T97(@
M+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S='(@(E9E
M<G=A;'1E;B`M(%)E8VAT92!F_'(@86YD97)E($)E;G5T>F5R(&9E<W1L96=E
M;B(*"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ.2!S97)V:6-E<R]P;W)T86PO<VED
M96)A<BYP:'`Z,3$W"FUS9VED(")!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!
M9&UI;FES=')A=&EO;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M-#,*;7-G:60@(D%D<R(*;7-G<W1R(")797)B=6YG(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM
M<V=I9"`B069G:&%N:7-T86XB"FUS9W-T<B`B069G:&%N:7-T86XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4W"FUS9VED(")!;&)A;FEA(@IM<V=S='(@(D%L8F%N:65N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,`IM<V=I9"`B06QG97)I82(*;7-G<W1R(")!;&=E<FEE;B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*;7-G
M:60@(D%L:6%S(@IM<V=S='(@(E-P:71Z;F%M92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*;7-G:60@(D%L
M:6=N(@IM<V=S='(@(D%U<W)I8VAT=6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*
M;7-G<W1R(")!=7-R:6-H='5N9SHB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R(")!;&QE(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHV-@IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T
M<B`B06YG96UE;&1E=&4@0F5N=71Z97(B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C(X"FUS9VED(")!;&P@1W)O=7!S(@IM
M<V=S='(@(D%L;&4@1W)U<'!E;B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+V1A=&%T<F5E+G!H
M<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(D%L;&4@4F5C
M:'1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS9W-T<B`B06QL
M92!V:65R(%-E:71E;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M.#D*;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R(")-
M96AR97)E($%D<F5S<V5N(&5R;&%U8F5N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4S,0IM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI
M<W0@='EP93\B"FUS9W-T<B`B1F]R;6%T('9O;B!N=6UM97)I97)T96X@3&ES
M=&5N(.1N9&5R;C\B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O
M<W%L+G!H<#HU,#<*;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@(D5X
M:7-T:65R="!B97)E:71S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R
M-@IM<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`B06QT97)N
M871I=F4@24U34"U!;FUE;&1U;F<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3`T"FUS9VED(")!;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R
M(")!;'1E<FYA=&EV97,@24U34"U087-S=V]R="(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT.38*;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE
M(@IM<V=S='(@(D%L=&5R;F%T:79E<B!)35-0+4)E;G5T>F5R;F%M92(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,V"FUS9VED(")!;'1E<FYA
M=&4@96UA:6P@861D<F5S<R(*;7-G<W1R(")!;'1E<FYA=&EV92!%+4UA:6PM
M061R97-S92(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!
M;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(D%L=&5R;F%T:79E(%9O<FQA
M9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS9W-T
M<B`B06QT97)N871I=F5R(%1E>'0Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE
M<FEC86X@4V%M;V$B"FUS9W-T<B`B06UE<FEK86YI<V-H+5-A;6]A(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HY-2!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@:6QL96=A;"!V86QU92!W
M87,@<W!E8VEF:65D+B(*;7-G<W1R(")%<R!W=7)D92!E:6X@=6YG_&QT:6=E
M<B!797)T(&%N9V5G96)E;BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,34U"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D
M+B(*;7-G<W1R(")%:6X@=6YB96MA;FYT97(@1F5H;&5R(&ES="!A=69G971R
M971E;BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(D%N
M9&]R<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B06YG
M;VQA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B06YG
M=6EL;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS
M9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B06YO;GEM97(@4')O>'DB
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B06YS
M=V5R(@IM<V=S='(@(D%N='=O<G0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;G1A
M<F-T:6-A(@IM<V=S='(@(D%N=&%R:W1I<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@
M(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B06YT:6=U82!U;F0@0F%R
M8G5D82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO<&AP<VAE
M;&PN<&AP.C,V"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3@@
M=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P
M;&EC871I;VXB"FUS9W-T<B`B06YW96YD=6YG(@H*(SH@=71I;"]I8V]N7V)R
M;W=S97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T(@IM<V=S='(@
M(D%N=V5N9'5N9W-L:7-T92(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M,SD*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R(")!;G=E
M;F1U;F<@:7-T(&)E<F5I="XB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C(Q.0IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@
M(D%U9B!5;G1E<G)E8VAT92!A;G=E;F1E;B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@
M(D)E<W3D=&EG96XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HX-#(*;7-G:60@(D%P<')O>&EM871E(%-I>F4B"FUS9W-T<B`B56YG
M96;D:')E($=R]M]E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(D%P<FEL(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D%R86)I8R`H5VEN9&]W
M<RTQ,C4V*2(*;7-G<W1R(")!<F%B:7-C:"`H5VEN9&]W<RTQ,C4V*2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<X"FUS9VED(")!<F-H:79E($9I
M;&4@4VEZ92(*;7-G<W1R(")!<F-H:79G<O;?92(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HV-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T9WHN<&AP.C<W"FUS9VED(")!<F-H:79E($YA;64B"FUS9W-T<B`B
M07)C:&EV;F%M92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U
M975E9"YI;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E
M('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S
M(#\B"FUS9W-T<B`B(@HB4VEN9"!3:64@<VEC:&5R+"!D87-S(%-I92!D:64@
M4F5G:7-T<FEE<G5N9W-A;F9R86=E('9O;B`E<R!L]G-C:&5N(&WV8VAT96X_
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E
M;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R("(B"B)3
M:6YD(%-I92!S:6-H97(L(&1A<W,@4VEE(%PB)7-<(B!U;F0@86QL92!5;G1E
M<F=R=7!P96X@;/9S8VAE;B!M]F-H=&5N/R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@
M(D%R9V5N=&EN82(*;7-G<W1R(")!<F=E;G1I;FEE;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*
M;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B07)M96YI96XB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB
M"FUS9W-T<B`B07)M96YI<V-H("A!4DU30TE)+3@I(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B2W5N<W0B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4Y"FUS9VED(")!<G5B82(*;7-G<W1R(")!<G5B82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)
M<VQA;F0B"FUS9W-T<B`B07-C96YS:6]N+4EN<V5L;B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@07)T(@IM<V=S='(@(D%3
M0TE)+4MU;G-T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U
M"FUS9VED(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@(D%S:65N+U!A
M>FEF:7-C:&4@4F5G:6]N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R
M,@IM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@(D%N<W1E:&5N9&4@5V%R
M='5N9W-A<F)E:71E;B!B97-TY'1I9V5N(&QA<W-E;C\B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,3$S"FUS9VED(")!<W-I9VYM96YT(&-O;'5M
M;G,B"FUS9W-T<B`B6G5O<F1N=6YG<V9E;&1E<B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-S0*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T
M96YT(&=R;W5P+B(*;7-G<W1R(")%<R!W=7)D92!V97)S=6-H="P@96EN92!N
M:6-H="!E>&ES=&EE<F5N9&4@1W)U<'!E('IU(&SV<V-H96XN(@H*(SH@861M
M:6XO<&5R;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE
M=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B17,@=W5R
M9&4@=F5R<W5C:'0L(&5I;B!N:6-H="!E>&ES=&EE<F5N9&5S(%)E8VAT('IU
M(&SV<V-H96XN(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*;7-G:60@
M(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*
M;7-G<W1R(")%<R!W=7)D92!V97)S=6-H="P@96EN(&YI8VAT(&5X:7-T:65R
M96YD97,@4F5C:'0@>G4@8F5A<F)E:71E;BXB"@HC.B!S97)V:6-E<R]S:&%R
M97,O961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE
M>&ES=&5N="!S:&%R92XB"FUS9W-T<B`B17,@=W5R9&4@=F5R<W5C:'0L(&5I
M;B!N:6-H="!E>&ES=&EE<F5N9&5S(%)E8VAT('IU(&)E87)B96ET96XN(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-"!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#,*;7-G:60@(D%T=')I8G5T
M97,B"FUS9W-T<B`B071T<FEB=71E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P.0HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R(")!
M=6=U<W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B
M075S=')A;&EE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R:6$B"FUS9W-T
M<B`BUG-T97)R96EC:"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L
M+G!H<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER<W%L.B!$:64@
M8F5N]G1I9W1E($E-05`M17)W96ET97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD
M96XN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3,U"FUS
M9VED(")!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER
M960@8V%P86)I;&ET97,N(@IM<V=S='(@(D%U=&A?8WER=7,Z($1A<R!"86-K
M96YD(&AA="!N:6-H="!D:64@8F5N]G1I9W1E;B!&Y&AI9VME:71E;BXB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U
M=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B075T:%]C>7)U<SH@1&EE(&)E;O9T:6=T92!)34%0+45R=V5I
M=&5R=6YG('=U<F1E(&YI8VAT(&=E9G5N9&5N+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E<75I
M<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H
M('1H92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B"B)!=71H
M7V9T<#H@1&EE(&)E;O9T:6=T92!&5%`M17)W96ET97)U;F<@=W5R9&4@;FEC
M:'0@9V5F=6YD96XN($MO;7!I;&EE<F5N("(*(E-I92!02%`@;6ET(&1E;2`M
M+65N86)L92UF='`@4&%R86UE=&5R+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:6UA<"YP:'`Z-C`*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VEM87`Z($1I
M92!B96[V=&EG=&4@24U!4"U%<G=E:71E<G5N9R!W=7)D92!N:6-H="!G969U
M;F1E;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C4Q"FUS
M9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B075T:%]K<F(U.B!$:64@8F5N]G1I9W1E($ME<F)E
M<F]S+45R=V5I=&5R=6YG('=U<F1E(&YI8VAT(&=E9G5N9&5N+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S`R"FUS9VED(")!=71H7VQD
M87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@
M1&ER96-T;W)Y(@IM<V=S='(@(B(*(D%U=&A?;&1A<#H@1&%S($AI;GIU9OQG
M96X@=F]N($)E;G5T>F5R;B!W:7)D(&;\<B!!8W1I=F4@1&ER96-T;W)Y(&YI
M8VAT("(*(G5N=&5R<W3\='IT(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HS-3<*;7-G:60@(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@
M:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R
M("(B"B)!=71H7VQD87`Z($1A<R!,]G-C:&5N('9O;B!"96YU='IE<FX@=VER
M9"!F_'(@06-T:79E($1I<F5C=&]R>2!N:6-H="`B"B)U;G1E<G-T_'1Z="(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-C,*;7-G:60@(D%U
M=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")!=71H7VQD87`Z($1I92!B96[V=&EG=&4@3$1!4"U%<G=E:71E
M<G5N9R!W=7)D92!N:6-H="!G969U;F1E;BXB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H
M7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H
M92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*(D%U=&A?;&1A<#H@1&5R($)E
M;G5T>F5R("5S(&MO;FYT92!N:6-H="!H:6YZ=6=E9OQG="!W97)D96XN($UE
M;&1U;F<@9&5S("(*(E-E<G9E<G,Z("(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A
M<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A
M<#H@0F5N=71Z97(@)7,@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#DY"B,L('!H<"UF
M;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R
M("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@0F5N=71Z97(@)7,@:V]N;G1E(&YI
M8VAT(&%K='5A;&ES:65R="!W97)D96XB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U
M<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*
M;7-G<W1R("(B"B)!=71H7VQD87`Z($1A<R!!:W1U86QI<VEE<F5N('9O;B!"
M96YU='IE<FX@=VER9"!F_'(@06-T:79E($1I<F5C=&]R>2!N:6-H="`B"B)U
M;G1E<G-T_'1Z="XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP
M.C0V"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]M8V%L.B!$:64@8F5N]G1I9W1E
M($U#04PM17)W96ET97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD96XN(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M
M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B075T:%]S;6)A=71H.B!$:64@8F5N]G1I9W1E(%-A;6)A+45R
M=V5I=&5R=6YG('=U<F1E(&YI8VAT(&=E9G5N9&5N+B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O061M:6XN<&AP.C$P,PIM<V=I9"`B075T:&5N=&EC871I
M;VX@870@24U!4"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")!;FUE;&1U;F<@
M8F5I;2!)34%0+5-E<G9E<B!F96AL9V5S8VAL86=E;BXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@
M(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R(")!=71H96YT:69I>FEE
M<G5N9R!F96AL9V5S8VAL86=E;B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G
M:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`B06YM96QD
M=6YG(&9E:&QG97-C:&QA9V5N+B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<F%D:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C
M=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S='(@(D1I92!!=71H96YT:69I
M>FEE<G5N9R!W=7)D92!V;VT@4D%$2553+5-E<G9E<B!Z=7+\8VMG97=I97-E
M;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@Y-`IM<V=I9"`B
M075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@
M(D%N;65L9'5N9R!B96EM($944"U397)V97(@9F5H;&=E<V-H;&%G96XN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HW,`IM<V=I9"`B075T:&5N
M=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")!
M;FUE;&1U;F<@8F5I;2!334(M4V5R=F5R(&9E:&QG97-C:&QA9V5N+B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L
M92!F:65L9',Z(@IM<V=S='(@(E9E<F;\9V)A<F4@1F5L9&5R.B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3D*;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B07-E<F)A:61S8VAA
M;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I9"`B0D]&2"!%
M>&-U<V5S(@IM<V=S='(@(D)/1D@M075S<F5D96XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"
M86-K9W)O=6YD(@IM<V=S='(@(DAI;G1E<F=R=6YD(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R
M;W5N9"!#;VQO<B(*;7-G<W1R(")(:6YT97)G<G5N9&9A<F)E(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E
M<F]S('!A<W-W;W)D+B(*;7-G<W1R(")&86QS8VAE<R!+97)B97)O<RU087-S
M=V]R="XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@S"FUS
M9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@(D9A;'-C:&5R
M($ME<F)E<F]S+4)E;G5T>F5R;F%M92XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"
M86AA;6%S(@IM<V=S='(@(D)A:&%M87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"
M86AR86EN(@IM<V=S='(@(D)A:')E:6XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X,`IM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B
M0F%L=&ES8V@@*$E33RTX.#4Y+3$S*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A
M;F=L861E<V@B"FUS9W-T<B`B0F%N9VQA9&5S8V@B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS
M9VED(")"87)B861O<R(*;7-G<W1R(")"87)B861O<R(*"B,Z('5T:6PO:6-O
M;E]B<F]W<V5R+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R
M87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")"
M87-I<RU":6QD97(M5F5R>F5I8VAN:7,@7"(E<UPB(&YI8VAT(&=E9G5N9&5N
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW,PIM<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B1W)U;F1L:6YI92(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C,*;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B5V5IWW)U;&%N
M9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C`*;7-G:60@(D)E;&=I=6TB"FUS9W-T<B`B0F5L9VEE
M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&EZ92(*;7-G<W1R(")"96QI>F4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8Q"FUS9VED(")"96YI;B(*;7-G<W1R(")"96YI;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B0F5R;75D87,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8S"FUS9VED(")":'5T86XB"FUS9W-T<B`B0FAU=&%N(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I
M9"`B0FER=&AD87DB"FUS9W-T<B`B1V5B=7)T<W1A9R(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS-C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N
M;W0@9F]U;F0N(@IM<V=S='(@(D)L;V-K(%PB)7-<(B!D97(@06YW96YD=6YG
M(%PB)7-<(B!N:6-H="!G969U;F1E;BXB"@HC.B!T96UP;&%T97,O<&]R=&%L
M+VQA>6]U="YI;F,Z.3`*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@
M(D)L;V-K96EN<W1E;&QU;F=E;B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R(")";&]C:W1Y
M<"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.`IM<V=I9"`B0F]L9"(*;7-G<W1R(")&971T(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I
M9"`B0F]L:79I82(*;7-G<W1R(")";VQI=FEE;B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR,#<*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R("),
M97-E>F5I8VAE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C`*;7-G:60@(D)O<F1E<B(*;7-G<W1R(")286YD
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B4F%H;65N9&EC
M:V4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR,0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R(")2Y&YD97(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8P"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S
M='(@(D)O<VYI96XM2&5R>F5G;W=I;F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z.38*;7-G:60@(D)O=&@B"FUS9W-T<B`B0F5I9&5S(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,PIM<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B0F]T<W=A;F$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(R
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*
M;7-G:60@(D)O='1O;2(*;7-G<W1R(")5;G1E;B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G
M:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B0F]U=F5T:6YS96PB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8R"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B0G)A<VEL:65N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#$*;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R
M>2(*;7-G<W1R(")"<FET:7-C:&5S(%1E<G)I=&]R:75M(&EM($EN9&ES8VAE
M;B!/>F5A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M
M(@IM<V=S='(@(D)R=6YE:2!$87)U<W-A;&%M(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I
M9"`B0G5L9V%R:6$B"FUS9W-T<B`B0G5L9V%R:65N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T
M960@3&ES="(*;7-G<W1R(")5;FYU;6UE<FEE<G1E($QI<W1E(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,0IM<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(D)U<FMI;F$@1F%S
M;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,SD@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B0G5R=6YD
M:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#8*;7-G:60@(D--
M4R(*;7-G<W1R(")#35,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B0U)#(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@*;7-G:60@(D-23"!$
M:7-T<FEB=71I;VX@4&]I;G1S(@IM<V=S='(@(D-23"!$:7-T<FEB=71I;VYS
M<W1E;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM
M<V=S='(@(E]:96QL96YE:6=E;G-C:&%F=&5N+BXN(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$U,0IM<V=I9"`B0V%C:&4@:6YI="!W87,@
M;F]T(&-O;7!L971E9"XB"FUS9W-T<B`B1&5R(%IW:7-C:&5N<W!E:6-H97(@
M:V]N;G1E(&YI8VAT(&EN:71I86QI<VEE<G0@=V5R9&5N+B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.30R(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT.#4*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T
M.C$P-3`@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$U-PIM<V=I9"`B0V%L
M96YD87(B"FUS9W-T<B`B2V%L96YD97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C,U"FUS9VED(")#86QM(@IM<V=S='(@(E=I;F1S=&EL
M;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R(")+86UB
M;V1S8VAA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B
M2V%M97)U;B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,@IM<V=I9"`B0V%N
M)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+B(*;7-G
M<W1R(")%>'1E<FYE(%-E<W-I;VXM2&%N9&QE<B!K]FYN96X@;FEC:'0@861M
M:6YI<W1R:65R="!W97)D96XN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)U<RYP:'`Z,C,U(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS
M,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0
M('-E<G9E<CH@)7,B"FUS9W-T<B`B5F5R8FEN9'5N9R!Z=6T@24U!4"U397)V
M97(@:V%N;B!N:6-H="!H97)G97-T96QL="!W97)D96XZ("5S(@H*(SH@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0V"B,L('!H<"UF;W)M870*;7-G
M:60@(D-A;B=T(&]P96X@9FEL92!<(B5S7"(N(@IM<V=S='(@(D1I92!$871E
M:2!<(B5S7"(@:V%N;B!N:6-H="!G9?9F9FYE="!W97)D96XN(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-`IM<V=I9"`B0V%N861A(@IM<V=S='(@(DMA;F%D82(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$P,2!A9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8U"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,2!T96UP;&%T97,O861M:6XO=7-E
M<B]C;&5A<BYI;F,Z,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M+FEN8SHQ,@IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(D%B8G)E8VAE;B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#86YC
M96P@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B4')O8FQE;6)E<FEC:'0@86)B
M<F5C:&5N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-#0@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C,U"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z-C<U(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HR,C(*;7-G:60@(D-A;FYO="!C;W!Y(&9I;&4H<RD@+2!S;W5R8V4@86YD
M(&1E<W1I;F%T:6]N(&%R92!T:&4@<V%M92XB"FUS9W-T<B`B(@HB1&%T96DH
M96XI(&OV;FYE;B!N:6-H="!K;W!I97)T('=E<F1E;B`M(%%U96QL+2!U;F0@
M6FEE;&1A=&5I96X@<VEN9"`B"B)I9&5N=&ES8V@N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N
M;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B1&EE($1A=&5I(%PB
M)7-<(B!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N+B(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HT-@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R"FUS9VED(")#
M86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(DME
M:6X@=&5M<&]RY')E<R!697)Z96EC:&YI<R!G969U;F1E;BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4Q,"!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HR,#4*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-3$@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$X-PIM<V=I9"`B0V%N
M;F]T(&UO=F4@9FEL92AS*2`M(&1E<W1I;F%T:6]N(&ES('=I=&AI;B!S;W5R
M8V4N(@IM<V=S='(@(B(*(D1A=&5I*&5N*2!K]FYN96X@;FEC:'0@=F5R<V-H
M;V)E;B!W97)D96X@+2!::65L9&%T96D@8F5F:6YD970@<VEC:"!I;2`B"B)1
M=65L;&]R9&YE<BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(N<&AP.CDQ"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T
M87)G971&:6QE)R!P87)A;65T97(N(@IM<V=S='(@(D9O<G1S971Z=6YG(&]H
M;F4@7")T87)G971&:6QE7"(M4&%R86UE=&5R(&YI8VAT(&WV9VQI8V@N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G
M<W1R(")$87,@5F5R>F5I8VAN:7,@7"(E<UPB(&MO;FYT92!N:6-H="!E;G1F
M97)N="!W97)D96XN(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E
M+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z
M-C@S"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H
M:6QD<F5N(&5X:7-T+B(*;7-G<W1R(")+;VYN=&4@;FEC:'0@96YT9F5R;G0@
M=V5R9&5N+"`E9"!+:6YD97(@97AI<W1I97)E;BXB"@HC.B!F<F%M97=O<FLO
M1&%T851R964O1&%T851R964O<W%L+G!H<#HV,3$*;7-G:60@(B(*(D-A;FYO
M="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O
M<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R
M("(B"B)5;7-O<G1I97)E;B!N:6-H="!M]F=L:6-H+B!$:64@06YZ86AL(&1E
M<B!%:6YT<N1G92P@9&EE('5M<V]R=&EE<G0@=V5R9&5N("(*(G-O;&QE;BP@
M<W1I;6UT(&YI8VAT(&UI="!D97(@06YZ86AL(&1E<B!G97-P96EC:&5R=&5N
M($5I;G1RY&=E(/QB97)E:6XN(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z,C$*;7-G:60@(D-A;FYO="!R97-E="!P87-S=V]R9"!A=71O;6%T
M:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B
M(@HB4&%S<W=O<G0@:V%N;B!N:6-H="!A=71O;6%T:7-C:"!Z=7+\8VMG97-E
M='IT('=E<F1E;BP@8FET=&4@=V5N9&5N(%-I92!S:6-H("(*(F%N($EH<F5N
M($%D;6EN:7-T<F%T;W(N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@<F]U=&4@;65S
M<V%G92!T;R!S<&5C:69I960@;G5M8F5R+B(*;7-G<W1R("(B"B)$:64@3F%C
M:')I8VAT(&MO;FYT92!N:6-H="!A;B!D:64@86YG96=E8F4@3G5M;65R('=E
M:71E<F=E;&5I=&5T('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HS-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T('=R:71E
M('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@(D1I92!$871E:2!<(B5S7"(@:V%N
M;B!N:6-H="!G97-P96EC:&5R="!W97)D96XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED
M(")#87!E(%9E<F1E(@IM<V=S='(@(DMA<"!697)D92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*;7-G:60@
M(D-A<'1I;VXB"FUS9W-T<B`BW&)E<G-C:')I9G0B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I
M97(B"FUS9W-T<B`B4')O=FED97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.3,*;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R(")+
M871E9V]R:65N('5N9"!"97-C:')I9G1U;F=E;B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS
M9VED(")#87EM86X@27-L86YD<R(*;7-G<W1R(")#87EM86XM26YS96QN(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM
M<V=I9"`B0V5L;"!0:&]N92(*;7-G<W1R(")-;V)I;'1E;&5F;VXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U
M"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`B6F5L;&5N96EG96YS
M8VAA9G1E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(DEN;F5N
M86)S=&%N9#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS9W-T
M<B`B6F5L;&5N96EG96YS8VAA9G1E;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS9VED(")#96QL('-P86-I;F<Z
M(@IM<V=S='(@(EIE;&QE;F%B<W1A;F0Z(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(W-`IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(DUO8FEL
M=&5L969O;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#
M96QT:6,@*$E33RTX.#4Y+3$T*2(*;7-G<W1R(")+96QT:7-C:"`H25-/+3@X
M-3DM,30I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(EIE;G1R:65R
M="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C4*;7-G:60@(D-E;G1R86P@069R:6-A;B!297!U8FQI
M8R(*;7-G<W1R("):96YT<F%L869R:6MA;FES8VAE(%)E<'5B;&EK(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G:60@(D-E;G1R86P@175R;W!E
M86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(DUI='1E;&5U<F]PY&ES8V@@*$E3
M3RTX.#4Y+3(I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HW,#`*;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B6F5R
M=&EF:6MA=&1E=&%I;',B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8Q,@IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B
M6F5R=&EF:6MA=&)E<VET>F5R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM
M<V=S='(@(EIE<G1I9FEK871R:6-H=&QI;FEE;B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM
M<V=I9"`B0VAA9"(*;7-G<W1R(")4<V-H860B"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.CDV"FUS9VED(")#:&%N9V4B"FUS9W-T<B`BQ&YD97)N(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,Q"FUS9VED(")#:&%N9V4@66]U<B!0
M87-S=V]R9"(*;7-G<W1R("+$;F1E<FX@4VEE($EH<B!087-S=V]R="(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.0IM<V=I9"`B(@HB0VAA;F=E('1H
M92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@
M<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(B(*
M(L1N9&5R;B!3:64@9&5N($YA;65N(&]D97(@9&EE($%D<F5S<V4L(&1I92!D
M:64@16UP9N1N9V5R($EH<F5R($4M36%I;"TB"B).86-H<FEC:'1E;B!S96AE
M;BP@=V5N;B!S:64@9&EE<V4@;&5S96X@;V1E<B!D87)A=68@86YW;W)T96XN
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B
M"B)#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET
M:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R
M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(D1A<R#$;F1E<FX@26AR97,@
M4&%S<W=O<G1S('=I<F0@=F]N(&1I97-E;2!3>7-T96T@>G5R(%IE:70@;FEC
M:'0@(@HB=6YT97)S=/QT>G0N($)I='1E('=E;F1E;B!3:64@<VEC:"!A;B!)
M:')E;B!!9&UI;FES=')A=&]R+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*;7-G:60@(D-H87(B"FUS9W-T
M<B`B6F5I8VAE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB"FUS
M9W-T<B`B3&EN:R#\8F5R7W!R_&9E;BXN+B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@
M(D-H:6QE(@IM<V=S='(@(D-H:6QE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI
M;F$B"FUS9W-T<B`B0VAI;F$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M,PIM<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@
M(D-H:6YE<VES8V@@=F5R96EN9F%C:'0@*$=",C,Q,BDB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H
M0FEG-2DB"FUS9W-T<B`B0VAI;F5S:7-C:"!T<F%D:71I;VYE;&P@*$)I9S4I
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-PIM<V=I9"`B0VAO;W-E
M($%P<&QI8V%T:6]N.B(*;7-G<W1R(")!;G=E;F1U;F<@875S=^1H;&5N.B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@
M(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(E?D:&QE;B!3:64@96EN(%!A
M<W-W;W)T(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V
M.0IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B5^1H;&5N(%-I
M92!E:6YE;B!"96YU='IE<FYA;65N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(Y-0IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*
M;7-G<W1R("),96=E;B!3:64@9F5S="P@=VEE(&1A<R!$871U;2!A;F=E>F5I
M9W0@=V5R9&5N('-O;&PZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@
M<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I(@IM<V=S='(@(DQI<W1E
M;F9O<FUA="!A=7-WY&AL96X@*&;\<B!N=6UM97)I97)T92!,:7-T96XI(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R(")7
M96EH;F%C:'1S:6YS96PB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,N<&AP
M.C(Y-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.3`U"B,L('!H<"UF;W)M870*
M;7-G:60@(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G
M<W1R(")+;&%S<V5N9&5F:6YI=&EO;B!F_'(@)7,@;FEC:'0@9V5F=6YD96XN
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,34*
M;7-G:60@(D-L96%R(@IM<V=S='(@(DAE:71E<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U3
M3V9F:6-E('1A9W,B"FUS9W-T<B`B35,M3V9F:6-E+51A9W,@96YT9F5R;F5N
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.0IM<V=I9"`B0VQE87(@475E
M<GDB"FUS9W-T<B`B06)F<F%G92!Z=7+\8VMS971Z96XB"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B0F5N=71Z97)D871E;B!L
M]G-C:&5N.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN
M8SHQ,0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R(")"96YU='IE<F1A=&5N
M(&SV<V-H96XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS
M-`IM<V=I9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@(D)E;G5T>F5R9&%T
M96X@;/9S8VAE;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$V"FUS9VED(")#;&5A<FEN9R!,871E(@IM<V=S='(@(E-PY'1E
M<B!!=69K;&%R96YD(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT
M96YA;F-E+FAT;6PZ-C`*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S
M='(@(D9O<G1F86AR96XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A4
M5%`B"FUS9W-T<B`B0VQI8VMA=&5L;"!P97(@2%144"(*"B,Z('-E<G9I8V5S
M+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(D9E;G-T97(@<V-H;&EE
MWV5N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#8*;7-G:60@(D-L;W5D
M<R(*;7-G<W1R(")7;VQK96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ-PIM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@
M(D9R_&@@5V]L:V5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3@*;7-G:60@(D-L;W5D>2(*;7-G<W1R(")"97?V;&MT(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-`IM<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS
M9W-T<B`B2V]K;W-I;G-E;&XB"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B
M87(N:6YC.C(S"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@(DUE
M;OP@96EN9F%H<F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B
M"FUS9W-T<B`B6G5S86UM96YHY&YG96YD92!286AM96XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W
M"FUS9VED(")#;VQO;6)I82(*;7-G<W1R(")+;VQU;6)I96XB"@HC.B!L:6(O
M0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`B1F%R8F4B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S,X"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,SD*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4P,R!S97)V:6-E<R]I;6%G97,O
M8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T
M<B`B1F%R8F%U<W=A:&PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.#0V"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@(D9A<F)W86AL
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(E-P86QT96XZ(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3DV-`IM<V=I9"`B0V]L=6UN('1I=&QE<R(*
M;7-G<W1R(")3<&%L=&5N_&)E<G-C:')I9G1E;B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR-C8*;7-G:60@(D-O;6EC<R(*;7-G<W1R(")#;VUI
M8W,B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C8*;7-G:60@(D-O;6UA;F0B
M"FUS9W-T<B`B0F5F96AL(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS
M9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@(D)E9F5H;'-Z96EL92(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B0V]M
M;65N="(*;7-G<W1R(")+;VUM96YT87(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B0V]M;6]N($YA;64B"FUS9W-T
M<B`B16EN9&5U=&EG97(@3F%M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")#;VUO
M<F]S(@IM<V=S='(@(DMO;6]R96XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@
M(D9I<FUA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#
M;VUP=71E<G,B"FUS9W-T<B`B0V]M<'5T97(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C@V"FUS9VED(")#;VYD:71I;VXB"FUS9W-T<B`B
M0F5D:6YG=6YG96XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U,0IM<V=I
M9"`B0V]N9&ET:6]N<R(*;7-G<W1R(")"961I;F=U;F=E;B(*"B,Z(&%D;6EN
M+W-E='5P+V1I9F8N<&AP.CDS"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E
M<F5N8V5S(@IM<V=S='(@(DMO;F9I9W5R871I;VYS=6YT97)S8VAI961E(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-`IM<V=I9"`B0V]N9FEG=7)A
M=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B1&EE($MO;F9I9W5R871I
M;VX@;75S<R!A:W1U86QI<VEE<G0@=V5R9&5N+B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG=7)E
M("5S(@IM<V=S='(@(B5S(&MO;F9I9W5R:65R96XB"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"FUS9VED(")#;VYF:7)M(%!A<W-W
M;W)D(@IM<V=S='(@(E!A<W-W;W)T(&)E<W3D=&EG96XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V
M"FUS9VED(")#;VYG;R(*;7-G<W1R(")+;VYG;R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HV,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G
M:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4B"FUS
M9W-T<B`B1&5M;VMR871I<V-H92!297!U8FQI8R!+;VYG;R(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(P-`HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#<*;7-G:60@(D-O;FYE
M8W1I;VX@9F%I;&5D+B(*;7-G<W1R(")697)B:6YD=6YG(&9E:&QG97-C:&QA
M9V5N+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C(P-`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M-#<*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`B5F5R8FEN
M9'5N9R!F96AL9V5S8VAL86=E;CH@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-SDY"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@
M=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(E9E<F)I;F1U;F<@>G5M
M(/9F9F5N=&QI8VAE;B!38VAL_'-S96QS97)V97(@=W5R9&4@86)G97=I97-E
M;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HX,#$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B(@HB
M5F5R8FEN9'5N9R!Z=6T@]F9F96YT;&EC:&5N(%-C:&S\<W-E;'-E<G9E<B!W
M=7)D92!A8F=E=VEE<V5N+B!'<G5N9#H@)7,@*"5S*2(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#@X"FUS9VED(")#;VYN96-T:6]N('1O($94
M4"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")697)B:6YD=6YG('IU;2!&5%`M
M4V5R=F5R(&9E:&QG97-C:&QA9V5N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HY-3`@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-S<*;7-G:60@
M(D-O;G1A8W1S(@IM<V=S='(@(DMO;G1A:W1E(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C4S"FUS9VED(")#;VYT86-T<R!W
M97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB
M"FUS9W-T<B`B1&EE($MO;G1A:W1E('=U<F1E;B!E<F9O;&=R96EC:"!):')E
M;2!!9')E<W-B=6-H(&AI;GIU9V5F_&=T+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z-C`*;7-G:60@(D-O;G1E;G0@='EP92!O
M9B!C;VUP<F5S<V5D(&9I;&4Z("(*;7-G<W1R("));FAA;'1S='EP(&1E<B!K
M;VUP<FEM:65R=&5N($1A=&5I.B`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C4V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O9B!<(B5S
M7"(B"FUS9W-T<B`B26YH86QT('9O;B!<(B5S7"(B"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HS,"!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z,S,*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@(E=E:71E<B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R(")#;V]K+4EN<V5L
M;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O:VEE
M(@IM<V=S='(@(D-O;VMI92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0IM<V=I9"`B0V]P>2(*;7-G<W1R
M(")+;W!I97)E;B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#@Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R
M(")+;W!I97)E;B!F96AL9V5S8VAL86=E;CH@)7,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,V"FUS9VED(")#;W!Y('-E
M;&5C=&EO;B(*;7-G<W1R(")!=7-W86AL(&MO<&EE<F5N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-S`*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B
M"FUS9W-T<B`B2V]S=&5N+4E$(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@
M4FEC82(*;7-G<W1R(")#;W-T82!2:6-A(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B
M0V]T92!D)TEV;VER92(*;7-G<W1R(")%;&9E;F)E:6YK_'-T92(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDX-@IM<V=I9"`B0V]U;&0@
M;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z("(*;7-G<W1R(")$:64@3F%C:')I
M8VAT(&MO;FYT92!N:6-H="!M:70@4$=0('9E<G-C:&S\<W-E;'0@=V5R9&5N
M.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#8T"FUS
M9VED(")#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G93H@(@IM<V=S='(@(D1I
M92!.86-H<FEC:'0@:V]N;G1E(&YI8VAT(&UI="!01U`@=6YT97)Z96EC:&YE
M="!W97)D96XZ("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,SDS"FUS9VED(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G
M92XB"FUS9W-T<B`B1&EE($YA8VAR:6-H="!K;VYN=&4@;FEC:'0@;6ET(%,O
M34E-12!V97)S8VAL_'-S96QT('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-
M12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(D1I92!.86-H<FEC:'0@:V]N;G1E
M(&YI8VAT(&UI="!3+TU)344@=6YT97)Z96EC:&YE="!W97)D96XN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E
M<R(*;7-G<W1R(")+;VYT86MT(&MO;FYT92!N:6-H="!G97-P96EC:&5R="!W
M97)D96XN("5S(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.CDV(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(P"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HT.#(*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O
M($Q$05`@<V5R=F5R+B(*;7-G<W1R(")697)B:6YD=6YG('IU;2!,1$%0+5-E
M<G9E<B!F96AL9V5S8VAL86=E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C$U-@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@(DMO
M;G1O<W1A;F0@:V]N;G1E(&YI8VAT(/QB97)P<OQF="!W97)D96XN("5S(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0V-@IM<V=I9"`B0V]U;&0@;F]T
M(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(E9E<F)I;F1U;F<@
M>G5M($Q$05`M4V5R=F5R(&9E:&QG97-C:&QA9V5N+B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@8V]N;F5C="!T;R!S97)V97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS
M9W-T<B`B1E10+59E<F)I;F1U;F<@>G5M(%-E<G9E<B!<(B5S7"(@:V]N;G1E
M(&YI8VAT(&AE<F=E<W1E;&QT('=E<F1E;CH@)7,B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<R(*;7-G<W1R(")697)T96EL97)L:7-T92!K;VYN=&4@;FEC:'0@97)S
M=&5L;'0@=V5R9&5N+B`E<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$Q,S<*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A
M.B`B"FUS9W-T<B`B4$=0+41A=&5N(&MO;FYT96X@;FEC:'0@96YT<V-H;/QS
M<V5L="!W97)D96XZ("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3(S"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T
M82XB"FUS9W-T<B`B4R]-24U%+41A=&5N(&MO;FYT96X@;FEC:'0@96YT<V-H
M;/QS<V5L="!W97)D96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R(")+;VYT86MT(&MO
M;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN("5S(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,B"FUS9W-T<B`B5F5R=&5I;&5R;&ES=&4@:V]N;G1E(&YI8VAT(&=E
M;/9S8VAT('=E<F1E;BX@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E('-E
M='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B1&%S($%K='5A
M;&ES:65R=6YG<W-K<FEP="!<(B5S7"(@:V]N;G1E(&YI8VAT(&=E;/9S8VAT
M('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C,X,2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-C(*;7-G:60@
M(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A
M9&1R97-S+B(*;7-G<W1R(")$:64@12U-86EL+4%D<F5S<V4@9&5S($5M<&;D
M;F=E<G,@:V]N;G1E(&YI8VAT(&5R;6ET=&5L="!W97)D96XN(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*;7-G
M:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM
M<V=S='(@(D1A<R!!9')E<W-B=6-H(&MO;FYT92!N:6-H="!K;VUP;&5T="!G
M96QE<V5N('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C0Y,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O
M;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(")697)T96EL97)L
M:7-T92!K;VYN=&4@;FEC:'0@875S9V5L97-E;B!W97)D96XN("5S(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*
M;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D
M:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(DQI<W1E(&1E<B!697)T96EL
M97)L:7-T96X@:V]N;G1E(&YI8VAT(&%U<V=E;&5S96X@=V5R9&5N+B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDN<&AP.C8X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E<UPB+B(*;7-G
M<W1R(")$:64@4W1R871E9VEE(%PB)7-<(B!K;VYN=&4@;FEC:'0@9V5L861E
M;B!W97)D96XN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y
M+V1I<F5C="YP:'`Z,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B1&%S(%9E<GIE:6-H;FES(%PB)7-<
M(B!K;VYN=&4@;FEC:'0@86YG96QE9W0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Q.0IM<V=I9"`B0V]U;&0@;F]T(&]B
M=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`B
MUF9F96YT;&EC:&5R(%-C:&S\<W-E;"!K;VYN=&4@;FEC:'0@=F]M(%-C:&S\
M<W-E;'-E<G9E<B!G96AO;'0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HQ,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@7"(E
M<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R(")<(B5S7"(@:V]N;G1E(&YI8VAT
M('IU;2!38VAR96EB96X@9V7V9F9N970@=V5R9&5N+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(V,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B)7,@
M:V]N;G1E(&YI8VAT(&=E;&5S96X@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]-
M86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-#(P"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE
M("5S(@IM<V=S='(@(D1A<R!-86EN=&5N86YC95]487-K($UO9'5L("5S(&MO
M;FYT92!N:6-H="!G9?9F9FYE="!W97)D96XB"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER
M96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B5F5R>F5I8VAN:7,@7"(E<UPB(&MO
M;FYT92!N:6-H="!G9?9F9FYE="!W97)D96XN(@H*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HR,S<@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-CDY"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R
M+B(*;7-G<W1R(")697)B:6YD=6YG('IU;2!,1$%0+5-E<G9E<B!K;VYN=&4@
M;FEC:'0@:&5R9V5S=&5L;'0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+T]B:F5C="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!R96%D("5S+B(*;7-G<W1R("(E<R!K;VYN=&4@;FEC:'0@9V5L97-E
M;B!W97)D96XN(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#8*
M;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H
M92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I
M;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R
M(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*
M;7-G<W1R("(B"B)$87,@4&%S<W=O<G0@9OQR(&1E;B!A;F=E9V5B96YE;B!"
M96YU='IE<B!K;VYN=&4@;FEC:'0@>G5R_&-K9V5S971Z="!W97)D96XL("(*
M(G=E:6P@96EN:6=E($%N9V%B96X@;FEC:'0@<FEC:'1I9R!W87)E;BX@5F5R
M<W5C:&5N(%-I92!E<R!E<FYE=70@;V1E<B!W96YD96X@(@HB4VEE('-I8V@@
M86X@26AR96X@061M:6YI<W1R871O<BP@=V5N;B!3:64@=V5I=&5R92!(:6QF
M92!B96[V=&EG96XN(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S`U"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,T-@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS-S<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z-#$T"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C0R,`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HT
M,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#
M3"(*;7-G<W1R(")!0TP@:V]N;G1E(&YI8VAT(&=E;&5S96X@=V5R9&5N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR
M-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&%D
M9')E<W,@8F]O:RX@)7,B"FUS9W-T<B`B1&%S($%D<F5S<V)U8V@@:V]N;G1E
M(&YI8VAT(&=E;&5S96X@=V5R9&5N+B`E<R(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,B"FUS9W-T<B`B5F5R=&5I;&5R;&ES=&4@:V]N;G1E(&YI8VAT(&%U<V=E
M;&5S96X@=V5R9&5N+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S
M='(@(E9E<G1E:6QE<FQI<W1E;B!K;VYN=&4@;FEC:'0@875S9V5L97-E;B!W
M97)D96XN("5S(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,C`T"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C(R-`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HR,C@*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A
M8FEL:71I97,B"FUS9W-T<B`B1&EE(%-E<G9E<F;D:&EG:V5I=&5N(&MO;FYT
M96X@;FEC:'0@875S9V5L97-E;B!W97)D96XB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C4T"FUS9VED(")#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(DMO;F9I9W5R871I;VX@:V]N;G1E(&YI8VAT('IU
M<OQC:V=E<V5T>G0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*
M;7-G<W1R(")697)Z96EC:&YI<R!<(B5S7"(@:V]N;G1E(&YI8VAT(&=E;/9S
M8VAT('=E<F1E;BXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R("(E<RU+;VYF:6=U<F%T:6]N(&MO;FYT92!N:6-H
M="!G97-P96EC:&5R="!W97)D96XN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y"FUS9VED(")#;W5L
M9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@(D)A
M8VMU<"!D97(@2V]N9FEG=7)A=&EO;B!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE
M<G0@=V5R9&5N+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF
M:6=U871I;VXZ("5S(@IM<V=S='(@(D)A8VMU<"!D97(@2V]N9FEG=7)A=&EO
M;B!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N.B`E<R(*"B,Z(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.CDU"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S
M7"(N(@IM<V=S='(@(D1A<R!!:W1U86QI<VEE<G5N9W-S:W)I<'0@:V]N;G1E
M(&YI8VAT(&YA8V@@7"(E<UPB(&=E<W!E:6-H97)T('=E<F1E;BXB"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE
M("5S+B(*;7-G<W1R(")"86-K=7`@9&5R($MO;F9I9W5R871I;VX@)7,@:V]N
M;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E;BXB"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C<W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD
M(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@
M96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@
M8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L
M;W<@=&\@)7,N(@IM<V=S='(@(B(*(D1I92!+;VYF:6=U<F%T:6]N("5S(&MO
M;FYT92!N:6-H="!G97-P96EC:&5R="!W97)D96XN(%-I92!K]FYN96X@96YT
M=V5D97(@(@HB96EN92!D97(@3?9G;&EC:&ME:71E;B!U;G1E<B`E<R!V97)W
M96YD96XL('5M(&1E;B!#;V1E('IU('-P96EC:&5R;BP@;V1E<B`B"B)D96X@
M=6YT96YS=&5H96YD96X@0V]D92!M86YU96QL(&YA8V@@)7,@:V]P:65R96XN
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-#,*;7-G:60@
M(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R(")$
M97(@3$1!4"U397)V97(@:V]N;G1E(&YI8VAT(&1U<F-H<W5C:'0@=V5R9&5N
M+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB(&MO
M;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R
M(")$97(@2V]N=&%K="!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N
M+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,SDV"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A
M=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(E9E<G1E:6QE<FQI
M<W1E(&MO;FYT92!N:6-H="!A:W1U86QI<VEE<G0@=V5R9&5N+B`E<R(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E
M<R(*;7-G<W1R(")$:64@2V]N9FEG=7)A=&EO;B!F_'(@7"(E<UPB(&MO;FYT
M92!N:6-H="!G97-P96EC:&5R="!W97)D96XZ("5S(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,V,PIM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@36]Z
M:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB
M"FUS9W-T<B`B(@HB1&EE($UO>FEL;&$@4VED96)A<B!K;VYN=&4@;FEC:'0@
M9V5F=6YD96X@=V5R9&5N+B!3=&5L;&5N(%-I92!S:6-H97(L(&1A<W,@(@HB
M9&EE(%-I9&5B87(@9V7V9F9N970@:7-T+B(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H92!F;VQL;W=I;F<@
M<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@HB
M1&5M($)E;G5T>F5R(%PB)7-<(B!K;VYN=&5N(&1I92!F;VQG96YD92!296-H
M=&4@9OQR(&1E;B!/<F1N97(@7"(E<UPB(&YI8VAT("(*(GIU9V5W:65S96X@
M=V5R9&5N.B`E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,3D*
M;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R(")'97KD:&QT97(@5&5X="(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED
M(")#;W5N=')Y(@IM<V=S='(@(DQA;F0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C<U"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(DMU<G-E(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B17)S=&5L;&5N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8X"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@(DQI;FL@97)S
M=&5L;&5N(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN
M8SHY-@IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R(").975E($ED
M96YT:73D="!A;FQE9V5N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C-#,Q-"YP:'`Z-3(*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.3(*;7-G:60@(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R
M(")5;G1E<F]R9&YE<B!E<G-T96QL96XB"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C(T,`IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*
M;7-G<W1R(")%<G-T96QL97)R96-H=&4B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,C,P"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T
M<B`B2W)E9&ET:V%R=&5N;G5M;65R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(D-R
M;V%T:6$B"FUS9W-T<B`B2W)O871I96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#
M=6)A(@IM<V=S='(@(DMU8F$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*
M;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B06MT=65L;&4@-"!0
M:&%S96XB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*;7-G:60@(D-U<G)E
M;G0@4V5S<VEO;G,B"FUS9W-T<B`B06MT=65L;&4@4V5S<VEO;G,B"@HC.B!L
M:6(O0FQO8VLO=&EM92YP:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G
M:60@(D-U<G)E;G0@5&EM92(*;7-G<W1R(")!:W1U96QL92!:96ET(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4T"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G<W1R(")!:W1U96QL92!5
M4DP@:7-T(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,U"FUS9VED(")#=7)R
M96YT(%5S97)S(@IM<V=S='(@(D%K='5E;&QE($)E;G5T>F5R(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I9"`B0W5R<F5N="!796%T:&5R(@IM
M<V=S='(@(D%K='5E;&QE<R!7971T97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C8T"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM
M<V=S='(@(D1E<GIE:71I9V4@0F5D:6YG=6YG96XZ("(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E
M;G0@<W1Y;&4B"FUS9W-T<B`B06MT=65L;&5R(%-T:6PB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3$Q"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O
M;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B
M(@HB3&5G96X@4VEE(&9E<W0L('=E;&-H92!!=69G86)E;B!N86-H(&1E<B!!
M;FUE;&1U;F<@8F5I("5S(&5R;&5D:6=T('=E<F1E;B`B"B)S;VQL96XN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`B075S<V-H;F5I9&5N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I
M9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R(")!=7-W86AL(&%U<W-C:&YE:61E
M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C@*;7-G:60@(D-Y<')U<R(*;7-G<W1R("):>7!E<FXB
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B0WER:6QL:6,@
M*$M/23@M4BDB"FUS9W-T<B`B2WER:6QL:7-C:"`H2T])."U2*2(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@V"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W
M<RTQ,C4Q*2(*;7-G<W1R(")+>7)I;&QI<V-H("A7:6YD;W=S+3$R-3$I(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*;7-G:60@(D-Y<FEL;&EC+U5K
M<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R(")+>7)I;&QI<V-H+U5K<F%I;FES
M8V@@*$M/23@M52DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#>F5C:"!297!U8FQI
M8R(*;7-G<W1R(")4<V-H96-H:7-C:&4@4F5P=6)L:6LB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4R('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R(")45"(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,R.3`*;7-G:60@(B(*(D133B`H<V5E(&AT
M='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N
M9&(N:6YT<F\M9'-N+G!H<"DB"FUS9W-T<B`B(@HB1%-.("AS:65H92!H='1P
M.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B
M+FEN=')O+61S;BYP:'`I(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA
M:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`B5.1G;&EC
M:"(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I9"`B1&%T851R964@
M0G)O=W-E<B(*;7-G<W1R(")$871A5')E92!"<F]W<V5R(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S(X.`IM<V=I9"`B1&%T86)A<V4@3&]O:W5P
M(@IM<V=S='(@(D1A=&5N8F%N:V%B9G)A9V4B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(T,38*;7-G:60@(D1A=&4B"FUS9W-T<B`B1&%T=6TB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T
M92!296-E:79E9"(*;7-G<W1R(")%;7!F86YG<V1A='5M(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C@P-PIM<V=I9"`B1&%T92!S96QE8W1I;VXB
M"FUS9W-T<B`B1&%T=6US875S=V%H;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR.#$@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q
M,0IM<V=I9"`B1&%Y(@IM<V=S='(@(E1A9R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@IM<V=I9"`B1&5?
M;&5T92!#;VQU;6XB"FUS9W-T<B`B4W!A;'1E(%]L]G-C:&5N(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,PHC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4Q"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E
M8V5M8F5R(@IM<V=S='(@(D1E>F5M8F5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I9"`B1&5C
M:6UA;"!N=6UB97)S(@IM<V=S='(@(EIA:&QE;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C`*;7-G:60@(D1E8W)E87-E
M($EN9&5N="(*;7-G<W1R(")%:6YZ=6<@=F5R<FEN9V5R;B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3@W(&QI8B]P<F5F<RYP:'`Z,3$W
M"FUS9VED(")$969A=6QT(@IM<V=S='(@(E-T86YD87)D(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-S<*;7-G:60@(D1E
M9F%U;'0@0V]L;W(B"FUS9W-T<B`B4W1A;F1A<F1F87)B92(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R])9&5N=&ET>2YP:'`Z.3@*;7-G:60@(D1E9F%U;'0@261E
M;G1I='DB"FUS9W-T<B`B4W1A;F1A<F1I9&5N=&ETY'0B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-S4*;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T
M<B`B4W1A;F1A<F1S:&5L;"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M,PIM<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`B1&5F:6YI=&EO;F5N(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HW,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C,R-PHC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0S.0HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C,W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M-S$*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY-"!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$Q-PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$T,"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,PHC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.CDX"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E
M+FEN8SHQ,"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I
M9"`B1&5L971E(@IM<V=S='(@(DSV<V-H96XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S(*;7-G:60@(D1E
M;&5T92!#96QL(@IM<V=S='(@(EIE;&QE(&SV<V-H96XB"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C(P-2!A9&UI;B]G<F]U<',N<&AP.C(S,PIM<V=I9"`B1&5L
M971E($=R;W5P(@IM<V=S='(@(D=R=7!P92!L]G-C:&5N(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4Q"FUS9VED(")$96QE=&4@3&]G(@IM
M<V=S='(@(DQO9R!L]G-C:&5N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HW-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,0IM
M<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B4F5C:'1E(&SV<V-H
M96XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M,PIM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R(").
M86-H<FEC:'1E;B!L]G-C:&5N('5N9"!E;G1F97)N96XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W"FUS9VED
M(")$96QE=&4@8V5L;"(*;7-G<W1R("):96QL92!L]G-C:&5N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM
M<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R(")3<&%L=&4@;/9S8VAE;B(*
M"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS9VED(")$96QE=&4@97AI
M<W1I;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(D)E<W1E:&5N9&4@
M86QT97)N871I=F4@5F]R;&%G92!L]G-C:&5N(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-30*;7-G:60@(D1E;&5T92!M97-S
M86=E<R(*;7-G<W1R(").86-H<FEC:'1E;B!L]G-C:&5N(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B4F5C
M:'1E(&;\<B!<(B5S7"(@;/9S8VAE;B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z-#(T"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P
M97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS
M/R(*;7-G<W1R(")296-H=&4@9OQR(%PB)7-<(B!U;F0@86QL92!5;G1E<G)E
M8VAT92!L]G-C:&5N/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T
M<B`B6F5I;&4@;/9S8VAE;B(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I
M9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET
M>2(*;7-G<W1R(")!=7-G97?D:&QT92!)9&5N=&ETY'0@;/9S8VAE;B(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4S"FUS9VED
M(")$96QE=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B56YT97)O<F1N97(@;/9S
M8VAE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(&-O;'5M
M;B(*;7-G<W1R(")$:64@86MT=65L;&4@4W!A;'1E(&SV<V-H96XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C,*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B1&EE
M(&%K='5E;&QE(%IE:6QE(&SV<V-H96XB"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HS-@HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('-E='5P
M('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B1&%S($%K='5A;&ES
M:65R=6YG<W-K<FEP="!<(B5S7"(@=W5R9&4@9V5L]G-C:'0N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C,*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.34*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C(Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(U,PIM<V=I9"`B1&5L:79E<GD@=&EM92(*;7-G<W1R(")!=7-L:65F
M97)U;F=S>F5I="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1E;FUA<FLB"FUS9W-T
M<B`B1.1N96UA<FLB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`B0F5S
M8VAR96EB96X@4VEE(&1A<R!0<F]B;&5M(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.3,X('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S`*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(D)E
M<V-H<F5I8G5N9R(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,C`V
M"FUS9VED(")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM
M<V=S='(@(D1E=&%I;',@*&%U8V@@:6X@2&]R9&5S($QO9V1A=&5I*3HB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C(Q,`IM<V=I9"`B1&5T86EL
M<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS
M9W-T<B`B1&5T86EL<R!W=7)D96X@9OQR(&1E;B!!9&UI;FES=')A=&]R(&UI
M=&=E;&]G9W0N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R,0IM
M<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B16YT=VEC:VQU;F<B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(Q.0IM<V=I9"`B1&5W(%!O:6YT(@IM<V=S
M='(@(E1A=7!U;FMT(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.38*;7-G
M:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B5&%U<'5N
M:W0@9&5R(&QE='IT96X@4W1U;F1E.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C$V"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R(")4
M875P=6YK=#H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS
M9W-T<B`B5F]N(&QI;FMS(&YA8V@@<F5C:'1S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N
M(')I9VAT('1O(&QE9G0B"FUS9W-T<B`B5F]N(')E8VAT<R!N86-H(&QI;FMS
M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R
M>2(*;7-G<W1R(")697)Z96EC:&YI<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR-C(*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T
M<B`B6F5I="!I;2`R-"U3='5N9&5N+49O<FUA="!A;GIE:6=E;C\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`P"FUS9VED(")$:7-P;&%Y($]P=&EO
M;G,B"FUS9W-T<B`B06YZ96EG92U%:6YS=&5L;'5N9V5N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C@Y"FUS9VED(")$:7-P;&%Y(&1E=&%I
M;&5D(&9O<F5C87-T(@IM<V=S='(@(D1E=&%I;&EE<G1E(%9O<FAE<G-A9V4@
M86YZ96EG96XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.CDR"FUS9VED(")$
M:7-P;&%Y(&9O<F5C87-T("A4048I(@IM<V=S='(@(E9O<FAE<G-A9V4@*%1!
M1BD@86YZ96EG96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$W
M"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R(")!;GIE:6=E9F]R;6%T
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C$Y,0IM<V=I9"`B
M1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(D5M<&9A;F=S8F5S
M=.1T:6=U;F<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R
M(")$<V-H:6)U=&DB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C0R,@IM<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G<W1R(").:6-H="!L]G-C
M:&5N(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(U"FUS9VED(")$
M;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R
M(")'<F5I9F5N(%-I92!N:6-H="!D:7)E:W0@875F(&UA:6YT96YA;F-E+G!H
M<"!Z=2(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$R('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C$R"FUS9VED(")$;V5S('1H92!F:7)S
M="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@
M=&AI<R!B;W@Z(@IM<V=S='(@(B(*(D5N=&CD;'0@9&EE(&5R<W1E(%IE:6QE
M(&1I92!&96QD;F%M96X_(%=E;FX@:F$L(&1I97-E<R!!=7-W86AL:^1S=&-H
M96X@(@HB;6%R:VEE<F5N.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1O;6EN:6-A
M(@IM<V=S='(@(D1O;6EN:6-A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&]M:6YI
M8V%N(%)E<'5B;&EC(@IM<V=S='(@(D1O;6EN:6MA;FES8VAE(%)E<'5B;&EK
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY-@IM<V=I9"`B1&]N
M)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R(").;V-H(&ME
M:6YE;B!:=6=A;F<_($AI97(@86YM96QD96XN(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]#;VYT96YT<RYP:'`Z.#4S"FUS9VED(")$;W=N;&]A9"(*;7-G
M<W1R(")(97)U;G1E<FQA9&5N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z.#4S"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D
M("5S(@IM<V=S='(@(B5S($AE<G5N=&5R;&%D96XB"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,38Q"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N
M9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R(")%<GIE=6=T92!+
M;VYF:6=U<F%T:6]N(&%L<R!02%`M4VMR:7!T(&AE<G5N=&5R;&%D96XN(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$R-0IM<V=I9"`B1')O<"!D
M;W=N(&QI<W0B"FUS9W-T<B`B075S=V%H;&QI<W1E(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G<W1R(")$<F]G96XB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@
M(D4M36%I;"(*;7-G<W1R(")%+4UA:6PB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM=&\M4TU3
M(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T
M:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*(D4M36%I;"UN86-H+5--4RUG871E
M=V%Y(&;\<B!0<F]V:61E<BP@9&EE(&5I;F5N('-O;&-H96X@1&EE;G-T('5N
M=&5R<W3\='IE;BXB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS
M9W-T<B`B1D5(3$52(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G
M<W1R(")%8W5A9&]R(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS
M,C8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C<P('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M.3,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ.#(@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<R"FUS9VED
M(")%9&ET(@IM<V=S='(@(D)E87)B96ET96XB"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO54DN<&AP.C4P"FUS9VED(")%9&ET($)L;V-K(@IM<V=S='(@
M(D)L;V-K(&)E87)B96ET96XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(P-`IM
M<V=I9"`B161I="!'<F]U<"(*;7-G<W1R(")'<G5P<&4@8F5A<F)E:71E;B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S8@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#`*;7-G:60@(D5D:70@4&5R;6ES<VEO
M;B(*;7-G<W1R(")296-H=&4@8F5A<F)E:71E;B(*"B,Z('-E<G9I8V5S+W-H
M87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B"FUS
M9W-T<B`B4F5C:'1E(&)E87)B96ET96XB"@HC.B!S97)V:6-E<R]S:&%R97,O
M961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@4&5R;6ES
M<VEO;G,@9F]R("5S(@IM<V=S='(@(E)E8VAT92!F_'(@)R5S)R!B96%R8F5I
M=&5N(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B161I
M="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`B16EN<W1E;&QU;F=E;B!B96%R8F5I
M=&5N(&;\<CHB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,V
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B!<
M(B5S7"(B"FUS9W-T<B`B4F5C:'1E(&;\<B!<(B5S7"(@8F5A<F)E:71E;B(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B4F5C
M:'1E(&;\<B`E<R!B96%R8F5I=&5N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,U"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B0FEL9'5N9R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S`*;7-G:60@(D5G>7!T(@IM<V=S='(@(L1G>7!T96XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@(D5L(%-A;'9A
M9&]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@(D5L96UE
M;G0N+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B16TB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$X.#<*;7-G:60@(D5M86EL(@IM<V=S='(@(D4M36%I;"(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38V('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3`*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHV.`IM<V=I9"`B16UA:6P@061D<F5S<R(*
M;7-G<W1R(")%+4UA:6PM061R97-S92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y.#$*;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H
M+B(*;7-G<W1R(")$:64@12U-86EL+4%D<F5S<V5N(&W\<W-E;B!G;&5I8V@@
M<V5I;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`W"FUS9VED
M(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")%+4UA:6PM061R
M97-S92!M:70@0F5S=.1T:6=U;F<B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A
M=&5W87DB"FUS9W-T<B`B12U-86EL+6YA8V@M4TU3+4=A=&5W87DB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDY"FUS9VED
M(")%;6]T:6-O;G,B"FUS9W-T<B`B4VUI;&5Y<R(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM<V=I9"`B16UP
M='D@;65S<V%G92XB"FUS9W-T<B`B3&5E<F4@3F%C:')I8VAT+B(*"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR-#,@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C0X-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z-C8R(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HW,#4*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-3`*;7-G
M:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B3&5E<F5S($5R9V5B;FES+B(*
M"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@
M(D5M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R(")3=6-H8F5G<FEF9F4@;/9S
M8VAE;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#`*;7-G:60@(D5N
M86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S
M(&EN('1E>'0_(@IM<V=S='(@(D5I;F;\9V5N('9O;B!":6QD97)N(&%U<R!&
M;W1O9V%L97)I96X@:6X@9&5N(%1E>'0@97)L875B96X_(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4Q-0IM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K
M(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B2V]N=&5X=&UE;OP@8F5I(%)E8VAT
M<VML:6-K(&%K=&EV:65R96X_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C8P-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$Q"FUS9VED(")%
M;F0@>65A<B(*;7-G<W1R(")%;F1J86AR(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%9&ET
M;W(B"FUS9W-T<B`B161I=&]R('9E<F=R]M]E<FXB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C$V"FUS9VED("(B"B)%;G1E<B!A('-E8W5R:71Y('%U
M97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O
M(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA
M;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@HB1V5B96X@4VEE(&5I;F4@
M4VEC:&5R:&5I='-F<F%G92!E:6XL(&1I92!):&YE;B!G97-T96QL="!W:7)D
M+"!W96YN(%-I92!):'(@(@HB4&%S<W=O<G0@>G5R_&-K<V5T>F5N(&WV8VAT
M96XL('HN($(N(%PB5VEE(&QA=71E="!D97(@3F%M92!):')E<R!(875S=&EE
M<G,_(@HB7"(Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@
M55),(&AE<F4B"FUS9W-T<B`B2&EE<B!D:64@0FEL9"U54DP@86YG96)E;B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX.3(*
M;7-G:60@(D5N=&5R('1H92!L971T97)S(&)E;&]W.B(*;7-G<W1R(")'96)E
M;B!S:64@9&EE($)U8VAS=&%B96X@=6YT96X@96EN.B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*
M;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(L1Q=6%T;W)I86PM
M1W5I;F5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E82(*;7-G<W1R(")%
M<FET<F5A(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I
M;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+U9I97<N<&AP.CDR(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HT.`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,V"FUS9VED(")%
M<G)O<B(*;7-G<W1R(")&96AL97(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O
M5&5M<&QA=&4N<&AP.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C
M<F5A=&EN9R!B;&]C:SH@)7,B"FUS9W-T<B`B1F5H;&5R(&)E:6T@17)S=&5L
M;&5N(&5I;F5S($)L;V-K<SH@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN
M9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T<B`B1F5H;&5R(&)E:6T@3/9S8VAE
M;B!D97,@4WEN8VAR;VYI<V%T:6]N<V%N:V5R<SH@)7,B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B"FUS9W-T<B`B1F5H;&5R(&)E
M:6T@3/9S8VAE;B!D97,@4WEN8VAR;VYI<V%T:6]N<VQO9W,Z("5S(@H*(SH@
M9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*;7-G<W1R
M(")&96AL97(@8F5I;2!%<GIE=6=E;B!D97,@26YH86QT<SH@)7,B"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(D9E
M:&QE<B!B96EM(,1N9&5R;B!D97,@4&%S<W=O<G1S.B`E<R(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I
M9"`B17)R;W(@=VET:"!E;6%I;"!M97-S86=E+B(*;7-G<W1R(")&96AL97(@
M:6X@9&5R($4M36%I;"U.86-H<FEC:'0N(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP
M.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG(%PB)7-<
M(BXB"FUS9W-T<B`B1F5H;&5R(&)E:6T@4V-H<F5I8F5N('9O;B!<(B5S7"(N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,`IM<V=I9"`B17-T;VYI82(*;7-G<W1R(")%<W1L86YD
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`BQ'1H:6]P
M:65N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS9VED(")%=&AN
M:6,B"FUS9W-T<B`B171N:7-C:&5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B175R;W!A(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-@IM<V=I9"`B179E<GD@,34@
M;6EN=71E<R(*;7-G<W1R(")!;&QE(#$U($UI;G5T96XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S@V"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS
M9W-T<B`B06QL92`R($UI;G5T96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S,S(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#0*;7-G:60@(D5V97)Y
M(#,P('-E8V]N9',B"FUS9W-T<B`B06QL92`S,"!396MU;F1E;B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S4@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,X-PIM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(D%L;&4@-2!-
M:6YU=&5N(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E
M+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T<B`B0F5I(&IE9&5R
M($%N;65L9'5N9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S<*;7-G
M:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R(")!;&QE(&AA;&)E(%-T=6YD
M92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S0@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,X-0IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@(D%L
M;&4@-C`@4V5K=6YD96XB"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN
M8SHR-`IM<V=I9"`B17AA;7!L92!V86QU97,Z(@IM<V=S='(@(D)E:7-P:65L
M=V5R=&4Z(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C@R(&%D;6EN+V-M9'-H
M96QL+G!H<#HU,2!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"FUS9VED(")%>&5C
M=71E(@IM<V=S='(@(D%U<V;\:')E;B(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z-C$T"FUS9VED(")%>'!A;F0B"FUS
M9W-T<B`B5F5R9W+VWV5R;B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O
M<F1S+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R("(G*2<@
M97)W87)T970B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z
M,3<U"FUS9VED(")%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C
M:"!T97)M(@IM<V=S='(@(D5I;GIE;&YE<R!7;W)T(&]D97(@4W5C:&)E9W)I
M9F8@:6X@06YF_&AR=6YG<WIE:6-H96X@97)W87)T970B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER871I;VX@
M1&%T92(*;7-G<W1R(")697)F86QL<V1A='5M(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S<*;7-G:60@(D5X<&]N96YT(@IM<V=S
M='(@(D5X<&]N96YT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B
M5F]R9&5R9W)U;F1F87)B92(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M-S8*;7-G:60@(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B2&]C:&QA
M9&5N(&1E<B!+;VYF:6=U<F%T:6]N('!E<B!&5%`B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O<W%L+G!H<#HR,C4*;7-G:60@(D9A:6QE9"!R971R:65V
M:6YG('!R969E<F5N8V5S+B(*;7-G<W1R(")"96YU='IE<F5I;G-T96QL=6YG
M96X@:V]N;G1E;B!N:6-H="!G96QA9&5N('=E<F1E;BXB"@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!
M4"!S97)V97(N(@IM<V=S='(@(E9E<F)I;F1U;F<@>G5M($Q$05`@4V5R=F5R
M(&=E<V-H96ET97)T+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H
M<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB
M"FUS9W-T<B`B5F5R8FEN9'5N9R!Z=6T@4TU"+5-E<G9E<B!G97-C:&5I=&5R
M="XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS
M9W-T<B`B17,@:V]N;G1E(&ME:6YE($MO<&EE('9O;B!<(B5S7"(@97)S=&5L
M;'0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S(Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<
M(BXB"FUS9W-T<B`B17,@:V]N;G1E(&YI8VAT(&YA8V@@7"(E<UPB(&MO<&EE
M<G0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z
M.#<*;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO
M;BXB"FUS9W-T<B`B075F8F%U(&5I;F5N(&YE=65N(%-!4TPM5F5R8FEN9'5N
M9R!I<W0@9F5H;&=E<V-H;&%G96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HU,C,@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*
M;7-G<W1R(")%<R!K;VYN=&4@;FEC:'0@;F%C:"!<(B5S7"(@=F5R<V-H;V)E
M;B!W97)D96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(')E=')I979E.B`E<R(*
M;7-G<W1R(")&96AL97(@8F5I;2!,97-E;CH@)7,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F%I<B(*;7-G
M<W1R(")(96ET97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&86QK;&%N9"!)<VQA
M;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B1F%L:VQA;F1I;G-E;&XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<S"FUS9VED(")&87)O92!)<VQA;F1S(@IM<V=S='(@(D9A<O9E<B(*
M"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-#`*;7-G:60@(D9A=&%L($5R
M<F]R.B(*;7-G<W1R(")38VAW97)E<B!&96AL97(Z(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM
M<V=S='(@(D9A>"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3$*
M;7-G:60@(D9A>&5S(@IM<V=S='(@(D9A>&4B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM<V=I9"`B1F5B<G5A<GDB"FUS
M9W-T<B`B1F5B<G5A<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(R"FUS
M9VED(")&965L<R!,:6ME(@IM<V=S='(@(D=E9OQH;'1E(%1E;7!E<F%T=7(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(P"FUS9VED(")&
M965L<R!L:6ME.B`B"FUS9W-T<B`B1V5F_&AL=&4@5&5M<&5R871U<CH@(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G
M:60@(D9E=R!3:&]W97)S(@IM<V=S='(@(E9E<F5I;GIE;'1E(%-C:&%U97(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM
M<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")697)E:6YZ96QT92!3
M8VAN965S8VAA=65R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DV
M,@IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(D9E;&1M871R:7@B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S0S"FUS9VED(")&:6=L970@
M0T%05$-(02(*;7-G<W1R(")&:6=L970@0T%05$-(02(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,S-#<*;7-G:60@(D9I9VQE="!F;VYT(@IM<V=S
M='(@(D9I9VQE="U&;VYT(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEJ:2(*;7-G
M<W1R(")&:61S8VAI(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C4W"FUS9VED(")&:6QE(@IM<V=S='(@(D1A=&5I(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#
M;W5N=#H@)7,@9FEL92(*;7-G<W1R(")!;GIA:&PZ("5S($1A=&5I(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`B06YZ86AL.B`E<R!$
M871E:65N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P.0IM<V=I
M9"`B1FEL92!-86YA9V5R(@IM<V=S='(@(D1A=&5I;6%N86=E<B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,`HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"FUS9VED(")&:6QE($YA;64B"FUS
M9W-T<B`B1&%T96EN86UE(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,CDY-0IM<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T<B`B1&%T96EA=7-W
M86AL(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30X-@IM<V=I9"`B
M1FEL92!U<&QO860B"FUS9W-T<B`B1&%T96DM2&]C:&QA9&5N(@H*(SH@9G)A
M;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3`P"FUS9VED(")&:6QE('5P
M;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B1&%S($AO8VAL861E;B!V
M;VX@1&%T96EE;B!W:7)D(&YI8VAT('5N=&5R<W3\='IT+B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HY,0IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R
M(")&:6QT97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")&:6YL86YD(@IM<V=S='(@
M(D9I;FYL86YD(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V-@IM<V=I9"`B
M1FER<W0@2&%L9B(*;7-G<W1R(")%<G-T92!(Y&QF=&4B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&
M:7)S="!1=6%R=&5R(@IM<V=S='(@(D5R<W1E<R!6:65R=&5L(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U-PIM<V=I9"`B
M1FEX(')A=&EO(@IM<V=S='(@(E9E<FCD;'1N:7,@>G5R_&-K<V5T>F5N(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,@IM
M<V=I9"`B1FQI<"(*;7-G<W1R(")5;61R96AE;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L
M;V%T(@IM<V=S='(@(E1E>'1F;'7?(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(D9O9R(*;7-G<W1R(").96)E
M;"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C@P(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HQ,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(D1A<R!697)Z96EC
M:&YI<R`E<R!E>&ES=&EE<G0@;FEC:'0B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(R"FUS9VED(")&;VYT($-O;&]R(@IM
M<V=S='(@(E-C:')I9G1F87)B92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R(")%<W-E;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM
M<V=I9"`B1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B
M"FUS9W-T<B`B1OQR($)R;W=S97(L(&1I92!K96EN92!":6QD97(@=6YT97)S
M=/QT>F5N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,S8*;7-G:60@(D9O
M<F5C87-T("A4048I(@IM<V=S='(@(E9O<FAE<G-A9V4@*%1!1BDB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S(*;7-G:60@(B(*(D9O<F5C
M87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T
M=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE
M<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@HB
M5F]R:&5R9V5S86=T92!486=E("A6;W)H97)S86=E;B!E;G1H86QT96X@5&%G
M92!U;F0@3N1C:'1E+"!E:6X@:&]H97(@5V5R="`B"B)K86YN('IU(&5I;F5M
M('-E:'(@9W)OWV5N($)L;V-K(&;\:')E;BDB"@HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C$P,@IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_
M(@IM<V=S='(@(E!A<W-W;W)T('9E<F=E<W-E;C\B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#8T"FUS9VED(")&;W)M<R(*;7-G<W1R(")&;W)M
M=6QA<F4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*;7-G:60@(D9O
M<G1U;F4B"FUS9W-T<B`B1VS\8VMS:V5K<R(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S='(@(D=L_&-K
M<VME:W-T>7`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*;7-G:60@
M(D9O<G1U;F5S(@IM<V=S='(@(D=L_&-K<VME:W-E(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,Y"FUS9VED(")&;W)T=6YE<R`R(@IM<V=S='(@(D=L
M_&-K<VME:W-E(#(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4U
M"FUS9VED(")&;W)U;7,B"FUS9W-T<B`B1F]R96XB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3$Q"FUS9VED(")&;W)W87)D<R(*;7-G<W1R(")7
M96ET97)L96ET=6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`B1G(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S"FUS
M9VED(")&<F%M97,B"FUS9W-T<B`B4F%H;65N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I
M9"`B1G)A;F-E(@IM<V=S='(@(D9R86YK<F5I8V@B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI
M=&%N(@IM<V=S='(@(D5U<F]PY&ES8VAE<R!&<F%N:W)E:6-H(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C,*;7-G:60@(D9R
M965Z:6YG($1R:7IZ;&4B"FUS9W-T<B`B1V5F<FEE<F5N9&5R(%)E9V5N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R(")&<F%N
M>O9S:7-C:"U'=6%Y86YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0
M;VQY;F5S:6$B"FUS9W-T<B`B1G)A;GKV<VES8V@M4&]L>6YE<VEE;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S
M(@IM<V=S='(@(D9R86YZ]G-I<V-H92!'96)I971E(&EM('/\9&QI8VAE;B!)
M;F1I<V-H96X@3WIE86XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S='(@(E9O;B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,T.0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,SDU"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B075S("(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"FUS9VED(")&=6QL
M($1E<V-R:7!T:6]N(@IM<V=S='(@(E9O;&QS=.1N9&EG92!"97-C:')E:6)U
M;F<B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K+VUO;VXN
M<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(E9O;&QM;VYD(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8U('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z-C`*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R(")6
M;VQL<W3D;F1I9V5R($YA;64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")'86)O;B(*
M;7-G<W1R(")'86)U;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T
M86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B0FEL9&5R(&%U<R!D:65S97(@1V%L
M97)I92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B1V%L
M97)I93HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDV(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'86UB:6$B"FUS9W-T<B`B1V%M
M8FEA(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@
M(B5S+4MO;F9I9W5R871I;VX@97)Z975G96XB"@HC.B!T96UP;&%T97,O861M
M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I9"`B1V5N97)A=&5D($-O9&4B
M"FUS9W-T<B`B17)Z975G=&5R($-O9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'
M96]R9VEA(@IM<V=S='(@(D=E;W)G:65N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B
M1V5R;6%N>2(*;7-G<W1R(")$975T<V-H;&%N9"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HY,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G
M:60@(D=H86YA(@IM<V=S='(@(D=H86YA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B
M1VEB<F%L=&%R(@IM<V=S='(@(D=I8G)A;'1A<B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3<V"FUS9VED(")':79E;B!.86UE(@IM
M<V=S='(@(E9O<FYA;64B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP
M:'`Z,3<Y('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$P"B,Z('1E;7!L871E
M<R]P<F5F<R]A<'`N:6YC.C$Y"FUS9VED(")';&]B86P@3W!T:6]N<R(*;7-G
M<W1R(")!;&QG96UE:6YE($5I;G-T96QL=6YG96XB"@HC.B!T96UP;&%T97,O
M<')E9G,O87!P+FEN8SHQ-PIM<V=I9"`B1V\B"FUS9W-T<B`B3&]S(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D96PB"FUS9W-T
M<B`B1V]E9&5L(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$Q,S$*;7-G:60@(D=O;V=L92!-87!S(@IM<V=S='(@(D=O;V=L
M92!-87!S(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B
M1V]O9VQE(%-E87)C:"(*;7-G<W1R(")';V]G;&4@4W5C:&4B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,X"FUS9VED(")'
M<F%Y<V-A;&4B"FUS9W-T<B`B1W)A=7-T=69E;B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS
M9VED(")'<F5E8V4B"FUS9W-T<B`B1W)I96-H96YL86YD(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*
M;7-G<W1R(")'<FEE8VAI<V-H("A)4T\M.#@U.2TW*2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*
M;7-G:60@(D=R965N;&%N9"(*;7-G<W1R(")'<O9N;&%N9"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HY-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S0*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B1W)E;F%D82(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,3@U"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*
M;7-G<W1R(")'<G5P<&5N=F5R=V%L='5N9R(*"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"YP:'`Z-3D@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C$V.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS
M9W-T<B`B1W)U<'!E;FYA;65N(&3\<F9E;B!N:6-H="!L965R('-E:6XB"@HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L('!H<"UF
M;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@
M)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("(B
M"B)'<F]U<%]L9&%P.B!$:64@1W)U<'!E("5S(&MO;FYT92!N:6-H="!H:6YZ
M=6=E9OQG="!W97)D96XN($UE;&1U;F<@9&5S("(*(E-E<G9E<G,Z("(*"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3@@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P
M7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS9W-T<B`B1W)O
M=7!?;&1A<#H@1&EE($=R=7!P92`E<R!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@
M=V5R9&5N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,S
M."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O
M=7`@)7,B"FUS9W-T<B`B1W)O=7!?;&1A<#H@1&EE($=R=7!P92`E<R!K;VYN
M=&4@;FEC:'0@86MT=6%L:7-I97)T('=E<F1E;B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,C0Q(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S$T"B,Z
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3<X"FUS9VED(")'<F]U<',B"FUS9W-T<B`B1W)U<'!E;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B1W5A9&5L;W5P
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(D=U86TB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@(D=U871E;6%L
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3(*;7-G:60@(D=U
M97)N<V5Y(@IM<V=S='(@(D=U97)N<V5Y(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX
M.0IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B1V%S=')E8VAT
M92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S(*;7-G:60@(D=U
M97-T8F]O:R(*;7-G<W1R(")'Y'-T96)U8V@B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED
M(")'=6EN96$B"FUS9W-T<B`B1W5I;F5A(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED
M(")'=6EN96$M0FES<V%U(@IM<V=S='(@(D=U:6YE82U":7-S874B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S@*;7-G:60@(D=U>6%N82(*;7-G<W1R(")'=7EA;F$B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-C`*;7-G:60@(DA434PB"FUS9W-T
M<B`B2%1-3"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#4*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S
M97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R(")$
M97(@161I=&]R(&MA;FX@9&EE(&QE='IT92!:96QL92!E:6YE<B!:96EL92!N
M:6-H="!L]G-C:&5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY
M(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB
M"FUS9W-T<B`B1&5R($5D:71O<B!K86YN(&1I92!L971Z=&4@4W!A;'1E(&5I
M;F5R(%1A8F5L;&4@;FEC:'0@;/9S8VAE;BXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,
M07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@
M:6X@=&%B;&4N(@IM<V=S='(@(D1E<B!%9&ET;W(@:V%N;B!D:64@;&5T>G1E
M(%IE:6QE(&5I;F5R(%1A8F5L;&4@;FEC:'0@;/9S8VAE;BXB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VAT='`N<&AP.C$U-PIM<V=I9"`B2%144"!!=71H
M96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(DA45%`M075T:&5N=&EF
M:7II97)U;F<@;FEC:'0@9V5F=6YD96XN(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED
M(")(86ET:2(*;7-G<W1R(")(86ET:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T
M<B`B2&%S:"U!;&=O<FET:&UU<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(T"FUS9VED(")(87IE(@IM<V=S='(@(D1I97-I
M9R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDQ.2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.3,R"FUS9VED(")(96%D97(B"FUS9W-T<B`BW&)E
M<G-C:')I9G0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S
M970N<&AP.C8Q"FUS9VED(")(96%D97)S(@IM<V=S='(@(DMO<&9E:6YT<N1G
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O
M;F%L9"!)<VQA;F1S(@IM<V=S='(@(DAE87)D+2!U;F0@36-$;VYA;&1I;G-E
M;&XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M-0IM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R(")38VAW97)E($=E=VET
M=&5R(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DAE8G)E
M=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R(")(96)RY&ES8V@@*$E33RTX.#4Y
M+3@M22DB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HR,B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T"FUS9VED(")(
M96EG:'0B"FUS9W-T<B`B2/9H92(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92](96QP+G!H<#HQ.#0@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP
M.C$X-@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3<U('-E
M<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W"B,Z('1E;7!L871E<R]H96QP+VEN
M9&5X+FEN8SHT"FUS9VED(")(96QP(@IM<V=S='(@(DAI;&9E(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B
M2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`B161I=&]R:&EL9F4B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<Q"FUS9VED(")(96QP97(B"FUS
M9W-T<B`B2&EL9F4B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@
M(DAE;6ES<&AE<F4B"FUS9W-T<B`B2&5M:7-P:&5R92(*"B,Z('1E;7!L871E
M<R]D871A+W1S=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V-S=FEN9F\N
M:6YC.C$P"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I
M;&4Z(@IM<V=S='(@(D1I97,@:7-T(&1E<B!"96=I;FX@9&5R($1A=&5I.B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"FUS
M9VED(")(:6=H(@IM<V=S='(@(DAO8V@B"@HC.B!T96UP;&%T97,O<&]R=&%L
M+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC
M.C4*;7-G:60@(DAO7VUE(@IM<V=S='(@(E]3=&%R='-E:71E(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-`IM<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB
M"FUS9W-T<B`B5F%T:6MA;G-T861T(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$R,@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,34U"FUS9VED(")(;VUE($%D9')E<W,B"FUS
M9W-T<B`B061R97-S92!P<FEV870B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-S`*;7-G:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S='(@(DAE:6UV97)Z
M96EC:&YI<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B5&5L969O;B!P
M<FEV870B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@
M(DAO;F1U<F%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")(;VYG($MO;F<B"FUS
M9W-T<B`B2&]N9R!+;VYG(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C8W"FUS9VED(")(;W)D92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z-#<X"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN
M(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(%5N9_QL=&EG92`E
M<RU834PM1&%T96X@:6X@3F%C:')I8VAT("5S(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HR.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S(@IM
M<V=S='(@(DAO<F1E+TMO;&%B.B!%<R!P87-S="!K96EN92!.86-H<FEC:'0@
M>G5M($]B:F5K="`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M-#<Q"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE
M8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S(@IM<V=S='(@(DAO
M<F1E+TMO;&%B.B!+96EN($]B:F5K="!V;VT@5'EP("5S(&EN($YA8VAR:6-H
M="`E<R!G969U;F1E;B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,3(X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C8V5S
M<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B
M.B`E<R!<(B5S7"(@=W5R9&4@97)F;VQG<F5I8V@@96YT9F5R;G0B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L
M86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX
M;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B(@HB2&]R9&4O2V]L86(Z($1I
M92!);G1E9W)A=&EO;G-F=6YK=&EO;F5N(&)E;O9T:6=E;B!D:64@7")D;VUX
M;6Q<(B!02%`M(@HB17)W96ET97)U;F<B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C4S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E
M<R(*;7-G<W1R("(B"B)(;W)D92]+;VQA8CH@1OQR(&1A<R!/8FIE:W0@)7,@
M:V]N;G1E(&ME:6X@;F5U97(@6$U,+4)A=6T@97)Z975G="!W97)D96XB"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R.#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E
M<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@)7,@7"(E<UPB(&MO;FYT
M92!N:6-H="!E;G1F97)N="!W97)D96XZ("5S(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HU,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R
M="!O9B!T>7!E("5S(@IM<V=S='(@(B(*(DAO<F1E+TMO;&%B.B!$:64@34E-
M12U)1"!D97,@06)S8VAN:71T<R!V;VT@5'EP("5S(&MO;FYT92!N:6-H="`B
M"B)H97)A=7-G969U;F1E;B!W97)D96XN(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HQ,C,T"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G
M<W1R(")(;W)D92]+;VQA8CH@)7,@7"(E<UPB(&MO;FYT92!N:6-H="!S>6YC
M:')O;FES:65R="!W97)D96XZ("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HQ,S8X"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R("(B
M"B)(;W)D92]+;VQA8CH@1&EE(&=E;65I;G-A;65N($]B:F5K=&4@:V]N;G1E
M;B!N:6-H="!S>6YC:')O;FES:65R="!W97)D96XZ("5S(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HS-C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(DAO
M<F1E+TMO;&%B.B!5;F)E:V%N;G1E<R!G96UE:6YS86UE<R!/8FIE:W0@7"(E
M<UPB(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR-`IM<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(DAO<FEZ;VYT
M86QE($QI;FEE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX,@IM<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@
M(DAO<FEZ;VYT86QE<B!);FYE;F%B<W1A;F0B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L
M.B(*;7-G<W1R(")(;W)I>F]N=&%L.B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I
M9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B5VEE
M('-I;F0@4VEE(&AI97)H97)G96QA;F=T/R!":71T92!A;B!D:64@16YT=VEC
M:VQE<B!Z=7+\8VMM96QD96XA*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O
M;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(E=I92!V
M:65L92!3<&%L=&5N('-O;&QE;B!Z=7-A;6UE;F=E9OQG="!W97)D96X_(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M
M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G<W1R(")7:65V
M:65L92!&96QD97(@*%-P86QT96XI(&=I8G0@97,_(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B
M2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T
M<B`B5VEE('9I96QE(%IE:6QE;B!S;VQL96X@>G5S86UM96YG96;\9W0@=V5R
M9&5N/R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,S(*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@
M(DQU9G1F975C:'1I9VME:70B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C0X"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@(DQU9G1F975C
M:'1I9VME:70Z("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I
M9"`B2'5M;W)I<W1S(@IM<V=S='(@(DMO;6EK97(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*
M;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B56YG87)N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<R(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER<W%L+G!H<#HR,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL
M8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B06YL96=E;B!D97,@
M24U!4"U0;W-T9F%C:',@:7-T(&9E:&QG97-C:&QA9V5N.B`E<R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(Q-"!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G-Q;"YP:'`Z,CDU"B,L('!H<"UF;W)M870*;7-G:60@(DE-
M05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM<V=S='(@(DSV<V-H
M96X@9&5S($E-05`M4&]S=&9A8VAS(&ES="!F96AL9V5S8VAL86=E;CH@)7,B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-SD@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(T,@HC+"!P:'`M9F]R;6%T"FUS
M9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<R(*
M;7-G<W1R(")&97-T;&5G96X@9&5R($E-05`M4&]S=&9A8V@M475O=&$@:7-T
M(&9E:&QG97-C:&QA9V5N.B`E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$S,38*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`B25`M061R97-S
M92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G
M:60@(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B25`M061R
M97-S92!N:6-H="!V97)F_&=B87(N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN
M(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B25`M061R97-S92!N:6-H
M="!I;2!E<FQA=6)T96X@0TE$4BU";&]C:RXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@(DE0(&QO
M8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B5F5R;&5T>G5N9R!D97(@9F5S
M=&=E;&5G=&5N($E0+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F
M;W)E(@IM<V=S='(@(EIE:6QE(&5I;F;\9V5N(%]V;W(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#(*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B27-L86YD(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,W,PIM<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R
M(").=7(@0FEL9&5R(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L
M('!H<"UF;W)M870*;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R("))8V]N
M<R!F_'(@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<T"FUS9VED
M("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B0FEL9&5R('5N9"!497AT(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X-0IM<V=I9"`B261E;G1I='DG
M<R!N86UE.B(*;7-G<W1R(")"97IE:6-H;G5N9R!D97(@261E;G1I=.1T(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-C`P"B,L('!H
M<"UF;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C
M=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B
M(@HB5V5N;B!S:64@;FEC:'0@:V]R<F5K="!A;F=E>F5I9W0@=VER9"P@)7,L
M('5M('-I92!I;B!E:6YE;2!N975E;B!&96YS=&5R("(*(F%N9V5Z96EG="!Z
M=2!B96MO;6UE;BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4R"FUS
M9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E
M<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@
M8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*
M(E=E;FX@4VEE(&UI="!D96T@26YT97)N970@17AP;&]R97(@:V5I;F4@4WEM
M8F]L92!S96AE;BP@;?QS<V5N(%-I92!D:65S97,@(@HB2^1S=&-H96X@;6%R
M:VEE<F5N+"!U;2!03D<M5')A;G!A<F5N>B!A=7-Z=7-T96QL96XN(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W,@IM<V=I
M9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T
M:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L
M87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*(E=E;FX@4VEE(&1I
M97-E($YA8VAR:6-H="!A;B!3=&5L;&4@96EN92!":6QD97,@<V5H96XL(&MA
M;FX@26AR($)R;W=S97(@9&%S("(*(D)I;&0L(&1A<R!3:64@:&]C:&QA9&5N
M(&WV8VAT96X@;FEC:'0@86YZ96EG96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(X"FUS9VED("))
M;6%G92!0<F5V:65W.B(*;7-G<W1R(")":6QD=F]R<V-H874Z(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM
M<V=I9"`B26UA9V4@55),(@IM<V=S='(@(D)I;&0M55),(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3@*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Q
M"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(D)I;&0M55),.B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@(D)I;&0@
M=F]N($=A;&5R:64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L
M;&5R>3HB"FUS9W-T<B`B0FEL9"!V;VX@1V%L97)I93HB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-S8Q"FUS9VED("));6%G92!U<&QO860B"FUS
M9W-T<B`B0FEL9"U(;V-H;&%D96XB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H
M<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(D)I;&1E<B(*"B,Z('1E;7!L
M871E<R]D871A+W1S=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA
M<"YI;F,Z-PHC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4T('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(DEM<&]R=&EE<F5N+"!38VAR:71T
M("5D(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(DEM
M<&]R=&EE<G1E<R!&96QD.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`B26UP
M;W)T:65R=&4@1F5L9&5R.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2;W<@
M069T97(B"FUS9W-T<B`B6F5I;&4@96EN9OQG96X@7VYA8V@B"@HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S0*;7-G:60@(DEN
M8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B56YG_&QT:6=E
M($%K=&EO;B!A;F=E9V5B96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*;7-G:60@(DEN8V]R<F5C="!U<V5R
M;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(E5N9_QL=&EG97(@0F5N
M=71Z97)N86UE('5N9"]O9&5R(%!A<W-W;W)T+B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C4S"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA
M;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T
M('EO=7(@(@HB861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE
M;'`N(@IM<V=S='(@(B(*(D9A;'-C:&5R($)E;G5T>F5R;F%M92!O9&5R($4M
M36%I;"U!9')E<W-E+B!697)S=6-H96X@4VEE(&5S(&5R;F5U="!O9&5R("(*
M(G=E;F1E;B!3:64@<VEC:"!A;B!):')E;B!3>7-T96UA9&UI;FES=')A=&]R
M+"!W96YN(%-I92!W96ET97)E($AI;&9E("(*(F)E;O9T:6=E;BXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED
M("));F-R96%S92!);F1E;G0B"FUS9W-T<B`B16EN>G5G('9E<F=R]M]E<FXB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#$*;7-G:60@(DEN9&EA(@IM<V=S='(@(DEN9&EE;B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C4T('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3,U"FUS9VED("));F1I=FED=6%L(%5S97)S
M(@IM<V=S='(@(D5I;GIE;&YE($)E;G5T>F5R(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS
M9VED("));F1O;F5S:6$B"FUS9W-T<B`B26YD;VYE<VEE;B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(DEN
M9F\B"FUS9W-T<B`B26YF;W)M871I;VXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C4Y"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R("));F9O
M<FUA=&EO;F5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q
M.0IM<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB"FUS
M9W-T<B`B26YF;W)M871I;VYE;B!N:6-H="!M96AR('9E<F;\9V)A<BXB"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,U"FUS9VED("))
M;FAE<FET960@365M8F5R<R(*;7-G<W1R(")697)E<F)T92!-:71G;&EE9&5R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R
M(")?4W!A;'1E(&1A=F]R(&5I;F;\9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS9VED("))
M;G-E<G0@26UA9V4B"FUS9W-T<B`B0FEL9"!H:6YZ=6;\9V5N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I9"`B
M26YS97)T(%1A8FQE(@IM<V=S='(@(E1A8F5L;&4@96EN9OQG96XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED
M("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B3&EN:R!E:6YF_&=E;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS-`IM<V=I9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(E-?
M<&%L=&4@9&%N86-H(&5I;F;\9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED("));G-E<G0@
M82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R(")%
M:6YE(&YE=64@4W!A;'1E(&YA8V@@9&5R(&%K='5E;&QE;B!E:6YF_&=E;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE
M(&-U<G)E;G0@;VYE(@IM<V=S='(@(D5I;F4@;F5U92!3<&%L=&4@=F]R(&1E
M<B!A:W1U96QL96X@96EN9OQG96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@(DEN<V5R="!A
M(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(D5I;F4@
M;F5U92!:96EL92!N86-H(&1E<B!A:W1U96QL96X@96EN9OQG96XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C$*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT
M(&]N92(*;7-G<W1R(")%:6YE(&YE=64@6F5I;&4@=F]R(&1E<B!A:W1U96QL
M96X@96EN9OQG96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-S`*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P
M:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(D5I;F5N(&YE=65N
M($%B<V%T>B!N86-H(&1E;2!A:W1U96QL96X@16QE;65N="!E:6YF_&=E;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@
M8W5R<F5N="!N;V1E(@IM<V=S='(@(D5I;F5N(&YE=65N($%B<V%T>B!V;W(@
M9&5M(&%K='5E;&QE;B!%;&5M96YT(&5I;F;\9V5N(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA
M=&4B"FUS9W-T<B`B06QT97)N871I=F4@5F]R;&%G92!E:6YF_&=E;B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S0*;7-G:60@(DEN<V5R="!A;B!E
M;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W
M('!A<W-W;W)D.B(*;7-G<W1R("(B"B)'96)E;B!3:64@96EN92!%+4UA:6PM
M061R97-S92!A;BP@86X@9&EE(&1A<R!N975E(%!A<W-W;W)T(&=E<V-H:6-K
M="!W97)D96X@(@HB<V]L;#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4X"FUS9VED("));G-E<G0@8V5L;"!A
M9G1E<B(*;7-G<W1R("):96QL92!D86YA8V@@96EN9OQG96XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Y"FUS
M9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`B6F5L;&4@9&%V;W(@
M96EN9OQG96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L=6UN(&%F=&5R(@IM
M<V=S='(@(E-P86QT92!D86YA8V@@96EN9OQG96XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U"FUS9VED("))
M;G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R(")3<&%L=&4@9&%V;W(@96EN
M9OQG96XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H
M<#HU,`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M,`IM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S='(@(DYA8VAR:6-H=&5N
M(&AI;GIU9OQG96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@
M869T97(B"FUS9W-T<B`B06)S871Z(&1A;F%C:"!E:6YF_&=E;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M-`IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B06)S
M871Z(&1A=F]R(&5I;F;\9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(')O=R!A
M9G1E<B(*;7-G<W1R("):96EL92!D86YA8V@@96EN9OQG96XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8X"FUS
M9VED("));G-E<G0@<F]W(&)E9F]R92(*;7-G<W1R("):96EL92!D879O<B!E
M:6YF_&=E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C4*;7-G:60@
M(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q
M=65S=&EO;CHB"FUS9W-T<B`B1V5B96X@4VEE(&1I92!!;G1W;W)T(&%U9B!D
M:64@4VEC:&5R:&5I='-F<F%G92!E:6XZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM<V=I9"`B26YS97)T+TUO9&EF
M>2!);6%G92(*;7-G<W1R(")":6QD(&5I;F;\9V5N+V)E87)B96ET96XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS
M9VED("));G-E<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B3&EN:R!E:6YF_&=E
M;B]B96%R8F5I=&5N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70@
M=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(EIU
M('=E;FEG($=U=&AA8F5N+"!U;2!A;B!D:64@5F5R=&5I;&5R;&ES=&4@>G4@
M=F5R<V-H:6-K96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70N
M(@IM<V=S='(@(EIU('=E;FEG($=U=&AA8F5N+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$P-S4*;7-G:60@(DEN=&5G97(B"FUS9W-T<B`B1V%N
M>GIA:&PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3,S"FUS9VED
M("));G1E9V5R(&QI<W0B"FUS9W-T<B`B3&ES=&4@=F]N($=A;GIZ86AL96XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.3<*;7-G:60@(DEN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN
M(@IM<V=S='(@(E5N9_QL=&EG97(@541(+B`H57-E<B!$871A($AE861E<BDN
M(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,38W
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$Y-`HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,3(*;7-G
M:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`B56YG_&QT:6=E(%I)4"U$
M871E;BXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T"FUS9VED("))
M;G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R(")5;F?\;'1I9V4@06YW96YD
M=6YG+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI9"!B871C:"!)1"XB"FUS9W-T<B`B
M56YG_&QT:6=E($)A=&-H+4E$+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q,#4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$W-@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C4P(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S,3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T
M+G!H<#HS-PIM<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T
M<B`B56YG_&QT:6=E($1A=&5N(&5I;F=E8F5N+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,`IM<V=I9"`B26YV
M86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R(")5;F?\;'1I9V4@
M6FEE;&%D<F5S<V4N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S
M+V1B>"YP:'`Z,3`Y"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D
M8G@N<&AP.C$S.0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X
M+G!H<#HR-#$*;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B
M56YG_&QT:6=E<R!$871E:69O<FUA="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-C4*;7-G:60@(DEN=F%L:60@;&EC96YS92!K97DN(@IM
M<V=S='(@(E5N9_QL=&EG97(@3&EZ96YZ<V-H;/QS<V5L+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3D*;7-G:60@(DEN=F%L:60@;&]C
M871I;VX@<')O=FED960N(@IM<V=S='(@(E5N9_QL=&EG97(@3W)T(&%N9V5G
M96)E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@
M(E5N9_QL=&EG97(@;7-G7W1Y<&4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S"FUS9VED("));G9A;&ED(&]R
M(&UI<W-I;F<@87!I7VED+B(*;7-G<W1R(")5;F?\;'1I9V4@;V1E<B!F96AL
M96YD92!A<&E?:60N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@
M<&%R86UE=&5R<RXB"FUS9W-T<B`B56YG_&QT:6=E(&]D97(@9F5H;&5N9&4@
M4&%R86UE=&5R+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR-PIM
M<V=I9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B56YG
M_&QT:6=E<R#<8F5R<F5C:'0N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$V,0IM<V=I9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R
M(")5;F?\;'1I9V4@4&%R=&YE<BU)1"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,38S"FUS9VED("));G9A;&ED('!R;V1U8W0@8V]D92XB
M"FUS9W-T<B`B56YG_&QT:6=E<B!0<F]D=6MT8V]D92XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G:60@
M(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(E5N9_QL=&EG97,@4')O=&]K
M;VQL+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z.3,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HW,2!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C@P"B,L
M('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@<F5C:7!I96YT.B!<(B5S7"(B
M"FUS9W-T<B`B56YG_&QT:6=E<B!%;7!FY&YG97(Z(%PB)7-<(B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$Q-R!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C$R.3<*;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM
M<V=S='(@(E5N9_QL=&EG97,@9V5M96EN<V%M97,@3V)J96MT(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"FUS
M9VED("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R(")5;F?\;'1I
M9V4@57)S<')U;F=S861R97-S92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI
M8V]D92!D871A+B(*;7-G<W1R(")5;F?\;'1I9V4@56YI8V]D92U$871E;BXB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4Y"FUS9VED("));G9E
M;G1O<GDB"FUS9W-T<B`B26YV96YT87(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<X"FUS9VED("));G9E<G0@<V5L96-T
M:6]N(@IM<V=S='(@(D%U<W=A:&P@=6UK96AR96XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*
M;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B27-L
M86UI<V-H92!297!U8FQI:R!)<F%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))
M<F%Q(@IM<V=S='(@(DER86LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DER96QA
M;F0B"FUS9W-T<B`B27)L86YD(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,34*;7-G:60@(DES;&4@;V8@36%N(@IM<V=S='(@(DES;&4@;V8@
M36%N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C8*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM<V=S='(@(E9E<F5I;GIE
M;'1E($=E=VET=&5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<W)A96PB"FUS
M9W-T<B`B27-R865L(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV,C8*;7-G:60@(DES<W5E<B(*;7-G<W1R(")!=7-S=&5L;&5R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS
M9VED("))=&%L:6,B"FUS9W-T<B`B2W5R<VEV(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS
M9VED("))=&%L>2(*;7-G<W1R("))=&%L:65N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS
M9VED(")*86UA:6-A(@IM<V=S='(@(DIA;6%I:V$B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`R"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#`*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*
M;7-G<W1R(")*86YU87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIA<&%N(@IM
M<V=S='(@(DIA<&%N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G
M:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`B2F%P86YI<V-H
M("A)4T\M,C`R,BU*4"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$R,@IM<V=I9"`B2F5R<V5Y(@IM<V=S='(@(DIE<G-E>2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,PIM<V=I9"`B2F]R9&%N(@IM<V=S='(@(DIO<F1A;FEE;B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#@*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*
M=6QY(@IM<V=S='(@(DIU;&DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`W"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R(")*=6YI(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R(")";&]C:W-A='HB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T<B`B6F5N=')I97)E;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B0FQO8VMS871Z
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,30*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R("),:6YK<R!A
M=7-R:6-H=&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T
M<B`B4F5C:'1S(&%U<W)I8VAT96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA
M>F%K:'-T86XB"FUS9W-T<B`B2V%S86-H<W1A;B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR-C4*;7-G:60@(DME97`@;W)I
M9VEN86P_(@IM<V=S='(@(D]R:6=I;F%L(&)E:6)E:&%L=&5N/R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T<B`B2V5N:6$B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@U"FUS9VED(")+97)B97)O<R!S
M97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DME<F)E
M<F]S+5-E<G9E<B!H870@075T:&5N=&EF:7II97)U;F<@>G5R_&-K9V5W:65S
M96XN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED(")+97)N
M96P@3F5W8FEE<R(*;7-G<W1R(")+97)N96PM3F5U;&EN9V4B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A
M=&EO;B(*;7-G<W1R(")38VAL_'-S96QE<GIE=6=U;F<B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@(DME>2!&:6YG97)P
M<FEN="(*;7-G<W1R(")&:6YG97)A8F1R=6-K(&1E<R!38VAL_'-S96QS(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+
M97D@3&5N9W1H(@IM<V=S='(@(E-C:&S\<W-E;&SD;F=E(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@5'EP92(*
M;7-G<W1R(")38VAL_'-S96QT>7`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4Y.0IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(E-C
M:&S\<W-E;'IW96-K(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-S0P"FUS9VED(")+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI
M8R!K97ES97)V97(N(@IM<V=S='(@(B(*(D1E<B!38VAL_'-S96P@8F5F:6YD
M970@<VEC:"!B97)E:71S(&%U9B!D96T@]F9F96YT;&EC:&5N(%-C:&S\<W-E
M;'-E<G9E<BXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@
M(DMI9',B"FUS9W-T<B`B2VEN9&5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+
M:7)I8F%T:2(*;7-G<W1R(")+:7)I8F%T:2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I
M9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS
M9W-T<B`B1&5M;VMR871I<V-H92!6;VQK<W)E<'5B;&EC($MO<F5A(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@U"FUS9VED(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B
M4F5P=6)L:6L@2V]R96$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM
M<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@(DMO<F5A;FES8V@@*$55
M0RU+4BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R(")+
M=7=A:70B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T
M<B`B2VER9VES:7-T86XB"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC
M.C@*;7-G:60@(DQA7WEO=70B"FUS9W-T<B`B06Y?<&%S<V5N(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B"FUS
M9W-T<B`B4W!R86-H92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&%O(%!E;W!L
M92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T<B`B3&%O<R(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HQ-CD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R
M("),971Z=&4@2.1L9G1E(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@X
M"FUS9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R("),971Z=&4@
M4&%S<W=O<G3D;F1E<G5N9R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX-B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G
M<W1R("),971Z=&5S(%9I97)T96PB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$U,PIM<V=I9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R("),971Z=&4@06MT
M=6%L:7-I97)U;F<Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$W
M"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@
M(DQE='IT92!!;FUE;&1U;F<Z("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S
M(&9R;VT@)7,B"FUS9W-T<B`B3&5T>G1E($%N;65L9'5N9SH@)7,@=F]N("5S
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$T"FUS9VED("),87-T
M(&QO9VEN.B!.979E<B(*;7-G<W1R("),971Z=&4@06YM96QD=6YG.B!.;V-H
M(&YI92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(DQE
M='1L86YD(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED("),
M87<B"FUS9W-T<B`B1V5S971Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"FUS9VED("),87EO=70B"FUS9W-T
M<B`B1F]R;6%T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<B(*
M;7-G<W1R("),965R(&QA<W-E;B!F_'(@:V5I;F5N(%)A:&UE;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R("),:6)A;F]N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y
M"FUS9VED("),969T(@IM<V=S='(@(DQI;FMS(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$Q.0IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B
M3&EN:V4@W&)E<G-C:')I9G0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,3$U"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R("),:6YK92!797)T
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("),97-O
M=&AO(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4W"FUS9VED
M("),979E;"(*;7-G<W1R(")%8F5N92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B
M3&EB97)I82(*;7-G<W1R("),:6)E<FEA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED
M("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(DQI8GEE;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("),:65C
M:'1E;G-T96EN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C<*;7-G:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`B4W!R_&AR
M96=E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(X"FUS9VED("),:6=H="!286EN(@IM<V=S='(@(DQE:6-H=&5R(%)E9V5N
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*
M;7-G:60@(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B1G+\:"!L96EC:'1E
M<B!296=E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,P"FUS9VED("),:6=H="!286EN($QA=&4B"FUS9W-T<B`B4W#D=&5R
M($QE:6-H=&5R(%)E9V5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S$*;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S
M='(@(DQE:6-H=&4@4F5G96YS8VAA=65R(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%)A:6X@=VET
M:"!4:'5N9&5R(@IM<V=S='(@(DQE:6-H=&5R(%)E9V5N(&UI="!'97=I='1E
M<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S
M"FUS9VED("),:6=H="!3;F]W(@IM<V=S='(@(DQE:6-H=&5R(%-C:&YE969A
M;&PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M-`IM<V=I9"`B3&EG:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`B3&5I8VAT92!3
M8VAN965S8VAA=65R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0U"FUS
M9VED("),:6UE<FEC:R(*;7-G<W1R("),:6UE<FEC:R(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$X,30*;7-G:60@(DQI;FLB"FUS9W-T<B`B3&EN
M:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,3<*;7-G:60@(DQI
M;FL@55),(@IM<V=S='(@(DQI;FLM55),(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@S,@IM<V=I9"`B3&EN:R!A8V-E<W,@:V5Y(@IM<V=S='(@
M(DQI;FLM6G5G<FEF9G-T87-T92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B3&EN:R!P;VEN
M=',@=&\Z(@IM<V=S='(@(DQI;FL@=F5R=V5I<W0@875F.B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X,C,*;7-G:60@(DQI;FL@=&%R9V5T(@IM
M<V=S='(@(DQI;FLM6FEE;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X,C`*;7-G:60@(DQI;FL@=&5X="(*;7-G<W1R("),:6YK+51E>'0B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#DS"FUS9VED("),:6YK('1H
M92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P
M;&%Y:6YG(@IM<V=S='(@(D4M36%I;"U!9')E<W-E('9E<FQI;FME;C\B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#(Y"FUS9VED("),:6YK('1I
M=&QE(&%T=')I8G5T92(*;7-G<W1R("),:6YK+51I=&QE+4%T=')I8G5T(@H*
M(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H=&UL,G1E>'0N<&AP
M.C$X,@IM<V=I9"`B3&EN:W,B"FUS9W-T<B`B3&EN:W,B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI92(*;7-G<W1R
M("),:6YU>"U';/QC:W-K96MS92(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S0S,30N<&AP.C0V"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T("T@=7-E<B!C86X@<V5E('1H
M92!F;VQD97(B"FUS9W-T<B`B3&ES="`M($)E;G5T>F5R(&MA;FX@9&5N($]R
M9&YE<B!S96AE;B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S0*;7-G:60@
M(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(D1A=&5N8F%N:V5N(&%N>F5I9V5N
M(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3(*;7-G:60@(DQI<W0@
M2&5L<"!4;W!I8W,B"FUS9W-T<B`B2&EL9F5E:6YT<N1G92!A;GIE:6=E;B(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*;7-G:60@(DQI<W0@5&%B;&5S
M(@IM<V=S='(@(E1A8F5L;&5N(&%N>F5I9V5N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12](96%D97)S+G!H<#HV,#$*;7-G:60@(DQI<W0M07)C:&EV92(*
M;7-G<W1R("),:7-T96XM07)C:&EV(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12](96%D97)S+G!H<#HU.38*;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R("),
M:7-T96XM2&EL9F4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N
M<&AP.C8P,PIM<V=I9"`B3&ES="U)9"(*;7-G<W1R("),:7-T96XM260B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y.0IM<V=I9"`B
M3&ES="U/=VYE<B(*;7-G<W1R("),:7-T96XM0F5S:71Z97(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C8P,`IM<V=I9"`B3&ES="U0
M;W-T(@IM<V=S='(@(DQI<W1E;BU!9')E<W-E(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12](96%D97)S+G!H<#HU.3@*;7-G:60@(DQI<W0M4W5B<V-R:6)E
M(@IM<V=S='(@(DQI<W1E;BU!;FUE;&1U;F<B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TAE861E<G,N<&AP.C4Y-PIM<V=I9"`B3&ES="U5;G-U8G-C<FEB
M92(*;7-G<W1R("),:7-T96XM06)M96QD=6YG(@H*(SH@861M:6XO<V5S<VEO
M;G,N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@<V5S<VEO
M;G,@9F%I;&5D.B`E<R(*;7-G<W1R(")$87,@06YZ96EG96X@9&5R(%-E<W-I
M;VYS(&ES="!F96AL9V5S8VAL86=E;CH@)7,B"@HC.B!A9&UI;B]S97-S:6]N
M<RYP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!U<V5R<R!F
M86EL960Z("5S(@IM<V=S='(@(D1A<R!!;GIE:6=E;B!D97(@0F5N=71Z97(@
M:7-T(&9E:&QG97-C:&QA9V5N.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A
M8FQE9"XB"FUS9W-T<B`B1&%S($%N>F5I9V5N(&1E<B!"96YU='IE<B!I<W0@
M;FEC:'0@;?9G;&EC:"XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*
M;7-G:60@(DQI=&5R871U<F4B"FUS9W-T<B`B3&ET97)A='5R(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@Y"FUS9VED("),:71H=6%N:6$B"FUS9W-T<B`B3&ET875E;B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z-S<*;7-G
M:60@(DQO861I;F<N+BXB"FUS9W-T<B`B3&%D92XN+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,#`*;7-G:60@(DQO8V%L('1I;64Z("(*
M;7-G<W1R("),;VMA;&4@56AR>F5I=#H@(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@V"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B4W!R
M86-H92!U;F0@6F5I="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3<R(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-PHC.B!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HW
M,@IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B3W)T(@H*(SH@;&]G:6XN<&AP
M.C$X.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C`T('1E;7!L871E
M<R]L;V=I;B]M;V)I;&4N:6YC.C,*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL
M92YI;F,Z,34@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY,`IM<V=I9"`B
M3&]G(&EN(@IM<V=S='(@(D%N;65L9&5N(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C0W"FUS9VED("),;V<@;V8@<')E=FEO=7,@<WEN8R!S
M97-S:6]N(@IM<V=S='(@(DQO9R!D97(@;&5T>G1E;B!3>6YC:')O;FES871I
M;VXN(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y.`IM<V=I
M9"`B3&]G(&]U="(*;7-G<W1R(")!8FUE;&1E;B(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HV,0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`B06YM96QD96XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$P"FUS9VED("),;V=I;B!4
M87-K<R(*;7-G<W1R(")!;FUE;&1E875F9V%B96XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HY.34*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E
M('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R
M96-T;'DN(@IM<V=S='(@(B(*(D1I92!!;FUE;&1U;F<@:7-T(&9E:&QG97-C
M:&QA9V5N+"!W96EL(%-I92!):')E;B!"96YU='IE<FYA;65N(&]D97(@26AR
M("(*(E!A<W-W;W)T(&9A;'-C:"!E:6YG96=E8F5N(&AA8F5N+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY,0IM<V=I9"`B3&]G:6X@9F%I;&5D
M+B(*;7-G<W1R(")!;FUE;&1U;F<@9F5H;&=E<V-H;&%G96XN(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-0IM<V=I9"`B3&]N9R!T97AT(@IM
M<V=S='(@(DQA;F=E<B!497AT(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0X"FUS9VED("),;W9E(@IM<V=S='(@(DQI96)E(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*;7-G:60@(DQO=R(*;7-G
M<W1R(").:65D<FEG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T
M=&5R<R(*;7-G<W1R(")+;"X@9W)I96-H:7-C:&4@0G5C:'-T86)E;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B2VPN
M(&QA=&5I;FES8VAE($)U8VAS=&%B96XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$W"FUS9VED("),;W=E
M<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(DML+B!R]FUI<V-H92!:86AL96XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B3'5X
M96UB=7)G(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#,Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G
M<W1R(")-32(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#,*;7-G
M:60@(DU/5$0B"FUS9W-T<B`B34]41"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1N968N<&AP.C,V"FUS9VED(")-4RU43D5&($%T=&%C:&UE
M;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(DU3+51.148M06YH86YG
M(&5N=&AI96QT(&ME:6YE($1A=&5N+B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*;7-G
M:60@(DU31R(*;7-G<W1R(")(24Y714E3(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED
M(")-86-A;R(*;7-G<W1R(")-86-A;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,34S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B
M36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(D1I92!E:&5M86QI9V4@2G5G;W-L87=I<V-H92!297!U8FQI:R!-
M87IE9&]N:65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-861A9V%S8V%R(@IM
M<V=S='(@(DUA9&%G87-K87(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#D*;7-G:60@(DUA9VEC(@IM<V=S='(@(DUA9VEE(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C@S"FUS9VED(")-86EL(@IM<V=S='(@(E=E8FUA
M:6PB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3(T"FUS9VED(")-
M86EL($%D;6EN(@IM<V=S='(@(D4M36%I;"!!9&UI;FES=')A=&EO;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R("),:6YK(%]A;FQE
M9V5N+BXN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QA=VDB"FUS9W-T<B`B
M36%L87=I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-86QA>7-I82(*;7-G<W1R
M(")-86QA>7-I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS
M9W-T<B`B36%L:61I=F5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86QI(@IM
M<V=S='(@(DUA;&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;'1A(@IM<V=S
M='(@(DUA;'1A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT"FUS9VED
M("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T
M;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@
M=VET:"!T:&]S92!C871E9V]R:65S+B(*;7-G<W1R("(B"B)697)W86QT96X@
M4VEE(&1I92!+871E9V]R:65N+"!M:70@9&5N96X@4VEE($5L96UE;G1E('5N
M9"!%:6YT<N1G92`B"B)K96YN>F5I8VAN96X@:_9N;F5N+"!S;W=I92!D:64@
M>G5G96CV<FEG96X@1F%R8F5N+B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,34V"FUS9VED(")-87`R-"!M87`B"FUS9W-T
M<B`B36%P,C0M2V%R=&4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3`X-PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3$W,0IM<V=I9"`B36%P475E<W0@;6%P(@IM<V=S='(@
M(DUA<%%U97-T+4MA<G1E(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S=&]R960N(@IM<V=S='(@(EIU;W)D
M;G5N9V5N(&=E<W!E:6-H97)T+B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED(")-87)C:"(*;7-G<W1R(")-Y')Z
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT,0IM<V=I9"`B36%R9VEN(@IM<V=S='(@(D%UWV5N86)S=&%N9"(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C0X"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED
M(")-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`B36ET($=E
M;&5S96XM+U5N9V5L97-E;BU3=&%T=7,@=F5R<V5H96XB"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT.0HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H
M(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T
M<B`B36ET(&%N9&5R96T@4W1A='5S('9E<G-E:&5N("AZ+D(N(%=I8VAT:6<O
M0F5A;G=O<G1E="DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA<G-H86QL($ES
M;&%N9',B"FUS9W-T<B`B36%R<VAA;&QI;G-E;&XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$U.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*
M;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B36%R=&EN:7%U92(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")-871C:&EN9R!F
M:65L9',B"FUS9W-T<B`B6G5G96]R9&YE=&4@1F5L9&5R(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDS"FUS9VED(")-875R:71A;FEA(@IM<V=S='(@(DUA=7)E=&%N:65N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDT"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`B36%U<FET
M:75S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S$U"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@
M(DUA>&EM86P@97)L875B=&5R($MR961I="XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@(DUA>"!M
M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G<W1R(")-87AI;6%L92!.86-H
M=&EC:'1E;G1E:6QE(/QB97)S8VAR:71T96XN(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,#@*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*
M;7-G<W1R(")(]F-H<W1T96UP97)A='5R(&1E<B!L971Z=&5N(#(T(%-T=6YD
M96XZ("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`P"FUS9VED(")-87@@
M=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R(")(]F-H<W1T96UP97)A='5R
M(&1E<B!L971Z=&5N(#8@4W1U;F1E;CH@(@H*(SH@;&EB+V%P:2YP:'`Z,3@Q
M"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S
M='(@(DUA>&EM86QE($%N>F%H;"!A;B!0;W)T86QB;/9C:V5N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DX(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R,3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S.0IM<V=I
M9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T<B`B36%X:6UA;&4@3.1N9V4B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#0*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I
M9"`B36%Y(@IM<V=S='(@(DUA:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(DUA
M>6]T=&4B"FUS9W-T<B`B36%Y;W1T92!)<VQA;F0B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3`*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(DUE9&EZ
M:6XB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS
M9VED(")-96UB97)S(@IM<V=S='(@(DUI=&=L:65D97(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S<U"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S='(@
M(DUE;OQM;V1U<SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R
M("):96QL96X@>G5S86UM96YF_&=E;B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4W"FUS9VED(")-97-S86=E
M(@IM<V=S='(@(DYA8VAR:6-H="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,C$V"FUS9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U
M8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD
M(&YO="!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@HB1&EE($YA8VAR:6-H
M="!K;VYN=&4@97)F;VQG<F5I8V@@_&)E<G!R_&9T('=E<F1E;B!A8F5R(&YI
M8VAT(&1A<R!:97)T:69I:V%T("(*(F1E<R!!8G-E;F1E<G,N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"FUS
M9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(DYA8VAR:6-H="!N:6-H
M="!M96AR(&?\;'1I9RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4V.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"FUS9VED(")-97-S86=E
M('1Y<&4B"FUS9W-T<B`B3F%C:')I8VAT96YT>7`B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E871H97(B"FUS9W-T<B`B365T
M87(@5V5T=&5R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B
M365T87(@8FQO8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B365T87)B;&]C
M:R!N:6-H="!V97)F_&=B87(N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M,3D*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I
M;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM
M<V=S='(@(B(*(DUE=&%R8FQO8VL@;FEC:'0@=F5R9OQG8F%R+B!$971A:6QS
M('=U<F1E;B!F_'(@9&5N($%D;6EN:7-T<F%T;W(@;6ET9V5L;V=G="XB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34S"FUS9VED(")-971A
M<D1"(&ES(&YO="!C;VYN96-T960N(@IM<V=S='(@(DME:6YE(%9E<F)I;F1U
M;F<@>G5R($UE=&%R1$(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HV-R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<T"FUS9VED(")-971H;V0B"FUS9W-T<B`B365T:&]D92(*"B,Z(&9R
M86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z.#$@9G)A;65W;W)K+U)00R]2
M4$,O<V]A<"YP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!<
M(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`B1&EE($UE=&AO9&4@7"(E
M<UPB(&ES="!N:6-H="!D969I;FEE<G0B"@HC.B!F<F%M97=O<FLO4E!#+U)0
M0R]R97-T+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@;F]T
M(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S(@IM<V=S='(@(DUE=&AO9&4@
M;FEC:'0@9&5F:6YI97)T+B!!=69G97)U9F5N92!-971H;V1E.B`E<R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-R!L:6(O0FQO8VLO;65T
M87(N<&AP.C@R"FUS9VED(")-971R:6,B"FUS9W-T<B`B365T<FES8V@B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.34*;7-G:60@(DUE>&EC;R(*;7-G<W1R(")-97AI:V\B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E
M<R!O9B(*;7-G<W1R(")&]F1E<FEE<G1E(%-T86%T96X@=F]N($UI:W)O;F5S
M:65N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<V"FUS9VED(")-:61D;&4B"FUS9W-T<B`B36ET=&4B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B
M36EM92!4>7!E(@IM<V=S='(@(DUI;65T>7`B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,Q,@IM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM
M<V=S='(@(E1I969S='1E;7!E<F%T=7(@9&5R(&QE='IT96X@,C0@4W1U;F1E
M;CH@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#0*;7-G:60@(DUI;B!T
M96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(E1I969S='1E;7!E<F%T=7(@
M9&5R(&QE='IT96X@-B!3='5N9&5N.B`B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@
M:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R(")$87,@;6EN:6UA;&4@4&%S
M<W=O<G1A;'1E<B!I<W0@;F]C:"!N:6-H="!A8F=E;&%U9F5N(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-0IM<V=I9"`B
M36ER<F]R(@IM<V=S='(@(E-P:65G96QN(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(E9E<G-C
M:&EE9&5N97,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8W,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS-#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A4
M5%!?4F5Q=65S="XB"FUS9W-T<B`B4$5!4BU086ME="!(5%107U)E<75E<W0@
M9F5H;'0N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q-`IM<V=I9"`B
M(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T
M92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC871I
M;VXN(@IM<V=S='(@(B(*(D9E:&QE;F1E($MO;F9I9W5R871I;VXN(%-I92!M
M_'-S96X@9&EE<V4@:F5T>G0@97)Z975G96XL('=E;FX@4VEE(&1I92`B"B)!
M;G=E;F1U;F<@=F5R=V5N9&5N(&WV8VAT96XN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`T"FUS9VED(")-:7-S
M:6YG(&UE<W-A9V4@240N(@IM<V=S='(@(D9E:&QE;F1E($YA8VAR:6-H=&5N
M+4E$+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY
M7W-M='`N<&AP.C4X"FUS9VED(")-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C
M:V%G92!-86EL+B(*;7-G<W1R(")014%2+5!A:V5T($UA:6P@9F5H;'0N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDT"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM<V=S='(@(D9E:&QE
M;F1E(%-I='IU;F=S+4E$+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(DUO(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C<V"FUS9VED(")-;V)I;&4@36%I
M;"(*;7-G<W1R(")%+4UA:6P@36]B:6PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HW,@IM<V=I9"`B36]D97)A=&4B"FUS9W-T
M<B`B3>3?:6<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C8V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S,*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-0IM<V=I
M9"`B36]D:69I960@1&%T92(*;7-G<W1R("+$;F1E<G5N9W-D871U;2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU,PIM<V=I9"`B36]D:69Y(%523"(*;7-G<W1R(")54DP@8F5A<F)E:71E
M;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<T"FUS
M9VED(")-;V1U;'5S(@IM<V=S='(@(DUO9'5L=7,B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*
M;7-G:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(E)E<'5B;&EK
M($UO;&1A=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]N86-O(@IM<V=S='(@
M(DUO;F%C;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36]N9V]L:6$B"FUS9W-T
M<B`B36]N9V]L96DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C`R
M"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R(")-;VYA="!U;F0@2F%H
M<B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z
M-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`B36]N871L:6-H(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDT"FUS9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(DUO;G1S97)R870B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S='(@(DUO;F1P:&%S96XB"@HC
M.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ.38@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z,C@P"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@
M9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N
M(@IM<V=S='(@(DUE:'(@1F5L9&5R(&EN(%IE:6QE("5D(&%L<R!D:64@97)W
M87)T971E;B`E9"!G969U;F1E;BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO
M<F]C8V\B"FUS9W-T<B`B36%R;VMK;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,U"FUS9VED(")-;W-T;'D@0VQE87(B"FUS
M9W-T<B`BW&)E<G=I96=E;F0@:&5I=&5R(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S8*;7-G:60@(DUO<W1L>2!#;&]U9'DB
M"FUS9W-T<B`BW&)E<G=I96=E;F0@0F5W]FQK="(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")-;W-T;'D@0VQO
M=61Y(&%N9"!7:6YD>2(*;7-G<W1R("+<8F5R=VEE9V5N9"!"97?V;&MT('5N
M9"!7:6YD:6<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS.`IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@(MQB97)W:65G
M96YD(%-O;FYI9R(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z-C0X"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B3F%C
M:"!U;G1E;B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z-C4R"FUS9VED(")-;W9E($QE9G0B"FUS9W-T<B`B3F%C:"!L
M:6YK<R(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z-C4V"FUS9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(DYA8V@@<F5C
M:'1S(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HV-#0*;7-G:60@(DUO=F4@57`B"FUS9W-T<B`B3F%C:"!O8F5N(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-@IM
M<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(DYA8V@@=6YT96XB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(U"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C8*;7-G:60@(DUO
M=F4@=7`B"FUS9W-T<B`B3F%C:"!O8F5N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED
M(")-;WIA;6)I<75E(@IM<V=S='(@(DUO<V%M8FEK(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C(P,@IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D
M;W=N(&QI<W1S(@IM<V=S='(@(D%U<W=A:&QL:7-T92!I;B!M96AR97)E;B!%
M8F5N96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3`U.0IM<V=I9"`B375L=&EM87`@54L@;6%P(@IM<V=S='(@(DUU;'1I
M;6%P+55++4MA<G1E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V
M,`IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@(DUE:')F86-H
M875S=V%H;"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#(*;7-G
M:60@(DUY($%C8V]U;G0B"FUS9W-T<B`B365I;B!+;VYT;R(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HR.`IM<V=I9"`B37D@06-C;W5N="!);F9O<FUA
M=&EO;B(*;7-G<W1R(")-96EN($MO;G1O(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+VEN9&5X+G!H<#HT-`IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(DUE:6X@
M4&]R=&%L(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C0R"FUS9VED
M(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(DUE:6X@4&]R=&%L;&%Y;W5T
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S='(@(D)U<FUA
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ
M-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R(").14E.+"!I
M8V@@<W1I;6UE($Y)0TA4('IU(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$Q(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP
M:'`Z,S@*;7-G:60@(DYA;64B"FUS9W-T<B`B3F%M92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,38Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R(").86UI8FEA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDW"FUS9VED(").875R=2(*;7-G<W1R(").875R=2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B3F5P86PB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*
M;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(DYI961E<FQA;F1E(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3<*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@
M(DYI961E<FSD;F1I<V-H92!!;G1I;&QE;B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P92!"87-E(%52
M3"(*;7-G<W1R(").971S8V%P92U"87-I<RU54DPB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@0T$@
M4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B3F5T<V-A<&4M0T$M4W!E<G)U;F=S
M+5523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V
M"FUS9VED(").971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(DYE='-C
M87!E+4-!+5)I8VAT;&EN:65N+5523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P92!296YE=V%L(%52
M3"(*;7-G<W1R(").971S8V%P92U:971I9FEK871S97)N975E<G5N9W,M55),
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G
M:60@(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@(DYE='-C87!E
M+5-P97)R=6YG<RU54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM
M<V=S='(@(DYE='-C87!E+5-33"U397)V97)N86UE(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#@*;7-G:60@(DYE='-C87!E(&-E
M<G1I9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B3F5T<V-A<&4M2V]M;65N=&%R
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G
M:60@(DYE='-C87!E(&-E<G1I9FEC871E('1Y<&4B"FUS9W-T<B`B3F5T<V-A
M<&4M6F5R=&EF:6MA='1Y<"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR-3,*;7-G:60@(DYE='=O<FLB"FUS9W-T<B`B3F5T>G=E<FLB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,S,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@S"FUS
M9VED(").979E<B(*;7-G<W1R(").:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@
M(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B3F5U:V%L961O;FEE;B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(V"FUS
M9VED(").97<@0V%T96=O<GDB"FUS9W-T<B`B3F5U92!+871E9V]R:64B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X
M(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S
M='(@(DYE=6UO;F0B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R
M(").975E<B!"96YU='IE<FYA;64@*&]P=&EO;F%L*2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M.`IM<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B3F5U<V5E;&%N9"(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-PIM<V=I9"`B3F5W('!A
M<W-W;W)D(@IM<V=S='(@(DYE=65S(%!A<W-W;W)T(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]S<6PN<&AP.C(R-PHC+"!P:'`M9F]R;6%T"FUS9VED(").
M97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@(D1A<R!N
M975E(%!A<W-W;W)D('=I<F0@86T@)7@@86)L875F96XN(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R"FUS9VED(").97<@<&%S<W=O<F1S
M(&1O;B=T(&UA=&-H+B(*;7-G<W1R(")$:64@;F5U96X@4&%S<W?V<G1E<B!S
M=&EM;65N(&YI8VAT(/QB97)E:6XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L
M86YK*2(*;7-G<W1R(").975E<R!&96YS=&5R("A?8FQA;FLI(@H*(SH@;&EB
M+T)L;V-K+V=O;V=L92YP:'`Z-#`@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.3$*;7-G:60@(DYE=W,B
M"FUS9W-T<B`B3F%C:')I8VAT96XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S`W"FUS9VED(").97=S9W)O=7!S(@IM<V=S='(@(DYE=W-G<G5P
M<&5N(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34@=&5M<&QA
M=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHQ,CD@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4*;7-G
M:60@(DYE>'0B"FUS9W-T<B`B5V5I=&5R(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C(W"FUS9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@(D[D8VAS=&4@
M-"!0:&%S96XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V
M-B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W,`IM<V=I9"`B3F5X
M="!O<'1I;VYS(@IM<V=S='(@(D[D8VAS=&4@16EN<W1E;&QU;F=E;B(*"B,Z
M(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z,3`V"FUS9VED(").97AT/B(*
M;7-G<W1R(")796ET97(^(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6-A<F%G
M=6$B"FUS9W-T<B`B3FEC87)A9W5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").
M:6=E<B(*;7-G<W1R(").:6=E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG
M97)I82(*;7-G<W1R(").:6=E<FEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,V.0IM<V=I9"`B3FEG:'0B"FUS9W-T<B`B3F%C:'1S(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-SD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDW"FUS9VED(").:75E(@IM<V=S='(@(DYI=64B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38V"FUS9VED
M(").;R(*;7-G<W1R(").96EN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P
M+V1I9F8N:'1M;#HY"FUS9VED(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO
M;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*;7-G<W1R(")+96EN
M92!+;VYF:6=U<F%T:6]N<V1A=&5N('9E<F;\9V)A<BP@=6T@56YT97)S8VAI
M961E(&%N>G5Z96EG96XN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+G!H<#HQ,#8*;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G
M>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@(DME:6YE(%-T<F%T
M96=I92!Z=6T@17)S=&5L;&5N('9O;B!)4T\M06)B:6QD97)N('9E<F;\9V)A
M<BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R(")+
M96EN92!"871C:"U6;W)L86=E+B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70O36%N86=E<BYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z,S@U"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-#`W"FUS9VED(").;R!B;&]C
M:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R(")%
M<R!E>&ES=&EE<G0@:V5I;B!";&]C:R!A;B!D97(@86YG96=E8F5N96X@4&]S
M:71I;VXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C4P"FUS
M9VED(").;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R(")+96EN($MA;&5N9&5R;F%M92!F_'(@9&EE
M($U#04PM075T:&5N=&EF:7II97)U;F<@86YG96=E8F5N+B(*"B,Z(&%D;6EN
M+W-E='5P+V1I9F8N<&AP.C4Q"FUS9VED(").;R!C:&%N9V4N(@IM<V=S='(@
M(DME:6YE(,1N9&5R=6YG96XN(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HQ-38*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T
M;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*(E5N=&5R:&%L8B!D:65S
M97(@16)E;F4@:_9N;F5N(&ME:6YE('=E:71E<F5N(%5N=&5R<F5C:'1E(&AI
M;GIU9V5F_&=T('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C$W."!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,0HC.B!F<F%M
M97=O<FLO571I;"]5=&EL+G!H<#HW.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S
M+B(*;7-G<W1R(")&_'(@)7,@=W5R9&5N(&ME:6YE($MO;F9I9W5R871I;VYS
M:6YF;W)M871I;VYE;B!A;F=E9V5B96XN(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HX-C<*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R("(B"B)&_'(@
M9&5N($944"U61E,M5')E:6)E<B!W=7)D96X@:V5I;F4@2V]N9FEG=7)A=&EO
M;G-I;F9O<FUA=&EO;F5N(&%N9V5G96)E;BXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C<R-PIM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S='(@(B(*(D;\
M<B!D96X@4U%,+59&4RU4<F5I8F5R('=U<F1E;B!K96EN92!+;VYF:6=U<F%T
M:6]N<VEN9F]R;6%T:6]N96X@86YG96=E8F5N+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HW-S(*;7-G:60@(DYO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM
M<V=S='(@(B(*(D;\<B!D96X@4U%,+41A=&5I+59&4RU4<F5I8F5R('=U<F1E
M;B!K96EN92!+;VYF:6=U<F%T:6]N<VEN9F]R;6%T:6]N96X@(@HB86YG96=E
M8F5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(DME
M:6X@2W)E9&ET(&UE:'(@_&)R:6<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S0*;7-G:60@(DYO(&1E<W1I;F%T
M:6]N('-U<'!L:65D+B(*;7-G<W1R(")+96EN($5M<&;D;F=E<B!A;F=E9V5B
M96XN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3$X"FUS
M9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(DME:6YE($1A=&5I(&AO
M8VAG96QA9&5N(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q"FUS9VED
M(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`B2V5I;F4@26-O;G,@9V5F=6YD
M96XN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q-B!L:6(O
M0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M,S`*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B17,@=W5R
M9&4@:V5I;B!/<G0@9F5S=&=E;&5G="XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,34W"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E9"XB
M"FUS9W-T<B`B2V5I;B!/<G0@86YG96=E8F5N+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").;R!M
M97-S86=E('-U<'!L:65D+B(*;7-G<W1R(")+96EN92!.86-H<FEC:'0@86YG
M96=E8F5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,V"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T
M<B`B2V5I;B!.86UE(&%N9V5G96)E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PIM<V=I9"`B3F\@;G5M8F5R
M('-P96-I9FEE9"XB"FUS9W-T<B`B2V5I;F4@3G5M;65R(&%N9V5G96)E;BXB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*;7-G:60@(DYO(&]F9F5N
M<VEV92!F;W)T=6YE<R(*;7-G<W1R(")+96EN92!A;G-T]M]I9V5N($=L_&-K
M<VME:W-E(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HY,0IM
M<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(DME:6X@4&%S<W=O<G0@9OQR(&1I92!(5%10+4%U
M=&AE;G1I9FEZ:65R=6YG(&%N9V5G96)E;BXB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VEM87`N<&AP.C$P,`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($E-05`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DME:6X@4&%S
M<W=O<G0@9OQR(&1I92!)34%0+4%U=&AE;G1I9FEZ:65R=6YG(&%N9V5G96)E
M;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C<R"FUS9VED
M(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(DME:6X@4&%S<W=O<G0@9OQR(&1I92!+97)B97)O
M<RU!=71H96YT:69I>FEE<G5N9R!A;F=E9V5B96XN(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]S87-L+G!H<#HW-R!F<F%M97=O<FLO075T:"]!=71H+VQO
M9VEN+G!H<#HX-`HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-S4*
M;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B2V5I;B!087-S=V]R="!F_'(@9&EE($QO9VEN
M+4%U=&AE;G1I9FEZ:65R=6YG(&%N9V5G96)E;BXB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W!A<W-W9"YP:'`Z,3,U"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")+
M96EN(%!A<W-W;W)T(&;\<B!D:64@4$%34U=$+4%U=&AE;G1I9FEZ:65R=6YG
M(&%N9V5G96)E;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z
M.#0*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(DME:6X@4&%S<W=O<G0@9OQR(&1I92!334(M
M075T:&5N=&EF:7II97)U;F<@86YG96=E8F5N+B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X-PIM<V=I9"`B(@HB3F\@<&%T:"!T
M;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I
M;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T
M82XB"FUS9W-T<B`B(@HB2V5I;B!09F%D('IU;2!/<&5N4U-,+5!R;V=R86UM
M(&%N9V5G96)E;BX@1&%S($]P96Y34TPM4')O9W)A;6T@=VER9"`B"B)B96[V
M=&EG="P@=6T@4$M#4RTQ,BU$871E;B!V97)A<F)E:71E;B!Z=2!K]FYN96XN
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I
M9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R(")+96EN92!A=7-S=&5H
M96YD96X@4F5G:7-T<FEE<G5N9V5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HW-3,*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B2V5I;B!3
M<&5I8VAE<G!L871Z+4MO;G1I;F=E;G0@9F5S=&=E;&5G="XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0S"FUS
M9VED(").;R!R=6QE<R(*;7-G<W1R(")+96EN92!286AM96XB"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT.#(*;7-G:60@(DYO('-E<&%R871O
M<B!S<&5C:69I960N(@IM<V=S='(@(DME:6X@5')E;FYZ96EC:&5N(&%N9V5G
M96)E;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0T"FUS9VED(").;R!S:61E<R(*;7-G<W1R(")+96EN92!3
M96ET96XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C8P.0IM<V=I
M9"`B3F\@<W5C:"!F:6QE(@IM<V=S='(@(D1A=&5I(&YI8VAT(&=E9G5N9&5N
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$R-@IM<V=I9"`B
M3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+B(*
M;7-G<W1R(")+96EN92!T96UP;W+D<F5S(%9E<GIE:6-H;FES(&;\<B!D96X@
M0V%C:&4@9V5F=6YD96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HR,C$*;7-G:60@(DYO('5S97)N86UE(&%N9"]O<B!P
M87-S=V]R9"!S96YT+B(*;7-G<W1R(")+96EN($)E;G5T>F5R;F%M92!U;F0O
M;V1E<B!087-S=V]R="!A;F=E8F5N+B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#
M+WAM;')P8RYP:'`Z,30V"FUS9VED(").;R!V86QI9"!834P@9&%T82!R971U
M<FYE9"(*;7-G<W1R(")%<R!W=7)D96X@:V5I;F4@9_QL=&EG96X@6$U,+41A
M=&5N('IU<OQC:V=E9V5B96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.3<T"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HY.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.CDY-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3`Q,@IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(DME
M:6YE(%=E<G1E(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q.0IM<V=I
M9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N
M+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(DME:6YE
M(%9E<G-I;VYS;G5M;65R(&EN(&1E<B!/<FEG:6YA;&MO;F9I9W5R871I;VX@
M9V5F=6YD96XN($5R;F5U97)N(%-I92`B"B)):')E($MO;F9I9W5R871I;VXN
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R-PIM<V=I9"`B3F\@=F5R
M<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB2V5I;F4@5F5R<VEO;G-N=6UM
M97(@:6X@26AR97(@2V]N9FEG=7)A=&EO;B!G969U;F1E;BX@17)N975E<FX@
M4VEE($EH<F4@(@HB2V]N9FEG=7)A=&EO;BXB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E9G,O
M:61E;G1I='ES96QE8W0N:6YC.CDU"FUS9VED(").;VYE(@IM<V=S='(@(DME
M:6YE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R(")+96EN
M<R`H4W1A;F1A<F0@8F5N=71Z96XI(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.3(*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(DYO
M<F1I<V-H("A)4T\M.#@U.2TQ,"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYO
M<F9O;&L@27-L86YD(@IM<V=S='(@(DYO<F9O;&MI;G-E;"(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@
M(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B3O9R9&QI8VAE($AE;6ES
M<&AE<F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N($UA<FEA;F$@
M27-L86YD<R(*;7-G<W1R(").]G)D;&EC:&4@36%R:6%N96XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3<*;7-G:60@(DYO<G=A>2(*;7-G<W1R(").;W)W96=E;B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0Q"FUS9VED(").;W0@
M069T97(B"FUS9W-T<B`B1_QL=&EG(&)I<R(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C0P"FUS9VED(").;W0@0F5F;W)E(@IM<V=S
M='(@(D?\;'1I9R!A8B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C0R-`IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@(DME:6X@5F5R
M>F5I8VAN:7,B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L
M+G!H<#HS-#@*;7-G:60@(DYO="!F;W5N9"XB"FUS9W-T<B`B3FEC:'0@9V5F
M=6YD96XN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+G!H<#HV,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX-`HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-0HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*;7-G:60@(DYO="!I
M;7!L96UE;G1E9"XB"FUS9W-T<B`B3FEC:'0@:6UP;&5M96YT:65R="XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8X"FUS
M9VED(").;W0@<V5T(@IM<V=S='(@(DYI8VAT(&9E<W1G96QE9W0B"@HC.B!F
M<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$T
M.`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N
M<&AP.C$V,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA
M;F1L97(N<&AP.C$W.`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S
M<VEO;DAA;F1L97(N<&AP.C$Y,@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L
M97(O4V5S<VEO;DAA;F1L97(N<&AP.C(S-R!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,3DS"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,SD@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C(V-0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C@S
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,#`*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C,Q-B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S,R"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HS-#<@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,V
M-`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,SDW(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HT-3<*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4S-B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z-C`U"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HV,C(*;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(DYI8VAT('5N
M=&5R<W3\='IT+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,T
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0*(SH@
M8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-C@@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$X,`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B3F]T:7IE;B(*"B,Z
M('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN
M9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(DYI8VAT<R!A;GIU>F5I
M9V5N+"!B:71T92!Z=7+\8VMG96AE;BXB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS9W-T
M<B`B3F]V96UB97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#0V
M"FUS9VED(").=6UB97(B"FUS9W-T<B`B6F%H;"(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T,C4*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S
M(@IM<V=S='(@(D%N>F%H;"!D97(@6F5I8VAE;B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$S-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R
M,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0U('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB97(@
M;V8@8V]L=6UN<R(*;7-G<W1R(")!;GIA:&P@9&5R(%-P86QT96XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8W(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,R!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@IM<V=I
M9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`B06YZ86AL(&1E<B!:96EL96XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8T-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN
M9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B2V5I;F4@3G5M;65R
M;B!F_'(@9&EE(%9E<G1E:6QE<FQI<W1E(&%N9V5G96)E;BXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+
M(@IM<V=S='(@(D]+(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C@W,PIM<V=I9"`B3V)J96-T(@IM<V=S='(@(D]B:F5K="(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$R"FUS9VED(")/8FIE
M8W0@0W)E871O<B(*;7-G<W1R(")/8FIE:W1E<G-T96QL97(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`T"FUS9VED(")/8W1A;"(*;7-G<W1R
M(")/:W1A;'IA:&PB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#$Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R(")/:W1O8F5R(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I
M;'1E<B(*;7-G<W1R(")&:6QT97(@9OQR(&%N<W3VWVEG92!);FAA;'1E(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R.`IM<V=I9"`B3V9F:6-E
M(@IM<V=S='(@(D+\<F\B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I
M9F9E<F5N="XB"FUS9W-T<B`B26AR(&YE=65S(%!A<W-W;W)T(&UU<W,@<VEC
M:"!V;VX@26AR96T@86QT96X@=6YT97)S8VAE:61E;BXB"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*;7-G:60@(D]L9"!P87-S=V]R9"(*
M;7-G<W1R(")!;'1E<R!087-S=V]R="(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HT-@IM<V=I9"`B3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R
M96-T+B(*;7-G<W1R(")&86QS8VAE<R!A;'1E<R!087-S=V]R="XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T<B`B3VUA;B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X,C8*;7-G:60@(D]N8VQI8VL@979E;G0B
M"FUS9W-T<B`B3VYC;&EC:RU%=F5N="(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R
M<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+B(*;7-G<W1R(").=7(@24U!4"U3
M97)V97(@=6YT97)S=/QT>F5N(&=E;65I;G-A;64@3W)D;F5R+B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@
M9F]R='5N97,B"FUS9W-T<B`B3G5R(&%N<W3VWVEG92!';/QC:W-K96MS92(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-CD@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3DX.0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@861D<F5S
M<R!A;&QO=V5D+B(*;7-G<W1R(").=7(@96EN92!%+4UA:6PM061R97-S92!E
M<FQA=6)T+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I
M9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@
M;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@
M9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@HB3G5R(&1E<B!"97-I='IE<B!O9&5R
M(&1E<B!3>7-T96UA9&UI;FES=')A=&]R(&MA;FX@9&5N($)E<VET>F5R(&]D
M97(@9&EE("(*(D)E<VET>F5R<F5C:'1E(.1N9&5R;B(*"B,Z(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C0Q(&QI8B]";&]C:R]I9G)A;64N<&AP.C0R"FUS9VED
M(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("));B!N975E;2!&96YS
M=&5R(/9F9FYE;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C
M="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*;7-G<W1R("(B"B)/
M<&5N4U-,+49E:&QE<CH@4VEG;FEE<G1E(%,O34E-12U$871E;B!K;VYN=&5N
M(&YI8VAT(&5X=')A:&EE<G0@=V5R9&5N+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E
M;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")$:65S96X@
M3&EN:R!I;B!E:6YE;2!N975E;2!&96YS=&5R(/9F9FYE;B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*
M;7-G<W1R(")"971R:65B<WES=&5M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I
M9&5B87(N<&AP.C$U-0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")%:6YS=&5L
M;'5N9V5N(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C,Q('1E;7!L871E<R]P
M<F5F<R]A<'`N:6YC.C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@
M9F]R("5S(@IM<V=S='(@(D5I;G-T96QL=6YG96X@9OQR("5S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B
M3W)D97)E9"!,:7-T(@IM<V=S='(@(DYU;6UE<FEE<G1E($QI<W1E(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R
M9V%N:7-A=&EO;B(*;7-G<W1R(")/<F=A;FES871I;VXB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I9"`B3W)G86YI<V%T
M:6]N86P@56YI="(*;7-G<W1R(")/<F=A;FES871I;VYS86)T96EL=6YG(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S-`IM<V=I9"`B3W)G86YI
M>FEN9R(*;7-G<W1R(")/<F=A;FES:65R96XB"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA
M=&4B"FUS9W-T<B`B3W)I9VEN86QV;W)L86=E(&1E<B!!;G=E;F1U;F<B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(D]R:6=I;F%L
M=F]R;&%G92!I;B`E<SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$Y('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B
M"FUS9W-T<B`B4V]N<W1I9V4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3D@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.0HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3$V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C4*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$S-`IM<V=I9"`B3W1H97(@26YF;W)M871I
M;VXB"FUS9W-T<B`B06YD97)E($EN9F]R;6%T:6]N96XB"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C,R"FUS9VED(")/=VYE<B!097)M:7-S:6]N
M<R(*;7-G<W1R(")"97-I='IE<G)E8VAT92(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<&%M+G!H<#HW.0IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES
M(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(E!!32U!=71H96YT:69I>FEE<G5N
M9R!I<W0@;FEC:'0@=F5R9OQG8F%R+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B
M86-K96YD(@IM<V=S='(@(E!%05(Z.DUA:6PM0F%C:V5N9"(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$R.#4*;7-G:60@(E!'4"!$:6=I
M=&%L(%-I9VYA='5R92(*;7-G<W1R(")$:6=I=&%L92!01U`M56YT97)S8VAR
M:69T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,S,0IM
M<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S='(@(E!'4"UV97)S8VAL
M_'-S96QT92!$871E;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$S.#,*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(M9F9F5N
M=&QI8VAE<B!01U`M4V-H;/QS<V5L(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3,V-0IM<V=I9"`B4$=0(%-I9VYE9"]%;F-R>7!T960@
M1&%T82(*;7-G<W1R(")-:70@4$=0('5N=&5R>F5I8VAN971E+W9E<G-C:&S\
M<W-E;'1E($1A=&5N(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8Y"FUS9VED
M(")02%`@0V]D92(*;7-G<W1R(")02%`@0V]D92(*"B,Z(&%D;6EN+W!H<'-H
M96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(E!(4"!3:&5L
M;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P
M"FUS9VED(")032!,:6=H="!286EN(@IM<V=S='(@(E9O<FUI='1A9W,@;&5I
M8VAT97(@4F5G96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT,0IM<V=I9"`B4$T@4F%I;B(*;7-G<W1R(").86-H;6ET=&%G
M<R!296=E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0R"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@(DYA8VAM:71T86=S
M(%-C:&%U97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT,PIM<V=I9"`B4$T@4VYO=R(*;7-G<W1R(").86-H;6ET=&%G<R!3
M8VAN964B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT-`IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(DYA8VAM:71T
M86=S(%-C:&YE97-C:&%U97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT-0IM<V=I9"`B4$T@4W5N(@IM<V=S='(@(DYA8VAM
M:71T86=S(%-O;FYE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#8*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(DYA8VAM
M:71T86=S($=E=VET=&5R(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X
M-@IM<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T<B`B
M1&EE(%!/4TE8+45R=V5I=&5R=6YG(&9E:&QT(@H*(SH@;&EB+V%P:2YP:'`Z
M,C$U"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@(E]02%`@4VAE;&PB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0V"FUS9VED(")0861D:6YG(@IM<V=S='(@(DEN;F5N86)S=&%N9"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY.0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`B4&%K:7-T86XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QA=2(*;7-G<W1R(")086QA=2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DR(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@
M3V-C=7!I960B"FUS9W-T<B`B0F5S971Z=&4@4&%LY'-T:6YE;G-I<V-H92!'
M96)I971E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")086YA;6$B"FUS9W-T<B`B
M4&%N86UA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")087!U82!.97<@1W5I;F5A
M(@IM<V=S='(@(E!A<'5A+4YE=6=U:6YE82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G
M:60@(E!A<F%G=6%Y(@IM<V=S='(@(E!A<F%G=6%Y(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,SD*;7-G:60@(E!A<G1L>2!#
M;&]U9'DB"FUS9W-T<B`B5&5I;'=E:7-E($)E=_9L:W0B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#,V"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT
M,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(U"FUS9VED(")087-S
M=V]R9"(*;7-G<W1R(")087-S=V]R="(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S
M9G5L;'DN(@IM<V=S='(@(E!A<W-W;W)T(&5R9F]L9W)E:6-H(&=EY&YD97)T
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3,R,PIM
M<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(D9A;'-C:&5S(%!A
M<W-W;W)T(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$U
M,@IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B2V5I;B!087-S=V]R="!F_'(@9&EE(%)!1$E5
M4RU!=71H96YT:69I>FEE<G5N9R!A;F=E9V5B96XN(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C`W,0IM<V=I9"`B4&%S<W=O<F0@=VET:"!C;VYF
M:7)M871I;VXB"FUS9W-T<B`B4&%S<W=O<G0@;6ET($)E<W3D=&EG=6YG(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP"FUS9VED(")087-S
M=V]R9#HB"FUS9W-T<B`B4&%S<W=O<G0Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VUO8FEL92YI;F,Z,3$*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`B4&%S
M<W=O<G0Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,#4R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G<W1R
M(")$:64@4&%S<W?V<G1E<B!M_'-S96X@9VQE:6-H('-E:6XN(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C$R,"!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G:60@(E!A<W1E(@IM<V=S='(@
M(D5I;F;\9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T
M<B`B5F]N(&1E<B!:=VES8VAE;F%B;&%G92!E:6YF_&=E;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A
M=&@B"FUS9W-T<B`B4&9A9"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D
M+FEN8SHW"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(D%U<W-T
M96AE;F1E(%)E9VES=')I97)U;F=E;CHB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-30*;7-G:60@(E!E;W!L92(*;7-G<W1R(")097)S;VYE;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS
M9VED(")097)C96YT(@IM<V=S='(@(E!R;WIE;G0B"@HC.B!T96UP;&%T97,O
M;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0IM<V=I9"`B4&5R9F]R
M;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@(E=A<G1U;F=S87)B
M96ET96X@9'5R8VAF_&AR96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#`S"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@
M;&]G:6X_(@IM<V=S='(@(E=A<G1U;F=S87)B96ET96X@;F%C:"!D97(@06YM
M96QD=6YG(&1U<F-H9OQH<F5N/R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,34V"FUS9VED(")097)M:7-S:6]N(@IM<V=S='(@(E)E8VAT
M92(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T960N(@IM<V=S
M='(@(E)E8VAT(%PB)7-<(B!W=7)D92!N:6-H="!G96SV<V-H="XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C8Q,@IM<V=I9"`B4&5R;6ES<VEO
M;B!$96YI960B"FUS9W-T<B`B6G5G<FEF9B!V97)W96EG97)T(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C$@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ-C0*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@
M(E)E8VAT92(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P.2!A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`Z-C`*(SH@861M:6XO<&5R;7,O:6YD97@N<&AP
M.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3@*;7-G:60@(E!E<FUI<W-I
M;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E)E8VAT979E<G=A;'1U;F<B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@*;7-G:60@(E!E<G-O;F%L
M($EN9F]R;6%T:6]N(@IM<V=S='(@(E!E<G/V;FQI8VAE($%N9V%B96XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B4&5R=2(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU-0IM<V=I9"`B4&5T<R(*;7-G<W1R(")(
M875S=&EE<F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!H:6QI<'!I;F5S(@IM
M<V=S='(@(E!H:6QI<'!I;F5N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B4&AO;F4B"FUS9W-T<B`B5&5L
M969O;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#`*;7-G:60@
M(E!H;W1O<R(*;7-G<W1R(")&;W1O<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@
M(E!I=&-A:7)N(@IM<V=S='(@(E!I=&-A:7)N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*
M;7-G<W1R(")0:7AE;"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM
M<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R(")0;&%T=&AE:71E;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*
M;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R(")"
M:71T92!K;&EC:V5N(%-I92!I;B!E:6YE(%IE;&QE(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED
M(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES
M(&5L96UE;G0Z(@IM<V=S='(@(D)I='1E(&)E<W3D=&EG96X@4VEE+"!D87-S
M(%-I92!D:65S97,@16QE;65N="!L]G-C:&5N(&WV8VAT96XZ(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4V
M"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN
M:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(B(*(D)I='1E(&)E=.1T:6=E;B!3
M:64L(&1A<W,@4VEE(&1E;B!,:6YK('9O;B!D:65S96T@16QE;65N="!E;G1F
M97)N96X@;?9C:'1E;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-3@P"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+B(*
M;7-G<W1R(")":71T92!E:6YE;B!-;VYA="!U;F0@96EN($IA:'(@86YG96)E
M;BXB"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHQ,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C
M871E9V]R>3HB"FUS9W-T<B`B0FET=&4@9V5B96X@4VEE(&5I;F5N($YA;65N
M(&;\<B!D:64@;F5U92!+871E9V]R:64@86XZ(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3,P,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@
M25`@861D<F5S<RXB"FUS9W-T<B`B0FET=&4@96EN92!G_&QT:6=E($E0+4%D
M<F5S<V4@96EN9V5B96XN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C8U.`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@
M=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B(@HB
M0FET=&4@9V5B96X@4VEE(&5I;B!G_&QT:6=E<R!$871U;2!A;CL@_&)E<G!R
M_&9E;B!3:64@9&EE(%IA:&P@9&5R(%1A9V4@:6X@(@HB9&5M($UO;F%T+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-C4*;7-G:60@(E!L96%S
M92!E;G1E<B!A('9A;&ED('1I;64N(@IM<V=S='(@(D)I='1E(&5I;F5N(&?\
M;'1I9V5N(%IE:71W97)T(&5I;F=E8F5N+B(*"B,Z('1E;7!L871E<R]P<F]B
M;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@(E!L96%S92!P<F]V:61E(&$@<W5M
M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS9W-T<B`B0FET=&4@9V5B96X@4VEE
M(&5I;F4@6G5S86UM96YF87-S=6YG($EH<F5S(%!R;V)L96US(&%N+B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R
M;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B0FET=&4@9V5B96X@4VEE($EH
M<F5N($)E;G5T>F5R;F%M96X@=6YD($EH<B!087-S=V]R="!A;B(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B(@HB4&QE87-E(')E
M860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H
M92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B(@HB0FET
M=&4@;&5S96X@4VEE('-I8V@@9&5N(&9O;&=E;F1E;B!497AT('-O<F=FY&QT
M:6<@9'5R8V@N(%-I92!-W%-314X@9&EE<V5N("(*(D)E9&EN9W5N9V5N('IU
M<W1I;6UE;BP@=V5N;B!3:64@9&EE<V5S(%-Y<W1E;2!B96YU='IE;B!M]F-H
M=&5N+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G
M97(N<&AP.C<P"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y
M(&YA;64Z(@IM<V=S='(@(D)I='1E(&1E;B!N975E;B!+871E9V]R:65N86UE
M;B!E:6YG96)E;CHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!O;&%N9"(*;7-G
M<W1R(")0;VQE;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-PIM<V=I
M9"`B4&]L:71I8W,B"FUS9W-T<B`B4&]L:71I:R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT.#D*;7-G:60@(E!O;&QS(@IM<V=S='(@(E5M9G)A
M9V5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B
M4&]R='5G86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$R-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H
M:7,@:6UA9V4B"FUS9W-T<B`B4&]S:71I;VYI97)U;F<@9&EE<V4@0FEL9&5S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`B
M4&]S:71I;VYI97)U;F<@9&EE<V5R(%1A8F5L;&4B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,0HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES
M(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(E-E;F1E
M;B!A;B!D:65S96X@3W)D;F5R("AN:6-H="!D=7)C:"!)34%0*2(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C8X(&QI8B]";&]C:R]M971A<BYP:'`Z,C<S
M"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R(&QA<W0@
M)7,@:&]U<BAS*3H@(@IM<V=S='(@(DYI961E<G-C:&QA9R!I;B!D96X@;&5T
M>G1E;B`E<R!3='5N9&4H;BDZ("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR.#<*;7-G:60@(E!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4B
M"FUS9W-T<B`B3FEE9&5R<V-H;&%G<RT\8G(@+SYW86AR<V-H96EN;&EC:&ME
M:70B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O;&1A<"YP:'`Z,3`T"FUS
M9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(E!R969S7VQD87`Z($1I92!B96[V=&EG=&4@3$1!
M4"U%<G=E:71E<G5N9R!W=7)D92!N:6-H="!G969U;F1E;BXB"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@(E!R969S
M7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B4')E9G-?<V5S<VEO;CH@1&EE(&)E;O9T:6=T92!397-S
M:6]N+45R=V5I=&5R=6YG('=U<F1E(&YI8VAT(&=E9G5N9&5N+B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C(W"FUS9VED(")0<F5S<W5R92(*;7-G<W1R
M("),=69T9')U8VLB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V,0IM<V=I
M9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B3'5F=&1R=6-K
M(&%U9B!3965H]FAE.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C(T"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@(DQU9G1D<G5C:SH@
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P
M,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R
M,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C,*;7-G:60@(E!R979I97<B"FUS9W-T<B`B5F]R<V-H874B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R
M,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C0*;7-G:60@(E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W
M('=I;F1O=R(*;7-G<W1R(")%:6YE(%9O<G-C:&%U(&1E<R!":6QD97,@:6X@
M96EN96T@;F5U96T@1F5N<W1E<B!A;GIE:6=E;B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,S4V(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,S8P"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S='(@(E9O
M:&5R:6=E($5I;G-T96QL=6YG96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*
M;7-G<W1R(")$;VMU;65N="!D<G5C:V5N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0<FEV871E($ME>2(*;7-G<W1R
M(")0<FEV871E<B!38VAL_'-S96PB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O365N=2YP:'`Z,38Y"FUS9VED(")0<F]B;&5M(@IM<V=S='(@(E!R;V)L
M96UE(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3(W"FUS9VED(")0<F]B
M;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@(E!R;V)L96UB97-C:')E:6)U;F<B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<Q"FUS9VED(")0<F]J
M96-T<R(*;7-G<W1R(")0<F]J96MT92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q,CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(P-@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,CDT"FUS9VED(")0<F]M<'0@=&5X
M="(*;7-G<W1R(").86-H9G)A9V5T97AT(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@
M(M9F9F5N=&QI8VAE<B!38VAL_'-S96PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8T-@IM<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET
M:&TB"FUS9W-T<B`B06QG;W)I=&AM=7,@9&5S(/9F9F5N=&QI8VAE;B!38VAL
M_'-S96QS(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M-#4*;7-G:60@(E!U8FQI8R!+97D@26YF;R(*;7-G<W1R("));F9O<FUA=&EO
M;F5N('IU;2#V9F9E;G1L:6-H96X@4V-H;/QS<V5L(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I=F%T
M92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R
M(")$87,@]F9F96YT;&EC:&4O<')I=F%T92!38VAL_'-S96QP86%R(&MO;FYT
M92!N:6-H="!E<G-T96QL="!W97)D96XN(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I
M9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B4'5E<G1O(%)I8V\B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU-0IM<V=I9"`B4'5R
M9V4@;65S<V%G97,B"FUS9W-T<B`B3F%C:')I8VAT96X@96YD9_QL=&EG(&SV
M<V-H96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")1871A<B(*;7-G<W1R(")+
M871A<B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HV-`IM<V=I9"`B475E<GDB
M"FUS9W-T<B`B06)F<F%G92(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX
M,`IM<V=I9"`B475O=&$B"FUS9W-T<B`B4W!E:6-H97)P;&%T>BU+;VYT:6YG
M96YT(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB
M"FUS9W-T<B`BUF9F96YT;&EC:&5R(%)302!38VAL_'-S96P@*"5D($)I="DB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C@R"FUS9VED(")2861I
M;R!S96QE8W1I;VXB"FUS9W-T<B`B075S=V%H;&MN;W!F(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A:6XB
M"FUS9W-T<B`B4F5G96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R(")&<OQH
M(%)E9V5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#D*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R(")3<.1T97(@4F5G96XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM
M<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B4F5G96YS8VAA=65R(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@
M(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B4V-H;F5E<F5G96XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4F%I
M;B!T;R!3;F]W(@IM<V=S='(@(E)E9V5N(&EN(%-C:&YE92#\8F5R9V5H96YD
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A;F1O;2!&
M;W)T=6YE(@IM<V=S='(@(D=L_&-K<VME:W,B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO(@IM<V=S='(@(E9E<FCD
M;'1N:7,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-2!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X
M,0IM<V=I9"`B4F5A9"(*;7-G<W1R("),97-E;B(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C0W"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W"FUS9VED(")296%D(&UE<W-A9V5S
M(@IM<V=S='(@(DYA8VAR:6-H=&5N(&QE<V5N(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E
M86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O
M;F4N(@IM<V=S='(@(B(*(B5S('=I<FML:6-H(&SV<V-H96X_($1I97-E<B!6
M;W)G86YG(&MA;FX@;FEC:'0@<OQC:V?D;F=I9R!G96UA8VAT('=E<F1E;BXB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E
M<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T
M<B`B(@HB1&%T96X@9&5S($)E;G5T>F5R<R`E<R!W:7)K;&EC:"!L]G-C:&5N
M/R!$:65S97(@5F]R9V%N9R!K86YN(&YI8VAT("(*(G+\8VMGY&YG:6<@9V5M
M86-H="!W97)D96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS-`IM<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB
M"FUS9W-T<B`B1OQH<G0@;&5T>G1E($%K=&EO;B!E<FYE=70@875S(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30T('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(Q,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-#@*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B06MT=6%L:7-I97)E(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X.`IM<V=I9"`B4F5F<F5S:"!$
M>6YA;6EC($UE;G4@16QE;65N=',Z(@IM<V=S='(@(D1Y;F%M:7-C:&4@365N
M_&5L96UE;G1E(&%K='5A;&ES:65R96XZ(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,S.`IM<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB"FUS9W-T
M<B`B4&]R=&%L86YS:6-H="!A:W1U86QI<VEE<F5N.B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C@Y-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C$S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S4*;7-G:60@(E)E
M9V5X(@IM<V=S='(@(E)E9W5LY')E<B!!=7-D<G5C:R(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,R-#D*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W
M<V5R(@IM<V=S='(@(E9E<F)I;F1U;F=S+4)R;W=S97(B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#0@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C$P"FUS9VED(")296QO860B"FUS9W-T<B`B06MT=6%L:7-I97)E
M;B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(X"FUS9VED(")296UA<FMS
M(@IM<V=S='(@(D)E;65R:W5N9V5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q-PIM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B16YT9F5R
M;G1E(%-E<G9E<B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX
M-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H
M;W)D92DZ(@IM<V=S='(@(E-E<G9E<F%D<F5S<V4@*&AT='`Z+R]W=W<N97AA
M;7!L92YC;VTO:&]R9&4I.B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M961I="YI;F,Z,C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z
M,C@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ
M,PIM<V=I9"`B4F5M;W9E(@IM<V=S='(@(D5N=&9E<FYE;B(*"B,Z('1E;7!L
M871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,0IM<V=I9"`B4F5M;W9E($)L;V-K
M(@IM<V=S='(@(D)L;V-K(&SV<V-H96XB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34Y"FUS9VED(")296UO=F4@8V]L=6UN
M(@IM<V=S='(@(E-P86QT92!L]G-C:&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`IM<V=I9"`B4F5M;W9E(&9O<FUA
M='1I;F<B"FUS9W-T<B`B1F]R;6%T:65R=6YG(&5N=&9E<FYE;B(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(X"FUS9VED(")296UO=F4@<&%I
M<B(*;7-G<W1R(")086%R(&SV<V-H96XB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,C`Q"FUS9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R
M=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B1V5S<&5I8VAE
M<G1E<R!3:W)I<'0@875S(&1E;2!T96UP;W+D<F5N(%9E<GIE:6-H;FES(&5N
M=&9E<FYE;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#(*;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T<B`B
M16YT9F5R;F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O
M;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`B1&EE<V5S($5L96UE;G0@875S(&1E
M;2!$;VMU;65N="!E;G1F97)N96XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F4N:6YC.C$Q"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R(")"
M96YU='IE<B!L]G-C:&5N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R.B`E
M<R(*;7-G<W1R(")"96YU='IE<B!L]G-C:&5N.B`E<R(*"B,Z(&9R86UE=V]R
M:R]24$,O4E!#+WAM;')P8RYP:'`Z,30T"FUS9VED(")297%U97-T(&-O=6QD
M;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R
M(")!;F9R86=E(&MO;FYT92!N:6-H="!B96%N='=O<G1E="!W97)D96XN(%IU
M<OQC:V=E9V5B96YE<B!&96AL97)C;V1E.B`B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,30U"FUS9VED(")297%U97-T960@<V5R=FEC92!C
M;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@(D1E<B!G97?\;G-C:'1E($1I
M96YS="!K;VYN=&4@;FEC:'0@9V5F=6YD96X@=V5R9&5N+B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,3@U(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z-3(Q"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<
M(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(EPB)7-<(B!W=7)D92!I;B!D97(@2V]N9FEG=7)A=&EO;B!F_'(@)7,@;FEC
M:'0@86YG96=E8F5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M-S,S(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#<S"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW-S@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(EPB)7-<(B!W=7)D92!I;B!D97(@5D93+4MO
M;F9I9W5R871I;VX@;FEC:'0@86YG96=E8F5N+B(*"B,Z(&9R86UE=V]R:R]5
M=&EL+U5T:6PN<&AP.C@P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E
M9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R(")<(B5S7"(@=W5R9&4@:6X@9&5R($MO;F9I9W5R871I;VX@;FEC:'0@
M86YG96=E8F5N+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N
M<&AP.C,S-@IM<V=I9"`B4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B3F]T=V5N
M9&EG97,@1F5L9"(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,S.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E
M<F5R+G!H<#HS,C$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(R,"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@(E)E
M<V5T(@IM<V=S='(@(EIU<OQC:W-E='IE;B(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C0X"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R
M(")087-S=V]R="!Z=7+\8VMS971Z96XB"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HR.`IM<V=I9"`B4F5S970@66]U<B!087-S=V]R9"(*;7-G
M<W1R(")3971Z96X@4VEE($EH<B!087-S=V]R="!Z=7+\8VLB"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,3,Q"FUS9VED(")297-T;W)E($QA<W0@475E<GDB
M"FUS9W-T<B`B3&5T>G1E($%B9G)A9V4@96EN9OQG96XB"@HC.B!A9&UI;B]P
M:'!S:&5L;"YP:'`Z-S(@861M:6XO8VUD<VAE;&PN<&AP.C(Y(&%D;6EN+W-Q
M;'-H96QL+G!H<#HV-PIM<V=I9"`B4F5S=6QT<R(*;7-G<W1R(")%<F=E8FYI
M<W-E(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,2!T96UP
M;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U<FX@=&\@3W!T:6]N
M<R(*;7-G<W1R("):=7+\8VL@>G4@16EN<W1E;&QU;F=E;B(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS.`IM<V=I9"`B4F5T>7!E(&YE=R!P
M87-S=V]R9"(*;7-G<W1R(").975E<R!087-S=V]R="!E<FYE=70@96EN9V5B
M96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2975N:6]N(@IM<V=S='(@(E+I
M=6YI;VXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N
M(@IM<V=S='(@(DMO;F9I9W5R871I;VX@>G5R_&-K<V5T>F5N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$S-0IM<V=I9"`B4FEC:"!497AT($5D:71O
M<B!/<'1I;VYS(@IM<V=S='(@(E=94TE764<M161I=&]R($5I;G-T96QL=6YG
M96XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L
M97,B"FUS9W-T<B`B4N1T<V5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<P"FUS9VED(")2:6=H="(*;7-G<W1R
M(")296-H=',B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(Q"FUS
M9VED(")2:6=H="!H96%D97(B"FUS9W-T<B`B4F5C:'1E(-QB97)S8VAR:69T
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-PIM<V=I9"`B4FEG
M:'0@=F%L=65S(@IM<V=S='(@(E)E8VAT92!797)T92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I
M9"`B4F]?=R!0<F]P97)T:65S+BXN(@IM<V=S='(@(E]:96EL96YE:6=E;G-C
M:&%F=&5N+BXN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R(")2;VQL92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`B4G5MY&YI96XB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(V"FUS
M9VED(")2;W1A=&4@,3@P(@IM<V=S='(@(E5M(#$X,+`@9')E:&5N(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,PIM<V=I
M9"`B4F]T871E($QE9G0B"FUS9W-T<B`B3F%C:"!L:6YK<R!D<F5H96XB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(Y"FUS
M9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`B3F%C:"!R96-H=',@9')E:&5N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B6F5I;&5N
M96EG96YS8VAA9G1E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P<F]P97)T:65S(@IM
M<V=S='(@(EIE:6QE;F5I9V5N<V-H869T96XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W<SHB"FUS
M9W-T<B`B6F5I;&5N.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G:60@(E)U;&5S(@IM<V=S='(@(E)E
M9V5L;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@
M86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`B4F%H;65N('IW:7-C:&5N
M(&%L;&5N(%IE:6QE;B!U;F0@4W!A;'1E;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(E)A
M:&UE;B!N=7(@>G=I<V-H96X@4W!A;'1E;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S='(@(E)A:&UE
M;B!N=7(@>G=I<V-H96X@6F5I;&5N(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$R,0IM<V=I9"`B4G5N(@IM<V=S='(@(E-T87)T96XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`S"FUS9VED(")2=7-S:6%N($9E9&5R871I;VXB"FUS9W-T<B`B4G5S<VES
M8VAE($;V<F1E<F%T:6]N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G=A;F1A
M(@IM<V=S='(@(E)U86YD82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N
M871U<F4B"FUS9W-T<B`B4R]-24U%(&MR>71O9W)A<&AI<V-H92!5;G1E<G-C
M:')I9G0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,R
M,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@(DUI
M="!3+TU)344@=F5R<V-H;/QS<V5L=&4@3F%C:')I8VAT(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]S87-L+G!H<#HX,0IM<V=I9"`B4T%33"!A=71H96YT
M:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")305-,+4%U=&AE
M;G1I9FEZ:65R=6YG(&ES="!N:6-H="!V97)F_&=B87(N(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C4P-@IM<V=I9"`B4TU3($UE<W-A9VEN9R(*
M;7-G<W1R(")335,M5F5R<V%N9"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR
M,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(E-13"!3:&5L;"(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.3(*;7-G:60@(E-13"!S=&%T96UE
M;G0@9F]R('9A;'5E(&QO;VMU<',B"FUS9W-T<B`B4U%,+4%N=V5I<W5N9R!Z
M=7(@06)F<F%G92!D97(@5V5R=&4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#,S"FUS9VED(")34T@B"FUS9W-T<B`B4U-((@H*(SH@9G)A;65W
M;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE
M+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R(")%4D9/3$<B"@HC.B!L
M:6(O87!I+G!H<#HR,3D*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B4U]1
M3"!3:&5L;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@(E-A(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@(E-A:6YT($AE;&5N82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES(@IM
M<V=S='(@(E-A:6YT($MI='1S('5N9"!.979I<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM
M<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B4V%I;G0@3'5C:6$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`P"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@IM
M<V=S='(@(E-A:6YT(%!I97)R92!U;F0@36EQ=65L;VXB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$U"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*
M;7-G<W1R(")386EN="!6:6YC96YT('5N9"!D:64@1W)E;F%D:6YE;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G
M:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R(")';&5I8VAE<B!286AM
M96X@*%]S96QF*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S
M='(@(E-A;6]A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V%N($UA<FEN;R(*
M;7-G<W1R(")386X@36%R:6YO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.38*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4V%O
M(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S='(@(E-A;R!4;VUE('5N9"!0<FEN
M8VEP92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G
M:60@(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R(")3871E;&QI=&5N<')O
M=FED97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3875D:2!!<F%B:6$B"FUS
M9W-T<B`B4V%U9&DM07)A8FEE;B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHY.0IM<V=I9"`B4V%V92(*;7-G<W1R(")3<&5I8VAE<FXB"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C4W"B,L('!H<"UF
M;W)M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(EPB)7-<(B!S<&5I
M8VAE<FXB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@(B5S('-P96EC:&5R
M;B(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@
M3W!T:6]N<R(*;7-G<W1R(")%:6YS=&5L;'5N9V5N('-P96EC:&5R;B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C8*;7-G:60@(B(*(E-A=F4@9V5N
M97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@
M<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB
M17)Z975G=&4@2V]N9FEG=7)A=&EO;B!A;',@4$A0+5-K<FEP="!I;2!T96UP
M;W+D<F5N(%9E<GIE:6-H;FES($EH<F5S("(*(E-E<G9E<G,@<W!E:6-H97)N
M+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B5S
M+4MO;F9I9W5R871I;VX@9V5S<&5I8VAE<G0N(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B1&%S($%K
M='5A;&ES:65R=6YG<W-K<FEP="!W=7)D92!I;B!<(B5S7"(@9V5S<&5I8VAE
M<G0N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-3,*;7-G:60@(E-C871T97)E9"!4+5-T;W)M<R(*;7-G<W1R(")697)E:6YZ
M96QT92!'97=I='1E<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.0IM
M<V=I9"`B4V-I96YC92(*;7-G<W1R(")7:7-S96YS8VAA9G0B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T97,O861M:6XO
M=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(E-U8VAE
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R,@IM<V=I9"`B4V5A
M<F-H($5N9VEN97,B"FUS9W-T<B`B4W5C:&UA<V-H:6YE;B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Y-S,*;7-G:60@(E-E;&5C="!&:6QE<R(*
M;7-G<W1R(")$871E:65N(&%U<W?D:&QE;B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT.#4*;7-G:60@(E-E;&5C="!A(&1A
M=&4B"FUS9W-T<B`B1&%T=6T@875S=^1H;&5N(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ.3D*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D
M9"(*;7-G<W1R(")(:6YZ=7IU9OQG96YD92!'<G5P<&5N(&%U<W?D:&QE;B(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-#0*;7-G:60@(E-E;&5C
M="!A(&YE=R!O=VYE<B(*;7-G<W1R(").975E;B!"97-I='IE<B!A=7-WY&AL
M96XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@
M(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R(")397)V97(@875S=^1H;&5N(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-3<*;7-G:60@(E-E;&5C
M="!A('5S97(@=&\@861D(@IM<V=S='(@(DAI;GIU>G5F_&=E;F1E;B!"96YU
M='IE<B!A=7-WY&AL96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-C<V"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(D%L
M;&4@875S=^1H;&5N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V
M,0IM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@
M(DQE9V5N(%-I92!A;&QE($1A='5M<VMO;7!O;F5N=&5N(&9E<W0N(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I
M9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R(")/8FIE:W0@875S=^1H;&5N
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W
M-PIM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B2V5I;F5N(&%U<W?D:&QE
M;B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HS-PIM<V=I9"`B(@HB4V5L
M96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E
M;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M
M('1H92!T97AT(&%R96$N(@IM<V=S='(@(B(*(E?D:&QE;B!3:64@9&EE(&)E
M;O9T:6=T96X@6F5I8VAE;B!A=7,@9&5N(&IE=V5I;&EG96X@1F5L9&5R;B!A
M=7,N($1A;FX@(@HB:_9N;F5N(%-I92!D:65S92!A=7,@9&5M(%1E>'1F96QD
M(&MO<&EE<F5N('5N9"!I;B!):')E($YA8VAR:6-H="!E:6YF_&=E;BXB"@HC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H
M92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`B5^1H;&5N(%-I92!D87,@1&%T
M=6US=')E;FYZ96EC:&5N.B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R(")7
MY&AL96X@4VEE(&1A<R!$871U;7-F;W)M870Z(@H*(SH@=&5M<&QA=&5S+W!R
M969S+VED96YT:71Y<V5L96-T+FEN8SHY,@IM<V=I9"`B4V5L96-T('1H92!I
M9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(E?D:&QE;B!3
M:64@9&EE($ED96YT:73D="P@9&EE(%-I92#D;F1E<FX@;?9C:'1E;CHB"@HC
M.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H
M92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B5^1H;&5N(%-I92!D87,@6F5I
M='1R96YN>F5I8VAE;CHB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR
M-0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`B5^1H
M;&5N(%-I92!D87,@6F5I=&9O<FUA=#HB"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C4W"FUS9VED(")396QE8W0@='=O(&UA=&-H:6YG(&9I96QD
M<RXB"FUS9W-T<B`B5^1H;&5N(%-I92!Z=V5I('IU<V%M;65N9V5H]G)I9V4@
M1F5L9&5R(&%U<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`S"FUS
M9VED(")396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N(@IM<V=S='(@(E?D:&QE
M;B!3:64@96EN($9A<F)S8VAE;6$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(T-`IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E
M.B(*;7-G<W1R(")7Y&AL96X@4VEE($EH<F4@8F5V;W)Z=6=T92!3<')A8VAE
M.B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED
M(")396YD(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(E!R;V)L96UB97)I8VAT
M(&%B<V-H:6-K96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3`T,@IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B4TU3('9E
M<G-C:&EC:V5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G
M<W1R(")396YE9V%L(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3@*;7-G
M:60@(E-E;G-O<CH@(@IM<V=S='(@(E-E;G-O<CH@(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,`HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@(E-E<'1E;6)E
M<B(*;7-G<W1R(")397!T96UB97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O
M(@IM<V=S='(@(E-E<F)I96X@=6YD($UO;G1E;F5G<F\B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,@IM<V=I9"`B4V5R:6%L($YU
M;6)E<B(*;7-G<W1R(")397)I96YN=6UM97(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,30Y"FUS9VED(")397)V97(@9&%T82!W<F]N9R!O
M<B!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")397)V97)D871E;B!U;F?\;'1I
M9R!O9&5R(&YI8VAT('9E<F;\9V)A<BXB"@HC.B!A9&UI;B]S97-S:6]N<RYP
M:'`Z,C<*;7-G:60@(E-E<W-I;VX@061M:6XB"FUS9W-T<B`B4V5S<W-I;VYV
M97)W86QT=6YG(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")397-S:6]N($E$(&5X<&ER960N(@IM
M<V=S='(@(E-E<W-I;VXM240@86)G96QA=69E;BXB"@HC.B!L:6(O87!I+G!H
M<#HR,3$*;7-G:60@(E-E<W-I;VYS(@IM<V=S='(@(E-I='IU;F=E;B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,S(*;7-G:60@(E-E="(*;7-G
M<W1R(")!=7-W86AL+5-A='HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-SD*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y
M;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B
M(@HB3&5G96X@4VEE(&1I92!%:6YS=&5L;'5N9V5N(&9E<W0L(&1I92!E<R!)
M:&YE;B!E<FQA=6)E;B!):'(@4&%S<W=O<G0@(@HB>G5R_&-K>G5S971Z96XL
M(&9A;&QS('-I92!E<R!E:6YM86P@=F5R9V5S<V5N('-O;&QT96XN(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q.`IM<V=I9"`B4V5T('5P(')E;6]T
M92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P
M;W)T86PN(@IM<V=S='(@(B(*(DQE9V5N(%-I92!E;G1F97)N=&4@4V5R=F5R
M(&9E<W0L(&%U9B!D:64@4VEE('9O;B!):')E;2!0;W)T86P@875S('IU9W)E
M:69E;B`B"B)M]F-H=&5N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M-PIM<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N
M92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R(")7Y&AL96X@4VEE($EH<F4@
M8F5V;W)Z=6=T92!3<')A8VAE+"!:96ET>F]N92!U;F0@1&%T=6US96EN<W1E
M;&QU;F=E;BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Q"FUS9VED
M("(B"B)3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE
M;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T
M:6]N<RXB"FUS9W-T<B`B(@HB3&5G96X@4VEE(&1A<R!D:64@4W1A<G1A;G=E
M;F1U;F<L(&1A<R!&87)B<V-H96UA+"!D:64@4V5I=&5N86MT=6%L:7-I97)U
M;F<@(@HB=6YD(&%N9&5R92!!;GIE:6=E96EN<W1E;&QU;F=E;B!F97-T+B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S<*;7-G:60@(E-E='5P(@IM
M<V=S='(@(DMO;F9I9W5R871I;VXB"@HC.B!T96UP;&%T97,O861M:6XO<V5T
M=7`O:6YD97@N:'1M;#HS-PIM<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S
M(&%V86EL86)L92(*;7-G<W1R(")!:W1U86QI<VEE<G5N9W-S:W)I<'1E('-I
M;F0@=F5R9OQG8F%R(@H*(R!-96AR97)E('!A<W-E;F1E($]R=&4@;6ET(&1I
M97-E;2!087)A;65T97(Z(`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3<U"FUS9VED(")3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H
M('1H92!P87)A;65T97(Z("(*;7-G<W1R(")-96AR97)E('!A<W-E;F1E($]R
M=&4@;6ET(&1I97-E;2!087)A;65T97(Z("(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G
M:60@(E-E>6-H96QL97,B"FUS9W-T<B`B4V5Y8VAE;&QE;B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT.3@*;7-G:60@(E-H;W!P:6YG(@IM<V=S
M='(@(D5I;FMA=68B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHT,PIM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G<W1R(")+=7)Z92!:=7-A
M;6UE;F9A<W-U;F<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0S"FUS
M9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L
M:6YK<S\B"FUS9W-T<B`B4V]L;&5N(%1A<W1E;FMO;6)I;F%T:6]N96X@9OQR
M(&1I92!M96ES=&5N($QI;FMS(&%K=&EV:65R="!W97)D96X_(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*;7-G:60@(E-H;W<B
M"FUS9W-T<B`B6F5I9V5N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U
M-`IM<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L
M>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("(B"B)5;G1E<G-C:&EE9&4@>G=I<V-H96X@9&5R(&%K
M='5E;&QE;B!U;F0@9&5R(&=E<F%D92!E<GIE=6=T96X@2V]N9FEG=7)A=&EO
M;B`B"B)A;GIE:6=E;BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#@W
M"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_
M(@IM<V=S='(@(D%N>F5I9V5N+"!W86YN(&1I92!L971Z=&4@06YM96QD=6YG
M(&5R9F]L9W0@:7-T/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W
M-C4*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS9W-T
M<B`B17)H86QT96X@9&5S($]R:6=I;F%L<R!E<FWV9VQI8VAE;B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3,*;7-G:60@(E-H;W<@<&EC:V5R
M(@IM<V=S='(@(D%U<W?D:&QE<B!A;GIE:6=E;B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,C,*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M
M96YU(&)A<C\B"FUS9W-T<B`B5V5R:WIE=6=L96ES=&4@9OQR(%1A8F5L;&5N
M(&%N>F5I9V5N/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F
M=#\B"FUS9W-T<B`B1&%S("5S+4UE;OP@875F(&1E<B!L:6YK96X@4V5I=&4@
M86YZ96EG96X_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!486)L92!#96QL
M(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(D1I86QO9R!F_'(@5&%B96QL
M96YZ96QL96YE:6=E;G-C:&%F=&5N(&%N>F5I9V5N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8T"FUS9VED
M(")3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")$
M:6%L;V<@9OQR(%1A8F5L;&5N96EG96YS8VAA9G1E;B!A;GIE:6=E;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV,`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA
M;&]G(@IM<V=S='(@(D1I86QO9R!F_'(@5&%B96QL96YZ96EL96YE:6=E;G-C
M:&%F=&5N(&%N>F5I9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")3:&]W('1H92!I;6%G
M92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")$:6%L;V<@9OQR($)I;&1E
M:6=E;G-C:&%F=&5N(&%N>F5I9V5N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3<V,PIM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T<B`B2&]C:&QA
M9&5N(&5R;?9G;&EC:&5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-30*;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`B4V-H875E
M<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U
M"FUS9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(D9R_&@@4V-H875E<B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V"FUS
M9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B4W#D=&5R(%-C:&%U97(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I
M9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B4V-H875E<B!I
M;B!D97(@56UG96)U;F<B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C8Q.0IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(E9E
M<FML96EN97)N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-
M86YA9V5R+G!H<#HY,3`*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HY-S(*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HQ,#4X"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70O36%N86=E<BYP:'`Z,3$R,`HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$Q.#,*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C(S"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(U,@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R.#4*;7-G
M:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@
M;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R(")697)K;&5I;F5R;B!O9&5R('9E
M<G-C:&EE8F5N(%-I92!E<G-T(&1I92!B96YA8VAB87)T96X@0FSV8VME(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(E-I
M97)R82!,96]N92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H
M<#HR-C8*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B4F5G:7-T<FEE<F5N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3,*;7-G:60@
M(E-I9VYA='5R92(*;7-G<W1R(")3:6=N871U<B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED(")3:6=N871U<F4@06QG
M;W)I=&AM(@IM<V=S='(@(E-I9VYA='5R86QG;W)I=&AM=7,B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`B4VEN9V%P=7(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8U(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-"!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HX.38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,W"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(R-C0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,`HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(S"FUS9VED(")3:7IE(@IM
M<V=S='(@(D=R]M]E(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT
M96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T
M<B`B5V%R='5N9W-A<F)E:71E;B#\8F5R<W!R:6YG96XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`U"FUS9VED(")3;&]V86MI82(*;7-G<W1R(")3;&]W86ME:2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@(E-L;W=E;FEE;B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS
M9VED(")3;F]W(@IM<V=S='(@(E-C:&YE92(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3;F]W(%-H;W=E<B(*
M;7-G<W1R(")38VAN965S8VAA=65R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G
M<W1R(")38VAN965S8VAA=65R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*
M;7-G<W1R(")&<OQH(%-C:&YE97-C:&%U97(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B4VYO=R!3:&]W97)S
M($QA=&4B"FUS9W-T<B`B4W#D=&5R(%-C:&YE97-C:&%U97(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(X,`IM<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S
M='(@(E-C:&YE96CV:&4Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@T
M"FUS9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R(")3
M8VAN965M96YG92!A;',@5V%S<V5R.B`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED
M(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B4V]L;VUO;FEN<V5L;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#8*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`B4V]M86QI96XB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*;7-G:60@(E-O;F=S("8@
M4&]E;7,B"FUS9W-T<B`B3&EE9&5R("8@1V5D:6-H=&4B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.3(V"FUS9VED(")3;W)T(&]R9&5R('-E;&5C
M=&EO;B(*;7-G<W1R(")!=7-W86AL(&1E<B!3;W)T:65R<F5I:&5N9F]L9V4B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,3@Y"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G<W1R(")5<G-P
M<G5N9W-A9')E<W-E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R
M:6-A(@IM<V=S='(@(E/\9&%F<FEK82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3DS"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB"FUS
M9W-T<B`B4_QD975R;W#D:7-C:"`H25-/+3@X-3DM,RDB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S<*;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC
M:"!)<VQA;F1S(@IM<V=S='(@(E/\9&=E;W)G:65N('5N9"!D:64@4_QD;&EC
M:&5N(%-A;F1W:6-H:6YS96QN(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S
M(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P
M:&5R92(*;7-G<W1R(")3_&1L:6-H92!(96UI<W!H97)E(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P
M86-E(&)E='=E96X@861J86-E;G0@8V5L;',B"FUS9W-T<B`B06)S=&%N9"!Z
M=VES8VAE;B!A=69E:6YA;F1E<B!F;VQG96YD96X@6F5L;&5N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@
M(E-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS
M9W-T<B`B06)S=&%N9"!Z=VES8VAE;B!);FAA;'0@=6YD(%)A:&UE;B!V;VX@
M6F5L;&5N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#$U"FUS9VED
M(")3<&%C97(B"FUS9W-T<B`B06)S=&%N9&AA;'1E<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`IM<V=I9"`B
M4W!A8VEN9R(*;7-G<W1R(")!8G-T86YD(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN
M9R!A;F0@<&%D9&EN9R(*;7-G<W1R(")!8G-TY&YD92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q
M"FUS9VED(")3<&%I;B(*;7-G<W1R(")3<&%N:65N(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$P,`IM<V=I9"`B4W!A;2(*;7-G<W1R(")3<&%M
M(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C:6%L
M($-H87)A8W1E<B!);G!U="(*;7-G<W1R(")3;VYD97)Z96EC:&5N+45I;F=A
M8F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S='(@(EIE;&QE('1E
M:6QE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R(")3<&%L
M=&4@=&5I;&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S='(@(EIE
M:6QE('1E:6QE;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,0IM<V=I
M9"`B4W!O<G1S(@IM<V=S='(@(E-P;W)T(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED
M(")3<FD@3&%N:V$B"FUS9W-T<B`B4W)I($QA;FMA(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C8V(&QI8B]";&]C:R]M971A<BYP:'`Z.#$*
M;7-G:60@(E-T86YD87)D(@IM<V=S='(@(E-T86YD87)D(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED(")3=&%R(%1R96LB"FUS9W-T<B`B
M4W1A<B!4<F5K(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8P-"!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`Y"FUS9VED(")3=&%R="!Y96%R
M(@IM<V=S='(@(E-T87)T:F%H<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3<Q"FUS9VED(")3=&%T92!O<B!0<F]V:6YC92(*;7-G
M<W1R(")"=6YD97-S=&%A="!O9&5R(%!R;W9I;GHB"@HC.B!T96UP;&%T97,O
M861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S(@IM<V=S
M='(@(E-T871U<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,34*
M;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(E-P96EC:&5R9F]R;6%T
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G
M:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@(E-T<F'?92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T
M<FEK971H<F]U9V@B"FUS9W-T<B`B1'5R8VAG97-T<FEC:&5N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S,PIM<V=I9"`B4W1R:6YG(&QI<W0B
M"FUS9W-T<B`B6F5I8VAE;FQI<W1E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@Y,0IM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E
M<W,B"FUS9W-T<B`B1&]M86EN(&%U<R!D97(@061R97-S92!E;G1F97)N96XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G<W1R(")3=&EL(%M#4U-=
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M,@IM<V=I9"`B4W4B"FUS9W-T<B`B4V\B"@HC.B!U=&EL+VEC;VY?8G)O=W-E
M<BYP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB
M)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(E5N=&5R=F5R>F5I8VAN:7,@7"(E
M<UPB(&YI8VAT(&=E9G5N9&5N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B
M0F5T<F5F9B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,B!F<F%M
M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3@*;7-G:60@(E-U8FUI
M="(*;7-G<W1R(")!8G-C:&EC:V5N(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@
M7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL
M('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B
M(@HB1&EE(%)E9VES=')I97)U;F=S86YF<F%G92!F_'(@7"(E<UPB('=U<F1E
M(&%B9V5S8VAI8VMT+B!3:64@:_9N;F5N('-I8V@@;F]C:"`B"B)N:6-H="!A
M;FUE;&1E;BP@<V]L86YG92!D:64@06YF<F%G92!N;V-H(&YI8VAT(&)E<W3D
M=&EG="!W=7)D92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$R"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`B5&EE9F=E
M<W1E;&QT(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P-0HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N
M<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S='(@(D5R9F]L9R(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F
M=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B7"(E
M<UPB('=U<F1E(&5R9F]L9W)E:6-H(&AI;GIU9V5F_&=T+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@8VQE87)E9"!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T
M96TN(@IM<V=S='(@(D1A=&5N(&1E<R!"96YU='IE<G,@7"(E<UPB('=U<F1E
M(&5R9F]L9W)E:6-H(&=E;/9S8VAT+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N(@IM<V=S='(@(EPB
M)7-<(B!W=7)D92!E<F9O;&=R96EC:"!G96SV<V-H="XB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B7"(E
M<UPB('=U<F1E(&5R9F]L9W)E:6-H(&=E;/9S8VAT+B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E
M9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S
M='(@(B(*(DMO;F9I9W5R871I;VX@97)F;VQG<F5I8V@@>G5R_&-K9V5S971Z
M="X@4V5I=&4@;F5U(&QA9&5N+"!U;2!D:64@Q&YD97)U;F=E;B`B"B)A;GIU
M>F5I9V5N+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU.2!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HU-PIM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D
M(&)A8VMU<"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")"86-K=7`@9&5R($MO
M;F9I9W5R871I;VX@97)F;VQG<F5I8V@@9V5S<&5I8VAE<G0N(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I
M;&4@)7,N(@IM<V=S='(@(D)A8VMU<"!D97(@2V]N9FEG=7)A=&EO;B`E<R!E
M<F9O;&=R96EC:"!G97-P96EC:&5R="XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@
M7"(E<UPB(@IM<V=S='(@(EPB)7-<(B!W=7)D92!E<F9O;&=R96EC:"!A:W1U
M86QI<VEE<G0B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C
M97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`B)7,@=W5R9&4@97)F;VQG<F5I
M8V@@9V5S<&5I8VAE<G0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=61A;B(*
M;7-G<W1R(")3=61A;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-38*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`B
M6G5S86UM96YF87-S=6YG(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U
M"FUS9VED(")3=6X@4FES92(*;7-G<W1R(")3;VYN96YA=69G86YG(@H*(SH@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S
M='(@(E-O;FYE;G5N=&5R9V%N9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8S"FUS9VED(")3=6YN>2(*;7-G<W1R(")3;VYN
M:6<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`U"FUS9VED
M(")3=6YR:7-E(@IM<V=S='(@(E-O;FYE;F%U9F=A;F<B"@HC.B!L:6(O0FQO
M8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,38*;7-G
M:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@(E-O;FYE;F%U9B]U;G1E<F=A
M;F<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`T"FUS9VED
M(")3=6YR:7-E.B`B"FUS9W-T<B`B4V]N;F5N875F9V%N9SH@(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P.`IM<V=I9"`B4W5N<V5T(@IM
M<V=S='(@(E-O;FYE;G5N=&5R9V%N9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,#<*;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@(E-O;FYE
M;G5N=&5R9V%N9SH@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`B2&]C
M:&=E<W1E;&QT(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X,`IM
M<V=I9"`B4W5P<&]R="(*;7-G<W1R(")3=7!P;W)T(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-@IM<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`B4W5R:6YA;2(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<U"FUS9VED(")3=7)N86UE
M(@IM<V=S='(@(DYA8VAN86UE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4W9A
M;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R(")3=F%L8F%R9"!U;F0@2F%N
M($UA>65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B4W=A>FEL86YD(@IM<V=S
M='(@(E-W87-I;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*
M;7-G<W1R(")38VAW961E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")3=VET>F5R
M;&%N9"(*;7-G<W1R(")38VAW96EZ(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z.#8*;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B"FUS9W-T<B`B
M4WEN8VAR;VYI>F%T:6]N<VQO9R!G96SV<V-H="(*"B,Z(&9R86UE=V]R:R]3
M44PO4U%,+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN
M('-E87)C:"!T97)M<R(*;7-G<W1R(")&;W)M871F96AL97(@:6X@4W5C:&)E
M9W)I9F9E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-Y<FEA;B!!<F%B(%)E
M<'5B;&EC(@IM<V=S='(@(D%R86)I<V-H92!297!U8FQI:R!3>7)I96XB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-`IM<V=I
M9"`B5"U3=&]R;2(*;7-G<W1R(")'97=I='1E<B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")4+5-T;W)M(&%N
M9"!7:6YD>2(*;7-G<W1R(")'97=I='1E<B!U;F0@5VEN9&EG(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E0M
M4W1O<FUS(@IM<V=S='(@(D=E=VET=&5R(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(E0M4W1O<FUS($5A<FQY
M(@IM<V=S='(@(D9R_&@@1V5W:71T97(B"@HC.B!F<F%M97=O<FLO1&%T82]$
M871A+W1S=BYP:'`Z,3<P"FUS9VED(")44U8@9FEL92(*;7-G<W1R(")44U8M
M1&%T96DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<S"FUS9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@
M(E1A8F5L;&5N96EG96YS8VAA9G1E;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTO5'EP92]T86)L97-E="YP:'`Z-3<*;7-G:60@(E1A8FQE(%-E="(*;7-G
M<W1R(")486)E;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*
M;7-G<W1R(")486)E;&QE;F5I9V5N<V-H869T96XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$Q"FUS9VED(")486EW86XB"FUS9W-T<B`B5&%I=V%N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A
M;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`B5&%I=V%N+"!C:&EN97-I
M<V-H92!0<F]V:6YZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A
M;B(*;7-G<W1R(")4861S8VAI:VES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I
M9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R(")697)E
M:6YI9W1E(%)E<'5B;&EK(%1A;G-A;FEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T.B(*;7-G
M<W1R(")::65L.B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.34X
M(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#4Y"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ.#D*;7-G:60@(E1A<VMS(@IM<V=S='(@(D%U9F=A8F5N
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S0*;7-G
M:60@(E1E;&5P:&]N92!.=6UB97(B"FUS9W-T<B`B5&5L969O;FYU;6UE<B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDR"FUS9VED(")496UP(&9O<B!L
M87-T(&AO=7(Z("(*;7-G<W1R(")496UP97)A='5R(&1E<B!L971Z=&5N(%-T
M=6YD93H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,38*;7-G:60@(E1E
M;7!E<F%T=7)E(@IM<V=S='(@(E1E;7!E<F%T=7(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C$R"FUS9VED(")496UP97)A='5R93H@(@IM
M<V=S='(@(E1E;7!E<F%T=7(Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&5R871U<F4\
M8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<R(*;7-G<W1R(")496UP97)A
M='5R/&)R("\^*"5S36%X)7,O)7--:6XE<RD@)F1E9SLE<R(*"B,Z(&9R86UE
M=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-CDU"B,L('!H<"UF;W)M870*
M;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(E9O
M<FQA9V4@7"(E<UPB(&YI8VAT(&=E9G5N9&5N+B(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z,38Y"FUS9VED(")496UP;&%T92!!9&UI;FES=')A=&EO;B(*
M;7-G<W1R(")6;W)L86=E;G9E<G=A;'1U;F<B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S-#4*
M;7-G:60@(E1E>'0B"FUS9W-T<B`B5&5X="(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-S(*;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R(").=7(@5&5X
M="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S0*;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T<B`B075S<FEC:'1U
M;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<Q"FUS9VED(")497AT=&]P(@IM<V=S='(@(E1E>'0@3V)E;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@
M(E1H(@IM<V=S='(@(D1O(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.30*
M;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(E1H86ELY&YD:7-C:"`H
M5$E3+38R,"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4:&%I;&%N9"(*;7-G
M<W1R(")4:&%I;&%N9"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.#8S"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R(")$:64@1E10+45X=&5N<VEO;B!I<W0@;FEC:'0@=F5R9OQG
M8F%R+B(*"B,Z(&9R86UE=V]R:R](:7-T;W)Y+TAI<W1O<GDN<&AP.C4U"FUS
M9VED(")4:&4@2&ES=&]R>2!S>7-T96T@:7,@9&ES86)L960N(@IM<V=S='(@
M(D1I92!#:')O;FEK('-T96AT(&YI8VAT('IU<B!697)F_&=U;F<N(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY-C0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S
M(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R(")$:64@2&]R9&4O2V]L86(@
M26YT96=R871I;VYS9G5N:W1I;VYE;B!U;G1E<G-T_'1Z96X@7"(E<UPB(&YI
M8VAT(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O0F]O:RYP:'`Z,3(Y
M.`IM<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE
M9"XB"FUS9W-T<B`B1&EE($E-4U`M3&]G9&%T96D@:V]N;G1E(&YI8VAT(&5R
M<W1E;&QT('=E<F1E;BXB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A
M9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B1&EE($UA:6YT96YA;F-E.CH@2VQA
M<W-E(&MO;FYT92!N:6-H="!G96QA9&5N('=E<F1E;B(*"B,Z('-E<G9I8V5S
M+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS
M('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R(")$87,@16EN
M<W1E;&QU;F=E;BU&96YS=&5R(&ES="!G97-C:&QO<W-E;B!W;W)D96XN($%B
M8G)U8V@N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.3`@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,#$*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HR,3(@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,C0*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,S4@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HR-3,*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HR-C4@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,#0*;7-G:60@(B(*
M(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA
M;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S
M92!097)M:7-S:6]N<RXB"FUS9W-T<B`B(@HB1&5R($%D;6EN:7-T<F%T;W(@
M;75S<R!E:6X@<&5R;6%N96YT97,@4F5C:'1E+4)A8VME;F0@96EN<FEC:'1E
M;BP@=V5N;B!3:64@(@HB9&EE(%)E8VAT979E<G=A;'1U;F<@;G5T>F5N(&WV
M8VAT96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS
M9W-T<B`B3G5R('5N=&5N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT86-T($E$
M(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@
M;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B(@HB1&EE
M($E$+4YU;6UE<B!D97,@2V]N=&%K=',@=W5R9&4@;FEC:'0@86YG96)E;BP@
M=V%R(&QE97(@;V1E<B!K;VYN=&4@:6X@9&5R("(*(D1A=&5N8F%N:R!N:6-H
M="!G969U;F1E;B!W97)D96XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C4Q"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C
M8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R
M(")$97(@2V]N=&%K="!W=7)D92!E<F9O;&=R96EC:"!):')E;2!!9')E<W-B
M=6-H(&AI;GIU9V5F_&=T+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$Q.#$*;7-G:60@(B(*(E1H92!D971A8VAE9"!01U`@<VEG;F%T
M=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE
M<W-A9V4N(@IM<V=S='(@(B(*(D1E<B!01U`M4VEG;F%T=7)B;&]C:R!W:7)D
M(&)E;O9T:6=T+"!U;2!D:64@=6YT97)Z96EC:&YE=&4@3F%C:')I8VAT('IU
M("(*(OQB97)P<OQF96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@(B(*(E1H92!D:7-T<FEB=71I
M;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA
M;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D871A8F%S92XB"FUS9W-T<B`B
M(@HB1&EE($E$+4YU;6UE<B!D97(@5F5R=&5I;&5R;&ES=&4@=W5R9&4@;FEC
M:'0@86YG96)E;BP@=V%R(&QE97(@;V1E<B!K;VYN=&4@(@HB:6X@9&5R($1A
M=&5N8F%N:R!N:6-H="!G969U;F1E;B!W97)D96XN(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*;7-G:60@(E1H
M92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"XB"FUS9W-T
M<B`B1&EE(%9E<G1E:6QE<FQI<W1E('=U<F1E(&YI8VAT(&%N9V5G96)E;BXB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q-@IM<V=I9"`B5&AE
M(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N
M;F5C=&EO;BXB"FUS9W-T<B`B(@HB1&EE(%9E<G-C:&S\<W-E;'5N9W-F=6YK
M=&EO;F5N(&)E;O9T:6=E;B!E:6YE('-I8VAE<F4@4V5R=F5R=F5R8FEN9'5N
M9RXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$X-B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C4R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S
M='(@(D1I92!$871E:2`E<R!S;VQL=&4@96EN96X@)7,@16EN=')A9R!E;G1H
M86QT96XN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-SD@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG
M<RXB"FUS9W-T<B`B1&EE($1A=&5I("5S('-O;&QT92!E:6YI9V4@)7,@16EN
M='+D9V4@96YT:&%L=&5N+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP
M.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S
M='(@(D1I92!$871E:2!E;G1H:65L="!K96EN92!$871E;BXB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4
M:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E
M+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R(")(:65R('-I;F0@9&EE($MO<&9E
M:6YT<N1G92!F_'(@9&EE<V4@;65S<V%G92]R9F,X,C(@3F%C:')I8VAT+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*
M;7-G:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A
M=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92`B"B)T
M;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R
M;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA
M>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O
M=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y
M>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L
M("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<
M7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I
M9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O
M<BXB"FUS9W-T<B`B(@HB1&5R(%9O;&QB:6QD;6]D=7,@=F5R=7)S86-H="!A
M=68@1W)U;F0@=F]N($9E:&QE<FX@:6T@26YT97)N970@17AP;&]R97(@(@HB
M8F5K86YN=&5R;6'?96X@4')O8FQE;64@;6ET(&1I97-E;2!"<F]W<V5R+"!D
M:64@=VER(&YI8VAT('5M9V5H96X@:_9N;F5N+B`B"B)5;G1E<B!5;7-TY&YD
M96X@97)H86QT96X@4VEE(&5I;F4@9F5H;&5R:&%F=&4@06YZ96EG92P@9F5H
M;&5N("(*(D5D:71O<F9U;FMT:6]N96XL(&]D97(@9&5R($)R;W=S97(@<W3\
M<GIT(&%B+B!!=68@96EN96T@5VEN9&]W(#EX(%-Y<W1E;2`B"B)W97)D96X@
M4VEE('9E<FUU=&QI8V@@96EN92`G06QL9V5M96EN92!38VAU='IV97)L971Z
M=6YG)R!E<FAA;'1E;B!U;F0@;?QS<V5N("(*(F1E;B!296-H;F5R(&YE=2!S
M=&%R=&5N+EQ<;EQ<;E-I92!W=7)D96X@9V5W87)N="X@0FET=&4@9'+\8VME
M;B!3:64@875F($]++"`B"B)W96YN(%-I92!N;V-H(&EM;65R(&1E;B!6;VQL
M8FEL9&UO9'5S('9E<G=E;F1E;B!M]F-H=&5N+B(*"B,Z('-E<G9I8V5S+W!R
M969S+G!H<#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y
M(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")$:64@261E;G1I
M=.1T(%PB)7-<(B!W=7)D92!G96SV<V-H="XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4:&4@
M;&5F="UH86YD('-I9&4@;VYL>2(*;7-G<W1R(").=7(@;&EN:W,B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ-3<*;7-G:60@(B(*(E1H
M92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@
M=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R("(B"B)$97(@3W)T
M(&1E<R!';G501RU0<F]G<F%M;7,@;75S<R!D97(@0W)Y<'1?<&=P.CH@2VQA
M<W-E(/QB97)G96)E;B!W97)D96XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-1$XN<&AP.C(P,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@;65S
M<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<(B5S7"(@:&%S
M(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R86YT964@=&AA
M="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N(@IM
M<V=S='(@(B(*(D1I92!.86-H<FEC:'0@;6ET(&1E;2!"971R969F(%PB)3,D
M<UPB+"!D:64@86T@)3$D<R!A;B`E,B1S(&=E<V-H:6-K="!W=7)D92P@(@HB
M:7-T(&%N9V5Z96EG="!W;W)D96XN7&XB"B)$87,@:&5IWW0@;FEC:'0L(&1A
M<W,@9&EE($YA8VAR:6-H="!A=6-H(&=E;&5S96X@;V1E<B!V97)S=&%N9&5N
M('=U<F1E+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X.34*;7-G
M:60@(E1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O
M<V4@<&%G92(*;7-G<W1R(").86UE(&;\<B!D96X@3&EN:R!Z=7(@3F%C:')I
M8VAT96YE<G-T96QL=6YG(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z-#<T"FUS9VED(")4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU
M;65R:6,N(@IM<V=S='(@(D1I92!!;GIA:&P@9&5R($9E;&1E<B!M=7-S(&%L
M<R!:86AL(&%N9V5G96)E;B!W97)D96XN(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HQ,C,R"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U
M;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L
M87-S+B(*;7-G<W1R(")$87,@3W!E;E-33"U-;V1U;"!W:7)D(&;\<B!D:64@
M2&]R9&5?0W)Y<'1?<VUI;64Z.B!+;&%S<V4@8F5N]G1I9W0N(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+G!H<#HR.#@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S879E
M9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M87AI;75M(&%L
M;&]W86)L92!S:7IE(@IM<V=S='(@(B(*(D1I92!"96YU='IE<F5I;G-T96QL
M=6YG(%PB)7-<(B!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N+"!W
M96EL(&EH<F4@(@HB1&%T96X@9&EE(&UA>&EM86P@97)L875B=&4@1W+VWV4@
M_&)E<G-C:')E:71E;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O96YS
M8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS
M<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W=E
M8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<W)C
M:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VUS97AC96PN<&AP.C,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P
M<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N
M;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@HB1&%S(%!R;V=R
M86UM(&;\<B!D:64@06YZ96EG92!D:65S97,@1&%T96ET>7!S("@E<RD@=W5R
M9&4@;FEC:'0@9V5F=6YD96XN(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-3
M5BYP:'`Z-#@W"FUS9VED(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@
M;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(D1A<R!!;F;\:')U;F=S
M>F5I8VAE;B!M=7-S(&%L<R!E:6YZ96QN97,@6F5I8VAE;B!A;F=E9V5B96X@
M=V5R9&5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A;F0@;&5F="!S:61E
M<R!O;FQY(@IM<V=S='(@(DYU<B!L:6YK<R!U;F0@<F5C:'1S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM
M<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(DYU<B!R
M96-H=',B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-SD*;7-G
M:60@(E1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E
M<BXB"FUS9W-T<B`B1&%S(%1R96YN>F5I8VAE;B!M=7-S(&%L<R!E:6YZ96QN
M97,@6F5I8VAE;B!A;F=E9V5B96X@=V5R9&5N+B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S
M97)V97(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(D1E<B!3
M97)V97(@7"(E<UPB('=U<F1E(&5N=&9E<FYT+B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]R<&-S=6TN<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S
M97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R(")$97(@4V5R
M=F5R(%PB)7-<(B!W=7)D92!G97-P96EC:&5R="XB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U
M97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R(")$:64@4F5G
M:7-T<FEE<G5N9W-A;F9R86=E('9O;B`E<R!W=7)D92!E;G1F97)N="XB"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C0W
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R`H)60I
M(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")$:64@86YG96=E8F5N92!:96EL
M92`H)60I(&5X:7-T:65R="!N:6-H="XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C(R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R
M87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")$:64@
M=&5M<&]RY')E($1A=&5I(%PB)7-<(B!E>&ES=&EE<G0@;FEC:'0N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R,`IM<V=I9"`B5&AE('1E>'0@
M>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R
M965N+B(*;7-G<W1R("(B"B)$97(@5&5X="P@9&5N(%-I92!A;F=E9V5B96X@
M:&%B96XL(&5N='-P<FEC:'0@;FEC:'0@9&5M(%1E>'0@875F(&1E;2`B"B)"
M:6QD<V-H:7)M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S
M:61E<R!O;FQY(@IM<V=S='(@(DYU<B!O8F5N('5N9"!U;G1E;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*
M;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(DYU<B!O8F5N(@H*
M(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L
M;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB
M"FUS9W-T<B`B(@HB1&EE(&AO8VAG96QA9&5N96X@1&%T96X@<VEN9"!N86-H
M(&1E;2!L971Z=&5N(%-C:')I='0@=F5R;&]R96X@9V5G86YG96XN(@H*(SH@
M9G)A;65W;W)K+T1A=&$O1&%T82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T
M82]$871A+W1S=BYP:'`Z,3<V"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C
M;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(D1I92!H;V-H9V5L861E;F4@
M1&%T96D@:V]N;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E;BXB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#D@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$Q,`IM<V=I9"`B5&AE('=E871H97(N8V]M(&)L;V-K
M(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D1E<B!W96%T:&5R+F-O;2!"
M;&]C:R!I<W0@;FEC:'0@=F5R9OQG8F%R+B(*"B,Z('5T:6PO:6-O;E]B<F]W
M<V5R+G!H<#HR-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER96-T
M;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(E1H96UE;BU697)Z96EC
M:&YI<R!<(B5S7"(@;FEC:'0@9V5F=6YD96XN(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ-S@*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I
M;VYS(&%V86EL86)L92XB"FUS9W-T<B`B17,@<VEN9"!K96EN92!%:6YS=&5L
M;'5N9V5N('9E<F;\9V)A<BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HS-#D*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T
M(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R(")%<R!G:6)T(&ME
M:6YE(&%N>F5I9V)A<F5N($YA8VAR:6-H=&5N=&5I;&4N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,30P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD
M+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[("(*(GEO=2!M=7-T
M(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@HB1&EE<V5S($9E;&0@
M96YT:.1L="!Z=2!V:65L92!:96EC:&5N+B!3:64@:&%B96X@)7,@6F5I8VAE
M;B!A;F=E9V5B96X[(%-I92`B"B)M_'-S96X@=V5N:6=E<B!A;',@)7,@86YG
M96)E;BXB"@HC.B!S:6=N=7`N<&AP.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG
M(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R(")"96EM($AI;GIU
M9OQG96X@=F]N(%PB)7-<(B!Z=6T@4WES=&5M(&ES="!E:6X@4')O8FQE;2!A
M=69G971R971E;CH@)7,B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D
M871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R
M("(B"B)"96EM($SV<V-H96X@9&5R($1A=&5N('9O;B!"96YU='IE<B!<(B5S
M7"(@:7-T(&5I;B!0<F]B;&5M(&%U9F=E=')E=&5N.B`B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@
M<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS
M9W-T<B`B0F5I;2!,]G-C:&5N('9O;B!<(B5S7"(@875S(&1E;2!3>7-T96T@
M:7-T(&5I;B!0<F]B;&5M(&%U9F=E=')E=&5N.B`B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O
M8FQE;2!U<&1A=&EN9R!<(B5S7"(Z("5S(@IM<V=S='(@(D)E:6T@06MT=6%L
M:7-I97)E;B!V;VX@7"(E<UPB(&ES="!E:6X@4')O8FQE;2!A=69G971R971E
M;CH@)7,B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,C4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H
M('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R
M("(B"B)"96EM($AO8VAL861E;B!D97(@1&%T96D@:7-T(&5I;B!&96AL97(@
M875F9V5T<F5T96XN("5S('=U<F1E(&YI8VAT("(*(FAO8VAG96QA9&5N+B(*
M"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDS,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE
M(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI
M;75M("(*(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B"B)"
M96EM($AO8VAL861E;B!D97(@1&%T96D@:7-T(&5I;B!&96AL97(@875F9V5T
M<F5T96XN("5S('=A<B!G<O;?97(@86QS(&1I92`B"B)M87AI;6%L(&5R;&%U
M8G1E($=R]M]E("@E9"!">71E<RDN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O
M0G)O=W-E<BYP:'`Z.3,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E
M('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W
M87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N(@IM<V=S='(@(B(*(D)E:6T@
M2&]C:&QA9&5N(&1E<B!$871E:2!I<W0@96EN($9E:&QE<B!A=69G971R971E
M;BX@)7,@=W5R9&4@;G5R('1E:6QW96ES92`B"B)H;V-H9V5L861E;BXB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A
M9V4@<&%R="(*;7-G<W1R(")"96EM($%N>F5I9V5N(&1I97-E<R!.86-H<FEC
M:'1E;G1E:6QS(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.0HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB
M"FUS9W-T<B`B0F5I;2!);7!O<G1I97)E;B!D97(@2V]N=&%K=&1A=&5N(&ES
M="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+B(*"B,Z(&9R86UE=V]R:R]$871A
M+T1A=&$O:6UC+G!H<#HS,`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(D)E:6T@26UP
M;W)T:65R96X@9&5R(&E#86QE;F1A<B!$871E;B!I<W0@96EN($9E:&QE<B!A
M=69G971R971E;BXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C@R"FUS
M9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I
M;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F
M:65L9"XB"FUS9W-T<B`B(@HB1&%S($MO;F9I9W5R871I;VYS+49O<FUU;&%R
M(&5N=&AI96QT(&5I;F5N($9E:&QE<BX@5FEE;&QE:6-H="!H86)E;B!3:64@
M96EN("(*(E!F;&EC:'1F96QD(&QE97(@9V5L87-S96XN(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@
M(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I
M960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN
M(&QA=&5R+B(*;7-G<W1R("(B"B)"96EM($%U<V;\:')E;B!D97(@86YG96=E
M8F5N96X@061R97-S8G5C:&9U;FMT:6]N(&ES="!E:6X@1F5H;&5R("(*(F%U
M9F=E=')E=&5N+B!":71T92!V97)S=6-H96X@4VEE(&5S('-PY'1E<B!N;V-H
M(&5I;FUA;"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8T,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P
M9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@
M;&%T97(N(@IM<V=S='(@(B(*(D)E:2!D97(@06MT=6%L:7-I97)U;F<@9&5R
M($MO;G1A:W1D971A:6QS(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+B!"
M:71T92`B"B)V97)S=6-H96X@4VEE(&5S('-PY'1E<B!N;V-H(&5I;FUA;"XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R
M,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D
M:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS
M9W-T<B`B(@HB0F5I(&1E<B!!:W1U86QI<VEE<G5N9R!D97(@5F5R=&5I;&5R
M;&ES=&4@:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XN($)I='1E("(*(G9E
M<G-U8VAE;B!3:64@97,@<W#D=&5R(&YO8V@@96EN;6%L+B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T.0HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR.3D*;7-G:60@(E1H:7,@
M24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N
M(@IM<V=S='(@(D1I97-E<B!)34%0+5-E<G9E<B!U;G1E<G-T_'1Z="!K96EN
M92!G96UE:6YS86UE;B!/<F1N97(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E
M87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`B1&EE<R!S
M8VAE:6YT(&ME:6X@9_QL=&EG97,@4D%2+4%R8VAI=B!Z=2!S96EN+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@
M(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N
M(@IM<V=S='(@(D1I97,@<V-H96EN="!K96EN(&?\;'1I9V5S(%I)4"U!<F-H
M:78@>G4@<V5I;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,30U
M"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D
M(&YU;6)E<BXB"FUS9W-T<B`B1&EE<R!S8VAE:6YT(&ME:6YE(&?\;'1I9V4@
M2V%R=&5N;G5M;65R('IU('-E:6XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R
M:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#
M;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL
M('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"B)$:65S97(@5')E:6)E
M<B!E<FQA=6)T(&1A<R!697)S8VAI8VME;B!V;VX@3F%C:')I8VAT96X@9'5R
M8V@@9&5N($-L:6-K871E;&PM(@HB1V%T97=A>2`H:'1T<#HO+V-L:6-K871E
M;&PN8V]M*2!M:70@2&EL9F4@9&5R($A45%`M05!)+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED("(B"B)4:&ES
M(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H
M92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y+"!U<VEN9R!T
M:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB1&EE<V5R(%1R96EB97(@97)L875B
M="!D87,@5F5R<V-H:6-K96X@=F]N($YA8VAR:6-H=&5N(&1U<F-H(&1E;B!7
M24XM1V%T97=A>2`B"B(H:'1T<#HO+W=I;G!L8RYC;VTI(&UI="!(:6QF92!D
M97(@2%144"U!4$DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU,34*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H
M:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(
M5%10($%022(*;7-G<W1R("(B"B)$:65S97(@5')E:6)E<B!E<FQA=6)T(&1A
M<R!697)S8VAI8VME;B!V;VX@3F%C:')I8VAT96X@9'5R8V@@9&5N('-M<S)M
M86EL+2(*(D=A=&5W87D@*&AT='`Z+R]S;7,R;6%I;"YC;VTI(&UI="!(:6QF
M92!D97(@2%144"U!4$DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O
M9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@
M=&AE(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O
M;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H
M("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S
M='(@(B(*(D1I97-E<B!4<F5I8F5R(&5R;&%U8G0@9&%S(%9E<G-C:&EC:V5N
M('9O;B!.86-H<FEC:'1E;B!P97(@4TU44"!D=7)C:"!D96X@(@HB5F]D869O
M;F4M271A;&EE;BU'871E=V%Y(&%U<W-C:&QI9=]L:6-H(&%N(%9O9&%F;VYE
M+4YU;6UE<FXN($1A9OQR('=I<F0@96EN("(*(D4M36%I;"U+;VYT;R!B96D@
M5F]D869O;F4@271A;&EE;B`H:'1T<#HO+W=W=RXQ.3`N:70I(&)E;O9T:6=T
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDW."!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,#4W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$P.#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Q-0HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,3@R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R-38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P-2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,SDX"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$U-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U-PHC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<V(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(P,C,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`T-R!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#DV"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q-C<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(S.0HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#(V(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(T-C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8U-2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#(X"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,Q,S<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Q-0HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#(S(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,X,S$*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N
M(@IM<V=S='(@(D1I97-E<R!&96QD(&ES="!N;W1W96YD:6<N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V-0IM<V=I9"`B5&AI<R!F:65L9"!M
M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R(")$:65S97,@1F5L
M9"!D87)F(&YU<B!G86YZ92!:86AL96X@96YT:&%L=&5N+B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(T,S0*;7-G:60@(E1H:7,@9FEE;&0@;6%Y
M(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@
M(D1I97-E<R!&96QD(&1A<F8@;G5R(%IA:&QE;B!U;F0@96EN96X@4'5N:W0@
M96YT:&%L=&5N+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.30*
M;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU
M97,N(@IM<V=S='(@(D1I97-E<R!&96QD(&1A<F8@;G5R($]K=&%L>F%H;&5N
M(&5N=&AA;'1E;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(S
M"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S
M97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B"B)$:65S97,@
M1F5L9"!M=7-S(&5I;F4@:V]M;6$M(&]D97(@;&5E<GIE:6-H96YG971R96YN
M=&4@3&ES=&4@=F]N(&=A;GIE;B`B"B):86AL96X@96YT:&%L=&5N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3@Y"FUS9VED(")4:&ES(&9I96QD
M(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@(D1I97-E<R!&96QD
M(&UU<W,@96EN92!G_&QT:6=E(%IA:&P@96YT:&%L=&5N+B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(X,S8*;7-G:60@(B(*(E1H:7,@9FEE;&0@
M;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M
M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T<B`B(@HB1&EE
M<V5S($9E;&0@;75S<R!E:6YE;B!&87)B=V5R="!I;2!H97AA9&5Z:6UA;&5N
M(%)'0BU&;W)M870@96YT:&%L=&5N+"!Z+B!"+B`B"B(G(S$R,S1A9B<N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z-38Q"FUS9VED(")4:&ES(&9O
M<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@(D1I97-E
M<R!&;W)M=6QA<B!W=7)D92!B97)E:71S('9E<F%R8F5I=&5T+B(*"B,Z('1E
M;7!L871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H:7,@:7,@)7,N(@IM<V=S='(@(D1I97,@:7-T("5S+B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#DU"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W
M('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT
M('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N
M($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V
M:7-I="`E<R(*;7-G<W1R("(B"B)$:64@:7-T(&5I;B!+;VQA8BU'<F]U<'=A
M<F4M3V)J96MT+B!5;2!D:65S97,@3V)J96MT(&%N>G5Z96EG96XL(&)E;O9T
M:6=E;B`B"B)3:64@96EN($4M36%I;"U0<F]G<F%M;2P@9&%S(&1A<R!+;VQA
M8BU'<F]U<'=A<F4M1F]R;6%T('5N=&5R<W3\='IT+B!%:6YE("(*(DQI<W1E
M('-O;&-H97(@4')O9W)A;6UE(&9I;F1E;B!3:64@=6YT97(@)7,B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA
M<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@
M(B(*(D1I97-E($YA8VAR:6-H="!W=7)D92!I;B!E:6YE;2!:96EC:&5N<V%T
M>B`H)7,I(&5R<W1E;&QT+"!D97(@;FEC:'0@26AR96T@(@HB96EG96YE;B!E
M;G1S<')I8VAT+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB
M"FUS9W-T<B`B1&EE<V4@6F%H;"!M=7-S(#$@;V1E<B!G<O;?97(@<V5I;BXB
M"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*
M;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G
M>FEP(&9I;&5S+B(*;7-G<W1R(")$:65S97(@4V5R=F5R(&MA;FX@6DE0+2!U
M;F0@1UI)4"U$871E:6X@;FEC:'0@96YT<&%C:V5N+B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3@V"FUS9VED(")4:&ES('-Y
M<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(D1I97-E
M<R!3>7-T96T@:7-T('IU<B!:96ET(&1E86MT:79I97)T+B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E
M(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(D1I97-E<B!797)T(&UU<W,@
M96EN92!:86AL('-E:6XN(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC
M:V5R+G!H<#HS-0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@
M9G)O;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R(")$:65S97,@1F5N<W1E
M<B!M=7-S('9O;B!E:6YE;2!%:6YS=&5L;'5N9V5N+49E;G-T97(@9V7V9F9N
M970@=V5R9&5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C@*;7-G:60@(E1H=6YD97(B"FUS9W-T<B`B1&]N;F5R(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S-@IM<V=I9"`B5&EC:V5T<R(*
M;7-G<W1R(")4:6-K971S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C0T,R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-3<*;7-G:60@(E1I
M;64B"FUS9W-T<B`B6F5I="(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS.#@*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS9W-T<B`B6F5I=&5R9F%S
M<W5N9R(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM92!F
M;W)M870B"FUS9W-T<B`B6F5I=&9O<FUA="(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(U-#D*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@
M(EIE:71A=7-W86AL(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S
M=&4B"FUS9W-T<B`B5&EM;W(M3&5S=&4B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP
M.C(P"FUS9VED(")4:71L92(*;7-G<W1R(")4:71E;"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE
M("AT;V]L=&EP*3HB"FUS9W-T<B`B5&ET96P@*%1O;VQT:7`I.B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@
M(E1O(@IM<V=S='(@(D%N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C8U-`IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE
M(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD
M("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B(@HB2&%L
M=&5N(%-I92!B96EM($ML:6-K96X@4W1R9R!B>G<N("A00RD@0V]M;6%N9"`H
M36%C*2!G961R_&-K="P@=6T@;65H<F5R92`B"B)%:6YT<N1G92!A=7-Z=7?D
M:&QE;BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P"FUS
M9VED(")4;V1A>2(*;7-G<W1R(")(975T92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,
M(%-O=7)C92(*;7-G<W1R("):=2!(5$U,+5%U96QL8V]D92!U;7-C:&%L=&5N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&]G;R(*;7-G<W1R(")4;V=O(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA=2(*;7-G<W1R(")4;VME;&%U
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,@IM<V=I9"`B
M5&]M;W)R;W<B"FUS9W-T<B`B36]R9V5N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I
M9"`B5&]N9V$B"FUS9W-T<B`B5&]N9V$B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VMO;&%B+G!H<#HQ,#0*;7-G:60@(E1O;R!M86YY(&EN=F%L:60@;&]G
M:6YS(&1U<FEN9R!T:&4@;&%S="!M:6YU=&5S+B(*;7-G<W1R("):=2!V:65L
M92!U;F?\;'1I9V4@06YM96QD979E<G-U8VAE(&EN(&1E;B!L971Z=&5N($UI
M;G5T96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<W"FUS9VED(")4;W`B"FUS9W-T<B`B3V)E;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@
M(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`BQ'7?97)S=&5R(%)A:&UE;B`H
M7W1O<"DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R
M86YS;&%T:6]N<R(*;7-G<W1R("+<8F5R<V5T>G5N9V5N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,0IM<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G<W1R(")4<FEN
M:61A9"!U;F0@5&]B86=O(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3<Y,`IM<V=I9"`B5')U92!O<B!F86QS92(*;7-G<W1R(")786AR(&]D97(@
M9F%L<V-H(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T<B`B1&DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P
M"FUS9VED(")4=6YI<VEA(@IM<V=S='(@(E1U;F5S:65N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(E3\<FME:2(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY
M*2(*;7-G<W1R(")4_')K:7-C:"`H25-/+3@X-3DM.2DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$P"FUS9VED(")4=7)K;65N:7-T86XB"FUS9W-T<B`B5'5R:VUE;FES=&%N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)<VQA
M;F1S(@IM<V=S='(@(E1U<FMS+2!U;F0@0V%I8V]S:6YS96QN(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,0IM<V=I9"`B5'5V86QU(@IM<V=S='(@(E1U=F%L=2(*"B,Z(&9R
M86UE=V]R:R]#3$DO0TQ)+G!H<#HR-S,*;7-G:60@(E1Y<&4@>6]U<B!C:&]I
M8V4Z("(*;7-G<W1R(")):')E($%U<W=A:&PZ("(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-3@*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G
M<W1R(")55BU);F1E>#H@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM<V=I
M9"`B55),(@IM<V=S='(@(DAO;65P86=E(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@
M>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R(")5
M4DP@26AR97,@4VMR:7!T<R!F_'(@9&5N(%9E<G-A;F1S=&%T=7-B97)I8VAT
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M-PIM<V=I9"`B55),.B(*;7-G<W1R(")!9')E<W-E.B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3(*;7-G:60@(E5G86YD82(*;7-G<W1R(")59V%N9&$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$R"FUS9VED(")5:W)A:6YE(@IM<V=S='(@(E5K<F%I;F4B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,C@*;7-G:60@(E5N86)L92!T;R!A
M8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B075F(&1A<R!61E,M5F5R
M>F5I8VAN:7,@:V]N;G1E(&YI8VAT('IU9V5G<FEF9F5N('=E<F1E;BXB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N
M86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI
M;F<@=7`N(@IM<V=S='(@(B(*(D1I92!Z=7/D='IL:6-H96X@0F5N=71Z97)I
M;F9O<FUA=&EO;F5N(&MO;FYT96X@8F5I(&1E<B!296=I<W1R:65R=6YG(&YI
M8VAT("(*(FAI;GIU9OQG="!W97)D96XN(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HS.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S
M='(@(B(*(D1I92!:=6=R:69F<W)E8VAT92!F_'(@9&EE(%9&4RU$871E:2!<
M(B5S7"(@:V]N;G1E;B!N:6-H="!G9>1N9&5R="!W97)D96XN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#`Q(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HT-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T
M<B`B(@HB1&EE(%IU9W)I9F9S<F5C:'1E(&;\<B!D:64@5D93+41A=&5I("5S
M+R5S(&MO;FYT96X@;FEC:'0@9V7D;F1E<G0@=V5R9&5N+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z-SDX"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@(D5S(&MA;FX@;FEC
M:'0@:6X@5F5R>F5I8VAN:7,@)7,@9V5W96-H<V5L="!W97)D96XN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HY-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7-<(BXB"FUS
M9W-T<B`B1&EE($=R]M]E('9O;B!<(B5S7"(@:V]N;G1E(&YI8VAT(&)E<W1I
M;6UT('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV
M-2!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.CDT"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HV-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T
M<B`B1&EE($=R]M]E('9O;B!<(B5S+R5S7"(@:V]N;G1E(&YI8VAT(&)E<W1I
M;6UT('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z
M-#,Y"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+B(*
M;7-G<W1R(")697)B:6YD=6YG('IU;2!344P@4V5R=F5R(&MA;FX@;FEC:'0@
M:&5R9V5S=&5L;'0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z.#@R"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB
M"FUS9W-T<B`B4U-,+59E<F)I;F1U;F<@:V]N;G1E(&YI8VAT(&AE<F=E<W1E
M;&QT('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR
M-#$@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C0V"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,S,@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C(S.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,C0V"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS
M9W-T<B`B1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@:V]P:65R="!W97)D
M96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y
M(%PB)7-<(BXB"FUS9W-T<B`B1&%S(%9&4RU697)Z96EC:&YI<R!<(B5S7"(@
M:V]N;G1E(&YI8VAT(&%N9V5L96=T('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HS-S`@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C(V.0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,CDS
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(D1A<R!61E,M5F5R>F5I8VAN:7,@:V]N;G1E(&YI8VAT(&%N9V5L96=T
M('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3(S
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R(")$
M:64@5D93+41A=&5I(&MO;FYT92!N:6-H="!A;F=E;&5G="!W97)D96XN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HS,#,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R(%PB)7-<(BXB
M"FUS9W-T<B`B1&%S(%9&4RU697)Z96EC:&YI<R!<(B5S7"(@:V]N;G1E(&YI
M8VAT(&%N9V5L96=T('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HR.#$*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93
M(&9I;&4N(@IM<V=S='(@(DQE97)E(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@
M86YG96QE9W0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]T87(N<&AP.C<U"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]G>FEP+G!H<#HU,@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M9WII<"YP:'`Z.#(*;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N
M(@IM<V=S='(@(D1I92!$871E;B!K;VYN=&5N(&YI8VAT(&1E:V]M<')I;6EE
M<G0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C,Q
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S`R"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y
M(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B7"(E<UPB(&MO;FYT92!N:6-H="!G
M96SV<V-H="!W97)D96XL(&1A<R!697)Z96EC:&YI<R!I<W0@;FEC:'0@;&5E
M<BXB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D;6EN+W!E<FUS+V1E;&5T
M92YP:'`Z-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!<(B5S7"(Z("5S+B(*;7-G<W1R(")<(B5S7"(@:V%N;B!N:6-H="!G96SV
M<V-H="!W97)D96XZ("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C,T-R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0U,`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S(R(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HS.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS
M9W-T<B`B)7,@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;BP@9&%S(%9E
M<GIE:6-H;FES(&ES="!N:6-H="!L965R(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C0P,R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z-#`W"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O
M<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(D1A<R!61E,M5F5R>F5I8VAN:7,@
M:V]N;G1E(&YI8VAT(')E:W5R<VEV(&=E;/9S8VAT('=E<F1E;BXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-3,@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C,S,PHC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,S0V(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS-30*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,Y.0IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")$87,@5D93+59E
M<GIE:6-H;FES(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT-S4@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HT.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B1&%S(%9&4RU6
M97)Z96EC:&YI<R!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N.B`E<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(S-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB
M"FUS9W-T<B`B1&EE(%9&4RU$871E:2!<(B5S7"(@:V]N;G1E(&YI8VAT(&=E
M;/9S8VAT('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HS,3D@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,S0*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C$V-B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,3<Y"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ
M.#8@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C0S.`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-#0V"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R(")$:64@5D93+41A=&5I(&MO
M;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HR-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B1&%S(%9&
M4RU697)Z96EC:&YI<R!<(B5S7"(@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E
M<F1E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0V-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I
M=F5L>3H@)7,N(@IM<V=S='(@(D1A<R!61E,@:V]N;G1E(&YI8VAT(')E:W5R
M<VEV(&=E;/9S8VAT('=E<F1E;CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HX-#8*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@8W5R
M<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(D1A<R!A:W1U96QL92!697)Z96EC
M:&YI<R!K;VYN=&4@;FEC:'0@8F5S=&EM;70@=V5R9&5N+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C`T"FUS9VED(")5;F%B;&4@
M=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM<V=S='(@(D1I92!:
M97)T:69I:V%T9&5T86EL<R!K;VYN=&5N(&YI8VAT(&%U<V=E;&5S96X@=V5R
M9&5N(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`N<&AP.C0S-R!F<F%M
M97=O<FLO3F5T7TE-4U`O24U34"]!=71H+G!H<#HQ,C,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N
M(@IM<V=S='(@(D1E<B`E<RU4<F5I8F5R(&MO;FYT92!N:6-H="!G96QA9&5N
M('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,3$@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C$V"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HQ.3@@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C(P,PIM<V=I9"`B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N
M(@IM<V=S='(@(D1I92!61E,M1&%T96D@:V]N;G1E(&YI8VAT('9E<G-C:&]B
M96X@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z.3,@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ,#8*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HV-S0@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ
M,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R(")$:64@5D93+41A=&5I(%PB)7-<(B!K;VYN
M=&4@;FEC:'0@9V7V9F9N970@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C(Y,R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,34W"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-C`*
M;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*
M;7-G<W1R(")$:64@5D93+41A=&5I(&MO;FYT92!N:6-H="!Z=6T@0F5S8VAR
M96EB96X@9V7V9F9N970@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C@V(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$T,`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z.34*;7-G:60@(E5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R(")$:64@5D93+41A=&5I
M(&MO;FYT92!N:6-H="!G9?9F9FYE="!W97)D96XN(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HT-0IM<V=I9"`B56YA8FQE('1O
M(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R(")$87,@07)C:&EV
M(&MO;FYT92!N:6-H="!G9?9F9FYE="!W97)D96XN(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C@T,PIM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I
M;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B1&EE(%9&4RU$871E
M:2!K;VYN=&4@;FEC:'0@9V5L97-E;B!W97)D96X@*&9I;&5S:7IE*"D@9F5H
M;&=E<V-H;&%G96XI+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-S@*
M;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AS:7IE*"D@9F%I;&5D
M*2XB"FUS9W-T<B`B1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@9V5L97-E
M;B!W97)D96X@*'-I>F4H*2!F96AL9V5S8VAL86=E;BDN(@H*(SH@9G)A;65W
M;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X
M"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`B1&EE($1A
M=&5I(&MO;FYT92!N:6-H="!G96QE<V5N('=E<F1E;CH@(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z-CDQ"FUS9VED(")5;F%B;&4@=&\@<F5A
M9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(D1A<R!V9G-R;V]T
M+59E<GIE:6-H;FES(&MO;FYT92!N:6-H="!G96QE<V5N('=E<F1E;BXB"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q-#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I
M;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*(B5S(&MO;FYT
M92!N:6-H="!N86-H("5S('5M8F5N86YN="!W97)D96XZ($1A<R!::65L=F5R
M>F5I8VAN:7,@97AI<W1I97)T("(*(F)E<F5I=',B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0R"FUS9VED(")5;F%B;&4@=&\@<F5N
M86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(D1A<R!61E,M5F5R>F5I8VAN
M:7,@:V]N;G1E(&YI8VAT('5M8F5N86YN="!W97)D96XN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HS.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B
M1&%S(%9&4RU697)Z96EC:&YI<R!K;VYN=&4@;FEC:'0@=6UB96YA;FYT('=E
M<F1E;CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR.#`@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S
M='(@(D1I92!61E,M1&%T96D@7"(E<UPB(&MO;FYT92!N:6-H="!U;6)E;F%N
M;G0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8S
M,B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C0P"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N(@IM
M<V=S='(@(D1I92!61E,M1&%T96D@)7,O)7,@:V]N;G1E(&YI8VAT('5M8F5N
M86YN="!W97)D96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS
M.#$@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(Q,@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#8S(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HS,S0*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C,U-@IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS
M9W-T<B`B1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@=6UB96YA;FYT('=E
M<F1E;BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M;6MI<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G
M+B(*;7-G<W1R(")<(FUK:7-O9G-<(B!K;VYN=&4@;FEC:'0@875S9V5F_&AR
M="!W97)D96XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W
M;W)D+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O
M<F0@9&]C=6UE;G0B"FUS9W-T<B`B1&EE<V5S(%=O<F0M1&]K=6UE;G0@;.1S
M<W0@<VEC:"!N:6-H="!A;GIE:6=E;B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,3@S,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M=')I9V=E<B!F<F5E+V)U<WD@=7!D871E(&9O<B`E<R(*;7-G<W1R("(B"B)$
M:64@1G)E:2]'96)U8VAT+4EN9F]R;6%T:6]N96X@9OQR("5S(&MO;FYT96X@
M;FEC:'0@86MT=6%L:7-I97)T('=E<F1E;B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,3<X(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,3@Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL
M92!<(B5S7"(N(@IM<V=S='(@(D1I92!61E,M1&%T96D@7"(E<UPB(&MO;FYT
M92!N:6-H="!G97-P96EC:&5R="!W97)D96XN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,3@Y"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R(")$:64@5D93+41A=&5I
M(&MO;FYT92!N:6-H="!G97-C:')I96)E;B!W97)D96X@*&-O<'DH*2!F96AL
M9V5S8VAL86=E;BDN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,CDW(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-C4*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$W,`IM<V=I9"`B56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@(D1I92!61E,M1&%T
M96X@:V]N;G1E;B!N:6-H="!G97-C:')I96)E;B!W97)D96XN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C@U,PIM<V=I9"`B56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(*;7-G<W1R("(B
M"B)$:64@5D93+41A=&5I(&MO;FYT92!N:6-H="!G97-C:')I96)E;B!W97)D
M96XL(&1A<R!3<&5I8VAE<G!L871Z+4MO;G1I;F=E;G0@(@HB=_QR9&4@_&)E
M<G-C:')I='1E;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`B56YT97)S
M=')I8VAE;B(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@
M(E5N9&\@0VAA;F=E<R(*;7-G<W1R("+$;F1E<G5N9V5N('+\8VMGY&YG:6<@
M;6%C:&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T
M<B`B36%C:'0@9&EE(&QE='IT92!!:W1I;VX@<OQC:V?D;F=I9R(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R.`HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HT,C<*;7-G:60@(E5N
M97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@
M(@IM<V=S='(@(E5N9_QL=&EG92!2_&-K;65L9'5N9R!V;VT@4V5R=F5R(&)E
M:6T@2&5R<W1E;&QE;B!D97(@5F5R8FEN9'5N9SH@(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(T"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W.`HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HT,34*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z-#(Q"FUS9VED(")5;F5X<&5C=&5D(')E
M<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B56YE<G=A<G1E=&4@
M06YT=V]R="!D97,@4V5R=F5R<R!A=68Z("(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q"FUS9VED(")5;F9I;&5D
M(@IM<V=S='(@(DYI8VAT('IU9V5O<F1N970B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y-@IM<V=I9"`B56YI8V]D92`H551&+3@I(@IM<V=S='(@(E5N
M:6-O9&4@*%541BTX*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")5;FET960@07)A
M8B!%;6ER871E<R(*;7-G<W1R(")697)E:6YI9W1E($%R86)I<V-H92!%;6ER
M871E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")5;FET960@2VEN9V1O;2(*;7-G
M<W1R(")697)E:6YI9W1E<R!+]FYI9W)E:6-H(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM
M<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R(")697)E:6YI9W1E(%-T86%T
M96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R
M($]U=&QY:6YG($ES;&%N9',B"FUS9W-T<B`B2VQE:6YE<F4@06UE<FEK86YI
M<V-H92#<8F5R<V5E:6YS96QN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C8R(&QI8B]";&]C:R]M971A<BYP:'`Z-S@*;7-G:60@(E5N:71S
M(@IM<V=S='(@(D5I;FAE:71E;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0R.2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,S`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HU.`IM
M<V=I9"`B56YK;F]W;B(*;7-G<W1R(")5;F)E:V%N;G0B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@
M(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B
M56YB96MA;FYT92!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM
M<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*
M;7-G<W1R(")5;F)E:V%N;G1E(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)
M1"DN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T-PIM<V=I
M9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B17,@=W5R
M9&4@96EN('5N8F5K86YN=&5R($]R="!A;F=E9V5B96XN(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED
M(")5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R(")5;F)E
M:V%N;G1E<B!"96YU='IE<FYA;64@;V1E<B!087-S=V]R="XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*
M;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(DQI
M;FL@=F]M(&%K='5E;&QE;B!%;&5M96YT(&5N=&9E<FYE;B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R])9&5N=&ET>2YP:'`Z,S`T"FUS9VED(")5;FYA;65D(@IM
M<V=S='(@(E5N8F5N86YN="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL96=E9"!S8W)I
M<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A
M;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E
M(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB<VAO
M=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L
M:7!B;V%R9"XB"FUS9W-T<B`B(@HB075S(%-I8VAE<FAE:71S9W+\;F1E;B!D
M_')F96X@=6YA=71O<FES:65R=&4@4VMR:7!T92!N:6-H="!A=7-C:&YE:61E
M;BP@(@HB:V]P:65R96X@=6YD(&5I;F;\9V5N+B!+;&EC:V5N(%-I92!A=68@
M3TLL('5M(&5I;F5N($AI;G=E:7,@875F(&UO>FEL;&$N;W)G("(*(F%N9V5Z
M96EG="!Z=2!B96MO;6UE;BP@9&5R(&)E<V-H<F5I8G0L('=I92!3:64@96EN
M96T@4VMR:7!T(&1E;B!:=6=R:69F(&%U9B`B"B)D:64@6G=I<V-H96YA8FQA
M9V4@97)L875B96X@:_9N;F5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R
M(@IM<V=S='(@(D9A<F)E('IU<OQC:W-E='IE;B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C@W(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z.3(W"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z.3,S"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T
M<B`B17)W96ET97)U;F<@;FEC:'0@=6YT97)S=/QT>G0B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$Y-R!T96UP;&%T97,O861M:6XO=7-E
M<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D871E(@IM<V=S='(@(D%K='5A;&ES
M:65R=6YG(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHR
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B)7,@
M86MT=6%L:7-I97)E;B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z-S8*;7-G:60@(E5P9&%T92!U<V5R(@IM<V=S='(@(D)E;G5T>F5R
M(&%K='5A;&ES:65R96XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$T-"!A9&UI
M;B]P97)M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP
M.C(S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS
M9W-T<B`B7"(E<UPB('=U<F1E(&%K='5A;&ES:65R="XB"@HC.B!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HX,PIM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L
M971E9"XB"FUS9W-T<B`B06MT=6%L:7-I97)U;F=S<VMR:7!T(&=E;/9S8VAT
M+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S<@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y.`IM<V=I9"`B57!L;V%D(@IM
M<V=S='(@(DAO8VAL861E;B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M.#4*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE
M<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R("(B"B)$:64@2V]N9FEG=7)A=&EO
M;G-D871E:65N(&%L;&5R($%N=V5N9'5N9V5N('=U<F1E;B!A=68@9&5N(%-E
M<G9E<B`B"B)H;V-H9V5L861E;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(P"FUS9VED(")5<'!E<B!L
M871I;B!L971T97)S(@IM<V=S='(@(D=R+B!L871E:6YI<V-H92!"=6-H<W1A
M8F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G
M<W1R(")'<BX@<O9M:7-C:&4@6F%H;&5N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I
M9"`B57)U9W5A>2(*;7-G<W1R(")5<G5G=6%Y(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(D%K='5E;&QE(&)E
M;G5T>F5N.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(E-33"!B
M96YU='IE;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C<*;7-G:60@
M(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S
M97)V97(N(@IM<V=S='(@(B(*(D)I='1E(&%U<V;\;&QE;BP@=V5N;B!3:64@
M96EN96X@86YD97)E;B!"96YU='IE<FYA;65N+U!A<W-W;W)T(&;\<B!D96X@
M24U34"TB"B)397)V97(@:&%B96XN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]E9&ET+FEN8SHR,0IM<V=I9"`B57-E<B(*;7-G<W1R(")"96YU='IE
M<B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S<Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES
M960@9F]R("5S+B(*;7-G<W1R(")"96YU='IE<B`E<R!I<W0@9OQR("5S(&YI
M8VAT(&%U=&]R:7-I97)T+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PIM<V=I
M9"`B57-E<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")"96YU='IE<G9E<G=A
M;'1U;F<B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(T-0IM
M<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(D)E;G5T>F5R96EN<W1E;&QU
M;F=E;B(*"B,Z('-I9VYU<"YP:'`Z-C(*;7-G:60@(E5S97(@4F5G:7-T<F%T
M:6]N(@IM<V=S='(@(D)E;G5T>F5R<F5G:7-T<FEE<G5N9R(*"B,Z('-I9VYU
M<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I
M<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(D1I92!"96YU='IE<G)E
M9VES=')I97)U;F<@=W5R9&4@875F(&1I97-E;2!3>7-T96T@9&5A:W1I=FEE
M<G0N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0Y-`IM<V=I9"`B57-E
M<B!A8V-O=6YT(&YO="!F;W5N9"(*;7-G<W1R(")"96YU='IE<FMO;G1O(&YI
M8VAT(&=E9G5N9&5N(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$W.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=F]D869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3`@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z,S0*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,B!T
M96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E
M<FYA;64B"FUS9W-T<B`B0F5N=71Z97)N86UE(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]3:6=N=7`N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M<V5R;F%M92!<(B5S7"(@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(D1E<B!"
M96YU='IE<FYA;64@7"(E<UPB(&5X:7-T:65R="!B97)E:71S+B(*"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PIM<V=I9"`B57-E<FYA;64Z
M(@IM<V=S='(@(D)E;G5T>F5R;F%M93HB"@HC.B!T96UP;&%T97,O;&]G:6XO
M;6]B:6QE+FEN8SHX"FUS9VED(")5<V5R;F%M93H@(@IM<V=S='(@(D)E;G5T
M>F5R;F%M93H@(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`B0F5N=71Z
M97(@9&5S(%-Y<W1E;7,Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B57IB96MI
M<W1A;B(*;7-G<W1R(")5<V)E:VES=&%N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,3<S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(W
M,0IM<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T
M<B`B1&%S(%9&4RU697)Z96EC:&YI<R!E>&ES=&EE<G0@;FEC:'0N(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$R,`IM<V=I9"`B5F%C871I;VXB
M"FUS9W-T<B`B06)W97-E;FAE:70B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HX-C8*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E
M.B`B"FUS9W-T<B`B4&%S<V5N9&4@9V5F=6YD96YE($]R=&4Z("(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(")686QI
M9&ET>2(*;7-G<W1R(")'_&QT:6=K96ET(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.3<*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U"FUS9VED(")686QU
M92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R(")797)T(&EN($UI;G5T
M96X@=F]N(&IE='IT(&%N+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C@U-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3<W"B,L('!H<"UF;W)M
M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F
M("5S+B(*;7-G<W1R(")$97(@5V5R="!I<W0@_&)E<B!D97(@;6%X:6UA;&5N
M($SD;F=E('9O;B`E<RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,C8R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R.#0*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C,S-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.3(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z
M-3D*;7-G:60@(E9A;'5E<R(*;7-G<W1R(")797)T92(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Q,C<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C(P-`IM<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(E=E
M<G1E+"!A=7,@9&5N96X@875S9V5WY&AL="!W97)D96X@:V%N;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3<*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B5F%N=6%T=2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S,*;7-G:60@(E9A<FEA
M8FQE(@IM<V=S='(@(D1R96AE;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")6
M96YE>G5E;&$B"FUS9W-T<B`B5F5N97IU96QA(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F
M86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W
M:71H+B(*;7-G<W1R("(B"B+<8F5R<'+\9G5N9R!F96AL9V5S8VAL86=E;B`M
M(&1I97-E($YA8VAR:6-H="!K]FYN=&4@;6%N:7!U;&EE<G0@=V]R9&5N('-E
M:6XN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#$*
M;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`B5F5R<VEO;B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR,C@*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*
M;7-G<W1R(")697)S:6]N<VMO;G1R;VQL92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I
M8V%L(&%L:6=N(@IM<V=S='(@(D%U<W)I8VAT=6YG(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC
M86P@<&%D9&EN9R(*;7-G<W1R(")697)T:6MA;&5R($EN;F5N86)S=&%N9"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*
M;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R(")697)T:6MA;#HB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW-`IM<V=I9"`B5F5R
M>2!(:6=H(@IM<V=S='(@(E-E:'(@2&]C:"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G
M:60@(E9I970@3F%M(@IM<V=S='(@(E9I971N86TB"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$Y-PIM<V=I9"`B5FEE=&YA;65S92`H5DE30TE)*2(*;7-G
M<W1R(")6:65T;F%M97-I<V-H("A625-#24DI(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]#;VYT96YT<RYP:'`Z.3<Q"B,L('!H<"UF;W)M870*;7-G:60@
M(E9I97<@)7,B"FUS9W-T<B`B)7,@86YZ96EG96XB"@HC.B!L:6(O0FQO8VLO
M:69R86UE+G!H<#HS"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E
M(@IM<V=S='(@(D5I;F4@97AT97)N92!796)S96ET92!A;GIE:6=E;B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@(D%N>F5I9V5N(&%L
M<R`E<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"
M<FET:7-H(@IM<V=S='(@(D)R:71I<V-H92!*=6YG9F5R;FEN<V5L;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S
M='(@(D%M97)I:V%N:7-C:&4@2G5N9V9E<FYI;G-E;&XB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(Q,0IM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R(")3
M:6-H="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3(*;7-G
M:60@(E9I<VEB:6QI='DZ("(*;7-G<W1R(")3:6-H=#H@(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*;7-G
M:60@(E9O9&%F;VYE($ET86QY('9I82!33510(@IM<V=S='(@(E9O9&%F;VYE
M($ET86QI96X@<&5R(%--5%`B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS9VED(")7
M05).(@IM<V=S='(@(E=!4DY53D<B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'(2$A(%)%34]6
M12!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B5T%23E5.1R$A
M(2!,UE-#2$5.(%-)12!$05,@4TM225!4($U!3E5%3$P@0553("5S+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS9VED
M(")724X@=FEA($A45%`B"FUS9W-T<B`B5TE.(/QB97(@2%144"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3<*;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(E=A
M;&QI<R!U;F0@1G5T=6YA(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].
M;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,C<@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.CDU"FUS9VED(")787)N:6YG(@IM<V=S='(@(E=A<FYU;F<B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X
M"FUS9VED(")792(*;7-G<W1R(")-:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R
M(")7971T97)V;W)H97)S86=E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C0Q-@IM<V=I9"`B5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM
M<V=S='(@(E=E='1E<F1A=&5N('9O;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@Y,@IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B5V5A=&AE
M<BYC;VTB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B
M(@IM<V=S='(@(E=E8B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M,SD*;7-G:60@(E=E8B!3:71E(@IM<V=S='(@(E=E8G-I=&4B"@HC.B!F<F%M
M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4X"FUS9VED(")7
M965K;'DB"FUS9W-T<B`B5_9C:&5N=&QI8V@B"@HC.B!S97)V:6-E<R]P;W)T
M86PO;6]B:6QE+G!H<#HR.`IM<V=I9"`B5V5L8V]M92(*;7-G<W1R(")7:6QL
M:V]M;65N(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z-"!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W"B,L('!H<"UF;W)M870*;7-G:60@
M(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B5VEL;&MO;6UE;B!B96D@)7,B"@HC
M.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R
M=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@
M)7,B"FUS9W-T<B`B5VEL;&MO;6UE;BP@)7,B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y.`IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T
M<B`B5V5S=&5U<F]PY&ES8V@@*$E33RTX.#4Y+3$I(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.3D*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*
M;7-G<W1R(")797-T975R;W#D:7-C:"`H25-/+3@X-3DM,34I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(E=E<W1S86AA
M<F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,T"B,L('!H<"UF;W)M
M870*;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@
M869T97(@;&]G:6X_(@IM<V=S='(@(E=E;&-H92!!;G=E;F1U;F<@<V]L;"`E
M<R!N86-H(&1E;2!!;FUE;&1E;B!A;F=E>F5I9V5N/R(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T(&ES('1H92!D96QI
M;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R(")796QC:&5S(%1R96YN>F5I8VAE
M;B!W:7)D('9E<G=E;F1E=#\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*
M;7-G<W1R(")796QC:&4@06YF_&AR=6YG<WIE:6-H96X@=V5R9&5N('9E<G=E
M;F1E=#\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3`V-0IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S='(@
M(E=H97)E:7,M075S=')A;&EA+4MA<G1E(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B5V5L8VAE(%!H
M87-E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S8*;7-G:60@(E=H
M:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O
M<BXB"FUS9W-T<B`B5V5L8VAE(%!L=6=I;G,@9OQR(&1E;B!765-)5UE'+45D
M:71O<B!S;VQL96X@86MT:79I97)T('=E<F1E;C\B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED(")7
M:61T:"(*;7-G<W1R(")"<F5I=&4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,3(U"FUS9VED(")7:61T:"!I;B!#4U,@=6YI=',B"FUS9W-T<B`B
M0G)E:71E(&EN($-34RU%:6YH96ET96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S4T"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H92`E
M<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M
M:6XI.B(*;7-G<W1R(")"<F5I=&4@9&5S("5S+4UE;OQS(&QI;FMS("AW:7)K
M<V%M(&YA8V@@9&5R(&[D8VAS=&5N($%N;65L9'5N9RDZ(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I
M9'1H(&]F('1H92!T86)L92(*;7-G<W1R(")486)E;&QE;F)R96ET92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS
M9VED(")7:61T:"!U;FET(@IM<V=S='(@(D5I;FAE:70B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0IM<V=I9"`B5VED
M=&@Z(@IM<V=S='(@(D)R96ET93HB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-3$U"FUS9VED(")7:6MI(@IM<V=S='(@(E=I:VDB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Y(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"FUS9VED(")7:6YD(@IM<V=S='(@(E=I
M;F0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW
M,`IM<V=I9"`B5VEN9"!%87)L>2(*;7-G<W1R(")&<OQH(%=I;F0B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C@W"FUS9VED(")7:6YD('-P965D(&EN(&MN
M;W1S(@IM<V=S='(@(E=I;F1G97-C:'=I;F1I9W1K96ET(&EN($MN;W1E;B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34X"FUS9VED(")7:6YD.B(*;7-G
M<W1R(")7:6YD.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,S$*;7-G:60@(E=I;F0Z("(*;7-G<W1R(")7:6YD.B`B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@(E=I<V1O;2(*;7-G<W1R(")796ES
M:&5I="(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.3@*;7-G:60@
M(E=I<VAL:7-T(@IM<V=S='(@(E=U;G-C:'IE='1E;"(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R(")!<F)E:70B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*
M;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R(")!9')E<W-E(&=E<V-HY&9T
M;&EC:"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ.3(*;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`B5&5L969O;B!G97-C
M:.1F=&QI8V@B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ.3,@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,CDT"B,L('!H<"UF;W)M870*
M;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP
M96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R(")&86QS8VAE($%N>F%H;"!A
M;B!&96QD97)N(&EN(%IE:6QE("5D+B`E9"!E<G=A<G1E="P@)60@9V5F=6YD
M96XN(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S,R"B,L('!H
M<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C
M=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B1F%L<V-H92!!;GIA:&P@86X@
M1F5L9&5R;BX@)60@97)W87)T970L("5D(&=E9G5N9&5N+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*
M;7-G<W1R(")5;F?\;'1I9V5R($]F9G-E="`E9"!B96EM($QE<V5N(&1E<B!6
M1E,M1&%T96DN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T-0IM
M<V=I9"`B6"U2968B"FUS9W-T<B`B475E<G9E<G=E:7-E(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!"
M87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R(")8-3`Y=C,@1V5N97)E;&QE($5I
M;G-C:'+D;FMU;F<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4Y,PIM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME>2!5<V%G92(*;7-G
M<W1R(")8-3`Y=C,@17)W96ET97)T97(@4V-H;/QS<V5L>G=E8VLB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P
M.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R(")8-3`Y=C,@
M06QT97)N871I=F5R($YA;64@9&5S(%IE<G1I9FEK871I;FAA8F5R<R(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")8
M-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R(")8-3`Y=C,@
M261E;G1I=.1T(&1E<R!:97)T:69I:V%T<V-H;/QS<V5L<R(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@S"FUS9VED(")8-3`Y=C,@
M97AT96YS:6]N<R(*;7-G<W1R(")8-3`Y=C,@17)W96ET97)U;F=E;B(*"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R(")*2B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,30*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-@IM
M<V=I9"`B65E962(*;7-G<W1R(")*2DI*(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,3$*;7-G:60@(EEA:&]O(2!M87`B
M"FUS9W-T<B`B66%H;V\A($MA<G1E(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA
M;F-E+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@
M(DKD:')L:6-H(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B665M96XB"FUS9W-T
M<B`B2F5M96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.38V"FUS9VED(")997,B"FUS9W-T<B`B2F$B"@HC.B!T96UP;&%T
M97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM<V=I9"`B665S
M+"!)($%G<F5E(@IM<V=S='(@(DIA+"!I8V@@<W1I;6UE('IU(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B
M66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O
M('-W:71C:"!B86-K('1O(%=94TE764<N(@IM<V=S='(@(B(*(E-I92!B969I
M;F1E;B!S:6-H(&EM(%1E>'1M;V1U<RX@0F5N=71Z96X@4VEE(&1E;B!;/#Y=
M($MN;W!F+"!U;2!I;B!D96X@(@HB5UE325=)1RU-;V1U<R!Z=2!W96-H<V5L
M;BXB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.C(S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO
M=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G<W1R(")3
M:64@9/QR9F5N(&YI8VAT(&UE:'(@86QS("5D($)L]F-K92!E<G-T96QL96XN
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#$U"FUS9VED(")9
M;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R(")3:64@<VEN9"!N
M:6-H="!A;F=E;65L9&5T+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R])9&5N=&ET
M>2YP:'`Z,S$P"FUS9VED(")9;W4@8V%N;F]T(&AA=F4@=&AE("=<7"<@8VAA
M<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*;7-G<W1R(")3:64@9/QR9F5N
M(&1A<R!:96EC:&5N("=<7"<@;FEC:'0@:6X@26AR96T@3F%M96X@=F5R=V5N
M9&5N+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S,@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3DY,PIM<V=I9"`B66]U(&1I9"!N;W0@96YT
M97(@82!V86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R(")3:64@:&%B96X@
M:V5I;F4@9_QL=&EG92!%+4UA:6PM061R97-S92!A;F=E9V5B96XN(@H*(SH@
M9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP
M;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@
M)7,N(@IM<V=S='(@(B(*(E-I92!H86)E;B!K96EN92!&96QD97(@875S(&1E
M;B!I;7!O<G1I97)T96X@1&%T96X@9&5N(&5N='-P<F5C:&5N9&5N($9E;&1E
M<FX@(@HB:6X@)7,@>G5G96]R9&YE="XB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HY.#<*;7-G:60@(EEO=2!H879E(&)E96X@;&]G9V5D(&]U="XB
M"FUS9W-T<B`B4VEE('=U<F1E;B!A8F=E;65L9&5T+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R-C$*;7-G:60@(B(*(EEO=2!H879E('1O(&5N
M=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET
M:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I
M86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"B)3:64@;?QS<V5N(&5I;F4@9_QL
M=&EG92!-;V)I;'1E;&5F;VYN=6UM97(@86YG96)E;BP@;G5R(&%U<R!:86AL
M96X@=6YD(&=G9BX@(@HB96EN96T@7"(K7"(@9OQR(&EN=&5R;F%T:6]N86QE
M(%9O<G=A:&QE;B!B97-T96AE;F0N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3$X.`IM<V=I9"`B66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V
M86QU92XB"FUS9W-T<B`B4VEE(&W\<W-E;B!E:6YE;B!G_&QT:6=E;B!797)T
M(&%N9V5G96)E;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP
M:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A
M8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(B(*(E-I92!M_'-S96X@
M96EN($1A=&%4<F5E+4)A8VME;F0@:V]N9FEG=7)I97)E;BP@=6T@4F5G:7-T
M<FEE<G5N9V5N('9E<G=E;F1E;B`B"B)Z=2!K]FYN96XN(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HT-C4*;7-G:60@(EEO=2!M=7-T(&-O;F9I
M9W5R92!A(%9&4R!B86-K96YD+B(*;7-G<W1R(")3:64@;?QS<V5N(&5I;B!6
M1E,M0F%C:V5N9"!K;VYF:6=U<FEE<F5N+B(*"B,Z('1E;7!L871E<R]P<F]B
M;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T
M:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E
M<&]R="XB"FUS9W-T<B`B4VEE(&W\<W-E;B!D87,@4')O8FQE;2!B97-C:')E
M:6)E;BP@=6T@9&5N($)E<FEC:'0@86)Z=7-C:&EC:V5N+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*;7-G:60@(EEO
M=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T
M;R(*;7-G<W1R(")3:64@;?QS<V5N(&1I92!54DP@86YG96)E;BP@875F(&1I
M92!D:65S97(@3&EN:R!V97)W96ES96X@<V]L;"(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@
M<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(E-I92!M_'-S96X@97)S
M="!D96X@>G4@96YT9F5R;F5N9&5N(%-E<G9E<B!A=7-WY&AL96XN(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3$Y"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@
M=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R("(B"B)3:64@;?QS<V5N
M(&5I;F5N($)E;G5T>F5R;F%M96X@86YG96)E;BP@9&5S<V5N($1A=&5N(&=E
M;/9S8VAT('=E<F1E;B!S;VQL96XN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P
M"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E
M+B(*;7-G<W1R(")3:64@;?QS<V5N(&5I;F5N('IU(&SV<V-H96YD96X@0F5N
M=71Z97)N86UE;B!A;F=E8F5N+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU
M<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R(")3:64@
M;?QS<V5N(&5I;F5N(&AI;GIU>G5F_&=E;F1E;B!"96YU='IE<FYA;65N(&%N
M9V5B96XN(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9;W4@;75S
M="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@(E-I
M92!M_'-S96X@9&5N('IU(&%K='5A;&ES:65R96YD96X@0F5N=71Z97)N86UE
M;B!A;F=E8F5N+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z
M:7`N<&AP.C$S.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO
M;B!T;R!P97)F;W)M+B(*;7-G<W1R(")3:64@;?QS<V5N(&5I;F4@06MT:6]N
M(&%N9V5B96XN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y
M36%N86=E<BYP:'`Z-S$*;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T
M96=O<GD@;F%M92XB"FUS9W-T<B`B4VEE(&W\<W-E;B!E:6YE;B!N975E;B!+
M871E9V]R:65N86UE;B!A;F=E8F5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S"FUS9VED(")9;W4@;F5E
M9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(@IM<V=S='(@
M(E-I92!M_'-S96X@96EN92!)=&%L:65N:7-C:&4@5&5L969O;FYU;6UE<B!A
M;F=E8F5N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<U"B,L('!H
M<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@
M4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R(")):')E("5S+5-E<W-I;VX@
M:7-T(&%B9V5L875F96XN($)I='1E(&UE;&1E;B!3:64@<VEC:"!E<FYE=70@
M86XN(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*;7-G
M:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R(")):')E($4M36%I;"U!
M9')E<W-E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P-PIM<V=I9"`B
M66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R(")):')E(%9O;CH@061R97-S
M93HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C<@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C<W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-0HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3(*;7-G:60@(EEO=7(@26YF;W)M871I;VXB
M"FUS9W-T<B`B26AR92!!;F=A8F5N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z.3<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N
M970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F
M('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y
M+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB26AR92!);G1E
M<FYE=&%D<F5S<V4@:&%T('-I8V@@9V7D;F1E<G0L('-E:70@4VEE(&1I92`E
M<RU3:71Z=6YG(&)E9V]N;F5N("(*(FAA8F5N+B!:=6T@4V-H=71Z($EH<F5R
M(%-I8VAE<FAE:70@;?QS<V5N(%-I92!S:6-H(&YE=2!A;FUE;&1E;BXB"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B66]U
M<B!.86UE(@IM<V=S='(@(DEH<B!.86UE(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;F]A9&0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I
M;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@
M>6]U('=I<V@@=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A
M8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I
M8V%T:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*(DEH<B!!=71H96YT:69I>FEE
M<G5N9W-S>7-T96T@97)L875B="!K96EN($AI;GIU9OQG96X@=F]N(&YE=65N
M($)E;G5T>F5R;BX@(@HB5V5N;B!3:64@2&]R9&4@8F5N=71Z96X@;?9C:'1E
M;BP@=6T@26AR92!"96YU='IE<B!Z=2!V97)W86QT96XL(&W\<W-E;B!3:64@
M(@HB96EN96X@86YD97)E;B!!=71H96YT:69I>FEE<G5N9W-T<F5I8F5R(&)E
M;G5T>F5N+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z
M-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@
M;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB
M:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G
M<W1R("(B"B)):'(@075T:&5N=&EF:7II97)U;F=S<WES=&5M(&5R;&%U8G0@
M9&%S($%N>F5I9V5N(&1E<B!"96YU='IE<B!N:6-H="P@;V1E<B`B"B)D:65S
M92!-]F=L:6-H:V5I="!W=7)D92!A=7-G97-C:&%L=&5T+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.CDX,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@
M=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E
M8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S
M='(@(B(*(DEH<B!"<F]W<V5R(&AA="!S:6-H(&%N<V-H96EN96YD(&=EY&YD
M97)T('-E:70@4VEE(&1I92`E<RU3:71Z=6YG(&)E9V]N;F5N("(*(FAA8F5N
M+B!:=6T@4V-H=71Z($EH<F5R(%-I8VAE<FAE:70@;?QS<V5N(%-I92!S:6-H
M(&YE=2!A;FUE;&1E;BXB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU-PIM
M<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T
M=7)E+B(*;7-G<W1R(")):'(@0G)O=W-E<B!U;G1E<G-T_'1Z="!D:65S92!&
M=6YK=&EO;B!N:6-H="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]P<FEN
M="YJ<SHT,@IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O
M<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K
M(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*(DEH<B!"<F]W<V5R('5N=&5R
M<W3\='IT(&1I97-E($1R=6-K9G5N:W1I;VX@;FEC:'0N($)I='1E(&1R_&-K
M96X@4VEE(%-T<F<O(@HB2V]M;6%N9&\@*R!0('5M('IU(&1R=6-K96XN(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U,PIM<V=I9"`B66]U<B!C=7)R
M96YT('1I;64@>F]N93HB"FUS9W-T<B`B26AR92!A:W1U96QL92!:96ET>F]N
M93HB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,3$W"FUS9VED(")9;W5R(&1E
M9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"XB"FUS9W-T<B`B26AR
M92!3=&%N9&%R9&ED96YT:73D="!W=7)D92!G9>1N9&5R="XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,34S"FUS9VED(")9;W5R(&1E9F%U;'0@:61E
M;G1I='DZ(@IM<V=S='(@(DEH<F4@4W1A;F1A<F1I9&5N=&ETY'0Z(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y-@IM<V=I9"`B66]U<B!F=6QL(&YA
M;64Z(@IM<V=S='(@(DEH<B!V;VQL<W3D;F1I9V5R($YA;64Z(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z.3DY"FUS9VED(")9;W5R(&QO9VEN(&AA
M<R!E>'!I<F5D+B(*;7-G<W1R(")):'(@6G5G86YG(&ES="!A8F=E;&%U9F5N
M+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<W"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B
M"FUS9W-T<B`B26AR(&YE=65S(%!A<W-W;W)T(&;\<B`E<R!L875T970Z("5S
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-30*;7-G:60@
M(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T
M:6]N(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`B26AR92!%:6YS=&5L;'5N
M9V5N('=U<F1E;B!F_'(@9&EE($1A=65R(&1I97-E<B!3:71Z=6YG(&=E<W!E
M:6-H97)T+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34V
M"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S
M='(@(DEH<F4@16EN<W1E;&QU;F=E;B!W=7)D96X@9V5S<&5I8VAE<G0N(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*;7-G:60@(EEO=7(@
M<&%S<W=O<F0@:&%S(&)E96X@<F5S970B"FUS9W-T<B`B26AR(%!A<W-W;W)T
M('=U<F1E('IU<OQC:V=E<V5T>G0B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HX,`IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R
M97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N
M97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*(DEH<B!087-S=V]R="!W=7)D
M92!Z=7+\8VMG97-E='IT+B!2=69E;B!3:64@26AR92!%+4UA:6PM3F%C:')I
M8VAT96X@86(@=6YD("(*(FUE;&1E;B!3:64@<VEC:"!M:70@26AR96T@;F5U
M96X@4&%S<W=O<G0@86XN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M-S,S"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+B(*;7-G<W1R
M(")):'(@4&%S<W=O<G0@:7-T(&%B9V5L875F96XN(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9;W5R(')E;6]T92!S97)V
M97)S.B(*;7-G<W1R(")):')E(%-E<G9E<CHB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S='(@(DIU9V]S;&%W:65N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I
M<F4B"FUS9W-T<B`B6F%I<F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(U-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB
M:6$B"FUS9W-T<B`B4V%M8FEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM
M8F%B=V4B"FUS9W-T<B`B4VEM8F%B=V4B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-C8*;7-G:60@(EII<'!Y(@IM<V=S='(@(EII<'!Y(@H*(SH@9G)A
M;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP
M.C(P,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ
M,@IM<V=I9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(EM::71A='1E
M>'0@=F5R<W1E8VME;ETB"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HX.0IM
M<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R(");4')O8FQE;6)E<FEC
M:'1=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z
M,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS9W-T<B`B6UII=&%T
M=&5X="!A;GIE:6=E;B`M(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I
M;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C(P,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(");4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R(");
M6FET871T97AT(&%N>F5I9V5N("T@)7,@6F5I;&5N72(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,C`T"B,L('!H<"UF;W)M870*;7-G:60@(EML
M:6YE("5S(&]F("5S72(*;7-G<W1R(");6F5I;&4@)7,@=F]N("5S72(*"B,Z
M('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES
M=')A=&EO;B(*;7-G<W1R(")?061M:6YI<W1R871I;VXB"@HC.B!L:6(O87!I
M+G!H<#HR,C,*;7-G:60@(E]#3$DB"FUS9W-T<B`B0F5?9F5H;'-Z96EL92(*
M"B,Z(&QI8B]A<&DN<&AP.C(P-PIM<V=I9"`B7T1A=&%4<F5E(@IM<V=S='(@
M(E]$871A5')E92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T92!2;W<B"FUS9W-T
M<B`B6F5I;&4@7VSV<V-H96XB"@HC.B!L:6(O87!I+G!H<#HQ.3D*;7-G:60@
M(E]'<F]U<',B"FUS9W-T<B`B7T=R=7!P96XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@(E])
M;6%G92!0<F]P97)T:65S+BXN(@IM<V=S='(@(E]":6QD96EG96YS8VAA9G1E
M;BXN+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.30*
M;7-G:60@(E],;V<@:6XB"FUS9W-T<B`B06Y?;65L9&5N(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I9"`B7TQO9R!O=70B
M"FUS9W-T<B`B06)?;65L9&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI
M;FLN+BXB"FUS9W-T<B`B3&EN:R!?8F5A<F)E:71E;BXN+B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-C0*;7-G:60@(E]/<'1I;VYS
M(@IM<V=S='(@(E]%:6YS=&5L;'5N9V5N(@H*(SH@;&EB+V%P:2YP:'`Z,C`S
M"FUS9VED(")?4&5R;6ES<VEO;G,B"FUS9W-T<B`B7U)E8VAT92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M-@IM<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@(DQI;FL@7V5N=&9E
M<FYE;BXN+B(*"B,Z(&QI8B]A<&DN<&AP.C$Y,0IM<V=I9"`B7U-E='5P(@IM
M<V=S='(@(E]+;VYF:6=U<F%T:6]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED(")?5&%B;&4@
M4')O<&5R=&EE<RXN+B(*;7-G<W1R(")?5&%B96QL96YE:6=E;G-C:&%F=&5N
M+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3DU"FUS9VED(")?57-E<G,B"FUS9W-T
M<B`B7T)E;G5T>F5R(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY
M-3$*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R(")!9')E<W-B=6-H(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S0*;7-G:60@
M(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(D%D<F5S<V%T('5N8F5K86YN
M="(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.30S"FUS9VED(")C
M86QE;F1A<B(*;7-G<W1R(")+86QE;F1E<B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3<T(&QI8B]";&]C:R]M971A<BYP:'`Z,S8P"B,L('!H<"UF;W)M
M870*;7-G:60@(F-A;&TB"FUS9W-T<B`B=VEN9'-T:6QL(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C
M<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B075S9V%B961A=&5I(&MO;FYT
M92!N:6-H="!E<G-T96QL="!W97)D96XB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B
M"FUS9W-T<B`B16EN9V%B92!K86YN(&YI8VAT(&=E]F9F;F5T('=E<F1E;B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C8P,`IM<V=I
M9"`B8VQI8VL@:&5R92(*;7-G<W1R(")K;&EC:V5N(%-I92!H:65R(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O
M;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R(")5;F?\;'1I9V4@0F5N
M=71Z=6YG(&1E<B!+;VUM86YD;WIE:6QE(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ-S@*;7-G:60@(F-O;F9I9W5R871I;VX@97)R
M;W(B"FUS9W-T<B`B2V]N9FEG=7)A=&EO;G-F96AL97(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC86P@
M<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R(")+<FET:7-C:&4@4WES=&5M
M9&%T96D@9F5H;'0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B1&%T
M96YF;W)M871F96AL97(B"@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC
M.C,P"FUS9VED(")E9&ET(@IM<V=S='(@(F)E87)B96ET96XB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$X,@IM<V=I9"`B96YT<GD@
M;F]T(&9O=6YD(@IM<V=S='(@(D5I;G1R86<@;FEC:'0@9V5F=6YD96XB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW-0IM<V=I
M9"`B9F%L;&EN9R(*;7-G<W1R(")F86QL96YD(@H*(SH@9G)A;65W;W)K+T)R
M;W=S97(O0G)O=W-E<BYP:'`Z.#DV"FUS9VED(")F:6QE(@IM<V=S='(@(D1A
M=&5I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S8@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS-C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.#@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R
M(")A=7,@)7,@*"5S*2!M:70@)7,@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C,Y"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(F+V:6<B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4P
M"FUS9VED(")H.B(*;7-G<W1R(")H.B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HS-3D*;7-G:60@(FAH(@IM<V=S='(@(FAH
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S@*;7-G
M:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(DAO<W1N86UE('5N8F5K
M86YN="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E(@IM<V=S='(@(G-O9F]R
M="(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8T(&%D;6EN+W-E='5P+V1I
M9F8N<&AP.C<V"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B26YL:6YE(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G:60@(FEN
M<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R(")%:6XM+T%U<V=A8F5F96AL97(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I
M9"`B:6YT97)N86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B26YT97)N97(@
M4V]F='=A<F5F96AL97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T
M94)L;V-K<RYJ<SHQ,PIM<V=I9"`B;&EN97-=(@IM<V=S='(@(EIE:6QE;ETB
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F
M<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C
M;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@(FUK:7-O9G,M1F5H
M;&5R8V]D92`E9"!B96D@9&5R($5R<W1E;&QU;F<@9&5S($E33RU!8F)I;&1E
M<RXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,S<P"FUS9VED(")M;2(*;7-G<W1R(")M;2(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,C@U('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ-S0*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(T,PIM<V=I
M9"`B;F%M92(*;7-G<W1R(").86UE(@H*(SH@9G)A;65W;W)K+U)00R]24$,N
M<&AP.C$R-`IM<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(FYI8VAT
M(&EM<&QE;65N=&EE<G0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C$R,C`*;7-G:60@(FYO="!Y970@:6UP;&5M96YT960B"FUS9W-T
M<B`B3F]C:"!N:6-H="!I;7!L96UE;G1I97)T(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,S4*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B3F]T
M:7IB;&]C:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B4')O>F5N
M="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<T"FUS
M9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R("):=6=R:69F('9E<G=E
M:6=E<G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS9W-T<B`B4&EX96PB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I9"`B
M<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(E)E;6]T969E:&QE
M<B!I;2!0<F]T;VMO;&PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HW-PIM<V=I9"`B<FES:6YG(@IM<V=S='(@(G-T96EG96YD
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#(*;7-G
M:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B4V5R=FEC92!N:6-H
M="!V97)F_&=B87(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C$P,0IM
M<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R(")5;G1E<G-C:&EE9&4@
M86YZ96EG96XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S
M='(@(G-M<S)E;6%I;"#\8F5R($A45%`B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@W"FUS9VED(")S<R(*;7-G<W1R(")S
M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<V
M"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B9VQE:6-H8FQE:6)E;F0B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES
M=&5M(&5R<F]R(@IM<V=S='(@(E-Y<W1E;69E:&QE<B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.34Y"FUS9VED(")T87-K(&QI<W0B"FUS9W-T
M<B`B075F9V%B96YL:7-T92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,38V"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R
M(")6;W+\8F5R9V5H96YD97(@1F5H;&5R(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,S8@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W,`IM<V=I9"`B
M='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R(")G
M96)E;B!3:64@9&%S(%!A<W-W;W)T(&5I;B!Z=V5I=&5S($UA;"!Z=7(@0F5S
M=.1T:6=U;F<@96EN(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C0@861M
M:6XO<V5T=7`O9&EF9BYP:'`Z-S8*;7-G:60@(G5N:69I960B"FUS9W-T<B`B
M=6YI9FEE9"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O4&%R="YP:'`Z,C<*
M;7-G:60@(G5N;F%M960B"FUS9W-T<B`B=6YB96YA;FYT(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS
M9VED(")U<V5R('-E;&5C="(*;7-G<W1R(")B96YU='IE<F1E9FEN:65R="(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS-0IM
M<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0R"FUS9VED(")W.B(*;7-G<W1R
M(")B.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED
M(")W96%T:&5R+F-O;2(*;7-G<W1R(")W96%T:&5R+F-O;2(*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&\O;FQ?3DPN<&\`````````````````````````````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P-S,T-C$V(#$P-3$U-#,S-S0R(#`Q-S4T,``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````C($AO<F1E
M($1U=&-H('1R86YS;&%T:6]N+@HC($-O<'ER:6=H="`H0RD@,C`P,2TR,#`V
M($IA;B!+=6EP97)S+@HC($IA;B!+=6EP97)S(#QJ<FMU:7!E<G-`;&%U=V5R
M<V-O;&QE9V4N;FP^+"`R,#`Q+3(P,#8N"B,@"FUS9VED("(B"FUS9W-T<B`B
M(@HB4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C$N,2UC=G-<;B(*(E)E
M<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)0
M3U0M0W)E871I;VXM1&%T93H@,C`P-BTP,RTQ,B`P,#HS,2LP,3`P7&XB"B)0
M3RU2979I<VEO;BU$871E.B`R,#`V+3`S+3$S(#(R.C0P*S`Q,#!<;B(*(DQA
M<W0M5')A;G-L871O<CH@2F%N($MU:7!E<G,@/&IR:W5I<&5R<T!L875W97)S
M8V]L;&5G92YN;#Y<;B(*(DQA;F=U86=E+51E86TZ($1U=&-H(#QI,3AN0&QI
M<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT
M96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,5QN(@HB
M0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,V.0HC+"!P:'`M9F]R;6%T"FUS9VED("(@
M*"5S(&1A>7,@86=O*2(*;7-G<W1R("(@*"5S(&1A9V5N(&=E;&5D96XI(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ,S@S"B,L('!H<"UF;W)M
M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(@*%-N96QT;V5T
M<R`E<RDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<W"B,L('!H
M<"UF;W)M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B("AB:6YN
M96X@)7,@9&%G96XI(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W
M,PIM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B("AV86YD86%G*2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S4*;7-G:60@(B`H=&]M;W)R;W<I
M(@IM<V=S='(@(B`H;6]R9V5N*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S-S$*;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(@*&=I<W1E
M<F5N*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#4@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U,`HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,SDV"FUS9VED("(@870@(@IM<V=S='(@(B!O<"`B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Q.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R
M(")<(B5S7"(@:7,@9V5E;B!D:7)E8W1O<GDN(@H*(SH@9G)A;65W;W)K+T-,
M22]#3$DN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@
M;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R(")<(B5S7"(@:7,@9V5E;B!G
M96QD:6=E(&ME=7IE+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I
M<W1R>2YP:'`Z-S$P"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R
M>2YP:'`Z,3`Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T
M(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*;7-G<W1R(")<
M(B5S7"(@:7,@;FEE="!G96-O;F9I9W5R965R9"!I;B!H970@2&]R9&4@<F5G
M:7-T97(N(@H*(SH@9G)A;65W;W)K+U1R964O5')E92YP:'`Z,3<Q"B,L('!H
M<"UF;W)M870*;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N
M9"XB"FUS9W-T<B`B7"(E<UPB('1R964@=V5E<F=E=F5R(&YI970@9V5V;VYD
M96XN(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*
M;7-G<W1R(")<(B5S7"(@86%N(&AE="!G<F]E<&5N<WES=&5E;2!T;V5G979O
M96=D+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S
M:6]N<R!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B!A86X@:&5T(')E8VAT96YS
M>7-T965M('1O96=E=F]E9V0N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB('=A<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(EPB)7-<
M(B!I<R!N:65T(&%A;F=E;6%A:W0Z("5S+B(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E9"!O
M9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R("(E+C)F34(@9V5B
M<G5I:W0@=F%N("4N,F9-0B!T;V5G97-T86%N("@E+C)F)24I(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B)60@)7,@96X@)7,B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C(V."!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-3DT"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&1A>7,@=6YT
M:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R("(E9"!D86=E;B!T
M;W0@=7<@=V%C:'1W;V]R9"!V97)V86QT+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y
M(&9O<F5C87-T(@IM<V=S='(@(B5D+61A9R!V;V]R=6ET>FEC:'0B"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B)7,@+2!/<&UE<FMI;F<B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*;7-G<W1R("(E<R!V:6YG97)A
M9F1R=6LB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX
M-#(@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0T"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B5S($M"(@H*(SH@<V5R
M=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS
M9W-T<B`B)7,@3VYD97)H;W5D<W=E<FMZ86%M:&5D96X@+2!"979E<W1I9VEN
M9R(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*
M;7-G<W1R("(E<R!);G-T96QL96XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,C8T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I9VX@
M57`B"FUS9W-T<B`B)7,@:6YS8VAR:6IV96XB"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@
M;V8@06=R965M96YT(@IM<V=S='(@(B5S(&=E8G)U:6ME<G-O=F5R965N:V]M
M<W0B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8X,B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C<U,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C0S,B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y-`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B
M)7,@8F5S=&%A="!A;"XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$V-B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C(T
M-@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,U,B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,U.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G
M<W1R("(E<R!O<"`E<R`E<R(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<R!I<R!R96%D>2!T;R!P
M97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L
M;W<N($-H96-K('1H92`B"B)B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U
M('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N(@IM<V=S='(@(B(*(B5S
M(&ES(&=E<F5E9"!O;2!O;F1E<G-T86%N9&4@9V5S96QE8W1E97)D92!O;F1E
M<FAO=61S=V5R:WIA86UH961E;B!U:70@=&4@(@HB=F]E<F5N+B!6:6YK(&1E
M(&)E=V5R:VEN9RAE;BD@86%N(&1I92!U(&]P(&1I="!M;VUE;G0@=VEL="!U
M:71V;V5R96XN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,T,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("(E
M<R!I<R!V97)E:7-T(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R("(E<R!M:6YU
M=&5N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP
M.C$S,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S
M='(@(B5S(&YI970@9V5V;VYD96XN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O
M9B`E<R(*;7-G<W1R("(E<R!T;W0@)7,@=F%N("5S(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G
M<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B)7,G<R!A9')E<V)O96LB"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ.`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@(B5S)W,@86=E;F1A(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(B5S)W,@;F]T:71I96)O96LB
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS-`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(B5S)W,@=&%K96YL
M:6IS="(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,Z("5S(@IM<V=S='(@(B5S.B`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VAT;6PN<&AP.C$R-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B(E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L
M86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@
M:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R
M<V]N86P@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*(B5S.B!$:70@8F5R:6-H
M="!K;VUT(&UI<W-C:&EE;B!N:65T('9A;B!D96=E;F4@9&EE(&AE="!B97=E
M97)T('1E('II:FXN(%=E97,@(@HB=F]O<GII8VAT:6<@8FEJ(&AE="!K;&EK
M:V5N(&]P(&QI;FMS(&EN(&AE="!B97)I8VAT(&]F(&1E(&%F>F5N9&5R("(*
M(G!E<G-O;VYL:6IK92!I;F9O<FUA=&EE('1E('-T=7)E;BXB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4T(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS.3D*;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B+"!W
M:6YD=FQA9V5N("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3DU(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C`P"B,L('!H<"UF;W)M870*;7-G:60@(BP@9W5S
M=&EN9R`E<R`E<R(*;7-G<W1R("(L('=I;F1V;&%G96X@)7,@)7,B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(P.`HC+"!P:'`M9F]R;6%T"FUS9VED("(L
M('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B+"!V87)I86)E;"!V
M86X@)7,@=&]T("5S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C<T."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Y
M-`HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,T."!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,#8Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q,C@*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(M+2!S96QE
M8W1E<F5N("TM(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P"FUS9VED("(Q
M,B!(;W5R($9O<FUA="(*;7-G<W1R("(Q,B!U=7)S=V5E<F=A=F4B"@HC.B!L
M:6(O0FQO8VLO=&EM92YP:'`Z,3D*;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM
M<V=S='(@(C(T('5U<G-W965R9V%V92(*"B,Z('1E;7!L871E<R]D871A+W1I
M;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(R-"!U=7)S(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0IM<V=I9"`B/%!R979I
M;W5S(@IM<V=S='(@(CQ6;W)I9V4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$R-@IM<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O
M<B!T:&ES(&)L;V-K+B(*;7-G<W1R(")%96X@9&%T86)A<V4@8F%C:V5N9"!I
M<R!V97)E:7-T('9O;W(@9&ET(&)L;VLN(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ-S$*;7-G:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R
M<F5D(@IM<V=S='(@(D5R(&AE969T('II8V@@965N(&9A=&%L92!F;W5T('9O
M;W)G961A86XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY
M,S4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC
M<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(D5E;B!O<&5N8F%R92!01U`@<VQE
M=71E;"!I<R!V97)E:7-T(&]M(&5E;B!B97)I8VAT('1E(&-O9&5R96XN(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V.`IM<V=I9"`B
M02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N
M960@;65S<V%G92XB"FUS9W-T<B`B(@HB165N(&]P96YB87)E(%!'4"!S;&5U
M=&5L(&ES('9E<F5I<W0@;VT@965N(&]N9&5R=&5K96YD(&)E<FEC:'0@=&4@
M=F5R:69IZW)E;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,#DY"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'
M4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T
M(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB165N(&]P96YB87)E(%!'4"!S
M;&5U=&5L+"!P<FEVZ2!01U`@<VQE=71E;"!E;B!W86-H='=O;W)D<F5G96P@
M>FEJ;B!V97)E:7-T("(*(F]M(&5E;B!B97)I8VAT('1E(&1E8V]D97)E;BXB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#$V"FUS9VED
M("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB
M"FUS9W-T<B`B(@HB165N(&]P96YB87)E(%!'4"!S;&5U=&5L+"!P<FEVZ2!0
M1U`@<VQE=71E;"!E;B!W86-H='=O;W)D<F5G96P@>FEJ;B!V97)E:7-T("(*
M(F]M(&5E;B!B97)I8VAT('1E(&]N9&5R=&5K96YE;BXB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4P-@IM<V=I9"`B(@HB02!P=6)L
M:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM
M<V=S='(@(B(*(D5E;B!O<&5N8F%R92!3+TU)344@<VQE=71E;"P@<')I=ND@
M4R]-24U%('-L975T96P@96X@=V%C:'1W;V]R9')E9V5L('II:FX@(@HB=F5R
M96ES="!O;2!E96X@8F5R:6-H="!T92!D96-O9&5R96XN(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B
M;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M97-S86=E+B(*;7-G
M<W1R("(B"B)%96X@;W!E;F)A<F4@4R]-24U%('-L975T96PL('!R:7;I(%,O
M34E-12!S;&5U=&5L(&5N('=A8VAT=V]O<F1R96=E;"!Z:6IN("(*(G9E<F5I
M<W0@;VT@965N(&)E<FEC:'0@=&4@;VYD97)T96ME;F5N+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U8FQI
M8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N
M(@IM<V=S='(@(D5E;B!O<&5N8F%R92!334E-12!S;&5U=&5L(&ES('9E<F5I
M<W0@;VT@965N(&)E<FEC:'0@=&4@8V]D97)E;BXB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HY"FUS9VED(")!32!#;&]U9',B
M"FUS9W-T<B`B0F5W;VQK:6YG('9O;W(@,3(N,#`@=75R(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*;7-G:60@(D%-($QI
M9VAT(%)A:6XB"FUS9W-T<B`B3&EC:'1E(')E9V5N('9O;W(@,3(N,#`@=75R
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3$*
M;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B4F5G96X@=F]O<B`Q,BXP,"!U=7(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM
M<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R(")"=6EE;B!V;V]R(#$R+C`P('5U
M<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S
M"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B4VYE975W8G5I96X@
M=F]O<B`Q,BXP,"!U=7(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR
M.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`B04TO4$TB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%0
M22!)1"(*;7-G<W1R(")!4$D@240B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O
M<B(*;7-G<W1R(")/=F5R(&1E>F4@961I=&]R(@H*(SH@<V5R=FEC97,O:&5L
M<"]I;F1E>"YP:'`Z-3,*;7-G:60@(D%B;W5T+BXN(@IM<V=S='(@(D]V97(N
M+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<T"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B06)S8F]T=&]M(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I
M9"`B06)S;6ED9&QE(@IM<V=S='(@(D%B<VUI9&1L92(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI960@
M8W)E871I;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B5&]E9V%N9R!G97=E
M:6=E<F0@8FEJ(&AE="!M86ME;B!V86X@5D93(&1I<F5C=&]R>2XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3,V"FUS9VED(")!8V-E<W,@
M9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G<W1R(")4;V5G86YG(&=E
M=V5I9V5R9"!B:6H@:&5T(&UA:V5N('9A;B!61E,@8F5S=&%N9"XB"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z,PIM<V=I9"`B06-C;W5N="!);F9O<FUA
M=&EO;B(*;7-G<W1R(")!8V-O=6YT:6YF;W)M871I92(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW.`IM<V=I9"`B06-C;W5N="!087-S=V]R9"(*;7-G
M<W1R(")!8V-O=6YT=V%C:'1W;V]R9"(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N="!F
M<F]Z96XN(@IM<V=S='(@(D%C8V]U;G0@8F5V<F]R96XN(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,S-0IM<V=I9"`B06-C;W5N=&EN9R(*;7-G
M<W1R(")697)A;G1W;V]R9&EN9R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,30X('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0IM<V=I9"`B
M061D(@IM<V=S='(@(E1O979O96=E;B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,C(T(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!9&0@0VAI;&0@1W)O
M=7`B"FUS9W-T<B`B0VAI;&0@9W)O97`@=&]E=F]E9V5N(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY."!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.CDY"FUS9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G
M<W1R(")#:&EL9"!R96-H="!T;V5V;V5G96XB"@HC.B!T96UP;&%T97,O<&]R
M=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D($AE<F4Z(@IM<V=S='(@(DAI97(@
M=&]E=F]E9V5N.B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$X(&%D;6EN+V=R
M;W5P<RYP:'`Z,C$Y"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S='(@(DYI
M975W92!G<F]E<"!T;V5V;V5G96XB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C@W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#@*
M;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO;B(*;7-G<W1R(").:65U=R!R96-H
M="!T;V5V;V5G96XB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H
M:6QD+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R
M;W5P('1O(%PB)7-<(B(*;7-G<W1R(")%96X@7")C:&EL9&=R;V5P7"(@86%N
M(%PB)7-<(B!T;V5V;V5G96XB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!P
M97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R(")%96X@7")C:&EL9')E8VAT
M7"(@86%N(%PB)7-<(B!T;V5V;V5G96XB"@HC.B!A9&UI;B]U<V5R+G!H<#HS
M,`IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S='(@(DYI975W92!G96)R
M=6EK97(@=&]E=F]E9V5N.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HU-38*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B
M2V]L;VT@=&]E=F]E9V5N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E
M9&ET+FEN8SHS-`IM<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S='(@(DYI
M975W92!L961E;B!T;V5V;V5G96XB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M
M87`N:6YC.CDU"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R(")086%R('1O979O
M96=E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E
M8F%R(@IM<V=S='(@(DAE="`E<R!M96YU('1O979O96=E;B!A;',@965N($UO
M>FEL;&$@4VED96)A<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HW,0IM<V=I9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS
M9W-T<B`B5F]E9R!T;V4@86%N(&%D<F5S8F]E:SHB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*;7-G:60@(D%D9"!T;R!M
M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`B5F]E9R!T;V4@86%N(&UI:FX@861R
M97-B;V5K(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*;7-G:60@(D%D9"!U<V5R
M(@IM<V=S='(@(D=E8G)U:6ME<B!T;V5V;V5G96XB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S7"(@
M=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S
M:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R("(B"B)<(B5S7"(@
M86%N(&AE="!S>7-T965M('1O96=E=F]E9V0L(&UA87(@:V]N(&=E96X@97AT
M<F$@(@HB:6YS8VAR:6IV:6YG<VEN9F]R;6%T:64@=&]E=F]E9V5N.B`E<RXB
M"@HC.B!S:6=N=7`N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&5D
M(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM
M<V=S='(@(EPB)7-<(B!A86X@:&5T('-Y<W1E96T@=&]E9V5V;V5G9"X@52!K
M=6YT(&YU(&%A;FUE;&1E;BXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N
M;V%D9"YI;F,Z,@IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*
M;7-G<W1R(")4;V5V;V5G96X@=F%N(&=E8G)U:6ME<G,@:7,@=6ET9V5S8VAA
M:V5L9"XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3(V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ-S,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,0IM<V=I9"`B061D
M<F5S<R(*;7-G<W1R(")!9')E<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ-#$*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R(")!9')E<V)O
M96LB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M-`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU-@IM
M<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@
M=7-E<G,B"FUS9W-T<B`B0F5H965R("T@<F5C:'1E;B!V;V]R(&%N9&5R92!G
M96)R=6EK97)S(&EN<W1E;&QE;B(*"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ.2!S
M97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED(")!9&UI;FES
M=')A=&EO;B(*;7-G<W1R(")"96AE97(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S0S"FUS9VED(")!9',B"FUS9W-T<B`B061V97)T96YT:65S
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.`IM<V=I9"`B069G:&%N:7-T86XB"FUS9W-T<B`B069G
M86YI<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$*;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B
M06QB86YIZR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S0*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B
M06QG97)I:F4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R(")!;&EA<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*
M;7-G:60@(D%L:6=N(@IM<V=S='(@(E5I=&QI:FYE;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N
M;65N=#HB"FUS9W-T<B`B56ET;&EJ;FEN9SHB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R(")!;&QE(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B
M"FUS9W-T<B`B06QL92!G96%U=&AE;G1I8V5E<F1E(&=E8G)U:6ME<G,B"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C(R"FUS
M9VED(")!;&P@1W)O=7!S(@IM<V=S='(@(D%L;&4@9W)O97!E;B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]D871A=')E92YP:'`Z-S4@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HY,0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS
M(@IM<V=S='(@(D%L;&4@<F5C:'1E;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R
M('-I9&5S(@IM<V=S='(@(D%L;&4@=FEE<B!Z:6ID96XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#<Q"FUS9VED(")!;&QO=R!M=6QT:7!L92!A
M9&1R97-S97,B"FUS9W-T<B`B365E<F1E<F4@861R97-S96X@=&]E<W1A86XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,X"FUS9VED(")!;&QO=R!S
M971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R("));G-T96QL
M96X@=F%N(&=E;W)D96YD92!L:6IS="!T>7!E('1O97-T86%N/R(*"B,Z(&9R
M86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B
M06QR96%D>2!E>&ES=',B"FUS9W-T<B`B0F5S=&%A="!A;"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,C8*;7-G:60@(D%L=&5R;F%T92!)35-0($QO
M9VEN(@IM<V=S='(@(D%L=&5R;F%T:65V92!)35-0(&%A;FUE;&1I;F<B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$Q"FUS9VED(")!;'1E<FYA=&4@
M24U34"!087-S=V]R9"(*;7-G<W1R(")!;'1E<FYA=&EE9B!)35-0('=A8VAT
M=V]O<F0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`S"FUS9VED(")!
M;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G<W1R(")!;'1E<FYA=&EE=F4@
M24U34"!G96)R=6EK97)S;F%A;2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C,U"FUS9VED(")!;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G
M<W1R(")!;'1E<FYA=&EE9B!E+6UA:6QA9')E<R(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z,30R"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S
M='(@(D%L=&5R;F%T:65V92!S:F%B;&]N96XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C4*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C(*;7-G:60@
M(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R(")!;'1E<FYA=&EE=F4@=&5K<W0Z
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-PIM<V=I9"`B06UE<FEC86X@4V%M;V$B"FUS9W-T<B`B
M06UE<FEK86%N<R!386UO82(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z.34@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,34*;7-G
M:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB"FUS9W-T<B`B
M165N(&]N9V5L9&EG92!W86%R9&4@;W!G96=E=F5N+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-34*;7-G:60@(D%N('5N:VYO=VX@97)R
M;W(@:&%S(&]C8W5R960N(@IM<V=S='(@(D5R(&AE969T('II8V@@965N(&]N
M8F5K96YD969O=70@=F]O<F=E9&%A;BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V"FUS9VED(")!
M;F1O<G)A(@IM<V=S='(@(D%N9&]R<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T"FUS9VED(")!
M;F=O;&$B"FUS9W-T<B`B06YG;VQA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,`IM<V=I9"`B06YG
M=6EL;&$B"FUS9W-T<B`B06YG=6EL;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T
M<B`B06YO;FEE;64@<')O>'DB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@(D%N='=O;W)D(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-0IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R(")!;G1A<F-T:6-A
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.0IM<V=I9"`B06YT:6=U82!A;F0@0F%R8G5D82(*;7-G
M<W1R(")!;G1I9W5A(&5N($)A<F)U9&$B"@HC.B!A9&UI;B]P:'!S:&5L;"YP
M:'`Z,S8@861M:6XO=&5M<&QA=&5S+G!H<#HW-`HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO54DN<&AP.C4X('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E
M>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(E1O97!A<W-I
M;F<B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI
M8V%T:6]N($QI<W0B"FUS9W-T<B`B5&]E<&%S<VEN9V5N;&EJ<W0B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,30P"FUS9VED(")!<'!L:6-A=&EO;B!I
M<R!R96%D>2XB"FUS9W-T<B`B5&]E<&%S<VEN9R!I<R!G97)E960N(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O
M($-H:6QD(%-H87)E<R(*;7-G<W1R(")/<"!C:&EL9'-H87)E<R!T;V5P87-S
M96XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM
M<V=I9"`B07!P<F]V92(*;7-G<W1R(")';V5D:V5U<F5N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0R"FUS9VED(")!<'!R;WAI
M;6%T92!3:7IE(@IM<V=S='(@(D=E<V-H871T92!G<F]O='1E(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-0HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0S"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P
M<FEL(@IM<V=S='(@(D%P<FEL(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M-S@*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R(")!<F%B
M:7-C:"`H5VEN9&]W<RTQ,C4V*2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-3D@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HW.`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C8V"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R(")!<F-H
M:65F8F5S=&%N9'-G<F]O='1E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HU."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C<W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C4*;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R(")!<F-H:65F;F%A
M;2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z
M,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT
M('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B"FUS9W-T
M<B`B5V5E="!U('IE:V5R(&1A="!U(&AE="!A86YM96QD:6YG<W9E<GIO96L@
M=F%N("5S('=I;'0@=F5R=VEJ9&5R96X_(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E
M('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S
M=6(M9W)O=7!S/R(*;7-G<W1R(")7965T('4@>F5K97(@9&%T('4@7"(E<UPB
M(&5N(&%L;&4@<W5B9W)O97!E;B!W:6QT('9E<G=I:F1E<F5N/R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C8*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R(")!<F=E;G1I;FGK(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,@IM<V=I9"`B07)M96YI82(*;7-G<W1R(")!<FUE;FGK(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D%R;65N:6%N("A!
M4DU30TE)+3@I(@IM<V=S='(@(D%R;65E;G,@*$%235-#24DM."DB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R="(*;7-G<W1R(")+
M=6YS="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,S`*;7-G:60@(D%R=6)A(@IM<V=S='(@(D%R=6)A
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C
M96YS:6]N($ES;&%N9"(*;7-G<W1R(")!<V-E;G-I;VX@96EL86YD(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS
M9W-T<B`B07-C:6D@:W5N<W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`B
M07IIZR]086-I9FES8VAE(%)E9VEO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0R.0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O
M:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@(D]M(&)E=F5S
M=&EG:6YG('9R86=E;B!V;V]R(&AE="!U:71V;V5R96X@=F%N(&]N9&5R:&]U
M9'-W97)K>F%A;6AE9&5N/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,P.34*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R(")/<&1R
M86-H="!K;VQO;6UE;B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@
M(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G
M<W1R(")0;V=I;F<@;VT@965N(&YI970@8F5S=&%A;F1E(&=R;V5P('1E('9E
M<G=I:F1E<F5N+B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z,CD*;7-G
M:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I
M;VXN(@IM<V=S='(@(E!O9VEN9R!O;2!E96X@;FEE="!B97-T86%N9"!R96-H
M="!T92!V97)W:6ID97)E;BXB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HX
M-PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI
M<W-I;VXN(@IM<V=S='(@(E!O9VEN9R!O;2!E96X@;FEE="!B97-T86%N9"!R
M96-H="!T92!B97=E<FME;BXB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP
M:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S
M:&%R92XB"FUS9W-T<B`B4&]G:6YG(&]M(&5E;B!N:65T(&)E<W1A86YD92!S
M:&%R92!T92!B97=E<FME;BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C8T(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HW,0IM<V=I9"`B071T<FEB=71E<R(*;7-G<W1R(")!='1R:6)U=&5N(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.0HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G
M:60@(D%U9W5S="(*;7-G<W1R(")!=6=U<W1U<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD*;7-G
M:60@(D%U<W1R86QI82(*;7-G<W1R(")!=7-T<F%L:>LB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X
M"FUS9VED(")!=7-T<FEA(@IM<V=S='(@(D]O<W1E;G)I:FLB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y
M<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R(")!=71H7V-Y<G-Q;#H@=F5R96ES=&4@:6UA<"!E>'1E;G1I92!N:65T
M(&=E=F]N9&5N+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP
M.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E
M(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!B
M86-K96YD(&AE969T(&YI970@9&4@=F5R96ES=&4@8F5K=V%A;6AE9&5N+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B
M075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!V97)E:7-T92!I;6%P(&5X=&5N=&EE
M(&YI970@9V5V;VYD96XN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]F='`N
M<&AP.C,V"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE
M+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@(B(*(D%U=&A?9G1P.B!V97)E:7-T
M92!&5%`@97AT96YT:64@;FEE="!G979O;F1E;BX@0V]M<&EL965R(%!(4"!M
M970@9&4@+2UE;F%B;&4M(@HB9G1P(&]P=&EE+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O:6UA<"YP:'`Z-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER
M960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VEM
M87`Z('9E<F5I<W1E($E-05`@97AT96YT:64@;FEE="!G979O;F1E;BXB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H
M7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B075T:%]K<F(U.B!V97)E:7-T92!K<F(U(&5X=&5N=&EE(&YI970@
M9V5V;VYD96XN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS
M,#(*;7-G:60@(D%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P
M;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@HB075T:%]L
M9&%P.B!T;V5V;V5G96X@=F%N(&=E8G)U:6ME<G,@=V]R9'0@;FEE="!O;F1E
M<G-T975N9"!V;V]R($%C=&EV92`B"B)$:7)E8W1O<GDB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C,U-PIM<V=I9"`B075T:%]L9&%P.B!2
M96UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER
M96-T;W)Y(@IM<V=S='(@(B(*(D%U=&A?;&1A<#H@5F5R=VEJ9&5R96X@=F%N
M(&=E8G)U:6ME<G,@=V]R9'0@;FEE="!O;F1E<G-T975N9"!V;V]R($%C=&EV
M92`B"B)$:7)E8W1O<GDB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C8S"FUS9VED(")!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]L9&%P.B!V97)E:7-T92!,
M1$%0(&5X=&5N=&EE(&YI970@9V5V;VYD96XN(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HS,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T
M:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R(")!=71H7VQD87`Z($YI970@:6X@
M<W1A870@9V5B<G5I:V5R("5S('1O92!T92!V;V5G96XN($1E('-E<G9E<B!M
M96QD=#H@(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS.#4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M
M;W9E('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B!.:65T(&EN('-T86%T
M(&=E8G)U:6ME<B`E<R!T92!V97)W:6ID97)E;B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z-#DY"B,L('!H<"UF;W)M870*;7-G:60@(D%U
M=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S(@IM<V=S='(@(D%U
M=&A?;&1A<#H@3FEE="!I;B!S=&%A="!G96)R=6EK97(@)7,@8FEJ('1E('=E
M<FME;B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#`U"FUS
M9VED(")!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T
M960@9F]R($%C=&EV92!$:7)E8W1O<GDN(@IM<V=S='(@(B(*(D%U=&A?;&1A
M<#H@0FEJ=V5R:V5N('9A;B!G96)R=6EK97)S('=O<F1T(&YI970@;VYD97)S
M=&5U;F0@=F]O<B!!8W1I=F4@(@HB1&ER96-T;W)Y+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;6-A;"YP:'`Z-#8*;7-G:60@(D%U=&A?;6-A;#H@4F5Q
M=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H
M7VUC86PZ('9E<F5I<W1E($U#04P@97AT96YT:64@;FEE="!G979O;F1E;BXB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U
M=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R(")!=71H7W-M8F%U=&@Z('9E<F5I<W1E('-M8F%U=&@@
M97AT96YT:64@;FEE="!G979O;F1E;BXB"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%D;6EN+G!H<#HQ,#8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&%T($E-
M05`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B075T:&5N=&EC871I92!O<"!)
M34%0('-E<G9E<B!M:7-L=6MT+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM<V=I9"`B075T:&5N=&EC871I
M;VX@9F%I;&5D(@IM<V=S='(@(D%U=&AE;G1I8V%T:64@;6ES;'5K="(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE
M9"X@)7,B"FUS9W-T<B`B075T:&5N=&EC871I92!M:7-L=6MT+B`E<R(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-S8*;7-G:60@(D%U
M=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S
M='(@(D%U=&AE;G1I8V%T:64@9V5W96EG97)D(&1O;W(@9&4@4D%$2553('-E
M<G9E<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@X,@IM<V=I
M9"`B075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S
M='(@(D%U=&AE;G1I8V%T:64@;W`@1E10('-E<G9E<B!M:7-L=6MT+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-S`*;7-G:60@(D%U=&AE;G1I
M8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B075T
M:&5N=&EC871I92!O<"!D92!334(@<V5R=F5R(&UI<VQU:W0N(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I
M96QD<SHB"FUS9W-T<B`B0F5S8VAI:V)A<F4@=F5L9&5N.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,S$*;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B07IE<F)A:61Z:F%N(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"3T9(($5X8W5S
M97,B"FUS9W-T<B`B0D]&2"!%>&-U<V5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R
M;W5N9"(*;7-G<W1R(")!8VAT97)G<F]N9"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@
M0V]L;W(B"FUS9W-T<B`B06-H=&5R9W)O;F1K;&5U<B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#$*;7-G:60@(D)A9"!K97)B97)O<R!P
M87-S=V]R9"XB"FUS9W-T<B`B1F]U="!K97)B97)O<W=A8VAT=V]O<F0N(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D
M(&ME<F)E<F]S('5S97)N86UE+B(*;7-G<W1R(")&;W5T92!K97)B97)O<V=E
M8G)U:6ME<G-N86%M+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#4*;7-G:60@(D)A:&%M87,B"FUS
M9W-T<B`B0F%H86UA<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S@*;7-G:60@(D)A:')A:6XB"FUS
M9W-T<B`B0F%H<F5I;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS
M9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R(")"86QT:7-C:"`H
M25-/+3@X-3DM,3,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-`IM<V=I9"`B0F%N9VQA9&5S:"(*
M;7-G<W1R(")"86YG;&%D97-H(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,PIM<V=I9"`B0F%R8F%D
M;W,B"FUS9W-T<B`B0F%R8F%D;W,B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP
M:'`Z,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E
M8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B0F%S:7,@869B965L
M9&EN9V5N9&ER96-T;W)Y(%PB)7-<(B!N:65T(&=E=F]N9&5N+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0IM
M<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B0F%S:7-L:6IN(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M.0IM<V=I9"`B0F5L87)U<R(*;7-G<W1R(")7:70@<G5S;&%N9"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S4*;7-G:60@(D)E;&=I=6TB"FUS9W-T<B`B0F5L9VGK(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HU,`IM<V=I9"`B0F5L:7IE(@IM<V=S='(@(D)E;&EZ92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-#`*;7-G:60@(D)E;FEN(@IM<V=S='(@(D)E;FEN(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,0IM
M<V=I9"`B0F5R;75D82(*;7-G<W1R(")"97)M=61A(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-@IM
M<V=I9"`B0FAU=&%N(@IM<V=S='(@(D)H=71A;B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G:60@(D)I<G1H9&%Y
M(@IM<V=S='(@(E9E<FIA87)D86<B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO0V]L;&5C=&EO;BYP:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D)L
M;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*
M;7-G<W1R(")";&]K(%PB)7-<(B!V86X@=&]E<&%S<VEN9R!<(B5S7"(@;FEE
M="!G979O;F1E;BXB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M.3`*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(D)L;VMI;G-T96QL
M:6YG96XB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z-S0*;7-G
M:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B0FQO:W1Y<&4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@(D)O;&0B
M"FUS9W-T<B`B5F5T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,PIM<V=I9"`B0F]L:79I82(*;7-G
M<W1R(")";VQI=FEA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(P
M-PIM<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@(D)O;VMM87)K<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*
M;7-G:60@(D)O<F1E<B(*;7-G<W1R(")286YD(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H
M:6-K;F5S<SHB"FUS9W-T<B`B4F%N9&1I:W1E.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*;7-G:60@(D)O
M<F1E<G,B"FUS9W-T<B`B4F%N9&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,@IM<V=I9"`B0F]S
M;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R(")";W-N:>L@96X@2&5R>F5G
M;W9I;F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.38*;7-G:60@(D)O
M=&@B"FUS9W-T<B`B0F5I9&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT.`IM<V=I9"`B0F]T<W=A
M;F$B"FUS9W-T<B`B0F]T<W=A;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<U"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*;7-G:60@(D)O='1O;2(*;7-G
M<W1R(")/;F1E<FMA;G0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0W"FUS9VED(")";W5V970@27-L
M86YD(@IM<V=S='(@(D)O=79E="!E:6QA;F0B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HT,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0T"FUS9VED
M(")"<F%Z:6PB"FUS9W-T<B`B0G)A>FEL:>LB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HT,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-PIM<V=I
M9"`B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(D)R
M:71S($EN9&ES8VAE($]C96%A;B!497)R:71O<FEU;2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#(*
M;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@(D)R=6YE:2!$87)U
M<W-A;&%M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS-PIM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B
M0G5L9V%R:6IE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES="(*;7-G<W1R(")/;F=E
M;W)D96YD92!L:6IS="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S8*;7-G:60@(D)U<FMI;F$@1F%S
M;R(*;7-G<W1R(")"=7)K:6YA($9A<V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Y"FUS9VED(")"
M=7)U;F1I(@IM<V=S='(@(D)U<G5N9&DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#0V"FUS9VED(")#35,B"FUS9W-T<B`B0TU3(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#
M(@IM<V=S='(@(D-20R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3DX"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G
M<W1R(")#4DP@1&ES=')I8G5T:65P=6YT96XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?
M96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B0U]E;&5I9V5N<V-H87!P96XN
M+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Q"FUS9VED
M(")#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R(")#86-H
M92!I;FET:6%L:7-A=&EE(&ES(&YI970@869G97)O;F0N(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-2!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDQ-@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z
M,3`T,"!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,34W"FUS9VED(")#86QE
M;F1A<B(*;7-G<W1R(")!9V5N9&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C,U"FUS9VED(")#86QM(@IM<V=S='(@(DMA;&TB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R.`IM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B0V%M8F]D:F$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8P"FUS9VED(")#86UE<F]O;B(*;7-G<W1R(")+86UE<F]E;B(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#86X@
M;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U
M<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)+86X@=V%C:'1W;V]R9"!N
M:65T(&%U=&]M871I<V-H(')E<V5T=&5N+"!N965M(&-O;G1A8W0@;W`@;65T
M(&1E("(*(G-Y<W1E96UB96AE97)D97(N(@H*(SH@9G)A;65W;W)K+T9I;&5?
M0U-6+T-35BYP:'`Z,S4P"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B!N;W0@
M=W)I=&4@=&\@9FEL92!<(B5S7"(B"FUS9W-T<B`B2V%N(&YI970@;F%A<B!B
M97-T86YD(%PB)7-<(B!S8VAR:6IV96XB"@HC.B!A9&UI;B]S97-S:6]N<RYP
M:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO
M;B!H86YD;&5R<RXB"FUS9W-T<B`B2V%N(&=E96X@97AT97)N92!S97-S:65H
M86YD;&5R(&)E:&5R96XN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S
M<6PN<&AP.C,Q.2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E
M<G9E<CH@)7,B"FUS9W-T<B`B2V%N(&YI970@=F5R8FEN9&5N(&UE="!)34%0
M('-E<G9E<CH@)7,B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT
M-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B2V%N(&)E<W1A;F0@7"(E<UPB(&YI970@;W!E;F5N+B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-3$*;7-G:60@(D-A;F%D82(*;7-G<W1R(")#86YA9&$B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-2!T96UP;&%T
M97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O<F5M;W9E+FEN8SHQ,B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E
M;&5T92YI;F,Z,3$*;7-G:60@(D-A;F-E;"(*;7-G<W1R(")!9F)R96ME;B(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#
M86YC96P@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B4')O8FQE96UR87!P;W)T
M(&%F8G)E:V5N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,C,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B2V%N(&)E<W1A;F0@7"(E<UPB(&YI970@=F5R=VEJ9&5R
M96XN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU,@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z-#8*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R
M>2XB"FUS9W-T<B`B2V%N(&=E96X@=&EJ9&5L:6IK92!D:7)E8W1O<GD@=FEN
M9&5N+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP
M:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I
M;&4G('!A<F%M971E<BXB"FUS9W-T<B`B2V%N(&YI970@9&]O<F=A86X@>F]N
M9&5R("=T87)G971&:6QE)R!P87)A;65T97(N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T
M(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")+86X@9&ER96-T
M;W)Y(%PB)7-<(B!N:65T('9E<G=I:F1E<F5N+B(*"B,Z(&9R86UE=V]R:R]$
M871A5')E92]$871A5')E92YP:'`Z,3(X(&9R86UE=V]R:R]$871A5')E92]$
M871A5')E92]S<6PN<&AP.C8X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN
M;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`B2V%N(&YI
M970@=F5R=VEJ9&5R96X[("5D(&-H:6QD<F5N(&)E<W1A86XN(@H*(SH@9G)A
M;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B
M"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@
M9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB
M"FUS9W-T<B`B(@HB2V%N(&YI970@;W!N:65U=R!R86YG<V-H:6MK96XL(&AE
M="!A86YT86P@:6YV;V5R96X@;VT@;W!N:65U=R!T92`B"B)R86YG<V-H:6MK
M96X@:V]M="!N:65T(&]V97)E96X@;65T(&AE="!O<&=E<VQA9V5N(&%A;G1A
M;"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I
M9FEE9"!N=6UB97(N(@IM<V=S='(@(DMA;B!B97)I8VAT(&YI970@;F%A<B!H
M970@;W!G96=E=F5N(&YU;6UE<B!V97)S='5R96XN(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-0IM
M<V=I9"`B0V%P92!697)D92(*;7-G<W1R(")+86%P(%9E<F1E(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`IM
M<V=I9"`B0V%P=&EO;B(*;7-G<W1R(")/<'-C:')I9G0B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A
M<G)I97(B"FUS9W-T<B`B1')A9V5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDS"FUS9VED(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`B
M0V%T96=O<FEEZVX@96X@;&%B96QS(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S4*;7-G:60@(D-A
M>6UA;B!)<VQA;F1S(@IM<V=S='(@(D-A>6UA;B!E:6QA;F1E;B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@
M(D-E;&P@4&AO;F4B"FUS9W-T<B`B5&5L+FYR+FUO8FEE;"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*;7-G
M:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G<W1R(")#96QE:6=E;G-C:&%P<&5N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B0V5L('9R:6IE(')U
M:6UT93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS9W-T<B`B
M0V5L96EG96YS8VAA<'!E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$R"FUS9VED(")#96QL('-P86-I;F<Z(@IM<V=S
M='(@(D-E;'-P871IZW)I;F<Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(W-`IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(E1E;"YN<BYM;V)I
M96PB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0V5L=&EC
M("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B2V5L=&ES8V@@*$E33RTX.#4Y+3$T
M*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R(")-:61D96XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4T"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T
M<B`B0V5N=')A86P@069R:6MA86YS92!297!U8FQI96LB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X,@IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/
M+3@X-3DM,BDB"FUS9W-T<B`B0V5N=')A86P@175R;W!E97,@*$E33RTX.#4Y
M+3(I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#`*
M;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B0V5R=&EF:6-A
M871D971A:6QS(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV,3(*;7-G:60@(D-E<G1I9FEC871E($]W;F5R(@IM<V=S='(@(D-E<G1I
M9FEC86%T96EG96YA87(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4Y-PIM<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T
M<B`B0V5R=&EF:6-A871B96QE:60B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$*;7-G:60@(D-H
M860B"FUS9W-T<B`B5'-J86%D(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@IM<V=I
M9"`B0VAA;F=E(@IM<V=S='(@(E=I:GII9V5N(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C,Q"FUS9VED(")#:&%N9V4@66]U<B!087-S=V]R
M9"(*;7-G<W1R(")7:6IZ:6<@=7<@=V%C:'1W;V]R9"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV.0IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N
M9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@
M<F5P;'D@=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(B(*(E=I:GII9R!D
M92!N86%M+"!A9')E<R!E;B!O;F1E<G1E:V5N:6YG(&1I92!M96X@>FEE="!B
M:6H@:&5T(&QE>F5N(&5N("(*(F)E86YT=V]O<F1E;B!V86X@=7<@92UM86EL
M<RXB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*;7-G:60@
M(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W
M:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#;VYT86-T('EO
M=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB5VEJ>FEG96X@=F%N('5W
M('=A8VAT=V]O<F0@=V]R9'0@;FEE="!O;F1E<G-T975N9"!D;V]R(&1E(&AU
M:61I9V4@(@HB8V]N9FEG=7)A=&EE+B!.965M(&-O;G1A8W0@;W`@;65T('5W
M('-Y<W1E96UB96AE97)D97(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PIM<V=I9"`B0VAA<B(*;7-G<W1R
M(")+87)A:W1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB"FUS
M9W-T<B`B0V]N=%]R;VQE97(@;&EN:RXN+B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3D*;7-G:60@
M(D-H:6QE(@IM<V=S='(@(D-H:6QI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-30*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,0IM<V=I9"`B0VAI
M;F$B"FUS9W-T<B`B0VAI;F$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M,PIM<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@
M(D-H:6YE97,@=F5R965N=F]U9&EG9"`H1T(R,S$R*2(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@T"FUS9VED(")#:&EN97-E(%1R861I=&EO;F%L("A"
M:6<U*2(*;7-G<W1R(")#:&EN965S('1R861I=&EO;F5E;"`H0FEG-2DB"@HC
M.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHW"FUS9VED(")#:&]O<V4@07!P
M;&EC871I;VXZ(@IM<V=S='(@(DMI97,@=&]E<&%S<VEN9SHB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C<P"FUS9VED(")#:&]O<V4@
M82!P87-S=V]R9"(*;7-G<W1R(")+:65S(&5E;B!W86-H='=O;W)D(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B0VAO
M;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B2VEE<R!E96X@9V5B<G5I:V5R<VYA
M86TB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`R"FUS9VED(")#:&]O
M<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(DMI97,@9&%T=6UW
M965R9V%V93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T
M>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B2VEE<R!L:6IS='-T
M:6IL='EP92`H=F]O<B!G96]R9&5N9&4@;&EJ<W1E;BDB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V
M"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(D-H<FES=&UA<R!E
M:6QA;F0B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.3$T(&9R86UE=V]R
M:R].971?4TU3+U--4RYP:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-L
M87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R(")#;&%S
M<V1E9FEN:71I92!V86X@)7,@;FEE="!G979O;F1E;BXB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`IM<V=I9"`B0VQE87(B
M"FUS9W-T<B`B2&5L9&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*
M;7-G<W1R(")-4T]F9FEC92!T86=S('=I<W-E;B(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HQ,CD*;7-G:60@(D-L96%R(%%U97)Y(@IM<V=S='(@(E=I<R!Q
M=65R>2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHU"B,L
M('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R
M(")7:7,@9V5B<G5I:V5R.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V-L96%R+FEN8SHQ,0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R(")7:7,@
M9V5B<G5I:V5R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,S0*;7-G:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R(")7:7,@9V5B<G5I
M:V5R<V1A=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R("),871E(&]P
M:VQA<FEN9V5N(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA
M;F-E+FAT;6PZ-C`*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@
M(DML:6L@;VT@=F5R9&5R('1E(&=A86XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E
M;&P@=FEA($A45%`B"FUS9W-T<B`B0VQI8VMA=&5L;"!V:6$@2%144"(*"B,Z
M('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(E-L=6ET
M('-C:&5R;2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Q"FUS9VED(")#
M;&]U9',B"FUS9W-T<B`B5V]L:V5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,38*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G
M<W1R(")6<F]E9V4@8F5W;VQK:6YG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3<*;7-G:60@(D-L;W5D>2(*;7-G<W1R(")"
M97=O;&MT(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HU,@IM<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES
M;&%N9',B"FUS9W-T<B`B0V]C;W,@*$ME96QI;F<I(&5I;&%N9&5N(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR,PIM<V=I9"`B0V]L;&%P
M<V4@4VED96)A<B(*;7-G<W1R(")::6IB86QK(&EN:VQA<'!E;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*
M;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@(DEN9V5K;&%P=&4@
M<F%N9&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HV,@IM<V=I9"`B0V]L;VUB:6$B"FUS9W-T<B`B
M0V]L;VUB:6$B"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C
M:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`B2VQE
M=7(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-3`S"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS
M,S@*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,S
M.2!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@R"FUS9VED(")#
M;VQO<B!0:6-K97(B"FUS9W-T<B`B2VQE=7)E;FMI97IE<B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(X,C@*;7-G:60@(D-O;&]U<B!S96QE8W1I
M;VXB"FUS9W-T<B`B2VQE=7)S96QE8W1I92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G
M<W1R(")+;VQO;6UE;CHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.30V"FUS9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S='(@(DMO;&]M=&ET96QS
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V-@IM<V=I9"`B0V]M
M:6-S(@IM<V=S='(@(E-T<FEP<R(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR
M-@IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R(")/<&1R86-H="(*"B,Z(&%D;6EN
M+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R
M(")/<&1R86-H='-H96QL(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$S"FUS9VED(")#;VUM96YT(@IM<V=S='(@(D]P;65R:VEN9R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38W"FUS9VED
M(")#;VUM;VX@3F%M92(*;7-G<W1R(")!;&=E;65N92!N86%M(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,S`*;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`B0V]M;W)E;B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@
M(D-O;7!A;GDB"FUS9W-T<B`B0F5D<FEJ9B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(D-O;7!U=&5R
M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#8*;7-G:60@
M(D-O;F1I=&EO;B(*;7-G<W1R(")#;VYD:71I92(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C4V"FUS9VED(")#;VYD:71I;VYS(@IM<V=S='(@(D-O;F1I
M=&EE<R(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF
M:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S='(@(E9E<G-C:&EL;&5N(&EN
M(&-O;F9I9W5R871I92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#8*
M;7-G:60@(D-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3
M;6%R='!H;VYE<R!A;F0@3W5T;&]O:RXB"FUS9W-T<B`B(@HB0V]N9FEG=7)A
M=&EE('9O;W(@:&5T('-Y;F-H<F]N:7-E<F5N(&UE="!01$$G<RP@4VUA<G1P
M:&]N97,@96X@3W5T;&]O:RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3,U"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*;7-G
M<W1R(")#;VYF:6=U<F%T:64@:7,@=F5R;W5D97)D+B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG
M=7)E("5S(@IM<V=S='(@(B5S(&-O;F9I9W5R97)E;B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-3$*;7-G:60@(D-O;F9I<FT@4&%S
M<W=O<F0B"FUS9W-T<B`B0F5V97-T:6<@=V%C:'1W;V]R9"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C4Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-34*;7-G:60@(D-O;F=O(@IM<V=S='(@(DMO;F=O(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,PIM
M<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*
M;7-G<W1R(")+;VYG;RP@1&4@1&5M;V-R871I<V-H92!297!U8FQI96L@=F%N
M(&1E(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,3DW"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P
M.`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960N(@IM<V=S='(@(E9E<F)I;F1I
M;F<@;6ES;'5K="XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S`X"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@
M(E9E<F)I;F1I;F<@;6ES;'5K=#H@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-SDP"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@
M=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(E9E<F)I;F1I;F<L(&UE
M="!D92!O<&5N8F%R92!S;&5U=&5L<V5R=F5R+"!I<R!G97=E:6=E<F0N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDR"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC
M(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(B(*(E9E<F)I
M;F1I;F<L(&UE="!D92!O<&5N8F%R92!S;&5U=&5L<V5R=F5R+"!I<R!G97=E
M:6=E<F0N(%)E9&5N.B`E<R`H)7,I(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HX-S8*;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F
M86EL960N(@IM<V=S='(@(E9E<F)I;F1I;F<@;65T($944"!S97)V97(@;6ES
M;'5K="XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR-"!C;VYF
M:6<O:&]O:W,N<&AP+F1I<W0Z,3`V-PIM<V=I9"`B0V]N=&%C=',B"FUS9W-T
M<B`B061R97-S96XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY
M(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R(")!9')E<W-E
M;B!Z:6IN(&UE="!S=6-C97,@86%N('5W(&%D<F5S8F]E:R!T;V5G979O96=D
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-C`*
M;7-G:60@(D-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z("(*;7-G
M<W1R(")#;VYT96YT('1Y<&4@=F%N(&=E8V]M<')I;65E<F0@8F5S=&%N9#H@
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU-B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<U"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@(DEN:&]U9"!V
M86X@7"(E<UPB(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S"FUS9VED(")#;VYT:6YU
M92(*;7-G<W1R(")$;V]R9V%A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@*;7-G:60@(D-O;VL@
M27-L86YD<R(*;7-G<W1R(")#;V]K(&5I;&%N9&5N(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,R"FUS9VED(")#;V]K:64B"FUS9W-T<B`B0V]O:VEE
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(Q"FUS9VED(")#;W!Y(@IM<V=S='(@(DMO<&GK<F5N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@(DMO<&GK<F5N(&UI<VQU
M:W0Z("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B2V]P:65E
M<B!S96QE8W1I92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S='(@(DMO<W1E;B!)1"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-C,*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B0V]S=&$@4FEC
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-3<*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B
M279O;W)K=7-T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M.3<W"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@(@IM
M<V=S='(@(DMO;B!01U`@8F5R:6-H="!N:65T(&-O9&5R96XZ("(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P-34*;7-G:60@(D-O=6QD
M(&YO="!01U`@<VEG;B!M97-S86=E.B`B"FUS9W-T<B`B2V]N(%!'4"!B97)I
M8VAT(&YI970@;VYD97)T96ME;F5N.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E
M;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(DMO;B!B97)I8VAT(&YI970@4R]-
M24U%(&-O9&5R96XN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HT-C<*;7-G:60@(D-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E
M+B(*;7-G<W1R(")+;VX@8F5R:6-H="!N:65T(%,O34E-12!O;F1E<G1E:V5N
M96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C
M;VYT86-T+B`E<R(*;7-G<W1R(")+;VX@861R97,@)7,@;FEE="!T;V5V;V5G
M96XN(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.CDV(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HT.#(*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$05`@
M<V5R=F5R+B(*;7-G<W1R(")+;VX@9V5E;B!V97)B:6YD:6YG(&UE="!D92!,
M1$%0+7-E<G9E<B!M86ME;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@(DMO;B!T
M96=O960@)7,@;FEE="!C;VYT<F]L97)E;BXB"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-#8V"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0
M('-E<G9E<BXB"FUS9W-T<B`B2V]N(&YI970@=F5R8FEN9&5N(&UE="!,1$%0
M('-E<G9E<BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB
M)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(DMO;B!N:65T('9E<F)I;F1E
M;B!M970@<V5R=F5R(%PB)7-<(B!M970@1E10.B`E<R(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI
M<W0N("5S(@IM<V=S='(@(DMO;B!G965N(&1I<W1R:6)U=&EE;&EJ<W0@)7,@
M;6%K96XN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$R
M.`IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z("(*;7-G<W1R
M(")+;VX@4$=0(&1A=&$@;FEE="!D96-O9&5R96XZ("(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3(S"FUS9VED(")#;W5L9"!N;W0@
M9&5C<GEP="!3+TU)344@9&%T82XB"FUS9W-T<B`B2V]N(%,O34E-12!D871A
M(&YI970@9&5C;V1E<F5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,C0V"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B2V]N(&%D<F5S
M("5S(&YI970@=F5R=VEJ9&5R96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS
M9W-T<B`B2V]N(&1I<W1R:6)U=&EE;&EJ<W0@)7,@;FEE="!V97)W:6ID97)E
M;BXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R
M:7!T(%PB)7-<(BXB"FUS9W-T<B`B2V]N('-E='5P('5P9W)A9&4@<V-R:7!T
M(%PB)7-<(B!N:65T('9E<G=I:F1E<F5N+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,S@Q(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.CDU,PIM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C
M:7!I96YT)W,@92UM86EL(&%D9')E<W,N(@IM<V=S='(@(DMO;B!H970@92UM
M86EL861R97,@=F%N(&1E(&]N='9A;F=E<B!N:65T(&)E<&%L96XN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*
M;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN
M(@IM<V=S='(@(DMO;B!C;VUP;&5T92!A9')E<V)O96L@;FEE="!O<&AA;&5N
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I
M8G5T:6]N(&QI<W0N(@IM<V=S='(@(DMO;B!C;VUP;&5T92!D:7-T<FEB=71I
M96QI:G-T(&YI970@;W!H86QE;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I9"`B0V]U;&0@;F]T(&9E
M=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RXB
M"FUS9W-T<B`B2V]N(&-O;7!L971E(&QI:G-T('9A;B!D:7-T<FEB=71I96QI
M:G-T96X@;FEE="!O<&AA;&5N+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO
M860@<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R(")+;VX@<W1R871E9VEE(%PB
M)7-<(B!N:65T(&QA9&5N+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(DMO;B!D:7)E8W1O<GD@
M7"(E<UPB(&YI970@;6%K96XN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-S$Y"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K
M97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R(")+;VX@9&4@;W!E;F)A
M<F4@<VQE=71E;"!N:65T('9E<FMR:6IG96X@=F%N(&1E('-L975T96QS97)V
M97(N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S
M='(@(DMO;B!<(B5S7"(@;FEE="!O<&5N96X@=F]O<B!S8VAR:6IV96XN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C<W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M,C8R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*
M;7-G<W1R(")+;VX@)7,@;FEE="!O<&5N96XN(@H*(SH@9G)A;65W;W)K+TUA
M:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HT,C`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@
M)7,B"FUS9W-T<B`B2V]N(&]N9&5R:&]U9'-T86ME;FUO9'5L92`E<R!N:65T
M(&]P96YE;B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HW,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G
M<W1R(")+;VX@9&ER96-T;W)Y(%PB)7-<(B!N:65T(&]P96YE;BXB"@HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$Q(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C(S-R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-#<X"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HU,38@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C4V(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HV.3D*;7-G:60@(D-O=6QD(&YO="!R96%C:"!T:&4@
M3$1!4"!S97)V97(N(@IM<V=S='(@(DMO;B!D92!,1$%0+7-E<G9E<B!N:65T
M(&)E<F5I:V5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+T]B:F5C="YP:'`Z
M,C0P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R96%D("5S+B(*
M;7-G<W1R(")+;VX@)7,@;FEE="!L97IE;BXB"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HX-0IM<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H
M92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L
M;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I
M;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B
M"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(DMO;B!H970@=V%C:'1W;V]R
M9"!V86X@9&4@9V5W96YS=&4@9V5B<G5I:V5R(&YI970@<F5S971T96XN(%-O
M;6UI9V4@;V8@86QL92`B"B)D971A:6QS('II:FX@;FEE="!J=6ES="X@4')O
M8F5E<B!O<&YI975W(&]F(&YE96T@8V]N=&%C="!O<"!M970@9&4@(@HB<WES
M=&5E;6)E:&5E<F1E<BP@=V%N;F5E<B!U('9E<F1E<F4@:'5L<"!N;V1I9R!H
M965F="XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS,#<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S,X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W
M-0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#$*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@W"FUS
M9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(DMO;B!!0TP@
M;FEE="!O<&AA;&5N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,B"FUS9W-T<B`B2V]N(&%D
M<F5S8F]E:R`E<R!N:65T(&]P:&%L96XN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<R(*;7-G<W1R(")+;VX@9&ES=')I8G5T:65L:6IS="`E<R!N:65T(&]P:&%L
M96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B2V]N(&1I<W1R
M:6)U=&EE;&EJ<W1E;B`E<R!N:65T(&]P:&%L96XN(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DW"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q-PHC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C$*;7-G:60@(D-O=6QD(&YO="!R
M971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`B2V]N('-E
M<G9E<F)E:W=A86UH961E;B!N:65T(&]P:&%L96XB"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C4T"FUS9VED(")#;W5L9"!N;W0@<F5V97)T(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(DMO;B!C;VYF:6=U<F%T:64@;FEE="!T97)U
M9WIE='1E;BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`B2V]N
M(&1I<F5C=&]R>2!<(B5S7"(@;FEE="!V97)W:6ID97)E;BXB"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")+;VX@
M8V]N9FEG=7)A=&EE("5S(&YI970@;W!S;&%A;BXB"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3D*;7-G
M:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS
M9W-T<B`B2V]N(&=E96X@8F%C:W5P8V]N9FEG=7)A=&EE(&]P<VQA86XN(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B
M"FUS9W-T<B`B2V]N(&=E96X@8F%C:W5P8V]N9FEG=7)A=&EE(&]P<VQA86XZ
M("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.34*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I
M<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B2V]N('-E='5P('5P9W)A9&4@<V-R
M:7!T(&YI970@;W!S;&%A;B!A;',Z(%PB)7-<(BXB"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G
M<W1R(")+;VX@:&5T(&)A8VMU<&-O;F9I9W5R871I96)E<W1A;F0@;FEE="!O
M<'-L86%N("5S+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I
M9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T
M:&4@(@HB;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@
M8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B
M(@HB2V]N(&AE="!C;VYF:6=U<F%T:65B97-T86YD("5S(&YI970@;W!S;&%A
M;BX@52!K=6YT(&]F(.OK;B!V86X@9&4@;W!T:65S("(*(F=E8G)U:6ME;B!O
M;2!D92!C;V1E('1E<G5G(&]P('1E('-L86%N(&]P("5S(&]F(&]N9&5R<W1A
M86YD92!C;V1E(&AA;F1M871I9R`B"B)N86%R("5S(&MO<&GK<F5N+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,30S"FUS9VED(")#;W5L
M9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B2V]N(&1E
M($Q$05`M<V5R=F5R(&YI970@9&]O<GIO96ME;BXB"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN
M:R!<(B5S7"(N(@IM<V=S='(@(DMO;B!<(B5S7"(@;FEE="!L;W-K;W!P96QE
M;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E
M(&-O;G1A8W0N("5S(@IM<V=S='(@(DMO;B!A9')E<R`E<R!N:65T(&)I:G=E
M<FME;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C,Y-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D
M871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")+;VX@9&ES=')I
M8G5T:65L:6IS="`E<R!N:65T(&)I:G=E<FME;BXB"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B
M2V]N(&-O;F9I9W5R871I92!V;V]R(%PB)7-<(B!N:65T('=E9W-C:')I:G9E
M;CH@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<P"FUS9VED(")#
M;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T
M:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R("(B"B)+;VX@9&4@36]Z:6QL
M82!3:61E8F%R(&YI970@=FEN9&5N+B!:;W)G(&5R=F]O<B!D870@9&4@<VED
M96)A<B!O<&5N(&ES+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C$U-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG
M="!G:79E('5S97(@7"(E<UPB('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T
M:&4@9F]L9&5R(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@HB2V]N(&=E8G)U:6ME
M<B!<(B5S7"(@9&4@=F]L9V5N9&4@<F5C:'1E;B!O<"!D92!M87`@7"(E<UPB
M(&YI970@9V5V96XZ("5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30Q.0IM<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(D=E=&5L9&4@=&5K
M<W0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM
M<V=I9"`B0V]U;G1R>2(*;7-G<W1R("),86YD(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(W-0IM<V=I9"`B0V]U<G-E<R(*;7-G<W1R(")#=7)S
M=7-S96XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G<W1R(")-86ME
M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV.`IM<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R(")-86%K
M(&5E;B!L:6YK(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T
M+FEN8SHY-`IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R(")-86%K
M(&5E;B!N:65U=V4B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY,@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T
M+G!H<#HU,@IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(DUA
M86L@<W5B;6%P<&5N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HR-#`*;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B16EG
M96YA87)R96-H=&5N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(Q
M,@IM<V=I9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(D-R961I=&-A
M<F1N=6UM97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.0IM<V=I9"`B0W)O871I82(*;7-G<W1R
M(")+<F]A=&GK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HV-`IM<V=I9"`B0W5B82(*;7-G<W1R(")#
M=6)A(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(V"FUS9VED(")#=7)R96YT
M(#0@4&AA<V5S(@IM<V=S='(@(DAU:61I9V4@-"!F87-E;B(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HU,`IM<V=I9"`B0W5R<F5N="!397-S:6]N<R(*;7-G
M<W1R(")(=6ED:6=E('-E<W-I97,B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z
M,R!L:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E;G0@5&EM92(*
M;7-G<W1R(")(=6ED:6=E('1I:F0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@
M55),(&ES(@IM<V=S='(@(DAU:61I9V4@55),(&ES(@H*(SH@861M:6XO<V5S
M<VEO;G,N<&AP.C,U"FUS9VED(")#=7)R96YT(%5S97)S(@IM<V=S='(@(DAU
M:61I9V4@9V5B<G5I:V5R<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*
M;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R(")(=6ED:6<@=V5E<B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-C0*;7-G:60@(D-U
M<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`B2'5I9&EG92!C;VYD:71I93H@
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R(")(=6ED:6=E('-T:6IL
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@
M)7,N(@IM<V=S='(@(D%A;G!A<W-E;B!V86X@=&%K96X@=&EJ9&5N<R!A86YM
M96QD:6YG(&)I:B`E<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*;7-G<W1R(")+
M;FEP<&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R(")396QE8W1I
M92!K;FEP<&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HV-PIM<V=I9"`B0WEP<G5S(@IM<V=S='(@
M(D-Y<')U<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED(")#
M>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R(")#>7)I;&QI<V-H("A+3TDX+5(I
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@(D-Y<FEL;&EC
M("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(D-Y<FEL;&ES8V@@*%=I;F1O=W,M
M,3(U,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-PIM<V=I9"`B0WER
M:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@(D-Y<FEL;&ES8V@O
M56MR86EN<R`H2T])."U5*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@*;7-G:60@(D-Z96-H(%)E
M<'5B;&EC(@IM<V=S='(@(E1S:F5C:&ES8VAE(%)E<'5B;&EE:R(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3(@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(D1$(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W,@IM<V=I9"`B(@HB1%-.("AS
M964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A
M8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B"B)$4TX@*'II92!H
M='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E
M+F1B+FEN=')O+61S;BYP:'`I(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E
M+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`B1&%G
M96QI:FMS(@H*(SH@861M:6XO9&%T871R964N<&AP.C8U"FUS9VED(")$871A
M5')E92!"<F]W<V5R(@IM<V=S='(@(D1A=&%4<F5E(&)R;W=S97(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<P"FUS9VED(")$871A8F%S92!,
M;V]K=7`B"FUS9W-T<B`B1&%T86)A<V4@9&]O<GIO96ME;B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C,Y.`IM<V=I9"`B1&%T92(*;7-G<W1R(")$871U
M;2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S"FUS
M9VED(")$871E(%)E8V5I=F5D(@IM<V=S='(@(D1A='5M($]N='9A;F=E;B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W.#D*;7-G:60@(D1A=&4@
M<V5L96-T:6]N(@IM<V=S='(@(D1A='5M('-E;&5C=&EE(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(X,2!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S$Q"FUS9VED(")$87DB"FUS9W-T<B`B1&%G(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,V
M"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G<W1R(")697)?=VEJ9&5R(&MO
M;&]M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#4Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(D1E8V5M8F5R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ
M-@IM<V=I9"`B1&5C:6UA;"!N=6UB97)S(@IM<V=S='(@(D1E8VEM86QE(&=E
M=&%L;&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S='(@(DEN<W!R
M:6YG96X@=F5R:VQE:6YE;B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,3@W(&QI8B]P<F5F<RYP:'`Z,3$W"FUS9VED(")$969A=6QT(@IM
M<V=S='(@(E-T86YD86%R9"(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C<W"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S
M='(@(E-T86YD86%R9"!K;&5U<B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])
M9&5N=&ET>2YP:'`Z.38*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T
M<B`B4W1A;F1A87)D(&ED96YT:71E:70B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-S4*;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`B4W1A;F1A
M87)D('-H96QL(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED
M(")$969I;FET:6]N<R(*;7-G<W1R(")$969I;FET:65S(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HW,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C,V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$Q-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.2!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.CDX"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,`IM<V=I9"`B1&5L971E
M(@IM<V=S='(@(E9E<G=I:F1E<F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"FUS9VED(")$96QE=&4@
M0V5L;"(*;7-G<W1R(")697)W:6ID97(@8V5L(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR,C<*;7-G:60@(D1E;&5T92!'
M<F]U<"(*;7-G<W1R(")'<F]E<"!V97)W:6ID97)E;B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C(T.0IM<V=I9"`B1&5L971E($QO9R(*;7-G
M<W1R(")697)W:6ID97(@;&]G(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HW-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,0IM
M<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B4F5C:'0@=F5R=VEJ
M9&5R96XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HY,PIM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R
M(")697)W:6ID97(@96X@=VES(&)E<FEC:'1E;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3<*;7-G:60@(D1E
M;&5T92!C96QL(@IM<V=S='(@(E9E<G=I:F1E<B!C96PB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8S"FUS9VED
M(")$96QE=&4@8V]L=6UN(@IM<V=S='(@(E9E<G=I:F1E<B!K;VQO;2(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS9VED(")$96QE=&4@97AI<W1I
M;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(D)E<W1A86YD(&%L=&5R
M;F%T:65F('-J86)L;V]N('9E<G=I:F1E<F5N(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-30*;7-G:60@(D1E;&5T92!M97-S
M86=E<R(*;7-G<W1R(")697)W:6ID97(@8F5R:6-H=&5N(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B4F5C
M:'1E;B!V86X@7"(E<UPB('9E<G=I:F1E<F5N(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L
M971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES
M<VEO;G,_(@IM<V=S='(@(E)E8VAT96X@96X@979E;G1U96QE('-U8G)E8VAT
M96X@=F]O<B!<(B5S7"(@=F5R=VEJ9&5R96X_(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L
M971E(')O=R(*;7-G<W1R(")697)W:6ID97(@<FEJ(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V1E;&5T96ED96YT:71Y+FEN8SHQ-0IM<V=I9"`B1&5L971E('-E
M;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@(D=E<V5L96-T965R9&4@:61E;G1I
M=&5I="!V97)W:6ID97)E;B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S0S,30N<&AP.C4S"FUS9VED(")$96QE=&4@<W5B(&9O;&1E<G,B"FUS
M9W-T<B`B5F5R=VEJ9&5R('-U8FUA<'!E;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L
M971E('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R(")697)W:6ID97(@9&4@
M:'5I9&EG92!K;VQO;2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E('1H92!C=7)R
M96YT(')O=R(*;7-G<W1R(")697)W:6ID97(@9&4@:'5I9&EG92!R:6HB"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS
M9W-T<B`B4V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB('9E<G=I:F1E<F0N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C(Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(U,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4V,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4Y-0IM<V=I9"`B1&5L:79E<GD@=&EM92(*;7-G<W1R
M(")!9FQE=F5R=&EJ9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S$*;7-G:60@(D1E;FUA<FLB"FUS
M9W-T<B`B1&5N96UA<FME;B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R
M(")"97-C:')I:F8@:&5T('!R;V)L965M(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.3,X('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S`*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(D)E
M<V-H<FEJ=FEN9R(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,C`V
M"FUS9VED(")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM
M<V=S='(@(D1E=&%I;',@*&]O:R!I;B!(;W)D92=S(&QO9V)E<W1A;F0I.B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,C$P"FUS9VED(")$971A
M:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*
M;7-G<W1R(")$971A:6QS('II:FX@9V5L;V=D('9O;W(@9&4@<WES=&5E;6)E
M:&5E<F1E<BXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(Q"FUS
M9VED(")$979E;&]P;65N="(*;7-G<W1R(")/;G1W:6MK96QI;F<B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(R-`IM<V=I9"`B1&5W(%!O:6YT(@IM<V=S
M='(@(D1A=7=P=6YT(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#$*;7-G
M:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B1&%U=W!U
M;G0@=F]O<B!H970@869G96QO<&5N('5U<CH@(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Q-@IM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T
M<B`B1&%U=W!U;G0Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT
M(@IM<V=S='(@(E)I8VAT:6YG(&QI;FMS(&YA87(@<F5C:'0B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$
M:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R(")2:6-H=&EN9R!R96-H
M=',@;F%A<B!L:6YK<R(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS
M9VED(")$:7)E8W1O<GDB"FUS9W-T<B`B1&ER96-T;W)Y(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(W,`IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I
M;65S/R(*;7-G<W1R("(R-"UU=7)S('1I:F1W965R9V%V93\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3`P"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B
M"FUS9W-T<B`B5V5E<F=A=F5O<'1I97,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z.#D*;7-G:60@(D1I<W!L87D@9&5T86EL960@9F]R96-A
M<W0B"FUS9W-T<B`B1V5D971A:6QL965R9&4@=V5E<G-V;V]R<W!E;&QI;F<@
M=&]N96XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.CDR"FUS9VED(")$:7-P
M;&%Y(&9O<F5C87-T("A4048I(@IM<V=S='(@(E=E97)S=F]O<G-P96QL:6YG
M('1O;F5N("A4048I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<Y
M.0IM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B5V5E<F=A=F5F;W)M
M86%T(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C$Y,0IM<V=I
M9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(E9O;W)B97)E
M:61I;F=S;F]T:69I8V%T:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<P"FUS9VED(")$:FEB;W5T
M:2(*;7-G<W1R(")$:FEB;W5T:2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z-#(R"FUS9VED(")$;R!N;W0@9&5L971E(@IM<V=S='(@(DYI
M970@=F5R=VEJ9&5R96XB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M,C4*;7-G:60@(D1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N
M<&AP(@IM<V=S='(@(FUA:6YT96YA;F-E+G!H<"!N:65T(&1I<F5C="!A86YS
M<')E:V5N(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(@=&5M
M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I
M<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C
M:R!T:&ES(&)O>#HB"FUS9W-T<B`B0F5V870@9&4@965R<W1E(')I:B!D92!V
M96QD;F%M96X_(%IO(&IA+"!D:70@:&]K:F4@86%N=FEN:V5N.B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S(*;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@(D1O;6EN:6-A(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW,PIM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(D1O
M;6EN:6-A86YS92!297!U8FQI96LB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.CDV"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@
M=7`N(@IM<V=S='(@(D=E96X@86-C;W5N=#\@4V-H<FEJ9B!U(&EN+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@U,PIM<V=I9"`B
M1&]W;FQO860B"FUS9W-T<B`B1&]W;FQO861E;B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C@U,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")$;W=N;&]A9"`E<R(*;7-G<W1R("(E<R!D;W=N;&]A9&5N(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO860@9V5N97)A
M=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`B1&]W
M;FQO860@9V5G96YE<F5E<F1E(&-O;F9I9W5R871I92!A;',@4$A0('-C<FEP
M="XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`W"FUS9VED(")$
M<F]P(&1O=VX@;&ES="(*;7-G<W1R(")$<F]P(&1O=VX@;&EJ<W0B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@
M(D1R=6=S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S
M"FUS9VED(")%+4UA:6PB"FUS9W-T<B`B12U-86EL(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL
M+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R
M;W9I9&4@=&AI<R!S97)V:6-E+B(*;7-G<W1R("(B"B)%+6UA:6P@;F%A<B!3
M35,@9V%T97=A>2!S='5U<G!R;V=R86UM82P@=F]O<B!D<F%G97)S(&1I92!D
M97IE('-E<G9I8V4@(@HB;VYD97)S=&5U;F5N+B(*"B,Z(&9R86UE=V]R:R].
M;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z
M,S0*;7-G:60@(D524B(*;7-G<W1R(")%4E(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HW,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<U"FUS9VED
M(")%8W5A9&]R(@IM<V=S='(@(D5C=6%D;W(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C,R-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$Q-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$X,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z-S(*;7-G:60@(D5D:70B"FUS9W-T<B`B0F5W97)K96XB"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4P"FUS9VED(")%9&ET($)L
M;V-K(@IM<V=S='(@(D)L;VL@8F5W97)K96XB"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C$Y."!A9&UI;B]G<F]U<',N<&AP.C(R-@IM<V=I9"`B161I="!'<F]U
M<"(*;7-G<W1R(")'<F]E<"!B97=E<FME;B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z-S8@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HQ,#`*;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R(")296-H="!B
M97=E<FME;B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G
M:60@(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`B4F5C:'1E;B!B97=E<FME
M;B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B
M4F5C:'1E;B!V86X@)R5S)R!B97=E<FME;B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@
M(D]P=&EE<R!B97=E<FME;B!V;V]R.B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R
M;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R(")296-H=&5N('9A;B!<(B5S
M7"(@8F5W97)K96XB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T
M"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S
M(@IM<V=S='(@(E)E8VAT96X@=F%N("5S(&)E=V5R:V5N(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,U"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B
M3VYD97)W:6IS(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW-PIM<V=I9"`B16=Y<'0B"FUS9W-T<B`B
M16=Y<'1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$W"FUS9VED(")%;"!386QV861O<B(*;7-G
M<W1R(")%;"!386QV861O<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM<V=I9"`B16QE;65N="XN+B(*
M;7-G<W1R(")%;&5M96YT+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@(D5M(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R-"!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8Y"FUS9VED(")%;6%I;"(*;7-G
M<W1R(")%+6UA:6PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4V-B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3`*;7-G:60@(D5M
M86EL($%D9')E<W,B"FUS9W-T<B`B12UM86EL861R97,B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.38S"FUS9VED(")%;6%I;"!A9&1R97-S97,@
M;75S="!M871C:"XB"FUS9W-T<B`B12UM86EL861R97-S96X@;6]E=&5N(&]V
M97)E96YK;VUE;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3@Y
M"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")%+6UA
M:6P@;65T(&)E=F5S=&EG:6YG(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V=E;F5R:6-?<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E
M=V%Y(@IM<V=S='(@(D4M;6%I;"!N86%R(%--4R!G871E=V%Y(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y.0IM<V=I9"`B
M16UO=&EC;VYS(@IM<V=S='(@(D5M;W1I8V]N<R(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM<V=I9"`B16UP
M='D@;65S<V%G92XB"FUS9W-T<B`B3&5E9R!B97)I8VAT+B(*"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR-#,@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C0X-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-C8R(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW
M,#4*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-3`*;7-G:60@
M(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B1V5E;B!R97-U;'1A870N(@H*(SH@
M9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$Q,PIM<V=I9"`B16UP
M='D@<V5A<F-H('1E<FUS(@IM<V=S='(@(DQE9V4@>F]E:W1E<FUE;B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#<*;7-G:60@(D5N86)L92!I;G-E
M<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_
M(@IM<V=S='(@(DEN=F]E9V5N('9A;B!A9F)E96QD:6YG96X@=6ET(&9O=&]A
M;&)U;7,@:6X@=&5K<W0@:6YS8VAA:V5L96X_(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4R,@IM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E
M>'0@;65N=3\B"FUS9W-T<B`B4F5C:'1K;&EK:V5N(&-O;G1E>'0@;65N=2!I
M;G-C:&%K96QE;C\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3@X
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W.3,*;7-G:60@(D5N9"!Y96%R
M(@IM<V=S='(@(D5I;F1J86%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%9&ET;W(B"FUS
M9W-T<B`B5F5R9W)O;W0@961I=&]R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(R-`IM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W
M:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y
M;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO
M=7(@<&5T/R<Z(@IM<V=S='(@(B(*(D=E968@965N(&)E=F5I;&EG:6YG<W9R
M86%G(&1I92!U(&=E=G)A86=D('=O<F1T+"!W86YN965R(&AE="!N;V1I9R!I
M<R!O;2!U=R`B"B)W86-H='=O;W)D('1E(')E<V5T=&5N+"!B+G8N("=W870@
M:7,@9&4@;F%A;2!V86X@=7<@:'5I<V1I97(_)SHB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*;7-G
M:60@(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(*;7-G<W1R(")6;V5R(&1E
M(&%F8F5E;&1I;F<@55),(&AI97(@:6XB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DR"FUS9VED(")%;G1E<B!T:&4@;&5T
M=&5R<R!B96QO=SHB"FUS9W-T<B`B5F]E<B!O;F1E<G-T86%N9&4@;&5T=&5R
M<R!I;CHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDY"FUS9VED(")%<75A=&]R:6%L($=U:6YE82(*
M;7-G<W1R(")%<75A=&]R:6%A;"!'=6EN964B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HW-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Y"FUS9VED
M(")%<FET<F5A(@IM<V=S='(@(D5R:71R96$B"@HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O5FEE=RYP:'`Z.30@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS-@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-#@*;7-G:60@(D5R<F]R(@IM<V=S='(@(D9O=70B"@HC.B!F
M<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,B"FUS9W-T<B`B
M1F]U="!B:6H@;6%K96X@=F%N(&)L;VLZ("5S(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S(@IM<V=S='(@(D9O=70@8FEJ('9E
M<G=I:F1E<F5N('9A;B!S>6YC(&%N:V5R.B`E<R(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R
M(&1E;&5T:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R(")&;W5T(&)I:B!V97)W
M:6ID97)E;B!V86X@<WEN8R!L;V<Z("5S(@H*(SH@9G)A;65W;W)K+U1E;7!L
M871E+U1E;7!L871E+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R
M;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*;7-G<W1R(")&;W5T(&)I:B!O<&AA
M;&5N('9A;B!I;FAO=60Z("5S(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T:6YG
M('!A<W-W;W)D.B`E<R(*;7-G<W1R(")&;W5T(&)I:B!B:6IW97)K96X@=F%N
M('=A8VAT=V]O<F0Z("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H(&5M86EL
M(&UE<W-A9V4N(@IM<V=S='(@(D9O=70@;65T(&4M;6%I;&)E<FEC:'0N(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B1F]U="!B:6H@<V-H<FEJ
M=F5N('9A;B!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-@IM<V=I9"`B17-T;VYI82(*
M;7-G<W1R(")%<W1L86YD(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,0IM<V=I9"`B171H:6]P:6$B
M"FUS9W-T<B`B171H:6]P:>LB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R(")%=&YI<V-H(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T
M<B`B175R;W!A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,PIM<V=I
M9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R(")%;&ME(#$U(&UI;G5T96XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDS"FUS9VED(")%=F5R>2`R
M(&UI;G5T97,B"FUS9W-T<B`B16QK92`R(&UI;G5T96XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S0P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*
M;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B16QK92`S,"!S96-O
M;F1E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#(@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,Y-`IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S
M='(@(D5L:V4@-2!M:6YU=&5N(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E
M+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T
M<B`B16QK92!A86YM96QD:6YG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,T-`IM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(D5L:R!H86QF
M('5U<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,Y,@IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@
M(D5L:V4@;6EN=75T(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z
M,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R(")6;V]R8F5E;&1W
M86%R9&5N.B(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HU,2!A9&UI;B]P:'!S
M:&5L;"YP:'`Z.#(@861M:6XO<W%L<VAE;&PN<&AP.C$R.`IM<V=I9"`B17AE
M8W5T92(*;7-G<W1R(")5:71V;V5R96XB"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8Q-`IM<V=I9"`B17AP86YD(@IM
M<V=S='(@(E5I=&ML87!P96XB"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B
M87(N:6YC.C,R"FUS9VED(")%>'!A;F0@4VED96)A<B(*;7-G<W1R(")::6IB
M86QK('5I=&ML87!P96XB"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D
M<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B5F5R=V%C
M:'1T92`G*2<B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z
M,3<U"FUS9VED(")%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C
M:"!T97)M(@IM<V=S='(@(E9E<G=A8VAT=&4@96YK96P@=V]O<F0@;V8@86%N
M9V5H86%L9&4@>F]E:W1E<FTB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R(")6
M97)V86QD871U;2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C<W"FUS9VED(")%>'!O;F5N="(*;7-G<W1R(")%>'!O;F5N="(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(E9O;W)G<F]N9&ML975R(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I9"`B1E10('5P;&]A
M9"!O9B!S971U<"(*;7-G<W1R(")&5%`@=7!L;V%D('9A;B!S971U<"(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S<6PN<&AP.C(R,`IM<V=I9"`B1F%I
M;&5D(')E=')I979I;F<@<')E9F5R96YC97,N(@IM<V=S='(@(D]P:&%L96X@
M=F]O<FME=7)S:6YS=&5L;&EN9V5N(&UI<VQU:W0N(@H*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<U(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@
M<V5R=F5R+B(*;7-G<W1R(")697)B:6YD:6YG(&UE="!D92!,1$%0+7-E<G9E
M<B!I<R!M:7-L=6MT+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H
M<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB
M"FUS9W-T<B`B5F5R8FEN9&EN9R!M970@9&4@4TU"+7-E<G9E<B!I<R!M:7-L
M=6MT+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S$W"B,L('!H
M<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*
M;7-G<W1R(")+;W!IZW)E;B!U:70@7"(E<UPB(&ES(&UI<VQU:W0N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,C(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*;7-G<W1R(")+;W!I
MZW)E;B!N86%R(%PB)7-<(B!I<R!M:7-L=6MT+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<V%S;"YP:'`Z.#<*;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@
M;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`B36%K96X@=F%N(&YI975W
M92!305-,('9E<F)I;F1I;F<@:7,@;6ES;'5K="XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C<U-2!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C4P,0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@;6]V92!T;R!<
M(B5S7"(N(@IM<V=S='(@(E9E<G!L86%T<V5N(&YA87(@7"(E<UPB(&ES(&UI
M<VQU:W0N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G
M<W1R(")/<&AA;&5N('9A;B`E<R!I<R!M:7-L=6MT(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS
M9W-T<B`B36]O:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0*;7-G:60@(D9A;&ML86YD($ES;&%N
M9',@*$UA;'9I;F%S*2(*;7-G<W1R(")&86QK;&%N9"!E:6QA;F1E;B`H36%L
M=FEN87,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX-@IM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G
M<W1R(")&87)OZW(@96EL86YD96XB"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP
M:'`Z,C,X"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`B1F%T86QE(&9O
M=70Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@(D9A>"(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS-3$*;7-G:60@(D9A>&5S(@IM<V=S='(@(D9A>&5N
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Q
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*
M;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(D9E8G)U87)I(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,C<*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B
M5F]E;'0@86QS(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R
M,`IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(E9O96QT(&%L<SH@(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G
M:60@(D9E=R!3:&]W97)S(@IM<V=S='(@(D5N:V5L92!B=6EE;B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS9VED(")&
M97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(D5N:6=E('-N965U=V)U:65N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-`IM<V=I9"`B1FEE;&0@
M;6%T<FEX(@IM<V=S='(@(E9E;&1M871R:7@B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,S(U"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R
M(")&:6=L970@0T%05$-(02(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,S,CD*;7-G:60@(D9I9VQE="!F;VYT(@IM<V=S='(@(D9I9VQE="!F;VYT
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX,PIM<V=I9"`B1FEJ:2(*;7-G<W1R(")&:6II(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")&:6QE(@IM
M<V=S='(@(D)E<W1A;F0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-SD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM
M<V=S='(@(D%A;G1A;"!B97-T86YD96XZ("5S(&)E<W1A;F0B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HV-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&
M:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R(")!86YT86P@8F5S=&%N9&5N
M.B`E<R!B97-T86YD96XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#`Y"FUS9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`B0F5S=&%N9&)E:&5E
M<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"FUS9VED(")&:6QE
M($YA;64B"FUS9W-T<B`B0F5S=&%N9'-N86%M(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,CDW-PIM<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T
M<B`B0F5S=&%N9"!K:65Z96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-#@V"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R(")"97-T86YD=7!L
M;V%D(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3`R"FUS
M9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B0F5S
M=&%N9'5P;&]A9',@=V]R9&5N(&YI970@;VYD97)S=&5U;F0N(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDQ"FUS9VED(")&:6QT97)S(@IM<V=S
M='(@(D9I;'1E<G,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@R"FUS9VED(")&:6YL86YD(@IM<V=S
M='(@(D9I;FQA;F0B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED
M(")&:7)S="!(86QF(@IM<V=S='(@(D5E<G-T92!H96QF="(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@
M(D9I<G-T(%%U87)T97(B"FUS9W-T<B`B165R<W1E(&MW87)T86%L(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U-PIM<V=I
M9"`B1FEX(')A=&EO(@IM<V=S='(@(E9E<FAO=61I;F<@:&5R<W1E;&QE;B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S(*
M;7-G:60@(D9L:7`B"FUS9W-T<B`B3VUK97)E;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L
M;V%T(@IM<V=S='(@(D1R:6IV96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G(@IM<V=S='(@(DUI<W0B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3`W(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z,C,W"B,L('!H<"UF;W)M870*;7-G:60@(D9O
M;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*;7-G<W1R(")-87`@)7,@8F5S=&%A
M="!N:65T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R(")&;VYT:VQE=7(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS
M9W-T<B`B5F]E9'-E;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$R,PIM<V=I9"`B1F]R(&)R;W=S97)S
M('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B5F]O<B!B<F]W
M<V5R<R!D:64@9V5E;B!A9F)E96QD:6YG96X@;VYD97)S=&5U;F5N(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#$*;7-G:60@(D9O<F5C87-T("A4048I
M(@IM<V=S='(@(E=E97)S=F]O<G-P96QL:6YG("A4048I(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C<R"FUS9VED("(B"B)&;W)E8V%S="!$
M87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@
M8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O
M=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*(E9O;W)U
M:71Z:6-H=&1A9V5N("AM97)K(&]P(&1A="!H970@9V5G979E;B!V;V]R=6ET
M>FEC:'0@9&%G96X@96X@;F%C:'1E;B`B"B)G965F=#L@965N(&=R;V]T(&%A
M;G1A;"!K86X@<F5S=6QT97)E;B!I;B!E96X@8G)E960@8FQO:RDB"@HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$P,@IM<V=I9"`B1F]R9V]T('EO
M=7(@<&%S<W=O<F0_(@IM<V=S='(@(E5W('=A8VAT=V]O<F0@=F5R9V5T96X_
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V-`IM<V=I9"`B1F]R
M;7,B"FUS9W-T<B`B1F]R;75L:65R96XB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,C$*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`B1F]R='5N92(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E
M(@IM<V=S='(@(D9O<G1U;F5T>7!E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,X"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R(")&;W)T=6YE<R(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*
M;7-G<W1R(")&;W)T=6YE<R`R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0U-0IM<V=I9"`B1F]R=6US(@IM<V=S='(@(D9O<G5M<R(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,3$*;7-G:60@(D9O<G=A<F1S(@IM
M<V=S='(@(D1O;W)S='5R96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R(")6<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S,*;7-G:60@(D9R86UE<R(*;7-G<W1R(")&<F%M97,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@W
M"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B1G)A;FMR:6IK(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4L($UE=')O
M<&]L:71A;B(*;7-G<W1R(")&<F%N:W)I:FLL($AO;V9D<W1E9&5L:6IK(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY,0IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R(")&<F%N
M<R!'=7EA;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I
M82(*;7-G<W1R(")&<F%N<R!0;VQY;F5S:>LB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C(*;7-G
M:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*;7-G<W1R(")&<F%N
M<V4@6G5I9&5L:6IK92!497)R:71O<FEA(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R
M(")686XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,W(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-#D*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,Y-0IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@
M(E9A;B!D92`B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT
M.`IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R(")6;VQL961I9V4@
M8F5S8VAR:6IV:6YG(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]"
M;&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R(")6
M;VQL92!M86%N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8U('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*;7-G:60@(D9U;&P@3F%M
M92(*;7-G<W1R(")6;VQL961I9V4@;F%A;2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#@*;7-G:60@
M(D=A8F]N(@IM<V=S='(@(D=A8F]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL
M97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R(")!;&)U;2!W86%R=6ET
M(&1E(&%F8F5E;&1I;F<@9V5H86%L9"!D:65N="!T92!W;W)D96XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(D%L8G5M.B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.38*;7-G:60@(D=A;6)I82(*;7-G<W1R(")'86UB:6$B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@(D=E
M;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B1V5N97)E97(@)7,@
M8V]N9FEG=7)A=&EE(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I
M9RYH=&UL.C@*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@(D=E9V5N
M97)E97)D92!C;V1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,`IM<V=I9"`B1V5O<F=I82(*;7-G
M<W1R(")'96]R9VGK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G
M<W1R(")$=6ET<VQA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDS"FUS9VED(")':&%N82(*;7-G
M<W1R(")':&%N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.30*;7-G:60@(D=I8G)A;'1A<B(*;7-G
M<W1R(")':6)R86QT87(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4W-@IM<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R(")6;V]R;F%A
M;2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S4@=&5M<&QA
M=&5S+W!R969S+V%P<"YI;F,Z,3`*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI
M;F,Z,3D*;7-G:60@(D=L;V)A;"!/<'1I;VYS(@IM<V=S='(@(D=L;V)A;&4@
M;W!T:65S(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3<*;7-G:60@
M(D=O(@IM<V=S='(@(D=A(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P
M"FUS9VED(")';V5D96PB"FUS9W-T<B`B1V]E9&5L(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,S$*;7-G:60@(D=O;V=L
M92!-87!S(@IM<V=S='(@(D=O;V=L92!K86%R=&5N(@H*(SH@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE+G!H<#HR,2!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE(%-E87)C:"(*;7-G<W1R
M(")';V]G;&4@>F]E:V5N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(S.`IM<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@(D=R
M:6IS<V-H86%L(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`*;7-G:60@(D=R965C92(*;7-G<W1R
M(")'<FEE:V5N;&%N9"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS
M9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B1W)I96MS("A)4T\M
M.#@U.2TW*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.34*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R
M(")'<F]E;FQA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y"FUS9VED(")'<F5N861A(@IM<V=S
M='(@(D=R96YA9&$B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W.0IM<V=I9"`B
M1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B1W)O97!S8F5H965R(@H*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+G!H<#HU.2!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N86UE<R!M=7-T
M(&)E(&YO;BUE;7!T>2(*;7-G<W1R(")'<F]E<&YA;65N(&UO9V5N(&YI970@
M;&5E9R!Z:6IN(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C,P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@
M=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M.B`B"FUS9W-T<B`B1W)O=7!?;&1A<#H@3FEE="!I;B!S=&%A="!G<F]E<"`E
M<R!T;V4@=&4@=F]E9V5N+B!$92!S97)V97(@;65L9'0Z("(*"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3@@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z
M(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS9W-T<B`B1W)O=7!?;&1A
M<#H@3FEE="!I;B!S=&%A="!G<F]E<"`E<R!T92!V97)W:6ID97)E;B(*"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,S@@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,W.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S
M='(@(D=R;W5P7VQD87`Z($YI970@:6X@<W1A870@9W)O97`@)7,@8FEJ('1E
M('=E<FME;B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S$T
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS9W-T<B`B1W)O97!E;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.3@*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B1W5A9&5L
M;W5P92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3`S"FUS9VED(")'=6%M(@IM<V=S='(@(D=U86TB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$P,@IM<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@(D=U871E
M;6%L82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3(*;7-G:60@
M(D=U97)N<V5Y(@IM<V=S='(@(D=U97)N<V5Y(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B1V%S="!R
M96-H=&5N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W,@IM<V=I
M9"`B1W5E<W1B;V]K(@IM<V=S='(@(D=A<W1E;F)O96LB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HY.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDW
M"FUS9VED(")'=6EN96$B"FUS9W-T<B`B1W5I;F5E(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`T
M"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(D=U:6YE92U":7-S874B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,#4*;7-G:60@(D=U>6%N82(*;7-G<W1R(")'=7EA;F$B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-C`*;7-G:60@(DA434PB
M"FUS9W-T<B`B2%1-3"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY
M(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+B(*;7-G
M<W1R(")(5$U,07)E82!W96EG97)T(&QA9B!O;2!D92!L86%T<W1E(&-E;"!I
M;B!D92!R:6H@=&4@=F5R=VEJ9&5R96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R
M96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN
M(&EN('1A8FQE+B(*;7-G<W1R(")(5$U,07)E82!W96EG97)T(&QA9B!O;2!D
M92!L86%T<W1E(&MO;&]M(&EN(&1E('1A8F5L('1E('9E<G=I:F1E<F5N+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#<*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L
M971E('1H92!L87-T(')O=R!I;B!T86)L92XB"FUS9W-T<B`B2%1-3$%R96$@
M=V5I9V5R="!L868@;VT@9&4@;&%A='-T92!R:6H@:6X@9&4@=&%B96P@=&4@
M=F5R=VEJ9&5R96XN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H
M<#HQ-3<*;7-G:60@(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")(5%10(&%U=&AE;G1I8V%T:64@;FEE="!G979O;F1E;BXB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,3`*;7-G:60@(DAA:71I(@IM<V=S='(@(DAA:71I(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")(87-H
M+4%L9V]R:71H;2(*;7-G<W1R(")(87-H+6%L9V]R:71H;64B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@IM<V=I9"`B2&%Z
M92(*;7-G<W1R(").979E;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.CDQ.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3$T"FUS9VED(")(96%D
M97(B"FUS9W-T<B`B2V]P(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E
M+W1A8FQE<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R(")+;W!P
M96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#<*;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$
M;VYA;&0@27-L86YD<R(*;7-G<W1R(")(96%R9"!E:6QA;F0@96X@36-$;VYA
M;&0@96EL86YD96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR,PIM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R("):=V%R
M92!O;G=E97)S8G5I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G
M:60@(DAE8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R(")(96)R965U=W,@
M*$E33RTX.#4Y+3@M22DB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HR,B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T
M"FUS9VED(")(96EG:'0B"FUS9W-T<B`B2&]O9W1E(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$X-"!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O2&5L<"YP:'`Z,3@V"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W
M('1E;7!L871E<R]H96QP+VEN9&5X+FEN8SHT"FUS9VED(")(96QP(@IM<V=S
M='(@(DAE;'`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R(")(
M96QP(&)I:B!G96)R=6EK('9A;B!E9&ET;W(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,S<Q"FUS9VED(")(96QP97(B"FUS9W-T<B`B2&5L<&5R
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H97)E
M(@IM<V=S='(@(DAA;&9R;VYD(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`*;7-G:60@
M(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B
M2&EE<B!I<R!H970@8F5G:6X@=F%N(&AE="!B97-T86YD.B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")(:6=H
M(@IM<V=S='(@(DAO;V<B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC
M.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C4*;7-G:60@
M(DAO7VUE(@IM<V=S='(@(DAO7VUE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,PIM<V=I9"`B
M2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`B2&]L>2!3
M964@*%9A=&EC86%N<W1A9"DB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C$U-#@*;7-G:60@(DAO;64B"FUS9W-T<B`B2&]M92(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M
M92!!9&1R97-S(@IM<V=S='(@(D%D<F5S("AP<FEVZ2DB"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-S`*;7-G:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S
M='(@(DAO;65D:7)E8W1O<GDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@
M(E1E;"YN<BX@*'!R:7;I*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.`IM<V=I9"`B2&]N9'5R
M87,B"FUS9W-T<B`B2&]N9'5R87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#8*;7-G:60@(DAO
M;F<@2V]N9R(*;7-G<W1R(")(;VYG($MO;F<B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-C<*;7-G:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-3(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC
M;W5N=&5R960@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@
M3VYG96QD:6=E("5S(%A-3"!D871A('1E9V5N9V5K;VUE;B!I;B!B97)I8VAT
M("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR.3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S
M<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!'965N
M(&)E<FEC:'0@8V]R<F5S<&]N9&5E<G0@;65T(&]B:F5C="`E<R(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#0U"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I
M;B!M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!'965N(&]B:F5C
M="!V86X@='EP92`E<R!G979O;F1E;B!I;B!B97)I8VAT("5S(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C4Q"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S
M7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(Z("5S(&UE="!S=6-C97,@=F5R=VEJ
M9&5R9"!<(B5S7"(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(R
M,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@
M<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B
M2&]R9&4O2V]L86(Z($1E(&EN=&5R9W)A=&EE('9E<F5I<W0@9&4@)V1O;7AM
M;"<@97AT96YS:64B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C4Q
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O
M(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R(")(
M;W)D92]+;VQA8CH@2V%N(&=E96X@;FEE=7=E(%A-3"!B;V]M(&UA:V5N('9O
M;W(@;V)J96-T("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ
M,C0X"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z
M($MA;B`E<R!<(B5S7"(@;FEE="!V97)W:6ID97)E;CH@)7,B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C0X,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R
M('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B(@HB2&]R9&4O2V]L86(Z
M($YI970@:6X@<W1A870@:&5T($U)344@240L('9O;W(@:&5T(&=E9&5E;'1E
M(&UE="!T>7!E("5S+"!O<"!T92`B"B)H86QE;B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,3$Y-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B
M"FUS9W-T<B`B2&]R9&4O2V]L86(Z($MA;B`E<R!<(B5S7"(@;FEE="!S>6YC
M:')O;FES97)E;CH@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C$S,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@(DAO<F1E+TMO
M;&%B.B!+86X@9V5D965L9&4@8G)O;FYE;B!N:65T('-Y;F-H<F]N:7-E<F5N
M.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,S0P"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB
M)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@3VYB96ME;F1E(&=E9&5E;&1E
M(&)R;VX@7"(E<UPB(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@
M(DAO<FEZ;VYT86QE(&QI:FXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B
M"FUS9W-T<B`B2&]R:7IO;G1A;&4@=G)I:F4@<G5I;71E(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R
M:7IO;G1A;#HB"FUS9W-T<B`B2&]R:7IO;G1A86PZ(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q"FUS9VED
M(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*2(*;7-G
M<W1R(")(;V4@:W=A;2!U(&AI97(_("A'<F%A9R!R87!P;W)T86=E(2DB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O
M(&UE<F=E/R(*;7-G<W1R(")(;V5V965L(&MO;&]M;65N('=I;'0@=2!S86UE
M;G9O96=E;C\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR,0IM
M<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_(@IM
M<V=S='(@(DAO979E96P@=F5L9&5N("AK;VQO;6UE;BD@>FEJ;B!E<C\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,V"FUS9VED(")(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE
M<F=E/R(*;7-G<W1R(")(;V5V965L(')I:F5N('=I;'0@=2!S86UE;G9O96=E
M;C\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(S-R!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C@Y"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R(")6
M;V-H=&EG:&5I9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-#@*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B5F]C:'1I9VAE:60Z("(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S
M(@IM<V=S='(@(DAU;6]R:7-T96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3$*;7-G:60@(DAU
M;F=A<GDB"FUS9W-T<B`B2&]N9V%R:6IE(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]C>7)S<6PN<&AP.C(S-2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S
M+G!H<#HQ-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R
M96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B36%K96X@=F%N($E-05`@;6%I
M;&)O>"!M:7-L=6MT.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M<W%L+G!H<#HR.34@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C$T
M"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F
M86EL960Z("5S(@IM<V=S='(@(E9E<G=I:F1E<F5N('9A;B!)34%0(&UA:6QB
M;W@@;6ES;'5K=#H@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q
M;"YP:'`Z,C0R(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I
M;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")-86ME;B!V86X@24U!4"!M86EL8F]X
M('%U;W1A(&UI<VQU:W0Z("5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3,Q-@IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R("))4"!!9')E<R(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@
M(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B25`@861R97,@
M;FEE="!B97-C:&EK8F%A<BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP
M8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL
M;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("))4"!A9')E<R!V86QT(&YI970@
M8FEN;F5N(&AE="!T;V5G97-T86YE($-)1%(@8FQO:RXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@
M(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B25`@;&]C:V1O=VX@
M;W9E<G1R961I;F<N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O
M<F4B"FUS9W-T<B`B4FEJ(&E?;G9O96=E;B!V;V]R(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(P
M"FUS9VED("))8V5L86YD(@IM<V=S='(@(DE*<VQA;F0B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S@P"FUS9VED("))8V]N<R!/;FQY(@IM<V=S='(@
M(D%L;&5E;B!P:6-T;V=R86UM96XB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP
M:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S
M='(@(E!I8W1O9W)A;6UE;B!V;V]R("5S(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,X,0IM<V=I9"`B26-O;G,@=VET:"!T97AT(@IM<V=S='(@(E!I
M8W1O9W)A;6UE;B!M970@=&5K<W0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3DS"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@(DED96YT
M:71E:71S;F%A;3HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HV,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I
M<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN
M9&]W+B(*;7-G<W1R("(B"B)786YN965R(&AE="!N:65T(&=O960@=V]R9'0@
M=V5E<F=E9V5V96XL("5S(&]M(&AE="!I;B!E96X@;FEE=7<@<V-H97)M('1E
M("(*(F]P96YE;BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4Y"FUS
M9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E
M<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@
M8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*
M(D%L<R!U(&=E96X@<&EC=&]G<F%M;65N('II970L(&)I:B!G96)R=6EK('9A
M;B!);G1E<FYE="!%>'!L;W)E<BP@:V%N(&AE="`B"B)N;V1I9R!Z:6IN(&1I
M="!V86MJ92!A86X@=&4@=FEN:V5N(&]M(%!.1R!T<F%N<W!A<F%T:64@=6ET
M('1E('-C:&%K96QE;BXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3<R"FUS9VED("(B"B))9B!Y;W4@<V5E('1H:7,@;65S
M<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO
M860@8V%N)W0@8F4@(@HB9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS
M9W-T<B`B(@HB5V%N;F5E<B!U(&1I="!B97)I8VAT('II970L(&UA87(@9V5E
M;B!A9F)E96QD:6YG+"!D86X@:V%N(&1E(&%F8F5E;&1I;F<@9&EE("(*(G4@
M=VEL="!U<&QO861E;B!N:65T(&1O;W(@=7<@8G)O=W-E<B!W;W)D96X@=V5E
M<F=E9V5V96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(X"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"FUS9VED("));6%G92!0<F5V:65W.B(*
M;7-G<W1R(")!9F)E96QD:6YG<V)E;V]R9&5L:6YG.B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@
M(DEM86=E(%523"(*;7-G<W1R(")!9F)E96QD:6YG(%523"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M.`IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R(")!9F)E96QD:6YG(%523#HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R
M(")!9F)E96QD:6YG('5I="!A;&)U;2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA
M9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R(")!9F)E96QD:6YG('5I="!A;&)U
M;3HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8Q"FUS9VED("))
M;6%G92!U<&QO860B"FUS9W-T<B`B069B965L9&EN9W-U<&QO860B"@HC.B!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@
M(D%F8F5E;&1I;F=E;B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C<@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-`HC.B!T96UP;&%T97,O
M9&%T82]D871E;6%P+FEN8SHW('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC
M.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S
M='(@(DEM<&]R=&5R96XL('-T87`@)60B"@HC.B!T96UP;&%T97,O9&%T82]D
M871E;6%P+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F
M:65L9#H@)7,B"FUS9W-T<B`B1V5I;7!O<G1E97)D('9E;&0Z("5S(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T960@
M9FEE;&1S.B(*;7-G<W1R(")'96EM<&]R=&5E<F1E('9E;&1E;CHB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@(E)I:B!I;G9O
M96=E;B!N82(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N
M<&AP.C$S-`IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*
M;7-G<W1R(")/;FIU:7-T92!B97=E<FMI;F=S8V]D92!O<&=E9V5V96XN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,S(*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N
M(@IM<V=S='(@(D]N:G5I<W1E(&=E8G)U:6ME<G-N86%M(&5N+V]F('=A8VAT
M=V]O<F0N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-3$*;7-G
M:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S
M<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI;FES=')A=&]R
M(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB3VYJ=6ES
M=&4@9V5B<G5I:V5R<VYA86T@;V8@86QT97)N871I968@861R97,N(%!R;V)E
M97(@;W!N:65U=R!O9B!N965M("(*(F-O;G1A8W0@;W`@;65T(&1E('-Y<W1E
M96UB96AE97)D97(L('=A;FYE97(@=2!V97)D97)E(&AU;'`@;F]D:6<@:&5E
M9G0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@(E9E<F=R;V]T
M(&EN<W!R:6YG:6YG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$V"FUS9VED("));F1I82(*;7-G
M<W1R("));F1I82(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,C4T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS9VED("));F1I
M=FED=6%L(%5S97)S(@IM<V=S='(@(DEN9&EV:61U96QE(&=E8G)U:6ME<G,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,3(*;7-G:60@(DEN9&]N97-I82(*;7-G<W1R("));F1O
M;F5S:>LB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N
M<&AP.C8W"FUS9VED("));F9O(@IM<V=S='(@(DEN9F\B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C4Y"FUS9VED("));F9O<FUA=&EO;B(*;7-G
M<W1R("));F9O<FUA=&EE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,Q.0IM<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L
M92XB"FUS9W-T<B`B26YF;W)M871I92!N:65T(&QA;F=E<B!B97-C:&EK8F%A
M<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S4*;7-G:60@(DEN<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S
M='(@(DMO;&]M(&EN=F]E9V5N(&YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"FUS9VED("));G-E
M<G0@26UA9V4B"FUS9W-T<B`B069B965L9&EN9R!I;G9O96=E;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@
M(DEN<V5R="!486)L92(*;7-G<W1R(")486)E;"!I;G9O96=E;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@
M(DEN<V5R="!796(@3&EN:R(*;7-G<W1R(")796)L:6YK(&EN=F]E9V5N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,T"FUS9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B
M7TMO;&]M(&EN=F]E9V5N('9O;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(DEN<V5R="!A
M(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(D5E
M;B!N:65U=V4@:V]L;VT@:6YV;V5G96X@;F$@9&4@:'5I9&EG92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E
M;G0@;VYE(@IM<V=S='(@(D5E;B!N:65U=V4@:V]L;VT@:6YV;V5G96X@=F]O
M<B!D92!H=6ED:6=E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8R"FUS9VED("));G-E<G0@82!N97<@<F]W
M(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R(")%96X@;FEE=7=E(')I
M:B!I;G9O96=E;B!N82!D92!H=6ED:6=E(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E
M<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B
M165N(&YI975W92!R:6H@:6YV;V5G96X@;F$@9&4@:'5I9&EG92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW
M,`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT
M(&YO9&4B"FUS9W-T<B`B165N(&YI975W92!P87)A9W)A868@:6YV;V5G96X@
M;F$@9&4@:'5I9&EG92!N;V1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P
M87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B165N
M(&YI975W92!P87)A9W)A868@:6YV;V5G96X@;F$@9&4@:'5I9&EG92!N;V1E
M(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A
M;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B06QT97)N871I968@<VIA8FQO
M;VX@:6YV;V5G96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0R"FUS
M9VED("));G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N
M(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B165N(&4M;6%I
M;&%D<F5S(&EN=F]E9V5N+"!W86%R('4@:&5T(&YI975W92!W86-H='=O;W)D
M(&MA;B!O;G1V86YG96XZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`IM<V=I9"`B26YS97)T(&-E;&P@869T
M97(B"FUS9W-T<B`B0V5L(&EN=F]E9V5N(&YA(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0IM<V=I9"`B26YS
M97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(D-E;"!I;G9O96=E;B!V;V]R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R(")+;VQO
M;2!I;G9O96=E;B!N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F
M;W)E(@IM<V=S='(@(DMO;&]M(&EN=F]E9V5N('9O;W(B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,`IM<V=I9"`B26YS97)T(&UE
M<W-A9V5S(@IM<V=S='(@(D)E<FEC:'1E;B!I;G9O96=E;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-0IM
M<V=I9"`B26YS97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R(")087)A9W)A
M868@:6YV;V5G96X@;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A
M<&@@8F5F;W)E(@IM<V=S='(@(E!A<F%G<F%A9B!I;G9O96=E;B!V;V]R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV.0IM<V=I9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R(")2:6H@:6YV
M;V5G96X@;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E9F]R92(*;7-G
M<W1R(")2:6H@:6YV;V5G96X@=F]O<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR,S,*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O
M('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B2&5T(&=E=V5N<W1E
M(&%N='=O;W)D('9O;W(@9&4@8F5V96EL:6=I;F=S=G)A86<@:6YV;V5G96XZ
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M-@IM<V=I9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R(")!9F)E96QD
M:6YG(&EN=F]E9V5N+V%A;G!A<W-E;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@
M3&EN:R(*;7-G<W1R("),:6YK(&EN=F]E9V5N+V%A;G!A<W-E;B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS
M9VED("));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R
M:6)U=&EO;B!L:7-T+B(*;7-G<W1R(")/;G9O;&1O96YD92!K<F5D:65T(&]M
M(&YA87(@9&4@9&ES=')I8G5T:65L:6IS="!T92!Z96YD96XN(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G
M:60@(DEN<W5F9FEC:65N="!C<F5D:70N(@IM<V=S='(@(D]N=F]L9&]E;F1E
M(&MR961I970B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<U"FUS
M9VED("));G1E9V5R(@IM<V=S='(@(DEN=&5G97(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,3,S"FUS9VED("));G1E9V5R(&QI<W0B"FUS9W-T
M<B`B26YT96=E<B!L:6IS="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI9"!51$@N("A5
M<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B3VYG96QD:6=E(%5$2"X@*%5S
M97(@1&%T82!(96%D97(I+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]Z:7`N<&AP.C$V-PHC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O>FEP+G!H<#HQ.30*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S
M+WII<"YP:'`Z,C$R"FUS9VED("));G9A;&ED(%I)4"!D871A(@IM<V=S='(@
M(D]N9V5L9&EG92!:25`@9&%T82(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P;&EC871I;VXN(@IM<V=S='(@(D]N
M9V5L9&EG92!T;V5P87-S:6YG+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI9"!B871C
M:"!)1"XB"FUS9W-T<B`B3VYG96QD:6<@8F%T8V@@240N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`X-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,34X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,S(@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C(Y.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+U1Y<&4O=&%B;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B
M;6ET=&5D+B(*;7-G<W1R(")/;F=E;&1I9V4@9&%T82!O<&=E9V5V96XN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`P"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S
M='(@(D]N9V5L9&EG(&)E<W1E;6UI;F=A9')E<RXB"@HC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,#D*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,3,Y"B,Z(&9R86UE=V]R:R]#;VUP
M<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C(T,0IM<V=I9"`B26YV86QI9"!F:6QE
M(&9O<FUA="(*;7-G<W1R(")/;F=E;&1I9R!T:6ID9F]R;6%A="(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C4*;7-G:60@(DEN=F%L:60@
M;&EC96YS92!K97DN(@IM<V=S='(@(D]N9V5L9&EG92!L:6-E;G1I97-L975T
M96PN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U.0IM<V=I
M9"`B26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B3VYG96QD
M:6=E(&QO8V%T:64@;W!G96=E=F5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M
M<V=?='EP92XB"FUS9W-T<B`B3VYG96QD:6<@;7-G7W1Y<&4N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S"FUS
M9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*;7-G<W1R(")/;F=E
M;&1I9R!O9B!O;G1B<F5K96YD(&%P:5]I9"XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.38*;7-G:60@(DEN=F%L
M:60@;W(@;6ES<VEN9R!P87)A;65T97)S+B(*;7-G<W1R(")/;F=E;&1I9V4@
M;V8@;VYT8G)E:V5N9&4@<&%R86UE=&5R<RXB"@HC.B!A9&UI;B]P97)M<R]A
M9&1C:&EL9"YP:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I
M;VXN(@IM<V=S='(@(D]N9V5L9&EG('!A<F5N="!R96-H="XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Q"FUS9VED("));G9A;&ED('!A
M<G1N97(@:60N(@IM<V=S='(@(D]N9V5L9&EG('!A<G1N97(@:60N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,PIM<V=I9"`B26YV86QI
M9"!P<F]D=6-T(&-O9&4N(@IM<V=S='(@(D]N9V5L9&EG92!P<F]D=6-T:65C
M;V1E+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B
M3VYG96QD:6<@<')O=&]C;VPN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HY,PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C<Q(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!R96-I
M<&EE;G0Z(%PB)7-<(B(*;7-G<W1R(")/;F=E;&1I9V4@;VYT=F%N9V5R.B!<
M(B5S7"(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$P.#`@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C8S"FUS9VED("));G9A;&ED('-H
M87)E(&]B:F5C="(*;7-G<W1R(")/;F=E;&1I9V4@9V5D965L9&4@8G)O;B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P,0IM<V=I9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B
M3VYG96QD:6<@8G)O;F%D<F5S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0IM<V=I9"`B26YV86QI9"!U;FEC
M;V1E(&1A=&$N(@IM<V=S='(@(D]N9V5L9&EG92!U;FEC;V1E(&1A=&$N(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U.0IM<V=I9"`B26YV96YT
M;W)Y(@IM<V=S='(@(DEN=F5N=&%R:7,B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<X"FUS9VED("));G9E<G0@<V5L96-T
M:6]N(@IM<V=S='(@(E-E;&5C=&EE(&]M:V5R96XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3D*
M;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B27)A
M;BP@27-L86UI=&ES8VAE(%)E<'5B;&EE:R!V86XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3@*
M;7-G:60@(DER87$B"FUS9W-T<B`B27)A:R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,PIM<V=I
M9"`B27)E;&%N9"(*;7-G<W1R("))97)L86YD(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@;V8@36%N(@IM<V=S='(@
M(D5I;&%N9"!-86XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR-`IM<V=I9"`B27-O;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B
M1V5I<V]L965R9&4@;VYW965R<V)U:65N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$T"FUS9VED
M("))<W)A96PB"FUS9W-T<B`B27-R8>ML(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV,C8*;7-G:60@(DES<W5E<B(*;7-G<W1R(")5
M:71G979E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(D-U<G-I968B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,C$*;7-G:60@(DET86QY(@IM<V=S='(@(DET86QIZR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R,PIM<V=I9"`B2F%M86EC82(*;7-G<W1R(")*86UA:6-A(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@
M(DIA;G5A<GDB"FUS9W-T<B`B2F%N=6%R:2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-0IM<V=I
M9"`B2F%P86XB"FUS9W-T<B`B2F%P86XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$Y,`IM<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R
M(")*87!A;G,@*$E33RTR,#(R+4I0*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(R"FUS9VED(")*97)S97DB"FUS9W-T<B`B2F5R<V5Y(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(T"FUS9VED(")*;W)D86XB"FUS9W-T<B`B2F]R9&%N:>LB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#8*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM
M<V=I9"`B2G5L>2(*;7-G<W1R(")*=6QI(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B
M2G5N:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`B=6ET;&EJ;F5N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(D=E8V5N
M=')E97)D('5I=&QI:FYE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$W"FUS9VED(")*=7-T:69Y($9U;&PB
M"FUS9W-T<B`B5F]L;&5D:6<@=6ET;&EJ;F5N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G:60@(DIU
M<W1I9GD@3&5F="(*;7-G<W1R("),:6YK<R!U:71L:6IN96XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM
M<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R(")296-H=',@=6ET;&EJ;F5N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@(DMA
M>F%C:'-T86XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C8U"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G<W1R(")/<FEG
M:6YE96P@8F5H;W5D96X_(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(V"FUS9VED(")+96YY82(*
M;7-G<W1R(")+96YI82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP
M:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B2V5R8F5R;W,@<V5R=F5R('=E:6=E<F1E(&%U
M=&AE;G1I8V%T:64N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS
M9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R(")+97)N96P@3F5W8FEE<R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B
M2V5Y($-R96%T:6]N(@IM<V=S='(@(E-L975T96P@;6%K96XB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@(DME>2!&:6YG
M97)P<FEN="(*;7-G<W1R(")3;&5U=&5L=FEN9V5R869D<G5K(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N
M9W1H(@IM<V=S='(@(E-L975T96QL96YG=&4B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@
M(E-L975T96QT>7!E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.3D*;7-G:60@(DME>2!5<V%G92(*;7-G<W1R(")3;&5U=&5L9V5B
M<G5I:R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<T,`IM
M<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R
M=F5R+B(*;7-G<W1R(")$92!S;&5U=&5L(&)E<W1A870@86P@;W`@9&4@;W!E
M;F)A<F4@<VQE=71E;'-E<G9E<BXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`B2VEN9&5R96XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,CD*;7-G:60@(DMI<FEB871I(@IM<V=S='(@(DMI<FEB871I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,R"FUS9VED(")+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!2
M97!U8FQI8R!O9B(*;7-G<W1R(")+;W)E82P@1&5M;V-R871I<V-H92!6;VQK
M<W)E<'5B;&EE:R!V86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S,*;7-G:60@(DMO<F5A+"!2
M97!U8FQI8R!O9B(*;7-G<W1R(")+;W)E82P@4F5P=6)L:65K('9A;B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ"FUS9VED(")+;W)E86X@*$550RU+
M4BDB"FUS9W-T<B`B2V]R96%A;G,@*$550RU+4BDB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S0*
M;7-G:60@(DMU=V%I="(*;7-G<W1R(")+;V5W96ET(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(W
M"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(DMY<F=I97-IZR(*"B,Z('1E
M;7!L871E<R]P;W)T86PO;65N=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G
M<W1R(")/7W!M86%K(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX
M,PIM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B5&%A;"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S
M-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS
M9W-T<B`B1&5M;V-R871I<V-H92!6;VQK<W)E<'5B;&EE:R!,86\B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),87-T($AA;&8B"FUS9W-T
M<B`B3&%A='-T92!H96QF="(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX
M.`IM<V=I9"`B3&%S="!087-S=V]R9"!#:&%N9V4B"FUS9W-T<B`B3&%A='-T
M92!W86-H='=O;W)D=VEJ>FEG:6YG(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R=&5R
M(@IM<V=S='(@(DQA871S=&4@:W=A<G1I97(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$U.`IM<V=I9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R("),86%T
M<W0@8FEJ9V5W97)K=#HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW
M,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T
M<B`B3&%A='-T92!A86YM96QD:6YG.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN
M.B`E<R!F<F]M("5S(@IM<V=S='(@(DQA871S=&4@86%N;65L9&EN9SH@)7,@
M=F%N("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$T"FUS9VED
M("),87-T(&QO9VEN.B!.979E<B(*;7-G<W1R("),86%T<W1E(&%A;FUE;&1I
M;F<Z($YO;VET(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30V"FUS9VED("),871V:6$B"FUS9W-T
M<B`B3&5T;&%N9"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I
M9"`B3&%W(@IM<V=S='(@(E)E8VAT96XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*;7-G:60@(DQA>6]U="(*
M;7-G<W1R(")/<&UA86LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R
M9&5R(@IM<V=S='(@(DQA870@;&5E9R!V;V]R(&=E96X@<F%N9"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S.`IM<V=I9"`B3&5B86YO;B(*;7-G<W1R("),:6)A;F]N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0P
M"FUS9VED("),969T(@IM<V=S='(@(DQI;FMS(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$P,0IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B
M3&EN:W-E(&MO<"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,P.3<*
M;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@(DQI;FMS92!W86%R9&5N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30S"FUS9VED("),97-O=&AO(@IM<V=S='(@(DQE<V]T:&\B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DQE
M=F5L(@IM<V=S='(@(DYI=F5A=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,@IM<V=I9"`B3&EB
M97)I82(*;7-G<W1R("),:6)E<FEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30W"FUS9VED("),
M:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(DQI8FES8VAE($%R86)I
M<V-H92!*86UA:&ER:7EA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30P"FUS9VED("),:65C:'1E
M;G-T96EN(@IM<V=S='(@(DQI96-H=&5N<W1E:6XB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM<V=I9"`B3&EG:'0@1')I
M>GIL92(*;7-G<W1R("):86-H="!B=6ET:F4B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@IM<V=I9"`B3&EG:'0@4F%I;B(*
M;7-G<W1R("),:6-H=&4@<F5G96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*
M;7-G<W1R(")6<F]E9R!L:6-H=&4@<F5G96XB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B!,
M871E(@IM<V=S='(@(DQI8VAT92!R96=E;B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H="!286EN(%-H
M;W=E<B(*;7-G<W1R("),:6-H=&4@<F5G96YB=6DB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I9"`B3&EG:'0@4F%I
M;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B3&EC:'1E(')E9V5N(&UE="!O;G=E
M97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M,0IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R("),:6-H=&4@<VYE975W(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G
M:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(DQI8VAT92!S;F5E=7=B
M=6DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI;65R
M:6-K(@IM<V=S='(@(DQI;65R:6-K(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@Q-`IM<V=I9"`B3&EN:R(*;7-G<W1R("),:6YK(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W
M"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B3&EN:R!W:6IS="!N
M86%R.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S4*;7-G:60@
M(DQI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W
M:&5N(&1I<W!L87EI;F<B"FUS9W-T<B`B3&EN:R!H970@92UM86EL861R97,@
M86%N(&1E(&YI975W(&)E<FEC:'0@<&%G:6YA('1I:F1E;G,@=V5E<F=A=F4B
M"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAT;6PR=&5X="YP
M:'`Z,3@R"FUS9VED("),:6YK<R(*;7-G<W1R("),:6YK<R(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S
M='(@(DQI;G5X($-O;VMI92(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C@V"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S0S,30N<&AP.C0V"FUS9VED("),:7-T("T@=7-E<B!C86X@<V5E('1H92!F
M;VQD97(B"FUS9W-T<B`B3&EJ<W0@+2!G96)R=6EK97(@:V%N(&1E(&UA<"!Z
M:65N(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S-`IM<V=I9"`B3&ES="!$
M871A8F%S97,B"FUS9W-T<B`B1&%T86)A<V5L:6IS="(*"B,Z('-E<G9I8V5S
M+VAE;'`O:6YD97@N<&AP.C4Q"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM
M<V=S='(@(DQI:G-T('9A;B!H96QP(&]N9&5R9&5L96XB"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3,S"FUS9VED("),:7-T(%1A8FQE<R(*;7-G<W1R(")4
M86)E;&QI:G-T(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H
M<#HU.30*;7-G:60@(DQI<W0M07)C:&EV92(*;7-G<W1R("),:6IS="U!<F-H
M:65F(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.#D*
M;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R("),:6IS="U(96QP(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.38*;7-G:60@(DQI<W0M
M260B"FUS9W-T<B`B3&EJ<W0M260B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TAE861E<G,N<&AP.C4Y,@IM<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R("),
M:6IS="U%:6=E;F%A<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R
M<RYP:'`Z-3DS"FUS9VED("),:7-T+5!O<W0B"FUS9W-T<B`B3&EJ<W0M4&]S
M="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DQ"FUS
M9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("),:6IS="U);G-C:')I:G9E
M;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DP"FUS
M9VED("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(DQI:G-T+55I='-C:')I
M:G9E;B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,@HC+"!P:'`M9F]R;6%T
M"FUS9VED("),:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,B"FUS9W-T<B`B
M5V5E<F=E=F5N('9A;B!S97-S:65L:6IS="!I<R!M:7-L=6MT.B`E<R(*"B,Z
M(&%D;6EN+W-E<W-I;VYS+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED("),
M:7-T:6YG('5S97)S(&9A:6QE9#H@)7,B"FUS9W-T<B`B5V5E<F=E=F5N('9A
M;B!G96)R=6EK97)S;&EJ<W0@:7,@;6ES;'5K=#H@)7,B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E
M<G,@:7,@9&ES86)L960N(@IM<V=S='(@(E=E97)G979E;B!V86X@9V5B<G5I
M:V5R<VQI:G-T(&ES('5I=&=E<V-H86ME;&0N(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0W"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@(DQI=&5R
M871U=7(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#0*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R
M("),:71O=7=E;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEM
M86=E<RYP:'`Z-S<*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`B3&%D96XN
M+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`P"FUS9VED
M("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B3&]K86QE('1I:F0Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@V"FUS9VED("),;V-A;&4@86YD(%1I;64B
M"FUS9W-T<B`B3&%N9&EN<W1E;&QI;F<@96X@=&EJ9"(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<R(&QI8B]";&]C:R]M971A<BYP
M:'`Z-S(*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HU-PIM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B
M3&]C871I92(*"B,Z(&QO9VEN+G!H<#HQ.#D@<V5R=FEC97,O<&]R=&%L+W-I
M9&5B87(N<&AP.C(P,"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDP"B,Z
M('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C,@=&5M<&QA=&5S+VQO9VEN
M+VUO8FEL92YI;F,Z,34*;7-G:60@(DQO9R!I;B(*;7-G<W1R(")!86YM96QD
M96XB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*;7-G:60@
M(DQO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B3&]G('9A
M;B!V;V]R9V%A;F1E('-Y;F,@<V5S<VEE(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C$Y-`IM<V=I9"`B3&]G(&]U="(*;7-G<W1R(")!9FUE
M;&1E;B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV,0IM<V=I9"`B3&]G
M:6XB"FUS9W-T<B`B06%N;65L9&5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q,`IM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B06%N;65L9'1A
M:V5N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DU"FUS9VED("),
M;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D
M('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R("(B"B)!86YM96QD
M:6YG(&UI<VQU:W0@;VUD870@=7<@9V5B<G5I:V5R<VYA86T@;V8@=V%C:'1W
M;V]R9"!O;FIU:7-T(&ES("(*(FEN9V5V;V5R9"XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HY.3$*;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T
M<B`B06%N;65L9&EN9R!M:7-L=6MT+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$S-C4*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R("),86YG92!T
M96MS="(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`IM<V=I9"`B3&]V
M92(*;7-G<W1R("),:65F9&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV.0IM<V=I9"`B3&]W(@IM<V=S='(@(DQA86<B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@(D=R
M:65K<V4@:VQE:6YE(&QE='1E<G,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L
M871I;B!L971T97)S(@IM<V=S='(@(DQA=&EJ;G-E(&ML96EN92!L971T97)S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R
M(")+;&5I;F4@4F]M96EN<V4@9V5T86QL96XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#4*;7-G
M:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B3'5X96UB=7)G(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,0HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R(")-32(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR.#,*;7-G:60@(DU/5$0B"FUS9W-T<B`B
M34]41"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP
M.C,V"FUS9VED(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A
M=&$N(@IM<V=S='(@(DU3+51.148@8FEJ;&%G92!B979A='1E(&=E96X@9&%T
M82XB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B35-'
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34W"FUS9VED(")-86-A;R(*;7-G<W1R(")-86-A;R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$U,PIM<V=I9"`B36%C961O;FEA+"!4:&4@1F]R;65R(%EU
M9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUA8V5D;VYIZRP@1&4@=G)O
M96=E<F4@2F]E9V]S;&%V:7-C:&4@4F5P=6)L:65K('9A;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U,0IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R(")-861A9V%S8V%R(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"FUS9VED(")-86=I8R(*;7-G
M<W1R(")-86=I92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX,PIM
M<V=I9"`B36%I;"(*;7-G<W1R(")%+6UA:6PB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-3(T"FUS9VED(")-86EL($%D;6EN(@IM<V=S='(@(DUA
M:6QB96AE97)D97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS
M9W-T<B`B36%A:R!L:6Y?:RXN+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-0IM<V=I9"`B36%L
M87=I(@IM<V=S='(@(DUA;&%W:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-PIM<V=I9"`B36%L
M87ES:6$B"FUS9W-T<B`B36%L96ES:>LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C0*;7-G:60@
M(DUA;&1I=F5S(@IM<V=S='(@(DUA;&%D:79E;B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-`IM
M<V=I9"`B36%L:2(*;7-G<W1R(")-86QI(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38R"FUS9VED
M(")-86QT82(*;7-G<W1R(")-86QT82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY-`IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I
M97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R`B
M"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B
M(@HB0F5H965R('5W(&QI:G-T(&UE="!C871E9V]R:67K;B!E;B!D92!C;W)R
M97-P;VYD97)E;F1E(&ML975R96XL('=A87)M964@(@HB;VYD97)D96QE;B!W
M;W)D96X@9V5L86)E;&0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3$U-@IM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(DUA
M<#(T(&MA87)T(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$P.#<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$Q-S$*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R(")-87!1
M=65S=&MA87)T(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U
M"FUS9VED(")-87!P:6YG<R!S=&]R960N(@IM<V=S='(@(DMO<'!E;&EN9V5N
M(&]P9V5S;&%G96XN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@(DUA87)T(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M,0IM<V=I9"`B36%R9VEN(@IM<V=S='(@(DUA<F=E(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#@*;7-G:60@(DUA<FL@=VET:"!3
M965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R(")-87)K965R(&UE="!'97II96XO
M3FEE="!'97II96X@=FQA9V=E;B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C@Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S0S,30N<&AP.C0Y"FUS9VED(")-87)K('=I=&@@;W1H97(@9FQA9W,@
M*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R(")-87)K965R(&UE
M="!A;F1E<F4@=FQA9V=E;B`H8BYV+B!"96QA;F=R:6IK+T)E86YT=V]O<F0I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34R"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S
M='(@(DUA<F-H86QL(&5I;&%N9&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Y"FUS9VED(")-
M87)T:6YI<75E(@IM<V=S='(@(DUA<G1I;FEQ=64B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM
M<V=S='(@(D]V97)E96YK;VUE;F1E('9E;&1E;B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,`IM
M<V=I9"`B36%U<FET86YI82(*;7-G<W1R(")-875R971A;FGK(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,38S"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`B36%U<FET:75S(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$U"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(DUA>&EM
M86%L('1O96=E<W1A86X@:W)E9&EE="XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@(DUA>"!M97-S
M86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G<W1R(")-87AI;75M(&)E<FEC:'1O
M;F1E<F1E;&5N(&]V97)S8VAR961E;BXB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,Q,PIM<V=I9"`B36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S
M='(@(DUA>&EM=6T@=&5M<&5R871U=7(@=F%N(&1E(&%F9V5L;W!E;B`R-"!U
M=7(Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`U"FUS9VED(")-87@@
M=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R(")-87AI;75M('1E;7!E<F%T
M=75R('9A;B!D92!A9F=E;&]P96X@-B!U=7(Z("(*"B,Z(&QI8B]A<&DN<&AP
M.C@V"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM
M<V=S='(@(DUA>&EM=6T@86%N=&%L('!O<G1A86QB;&]K:V5N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DX(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R,3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S.0IM<V=I
M9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T<B`B36%X:6UU;2!L96YG=&4B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#0*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I
M9"`B36%Y(@IM<V=S='(@(DUE:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3,*;7-G:60@(DUA
M>6]T=&4B"FUS9W-T<B`B36%Y;W1T92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B1V5N965S:W5N9&4B
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED
M(")-96UB97)S(@IM<V=S='(@(DQE9&5N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,X,@IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R(")-96YU(&UO
M9&4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T<B`B0V5L;&5N
M('-A;65N=F]E9V5N(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I
M9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`B
M0F5R:6-H="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,C$V"FUS9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B
M=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92`B"B)V
M97)I9FEE9"XB"FUS9W-T<B`B(@HB0F5R:6-H="!M970@<W5C8V5S(&=E=F5R
M:69I965R9"P@;6%A<B!H970@8V5R=&EF:6-A870@=F%N(&1E(&]N9&5R9V5T
M96ME;F1E("(*(FMO;B!N:65T('=O<F1E;B!G979E<FEF:65E<F0N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P
M"FUS9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(D)E<FEC:'0@=F5R
M;&]P96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C(W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(V,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4V.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8P,@IM<V=I9"`B365S<V%G92!T>7!E(@IM
M<V=S='(@(D)E<FEC:'1T>7!E(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M"FUS9VED(")-971A<B!796%T:&5R(@IM<V=S='(@(DUE=&%R(%=E97(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W"FUS9VED(")-971A<B!B;&]C:R!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R(")-151!4B!B;&]K(&ES(&YI970@8F5S
M8VAI:V)A87(N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3D*;7-G:60@
M(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B
M965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*
M(DU%5$%2(&)L;VL@:7,@;FEE="!B97-C:&EK8F%A<BX@1&5T86EL<R!Z:6IN
M(&=E;&]G9"!V;V]R(&1E('-Y<W1E96UB96AE97)D97(N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$U,PIM<V=I9"`B365T87)$0B!I<R!N
M;W0@8V]N;F5C=&5D+B(*;7-G<W1R(")-971A<D1"(&ES(&YI970@=F5R8F]N
M9&5N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C<@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I
M9"`B365T:&]D(@IM<V=S='(@(DUE=&AO9&4B"@HC.B!F<F%M97=O<FLO4E!#
M+U)00R]S;V%P+G!H<#HQ,3<@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H
M<#HX,0HC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB(&ES(&YO
M="!D969I;F5D(@IM<V=S='(@(DUE=&AO9&4@7"(E<UPB(&ES(&YI970@9V5D
M969I;FEE97)D(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL
M960@;65T:&]D.B`E<R(*;7-G<W1R(")-971H;V1E(&ES(&YI970@9V5D969I
M;FEE97)D+B!!86YG97)O97!E;B!M971H;V1E.B`E<R(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z.#(@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8W
M"FUS9VED(")-971R:6,B"FUS9W-T<B`B365T<FES8V@B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-C8*;7-G:60@(DUE>&EC;R(*;7-G<W1R(")-97AI8V\B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M-0IM<V=I9"`B36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(*;7-G
M<W1R(")-:6-R;VYE<VGK+"!&961E<F%L92!3=&%T96X@=F%N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0R"FUS
M9VED(")-:61D;&4B"FUS9W-T<B`B36ED9&5N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*
M;7-G<W1R(")-:6UE('1Y<&4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q
M-PIM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(DUI
M;FEM=6T@=&5M<&5R871U=7(@=F%N(&1E(&%F9V5L;W!E;B`R-"!U=7(Z("(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`Y"FUS9VED(")-:6X@=&5M<"!L
M87-T(#8@:&]U<G,Z("(*;7-G<W1R(")-:6YI;75M('1E;7!E<F%T=75R('9A
M;B!D92!A9F=E;&]P96X@-B!U=7(Z("(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z-#,Y"FUS9VED(")-:6YI;75M('!A<W-W;W)D(&%G92!H
M87,@;F]T('EE="!E>'!I<F5D(@IM<V=S='(@(DUI;FEM=6T@=V%C:'1W;V]R
M9&QE969T:6ID(&ES(&YO9R!N:65T('9E<FQO<&5N(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-0IM<V=I9"`B36ER<F]R
M(@IM<V=S='(@(DUI<G)O<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M,0IM<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R(")!;&QE<FAA;F1E(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S0P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C<R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M,C4P"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N
M(@IM<V=S='(@(D]N=&)R96ME;F1E(%!%05(@;6]D=6QE($A45%!?4F5Q=65S
M="XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U"FUS9VED("(B"B)-
M:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET
M(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB
M"FUS9W-T<B`B(@HB3VYT8G)E:V5N9&4@8V]N9FEG=7)A=&EE+B!5(&1I96YT
M(&1E>F4@;G4@=&4@9V5N97)E<F5N+"!W86YN965R('4@9&5Z92`B"B)T;V5P
M87-S:6YG('=I;'0@9V5B<G5I:V5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M
M97-S86=E($E$+B(*;7-G<W1R(")/;G1B<F5K96YD(&)E<FEC:'0@240N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA
M:6PN(@IM<V=S='(@(D]N=&)R96ME;F1E+"!V97)E:7-T92P@4$5!4B!M;V1U
M;&4@36%I;"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS
M9W-T<B`B3VYT8G)E:V5N9"!S97-S:64@240N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T
M<B`B36$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S8*;7-G:60@
M(DUO8FEL92!-86EL(@IM<V=S='(@(DUO8FEE;&4@92UM86EL(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*;7-G:60@(DUO
M9&5R871E(@IM<V=S='(@(D=E;6ED9&5L9"(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HX-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<S"FUS9VED(")-;V1I9FEE9"!$871E(@IM<V=S='(@(E=I
M:GII9VEN9W-D871U;2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D:69Y(%523"(*;7-G
M<W1R(")7:6IZ:6<@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV-S0*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B36]D=6QU<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$U,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS
M9W-T<B`B36]L9&%V:>LL(%)E<'5B;&EE:R!V86XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#D*
M;7-G:60@(DUO;F%C;R(*;7-G<W1R(")-;VYA8V\B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38*
M;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(DUO;F=O;&GK(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C4X-`IM<V=I9"`B36]N=&@@86YD('EE87(B
M"FUS9W-T<B`B36%A;F0@96X@:F%A<B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N
M86YC92]-86EN=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T
M<B`B36%A;F1E;&EJ:W,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C$*;7-G:60@(DUO;G1S97)R
M870B"FUS9W-T<B`B36]N='-E<G)A="(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B
M"FUS9W-T<B`B36%A;F9A<V5N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-3
M5BYP:'`Z,3DV(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(X,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D
M('1H86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R(")-965R('9E;&1E;B!I
M;B!R96=E;"`E9"!G979O;F1E;BP@9&%N(&1E('9E<G=A8VAT=&4@)60N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30X"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(DUA<F]K:V\B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM
M<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@(E9O;W)N86UE;&EJ:R!O;F)E
M=V]L:W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS-`IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R(")6;V]R;F%M96QI
M:FL@8F5W;VQK="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,U"FUS9VED(")-;W-T;'D@0VQO=61Y(&%N9"!7:6YD>2(*;7-G
M<W1R(")6;V]R;F%M96QI:FL@8F5W;VQK="!E;B!W:6YD97)I9R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")-
M;W-T;'D@4W5N;GDB"FUS9W-T<B`B5F]O<FYA;65L:6IK('IO;FYI9R(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C0X
M"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B3F%A<B!B96YE9&5N(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-3(*
M;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R(").86%R(&QI;FMS(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-38*;7-G
M:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`B3F%A<B!R96-H=',B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8T-`IM<V=I
M9"`B36]V92!5<"(*;7-G<W1R(").86%R(&)O=F5N(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-@IM<V=I9"`B36]V92!D
M;W=N(@IM<V=S='(@(DYA87(@8F5N961E;B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HU,C4*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-@IM<V=I9"`B36]V92!U<"(*;7-G
M<W1R(").86%R(&)O=F5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38X"FUS9VED(")-;WIA;6)I
M<75E(@IM<V=S='(@(DUO>F%M8FEQ=64B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,3@T"FUS9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES
M=',B"FUS9W-T<B`B375L=&DM;&5V96P@9')O<"!D;W=N(&QI:G-T96XB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U.0IM
M<V=I9"`B375L=&EM87`@54L@;6%P(@IM<V=S='(@(DUU;'1I;6%P(%9+(&MA
M87)T(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T,@IM<V=I9"`B
M375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@(DUE97)V;W5D:6=E('-E;&5C
M=&EE(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P,@IM<V=I9"`B
M37D@06-C;W5N="(*;7-G<W1R(")-:6IN(&%C8V]U;G0B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z,C@*;7-G:60@(DUY($%C8V]U;G0@26YF;W)M871I
M;VXB"FUS9W-T<B`B57<@86-C;W5N=&EN9F]R;6%T:64B"@HC.B!S97)V:6-E
M<R]P;W)T86PO:6YD97@N<&AP.C0T"FUS9VED(")->2!0;W)T86PB"FUS9W-T
M<B`B36EJ;B!P;W)T86%L(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP
M.C0R"FUS9VED(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(DUI:FX@<&]R
M=&%A;&QA>6]U="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-0IM<V=I9"`B37EA;FUA<B(*;7-G
M<W1R(")":7)M82(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N
M86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T
M<B`B3F5E+"!I:R!A8V-E<'1E97(@9&4@=F]O<G=A87)D96X@3DE%5"(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(").86UE(@IM<V=S
M='(@(DYA86TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD*;7-G:60@(DYA;6EB:6$B"FUS9W-T
M<B`B3F%M:6)IZR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W.`IM<V=I9"`B3F%U<G4B"FUS9W-T
M<B`B3F%U<G4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<*;7-G:60@(DYE<&%L(@IM<V=S='(@
M(DYE<&%L(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<U"FUS9VED(").971H97)L86YD<R(*;7-G
M<W1R(").961E<FQA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,PIM<V=I9"`B3F5T:&5R;&%N
M9',@06YT:6QL97,B"FUS9W-T<B`B3F5D97)L86YD<R!!;G1I;&QE;B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").
M971S8V%P92!"87-E(%523"(*;7-G<W1R(").971S8V%P92!"87-I<R!54DPB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-`IM<V=I
M9"`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B3F5T<V-A
M<&4@0T$@:6YT<F5K:VEN9R!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%52
M3"(*;7-G<W1R(").971S8V%P92!#02!B96QE:60@55),(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#4*;7-G:60@(DYE='-C87!E
M(%)E;F5W86P@55),(@IM<V=S='(@(DYE='-C87!E('9E<FYI975W:6YG(%52
M3"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@S"FUS
M9VED(").971S8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R(").971S8V%P
M92!I;G1R96MK:6YG(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3@W"FUS9VED(").971S8V%P92!34TP@<V5R=F5R(&YA;64B
M"FUS9W-T<B`B3F5T<V-A<&4@4U-,('-E<G9E<FYA86TB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X.`IM<V=I9"`B3F5T<V-A<&4@
M8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R(").971S8V%P92!C97)T:69I
M8V%A=&-O;6UE;G1A87(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*
M;7-G<W1R(").971S8V%P92!C97)T:69I8V%A='1Y<&4B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C4S"FUS9VED(").971W;W)K(@IM<V=S='(@
M(DYE='=E<FLB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S.0HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,SDP"FUS9VED(").979E<B(*;7-G<W1R(").;V]I="(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W,`IM<V=I9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R(").:65U
M=R!#86QE9&]N:>LB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O
M<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@
M(DYI975W92!C871E9V]R:64B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@
M;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*
M;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(DYI975W92!M86%N(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S
M97)N86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B3FEE=7=E(&=E8G)U:6ME<G-N
M86%M("AO<'1I;VYE96PI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@P"FUS9VED(").97<@6F5A
M;&%N9"(*;7-G<W1R(").:65U=R!:965L86YD(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C,W"FUS9VED(").97<@<&%S<W=O<F0B"FUS9W-T
M<B`B3FEE=7<@=V%C:'1W;V]R9"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D
M('=I;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R(").:65U=R!W86-H='=O;W)D
M('IA;"!V97)L;W!E;B!O<"`E>"XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z-3(*;7-G:60@(DYE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N
M(@IM<V=S='(@(DYI975W92!786-H='=O;W)D96X@:V]M96X@;FEE="!O=F5R
M965N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B3FEE
M=7<@<V-H97)M("A?8FQA;FLI(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4R(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR.3$*;7-G:60@(DYE=W,B"FUS9W-T<B`B3FEE=7=S(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-PIM<V=I9"`B3F5W<V=R
M;W5P<R(*;7-G<W1R(").:65U=W-G<F]E<&5N(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,Z,C4@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ
M,CD*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$@=&5M<&QA=&5S
M+V1A=&$O='-V:6YF;RYI;F,Z,34*;7-G:60@(DYE>'0B"FUS9W-T<B`B5F]L
M9V5N9&4B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*;7-G:60@(DYE>'0@
M-"!0:&%S97,B"FUS9W-T<B`B5F]L9V5N9&4@-"!F87-E;B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8V(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,S<P"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T<B`B
M5F]L9V5N9&4@;W!T:65S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H
M<#HQ,#,*;7-G:60@(DYE>'0^(@IM<V=S='(@(E9O;&=E;F1E/B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W-`IM<V=I9"`B3FEC87)A9W5A(@IM<V=S='(@(DYI8V%R86=U82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W,0IM<V=I9"`B3FEG97(B"FUS9W-T<B`B3FEG97(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-S,*;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`B3FEG97)I82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-CD*;7-G:60@(DYI
M9VAT(@IM<V=S='(@(DYA8VAT(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Y"FUS9VED(").:75E
M(@IM<V=S='(@(DYI=64B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.38V"FUS9VED(").;R(*;7-G<W1R(").964B"@HC.B!T
M96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V
M86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E
M<R!F;W(N(@IM<V=S='(@(D=E96X@8F5S8VAI:V)A<F4@8V]N9FEG=7)A=&EE
M9&%T82!O;2!V97)S8VAI;&QE;B!T92!L871E;B!Z:65N+B(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z,3`V"FUS9VED(").
M;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*
M;7-G<W1R(")'965N(&)E<V-H:6MB87)E('-T<F%T96=I92!V;V]R(&AE="!M
M86ME;B!V86X@25-/(&EM86=E<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E
M;7!L871E+B(*;7-G<W1R(")'965N(&)A=&-H<VIA8FQO;VXN(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,#$*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HS.#4*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT
M,#<*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O
M<VET:6]N(@IM<V=S='(@(D5R(&)E<W1A870@9V5E;B!B;&]K(&]P(&1E(&=E
M=G)A86=D92!P;W-I=&EE(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L
M+G!H<#HU,`IM<V=I9"`B3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@
M34-!3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B1V5E;B!A9V5N9&%N86%M
M(&]P9V5G979E;B!V;V]R($U#04P@875T:&5N=&EC871I92XB"@HC.B!A9&UI
M;B]S971U<"]D:69F+G!H<#HU-`IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R
M(")'965N('=I:GII9VEN9V5N+B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,34V"FUS9VED(").;R!C:&EL9')E;B!C86X@8F4@861D960@
M=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R(")!86X@9&ET(')E8VAT(&MU
M;FYE;B!G965N(&-H:6QD(')E8VAT96X@=V]R9&5N('1O96=E=F]E9V0N(@H*
M(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S8X(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,3<X"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M-3$W"B,L('!H<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B1V5E;B!C;VYF
M:6=U<F%T:65I;F9O<FUA=&EE(&]P9V5G979E;B!V;V]R("5S+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#4U"FUS9VED(").;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS
M9W-T<B`B1V5E;B!C;VYF:6=U<F%T:65I;F9O<FUA=&EE(&]P9V5G979E;B!V
M;V]R($944"!61E,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV
M-S(*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!344P@5D93+B(*;7-G<W1R(")'965N(&-O;F9I9W5R871I96EN
M9F]R;6%T:64@;W!G96=E=F5N('9O;W(@4U%,(%9&4RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(U"FUS9VED(").;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93
M+B(*;7-G<W1R(")'965N(&-O;F9I9W5R871I96EN9F]R;6%T:64@;W!G96=E
M=F5N('9O;W(@4U%,+6)E<W1A;F0@5D93+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E
M9&ET(&QE9G0N(@IM<V=S='(@(D=E96X@:W)E9&EE="!M965R+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS
M9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`B1V5E;B!B
M97-T96UM:6YG(&]P9V5G979E;BXB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"
M<F]W<V5R+G!H<#HY,C`*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T
M<B`B1V5E;B!B97-T86YD('5P;&]A9&5D(@H*(SH@=71I;"]I8V]N7V)R;W=S
M97(N<&AP.C<Q"FUS9VED(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`B1V5E
M;B!P:6-T;V=R86UM96X@9V5V;VYD96XN(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ,S`@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ,38*;7-G:60@(DYO(&QO8V%T:6]N(&ES
M('-E="XB"FUS9W-T<B`B17(@:7,@9V5E;B!L;V-A=&EE(&EN9V5S=&5L9"XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W"FUS9VED(").
M;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B1V5E;B!L;V-A=&EE(&]P
M9V5G979E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S,PIM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS
M9W-T<B`B1V5E;B!B97)I8VAT(&=E;&5V97)D+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS9VED(").;R!N
M86UE('-P96-I9FEE9"XB"FUS9W-T<B`B1V5E;B!N86%M(&]P9V5G979E;BXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S-PIM<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`B1V5E
M;B!G971A;"!O<&=E9V5V96XN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.CDT"FUS9VED(").;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B1V5E
M;B!B96QE9&EG96YD92!F;W)T=6YE<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:'1T<"YP:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")'965N('=A8VAT=V]O
M<F0@;W!G96=E=F5N('9O;W(@2%144"!A=71H96YT:6-A=&EE+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B1V5E;B!W86-H='=O;W)D(&]P9V5G979E;B!V;V]R($E-05`@875T:&5N
M=&EC871I92XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C<R
M"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(D=E96X@=V%C:'1W;V]R9"!O<&=E9V5V
M96X@=F%N($ME<F)E<F]S(&%U=&AE;G1I8V%T:64N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L;V=I;BYP:'`Z.#0@9G)A;65W;W)K+T%U=&@O075T:"]P
M86TN<&AP.C<U"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z-S<*
M;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B1V5E;B!W86-H='=O;W)D(&]P9V5G979E;B!V
M;V]R($QO9VEN(&%U=&AE;G1I8V%T:64N(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]P87-S=V0N<&AP.C$S-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B1V5E;B!W
M86-H='=O;W)D(&]P9V5G979E;B!V;V]R(%!!4U-71"!A=71H96YT:6-A=&EE
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HX-`IM<V=I9"`B
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B1V5E;B!W86-H='=O;W)D(&]P9V5G979E;B!V;V]R(%--0B!A
M=71H96YT:6-A=&EE+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,3(X-PIM<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B
M:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A
M<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@HB
M1V5E;B!P860@;F%A<B!D92!/<&5N4U-,(&)I;F%R>2!O<&=E9V5V96XN($1E
M($]P96Y34TP@8FEN87)Y(&ES(&YO9&EG(&]M('1E("(*(FMU;FYE;B!W97)K
M96X@;65T(%!+0U,@,3(@9&%T82XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]A<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM
M<V=S='(@(D=E96X@:&%N9V5N9&4@:6YS8VAR:6IV:6YG96XN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C<V-@IM<V=I9"`B3F\@<75O=&$@<V5T+B(*
M;7-G<W1R(")'965N('%U;W1A(&EN9V5S=&5L9"XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0S"FUS9VED(").
M;R!R=6QE<R(*;7-G<W1R(")'965N(&QI;FGK<FEN9R(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C0X,@IM<V=I9"`B3F\@<V5P87)A=&]R('-P
M96-I9FEE9"XB"FUS9W-T<B`B1V5E;B!S8VAE:61I;F=S=&5K96X@;W!G96=E
M=F5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#0*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(D=E96X@>FEJ
M9&5N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#<*;7-G:60@
M(DYO('-U8V@@9FEL92(*;7-G<W1R(")'965N(&1E<F=E;&EJ:R!B97-T86YD
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$R-@IM<V=I9"`B
M3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+B(*
M;7-G<W1R(")'965N('1I:F1E;&EJ:R!D:7)E8W1O<GD@8F5S8VAI:V)A87(@
M=F]O<B!C86-H92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C(R,0IM<V=I9"`B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W
M;W)D('-E;G0N(@IM<V=S='(@(D=E96X@9V5B<G5I:V5R<VYA86T@96XO;V8@
M=V%C:'1W;V]R9"!V97)Z;VYD96XN(@H*(SH@9G)A;65W;W)K+U)00R]24$,O
M>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO('9A;&ED(%A-3"!D871A(')E='5R
M;F5D(@IM<V=S='(@(D=E96X@9V5L9&EG92!834P@9&%T82!T97)U9V=E<W1U
M=7)D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.CDW-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.3@T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY
M.34*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P
M,3(*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R(")'965N('=A87)D96XB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V97)S:6]N
M(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB1V5E;B!V97)S:64@9V5V;VYD
M96X@:6X@;W)I9VEN96QE(&-O;F9I9W5R871I92X@2&5R9V5N97)E97(@8V]N
M9FEG=7)A=&EE+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G
M:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!2
M96=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D=E96X@=F5R<VEE
M(&=E=F]N9&5N(&EN('5W(&-O;F9I9W5R871I92X@2&5R9V5N97)E97(@8V]N
M9FEG=7)A=&EE+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0R-R!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDS"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#4*;7-G:60@(DYO;F4B"FUS9W-T<B`B1V5E;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S
M92!I;7!L:6-I="DB"FUS9W-T<B`B1V5E;B`H=F5R<&QI8VAT*2(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED(").;W)D:6,@*$E33RTX.#4Y
M+3$P*2(*;7-G<W1R(").;V]R9"!%=7)O<&5E<R`H25-/+3@X-3DM,3`I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<R"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G<W1R(").
M;W)F;VQK(&5I;&%N9"(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B
M"FUS9W-T<B`B3F]O<F1E;&EJ:R!H86QF<F]N9"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.`IM
M<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S='(@(DUA<FEA
M;F5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3<V"FUS9VED(").;W)W87DB"FUS9W-T<B`B3F]O
M<G=E9V5N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M-#$*;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R(").:65T(&YA(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!"
M969O<F4B"FUS9W-T<B`B3FEE="!V;V]R(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z-#$U"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T
M<B`B1V5E;B!D:7)E8W1O<GDB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(N<&AP.C8S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-#@*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+G!H<#HU.0HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX-`HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-0IM
M<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*;7-G<W1R(").:65T(&=E:6UP;&5M
M96YT965R9"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C8X"FUS9VED(").;W0@<V5T(@IM<V=S='(@(DYI970@:6YG97-T
M96QD(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C$Y,R!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,S0@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C(U,@HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,C8Y(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.#4*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C,P,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S$V
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,S,@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C,V-@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-#(V(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HU,#4*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C4W-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3DQ"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HV-CD@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I
M;VY(86YD;&5R+G!H<#HQ-#4*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R
M+U-E<W-I;VY(86YD;&5R+G!H<#HQ-C`*(SH@9G)A;65W;W)K+U-E<W-I;VY(
M86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S4*(SH@9G)A;65W;W)K+U-E
M<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#D*(SH@9G)A;65W
M;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HR,S8*;7-G
M:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(DYI970@;VYD97)S=&5U;F0N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T
M-"!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP.`HC.B!C;VYF:6<O:&]O
M:W,N<&AP+F1I<W0Z,3`U."!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@P
M"FUS9VED(").;W1E<R(*;7-G<W1R(").;W1I=&EE<R(*"B,Z('-E<G9I8V5S
M+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W
M<V4L(&=O(&)A8VLN(@IM<V=S='(@(DYI971S('1E(&)L861E<F5N+"!G82!T
M97)U9RXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#$R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-3`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B3F]V96UB97(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#0V"FUS9VED(").=6UB97(B"FUS
M9W-T<B`B1V5T86PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(U
M"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R(")!86YT86P@
M:V%R86MT97)S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V.2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(S"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T-#4@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@
M(D%A;G1A;"!K;VQO;6UE;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$S-C<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,0HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-#0S('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@;V8@<F]W<R(*;7-G
M<W1R(")!86YT86P@<FEJ96XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E
M8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS
M9W-T<B`B1V5T86QL96X@;FEE="!O<&=E9V5V96X@=F]O<B!B:6IW97)K96X@
M:6X@965N(&1I<W1R:6)U=&EE;&EJ<W0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R(")/
M2R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX
M-S,*;7-G:60@(D]B:F5C="(*;7-G<W1R(")/8FIE8W0B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B3V)J96-T($-R96%T;W(B
M"FUS9W-T<B`B3V)J96-T96EG96YA87(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,3`T"FUS9VED(")/8W1A;"(*;7-G<W1R(")/8W1A86PB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#D*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I
M9"`B3V-T;V)E<B(*;7-G<W1R(")/:W1O8F5R(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R(")"
M96QE9&EG:6YG9FEL=&5R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,R.`IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(DMA;G1O;W(B"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W
M('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB"FUS9W-T<B`B3W5D92!E
M;B!N:65U=V4@=V%C:'1W;V]R9&5N(&1I96YE;B!V97)S8VAI;&QE;F0@=&4@
M>FEJ;BXB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*;7-G
M:60@(D]L9"!P87-S=V]R9"(*;7-G<W1R(")/=61E('=A8VAT=V]O<F0B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*;7-G:60@(D]L9"!P
M87-S=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`B3W5D92!W86-H='=O
M;W)D(&ES(&YI970@:G5I<W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#$*;7-G:60@(D]M86XB
M"FUS9W-T<B`B3VUA;B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T
M('-H87)E9"!F;VQD97)S+B(*;7-G<W1R(")!;&QE96X@24U!4"!S97)V97)S
M(&]N9&5R<W1E=6YE;B!G961E96QD92!M87!P96XN(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.CDU"FUS9VED(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE
M<R(*;7-G<W1R(")!;&QE96X@8F5L961I9V5N9&4@9F]R='5N97,B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4Q(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y-S$*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL
M;W=E9"XB"FUS9W-T<B`B4VQE8VAT(.GI;B!E+6UA:6QA9')E<R!T;V5G97-T
M86%N+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B
M(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y
M(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R
M(&$@<VAA<F4B"FUS9W-T<B`B(@HB06QL965N(&1E(&5I9V5N86%R(&]F(&5E
M;B!S>7-T965M8F5H965R9&5R(&UA9R!D92!E:6=E;F%A<G)E8VAT96X@=F%N
M(&5E;B`B"B)S:&%R92!W:6IZ:6=E;B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N
M<&AP.C0Q(&QI8B]";&]C:R]I9G)A;64N<&AP.C0R"FUS9VED(")/<&5N(&EN
M(&$@;F5W('=I;F1O=R(*;7-G<W1R(")/<&5N(&EN(&5E;B!N:65U=R!S8VAE
M<FTB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(T-0IM
M<V=I9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F
M<F]M('-I9VYE9"!3+TU)344@<&%R="XB"FUS9W-T<B`B(@HB3W!E;E-33"!F
M;W5T.B!K;VX@9V5E;B!D871A('5I="!H970@;VYD97)T96ME;F1E(%,O34E-
M12!O;F1E<F1E96P@:&%L96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")/<&5N<R!T:&ES
M(&QI;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D]P96YT(&1E>F4@;&EN
M:R!I;B!E96X@;FEE=7<@<V-H97)M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4S"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S='(@(D)E<W1U
M<FEN9W-S>71E96TB"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,34Q"FUS9VED(")/<'1I;VYS(@IM<V=S='(@(D]P=&EE<R(*"B,Z('-E<G9I
M8V5S+W!R969S+G!H<#HS,2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R(")/
M<'1I97,@=F]O<B`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES="(*;7-G<W1R(")'
M96]R9&5N9&4@;&EJ<W0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(D]R9V%N
M:7-T871I92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-38Y"FUS9VED(")/<F=A;FES871I;VYA;"!5;FET(@IM<V=S='(@(D]R9V%N
M:7-A=&EE(&5E;FAE:60B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,3,T"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(D]R9V%N:7-E<F5N(@H*
M(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L(&%P
M<&QI8V%T:6]N('1E;7!L871E(@IM<V=S='(@(D]R:6=I;F5E;"!T;V5P87-S
M:6YG<W-J86)L;V]N(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.B(*
M;7-G<W1R(")/<FEG:6YE;&4@<VIA8FQO;F5N(&EN("5S.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N
M<&AP.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G<W1R(")!;F1E<F4B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3D@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P
M.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$V(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,C4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-"!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,30T"FUS9VED(")/=&AE<B!);F9O<FUA=&EO
M;B(*;7-G<W1R(")!;F1E<F4@:6YF;W)M871I92(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM
M<V=S='(@(D5I9V5N86%R<F5C:'1E;B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<&%M+G!H<#HW.0IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(E!!32!A=71H96YT:6-A=&EE(&ES(&YI
M970@8F5S8VAI:V)A87(N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E
M;F5R:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A8VME;F0B
M"FUS9W-T<B`B4$5!4CHZ36%I;"!B86-K96YD(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3(W-@IM<V=I9"`B4$=0($1I9VET86P@4VEG
M;F%T=7)E(@IM<V=S='(@(D1I9VET86QE(%!'4"!H86YD=&5K96YI;F<B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S(R"FUS9VED(")0
M1U`@16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B1V5C;V1E97)D92!01U`@9&%T
M82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-S0*;7-G
M:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(D]P96YB87)E(%!'4"!S;&5U
M=&5L(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,U-@IM
M<V=I9"`B4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T82(*;7-G<W1R(")/;F1E
M<G1E:V5N9&4O9V5C;V1E97)D92!01U`@9&%T82(*"B,Z(&%D;6EN+W!H<'-H
M96QL+G!H<#HV.0IM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B4$A0(&-O9&4B
M"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*;7-G:60@(E!(4"!3:&5L;"(*
M;7-G<W1R(")02%`@<VAE;&PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS.`IM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R
M("),:6-H=&4@<F5G96X@;F$@,3(N,#`@=75R(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%)A:6XB"FUS
M9W-T<B`B4F5G96X@;F$@,3(N,#`@=75R(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#`*;7-G:60@(E!-(%-H;W=E<G,B"FUS
M9W-T<B`B0G5I96X@;F$@,3(N,#`@=75R(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*;7-G:60@(E!-(%-N;W<B"FUS9W-T
M<B`B4VYE975W(&YA(#$R+C`P('5U<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0R"FUS9VED(")032!3;F]W(%-H;W=E<G,B
M"FUS9W-T<B`B4VYE975W8G5I96X@;F$@,3(N,#`@=75R(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#,*;7-G:60@(E!-(%-U
M;B(*;7-G<W1R("):;VX@;F$@,3(N,#`@=75R(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E!-(%0M4W1O<FUS
M(@IM<V=S='(@(D]N=V5E<G-B=6EE;B!N82`Q,BXP,"!U=7(B"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z,C@V"FUS9VED(")03U-)6"!E>'1E;G-I;VX@
M:7,@;6ES<VEN9R(*;7-G<W1R(")03U-)6"!E>'1E;G-I92!O;G1B<F5E:W0B
M"@HC.B!L:6(O87!I+G!H<#HQ-#D*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T
M<B`B4$A0(%]3:&5L;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B
M5G)I:F4@<G5I;71E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@W"FUS9VED(")086MI<W1A;B(*
M;7-G<W1R(")086MI<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.30*;7-G:60@(E!A;&%U
M(@IM<V=S='(@(E!A;&%U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,@IM<V=I9"`B4&%L97-T
M:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(*;7-G<W1R(")086QE<W1I:FYS
M(%1E<G)I=&]R:75M+"!"97IE="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,@IM<V=I9"`B4&%N
M86UA(@IM<V=S='(@(E!A;F%M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-0IM<V=I9"`B4&%P
M=6$@3F5W($=U:6YE82(*;7-G<W1R(")087!U82!.:65U=R!'=6EN96$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DU"FUS9VED(")087)A9W5A>2(*;7-G<W1R(")087)A9W5A
M>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W
M"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S='(@(D=E9&5E;'1E;&EJ:R!B
M97=O;&MT(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$X,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU,S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HQ-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`Q.`HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<W('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z-#,*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0R-0IM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`B5V%C:'1W;V]R9"(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S
M<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(E=A8VAT=V]O
M<F0@;65T('-U8V-E<R!G97=I:GII9V0N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HQ,S(S"FUS9VED(")087-S=V]R9"!I;F-O<G)E
M8W0B"FUS9W-T<B`B5V%C:'1W;V]R9"!O;FIU:7-T(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]R861I=7,N<&AP.C$U,@IM<V=I9"`B4&%S<W=O<F0@<F5Q
M=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B5V%C
M:'1W;V]R9"!I<R!V97)E:7-T('9O;W(@4D%$2553(&%U=&AE;G1I8V%T:64N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`U,PIM<V=I9"`B4&%S
M<W=O<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B5V%C:'1W;V]R9"!M
M970@8F5V97-T:6=I;F<B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.3`*;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R(")786-H='=O;W)D.B(*
M"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"FUS9VED(")087-S
M=V]R9#H@(@IM<V=S='(@(E=A8VAT=V]O<F0Z("(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$U,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#,T"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D
M<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")786-H='=O;W)D96X@;6]E=&5N(&]V
M97)E96YK;VUE;BXB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM
M<V=I9"`B4&%S=&4B"FUS9W-T<B`B4&QA:VME;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R
M;VT@8VQI<&)O87)D(@IM<V=S='(@(E!L86MK96X@=F%N868@<')I:V)O<F0B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q
M"FUS9VED(")0871H(@IM<V=S='(@(E!A9"(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E<75E=65D+FEN8SHW"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S
M='(@(DAA;F=E;F1E(&EN<V-H<FEJ=FEN9V5N.B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU-`IM<V=I9"`B4&5O<&QE(@IM<V=S='(@(DUE;G-E;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W
M"FUS9VED(")097)C96YT(@IM<V=S='(@(E!R;V-E;G0B"@HC.B!T96UP;&%T
M97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0IM<V=I9"`B4&5R
M9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@(D]N9&5R:&]U
M9'-W97)K>F%A;6AE9&5N('5I='9O97)E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT,3`*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T
M:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`B3VYD97)H;W5D<W=E<FMZ86%M:&5D
M96X@=6ET=F]E<F5N(&)I:B!A86YM96QD:6YG/R(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,34V"FUS9VED(")097)M:7-S:6]N(@IM<V=S
M='(@(E)E8VAT(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E
M9"XB"FUS9W-T<B`B4F5C:'0@7"(E<UPB(&YI970@=F5R=VEJ9&5R9"XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4Y,`IM<V=I9"`B4&5R;6ES
M<VEO;B!$96YI960B"FUS9W-T<B`B4F5C:'0@9V5W96EG97)D(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C$@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ-C0*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@
M(E)E8VAT96XB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C`@861M
M:6XO<&5R;7,O9&5L971E+G!H<#HU.`HC.B!A9&UI;B]P97)M<R]E9&ET+G!H
M<#HQ,#D@861M:6XO<&5R;7,O:6YD97@N<&AP.C(R"FUS9VED(")097)M:7-S
M:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")296-H=&5N8F5H965R(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X"FUS9VED(")097)S;VYA;"!)
M;F9O<FUA=&EO;B(*;7-G<W1R(")097)S;V]N;&EJ:V4@:6YF;W)M871I92(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X,PIM<V=I9"`B4&5R=2(*;7-G<W1R(")097)U(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0971S(@IM<V=S='(@
M(DAU:7-D:65R96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#8*;7-G:60@(E!H:6QI<'!I;F5S
M(@IM<V=S='(@(E!H:6QI<'!I:FYE;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM<V=S='(@
M(E1E;&5F;V]N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X,`IM
M<V=I9"`B4&AO=&]S(@IM<V=S='(@(D9O=&\G<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3`*
M;7-G:60@(E!I=&-A:7)N(@IM<V=S='(@(E!I=&-A:7)N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I
M>&5L<R(*;7-G<W1R(")0:7AE;',B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-38*;7-G:60@(E!L871I='5D97,B"FUS9W-T<B`B4&QA=&ET=61E<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G
M<W1R(")+;&EK(&EN(&5E;B!C96PL(&$N=2YB+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B
M4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E
M;&5M96YT.B(*;7-G<W1R(")"979E<W1I9RP@9&%T('4@9&ET(&5L96UE;G0@
M=VEL="!V97)W:6ID97)E;BP@82YU+F(Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED(")0;&5A
M<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE
M;G0N(@IM<V=S='(@(D)E=F5S=&EG+"!D870@=2!D:70@96QE;65N="!W:6QT
M(&QO<VMO<'!E;&5N+"!A+G4N8BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-38R"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y
M96%R+B(*;7-G<W1R(")'965F(&5E;B!M86%N9"!E;B!E96X@:F%A<BP@82YU
M+F(N(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z,3(*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@
M8V%T96=O<GDZ(@IM<V=S='(@(D5E;B!N86%M('9O;W(@9&4@;FEE=7=E(&-A
M=&5G;W)I92!I;G9O97)E;BP@82YU+F(N.B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$S,#$*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED($E0
M(&%D9')E<W,N(@IM<V=S='(@(D=E968@965N(&=E;&1I9R!)4"!A9')E<RP@
M82YU+F(N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8T,`IM<V=I
M9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E
M<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B(@HB1V5E9B!E96X@
M9V5L9&EG92!D871U;2!A+G4N8BXL(&-O;G1R;VQE97(@:&5T(&%A;G1A;"!D
M86=E;B!I;B!D92!M86%N9"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-#0W"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+B(*;7-G
M<W1R(")'965F(&5E;B!G96QD:6=E('1I:F0L(&$N=2YB+B(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@(E!L96%S92!P<F]V
M:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS9W-T<B`B1V5E9B!E
M96X@<V%M96YV871T:6YG('9A;B!H970@<')O8FQE96TL(&$N=2YB+B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R
M;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B1V5E9B!U=R!G96)R=6EK97)S
M;F%A;2!E;B!W86-H='=O;W)D+"!A+G4N8BXB"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z-3@*;7-G:60@(B(*(E!L96%S92!R96%D('1H92!F;VQL
M;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@
M=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*(DQE97,@9&4@=F]L9V5N
M9&4@=&5K<W0L(&$N=2YB+B!5($U/150@9&4@=F]O<G=A87)D96X@=&4@86-C
M97!T97)E;B!O;2!H970@(@HB<WES=&5E;2!T92!K=6YN96X@9V5B<G5I:V5N
M+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C<P"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA
M;64Z(@IM<V=S='(@(D=E968@9&4@;FEE=7=E(&-A=&5G;W)I96YA86TL(&$N
M=2YB+CHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#@*;7-G:60@(E!O;&%N9"(*;7-G<W1R(")0
M;VQE;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-PIM<V=I9"`B4&]L
M:71I8W,B"FUS9W-T<B`B4&]L:71I96LB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#@Y"FUS9VED(")0;VQL<R(*;7-G<W1R(")096EL:6YG96XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DS"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R(")0;W)T
M=6=A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$R-`IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I
M;6%G92(*;7-G<W1R(")0;W-I=&EO;F5R:6YG('9A;B!D97IE(&%F8F5E;&1I
M;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R
M(")0;W-I=&EO;F5R:6YG('9A;B!D97IE('1A8F5L(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3$*;7-G:60@(E!O<W0@=&\@=&AI
M<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R(")3='5U
M<B!N86%R(&1E>F4@;6%P("AN:65T(&%F9V5D=V]N9V5N(&1O;W(@24U!4"DB
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W,R!L:6(O0FQO8VLO;65T87(N
M<&AP.C(W.`HC+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O
M<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R(").965R<VQA9R!V86X@9&4@
M869G96QO<&5N("5S('5R96XZ("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR.#<*;7-G:60@(E!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4B
M"FUS9W-T<B`B3F5E<G-L86<\8G(@+SYK86YS(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+VQD87`N<&AP.CDX"FUS9VED(")0<F5F<U]L9&%P.B!297%U
M:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S
M7VQD87`Z('9E<F5I<W1E($Q$05`@97AT96YT:64@;FEE="!G979O;F1E;BXB
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G
M:60@(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?<V5S<VEO;CH@=F5R96ES=&4@
M<V5S<VEE(&5X=&5N=&EE(&YI970@9V5V;VYD96XN(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,S(*;7-G:60@(E!R97-S=7)E(@IM<V=S='(@(DQU8VAT
M9')U:R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C8V"FUS9VED(")0<F5S
M<W5R92!A="!S96$@;&5V96PZ("(*;7-G<W1R("),=6-H=&1R=6L@;W`@>F5E
M;FEV96%U.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(T
M"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@(DQU8VAT9')U:SH@(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P,PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C`*;7-G:60@(E!R979I97<B"FUS9W-T<B`B0F5O;W)D96QE;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R,0IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN
M9&]W(@IM<V=S='(@(D)E;V]R9&5E;"!D92!A9F)E96QD:6YG(&EN(&5E;B!N
M:65U=R!S8VAE<FTB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C,U-B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V,`IM<V=I9"`B
M4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R(")6;W)I9V4@;W!T:65S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I
M9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B1&]C=6UE;G0@869D<G5K:V5N
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED
M(")0<FEV871E($ME>2(*;7-G<W1R(")0<FEV92!S;&5U=&5L(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V.0IM<V=I9"`B4')O8FQE
M;2(*;7-G<W1R(")0<F]B;&5E;2(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP
M.C$R-PIM<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R(")0<F]B
M;&5E;6)E<V-H<FEJ=FEN9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS-S$*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(E!R;VIE8W1E;B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,3$@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C$X.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<V
M"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R(")0<F]M<'0@=&5K<W0B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U
M8FQI8R!+97DB"FUS9W-T<B`B3W!E;F)A<F4@<VQE=71E;"(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0V"FUS9VED(")0=6)L:6,@
M2V5Y($%L9V]R:71H;2(*;7-G<W1R(")/<&5N8F%R92!S;&5U=&5L(&%L9V]R
M:71H;64B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T
M-0IM<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(D]P96YB87)E('-L
M975T96QI;F9O<FUA=&EE(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G
M96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")/<&5N8F%A<B]0<FEV
M92!S;&5U=&5L<&%A<B!N:65T(&=E9V5N97)E97)D+B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.3$*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S='(@(E!U97)T;R!2:6-O(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-34*;7-G
M:60@(E!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(E=I<R!B97)I8VAT96XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DV"FUS9VED(")1871A<B(*;7-G<W1R(")1=6%T87(B"@HC
M.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C0*;7-G:60@(E%U97)Y(@IM<V=S='(@
M(E%U97)Y(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@P"FUS9VED(")1
M=6]T82(*;7-G<W1R(")1=6]T82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C8T"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L
M:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@(E)302!O<&5N8F%R92!S;&5U=&5L
M("@E9"!B:70I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-`IM
M<V=I9"`B4F%D:6\@<V5L96-T:6]N(@IM<V=S='(@(DME=7IE<F]N9&IE('-E
M;&5C=&EE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#4*;7-G:60@(E)A:6XB"FUS9W-T<B`B4F5G96XB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B4F%I;B!%
M87)L>2(*;7-G<W1R(")6<F]E9R!R96=E;B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")286EN($QA=&4B"FUS
M9W-T<B`B3&%A="!R96=E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R(")2
M96=E;F)U:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0Y"FUS9VED(")286EN(&%N9"!3;F]W(@IM<V=S='(@(E)E9V5N(&5N
M('-N965U=R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4P"FUS9VED(")286EN('1O(%-N;W<B"FUS9W-T<B`B4F5G96X@;F%A
M<B!S;F5E=7<B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B
M4F%N9&]M($9O<G1U;F4B"FUS9W-T<B`B4F%N9&]M($9O<G1U;F4B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8X(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO(@IM
M<V=S='(@(E9E<FAO=61I;F<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-"!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A9"(*;7-G<W1R("),97IE;B(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C0W"FUS9VED(")2
M96%D(&UE<W-A9V5S(@IM<V=S='(@(DQE97,@8F5R:6-H=&5N(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO
M="!B92!U;F1O;F4N(@IM<V=S='(@(B5S(&5C:'0@=F5R=VEJ9&5R96X_($1E
M>F4@8F5W97)K:6YG(&MA;B!N:65T(&]N9V5D86%N(&=E;6%A:W0@=V]R9&5N
M+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX"B,L('!H
M<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U
M<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G
M<W1R("(B"B)'96)R=6EK97)S9&%T82!V86X@9V5B<G5I:V5R("5S(&5C:'0@
M=F5R=VEJ9&5R96X_($1E>F4@8F5W97)K:6YG(&MA;B!N:65T("(*(F]N9V5D
M86%N(&=E;6%A:W0@=V]R9&5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@
M86-T:6]N(@IM<V=S='(@(DAE<FAA86QT('5W('9O<FEG92!B97=E<FMI;F<B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R(")697)V97)S96XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDU"FUS9VED(")2969R97-H
M($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B5F5R=F5R<R!D>6YA
M;6ES8VAE(&UE;G4@;VYD97)D96QE;CHB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S0U"FUS9VED(")2969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R
M(")0;W)T86QW965R9V%V92!V97)V97)S96XZ(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#DT(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3,*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-0IM<V=I9"`B4F5G97@B
M"FUS9W-T<B`B4F5G97@B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,C,Q"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R(")"971R
M96MK:6YG96X@8G)O=W-E<B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*;7-G:60@
M(E)E;&]A9"(*;7-G<W1R(")(97)L861E;B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S,S"FUS9VED(")296UA<FMS(@IM<V=S='(@(D]P;65R:VEN9V5N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-PIM<V=I9"`B4F5M;W1E
M(%-E<G9E<G,B"FUS9W-T<B`B4V5R=F5R<R!O<"!A9G-T86YD(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED(")296UO=&4@55),
M("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T<B`B55),
M(&]P(&%F<W1A;F0@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3,@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,@IM<V=I9"`B4F5M;W9E(@IM
M<V=S='(@(E9E<G=I:F1E<F5N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO
M=70N:6YC.C$Q"FUS9VED(")296UO=F4@0FQO8VLB"FUS9W-T<B`B0FQO:R!V
M97)W:6ID97)E;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HU-3D*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B2V]L
M;VT@=F5R=VEJ9&5R96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C0P"FUS9VED(")296UO=F4@9F]R;6%T=&EN9R(*;7-G
M<W1R(")/<&UA86L@=F5R=VEJ9&5R96XB"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`B4&%A
M<B!V97)W:6ID97)E;B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,#(*
M;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP
M;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("(B"B)697)W:6ID97(@:&5T(&]P
M9V5S;&%G96X@<V-R:7!T('5I="!D92!T:6ID96QI:FME(&1I<F5C=&]R>2!O
M<"!D92!S97)V97(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C0R"FUS9VED(")296UO=F4@=&AE(@IM<V=S
M='(@(E9E<G=I:F1E<B!D92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I9"`B4F5M;W9E('1H:7,@
M;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G<W1R(")697)W:6ID97(@9&5Z
M92!N;V1E('5I="!H970@9&]C=6UE;G0B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F4N:6YC.C$Q"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R
M(")'96)R=6EK97(@=F5R=VEJ9&5R96XB"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F4N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E
M('5S97(Z("5S(@IM<V=S='(@(E9E<G=I:F1E<B!G96)R=6EK97(Z("5S(@H*
M(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ,S@*;7-G:60@(E)E
M<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D
M93H@(@IM<V=S='(@(E9E<GIO96L@:V]N(&YI970@=V]R9&5N(&)E86YT=V]O
M<F0N($=E<F5T;W5R;F5E<F1E(&9O=71C;V1E.B`B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,30U"FUS9VED(")297%U97-T960@<V5R=FEC
M92!C;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@(D1E(&=E=G)A86=D92!S
M97)V:6-E(&MO;B!N:65T('=O<F1E;B!G979O;F1E;BXB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$X-2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C4R-PHC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@
M;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")6
M97)E:7-T92!<(B5S7"(@;FEE="!O<&=E9V5V96X@:6X@)7,@8V]N9FEG=7)A
M=&EE+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#8Q(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C<X"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HW,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER
M960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(E9E<F5I<W1E(%PB)7-<(B!N:65T(&]P9V5G979E;B!I;B!6
M1E,@8V]N9FEG=7)A=&EE+B(*"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP
M.C<W-@HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T
M('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")697)E:7-T
M92!<(B5S7"(@;FEE="!O<&=E9V5V96X@:6X@8V]N9FEG=7)A=&EE+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,S-@IM<V=I9"`B
M4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B5F5R96ES="!V96QD(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,S$@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(R,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,SD@9G)A
M;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S(Q"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`B2&5R<W1E;&QE
M;B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"FUS9VED(")2
M97-E="!087-S=V]R9"(*;7-G<W1R(")297-E="!W86-H='=O;W)D(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*;7-G:60@(E)E<V5T(%EO
M=7(@4&%S<W=O<F0B"FUS9W-T<B`B4F5S970@=7<@=V%C:'1W;V]R9"(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S$*;7-G:60@(E)E<W1O<F4@3&%S="!1
M=65R>2(*;7-G<W1R(")6;V]R9V%A;F1E('%U97)Y(&AE<G-T96QL96XB"@HC
M.B!A9&UI;B]C;61S:&5L;"YP:'`Z,CD@861M:6XO<&AP<VAE;&PN<&AP.C<R
M(&%D;6EN+W-Q;'-H96QL+G!H<#HV-PIM<V=I9"`B4F5S=6QT<R(*;7-G<W1R
M(")297-U;'1A=&5N(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C$P,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U<FX@
M=&\@3W!T:6]N<R(*;7-G<W1R(")497)U9R!N86%R(&]P=&EE<R(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS.`IM<V=I9"`B4F5T>7!E(&YE
M=R!P87-S=V]R9"(*;7-G<W1R(")4>7`@;FEE=7<@=V%C:'1W;V]R9"!O<&YI
M975W(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y-PIM<V=I9"`B4F5U;FEO;B(*;7-G<W1R(")2
M975N:6]N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO
M;B(*;7-G<W1R(")#;VYF:6=U<F%T:64@=&5R=6=Z971T96XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3,U"FUS9VED(")2:6-H(%1E>'0@161I=&]R
M($]P=&EO;G,B"FUS9W-T<B`B4FEC:"!497AT($5D:71O<B!O<'1I97,B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS
M9W-T<B`B4F%A9'-E;',B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#@*;7-G:60@(E)I9VAT(@IM<V=S='(@(E)E
M8VAT<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,#,*;7-G:60@
M(E)I9VAT(&AE861E<B(*;7-G<W1R(")296-H='-E(&MO<"(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,P.3D*;7-G:60@(E)I9VAT('9A;'5E<R(*
M;7-G<W1R(")296-H='-E('=A87)D96XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@
M4')O<&5R=&EE<RXN+B(*;7-G<W1R(")2:5]J96EG96YS8VAA<'!E;BXN+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,S0*
M;7-G:60@(E)O;&4B"FUS9W-T<B`B4F]L(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y.`IM<V=I
M9"`B4F]M86YI82(*;7-G<W1R(")2;V5M96YIZR(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,C8*;7-G:60@(E)O=&%T92`Q
M.#`B"FUS9W-T<B`B,3@P(&1R86%I96XB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(S"FUS9VED(")2;W1A=&4@3&5F="(*
M;7-G<W1R(").86%R(&QI;FMS(&1R86%I96XB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(Y"FUS9VED(")2;W1A=&4@4FEG
M:'0B"FUS9W-T<B`B3F%A<B!R96-H=',@9')A86EE;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G:60@
M(E)O=R!0<F]P97)T:65S(@IM<V=S='(@(E)I:B!E:6=E;G-C:&%P<&5N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW,`IM<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`B4FEJ(&5I9V5N
M<V-H87!P96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P,0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`B4FEJ96XZ(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M,PIM<V=I9"`B4G5L97,B"FUS9W-T<B`B3&EN:>MR:6YG(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,`IM<V=I
M9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L
M=6UN<R(*;7-G<W1R("),:6YIZW)I;F<@>F%L('9E<G-C:&EJ;F5N('1U<W-E
M;B!A;&QE(')I:F5N(&5N(&MO;&]M;65N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@
M=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`B3&EN
M:>MR:6YG('IA;"!A;&QE96X@='5S<V5N(&MO;&]M;65N('9E<G-C:&EJ;F5N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S
M(&]N;'DB"FUS9W-T<B`B3&EN:>MR:6YG('IA;"!A;&QE96X@='5S<V5N(')I
M:F5N('9E<G-C:&EJ;F5N(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R,0IM
M<V=I9"`B4G5N(@IM<V=S='(@(E-T87)T96XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DY"FUS
M9VED(")2=7-S:6%N($9E9&5R871I;VXB"FUS9W-T<B`B4G5S<VES8VAE($9E
M9&5R871I92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,#`*;7-G:60@(E)W86YD82(*;7-G<W1R
M(")2=V%N9&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C(X-0IM<V=I9"`B4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM
M<V=S='(@(D-R>7!T;V=R869I<V-H92!3+TU)344@:&%N9'1E:V5N:6YG(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS,C,*;7-G:60@
M(E,O34E-12!%;F-R>7!T960@365S<V%G92(*;7-G<W1R(")3+TU)344@9V5C
M;V1E97)D(&)E<FEC:'0B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN
M<&AP.C@Q"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I
M;&%B;&4N(@IM<V=S='(@(E-!4TP@875T:&5N=&EC871I92!I<R!N:65T(&)E
M<V-H:6MB86%R+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,#8*
M;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T<B`B4TU3('9E<G-T=7)E;B(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM
M<V=S='(@(E-13"!S:&5L;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,R-S0*;7-G:60@(E-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',B
M"FUS9W-T<B`B4U%,('-T871E;65N="!V;V]R('=A87)D97IO96MO<&1R86-H
M=&5N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S,PIM<V=I9"`B
M4U-((@IM<V=S='(@(E-32"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-5
M0T-%4U,B"FUS9W-T<B`B4U5#0T53(@H*(SH@;&EB+V%P:2YP:'`Z,34S"FUS
M9VED(")37U%,(%-H96QL(@IM<V=S='(@(E-?44P@<VAE;&PB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")3
M82(*;7-G<W1R("):82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#<*;7-G:60@(E-A:6YT($AE
M;&5N82(*;7-G<W1R(")3="!(96QE;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S$*;7-G:60@
M(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R(")3="!+:71T<R!E;B!.
M979I<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S.0IM<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T
M<B`B4W0@3'5C:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Y"FUS9VED(")386EN="!0:65R
M<F4@86YD($UI<75E;&]N(@IM<V=S='(@(E-T(%!I97)R92!E;B!-:7%U96QO
M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-#0*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H
M92!'<F5N861I;F5S(@IM<V=S='(@(E-T(%9I;F-E;G0@96X@9&4@1W)E;F%D
M:6YE<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R("):96QF
M9&4@9G)A;64@*%]S96QF*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.30*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3$*;7-G:60@(E-A;6]A
M(@IM<V=S='(@(E-A;6]A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,@IM<V=I9"`B4V%N($UA
M<FEN;R(*;7-G<W1R(")386X@36%R:6YO(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Y-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-@IM<V=I
M9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S='(@(E-A;R!4;VUE(&5N
M(%!R:6YC:7!E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M.0IM<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(E-A=&5L;&EE
M='!R;W9I9&5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,0IM<V=I9"`B4V%U9&D@07)A8FEA
M(@IM<V=S='(@(E-A=61I($%R86)IZR(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;&%Y;W5T+FEN8SHY.0IM<V=I9"`B4V%V92(*;7-G<W1R(")/<'-L86%N(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3879E(%PB)7-<(B(*;7-G<W1R(")<(B5S7"(@;W!S
M;&%A;B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V"B,L('!H
M<"UF;W)M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`B)7,@;W!S;&%A;B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T
M:6]N<R(*;7-G<W1R(")/<'1I97,@;W!S;&%A;B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ-C<*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I
M9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M
M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB1V5G96YE<F5E<F1E
M(&-O;F9I9W5R871I92!A;',@4$A0('-C<FEP="!O<&=E<VQA9V5N(&EN(&1E
M('1I:F1E;&EJ:V4@(@HB9&ER96-T;W)Y('9A;B!U=R!S97)V97(N(@H*(SH@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B)7,@8V]N9FEG
M=7)A=&EE(&]P9V5S;&%G96XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HY,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U<&=R861E
M('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(")3971U<"!U<&=R861E('-C
M<FEP="!O<&=E<VQA9V5N(&YA87(Z(%PB)7-<(BXB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,0IM<V=I9"`B4V-A='1E<F5D
M(%0M4W1O<FUS(@IM<V=S='(@(D=E<W!R96ED92!O;G=E97)S8G5I96XB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C:65N8V4B"FUS
M9W-T<B`B5V5T96YS8VAA<"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI
M<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS
M9VED(")396%R8V@B"FUS9W-T<B`B6F]E:V5N(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,R,@IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T
M<B`B6F]E:VUA8VAI;F5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,CDU-0IM<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S='(@(DMI97,@8F5S=&%N
M9&5N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0X-0IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R(")396QE8W1E97(@
M965N(&1A='5M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.3@*
M;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R(")396QE8W1E
M97(@965N(&=R;V5P(&]M('1O92!T92!V;V5G96XB"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C0S"FUS9VED(")396QE8W0@82!N97<@;W=N97(B
M"FUS9W-T<B`B4V5L96-T965R(&5E;B!N:65U=V4@96EG96YA87(B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@(E-E;&5C="!A
M('-E<G9E<B(*;7-G<W1R(")396QE8W1E97(@965N('-E<G9E<B(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,34V"FUS9VED(")396QE8W0@82!U
M<V5R('1O(&%D9"(*;7-G<W1R(")396QE8W1E97(@965N(&=E8G)U:6ME<B!O
M;2!T;V4@=&4@=F]E9V5N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C8W-@IM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R(")!
M;&QE<R!S96QE8W1E<F5N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C8T,PIM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM<V=S
M='(@(E-E;&5C=&5E<B!A;&QE(&1A='5M8V]M<&]N96YT96XN(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B
M4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R(")396QE8W1E97(@965N(&]B:F5C
M="(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV
M-S<*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(DYI971S('-E;&5C=&5R
M96XB"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*;7-G:60@(B(*(E-E
M;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B
M96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O
M;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B)396QE8W1E97(@9&4@8F5N
M;V1I9V1E(&MA<F%K=&5R<R!U:70@9&4@;VYD97)S=&%A;F1E('9A:VIE<RX@
M52!K=6YT(&1E>F4@9&%N("(*(FMO<&GK<F5N(&5N('!L86MK96X@:6X@:&5T
M('1E:W-T9V5B:65D+B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T
M"FUS9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R(")3
M96QE8W1E97(@:&5T(&1A='5M<V-H96ED:6YG<W1E:V5N.B(*"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@
M9F]R;6%T.B(*;7-G<W1R(")396QE8W1E97(@:&5T(&1A='5M9F]R;6%A=#HB
M"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDP"FUS
M9VED(")396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93HB
M"FUS9W-T<B`B4V5L96-T965R(&1E(&ED96YT:71E:70@9&EE('4@=VEL="!W
M:6IZ:6=E;CHB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@IM<V=I
M9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B4V5L96-T
M965R(&AE="!T:6ID<V-H96ED:6YG<W1E:V5N.B(*"B,Z('1E;7!L871E<R]D
M871A+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE('1I;64@9F]R;6%T
M.B(*;7-G<W1R(")396QE8W1E97(@:&5T('1I:F1S9F]R;6%A=#HB"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4W"FUS9VED(")396QE8W0@='=O
M(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`B4V5L96-T965R('1W964@;W9E
M<F5E;FMO;65N9&4@=F5L9&5N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS,3`*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T
M<B`B4V5L96-T965R('5W(&ML975R<V-H96UA+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR-3(*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L
M86YG=6%G93HB"FUS9W-T<B`B4V5L96-T965R('5W(&=E=V5N<W1E('1A86PZ
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@
M(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B4')O8FQE96UR87!P;W)T
M('9E<GIE;F1E;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,#0R"FUS9VED(")396YD(%--4R(*;7-G<W1R(")697)Z96YD
M(%--4R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,3,*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B
M4V5N96=A;"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(S"FUS9VED(")3
M96YS;W(Z("(*;7-G<W1R(")396YS;W(Z("(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,3`*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS
M9W-T<B`B4V5P=&5M8F5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R;R(*;7-G
M<W1R(")397)V:>L@96X@36]N=&5N96=R;R(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-S`R"FUS9VED(")397)I86P@3G5M8F5R(@IM
M<V=S='(@(E-E<FEE;G5M;65R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$T.0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B4V5R=F5R9&%T82!F;W5T(&]F(&YI970@8F5S
M8VAI:V)A87(N(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(W"FUS9VED(")3
M97-S:6]N($%D;6EN(@IM<V=S='(@(E-E<W-I96)E:&5E<F1E<B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@IM
M<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R(")397-S:64@240@
M=F5R;&]P96XN(@H*(SH@;&EB+V%P:2YP:'`Z,30U"FUS9VED(")397-S:6]N
M<R(*;7-G<W1R(")397-S:65S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C,Q-`IM<V=I9"`B4V5T(@IM<V=S='(@(DEN<W1E;&QE;B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HW.0IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@
M86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@
M9F]R9V5T(&ET+B(*;7-G<W1R("(B"B));G-T96QL96X@=F%N(&]P=&EE<R!O
M;2!U('1O92!T92!S=&%A;B!U=R!W86-H='=O;W)D('1E(')E<V5T=&5N+"!W
M86YN965R('4@(@HB9&ET(&)E;G0@=F5R9V5T96XN(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$Q.`IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S
M('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM
M<V=S='(@(B(*(DEN<W1E;&QE;B!V86X@<V5R=F5R<R!O<"!A9G-T86YD(&1I
M92!U('=I;'0@8F5N861E<F5N('9A;G5I="!U=R!P;W)T86PN(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@W"FUS9VED(")3970@>6]U<B!P<F5F97)R
M960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S
M='(@(DEN<W1E;&QE;B!V86X@=7<@9V5W96YS=&4@=&%A;"P@=&EJ9'IO;F4@
M96X@9&%T=6UO<'1I97,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P
M,0IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L
M;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P
M;&%Y(&]P=&EO;G,N(@IM<V=S='(@(B(*(DEN<W1E;&QE;B!V86X@=7<@;W!S
M=&%R='1O97!A<W-I;F<L(&ML975R<V-H96UA+"!P86=I;F%V97)V97)S:6YG
M(&5N(&%N9&5R92`B"B)W965R9V%V96]P=&EE<RXB"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C<W"FUS9VED(")3971U<"(*;7-G<W1R("));G-T96QL
M96XB"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS-PIM
M<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R
M(")3971U<"!U<&=R861E('-C<FEP=',@8F5S8VAI:V)A87(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<U"FUS9VED(")3979E<F%L(&QO
M8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*;7-G<W1R
M(")697)S8VAI;&QE;F1E(&QO8V%T:65S(&UO9V5L:6IK(&UE="!D92!P87)A
M;6%T97(Z("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,#,*;7-G:60@(E-E>6-H96QL97,B"FUS
M9W-T<B`B4V5Y8VAE;&QE;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT.3@*;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@(E=I;FME;&5N(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@(E-H;W)T
M(%-U;6UA<GDB"FUS9W-T<B`B2V]R=&4@<V%M96YV871T:6YG(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0U,`IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K
M97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@(D1I96YE
M;B!S;F5L=&]E='-E;B!V;V]R(&1E(&UE97-T92!L:6YK<R!G961E9FEN:65E
M<F0@=&4@=V]R9&5N/R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,S(S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$S('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(E=E97)G979E;B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF
M9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L
M>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB5F5R
M<V-H:6QL96X@;&%T96X@>FEE;B!T=7-S96X@9&4@:'5I9&EG92!O<&=E<VQA
M9V5N(&-O;F9I9W5R871I92!E;B!D92`B"B)N:65U=V4@9V5G96YE<F5E<F1E
M(&-O;F9I9W5R871I92XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DT
M"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_
M(@IM<V=S='(@(DQA871S=&4@86%N;65L9&EN9W-T:6ID('=E97)G979E;B!B
M:6H@86%N;65L9&5N/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W
M-C4*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS9W-T
M<B`B3W!T:64@=V5E<F=E=F5N(&]M(&]R:6=I;F5E;"!T92!B97=A<F5N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<Y-0IM<V=I9"`B4VAO=R!P
M:6-K97(B"FUS9W-T<B`B2VEE>F5R('=E97)G979E;B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,S`*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T:6]N
M<R!M96YU(&)A<C\B"FUS9W-T<B`B5&%B96QB97=E<FMI;F=S=&%A:V)A;&L@
M=V5E<F=E=F5N/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F
M=#\B"FUS9W-T<B`B)7,@;65N=2!A86X@9&4@;&EN:V5R:V%N="!W965R9V5V
M96X_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!486)L92!#96QL(%!R;W!E
M<G1I97,@9&EA;&]G(@IM<V=S='(@(E1A8F5L8V5L96EG96YS8VAA<'!E;B!D
M:6%L;V]G=F5N<W1E<B!W965R9V5V96XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@
M=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(E1A8F5L96EG
M96YS8VAA<'!E;B!D:6%L;V]G=F5N<W1E<B!W965R9V5V96XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*
M;7-G:60@(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*
M;7-G<W1R(")486)E;')I:F5I9V5N<V-H87!P96X@9&EA;&]O9W9E;G-T97(@
M=V5E<F=E=F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P
M97)T:65S(&1I86QO9R(*;7-G<W1R(")!9F)E96QD:6YG<V5I9V5N<V-H87!P
M96X@9&EA;&]O9W9E;G-T97(@=V5E<F=E=F5N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3<V,PIM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T<B`B
M57!L;V%D('=E97)G979E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4R"FUS9VED(")3:&]W97)S(@IM<V=S='(@(D)U:65N
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*
M;7-G:60@(E-H;W=E<G,@16%R;'DB"FUS9W-T<B`B0G5I96X@=G)O96<B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-`IM<V=I
M9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(D)U:65N(&QA870B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VAO
M=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B0G5I96X@:6X@9&4@;F%B
M:6IH96ED(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA
M9V5R+G!H<#HV,3D*;7-G:60@(E-H<FEN:R(*;7-G<W1R(")697)K;&5I;F5N
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HY,3`*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HY-S(*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA
M9V5R+G!H<#HQ,#4X"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z,3$R,`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C$Q.#,*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HQ,C(S"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(U,@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R.#4*;7-G:60@(E-H<FEN
M:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A
M>2!F:7)S="(*;7-G<W1R(")697)K;&5I;B!O9B!V97)P;&%A=',@;F%B=7)I
M9V4@8FQO:VME;B!E97)S="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3$*;7-G:60@(E-I97)R
M82!,96]N92(*;7-G<W1R(")3:65R<F$@3&5O;F4B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z,C8V"FUS9VED(")3:6=N('5P(@IM<V=S
M='(@(DEN=&5K96YE;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-S$S"FUS9VED(")3:6=N871U<F4B"FUS9W-T<B`B2&%N9'1E:V5N
M:6YG(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3(*
M;7-G:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`B2&%N9'1E:V5N
M:6YG(&%L9V]R:71H;64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V"FUS9VED(")3:6YG87!O
M<F4B"FUS9W-T<B`B4VEN9V%P;W)E(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV-2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C@T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DV"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R,34@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(S-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0V(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,3(*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S$P-0IM<V=I9"`B4VEZ92(*;7-G<W1R(")'<F]O='1E(@H*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G
M:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B3VYD97)H;W5D(&]V97)S
M;&%A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,3`*;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@
M(E-L;W=A:VEJ92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#@*;7-G:60@(E-L;W9E;FEA(@IM
M<V=S='(@(E-L;W9E;FGK(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-38*;7-G:60@(E-N;W<B"FUS9W-T<B`B4VYE975W(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G
M:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@(E-N965U=W9L86%G(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@(E-N
M;W<@4VAO=V5R<R(*;7-G<W1R(")3;F5E=7=B=6EE;B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3;F]W(%-H
M;W=E<G,@16%R;'DB"FUS9W-T<B`B<VYE975W8G5I96X@=G)O96<B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,`IM<V=I9"`B
M4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B4VYE975W8G5I96X@;&%A="(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@U"FUS9VED(")3;F]W(&1E<'1H
M.B`B"FUS9W-T<B`B4VYE975W9&EE<'1E.B`B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(X.0IM<V=I9"`B4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B`B
M"FUS9W-T<B`B4VYE975W97%U:79A;&5N="!I;B!W871E<CH@(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P,@IM<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(E-O;&]M
M;VX@96EL86YD96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$T"FUS9VED(")3;VUA;&EA(@IM
M<V=S='(@(E-O;6%L:>LB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*
M;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B3&EE9&5R96X@96X@9V5D
M:6-H=&5N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDP.`IM<V=I
M9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`B4V]R=&5E<G9O;&=O
M<F1E('-E;&5C=&EE(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C$W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(T-PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C$V-@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C$X.0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B
M"FUS9W-T<B`B0G)O;F%D<F5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-0IM<V=I9"`B4V]U
M=&@@069R:6-A(@IM<V=S='(@(EIU:60@069R:6MA(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E-O=71H($5U<F]P96%N("A)4T\M.#@U
M.2TS*2(*;7-G<W1R("):=6ED($5U<F]P965S("A)4T\M.#@U.2TS*2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$P,0IM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H
M(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B6G5I9"!'96]R9VGK(&5N(&1E
M(%IU:60@4V%N9'=I8V@@96EL86YD96XB"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(
M96UI<W!H97)E(@IM<V=S='(@(EIU:61E;&EJ:R!H86QF<F]N9"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED
M(")3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(E-P871I
MZW)I;F<@='5S<V5N(&%A;F=R96YZ96YD92!C96QL96XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A
M8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R
M(")3<&%T:>MR:6YG('1U<W-E;B!I;FAO=60@96X@<F%N9"!I;B!C96PB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX,34*;7-G:60@(E-P86-E<B(*
M;7-G<W1R(")38VAE:61I;F=S=&5K96XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@P"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*;7-G:60@(E-P86-I;F<B
M"FUS9W-T<B`B4W!A=&GK<FEN9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I;F<@86YD
M('!A9&1I;F<B"FUS9W-T<B`B4W!A=&GK<FEN9R!E;B!V<FEJ92!R=6EM=&4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX,`IM<V=I9"`B4W!A:6XB"FUS9W-T<B`B4W!A;FIE(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P,`IM<V=I9"`B4W!A;2(*
M;7-G<W1R(")3<&%M(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS
M9VED(")3<&5C:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R(")3<&5C:6%A
M;"!K87)A:W1E<B!I;G9O97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM
M<V=S='(@(D-E;"!O<'-P;&ET<V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L:70@8V]L
M=6UN(@IM<V=S='(@(DMO;&]M(&]P<W!L:71S96XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED(")3
M<&QI="!R;W<B"FUS9W-T<B`B4FEJ(&]P<W!L:71S96XB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-C$*;7-G:60@(E-P;W)T<R(*;7-G<W1R(")3<&]R
M="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T,0IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(E-R
M:2!,86YK82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#$@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C8V"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R
M(")3=&%N9&%A<F0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G
M:60@(E-T87(@5')E:R(*;7-G<W1R(")3=&%R(%1R96LB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-3@V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(W.3$*;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B4W1A<G1J86%R(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S$*;7-G:60@
M(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(E-T86%T(&]F('!R;W9I;F-I
M92(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS
M9VED(")3=&%T=7,B"FUS9W-T<B`B4W1A='5S(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C<Y-PIM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T
M<B`B3W!S;&%G9F]R;6%A="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3<S"FUS9VED(")3=')E970@061D<F5S<R(*;7-G<W1R(")!
M9')E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T<B`B1&]O<FAA;&5N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S,PIM<V=I9"`B4W1R
M:6YG(&QI<W0B"FUS9W-T<B`B4W1R:6YG;&EJ<W0B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#<S"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T
M:&4@861D<F5S<R(*;7-G<W1R(")3=')I<"!D;VUE:6X@=F%N(&AE="!A9')E
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(E-T:6IL(%M#
M4U-=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHV,@IM<V=I9"`B4W4B"FUS9W-T<B`B6F\B"@HC.B!U=&EL+VEC;VY?8G)O
M=W-E<BYP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y
M(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(E-U8F1I<F5C=&]R>2!<(B5S
M7"(@;FEE="!G979O;F1E;BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J96-T(@IM<V=S='(@(D]N
M9&5R=V5R<"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,B!F<F%M
M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3@*;7-G:60@(E-U8FUI
M="(*;7-G<W1R(")"979E<W1I9V5N(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@
M7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL
M('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B
M(@HB5F5R>F]E:R!V97)S='5U<F0@;VT@7"(E<UPB(&%A;B!H970@<WES=&5E
M;2!T;V4@=&4@=F]E9V5N+B!5(&MU;G0@;FEE="`B"B)A86YM96QD96X@=&]T
M('5W('9E<GIO96L@:7,@9V]E9&=E:V5U<F0N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R:7!T
M(@IM<V=S='(@(E-U8G-C<FEP="(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,#4*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES
M=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R(")3
M=6-C97,B"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S>7-T96TN
M(@IM<V=S='(@(EPB)7-<(B!M970@<W5C8V5S(&%A;B!H970@<WES=&5E;2!T
M;V5G979O96=D+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R
M(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(D1A=&$@=F%N(&=E
M8G)U:6ME<B!<(B5S7"(@;65T('-U8V-E<R!U:70@:&5T('-Y<W1E96T@=F5R
M=VEJ9&5R9"XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS
M+V1E;&5T92YP:'`Z-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R(")<(B5S7"(@;65T('-U8V-E
M<R!V97)W:6ID97)D+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O
M;2!T:&4@<WES=&5M+B(*;7-G<W1R(")<(B5S7"(@;65T('-U8V-E<R!U:70@
M:&5T('-Y<W1E96T@=F5R=VEJ9&5R9"XB"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG
M=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R(")#;VYF
M:6=U<F%T:64@;65T('-U8V-E<R!T97)U9V=E>F5T+B!697)N:65U=R!O;2!W
M:6IZ:6=I;F=E;B!T92!Z:65N+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HU.2!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU-PIM<V=I9"`B4W5C8V5S
M<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")"
M86-K=7!C;VYF:6=U<F%T:64@;65T('-U8V-E<W,@;W!G97-L86=E;BXB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8R"B,L('!H<"UF;W)M870*;7-G
M:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I
M;VX@9FEL92`E<RXB"FUS9W-T<B`B0F%C:W5P8V]N9FEG=7)A=&EE8F5S=&%N
M9"`E<R!M970@<W5C8V5S<R!O<&=E<VQA9V5N+B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=7!D
M871E9"!<(B5S7"(B"FUS9W-T<B`B7"(E<UPB(&UE="!S=6-C97,@8FEJ9V5W
M97)K="(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F
M=6QL>2!W<F]T92`E<R(*;7-G<W1R("(E<R!M970@<W5C8V5S(&=E<V-H<F5V
M96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`T"FUS9VED(")3=61A;B(*;7-G<W1R(")3;V5D
M86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4V"FUS9VED(")3=6UM87)Y(@IM<V=S='(@(E-A;65N=F%T=&EN
M9R(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV-0IM<V=I9"`B4W5N(%)I
M<V4B"FUS9W-T<B`B6F]N<V]P9V%N9R(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*;7-G<W1R("):;VYS;VYD97)G86YG
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C$*
M;7-G:60@(E-U;FYY(@IM<V=S='(@(EIO;FYI9R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,#4*;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`B
M6F]N<V]P9V%N9R(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]"
M;&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS
M9W-T<B`B6F]N<V]P9V%N9R]:;VYS;VYD97)G86YG(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(P-`IM<V=I9"`B4W5N<FES93H@(@IM<V=S
M='(@(EIO;G-O<&=A;F<Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,#@*;7-G:60@(E-U;G-E="(*;7-G<W1R("):;VYS;VYD97)G86YG
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-PIM<V=I9"`B
M4W5N<V5T.B`B"FUS9W-T<B`B6F]N<V]N9&5R9V%N9SH@(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P
M97)S8W)I<'0B"FUS9W-T<B`B4W5P97)S8W)I<'0B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S@P"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(D]N
M9&5R<W1E=6YI;F<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$U"FUS9VED(")3=7)I;F%M92(*
M;7-G<W1R(")3=7)I;F%M92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3<U"FUS9VED(")3=7)N86UE(@IM<V=S='(@(D%C:'1E<FYA
M86TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`Y"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA
M>65N(@IM<V=S='(@(E-P:71S8F5R9V5N(&5N($IA;B!-87EE;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,3D*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R(")3=V%Z:6QA;F0B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`U"FUS9VED(")3=V5D96XB"FUS9W-T<B`B6G=E9&5N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-38*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S='(@(EIW
M:71S97)L86YD(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*
M;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B"FUS9W-T<B`B4WEN8R!L;V<@=F5R
M=VEJ9&5R9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#4*;7-G:60@
M(E-Y;F--3"(*;7-G<W1R(")3>6YC34PB"@HC.B!F<F%M97=O<FLO4U%,+U-1
M3"]+97EW;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R
M8V@@=&5R;7,B"FUS9W-T<B`B4WEN=&%X9F]U="!I;B!Z;V5K=&5R;65N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q.`IM<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS
M9W-T<B`B4WER:7-C:&4@07)A8FES8VAE(%)E<'5B;&EE:R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS9VED(")4+5-T
M;W)M(@IM<V=S='(@(D]N=V5E<G-B=6DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3=&]R;2!A;F0@5VEN
M9'DB"FUS9W-T<B`B3VYW965R<V)U:65N(&5N('=I;F1E<FEG(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*;7-G:60@(E0M
M4W1O<FUS(@IM<V=S='(@(D]N=V5E<G-B=6EE;B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")4+5-T;W)M<R!%
M87)L>2(*;7-G<W1R(")/;G=E97)S8G5I96X@=G)O96<B"@HC.B!F<F%M97=O
M<FLO1&%T82]$871A+W1S=BYP:'`Z,38V"FUS9VED(")44U8@9FEL92(*;7-G
M<W1R(")44U8@8F5S=&%N9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I
M97,B"FUS9W-T<B`B5&%B96QE:6=E;G-C:&%P<&5N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PIM<V=I9"`B5&%B;&4@
M4V5T(@IM<V=S='(@(E1A8F5L<V5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O
M<&5R=&EE<R(*;7-G<W1R(")486)E;&5I9V5N<V-H87!P96XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,T"FUS9VED(")486EW86XB"FUS9W-T<B`B5&%I=V%N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@
M(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`B5&%I=V%N+"!0
M<F]V:6YC:64@=F%N($-H:6YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-0IM<V=I9"`B5&%J
M:6MI<W1A;B(*;7-G<W1R(")4861Z:FEK:7-T86XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,U
M"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S='(@
M(E1A;GIA;FEA+"!697)E;FEG9&4@4F5P=6)L:65K('9A;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A
M<F=E=#HB"FUS9W-T<B`B1&]E;#HB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDS,B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`T.0HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@Y"FUS9VED(")487-K<R(*;7-G<W1R
M(")486ME;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3<T"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(E1E;&5F;V]N
M;G5M;65R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3<*;7-G:60@(E1E
M;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(E1E;7!E<F%T=75R('9A;B!H
M970@869G96QO<&5N('5U<CH@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,C$*;7-G:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@(E1E;7!E<F%T=75R(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,@IM<V=I9"`B5&5M
M<&5R871U<F4Z("(*;7-G<W1R(")496UP97)A='5U<CH@(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(X,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM
M<V=S='(@(E1E;7!E<F%T=75R/&)R("\^*"5S2&]O9R5S+R5S3&%A9R5S*2`F
M9W)D.R5S(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HV
M.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F
M;W5N9"XB"FUS9W-T<B`B4VIA8FQO;VX@7"(E<UPB(&YI970@9V5V;VYD96XN
M(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@(E1E;7!L871E
M($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E-J86)L;V]N8F5H965R(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,2!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,S(W"FUS9VED(")497AT(@IM<V=S='(@(E1E:W-T(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.0IM<V=I9"`B5&5X="!/;FQY(@IM
M<V=S='(@(D%L;&5E;B!T96MS="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G:60@(E1E>'0@86QI9VXB
M"FUS9W-T<B`B5&5K<W0@=6ET;&EJ;F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G
M<W1R(")496MS=&)O=F5N:V%N="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(D1O(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.30*;7-G:60@(E1H86D@*%1)4RTV
M,C`I(@IM<V=S='(@(E1H86ES("A425,M-C(P*2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C0*
M;7-G:60@(E1H86EL86YD(@IM<V=S='(@(E1H86EL86YD(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HX-3$*;7-G:60@(E1H92!&5%`@97AT96YS
M:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D1E($944"!E>'1E;G1I
M92!I<R!N:65T(&)E<V-H:6MB86%R+B(*"B,Z(&9R86UE=V]R:R](:7-T;W)Y
M+TAI<W1O<GDN<&AP.C4U"FUS9VED(")4:&4@2&ES=&]R>2!S>7-T96T@:7,@
M9&ES86)L960N(@IM<V=S='(@(DAE="!G97-C:&EE9&5N:7-S>7-T965M(&ES
M('5I=&=E<V-H86ME;&0N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN
M=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G
M<W1R(")$92!(;W)D92]+;VQA8B!I;G1E9W)A=&EE(&]N9&5R<W1E=6YT(%PB
M)7-<(B!N:65T(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O0F]O:RYP
M:'`Z,3(Y.`IM<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET
M:6%L:7IE9"XB"FUS9W-T<B`B2&5T($E-4U`@;&]G(&MO;B!N:65T('=O<F1E
M;B!G96EN:71I86QI<V5E<F0N(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C,Q"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T
M(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(D1E($UA:6YT96YA;F-E.CH@
M8VQA<W,@=V5R9"!N:65T(&=E;&%D96XB"@HC.B!S97)V:6-E<R]I;6%G97,O
M8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@
M:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B2&5T($]P=&EE<W-C:&5R
M;2!I<R!G97-L;W1E;BX@069S;'5I=&5N+B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,3@Y(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C`P
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C$Q(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,C,T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C4R"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,C8T(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,S`S"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T
M;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I
M9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*
M(D1E(&)E:&5E<F1E<B!D:65N="!E96X@<&5R;6%N96YT(')E8VAT96YB86-K
M96YD('1E(&-O;F9I9W5R97)E;B!A;',@=2`B"B)R96-H=&5N('=I;'0@9V5B
M<G5I:V5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T;VT@<VED92!O;FQY(@IM
M<V=S='(@(D%L;&5E;B!D92!O;F1E<FMA;G0B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE
M(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L
M86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G
M<W1R("(B"B)(970@8V]N=&%C="!)1"!N=6UM97(@:7,@;FEE="!O<&=E9V5V
M96XL(&QE96<@9V5L871E;B!O9B!I<R!N:65T(&=E=F]N9&5N(&EN("(*(F1E
M(&1A=&%B87-E+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL
M>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B2&5T(&%D
M<F5S(&ES(&UE="!S=6-C97,@86%N('5W(&%D<F5S8F]E:R!T;V5G979O96=D
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-S(*;7-G
M:60@(B(*(E1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E
M<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@
M(B(*(DAE="!L;W-G96MO<'!E;&1E(%!'4"!O;F1E<G1E:V5N:6YG<V)L;VL@
M:7,@=F5R96ES="!O;2!H970@;VYD97)T96ME;F1E("(*(F)E<FEC:'0@=&4@
M=F5R:69IZW)E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L
M:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O
M<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R("(B"B)(
M970@9&ES=')U8G5T:65L:6IS="!)1"!I<R!N:65T(&]P9V5G979E;BP@;&5E
M9R!G96QA=&5N(&]F(&ES(&YI970@9V5V;VYD96X@(@HB:6X@9&4@9&%T86)A
M<V4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-#(*;7-G:60@(E1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T
M('-P96-I9FEE9"XB"FUS9W-T<B`B1&4@9&ES=')I8G5T:65L:6IS="!I<R!N
M:65T(&]P9V5G979E;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP
M.C$Q-@IM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A
M('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B1&4@8V]D965R;6]G
M96QI:FMH961E;B!V97)E:7-E;B!E96X@8F5V96EL:6=D92!W96)V97)B:6YD
M:6YG+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3@V(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z-3(X"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS
M9W-T<B`B2&5T(&)E<W1A;F0@)7,@9&EE;G0@965N("5S(&EN<W1E;&QI;F<@
M=&4@8F5V871T96XN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M-SD@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S
M971T:6YG<RXB"FUS9W-T<B`B2&5T(&)E<W1A;F0@)7,@9&EE;G0@96YI9V4@
M)7,@:6YS=&5L;&EN9V5N('1E(&)E=F%T=&5N+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C(R-@IM<V=I9"`B5&AE(&9I;&4@8V%N;F]T(&)E
M(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B2&5T(&)E<W1A;F0@:V%N
M(&YI970@;F%A<B!Z:6-H>F5L9B!G96MO<&EE97)D('=O<F1E;BXB"@HC.B!F
M<F%M97=O<FLO1&%T82]$871A+G!H<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O
M;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")(970@8F5S=&%N9"!B979A='1E
M(&=E96X@9&%T82XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A
M9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R
M(")(970@=F]L9V5N9&4@>FEJ;B!D92!K;W!P96X@=F%N(&1I="!M97-S86=E
M+W)F8S@R,B!B97)I8VAT+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C<F5E;B!M
M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@
M17AP;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E
M;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E
M("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS
M(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S
M>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U
M)VQL(&=E="!A("='96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N
M965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L
M96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE
M(&9U;&P@<V-R965N(&5D:71O<BXB"FUS9W-T<B`B(@HB5F%N(&1E('9O;&QE
M9&EG('-C:&5R;2!M;V1E(&ES(&)E:V5N9"P@9&%T(&1I="!P<F]B;&5M96X@
M:V%N('9E<F]O<GIA:V5N(&UE="`B"B));G1E<FYE="!%>'!L;W)E<BP@=F%N
M=V5G92!B<F]W<V5R8G5G<R!W86%R('=I:B!N:65T(&]M:&5E;B!K=6YN96XN
M($AE="!I<R`B"B)M;V=E;&EJ:R!D870@=2!R;VUM96P@:6X@:&5T(&)E96QD
M<V-H97)M+"!G96)R96L@86%N(&5D:71O<F9U;F-T:65S(&5N+V]F("(*(G)A
M;F1O;2!B<F]W<V5R+2!C<F%S:&5S(&5R=F%A<G0N(%=A;FYE97(@=7<@<WES
M=&5E;2!7:6YD;W=S(#EX(&ES+"!I<R!H970@(@HB=V%A<G-C:&EJ;FQI:FL@
M9&%T('4@965N("=!;&=E;65N92!"979E:6QI9VEN9W,@1F]U="<@:W)I:F=T
M+"!E;B!O<&YI975W("(*(F1I96YT('1E(&AE<G-T87)T96XN7%QN7%QN52!B
M96YT(&=E=V%A<G-C:'5W9"X@1')U:R!O<"!/2R!W86YN965R('4@=&]C:"!D
M92`B"B)V;VQL961I9R!S8VAE<FT@961I=&]R('=I;'0@<')O8F5R96XN(@H*
M(SH@<V5R=FEC97,O<')E9G,N<&AP.C$Q,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S
M='(@(D1E(&ED96YT:71E:70@7"(E<UPB(&ES('9E<G=I:F1E<F0N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B06QL
M965N(&1E(&QI;FME<FMA;G0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU
M4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L
M87-S+B(*;7-G<W1R("(B"B)$92!P;&%A=',@=F%N(&AE="!';G501R!P<F]G
M<F%M;6$@9&EE;G0@;W!G96=E=F5N('1E('=O<F1E;B!I;B!D92`B"B)#<GEP
M=%]P9W`Z.B!C;&%S<RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP
M:'`Z,C`R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E('-E
M;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D
M:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M
M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B
M(@HB2&5T(&)E<FEC:'0@=F5R<W1U=7)D(&]P("5S(&%A;B`E<R!M970@;VYD
M97)W97)P(%PB)7-<(B!I<R!W965R9V5G979E;BY<;B(*(D1I="!I<R!G965N
M(&=A<F%N=&EE(&1A="!H970@8F5R:6-H="!I<R!G96QE>F5N(&]F(&)E9W)E
M<&5N+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S<*;7-G:60@
M(E1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@
M<&%G92(*;7-G<W1R(")$92!N86%M(&1I92!G96)R=6EK="!W;W)D="!B:6H@
M;&EN:V5N(&YA87(@9&4@;FEE=7<@8F5R:6-H="!P86=I;F$B"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-S0*;7-G:60@(E1H92!N=6UB97(@
M;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`B2&5T(&%A;G1A
M;"!V96QD96X@9&EE;G0@;G5M97)I96L@=&4@>FEJ;BXB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S(*;7-G:60@(E1H92!O<&5N
M<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M
M:6UE.CH@8VQA<W,N(@IM<V=S='(@(D1E(&]P96YS<VP@;6]D=6QE(&ES('9E
M<F5I<W0@=F]O<B!D92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,CDU"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@
M<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU
M;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"B)$92!V;V]R:V5U<G-I;G-T
M96QL:6YG(%PB)7-<(B!K;VX@;FEE="!W;W)D96X@;W!G97-L86=E;BP@;VUD
M870@9&4@9&%T82!D92`B"B)M87AI;75M('1O96QA871B87)E(&=R;V]T=&4@
M;W9E<G-C:')I:F1T+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O96YS
M8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS
M97AC96PN<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS
M<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W-R
M8VAI9VAL:71E+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]W96)C<'`N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P
M<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N
M;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@HB2&5T('!R;V=R
M86UM82!O;2!D:70@9&%T871Y<&4@*"5S*2!T92!B96MI:FME;BP@=V5R9"!N
M:65T(&]P(&AE="!S>7-T965M("(*(F=E=F]N9&5N+B(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C0X-PIM<V=I9"`B5&AE('%U;W1E(&-H87)A
M8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R(")(
M970@86%N:&%L:6YG<W1E:V5N(&1I96YT(.OK;B!E;FME;"!T96ME;B!T92!Z
M:6IN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O
M;FQY(@IM<V=S='(@(D%L;&5E;B!D92!R96-H=&5R+2!E;B!L:6YK97)K86YT
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW.`IM<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S
M='(@(D%L;&5E;B!D92!R96-H=&5R:V%N="(*"B,Z(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C0W.0IM<V=I9"`B5&AE('-E<&%R871O<B!M=7-T(&)E
M(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R(")(970@<V-H96ED:6YG
M<W1E:V5N(&1I96YT(.OK;B!E;FME;"!T96ME;B!T92!Z:6IN+B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S
M='(@(D1E('-E<G9E<B!<(B5S7"(@:7,@=F5R=VEJ9&5R9"XB"@HC.B!S97)V
M:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B
M1&4@<V5R=F5R(%PB)7-<(B!I<R!O<&=E<VQA9V5N+B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E
M<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N(@IM<V=S='(@(DAE="!A
M86YM96QD:6YG<W9E<GIO96L@=F]O<B`E<R!I<R!V97)W:6ID97)D+B(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-#<P
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S<&5C:69I960@<F]W("@E9"D@
M9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(D1E(&]P9V5G979E;B!R:6H@*"5D
M*2!B97-T86%T(&YI970N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HQ-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE
M(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B2&5T('1I:F1E;&EJ
M:R!B97-T86YD(%PB)7-<(B!B97-T86%T(&YI970N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S,P,@IM<V=I9"`B5&AE('1E>'0@>6]U(&5N=&5R
M960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+B(*;7-G
M<W1R(")$92!I;F=E=F]E<F1E('1E:W-T(&MO;70@;FEE="!O=F5R965N(&UE
M="!D92!T96MS="!O<"!H970@<V-H97)M+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T
M;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@(D%L;&5E;B!D92!B
M;W9E;BT@96X@;VYD97)K86YT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E
M(&]N;'DB"FUS9W-T<B`B06QL965N(&1E(&)O=F5N:V%N="(*"B,Z(&9R86UE
M=V]R:R]$871A+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A
M=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@
M(D1E('5P;&]A9&5D(&1A=&$@:7,@;F$@9&4@=F]O<F=A86YD92!S=&%P('9E
M<FQO<F5N(&=E9V%A;BXB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+V-S=BYP
M:'`Z,C8R(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-S(*;7-G:60@
M(E1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T
M<B`B2&5T('5P;&]A9&5D(&)E<W1A;F0@:7,@;FEE="!O<&=E<VQA9V5N+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT.2!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,3$P"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@
M8FQO8VL@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B2&5T('=E871H97(N
M8V]M(&)L;VL@:7,@;FEE="!B97-C:&EK8F%A<BXB"@HC.B!U=&EL+VEC;VY?
M8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE;65S(&1I
M<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")4:&5M861I<F5C
M=&]R>2!<(B5S7"(@;FEE="!G979O;F1E;BXB"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C$W.`IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO
M;G,@879A:6QA8FQE+B(*;7-G<W1R(")'965N(&]P=&EE<R!B97-C:&EK8F%A
M<BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HS-3`*
M;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y
M960@:6YL:6YE+B(*;7-G<W1R(")%<B!Z:6IN(&=E96X@;VYD97)D96QE;BP@
M=V5L:V4@:6YL:6YE('=E97)G96=E=F5N(&MU;FYE;B!W;W)D96XN(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30P,0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES
M(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[("(*(GEO
M=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@HB17(@>FEJ
M;B!T92!V965L(&MA<F%K=&5R<R!I;B!D:70@=F5L9"X@52!H965F="`E<R!K
M87)A:W1E<G,@;W!G96=E=F5N.R!U("(*(F1I96YT(&UI;F1E<B!D86X@)7,@
M;W`@=&4@9V5V96XN(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U<V5R+G!H
M<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M
M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`B165N
M('!R;V)L965M(&UE="!H970@=&]E=F]E9V5N('9A;B!<(B5S7"(@86%N(&AE
M="!S>7-T965M.B`E<R(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A
M=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@
M(B(*(D5E;B!P<F]B;&5E;2!M970@:&5T('9E<G=I:F1E<F5N('9A;B!D871A
M('9A;B!G96)R=6EK97(@7"(E<UPB('5I="!H970@(@HB<WES=&5E;3H@(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R;VT@=&AE('-Y
M<W1E;3H@(@IM<V=S='(@(D5E;B!P<F]B;&5E;2!M970@:&5T('9E<G=I:F1E
M<F5N('9A;B!<(B5S7"(@=6ET(&AE="!S>7-T965M.B`B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@
M<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z("5S(@IM<V=S='(@(D5E;B!P<F]B
M;&5E;2!M970@:&5T(&)I:G=E<FME;B!V86X@7"(E<UPB.B`E<R(*"B,Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDR-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L
M;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(D5E;B!P<F]B;&5E
M;2!M970@9&4@8F5S=&%N9'-U<&QO860Z($=E96X@)7,@=V5R9"!G975P;&]A
M9"XB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H
M('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@
M;6%X:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B
M(@HB165N('!R;V)L965M(&UE="!D92!B97-T86YD<W5P;&]A9#H@2&5T("5S
M(&ES(&=R;W1E<B!D86X@9&4@;6%X:6UU;2`B"B)T;V5L86%T8F%R92!G<F]O
M='1E("@E9"!B>71E<RDN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E
M<BYP:'`Z.3,T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A
M('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL
M>2!P87)T:6%L;'D@=7!L;V%D960N(@IM<V=S='(@(B(*(D5E;B!P<F]B;&5E
M;2!M970@9&4@8F5S=&%N9'-U<&QO860Z($AE="`E<R!I<R!S;&5C:'1S(&=E
M9&5E;'1E;&EJ:R!G975P;&]A9"XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R(")%96X@
M9F]U="!B:6H@:&5T(&)E:VEJ:V5N('9A;B!D:70@8F5R:6-H=&]N9&5R9&5E
M;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS
M.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A
M8W0@9&%T82XB"FUS9W-T<B`B165N(&9O=70@8FEJ(&AE="!I;7!O<G1E<F5N
M('9A;B!D92!A9')E<V1A=&$N(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]I
M;6,N<&AP.C,Q"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG
M('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`B165N(&9O=70@8FEJ(&AE
M="!I;7!O<G1E<F5N('9A;B!D92!I0V%L96YD87)D871A+B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z.#(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E
M<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L
M969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("(B"B)%96X@
M9F]U="!I;B!H970@8V]N9FEG=7)A=&EE9F]R;75L:65R+B!-:7-S8VAI96X@
M8F5N="!U(&5E;B!V97)P;&EC:'0@=F5L9"`B"B)V97)G971E;BXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM
M<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P
M96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@
M86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(D5E;B!F;W5T(&)I:B!H970@=6ET
M=F]E<F5N('9A;B!D92!O<&=E9V5V96X@861R97-B;V5K9G5N8W1I92X@4')O
M8F5E<B!L871E<B`B"B)O<&YI975W+"!A+G4N8BXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I
M;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(D5E;B!F
M;W5T(&UE="!H970@8FEJ=V5R:V5N('9A;B!D92!A9')E<V1E=&%I;',N(%!R
M;V)E97(@;&%T97(@;W!N:65U=RP@82YU+F(N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C(*;7-G:60@(B(*(E1H97)E
M('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N
M(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(D5E;B!F;W5T
M(&UE="!H970@8FEJ=V5R:V5N('9A;B!D92!D:7-T<FEB=71I96QI:G-T+B!0
M<F]B965R(&QA=&5R(&]P;FEE=7<L(&$N(@HB=2YB+B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T.`IM<V=I9"`B5&AI<R!)
M34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB
M"FUS9W-T<B`B1&5Z92!)34%0('-E<G9E<B!O;F1E<G-T975N="!G965N(&1E
M;&EN9R!V86X@;6%P<&5N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O
M(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(D1I="!L:6IK="!N
M:65T(&5E;B!G96QD:6<@<F%R(&)E<W1A;F0@=&4@>FEJ;BXB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES
M(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G
M<W1R(")$:70@;&EJ:W0@;FEE="!E96X@9V5L9&EG('II<"!B97-T86YD('1E
M('II:FXN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R-PIM<V=I
M9"`B5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB
M97(N(@IM<V=S='(@(D1I="!L:6IK="!N:65T(&5E;B!G96QD:6<@:V%A<G1N
M=6UM97(@=&4@>FEJ;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HQ.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E
M;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@
M=&AE($A45%`@05!)(@IM<V=S='(@(B(*(D1I="!S='5U<G!R;V=R86UM82!G
M965F="!D92!M;V=E;&EJ:VAE:60@;VT@8F5R:6-H=&5N('9I82!D92!#;&EC
M:V%T96QL("(*(BAH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&=A=&5W87D@=&4@
M=F5R>F5N9&5N+"!D+FTN=BX@9&4@2%144"!!4$DB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S-`IM<V=I9"`B(@HB5&AI<R!D
M<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@
M5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE
M($A45%`@05!)(@IM<V=S='(@(B(*(D1I="!S='5U<G!R;V=R86UM82!G965F
M="!D92!M;V=E;&EJ:VAE:60@;VT@8F5R:6-H=&5N('9I82!D92!724X@*&AT
M='`Z+R\B"B)W:6YP;&,N8V]M*2!G871E=V%Y('1E('9E<GIE;F1E;BP@9"YM
M+G8N(&1E($A45%`@05!)(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I
M;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H
M92!(5%10($%022(*;7-G<W1R("(B"B)$:70@<W1U=7)P<F]G<F%M;6$@9V5E
M9G0@9&4@;6]G96QI:FMH96ED(&]M(&)E<FEC:'1E;B!V:6$@9&4@<VUS,F5M
M86EL("(*(BAH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A>2!T92!V97)Z
M96YD96XL(&0N;2YV+B!D92!(5%10($%022(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U"FUS9VED("(B"B)4
M:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU4
M4"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY
M('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C
M8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N
M:70I+B(*;7-G<W1R("(B"B)$:70@<W1U=7)P<F]G<F%M;6$@9V5E9G0@9&4@
M;6]G96QI:FMH96ED(&]M(&)E<FEC:'1E;B!V:6$@4TU44"!D+FTN=BX@9&4@
M(@HB5F]D869O;F4@271A;'D@9V%T97=A>2!T92!V97)Z96YD96X@;F%A<B!6
M;V1A9F]N92!N=6UM97)S+B!(:65R=F]O<B!I<R!E96X@(@HB5F]D869O;F4@
M271A;'D@92UM86EL861R97,@*&AT='`Z+R]W=W<N,3DP+FET*2!N;V]D>F%K
M96QI:FLN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3<X(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$P-3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3`X-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3$U"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#(@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(U-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`U(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S.3@*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,34U-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#,Y"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-3@@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`P-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#(Y
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-S@*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C$T.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C(Q
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,#@@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C0U,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-C,W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3`*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$Q.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,CDW"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,#4@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S@Q,PIM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U
M:7)E9"XB"FUS9W-T<B`B1&ET('9E;&0@:7,@=F5R96ES="(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C4*;7-G:60@(E1H:7,@9FEE;&0@;6%Y
M(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB"FUS9W-T<B`B1&ET('9E;&0@;6%G
M(&%L;&5E;B!I;G1E9V5R<R!B979A='1E;BXB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-#$V"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O
M;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R(")$:70@=F5L
M9"!M86<@86QL965N(&=E=&%L;&5N(&5N(&1E(&1U8F)E;&4@<'5N="!B979A
M='1E;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DT"FUS9VED
M(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*
M;7-G<W1R(")$:70@=F5L9"!M86<@86QL965N(&]C=&%A;"!W86%R9&5N(&)E
M=F%T=&5N+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,C,*;7-G
M:60@(E1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R
M871E9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S='(@(B(*(D1I="!V96QD(&1I
M96YT(&5E;B!K;VUM82!O9B!S<&%T:64@9V5S8VAE:61E;B!L:6IS="!M970@
M:6YT96=E<G,@=&4@>FEJ;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.CDX.0IM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R
M+B(*;7-G<W1R(")$97IE('=A87)D92!D:65N="!E96X@9V5L9&EG(&=E=&%L
M('1E('II:FXN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q.`IM
M<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E
M(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T
M868G+B(*;7-G<W1R("(B"B)$:70@=F5L9"!D:65N="!E96X@:VQE=7)C;V1E
M(&EN(%)'0B!(15@M9F]R;6%A="!T92!B979A='1E;BP@8BYV+B`G(S$R,S1A
M9B<N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z-38Q"FUS9VED(")4
M:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@
M(D1I="!F;W)M=6QI97(@:7,@<F5E9',@=F5R=V5R:W0N(@H*(SH@=&5M<&QA
M=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI
M<R!I<R`E<RXB"FUS9W-T<B`B1&ET(&ES("5S+B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z-#8Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@
M;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H870@
M=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A
M(&QI<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E
M<R(*;7-G<W1R("(B"B)$:70@:7,@965N($MO;&%B($=R;W5P=V%R92!O8FIE
M8W0N($]M(&1I="!O8FIE8W0@=V5E<B!T92!G979E;B!H965F="!U(&5E;B!E
M+2(*(FUA:6P@8VQI96YT(&YO9&EG(&1I92!H970@2V]L86(@1W)O=7!W87)E
M(&9O<FUA870@8F5G<FEJ<'0N(%9O;W(@965N(&QI:G-T("(*(FUE="!D97IE
M(&4M;6%I;&-L:65N=',L(&)E>F]E:R`E<RP@82YU+F(N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DY"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E
M<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R("(B"B)$
M:70@8F5R:6-H="!I<R!I;B!E96X@86YD97)E(&MA<F%K=&5R<V5T("@E<RD@
M9V5S8VAR979E;BP@9&%N('5W(&5I9V5N+B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E
M(&%T(&QE87-T(&]N92XB"FUS9W-T<B`B1&ET(&=E=&%L(&1I96YT('1E;FUI
M;G-T92#IZ6X@=&4@>FEJ;BXB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M
M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N
M8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R(")$97IE('-E
M<G9E<B!K86X@9V5E;B!Z:7`@96X@9WII<"!B97-T86YD96X@=6ET<&%K:V5N
M+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3@Y
M"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N
M(@IM<V=S='(@(DAE="!S>7-T965M(&ES(&UO;65N=&5E;"!U:71G97-C:&%K
M96QD+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(T"FUS
M9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(D1E
M>F4@=V%A<F1E(&1I96YT(&5E;B!G971A;"!T92!Z:6IN+B(*"B,Z('-E<G9I
M8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN
M9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS
M9W-T<B`B1&ET('-C:&5R;2!D:65N="!A86YG97)O97!E;B!T92!W;W)D96X@
M=F%N=6ET(&5E;B!/<'1I97-S8VAE<FTB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV-@IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R
M(")/;G=E97(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,V"FUS
M9VED(")4:6-K971S(@IM<V=S='(@(E1I8VME=',B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-#(U('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(U-0IM<V=I9"`B5&EM92(*;7-G<W1R(")4:6ID(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,X.`IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G
M<W1R(")4:6ID<&QA;FYI;F<B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3<*
M;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(E1I:F1F;W)M86%T(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4S,0IM<V=I9"`B5&EM92!S96QE
M8W1I;VXB"FUS9W-T<B`B5&EJ9'-E;&5C=&EE(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,`IM
M<V=I9"`B5&EM;W(M3&5S=&4B"FUS9W-T<B`B5&EM;W(M3&5S=&4B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]"
M;&]C:R]I9G)A;64N<&AP.C(P"FUS9VED(")4:71L92(*;7-G<W1R(")4:71E
M;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.38*;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B5&ET96P@*'1O
M;VQT:7`I.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R
M,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(D%A;B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-30*;7-G:60@(B(*(E1O
M('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L
M("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N
M(@IM<V=S='(@(B(*(D]M(&UE97)D97)E(&]N9&5R9&5L96X@=&4@<V5L96-T
M97)E;BP@:&]U9"!D92!#;VYT<F]L("A00RD@;V8@0V]M;6%N9"`H36%C*2`B
M"B)T;V5T<R!V87-T('1I:F1E;G,@:VQI:VME;BXB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S`P"FUS9VED(")4;V1A>2(*;7-G<W1R(")6
M86YD86%G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@(DA4
M34P@8G)O;B!O;7-C:&%K96QE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C,*;7-G:60@(E1O
M9V\B"FUS9W-T<B`B5&]G;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C8*;7-G:60@(E1O:V5L
M874B"FUS9W-T<B`B5&]K96QA=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS,#(*;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(DUO<F=E;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,CD*;7-G:60@(E1O;F=A(@IM<V=S='(@(E1O;F=A(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]K;VQA8BYP:'`Z,3`T"FUS9VED(")4
M;V\@;6%N>2!I;G9A;&ED(&QO9VEN<R!D=7)I;F<@=&AE(&QA<W0@;6EN=71E
M<RXB"FUS9W-T<B`B5&4@=F5E;"!O;F=E;&1I9V4@86%N;65L9&EN9V5N(&=E
M9'5R96YD92!D92!A9F=E;&]P96X@;6EN=71E;BXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<W"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*;7-G:60@(E1O
M<"(*;7-G<W1R(")";W9E;FMA;G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A;64@*%]T;W`I
M(@IM<V=S='(@(D)O=F5N<W1E(&9R86UE("A?=&]P*2(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV,PIM<V=I9"`B5')A;G-L871I;VYS(@IM<V=S='(@
M(E9E<G1A;&EN9V5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,@IM<V=I9"`B5')I;FED860@
M86YD(%1O8F%G;R(*;7-G<W1R(")4<FEN:61A9"!E;B!4;V)A9V\B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-SDP"FUS9VED(")4<G5E(&]R(&9A
M;'-E(@IM<V=S='(@(E1R=64@;V8@9F%L<V4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R
M(")$:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C@*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B
M5'5N97-IZR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,S$*;7-G:60@(E1U<FME>2(*;7-G<W1R
M(")4=7)K:6IE(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@
M(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(E1U<FMS("A)4T\M.#@U
M.2TY*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C<*;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G
M<W1R(")4=7)K;65N:7-T86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(P"FUS9VED(")4=7)K
M<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B5'5R:W,@96X@0V%I8V]S
M(&5I;&%N9&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,PIM<V=I9"`B5'5V86QU(@IM<V=S
M='(@(E1U=F%L=2(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-C0*;7-G
M:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R(")4>7`@=7<@:V5U>F4Z
M("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3@*;7-G:60@
M(E4N5BX@:6YD97@Z("(*;7-G<W1R(")5+E8N(&EN9&5X.B`B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*
M;7-G:60@(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E
M<&]R="(*;7-G<W1R(")54DP@=F]O<B!U=R!A9FQE=F5R:6YG<W-T871U<W)A
M<'!O<G0@<V-R:7!T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY-PIM<V=I9"`B55),.B(*;7-G<W1R(")54DPZ(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(S-PIM<V=I9"`B56=A;F1A(@IM<V=S='(@(D]E9V%N9&$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,V"FUS9VED(")5:W)A:6YE(@IM<V=S='(@(D]E:W)A[VYE
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#$Y"FUS9VED(")5
M;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYI970@
M:6X@<W1A870@5D93(&1I<F5C=&]R>2!A86X@=&4@<W!R96ME;BXB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L
M92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@
M=7`N(@IM<V=S='(@(B(*(DYI970@:6X@<W1A870@97AT<F$@9V5B<G5I:V5R
M<VEN9F]R;6%T:64@=&]E('1E('9O96=E;B!B:6H@:6YS8VAR:6IV96XN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS.3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@
M9FEL92!<(B5S7"(N(@IM<V=S='(@(DYI970@:6X@<W1A870@9&4@<F5C:'1E
M;B!V86X@5D93(&)E<W1A;F0@7"(E<UPB('1E('=I:GII9V5N+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,Y,B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S
M='(@(DYI970@:6X@<W1A870@9&4@<F5C:'1E;B!V86X@5D93(&)E<W1A;F0@
M)7,O)7,@=&4@=VEJ>FEG96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HW.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG
M92!T;R`E<RXB"FUS9W-T<B`B3FEE="!I;B!S=&%A="!T92!W:6IZ:6=E;B!N
M86%R("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C,W"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@
M;V8@7"(E<UPB+B(*;7-G<W1R(").:65T(&EN('-T86%T(&)E<W1A;F1S9W)O
M;W1T92!V86X@7"(E<UPB('1E(&-O;G1R;VQE<F5N+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C8Y-2!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C$P,C@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C@U
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S
M:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`B3FEE="!I;B!S=&%A="!B97-T
M86YD<V=R;V]T=&4@=F%N(%PB)7,O)7-<(B!T92!C;VYT<F]L97)E;BXB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z-#,Y"FUS9VED(")5;F%B
M;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+B(*;7-G<W1R(").:65T(&EN
M('-T86%T(&UE="!D92!344P@<V5R=F5R('1E('9E<F)I;F1E;BXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@W,`IM<V=I9"`B56YA8FQE('1O
M(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S='(@(DYI970@:6X@<W1A870@;65T
M(%-33"!T92!V97)B:6YD96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C,R(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(S-PHC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`T(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HR,#D*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C(Q-PIM<V=I9"`B56YA8FQE('1O(&-O<'D@5D93(&9I
M;&4N(@IM<V=S='(@(DYI970@:6X@<W1A870@5D93(&)E<W1A;F0@=&4@:V]P
M:>MR96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-S`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T
M;W)Y(%PB)7-<(BXB"FUS9W-T<B`B3FEE="!I;B!S=&%A="!61E,@9&ER96-T
M;W)Y(%PB)7-<(B!T92!M86ME;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HS-C$@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(U.`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C8T"FUS9VED(")5
M;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYI970@
M:6X@<W1A870@5D93(&1I<F5C=&]R>2!T92!M86ME;BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3(T"FUS9VED(")5;F%B;&4@=&\@8W)E
M871E(%9&4R!F:6QE+B(*;7-G<W1R(").:65T(&EN('-T86%T(%9&4R!B97-T
M86YD('1E(&UA:V5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M,CDP"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93
M(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(DYI970@:6X@<W1A870@5D93(&UA
M<"!<(B5S7"(@=&4@;6%K96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C<R"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F
M:6QE+B(*;7-G<W1R(").:65T(&EN('-T86%T(&5E;B!L965G(%9&4R!B97-T
M86YD('1E(&UA:V5N+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]G>FEP+G!H<#HW.0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M=&%R+G!H<#HW-@IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB
M"FUS9W-T<B`B3FEE="!I;B!S=&%A="!D871A('5I="!T92!P86MK96XN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,#,@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HR,C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y
M+B(*;7-G<W1R(").:65T(&EN('-T86%T(%PB)7-<(B!T92!V97)W:6ID97)E
M;BP@9&4@9&ER96-T;W)Y(&ES(&YI970@;&5E9R(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-S@@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM<V=S
M='(@(DYI970@:6X@<W1A870@7"(E<UPB.B`E<R!T92!V97)W:6ID97)E;BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S@@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C,Q,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C,Y-2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0R
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H
M92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(DYI970@:6X@<W1A
M870@)7,@=&4@=F5R=VEJ9&5R96XL(&1E(&1I<F5C=&]R>2!I<R!N:65T(&QE
M96<B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4V(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-C`*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T
M<B`B3FEE="!I;B!S=&%A="!61E,@9&ER96-T;W)Y(')E8W5R<VEE9B!T92!V
M97)W:6ID97)E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS
M-#0@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,R,@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HS-#,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C,U,@IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*
M;7-G<W1R(").:65T(&EN('-T86%T(%9&4R!D:7)E8W1O<GD@=&4@=F5R=VEJ
M9&5R96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,C`@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T
M<B`B3FEE="!I;B!S=&%A="!61E,@9&ER96-T;W)Y("5S('1E('9E<G=I:F1E
M<F5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C$R"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E
M<UPB+B(*;7-G<W1R(").:65T(&EN('-T86%T(%9&4R!B97-T86YD(%PB)7-<
M(B!T92!V97)W:6ID97)E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HS,3`@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$V-PHC.B!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HQ.#<*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HR.3$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,Y,0HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDY"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R(").:65T(&EN('-T86%T
M(%9&4R!B97-T86YD('1E('9E<G=I:F1E<F5N+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z,C0X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(DYI970@
M:6X@<W1A870@5D93(&UA<"!<(B5S7"(@=&4@=F5R=VEJ9&5R96XN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,#D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+B(*
M;7-G<W1R(").:65T(&EN('-T86%T(%9&4R`E<R!R96-U<G-I968@=&4@=F5R
M=VEJ9&5R96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,S0*
M;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN
M(@IM<V=S='(@(DYI970@:6X@<W1A870@:'5I9&EG92!D:7)E8W1O<GD@=&4@
M8F5P86QE;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8P-`IM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T
M86EL<R(*;7-G<W1R(").:65T(&EN('-T86%T(&-E<G1I9FEC86%T9&5T86EL
M<R!U:70@=&4@9FEL=&5R96XB"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U3
M4"YP:'`Z-#,W(&9R86UE=V]R:R].971?24U34"])35-0+T%U=&@N<&AP.C$R
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F
M:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B3FEE="!I;B!S=&%A="!O;2!D92!D
M969I;FET:64@=F%N("5S('1E(&QA9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C(P,R!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR
M,#@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$W-"!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3<Y"FUS9VED(")5;F%B;&4@
M=&\@;6]V92!61E,@9FEL92XB"FUS9W-T<B`B3FEE="!I;B!S=&%A="!61E,@
M8F5S=&%N9"!T92!V97)P;&%A='-E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.CDX(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z.3,*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ,#8@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HV-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").:65T(&EN('-T86%T
M(%9&4R!B97-T86YD(%PB)7-<(B!T92!O<&5N96XN(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,C@T(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HQ,S@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C$T,0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I
M;F<N(@IM<V=S='(@(DYI970@:6X@<W1A870@5D93(&)E<W1A;F0@=&4@;W!E
M;F5N('9O;W(@<V-H<FEJ=F5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C@S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$S-PHC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S8*;7-G:60@(E5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R(").:65T(&EN('-T86%T(%9&
M4R!B97-T86YD('1E(&]P96YE;BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C0U"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP
M<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@(DYI970@:6X@<W1A870@:&5T(&EN
M9V5P86MT92!B97-T86YD('1E(&]P96YE;BXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z.#4V"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H
M9FEL97-I>F4H*2!F86EL960I+B(*;7-G<W1R(").:65T(&EN('-T86%T(%9&
M4R!B97-T86YD('1E(&QE>F5N("AF:6QE<VEZ92@I(&UI<VQU:W0I+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HX.#<*;7-G:60@(E5N86)L92!T;R!R
M96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@
M(DYI970@:6X@<W1A870@5D93(&)E<W1A;F0@=&4@;&5Z96X@*&=E=$9I;&53
M:7IE*"D@;6ES;'5K="DN(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R
M+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"FUS9VED(")5;F%B;&4@=&\@
M<F5A9"!F:6QE.B`B"FUS9W-T<B`B3FEE="!I;B!S=&%A="!B97-T86YD('1E
M(&QE>F5N.B`B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV-S8*
M;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B3FEE="!I;B!S=&%A="!V9G-R;V]T(&1I<F5C=&]R>2!T92!O
M<&5N96XN(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3`Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z
M(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*;7-G<W1R(").
M:65T(&EN('-T86%T(&]M("5S('1E(&AE<FYO96UE;B!N86%R("5S.B!B97-T
M96UM:6YG<VUA<"!B97-T86%T(&%L(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C,P,0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@
M9&ER96-T;W)Y+B(*;7-G<W1R(").:65T(&EN('-T86%T(%9&4R!D:7)E8W1O
M<GD@=&4@:&5R;F]E;65N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z,S,R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(DYI970@:6X@<W1A870@5D93
M(&1I<F5C=&]R>2`E<R!T92!H97)N;V5M96XN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HS-#@@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR
M-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@
M9FEL92!<(B5S7"(N(@IM<V=S='(@(DYI970@:6X@<W1A870@5D93(&)E<W1A
M;F0@7"(E<UPB('1E(&AE<FYO96UE;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HV,3<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(R
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE("5S+R5S+B(*;7-G<W1R(").:65T(&EN('-T86%T(%9&4R!B97-T86YD
M("5S+R5S('1E(&AE<FYO96UE;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,C$S(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-3(*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,C8@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C(Y,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,S`Y"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE+B(*;7-G<W1R(").:65T(&EN('-T86%T(%9&4R!B97-T86YD('1E(&AE
M<FYO96UE;BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O;6MI<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O
M9G,G+B(*;7-G<W1R(")+86X@)VUK:7-O9G,G(&YI970@=6ET=F]E<F5N+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*
M;7-G:60@(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT
M(@IM<V=S='(@(DYI970@:6X@<W1A870@9&ET(%=O<F0@9&]C=6UE;G0@=&4@
M=F5R=&%L96XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$U-"!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$U-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M(").:65T(&EN('-T86%T(%9&4R!B97-T86YD(%PB)7-<(B!T92!S8VAR:6IV
M96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3@V"FUS9VED
M(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*
M;7-G<W1R(").:65T(&EN('-T86%T(%9&4R!B97-T86YD('1E('-C:')I:G9E
M;B`H8V]P>2@I(&9A:6QE9"DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C@X(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-#8*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$U,0IM<V=I9"`B
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@(DYI970@
M:6X@<W1A870@5D93(&)E<W1A;F1S9&%T82!T92!S8VAR:6IV96XN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C@V,@IM<V=I9"`B56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(*;7-G<W1R
M(").:65T(&EN('-T86%T(%9&4R!B97-T86YD('1E('-C:')I:G9E;BP@<75O
M=&$@=V]R9'0@;W9E<G-C:')E9&5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*;7-G:60@(E5N9&5R;&EN92(*;7-G
M<W1R(")/;F1E<G-T<F5P96XB"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN
M8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B2&5R<W1E;"!W:6IZ
M:6=I;F=E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S
M='(@(D1O970@=7<@;&%A='-T92!B97=E<FMI;F<@=&5N:65T(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(Q"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.`IM<V=I9"`B56YE
M>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B`B
M"FUS9W-T<B`B3VYV97)W86-H="!A;G1W;V]R9"!V86X@9&4@<V5R=F5R(&]P
M('9E<F)I;F1I;F<Z("(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C(Q-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS,SD*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S<V"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,X,@IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E
M<B!T;SH@(@IM<V=S='(@(D]N=F5R=V%C:'0@86YT=V]O<F0@=F%N('-E<G9E
M<B!A86XZ("(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA
M;F%G97(N<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C8Q"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(D]N8F5N;V5M
M9"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS9VED(")5;FEC;V1E
M("A55$8M."DB"FUS9W-T<B`B56YI8V]D92`H551&+3@I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<*;7-G:60@(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(E9E<F5N
M:6=D92!!<F%B:7-C:&4@16UI<F%T96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S@*;7-G:60@
M(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(E9E<F5N:6=D($MO;FEN9VMR:6IK
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(T,`IM<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R
M(")697)E;FEG9&4@4W1A=&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.0IM<V=I9"`B56YI
M=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S='(@(E9E
M<F5N:6=D92!3=&%T96XL(&ML96EN92!B=6ET96X@;&EG9V5N9&4@96EL86YD
M96XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C<X(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HV,@IM<V=I9"`B56YI=',B"FUS9W-T<B`B165N:&5D
M96XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C4X
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R.0HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,S`*;7-G:60@(E5N:VYO=VXB"FUS
M9W-T<B`B3VYB96ME;F0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@
M*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B3VYB96ME;F0@87!I;7-G:60@
M*$%022!-97-S86=E($E$*2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@(E5N:VYO=VX@8VQI;7-G
M:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T<B`B3VYB96ME;F0@8VQI
M;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,30W"FUS9VED(")5;FMN;W=N(&QO8V%T:6]N('!R
M;W9I9&5D+B(*;7-G<W1R(")/;F)E:V5N9&4@;&]C871I92!O<&=E9V5V96XN
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+B(*
M;7-G<W1R(")/;F)E:V5N9&4@9V5B<G5I:V5R<VYA86T@;V8@=V%C:'1W;V]R
M9"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-3@*;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT
M(@IM<V=S='(@(DAE="!H=6ED:6=E(&5L96UE;G0@;&]S:V]P<&5L96XB"@HC
M.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,P,@IM<V=I9"`B
M56YN86UE9"(*;7-G<W1R(")/;F)E;F]E;60B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I
M;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R
M;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K
M($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H
M:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C
M97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*(DYI970@9V5R96-H=&EG
M9&4@<V-R:7!T<R!K=6YN96X@<')O9W)A;6UA;6%T:6<@;FEE="!+;FEP<&5N
M+TMO<&GK<F5N+R(*(E!L86MK96XL('9A;G=E9V4@8F5V96EL:6=I;F=S<F5D
M96YE;BX@2VQI:R!O<"!/2R!O;2!E96X@=&5C:&YI<V-H92!O<&UE<FMI;F<@
M(@HB;W`@;6]Z:6QL82YO<F<@=&4@8F5K:6IK96X@:&]E('4@965N('-C<FEP
M="!T;V5S=&%A="!H970@<')I:V)O<F0@=&4@(@HB8F5N861E<F5N+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@(DML975R('1E<G5G<W1E
M;&QE;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@W
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3(W"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3,S"FUS9VED(")5;G-U<'!O
M<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`B3FEE="!O;F1E<G-T975N9&4@97AT
M96YT:64B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$Y-R!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D871E
M(@IM<V=S='(@(D)I:G=E<FME;B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E("5S
M(@IM<V=S='(@(B5S(&)I:G=E<FME;B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z-S8*;7-G:60@(E5P9&%T92!U<V5R(@IM<V=S='(@
M(D=E8G)U:6ME<B!B:6IW97)K96XN(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ
M-#0@861M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E
M9&ET+G!H<#HR,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S
M7"(N(@IM<V=S='(@(EPB)7-<(B!B:6IG97=E<FMT+B(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C@S"FUS9VED(")5<&=R861E('-C<FEP="!D96QE
M=&5D+B(*;7-G<W1R(")5<&=R861E('-C<FEP="!V97)W:6ID97)D+B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S@@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$Y.`IM<V=I9"`B57!L;V%D(@IM<V=S='(@
M(E5P;&]A9"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#8*;7-G:60@
M(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@
M<V5R=F5R+B(*;7-G<W1R(")!;&QE('1O97!A<W-I;F<@<V5T=7!B97-T86YD
M96X@;F%A<B!D92!S97)V97(@9V5U<&QO860N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B
M57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("),871I:FYS92!H;V]F9&QE
M='1E<G,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM
M<V=S='(@(D=R;W1E(%)O;65I;G-E(&=E=&%L;&5N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M,0IM<V=I9"`B57)U9W5A>2(*;7-G<W1R(")5<G5G=6%Y(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(D=E8G)U
M:6L@:'5I9&EG93H@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R(")'
M96)R=6EK(%-33"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C<*;7-G
M:60@(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U3
M4"!S97)V97(N(@IM<V=S='(@(D=E8G)U:6ME;B!W86YN965R(&YA86TO=V%C
M:'1W;V]R9"!V97)S8VAI;'0@;65T($E-4U`@<V5R=F5R+B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$*;7-G:60@(E5S97(B"FUS
M9W-T<B`B1V5B<G5I:V5R(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E
M9VES=')Y+G!H<#HW-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I
M<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(D=E8G)U:6ME<B`E
M<R!I<R!N:65T(&=E875T;W)I<V5E<F0@=F]O<B`E<RXB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HR,#,*;7-G:60@(E5S97(@061M:6YI<W1R871I;VXB"FUS9W-T
M<B`B1V5B<G5I:V5R<V)E:&5E<B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z,C0U"FUS9VED(")5<V5R($]P=&EO;G,B"FUS9W-T<B`B1V5B
M<G5I:V5R<V]P=&EE<R(*"B,Z('-I9VYU<"YP:'`Z-C(*;7-G:60@(E5S97(@
M4F5G:7-T<F%T:6]N(@IM<V=S='(@(D=E8G)U:6ME<G-R96=I<W1R871I92(*
M"B,Z('-I9VYU<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA
M<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(D=E8G)U
M:6ME<G-R96=I<W1R871I92!I<R!U:71G97-C:&%K96QD(&]P(&1E>F4@<VET
M92XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#DT"FUS9VED(")5<V5R
M(&%C8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@(D=E8G)U:6ME<G-A8V-O=6YT
M(&YI970@9V5V;VYD96XN(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$W.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.3@*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3`@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z,S,*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW
M,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B
M57-E<FYA;64B"FUS9W-T<B`B1V5B<G5I:V5R<VYA86TB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G
M:60@(E5S97)N86UE(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B
M1V5B<G5I:V5R<VYA86T@7"(E<UPB(&)E<W1A870@86PN(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@W"FUS9VED(")5<V5R;F%M93HB"FUS
M9W-T<B`B1V5B<G5I:V5R<VYA86TZ(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO
M8FEL92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R(")'96)R=6EK
M97)S;F%A;3H@(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`B1V5B<G5I
M:V5R<R!I;B!H970@<WES=&5E;3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R"FUS9VED(")5
M>F)E:VES=&%N(@IM<V=S='(@(D]E>F)E:VES=&%N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,3<P(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(V,@IM<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB
M"FUS9W-T<B`B5D93(&1I<F5C=&]R>2!B97-T86%T(&YI970N(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$R,`IM<V=I9"`B5F%C871I;VXB"FUS
M9W-T<B`B069W97II9VAE:60B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HX-C8*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B
M"FUS9W-T<B`B1V5V;VYD96X@9V5L9&EG92!L;V-A=&EE<R!B979A='1E;CH@
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G
M:60@(E9A;&ED:71Y(@IM<V=S='(@(D=E;&1I9VAE:60B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.3<*;7-G
M:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(E=A87)D
M92!I;B!M:6YU=&5N('9A;F%F(&YU+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@U-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3<W"B,L('!H
M<"UF;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N
M9W1H(&]F("5S+B(*;7-G<W1R(")786%R9&4@;&EG="!B;W9E;B!D92!M87AI
M;75M(&QE;F=T92!V86X@)7,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(T-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8V"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(S,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,CDQ,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N
M<&AP.C4Y"FUS9VED(")686QU97,B"FUS9W-T<B`B5V%A<F1E;B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#D@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C$X-@IM<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S
M='(@(E=A87)D96X@=V%A<G5I="!G97-E;&5C=&5E<F0@:V%N('=O<F1E;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#D*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B5F%N=6%T
M=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S,*;7-G:60@
M(E9A<FEA8FQE(@IM<V=S='(@(E9A<FEA8F5L92(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#4*
M;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R(")696YE>G5E;&$B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I
M8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A
M;7!E<F5D('=I=&@N(@IM<V=S='(@(E9E<FEF:6-A=&EE(&UI<VQU:W0@+2!E
M<B!K86X@;65T(&1I="!B97)I8VAT(&=E:VYO96ED('II:FXN(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#$*;7-G:60@(E9E<G-I
M;VXB"FUS9W-T<B`B5F5R<VEE(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(R.`IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(E9E<G-I
M96-O;G1R;VQE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI9VXB"FUS9W-T
M<B`B5F5R=&EK86%L('5I=&QI:FYE;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I
M;F<B"FUS9W-T<B`B5F5R=&EK86QE('9R:6IE(')U:6UT92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*;7-G:60@(E9E
M<G1I8V%L.B(*;7-G<W1R(")697)T:6MA86PZ(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S(*;7-G:60@(E9E<GD@2&EG:"(*
M;7-G<W1R(")%<F<@:&]O9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#@*;7-G:60@(E9I970@
M3F%M(@IM<V=S='(@(E9I971N86TB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$Y-PIM<V=I9"`B5FEE=&YA;65S92`H5DE30TE)*2(*;7-G<W1R(")6:65T
M;F%M965S("A625-#24DI(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT
M96YT<RYP:'`Z.3<Q"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS
M9W-T<B`B)7,@8F5K:6IK96XB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS
M"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S='(@(D)E
M:VEJ:R!E96X@97AT97)N92!W96)P86=I;F$B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HX,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5FEE=R!A<R`E<R(*;7-G<W1R(")"96MI:FME;B!A;',@)7,B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0V"FUS9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R
M(")-86%G9&5N(&5I;&%N9&5N+"!"<FET<V4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0W"FUS
M9VED(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R(")-86%G9&5N(&5I
M;&%N9&5N+"!6+E,N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,38*;7-G
M:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B6FEC:'0B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C4R"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS
M9W-T<B`B6FEC:'0Z("(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A
M9F]N96ET86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L>2!V
M:6$@4TU44"(*;7-G<W1R(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*"B,Z
M(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+VUO8FEL92YP:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T<B`B5T%23B(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G
M:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S
M+B(*;7-G<W1R(")704%24T-(55=)3D<A(2$@(%9%4E=)2D1%4B!30U))4%0@
M2$%.1$U!5$E'(%5)5"`E<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C$S,PIM<V=I9"`B5TE.('9I82!(5%10(@IM<V=S='(@
M(E=)3B!V:6$@2%144"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3`*;7-G:60@(E=A;&QI<R!A
M;F0@1G5T=6YA(@IM<V=S='(@(E=A;&QI<R!E;B!&=71U;F$B"@HC.B!F<F%M
M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T
M=7,N<&AP.C(Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN
M<&AP.C$R-R!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.34*;7-G:60@(E=A<FYI
M;F<B"FUS9W-T<B`B5V%A<G-C:'5W:6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B
M5V\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@
M(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`B5V5E<G-V;V]R=6ET>FEC:'0B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#$V"FUS9VED(")7
M96%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS9W-T<B`B5V5E<F)E<FEC:'0@
M9V5G979E;G,@9V5L979E<F0@9&]O<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@Y,@IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B5V5A=&AE
M<BYC;VTB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B
M(@IM<V=S='(@(E=E8B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M,SD*;7-G:60@(E=E8B!3:71E(@IM<V=S='(@(E=E8G-I=&4B"@HC.B!F<F%M
M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4X"FUS9VED(")7
M965K;'DB"FUS9W-T<B`B5V5K96QI:FMS(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+VUO8FEL92YP:'`Z,C@*;7-G:60@(E=E;&-O;64B"FUS9W-T<B`B5V5L:V]M
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU-R!T96UP;&%T97,O
M;&]G:6XO;6]B:6QE+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O
M;64@=&\@)7,B"FUS9W-T<B`B5V5L:V]M(&)I:B`E<R(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T86PO;65N=2YI
M;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE+"`E<R(*;7-G<W1R
M(")796QK;VTL("5S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3@*;7-G
M:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$I(@IM<V=S='(@(E=E<W1E<G,@*$E3
M3RTX.#4Y+3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3D*;7-G:60@
M(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R(")797-T97)S("A)4T\M
M.#@U.2TQ-2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW.`IM<V=I9"`B5V5S=&5R;B!386AA<F$B
M"FUS9W-T<B`B5V5S=&5L:6IK92!386AA<F$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#0Q"B,L('!H<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC
M871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@
M(E=E;&ME('1O97!A<W-I;F<@9&EE;G0@)7,@=V5E<B!T92!G979E;B!N82!A
M86YM96QD:6YG/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T
M"FUS9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G
M<W1R(")7870@:7,@:&5T('-C:&5I9&EN9W-K87)A:W1E<C\B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@
M<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R(")7870@:7,@:&5T(&-I=&%A=&MA
M<F%K=&5R/R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,#8U"FUS9VED(")7:&5R96ES($%U<W1R86QI82!M87`B"FUS9W-T
M<B`B5VAE<F5I<R!!=7-T<F%L:>L@:V%A<G0B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E<R(*;7-G<W1R(")796QK92!F
M87-E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S8*;7-G:60@(E=H
M:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O
M<BXB"FUS9W-T<B`B5V5L:V4@<&QU9VEN<R!V;V]R(&1E(%)I8V@@5&5X="!E
M9&ET;W(@:6YS8VAA:V5L96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T
M<B`B0G)E961T92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,#<*
M;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G<W1R(")"<F5E9'1E(&EN
M($-34R!E96YH961E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@
M=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S
M='(@(B(*(D)R965D=&4@=F%N(&AE="`E<R!M96YU(&%A;B!D92!L:6YK97)K
M86YT("AA:W1I968@8FEJ('9O;&=E;F1E(&%A;FUE;&1I;F<I.B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED
M(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`B0G)E961T92!V86X@9&4@
M=&%B96PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q,`IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R(")"<F5E9'1E(&5E
M;FAE:60B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P-0IM<V=I9"`B5VED=&@Z(@IM<V=S='(@(D)R965D=&4Z(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4Q-0IM<V=I9"`B5VEK:2(*;7-G
M<W1R(")7:6MI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X
M.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I
M9"`B5VEN9"(*;7-G<W1R(")7:6YD(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C@*;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T
M<B`B5VEN9"!V<F]E9R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#<*;7-G
M:60@(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T<B`B5VEN9'-N96QH96ED
M(&EN(&MN;W!E;B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,38S"FUS9VED
M(")7:6YD.B(*;7-G<W1R(")7:6YD.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,S$*;7-G:60@(E=I;F0Z("(*;7-G<W1R(")7:6YD.B`B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@(E=I<V1O;2(*
M;7-G<W1R(")7:6IS:&5I9"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ.3@*;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@(E=E;G-L:6IS="(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R
M(")797)K(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$R-`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`B5V5R:V%D<F5S
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y
M,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R(")496PN;G(N("AW97)K*2(*
M"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$Y,R!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HR.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O
M;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@
M9F]U;F0@)60N(@IM<V=S='(@(E9E<FME97)D(&%A;G1A;"!V96QD96X@:6X@
M<F5G96P@)60N(%9E<G=A8VAT("5D+"!G979O;F1E;B`E9"XB"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD
M("5D+B(*;7-G<W1R(")697)K965R9"!A86YT86P@=F5L9&5N+B!697)W86-H
M="`E9"P@9V5V;VYD96X@)60N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,3(Q"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&]F9G-E="`E
M9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@(E9E<FME97)D
M92!O9F9S970@)60@8FEJ(&QE>F5N('9A;B!61E,@8F5S=&%N9"XB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C0U"FUS9VED(")8+5)E9B(*;7-G
M<W1R(")8+5)E9B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3DT"FUS9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T
M<B`B6#4P.78S(&)A<VES8F5P97)K:6YG96XB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S($5X=&5N9&5D
M($ME>2!5<V%G92(*;7-G<W1R(")8-3`Y=C,@=6ET9V5B<F5I9"!S;&5U=&5L
M9V5B<G5I:R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM
M<V=S='(@(E@U,#EV,R!A;'1E<FYA=&EE=F4@;VYD97)W97)P;F%A;2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")8
M-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R(")8-3`Y=C,@
M;VYD97)W97)P('-L975T96QI9&5N=&EF:6-A=&]R(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#,*;7-G:60@(E@U,#EV,R!E>'1E
M;G-I;VYS(@IM<V=S='(@(E@U,#EV,R!E>'1E;G1I97,B"@HC.B!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M.`HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T<B`B2DHB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$T"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-38*;7-G:60@(EE9
M65DB"FUS9W-T<B`B2DI*2B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,3$Q"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@
M(EEA:&]O(2!M87`B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E
M;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T<B`B2F%A<FQI:FMS
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U,@IM<V=I9"`B665M96XB"FUS9W-T<B`B2F5M96XB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38V
M"FUS9VED(")997,B"FUS9W-T<B`B2F$B"@HC.B!T96UP;&%T97,O;6%I;G1E
M;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E
M(@IM<V=S='(@(DIA+"!I:R!A8V-E<'1E97(@9&4@=F]O<G=A87)D96XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R"FUS
M9VED(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T
M;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`B(@HB52!B
M96YT(&EN(%1%2U-4($U/1$4N($=E8G)U:6L@9&4@6SP^72!K;F]P(&]M(&YA
M87(@5UE325=91R!T97)U9R!T92`B"B)S8VAA:V5L96XN(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HR,S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@
M;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`B2&5T(&ES('4@;FEE="!T
M;V5G97-T86%N(&]M(&UE97(@9&%N("5D(&)L;VMK96X@=&4@;6%K96XN(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#(T"FUS9VED(")9;W4@
M87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R(")5(&)E;G0@;FEE="!G
M96%U=&AE;G1I9FEC965R9"XB"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E
M;G1I='DN<&AP.C,P.`IM<V=I9"`B66]U(&-A;FYO="!H879E('1H92`G7%PG
M(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`B52!K=6YT
M(&=E96X@)UQ<)R!K87)A:W1E<B!I;B!U=R!V;VQL96=E(&YA86T@:&5B8F5N
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-34@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3DW-0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@
M82!V86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R(")5(&AE969T(&=E96X@
M9V5L9&EG(&4M;6%I;&%D<F5S(&]P9V5G979E;BXB"@HC.B!F<F%M97=O<FLO
M1&%T82]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U
M(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE
M('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T
M<B`B(@HB52!H965F="!G965N('9E;&1E;B!U:70@:&5T(&=E:6UP;W)T965R
M9&4@8F5S=&%N9"!G96MO<'!E;&0@;65T(&1E("(*(F]V97)E96YK;VUS=&EG
M92!V96QD96X@:6X@)7,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M.3@W"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@
M(E4@8F5N="!A9F=E;65L9"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C8Q"FUS9VED("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E
M;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@
M)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"XB
M"FUS9W-T<B`B(@HB52!D:65N="!E96X@9V5L9&EG(&UO8FEE;"!N=6UM97(@
M:6X@=&4@=F]E<F5N+"!A;&QE96X@8VEJ9F5R<R!M970@965N("(*(F]P=&EO
M;F5L92`G*R<@=F]O<B!H970@:6YT97)N871I;VYA;&4@:VEE<W9O;W)V;V5G
M<V5L+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#@*;7-G:60@
M(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(E4@
M9&EE;G0@965N(&=E;&1I9V4@=V%A<F1E(&]P('1E(&=E=F5N+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU
M<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P
M<RXB"FUS9W-T<B`B(@HB52!D:65N="!E96X@1&%T851R964@8F%C:V5N9"!T
M92!C;VYF:6=U<F5R96X@;VT@:6YS8VAR:6IV:6YG96X@=&4@:W5N;F5N("(*
M(F=E8G)U:6ME;BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0W
M,0IM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM
M<V=S='(@(E4@9&EE;G0@965N(%9&4R!B86-K96YD('1E(&-O;F9I9W5R97)E
M;BXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I
M9"`B66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C
M86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@(B(*(E4@9&EE
M;G0@:&5T('!R;V)L965M('1E(&)E<V-H<FEJ=F5N+"!V;V]R9&%T('4@:&5T
M('!R;V)L965M<F%P<&]R="!K=6YT("(*(G9E<GIE;F1E;BXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9
M;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@
M=&\B"FUS9W-T<B`B52!D:65N="!E96X@55),(&EN('1E('9O97)E;B!W86%R
M;F%A<B!D97IE(&QI;FL@=F5R=VEJ<W0B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<G!C<W5M+G!H<#HX,`IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E
M<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R(")5(&1I96YT(&5E;B!S97)V97(@
M=&4@<V5L96-T97)E;B!O;2!T92!V97)W:6ID97)E;BXB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ,3D*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M
M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@(E4@9&EE;G0@965N(&=E8G)U:6ME
M<G-N86%M(&]P('1E(&=E=F5N(&]M('1E('=I<W-E;BXB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M
M92!T;R!R96UO=F4N(@IM<V=S='(@(E4@9&EE;G0@965N(&=E8G)U:6ME<G-N
M86%M(&]P('1E(&=E=F5N(&]M('1E('9E<G=I:F1E<F5N+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C8R('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D
M+B(*;7-G<W1R(")5(&1I96YT(&5E;B!G96)R=6EK97)S;F%A;2!O<"!T92!G
M979E;B!O;2!T;V4@=&4@=F]E9V5N+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T
M-@IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D
M871E+B(*;7-G<W1R(")5(&1I96YT(&5E;B!G96)R=6EK97)S;F%A;2!O<"!T
M92!G979E;B!O;2!B:6H@=&4@:W5N;F5N('=E<FME;BXB"@HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S@*;7-G:60@(EEO=2!M
M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B
M52!D:65N="!E96X@8F5W97)K:6YG(&]P('1E(&=E=F5N('=E;&ME('5I=&=E
M=F]E<F0@;6]E="!W;W)D96XN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*;7-G:60@(EEO=2!M=7-T('1Y<&4@
M82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T<B`B52!D:65N="!E96X@;FEE
M=7=E(&-A=&5G;W)I96YA86T@;W`@=&4@9V5V96XN(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@
M(EEO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(B
M"FUS9W-T<B`B52!D:65N="!E96X@271A;&EA86YS('1E;&5F;V]N;G5M;65R
M(&]P('1E(&=E=F5N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<U
M"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP
M:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R(")5=R`E<R!S97-S
M:64@:7,@=F5R;&]P96XN($]P;FEE=7<@86%N;65L9&5N+"!A+G4N8BXB"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS.`IM<V=I9"`B66]U
M<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(E5W(&4M;6%I;&%D<F5S(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q-0IM<V=I9"`B66]U<B!&<F]M.B!A
M9&1R97-S.B(*;7-G<W1R(")5=R!686XZ(&%D<F5S.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S<@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,@IM<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R(")5=R!I;F9O
M<FUA=&EE(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<Y"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H87,@
M8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO
M;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I
M;B!A9V%I;BXB"FUS9W-T<B`B(@HB57<@:6YT97)N971A9')E<R!I<R!G97=I
M:GII9V0@<VEN9',@:&5T(&)E9VEN('9A;B!U=R`E<R!S97-S:64N($]M('5W
M("(*(G9E:6QI9VAE:60@=&4@8F5S8VAE<FUE;BP@9&EE;G0@=2!Z:6-H(&]P
M;FEE=7<@86%N('1E(&UE;&1E;BXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHS,PIM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@(E5W(&YA
M86TZ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C4*;7-G
M:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S
M=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@(@HB=7-E($AO
M<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E
M(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N(&)A8VME;F0N(@IM<V=S
M='(@(B(*(DAE="!T;V5V;V5G96X@=F%N(&=E8G)U:6ME<G,@=V]R9'0@;FEE
M="!O;F1E<G-T975N9"!D;V]R('5W(&%U=&AE;G1I8V%T:64@(@HB8F%C:V5N
M9"X@5V%N;F5E<B!U($AO<F1E(&=E8G)U:6ME<G,@=VEL="!B96AE<F5N+"!D
M:65N="!U(&5E;B!A;F1E<B`B"B)A=71H96YT:6-A=&EE(&)A8VME;F0@=&4@
M9V5B<G5I:V5N+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI
M;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O
M97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@
M(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*
M;7-G<W1R("(B"B)(970@=V5E<F=E=F5N('9A;B!E96X@9V5B<G5I:V5R<VQI
M:G-T('=O<F1T(&YI970@;VYD97)S=&5U;F0@9&]O<B!U=R`B"B)A=71H96YT
M:6-A=&EE(&)A8VME;F0L(&]F(&1E>F4@;W!T:64@:7,@;VT@86YD97)E(')E
M9&5N96X@=6ET9V5S8VAA:V5L9"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HY.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R
M(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@
M;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I
M='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B)5=R!B<F]W
M<V5R(&QI:FMT('1E('II:FX@9V5W:6IZ:6=D('-I;F1S(&AE="!B96=I;B!V
M86X@=7<@)7,@<V5S<VEE+B!/;2!U=R`B"B)V96EL:6=H96ED('1E(&)E<V-H
M97)M96XL(&1I96YT('4@>FEC:"!O<&YI975W(&%A;B!T92!M96QD96XN(@H*
M(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3<*;7-G:60@(EEO=7(@8G)O=W-E
M<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`B57<@
M8G)O=W-E<B!O;F1E<G-T975N="!D97IE(&UO9V5L:6IK:&5I9"!N:65T+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"FUS9VED("(B
M"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P
M=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN="XB
M"FUS9W-T<B`B(@HB57<@8G)O=W-E<B!O;F1E<G-T975N="!D97IE('!R:6YT
M;W!T:64@;FEE="X@1')U:R!O<"!#;VYT<F]L+T-O;6UA;F0@*R!0(&]M("(*
M(F%F('1E(&1R=6MK96XN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V
M,0IM<V=I9"`B66]U<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`B57<@
M:'5I9&EG92!T:6ID>F]N93HB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,3$W
M"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E
M9"XB"FUS9W-T<B`B57<@<W1A;F1A87)D(&ED96YT:71E:70@:7,@9V5W:6IZ
M:6=D+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-C$*;7-G:60@(EEO
M=7(@9&5F875L="!I9&5N=&ET>3HB"FUS9W-T<B`B57<@<W1A;F1A87)D(&ED
M96YT:71E:70Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P-`IM<V=I
M9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@(E5W('9O;&QE9&EG92!N86%M
M.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY.0IM<V=I9"`B66]U
M<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T<B`B57<@86%N;65L9&EN9R!I
M<R!V97)L;W!E;BXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@
M)7,@:7,Z("5S(@IM<V=S='(@(E5W(&YI975W92!W86-H='=O;W)D('9O;W(@
M)7,@:7,Z("5S(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ
M-30*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@
M=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`B57<@;W!T
M:65S('II:FX@8FEJ9V5W97)K="!V;V]R(&1E(&1U=7(@=F%N(&1E>F4@<V5S
M<VEE+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34V"FUS
M9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S='(@
M(E5W(&]P=&EE<R!Z:6IN(&)I:F=E=V5R:W0N(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E
M96X@<F5S970B"FUS9W-T<B`B57<@=V%C:'1W;V]R9"!I<R!G97)E<V5T(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*(EEO
M=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@
M86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G<W1R
M("(B"B)5=R!W86-H='=O;W)D(&ES('9E<FYI975W9"P@8V]N=')O;&5E<B!U
M=R!E+6UA:6P@96X@;65L9"!A86X@;65T('5W(&YI975W92`B"B)W86-H='=O
M;W)D+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<S,PIM<V=I9"`B
M66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"XB"FUS9W-T<B`B57<@=V%C:'1W
M;V]R9"!I<R!V97)L;W!E;BXB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z-3@*;7-G:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@
M(E5W('-E<G9E<G,@;W`@869S=&%N9#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4T
M"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S='(@(DIO96=O<VQA=FGK(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I<F4B
M"FUS9W-T<B`B6F'O<F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4V"FUS9VED("):86UB:6$B
M"FUS9W-T<B`B6F%M8FEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-PIM<V=I9"`B6FEM8F%B
M=V4B"FUS9W-T<B`B6FEM8F%B=V4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C8*;7-G:60@(EII<'!Y(@IM<V=S='(@(EII<'!Y(@H*(SH@9G)A;65W
M;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W
M-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM
M<V=I9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(EM697)B97)G(&%A
M;F=E:&%A;&1E('1E:W-T72(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C@Y
M"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM<V=S='(@(EM0<F]B;&5E;7)A
M<'!O<G1=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N
M:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS9W-T<B`B6T%A
M;F=E:&%A;&1E('1E:W-T('=E97)G979E;B`M(@H*(SH@9G)A;65W;W)K+U1E
M>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S
M72(*;7-G<W1R(");06%N9V5H86%L9&4@=&5K<W0@+2`E<R!R96=E;'-=(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HR,#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(EMR96=E;"`E<R!V
M86X@)7-=(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-34T('1E
M;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES=')A
M=&EO;B(*;7-G<W1R(")"7V5H965R(@H*(SH@;&EB+V%P:2YP:'`Z,34W"FUS
M9VED(")?0TQ)(@IM<V=S='(@(E]#3$DB"@HC.B!L:6(O87!I+G!H<#HQ-#$*
M;7-G:60@(E]$871A5')E92(*;7-G<W1R(")?1&%T851R964B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*
M;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(E9E<E]W:6ID97(@<FEJ(@H*
M(SH@;&EB+V%P:2YP:'`Z,3,S"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(E]'
M<F]E<&5N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W
M-0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`B7TAE;'`B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@
M(E]);6%G92!0<F]P97)T:65S+BXN(@IM<V=S='(@(E]!9F)E96QD:6YG<V5I
M9V5N<V-H87!P96XN+BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N
M=2YP:'`Z,3DT"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(E]!86YM96QD96XB
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DP"FUS9VED
M(")?3&]G(&]U="(*;7-G<W1R(")?069M96QD96XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G:60@
M(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R(")?5VEJ>FEG(&QI;FLN+BXB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38T"FUS9VED(")?
M3W!T:6]N<R(*;7-G<W1R(")?3W!T:65S(@H*(SH@;&EB+V%P:2YP:'`Z,3,W
M"FUS9VED(")?4&5R;6ES<VEO;G,B"FUS9W-T<B`B7U)E8VAT96XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C8*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R(")?5F5R=VEJ9&5R
M(&QI;FLN+BXB"@HC.B!L:6(O87!I+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*
M;7-G<W1R(")?26YS=&5L;&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED(")?5&%B;&4@4')O
M<&5R=&EE<RXN+B(*;7-G<W1R(")?5&%B96QE:6=E;G-C:&%P<&5N+BXN(@H*
M(SH@;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?57-E<G,B"FUS9W-T<B`B1V5?
M8G)U:6ME<G,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR-0IM
M<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(D%D<F5S8F]E:R(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,T"FUS9VED(")A9&1R
M97-S964@=6YK;F]W;B(*;7-G<W1R(")'96%D<F5S<V5E<F1E(&]N8F5K96YD
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3<*;7-G:60@(F-A
M;&5N9&%R(@IM<V=S='(@(DMA;&5N9&5R(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ-SD@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C4*;7-G:60@(F-A;&TB
M"FUS9W-T<B`B2V%L;2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,34X"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM
M<V=S='(@(DMA;B!O=71P=71B97-T86YD(&YI970@;6%K96XB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T
M(&]P96X@:6YP=70B"FUS9W-T<B`B2V%N(&EN<'5T(&YI970@;W!E;F5N(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-C`P"FUS9VED
M(")C;&EC:R!H97)E(@IM<V=S='(@(DML:6L@:&EE<B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI
M;F4@=7-A9V4@97)R;W(B"FUS9W-T<B`B0V]M;6%N9&]R96=E;"!G96)R=6EK
M<V9O=70B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W
M.`IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R(")#;VYF:6=U
M<F%T:65F;W5T(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-30*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS
M9W-T<B`B2W)I=&ES8V@@<WES=&5E;6)E<W1A;F0@;VYT8G)E96MT(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C8*;7-G:60@(F1A
M=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(D1A=&%F;W)M86%T9F]U="(*"B,Z
M('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,S`*;7-G:60@(F5D:70B"FUS
M9W-T<B`B8F5W97)K96XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$X,@IM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S='(@(FEN
M=F]E<B!N:65T(&=E=F]N9&5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-S,*;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B9&%L
M96YD(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#DX"FUS
M9VED(")F:6QE(@IM<V=S='(@(F)E<W1A;F0B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$X,2!L:6(O0FQO8VLO;65T87(N<&AP.C,V-R!L:6(O0FQO8VLO
M;65T87(N<&AP.C,Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E
M<R`H)7,I(&%T("5S("5S(@IM<V=S='(@(G9A;B!D92`E<R`H)7,I(&]P("5S
M("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S.0IM<V=I
M9"`B9W5S=&EN9R(*;7-G<W1R(")V;&%G97)I9R(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR-3`*;7-G:60@(F@Z(@IM<V=S
M='(@(F@Z(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C,U.0IM<V=I9"`B:&@B"FUS9W-T<B`B:&@B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE('5N
M:VYO=VXB"FUS9W-T<B`B:&]S=&YA86T@;VYB96ME;F0B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*;7-G
M:60@(FEM;65D:6%T92(*;7-G<W1R(")O;FUI9&1E;&EJ:R(*"B,Z(&%D;6EN
M+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS
M9VED(")I;FQI;F4B"FUS9W-T<B`B:6YL:6YE(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U='!U="!E
M<G)O<B(*;7-G<W1R(")I;G!U="]O=71P=70@9F]U="(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S
M;V9T=V%R92!E<G)O<B(*;7-G<W1R(")I;G1E<FYE('-O9G1W87)E9F]U="(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS
M9VED(")L:6YE<UTB"FUS9W-T<B`B<F5G96QS72(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K
M:6YG($E33RXB"FUS9W-T<B`B;6MI<V]F<R!F;W5T8V]D92`E9"!B:6H@:&5T
M(&%A;FUA:V5N('9A;B!)4T\N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C,W,`IM<V=I9"`B;6TB"FUS9W-T<B`B;6TB"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(X-2!S97)V:6-E<R]P
M;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E
M8F%R+G!H<#HR-#$*;7-G:60@(FYA;64B"FUS9W-T<B`B;F%A;2(*"B,Z(&9R
M86UE=V]R:R]24$,O4E!#+G!H<#HQ,C0*;7-G:60@(FYO="!I;7!L96UE;G1E
M9"(*;7-G<W1R(")N:65T('9A;B!T;V5P87-S:6YG(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C(P"FUS9VED(")N;W0@>65T(&EM
M<&QE;65N=&5D(@IM<V=S='(@(DYO9R!N:65T('9A;B!T;V5P87-S:6YG(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#D*;7-G:60@(FYO=&5P
M860B"FUS9W-T<B`B;F]T:71I96)O96LB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED(")P97)C96YT
M(@IM<V=S='(@(G!R;V-E;G0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$W-`IM<V=I9"`B<&5R;6ES<VEO;B!D96YI960B"FUS9W-T
M<B`B4F5C:'0@9V5W96EG97)D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S
M='(@(G!I>&5L<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,3<P"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T
M<B`B4F5M;W1E(&9O=70@:6X@<')O=&]C;VPB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW-0IM<V=I9"`B<FES:6YG(@IM<V=S
M='(@(G-T:6IG96YD(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-#(*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B
M4V5R=FEC92!N:65T(&)E<V-H:6MB86%R(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HQ,#$*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B
M=&]O;B!V97)S8VAI;&QE;B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA($A4
M5%`B"FUS9W-T<B`B<VUS,F5M86EL('9I82!(5%10(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-PIM<V=I9"`B<W,B"FUS
M9W-T<B`B<W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HW-`IM<V=I9"`B<W1E861Y(@IM<V=S='(@(G-T86)I96PB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES
M=&5M(&5R<F]R(@IM<V=S='(@(G-Y<W1E96UF;W5T(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,S,*;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R
M(")T86ME;FQI:G-T(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(G1I
M:F1E;&EJ:V4@;6ES;'5K:VEN9R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&9R
M86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@(G1Y<&4@
M=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B5F]E<BP@
M=&5R(&)E=F5S=&EG:6YG+"!H970@=V%C:'1W;V]R9"!T=V5E(&UA86P@:6XB
M"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F
M+G!H<#HW.0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R(")U;FEF:65D(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]087)T+G!H<#HR-PIM<V=I9"`B=6YN86UE
M9"(*;7-G<W1R(")O;F)E;F]E;60B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*;7-G:60@(G5S97(@<V5L
M96-T(@IM<V=S='(@(D=E8G)U:6ME<G-E;&5C=&EE(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*
M;7-G<W1R(")V0V%R9"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR-#(*;7-G:60@(G<Z(@IM<V=S='(@(G<Z(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E871H97(N8V]M
M(@IM<V=S='(@(G=E871H97(N8V]M(@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]J85]*4"YP;P``````````
M````````````````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`V-S<W
M,S(@,3`U,34T,S,W-#(@,#$W-3(V`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````",@2F%P86YE<V4@=')A;G-L871I;VX@9F]R
M($AO<F1E+@HC($-O<'ER:6=H="`H0RD@,C`P-"!(;W)D92!0<F]J96-T"B,@
M5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N
M<V4@87,@=&AE($AO<F1E('!A8VMA9V4N"B,@2&ER;VUI($MI;75R82`\:&ER
M;VUI0'1A8RYT<W5K=6)A+F%C+FIP/@HC"FUS9VED("(B"FUS9W-T<B`B(@HB
M4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C$N,%QN(@HB4$]4+4-R96%T
M:6]N+41A=&4Z(#(P,#8M,#,M,#8@,3(Z-#<K,#$P,%QN(@HB4$\M4F5V:7-I
M;VXM1&%T93H@,C`P-BTP,RTR,B`Q,CHP,"LP.3`P7&XB"B),87-T+51R86YS
M;&%T;W(Z($AI<F]M:2!+:6UU<F$@/&AI<F]M:4!T86,N='-U:W5B82YA8RYJ
M<#Y<;B(*(DQA;F=U86=E+51E86TZ($IA<&%N97-E(#QU;FMN;W=N0'5N:VYO
M=VXN9&]M86EN/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M
M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U32$E&5%]*25-<;B(*(D-O;G1E
M;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S-C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D
M87ES(&%G;RDB"FUS9W-T<B`B("@E<R"3^I%/*2(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,3,X,PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C
M8V5S<VME>2`E<RDB"FUS9W-T<B`B@T&#3H-:@UB#3(-#("5S(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(H%I)7,@D_J"S)/@@LF!:B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S`*;7-G:60@(B`H=&]D87DI
M(@IM<V=S='(@(B`HC:&3^BDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S<R"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("*!:9:^D_J!:B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-C@*;7-G:60@(B`H>65S
M=&5R9&%Y*2(*;7-G<W1R("(@*(WPD_HI(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(T-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S4P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.38*;7-G:60@
M(B!A="`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A(&1I
M<F5C=&]R>2XB"FUS9W-T<B`B)R5S)R""S8-F@T*#C(-.@V>#BH%;@L6"S8*@
M@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC
M92XB"FUS9W-T<B`B7"(E<UPB((+-D+."M8*BD4F1\(+%@LV"H(+H@MR"N8+Q
M@4(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<Q
M,`HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$P.3@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D
M(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B7"(E<UPB((+-($AO
M<F1E((.,@U>#6(-G@XJ"R9#=DNB"LX+J@L2"HH+<@KF"\2XB"@HC.B!F<F%M
M97=O<FLO5')E92]4<F5E+G!H<#HQ-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R(")<(B5S
M7"(@@V.#BH%;E5R.IHM`E%R"JHRIE72"J8+H@MR"N8+Q@4(B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C4V"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W
M87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(EPB)7-<
M(B""JH-/@XN!6X-V@U:#6(-E@X""R9+'B<&"LX+J@MR"M8*]@4(B"@HC.B!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M
M+B(*;7-G<W1R(")<(B5S7"(@@JJ#08-.@UJ#6(R@@U:#6(-E@X""R9+'B<&"
MLX+J@MR"M8*]+B(*"B,@;7-G<W1R("(G)7,G@JJ+EHG"D-V2Z(-6@UB#98.`
M@LF2QXG!@K."ZH+<@K6"O2XB"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-30@861M
M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@
M(EPB)7-<(B!W87,@;F]T(&-R96%T960Z("5S+B(*;7-G<W1R(")<(B5S7"(@
M@LV-[)"L@K."ZH+<@KF"\8+%@K6"O3H@)7,N(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D
M(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(I=EE\H@)3(D
M+C)F34(@DH:"S"`E,20N,F9-0B".9Y=P*"4S)"XR9B4E*2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)60@)7,@86YD("5S(@IM<V=S='(@(B5D("5S((+&("5S(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HR-C@@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C4U-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!D87ES('5N=&EL
M('EO=7(@<&%S<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`B@W"#6(./@5N#:(+-
M@J""QB`E9""3^I=,C/B"Q8*W@4(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E
M8V%S="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B
MDLJ2;2`M("5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HW,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS
M9W-T<B`B)7,@DV2.<8YWEN0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HX-#`@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z.#0R"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B5S
M($M"(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF
M:7)M871I;VXB"FUS9W-T<B`B)7,@E=N.YY&`C>R"S(IME$8B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR
M,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B)7,@
M@LR0W9+H(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N(%5P(@IM<V=S='(@(B5S
M((-4@T.#DX-!@V*#=B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE;G0B
M"FUS9W-T<B`B)7,@DZ^(TX_PC8`B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C0S,B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y-`HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8X,B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C<U,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y
M(&5X:7-T<RXB"FUS9W-T<B`B)7,@@LV*^8+)D;:-W8*U@MR"MX%"(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#8*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS-3(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S
M(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P
M97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB
M"FUS9W-T<B`B(@HB)7,@@LV.GX+)CG>2Z(*S@NJ"Q(*B@NF5VX[GD8"-[(+P
MCL"-<X*W@NF/@)3U@JJ0KH*B@MR"M8*]@4*.P(US@K6"O8*BD8"-[(+,(@HB
M@WN#8H-.@UB"\(-@@T:#8H-.@K6"Q(*M@KZ"LX*B@4(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,S,W"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&ES(')E<75I<F5D(@IM<V=S='(@(B5S((*JE4N7=H+%@K<B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M
M:6YU=&5S(@IM<V=S='(@(B5S()6J(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+T-O;&QE8W1I;VXN<&AP.C$R.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!N;W0@9F]U;F0N(@IM<V=S='(@(B5S((*J@J""Z(+<@KF"\8%"(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R("(E<R""J8+G("5S@4&-
MAXQV("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B
M)7,@@LR#08-H@XR#6)*@(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G
M<W1R("(E<R""S)=<DNB57"(*"B,@;7-G<W1R("(E<X+,@TJ#C(.3@U\B"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$P"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R("(E<R""S(.!@X*2H"(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,T"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B)7,@@LR#7H-8@TZ#BH-8
M@V<B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M.B`E<R(*;7-G<W1R("(E<SH@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]H=&UL+G!H<#HQ,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I
M;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@(@HB86YY(&QI;FMS(&EN
M(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O
M;F%L(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"B(E<SH@@K&"S(.!@V*#6H%;
M@U>"S8ZF@K."ZH+$@J*"Z9&7D$V.TH*I@N>"S(+@@LR"Q8+-@LB"HH+&CG:"
M[8+J@MR"MX%"@KN"S)*&(@HB@LR#BH.3@TZ"\(-.@XJ#8H-.@K6"O8+H@4&,
MPI!LC^Z5\8+PD9>038*W@NF"S(+-CUR5JH+)DHV(TX*U@L2)NH*S@J*!0B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-30@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,Y.0IM<V=I9"`B+"!G=7-T:6YG("(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Y-2!L:6(O0FQO8VLO
M;65T87(N<&AP.C(P,`HC+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U<W1I;F<@
M)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L92!F<F]M("5S('1O("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,CDT(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S0X"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(P-C8@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$R-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-S0X"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B+2T@D4F1\"`M
M+2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&
M;W)M870B"FUS9W-T<B`B,3*.GHK4C&".KB(*"B,Z(&QI8B]";&]C:R]T:6UE
M+G!H<#HQ.0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B,C2.GHK4
MC&".KB(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R
M-"!H;W5R<R(*;7-G<W1R("(R-"".GHK4(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U!A9V5R+G!H<#HV.0IM<V=I9"`B/%!R979I;W5S(@IM<V=S='(@(CR13X+,
M@WF!6X-7(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,C8*;7-G:60@(D$@
M9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RXB
M"FUS9W-T<B`B@K&"S(-U@XV#8H-.@LF"S8-F@5N#7H-X@5N#6(*JE4N7=H+%
M@K>!0B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<Q"FUS9VED
M(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R("*2=I:]DTF"
MR(-'@XF!6X*JE*V0MH*U@MR"M8*](@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E
M<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(")01U",]HI*
MC*Z"JH.!@V*#6H%;@U>"S(C#C8:)NX+)E4N7=H+%@K>!0B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-C@*;7-G:60@(D$@<'5B;&EC
M(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A
M9V4N(@IM<V=S='(@(E!'4(SVBDJ,KH*JCY"6O(*S@NJ"O8.!@V*#6H%;@U>"
MS(R?C]B"R95+EW:"Q8*W@4(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ,#DY"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV
M871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D
M96-R>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB4$=0C/:*2HRN@4%0
M1U"4Z9:GC*Z"J(+F@M&#<(-8@W2#C(%;@UF"JHC#C8:)NX.!@V*#6H%;@U>"
MS)6<C8:"R95+EW:"Q8*W@4(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ,#$V"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV
M871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S
M:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B4$=0C/:*2HRN@4%01U"4Z9:G
MC*Z"J(+F@M&#<(-8@W2#C(%;@UF"JH.!@V*#6H%;@U>"S(^0EKR"R95+EW:"
MQ8*W@4(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4P
M-@IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)
M344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB9&5C
M<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*(E,O34E-18SVBDJ,KH%!4R]-
M24U%E.F6IXRN@JB"YH+1@W"#6(-T@XR!6X-9@JJ(PXV&B;N#@8-B@UJ!6X-7
M@LR5G(V&@LF52Y=V@L4B"B*"MX%"(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K
M97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B"B)3+TU)
M346,]HI*C*Z!05,O34E-193IEJ>,KH*H@N:"T8-P@UB#=(.,@5N#68*J@X&#
M8H-:@5N#5X+,CY"6O(+)E4N7=H+%@K>!0B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!334E-12!K
M97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@
M(E,O34E-18SVBDJ,KH*J@X&#8H-:@5N#5X+,B,.-AHF[@LF52Y=V@L6"MX%"
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0IM
M<V=I9"`B04T@0VQO=61S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!,:6=H="!286EN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$Q"FUS9VED(")!32!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED(")!32!3
M:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-
M+U!-(@IM<V=S='(@(D%-+U!-(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`P"FUS9VED(")!4$D@240B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`B@K&"S(-'
M@V:#0H->@5N"R8+"@J*"Q"(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP
M.C4S"FUS9VED(")!8F]U="XN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T"FUS9VED(")!8G-B;W1T
M;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED9&QE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-S`*;7-G:60@(D%C8V5S
M<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B5D93
M@V:#0H.,@TZ#9X.*@LR-[)"L@LV#08-.@UJ#6(N1E-N"LX+J@MR"M8*]@4(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3,V"FUS9VED(")!
M8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G<W1R(")61E.#
M=(-`@T.#BX+,C>R0K(+-@T&#3H-:@UB+D93;@K."ZH+<@K6"O8%"(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C,*;7-G:60@(D%C8V]U;G0@26YF;W)M
M871I;VXB"FUS9W-T<B`B@T&#2H-%@Y.#9X_NE?$B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-S@*;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS9W-T
M<B`B@T&#2H-%@Y.#9X+,@W"#6(./@5N#:"(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N
M="!F<F]Z96XN(@IM<V=S='(@(H-!@TJ#18.3@V>"S9.`C(N"LX+J@L2"HH+<
M@K>!0B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,S4*;7-G:60@
M(D%C8V]U;G1I;F<B"FUS9W-T<B`B@T&#2H-%@Y.#9R(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,30X('1E;7!L871E<R]P;W)T86PO861D
M+FEN8SHQ-`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN
M8SHQ,0IM<V=I9"`B061D(@IM<V=S='(@(I+'B<$B"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C(R-"!A9&UI;B]G<F]U<',N<&AP.C(R-0IM<V=I9"`B061D($-H
M:6QD($=R;W5P(@IM<V=S='(@(H-4@W6#3X.+@5N#=H+PDL>)P2(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3@@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HY.0IM<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB
M"FUS9W-T<B`B@U2#=8-!@TZ#6H-8C*""\)+'B<$B"@HC(&US9W-T<B`B@U2#
M=8N6B<*#=(.)@T^"\)+'B<$B"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN
M8SHU"FUS9VED(")!9&0@2&5R93HB"FUS9W-T<B`B@K&"L8+)DL>)P3HB"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q.0IM
M<V=I9"`B061D($YE=R!'<F]U<"(*;7-G<W1R("*05H*U@J*#3X.+@5N#=H+P
MDL>)P2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#<@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX.`IM<V=I9"`B061D($YE=R!0
M97)M:7-S:6]N(@IM<V=S='(@(I!6@K6"HH+P@T&#3H-:@UB,H(+PDL>)P2(*
M"B,@;7-G<W1R("*05H*U@J*+EHG"@W2#B8-/@O"2QXG!(@HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHW"B,L('!H<"UF;W)M870*
M;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R("*#
M5(-U@T^#BX%;@W:"\"!<(B5S7"(@@LF2QXG!(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D
M(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B@U2#=8-!
M@TZ#6H-8C*""\"!<(B5S7"(@@LF2QXG!(@H*(R!M<V=S='(@(H-4@W6+EHG"
MD-V2Z(+P)R5S)X+)DL>)P2(*(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@
M(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R("*05HM+@X:!6X-5@O"2QXG!@48B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34V
M"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S='(@(I?Q@O"2QXG!(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS-`IM<V=I9"`B061D(&YE
M=R!M96UB97)S(@IM<V=S='(@(I!6BTN#@8.3@V^"\)+'B<&!1B(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM
M<V=S='(@(H-Y@T&"\)+'B<$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S<Q"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A
M($UO>FEL;&$@4VED96)A<B(*;7-G<W1R("(E<R"#@8-J@X6!6X+P($UO>FEL
M;&$@@LR#5(-#@VB#;X%;@LF2QXG!@K>"Z2(*"B,@;7-G<W1R("*#2H.,@Y.#
M7X%;@LF2QXG!(@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z-S$*;7-G:60@(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@
M(H-!@VB#C(-8DJ""R9+'B<$Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C<X"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B
M;V]K(@IM<V=S='(@(HZ$@LR"S(-!@VB#C(-8DJ""R9+'B<$B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HS,0IM<V=I9"`B061D('5S97(B"FUS9W-T<B`B@X:!6X-5
M@O"2QXG!(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB061D960@7"(E<UPB('1O('1H92!S>7-T96TL(&)U="!C;W5L
M9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`B"B(E
M<RXB"FUS9W-T<B`B(@HB@U:#6(-E@X""R2!<(B5S7"(@@O"2QXG!@K6"W(*U
M@KV"JH%!@U2#0X.3@T&#8H-V@LR/[I7Q@JJ2QXG!@L6"JX+<@KF"\8+%@K4B
M"B*"O8%&)7,B"@HC.B!S:6=N=7`N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G
M:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I
M;B!N;W<N(@IM<V=S='(@(H-6@UB#98.`@LD@7"(E<UPB((+PDL>)P8*U@MR"
MM8*]@LR"Q8%!@XV#3X-#@Y."Q8*K@MR"MX%"(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G:60@(D%D9&EN9R!U<V5R<R!I<R!D
M:7-A8FQE9"XB"FUS9W-T<B`B@X:!6X-5@LR2QXG!CXB7G8+-EK.,^(+)@LB"
MP8+$@J*"W(*W@4(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3(V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ-S,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30S.`IM<V=I
M9"`B061D<F5S<R(*;7-G<W1R("*/6H^*(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$T,0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(H-!
M@VB#C(-8DJ`B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T
M+G!H<#HU-@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HY-`IM<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@
M;W1H97(@=7-E<G,B"FUS9W-T<B`BBL>7G2`M()&\@LR#AH%;@U6"S(-!@TZ#
M6H-8C*`B"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T
M<B`BBL>7G2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#,*;7-G
M:60@(D%D<R(*;7-G<W1R(")!9',B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!9F=H
M86YI<W1A;B(*;7-G<W1R("*#08-T@TN#:H-8@UZ#DR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*
M;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B@T&#BX-O@VJ#02(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S`*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B@T&#BX-7@T:#BH-!(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P-PIM<V=I
M9"`B06QI87,B"FUS9W-T<B`BE<J6O"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*;7-G:60@(D%L:6=N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N=#HB"FUS9W-T<B`BB,J2=9&U@J:!
M1B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM
M<V=S='(@(I%3E90B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C(P-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8U"FUS9VED(")!;&P@
M075T:&5N=&EC871E9"!5<V5R<R(*;7-G<W1R("*14Y1&C]B#AH%;@U4B"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C(R"FUS
M9VED(")!;&P@1W)O=7!S(@IM<V=S='(@(I%3@L2"S(-/@XN!6X-V(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY,2!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O9&%T871R964N<&AP.C<U"FUS9VED(")!;&P@4&5R;6ES<VEO
M;G,B"FUS9W-T<B`BD5."Q(+,@T&#3H-:@UB,H"(*"B,@;7-G<W1R("*14X+$
M@LR+EHG"D-V2Z"(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V.`IM<V=I9"`B
M06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(I6AD)2"S(-!@VB#
MC(-8@O"+EHG"(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S.`IM<V=I
M9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T
M<B`BE-2-AI5T@JN#BH-8@V>"\)#=DNB"Q8*K@NF"YH*D@LF"M8+<@K>"J8%(
M(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T
M"FUS9VED(")!;')E861Y(&5X:7-T<R(*;7-G<W1R("**^8+)D;:-W8*U@MR"
MMR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C8*;7-G:60@(D%L=&5R
M;F%T92!)35-0($QO9VEN(@IM<V=S='(@(I'CD=:"S"!)35-0((.-@T^#0X.3
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q,0IM<V=I9"`B06QT97)N
M871E($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`BD>.1UH+,($E-4U`@@W"#6(./
M@5N#:"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#,*;7-G:60@(D%L
M=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S='(@(I'CD=:"S"!)35-0((.&
M@5N#59:\(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*;7-G
M:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@(I'CD=:"S(.!
M@5N#BX-!@VB#C(-8(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*;7-G
M:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`BD>.1UH+,@V6#DX-V
M@XR!6X-G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS
M9W-T<B`BD>.1UH-E@TR#6(-G@48B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;65R
M:6-A;B!386UO82(*;7-G<W1R("*#08.!@XJ#2I?,@U2#@H-!(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HY-2!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@:6QL96=A;"!V86QU92!W87,@
M<W!E8VEF:65D+B(*;7-G<W1R("*5<Y"S@LB2;(*JCG>2Z(*S@NJ"Q(*B@MR"
MMR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-34*;7-G:60@
M(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N(@IM<V=S='(@(I=<BOJ"
MM8+(@J*#1X.)@5N"JI2MD+:"M8+<@K6"O2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@
M(D%N9&]R<F$B"FUS9W-T<B`B@T&#DX-H@XDB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED
M(")!;F=O;&$B"FUS9W-T<B`B@T&#DX-3@XF+I)AAC9$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W
M"FUS9VED(")!;F=U:6QL82(*;7-G<W1R("*#08.3@T^#0H.)(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S
M(%!R;WAY(@IM<V=S='(@(I.]EKR#=H.-@TR#5H%;(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R("*3
MFH*F(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R("*3
M[(O)@6F1Y9>D@6HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N9"!"
M87)B=61A(@IM<V=S='(@(H-!@Y.#98-"@T^#08%%@V^!6X-U@5N#7R(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN<&AP.C,V
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3@@=&5M<&QA=&5S
M+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I;VXB
M"FUS9W-T<B`B@T&#=H.*@U"!6X-6@X>#DR(*"B,Z('5T:6PO:6-O;E]B<F]W
M<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*;7-G<W1R("*#
M08-V@XJ#4(%;@U:#AX.3B.J7ER(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-#`*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R("*#
M08-V@XJ#4(%;@U:#AX.3CF>7<(G"(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O($-H:6QD(%-H87)E<R(*;7-G
M<W1R("*)NHC*@LR+I)=,@LF32Y=P(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`BC[.4
M1B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T,`IM
M<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R("*"J(*H@N:"NX+,@U2#
M0X-9(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(H)3C(XB"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$W.`IM<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-3D@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<X"FUS9VED
M(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R("*#08%;@TJ#0X-U@W2#0(-#
M@XN#5(-#@UDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C4X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW-PIM<V=I
M9"`B07)C:&EV92!.86UE(@IM<V=S='(@(H-!@5N#2H-#@W66O"(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V
M92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B"FUS9W-T<B`B)7,@@LR#
M5(-#@Y.#08-B@W:7=HN!@O"6>Y.6@LF-[8^<@K6"Q(*B@J*"Q8*W@JF!2"(*
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHW"B,L('!H
M<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE
M=&4@7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS9W-T<B`BEGN3EH+)
M(%PB)7-<(B""QH-4@W6#3X.+@5N#=I%3@L2"\(WMCYR"M8+$@J*"HH+%@K>"
MJ3\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4X"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B@T&#
MBX-;@Y.#8(.3BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B07)M96YI82(*
M;7-G<W1R("*#08.+@X&#:H-!BZ2888V1(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ-SD*;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.`IM<V=I9"`B07)T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%R=6)A(@IM<V=S='(@(H-!
M@XN#;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34*;7-G:60@
M(D%S8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B@T&#6H.3@U:#AX.3DX<B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*
M;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`B@T&#5X-!@5Z1
MOI6]EVV2;HCF(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R.0IM<V=I
M9"`B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@(I7;CN>-[(O&@LR.P(USD4^"R8IM
ME$:"\(N!@M^"Z8+F@J2"R8*U@MR"MX*I@4@B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,#DR"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS
M9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I9"`B071T96UP
M="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(I&V
MC=V"M8+(@J*#3X.+@5N#=H+PC>V/G(*U@N:"I(+&@K6"W(*U@KV!0B(*"B,Z
M(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@
M9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(I&V
MC=V"M8+(@J*#08-.@UJ#6(R@@O"-[8^<@K6"YH*D@L:"M8+<@K6"O8%"(@H*
M(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*;7-G:60@(D%T=&5M<'0@=&\@
M961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("*1MHW=
M@K6"R(*B@T&#3H-:@UB,H(+PE=*/5X*U@N:"I(+&@K6"W(*U@KV!0B(*"B,Z
M('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I9"`B071T96UP="!T
M;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R("*1MHW=@K6"
MR(*BBZ273(+PE=*/5X*U@N:"I(+&@K6"W(*U@KV!0B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HW,0HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C@S"FUS9VED(")!='1R:6)U=&5S(@IM<V=S='(@
M(I&ND*LB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`Y"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW,@IM<V=I9"`B075G=7-T(@IM<V=S='(@(H)7C(XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y
M"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B@TF!6X-8@V>#B8.*@T$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4Y"FUS9VED(")!=7-T<FEA(@IM<V=S='(@(H-)@5N#6(-G@XJ#
M08NDF&&-D2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HQ
M-C@*;7-G:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER<W%L.B"52Y=V@LA)34%0
MBF>2HXM`E%R"JHRI@L*"J8+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A8VME
M;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB"FUS9W-T
M<B`B075T:%]C>7)U<SH@@V^#8H-.@T>#DX-H@LV52Y=V@LB47)?-@O"73(*U
M@L2"HH+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP
M:'`Z,3(R"FUS9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER=7,Z()=VBX&"MX+I
M:6UA<(IGDJ."JHRI@L*"J8+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E
M9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T
M:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B(@HB075T:%]F
M='`Z($944(IGDJ.+0)1<@JJ"W8+"@JF"Z(+<@KF"\2X@4$A0@O`@+2UE;F%B
M;&4M9G1P((-)@W:#5H.'@Y."\(+"@J^"Q"(*(H-2@Y.#<(-#@XN"M8+(@JB"
MM8+$@JV"OH*S@J*!0B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP
M:'`Z-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VEM87`Z($E-05"*9Y*CBT"4
M7(*JC*F"PH*I@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VMR8C4Z(&MR8C6*
M9Y*CBT"47(*JC*F"PH*I@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z,S`R"FUS9VED(")!=71H7VQD87`Z($%D9&EN9R!U
M<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM
M<V=S='(@(D%U=&A?;&1A<#H@06-T:79E($1I<F5C=&]R>2""Q8+,@X:!6X-5
MDL>)P8+-@U2#?(%;@V>"LX+J@L2"HH+<@KF"\2(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z(%)E;6]V
M:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O
M<GDB"FUS9W-T<B`B075T:%]L9&%P.B!!8W1I=F4@1&ER96-T;W)Y((+%@LR#
MAH%;@U6-[8^<@LV#5(-\@5N#9X*S@NJ"Q(*B@MR"N8+Q(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HV,PIM<V=I9"`B075T:%]L9&%P.B!2
M97%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U
M=&A?;&1A<#H@3$1!4(IGDJ.+0)1<@JJ,J8+"@JF"Z(+<@KF"\8%"(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,SD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R(")!=71H7VQD
M87`Z((.&@5N#52`E<R""\)+'B<&"Q8*K@MR"N8+Q@4*#5(%;@V^"S(F>DYHZ
M("(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H
M<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U
M<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@@X:!6X-5("5S((+PC>V/G(+%
M@JN"W(*Y@O$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0Y
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!U
M<&1A=&4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z((.&@5N#52`E<R""
M\(U8D%:"Q8*K@MR"N8+Q(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HT,#4*;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@
M;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B
M075T:%]L9&%P.B!!8W1I=F4@1&ER96-T;W)Y((+%@LR#AH%;@U6-6)!6@LV#
M5(-\@5N#9X*S@NJ"Q(*B@MR"N8+Q(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;6-A;#H@34-!
M4(IGDJ.+0)1<@JJ,J8+"@JF"Z(+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E<75I
M<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T
M:%]S;6)A=71H.B!S;6)A=71HBF>2HXM`E%R"JHRI@L*"J8+H@MR"N8+Q@4(B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%D;6EN+G!H<#HQ,#8*;7-G:60@
M(D%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T
M<B`B24U!4(-4@5N#;X+%@LR41H_8@LF.N)1S@K6"W(*U@KV!0B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM
M<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S='(@(I1&C]B"R8ZX
ME'."M8+<@K6"O2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&AE
M;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`BE$:/V(+)CKB4<X*U@MR"
MM8*]@4(E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ
M-S8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S
M97)V97(N(@IM<V=S='(@(E)!1$E54X-4@5N#;X+)@N:"Z)1&C]B"JHN1E-N"
MLX+J@MR"M8*]@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@X
M,@IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N
M(@IM<V=S='(@(D944(-4@5N#;X+,E$:/V(+)CKB4<X*U@MR"M8*]@4(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C<P"FUS9VED(")!=71H96YT
M:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N(@IM<V=S='(@(E--
M0H-4@5N#;X+,E$:/V(+)CKB4<X*U@MR"M8*]@4(B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C<U"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*
M;7-G<W1R("*.9Y=PB<*47(+(@W2#0H%;@XN#:(%&(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM
M<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R("*#08-;@XN#;X-#@U>#@X.3BZ28
M88V1(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"3T9(
M($5X8W5S97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*
M;7-G<W1R("*4=XQI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R
M("*4=XQID$8B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@Q
M"FUS9VED(")"860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(DME<F]B
M97)O<R"#<(-8@X^!6X-H@JJ6LXSX@L6"MX%"(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N
M86UE+B(*;7-G<W1R(")+97)O8F5R;W,@@X:!6X-5EKR"JI:SC/B"Q8*W@4(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8R"FUS9VED(")"86AA;6%S(@IM<V=S='(@(H-O@VZ#?2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C$*;7-G:60@(D)A:')A:6XB"FUS9W-T<B`B@V^!6X.,@5N#
MDR(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS9VED(")"86QT:6,@
M*$E33RTX.#4Y+3$S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"
M86YG;&%D97-H(@IM<V=S='(@(H-O@Y.#3X.)@V:#5H.%D&R6KXNDF&&-D2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(H-O@XN#;X-H
M@U@B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F
M;W5N9"XB"FUS9W-T<B`BBNZ6>X-/@XF#=(-"@TZ#6(+,@V:#0H.,@TZ#9X.*
M@5L@7"(E<UPB((*J@J""Z(+<@KF"\8%"(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S"FUS9VED(")"87-E;&EN
M92(*;7-G<W1R("**[H^`D/PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QA<G5S
M(@IM<V=S='(@(H-X@XF#BX%;@U:+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED
M(")"96QG:75M(@IM<V=S='(@(H-X@XN#38%;(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I
M9"`B0F5L:7IE(@IM<V=S='(@(H-X@XJ!6X-9(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I
M9"`B0F5N:6XB"FUS9W-T<B`B@WB#:8.3BZ2888V1(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM
M<V=I9"`B0F5R;75D82(*;7-G<W1R("*#;X-^@X6!6X-?@6F/E).'@6HB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8S"FUS9VED(")":'5T86XB"FUS9W-T<B`B@W6!6X->@Y.)I(V1
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q
M,0IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`BDF&0MI/Z(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,V-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")";&]C:R!<(B5S7"(@;V8@87!P;&EC871I;VX@7"(E<UPB
M(&YO="!F;W5N9"XB"FUS9W-T<B`B@W6#C8-B@TX@7"(E<UPB((+,@T&#=H.*
M@U"!6X-6@X>#DR!<(B5S7"(@@JJ"H(+H@MR"N8+Q@4(B"@HC.B!T96UP;&%T
M97,O<&]R=&%L+VQA>6]U="YI;F,Z.3`*;7-G:60@(D)L;V-K(%-E='1I;F=S
M(@IM<V=S='(@(H-U@XV#8H-.D-V2Z"(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R("*#=8.-
M@V*#3H->@T.#=B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G<W1R("*1OHZ:(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,@IM<V=I9"`B0F]L:79I82(*;7-G<W1R("*#>X.*@W*#08NDF&&-D2(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,#<*;7-G:60@(D)O;VMM
M87)K<R(*;7-G<W1R("*#=8-B@TZ#?8%;@TXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(P"FUS9VED(")";W)D
M97(B"FUS9W-T<B`BB8\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G
M<W1R("*)CX+,D;Z"LX%&(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R
M("*)CR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I
M;F$B"FUS9W-T<B`B@WN#6(-J@T&!18-W@XN#8X-&@U.#<H-I(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED(")";W1H(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C,*;7-G:60@(D)O='-W86YA(@IM<V=S='(@(H-[@V.#CX-I
MBZ2888V1(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<U"FUS9VED(")";W1T;VTB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R("*#=8%;@WB3AR(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C(*;7-G:60@(D)R87II;"(*;7-G<W1R("*#=8.)@U>#BR(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@Q"FUS9VED(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R
M:71O<GDB"FUS9W-T<B`BB7"7S(-#@Y.#:(^4DX<B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS
M9VED(")"<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R("*#=8.+@VR#0X%%@U^#
MBX-4@XF!6X.`(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T
M<B`B@W6#BX-+@XJ#02(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D($QI<W0B"FUS9W-T<B`B
MB=./\(^1@JLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B"FUS
M9W-T<B`B@W6#BX-,@VF#=(-`@UPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)U
M;F1I(@IM<V=S='(@(H-U@XN#DX-7BZ2888V1(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0T-@IM<V=I9"`B0TU3(@IM<V=S='(@(D--4R(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@
M(D-20R(*;7-G<W1R(")#4D,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4Y.`IM<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN=',B
M"FUS9W-T<B`B0U),()1ZE7J#?(-#@Y.#9R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-PIM<V=I9"`B0U]E
M;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")?18-:@XN1KI"K+BXN(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U,0IM<V=I9"`B0V%C:&4@
M:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T<B`B@TR#@X-B@U:#A8+,
MCXF*^HF[@JJ*KI>Y@K6"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.3$V(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT.#4*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-#`@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$U-PIM<V=I9"`B0V%L96YD87(B
M"FUS9W-T<B`BEUR2Z)5<(@H*(R!M<V=S='(@(H-*@XR#DX-?@5LB"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S4*;7-G:60@(D-A;&TB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@
M(H-*@Y.#>X-7@T$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#86UE<F]O;B(*;7-G
M<W1R("*#2H.!@XN!6X.3BZ2888V1(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T
M;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S
M='(@(H-P@UB#CX%;@VB"S8ZIDZZ"Q8+-@XJ#6H-B@V>"Q8*K@MR"N8+Q@4**
MQY>=CM*"R9A!EXV"M8+$B;J"LX*B@4(B"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HS-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W
M<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R("*#=(-`@T.#BR!<(B5S7"(@
M@LF/D8*O@MR"N8+Q@4(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C(*;7-G
M:60@(D-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R
M<RXB"FUS9W-T<B`BBD^5E(+,@UJ#8H-6@X>#DX-N@Y.#:(.)@5N"S8K'EYV"
MQ8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H
M<#HR,S4@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,Q.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R
M.B`E<R(*;7-G<W1R("))34%0((-4@5N#;X+)D-J1L8+%@JN"W(*Y@O&"Q8*U
M@KTZ("5S(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0V"B,L
M('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&]P96X@9FEL92!<(B5S7"(N(@IM
M<V=S='(@(H-T@T"#0X.+(%PB)7-<(B""JHI*@J^"W(*Y@O&!0B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C0*;7-G:60@(D-A;F%D82(*;7-G<W1R("*#2H-I@U\B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-0HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*;7-G<W1R("*#3(.#@Y.#6H.+(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A
M;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R("*/X8I1E?&-D(+P@TR#@X.3
M@UJ#BX*W@NDB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,R,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R("*#=(-`@T.#BR!<(B5S7"(@@O"-[8^<@L6"JX+<@KF"\8%"
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z
M-3(*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB
M"FUS9W-T<B`BC>R+QH-F@T*#C(-.@V>#BH*JC*F5=(*I@NB"W(*Y@O&!0B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z.3$*
M;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A
M<F%M971E<BXB"FUS9W-T<B`B)W1A<F=E=$9I;&4G((-P@XF#@8%;@UZ"R(*U
M@L6"S9&QC7."Q8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C,Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E
M(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(H-F@T*#C(-.@V>#BH%;(%PB
M)7-<(B""\(WMCYR"Q8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO1&%T851R
M964O1&%T851R964N<&AP.C$R."!F<F%M97=O<FLO1&%T851R964O1&%T851R
M964O<W%L+G!H<#HV.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E
M;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(HWMCYR"Q8*K@MR"
MN8+Q@4*.<9&W@JH@)60@D;:-W8*U@MR"MX%"(@H*(SH@9G)A;65W;W)K+T1A
M=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B"B)#86YN;W0@
M<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D
M97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B
M(@HBE<""UY'6@J:"S)'.C]N"S)"4@JJ5VY&V@K."ZH+$@J*"Z9"4@L:-AX+M
M@LB"HH+,@L65P(+7D=:"IH*J@L6"JX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED(")#
M86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+B(*;7-G
M<W1R("*.=Y+H@K."ZH*]E-2-AH+)@X&#8H-:@5N#5X+PE'J1EX+%@JN"W(*Y
M@O&"Q8*U@KV!0B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS
M9W-T<B`B@TJ!6X-\@WB#BX-FBZ2888V1(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`IM<V=I9"`B0V%P=&EO
M;B(*;7-G<W1R("*57)'H(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E
M;F5R:6-?<VUT<"YP:'`Z,3`T"FUS9VED(")#87)R:65R(@IM<V=S='(@(H-,
M@X.#BH-!(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS"FUS9VED(")#
M871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`BE:J7WH+&@XF#>(.+(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#8*;7-G:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(H-0
M@T.#?8.3CY23AR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`BC&>1T9-D
MF&(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(U"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`B@UJ#
MBY&ND*LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R("*#6H.+EH21
MD(%&(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S='(@(H-:
M@XN1KI"K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`B@UJ#BY==
ME)*!1B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-S$*;7-G:60@
M(D-E;&QP:&]N92(*;7-G<W1R("*,9Y'1DV288B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@Q"FUS9VED(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(V"FUS9VED(")#96YT97(B"FUS9W-T<B`BDH:)FR(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C4*;7-G:60@(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*;7-G
M<W1R("*2AHF;@T&#=(.*@TJ+I)AAC9$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X,@IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HW,#`*;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`BC]B6
MOH^1@LR/VHW7(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV,3(*;7-G:60@(D-E<G1I9FEC871E($]W;F5R(@IM<V=S='(@(H_8EKZ/
MD8+,CXJ73([2(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.3<*;7-G:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(H_8
MEKZ/D8-\@XJ#5H%;(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")#:&%D(@IM<V=S
M='(@(H-@@X.#:(NDF&&-D2(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHR-"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*;7-G:60@
M(D-H86YG92(*;7-G<W1R("*5SXU8(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C,Q"FUS9VED(")#:&%N9V4@66]U<B!087-S=V]R9"(*;7-G
M<W1R("*#<(-8@X^!6X-H@O"5SXU8(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C8Y"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@
M=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y
M;W5R("(*(F5M86EL<RXB"FUS9W-T<B`BDV2.<8.!@T.#BX+)CF>7<(*W@NF6
MO)%/@L:#08-H@XR#6(+PE<^-6(*U@MR"MX%"(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#:&%N9VEN9R!Y;W5R('!A
M<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF
M:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM
M<V=S='(@(B(*(HR[C=V"S)#=DNB"Q8+-@W"#6(./@5N#:(+,E<^-6(+P@U2#
M?(%;@V>"M8+$@J*"W(*Y@O&!0HK'EYV.TH+)F$&7C8*U@L2)NH*S(@HB@J*!
M0B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C<*;7-G:60@(D-H87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED
M(")#:&5C7VL@3&EN:RXN+B(*;7-G<W1R(")?2X.*@Y.#3H+P@V"#1H-B@TXN
M+BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EL92(*;7-G<W1R("*#8(.*BZ28
M88V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;F$B"FUS9W-T<B`BDH:)V)!L
MEJ^+I)AAC9$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B
M0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@T"FUS9VED(")#:&EN97-E(%1R861I=&EO
M;F%L("A":6<U*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O87!P
M+FEN8SHW"FUS9VED(")#:&]O<V4@07!P;&EC871I;VXZ(@IM<V=S='(@(H-!
M@W:#BH-0@5N#5H.'@Y.129'P@48B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,C<P"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*;7-G
M<W1R("*#<(-8@X^!6X-H@O"129'P(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS
M9W-T<B`B@X:!6X-5EKR"\)%)D?`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S`R"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z(@IM
M<V=S='(@(I/ZE7257(ZFC&".KH%&(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E
M(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T
M<B`B@TZ#BH-8@WV#6).'(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H
M<#HR.30@9G)A;65W;W)K+U9&4R]61E,N<&AP.CDQ-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS
M9W-T<B`B@TZ#B8-8DNB+8"`E<R""JHRIE72"J8+H@MR"N8+Q@4(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`IM<V=I9"`B
M0VQE87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*
M;7-G<W1R(")-4RU/9F9I8V6"S(->@T^"\([F@NB/G(*M(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C$R.0IM<V=I9"`B0VQE87(@475E<GDB"FUS9W-T<B`B
MC)^-]8_!BXXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS
M9W-T<B`B@X:!6X-5@LR1WHN.@48E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V-L96%R+FEN8SHQ,0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R("*#
MAH%;@U6/P8N.(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,S0*;7-G:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R("*#AH%;@U6#9H%;
M@UZ/P8N.(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,34*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-C`*;7-G:60@
M(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(H-.@XJ#8H-.@K>"Z8+&CI^"
MUB(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R("*#
M18-"@Y.#:(-%@O"5PH*V@NDB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U
M,0IM<V=I9"`B0VQO=61S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$V"FUS9VED(")#;&]U9',@16%R;'DB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3<*;7-G:60@(D-L;W5D>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T
M"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R("*#4H-2
M@UB/E).'(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR,PIM
M<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R("*#5(-#@VB#;X%;@O"/
M](+>(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]L;VUB:6$B"FUS9W-T<B`B@U*#C8.3
M@W*#08NDF&&-D2(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L
M;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#;VQO<B(*;7-G<W1R("*0
M1B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS
M,S4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,S
M-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`S
M('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O
M;&]R(%!I8VME<B(*;7-G<W1R("*01I%)D?`B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.#(U"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S
M='(@(I!&D4F1\"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R("*7\8%&(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT,PIM<V=I9"`B0V]L=6UN('1I
M=&QE<R(*;7-G<W1R("*7\8->@T.#9X.+(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(V-@IM<V=I9"`B0V]M:6-S(@IM<V=S='(@(H-2@WZ#8H-.
M@U@B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C8*;7-G:60@(D-O;6UA;F0B
M"FUS9W-T<B`B@U*#?8.3@V@B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C`*
M;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B@U*#?8.3@VB#5H-&@XLB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@
M(D-O;6UE;G0B"FUS9W-T<B`B@U*#@8.3@V<B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B0V]M;6]N($YA;64B"FUS
M9W-T<B`BBZ22RI:\(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(D-O;6]R;W,B"FUS
M9W-T<B`B@U*#@H.-F$&-AR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`BB>^.
MT"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T
M97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR.#8*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(U-@IM<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A
M=&EO;B!$:69F97)E;F-E<R(*;7-G<W1R("*0W9+H@LR-MY6J(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$T-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!F
M;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K
M+B(*;7-G<W1R(")01$&!08-8@WV!6X-G@W2#2(.3@4%/=71L;V]K@L:"S).O
MBOJ"\)#=DNB"M8+<@K>!0B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M,S4*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM<V=S
M='(@(I#=DNB"S8_<EJ&*^HS`D-B"ZH+%@K>!0B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG=7)E
M("5S(@IM<V=S='(@(B5S((+PD-V2Z(*W@NDB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"FUS9VED(")#;VYF:7)M(%!A<W-W;W)D
M(@IM<V=S='(@(H-P@UB#CX%;@VB"\(IME$8B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED
M(")#;VYG;R(*;7-G<W1R("*#4H.3@U.+I)AAC9$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS
M9VED(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM
M<V=S='(@(H-2@Y.#4Y:OCN6+I)AAC9$B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S`X"FUS9VED(")#;VYN96-T:6]N(&9A:6QE
M9"XB"FUS9W-T<B`BD-J1L8ZXE'.!0B(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C$Y-PHC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS,#@*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D
M.B`B"FUS9W-T<B`BD-J1L8ZXE'.!1B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O
M('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("*,]H]/C*Z#5(%;@V^"
MUH+,D-J1L8*JBY&4VX*S@NJ"W(*U@KV!0B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C<Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN
M96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O
M;CH@)7,@*"5S*2(*;7-G<W1R("*,]HI*C*Z#5(%;@V^"UH+,D-J1L8*JBY&4
MVX*S@NJ"W(*U@KV!0I>=EU*!1B5S("@E<RDB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C@W-@IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R
M=F5R(&9A:6QE9"XB"FUS9W-T<B`B1E10@U2!6X-O@M:"S)#:D;&"R8ZXE'."
MM8+<@K6"O8%"(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C0@
M8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-C<*;7-G:60@(D-O;G1A8W1S(@IM
M<V=S='(@(IA!EXV0YB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L
M;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(IA!EXV0
MYH+-@T&#:(.,@UB2H(+)DL>)P8*S@NJ"W(*U@KV!0B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-C`*;7-G:60@(D-O;G1E;G0@
M='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z("(*;7-G<W1R("*(LX]K@W2#0(-#
M@XN"S(-2@Y.#98.3@V.#7H-#@W:!1B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-38@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HV,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB
M)7-<(B(*;7-G<W1R(")<(B5S7"(@@LR3X)=E(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z,CD@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C,S"FUS9VED(")#;VYT:6YU92(*;7-G<W1R("*1L8*M(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C8Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-@IM<V=I9"`B0V]O:R!)<VQA;F1S(@IM<V=S='(@(H-.@V*#3H^4DX<B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B@U*#<X%;(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-S(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@(H-2@W.!6XZXE'.!
M1B5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`BD4F1\)3-B,V"
M\(-2@W.!6R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,3<P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M,3DU"FUS9VED(")#;W-T($E$(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G
M:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B@U*#6(->@XJ#2HNDF&&-D2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C8*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B@U*!6X-G
M@U>#>X./@5N#BXNDF&&-D2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.CDW-PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A
M9V4Z("(*;7-G<W1R("*#@8-B@UJ!6X-7@LP@4$=0((C#C8:)NX*J@L6"JX+<
M@KF"\8+%@K6"O8%"(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,3`U-0IM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z("(*
M;7-G<W1R("*#@8-B@UJ!6X-7@LP@4$=0((^0EKR"JH+%@JN"W(*Y@O&"Q8*U
M@KV!0B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,SDS
M"FUS9VED(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS
M9W-T<B`B@X&#8H-:@5N#5X+,(%,O34E-12"(PXV&B;N"JH+%@JN"W(*Y@O&"
MQ8*U@KV!0B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-#8W"FUS9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS
M9W-T<B`B@X&#8H-:@5N#5X+,(%,O34E-12"/D):\@JJ"Q8*K@MR"N8+Q@L6"
MM8*]@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C$X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D
M(&-O;G1A8W0N("5S(@IM<V=S='(@(IA!EXV0YH+PDL>)P8+%@JN"W(*Y@O&"
MQ8*U@KV!0B5S(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.CDV(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HT-3<*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O
M($Q$05`@<V5R=F5R+B(*;7-G<W1R("),1$%0((-4@5N#;X+)@V^#0X.3@VB"
MQ8*K@MR"N8+Q@L6"M8*]@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C$U-@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@(HYCC8*"
MJHIME$:"Q8*K@MR"N8+Q@L6"M8*]@4(E<R(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HT-#$*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O($Q$05`@
M<V5R=F5R+B(*;7-G<W1R("),1$%0((-4@5N#;X+)D-J1L8+%@JN"W(*Y@O&"
MQ8*U@KV!0B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@7"(E
M<UPB('5S:6YG($944#H@)7,B"FUS9W-T<B`B1E10((+%@U2!6X-O(%PB)7-<
M(B""R9#:D;&"Q8*K@MR"N8+Q@L6"M8*].B`E<R(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S(@IM<V=S='(@(I&7D$V0YH.*@UB#9X*JC>R0K(+%@JN"W(*Y@O&"Q8*U
M@KV!0B5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$R
M.`IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z("(*;7-G<W1R
M(")01U`@@V:!6X->@LR5G(V&B;N"JH+%@JN"W(*Y@O&"Q8*U@KTZ(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,C,*;7-G:60@(D-O
M=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+B(*;7-G<W1R(")3+TU)344@
M@V:!6X->@LR5G(V&B;N"JH+%@JN"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,B
M"FUS9W-T<B`BF$&7C9#F@JJ-[8^<@L6"JX+<@KF"\8+%@K6"O8%")7,B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("*1EY!-D.:#BH-8@V>"JHWMCYR"
MQ8*K@MR"N8+Q@L6"M8*]@4(E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C,X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@
M<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R("*0W9+HC5B0
M5I=P@UB#3H.*@W:#9R!<(B5S7"(@@O"-[8^<@L6"JX+<@KF"\8+%@K6"O8%"
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.#$@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.34S"FUS9VED(")#;W5L9"!N
M;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB
M"FUS9W-T<B`BCO.038[2@LR39(YQ@X&!6X.+@T&#:(.,@UB"JHIMDNB"Q8*K
M@MR"N8+Q@L6"M8*]@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O
M;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B@T&#:(.,@UB2H(*JBJZ1
M4X+)@LV.YI.^@L6"JX+<@KF"\8+%@K6"O8%"(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*;7-G:60@(D-O=6QD
M(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T
M<B`BD9>039#F@XJ#6(-G@JJ*KI%3@LF"S8[FD[Z"Q8*K@MR"N8+Q@L6"M8*]
M@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C0T-@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L
M:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS9W-T<B`BD9>039#F@XJ#
M6(-G@JJ*KI%3@LF"S8[FD[Z"Q8*K@MR"N8+Q@L6"M8*]@4(B"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T
M96=Y+G!H<#HV.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T<B`B
M@UB#9X.)@V6#5X%;(%PB)7-<(B""\(.-@5N#:(+%@JN"W(*Y@O&"Q8*U@KV!
M0B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N
M<&AP.C,P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!M:V1I<B!<
M(B5S7"(N(@IM<V=S='(@(DUK9&ER(%PB)7-<(B""R8ZXE'."M8+<@K6"O8%"
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S$Y"FUS9VED
M(")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R
M=F5R+B(*;7-G<W1R("*,]HI*C*Z"\(RN@U2!6X-O@JF"YX[FD[Z"Q8*K@MR"
MN8+Q@L6"M8*]@4(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN
M9RXB"FUS9W-T<B`B7"(E<UPB((+PCY&"JXV>@MV7<(+)@TF!6X-V@Y."Q8*K
M@MR"N8+Q@L6"M8*]@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8W-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@(B5S((+P@TF!6X-V@Y."Q8*K@MR"
MN8+Q@L6"M8*]@4(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E
M;F%N8V4N<&AP.C0R,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*;7-G<W1R("*5VX[G
MC>R+QH."@U>#A8%;@XL@)7,@@O"*2H*O@MR"N8+Q@L6"M8*]@4(B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDO8V]P>2YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B@V:#0H.,@TZ#
M9X.*@5L@7"(E<UPB((*JBDJ"KX+<@KF"\8+%@K6"O8%"(@H*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HR,S<@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0W
M.`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-CDY"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@
M<V5R=F5R+B(*;7-G<W1R("),1$%0((-4@5N#;X+)D-J1L8+%@JN"W(*Y@O&!
M0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+T]B:F5C="YP:'`Z,C0P"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R96%D("5S+B(*;7-G<W1R("(E
M<R""JI/'@MV/;X*Y@MR"N8+Q@4(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HX-0IM<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S
M=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T
M:&4@(@HB9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C
M;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T
M:&5R(&AE;'`N(@IM<V=S='(@(B(*(I=VBX&"LX+J@KV#AH%;@U6"S(-P@UB#
MCX%;@VB"\(.*@UJ#8H-G@L6"JX+<@KF"\8+%@K6"O8%"@J*"K8+"@JF"H(+I
M@J*"S9%3@L0B"B*"S(_NE?&"S8K4B.&"P8+$@J*"W(*W@4*-Q)-XCHZ"M8+$
M@MV"Z8*IBL>7G8[2@LF809>-@K6"Q(FZ@K."HH%"(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`W"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,S.`HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S4*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Q"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,X-PIM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E($%#3"(*;7-G<W1R(")!0TP@@O".YI.^@L6"JX+<@KF"\8+%@K6"O2(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,C<T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A
M9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(H-!@VB#C(-8DJ""\([FD[Z"Q8*K
M@MR"N8+Q@L6"M8*]@4(E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T
M<B`BD9>039#F@XJ#6(-G@O".YI.^@L6"JX+<@KF"\8+%@K6"O8%")7,B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0S
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES
M=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R("*1EY!-D.:#BH-8@V>"\([F
MD[Z"Q8*K@MR"N8+Q@L6"M8*]@4(E<R(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C$Y-PHC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HR,3<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,C(Q"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@
M<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@(H-4@5N#;X+,BT"47(CJ
MEY>"\([FD[Z"Q8*K@MR"N8+Q@L6"M8*](@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HU-`IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("*0W9+H@O",LX+)EM^"N8+<@KF"\8+%@K6"O8%"(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S='(@(EPB)7-<(B"#9H-"@XR#
M3H-G@XJ!6X*JC>V/G(+%@JN"W(*Y@O&!0B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S
M879E("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B5S()#=DNB"\)7;D;:"
MQ8*K@MR"N8+Q@L6"M8*]@4(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3D*;7-G:60@(D-O=6QD(&YO
M="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`BD-V2Z(+,
M@V^#8H-.@T&#8H-V@O"5VY&V@L6"JX+<@KF"\8+%@K6"O8%"(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T
M<B`BD-V2Z(+,@V^#8H-.@T&#8H-V@O"5VY&V@L6"JX+<@KF"\8+%@K6"O8%&
M)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP
M="!T;SH@7"(E<UPB+B(*;7-G<W1R("*0W9+HC5B05I=P@UB#3H.*@W:#9X+P
M(%PB)7-<(B""R97;D;:"Q8*K@MR"N8+Q@L6"M8*]@4(B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*
M;7-G<W1R("*0W9+H@LR#;X-B@TZ#08-B@W:#=(-`@T.#BR`E<R""\)7;D;:"
MQ8*K@MR"N8+Q@L6"M8*]@4(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C<W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO="!S879E('1H
M92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O
M;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N
M("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N(@IM
M<V=S='(@(B(*(I#=DNB#=(-`@T.#BR`E<R""R97;D;:"Q8*K@MR"N8+Q@L6"
MM8*]@4(E<R""R9;?@L&"Q)7;D;:#28-V@U:#AX.3@O".P(US@K>"Z2(*(H*I
M@4&.Z(+%@K&"S(GFELJ"S(-2@5N#:(+P("5S((+)@U*#<X%;@K6"Q(FZ@K."
MHH%"(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-#,*;7-G
M:60@(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R
M("),1$%0((-4@5N#;X*JC)^-]8+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HX-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL
M:6YK(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB((+PC>V/G"AU;FQI;FLI@L6"
MJX+<@KF"\8+%@K6"O8%"(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R("*809>-D.:"\(U8
MD%:"Q8*K@MR"N8+Q@L6"M8*]@4(E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM
M<V=S='(@(I&7D$V0YH.*@UB#9X+PC5B05H+%@JN"W(*Y@O&"Q8*U@KV!0B5S
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B!<(B5S
M7"(Z("5S(@IM<V=S='(@(EPB)7-<(B""S)#=DNB"JH^1@JN-GH+?@MR"N8+Q
M@48E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S`*;7-G:60@(D-O
M=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H
M92!S:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(DUO>FEL;&$@@LR#5(-#@VB#
M;X%;@JJ,J95T@JF"Z(+<@KF"\8%"@U2#0X-H@V^!6X+PBDJ"HH+$B;J"LX*B
M@4(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ
M-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R
M(%PB)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<
M(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T,38*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B0V]U
M;G1R>2(*;7-G<W1R("*-D2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR-S4*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"FUS
M9VED(")#<F5A=&4B"FUS9W-T<B`BC>R0K"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B0W)E
M871E(&$@;&EN:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O:61E
M;G1I='ES96QE8W0N:6YC.CDT"FUS9VED(")#<F5A=&4@82!N97<@;VYE(@IM
M<V=S='(@(I!6BTN-[)"L(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C-#,Q-"YP:'`Z-3(*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.3(*;7-G:60@(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R
M("*#5(-U@W2#2(.+@U^"\(WLD*PB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C(T,`IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*;7-G
M<W1R("*-[)"LCM*"S(-!@TZ#6H-8C*`B"@HC(&US9W-T<B`BC>R0K([2@LR5
MVXSLD-V2Z"(*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(P.0IM<V=I
M9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(H-.@XR#5X-B@V>#2H%;
M@VB4U(V&(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B
M@TZ#C8-!@V"#08NDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS
M9W-T<B`B@TR#A8%;@V^+I)AAC9$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,C8*;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5S<VEO;G,N<&AP.C4P"FUS9VED(")#=7)R96YT(%-E<W-I;VYS(@IM
M<V=S='(@(HR[C=V"S(-:@V*#5H.'@Y,B"@HC.B!L:6(O0FQO8VLO=&EM92YP
M:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E;G0@5&EM
M92(*;7-G<W1R("*,NXW=@LR.GHK4(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4T"FUS9VED(")#=7)R96YT
M(%523"!I<R(*;7-G<W1R("*,NXW=@LP@55),((+-(@H*(SH@861M:6XO<V5S
M<VEO;G,N<&AP.C,U"FUS9VED(")#=7)R96YT(%5S97)S(@IM<V=S='(@(HR[
MC=V"S(.&@5N#58%;(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I
M9"`B0W5R<F5N="!796%T:&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-C0*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N
M.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$Q"B,L('!H<"UF;W)M870*
M;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E
M<RXB"FUS9W-T<B`B)7,@@M:"S(.-@T^#28.3CIZ"R8[`C7."MX+I@UZ#6(-.
M@O"0W9+H@K6"W(*W@4(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*;7-G<W1R("*0
MV(+HCN:"Z"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I;VXB"FUS9W-T<B`BD4F1\)3-
MB,V"\)#8@NB.YH+H(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S(@IM<V=S
M='(@(H-,@W:#C8-8BZ2888V1(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#4*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@V"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W
M<RTQ,C4Q*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M-PIM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@
M(H-@@T:#4HNDF&&-D2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-3(@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@
M(D1$(@IM<V=S='(@(I/Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S(V.0IM<V=I9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M
M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R("*6B)/Z(@H*(SH@861M
M:6XO9&%T871R964N<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM
M<V=S='(@(D1A=&%4<F5E((E[EY<B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,C8W"FUS9VED(")$871A8F%S92!,;V]K=7`B"FUS9W-T<B`B@V:!
M6X->@WB!6X-8CE&/QB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y-0IM
M<V=I9"`B1&%T92(*;7-G<W1R("*3^I5T(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G:60@(D1A=&4@4F5C96EV960B"FUS
M9W-T<B`B@V:!6X->CO.032(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(W.#8*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM<V=S='(@(I/ZE72129'P
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X,2!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Q"FUS9VED(")$87DB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,V"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G<W1R(")?3)?Q
M@LR-[8^<(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0Q,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#4Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(C$RC(XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V
M"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`BCUR0:9"4(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I
M9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S='(@(I)IB;J"L(+PD/."K2(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3@W(&QI8B]P<F5F<RYP
M:'`Z,3$W"FUS9VED(")$969A=6QT(@IM<V=S='(@(H-F@W2#2(.+@V<B"@HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT-0HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHW-PIM
M<V=I9"`B1&5F875L="!#;VQO<B(*;7-G<W1R("*#9H-T@TB#BX-GD$8B"@HC
M.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.CDV"FUS9VED(")$
M969A=6QT($ED96YT:71Y(@IM<V=S='(@(H-F@W2#2(.+@V<@240B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-C<*;7-G:60@(D1E9F%U;'0@4VAE;&PB
M"FUS9W-T<B`B@V:#=(-(@XN#9R!S:&5L;"(*"B,@;7-G<W1R("*#9H-T@TB#
MBX-GBY:)PI#=DN@B"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,PIM<V=I
M9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HW,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q
M-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,"!T96UP;&%T97,O
M861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S='(@
M(HWMCYPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S(*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S='(@(H-:
M@XN-[8^<(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S
M+G!H<#HR,C<*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R("*#3X.+@5N#
M=H+PC>V/G"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T.0IM
M<V=I9"`B1&5L971E($QO9R(*;7-G<W1R("*#C8-/@LR-[8^<(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-R!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C$P,0IM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS
M9W-T<B`B@T&#3H-:@UB,H(+PC>V/G"(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E
M(&UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3<*;7-G:60@(D1E;&5T92!C96QL
M(@IM<V=S='(@(H-:@XN-[8^<(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E(&-O;'5M
M;B(*;7-G<W1R("*7\8+,C>V/G"(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M,30X"FUS9VED(")$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E
M(@IM<V=S='(@(I'CD=:#98.3@W:#C(%;@V>"S(WMCYPB"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU-`IM<V=I9"`B1&5L971E
M(&UE<W-A9V5S(@IM<V=S='(@(H.!@V*#6H%;@U>"\(WMCYPB"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R(")<
M(B5S7"(@@LR#08-.@UJ#6(R@@O"-[8^<(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E
M('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES<VEO
M;G,_(@IM<V=S='(@(EPB)7-<(B""S(-!@TZ#6H-8C*""QH*[@LR#5(-U@T&#
M3H-:@UB,H(+PD5."Q(WMCYR"M8+<@K>"J8%((@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L
M971E(')O=R(*;7-G<W1R("*-<X+,C>V/G"(*"B,Z('1E;7!L871E<R]P<F5F
M<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S96QE8W1E
M9"!I9&5N=&ET>2(*;7-G<W1R("*129'P@K6"O4E$@O"-[8^<(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3,*;7-G:60@(D1E
M;&5T92!S=6(@9F]L9&5R<R(*;7-G<W1R("*#5(-U@W2#2(.+@U^"\(WMCYPB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS
M9W-T<B`BC+N-W8C*DG6"S)?Q@O"-[8^<(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED(")$96QE
M=&4@=&AE(&-U<G)E;G0@<F]W(@IM<V=S='(@(HR[C=V(RI)U@LR-<X+PC>V/
MG"(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,V"B,L('!H<"UF;W)M
M870*;7-G:60@(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB
M+B(*;7-G<W1R("*0W9+HC5B05I=P@UB#3H.*@W:#9R!<(B5S7"(@@O"-[8^<
M@K6"W(*U@KV!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-38S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(R,0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*;7-G:60@(D1E;&EV97)Y('1I
M;64B"FUS9W-T<B`BE'J1EXZ>BM0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$96YM
M87)K(@IM<V=S='(@(H-F@Y.#?8%;@TXB"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB
M"FUS9W-T<B`BC^&*49/@EV6"S)#@EKXB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HY,S4@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`BD."6
MOB(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,C`V"FUS9VED(")$
M971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@(H_:
MC=>!:4AO<F1E@LR#C8-/@W2#0(-#@XN"X(Y1C\:!:H%&(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HR,3`*;7-G:60@(D1E=&%I;',@:&%V92!B
M965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(H_:
MC=>"S8K'EYV.TH+,@KV"WX+)BTR87H*S@NJ"W(*U@KV!0B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR,C$*;7-G:60@(D1E=F5L;W!M96YT(@IM
M<V=S='(@(HI*E*TB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-`IM<V=I
M9"`B1&5W(%!O:6YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S`Q"FUS9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*;7-G
M:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L
M969T('1O(')I9VAT(@IM<V=S='(@(HVV@JF"YXE%@M8B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E
M8W1I;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R("*)18*I@N>-MH+6(@H*(SH@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<P"FUS9VED(")$
M:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@(C(TCIZ*U)5<CJ8B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`P"FUS9VED(")$:7-P;&%Y($]P
M=&EO;G,B"FUS9W-T<B`BE5R.IH-)@W:#5H.'@Y,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z.#D*;7-G:60@(D1I<W!L87D@9&5T86EL960@
M9F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HY
M,@IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-SDV"FUS9VED(")$:7-P;&%Y
M(&9O<FUA="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$
M3BYP:'`Z,3DQ"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B
M@U>#=8-@BZ2888V1(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HT,C(*;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T<B`BC>V/G(*U@LB"
MHB(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR-0IM<V=I9"`B1&\@
M;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'`B"FUS9W-T<B`B
M;6%I;G1E;F%N8V4N<&AP((+)DKR0VH-!@TZ#6H-8@K6"R(*B@L6"K8*^@K."
MHB(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$R('1E;7!L871E
M<R]D871A+V-S=FEN9F\N:6YC.C$R"FUS9VED(")$;V5S('1H92!F:7)S="!R
M;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI
M<R!B;W@Z(@IM<V=S='(@(HW%CXF"S)?Q@JJ#=(-"@5N#BX-HEKR"\(K<@O&"
MQ8*B@MR"MX*I/R""NX*D@LB"YX-@@T:#8H-.@K6"Q(*M@KZ"LX*B@48B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R("*#:(-^@VJ#2B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S`*;7-G:60@(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R
M("*#:(-^@VJ#2HNDF&&-D2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB
M"FUS9W-T<B`B@T&#2H-%@Y.#9X*JE4N7=H+(@N>#5(-#@Y.#08-B@W:!0B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@U,0IM<V=I
M9"`B1&]W;FQO860B"FUS9W-T<B`B@U^#18.3@XV!6X-H(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#4Q"B,L('!H<"UF;W)M870*
M;7-G:60@(D1O=VYL;V%D("5S(@IM<V=S='(@(B5S((+,@U^#18.3@XV!6X-H
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO
M860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS
M9W-T<B`BD+:0K(*S@NJ"O9#=DNB"\"!02%`@@UB#3H.*@W:#9X+P@L:"M8+$
M@U^#18.3@XV!6X-H@K>"Z8%"(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$P-`IM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G
M:60@(D4M36%I;"(*;7-G<W1R("*39(YQ@X&!6X.+(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL
M+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R
M;W9I9&4@=&AI<R!S97)V:6-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP
M.C,T"FUS9VED(")%4E(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B
M16-U861O<B(*;7-G<W1R("*#1X-.@T&#:(.+BZ2888V1(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHS-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,34@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C<R"FUS9VED(")%9&ET(@IM<V=S='(@(I72CU<B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4P"FUS9VED(")%9&ET
M($)L;V-K(@IM<V=S='(@(H-U@XV#8H-.@LR5TH]7(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H<#HR,C8*;7-G:60@(D5D:70@
M1W)O=7`B"FUS9W-T<B`B@T^#BX%;@W:"S)72CU<B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C<V(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,3`P"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`B@T&#
M3H-:@UB,H(+,E=*/5R(*"B,@;7-G<W1R("*+EHG"D-V2Z(+,E=*/5R(*(SH@
M<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B161I="!097)M
M:7-S:6]N<R(*;7-G<W1R("*#08-.@UJ#6(R@@LR5TH]7(@H*(R!M<V=S='(@
M(HN6B<*0W9+H@LR5TH]7(@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z
M,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R
M("5S(@IM<V=S='(@(B5S((+,@T&#3H-:@UB,H(+,E=*/5R(*"B,@;7-G<W1R
M("(E<R""S(N6B<*0W9+H@LR5TH]7(@HC.B!T96UP;&%T97,O<')E9G,O87!P
M+FEN8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R("*#28-V
M@U:#AX.3@LR5TH]7@48B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS
M(&9O<B!<(B5S7"(B"FUS9W-T<B`B7"(E<UPB((+,@T&#3H-:@UB,H(+,E=*/
M5R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B
M)7,@@LR#08-.@UJ#6(R@@LR5TH]7(@H*(R!M<V=S='(@(B5S((+,BY:)PI#=
MDNB"S)72CU<B"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0IM<V=I9"`B
M161U8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T
M(@IM<V=S='(@(H-'@U>#=H-G@46#08.)@W6+I)AAC9$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@(H-'@XN#5(.+@V^#:(.+
MBZ2888V1(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y
M"FUS9VED(")%;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,C(T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X-C8*;7-G:60@(D5M86EL(@IM<V=S='(@(I-DCG&#@8%;@XLB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V5D:70N:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z-C@*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T
M<B`B18.!@5N#BX-!@VB#C(-8(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3DV,`IM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM
M<V=S='(@(D6#@8%;@XN#08-H@XR#6(*JB.J2=H*U@LB"KX+J@LZ"HH*O@MR"
MN8+Q@4(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3@V"FUS9VED
M(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")%@X&!6X.+@T&#
M:(.,@UB*;91&(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?
M<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E=V%Y(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR.3D*;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*;7-G:60@
M(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(HOS@X&#8H-:@5N#5X+%@K>!0B(*
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR-#,@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0X-`HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z-C8R(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HW,#4*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ
M-3`*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`BB;V"X(RI@L*"J8+H
M@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z
M,3$S"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`BB_."S(R?
MC?6,ZB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#<*;7-G:60@(D5N
M86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S
M(&EN('1E>'0_(@IM<V=S='(@(H--@X.#B8.*@5N"J8+GB>:1G(+PD7V3_(+%
M@JN"Z8+F@J2"R8*U@MR"MX*I@4@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3(R"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU
M/R(*;7-G<W1R("*)18-.@XJ#8H-.@L6#@8-J@X6!6X+PE5R.IH*U@MR"MX*I
M@4@B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3@U(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(W.3`*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@(H-'@V:#0H->@5N)
MYI;*@O"1Y8*K@JTB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(T"FUS
M9VED("(B"B)%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W
M:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S
M<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB
M"FUS9W-T<B`B(@HB@J""R(*]@LR#<(-8@X^!6X-H@O"#BH-:@V*#9X*W@NF.
MGH+,EW"04X+,@KV"WX+,CK^6XH+PD_R7S8%"E^&"IH+.@4&!=8-Y@V*#9R(*
M(H+,EKR13X+-@4B!=H%&(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@
M:6UA9V4@55),(&AE<F4B"FUS9W-T<B`BB>:1G(+,55),@O"3_)?-(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Y,@IM<V=I
M9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(I#4D[F#
M38-J@T&+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%<FET<F5A(@IM<V=S
M='(@(H-'@XJ#9X.*@T$B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70O5FEE=RYP:'`Z.30@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C0X"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S8*
M;7-G:60@(D5R<F]R(@IM<V=S='(@(H-'@XF!6R(*"B,Z(&9R86UE=V]R:R]4
M96UP;&%T92]496UP;&%T92YP:'`Z-#8S"B,L('!H<"UF;W)M870*;7-G:60@
M(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R("*#=8.-@V*#3HWL
MD*R#1X.)@5LZ("5S+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C<R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@
M86YC:&]R.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN
M9R!S>6YC(&QO9SH@)7,B"FUS9W-T<B`BDZ^*^H.-@T^"S(WMCYR#1X.)@5LZ
M("5S+B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8X
M"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@
M)7,B"FUS9W-T<B`BD^"798[FD[Z#1X.)@5LZ("5S+B(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`B@W"#6(./@5N#
M:(U8D%:#1X.)@5LZ("5S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET:"!E;6%I
M;"!M97-S86=E+B(*;7-G<W1R("*#@8%;@XN#08-H@XR#6(+,@T>#B8%;@L6"
MMX%"(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB((+,
MCY&"JXV>@MV#1X.)@5N"Q8*W@4(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%<W1O
M;FEA(@IM<V=S='(@(H-'@UB#9X-J@T&+I)AAC9$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS
M9VED(")%=&AI;W!I82(*;7-G<W1R("*#1X-@@TF#<X-!(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%=7)O
M<&4B"FUS9W-T<B`B@XB!6X.-@V*#<"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-#,*;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`B,365
MJI:((@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,PIM<V=I9"`B179E
M<GD@,B!M:6YU=&5S(@IM<V=S='(@(C*5JI:((@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,T,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED
M(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(C,PE:J6B"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-#(@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y
M-`IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(C65JI:((@H*(SH@
M9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I
M9"`B179E<GD@3&]G:6XB"FUS9W-T<B`B@XV#3X-#@Y.6B"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-#0*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*
M;7-G<W1R("(S,)6JEH@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3(*;7-G:60@(D5V97)Y(&UI;G5T
M92(*;7-G<W1R("(QE:J6B"(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N
M:6YC.C(T"FUS9VED(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`BCG>2Z))L
M@LR7X2(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HX,B!A9&UI;B]C;61S:&5L
M;"YP:'`Z-3$@861M:6XO<W%L<VAE;&PN<&AP.C$R.`IM<V=I9"`B17AE8W5T
M92(*;7-G<W1R("*.P(US(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HV,30*;7-G:60@(D5X<&%N9"(*;7-G<W1R("*3
M5XI*(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHS,@IM<V=I
M9"`B17AP86YD(%-I9&5B87(B"FUS9W-T<B`B@U2#0X-H@V^!6X+PDU>*2B(*
M"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@
M(D5X<&5C=&5D("<I)R(*;7-G<W1R("(G*2<@@O"35XI*(@H*(SH@9G)A;65W
M;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP96-T960@
M8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(D5X
M<&ER871I;VX@1&%T92(*;7-G<W1R("*73(SXBOJ,P"(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<W"FUS9VED(")%>'!O;F5N="(*
M;7-G<W1R("*.=Y"4(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B
MD4^,:9!&(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I9"`B
M1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R("*0W9+H@O`@1E10((+%@T&#
M8H-V@XV!6X-H@K>"Z2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S<6PN
M<&AP.C(R,`IM<V=I9"`B1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N
M(@IM<V=S='(@(H-V@XR#=(-`@XR#DX-8D-V2Z(+PCN:3OH+%@JN"W(*Y@O&!
M0B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW-2!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.CDX"FUS9VED(")&86EL960@=&\@
M8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3$1!4""#5(%;@V^"
MR9#:D;&"Q8*K@MR"N8+Q@L6"M8*]@4(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W-M8BYP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--
M0B!S97)V97(N(@IM<V=S='(@(E--0B"#5(%;@V^"R9#:D;&"Q8*K@MR"N8+Q
M@L6"M8*]@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<Q-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<
M(BXB"FUS9W-T<B`B7"(E<UPB((*I@N>"S(-2@W.!6X+)CKB4<X*U@MR"M8*]
M@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S
M='(@(EPB)7-<(B""UH+,@U*#<X%;@LF.N)1S@K6"W(*U@KV!0B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#<*;7-G:60@(D9A:6QE9"!T
M;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`BD%:+2X+,
M(%-!4TP@D-J1L8+)CKB4<X*U@MR"M8*]@4(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C4P,2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S
M7"(N(@IM<V=S='(@(EPB)7-<(B""UH+,B-J3KH+)CKB4<X*U@MR"M8*]@4(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&86EL960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(H[F
MD[Z"R8ZXE'."M8+<@K6"O8%&)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<R"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB
M"FUS9W-T<B`B@W2#2(%;@TZ#B8.3@VB/E).'@6F#?8.+@W*#:8-8CY23AX%J
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R("*#
M=(-&@XV!6X^4DX<B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C,X"FUS
M9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`BDG:6O9-)@T>#B8%;@48B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W"FUS
M9VED(")&87@B"FUS9W-T<B`B1D%8(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,U,0IM<V=I9"`B1F%X97,B"FUS9W-T<B`B1D%8(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,PHC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@(D9E
M8G)U87)Y(@IM<V=S='(@(H)1C(XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(R-PIM<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(P"FUS9VED(")&965L<R!L:6ME.B`B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS9VED(")&
M97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Y-#$*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(R"FUS9VED(")&:6=L
M970@0T%05$-(02(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,S(V"FUS9VED(")&:6=L970@9F]N="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@(H-T@T*#5X%;CY23AXNDF&&-
MD2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B
M1FEL92(*;7-G<W1R("*#=(-`@T.#BR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S
M(&9I;&4B"FUS9W-T<B`B@W2#0(-#@XN0E#H@)7,@@W2#0(-#@XLB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R("*#=(-`@T.#BY"4.B`E
M<R"#=(-`@T.#BR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#D*
M;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R("*#=(-`@T.#BX-]@VR!6X-7
M@X,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8S
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,@IM<V=I9"`B1FEL
M92!.86UE(@IM<V=S='(@(H-T@T"#0X.+EKPB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.3<T"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R
M("*#=(-`@T.#BY%)D?`B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#@S"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R("*#=(-`@T.#BX-!@V*#
M=H.-@5N#:"(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDP
M,@IM<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM<V=S='(@
M(H-T@T"#0X.+@T&#8H-V@XV!6X-H@LV#5(-\@5N#9X*S@NJ"Q(*B@MR"N8+Q
M@4(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3$*;7-G:60@(D9I
M;'1E<G,B"FUS9W-T<B`B@W2#0H.+@UXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")&
M:6YL86YD(@IM<V=S='(@(H-T@T*#DX.)@Y.#:(NDF&&-D2(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H
M<#HW-@IM<V=I9"`B1FER<W0@475A<G1E<B(*;7-G<W1R("*/XXRW@LR,CB(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-3<*
M;7-G:60@(D9I>"!R871I;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,R"FUS9VED(")&;&EP(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED(")&;V<B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR,S<@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$P-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B@W2#
M2(.+@U^!6R`E<R""JH*@@NB"W(*Y@O$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(R"FUS9VED(")&;VYT($-O;&]R(@IM
M<V=S='(@(I6VCIJ01B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM
M<V=I9"`B1F]O9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$R,PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C8*;7-G:60@(D9O<B!B
M<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@(HGF
MD9R"\(-4@WR!6X-G@K6"R(*B@W6#B8-%@U67<"(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S0Q"FUS9VED(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S(*;7-G:60@(B(*
M(D9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A
M<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M
M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,#(*;7-G:60@
M(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R("*#<(-8@X^!6X-H@O"6
M68+J@L2"M8+<@J*"W(*U@KV"J8%((@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0V-`IM<V=I9"`B1F]R;7,B"FUS9W-T<B`B@W2#2(%;@X`B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*;7-G:60@(D9O<G1U;F4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED(")&
M;W)T=6YE('1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,X"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U-0IM<V=I9"`B1F]R
M=6US(@IM<V=S='(@(H-T@TB!6X.)@X`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3$Q"FUS9VED(")&;W)W87)D<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED
M(")&<B(*;7-G<W1R("*+X"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*;7-G:60@(D9R86UE<R(*;7-G<W1R
M("*89R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92(*;7-G<W1R("*#=(.)
M@Y.#6(NDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,PIM<V=I9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B@W2#B8.3
M@UB!:99[C9&!:B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D9R96YC:"!'=6EA;F$B
M"FUS9W-T<B`B@W2#B8.3@UB7S(--@T&#:2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED
M(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(H-T@XF#DX-8E\R#?(.*@VR#
M5H-!(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R
M<FET;W)I97,B"FUS9W-T<B`B@W2#B8.3@UB7S(O)D^R/E).'(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-`IM<V=I9"`B
M1G)O;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C,W(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-#D*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y-0IM<V=I9"`B1G)O;2!T:&4@
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C0X"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(H_:@K6"HI#@
MEKXB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K+VUO;VXN
M<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(I:>C(XB"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHV,`IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(HZ!EKPB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<S"FUS9VED(")'86)O;B(*;7-G<W1R("*#2X-[@Y.+I)AA
MC9$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F
M<F]M(@IM<V=S='(@(HGFD9R"\([F@NB/;X*W@TV#@X.)@XJ!6R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B@TV#@X.)@XJ!6X%&(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-0IM<V=I9"`B1V%M8FEA(@IM<V=S='(@(H-+@Y.#<H-!BZ28
M88V1(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@
M(B5S((U<D*R/[I7Q@O"0MI"L@K>"Z2(*"B,Z('1E;7!L871E<R]A9&UI;B]S
M971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G
M<W1R("*0MI"L@K."ZH*]@U*!6X-H(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1V5O
M<F=I82(*;7-G<W1R("*#3X.+@U>#08NDF&&-D2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G
M:60@(D=E<FUA;GDB"FUS9W-T<B`B@VB#0X-CF$&638NDF&&-D2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S4*;7-G:60@(D=H86YA(@IM<V=S='(@(H-+@5N#:8NDF&&-D2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.30@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R("*#5X-U@XF#BX->
M@XLB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-@IM
M<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R("*0J2(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S:61E8F%R+G!H<#HQ-S4@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z
M,3`*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3D*;7-G:60@(D=L;V)A
M;"!/<'1I;VYS(@IM<V=S='(@(HNDDLJ#28-V@U:#AX.3(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V%P<"YI;F,Z,3<*;7-G:60@(D=O(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,`IM<V=I9"`B1V]E9&5L(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,3,Q"FUS9VED(")';V]G;&4@36%P<R(*;7-G<W1R(")';V]G;&4@@WV#
M8H-V(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O
M9VQE(%-E87)C:"(*;7-G<W1R(")';V]G;&4@C)^-]2(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S@*;7-G:60@(D=R87ES
M8V%L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W)E96-E(@IM
M<V=S='(@(H--@XJ#5H.#BZ2888V1(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#@*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDU(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<U"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B@T^#BH%;@Y.#
MB8.3@V@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'<F5N861A(@IM<V=S='(@(H-/
M@XR#:8-?(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-SD*;7-G:60@(D=R;W5P
M($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(H-/@XN!6X-VBL>7G2(*"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"YP:'`Z-3D@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C$V.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N
M;VXM96UP='DB"FUS9W-T<B`B@T^#BX%;@W:6O(+-B_.4DH+%@LV"R(*B@K&"
MQB(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G
M<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S
M='(@(D=R;W5P7VQD87`Z((-/@XN!6X-V("5S((+PDL>)P8+%@JN"W(*Y@O&!
M0H-4@5N#;X+,B9Z3FCH@(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C$Q."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3(T
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT,3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G
M<F]U<"`E<R(*;7-G<W1R(")'<F]U<%]L9&%P.B"#3X.+@5N#=B`E<R""\(WM
MCYR"Q8*K@MR"N8+Q(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C,S."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L
M('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A
M=&4@9W)O=7`@)7,B"FUS9W-T<B`B1W)O=7!?;&1A<#H@@T^#BX%;@W8@)7,@
M@O"-6)!6@L6"JX+<@KF"\2(*"B,@;7-G<W1R("*#3X.+@5N#=HN6B<*0W9+H
M(@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,Q-"!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(H-/@XN!6X-V(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-@IM<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R("*#3X-!@VB#BX%;@W:3
MAR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(H-/@T&#@).'
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R("*#3X-!
M@V6#?8.)BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B@TN!6X.3@U>!6Y.'(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS
M9W-T<B`B@U&#6(-G@T&#3H-:@UB,H"(*"B,@;7-G<W1R("*#48-8@V>+EHG"
MD-V2Z"(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W,@IM<V=I9"`B
M1W5E<W1B;V]K(@IM<V=S='(@(H-1@UB#9X-U@V*#3B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*
M;7-G:60@(D=U:6YE82(*;7-G<W1R("*#38-J@T&+I)AAC9$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S@*;7-G:60@(D=U:6YE82U":7-S874B"FUS9W-T<B`B@TV#:H-!@W*#
M5(-%BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=7EA;F$B"FUS9W-T
M<B`B@TN#0X-!@VF+I).OBZ2888V1(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.34W"FUS9VED(")(5$U,(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G:60@
M(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T
M(&-E;&P@:6X@<F]W+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS9VED(")(5$U,07)E
M82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@
M:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A(&-O
M=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H
M<#HQ-3<*;7-G:60@(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")(5%10()1&C]B"JH+=@L*"J8+H@MR"N8+Q@4(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#`*;7-G:60@(DAA:71I(@IM<V=S='(@(H-N@T.#8(NDF&&-D2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S
M:"U!;&=O<FET:&TB"FUS9W-T<B`B@VZ#8H-6@X6#08.+@U.#BH-9@X`B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@IM<V=I
M9"`B2&%Z92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HY,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDQ,0IM<V=I9"`B2&5A
M9&5R(@IM<V=S='(@(H-W@V*#7R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO
M5'EP92]T86)L97-E="YP:'`Z-C$*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B
M@W>#8H-?(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@86YD
M($UC1&]N86QD($ES;&%N9',B"FUS9W-T<B`B@VZ!6X-H@46#?8-.@VB#:8.+
M@VB/E).'(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C,*;7-G:60@(DAE879Y(%0M4W1O<FTB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DAE8G)E=R`H25-/+3@X-3DM
M."U)*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HR,B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T
M"FUS9VED(")(96EG:'0B"FUS9W-T<B`BC8*"LR(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92](96QP+G!H<#HQ.#0@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+TAE;'`N<&AP.C$X-@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ-R!T
M96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z-`IM<V=I9"`B2&5L<"(*;7-G<W1R
M("*#=X.+@W8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8X"FUS9VED(")(96QP
M97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED
M(")(96UI<W!H97)E(@IM<V=S='(@(I2\BX4B"@HC.B!T96UP;&%T97,O9&%T
M82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ
M,`IM<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HW,0IM<V=I9"`B2&EG:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<&]R=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D
M97(N:6YC.C4*;7-G:60@(DAO7VUE(@IM<V=S='(@(H-Z@5N#@"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I
M(@IM<V=S='(@(H.-@5N#?99`B:22H8%I@V^#8(-*@Y..<XV1@6HB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U-#@*;7-G:60@(DAO;64B"FUS
M9W-T<B`B@WJ!6X.`(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$R,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,34U"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`BCJF1
M[H+,CUJ/BB(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-`IM<V=I9"`B
M2&]M92!$:7)E8W1O<GDB"FUS9W-T<B`B@WJ!6X.`@V:#0H.,@TZ#9X.*@5LB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP
M"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(HZID>Z"S)-DF&*4U(V&(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R("*#>H.3@U>#
MA8.)@UB+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N9R(*
M;7-G<W1R("*-@8U@(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8W
M"FUS9VED(")(;W)D92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z-#4R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE
M<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z()5SD+."R"!834P@@V:!
M6X->("5S((*J@X&#8H-:@5N#5R`E<R""Q8R?CV^"LX+J@MR"M8*](@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR.3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@
M;V)J96-T("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B"#28-U@U>#1H-.@V<@
M)7,@@LF1SHF>@K>"Z8.!@V*#6H%;@U>"S8*@@NB"W(*Y@O$B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C0T-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@
M;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@@TF#=8-7@T:#3H-G
MC%X@)7,@@LV#@8-B@UJ!6X-7("5S((+)@LV"H(+H@MR"N8+Q(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C4Q"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S
M7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(Z("5S((+-C>V/G(*S@NJ"W(*U@KT@
M7"(E<UPB(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR,C,*;7-G
M:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I
M<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N(@IM<V=S='(@(DAO<F1E
M+TMO;&%B.B!02%`@BF>2HR`G9&]M>&UL)R""JI5+EW:"Q8*W(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HU,3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E
M(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z((-)@W6#5X-&
M@TZ#9R`E<R""S"!834P@@V.#BH%;@JJ-[)"L@L6"JX+<@KF"\2(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(T.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z
M("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B`E<R""JHWMCYR"Q8*K@MR"N8+Q
M(%PB)7-<(CH@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0X
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O
M(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS
M9W-T<B`B2&]R9&4O2V]L86(Z("5S((+,($U)344@240@@JJ.YI.^@L6"JX+<
M@KF"\2(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$Y-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H
M<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z("5S
M((+&DZ^*^H+%@JN"W(*Y@O$@7"(E<UPB.B`E<R(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,3,S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS
M9W-T<B`B2&]R9&4O2V]L86(Z().OBOJ"Q8*K@MR"N8+Q@48E<R(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*;7-G<W1R
M(")(;W)D92]+;VQA8CH@7"(E<UPB((+-E7.6OH+(BZ273(+%@K<B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(T"FUS9VED
M(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`BD(65O9#\(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM<V=I9"`B2&]R
M:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T(&AE
M<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B
M2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS
M9W-T<B`B@J*"K8+"@LR7\8+PC(N-AX*U@MR"MX*I@4@B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9I;F9O+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S
M("AC;VQU;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@(H-T@T*!6X.+@V@HC7,I
M@LR0E(+-@J*"K8+"@L6"MX*I@4@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N>2!R
M;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R("*"HH*M@L*"
MS(US@O",BXV'@K6"W(*W@JF!2"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR.#D@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S<*;7-G:60@(DAU
M;6ED:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-#@*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED(")(=6UO<FES=',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(=6YG87)Y(@IM<V=S='(@(H-N
M@Y.#2X.*@5N+I)AAC9$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S
M+G!H<#HQ-S(@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(S-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I
M;&5D.B`E<R(*;7-G<W1R("))34%0((.!@5N#BX-[@V*#3H-8@LR-[)"L@LF.
MN)1S@K6"W(*U@KTZ("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U
M<RYP:'`Z,C$T(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR.34*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A
M:6QE9#H@)7,B"FUS9W-T<B`B24U!4""#@8%;@XN#>X-B@TZ#6(+,C>V/G(+)
MCKB4<X*U@MR"M8*].B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M=7,N<&AP.C$W.2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C0R
M"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A
M=&EO;B!F86EL960Z("5S(@IM<V=S='(@(DE-05`@@X&!6X.+@WN#8H-.@UB#
M3H-(@5N#7H+,C>R0K(+)CKB4<X*U@MR"M8*].B`E<R(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S,3,*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T
M<B`B25`@@T&#:(.,@U@B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S
M:6,N<&AP.C<W"FUS9VED("))4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(DE0((-!@VB#C(-8@JJ"H(+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R97-S
M(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("))4(-!
M@VB#C(-8@JJ+EHG"@K."ZH*]0TE$4H-U@XV#8H-.D^""R8*@@NB"W(*Y@O&!
M0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R
M("))4)65C;V(X92]@L6"MX%"(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED("))7VYS97)T(%)O
M=R!"969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))8V5L
M86YD(@IM<V=S='(@(H-!@T.#6(.)@Y.#:(NDF&&-D2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.#`*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B
M@T&#0X-2@Y."S(+=(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L
M('!H<"UF;W)M870*;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R("(E<R""
MS(-!@T.#4H.3(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,0IM<V=I
M9"`B26-O;G,@=VET:"!T97AT(@IM<V=S='(@(H-!@T.#4H.3@L:#98-,@UB#
M9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3,*;7-G:60@(DED96YT
M:71Y)W,@;F%M93HB"FUS9W-T<B`B242"S):\D4\B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P
M96X@:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R("*"X(*U@N"0LX*U@JV5
M7(ZF@K."ZH+(@J*"R(+G@4$E<R""M8+$D%:"M8*B@T6#0X.3@VB!6X+PBDJ"
MHH+$B;J"LX*B@4(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4Y"FUS
M9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E
M<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@
M8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*
M(H+@@K6"X"!);G1E<FYE="!%>'!L;W)E<B""\(YG@L&"Q(*B@L2!08-!@T.#
M4H.3@JJ57(ZF@K."ZH+(@J*"R(+G@4&"L8*Q@O"129'P(@HB@K6"Q(FZ@K."
MHH%"(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$W,@IM<V=I9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO
M(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E
M("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR.`IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T<B`BB>:1G(-V
M@XR#<H.%@5LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,W"FUS9VED("));6%G92!54DPB"FUS9W-T<B`BB>:1
MG"!54DPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM86=E(%523#HB"FUS9W-T<B`B
MB>:1G"!54DPZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE
M<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A
M;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$W-3@*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(HGF
MD9PB"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW('1E;7!L871E
M<R]D871A+V1A=&5M87`N:6YC.C<*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHU-"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW"B,L('!H<"UF
M;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("*#0X.3@WR!
M6X-G@4&#6(-E@V*#=B`E9"(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N
M:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E
M<R(*;7-G<W1R("*#0X.3@WR!6X-G@K."ZH*]@W2#0H%;@XN#:(%&("5S(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T
M960@9FEE;&1S.B(*;7-G<W1R("*#0X.3@WR!6X-G@K."ZH*]@W2#0H%;@XN#
M:(%&(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,P"FUS9VED("));E]S97)T(%)O=R!!9G1E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ
M,S0*;7-G:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T
M<B`BBM2(X8+!@KV#08-.@U:#AX.3@U*!6X-H@JJ77H*F@N>"ZH+$@J*"W(*W
M@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S,@IM<V=I9"`B26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S
M=V]R9"XB"FUS9W-T<B`B@X:!6X-5EKR"J8-P@UB#CX%;@VB"JI"S@K6"K8*@
M@NB"W(*Y@O&!0B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q
M"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D
M9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M:6YI<W1R
M871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(H.&
M@5N#59:\@JF1XY'6@T&#:(.,@UB"JI"S@K6"K8*@@NB"W(*Y@O&!0HW$DWB.
MCH*U@L2"W8+I@JF!08K'EYV.TH+)F$&7C8*U@L0B"B*)NH*S@J*!0B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*;7-G
M:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R("*2:8FZ@K""\)!;@JTB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#$*;7-G:60@(DEN9&EA(@IM<V=S='(@(H-#@Y.#:"(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C4T('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3,T"FUS9VED("));F1I=FED=6%L(%5S97)S(@IM
M<V=S='(@(HS"E<J#AH%;@U4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DEN9&]N
M97-I82(*;7-G<W1R("*#0X.3@VB#;(-6@T&+I)AAC9$B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O
M(@IM<V=S='(@(H_NE?$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C4Y"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R("*#0X.3@W2#2(.!@5N#
M5H.'@Y,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Y"FUS
M9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S4*;7-G:60@(DEN<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S
M='(@(E]/C.."ZX+)E_&"\)%]D_PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G:60@(DEN<V5R
M="!);6%G92(*;7-G<W1R("*)YI&<@O"1?9/\(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I9"`B26YS97)T(%1A
M8FQE(@IM<V=S='(@(I5<@O"1?9/\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E8B!,:6YK
M(@IM<V=S='(@(H.*@Y.#3H+PD7V3_"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T
M(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(E]#D4^"R9?Q@O"1?9/\(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8V"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R
M96YT(&]N92(*;7-G<W1R("*,NXW=B,J2=8+,C.."ZX+)E_&"\)%]D_PB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C
M=7)R96YT(&]N92(*;7-G<W1R("*,NXW=B,J2=8+,D4^"R9?Q@O"1?9/\(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8R"FUS9VED("));G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R
M96YT(&]N92(*;7-G<W1R("*,NXW=B,J2=8+,C.."ZX+)C7."\)%]D_PB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R
M96YT(&]N92(*;7-G<W1R("*,NXW=B,J2=8+,D4^"R8US@O"1?9/\(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C<P"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E
M;G0@;F]D92(*;7-G<W1R("*,NXW=B,J2=8+,C.."ZX+)DFF7CH+PD7V3_"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@
M8W5R<F5N="!N;V1E(@IM<V=S='(@(HR[C=V(RI)U@LR13X+)DFF7CH+PD7V3
M_"(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS9VED("));G-E<G0@
M86QT97)N871E('1E;7!L871E(@IM<V=S='(@(I'CD=:#98.3@W:#C(%;@V>"
MS)%]D_PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0R"FUS9VED("))
M;G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I
M=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`BD%:"M8*B@W"#6(./@5N#
M:(+PCO."KX[F@NF#@8%;@XN#08-H@XR#6(+PD_R7S8%&(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`IM<V=I
M9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T<B`BC.."ZX+)@UJ#BX+PD7V3
M_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3D*;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R("*1
M3X+)@UJ#BX+PD7V3_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU;6X@869T
M97(B"FUS9W-T<B`BC.."ZX+)E_&"\)%]D_PB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U"FUS9VED("));G-E
M<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R("*13X+)@UJ#BX+PD7V3_"(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4P"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED("))
M;G-E<G0@;65S<V%G97,B"FUS9W-T<B`B@X&#8H-:@5N#5X+PD7V3_"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT-0IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R("*,
MXX+K@LF2:9>.@O"1?9/\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED("));G-E<G0@<&%R86=R
M87!H(&)E9F]R92(*;7-G<W1R("*13X+)DFF7CH+PD7V3_"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*;7-G
M:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`BC.."ZX+)C7."\)%]D_PB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E9F]R92(*;7-G<W1R("*13X+)
MC7."\)%]D_PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,S"FUS9VED
M("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@
M<75E<W1I;VXZ(@IM<V=S='(@(I=PD%."S(*]@M^"S(Z_EN*"S).:@J:"\)/\
ME\V!1B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`BB>:1
MG(+,D7V3_(%>E<^-6"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*;7-G
M<W1R("*#BH.3@TZ"S)%]D_R!7I7/C5@B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B26YS=69F:6-I
M96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="XB
M"FUS9W-T<B`BD9>039#F@LF1EX+I@KV"WX+,CF.-@H*JE7.1JX*U@L2"HH+<
M@K>!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,U"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R
M("*.8XV"@JJ5<Y&K@L6"MX%"(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3`W,@IM<V=I9"`B26YT96=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,3,P"FUS9VED("));G1E9V5R(&QI<W0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDW"FUS9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(
M96%D97(I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M
M<')E<W,O>FEP+G!H<#HQ-C<*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+WII<"YP:'`Z,3DT"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]Z:7`N<&AP.C(Q,@IM<V=I9"`B26YV86QI9"!:25`@9&%T82(*;7-G<W1R
M("*5<Y"S@L@@6FEP((-F@5N#7H+%@K>!0B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P;&EC871I;VXN(@IM<V=S
M='(@(I5SD+."R(-!@W:#BH-0@5N#5H.'@Y."Q8*W@4(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@
M(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(P.#0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U
M-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C(Y(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(R.38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E
M+W1A8FQE<V5T+G!H<#HS-PIM<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E
M9"XB"FUS9W-T<B`BEK.,^(+(@V:!6X->@JJ2\8]O@K."ZH+<@K6"O2XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB"FUS9W-T
M<B`BD9>"Z)#F@LR#08-H@XR#6(*JE7.0LX+%@K>!0B(*"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P.0HC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,SD*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,C0Q"FUS9VED("));G9A;&ED(&9I
M;&4@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-C4*;7-G:60@(DEN=F%L:60@;&EC96YS92!K97DN(@IM<V=S
M='(@(I5SD+."R(.)@T.#6H.3@UB#3(-#@L6"MX%"(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$U.0IM<V=I9"`B26YV86QI9"!L;V-A=&EO
M;B!P<F]V:61E9"XB"FUS9W-T<B`BE7.0LX+(C^J/BH*JCG>2Z(*S@NJ"W(*U
M@KV!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`S"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.38*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T
M97)S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z
M,C<*;7-G:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN(@IM<V=S='(@
M(H_CB,J"S(-!@TZ#6H-8C*""JI5SD+."Q8*W@4(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,38Q"FUS9VED("));G9A;&ED('!A<G1N97(@
M:60N(@IM<V=S='(@(I5SD+."R(-P@5N#9X-I@5M)1(+%@K>!0B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C,*;7-G:60@(DEN=F%L:60@
M<')O9'5C="!C;V1E+B(*;7-G<W1R("*5<Y"S@LB0NY5I@U*!6X-H@L6"MX%"
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`V"FUS9VED("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R("*5<Y"S
M@LB#=H.-@V>#4H.+@L6"MX%"(@H*(R`@<&AP+69O<FUA=`HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HX,`IM<V=I9"`B26YV86QI9"!R96-I
M<&EE;G0Z(%PB)7-<(B(*;7-G<W1R("*5<Y"S@LB.\Y!-CM*"Q8*W@49<(B5S
M7"(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$P.#`@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C8S"FUS9VED("));G9A;&ED('-H87)E
M(&]B:F5C="(*;7-G<W1R("*5<Y"S@LB+I)=,@TF#=8-7@T:#3H-G(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q
M"FUS9VED("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R("*5<Y"S
M@LB4K9!-C+.#08-H@XR#6(+%@K>!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0IM<V=I9"`B26YV86QI9"!U
M;FEC;V1E(&1A=&$N(@IM<V=S='(@(I5SD+."R'5N:6-O9&6#9H%;@UZ"Q8*W
M@4(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4Y"FUS9VED("))
M;G9E;G1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C8W.`IM<V=I9"`B26YV97)T('-E;&5C=&EO;B(*
M;7-G<W1R("*129'P@O"4O9-=(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))<F%N
M+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM<V=S='(@(H-#@XF#DX%%@T.#6(.)
M@X"+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DER87$B"FUS9W-T<B`B
M@T.#B8-.BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<F5L86YD(@IM
M<V=S='(@(H-!@T.#BX.)@Y.#:"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G<W1R("*#?8.3DX<B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM
M<V=I9"`B27-O;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,30@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@P"FUS9VED("))<W)A96PB"FUS9W-T<B`B@T.#6(.)@T>#BR(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C(V"FUS9VED("))<W-U
M97(B"FUS9W-T<B`BE*V-<X[2(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS9W-T<B`BCLZ1
MS"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B271A;'DB"FUS9W-T<B`B@T.#7H.*
M@T&+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS9W-T
M<B`B@U>#@X-]@T.#2B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y(@IM<V=S='(@(H)0C(XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#,*;7-G:60@(DIA<&%N(@IM<V=S='(@(I/ZEGLB"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B2F%P86YE<V4@*$E33RTR
M,#(R+4I0*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R,@IM<V=I9"`B2F5R<V5Y(@IM<V=S='(@(H-7@X.!6X-7@5N3AR(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F]R9&%N(@IM<V=S='(@(H.(@XN#7X.3
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*
M;7-G:60@(DIU;'DB"FUS9W-T<B`B@E:,CB(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#<*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S='(@
M(H)5C(XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S='(@(I&U@J:"Z2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$U"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R("*2AHF;D;6"
MIB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`BE[R26Y&U
M@J8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(HVVD;6"
MIB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$V"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(HE%D;6"
MIB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R("*#
M2H-5@W2#6(->@Y.+I)AAC9$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C8U"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G
M<W1R("*#28.*@U>#:8.+@O"5VY&V@4@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@
M(DME;GEA(@IM<V=S='(@(H-0@VJ#08NDF&&-D2(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R
M96IE8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B2V5R8F5R;W,@@U2!
M6X-O@JJ41H_8BY&4VX*U@MR"M8*]@4(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B:65S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y
M($-R96%T:6]N(@IM<V=S='(@(HRNC>R0K)/Z(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B
M"FUS9W-T<B`BC*Z.=Y;D(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N9W1H(@IM<V=S='(@(HRNDK<B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME
M>2!4>7!E(@IM<V=S='(@(HRNCNV7WB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DY"FUS9VED(")+97D@57-A9V4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S0P"FUS9VED
M(")+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N
M(@IM<V=S='(@(I-DCG&,KH*J@K>"Q8+)C/:/3XRN@U2!6X-O@LF1MHW=@K6"
MW(*W@4(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI
M9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+:7)I8F%T:2(*
M;7-G<W1R("*#3(.*@V^#6(NDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B
M2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T
M<B`BDJF13I:OCN6.Y8M@D&R6KXNDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I
M9"`B2V]R96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(I'EBMB6KXV1(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@(DMO<F5A;B`H155#+4M2
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G
M<W1R("*#3H-%@T:!6X-G(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+>7)G>7IS
M=&%N(@IM<V=S='(@(H-,@XN#38-8BZ2888V1(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]M96YU+FEN8SHX"FUS9VED("),85]Y;W5T(@IM<V=S='(@(E]9@XR#
M0X-!@T6#9R(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.#,*;7-G
M:60@(DQA;F=U86=E(@IM<V=S='(@(HR^C.HB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G
M:60@(DQA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@
M(H.)@TF#6)!LEJ^6KX[EBZ2888V1(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HW-@IM<V=I9"`B3&%S="!087-S=V]R9"!#:&%N9V4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@V(&QI8B]";&]C
M:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@(HFZ
MC+>"S(R.(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3@*;7-G:60@(DQA
M<W0@57!D871E9#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z-S$W"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S
M(@IM<V=S='(@(I%/B?&"S(.-@T^#0X.3.B`E<R(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO
M9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(I%/B?&"S(.-@T^#0X.3.B`E,B1S
M((*I@N<@)3$D<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q-`IM
M<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`BD4^)\8+,@XV#3X-#
M@Y,Z((+(@K4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQA='9I82(*;7-G<W1R
M("*#B8-G@W*#08NDF&&-D2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M-`IM<V=I9"`B3&%W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0IM<V=I9"`B3&%Y;W5T(@IM
M<V=S='(@(I1ZDG4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G
M<W1R("*#C(-O@VV#DXNDF&&-D2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B3&5F="(*;7-G<W1R
M("*-MB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,P.3@*;7-G:60@
M(DQE9G0@:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,P.30*;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX.`IM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("*#C(-<@V>)I(V1
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED("),
M979E;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI8F5R:6$B
M"FUS9W-T<B`B@XJ#>(.*@T&+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@
M(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`BD>6#BH-R@T&!18-!
M@XF#=8[0B>^.Y8M@D&R6KX-7@X.#?8%;@W&#BH%;@X0B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#@*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B@XJ#<8-E@Y.#5H.%
M@UZ#0X.3C/:-D2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(U"FUS9VED("),:6=H="!$<FEZ>FQE(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"FUS9VED
M("),:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!286EN($5A<FQY
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(X"FUS9VED("),:6=H="!286EN($QA=&4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G
M:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P"FUS9VED("),:6=H="!2
M86EN('=I=&@@5&AU;F1E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B3&EG:'0@4VYO=R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS,@IM<V=I9"`B3&EG:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0U"FUS9VED("),:6UE<FEC:R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#$Q"FUS
M9VED("),:6YK(@IM<V=S='(@(H.*@Y.#3B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B3&EN
M:R!P;VEN=',@=&\Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$X-S(*;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@
M=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T<B`B@X&!
M6X.+C>R0K)=P@LF#@8%;@XN#08-H@XR#6(+)@XJ#DX-.@K>"Z2(*"B,Z(&9R
M86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:'1M;#)T97AT+G!H<#HQ.#(*
M;7-G:60@(DQI;FMS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT-@IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C0V"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T
M("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C$S-`IM<V=I9"`B3&ES="!$871A8F%S97,B"FUS
M9W-T<B`B@V:!6X->@WB!6X-8B.J7ER(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD
M97@N<&AP.C4Q"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(H-W
M@XN#=HV`EMJ"\)5<CJ:"MX+I(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S
M,PIM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`BE5R"S(CJEY<B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-`IM<V=I9"`B3&ES
M="U!<F-H:79E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M2&5A9&5R<RYP:'`Z-3@Y"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.38*;7-G:60@
M(DQI<W0M260B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](
M96%D97)S+G!H<#HU.3(*;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3,*;7-G:60@
M(DQI<W0M4&]S="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TAE861E<G,N<&AP.C4Y,0IM<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3`*
M;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5S<VEO;G,N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@
M<V5S<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R("*#6H-B@U:#AX.3@LR(ZI>7
MC>R0K(+)CKB4<X%&)7,B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!U<V5R<R!F86EL960Z("5S(@IM
M<V=S='(@(H.&@5N#58+,B.J7EXWLD*R"R8ZXE'.!1B5S(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED("),:7-T:6YG('5S
M97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("*#AH%;@U6"S(.*@UB#9X+-EK.,
M^(+)@LB"P8+$@J*"W(*W@4(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#<*;7-G:60@(DQI=&5R871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y
M"FUS9VED("),:71H=6%N:6$B"FUS9W-T<B`B@XJ#9X-!@VJ#08NDF&&-D2(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z-S<*
M;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`B@XV!6X-HDH8N+BXB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`P"FUS9VED("),;V-A;"!T
M:6UE.B`B"FUS9W-T<B`BC+N2;HZ>BM2!1B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX-@IM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(I)N
MB.:"QHZ>BM0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4W,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-3<*(SH@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C:R]M971A<BYP:'`Z-S(*;7-G
M:60@(DQO8V%T:6]N(@IM<V=S='(@(H_JCXHB"@HC.B!L;V=I;BYP:'`Z,3@Y
M('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,#`@=&5M<&QA=&5S+VQO
M9VEN+VUO8FEL92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN
M8SHQ-2!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDP"FUS9VED("),;V<@
M:6XB"FUS9W-T<B`B@XV#3X-#@Y,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR-#4*;7-G:60@(DQO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I
M;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP
M.C$Y-`IM<V=I9"`B3&]G(&]U="(*;7-G<W1R("*#C8-/@T&#18-G(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4Y"FUS9VED("),;V=I;B(*;7-G<W1R
M("*#C8-/@T.#DR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3`*;7-G
M:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@(H.-@T^#0X.3((->@UB#3B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY-0IM<V=I9"`B3&]G:6X@9F%I
M;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT
M97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B@X:!6X-5EKR"J8-P@UB#CX%;
M@VB"JI"S@K6"K8+(@J*"O8+?@LF#C8-/@T.#DX+)CKB4<X*U@MR"M8*]@4(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.3$*;7-G:60@(DQO9VEN
M(&9A:6QE9"XB"FUS9W-T<B`B@XV#3X-#@Y."R8ZXE'."M8+<@K6"O8%"(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V,@IM<V=I9"`B3&]N9R!T
M97AT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`IM
M<V=I9"`B3&]V92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV.0IM<V=I9"`B3&]W(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T<B`B@TV#
MBH-6@X.5MHZ:@6F/K)6VCIJ!:B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA
M=&EN(&QE='1E<G,B"FUS9W-T<B`B@XF#98.3E;:.FH%ICZR5MHZ:@6HB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C$W"FUS9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(H.-
M@5N#?9"4CIJ!:8^LE;:.FH%J(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),=7AE
M;6)O=7)G(@IM<V=S='(@(H.+@TZ#6H.3@W6#BX-.D>6,]HV1(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,0HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R("*,CB(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#,*;7-G:60@(DU/5$0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z
M,S8*;7-G:60@(DU3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T
M82XB"FUS9W-T<B`BDUF5=(*S@NJ"O2!-4RU43D5&((+-@V:!6X->@O"*W(+Q
M@L6"HH+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I
M9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C86\B"FUS9W-T<B`B
M@WV#2H-)(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-86-E9&]N:6$L(%1H92!&
M;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T<B`B@WV#4(-H@VJ#
M08N,@X:!6X-3@UB#B8-R@T&+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@
M(DUA9&%G87-C87(B"FUS9W-T<B`B@WV#7X-+@UB#2H.+BZ2888V1(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"FUS9VED(")-86=I8R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#,*;7-G:60@(DUA
M:6PB"FUS9W-T<B`BDV2.<8.!@5N#BR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HU,C0*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-`IM<V=I9"`B36%L87=I(@IM<V=S='(@(H-]@XF#18-#BZ2888V1(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDU"FUS9VED(")-86QA>7-I82(*;7-G<W1R("*#?8.,@5N#
M5H-!(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD:79E<R(*;7-G<W1R("*#
M@H.+@V:#0H-UBZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86QI(@IM
M<V=S='(@(I-DCG&#@8%;@XLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;'1A
M(@IM<V=S='(@(H-]@XN#7HNDF&&-D2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY-`IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I
M97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R`B
M"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B
MD$:5=(*O@K."ZH*]@XF#>(.+@O"1SHF>@K."N8+$E:J7WH+PBL>7G8*U@MR"
MMX%"(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$Q-38*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X-PHC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$W,0IM<V=I9"`B36%P
M475E<W0@;6%P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#(*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM
M<V=I9"`B36%R8V@B"FUS9W-T<B`B@E*,CB(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*;7-G:60@(DUA<F=I
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T
M,S$T+G!H<#HT.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L86=S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N
M<&AP.C0Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T
M86YT+T%N<W=E<F5D*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@
M(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`B@WV!6X-6@X.#BX^4DX>+I)AA
MC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B
M@WV#BX-E@T*#:H-.DX<B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C$P,PIM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(H-T@T*!6X.+
M@VB"\(CJDG:"LX*Y@L2"HH+<@K<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$V,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA
M=7)I=&%N:6$B"FUS9W-T<B`B@X*!6X.*@UZ#:H-!@46#0X-8@XF#@(NDF&&-
MD2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(H."
M@5N#BH-6@X.#6(NDF&&-D2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E
M9&ET+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@(DUA>"!M97-S86=E('!A<G1S
M(&5X8V5E9&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,Q,PIM<V=I9"`B36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`U"FUS9VED(")-87@@=&5M
M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HX
M-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.34@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C,V"FUS9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#0*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I
M9"`B36%Y(@IM<V=S='(@(H)4C(XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")-
M87EO='1E(@IM<V=S='(@(H-]@T.#B(-B@V>3AR(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@IM<V=I9"`B365M
M8F5R<R(*;7-G<W1R("*#@8.3@V\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S@R"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S='(@(H.!@VJ#A8%;@X*!
M6X-H(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T<B`B@UJ#BXR+
MC8<B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*;7-G<W1R("*6>Y6V(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*
M(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R
M)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G
M<W1R("*#@8-B@UJ!6X-7@LV,GX_8@L6"JX+<@K6"O8*J@4&/D):\CM*"S)!G
MC+."S8R?C]B"Q8*K@MR"N8+Q@L6"M8*]@4(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*;7-G:60@(DUE<W-A
M9V4@97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V,`IM<V=I9"`B
M365S<V%G92!T>7!E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,PIM<V=I9"`B365T87(@5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,W"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A
M:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q
M.0IM<V=I9"`B(@HB365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL
M<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U,PIM
M<V=I9"`B365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8W(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO
M9"(*;7-G<W1R("*#@8-<@V*#:"(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM
M;')P8RYP:'`Z.#$@9G)A;65W;W)K+U)00R]24$,O<V]A<"YP:'`Z,3$W"B,L
M('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN
M960B"FUS9W-T<B`B@X&#7(-B@V@@7"(E<UPB((+-DNB+8(*S@NJ"Q(+<@KF"
M\2(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF
M;W)M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO
M9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C8W(&QI8B]";&]C:R]M971A<BYP:'`Z.#(*;7-G:60@(DUE=')I8R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUE>&EC;R(*;7-G<W1R
M("*#@8-,@U:#4HV'CT^-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")-:6-R;VYE
M<VEA+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(H-^@TZ#C8-L@U:#
M09A!EDTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-S8*;7-G:60@(DUI9&1L92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM
M92!4>7!E(@IM<V=S='(@(DUI;64@5'EP92(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S$W"FUS9VED(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#D*;7-G:60@(DUI
M;B!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#,Y"FUS9VED(")-:6YI;75M('!A<W-W
M;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S4*;7-G:60@
M(DUI<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0P"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C4P"FUS9VED
M(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S='(@
M(E!%05(@@W"#8H-0@5N#5X+,($A45%!?4F5Q=65S="""JHRIDY:"O8+H@MR"
MN8+Q@4(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U"FUS9VED("(B
M"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E
M(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO
M;BXB"FUS9W-T<B`B(@HBEJ*0W9+H@L6"MX%"@K&"S(-!@W:#BH-0@5N#5H.'
M@Y."\(YGEW""MX+I@KV"WX+)@LV0W9+H@W2#0(-#@XN"\(WLD*R"MX+IE4N7
M=B(*(H*J@J""Z(+<@K>!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E
M($E$+B(*;7-G<W1R("*#@8-B@UJ!6X-7($E$((*JC*F3EH*]@NB"W(*Y@O&!
M0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M
M='`N<&AP.C4X"FUS9VED(")-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G
M92!-86EL+B(*;7-G<W1R(")014%2((-P@V*#4(%;@U>"S"!-86EL((*JC*F3
MEH*]@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES<VEN9R!S97-S:6]N($E$
M+B(*;7-G<W1R("*#6H-B@U:#AX.3($E$((*JC*F3EH*]@NB"W(*Y@O&!0B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-38*
M;7-G:60@(DUO(@IM<V=S='(@(HR.(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C<V"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R("*,9Y'1@X&!
M6X.+(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-S`*;7-G:60@(DUO9&5R871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HW,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T9WHN<&AP.C@U"FUS9VED(")-;V1I9FEE9"!$871E(@IM<V=S='(@
M(H]#D+.3^B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D:69Y(%523"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-`IM<V=I
M9"`B36]D=6QU<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO
M;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(H."@XN#:(-OBZ2888V1(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B@X*#:8-2C/:-
MD2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36]N9V]L:6$B"FUS9W-T<B`B@X*#
MDX-3@XLB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3@Q"FUS9VED
M(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I
M;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM
M<V=S='(@(I:(C(XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUO;G1S97)R870B
M"FUS9W-T<B`B@X*#DX-G@UJ#B8-GDX<B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S
M(@IM<V=S='(@(HR.E^XB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HQ.38@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C@P"B,L('!H<"UF
M;W)M870*;7-G:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA
M;B!T:&4@97AP96-T960@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM
M<V=I9"`B36]R;V-C;R(*;7-G<W1R("*#@H.-@V*#4HFDC9$B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B36]S
M=&QY($-L96%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,U"FUS9VED(")-;W-T;'D@0VQO=61Y(&%N9"!7:6YD>2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@IM
M<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C0X"FUS9VED(")-;W9E
M($1O=VXB"FUS9W-T<B`BB;J"UB(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70O36%N86=E<BYP:'`Z-C4R"FUS9VED(")-;W9E($QE9G0B"FUS
M9W-T<B`BC;:"UB(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z-C4V"FUS9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(HE%
M@M8B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.C8T-`IM<V=I9"`B36]V92!5<"(*;7-G<W1R("*/XX+6(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-@IM<V=I9"`B
M36]V92!D;W=N(@IM<V=S='(@(HFZ@M8B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(U"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HU,C8*;7-G:60@(DUO=F4@=7`B"FUS9W-T
M<B`BC^."UB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36]Z86UB:7%U92(*;7-G
M<W1R("*#@H-5@Y.#<H%;@TZ+I)AAC9$B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,3@Q"FUS9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES
M=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$P-3D*;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C,Y"FUS9VED(")-
M=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0P,@IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R("*#
M08-*@T6#DX-G(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X"FUS9VED
M(")->2!!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(H-!@TJ#18.3@V>/
M[I7Q(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HT-0IM<V=I9"`B
M37D@4&]R=&%L(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET
M+G!H<#HT,PIM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3(*;7-G:60@(DUY86YM87(B"FUS9W-T<B`B@WZ#@X.3@WV!
M6YA!EDTB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N
M:'1M;#HU-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM<V=S='(@(I.O
MB-."M8+<@KF"\2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q,2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS
M9VED(").86UE(@IM<V=S='(@(I:\D4\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@
M(DYA;6EB:6$B"FUS9W-T<B`B@VF#?H-R@T&+I)AAC9$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$W."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(H-I@T6#BXNDF&&-D2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B@VR#<(%;@XN)I(V1(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDW"FUS9VED(").971H97)L86YD<R(*;7-G<W1R("*#28.)
M@Y.#7XFDC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT
M:6QL97,B"FUS9W-T<B`B@TF#B8.3@U^7S(-!@Y.#98-"@XN/E).'(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G:60@(DYE
M='-C87!E($)A<V4@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P92!#02!2979O
M8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%52
M3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G
M:60@(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@W"FUS9VED(").971S
M8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#@*;7-G:60@(DYE='-C87!E(&-E
M<G1I9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C87!E(&-E<G1I
M9FEC871E('1Y<&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(U,PIM<V=I9"`B3F5T=V]R:R(*;7-G<W1R("*#;(-B@V>#CX%;
M@TXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,S.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,SDP"FUS9VED(").979E<B(*;7-G<W1R("*"R(*U(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDU"FUS9VED(").97<@0V%L961O;FEA(@IM<V=S='(@(H-T@XF#DX-8E\R#
M:H.%@5N#2H.,@VB#:H-!(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A
M=&5G;W)Y36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G
M<W1R("*05HM+E:J7WB(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I
M9"`B3F5W($UO;VXB"FUS9W-T<B`BD%:,CB(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T
M:6]N86PI(@IM<V=S='(@(I!6@K6"HH.&@5N#59:\*)1#B-,I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDX"FUS9VED(").97<@6F5A;&%N9"(*;7-G<W1R("*#:H.%@5N#5X%;
M@XF#DX-H(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,W"FUS
M9VED(").97<@<&%S<W=O<F0B"FUS9W-T<B`BD%:"M8*B@W"#6(./@5N#:"(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HR,C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+B(*
M;7-G<W1R("*05H*U@J*#<(-8@X^!6X-H@LT@)7@@@LF*^HS`D-B"ZH+)@LB"
MZ(+<@K>!0B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU,@IM
M<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"XB"FUS9W-T<B`BD%:"
MM8*B@W"#6(./@5N#:(*JB.J2=H*U@MR"N8+Q@4(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@=VEN
M9&]W("A?8FQA;FLI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N
M<&AP.C0P(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,CDQ"FUS9VED(").97=S(@IM<V=S='(@(H-J@X6!
M6X-8(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-PIM<V=I9"`B
M3F5W<V=R;W5P<R(*;7-G<W1R("*#:H.%@5N#6(-/@XN!6X-V(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34@=&5M<&QA=&5S+V1A=&$O9&%T
M96UA<"YI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,CD@
M=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4*;7-G:60@(DYE>'0B"FUS
M9W-T<B`BCI\B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*;7-G:60@(DYE
M>'0@-"!0:&%S97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HS-C8@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS
M-S`*;7-G:60@(DYE>'0@;W!T:6]N<R(*;7-G<W1R("*.GX+,@TF#=H-6@X>#
MDR(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z,3`S"FUS9VED(").
M97AT/B(*;7-G<W1R("*.GX+,@WF!6X-7/B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I
M9"`B3FEC87)A9W5A(@IM<V=S='(@(H-J@TJ#B8-/@T&+I)AAC9$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.38*;7-G:60@(DYI9V5R(@IM<V=S='(@(H-J@U>#1H%;@XN+I)AA
MC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`B@VF#
M0X-7@T:#BH-!F$&638NDF&&-D2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS-CD*;7-G:60@(DYI9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-PIM<V=I9"`B3FEU92(*;7-G<W1R("*#:H-%@T>3AR(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C8*;7-G:60@(DYO
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT
M;6PZ.0IM<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T
M;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`BC;>5JH+PE5R.IH*W
M@NF"O8+?@LR0W9+H@JJ"H(+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(N<&AP.C$P-@IM<V=I9"`B3F\@879A:6QA
M8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S$S"FUS9VED(").;R!B871C:"!T96UP;&%T92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ
M,#$*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HS.#4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HT,#<*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S
M=&5D('!O<VET:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;6-A;"YP:'`Z-3`*;7-G:60@(DYO(&-A;&5N9&%R(&YA;64@<')O=FED
M960@9F]R($U#04P@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+V1I9F8N<&AP.C4T"FUS9VED(").;R!C:&%N9V4N(@IM<V=S
M='(@(I7/C5B"R(*U@4(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C$U-@IM<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H
M:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B@K&"S(-!@TZ#6H-8C*""R8+-@U2#
M=8-!@TZ#6H-8C*""S9+'B<&"Q8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$W."!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C4Q-PHC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW-C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R("5S+B(*;7-G<W1R("(E<R""S)#=DNB/[I7Q@JJ.=Y+H@K."
MZH+$@J*"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.#4U"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B1E10(%9&4R""S(U<D*R/[I7Q
M@JJ.=Y+H@K."ZH+$@J*"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z-C<R"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B4U%,(%9&4R""
MS(U<D*R/[I7Q@JJ.=Y+H@K."ZH+$@J*"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,C4*;7-G:60@(DYO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N
M(@IM<V=S='(@(E-13""#2H-E@U.#BH+,C5R0K(_NE?&"JHYWDNB"LX+J@L2"
MHH+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T
M<B`BCF.-@H*J@J""Z(+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S0*;7-G:60@(DYO(&1E<W1I;F%T
M:6]N('-U<'!L:65D+B(*;7-G<W1R("*1EY!-D.:"JHYWDNB"LX+J@L2"HH+<
M@KF"\8%"(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3(P
M"FUS9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(H-T@T"#0X.+@JJ#
M08-B@W:#C8%;@VB"LX+J@L2"HH+<@KF"\2(*"B,Z('5T:6PO:6-O;E]B<F]W
M<V5R+G!H<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@(H-!
M@T.#4H.3@JJ"H(+H@MR"N8+Q@4(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,3$V(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$S,`IM<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,34W"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`BC^J/
MBH*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I9"`B3F\@;65S<V%G
M92!S=7!P;&EE9"XB"FUS9W-T<B`B@X&#8H-:@5N#5X*JCG>2Z(*S@NJ"Q(*B
M@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S-@IM<V=I9"`B3F\@;F%M92!S<&5C:69I960N(@IM<V=S
M='(@(I:\D4^"JHYWDNB"LX+J@L2"HH+<@KF"\8%"(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*;7-G:60@(DYO
M(&YU;6)E<B!S<&5C:69I960N(@IM<V=S='(@(I34C8:"JHYWDNB"LX+J@L2"
MHH+<@KF"\8%"(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS9VED
M(").;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DA4
M5%`@E$:/V(+,@W"#6(./@5N#:(*J@J""Z(+<@KF"\8%"(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]I;6%P+G!H<#HQ,#@*;7-G:60@(DYO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("))
M34%0()1&C]B"S(-P@UB#CX%;@VB"JH*@@NB"W(*Y@O&!0B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-S(*;7-G:60@(DYO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B2V5R8F5R;W,@E$:/V(+,@W"#6(./@5N#:(*J@J""Z(+<@KF"\8%"(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HW-R!F<F%M97=O<FLO
M075T:"]!=71H+VQO9VEN+G!H<#HX-`HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W!A;2YP:'`Z-S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,
M;V=I;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B@XV#3X-#@Y,@E$:/V(+,
M@W"#6(./@5N#:(*J@J""Z(+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]P87-S=V0N<&AP.C$S-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B4$%34U=$
M()1&C]B"S(-P@UB#CX%;@VB"JH*@@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<VUB+G!H<#HX-`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B4TU"()1&
MC]B"S(U<D*R/[I7Q@JJ.=Y+H@K."ZH+$@J*"W(*Y@O&!0B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X-PIM<V=I9"`B(@HB3F\@
M<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N
M4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@
M,3(@9&%T82XB"FUS9W-T<B`B(@HB3W!E;E-33""#=H.-@T^#B8.`@LR#<(-8
M@JJ.=Y+H@K."ZH+$@J*"W(*Y@O&!0D]P96Y34TP@@LT@4$M#4R`Q,B""S(-F
M@5N#7H+PB+4B"B*"I(+,@LF52Y=V@L6"MX%"(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N
M=7!S+B(*;7-G<W1R("*5VY>O@LR#5(-#@Y.#08-B@W:"R(*U@4(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z-S8V"FUS9VED(").;R!Q=6]T82!S970N
M(@IM<V=S='(@(H-.@TB!6X->@JJ0W9+H@K."ZH+$@J*"W(*Y@O&!0B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#,*;7-G:60@(DYO(')U;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C0X,@IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I
M9FEE9"XB"FUS9W-T<B`B@UJ#<(.,@5N#7H*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q
M@4(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0T"FUS9VED(").;R!S:61E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X-PIM<V=I9"`B3F\@<W5C:"!F:6QE
M(@IM<V=S='(@(HI9DY:#=(-`@T.#BX+(@K4B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3(V"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T
M;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"FUS9VED(").
M;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`B@X:!
M6X-5EKR"J8-P@UB#CX%;@VB"JI&7@N>"ZH+<@KF"\8+%@K6"O8%"(@H*(SH@
M9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO('9A
M;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@(I:SC/B"S%A-3(-F@5N#
M7H*JE=2"Z(+<@K6"O2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HY-S0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.CDX-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.3DU"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,#$R"FUS9VED(").;R!V86QU97,B"FUS9W-T<B`BDFR"R(*U
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B3F\@=F5R
M<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R
M871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(H-)@XJ#5X-I@XN"S)#=DNB#
M=(-`@T.#BX+)@V^!6X-7@X>#DX*J@J""Z(+<@KF"\8%"D-V2Z(+PC<20MI"L
M@K6"W(*W@4(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(X"FUS9VED
M(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G
M96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("*0W9+H@W2#0(-#@XN"
MR8-O@5N#5X.'@Y."JH*@@NB"W(*Y@O&!0I#=DNB#=(-`@T.#BX+PC>R"Z)*\
M@K6"Q(FZ@K."HH%"(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T
M+FEN8SHY,PIM<V=I9"`B3F]N92(*;7-G<W1R("*"R(*U(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I9"`B3F]N
M92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y,@IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G
M<W1R("*#;8%;@W2#2(%;@TZ3AR(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS
M,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES
M<&AE<F4B"FUS9W-T<B`BEFN4O(N%(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(").
M;W)T:&5R;B!-87)I86YA($ES;&%N9',B"FUS9W-T<B`BEFN#?8.*@T&#:8^4
MDX<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYO<G=A>2(*;7-G<W1R("*#;8.+
M@T6#1H%;B:2-D2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C0Q"FUS9VED(").;W0@069T97(B"FUS9W-T<B`B@K&"ZH+F@NB13R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0P"FUS9VED
M(").;W0@0F5F;W)E(@IM<V=S='(@(H*Q@NJ"YH+HC.,B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HT,34*;7-G:60@(DYO="!A(&1I<F5C=&]R
M>2(*;7-G<W1R("*#9H-"@XR#3H-G@XJ"Q8+-@J""Z(+<@KF"\2(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z-C,*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2YP:'`Z.#0*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.34*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT
M.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDN<&AP.C4Y"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM
M<V=S='(@(H[`D96"LX+J@L2"HH+<@KF"\8%"(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`IM<V=I9"`B3F]T('-E="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO
M;DAA;F1L97(N<&AP.C$T-0HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O
M4V5S<VEO;DAA;F1L97(N<&AP.C$V,`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA
M;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$W-0HC.B!F<F%M97=O<FLO4V5S
M<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$X.0HC.B!F<F%M97=O
M<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C(S-B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR,#@@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(S-`HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,C4R(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-CD*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C(X-2!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,S`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,38@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C,S,PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S8V
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HT,C8*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C4P-2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3<T"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HU.3$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C8V
M.0IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B@U2#?(%;@V>"LX+J
M@L2"HH+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY
M,#@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T-`HC
M.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`U."!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3@P"FUS9VED(").;W1E<R(*;7-G<W1R("*#@8."(@H*(SH@
M<V5R=FEC97,O;V)R;W=S97(O:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG
M('1O(&)R;W=S92P@9V\@8F%C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S4*;7-G:60@(DYO=F5M8F5R
M(@IM<V=S='(@(C$QC(XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,#0S"FUS9VED(").=6UB97(B"FUS9W-T<B`BD)0B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#(R"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R
M<R(*;7-G<W1R("*5MHZ:D)0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,S8V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C`*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,30T,B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B
M"FUS9W-T<B`BE_&0E"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S
M-C0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q.`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#0P('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@;V8@<F]W<R(*;7-G<W1R
M("*-<Y"4(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@
M=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(I&7D$V0
MYH.*@UB#9X+PC5B05H*]@M^"S)34C8:"JHYWDNB"LX+J@MR"N8+Q@L6"M8*]
M@4(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-C0*;7-G:60@(D]+(@IM<V=S='(@(D]+(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B3V)J96-T(@IM<V=S
M='(@(H-)@W6#5X-&@TZ#9R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E871O<B(*;7-G<W1R("*#28-U@U>#
M1H-.@V>-[)"LCM(B"@HC(&US9W-T<B`B@TF#=8-7@T:#3H-GC>R0K([2@LR+
MEHG"D-V2Z"(*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$P,0IM<V=I
M9"`B3V-T86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0Q,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS9W-T<B`B,3",
MCB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B3V9F96YS
M92!F:6QT97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,R.`IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(H-)@W2#0H-8(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/;&0@86YD
M(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-@IM<V=I9"`B3VQD
M('!A<W-W;W)D(@IM<V=S='(@(HS#@J*#<(-8@X^!6X-H(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C0V"FUS9VED(")/;&0@<&%S<W=O<F0@
M:7,@;F]T(&-O<G)E8W0N(@IM<V=S='(@(HS#@J*#<(-8@X^!6X-H@JJ0LX*U
M@JV"H(+H@MR"N8+Q(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")/;6%N(@IM<V=S
M='(@(H-)@WV!6X.3(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@
M<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(HNDETR#=(-(@XN#7X+-($E-05`@
M@U2!6X-O@KZ"KX*J@U2#?(%;@V>"Q8*K@MR"MX%"(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.CDU"FUS9VED(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#0X
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C@*;7-G:60@(D]N;'D@;VYE
M(&5M86EL(&%D9')E<W,@86QL;W=E9"XB"FUS9W-T<B`BDV2.<8.!@5N#BX-!
M@VB#C(-8@LTQ@L*"OH*OCG>2Z(+%@JN"W(*W@4(B"@HC.B!S97)V:6-E<R]S
M:&%R97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R
M('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R
M(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(H^*
METR.TH*I@U:#6(-E@X"*QY>=CM*"OH*O@JJ+I)=,@LR/BI=,C*""QH-!@TZ#
M6H-8C*""\)7/C5B"Q8*K@MR"MR(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP
M.C0Q(&QI8B]";&]C:R]I9G)A;64N<&AP.C0R"FUS9VED(")/<&5N(&EN(&$@
M;F5W('=I;F1O=R(*;7-G<W1R("*05HM+@T6#0X.3@VB!6X+)E5R.IB(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/
M<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG
M;F5D(%,O34E-12!P87)T+B(*;7-G<W1R("(B"B)/<&5N4U-,((-'@XF!6X%&
M4R]-24U%((^0EKR"LX+J@KV#<(%;@V>"J8+G@V:!6X->@O".YH+HCV^"N8+<
M@KF"\8+%@K6"O8%"(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")/<&5N<R!T:&ES(&QI;FL@
M:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED(")/
M<'1I;VYS(@IM<V=S='(@(H-)@W:#5H.'@Y,B"@HC.B!S97)V:6-E<R]P<F5F
M<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B)7,@@TF#=H-6
M@X>#DR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES="(*;7-G<W1R("*4U(V&E72)TX_P
MCY&"JR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38X
M"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`BD6>01"(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED(")/<F=A;FES
M871I;VYA;"!5;FET(@IM<V=S='(@(I64CY`B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3,T"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(I"N
MEYTB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN
M86P@87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`BC+."S(-!@W:#BH-0
M@5N#5H.'@Y.#98.3@W:#C(%;@V<B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@
M:6X@)7,Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE
M<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3D@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$P.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C4*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$S-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30T"FUS
M9VED(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R("*1O(+,@T.#DX-T@TB#
M@8%;@U:#AX.3(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,0IM
M<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`BCXJ73([2@LR#08-.
M@UJ#6(R@(@H*(R!M<V=S='(@(H^*CIV.TH+,BY:)PI#=DN@B"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW.0IM<V=I9"`B4$%-(&%U=&AE;G1I
M8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(E!!32"41H_8@LV.
M9Y=P@L6"JX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E
M;F5R:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A8VME;F0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3(W-@IM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S='(@(E!'
M4""39(YQCY"6O"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$S,C(*;7-G:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R(")01U`@
MB,.-AI6V(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,W
M-`IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B4$=0((SVBDJ,KB(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-38*;7-G:60@
M(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B4$=0((^0EKR-
MSR^(PXV&B;N#9H%;@UXB"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-CD*;7-G
M:60@(E!(4"!#;V1E(@IM<V=S='(@(E!(4(-2@5N#:"(*"B,Z(&%D;6EN+W!H
M<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(E!(4(-6
M@T:#BR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,X"FUS9VED(")032!,:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Y"FUS9VED(")032!2
M86EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0P"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"FUS9VED
M(")032!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0R"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#,*;7-G:60@(E!-(%-U;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4$T@5"U3=&]R
M;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(W-`IM
M<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T<B`B4$]3
M25@@BF>2HX*JC*F3EH*]@NB"W(*Y@O$B"@HC.B!L:6(O87!I+G!H<#HQ-#D*
M;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B4&%D
M9&EN9R(*;7-G<W1R("*6A)&0(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")086MI
M<W1A;B(*;7-G<W1R("*#<(-,@UB#7H.3@46#0X-8@XF#@(NDF&&-D2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(H-P@XF#28NDF&&-
MD2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DR(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R
M>2P@3V-C=7!I960B"FUS9W-T<B`B@W"#C(-8@V"#:8ZICJ&+YB(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY.`IM<V=I9"`B4&%N86UA(@IM<V=S='(@(H-P@VF#?8NDF&&-D2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R
M("*#<(-V@T&#:H.%@5N#38-J@T&3QI>GC9$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS
M9VED(")087)A9W5A>2(*;7-G<W1R("*#<(.)@T^#08-#BZ2888V1(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*;7-G:60@
M(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,S8@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-PHC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3$@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C`Q-0HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C<W('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R-0IM<V=I9"`B4&%S<W=O<F0B"FUS
M9W-T<B`B@W"#6(./@5N#:"(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN
M(@IM<V=S='(@(H-P@UB#CX%;@VB"S9"SC^V"R97/C5B"LX+J@MR"M8*]@4(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$S,C,*;7-G
M:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G<W1R("*#<(-8@X^!6X-H@JJ0
MLX*U@JV"H(+H@MR"N8+Q(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I
M=7,N<&AP.C$U,@IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E5
M4R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B4D%$2553()1&C]B"S(-P@UB#
MCX%;@VB"JI5+EW:"Q8*W@4(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,#4P"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G
M<W1R("*#<(-8@X^!6X-H@LR*;91&(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.CDP"FUS9VED(")087-S=V]R9#HB"FUS9W-T<B`B@W"#6(./
M@5N#:#HB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0IM<V=I
M9"`B4&%S<W=O<F0Z("(*;7-G<W1R("*#<(-8@X^!6X-H.B`B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ-3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`S,0HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS9VED(")0
M87-S=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`B@W"#6(./@5N#:(*JB.J2
M=H*U@MR"N8+Q@4(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM
M<V=I9"`B4&%S=&4B"FUS9W-T<B`BDUR"Z)5T@J\B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,W"FUS9VED(")087-T92!F
M<F]M(&-L:7!B;V%R9"(*;7-G<W1R("*#3H.*@V*#=H-[@5N#:(*I@N>37(+H
ME72"KR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`B@W"#6"(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E<75E=65D+FEN8SHW"FUS9VED(")096YD:6YG(%-I9VYU<',Z
M(@IM<V=S='(@(I7;EZ^2AH+,@U2#0X.3@T&#8H-V@48B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-30*;7-G:60@(E!E;W!L92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-PIM
M<V=I9"`B4&5R8V5N="(*;7-G<W1R("*#<(%;@UJ#DX-G(@H*(SH@=&5M<&QA
M=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@(E!E
M<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R("*5VX[GD8"-
M[(+PCL"-<X*W@NDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#$P"FUS
M9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_
M(@IM<V=S='(@(H.-@T^#0X.3CIZ"R97;CN>1@(WL@O".P(US@K6"W(*W@JF!
M2"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED
M(")097)M:7-S:6]N(@IM<V=S='(@(H-!@TZ#6H-8C*`B"@HC(&US9W-T<B`B
MBY:)PI#=DN@B"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T960N
M(@IM<V=S='(@(H-!@TZ#6H-8C*`@7"(E<UPB((+-C>V/G(*S@NJ"W(*Y@O&"
MQ8*U@KV!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3DP"FUS
M9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("*#08-.@UJ#6(+-BY&4
MVX*S@NJ"W(*U@KTB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C$V,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V-`IM<V=I9"`B
M4&5R;6ES<VEO;G,B"FUS9W-T<B`B@T&#3H-:@UB,H"(*"B,Z(&%D;6EN+W!E
M<FUS+V5D:70N<&AP.C$P.2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C`*
M(SH@861M:6XO<&5R;7,O:6YD97@N<&AP.C(R(&%D;6EN+W!E<FUS+V1E;&5T
M92YP:'`Z-3@*;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(H-!@TZ#6H-8C*""S(K'EYTB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C@*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@
M(HS"D&R/[I7Q(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")097)U(@IM<V=S='(@
M(H-Y@XN!6XNDF&&-D2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-0IM
M<V=I9"`B4&5T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!H
M:6QI<'!I;F5S(@IM<V=S='(@(H-T@T*#BH-S@Y.+I)AAC9$B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0
M:&]N92(*;7-G<W1R("*39)AB(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0X,`IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#`*;7-G:60@(E!I=&-A:7)N(@IM<V=S='(@(H-S@V>#4(-!@Y.3AR(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS
M9VED(")0:7AE;',B"FUS9W-T<B`B@W.#3H-:@XLB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I='5D97,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@
M=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL
M:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C4U.0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@
M86YD(&$@>65A<BXB"FUS9W-T<B`BC(Z"QI1.@O"3_)?-@K6"Q(*M@KZ"LX*B
M@4(B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHQ,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C
M871E9V]R>3HB"FUS9W-T<B`BD%:"M8*BE:J7WH+,EKR13X+PD_R7S8*U@L2)
MNH*S@J(Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Y.`IM<V=I
M9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8S-PIM<V=I9"`B4&QE
M87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D
M87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`BD+."M8*BD_J5=(+PD_R7S8*U
M@L2"K8*^@K."HBX@C(Z"S)/ZD)2"\(-@@T:#8H-.@K6"Q(*M@KZ"LX*B@4(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#0T"FUS9VED(")0;&5A
M<V4@96YT97(@82!V86QI9"!T:6UE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O=FED
M92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@(H_ABE&3X)=E
M@O"7=I;Q@K6"Q(*RBTR3_(*M@KZ"LX*B@4(B"@HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C8*
M;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W
M;W)D(@IM<V=S='(@(H.&@5N#59:\@L:#<(-8@X^!6X-H@O"3_)?-@K6"Q(*M
M@KZ"LX*B@4(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*;7-G
M:60@(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U5
M4U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN
M(@IM<V=S='(@(B(*(HZ?@LR5MH^1@O"3QX+Q@L6"K8*^@K."HBX@@K&"S(-6
M@UB#98.`@O".9Y=P@K>"Z8*]@M^"S(M+DNB.EHV`@LF3KXC3@K>"Z95+EW8B
M"B*"JH*@@NB"W(*W@4(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T
M96=O<GE-86YA9V5R+G!H<#HW,`IM<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE
M=R!C871E9V]R>2!N86UE.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G
M:60@(E!O;&%N9"(*;7-G<W1R("*#?(%;@XF#DX-HBZ2888V1(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@Y"FUS9VED(")0
M;VQL<R(*;7-G<W1R("*3BI5;D)0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0
M;W)T=6=A;"(*;7-G<W1R("*#?(.+@V>#2X.+BZ2888V1(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W
M"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q
M"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4Q"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED
M(")0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S,@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E8VEP
M:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-PIM<V=I9"`B4')E8VEP
M:71A=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O;&1A<"YP:'`Z.3@*;7-G:60@(E!R969S7VQD87`Z(%)E
M<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E
M9G-?;&1A<#H@E4N7=H+(3$1!4(IGDJ.+0)1<@JJ,J8+"@JF"Z(+<@KF"\8%"
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS
M9VED(")0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S7VQD87`Z()5+EW:"R'-E<W-I
M;VZ*9Y*CBT"47(*JC*F"PH*I@NB"W(*Y@O&!0B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C,R"FUS9VED(")0<F5S<W5R92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(V-@IM<V=I9"`B4')E<W-U<F4@870@<V5A
M(&QE=F5L.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(R-`IM<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`S"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R("*#=H.,@W*#A8%;(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(T"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD
M;W<B"FUS9W-T<B`BD%:"M8*B@T6#0X.3@VB!6X+)B>:1G(+PE5R.IB(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S4V(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,S8P"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS
M(@IM<V=S='(@(I%/@LR#28-V@U:#AX.3(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE
M;G0B"FUS9W-T<B`BB/.-_"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+97DB"FUS9W-T<B`BE.F6IXRN
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V.0IM<V=I
M9"`B4')O8FQE;2(*;7-G<W1R("*/X8I1(@H*(SH@<V5R=FEC97,O<')O8FQE
M;2YP:'`Z,3(W"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@
M(H_ABE&3X)=E@LR0X):^(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,W,0IM<V=I9"`B4')O:F5C=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C$P."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,3@U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-S,*;7-G:60@(E!R
M;VUP="!T97AT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0R,PIM<V=I9"`B4'5B;&EC($ME>2(*;7-G<W1R("*,]HI*
MC*XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-@IM
M<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET:&TB"FUS9W-T<B`BC/:/3XRN@T&#
MBX-3@XJ#68.`(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@26YF;R(*;7-G<W1R("*,]HI*C*Z/
M[I7Q(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS
M9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C
M8V5S<V9U;&QY+B(*;7-G<W1R("*,]H]/C*XOE.F6IXRN@JJ0MI"L@L6"JX+<
M@KF"\8+%@K6"O8%"(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I
M8V\B"FUS9W-T<B`B@W:#1X.+@V>#BH-2(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-34*;7-G:60@(E!U<F=E(&UE<W-A9V5S
M(@IM<V=S='(@(H.!@V*#6H%;@U>"\(-P@5N#5R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3DV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*
M;7-G:60@(E%A=&%R(@IM<V=S='(@(H-*@UZ!6X.+(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C8T"FUS9VED(")1=65R>2(*;7-G<W1R("*#3H-'@XJ!6R(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`IM<V=I9"`B475O=&$B"FUS
M9W-T<B`B@TJ#7H%;@XLB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8V-`HC+"!P:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME
M>2`H)60@8FET*2(*;7-G<W1R(")24T&,]H]/C*XH)62#<H-B@V<I(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V,0IM<V=I9"`B4F%D:6\@<V5L
M96-T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")286EN(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0V"FUS9VED(")2
M86EN($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")286EN($QA=&4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*
M;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"FUS9VED(")286EN(&%N9"!3
M;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4P"FUS9VED(")286EN('1O(%-N;W<B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A;F1O;2!&;W)T
M=6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T<B`BE.0B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C,T"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$Q-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A9"(*;7-G<W1R
M("*3QX+>(@H*(R"3QXV>()/'CV\*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C-#,Q-"YP:'`Z-#<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.#<*;7-G:60@(E)E860@;65S<V%G97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H
M<"UF;W)M870*;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T
M:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(I9[DY:"R2`E<R""\(WM
MCYR"M8+<@K>"J3\@@K&"S)&`C>R"S8RS@LF6WX*Y@MR"N8+Q@4(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@
M5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`BEGN3
MEH+)@X:!6X-5("5S((+,@V:!6X->@O"-[8^<@K6"W(*W@JF!2"""L8+,D8"-
M[(+-CN:"Z(_!@KF"W(*Y@O&!0B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@
M86-T:6]N(@IM<V=S='(@(HW%C.."S)&`C>R"\(+B@NB2O(*W(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,Y-0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE
M;65N=',Z(@IM<V=S='(@(I.NDTF#@8-J@X6!6X+,C<257(ZFBM2*=3HB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0U"FUS9VED(")2969R97-H(%!O
M<G1A;"!6:65W.B(*;7-G<W1R("*#?(%;@UZ#BX+,C<257(ZF(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DQ(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R,3`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S,@IM<V=I
M9"`B4F5G97@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S(R.`IM<V=I9"`B4F5L871I;VYS:&EP($)R;W=S97(B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`IM<V=I9"`B4F5L;V%D(@IM<V=S='(@
M(H.*@XV!6X-H(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,S,*;7-G:60@
M(E)E;6%R:W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Q-PIM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B@XJ#@H%;@V>#
M5(%;@W*#6"(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM
M<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D
M92DZ(@IM<V=S='(@(H.*@X*!6X-G55),("AH='1P.B\O=W=W+F5X86UP;&4N
M8V]M+VAO<F1E*3H@(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHR,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S"FUS
M9VED(")296UO=F4B"FUS9W-T<B`BC>V/G"(*"B,Z('1E;7!L871E<R]P;W)T
M86PO;&%Y;W5T+FEN8SHQ,0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@
M(H-U@XV#8H-.@O"-[8^<(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C4U.0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C0P"FUS9VED(")296UO=F4@9F]R;6%T=&EN9R(*;7-G<W1R("*/D8ZN@O"-
M[8^<(@H*(R!M<V=S='(@(HZIE:J"S(-*@XR#DX-?@JF"YXWMCYPB"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(X"FUS9VED(")296UO=F4@<&%I
M<B(*;7-G<W1R("*#>8-!@O"-[8^<(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C(P,@IM<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E
M<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(I7;D;:"M8*]@UB#
M3H.*@W:#9X+PC>R+QH-F@T*#C(-.@V>#BH*I@N>-[8^<@K>"Z8%"(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C0R"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(HWMCYR!1B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M,`IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*
M;7-G<W1R("*"L8+,@VV!6X-H@O"#:(-,@X6#@8.3@V>"J8+GC>V/G"(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*;7-G:60@(E)E
M;6]V92!U<V5R(@IM<V=S='(@(H.&@5N#58+PC>V/G"(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")296UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B@X:!6X-5@O"-[8^<.B`E<R(*
M"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED(")2
M97%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O
M9&4Z("(*;7-G<W1R("*7=HN!@LF5U).:@L6"JX+<@KF"\3H@(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T-0IM<V=I9"`B4F5Q=65S=&5D
M('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$X-2!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C4R-PHC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<
M(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R("*7=HN!@K."ZH*](%PB)7-<(B""S2`E<R""S)#=DNB"R8YWDNB"LX+J
M@L2"HH+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV
M-S@@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-C$*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<S,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`BEW:+@8*S@NJ"O2!<(B5S7"(@@LT@5D93()#=
MDNB"R8YWDNB"LX+J@L2"HH+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U5T:6PO
M571I;"YP:'`Z-S<V"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB
M)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(I=VBX&"LX+J@KT@7"(E<UPB((+-D-V2Z(+)CG>2Z(*S@NJ"Q(*B@MR"N8+Q
M@4(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,S4*
M;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C,Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S-@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,C`*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,"!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,3`P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(H.*@UJ#8H-G(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#8*;7-G:60@(E)E<V5T
M(%!A<W-W;W)D(@IM<V=S='(@(H-P@UB#CX%;@VB"\(.*@UJ#8H-G(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*;7-G:60@(E)E<V5T(%EO
M=7(@4&%S<W=O<F0B"FUS9W-T<B`B@J""R(*]@LR#<(-8@X^!6X-H@O"#BH-:
M@V*#9R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S$*;7-G:60@(E)E<W1O
M<F4@3&%S="!1=65R>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]P:'!S:&5L;"YP
M:'`Z-S(@861M:6XO8VUD<VAE;&PN<&AP.C(Y(&%D;6EN+W-Q;'-H96QL+G!H
M<#HV-PIM<V=I9"`B4F5S=6QT<R(*;7-G<W1R("*,BXG*(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,2!T96UP;&%T97,O<')E9G,O96YD
M+FEN8SHW"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R("*#28-V
M@U:#AX.3@LF6WX+I(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C,X"FUS9VED(")2971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(H-P@UB#
MCX%;@VB"\(W$D_R7S2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)E=6YI;VXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A
M=&EO;B(*;7-G<W1R("*,LX+,C5R0K(+)EM^"MR(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,S4*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@3W!T:6]N
M<R(*;7-G<W1R("*#98-,@UB#9X-'@V:#0H->@5N"S(-)@W:#5H.'@Y,B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<P"FUS9VED(")2:6=H="(*;7-G<W1R("*)12(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,#`*;7-G:60@(E)I9VAT(&AE861E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,#DV
M"FUS9VED(")2:6=H="!V86QU97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X"FUS9VED
M(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*
M;7-G<W1R("*6\(J$(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*
M;7-G<W1R("*#BX%;@WV#:H-!(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(R-@IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R
M("(Q.#"3>(GQDUTB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C(S"FUS9VED(")2;W1A=&4@3&5F="(*;7-G<W1R("*-MH+)
MB?&372(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,CD*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R("*)18+)B?&372(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#D*;7-G:60@(E)O=R!0<F]P97)T:65S(@IM<V=S='(@(HUSD:Z0JR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S`*;7-G:60@(E)O=R!P<F]P97)T:65S(@IM<V=S='(@(HUSD:Z0JR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q
M"FUS9VED(")2;W=S.B(*;7-G<W1R("*-<X%&(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PIM<V=I9"`B4G5L
M97,B"FUS9W-T<B`BC'*0_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P
M96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`BD5."
MQ(+,C7."QI?Q@LR*U(+)C'*0_(+PB/B"K2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(HUS
M@LR*U(+)C'*0_(+PB/B"K2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P
M96%R(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S='(@(I?Q@LR*U(+)C'*0_(+P
MB/B"K2(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C$*;7-G:60@(E)U;B(*
M;7-G<W1R("*.P(US(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G5S<VEA;B!&
M961E<F%T:6]N(@IM<V=S='(@(H.-@U:#09A!EDTB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S
M"FUS9VED(")2=V%N9&$B"FUS9W-T<B`B@XN#CX.3@U\B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%($-R
M>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(E,O34E-12"(PXV&CY"6
MO"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S(S"FUS
M9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B4R]-24U%
M((C#C8:5MB(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#$*
M;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB
M"FUS9W-T<B`B4T%33""41H_8@LV.9Y=P@L6"JX+<@KF"\8%"(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4P-@IM<V=I9"`B4TU3($UE<W-A9VEN
M9R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@
M(E-13"!3:&5L;"(*;7-G<W1R(")344P@@U:#1H.+(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S(W,0IM<V=I9"`B4U%,('-T871E;65N="!F;W(@
M=F%L=64@;&]O:W5P<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#,S"FUS9VED(")34T@B"FUS9W-T<B`B4U-((@H*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B
M:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R("*0K(SW(@H*(SH@
M;&EB+V%P:2YP:'`Z,34S"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*
M;7-G:60@(E-A(@IM<V=S='(@(I-Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B
M4V%I;G0@2&5L96YA(@IM<V=S='(@(H-:@Y.#9X-W@XR#:9.'(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@T"FUS9VED(")386EN="!+:71T<R!A;F0@3F5V:7,B"FUS9W-T<B`B
M@UJ#DX-G@TR#8H-C@96#;(%;@Y2#0H-8(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED
M(")386EN="!,=6-I82(*;7-G<W1R("*#6H.3@V>#BX-6@T$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`P"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S
M='(@(H-4@Y.#<X-'@5N#BX%%@WZ#3H.-@Y.3AR(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*
M;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM<V=S
M='(@(H-:@Y.#9X-S@Y.#6H.3@V>"J(+F@M&#3X.,@VF#9H-"@5N#DX^4DX<B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR
M"FUS9VED(")386UE(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-PIM<V=I9"`B4V%M;V$B"FUS9W-T<B`B@U2#@H-!D\:7IXV1(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R("*#5(.3
M@WV#BH-MBZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4V%O(%1O;64@
M86YD(%!R:6YC:7!E(@IM<V=S='(@(H-4@Y.#9X.!@46#=H.*@Y.#5H-YEJ^.
MY8NDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*
M;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`S"FUS9VED(")3875D:2!!<F%B:6$B"FUS9W-T<B`B@U2#18-7@T&#
MB8-R@T&)I(V1(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDY
M"FUS9VED(")3879E(@IM<V=S='(@(I7;D;8B"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E-A
M=F4@7"(E<UPB(@IM<V=S='(@(EPB)7-<(B""\)7;D;8B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M879E("5S(@IM<V=S='(@(B5S((+PE=N1MB(*"B,Z('1E;7!L871E<R]P<F5F
M<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R("*#28-V
M@U:#AX.3@O"5VY&V(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-PIM
M<V=I9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(
M4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T
M;W)Y+B(*;7-G<W1R("(B"B*0MI"L@K."ZH*]D-V2Z(+P(%!(4""#6(-.@XJ#
M=H-G@L:"M8+$@U2!6X-O@LR-[(O&@V:#0H.,@TZ#9X.*@LF5VY&V@K>"Z8%"
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B)7,@
MD-V2Z(+PE=N1MH*U@MR"M8*]@4(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HY,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U<&=R
M861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("*0W9+HC5B05I=P@UB#
M3H.*@W:#9R!<(B5S7"(@@O"5VY&V@K6"W(*U@KV!0B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"FUS9VED(")38V%T=&5R
M960@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4Y"FUS9VED(")38VEE;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C$V"FUS9VED(")396%R8V@B"FUS9W-T<B`BC)^-]2(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C(*;7-G:60@(E-E87)C:"!%
M;F=I;F5S(@IM<V=S='(@(HR?C?6#1X.3@U>#DR(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Y-3(*;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R
M("*#=(-`@T.#BX+PD4F1\"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT.#4*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T
M<B`BD_J5=(+PCG>2Z(*U@L2"K8*^@K."HH%&(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D
M9"(*;7-G<W1R("*2QXG!@K>"Z8-/@XN!6X-V@O"129'P@K6"Q(*M@KZ"LX*B
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L
M96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@(I!6@K6"HH^*CIV.TH+PD4F1\(*U
M@L2"K8*^@K."HB(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV
M,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(H-4@5N#;X+PD4F1
M\(*U@L2"K8*^@K."HB(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,34V"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*;7-G<W1R("*2QXG!
M@K>"Z8.&@5N#58+PD4F1\(*U@L2"K8*^@K."HB(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HV-S8*;7-G:60@(E-E;&5C="!A
M;&PB"FUS9W-T<B`BD5."Q)%)D?`B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-C0P"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C@W,PIM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<W
M"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K
M97EB;V%R9"YP:'`Z,S<*;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R
M<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N
M(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*
M;7-G<W1R("(B"B*52Y=V@LB5MHZ:@O")NH+,@WN#8H-.@UB"J8+GD4F"\8+%
M@U*#<X%;@K>"Z8+&@4&#98-,@UB#9X-'@XJ#08+6@WF!6X-8@V>"Q8*K(@HB
M@MR"MX%"(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@
M(E-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z(@IM<V=S='(@(I/ZE72"S(OF
MD-B"Z)6VCIJ"\(YWDNB"M8+$@JV"OH*S@J*!1B(*"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T
M.B(*;7-G<W1R("*3^I5T@LR,8(ZN@O".=Y+H@K6"Q(*M@KZ"LX*B@48B"@HC
M.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDP"FUS9VED
M(")396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93HB"FUS
M9W-T<B`BE<^-6(*U@KV"HDE$@O"129'P.B(*"B,Z('1E;7!L871E<R]D871A
M+W1I;64N:6YC.C$V"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R
M.B(*;7-G<W1R("*.GHV/@LR+YI#8@NB5MHZ:@O".=Y+H@K6"Q(*M@KZ"LX*B
M@48B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L
M96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`BCIZ-CX+,C&".KH+PCG>2
MZ(*U@L2"K8*^@K."HH%&(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN
M8SHU-PIM<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N(@IM<V=S
M='(@(HCJDG:"MX+I@E&"PH+,@W2#0H%;@XN#:(+PD4F"\8+%@JV"OH*S@J*!
M0B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,3`*;7-G:60@(E-E;&5C
M="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`BD$:2LH+PD4F1\(*U@L2"
MK8*^@K."HBXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4R"FUS9VED
M(")396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(HR^
MC.J"\)%)D?""M8+$@JV"OH*S@J(Z(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS
M9W-T<B`BC^&*48.,@WR!6X-G@O"1EY!-@K>"Z2(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#0R"FUS9VED(")396YD(%--
M4R(*;7-G<W1R(")335,@D9>032(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E
M;F5G86PB"FUS9W-T<B`B@UJ#;(-+@XN+I)AAC9$B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,R,PIM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,`HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@
M(E-E<'1E;6)E<B(*;7-G<W1R("*"6(R.(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N
M96=R;R(*;7-G<W1R("*#6H.+@W*#08%%@X*#DX-E@VR#3X.-(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#(*;7-G:60@(E-E<FEA
M;"!.=6UB97(B"FUS9W-T<B`BDLJ4U"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-#D*;7-G:60@(E-E<G9E<B!D871A('=R;VYG(&]R(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H
M<#HR-PIM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G<W1R("*#6H-B@U:#AX.3
MBL>7G2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R
M("(B"@HC.B!L:6(O87!I+G!H<#HQ-#4*;7-G:60@(E-E<W-I;VYS(@IM<V=S
M='(@(H-:@V*#5H.'@Y,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S$Q"FUS9VED(")3970B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C<Y"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@
M<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N(@IM
M<V=S='(@(I99@NJ"Q(*U@MR"P8*]@W"#6(./@5N#:(+P@XJ#6H-B@V>"Q8*K
M@NF"YH*D@LF"M8+<@K>!0B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,3@*;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT
M('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R("*#?(%;@UZ#
MBX+%@T&#3H-:@UB"MX+I@XJ#@H%;@V>#5(%;@V^"\)#=DNB"M8+<@K>!0B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-PIM<V=I9"`B4V5T('EO=7(@
M<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS
M+B(*;7-G<W1R("*,OHSJ@4&.GHK4D=&!09/ZE72"\)#=DNB"M8+<@K>!0B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#$*;7-G:60@(B(*(E-E="!Y
M;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R
M969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G
M<W1R("(B"B**2HYNCIZ"S(-!@W:#BH-0@5N#5H.'@Y.!09!&DK*!08-Y@5N#
M5XW$E5R.IH%!@KN"S)&\@LR57(ZF@TF#=H-6@X>#DX+PD4F1\(*U(@HB@L2"
MK8*^@K."HBXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<W"FUS9VED
M(")3971U<"(*;7-G<W1R("*0W9+H(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E
M='5P+VEN9&5X+FAT;6PZ,S<*;7-G:60@(E-E='5P('5P9W)A9&4@<V-R:7!T
M<R!A=F%I;&%B;&4B"FUS9W-T<B`BD-V2Z(U8D%:#6(-.@XJ#=H-G(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-0IM<V=I9"`B4V5V97)A
M;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G
M<W1R("*#6H%;@U:#1H.+BZ2888V1(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0Y.`IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@(E-H;W)T(%-U
M;6UA<GDB"FUS9W-T<B`BBLB24(+(EW:6\8%&(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0U,`IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E
M9FEN960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@(H%I@X&#:H.%@5N"R(+'
M@L6!:H-6@X>!6X-G@TJ#8H-G@TR!6X*JCF>"IH+I@N:"I(+)@K6"W(*W@JF!
M2"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(S('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3$S('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS
M9VED(")3:&]W(@IM<V=S='(@(I5<CJ8B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,34U"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@
M8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*(F-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(HR[C=V"S)#=DNB"QI!6@K6"K9"VD*R"
MLX+J@KV0W9+H@L:"S(VWE:J"\)5<CJ:"MX+I@4(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#DT"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W
M:&5N(&QO9V=I;F<@:6X_(@IM<V=S='(@(H.-@T^#0X.3CIZ"R9%/B?&"S(.-
M@T^#0X.3CIZ*U(+PE5R.IH*U@MR"MX*I@4@B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-S8R"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K965P(&]R
M:6=I;F%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(W.3(*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,S`*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T
M:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`BE5R1@(WL@X&#:H.%@5N"\)5<CJ:"
MM8+<@K>"J8%((@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T
M/R(*;7-G<W1R("*)YI;*C;:"R2`E<R"#@8-J@X6!6X+PE5R.IH*U@MR"MX*I
M@4@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R
M=&EE<R!D:6%L;V<B"FUS9W-T<B`BE5R"S(-:@XN1KI"K@U^#0X-!@XV#3X+P
ME5R.IB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV-`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE
M<R!D:6%L;V<B"FUS9W-T<B`BE5R1KI"K@U^#0X-!@XV#3X+PE5R.IB(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV,`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA
M;&]G(@IM<V=S='(@(I5<@LR7\9&ND*N#7X-#@T&#C8-/@O"57(ZF(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4R"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*
M;7-G<W1R("*57(+,C7.1KI"K@U^#0X-!@XV#3X+PE5R.IB(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C`*;7-G:60@(E-H;W<@=7!L;V%D(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4R"FUS9VED(")3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W97)S
M($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4T"FUS9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-34*
M;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C$Y
M"FUS9VED(")3:')I;FLB"FUS9W-T<B`BCVN/K"(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z.3$P"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z.3<R"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3`U.`HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$Q,C`*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ
M,3@S"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP
M:'`Z,3(R,PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.C$R-3(*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-
M86YA9V5R+G!H<#HQ,C@U"FUS9VED(")3:')I;FL@;W(@;6]V92!N96EG:&)O
M=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0B"FUS9W-T<B`B
M@MR"N)?7@NB"S(-U@XV#8H-.@O"/:X^L@MR"O8+-B-J3KH*S@KF"Q(*M@KZ"
MLX*B@4(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3:65R<F$@3&5O;F4B"FUS
M9W-T<B`B@U:#1X.)@XR#28-LBZ2888V1(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.C(V-@IM<V=I9"`B4VEG;B!U<"(*;7-G<W1R("*#
M5(-#@Y.#08-B@W8B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C<Q,PIM<V=I9"`B4VEG;F%T=7)E(@IM<V=S='(@(I-DCG&/D):\(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3(*;7-G:60@
M(E-I9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`BDV2.<8^0EKR#08.+@U.#
MBH-9@X`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B"FUS9W-T
M<B`B@U:#DX-+@WR!6X.+BZ2888V1(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV-2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DS"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3(@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(S-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0S(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,#D*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S$P,@IM<V=I9"`B4VEZ92(*;7-G<W1R("*#5(-#@UDB"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM<V=I
M9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R("*5VX[G@O"#6(-,@V*#=H*W
M@NDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V86MI82(*;7-G<W1R("*#
M6(.-@V^#3(-!BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F5N
M:6$B"FUS9W-T<B`B@UB#C8-X@VJ#08NDF&&-D2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V"FUS9VED(")3;F]W(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4W"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R!3
M:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C`*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C@U"FUS9VED(")3;F]W(&1E<'1H.B`B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#D*;7-G:60@
M(E-N;W<@97%U:79A;&5N="!I;B!W871E<CH@(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#,*;7-G:60@(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R("*#7(.-
M@X*#DX^4DX<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3;VUA;&EA(@IM<V=S
M='(@(H-<@WV#BH-!EJ^.Y8NDF&&-D2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3`U"FUS9VED(")3;W)T(&]R9&5R
M('-E;&5C=&EO;B(*;7-G<W1R("*5P(+1CX>"S)%)D?`B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U.0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C0W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,38V
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"FUS
M9VED(")3;W5R8V4@861D<F5S<R(*;7-G<W1R("*1EY!-C+.#08-H@XR#6"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3@*;7-G:60@(E-O=71H($%F<FEC82(*;7-G<W1R("*3
M[(-!@W2#BH-*BZ2888V1(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3,*
M;7-G:60@(E-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S<*;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3
M;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM<V=S='(@(I/L@U>#AX%;@U>#09.'
M@463[(-4@Y.#:(-#@V*#8(^4DX<B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(96UI
M<W!H97)E(@IM<V=S='(@(I/LE+R+A2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B971W965N
M(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(I?7@LR#6H.+@L:"S)==E)(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM
M<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L
M;"(*;7-G<W1R("*#6H.+@L:+JXI%@L:"S)==E)(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HX,3(*;7-G:60@(E-P86-E<B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#`*;7-G:60@(E-P86-I;F<B"FUS9W-T<B`BEUV4DB(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@
M(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T<B`BEUV4DH+&EH21D"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<Q"FUS9VED(")3<&%I;B(*;7-G<W1R("*#6(-Y@T.#DR(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#`*;7-G:60@(E-P86TB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3
M<&5C:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R("*3P8[JE;:.FH+,D_R7
MS2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C(*;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`B@UJ#BY6JBH0B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8V"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`BE_&5JHJ$(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S='(@(HUSE:J*A"(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HV,0IM<V=I9"`B4W!O<G1S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(H-8
M@XJ#B8.3@TJ6KX[ECM")[X[EBV"+I)AAC9$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,0IM<V=I
M9"`B4W1A;F1A<F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C8R"FUS9VED(")3=&%R(%1R96LB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C4X,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-S@X"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q"FUS9VED(")3=&%T92!O
M<B!0<F]V:6YC92(*;7-G<W1R("*/0H+<@KV"S8RG(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G
M<W1R("*/\Y'4(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<Y-`IM
M<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E-T<F5E="!!9&1R
M97-S(@IM<V=S='(@(H]:CXJ4U))N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*
M;7-G<W1R("*.YH_!@K60_"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R,S`*;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S`*;7-G:60@(E-T<FEP(&1O;6%I;B!F
M<F]M('1H92!A9&1R97-S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE
M(%M#4U-=(@IM<V=S='(@(H-8@UZ#0X.+(%M#4U-=(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS
M9W-T<B`BD_HB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N
M(@IM<V=S='(@(H-4@W6#9H-"@XR#3H-G@XH@7"(E<UPB((*J@J""Z(+<@KF"
M\8%"(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,CD@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E
M<BYP:'`Z,S$W"FUS9VED(")3=6)M:70B"FUS9W-T<B`BCL"-<R(*"B,Z('-I
M9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D
M(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N
M;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@:&%S(&)E96X@87!P
M<F]V960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R("*)
MNI5T@JLB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`U"B,Z(&9R86UE=V]R
M:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP
M:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`BD*R,]R(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL
M>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B7"(E<UPB
M((+-@U:#6(-E@X""R9+'B<&"LX+J@MR"M8*]@4(B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L
M96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*
M;7-G<W1R(")<(B5S7"(@@JJ#5H-8@V6#@(*I@N>-[8^<@K."ZH+<@K6"O8%"
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI;B]P97)M<R]D96QE=&4N
M<&AP.C0V"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE
M=&5D(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB((*JC>V/G(*S@NJ"W(*U@KV!
M0B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M
M+B(*;7-G<W1R(")<(B5S7"(@@JJ#5H-8@V6#@(*I@N>-[8^<@K."ZH+<@K6"
MO8%"(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU,0IM<V=I9"`B4W5C
M8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S
M964@8VAA;F=E<RXB"FUS9W-T<B`BD-V2Z(+-D+./[8+)EM^"LX+J@MR"M8*]
M@4*#BH.-@5N#:(*U@L2*;91&@L6"JX+<@K>!0B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HU.2!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU-PIM<V=I
M9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R("*0W9+H@LR#;X-B@TZ#08-B@W:"S9"SC^V"R97;D;:"LX+J@MR"
MM8*]@4(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8R"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O
M;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`BD-V2Z(-T@T"#0X.+@LR#
M;X-B@TZ#08-B@W8@)7,@@LV0LX_M@LF5VY&V@K."ZH+<@K6"O8%"(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,38X"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*;7-G<W1R(")<(B5S7"(@@LV0LX_M
M@LF-6)!6@K."ZH+<@K6"O2(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-S$@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L('!H<"UF;W)M870*;7-G
M:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R("(E<R""S9"SC^V"
MR8^1@JN-GH+<@NJ"W(*U@KTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=61A
M;B(*;7-G<W1R("*#6(%;@U^#DXNDF&&-D2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*;7-G:60@(E-U;6UA
M<GDB"FUS9W-T<B`BBE27=B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV
M-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`BD_J"S(]O(@H*(SH@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(I/Z
M@LR3_(+H(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C$*;7-G:60@(E-U;FYY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,#4*;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I
M<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R("*3^H+,
MCV\OD_J"S)/\@N@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C`T"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`BD_J"S(]O@48B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`X"FUS9VED(")3=6YS970B
M"FUS9W-T<B`BD_J6=B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,#<*;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@(I/ZEG:!1B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@
M(E-U<&5R<V-R:7!T(@IM<V=S='(@(H_CE72"JR(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS.#`*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B@U2#
M?(%;@V<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3=7)I;F%M92(*;7-G<W1R
M("*#6(.*@VF#@(NDF&&-D2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3<U"FUS9VED(")3=7)N86UE(@IM<V=S='(@(I"I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G
M<W1R("*#6(.4@T"!6X.+@V^#BX%!@X2#DX-]@T.#1X.3CY23AR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R("*#6(./@U>#B8.3
M@VB)I(V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM<V=S='(@
M(H-8@T6#1H%;@V:#DXFDC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I='IE
M<FQA;F0B"FUS9W-T<B`B@UB#0X-8F$&632(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C@V"FUS9VED(")3>6YC(&QO9R!D96QE=&5D(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#4*;7-G:60@(E-Y
M;F--3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D
M<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4WER:6%N($%R86(@
M4F5P=6)L:6,B"FUS9W-T<B`B@U:#BH-!@46#08.)@W6+I)AAC9$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B
M5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C0*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")4+5-T;W)M
M<R!%87)L>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+W1S
M=BYP:'`Z,38V"FUS9VED(")44U8@9FEL92(*;7-G<W1R(")44U:#=(-`@T.#
MBR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`BE5R1
MKI"K(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H
M<#HU-PIM<V=I9"`B5&%B;&4@4V5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*;7-G:60@
M(E1A8FQE('!R;W!E<G1I97,B"FUS9W-T<B`BE5R1KI"K(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,S0@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,0IM<V=I9"`B5&%I=V%N(@IM<V=S='(@(I'DF'`B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I9"`B5&%I
M=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R("*1Y)AP@6F2AHV1@LR(
MZI64@6HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")486II:VES=&%N(@IM<V=S
M='(@(H->@U>#3(-8@UZ#DXNDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@
M(E1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8B"FUS9W-T<B`B@UZ#DX-5
M@VJ#09A!EDV+I)AAC9$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CDU"FUS9VED(")487)G970Z(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,R(&-O;F9I9R]H;V]K<RYP
M:'`N9&ES=#HQ,#0Y"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#D*
M;7-G:60@(E1A<VMS(@IM<V=S='(@(H->@UB#3B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3<T"FUS9VED(")496QE<&AO;F4@3G5M
M8F5R(@IM<V=S='(@(I-DF&*4U(V&(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR.3<*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(Q"FUS9VED(")496UP97)A='5R
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C$R"FUS9VED(")496UP97)A='5R93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP
M.C8Y-0HC+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S7"(@;F]T
M(&9O=6YD+B(*;7-G<W1R("*#98.3@W:#C(%;@V<@7"(E<UPB((*J@J""Z(+<
M@KF"\8%"(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@(E1E
M;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(H-E@Y.#=H.,@5N#9X+,
MBL>7G2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,#@@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S,R-`IM<V=I9"`B5&5X="(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Y"FUS9VED(")497AT($]N
M;'DB"FUS9W-T<B`B@V6#3(-8@V>"S(+=(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`IM<V=I9"`B5&5X="!A
M;&EG;B(*;7-G<W1R("*5MHZ:E'J2=2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B"FUS9W-T
M<B`BE;:.FH+,C^,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R("*6V"(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R
M("*#7H-#B:2-D2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#4Q
M"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R(")&5%`@BF>2HX*J@J""Z(+<@KF"\8%"(@H*(SH@9G)A;65W;W)K
M+TAI<W1O<GDO2&ES=&]R>2YP:'`Z-34*;7-G:60@(E1H92!(:7-T;W)Y('-Y
M<W1E;2!I<R!D:7-A8FQE9"XB"FUS9W-T<B`BEYJ7\(-6@UB#98.`@LV6LXSX
M@LF"R(+!@L2"HH+<@K>!0B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3,X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!(;W)D92]+;VQA8B!I
M;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O0F]O:RYP:'`Z
M,3(Y.`IM<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L
M:7IE9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C,Q"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO
M860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(DUA:6YT96YA;F-E((-.@XF#6(+,
MD\>-GH+=@JJ0LX_M@LF-<X*F@MR"N8+Q@L6"M8*](@H*(SH@<V5R=FEC97,O
M:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I9"`B5&AE($]P=&EO;G,@
M=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM<V=S='(@(H-)@W:#5H.'
M@Y.#18-"@Y.#:(-%@O"5PH*V@MR"M8*]@4*/29>Y@K6"W(*W@4(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$X.2!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C(P,`HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(Q
M,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(R,PHC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C(S-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C(U,@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(V-"!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C,P,PIM<V=I9"`B(@HB5&AE(&%D;6EN:7-T
M<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I
M;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS
M+B(*;7-G<W1R("(B"B*#08-.@UJ#6(R@@O"73(SX@LF"MX+I@LF"S8K'EYV.
MTH*J@KN"S(-O@V*#3H-'@Y.#:(+PD-V2Z(*W@NF"L8+&@JJ52Y=V@L6"MX%"
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T
M('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H
M92`B"B)D871A8F%S92XB"FUS9W-T<B`B(@HBF$&7C9#F2424U(V&@JJ.=Y+H
M@K."ZH+(@JF"P8*]@JF!08OS@KZ"P8*]@JF!08*@@NF"HH+-@V:!6X->@WB!
M6X-8DH:"R8RIE72"J2(*(H+H@MR"N8+Q@L6"M8*]@4(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*;7-G:60@(E1H92!C
M;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S
M(&)O;VLN(@IM<V=S='(@(IA!EXV0YH+-@J""R(*]@LR#08-H@XR#6)*@@LF2
MQXG!@K."ZH+<@K6"O8%"(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3$W,@IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U
M<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S
M<V%G92XB"FUS9W-T<B`BDV2.<8^0EKR"LX+J@KV#@8-B@UJ!6X-7@O",GX_8
M@K>"Z8+)@LV!05!'4""/D):\@JJ52Y=V@L6"MX%"(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@(B(*
M(E1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C
M:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D871A
M8F%S92XB"FUS9W-T<B`B(@HBD9>039#F2424U(V&@JJ.=Y+H@K."ZH+(@JF"
MP8*]@JF!08OS@KZ"P8*]@JF!08*@@NF"HH+-@V:!6X->@WB!6X-8DH:"R8RI
ME72"J2(*(H+H@MR"N8+Q@L6"M8*]@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R
M:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R("*1EY!-
MD.9)1)34C8:"JHYWDNB"LX+J@MR"N8+Q@L6"M8*]@4(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q-@IM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@
M9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS
M9W-T<B`BB,.-AHF[@LF"S8C`D5."R(-%@T:#=9#:D;&"JI5+EW:"Q8*W@4(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$X-B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C4R.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@
M(H-T@T"#0X.+("5S((+)@LT@)7,@@LR0W9+H@JJ52Y![@L6"MX%"(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-SD@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HU,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@
M)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS9W-T<B`B
M@W2#0(-#@XL@)7,@@LF"S2`E<R""S)#=DNB"JI5+D'N"Q8*W@4(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,C8*;7-G:60@(E1H92!F:6QE
M(&-A;FYO="!B92!C;W!I960@;VYT;R!I='-E;&8N(@IM<V=S='(@(H-T@T"#
M0X.+@LV.J96JCJF09X+)@U*#<X%;@L6"JX+<@KF"\8%"(@H*(SH@9G)A;65W
M;W)K+T1A=&$O1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@9FEL92!C;VYT86EN
M960@;F\@9&%T82XB"FUS9W-T<B`B@W2#0(-#@XN"JH-F@5N#7H+PBMR"\8+%
M@J*"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D
M97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@
M(HC(B;J"S8*Q@LR#@8-B@UJ!6X-7@6E21D,X,C*!:H+,@W>#8H-?@L6"MX%"
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU
M-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@
M8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E("(*
M(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K
M87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P
M;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B
M<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S
M(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R
M86P@(@HB4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQ<
M;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E("(*(G!R97-S($]+
M(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I
M=&]R+B(*;7-G<W1R("(B"B*2C8C3@4D@@W2#BX-8@TZ#BH%;@Y.#@H%;@VB"
MS2!);G1E<FYE="!%>'!L;W)E<B""Q8+-EN*1Z(*JE*V0MH*W@NF"L8+&@JJ"
MH(+H(@HB@MR"MX%I@W6#B8-%@U6"S(-O@T^"Q8*W@6J!0HGFELJ"R8-3@WZ"
MJI5<CJ:"LX+J@KV"Z(%!5VEN9&]W<R""JH-.@XF#8H-6@X6"M2(*(H*]@NB"
MMX+I@JF"X(*U@NJ"W(*Y@O&!0EQN(@HB@W2#BX-8@TZ#BH%;@Y.#@H%;@VB"
MR8*W@NF"R(+G($]+((+PB9^"M8+$B;J"LX*B@4(B"@HC.B!S97)V:6-E<R]P
M<F5F<RYP:'`Z,3$Q"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!I9&5N=&ET
M>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B240@7"(E<UPB
M((+-C>V/G(*S@NJ"W(*U@KV!0B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T+6AA
M;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H
M92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P
M.CH@8VQA<W,N(@IM<V=S='(@(B(*(D=N=5!'((-O@T.#:8.*@LR#<(-8@JH@
M0W)Y<'1?<&=P((-.@XF#6(+)D-V2Z(*S@NJ"Q(*B@NF52Y=V@JJ"H(+H@MR"
MMX%"(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C(P,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O
M("5S('=I=&@@<W5B:F5C="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN
M(@HB5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@
M8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S0*;7-G:60@(E1H92!N86UE('1O('5S
M92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-S0*;7-G:60@(E1H
M92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`B
M@K&"S(-T@T*!6X.+@VB"S9"4CIJ"Q8+(@J^"ZH+.@LB"Z(+<@KF"\8%"(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C,R"FUS9VED
M(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D
M95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R(")(;W)D95]#<GEP=%]S
M;6EM98-.@XF#6(+)@LUO<&5N<W-L@X*#5X.%@5N#BX*JE4N7=H+%@K>!0B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,CDU"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@
M8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@(@HB;6%X
M:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"B*#=H.,@W2#0(.,@Y.#
M6%PB)7-<(H+-@V:!6X->@JJ#5(-#@UF0IXS`@O")>H*F@KV"O8+?E=N1MH+%
M@JN"W(*Y@O&"Q8*U@KTN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O9&5B+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]E
M;G-C<FEP="YP:'`Z,S4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)P;2YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=V5B8W!P+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]S
M<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S
M(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R("(B"B*"L8+,@V:!
M6X->C%XH)7,I@O"57(ZF@K>"Z8*]@M^"S(-V@XV#3X.)@X""JH*Q@LR#5H-8
M@V6#@(+)@MV"PH*I@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C0X-PIM<V=I9"`B5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T
M(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("*(^)=PE82"S8)0
ME;:.FH+%@LB"KX+J@LZ"R(+H@MR"N8+Q@4(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS9VED(")4:&4@
M<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS
M9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#<Y"FUS9VED(")4:&4@<V5P
M87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@
M(HOFD-B"Z)6$@LV"4)6VCIJ"Q8+(@J^"ZH+.@LB"Z(+<@KF"\8%"(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS
M9W-T<B`B@U2!6X-O(%PB)7-<(B""S8WMCYR"LX+J@MR"M8*]@4(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T
M<B`B@U2!6X-O(%PB)7-<(B""S97;D;:"LX+J@MR"M8*]@4(B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU
M<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C0W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R`H
M)60I(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("*.=Y+H@K6"O9?Q@6DE9(%J
M@JJ"H(+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C$W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y(&9I;&4@
M7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("*(ZHZ>@W2#0(-#@XL@
M7"(E<UPB((*J@J""Z(+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S(Y.0IM<V=I9"`B5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO
M="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<Y"FUS9VED(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HS,C<*;7-G:60@(E1H
M92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S
M=&5P+B(*;7-G<W1R("*#08-B@W:#C8%;@VB#9H%;@UZ"JI*\D4^"S(-8@V6#
M8H-V@L6/P8ZX@K6"W(*U@KV!0B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O
M8W-V+G!H<#HR-C(@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$W,@IM
M<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*
M;7-G<W1R("*#08-B@W:#C8%;@VB#9H%;@UZ"\)7;D;:"Q8*K@MR"N8+Q@L6"
MM8*]@4(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#D@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q,`IM<V=I9"`B5&AE('=E871H
M97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z
M('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5M97,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@
M(H-E@5N#?8-F@T*#C(-.@V>#BH%;(%PB)7-<(B""JH*@@NB"W(*Y@O&!0B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3<X"FUS9VED(")4
M:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@(HYWDNB"
MQ8*K@NF#28-V@U:#AX.3@LV"H(+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HS-#@*;7-G:60@(E1H97)E(&%R92!N
M;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R
M("*#0X.3@XF#0X.3E5R.IH+%@JN"Z964E:J"S8*@@NB"W(*Y@O&!0B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S.3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI
M<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y
M;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*(I6VCIJ0
ME(*J@K&"S(-T@T*!6X.+@VB"R9&]B=^"K(+<@K<N("5S((+,E;:.FH*JD_R7
MS8*S@NJ"Q(*B@MR"MRX@)7,@B,B)NH+%@L@B"B*"K8+$@LV"HH*O@MR"N8+Q
M@4(B"@HC.B!S:6=N=7`N<&AP.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG(%PB
M)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R(")<(B5S7"(@@O"#5H-8
M@V6#@(+6DL>)P9*&@LF6XI'H@JJ4K9"V@K6"W(*U@KTZ("5S(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3(R"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O
M;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B@X:!6X-5(%PB)7-<(B""S(-F@5N#
M7H+P@U:#6(-E@X""J8+GC\&+CI*&@LF6XI'H@JJ4K9"V@K6"W(*U@KTZ(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R;VT@=&AE('-Y
M<W1E;3H@(@IM<V=S='(@(EPB)7-<(B""\(-6@UB#98.`@JF"YXWMCYR2AH+)
MEN*1Z(*JE*V0MH*U@MR"M8*].B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('5P9&%T
M:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B7"(E<UPB((+PC5B05I*&@LF6XI'H
M@JJ4K9"V@K6"W(*U@KTZ("5S(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O
M=W-E<BYP:'`Z.3(W"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO
M861E9"XB"FUS9W-T<B`B(@HB@W2#0(-#@XN#08-B@W:#C8%;@VB"R9;BD>B"
MJI2MD+:"M8+<@K6"O3H@)7,@@LV#08-B@W:#C8%;@VB"LX+J@L2"HH+<@KF"
M\8%"(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3,R"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE
M(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@
M(B(*(H-T@T"#0X.+@T&#8H-V@XV!6X-H@LF6XI'H@JJ4K9"V@K6"W(*U@KTZ
M("5S((+-@W2#0(-#@XN"S(-4@T.#69"GC,"2;"@E9(-O@T,B"B*#9RF"\(EZ
M@J:"Q(*B@MR"MX%"(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP
M:'`Z.3,T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R
M;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P
M87)T:6%L;'D@=7!L;V%D960N(@IM<V=S='(@(B(*(H-T@T"#0X.+@T&#8H-V
M@XV!6X-H@LF6XI'H@JJ4K9"V@K6"W(*U@KTZ("5S((+-B.J5E(+,@MV#08-B
M@W:#C8%;@VB"LX+J@MR"M2(*(H*]@4(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R("*"
ML8+,@W"!6X-G@O"57(ZFDH:"R8-'@XF!6X*JE*V0MH*U@MR"M8*](@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A
M+B(*;7-G<W1R("*809>-D.:#9H%;@UZ"S(-#@Y.#?(%;@V>2AH+)@T>#B8%;
M@JJ4K9"V@K6"W(*U@KV!0B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC
M+G!H<#HS,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(FE#86QE;F1A<B""S(-#@Y.#
M?(%;@V>2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KTN(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HX,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R
M(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@
M;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(B(*(I#=DNB#=(-(
M@5N#@)*&@LF#1X.)@5N"JH*@@NB"W(*U@KV!0H*]@M2"\8%!E4N0>XV`EMJ"
MJHOSE)*"OH+!@KV"S(+%@K6"Y8*D@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S
M(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM
M<V=S='(@(B(*(HYWDNB"LX+J@KV#08-H@XR#6)*@@LR1@(WLDH:"R8-'@XF!
M6X*JE*V0MH*U@MR"M8*]@4*,XX+%C<23>([`C7."M8+$@JV"OH*S(@HB@J*!
M0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@
M=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB
M"FUS9W-T<B`BF$&7C9#F@LR/VHW7@O"-6)!6DH:"R8-'@XF!6X*JE*V0MH*U
M@MR"M8*]@4*,XX+%C<23>([`C7."M8+$@JV"OH*S@J*!0B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(R"FUS9VED("(B
M"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO
M;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("*1EY!-
MD.:#BH-8@V>"S(U8D%:2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KV!0HSC@L6-
MQ)-XCL"-<X*U@L2"K8*^@K."HH%"(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS9VED(")4:&ES($E-05`@<V5R=F5R
M(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R("*"
ML8+,($E-05`@@U2!6X-O@LV+I)=,@W2#2(.+@U^"\(-4@WR!6X-G@K6"Q(*B
M@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C0X"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A
M;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R("*"L8+J@LV73(SX@L@@<F%R((-!
M@5N#2H-#@W6"Q8+-@LB"HH+F@J2"Q8*W@4(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R("*"L8+J
M@LV73(SX@L@@>FEP((-T@T"#0X.+@L6"S8+(@J*"YH*D@L6"MX%"(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R-`IM<V=I9"`B5&AI<R!D;V5S
M(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@
M(H*Q@NJ"S9=,C/B"R(-*@5N#:)34C8:"Q8+-@LB"HH+F@J2"Q8*W@4(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ
M.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC
M:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M,3,T"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B
M"B)G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*
M;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I
M;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P
M+G!H<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A
M;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R
M97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D869O;F4@271A
M;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.3<U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$P-30*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`X,R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,3$R"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q-SD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(U,PHC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`R(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$S.34*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34U-"!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#,V"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y-34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P,@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#(V(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P-S4*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$T-B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C$X"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(T,#4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0T-PHC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C,T(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X,#<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q
M-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,CDT"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,X,#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@Q
M,`IM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B@K&"
MS(-T@T*!6X.+@VB"S95+D'N"Q8*W@4(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,#8R"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@:6YT96=E<G,N(@IM<V=S='(@(H*Q@LR#=(-"@5N#BX-H@LV0KI"4@L6"
MR(*M@L2"S8*B@J^"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(T,3,*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N
M=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(H*Q@LR#=(-"@5N#BX-H
M@LV0E(Z:@L:#4H.-@Y."Q8+(@JV"Q(+-@J*"KX+<@KF"\8%"(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`Y,0IM<V=I9"`B5&AI<R!F:65L9"!M
M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B@K&"S(-T
M@T*!6X.+@VB"S3B0:9"4@L6"R(*M@L2"S8*B@J^"W(*Y@O&!0B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,C`*;7-G:60@(E1H:7,@9FEE;&0@
M;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN
M=&5G97)S(@IM<V=S='(@(B(*(H*Q@LR#=(-"@5N#BX-H@LV#4H.3@WV"W(*]
M@LV+\Y22@L6+YI#8@N>"ZH*]D*Z0E(+,@XJ#6(-G@L6"R(*M@L2"S8*B@J^"
MW(*Y(@HB@O&!0B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDX-@IM
M<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+B(*;7-G
M<W1R("*"L8+,@W2#0H%;@XN#:(+-D)2.FH+%@LB"KX+J@LZ"R(+H@MR"N8+Q
M@4(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$U"FUS9VED("(B
M"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE
M(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM
M<V=S='(@(H*Q@LR#=(-"@5N#BX-H@LTQ-I!I4D="E5R+3(+,D$:#4H%;@VB"
MR(*M@L2"S8*B@J^"W(*Y@O&!0I?A.B<C,3(S-&%F)RXB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HU-3@*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR
M96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B@K&"S(-T@TB!6X.`@LV*
M^8+)CXB7G8*S@NJ"Q(*B@MR"MX%"(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O
M=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-CD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R
M92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A
M;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@
M1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*
M(F-L:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T
M97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B(@HB
M@K&"S(.!@V*#6H%;@U>"S8*@@LB"O8*JCF>7<(*W@NF"S(+&B-F"R(+IE;:.
MFH-:@V*#9X%I)7.!:H+%CY&"J8+J@L2"HH+<@K>!0B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M
M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T<B`B@K&"S)34C8:"S8W%CZR"
MQ8+@,8+%@LB"K8+$@LV"HH*O@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R
M(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R
M("*"L8+,@U2!6X-O@L6"S7II<(+&9WII<(-T@T"#0X.+@O"35XI*@L6"JX+<
M@KF"\8%"(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H
M<#HQ.#D*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV
M871E9"XB"FUS9W-T<B`B@K&"S(-6@UB#98.`@LV(ZHZ>DTF"R9:SC/B"R8+(
M@L&"Q(*B@MR"MX%"(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS
M9W-T<B`B@K&"S))L@LV0E(Z:@L6"R(*O@NJ"SH+(@NB"W(*Y@O&!0B(*"B,Z
M('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H
M:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD
M;W<B"FUS9W-T<B`B@K&"S(-%@T*#DX-H@T6"S8-)@W:#5H.'@Y.#18-"@Y.#
M:(-%@JF"YXS$CV^"LX+J@NF52Y=V@JJ"H(+H@MR"MX%"(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E1H=6YD
M97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S
M-@IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-#(R('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U
M-0IM<V=I9"`B5&EM92(*;7-G<W1R("*.GHK4(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,X.`IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R
M("*#7H-#@X"#5H%;@V<B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3<*;7-G
M:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(HZ>BM2/D8ZN(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C4R.`IM<V=I9"`B5&EM92!S96QE8W1I;VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S=&4B
M"FUS9W-T<B`BDXR#98-"@X*!6X.+EJ^.Y8NDF&&-D2(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@;&EB+T)L;V-K+VEF
M<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@(H->@T.#9X.+(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM
M<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED(")4;R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C4T"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L
M(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@
M:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"B*5H9"4@LR-@);:
M@O"129'P@K>"Z8+)@LV!05!#@L6"S4-O;G1R;VR#3(-#@4%-86."R(+G0V]M
M;6%N9(-,@T."\(F?@K6"R(*J@N>#3B(*(H.*@V*#3H*U@MR"MX%"(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,`IM<V=I9"`B5&]D87DB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@
M(DA434R#7(%;@UB57(ZFD-B1UB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1O
M9V\B"FUS9W-T<B`B@V>!6X-3BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I
M9"`B5&]K96QA=2(*;7-G<W1R("*#9X-0@XF#18^4DX<B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`R"FUS9VED(")4;VUO<G)O=R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G<W1R("*#
M9X.3@TN)I(V1(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K;VQA8BYP:'`Z
M,3`T"FUS9VED(")4;V\@;6%N>2!I;G9A;&ED(&QO9VEN<R!D=7)I;F<@=&AE
M(&QA<W0@;6EN=71E<RXB"FUS9W-T<B`B@K&"S)"4E:J*U(+)B;V3>(+@@XV#
M3X-#@Y."JHZ.C7."LX+J@MR"M8*]@4(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S<*;7-G:60@(E1O<"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDS"FUS9VED(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I9"`B5')A;G-L871I;VYS
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N
M9"!4;V)A9V\B"FUS9W-T<B`B@V>#BH-J@U^!6X-H@46#9X-O@U.+I)AAC9$B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S@W"FUS9VED(")4<G5E
M(&]R(&9A;'-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(HG.(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R("*#8(.%@VJ#
M5X-!BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5R:V5Y(@IM<V=S
M='(@(H-G@XN#4HNDF&&-D2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DU
M"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$P"FUS9VED(")4=7)K;65N:7-T86XB"FUS9W-T<B`B@V>#BX-.
M@X&#:H-8@UZ#DR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#
M86EC;W,@27-L86YD<R(*;7-G<W1R("*#7H%;@TZ#6(%%@TJ#0X-2@UB/E).'
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5V86QU(@IM<V=S='(@(H-C@V^#
MBR(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@
M>6]U<B!C:&]I8V4Z("(*;7-G<W1R("*129'P@48B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C4X"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM<V=I9"`B55),(@IM
M<V=S='(@(E523"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E
M;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PIM<V=I9"`B55),.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")59V%N9&$B"FUS9W-T
M<B`B@T6#2X.3@U^+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")5:W)A
M:6YE(@IM<V=S='(@(H-%@TZ#B8-#@VDB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HT,3D*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@5D93(&1I
M<F5C=&]R>2XB"FUS9W-T<B`B5D93((-F@T*#C(-.@V>#BH+)@T&#3H-:@UB"
MQ8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP
M:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA
M=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,SDS"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R(")61E,@@W2#0(-#@XL@7"(E<UPB((+,@T&#3H-:@UB,H(+-
ME<^-6(+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C,Y,B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#8X"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F
M;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(E9&4R"#=(-`@T.#BR`E<R\E
M<R""S(-!@TZ#6H-8C*""S97/C5B"Q8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C<X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R("(E<R""R97/C5B"Q8*K
M@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(S-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE
M(&]F(%PB)7-<(BXB"FUS9W-T<B`B@W2#0(-#@XL@7"(E<UPB((+,@U2#0X-9
M@JJ#8(-&@V*#3H*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HV.34@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ,#(X"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HX-3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S
M+R5S7"(N(@IM<V=S='(@(H-T@T"#0X.+(%PB)7,O)7-<(B""S(-4@T.#68*J
M@V"#1H-B@TZ"Q8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W-Q;"YP:'`Z-#,Y"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@
M<V5R=F5R+B(*;7-G<W1R(")344P@@U2!6X-O@LF0VI&Q@L6"JX+<@KF"\8%"
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-S`*;7-G:60@(E5N
M86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R(")34TP@@L60VI&Q
M@L6"JX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,C,R(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(S-PHC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`T(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HR,#D*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C(Q-PIM<V=I9"`B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM
M<V=S='(@(E9&4R"#=(-`@T.#BX+P@U*#<X%;@L6"JX+<@KF"\8%"(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-S`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB
M"FUS9W-T<B`B5D93((-F@T*#C(-.@V>#BB!<(B5S7"(@@O"-[)"L@L6"JX+<
M@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S8Q(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C(V-`IM<V=I9"`B56YA8FQE('1O(&-R96%T
M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")61E,@@V:#0H.,@TZ#9X.*@O"-
M[)"L@L6"JX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C$R-`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9FEL92XB"FUS
M9W-T<B`B5D93((-T@T"#0X.+@O"-[)"L@L6"JX+<@KF"\8%"(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T
M<B`B5D93((-F@T*#C(-.@V>#BB!<(B5S7"(@@O"-[)"L@L6"JX+<@KF"\8%"
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C<R"FUS9VED(")5
M;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R("*+\X+,
M(%9&4R"#=(-`@T.#BX+PC>R0K(+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N<&AP.C<V"B,Z(&9R86UE=V]R:R]#
M;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HW.0IM<V=I9"`B56YA8FQE('1O
M(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B@V:!6X->@O"(LX]K@L6"JX+<
M@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,C@@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,#,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@
M;F]T(&5M<'1Y+B(*;7-G<W1R(")<(B5S7"*"\(WMCYR"Q8*K@MR"N8+Q+B"#
M9H-"@XR#3H-G@XJ"JHOS@L6"S8*@@NB"W(*Y@O&!0B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z-S@@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM
M<V=S='(@(EPB)7-<(H+PC>V/G(+%@JN"W(*Y@O$Z("5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S."!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C,Y-0HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S$Q
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R
M>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B)7."\(WMCYR"Q8*K@MR"N8+Q+B"#
M9H-"@XR#3H-G@XJ"JHOS@L6"S8*@@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-38@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C,V,`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R(")61E,@@V:#0H.,@TZ#
M9X.*@O"-Q(M!DTF"R8WMCYR"Q8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HS-#0@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C,R,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,U,@IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")61E,@@V:#0H.,@TZ#9X.*@O"-
M[8^<@L6"JX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HT,C`@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E
M<RXB"FUS9W-T<B`B5D93((-F@T*#C(-.@V>#BH+PC>V/G(+%@JN"W(*Y@O&!
M1B5S(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S
M7"(N(@IM<V=S='(@(E9&4R"#=(-`@T.#BR!<(B5S7"(@@O"-[8^<@L6"JX+<
M@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S$P(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,CDQ"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HQ-C<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C$X,`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@W(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.3$*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,Y.0IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@9FEL92XB"FUS9W-T<B`B5D93((-T@T"#0X.+@O"-[8^<@L6"JX+<
M@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-#@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R
M(%PB)7-<(BXB"FUS9W-T<B`B5D93((-F@T*#C(-.@V>#BB!<(B5S7"(@@O"-
M[8^<@L6"JX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HT,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R(")61E,@@O"-Q(M!DTF"R8WM
MCYR"Q8*K@MR"N8+Q@48E<R(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z.#,T"FUS9VED(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER
M96-T;W)Y+B(*;7-G<W1R("*,NXW=@LR#9H-"@XR#3H-G@XJ!6X*JD\&2Z(+%
M@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C`T"FUS9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D
M971A:6QS(@IM<V=S='(@(H_8EKZ/D8+,C]J-UX*JCN:"Z(]O@KF"W(*Y@O$B
M"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z-#,W(&9R86UE=V]R
M:R].971?24U34"])35-0+T%U=&@N<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS
M9W-T<B`B)7,@@LR2Z(M@@JJ#C8%;@VB"Q8*K@MR"N8+Q@4(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,#,@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,C`X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ-S0@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$W.0IM<V=I
M9"`B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(E9&4R"#=(-`
M@T.#BX*JB-J3KH+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z.3,@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ,#8*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HV-3(@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HY.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(E9&4R"#=(-`@T.#BR!<
M(B5S7"(@@JJ*2H*O@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HR.#0@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S
M.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,30Q"FUS9VED
M(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T
M<B`B5D93((-T@T"#0X.+@O"/D8*KC9Z"W9=P@LF*2H*O@MR"N8+Q@4(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HX,R!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HQ,S<*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C<V"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB"FUS
M9W-T<B`B5D93((-T@T"#0X.+@JJ*2H*O@MR"N8+Q@4(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C0U"FUS9VED(")5;F%B;&4@
M=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@(HBSCVN/D8S)
M@W2#0(-#@XN"\(I*@J^"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HX-38*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE
M<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(E9&4R"#=(-`@T.#BX*JD\>"WX+<
M@KF"\8%I9FEL97-I>F4H*2"#1X.)@5N!:H%"(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C@X-PIM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@
M*&=E=$9I;&53:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B5D93((-T@T"#0X.+
M@JJ3QX+?@MR"N8+Q@6EG971&:6QE4VEZ92@I((-'@XF!6X%J@4(B"@HC.B!F
M<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O;F]N92YP
M:'`Z,S@*;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R(")6
M1E,@@W2#0(-#@XN"JI/'@M^"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C8W-@IM<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F
M<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R(")V9G-R;V]T((-F@T*#C(-.@V>#
MBH+PD\>"WX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HQ,3`Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*
M;7-G<W1R("*6O)%/("5S((+P("5S((+)E<^-6(+%@JN"W(*Y@O&!1H-T@TB#
MBX-?@5N"S8KY@LF1MHW=@K6"W(*W(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C,P,0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@
M9&ER96-T;W)Y+B(*;7-G<W1R(")61E,@@V:#0H.,@TZ#9X.*@5N"S):\D4^"
M\)7/C5B"Q8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE
M(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R(")61E,@@V:#0H.,@TZ#9X.*
M@5N"S):\D4^"\)7/C5B"Q8*K@MR"N8+Q@48E<R(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z,C<Q(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,S0X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93
M(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")61E,@@W2#0(-#@XL@7"(E<UPB((+,
MEKR13X+PE<^-6(+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C8Q-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C(Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I
M;&4@)7,O)7,N(@IM<V=S='(@(E9&4R"#=(-`@T.#BR`E<R\E<R""S):\D4^"
M\)7/C5B"Q8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C,R-B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$S"B,Z(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-3(@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C(Y,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,S`Y"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE
M+B(*;7-G<W1R(")61E,@@W2#0(-#@XN"S):\D4^"\)7/C5B"Q8*K@MR"N8+Q
M@4(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI
M<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O
M<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R
M9"!D;V-U;65N="(*;7-G<W1R("*"L8+,(%=O<F0@E;:/D8+PEGR6\X+%@JN"
MW(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,34T(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,34W"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(E9&4R"#=(-`@T.#BR!<(B5S7"(@@LF/D8*O@MR"N8+Q@4(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ.#8*;7-G:60@(E5N86)L92!T;R!W
M<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(E9&4R"#
M=(-`@T.#BX+)CY&"KX+<@KF"\8%I8V]P>2@ICKB4<X%J@4(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR.#@@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C$T-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,34Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T
M82XB"FUS9W-T<B`B5D93((-T@T"#0X.+@LF/D8*O@MR"N8+Q@4(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z.#8R"FUS9VED(")5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N(@IM<V=S='(@
M(E9&4R"#=(-`@T.#BX+)CY&"KX+<@KF"\8%"<75O=&$@@O"2M(G?@K6"O8+F
M@J2"Q8*W@4(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`BB;J0_"(*"B,Z
M('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E
M<R(*;7-G<W1R("*5SXU8@O".YH+HC\&"MR(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R
M(&QA<W0@86-T:6]N(@IM<V=S='(@(HW%C.."S)&`C>R"\(RS@LF6WX*W(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(Q"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.`IM<V=I
M9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T
M:6]N.B`B"FUS9W-T<B`BD-J1L8Z>@LR#5(%;@V^!6X*I@N>"S)=<BOJ"M8+(
M@J*)GI.:@48B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HR,3<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S,Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,W-@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M.#(*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z
M("(*;7-G<W1R("*#5(%;@V^!6X*I@N>"S)=<BOJ"M8+(@J*)GI.:@48B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU
M-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV
M,0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R("*6HI"NEYTB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B56YI8V]D92`H551&+3@I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")5;FET960@07)A8B!%;6ER871E
M<R(*;7-G<W1R("*#08.)@W6.\9*WC9&8099-(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS
M9VED(")5;FET960@2VEN9V1O;2(*;7-G<W1R("*)<(V1(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R("*5Q(V1(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,SD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN
M9R!)<VQA;F1S(@IM<V=S='(@(I7$E\R1OI6]EVV/E).'(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C8R(&QI8B]";&]C:R]M971A<BYP:'`Z
M-S@*;7-G:60@(E5N:71S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0R.2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,S`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H
M<#HU.`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R("*5<Y:^(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED
M(")5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A
M9V4@240I+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,30W"FUS9VED(")5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3$*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S
M<W=O<F0N(@IM<V=S='(@(H.&@5N#59:\@JF#<(-8@X^!6X-H@JJ5<Y:^@L6"
MMX%"(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN
M<&AP.C,P,@IM<V=I9"`B56YN86UE9"(*;7-G<W1R("*6LY:\(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B
M(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P
M>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O
M;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII
M;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R
M:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"B*#6H-,
M@X6#BH-E@T*!6X_C@LR7G9=2@JF"YY/!C*""S):S@J*#6(-.@XJ#=H-G@LT@
M0W5T+T-O<'DO4&%S=&4@@L6"JX+<@KF"\8%"(@HB3TL@@O"#3H.*@V*#3H*W
M@NF"QH%!@L>"I(+B@L&"Q(-.@XJ#8H-V@WN!6X-H@LF#08-.@UJ#6(*W@NF"
MJ8+&@J*"I"!M;WII;&QA+B(*(F]R9R""S(M:CW"5MH^1@O",J8+I@K&"QH*J
M@L6"JX+<@K>!0B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@W(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3(W"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3,S"FUS9VED(")5;G-U<'!O<G1E
M9"!%>'1E;G-I;VXB"FUS9W-T<B`B@U2#?(%;@V>"M8+$@J*"R(*BBF>2HXYQ
M@L6"MR(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3DW('1E
M;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B
M"FUS9W-T<B`BC5B05B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S
M='(@(B5S((+PC5B05H*W@NF!0B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z-S8*;7-G:60@(E5P9&%T92!U<V5R(@IM<V=S='(@(H.&
M@5N#58+PC5B05H*W@NDB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$T-"!A9&UI
M;B]P97)M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP
M.C(S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS
M9W-T<B`B7"(E<UPB((+PC5B05H*U@MR"M8*]@4(B"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HX,PIM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E
M9"XB"FUS9W-T<B`BC5B05H-8@TZ#BH-V@V>"\(WMCYR"M8+<@K6"O8%"(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W."!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DX"FUS9VED(")5<&QO860B"FUS9W-T
M<B`B@T&#8H-V@XV!6X-H(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X
M-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S
M('1O('1H92!S97)V97(N(@IM<V=S='(@(I%3@L2"S(-!@W:#BH-0@5N#5H.'
M@Y."S)#=DNB#=(-`@T.#BX+P@U2!6X-O@LF#08-B@W:#C8%;@VB"M8+<@K6"
MO8%"(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G
M<W1R("*#B8-E@Y.5MHZ:@6F1Y96VCIJ!:B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P
M<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B@XV!6X-]D)2.FH%ID>65MHZ:
M@6HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(H-%
M@XN#3X-!@T.3C)7[BZ2888V1(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(HR[C=V"S))L@O".9Y=P@48E<R(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(E-33"""\(YGEW`B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(W"FUS9VED(")5<V4@:68@;F%M92]P
M87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R
M("))35-0((-4@5N#;X+,@X:!6X-5EKR!7H-P@UB#CX%;@VB"JHC9@LB"Z8_J
MC8>"R8YGEW""M8+<@K>!0B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M961I="YI;F,Z,C$*;7-G:60@(E5S97(B"FUS9W-T<B`B@X:!6X-5(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HW-S0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@
M)7,N(@IM<V=S='(@(H.&@5N#52`E<R""S2`E<R""Q91&C]B"LX+J@L2"HH+<
M@KF"\8%"(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S"FUS9VED(")5<V5R($%D
M;6EN:7-T<F%T:6]N(@IM<V=S='(@(H.&@5N#58K'EYTB"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C(T-0IM<V=I9"`B57-E<B!/<'1I;VYS
M(@IM<V=S='(@(H.&@5N#58-)@W:#5H.'@Y,B"@HC.B!S:6=N=7`N<&AP.C8R
M"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R("*#AH%;@U63;YA>
M(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I9"`B57-E<B!296=I<W1R871I;VX@
M:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92XB"FUS9W-T<B`B@X:!
M6X-5@LR3;YA>@LV"L8+,@U2#0X-G@L6"S8O6CGZ"LX+J@L2"HH+<@K>!0B(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-CD*;7-G:60@(E5S97(@86-C
M;W5N="!N;W0@9F]U;F0B"FUS9W-T<B`B@X:!6X-5@5N#08-*@T6#DX-G@JJ"
MH(+H@MR"N8+Q@4*!0B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.3@*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34P('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C,S"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S(@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S
M97)N86UE(@IM<V=S='(@(H.&@5N#59:\(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R
M;F%M92!<(B5S7"(@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(H.&@5N#59:\
M(%PB)7-<(B""S8KY@LF"H(+H@MR"MX%"(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C@W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B@X:!
M6X-5EKPZ(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`IM<V=I
M9"`B57-E<FYA;64Z("(*;7-G<W1R("*#AH%;@U66O#H@(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@:6X@=&AE
M('-Y<W1E;3HB"FUS9W-T<B`B@U:#6(-E@X"2AH+,@X:!6X-5@48B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$T"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@(H-%@UF#>(-,
M@UB#7H.3BZ2888V1(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,3<P(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(V,@IM<V=I9"`B5D93
M(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$R,`IM<V=I9"`B5F%C871I;VXB"FUS
M9W-T<B`BBWB)R2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@V,PIM
M<V=I9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.0IM
M<V=I9"`B5F%L:61I='DB"FUS9W-T<B`BETR,^)"K(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.3<*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U"FUS9VED
M(")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-3,@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3$W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")686QU92!I<R!O=F5R
M('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T,2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,C8S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,3,@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDP-PHC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED(")686QU97,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P-B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,3@S"FUS9VED(")686QU97,@=&\@<V5L96-T
M(&9R;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T
M=2(*;7-G<W1R("*#;X-K@T&#8XNDF&&-D2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,S,*;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R("*#>(-L
M@UF#1X.)@46#>X.*@V^#BXNDF&&-D2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED(")697)I9FEC871I;VX@9F%I;&5D
M("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"XB
M"FUS9W-T<B`BC)^/V(ZXE',@+2""L8+,@X&#8H-:@5N#5X+-B?SB@H*S@NJ"
MQ(*B@NF"YH*D@L6"MX%"(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HW,#$*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`BE,4B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(X"FUS9VED(")697)S:6]N($-O
M;G1R;VPB"FUS9W-T<B`B@V^!6X-7@X>#DXK'EYTB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")6
M97)T:6-A;"!A;&EG;B(*;7-G<W1R("*/8XC*DG4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T"FUS9VED(")697)T:6-A
M;"!P861D:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW
M,@IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*
M;7-G:60@(E9I970@3F%M(@IM<V=S='(@(H-X@V>#:8.`CM")[X[EBV"+I)AA
MC9$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-PIM<V=I9"`B5FEE=&YA
M;65S92`H5DE30TE)*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HY-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE
M=R`E<R(*;7-G<W1R("(E<R""\(RI@NDB"@HC.B!L:6(O0FQO8VLO:69R86UE
M+G!H<#HS"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S
M='(@(HI/E92"S"!W96(@@WF!6X-7@O"57(ZF(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]#;VYT96YT<RYP:'`Z.#(X"B,L('!H<"UF;W)M870*;7-G:60@
M(E9I97<@87,@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B
M5FER9VEN($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`BB7"7S(-O@5N#5X.3
MCY23AR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5
M+E,N(@IM<V=S='(@(I7$E\R#;X%;@U>#DX^4DX<B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(Q-@IM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4R"FUS9VED(")6:7-I
M8FEL:71Y.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET
M86QY('9I82!33510(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G
M:60@(E=!4DXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!214U/5D4@
M4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS9VED(")724X@
M=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5V%L
M;&ES(&%N9"!&=71U;F$B"FUS9W-T<B`B@T6#2(.*@UB!18-T@V>#1(%;@VF/
ME).'(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]H=&UL+G!H<#HQ,C<@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@S
M"FUS9VED(")787)N:6YG(@IM<V=S='(@(HQXC9`B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G
M<W1R("*0A2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.0IM
M<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#$V"FUS9VED(")796%T:&5R(&1A=&$@
M<')O=FED960@8GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.#@Y"FUS9VED(")796%T:&5R+F-O;2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,SD*;7-G:60@(E=E8B!3
M:71E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN
M=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R("*6B(]4(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*;7-G:60@(E=E;&-O
M;64B"FUS9W-T<B`B@N:"I(*Q@KLB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B
M:6QE+FEN8SHT('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R("(E<R""R8+F
M@J2"L8*[(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M
M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@
M(E=E;&-O;64L("5S(@IM<V=S='(@(B5S((*S@O&!08+F@J2"L8*[(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3@*;7-G:60@(E=E<W1E<FX@*$E33RTX
M.#4Y+3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DY
M"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(I"\@U2#
M;H.)(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y
M(&%F=&5R(&QO9VEN/R(*;7-G<W1R("(E<X.-@T^#0X.3C.."QX+,@T&#=H.*
M@U"!6X-6@X>#DX+PE5R.IH*U@MR"MX*I@4@B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R
M(&-H87)A8W1E<C\B"FUS9W-T<B`BB^:0V(+HE;:.FH+-B;V"Q8*W@JF!2"(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T
M(&ES('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(HCXEW"5MHZ:@LV)
MO8+%@K>"J8%((@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$P-C4*;7-G:60@(E=H97)E:7,@075S=')A;&EA(&UA<"(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H
M('!H87-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3,V"FUS9VED(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I
M8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@(H-E@TR#6(-G@T>#9H-"@UZ!6X+,
M@W:#B8-/@T.#DX+PD4F1\(*U@MR"MX%"(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B
M"FUS9W-T<B`BE9TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3`T
M"FUS9VED(")7:61T:"!I;B!#4U,@=6YI=',B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,V,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7
M:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T
M(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`BC;:"R9)U@JTE<X.!@VJ#A8%;
M@LR5G8%ICI^)\8+,@XV#3X-#@Y."J8+GETR,^(%J.B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T
M:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`BE5R"S)6=(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G:60@(E=I9'1H
M('5N:70B"FUS9W-T<B`BE9V"S))0B,HB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0IM<V=I9"`B5VED=&@Z(@IM<V=S
M='(@(I6=@48B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$U"FUS
M9VED(")7:6MI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR.#D@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C<*;7-G:60@(E=I;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*;7-G:60@(E=I;F0@16%R;'DB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX-PIM<V=I9"`B
M5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$V,PIM<V=I9"`B5VEN9#HB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,0IM<V=I9"`B5VEN9#H@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B
M5VES9&]M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ.3@*;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@(I=^@K6"HH+@@LR(ZI>7
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$V-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(HO.EK&0YH+,
MCUJ/BB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ.3(*;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`BB\Z6L9#F@LR39)AB
ME-2-AB(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$Y,R!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR.30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E
M9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(B5D((USEMJ"Q8K4B.&"P8*]C8"6
MVI"4@4*0LX*U@JV"S2`E9(%!CG>2Z(*S@NJ"O8+,@LT@)62!0B(*"B,Z(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U
M;F0@)60N(@IM<V=S='(@(HK4B.&"P8*]C8"6VI"4@4*0LX*U@JV"S2`E9(%!
MCG>2Z(*S@NJ"O8+,@LT@)62!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C$R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!O9F9S970@
M)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*;7-G<W1R(")61E.#=(-`
M@T.#BX+,D\>"W8]O@K62AH+)E7.0LX+(@TF#=(-:@V*#9R`E9"""JHYWDNB"
MLX+J@MR"M8*]@4(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C0U
M"FUS9VED(")8+5)E9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S($)A<VEC($-O;G-T
M<F%I;G1S(@IM<V=S='(@(E@U,#EV,R"*[I9[D*>,P"(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@17AT
M96YD960@2V5Y(%5S86=E(@IM<V=S='(@(E@U,#EV,R",KHYGEW"60"(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8
M-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(E@U,#EV
M,R".Y9',CM*"S)7*EKPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4Y-@IM<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I
M97(B"FUS9W-T<B`B6#4P.78S(([ED<R.TH+,C*Z.KY7*CG$B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X,PIM<V=I9"`B6#4P.78S
M(&5X=&5N<VEO;G,B"FUS9W-T<B`B6#4P.78S((IGDJ.+0)1<(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@(I1.(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-`HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4V"FUS9VED
M(")965E9(@IM<V=S='(@(I1.(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$Q,3$*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H
M<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@(I:(E$XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$W"FUS9VED(")996UE;B(*;7-G<W1R("*#0X-'@X&#DXNDF&&-D2(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C8*;7-G
M:60@(EEE<R(*;7-G<W1R("*"S8*B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!9W)E92(*
M;7-G<W1R("*3KXC3@K6"W(*W(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I;B!415A4($U/
M1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=9
M4TE764<N(@IM<V=S='(@(HVA@LV#98-,@UB#9X."@5N#:(+%@K>!0EL\/EV#
M>X->@Y."Q5=94TE764>#@H%;@VB"R9;?@NB"W(*W@4(B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C(S-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M
M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G<W1R("(E9""(R(_C@LR#=8.-@V*#
M3H+PC>R0K(*W@NF"L8+&@LV+EHG"@K."ZH+$@J*"W(*Y@O&!0B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,30R-`IM<V=I9"`B66]U(&%R92!N
M;W0@875T:&5N=&EC871E9"XB"FUS9W-T<B`B@J""R(*]@LV41H_8@K."ZH+$
M@J*"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP
M:'`Z,S`X"FUS9VED(")9;W4@8V%N;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C
M=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*;7-G<W1R("*6O)%/@LR2AH+)("=<
M7"<@@L:"HH*DE;:.FH+-CF>"IH+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3@U,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<R
M"FUS9VED(")9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E
M<W,N(@IM<V=S='(@(I=,C/B"R)-DCG&#@8%;@XN#08-H@XR#6(+%@LV"H(+H
M@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.3`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M87`@86YY(&9I96QD
M<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG
M(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B(@HB@T.#DX-\@5N#9X*S@NJ"
MO8-T@T"#0X.+@LR#=(-"@5N#BX-H@O`E<Y/@@LR1SHF>@K>"Z8-T@T*!6X.+
M@VB"R8-]@V*#=H*U@L2"W"(*(H*Y@O$N(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z.3@W"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N
M(@IM<V=S='(@(H.-@T^#08-%@V>"M8+<@K6"O2XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,C4X"FUS9VED("(B"B)9;W4@:&%V92!T;R!E;G1E
M<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@
M86X@;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L
M:6YG('!R969I>"XB"FUS9W-T<B`B(@HBD+."M8*BDV288I34C8:"\)/\E\V"
MMX+I@N:"I(+)DHV(TX*U@L2)NH*S@J*!0I"4CIJ"OH*O@JJ.9Y=P@L6"JX+<
M@K>"JH%!C9&-VR(*(I-DF&*"R(+GD.:3JH+)@7N"\)5T@J^"W(*W@4(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@U"FUS9VED(")9;W4@:&%V
M92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R("*0LX*U@J*2;(+P
MD_R7S8*U@L2)NH*S@J*!0B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG
M;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R
M964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B(@HB@U2#0X.3
M@T&#8H-V@O"7F)=P@K>"Z8*]@M^"R8+-($1A=&%4<F5E((-O@V*#3H-'@Y.#
M:(+PD-V2Z(*W@NF52Y=V@JJ"H(+H@MPB"B*"MX%"(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HT-S$*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R
M92!A(%9&4R!B86-K96YD+B(*;7-G<W1R(")61E,@@V^#8H-.@T>#DX-H@O"0
MW9+H@K>"Z95+EW:"JH*@@NB"W(*W@4(B"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@=&AE
M('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O
M<G0N(@IM<V=S='(@(H_ABE&"S)/@EV6"\(M,CW&"M8+$@JF"YX%!C^&*48.,
M@WR!6X-G@O"1EY!-@K6"Q(*M@KZ"LX*B@4(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E
M;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T
M<B`B@K&"L8+)@XJ#DX-.@K>"Z5523(+PD_R7S8*U@L2)NH*S@J(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`IM<V=I9"`B66]U(&UU<W0@
M<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R("*-[8^<
M@K>"Z8-4@5N#;X+PCG>2Z(*U@L2"K8*^@K."HH%"(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3$Y"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@
M=&\@8VQE87(@;W5T+B(*;7-G<W1R("*/P8N.@K>"Z8.&@5N#59:\@O".=Y+H
M@K6"Q(*M@KZ"LX*B@4(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#`*;7-G:60@
M(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N(@IM<V=S
M='(@(HWMCYR"MX+I@X:!6X-5EKR"\(YWDNB"M8+$@JV"OH*S@J*!0B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@
M=&\@861D+B(*;7-G<W1R("*2QXG!@K>"Z8.&@5N#59:\@O".=Y+H@K6"Q(*M
M@KZ"LX*B@4(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#8*;7-G:60@(EEO=2!M
M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`B
MC5B05H*W@NF#AH%;@U66O(+PCG>2Z(*U@L2"K8*^@K."HH%"(@H*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,X"FUS9VED(")9
M;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM<V=S
M='(@(H[`C7."MX+I@T&#3H-6@X>#DX+PCG>2Z(*U@L2"K8*^@K."HH%"(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z
M-S$*;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB
M"FUS9W-T<B`BD%:"M8*BE:J7WI:\@O"3_)?-@K6"Q(FZ@K."HH%"(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z
M-S,*;7-G:60@(EEO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N
M92!N=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP
M:'`Z.3<U"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H
M87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R("(E<R"#
M6H-B@U:#AX.3@LR73(SXBOJ,P(*JD-B"ZH+$@J*"W(*W@4*#C8-/@T.#DX*U
MDKR"M8+$@JV"OH*S@J*!0B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C,X"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`B
MDV2.<8.!@5N#BX-!@VB#C(-8(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(Q-0IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R("*"H(+(
M@KV"S"!&<F]M.B"#08-H@XR#6"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S<@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,@IM<V=I9"`B
M66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R("*"H(+(@KV"S(-#@Y.#=(-(@X&!
M6X-6@X>#DR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S
M(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I
M;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G
M:6X@86=A:6XN(@IM<V=S='(@(B(*(H-:@V*#5H.'@Y,@)7,@@LR*U(+)@J""
MR(*]@LR#08-H@XR#6(*JE<^-6(*S@NJ"W(*U@KV!0H-:@TR#A8.*@V6#0H%;
ME=N,[(+,@KTB"B*"WX+)@XV#3X-#@Y."M9*\@K>"UX*K@L6"MX%"(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*;7-G:60@(EEO=7(@
M3F%M92(*;7-G<W1R("*"H(+(@KV"S):\D4\B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]N;V%D9"YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A
M=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)
M9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R
M(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@(@HB875T:&5N
M=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T<B`B(@HB@K&"S)1&C]B#;X-B@TZ#
M1X.3@VB"Q8+-@4&#AH%;@U6"S)+'B<&"JH-4@WR!6X-G@K."ZH+$@J*"W(*Y
M@O&!0H+@@K4@2&]R9&4@@L4B"B*#AH%;@U6#08-*@T6#DX-G@O"*QY>=@K6"
MO8*B@LR"R(+G@4&1O(+,E$:/V(-O@V*#3H-'@Y.#:(+PCF>"I(+7@JN"Q8*W
M@4(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*;7-G
M:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S
M=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B
M965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B
M(@HB@K&"S)1&C]B#;X-B@TZ#1X.3@VB"Q8+-@4&#AH%;@U6"S(.*@UB#9X*J
M@U2#?(%;@V>"LX+J@L2"HH+(@J*"J8%!@J""Z8*B@LV)O2(*(H+G@JF"S)>=
MEU*"Q8*Q@LR+0)1<@JJ6LXSX@LF"R(+!@L2"HH+<@K>!0B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.CDX,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@
M=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E
M8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S
M='(@(B(*(H-:@V*#5H.'@Y,@)7,@@LR*U(+)@J""R(*]@LR#=8.)@T6#58*J
ME<^-6(*S@NJ"O8+F@J2"R(+,@L6!08-:@TR#A8.*@V6#0H%;E=LB"B*,[(+,
M@KV"WX+)@XV#3X-#@Y."M9*\@K>"UX*K@L6"MX%"(@H*(SH@;&EB+T)L;V-K
M+VEF<F%M92YP:'`Z-3<*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S
M=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`B@JB.9X*B@LR#=8.)@T6#
M58+-@K&"S(M`E%R"\(-4@WR!6X-G@K6"Q(*B@MR"N8+Q@4(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]P<FEN="YJ<SHT,@IM<V=I9"`B(@HB66]U<B!B
M<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R
M97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@
M(B(*(H*HCF>"HH+,@W6#B8-%@U6"S8*Q@LR(\XW\@TF#=H-6@X>#DX+P@U2#
M?(%;@V>"M8+$@J*"W(*Y@O&!0D-O;G1R;VPO0V]M;6%N9"`B"B(K(%`@@L6(
M\XW\@K6"Q(FZ@K."HH%"(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V
M,0IM<V=I9"`B66]U<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`B@UZ#
M0X.`@UV!6X.3@48B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,3$W"FUS9VED
M(")9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"XB"FUS
M9W-T<B`B@J""R(*]@LR#9H-T@TB#BX-G242"S97/C5B"LX+J@MR"M8*]@4(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,38Q"FUS9VED(")9;W5R(&1E
M9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@(H*@@LB"O8+,@V:#=(-(@XN#9TE$
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#0*;7-G:60@(EEO=7(@
M9G5L;"!N86UE.B(*;7-G<W1R("*"H(+(@KV"S(Z!EKPB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+G!H<#HY.3D*;7-G:60@(EEO=7(@;&]G:6X@:&%S(&5X
M<&ER960N(@IM<V=S='(@(H.-@T^#0X.3@LV*^HS`D-B"ZH+%@K>!0B(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*
M;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T
M<B`BD%:"M8*B("5S()=P@LR#<(-8@X^!6X-H@48E<R(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO;G,@
M:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E
M<W-I;VXN(@IM<V=S='(@(H*@@LB"O8+,@TF#=H-6@X>#DX+-C+N-W8+,@UJ#
M8H-6@X>#DY*&@LF5SXU8@K."ZH+<@K6"O8%"(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E
M(&)E96X@=7!D871E9"XB"FUS9W-T<B`B@TF#=H-6@X>#DX+PC5B05H*U@MR"
MM8*](@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S4*;7-G:60@
M(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B"FUS9W-T<B`B@W"#6(./
M@5N#:(+-@XJ#6H-B@V>"LX+J@MR"M8*]@4(B"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@
M8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@
M>6]U<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*(H-P@UB#CX%;@VB"
MS8.*@UJ#8H-G@K."ZH+<@K6"O8+,@L6!09!6@K6"HH-P@UB#CX%;@VB"Q8.-
M@T^#0X.3@K6"Q(+=@L2)NH*S(@HB@J*!0B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.C<S,PIM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP:7)E
M9"XB"FUS9W-T<B`B@W"#6(./@5N#:(*JBOJ,P)#8@NJ"Q8*W@4(B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G:60@(EEO=7(@<F5M
M;W1E('-E<G9E<G,Z(@IM<V=S='(@(H.*@X*!6X-G@U2!6X-O.B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4T(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B@X:!
M6X-3@UB#B8-R@T$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$X"FUS9VED("):86ER92(*;7-G<W1R("*#58-#@5N#BXNDF&&-D8%I@U*#
MDX-3EJ^.Y8NDF&&-D8%J(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA
M(@IM<V=S='(@(H-5@Y.#<H-!BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I
M9"`B6FEM8F%B=V4B"FUS9W-T<B`B@U>#DX-O@W6#1XNDF&&-D2(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q
M=6]T97,N<&AP.C$W-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L
M;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C@Y"FUS9VED(");4')O8FQE
M;2!297!O<G1=(@IM<V=S='(@(H%MC^&*497QC9"!;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(");4VAO=R!1
M=6]T960@5&5X="`M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I
M;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HR,#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(EN-
M<SHE<R\E<UTB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U-30@
M=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHQ,0IM<V=I9"`B7T%D;6EN:7-T
M<F%T:6]N(@IM<V=S='(@(E]!BL>7G2(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM
M<V=I9"`B7T-,22(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#$*;7-G
M:60@(E]$871A5')E92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*;7-G:60@(E]$96QE
M=&4@4F]W(@IM<V=S='(@(E]$C7."\(WMCYPB"@HC.B!L:6(O87!I+G!H<#HQ
M,S,*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B7T>#3X.+@5N#=B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-S4*;7-G:60@(E](96QP
M(@IM<V=S='(@(E](@W>#BX-V(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S"FUS9VED(")?26UA9V4@4')O
M<&5R=&EE<RXN+B(*;7-G<W1R(")?28GFD9R#=H.-@W"#98-"+BXN(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y-`IM<V=I9"`B7TQO
M9R!I;B(*;7-G<W1R(")?3(.-@T^#0X.3(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`B
M7TR#C8-/@T&#18-G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI;FLN+BXB
M"FUS9W-T<B`B7TV#BH.3@TZ5SXU8(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+TUE;G4N<&AP.C$V-`IM<V=I9"`B7T]P=&EO;G,B"FUS9W-T<B`B7T^#
M28-V@U:#AX.3(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?4&5R;6ES
M<VEO;G,B"FUS9W-T<B`B7U"#08-.@UJ#6(R@(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V"FUS9VED(")?
M4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`B7U*#BH.3@TZ-[8^<(@H*(SH@;&EB
M+V%P:2YP:'`Z,3(U"FUS9VED(")?4V5T=7`B"FUS9W-T<B`B7U.#6H-B@V>#
M08-B@W8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM
M<V=S='(@(E]4E5R1KI"K(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?
M57-E<G,B"FUS9W-T<B`B7U6#AH%;@U4B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.CDR-0IM<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(H-!
M@VB#C(-8DJ`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$S-`IM<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`BE7.6OH+(
M@T&#:(.,@U@B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ-PIM
M<V=I9"`B8V%L96YD87(B"FUS9W-T<B`BEUR2Z)5<(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ-SD@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N;F]T(&-R96%T
M92!O=71P=70@9FEL92(*;7-G<W1R("*/;Y?-@W2#0(-#@XN"JHWLD*R"Q8*K
M@MR"N8+Q(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(I/\E\V#=(-`
M@T.#BX*JBDJ"KX+<@KF"\2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C4Y.`IM<V=I9"`B8VQI8VL@:&5R92(*;7-G<W1R("*"L8*Q
M@O"#3H.*@V*#3B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T
M<B`B@U*#?8.3@VB-<XYGEW""S(-'@XF!6R(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,3<X"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R
M<F]R(@IM<V=S='(@(I#=DNB#1X.)@5LB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I
M;&4@;6ES<VEN9R(*;7-G<W1R("*/9)=V@LB#5H-8@V6#@(-T@T"#0X.+@LR,
MAY>.(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C8*
M;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(H-F@5N#7HQ@CJZ#
M1X.)@5LB"@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C,P"FUS9VED
M(")E9&ET(@IM<V=S='(@(I72CU<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$X,@IM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S
M='(@(HV`EMJ"JH*@@NB"W(*Y@O$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HW,PIM<V=I9"`B9F%L;&EN9R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.3@*;7-G:60@
M(F9I;&4B"FUS9W-T<B`B@W2#0(-#@XLB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$X,2!L:6(O0FQO8VLO;65T87(N<&AP.C,V-R!L:6(O0FQO8VLO;65T
M87(N<&AP.C,Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H
M)7,I(&%T("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,SD*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U,`IM<V=I
M9"`B:#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C,U.0IM<V=I9"`B:&@B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@
M;F%M92!U;FMN;W=N(@IM<V=S='(@(H-Z@UB#9Y:\@JJ5<Y:^(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S
M"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(FEN
M;&EN92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@
M(I/\CV^7S8-'@XF!6R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G
M<W1R("*#7(-T@V>#18-&@T&3X)64@LR#1X.)@5LB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B;&EN97-=(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES;V9S
M(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W,`IM
M<V=I9"`B;6TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HR.#4@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W,`HC
M.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C0Q"FUS9VED(")N86UE
M(@IM<V=S='(@(I:\D4\B"@HC.B!F<F%M97=O<FLO4E!#+U)00RYP:'`Z,3(T
M"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`BCL"1E8*S@NJ"Q(*B
M@MR"N8+Q(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ
M,C(P"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(H+<@KZ.
MP)&5@K."ZH+$@J*"W(*Y@O$B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDP.0IM<V=I9"`B;F]T97!A9"(*;7-G<W1R("*#@8."DJ`B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X
M"FUS9VED(")P97)C96YT(@IM<V=S='(@(H-P@5N#6H.3@V<B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W-`IM<V=I9"`B<&5R;6ES
M<VEO;B!D96YI960B"FUS9W-T<B`B@T&#3H-:@UB"S8N1E-N"LX+J@MR"M8*]
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(H-S@TZ#6H.+(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S`*;7-G:60@(G)E
M;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R("*#BH."@5N#9X+%@LR#
M=H.-@V>#4H.+@T>#B8%;(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-S4*;7-G:60@(G)I<VEN9R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T,@IM<V=I9"`B<V5R
M=FEC92!U;F%V86EL86)L92(*;7-G<W1R("*#5(%;@W*#6)5SE%PB"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C$P,0IM<V=I9"`B<VAO=R!D:69F97)E
M;F-E<R(*;7-G<W1R("*-MY6J@O"57(ZF(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I
M;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,S@W"FUS9VED(")S<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW-`IM<V=I
M9"`B<W1E861Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,34P"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`B
M@U:#6(-E@X"#1X.)@5LB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDS,PIM<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@(H->@UB#3H.*@UB#9R(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,38V"FUS9VED
M(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R("*(ZHZ>DTF"R(-'@XF!6R(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG
M;G5P+G!H<#HR-S`*;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O
M(&-O;F9I<FTB"FUS9W-T<B`BBFV41H+,@KV"WX-P@UB#CX%;@V@RDWB3_)?-
M@K6"Q(FZ@K."HB(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN
M+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")U;FEF:65D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N
M;F%M960B"FUS9W-T<B`BEK.6O"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B=7-E<B!S96QE
M8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-#(*;7-G
M:60@(G<Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HV"FUS9VED(")W96%T:&5R+F-O;2(*;7-G<W1R("(B"@``````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&\O=')A;G-L871I;VXN<&AP````````````````````````
M`````````````````````````````````````````````````````#`P,#<U
M-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,34V,C<P(#$P-3$U-#,S-S0R(#`R
M,3(T,@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```C(2]U<W(O;&]C86PO<'-A+V%D;6EN+V)I;B]P:'`@+7$*/#]P:'`*+RHJ
M"B`J(%1R86YS;&%T:6]N(&AE;'!E<B!A<'!L:6-A=&EO;B!F;W(@=&AE($AO
M<F1E(&9R86UE=V]R:RX*("H*("H@1F]R('5S86=E(&EN9F]R;6%T:6]N(&-A
M;&PZ"B`J("XO=')A;G-L871I;VXN<&AP(&AE;'`*("H*("H@)$AO<F1E.B!H
M;W)D92]P;R]T<F%N<VQA=&EO;BYP:'`L=B`Q+CDQ+C(N,38@,C`P-B\P-2\R
M,R`P,CHQ,SHT,R!S96QS:WD@17AP("0*("HO"@IF=6YC=&EO;B!F;V]T97(H
M*0I["B`@("!G;&]B86P@)&,L("1C=7)D:7(["@H@("`@)&,M/G=R:71E;&XH
M*3L*("`@("1C+3YW<FET96QN*"=0;&5A<V4@<F5P;W)T(&%N>2!B=6=S('1O
M(&DQ.&Y`;&ES=',N:&]R9&4N;W)G+B<I.PH*("`@(&-H9&ER*"1C=7)D:7(I
M.PH@("`@97AI=#L*?0H*9G5N8W1I;VX@=7-A9V4H*0I["B`@("!G;&]B86P@
M)&]P=&EO;G,L("1C.PH*("`@(&EF("AC;W5N="@D;W!T:6]N<ULQ72D@)B8*
M("`@("`@("`H)&]P=&EO;G-;,5U;,%T@/3T@)VAE;'`G("8F("%E;7!T>2@D
M;W!T:6]N<ULQ75LQ72D@?'P*("`@("`@("`A96UP='DH)&]P=&EO;G-;,5U;
M,%TI("8F(&EN7V%R<F%Y*"1O<'1I;VYS6S%=6S!=+"!A<G)A>2@G8V]M;6ET
M)RP@)V-O;7!E;F1I=6TG+"`G97AT<F%C="<L("=I;FET)RP@)VUA:V4G+"`G
M;65R9V4G*2DI*2!["B`@("`@("`@:68@*"1O<'1I;VYS6S%=6S!=(#T]("=H
M96QP)RD@>PH@("`@("`@("`@("`D8VUD(#T@)&]P=&EO;G-;,5U;,5T["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&-M9"`]("1O<'1I;VYS6S%=
M6S!=.PH@("`@("`@('T*("`@("`@("`D8RT^=W)I=&5L;B@G57-A9V4Z)R`N
M("<@=')A;G-L871I;VXN<&AP(%MO<'1I;VYS72`G("X@)&-M9"`N("<@6V-O
M;6UA;F0M;W!T:6]N<UTG*3L*("`@("`@("!I9B`H(65M<'1Y*"1C;60I*2![
M"B`@("`@("`@("`@("1C+3YW<FET96QN*"D["B`@("`@("`@("`@("1C+3YW
M<FET96QN*"=#;VUM86YD(&]P=&EO;G,Z)RD["B`@("`@("`@?0H@("`@("`@
M('-W:71C:"`H)&-M9"D@>PH@("`@("`@("`@("!C87-E("=C;&5A;G5P)SH*
M("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"<@("UL+"`M+6QO8V%L93UL
M;%]#0R`@("`@57-E(&]N;'D@=&AI<R!L;V-A;&4N)RD["B`@("`@("`@("`@
M("`@("`D8RT^=W)I=&5L;B@G("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($-L
M96%N=7`@4$\@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92XG
M*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=C
M;VUM:70G.@H@("`@("`@("`@("!C87-E("=C;VUM:70M:&5L<"<Z"B`@("`@
M("`@("`@("`@("`D8RT^=W)I=&5L;B@G("`M;"P@+2UL;V-A;&4];&Q?0T,@
M("`@(%5S92!T:&ES(&QO8V%L92XG*3L*("`@("`@("`@("`@("`@("1C+3YW
M<FET96QN*"<@("UM+"`M+6UO9'5L93U-3T153$4@("`@0V]M;6ET('1R86YS
M;&%T:6]N<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+B<I.PH@("`@
M("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@+4TL("TM;65S<V%G93U-15-3
M04=%("!5<V4@=&AI<R!C;VUM:70@;65S<V%G92!I;G-T96%D(&]F('1H92!D
M969A=6QT(&]N97,N)RD["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G
M("`M;BP@+2UN97<@("`@("`@("`@("`@(%1H:7,@:7,@82!N97<@=')A;G-L
M871I;VXL(&-O;6UI="!A;'-O($-2141)5%,L)RD["B`@("`@("`@("`@("`@
M("`D8RT^=W)I=&5L;B@G("`@("`@("`@("`@("`@("`@("`@("`@($-(04Y'
M15,@86YD(&YL<RYP:'`N9&ES="XG*3L*("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("!C87-E("=C;VUP96YD:75M)SH*("`@("`@("`@("`@
M("`@("1C+3YW<FET96QN*"<@("UA+"`M+6%D9#U&24Q%("`@("`@("!!9&0@
M=&AI<R!03R!F:6QE('1O('1H92!C;VUP96YD:75M+B!5<V5F=6P@=&\G*3L*
M("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"<@("`@("`@("`@("`@("`@
M("`@("`@("!I;F-L=61E(&$@8V]M<&5N9&EU;2!F<F]M(&$@9&EF9F5R96YT
M(&)R86YC:"!T;R<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@
M("`@("`@("`@("`@("`@("`@("`@('1H92!G96YE<F%T960@8V]M<&5N9&EU
M;2XG*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"<@("UD+"`M+61I
M<F5C=&]R>3U$25(@("!#<F5A=&4@8V]M<&5N9&EU;2!I;B!T:&ES(&1I<F5C
M=&]R>2XG*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"<@("UL+"`M
M+6QO8V%L93UL;%]#0R`@("!5<V4@=&AI<R!L;V-A;&4N)RD["B`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G97AT<F%C="<Z"B`@
M("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G("`M;2P@+2UM;V1U;&4]34]$
M54Q%("!'96YE<F%T92!03U0@9FEL92!O;FQY(&9O<B!T:&ES("A(;W)D92D@
M;6]D=6QE+B<I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M(&-A<V4@)VEN:70G.@H@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@
M+6PL("TM;&]C86QE/6QL7T-#("`@("!5<V4@=&AI<R!L;V-A;&4N)RD["B`@
M("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G("`M;2P@+2UM;V1U;&4]34]$
M54Q%("`@($-R96%T92!A(%!/(&9I;&4@;VYL>2!F;W(@=&AI<R`H2&]R9&4I
M(&UO9'5L92XG*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"<@("UC
M+"`M+6-O;7!E;F1I=6T]1DE,12`@57-E('1H:7,@8V]M<&5N9&EU;2!F:6QE
M(&EN<W1E860@;V8@=&AE(&1E9F%U;'0G*3L*("`@("`@("`@("`@("`@("1C
M+3YW<FET96QN*"<@("`@("`@("`@("`@("`@("`@("`@("`@;VYE("AC;VUP
M96YD:75M+G!O(&EN('1H92!H;W)D92]P;R!D:7)E8W1O<GDI+B<I.PH@("`@
M("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@+6XL("TM;F\M8V]M<&5N9&EU
M;2`@("!$;VY<)W0@=7-E(&$@8V]M<&5N9&EU;2XG*3L*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=M86ME)SH*("`@("`@("`@
M("`@("`@("1C+3YW<FET96QN*"<@("UL+"`M+6QO8V%L93UL;%]#0R`@("`@
M57-E(&]N;'D@=&AI<R!L;V-A;&4N)RD["B`@("`@("`@("`@("`@("`D8RT^
M=W)I=&5L;B@G("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($)U:6QD($U/(&9I
M;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N)RD["B`@("`@("`@
M("`@("`@("`D8RT^=W)I=&5L;B@G("`M8RP@+2UC;VUP96YD:75M/49)3$4@
M($UE<F=E(&YE=R!T<F%N<VQA=&EO;G,@=&\@=&AI<R!C;VUP96YD:75M(&9I
M;&4G*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"<@("`@("`@("`@
M("`@("`@("`@("`@("`@:6YS=&5A9"!O9B!T:&4@9&5F875L="!O;F4@*&-O
M;7!E;F1I=6TN<&\@:6X@=&AE)RD["B`@("`@("`@("`@("`@("`D8RT^=W)I
M=&5L;B@G("`@("`@("`@("`@("`@("`@("`@("`@(&AO<F1E+W!O(&1I<F5C
M=&]R>2XG*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"<@("UN+"`M
M+6YO+6-O;7!E;F1I=6T@("`@1&]N7"=T(&UE<F=E(&YE=R!T<F%N<VQA=&EO
M;G,@=&\@=&AE(&-O;7!E;F1I=6TN)RD["B`@("`@("`@("`@("`@("`D8RT^
M=W)I=&5L;B@G("`M<RP@+2US=&%T:7-T:6-S("`@("`@(%-A=F4@=')A;G-L
M871I;VX@<W1A=&ES=&EC<R!I;B!A(&QO8V%L(&9I;&4N)RD["B`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G;6%K92UH96QP)SH*
M("`@("`@("`@("`@8V%S92`G=7!D871E+6AE;'`G.@H@("`@("`@("`@("`@
M("`@)&,M/G=R:71E;&XH)R`@+6PL("TM;&]C86QE/6QL7T-#("`@("!5<V4@
M;VYL>2!T:&ES(&QO8V%L92XG*3L*("`@("`@("`@("`@("`@("1C+3YW<FET
M96QN*"<@("UM+"`M+6UO9'5L93U-3T153$4@("`@57!D871E(&AE;'`@9FEL
M97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92XG*3L*("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=M97)G92<Z"B`@("`@
M("`@("`@("`@("`D8RT^=W)I=&5L;B@G("`M;"P@+2UL;V-A;&4];&Q?0T,@
M("`@(%5S92!T:&ES(&QO8V%L92XG*3L*("`@("`@("`@("`@("`@("1C+3YW
M<FET96QN*"<@("UM+"`M+6UO9'5L93U-3T153$4@("`@365R9V4@4$\@9FEL
M97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92XG*3L*("`@("`@("`@
M("`@("`@("1C+3YW<FET96QN*"<@("UC+"`M+6-O;7!E;F1I=6T]1DE,12`@
M57-E('1H:7,@8V]M<&5N9&EU;2!F:6QE(&EN<W1E860@;V8@=&AE(&1E9F%U
M;'0G*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"<@("`@("`@("`@
M("`@("`@("`@("`@("`@;VYE("AC;VUP96YD:75M+G!O(&EN('1H92!H;W)D
M92]P;R!D:7)E8W1O<GDI+B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E
M;&XH)R`@+6XL("TM;F\M8V]M<&5N9&EU;2`@("!$;VY<)W0@=7-E(&$@8V]M
M<&5N9&EU;2XG*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("!C87-E("=U<&1A=&4G.@H@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH
M)R`@+6PL("TM;&]C86QE/6QL7T-#("`@("!5<V4@=&AI<R!L;V-A;&4N)RD[
M"B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G("`M;2P@+2UM;V1U;&4]
M34]$54Q%("`@(%5P9&%T92!O;FQY('1H:7,@*$AO<F1E*2!M;V1U;&4N)RD[
M"B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G("`M8RP@+2UC;VUP96YD
M:75M/49)3$4@(%5S92!T:&ES(&-O;7!E;F1I=6T@9FEL92!I;G-T96%D(&]F
M('1H92!D969A=6QT)RD["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G
M("`@("`@("`@("`@("`@("`@("`@("`@(&]N92`H8V]M<&5N9&EU;2YP;R!I
M;B!T:&4@:&]R9&4O<&\@9&ER96-T;W)Y*2XG*3L*("`@("`@("`@("`@("`@
M("1C+3YW<FET96QN*"<@("UN+"`M+6YO+6-O;7!E;F1I=6T@("`@1&]N7"=T
M('5S92!A(&-O;7!E;F1I=6TN)RD["B`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("!]"B`@("!](&5L<V4@>PH@("`@("`@("1C+3YW<FET96QN*"=5
M<V%G93HG("X@)R!T<F%N<VQA=&EO;BYP:'`@6V]P=&EO;G-=(&-O;6UA;F0@
M6V-O;6UA;F0M;W!T:6]N<UTG*3L*("`@("`@("`D8RT^=W)I=&5L;BAS=')?
M<F5P96%T*"<@)RP@4W1R:6YG.CIL96YG=&@H)U5S86=E.B<I*2`N("<@=')A
M;G-L871I;VXN<&AP(%MH96QP?"UH?"TM:&5L<%T@6V-O;6UA;F1=)RD["B`@
M("`@("`@)&,M/G=R:71E;&XH*3L*("`@("`@("`D8RT^=W)I=&5L;B@G2&5L
M<&5R(&%P<&QI8V%T:6]N('1O(&-R96%T92!A;F0@;6%I;G1A:6X@=')A;G-L
M871I;VYS(&9O<B!T:&4@2&]R9&4G*3L*("`@("`@("`D8RT^=W)I=&5L;B@G
M9G)A;65W;W)K(&%N9"!I=',@87!P;&EC871I;VYS+B<I.PH@("`@("`@("1C
M+3YW<FET96QN*"=&;W(@86X@:6YT<F]D=6-T:6]N(')E860@=&AE(&9I;&4@
M4D5!1$U%(&EN('1H:7,@9&ER96-T;W)Y+B<I.PH@("`@("`@("1C+3YW<FET
M96QN*"D["B`@("`@("`@)&,M/G=R:71E;&XH)T-O;6UA;F1S.B<I.PH@("`@
M("`@("1C+3YW<FET96QN*"<@(&AE;'`@("`@("`@(%-H;W<@=&AI<R!H96QP
M(&UE<W-A9V4N)RD["B`@("`@("`@)&,M/G=R:71E;&XH)R`@8V]M<&5N9&EU
M;2`@4F5B=6EL9"!T:&4@8V]M<&5N9&EU;2!F:6QE+B!787)N:6YG.B!4:&ES
M(&]V97)W<FET97,@=&AE)RD["B`@("`@("`@)&,M/G=R:71E;&XH)R`@("`@
M("`@("`@("`@8W5R<F5N="!C;VUP96YD:75M+B<I.PH@("`@("`@("1C+3YW
M<FET96QN*"<@(&5X=')A8W0@("`@($=E;F5R871E(%!/('1E;7!L871E("@N
M<&]T*2!F:6QE<RXG*3L*("`@("`@("`D8RT^=W)I=&5L;B@G("!I;FET("`@
M("`@("!#<F5A=&4@;VYE(&]R(&UO<F4@4$\@9FEL97,@9F]R(&$@;F5W(&QO
M8V%L92X@5V%R;FEN9SH@5&AI<R<I.PH@("`@("`@("1C+3YW<FET96QN*"<@
M("`@("`@("`@("`@(&]V97)W<FET97,@=&AE(&5X:7-T:6YG(%!/(&9I;&5S
M(&]F('1H:7,@;&]C86QE+B<I.PH@("`@("`@("1C+3YW<FET96QN*"<@(&UE
M<F=E("`@("`@($UE<F=E('1H92!C=7)R96YT(%!/(&9I;&4@=VET:"!T:&4@
M8W5R<F5N="!03R!T96UP;&%T92!F:6QE+B<I.PH@("`@("`@("1C+3YW<FET
M96QN*"<@('5P9&%T92`@("`@(%)U;B!E>'1R86-T(&%N9"!M97)G92!S97%U
M96YT+B<I.PH@("`@("`@("1C+3YW<FET96QN*"<@('5P9&%T92UH96QP($5X
M=')A8W0@86QL(&YE=R!A;F0@8VAA;F=E9"!E;G1R:65S(&9R;VT@=&AE($5N
M9VQI<V@@6$U,(&AE;'`G*3L*("`@("`@("`D8RT^=W)I=&5L;B@G("`@("`@
M("`@("`@("!F:6QE(&%N9"!M97)G92!T:&5M('=I=&@@=&AE(&5X:7-T:6YG
M(&]N97,N)RD["B`@("`@("`@)&,M/G=R:71E;&XH)R`@8VQE86YU<"`@("`@
M0VQE86YS('1H92!03R!F:6QE<R!U<"!F<F]M('5N=')A;G-L871E9"!A;F0@
M;V)S;VQE=&4@96YT<FEE<RXG*3L*("`@("`@("`D8RT^=W)I=&5L;B@G("!M
M86ME("`@("`@("!"=6EL9"!B:6YA<GD@34\@9FEL97,@9G)O;2!T:&4@<W!E
M8VEF:65D(%!/(&9I;&5S+B<I.PH@("`@("`@("1C+3YW<FET96QN*"<@(&UA
M:V4M:&5L<"`@($UA<FL@86QL(&5N=')I97,@:6X@=&AE(%A-3"!H96QP(&9I
M;&4@8F5I;F<@=7`M=&\M9&%T92!A;F0G*3L*("`@("`@("`D8RT^=W)I=&5L
M;B@G("`@("`@("`@("`@("!P<F5P87)E('1H92!F:6QE(&9O<B!T:&4@;F5X
M="!E>&5C=71I;VX@;V8@=7!D871E+6AE;'`N(%EO=2<I.PH@("`@("`@("1C
M+3YW<FET96QN*"<@("`@("`@("`@("`@('-H;W5L9"!O;FQY(')U;B!M86ME
M+6AE;'`@049415(@=7!D871E+6AE;'`@86YD(')E=FES:6YG('1H92<I.PH@
M("`@("`@("1C+3YW<FET96QN*"<@("`@("`@("`@("`@(&AE;'`@9FEL92XG
M*3L*("`@("`@("`D8RT^=W)I=&5L;B@G("!C;VUM:70@("`@("!#;VUM:70@
M=')A;G-L871I;VYS('1O('1H92!#5E,@<V5R=F5R+B<I.PH@("`@("`@("1C
M+3YW<FET96QN*"<@(&-O;6UI="UH96QP($-O;6UI="!H96QP(&9I;&5S('1O
M('1H92!#5E,@<V5R=F5R+B<I.PH@("`@?0H@("`@)&,M/G=R:71E;&XH*3L*
M("`@("1C+3YW<FET96QN*"=/<'1I;VYS.B<I.PH@("`@)&,M/G=R:71E;&XH
M)R`@+6(L("TM8F%S93TO4$%42"`@1G5L;"!P871H('1O('1H92`H2&]R9&4I
M(&)A<V4@9&ER96-T;W)Y('1H870@<VAO=6QD(&)E)RD["B`@("`D8RT^=W)I
M=&5L;B@G("`@("`@("`@("`@("`@("`@("!U<V5D+B<I.PH@("`@)&,M/G=R
M:71E;&XH)R`@+60L("TM9&5B=6<@("`@("`@4VAO=R!E<G)O<B!M97-S86=E
M<R!F<F]M('1H92!E>&5C=71E9"!B:6YA<FEE<RXG*3L*("`@("1C+3YW<FET
M96QN*"<@("UH+"`M+6AE;'`@("`@("`@(%-H;W<@=&AI<R!H96QP(&UE<W-A
M9V4N)RD["B`@("`D8RT^=W)I=&5L;B@G("`M="P@+2UT97-T("`@("`@("!3
M:&]W('1H92!E>&5C=71E9"!C;VUM86YD<R!B=70@9&]N7"=T(')U;B!A;GET
M:&EN9RXG*3L*?0H*9G5N8W1I;VX@8VAE8VM?8FEN87)I97,H*0I["B`@("!G
M;&]B86P@)&=E='1E>'1?=F5R<VEO;BP@)&,["@H@("`@)&,M/G=R:71E;&XH
M)U-E87)C:&EN9R!G971T97AT(&)I;F%R:65S+BXN)RD["B`@("!R97%U:7)E
M7V]N8V4@)U-Y<W1E;2YP:'`G.PH@("`@9F]R96%C:"`H87)R87DH)V=E='1E
M>'0G+"`G;7-G871T<FEB)RP@)VUS9V-A="<L("=M<V=C;VUM)RP@)VUS9V9M
M="<L("=M<V=I;FET)RP@)VUS9VUE<F=E)RP@)WAG971T97AT)RD@87,@)&)I
M;F%R>2D@>PH@("`@("`@(&5C:&\@)&)I;F%R>2`N("<N+BX@)SL*("`@("`@
M("`D1TQ/0D%,4ULD8FEN87)Y72`](%-Y<W1E;3HZ=VAI8V@H)&)I;F%R>2D[
M"B`@("`@("`@:68@*"1'3$]"04Q36R1B:6YA<GE=*2!["B`@("`@("`@("`@
M("1C+3YW<FET96QN*"1C+3YG<F5E;B@G9F]U;F0Z("<I("X@)$=,3T)!3%-;
M)&)I;F%R>5TI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1C+3YW
M<FET96QN*"1C+3YR960H)VYO="!F;W5N9"<I*3L*("`@("`@("`@("`@9F]O
M=&5R*"D["B`@("`@("`@?0H@("`@?0H@("`@)&,M/G=R:71E;&XH*3L*"B`@
M("`D;W5T(#T@)R<["B`@("!E>&5C*"1'3$]"04Q36R=G971T97AT)UT@+B`G
M("TM=F5R<VEO;B<L("1O=70L("1R970I.PH@("`@)'-P;&ET(#T@97AP;&]D
M92@G("<L("1O=71;,%TI.PH@("`@96-H;R`G9V5T=&5X="!V97)S:6]N.B`G
M("X@)'-P;&ET6V-O=6YT*"1S<&QI="D@+2`Q73L*("`@("1G971T97AT7W9E
M<G-I;VX@/2!E>'!L;V1E*"<N)RP@)'-P;&ET6V-O=6YT*"1S<&QI="D@+2`Q
M72D["B`@("!I9B`H)&=E='1E>'1?=F5R<VEO;ELP72`]/2`P("8F("1G971T
M97AT7W9E<G-I;VY;,5T@/"`Q,BD@>PH@("`@("`@("1'3$]"04Q36R=P:'!?
M<W5P<&]R="==(#T@9F%L<V4["B`@("`@("`@)&,M/G=R:71E;&XH*3L*("`@
M("`@("`D8RT^=W)I=&5L;B@D8RT^<F5D*"=787)N:6YG.B`G*2`N("=9;W5R
M(&=E='1E>'0@=F5R<VEO;B!I<R!T;V\@;VQD(&%N9"!D;V5S(&YO="!S=7!P
M;W)T(%!(4"!N871I=F5L>2XG*3L*("`@("`@("`D8RT^=W)I=&5L;B@G3F]T
M(&%L;"!S=')I;F=S('=I;&P@8F4@97AT<F%C=&5D+B<I.PH@("`@?2!E;'-E
M('L*("`@("`@("`D1TQ/0D%,4ULG<&AP7W-U<'!O<G0G72`]('1R=64["B`@
M("`@("`@)&,M/G=R:71E;&XH)&,M/F=R965N*"<@)R`N("=/2R<I*3L*("`@
M('T*("`@("1C+3YW<FET96QN*"D["GT*"F9U;F-T:6]N('-E87)C:%]F:6QE
M*"1F:6QE+"`D9&ER(#T@)RXG+"`D;&]C86P@/2!F86QS92D*>PH@("`@<W1A
M=&EC("1F9CL*("`@(&EF("@A:7-S970H)&9F*2D@>PH@("`@("`@("1F9B`]
M("9N97<@1FEL95]&:6YD*"D["B`@("!]"@H@("`@:68@*'-U8G-T<B@D9FEL
M92P@,"P@,2D@(3T@1%,I('L*("`@("`@("`D9FEL92`]("(O)&9I;&4O(CL*
M("`@('T*"B`@("!I9B`H)&QO8V%L*2!["B`@("`@("`@)&9I;&5S(#T@)&9F
M+3YG;&]B*"1F:6QE+"`D9&ER+"`G<&5R;"<I.PH@("`@("`@("1F:6QE<R`]
M(&%R<F%Y7VUA<"AC<F5A=&5?9G5N8W1I;VXH)R1F:6QE)RP@)W)E='5R;B`B
M)R`N("1D:7(@+B!$4R`N("<B("X@)&9I;&4[)RDL("1F:6QE<RD["B`@("`@
M("`@<F5T=7)N("1F:6QE<SL*("`@('T@96QS92!["B`@("`@("`@<F5T=7)N
M("1F9BT^<V5A<F-H*"1F:6QE+"`D9&ER+"`G<&5R;"<I.PH@("`@?0I]"@IF
M=6YC=&EO;B!S96%R8VA?97AT*"1E>'0L("1D:7(@/2`G+B<L("1L;V-A;"`]
M(&9A;'-E*0I["B`@("!R971U<FX@<V5A<F-H7V9I;&4H(BXK7%PN)&5X=%PD
M(BP@)&1I<BP@)&QO8V%L*3L*?0H*9G5N8W1I;VX@9V5T7W!O7V9I;&5S*"1D
M:7(I"GL*("`@("1L86YG<R`]('-E87)C:%]E>'0H)W!O)RP@)&1I<BD["B`@
M("!I9B`H*"1K97D@/2!A<G)A>5]S96%R8V@H)&1I<B`N($13("X@)VUE<W-A
M9V5S+G!O)RP@)&QA;F=S*2D@(3T](&9A;'-E*2!["B`@("`@("`@=6YS970H
M)&QA;F=S6R1K97E=*3L*("`@('T*("`@(&EF("@H)&ME>2`](&%R<F%Y7W-E
M87)C:"@D9&ER("X@1%,@+B`G8V]M<&5N9&EU;2YP;R<L("1L86YG<RDI("$]
M/2!F86QS92D@>PH@("`@("`@('5N<V5T*"1L86YG<ULD:V5Y72D["B`@("!]
M"B`@("!R971U<FX@)&QA;F=S.PI]"@IF=6YC=&EO;B!G971?;&%N9W5A9V5S
M*"1D:7(I"GL*("`@(&=L;V)A;"`D8W5R9&ER.PH*("`@(&-H9&ER*"1D:7(I
M.PH@("`@)&QA;F=S(#T@9V5T7W!O7V9I;&5S*"=P;R<I.PH@("`@)&QA;F=S
M(#T@87)R87E?;6%P*&-R96%T95]F=6YC=&EO;B@G)&QA;F<G+"`G<F5T=7)N
M('-T<E]R97!L86-E*")P;R(@+B!$4RP@(B(L('-T<E]R97!L86-E*"(N<&\B
M+"`B(BP@)&QA;F<I*3LG*2P@)&QA;F=S*3L*("`@(&-H9&ER*"1C=7)D:7(I
M.PH@("`@<F5T=7)N("1L86YG<SL*?0H*9G5N8W1I;VX@<V5A<F-H7V%P<&QI
M8V%T:6]N<R@I"GL*("`@("1D:7)S(#T@87)R87DH*3L*("`@("1H;W)D92`]
M(&9A;'-E.PH@("`@:68@*$!I<U]D:7(H0D%312`N($13("X@)W!O)RDI('L*
M("`@("`@("`D9&ER<UM=(#T@0D%313L*("`@("`@("`D:&]R9&4@/2!T<G5E
M.PH@("`@?0H@("`@)&1H(#T@0&]P96YD:7(H0D%312D["B`@("!I9B`H)&1H
M*2!["B`@("`@("`@=VAI;&4@*"1E;G1R>2`]($!R96%D9&ER*"1D:"DI('L*
M("`@("`@("`@("`@)&1I<B`]($)!4T4@+B!$4R`N("1E;G1R>3L*("`@("`@
M("`@("`@:68@*&ES7V1I<B@D9&ER*2`F)@H@("`@("`@("`@("`@("`@<W5B
M<W1R*"1E;G1R>2P@,"P@,2D@(3T@)RXG("8F"B`@("`@("`@("`@("`@("!F
M:6QE:6YO9&4H2$]21$5?0D%312D@(3T@9FEL96EN;V1E*"1D:7(I*2!["B`@
M("`@("`@("`@("`@("`D<W5B(#T@;W!E;F1I<B@D9&ER*3L*("`@("`@("`@
M("`@("`@(&EF("@D<W5B*2!["B`@("`@("`@("`@("`@("`@("`@=VAI;&4@
M*"1S=6)E;G1R>2`](')E861D:7(H)'-U8BDI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"1S=6)E;G1R>2`]/2`G<&\G("8F(&ES7V1I<B@D9&ER
M("X@1%,@+B`D<W5B96YT<GDI*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D9&ER<UM=(#T@)&1I<CL*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@D96YT<GD@/3T@)VAO<F1E)RD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1H;W)D92`]('1R=64["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@("`@("!I9B`H(21H;W)D92D@>PH@("`@("`@("`@("!A<G)A
M>5]U;G-H:69T*"1D:7)S+"!(3U)$15]"05-%*3L*("`@("`@("!]"B`@("!]
M"@H@("`@<F5T=7)N("1D:7)S.PI]"@IF=6YC=&EO;B!S=')I<%]H;W)D92@D
M9FEL92D*>PH@("`@:68@*&ES7V%R<F%Y*"1F:6QE*2D@>PH@("`@("`@(')E
M='5R;B!A<G)A>5]M87`H8W)E871E7V9U;F-T:6]N*"<D9FEL92<L("=R971U
M<FX@<W1R:7!?:&]R9&4H)&9I;&4I.R<I+"`D9FEL92D["B`@("!](&5L<V4@
M>PH@("`@("`@(')E='5R;B!S=')?<F5P;&%C92A"05-%("X@1%,L("<G+"`D
M9FEL92D["B`@("!]"GT*"F9U;F-T:6]N('AT<F%C="@I"GL*("`@(&=L;V)A
M;"`D8VUD7V]P=&EO;G,L("1A<'!S+"`D9&ER<RP@)&1E8G5G+"`D=&5S="P@
M)&,L("1G971T97AT7W9E<G-I;VXL("1S:6QE;F-E+"`D8W5R9&ER.PH*("`@
M(&9O<F5A8V@@*"1C;61?;W!T:6]N<ULP72!A<R`D;W!T:6]N*2!["B`@("`@
M("`@<W=I=&-H("@D;W!T:6]N6S!=*2!["B`@("`@("`@("`@(&-A<V4@)V@G
M.@H@("`@("`@("`@("`@("`@=7-A9V4H*3L*("`@("`@("`@("`@("`@(&9O
M;W1E<B@I.PH@("`@("`@("`@("!C87-E("=M)SH*("`@("`@("`@("`@8V%S
M92`G+2UM;V1U;&4G.@H@("`@("`@("`@("`@("`@)&UO9'5L92`]("1O<'1I
M;VY;,5T["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@("!]
M"B`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T%R<F%Y+G!H<"<["B`@("!I9B`H
M)$=,3T)!3%-;)W!H<%]S=7!P;W)T)UTI('L*("`@("`@("`D;&%N9W5A9V4@
M/2`G4$A0)SL*("`@('T@96QS92!["B`@("`@("`@)&QA;F=U86=E(#T@)T,K
M*R<["B`@("!]"B`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D9&ER<RD[
M("1I*RLI('L*("`@("`@("!I9B`H(65M<'1Y*"1M;V1U;&4I("8F("1M;V1U
M;&4@(3T@)&%P<'-;)&E=*2!["B`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@
M("`@('T*("`@("`@("!P<FEN=&8H)T5X=')A8W1I;F<@9G)O;2`E<RXN+B`G
M+"`D87!P<ULD:5TI.PH@("`@("`@(&-H9&ER*"1D:7)S6R1I72D["B`@("`@
M("`@:68@*"1A<'!S6R1I72`]/2`G:&]R9&4G*2!["B`@("`@("`@("`@("1F
M:6QE<R`]('-E87)C:%]E>'0H)W!H<"<L("<N)RP@=')U92D["B`@("`@("`@
M("`@(&9O<F5A8V@@*&%R<F%Y*"=A9&UI;B<L("=F<F%M97=O<FLG+"`G;&EB
M)RP@)W-E<G9I8V5S)RP@)W1E;7!L871E<R<L("=U=&EL)RP@)V-O;F9I9R<@
M+B!$4R`N("=T:&5M97,G*2!A<R`D<V5A<F-H7V1I<BD@>PH@("`@("`@("`@
M("`@("`@)&9I;&5S(#T@87)R87E?;65R9V4H)&9I;&5S+"!S96%R8VA?97AT
M*"<H<&AP?&EN8WQJ<RDG+"`D<V5A<F-H7V1I<BDI.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1F:6QE<R`](&%R<F%Y7VUE<F=E*"1F:6QE<RP@<V5A
M<F-H7V5X="@G9&ES="<L("=C;VYF:6<G*2D["B`@("`@("`@("`@("1S:"`]
M("1'3$]"04Q36R=X9V5T=&5X="==("X@)R`M+6QA;F=U86=E/2<@+B`D;&%N
M9W5A9V4@+@H@("`@("`@("`@("`@("`@("`G("TM9G)O;2UC;V1E/6ES;RTX
M.#4Y+3$@+2UK97EW;W)D/5\@+2US;W)T+6]U='!U="`M+6-O<'ER:6=H="UH
M;VQD97(](DAO<F1E(%!R;VIE8W0B)SL*("`@("`@("`@("`@:68@*"1G971T
M97AT7W9E<G-I;VY;,%T@/B`P('Q\("1G971T97AT7W9E<G-I;VY;,5T@/B`Q
M,2D@>PH@("`@("`@("`@("`@("`@)'-H("X]("<@+2UM<V=I9"UB=6=S+6%D
M9')E<W,](F1E=D!L:7-T<RYH;W)D92YO<F<B)SL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D9FEL92`]("1D:7)S6R1I72`N($13("X@)W!O)R`N($13
M("X@)&%P<'-;)&E=("X@)RYP;W0G.PH@("`@("`@("`@("!I9B`H9FEL95]E
M>&ES=',H)&9I;&4I("8F("%I<U]W<FET86)L92@D9FEL92DI('L*("`@("`@
M("`@("`@("`@("1C+3YW<FET96QN*"1C+3YR960H<W!R:6YT9B@G)7,@:7,@
M;F]T('=R:71A8FQE+B<L("1F:6QE*2DI.PH@("`@("`@("`@("`@("`@9F]O
M=&5R*"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1M<%]F:6QE(#T@
M)&9I;&4@+B`G+G1M<"YP;W0G.PH@("`@("`@("`@("`D<V@@+CT@)R`M;R`G
M("X@)'1M<%]F:6QE("X@)R`G("X@:6UP;&]D92@G("<L("1F:6QE<RD["B`@
M("`@("`@("`@(&EF("A`9FEL95]E>&ES=',H)&1I<G-;)&E=("X@)R]P;R]T
M<F%N<VQA=&EO;BYP:'`G*2D@>PH@("`@("`@("`@("`@("`@)'-H("X]("<@
M<&\O=')A;G-L871I;VXN<&AP)SL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H(21D96)U9RD@>PH@("`@("`@("`@("`@("`@)'-H("X]("1S:6QE
M;F-E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D9&5B=6<@?'P@
M)'1E<W0I('L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"=%>&5C=71I
M;F<Z)RD["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@D<V@I.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&EF("@A)'1E<W0I(&5X96,H)'-H*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9FEL97,@/2!S96%R8VA?
M97AT*"<H<&AP?&EN8WQJ<RDG*3L*("`@("`@("`@("`@)&9I;&5S(#T@87)R
M87E?9FEL=&5R*"1F:6QE<RP@8W)E871E7V9U;F-T:6]N*"<D9FEL92<L("=R
M971U<FX@<W5B<W1R*"1F:6QE+"`P+"`Y*2`A/2`B+B(@+B!$4R`N(")C;VYF
M:6<B("X@1%,[)RDI.PH@("`@("`@("`@("`D9FEL97,@/2!A<G)A>5]M97)G
M92@D9FEL97,L('-E87)C:%]E>'0H)V1I<W0G+"`G8V]N9FEG)RDI.PH@("`@
M("`@("`@("`D<V@@/2`D1TQ/0D%,4ULG>&=E='1E>'0G72`N("<@+2UL86YG
M=6%G93TG("X@)&QA;F=U86=E("X*("`@("`@("`@("`@("`@("`@)R`M+6ME
M>7=O<F0]7R`M+7-O<G0M;W5T<'5T("TM9F]R8V4M<&\@+2UC;W!Y<FEG:'0M
M:&]L9&5R/2)(;W)D92!0<F]J96-T(B<["B`@("`@("`@("`@(&EF("@D9V5T
M=&5X=%]V97)S:6]N6S!=(#X@,"!\?"`D9V5T=&5X=%]V97)S:6]N6S%=(#X@
M,3$I('L*("`@("`@("`@("`@("`@("1S:"`N/2`G("TM;7-G:60M8G5G<RUA
M9&1R97-S/2)D979`;&ES=',N:&]R9&4N;W)G(B<["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)&9I;&4@/2`G<&\G("X@1%,@+B`D87!P<ULD:5T@+B`G
M+G!O="<["B`@("`@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D9FEL92D@)B8@
M(6ES7W=R:71A8FQE*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@)&,M/G=R
M:71E;&XH)&,M/G)E9"AS<')I;G1F*"<E<R!I<R!N;W0@=W)I=&%B;&4N)RP@
M)&9I;&4I*2D["B`@("`@("`@("`@("`@("!F;V]T97(H*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D=&UP7V9I;&4@/2`D9FEL92`N("<N=&UP+G!O
M="<["B`@("`@("`@("`@("1S:"`N/2`G("UO("<@+B`D=&UP7V9I;&4@+B`G
M("<@+B!I;7!L;V1E*"<@)RP@)&9I;&5S*2`N("@D9&5B=6<@/R`G)R`Z("1S
M:6QE;F-E*3L*("`@("`@("`@("`@:68@*"1D96)U9R!\?"`D=&5S="D@>PH@
M("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)T5X96-U=&EN9SHG*3L*("`@
M("`@("`@("`@("`@("1C+3YW<FET96QN*"1S:"D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@:68@*"$D=&5S="D@97AE8R@D<V@I.PH@("`@("`@('T*
M("`@("`@("!I9B`H9FEL95]E>&ES=',H)'1M<%]F:6QE*2D@>PH@("`@("`@
M("`@("`D9FEL97,@/2!S96%R8VA?97AT*"=H=&UL)RP@)W1E;7!L871E<R<I
M.PH@("`@("`@("`@("!I9B`H(21T97-T*2`D=&UP(#T@9F]P96XH)&9I;&4@
M+B`G+G1E;7!L871E<R<L("=W)RD["B`@("`@("`@("`@(&9O<F5A8V@@*"1F
M:6QE<R!A<R`D=&5M<&QA=&4I('L*("`@("`@("`@("`@("`@("1F<"`](&9O
M<&5N*"1T96UP;&%T92P@)W(G*3L*("`@("`@("`@("`@("`@("1L:6YE;F\@
M/2`P.PH@("`@("`@("`@("`@("`@=VAI;&4@*"@D;&EN92`](&9G971S*"1F
M<"P@-#`Y-BDI("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@("1L
M:6YE;F\K*SL*("`@("`@("`@("`@("`@("`@("`D;V9F<V5T(#T@,#L*("`@
M("`@("`@("`@("`@("`@("!W:&EL92`H*"1L969T(#T@<W1R<&]S*"1L:6YE
M+"`G/&=E='1E>'0^)RP@)&]F9G-E="DI("$]/2!F86QS92D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D;&5F="`K/2`Y.PH@("`@("`@("`@("`@("`@
M("`@("`@("`D8G5F9F5R(#T@)R<["B`@("`@("`@("`@("`@("`@("`@("`@
M("1L:6YE<W!A;B`](#`["B`@("`@("`@("`@("`@("`@("`@("`@('=H:6QE
M("@H)&5N9"`]('-T<G!O<R@D;&EN92P@)SPO9V5T=&5X=#XG+"`D;&5F="DI
M(#T]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&)U
M9F9E<B`N/2!S=6)S='(H)&QI;F4L("1L969T*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1L969T(#T@,#L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1L:6YE(#T@9F=E=',H)&9P+"`T,#DV*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1L:6YE<W!A;BLK.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"1L:6YE(#T]/2!F86QS92D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"1C+3YR960H<W!R
M:6YT9B@B/&=E='1E>'0^('1A9R!N;W0@8VQO<V5D(&EN(&9I;&4@)7,N7&Y/
M<&5N:6YG('1A9R!F;W5N9"!I;B!L:6YE("5D+B(L("1T96UP;&%T92P@)&QI
M;F5N;RDI*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A
M:R`R.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("1B=69F
M97(@+CT@<W5B<W1R*"1L:6YE+"`D;&5F="P@)&5N9"`M("1L969T*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"$D=&5S="D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@9G=R:71E*"1T;7`L("(C.B`D=&5M<&QA=&4Z
M)&QI;F5N;UQN(BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F=W)I
M=&4H)'1M<"P@)VUS9VED("(G("X@<W1R7W)E<&QA8V4H87)R87DH)R(G+"`B
M7&XB*2P@87)R87DH)UPB)RP@(EQ<;EPB7&Y<(B(I+"`D8G5F9F5R*2`N(")<
M(EQN(BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F=W)I=&4H)'1M
M<"P@)VUS9W-T<B`B(B<@+B`B7&Y<;B(I.PH@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("1O9F9S970@/2`D96YD
M("L@,3`["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@9F-L;W-E*"1F<"D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@9F-L;W-E*"1T;7`I.PH@("`@("`@("`@("`D<V@@/2`D
M1TQ/0D%,4ULG;7-G8V]M;2==("X@(B`M+6UO<F4M=&AA;CTP("TM<V]R="UO
M=71P=70@7"(D=&UP7V9I;&5<(B!<(B1F:6QE+G1E;7!L871E<UPB("TM;W5T
M<'5T+69I;&4@7"(D=&UP7V9I;&5<(B(@+B`D<VEL96YC93L*("`@("`@("`@
M("`@:68@*"1D96)U9R!\?"`D=&5S="D@>PH@("`@("`@("`@("`@("`@)&,M
M/G=R:71E;&XH)T5X96-U=&EN9SHG*3L*("`@("`@("`@("`@("`@("1C+3YW
M<FET96QN*"1S:"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"$D
M=&5S="D@>PH@("`@("`@("`@("`@("`@97AE8R@D<V@I.PH@("`@("`@("`@
M("`@("`@=6YL:6YK*"1F:6QE("X@)RYT96UP;&%T97,G*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!I9B`H9FEL95]E>&ES=',H)&9I;&4I*2!["B`@
M("`@("`@("`@("`@("`D9&EF9B`](&%R<F%Y7V1I9F8H9FEL92@D=&UP7V9I
M;&4I+"!F:6QE*"1F:6QE*2D["B`@("`@("`@("`@("`@("`D9&EF9B`]('!R
M96=?9W)E<"@G+UXB4$]4+4-R96%T:6]N+41A=&4Z+R<L("1D:69F+"!04D5'
M7T=215!?24Y615)4*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!I9B`H(69I;&5?97AI<W1S*"1F:6QE*2!\?"!C;W5N="@D9&EF9BDI('L*
M("`@("`@("`@("`@0'5N;&EN:R@D9FEL92D["B`@("`@("`@("`@(')E;F%M
M92@D=&UP7V9I;&4L("1F:6QE*3L*("`@("`@("`@("`@)&,M/G=R:71E;&XH
M)&,M/F=R965N*"=U<&1A=&5D)RDI.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@($!U;FQI;FLH)'1M<%]F:6QE*3L*("`@("`@("`@("`@)&,M/G=R
M:71E;&XH)&,M/F)O;&0H)VYO="!C:&%N9V5D)RDI.PH@("`@("`@('T*("`@
M("`@("!C:&1I<B@D8W5R9&ER*3L*("`@('T*?0H*9G5N8W1I;VX@;65R9V4H
M*0I["B`@("!G;&]B86P@)&-M9%]O<'1I;VYS+"`D87!P<RP@)&1I<G,L("1D
M96)U9RP@)'1E<W0L("1C.PH*("`@("1C;VUP96YD:75M(#T@)R`M+6-O;7!E
M;F1I=6T](B<@+B!"05-%("X@1%,@+B`G<&\G("X@1%,@+B`G8V]M<&5N9&EU
M;2YP;R(G.PH@("`@9F]R96%C:"`H)&-M9%]O<'1I;VYS6S!=(&%S("1O<'1I
M;VXI('L*("`@("`@("!S=VET8V@@*"1O<'1I;VY;,%TI('L*("`@("`@("`@
M("`@8V%S92`G:"<Z"B`@("`@("`@("`@("`@("!U<V%G92@I.PH@("`@("`@
M("`@("`@("`@9F]O=&5R*"D["B`@("`@("`@("`@(&-A<V4@)VPG.@H@("`@
M("`@("`@("!C87-E("<M+6QO8V%L92<Z"B`@("`@("`@("`@("`@("`D;&%N
M9R`]("1O<'1I;VY;,5T["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@8V%S92`G;2<Z"B`@("`@("`@("`@(&-A<V4@)RTM;6]D=6QE)SH*
M("`@("`@("`@("`@("`@("1M;V1U;&4@/2`D;W!T:6]N6S%=.PH@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@)V,G.@H@("`@("`@
M("`@("!C87-E("<M+6-O;7!E;F1I=6TG.@H@("`@("`@("`@("`@("`@)&-O
M;7!E;F1I=6T@/2`G("TM8V]M<&5N9&EU;3TG("X@)&]P=&EO;ELQ73L*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=N)SH*("`@
M("`@("`@("`@8V%S92`G+2UN;RUC;VUP96YD:75M)SH*("`@("`@("`@("`@
M("`@("1C;VUP96YD:75M(#T@)R<["B`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("!]"B`@("!]"B`@("!I9B`H(6ES<V5T*"1L86YG*2`F)B`A96UP
M='DH)&-O;7!E;F1I=6TI*2!["B`@("`@("`@)&,M/G=R:71E;&XH)&,M/G)E
M9"@G17)R;W(Z("<@+B`G3F\@;&]C86QE('-P96-I9FEE9"XG*2D["B`@("`@
M("`@)&,M/G=R:71E;&XH*3L*("`@("`@("!U<V%G92@I.PH@("`@("`@(&9O
M;W1E<B@I.PH@("`@?0H*("`@(&-L96%N=7`H*3L*"B`@("!F;W(@*"1I(#T@
M,#L@)&D@/"!C;W5N="@D9&ER<RD[("1I*RLI('L*("`@("`@("!I9B`H(65M
M<'1Y*"1M;V1U;&4I("8F("1M;V1U;&4@(3T@)&%P<'-;)&E=*2!["B`@("`@
M("`@("`@(&-O;G1I;G5E.PH@("`@("`@('T*("`@("`@("`D8RT^=W)I=&5L
M;BAS<')I;G1F*"=-97)G:6YG('1R86YS;&%T:6]N(&9O<B!M;V1U;&4@)7,N
M+BXG+"`D8RT^8F]L9"@D87!P<ULD:5TI*2D["B`@("`@("`@)&1I<B`]("1D
M:7)S6R1I72`N($13("X@)W!O)R`N($13.PH@("`@("`@(&EF("AE;7!T>2@D
M;&%N9RDI('L*("`@("`@("`@("`@)&QA;F=S(#T@9V5T7VQA;F=U86=E<R@D
M9&ER<ULD:5TI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@A
M0&9I;&5?97AI<W1S*"1D:7(@+B`D;&%N9R`N("<N<&\G*2D@>PH@("`@("`@
M("`@("`@("`@)&,M/G=R:71E;&XH)U-K:7!P960N+BXG*3L*("`@("`@("`@
M("`@("`@("1C+3YW<FET96QN*"D["B`@("`@("`@("`@("`@("!C;VYT:6YU
M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D;&%N9W,@/2!A<G)A>2@D
M;&%N9RD["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1L86YG<R!A<R`D
M;&]C86QE*2!["B`@("`@("`@("`@("1C+3YW<FET96QN*'-P<FEN=&8H)TUE
M<F=I;F<@;&]C86QE("5S+BXN("<L("1C+3YB;VQD*"1L;V-A;&4I*2D["B`@
M("`@("`@("`@("1S:"`]("1'3$]"04Q36R=M<V=M97)G92==("X@)R`M+75P
M9&%T92`M=B<@+B`D8V]M<&5N9&EU;2`N("<@(B<@+B`D9&ER("X@)&QO8V%L
M92`N("<N<&\B("(G("X@)&1I<B`N("1A<'!S6R1I72`N("<N<&]T(B<["B`@
M("`@("`@("`@(&EF("@D9&5B=6<@?'P@)'1E<W0I('L*("`@("`@("`@("`@
M("`@("1C+3YW<FET96QN*"=%>&5C=71I;F<Z)RD["B`@("`@("`@("`@("`@
M("`D8RT^=W)I=&5L;B@D<V@I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("@A)'1E<W0I(&5X96,H)'-H*3L*("`@("`@("`@("`@)&,M/G=R:71E
M;&XH)&,M/F=R965N*"=D;VYE)RDI.PH@("`@("`@('T*("`@('T*?0H*9G5N
M8W1I;VX@<W1A='5S*"D*>PH@("`@<F5T=7)N.PH@("`@9VQO8F%L("1C;61?
M;W!T:6]N<RP@)&%P<',L("1D:7)S+"`D9&5B=6<L("1T97-T+"`D8SL*"B`@
M("`D;W5T<'5T(#T@(G-T871U<RYH=&UL(CL*("`@(&9O<F5A8V@@*"1C;61?
M;W!T:6]N<ULP72!A<R`D;W!T:6]N*2!["B`@("`@("`@<W=I=&-H("@D;W!T
M:6]N6S!=*2!["B`@("`@("`@("`@(&-A<V4@)V@G.@H@("`@("`@("`@("`@
M("`@=7-A9V4H*3L*("`@("`@("`@("`@("`@(&9O;W1E<B@I.PH@("`@("`@
M("`@("!C87-E("=L)SH*("`@("`@("`@("`@8V%S92`G+2UL;V-A;&4G.@H@
M("`@("`@("`@("`@("`@)&QA;F<@/2`D;W!T:6]N6S%=.PH@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@)VTG.@H@("`@("`@("`@
M("!C87-E("<M+6UO9'5L92<Z"B`@("`@("`@("`@("`@("`D;6]D=6QE(#T@
M)&]P=&EO;ELQ73L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("!C87-E("=O)SH*("`@("`@("`@("`@8V%S92`G+2UO=71P=70G.@H@("`@
M("`@("`@("`@("`@)&]U='!U="`]("1O<'1I;VY;,5T["B`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@('T*("`@('T*("`@(&9O<B`H)&D@/2`P.R`D
M:2`\(&-O=6YT*"1D:7)S*3L@)&DK*RD@>PH@("`@("`@(&EF("@A96UP='DH
M)&UO9'5L92D@)B8@)&UO9'5L92`A/2`D87!P<ULD:5TI('L*("`@("`@("`@
M("`@8V]N=&EN=64["B`@("`@("`@?0H@("`@("`@("1C+3YW<FET96QN*'-P
M<FEN=&8H)T=E;F5R871I;F<@<W1A='5S(&9O<B!M;V1U;&4@)7,N+BXG+"`D
M8RT^8F]L9"@D87!P<ULD:5TI*2D["B`@("`@("`@:68@*&5M<'1Y*"1L86YG
M*2D@>PH@("`@("`@("`@("`D;&%N9W,@/2!G971?;&%N9W5A9V5S*"1D:7)S
M6R1I72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*"%`9FEL
M95]E>&ES=',H)&1I<G-;)&E=("X@1%,@+B`G<&\G("X@1%,@+B`D;&%N9R`N
M("<N<&\G*2D@>PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)U-K:7!P
M960N+BXG*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"D["B`@("`@
M("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D;&%N9W,@/2!A<G)A>2@D;&%N9RD["B`@("`@("`@?0H@("`@("`@(&9O
M<F5A8V@@*"1L86YG<R!A<R`D;&]C86QE*2!["B`@("`@("`@("`@("1C+3YW
M<FET96QN*'-P<FEN=&8H)U-T871U<R!F;W(@;&]C86QE("5S+BXN("<L("1C
M+3YB;VQD*"1L;V-A;&4I*2D["B`@("`@("`@?0H@("`@?0I]"@IF=6YC=&EO
M;B!C;VUP96YD:75M*"D*>PH@("`@9VQO8F%L("1C;61?;W!T:6]N<RP@)&1I
M<G,L("1D96)U9RP@)'1E<W0L("1C+"`D<VEL96YC93L*"B`@("`D9&ER(#T@
M0D%312`N($13("X@)W!O)R`N($13.PH@("`@)&%D9"`]("<G.PH@("`@9F]R
M96%C:"`H)&-M9%]O<'1I;VYS6S!=(&%S("1O<'1I;VXI('L*("`@("`@("!S
M=VET8V@@*"1O<'1I;VY;,%TI('L*("`@("`@("`@("`@8V%S92`G:"<Z"B`@
M("`@("`@("`@("`@("!U<V%G92@I.PH@("`@("`@("`@("`@("`@9F]O=&5R
M*"D["B`@("`@("`@("`@(&-A<V4@)VPG.@H@("`@("`@("`@("!C87-E("<M
M+6QO8V%L92<Z"B`@("`@("`@("`@("`@("`D;&%N9R`]("1O<'1I;VY;,5T[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G9"<Z
M"B`@("`@("`@("`@(&-A<V4@)RTM9&ER96-T;W)Y)SH*("`@("`@("`@("`@
M("`@("1D:7(@/2`D;W!T:6]N6S%=.PH@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@(&-A<V4@)V$G.@H@("`@("`@("`@("!C87-E("<M+6%D
M9"<Z"B`@("`@("`@("`@("`@("`D861D(#T@)R`G("X@)&]P=&EO;ELQ73L*
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@('T*("`@(&EF
M("@A:7-S970H)&QA;F<I*2!["B`@("`@("`@)&,M/G=R:71E;&XH)&,M/G)E
M9"@G17)R;W(Z("<@+B`G3F\@;&]C86QE('-P96-I9FEE9"XG*2D["B`@("`@
M("`@)&,M/G=R:71E;&XH*3L*("`@("`@("!U<V%G92@I.PH@("`@("`@(&9O
M;W1E<B@I.PH@("`@?0H@("`@<')I;G1F*"=-97)G:6YG(&%L;"`E<RYP;R!F
M:6QE<R!T;R!T:&4@8V]M<&5N9&EU;2XN+B`G+"`D;&%N9RD["B`@("`D<&]F
M:6QE<R`](&%R<F%Y*"D["B`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D
M9&ER<RD[("1I*RLI('L*("`@("`@("`D<&]F:6QE(#T@)&1I<G-;)&E=("X@
M1%,@+B`G<&\G("X@1%,@+B`D;&%N9R`N("<N<&\G.PH@("`@("`@(&EF("AF
M:6QE7V5X:7-T<R@D<&]F:6QE*2D@>PH@("`@("`@("`@("`D<&]F:6QE<UM=
M(#T@)'!O9FEL93L*("`@("`@("!]"B`@("!]"B`@("!I9B`H(65M<'1Y*"1D
M:7(I("8F('-U8G-T<B@D9&ER+"`M,2D@(3T@1%,I('L*("`@("`@("`D9&ER
M("X]($13.PH@("`@?0H@("`@)'-H(#T@)$=,3T)!3%-;)VUS9V-A="==("X@
M)R`M+7-O<G0M;W5T<'5T("<@+B!I;7!L;V1E*"<@)RP@)'!O9FEL97,I("X@
M)&%D9"`N("<@/B`G("X@)&1I<B`N("=C;VUP96YD:75M+G!O("<@+B`H)&1E
M8G5G(#\@)R<@.B`D<VEL96YC92D["B`@("!I9B`H)&1E8G5G('Q\("1T97-T
M*2!["B`@("`@("`@)&,M/G=R:71E;&XH*3L*("`@("`@("`D8RT^=W)I=&5L
M;B@G17AE8W5T:6YG.B<I.PH@("`@("`@("1C+3YW<FET96QN*"1S:"D["B`@
M("!]"B`@("!I9B`H)'1E<W0I('L*("`@("`@("`D<F5T(#T@,#L*("`@('T@
M96QS92!["B`@("`@("`@97AE8R@D<V@L("1O=70L("1R970I.PH@("`@?0H@
M("`@:68@*"1R970@/3T@,"D@>PH@("`@("`@("1C+3YW<FET96QN*"1C+3YG
M<F5E;B@G9&]N92<I*3L*("`@('T@96QS92!["B`@("`@("`@)&,M/G=R:71E
M;&XH)&,M/G)E9"@G9F%I;&5D)RDI.PH@("`@?0I]"@IF=6YC=&EO;B!I;FET
M*"D*>PH@("`@9VQO8F%L("1C;61?;W!T:6]N<RP@)&%P<',L("1D:7)S+"`D
M9&5B=6<L("1T97-T+"`D8RP@)'-I;&5N8V4["@H@("`@9F]R96%C:"`H)&-M
M9%]O<'1I;VYS6S!=(&%S("1O<'1I;VXI('L*("`@("`@("!S=VET8V@@*"1O
M<'1I;VY;,%TI('L*("`@("`@("`@("`@8V%S92`G:"<Z"B`@("`@("`@("`@
M("`@("!U<V%G92@I.PH@("`@("`@("`@("`@("`@9F]O=&5R*"D["B`@("`@
M("`@("`@(&-A<V4@)VPG.@H@("`@("`@("`@("!C87-E("<M+6QO8V%L92<Z
M"B`@("`@("`@("`@("`@("`D;&%N9R`]("1O<'1I;VY;,5T["B`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G;2<Z"B`@("`@("`@
M("`@(&-A<V4@)RTM;6]D=6QE)SH*("`@("`@("`@("`@("`@("1M;V1U;&4@
M/2`D;W!T:6]N6S%=.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M?0H@("`@?0H@("`@:68@*&5M<'1Y*"1L86YG*2D@>R`D;&%N9R`](&=E=&5N
M=B@G3$%.1R<I.R!]"B`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D9&ER
M<RD[("1I*RLI('L*("`@("`@("!I9B`H(65M<'1Y*"1M;V1U;&4I("8F("1M
M;V1U;&4@(3T@)&%P<'-;)&E=*2![(&-O;G1I;G5E.R!]"B`@("`@("`@)'!A
M8VMA9V4@/2!U8V9I<G-T*"1A<'!S6R1I72D["B`@("`@("`@)'!A8VMA9V5?
M=2`](%-T<FEN9SHZ=7!P97(H)&%P<'-;)&E=*3L*("`@("`@("!`:6YC;'5D
M92`D9&ER<ULD:5T@+B`G+VQI8B]V97)S:6]N+G!H<"<["B`@("`@("`@)'9E
M<G-I;VX@/2!D969I;F5D*"1P86-K86=E7W4@+B`G7U9%4E-)3TXG*2`_(&-O
M;G-T86YT*"1P86-K86=E7W4@+B`G7U9%4E-)3TXG*2`Z("<_/S\G.PH@("`@
M("`@('!R:6YT9B@G26YI=&EA;&EZ:6YG(&UO9'5L92`E<RXN+B`G+"`D87!P
M<ULD:5TI.PH@("`@("`@(&EF("@A0&9I;&5?97AI<W1S*"1D:7)S6R1I72`N
M("<O<&\O)R`N("1A<'!S6R1I72`N("<N<&]T)RDI('L*("`@("`@("`@("`@
M)&,M/G=R:71E;&XH)&,M/G)E9"@G9F%I;&5D)RDI.PH@("`@("`@("`@("`D
M8RT^=W)I=&5L;BAS<')I;G1F*"<E<R!N;W0@9F]U;F0N(%)U;B!<)W1R86YS
M;&%T:6]N(&5X=')A8W1<)R!F:7)S="XG+"`D9&ER<ULD:5T@+B!$4R`N("=P
M;R<@+B!$4R`N("1A<'!S6R1I72`N("<N<&]T)RDI.PH@("`@("`@("`@("!C
M;VYT:6YU93L*("`@("`@("!]"B`@("`@("`@)&1I<B`]("1D:7)S6R1I72`N
M($13("X@)W!O)R`N($13.PH@("`@("`@("1S:"`]("1'3$]"04Q36R=M<V=I
M;FET)UT@+B`G("TM;F\M=')A;G-L871O<B`M:2`G("X@)&1I<B`N("1A<'!S
M6R1I72`N("<N<&]T("<@+@H@("`@("`@("`@("`@("@A96UP='DH)&QA;F<I
M(#\@)R`M;R`G("X@)&1I<B`N("1L86YG("X@)RYP;R`M+6QO8V%L93TG("X@
M)&QA;F<@.B`G)RD@+@H@("`@("`@("`@("`@("@D9&5B=6<@/R`G)R`Z("1S
M:6QE;F-E*3L*("`@("`@("!I9B`H(65M<'1Y*"1L86YG*2`F)B`A3U-?5TE.
M1$]74RD@>PH@("`@("`@("`@("`D<&]F:6QE(#T@)&1I<G-;)&E=("X@)R]P
M;R\G("X@)&QA;F<@+B`G+G!O)SL*("`@("`@("`@("`@)'-H("X]("([('-E
M9"`G<R]004-+04=%('!A8VMA9V4O)'!A8VMA9V4@<&%C:V%G92\G("1P;V9I
M;&4@(B`N"B`@("`@("`@("`@("`@("`@("`B?"!S960@)W,O4$%#2T%'12!6
M15)324].+R1P86-K86=E("1V97)S:6]N+R<@(B`N"B`@("`@("`@("`@("`@
M("`@("`B?"!S960@)W,O;65S<V%G97,@9F]R(%!!0TM!1T4O;65S<V%G97,@
M9F]R("1P86-K86=E+R<@(B`N"B`@("`@("`@("`@("`@("`@("`B?"!S960@
M)W,O3&%N9W5A9V4M5&5A;3H@;F]N92],86YG=6%G92U496%M.B!I,3AN0&QI
M<W1S+FAO<F1E+F]R9R\G("(@+@H@("`@("`@("`@("`@("`@("`@(CX@)'!O
M9FEL92YT;7`B.PH@("`@("`@('T*("`@("`@("!I9B`H)&1E8G5G('Q\("1T
M97-T*2!["B`@("`@("`@("`@("1C+3YW<FET96QN*"=%>&5C=71I;F<Z)RD[
M"B`@("`@("`@("`@("1C+3YW<FET96QN*"1S:"D["B`@("`@("`@?0H@("`@
M("`@(&EF("@D=&5S="D@>PH@("`@("`@("`@("`D<F5T(#T@,#L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!E>&5C*"1S:"P@)&]U="P@)')E="D[
M"B`@("`@("`@?0H@("`@("`@(')E;F%M92@D<&]F:6QE("X@)RYT;7`G+"`D
M<&]F:6QE*3L*("`@("`@("!I9B`H)')E="`]/2`P*2!["B`@("`@("`@("`@
M("1C+3YW<FET96QN*"1C+3YG<F5E;B@G9&]N92<I*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D8RT^=W)I=&5L;B@D8RT^<F5D*"=F86EL960G
M*2D["B`@("`@("`@?0H@("`@?0I]"@IF=6YC=&EO;B!M86ME*"D*>PH@("`@
M9VQO8F%L("1C;61?;W!T:6]N<RP@)&%P<',L("1D:7)S+"`D9&5B=6<L("1T
M97-T+"`D8RP@)'-I;&5N8V4L("1R961I<E]E<G(["@H@("`@)&-O;7!E;F1I
M=6T@/2!"05-%("X@1%,@+B`G<&\G("X@1%,@+B`G8V]M<&5N9&EU;2YP;R<[
M"B`@("`D<V%V95]S=&%T<R`](&9A;'-E.PH@("`@9F]R96%C:"`H)&-M9%]O
M<'1I;VYS6S!=(&%S("1O<'1I;VXI('L*("`@("`@("!S=VET8V@@*"1O<'1I
M;VY;,%TI('L*("`@("`@("`@("`@8V%S92`G:"<Z"B`@("`@("`@("`@("`@
M("!U<V%G92@I.PH@("`@("`@("`@("`@("`@9F]O=&5R*"D["B`@("`@("`@
M("`@(&-A<V4@)VPG.@H@("`@("`@("`@("!C87-E("<M+6QO8V%L92<Z"B`@
M("`@("`@("`@("`@("`D;&%N9R`]("1O<'1I;VY;,5T["B`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G;2<Z"B`@("`@("`@("`@
M(&-A<V4@)RTM;6]D=6QE)SH*("`@("`@("`@("`@("`@("1M;V1U;&4@/2`D
M;W!T:6]N6S%=.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M(&-A<V4@)V,G.@H@("`@("`@("`@("!C87-E("<M+6-O;7!E;F1I=6TG.@H@
M("`@("`@("`@("`@("`@)&-O;7!E;F1I=6T@/2`D;W!T:6]N6S%=.PH@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@)VXG.@H@("`@
M("`@("`@("!C87-E("<M+6YO+6-O;7!E;F1I=6TG.@H@("`@("`@("`@("`@
M("`@)&-O;7!E;F1I=6T@/2`G)SL*("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("!C87-E("=S)SH*("`@("`@("`@("`@8V%S92`G+2US=&%T
M:7-T:6-S)SH*("`@("`@("`@("`@("`@("1S879E7W-T871S(#T@=')U93L*
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@('T*("`@("1H
M;W)D92`](&%R<F%Y7W-E87)C:"@G:&]R9&4G+"`D9&ER<RD["B`@("`D:&]R
M9&5?;7-G(#T@87)R87DH*3L*("`@("1S=&%T<U]A<G)A>2`](&%R<F%Y*"D[
M"@H@("`@<F5Q=6ER95]O;F-E("=#;VYS;VQE+U1A8FQE+G!H<"<["B`@("`D
M<W1A=',@/2!N97<@0V]N<V]L95]486)L92@I.PH@("`@)'-T871S+3YS971(
M96%D97)S*&%R<F%Y*"=-;V1U;&4G+"`G3&%N9W5A9V4G+"`G5')A;G-L871E
M9"<L("=&=7IZ>2<L("=5;G1R86YS;&%T960G*2D["@H@("`@9F]R("@D:2`]
M(#`[("1I(#P@8V]U;G0H)&1I<G,I.R`D:2LK*2!["B`@("`@("`@:68@*"%E
M;7!T>2@D;6]D=6QE*2`F)B`D;6]D=6QE("$]("1A<'!S6R1I72D@8V]N=&EN
M=64["B`@("`@("`@)&,M/G=R:71E;&XH<W!R:6YT9B@G0G5I;&1I;F<@34\@
M9FEL97,@9F]R(&UO9'5L92`E<RXN+B<L("1C+3YB;VQD*"1A<'!S6R1I72DI
M*3L*("`@("`@("!I9B`H96UP='DH)&QA;F<I*2!["B`@("`@("`@("`@("1L
M86YG<R`](&=E=%]L86YG=6%G97,H)&1I<G-;)&E=*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!I9B`H(4!F:6QE7V5X:7-T<R@D9&ER<ULD:5T@
M+B!$4R`N("=P;R<@+B!$4R`N("1L86YG("X@)RYP;R<I*2!["B`@("`@("`@
M("`@("`@("`D8RT^=W)I=&5L;B@G4VMI<'!E9"XN+B<I.PH@("`@("`@("`@
M("`@("`@)&,M/G=R:71E;&XH*3L*("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1L86YG<R`](&%R<F%Y*"1L
M86YG*3L*("`@("`@("!]"B`@("`@("`@9F]R96%C:"`H)&QA;F=S(&%S("1L
M;V-A;&4I('L*("`@("`@("`@("`@)&,M/G=R:71E;&XH<W!R:6YT9B@G0G5I
M;&1I;F<@;&]C86QE("5S+BXN("<L("1C+3YB;VQD*"1L;V-A;&4I*2D["B`@
M("`@("`@("`@("1D:7(@/2`D9&ER<ULD:5T@+B!$4R`N("=L;V-A;&4G("X@
M1%,@+B`D;&]C86QE("X@1%,@+B`G3$-?34534T%'15,G.PH@("`@("`@("`@
M("!I9B`H(6ES7V1I<B@D9&ER*2D@>PH@("`@("`@("`@("`@("`@<F5Q=6ER
M95]O;F-E("=3>7-T96TN<&AP)SL*("`@("`@("`@("`@("`@(&EF("@D9&5B
M=6<I('L*("`@("`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;BAS<')I;G1F
M*"=-86MI;F<@9&ER96-T;W)Y("5S)RP@)&1I<BDI.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@:68@*"$D=&5S="`F)B`A0%-Y<W1E;3HZ
M;6MD:7(H(BUP("1D:7(B*2D@>PH@("`@("`@("`@("`@("`@("`@("1C+3YW
M<FET96QN*"1C+3YR960H)U=A<FYI;F<Z("<I("X@<W!R:6YT9B@G0V]U;&0@
M;F]T(&-R96%T92!L;V-A;&4@9&ER96-T;W)Y(&9O<B!L;V-A;&4@)7,Z)RP@
M)&QO8V%L92DI.PH@("`@("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"1D
M:7(I.PH@("`@("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"D["B`@("`@
M("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("\J($-O;G9E<G0@=&\@=6YI>"!L
M:6YE8G)E86MS+B`J+PH@("`@("`@("`@("`D<&]F:6QE(#T@)&1I<G-;)&E=
M("X@1%,@+B`G<&\G("X@1%,@+B`D;&]C86QE("X@)RYP;R<["B`@("`@("`@
M("`@("1C;VYT96YT(#T@9FEL95]G971?8V]N=&5N=',H)'!O9FEL92D["@H@
M("`@("`@("`@("`D8V]N=&5N="`]('-T<E]R97!L86-E*")<<B(L("<G+"`D
M8V]N=&5N="D["B`@("`@("`@("`@("1F<"`](&9O<&5N*"1P;V9I;&4L("=W
M8B<I.PH@("`@("`@("`@("!F=W)I=&4H)&9P+"`D8V]N=&5N="D["B`@("`@
M("`@("`@(&9C;&]S92@D9G`I.PH*("`@("`@("`@("`@+RH@0VAE8VL@4$\@
M9FEL92!S86YI='DN("HO"B`@("`@("`@("`@("1S:"`]("1'3$]"04Q36R=M
M<V=F;70G72`N("(@+2UC:&5C:R!<(B1P;V9I;&5<(B1R961I<E]E<G(B.PH@
M("`@("`@("`@("!I9B`H)&1E8G5G('Q\("1T97-T*2!["B`@("`@("`@("`@
M("`@("`D8RT^=W)I=&5L;B@G17AE8W5T:6YG.B<I.PH@("`@("`@("`@("`@
M("`@)&,M/G=R:71E;&XH)'-H*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H)'1E<W0I('L*("`@("`@("`@("`@("`@("1R970@/2`P.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@97AE8R@D<V@L("1O
M=70L("1R970I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D<F5T
M("$](#`I('L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"1C+3YR960H
M)U=A<FYI;F<Z("<I("X@)V%N(&5R<F]R(&AA<R!O8V-U<F5D.B<I.PH@("`@
M("`@("`@("`@("`@)&,M/G=R:71E;&XH:6UP;&]D92@B7&XB+"`D;W5T*2D[
M"B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@("`@("`@
M("`@:68@*"1A<'!S6R1I72`]/2`G:&]R9&4G*2!["B`@("`@("`@("`@("`@
M("`@("`@8V]N=&EN=64@,CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O
M*B!#;VUP:6QE($U/(&9I;&4N("HO"B`@("`@("`@("`@("1S:"`]("1'3$]"
M04Q36R=M<V=F;70G72`N("<@+2US=&%T:7-T:6-S("UO("(G("X@)&1I<B`N
M($13("X@)&%P<'-;)&E=("X@)RYM;R(@)SL*("`@("`@("`@("`@:68@*"1A
M<'!S6R1I72`A/2`G:&]R9&4G*2!["B`@("`@("`@("`@("`@("`D:&]R9&5?
M<&\@/2`D9&ER<ULD:&]R9&5=("X@1%,@+B`G<&\G("X@1%,@+B`D;&]C86QE
M("X@)RYP;R<["B`@("`@("`@("`@("`@("!I9B`H(4!I<U]R96%D86)L92@D
M:&]R9&5?<&\I*2!["B`@("`@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH
M)&,M/G)E9"@G5V%R;FEN9SH@)RD@+B!S<')I;G1F*"=T:&4@2&]R9&4@4$\@
M9FEL92!F;W(@=&AE(&QO8V%L92`E<R!D;V5S(&YO="!E>&ES=#HG+"`D;&]C
M86QE*2D["B`@("`@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)&AO<F1E
M7W!O*3L*("`@("`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@
M("`@("`@("`@("`@("`@("1S:"`N/2`D9&ER<ULD:5T@+B!$4R`N("=P;R<@
M+B!$4R`N("1L;V-A;&4@+B`G+G!O)SL*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@)'-H(#T@)$=,3T)!3%-;)VUS9V-O
M;6TG72`N("(@+2UM;W)E+71H86X],"`M+7-O<G0M;W5T<'5T(%PB)'!O9FEL
M95PB(%PB)&AO<F1E7W!O7"(@?"`D<V@@+2(["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<V@@+CT@
M)'!O9FEL93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<V@@+CT@)')E
M9&ER7V5R<CL*("`@("`@("`@("`@:68@*"1D96)U9R!\?"`D=&5S="D@>PH@
M("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)T5X96-U=&EN9SHG*3L*("`@
M("`@("`@("`@("`@("1C+3YW<FET96QN*"1S:"D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)&]U="`]("<G.PH@("`@("`@("`@("!I9B`H)'1E<W0I
M('L*("`@("`@("`@("`@("`@("1R970@/2`P.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@<'5T96YV*"=,04Y'/65N)RD["B`@("`@
M("`@("`@("`@("!E>&5C*"1S:"P@)&]U="P@)')E="D["B`@("`@("`@("`@
M("`@("!P=71E;G8H)TQ!3D<])R`N("1'3$]"04Q36R=L86YG=6%G92==*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)')E="`]/2`P*2!["B`@
M("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@D8RT^9W)E96XH)V1O;F4G*2D[
M"B`@("`@("`@("`@("`@("`D;65S<V%G97,@/2!A<G)A>2@P+"`P+"`P*3L*
M("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O*%QD*RD@=')A;G-L
M871E9"\G+"`D;W5T6S!=+"`D;6%T8V@I*2!["B`@("`@("`@("`@("`@("`@
M("`@)&UE<W-A9V5S6S!=(#T@)&UA=&-H6S%=.PH@("`@("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D:&]R9&5?;7-G6R1L;V-A;&5=*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D;65S<V%G97-;,%T@+3T@)&AO<F1E7VUS9ULD
M;&]C86QE75LP73L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1M97-S
M86=E<ULP72`\(#`I("1M97-S86=E<ULP72`](#`["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@
M*'!R96=?;6%T8V@H)R\H7&0K*2!F=7IZ>2\G+"`D;W5T6S!=+"`D;6%T8V@I
M*2!["B`@("`@("`@("`@("`@("`@("`@)&UE<W-A9V5S6S%=(#T@)&UA=&-H
M6S%=.PH@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D:&]R9&5?;7-G
M6R1L;V-A;&5=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;65S<V%G
M97-;,5T@+3T@)&AO<F1E7VUS9ULD;&]C86QE75LQ73L*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"1M97-S86=E<ULQ72`\(#`I("1M97-S86=E<ULQ
M72`](#`["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R\H7&0K*2!U;G1R
M86YS;&%T960O)RP@)&]U=%LP72P@)&UA=&-H*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1M97-S86=E<ULR72`]("1M871C:%LQ73L*("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&AO<F1E7VUS9ULD;&]C86QE72DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&UE<W-A9V5S6S)=("T]("1H;W)D95]M
M<V=;)&QO8V%L95U;,ET["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D
M;65S<V%G97-;,ET@/"`P*2`D;65S<V%G97-;,ET@/2`P.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&EF("@D87!P<ULD:5T@/3T@)VAO<F1E)RD@>PH@("`@("`@("`@("`@("`@
M("`@("1H;W)D95]M<V=;)&QO8V%L95T@/2`D;65S<V%G97,["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`D<W1A='-?87)R87E;)&%P<'-;
M)&E=75LD;&]C86QE72`]("1M97-S86=E<SL*("`@("`@("`@("`@("`@("1S
M=&%T<RT^861D4F]W*&%R<F%Y*"1A<'!S6R1I72P@)&QO8V%L92P@)&UE<W-A
M9V5S6S!=+"`D;65S<V%G97-;,5TL("1M97-S86=E<ULR72DI.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)&,M
M/G)E9"@G9F%I;&5D)RDI.PH@("`@("`@("`@("`@("`@97AE8R@D<V@L("1O
M=70L("1R970I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH:6UP;&]D
M92@B7&XB+"`D;W5T*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@
M*&-O=6YT*"1L86YG<RD@/B`Q*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU
M93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@365R9V4@=')A;G-L
M871I;VX@:6YT;R!C;VUP96YD:75M+B`J+PH@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1C;VUP96YD:75M*2D@>PH@("`@("`@("`@("`@("`@<')I;G1F*"=-
M97)G:6YG('1H92!03R!F:6QE(&9O<B`E<R!T;R!T:&4@8V]M<&5N9&EU;2XN
M+B`G+"`D8RT^8F]L9"@D87!P<ULD:5TI*3L*("`@("`@("`@("`@("`@(&EF
M("@A96UP='DH)&1I<BD@)B8@<W5B<W1R*"1D:7(L("TQ*2`A/2!$4RD@>PH@
M("`@("`@("`@("`@("`@("`@("1D:7(@+CT@1%,["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`D<V@@/2`D1TQ/0D%,4ULG;7-G8V%T)UT@
M+B`B("TM<V]R="UO=71P=70@7"(D8V]M<&5N9&EU;5PB(%PB)'!O9FEL95PB
M(#X@7"(D8V]M<&5N9&EU;2YT;7!<(B(["B`@("`@("`@("`@("`@("!I9B`H
M(21D96)U9RD@>PH@("`@("`@("`@("`@("`@("`@("1S:"`N/2`D<VEL96YC
M93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@D9&5B
M=6<@?'P@)'1E<W0I('L*("`@("`@("`@("`@("`@("`@("`D8RT^=W)I=&5L
M;B@I.PH@("`@("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"=%>&5C=71I
M;F<Z)RD["B`@("`@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)'-H*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1O=70@/2`G)SL*
M("`@("`@("`@("`@("`@(&EF("@D=&5S="D@>PH@("`@("`@("`@("`@("`@
M("`@("1R970@/2`P.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("!E>&5C*"1S:"P@)&]U="P@)')E="D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!`=6YL:6YK*"1C;VUP96YD:75M
M*3L*("`@("`@("`@("`@("`@(')E;F%M92@D8V]M<&5N9&EU;2`N("<N=&UP
M)RP@)&-O;7!E;F1I=6TI.PH@("`@("`@("`@("`@("`@:68@*"1R970@/3T@
M,"D@>PH@("`@("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"1C+3YG<F5E
M;B@G9&]N92<I*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@)&,M/G=R:71E;&XH)&,M/G)E9"@G9F%I;&5D)RDI.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1C
M+3YW<FET96QN*"D["B`@("`@("`@?0H@("`@?0H@("`@:68@*&5M<'1Y*"1M
M;V1U;&4I*2!["B`@("`@("`@)&,M/G=R:71E;&XH)U)E<W5L=',Z)RD["B`@
M("!](&5L<V4@>PH@("`@("`@("1C+3YW<FET96QN*"=297-U;'1S("AI;F-L
M=61I;F<@2&]R9&4I.B<I.PH@("`@?0H@("`@)&,M/G=R:71E;&XH)'-T871S
M+3YG971486)L92@I*3L*("`@(&EF("@D<V%V95]S=&%T<RD@>PH@("`@("`@
M("1F<"`]($!F;W!E;B@G=')A;G-L871I;VY?<W1A=',N='AT)RP@)W<G*3L*
M("`@("`@("!I9B`H)&9P*2!["B`@("`@("`@("`@(&9W<FET92@D9G`L('-E
M<FEA;&EZ92@D<W1A='-?87)R87DI*3L*("`@("`@("`@("`@9F-L;W-E*"1F
M<"D["B`@("`@("`@?0H@("`@?0I]"@IF=6YC=&EO;B!C;&5A;G5P*"1K965P
M7W5N=')A;G-L871E9"`](&9A;'-E*0I["B`@("!G;&]B86P@)&-M9%]O<'1I
M;VYS+"`D87!P<RP@)&1I<G,L("1D96)U9RP@)'1E<W0L("1C.PH*("`@(&9O
M<F5A8V@@*"1C;61?;W!T:6]N<ULP72!A<R`D;W!T:6]N*2!["B`@("`@("`@
M<W=I=&-H("@D;W!T:6]N6S!=*2!["B`@("`@("`@("`@(&-A<V4@)V@G.@H@
M("`@("`@("`@("`@("`@=7-A9V4H*3L*("`@("`@("`@("`@("`@(&9O;W1E
M<B@I.PH@("`@("`@("`@("!C87-E("=L)SH*("`@("`@("`@("`@8V%S92`G
M+2UL;V-A;&4G.@H@("`@("`@("`@("`@("`@)&QA;F<@/2`D;W!T:6]N6S%=
M.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@)VTG
M.@H@("`@("`@("`@("!C87-E("<M+6UO9'5L92<Z"B`@("`@("`@("`@("`@
M("`D;6]D=6QE(#T@)&]P=&EO;ELQ73L*("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@('T*("`@('T*"B`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N
M="@D9&ER<RD[("1I*RLI('L*("`@("`@("!I9B`H(65M<'1Y*"1M;V1U;&4I
M("8F("1M;V1U;&4@(3T@)&%P<'-;)&E=*2![(&-O;G1I;G5E.R!]"B`@("`@
M("`@)&,M/G=R:71E;&XH<W!R:6YT9B@G0VQE86YI;F<@=7`@4$\@9FEL97,@
M9F]R(&UO9'5L92`E<RXN+B<L("1C+3YB;VQD*"1A<'!S6R1I72DI*3L*("`@
M("`@("!I9B`H96UP='DH)&QA;F<I*2!["B`@("`@("`@("`@("1L86YG<R`]
M(&=E=%]L86YG=6%G97,H)&1I<G-;)&E=*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!I9B`H(4!F:6QE7V5X:7-T<R@D9&ER<ULD:5T@+B!$4R`N
M("=P;R<@+B!$4R`N("1L86YG("X@)RYP;R<I*2!["B`@("`@("`@("`@("`@
M("`D8RT^=W)I=&5L;B@G4VMI<'!E9"XN+B<I.PH@("`@("`@("`@("`@("`@
M)&,M/G=R:71E;&XH*3L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1L86YG<R`](&%R<F%Y*"1L86YG*3L*
M("`@("`@("!]"B`@("`@("`@9F]R96%C:"`H)&QA;F=S(&%S("1L;V-A;&4I
M('L*("`@("`@("`@("`@)&,M/G=R:71E;&XH<W!R:6YT9B@G0VQE86YI;F<@
M=7`@;&]C86QE("5S+BXN("<L("1C+3YB;VQD*"1L;V-A;&4I*2D["B`@("`@
M("`@("`@("1P;V9I;&4@/2`D9&ER<ULD:5T@+B!$4R`N("=P;R<@+B!$4R`N
M("1L;V-A;&4@+B`G+G!O)SL*("`@("`@("`@("`@)'-H(#T@)$=,3T)!3%-;
M)VUS9V%T=')I8B==("X@*"1K965P7W5N=')A;G-L871E9"`_("<G(#H@)R`M
M+71R86YS;&%T960G*2`N("(@+2UN;RUO8G-O;&5T92`M+69O<F-E+7!O("1P
M;V9I;&4@/B`D<&]F:6QE+G1M<"(["B`@("`@("`@("`@(&EF("@A)&1E8G5G
M*2!["B`@("`@("`@("`@("`@("`D<V@@+CT@)'-I;&5N8V4["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@:68@*"1D96)U9R!\?"`D=&5S="D@>PH@("`@
M("`@("`@("`@("`@)&,M/G=R:71E;&XH*3L*("`@("`@("`@("`@("`@("1C
M+3YW<FET96QN*"=%>&5C=71I;F<Z)RD["B`@("`@("`@("`@("`@("`D8RT^
M=W)I=&5L;B@D<V@I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1O=70@
M/2`G)SL*("`@("`@("`@("`@:68@*"1T97-T*2!["B`@("`@("`@("`@("`@
M("`D<F5T(#T@,#L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@(&5X96,H)'-H+"`D;W5T+"`D<F5T*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!I9B`H)')E="`]/2`P*2!["B`@("`@("`@("`@("`@("!`=6YL
M:6YK*"1P;V9I;&4I.PH@("`@("`@("`@("`@("`@<F5N86UE*"1P;V9I;&4@
M+B`G+G1M<"<L("1P;V9I;&4I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E
M;&XH)&,M/F=R965N*"=D;VYE)RDI.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@0'5N;&EN:R@D<&]F:6QE("X@)RYT;7`G+"`D<&]F
M:6QE*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"1C+3YR960H)V9A
M:6QE9"<I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D8RT^=W)I=&5L
M;B@I.PH@("`@("`@('T*("`@('T*?0H*9G5N8W1I;VX@8V]M;6ET*"1H96QP
M7V]N;'D@/2!F86QS92D*>PH@("`@9VQO8F%L("1C;61?;W!T:6]N<RP@)&%P
M<',L("1D:7)S+"`D9&5B=6<L("1T97-T+"`D8SL*"B`@("`D9&]C<R`](&9A
M;'-E.PH@("`@9F]R96%C:"`H)&-M9%]O<'1I;VYS6S!=(&%S("1O<'1I;VXI
M('L*("`@("`@("!S=VET8V@@*"1O<'1I;VY;,%TI('L*("`@("`@("`@("`@
M8V%S92`G:"<Z"B`@("`@("`@("`@("`@("!U<V%G92@I.PH@("`@("`@("`@
M("`@("`@9F]O=&5R*"D["B`@("`@("`@("`@(&-A<V4@)VPG.@H@("`@("`@
M("`@("!C87-E("<M+6QO8V%L92<Z"B`@("`@("`@("`@("`@("`D;&%N9R`]
M("1O<'1I;VY;,5T["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@8V%S92`G;2<Z"B`@("`@("`@("`@(&-A<V4@)RTM;6]D=6QE)SH*("`@
M("`@("`@("`@("`@("1M;V1U;&4@/2`D;W!T:6]N6S%=.PH@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@)VXG.@H@("`@("`@("`@
M("!C87-E("<M+6YE=R<Z"B`@("`@("`@("`@("`@("`D9&]C<R`]('1R=64[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G32<Z
M"B`@("`@("`@("`@(&-A<V4@)RTM;65S<V%G92<Z"B`@("`@("`@("`@("`@
M("`D;7-G(#T@)&]P=&EO;ELQ73L*("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@('T*("`@('T*("`@("1F:6QE<R`](&%R<F%Y*"D["B`@("!F;W(@
M*"1I(#T@,#L@)&D@/"!C;W5N="@D9&ER<RD[("1I*RLI('L*("`@("`@("!I
M9B`H(65M<'1Y*"1M;V1U;&4I("8F("1M;V1U;&4@(3T@)&%P<'-;)&E=*2!C
M;VYT:6YU93L*("`@("`@("!I9B`H)&%P<'-;)&E=(#T]("=H;W)D92<I('L*
M("`@("`@("`@("`@)&1I<G-;72`]("1D:7)S6R1I72`N($13("X@)V%D;6EN
M)SL*("`@("`@("`@("`@)&%P<'-;72`]("=H;W)D92]A9&UI;B<["B`@("`@
M("`@("`@(&EF("@A96UP='DH)&UO9'5L92DI('L*("`@("`@("`@("`@("`@
M("1M;V1U;&4@/2`G:&]R9&4O861M:6XG.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@("`@(&EF("AE;7!T>2@D;&%N9RDI('L*("`@("`@("`@("`@
M:68@*"1H96QP7V]N;'DI('L*("`@("`@("`@("`@("`@("1F:6QE<R`](&%R
M<F%Y7VUE<F=E*"1F:6QE<RP@<W1R:7!?:&]R9&4H<V5A<F-H7V5X="@G>&UL
M)RP@)&1I<G-;)&E=("X@1%,@+B`G;&]C86QE)RDI*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1F:6QE<R`](&%R<F%Y7VUE<F=E
M*"1F:6QE<RP@<W1R:7!?:&]R9&4H9V5T7W!O7V9I;&5S*"1D:7)S6R1I72`N
M($13("X@)W!O)RDI*3L*("`@("`@("`@("`@("`@("1F:6QE<R`](&%R<F%Y
M7VUE<F=E*"1F:6QE<RP@<W1R:7!?:&]R9&4H<V5A<F-H7V9I;&4H)UY;82UZ
M77LR?5];02U:77LR?2<L("1D:7)S6R1I72`N($13("X@)VQO8V%L92<L('1R
M=64I*2D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!I9B`H)&AE;'!?;VYL>2D@>PH@("`@("`@("`@("`@("`@:68@*"%`
M9FEL95]E>&ES=',H)&1I<G-;)&E=("X@1%,@+B`G;&]C86QE)R`N($13("X@
M)&QA;F<@+B!$4R`N("=H96QP+GAM;"<I*2!C;VYT:6YU93L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&EF("@A0&9I;&5?97AI<W1S
M*"1D:7)S6R1I72`N("<O<&\O)R`N("1L86YG("X@)RYP;R<I*2!C;VYT:6YU
M93L*("`@("`@("`@("`@("`@("1F:6QE<UM=(#T@<W1R:7!?:&]R9&4H)&1I
M<G-;)&E=("X@1%,@+B`G<&\G("X@1%,@+B`D;&%N9R`N("<N<&\G*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D9FEL97-;72`]('-T<FEP7VAO<F1E
M*"1D:7)S6R1I72`N($13("X@)VQO8V%L92<@+B!$4R`N("1L86YG*3L*("`@
M("`@("!]"B`@("`@("`@:68@*"1D;V-S("8F("$D:&5L<%]O;FQY("8F("1A
M<'!S6R1I72D@>PH@("`@("`@("`@("`D9FEL97-;72`]('-T<FEP7VAO<F1E
M*"1D:7)S6R1I72`N($13("X@)V1O8W,G*3L*("`@("`@("`@("`@:68@*"1A
M<'!S6R1I72`]/2`G:&]R9&4G*2!["B`@("`@("`@("`@("`@("`D:&]R9&5?
M8V]N9B`]("1D:7)S6V%R<F%Y7W-E87)C:"@G:&]R9&4G+"`D9&ER<RE=("X@
M1%,@+B`G8V]N9FEG)R`N($13.PH@("`@("`@("`@("`@("`@)&9I;&5S6UT@
M/2!S=')I<%]H;W)D92@D:&]R9&5?8V]N9B`N("=N;',N<&AP+F1I<W0G*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*("`@(&-H9&ER*$)!4T4I
M.PH@("`@:68@*&-O=6YT*"1F:6QE<RDI('L*("`@("`@("!I9B`H)&1O8W,I
M('L*("`@("`@("`@("`@)&,M/G=R:71E;&XH)T%D9&EN9R!N97<@9FEL97,@
M=&\@<F5P;W-I=&]R>3HG*3L*("`@("`@("`@("`@)'-H(#T@)V-V<R!A9&0G
M.PH@("`@("`@("`@("!F;W)E86-H("@D9FEL97,@87,@)&9I;&4I('L*("`@
M("`@("`@("`@("`@(&EF("AS=')S='(H)&9I;&4L("=L;V-A;&4G*2!\?"!S
M=')S='(H)&9I;&4L("<N<&\G*2D@>PH@("`@("`@("`@("`@("`@("`@("1S
M:"`N/2`B("1F:6QE(CL*("`@("`@("`@("`@("`@("`@("`D8RT^=W)I=&5L
M;B@D9FEL92D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)'-H("X]("<[(&-V<R!A9&0G.PH@("`@("`@("`@("!F;W)E
M86-H("@D9FEL97,@87,@)&9I;&4I('L*("`@("`@("`@("`@("`@(&EF("AS
M=')S='(H)&9I;&4L("=L;V-A;&4G*2D@>PH@("`@("`@("`@("`@("`@("`@
M(&EF("@D:&5L<%]O;FQY*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1S
M:"`N/2`G("<@+B`D9FEL92`N($13("X@)RHN>&UL)SL*("`@("`@("`@("`@
M("`@("`@("`@("`@)&,M/G=R:71E;&XH)&9I;&4@+B!$4R`N("<J+GAM;"<I
M.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1S:"`N/2`G("<@+B`D9FEL92`N($13("X@)RHN>&UL("<@
M+B`D9FEL92`N($13("X@)TQ#7TU%4U-!1T53)SL*("`@("`@("`@("`@("`@
M("`@("`@("`@)&,M/G=R:71E;&XH)&9I;&4@+B!$4R`N("(J+GAM;%QN)&9I
M;&4B("X@1%,@+B`G3$-?34534T%'15,G*3L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*"$D:&5L<%]O;FQY*2!["B`@("`@("`@("`@("`@("`D<V@@+CT@
M)SL@8W9S(&%D9"<["B`@("`@("`@("`@("`@("!F;W)E86-H("@D9FEL97,@
M87,@)&9I;&4I('L*("`@("`@("`@("`@("`@("`@("!I9B`H<W1R<W1R*"1F
M:6QE+"`G;&]C86QE)RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&%D
M9"`]("1F:6QE("X@1%,@+B`G3$-?34534T%'15,G("X@1%,@+B`G*BYM;R<[
M"B`@("`@("`@("`@("`@("`@("`@("`@("1S:"`N/2`G("<@+B`D861D.PH@
M("`@("`@("`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@D861D*3L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)&,M/G=R:71E;&XH*3L*("`@("`@("`@("`@
M:68@*"1D96)U9R!\?"`D=&5S="D@>PH@("`@("`@("`@("`@("`@)&,M/G=R
M:71E;&XH)T5X96-U=&EN9SHG*3L*("`@("`@("`@("`@("`@("1C+3YW<FET
M96QN*"1S:"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"$D=&5S
M="D@<WES=&5M*"1S:"D["B`@("`@("`@("`@("1C+3YW<FET96QN*"D["B`@
M("`@("`@?0H@("`@("`@("1C+3YW<FET96QN*"=#;VUM:71T:6YG.B<I.PH@
M("`@("`@("1C+3YW<FET96QN*&EM<&QO9&4H)R`G+"`D9FEL97,I*3L*("`@
M("`@("!I9B`H(65M<'1Y*"1L86YG*2D@>PH@("`@("`@("`@("`D;&%N9R`]
M("<@)R`N("1L86YG.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&US
M9RDI('L*("`@("`@("`@("`@:68@*"1D;V-S*2!["B`@("`@("`@("`@("`@
M("`D;7-G(#T@(D%D9"1L86YG('1R86YS;&%T:6]N+B(["B`@("`@("`@("`@
M('T@96QS96EF("@D:&5L<%]O;FQY*2!["B`@("`@("`@("`@("`@("`D;7-G
M(#T@(E5P9&%T921L86YG(&AE;'`@9FEL92XB.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)&US9R`](")5<&1A=&4D;&%N9R!T<F%N
M<VQA=&EO;BXB.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1S
M:"`]("=C=G,@8V]M;6ET("UM("(G("X@)&US9R`N("<B("<@+B!I;7!L;V1E
M*"<@)RP@)&9I;&5S*3L*("`@("`@("!I9B`H)&1E8G5G('Q\("1T97-T*2![
M"B`@("`@("`@("`@("1C+3YW<FET96QN*"=%>&5C=71I;F<Z)RD["B`@("`@
M("`@("`@("1C+3YW<FET96QN*"1S:"D["B`@("`@("`@?0H@("`@("`@(&EF
M("@A)'1E<W0I('-Y<W1E;2@D<V@I.PH@("`@?0I]"@IF=6YC=&EO;B!U<&1A
M=&5?:&5L<"@I"GL*("`@(&=L;V)A;"`D8VUD7V]P=&EO;G,L("1D:7)S+"`D
M87!P<RP@)&1E8G5G+"`D=&5S="P@)&QA<W1?97)R;W)?;7-G+"`D8SL*"B`@
M("!F;W)E86-H("@D8VUD7V]P=&EO;G-;,%T@87,@)&]P=&EO;BD@>PH@("`@
M("`@('-W:71C:"`H)&]P=&EO;ELP72D@>PH@("`@("`@("`@("!C87-E("=H
M)SH*("`@("`@("`@("`@("`@('5S86=E*"D["B`@("`@("`@("`@("`@("!F
M;V]T97(H*3L*("`@("`@("`@("`@8V%S92`G;"<Z"B`@("`@("`@("`@(&-A
M<V4@)RTM;&]C86QE)SH*("`@("`@("`@("`@("`@("1L86YG(#T@)&]P=&EO
M;ELQ73L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E
M("=M)SH*("`@("`@("`@("`@8V%S92`G+2UM;V1U;&4G.@H@("`@("`@("`@
M("`@("`@)&UO9'5L92`]("1O<'1I;VY;,5T["B`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("!]"B`@("!]"B`@("`D9FEL97,@/2!A<G)A>2@I.PH@
M("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)&1I<G,I.R`D:2LK*2!["B`@
M("`@("`@:68@*"%E;7!T>2@D;6]D=6QE*2`F)B`D;6]D=6QE("$]("1A<'!S
M6R1I72D@>R!C;VYT:6YU93L@?0H@("`@("`@(&EF("@A:7-?9&ER*"(D9&ER
M<ULD:5TO;&]C86QE(BDI(&-O;G1I;G5E.PH@("`@("`@(&EF("@D87!P<ULD
M:5T@/3T@)VAO<F1E)RD@>PH@("`@("`@("`@("`D9&ER<UM=(#T@)&1I<G-;
M)&E=("X@1%,@+B`G861M:6XG.PH@("`@("`@("`@("`D87!P<UM=(#T@)VAO
M<F1E+V%D;6EN)SL*("`@("`@("`@("`@:68@*"%E;7!T>2@D;6]D=6QE*2D@
M>PH@("`@("`@("`@("`@("`@)&UO9'5L92`]("=H;W)D92]A9&UI;B<["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1L86YG
M*2D@>PH@("`@("`@("`@("`D9FEL97,@/2!S96%R8VA?9FEL92@G:&5L<"YX
M;6PG+"`D9&ER<ULD:5T@+B!$4R`N("=L;V-A;&4G*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D9FEL97,@/2!A<G)A>2@D9&ER<ULD:5T@+B!$
M4R`N("=L;V-A;&4G("X@1%,@+B`D;&%N9R`N($13("X@)VAE;'`N>&UL)RD[
M"B`@("`@("`@?0H@("`@("`@("1F:6QE7V5N("`]("1D:7)S6R1I72`N($13
M("X@)VQO8V%L92<@+B!$4R`N("=E;E]54R<@+B!$4R`N("=H96QP+GAM;"<[
M"B`@("`@("`@:68@*"%`9FEL95]E>&ES=',H)&9I;&5?96XI*2!["B`@("`@
M("`@("`@("1C+3YW<FET96QN*'=O<F1W<F%P*"1C+3YR960H)U=A<FYI;F<Z
M("<I("X@<W!R:6YT9B@G5&AE<F4@9&]E<VY<)W0@>65T(&5X:7-T(&$@:&5L
M<"!F:6QE(&9O<B`E<RXG+"`D8RT^8F]L9"@D87!P<ULD:5TI*2DI.PH@("`@
M("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@("`@("!C;VYT:6YU93L*
M("`@("`@("!]"B`@("`@("`@9F]R96%C:"`H)&9I;&5S(&%S("1F:6QE7VQO
M8RD@>PH@("`@("`@("`@("`D;&]C86QE(#T@<W5B<W1R*"1F:6QE7VQO8RP@
M,"P@<W1R<G!O<R@D9FEL95]L;V,L($13*2D["B`@("`@("`@("`@("1L;V-A
M;&4@/2!S=6)S='(H)&QO8V%L92P@<W1R<G!O<R@D;&]C86QE+"!$4RD@*R`Q
M*3L*("`@("`@("`@("`@:68@*"1L;V-A;&4@/3T@)V5N7U53)RD@8V]N=&EN
M=64["B`@("`@("`@("`@(&EF("@A0&9I;&5?97AI<W1S*"1F:6QE7VQO8RDI
M('L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*'=O<F1W<F%P*"1C+3YR
M960H)U=A<FYI;F<Z("<I("X@<W!R:6YT9B@G5&AE("5S(&AE;'`@9FEL92!F
M;W(@)7,@9&]E<VY<)W0@>65T(&5X:7-T+B!#<F5A=&EN9R!A(&YE=R!O;F4N
M)RP@)&,M/F)O;&0H)&QO8V%L92DL("1C+3YB;VQD*"1A<'!S6R1I72DI*2D[
M"B`@("`@("`@("`@("`@("`D9&ER7VQO8R`]('-U8G-T<B@D9FEL95]L;V,L
M(#`L("TY*3L*("`@("`@("`@("`@("`@(&EF("@A:7-?9&ER*"1D:7)?;&]C
M*2D@>PH@("`@("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G4WES=&5M
M+G!H<"<["B`@("`@("`@("`@("`@("`@("`@:68@*"1D96)U9R!\?"`D=&5S
M="D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;BAS<')I
M;G1F*"=-86MI;F<@9&ER96-T;W)Y("5S)RP@)&1I<E]L;V,I*3L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@:68@*"$D=&5S
M="`F)B`A0%-Y<W1E;3HZ;6MD:7(H(BUP("1D:7)?;&]C(BDI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)&,M/G)E9"@G5V%R;FEN
M9SH@)RD@+B!S<')I;G1F*"=#;W5L9"!N;W0@8W)E871E(&QO8V%L92!D:7)E
M8W1O<GD@9F]R(&QO8V%L92`E<SHG+"`D;&]C86QE*2D["B`@("`@("`@("`@
M("`@("`@("`@("`@("1C+3YW<FET96QN*"1D:7)?;&]C*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"1D96)U9R!\?"`D
M=&5S="D@>PH@("`@("`@("`@("`@("`@("`@("1C+3YW<FET96QN*'=O<F1W
M<F%P*'-P<FEN=&8H)T-O<'EI;F<@)7,@=&\@)7,G+"`D9FEL95]E;BP@)&9I
M;&5?;&]C*2DI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M:68@*"$D=&5S="`F)B`A0&-O<'DH)&9I;&5?96XL("1F:6QE7VQO8RDI('L*
M("`@("`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@D8RT^<F5D*"=787)N
M:6YG.B`G*2`N('-P<FEN=&8H)T-O=6QD(&YO="!C;W!Y("5S('1O("5S)RP@
M)&9I;&5?96XL("1F:6QE7VQO8RDI.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@)&,M/G=R:71E;&XH*3L*("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1C+3YW<FET96QN
M*'-P<FEN=&8H)U5P9&%T:6YG("5S(&AE;'`@9FEL92!F;W(@)7,N)RP@)&,M
M/F)O;&0H)&QO8V%L92DL("1C+3YB;VQD*"1A<'!S6R1I72DI*3L*("`@("`@
M("`@("`@)&9P(#T@9F]P96XH)&9I;&5?;&]C+"`G<B<I.PH@("`@("`@("`@
M("`D;&EN92`](&9G971S*"1F<"D["B`@("`@("`@("`@(&9C;&]S92@D9G`I
M.PH@("`@("`@("`@("!I9B`H(7-T<G-T<B@D;&EN92P@)SP_>&UL)RDI('L*
M("`@("`@("`@("`@("`@("1C+3YW<FET96QN*'=O<F1W<F%P*"1C+3YR960H
M)U=A<FYI;F<Z("<I("X@<W!R:6YT9B@G5&AE(&AE;'`@9FEL92`E<R!D:61N
M7"=T('-T87)T('=I=&@@/#]X;6PG+"`D9FEL95]L;V,I*2D["B`@("`@("`@
M("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@("`@("`@("`@8V]N=&EN
M=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&5N8V]D:6YG(#T@)R<[
M"B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O96YC;V1I;F<]*%LB7"==
M*2A;7EQ<,5TK*5Q<,2\G+"`D;&EN92P@)&UA=&-H*2D@>PH@("`@("`@("`@
M("`@("`@)&5N8V]D:6YG(#T@)&UA=&-H6S)=.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1D;V-?96X@/2!D;VUX;6Q?;W!E;E]F:6QE*"1F:6QE7V5N
M*3L*("`@("`@("`@("`@:68@*"%I<U]O8FIE8W0H)&1O8U]E;BDI('L*("`@
M("`@("`@("`@("`@("1C+3YW<FET96QN*'=O<F1W<F%P*"1C+3YR960H)U=A
M<FYI;F<Z("<I("X@<W!R:6YT9B@G5&AE<F4@=V%S(&%N(&5R<F]R(&]P96YI
M;F<@=&AE(&9I;&4@)7,N(%1R>2!R=6YN:6YG('1R86YS;&%T:6]N+G!H<"!W
M:71H('1H92!F;&%G("UD('1O('-E92!A;GD@97)R;W(@;65S<V%G97,@9G)O
M;2!T:&4@>&UL('!A<G-E<BXG+"`D9FEL95]E;BDI*3L*("`@("`@("`@("`@
M("`@("1C+3YW<FET96QN*"D["B`@("`@("`@("`@("`@("!C;VYT:6YU92`R
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1D;V-?;&]C(#T@9&]M>&UL
M7V]P96Y?9FEL92@D9FEL95]L;V,I.PH@("`@("`@("`@("!I9B`H(6ES7V]B
M:F5C="@D9&]C7VQO8RDI('L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN
M*'=O<F1W<F%P*"1C+3YR960H)U=A<FYI;F<Z("<I("X@<W!R:6YT9B@G5&AE
M<F4@=V%S(&%N(&5R<F]R(&]P96YI;F<@=&AE(&9I;&4@)7,N(%1R>2!R=6YN
M:6YG('1R86YS;&%T:6]N+G!H<"!W:71H('1H92!F;&%G("UD('1O('-E92!A
M;GD@97)R;W(@;65S<V%G97,@9G)O;2!T:&4@>&UL('!A<G-E<BXG+"`D9FEL
M95]L;V,I*2D["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@
M("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)&1O8U]N97<@(#T@9&]M>&UL7VYE=U]D;V,H)S$N,"<I.PH@("`@("`@
M("`@("`D:&5L<%]E;B`@/2`D9&]C7V5N+3YD;V-U;65N=%]E;&5M96YT*"D[
M"B`@("`@("`@("`@("1H96QP7VQO8R`]("1D;V-?;&]C+3YD;V-U;65N=%]E
M;&5M96YT*"D["B`@("`@("`@("`@("1H96QP7VYE=R`]("1H96QP7VQO8RT^
M8VQO;F5?;F]D92@I.PH@("`@("`@("`@("`D96YT<FEE<U]L;V,@/2!A<G)A
M>2@I.PH@("`@("`@("`@("`D96YT<FEE<U]N97<@/2!A<G)A>2@I.PH@("`@
M("`@("`@("`D8V]U;G1?=7!T;V1A=&4@/2`P.PH@("`@("`@("`@("`D8V]U
M;G1?;F5W("`@("`@/2`P.PH@("`@("`@("`@("`D8V]U;G1?8VAA;F=E9"`@
M/2`P.PH@("`@("`@("`@("`D8V]U;G1?=6YK;F]W;B`@/2`P.PH@("`@("`@
M("`@("!F;W)E86-H("@D9&]C7VQO8RT^9V5T7V5L96UE;G1S7V)Y7W1A9VYA
M;64H)V5N=')Y)RD@87,@)&5N=')Y*2!["B`@("`@("`@("`@("`@("`D96YT
M<FEE<U]L;V-;)&5N=')Y+3YG971?871T<FEB=71E*"=I9"<I72`]("1E;G1R
M>3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!F;W)E86-H("@D9&]C7V5N
M+3YG971?96QE;65N='-?8GE?=&%G;F%M92@G96YT<GDG*2!A<R`D96YT<GDI
M('L*("`@("`@("`@("`@("`@("1I9"`]("1E;G1R>2T^9V5T7V%T=')I8G5T
M92@G:60G*3L*("`@("`@("`@("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S
M*"1I9"P@)&5N=')I97-?;&]C*2D@>PH@("`@("`@("`@("`@("`@("`@(&EF
M("@D96YT<FEE<U]L;V-;)&ED72T^:&%S7V%T=')I8G5T92@G;60U)RD@)B8*
M("`@("`@("`@("`@("`@("`@("`@("`@;60U*"1E;G1R>2T^9V5T7V-O;G1E
M;G0H*2D@(3T@)&5N=')I97-?;&]C6R1I9%TM/F=E=%]A='1R:6)U=&4H)VUD
M-2<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1C;VUM96YT(#T@)&1O
M8U]L;V,M/F-R96%T95]C;VUM96YT*"(@16YG;&ES:"!E;G1R>3I<;B(@+B!S
M=')?<F5P;&%C92@G+2TG+"`G)B,T-3LF(S0U.R<L("1D;V-?;&]C+3YD=6UP
M7VYO9&4H)&5N=')Y*2DI.PH@("`@("`@("`@("`@("`@("`@("`@("`D96YT
M<FEE<U]L;V-;)&ED72T^87!P96YD7V-H:6QD*"1C;VUM96YT*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&5N=')Y7VYE=R`]("1E;G1R:65S7VQO8ULD
M:61=+3YC;&]N95]N;V1E*'1R=64I.PH@("`@("`@("`@("`@("`@("`@("`@
M("`D96YT<GE?;F5W+3YS971?871T<FEB=71E*"=S=&%T92<L("=C:&%N9V5D
M)RD["B`@("`@("`@("`@("`@("`@("`@("`@("1C;W5N=%]C:&%N9V5D*RL[
M"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"$D96YT<FEE<U]L;V-;)&ED72T^:&%S7V%T=')I8G5T
M92@G<W1A=&4G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O
M;6UE;G0@/2`D9&]C7VQO8RT^8W)E871E7V-O;6UE;G0H(B!%;F=L:7-H(&5N
M=')Y.EQN(B`N('-T<E]R97!L86-E*"<M+2<L("<F(S0U.R8C-#4[)RP@)&1O
M8U]L;V,M/F1U;7!?;F]D92@D96YT<GDI*2D["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D96YT<FEE<U]L;V-;)&ED72T^87!P96YD7V-H:6QD*"1C
M;VUM96YT*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E;G1R>5]N
M97<@/2`D96YT<FEE<U]L;V-;)&ED72T^8VQO;F5?;F]D92AT<G5E*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1E;G1R>5]N97<M/G-E=%]A='1R
M:6)U=&4H)W-T871E)RP@)W5N:VYO=VXG*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1C;W5N=%]U;FMN;W=N*RL["B`@("`@("`@("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M96YT<GE?;F5W(#T@)&5N=')I97-?;&]C6R1I9%TM/F-L;VYE7VYO9&4H=')U
M92D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]U;G1?=7!T;V1A
M=&4K*SL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@)&5N=')Y7VYE=R`]("1E;G1R>2T^8VQO;F5?;F]D92AT<G5E
M*3L*("`@("`@("`@("`@("`@("`@("`D96YT<GE?;F5W+3YS971?871T<FEB
M=71E*"=S=&%T92<L("=N97<G*3L*("`@("`@("`@("`@("`@("`@("`D8V]U
M;G1?;F5W*RL["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M96YT<FEE<U]N97=;72`]("1E;G1R>5]N97<["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)&1O8U]N97<M/F%P<&5N9%]C:&EL9"@D9&]C7VYE=RT^8W)E
M871E7V-O;6UE;G0H)R`D)R`N("=(;W)D920@)RDI.PH@("`@("`@("`@("!F
M;W)E86-H("@D96YT<FEE<U]N97<@87,@)&5N=')Y*2!["B`@("`@("`@("`@
M("`@("`D:&5L<%]N97<M/F%P<&5N9%]C:&EL9"@D96YT<GDI.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1C+3YW<FET96QN*'=O<F1W<F%P*'-P<FEN
M=&8H)T5N=')I97,Z("5D('1O=&%L+"`E9"!U<"UT;RUD871E+"`E9"!N97<L
M("5D(&-H86YG960L("5D('5N:VYO=VXG+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&-O=6YT7W5P=&]D871E("L@)&-O=6YT7VYE
M=R`K("1C;W5N=%]C:&%N9V5D("L@)&-O=6YT7W5N:VYO=VXL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]U;G1?=7!T;V1A=&4L
M("1C;W5N=%]N97<L("1C;W5N=%]C:&%N9V5D+"`D8V]U;G1?=6YK;F]W;BDI
M*3L*("`@("`@("`@("`@)&1O8U]N97<M/F%P<&5N9%]C:&EL9"@D:&5L<%]N
M97<I.PH@("`@("`@("`@("`D;W5T<'5T(#T@)&1O8U]N97<M/F1U;7!?;65M
M*'1R=64L("1E;F-O9&EN9RD["B`@("`@("`@("`@(&EF("@D9&5B=6<@?'P@
M)'1E<W0I('L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*'=O<F1W<F%P
M*'-P<FEN=&8H)U=R:71I;F<@=7!D871E9"!H96QP(&9I;&4@=&\@)7,N)RP@
M)&9I;&5?;&]C*2DI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A
M)'1E<W0I('L*("`@("`@("`@("`@("`@("1F<"`](&9O<&5N*"1F:6QE7VQO
M8RP@)W<G*3L*("`@("`@("`@("`@("`@("1L:6YE(#T@9G=R:71E*"1F<"P@
M)&]U='!U="D["B`@("`@("`@("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D8RT^=W)I=&5L;BAS<')I;G1F*"<E9"!B
M>71E<R!W<FET=&5N+B<L('-T<FQE;B@D;W5T<'5T*2DI.PH@("`@("`@("`@
M("`D8RT^=W)I=&5L;B@I.PH@("`@("`@('T*("`@('T*?0H*9G5N8W1I;VX@
M;6%K95]H96QP*"D*>PH@("`@9VQO8F%L("1C;61?;W!T:6]N<RP@)&1I<G,L
M("1A<'!S+"`D9&5B=6<L("1T97-T+"`D8SL*"B`@("!F;W)E86-H("@D8VUD
M7V]P=&EO;G-;,%T@87,@)&]P=&EO;BD@>PH@("`@("`@('-W:71C:"`H)&]P
M=&EO;ELP72D@>PH@("`@("`@("`@("!C87-E("=H)SH*("`@("`@("`@("`@
M("`@('5S86=E*"D["B`@("`@("`@("`@("`@("!F;V]T97(H*3L*("`@("`@
M("`@("`@8V%S92`G;"<Z"B`@("`@("`@("`@(&-A<V4@)RTM;&]C86QE)SH*
M("`@("`@("`@("`@("`@("1L86YG(#T@)&]P=&EO;ELQ73L*("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=M)SH*("`@("`@("`@
M("`@8V%S92`G+2UM;V1U;&4G.@H@("`@("`@("`@("`@("`@)&UO9'5L92`]
M("1O<'1I;VY;,5T["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]
M"B`@("!]"B`@("`D9FEL97,@/2!A<G)A>2@I.PH@("`@9F]R("@D:2`](#`[
M("1I(#P@8V]U;G0H)&1I<G,I.R`D:2LK*2!["B`@("`@("`@:68@*"%E;7!T
M>2@D;6]D=6QE*2`F)B`D;6]D=6QE("$]("1A<'!S6R1I72D@8V]N=&EN=64[
M"B`@("`@("`@:68@*"%I<U]D:7(H(B1D:7)S6R1I72]L;V-A;&4B*2D@8V]N
M=&EN=64["B`@("`@("`@:68@*"1A<'!S6R1I72`]/2`G:&]R9&4G*2!["B`@
M("`@("`@("`@("1D:7)S6UT@/2`D9&ER<ULD:5T@+B!$4R`N("=A9&UI;B<[
M"B`@("`@("`@("`@("1A<'!S6UT@/2`G:&]R9&4O861M:6XG.PH@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1M;V1U;&4I*2!["B`@("`@("`@("`@("`@("`D
M;6]D=6QE(#T@)VAO<F1E+V%D;6EN)SL*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("!I9B`H96UP='DH)&QA;F<I*2!["B`@("`@("`@("`@("1F
M:6QE<R`]('-E87)C:%]F:6QE*"=H96QP+GAM;"<L("1D:7)S6R1I72`N($13
M("X@)VQO8V%L92<I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1F
M:6QE<R`](&%R<F%Y*"1D:7)S6R1I72`N($13("X@)VQO8V%L92<@+B!$4R`N
M("1L86YG("X@1%,@+B`G:&5L<"YX;6PG*3L*("`@("`@("!]"B`@("`@("`@
M)&9I;&5?96X@(#T@)&1I<G-;)&E=("X@1%,@+B`G;&]C86QE)R`N($13("X@
M)V5N7U53)R`N($13("X@)VAE;'`N>&UL)SL*("`@("`@("!I9B`H(4!F:6QE
M7V5X:7-T<R@D9FEL95]E;BDI('L*("`@("`@("`@("`@8V]N=&EN=64["B`@
M("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1F:6QE<R!A<R`D9FEL95]L;V,I
M('L*("`@("`@("`@("`@:68@*"%`9FEL95]E>&ES=',H)&9I;&5?;&]C*2D@
M>PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)U-K:7!P960N+BXG*3L*
M("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"D["B`@("`@("`@("`@("`@
M("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D;&]C86QE
M(#T@<W5B<W1R*"1F:6QE7VQO8RP@,"P@<W1R<G!O<R@D9FEL95]L;V,L($13
M*2D["B`@("`@("`@("`@("1L;V-A;&4@/2!S=6)S='(H)&QO8V%L92P@<W1R
M<G!O<R@D;&]C86QE+"!$4RD@*R`Q*3L*("`@("`@("`@("`@:68@*"1L;V-A
M;&4@/3T@)V5N7U53)RD@8V]N=&EN=64["B`@("`@("`@("`@("1C+3YW<FET
M96QN*'-P<FEN=&8H)U5P9&%T:6YG("5S(&AE;'`@9FEL92!F;W(@)7,N)RP@
M)&,M/F)O;&0H)&QO8V%L92DL("1C+3YB;VQD*"1A<'!S6R1I72DI*3L*("`@
M("`@("`@("`@)&9P(#T@9F]P96XH)&9I;&5?;&]C+"`G<B<I.PH@("`@("`@
M("`@("`D;&EN92`](&9G971S*"1F<"D["B`@("`@("`@("`@(&9C;&]S92@D
M9G`I.PH@("`@("`@("`@("!I9B`H(7-T<G-T<B@D;&EN92P@)SP_>&UL)RDI
M('L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*'=O<F1W<F%P*"1C+3YR
M960H)U=A<FYI;F<Z("<I("X@<W!R:6YT9B@G5&AE(&AE;'`@9FEL92`E<R!D
M:61N7"=T('-T87)T('=I=&@@/#]X;6PG+"`D9FEL95]L;V,I*2D["B`@("`@
M("`@("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@("`@("`@("`@8V]N
M=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&5N8V]D:6YG(#T@
M)R<["B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O96YC;V1I;F<]*%LB
M7"==*2A;7EQ<,5TK*5Q<,2\G+"`D;&EN92P@)&UA=&-H*2D@>PH@("`@("`@
M("`@("`@("`@)&5N8V]D:6YG(#T@)&UA=&-H6S)=.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1D;V-?96X@("`](&1O;7AM;%]O<&5N7V9I;&4H)&9I
M;&5?96XI.PH@("`@("`@("`@("!I9B`H(6ES7V]B:F5C="@D9&]C7V5N*2D@
M>PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH=V]R9'=R87`H)&,M/G)E
M9"@G5V%R;FEN9SH@)RD@+B!S<')I;G1F*"=4:&5R92!W87,@86X@97)R;W(@
M;W!E;FEN9R!T:&4@9FEL92`E<RX@5')Y(')U;FYI;F<@=')A;G-L871I;VXN
M<&AP('=I=&@@=&AE(&9L86<@+60@=&\@<V5E(&%N>2!E<G)O<B!M97-S86=E
M<R!F<F]M('1H92!X;6P@<&%R<V5R+B<L("1F:6QE7V5N*2DI.PH@("`@("`@
M("`@("`@("`@)&,M/G=R:71E;&XH*3L*("`@("`@("`@("`@("`@(&-O;G1I
M;G5E(#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&1O8U]L;V,@(#T@
M9&]M>&UL7V]P96Y?9FEL92@D9FEL95]L;V,I.PH@("`@("`@("`@("!I9B`H
M(6ES7V]B:F5C="@D9&]C7VQO8RDI('L*("`@("`@("`@("`@("`@("1C+3YW
M<FET96QN*'=O<F1W<F%P*"1C+3YR960H)U=A<FYI;F<Z("<I("X@<W!R:6YT
M9B@G5&AE<F4@=V%S(&%N(&5R<F]R(&]P96YI;F<@=&AE(&9I;&4@)7,N(%1R
M>2!R=6YN:6YG('1R86YS;&%T:6]N+G!H<"!W:71H('1H92!F;&%G("UD('1O
M('-E92!A;GD@97)R;W(@;65S<V%G97,@9G)O;2!T:&4@>&UL('!A<G-E<BXG
M+"`D9FEL95]L;V,I*2D["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@I
M.PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)&AE;'!?;&]C(#T@)&1O8U]L;V,M/F1O8W5M96YT7V5L96UE
M;G0H*3L*("`@("`@("`@("`@)&UD-5]E;B`@(#T@87)R87DH*3L*("`@("`@
M("`@("`@)&-O=6YT7V%L;"`](#`["B`@("`@("`@("`@("1C;W5N="`@("`@
M/2`P.PH@("`@("`@("`@("!F;W)E86-H("@D9&]C7V5N+3YG971?96QE;65N
M='-?8GE?=&%G;F%M92@G96YT<GDG*2!A<R`D96YT<GDI('L*("`@("`@("`@
M("`@("`@("1M9#5?96Y;)&5N=')Y+3YG971?871T<FEB=71E*"=I9"<I72`]
M(&UD-2@D96YT<GDM/F=E=%]C;VYT96YT*"DI.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&9O<F5A8V@@*"1D;V-?;&]C+3YG971?96QE;65N='-?8GE?
M=&%G;F%M92@G96YT<GDG*2!A<R`D96YT<GDI('L*("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1E;G1R>2T^8VAI;&1?;F]D97,H*2!A<R`D8VAI;&0I('L*
M("`@("`@("`@("`@("`@("`@("!I9B`H)&-H:6QD+3YN;V1E7W1Y<&4H*2`]
M/2!834Q?0T]-345.5%].3T1%("8F('-T<G-T<B@D8VAI;&0M/FYO9&5?=F%L
M=64H*2P@)T5N9VQI<V@@96YT<GDG*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D96YT<GDM/G)E;6]V95]C:&EL9"@D8VAI;&0I.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("1C;W5N=%]A;&PK*SL*("`@("`@("`@("`@("`@("1I9"`]("1E;G1R>2T^
M9V5T7V%T=')I8G5T92@G:60G*3L*("`@("`@("`@("`@("`@(&EF("@A87)R
M87E?:V5Y7V5X:7-T<R@D:60L("1M9#5?96XI*2!["B`@("`@("`@("`@("`@
M("`@("`@)&,M/G=R:71E;&XH=V]R9'=R87`H)&,M/G)E9"@G5V%R;FEN9SH@
M)RD@+B!S<')I;G1F*"=.;R!E;G1R>2!W:71H('1H92!I9"`B)7,B(&5X:7-T
M<R!I;B!T:&4@;W)I9VEN86P@:&5L<"!F:6QE+B<L("1I9"DI*3L*("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&5N=')Y
M+3YS971?871T<FEB=71E*"=M9#4G+"`D;60U7V5N6R1I9%TI.PH@("`@("`@
M("`@("`@("`@("`@("1E;G1R>2T^<V5T7V%T=')I8G5T92@G<W1A=&4G+"`G
M=7!T;V1A=&4G*3L*("`@("`@("`@("`@("`@("`@("`D8V]U;G0K*SL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D;W5T
M<'5T(#T@)&1O8U]L;V,M/F1U;7!?;65M*'1R=64L("1E;F-O9&EN9RD["B`@
M("`@("`@("`@(&EF("@A)'1E<W0I('L*("`@("`@("`@("`@("`@("1F<"`]
M(&9O<&5N*"1F:6QE7VQO8RP@)W<G*3L*("`@("`@("`@("`@("`@("1L:6YE
M(#T@9G=R:71E*"1F<"P@)&]U='!U="D["B`@("`@("`@("`@("`@("!F8VQO
M<V4H)&9P*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D8RT^=W)I=&5L
M;BAS<')I;G1F*"<E9"!O9B`E9"!E;G1R:65S(&UA<FME9"!A<R!U<"UT;RUD
M871E)RP@)&-O=6YT+"`D8V]U;G1?86QL*2D["B`@("`@("`@("`@("1C+3YW
M<FET96QN*"D["B`@("`@("`@?0H@("`@?0I]"@HD8W5R9&ER(#T@9V5T8W=D
M*"D["F1E9FEN92@G1%,G+"!$25)%0U1/4EE?4T5005)!5$]2*3L*"B1L86YG
M=6%G92`](&=E=&5N=B@G3$%.1R<I.PII9B`H96UP='DH)&QA;F=U86=E*2D@
M>PH@("`@)&QA;F=U86=E(#T@9V5T96YV*"=,04Y'54%'12<I.PI]"@I`9&5F
M:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD[
M"G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8V]R92YP:'`G.PIR
M97%U:7)E7V]N8V4@)TAO<F1E+T-,22YP:'`G.PH*)&,@/2`F;F5W($AO<F1E
M7T-,22@I.PII9B`H(21C+3YR=6YN:6YG1G)O;4-,22@I*2!["B`@("`D8RT^
M9F%T86PH)U1H:7,@<V-R:7!T(&UU<W0@8F4@<G5N(&9R;VT@=&AE(&-O;6UA
M;F0@;&EN92XG*3L*?0HD8RT^:6YI="@I.PH*)&,M/G=R:71E;&XH)&,M/F)O
M;&0H)RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2<I*3L*)&,M/G=R:71E
M;&XH)&,M/F)O;&0H)TAO<F1E('1R86YS;&%T:6]N(&=E;F5R871O<B<I*3L*
M)&,M/G=R:71E;&XH)&,M/F)O;&0H)RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2<I*3L*"B\J(%-A;FET>2!C:&5C:W,@*B\*:68@*"%E>'1E;G-I;VY?
M;&]A9&5D*"=G971T97AT)RDI('L*("`@("1C+3YW<FET96QN*"1C+3YR960H
M)T=E='1E>'0@97AT96YS:6]N(&YO="!F;W5N9"$G*2D["B`@("!F;V]T97(H
M*3L*?0H*)&,M/G=R:71E;&XH)TQO861I;F<@;&EB<F%R:65S+BXN)RD["B1L
M:6)S7V9O=6YD(#T@=')U93L*"F9O<F5A8V@@*&%R<F%Y*"=#;VYS;VQE7T=E
M=&]P="<@/3X@)T-O;G-O;&4O1V5T;W!T+G!H<"<L"B`@("`@("`@("`@("`@
M("=#;VYS;VQE7U1A8FQE)R`@/3X@)T-O;G-O;&4O5&%B;&4N<&AP)RP*("`@
M("`@("`@("`@("`@)T9I;&5?1FEN9"<@("`@("`]/B`G1FEL92]&:6YD+G!H
M<"<I"B`@("`@("`@(&%S("1C;&%S<R`]/B`D9FEL92D@>PH@("`@96-H;R`D
M8VQA<W,@+B`G+BXN("<["B`@("!`:6YC;'5D92`D9FEL93L*("`@(&EF("AC
M;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("1C+3YW<FET96QN*"1C
M+3YG<F5E;B@G3TLG*2D["B`@("!](&5L<V4@>PH@("`@("`@("1C+3YW<FET
M96QN*"1C+3YR960H<W!R:6YT9B@G)7,@;F]T(&9O=6YD+B<L("1C;&%S<RDI
M*3L*("`@("`@("`D;&EB<U]F;W5N9"`](&9A;'-E.PH@("`@?0I]"@II9B`H
M(21L:6)S7V9O=6YD*2!["B`@("`D8RT^=W)I=&5L;B@I.PH@("`@)&,M/G=R
M:71E;&XH)TUA:V4@<W5R92!T:&%T('EO=2!H879E(%!%05(@:6YS=&%L;&5D
M(&%N9"!I;B!Y;W5R(&EN8VQU9&4@<&%T:"XG*3L*("`@("1C+3YW<FET96QN
M*"=I;F-L=61E7W!A=&@Z("<@+B!I;FE?9V5T*"=I;F-L=61E7W!A=&@G*2D[
M"B`@("!F;V]T97(H*3L*?0HD8RT^=W)I=&5L;B@I.PH*+RH@0V]M;6%N9&QI
M;F4@<&%R86UE=&5R<R`J+PHD87)G<R`@("`]($-O;G-O;&5?1V5T;W!T.CIR
M96%D4$A007)G=B@I.PHD;W!T:6]N<R`]($-O;G-O;&5?1V5T;W!T.CIG971O
M<'0H)&%R9W,L("=B.F1H="<L(&%R<F%Y*"=B87-E/2<L("=D96)U9R<L("=H
M96QP)RP@)W1E<W0G*2D["FEF("A014%2.CII<T5R<F]R*"1O<'1I;VYS*2`F
M)B`D87)G<ULP72`]/2`D7U-%4E9%4ELG4$A07U-%3$8G72D@>PH@("`@87)R
M87E?<VAI9G0H)&%R9W,I.PH@("`@)&]P=&EO;G,@/2!#;VYS;VQE7T=E=&]P
M=#HZ9V5T;W!T*"1A<F=S+"`G8CID:'0G+"!A<G)A>2@G8F%S93TG+"`G9&5B
M=6<G+"`G:&5L<"<L("=T97-T)RDI.PI]"FEF("A014%2.CII<T5R<F]R*"1O
M<'1I;VYS*2D@>PH@("`@)&,M/G=R:71E;&XH)&,M/G)E9"@G1V5T;W!T($5R
M<F]R.B`G("X@<W1R7W)E<&QA8V4H)T-O;G-O;&5?1V5T;W!T.B<L("<G+"`D
M;W!T:6]N<RT^9V5T365S<V%G92@I*2DI.PH@("`@)&,M/G=R:71E;&XH*3L*
M("`@('5S86=E*"D["B`@("!F;V]T97(H*3L*?0II9B`H96UP='DH)&]P=&EO
M;G-;,%U;,%TI("8F(&5M<'1Y*"1O<'1I;VYS6S%=6S!=*2D@>PH@("`@)&,M
M/G=R:71E;&XH)&,M/G)E9"@G17)R;W(Z("<@+B`G3F\@8V]M;6%N9"!S<&5C
M:69I960N)RDI.PH@("`@)&,M/G=R:71E;&XH*3L*("`@('5S86=E*"D["B`@
M("!F;V]T97(H*3L*?0HD9&5B=6<@/2!F86QS93L*)'1E<W0@(#T@9F%L<V4[
M"F9O<F5A8V@@*"1O<'1I;VYS6S!=(&%S("1O<'1I;VXI('L*("`@('-W:71C
M:"`H)&]P=&EO;ELP72D@>PH@("`@("`@(&-A<V4@)V(G.@H@("`@("`@(&-A
M<V4@)RTM8F%S92<Z"B`@("`@("`@("`@(&EF("AS=6)S='(H)&]P=&EO;ELQ
M72P@+3$I(#T]($13*2!["B`@("`@("`@("`@("`@("`D;W!T:6]N6S%=(#T@
M<W5B<W1R*"1O<'1I;VY;,5TL(#`L("TQ*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!D969I;F4H)T)!4T4G+"`D;W!T:6]N6S%=*3L*("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@8V%S92`G9"<Z"B`@("`@("`@8V%S92`G+2UD
M96)U9R<Z"B`@("`@("`@("`@("1D96)U9R`]('1R=64["B`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@(&-A<V4@)W0G.@H@("`@("`@(&-A<V4@)RTM=&5S
M="<Z"B`@("`@("`@("`@("1T97-T(#T@=')U93L*("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@8V%S92`G:"<Z"B`@("`@("`@8V%S92`G+2UH96QP)SH*
M("`@("`@("`@("`@=7-A9V4H*3L*("`@("`@("`@("`@9F]O=&5R*"D["B`@
M("!]"GT*:68@*"$D9&5B=6<I('L*("`@(&EN:5]S970H)V5R<F]R7W)E<&]R
M=&EN9R<L(&9A;'-E*3L*?0II9B`H(61E9FEN960H)T)!4T4G*2D@>PH@("`@
M9&5F:6YE*"="05-%)RP@2$]21$5?0D%312D["GT*:68@*"1O<'1I;VYS6S%=
M6S!=(#T]("=H96QP)RD@>PH@("`@=7-A9V4H*3L*("`@(&9O;W1E<B@I.PI]
M"B1S:6QE;F-E(#T@)&1E8G5G('Q\($]37U=)3D1/5U,@/R`G)R`Z("<@,CX@
M+V1E=B]N=6QL)SL*)')E9&ER7V5R<B`]($]37U=)3D1/5U,@/R`G)R`Z("<@
M,CXF,2<["B1O<'1I;VYS7VQI<W0@/2!A<G)A>2@*("`@("=C;&5A;G5P)R`@
M("`]/B!A<G)A>2@G:&PZ;3HG+"!A<G)A>2@G;6]D=6QE/2<L("=L;V-A;&4]
M)RDI+`H@("`@)V-O;6UI="<@("`@(#T^(&%R<F%Y*"=H;#IM.FY-.B<L(&%R
M<F%Y*"=M;V1U;&4])RP@)VQO8V%L93TG+"`G;F5W)RP@)VUE<W-A9V4])RDI
M+`H@("`@)V-O;6UI="UH96QP)ST^(&%R<F%Y*"=H;#IM.FY-.B<L(&%R<F%Y
M*"=M;V1U;&4])RP@)VQO8V%L93TG+"`G;F5W)RP@)VUE<W-A9V4])RDI+`H@
M("`@)V-O;7!E;F1I=6TG(#T^(&%R<F%Y*"=H;#ID.F$Z)RP@87)R87DH)VQO
M8V%L93TG+"`G9&ER96-T;W)Y/2<L("=A9&0])RDI+`H@("`@)V5X=')A8W0G
M("`@(#T^(&%R<F%Y*"=H;3HG+"!A<G)A>2@G;6]D=6QE/2<I*2P*("`@("=I
M;FET)R`@("`@("`]/B!A<G)A>2@G:&PZ;3IN8SHG+"!A<G)A>2@G;6]D=6QE
M/2<L("=L;V-A;&4])RP@)VYO+6-O;7!E;F1I=6TG+"`G8V]M<&5N9&EU;3TG
M*2DL"B`@("`G;65R9V4G("`@("`@/3X@87)R87DH)VAL.FTZ8SIN)RP@87)R
M87DH)VUO9'5L93TG+"`G;&]C86QE/2<L("=C;VUP96YD:75M/2<L("=N;RUC
M;VUP96YD:75M)RDI+`H@("`@)VUA:V4G("`@("`@(#T^(&%R<F%Y*"=H;#IM
M.F,Z;G,G+"!A<G)A>2@G;6]D=6QE/2<L("=L;V-A;&4])RP@)V-O;7!E;F1I
M=6T])RP@)VYO+6-O;7!E;F1I=6TG+"`G<W1A=&ES=&EC<R<I*2P*("`@("=M
M86ME+6AE;'`G("`]/B!A<G)A>2@G:&PZ;3HG+"!A<G)A>2@G;6]D=6QE/2<L
M("=L;V-A;&4])RDI+`H@("`@)W5P9&%T92<@("`@(#T^(&%R<F%Y*"=H;#IM
M.F,Z;B<L(&%R<F%Y*"=M;V1U;&4])RP@)VQO8V%L93TG+"`G8V]M<&5N9&EU
M;3TG+"`G;F\M8V]M<&5N9&EU;2<I*2P*("`@("=U<&1A=&4M:&5L<"<]/B!A
M<G)A>2@G:&PZ;3HG+"!A<G)A>2@G;6]D=6QE/2<L("=L;V-A;&4])RDI+`H@
M("`@)W-T871U<R<@("`@(#T^(&%R<F%Y*"=H;#IM.F\Z)RP@87)R87DH)VUO
M9'5L93TG+"`G;&]C86QE/2<L("=O=71P=70])RDI"BD["B1O<'1I;VYS7V%R
M<B`]("1O<'1I;VYS6S%=.PHD8VUD("`@("`@("`@/2!A<G)A>5]S:&EF="@D
M;W!T:6]N<U]A<G(I.PII9B`H87)R87E?:V5Y7V5X:7-T<R@D8VUD+"`D;W!T
M:6]N<U]L:7-T*2D@>PH@("`@)&-M9%]O<'1I;VYS(#T@0V]N<V]L95]'971O
M<'0Z.F=E=&]P="@D;W!T:6]N<U]A<G(L("1O<'1I;VYS7VQI<W1;)&-M9%U;
M,%TL("1O<'1I;VYS7VQI<W1;)&-M9%U;,5TI.PH@("`@:68@*%!%05(Z.FES
M17)R;W(H)&-M9%]O<'1I;VYS*2D@>PH@("`@("`@("1C+3YW<FET96QN*"1C
M+3YR960H)T5R<F]R.B`G("X@<W1R7W)E<&QA8V4H)T-O;G-O;&5?1V5T;W!T
M.B<L("<G+"`D8VUD7V]P=&EO;G,M/F=E=$UE<W-A9V4H*2DI*3L*("`@("`@
M("`D8RT^=W)I=&5L;B@I.PH@("`@("`@('5S86=E*"D["B`@("`@("`@9F]O
M=&5R*"D["B`@("!]"GT*"B\J(%-E87)C:&EN9R!A<'!L:6-A=&EO;G,@*B\*
M8VAE8VM?8FEN87)I97,H*3L*"B1C+3YW<FET96QN*'-P<FEN=&8H)U-E87)C
M:&EN9R!(;W)D92!A<'!L:6-A=&EO;G,@:6X@)7,G+"!"05-%*2D["B1D:7)S
M(#T@<V5A<F-H7V%P<&QI8V%T:6]N<R@I.PH*:68@*"1D96)U9RD@>PH@("`@
M)&,M/G=R:71E;&XH)T9O=6YD(&1I<F5C=&]R:65S.B<I.PH@("`@)&,M/G=R
M:71E;&XH:6UP;&]D92@B7&XB+"`D9&ER<RDI.PI]"@HD87!P<R`]('-T<FEP
M7VAO<F1E*"1D:7)S*3L*)&%P<'-;,%T@/2`G:&]R9&4G.PHD8RT^=W)I=&5L
M;BAW;W)D=W)A<"AS<')I;G1F*"=&;W5N9"!A<'!L:6-A=&EO;G,Z("5S)RP@
M:6UP;&]D92@G+"`G+"`D87!P<RDI*2D["B1C+3YW<FET96QN*"D["@IS=VET
M8V@@*"1C;60I('L*("`@(&-A<V4@)V-L96%N=7`G.@H@("`@8V%S92`G8V]M
M;6ET)SH*("`@(&-A<V4@)V-O;7!E;F1I=6TG.@H@("`@8V%S92`G;65R9V4G
M.@H@("`@("`@("1C;60H*3L*("`@("`@("!B<F5A:SL*("`@(&-A<V4@)V-O
M;6UI="UH96QP)SH*("`@("`@("!C;VUM:70H=')U92D["B`@("`@("`@8G)E
M86L["B`@("!C87-E("=E>'1R86-T)SH*("`@("`@("!X=')A8W0H*3L*("`@
M("`@("!B<F5A:SL*("`@(&-A<V4@)VEN:70G.@H@("`@("`@(&EN:70H*3L*
M("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@(&UE<F=E*"D["B`@("`@
M("`@8G)E86L["B`@("!C87-E("=M86ME)SH*("`@("`@("!C;&5A;G5P*'1R
M=64I.PH@("`@("`@("1C+3YW<FET96QN*"D["B`@("`@("`@;6%K92@I.PH@
M("`@("`@(&)R96%K.PH@("`@8V%S92`G;6%K92UH96QP)SH*("`@("`@("!M
M86ME7VAE;'`H*3L*("`@("`@("!B<F5A:SL*("`@(&-A<V4@)W5P9&%T92<Z
M"B`@("`@("`@>'1R86-T*"D["B`@("`@("`@)&,M/G=R:71E;&XH*3L*("`@
M("`@("!M97)G92@I.PH@("`@("`@(&)R96%K.PH@("`@8V%S92`G=7!D871E
M+6AE;'`G.@H@("`@("`@('5P9&%T95]H96QP*"D["B`@("`@("`@8G)E86L[
M"B`@("!C87-E("=S=&%T=7,G.@HO+R`@("`@("`@>'1R86-T*"D["B`@("`@
M("`@;65R9V4H*3L*+R\@("`@("`@('-T871U<R@I.PH@("`@("`@(&)R96%K
M.PH@("`@9&5F875L=#H*("`@("`@("`D8RT^=W)I=&5L;B@D8RT^<F5D*"=%
M<G)O<CH@)RD@+B!S<')I;G1F*"=5;FMN;W=N(&-O;6UA;F0Z("5S)RP@)&-M
M9"DI.PH@("`@("`@("1C+3YW<FET96QN*"D["B`@("`@("`@=7-A9V4H*3L*
M("`@("`@("!F;V]T97(H*3L*?0H*9F]O=&5R*"D["@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]I<U])4RYP;P``````````````
M````````````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`V,S(S-#0@
M,3`U,34T,S,W-#(@,#$W-3,W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````",@26-E;&%N9&EC('1R86YS;&%T:6]N<R!F;W(@
M9&ES:R!P86-K86=E+@HC($-O<'ER:6=H="`H0RD@,C`P-2!(;W)D92!0<F]J
M96-T"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE
M(&QI8V5N<V4@87,@=&AE(&1I<VL@<&%C:V%G92X*(PIM<V=I9"`B(@IM<V=S
M='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@,RXP+C5<;B(*(E)E
M<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)0
M3U0M0W)E871I;VXM1&%T93H@,C`P,BTP,2TQ,"`Q.3HP,"LP,3`P7&XB"B)0
M3RU2979I<VEO;BU$871E.B`R,#`U+3$Q+3$Y(#(P.C,S*S`P,#!<;B(*(DQA
M<W0M5')A;G-L871O<CH@0FIO<FX@1&%V:61S<V]N(#QB:F]S<VE`<VYE<G!A
M+FES/EQN(@HB3&%N9W5A9V4M5&5A;3H@26-E;&%N9&EC(#QS=7!P;W)T0'-N
M97)P82YI<SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y
M<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,5QN(@HB0V]N=&5N
M="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C0Y"FUS9VED("(B"B(@("U-+"`M+6UE<W-A9V4]34534T%'12`@
M57-E('1H:7,@8V]M;6ET(&UE<W-A9V4@:6YS=&5A9"!O9B!T:&4@9&5F875L
M="!O;F5S+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-3,*
M;7-G:60@(B(*(B`@+6$L("TM861D/49)3$4@("`@("`@($%D9"!T:&ES(%!/
M(&9I;&4@=&\@=&AE(&-O;7!E;F1I=6TN(%5S969U;"!T;UQN(@HB("`@("`@
M("`@("`@("`@("`@("`@("`@:6YC;'5D92!A(&-O;7!E;F1I=6T@9G)O;2!A
M(&1I9F9E<F5N="!B<F%N8V@@=&]<;B(*(B`@("`@("`@("`@("`@("`@("`@
M("`@('1H92!G96YE<F%T960@8V]M<&5N9&EU;2XB"FUS9W-T<B`B(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C$Q,PIM<V=I9"`B(@HB("`M8BP@+2UB87-E
M/2]0051(("!&=6QL('!A=&@@=&\@=&AE("A(;W)D92D@8F%S92!D:7)E8W1O
M<GD@=&AA="!S:&]U;&0@8F5<;B(*(B`@("`@("`@("`@("`@("`@("`@=7-E
M9"XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8Y"FUS9VED
M("(B"B(@("UC+"`M+6-O;7!E;F1I=6T]1DE,12`@365R9V4@;F5W('1R86YS
M;&%T:6]N<R!T;R!T:&ES(&-O;7!E;F1I=6T@9FEL95QN(@HB("`@("`@("`@
M("`@("`@("`@("`@("`@(&EN<W1E860@;V8@=&AE(&1E9F%U;'0@;VYE("AC
M;VUP96YD:75M+G!O(&EN('1H95QN(@HB("`@("`@("`@("`@("`@("`@("`@
M("`@(&AO<F1E+W!O(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C8S('!O+W1R86YS;&%T:6]N+G!H<#HX,2!P;R]T<F%N
M<VQA=&EO;BYP:'`Z.#<*;7-G:60@(B(*(B`@+6,L("TM8V]M<&5N9&EU;3U&
M24Q%("!5<V4@=&AI<R!C;VUP96YD:75M(&9I;&4@:6YS=&5A9"!O9B!T:&4@
M9&5F875L=%QN(@HB("`@("`@("`@("`@("`@("`@("`@("`@(&]N92`H8V]M
M<&5N9&EU;2YP;R!I;B!T:&4@:&]R9&4O<&\@9&ER96-T;W)Y*2XB"FUS9W-T
M<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$Q-`IM<V=I9"`B("`M9"P@
M+2UD96)U9R`@("`@("!3:&]W(&5R<F]R(&UE<W-A9V5S(&9R;VT@=&AE(&5X
M96-U=&5D(&)I;F%R:65S+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z-30*;7-G:60@(B`@+60L("TM9&ER96-T;W)Y/41)4B`@($-R96%T
M92!C;VUP96YD:75M(&EN('1H:7,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$U"FUS9VED("(@("UH+"`M+6AE;'`@
M("`@("`@(%-H;W<@=&AI<R!H96QP(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HT,B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C<@
M<&\O=')A;G-L871I;VXN<&AP.C<U"FUS9VED("(@("UL+"`M+6QO8V%L93UL
M;%]#0R`@("`@57-E(&]N;'D@=&AI<R!L;V-A;&4N(@IM<V=S='(@(B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HT-R!P;R]T<F%N<VQA=&EO;BYP:'`Z-C$@
M<&\O=')A;G-L871I;VXN<&AP.C<Y"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HX
M-0IM<V=I9"`B("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S92!T:&ES(&QO
M8V%L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C4U"FUS
M9VED("(@("UL+"`M+6QO8V%L93UL;%]#0R`@("!5<V4@=&AI<R!L;V-A;&4N
M(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV.`IM<V=I9"`B
M("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($)U:6QD($U/(&9I;&5S(&]N;'D@
M9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N(@IM<V=S='(@(B(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HT,PIM<V=I9"`B("`M;2P@+2UM;V1U;&4]34]$54Q%
M("`@($-L96%N=7`@4$\@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO
M9'5L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0X"FUS
M9VED("(B"B(@("UM+"`M+6UO9'5L93U-3T153$4@("`@0V]M;6ET('1R86YS
M;&%T:6]N<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+B(*;7-G<W1R
M("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C(*;7-G:60@(B`@+6TL("TM
M;6]D=6QE/4U/1%5,12`@("!#<F5A=&4@82!03R!F:6QE(&]N;'D@9F]R('1H
M:7,@*$AO<F1E*2!M;V1U;&4N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HX,`IM<V=I9"`B("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($UE
M<F=E(%!/(&9I;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N(@IM
M<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW-@IM<V=I9"`B(@HB
M("`M;2P@+2UM;V1U;&4]34]$54Q%("`@(%5P9&%T92!H96QP(&9I;&5S(&]N
M;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N(@IM<V=S='(@(B(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HX-@IM<V=I9"`B("`M;2P@+2UM;V1U;&4]34]$
M54Q%("`@(%5P9&%T92!O;FQY('1H:7,@*$AO<F1E*2!M;V1U;&4N(@IM<V=S
M='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HU.`IM<V=I9"`B("`M;2P@
M+2UM;V1U;&4]34]$54Q%("!'96YE<F%T92!03U0@9FEL92!O;FQY(&9O<B!T
M:&ES("A(;W)D92D@;6]D=6QE+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z-S`*;7-G:60@(B(*(B`@+6XL("TM;F\M8V]M<&5N9&EU;2`@
M("!$;VXG="!M97)G92!N97<@=')A;G-L871I;VYS('1O('1H92!C;VUP96YD
M:75M+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C0@<&\O
M=')A;G-L871I;VXN<&AP.C@R('!O+W1R86YS;&%T:6]N+G!H<#HX.`IM<V=I
M9"`B("`M;BP@+2UN;RUC;VUP96YD:75M("`@($1O;B=T('5S92!A(&-O;7!E
M;F1I=6TN(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW,0IM
M<V=I9"`B("`M<RP@+2US=&%T:7-T:6-S("`@("`@(%-A=F4@=')A;G-L871I
M;VX@<W1A=&ES=&EC<R!I;B!A(&QO8V%L(&9I;&4N(@IM<V=S='(@(B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HQ,38*;7-G:60@(B`@+70L("TM=&5S="`@
M("`@("`@4VAO=R!T:&4@97AE8W5T960@8V]M;6%N9',@8G5T(&1O;B=T(')U
M;B!A;GET:&EN9RXB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C$P-0IM<V=I9"`B(@HB("!C;&5A;G5P("`@("!#;&5A;G,@=&AE(%!/(&9I
M;&5S('5P(&9R;VT@=6YT<F%N<VQA=&5D(&%N9"!O8G-O;&5T92!E;G1R:65S
M+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`X"FUS9VED
M("(@(&-O;6UI="`@("`@($-O;6UI="!T<F%N<VQA=&EO;G,@=&\@=&AE($-6
M4R!S97)V97(N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ
M,#D*;7-G:60@(B`@8V]M;6ET+6AE;'`@0V]M;6ET(&AE;'`@9FEL97,@=&\@
M=&AE($-64R!S97)V97(N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HY.0IM<V=I9"`B(@HB("!C;VUP96YD:75M("!296)U:6QD('1H92!C
M;VUP96YD:75M(&9I;&4N(%=A<FYI;F<Z(%1H:7,@;W9E<G=R:71E<R!T:&5<
M;B(*(B`@("`@("`@("`@("`@8W5R<F5N="!C;VUP96YD:75M+B(*;7-G<W1R
M("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`P"FUS9VED("(@(&5X=')A
M8W0@("`@($=E;F5R871E(%!/('1E;7!L871E("@N<&]T*2!F:6QE<RXB"FUS
M9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.CDX"FUS9VED("(@(&AE
M;'`@("`@("`@(%-H;W<@=&AI<R!H96QP(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#$*;7-G:60@(B(*(B`@:6YI="`@
M("`@("`@0W)E871E(&]N92!O<B!M;W)E(%!/(&9I;&5S(&9O<B!A(&YE=R!L
M;V-A;&4N(%=A<FYI;F<Z(%1H:7-<;B(*(B`@("`@("`@("`@("`@;W9E<G=R
M:71E<R!T:&4@97AI<W1I;F<@4$\@9FEL97,@;V8@=&AI<R!L;V-A;&4N(@IM
M<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#8*;7-G:60@(B`@
M;6%K92`@("`@("`@0G5I;&0@8FEN87)Y($U/(&9I;&5S(&9R;VT@=&AE('-P
M96-I9FEE9"!03R!F:6QE<RXB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C$P-PIM<V=I9"`B(@HB("!M86ME+6AE;'`@("!-87)K(&%L;"!E
M;G1R:65S(&EN('1H92!834P@:&5L<"!F:6QE(&)E:6YG('5P+71O+61A=&4@
M86YD7&XB"B(@("`@("`@("`@("`@('!R97!A<F4@=&AE(&9I;&4@9F]R('1H
M92!N97AT(&5X96-U=&EO;B!O9B!U<&1A=&4M:&5L<"X@66]U7&XB"B(@("`@
M("`@("`@("`@('-H;W5L9"!O;FQY(')U;B!M86ME+6AE;'`@049415(@=7!D
M871E+6AE;'`@86YD(')E=FES:6YG('1H95QN(@HB("`@("`@("`@("`@("!H
M96QP(&9I;&4N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ
M,#(*;7-G:60@(B(*(B`@;65R9V4@("`@("`@365R9V4@=&AE(&-U<G)E;G0@
M4$\@9FEL92!W:71H('1H92!C=7)R96YT(%!/('1E;7!L871E(&9I;&4N(@IM
M<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#,*;7-G:60@(B`@
M=7!D871E("`@("`@4G5N(&5X=')A8W0@86YD(&UE<F=E('-E<75E;G0N(@IM
M<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#0*;7-G:60@(B(*
M(B`@=7!D871E+6AE;'`@17AT<F%C="!A;&P@;F5W(&%N9"!C:&%N9V5D(&5N
M=')I97,@9G)O;2!T:&4@16YG;&ES:"!834P@:&5L<%QN(@HB("`@("`@("`@
M("`@("!F:6QE(&%N9"!M97)G92!T:&5M('=I=&@@=&AE(&5X:7-T:6YG(&]N
M97,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF
M:7)M7W1O<"YI;F,Z,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB("8C,34Q
M.R`E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R
M871I;VYS(&-H96-K960@8F5L;W<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(S-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E
M<R!D87ES(&%G;RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ,C0W"B,L('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y
M("5S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S<U"B,L('!H<"UF;W)M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,0IM<V=I9"`B
M("AT;V1A>2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C,W,PIM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,V.0IM<V=I9"`B("AY97-T97)D87DI
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,3@*;7-G:60@(B!A="`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(P-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A
M;F0@)7,B"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$Q-S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@8GET97,@=W)I='1E;BXB"FUS9W-T
M<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$R.#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)60@;V8@)60@96YT<FEE<R!M87)K960@87,@=7`M=&\M9&%T
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C0U"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;F]T:6-E7W1O<"YI
M;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z,S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@061M:6YI<W1R871I;VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#(T(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@R-@HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I
M;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC.C0*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M
M871I;VXB"FUS9W-T<B`B5FGP:&%L9'-A\&=E<O!I<B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q.`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8S"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+V%G<F5E;65N=%]T;W`N:6YC.C0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-38X(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z-C,V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B36%P<&%N(%PB)7-<(B!E<B!N
M^B#^96=A<B!T:6PB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U-R!L:6(O
M0FQO8VLO;65T87(N<&AP.C$V,R!L:6(O0FQO8VLO;65T87(N<&AP.C(S-PHC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T,R!L:6(O0FQO8VLO;65T87(N<&AP
M.C,T.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C4S,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@8V%N8V5L;&5D
M("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C0R-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H
M87,@<F5P;&EE9"!T;R!A(&9R964O8G5S>2!R97%U97-T+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C4R-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@<F5P;&EE9"!T;R!T
M:&4@:6YV:71A=&EO;B!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT,38*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@:&%S('-E;G0@>6]U(&9R964O8G5S>2!I;F9O<FUA
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C(X-R!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,S$T"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&ES(&YO="!W<FET86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,S.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R
M97%U:7)E9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G
M<W1R("+!(&9I;6T@;>UN^G1N82!F<F5S=&DB"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3(S('!O+W1R86YS;&%T:6]N+G!H
M<#HQ,S4P"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C4X-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(%)U;B`G=')A;G-L871I;VX@97AT
M<F%C="<@9FER<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#(Q"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(')E<75E<W1S('EO=7(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C4P.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!R97%U97-T
M<R!Y;W5R('!R97-E;F-E(&%T("5S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8SHT"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R("(E9"!T:6P@)60@868@
M)60@<VME>71U;2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z-3$S"B,L('!H<"UF;W)M870*;7-G:60@(B5S('=I<VAE
M<R!T;R!A9&0@=&\@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3`R"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S('=I<VAE<R!T;R!M86ME('EO=2!A=V%R92!O9B`E<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HU,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O
M(')E8V5I=F4@=&AE(&QA=&5S="!I;F9O<FUA=&EO;B!A8F]U="`E<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HX.3$*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM
M<V=S='(@(DYE=&9A;F=A8O-K(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HX.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C@W-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HX.3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N
M<&AP.CDV"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<R"B,L('!H<"UF;W)M870*
M;7-G:60@(B<E<R<@:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C4U-`HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.CDR.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(G)7,G(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H
M92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1R
M964O5')E92YP:'`Z,38T"B,L('!H<"UF;W)M870*;7-G:60@(B<E<R<@=')E
M92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)R5S)R!W87,@861D
M960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W!E<FUS+V%D9&-H:6QD+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED("(G
M)7,G('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4U(&%D;6EN+W!E<FUS+V%D
M9&-H:6QD+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED("(G)7,G('=A<R!N
M;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3@V(&QI8B]";&]C:R]M971A<BYP:'`Z,3DQ"B,L('!H<"UF;W)M
M870*;7-G:60@(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$Y.0HC+"!P:'`M9F]R;6%T"FUS9VED("(L('9A
M<FEA8FQE(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C`V.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,3(X"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV
M.3$*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,3,R."!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,S,`IM<V=I
M9"`B+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]T:6UE+G!H<#HR,`HC+"!F=7IZ>0IM<V=I9"`B,3(@2&]U
M<B!&;W)M870B"FUS9W-T<B`B57!P;/US:6YG87(B"@HC.B!L:6(O0FQO8VLO
M=&EM92YP:'`Z,3D*(RP@9G5Z>GD*;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM
M<V=S='(@(E5P<&S]<VEN9V%R(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI
M;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]086=E<BYP:'`Z-CD*(RP@9G5Z>GD*;7-G:60@(CQ0<F5V:6]U
M<R(*;7-G<W1R(")&>7)R:2!B;&'P<^WP82(*"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HS-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB/&=E='1E>'0^('1A
M9R!N;W0@8VQO<V5D(&EN(&9I;&4@)7,N7&XB"B)/<&5N:6YG('1A9R!F;W5N
M9"!I;B!L:6YE("5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$Q-PIM<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D
M(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$V,`IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@;V-C
M=7)R960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z.3$W"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D
M('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,30R"FUS9VED(")!('!U8FQI8R!0
M1U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,#<T"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'
M4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T
M(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z.3DR"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y
M+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,#4*;7-G:60@(B(*(D$@<'5B
M;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3
M+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG
M;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!334E-12!K
M97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<*
M;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HX"FUS9VED(")!32!,:6=H="!286EN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.CD*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*;7-G:60@(D%-(%-H
M;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3$*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B04TO
M4$TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,3DY"FUS9VED(")!4$D@240B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM
M<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O:&5L<"]I;F1E>"YP:'`Z-3(*;7-G:60@(D%B;W5T+BXN(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M:61D
M;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HV-#`*;7-G:60@(D%C8V5P="!R97%U97-T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-C@Q"FUS9VED(")!8V-E<'1E9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C<P"FUS9VED(")!8V-E<W,@9&5N
M:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D
M96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW-0HC+"!F=7IZ>0IM<V=I9"`B06-C;W5N="!0
M87-S=V]R9"(*;7-G<W1R("),>6MI;&]R\"(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@IM<V=I9"`B06-C;W5N
M="!F<F]Z96XN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS,30*(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T<B`B
M2.9K:V%N9&DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C0U,0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C8R-0HC+"!F=7IZ>0IM<V=I9"`B06-T:6]N<R(*;7-G
M<W1R(")!\&=E<O`B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-30@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,S(*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]A9&0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D
M8VAI;&0N:6YC.C$V"FUS9VED(")!9&0B"FUS9W-T<B`B(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HR,30@861M:6XO9W)O=7!S+G!H<#HR,34*;7-G:60@(D%D
M9"!#:&EL9"!'<F]U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C@T(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M.#4*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!9&0@2&5R93HB
M"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,#@@861M:6XO9W)O
M=7!S+G!H<#HR,#D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW,R!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C<T"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I
M;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C
M:&EL9"YI;F,Z.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!G
M<F]U<"!T;R`G)7,G(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H
M:6QD+G!H<#HU,R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$S,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O
M("<E<R<B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@
M(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(Y"FUS9VED(")!9&0@8V]L=6UN
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI
M;F,Z,S4*;7-G:60@(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B061D('!A:7(B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA
M(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HV,S$*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HV,S<*;7-G:60@(D%D9"!T:&ES('1O
M(&UY(&-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B061D('1O
M(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B0N9T82#M(&YE=&9A;F=A8O-K("@E
M<RDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M-S@*(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS
M9W-T<B`B0N9T82#M(&YE=&9A;F=A8O-K("@E<RDB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HS,0IM<V=I9"`B061D('5S97(B"FUS9W-T<B`B(@H*(SH@861M:6XO
M=7-E<BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB061D960@)R5S
M)R!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L
M('-I9VYU<"!I;F9O<FUA=&EO;CH@)2(*(G,N(@IM<V=S='(@(B(*"B,Z('-I
M9VYU<"YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D960@)R5S)R!T
M;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HY-C(*;7-G:60@(D%D9&EN9R!N97<@
M9FEL97,@=&\@<F5P;W-I=&]R>3HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;F]A9&0N:6YC.C0*;7-G:60@(D%D9&EN9R!U<V5R<R!I
M<R!D:7-A8FQE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3<S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$T-#8*(RP@9G5Z>GD*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`B4V5N9&%N
M9&%N971F86YG(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S-@IM
M<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(DYE=&9A;F=A8O-K(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30*;7-G:60@
M(D%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ.2!S97)V:6-E<R]P
M;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED(")!9&UI;FES=')A=&EO;B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@R"FUS
M9VED(")!9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B069G:&%N
M:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06QB86YI82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")!;&=E<FEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M,#<*;7-G:60@(D%L:6%S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*;7-G:60@(D%L:6=N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N=#HB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C@W"FUS9VED(")!;&PB"FUS9W-T<B`B
MUFQL('-K97ET:2(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$Q."!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC
M871E9"!5<V5R<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S
M(&%D;6EN+V=R;W5P<RYP:'`Z,C$R"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HS."!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<W"FUS9VED(")!;&P@4&5R;6ES<VEO
M;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,0IM<V=I
M9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C,*;7-G:60@(D%L;&]W('-E='1I;F<@
M;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C0P.`IM<V=I9"`B06QR96%D
M>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$R,@IM<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y-@IM<V=I9"`B06QT97)N871E
M($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0X.`IM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*(RP@
M9G5Z>GD*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@
M(DYE=&9A;F<B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B
M06QT97)N871E('1E;7!L871E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C4*;7-G
M:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS
M9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I
M960N(@IM<V=S='(@(M-TYFMT(&=I;&1I('1I;&=R96EN="XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4U"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G
M:60@(D%N9V]L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;F=U
M:6QL82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#D*(RP@9G5Z>GD*;7-G:60@
M(D%N<W=E<B(*;7-G<W1R(")3=F%R8?`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!
M;G1A<F-T:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%N=&EG
M=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S
M+G!H<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z,S4*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+U5)+G!H<#HU."!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD
M97@N:'1M;#HV"B,L(&9U>GIY"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R
M(")!\&=E<O`B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@
M(D%P<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$S.0IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS
M9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O
M=F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.#(T"FUS9VED(")!<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-S<*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS
M9VED(")!<')I;"(*;7-G<W1R(")A<'+M;"(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3<U"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU
M.2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#$*;7-G:60@(D%R
M8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HV,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C@P"FUS9VED(")!<F-H:79E($YA;64B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHY"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A
M;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G
M<W1R(")%<G0@_OH@=FES<R!U;2!A\"#^^B!V:6QJ:7(@9V5R82#^971T83\B
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z.0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H
M('1O(&1E;&5T92`G)7,G(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS9W-T<B`B
M17)T(/[Z('9I<W,@=6T@8?`@_OH@=FEL:FER('3F;6$@_F5S<V$@;?9P<'4_
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU.`IM<V=I9"`B07)G96YT:6YA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ-S8*;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.`IM<V=I
M9"`B07)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%R=6)A(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34*;7-G
M:60@(D%S8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!<VEA
M+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT,34*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R
M92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$W"FUS9VED(")!<W-I9VYM
M96YT(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HR-#D*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HS,3@*;7-G:60@(D%T=&%C
M:&5D(&ES(&%N(&E#86QE;F1A<B!F:6QE(')E<&QY('1O(&$@<F5Q=65S="!Y
M;W4@<V5N="(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<U"FUS
M9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HS.`IM<V=I
M9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO
M;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z.3@*;7-G
M:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N
M+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*
M;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HU-S<*(RP@9G5Z>GD*;7-G:60@(D%T=&5N9&5E<R(*;7-G
M<W1R(")6:?!H96YG:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C0@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HV.`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@V
M"FUS9VED(")!='1R:6)U=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HS.#$*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q.`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS
M9W-T<B`BX6?Z<W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<F%L:6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B075S=')I82(*
M;7-G<W1R("+A9_IS="(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L
M+G!H<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER=7,N<&AP.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C
M:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,C(*
M;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]F
M='`N<&AP.C,V"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA
M8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O:6UA<"YP:'`Z-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER
M960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR
M8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-#0*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O
M(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B
M"FUS9W-T<B`B(@HB5FES='5N('5P<&MA<W1S:6YS(&UI<W3S:W-T+B!.973^
M:O-N;FEN;B!K;VT@;67P(&5F=&ER9F%R86YD:2!V:6QL=3H@)7,B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$X,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C(T
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!U
M<&1A=&4@=7-E<B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VUC86PN<&AP.C0V"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#
M04P@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z
M(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C@Y"B,L(&9U>GIY"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL
M960B"FUS9W-T<B`B16YD=7)V[7-U;B!M:7-H97!P8?!I<W0N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A
M:6QE9"X@)7,B"FUS9W-T<B`B16YD=7)V[7-U;B!M:7-H97!P8?!I<W0N(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B
M075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-C@*;7-G
M:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C@S"B,L(&9U
M>GIY"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R(")4:6QTYFMA
M<B!N971F86YG86+F:W5R.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-C$T"FUS9VED(")!=V%I=&EN9R!297-P;VYS
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I:F%N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I9"`B
M0D]&2"!%>&-U<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U
M;F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@Q"FUS9VED
M(")"860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O
M<R!U<V5R;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F%H
M86UA<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"86AR86EN(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<W"FUS9VED(")"
M86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS
M9VED(")"86YG;&%D97-H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@
M(D)A<F)A9&]S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(V,#@*;7-G:60@(D)A<F4B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C,Q"B,L('!H<"UF;W)M870*;7-G:60@(D)A<V4@9W)A
M<&AI8W,@9&ER96-T;W)Y("<E<R<@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S,*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G
M:60@(D)E;&%R=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F5L
M9VEU;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"B,L(&9U>GIY"FUS9VED(")"
M96QI>F4B"FUS9W-T<B`B4W3F<O`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"96YI
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"97)M=61A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS
M9VED(")":7)T:&1A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(V"B,L('!H<"UF;W)M870*;7-G:60@
M(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M.#D*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@*(RP@9G5Z>GD*;7-G:60@(D)O;&0B"FUS9W-T<B`B365G:6YM
MX6PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8R"FUS9VED(")";VQI=FEA(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#@*;7-G:60@(D)O;VMM87)K
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(P"B,L(&9U>GIY"FUS9VED(")";W)D97(B"FUS
M9W-T<B`B3?9P<'5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR,0HC+"!F=7IZ>0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R(")-
M]G!P=7(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V
M:6YA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-@IM
M<V=I9"`B0F]T:"(*;7-G<W1R(")"YO!I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HT."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B
M0F]T<W=A;F$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<U"B,L(&9U>GIY"FUS9VED(")";W1T
M;VTB"FUS9W-T<B`B0N;P:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O=79E="!)
M<VQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)A>FEL(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")"<FET:7-H($EN9&EA;B!/
M8V5A;B!497)R:71O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B
M0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C8V,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"=6EL9&EN9R!-3R!F
M:6QE<R!F;W(@;6]D=6QE("5S+BXN(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HV-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0G5I;&1I;F<@
M;&]C86QE("5S+BXN("(*;7-G<W1R(")">6=G:2!N^B!L;V-A;&4@)7,@+BXN
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I
M9"`B0G5L;&5T960@3&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED
M(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B
M0G5R=6YD:2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S<S"FUS9VED(")#35,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HW,@IM<V=I9"`B0U)#(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DW"FUS
M9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,30U"FUS9VED(")#86QE;F1A<B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$S"B,L
M(&9U>GIY"FUS9VED(")#86QM(@IM<V=S='(@(DCF='1A('9I\"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W
M"FUS9VED(")#86UE<F]O;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N(&YO="!R97-E="!P87-S=V]R
M9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z
M,C,U(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS,38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V%N861A(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,2!A9&UI;B]U<V5R+G!H<#HQ
M,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT
M-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8U
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ-"!T96UP
M;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3<*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O<F5M;W9E+FEN8SHQ-PIM<V=I9"`B0V%N8V5L(@IM<V=S='(@
M(DCF='1A('9I\"(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR-38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z
M-3(*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R
M9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C(U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN
M;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]$871A5')E92]$871A5')E92YP:'`Z,3$R(&9R86UE=V]R:R]$
M871A5')E92]$871A5')E92]S<6PN<&AP.C4X-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z
M-3$S"FUS9VED("(B"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I
M97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R
M("(*(G-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")#86YN;W0@<F]U
M=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8X"FUS9VED(")#87!E(%9E<F1E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*
M(RP@9G5Z>GD*;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`B5F%L<W1I;&QI;F=A
M<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,`IM<V=I9"`B0V%T96=O
M<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED
M(")#87EM86X@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#96QL(%!H;VYE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C4*;7-G:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Q
M"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E
M;&P@<W!A8VEN9SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(W-`IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED(")#96QT:6,@*$E33RTX.#4Y
M+3$T*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(V"B,L(&9U>GIY"FUS9VED(")#96YT97(B
M"FUS9W-T<B`B0OIA('1I;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-E;G1R86P@
M069R:6-A;B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$W.0IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM
M,BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV.3D*;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G
M:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P.`HC+"!F=7IZ>0IM<V=I9"`B0VAA9"(*;7-G<W1R(")%9FYI<_YRX?!U
M<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z-3DV"B,L(&9U>GIY"FUS9VED(")#:&%I<B!097)S;VXB"FUS9W-T<B`B
M4&5R<_-N=6QE9W0B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDW"FUS9VED(")#:&%N
M9V4B"FUS9W-T<B`B0G)E>71A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8V"B,L(&9U>GIY"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64@86YD(&%D
M9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L
M>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B(@HB2.ER(&=E='5R(/[Z
M(&)R97ET="#^=NT@:'9A\&$@;F%F;BP@;F5T9F%N9R!O9R!S:V5Y=&ES8F]T
M;B!K96UU<B!F<F%M(.T@(@HB<VME>71U;2#^[6YU;2XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(W"B,L(&9U
M>GIY"FUS9VED(")#:&%R(@IM<V=S='(@(D)R97ET82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I
M9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA
M:6YT96YA;F-E+V-O;F9I<FU?=&]P+FEN8SHQ,PIM<V=I9"`B0VAE8VL@=&AE
M(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M
M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B
M0VAI;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;F$B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@(D-H
M:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA
M;"`H0FEG-2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3
M:6=N=7`N<&AP.C(V.0IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.`HC
M+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B4V5M
M:F$@;OUT="!S:V5Y=&DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C0U,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C8R-@HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E
M(&%N(&%C=&EO;CHB"FUS9W-T<B`B5F5L9'4@8?!G97+P.B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR.#@*;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES
M<&QA>2!D871E<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E
M(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C8Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S
M<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C@U-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;&5A;FEN9R!U<"!03R!F:6QE<R!F;W(@;6]D=6QE("5S+BXN(@IM<V=S='(@
M(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HX-C<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0VQE86YI;F<@=7`@;&]C86QE("5S+BXN("(*;7-G<W1R(")(<F5I
M;G-A('1I;"#M(&QO8V%L92`E<R`N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B0VQE87(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT
M,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$V"FUS9VED(")#;&5A<B!U
M<V5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C,T"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@
M(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT
M96YA;F-E+VYO=&EC95]B;W1T;VTN:6YC.C8*;7-G:60@(D-L:6-K('1O($-O
M;G1I;G5E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C$X,PIM<V=I9"`B0VQI8VMA=&5L;"!V:6$@
M2%144"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I
M;F1O=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T,@IM
M<V=I9"`B0VQO=61S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS9VED(")#;&]U9',@16%R;'DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,34*(RP@9G5Z>GD*;7-G:60@(D-L;W5D>2(*;7-G<W1R(")!9G)I="(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C0*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z-`HC
M+"!F=7IZ>0IM<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R("),;VMA
M(&WV<'!U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR.`HC+"!F=7IZ>0IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E
M<G,B"FUS9W-T<B`B3&]K82!M]G!P=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O
M;&]M8FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@
M;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#;VQO<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP
M:'`Z,CDW"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H
M<#HR.3@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0W,B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4Q"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4R"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8X"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Y"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@U"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@V"FUS9VED
M(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C@U,`HC+"!F=7IZ>0IM<V=I9"`B0V]L;W5R('-E;&5C=&EO
M;B(*;7-G<W1R(")696QD=2!A\&=E<O`Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#8*;7-G:60@
M(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(X,PHC+"!F=7IZ>0IM<V=I9"`B0V]M:6-S(@IM<V=S='(@
M(E-E;6IA(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(U"FUS9VED(")#;VUM
M86YD(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I
M9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,S@*;7-G:60@(D-O;6UA;F0@;W!T:6]N<SHB"FUS9W-T<B`B(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.CDW"FUS9VED(")#;VUM86YD<SHB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,SDY
M"FUS9VED(")#;VUM96YT(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HQ,#`P"FUS9VED(")#;VUM:71T:6YG.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-@IM<V=I9"`B0V]M
M;6]N($YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*(RP@9G5Z>GD*;7-G
M:60@(D-O;6]R;W,B"FUS9W-T<B`B4V5M:F$B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"B,L(&9U>GIY"FUS9VED(")#
M;VUP86YY(@IM<V=S='(@(D%F<FET(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HV.3<*(RP@9G5Z>GD*;7-G:60@(D-O
M;7!L971E9"(*;7-G<W1R(")396UJ82(*"B,Z(&9R86UE=V]R:R]497AT7T9I
M;'1E<B]&:6QT97(O96UA:6QS+G!H<#HX,0HC.B!F<F%M97=O<FLO5&5X=%]&
M:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.#<*(SH@9G)A;65W;W)K+U1E>'1?
M1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.CDW"B,Z(&9R86UE=V]R:R]497AT
M7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HQ,#$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]M<&]S92!-97-S86=E("@E<RDB"FUS9W-T<B`B4V5M:F$@<VME
M>71I("@E<RDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S$*(RP@9G5Z
M>GD*;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R(")396UJ82(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C0W"FUS9VED(")#;VYD:71I;VYS(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C@Y"FUS9VED(")#;VYF:6=U
M<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ,S0*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F
M(&1A=&4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HY
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-PHC+"!F
M=7IZ>0IM<V=I9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R("),>6MI;&]R
M\"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-34@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C4*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O
M9B!T:&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,Q,`HC+"!F=7IZ>0IM<V=I9"`B0V]N;F5C=&EO;B!F86EL
M960N(@IM<V=S='(@(D5N9'5R=NUS=6X@;6ES:&5P<&'P:7-T+B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*(RP@9G5Z>GD*
M;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`B16YD=7)V[7-U
M;B!M:7-H97!P8?!I<W0N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-S<V"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U
M8FQI8R!K97ES97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C<W.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN
M96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O
M;CH@)7,@*"5S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C<V,@IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A
M:6QE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C4S"B,L(&9U>GIY"FUS9VED(")#;VYT86-T<R!W97)E
M('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS
M9W-T<B`B3F5T9F%N9VGP(%PB)7-<(B!V87(@8N9T="#M(&YE=&9A;F=A8O-K
M:6YA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU
M-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8P"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@)R5S)R(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.0IM<V=I9"`B0V]N=&EN=64B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]O:R!)<VQA;F1S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@HC+"!F=7IZ
M>0IM<V=I9"`B0V]O:VEE(@IM<V=S='(@(E-E;6IA(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED
M(")#;W!Y(@IM<V=S='(@(D%F<FET(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@HC+"!F=7IZ>0IM<V=I9"`B0V]P>2!S
M96QE8W1I;VXB"FUS9W-T<B`B5F5L9'4@8?!G97+P.B(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HQ,#@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W!Y:6YG("5S('1O("5S(@IM<V=S='(@(E1E;F=J87-T("5S(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V
M"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU,PIM<V=I9"`B0V]U;&0@;F]T(%!'
M4"!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C$P,S`*(RP@9G5Z>GD*;7-G:60@(D-O=6QD
M(&YO="!01U`@<VEG;B!M97-S86=E+B(*;7-G<W1R("+>^B#A='0@,2!N_71T
M('-K97ET:2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C,Y,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-#8W"FUS9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HQ.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C<P"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,
M1$%0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-34*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<R"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("<E<R<@=7-I;F<@
M1E10.B`E<R(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`X
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]P>2`E<R!T;R`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C,R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C@Q('!O+W1R86YS;&%T:6]N+G!H<#HQ
M,#<W"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@;&]C
M86QE(&1I<F5C=&]R>2!F;W(@;&]C86QE("5S.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3`R"FUS9VED(")#;W5L
M9"!N;W0@9&5C<GEP="!01U`@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,C(*;7-G:60@(D-O=6QD(&YO
M="!D96-R>7!T(%,O34E-12!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(T-0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T
M+B`E<R(*;7-G<W1R(")'870@96MK:2!E>71T('-K97ET=6T@9G+A("5S.B`E
M<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,S4U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")'870@96MK
M:2!E>71T('-K97ET=6T@9G+A("5S.B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T("<E<R<N(@IM<V=S
M='(@(D=A="!E:VMI(&5Y='0@<VME>71U;2!F<N$@)7,Z("5S(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.#$@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z.3,U"FUS9VED(")#;W5L9"!N;W0@9&5T97)M
M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HR.#(*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S
M(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-#DR"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@
M8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0U"FUS
M9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES
M=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV
M.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDN<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!L;V%D('-T<F%T96=Y("<E<R<N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HQ,3`*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!M:V1I<B`G)7,G+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW,#4*;7-G
M:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES
M97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C<V"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C$S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E
M;B`G)7,G(&9O<B!W<FET:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L
M92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y("<E<R<N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+T]B:F5C="YP:'`Z
M,C,X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R96%D("5S+B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM
M<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE
M(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL
M<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@
M861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,P.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS-#`*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S<W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X
M,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#D*
M;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-S,*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V
M92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(D=A="!E:VMI(&5Y='0@<VME
M>71U;2!F<N$@)7,Z("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HT.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C0S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE
M=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PIM<V=I9"`B0V]U;&0@
M;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"FUS9VED(")#;W5L9"!N
M;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<FUD:7(@)R5S)RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@
M)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS9VED
M(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I
M;VXZ("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.CDR"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('-E='5P
M('5P9W)A9&4@<V-R:7!T('1O.B`G)7,G+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<T"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO="!S879E('1H92!C;VYF
M:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@
M=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R
M(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z.#`*;7-G:60@
M(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('5N;&EN:R`G)7,G+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(Q.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,SDU"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U
M<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R("<E<R<Z
M("5S(@IM<V=S='(@(D=A="!E:VMI(&5Y='0@<VME>71U;2!F<N$@)7,Z("5S
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U-@IM<V=I9"`B0V]U;&1N
M)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I
M9&5B87(@:7,@;W!E;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD;B=T(&=I=F4@=7-E<B`G)7,G('1H92!F;VQL;W=I;F<@<FEG:'1S
M(&9O<B!T:&4@9F]L9&5R("<E<R<Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C0*(RP@9G5Z>GD*;7-G:60@(D-O=6YT
M960@=&5X="(*;7-G<W1R("),96GP<NET='5R('1E>'1I(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D-O=6YT<GDB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V-PIM
M<V=I9"`B0V]U<G-E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDW
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$*;7-G:60@(D-R
M96%T92(*;7-G<W1R(")"^F$@=&EL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W"B,L(&9U>GIY"FUS9VED
M(")#<F5A=&4@82!L:6YK(@IM<V=S='(@(D+Z82!T:6PB"@HC.B!T96UP;&%T
M97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDS"B,L(&9U>GIY"FUS9VED
M(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(D+Z82!T:6P@;OUJ82!M]G!P
M=2`H<G5S;&%K]G)F=2D@=6YD:7(@97ED9"!S:V5Y=&DB"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@HC+"!F=7IZ>0IM<V=I
M9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(D+Z82!T:6P@;?9P<'4B
M"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,S8@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HR,30*;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(S-`IM
M<V=I9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<Y"B,L(&9U>GIY"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(D+Z82!T:6PB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8X"FUS9VED(")#=6)A(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HR-@IM<V=I9"`B0W5R<F5N="!0:&%S92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,R!L:6(O0FQO8VLO=&EM92YP
M:'`Z,S`*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@5&EM92(*;7-G<W1R("),
M96GP<NET='5R('1E>'1I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4S"FUS9VED(")#=7)R96YT(%523"!I
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS9VED
M(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S-PIM<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ
M("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S
M+B(*;7-G<W1R(")3=&EL;&$@8?!G97+P:7(@<V5M(&5R=2!F<F%M:W;F;61A
M<B#^96=A<B#^^B!T96YG:7-T("5S+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV.`IM<V=I9"`B0WEP<G5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@R"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B0WER
M:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#0*;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])
M."U5*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#>F5C:"!297!U
M8FQI8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#(S('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED
M(")$1"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I
M;G1E;F%N8V4N<&AP.C4Y"B,L(&9U>GIY"FUS9VED(")$86EL>2(*;7-G<W1R
M("+:=&QI="(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I9"`B1&%T
M851R964@0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S.3<*;7-G:60@(D1A=&4B"FUS9W-T<B`B1&%G<R(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S"B,L(&9U>GIY"FUS9VED
M(")$871E(%)E8V5I=F5D(@IM<V=S='(@(DWS='1E:VGP(/YA;FXZ(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,0IM<V=I9"`B1&%T92!S96QE
M8W1I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(X,0HC+"!F=7IZ>0IM<V=I9"`B1&%Y(@IM<V=S='(@(FUA[2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS-0HC+"!F=7IZ>0IM<V=I9"`B1&5?;&5T92!#;VQU;6XB"FUS9W-T<B`B
M17GP82!M]G!P=2AM*2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HS.#4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0R,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C<V"FUS9VED(")$96-E;6)E<B(*;7-G<W1R(")D97-E;6)E
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,38*(RP@9G5Z>GD*;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*
M;7-G<W1R(")D97-E;6)E<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-C@U"B,L(&9U>GIY"FUS9VED(")$96-L:6YE
M9"(*;7-G<W1R(")%>71T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3@W(&QI
M8B]P<F5F<RYP:'`Z,3$Q"B,L(&9U>GIY"FUS9VED(")$969A=6QT(@IM<V=S
M='(@(D5Y\&$B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M
M96YT+FEN8SHT-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M
M96YT+FEN8SHX,0HC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!#;VQO<B(*;7-G
M<W1R(").;W1A('-JX6QF9V5F:?`@9VEL9&DB"@HC.B!F<F%M97=O<FLO261E
M;G1I='DO261E;G1I='DN<&AP.CDQ"FUS9VED(")$969A=6QT($ED96YT:71Y
M(@IM<V=S='(@(E-JX6QF9V5F:?`@:V5N;FEM87)K(@H*(SH@861M:6XO<&5R
M;7,O961I="YP:'`Z,3$Y(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,3DV"FUS9VED(")$969A=6QT(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3DW"FUS9VED(")$969A
M=6QT('!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS,PHC+"!F=7IZ>0IM<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T
M<B`B4VMI;&=R96EN:6YG(.$@<^UU<F5G;'4B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8T,PHC+"!F=7IZ>0IM<V=I
M9"`B1&5L96=A=&4@<&]S:71I;VXB"FUS9W-T<B`B4V5M:F$@;OUT="!S:V5Y
M=&DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C8Y,PHC+"!F=7IZ>0IM<V=I9"`B1&5L96=A=&5D(@IM<V=S='(@(D5Y
M='0B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<R(&%D;6EN+W!E<FUS+V1E;&5T
M92YP:'`Z-#8@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C(Y-2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C,Q-0HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,S
M,B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z-S`@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY
M,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$X,B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDY('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O9&5L971E+FEN8SHQ,PHC.B!T96UP;&%T97,O861M:6XO=7-E<B]L
M:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S='(@(D5Y\&$B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C$X.2!A9&UI;B]G<F]U<',N<&AP.C(Q-PHC+"!F
M=7IZ>0IM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@(D5Y\&$B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C8S(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z.#<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!097)M
M:7-S:6]N(@IM<V=S='(@(D5Y\&$@<VME>71U;2(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDS"B,L(&9U>GIY"FUS9VED(")$
M96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(D5Y9&0@<VME>71I
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU-PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E(&-E;&PB"FUS9W-T<B`B
M17GP82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C,*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!C;VQU;6XB"FUS
M9W-T<B`B17GP82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS9VED
M(")$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3`@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HS,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L
M971E('!E<FUI<W-I;VYS(&9O<B`G)7,G(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,S$W"B,L('!H<"UF;W)M870*;7-G
M:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@)R5S)R!A;F0@86YY('-U8BUP
M97)M:7-S:6]N<S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PHC+"!F=7IZ>0IM<V=I9"`B
M1&5L971E(')O=R(*;7-G<W1R(")%>?!A(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V1E;&5T96ED96YT:71Y+FEN8SHQ-0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E
M('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@(E9E;&1U(&ME;FYI(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8V"B,L(&9U>GIY"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN
M(@IM<V=S='(@(E-T:6QL82!N^G9E<F%N9&D@=.UM86)E;'1I+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M,@HC+"!F=7IZ>0IM<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O=R(*;7-G
M<W1R(")3=&EL;&$@;OIV97)A;F1I('3M;6%B96QT:2XB"@HC.B!A9&UI;B]P
M97)M<R]D96QE=&4N<&AP.C0X"FUS9VED(")$96QE=&4@=&AI<R!P97)M:7-S
M:6]N(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T("<E<R<N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-38R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3DT"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(R,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR-3(*(RP@9G5Z>GD*;7-G:60@(D1E;&EV97)Y('1I
M;64B"FUS9W-T<B`B17GP82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1E;FUA<FLB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HV-#(*;7-G:60@(D1E;GD@<F5Q=65S="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C0W,0IM<V=I9"`B1&5N>2!R97%U97-T(&9O<B!F<F5E+V)U<WD@:6YF;W)M
M871I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3$P
M('-E<G9I8V5S+W!R;V)L96TN<&AP.C$Q-"!S97)V:6-E<R]P<F]B;&5M+G!H
M<#HQ,C0*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M-38U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDS.`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,P"B,L(&9U>GIY
M"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R(")686QK;W-T:7(@;F]T86YD
M82(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DU"FUS9VED(")$
M971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DY"B,L(&9U>GIY"FUS
M9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES
M=')A=&]R+B(*;7-G<W1R("(B"B+>971T82!S:V5Y=&D@:&5F=7(@=F5R:?`@
M<V5N="!T:6P@:V5R9FES=6US:O-N87(@<V5M('1I;&MY;FYI;F<@=6T@<G5S
M;'#S<W0@(@HB*%-004TI+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ.34*;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C$U"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3(*;7-G:60@(D1E=R!0;VEN
M="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$Y-`IM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT('1O(&QE9G0B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*(RP@9G5Z>GD*;7-G:60@(D1I
M<F5C=&]R>2(*;7-G<W1R(")2]O!U;F%RX71T(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(U-@IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<*;7-G:60@
M(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R("+:=&QI='-S=&EL;&EN9V%R(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,PIM<V=I9"`B1&ES<&QA>2!F;W)E
M8V%S="`H5$%&*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.#(Q"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G
M<W1R("+:=&QI="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HQ
M.3`*;7-G:60@(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8Y"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,S$U"B,L(&9U>GIY"FUS9VED(")$;R!N;W0@9&5L971E(@IM
M<V=S='(@(D5N9'5R=F5K:F$B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP
M:'`Z,C0*;7-G:60@(D1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N
M8V4N<&AP(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N
M:6YC.C$Y('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$Y"FUS9VED(")$
M;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF
M('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*
M;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@
M(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S4*;7-G:60@(D1O=VYL;V%D(@IM
M<V=S='(@(E/F:VIA('EF:7(@X2!V:6YN=7-T]O`B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B4^9K:F$@)7,@>69I<B#A('9I;FYU
M<W3V\"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C4*;7-G:60@(D1O
M=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#<*
M;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B1')U9W,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,SDY"B,L(&9U>GIY"FUS
M9VED(")%+4UA:6PB"FUS9W-T<B`B4/-S=&UA<'!A(@H*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H
M<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@
M(D5C=6%D;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HR.30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-0HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,34@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<R
M"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,C(*;7-G:60@(D5D:70B
M"FUS9W-T<B`B0G)E>71A(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)
M+G!H<#HU,"!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(R"FUS9VED(")%
M9&ET($)L;V-K(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3@X
M(&%D;6EN+V=R;W5P<RYP:'`Z,C$V"FUS9VED(")%9&ET($=R;W5P(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-C(@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX-@IM<V=I9"`B161I="!097)M
M:7-S:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H
M<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')E9G,O87!P+FEN8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@
M9F]R.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R
M("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C(P-"!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(X,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`G)7,G(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0HC+"!F=7IZ>0IM<V=I9"`B
M161U8V%T:6]N(@IM<V=S='(@(D'P9V5R\"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@
M(D5G>7!T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B16P@4V%L
M=F%D;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"FUS9VED(")%;&5M96YT+BXN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$X-CD*;7-G:60@(D5M86EL(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38U('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHT,`IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R
M(").971F86YG(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DV,PHC
M+"!F=7IZ>0IM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM
M<V=S='(@(DYE=&9A;F<B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.3@Y"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C@P
M"B,L(&9U>GIY"FUS9VED(")%;6]T:6-O;G,B"FUS9W-T<B`B5F%L<W1I;&QI
M;F=A<B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P,0HC+"!F=7IZ>0IM<V=I9"`B16UP='D@;65S<V%G92XB"FUS
M9W-T<B`BP7+M\&%N9&D@<VME>71I(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HX.`HC+"!F=7IZ>0IM<V=I9"`B16UP='D@<F5S=6QT+B(*
M;7-G<W1R(")4YFUA(')U<VQA:_9R9G4B"@HC.B!F<F%M97=O<FLO4U%,+U-1
M3"]+97EW;W)D<RYP:'`Z,3$S"B,L(&9U>GIY"FUS9VED(")%;7!T>2!S96%R
M8V@@=&5R;7,B"FUS9W-T<B`B5.9M82!R=7-L86OV<F9U;?9P<'4B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,R"FUS9VED(")%;F%B;&4@:6YS97)T
M:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`W"FUS9VED
M(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C0T.`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C4U,PIM<V=I9"`B16YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(V,#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q
M-0IM<V=I9"`B16YD('EE87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%
M9&ET;W(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q
M,0IM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y
M;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*
M(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T
M/R<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE(&EM
M86=E(%523"!H97)E(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HQ,38S"B,L('!H<"UF;W)M870*;7-G:60@(D5N=')I97,Z("5D('1O=&%L
M+"`E9"!U<"UT;RUD871E+"`E9"!N97<L("5D(&-H86YG960L("5D('5N:VYO
M=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B17%U871O<FEA;"!'
M=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HT-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-34*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-B!S97)V:6-E<R]P;W)T86PO
M:6YD97@N<&AP.C<Y"FUS9VED(")%<G)O<B(*;7-G<W1R(")6:6QL82(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3DU
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M,C<X"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z,S0W"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('-E;F1I;F<@<F5P
M;'DZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(D5R<F]R('=I=&@@96UA
M:6P@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG("<E<R<N(@IM
M<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT,3,@<&\O=')A;G-L
M871I;VXN<&AP.C4R,B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,W-PHC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,30S."!P;R]T<F%N<VQA=&EO;BYP:'`Z,34P,0HC
M+"!F=7IZ>0IM<V=I9"`B17)R;W(Z("(*;7-G<W1R(")6:6QL82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM
M<V=I9"`B171H:6]P:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,R.0IM<V=I9"`B179E
M<GD@,34@;6EN=71E<R(*;7-G<W1R("+!(&MO<G1E<G,@9G)E<W1I(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.0HC+"!F=7IZ>0IM<V=I9"`B179E
M<GD@,B!M:6YU=&5S(@IM<V=S='(@(L$@9FEM;2!M[6[Z=&YA(&9R97-T:2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,C8@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,W-PIM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R("+!
M(#,P('-E:RX@9G)E<W1I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,R
M."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@P"FUS9VED(")%=F5R>2`U(&UI
M;G5T97,B"FUS9W-T<B`BP2!F:6UM(&WM;OIT;F$@9G)E<W1I(@H*(SH@9G)A
M;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HV,`HC+"!F=7IZ
M>0IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T<B`BP2!M[6[Z='4@9G)E<W1I
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S,`IM<V=I9"`B179E<GD@
M:&%L9B!H;W5R(@IM<V=S='(@(L$@:.%L9G3M;6$@9G)E<W1I(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,R-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S<X"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`BP2!M[6[Z='4@9G)E
M<W1I(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C@*;7-G:60@
M(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P:'!S:&5L
M;"YP:'`Z.#$@861M:6XO8VUD<VAE;&PN<&AP.C4P(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,C@*;7-G:60@(D5X96-U=&4B"FUS9W-T<B`B(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C(Y.2!P;R]T<F%N<VQA=&EO;BYP:'`Z,S(P('!O+W1R
M86YS;&%T:6]N+G!H<#HS-C(*(SH@<&\O=')A;G-L871I;VXN<&AP.C0T,2!P
M;R]T<F%N<VQA=&EO;BYP:'`Z-30Q('!O+W1R86YS;&%T:6]N+G!H<#HV,#$*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C<P,B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-S,W('!O+W1R86YS;&%T:6]N+G!H<#HW.3@*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C@W-2!P;R]T<F%N<VQA=&EO;BYP:'`Z.3DT('!O+W1R86YS;&%T:6]N
M+G!H<#HQ,#$V"FUS9VED(")%>&5C=71I;F<Z(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C,Y-`HC+"!F=7IZ>0IM
M<V=I9"`B17AP86YD(@IM<V=S='(@(D]P;F$@86QL87(B"@HC.B!T96UP;&%T
M97,O<&]R=&%L+W-I9&5B87(N:6YC.C,Q"B,L(&9U>GIY"FUS9VED(")%>'!A
M;F0@4VED96)A<B(*;7-G<W1R(")/<&YA(&WV<'!U(@H*(SH@9G)A;65W;W)K
M+U-13"]344PO2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP96-T960@)RDG
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H
M<#HQ-S4*;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A
M<F-H('1E<FTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,SDX"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S8*;7-G
M:60@(D5X<&]N96YT(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17AT<F%C=&EN9R!F<F]M("5S
M+BXN("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,Q"FUS9VED(")&1R!#;VQO<B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P"FUS9VED(")&5%`@
M=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]S<6PN<&AP.C(Q-@IM<V=I9"`B1F%I;&5D(')E=')I979I;F<@
M<')E9F5R96YC97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z-C`*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$
M05`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W-M8BYP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S
M97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z-C`S"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R
M;VT@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C8P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P
M>2!T;R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<V%S;"YP:'`Z.#<*;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!
M4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HV-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O
M(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-@IM<V=I9"`B1F%I<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<R"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV
M:6YA<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C,X
M"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HS-S4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0Q,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8V"FUS9VED(")&96)R=6%R>2(*;7-G<W1R(")F96)R^F%R(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,3@*;7-G:60@(D9E96QS($QI:V4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Y.`IM
M<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$W"FUS9VED(")&97<@4VAO=V5R
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ.`IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30T"FUS9VED(")&:65L
M9"!M871R:7@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEJ:2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C0*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-`HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M
M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#,*(RP@9G5Z>GD*;7-G:60@
M(D9I;&4@36%N86=E<B(*;7-G<W1R(")3:W+A<FYA9FXB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8S(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HX-0HC+"!F=7IZ>0IM<V=I9"`B1FEL92!.86UE
M(@IM<V=S='(@(E-K<N%R;F%F;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Y.3D*(RP@9G5Z>GD*;7-G:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S
M='(@(F5N9VEN(')E9VQA('9A;&EN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,30Y,0HC+"!F=7IZ>0IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T
M<B`B4F5I='5R(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z
M.#4S"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@V"FUS9VED(")&
M:6QT97)S(@IM<V=S='(@(E/M=7(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"B,L(&9U>GIY"FUS
M9VED(")&:6YL86YD(@IM<V=S='(@(D9I;FYA(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C$W,0HC+"!F=7IZ>0IM<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R
M(")&>7)S=&$@<^WP82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-S8*(RP@9G5Z>GD*;7-G:60@(D9I<G-T(%%U87)T
M97(B"FUS9W-T<B`B1GER<W1A('/M\&$B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,Y"FUS9VED(")&:7@@<F%T:6\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(Q-`IM<V=I9"`B1FQI<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,R"FUS9VED(")&
M;&]A="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F]G(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z,34X(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HQ,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O
M97,@;F]T(&5X:7-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L;W(B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS9VED(")&
M;V]D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R;W=S97)S
M('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,S(*;7-G:60@(D9O<F5C87-T("A4048I(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW.`IM
M<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE
M9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L
M87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K
M*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDU
M"FUS9VED(")&;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,Y.0HC+"!F=7IZ>0IM<V=I9"`B
M1F]R;7,B"FUS9W-T<B`B1G+A(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C(Q"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM<V=I9"`B1F]R='5N97,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y"FUS9VED
M(")&;W)T=6YE<R`R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS.3`*(RP@9G5Z>GD*;7-G:60@(D9O<G5M<R(*;7-G<W1R(")-
M]G!P=7(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3`V"B,L(&9U
M>GIY"FUS9VED(")&;W)W87)D<R(*;7-G<W1R("+!9G)A;7-E;F1A(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C$T-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1F]U;F0@87!P;&EC871I;VYS.B`E<R(*;7-G<W1R("(B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,30U,@IM<V=I9"`B1F]U;F0@9&ER96-T;W)I97,Z(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C`*(RP@9G5Z>GD*;7-G:60@(D9R(@IM<V=S='(@(D9RX2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S,*(RP@9G5Z>GD*;7-G:60@(D9R86UE<R(*;7-G<W1R(").869N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,PHC+"!F=7IZ>0IM<V=I9"`B1G)A;F-E(@IM<V=S='(@(DCF='1A
M('9I\"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I
M9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT,3<*(RP@9G5Z
M>GD*;7-G:60@(D9R964O0G5S>2!);F9O<FUA=&EO;B(*;7-G<W1R(")5<'!L
M_7-I;F=A<B!N973^:O-N<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-#(W"FUS9VED(")&<F5E+T)U<WD@4F5P;'DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HT,C(*;7-G:60@(D9R964O0G5S>2!297%U97-T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z,C<R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z,S0Q"FUS9VED(")&<F5E+T)U<WD@4F5Q=65S="!297-P;VYS
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDQ
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")&<F5N8V@@4&]L>6YE
M<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O
M=71H97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB"FUS
M9W-T<B`B1G+A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q
M-0HC+"!F=7IZ>0IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@(D9RX2(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"B,L(&9U>GIY"FUS
M9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(E-K:6QG<F5I;FEN9R#A
M('/M=7)E9VQU(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@R(&QI8B]";&]C
M:R]M;V]N+G!H<#HQ.#$*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,Y"B,L(&9U>GIY
M"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`B3F%F;B(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HV-3<*;7-G:60@(D9U>GIY(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I
M9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U
M"FUS9VED(")'86UB:6$B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#
M;VYF:6=U<F%T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S
M971U<"]C;VYF:6<N:'1M;#HQ,`IM<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS
M9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0W.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")'96YE<F%T:6YG('-T871U<R!F;W(@;6]D=6QE("5S+BXN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R("(B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,W,0IM<V=I9"`B1V5T;W!T($5R<F]R
M.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VAA;F$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<U"B,L(&9U
M>GIY"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(E-K<N%R;F%F;B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$R"FUS9VED(")';R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O961E
M;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q"B,L
M(&9U>GIY"FUS9VED(")';V]G;&4@4V5A<F-H(@IM<V=S='(@(DQE:71A(.T@
M<VME>71U;2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR,C`*;7-G:60@(D=R87ES8V%L92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-@IM<V=I9"`B1W)E96-E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@U"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W)E96YL86YD(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S0*(RP@9G5Z>GD*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B
M169N:7/^<N'P=7(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W,`IM<V=I9"`B
M1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+G!H<#HU.`IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B
M92!N;VXM96UP='DB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP
M:'`Z,C`Q(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C<W"FUS9VED
M(")'<F]U<"!P97)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M
M<R]E9&ET+G!H<#HQ-S8@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR
M-3`*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED
M(")'=6%T96UA;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<&5R;7,O961I="YP:'`Z,3(W(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,C`U"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*;7-G
M:60@(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E
M<FUS+V5D:70N<&AP.C$R."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C(P-@IM<V=I9"`B1W5E<W0@<&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P-PIM<V=I9"`B1W5E<W1B;V]K
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(D=U:6YE
M82(*;7-G<W1R(")J^F[M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=6EN96$M
M0FES<V%U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HS,S$*;7-G:60@(DA((@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.CDV,`IM<V=I9"`B2%1-3"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@U"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T
M92!T:&4@;&%S="!C96QL(&EN(')O=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I
M9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA
M<W0@8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R
M;W<@:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:'1T<"YP:'`Z,34W"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(86ET
M:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HS.3D*;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS9VED(")(
M87IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDQ
M.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,V"FUS9VED(")(96%D97(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@
M86YD($UC1&]N86QD($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#8*;7-G:60@(DAE8G)E=R`H25-/+3@X-3DM."U)*2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,T"FUS9VED(")(96EG:'0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$W."!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3@U"B,Z('-E<G9I8V5S+VAE;'`O:6YD
M97@N<&AP.C$W('1E;7!L871E<R]H96QP+VEN9&5X+FEN8SHS"FUS9VED(")(
M96QP(@IM<V=S='(@(DAJX6QP(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W-@HC
M+"!F=7IZ>0IM<V=I9"`B2&5L<&5R(@IM<V=S='(@(DAJX6QP(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.CDU"FUS9VED("(B"B)(96QP97(@87!P;&EC871I
M;VX@=&\@8W)E871E(&%N9"!M86EN=&%I;B!T<F%N<VQA=&EO;G,@9F]R('1H
M92!(;W)D95QN(@HB9G)A;65W;W)K(&%N9"!I=',@87!P;&EC871I;VYS+EQN
M(@HB1F]R(&%N(&EN=')O9'5C=&EO;B!R96%D('1H92!F:6QE(%)%041-12!I
M;B!T:&ES(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$W('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C$W"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@
M=&AE(&9I;&4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")(:6=H(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](:7-T;W)Y+TAI<W1O<GDN<&AP.C,R,0IM<V=I9"`B2&ES
M=&]R>2!E;G1R>2!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D
M;6EN+V-O;6UO;BUH96%D97(N:6YC.C0*;7-G:60@(DAO7VUE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6871I8V%N($-I
M='D@4W1A=&4I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,30R-@IM<V=I9"`B2&]M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-34*(RP@9G5Z>GD*;7-G
M:60@(DAO;64@061D<F5S<R(*;7-G<W1R(")396YD86YD86YE=&9A;F<B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"B,L
M(&9U>GIY"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(E3M;6%B96QT:2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<X"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8R"FUS9VED(")(;W)D92(*;7-G<W1R
M("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,R.0IM<V=I9"`B2&]R9&4@
M=')A;G-L871I;VX@9V5N97)A=&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z-#(P"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN
M(&UE<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HR-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#$S"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E
M<R!F;W5N9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z,3(P.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB
M)7-<(B(*;7-G<W1R(")-87!P86X@7"(E<UPB('9A<B!E;F1U<FYE9FYD(%PB
M)7-<(BXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q-30*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!3=6-C97-S
M9G5L;'D@<WEN8VAR;VYI<V5D("5S(%PB)7-<(B(*;7-G<W1R(")<(B5S7"(@
M=F%R(&=E<O`@=FER:R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,C(S"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN
M92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0X,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N
M97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R,#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0U
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O
M(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,34Q"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN
M8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C$R.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,S$X
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H
M87)E(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX,@IM<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I
M9"`B2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y
M;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,Z,C@*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L
M=6UN<RD@87)E('1H97)E/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@
M;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R.`IM<V=I9"`B2'5M:61I='DB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R
M,0IM<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<R(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER<W%L+G!H<#HR,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!
M4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C$T(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER<W%L+G!H<#HR.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<Y(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,R,`HC+"!F
M=7IZ>0IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R(")396YD86YD86YE=&9A
M;F<B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C<W"FUS
M9VED("))4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0
M($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y-`IM<V=I9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-@IM<V=I9"`B26-O;G,@
M3VYL>2(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C<*;7-G:60@(DEC;VYS('=I
M=&@@=&5X="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3@P"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@(DME;FYI;F%F
M;CHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.#8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L87EE9"!C
M;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0U"FUS9VED("(B
M"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%
M>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O
M('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ-3@*;7-G:60@
M(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE
M(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y
M960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*;7-G
M:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM
M86=E(%523"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM86=E(%52
M3#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A
M;&QE<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M
M(&=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$W-C4*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$P('1E;7!L871E
M<R]D871A+V1A=&5M87`N:6YC.C$P"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z-3<@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(P"B,L('!H<"UF;W)M870*
M;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C<S"FUS9VED("));7!O<G1E9"!F:65L
M9',Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-S`Q"FUS9VED("));B!0<F]C97-S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,T
M"FUS9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,Q"B,L(&9U>GIY"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD
M+V]R('!A<W-W;W)D+B(*;7-G<W1R(")3;.'P=2!I;FX@;F]T86YD86YA9FX@
M;V<@;'EK;&EO<O`B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU
M,0IM<V=I9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A
M9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T
M<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS
M9VED("));F-R96%S92!);F1E;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q
M"FUS9VED("));F1I82(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E9&ET
M+G!H<#HQ-#$@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@
M(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"B,L
M(&9U>GIY"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`B96YG:6YN(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PHC+"!F
M=7IZ>0IM<V=I9"`B26YF;R(*;7-G<W1R(")(=6YD<V$B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C0S"B,L(&9U>GIY"FUS9VED("));F9O<FUA
M=&EO;B(*;7-G<W1R(")5<'!L_7-I;F=A<B(*"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HU.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YI=&EA;&EZ:6YG(&UO
M9'5L92`E<RXN+B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED("));G-E<G0@
M0U]O;'5M;B!!9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*(RP@9G5Z>GD*
M;7-G:60@(DEN<V5R="!);6%G92(*;7-G<W1R(")3:V5Y=&D@<V5M(&+Z:?`@
M97(@8?`@<W9A<F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`P"FUS9VED("));G-E<G0@5&%B;&4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM
M<V=I9"`B26YS97)T(%=E8B!,:6YK(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PIM<V=I
M9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM
M<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O
M;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8T"FUS9VED("));G-E<G0@82!N97<@8V]L
M=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q
M"FUS9VED("));G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@
M8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G
M:60@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H
M(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z,34P"FUS9VED("));G-E<G0@86QT97)N871E('1E
M;7!L871E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,CD*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO
M=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4X"FUS9VED("));G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Y
M"B,L(&9U>GIY"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`B
M3?-T=&5K:?`@9GER:7(Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A
M9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8U"FUS9VED("));G-E<G0@8V]L=6UN(&)E
M9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HY,`HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(&UE<W-A9V5S
M(@IM<V=S='(@(E-K97ET:2!S96T@8OII\"!E<B!A\"!S=F%R82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M-`IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#,*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R,`IM<V=I9"`B26YS97)T('1H92!R
M97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(V"FUS9VED("));G-E<G0O36]D:69Y($EM86=E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#D*
M;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I
M9"`B26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB
M=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S0*;7-G:60@(DEN<W5F9FEC:65N
M="!C<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$P-S4*;7-G:60@(DEN=&5G97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3$S,PIM<V=I9"`B26YT96=E<B!L:7-T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z,C@S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z,S4R"FUS9VED("));G9A;&ED($%C=&EO;B!S96QE8W1E
M9"!F;W(@=&AI<R!C;VUP;VYE;G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-@IM<V=I9"`B
M26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A
M<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED(&)A
M=&-H($E$+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,#@W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-3@*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C(S,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,CDW"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.3D*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B
M>"YP:'`Z.#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP
M:'`Z,3`P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP
M.C(R,`IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#8*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM
M<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDU"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C0S"FUS9VED
M("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*
M;7-G:60@(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z("<E<R<B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,#0S(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(R,`IM<V=I9"`B26YV86QI9"!S:&%R
M92!O8FIE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED("));G9A;&ED('-O=7)C
M92!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*;7-G:60@(DEN=F%L:60@=6YI
M8V]D92!D871A+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S(R"FUS9VED("));G9E;G1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@R"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#`*(RP@9G5Z>GD*;7-G:60@(DER96QA;F0B"FUS9W-T<B`B
M169N:7/^<N'P=7(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M-0IM<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@(DES;VQA=&5D
M(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27-R
M865L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C(U"FUS9VED("))<W-U97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))=&%L
M:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))=&%L>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W
M-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*
M;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B:F%N^F%R(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S
M"FUS9VED(")*87!A;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X-PIM<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,@IM<V=I9"`B
M2F5R<V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F]R9&%N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HS.#`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@(FKZ;.TB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<Y"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,38*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N
M92(*;7-G<W1R(")J^F[M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3<*;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-`IM
M<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V"FUS9VED(")*
M=7-T:69Y(%)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B
M2V%Z86MH<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C0V"FUS9VED(")+965P(&]R:6=I;F%L/R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DME;GEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#4*;7-G:60@
M(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED(")+
M97)N96P@3F5W8FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HS.3<*;7-G:60@(DME>2!#<F5A=&EO;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,#`*;7-G
M:60@(DME>2!&:6YG97)P<FEN="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HS.3@*;7-G:60@(DME>2!,96YG=&@B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,SDW
M"FUS9VED(")+97D@5'EP92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.`HC+"!F=7IZ>0IM<V=I9"`B2V5Y(%5S
M86=E(@IM<V=S='(@(E-K97ET:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C<R-@IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,CD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@T"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#4*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC
M(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E
M<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@X"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@V"FUS9VED(")+=7=A:70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S
M"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M;W)T86PO;65N=2YI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B3&%?>6]U="(*;7-G
M<W1R(")!9G1E;F=J87-T(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHW-B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C4W"FUS9VED("),86YG=6%G92(*
M;7-G<W1R(")4=6YG=6WA;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&%O(%!E
M;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C$W-`HC+"!F=7IZ>0IM<V=I9"`B3&%S="!(86QF
M(@IM<V=S='(@(G/M\&%S=&$@8FQS+B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HX."!L:6(O0FQO8VLO;6]O;BYP:'`Z.3`*(RP@9G5Z>GD*;7-G:60@(DQA
M<W0@475A<G1E<B(*;7-G<W1R(")S[?!A<W1A(&)L<RXB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$T.0IM<V=I9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R
M(")S[?!A<W0@=7!P9N9R=#HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HV-C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS
M9W-T<B`B4^WP87-T('1E;F=S=#H@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HV-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@
M)7,@9G)O;2`E<R(*;7-G<W1R(")3[?!A<W0@=&5N9W-T.B`E<R!F<N$@)7,B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HV-C,*;7-G:60@(DQA<W0@
M;&]G:6XZ($YE=F5R(@IM<V=S='(@(E/M\&%S="!T96YG<W0Z($%L9')E:2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(DQE='1L86YD
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED("),87<B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<Y"FUS9VED("),87EO=70B"FUS9W-T<B`B1G)A;7-E=&YI
M;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R("),[6)A
M;F]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C8Y"FUS9VED("),969T(@IM<V=S='(@(E9I;G-T<FDB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(S"FUS9VED("),969T(&AE861E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$Y
M"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*
M;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED
M("),:6)E<FEA(@IM<V=S='(@(DSM8F5R[6$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G
M:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@X"FUS9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED("),
M:6=H="!$<FEZ>FQE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(S"FUS9VED("),:6=H="!286EN(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(T"FUS9VED("),:6=H="!286EN($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),
M:6=H="!286EN($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*;7-G:60@(DQI9VAT(%)A:6X@4VAO
M=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HR.`IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM<V=I9"`B3&EG
M:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0U"FUS9VED("),:6UE<FEC:R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#$X"FUS9VED("),:6YK(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU-@IM<V=I9"`B3&EN:R!P;VEN=',@=&\Z(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S4*;7-G:60@(DQI;FL@
M=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I
M<W!L87EI;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R
M+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,PIM<V=I9"`B3&EN:W,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0V"FUS9VED("),:6YU
M>"!#;V]K:64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.#8*;7-G:60@(DQI<W0@+2!U<V5R(&-A;B!S964@
M=&AE(&9O;&1E<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3,P"FUS9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]H96QP+VEN9&5X+G!H<#HU,`IM<V=I9"`B3&ES="!(96QP(%1O<&EC
M<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(Y"FUS9VED
M("),:7-T(%1A8FQE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4Y-`IM<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3@Y
M"B,L(&9U>GIY"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`B2&KA;'`B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-@IM<V=I9"`B
M3&ES="U)9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE
M861E<G,N<&AP.C4Y,@IM<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,PIM<V=I9"`B
M3&ES="U0;W-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M2&5A9&5R<RYP:'`Z-3DQ"FUS9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,`IM
M<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C0*;7-G:60@(DQI<W1I;F<@=7-E
M<G,@:7,@9&ES86)L960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT-PIM<V=I9"`B3&ET97)A='5R92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R("),:71HX65N(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C$S,S@*;7-G:60@(DQO861I;F<@;&EB
M<F%R:65S+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEM86=E<RYP:'`Z.#,*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W.`IM<V=I
M9"`B3&]C86P@=&EM93H@(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX,PIM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3<P(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-`HC.B!L:6(O0FQO8VLO<W5N
M<FES92YP:'`Z,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HV,PHC+"!F=7IZ>0IM
M<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B0?!G97+P(@H*(SH@;&]G:6XN<&AP
M.C$U-2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,38T('1E;7!L871E
M<R]L;V=I;B]M;V)I;&4N:6YC.C,*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL
M92YI;F,Z,34@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B
M3&]G(&EN(@IM<V=S='(@(E1E;F=J87-T(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C$U.`IM<V=I9"`B3&]G(&]U="(*;7-G<W1R("+:='-K
M<N$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W"FUS9VED("),;V=I
M;B!487-K<R(*;7-G<W1R(")697)K969N:2!V:?`@=&5N9VEN9W4B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HY,3$*(RP@9G5Z>GD*;7-G:60@(DQO
M9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@
M=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@(B(*(E1E;F=I;F<@
M;6ES=/-K<W0N($SM:VQE9V$@97(@;F]T86YD86YA9FX@_FET="!E\&$@;'EK
M:6QO<O`@<F%N9W0@:6YN<VQE9VGP+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.CDP-PHC+"!F=7IZ>0IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G
M<W1R(")%;F1U<G;M<W5N(&UI<VAE<'!A\&ES="XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,S<P"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED("),;W9E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8S"FUS9VED("),;W<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B
M3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED
M("),;W=E<B!L871I;B!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3<*;7-G
M:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@Y"FUS9VED("),=7AE;6)O=7)G(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-#(*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W,PHC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C4P"FUS9VED(")-3U1$(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,V"FUS9VED
M(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA8V%O(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,0IM<V=I9"`B36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,34Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B
M36%D86=A<V-A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#D*;7-G:60@(DUA9VEC(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HW.`IM<V=I9"`B36%I;"(*;7-G<W1R(")6969P\W-T
M=7(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8W"FUS9VED(")-
M86EL($%D;6EN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`IM<V=I9"`B36%K92!L:6Y?
M:RXN+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,U-PIM
M<V=I9"`B36%K92!S=7)E('1H870@>6]U(&AA=F4@4$5!4B!I;G-T86QL960@
M86YD(&EN('EO=7(@:6YC;'5D92!P871H+B(*;7-G<W1R("(B"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z-C<X('!O+W1R86YS;&%T:6]N+G!H<#HQ,#<T"B,L
M('!H<"UF;W)M870*;7-G:60@(DUA:VEN9R!D:7)E8W1O<GD@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QA=VDB"FUS9W-T<B`B36%L
M87;M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-86QA>7-I82(*;7-G<W1R(")-
M86QA[7/M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T
M<B`B1W+F;FCV9O!A97EJ87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA;&DB
M"FUS9W-T<B`B36%L[2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L=&$B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ"FUS9VED("(B
M"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L
M86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@=VET
M:"!T:&]S92!C871E9V]R:65S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`T,`IM<V=I9"`B36%P,C0@
M;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HY-S@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$P-34*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<V
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3,*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM
M<V=I9"`B36%R8V@B"FUS9W-T<B`B;6%R<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*;7-G:60@(DUA<F=I
M;B(*;7-G<W1R(")3<.%S<^UA(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@(DUA<FL@=VET:"!3965N+U5N<V5E
M;B!F;&%G<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L86=S
M("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(DUA<G-H
M86QL97EJ87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,3$*(RP@
M9G5Z>GD*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R(")3=N;P:2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%U<FET86YI82(*;7-G<W1R(")-X7+M
M=&%N[6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,30*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`W"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#0*;7-G:60@(DUA
M>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(Y-@IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S
M.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DX
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3<*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(S.0IM<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C,W.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#$U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-CD*;7-G:60@(DUA>2(*;7-G<W1R(")M8>TB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"B,L
M(&9U>GIY"FUS9VED(")-87EO='1E(@IM<V=S='(@(FUA[2(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HU,S$*;7-G:60@(DUE971I;F<@0V%N8V5L;&%T:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M-3`S"FUS9VED(")-965T:6YG($EN9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3`Y
M"FUS9VED(")-965T:6YG(%!R;W!O<V%L(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3(U"FUS9VED
M(")-965T:6YG(%)E<&QY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3$T"FUS9VED(")-965T:6YG
M(%5P9&%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C4Q.0IM<V=I9"`B365E=&EN9R!5<&1A=&4@
M4F5Q=65S="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V5D:70N:6YC.C$Y"FUS9VED(")-96UB97)S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C@*;7-G:60@(DUE;G4@;6]D93HB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T<B`B(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C4R-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")-97)G:6YG(&%L;"`E<RYP;R!F:6QE<R!T;R!T:&4@8V]M<&5N9&EU;2XN
M+B`B"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0S.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")-97)G:6YG(&QO8V%L92`E<RXN+B`B"FUS9W-T
M<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C<X.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")-97)G:6YG('1H92!03R!F:6QE(&9O<B`E<R!T;R!T:&4@8V]M
M<&5N9&EU;2XN+B`B"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C0R-0HC+"!P:'`M9F]R;6%T"FUS9VED(")-97)G:6YG('1R86YS;&%T:6]N
M(&9O<B!M;V1U;&4@)7,N+BXB"FUS9W-T<B`B4V%M96EN82#^_?!I;F=A<B!F
M>7)I<B`E<R!E:6YI;F=U;F$N+BXB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T
M:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"FUS9VED
M(")-97-S86=E(@IM<V=S='(@(E-K97ET:2(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,C$V"FUS9VED("(B"B)-97-S86=E(%9E<FEF
M:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E
M(&-O=6QD(&YO="!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS
M9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38X"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`Q"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M-3D*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E871H97(B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO
M8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ,3`*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B
M;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T
M<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C<@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HW,0IM<V=I9"`B365T:&]D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]24$,O4E!#+WAM;')P8RYP:'`Z.#$@9G)A;65W;W)K+U)00R]24$,O<V]A
M<"YP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"`G)7,G(&ES
M(&YO="!D969I;F5D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HW,R!L:6(O0FQO8VLO;65T87(N<&AP.C<S"FUS9VED(")-
M971R:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-97AI8V\B
M"FUS9W-T<B`B365X[6OS(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O;F5S
M:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B3>UK<O-N97/M82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW-@IM<V=I9"`B36ED9&QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#@*;7-G:60@
M(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,P,`IM<V=I9"`B36EN('1E;7`@;&%S="`V(&AO
M=7)S.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(Q-PIM<V=I9"`B36ER<F]R(@IM<V=S='(@(E-P96=L
M82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM<V=I9"`B36ES8V5L
M;&%N96]U<R(*;7-G<W1R("+=;6ES;&5G="(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<Q"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,S.0IM<V=I9"`B36ES
M<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$T"FUS9VED("(B"B)-:7-S:6YG
M(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I
M9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`S"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@240N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M
M='`N<&AP.C4W"FUS9VED(")-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G
M92!-86EL+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*;7-G:60@(DUI<W-I;F<@<V5S<VEO
M;B!)1"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`B3>$B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S$*;7-G:60@(DUO8FEL92!-86EL
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8T"FUS9VED(")-;V1E<F%T92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8V(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HX.`IM<V=I9"`B36]D:69I960@1&%T92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3(*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B
M0G)E>71A('-L\_`B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C4W"FUS9VED
M(")-;V1U;&4B"FUS9W-T<B`B16EN:6YG(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV-S,*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R
M(")-\VYA:_,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V,#(*;7-G:60@
M(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN
M=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-;VYT<V5R<F%T(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P"FUS9VED(")-;W-T;'D@
M0VQE87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S$*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*
M;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT,C@*;7-G:60@(DUO=F4@1&]W;B(*
M;7-G<W1R(")&;'ET:F$@;FGP=7(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HT,S(*(RP@9G5Z>GD*;7-G:60@(DUO=F4@3&5F="(*
M;7-G<W1R(")&;'ET:F$@=7!P(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z-#,V"FUS9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C0R-`IM<V=I
M9"`B36]V92!5<"(*;7-G<W1R(")&;'ET:F$@=7!P(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Y-PHC+"!F=7IZ>0IM<V=I
M9"`B36]V92!D;W=N(@IM<V=S='(@(F;F<F$@;FGP=7(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#DV"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.3<*(RP@9G5Z>GD*;7-G
M:60@(DUO=F4@=7`B"FUS9W-T<B`B9N9R82!U<'`B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*
M;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C$X-`IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D;W=N
M(&QI<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(R-#(*;7-G:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(X(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS,S4*;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HU,0IM<V=I9"`B37D@4&]R
M=&%L(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HQ
M,C0*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M86EN=&5N86YC92]A9W)E96UE;G1?8F]T=&]M+FEN8SHW"FUS9VED(").
M3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,SDW(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&YE9BYP:'`Z,S@*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HU.#,*;7-G:60@(DYA;64B"FUS9W-T<B`B3F%F;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-S`V"B,L(&9U>GIY
M"FUS9VED(").965D<R!!8W1I;VXB"FUS9W-T<B`B0?!G97+P(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDW"B,L(&9U>GIY"FUS9VED(").97!A;"(*;7-G<W1R(")._7(@</-S
M='5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").971H97)L86YD<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.#$*;7-G:60@(DYE='-C87!E($)A<V4@55),(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED(").
M971S8V%P92!#02!2979O8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A
M<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@4F5N97=A
M;"!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.#(*;7-G:60@(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3@V"FUS9VED(").971S8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G
M:60@(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#`*;7-G:60@
M(DYE='-C87!E(&-E<G1I9FEC871E('1Y<&4B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S-@HC+"!F=7IZ>0IM<V=I9"`B3F5T
M=V]R:R(*;7-G<W1R(")._71T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,C4*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,W-@IM<V=I9"`B3F5V97(B"FUS9W-T<B`B
M06QD<F5I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").97<@0V%L961O;FEA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA
M;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C(W"FUS9VED(").97<@0V%T96=O<GDB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV
M."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<Y"B,L(&9U>GIY"FUS9VED(").97<@
M36]O;B(*;7-G<W1R(")._7(@</-S='5R(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I
M;VYA;"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"B,L(&9U>GIY"FUS9VED
M(").97<@6F5A;&%N9"(*;7-G<W1R(")._7(@</-S='5R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W
M('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3(*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(U.`HC+"!F=7IZ>0IM<V=I9"`B3F5W<R(*
M;7-G<W1R(")._71T(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Y
M,@IM<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9&%T82]T<W9I;F9O+FEN8SHR,2!T96UP;&%T97,O9&%T82]D871E;6%P+FEN
M8SHT-@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$S-R!T96UP;&%T
M97,O9&%T82]C<W9I;F9O+FEN8SHS,@IM<V=I9"`B3F5X="(*;7-G<W1R(").
MYG-T82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PHC+"!F=7IZ>0IM<V=I
M9"`B3F5X="!0:&%S92(*;7-G<W1R(").YG-T82!S[?!A(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C@@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HS-S(*(RP@9G5Z>GD*;7-G:60@(DYE>'0@;W!T:6]N<R(*
M;7-G<W1R(")686QK;W-T:7(@;F]T86YD82(*"B,Z(&9R86UE=V]R:R]522]5
M22]086=E<BYP:'`Z,3`S"B,L(&9U>GIY"FUS9VED(").97AT/B(*;7-G<W1R
M(").YG-T82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEC87)A9W5A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B3FEG97(B"FUS
M9W-T<B`B06QD<F5I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<FEA(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3,*
M;7-G:60@(DYI9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B
M3FEU92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.#@X"FUS9VED(").;R(*;7-G<W1R(").96DB"@HC.B!T
M96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.C$V"FUS9VED(").;R!A
M=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC
M97,@9F]R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(N<&AP.C$P-0IM<V=I9"`B3F\@879A:6QA8FQE('-T<F%T
M96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS
M9VED(").;R!B871C:"!T96UP;&%T92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-SD@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z,C,P"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C(U,@IM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H
M92!R97%U97-T960@<&]S:71I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]M8V%L+G!H<#HU,`IM<V=I9"`B3F\@8V%L96YD87(@;F%M
M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-34*(RP@9G5Z>GD*;7-G:60@
M(DYO(&-H86YG92XB"FUS9W-T<B`B0G)E>71A(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ-#`*;7-G:60@(DYO(&-H:6QD('!E<FUI<W-I
M;VYS(&%R92!T;R!B92!A9&1E9"!B96QO=R!T:&ES(&QE=F5L+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C$*;7-G:60@(DYO
M(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM
M<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,S<W"B,L(&9U>GIY
M"FUS9VED(").;R!C;VUM86YD('-P96-I9FEE9"XB"FUS9W-T<B`B16YG:6X@
M;6%P<&$@=F%R('1I;&=R96EN9"(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,38W(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#<W"B,Z(&9R
M86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<W-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M-S0Q"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HU-S4*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S`T"FUS9VED(").
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,
M+49I;&4@5D93+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@(DYO(&-R961I="!L
M969T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P
M<&QI960N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,C<Q
M"B,L('!H<"UF;W)M870*;7-G:60@(DYO(&5N=')Y('=I=&@@=&AE(&ED("<E
M<R<@97AI<W1S(&EN('1H92!O<FEG:6YA;"!H96QP(&9I;&4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@W,0IM<V=I
M9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?
M8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R
M("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#$S('!O+W1R86YS;&%T:6]N
M+G!H<#HU,C(*(RP@9G5Z>GD*;7-G:60@(DYO(&QO8V%L92!S<&5C:69I960N
M(@IM<V=S='(@(D5N9VEN(&UA<'!A('9A<B!T:6QG<F5I;F0B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(P(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R,0IM<V=I9"`B3F\@
M;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@HC+"!F=7IZ>0IM<V=I
M9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`B3OT@<VME>71I(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,S4*(RP@9G5Z>GD*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R
M(")E;F=I;FX@=&5X=&D@=&EL9W)E:6YD=7(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@HC+"!F=7IZ>0IM<V=I
M9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`B96YG:6YN('1E>'1I
M('1I;&=R96EN9'5R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS
M9VED(").;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED
M(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H
M<#HW,@IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W-A<VPN<&AP.C<W(&9R86UE=V]R:R]!=71H+T%U=&@O;&]G:6XN
M<&AP.C@T"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW-0IM<V=I
M9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A<W-W
M9"YP:'`Z,3,U"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%3
M4U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X-@IM<V=I9"`B(@HB
M3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/
M<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+
M0U,@,3(@9&%T82XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0S"FUS9VED(").;R!R=6QE<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0T"FUS9VED(").;R!S:61E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,3,P"FUS9VED(").;R!T96UP;W)A<GD@9&ER
M96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,P"B,L
M(&9U>GIY"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N
M="XB"FUS9W-T<B`B4VSA\'4@:6YN(&YO=&%N9&%N869N(&]G(&QY:VQI;W+P
M(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@
M(DYO('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX.38*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDP-@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3$W"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY,S0*;7-G:60@(DYO
M('9A;'5E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3$Y"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I
M9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R-PIM<V=I9"`B3F\@=F5R
M<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV,#0*;7-G:60@(DYO;B!087)T
M:6-I<&%N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,3,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HU-C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I
M='ES96QE8W0N:6YC.CDR"FUS9VED(").;VYE(@IM<V=S='(@(D5N9VEN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,`IM
M<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ
M,"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").;W)F;VQK($ES
M;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB
M+T)L;V-K+VUO;VXN<&AP.C8P"FUS9VED(").;W)T:&5R;B!(96UI<W!H97)E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B3F]R=&AE<FX@36%R
M:6%N82!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PHC+"!F=7IZ
M>0IM<V=I9"`B3F]R=V%Y(@IM<V=S='(@(L%F<F%M<V5N9&$B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,`HC+"!F=7IZ>0IM<V=I
M9"`B3F]T($%F=&5R(@IM<V=S='(@(D5K:VD@=7!P:V%S="(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(").;W0@0F5F
M;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C,S,0HC+"!F=7IZ>0IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@
M(E+V\'5N87+A='0B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(N<&AP.C8S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C@S"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP
M.CDT"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2YP:'`Z-#@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HU.0HC+"!F=7IZ
M>0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*;7-G<W1R(")%:VMI(&5Y='0B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8X
M"B,L(&9U>GIY"FUS9VED(").;W0@<V5T(@IM<V=S='(@(D5K:VD@97ET="(*
M"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP
M:'`Z,30S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N
M9&QE<BYP:'`Z,34X"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S
M:6]N2&%N9&QE<BYP:'`Z,3<S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE
M<B]397-S:6]N2&%N9&QE<BYP:'`Z,3@W"B,Z(&9R86UE=V]R:R]397-S:6]N
M2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,T(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HQ-S4*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C$Y,R!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,C$P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR,C8@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(T,@HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,C4W(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-S0*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C,P-R!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,S8U"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HT-#0@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C4Q,PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3,P
M"FUS9VED(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ-C$*(RP@9G5Z>GD*;7-G:60@(DYO=&5S(@IM<V=S
M='(@(D5N9VEN(@H*(SH@<V5R=FEC97,O;V)R;W=S97(O:6YD97@N<&AP.C,V
M"FUS9VED(").;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?=&]P+FEN8SHQ
M,`HC+"!F=7IZ>0IM<V=I9"`B3F]T:6-E(@IM<V=S='(@(D5N9VEN(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-`HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#(Q"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S4*;7-G:60@
M(DYO=F5M8F5R(@IM<V=S='(@(F[S=F5M8F5R(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3`T-@HC+"!F=7IZ>0IM<V=I9"`B3G5M8F5R(@IM<V=S
M='(@(F[S=F5M8F5R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30S
M,`IM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W-"!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-#(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-3`@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G
M:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30R-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0X('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB
M97(@;V8@<F]W<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B3G5M8F5R<R!N;W0@
M<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HT.#,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HV-C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C8T('!O+W1R86YS;&%T:6]N+G!H<#HQ-#@*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C$S-#@*;7-G:60@(D]+(@IM<V=S='(@(LT@;&%G
M:2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX
M,30*(RP@9G5Z>GD*;7-G:60@(D]B:F5C="(*;7-G<W1R(")%9FYI(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*;7-G:60@(D]B:F5C="!#
M<F5A=&]R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$S
M-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Q-0IM<V=I9"`B3V)J
M96-T(&-R96%T;W(@<&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3$P-`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X
M,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#(P
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*
M;7-G:60@(D]C=&]B97(B"FUS9W-T<B`B;VMT\V)E<B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Y.`IM<V=I9"`B
M3V9F:6-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HW,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R
M960@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.CDU"FUS9VED(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4Q(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y-S$*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D
M9')E<W,@86QL;W=E9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S
M+V5D:70N<&AP.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T
M96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE
M<B`B"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO:69R86UE+G!H<#HS-0IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W
M:6YD;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E
M>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU-`IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I
M;F1O=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*
M;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV,#`*;7-G:60@
M(D]P=&EO;F%L(%!A<G1I8VEP86YT(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3$*;7-G:60@(D]P=&EO;G,B"FUS9W-T
M<B`B5F%L<W1I;&QI;F=A<B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS,2!T
M96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B5F%L<W1I;&QI;F=A
M<B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,3(*(RP@9G5Z>GD*;7-G:60@
M(D]P=&EO;G,Z(@IM<V=S='(@(E9A;'-T:6QL:6YG87(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$X"FUS9VED(")/<F1E
M<F5D($QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-C<*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I
M9"`B3W)G86YI<V%T:6]N86P@56YI="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3(Y"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3,U"FUS9VED(")/<FEG
M:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG
M:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP
M.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDT"B,L(&9U>GIY"FUS9VED(")/=&AE<B(*;7-G<W1R(")O:W3S8F5R(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,#8*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,R!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3(Q"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,CD*(RP@9G5Z>GD*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@
M(E5P<&S]<VEN9V%R(&YE=/YJ\VYS(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHS,0IM<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<Y"FUS9VED(")0
M04T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3(U,`HC+"!F
M=7IZ>0IM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S='(@(DAA
M9F$@=6YD:7)S:W)I9G1I<B!M9?`@9&%U9G5M(&QI=#\B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,CDV"FUS9VED(")01U`@16YC<GEP
M=&5D($1A=&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3,T.`IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,S,`IM<V=I
M9"`B4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T82(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]P:'!S:&5L;"YP:'`Z-C@*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,T"FUS9VED(")032!,:6=H="!286EN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,U"FUS9VED
M(")032!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")032!3;F]W(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W
M"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@(E!-(%-U
M;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS.0IM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@
M;&EB+V%P:2YP:'`Z,3(V"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY
M"FUS9VED(")086MI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS
M9VED(")086QA=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0
M86QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY.`IM<V=I9"`B4&%N86UA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`R"FUS9VED(")087)A9W5A>2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B4&%R
M=&QY($-L;W5D>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@S"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y."!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,#$X"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M-S`@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4R"FUS9VED(")087-S=V]R9"(*;7-G
M<W1R("),>6MI;&]R\"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,3,R,@HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T
M(@IM<V=S='(@(DQY:VEL;W+P(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R
M861I=7,N<&AP.C$U,@IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!
M1$E54R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C`U,PIM<V=I9"`B4&%S<W=O<F0@=VET:"!C;VYF
M:7)M871I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.CDP"B,L(&9U>GIY"FUS9VED(")087-S=V]R9#HB"FUS9W-T<B`B
M3'EK:6QO<O`B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0HC
M+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R("),>6MI;&]R\"(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,#,T"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*
M;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3(P('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@HC+"!F=7IZ>0IM<V=I9"`B4&%S
M=&4B"FUS9W-T<B`B1&%G<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F5Q=65U960N:6YC.C0*;7-G:60@(E!E;F1I;F<@4VEG;G5P
M<SHB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T"FUS
M9VED(")096]P;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*(RP@9G5Z>GD*;7-G:60@(E!E<F-E
M;G0B"FUS9W-T<B`B4')E;G1A(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E
M+V-O;F9I<FU?8F]T=&]M+FEN8SHV"B,L(&9U>GIY"FUS9VED(")097)F;W)M
M($UA:6YT96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B5FGP:&%L9'-A\&=E
M<O!I<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.38*(RP@9G5Z>GD*
M;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I
M;C\B"FUS9W-T<B`B1G)A;6MVYFUA('9I\&AA;&1S8?!G97+P:7(@=FGP('1E
M;F=I;F=U(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8Q(&%D;6EN
M+W!E<FUS+V%D9&-H:6QD+G!H<#HV-`HC.B!A9&UI;B]P97)M<R]A9&1C:&EL
M9"YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B
M4&5R<_-N=6QE9W0B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C8X"B,L
M('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@)R5S)R!N;W0@9&5L971E
M9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,C(T(&%D
M;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HY,PHC.B!A9&UI;B]P97)M<R]I;F1E
M>"YP:'`Z,C(@861M:6XO<&5R;7,O9&5L971E+G!H<#HW-`HC+"!F=7IZ>0IM
M<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VXB"FUS9W-T<B`B57!P
M;/US:6YG87(@=6T@;F]T86YD82(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,30U(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30X
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34R"FUS9VED(")0
M97)M:7-S:6]N<R!F;W(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8U"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R
M(")5<'!L_7-I;F=A<B!U;2!N;W1A;F1A(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED
M(")097)U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M-0IM<V=I9"`B4&5T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@
M(E!H:6QI<'!I;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ.38*(RP@9G5Z>GD*;7-G:60@(E!H;VYE
M(@IM<V=S='(@(F5N9VEN;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT,34*;7-G:60@(E!H;W1O<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P
M"FUS9VED(")0:71C86ER;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX96QS(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B
M4&QA=&ET=61E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI
M8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0X"FUS9VED(")0
M;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L
M96UE;G0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B4&QE87-E(&-O;F9I
M<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3<Q"B,L(&9U
M>GIY"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+B(*
M;7-G<W1R(")3;.'P=2!I;FX@;OUJ82!N869N:?`Z(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*(RP@9G5Z>GD*;7-G
M:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ
M(@IM<V=S='(@(E-LX?!U(&EN;B!N_71T(&WV<'!U;F%F;CHB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`W"B,L(&9U>GIY"FUS9VED(")0;&5A
M<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R(")3;.'P=2!I
M;FX@9VEL9&%R(&QE:71A<F9O<G-E;F1U<BXB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-C8W"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!D
M871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#0Y"B,L
M(&9U>GIY"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+B(*;7-G
M<W1R(")3;.'P=2!I;FX@9VEL9&%R(&QE:71A<F9O<G-E;F1U<BXB"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@
M<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3@@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHR,@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U
M<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B4VSA\'4@:6YN(&YO=&%N
M9&%N869N(&]G(&QY:VQI;W+P(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E
M+V%G<F5E;65N=%]T;W`N:6YC.C$R"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@(%EO=2!-55-4(&%G
M<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G
M<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3<*;7-G:60@(E!L96%S
M92!R97!O<G0@86YY(&)U9W,@=&\@:3$X;D!L:7-T<RYH;W)D92YO<F<N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-30P"FUS9VED("(B"B)0;&5A<V4@<F5V:65W('1H92!F;VQL
M;W=I;F<@:6YF;W)M871I;VXL(&%N9"!T:&5N('-E;&5C="!A;B!A8W1I;VX@
M9G)O;2!T:&4@(@HB;65N=2!B96QO=RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT,S4*(RP@9G5Z
M>GD*;7-G:60@(E!L96%S92!S96QE8W0@86X@86-T:6]N(&9R;VT@=&AE(&UE
M;G4@8F5L;W<N(@IM<V=S='(@(E9E;&1U(&$N;2YK(&5I;F$@;?9P<'4@=&EL
M(&'P(&QE:71A(.TN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!T>7!E
M('1H92!N97<@8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B4VSA\'4@:6YN(&[]
M:F$@;F%F;FGP.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&]L86YD(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-PIM<V=I9"`B4&]L
M:71I8W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0R-`IM<V=I9"`B4&]L;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM
M<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W"FUS9VED(")0
M;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0
M;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T
M('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C0@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO
M;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+VQD87`N<&AP.CDX"FUS9VED(")0<F5F<U]L9&%P
M.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S97-S:6]N+G!H<#HS,PIM
M<V=I9"`B4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(R,PIM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR-3<*;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E
M;#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,#(*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$X.`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*
M(RP@9G5Z>GD*;7-G:60@(E!R979I97<B"FUS9W-T<B`B1GER<FD@8FQA\'/M
M\&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C0*;7-G:60@(E!R979I97<@=&AE(&EM86=E(&EN(&$@
M;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C,U."!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V
M,@HC+"!F=7IZ>0IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R(")&
M>7)R82!S:V5Y=&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,#D*;7-G:60@
M(E!R:79A=&4@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]-96YU+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@(E!R;V)L96TB"FUS
M9W-T<B`B5F%N9&%MX6P_(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3(W
M"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,3`*;7-G:60@(E!R;VIE8W1S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,3$@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X.`IM<V=I9"`B4')O;7!T('1E>'0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#`Y"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y
M($%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HR,C<*;7-G:60@(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@
M;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DQ(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#`*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DV(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#(*;7-G:60@(E%A=&%R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HV,@IM<V=I9"`B475E<GDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-`IM<V=I9"`B4F%D:6\@
M<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")286EN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"FUS9VED
M(")286EN($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0R"FUS9VED(")286EN($QA=&4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#,*;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")286EN(&%N
M9"!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")286EN('1O(%-N;W<B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A;F1O;2!&
M;W)T=6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HW,PIM<V=I9"`B4F%T:6\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HR.3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*(RP@9G5Z>GD*;7-G:60@(E)E
M860B"FUS9W-T<B`BTVQE<VGP(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.#<*(RP@9G5Z>GD*;7-G:60@(E)E860@;65S<V%G
M97,B"FUS9W-T<B`B3OT@<VME>71I(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E+FEN8SHQ,@HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@
M9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z
M,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A
M=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O
M;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#$*;7-G
M:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Q"B,L(&9U>GIY"FUS9VED
M(")2969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R(")%;F1U<FAL8?!A(&WV
M<'!U:&%M.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-"!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$S"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R,S4*(RP@9G5Z>GD*;7-G:60@(E)E9V5X(@IM<V=S='(@(D5N
M9'5R<V5T:F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C4S"FUS
M9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,R-`IM<V=I9"`B4F5M87)K<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C0U-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C0W-@IM<V=I9"`B4F5M96UB97(@=&AE(&9R964O8G5S>2!I;F9O<FUA
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q
M-`HC+"!F=7IZ>0IM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B1FIA
M<FSF9VIA('9A;&EN(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C@T"FUS9VED(")296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M
M+VAO<F1E*3HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]E9&ET+FEN8SHR,2!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN
M8SHR.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC
M.C$U"B,L(&9U>GIY"FUS9VED(")296UO=F4B"FUS9W-T<B`B2&%L9&$@X69R
M86TB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$*(RP@9G5Z
M>GD*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R(")&:F%R;.9G:F$@=F%L
M:6XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-3,R"B,L(&9U>GIY"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(F;F
M<F$@;FGP=7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C0P"B,L(&9U>GIY"FUS9VED(")296UO=F4@9F]R;6%T=&EN9R(*
M;7-G<W1R(")5<'!L_7-I;F=A<B!N973^:O-N<R(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C4X"FUS9VED(")296UO
M=F4@9G)O;2!M>2!C86QE;F1A<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C$S-@HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E('!A
M:7(B"FUS9W-T<B`B9N9R82!U<'`B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,C`U"FUS9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R
M)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Q"B,L
M(&9U>GIY"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(D9J87)LYF=J82!V
M86QI;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H
M92!D;V-U;65N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F4N:6YC.C$V"B,L(&9U>GIY"FUS9VED(")296UO=F4@=7-E<B(*
M;7-G<W1R(")F:F%R;.9G:F$@:&%N9')I="(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V92YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")296UO
M=F4@=7-E<CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HR.#`*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HS-#D*(RP@9G5Z>GD*;7-G
M:60@(E)E<&QY(%-E;G0N(@IM<V=S='(@(E-V87)A(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT-3D*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT-C@*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT-S@*;7-G
M:60@(E)E<&QY('=I=&@@3F]T(%-U<'!O<G1E9"!-97-S86=E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z-#8V"FUS9VED(")297!L>2!W:71H(&9R964O8G5S>2!F;W(@;F5X="`R
M(&UO;G1H<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HT-C4*;7-G:60@(E)E<&QY('=I=&@@<F5Q
M=65S=&5D(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ.#D*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<&QY.B`E<R(*;7-G<W1R
M(")3=F%R.B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X
M"FUS9VED(")297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE
M9"!E<G)O<F-O9&4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C$W-"!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0X-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"`G)7,G(&YO="!S<&5C:69I
M960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HU.#$@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HW-#<*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<Q
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"`G)7,G(&YO="!S<&5C
M:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<X,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")297%U:7)E9"`G)7,G(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E
M<BYP:'`Z,S(X"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4Y
M,@IM<V=I9"`B4F5Q=6ER960@4&%R=&EC:7!A;G0B"FUS9W-T<B`B(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,S$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Y
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,Q-2!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z-#0*;7-G:60@(E)E<V5T(@IM<V=S='(@(D5N
M9'5R<V5T:F$B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT-@HC
M+"!F=7IZ>0IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`B3'EK:6QO
M<O`B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B
M4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]P:'!S
M:&5L;"YP:'`Z-S$@861M:6XO8VUD<VAE;&PN<&AP.C(X(&%D;6EN+W-Q;'-H
M96QL+G!H<#HV-0HC+"!F=7IZ>0IM<V=I9"`B4F5S=6QT<R(*;7-G<W1R(").
M:?!U<G-T8?!A(&QE:71A<B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HX,C$*
M;7-G:60@(E)E<W5L=',@*&EN8VQU9&EN9R!(;W)D92DZ(@IM<V=S='(@(B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HX,3D*(RP@9G5Z>GD*;7-G:60@(E)E
M<W5L=',Z(@IM<V=S='(@(DYI\'5R<W1A\&$@;&5I=&%R(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,B!T96UP;&%T97,O<')E9G,O96YD
M+FEN8SHW"B,L(&9U>GIY"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G
M<W1R(")686QK;W-T:7(@;F]T86YD82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@
M(E)E=6YI;VXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0X"B,L(&9U>GIY"FUS9VED
M(")2979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R(")5<'!L_7-I;F=A<B!N
M973^:O-N<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S`*;7-G:60@
M(E)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<P"FUS9VED(")2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3(U"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,0IM<V=I9"`B
M4FEG:'0@=F%L=65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?=R!0
M<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR,S0*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HU.#,*;7-G:60@(E)O;&4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`X
M"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,#4*(RP@9G5Z>GD*;7-G:60@
M(E)O=&%T92!,969T(@IM<V=S='(@(E1E;F=I;&GP86QI<W1I(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Q,0IM<V=I9"`B
M4F]T871E(%)I9VAT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0<F]P
M97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P<F]P97)T:65S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4S"B,L
M(&9U>GIY"FUS9VED(")2=6QE<R(*;7-G<W1R(")%;F1U<G-E=&IA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A
M;F0@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL
M(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4R
M"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(Q"FUS9VED(")2
M=6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G5S<VEA;B!&
M961E<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)W
M86YD82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T
M=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,S(S"B,L(&9U>GIY"FUS9VED(")3+TU)344@16YC<GEP=&5D($UE
M<W-A9V4B"FUS9W-T<B`B4V5N9&$@<VME>71I(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S87-L+G!H<#HX,0IM<V=I9"`B4T%33"!A=71H96YT:6-A=&EO
M;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#0Y"B,L(&9U>GIY"FUS9VED(")335,@365S<V%G
M:6YG(@IM<V=S='(@(E-K;_!A('-K97ET:2(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-3@*;7-G:60@(E-3
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-C`*
M;7-G:60@(E-32"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T
M:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,U"FUS9VED
M(")354-#15-3(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$S,`IM<V=I
M9"`B4U]13"!3:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")382(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`T"FUS9VED(")386EN="!(96QE;F$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@T"FUS9VED(")386EN="!+:71T<R!A;F0@3F5V:7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,SD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED(")386EN="!,=6-I82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")386EN="!0:65R<F4@
M86YD($UI<75E;&]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@
M(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*
M;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$W"FUS9VED(")386UO82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V
M"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*
M;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3871E;&QI
M=&4@4')O=FED97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B
M4V%U9&D@07)A8FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;&%Y;W5T+FEN8SHY.`HC+"!F=7IZ>0IM<V=I9"`B4V%V92(*;7-G<W1R(")6
M:7-T82!S96TB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R(")6
M:7-T82!S96TB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC
M.C0Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3879E("<E<R<B"FUS
M9W-T<B`B5FES=&$@<V5M(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z
M-0HC+"!F=7IZ>0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@(E9A;&MO
M<W1I<B!N;W1A;F1A(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W,`IM
M<V=I9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(
M4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T
M;W)Y+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HV
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U<&=R861E('-C<FEP
M="!T;SH@)R5S)RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E-C871T97)E9"!4+5-T;W)M
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G
M:60@(E-C:65N8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,38*;7-G:60@(E-E87)C:"(*;7-G<W1R("),96ET82(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR-S4*(RP@9G5Z>GD*;7-G:60@(E-E87)C:"!%
M;F=I;F5S(@IM<V=S='(@(DYI\'5R<W1A\&$@;&5I=&%R(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C$T-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V5A<F-H
M:6YG($AO<F1E(&%P<&QI8V%T:6]N<R!I;B`E<R(*;7-G<W1R("(B"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,3(S"FUS9VED(")396%R8VAI;F<@9V5T=&5X
M="!B:6YA<FEE<RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.3<W"B,L(&9U>GIY"FUS9VED(")396QE8W0@1FEL97,B"FUS
M9W-T<B`B5F5L:F$@86QL="(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-38*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A(&1A
M=&4B"FUS9W-T<B`B5F5L9'4@:V5N;FDB"@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$Y.`IM<V=I9"`B4V5L96-T(&$@9W)O=7`@=&\@861D(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-#,*(RP@
M9G5Z>GD*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R(")696QJ
M82!E:VME<G0B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*
M(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R(")696QD
M=2!S=&%F87-E='0Z(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M-38*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S
M='(@(E9E;&1U('-T869A<V5T=#HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-C<P"B,L(&9U>GIY"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M
M<&]N96YT<RXB"FUS9W-T<B`B17GP82!V:?!H96YG:2XB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#$T"B,L(&9U>GIY"FUS
M9VED(")396QE8W0@86X@;V)J96-T(@IM<V=S='(@(E9E;&IA(&5K:V5R="(*
M"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HS-PIM<V=I9"`B(@HB4V5L96-T
M('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W
M+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H
M92!T97AT(&%R96$N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C,T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-`HC+"!F
M=7IZ>0IM<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`B
M5F5L9'4@<W1A9F%S971T.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET
M>7-E;&5C="YI;F,Z.#D*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U
M('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T
M82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E
M<CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*
M;7-G:60@(E-E;&5C="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-C0*;7-G:60@(E-E;&5C="!T
M=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,CDV"FUS9VED(")396QE8W0@>6]U<B!C;VQO<B!S8VAE
M;64N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S@*
M;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T
M<B`B5F5L9'4@<VKA;&9G969I\"!T=6YG=6WA;#HB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8U,PHC+"!F=7IZ>0IM
M<V=I9"`B4V5N9"!,871E<W0@26YF;W)M871I;VXB"FUS9W-T<B`B57!P;/US
M:6YG87(@;F5T_FKS;G,B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38T
M"B,L(&9U>GIY"FUS9VED(")396YD(%--4R(*;7-G<W1R(")396YD82!S:V5Y
M=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")396YE9V%L(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$T"FUS9VED(")396YS;W(Z("(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,S@R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW,PIM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(G-E<'1E;6)E<B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED
M(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#$*;7-G:60@(E-E<FEA;"!.
M=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED(")397-S:6]N($E$(&5X<&ER
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S
M,3(*(RP@9G5Z>GD*;7-G:60@(E-E="(*;7-G<W1R(")696QJ82(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HW-@IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@
M86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@
M9F]R9V5T(&ET+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$U"FUS9VED(")3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@
M=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T"B,L(&9U>GIY"FUS9VED(")3
M970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E
M(&]P=&EO;G,N(@IM<V=S='(@(E9E;&1U('-JX6QF9V5F:?`@='5N9W5MX6PZ
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX"FUS9VED("(B"B)3970@
M>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@
M<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-`IM<V=I9"`B
M4V5T=7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN
M9&5X+FAT;6PZ,SD*;7-G:60@(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I
M;&%B;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$U,PIM<V=I9"`B4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET
M:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM
M<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#0Q"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT,PIM<V=I9"`B4VAO
M<G0@4W5M;6%R>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#,V"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F
M;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HR.3(@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U.`IM<V=I9"`B(@HB4VAO=R!D
M:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE
M=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#@P"B,L(&9U>GIY"FUS9VED(")3
M:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S='(@
M(E/];F$@:'9E;N9R(/[Z('1E;F=D:7-T('/M\&%S="(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$W-CD*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME
M97`@;W)I9VEN86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C@Q-PIM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q-0IM<V=I9"`B4VAO=R!T86)L92!O
M<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S,Y"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE
M("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.`IM<V=I
M9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C,*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I
M97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.0IM<V=I9"`B4VAO=R!T:&4@
M5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M,0IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V-PHC+"!F
M=7IZ>0IM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T<B`B4^9K:F$@>69I<B#A
M('9I;FYU<W3V\"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0W"FUS9VED(")3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")3:&]W
M97)S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0Y"FUS9VED(")3:&]W97)S($QA=&4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-3`*;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C,Y.0IM<V=I
M9"`B4VAR:6YK(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C8Y,B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HW-30*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M.#$R(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C@W-`HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY,#D@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.30V"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.CDW-"!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HQ,#`T"FUS9VED(")3:')I;FL@;W(@;6]V92!N96EG:&)O
M=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C4*;7-G
M:60@(E-I9VX@=7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHX.0IM<V=I9"`B4VEG;B!U<"!I9B!N;W0@<F5G:7-T97)E9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C<Q,@HC+"!F=7IZ>0IM<V=I9"`B4VEG;F%T=7)E(@IM<V=S='(@(E5N9&ER
M<VMR:69T(/[M;CHB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C<Q,0IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-2!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8Y"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#<@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.#DV"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,34@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-PHC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C0V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S0*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R-PIM<V=I9"`B4VEZ92(*
M;7-G<W1R(")3=.9R\"(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF
M:7)M7V)O='1O;2YI;F,Z.0IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G
M<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#,Q('!O+W1R86YS;&%T
M:6]N+G!H<#HT.#0@<&\O=')A;G-L871I;VXN<&AP.C8V-@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z.#8P('!O+W1R86YS;&%T:6]N+G!H<#HQ,C(S"FUS9VED
M(")3:VEP<&5D+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@
M(E-L;W9A:VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L
M;W9E;FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4Q"FUS9VED(")3;F]W(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED(")3
M;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU,PIM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4T"FUS9VED(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@
M(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C<V"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#`*;7-G:60@(E-N;W<@97%U:79A
M;&5N="!I;B!W871E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G
M:60@(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V
M"FUS9VED(")3;VUA;&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,P"B,L(&9U>GIY"FUS9VED
M(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R(")2]O!U;F%RX71T(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M-3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU.#@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C$V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(T-@HC+"!F=7IZ>0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B
M"FUS9W-T<B`B1G5L;'0@;F5T9F%N9R#^:71T("A&<N$Z*2`Z(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-34@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H
M25-/+3@X-3DM,RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")3
M;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K
M+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$S"FUS9VED(")3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O
M<F1E<B!I;B!C96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@Q-0IM<V=I9"`B4W!A8V5R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`IM<V=I
M9"`B4W!A8VEN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C:6YG(&%N
M9"!P861D:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")3<&%I
M;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.34*
M;7-G:60@(E-P86TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N
M<&AP.C$T"B,L(&9U>GIY"FUS9VED(")3<&5C:6%L($-H87)A8W1E<B!);G!U
M="(*;7-G<W1R(")3Z7)TX6MN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@HC+"!F=7IZ>0IM<V=I9"`B4W!L
M:70@8V5L;"(*;7-G<W1R(")696QJ82!A;&QT(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L
M:70@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*;7-G:60@
M(E-P;W)T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(E-R:2!,
M86YK82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,@IM<V=I9"`B4W1A;F1A<F0B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED
M(")3=&%R(%1R96LB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HT-#,*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU-#@*;7-G:60@(E-T87)T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V,#0@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,PIM<V=I9"`B4W1A<G0@>65A<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4W,`IM<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU.#,*
M(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@
M(E-T871U<R(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#DQ
M"B,L('!H<"UF;W)M870*;7-G:60@(E-T871U<R!F;W(@;&]C86QE("5S+BXN
M("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$Y
M"B,L(&9U>GIY"FUS9VED(")3=&]R86=E(&9O<FUA="(*;7-G<W1R(")5<'!L
M_7-I;F=A<B!N973^:O-N<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3<R"B,L(&9U>GIY"FUS9VED(")3=')E970@061D<F5S<R(*
M;7-G<W1R(")396YD86YD86YE=&9A;F<B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q"FUS9VED(")3=')I:V5T:')O=6=H
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S,*
M;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$X-S,*;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H
M92!A9&1R97-S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C(*;7-G:60@(E-U(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O
M;E]B<F]W<V5R+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E
M8W1O<GD@)R5S)R!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C$Q"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS
M9W-T<B`B169N:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C0T"FUS9VED(")3=6)J96-T(%!U8FQI8R!+97D@26YF;R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(@9G)A;65W;W)K
M+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S$R"B,L(&9U>GIY"FUS9VED(")3
M=6)M:70B"FUS9W-T<B`B169N:2(*"B,Z('-I9VYU<"YP:'`Z-#D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D("<E
M<R<@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@;&]G(&EN('5N=&EL('EO
M=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@HC
M+"!F=7IZ>0IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S='(@(D5F;FDB"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3`U"B,Z(&9R86UE=V]R:R].;W1I9FEC871I
M;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@
M(E-U8V-E<W,B"FUS9W-T<B`B1G)A;6MVYFUT(@H*(SH@861M:6XO=7-E<BYP
M:'`Z.#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL
M>2!A9&1E9"`G)7,G('1O('1H92!S>7-T96TN(@IM<V=S='(@(DYE=&9A;F=I
M\"!<(B5S7"(@=F%R(&+F='0@[2!N971F86YG86+S:VEN82(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@8VQE87)E9"!D871A(&9O<B!U<V5R("<E<R<@9G)O;2!T:&4@<WES=&5M
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C@Q(&%D;6EN+W!E
M<FUS+V1E;&5T92YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S
M<V9U;&QY(&1E;&5T960@)R5S)RXB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3`U"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R
M96UO=F5D("<E<R<@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@
M<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-34*;7-G:60@(E-U8V-E<W-F=6QL>2!S
M879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I
M;&4@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=7!D871E9"`G)7,G(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS
M9VED(")3=61A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C4U.`HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4V,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"FUS9VED(")3=6UM
M87)Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV-@IM
M<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;G)I
M<V4N<&AP.C<Q"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V"FUS9VED(")3=6YN
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3@S"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I9"`B
M4W5N<FES92]3=6YS970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$X,@IM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ.#8*(RP@9G5Z>GD*
M;7-G:60@(E-U;G-E="(*;7-G<W1R(")%9FYI(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$X-0HC+"!F=7IZ>0IM<V=I9"`B4W5N<V5T.B`B
M"FUS9W-T<B`B($5F;FES;.UN83H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S,PIM<V=I
M9"`B4W5P<&]R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"B,L(&9U>GIY
M"FUS9VED(")3=7)I;F%M92(*;7-G<W1R(")3:W+A<FYA9FXB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-`HC+"!F=7IZ>0IM<V=I
M9"`B4W5R;F%M92(*;7-G<W1R(").;W1A;F1A;F%F;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#4*;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P.`IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#0*(RP@9G5Z>GD*;7-G:60@(E-W961E;B(*;7-G<W1R("),
M97-I\"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-38@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")3=VET>F5R;&%N9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z.3<*;7-G
M:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-PIM<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-3<*;7-G:60@(E0M4W1O<FTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@(E0M4W1O<FT@
M86YD(%=I;F1Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,38V"FUS9VED(")4
M4U8@9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5&%B;&4N
M<&AP.C$S-@IM<V=I9"`B5&%B;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B
M5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<R"FUS9VED(")486)L
M92!P<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*
M;7-G:60@(E1A:7=A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O
M9B!#:&EN82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")486II
M:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A;GIA
M;FEA+"!5;FET960@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R
M9V5T.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,3<P"B,L(&9U>GIY"FUS9VED(")487-K<R(*;7-G<W1R(")697)K969N:2!V
M:?`@=&5N9VEN9W4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4W,PIM<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X.`IM<V=I9"`B5&5M<"!F;W(@;&%S
M="!H;W5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,3(*;7-G:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ.3`*;7-G:60@(E1E;7!E<F%T=7)E.B`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H
M<#HR,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@)R5S)R!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y
M"FUS9VED(")496UP;&%T92!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8T
M,0IM<V=I9"`B5&5N=&%T:79E;'D@06-C97!T(')E<75E<W0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HV.#D*;7-G:60@(E1E;G1A=&EV96QY($%C8V5P=&5D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3$*;7-G:60@(E1E>'0B
M"FUS9W-T<B`B5&5X=&DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8U
M"B,L(&9U>GIY"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`B5&5X=&DB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<T"B,L(&9U>GIY"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@(D[F<W1A
M('/M\&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<Q"B,L(&9U>GIY"FUS9VED(")497AT=&]P(@IM<V=S='(@(E1E>'1I
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU
M.0IM<V=I9"`B5&@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.3$*;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#D*;7-G:60@(E1H86EL86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.CDP,PHC+"!F=7IZ>0IM<V=I9"`B5&AA;FL@
M>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+B(*;7-G<W1R("(B"B+>^B!H969U
M<B!N^B!A9G1E;F=S="`E<RX@5&%K:R!F>7)I<B!N;W1K=6YI;F$N(-YE9V%R
M(/[Z('9I;'0@=&5N9VIA<W0@869T=7(L("(*(FYO=&'P=2#^X2!R96ET:6YA
M(&CI<B!A\"!N9?!A;BXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`V.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@)7,@:&5L<"!F:6QE(&9O<B`E<R!D
M;V5S;B=T('EE="!E>&ES="X@0W)E871I;F<@82!N97<@;VYE+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<S-PIM<V=I9"`B
M5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN
M92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]M86EN=&5N86YC92YP:'`Z,CD*;7-G:60@(E1H92!-86EN=&5N86YC
M93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0HC+"!F
M=7IZ>0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X
M:71I;F<N(@IM<V=S='(@(E-K97ET:6YU('-E;2!V97)I\"!V87(@8?`@<V5M
M:F$@:&5F=7(@=F5R:?`@;&]K8?`N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HQ-3@@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ-CD*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.#`@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HQ.3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR
M,#,@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,C$*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HR,S,@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HR-S(*;7-G:60@(B(*(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O
M;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO
M=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N<RXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT.0IM
M<V=I9"`B5&AE(&-A;&5N9&%R(&1A=&$@:7,@:6YV86QI9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S.`IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@
M<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE
M("(*(F1A=&%B87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*(RP@9G5Z>GD*;7-G:60@(E1H92!C
M;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S
M(&)O;VLN(@IM<V=S='(@(DYE=&9A;F=I\"!<(B5S7"(@=F%R(&+F='0@[2!N
M971F86YG86+S:VEN82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$Q-#8*;7-G:60@(B(*(E1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E
M(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A
M9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C0P"FUS9VED("(B"B)4:&4@9&ES=')I8G5T:6]N
M(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK
M(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C0Q"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C
M:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="YP
M:'`Z,3$S"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E
M(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C<X"FUS9VED
M(")4:&4@979E;G0@:&%S(&)E96X@861D960@=&\@>6]U<B!C86QE;F1A<BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S4@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT.#@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V
M."!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0W.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E
M='1I;F=S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HQ-3(*;7-G:60@(E1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N
M=&\@:71S96QF+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A
M+G!H<#HR-C`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R
M<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4V
M"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C
M875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB
M=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA
M<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E(&1I<W!L
M87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R
M;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@
M.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A
M;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN
M7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E<W,@3TL@
M:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET
M;W(N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#DW('!O
M+W1R86YS;&%T:6]N+G!H<#HQ,C,U"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!H96QP(&9I;&4@)7,@9&ED;B=T('-T87)T('=I=&@@/#]X;6PB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDP"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB
M"FUS9W-T<B`B2V5N;FEN=2!<(B5S7"(@:&5F=7(@=F5R:?`@97ET="XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ-#,*;7-G:60@
M(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@
M9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,C`Q"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET
M:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES
M(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E
M860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3@W-PIM<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H96X@
M;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(S,0IM<V=I9"`B5&AE
M(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y
M<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+G!H<#HR.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E
M(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M87AI;75M(&%L;&]W86)L92!S
M:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O96YS
M8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS
M<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W=E
M8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<W)C
M:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VUS97AC96PN<&AP.C,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P
M<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N
M;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I
M9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW.`IM<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E
M;B!D96QE=&5D+B(*;7-G<W1R(")+96YN:6YU(%PB)7-<(B!H969U<B!V97)I
M\"!E>71T+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C0Y"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H
M87,@8F5E;B!S879E9"XB"FUS9W-T<B`B2V5N;FGP("!<(B5S7"(@:&5F=7(@
M=F5R:?`@=FES=&'P+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E
M<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R(")+96YN:?`@(%PB)7-<(B!H
M969U<B!V97)I\"!V:7-T8?`N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z,CDP"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R!D;V5S
M(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ,#@*;7-G:60@(E1H92!T87-K(&AA
M<R!B965N(&%D9&5D('1O('EO=7(@=&%S:VQI<W0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3`X"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!T96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI
M<W0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD(&)O='1O
M;2!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@
M<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N
M<&AP.C,P-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN
M8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]$871A+T1A=&$O8W-V+G!H<#HR-#`@9G)A;65W;W)K+T1A=&$O1&%T82]T
M<W8N<&AP.C$W,@HC+"!F=7IZ>0IM<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@
M8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R(")%:VMI('9A<B!HYF=T(&'P
M('-K:7!T82!U;2!U;F1I<G-K<FEF="XB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.CDS"B,L(&9U>GIY"FUS9VED(")4
M:&4@=7-E<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO;B!W87,@<W5C97-S9G5L
M;'D@<W1O<F5D+B(*;7-G<W1R(")5;F1I<G-K<FEF="!H969U<B!V97)I\"!B
M<F5Y='0N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0V(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3`W(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ,3$*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A
M:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z
M,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE;65S(&1I<F5C=&]R>2`G)7,G
M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HQ-S@*(RP@9G5Z>GD*;7-G:60@(E1H97)E(&%R92!N;R!O
M<'1I;VYS(&%V86EL86)L92XB"FUS9W-T<B`BWF'P(&5R=2!E;F=I;B!S:V5Y
M=&D@[2#^97-S=2!P\W-T:/-L9FDN(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z,S,X"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@
M=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30P-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES
M(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[("(*(GEO
M=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C$P-C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@9&]E<VXG="!Y970@97AI<W0@82!H96QP(&9I;&4@9F]R("5S+B(*;7-G
M<W1R("(B"@HC.B!S:6=N=7`N<&AP.C4S"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`G)7,G('1O('1H
M92!S>7-T96TN("5S+B(*;7-G<W1R("(B"B)686YD86WA;"!K;VT@=7!P('9I
M\"!TYFUI;F=U(.$@)7,N(%9I;&QU=&EL:WEN;FEN9R!N973^:O-N<VEN<R!F
M>6QG:7(@:.ER(.$@(@HB969T:7(B"@HC.B!A9&UI;B]U<V5R+G!H<#HW,PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE
M;2!A9&1I;F<@)R5S)R!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R("(B"B)6
M86YD86WA;"!K;VT@=7!P('9I\"!TYFUI;F=U(.$@)7,N(%9I;&QU=&EL:WEN
M;FEN9R!N973^:O-N<VEN<R!F>6QG:7(@:.ER(.$@(@HB969T:7(B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B`G
M)7,G(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(B(*(E9A;F1A;>%L(&MO
M;2!U<'`@=FGP('3F;6EN9W4@</-S=&CS;&9S+B!6:6QL=71I;&MY;FYI;F<@
M;F5T_FKS;G-I;G,@9GEL9VER("(*(FCI<B#A(&5F=&ER(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3`S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@82!P<F]B;&5M(')E;6]V:6YG("<E<R<@9G)O;2!T:&4@<WES=&5M
M.B`B"FUS9W-T<B`B(@HB5F%N9&%MX6P@:V]M('5P<"!V:?`@=.9M:6YG=2#A
M("5S+B!6:6QL=71I;&MY;FYI;F<@;F5T_FKS;G-I;G,@9GEL9VER(&CI<B#A
M("(*(F5F=&ER(@H*(SH@861M:6XO=7-E<BYP:'`Z,34Y"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG
M("<E<R<Z("5S(@IM<V=S='(@(D5K:VD@=/-K<W0@8?`@<V5N9&$@<VME>71I
M\#H@)7,B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-S@*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L
M96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB
M"FUS9W-T<B`B(@HB5F%N9&%MX6P@:V]M('5P<"!V:?`@=7!P:&QE\'-L=2!S
M:W+A<BX@4VMRX6EN(&5R(&4N="YV+B!S=.9R<FD@96X@;&5Y9FEL96=T("(*
M(F5R+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X,PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@
M=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB
M"FUS9W-T<B`B(@HB5F%N9&%MX6P@:V]M('5P<"!V:?`@=7!P:&QE\'-L=2!S
M:W+A<BX@4VMRX6EN(&5R(&4N="YV+B!S=.9R<FD@96X@;&5Y9FEL96=T("(*
M(F5R("@E9"!-0BDN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP
M:'`Z.#@U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W
M87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S
M(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R("(B"B)686YD86WA
M;"!K;VT@=7!P('9I\"!U<'!H;&7P<VQU('-K<N%R+B!3:W+A:6X@97(@92YT
M+G8N('-TYG)R:2!E;B!L97EF:6QE9W0@(@HB97(N(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS
M9W-T<B`B5FEL;&$@:V]M('5P<"!V:?`@8FER=&EN9W4@_F5S<V$@:&QU=&$@
M<VME>71I<VEN<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HS.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`B5FEL;&$@:V]M
M('5P<"#^96=A<B#A='1I(&'P('9I<W1A('5P<&MA<W1I\"XB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C<U"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!E=F5N=#H@)7,N(@IM<V=S='(@(E9I;&QA(&MO;2!U<'`@
M_F5G87(@X71T:2!A\"!S_6YA('5M8F7P:?`@<VME>71I+B(*"B,Z(&9R86UE
M=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS,@HC+"!F=7IZ>0IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N
M(@IM<V=S='(@(E9I;&QA(&MO;2!U<'`@_F5G87(@X71T:2!A\"!V:7-T82!U
M<'!K87-T:?`N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HQ,#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE('1A<VLZ("5S+B(*;7-G
M<W1R(")6:6QL82!K;VT@=7!P(/YE9V%R(.%T=&D@8?`@<_UN82!U;6)E\&GP
M('-K97ET:2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.CDQ"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('5S97(G<R!F<F5E+V)U<WD@:6YF
M;W)M871I;VXZ("5S+B(*;7-G<W1R(")%:VMI('3S:W-T(&'P('-E;F1A('-K
M97ET:?`Z("5S(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW.0IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N
M(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q=6ER960@9FEE
M;&0N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,3`W('!O
M+W1R86YS;&%T:6]N+G!H<#HQ,3$S('!O+W1R86YS;&%T:6]N+G!H<#HQ,C0U
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,C4Q"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!O<&5N:6YG('1H92!F:6QE("5S
M+B!4<GD@<G5N;FEN9R!T<F%N<VQA=&EO;BYP:'`@=VET:"!T:&4@(@HB9FQA
M9R`M9"!T;R!S964@86YY(&5R<F]R(&UE<W-A9V5S(&9R;VT@=&AE('AM;"!P
M87)S97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS9VED("(B"B)4:&5R92!W87,@86X@
M97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F
M=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,SD*(RP@9G5Z>GD*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U
M<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN
M(&QA=&5R+B(*;7-G<W1R(")6:6QL82!K;VT@=7!P('9I\"!B:7)T:6YG=2#^
M97-S82!H;'5T82!S:V5Y=&ES:6YS(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*(RP@9G5Z>GD*;7-G:60@(B(*
M(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N
M(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(E9I;&QA
M(&MO;2!U<'`@_F5G87(@X71T:2!A\"!S_6YA('5M8F7P:?`@<VME>71I+B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T.`IM
M<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I
M;F<@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HX,@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.CDV"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3$R"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,C`P"FUS9VED(")4:&ES
M(&%C=&EO;B!I<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C$Q.`HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C,U.0IM
M<V=I9"`B5&AI<R!A8W1I;VX@:7,@;F]T('EE="!I;7!L96UE;G1E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI
M9"!R87(@87)C:&EV92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO="!A
M<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$T.0HC+"!F=7IZ>0IM<V=I9"`B
M5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N
M(@IM<V=S='(@(MYE='1A(&=I;&1I('9E<O!U<B!A\"!V97)A('1A;&$N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,3@T"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI
M8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4Q-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O
M(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N
M96ET86QY7W-M='`N<&AP.C@P"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO
M=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6
M;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU
M;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6
M;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-S@@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3`U-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,#@V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,34*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3$X,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C4V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R.3`@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30P,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-38R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-#,*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3DU."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,#`U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,CD@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`W.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,30Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,C$*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0P."!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-#4R"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C0@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@S,@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,30Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,W,C@*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S<S-@IM<V=I9"`B5&AI<R!F:65L
M9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3`V-0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT
M86EN(&EN=&5G97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-#$V"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DT"FUS9VED(")4:&ES(&9I96QD(&UA
M>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(S"FUS9VED(")4:&ES(&9I96QD
M(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I
M;G1E9V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HY.#D*(RP@9G5Z>GD*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A
M;&ED(&YU;6)E<BXB"FUS9W-T<B`BWF5T=&$@9VEL9&D@=F5R\'5R(&'P('9E
M<F$@=&%L82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#0P"FUS
M9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@
M:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A
M9B<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C4V
M,0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0S-PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@
M5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL("(*
M(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@
M9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI96YT<R!P
M;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z-3@U"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S
M*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@
M;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(E1A;&%N('9E<O!U<B!A
M\"!V97)A(&'P(&SA9VUA<FMI(#$N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C$S,#0*;7-G:60@(E1H:7,@<V-R:7!T(&UU<W0@8F4@<G5N(&9R;VT@=&AE
M(&-O;6UA;F0@;&EN92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E<B!C
M86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ-#<*
M;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ
M,C0*;7-G:60@(E1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS9W-T
M<B`BWF5T=&$@9VEL9&D@=F5R\'5R(&'P('9E<F$@=&%L82XB"@HC.B!S97)V
M:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"B,L(&9U>GIY"FUS9VED
M(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@
M=VEN9&]W(@IM<V=S='(@(B(*(MYE<W-I(&=L=6=G:2#^87)F(&'P('9E<F$@
M=NUS=6X@9G+A(&=L=6=G86YU;2#^87(@<V5M(&[]('-K97ET:2!E<G4@<V%M
M:6XN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C`*;7-G:60@(E1H=6YD97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(Q.0IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#(V"B,L(&9U>GIY"FUS9VED
M(")4:6UE(@IM<V=S='(@(E3M;6%B96QT:2(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS,#4*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W"B,L(&9U>GIY"FUS9VED(")4
M:6UE(&9O<FUA="(*;7-G<W1R(")4[6UA8F5L=&DB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-3,W"B,L(&9U>GIY"FUS9VED(")4:6UE('-E;&5C
M=&EO;B(*;7-G<W1R(")4[6UA8F5L=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED
M(")4:6UO<BU,97-T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP
M.C(P"FUS9VED(")4:71L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L92`H=&]O
M;'1I<"DZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(E1I;"(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV,CD*;7-G
M:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H
M92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@
M8VQI8VMI;F<N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(E1O9&%Y(@IM<V=S='(@(DUE
M9VEN;>%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#D*(RP@9G5Z>GD*;7-G:60@(E1O9V\B"FUS9W-T<B`B
M5&EL(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA=2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4W"FUS9VED(")4
M;VUO<G)O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VYG
M82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S<*(RP@9G5Z>GD*;7-G:60@(E1O<"(*;7-G<W1R
M(")4:6PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDS"FUS9VED(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@(B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HV-3<*;7-G:60@(E1R86YS;&%T960B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S"FUS9VED(")4
M<F%N<VQA=&EO;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B
M5')I;FED860@86YD(%1O8F%G;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-SDT"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G
M:60@(E1U;FES:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B
M5'5R:V5Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DR
M"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$P"FUS9VED(")4=7)K;65N:7-T86XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P.`IM<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U=F%L=2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E
M('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(S,0IM<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR
M-#D@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@(E523"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4T,`IM<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S
M=&%T=7,@<F5P;W)T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3<*;7-G:60@(E523#HB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A;F1A(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3(*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,U"FUS9VED(")5;F%B;&4@=&\@
M86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B56YA8FQE('1O(&%D
M9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,C8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N
M(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C,P."!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N
M9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C<R"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HS-S$*;7-G:60@(E5N
M86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4V"FUS9VED(")5;F%B;&4@
M=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,34X(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C$V,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3@X
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ.3,*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P,0IM<V=I9"`B56YA8FQE('1O
M(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,S`S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(W-R!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,C4X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HR-#@*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C$R-`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9FEL92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3DX"FUS
M9VED(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O=&%R+G!H<#HW
M-@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-SD*
M;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C,V"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T
M;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,C4T(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M,S`U"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,3$@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,R-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO
M="!E;7!T>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Y(&%D
M;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92`G)7,G.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T,"!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,S0T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(V,"!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HS,S4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T,PHC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S,V"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S,P(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z,S0R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,3<P"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,C8@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HR,#8*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C$V-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P"B,Z(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,W,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,S<X"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,Q
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!R
M96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z-S(P"FUS9VED(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U
M<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8P,PIM<V=I9"`B56YA8FQE('1O(&5X=')A
M8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7TE-4U`O24U34"YP:'`Z-#4Q(&9R86UE=V]R:R].971?24U34"])
M35-0+T%U=&@N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3(Y(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C$S-`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,34X(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-C,*
M;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<V"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C`U(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,C(*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C$R-0IM<V=I9"`B56YA8FQE('1O(&]P96X@
M5D93(&9I;&4@9F]R('=R:71I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C8W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HW,@IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E
M<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"FUS9VED(")5;F%B;&4@=&\@<F5A
M9"!F:6QE.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z-3DR"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D
M:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,3`V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N
M86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES
M=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C(X-0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(T
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D
M:7)E8W1O<GDZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C(X,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z-3,S(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HR,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E
M;F%M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HR,S@@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C(Q,PHC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#4R(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR-S<*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(Y,PIM<V=I9"`B56YA8FQE('1O(')E
M;F%M92!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS9VED(")5;F%B
M;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B56YA8FQE
M('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ,C(@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HQ,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3$R"FUS9VED(")5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,#D@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,3,U"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4@9&%T82XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,`HC+"!F=7IZ>0IM<V=I9"`B56YD97)L:6YE
M(@IM<V=S='(@(D5N9'5R=F5K:F$B"@HC.B!T96UP;&%T97,O<')E9G,O96YD
M+FEN8SHV"B,L(&9U>GIY"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B
M0G)E>71A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,C(S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y
M,`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C
M;VYN96-T:6]N.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,T,0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS-S@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S@T"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R
M;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C0*(RP@9G5Z>GD*;7-G:60@
M(E5N9FEL960B"FUS9W-T<B`BTVQE<VGP(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HS.#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YH86YD;&5D(&-O;7!O;F5N="!O9B!T>7!E.B`E<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B56YI8V]D
M92`H551&+3@I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")5;FET
M960@07)A8B!%;6ER871E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G
M:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*
M;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,PIM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV
M.2!L:6(O0FQO8VLO;65T87(N<&AP.C8Y"FUS9VED(")5;FET<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,34@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$V"FUS9VED(")5;FMN;W=N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)
M($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO=VX@
M8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C$U,#$*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E5N:VYO=VX@8V]M;6%N9#H@)7,B"FUS9W-T<B`B4^9K:F$@)7,@
M>69I<B#A('9I;FYU<W3V\"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM<V=I9"`B56YK;F]W;B!U<V5R;F%M
M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"B,L(&9U>GIY"FUS
M9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(*;7-G<W1R(")3=&EL
M;&$@;OIV97)A;F1I('3M;6%B96QT:2XB"@HC.B!F<F%M97=O<FLO261E;G1I
M='DO261E;G1I='DN<&AP.C(Y-@IM<V=I9"`B56YN86UE9"(*;7-G<W1R("+3
M;F5F;G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@
M86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB
M<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A
M;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@
M=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@V(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3(V"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z.3,R"FUS9VED(")5;G-U<'!O<G1E9"!%
M>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8U
M-PHC+"!F=7IZ>0IM<V=I9"`B56YT<F%N<VQA=&5D(@IM<V=S='(@(M-S=F%R
M8?`B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#8@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ.#,*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;&ES="YI;F,Z,S,*(RP@9G5Z>GD*;7-G:60@(E5P9&%T92(*;7-G<W1R(")$
M86=S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV-#@*
M;7-G:60@(E5P9&%T92!R97-P;VYD96YT('-T871U<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S"FUS9VED(")5
M<&1A=&4@=7-E<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$S
M-R!A9&UI;B]P97)M<R]E9&ET+G!H<#HR,3<@<V5R=FEC97,O<VAA<F5S+V5D
M:70N<&AP.C(S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D("<E<R<N
M(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#DR('!O+W1R
M86YS;&%T:6]N+G!H<#HQ,C,P"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T
M:6YG("5S(&AE;'`@9FEL92!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.C@Q"FUS9VED(")5<&=R861E('-C<FEP="!D
M96QE=&5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3@Q(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ.#(*
M;7-G:60@(E5P;&]A9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3@Y"FUS9VED(")5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T
M=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM
M<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$X
M"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C,U('!O+W1R86YS;&%T:6]N+G!H<#HY,B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z.3,*(RP@9G5Z>GD*;7-G:60@(E5S86=E.B(*;7-G<W1R
M(")3:V5Y=&DB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-
M86YA9V5R+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N
M=#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU,S<*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,PIM<V=I9"`B57-E(&EF
M(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y
M+G!H<#HV,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@
M875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C(P,PIM<V=I9"`B57-E<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(U,`IM<V=I9"`B
M57-E<B!/<'1I;VYS(@IM<V=S='(@(E9A;&MO<W1I<B!N;W1A;F1A(@H*(SH@
M<VEG;G5P+G!H<#HV,@HC+"!F=7IZ>0IM<V=I9"`B57-E<B!296=I<W1R871I
M;VXB"FUS9W-T<B`B5F%L:V]S=&ER(&YO=&%N9&$B"@HC.B!S:6=N=7`N<&AP
M.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE
M9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E
M9&ET+G!H<#HQ-S(@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-#8*
M(RP@9G5Z>GD*;7-G:60@(E5S97(@<&5R;6ES<VEO;G,B"FUS9W-T<B`B5F%L
M:V]S=&ER(&YO=&%N9&$B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3@R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3,U"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.CDS"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y-R!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HS,PHC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C8U('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED
M(")5<V5R;F%M92(*;7-G<W1R(").;W1A;F1A;F%F;B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HQ,C0*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E5S97)N86UE("<E<R<@86QR96%D>2!E>&ES=',N(@IM<V=S
M='(@(DUA<'!A;B!<(B5S7"(@97(@;OH@_F5G87(@=&EL(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@W"B,L(&9U>GIY"FUS9VED(")5<V5R
M;F%M93HB"FUS9W-T<B`B3F]T86YD86YA9FXB"@HC.B!T96UP;&%T97,O;&]G
M:6XO;6]B:6QE+FEN8SHX"B,L(&9U>GIY"FUS9VED(")5<V5R;F%M93H@(@IM
M<V=S='(@(DYO=&%N9&%N869N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HR,3D*(RP@9G5Z>GD*;7-G:60@(E5S97)S(@IM<V=S='(@(DYO
M=&%N9&%N869N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-`IM<V=I9"`B57IB96MI<W1A;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,#$@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,3@X"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T
M(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3$U"B,L(&9U>GIY"FUS9VED(")686-A=&EO;B(*;7-G<W1R(")!\&=E
M<O`B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-C8*;7-G:60@(E9A
M;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,S@*;7-G:60@(E9A
M;&ED:71Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3DV"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-`IM<V=I9"`B5F%L=64@:6X@;6EN
M=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.#4V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q-S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L
M96YG=&@@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R-#0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$T(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Y,S(*;7-G:60@(E9A;'5E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`Y(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q.#8*;7-G:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")686YU871U(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3$*;7-G:60@(E9A
M<FEA8FQE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z
M=65L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@
M;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P"B,L
M(&9U>GIY"FUS9VED(")697)S:6]N(@IM<V=S='(@(E!E<G/S;G5L96=T(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(P,@IM<V=I9"`B5F5R<VEO
M;B!#;VYT<F]L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L(&%L
M:6=N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V"FUS9VED(")697)Y($AI
M9V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FEE="!.86TB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.30*;7-G:60@
M(E9I971N86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z.34S"B,L('!H<"UF;W)M870*;7-G
M:60@(E9I97<@)7,B"FUS9W-T<B`B4_UN82`E<R(*"B,Z(&QI8B]";&]C:R]I
M9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z.#$R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&%S("5S
M(@IM<V=S='(@(E/];F$@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C<Y"FUS9VED(")6:65W(&5V96YT(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z,3`Y"B,L(&9U>GIY"FUS9VED(")6:65W('1A<VLB"FUS9W-T<B`B
M4_UN82`E<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S
M+"!"<FET:7-H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I
M<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C`W"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C4*;7-G:60@(E9I<VEB
M:6QI='DZ("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=F]D869O;F5I=&%L>5]S;71P+G!H<#HW.0IM<V=I9"`B5F]D869O;F4@271A
M;'D@=FEA(%--5%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I
M9"`B5T%23B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'(2$A(%)%34]612!3
M0U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-PIM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O
M<W1A='5S+G!H<#HR.0IM<V=I9"`B5V%R;FEN9R(*;7-G<W1R(")!\';V<G5N
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$T-2!P;R]T<F%N<VQA=&EO;BYP
M:'`Z-C@Q('!O+W1R86YS;&%T:6]N+G!H<#HW,3$*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C<R-2!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`V,"!P;R]T<F%N<VQA
M=&EO;BYP:'`Z,3`V.0HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`W-R!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,3`X-R!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`Y-PHC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$P-R!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,3$Q,R!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(S-0HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,3(T-2!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(U,2!P;R]T<F%N<VQA
M=&EO;BYP:'`Z,3(W,0HC+"!F=7IZ>0IM<V=I9"`B5V%R;FEN9SH@(@IM<V=S
M='(@(D'P=O9R=6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H97(@1F]R96-A
M<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,P.0IM<V=I9"`B5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y,@IM<V=I9"`B5V5A
M=&AE<BYC;VTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M,S8*;7-G:60@(E=E8B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S8V"FUS9VED(")796(@4VET92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4X"FUS9VED
M(")7965K;'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL
M92YP:'`Z,C@*(RP@9G5Z>GD*;7-G:60@(E=E;&-O;64B"FUS9W-T<B`B5F5L
M:V]M:6XH;BD@[2`E<R(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC
M.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(E9E;&MO;6EN*&XI(.T@
M)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.2!T96UP;&%T
M97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E=E;&-O;64L("5S(@IM<V=S='(@(E9E;&MO;6EN*&XI(.T@)7,B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-0IM<V=I9"`B5V5S=&5R;B`H25-/
M+3@X-3DM,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.38*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R-PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA
M>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B36%P<&$@9?!A(&AA;75R('-E;2#A
M(&'P('/];F$@[2!U<'!H869I.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC.C(Q"FUS9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C
M=&5R/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHR-`IM<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H
M('!H87-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3,Q"FUS9VED(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I
M8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@(E=I9'1H
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,CD*
M;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S0W"B,L('!H<"UF;W)M870*;7-G:60@(E=I
M9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@
M;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@
M=&AE('1A8FQE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`U"FUS9VED(")7:61T:#HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0U.`IM<V=I9"`B5VEK:2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0HC+"!F
M=7IZ>0IM<V=I9"`B5VEN9"(*;7-G<W1R(")&:6YN82(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS9VED(")7:6YD($5A
M<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z-S@*;7-G
M:60@(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ-30*(RP@9G5Z>GD*;7-G:60@(E=I;F0Z(@IM<V=S
M='(@(D9I;FYA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P
M.0HC+"!F=7IZ>0IM<V=I9"`B5VEN9#H@(@IM<V=S='(@(D9I;FYA(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$W.0IM<V=I9"`B
M5VES:&QI<W1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV-0HC+"!F=7IZ>0IM<V=I9"`B5V]R:R(*;7-G<W1R(")E\&$B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*(RP@9G5Z
M>GD*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R(")396YD86YD86YE=&9A
M;F<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HQ,38Y"B,L('!H<"UF;W)M870*;7-G:60@(E=R:71I;F<@
M=7!D871E9"!H96QP(&9I;&4@=&\@)7,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR,C@*;7-G:60@(E@M4F5F(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DS"FUS
M9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3(*;7-G:60@(E@U
M,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!3
M=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3
M=6)J96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@R"FUS9VED(")8-3`Y=C,@97AT
M96YS:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM
M<V=I9"`B65DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C,X-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#(W"FUS9VED(")965E9(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#`R"FUS
M9VED(")986AO;R$@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN
M=&5N86YC92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$W"B,L(&9U>GIY"FUS9VED(")996UE;B(*
M;7-G<W1R("),97-I\"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HX.#@*;7-G:60@(EEE<R(*;7-G<W1R(")*X2(*"B,Z('1E
M;7!L871E<R]M86EN=&5N86YC92]A9W)E96UE;G1?8F]T=&]M+FEN8SHV"FUS
M9VED(")997,L($D@06=R964B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I
M;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B
M86-K('1O(%=94TE764<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,3(X.`IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC
M871E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT
M:71Y+G!H<#HS,#(*;7-G:60@(EEO=2!C86X@;F]T(&AA=F4@=&AE("=<7"<@
M8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4U(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y-S4*;7-G:60@(EEO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@
M96UA:6P@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O
M1&%T82YP:'`Z,C<P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N
M)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T
M:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDP,PHC+"!F=7IZ>0IM<V=I
M9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R(")3=&EL;&EN
M9V%R(/[M;F%R(&AA9F$@=F5R:?`@=7!P9N9R\&%R+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R-C$*;7-G:60@(B(*(EEO=2!H879E('1O(&5N
M=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET
M:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I
M86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,3@X"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED
M('9A;'5E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I
M9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4
M<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#,Q"FUS9VED(")9;W4@;75S="!C
M;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E
M<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R
M;V)L96T@<F5P;W)T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E
M<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*(RP@9G5Z>GD*
M;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E
M9"XB"FUS9W-T<B`B5F5L9'4@:'9A\&$@:V5N;FD@_OH@=FEL="!E>?!A+B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU
M<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`B
M5&EL9W)E:6YD=2!V:?!T86MA;F1A+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P
M,`HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE
M('1O(')E;6]V92XB"FUS9W-T<B`B5&EL9W)E:6YD=2!V:?!T86MA;F1A+B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T
M:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R("+>^B#^87)F="!F>7)S="!A
M\"!V96QJ82#^874@=FGP:&5N9VD@<V5M(/[Z('9I;'0@<V5N9&$@;67P('-K
M97ET:6YU+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@HC+"!F=7IZ>0IM<V=I
M9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*
M;7-G<W1R("+>^B#^87)F="!F>7)S="!A\"!V96QJ82#^874@=FGP:&5N9VD@
M<V5M(/[Z('9I;'0@<V5N9&$@;67P('-K97ET:6YU+B(*"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S-PHC+"!F=7IZ>0IM<V=I
M9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*
M;7-G<W1R(")4:6QG<F5I;F1U('9I\'1A:V%N9&$N(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S(*(RP@9G5Z>GD*
M;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS
M9W-T<B`B5&EL9W)E:6YD=2!V:?!T86MA;F1A+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.C@Y,0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R("5S
M('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS
M9W-T<B`B3&]T86X@)7,@97(@<G5N;FEN(/IT(.$@=.UM82X@5&5N9V1U(/YI
M9R!A9G1U<BXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS
M.`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@
M(DYE=&9A;F<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`R"FUS9VED
M(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@(D9U;&QT(&YE=&9A;F<@
M_FET="`H1G+A.BD@.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-"!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S0@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.0IM<V=I9"`B66]U<B!)
M;F9O<FUA=&EO;B(*;7-G<W1R(")5<'!L_7-I;F=A<B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.C@Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9
M;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E
M9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U
M<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S"B,L(&9U>GIY
M"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`B1G5L;'0@;F%F;B#^:71T.B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHY"FUS9VED("(B
M"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R
M="!A9&1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I
M<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHY"FUS9VED("(B"B)9
M;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L
M:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B"B)H87,@8F5E;B!D:7-A
M8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.C@Y.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN
M8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R
M;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C4P"B,L(&9U>GIY
M"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E
M871U<F4N(@IM<V=S='(@(B(*(E9E9G-K;_!A<FD@_FEN;B!S='GP=7(@96MK
M:2#^97-S82!P<F5N=&'P9V5R\"X@3F]T8?!U($-44DPO3W!T:6]N(&]G(%`@
M=&EL("(*(F'P('!R96YT82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]P
M<FEN="YJ<SHR-PIM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U
M<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO3W!T:6]N
M("L@4"!T;R`B"B)P<FEN="XB"FUS9W-T<B`B(@HB5F5F<VMO\&%R:2#^:6YN
M('-T>?!U<B!E:VMI(/YE<W-A('!R96YT8?!G97+P+B!.;W1A\'4@0U123"]/
M<'1I;VX@;V<@4"!T:6P@(@HB8?`@<')E;G1A+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR-#<*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z
M(@IM<V=S='(@(D[Z=F5R86YD:2!T[6UA8F5L=&DZ(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$T.`IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y
M.B(*;7-G<W1R(")3:N%L9F=E9FGP(&ME;FYI(/YI='0Z(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$Y,0IM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM
M<V=S='(@(D9U;&QT(&YA9FX@_FET=#HB"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z,30U"FUS9VED("(B"B)9;W5R(&=E='1E>'0@=F5R<VEO;B!I<R!T;V\@
M;VQD(&%N9"!D;V5S(&YO="!S=7!P;W)T(%!(4"!N871I=F5L>2Y<;B(*(DYO
M="!A;&P@<W1R:6YG<R!W:6QL(&)E(&5X=')A8W1E9"XB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-`HC
M+"!F=7IZ>0IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D
M(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R(")3
M=&EL;&EN9V%R(/[M;F%R(&AA9F$@=F5R:?`@=7!P9N9R\&%R+B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34V"FUS9VED(")9;W5R(&]P
M=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S='(@(E-T:6QL:6YG87(@
M_NUN87(@:&%F82!V97)I\"!U<'!FYG+P87(N(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E
M96X@<F5S970B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S
M970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W
M("(*(G!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z-3@*(RP@9G5Z>GD*;7-G:60@(EEO=7(@<F5M;W1E('-E
M<G9E<G,Z(@IM<V=S='(@(D9U;&QT(&YE=&9A;F<@_FET="`H1G+A.BD@.B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4T(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EEU9V]S;&%V:6$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I
M9"`B6F%I<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%M
M8FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EII;6)A8G=E
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I
M9"`B6FEP<'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R
M+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O
M=&5D(%1E>'1=(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP
M.C4V"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(");
M4VAO=R!1=6]T960@5&5X="`M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]4
M97AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE
M<UTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,30S,B!T96UP
M;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q"FUS9VED(")?061M:6YI<W1R871I
M;VXB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3,T"FUS9VED(")?0TQ)
M(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$R,@HC+"!F=7IZ>0IM<V=I
M9"`B7T1A=&%4<F5E(@IM<V=S='(@(D1A9W,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*(RP@9G5Z>GD*
M;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(D5Y\&$B"@HC.B!L:6(O87!I
M+G!H<#HQ,30*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W-0IM<V=I9"`B7TAE;'`B"FUS
M9W-T<B`B2&KA;'`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P97)T:65S
M+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU
M+G!H<#HQ.30*(RP@9G5Z>GD*;7-G:60@(E],;V<@:6XB"FUS9W-T<B`B5&5N
M9VIA<W0B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DP
M"FUS9VED(")?3&]G(&]U="(*;7-G<W1R("+:='-K<N$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G
M:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O365N=2YP:'`Z,38T"FUS9VED(")?3W!T:6]N<R(*;7-G
M<W1R(")686QK;W-T:7(B"@HC.B!L:6(O87!I+G!H<#HQ,3@*;7-G:60@(E]0
M97)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]296UO=F4@
M3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,#8*;7-G:60@
M(E]3971U<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S(*;7-G:60@(E]486)L92!0<F]P
M97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$Q,`IM<V=I
M9"`B7U5S97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.#DP"B,L(&9U>GIY"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T
M<B`B3F5T9F%N9V%B\VLB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S$Q"FUS
M9VED(")A;B!E<G)O<B!H87,@;V-C=7)E9#HB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HX.#(*;7-G:60@(F-A;&5N9&%R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<P(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G:60@(F-A;&TB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z
M-3@V"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HT-#4@<&\O=')A;G-L871I;VXN<&AP.C4U,"!P;R]T<F%N
M<VQA=&EO;BYP:'`Z-C$Q"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW-#D@<&\O
M=')A;G-L871I;VXN<&AP.C@Q,"!P;R]T<F%N<VQA=&EO;BYP:'`Z.#@W"FUS
M9VED(")D;VYE(@IM<V=S='(@(FQO:VGP(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C4U,B!P;R]T<F%N<VQA=&EO;BYP:'`Z-3@T('!O+W1R86YS;&%T:6]N
M+G!H<#HV,3,*(SH@<&\O=')A;G-L871I;VXN<&AP.C<W."!P;R]T<F%N<VQA
M=&EO;BYP:'`Z.#$R('!O+W1R86YS;&%T:6]N+G!H<#HX.3`*;7-G:60@(F9A
M:6QE9"(*;7-G<W1R(")K;&EK:V'P:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8W"FUS9VED(")F86QL:6YG(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@T.0IM<V=I
M9"`B9FEL92(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(Y
M"FUS9VED(")F;W5N9#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A<BYP:'`Z,S4X(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S@T"B,L('!H<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S
M("@E<RD@870@)7,@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,@IM<V=I9"`B:#HB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-C0*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C(R"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O9&EF9BYP:'`Z-C@@861M:6XO<V5T=7`O9&EF9BYP:'`Z-S8*
M(RP@9G5Z>GD*;7-G:60@(FEN;&EN92(*;7-G<W1R(")E;F=I;FXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B
M;&EN97-=(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR.#<@
M<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(P-0HC+"!F=7IZ>0IM<V=I
M9"`B;F%M92(*;7-G<W1R(").869N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C,W.`IM<V=I9"`B;F]T(&-H86YG960B"FUS9W-T<B`B(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C$S,0IM<V=I9"`B;F]T(&9O=6YD(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ,C$*(RP@9G5Z>GD*;7-G:60@
M(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R(")%:VMI(&5Y='0B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,3D*(RP@9G5Z>GD*;7-G
M:60@(FYO="!Y970@:6UP;&5M96YT960B"FUS9W-T<B`B16MK:2!E>71T(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HX-S0*(RP@9G5Z>GD*;7-G
M:60@(FYO=&5P860B"FUS9W-T<B`BTVQE<VGP(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.`IM<V=I9"`B<&5R
M8V5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*
M(RP@9G5Z>GD*;7-G:60@(G)I<VEN9R(*;7-G<W1R(")!\';V<G5N(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HY.`IM<V=I9"`B<VAO=R!D:69F97)E
M;F-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4Q,PIM<V=I9"`B<VUS,F5M86EL('9I82!(5%10
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8X"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HX.3@*(RP@9G5Z>GD*;7-G:60@(G1A<VL@
M;&ES="(*;7-G<W1R(")3=F%R=&QI<W1I(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C<R-0HC+"!P:'`M9F]R;6%T"FUS9VED(")T:&4@2&]R9&4@4$\@9FEL
M92!F;W(@=&AE(&QO8V%L92`E<R!D;V5S(&YO="!E>&ES=#HB"FUS9W-T<B`B
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@9G)A;65W;W)K+T%U=&@O075T:"]3
M:6=N=7`N<&AP.C(V.0IM<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@='=I8V4@
M=&\@8V]N9FER;2(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H
M<#HV."!A9&UI;B]S971U<"]D:69F+G!H<#HW-@IM<V=I9"`B=6YI9FEE9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U!A<G0N<&AP.C(W
M"B,L(&9U>GIY"FUS9VED(")U;FYA;65D(@IM<V=S='(@(M-N969N="(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HS-S4*;7-G:60@(G5P9&%T960B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU-C0*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C(R"B,L(&9U>GIY"FUS9VED(")U<V5R('-E;&5C="(*;7-G
M<W1R(")E;F=I;B!R96=L82!V86QI;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R
M-`HC+"!F=7IZ>0IM<V=I9"`B=SHB"FUS9W-T<B`BP69R86US+CHB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC
M;VTB"FUS9W-T<B`B(@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!O+W-L7U-)+G!O````````````````````````````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#8U-#0U-B`Q,#4Q-30S,S<T,B`P,3<U
M-3(`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M(R!3;&]V96YI86X@=')A;G-L871I;VYS(&9O<B!(;W)D92!P86-K86=A"B,@
M4VQO=F5N<VMI('!R979O9"!(;W)D92!P86ME=&$*(R!#;W!Y<FEG:'0@*$,I
M(#(P,#8@2&]R9&4@4')O:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E
M9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!H;W)D92!P86-K86=E
M+@HC($%U=&]M871I8V%L;'D@9V5N97)A=&5D+"`R,#`V+@HC"FUS9VED("(B
M"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B`N7&XB"B)297!O<G0M
M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R
M96%T:6]N+41A=&4Z(#(P,#8M,#<M,C4@,3$Z,S`K,#(P,%QN(@HB4$\M4F5V
M:7-I;VXM1&%T93H@,C`P-BTP-"TS,"`Q,#HS,BLP,3`P7&XB"B),87-T+51R
M86YS;&%T;W(Z(&1U8VM`;V)A;&$N;F5T7&XB"B),86YG=6%G92U496%M.B!S
M;%]322`\9'5C:T!O8F%L82YN970^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN
M(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/75T9BTX7&XB
M"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C4W"B,L('!H<"UF;W)M870*;7-G:60@
M(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B`H<')E9"`E<R!D;F5V:2DB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S-38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B`H1&]S=&]P;F$@
M=&EP:V$@)7,I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B`H
M=B`E<R!D;F5H*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C$*
M;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(BAD86YE<RDB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-C8S"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G
M<W1R(")*=71R:2`B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C4Y
M"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B*';$C65R86HI(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,"!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S4S"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS.3D*;7-G:60@(B!A="`B"FUS9W-T<B`B(&]B("(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z,C$P"B,L('!H<"UF;W)M870*;7-G:60@
M(EPB)7-<(B!I<R!N;W0@82!D:7)E8W1O<GDN(@IM<V=S='(@(EPB)7-<(B!N
M:2!I;65N:6LB"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<R"B,L('!H
M<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N
M(@IM<V=S='(@(EPB)7-<(B!J92!N979E;&IA=FYA(&EZ8FER82(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S@*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V86QI9"!E;6%I;"!A9&1R97-S
M+B(*;7-G<W1R(").:7-T92!V<W1A=FEL:2!V96QJ879N96=A(&5L96MT<F]N
M<VME9V$@;F%S;&]V82XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G
M:7-T<GDN<&AP.C<P,`HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T
M<GDN<&AP.C$P-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO
M="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B
M7"(E<UPB(&YE('IA>FYA;2!V($AO<F1O=F5M(')E9VES=')U("(*"B,Z(&9R
M86UE=V]R:R]4<F5E+U1R964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(B<E
M<R<@;F4@;F%J9&5M(&1R979E<V$@>F$@:7IR:7,N(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HU-0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D
M9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R("(G)7,G(&IE(&)I
M;"!D;V1A;B!S:W5P:6YS:V5M=2!S:7-T96UU(@H*(SH@861M:6XO<&5R;7,O
M861D8VAI;&0N<&AP.C4Q"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W
M87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B
M)R5S)R!J92!B:6P@9&]D86X@:R!D;W!U<W1N96UU('-I<W1E;74N(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HU,R!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z
M-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E871E
M9#H@)7,N(@IM<V=S='(@(B<E<R<@;FD@=7-T=F%R:F5N.B`E<R`B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T
M<B`B57!O<F%B;&IE;FEH("4N,F9-0B!O9"`E+C)F34(@9&]V;VQJ96YI:"`H
M)2XR9B4E*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S='(@(B5D
M("5S(&EN("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HR
M-C<@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4Y-`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RXB"FUS
M9W-T<B`BQ:!E("5D(&1N:2!D;R!P;W1E:V$@9V5S;&$B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C<X"B,L('!H<"UF;W)M870*;7-G:60@
M(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R("(E9"UD;F5V;F$@;F%P;W9E9"(*
M"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HV.`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R("(E<R#B@),@0F]D:71E('!O
M>F]R;FDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P
M-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*;7-G<W1R
M("(E<R!/9'1I<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C@S-R!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B)7,@2T(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S4@9G)A;65W
M;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0Q"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!-0B(*;7-G<W1R("(E<R!+0B(*"B,Z('-E<G9I
M8V5S+VUA:6YT96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S
M='(@(B5S(%9Z9'+%OF5V86QN82!D96QA("T@4&]T<F1I=&5V(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,C$S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B5S
M("`@("`@(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V
M-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N(%5P(@IM<V=S='(@(B5S
M('!R:6IA=F$B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S
M='(@(B5S(%!O9V]J:2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M-#0S(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DY"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z-CDX(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z-S8P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-S:#(N<&AP.C<P,"!F<F%M
M97=O<FLO5D93+U9&4R]S<V@R+G!H<#HW-C4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B5S(,6^92!O8G-T86IA
M+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<Q(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3<W(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Q"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S4W(&QI8B]";&]C:R]M971A<BYP:'`Z,S8S"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B5S(&]B("5S
M("5S(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0X"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE
M("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F
M;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B(@HB)7,@:F4@<')I<')A=FQJ
M96X@;F$@:7IV86IA;FIE('9Z9'+%OF5V86QN:6@@;W!E<F%C:6HL('!R979E
M<FD@<W!O9&%J+E!R979E<FD@(@HB;F%B:7)A;&YI:R!Z82!V<V4@;W!E<F%C
M:6IE+"!K:2!B:2!J:6@@<F%D(&]P<F%V:6P@<V5D86HN(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C8R.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!I<R!R97%U:7)E9"(*;7-G<W1R(")0;W1R96)U:F5M("5S("(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,CDX"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&UI;G5T97,B"FUS9W-T<B`B)7,@;6EN=70B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3,U"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`B)7,@;F4@;F%J9&5M(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R("(E<R!O8B`E<R!O9"`E
M<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(V"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(DEM96YI
M:R`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$X"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B2V]L961A
M<B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$P"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R(")"96QEQ;YK
M82`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,T"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B)7,@3W!R
M879I;&$B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S.B`E<R(*;7-G<W1R("(E<SH@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]H=&UL+G!H<#HQ,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C
M;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@(@HB86YY(&QI;FMS
M(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E
M<G-O;F%L(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"B(E<SH@=&\@<W!O<F_$
MC6EL;R!M;V=OQ(UE(&YI(&]D('!OQ:%I;&IA=&5L:F$L(&MA=&5R:2!P<F%V
M:2!D82!J92X@4&%Z:71E('-E("(*(FMA=&5R:6AK;VQI('!O=F5Z878@=B!S
M<&]R;\2-:6QU(&%L:2!P;V1A:F%N:G4@:V%T97)I:"!K;VQI(&]S96)N:6@@
M(@HB:6YF;W)M86-I:B!N82!T82!N87-L;W8N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,U-R!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-#`R"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(BP@9V]S=&EM("(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`P(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C`U"B,L('!H<"UF;W)M870*;7-G:60@(BP@9W5S=&EN9R`E<R`E<R(*
M;7-G<W1R("(L(&=O<W1I;2`E<R`E<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C$S"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E
M<R!T;R`E<R(*;7-G<W1R("(L('-P<F5M96YL:FEV:V$@;V0@)7,@9&\@)7,B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Y-"!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,T.`HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S4W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,38*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<U,`IM<V=I
M9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(BTM(&EZ8F5R:2`M+2(*"B,Z(&QI
M8B]";&]C:R]T:6UE+G!H<#HR-0IM<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS
M9W-T<B`B,3(@=7(@9F]R;6%T(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(T
M"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R("(R-"!U<B!F;W)M870B
M"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U
M<G,B"FUS9W-T<B`B,C0@=7(B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N
M<&AP.C8Y"FUS9VED("(\4')E=FEO=7,B"FUS9W-T<B`B4')E:L6A;FIA(&UO
MQ;YN;W-T(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,S$*;7-G:60@(D$@
M9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RXB
M"FUS9W-T<B`B6F$@=&$@8FQO:R!J92!P;W1R96)N82!P;W9E>F%V82!N82!P
M;V1A=&MO=FYI('-T<F7%OFYI:R(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,3<Q"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*
M;7-G<W1R(")0;VIA=FEL82!S92!J92!H=61A(&YA<&%K82XB"@HC.B!F<F%M
M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C0R.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)!(&UE<W-A9V4@:&%S(&)E96X@<V5N="!T;R!<(B5S7"(@
M=&\@=F5R:69Y('1H870@=&AI<R!I<R!R96%L;'D@>6]U<B`B"B)A9&1R97-S
M+B!4:&4@;F5W(&5M86EL(&%D9')E<W,@:7,@86-T:79A=&5D(&%S('-O;VX@
M87,@>6]U(&-O;F9I<FT@=&AI<R`B"B)M97-S86=E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@(D$@
M<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A
M9V4N(@IM<V=S='(@(EIA(&MO9&ER871I('-P;W)OQ(UI;&\@<&]T<F5B=6IE
M;2!J879N:2!01U`@:VQJ=<2-+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$Q-C@*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(DIA
M=FYI(%!'4"!K;&IUQ(T@:F4@<&]T<F5B96X@>F$@;V1K;&5P86YJ92!S<&]R
M;\2-:6QA+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P
M.3D*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B
M"B)M97-S86=E+B(*;7-G<W1R("(B"B)*879N:2!01U`@:VQJ=<2-+"!Z87-E
M8FYI(%!'4"!K;&IUQ(T@:6X@9V5S;&\@<V\@<&]T<F5B;FD@>F$@;V1K;&5P
M86YJ92`B"B)S<&]R;\2-:6QA+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$P,38*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R
M:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M('-I9VX@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"B)*879N:2!01U`@:VQJ
M=<2-+"!Z87-E8FYI(%!'4"!K;&IUQ(T@:6X@9V5S;&\@<V\@<&]T<F5B;FD@
M>F$@<&]D<&ES('-P;W)OQ(UI;&$N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU,#8*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K
M97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"B)*
M879N:2!3+TU)344@:VQJ=<2-+"!Z87-E8FYI(%,O34E-12!K;&IUQ(T@:6X@
M9V5S;&\@<V\@<&]T<F5B;FD@>F$@<&]D<&ES("(*(G-P;W)OQ(UI;&$N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G:60@
M(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M97-S
M86=E+B(*;7-G<W1R("(B"B)*879N:2!3+TU)344@:VQJ=<2-+"!Z87-E8FYI
M(%,O34E-12!K;&IUQ(T@:6X@9V5S;&\@<V\@<&]T<F5B;FD@>F$@<&]D<&ES
M("(*(G-P;W)OQ(UI;&$N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HS-C0*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U
M:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B($IA=FYI(%--
M24U%(&ML:G5E(&IE('!O=')E8F5N('IA(&]D:VQE<&%N:F4@<W!O<F_$C6EL
M82`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HY
M"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B3V)L8<2-;F\B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B04T@
M3&EG:'0@4F%I;B(*;7-G<W1R(")*=71R86YJ:2!286AE;"!D9<6^(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3$*;7-G:60@
M(D%-(%)A:6XB"FUS9W-T<B`B2G5T<F%N:FD@9&7%OB(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED(")!32!3:&]W
M97)S(@IM<V=S='(@(DIU=')A;FII(&YA;&EV(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-N;W<@4VAO
M=V5R<R(*;7-G<W1R(")*=71R86YJ:2!S;F7%OFYI(&UE=&7%OB(*"B,Z('1E
M;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R
M(")!32]032(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S='(@(D%022!)1"(*
M"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4S"FUS9VED(")!8F]U="XN
M+B(*;7-G<W1R(")/<&ES+BXN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C(X,@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@
M9&ER96-T;W)Y+B(*;7-G<W1R(")0<F5P;W9E9&%N(&1O<W1O<"!Z82!U<W1V
M87)J86YJ92!M87!E(%9&4RX@(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@
M9FEL92XB"FUS9W-T<B`B4')E<&]V961A;B!D;W-T;W`@>F$@=7-T=F%R:F%N
M:F4@9&%T;W1E:V4@5D93+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS
M"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(E9AQ:%I('!O
M9&%T:VDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@*;7-G:60@(D%C
M8V]U;G0@4&%S<W=O<F0B"FUS9W-T<B`B4&]T<F1I(&=E<VQO(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS
M9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`B27IV86IA;2(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#D*;7-G:60@(D%C8V]U;G1I;F<B
M"FUS9W-T<B`B27IV86IA;2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,30X('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0IM<V=I9"`B061D
M(@IM<V=S='(@(D1O9&%J(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C(@861M
M:6XO9W)O=7!S+G!H<#HR,C,*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G
M<W1R(")$;V1A:B!S:W5P:6YO(&]T<F]K(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HY."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.CDY"FUS9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R(")$;V1A
M:B!D;W9O;&IE;FIA(&]T<F]K82(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E
M>"YP:'`Z-S`*;7-G:60@(D%D9"!#;VYT96YT(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!9&0@2&5R93HB"FUS
M9W-T<B`B1&5D86H@<V5M.B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$V(&%D
M;6EN+V=R;W5P<RYP:'`Z,C$W"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S
M='(@(D1O9&%J(&YO=F\@<VMU<&EN;R(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX
M.`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(D1O9&%J(&YO
M=F$@9&]V;VQJ96YJ82(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D
M8VAI;&0N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@
M9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(D1O9&%J('-K=7!I;F\@;W1R;VL@
M7"(E<UPB(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T
M;R!<(B5S7"(B"FUS9W-T<B`B1&]D86H@9&]V;VQJ96YJ92!O=')O:V$@7"(E
M<UPB(@H*(SH@861M:6XO=7-E<BYP:'`Z,CD*;7-G:60@(D%D9"!A(&YE=R!U
M<V5R.B(*;7-G<W1R(")$;V1A:B!N;W9E9V$@=7!O<F%B;FEK83HB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34X"FUS9VED
M(")!9&0@8V]L=6UN(@IM<V=S='(@(D1O9&%J('-T;VQP96,B"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,T"FUS9VED(")!9&0@;F5W
M(&UE;6)E<G,B"FUS9W-T<B`B1&]D86H@;F]V92#$C6QA;F4B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@<&%I<B(*;7-G
M<W1R(")$;V1A:B!P87(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Q
M"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO
M>FEL;&$@4VED96)A<B(*;7-G<W1R(")$;V1A:B`E<R!-96YU('8@36]Z:6QL
M82!3:61E8F%R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C<Q"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R
M(")$;V1A:B!V(&EM96YI:SHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z-S@*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O
M;VLB"FUS9W-T<B`B1&]D86H@=B!M;VH@:6UE;FEK.B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C,P"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R(")$;V1A:B!U<&]R
M86)N:6MA(@H*(SH@861M:6XO=7-E<BYP:'`Z-S@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB061D960@7"(E<UPB('1O('1H92!S>7-T96TL(&)U="!C;W5L
M9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`B"B(E
M<RXB"FUS9W-T<B`B(@HB($1O9&%L("<E<R<@<VES=&5M=2P@=F5N9&%R(&)O
M(&YE;6]G;\2-92!D;V1A:F%N:F4@9&]D871N:6@@=G!I<VYI:"`B"B)I;F9O
M<FUA8VEJ.B`E<RXB"@HC.B!S:6=N=7`N<&AP.C0U"B,L('!H<"UF;W)M870*
M;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO
M9R!I;B!N;W<N(@IM<V=S='(@(D1O9&%N("<E<R<@<VES=&5M=2X@4V5D86H@
M<V4@;&%H:V\@<')I:F%V:71E+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N
M(@IM<V=S='(@(D1O9&%J86YJ92!U<&]R86)N:6MO=B!J92!O;F5M;V=OQ(UE
M;F\N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$R-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3<S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-30*;7-G:60@(D%D9')E
M<W,B"FUS9W-T<B`B3F%S;&]V(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$T.`IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(DEM96YI:R(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4V"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT"FUS9VED
M(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R
M<R(*;7-G<W1R(")5<F5D:2!D;W9O;&IE;FIA('IA(&]S=&%L92!U<&]R86)N
M:6ME(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q-PIM<V=I
M9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`B57!R879L:F%N:F4B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4W"FUS9VED(")!9',B"FUS9W-T
M<B`B4F5K;&%M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM
M<V=S='(@(D%F:&%N:7-T86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;&)A;FEA
M(@IM<V=S='(@(D%L8F%N:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B06QG97)I
M82(*;7-G<W1R(")!;,6^:7)I:F$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R(")/
M>FER;VUA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDR"FUS9VED(")!
M;&PB"FUS9W-T<B`B5G-E(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-0IM<V=I9"`B
M06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`B5G-I(&]V97)J96YI
M('5P;W)A8FYI:VDB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,R(&%D;6EN+V=R
M;W5P<RYP:'`Z,C(P"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S='(@(E9S92!S
M:W5P:6YE(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY,2!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O9&%T871R964N<&AP.C<U"FUS9VED(")!
M;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`B5G-A($1O=F]L:F5N:F$B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`Y"FUS9VED(")!;&QO=R!M=6QT
M:7!L92!A9&1R97-S97,B"FUS9W-T<B`B1&]V;VQI(&UN;V=O:W)A=&YE(&YA
M<VQO=F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(X"FUS9VED(")!
M;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R(")$
M;W9O;&D@;F%S=&%V:71V92`@(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A
M=&%4<F5E+W-Q;"YP:'`Z-3$X"FUS9VED(")!;')E861Y(&5X:7-T<R(*;7-G
M<W1R("+#@L6]92!O8G-T86IA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$R-@IM<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`B3F%D
M;VUE<W1N;R!)35-0('5P;W)A8FYIQ:%K;R!I;64B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3`R"FUS9VED(")!;'1E<FYA=&4@24U34"!087-S=V]R
M9"(*;7-G<W1R(").861O;65S=&YO($E-4U`@9V5S;&\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#DT"FUS9VED(")!;'1E<FYA=&4@24U34"!5<V5R
M;F%M92(*;7-G<W1R(").861O;65S=&YO($E-4U`@=7!O<F%B;FG%H6MO(&EM
M92(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED(")!
M;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R(").861O;65S=&YI(&5L
M96MT<F]N<VMI(&YA<VQO=B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30Q
M"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(DYA9&]M97-T
M;FD@=GIO<F-I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@4V%M;V$B
M"FUS9W-T<B`B($%M97)IQ:%K82!386UO82`B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N
M(@IM<V=S='(@(DYA=F5D96YA(&IE(&)I;&$@;F5Z86MO;FET82!V<F5D;F]S
M="XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38P"FUS9VED
M(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+B(*;7-G<W1R(")P;VIA
M=FEL82!S92!J92!N87!A:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O<G)A
M(@IM<V=S='(@(D%N9&]R82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*
M;7-G<W1R(")!;F=O;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;F=U:6QL82(*
M;7-G<W1R(")!;F=U:6QL82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R(")!;F]N
M:6UE;B!0<F]X>2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0Y
M"FUS9VED(")!;G-W97(B"FUS9W-T<B`B3V1G;W9O<B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*
M;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`B06YT87)K=&EC82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-38*;7-G:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B06YT
M:6=U82!I;B!"87)B=61A(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HW,R!A
M9&UI;B]P:'!S:&5L;"YP:'`Z,S0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+U5)+G!H<#HU."!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HT
M"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R(")!<&QI:V%C:6IA(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,
M:7-T(@IM<V=S='(@(E-E>FYA;2!A<&QI:V%C:6HB"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3,Y"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB
M"FUS9W-T<B`B07!L:6MA8VEJ82!J92!P<FEP<F%V;&IE;F$B"@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI
M;&0@4VAA<F5S(@IM<V=S='(@(E!R:6IA=FD@;W1R;VMO=F4@9&5L;FEC92`B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I
M9"`B07!P<F]V92(*;7-G<W1R(")0;W1R9&DB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Y"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B07!R:6PB"FUS9W-T
M<B`B07!R:6PB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B
M07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(D%R86)S:VD@*%=I;F1O
M=W,M,3(U-BDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C4Y(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C8*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.`IM<V=I
M9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`B5F5L:6MO<W0@9&%T;W1E
M:V4@07)H:78@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HU."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8U
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S<*;7-G
M:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R("));64@07)H:79A(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E
M('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R(")3=&4@<')E
M<')IQ(UA;FDL(&1A(,6^96QI=&4@<')E:VQI8V%T:2!Z86AT979O('IA('!R
M:6IA=F\@>F$@)7,@/R`B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E
M;&5T92YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@
M>6]U('=I<V@@=&\@9&5L971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_
M(@IM<V=S='(@(E-T92!P<F5P<FG$C6%N:2P@9&$@Q;YE;&ET92!I>F)R:7-A
M=&D@)R5S)R!I;B!O<W1A;&4@<&]D<VMU<&EN93\B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS
M9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B07)G96YT:6YA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M-PIM<V=I9"`B07)M96YI82(*;7-G<W1R(")!<FUE;FEJ82(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")!<FUE;FEA;B`H05)-4T-)22TX
M*2(*;7-G<W1R(")!<FUE;G-K:2`H05)-4T-)22TX*2(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B07)T(@IM<V=S='(@(E5M971N;W-T
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B07)U8F$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I
M;VX@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS-`IM<V=I9"`B07-C:6D@07)T(@IM<V=S='(@(E5M971N;W-T:2#$C7)K
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!
M<VEA+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@(D%Z:6$O4&%C:69IQ:%K92!R
M96=I:F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(Y"FUS9VED(")!
M<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<S\B"FUS9W-T<B`B5G!R8<6A86H@>F$@<&]T<F1I=&5V('!R
M960@:7IV86IA;FIE;2!V>F1RQ;YE=F%N:F$B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,S@R"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS
M9W-T<B`B1&]D96QJ96YE(&MO;&]N92(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M-S,*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R
M;W5P+B(*;7-G<W1R(")0;W-K=7,@:7IB<FES82!N96]B<W1O:F7$C64@<VMU
M<&EN92XB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C(X"FUS9VED(")!
M='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*
M;7-G<W1R(")0;W-K=7,@:7IB<FES82!N96]B<W1O:F7$C65G82!D;W9O;&IE
M;FIA+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@V"FUS9VED(")!='1E
M;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T
M<B`B4&]S:W5S('5R961I='9E(&YE;V)S=&]J9<2-96=A(&1O=F]L:F5N:F$N
M(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4X"FUS9VED(")!='1E
M;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(E!O
M<VMU<R!U<F5D:71V92!N96]B<W1O:F7$C64@9&5L;FEC92XB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8T(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HX,PIM<V=I9"`B071T<FEB=71E<R(*;7-G
M<W1R("),87-T;F]S=&DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-3$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHW-`IM<V=I9"`B075G=7-T(@IM<V=S='(@(D%V9W5S="(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R(")!=G-T<F%L
M:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')I82(*;7-G<W1R(")!=G-T
M<FEJ82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS,38*
M;7-G:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B!!=71H7V-Y<G5S.B!:86AT979A;F\@:6UA
M<"#%H6ER:71E=B!N:7-E;2!N8<6A96PN(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]C>7)U<RYP:'`Z,3,Q"FUS9VED(")!=71H7V-Y<G5S.B!"86-K96YD
M(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N(@IM<V=S='(@
M(D%U=&A?8WER=7,Z($)A8VME;F0@;FEM82!Z86AT979A;FEH('IM;\6^;F]S
M=&DN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C,T"FUS
M9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER=7,Z(%IA:'1E=F%N;R!I;6%P(,6A
M:7)I=&5V(&YI<V5M(&YAQ:%E;"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V9T<"YP:'`Z-38*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@
M97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE
M;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B(@HB075T:%]F='`Z(%IA
M:'1E=F%N;R!&5%`@Q:%I<FET978@;FES96T@;F'%H65L+B!)>G!O;&YI(%!(
M4"!Z("UO;F5M;V=OQ(UE;F\M(&9T<"`B"B)Z86UE;FIA=F\N("(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`T"FUS9VED(")!=71H7VEM
M87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B075T:%]I;6%P:'1E=F%N;R!)34%0:71E=B!N:7-E;2!N8<6A96PN(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW,PIM<V=I9"`B075T
M:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(D%U=&A?:W)B-3H@6F%H=&5V86YO(&MR8C4@Q:%I<FET978@;FES
M96T@;F'%H65L+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M,S`Q"FUS9VED(")!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P
M<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(D%U=&A?;&1A
M<#H@3FD@;6_%OFYO(&1O9&%J86YJ92!U<&]R86)N:6MO=B!V($%C=&EV92!$
M:7)E8W1O<GDB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,U
M-@IM<V=I9"`B075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P
M<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(D%U=&A?;&1A
M<#H@3FD@;6_%OFYO(&]D<W1R86YJ979A;FIE('5P;W)A8FYI:V]V('8@06-T
M:79E($1I<F5C=&]R>2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z.3(*;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VQD87`Z(%IA:'1E=F%N;R!,
M1$%0(,6A:7)I=&5V(&YI<V5M(&YAQ:%E;"XB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C,S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H
M7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H
M92!S97)V97(@<V%I9#H@(@IM<V=S='(@(D%U=&A?;&1A<#H@3F4@;6]R96T@
M9&]D871I('5P;W)A8FYI:V$@)7,N(%-P;W)OQ(UI;&\@<W1R9<6^;FEK83H@
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS.#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S
M97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B!.92!M;W)E;2!O9'-T<F%N:71I
M('5P;W)A8FYI:V$@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C0Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L
M92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z($YE(&UO
M<F5M(&YA9&=R861I=&D@=7!O<F%B;FEK82`E<R`B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C0P-`IM<V=I9"`B075T:%]L9&%P.B!5<&1A
M=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T
M;W)Y+B(*;7-G<W1R(")!=71H7VQD87`Z(&YE(&UO<F5M(&YA9&=R86IE=F%T
M:2!U<&]R86)N:6MO=B!V($%C=&EV92!$:7)E<W1O<GDN(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]M8V%L+G!H<#HV,@IM<V=I9"`B075T:%]M8V%L.B!2
M97%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U
M=&A?;6-A;#H@6F%H=&5V86YO($U#04P@Q:%I<FET978@;FES96T@;F'%H65L
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HX-@IM<V=I9"`B
M075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(D%U=&A?<VUB875T:#H@6F%H=&5V86YE9V$@<VUB
M875T:"!Z82#%H6ER:71E=B!N:7-E;2!N8<6A96PN(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!9&UI;BYP:'`Z,3`V"FUS9VED(")!=71H96YT:6-A=&EO
M;B!A="!)34%0('-E<G9E<B!F86EL960N(@IM<V=S='(@(D]V97)J86YJ92!Z
M82!&5%`@<W1R9<6^;FEK(&YI('5S<&5L;RXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@(D%U=&AE
M;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R(")/=F5R:F%N:F4@;FD@=7-P96QO
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C8W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N
M(&9A:6QE9"X@)7,B"FUS9W-T<B`B3W9E<FIA;FIE(&YI('5S<&5L;RX@)7,B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,3@R"FUS9VED
M(")!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*
M;7-G<W1R(")/=F5R:F%N:F4@:F4@>F%V<FYI;"!2041)55,@<W1R9<6^;FEK
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#<S"FUS9VED(")!
M=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B
M3W9E<FIA;FIE('IA($944"!S=')EQ;YN:6L@;FD@=7-P96QO+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-S:#(N<&AP.C@X.0HC+"!F=7IZ>0IM<V=I9"`B
M075T:&5N=&EC871I;VX@=&\@4U-(,B!S97)V97(@9F%I;&5D+B(*;7-G<W1R
M(")/=F5R:F%N:F4@>F$@1E10('-T<F7%OFYI:R!N:2!U<W!E;&\N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HW,`IM<V=I9"`B075T:&5N=&EC
M871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")/=F5R
M:F%N:F4@>F$@4TU"('-T<F7%OFYI:R!N:2!U<W!E;&\N(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD
M<SHB"FUS9W-T<B`B4&]L:F$@;F$@<F%Z<&]L86=O.B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*
M;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B07IE<F)A:F3%OF%N("(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0IM<V=I9"`B0D]&2"!%>&-U<V5S
M(@IM<V=S='(@(DYE=6UN:2!I>F=O=F]R:2(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:W)B-2YP:'`Z.#(*;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R
M9"XB"FUS9W-T<B`B3F%P8<2-;F\@:V5R8F5R;W,@9V5S;&\N(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX-`IM<V=I9"`B0F%D(&ME<F)E
M<F]S('5S97)N86UE+B(*;7-G<W1R(").87!AQ(UN;R!K97)B97)O<R!U<&]R
M86)N:<6A:V\@:6UE+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A:&%M87,B"FUS
M9W-T<B`B0F%H86UI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H<F%I;B(*;7-G
M<W1R(")"86AR86EN(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G
M:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(D)A;'1I:R`H25-/
M+3@X-3DM,3,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G
M<W1R(")"86YG;&%D9<6A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HS,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B
M"FUS9W-T<B`B0F%R8F%D;W,B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z
M,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O
M<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B3FES96T@;F'%H65L(&]S
M;F]V;F5G82!G<F%F:<2-;F5G82!I;65N:6MA(%PB)7-<(BXB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8S"FUS9VED(")"96QA<G5S(@IM<V=S='(@(D)E;&]R=7-I:F$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8P"FUS9VED(")"96QG:75M(@IM<V=S='(@(D)E;&=I:F$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8S"FUS9VED(")"96QI>F4B"FUS9W-T<B`B0F5L:7IE(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,0IM<V=I9"`B0F5N:6XB"FUS9W-T<B`B0F5N:6XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R
M"FUS9VED(")"97)M=61A(@IM<V=S='(@(D)E<FUU9'-K:2!O=&]K:2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R(")"=71A;B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G:60@
M(D)I<G1H9&%Y(@IM<V=S='(@(E)O:G-T;FD@9&%N(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,V.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")";&]C:R!<(B5S7"(@;V8@87!P;&EC871I;VX@7"(E<UPB(&YO
M="!F;W5N9"XB"FUS9W-T<B`B3FES96T@;F'%H65L(&)L;VMA(%PB)7-<(BP@
M87!L:6MA8VEJ92!<(B5S7"(@+B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHY,`IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B6F%U
M<W1A=FD@3F%S=&%V:71V92(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T
M+FEN8SHW,@IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R("):875S=&%V:2!4
M:7`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8R"FUS9VED(")";VQI=FEA(@IM<V=S='(@(D)O;&EV
M:6IA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R,0IM<V=I9"`B
M0F]O:VUA<FMS(@IM<V=S='(@(E!R:6QJ=6)L:F5N92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HS-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*
M;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B"FUS9W-T<B`B0F]S;F$@
M:6X@2&5R8V5G;W9I;F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,3`Q
M"FUS9VED(")";W1H(@IM<V=S='(@(D]B;VII(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I
M9"`B0F]T<W=A;F$B"FUS9W-T<B`B0F]C=F%N82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G
M:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B0F]U=F5T;W9O(&]T;\2-:F4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8R"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B0G)A>FEL:6IA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#$*;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E
M<G)I=&]R>2(*;7-G<W1R("(@0G)I=&%N<VMO(&]Z96UL:F4@26YD:6IS:V5G
M82!O8V5A;F$@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L
M86TB"FUS9W-T<B`B0G)U;F5I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5L9V%R
M:6$B"FUS9W-T<B`B0F]L9V%R:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R
M:VEN82!&87-O(@IM<V=S='(@(D)U<FMI;F$@1F%S;R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*
M;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B0G5R=6YD:2(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT-C<*;7-G:60@(D--4R(*;7-G<W1R(")-4T<B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS
M9VED(")#4D,B"FUS9W-T<B`B0U)#(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.3@*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I
M;G1S(@IM<V=S='(@(B!#4DP@<F%Z9&5L:71V96YE('1OQ(UK92`B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34V"FUS9VED(")#86-H92!I
M;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R(").87-T879L:F%N:F4@
M<')E9'!O;6YI;&YI:V$@;FD@9&]K;V[$C6%N;RXB"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDQ-B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#@Y"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#DR
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-C0*;7-G:60@(D-A;&5N9&%R
M(@IM<V=S='(@(DMO;&5D87(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C0P"FUS9VED(")#86QM(@IM<V=S='(@(EIB<FG%H6DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B2V%M8F]DQ;YA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B2V%M97)U;B(*
M"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,0IM<V=I9"`B0V%N)W0@861M:6YI
M<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+B(*;7-G<W1R(").92!M
M;W)E:F\@=7!R879L:F%T:2!Z=6YA;FII('5P<F%V;&IA;&-I(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C0Q(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER<W%L+G!H<#HS,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N
M)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`B3F4@;6]R
M96T@=GIP;W-T879I=&D@<&]V97IA=F4@>B!)34%0('-T<F7%OFYI:V]M.B`E
M<R`B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS9W-T
M<B`B3FD@;6]G;\2-92!O9'!R971I(%PB)7-<(B!D871O=&5K92XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8T"FUS9VED(")#86YA9&$B"FUS9W-T<B`B2V%N861A(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3`P(&%D;6EN+W5S97(N<&AP.C$Q.2!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O8VQE87(N:6YC.C$R('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*;7-G<W1R("):8G)IQ:%I(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3(*;7-G:60@(D-A;F-E
M;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")P;W)OQ(UI;&\@;R!T9<6^879A
M:"!Z(&)R:7-A;FIE;2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,#0@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT,C<*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,C0X(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M-C<W"B,Z(&9R86UE=V]R:R]61E,O5D93+W-S:#(N<&AP.C8W.2!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C$U"FUS9VED(")#86YN;W0@8V]P
M>2!F:6QE*',I("T@<V]U<F-E(&%N9"!D97-T:6YA=&EO;B!A<F4@=&AE('-A
M;64N(@IM<V=S='(@(DYE(&UO<F5M(&MO<&ER871I(&1A=&]T96L@*&4I("T@
M=FER(&EN(&-I;&IA('-T82!I<W1A+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z,S(S(&9R86UE=V]R:R]61E,O5D93+W-S:#(N<&AP.C,Q-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R(").92!M;W)E;2!I>F)R:7-A=&D@9&%T;W1E:V4@7"(E<UPB
M+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HT-@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP
M.C4R"FUS9VED(")#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN
M(@IM<V=S='(@(DYE(&YA:F1E;2!Z8<2-87-N92!D871O=&5K+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#@S(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C(P-PHC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<S
M.2!F<F%M97=O<FLO5D93+U9&4R]S<V@R+G!H<#HW-#,*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$V.0IM<V=I9"`B0V%N;F]T(&UO=F4@
M9FEL92AS*2`M(&1E<W1I;F%T:6]N(&ES('=I=&AI;B!S;W5R8V4N(@IM<V=S
M='(@(DYE(&UO<F5M('!R96UA:VYI=&D@9&%T;W1E:R`H92D@+2!C:6QJ(&IE
M('IN;W1R86H@=FER82XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(N<&AP.CDQ"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T
M("=T87)G971&:6QE)R!P87)A;65T97(N(@IM<V=S='(@(DYE(&UO<F5M(&YA
M9&%L:F5V871I(&)R97H@<&%R86UE=')O=B`G8VEL:FYE(&1A=&]T96ME)RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q.2!F<F%M97=O<FLO
M5D93+U9&4R]S<V@R+G!H<#HS,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N
M;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")<(B5S7"(@
M26UE;FEK82!N92!M;W)E;2!Z8G)I<V%T:2XB"@HC.B!F<F%M97=O<FLO1&%T
M851R964O1&%T851R964N<&AP.C$R."!F<F%M97=O<FLO1&%T851R964O1&%T
M851R964O<W%L+G!H<#HV.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T
M(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(DYE(&UO<F5M
M(&]D<W1R86YI=&D[(&]B<W1A:F$@)60@<&]D=F5L:B(*"B,Z(&9R86UE=V]R
M:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8R,@IM<V=I9"`B(@HB0V%N
M;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R
M96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM<V=S
M='(@(B(*(DYE(&UO<F5M('!O;F]V;F\@=7)E9&ET:2P@Q:%T979I;&\@9&%N
M:6@@=FYO<V]V('-E(&YE('-K;&%D82!S(,6A=&5V:6QO;2`@(@HB<VAR86YJ
M96YI:"XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I
M9"`B0V%N;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A
M8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R(").92!M;W)E;2!A=G1O
M;6%T<VMO('!O;F%S=&%V:71I(&=E<VQA+"!O8G)N:71E('-E(&YA('-K<F)N
M:6MA(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C
M:69I960@;G5M8F5R+B(*;7-G<W1R(").92!M;W)E;2!P<F5U<VUE<FET:2!S
M<&]R;\2-:6QA(&YA=F5D96YE;74@Q:%T979I;'4N(@H*(SH@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z,S4P"B,L('!H<"UF;W)M870*;7-G:60@(D-A
M;FYO="!W<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R(")#86YN;W0@=W)I
M=&4@=&\@9FEL92!<(B5S7"(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#87!E(%9E
M<F1E(@IM<V=S='(@(DMA<'9E<F1S:VD@;W1O:VDB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I
M97(B"FUS9W-T<B`B4')I;F'%H6%L96,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.3,*;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R
M(")+871E9V]R:6IE(&EN('IN86UK92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")#
M87EM86X@27-L86YD<R(*;7-G<W1R(")+87EM86YS:VD@;W1O:VDB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED
M(")#96QL(%!H;VYE(@IM<V=S='(@(DUO8FEL;FD@=&5L969O;B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R.#,*;7-G:60@(D-E;&QP:&]N92(*
M;7-G<W1R(")-;V)I;&YI('1E;&5F;VXB"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X,0IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B
M2V5L='-K:2`H25-/+3@X-3DM,30I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HU-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V5N
M=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@(D-E;G1R86QN;R!!9G)I
MQ:%K82!297!U8FQI:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,@IM
M<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T<B`B
M4W)E9&YJ965V<F]P<VMI("A)4T\M.#@U.2TR*2(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED(")#97)T:69I8V%T92!$
M971A:6QS(@IM<V=S='(@(E!O9')O8FYO<W1I('!O=')D:6QA(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3(*;7-G:60@(D-E<G1I
M9FEC871E($]W;F5R(@IM<V=S='(@(DQA<W1N:6L@<&]T<F1I;&$B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B0V5R
M=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B4')A=FEL82!P;W1R9&EL82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P.`IM<V=I9"`B0VAA9"(*;7-G<W1R(")%860B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.CDV"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B4W!R96UE
M;FDB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*;7-G:60@
M(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(G-P<F5M96YI=&4@=F'%
MH64@9V5S;&\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-CD*;7-G:60@
M(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S
M964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS
M+B(*;7-G<W1R("(B"B)3<')E;65N:71E(&EM92!I;B!N87-L;W8@=F'%H65G
M82!E;&5K=')O;G-K96=A(&YA<VQO=F$L(&MI(&=A("(*(G9I9&EJ;W!R96IE
M;6YI:VD@;V(@8G)A;FIU(&EN(&]D9V]V87)J86YJ=2!N82!V8<6A;R!P;\6A
M=&\N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED
M("(B"B)#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@
M=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(E8@=')E;G5T;FD@:V]N
M9FEG=7)A8VEJ92!N92!M;W)E=&4@<W!R96UE;FET:2!G97-L82X@2V]N=&%K
M=&ER86IT92!V8<6A96=A("(*(G-K<F)N:6MA+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(P,3<*(RP@9G5Z>GD*;7-G:60@(D-H87)A8W1E<B!T
M;R!S<&QI="!M=6QT:7!L92!A9&1R97-S97,@=VET:"(*;7-G<W1R(")$;W9O
M;&D@;6YO9V]K<F%T;F4@;F%S;&]V92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H
M:6QE(@IM<V=S='(@(L2-:6QE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;F$B
M"FUS9W-T<B`B2VET86IS:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M,PIM<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@
M(E!O96YO<W1A=FQJ96YA(&MI=&%JQ:'$C6EN82A'0C(S,3(I(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N
M86P@*$)I9S4I(@IM<V=S='(@(E1R861I8VEO;F%L;F$@:VET86K%H<2-:6YA
M("A":6<U*2(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C<*;7-G:60@
M(D-H;V]S92!!<'!L:6-A=&EO;CHB"FUS9W-T<B`B27IB97)I(&%P;&EK86-I
M:F\Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W,0IM
M<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B27IB97)I(&=E<VQO
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W,`IM<V=I
M9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B27IB97)I('5P;W)A8FYI
MQ:%K;R!I;64B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`R"FUS9VED
M(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(DMA:V\@
M<')I:V%Z871I(&1A='5M93HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-34*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#:')I<W1M
M87,@27-L86YD(@IM<V=S='(@(D)OQ;YIQ(UN:2!O=&]K:2(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4RYP:'`Z,CDT(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HY.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O
M9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(DYI<V5M(&YAQ:%E;"!D969I;FEC
M:6IE('9R<W1E('IA("5S+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$T"FUS9VED(")#;&5A<B(*;7-G<W1R(")*87-N;R(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C<*;7-G:60@(D-L96%R(%%U97)Y
M(@IM<V=S='(@(E!R9<2-:7-T:2!P;VEZ=F5D8F4B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B3V1S=')A;FD@>G5N86YJ96=A
M('5P;W)A8FYI:V$Z("5S("(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L
M96%R+FEN8SHQ,0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R(")/9'-T<F%N
M:2!U<&]R86)N:6MA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI
M;F,Z,S0*;7-G:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R("))>F)R:<6A
M:2!P;V1A=&5K('5P;W)A8FYI:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G
M<W1R(")I>F)R:<6A:2!P;W1E;2(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]M86EN=&5N86YC92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU
M92(*;7-G<W1R(")+;&EK;FD@>F$@;F%D86QJ979A;FIE("(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I
M9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R(")#;&EC:V%T96QL('!R
M;W1O;2!(5%10(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B
M"FUS9W-T<B`B6F%P<FD@;VMN;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C4V"FUS9VED(")#;&]U9',B"FUS9W-T<B`B3V)L86MI(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*;7-G:60@(D-L;W5D
M<R!%87)L>2(*;7-G<W1R(")::G5T<F%J($]B;&'$C6YO(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3<*;7-G:60@(D-L;W5D
M>2(*;7-G<W1R(")/8FQAQ(UN;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-O8V]S
M("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(DMO:V]S;W9I(&]T;VMI(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR-`IM<V=I9"`B0V]L
M;&%P<V4@4VED96)A<B(*;7-G<W1R("):9')UQ;YI('-T<F%N<VMO(&]K;F\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8W"FUS9VED(")#;VQO;6)I82(*;7-G<W1R(")+;VQU;6)I
M:F$B"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO
M<BYP:'`Z,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@(D)A<G9A(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,T,`HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S0Q"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,#<@<V5R=FEC97,O
M:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,@IM<V=I9"`B0V]L;W(@4&EC:V5R
M(@IM<V=S='(@(DEZ8FER86QE8R!B87)V(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$Q-@IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R
M("(@27IB:7)A($)A<G9E("(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(R,S0*;7-G:60@(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B3F%S;&]V('-T
M;VQP:6-A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X,`IM<V=I
M9"`B0V]M:6-S(@IM<V=S='(@(E-T<FEP:2(*"B,Z(&%D;6EN+V-M9'-H96QL
M+G!H<#HR-`IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R(")5:V%Z(@H*(SH@861M
M:6XO8VUD<VAE;&PN<&AP.C$X"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S
M='(@(E5K87IN82!L=7!I;F$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,3,*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B2V]M96YT87(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-PIM<V=I
M9"`B0V]M;6]N($YA;64B"FUS9W-T<B`B4VMU<&YO(&EM92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@T"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(DMO;6]R:2`B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#
M;VUP86YY(@IM<V=S='(@(D1R=<6^8F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S8*;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R(")28<2-=6YA;&YI
M:VDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDP"FUS9VED
M(")#;VYD:71I;VXB"FUS9W-T<B`B3F%S=&%V:71E=B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C8Q"FUS9VED(")#;VYD:71I;VYS(@IM<V=S='(@(DYA
M<W1A=FET=F4B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HY-@IM<V=I9"`B
M0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*;7-G<W1R(")287IL:6ME(&YA
M<W1A=FET=F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30V"FUS9VED
M(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P
M:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@(DYA<W1A=FET=F4@>F$@<VEN
M:W)O;FEZ86-I:F%O(&1L86[$C6YI:V]V(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$S-`IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T
M92XB"FUS9W-T<B`B3F%S=&%V:71V92!P;W1R96)U:F5J;R!AQ;YU<FER86YJ
M92(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(DYA<W1A=FD@)7,B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4R"FUS9VED(")#
M;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(E!O=')D:2!G97-L;R(*"B,Z(&9R
M86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z-#`W"B,L(&9U>GIY"FUS
M9VED(")#;VYF:7)M(&YE=R!E;6%I;"!A9&1R97-S(@IM<V=S='(@(DYA9&]M
M97-T;FD@96QE:W1R;VYS:VD@;F%S;&]V(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B
M0V]N9V\B"FUS9W-T<B`B2V]N9V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#;VYG
M;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@(DMO
M;F=O+"!$96UO:W)A=&G$C6YA(')E<'5B;&EK82(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y-PHC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#@*;7-G:60@(D-O;FYE8W1I;VX@
M9F%I;&5D+B(*;7-G<W1R(")0;W9E>F%V82!N:2!U<W!E;&$N(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DW"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.`IM<V=I9"`B0V]N
M;F5C=&EO;B!F86EL960Z("(*;7-G<W1R(")0;W9E>F%V82!N:2!U<W!E;&$Z
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDP"FUS9VED
M(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N
M(@IM<V=S='(@(EIA=G)N:F5N82!P;W9E>F%V82!Z(&IA=FYI;2!K;&IUQ(UN
M:6T@<W1R9<6^;FEK;VTN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-SDR"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F
M=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I
M(@IM<V=S='(@(EIA=G)N:F5N82!P;W9E>F%V82!Z(&IA=FYI;2!K;&IUQ(UN
M:6T@<W1R9<6^;FEK;VTN(%)A>FQO9SH@)7,@*"5S*2(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#8W"FUS9VED(")#;VYN96-T:6]N('1O($94
M4"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")0;W9E>F%V82!S($944"!S=')E
MQ;YN:6MO;2!N:2!U<W!E;&$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W-H
M,BYP:'`Z.#@S"B,L(&9U>GIY"FUS9VED(")#;VYN96-T:6]N('1O(%-32#(@
M<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B4&]V97IA=F$@<R!&5%`@<W1R9<6^
M;FEK;VT@;FD@=7-P96QA+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3(T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,3,W"FUS9VED(")#;VYT
M86-T<R(*;7-G<W1R(")3=&EK:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C
M97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@
M(E-T:6L@:F4@8FEL('5S<&7%H6YO(&1O9&%N(&L@=F'%H6EM(&YA<VQO=F]M
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-C`*
M;7-G:60@(D-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z("(*;7-G
M<W1R(")4:7`@<W1I:V$@<W1I<VYJ96YE(&1A=&]T96ME.B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R(")6<V5B:6YE(&]D7"(E<UPB(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C,S"FUS9VED(")#;VYT:6YU92(*;7-G<W1R(").
M861A;&IU:B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G
M<W1R(")#;V]K;W9I(&]T;VMI(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,W"FUS9VED(")#;V]K:64B"FUS9W-T<B`B4&G%H6MO=&5K(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@(DMO<&ER86YJ92!N:2!U<W!E
M;&\Z("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HQ-S`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ
M.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B240@<W1R;\6A96LB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8W"FUS9VED(")#;W-T82!2:6-A(@IM<V=S='(@(DMO<W1A<FEK82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C8*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B(%-L
M;VYO:V_%H<2-96YA(&]B86QA("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.CDW-PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE
M<W-A9V4Z("(*;7-G<W1R(")01U`@;F4@;6]R92#%H6EF<FER871I('-P;W)O
MQ(UI;&$Z(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`U
M-0IM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z("(*;7-G<W1R
M(").:2!M;V=O92!01U`@<&]D<&ES('-P;W)O96EL82XB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@;F]T
M(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(DYI(&UO9V_$C64@
M4R]-24U%(,6A:69R:7)A=&D@<W!O<F_$C6EL82XB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@;F]T(%,O
M34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(DYI(&UO9V_$C64@4R]-24U%
M('!O9'!I<R!S<&]R;\2-:6QA+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,B"FUS9W-T<B`B3FD@;6]G;\2-
M92!D;V1A=&D@<W1I:V]V+B`E<RXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z.38@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ
M,C$*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0X,@IM<V=I9"`B0V]U;&0@
M;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(E!O=F5Z879A('H@
M3$1!4"!S=')EQ;YN:6MO;2!N:2!M;V=OQ(UA+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS
M9W-T<B`B3FD@;6]G;\2-92!K;VYT<F]L:7)A=&D@/S\_/S\_("5S+B(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-C8*;7-G:60@(D-O=6QD(&YO="!C
M;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(")0;W9E>F%V82!Z($Q$
M05`@<W1R9<6^;FEK;VT@;FD@;6]G;\2-82XB"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O
M;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@
M(DYE(&UO<F5M('9Z<&]S=&%V:71I('!O=F5Z879E(',@<W1R9<6^;FEK;VT@
M7"(E<UPB('H@=7!O<F%B;R!&5%`Z("5S(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B
M"FUS9W-T<B`B3F4@;6]R96T@=7-T=F%R:71I('-E>FYA;6$@>F$@9&ES=')I
M8G5C:6IO+B`E<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$Q,C@*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B`B"FUS
M9W-T<B`B3FD@;6]G;\2-92!D9<6A:69R:7)A=&D@4$=0('!O9&%T:V]V.B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3(S"FUS9VED
M(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB"FUS9W-T<B`B3FD@
M;6]G;\2-92!D9<6A:69R:7)A=&D@4R]-24U%('!O9&%T:V4N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E
M<R(*;7-G<W1R(").92!M;W)E;2!I>F)R:7-A=&D@<W1I:V]V+B`E<R(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES=')I
M8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYE(&UO<F5M(&EZ8G)I<V%T:2!D
M:7-T<FEB=6-I:G-K96=A('-E>FYA;6$N("5S(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@
M(DYE(&UO<F5M(&EZ8G)I<V%T:2!N87-T879I='9E;F4@8<6^=7)A8VEJ<VME
M('-K<FEP=&4@7"(E<UPB(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HS.#$@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.34S
M"FUS9VED(")#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E
M+6UA:6P@861D<F5S<RXB"FUS9W-T<B`B3FD@;6]G;\2-92!D;VQOQ(UI=&D@
M96QE:W1R;VYS:V5G82!N87-L;W9A('!R96IE;6YI:V$N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*;7-G:60@
M(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S
M='(@(DYI(&UO9V_$C64@9&]L;\2-:71I(&-E;&]T;F5G82!I;65N:6MA+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-#DS"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T
M:6]N(&QI<W0N(@IM<V=S='(@(DYI(&UO9V_$C64@9&]L;\2-:71I(&-E;&]T
M;F5G82!D:7-T<FEB=6-I:G-K96=A('-E>FYA;6$N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@(D-O
M=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I
M;VX@;&ES=',N(@IM<V=S='(@(DYI(&UO9V_$C64@9&]L;\2-:71I(&-E;&]T
M;F5G82!S97IN86UA(&1I<W1R:6)U8VEJ<VMI:"!S97IN86UO=B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R
M871E9WDN<&AP.C8X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R
M(").:2!M;V=OQ(UE(&YA;&_%OFET:2!S=')A=&5G:6IE(%PB)7-<(BXB"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB
M+B(*;7-G<W1R(").92!M;W)E;2!T=F]R:71I(&UA<&4@7"(E<UPB+B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Q.0IM<V=I9"`B0V]U
M;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB
M"FUS9W-T<B`B3FD@;6]G;\2-92!D;V)I=&D@:F%V;F5G82!K;&IUQ(UA(&]D
M(&ML:G7$C6YE9V$@<W1R9<6^;FEK82XB"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M,3,Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<
M(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B3FD@;6]G;\2-92!O9'!R971I(%PB
M)7-<(B!Z82!P:7-A;FIE+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B3FD@;6]G;\2-92!O9'!R971I
M("5S+B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP
M:'`Z-#(P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N($UA
M:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(DYI(&UO9V_$C64@
M;V1P<F5T:2!M;V1U;&$@;R!O<')A=FEL=5]V>F1RQ;YE=F%N:F$@)7,@(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DYI(&UO
M9V_$C64@<')E8G)A=&D@:6UE;FEK(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$Q(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HQ-#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C(S-R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#<X"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HU,38@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z-C4V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HV.3D*;7-G:60@(D-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V
M97(N(@IM<V=S='(@(DYI(&UO9V_$C64@9&]S9<2-:2!,1$%0('-T<F7%OFYI
M:V$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O3V)J96-T+G!H<#HR-#`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S='(@
M(DYI(&UO9V_$C64@<')E8G)A=&D@)7,N(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@
M<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@
M;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@
M;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB
M9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B).:2!M;\6^;F\@<&]N87-T879I
M=&D@9V5S;&$@>F$@>F%H=&5V86YE9V$@=7!O<F%B;FEK82X@3F5K871E<F4@
M86QI("(*(G9S97!O9')O8FYO<W1I(&YI<V\@<')A=FEL;F4N(%!O<VMU<VET
M92!Z;F]V82!A;&D@:V]N=&%K=&ER86IT92`B"B)V8<6A96=A=7!R879I=&5L
M:F$L(,2-92!P;W1R96)U:F5T92!N861A;&IN:F\@<&]M;\2-+B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P-PHC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,S@*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<U"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,0HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#<*;7-G:60@(D-O=6QD(&YO
M="!R971R:65V92!!0TPB"FUS9W-T<B`B3FD@=7-P96QO('9Z<&]S=&%V:71I
M.B`E<R`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T
M<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R(").:2!U<W!E;&\@=GIP
M;W-T879I=&D@:6UE;FEK83H@)7,@(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*
M;7-G<W1R(").:2!U<W!E;&\@=GIP;W-T879I=&D@9&ES=')I8G5C:6IS:V5G
M82!S97IN86UA.B`E<R`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R
M(").:2!U<W!E;&\@=GIP;W-T879I=&D@9&ES=')I8G5C:6IS:V5G82!S97IN
M86UA.B`E<R`B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,C$W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C(R,0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B
M:6QI=&EE<R(*;7-G<W1R(").:2!U<W!E;&\@=GIP;W-T879I=&DZ("5S("(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@(D-O=6QD(&YO
M="!R979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B6F%H=&5V86YI("<E
M<R<@;FD@<&]D<F]B;F\@;V)L:6MO=F%N('8@)7,@<&]D;V)I+B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2]C;W!Y+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R(").92!M;W)E;2!I>F)R:7-A=&D@
M;6%P92!<(B5S7"(N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B)7,@:V]N9FEG=7)A8VEJ92!N:2!M;V=OQ(UE
M('-H<F%N:71I+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,R!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U;&0@;F]T('-A=F4@
M82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R(")+;VYF:6=U<F%C:6IE
M('9A<FYO<W1N92!K;W!I:F4@;FD@;6]G;\2-92!S:')A;FET:2XB"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G
M<W1R(")+;VYF:6=U<F%C:6IE('9A<FYO<W1N92!K;W!I:F4@;FD@;6]G;\2-
M92!S:')A;FET:3H@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HQ
M,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B3F4@;6]R96T@
M<VAR86YI=&D@;F%S=&%V:71V96YE(&'%OG5R86-I:G-K92!S:W)I<'1E(&YA
M.B!<(B5S7"(N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O
M;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B3F4@;6]R96T@<VAR86YI
M=&D@:V]N9FEG=7)A8VEJ<VMO(&1A=&]T96MO("5S+"!V87)N;W-T;F4@:V]P
M:6IE+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I
M;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@(@HB
M;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M
M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B(@HB3F4@
M;6]R96T@<VAR86YI=&D@(&MO;F9I9W5R86-I:G-K92!D871O=&5K92`E<RX@
M3&%H:V\@=7!O<F%B:71E(&%L:2!E;F\@;V0@(@HB;W!C:6H@>F$@<VAR86YI
M=&D@:V]D;R!Z861A:B!N82`E<R!A;&D@<F_$C6YO(&MO<&ER871E('-P;V1N
M:F\@:V]D;R!N82`E<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C$T,PIM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V
M97(N(@IM<V=S='(@(DYI(&UO9V_$C64@:7-K86YJ92!,1$%0('-T<F7%OFYI
M:V$N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R(").:2!M;V=O
MQ(UE(&]D<W1R86YI=&D@<&]V97IA=F4@>B!<(B5S7"(N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<R(*
M;7-G<W1R(").:2!M;V=OQ(UE(&'%OG5R:7)A=&D@<W1I:RX@)7,N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3FD@;6]G;\2-92!AQ;YU<FER871I
M(&1I<W1R:6)U8VEJ<VMI('-E>FYA;2X@)7,B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('=R
M:71E(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B3FD@
M;6]G;\2-92!N87!I<V%T:2!K;VYF:6=U<F%C:6IE('IA(%PB)7-<(CH@)7,B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<P"FUS9VED(")#;W5L9&XG
M="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED
M96)A<B!I<R!O<&5N+B(*;7-G<W1R(").92!N86ID96T@36]Z:6QL82!3:61E
M8F%R+B!0<F5V97)I(&%L:2!J92!O9'!R="XB"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T:&4@9F]L;&]W:6YG
M(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S(@IM<V=S='(@(EPB
M)7-<(B!U<&]R86)N:6MU(&YE(&UO<F5M(&1O9&5L:71I('-L961EQ(UI:"!P
M<F%V:6,@>F$@;6%P;R!<(B5S7"(Z("5S(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,30S,@IM<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(E!R
M9<6A=&5T;R!B97-E9&EL;R`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4W,`IM<V=I9"`B0V]U;G1R>2(*;7-G<W1R(")$<L6^879A
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X.0IM<V=I9"`B0V]U
M<G-E<R(*;7-G<W1R(")49<2-86II(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A
M=&4B"FUS9W-T<B`B57-T=F%R:2(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N
M=&ET>7-E;&5C="YI;F,Z.38*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS
M9W-T<B`B57-T=F%R:2!N;W9O(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C-#,Q-"YP:'`Z-3(*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.3(*;7-G:60@(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G
M<W1R(")5<W1V87)I('!O9&UA<&4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C(T,`IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*;7-G
M<W1R(")!=G1O<B!D;W9O;&IE;FHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS-#DY"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B
MQ:!T979I;&MA(&MR961I=&YE(&MA<G1I8V4@(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HV-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G
M:60@(D-R;V%T:6$B"FUS9W-T<B`B2')V8<6A:V$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS
M9VED(")#=6)A(@IM<V=S='(@(DMU8F$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,C8*;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B4V5D86YJ
M92`T(')A>G9O:FYE('-T;W!N:F4B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z
M-#@*;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B"FUS9W-T<B`B4V5D86YJ92!S
M96IE(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I;64N
M<&AP.C,U"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T<B`B4V5D86YJ:2#$
MC6%S(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,S"FUS9VED(")#=7)R96YT
M(%5S97)S(@IM<V=S='(@(E-E9&%N:FD@=7!O<F%B;FEK:2(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S`*;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G
M<W1R(")3961A;FIE('9R96UE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(V.0IM<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R
M(")3961A;FIE('-T86YJ93HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3$Q"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R
M=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B3F%S=&%V:71E(&%K=&EV
M;F]S=&DL(&MI('-E(&)O9&\@:7IV<L6A:6QE(&]B('!R:6IA=FD@;F$@)7,N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S(@IM<V=S='(@(D-I<&5R(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#4*;7-G:60@(D-Y<FEL;&EC("A+
M3TDX+5(I(@IM<V=S='(@(D-I<FEL:6-A*$M/23@M4BDB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U
M,2DB"FUS9W-T<B`B0VER:6QI8V$@*%=I;F1O=W,M,3(U,2DB"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X-PIM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N
M("A+3TDX+54I(@IM<V=S='(@(D-I<FEL:6-A+U5K<F%J:6YS:VD@*$M/23@M
M52DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R
M("+$C67%H6MA(')E<'5B;&EK82(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-38@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*
M;7-G:60@(D1$(@IM<V=S='(@(D1$(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S4U.0IM<V=I9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP
M+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN
M<&AP*2(*;7-G<W1R("(B"B)$3E,@*'!O9VQE:B!H='1P.B\O<&5A<BYP:'`N
M;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP
M:'`I(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H
M<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`B1&YE=FYO(@H*(SH@861M:6XO
M9&%T871R964N<&AP.C8S"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S
M='(@(E!R96=L961O=F%L;FEK(&1R979E<VYE('-T<G5K='5R92(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,U-3<*;7-G:60@(D1A=&%B87-E($QO
M;VMU<"(*;7-G<W1R(")0;VEZ=F5D8F$@8F%Z92!P;V1A=&MO=B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C@@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C8X-@IM<V=I9"`B1&%T92(*;7-G<W1R(")$
M871U;2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S
M"FUS9VED(")$871E(%)E8V5I=F5D(@IM<V=S='(@(D1A='5M('!R96IE;6$B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,#<W"FUS9VED(")$871E
M('-E;&5C=&EO;B(*;7-G<W1R("))>F)I<F$@9&%T=6UA(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-2!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S$T"FUS9VED(")$87DB"FUS9W-T<B`B1&%N(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-PHC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4U"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S@*;7-G:60@(D1E
M8V5M8F5R(@IM<V=S='(@(D1E8V5M8F5R(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ.#<@;&EB+W!R969S+G!H<#HQ,3<*;7-G:60@(D1E
M9F%U;'0B"FUS9W-T<B`B4')I=GIE=&\B"@HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHT-0HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHW-PIM<V=I9"`B1&5F875L="!#;VQO
M<B(*;7-G<W1R(")0<FEV>F5T82!"87)V82(*"B,Z(&9R86UE=V]R:R])9&5N
M=&ET>2])9&5N=&ET>2YP:'`Z.38*;7-G:60@(D1E9F%U;'0@261E;G1I='DB
M"FUS9W-T<B`B4')I=GIE=&$@:61E;G1I=&5T82(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HW-0IM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R(")0
M<FEV>F5T82!L=7!I;F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*
M;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S='(@(D]P<F5D96QI='9E(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HW,"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C,R-@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C,V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$Q-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$S.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.CDX"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN
M8SHQ,"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B
M1&5L971E(@IM<V=S='(@(EIB<FG%H6DB"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C$Y-R!A9&UI;B]G<F]U<',N<&AP.C(R-0IM<V=I9"`B1&5L971E($=R;W5P
M(@IM<V=S='(@(EIB<FG%H6D@<VMU<&EN;R(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(T.0IM<V=I9"`B1&5L971E($QO9R(*;7-G<W1R("):
M8G)IQ:%I(&1N979N:6LB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C<W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`Q"FUS9VED
M(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R("):8G)IQ:%I(&1O=F]L:F5N
M:F4B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M,PIM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R("))
M>F)R:<6A:2!I;B!P<F7$C6ES=&D@<W!O<F_$C6EL82(*"B,Z(&%D;6EN+W1E
M;7!L871E<RYP:'`Z,30W"FUS9VED(")$96QE=&4@97AI<W1I;F<@86QT97)N
M871E('1E;7!L871E(@IM<V=S='(@(DEZ8G)IQ:%I(&]B<W1O:F7$C6D@86QT
M97)N871I=FYI('9Z;W)E8R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S0S,30N<&AP.C4T"FUS9VED(")$96QE=&4@;65S<V%G97,B"FUS9W-T
M<B`B27IB<FG%H6D@<W!O<F_$C6EL82(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z-#(Q"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P
M97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(DEZ8G)IQ:%I(&1O=F]L
M:F5N:F$@>F$@7"(E<UPB(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I
M;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S
M='(@(DEZ8G)IQ:%E;2!D;W9O;&IE;FIE('IA(%PB)7-<(B!I;B!V<V$@<&]D
M9&]V;VQJ96YJ83\B"@HC.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I
M='DN:6YC.C$U"FUS9VED(")$96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS
M9W-T<B`B27IB<FG%H6D@:7IB<F%N;R!I9&5N=&ET971O(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3,*;7-G:60@(D1E;&5T
M92!S=6(@9F]L9&5R<R(*;7-G<W1R("))>F)R:<6A:2!P;V0@;6%P92(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,V"B,L('!H<"UF;W)M870*;7-G
M:60@(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G
M<W1R(").92!M;W)E;2!I>F)R:7-A=&D@;F%S=&%V:71V96YE(&'%OG5R86-I
M:G-K92!S:W)I<'1E(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4V,PHC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C$*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"FUS9VED(")$
M96QI=F5R>2!T:6UE(@IM<V=S='(@(L2,87,@9&]S=&%V92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-CD*;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`B1&%N<VMA(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,C<*;7-G:60@(D1E<V-R:6)E('1H
M92!0<F]B;&5M(@IM<V=S='(@(D]P:<6A:71E('1EQ;YA=F\B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HY-#<*;7-G:60@(D1E<V-R:7!T:6]N(@IM
M<V=S='(@(D]P:7,B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C(P
M-@IM<V=I9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*
M;7-G<W1R(")0;V1R;V)N;W-T:2`H='5D:2!V($AO<F1O=FD@;&]G(&1A=&]T
M96MI*3HB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C(Q,`IM<V=I
M9"`B1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R
M871O<BXB"FUS9W-T<B`B4&]D<F]B;F]S=&D@<V\@8FEL92!P<FEJ879L:F5N
M92!Z82!U<')A=FQJ86QC82XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C,U"FUS9VED(")$979E;&]P;65N="(*;7-G<W1R(")287IV;VHB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R.0IM<V=I9"`B1&5W(%!O:6YT(@IM
M<V=S='(@(E)O<VG%H<2-92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`V
M"FUS9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(E)O
M<VG%H<2-92!Z82!P<F5JQ:%N:F\@=7)O.B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,C$*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@
M(E)O<VG%H<2-93HB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM<V=I
M9"`B1&ER96-T;W)Y(@IM<V=S='(@(DEM96YI:R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR-S`*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B
M"FUS9W-T<B`B4')I:V'%OF5M(,2-87,@<&\@,C0@=7)N96T@<VES=&5M=3\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`P"FUS9VED(")$:7-P;&%Y
M($]P=&EO;G,B"FUS9W-T<B`B3F%S=&%V:71V92!P<FEK87IO=F%N:F$B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.30*;7-G:60@(D1I<W!L
M87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`B4')I:V'%OFD@<&]D<F]B
M;F\@;F%P;W9E9"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.3<*;7-G:60@
M(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B4')I:V'%OFD@;F%P
M;W9E9"`H5$%&*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,P.#<*
M;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM<V=S='(@(E!R:6MAQ;YI('9E;&EK
M;W-T(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C$Y,0IM<V=I
M9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(D]B=F5S=&EL
M;R!O(&1O<W1A=FQJ96YI('!OQ:%T:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J
M:6)O=71I(@IM<V=S='(@(D3%OFEB=71I(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HT,C(*;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T
M<B`B3F4@>F)R:<6A:2(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR
M-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP
M:'`B"FUS9W-T<B`B3F4@9&]S=&]P86H@;F5P;W-R961N;R!D;R!O:')A;FIA
M;FIA+G!H<"`B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,B!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E<R!T:&4@
M9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H
M96-K('1H:7,@8F]X.B(*;7-G<W1R(")!;&D@<')V82!V<G-T82!V<V5B=6IE
M(&EM96YA('!O;&H_(,2-92!J:6@L('!R979E<FD@;F%B:7)A;&YI:SHB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R(")$;VUI;FEC82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S`*;7-G:60@(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R
M(")$;VUI;FEK86YS:V$@4F5P=6)L:6MA(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHX.`IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3
M:6=N('5P+B(*;7-G<W1R(").:7-T92!R96=I<W1R:7)A;FD_(%)E9VES=')I
M<F%J=&4@<V4N("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C@U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G
M<W1R(")0<F5N97-I("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V
M,0IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@
M4$A0('-C<FEP="XB"FUS9W-T<B`B4')E;F5S:71E(&=E;F5R:7)A;F\@:V]N
M9FEG=7)A8VEJ;R!K;W0@4$A0('-K<FEP=&\N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,Y-0IM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T
M<B`B4&%D86IOQ(UI(&UE;FDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,SD*;7-G:60@(D1R=6=S(@IM<V=S='(@(EID<F%V:6QA(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C@S"FUS9VED(")$>6YA;6EC($UA:6PB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S
M"FUS9VED(")%+4UA:6PB"FUS9W-T<B`B16QE:W1R;VYS:VD@;F%S;&]V(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3(*
M;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I
M97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+B(*;7-G<W1R(")0<F5N
M;W,@96QE:W1R;VYS:VEH('-P;W)OQ(UI;"!V(%--4RUJ92!Z82!O<&5R871E
M<FIE+"!K:2!T;R!O;6]G;\2-86IO+B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G
M:60@(D524B(*;7-G<W1R(")%4E(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%8W5A
M9&]R(@IM<V=S='(@(D5K=F%D;W(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C,R-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$X,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M-S(*;7-G:60@(D5D:70B"FUS9W-T<B`B57)E9&DB"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO54DN<&AP.C4P"FUS9VED(")%9&ET($)L;V-K(@IM<V=S
M='(@(E5R961I('-T;VQP96,B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y-B!A
M9&UI;B]G<F]U<',N<&AP.C(R-`IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R
M(")5<F5D:2!S:W5P:6YO(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HW-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,`IM<V=I
M9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@(E5R961I(&1O=F]L:F5N:F4B
M"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C0R"FUS9VED(")%9&ET
M(%!E<FUI<W-I;VYS(@IM<V=S='(@(E5R961I(&1O=F]L:F5N:F$B"@HC.B!S
M97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C0T"B,L('!H<"UF;W)M870*;7-G
M:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(E5R961I(&1O
M=F]L:F5N:F$@>F$@)7,@(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z
M-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`B57)E9&D@;6_%
MOFYO<W1I('IA.B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R
M(%PB)7-<(B(*;7-G<W1R(")5<F5D:2!D;W9O;&IE;FIA('IA(%PB)7-<(B(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B57)E
M9&D@9&]V;VQJ96YJ82!Z82`E<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT,`IM<V=I9"`B161U8V%T:6]N(@IM<V=S='(@(DEZ;V)R8<6^979A;FIE
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`B16=I<'0B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@(E-A;'9A
M9&]R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(R-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`W"FUS9VED(")%;6%I
M;"(*;7-G<W1R(")%;&5K=')O;G-K82!P;\6A=&$B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V5D:70N:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z-CD*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B16QE:W1R
M;VYS:VD@;F%S;&]V(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(U
M,0IM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM<V=S='(@
M(D5L96MT<F]N<VMI(&YA<VQO=B!S92!M;W)A('5J96UA=&DN(@H*(SH@9G)A
M;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HT-3`*(RP@9G5Z>GD*;7-G
M:60@(D5M86EL(&%D9')E<W-E<R!T;R!C;VYF:7)M(&YO="!F;W5N9"XB"FUS
M9W-T<B`B16QE:W1R;VYS:VD@;F%S;&]V('-E(&UO<F$@=6IE;6%T:2XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C<W"FUS9VED(")%;6%I;"!W
M:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")%;&5K=')O;G-K82!P;\6A=&$@
M<R!P;W1R9&ET=FEJ;R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE
M<FEC7W-M='`N<&AP.CDQ"FUS9VED(")%;6%I;"UT;RU335,@1V%T97=A>2(*
M;7-G<W1R(")%;6%I;"U335,@4')E:&]D(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,P,PIM<V=I9"`B16UO=&EC;VYS(@IM
M<V=S='(@(E-M9<6A:VDB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#(*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM
M<V=S='(@(E!R87IE;F\@<W!O<F_$C6EL;RXB"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,C0S(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HT.#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C8V,B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%;7!T>2!R
M97-U;'0N(@IM<V=S='(@(E!R87IE;B!R97IU;'1A="XB"@HC.B!F<F%M97=O
M<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R
M8V@@=&5R;7,B"FUS9W-T<B`B4')A>F5N(&ES:V%L;FEK(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4T-0IM<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O
M9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS9W-T
M<B`B27IK;&]P:6T@=G-T879L:F%N:F4@<VQI:R!I>B!&;W1O($=A;&5R:6IE
M('8@=&5K<W0_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q,@IM<V=I
M9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B
M27IK;&]P:6T@;65N:2!Z(&1E<VYI;2!K;&EK;VT_(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C@W-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,#@Q"FUS9VED(")%;F0@>65A<B(*;7-G<W1R(")+;VYE8R!L971A(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R-`IM<V=I9"`B(@HB16YT97(@82!S
M96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y
M;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T
M(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*(E9N97-I
M=&4@=F%R;F]S=&YO('9P<F'%H6%N:F4L(&MI(&)O('!O<W1A=FQJ96YO+"#$
MC64@8F]S=&4@(@HB<&]T<F5B;W9A;&EP;VYA<W1A=FET:2!V8<6A92!G97-L
M;RP@;G!R+B##@N*`GFEM92!V8<6A96=A(&QJ=6)L:F5NQ(UK82!J93\Z(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Y,@IM
M<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S='(@(E9N97-I
M=&4@<W!O9&YJ92#$C7)K93HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")%<75A=&]R
M:6%L($=U:6YE82(*;7-G<W1R(")%:W9A=&]R:6%L;F$@1W9I;F5J82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T<B`B17)I=')E:F$B"@HC
M.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]S=&%T=7,N<&AP.C(W"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70O5FEE=RYP:'`Z.30@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4S
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z-#$*;7-G:60@(D5R<F]R(@IM<V=S
M='(@(DYA<&%K82(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP
M:'`Z-#8S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&-R96%T:6YG(&)L
M;V-K.B`E<R(*;7-G<W1R(").87!A:V$@<')I('5S='9A<FIA;FIU('-T;VQP
M83H@)7,N(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z
M("5S(@IM<V=S='(@(DYA<&%K82!P<FD@8G)I<V%N:G4@<&]V97IA=F4@<VEN
M:')O;B!I>F%C:6IE.B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y
M;F,@;&]G.B`E<R(*;7-G<W1R(").87!A:V$@<')I(&)R:7-A;FIU(&1N979N
M:6MA('-I;FAR;VYI>F%C:6IE.B`E<RXB"@HC.B!F<F%M97=O<FLO5&5M<&QA
M=&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O
M<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@(DYA<&%K82!P<FD@<&]V
M97IO=F%N:G4Z("5S+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!U<&1A=&EN9R!P87-S
M=V]R9#H@)7,B"FUS9W-T<B`B3F%P86MA('!R:2!AQ;YU<FER86YJ=2!G97-L
M83H@)7,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N
M(@IM<V=S='(@(DYA<&%K82!Z(&5L96MT<F]N<VMI;2!S<&]R;\2-:6QO;2XB
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDO8V]P>2YP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@
M(D5R<F]R('=R:71I;F<@7"(E<UPB+B(*;7-G<W1R(").87!A:V$@<')I('!I
M<V%N:G4@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS
M9W-T<B`B17-T;VYI:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%=&AI;W!I82(*
M;7-G<W1R(")%=&EO<&EJ82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M,0IM<V=I9"`B171H;FEC(@IM<V=S='(@(D5S=&]N:6IA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T
M<B`B179R;W!A(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$P
M,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0S"FUS9VED(")%=F5R>2`Q-2!M
M:6YU=&5S(@IM<V=S='(@(E9S86MI:"`Q-2!M:6YU="(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.3,*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G
M<W1R(")6<V%K:2`R(&UI;G5T:2(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHY."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0P"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B
M"FUS9W-T<B`B5G-A:VEH(#,P('-E:W5N9"(*"B,Z('1E;7!L871E<R]P;W)T
M86PO;&%Y;W5T+FEN8SHQ,#`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDT"FUS9VED(")%=F5R>2`U(&UI
M;G5T97,B"FUS9W-T<B`B5G-A:VEH(#4@;6EN=70B"@HC.B!F<F%M97=O<FLO
M36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,
M;V=I;B(*;7-G<W1R(")6<V%K82!P<FEJ879A(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]L87EO=70N:6YC.C$P,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0T
M"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`B5G-A:V4@<&]L('5R
M92(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,#,*(RP@9G5Z
M>GD*;7-G:60@(D5V97)Y(&AO=7(B"FUS9W-T<B`B5G-A:V4@<&]L('5R92(*
M"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY.2!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S0Q"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3(*
M;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R(")6<V%K;R!M:6YU=&\B"@HC
M.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR-`IM<V=I9"`B17AA;7!L
M92!V86QU97,Z(@IM<V=S='(@(E!R:6UE<B!V<F5D;F]S=&DZ(@H*(SH@861M
M:6XO<&AP<VAE;&PN<&AP.C@P(&%D;6EN+V-M9'-H96QL+G!H<#HT.2!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,3(V"FUS9VED(")%>&5C=71E(@IM<V=S='(@(DEZ
M=F5D:2(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z-C$T"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B4&]V9<2-86HB"@HC
M.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,Q"B,L(&9U>GIY"FUS
M9VED(")%>'!A;F0@4VED96)A<B(*;7-G<W1R(")+;VYE8R!L971A(@H*(SH@
M9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP
M96-T960@)RDG(@IM<V=S='(@(E!R:<2-86MO=F%N("<I)R(*"B,Z(&9R86UE
M=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-S4*;7-G:60@(D5X<&5C=&5D
M(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB"FUS9W-T<B`B4')I
MQ(UA:V]V86YA(&IE(&)I;&$@8F5S961A(&%L:2!B97-E9&YA('IV97IA('8@
M;F%V961N:6-A:"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@(D1A='5M('IA
M<&%D;&]S=&DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8W-PIM<V=I9"`B17AP;VYE;G0B"FUS9W-T<B`B6F%S=&]P;FEK(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-@IM<V=I9"`B1E10('5P;&]A9"!O
M9B!S971U<"(*;7-G<W1R(")&5%`@;F%L;\6^:71E=B!N86UE<W1I='9E+B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S<6PN<&AP.C(U,0IM<V=I9"`B
M1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N(@IM<V=S='(@(DYI('5S
M<&5L;R!V>G!O<W1A=FET:2!P<F5F97)E;F-E+B(*"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HW-2!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E
M<G9E<BXB"FUS9W-T<B`B4&]V97IA=F$@>B!,1$%0('-T<F7%OFYI:V]M(&YI
M('5S<&5L82XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z,3`Q
M"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*;7-G
M<W1R(")0;W9E>F%V82!S(%--0B!S=')EQ;YN:6MO;2!N:2!U<W!E;&$@(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,3$@9G)A;65W;W)K+U9&
M4R]61E,O<W-H,BYP:'`Z-S$T"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE
M9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R(")+;W!I<F%N:F4@:7H@
M7"(E<UPB+"!N:2!U<W!E;&\N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HW,38@9G)A;65W;W)K+U9&4R]61E,O<W-H,BYP:'`Z-S$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS
M9W-T<B`B2V]P:7)A;FIE(&YA(%PB)7-<(BP@;FD@=7-P96QO+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#D*;7-G:60@(D9A:6QE9"!T
M;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`B3FD@=7-P
M96QO('9Z<&]S=&%V:71I(&YO=F\@4T%33"!P;W9E>F%V;RXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4P-B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C<V-0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<V@R+G!H<#HW-S`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB
M+B(*;7-G<W1R(").:2!U<W!E;&\@<')E;6%K;FET:2!K.B`E<R`B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0U-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")&86EL960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(DYE;6]G;\2-
M92!P<F5B<F%T:3H@)7,@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T<B`B3V1D86QJ;F\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<R"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA
M<RDB"FUS9W-T<B`B1F%L:VQA;F1S:VD@;W1O:VDB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS
M9VED(")&87)O92!)<VQA;F1S(@IM<V=S='(@(D9E<G-K:2!O=&]K:2`B"@HC
M.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C,X"FUS9VED(")&871A;"!%<G)O
M<CHB"FUS9W-T<B`B2'5D82!N87!A:V$A(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@
M(D9A>"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-C4*;7-G:60@
M(D9A>&5S(@IM<V=S='(@(D9A>&DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`W"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B
M1F5B<G5A<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C,R"FUS9VED(")&
M965L<R!,:6ME(@IM<V=S='(@(E!OQ(UU=&ET:2!S92!K;W0B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(U"FUS9VED(")&965L<R!L:6ME
M.B`B"FUS9W-T<B`B4&_$C75T:71I('-E(&MO=#HB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F5W(%-H;W=E
M<G,B"FUS9W-T<B`B3F5K86H@;F%L:79O=B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS9VED(")&97<@4VYO=R!3:&]W
M97)S(@IM<V=S='(@(DYE:V%J('-N9<6^;FEH(&UE=&7%OF5V(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(S,@IM<V=I9"`B1FEE;&0@;6%T<FEX
M(@IM<V=S='(@(DUA=')I8V$@<&]L:F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS-C$R"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R(")&
M:6=L970@0T%05$-(02(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,V
M,38*;7-G:60@(D9I9VQE="!F;VYT(@IM<V=S='(@(D9I9VQE="!P:7-A=F$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@(D9I9,6^:2(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B1FEL92(*
M;7-G<W1R(")$871O=&5K82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B
M"FUS9W-T<B`BQ:!T971J92!$871O=&5K.B`E<R!D871O=&5K(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`BQ:!T971J92!$871O=&5K
M.B`E<R!D871O=&5K(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S
M,`IM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S='(@(E5P<F%V:71E;&H@9&%T
M;W1E:R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C,@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,`HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"FUS9VED(")&
M:6QE($YA;64B"FUS9W-T<B`B26UE(&1A=&]T96ME(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S(V-0IM<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS
M9W-T<B`B27IB:7)A(&1A=&]T96ME+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T.3D*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(DYA;&_%
MOFD@9&%T;W1E:V\B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H
M<#HY,#<*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G
M<W1R(")$;V1A;F$@9&%T;W1E:V$@;FD@<&]D<')T82XB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z.3@*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`B
M1FEL=')I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R(")&
M:6YS:V$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED(")&:7)S
M="!(86QF(@IM<V=S='(@(E!R=F$@<&]L;W9I8V$B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S
M="!1=6%R=&5R(@IM<V=S='(@(E!R=F$@Q(UE=')T:6YA(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U-PIM<V=I9"`B1FEX
M(')A=&EO(@IM<V=S='(@(E-T86QN92!V96QI:V]S=&DB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,R"FUS9VED(")&;&EP
M(@IM<V=S='(@(D]B<FYI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R(")-96=L82(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C8P(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HQ,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R
M("5S(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(B5S(&UA<&$@;F4@;V)S=&%J
M82`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(D9O;V0B
M"FUS9W-T<B`B2')A;F$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T-@IM
M<V=I9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B3F%P;W9E9"`H5$%&*2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW-PIM<V=I9"`B(@HB
M1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S
M="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G92!N=6UB
M97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R
M(")$;F5V:2!N87!O=F5D:2X@*$YA<&]V961A(&QE(&QA:&MO('IE;&\@9&]L
M9V$I(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY-`IM<V=I9"`B
M1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@(E-T92!P;WIA8FEL:2!V
M8<6A92!G97-L;S\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@U
M"FUS9VED(")&;W)M<R(*;7-G<W1R(")O8FQI:V4B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,C8*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`B4W)EQ(UA
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C$P-`IM<V=I9"`B1F]R='5N
M92!T>7!E(@IM<V=S='(@(E-R9<2-92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT,PIM<V=I9"`B1F]R='5N97,B"FUS9W-T<B`B4W)EQ(UE(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED(")&;W)T=6YE<R`R(@IM
M<V=S='(@(E-R9<2-92`R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0W-@IM<V=I9"`B1F]R=6US(@IM<V=S='(@(E1A8FQA('!O9V]V;W)O=B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,3@*;7-G:60@(D9O<G=A
M<F1S(@IM<V=S='(@(E!R975S;65R:71E=F4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")&<B(*;7-G<W1R
M(")&<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92(*;7-G<W1R(")&<F%N
M8VEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I
M9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B1G)A;F-I:F$L($MO
M;&]N:6%L;F$@;65T<F]P;VQA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H
M($=U:6%N82(*;7-G<W1R(")&<F%N8V]S:V$@1W9A:F%N82`B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R(")&<F%N8V]S
M:V$@4&]L:6YE>FEJ82`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3
M;W5T:&5R;B!497)R:71O<FEE<R(*;7-G<W1R(")&<F%N8V]S:VD@:G7%OFYI
M('1E<FET;W)I:B`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C<P"FUS9VED(")&<F]M(@IM<V=S='(@(D]D(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T,B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S4R"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS.3@*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R(")/9"`B"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT,@IM<V=I9"`B1G5L;"!$97-C
M<FEP=&EO;B(*;7-G<W1R(")0;VQN($]P:7,Z(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@
M36]O;B(*;7-G<W1R(")0;VQN82!L=6YA(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C8U('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C$*
M;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R(")0;VQN;R!I;64B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<S"FUS9VED(")'86)O;B(*;7-G<W1R(")'86)O;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*
M;7-G:60@(D=A;6)I82(*;7-G<W1R(")'86UB:6IA(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T
M92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(E5S='9A<FD@)7,@3F%S=&%V
M:71V92(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HV
M"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G<W1R(")'96YE<FER86H@:V]D
M;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T<B`B1W)U>FEJ
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-CD@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B3F5MQ(UI
M:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDS(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<U"FUS9VED(")':&%N82(*;7-G<W1R(")'86YA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-0IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(D=I8G)A;'1A
M<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<V"FUS
M9VED(")':79E;B!.86UE(@IM<V=S='(@(D1A;F\@:6UE(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W.2!T96UP;&%T97,O<')E9G,O87!P
M+FEN8SHQ,`HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ.0IM<V=I9"`B
M1VQO8F%L($]P=&EO;G,B"FUS9W-T<B`B4W!L;\6A;F4@36_%OFYO<W1I(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3<*;7-G:60@(D=O(@IM<V=S
M='(@(E!O:F1I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0U"FUS9VED
M(")';V5D96PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$Q,S$*;7-G:60@(D=O;V=L92!-87!S(@IM<V=S
M='(@(D=O;V=L;W9E(&UA<&4B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H(@IM<V=S='(@(DG%H<2-:2!Z($=O
M;V=L;VTB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C,X"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B3&5S='9I8V$@<VEV
M:6YE("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'<F5E8V4B"FUS9W-T<B`B1W+$
MC6EJ82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED(")'<F5E
M:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B1W+%H6MI("A)4T\M.#@U.2TW*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S4*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R(")'<F5N;&%N
M9&EJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B1W)E
M;F%D82(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<X"FUS9VED(")'<F]U<"!!
M9&UI;FES=')A=&EO;B(*;7-G<W1R(")3:W5P:6YS:V$@861M:6YI<W1R86-I
M:F$B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`N<&AP.C4Y(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S
M(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(DEM96YA(%-K=7!I;B!N92!S
M;65J;R!B:71I('!R87IN82(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HS,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@
M56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9#H@(@IM<V=S='(@(D%U=&A?;&1A<#H@3F4@;6]R96T@9&]D871I
M('-K=7!I;F4@)7,N(%-P;W)OQ(UI;&\@<W1R9<6^;FEK83H@(@H*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q."!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A
M<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<R(*;7-G<W1R(")3:W5P7VQD
M87`Z($YE(&UO<F5M(&EZ8G)I<V%T:2!S:W5P:6YE("5S(@H*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,S."!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P
M7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,B"FUS9W-T<B`B4VMU
M<%]L9&%P.B!.92!M;W)E;2!N861G<F%D:71I('-K=7!I;F4@)7,B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM
M<V=I9"`B1W)O=7!S(@IM<V=S='(@(E-K=7!I;F4B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS
M9VED(")'=6%D96QO=7!E(@IM<V=S='(@(D=U861E;&]U<&4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-PIM<V=I9"`B1W5A;2(*;7-G<W1R(")'=6%M(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*
M;7-G:60@(D=U871E;6%L82(*;7-G<W1R(")'=6%T96UA;&$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'=65R;G-E>2(*;7-G
M<W1R(")'=65R;G-E>2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,C(V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*;7-G:60@(D=U
M97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(D1O=F]L:F5N:F$@>F$@9V]S=&4B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DS"FUS9VED(")'=65S
M=&)O;VLB"FUS9W-T<B`B2VYJ:6=A(&=O<W1O=B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HY.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G
M:60@(D=U:6YE82(*;7-G<W1R(")'=FEN96IA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS
M9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(D=V:6YE:F$M0FES<V%O(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<X"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B1W9A:F%N82(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDV.0IM<V=I9"`B2%1-3"(*
M;7-G<W1R(")(5$U,(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H
M<#HQ-30*;7-G:60@(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")/=F5R:F5N96=A($A45%`@3FES96T@;F'%H65L+B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,`IM<V=I9"`B2&%I=&DB"FUS9W-T<B`B2&%I=&DB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA<V@M06QG
M;W)I=&AM(@IM<V=S='(@(DAA<V@@06QG;W)I=&5M(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4S-@IM<V=I9"`B(@HB2&%V92!A(&)U='1O;B!I;B!T
M:&4@=&]O;&)A<B!T:&%T('!O<',@=7`@82!W:6YD;W<@=VET:"!S<&5C:6%L
M(&-H87)A8W1E<G,_(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@(DUE
M9VQI8V$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,C@@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S(P,@IM<V=I9"`B2&5A9&5R(@IM<V=S='(@
M(D=L879A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T
M+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R(")';&%V92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA
M;F1S(@IM<V=S='(@(DAE87)D(&]T;VL@:6X@36-$;VYA;&1O=F\@;W1OQ(UJ
M92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S
M"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(DUOQ(UN82!N979I:'1A
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DAE8G)E=R`H
M25-/+3@X-3DM."U)*2(*;7-G<W1R(")(96)R96IS:VD@*$E33RTX.#4Y+3@M
M22DB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HR,@IM<V=I9"`B2&5I9VAT
M(@IM<V=S='(@(E9IQ:%I;F$B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M2&5L<"YP:'`Z,3@Q(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ
M.#(*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@=&5M<&QA=&5S+VAE
M;'`O:6YD97@N:6YC.C0*;7-G:60@(DAE;'`B"FUS9W-T<B`B4&]M;\2-(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,X-`IM<V=I9"`B2&5L<&5R
M(@IM<V=S='(@(E!O;6_$C6QN:6LB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`B4&]L;V)L82(*"B,Z('1E
M;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C$P"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@
M=&AE(&9I;&4Z(@IM<V=S='(@(E1U:V%J(&IE('IAQ(UE=&5K(&1A=&]T96ME
M.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q
M"FUS9VED(")(:6=H(@IM<V=S='(@(E9I<V]K;R(*"B,Z('1E;7!L871E<R]M
M96YU+VUE;G4N:6YC.C<*;7-G:60@(DAO7VUE(@IM<V=S='(@(D1O;6]V(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET>2!3
M=&%T92DB"FUS9W-T<B`B5F%T:6MA;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM
M<V=S='(@(D1O;6'$C6D@;F%S;&]V(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C<P"FUS9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R("));65N:6LB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP
M"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(D1O;6'$C6D@=&5L969O;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`B2&]N9'5R
M87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N9R(*;7-G<W1R(")(
M;VYG($MO;F<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C<*;7-G
M:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HT-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G
M92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@3F5V96QJ879E;B`E<R!834P@
M<&]D871E:R!N86ID96X@=B!S<&]R;\2-:6QU("5S(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HR.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S
M(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!.;V)E;F\@<W!O<F_$C6EL;R!S92!N
M92!U:F5M82!S('!R961M971O;2`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z-#0U"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S(@IM
M<V=S='(@(DAO<F1E+TMO;&%B.B!6('-P;W)OQ(UI;'4@)7,@;FD@;F%J9&5N
M(&YO8F5N('!R961M970@=&EP82`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,3(U,0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@(DAO
M<F1E+TMO;&%B.B!5<W!EQ:%N;R!O9'-T<F%N:F5N("5S(%PB)7-<(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D92]+
M;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O
M;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R(")(;W)D92]+;VQA8CH@26YT
M96=R86-I:G-K82!N87!R879A('IA:'1E=F$@)V1O;7AM;"<@4$A0(&5K<W1E
M;GII:F\B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C4Q,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T
M92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R(")(;W)D92]+
M;VQA8CH@3F4@;6]R92!U<W1V87)I=&D@;F]V;R!834P@9')E=F\@>F$@)7,B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-#@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@
M7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@3F4@;6]R96T@;V1S
M=')A;FET:2`E<R!<(B5S7"(Z("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HT.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T
M>7!E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!.92!M;W)E;2!P;VEZ=F5D
M971I('IA($U)344@240@>F$@9&5L(&]D('9R<W1E("5S(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DW"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB
M.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@3F4@;6]R96T@<VEN:')O;FEZ
M:7)A=&D@)7,@7"(E<UPB.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,3,S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B2&]R
M9&4O2V]L86(Z($YE(&UO<F5M('-I;FAR;VYI>FER871I(&1E;&4Z("5S(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM
M<V=S='(@(DAO<F1E+TMO;&%B.B!.97IN86YA(&1E;&ET978@7"(E<UPB(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M
M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G<W1R(")+;VQI
M:V\@<&]L:B`H<W1O;'!C978I:F4@=&%M/R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR.3,@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#(*;7-G
M:60@(DAU;6ED:71Y(@IM<V=S='(@(E9L8<6^;F]S="(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-3,*;7-G:60@(DAU;6ED:71Y.B`B"FUS
M9W-T<B`B5FQAQ;YN;W-T.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#8*;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R(")(=6UO<FES=&DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B36%DQ;YA<G-K82(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W,"!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C,T"B,L('!H<"UF;W)M870*;7-G
M:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@
M(E5S='9A<FIA;FIE($E-05`@;F%B:7)A;&YI:V$@;FD@=7-P96QO.B`E<R(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(Q-"!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,CDV"B,L('!H<"UF;W)M870*;7-G
M:60@(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM<V=S='(@
M(D)R:7-A;FIE($E-05`@;F%B:7)A;&YI:V$@;FD@=7-P96QO.B`E<R(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W-R!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C0Q"B,L('!H<"UF;W)M870*;7-G:60@
M(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S
M='(@(E5S='9A<FIA;FIE(&MV;W1E($E-05`@;F%B:7)A;&YI:V$L(&YI('5S
M<&5L;SH@)7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S(U"FUS
M9VED("))4"!!9&1R97-S(@IM<V=S='(@(DE0($YA<VQO=B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D9')E
M<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B25`@3F%S;&]V(&YI(&YA(')A
M>G!O;&%G;RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP
M.C@Y"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412
M(&)L;V-K+B(*;7-G<W1R("))4"!.87-L;W8@;FD@=B!D;W9O;&IE;FD@0TE$
M4B!S:W5P:6YI+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N
M+B(*;7-G<W1R("):86ML96YJ96X@25`N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED
M("))8V5L86YD(@IM<V=S='(@(DES;&%N9&EJ82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.#`*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B4V%M
M;R!I:V]N92(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T<B`B26MO;F4@>F$@
M)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Q"FUS9VED("))8V]N
M<R!W:71H('1E>'0B"FUS9W-T<B`B26MO;F4@>B!B97-E9&EL;VTB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DS"FUS9VED("))9&5N=&ET>2=S(&YA
M;64Z(@IM<V=S='(@(DED96YT:69I:V%C:6IS:V\@:6UE.B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C8P,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@
M=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(B5S('IA(&]D
M<')E=&D@=B!N;W9E;2!O:VYU+"#$C64@;FD@<')A=FEL;F\@<')I:V%Z86YO
M+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M-S(*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I
M;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B
M"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"B+$C64@
M=FED:71E('1O('-P;W)OQ(UI;&\@:6X@<VQIQ(UI8V4@;F4L('!O;65N:2P@
M9&$@=F'%H2!B<G-K86QN:6L@;F4@;6]R92`B"B)O9'!R971I('-L:<2-:6-E
M+"!K:2!J;R#%OF5L:71E(&YA;&_%OFET:2XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-S<T"FUS9VED("));6%G92!U<&QO860B"FUS9W-T<B`B
M1&]D86H@<VQI:V\B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I
M9"`B26UA9V5S(@IM<V=S='(@(E-L:6ME(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M='-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHW"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-30@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0L(%-T
M97`@)60B"FUS9W-T<B`B5FYO<RP@2V]R86L@)60B"@HC.B!T96UP;&%T97,O
M9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O
M<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`B5FYEQ:%E;F\@<&]L:F4Z("5S(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T
M960@9FEE;&1S.B(*;7-G<W1R(")6;F7%H65N82!P;VQJ83HB"@HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S0*;7-G:60@(DEN
M8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B4&]S<F5D;W9A
M;B!N97!R879I;&5N('5K87HN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*;7-G:60@(DEN8V]R<F5C="!U<V5R
M;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(DYE<')A=FEL;F\@=7!O
M<F%B;FG%H6MO(&EM92!I;B]A;&D@9V5S;&\N(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M
M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@
M>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L
M<"XB"FUS9W-T<B`B(@HB3F5P<F%V:6QN;R!U<&]R86)N:<6A:V\@:6UE(&%L
M:2!A;'1E<FYA=&EV96X@;F%S;&]V+B!0;W-K=7-I=&4@>FYO=F$@86QI("(*
M(FMO;G1A:W1I<F%J=&4@=F'%H65G82!S:W)B;FEK82P@Q(UE('!O=')E8G5J
M971E(&YA9&%L:FYJ;R!P;VUOQ(TN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))
M;F1I82(*;7-G<W1R("));F1I:F$B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C(U-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM
M<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R(")0;W-A;65Z;FD@57!O
M<F%B;FEK:2`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DEN9&]N97-I82(*;7-G
M<W1R("));F1O;F5Z:6IA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(W,PIM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M86-I:F4@
M;R!S97-T86YK=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M,C(*;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM
M<V=S='(@(DEN9F]R;6%C:6IE(&YI<V\@=F7$C2!D;W-E9VQJ:79E+B(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,30Y"FUS9VED("));G-E<G0@86QT97)N
M871E('1E;7!L871E(@IM<V=S='(@(E9S=&%V:2!A;'1E<FYA=&EV96X@=GIO
M<F5C(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T,@IM<V=I9"`B26YS
M97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E
M('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(E9S=&%V:71E(&5L96MT<F]N
M<VMI(&YA<VQO=B!N82!K871E<F5G82!L86AK;R!P<F5J;65T92!N;W9O(&=E
M<VQO.B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP
M.C4P"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP
M"FUS9VED("));G-E<G0@;65S<V%G97,B"FUS9W-T<B`B5G-T879I=&4@<W!O
M<F_$C6EL;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S,*;7-G:60@
M(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q
M=65S=&EO;CHB"FUS9W-T<B`B5G!IQ:%I=&4@>F%H=&5V86X@;V1G;W9O<B!N
M82!V87)N;W-T;F\@=G!R8<6A86YJ93HB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B26YS=69F:6-I
M96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="XB
M"FUS9W-T<B`B4W1A;FIE(&YA(')AQ(UU;G4@;F4@>F%D;W-T=6IE('IA('!O
MQ:%I;&IA;FIE(&YA(,6^96QJ96X@<W!I<V5K+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("));G-U
M9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R(")3=&%N:F4@;F$@<F'$C75N=2!N
M92!Z861O<W1U:F4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`X
M-`IM<V=I9"`B26YT96=E<B(*;7-G<W1R(")#96QO(,6A=&5V:6QO(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$T,@IM<V=I9"`B26YT96=E<B!L
M:7-T(@IM<V=S='(@(E-E>FYA;2!C96QI:"#%H71E=FEL(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED
M("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R(").
M979E;&IA=F5N(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$V-PHC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ.30*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C$R"FUS9VED("));G9A;&ED
M(%I)4"!D871A(@IM<V=S='(@(DYE=F5L:F%V96X@6DE0('!O9&%T96LN("(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@
M87!P;&EC871I;VXN(@IM<V=S='(@(DYE=F5L:F%V;F$@87!L:6MA8VEJ82XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(DYE=F5L
M:F%V;FD@240@<&%K970N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C,W-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#0V"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(U,C`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C4X-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP
M.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R(").
M979E;&IA=FYI('!O9&%T:VD@<V\@8FEL:2!O9'!O<VQA;FDN(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS
M9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(DYE
M=F5L:F%V96X@;F%S;&]V(&YA<VQO=FYI:V$N(@H*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,3`Y"B,Z(&9R86UE=V]R:R]#;VUP
M<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$S.0HC.B!F<F%M97=O<FLO0V]M<')E
M<W,O0V]M<')E<W,O9&)X+G!H<#HR-#$*;7-G:60@(DEN=F%L:60@9FEL92!F
M;W)M870B"FUS9W-T<B`B($YE=F5L:F%V;F$@;V)L:6MA(&1A=&]T96ME("(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S`*;7-G:60@(DEN
M=F%L:60@;&EC96YS92!K97DN(@IM<V=S='(@(DYE=F5L:F%V96X@;&EC96[$
MC6YI(&ML:G7$C2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,38T"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R
M(")/9')E:F5N(&YE=F5L:F%V96X@:W)A:BXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L
M:60@;7-G7W1Y<&4N(@IM<V=S='(@(DYE=F5L:F%V96X@=&EP7VUS9RXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#,*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@
M(DYE=F5L:F%V96X@86QI(&UA;FIK86IOQ(T@87!I7VED+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-@IM<V=I
M9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@(DYE
M=F5L:F%V;FD@86QI(&UA;FIK86IOQ(UI('!A<F%M971R:2XB"@HC.B!A9&UI
M;B]P97)M<R]A9&1C:&EL9"YP:'`Z,C8*;7-G:60@(DEN=F%L:60@<&%R96YT
M('!E<FUI<W-I;VXN(@IM<V=S='(@(DYE=F5L:F%V;F\@9&]V;VQJ96YJ92!S
M=&%RQ:%E=BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38V
M"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(DYE=F5L:F%V
M96X@<&%R=&YE<FIE=B!I9"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,38X"FUS9VED("));G9A;&ED('!R;V1U8W0@8V]D92XB"FUS9W-T
M<B`B3F5V96QJ879N82!K;V1A(&%R=&EK;&$N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED("));G9A
M;&ED('!R;W1O8V]L+B(*;7-G<W1R(").979E;&IA=F5N('!R;W1O:V]L+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M.3,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HW,2!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C@P"B,L('!H<"UF
M;W)M870*;7-G:60@(DEN=F%L:60@<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T
M<B`B3F5V96QJ879E;B!N87-L;W9N:6LZ(%PB)7-<(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z,3`X,"!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C$R-C,*;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S='(@
M(B!.979E;&IA=F5N(&]B:F5K="!D96QJ96YJ82`B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@(DEN
M=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(DYE=F5L:F%V96X@:7IV
M;W)N:2!N87-L;W8N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T
M82XB"FUS9W-T<B`B($YE=F5L:F%V96X@=6YI:V]D('!O9&%T96LB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<S"FUS9VED("));G9E;G1O<GDB
M"FUS9W-T<B`B26YV96YT=7)A+W!O<&ES(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8X,`IM<V=I9"`B26YV97)T('-E;&5C
M=&EO;B(*;7-G<W1R(")/8G)N:2!I>F)O<B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I
M9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("))<F%N+"!)
M<VQA;7-K82!297!U8FQI:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DER87$B
M"FUS9W-T<B`B27)A:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*
M;7-G<W1R("))<G-K82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O;&%T
M960@5"U3=&]R;7,B"FUS9W-T<B`B4&]S86UE>FYE(&YE=FEH=&4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#`*;7-G:60@(DES<F%E;"(*;7-G<W1R("))>G)A96PB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R-@IM<V=I9"`B27-S
M=65R(@IM<V=S='(@(DEZ9&%J871E;&HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@
M(DET86QY(@IM<V=S='(@(DET86QI:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@
M(DIA;6%I8V$B"FUS9W-T<B`B2F%M86IK82(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#8*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED(")*86YU87)Y(@IM<V=S
M='(@(DIA;G5A<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F%P86XB"FUS9W-T
M<B`B2F%P;VYS:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I
M9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R(")*87!O;G-K:2`H
M25-/+3(P,C(M2E`I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R(")*97)S97DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R(")*;W)D86YI:F$B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I9"`B2G5L
M>2(*;7-G<W1R(")*=6QI:B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,3$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<R"FUS9VED(")*=6YE(@IM<V=S='(@(DIU;FEJ(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@(DMA>F%H
M<W1A;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR-C4*;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@(D]B9'+%OFEM
M(&EZ=FER;FEK/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T
M<B`B2V5N:6IA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX
M-@IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R(")+97)B97)O<R!S=')EQ;YN:6L@>F%V<FYI;"!O=F5R
M:71E=BXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G:60@(DME
M<FYE;"!.97=B:65S(@IM<V=S='(@(DME<FYE;"!N;W9I;F-I(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@0W)E
M871I;VXB"FUS9W-T<B`B57-T=F%R:2!+;&IUQ(T@(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I
M;G0B"FUS9W-T<B`B3V1T:7,@2VQJ=<2-82(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R
M(")$;VS%OFEN82!+;&IUQ(UA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@5'EP92(*;7-G<W1R(")4:7`@2VQJ
M=<2-82`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y
M.0IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(E5P;W)A8F$@2VQJ=<2-82`B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW-#`*;7-G:60@
M(DME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB
M"FUS9W-T<B`B2VQJ=<2-(,6^92!O8G-T86IA(&YA(&IA=FYE;2!K;&IUQ(UN
M96T@<W1R9<6^;FEK=2XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*
M;7-G:60@(DMI9',B"FUS9W-T<B`B3W1R;V-I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS
M9VED(")+:7)I8F%T:2(*;7-G<W1R(")+:7)I8F%T:2`B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#4*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC
M(&]F(@IM<V=S='(@(DMO<F5J82P@1&5M;VMR871IQ(UN82!L:G5D<VMA(')E
M<'5B;&EK82`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!297!U8FQI
M8R!O9B(*;7-G<W1R(")+;W)E:F$L(%)E<'5B;&EK82`B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S
M='(@(DMO<F5J<VMI("A%54,M2U(I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+
M=7=A:70B"FUS9W-T<B`B2W5V86IT("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B
M2WER9WEZ<W1A;B(*;7-G<W1R(")+:7)G:7II:F$@(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHW-0IM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B
M2F5Z:6LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G<R!$96UO
M8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(DQA;W,@;&IU9'-K82!D96UO:W)A
M=&G$C6YA(')E<'5B;&EK82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-CD*
M;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R("):861N:F$@<&]L;W9I8V$B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#@*;7-G:60@(DQA<W0@4&%S<W=O
M<F0@0VAA;F=E(@IM<V=S='(@(EIA9&YJ82!S<')E;65M8F$@9V5S;&$Z("(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX-B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M.#@*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R("):861N:F$@Q(UE=')T
M:6YA(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C,*;7-G:60@(DQA<W0@
M57!D871E9#HB"FUS9W-T<B`B6F%D;FIE(&'%OG5R:7)A;FIE.B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q-PHC+"!P:'`M9F]R;6%T"FUS9VED
M("),87-T(&QO9VEN.B`E<R(*;7-G<W1R("):861N:F$@<')I:F%V83H@)7,@
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M
M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T<B`B6F%D
M;FIA('!R:6IA=F$Z("5S(&EZ("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z-S$T"FUS9VED("),87-T(&QO9VEN.B!.979E<B(*;7-G<W1R("):
M861N:F$@<')I:F%V83H@3FEK;VQI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),
M871V:6$B"FUS9W-T<B`B3&%T=FEJ82`B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#D*;7-G:60@(DQA=R(*;7-G<W1R(")0<F%V;R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R("),:6)A;F]N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,X.`IM<V=I9"`B3&5F="!H96%D97(B
M"FUS9W-T<B`B3&5V;R!O9VQA=FQJ92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,S.#0*;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@(E9R961N
M;W-T:2!N82!L979I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),97-O=&AO(@IM
M<V=S='(@(DQE<V]T;R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(U-0IM<V=I9"`B3&5V96PB"FUS9W-T<B`B4F%V96XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#@*;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B3&EB97)I:F$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#D*;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B
M3&EB:6IA("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*
M;7-G<W1R("),:65C:'1E;G-T96EN("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),:6=H="!$<FEZ>FQE(@IM
M<V=S='(@(E)A:&5L('!RQ:%E8R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(V"FUS9VED("),:6=H="!286EN(@IM<V=S='(@
M(E)A:&5L(&1EQ;XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R("):
M9V]D86H@<F%H96P@9&7%OB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),:6=H="!286EN($QA=&4B"FUS9W-T
M<B`B4&]Z;F\@<F%H96P@9&7%OB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*
M;7-G<W1R(")0;&]H82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,P"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*
M;7-G<W1R(")0;&]H82!Z(&=R;65N:F5M(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*;7-G:60@(DQI9VAT(%-N;W<B"FUS
M9W-T<B`B4F%H96P@<VYE9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,R"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G
M<W1R(")3;F7%OFYI(&UE=&7%OB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU,`HC+"!F=7IZ>0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B3&EB97)I
M:F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#(W"FUS9VED("),
M:6YK(@IM<V=S='(@(E!O=F5Z879A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C`Q,PIM<V=I9"`B3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T
M:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(*;7-G<W1R(")0;W9E
MQ;YI(&4M;F%S;&]V(',@;V)R87IC96T@>F$@<V5S=&%V;R!N;W9E('!OQ:%T
M;R!M92!P<FEK87IO=F%N:F5M(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R
M+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,@IM<V=I9"`B3&EN:W,B"FUS9W-T
M<B`B4&]V97IA=F4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G
M:60@(DQI;G5X($-O;VMI92(*;7-G<W1R("),:6YU>"!P:<6A:V]T96LB"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT-@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B
M3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(E-E>FYA
M;2`M('5P;W)A8FYI:R!L86AK;R!V:61I(&UA<&\B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3,R"FUS9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R(")3
M97IN86T@<&]D871K;W9N:6@@8F%Z(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E
M>"YP:'`Z-3$*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B4V5Z
M;F%M(%1E;2!0;VUOQ(UI("(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S$*
M;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(E-E>FYA;2!T86)E;"(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3$V"FUS9VED("),
M:7-T+4%R8VAI=F4B"FUS9W-T<B`B(%-E>FYA;2!!<FAI=F$@(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU,3$*;7-G:60@(DQI<W0M
M2&5L<"(*;7-G<W1R(")397IN86T@4&]M;\2-:2`B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TAE861E<G,N<&AP.C4Q.`IM<V=I9"`B3&ES="U)9"(*;7-G
M<W1R(")397IN86T@261E;G1I=&5T("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O2&5A9&5R<RYP:'`Z-3$T"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@
M(E-E>FYA;2!,87-T;FEK;W8@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](
M96%D97)S+G!H<#HU,34*;7-G:60@(DQI<W0M4&]S="(*;7-G<W1R(")397IN
M86T@4&_%H71E("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP
M:'`Z-3$S"FUS9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R(")397IN86T@
M4')I:F%V("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z
M-3$R"FUS9VED("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(E-E>FYA;2!/
M9&IA=B`B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@
M(E-P:7-E:R!S97IN86UA('-E:B!N:2!U<W!E;#H@)7,N(@H*(SH@861M:6XO
M<V5S<VEO;G,N<&AP.C,U"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@
M=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R(")397IN86T@=7!O<F%B;FEK;W8@
M;FD@;6]G;\2-93H@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI
M<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM
M<V=S='(@(E-E>FYA;2!U<&]R86)N:6MO=B!N:2!M;V=OQ(TN(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4R"FUS9VED("),:71E<F%T=7)E(@IM<V=S
M='(@(DQI=&5R871U<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI=&AU86YI
M82(*;7-G<W1R("),:71V82`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I;6%G97,N<&AP.C<W"FUS9VED("),;V%D:6YG+BXN(@IM<V=S='(@
M(DYA;&%G86TN+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C`U"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B3&]K86QN:2#$C6%S
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-@IM<V=I9"`B3&]C86QE
M(&%N9"!4:6UE(@IM<V=S='(@(DQO:V%L:7IA8VEJ82(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<R(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HV,@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HW-PIM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B
M365S=&\B"@HC.B!L;V=I;BYP:'`Z,3@X('-E<G9I8V5S+W!O<G1A;"]S:61E
M8F%R+G!H<#HR,#0@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,PHC.B!T
M96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-2!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C@R"FUS9VED("),;V<@:6XB"FUS9W-T<B`B4')I:F%V82(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B3&]G
M(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R(")/9&IA=F$@<R!P
M<F5D:&]D;F4@<WEN8R!S96IE("(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E
M8F%R+G!H<#HQ.3@*;7-G:60@(DQO9R!O=70B"FUS9W-T<B`B3V1J879A(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q"FUS9VED("),;V=I;B(*;7-G
M<W1R(")0<FEJ879A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,`IM
M<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B4')I:F%V82!N82!O<')A=FEL
M82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY-0IM<V=I9"`B3&]G
M:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W
M87,@96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B4')I:F%V82!N:2!U
M<W!E;&$N(%5P;W)A8FYIQ:%K;R!I;64@86QI(&=E<VQO(&YE<')A=FEL;F\@
M=FYEQ:%E;F\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.3$*;7-G
M:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`B4')I:F%V82!N:2!U<W!E;&$B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<X"FUS9VED("),;VYG
M('1E>'0B"FUS9W-T<B`B1&]L9V\@0F5S961I;&\B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3,*;7-G:60@(DQO=F4B"FUS9W-T<B`B3&IU8F5Z96XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.0IM
M<V=I9"`B3&]W(@IM<V=S='(@(DYI>F5K(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED
M("),=7AE;6)O=7)G(@IM<V=S='(@(DQU:W-E;6)U<F<B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#,@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(DU-(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(Y-PIM<V=I9"`B34]41"(*;7-G<W1R(")3
M<&]R;\2-:6QO(&1N979A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.148@071T86-H;65N="!C;VYT
M86EN960@;F\@9&%T82XB"FUS9W-T<B`B35,M5$Y%1B!0<FEP;VYK82!N:2!V
M<V5B;W9A;&$@<&]D871K;W8N(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B
M35-'(@IM<V=S='(@(DU31R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C86\B
M"FUS9W-T<B`B36%C874B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA8V5D;VYI
M82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G<W1R(")-
M86ME9&]N:6IA+"!F;W)M86QN82!*=6=O<VQO=F%N<VMA(')E<'5B;&EK82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R(")-861A
M9V%S:V%R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T"FUS9VED(")-
M86=I8R(*;7-G<W1R("+$C6%R;V)E;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HY,`IM<V=I9"`B36%I;"(*;7-G<W1R(")%;&5K=')O;G-K:2!N
M87-L;W8B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-30V"FUS9VED
M(")-86EL($%D;6EN(@IM<V=S='(@(D%D;6EN:7-T<F%T;W(@<&_%H71E(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDT"FUS9VED(")-86QA=VDB"FUS9W-T<B`B36%L879I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDU"FUS9VED(")-86QA>7-I82(*;7-G<W1R(")-86QE>FEJ
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B36%L
M9&EV:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%L:2(*;7-G<W1R(")-86QI
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QT82(*;7-G<W1R(")-86QT82(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-`IM<V=I9"`B(@HB36%N86=E
M('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E
M;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@
M8V%T96=O<FEE<RXB"FUS9W-T<B`B(@HB57)E9&ET92!S97IN86T@:V%T96=O
M<FEJ(',@:V%T97)I;6D@8F]S=&4@;WIN8<2-:6QI('!O<W1A=FME(&EN('!R
M:7!A9&%J;\2-92`B"B)B87)V92!Z82!T92!K871E9V]R:6IE+B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,34V"FUS9VED
M(")-87`R-"!M87`B"FUS9W-T<B`B6F5M;&IE=FED($UA<#(T(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#<*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-S$*;7-G:60@
M(DUA<%%U97-T(&UA<"(*;7-G<W1R("):96UL:F5V:60@36%P47)E<W0B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I
M;F=S('-T;W)E9"XB"FUS9W-T<B`B4VAR86YJ96YE('!O=F5Z879E(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.`HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*;7-G:60@
M(DUA<F-H(@IM<V=S='(@(DUA<F5C(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C-#,Q-"YP:'`Z-#@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@(DUA<FL@=VET:"!3965N+U5N<V5E
M;B!F;&%G<R(*;7-G<W1R(")/>FYAQ(UI('H@>F%S=&%V:6-A;6D@5FED96YO
M+TYE=FED96YO(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q
M-"YP:'`Z-#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O
M<G1A;G0O06YS=V5R960I(@IM<V=S='(@(D]Z;F'$C6D@>B!O<W1A;&EM:2!Z
M87-T879I8V%M:2AN<'(N(%!O;65M8FYO+T]D9V]V;W)J96YO*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,0IM<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R(")-87)S
M:&%L;&]V;R!O=&_$C6IE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-87)T:6YI
M<75E(@IM<V=S='(@(DUA<G1I;FEQ=64B"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C$P,PIM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@
M(E5J96UA;FIE('!O;&HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA=7)I=&%N
M:6$B"FUS9W-T<B`B36%V<F5T86YI:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@
M(DUA=7)I=&EU<R(*;7-G<W1R(")-879R:6-I=7,B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@(DUA
M>"!A;&QO=V5D(&-R961I="XB"FUS9W-T<B`B3F5J=F7$C2!D;W9O;&IE;FD@
M>FYE<V5K(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`X"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E>&-E961E
M9"XB"FUS9W-T<B`B36%K<VEM86QN:2!D96QI('-P;W)OQ(UI;&$@<')E:V]R
M8<2-96YI+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$X"FUS9VED(")-
M87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B36%K<VEM86QN82!T
M96UP97)A='5R82!Z861N:FEH(#(T('5R.B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S$P"FUS9VED(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G
M<W1R(")-86MS:6UA;&YA('1E;7!E<F%T=7)A('IA9&YJ:6@@-B!U<CHB"@HC
M.B!L:6(O87!I+G!H<#HX-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R
M=&%L($)L;V-K<R(*;7-G<W1R(")-86MS:6UA;&YO(,6A=&5V:6QO(&)L;VMO
M=B!P;W)T86QA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3`W(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,C8*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(T.`IM<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T<B`B
M36%K<VEM86QN82!D;VS%OFEN82(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,3`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")-87DB"FUS9W-T<B`B36%J(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-PIM<V=I9"`B36%Y;W1T92(*;7-G<W1R(")-87EO='1E
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED(")-961I8VEN
M92(*;7-G<W1R("):9')A=FEL;R`H365D:6-I;F$I(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@IM<V=I9"`B365M8F5R<R(*;7-G
M<W1R("+$C6QA;FDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@R"FUS
M9VED(")-96YU(&UO9&4Z(@IM<V=S='(@(E1I<"!M96YI:F$Z(@H*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A
M='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*
M;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`B4W!O<F_$C6EL;R(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$V"FUS9VED("(B"B)-97-S
M86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E
M<G1I9FEC871E(&-O=6QD(&YO="!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B
M(@HB4W!O<F_$C6EL;R!J92!B:6QO('5S<&7%H6YO('!R979E<FIE;F\L('1O
M9&$@<&]D<&ES;FEK;W9E9V$@<&]T<F1I;&$@;FD@8FEL;R`B"B)M;V=OQ(UE
M('!R979E<FET:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,3`*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS
M9W-T<B`B4W!O<F_$C6EL;R!J92!P;W1E:VQO+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*
M;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R(")4:7`@4W!O<F_$C6EL82(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B365T87(@5V5A=&AE
M<B(*;7-G<W1R(")-971A<B!V<F5M92(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z-#(*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N(@IM<V=S
M='(@(DUE=&%R(&)L;VL@;FD@;F$@<F%Z<&]L86=O+B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,3(T"FUS9VED("(B"B)-971A<B!B;&]C:R!N;W0@879A
M:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI
M;FES=')A=&]R+B(*;7-G<W1R(")0;V1R;V)N;W-T:2!S;R!B:6QE('!R:6IA
M=FQJ96YE('IA('5P<F%V;&IA;&-A+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-3@*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E
M9"XB"FUS9W-T<B`B365T87)$0B!N:2!P;W9E>F%N+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B365T:&]D(@IM<V=S='(@
M(E!O<W1O<&5K(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HX
M,2!F<F%M97=O<FLO4E!#+U)00R]P:'!G=RYP:'`Z.#@*(SH@9G)A;65W;W)K
M+U)00R]24$,O<&AP9W<N<&AP.C@Y(&9R86UE=V]R:R]24$,O4E!#+W-O87`N
M<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB(&ES
M(&YO="!D969I;F5D(@IM<V=S='(@(B<E<R<@<&]S=&]P96L@;FD@9&]L;\2-
M96XN(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T
M:&]D.B`E<R(*;7-G<W1R(")0;W-T;W!E:R!N:2!D;VQOQ(UE;BX@4&]S=&]P
M96L@8V5L:6-E.B`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HW,B!L:6(O0FQO8VLO;65T87(N<&AP.C@W"FUS9VED(")-971R:6,B"FUS
M9W-T<B`B365T<FG$C6YI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-97AI8V\B
M"FUS9W-T<B`B365H:6MA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O;F5S
M:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B36EK<F]N97II:F$L
M($9E9&5R871I=FYA(&1RQ;YA=F$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S='(@
M(E1I<"!D871O=&5K92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(R"FUS
M9VED(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B36EN:6UA
M;&YA('1E;7!E<F%T=7)A('IA9&YJ:6@@,C0@=7(Z(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,30*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@
M(@IM<V=S='(@(DUI;FEM86QN82!T96UP97)A='5R82!Z861N:FEH(#8@=7(Z
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,S@*;7-G:60@
M(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960B"FUS
M9W-T<B`B36EN:6UA;&YA('-T87)O<W0@9V5S;&$@Q:%E(&YI('!O=&5K;&$B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,U
M"FUS9VED(")-:7)R;W(B"FUS9W-T<B`B3V=L961A;&\B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T
M<B`B36YO9V]S=')A;G-K82(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!014%2('!A
M8VMA9V4@2%144%]297%U97-T+B(*;7-G<W1R(")0;V=R9<6A86X@4$5!4B!P
M86ME="P@2%144"!Z86AT979A;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3$T"B,L(&9U>GIY"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I
M;VXN(%EO=2!M=7-T(&=E;F5R871E(&ET(&)E9F]R92!U<VEN9R!T:&ES(&%P
M<&QI8V%T:6]N+B(*;7-G<W1R("(B"B)0;V=R9<6A86YA(&MO;F9I9W5R86-I
M:F$N(,2-92#%OF5L:71E('5P;W)A8FQJ871I('1O(&%P;&EK86-I:F\L(&UO
M<F%T92`B"B)G96YE<FER871I(&MO;F9I9W5R86-I:F\N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`T"FUS9VED
M(")-:7-S:6YG(&UE<W-A9V4@240N(@IM<V=S='(@(E!O9W)EQ:%A;F\@240@
M<W!O<F_$C6EL;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O
M;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!0
M14%2('!A8VMA9V4@36%I;"XB"FUS9W-T<B`B4&]G<F7%H6%N;R!S<&]R;\2-
M:6QO(&\@>F%H=&5V86YE;2!014%2('!A:V5T=2XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G:60@(DUI
M<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`B4&]G<F7%H6%N82!)1"!S96IA
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-3@*;7-G:60@(DUO(@IM<V=S='(@(E!O(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C<V"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R(")-;V)I
M;&YA('!OQ:%T82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C<P"FUS9VED(")-;V1E<F%T92(*;7-G<W1R("):;65R;F\B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8V(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S,*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-0IM<V=I9"`B36]D:69I960@
M1&%T92(*;7-G<W1R(")$871U;2!S<')E;65M8F4B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-`IM<V=I9"`B36]D=6QU<R(*;7-G
M<W1R(")-;V1U;&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;&1O=F$L(%)E
M<'5B;&EC(&]F(@IM<V=S='(@(DUO;&1A=FEJ82P@<F5P=6)L:6MA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B36]N86MO(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R(")-;VYG;VQI:F$B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#<R"FUS9VED(")-;VYT
M:"!A;F0@>65A<B(*;7-G<W1R(")-97-E8R!I;B!L971O(@H*(SH@9G)A;65W
M;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N
M=&AL>2(*;7-G<W1R(")-97-EQ(UN;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B
M36]N='-E<G)A="(*;7-G<W1R(")-;VYT<V5R<F%T(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N
M(%!H87-E<R(*;7-G<W1R("),=6YI;F4@;65N92(*"B,Z(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C$Y-B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HR.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!F:65L9',@9F]U;F0@
M:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T<B`B5B!V
M<G-T:2`E9"!J92!N86ID96YI:"!V9<2-('!O;&H@;V0@<')E9'9I9&5N:6@@
M)60N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(DUA
M<F]K;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,S"FUS9VED(")-;W-T;'D@0VQE87(B"FUS9W-T<B`B4')E=&7%OFYO(&IA
M<VYO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S0*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B4')E=&7%OFYO(&]B
M;&'$C6YO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S4*;7-G:60@(DUO<W1L>2!#;&]U9'D@86YD(%=I;F1Y(@IM<V=S='(@
M(E!R971EQ;YN;R!O8FQAQ(UN;R!I;B!V971R;W9N;R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")-;W-T;'D@
M4W5N;GDB"FUS9W-T<B`B4')E=&7%OFYO('-O;L2-;F\B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8T.`IM<V=I9"`B
M36]V92!$;W=N(@IM<V=S='(@(E!O;6%K;FD@<V4@9&]L(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-3(*;7-G:60@
M(DUO=F4@3&5F="(*;7-G<W1R(")0;VUA:VYI('-E('8@;&5V;R(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C4V"FUS
M9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(E!O;6%K;FD@<V4@=B!D97-N;R(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z
M-C0T"FUS9VED(")-;W9E(%5P(@IM<V=S='(@(E!O;6%K;FD@<V4@9V]R(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4S,`IM
M<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(E!O;6%K;FD@<V4@9&]L(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R.0HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3,P"FUS9VED
M(")-;W9E('5P(@IM<V=S='(@(E!O;6%K;FD@<V4@9V]R(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDU"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(DUO>F%M8FEK(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0W,@IM<V=I9"`B375L=&DM;&5V
M96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(E9EQ(T@;FEV;VIN:2!P861A
M:F_$C6D@<W!I<VMI(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$P-3D*;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R
M(")-=6QT:6UA<"!52R!Z96UL:F5V:60N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C4S,`IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S
M='(@(DUN;V=O:W)A=&5N(&EZ8F]R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0R,PIM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R(")-;VH@<F'$
MC75N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X"FUS9VED(")->2!!
M8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(E!O9&%T:VD@;6]J96=A(')A
MQ(UU;F$B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C8T"FUS9VED
M(")->2!0;W)T86PB"FUS9W-T<B`B36]J('!O<G1A;"(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]E9&ET+G!H<#HS-`IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*
M;7-G<W1R(")/8FQI:V$@;6]J92!P<G9E('-T<F%N:2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,@IM<V=I9"`B37EA;FUA<B(*;7-G<W1R(")-:F%N;6%R(@H*(SH@=&5M<&QA
M=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3<*;7-G:60@(DY/
M+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R(").92P@<V4@;F4@<W1R:6YJ86TB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P,@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B3F%M92(*
M;7-G<W1R("));64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS
M9W-T<B`B3F%M:6)I:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM
M<V=S='(@(DYA=7)U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G
M<W1R(").97!A;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B
M"FUS9W-T<B`B3FEZ;WIE;7-K82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H
M97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R(").:7IO>F5M<VMI($%N=&EL:2(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED
M(").971S8V%P92!"87-E(%523"(*;7-G<W1R(").971S8V%P92!O<VYO=FYI
M(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@T
M"FUS9VED(").971S8V%P92!#02!2979O8V%T:6]N(%523"(*;7-G<W1R("(@
M3F5T<V-A<&4@0T$@55),('IA('!R96ML:6,B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L
M:6-Y(%523"(*;7-G<W1R(").87-L;W8@3F5T<V-A<&4@8V5R=&EF:6MA=&$B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-0IM<V=I
M9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B($YE='-C87!E(&]B
M;F]V:71V96YI(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3@S"FUS9VED(").971S8V%P92!2979O8V%T:6]N(%523"(*;7-G
M<W1R("(@3F5T<V-A<&4@55),('IA('!R96ML:6,B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@4U-,
M('-E<G9E<B!N86UE(@IM<V=S='(@(DYE='-C87!E(%-33"!I;64@<W1R9<6^
M;FEK82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@X
M"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S='(@
M(DYE='-C87!E('5R861N:2!K;VUE;G1A<B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!C97)T:69I
M8V%T92!T>7!E(@IM<V=S='(@(E1I<"!.971S8V%P92!C97)T:69I:V%T82(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C<*;7-G:60@(DYE='=O
M<FLB"FUS9W-T<B`B3VUR9<6^:F4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,C4@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDW
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,Y,`IM<V=I9"`B3F5V97(B"FUS9W-T<B`B3FEK;VQI(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDU"FUS9VED(").97<@0V%L961O;FEA(@IM<V=S='(@(DYO=F$@
M2V%L961O;FEJ82(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R
M>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C(V"FUS9VED(").97<@0V%T96=O<GDB"FUS9W-T<B`B
M3F]V82!K871E9V]R:6IA(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI
M8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS
M9VED(").97<@36]O;B(*;7-G<W1R(").;W9A($QU;F$B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,V"FUS9VED(").97<@57-E<FYA
M;64@*&]P=&EO;F%L*2(*;7-G<W1R(").;W9O('5P;W)A8FYIQ:%K;R!I;64B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3@*;7-G:60@(DYE=R!:96%L86YD(@IM<V=S='(@(DYO
M=F$@6F5L86YD:6IA(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C,W"FUS9VED(").97<@<&%S<W=O<F0B"FUS9W-T<B`B3F]V;R!G97-L;R(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HR-#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+B(*
M;7-G<W1R(").;W9O(&=E<VQO(&)O('!O=&5K;&\@)7@N(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R"FUS9VED(").97<@<&%S<W=O<F1S
M(&1O;B=T(&UA=&-H+B(*;7-G<W1R(").;W9O(&=E<VQO('-E(&YE('5J96UA
M+B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU-PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`U"FUS
M9VED(").97=S(@IM<V=S='(@(DYO=FEC92(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS,C$*;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T<B`B3F]V
M:<2-87)S:V$@<VMU<&EN82(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N
M:6YC.C$U('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0Q"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y('1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC.C(U"FUS9VED(").97AT(@IM<V=S='(@(DYA<VQE9&YJ:2(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HR-PIM<V=I9"`B3F5X="`T(%!H87-E<R(*
M;7-G<W1R(").87-L961N:F4@-"!S=&]P;FIE(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HS-C(@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HS-C8*;7-G:60@(DYE>'0@;W!T:6]N<R(*;7-G<W1R(").87-L961N
M:F$@;6_%OFYO<W0B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C$P
M,PIM<V=I9"`B3F5X=#XB"FUS9W-T<B`B3F%S;&5D;FII/B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-@IM<V=I9"`B3FEC87)A9W5A(@IM<V=S='(@(DYI:V%R86=V82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-@IM<V=I9"`B3FEG97(B"FUS9W-T<B`B3FEG97(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.38*;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`B3FEG97)I:F$B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S<R"FUS9VED(").:6=H
M="(*;7-G<W1R(").:6=E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3FEU92(*
M;7-G<W1R(").:75E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.CDV-@IM<V=I9"`B3F\B"FUS9W-T<B`B3F]B961E;B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM<V=I9"`B3F\@
M879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N
M8V5S(&9O<BXB"FUS9W-T<B`B3FD@9&]S=&]P;FEH('!O9&%T:V]V(&\@:V]N
M9FEG=7)A8VEJ:2!D82!B:2!P;VMA>F%L(')A>FQI:V4N(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HQ,#8*;7-G:60@(DYO
M(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM
M<V=S='(@(E-T<F%T96=I:F$@>F$@:7ID96QA=F\@25-/('-L:6LL(&YI(&1O
M<W1O<&YA+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S
M='(@(DYI('!A:V5T;F4@<')E9&QO9V4B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$P,0HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C,X-0HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C0P-PIM<V=I9"`B3F\@
M8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB"FUS9W-T
M<B`B3F$@Q;YE;&5N96T@;65S="!B96QEQ;YK82!N92!O8G-T86IA+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-C<*;7-G:60@(DYO(&-A
M;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(EIA($U#04P@;W9E<FET978@;FD@:V]L961A<G-K96=A(&EM
M96YA(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-30*;7-G:60@(DYO(&-H
M86YG92XB"FUS9W-T<B`B;FD@<W!R96UE;FIE;F\B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B3F\@8VAI;&1R96X@8V%N
M(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B3F$@=&5J
M('-T;W!N:FD@;F4@9&]D86IA;6\@;W1R;\6A:VEH(&1O=F]L:F5N:BXB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W."!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C4Q,PHC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW
M.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R("):82`E<R!N:2!S
M<&5C:69I8VER86YI:"!K;VYF:6=U<F%C:6IS:VEH(&EN9F]R;6%C:6HN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-#8*;7-G:60@(DYO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93
M+B(*;7-G<W1R("):82!&5%`@5D93(&YI('!O<V5B;FEH(&EN9F]R;6%C:6HN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HW,3`*;7-G:60@(DYO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@
M5D93+B(*;7-G<W1R("(@6F$@4U%,(%9&4R!N:2!P;W-E8FYI:"!I;F9O<FUA
M8VEJ+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW-S4*
M;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(B!:82!D871O=&5K;RU344P@
M5D93(&YI('!O<V5B;FEH(&EN9F]R;6%C:6HN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W-H,BYP:'`Z.#<P"B,L(&9U>GIY"FUS9VED(").;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U-(,B!61E,N(@IM
M<V=S='(@(B!:82!344P@5D93(&YI('!O<V5B;FEH(&EN9F]R;6%C:6HN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B3FD@<W1A;FIA
M(&YA(')AQ(UU;G4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S0*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L
M:65D+B(*;7-G<W1R(").:2!D97-T:6YA8VEJ92(*"B,Z(&9R86UE=V]R:R]"
M<F]W<V5R+T)R;W=S97(N<&AP.CDR-0IM<V=I9"`B3F\@9FEL92!U<&QO861E
M9"(*;7-G<W1R(").:2!N86QOQ;YE;FEH(&1A=&]T96LN(@H*(SH@=71I;"]I
M8V]N7V)R;W=S97(N<&AP.C<Q"FUS9VED(").;R!I8V]N<R!F;W5N9"XB"FUS
M9W-T<B`B3F4@;F%J9&5M(&EK;VXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$R,2!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ,S4*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E
M="XB"FUS9W-T<B`B365S=&\@;FD@;F%S=&%V;&IE;F\N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,@IM<V=I9"`B3F\@;&]C871I;VX@
M<')O=FED960N(@IM<V=S='(@(DUE<W1O(&YI(&YA<W1A=FQJ96YO+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S
M"FUS9VED(").;R!M97-S86=E('-U<'!L:65D+B(*;7-G<W1R(").;V)E;F\@
M<W!O<F_$C6EL;R!D;W-T879L:F5N;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@IM<V=I9"`B3F\@;F%M92!S
M<&5C:69I960N(@IM<V=S='(@(DYI('-P96-I9FEC:7)A;F\@;F]B96YO(&EM
M92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S-PIM<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`B
M3FD@<W!E8VEF:6-I<F%N;R!N;V)E;F\@Q:%T979I;&\N(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED(").;R!O9F9E;G-I=F4@9F]R='5N
M97,B"FUS9W-T<B`B3F]B96YI:"!O9F5N>FEV;FEH('-R9<2-+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X-PIM<V=I9"`B(@HB
M3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/
M<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+
M0U,@,3(@9&%T82XB"FUS9W-T<B`B(@HB4&]T(&1O(&)I;F%R;F4@9&%T;W1E
M:V4@3W!E;E-33"!N:2!B:6QA(&YA<W1A=FQJ96YA+B!/<&5N4U-,(&)I;F%R
M;F$@(@HB9&%T;W1E:V$@:F4@<&]T<F5B;F$@>F$@9&5L;R!S(%!+0U,@,3(@
M<&]D871K:2XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN
M8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM<V=S='(@(DYE('-P
M<F5J96UA;6\@>F'$C6%S;FEH('!R:6IA=B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HX,3@*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B2W9O
M=&$@;FD@;F%S=&%V;&IE;F$O9&]L;\2-96YA+B(*"B,Z(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C0X,@IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I
M9FEE9"XB"FUS9W-T<B`B3FD@<W!E8VEF:6-I<F%N;R!L;\2-:6QO+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3<V"FUS9VED(").;R!S=6-H
M(&9I;&4B"FUS9W-T<B`B3FD@=&%K92!D871O=&5K92(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ,S$*;7-G:60@(DYO('1E;7!O<F%R>2!D
M:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B3F4@;F%J
M9&5M('IAQ(UA<VYE(&UA<&4@>F$@<')E9'!O;6YI;&YI:RXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,0IM<V=I9"`B
M3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(DYO
M8F5N;R!U<&]R86)N:<6A:V\@:6UE(&EN+V%L:2!G97-L;R!N:2!B:6QO('!O
M<VQA;F\N(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ-#`@
M9G)A;65W;W)K+U)00R]24$,O<&AP9W<N<&AP.C$W-0IM<V=I9"`B3F\@=F%L
M:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B4&]V<F%T;FEH('9E;&IA
M=FYI:"!834P@<&]D871K;W8@;FDB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.3<T"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HY.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.CDY-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3`Q,@IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@
M(D)R97H@=G)E9&YO<W1I(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q
M.0IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U
M<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*
M(E8@;W)I9VEN86QN:2!K;VYF:6=U<F%C:6II(&YE(&YA:F1E;2!N;V)E;F4@
M<F%Z;&G$C6EC92X@3V)N;W9I=&D@(@HB:V]N9FEG=7)A8VEJ;RXB"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(W"FUS9VED(").;R!V97)S:6]N(&9O
M=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R("(B"B)6('9AQ:%I(&MO;F9I9W5R86-I:FD@;F4@
M;F%J9&5M(&YO8F5N92!R87IL:<2-:6-E+B!/8FYO=FET92!K;VYF:6=U<F%C
M:6IO+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-R!T
M96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDU"FUS9VED(").
M;VYE(@IM<V=S='(@(DYO8F5D96XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$Y,@IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T<B`B3F]R
M9&EJ<VMI("A)4T\M.#@U.2TQ,"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R
M9F]L:R!)<VQA;F0B"FUS9W-T<B`B3F]R9F]LQ:%K:2!O=&]K:2(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G
M:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B4V5V97)N82!P;VQO
M8FQA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(").;W)T:&5R;B!-87)I86YA($ES
M;&%N9',B"FUS9W-T<B`B4V5V97)N:2!-87)I86YS:VD@;W1O:VDB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3<*;7-G:60@(DYO<G=A>2(*;7-G<W1R(").;W)V9<6A:V$B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,0IM<V=I9"`B
M3F]T($%F=&5R(@IM<V=S='(@(DYE(&MA<VYE:F4B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T($)E9F]R92(*
M;7-G<W1R(").92!P<F5J(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z-#0W"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B3FD@:6UE
M;FEK(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H
M<#HV,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+G!H<#HX-`HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-0HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*;7-G:60@(DYO="!I;7!L
M96UE;G1E9"XB"FUS9W-T<B`B3FD@:7IV961E;F\N(@H*(SH@9G)A;65W;W)K
M+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#4*(SH@9G)A
M;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-C`*
M(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H
M<#HQ-S4*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD
M;&5R+G!H<#HQ.#D*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I
M;VY(86YD;&5R+G!H<#HR,S8@9G)A;65W;W)K+U9&4R]61E,N<&AP.C$Y,PHC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C`X(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HR,S0*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(U,B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z,C8Y"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS
M-C@@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,X-0HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z-#$X(&9R86UE=V]R:R]61E,O5D93+G!H<#HT-S@*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C4U-R!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M-C(V"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HV-#,@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C<R,0HC.B!F<F%M97=O<FLO5D93+U9&4R]H;W)D92YP:'`Z
M.#(@9G)A;65W;W)K+U9&4R]61E,O:&]R9&4N<&AP.C$S,0HC.B!F<F%M97=O
M<FLO5D93+U9&4R]H;W)D92YP:'`Z,34Q(&9R86UE=V]R:R]61E,O5D93+VAO
M<F1E+G!H<#HQ-S`*(SH@9G)A;65W;W)K+U9&4R]61E,O:&]R9&4N<&AP.C$X
M.2!F<F%M97=O<FLO5D93+U9&4R]H;W)D92YP:'`Z,C`W"B,Z(&9R86UE=V]R
M:R]61E,O5D93+VAO<F1E+G!H<#HR,C<@9G)A;65W;W)K+U9&4R]61E,O:&]R
M9&4N<&AP.C,S,`IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B3F4@
M<&]D<&ER86TB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP."!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T"B,Z(&-O
M;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,3(R(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ.#<*;7-G:60@(DYO=&5S(@IM<V=S='(@(EIA<&ES:VDB"@HC.B!S
M97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@
M=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R(").:2!V<&ES86YI:"!B97-E
M9"!Z82!I<VMA;FIE+"!V<FYI=&4@<V4@;F%Z86HN(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4T"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S<*;7-G:60@(DYO=F5M8F5R
M(@IM<V=S='(@(DYO=F5M8F5R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3`U-0IM<V=I9"`B3G5M8F5R(@IM<V=S='(@(L6@=&5V:6QO(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30S.`IM<V=I9"`B3G5M8F5R(&]F
M(&-H87)A8W1E<G,B"FUS9W-T<B`BQ:!T979I;&\@>FYA:V]V(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,X,B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#,V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-3@*;7-G
M:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@(L6@=&5V:6QO('-T;VQP
M8V5V(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,X,"!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-#,T"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T-38*;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(L6@=&5V
M:6QO('9R<W1I8R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C0T"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@
M9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(").
M:2!S<&5C:69I8VER86YI:"#%H71E=FEL:R!Z82!AQ;YU<FER86YJ92!I;B!D
M:7-T<FEB=6-I:G-K:2!S97IN86TN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B3V)J96-T(@IM<V=S='(@
M(EIA9&5V82(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS
M9VED(")/8FIE8W0@0W)E871O<B(*;7-G<W1R(")5<W1V87)J86QE8R!P<F5D
M;65T;W8B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3$S"FUS9VED
M(")/8W1A;"(*;7-G<W1R(")/<VUIQ:%K:2(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,34*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED(")/8W1O8F5R(@IM<V=S
M='(@(D]K=&]B97(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3<*;7-G
M:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS-#(*;7-G:60@(D]F9FEC92(*;7-G<W1R(")0:7-A
M<FYA(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED
M(")/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N(@IM
M<V=S='(@(E-T87)O(&EN(&YO=F\@9V5S;&\@;6]R871A(&)I=&D@<F%Z;&G$
MC6YA+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-@IM<V=I
M9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@(E-T87)O($=E<VQO(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C0V"FUS9VED(")/;&0@<&%S<W=O
M<F0@:7,@;F]T(&-O<G)E8W0N(@IM<V=S='(@(E-T87)O(&=E<VQO(&YI('!R
M879I;&YO+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*;7-G<W1R(")/
M;6%N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M-S,*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O
M;&1E<G,N(@IM<V=S='(@(DUA<&4@=B!S:W5P;FD@=7!O<F%B:2!P;V1P:7)A
M('-A;6\@24U!4"!S=')EQ;YN:6LN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C$P,`IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T
M<B`B4V%M;R!N97-R86UN92!I>FIA=F4B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,C4Y"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L
M;&]W960N(@IM<V=S='(@(D1O=F]L:F5N(&IE(&QE(&5N(&5L96MT<F]N<VMI
M(&YA<VQO=BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8W"B,L
M(&9U>GIY"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&ES(&%L;&]W
M960N(@IM<V=S='(@(D1O=F]L:F5N(&IE(&QE(&5N(&5L96MT<F]N<VMI(&YA
M<VQO=BXB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-S`*;7-G:60@
M(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA
M>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O
M<B!A('-H87)E(@IM<V=S='(@(B(*(DQE(&QA<W1N:6L@86QI('5P<F%V;FEK
M('-I<W1E;6$@;&%H:V\@>F%M96YJ82!L87-T;FG%H71V;R!A;&D@;&%S=&YI
M:V]V;R`B"B)D;W9O;&IE;FIE('IA(&1E;&7%OBXB"@HC.B!L:6(O0FQO8VLO
M:69R86UE+G!H<#HS-@IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS
M9W-T<B`B3V1P<FD@=B!N;W9E;2!O:VYU(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O
M=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N
M(@IM<V=S='(@(D]D<')T85-33"!N87!A:V$Z($YE(&UO<F5M('!O=GIE=&D@
M9&%T=6UA(&EZ(&]Z;F'$C65N96=A(%,O34E-(&1E;&$N(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4X"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM
M<V=S='(@(D]P97)A=&EV;FD@<VES=&5M(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C$U-0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")-;\6^
M;F]S=&DB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S(@=&5M<&QA=&5S+W!R
M969S+V%P<"YI;F,Z,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F
M;W(@)7,B"FUS9W-T<B`B36_%OFYO<W1I('IA("5S(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A=&EO
M;B(*;7-G<W1R(")/<F=A;FEZ86-I:F$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I9"`B3W)G86YI<V%T:6]N86P@56YI
M="(*;7-G<W1R(")/<F=A;FEZ86-I:G-K82!E;F]T82(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ-#$*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T
M<B`B3W)G86YI>F%C:6IA(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,S0*
M;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S='(@
M(DEZ=FER;F4@Q:%A8FQO;F4@87!L:6MA8VEJ(@H*(SH@861M:6XO=&5M<&QA
M=&5S+G!H<#HQ,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@=&5M
M<&QA=&5S(&EN("5S.B(*;7-G<W1R("))>G9I<FYI(,6A86)L;VYE('8@)7,Z
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!S97)V:6-E
M<R]K97EB;V%R9"YP:'`Z,3$W"FUS9VED(")/=&AE<B(*;7-G<W1R(")$<G5G
M;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.2!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3`Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,38@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$R-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3,T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#0*;7-G:60@(D]T:&5R
M($EN9F]R;6%T:6]N(@IM<V=S='(@(D]S=&%L92!I;F9O<FUA8VEJ92(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(D1O=F]L:F5N:F$@;&%S=&YI:V$B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z.#`*;7-G:60@(E!!32!A=71H
M96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")/=F5R:F5N
M:F4@;FD@=7-P96QO(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R
M:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A8VME;F0B"FUS
M9W-T<B`B4$5!4CHZ(&=O;FEL;FEK(%!OQ:%T92(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C$R-S8*;7-G:60@(E!'4"!$:6=I=&%L(%-I
M9VYA='5R92(*;7-G<W1R(")$:6=I=&%L96X@<&]D<&ES(%!'4"(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,C(*;7-G:60@(E!'4"!%
M;F-R>7!T960@1&%T82(*;7-G<W1R(")+;V1I<F%N:2!01U`@<&]D871K:2(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-S0*;7-G:60@
M(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(DIA=FYI(&ML:G5E(%!'4"(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-38*;7-G:60@(E!'
M4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B4&]D<&ES86YI+VMO
M9&ER86YI(%!'4"!P;V1A=&MI(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8W
M"FUS9VED(")02%`@0V]D92(*;7-G<W1R(")02%`@:V]D82(*"B,Z(&%D;6EN
M+W!H<'-H96QL+G!H<#HQ.`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(E!(
M4"!L=7!I;F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS.`IM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R(")0;W!O;&1N
M92!R86AE;"!D9<6^(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%)A:6XB"FUS9W-T<B`B4&]P;VQD;F4@
M9&7%OB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0P"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@(E!O<&]L9&YE(&YA;&EV
M:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q
M"FUS9VED(")032!3;F]W(@IM<V=S='(@(E!O<&]L9&YE('-N96<N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#(*;7-G:60@
M(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")0;W!O;&1N92!S;F7%OFYI(&UE
M=&7%OFDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT,PIM<V=I9"`B4$T@4W5N(@IM<V=S='(@(E!O<&]L9&YE('-O;F-E(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G
M:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(E!O<&]L9&YE(&YE=FEH=&4B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@V"FUS9VED(")03U-)6"!E>'1E
M;G-I;VX@:7,@;6ES<VEN9R(*;7-G<W1R(")0;V=R9<6A86YA(%!/4TE8(&5K
M<W1E;GII:F$B"@HC.B!L:6(O87!I+G!H<#HQ-#D*;7-G:60@(E!?2%`@4VAE
M;&PB"FUS9W-T<B`B4$A0(&QU<&EN82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B
M4&%K:7-T86XB"FUS9W-T<B`B4&%K:7-T86XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS
M9VED(")086QA=2(*;7-G<W1R(")086QA=2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G
M:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B
M4&%L97-T:6YK:2!O:W5P:7)A;FD@=&5R:71O<FEJ(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX
M"FUS9VED(")086YA;6$B"FUS9W-T<B`B4&%N86UA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY
M"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(E!A<'5A($YO=F$@
M1W9I;F5J82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S
M='(@(E!A<F%G=F%J(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S<*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B1&5L
M;F\@;V)L8<2-;F\B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C$U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S`V"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-CD@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHT-`HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#0V"FUS9VED(")087-S=V]R9"(*;7-G<W1R(")'97-L;R(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S
M<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(D=E<VQO('5S
M<&7%H6YO('-P<F5M96YJ96YO(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HQ,S(S"FUS9VED(")087-S=V]R9"!I;F-O<G)E8W0B"FUS
M9W-T<B`B3F5P<F%V:6QN;R!G97-L;R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<F%D:75S+G!H<#HQ-3<*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O
M<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(EIA(%)!1$E54R!O
M=F5R:71E=B!J92!Z86AT979A;F\@9V5S;&\N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,T,0IM<V=I9"`B4&%S<W=O<F0@=VET:"!C;VYF:7)M
M871I;VXB"FUS9W-T<B`B1V5S;&\@:6X@<&]T<F1I=&5V(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP"FUS9VED(")087-S=V]R9#HB"FUS
M9W-T<B`B1V5S;&\Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z
M,3$*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`B1V5S;&\Z("(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$T.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S(R
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G:60@
M(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")'97-L;R!S92!M;W)A
M('5J96UA=&DN(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Q.`IM<V=I9"`B
M4&%S=&4B"FUS9W-T<B`B4')I;&5P:2(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M<75E=65D+FEN8SHW"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@
M(DYE<&]T<FIE;F4@<')I:F%V92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU.0IM<V=I9"`B4&5O<&QE(@IM<V=S='(@(DQJ=61J92(*"B,Z('1E;7!L
M871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED(")0
M97)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B27IV<L6A
M:2!V>F1RQ;YE=F%L;F$@9&5L82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT,3`*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O
M;B!L;V=I;C\B"FUS9W-T<B`B27IV<L6A:6T@=GID<L6^979A;&YA(&1E;&$@
M;V(@<')I:F%V:3\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C$U-@IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R(")$;W9O;&IE;FIE(@H*
M(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E9"XB"FUS9W-T<B`B
M7"(E<UPB(&1O=F]L:F5N:F4@;FD@:7IB<FES86YO+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z-3<Y"FUS9VED(")097)M:7-S:6]N($1E;FEE
M9"(*;7-G<W1R(")$;W9O;&IE;FIE(&IE('IA=G)N:F5N;RXB"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B
M1&]V;VQJ96YJ82(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P."!A9&UI
M;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3D*(SH@861M:6XO<&5R;7,O:6YD97@N
M<&AP.C(Q(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3<*;7-G:60@(E!E<FUI
M<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E5P<F%V;FG%H6MA(&1O
M=F]L:F5N:F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@*;7-G:60@
M(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(D]S96)N92!I;F9O<FUA
M8VEJ92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R(")097)U
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED(")0971S(@IM
M<V=S='(@(DQJ=6)L:F5NQ(UK:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&AI
M;&EP<&EN97,B"FUS9W-T<B`B1FEL:7!I;FDB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G
M<W1R(")496QE9F]N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4P
M,0IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(D9O=&]G<F%F:6IE(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B4&ET8V%I<FXB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*;7-G:60@(E!L871I='5D97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@U,`IM
M<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T
M<B`B4')O<VEM;RP@9&$@=FYE<V5T92!M97-E8R!I;B!L971O+B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C$R"FUS9VED
M(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*
M;7-G<W1R(")0<F]S:6UO+"!D82!V;F5S971E(&EM92!N;W9E(&MA=&5G;W)I
M:F4Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Q,`IM<V=I9"`B
M4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B4')O
M<VEM;RP@9&$@=FYE<V5T92!V96QJ879E;B!)4"!N87-L;W8N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR.`IM<V=I9"`B4&QE87-E(&5N=&5R
M(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H
M92!M;VYT:"XB"FUS9W-T<B`B4')O<VEM;RP@9&$@=FYE<V5T92!V96QJ879E
M;B!D871U;3H@<')E=F5R:71E(,6A=&5V:6QO(&1N:2!V(&UE<V5C=2XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-S,U"FUS9VED(")0;&5A<V4@
M96YT97(@82!V86QI9"!T:6UE+B(*;7-G<W1R(")0<F]S:6UO+"!D82!V;F5S
M971E('!R879I;&5N(,2-87,N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F
M('1H92!P<F]B;&5M+B(*;7-G<W1R(")0<F]S:6UO+"!D82!P<FEP<F%V:71E
M('!O=GIE=&5K('1EQ;YA=BXB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@(E!L
M96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM<V=S
M='(@(E!R;W-I;6\L(&1A('-I(&EZ8F5R971E('5P;W)A8FYIQ:%K;R!I;64@
M:6X@9V5S;&\N(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4X"FUS
M9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-
M55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M
M+B(*;7-G<W1R("(B"B)0<F]S:6UO+"!P<F5B97)I=&4@<VQE9&7$C64@8F5S
M961I;&\N(,2-92#%OF5L:71E('5P;W)A8FQJ871I('1A('-I<W1E;2P@<V4@
M(@HB;6]R871E('-T<FEN:F%T:2!S('!O9V]J:2XB"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM<V=I9"`B4&QE
M87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R(")0<F]S
M:6TL('9N97-I=&4@:6UE(&YO=F4@:V%T96=O<FEJ93HB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3D*;7-G:60@(E!O;&%N9"(*;7-G<W1R(")0;VQJ<VMA(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R(")0
M;VQI=&EK82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,3`*;7-G
M:60@(E!O;&QS(@IM<V=S='(@(D%N:V5T92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G
M:60@(E!O<G1U9V%L(@IM<V=S='(@(E!O<G1U9V%L<VMA(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3$*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@(E!O<W0@=&\@
M=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R(")/
M9&1A:B!V('1O(&UA<&\@*&YI('IA:'1E=F%N;R!O9"!)34%0*2(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C<X(&QI8B]";&]C:R]M971A<BYP:'`Z,C@S
M"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R(&QA<W0@
M)7,@:&]U<BAS*3H@(@IM<V=S='(@(E!A9&%V:6YE('8@>F%D;FII:"`E<R!U
M<F%H.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3$*;7-G
M:60@(E!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B4&%D879I
M;F4\8G(@+SYC:&%N8V4B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O;&1A
M<"YP:'`Z,3,Y"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B!0<F5F<U]L9&%P.B!Z86AT
M979A;F5G82!,1$%0(')A>G1E9V$@;F4@;F%J9&5M+B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C,W"FUS9VED(")0<F5S<W5R92(*;7-G<W1R(")4;&%K
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S$*;7-G:60@(E!R97-S=7)E
M(&%T('-E82!L979E;#H@(@IM<V=S='(@(E1L86L@;F$@;6]R<VMI('9IQ:%I
M;FDZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R.0IM<V=I
M9"`B4')E<W-U<F4Z("(*;7-G<W1R(")4;&%K.B`B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`S"FUS9VED(")0<F5V:65W
M(@IM<V=S='(@(E!R961O9VQE9"(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z,S4R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S4V
M"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S='(@(E!R96K%H6YJ92!M
M;\6^;F]S=&DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,C,*;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(EIA<V5B96X@:VQJ=<2-
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V.0IM<V=I
M9"`B4')O8FQE;2(*;7-G<W1R(")0<F]B;&5M(@H*(SH@<V5R=FEC97,O<')O
M8FQE;2YP:'`Z,3(V"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S
M='(@(EH@;W!I<V]M('-O('1EQ;YA=F4N+B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS.#4*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(E!R;VIE
M:W1I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y.2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-#<V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,U-C,*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S='(@(E1A:V]JQ:%N
M:F4@8F5S961I;&\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T<B`B2F%V;FD@:VQJ=<2-
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#8*;7-G
M:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(D%L9V]R:71E;2!J
M879N96=A(&ML:G7$C6$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(DEN
M9F]R;6%C:6IE(&IA=FYE9V$@:VQJ=<2-82(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y
M<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B2F%V
M;FDO>F%S96)N:2!P87(@:VQJ=<2-978@;FD@8FEL('5S<&7%H6YO(&=E;F5R
M:7)A;BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0=65R=&\@4FEC;R(*;7-G
M<W1R(")0;W)T;W)I:V\B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,T,S$T+G!H<#HU-0IM<V=I9"`B4'5R9V4@;65S<V%G97,B"FUS9W-T<B`B
M4')EQ(UI<W1I('-P;W)OQ(UI;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")1
M871A<B(*;7-G<W1R(")+871A<B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HV
M,@IM<V=I9"`B475E<GDB"FUS9W-T<B`B4&]I>G9E9&)A(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C@P"FUS9VED(")1=6]T82(*;7-G<W1R(")+=F]T
M82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C8T"B,L
M('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(@IM
M<V=S='(@(E)302!J879N:2!K;&IUQ(T@*"5D(&)I=&]V*2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(U-3(*;7-G:60@(E)A9&EO('-E;&5C=&EO
M;B(*;7-G<W1R("))>F)E<FET92!R861I;R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")286EN(@IM<V=S='(@
M(D1EQ;XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT-@IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R(")$9<6^('IJ=71R86HB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-PIM
M<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(D1EQ;X@<&]P;VQD;F4B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B
M4F%I;B!3:&]W97(B"FUS9W-T<B`B3F%L:78B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM<V=I9"`B4F%I;B!A;F0@4VYO
M=R(*;7-G<W1R(")$9<6^(&EN('-N96<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM
M<V=S='(@(D1EQ;X@=B!S;F5G(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,*;7-G:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@(E-R9<2-82(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-@IM<V=I9"`B4F%T:6\B
M"FUS9W-T<B`B4F%Z;65R:F4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-"!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A9"(*;7-G<W1R(")"97)I(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#<*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*;7-G:60@(E)E
M860@;65S<V%G97,B"FUS9W-T<B`B0F5R:2!S<&]R;\2-:6QO(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO
M="!B92!U;F1O;F4N(@IM<V=S='(@(E-T92!P<F5P<FG$C6%N:2P@9&$@Q;YE
M;&ET92!Z8G)I<V%T:2`E<S\@27IB<FES82!N:2!M;V=OQ(UE('!R96ML:6-A
M=&DN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R
M('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM
M<V=S='(@(B(*(E-T92!P<F5P<FG$C6%N:2P@9&$@Q;YE;&ET92!Z8G)I<V%T
M:2!U<&]R86)N:6MO=F4@<&]D871K92!Z82!U<&]R86)N:6MA)7,_("(*(DEZ
M8G)I<V$@;FD@;6]G;\2-92!P<F5K;&EC871I+B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED
M(")2969R97-H(@IM<V=S='(@(D]S=F7%OFDB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,SDU"FUS9VED(")2969R97-H($1Y;F%M:6,@365N=2!%;&5M
M96YT<SHB"FUS9W-T<B`B3W-V9<6^:2!D:6YA;6G$C6YI(&UE;FD@96QE;65N
M=&]V.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#4*;7-G:60@(E)E
M9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(D]S=F7%OFD@<&]R=&%L.B(*
M"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY-`HC+"!F=7IZ>0IM
M<V=I9"`B4F5F<F5S:"!R871E.B(*;7-G<W1R(")/<W9EQ;YI('!O<G1A;#HB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,#,@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(R,@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C0T"FUS9VED(")296=E>"(*;7-G<W1R(")296=E>"(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,U,3@*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W
M<V5R(@IM<V=S='(@(DES:V%L;FEK(')A>FUE<FEJ(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(P.`IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(E!O;F]V;F\@;F%L;\6^
M:2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,X"FUS9VED(")296UA<FMS
M(@IM<V=S='(@(E!R:7!O;6)E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Q-PIM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B3V1D86QJ96YI
M('-T<F7%OFYI:VDB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M.#0*;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO
M:&]R9&4I.B(*;7-G<W1R(")/9&1A;&IE;B!54DP@*&AT='`Z+R]W=W<N97AA
M;7!L92YC;VTO:&]R9&4I.B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T
M+FEN8SHX('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,PIM<V=I9"`B4F5M
M;W9E(@IM<V=S='(@(D]D<W1R86YI(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C4V,0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*
M;7-G<W1R(")/9'-T<F%N:2!S=&]L<&5C(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHQ,C@*;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@(D]D
M<W1R86YI('!A<B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,#$*;7-G
M:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A
M<GD@9&ER96-T;W)Y+B(*;7-G<W1R(")/9'-T<F%N:2!S:')A;FIE;F\@<VMR
M:7!T;R!I>B!S=')EQ;YN:6MO=F4@>F'$C6%S;F4@;6%P92(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*;7-G:60@(E)E;6]V92!U
M<V5R(@IM<V=S='(@(D]D<W1R86YI('5P;W)A8FYI:V$B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(D]D<W1R86YI('5P;W)A8FYI
M:V$Z("5S("(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X
M(&9R86UE=V]R:R]24$,O4E!#+W!H<&=W+G!H<#HQ-S,*;7-G:60@(E)E<75E
M<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@
M(@IM<V=S='(@(EIA:'1E=FD@;F4@;6]R96T@=6=O9&ET:2X@5G)N:F5N82!J
M92!N87!AQ(UN82!K;V1A.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,34P"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@
M8F4@9F]U;F0N(@IM<V=S='(@(DYE(&YA:F1E;2!Z86AT979A;F5G82!S97)V
M:7-A+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3@U(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z-3(S"B,L('!H<"UF;W)M870*;7-G:60@
M(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(EIA:'1E=F%N:2!<(B5S7"(@;FD@<&]D<F]B;F\@
M;V)L:6MO=F%N('8@)7,@:V]N9FEG=7)A8VEJ:2XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C<Q-B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C@U,@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<V@R+G!H<#HX-S8@9G)A;65W
M;W)K+U9&4R]61E,O:&]R9&4N<&AP.C0Q"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HW.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER
M960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(EIA:'1E=F%N:2!<(B5S7"(@;FD@<&]D<F]B;F\@;V)L:6MO
M=F%N('8@5DA3(&MO;F9I9W5R86-I:FDN(@H*(SH@9G)A;65W;W)K+U5T:6PO
M571I;"YP:'`Z-SDP"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB
M)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(EIA:'1E=F%N:2`G)7,G(&YI('!O9')O8FYO(&]B;&EK;W9A;BXB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,S4*;7-G:60@(E)E
M<75I<F5D($9I96QD(@IM<V=S='(@(EIA:'1E=F%N82!D871O=&5K82(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C,P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,T
M.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,C`*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,"!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z-S@*;7-G:60@(E)E<V5T(@IM<V=S='(@(E!O
M;F%S=&%V:2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"FUS
M9VED(")297-E="!087-S=V]R9"(*;7-G<W1R(")0;VYA<W1A=FD@9V5S;&\B
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S
M970@66]U<B!087-S=V]R9"(*;7-G<W1R(")0;VYA<W1A=FET92!V8<6A92!G
M97-L;R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,CD*;7-G:60@(E)E<W1O
M<F4@3&%S="!1=65R>2(*;7-G<W1R(")/8FYO=FET92!Z861N:F\@<&]I>G9E
M9&)O(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C<P(&%D;6EN+V-M9'-H96QL
M+G!H<#HR-R!A9&UI;B]S<6QS:&5L;"YP:'`Z-C4*;7-G:60@(E)E<W5L=',B
M"FUS9W-T<B`B6F%D971K:2(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T
M=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B5G)N:2!S92!N82!-;\6^;F]S=&DB
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S@*;7-G:60@(E)E
M='EP92!N97<@<&%S<W=O<F0B"FUS9W-T<B`B4&]N;W9N;R!V<&G%H6ET92!N
M;W9O(&=E<VQO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F5U;FEO;B(*;7-G
M<W1R(")0;VYO=FYO('ID<G7%OFDB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R
M="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(E!O=G)N:2!K;VYF:6=U<F%C:6IO
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-0IM<V=I9"`B4FEC:"!4
M97AT($5D:71O<B!/<'1I;VYS(@IM<V=S='(@(E9R;FD@<V4@;F$@;6_%OFYO
M<W1I('5R96IE=F%L;FEK82!B97-E9&EL82(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV,PIM<V=I9"`B4FED9&QE<R(*;7-G<W1R(")%;FEG;64B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,SDP"FUS9VED(")2:6=H="!H
M96%D97(B"FUS9W-T<B`B1&5S;F\@;V=L879J92(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,S.#8*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R
M(")$97-N92!V<F5D;F]S=&DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(D9U;FMC
M:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R(")2
M;VUU;FEJ82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR,C8*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B3V)R;FD@>F$@
M,3@P(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(R,PIM<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`B3V)R;FD@;F$@;&5V
M;R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,CD*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R(")/8G)N:2!N82!D97-N
M;R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,3D*;7-G:60@(E)U;B(*;7-G
M<W1R("):8<6^96YI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G5S<VEA;B!&
M961E<F%T:6]N(@IM<V=S='(@(E)U<VEJ82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G
M:60@(E)W86YD82(*;7-G<W1R(")2=6%N9&$B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%($-R>7!T;V=R
M87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(B!3+TU)344@:W)I<'1O9W)A9G-K
M:2!P;V1P:7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@
M(E,O34E-12!K;V1I<F%N;R!S<&]R;\2-:6QO(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S87-L+G!H<#HX,@IM<V=I9"`B4T%33"!A=71H96YT:6-A=&EO
M;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")305-,($]V97)J86YJ92!N
M:2!U<W!E;&\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3(X"FUS
M9VED(")335,@365S<V%G:6YG(@IM<V=S='(@(E--4R!S<&]R;\2-:6QO(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Y"FUS9VED(")344P@4VAE;&PB"FUS
M9W-T<B`B4U%,(&QU<&EN82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,U-C$*;7-G:60@(E-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',B
M"FUS9W-T<B`B4U%,('-T879E:R!Z82!P;VEZ=F5D8F\@=G)E9&YO<W1I(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U-`IM<V=I9"`B4U-((@IM
M<V=S='(@(E-32"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-50T-%4U,B
M"FUS9W-T<B`B55-014@B"@HC.B!L:6(O87!I+G!H<#HQ-3,*;7-G:60@(E-?
M44P@4VAE;&PB"FUS9W-T<B`B4U%,(&QU<&EN82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C,*;7-G:60@(E-A(@IM<V=S
M='(@(E-A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM
M<V=S='(@(E-V971A($AE;&5N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B4V%I
M;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@(E-A:6YT($MI='1S(&%N9"!.
M979I<R`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S
M='(@(E-A:6YT($QU8VEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@
M4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R(")386EN="!0:65R<F4@86YD
M($UI<75E;&]N("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E-A:6YT(%9I;F-E
M;G0@86YD('1H92!'<F5N861I;F5S(@IM<V=S='(@(E-A:6YT(%9I;F-E;G0@
M:6X@1W)E;F%D:6YE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B4V%M;V$B"FUS
M9W-T<B`B4V%M;V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")386X@36%R:6YO
M(@IM<V=S='(@(E-A;B!-87)I;F\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")3
M86\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B4V%O(%1O;64@:6X@4')I
M;F-I<&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS
M9VED(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B4V%T96QI='-K:2!O
M<VMR8F]V86QE8R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R86)I
M82(*;7-G<W1R(")3875D<VMA($%R86)I:F$B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+VQA>6]U="YI;F,Z,3$U"FUS9VED(")3879E(@IM<V=S='(@(E-H<F%N
M:2(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B4VAR86YI
M(%PB)7-<(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V"B,L
M('!H<"UF;W)M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`B4VAR86YI("5S
M("(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@
M3W!T:6]N<R(*;7-G<W1R(")3:')A;FD@36_%OFYO<W1I(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$V-@IM<V=I9"`B(@HB4V%V92!G96YE<F%T960@
M8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G
M<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R("(B"B)3:')A;FET
M92!G96YE<FER86YO(&MO;F9I9W5R86-I:F\@:V]T(%!(4"!S:W)I<'1O(&YA
M('IAQ(UA<VYI(&UA<&D@(@HB=F'%H65G87-T<F7%OFYI:V%D:7)E8W1O<GDN
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B4VAR
M86YJ96YA("5S(&MO;F9I9W5R86-I:F$B"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HY.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U
M<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(")3:')A;FIE;F$@
M;F%S=&%V:71V96YE('-K<FEP=&$@;F%D9W)A9&YJ92!N83H@7"(E<UPB+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"FUS
M9VED(")38V%T=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B4F%Z9&EV:F%N82!N
M979I:'1A('H@9W)M96YJ96TB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C0*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B6FYA;F]S="(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C$V"FUS9VED(")396%R8V@B"FUS9W-T<B`B2<6AQ(UI
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S-@IM<V=I9"`B4V5A
M<F-H($5N9VEN97,B"FUS9W-T<B`B27-K86QN:6MI(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S(T,PIM<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S
M='(@(DEZ8F5R:2!D871O=&5K;R(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT.#D*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS
M9W-T<B`B27IB97)I(&1A='5M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R
M("))>F)E<FD@<VMU<&EN;RP@:VD@:F\@Q;YE;&G%H2!D;V1A=&DN(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@
M;F5W(&]W;F5R(@IM<V=S='(@(DEZ8F5R:2!N;W9E9V$@;&%S=&YI:V$B"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@(E-E;&5C
M="!A('-E<G9E<B(*;7-G<W1R("))>F)E<FD@<W1R9<6^;FEK(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C="!A('5S
M97(@=&\@861D(@IM<V=S='(@(DEZ8F5R:2!U<&]R86)N:6MA+"!K:2!G82#%
MOF5L:<6A(&1O9&%T:2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HV-S@*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T<B`B27IB
M97)I('9S92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S$*;7-G
M:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R("))>F)E
M<FD@<&]P;VQN(&1A='5M(@H*(SH@<V5R=FEC97,O961I=&]R+WAI;FAA+W!L
M=6=I;G,O06YS96Q);6%G92]I;G-E<G1?:6UA9V4N<&AP.C$S,@HC+"!F=7IZ
M>0IM<V=I9"`B4V5L96-T(&%N(&EM86=E(@IM<V=S='(@(DEZ8F5R:2!D871U
M;2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX
M-S,*;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B27IB97)I('!R
M961M970B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-C<Y"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R(")/9&ML:G5K86H@
M=G-E(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W"FUS9VED("(B"B)3
M96QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@
M8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R
M;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B(@HB6FYA:V4L(&MI(&II:"!P
M;W1R96)U:F5T92!I>F)E<FET92!I>B!O:W9I<FIE=B!S<&]D86HN($YA=&\@
M:FEH(&QA:&MO("(*(FMO<&ER871E(&EN('!R:6QE<&ET92!V+VEZ(&)E<V5D
M:6QA+B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS9VED(")3
M96QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R(")$;VQOQ(UI(&MO
M;L2-;FD@9&%T=6TZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*
M;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM<V=S='(@(DEZ8F5R
M:2!O8FQI:V\@9&%T=6UA.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET
M>7-E;&5C="YI;F,Z.3(*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U
M('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R("))>F)E<FET92!I9&5N=&ET971O
M+"!K871E<F\@Q;YE;&ET92!S<')E;65N:71I.B(*"B,Z('1E;7!L871E<R]D
M871A+W1I;64N:6YC.C$V"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI
M=&5R.B(*;7-G<W1R(")$;VQOQ(UI(&MO;L2-;F\@=7)O.B(*"B,Z('1E;7!L
M871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE('1I;64@
M9F]R;6%T.B(*;7-G<W1R("))>F)E<FD@;V)L:6MO('5R93HB"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C4W"FUS9VED(")396QE8W0@='=O(&UA
M=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`B27IB97)I(&1V92!U:F5M86IOQ(UI
M('-E('!O;&II.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,3`*;7-G
M:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B27IB97)I
M=&4@=F'%H64@8F%R=FYO(&MO;6)I;F%C:6IO(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(U,@IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D(&QA
M;F=U86=E.B(*;7-G<W1R("))>F)E<FET92!J97II:SHB"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU,0IM<V=I9"`B4V5N9"!0<F]B;&5M
M(%)E<&]R="(*;7-G<W1R(")0;\6A;&II('!O<F_$C6EL;R!O(&YA<&%K86@B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`T
M,@IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B4&_%H6QJ:2!335,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`V"FUS9VED(")396YE9V%L(@IM<V=S='(@(E-E;F5G86PB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R.`IM<V=I9"`B4V5N<V]R.B`B"FUS
M9W-T<B`B4V5N>F]R.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,30*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0U,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C<U"FUS9VED(")397!T96UB97(B"FUS9W-T<B`B4V5P<F5M
M8F5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3D*
M;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R;R(*;7-G<W1R(")3<F)I:F$@
M:6X@Q(UR;F$@9V]R82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-S`R"FUS9VED(")397)I86P@3G5M8F5R(@IM<V=S='(@(E-E<FEJ
M<VMA(,6A=&5V:6QK82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-30*;7-G:60@(E-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B
M;&4N(@IM<V=S='(@(E-T<F7%OFYI:V]V(&1A='5M(&IE(&YA<&'$C65N(&%L
M:2!N:2!N82!R87IP;VQA9V\N(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(V
M"FUS9VED(")397-S:6]N($%D;6EN(@IM<V=S='(@(D%D;6EN:7-T<F%C:6IA
M('-E:F4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E9"XB"FUS9W-T
M<B`B240@<V5J92!J92!P;W1E:VQA+B(*"B,Z(&QI8B]A<&DN<&AP.C$T-0IM
M<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B4V5J92(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(V,#(*;7-G:60@(E-E="(*;7-G<W1R(").86UE<W1I
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y"FUS9VED(")3970@;W!T
M:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y
M;W4@979E<B!F;W)G970@:70N(@IM<V=S='(@(B(*(DYA<W1A=FD@;W!C:6IO
M+"!D82!V('!R:6UE<G4L(&1A('!O>F%B:71E('9AQ:%E(&=E<VQO+"!L86AK
M;R!P;VYA<W1A=FET92!L92TB"B)T;RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3$X"FUS9VED(")3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y
M;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B
M(@HB57)E9&ET92!O9&1A;&IE;F4@<W1R9<6^;FEK92!N82!K871E<F4@Q;YE
M;&ET92!D;W-T;W!A=&D@>B!V8<6A96=A('!O<G1A;&$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#<*;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L
M86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B
M3F%S=&%V:71E('!R:79Z970@:F5Z:6L@:6X@;F%S=&%V:71V92!D871U;6$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Q"FUS9VED("(B"B)3970@
M>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@
M<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS
M9W-T<B`B57)E9&D@>F'$C65T;F4@8F%R=FYE('-H96UE+"!A<&QI:V%C:6IE
M+"!O<W9EQ;YI='9E('-T<F%N:2XN+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-S<*;7-G:60@(E-E='5P(@IM<V=S='(@(DYA;65S=&DB"@HC.B!T
M96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS-0IM<V=I9"`B4V5T
M=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R(").87-T879I
M('-K<FEP=&\@>F$@;W-V9<6^:71E=B!K;W0@<F%Z<&]L;\6^;&II=F\N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$X,`IM<V=I9"`B4V5V
M97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B
M"FUS9W-T<B`B36_%OFYI:"!J92!V9<2-(&QO:V%C:6H@<R!P87)A;65T<F]M
M.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T<B`B
M4V5JQ:%E;&DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$Y"FUS
M9VED(")3:&]P<&EN9R(*;7-G<W1R(").86MU<&]V86YJ92(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED(")3:&]R="!3=6UM
M87)Y(@IM<V=S='(@(DMR871E:R!P;W9Z971E:R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT-3`*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D
M969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R(").871A=FEM('1I<&MA
M<G-K92!B;&G%OFYI8V4@;F$@<&]V97IA=F4_(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS
M,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`B
M4&]K8<6^:2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-30*;7-G:60@
M(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@
M86YD('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B(@HB4&]K8<6^:2!R87IL:6ME(&UE9"!S961A:B!S:')A;FIE;F\@
M:6X@;F%J;F]V96K%H6\@9V5N97)I<F%N;R!K;VYF:6=U<F%C:6IO+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.#4*;7-G:60@(E-H;W<@;&%S="!L
M;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`B4')I:V'%OFD@
M9&%T=6T@>F%D;FIE('!R:6IA=F4@<&\@=G-T;W!U/R(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$W-S@*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME
M97`@;W)I9VEN86PB"FUS9W-T<B`B4')I:V'%OFD@;W!C:6IE('IA(&]B9'+%
MOF%T:2!O<FEG:6YA;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,P
M.#,*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(E!O:V'%OFD@=&ES=&5G
M82P@:VD@<W!R96IE;6$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(P
M"FUS9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM<V=S
M='(@(E!R:6MAQ;YI(&UE;FEJ<VMO('9R<W1I8V\@9&5L;W9A;FIA('1A8F5L
M92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\B"FUS9W-T
M<B`B4')I:V'%OF5M("5S(&UE;FD@;F$@;&5V:2!S=')A;FD_(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<W-@IM<V=I9"`B4VAO=R!U<&QO860B
M"FUS9W-T<B`B1&]D86H@;F%L86=A;FIE(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H;W=E<G,B"FUS9W-T
M<B`B4&QO:&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R(")::G5T<F%J
M('!L;VAE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-30*;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G<W1R(")0;W!O;&1N92!P
M;&]H92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4U"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R(")6
M(&)L:<6^:6YI('!L;VAE(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HV,3D*;7-G:60@(E-H<FEN:R(*;7-G<W1R(")3
M:W+$C6DB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.CDQ,`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.CDW,@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.C$P-3@*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HQ,3(P"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70O36%N86=E<BYP:'`Z,3$X,PHC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R,C,*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C4R"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(X-0IM<V=I9"`B
M4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T
M:&4@=V%Y(&9I<G-T(@IM<V=S='(@(DYA:G!R96H@<VMRQ(UI(&%L:2!P<F5M
M86MN:2!S;W-E9&YJ92!B96QEQ;YK92XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED
M(")3:65R<F$@3&5O;F4B"FUS9W-T<B`B4VEE<G)A($QE;VYE(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V-PIM<V=I9"`B4VEG;B!U
M<"(*;7-G<W1R(")0<FEJ879I('-E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HW,3,*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R(")0
M;V1P:7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q
M,@IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R(")!;&=O<FET
M;6G$C65N('!O9'!I<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R
M92(*;7-G<W1R(")3:6YG87!U<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C4@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HW,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C@T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDP-0HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C(T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R-#8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4S-"!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,C`P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,S.3(*;7-G:60@(E-I>F4B"FUS9W-T<B`B5F5L:6MO<W0B"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM<V=I
M9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R(")0<F5S:V_$C6D@=GID<L6^
M979A;FIE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T
M<B`B4VQO=F'%H6MA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F5N:6$B
M"FUS9W-T<B`B4VQO=F5N:6IA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-38*;7-G:60@(E-N;W<B"FUS9W-T<B`B4VYE9R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS
M9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R(")3;F7%OFYA('!L;VAA(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@
M(E-N;W<@4VAO=V5R<R(*;7-G<W1R(")3;F7%OFYE('!L;VAE(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-N
M;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R(")::G5T<F%J('-N9<6^;F4@<&QO
M:&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M,`IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B4&]P;VQD;F4@
M<VYEQ;YN92!P;&]H92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDP"FUS
M9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B5FG%H6EN82!S;F5G83HB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-`IM<V=I9"`B4VYO=R!E<75I=F%L
M96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B4VYE9W4@96MV:79A;&5N=&YA(&MO
M;&G$C6EN82!V;V1E.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M;VX@
M27-L86YD<R(*;7-G<W1R(")386QO;6]N;W9I(&]T;VMI(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,30@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-@IM<V=I9"`B4V]M86QI82(*;7-G<W1R(")3;VUA;&EJ82(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*
M;7-G<W1R(")097-M:2!I;B!P;V5Z:6IE(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$Y-@IM<V=I9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS
M9W-T<B`B5G)S=&$@=7)E:F5N96=A(&EZ8F]R82(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Q-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-#<*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-C8*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.#D*;7-G:60@
M(E-O=7)C92!A9&1R97-S(@IM<V=S='(@(DYA<VQO=B!V:7)A(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-34@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(DIUQ;YN82!!
M9G)I:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B4V]U
M=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(DIUQ;YN;RUE=G)O
M<'-K:2`H25-/+3@X-3DM,RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(E-O=71H
M($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM<V=S
M='(@(DIUQ;YN82!'96]R9VEA(&EN(&]T;VMI($IUQ;YN:2!386YD=VEC:"(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z
M-C(*;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B2G7%OFYA
M('!O;&]B;&$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX,C0*;7-G
M:60@(E-P86-E<B(*;7-G<W1R(")0<F5S;&5D;FEC82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q
M"FUS9VED(")3<&%I;B(*;7-G<W1R("+%H'!A;FEJ82(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ,#<*;7-G:60@(E-P86TB"FUS9W-T<B`B3F5Z
M8<6^96QE;F$@<&_%H71A(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T
M"FUS9VED(")3<&5C:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R(")6:&]D
M('IA('!O<V5B;F4@>FYA:V4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C8*;7-G:60@(E-P;W)T<R(*;7-G<W1R("+%H'!O<G1I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@X"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T<B`BQ:!R:2!,86YK82(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,2!L:6(O0FQO8VLO;65T
M87(N<&AP.C@V"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R(")3=&%N9&%R9&5N
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8W"FUS9VED(")3=&%R(%1R
M96LB"FUS9W-T<B`B6G9E>F1N92!S=&5Z92(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X-S0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S`W.0IM
M<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R("):8<2-971N;R!L971O(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S$*;7-G:60@(E-T
M871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(D1RQ;YA=F$@86QI('!R;W9I;F-A
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3`*;7-G
M:60@(E-T871U<R(*;7-G<W1R(")3=&%T=7,B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,#@U"FUS9VED(")3=&]R86=E(&9O<FUA="(*;7-G<W1R
M(")/8FQI:V$@<&]M;FEL;FEK82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3<S"FUS9VED(")3=')E970@061D<F5S<R(*;7-G<W1R
M(").87-L;W8@=6QI8V4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C0R"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R(")3<&ES96L@8F5S961N
M:6@@>G9E>B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,3$*;7-G
M:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@(C\_
M/S\_/S\_/S]D;VUE;F$@:7H@;F%S;&]V82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C0*;7-G:60@(E-U(@IM<V=S='(@
M(DYE(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L('!H<"UF;W)M
M870*;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G
M<W1R(").92!N86ID96T@<&]D;6%P92!<(B5S7"(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8Y"FUS9VED(")3=6)J96-T
M(@IM<V=S='(@(EIA9&5V82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,T,2!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3<*;7-G
M:60@(E-U8FUI="(*;7-G<W1R(")0<F5D;&_%OFDB"@HC.B!S:6=N=7`N<&AP
M.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T
M('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L;V<@
M:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*
M;7-G<W1R("(B"B)3<')E:F5L:2!S;6\@>F%H=&5V96L@>F$@=G!I<R!<(B5S
M7"(N($YE(&UO<F5T92!S92!P<FEJ879I=&D@9&]K;&5R('9AQ:%A("(*(GIA
M:'1E=F5K(&YE('!O('!O=')J96XN(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$P,PHC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S='(@
M(E5S<&5H(@H*(SH@861M:6XO=7-E<BYP:'`Z.#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M
M+B(*;7-G<W1R(")<(B5S7"(@<V5M('5S<&7%H6YO(&1O9&%L(&L@<VES=&5M
M=2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@
M9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("(G)7,G('-E;2!U<W!EQ:%N;R!O
M9'-T<F%N:6P@:7H@<VES=&5M82XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Y
M(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R(")<(B5S
M7"(@<V5M('5S<&7%H6YO(&EZ8G)I<V%L+B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$P-`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E
M9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R(")<(B5S7"(@<V5M
M('5S<&7%H6YO(&]D<W1R86YI;"!I>B!S:7-T96UA+B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E
M9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S
M='(@(B(*(E5S<&7%H6YO(&]B<FYJ96YA(&MO;F9I9W5R86-I:F$N(,2-92#%
MOF5L:<6A('9I9&5T:2!S<')E;65M8F4L('!O;F]V;F\@;F%L;\6^:2XB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B57-P9<6A;F\@<VAR86YJ96YA('9A<FYO
M<W1N82!K;W!I:F$@:V]N9FEG=7)A8VEJ92XB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL
M>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS
M9W-T<B`B57-P9<6A;F\@<VAR86YJ96YA('9A<FYO<W1N82!K;W!I:F$@:V]F
M:6=U<F%C:6IE(&1A=&]T96ME("5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=7!D871E9"!<
M(B5S7"(B"FUS9W-T<B`B7"(E<UPB(&IE(&)I;"!U<W!EQ:%N;R!P;W-O9&]B
M;&IE;BXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S
M9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`B)7,@<V5M('5S<&7%H6YO('IA<&ES
M86PN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W5D86XB"FUS9W-T<B`B4W5D
M86XB"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C4*;7-G:60@(E-U;B!2
M:7-E(@IM<V=S='(@(E-O;L2-;FD@=GIH;V0B"@HC.B!L:6(O0FQO8VLO<W5N
M<FES92YP:'`Z-C@*;7-G:60@(E-U;B!3970B"FUS9W-T<B`B4V]NQ(UN:2!Z
M86AO9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8Q"FUS9VED(")3=6YN>2(*;7-G<W1R(")3;V[$C6YO(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,`IM<V=I9"`B4W5N<FES92(*;7-G
M<W1R(")3;V[$C6YI('9Z:&]D(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP
M.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E+U-U
M;G-E="(*;7-G<W1R(")3;V[$C6YI('9Z:&]D+WIA:&]D(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(P.0IM<V=I9"`B4W5N<FES93H@(@IM
M<V=S='(@(E-O;L2-;FD@=GIH;V0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C$S"FUS9VED(")3=6YS970B"FUS9W-T<B`B4V]NQ(UN:2!Z
M86AO9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3(*;7-G
M:60@(E-U;G-E=#H@(@IM<V=S='(@(E-O;L2-;FD@>F%H;V0Z(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,Y-`IM<V=I9"`B4W5P<&]R="(*;7-G
M<W1R(")0;V1P;W)A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4W5R:6YA;64B
M"FUS9W-T<B`B4W5R:6YA;2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3<U"FUS9VED(")3=7)N86UE(@IM<V=S='(@(E!R:6EM96LB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA>65N
M(@IM<V=S='(@(E-V86QB87)D(&EN($IA;B!-87EE;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#@*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R(")3=F%Z:2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G<W1R("+%H'9E9'-K82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-38@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8V"FUS9VED(")3=VET>F5R;&%N9"(*;7-G<W1R("+%H'9I8V$B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@IM<V=I9"`B4WEN8R!L
M;V<@9&5L971E9"(*;7-G<W1R("))>F)R:7-A;B!S:6YK<F]N:7IA8VEJ<VMI
M(&1N979N:6LB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30U"FUS9VED
M(")3>6YC34PB"FUS9W-T<B`B4VEN:W)O;FEZ86-I:F$B"@HC.B!F<F%M97=O
M<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O
M<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B3F%P86MA('8@<VEN=&%K<VD@
M:7-K86QN:6@@<&]G;VIE=B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-Y<FEA
M;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(E-I<FEJ<VMA(&%R86)S:V$@<F5P
M=6)L:6MA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C(*;7-G:60@(E0M4W1O<FTB"FUS9W-T<B`B1W)M96YJ92(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8S"FUS9VED(")4
M+5-T;W)M(&%N9"!7:6YD>2(*;7-G<W1R(").979I:'1A('H@9W)M96YJ96T@
M:6X@=F5T<F]M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C0*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(DYE=FEH=&$@>B!G
M<FUE;FIE;2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8U"B,L(&9U>GIY"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R
M(")::G5T<F%J('!L;VAE(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N
M<&AP.C$V-@IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B5%-6(&1A=&]T96MA
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU
M-PIM<V=I9"`B5&%B;&4@4V5T(@IM<V=S='(@(DYA<W1A=FET978@=&%B96QE
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S0@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I=V%N(@IM<V=S='(@
M(E1A:G9A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM<V=S='(@
M(E1A:7=A;BP@9&7%OF5L82!+:71A:G-K92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G
M:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B5&%DQ;YI:VES=&%N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B(*
M;7-G<W1R(")486YZ86YI:F$L(%ID<G7%OF5N82!R97!U8FQI:V$B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS,B!C;VYF:6<O:&]O:W,N<&AP
M+F1I<W0Z,3$P-PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DV"FUS
M9VED(")487-K<R(*;7-G<W1R(")/<')A=FEL82(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3<T"FUS9VED(")496QE<&AO;F4@3G5M
M8F5R(@IM<V=S='(@(E1E;&5F;VYS:V$@Q:%T979I;&MA(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS,#(*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@
M(@IM<V=S='(@(E1E;7!E<F%T=7)A('8@>F%D;FII('5R:3HB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(R-@IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T
M<B`B5&5M<&5R871U<F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C$W"FUS9VED(")496UP97)A='5R93H@(@IM<V=S='(@(E1E;7!E<F%T
M=7)A.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@V"B,L
M('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E
M<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B5&5M<&5R871U<F$\8G(@+SXH)7-(
M:25S+R5S3&\E<RD@)F1E9SLE<R(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]4
M96UP;&%T92YP:'`Z-CDU"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E
M(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(EPB)7-<(B!V>F]R8V$@;F4@
M;F%J9&5M+B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,38X"FUS9VED(")4
M96UP;&%T92!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")5<F5J979A;&YI:R#%
MH6%B;&]N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(R,"!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS-C$T"FUS9VED(")497AT(@IM<V=S='(@
M(D)E<V5D:6QO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.0IM<V=I
M9"`B5&5X="!/;FQY(@IM<V=S='(@(E-A;6\@0F5S961I;&\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")4
M:"(*;7-G<W1R(")4;R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS
M9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y
M"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R(")486IS:V$B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C@T,@IM<V=I9"`B5&AE($944"!E>'1E;G-I
M;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3W9E<FIE;FIE(&YI('5S
M<&5L;R(*"B,Z(&9R86UE=V]R:R](:7-T;W)Y+TAI<W1O<GDN<&AP.C8S"FUS
M9VED(")4:&4@2&ES=&]R>2!S>7-T96T@:7,@9&ES86)L960N(@IM<V=S='(@
M(EIG;V1O=FEN82!J92!I>FML;W!L:F5N82XB"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.CDS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R
M9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@
M7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B(&EN=&5G<F%C:6IA(&YE('!O
M9'!I<F$@7"(E<UPB(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O0F]O
M:RYP:'`Z,3(Y.`IM<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I
M;FET:6%L:7IE9"XB"FUS9W-T<B`B4&]S;V1O8FQJ96X@9&%T;W1E:V4@;F4@
M;6]R96T@<VAR86YI=&DN(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C,Q"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO
M860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(E9Z9'+%OF5V86YJ93H@<F%Z<F5D
M(&YI(&)I;"!U<W!EQ:%N;R!N86QOQ;YE;BXB"@HC.B!S97)V:6-E<R]I;6%G
M97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD
M;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B3VMN;R!-;\6^;F]S
M=&D@:F4@8FEL;R!Z87!R=&\N(%IA:VQJ=65U:F5M+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-S:#(N<&AP.C@V-@HC+"!F=7IZ>0IM<V=I9"`B5&AE(%-3
M2#(@4$5#3"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
M3W9E<FIE;FIE(&YI('5S<&5L;R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,3@Y(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C`P"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C$Q(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C,T
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,C8T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,S`S"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF
M:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@
M(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(D%D;6EN:7-T
M<F%T;W(@;6]R82!N86IP<F5J(&YA<W1A=FET:2!S:7-T96T@>F$@<')A=FEC
M92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N
M;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@
M=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R(")+;VYT86MT;FD@240@;FD@8FEL
M('!O<W)E9&]V86X@86QI(&YI(&)I;"!N86ID978@=B!B87II('!O9&%T:V]V
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU
M,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T
M;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B4W1I:R!J92!B:6P@=7-P
M9<6A;F\@9&]D86X@:R!V8<6A:6T@;F%S;&]V;VTN($ML:6MN:71E('-P;V1A
M:B!Z82!O9VQE9#HB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,3<R"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B
M;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E
M+B(*;7-G<W1R("(B"B)0;W1R96)U:F5M(&QOQ(UE;F\@4$=0('!O9'!I<V%N
M;R!B96QEQ;YN:6-O+"!D82!P<F5V:7)I;2!P;V1P:7-A;F\@<W!O<F_$C6EL
M;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A
M<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U
M;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R("))1"!S97IN86UA(&YI
M(&)I;"!P;W-R961O=F$@86QI(&YI(&)I;"!N86ID96X@=B!B87II('!O9&%T
M:V]V+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO
M="!S<&5C:69I960N(@IM<V=S='(@(E1O(&1E:F%N:F4@;FEM82!P;V1P;W)E
M+B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z-#8S"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!E;6%I;"!A9&1R97-S("5S(&AA
M<R!B965N(&%D9&5D('1O('EO=7(@:61E;G1I=&EE<RX@66]U(&-A;B!C;&]S
M92!T:&ES("(*(G=I;F1O=R!N;W<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="YP:'`Z,3$V"FUS9VED(")4:&4@96YC<GEP=&EO;B!F
M96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G
M<W1R(")+;V1I<F%N82!V<V5B:6YA('IA:'1E=F$@=F%R;F\@:6YT97)N971N
M;R!P;W9E>F%V;RXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$X
M-B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4R-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I
M;F<N(@IM<V=S='(@(B5S(&1A=&]T96MA(&)I(&UO<F%L82!V<V5B;W9A=&D@
M)7,@;F%S=&%V:71V<BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$W.2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S
M('-E='1I;F=S+B(*;7-G<W1R("(E<R!D871O=&5K82!B:2!M;W)A;&$@=G-E
M8F]V871I("5S(&YA<W1A=FET=F4N("(*"B,Z(&9R86UE=V]R:R]$871A+T1A
M=&$N<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N
M(@IM<V=S='(@(D1A=&]T96MA(&YE('9S96)U:F4@;F]B96YI:"!P;V1A=&MO
M=BXB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,3(T"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB
M"FUS9W-T<B`B4W1R9<6^;FEK(%PB)7-<(B!J92!B:6P@:7IB<FES86XN(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B
M"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I
M=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B365S=&\@
M1VYU4$<@<')O9W)A;6$@;6]R82!B:71I('!O<W)E9&]V86YO(')A>G)E9'4@
M0W)Y<'1?<&=P+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HR
M,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O
M;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L
M87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A
M9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"B)3
M<&]R;\2-:6QO('!O<VQA;F\@9&YE("5S('IA("5S('H@;F%S;&]V;VT@7"(E
M<UPB(&IE(&)I;"!P<F5B<F%N+EQN(@HB3FD@>F%G;W1O=FEL82!D82!J92!B
M:6QO(&1E:F%N<VMO('!R96)R86YO(&%L:2!R87IU;6QJ96YO+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,34*;7-G:60@(E1H92!N86UE('1O
M('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R
M("));64@>F$@<&]V97IA=F\@;F$@<W1R86X@>F$@<V5S=&%V;&IA;FIE('-P
M;W)OQ(UI;&$N(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C$P-@IM<V=I9"`B
M5&AE(&YE=R!F<F]M(&%D9')E<W,@8V%N)W0@8F4@=F5R:69I960L('1R>2!A
M9V%I;B!L871E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C0W-`IM<V=I9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@;75S
M="!B92!N=6UE<FEC+B(*;7-G<W1R(")482!V<F5D;F]S="!M;W)A(&)I=&D@
MQ:%T979I;&MA+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,3(S,@IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D
M(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B
M4&]T<F5B=6IE;2!O<&5N<W-L(&UO9'5L('IA($AO<F1E7T-R>7!T7W-M:6UE
M.CH@<F%Z<F5D+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,CDV
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<
M(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E
M9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"B).
M87-T879I96YE(&1A=&]T96ME(%PB)7-<(B!N92!M;W)E('-H<F%N:71I+"!K
M97(@;FIE;FD@<&]D871K:2`B"B)P<F5S96=A:F]N86IV9<2-:FD@9&]V;VQJ
M96X@;V)S96<N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+VQD87`N<&AP
M.C,P-2!F<F%M97=O<FLO4')E9G,O4')E9G,O<W%L+G!H<#HQ-#4*;7-G:60@
M(B(*(E1H92!P<F5F97)E;F-E<R!B86-K96YD(&ES(&-U<G)E;G1L>2!U;F%V
M86EL86)L92!A;F0@>6]U<B!P<F5F97)E;F-E<R!H879E("(*(FYO="!B965N
M(&QO861E9"X@66]U(&UA>2!C;VYT:6YU92!T;R!U<V4@=&AE('-Y<W1E;2!W
M:71H(&1E9F%U;'0@<V5T=&EN9W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A
M=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS
M9W-T<B`B4')O9W)A;6$L(&MI(&]D<&ER82!P;V1A=&ME('1E('9R<W1E("@E
M<RD@;F4@;F%J9&5M('8@<VES=&5M=2XB"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HT.#<*;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@;75S
M="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B4F%Z;65J:71E
M=B!M;W)A(&)I=&D@<V5S=&%V;&IE;F$@;&4@:7H@96YE9V$@>FYA:V$N(@H*
M(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#<Y"FUS9VED(")4:&4@
M<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S
M='(@(DQOQ(UI=&5V(&UO<F$@8FET:2!S97-T879L:F5N82!L92!I>B!E;F5G
M82!Z;F%K82XB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E
M;B!D96QE=&5D+B(*;7-G<W1R(")3=')EQ;YN:6L@7"(E<UPB(&IE(&)I;"!I
M>F)R:7-A;BXB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E
M;B!S879E9"XB"FUS9W-T<B`B4W1R9<6^;FEK(%PB)7-<(B!J92!S:')A;FIE
M;BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@
M<F5M;W9E9"XB"FUS9W-T<B`B6F%H=&5V96L@>F$@<')I:F%V;R!J92!B:6P@
M;V1S=')A;FIE;BXB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.C0W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<W!E
M8VEF:65D(')O=R`H)60I(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("))>F)R
M86YA('9R<W1I8V$@*"5D*2!N92!O8G-T86IA+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,C`R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*
M;7-G<W1R("):8<2-87-N82!D871O=&5K82!N92!O8G-T86IA+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,U.#D*;7-G:60@(E1H92!T97AT('EO
M=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E
M;BXB"FUS9W-T<B`B5FYEQ:%E;F\@8F5S961I;&\@;F4@=7-T<F5Z82!B97-E
M9&EL;R!N82!E:W)A;G4N(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z
M,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T
M:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B4&]S;V1O8FQJ96YI('!O9&%T
M:VD@<V\@8FEL:2!I>F=U8FQJ96YI('!R:2!P<F5JQ:%N:F5M(&MO<F%K=2XB
M"@HC.B!F<F%M97=O<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R86UE=V]R
M:R]$871A+T1A=&$O='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO861E9"!F
M:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`B4&]S;V1O8FQJ96X@
M9&%T;W1E:V4@;F4@;6]R96T@<VAR86YI=&DN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C4T(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ,34*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A
M:6QA8FQE+B(*;7-G<W1R(")W96%T:&5R+F-O;2!N:2!N82!V;VQJ;RXB"@HC
M.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R
M(").92!N86ID96T@;6%P92!O8FQI:R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K
M+TED96YT:71Y+TED96YT:71Y+G!H<#HT-#0@9G)A;65W;W)K+TED96YT:71Y
M+TED96YT:71Y+G!H<#HT-#@*;7-G:60@(E1H97)E(&%R92!N;R!E;6%I;"!A
M9&1R97-S97,@=&\@8V]N9FER;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HQ-S@*;7-G:60@(E1H97)E(&%R92!N;R!O
M<'1I;VYS(&%V86EL86)L92XB"FUS9W-T<B`B3FD@;6_%OFYO<W1I(&YA(')A
M>G!O;&%G;RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HS-#0*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D
M:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R(")$96QI(&YE(&UO<F5J;R!B:71I
M('!R:6MA>F%N:2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#$T
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C
M:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@
M8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+B(*
M;7-G<W1R("(B"B)6('!O;&IU(&IE('!R979EQ(T@>FYA:V]V+B!6=&EP:V%L
M:2!S=&4@)7,@>FYA:V]V+B!6=&EP:V%T:2!M;W)A=&4@;6%N:B!K;W0@)2(*
M(G,@>FYA:V]V+B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z
M-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A
M9&1I;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@(E!R:<6A
M;&\@:F4@9&\@;F%P86ME('!R:2!D;V1A:F%N:G4@)R5S)R!K('-I<W1E;74Z
M("5S(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(Q"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E
M<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B4')IQ:%L;R!J
M92!D;R!N87!A:V4@<')I(&]D<W1R86YJ86YJ=2`G)7,G(&EZ('-I<W1E;6$N
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`R"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R;VT@=&AE
M('-Y<W1E;3H@(@IM<V=S='(@(E!R:<6A;&\@:F4@9&\@;F%P86ME('!R:2!O
M9'-T<F%N:F%N:G4@)R5S)R!I>B!S:7-T96UA+B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$U.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B
M;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B4')IQ:%L;R!J92!D
M;R!N87!A:V4@<')I('!O<V]D86)L:F%N:G4@)R5S)SH@)7,@(@H*(SH@9G)A
M;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3,R"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO
M860Z($YO("5S('=A<R!U<&QO861E9"XB"FUS9W-T<B`B4')I(&YA;&%G86YJ
M=2!D871O=&5K92!J92!P<FG%H6QO(&1O(&YA<&%K92X@3F]B961E;B`E<R!N
M:2!B:6P@;F%L;\6^96XN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E
M<BYP:'`Z.3,W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A
M('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R
M9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B>71E
M<RDN(@IM<V=S='(@(B(*(E!R:2!N86QA9V%N:G4@9&%T;W1E:V4@:F4@<')I
MQ:%L;R!D;R!N87!A:V4N("5S('IA<V5D82!V9<2-('!R;W-T;W)A+"!K;W0@
M:F4@(@HB9&]V;VQJ96YO+B!$;W9O;&IE;F\@:F4@*"5D(&)Y=&]V*2XB"@HC
M.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,SD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F
M:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E
M9"XB"FUS9W-T<B`B4')I(&YA;&%G86YJ=2!D871O=&5K92!J92!P<FG%H6QO
M(&1O(&YA<&%K92X@)7,@:F4@;&4@9&5L;F\@;F%L;\6^96YA+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P
M87)T(@IM<V=S='(@(E8@<W!O<F]E:6QU('-E(&IE('!O:F%V:6QA(&YE>FYA
M;F$@;F%P86MA+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HS.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@
M=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`B4')I('-P<F5J96UA;FIU(&MO
M;G1A:W1A(&IE('!R:<6A;&\@9&\@;F%P86ME+B(*"B,Z(&9R86UE=V]R:R]$
M871A+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(E!R:2!S
M<')E:F5M86YJ=2!K;VYT86MT82!J92!P<FG%H6QO(&1O(&YA<&%K92XB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C@R"FUS9VED("(B"B)4:&5R92!W
M87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P
M<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B
M(@HB2V]N9FEG=7)A8VEJ<VMI(&]B<F%Z96,@=G-E8G5J92!N87!A:V\N(%9E
M<FIE=&YO('-T92!P;WIA8FEL:2!N87-T879I=&D@(@HB>F%H=&5V86YO('!O
M;&IE+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,X"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@<&5R9F]R
M;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE
M87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB4')IQ:%L;R!J
M92!D;R!N87!A:V4@<')I('!R;V-E<VER86YJ=2!I>F)R86YE9V$@:6UE;FEK
M82X@4')O<VEM;R!P;W-K=7-I=&4@(@HB>FYO=F%N96MO;&EK;R!K87-N96IE
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T
M:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*
M;7-G<W1R("(B"B)0<FD@<W!R96IE;6%N:G4@:V]N=&%K=&$@:F4@<')IQ:%L
M;R!D;R!N87!A:V4N(%!R;W-I;6\@<&]S:W5S:71E('IN;W9A("(*(FMA<VYE
M:F4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HR,C(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T
M:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N
M(@IM<V=S='(@(B(*(E!R:2!S<')E:F5M86YJ=2!K;VYT86MT82!J92!P<FG%
MH6QO(&1O(&YA<&%K92X@4')O<VEM;R!P;W-K=7-I=&4@:V%S;F5J92XB"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*;7-G
M:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG
M(&9O;&1E<G,N(@IM<V=S='(@(E9AQ:$@8G)S:V%L;FEK(&YE('!O9'!I<F$@
M=&4@<&]T97IE+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@
M=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(E1O(&YI('9E;&IA=F5N(%)!
M4B!A<FAI=BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A
M;&ED('II<"!F:6QE+B(*;7-G<W1R(")4;R!N:2!V96QJ879N82!Z:7`@9&%T
M;W1E:V$N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S0Q-`IM<V=I
M9"`B5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB
M97(N(@IM<V=S='(@(L2"XH":Q:!T979I;&MA(&MA<G1I8V4@;FD@=F5L:F%V
M;F$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN
M9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O
M(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%0
M22(*;7-G<W1R(")';VYI;&YI:R!O;6]G;\2-92!P;\6A:6QJ86YJ92!S<&]R
M;\2-:6P@<')E:V\@;W!E<F%T97)J82!#;&EC:V%T96QL+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED("(B"B)4
M:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H
M('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y+"!U<VEN
M9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B1V]N:6QN:6L@;VUO9V_$C64@<&_%
MH6EL:F%N:F4@<W!O<F_$C6EL('!R96MO(&]P97)A=&5R:F$@5TE.+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U
M"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA
M:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B
M1V]N:6QN:6L@;VUO9V_$C64@<&_%H6EL:F%N:F4@<W!O<F_$C6EL('!R96MO
M(&]P97)A=&5R:F$@<VUS,F5M86EL+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U"FUS9VED("(B"B)4:&ES
M(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T
M:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O
M(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U
M;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I
M+B(*;7-G<W1R("(B"B)';VYI;&YI:R!O;6]G;\2-92!P;\6A:6QJ86YJ92!S
M<&]R;\2-:6P@<')E:V\@:71A;&IA;G-K96=A(&]P97)A=&5R:F$@5F]D;V%F
M;VYE+B(*(EIA('!OQ:%I;&IA;FIE(&UO<F5T92!I;65T:2!R96=I<W1R:7)A
M;FD@;F$@:'1T<#HO+W=W=RXQ.3`N:70B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HY.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V-@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DU(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Q,C0*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Y,2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8U"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$S,30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q,0HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-3<P(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(R-#8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(Y
M,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$W"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S-C8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0S
M-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3`Y(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(V.38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C<S."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(U"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,P.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S0P-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS-3@T(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C0P.3(*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z-#$P,`IM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T
M<B`B4&]T<F5B=6IE;2!T;R!P;VQJ92XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,#<T"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@:6YT96=E<G,N(@IM<V=S='(@(E1O('!O;&IE(&QA:&MO('9S96)U:F4@
M;&4@8V5L82#%H71E=FEL82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-S`T"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M
M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R(")4;R!P;VQJ92!L86AK;R!V
M<V5B=6IE(&QE(,6A=&5V:6QA(&EN('-T;VQP96,N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3$P,PIM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL
M>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B5&\@<&]L:F4@;&%H
M:V\@=G-E8G5J92!L92#%H71E=FEL82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,3,R"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM
M82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R
M(")0;VQJ92!M;W)A('9S96)O=F%T:2!S97IN86T@Q:%T979I;"P@;&_$C65N
M:6@@>B!V96II8V\@86QI('!R97-L961K;VTN(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.3DX"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V
M86QI9"!N=6UB97(N(@IM<V=S='(@(E1A('9R961N;W-T(&UO<F$@8FET:2#%
MH71E=FEL:V$N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P-@IM
M<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E
M(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T
M868G+B(*;7-G<W1R("(B"B)4;R!P;VQJ92!M;W)A('9S96)O=F%T:2!B87)V
M;F\@:V]D;R!V(%)'0B!(97@@9F]R;6%T=2P@;F$@<')I;65R("<C,3(S-&%F
M)RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU-S$*;7-G:60@(E1H
M:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B
M5&$@;V)L:6MA(&IE(&)I;&$@Q;YE(&]B9&5L86YA+B(*"B,Z('1E;7!L871E
M<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@
M:7,@)7,N(@IM<V=S='(@(E1O(&IE("5S+B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z-#8Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@
M:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J
M96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD
M97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI
M<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*
M;7-G<W1R("(B"B)4;R!J92!P;V1A=&5K('-K=7!I;G-K82!U<')A=FQJ86YJ
M92!+;VQA8BX@6F$@<')E9VQE9"!T96=A('!O9&%T:V$@(@HB<&]T<F5B=6IE
M=&5P<F5G;&5D;&]V86QN:6LL(&MI('!O9'!I<F$@;F'$C6EN('IA<&ES82!+
M;VQA8B!'<F]U<'=A<F4N(%IA("(*(G-E>FYA;2!O9&IE;6%L8V5V:VD@=&\@
M<&]D<&ER86IO(&]B:<6AQ(UI=&4@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HU.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI
M<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I
M(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(E-P;W)OQ(UI;&\@:F4@
M8FEL;R!N87!I<V%N;R!V(&MO9&YI('1A8F5L:2!D<G5G8<2-;F4@;V0@=F'%
MH64@*"5S*2XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R
M-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N(@IM
M<V=S='(@(E1O(,6A=&5V:6QO(&UO<F$@8FET:2!V<V%J(&5N82XB"@HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@
M(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I
M;&5S+B(*;7-G<W1R(")482!S=')EQ;YN:6L@;F4@;6]R92!O9'!R971I('II
M<"!I;B!G>FEP(&1A=&]T96LN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+U)E9VES=')Y+G!H<#HQ-SD*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E
M;G1L>2!D96%C=&EV871E9"XB"FUS9W-T<B`B4VES=&5M(&IE('1R96YU=&YO
M(&YE86MI=&EV96XN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS
M9W-T<B`B5&$@=G)E9&YO<W0@;6]R82!B:71I(,6A=&5V:6QK82XB"@HC.B!S
M97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4:&ES
M('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W
M(@IM<V=S='(@(E1O(&]K;F\@;6]R871E('!O9VYA=&D@>B!O:VYA($UOQ;YN
M;W-T:2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV-@IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R(")";&ES:R(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR-3`*;7-G:60@(E1I8VME=',B"FUS9W-T
M<B`B4')I:F%V92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W,3,@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")4:6UE(@IM
M<V=S='(@(L2-87,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`R
M"FUS9VED(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(E-L961N:F4@Q(UA<V$B
M"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C(*;7-G:60@(E1I;64@9F]R;6%T
M(@IM<V=S='(@(D]B;&EK82#$C6%S82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X,3D*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@(DEZ
M8FER82!E87-A+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HR,CD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I
M=&QE(@IM<V=S='(@(DYA<VQO=B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z-S$*;7-G:60@(E1O(@IM<V=S='(@(EIA(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U-@IM
M<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@
M=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL
M92!C;&EC:VEN9RXB"FUS9W-T<B`B(@HB9<2-(,6^96QI=&4@:7IB<F%T:2!V
M9<2-('!R961M971O=BP@<')I=&ES;FET92!#;VYT<F]L("A00RD@86QI($-O
M;6UA;F0@*$UA8RD@(@HB=&EP:V\L(&UE9'1E;2!K;R!N86YJ92!K;&EK871E
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#,*;7-G:60@
M(E1O9&%Y(@IM<V=S='(@(F1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1O
M9V\B"FUS9W-T<B`B5&]G;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O:V5L
M874B"FUS9W-T<B`B5&]K96QA=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS,#4*;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(DMO;6]R:2`B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G<W1R(")4;VYG82(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:V]L86(N<&AP.C$P-0IM<V=I9"`B
M5&]O(&UA;GD@:6YV86QI9"!L;V=I;G,@9'5R:6YG('1H92!L87-T(&UI;G5T
M97,N(@IM<V=S='(@(E!R979EQ(T@;F5U<W!E;&EH('!O=F5Z878@=B!Z861N
M:FEH(&UI;G5T86@N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8X"FUS
M9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`B3W)G86YI>F%C:6IA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,0IM<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G<W1R
M(")4<FEN:61A9"!I;B!4;V)A9V\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.#`S"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@(D1A(&%L
M:2!N92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-3D*;7-G:60@(E1U(@IM<V=S='(@(L2,92(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*
M;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B5'5N:7II:F$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T<B`B5'5R96EJ82(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY
M*2(*;7-G<W1R(")4=7+%H6MI("A)4T\M.#@U.2TY*2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3`*;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R(")4=7)K;65N:7-T86XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N
M9',B"FUS9W-T<B`B5'5RQ:%K:2!I;B!#86EC;W,@;W1O:VDB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B5'5V86QU(@H*(SH@9G)A
M;65W;W)K+T-,22]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC
M93H@(@IM<V=S='(@(E9T:7!K86IT92!V8<6A;R!I>F)I<F\Z("(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-C,*;7-G:60@(E4N5BX@:6YD
M97@Z("(*;7-G<W1R(")5+E8N(&EN9&5K<SHB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N
M<&AP.C$W"FUS9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E52
M3"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G
M<W1R(")54DP@=F'%H64@<VMR:7!T92!Z82!P;W)OQ(UA;FIE('-T871U<V$@
M9&]S=&%V92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5G86YD82(*;7-G<W1R
M(")59V%N9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")5:W)A:6YE(@IM<V=S
M='(@(E5K<F%J:6YA(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M-#4Q"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM
M<V=S='(@(DYI;6%M(&1O<W1O<&$@9&\@5D93(&EM96YI:V$N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS.38@9G)A;65W;W)K+U9&4R]61E,O
M<W-H,BYP:'`Z,S@Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C
M:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M(").92!M;W)E;2!S<')E;65N:71I('!R879I8V4@>F$@5D93(&1A=&]T96MO
M(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,C0@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0X,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F
M:6QE("5S+R5S+B(*;7-G<W1R(")$;W9O;&IE;FIA('IA(%9&4R`E<R\E<R!N
M92!M;W)E;2!S<')E;65N:71I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z-SDV(&9R86UE=V]R:R]61E,O5D93+W-S:#(N<&AP.C@Q,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G
M<W1R(").92!M;W)E;2!S<')E;65N:71I(&YA("5S+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,C,W(&9R86UE=V]R:R]61E,O5D93+W-S:#(N
M<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@
M9FEL92!S:7IE(&]F(%PB)7-<(BXB"FUS9W-T<B`B3F4@;6]R96T@<W!R96UE
M;FET:2!N82!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z-S,S(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3`W-0HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z.3`P"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB
M+B(*;7-G<W1R(").92!M;W)E;2!P<F5I;65N;W9A=&D@5D93(&1A=&]T96ME
M("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#8Q"FUS
M9VED(")5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`B3F4@
M;6]R96T@<V4@<&]V97IA=&D@<R!34TPN(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,C8T(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(V
M.0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C,V(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR-#$*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C(T.0IM<V=I9"`B56YA8FQE('1O(&-O<'D@
M5D93(&9I;&4N(@IM<V=S='(@(E9&4R!D871O=&5K92!N92!M;W)E;2!K;W!I
M<F%T:2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,W,R!F<F%M
M97=O<FLO5D93+U9&4R]S<V@R+G!H<#HS-C8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS
M9W-T<B`B3F4@;6]R96T@=7-T879R:71I(&EM96YI:V$@7"(E<UPB+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,Y,R!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,C<P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HR.38*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B5D93(&EM96YI:V$@;F4@;6]R96T@=7-T879R:71I
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0*;7-G:60@
M(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(E9&4R!D871O
M=&5K92!N92!M;W)E;2!U<W1V87)I=&DN(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HR.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-R96%T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B3F4@;7)O96T@
M=7-T=F%R:71I(&EM96YI:V$@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C,P-`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T
M>2!61E,@9FEL92XB"FUS9W-T<B`B5D93(&1A=&]T96ME(&YE(&UO<F5M('5S
M='9A<FET:2XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O=&%R
M+G!H<#HW-@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP
M:'`Z-SD*;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N(@IM<V=S
M='(@(E!O9&%T:V]V(&YE(&UO<F5M('-P<F]S=&ET:2XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C(Q.2!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C,P,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<V@R+G!H<#HR.38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H
M92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R(").92!M;W)E;2!I
M>F)R:7-A=&D@)7,L(&EM96YI:R!N:2!P<F%Z96XN(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HW-R!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0S"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS
M9W-T<B`B3F4@;6]R96T@:7IB<FES871I("<E<R<Z("5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C,W,"!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C0S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S(S
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R
M>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B3F4@;6]R96T@:7IB<FES871I("5S
M+"!I;65N:6L@;FD@<')A>F5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HT,#8@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C0Q,`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E
M8W5R<VEV96QY+B(*;7-G<W1R(").92!M;W)E;2!I>F)R:7-A=&D@:6UE;FEK
M82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-S8@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C,S-`HC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,S0W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS
M-34*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C0P,@IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").
M92!M;W)E;2!I>F)R:7-A=&D@:6UE;FEK82XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C0U-2!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0V
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D
M:7)E8W1O<GDZ("5S+B(*;7-G<W1R(").92!M;W)E;2!I>F)R:7-A=&D@5D93
M(&EM96YI:V$Z("5S("(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,C$R(&9R86UE=V]R:R]61E,O5D93+W-S:#(N<&AP.C(Q,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB
M"FUS9W-T<B`B3F4@;6]R96T@:7IB<FES871I(&1A=&]T96ME+EPB)7-<(BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-#(@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HS,30*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C$V-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P"B,Z
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C0T,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z-#0Y"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F
M:6QE+B(*;7-G<W1R(").92!M;W)E;2!I>F)R:7-A=&D@5D93(&1A=&]T96ME
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C,Y"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B!<(B5S
M7"(N(@IM<V=S='(@(DYE(&UO<F5M(&EZ8G)I<V%T:2!D871O=&5K92!<(B5S
M7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT-#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E
M;'DZ("5S+B(*;7-G<W1R(").92!M;W)E;2!I>F)R:7-A=&D@5D93.B`E<R`B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R-0IM<V=I9"`B56YA
M8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M3F4@;6]R96T@9&]L;\2-:71I('-E9&%N:F5G82!I;65N:6MA+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C`T"FUS9VED(")5;F%B
M;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM<V=S='(@(DYE
M(&UO<F5M(&EZ<&ES871I('!O=')J96YI:"!P;V1R;V)N;W-T:2XB"@HC.B!F
M<F%M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z-#,W(&9R86UE=V]R:R].971?
M24U34"])35-0+T%U=&@N<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B
M3F4@;6]R96T@<W!R96UE;FET:2!N82`E<RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HR,C,@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,C(X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ.3`@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$Y-0IM<V=I9"`B56YA8FQE
M('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(DYE(&UO<F5M('!R96UA:VYI
M=&D@5D93(&1A=&]T96ME+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z.3,@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ,#8*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HV-#$@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HY.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<V@R+G!H<#HY-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S
M7"(N(@IM<V=S='(@(DYE(&UO<F5M(&]D<')E=&D@9&%T;W1E:V5<(B5S7"(N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S$V(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S@*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$T,0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93
M(&9I;&4@9F]R('=R:71I;F<N(@IM<V=S='(@(DYE(&UO<F5M(&]D<')E=&D@
M5D93(&1A=&]T96ME(&YA;65N:F5N92!P:7-A;FIU+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C@Q(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C@V"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$T,"!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S8*;7-G:60@(E5N86)L92!T
M;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R(").92!M;W)E;2!O9'!R971I(%9&
M4R!D871O=&5K92XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C0U"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R
M8VAI=F4N(@IM<V=S='(@(DYE(&UO<F5M(&]D<')E=&D@>F=OQ:'$C65N96=A
M(&%R:&EV82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.3`X"FUS9VED
M(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I
M+B(*;7-G<W1R(").92!M;W)E;2!P<F5I;65N;W9A=&D@5D93(&1A=&]T96ME
M("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HY,SD*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ
M92@I(&9A:6QE9"DN(@IM<V=S='(@(DYE(&UO<F5M('!R96EM96YO=F%T:2!6
M1E,@9&%T;W1E:V4@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD
M;&5R+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"FUS9VED(")5;F%B;&4@
M=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`B3F4@;6]R96T@<')E:6UE;F]V871I
M(%9&4R!D871O=&5K92XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HW,30*;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B3F4@;6]R96T@<')E8G)A=&D@5D93(&]S;F]V;F5G
M82!I;65N:6MA+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$P
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O
M("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T
M<B`B3F4@;6]R96T@<')E:6UE;F]V871I("5S('8@)7,Z(&UA<&$@Q;YE(&]S
M=&%J82(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#4*
M;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B3F4@;6]R96T@<')E:6UE;F]V871I(%9&4R!I;65N:6MA+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S
M='(@(DYE(&UO<F5M('!R96EM96YO=F%T:2!61E,@:6UE;FEK83H@)7,N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-C4@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HS-3$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W-H,BYP
M:'`Z,S0T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").92!M;W)E;2!P<F5I;65N;W9A
M=&D@5D93(&1A=&]T96ME(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HV-34@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(T
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE("5S+R5S+B(*;7-G<W1R(").92!M;W)E;2!P<F5I;65N;W9A=&D@5D93
M(&1A=&]T96ME("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z,S8Q(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,3,*(SH@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0V-"!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,S,W"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HS-3D*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N
M(@IM<V=S='(@(DYE(&UO<F5M('!R96EM96YO=F%T:2!61E,@9&%T;W1E:V4N
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O
M9G,N<&AP.C4P"FUS9VED(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS
M9W-T<B`B3F4@;6]R96T@<W!R96UE;FET:2!N82`E<RXB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B
M;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R(").
M92!M;W)E;2!P<F5V97-T:2!T96=A(%=O<F1O=F5G82!D;VMU;65N=&$N(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ.#,Y"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!T<FEG9V5R(&9R964O8G5S>2!U<&1A=&4@
M9F]R("5S(@IM<V=S='(@(DYE(&UO<F5M('-P<F_%OFET:2!P<F]S=&\O>F%S
M961E;F\@<&]S;V1O8FET92!Z82`E<R(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z,34T(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,34W"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-S:#(N<&AP.C$T.2!F<F%M97=O<FLO5D93
M+U9&4R]S<V@R+G!H<#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3F4@;6]R96T@
M;F%P:7-A=&D@5D93(&1A=&]T96ME(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HQ.#D*;7-G:60@(E5N86)L92!T;R!W<FET92!6
M1E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(DYE(&UO<F5M(&YA
M<&ES871I(%9&4R!P;V1A=&MO=FYI:"!D871O=&5K+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C,R,"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,30V"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ-3$*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+B(*
M;7-G<W1R(").92!M;W)E;2!N87!I<V%T:2!61E,@<&]D871K;W9N:6@@9&%T
M;W1E:RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.3$T"FUS9VED(")5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D
M960N(@IM<V=S='(@(DYE(&UO<F5M(&YA<&ES871I(%9&4R!D871O=&5K92P@
M:W9O=&$@8F\@<')E<V7%OF5N82XB"@HC.B!T96UP;&%T97,O<')E9G,O96YD
M+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B4F%Z=F5L:F%V
M:2!S<')E;65M8F4B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HR,C$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S@X"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R
M=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R(").97!R:<2-86MO=F%N(&]D
M9V]V;W(@<R!S=')EQ;YN:6MA('8@<&]V97IO=F%N:G4Z(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$W"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,S.0HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S8*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@R"FUS9VED(")5;F5X<&5C=&5D
M(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B3F5P<FG$C6%K
M;W9A;B!N97!R:<2-86MO=F%N(&]D9V]V;W(@<W1R9<6^;FEK82!Z83HB"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU
M-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV
M,0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R(").96EZ<&]L;FIE;F\B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B56YI8V]D92`H551&+3@I
M(@IM<V=S='(@(E5N:6MO9"`H551&+3@I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@
M(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(EID<G7%OF5N:2!A<F%B
M<VMI(&5M:7)A=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(E5N:71E9"!+:6YG
M9&]M(@IM<V=S='(@(EID<G7%OF5N;R!K<F%L:F5S='9O(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R("):9')UQ;YE;F4@
M9'+%OF%V92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,@
M36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R("):9')UQ;YE;F4@9'+%
MOF%V92!/=&]K:2!-:6YO<B!/=71L>6EN9R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HV-R!L:6(O0FQO8VLO;65T87(N<&AP.C@S"FUS9VED
M(")5;FET<R(*;7-G<W1R(")%;F]T92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0R.2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,S`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HU
M.`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R(").97!O>FYA;F\B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G
M:60@(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"FUS9W-T
M<B`B3F5P;WIN86YA(&%P:6US9VED("A)1"!!4$D@<W!O<F_$C6EL82DN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDY"FUS9VED(")5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)
M1"DN(@IM<V=S='(@(DYE<&]Z;F%N82!C;&EM<V=I9"`H240@=7!O<F%B;FG%
MH6ME9V$@<W!O<F_$C6EL82DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,34R"FUS9VED(")5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*
M;7-G<W1R(")-97-T;R!N:2!N87-T879L:F5N;RXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*;7-G:60@(E5N
M:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S='(@(DYE>FYA;F\@
M=7!O<F%B;FG%H6MO(&EM92!A;&D@9V5S;&\N(@H*(SH@9G)A;65W;W)K+TED
M96YT:71Y+TED96YT:71Y+G!H<#HS,3D*;7-G:60@(E5N;F%M960B"FUS9W-T
M<B`B0G)E>B!I;65N82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C@W(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3(W
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3,S"FUS9VED
M(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`B3F5P;V1P<G1A(')A
M>L6A:7)I=&5V(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ
M.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P
M9&%T92(*;7-G<W1R(")0;W-O9&]B:2(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E
M("5S(@IM<V=S='(@(E!O<V]D;V)I("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHW-PIM<V=I9"`B57!D871E('5S97(B"FUS9W-T
M<B`B4&]S;V1O8FQJ96X@=7!O<F%B;FEK(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HQ-#,@861M:6XO<&5R;7,O961I="YP:'`Z,3`Q('-E<G9I8V5S+W-H87)E
M<R]E9&ET+G!H<#HR,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"!<
M(B5S7"(N(@IM<V=S='(@(E!O<V]D;V)L:F5N("<E<R<N(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z.#D*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E
M;&5T960N(@IM<V=S='(@(DEZ8G)I<V%N82!S:W)I<'1A('IA(&YA9&=R861N
M:F\N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-R!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DX"FUS9VED(")5<&QO860B
M"FUS9W-T<B`B3F%L86=A;2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M.#4*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE
M<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R(").86QOQ;YI(&YA('-T<F7%OFYI
M:R!V<V4@;F%M97-T:71V96YE(&1A=&]T96ME(&%P;&EK86-I:BXB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$S"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(E5R=6=V86HB"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T
M<B`B57!O<F%B:2!S961A;FII.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM
M<V=S='(@(E5P;W)A8FD@4U-,(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$R-PIM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT
M(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B57!O<F%B:2P@Q(UE(&IE('5P
M;W)A8FYIQ:%K;R!I;64O9V5S;&\@9')U9V'$C6YO(&]D($E-4U`@<W1R9<6^
M;FEK82(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$*
M;7-G:60@(E5S97(B"FUS9W-T<B`B57!O<F%B;FEK(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HW-C0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S
M='(@(E5P;W)A8FYI:R`E<R!N:6UA(&1O<W1O<&$@9&\@)7,B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HR,#(*;7-G:60@(E5S97(@061M:6YI<W1R871I;VXB"FUS
M9W-T<B`B57!R879A('IA('5P;W)A8FYI:V4B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C(T-0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S
M='(@(E5P;W)A8FYIQ:%K92!N87-T879I='9E(@H*(SH@<VEG;G5P+G!H<#HV
M,@IM<V=I9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T<B`B4F5G:7-T<F%C
M:6IA('5P;W)A8FYI:V$B"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5<V5R
M(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E
M+B(*;7-G<W1R(")296=I<W1R:7)A;FIE('5P;W)A8FYI:V]V(&IE(&YA('1E
M:B!S=')A;FD@;VYE;6]G;\2-96YO+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HT.30*;7-G:60@(E5S97(@86-C;W5N="!N;W0@9F]U;F0B"FUS9W-T
M<B`B3F4@;F%J9&5M('5P;W)A8FYI:V]V(')AQ(UU;BXB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS-"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.CDX
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U
M,"!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,PHC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C8T('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O
M=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G<W1R(")5<&]R86)N:<6A
M:V\@:6UE(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C$R
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@86QR96%D
M>2!E>&ES=',N(@IM<V=S='(@(E5P;W)A8FYIQ:%K;R!I;64@7"(E<UPB(&IE
M(,6^92!V('5P;W)A8FDN(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C@W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B57!O<F%B;FG%H6MO
M(&EM93H@(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`IM<V=I
M9"`B57-E<FYA;64Z("(*;7-G<W1R(")5<&]R86)N:<6A:V\@:6UE.B`B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5<V5R
M<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R(")5<&]R86)N:6MI+"!K:2!S;R!V
M('-I<W1E;74Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B57IB96MI<W1A;B(*
M;7-G<W1R(")5>F)E:VES=&%N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,3<S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(Y-`IM<V=I
M9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B5D93
M(&EM96YI:R!N92!O8G-T86IA+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ,C<*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(D]D<V]T;F]S="(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@W-0IM<V=I9"`B5F%L:60@
M;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R(").86ID96YA('9E
M;&IA=FYA(&QO:V%C:6IA('IA:F5M83HB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B
M5F5L:F%V;F]S="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3DW"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(U-0IM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F
M<F]M(&YO=RXB"FUS9W-T<B`B5G)E9&YO<W0@=B!M:6YU=&%H(&]D('-E9&%J
M(&1A;&IE+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@V-2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@V"B,L('!H<"UF;W)M870*;7-G:60@
M(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G
M<W1R(")6<F5D;F]S="!P<F5S96=A(&UA:W-I;6%L;F\@9&]LQ;YI;F\@)7,N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4S,B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-34T"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(V,#0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Y.`HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED(")686QU
M97,B"FUS9W-T<B`B5G)E9&YO<W1I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C,Y-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#<T"FUS9VED
M(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B5G)E9&YO<W1I(&]D
M(&MO9&5R(&EZ8FER871I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T
M=2(*;7-G<W1R(")686YU871U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(S.`IM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B5F%R:6%B:6QN
M;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R(")6
M96YE>G5E;&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G
M92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(E!R979E
M<FIA;FIE(&YE=7-P9<6A;F\@+2!M;V=OQ(UE(&IE(&)I;&\@<W!O<F_$C6EL
M;R!S<')E;65N:F5N;RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C<P,0IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R(")287IL:<2-:6-A
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T,@IM<V=I9"`B5F5R
M<VEO;B!#;VYT<F]L(@IM<V=S='(@(E)A>FQIQ(UI8V$B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,@IM<V=I9"`B5F5R>2!(
M:6=H(@IM<V=S='(@(EIE;&\@=FES;VMO(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I
M9"`B5FEE="!.86TB"FUS9W-T<B`B5FEE=&YA;2(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DW"FUS9VED(")6:65T;F%M97-E("A625-#24DI(@IM<V=S
M='(@(E9I971N86US:VD@*%9)4T-)22DB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HY-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE
M=R`E<R(*;7-G<W1R(")0;V=L96H@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HX,C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E9I97<@)7,@6R5S72(*;7-G<W1R(")0;V=L96H@:V]T("5S(@H*(SH@
M;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA
M;"!W96(@<&%G92(*;7-G<W1R(")0;V=L960@;F$@>G5N86YJ;R!S<&QE=&YO
M('-T<F%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L
M($)R:71I<V@B"FUS9W-T<B`B1&5V:<6A:VD@;W1O:VD@*&)R:71A;G-K:2DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@52Y3+B(*
M;7-G<W1R(")$979IQ:%K:2!O=&]K:2`H6D1!*2(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C(Q"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S='(@(E9I9&QJ
M:79O<W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4W"FUS
M9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B5FED;&II=F]S=#HB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX
M-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B5F]D
M869O;B!)=&%L:6IA('!R96MO(%--5%`B"@HC.B!F<F%M97=O<FLO3F]T:69I
M8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS
M9VED(")705).(@IM<V=S='(@(D]03UI/4DE,3R(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.CDQ"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A
M(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R(")/
M4$]:3U))3$\A(2$@4D_$C4Y/($]$4U1204Y)32!32U))4%1/($E:("5S+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS
M9VED(")724X@=FEA($A45%`B"FUS9W-T<B`B5TE.('!R96MO($A45%`B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$W"FUS9VED(")786QL:7,@86YD($9U='5N82(*;7-G<W1R
M(")786QL:7,@:6X@1G5T=6YA(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,C<@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.CDU"FUS9VED(")787)N:6YG(@IM<V=S='(@(D]P;WIO
M<FEL;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C`*;7-G:60@(E=E(@IM<V=S='(@(DUI(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,T"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM
M<V=S='(@(E9R96UE;G-K82!N87!O=F5D(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C0Q.0IM<V=I9"`B5V5A=&AE<B!D871A('!R;W9I9&5D
M(&)Y(@IM<V=S='(@(E9R96UE;G-K:2!P;V1A=&MI(',@<W!L971A(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3`Q"FUS9VED(")796%T:&5R+F-O
M;2(*;7-G<W1R(")W96%T:&5R+F-O;2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N
M<&AP.C,V"FUS9VED(")796(B"FUS9W-T<B`B4W!L970B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#8P"FUS9VED(")796(@4VET92(*;7-G<W1R
M(")3<&QE=&YA('-T<F%N(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA
M:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM<V=S='(@(E1E9&5N
M<VMO(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*;7-G:60@
M(E=E;&-O;64B"FUS9W-T<B`B1&]B<F]D;\6A;&DB"@HC.B!T96UP;&%T97,O
M;&]G:6XO;6]B:6QE+FEN8SHT('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R
M(")$;V)R;V1OQ:%L:2!N82!S<&QE=&YI:"!S=')A;F5H('!R;V=R86UA("5S
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B1&]B<F]D;\6A;&DL
M("5S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3@*;7-G:60@(E=E<W1E
M<FX@*$E33RTX.#4Y+3$I(@IM<V=S='(@(EIA:&]D;FD@*$E33RTX.#4Y+3$I
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3D*;7-G:60@(E=E<W1E<FX@
M*$E33RTX.#4Y+3$U*2(*;7-G<W1R("):86AO9&YI("A)4T\M.#@U.2TQ-2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R("):
M86AO9&YA(%-A:&%R82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@
M)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B2V%T97)O(&%P;&EK
M86-I:F\@;F%J('!R:6MAQ;YE("5S+"!P;R!P<FEJ879I/R(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T(&ES('1H92!D
M96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R(")+86O%H65N(&IE(&QOQ(UI
M;&YI('IN86L_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*
M;7-G:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`B
M2V%KQ:%E;B!J92!N879E9&5N:2!Z;F%K/R(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HQ,#8U"FUS9VED(")7:&5R96ES($%U
M<W1R86QI82!M87`B"FUS9W-T<B`B6F5M;&IE=FED("!7:&5R96ES($%U<W1R
M86QI82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@
M<&AA<V5S(@IM<V=S='(@(E)A>G9O:FYA('-T;W!N:F$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3,V"FUS9VED(")7:&EC:"!P;'5G:6YS('1O(&5N
M86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@(DMA=&5R
M92!D;V1A=&ME(&YA:B!O;6]G;\2-:6T@<')I('5R96IA;FIU(&)E<V5D:6PN
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Y-`IM<V=I9"`B5VED
M=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(L6@:7)I;F$@=B!E;F]T86@@0U-3
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K
M97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`BQ:!I<FEN82`E
M<R!M96YI:F$@;F$@;&5V:2`H;V1R87II;&$@<V4@8F\@;V(@;F%S;&5D;FII
M('!R:6IA=FDI.B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,S<*
M;7-G:60@(E=I:VDB"FUS9W-T<B`B5VEK:2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR.3,@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-C<*;7-G:60@(E=I;F0B"FUS9W-T<B`B5F5T97(Z("(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED
M(")7:6YD($5A<FQY(@IM<V=S='(@(DIU=')A;FII('9E=&5R.B`B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.CDR"FUS9VED(")7:6YD('-P965D(&EN(&MN
M;W1S(@IM<V=S='(@(DAI=')O<W0@=F5T<F$@=B!V;WIL:6@B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$V.`IM<V=I9"`B5VEN9#HB"FUS9W-T<B`B5F5T
M97(Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-@IM<V=I
M9"`B5VEN9#H@(@IM<V=S='(@(E9E=&5R.B`B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-CD*;7-G:60@(E=I<V1O;2(*;7-G<W1R(")-;V1R;W-T(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Q,@IM<V=I9"`B5VES:&QI
M<W0B"FUS9W-T<B`B3&ES=&$@Q;YE;&IA(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C<P"FUS9VED(")7;W)K(@IM<V=S='(@(E-L=<6^8F$B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*;7-G:60@
M(E=O<FL@061D<F5S<R(*;7-G<W1R(")3;'7%OF)E;FD@;F%S;&]V(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I
M9"`B5V]R:R!0:&]N92(*;7-G<W1R(")3;'7%OF)E;FD@=&5L969O;B(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$Y,R!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HR.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@
M;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U
M;F0@)60N(@IM<V=S='(@(DYA<&'$C6YO(,6A=&5V:6QO('!O;&H@=B`E9"!V
M<G-T:2X@4')IQ(UA:V]V86YI:"`E9"P@;F%J9&5N:6@@)60N(@H*(SH@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S,R"B,L('!H<"UF;W)M870*;7-G
M:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N
M9"`E9"XB"FUS9W-T<B`B3F%P8<2-;F\@Q:%T979I;&\@<&]L:BX@4')IQ(UA
M:V]V86YI:"`E9"P@;F%J9&5N:6@@)60N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&]F
M9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@(DYA
M<&'$C65N(&]D;6EK("5D(&UE9"!B<F%N:F5M(&1A=&]T96ME(%9&4RXB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4Y"FUS9VED(")8+5)E9B(*
M;7-G<W1R(")8+5)E9B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS
M9W-T<B`B6#4P.78S(&]S;F]V;F$@;VUE:FET978B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S($5X=&5N
M9&5D($ME>2!5<V%G92(*;7-G<W1R(")8-3`Y=C,@4F%ZQ:%I<FIE;F$@=7!O
M<F%B82!K;&IUQ(UA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA
M;64B"FUS9W-T<B`B6#4P.78S(%IA9&5V82!A;'1E<FYA=&EV;F\@:6UE(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G:60@
M(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(E@U,#EV
M,R!+:G5E('IA(&1O;&]E:71I('IA9&5V;R(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C@S"FUS9VED(")8-3`Y=C,@97AT96YS:6]N
M<R(*;7-G<W1R(")8-3`Y=C,@<F%ZQ:%I<FET978B"@HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T<B`B3$PB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$X"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-C`*;7-G:60@(EE965DB
M"FUS9W-T<B`B3$Q,3"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,3$Q"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@(EEA
M:&]O(2!Z96UL:F5V:60B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I
M;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T<B`B3&5T;F\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$W"FUS9VED(")996UE;B(*;7-G<W1R(")*96UE;B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C8*
M;7-G:60@(EEE<R(*;7-G<W1R(")$82XB"@HC.B!T96UP;&%T97,O;6%I;G1E
M;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E
M(@IM<V=S='(@(D1A+"!S92!S=')I;FIA;2XB"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C(S-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H
M86X@)60@8FQO8VMS+B(*;7-G<W1R(").:6UA=&4@9&]V;VQJ96YJ82!U<W1V
M87)I=&D@=F7$C2!K;W0@)60@8FQO:V]V+B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,3,Y-0IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC
M871E9"XB"FUS9W-T<B`B3FES=&4@<')I:F%V;&IE;FDB"@HC.B!F<F%M97=O
M<FLO261E;G1I='DO261E;G1I='DN<&AP.C,R-0IM<V=I9"`B66]U(&-A;FYO
M="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB
M"FUS9W-T<B`B5B!I;65N=2!N92!M;W)E=&4@:6UE=&D@>FYA:V]V("=<7"<B
M"@HC.B!F<F%M97=O<FLO4E!#+U)00R]P:'!G=RYP:'`Z,3$W"B,L(&9U>GIY
M"FUS9VED(")9;W4@9&ED(&YO="!A=71H96YT:6-A=&4N(@IM<V=S='(@(DYI
M<W1E('!R:6IA=FQJ96YI(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C(V,PIM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A
M9&1R97-S+B(*;7-G<W1R(").:7-T92!V<W1A=FEL:2!V96QJ879N96=A(&5L
M96MT<F]N<VME9V$@;F%S;&]V82XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A
M+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M
M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C
M;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B(@HB365D
M('-P<F5J971I;6D@9&%T;W1E:V%M:2!N:7-T92!O>FYAQ(UI;&D@;F]B96YE
M9V$@<&]L:F$L(&MI('-E('5J96UA(',@<&]L:FD@(@HB=B5S+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX-PIM<V=I9"`B66]U(&AA=F4@8F5E
M;B!L;V=G960@;W5T+B(*;7-G<W1R(")":6QI('-T92!O9&IA=FQJ96YI+B(*
M"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,SDS"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(EEO=2!H879E(')E<75E<W1E9"!T;R!A9&0@
M=&AE(&5M86EL(&%D9')E<W,@7"(E<UPB('1O('1H92!L:7-T(&]F('EO=7(@
M(@HB<&5R<V]N86P@96UA:6P@861D<F5S<V5S+EQN(@HB7&XB"B)';R!T;R!T
M:&4@9F]L;&]W:6YG(&QI;FL@=&\@8V]N9FER;2!T:&%T('1H:7,@:7,@<F5A
M;&QY('EO=7(@861D<F5S<SI<;B(*(B5S7&XB"B)<;B(*(DEF('EO=2!D;VXG
M="!K;F]W('=H870@=&AI<R!M97-S86=E(&UE86YS+"!Y;W4@8V%N(&1E;&5T
M92!I="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3(W,`IM<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL
M<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K
M)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N(@IM
M<V=S='(@(B(*(E9N97-T:2!M;W)A=&4@=F5L:F%V;F\@9W-M(,6A=&5V:6QK
M;RY$=F]L:F5N:2!Z;F%K:2!S;R!L92#%H71E=FEL:V4@:6X@)RLG(&MO="`B
M"B)P<F5D<&]N82!M961N87)O9&YI;2#%H71E:79L:V%M+B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.3<*;7-G:60@(EEO=2!H879E('1O(&5N
M=&5R(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(E9S=&%V:71I(&UO<F%T92!V
M96QJ879N;R!V<F5D;F]S="XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I
M9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4
M<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(D]B;&EK;W9A
M=&D@;6]R871E(%-I9VYU<"!B86-K96YD+"#%H65L92!N871O('-E(&QA:&MO
M('!R:6IA=FQJ871E+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M-#8W"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB
M"FUS9W-T<B`B3V)L:6MO=F%T:2!M;W)A=&4@5D93(&)A8VME;F0N(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M
M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@
M=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R(").86IP<F5J(&]P:<6A:71E
M('1EQ;YA=F4L(,6A96QE(&YA=&\@;&%H:V\@<&_%H6QJ971E('!O<F_$C6EL
M;R!O('1EQ;YA=F%H+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M.#@*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T(&5N=&5R(&%N(&5M86EL(&%D
M9')E<W,N(@IM<V=S='(@(DYI<W1E('9S=&%V:6QI('9E;&IA=FYE9V$@96QE
M:W1R;VYS:V5G82!N87-L;W9A+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$X.#8*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T(&5N=&5R(&%T(&QE
M87-T(&]N92!E;6%I;"!A9&1R97-S+B(*;7-G<W1R(").:7-T92!V<W1A=FEL
M:2!V96QJ879N96=A(&5L96MT<F]N<VME9V$@;F%S;&]V82XB"@HC.B!S97)V
M:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`IM<V=I9"`B66]U(&UU<W0@<V5L
M96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R("))>F)R871I
M(&UO<F%T92!S=')EQ;YN:6LL(&MI(&)O(&EZ8G)I<V%N+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$Q.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N
M86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`B3F%T86[$C6YE:F4@;F%V961I
M=&4@=7!O<F%B;FG%H6MO(&EM92P@:VD@9V$@Q;YE;&ET92!I>F)R:6%T:2XB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HY.0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF
M>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B3F%T86[$C6YE:F4@
M;F%V961I=&4@=7!O<F%B;FG%H6MO(&EM92P@:VD@9V$@Q;YE;&ET92!O9'-T
M<F%N:71I+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8Q('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T
M:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R(").871A;L2-;F5J92!N879E
M9&ET92!U<&]R86)N:<6A:V\@:6UE+"!K:2!G82#%OF5L:71E(&1O9&%T:2XB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#4*;7-G:60@(EEO=2!M=7-T('-P96-I
M9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`B3F%T86[$C6YE
M:F4@;F%V961I=&4@=7!O<F%B;FG%H6MO(&EM92P@:VD@9V$@Q;YE;&ET92!P
M;W-O9&]B:71I+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z
M:7`N<&AP.C$S.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO
M;B!T;R!P97)F;W)M+B(*;7-G<W1R(").871A;L2-;F5J92!N879E9&ET92!K
M86H@Q;YE;&ET92!N87)E9&ET:2XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0IM<V=I9"`B66]U(&UU<W0@='EP
M92!A(&YE=R!C871E9V]R>2!N86UE+B(*;7-G<W1R(")6=&EP:V%J=&4@:6UE
M(&YO=F4@:V%T96=O<FEJ92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B66]U(&YE960@=&\@
M<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*;7-G<W1R(")6;F5S
M=&D@;6]R871E(&ET86QI:F%N<VMO('1E;&5F;VYS:V\@Q:%T979I;&MO(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<U"B,L('!H<"UF;W)M870*
M;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO
M9VEN(&%G86EN+B(*;7-G<W1R("(B"B)68<6A82!P<FEJ879I='9E;F$@<V5J
M82`E<R!J92!P;W1E:VQA+B!0<F]S:6UO+"!D82!S92!P;VYO=FYO('!R:6IA
M=FET92XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS-`IM
M<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(E9AQ:$@96QE:W1R
M;VYS:VD@;F%S;&]V.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,34*
M;7-G:60@(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`B5F'%H2!N87-L
M;W8Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HW-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDR"FUS9VED(")9;W5R($EN9F]R;6%T:6]N
M(@IM<V=S='(@(E9AQ:%I('!O9&%T:VDB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HY-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E
M<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@
M;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I
M='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B)/9"!Z8<2-
M971K82`E<R!S96IE+"!S92!J92!V8<6A('-P;&5T;FD@;F%S;&]V('-P<F5M
M96YI;"X@27H@(@HB=F%R;F]S=&YI:')A>FQO9V]V+"!S92!M;W)A=&4@<&]N
M;W9N;R!P<FEJ879I=&DN(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z,S`*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R(")68<6A92!I;64Z
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C4*;7-G:60@
M(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P
M;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@(@HB=7-E($AO<F1E
M('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@
M9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N(&)A8VME;F0N(@IM<V=S='(@
M(B(*(E9AQ:%E(&]Z861J92!Z82!O=F5R:F5N92!N92!P;V1P:7)A(&1O9&%J
M86YJ82!U<&]R86)N:6MO=BX@Q(UE(,6^96QI=&4@(@HB=7!O<F%B:71I2&]R
M9&4@>F$@861M:6YI<W1R:7)A;FIE('5P;W)A8FYIQ:%K:6@@<F'$C75N;W8L
M(&UO<F%T92!U<&]R86)I=&D@(@HB9')U9V\@;WIA9&IE('IA;W9E<FIA;FIE
M+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM<V=I
M9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U
M<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E
M96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B
M"B)68<6A92!O>F%D:F4@>F$@;W9E<FIA;FIE(&YE('!O9'!I<F$@;F%V86IA
M;FIA('5P;W)A8FYI:V]V(&%L:2!P82!J92!B:6QA("(*(FUOQ;YN;W-T(&]N
M96UO9V_$C65N82!I>B!D<G5G:6@@<F%Z;&]G;W8N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z.3@S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO
M=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@
M8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y
M;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B
M(@HB2V'%OF4L(&1A('-E(&IE(&]D('IAQ(UE=&MA("4@<V5J92P@=F'%H2!B
M<G-K86QN:6L@<W!R96UE;FEL+B!)>G9A<FYO<W1N:6@@(@HB<F%Z;&]G;W8L
M('-E(&UO<F%T92!P;VYO=FYO('!R:6IA=FET:2XB"@HC.B!L:6(O0FQO8VLO
M:69R86UE+G!H<#HU,`IM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U
M<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R(")68<6A(&)R<VMA;&YI:R!N
M92!P;V1P:7)A('1E(&9U;FMC:6IE+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+W!R:6YT+FIS.C0R"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N
M;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#
M;VUM86YD("L@4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B(@HB5F'%H2!B<G-K
M86QN:6L@;F4@<&]D<&ER82!D;VQOQ(UE;FEH(&UOQ;YN;W-T:2!P<FD@<')I
M;G1A;FIU+B!:82!P<FEN=&%N:F4@(@HB<')I=&ES;FET92!#;VYT<F]L+TUO
MQ;YN;W-T:2`K(%`N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V,0IM
M<V=I9"`B66]U<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`B5F'%H2!T
M<F5N=71N:2#$C6%S;W9N:2!P87,Z(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP
M.C$S,`IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H
M86YG960N(@IM<V=S='(@(E9AQ:%A('!R:79Z971A(&ED96YT:71E=&$@:F4@
M8FEL82!S<')E;65N:F5N82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,38Q"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@(E!R
M:79Z971A(&ED96YT:71E=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C`T"FUS9VED(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`B5F'%H64@:6UE
M.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY.0IM<V=I9"`B66]U
M<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T<B`B5F'%H6$@<')I:F%V82!J
M92!P;W1E:VQA+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V
M"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E
M<R!I<SH@)7,B"FUS9W-T<B`B5F'%H64@;F]V92!G97-L;R!Z82`E<R!J93H@
M)7,B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-`IM<V=I
M9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R
M871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R(")68<6A92!N87-T879I
M='9E('-O(&)I;&4@<&]S;V1O8FQJ96YE('IA(,2-87,@=&4@<V5J92XB"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U
M<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R(")68<6A92!N
M87-T879I='9E('-O(&)I;&4@<&]S;V1O8FQJ96YE+B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A<W-W;W)D(&AA
M<R!B965N(')E<V5T(@IM<V=S='(@(E9AQ:%E(&=E<VQO(&IE(&)I;&\@<&]N
M87-T879L:F5N;RXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW
M.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE
M8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S
M<W=O<F0N(@IM<V=S='(@(B(*(E9AQ:%E(&=E<VQO(&IE(&)I;&\@<&]N87-T
M879L:F5N;RX@3F$@=F'%H2!E+6YA<VQO=B!S;6\@=F%M('!O<VQA;&D@;F]V
M;V=E<VQO("(*(G,@:V%T97)I;2!S92!P<FEJ879I=&4N(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z-S,S"FUS9VED(")9;W5R('!A<W-W;W)D(&AA
M<R!E>'!I<F5D+B(*;7-G<W1R(")68<6A92!G97-L;R!J92!P;W1E:VQO+B(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B66]U
M<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`B5F'%H6D@<&]S<F5D;FD@<W1R
M9<6^;FEK:3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-"!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA
M=FEA(@IM<V=S='(@(DIU9V]S;&%V:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B6F%I<B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R("):86UB:6IA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T<B`B6FEM
M8F%B=F4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-S$*;7-G:60@(EII
M<'!Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT
M97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S0*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E9"!4
M97AT72(*;7-G<W1R(");4VMR:6H@8VET:7)A;F\@8F5S961I;&]=(@H*(SH@
M<V5R=FEC97,O<')O8FQE;2YP:'`Z.#@*;7-G:60@(EM0<F]B;&5M(%)E<&]R
M=%TB"FUS9W-T<B`B6W!O<F_$C6EL;R!O(&YA<&%K:5TB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@
M475O=&5D(%1E>'0@+2(*;7-G<W1R(");4&]K8<6^:2!C:71I<F%N;R!B97-E
M9&EL;R`M(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H
M;&EG:'1Q=6]T97,N<&AP.C$W-`HC+"!P:'`M9F]R;6%T"FUS9VED(");4VAO
M=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R(");4&]K8<6^:2!C
M:71I<F%N;R!B97-E9&EL;R`M("5S('9R<W1I8UTB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C(P-`HC+"!P:'`M9F]R;6%T"FUS9VED(");;&EN
M92`E<R!O9B`E<UTB"FUS9W-T<B`B6R5S('9R<W1I8V$@;V0@)7-=(@H*(SH@
M;&EB+V%P:2YP:'`Z,34W"FUS9VED(")?0TQ)(@IM<V=S='(@(E]#3$DB"@HC
M.B!L:6(O87!I+G!H<#HQ-#$*;7-G:60@(E]$871A5')E92(*;7-G<W1R(")$
M<F5V97-N82`B"@HC.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@(E]'<F]U<',B
M"FUS9W-T<B`B7U-K=7!I;F4B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M365N=2YP:'`Z,3<U"FUS9VED(")?2&5L<"(*;7-G<W1R(")0;VUOQ(TB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DT"FUS9VED(")?
M3&]G(&EN(@IM<V=S='(@(E!R:6IA=F$B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O365N=2YP:'`Z,3DP"FUS9VED(")?3&]G(&]U="(*;7-G<W1R(")/
M9&IA=F$B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38T
M"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R(")-;\6^;F]S=&DB"@HC.B!L:6(O
M87!I+G!H<#HQ,S<*;7-G:60@(E]097)M:7-S:6]N<R(*;7-G<W1R(")$;W9O
M;&IE;FIA(@H*(SH@;&EB+V%P:2YP:'`Z,3(U"FUS9VED(")?4V5T=7`B"FUS
M9W-T<B`B7TYA;65S=&DB"@HC.B!L:6(O87!I+G!H<#HQ,CD*;7-G:60@(E]5
M<V5R<R(*;7-G<W1R(")?57!O<F%B;FEK:2(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z.3(U"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`B
M26UE;FEK(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M,S0*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(DYA<VQO=FYI
M:R!N97IN86XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ-PIM
M<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B2V]L961A<B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,3@T(&QI8B]";&]C:R]M971A<BYP:'`Z,S<P"B,L('!H
M<"UF;W)M870*;7-G:60@(F-A;&TB"FUS9W-T<B`B36ER;F\B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N;F]T
M(&-R96%T92!O=71P=70@9FEL92(*;7-G<W1R(").92!M;W)E;2!U<W1V87)I
M=&D@:7IH;V1N92!D871O=&5K92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G
M<W1R(").92!M;W)E;2!O9'!R971I('9H;V1A(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]#;VYT96YT<RYP:'`Z-C`P"FUS9VED(")C;&EC:R!H97)E(@IM
M<V=S='(@(FML:6MN:2!T=2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B
M"FUS9W-T<B`B;F%P86MA('8@=7!O<F%B;FD@=6MA>FYE('9R<W1I8V4B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W.`IM<V=I9"`B
M8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R(").87!A:V$@=B!K;VYF:6=U
M<F%C:6II(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-30*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T
M<B`B3F4@;F%J9&5M('IA:'1E=F%N92!S:7-T96US:V4@9&%T;W1E:V4B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B
M9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B3F%P8<2-;F$@;V)L:6MA(&1A
M='5M82(*"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,S`*;7-G:60@
M(F5D:70B"FUS9W-T<B`B57)E9&DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$X,@IM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S
M='(@(DYE(&YA:F1E;2!V;F5S96YI:"!P;V1A=&MO=B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"FUS9VED(")F86QL:6YG
M(@IM<V=S='(@(E!A9&%V:6YE(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O
M=W-E<BYP:'`Z.3`S"FUS9VED(")F:6QE(@IM<V=S='(@(F1A=&]T96MA(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#8@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R(")I>B`E
M<R`H)7,I(&L@)7,@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C0T"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(F=O<W1I;2(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-3`*;7-G:60@
M(F@Z(@IM<V=S='(@(F@Z(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C,V,PIM<V=I9"`B:&@B"FUS9W-T<B`B:&@B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B:&]S
M="!N86UE('5N:VYO=VXB"FUS9W-T<B`B3F5Z;F%N;R!I;64@9V]S=&ET96QJ
M82(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E(@IM<V=S='(@(G1A:V]J(@H*
M(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP
M:'`Z-SD*;7-G:60@(FEN;&EN92(*;7-G<W1R(")-960@=G)S=&EC86UI(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G:60@
M(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R(")6:&]D;F$O:7IH;V1N82!N
M87!A:V$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T
M-@IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B26YT
M97)N82!N87!A:V$@=B!P<F]G<F%M=2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(")L:6YE<UTB"FUS9W-T<B`B
M=G)S=&EC92(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES;V9S
M(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B;6MI
M<V]F<R!N87!A:V$@:V]D92`E9"P@;65D('!R:7!R879L:F%N:F5M($E33RXB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<T
M"FUS9VED(")M;2(*;7-G<W1R(")M;2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,C@Q('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ
M-S0*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(T,PIM<V=I9"`B
M;F%M92(*;7-G<W1R(")I;64B"@HC.B!F<F%M97=O<FLO4E!#+U)00RYP:'`Z
M,3(T"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`B;FD@9&]K;V[$
MC6%N;R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(R
M,`IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*;7-G<W1R("+%H64@;FD@
M<&]D<')T82(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`Y"FUS
M9VED(")N;W1E<&%D(@IM<V=S='(@(D)E;&7%OFMA(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ-S0*;7-G:60@(G!E<FUI<W-I;VX@
M9&5N:65D(@IM<V=S='(@(D1O=F]L:F5N:F4@:F4@>F%V<FYJ96YO+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED(")R
M96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B;F%P86MA('8@;V1D
M;&IE;F5M('!R;W1O:V]L=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C<U"FUS9VED(")R:7-I;F<B"FUS9W-T<B`B=GIH86IA
M:F_$C64B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T
M,@IM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R(")397)V:7,@
M;FD@;F$@=F]L:F\N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HQ,#(*
M;7-G:60@(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B4&]K8<6^:2!R87IL
M:6ME(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R(")S
M;7,R96UA:6P@<')E:V\@2%144"(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HS.3$*;7-G:60@(G-S(@IM<V=S='(@(G-S(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S0*;7-G
M:60@(G-T96%D>2(*;7-G<W1R(")3=&%B:6QN;R(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,34P"FUS9VED(")S>7-T96T@97)R;W(B
M"FUS9W-T<B`B4VES=&5M<VMA(&YA<&%K82XB"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.CDS,PIM<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@(E-E
M>FYA;2!O<')A=FEL+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,38V"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R(")Z
M8<2-87-N82!O9'!O=F5D(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@9G)A;65W
M;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W,0IM<V=I9"`B='EP92!T:&4@
M<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R(")Z82!P;W1R9&ET
M978@=G1I<&MA:G1E(&=E<VQO(&1V86MR870B"@HC.B!A9&UI;B]S971U<"]D
M:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B=6YI
M9FEE9"(*;7-G<W1R(")E;F]T96XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]H
M;W)D92YP:'`Z,C<Y"B,L(&9U>GIY"FUS9VED(")U;FMN;W=N(&5R<F]R(@IM
M<V=S='(@(G!O:F%V:6QA('-E(&IE(&YA<&%K82(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS9W-T<B`B
M8G)E>B!I;65N82(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B=7-E<B!S96QE8W0B"FUS9W-T
M<B`B27IB:7)A('5P;W)A8FYI:V$@(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V
M($MA<G1I8V$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C0R"FUS9VED(")W.B(*;7-G<W1R(")W.B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED(")W96%T:&5R+F-O;2(*;7-G
M<W1R(")W96%T:&5R+F-O;2(*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O8F=?0D<N<&\`````````
M````````````````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P-C0S
M-S$Q(#$P-3$U-#,S-S0R(#`Q-S0W,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````C($)U;&=A<FEA;B!T<F%N<VQA=&EO;G,@
M9F]R($AO<F1E('!A8VMA9V4N"B,@0V]P>7)I9VAT("A#*2`R,#`R($AO<F1E
M(%!R;VIE8W0*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE
M('-A;64@;&EC96YS92!A<R!T:&4@2&]R9&4@<&%C:V%G92X*(R!-:7)O<VQA
M=B!096YD978@/&UI<F]`8WEB97)S:&%D92YU<SXL(#(P,#(N"B,*;7-G:60@
M(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,"UC
M=G-<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N
M;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP
M,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`R+3$Q+3$Y(#(P.C0T+3`U
M,#!<;B(*(DQA<W0M5')A;G-L871O<CH@36ER;W-L878@4&5N9&5V(#QM:7)O
M0&-Y8F5R<VAA9&4N=7,^7&XB"B),86YG=6%G92U496%M.B!I,3AN0&QI<W1S
M+FAO<F1E+F]R9UQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M
M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U#4#$R-3%<;B(*(D-O;G1E;G0M
M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(S-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES
M(&%G;RDB"FUS9W-T<B`B("@E<R#D[>@@[>#GX.0I(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ,S<P"B,L('!H<"UF;W)M870*;7-G:60@(B`H
M06-C97-S:V5Y("5S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S<W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN
M("5S(&1A>7,I(@IM<V=S='(@(B`H)7,@Y.WH(.W@Y^#D*2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S,*;7-G:60@(B`H=&]D87DI(@IM<V=S
M='(@(B`HY.WE\2DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<U
M"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,S<Q"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T
M<B`B("CB]^7PX"DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C4V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C$*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C0P-PIM<V=I9"`B(&%T("(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Q-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<R"B,L('!H<"UF
M;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP
M:'`Z-C4Y"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z
M,3`T,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO
M="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B
M)R5S)R#MY2#E(.KN[?3HX_/PZ/#@[2#B($AO<F1E(%)E9VES=')Y+B(*"B,Z
M(&9R86UE=V]R:R]4<F5E+U1R964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-38*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T
M96TN(@IM<V=S='(@(B<E<R?AY?CE(.3NX>#BY>W@(.KZ["#C\//OZ/+E+B(*
M"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES
M<VEO;G,@<WES=&5M+B(*;7-G<W1R("(G)7,G(.'E^.4@Y.[AX.+E[2#J^NP@
M\>CQ\N7LX/+@(.?@(._PX.+@(.W@(._N\O#EX>CRY>OH\N4N(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3`*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-R
M96%T960Z("5S+B(*;7-G<W1R("(G)7,G[>4@X>7XY2#Q^N?DX.3E[3H@)7,N
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"B,L('!H<"UF;W)M870*
M;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,C8X(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HU-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@
M9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R`M($YO=&EC92(*;7-G<W1R("(E<R`M(,?@X>7KY>;JX"(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`T"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S,R!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HX,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@2T(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S($UA:6YT96YA;F-E($]P97)A
M=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B)7,@SN'QZ_/FXN#YZ"#N
M[^7PX/;HZ"`M(,_N\N+Z\.;DY>WHY2(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z,C8S"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(%-I9VX@57`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N
M8V4N<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS(&]F($%G
M<F5E;65N="(*;7-G<W1R("(E<R#3\>ONXNC_(._N(-'O[O#@Y_/LY>WHY?+N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT,C@@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HT.3`*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HV-3$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Y(&QI8B]";&]C:R]M971A<BYP
M:'`Z,38U(&QI8B]";&]C:R]M971A<BYP:'`Z,C,Y"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S0U(&QI8B]";&]C:R]M971A<BYP:'`Z,S4Q"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X
M(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@
M=&AI<R!T:6UE+B(*;7-G<W1R("+(Y^'E\.7RY2#N[^7PX/;HZ/+E+"#J[NGR
M[B#H\>K@\N4@Y.`@Z.?B^O#XZ/+E(/'EX^`N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R
M97%U:7)E9"(*;7-G<W1R("(E<R#MY>[A]>[DZ.PB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(X-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M;6EN=71E<R(*;7-G<W1R("+"\>7JZ"`U(.SH[?/RZ"(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,C,*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`B[>4@X>7X
MY2#MX.SE\.7M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B
M"FUS9W-T<B`B6^OH[>C_("5S(.[R("5S72(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z.3(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R("+`Y/#E\>7M(.'EZ^7F[>CJ(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,30*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`BRN#KY>WD
MX/`B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(B5S
M("T@Q^#AY>OEYNK@(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY
M,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED("(E<SH@)7,B"FUS9W-T<B`B)7/MX.SE\.7M.B5S("5S(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,C<R"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F
M<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG
M("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E
M<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V-2!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-#$P"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@X(&QI8B]";&]C:R]M
M971A<BYP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@(BP@9W5S=&EN9R`E
M<R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P,0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR
M.30@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-#@*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`V.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,3(X"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HW-#D*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=&EM92YP:'`Z,C`*(RP@9G5Z>GD*;7-G:60@(C$R($AO=7(@1F]R
M;6%T(@IM<V=S='(@(LCM].[P[.#VZ/\@Y^`@PN#Q(@H*(SH@;&EB+T)L;V-K
M+W1I;64N<&AP.C$Y"B,L(&9U>GIY"FUS9VED("(R-"!(;W5R($9O<FUA="(*
M;7-G<W1R("+([?3N\.S@]NC_(.?@(,+@\2(*"B,Z('1E;7!L871E<R]D871A
M+W1I;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(R-"#WX/'@
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0IM<V=I9"`B/%!R
M979I;W5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y
M"FUS9VED(")!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H
M:7,@8FQO8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,38P"B,L(&9U>GIY"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O
M8V-U<G)E9"(*;7-G<W1R("(\8C[-Y>_PY>[D[NOH[.`@X_#E^.K@.CPO8CXB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@
M(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE
M<W-A9V4N(@IM<V=S='(@(L?@(.3@(.KPZ._RZ/#@\N4@[^CQ[.X@Y2#MY>[A
M]>[DZ.P@[_/AZ^CWY>T@4$=0(.KK_O<N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3$V-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I
M<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T
M<B`BQ^`@Y.`@[_#NXN7PZ/+E(._NY._H\>#M[B#OZ/'L[B#E(.WE[N'U[N3H
M["!01U`@ZNO^]RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,#DW"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'
M4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T
M(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HBQ^`@Y.`@Y.7J\.CO\NCPX/+E
M(._H\>SN(/'@(.WE[N'U[N3H[.@Z(._SX>OH]^7M(.KK_O<L(.OH]^7M(.KK
M_O<@Z"#JZ_[W[N+@("(*(O3PX.?@+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$P,34*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL
M('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O('-I9VX@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"B+'X"#DX"#O[N3O
MZ/CE\N4@[^CQ[.X@\>`@[>7NX?7NY.CLZ#H@[_/AZ^CWY>T@ZNO^]RP@Z^CW
MY>T@ZNO^]R#H(.KK_O?NXN`@(@HB]/#@Y^`N(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU,#4*(RP@9G5Z>GD*;7-G:60@(B(*(D$@
M<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E
M+B(*;7-G<W1R("(B"B+'X"#DX"#DY>KPZ._RZ/#@\N4@[^CQ[.X@\>`@[>7N
MX?7NY.CLZ#H@[_/AZ^CWY>T@4TU)344@ZNO^]RP@Z^CWY>T@4TU)344@(@HB
MZNO^]R#H(.KK_O?NXN`@]/#@Y^`N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HT,S$*(RP@9G5Z>GD*;7-G:60@(B(*(D$@<'5B;&EC
M(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R
M("(B"B+'X"#DX"#O[N3OZ/CE\N4@[^CQ[.X@\>`@[>7NX?7NY.CLZ#H@[_/A
MZ^CWY>T@4TU)344@ZNO^]RP@Z^CWY>T@4TU)344@ZNO^]R#H("(*(NKK_O?N
MXN`@]/#@Y^`N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HS-C0*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T
M;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`BQ^`@Y.`@ZO#H[_+H\.#R
MY2#OZ/'L[B#E(.WE[N'U[N3H["#O\^'KZ/?E[2!334E-12#JZ_[W+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.CD*;7-G:60@
M(D%-($-L;W5D<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@4VAO=V5R
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ,PIM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]032(*
M;7-G<W1R(")!32]032(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*
M;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+VAE;'`O:6YD97@N<&AP.C4R"FUS9VED(")!8F]U="XN+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<T"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED
M9&QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL
M92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C,*(RP@
M9G5Z>GD*;7-G:60@(D%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`BR.WT
M[O#LX/;H_R#GX"#"X/$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4*
M(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS9W-T<B`BS^[R
MXOKPY.7RY2#OX/#NZ^#RX"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N="!F<F]Z96XN
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,S,*
M(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T<B`BS.[_\N`@S^[Y
MX"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30X('1E;7!L
M871E<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V%D9&-H:6QD+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B061D(@IM<V=S
M='(@(L3NX>#BZN@B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G
M<F]U<',N<&AP.C(R-0HC+"!F=7IZ>0IM<V=I9"`B061D($-H:6QD($=R;W5P
M(@IM<V=S='(@(L3NX>#B_^WE(.W@(.WNXN`@X_#S[^`B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDX(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z.3D*(RP@9G5Z>GD*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S
M:6]N(@IM<V=S='(@(L3NX>#B_^WE(.W@(.WNXN@@[_#@XN`B"@HC.B!T96UP
M;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B061D($AE
M<F4Z(@IM<V=S='(@(L#D\.7Q(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@
M861M:6XO9W)O=7!S+G!H<#HR,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS
M9W-T<B`BQ.[AX.+_[>4@[>`@[>[BX"#C\//OX"(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HX.`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(L3N
MX>#B_^WE(.W@(.WNXN@@[_#@XN`B"@HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V%D9&-H:6QD+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")!9&0@82!C:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`BQ.[AX.+H
M(.W@\>OEY.7MX"#C\//OX"#J^NP@)R5S)R(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,30W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R("+$
M[N'@XN@@[>#QZ^7DY>WH(._PX.+@(.KZ["`G)7,G(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R("+$[N'@
MXN@@[>[B(._N\O#EX>CRY>LZ(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C4U-`IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,T"B,L
M(&9U>GIY"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`BQ.[AX.+H
M(.WNXB#WZ^7M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHY-0HC
M+"!F=7IZ>0IM<V=I9"`B061D('!A:7(B"FUS9W-T<B`BQ.[AX.+H(/#EY_[L
MY2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B061D('1O(&%D9')E<W,@8F]O
M:SHB"FUS9W-T<B`BQ.[AX.+H(.KZ["#L[O_RX"#@Y/#E\>W@(.KMZ./@.B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW.`HC
M+"!F=7IZ>0IM<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O:R(*;7-G<W1R
M("+$[N'@XN@@ZOKL(.SN__+@(.#D\.7Q[>`@ZNWHX^`Z(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@
M(L3NX>#BZ"#M[N(@[^[R\.7AZ/+EZSHB"@HC.B!A9&UI;B]U<V5R+G!H<#HW
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE
M('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@
M:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP
M.C0U"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@
M<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@
M=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(L3NX>#B_^WE\NX@[>`@[^[R
M\.7AZ/+EZ^@@Y2#GX.'PX.WE[>XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3<S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$T-#$*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`BP.3PY?$B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,Y"FUS9VED(")!9&1R97-S($)O;VLB
M"FUS9W-T<B`BP.3PY?'E[2#AY>OEYNWHZB(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT"B,L(&9U>GIY"FUS9VED(")!9&UI
M;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G
M<W1R("+0Y>3@ZO;H_R#MX"#O\.#BX/+@(.?@("<E<R<B"@HC.B!A9&UI;B]I
M;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM
M<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`BP.3LZ.WH\?+PZ/#@[>4B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Q"FUS9VED(")!9',B
M"FUS9W-T<B`BQ.[AX.+JZ"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES
M=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*(RP@9G5Z>GD*;7-G:60@(D%L
M8F%N:6$B"FUS9W-T<B`BS_'EXN3N[>CL(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`HC+"!F=7IZ
M>0IM<V=I9"`B06QG97)I82(*;7-G<W1R("+/\>7BY.[MZ.PB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!
M;&EA<R(*;7-G<W1R("+/\>7BY.[MZ.PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$V"B,L(&9U>GIY"FUS9VED
M(")!;&EG;B(*;7-G<W1R("+/\>7BY.[MZ.PB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM<V=I
M9"`B06QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,C`W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G:60@
M(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L
M;"!'<F]U<',B"FUS9W-T<B`BPO'H]^KH(./P\^_H(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HY,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M9&%T871R964N<&AP.C<U"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T
M<B`BPO'H]^KH(._PX.+@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,0IM
M<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S0*;7-G:60@(D%L;&]W('-E='1I
M;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR
M96%D>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$R,PIM<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P-PIM<V=I9"`B06QT97)N
M871E($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0Y.0IM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*
M(RP@9G5Z>GD*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S
M='(@(L+@^.C_($5M86EL(.#D\.7Q.B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP
M:'`Z,30R"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z.34@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L
M=64@=V%S('-P96-I9FEE9"XB"FUS9W-T<B`BPOKBY>3E[>#RX"#Q\N[I[>[Q
M\B#MY2#E(.3N[_/Q\NCLX"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,38W"B,L(&9U>GIY"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA
M<R!O8V-U<F5D+B(*;7-G<W1R("+MY>_PY>[D[NOH[.`@X_#E^.K@.B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-34*;7-G:60@(D%N9&]R<F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M.`IM<V=I9"`B06YG;VQA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@
M(D%N9W5I;&QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS
M=V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B06YT:6=U82!A;F0@0F%R
M8G5D82(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D
M;6EN+W!H<'-H96QL+G!H<#HS-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M54DN<&AP.C4X('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*
M(RP@9G5Z>GD*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(L+@ZN#M]NC_
M(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R"B,L(&9U>GIY"FUS9VED
M(")!<'!L:6-A=&EO;B!,:7-T(@IM<V=S='(@(LW@[.7PY>WH(._PZ.ONYN7M
MZ/\Z("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$T,`IM<V=I9"`B
M07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3
M:&%R97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S"FUS9VED(")!<'!R
M;WAI;6%T92!3:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T,@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!<')I;"(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-0IM<V=I9"`B07)A8FEC("A7
M:6YD;W=S+3$R-38I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-3D@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HV-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C@Q"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R("+0
MX.?LY?`@[>`@X/#UZ.+MZ/\@].#IZR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-3@@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HV-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C@P"FUS9VED(")!<F-H:79E($YA;64B"FUS9W-T<B`BR.SE(.W@
M(.#P]>CBX"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E
M9"YI;F,Z,3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@
M<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O
M<B`E<R`_(@IM<V=S='(@(M'HX_/P[>@@Z^@@\?+E+"#WY2#H\>K@\N4@Y.`@
MZ.?R\.CE\N4@)R5S)R#H(.+QZ/?JZ"#O[N3O\.#BX#\B"@HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<
M(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R("+1Z./S\.WH(.OH
M(/'RY2P@]^4@Z/'JX/+E(.3@(.CG\O#HY?+E("<E<R<@Z"#B\>CWZN@@[^[D
MX_#S[^@_(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B07)G96YT:6YA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S8*;7-G:60@(D%R;65N:6%N("A!4DU3
M0TE)+3@I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR
M.`IM<V=I9"`B07)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%R
M=6)A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED
M(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT,C4*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N
M(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G<W1R
M("+$X"#QY2#H\>K@(.OH(._N\N+Z\.;DY>WHY2#O\.7DZ"#NX?'K\^;BX/GH
M\N4@[N_E\.#VZ.@_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q
M,PIM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@
M;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R("+#\.7XZN`@[_#H(.CG\O#H
MXN#MY2#MX"#MY?'Z^>7Q\N+SXN#YX"#C\//OX"XB"@HC.B!A9&UI;B]P97)M
M<R]D96QE=&4N<&AP.C(Y"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO
M;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("+#\.7XZN`@[_#H(.CG
M\O#HXN#MY2#MY2#MY?'Z^>7Q\N+SXN#YZ"#O\.#BX"XB"@HC.B!A9&UI;B]P
M97)M<R]E9&ET+G!H<#HX-PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N
M+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(L/PY?CJX"#O\.@@\.7D
MX.KRZ/#@[>4@[>`@[>7Q^OGE\?+B\^+@^>@@[_#@XN`N(@H*(SH@<V5R=FEC
M97,O<VAA<F5S+V5D:70N<&AP.C4S"B,L(&9U>GIY"FUS9VED(")!='1E;7!T
M('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(L/PY?CJ
MX"#O\.@@\.7DX.KRZ/#@[>4@[>`@[>7Q^OGE\?+B\^+@^>@@[_#@XN`N(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-"!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#8*;7-G:60@(D%T=')I8G5T
M97,B"FUS9W-T<B`BP/+PZ.'S\N@B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`X"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW,@HC+"!F=7IZ>0IM<V=I9"`B075G=7-T(@IM
M<V=S='(@(L'ZX^[BY2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<FEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G
M:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M=7,N<&AP.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO
M="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?
M8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]F='`N<&AP.C,V"FUS
M9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S
M=VET8V@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA
M<"YP:'`Z-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D
M(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A
M<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$
M:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HS-3<*;7-G:60@(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@
M:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C8S"FUS9VED
M(")!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HS,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@
M=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z
M("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T
M;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C0Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H
M7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0P-0IM<V=I9"`B075T
M:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!
M8W1I=F4@1&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VUC86PN<&AP.C0V"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D
M($U#04P@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U
M=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDP"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS
M9W-T<B`BP_#E^.K@(._PZ"#HY.7M\NCTZ.K@]NC_(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@
M)7,B"FUS9W-T<B`BP_#E^.K@(._PZ"#HY.7M\NCTZ.K@]NC_(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B075T:&5N
M=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS9W-T<B`B
MR.3E[?+H].CJX/;H__+@(.'E^.4@[O+UXOKPZ^7MX"#N\B!2041)55,@\?KP
MXOKPX"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@U,0HC+"!F
M=7IZ>0IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL
M960N(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.3E[?+H].CJX/;H_R(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-S`*(RP@9G5Z>GD*;7-G:60@(D%U
M=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T
M<B`BPO#ZY^K@\N`@\?KQ($944"#Q^O#B^O#@(/'E(._P[N+@Z^@N(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE
M(&9I96QD<SHB"FUS9W-T<B`BS>#KZ/?MZ"#O[NOE\N`Z(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S`*;7-G:60@(D)/1D@@17AC=7-E<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C$X"FUS9VED(")"86-K9W)O=6YD(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A
M8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D
M+B(*;7-G<W1R("+-Y>+@Z^CD[>`@:V5R8F5R;W,@(._@\.[KX"XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R
M8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@(LWEXN#KZ.3M[B!K97)B97)O<R#O
M[O+PY>'H\N7K\>KN(.CLY2XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"86AA;6%S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(D)A:')A
M:6XB"FUS9W-T<B`B0F%R8FEE(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M-S<*;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C`*;7-G:60@(D)A;F=L861E<V@B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,`IM<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C,Q"B,L('!H<"UF;W)M870*;7-G:60@(D)A<V4@9W)A
M<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW,PIM<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM
M<V=I9"`B0F5L87)U<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"
M96QG:75M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@
M(D)E;&EZ92(*;7-G<W1R("+0X.?LY?`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"
M96YI;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"97)M=61A(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q
M"FUS9VED(")":7)T:&1A>2(*;7-G<W1R("+0[N;DY>T@Y.7M(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,U,PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T
M:6]N(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(M'K\_C@\N7K__(@)7,@
M[>4@Y2#MX.SE\.7M+B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN
M8SHX.0IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C:R!4>7!E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G<W1R("+3Y.7AY>OE[>@B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8R"FUS9VED(")";VQI=FEA(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR,#4*;7-G:60@(D)O;VMM87)K<R(*;7-G
M<W1R("+.\NSE\NKH(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR,`HC+"!F=7IZ>0IM<V=I9"`B0F]R9&5R(@IM
M<V=S='(@(DAO<F1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR,0HC+"!F=7IZ>0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R(")(
M;W)D92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I
M;F$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS
M9VED(")";W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*(RP@9G5Z>GD*;7-G
M:60@(D)O='-W86YA(@IM<V=S='(@(D)R;W=N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")";W1T
M;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"B,L(&9U>GIY"FUS9VED(")"<F%Z
M:6PB"FUS9W-T<B`BS^[YX"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")"<FET:7-H
M($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0HC+"!F=7IZ>0IM<V=I
M9"`B0G5L;&5T960@3&ES="(*;7-G<W1R("+/[N3PY>3E[2#Q[^CQ^NHB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#0T"FUS9VED(")#35,B"FUS9W-T<B`B0TU3
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-0IM
M<V=I9"`B0U)#(@IM<V=S='(@(D-20R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O
M:6YT<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I
M97,N+BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$V,PIM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0X-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3@W"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ-34*;7-G:60@(D-A;&5N9&%R(@IM<V=S
M='(@(LK@Z^7MY.#P(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(T-@HC+"!F=7IZ>0IM<V=I9"`B0V%L;2(*;7-G<W1R("+.\NK@YN@B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S
M<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C,Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86X@;F]T('=R:71E('1O(&9I
M;&4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR
M,@IM<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA
M;F1L97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G5S+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,Q
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-05`@
M<V5R=F5R.B`E<R(*;7-G<W1R("+#\.7XZN`@[_#H(/'B^O#GXN#MY2#Q(.SE
MZ>L@\?KPXOKP.B`E<R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C0Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!O<&5N(&9I;&4@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"B,L(&9U>GIY"FUS9VED(")#
M86YA9&$B"FUS9W-T<B`BRN#KY>WDX/`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,#$@861M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHV-0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V1E;&5T92YI;F,Z,3$@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC
M.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G
M:60@(D-A;F-E;"(*;7-G<W1R("+.\NK@YN@B"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P
M;W)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,S$X"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D96QE=&4@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HT-@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C4R"FUS9VED(")#86YN;W0@9FEN9"!A('1E;7!O
M<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C
M965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,30*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB
M)7-<(BXB"FUS9W-T<B`BP_#E^.K@(._PZ"#O\.7LX/7BX.WE.R`H)7,I(.+E
M]^4@\?KYY?'RXO/BX"(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E
M92YP:'`Z,3(X(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP
M.C8X,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V
M92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(L/PY?CJX"#O\.@@[_#E
M[.#UXN#MY3L@*"5S*2#BY??E(/'Z^>7Q\N+SXN`B"@HC.B!F<F%M97=O<FLO
M1&%T851R964O1&%T851R964O<W%L+G!H<#HV,#@*;7-G:60@(B(*(D-A;FYO
M="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O
M<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I
M9FEE9"!N=6UB97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A
M<&4@5F5R9&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`HC+"!F=7IZ>0IM<V=I9"`B0V%P
M=&EO;B(*;7-G<W1R("+.[_;HZ"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]G96YE<FEC7W-M='`N<&AP.C$P-`HC+"!F=7IZ>0IM<V=I9"`B0V%R<FEE
M<B(*;7-G<W1R(")"87)B:64B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3`*;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-@IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM
M<V=I9"`B0V5L;"!0:&]N92(*;7-G<W1R("+,[N'HZ^7M(/+EZ^7T[NTB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(U"B,L(&9U>GIY"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`B
MS.[AZ.OE[2#RY>OE].[M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R
M"FUS9VED(")#96QL('-P86-I;F<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R-S0*(RP@9G5Z>GD*;7-G:60@(D-E;&QP:&]N
M92(*;7-G<W1R("+,[N'HZ^7M(/+EZ^7T[NTB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$W.`IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR-@HC+"!F=7IZ>0IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(M;E
M[?+PZ/#@[2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-E;G1R86P@069R:6-A;B!2
M97!U8FQI8R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W
M.0IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.3D*
M;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3$*;7-G:60@(D-E<G1I
M9FEC871E($]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*(RP@9G5Z>GD*;7-G:60@(D-H
M860B"FUS9W-T<B`B=D-A<F0B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,L(&9U
M>GIY"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B3W)A;F=E(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,Q"B,L(&9U>GIY"FUS9VED(")#:&%N
M9V4@66]U<B!087-S=V]R9"(*;7-G<W1R("+/[O+B^O#DY?+E(._@\.[KX/+@
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V"FUS9VED("(B"B)#:&%N
M9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@
M=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED
M("(B"B)#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@
M=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*(RP@9G5Z>GD*
M;7-G:60@(D-H87(B"FUS9W-T<B`B=D-A<F0B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H
M96-?:R!,:6YK+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*(RP@9G5Z>GD*
M;7-G:60@(D-H:6QE(@IM<V=S='(@(O3@Z>LB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED
M(")#:&EN82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M,`IM<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#:&EN97-E
M(%1R861I=&EO;F%L("A":6<U*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"B,L(&9U>GIY"FUS9VED(")#:&]O
M<V4@82!P87-S=V]R9"(*;7-G<W1R("+/[O+B^O#DY?+E(._@\.[KX/+@(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.`IM<V=I9"`B
M0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(Y.`IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A
M=&5S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S
M='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C4U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,N<&AP.C(Y-"!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z.#DS"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S
M<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`BT>OS^.#R
MY>O_\B`E<R#MY2#E(.W@[.7PY>TN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,30*(RP@9G5Z>GD*;7-G:60@(D-L96%R(@IM
M<V=S='(@(LK@Z^7MY.#P(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"FUS9VED(")#
M;&5A<B!1=65R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]C;&5A<BYI;F,Z-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0VQE
M87(@;W5T('5S97(Z("5S(@IM<V=S='(@(L_PY>S@]>WH(._N\O#EX>CRY>LZ
M("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$Q"FUS
M9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC.C,T"B,L(&9U>GIY"FUS9VED(")#;&5A<B!U<V5R
M(&1A=&$B"FUS9W-T<B`BR.?AY?#H(._N\O#EX>CRY>L@Y^`@Y.[AX.+_[>4B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0IM
M<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV,`IM<V=I9"`B0VQI8VL@
M=&\@0V]N=&EN=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL
M('9I82!(5%10(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H
M<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@HC+"!F=7IZ>0IM
M<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(L?@\N+N\.@@[_#NY^[PY?8@
M7"+/[NSN^5PB(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#0*;7-G:60@
M(D-L;W5D<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ-@IM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$W
M"B,L(&9U>GIY"FUS9VED(")#;&]U9'DB"FUS9W-T<B`BRN[OZ/#@Z2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C0*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,C,*;7-G
M:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B
M0V]L;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I
M9"`B0V]L;VUB:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H
M<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T
M:6]N+G!H<#HS,C0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I
M;VXN<&AP.C,R-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-3`P('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*
M;7-G:60@(D-O;&]R(%!I8VME<B(*;7-G<W1R("+(Y^'H\.#MY2#MX"#VXO_R
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@T-@IM<V=I9"`B0V]L
M;W5R('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-@IM<V=I9"`B
M0V]L=6UN('1I=&QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C8T"FUS9VED(")#;VUI8W,B"FUS9W-T<B`BRN[LZ.KQZ"(*
M"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-0HC+"!F=7IZ>0IM<V=I9"`B0V]M
M;6%N9"(*;7-G<W1R("+*[NS@[>3H.B(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H
M<#HR,`HC+"!F=7IZ>0IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R("+*
M[NS@[>3H.B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q
M,PHC+"!F=7IZ>0IM<V=I9"`B0V]M;65N="(*;7-G<W1R("+*[NS@[>3H.B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38V"FUS9VED
M(")#;VUM;VX@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`HC+"!F=7IZ
M>0IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R("+*[NSHZO'H(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M
M<&%N>2(*;7-G<W1R("+*[NSOX.WH_R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3<*(RP@9G5Z>GD*;7-G:60@(D-O
M;F1I=&EO;B(*;7-G<W1R("+*[NWTZ./S\.#VZ/\B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(T.0HC+"!F=7IZ>0IM<V=I9"`B0V]N9&ET:6]N<R(*;7-G
M<W1R("+*[NWTZ./S\.#VZ/\B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HY
M-@HC+"!F=7IZ>0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*
M;7-G<W1R("+*[NWTZ./S\.#VZ/\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,30S"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@
M4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S4*(RP@9G5Z>GD*;7-G:60@(D-O
M;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@(LKN[?3HX_/P
MX/;H_R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R("+*[NWT
MZ./S\.#VZ/\B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C4Q"FUS9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(L_N\N+Z\.3E
M\N4@[^#P[NO@\N`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;VYG;R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8U"FUS9VED(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@
M4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*(RP@9G5Z>GD*;7-G:60@(D-O;FYE
M8W1I;VX@9F%I;&5D+B(*;7-G<W1R("+"\/KGZN#RX"#Q^O$@1E10(/'Z\.+Z
M\.`@\>4@[_#NXN#KZ"XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S$P"B,L(&9U>GIY"FUS9VED(")#;VYN96-T:6]N(&9A:6QE
M9#H@(@IM<V=S='(@(L+P^N?JX/+@(/'Z\2!&5%`@\?KPXOKPX"#QY2#O\.[B
MX.OH+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,`IM
M<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R
M=F5R+B(*;7-G<W1R("+$[O'R^N_@(.3N(._SX>OH]^WH_R#Q^O#B^O`@X>7X
MY2#N\NK@Y^#M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C<Y,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R
M969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E
M<RDB"FUS9W-T<B`BQ.[Q\OKOX"#D[B#O\^'KZ/?MZ/\@\?KPXOKP(.'E^.4@
M[O+JX.?@[2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@T-0HC
M+"!F=7IZ>0IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE
M9"XB"FUS9W-T<B`BPO#ZY^K@\N`@\?KQ($944"#Q^O#B^O#@(/'E(._P[N+@
MZ^@N(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,30*;7-G:60@(D-O
M;G1A8W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HU,PHC+"!F=7IZ>0IM<V=I9"`B0V]N=&%C=',@=V5R
M92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM
M<V=S='(@(B(*(M+EY^@@Y.#M[>@@Y^`@ZN[M\N#J\B#A__7@(//Q[^7X[>X@
MY.[AX.+E[>@@ZOKL(,+@^.#RX"#O\.[C\.#LX"X@RNOHZNWE\N4@[^XM(@HB
MY.[K\R#GX"#DX"#BZ.3H\N4Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HU-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C8S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-S@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O;G1E;G1S(&]F
M(%PB)7-<(B(*;7-G<W1R("+1^N3Z\.;@[>CE(.W@("<E<R<B"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.2!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z,S,*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`BRN[OZ/#@Z2(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8X"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`BR.SO[O#RZ/#@
M[>X@[^[KY3H@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$W,`HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I
M9"`B0V]S="!)1"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;W-T
M82!2:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O=&4@9"=)
M=F]I<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z.3<V"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G
M92XB"FUS9W-T<B`BP_#E^.K@(._PZ"!01U`@ZO#H[_+H\.#MY?+N(.W@(._H
M\>SN+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P-3,*
M;7-G:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+B(*;7-G<W1R("+#
M\.7XZN`@[_#H(%!'4"#O[N3OZ/'BX.WE\NX@[>`@[^CQ[.XN(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3,*(RP@9G5Z>GD*;7-G
M:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R
M("+#\.7XZN`@[_#H(%--24U%(.KPZ._RZ/#@[>7R[B#MX"#OZ/'L[BXB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PHC+"!F=7IZ
M>0IM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S
M='(@(L/PY?CJX"#O\.@@4TU)344@[^[D[^CQXN#MY?+N(.W@(._H\>SN+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,3@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D
M(&-O;G1A8W0N("5S(@IM<V=S='(@(LWEXOKG[.[F[>[Q\B#DX"#QY2#J[N_H
M\.`@)7,@\NX@)7,N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.CDV(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"B,L(&9U
M>GIY"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS
M9W-T<B`BS>7B^N?L[N;M[O'R(.3@(/'E(.[Q^OGE\?+BZ"#B\/KGZN`@\2!,
M1$%0(/'Z\.+Z\"XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#4W"B,L
M(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E<B(*
M;7-G<W1R("+#\.7XZN`@[_#H(._NZ_/WX.+@[>7R[B#MX"#O\^'KZ/?MZ/\@
MZNO^]R#N\B#JZ_[W+?'Z\.+Z\.`N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS
M9W-T<B`BS>7B^N?L[N;M[O'R(.3@(/'E(.KN[^CPX"`E<R#R[B`E<RXB"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#0Q"B,L(&9U>GIY"FUS9VED(")#
M;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E<B(*;7-G<W1R("+#\.7X
MZN`@[_#H(/'B^O#GXN#MY2#Q^O$@4TU"(/'Z\.+Z\"XB"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10
M.B`E<R(*;7-G<W1R("+#\.7XZN`@[_#H(/'B^O#GXN#MY2#Q(%)00R#Q^O#B
M^O`Z("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HS,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(L/P
MY?CJX"#O\.@@\?KGY.#BX.WE(.W@(.ONZN#K[>`@Y.CPY>KR[O#H_R#GX"#K
M[NK@Z^CGX/;H_R`E<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$Q,C4*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+B(*
M;7-G<W1R("+#\.7XZN`@[_#H(.3EZO#H[_+H\.#MY?+N(.W@(%!'4"#DX.WM
MZ"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R,@HC
M+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N
M(@IM<V=S='(@(L/PY?CJX"#O\.@@Y.7J\.CO\NCPX.WE\NX@[>`@4TU)344@
MY.#M[>@N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HR-#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!D96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`BS>7B^N?L[N;M[O'R
M(.3@(/'E(.KN[^CPX"`E<R#R[B`E<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A
M9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HS.#$@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z.34S"FUS9VED(")#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R
M96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T<B`BS>7J[O#EZO+E
M[2!E;6%I;"#@Y/#E\2#MX"#O[NOS]^#RY>O_+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"B,L(&9U>GIY"FUS
M9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*
M;7-G<W1R("+-Y>KN\.7J\N7M(&5M86EL(.#D\.7Q(.W@(._NZ_/WX/+EZ_\N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HT.3,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB
M=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F
M971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z
M.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D
M('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T<B`BS>7B^N?L[N;M[O'R(.3@(/'E
M(.KN[^CPX"`E<R#R[B`E<RXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDO9&ER96-T+G!H<#HS,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO="!O
M8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@
M(L/PY?CJX"#O\.@@[^[K\_?@XN#MY?+N(.W@(._SX>OH]^WH_R#JZ_[W(.[R
M(.KK_O<M\?KPXOKPX"XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@
M9F]R('=R:71I;F<N(@IM<V=S='(@(LWEXOKG[.[F[>[Q\B#DX"#QY2#J[N_H
M\.`@)7,@\NX@)7,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`BS>7B^N?L[N;M[O'R(.3@
M(/'E(.KN[^CPX"`E<R#R[B`E<RXB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N
M8V4O36%I;G1E;F%N8V4N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*;7-G
M<W1R("+-Y>+ZY^SNYNWN\?(@Y.`@\>4@[O+B[O#H(,[A\>OSYN+@^>A?Y^#D
MX/?H(.SNY//K("5S("(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HW,`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y
M(%PB)7-<(BXB"FUS9W-T<B`BS>7B^N?L[N;M[O'R(.3@(/'E(.KN[^CPX"`E
M<R#R[B`E<RXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M,3$Q(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(S-R!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z-#<X"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HU,38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C8Q,@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C4V(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV.3D*(RP@9G5Z>GD*;7-G
M:60@(D-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@
M(LWEXOKG[.[F[>[Q\B#DX"#QY2#N\?KYY?'RXN@@XO#ZY^K@(/$@3$1!4"#Q
M^O#B^O`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O3V)J96-T+G!H<#HR,S@*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R96%D("5S
M+B(*;7-G<W1R("+-Y>+ZY^SNYNWN\?(@Y.`@\>4@ZN[OZ/#@("5S(/+N("5S
M+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B
M"B)#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S
M=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N
M;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES
M=')A=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,`HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S<*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@S"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.0IM<V=I9"`B
M0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&%D9')E
M<W,@8F]O:RX@)7,B"FUS9W-T<B`BS>7J[O#EZO+E[2!E;6%I;"#@Y/#E\2#M
MX"#O[NOS]^#RY>O_+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E
M(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*;7-G:60@(D-O=6QD(&YO
M="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B
M0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")(;W)D
M92#MY2#E(.KN[?3HX_/PZ/#@[2#J[O#EZO+M[B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HW,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A
M=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BS>7NX?7NY.CLZ/\@)W!O
M<G0G(.WE(.4@Y^#DX.3E[2#B^N(@5D93(.KN[?3HX_/PX/;H__+@+B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HU.0IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG
M=6%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K
M=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HY-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG
M=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO
M="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET
M:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D
M92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@
M=&\@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z,30S"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H
M92!,1$%0('-E<G9E<BXB"FUS9W-T<B`BS>7B^N?L[N;M[O'R(.3@(/'E(.[Q
M^OGE\?+BZ"#B\/KGZN`@\2!,1$%0(/'Z\.+Z\"XB"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z.#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R("+#\.7XZN`@[_#H(%!'4"#O[N3O
MZ/'BX.WE\NX@[>`@[^CQ[.XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B
MS>7B^N?L[N;M[O'R(.3@(/'E(.KN[^CPX"`E<R#R[B`E<RXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!W
M<FET92!C;VYF:6=U<F%T:6]N(&9O<B!<(B5S7"(Z("5S(@IM<V=S='(@(L/P
MY?CJX"#O\.@@\?KGY.#BX.WE(.W@(.ONZN#K[>`@Y.CPY>KR[O#H_R#GX"#K
M[NK@Z^CGX/;H_R`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C8*
M;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K
M92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H
M92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q.0IM
M<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-38Y"B,L(&9U>GIY"FUS9VED(")#;W5N
M=')Y(@IM<V=S='(@(NCG\.7FZ"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR-S,*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P
M"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED(")#<F5A
M=&4@82!L:6YK(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N
M=&ET>7-E;&5C="YI;F,Z.30*(RP@9G5Z>GD*;7-G:60@(D-R96%T92!A(&YE
M=R!O;F4B"FUS9W-T<B`BR.?AY?#E\N4@[>[B(._PZ/+EYN#RY>L@[>`@X_#S
M[^`B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M,@IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C0P"B,L(&9U>GIY"FUS9VED
M(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(L_PX.+@(._N(._NY/#@
MY^'H\.#MY2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R,S`*;7-G
M:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M.0IM<V=I9"`B0W)O871I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED
M(")#=6)A(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-@IM
M<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M97-S:6]N<RYP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@4V5S<VEO
M;G,B"FUS9W-T<B`BS_#@XN`@Y^`@X^[Q\N@B"@HC.B!L:6(O0FQO8VLO=&EM
M92YP:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E;G0@
M5&EM92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@55),(&ES
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS,PHC+"!F=7IZ
M>0IM<V=I9"`B0W5R<F5N="!5<V5R<R(*;7-G<W1R("+"X/CH\N4@\?KPXOKP
MZ#HB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS9VED(")#=7)R96YT
M(%=E871H97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(W-0IM<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S
M=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*;7-G<W1R("+HY_#EYN@B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,U"FUS9VED
M(")#=70@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@
M(D-Y<')U<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M,@IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(D-Y<FEL;&EC("A7:6YD;W=S
M+3$R-3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@T
M"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U
M,2!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B1$0B"FUS9W-T<B`B
MQ,0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@Q"FUS9VED("(B
M"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K
M86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3D*;7-G
M:60@(D1A:6QY(@IM<V=S='(@(L7FY>3MY>+M[B(*"B,Z(&%D;6EN+V1A=&%T
M<F5E+G!H<#HV-0IM<V=I9"`B1&%T851R964@0G)O=W-E<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<Y"FUS9VED(")$871A
M8F%S92!,;V]K=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F9C.#(R+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,SDY"B,L(&9U>GIY"FUS9VED(")$871E(@IM<V=S='(@(L3@[>WH(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G:60@
M(D1A=&4@4F5C96EV960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C@P-PIM<V=I9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S(R"B,L(&9U>GIY"FUS9VED(")$87DB
M"FUS9W-T<B`BQ>;EY.WEXNWN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,V"B,L(&9U>GIY"FUS9VED(")$
M95]L971E($-O;'5M;B(*;7-G<W1R("+(Y^'E\.7RY2#J[NON[>@Z(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*(RP@9G5Z
M>GD*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(M?KY>WNXN4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V
M"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`HC+"!F=7IZ>0IM
M<V=I9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S='(@(LW@[.#KZ"#SY>3MX.KB
M_^+@[>7R[B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3@W
M(&QI8B]P<F5F<RYP:'`Z,3$W"B,L(&9U>GIY"FUS9VED(")$969A=6QT(@IM
M<V=S='(@(LCG\O#HZ2(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C<W"B,L(&9U>GIY"FUS9VED(")$969A=6QT($-O;&]R
M(@IM<V=S='(@(LCG[^[KY^+@Z2#O[N3PX.?AZ/#@^>#RX"#QY2#Q\N[I[>[Q
M\B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z.3$*;7-G
M:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`BR.3E[?+H]^WN\?(@[^X@
M[^[D\.#GX>CPX.WE(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8W"B,L
M(&9U>GIY"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@(LCDY>WRZ/?M
M[O'R(._N(._NY/#@Y^'H\.#MY2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS,PIM<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HW,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C,V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$Q-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.2!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.CDX"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,"!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E
M(@IM<V=S='(@(LCG\O#HZ2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@HC+"!F=7IZ>0IM<V=I9"`B1&5L
M971E($-E;&PB"FUS9W-T<B`BR.?R\.CI(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR,C<*(RP@9G5Z>GD*;7-G:60@(D1E
M;&5T92!'<F]U<"(*;7-G<W1R("+(Y_+PZ.DB"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-#D*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!,;V<B
M"FUS9W-T<B`BR.?R\.CI(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HW-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,0HC+"!F
M=7IZ>0IM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`BS_#@XN`@
M[^X@[^[D\.#GX>CPX.WE(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G
M97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU-PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E(&-E
M;&PB"FUS9W-T<B`BR.?R\.CI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PHC+"!F=7IZ>0IM<V=I9"`B1&5L
M971E(&-O;'5M;B(*;7-G<W1R("+(Y^'E\.7RY2#J[NON[>@Z(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A
M;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HT,C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(M#E
MY.#J]NC_(.W@(._PX.+@\N`@Y^`@)R5S)R(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z-#(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP
M97)M:7-S:6]N<S\B"FUS9W-T<B`BT>CC\_#MZ"#KZ"#Q\N4L(/?E(.CQZN#R
MY2#DX"#HY_+PZ.7RY2`G)7,G(.@@XO'H]^KH(._NY._PX.+@/R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*
M(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T<B`BR.?R\.CI(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V1E;&5T96ED96YT:71Y+FEN8SHQ-0HC+"!F
M=7IZ>0IM<V=I9"`B1&5L971E('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@
M(LCDY>WRZ/?M[O'R(._N(._NY/#@Y^'H\.#MY2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B
M1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*
M;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-38S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3DU"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(R,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR-3,*(RP@9G5Z>GD*;7-G:60@(D1E;&EV97)Y
M('1I;64B"FUS9W-T<B`BR.?R\.CI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&5N
M;6%R:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3,X('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*(RP@9G5Z>GD*
M;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(L_ZZ^WN(.[OZ/'@[>CE.B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DU"FUS9VED(")$971A
M:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DY"FUS9VED(")$971A:6QS
M(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G
M<W1R("+$Y?+@Z>OH\N4@X?_UX"#PY>/H\?+PZ/#@[>@@Y^`@X.3LZ.WH\?+P
MX/+N\.`N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Q.0IM<V=I
M9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,3<*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(Y-`IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T
M(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C(W"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED
M(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$
M:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-C8*;7-G:60@(D1I<W!L87D@
M,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDW"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`BQ.CQ
M[^OEZ2#.[_;HZ"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HY
M-@HC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*
M;7-G<W1R("+$Z/'OZ^7I(,[O]NCH(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HX-0IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$W"B,L(&9U>GIY"FUS
M9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R("+$Z/'OZ^7I(,[O]NCH(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C$Y,`IM<V=I9"`B1&ES
M<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*
M;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z-#(R"B,L(&9U>GIY"FUS9VED(")$;R!N;W0@9&5L
M971E(@IM<V=S='(@(LCG\O#HZ2(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E
M+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N
M86YC92YP:'`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF
M;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G:60@
M(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@
M268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I
M9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C
M;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z.#0T"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S(@IM<V=S
M='(@(LWEZ.?BY?'R[>`@ZN[LX.WDX#H@)7,B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG
M=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,3`W"FUS9VED(")$<F]P(&1O=VX@;&ES="(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S0*(RP@9G5Z
M>GD*;7-G:60@(D1R=6=S(@IM<V=S='(@(L'ZX^[BY2(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PHC+"!F=7IZ>0IM<V=I9"`B12U-
M86EL(@IM<V=S='(@(L_N^>`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM=&\M4TU3(&=A=&5W
M87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E
M<G9I8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G:60@(D52
M4B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%8W5A9&]R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(U('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@Q
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@HC.B!T96UP;&%T97,O
M<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET(@IM<V=S='(@(M#EY.#J
M]NC_(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU,"!T96UP
M;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET($)L;V-K(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DX(&%D;6EN+V=R;W5P
M<RYP:'`Z,C(V"B,L(&9U>GIY"FUS9VED(")%9&ET($=R;W5P(@IM<V=S='(@
M(L/P\^_H(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,`HC+"!F=7IZ>0IM<V=I
M9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@(L_PX.+@(@H*(SH@<V5R=FEC
M97,O<VAA<F5S+V5D:70N<&AP.C(S-PHC+"!F=7IZ>0IM<V=I9"`B161I="!0
M97)M:7-S:6]N<R(*;7-G<W1R("+/\.#BX"(*"B,Z('-E<G9I8V5S+W-H87)E
M<R]E9&ET+G!H<#HR,SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5D
M:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(M#EY.#J]NC_(.W@(._P
MX.+@\N`@Y^`@)R5S)R(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*
M(RP@9G5Z>GD*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@(M#E
MY.#J]NC_(.W@(._PX.+@\N`@Y^`@)R5S)R(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,S8W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")%9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`BT.7DX.KV
MZ/\@[>`@[_#@XN#RX"#GX"`G)7,G(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B161I="!P
M97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`BT.7DX.KVZ/\@[>`@[_#@XN#R
MX"#GX"`G)7,G(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U"B,L(&9U
M>GIY"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`BPN#JX.WVZ/\B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<P"FUS9VED(")%9WEP="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C,Q,`HC+"!P:'`M9F]R;6%T"FUS9VED(")%:71H
M97(@96YA8FQE(&ET('1H96XZ("5S+"!O<B!U<V4@=&AE(&)A<VEC($A434P@
M=F5R<VEO;CH@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B
M16P@4V%L=F%D;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M96YT
M+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$X-CD*;7-G:60@(D5M86EL(@IM<V=S='(@(L_H
M\>SN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C4@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"FUS9VED(")%;6%I;"!!9&1R
M97-S(@IM<V=S='(@(L5M86EL(.#D\.7Q(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3DV,PIM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T
M8V@N(@IM<V=S='(@(D5M86EL(.#D\.7QZ/+E(/+P_^'BX"#DX"#Q^N+OX.3@
M\BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3@Y"B,L(&9U>GIY
M"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R("+$\//C
MX"#H[?3N\.S@]NC_(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R
M:6-?<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E=V%Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR.3@*(RP@9G5Z>GD*;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R("+.
M[_;HZ"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P,@HC+"!F=7IZ>0IM<V=I9"`B16UP='D@;65S<V%G92XB"FUS
M9W-T<B`BS_#@Y^7M(/#EY_/K\N#R+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HR-#,@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C0X-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C8R
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW,#4*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-3`*;7-G:60@(D5M<'1Y(')E<W5L
M="XB"FUS9W-T<B`BS_#@Y^7M(/#EY_/K\N#R+B(*"B,Z(&9R86UE=V]R:R]3
M44PO4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E87)C:"!T
M97)M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-30S
M"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O
M($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3$X"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N
M=&5X="!M96YU/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-3DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3$*;7-G:60@
M(D5N9"!Y96%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C$*;7-G:60@
M(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@
M8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S=V]R
M9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!54DP@
M:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.#DQ"FUS9VED(")%;G1E<B!T:&4@;&5T=&5R<R!B96QO
M=SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B17%U871O<FEA;"!'
M=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HT-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-34*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-B!S97)V:6-E<R]P;W)T86PO
M:6YD97@N<&AP.C@R"FUS9VED(")%<G)O<B(*;7-G<W1R("+#\.7XZN`B"@HC
M.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@S
M"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G
M.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA
M=&4N<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!G971T:6YG
M(&-O;G1E;G0Z("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!U<&1A
M=&EN9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED(")%<G)O
M<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN
M9R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N
M:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P:6$B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS9VED(")%
M=&AN:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,S.0IM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G
M<W1R("+"\>7JZ"`Q-2#LZ.WS\N@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S@Y"B,L(&9U>GIY"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T
M<B`BPO'EZN@@-2#LZ.WS\N@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S,V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#<*;7-G:60@(D5V97)Y(#,P
M('-E8V]N9',B"FUS9W-T<B`BPO'EZN@@,S`@\>7J\^WDZ"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS,S@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y
M,`IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(L+QY>KH(#4@[.CM
M\_+H(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H
M<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T<B`BPO'_ZNX@Z^[CXN#M
MY2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`*;7-G:60@(D5V97)Y
M(&AA;&8@:&]U<B(*;7-G<W1R("+-X"#B\>7JZ"#O[NONXNCM(/?@\2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S<@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,X.`IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@(L+Q_^K@(.SH
M[?/RX"(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(T"FUS9VED
M(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`BS_#H[.7P[>@@\?+NZ>WN\?+H
M.B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HX,2!A9&UI;B]C;61S:&5L;"YP
M:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP.C$R-PHC+"!F=7IZ>0IM<V=I9"`B
M17AE8W5T92(*;7-G<W1R("+(Y^_ZZ^W_XN#MY2#MX#HB"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT-S4*;7-G:60@(D5X<&%N9"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R
M"FUS9VED(")%>'!A;F0@4VED96)A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G
M*2<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N
M<&AP.C$W-0IM<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S
M96%R8V@@=&5R;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-@IM
M<V=I9"`B17AP;VYE;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L
M;W(B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PHC
M+"!F=7IZ>0IM<V=I9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R("+(
MY^_PX/G@[>7R[B#MX"#TX.GK[N+E(.WE(/'E(._NY.3Z\.;@+B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]S<6PN<&AP.C(Q-@IM<V=I9"`B1F%I;&5D
M(')E=')I979I;F<@<')E9F5R96YC97,N(@IM<V=S='(@(LWEXOKG[.[F[>[Q
M\B#DX"#QY2#GX/#EY/_R(._PY?3E\.7M]NCH\N4N(@H*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<U(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@
M<V5R=F5R+B(*;7-G<W1R("+-Y>+ZY^SNYNWN\?(@Y.`@\>4@[O'Z^>7Q\N+H
M(.+P^N?JX"#Q($Q$05`@\?KPXOKP+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<VUB+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"
M('-E<G9E<BXB"FUS9W-T<B`BP_#E^.K@(._PZ"#QXOKPY^+@[>4@\?KQ(%--
M0B#Q^O#B^O`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.#8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M-CDQ"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P
M>2!T;R!<(B5S7"(N(@IM<V=S='(@(L/PY?CJX"#O\.@@\>+Z\.?BX.WE(/'Z
M\2!334(@\?KPXOKP+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP
M:'`Z.#<*;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HT.3<@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,C0*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB
M"FUS9W-T<B`BP_#E^.K@(._PZ"#QXOKPY^+@[>4@\?KQ(%--0B#Q^O#B^O`N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C$*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS
M9W-T<B`BS>7B^N?L[N;M[O'R(.3@(/'E(.?@\.7D__(@[_#E].7PY>WVZ.CR
MY2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M.`IM<V=I9"`B1F%I<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&
M86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,PIM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0TQ)+T-,22YP:'`Z,C,X"B,L(&9U>GIY"FUS9VED(")&871A;"!%
M<G)O<CHB"FUS9W-T<B`BP_#E^.K@(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@(M3@
MZO$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Y"B,L(&9U>GIY
M"FUS9VED(")&87AE<R(*;7-G<W1R("+4X.KQ(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(P"FUS9VED(")&
M965L<R!,:6ME(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,S$*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I
M9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E
M<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT
M-`IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,S,S0*;7-G:60@(D9I9VQE="!#05!40TA!(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S@*;7-G
M:60@(D9I9VQE="!F;VYT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@
M(D9I:FDB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")&:6QE(@IM<V=S='(@(O3@Z>LB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(L'P[ND@].#IZ^[B
MY3H@)7,@].#IZR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV
M-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L
M('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S
M='(@(L'P[ND@].#IZ^[BY3H@)7,@].#IZ^`B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#`W"FUS9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`B
MU.#IZR#LY>W@YN7P(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HV,R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<P"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*
M;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R("+([.4@[>`@].#IZR(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y.34*;7-G:60@(D9I;&4@<V5L96-T
M:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T
M.#8*(RP@9G5Z>GD*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(LCLY2#M
MX"#TX.GK(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4Y
M"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B
MR.?O\.#YX.WE\NX@[>`@].#IZ^[BY2#MY2#QY2#O[N3D^O#FX"XB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#D*;7-G:60@(D9I;'1E<G,B"FUS
M9W-T<B`BU.CK\OKP(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B1FEN;&%N9"(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED(")&:7)S
M="!(86QF(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW-"!L
M:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U87)T97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(U-@IM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S$*;7-G:60@(D9L
M:7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G
M:60@(D9O9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3`W"B,L('!H
M<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O
M<G0@:6UA9V5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S,T"FUS9VED(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-SD*;7-G:60@(B(*(D9O<F5C87-T
M($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N
M<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@
M8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,#(*;7-G:60@(D9O<F=O="!Y
M;W5R('!A<W-W;W)D/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#8R"B,L(&9U>GIY"FUS9VED(")&;W)M<R(*;7-G<W1R("+4
M[O#S[.@B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*(RP@9G5Z>GD*
M;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`BU.[P\^SH(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.CDY"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,X"B,L(&9U>GIY"FUS9VED
M(")&;W)T=6YE<R(*;7-G<W1R("+4[O#S[.@B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,SD*(RP@9G5Z>GD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T
M<B`BU.[P\^SH(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U,PIM
M<V=I9"`B1F]R=6US(@IM<V=S='(@(M3N\//LZ"(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ,#D*(RP@9G5Z>GD*;7-G:60@(D9O<G=A<F1S(@IM
M<V=S='(@(L_PY>_PX/G@[>C_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M,PHC+"!F=7IZ>0IM<V=I9"`B1G)A;65S(@IM<V=S='(@(M3N\//LZ"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S,*(RP@9G5Z>GD*;7-G:60@(D9R86YC92(*;7-G<W1R(")/<F%N
M9V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@
M(D9R86YC92P@365T<F]P;VQI=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HX-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*
M;7-G:60@(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*
M;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`Y"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HW-`HC+"!F=7IZ>0IM<V=I9"`B1G)O;2(*;7-G<W1R("+4[O#S[.@B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0X(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS-C`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C0P-@IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"B,L(&9U>GIY"FUS9VED
M(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(L_ZZ^WN(.[OZ/'@[>CE.B(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,3<V"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C8Q('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z-C`*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R("+([.4@[>`@].#IZR(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS
M,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<U"FUS9VED(")'86UB:6$B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HT,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("+*[NWTZ./S\.#V
MZ/\B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ.`IM
M<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM
M<V=I9"`B1V5O<F=I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")'
M97)M86YY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=H86YA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.30@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-0HC
M+"!F=7IZ>0IM<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R("+([.4@[>`@].#I
MZR(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$R"FUS9VED(")';R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@
M(D=O961E;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3$R.`IM<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O
M9VQE(%-E87)C:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C,W"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S8*(RP@9G5Z>GD*;7-G:60@(D=R965C92(*;7-G
M<W1R(")'<F5E;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED
M(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.CDT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0HC
M+"!F=7IZ>0IM<V=I9"`B1W)E96YL86YD(@IM<V=S='(@(D=R965N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-`HC+"!F=7IZ>0IM<V=I9"`B1W)E;F%D82(*;7-G<W1R(")'<F5E
M;B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y"FUS9VED(")'<F]U<"!!9&UI
M;FES=')A=&EO;B(*;7-G<W1R("+`Y.SH[>CQ\O#H\.#MY2#MX"#C\//OZ"(*
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"YP:'`Z-3D@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C$V.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S
M="!B92!N;VXM96UP='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C,P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U
M<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@
M=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C$Q."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HT,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z
M(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS9W-T<B`BP_#E^.K@(._P
MZ"#HY_+PZ.+@[>4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C,S."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,S<Y"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L
M92!T;R!U<&1A=&4@9W)O=7`@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HS,30@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R
M;W5P<R(*;7-G<W1R("+#\//OZ"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=U861E
M;&]U<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U86TB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDR"B,L(&9U>GIY
M"FUS9VED(")'=65R;G-E>2(*;7-G<W1R(")'<F5Y(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`BS_#@
MXN`@Y^`@X^[Q\N@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<P
M"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.CDY"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I
M9"`B1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5I
M;F5A+4)I<W-A=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U
M>6%N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY
M-C`*;7-G:60@(DA434PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R
M96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I
M;B!R;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R
M9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L
M92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@
M<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.C$U-PIM
M<V=I9"`B2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(DA45%`@Z.3E[?+H].CJX/;H_R#MY2#E(.W@[.7PY>W@+B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,`HC+"!F=7IZ>0IM<V=I9"`B2&%I=&DB"FUS9W-T<B`BRN[E].CVZ.7M
M\B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I
M9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3$Y(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Y,S(*(RP@9G5Z>GD*;7-G:60@(DAE861E<B(*
M;7-G<W1R("+'X./KX.+H_R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP
M92]T86)L97-E="YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(DAE861E<G,B"FUS
M9W-T<B`BQ^#CZ^#BZ/\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES
M;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PIM<V=I9"`B2&5A
M=GD@5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X-@IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S0*;7-G:60@(DAE:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3<Y(&9R86UE=V]R:R](;W)D92](;W)D
M92](96QP+G!H<#HQ.#8*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@
M=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C,*;7-G:60@(DAE;'`B"FUS9W-T
M<B`BS^[L[ODB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<Q"B,L(&9U>GIY"FUS
M9VED(")(96QP97(B"FUS9W-T<B`BS^[L[ODB"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T
M:&4@9FEL93HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DAI9V@B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C
M;VUM;VXM:&5A9&5R+FEN8SHU"B,L(&9U>GIY"FUS9VED(")(;U]M92(*;7-G
M<W1R("+-X/?@Z^XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")(;VQY(%-E92`H
M5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$U,S4*;7-G:60@(DAO;64B"FUS9W-T<B`BS>#W
MX.ON(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$R,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,34U"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`BQ.[LX/CE[2#@Y/#E
M\2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-`IM<V=I9"`B2&]M92!$
M:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R
M("+$[NS@^.7M(/+EZ^7T[NTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U
M<F%S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B2&]N9R!+;VYG
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-0IM
M<V=I9"`B2&]R9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C0T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S
M86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M
M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0S-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U
M;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C$R-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B
M"FUS9W-T<B`BT_'OY?CM[B#O\.7LX/7MX/(@)R5S)R#N\B#QZ/'RY>S@\N`N
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR,C,*;7-G:60@(DAO
M<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H
M92`G9&]M>&UL)R!02%`@97AT96YS:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-3`S"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F
M;W(@;V)J96-T("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,3(T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#<T"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-
M12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q.3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<
M(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,3,S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@R"FUS
M9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R
M:7IO;G1A;#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED('EO
M=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,U
M"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE
M<F=E/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE
M<F4_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O=W,@=V]U
M;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,S`*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-3D*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED(")(=6UO
M<FES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(=6YG87)Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP
M.C$W,B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C,U"B,L('!H
M<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z
M("5S(@IM<V=S='(@(L/PY?CJX"#O\.@@\?KGY.#BX.WE(.W@($E-05`@[^[Y
MY>WQZN`@ZO/RZ/\Z("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U
M<RYP:'`Z,C$T(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR.34*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A
M:6QE9#H@)7,B"FUS9W-T<B`BP_#E^.K@(._PZ"#HY_+PZ.+@[>4@[>`@24U!
M4"#O[OGE[?'JX"#J\_+H_SH@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G5S+G!H<#HQ-SD@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP
M.C(T,@HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@
M8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("+#\.7XZN`@[^[PX.3H(.KB
M[O+@(._PZ"#Q^N?DX.+@[>4@[>`@24U!4"#O[OGE[?'JX"#J\_+H_SH@)7,B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S$V"B,L(&9U>GIY"FUS
M9VED("))4"!!9&1R97-S(@IM<V=S='(@(L#D\.7Q(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]I<&)A<VEC+G!H<#HW-PHC+"!F=7IZ>0IM<V=I9"`B25`@
M061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("))4"#@Y/#E\>`@[>4@
MY2#B(._NY^+NZ^7MZ/\@0TE$4B#AZ^[J+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I
M=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@(DE0(.#D\.7QX"#M
MY2#E(.(@[^[GXN[KY>WH_R!#2412(.'K[NHN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))4"!L
M;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.0HC+"!F=7IZ
M>0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(L+L^NKMZ"#O
M[N3PX.+MZ/+EZR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<V"FUS9VED("))
M8V]N<R!/;FQY(@IM<V=S='(@(M'@[.X@Z.KN[>@B"@HC.B!U=&EL+VEC;VY?
M8G)O=W-E<BYP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R
M("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S<*
M;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R("+(ZN[MZ"#Q(/+EZO'R
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B261E;G1I
M='DG<R!N86UE.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HU.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@
M:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@
M82!N97<@=VEN9&]W+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#4U"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N
M<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H
M96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ-S,*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E
M(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C
M86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$R-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C@*;7-G:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C$*;7-G:60@(DEM86=E(%523#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,R"FUS
M9VED("));6%G92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q
M"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C$*;7-G:60@(DEM86=E('5P;&]A
M9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I
M9"`B26UA9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN
M9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-PHC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C4T('1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@
M4W1E<"`E9"(*;7-G<W1R("+([._N\/+H\.#M[B#O[NOE.B`E<R(*"B,Z('1E
M;7!L871E<R]D871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G
M:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R("+([._N\/+H\.#M[B#O
M[NOE.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-C4*;7-G
M:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`BR.SO[O#RZ/#@[>@@[^[K
MY?+@.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS,`HC+"!F=7IZ>0IM<V=I9"`B26Y?<V5R="!2;W<@069T
M97(B"FUS9W-T<B`BPNSZZNWH(._NY/#@XNWH\N7K(@H*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,U"FUS9VED("));F-O<G)E
M8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"B,L(&9U>GIY
M"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+B(*
M;7-G<W1R("+-Y>KN\.7J\NW@(._@\.[KX"#HZ^@@[^[R\.7AZ/+EZ_'J[B#H
M[.4A(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-3$*;7-G:60@
M(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@
M5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF
M('EO=2!N965D(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,0HC+"!F=7IZ>0IM
M<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@(M/BY>OH]^#BX.WE(.W@
M(//EY.W@ZN+_XN#MY?+N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("));F1I82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U
M-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD:79I
M9'5A;"!5<V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*(RP@9G5Z>GD*
M;7-G:60@(DEN9&]N97-I82(*;7-G<W1R("+-X._PX.+E[>XB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED("))
M;F9O(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M-3<*(RP@9G5Z>GD*;7-G:60@(DEN9F]R;6%T:6]N(@IM<V=S='(@(LCM].[P
M[.#VZ/\@Y^`@PN#Q(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,S,`IM<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,U"B,L(&9U>GIY"FUS9VED("));G-E<G0@0U]O
M;'5M;B!!9G1E<B(*;7-G<W1R("+"[/KJ[>@@[^[D\.#B[>CRY>LB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C`*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!);6%G92(*;7-G<W1R("+"
M[/KJ[>@@[^[D\.#B[>CRY>LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`P"B,L(&9U>GIY"FUS9VED("));G-E<G0@5&%B
M;&4B"FUS9W-T<B`BPNSZZNWH(._NY/#@XNWH\N7K(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS97)T
M(%=E8B!,:6YK(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`HC+"!F=7IZ>0IM<V=I9"`B
M26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(L+L^NKMZ"#O[N3PX.+M
MZ/+EZR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E
M<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("))
M;G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8R"FUS9VED("));G-E<G0@82!N97<@<F]W(&%F=&5R
M('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@(DEN
M<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-S`*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T
M:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.0IM<V=I9"`B26YS
M97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS9VED("));G-E
M<G0@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,SD*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R
M97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4X"B,L(&9U>GIY"FUS9VED("));G-E<G0@8V5L
M;"!A9G1E<B(*;7-G<W1R("+"[/KJ[>@@[^[D\.#B[>CRY>LB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Y"B,L
M(&9U>GIY"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`BPNSZ
MZNWH(._NY/#@XNWH\N7K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`HC+"!F=7IZ>0IM<V=I9"`B26YS97)T
M(&-O;'5M;B!A9G1E<B(*;7-G<W1R("+"[/KJ[>@@[^[D\.#B[>CRY>LB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8U"B,L(&9U>GIY"FUS9VED("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G
M<W1R("+"[/KJ[>@@[^[D\.#B[>CRY>LB"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS97)T(&UE<W-A9V5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHT-0IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!A
M9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A
M<&@@8F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*(RP@9G5Z>GD*;7-G:60@(DEN
M<V5R="!R;W<@869T97(B"FUS9W-T<B`BPNSZZNWH(._NY/#@XNWH\N7K(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV.`HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T
M<B`BPNSZZNWH(._NY/#@XNWH\N7K(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(S,`IM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@
M=&AE('-E8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(V"FUS9VED("));G-E
M<G0O36]D:69Y($EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I
M9GD@3&EN:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B26YS=69F:6-I96YT(&-R
M961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S4*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-S4*;7-G:60@(DEN
M=&5G97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3$S,PIM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I
M9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3<P
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(P,0HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,3`*(RP@
M9G5Z>GD*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`BR.?O\.#R
MY>WH\N4@Y.#M[>@@\>`@[>7BX.OHY.WH+B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z,S0*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@87!P;&EC871I
M;VXN(@IM<V=S='(@(LW@[.7PY>WH(._PZ.ONYN7MZ/\Z("5S(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"B,L
M(&9U>GIY"FUS9VED("));G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R("+(Y^_P
MX/+E[>CRY2#DX.WMZ"#QX"#MY>+@Z^CD[>@N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C`X-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,34X
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,S(@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C(Y.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O
M=&%B;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D
M+B(*;7-G<W1R("+(Y^_PX/+E[>CRY2#DX.WMZ"#QX"#MY>+@Z^CD[>@N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`P"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP
M.C@Q"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P
M,`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR,C`*
M;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-PIM<V=I9"`B26YV86QI9"!L
M:6-E;G-E(&ME>2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$W,0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!L;V-A=&EO
M;B!P<F]V:61E9"XB"FUS9W-T<B`BR.?O\.#RY>WH\N4@Y.#M[>@@\>`@[>7B
MX.OHY.WH+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P-PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!M<V=?='EP
M92XB"FUS9W-T<B`BR.?O\.#RY>WH\N4@Y.#M[>@@\>`@[>7BX.OHY.WH+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P,PIM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R
M<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C(W
M"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<S"B,L(&9U>GIY
M"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(LCG[_#@\N7M
MZ/+E(.3@[>WH(/'@(.WEXN#KZ.3MZ"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,3<U"FUS9VED("));G9A;&ED('!R;V1U8W0@8V]D92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`V"FUS9VED("));G9A;&ED('!R;W1O8V]L+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.CDS"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z-S$@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HX,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`W
M-B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-C(*;7-G:60@(DEN=F%L
M:60@<VAA<F4@;V)J96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B26YV86QI
M9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A
M;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,U-PIM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-SD*
M;7-G:60@(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@R"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@;V8@36%N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(T"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#`*;7-G:60@(DES<F%E;"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R-0IM<V=I9"`B27-S=65R
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(LW@ZNON[>7MZ"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,@HC+"!F=7IZ>0IM<V=I9"`B271A;'DB"FUS9W-T<B`B
MS>#JZ^[MY>WH(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED(")*86UA:6-A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0S.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8U"FUS9VED(")*86YU87)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM
M<V=I9"`B2F%P86XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#<*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*;7-G:60@(B(*
M(DIA=F%S8W)I<'0@:&%S(&)E96X@9&ES86)L960@;VX@>6]U<B!B<F]W<V5R
M(&%N9"!T:&ES('!A9V4@;6%Y(&YO="!B92`B"B)D:7-P;&%Y:6YG(&-O<G)E
M8W1L>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C(*(RP@9G5Z>GD*;7-G:60@(DIE<G-E>2(*;7-G<W1R(")'<F5Y(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@S"FUS9VED(")*;W)D86XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU
M;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`HC+"!F
M=7IZ>0IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R("+K_^+N(._NY/#@XNW_XN#M
MY2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$U"B,L(&9U>GIY"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G
M<W1R("+K_^+N(._NY/#@XNW_XN#MY2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$W"FUS9VED(")*=7-T:69Y
M($9U;&PB"FUS9W-T<B`B[_KK[>X@[^[D\.#B[?_BX.WE(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G
M:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R("+K_^+N(._NY/#@XNW_XN#MY2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$V"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(N3_\>WN(._N
MY/#@XNW_XN#MY2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C8T"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#,*(RP@9G5Z>GD*;7-G:60@(DME;GEA(@IM<V=S='(@(L?@
MX?#@[>@B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@U"FUS
M9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(DME<F)E<F]S(/'Z\.+Z\.`@[O+UXOKPZ^@@Z.3E[?+H].CJ
MX/;H__+@+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B
M2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$T"FUS
M9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N9W1H(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q
M,0HC+"!F=7IZ>0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B36EM92#RZ.\B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.`HC+"!F
M=7IZ>0IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(LCG[^[KY^+@[>4Z.B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B
M2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*
M;7-G<W1R("+*Z_[WX"#BY??E(/'Z^>7Q\N+SXN`@XB#O\^'KZ/?MZ/\@ZNO^
M]_'Z\.+Z\"XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@
M(DMI9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+:7)I8F%T
M:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!$96UO
M8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED(")+;W)E86X@*$55
M0RU+4BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+=7=A:70B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+>7)G>7IS=&%N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z.`HC+"!F
M=7IZ>0IM<V=I9"`B3&%?>6]U="(*;7-G<W1R("+(Y_7NY"(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S
M='(@(L7GZ.HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G<R!$
M96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HQ-CD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-S8*(RP@9G5Z>GD*;7-G:60@(DQA<W0@
M4&%S<W=O<F0@0VAA;F=E(@IM<V=S='(@(L_@\.[KX#H@(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B
M3&%S="!1=6%R=&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,34Q"B,L(&9U>GIY"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@
M(L[O\.7Q[>@B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S(Q"B,L('!H<"UF;W)M870*
M;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$V"FUS9VED("),87-T(&QO9VEN
M.B!.979E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*(RP@9G5Z>GD*;7-G
M:60@(DQA='9I82(*;7-G<W1R("+$X.WMZ"(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0HC+"!F=7IZ
M>0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(LCG]>[D(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@
M96UP='D@9F]R(&YO(&)O<F1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*
M;7-G:60@(DQE8F%N;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"FUS9VED("),969T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3D*;7-G
M:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,Q,34*(RP@9G5Z>GD*;7-G:60@(DQE9G0@=F%L=65S(@IM
M<V=S='(@(LW_[.`@\?+NZ>WN\?+H(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"B,L(&9U>GIY
M"FUS9VED("),97-O=&AO(@IM<V=S='(@(LSE\N[D(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED("),979E;"(*
M;7-G<W1R("+-Z.KNX^`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI8F5R:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:6)Y86X@07)A8B!*
M86UA:&ER:7EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EE
M8VAT96YS=&5I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR-0HC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@1')I
M>GIL92(*;7-G<W1R("),:6=H="!";'5E(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*(RP@9G5Z>GD*;7-G:60@(DQI9VAT
M(%)A:6XB"FUS9W-T<B`BPO7NY"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!286EN($5A<FQY(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(X"FUS9VED("),:6=H="!286EN($QA=&4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G:60@
M(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P"FUS9VED("),:6=H="!286EN
M('=I=&@@5&AU;F1E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@
M4VYO=R(*;7-G<W1R("),:6=H="!";'5E(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO
M=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM
M<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@Q-`HC+"!F=7IZ>0IM<V=I9"`B3&EN:R(*;7-G<W1R("+"
M]>[D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-0IM<V=I9"`B3&EN
M:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@
M9&ES<&QA>6EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT
M97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@S"FUS9VED("),:6YK<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI
M;G5X($-O;VMI92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E
M92!T:&4@9F]L9&5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,S,*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4P"FUS9VED("),:7-T($AE;'`@5&]P
M:6-S(@IM<V=S='(@(L_N[.[Y(/+E[.@B"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3,R"FUS9VED("),:7-T(%1A8FQE<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-`IM<V=I9"`B3&ES="U!
M<F-H:79E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A
M9&5R<RYP:'`Z-3@Y"B,L(&9U>GIY"FUS9VED("),:7-T+4AE;'`B"FUS9W-T
M<B`BS^[L[OD@\N7LZ"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R
M<RYP:'`Z-3DV"FUS9VED("),:7-T+4ED(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),:7-T+4]W
M;F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R
M<RYP:'`Z-3DS"FUS9VED("),:7-T+5!O<W0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3$*;7-G:60@(DQI<W0M
M4W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M2&5A9&5R<RYP:'`Z-3DP"FUS9VED("),:7-T+55N<W5B<V-R:6)E(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM
M<V=S='(@(M'OZ/'ZZN`@\2#O[O+PY>'H\N7KZ"#E(.?@X?#@[>7M+B(*"B,Z
M(&%D;6EN+W-E<W-I;VYS+G!H<#HS-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B3&ES=&EN9R!U<V5R<R!F86EL960Z("5S(@IM<V=S='(@(M'OZ/'Z
MZN`@\2#O[O+PY>'H\N7KZ"#E(.?@X?#@[>7M+B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I
M<R!D:7-A8FQE9"XB"FUS9W-T<B`BT>_H\?KJX"#Q(._N\O#EX>CRY>OH(.4@
MY^#A\.#MY>TN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED
M("),:71E<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B
M3&ET:'5A;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEM86=E<RYP:'`Z.#,*(RP@9G5Z>GD*;7-G:60@(DQO861I;F<N
M+BXB"FUS9W-T<B`BY^#PY>;DX.WE(.W@(.'HX>OH[O+EZNCRY2XN+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3$*;7-G:60@(DQO8V%L
M('1I;64Z("(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#,*;7-G:60@(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,2!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-C0*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R
M(&QI8B]";&]C:R]M971A<BYP:'`Z-C4*(RP@9G5Z>GD*;7-G:60@(DQO8V%T
M:6]N(@IM<V=S='(@(L+@ZN#M]NC_(@H*(SH@;&]G:6XN<&AP.C$W,B!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3DQ('1E;7!L871E<R]L;V=I;B]M
M;V)I;&4N:6YC.C,*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY,`IM<V=I9"`B3&]G(&EN(@IM
M<V=S='(@(L+U[N0B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M-#4*;7-G:60@(DQO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$X-0IM<V=I
M9"`B3&]G(&]U="(*;7-G<W1R("+(Y_7NY"(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`BPO7N
MY"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<*(RP@9G5Z>GD*;7-G
M:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@(L?@Y.#WZ"(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.CDY-@IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U
M<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O
M<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP
M:'`Z.3DR"B,L(&9U>GIY"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S='(@
M(N_P[N+@Z^7M[B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C4*
M(RP@9G5Z>GD*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R("+(Y_7NY"(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B3&]V
M92(*;7-G<W1R("+/\.7LX/7MZ"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8W"FUS9VED("),;W<B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L971T97)S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA
M;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@Y"FUS9VED("),=7AE;6)O=7)G(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#`*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S."!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`BS,PB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Q"FUS9VED(")-3U1$
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N
M968N<&AP.C,V"FUS9VED(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D
M(&YO(&1A=&$N(@IM<V=S='(@(DU3+51.148@[_#HZO#E[^7MZ/_R(/3@Z>L@
M[>4@\?KD^O#FX/CE(.3@[>WH+B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I
M;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*(RP@9G5Z
M>GD*;7-G:60@(DU31R(*;7-G<W1R(")#35,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*(RP@
M9G5Z>GD*;7-G:60@(DUA8V%O(@IM<V=S='(@(L+@ZN#M]NC_(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDQ"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-
M861A9V%S8V%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT.0HC+"!F=7IZ>0IM<V=I9"`B36%G:6,B"FUS9W-T<B`BS^[YX"(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX,0IM<V=I9"`B36%I;"(*;7-G
M<W1R("+/[OG@(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R,@IM
M<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA
M:V4@;&EN7VLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"B,L(&9U>GIY
M"FUS9VED(")-86QA=VDB"FUS9W-T<B`BS^[YX"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM
M<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED
M(")-86QD:79E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*(RP@9G5Z>GD*
M;7-G:60@(DUA;&DB"FUS9W-T<B`BS^[YX"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F
M=7IZ>0IM<V=I9"`B36%L=&$B"FUS9W-T<B`BS^[YX"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY,0IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F
M(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD
M(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$Q-3,*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X-`HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$V.`IM<V=I
M9"`B36%P475E<W0@;6%P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHV-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0HC+"!F=7IZ>0IM
M<V=I9"`B36%R9VEN(@IM<V=S='(@(L+MZ.S@[>CE(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@(DUA<FL@=VET
M:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H
M(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R=&EN:7%U92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I
M9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(M'ZXN_@Y.#YZ"#O[NOE\N`B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDT"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U
M"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM
M<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`V"FUS9VED(")-87@@=&5M<"!L
M87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR.3@*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS9VED(")-87AI;75M($YU;6)E
M<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C@Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$W
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,SD*;7-G:60@(DUA>&EM
M=6T@;&5N9W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-PIM<V=I9"`B36%Y;W1T92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3`*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,38*;7-G
M:60@(DUE;6)E<G,B"FUS9W-T<B`BU^OE[>[BY2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-S@*;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`BPNCD
M(.W@(.SE[?[R[CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*;7-G<W1R("+/Z/'L[B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$V"B,L(&9U>GIY
M"FUS9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@
M=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92`B"B)V97)I
M9FEE9"XB"FUS9W-T<B`B(@HBS^CQ[.[R[B#AY?CE(._P[N+E\.7M[B#S\>_E
M^.WN+"#M[B#QY?#RZ/3HZN#RX"#MX"#O[N3OZ/'@(.WE(.'E^.4@[^[RXOKP
MY.7M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,Q,`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!E>'!I<F5D+B(*
M;7-G<W1R("+/Z/'L[B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-PHC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*(RP@9G5Z>GD*;7-G:60@
M(DUE<W-A9V4@='EP92(*;7-G<W1R("+/Z/'L[B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,PIM<V=I9"`B365T87(@5V5A=&AE<B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W"FUS9VED(")-971A<B!B;&]C:R!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$Q,@HC+"!F=7IZ>0IM<V=I9"`B(@HB365T87(@8FQO8VL@;F]T(&%V
M86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M
M:6YI<W1R871O<BXB"FUS9W-T<B`BQ.7RX.GKZ/+E(.'_]>`@\.7CZ/'R\.CP
MX.WH(.?@(.#D[.CMZ/'R\.#R[O#@+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-C4*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HV-R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<T"FUS9VED(")-971H;V0B"FUS9W-T<B`BS.7R[N0B"@HC.B!F<F%M97=O
M<FLO4E!#+U)00R]X;6QR<&,N<&AP.C@Q(&9R86UE=V]R:R]24$,O4E!#+W-O
M87`N<&AP.C$Q-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D
M(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R("+,Y?+NY"`G)7,G(.WE
M(.4@Y.7TZ.WH\.#M(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`Z
M.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#
M86QL960@;65T:&]D.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-0IM<V=I
M9"`B365T<FEC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X
M:6-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")-:6-R;VYE<VEA
M+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@HC+"!F=7IZ
M>0IM<V=I9"`B36ED9&QE(@IM<V=S='(@(O3@Z>LB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E
M(@IM<V=S='(@(DUI;64@\NCO(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,3`*;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P,@IM<V=I9"`B36EN('1E;7`@
M;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HT,SD*;7-G:60@(DUI;FEM=6T@<&%S<W=O<F0@86=E
M(&AA<R!N;W0@>65T(&5X<&ER960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-`HC+"!F=7IZ>0IM<V=I
M9"`B36ER<F]R(@IM<V=S='(@(L/PY?CJX"(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU,0IM<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W
M,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS-#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR
M-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q-0IM<V=I
M9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE
M<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC
M871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E
M($E$+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D
M869O;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E
M9"!014%2('!A8VMA9V4@36%I;"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDT"FUS9VED(")-
M:7-S:6YG('-E<W-I;VX@240N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW-`IM<V=I9"`B
M36]B:6QE($UA:6PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C@*(RP@9G5Z>GD*;7-G:60@(DUO9&5R871E
M(@IM<V=S='(@(L3@\N`@[>`@[_#N[.7M_^WE(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HV-B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C<S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#@*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B
MQ.#RX"#MX"#O\.[LY>W_[>4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV-S,*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP
M"FUS9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(U.30*;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP
M:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`BS.7QY??M[B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-`IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@
M(DUO;VX@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C$W,B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR-3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!F:65L9',@9F]U;F0@:6X@;&EN
M92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@
M0VQE87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S0*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*
M;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,#D*(RP@9G5Z>GD*;7-G:60@(DUO
M=F4@1&]W;B(*;7-G<W1R("+O\.7LY?'RZ"#MX"#D[NOS+^3_\>WN(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$S"B,L(&9U>GIY
M"FUS9VED(")-;W9E($QE9G0B"FUS9W-T<B`B[_#E[.7Q\N@@[>`@X^[PY2_K
M_^+N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$W
M"B,L(&9U>GIY"FUS9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(N_PY>SE\?+H
M(.W@(.3NZ_,OY/_Q[>XB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HU,#4*(RP@9G5Z>GD*;7-G:60@(DUO=F4@57`B"FUS9W-T<B`B
M[_#E[.7Q\N@@[>`@X^[PY2_K_^+N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`HC+"!F=7IZ>0IM<V=I9"`B36]V92!D
M;W=N(@IM<V=S='(@(N_PY>SE\?+H(.W@(.3NZ_,OY/_Q[>XB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(S"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C0*(RP@9G5Z>GD*
M;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`B[_#E[.7Q\N@@[>`@X^[PY2_K_^+N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDU"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#0*;7-G:60@(DUU;'1I
M+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U-0IM<V=I9"`B375L
M=&EM87`@54L@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R-#(*;7-G:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`P"FUS9VED(")-
M>2!!8V-O=6YT(@IM<V=S='(@(LSN__+@(,_N^>`B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z,C@*(RP@9G5Z>GD*;7-G:60@(DUY($%C8V]U;G0@26YF
M;W)M871I;VXB"FUS9W-T<B`BR.WT[O#LX/;H_R#GX"#"X/$B"@HC.B!S97)V
M:6-E<R]P;W)T86PO:6YD97@N<&AP.C4T"FUS9VED(")->2!0;W)T86PB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C$S-@IM<V=I
M9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*
M;7-G:60@(DUY86YM87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT
M96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/
M5"!!9W)E92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,3$@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$P,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H
M<#HS.`IM<V=I9"`B3F%M92(*;7-G<W1R("+([.4B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*
M;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED
M(").875R=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE<&%L
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(DYE=&AE<FQA;F1S($%N
M=&EL;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,PIM
M<V=I9"`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#4*;7-G:60@
M(DYE='-C87!E($-!('!O;&EC>2!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#0*;7-G:60@(DYE='-C87!E
M(%)E;F5W86P@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P92!2979O8V%T:6]N
M(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3@W"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@P
M"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3$*;7-G:60@(DYE='=O
M<FLB"FUS9W-T<B`BS/#EYN`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-0HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S@V"FUS9VED(").979E<B(*;7-G<W1R("+-
MZ.KNX^`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N
M86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.#$*
M(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@W
M"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HY
M-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z
M,3`Q"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E('1O("5S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W
M($UO;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB"FUS
M9W-T<B`BS>[B[B#O[O+PY>'H\N7K\>KN(.CLY2`H[N_VZ.[MX.OM[BDB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3@*;7-G:60@(DYE=R!:96%L86YD(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-PHC+"!F=7IZ>0IM<V=I
M9"`B3F5W('!A<W-W;W)D(@IM<V=S='(@(L_@\.[KX"(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*(RP@9G5Z>GD*;7-G
M:60@(DYE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(LWEZN[P
MY>KR[>`@[^#P[NO@+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M.#D*(RP@9G5Z>GD*;7-G:60@(DYE=W,B"FUS9W-T<B`BP>7KY>;JZ"(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,#4*(RP@9G5Z>GD*;7-G:60@
M(DYE=W-G<F]U<',B"FUS9W-T<B`BP_#S[^@B"@HC.B!T96UP;&%T97,O9&%T
M82]T<W9I;F9O+FEN8SHQ-2!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT
M,0HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.2!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHR-0IM<V=I9"`B3F5X="(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*;7-G:60@(DYE>'0@-"!0:&%S97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS
M-S(@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S8*(RP@9G5Z>GD*
M;7-G:60@(DYE>'0@;W!T:6]N<R(*;7-G<W1R("+.[_;HZ"(*"B,Z(&9R86UE
M=V]R:R]522]522]086=E<BYP:'`Z,3`S"FUS9VED(").97AT/B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(DYI9V5R(@IM<V=S='(@
M(LWHZN[CX"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S@P"FUS9VED
M(").:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*(RP@9G5Z>GD*;7-G
M:60@(DYI=64B"FUS9W-T<B`BT?KNX?GE[>CE(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV,PIM<V=I9"`B3F\B"FUS9W-T
M<B`BS>4B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*
M;7-G:60@(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO
M=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z,3`U"FUS9VED(").;R!A=F%I
M;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW.2!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-#4*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C8W"FUS9VED(").;R!B;&]C:R!E
M>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C4P"B,L(&9U>GIY"FUS
M9VED(").;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R("+-_^S@(.?@Y.#DY>W@(._@\.[KX"#GX"!)
M34%0(.CDY>WRZ/3HZN#VZ/\N(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z
M-30*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*(RP@9G5Z>GD*;7-G:60@(DYO(&-H
M:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S
M='(@(B<E<R<@X>7XY2#D[N'@XN7M(.KZ["#QZ/'RY>S@\N`@Y^`@[_#@XN`@
M[>`@[^[R\.7AZ/+EZ^CRY2XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C$V-R!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P,@HC.B!F<F%M
M97=O<FLO571I;"]5=&EL+G!H<#HW-S,*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B`E<RXB"FUS9W-T<B`BS?_LX"#GX.3@Y.7MX"#J[NWTZ./S\.#VZ/\@
MY^`@4U%,(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R
M-`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R($944"!61E,N(@IM<V=S='(@(LW_[.`@Y^#DX.3E[>`@ZN[M].CC
M\_#@]NC_(.?@($944"!61E,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HV-CD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R("+-_^S@(.?@Y.#DY>W@
M(.KN[?3HX_/PX/;H_R#GX"!344P@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HW,3<*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S
M='(@(LW_[.`@Y^#DX.3E[>`@ZN[M].CC\_#@]NC_(.?@(%-13"U&:6QE(%9&
M4RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,30*;7-G:60@(DYO(&-R961I="!L969T+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M-`IM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@W-PIM<V=I9"`B
M3F\@9FEL92!U<&QO861E9"(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O
M=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(X(&QI8B]";&]C
M:R]S=6YR:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R,PIM
M<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Y"B,L(&9U>GIY"FUS9VED(").
M;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`BS?_LX"#GX.3@Y.7MX"#K
M[NK@Z^CGX/;H_RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S,PHC+"!F=7IZ>0IM<V=I9"`B3F\@;65S<V%G92!S
M=7!P;&EE9"XB"FUS9W-T<B`BS?_LX"#GX.3@Y.7MX"#K[NK@Z^CGX/;H_RXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S-@HC+"!F=7IZ>0IM<V=I9"`B3F\@;F%M92!S<&5C:69I960N(@IM<V=S
M='(@(LW_[.`@Y^#DX.3E[>`@Z^[JX.OHY^#VZ/\N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*(RP@9G5Z>GD*
M;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I960N(@IM<V=S='(@(LW_[.`@Y^#D
MX.3E[>`@Z^[JX.OHY^#VZ/\N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.CDT"FUS9VED(").;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HY,0HC+"!F=7IZ>0IM
M<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(LW_[.`@Y^#DX.3E[>`@[^#P[NO@(.?@($E-05`@
MZ.3E[?+H].CJX/;H_RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N
M<&AP.C$P.`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(LW_[.`@Y^#DX.3E[>`@[^#P[NO@
M(.?@($E-05`@Z.3E[?+H].CJX/;H_RXB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VMR8C4N<&AP.C<R"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(LW_[.`@Y^#D
MX.3E[>`@[^#P[NO@(.?@($ME<F)E<F]S(.CDY>WRZ/3HZN#VZ/\N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HW-R!F<F%M97=O<FLO075T
M:"]!=71H+VQO9VEN+G!H<#HX-`HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A
M;2YP:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BS?_LX"#J[NWT
MZ./S\.#VZ.[M[>`@Z.WT[O#LX/;H_R#GX"!,1$%0(.CDY>WRZ/3HZN#VZ/\N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P87-S=V0N<&AP.C$S-0HC+"!F
M=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BS?_LX"#J[NWTZ./S\.#VZ.[M[>`@
MZ.WT[O#LX/;H_R#GX"!334(@Z.3E[?+H].CJX/;H_RXB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(LW_[.`@
MZN[M].CC\_#@]NCN[>W@(.CM].[P[.#VZ/\@Y^`@4TU"(.CDY>WRZ/3HZN#V
MZ/\N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C@V
M"FUS9VED("(B"B).;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V
M:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W
M;W)K('=I=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG
M('-I9VYU<',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HW-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0S"B,L(&9U>GIY"FUS9VED(").;R!R=6QE<R(*;7-G<W1R
M("+-_^S@(/'R[NGM[O'RZ"(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C0T.0HC+"!F=7IZ>0IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I9FEE
M9"XB"FUS9W-T<B`BS?_LX"#GX.3@Y.7MX"#K[NK@Z^CGX/;H_RXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T
M"B,L(&9U>GIY"FUS9VED(").;R!S:61E<R(*;7-G<W1R("+!Y>OEYNKH(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#,*;7-G:60@(DYO('-U
M8V@@9FEL92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,3,X"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL
M86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"B,L(&9U>GIY"FUS9VED(").
M;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`BS>7J
M[O#EZO+MX"#OX/#NZ^`@Z.OH(._N\O#EX>CRY>OQZNX@Z.SE(2(*"B,Z(&9R
M86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED(").;R!V86QI
M9"!834P@9&%T82!R971U<FYE9"(*;7-G<W1R("+"^O#MX/+H\N4@Y.#M[>@@
M[>4@\>`@6$U,(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.CDW,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.3@Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HY.3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$P,#D*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R("+-_^S@(/'R[NGM
M[O'RZ"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C`*;7-G:60@(DYO
M('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G
M96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3(X"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN
M('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N
M:6YC.CDS"B,L(&9U>GIY"FUS9VED(").;VYE(@IM<V=S='(@(LW@[_#@XN7M
M[B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DYO<F1I8R`H25-/+3@X
M-3DM,3`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R9F]L
M:R!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R
M(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P
M:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N
M($UA<FEA;F$@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G
M:60@(DYO<G=A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED
M(").;W0@0F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C0P.`HC+"!F=7IZ>0IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y
M(@IM<V=S='(@(M'ZY^3@XN#MY2#MX"#DZ/#EZO+N\.C_("5S(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HV,PHC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T
M96=Y+G!H<#HX,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-`HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2YP:'`Z-3D*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHV.`HC+"!F=7IZ>0IM<V=I9"`B3F]T('-E="(*;7-G<W1R("+!Y>OE
MYNKH(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD
M;&5R+G!H<#HQ-#,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I
M;VY(86YD;&5R+G!H<#HQ-3@*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R
M+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S,*(SH@9G)A;65W;W)K+U-E<W-I;VY(
M86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#<*(SH@9G)A;65W;W)K+U-E
M<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HR,S0@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C`U
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C(T."!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C8U"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(Y
M-PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S$R(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HS,CD*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,V,B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z-#(R"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HU,#$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4W,`HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z-3@W(&9R86UE=V]R:R]61E,O5D93+G!H<#HV-C4*(RP@
M9G5Z>GD*;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(LCG[_#@^>#M
MY?+N(.W@(/3@Z>ONXN4@[>4@\>4@[^[DY/KPYN`N(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T-"!C;VYF:6<O:&]O:W,N
M<&AP+F1I<W0Z,3`P-0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3<X
M"FUS9VED(").;W1E<R(*;7-G<W1R("+!Y>OEYNKH(@H*(SH@<V5R=FEC97,O
M;V)R;W=S97(O:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S
M92P@9V\@8F%C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,0HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S4*(RP@9G5Z>GD*;7-G:60@(DYO=F5M8F5R
M(@IM<V=S='(@(M?KY>WNXN4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,#0V"B,L(&9U>GIY"FUS9VED(").=6UB97(B"FUS9W-T<B`BU^OE[>[B
MY2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C4*;7-G:60@(DYU
M;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$S-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R
M,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0U('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB97(@
M;V8@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,S8W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C$*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,R!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F
M;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM
M<V=I9"`B3TLB"FUS9W-T<B`BSLHB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*;7-G:60@(D]B
M:F5C="!#<F5A=&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Q,#0*;7-G:60@(D]C=&%L(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3`*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS9VED(")/8W1O
M8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM
M<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,R-@HC+"!F=7IZ>0IM<V=I9"`B3V9F:6-E(@IM
M<V=S='(@(LCGZNLN(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C4X"FUS9VED(")/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F
M97)E;G0N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HS-@HC+"!F=7IZ>0IM<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@
M(L_@\.[KX"(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT-@HC
M+"!F=7IZ>0IM<V=I9"`B3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*
M;7-G<W1R("+-Y>KN\.7J\NW@(._@\.[KX"#HZ^@@[^[R\.7AZ/+EZ_'J[B#H
M[.4A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDX"B,L(&9U>GIY"FUS9VED(")/;6%N(@IM<V=S
M='(@(L+JZRXB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HW,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R
M960@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.CDU"FUS9VED(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4Q(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y-S$*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D
M9')E<W,@86QL;W=E9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S
M+V5D:70N<&AP.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T
M96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE
M<B`B"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO:69R86UE+G!H<#HS-0IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W
M:6YD;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E
M>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I
M;F1O=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*
M;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G
M<W1R("+.[_;HZ"(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS,2!T96UP;&%T
M97,O<')E9G,O87!P+FEN8SHQ-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`BSN_VZ.@B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$X"FUS9VED(")/<F1E
M<F5D($QI<W0B"FUS9W-T<B`BS^[D\.7DY>T@\>_H\?KJ(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*(RP@9G5Z>GD*;7-G:60@
M(D]R9V%N:7-A=&EO;B(*;7-G<W1R("+`Y.SH[>CQ\O#H\.#MY2(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A
M;FES871I;VYA;"!5;FET(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ,S(*(RP@9G5Z>GD*;7-G:60@(D]R9V%N:7II;F<B"FUS
M9W-T<B`B3W)A;F=E(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G
M:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G
M:60@(D]R:6=I;F%L('1E;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB
M;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3,@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$R,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,Q(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-#$*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N
M(@IM<V=S='(@(L3P\^/@(.CM].[P[.#VZ/\B"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G
M<W1R("+/\.#BX"#MX"#O\.CRY>;@\N7K_R(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<&%M+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B4$%-(&%U=&AE;G1I
M8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(L/PY?CJX"#O\.@@
MZ.3E[?+H].CJX/;H_R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE
M<FEC7W-M='`N<&AP.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$R
M-S,*;7-G:60@(E!'4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S$Y"FUS9VED(")0
M1U`@16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3,W,0IM<V=I9"`B4$=0(%!U8FQI8R!+97DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3,U,PIM<V=I9"`B4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T82(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-C@*(RP@9G5Z>GD*;7-G:60@
M(E!(4"!#;V1E(@IM<V=S='(@(DAO<F1E(@H*(SH@861M:6XO<&AP<VAE;&PN
M<&AP.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B4$=0(%-H96QL(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*;7-G
M:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@(E!-(%-H;W=E<G,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,SD*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#`*;7-G:60@(E!-(%-N
M;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT,0HC+"!F=7IZ>0IM<V=I9"`B4$T@4W5N(@IM
M<V=S='(@(E-U;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0R"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z,C<T"FUS9VED(")03U-)6"!E>'1E;G-I
M;VX@:7,@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#D*
M(RP@9G5Z>GD*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B4$=0(%-H96QL
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3D*(RP@9G5Z>GD*;7-G:60@(E!A:VES=&%N(@IM<V=S='(@(L+L^NKMZ"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DR(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I
M960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")086YA;6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")087!U82!.97<@1W5I;F5A
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,V"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,3DY"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34Q
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,3@*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHW-R!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C0S"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C,*;7-G:60@
M(E!A<W-W;W)D(@IM<V=S='(@(L_@\.[KX"(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C
M97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,3,R,@HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0@:6YC
M;W)R96-T(@IM<V=S='(@(L_@\.[KX#H@(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]R861I=7,N<&AP.C$U,@HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0@
M<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B
MS?_LX"#J[NWTZ./S\.#VZ.[M[>`@Z.WT[O#LX/;H_R#GX"!2041)55,@Z.3E
M[?+H].CJX/;H_RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#4S
M"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@(E!A
M<W-W;W)D.B(*;7-G<W1R("+/X/#NZ^`Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VUO8FEL92YI;F,Z,3$*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`BS^#P
M[NO@.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3`@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`S-`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C$U"FUS9VED(")087-S=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`B
MS>7J[O#EZO+MX"#OX/#NZ^`N(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Q
M.2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C(*;7-G:60@(E!A<W1E(@IM<V=S='(@(L+L^NKMZ"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A
M<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3$*(RP@9G5Z>GD*;7-G:60@
M(E!A=&@B"FUS9W-T<B`BPNSZZNWH(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q
M=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T"B,L(&9U>GIY"FUS9VED
M(")096]P;&4B"FUS9W-T<B`BT.[K_R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH
M=&UL.C0Y"B,L(&9U>GIY"FUS9VED(")097)F;W)M($UA:6YT96YA;F-E($]P
M97)A=&EO;G,B"FUS9W-T<B`BQ.`@\>4@Z.?B^O#XXN#R(.OH(.[A\>OSYN+@
M^>CRY2#N[^7PX/;HZ"#O\.@@PO7NY#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#`V"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@;VX@;&]G:6X_(@IM<V=S='(@(L3@(/'E(.CGXOKP^.+@\B#KZ"#NX?'K
M\^;BX/GH\N4@[N_E\.#VZ.@@[_#H(,+U[N0_(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ-38*(RP@9G5Z>GD*;7-G:60@(E!E<FUI<W-I
M;VXB"FUS9W-T<B`BS_#@XN`B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP
M.C4R"B,L('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO
M="!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C4X-@HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B
M"FUS9W-T<B`BS_#@XN`B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C$V,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V-`IM<V=I
M9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`BS_#@XN`B"@HC.B!A9&UI;B]P97)M
M<R]E9&ET+G!H<#HQ,#D@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P"B,Z
M(&%D;6EN+W!E<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N
M<&AP.C4X"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G
M<W1R("+`Y.SH[>CQ\O#H\.#MY2#MX"#O\.#BX/+@(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C8U"B,L(&9U>GIY"FUS9VED(")097)S;VYA;"!);F9O
M<FUA=&EO;B(*;7-G<W1R("+$\//CX"#H[?3N\.S@]NC_(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDX"FUS9VED(")097)U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU-0IM<V=I9"`B4&5T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3D*;7-G:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE
M(@IM<V=S='(@(M+EZ^7T[NTB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#<X"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@
M(E!L871I='5D97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L
M:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B
M4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E
M;&5M96YT.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L96%S92!C;VYF
M:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4W,0IM<V=I
M9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T<B`B
MS.[K_RP@XOKBY>3E\N4@[.7QY?8@Z"#C[N3H[>`N(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*(RP@9G5Z>GD*;7-G
M:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ
M(@IM<V=S='(@(LSNZ_\L(.+ZXN7DY?+E(.SE\>7V(.@@X^[DZ.W@+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#$*(RP@9G5Z>GD*;7-G:60@
M(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(LSN
MZ_\L(.+ZXN7DY?+E(.SE\>7V(.@@X^[DZ.W@+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(V-C`*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED
M(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-3$*
M(RP@9G5Z>GD*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED('1I;64N(@IM
M<V=S='(@(LSNZ_\L(.+ZXN7DY?+E(.SE\>7V(.@@X^[DZ.W@+B(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@(E!L96%S92!P
M<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S
M97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M
M86EN=&5N86YC92YP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(B(*(E!L96%S92!R
M96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T
M:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*(LSN
MZ_\L(._P[O?E\N7RY2#QZ^7D[>C_\B#RY>KQ\BX@(,+HY2#2T-_!PL`@Y.`@
M\>4@\?KCZ^#QZ/+E(/$@\_'K[N+H__+@(.?@("(*(NCG[^[KY^+@[>4@[>`@
M\>CQ\N7LX/+@+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R
M>4UA;F%G97(N<&AP.C<P"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A
M=&5G;W)Y(&YA;64Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0HC+"!F=7IZ
M>0IM<V=I9"`B4&]L86YD(@IM<V=S='(@(M/DY>'EZ^7MZ"(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU-PIM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X-PIM<V=I9"`B4&]L
M;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&]R='5G86PB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(W"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T
M:&ES(&EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T
M:&ES('1A8FQE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O('1H:7,@9F]L9&5R
M("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H
M;W5R*',I.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(Y.`IM<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H86YC92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O;&1A<"YP:'`Z
M.3@*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N.B!297%U
M:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(U"FUS9VED(")0<F5S<W5R92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U.0IM<V=I9"`B
M4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-0HC+"!F=7IZ>0IM<V=I9"`B4')E
M<W-U<F4Z("(*;7-G<W1R("+/X/#NZ^`Z("(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,#4*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(S"FUS9VED(")0
M<F5V:65W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T
M:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8R(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,S8V"B,L(&9U>GIY"FUS9VED(")0<F5V:6]U<R!O<'1I
M;VYS(@IM<V=S='(@(L_PY>?E[?+@]NCH(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE
M;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#(S"FUS9VED(")0<FEV871E($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38Y"B,L(&9U>GIY"FUS9VED
M(")0<F]B;&5M(@IM<V=S='(@(L_P[N'KY>P_(@H*(SH@<V5R=FEC97,O<')O
M8FQE;2YP:'`Z,3(V"B,L(&9U>GIY"FUS9VED(")0<F]B;&5M($1E<V-R:7!T
M:6]N(@IM<V=S='(@(L_ZZ^WN(.[OZ/'@[>CE.B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS-CD*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,3$@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C$X.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,C@U"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0T"FUS9VED
M(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I=F%T92!K
M97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("+*
MZ_[W[N+@(.3B[NGJX"#O\^'KZ/?E[2_WX/'RY>T@ZNO^]R#MY2#AY?CE(./E
M[>7PZ/#@[>`N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.38@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@HC+"!F=7IZ>0IM<V=I9"`B46%T
M87(B"FUS9W-T<B`BQ.#M[>@B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C,*
M;7-G:60@(E%U97)Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HW,`IM<V=I9"`B475O=&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-`IM<V=I9"`B4F%D:6\@<V5L96-T
M:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0S"B,L(&9U>GIY"FUS9VED(")286EN(@IM<V=S='(@(LKN
MY?3H]NCE[?(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT-`IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I
M;B!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0V"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-PIM
M<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!T;R!3
M;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS
M9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO(@IM<V=S='(@(LKN
MY?3H]NCE[?(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-"!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,0HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-"!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$X,`IM<V=I9"`B4F5A9"(*;7-G<W1R("+7Y?+E[>4B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PHC+"!F=7IZ>0IM<V=I
M9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R("+/Z/'L[B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@
M=6YD;VYE+B(*;7-G<W1R("+(\>K@\N4@Y.`@Z.?R\.CE\N4@)7,@Z^@_(-+@
MY^@@[N_E\.#VZ/\@[>4@[.[FY2#DX"#QY2#B^O#MY2#MX.?@Y"XB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S
M97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S
M='(@(LCQZN#RY2#DX"#HY_+PZ.7RY2`E<R#KZ#\@TN#GZ"#N[^7PX/;H_R#M
MY2#L[N;E(.3@(/'E(.+Z\.WE(.W@Y^#D+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R
M(&QA<W0@86-T:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED(")2969R
M97-H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*
M;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q"B,L(&9U>GIY"FUS
M9VED(")2969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R("+.[_#E\>WH(-#E
MY_[LY2#HY^/KY>3@.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y
M-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$S"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$R,S4*;7-G:60@(E)E9V5X(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-#D*;7-G:60@(E)E;&%T:6]N
M<VAI<"!"<F]W<V5R(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*
M(RP@9G5Z>GD*;7-G:60@(E)E;&]A9"(*;7-G<W1R("+7Y?+E[>4B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,R-@HC+"!F=7IZ>0IM<V=I9"`B4F5M87)K
M<R(*;7-G<W1R("+.\NSE\NKH(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Q-`HC+"!F=7IZ>0IM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B
MPN#XZ/+E(/'Z\.+Z\.@Z(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C@T"FUS9VED(")296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N
M8V]M+VAO<F1E*3HB"FUS9W-T<B`BP.3PY?$@55),("AH='1P.B\O=W=W+F5X
M86UP;&4N8V]M+VAO<F1E*3HB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V5D:70N:6YC.C(R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC
M.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z
M,3,*;7-G:60@(E)E;6]V92(*;7-G<W1R("+/\.7LX/7MZ"(*"B,Z('1E;7!L
M871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4F5M
M;W9E($)L;V-K(@IM<V=S='(@(L_PY>S@]>WH(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-PHC+"!F=7IZ>0IM<V=I9"`B
M4F5M;W9E(&-O;'5M;B(*;7-G<W1R("+/\.7LX/7MZ"#PY>?^[.4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0P"B,L(&9U
M>GIY"FUS9VED(")296UO=F4@9F]R;6%T=&EN9R(*;7-G<W1R("+([?3N\.S@
M]NC_(.?@(,+@\2(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(X
M"B,L(&9U>GIY"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R("+/\.7LX/7M
MZ"#PY>?^[.4B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R"FUS9VED
M(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"B,L(&9U>GIY"FUS9VED
M(")296UO=F4@=&AE(@IM<V=S='(@(L_PY>S@]>WH(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED
M(")296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*(RP@
M9G5Z>GD*;7-G:60@(E)E;6]V92!U<V5R(@IM<V=S='(@(L_PY>S@]>WH(._N
M\O#EX>CRY>LZ("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R.B`E<R(*
M;7-G<W1R("+/\.7LX/7MZ"#O[O+PY>'H\N7K.B`E<R(*"B,Z(&9R86UE=V]R
M:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X"B,L(&9U>GIY"FUS9VED(")297%U
M97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z
M("(*;7-G<W1R("+-X"#GX._H\N+@[>7R[B#MY2#AY?CE(.[RX^[B[O#E[>XZ
M("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*(RP@9G5Z
M>GD*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N
M9"XB"FUS9W-T<B`BS>`@Y^#OZ/+BX.WE\NX@[>4@X>7XY2#N\N/NXN[PY>WN
M.B`B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-"!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`BS>7NX?7NY.CLZ/\@)W!O<G0G(.WE(.4@
MY^#DX.3E[2#B^N(@5D93(.KN[?3HX_/PX/;H__+@+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z-C<U(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z.#,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,C,*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N
M;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+-
MY>[A]>[DZ.SH_R`G<&]R="<@[>4@Y2#GX.3@Y.7M(.+ZXB!61E,@ZN[M].CC
M\_#@]NC_\N`N(@H*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S@Q"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T
M('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+-Y>[A]>[D
MZ.SH_R`G<&]R="<@[>4@Y2#GX.3@Y.7M(.+ZXB!61E,@ZN[M].CC\_#@]NC_
M\N`N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S,U
M"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,SD*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S(P('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#8*(RP@9G5Z>GD*;7-G:60@(E)E
M<V5T(%!A<W-W;W)D(@IM<V=S='(@(L_@\.[KX"(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C(W"B,L(&9U>GIY"FUS9VED(")297-E="!9;W5R
M(%!A<W-W;W)D(@IM<V=S='(@(L_N\N+Z\.3E\N4@[^#P[NO@\N`B"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3,P"FUS9VED(")297-T;W)E($QA<W0@475E
M<GDB"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C<Q(&%D;6EN
M+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S<6QS:&5L;"YP:'`Z-C8*;7-G:60@
M(E)E<W5L=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C$P,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2
M971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z,S@*;7-G:60@(E)E='EP92!N97<@<&%S<W=O<F0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F5U;FEO;B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(E)E=F5R="!#;VYF
M:6=U<F%T:6]N(@IM<V=S='(@(LKN[?3HX_/PX/;H_R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,S(*(RP@9G5Z>GD*;7-G:60@(E)I8V@@5&5X="!%
M9&ET;W(@3W!T:6]N<R(*;7-G<W1R(")$2%1-3"!2:6-H(%1E>'0@\.7DX.KR
M[O`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L
M97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<P"FUS9VED(")2:6=H="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(Q"FUS9VED(")2:6=H="!H
M96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S$Q-PHC+"!F=7IZ>0IM<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@(DQI
M9VAT($)L=64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(M#NZ_\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C4*;7-G:60@(E)O=&%T
M92`Q.#`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(R,@IM<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R
M.`IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G:60@
M(E)O=R!0<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P
M<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4S"B,L(&9U>GIY"FUS9VED(")2=6QE<R(*;7-G<W1R("+0[NO_(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W
M<R!A;F0@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W
M:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL
M>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P"B,L(&9U
M>GIY"FUS9VED(")2=6XB"FUS9W-T<B`B4W5N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM
M<V=I9"`B4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#,*(RP@9G5Z>GD*;7-G:60@(E)W86YD82(*;7-G<W1R("+7Y?+E[>4B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I
M9"`B4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S(S"B,L(&9U
M>GIY"FUS9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B
MP_#E^.K@(._PZ"!334E-12#J\.CO\NCPX.WE\NX@[>`@[^CQ[.XN(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX,0HC+"!F=7IZ>0IM<V=I
M9"`B4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R("+#\.7XZN`@[_#H(.CDY>WRZ/3HZN#VZ/\B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-3`T"B,L(&9U>GIY"FUS9VED(")335,@365S<V%G
M:6YG(@IM<V=S='(@(L_H\>SN(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q
M"FUS9VED(")344P@4VAE;&PB"FUS9W-T<B`B4U%,(%-H96QL(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,PIM<V=I9"`B4U%,('-T871E;65N
M="!F;W(@=F%L=64@;&]O:W5P<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#,Q"FUS9VED(")34T@B"FUS9W-T<B`B4U-((@H*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R("(B"@HC
M.B!L:6(O87!I+G!H<#HQ-3,*(RP@9G5Z>GD*;7-G:60@(E-?44P@4VAE;&PB
M"FUS9W-T<B`B4U%,(%-H96QL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-
M:7%U96QO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")386EN
M="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED
M(")386UE(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-PIM<V=I9"`B4V%M;V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I
M9"`B4V%N($UA<FEN;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED
M(")386\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R
M;W9I9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I
M($%R86)I82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U
M="YI;F,Z.3@*;7-G:60@(E-A=F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3879E(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C(Q-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V
M92`E<R(*;7-G<W1R("+.[_#E\>WH("5S(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V5N9"YI;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S
M='(@(L[O]NCH(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-PIM<V=I
M9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S
M8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`BRN[M].CC\_#@]NC_(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*;7-G:60@
M(E-C871T97)E9"!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C:"(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(P"FUS9VED(")396%R
M8V@@16YG:6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.3<S"B,L(&9U>GIY"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T
M<B`BR.?AY?#H(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0X-`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G
M<W1R("+(Y^'E\.7RY2#Q^O#B^O`B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$Y.`IM<V=I9"`B4V5L96-T(&$@9W)O=7`@=&\@861D(@IM<V=S
M='(@(LCGX>7PY?+E(./P\^_@(.?@(.3NX>#B_^WE(@H*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R
M(@IM<V=S='(@(LCGX>7PY?+E(.WNXB#O\.CRY>;@\N7K(.W@(./P\^_@(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS9VED(")396QE
M8W0@82!S97)V97(B"FUS9W-T<B`BR.?AY?#E\N4@\?KPXOKP(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C="!A('5S
M97(@=&\@861D(@IM<V=S='(@(LCGX>7PZ"#O[O+PY>'H\N7K(.?@(.3NX>#B
M_^WE(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C8W-PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R("+(Y^'E
M\.@B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8S"B,L(&9U>GIY
M"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`B
MR.?AY?#E\N4@].[P[.#R(.?@(,3@\N#RX#HB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"B,L(&9U>GIY"FUS9VED(")3
M96QE8W0@86X@;V)J96-T(@IM<V=S='(@(LCGX>7PY?+E(.WNXB#O\.CRY>;@
M\N7K(.W@(./P\^_@(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C8W.`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&YO;F4B"FUS
M9W-T<B`BR.?AY?#E\N4@[>[B(._PZ/+EYN#RY>L@[>`@X_#S[^`B"@HC.B!S
M97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(B(*(E-E
M;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B
M96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O
M;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B+(Y^'E\.7RY2#MY>[A]>[D
MZ.SH\N4@PN@@\>CLXN[KZ"X@T>OEY"#R[N+@(./H(.KN[^CPX.GRY2#N\B#R
MY>KQ\N[B[O+N(._NZ^4N(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z(@IM<V=S='(@
M(LCGX>7PY?+E(,3@\N`@\.#GY.7KZ/+EZSHB"@HC.B!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT-`IM<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB
M"FUS9W-T<B`BR.?AY?#E\N4@].[P[.#R(.?@(,3@\N#RX#HB"@HC.B!T96UP
M;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDP"FUS9VED(")396QE
M8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93HB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,38*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S='(@(LCGX>7P
MY?+E(,3@\N`@\.#GY.7KZ/+EZSHB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE
M+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T
M<B`BR.?AY?#E\N4@].[P[.#R(.?@(-?@\>`Z(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHU-PIM<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F
M:65L9',N(@IM<V=S='(@(LCGX>7PY?+E(.3BY2#Q^N+OX.3@^>@@[^[KY?+@
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#8*;7-G:60@(E-E;&5C
M="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`BR.?AY?#E\N4@XN#XX/+@
M(/'UY>S@(.?@(/;BY?+NXN7RY2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C0X"FUS9VED(")396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z
M(@IM<V=S='(@(LCGX>7PY?+E(._PY>3O[O?H\N#MZ/_R(.[R(,+@\2#EY^CJ
M.B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED
M(")396YD(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#,Y"FUS9VED(")396YD
M(%--4R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")396YE9V%L
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$V"FUS9VED
M(")396YS;W(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`Y"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW,PHC+"!F=7IZ>0IM<V=I9"`B4V5P=&5M8F5R
M(@IM<V=S='(@(M?KY>WNXN4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-S`Q"FUS9VED(")397)I86P@3G5M8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*;7-G:60@(E-E<G9E<B!D871A
M('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;B!!9&UI
M;B(*;7-G<W1R("+`Y.SH[>CQ\O#H\.#MY2#MX"#O\.#BX/+@(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS
M9VED(")397-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z(&QI8B]A
M<&DN<&AP.C$T-0HC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B
MS_#@XN`B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$T"B,L(&9U
M>GIY"FUS9VED(")3970B"FUS9W-T<B`BR.?AY?#H(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<V"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y
M;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@
M:70N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*
M;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O
M(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#0*(RP@9G5Z>GD*;7-G:60@(E-E="!Y;W5R
M('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N
M<RXB"FUS9W-T<B`BR.?AY?#E\N4@[_#EY._N]^CRX.WH__(@[O(@PN#Q(.7G
MZ.HZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX"FUS9VED("(B"B)3
M970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A
M9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB
M"FUS9W-T<B`B(@HBQ^#DX.GRY2#"X/CE\NX@[>#WX.OM[B#O\.CK[N;E[>CE
M+"#Q]>7LX"#GX"#VXN7R[N+E+"#N[_#E\>W_XN#MY2#MX"`B"B+Q\O#@[>CV
MX/+@(.@@Y/#SX^@@[N_VZ.@@Y^`@Y.CQ[^OE_RXB"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C<U"FUS9VED(")3971U<"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS-PIM<V=I9"`B4V5T
M=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3@V"FUS9VED(")3979E<F%L
M(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L;&5S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.38*;7-G:60@
M(E-H;W!P:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C0S"B,L(&9U>GIY"FUS9VED(")3:&]R="!3=6UM87)Y(@IM
M<V=S='(@(LKPX/+J[B#PY>?^[.4Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0T-@IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@
M9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,S(S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3$S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(L_N
MZN#GXN#MY2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@
M(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@
M86YD('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y,`IM<V=I9"`B
M4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8U"FUS9VED(")3
M:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3,*(RP@9G5Z>GD*;7-G:60@(E-H
M;W<@<&EC:V5R(@IM<V=S='(@(LCGX>CPX.WE(.W@(/;B__(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3(V"FUS9VED(")3:&]W('1A8FQE(&]P97)A
M=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@
M365N=2!O;B!T:&4@;&5F=#\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3
M:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV-`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D
M:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L
M92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS
M9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8S"FUS9VED(")3
M:&]W('5P;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B4VAO=V5R<R(*
M;7-G<W1R("+/[NK@Y^+@[>4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU,0IM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M,@IM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W97)S
M(&EN('1H92!6:6-I;FET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HT.#`*;7-G:60@(E-H<FEN:R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW-S0@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.#,V"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.CDR,B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HY.#0*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z,3`T-R!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HQ,#@W"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C$Q,38@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$T
M.0IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I
M(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#4*;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8U"FUS9VED(")3:6=N('5P(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-S$R"FUS9VED(")3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3$*;7-G:60@(E-I9VYA='5R92!!
M;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN
M9V%P;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C4@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HW,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C@W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,C$U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M,S<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.3,P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,C,*;7-G:60@(E-I>F4B"FUS9W-T<B`BT.#G[.7P(@H*(SH@=&5M<&QA
M=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K
M:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I
M9"`B4VQO=F%K:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B
M4VQO=F5N:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(E-N;W<B"FUS9W-T
M<B`BS^[JX.?BX.WE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-34*;7-G:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V"FUS9VED
M(")3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G:60@(E-N;W<@4VAO=V5R<R!%
M87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S@*;7-G:60@(E-N;W<@
M9&5P=&@Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X
M,@IM<V=I9"`B4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED(")3;VYG<R`F
M(%!O96US(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Y,C8*;7-G:60@(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-34Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3@Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR-#<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HQ.#D*(RP@9G5Z>GD*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM<V=S
M='(@(L'HY^WE\2#@Y/#E\2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(E-O=71H
M($%F<FEC82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y
M,`IM<V=I9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE
M(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM<V=I9"`B
M4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@
M8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A
M8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX,34*;7-G:60@(E-P
M86-E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4U"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#`*;7-G:60@(E-P86-I;F<B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDX"FUS9VED(")3<&%M(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA
M;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`BPOKBY>;DX.WE(.W@(/'OY?;H
MX.OMZ"#QZ.SB[NOH(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8V"B,L(&9U>GIY"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T
M<B`BR.?AY?#E\N4@ZN[K[NWH.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*;7-G:60@
M(E-P;W)T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(E-R:2!,
M86YK82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-S,@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-`HC+"!F=7IZ>0IM<V=I9"`B
M4W1A;F1A<F0B"FUS9W-T<B`B)7,@T?+@[>3@\/(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DV(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X,#D*;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@
M(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-0HC+"!F=7IZ
M>0IM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`BR.WT[O#LX/;H_R#G
MX"#"X/$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W
M,@HC+"!F=7IZ>0IM<V=I9"`B4W1R965T($%D9')E<W,B"FUS9W-T<B`BP>CG
M[>7Q(.#D\.7Q(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,S"FUS9VED(")3=')I;F<@
M;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.#<S"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"B,L
M(&9U>GIY"FUS9VED(")3=2(*;7-G<W1R(")3=6XB"@HC.B!U=&EL+VEC;VY?
M8G)O=W-E<BYP:'`Z,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U
M8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("+1Z_/XX/+E
MZ__R("5S(.WE(.4@[>#LY?#E[2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C<S"B,L(&9U>GIY"FUS9VED(")3=6)J96-T
M(@IM<V=S='(@(LCGX>7PZ"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,S,B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3<*;7-G
M:60@(E-U8FUI="(*;7-G<W1R("+(Y^_PX/+H(@H*(SH@<VEG;G5P+G!H<#HT
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T
M;R!A9&0@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I
M;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@:&%S(&)E96X@87!P<F]V960N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(*(RP@9G5Z>GD*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R("+(
MY^_PX/+H(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P-`HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N
M<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S='(@(M/Q[^7U(@H*(SH@861M
M:6XO=7-E<BYP:'`Z.#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U
M8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2XB"FUS9W-T
M<B`BT_'OY?CM[B#D[N'@XN7M("<E<R<@ZOKL(/'H\?+E[.#RX"XB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R
M;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`BT_'OY?CM[B#O\.7LX/7MX/(@)R5S
M)R#N\B#QZ/'RY>S@\N`N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI
M;B]P97)M<R]D96QE=&4N<&AP.C0V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N(@IM<V=S='(@(M/Q
M[^7X[>X@Z.?R\.CR("<E<R<N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E
M9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("+3\>_E^.WN(._P
MY>S@]>W@\B`G)7,G(.[R(/'H\?+E[.#RX"XB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N
M9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@7"(E<UPB(@IM<V=S
M='(@(M/Q[^7X[>X@X>7XY2#NX>WNXN7M("<E<R<N(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E
M<R(*;7-G<W1R("+3\>_E^.WN(.'E^.4@[N'M[N+E[2`G)7,G+B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#0*(RP@9G5Z>GD*;7-G:60@(E-U9&%N(@IM<V=S='(@(E-U;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-38*(RP@9G5Z>GD*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`BRO#@\NKN
M(/#EY_[LY3HB"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C4*;7-G:60@
M(E-U;B!2:7-E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H
M<#HV.`HC+"!F=7IZ>0IM<V=I9"`B4W5N(%-E="(*;7-G<W1R(")3=6XB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.0HC+"!F
M=7IZ>0IM<V=I9"`B4W5N;GDB"FUS9W-T<B`B4W5N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(Q-@HC+"!F=7IZ>0IM<V=I9"`B4W5N<FES
M92(*;7-G<W1R(")3=6XB"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,34*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C$Y"B,L(&9U>GIY"FUS9VED(")3=6YS970B
M"FUS9W-T<B`B4W5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Q.`IM<V=I9"`B4W5N<V5T.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S
M8W)I<'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,W.`IM<V=I9"`B4W5P<&]R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V
M"B,L(&9U>GIY"FUS9VED(")3=7)I;F%M92(*;7-G<W1R("+AY><@Z.SE(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S0*(RP@9G5Z
M>GD*;7-G:60@(E-U<FYA;64B"FUS9W-T<B`BX>7G(.CLY2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#4*;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*;7-G:60@(E-Y;F,@;&]G(&1E
M;&5T960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T
M,@IM<V=I9"`B4WEN8TU,(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO
M4U%,+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E
M87)C:"!T97)M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")3
M>7)I86X@07)A8B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,`IM<V=I9"`B5"U3=&]R;2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV,0IM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G
M:60@(E0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8S"FUS9VED(")4+5-T;W)M<R!%87)L>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,38V
M"B,L(&9U>GIY"FUS9VED(")44U8@9FEL92(*;7-G<W1R("+TX.GK(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U1A8FQE+G!H<#HQ,S0*(RP@9G5Z>GD*;7-G:60@
M(E1A8FQE(@IM<V=S='(@(L3K^N;M[O'R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@
M4')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+U1Y<&4O=&%B;&5S970N<&AP.C4W"FUS9VED(")486)L92!3970B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-"!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")486EW86XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G
M:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.34*(RP@9G5Z>GD*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B
MR.?O[NOGXN#MY3HZ(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDY-B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@W"FUS9VED(")487-K<R(*;7-G
M<W1R("+'X.3@]^@B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4W,PIM<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y,`IM<V=I9"`B5&5M<"!F;W(@;&%S
M="!H;W5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,30*;7-G:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,C,*;7-G:60@(E1E;7!E<F%T=7)E.B`B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")496UP97)A='5R93QB<B`O/B@E<TAI
M)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]4
M96UP;&%T92]496UP;&%T92YP:'`Z-C@W"B,L('!H<"UF;W)M870*;7-G:60@
M(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W1E;7!L871E<RYP:'`Z,38Y"B,L(&9U>GIY"FUS9VED(")496UP;&%T
M92!!9&UI;FES=')A=&EO;B(*;7-G<W1R("+`Y.SH[>CQ\O#H\.#MY2#MX"#O
M[O+PY>'H\N7KZ/+E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q
M,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,V"B,L(&9U>GIY"FUS9VED
M(")497AT(@IM<V=S='(@(M'@[.X@\N7J\?(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S<U"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`BT>#L[B#R
MY>KQ\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-S0*(RP@9G5Z>GD*;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T
M<B`BT>#L[B#RY>KQ\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I
M9"`B5&@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*
M;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#D*;7-G:60@(E1H86EL86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.CDX.`IM<V=I9"`B5&AA;FL@>6]U(&9O<B!U<VEN9R!T
M:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C@R,`IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B
M(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]";V]K+G!H
M<#HQ,CDR"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I
M86QI>F5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP
M:'`Z,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@
M;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:6UA
M9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN
M9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C$Q(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C4R
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C8T(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O
M<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@
M8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T;VT@<VED92!O;FQY(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@
M=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N
M9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0HC+"!F=7IZ>0IM<V=I
M9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R
M(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@HBTN7GZ"#DX.WMZ"#GX"#J[NWR
MX.KR(.'_]>`@\_'OY?CM[B#D[N'@XN7MZ"#J^NP@PN#XX/+@(._P[N/PX.S@
M+B#*Z^CJ[>7RY2#O[BTB"B+D[NOS(.?@(.3@(.+HY.CRY3HB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38Y"FUS9VED("(B"B)4:&4@
M9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V
M97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"B+/\.CJ\.7O
MY>WH__(@4$=0(._NY._H\2#E(.WE[N'U[N3H["#GX"#DX"#QY2#O\.[BY?#H
M(._NY._H\>#M[O+N(._H\>SN+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I
M8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T
M(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO
M="!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="YP:'`Z,3$S"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R
M97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("+*\.CO
M\NCPX.WE\NX@Z.?H\>KBX"#J\.CO\NCPX.W@('=E8B#B\/KGZN`N(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S4@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HU,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@
M)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V."!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL
M92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,3D*;7-G:60@
M(E1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.#`*(RP@9G5Z
M>GD*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R
M(")-4RU43D5&(._PZ.KPY>_E[>C_\B#TX.GK(.WE(/'ZY/KPYN#XY2#DX.WM
MZ"XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP
M.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@
M=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4V"FUS9VED
M("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P
M<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O
M=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N
M("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E(&1I<W!L87DL(&QA
M8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@
M8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G
M<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"`B"B)0
M<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U
M(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U
M('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T
M960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T+6AA;F0@<VED
M92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G50
M1R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA
M<W,N(@IM<V=S='(@(B(*(LSE\?+N[^[K[N;E[>CE\NX@[>`@1VYU4$<@].#I
MZ^`@\O#_X>+@(.3@(.'ZY.4@Y.#DY>UO(.W@($-R>7!T7W!G<#HZ(&-L87,B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,C`Q"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@
M=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4
M:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N
M(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3@W-PIM<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H
M96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T,0HC+"!F=7IZ>0IM<V=I
M9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*;7-G
M<W1R("+2X.?H(/'R[NGM[O'R(/+P_^'BX"#DX"#E(/?H\>ON+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(S,0HC+"!F=7IZ>0IM
M<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@
M2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`BS.[D\^OZ\B!/
M<&5N4U-,(.4@[>7NX?7NY.CL(.?@($-R>7!T7W-M:6UE.CH@8VQA<W,N(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+G!H<#HR.3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B
M92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M87AI
M;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@
M='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T
M<B`B(@HBS_#NX_#@[.#RX"P@ZN[_\NX@\>OSYN@@Y^`@[^[JX.?BX.WE(.W@
M(/+NY^@@\NCO(.3@[>WH("@E<RD@[>4@X>7XY2#N\NKPZ/+@("(*(N(@\>CQ
M\N7LX/+@(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#4T"FUS
M9VED(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C
M:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A
M;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H
M92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HT-#8*;7-G:60@(E1H92!S97!A<F%T;W(@
M;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@
M<V%V960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA
M<R!B965N(')E;6]V960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C,S,`IM<V=I9"`B5&AE('-P96-I9FEE9"!R
M;W<@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,3<W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*
M;7-G<W1R(")(;W)D92!03R#TX.GK(.?@(.ONZN#KZ.?@]NC_("5S(.WE(/'Z
M^>7Q\N+SXN`Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Q,0IM
M<V=I9"`B5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@
M=&5X="!O;B!T:&4@<V-R965N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED(")4
M:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P
M"FUS9VED(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1&%T82]$871A+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO861E9"!D
M871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R86UE
M=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO861E
M9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0V(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HU-@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3$U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,3D*;7-G:60@(E1H
M92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R
M("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$W
M.`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA
M8FQE+B(*;7-G<W1R("+-_^S@(.3B[NGJZ"P@ZN[H\NX@Y.`@X?KDX/(@[^[J
MX.?@[>@@XB#KZ.WH__+@+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C,T,@IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@
M8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(LW_[.`@Y.+NZ>KH
M+"#J[NCR[B#DX"#A^N3@\B#O[NK@Y^#MZ"#B(.OH[>C_\N`N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30P,0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I
M96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[("(*(GEO=2!M
M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@HBR.S@(/+B^O#D
MY2#L[>[C[B#QZ.SB[NOH(.(@\N[BX"#O[NOE+B#"^N+EZ^@@\?+E("5S(/'H
M[.+NZ^`[(/+P_^'BX"#DX"`B"B+B^N+EY.7RY2#O[BWLX.OJ[B#N\B`E<RXB
M"@HC.B!S:6=N=7`N<&AP.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN
M9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`BP_#E^.K@(._P
MZ"#D[N'@XO_MY2#MX"`G)7,G(.KZ["#QZ/'RY>S@\N`N(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB
M(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(L/PY?CJX"#O\.@@[_#E[.#U
MXN#MY?+N(.W@("<E<R<@[O(@\>CQ\N7LX/+@+B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$P,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B
M"FUS9W-T<B`BP_#E^.K@(._PZ"#O\.7LX/7BX.WE\NX@[>`@)R5S)R#N\B#Q
MZ/'RY>S@\N`N(@H*(SH@861M:6XO=7-E<BYP:'`Z,34Y"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG
M(%PB)7-<(CH@)7,B"FUS9W-T<B`BP_#E^.K@(._PZ"#N[_#E\>W_XN#MY2#M
MX"`G)7,G.B`E<R(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP
M.C@X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M
M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM
M<V=S='(@(L/PY?CJX"#O\.@@Z.?O\.#YX.WE\NX@[>`@].#IZ^`Z("5S(.WE
M(.'E^.4@Z.?O\.#RY>TN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E
M<BYP:'`Z.#@Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A
M('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R
M9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B>71E
M<RDN(@IM<V=S='(@(B(*(LCLX/CE(._P[N'KY>P@[_#H(.CG[_#@^>#MY?+N
M(.W@(/3@Z>O@+B`E<R#E(._N+>/NZ__L(.[R(.S@ZO'H[.#K[>X@(@HBY.[O
M\_'RZ.SH_R#PX.?LY?`@*"5D(.'@Z?+@*2XB"@HC.B!F<F%M97=O<FLO0G)O
M=W-E<B]"<F]W<V5R+G!H<#HX.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE
M("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"XB"FUS9W-T<B`BP_#E
M^.K@(._PZ"#HY^_PX/G@[>7R[B#MX"#TX.GKX"X@)7,@X>7XY2#QX.SN(.[R
M]^#Q\N@@Z.?O\.#RY>TN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HS-0HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B
MP_#E^.K@(._PZ"#O\.[BY?#JX/+@(.W@(/+NXN`@[^CQ[.XN(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*
M;7-G<W1R("+#\.7XZN`@[_#H(.CL[^[P\B#MX"#DX.WMZ"#GX"#J[NWRX.KR
MZ"XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+VEM8RYP:'`Z,S$*(RP@9G5Z
M>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#
M86QE;F1A<B!D871A+B(*;7-G<W1R("+#\.7XZN`@[_#H(.CL[^[P\NCPX.WE
M(.W@(.CGX?#@[>CRY2#DX.WMZ"#GX"#JX.OE[>3@\"XB"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C@P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R
M;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F
M="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G
M:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C
M:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G
M86EN(&QA=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`HC+"!F=7IZ>0IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I
M;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(L/PY?CJX"#O
M\.@@Z.SO[O#R(.W@(.3@[>WH(.?@(.KN[?+@ZO+H+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(R"B,L(&9U>GIY"FUS
M9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R
M:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R
M("+#\.7XZN`@[_#H(.CL[^[P\B#MX"#DX.WMZ"#GX"#J[NWRX.KRZ"XB"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*;7-G
M:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG
M(&9O;&1E<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R
M('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(M+NXN`@[>4@
MY2#BX.OHY.7M(')A<B#@\/7HXBXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A
M<B!T;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R("+2[N+@(.WE(.4@
MXN#KZ.3E[2!Z:7`@].#IZRXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,30U"B,L(&9U>GIY"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@
M8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`BTN[BX"#MY2#E(.+@
MZ^CDY>T@<F%R(.#P]>CB+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@
M86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA
M=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN
M9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HQ,S0*;7-G:60@(B(*(E1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H
M:'1T<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W87DL('5S:6YG('1H92!(5%10
M($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL
M;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL
M("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE
M($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U"FUS9VED("(B"B)4:&ES(&1R
M:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O
M=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O
M9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@
M=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-S@@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`U-PHC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,#@V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,34*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X,B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C4V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#4@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Y.`HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-34W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,SD*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DU."!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,#`U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M,CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`W.`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,30Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R
M,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q,"!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-#4T"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(V-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@R.`HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,3,W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,S,#8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@Q-"!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS.#(R"FUS9VED(")4:&ES(&9I96QD(&ES(')E
M<75I<F5D+B(*;7-G<W1R("+2[N+@(._NZ^4@Y2#MY>[A]>[DZ.SN+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C4*;7-G:60@(E1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB"FUS9W-T<B`BTN[BX"#O
M[NOE(.SNYN4@Y.`@\?KD^O#FX"#QX.SN(/;EZ^@@]^CQZ^`N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q.`IM<V=I9"`B5&AI<R!F:65L9"!M
M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BXB"FUS9W-T
M<B`BTN[BX"#O[NOE(.SNYN4@Y.`@\?KD^O#FX"#QX.SN(/?H\>O@(.@@Y.+N
MY?+N]^CE+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.30*(RP@
M9G5Z>GD*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A
M;"!V86QU97,N(@IM<V=S='(@(M+NXN`@[^[KY2#L[N;E(.3@(/'ZY/KPYN`@
M\>#L[B#M[NSE\.`N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$R
M,PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@
M<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T<B`BTN[BX"#O[NOE
M(/+P_^'BX"#DX"#E(.?@[^7RX/\@Z.OH(.CM\N7PXN#K(/#@Y^3EZ^7M(/'O
MZ/'ZZB#O\.[LY>WKZ.+H(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.3@Y"B,L(&9U>GIY"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI
M9"!N=6UB97(N(@IM<V=S='(@(M+@Y^@@\?+NZ>WN\?(@\O#_X>+@(.3@(.4@
M]^CQZ^XN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@S-@IM<V=I
M9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN
M('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU-C$*
M;7-G:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB
M"FUS9W-T<B`BTN#GZ"#T[O#LX"#BY??E(.'E^.4@[N'PX.'N\N7MX"XB"@HC
M.B!T96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&ES(&ES("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C0U.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES
M(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B
M:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N
M9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L
M:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z-3DQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@;65S<V%G92!W87,@
M=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO
M=7(@;W=N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S
M="!O;F4N(@IM<V=S='(@(M+NXN`@]^CQZ^X@\O#_X>+@(.3@(.4@[^[MY2#E
MY.CMZ/;@+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP
M+G!H<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z
M:7`@86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@(M+NY^@@\?KPXOKP(.WE(.SN
MYN4@Y.`@Y.7J[NSO\.7QZ/#@('II<"#H(&=Z:7`@].#IZ^[BY2XB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$X.0IM<V=I9"`B
M5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-`IM<V=I
M9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R("+2X.?H
M(/'R[NGM[O'R(/+P_^'BX"#DX"#E(/?H\>ON+B(*"B,Z('-E<G9I8V5S+VEM
M86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU
M<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*
M;7-G:60@(E1H=6YD97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(S-`IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#(X('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B5&EM92(*;7-G<W1R("+$
MZ_KF[>[Q\B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#8*;7-G
M:60@(E1I;64@5')A8VMI;F<B"FUS9W-T<B`BS_#N\>OEY/_BX.WE(.WE(.+P
MY>SE(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W"FUS9VED(")4:6UE(&9O
M<FUA="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-3,Y"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$P"FUS9VED(")4:6UO<BU,97-T92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C(P"FUS9VED(")4:71L92(*;7-G<W1R("+$Z_KF[>[Q
M\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.38*;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B
M5&\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C8U-`IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET
M96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-
M86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,0HC+"!F=7IZ>0IM<V=I9"`B
M5&]D87DB"FUS9W-T<B`B("CD[>7Q*2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O
M=7)C92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"B,L(&9U>GIY"FUS9VED
M(")4;V=O(@IM<V=S='(@(LCG]>[D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B
M5&]K96QA=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S$S"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S<*;7-G:60@(E1O
M<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PHC+"!F=7IZ>0IM<V=I
M9"`B5')A;G-L871I;VYS(@IM<V=S='(@(L_PY>?E[?+@]NCH(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,0IM<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-SDP"FUS9VED(")4<G5E
M(&]R(&9A;'-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,0HC+"!F=7IZ>0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(D=R97DB
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,@IM<V=I9"`B5'5R:VES:"`H
M25-/+3@X-3DM.2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B
M5'5R:VUE;FES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@
M(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-,22]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-CD*
M;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A
M;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@
M(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.CDW"B,L(&9U>GIY"FUS9VED(")54DPZ(@IM<V=S='(@(E523"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5G86YD82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$R"B,L(&9U>GIY"FUS9VED(")5:W)A:6YE(@IM<V=S='(@(L_N
MY/?E\/+@[>@B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,3(*
M(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R
M>2XB"FUS9W-T<B`BP_#E^.K@(._PZ"#WY?+E[>7R[B#MX"!V9G-R;V]T(._@
M[^K@+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HY-@IM
M<V=I9"`B56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H
M96X@<VEG;FEN9R!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HS.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,X-2!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@
M)7,O)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z-S4U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M8VAA;F=E('1O("5S+B(*;7-G<W1R("+-Y>+ZY^SNYNWN\?(@Y^`@XO#ZY^K@
M(/$@4U%,(/'Z\.+Z\"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C(S,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H
M96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(L/PY?CJX"#O\.@@
MZ.?R\.CBX.WE("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C8X."!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P,38*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C@S-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O
M9B!<(B5S+R5S7"(N(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.?R\.CBX.WE("<E
M<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HT,S4*
M;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S
M='(@(LWEXOKG[.[F[>[Q\B#GX"#B\/KGZN`@\2!344P@\?KPXOKP+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,Y"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`BS>7B^N?L
M[N;M[O'R(.?@(.+P^N?JX"#Q(%-13"#Q^O#B^O`N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,C(U(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3DV
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#$*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P.0HC+"!F=7IZ>0IM<V=I9"`B
M56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(LWEXOKG[.[F[>[Q
M\B#GX"#B\/KGZN`@\2!344P@\?KPXOKP+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,S8U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R
M("+#\.7XZN`@[_#H(/?E\N7MY?+N(.W@('9F<W)O;W0@[^#OZN`N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S4T(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C(U-@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!6
M1E,@9&ER96-T;W)Y+B(*;7-G<W1R("+#\.7XZN`@[_#H(/?E\N7MY?+N(.W@
M('9F<W)O;W0@[^#OZN`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C$R-`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@
M9FEL92XB"FUS9W-T<B`BP_#E^.K@(._PZ"#WY?+E[>7R[B#MX"!V9G-R;V]T
M(._@[^K@+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C@V"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&
M4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("+#\.7XZN`@[_#H(/?E\N7MY?+N
M(.W@('9F<W)O;W0@[^#OZN`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C8U"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&5M
M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R("+-Y>+ZY^SNYNWN\?(@Y^`@XO#ZY^K@
M(/$@4U%,(/'Z\.+Z\"XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O=&%R+G!H<#HW-@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M9WII<"YP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D96-O;7!R
M97-S(&1A=&$N(@IM<V=S='(@(L/PY?CJX"#O\.@@[O+BX/#_[>7R[B#MX"#J
M[NSO\.7QZ/#@[2#@\/7HXBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C(R-"!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(Y.`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L
M('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R("+#\.7XZN`@
M[_#H(/?E\N7MY?+N(.W@('9F<W)O;W0@[^#OZN`N(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@
M)7,N(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.?R\.CBX.WE("<E<R<Z("5S+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S,2!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C,Y,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,S$Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,S0*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(L/PY?CJ
MX"#O\.@@]^7RY>WE\NX@[>`@=F9S<F]O="#OX._JX"XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0X(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HS-3(*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`BP_#E
M^.K@(._PZ"#WY?+E[>7R[B#MX"!V9G-R;V]T(._@[^K@+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S-R!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS
M,S4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T,PHC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0T"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(L/PY?CJ
MX"#O\.@@]^7RY>WE\NX@[>`@=F9S<F]O="#OX._JX"XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C0Q-R!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C0R.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`BP_#E^.K@(._P
MZ"#HY_+PZ.+@[>4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HR,#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+#\.7XZN`@
M[_#H(.CG\O#HXN#MY2`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HS,#,@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR.#@*
M(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$V-R!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HQ.#<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,X
M,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDQ"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R
M("+#\.7XZN`@[_#H(.CG\O#HXN#MY2`G)7,G.B`E<RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C(T-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS
M9W-T<B`BP_#E^.K@(._PZ"#HY_+PZ.+@[>4@)R5S)SH@)7,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,#8*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E
M<RXB"FUS9W-T<B`BP_#E^.K@(._PZ"#HY_+PZ.+@[>4@)R5S)SH@)7,N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,#,*(RP@9G5Z>GD*;7-G
M:60@(E5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM
M<V=S='(@(L/PY?CJX"#O\.@@]^7RY>WE\NX@[>`@=F9S<F]O="#OX._JX"XB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8P,PIM<V=I
M9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z-#4Q(&9R
M86UE=V]R:R].971?24U34"])35-0+T%U=&@N<&AP.C$Q.`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I
M;VX@;V8@)7,N(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.?R\.CBX.WE("<E<R<Z
M("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$Y-B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$V-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,3<Q"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@
M9FEL92XB"FUS9W-T<B`BS>7B^N?L[N;M[O'R(.?@(.+P^N?JX"#Q(%-13"#Q
M^O#B^O`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HY,R!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C$P,@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C8T."!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.CDX"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@
M9FEL92!<(B5S7"(N(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.?R\.CBX.WE("<E
M<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(W-R!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S,*(RP@9G5Z>GD*;7-G:60@(E5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R("+#
M\.7XZN`@[_#H(.[RXN#P_^WE\NX@[>`@ZN[L[_#E\>CPX.T@X/#UZ.(N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z.#`@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HW,@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93
M(&9I;&4N(@IM<V=S='(@(L/PY?CJX"#O\.@@[O+BX/#_[>7R[B#MX"#J[NSO
M\.7QZ/#@[2#@\/7HXBXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C0U"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D
M(&%R8VAI=F4N(@IM<V=S='(@(L/PY?CJX"#O\.@@[O+BX/#_[>7R[B#MX"#J
M[NSO\.7QZ/#@[2#@\/7HXBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M.#,U"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H
M*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z.#8V"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL
M95-I>F4H*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4V5S
M<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R("+#\.7X
MZN`@[_#H(.CG\O#HXN#MY2`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HV-CD*;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V
M9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`BP_#E^.K@(._PZ"#WY?+E[>7R
M[B#MX"!V9G-R;V]T(._@[^K@+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,3$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N
M86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES
M=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C(Y,PHC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@
M9&ER96-T;W)Y+B(*;7-G<W1R("+#\.7XZN`@[_#H(/?E\N7MY?+N(.W@('9F
M<W)O;W0@[^#OZN`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS
M,CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(L/PY?CJX"#O\.@@]^7R
MY>WE\NX@[>`@=F9S<F]O="#OX._JX"XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C(V-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,T,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z-C$P(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,CD*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93
M(&9I;&4@)7,O)7,N(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.?R\.CBX.WE("<E
M<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(S(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,3,*(SH@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C0U,B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,C@U"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS
M,#$*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N
M(@IM<V=S='(@(L/PY?CJX"#O\.@@]^7RY>WE\NX@[>`@=F9S<F]O="#OX._J
MX"XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI
M<V]F<RYP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK
M:7-O9G,G+B(*;7-G<W1R("+#\.7XZN`@[_#H(.CG\O#HXN#MY2`G)7,G.B`E
M<RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP
M.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U
M;65N="(*;7-G<W1R("+#\.7XZN`@[_#H(._PY>+NY.`@[>`@\N[GZ"!7;W)D
M(.3NZO/LY>WR(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-#D@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-3(*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N
M(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.?R\.CBX.WE("<E<R<Z("5S+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$W.0IM<V=I9"`B56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@Q(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S@*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$T,PIM<V=I9"`B56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HX-#$*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O
M=&$@=VEL;"!B92!E>&-E961E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L
M:6YE(@IM<V=S='(@(L_NY/?E\/+@[>@B"@HC.B!T96UP;&%T97,O<')E9G,O
M96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PIM<V=I
M9"`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y,`HC+"!F=7IZ>0IM
M<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN
M96-T:6]N.B`B"FUS9W-T<B`BS>7BX.OHY.7M(.[RX^[B[O`@[O(@\?KPXOKP
MX"(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q
M.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#$*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<X"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-`HC+"!F
M=7IZ>0IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T
M;SH@(@IM<V=S='(@(LWEXN#KZ.3E[2#N\N/NXN[P(.[R(/'Z\.+Z\.`B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU
M-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV
M,0HC+"!F=7IZ>0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R("+O\.[BX.OE[>XB
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B56YI8V]D92`H
M551&+3@I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")5;FET960@
M07)A8B!%;6ER871E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@
M(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G
M:60@(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM
M<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV.2!L
M:6(O0FQO8VLO;65T87(N<&AP.C<Q"FUS9VED(")5;FET<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,CD@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#,P"FUS9VED(")5;FMN;W=N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)($UE
M<W-A9V4@240I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@(E5N:VYO=VX@8VQI
M;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U.0IM<V=I9"`B56YK;F]W;B!L
M;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"B,L(&9U>GIY"FUS
M9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R("+-
MY>KN\.7J\NW@(._@\.[KX"#HZ^@@[^[R\.7AZ/+EZ_'J[B#H[.4A(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C(Y-@HC
M+"!F=7IZ>0IM<V=I9"`B56YN86UE9"(*;7-G<W1R("+AY><@Z.SE(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I
M9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O
M0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E
M87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M
M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@
M<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@R"B,L(&9U>GIY"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R("+"[/KJ
M[>@@[^[D\.#B[>CRY>LB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8X-B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR
M-@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDS,@IM<V=I
M9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,3DW('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`BSN_PY?'M
MZ"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,CD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@(L[O\.7Q[>@@
M)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"B,L
M(&9U>GIY"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R("+.[_#E\>WH("5S
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I="YP
M:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@7"(E<UPB+B(*;7-G<W1R("+.
M[_#E\>WE[6$@)R5S)RXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX
M,PIM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W."!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DY"FUS9VED(")5<&QO860B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X-@IM<V=I9"`B57!L
M;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V
M97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA=&EN(&QE
M='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B57!P97(@<F]M86X@
M;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5<G5G
M=6%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E
M9V]R>4UA;F%G97(N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E5S92!#
M=7)R96YT.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-33"(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS9VED(")5
M<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R
M=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D
M:70N:6YC.C(Q"B,L(&9U>GIY"FUS9VED(")5<V5R(@IM<V=S='(@(L_N\O#E
MX>CRY>OH(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H
M<#HW,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@875T
M:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C(P,PIM<V=I9"`B57-E<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R("+`Y.SH
M[>CQ\O#H\.#MY2#MX"#O[O+PY>'H\N7KZ/+E(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HR-3$*(RP@9G5Z>GD*;7-G:60@(E5S97(@3W!T
M:6]N<R(*;7-G<W1R("+.[_;HZ"(*"B,Z('-I9VYU<"YP:'`Z-C(*(RP@9G5Z
M>GD*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(L#D[.CMZ/'R
M\.CPX.WE(.W@(._N\O#EX>CRY>OH\N4B"@HC.B!S:6=N=7`N<&AP.C(R"FUS
M9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@
M=&AI<R!S:71E+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-#8Y"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-SD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A
M;'E?<VUT<"YP:'`Z.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,3DX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,34P('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,S
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S(@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM<V=S
M='(@(LCLY2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HQ
M,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E<UPB(&%L<F5A
M9'D@97AI<W1S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R("+([.4Z(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`IM<V=I9"`B57-E<FYA
M;64Z("(*;7-G<W1R("+([.4Z("(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S
M='(@(L_N\O#EX>CRY>OH(.(@\>CQ\N7LX/+@.B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*
M;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,38S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C(U-0IM<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q.`IM<V=I
M9"`B5F%C871I;VXB"FUS9W-T<B`BPN#JX.WVZ/\B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HX-C8*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N
M9"!I;F-L=61E.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV,S@*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3DW"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(U-0IM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#4V(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Q-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#0@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S$V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C@*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0HC+"!F=7IZ
M>0IM<V=I9"`B5F%L=65S(@IM<V=S='(@(LW_[.`@\?+NZ>WN\?+H(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P.2!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,3@V"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0T"FUS9VED
M(")687)I86)L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")6
M96YE>G5E;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T
M:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G
M<W1R("+#\.7XZN`@[_#H(._P[N+E\.K@\N`@+2#R[N+@(._H\>SN(.SNYN4@
MY.`@Y2#AZ.ON(._NY._PX.+E[>XN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HW,#`*(RP@9G5Z>GD*;7-G:60@(E9E<G-I;VXB"FUS
M9W-T<B`BS_#@XN`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(V
M"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I
M9"`B5F5R=&EC86P@86QI9VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@
M<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*
M;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"B,L
M(&9U>GIY"FUS9VED(")6:65T($YA;2(*;7-G<W1R("+([.4@[>`@].#IZR(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")6:65T;F%M97-E
M("A625-#24DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.CDV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*;7-G:60@
M(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#(Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-@IM<V=I9"`B5FER9VEN($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#D*;7-G:60@(E9I
M<VEB:6QI='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(V,PIM<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP
M.C@T"FUS9VED(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]M;V)I;&4N<&AP.C,V"FUS9VED(")705).(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G
M:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$S,PIM<V=I9"`B5TE.('9I82!(5%10(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3<*;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O:'1M;"YP:'`Z,C<R(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,PIM
M<V=I9"`B5V%R;FEN9R(*;7-G<W1R("+"[>CLX.WHY2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.0IM
M<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#(W"FUS9VED(")796%T:&5R(&1A=&$@
M<')O=FED960@8GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.#DR"FUS9VED(")796%T:&5R+F-O;2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S<*;7-G:60@(E=E8B!3
M:71E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN
M=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R("+1Y>3LZ/?M
M[B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"B,L(&9U>GIY
M"FUS9VED(")796QC;VUE(@IM<V=S='(@(L3NX?#E(.3N^.OH+"`E<R(*"B,Z
M('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHU-PHC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O
M("5S(@IM<V=S='(@(L3NX?#E(,3N^.OH(.(@)7,B"@HC.B!S97)V:6-E<R]P
M;W)T86PO;6]B:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC
M.C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B
MQ.[A\.4@Y.[XZ^@L("5S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.34*
M;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$I(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS9VED(")797-T97)N("A)4T\M.#@U
M.2TQ-2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E=E<W1E<FX@
M4V%H87)A(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U
M;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`BR.?AY?#E\N4@
M[_#HZ^[FY>WHY?+N+"#J[N7R[B`E<R#DX"#O[NK@YN4@\>OEY"#B]>[D+B(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T
M(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T
M:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V,0IM<V=I9"`B5VAE<F5I
M<R!!=7-T<F%L:6$@;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*;7-G:60@(E=H:6-H('!L=6=I;G,@
M=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$R-0IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE
M(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`V"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G
M:60@(E=I9'1H('5N:70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$S"FUS9VED
M(")7:6MI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS,#`@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C4*;7-G:60@(E=I;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E=I;F0@16%R;'DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,`IM<V=I9"`B5VEN
M9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$U-@IM<V=I9"`B5VEN9#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(T,@HC+"!F=7IZ>0IM<V=I9"`B5VEN
M9#H@(@IM<V=S='(@(L+MZ.S@[>CE.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-C0*;7-G:60@(E=I<V1O;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3DV"FUS9VED(")7:7-H;&ES="(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G:60@(E=O<FLB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$R-`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`BP>CG[>7Q
M(.#D\.7Q(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R("+!Z.?MY?$@\N7K
MY?3N[2(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$V.2!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E
M9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C,P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N
M=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$Q-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN
M9R!A(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C0S"FUS9VED(")8+5)E9B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S
M($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3DR"FUS9VED(")8-3`Y=C,@17AT96YD
M960@2V5Y(%5S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E
M<FYA=&EV92!.86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+97D@
M261E;G1I9FEE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8X,@IM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM
M<V=S='(@(L/#(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0Q,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#4U"B,L(&9U>GIY"FUS9VED(")965E9(@IM<V=S='(@(L/#(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,#@*
M;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA
M:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM
M<V=S='(@(L/NY.CX[>XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"B,L(&9U>GIY"FUS9VED
M(")996UE;B(*;7-G<W1R(")'<F5E;B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(EEE<R(*;7-G<W1R("+$
MX"(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL
M.C4V"FUS9VED(")997,L($D@06=R964B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U
M(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W
M:71C:"!B86-K('1O(%=94TE764<N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]E9&ET+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@
M87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T
M,3$*;7-G:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`R"FUS
M9VED(")9;W4@8V%N(&YO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y
M;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@U-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<U"FUS
M9VED(")9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N
M(@IM<V=S='(@(LWE(.+ZXN7D[O7RY2#BX.OHY.7M(&5M86EL(.#D\.7Q+B(*
M"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE
M(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*
M(FEN("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HY.#@*(RP@9G5Z>GD*;7-G:60@(EEO=2!H879E(&)E96X@;&]G9V5D(&]U
M="XB"FUS9W-T<B`BPN#XZ/+E(.KN[?3HX_/PX/;H[NWMZ"#N[_;HZ"#A__7@
M(.[A[>[BY>WH+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-C$*
M;7-G:60@(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE
M(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB
M9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@X"B,L(&9U>GIY
M"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G
M<W1R("+-Y2#B^N+EY.[U\N4@XN#KZ.3E[2!E;6%I;"#@Y/#E\2XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M
M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU
M<',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M-#4V"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R
M92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX
M"FUS9VED(")9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN
M:R!P;VEN=',@=&\B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P
M8W-U;2YP:'`Z.#`*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A
M;B!S97)V97(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`BTO#_X>+@(.3@(.?@
MY.#DY?+E(._N\O#EX>CRY>L@Y^`@Z.?R\.CBX.WE+B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$Q.0HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A
M('5S97)N86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`BTO#_X>+@(.3@(.?@
MY.#DY?+E(._N\O#EX>CRY>L@Y^`@Z.?R\.CBX.WE+B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE
M('1O(')E;6]V92XB"FUS9W-T<B`BTO#_X>+@(.3@(.?@Y.#DY?+E(._N\O#E
MX>CRY>L@Y^`@Z.?R\.CBX.WE+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU
M<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R("+2\/_A
MXN`@Y.`@Y^#DX.3E\N4@[^[R\.7AZ/+EZR#GX"#D[N'@XO_MY2XB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ-#8*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE
M('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`BTO#_X>+@(.3@(.?@Y.#D
MY?+E(._N\O#EX>CRY>L@Y^`@[N_PY?'M_^+@[>4N(@H*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,X"B,L(&9U>GIY"FUS9VED
M(")9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM
M<V=S='(@(M+P_^'BX"#DX"#GX.3@Y.7RY2#O[O+PY>'H\N7K(.?@(.CG\O#H
MXN#MY2XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA
M9V5R+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE
M=R!C871E9V]R>2!N86UE+B(*;7-G<W1R("+2\/_AXN`@Y.`@Y^#DX.3E\N4@
M[^[R\.7AZ/+EZR#GX"#HY_+PZ.+@[>4N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N
M965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<V"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE
M87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHS.`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!%;6%I
M;"!!9&1R97-S(@IM<V=S='(@(L+@^.C_($5M86EL(.#D\.7Q.B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR,3(*(RP@9G5Z>GD*;7-G:60@(EEO=7(@
M1G)O;3H@861D<F5S<SHB"FUS9W-T<B`BPN#XZ/\@16UA:6P@X.3PY?$Z(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8T(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HW-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@Y"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S
M='(@(LCM].[P[.#VZ/\@Y^`@PN#Q(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z.3@P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N
M970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F
M('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y
M+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*(RP@9G5Z>GD*;7-G:60@(EEO
M=7(@3F%M92(*;7-G<W1R("+"X/CE\NX@Z.SE.B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VYO861D+FEN8SHU"B,L(&9U>GIY"FUS9VED("(B"B)9;W5R
M(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I
M;F<@=7-E<G,N($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI
M;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N
M="`B"B)A=71H96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R("(B"B+"X/CH
M__(@Z.3E[?+H].CJX/;H[NWE[2#D\.#IXN7P(.WE(._NY.3Z\.;@(.3NX>#B
M_^WE(.W@(._N\O#EX>CRY>OH+"#HZ^@@(@HB\N#GZ"#B^N?L[N;M[O'R(.4@
MY^#A\.#MY>W@+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI
M;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O
M97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@
M(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*
M;7-G<W1R("(B"B+"X/CH__(@Z.3E[?+H].CJX/;H[NWE[2#D\.#IXN7P(.WE
M(._NY.3Z\.;@(/'OZ/'ZZB#MX"#O[O+PY>'H\N7KZ/+E+"#HZ^@@(@HB\N#G
MZ"#B^N?L[N;M[O'R(.4@Y^#A\.#MY>W@+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.CDX-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&)R
M;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN
M;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U<B!S
M96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]I9G)A;64N<&AP.C4P"FUS9VED(")9;W5R(&)R;W=S97(@
M9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"FUS9VED("(B"B)9
M;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO
M;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN="XB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U-PIM<V=I9"`B
M66]U<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<')E9G,N<&AP.CDV"B,L(&9U>GIY"FUS9VED(")9;W5R(&1E9F%U;'0@
M:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"XB"FUS9W-T<B`BPN#XZ/+E(.KN
M[?3HX_/PX/;H[NWMZ"#N[_;HZ"#A__7@(.[A[>[BY>WH+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-3@*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9&5F
M875L="!I9&5N=&ET>3HB"FUS9W-T<B`BR.3E[?+H]^WN\?(@[^X@[^[D\.#G
MX>CPX.WE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P,0HC+"!F=7IZ
M>0IM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@(L+@^.7R[B#H[.4Z
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z,3`P,`HC+"!F=7IZ>0IM
M<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T<B`BPN#XZ/+E
M(.KN[?3HX_/PX/;H[NWMZ"#N[_;HZ"#A__7@(.[A[>[BY>WH+B(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G
M:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-30*(RP@9G5Z
M>GD*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@
M=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`BPN#XZ/+E
M(.KN[?3HX_/PX/;H[NWMZ"#N[_;HZ"#A__7@(.[A[>[BY>WH+B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34V"FUS9VED(")9;W5R(&]P
M=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S='(@(L+@^.CRY2#J[NWT
MZ./S\.#VZ.[M[>@@[N_VZ.@@X?_UX"#NX>WNXN7MZ"XB"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H
M87,@8F5E;B!R97-E="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E
M;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U
M<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.C<S,@IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP
M:7)E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C4X"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R("+"
MX/CH\N4@\?KPXOKPZ#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9
M=6=O<VQA=FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X
M"FUS9VED(")::6UB86)W92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-C8*;7-G:60@(EII<'!Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ
M-S(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*
M;7-G:60@(EM(:61E(%%U;W1E9"!497AT72(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P<F]B;&5M+G!H<#HX.`IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K
M<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U
M;W1E<RYP:'`Z,3<R"B,L('!H<"UF;W)M870*;7-G:60@(EM3:&]W(%%U;W1E
M9"!497AT("T@)7,@;&EN97-=(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE
M("5S(&]F("5S72(*;7-G<W1R(");Z^CMZ/\@)7,@[O(@)7-=(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-30Q('1E;7!L871E<R]P;W)T86PO
M;65N=2YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*
M;7-G<W1R("+`Y.SH[>CQ\O#H\.#MY2(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM
M<V=I9"`B7T-,22(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#$*(RP@
M9G5Z>GD*;7-G:60@(E]$871A5')E92(*;7-G<W1R("+$X.WMZ"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M,0HC+"!F=7IZ>0IM<V=I9"`B7T1E;&5T92!2;W<B"FUS9W-T<B`BR.?R\.CI
M(@H*(SH@;&EB+V%P:2YP:'`Z,3,S"B,L(&9U>GIY"FUS9VED(")?1W)O=7!S
M(@IM<V=S='(@(L/P\^_H(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE
M;G4N<&AP.C$W-0HC+"!F=7IZ>0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`BS^[L
M[ODB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P97)T:65S+BXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.30*
M(RP@9G5Z>GD*;7-G:60@(E],;V<@:6XB"FUS9W-T<B`BPO7NY"(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.3`*(RP@9G5Z>GD*;7-G
M:60@(E],;V<@;W5T(@IM<V=S='(@(LCG]>[D(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?
M36]D:69Y($QI;FLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+TUE;G4N<&AP.C$V-`HC+"!F=7IZ>0IM<V=I9"`B7T]P=&EO;G,B
M"FUS9W-T<B`BSN_VZ.@B"@HC.B!L:6(O87!I+G!H<#HQ,S<*(RP@9G5Z>GD*
M;7-G:60@(E]097)M:7-S:6]N<R(*;7-G<W1R("+/\.#BX"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@IM
M<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN
M<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PIM<V=I
M9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@;&EB+V%P
M:2YP:'`Z,3(Y"B,L(&9U>GIY"FUS9VED(")?57-E<G,B"FUS9W-T<B`BS^[R
M\.7AZ/+EZ^@B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR,0HC
M+"!F=7IZ>0IM<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(L#D\.7QY>T@
MX>7KY>;MZ.HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$S-`IM<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3,*(RP@9G5Z>GD*;7-G:60@
M(F-A;&5N9&%R(@IM<V=S='(@(LK@Z^7MY.#P(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N;F]T(&-R96%T92!O
M=71P=70@9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z
M-3DR"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI
M;F4@=7-A9V4@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ-S@*(RP@9G5Z>GD*;7-G:60@(F-O;F9I9W5R
M871I;VX@97)R;W(B"FUS9W-T<B`BRN[M].CC\_#@]NC_(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-30*;7-G:60@(F-R:71I8V%L
M('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ,C8*;7-G:60@(F1A=&$@9F]R;6%T
M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,3@R"B,L(&9U>GIY"FUS9VED(")E;G1R>2!N;W0@9F]U;F0B
M"FUS9W-T<B`B[>4@X>7XY2#MX.SE\.7M(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*;7-G:60@(F9A;&QI;F<B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4U"FUS
M9VED(")F:6QE(@IM<V=S='(@(O3@Z>LB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$W-"!L:6(O0FQO8VLO;65T87(N<&AP.C,V,"!L:6(O0FQO8VLO;65T
M87(N<&AP.C,X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H
M)7,I(&%T("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-3`*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T.0IM<V=I
M9"`B:#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C,U.`IM<V=I9"`B:&@B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@
M;F%M92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM961I
M871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D
M;6EN+W-E='5P+V1I9F8N<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")I;FQI;F4B
M"FUS9W-T<B`BS^[D]^7P\N#MZ"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,38R"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-#8*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"B,L
M(&9U>GIY"FUS9VED(")L:6YE<UTB"FUS9W-T<B`BQ^#CZ^#BZ/\B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z
M-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D
M('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HS-CD*;7-G:60@(FUM(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,CDQ('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S`*(SH@<V5R=FEC97,O<&]R
M=&%L+W-I9&5B87(N<&AP.C(S,@HC+"!F=7IZ>0IM<V=I9"`B;F%M92(*;7-G
M<W1R("+([.4B"@HC.B!F<F%M97=O<FLO4E!#+U)00RYP:'`Z,3(Q"FUS9VED
M(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C$Y"FUS9VED(")N;W0@>65T(&EM<&QE
M;65N=&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3`U"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@
M(G!E<F-E;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ-S0*(RP@9G5Z>GD*;7-G:60@(G!E<FUI<W-I;VX@9&5N
M:65D(@IM<V=S='(@(L_PX.+@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<P
M"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*(RP@
M9G5Z>GD*;7-G:60@(G)I<VEN9R(*;7-G<W1R("+"[>CLX.WHY2(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,30R"FUS9VED(")S97)V
M:6-E('5N879A:6QA8FQE(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z.3D*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU,30*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@U"FUS
M9VED(")S<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HW,@HC+"!F=7IZ>0IM<V=I9"`B<W1E861Y(@IM<V=S
M='(@(M?E\N7MY2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S`Y
M"FUS9VED(")S=VET8V@@;V9F(&IA=F%S8W)I<'0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y
M<W1E;2!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDR.0IM<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,38V"FUS9VED(")T96UP
M;W)A<GD@9F%I;'5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C,P-0HC+"!F=7IZ>0IM<V=I9"`B=')Y(&%G86EN(@IM<V=S
M='(@(L+Q_^KN(.ONX^+@[>4B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!F<F%M
M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")T>7!E('1H
M92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y
M"B,L(&9U>GIY"FUS9VED(")U;FEF:65D(@IM<V=S='(@(N_P[N+@Z^7M[B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N
M;F%M960B"FUS9W-T<B`BX>7G(.CLY2(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B=7-E<B!S
M96QE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-#$*
M;7-G:60@(G<Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HV"FUS9VED(")W96%T:&5R+F-O;2(*;7-G<W1R("(B"@``````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]F<E]&4BYP;P``````
M````````````````````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`W
M-#4W-C,@,3`U,34T,S,W-#(@,#$W-30Q`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````",@2&]R9&4@,RXQ+C$@1G)E;F-H('1R
M86YS;&%T:6]N+@HC($-O<'ER:6=H="`H0RD@,C`P,2TR,#`R(%1H92!(;W)D
M92!0<F]J96-T+@HC(%!I97)R92!,86-H86YC92`\<&Q`<&EE<G)E;&%C:&%N
M8V4N;F5T/B!E="!"96YO:70@4W0M06YD<ND@*&)E;D!B96YO:71S="UA;F1R
M92YN970I+"`R,#`S+"`R,#`T+@HC($9R961E<FEC(%1R=61E874@/&9T<G5D
M96%U0&-A;2YO<F<^+"`R,#`Q+@HC(%1H:65R<GD@5&AO;6%S(#QT:&EE<G)Y
M0'!O;7!O+FYE=#XL(#(P,#(L(#(P,#4L(#(P,#8N"B,@0V]U;G1R>2!T<F%N
M;&%T:6]N<R!F<F]M($UI9W5E;"!4<F5M8FQA>2`\:V)A8F5L+FUI9W5E;$!P
M=&%F9BYC83XL(#(P,#0N"B,@0F5N;VET(%-T+4%N9'+I(#QB96Y`8F5N;VET
M<W0M86YD<F4N;F5T/BP@,C`P-"X*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R
M;VIE8W0M260M5F5R<VEO;CH@9G)?1E)<;B(*(E)E<&]R="U-<V=I9"U"=6=S
M+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T
M93H@,C`P-BTP,RTP-B`Q,CHT-RLP,3`P7&XB"B)03RU2979I<VEO;BU$871E
M.B`R,#`V+3`S+3,Q(#(R.C,P*S`R,#!<;B(*(DQA<W0M5')A;G-L871O<CH@
M5&AI97)R>2!4:&]M87,@/'1H:65R<GE`<&]M<&\N;F5T/EQN(@HB3&%N9W5A
M9V4M5&5A;3H@1G)E;F-H(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)
M344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[
M(&-H87)S970]25-/+3@X-3DM,5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O
M9&EN9SH@.&)I=%QN(@HB4&QU<F%L+49O<FUS.B!N<&QU<F%L<STR.R!P;'5R
M86P]*&X@/B`Q*3M<;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S
M-C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS9W-T
M<B`B("AI;"!Y(&$@)7,@:F]U<G,I(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ,S@S"B,L('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y
M("5S*2(*;7-G<W1R("(@*%1O=6-H92!D)V%C8^AS(')A<&ED92`E<RDB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<T"B,L('!H<"UF;W)M870*
M;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B("AD86YS("5S(&IO=7)S
M*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S`*;7-G:60@(B`H
M=&]D87DI(@IM<V=S='(@(B`H875J;W5R9"=H=6DI(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C,W,@IM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T
M<B`B("AD96UA:6XI(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,V
M.`IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@(B`H:&EE<BDB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0U(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS-3`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,Y-@IM<V=I9"`B(&%T("(*;7-G<W1R("(@X"`B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")<
M(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R("*KH"5SH+L@;B=E
M<W0@<&%S('5N(&1O<W-I97(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z
M,C<R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V86QI
M9"!C:&]I8V4N(@IM<V=S='(@(JN@)7.@NR!N)V5S="!P87,@=6X@8VAO:7@@
M=F%L:61E+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP
M:'`Z-S$P"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z
M,3`Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I
M9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*;7-G<W1R("*KH"5SH+L@
M;B=E<W0@<&%S(&-O;F9I9W5RZ2!D86YS(&QE(')E9VES=')E(&1E($AO<F1E
M+B(*"B,Z(&9R86UE=V]R:R]4<F5E+U1R964N<&AP.C$W,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM
M<V=S='(@(DPG:6YT97)P<NET975R(&0G87)B<F4@JZ`E<Z"[(&XG82!P87,@
MZ73I('1R;W5VZ2XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4V"B,L('!H<"UF
M;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S
M>7-T96TN(@IM<V=S='(@(JN@)7.@NR!A(.ETZ2!A:F]U=.D@874@<WES=.AM
M92!D97,@9W)O=7!E<RXB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z
M-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T
M:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R("*KH"5SH+L@82#I=.D@
M86IO=73I(&%U('-Y<W3H;64@9&5S('!E<FUI<W-I;VYS+B(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z-30@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-R96%T960Z("5S
M+B(*;7-G<W1R("*KH"5SH+L@;B=A('!A<R#I=.D@8W+IZ:`Z("5S+B(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*2(*;7-G
M<W1R("(E+C)FH$UO('5T:6QI<^ES('-U<B`E+C)FH$UO('!E<FUI<R`H)2XR
M9J`E)2DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(V"B,L
M('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R("(E9"`E
M<R!E="`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,C8X
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU-3<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N(@IM<V=S
M='(@(B5D(&IO=7)S(&%V86YT(&PG97AP:7)A=&EO;B!D92!V;W1R92!M;W0@
M9&4@<&%S<V4N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(W
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B"FUS9W-T
M<B`B)60M<'+I=FES:6]N(&1U(&IO=7(B"@HC.B!S97)V:6-E<R]M86EN=&5N
M86YC92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B
M"FUS9W-T<B`B)7,@+2!.;W1I8V4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C<P-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG
M97)P<FEN="(*;7-G<W1R(")%;7!R96EN=&4@4$=0(&1E("5S(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0P(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C@T,@HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!+0B(*;7-G<W1R("(E<Z!+;R(*"B,Z('-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N86YC
M92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B5S(&]PZ7)A
M=&EO;G,@9&4@;6%I;G1E;F%N8V4@)FYD87-H.R!#;VYF:7)M871I;VXB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T
M<B`B0V]N9FEG=7)A=&EO;B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M4VEG;G5P+G!H<#HR-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5
M<"(*;7-G<W1R("));G-C<FEP=&EO;B!D92`E<R(*"B,Z('-E<G9I8V5S+VUA
M:6YT96YA;F-E+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M
M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`B0V]N9&ET:6]N<R!D)W5T:6QI<V%T
M:6]N(&1E("5S(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT,S(@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.30*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HV.#(@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW
M-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM
M<V=S='(@(B5S(&5X:7-T92!DZ6K@+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,38V(&QI8B]";&]C:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C0V"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S4R(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S4X"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S
M("5S(@IM<V=S='(@(B`E<Z#@("5S("5S(@H*(SH@<V5R=FEC97,O;6%I;G1E
M;F%N8V4N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S(&ES(')E
M861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE
M8VME9"!B96QO=RX@0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P97)A=&EO
M;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T
M<B`B(@HB)7,@97-T('!RZG0@X"!E9F9E8W1U97(@;&5S(&]PZ7)A=&EO;G,@
M9&4@;6%I;G1E;F%N8V4@8V]C:.EE<R!C:2UD97-S;W5S+B`B"B)3Z6QE8W1I
M;VYN97H@;&$@;W4@;&5S(&]PZ7)A=&EO;BAS*2!Q=64@=F]U<R!V;W5L97H@
M969F96-T=65R(&-E='1E(&9O:7,M8VDN(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C,S-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U
M:7)E9"(*;7-G<W1R("(E<R!E<W0@;V)L:6=A=&]I<F4B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU
M=&5S(@IM<V=S='(@(B5S(&UI;G5T97,B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3(Y"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`B)7,@;F]N('1R;W5VZ2(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B)7.@X"`E<R!D92`E<R(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(V"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(D-A<FYE="!D
M)V%D<F5S<V5S(&1E("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G
M<W1R(")!9V5N9&$@9&4@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDQ,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS
M9W-T<B`B0FQO8RUN;W1E<R!D92`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z.3,T"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI
M<W0B"FUS9W-T<B`B3&ES=&4@9&4@=.)C:&5S(&1E("5S(@H*(SH@9G)A;65W
M;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE
M+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B
M)7.@.B`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN
M<&AP.C$R-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M97-S
M86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W
M87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O
M=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I
M;VXN(@IM<V=S='(@(B(*(B5SH#H@;"?I;65T=&5U<B!D92!C92!M97-S86=E
M(&$@<'4@ZG1R92!F86QS:69IZ2X@071T96YT:6]N(&5N('-U:79A;G0@;&5S
M("(*(FQI96YS('%U)VEL(&-O;G1I96YT(&]U(&5N(&9O=7)N:7-S86YT(&1E
M<R!I;F9O<FUA=&EO;G,@<&5R<V]N;F5L;&5S(.`@(@HB;"?I;65T=&5U<BXB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4T(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS.3D*;7-G:60@(BP@9W5S=&EN9R`B"FUS
M9W-T<B`B+"!E;B!R869A;&4@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M.34@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S='(@(G)A9F%L92`E<R`E<R(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C`X"B,L('!H<"UF;W)M870*;7-G:60@
M(BP@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<R(*;7-G<W1R(")V87)I86)L92!D
M=2`E<R!A=2`E<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,CDT(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S0X"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(P-C8@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$R-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-S0X"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B+2T@4^EL96-T
M:6]N;F5R("TM(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P"FUS9VED("(Q
M,B!(;W5R($9O<FUA="(*;7-G<W1R(")&;W)M870@,3(@:&5U<F5S(@H*(SH@
M;&EB+T)L;V-K+W1I;64N<&AP.C$Y"FUS9VED("(R-"!(;W5R($9O<FUA="(*
M;7-G<W1R(")&;W)M870@,C0@:&5U<F5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T(&AE=7)E
M<R(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z-CD*;7-G:60@(CQ0
M<F5V:6]U<R(*;7-G<W1R("(\4'+I8^ED96YT(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ,C8*;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U
M:7)E9"!F;W(@=&AI<R!B;&]C:RXB"FUS9W-T<B`B56YE(&)A<V4@9&4@9&]N
M;NEE<R!P<FEN8VEP86QE("AB86-K96YD*2!E<W0@;NEC97-S86ER92!P;W5R
M(&-E(&)L;V,B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W,0IM
M<V=I9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`B56YE
M(&5R<F5U<B!F871A;&4@<R=E<W0@<')O9'5I=&4B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B;&EC(%!'4"!K
M97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@
M(E5N92!C;&5F('!U8FQI<75E(%!'4"!E<W0@;NEC97-S86ER92!P;W5R(&-H
M:69F<F5R('5N(&UE<W-A9V4N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3$V.`IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U
M:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@HB
M56YE(&-L968@<'5B;&EQ=64@4$=0(&5S="!NZ6-E<W-A:7)E('!O=7(@=NER
M:69I97(@;&$@<VEG;F%T=7)E(&0G=6X@;65S<V%G92XB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#DY"FUS9VED("(B"B)!('!U8FQI
M8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B
M(@HB56YE(&-L968@<'5B;&EQ=64@4$=0+"!U;F4@8VQE9B!P<FEVZ64@4$=0
M+"!E="!U;F4@<&AR87-E('-E8W+H=&4@<V]N="`B"B)NZ6-E<W-A:7)E<R!P
M;W5R(&3I8VAI9F9R97(@=6X@;65S<V%G92XB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,#$V"FUS9VED("(B"B)!('!U8FQI8R!01U`@
M:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB56YE(&-L
M968@<'5B;&EQ=64@4$=0+"!U;F4@8VQE9B!P<FEVZ64@4$=0+"!E="!U;F4@
M<&AR87-E('-E8W+H=&4@<V]N="`B"B)NZ6-E<W-A:7)E<R!P;W5R('-I9VYE
M<B!U;B!M97-S86=E+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3`V"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV
M871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R`B"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@HB56YE(&-L968@
M<'5B;&EQ=64@4R]-24U%+"!U;F4@8VQE9B!P<FEVZ64@4R]-24U%+"!E="!U
M;F4@<&AR87-E('-E8W+H=&4@<V]N="`B"B)NZ6-E<W-A:7)E<R!P;W5R(&3I
M8VAI9F9R97(@=6X@;65S<V%G92XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME
M>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*(E5N92!C
M;&5F('!U8FQI<75E(%,O34E-12P@=6YE(&-L968@<')I=NEE(%,O34E-12P@
M970@=6YE('!H<F%S92!S96-RZ'1E('-O;G0@(@HB;NEC97-S86ER97,@<&]U
M<B!S:6=N97(@=6X@;65S<V%G92XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES
M(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(")5;F4@
M8VQE9B!P=6)L:7%U92!3+TU)344@97-T(&[I8V5S<V%I<F4@<&]U<B!C:&EF
M9G)E<B!U;B!M97-S86=E+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.CD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R(").=6%G
M97,@;&4@;6%T:6XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ,`IM<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R(")0;'5I
M92!LZ6?H<F4@;&4@;6%T:6XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R(")0;'5I
M92!L92!M871I;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$R"FUS9VED(")!32!3:&]W97)S(@IM<V=S='(@(D%V97)S97,@
M;&4@;6%T:6XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ,PIM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(D-H=71E
M<R!D92!N96EG92!L92!M871I;B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N
M:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R(")!32]032(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I
M9"`B05!)($E$(@IM<V=S='(@(D%022!)1"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@
M961I=&]R(@IM<V=S='(@(L`@<')O<&]S(&1E(&-E="#I9&ET975R(@H*(SH@
M<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3,*;7-G:60@(D%B;W5T+BXN(@IM
M<V=S='(@(L`@<')O<&]S+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@
M(D)A<R!A8G-O;'4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<R"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B36EL:65U
M(&%B<V]L=2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-S`*
M;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B06-CZ',@<F5F=7/I(&QO<G,@9&4@;&$@8W+I871I;VX@9&4@
M<NEP97)T;VER92!61E,@+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I
M;&4N(@IM<V=S='(@(D%C8^AS(')E9G5SZ2!L;W)S(&1E(&QA(&-RZ6%T:6]N
M(&1E(&9I8VAI97(@5D93+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS
M"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(D1O;F[I97,@
M<&5R<V]N;F5L;&5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X"FUS
M9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@(DUO="!D92!P87-S92!D
M=2!C;VUP=&4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3,*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R
M(")#;VUP=&4@:6YA8W1I9B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS,S4*;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T<B`B0V]M<'1E<R(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30X('1E;7!L871E<R]P
M;W)T86PO861D+FEN8SHQ-`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D
M9&-H:6QD+FEN8SHQ,0IM<V=I9"`B061D(@IM<V=S='(@(D%J;W5T97(B"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G<F]U<',N<&AP.C(R-0IM
M<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S='(@(D%J;W5T97(@=6X@<V]U
M<RUG<F]U<&4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDX
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#
M:&EL9"!097)M:7-S:6]N(@IM<V=S='(@(D%J;W5T97(@=6YE(&YO=79E;&QE
M('-O=7,M<&5R;6ES<VEO;B(*"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN
M8SHU"FUS9VED(")!9&0@2&5R93HB"FUS9W-T<B`B06IO=71E<B!I8VF@.B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP:'`Z,C$Y
M"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S='(@(D%J;W5T97(@=6X@;F]U
M=F5A=2!G<F]U<&4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C@W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#@*;7-G:60@(D%D
M9"!.97<@4&5R;6ES<VEO;B(*;7-G<W1R(")!:F]U=&5R('5N92!N;W5V96QL
M92!P97)M:7-S:6]N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C
M:&EL9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!G
M<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B06IO=71E<B!U;B!G<F]U<&4@9FEL
M<R#@(*N@)7.@NR(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,30W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I
M;VX@=&\@7"(E<UPB(@IM<V=S='(@(D%J;W5T97(@=6YE('!E<FUI<W-I;VX@
M9FEL;&4@X""KH"5SH+LB"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B
M061D(&$@;F5W('5S97(Z(@IM<V=S='(@(D%J;W5T97(@=6X@;F]U=F5L('5T
M:6QI<V%T975RH#HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-34V"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S='(@(D%J;W5T
M97(@=6YE(&-O;&]N;F4B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D
M:70N:6YC.C,T"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`B06IO
M=71E<B!D92!N;W5V96%U>"!M96UB<F5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D('!A:7(B"FUS9W-T<B`B06IO=71E
M<B!U;F4@<&%I<F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Q"B,L
M('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL
M;&$@4VED96)A<B(*;7-G<W1R(")!:F]U=&5R(&QE(&UE;G4@)7,@X"!L82!B
M87)R92!D92!-;WII;&QA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C<Q"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*
M;7-G<W1R(")!:F]U=&5R(&%U(&-A<FYE="!D)V%D<F5S<V5SH#HB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*;7-G:60@
M(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`B06IO=71E<B#@(&UO
M;B!C87)N970@9"=A9')E<W-E<R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"FUS
M9VED(")!9&0@=7-E<B(*;7-G<W1R(")!:F]U=&5R('5N('5T:6QI<V%T975R
M(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB061D960@7"(E<UPB('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@
M861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`B"B(E<RXB"FUS
M9W-T<B`B(@HBJZ`E<Z"[(&$@Z73I(&%J;W5TZ2!A=2!S>7-TZ&UE+"!M86ES
M(&PG86IO=70@9"=I;F9O<FUA=&EO;B!S=7!P;.EM96YT86ER97,@)2(*(G,@
M;B=E<W0@<&%S('!O<W-I8FQE+B(*"B,Z('-I9VYU<"YP:'`Z-#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B061D960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO
M=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`BJZ`E<Z"[(&$@Z73I(&%J;W5T
MZ2X@5F]U<R!P;W5V97H@=F]U<R!C;VYN96-T97(N(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G:60@(D%D9&EN9R!U<V5R<R!I
M<R!D:7-A8FQE9"XB"FUS9W-T<B`B3&$@9F]N8W1I;VX@9"=A:F]U="!D)W5T
M:6QI<V%T975R<R!E<W0@9.ES86-T:7;I92XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-S,@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,30S.`IM<V=I9"`B061D<F5S<R(*;7-G<W1R(")!9')E<W-E(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$T,0IM<V=I9"`B061D<F5S
M<R!";V]K(@IM<V=S='(@(D-A<FYE="!D)V%D<F5S<V5S(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-38*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30*;7-G:60@(D%D;6EN:7-T
M97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S='(@
M(D%D;6EN:7-T<F%T975R("T@86IU<W1E<B!L97,@<&5R;6ES<VEO;G,@<&]U
M<B!D)V%U=')E<R!U=&EL:7-A=&5U<G,B"@HC.B!A9&UI;B]I;F1E>"YP:'`Z
M,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM<V=I9"`B061M
M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R871I;VXB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0S"FUS9VED(")!9',B"FUS9W-T<B`B
M4'5B<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@
M(D%F9VAA;FES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06QB86YI82(*;7-G
M<W1R(")!;&)A;FEE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B06QG97)I82(*;7-G
M<W1R(")!;&?I<FEE(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T<B`B06QI87,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C$V"FUS9VED(")!;&EG;B(*;7-G<W1R(")!;&EG;F5R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI
M9VYM96YT.B(*;7-G<W1R(")!;&EG;F5M96YTH#HB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R(")4;W5T(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E
M<G,B"FUS9W-T<B`B5&]U<R!L97,@<&%R=&EC:7!A;G1S(&%U=&AE;G1I9FGI
M<R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR
M,C(*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`B5&]U<R!L97,@9W)O=7!E
M<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3$@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+V1A=&%T<F5E+G!H<#HW-0IM<V=I9"`B06QL(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(E1O=71E<R!L97,@<&5R;6ES<VEO;G,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G<W1R("),97,@<75A=')E
M(&/T=.ES(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V.`IM<V=I
M9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(E!E<FUE='1R
M92!D97,@861R97-S97,@9&4@8V]U<G)I96P@;75L=&EP;&5S(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4S.`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O
M9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B075T;W)I<V5R(&QA(&UI
M<V4@96X@<&QA8V4@9&4@;&ES=&5S(&YU;>ER;W3I97.@/R(*"B,Z(&9R86UE
M=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR
M96%D>2!E>&ES=',B"FUS9W-T<B`B17AI<W1E(&3I:N`B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3(V"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I
M;B(*;7-G<W1R(").;VT@9"=U=&EL:7-A=&5U<B!)35-0(&%L=&5R;F%T:68B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$Q"FUS9VED(")!;'1E<FYA
M=&4@24U34"!087-S=V]R9"(*;7-G<W1R(")-;W0@9&4@<&%S<V4@24U34"!A
M;'1E<FYA=&EF(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P,PIM<V=I
M9"`B06QT97)N871E($E-4U`@57-E<FYA;64B"FUS9W-T<B`B3F]M(&0G=71I
M;&ES871E=7(@24U34"!A;'1E<FYA=&EF(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z,S4*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S
M(@IM<V=S='(@(D%D<F5S<V4@9&4@8V]U<G)I96P@86QT97)N871I=F4B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B06QT97)N871E('1E
M;7!L871E<R(*;7-G<W1R(")!=71R97,@;6]DZ&QE<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-0IM
M<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(E1E>'1E(&%L=&5R;F%T
M:6:@.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S
M='(@(E-A;6]A($%MZ7)I8V%I;B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z.34@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,34*
M;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB"FUS9W-T
M<B`B56YE('9A;&5U<B!I;&SI9V%L92!A(.ETZ2!S<.EC:69IZ64N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-0IM<V=I9"`B06X@=6YK
M;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B56YE(&5R<F5U<B!I
M;F-O;FYU92!S)V5S="!P<F]D=6ET92XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!
M;F1O<G)A(@IM<V=S='(@(D%N9&]R<F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!
M;F=O;&$B"FUS9W-T<B`B06YG;VQA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG
M=6EL;&$B"FUS9W-T<B`B06YG=6EL;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T
M<B`B4')O>'D@86YO;GEM92(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T<B`B4NEP;VYS92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`B06YT87)C=&EQ=64B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S
M='(@(D%N=&EG=6$M970M0F%R8G5D82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP
M:'`Z-S0@861M:6XO<&AP<VAE;&PN<&AP.C,V"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R]522YP:'`Z-3@@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X
M+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`B07!P;&EC871I
M;VXB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI
M8V%T:6]N($QI<W0B"FUS9W-T<B`B3&ES=&4@9"=A<'!L:6-A=&EO;G,B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,30P"FUS9VED(")!<'!L:6-A=&EO
M;B!I<R!R96%D>2XB"FUS9W-T<B`B3"=A<'!L:6-A=&EO;B!E<W0@<'+J=&4B
M"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P
M;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@(D%P<&QI<75E<B!A=7@@<&%R
M=&%G97,@9FEL<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N
M:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(D%P<')O=7;I(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0P"FUS9VED(")!
M<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@(E1A:6QL92!A<'!R;WAI;6%T:79E
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0S
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C@*
M;7-G:60@(D%P<FEL(@IM<V=S='(@(D%V<FEL(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ-S@*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G
M<W1R(")!<F%B92`H5VEN9&]W<RTQ,C4V*2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HV-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C<X"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R
M(")486EL;&4@9'4@9FEC:&EE<B!A<F-H:79E(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HU."!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C8U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z-S<*;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R(").
M;VT@9&4@;"=A<F-H:79E(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E<75E=65D+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U
M('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F
M;W(@)7,@/R(*;7-G<W1R("(B"B+*=&5S+79O=7,@8V5R=&%I;B!D92!V;W5L
M;VER('-U<'!R:6UE<B!C971T92!R97%UZG1E(&0G:6YS8W)I<'1I;VX@('!O
M=7(@)7.@/R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN
M8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES
M:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS9W-T
M<B`BRG1E<RUV;W5S(&-E<G1A:6X@9&4@=F]U;&]I<B!E9F9A8V5R(*N@)7.@
MNR!E="!S97,@<V]U<RUG<F]U<&5SH#\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!
M<F=E;G1I;F$B"FUS9W-T<B`B07)G96YT:6YE(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I
M9"`B07)M96YI82(*;7-G<W1R(")!<FWI;FEE(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ-SD*;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S
M='(@(D%R;>EN:65N("A!4DU30TE)+3@I(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B07)T(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B07)U8F$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM
M<V=S='(@(D%S8V5N<VEO;B`HSFQE*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HR.0IM<V=I9"`B07-C:6D@07)T(@IM<V=S='(@(D%R="!!4T-)22(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I
M82]086-I9FEC(%)E9VEO;B(*;7-G<W1R(")2Z6=I;VX@07-I92]086-I9FEQ
M=64B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(Y"FUS9VED(")!<VL@
M9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<S\B"FUS9W-T<B`B(@HB1&5M86YD97(@=6YE(&-O;F9I<FUA=&EO
M;B!A=F%N="!D92!L86YC97(@;&5S(&]PZ7)A=&EO;G,@9&4@;6%I;G1E;F%N
M8V6@/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,P.3(*;7-G:60@
M(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R(")#;VQO;FYE<R!D97,@=.)C
M:&5S(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I9"`B071T96UP="!T
M;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(E1E;G1A
M=&EV92!D)V5F9F%C96UE;G0@9"=U;B!G<F]U<&4@:6YE>&ES=&%N="XB"@HC
M.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C(Y"FUS9VED(")!='1E;7!T('1O
M(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")4
M96YT871I=F4@(&0G969F86-E;65N="!D)W5N92!P97)M:7-S:6]N(&EN97AI
M<W1A;G1E+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED(")!
M='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS
M9W-T<B`B5&5N=&%T:79E(&1E(&UO9&EF:6-A=&EO;B!D)W5N92!P97)M:7-S
M:6]N(&EN97AI<W1A;G1E+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H
M<#HU,PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H
M87)E+B(*;7-G<W1R(")496YT871I=F4@9&4@;6]D:69I8V%T:6]N(&0G=6X@
M<&%R=&%G92!I;F5X:7-T86YT+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C0@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HW,0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C@S"FUS9VED(")!='1R:6)U=&5S(@IM<V=S='(@(E!R;W!R:>ETZ7,B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Y
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM
M<V=I9"`B075G=7-T(@IM<V=S='(@(D%O^W0B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED
M(")!=7-T<F%L:6$B"FUS9W-T<B`B075S=')A;&EE(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM
M<V=I9"`B075S=')I82(*;7-G<W1R(")!=71R:6-H92(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L
M.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(D%U=&A?8WER=7.@.B!%>'1E;G-I;VX@<F5Q=6ES92!)34%0(&YO;B!T<F]U
M=NEE+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$S-0IM
M<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I
M<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R(")!=71H7V-Y<G5SH#H@;&4@8F%C
M:V5N9"!N)V$@<&%S(&QE<R!C87!A8VETZ7,@<F5Q=6ES97,N(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3(R"FUS9VED(")!=71H7V-Y
M<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(D%U=&A?8WER=7.@.B!E>'1E;G-I;VX@<F5Q=6ES92!)34%0(&YO;B!T
M<F]U=NEE(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]F='`N<&AP.C,V"FUS
M9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S
M=VET8V@N(@IM<V=S='(@(B(*(D%U=&A?9G1PH#H@97AT96YS:6]N(')E<75I
M<V4@1E10(&YO;B!T<F]U=NEE+B!);"!F875T(&-O;7!I;&5R(%!(4"!A=F5C
M("(*(FPG;W!T:6]N("TM96YA8FQE+69T<"XB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VEM87`N<&AP.C8T"FUS9VED(")!=71H7VEM87`Z(%)E<75I<F5D
M($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]I;6%P
MH#H@97AT96YS:6]N(')E<75I<V4@24U!4"!N;VX@=')O=7;I92XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR
M8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B075T:%]K<F(UH#H@97AT96YS:6]N(')E<75I<V4@:W)B-2!N;VX@=')O
M=7;I92XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,P,@IM
M<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E
M9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"B)!=71H7VQD87"@
M.B!L)V%J;W5T(&0G=71I;&ES871E=7)S(&XG97-T('!A<R!S=7!P;W)TZ2!A
M=F5C($%C=&EV92!$:7)E8W1O<GDB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C,U-PIM<V=I9"`B075T:%]L9&%P.B!296UO=FEN9R!U<V5R
M<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S
M='(@(B(*(D%U=&A?;&1A<*`Z(&QE(')E=')A:70@9"=U=&EL:7-A=&5U<G,@
M;B=E<W0@<&%S('-U<'!O<G3I(&%V96,@06-T:79E("(*(D1I<F5C=&]R>2(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-C,*;7-G:60@(D%U
M=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")!=71H7VQD87"@.B!E>'1E;G-I;VX@<F5Q=6ES92!,1$%0(&YO
M;B!T<F]U=NEE+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M,S,Y"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O
M(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B
M"FUS9W-T<B`B(@HB075T:%]L9&%PH#H@:6UP;W-S:6)L92!D)V%J;W5T97(@
M;"=U=&EL:7-A=&5U<B`E<RX@0V5C:2!E<W0@;&$@<NEP;VYS92!D=2`B"B)S
M97)V975RH#H@(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS
M.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@
M<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%PH#H@:6UP;W-S:6)L
M92!D92!S=7!P<FEM97(@;"=U=&EL:7-A=&5U<B`E<R(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#DY"B,L('!H<"UF;W)M870*;7-G:60@
M(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S(@IM<V=S='(@
M(D%U=&A?;&1A<*`Z(&UO9&EF:6-A=&EO;B!I;7!O<W-I8FQE(&1E(&PG=71I
M;&ES871E=7(@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C0P-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@
M<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*;7-G<W1R("(B"B)!
M=71H7VQD87"@.B!L82!M;V1I9FEC871I;VX@9&5S('5T:6QI<V%T975R<R!N
M)V5S="!P87,@<W5P<&]R=.EE(&%V96,@06-T:79E("(*(D1I<F5C=&]R>2XB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C0V"FUS9VED(")!
M=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B075T:%]M8V%LH#H@97AT96YS:6]N(')E<75I<V4@34-!3"!N
M;VX@=')O=7;I92XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z
M-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7W-M8F%U=&B@.B!E>'1E
M;G-I;VX@<F5Q=6ES92!S;6)A=71H(&YO;B!T<F]U=NEE+B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O061M:6XN<&AP.C$P-@IM<V=I9"`B075T:&5N=&EC
M871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("+)8VAE8R!D
M92!L)V%U=&AE;G1I9FEC871I;VX@874@<V5R=F5U<B!)34%0+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM
M<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S='(@(LEC:&5C(&1E
M(&PG875T:&5N=&EF:6-A=&EO;B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G
M:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`BR6-H96,@
M9&4@;"=A=71H96YT:69I8V%T:6]N("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B075T:&5N=&EC871I;VX@<F5J
M96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS9W-T<B`B3&4@<V5R=F5U<B!2
M041)55,@82!R96IE=.D@;"=A=71H96YT:69I8V%T:6]N+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z.#@R"FUS9VED(")!=71H96YT:6-A=&EO
M;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`BR6-H96,@9&4@;"=A
M=71H96YT:69I8V%T:6]N(&%U('-E<G9E=7(@1E10+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z-S`*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O
M('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`BR6-H96,@9&4@;"=A
M=71H96YT:69I8V%T:6]N(&%U('-E<G9E=7(@4TU"+B(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L92!F:65L9',Z
M(@IM<V=S='(@(D-H86UP<R!D:7-P;VYI8FQE<Z`Z(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM
M<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R(")!>F5R8F'O9&IA;B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I9"`B0D]&2"!%>&-U<V5S(@IM
M<V=S='(@(D5X8W5S97,@0D]&2"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B
M"FUS9W-T<B`B0V]U;&5U<B!D92!F;VYD(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#
M;VQO<B(*;7-G<W1R(")#;W5L975R(&1E(&9O;F0B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VMR8C4N<&AP.C@Q"FUS9VED(")"860@:V5R8F5R;W,@<&%S
M<W=O<F0N(@IM<V=S='(@(DUO="!D92!P87-S92!+97)B97)O<R!E<G)O;NDN
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,PIM<V=I9"`B
M0F%D(&ME<F)E<F]S('5S97)N86UE+B(*;7-G<W1R(").;VT@9&4@8V]N;F5X
M:6]N($ME<F)E<F]S(&5R<F]NZ2XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"86AA
M;6%S(@IM<V=S='(@(D)A:&%M87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"86AR
M86EN(@IM<V=S='(@(D)A:')E[VXB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X,`IM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B0F%L
M=&4@*$E33RTX.#4Y+3$S*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A;F=L861E
M<V@B"FUS9W-T<B`B0F%N9VQA9&5S:"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A
M<F)A9&]S(@IM<V=S='(@(D)A<F)A9&4B"@HC.B!U=&EL+VEC;VY?8G)O=W-E
M<BYP:'`Z,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D
M:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B4NEP97)T;VER
M92!D97,@9W)A<&AI<75E<R"KH"5SH+L@;F]N('1R;W5VZ2XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$Y"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*;7-G
M:60@(D)A<V5L:6YE(@IM<V=S='(@(DQI9VYE(&1E(&)A<V4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8S"FUS9VED(")"96QA<G5S(@IM<V=S='(@(D+I;&%R=7,B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8P"FUS9VED(")"96QG:75M(@IM<V=S='(@(D)E;&=I<75E(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,PIM<V=I9"`B0F5L:7IE(@IM<V=S='(@(D)E;&EZ92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C$*;7-G:60@(D)E;FEN(@IM<V=S='(@(D+I;FEN(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM
M<V=I9"`B0F5R;75D82(*;7-G<W1R(")"97)M=61E<R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HS-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*
M;7-G:60@(D)H=71A;B(*;7-G<W1R(")":&]U=&%N(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD
M87DB"FUS9W-T<B`B06YN:79E<G-A:7)E(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,V-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")";&]C:R!<(B5S7"(@;V8@87!P;&EC871I;VX@7"(E<UPB(&YO="!F;W5N
M9"XB"FUS9W-T<B`B0FQO8R"K)7,@NR!D92!L)V%P<&QI8V%T:6]N(*N@)7.@
MNR!I;F-O;FYU(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDP
M"FUS9VED(")";&]C:R!3971T:6YG<R(*;7-G<W1R(")0<NEFZ7)E;F-E<R!D
M92!B;&]C(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<T"FUS
M9VED(")";&]C:R!4>7!E(@IM<V=S='(@(E1Y<&4@9&4@8FQO8R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B
M0F]L9"(*;7-G<W1R(")'<F%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HT,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F]L:79I
M82(*;7-G<W1R(")";VQI=FEE(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(P-PIM<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@(E-I9VYE=',B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(P"FUS9VED(")";W)D97(B"FUS9W-T<B`B0F]R9'5R92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O
M<F1E<B!T:&EC:VYE<W,Z(@IM<V=S='(@(LEP86ES<V5U<B!D92!L82!B;W)D
M=7)EH#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(Q"FUS9VED(")";W)D97)S(@IM<V=S='(@(D)O<F1S(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G
M<W1R(")";W-N:64M2&5R>NEG;W9I;F4B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z.38*;7-G:60@(D)O=&@B"FUS9W-T<B`B3&5S(&1E=7@B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8S"FUS9VED(")";W1S=V%N82(*;7-G<W1R(")";W1S=V%N82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(D)A<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G
M:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B0F]U=F5T(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,@IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(D)RZ7-I;"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q
M"FUS9VED(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T
M<B`B5&5R<FET;VER97,@8G)I=&%N;FEQ=65S(&1E(&PG3V/I86X@26YD:65N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T
M<B`B4W5L=&%N870@9'4@0G)U;NEI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5L
M9V%R:6$B"FUS9W-T<B`B0G5L9V%R:64B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"FUS9VED(")"=6QL971E9"!,:7-T
M(@IM<V=S='(@(DQI<W1E(.`@<'5C97,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"
M=7)K:6YA($9A<V\B"FUS9W-T<B`B0G5R:VEN82!&87-O(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R(")"=7)U;F1I(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0T-@IM<V=I9"`B0TU3(@IM<V=S='(@(D=E
M<W1I;VX@9&4@8V]N=&5N=2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G<W1R(")#4D,B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.`IM<V=I9"`B0U),
M($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B1&ES=')I8G5T:6]N(&1E
M<R!P;VEN=',@3%)#("A,:7-T92!D92!RZ79O8V%T:6]N(&1E<R!C97)T:69I
M8V%T<RDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS
M9W-T<B`B4')O<')IZ73I<R!D92!L82!#7V5L;'5L92(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3$*;7-G:60@(D-A8VAE(&EN:70@=V%S
M(&YO="!C;VUP;&5T960N(@IM<V=S='(@(DPG:6YI=&EA;&ES871I;VX@9'4@
M8V%C:&4@;F4@<R=E<W0@<&%S('1E<FUI;NEE+B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.3$V(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT.#4*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-#`@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$U-PIM<V=I9"`B0V%L96YD87(B
M"FUS9W-T<B`B06=E;F1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(S-0IM<V=I9"`B0V%L;2(*;7-G<W1R(")#86QM92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R(")#86UB;V1G92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C<*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(D-A;65R;W5N(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@
M<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(DEM<&]S<VEB;&4@9&4@<NEI;FET
M:6%L:7-E<B!L92!M;W0@9&4@<&%S<V4@875T;VUA=&EQ=65M96YT+"!C;VYT
M86-T97H@=F]T<F4@(@HB861M:6YI<W1R871E=7(@<WES=.AM92XB"@HC.B!F
M<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS-3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V%N(&YO="!W<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R("))
M;7!O<W-I8FQE(&1E('-U<'!R:6UE<B!L92!F:6-H:65R(*N@)7.@NRXB"@HC
M.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T
M97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B26UP;W-S
M:6)L92!D)V%D;6EN:7-T<F5R(&1E<R!G97-T:6]N;F%I<F5S(&1E('-E<W-I
M;VX@97AT97)N97,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP
M:'`Z,C,U(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS,3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E
M<CH@)7,B"FUS9W-T<B`BR6-H96,@9&4@;&$@8V]N;F5X:6]N(&%U('-E<G9E
M=7(@24U!4*`Z("5S(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M-#0V"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&]P96X@9FEL92!<(B5S
M7"(N(@IM<V=S='(@(DEM<&]S<VEB;&4@9"=O=79R:7(@;&4@9FEC:&EE<B"K
MH"5SH+LN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V%N861A(@IM<V=S='(@(D-A
M;F%D82(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,2!A9&UI;B]U<V5R+G!H<#HQ
M,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT
M-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8U
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,2!T96UP
M;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O<F5M;W9E+FEN8SHQ,@IM<V=I9"`B0V%N8V5L(@IM<V=S='(@
M(D%N;G5L97(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU
M.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(D%N;G5L
M97(@;&4@<F%P<&]R="!D=2!P<F]B;.AM92(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,S(S"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D
M96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@<W5P
M<')I;65R(&QE(&9I8VAI97(@JZ`E<Z"[+B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HT-@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R"FUS9VED(")#86YN;W0@9FEN
M9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(DEM<&]S<VEB;&4@
M9&4@=')O=79E<B!U;B!RZ7!E<G1O:7)E('1E;7!O<F%I<F4B"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.CDQ"FUS9VED(")#
M86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N
M(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@<')O8^ED97(@<V%N<R!L92!P87)A
M;>AT<F4@JR!T87)G971&:6QE(+LB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C,Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E
M(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@<W5P
M<')I;65R(&QE('+I<&5R=&]I<F4@JZ`E<Z"[+B(*"B,Z(&9R86UE=V]R:R]$
M871A5')E92]$871A5')E92YP:'`Z,3(X(&9R86UE=V]R:R]$871A5')E92]$
M871A5')E92]S<6PN<&AP.C8X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN
M;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`B4W5P<')E
M<W-I;VX@:6UP;W-S:6)L92P@:6P@>2!A("5D(&5N<F5G:7-T<F5M96YT<R!F
M:6QS+B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP
M.C8P.`IM<V=I9"`B(@HB0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R
M:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E
M<B`B"B)S=&]R960N(@IM<V=S='(@(B(*(DEM<&]S<VEB;&4@9&4@<NEO<F1O
M;FYE<BP@;&4@;F]M8G)E(&0GZ6SI;65N=',@X"!RZ6]R9&]N;F5R(&YE(&-O
M<G)E<W!O;F0@(@HB<&%S(&%U(&YO;6)R92!D)^ELZ6UE;G1S(&5N<F5G:7-T
M<NES+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E
M8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B3F4@<&5U="!D:7)I9V5R(&QE(&UE
M<W-A9V4@=F5R<R!L92!N;VUB<F4@<W#I8VEF:>DN(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HV-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM
M<V=I9"`B0V%P92!697)D92(*;7-G<W1R(")#87`M5F5R="(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*;7-G
M:60@(D-A<'1I;VXB"FUS9W-T<B`B3.EG96YD92(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R<FEE
M<B(*;7-G<W1R(")4<F%N<W!O<G1E=7(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.3,*;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R
M(")#873I9V]R:65S(&5T(,ET:7%U971T97,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I
M9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`BSFQE<R!#8>]M86XB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED
M(")#96QL(%!H;VYE(@IM<V=S='(@(E3I;.EP:&]N92!C96QL=6QA:7)E(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR-0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(E!R;W!R:>ET
MZ7,@9&4@;&$@8V5L;'5L92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S
M='(@(E)E;7!L:7-S86=E(&%U=&]U<B!D92!L82!C96QL=6QEH#HB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Q
M"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS9W-T<B`B4')O<')IZ73I<R!D
M92!L82!C96QL=6QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`B
M17-P86-E;65N="!D92!L82!C96QL=6QEH#HB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C<Q"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`B5.EL
MZ7!H;VYE(&-E;&QU;&%I<F4@(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#$*;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(D-E;'1E
M("A)4T\M.#@U.2TQ-"DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(V"FUS9VED(")#96YT97(B"FUS9W-T<B`B
M0V5N=')E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-E;G1R86P@069R:6-A;B!2
M97!U8FQI8R(*;7-G<W1R(")2Z7!U8FQI<75E(&-E;G1R869R:6-A:6YE(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G:60@(D-E;G1R86P@175R
M;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(D5U<F]PZ65N(&-E;G1R86P@
M*$E33RTX.#4Y+3(I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HW,#`*;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B
M1.ET86EL<R!D=2!C97)T:69I8V%T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV,3(*;7-G:60@(D-E<G1I9FEC871E($]W;F5R(@IM
M<V=S='(@(E!R;W!R:>ET86ER92!D=2!C97)T:69I8V%T(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-E<G1I9FEC
M871E(%!O;&EC:65S(@IM<V=S='(@(E!O;&ET:7%U92!D92!C97)T:69I8V%T
M:6]N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")#:&%D(@IM<V=S='(@(E1C:&%D
M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@IM<V=I9"`B0VAA;F=E(@IM<V=S='(@
M(DUO9&EF:65R(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,Q
M"FUS9VED(")#:&%N9V4@66]U<B!087-S=V]R9"(*;7-G<W1R(")-;V1I9FEE
M<B!V;W1R92!M;W0@9&4@<&%S<V4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-CD*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T
M:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO
M=7(@(@HB96UA:6QS+B(*;7-G<W1R("(B"B)#:&%N9V5R(&QE(&YO;2P@;"=A
M9')E<W-E(&5T(&QA('-I9VYA='5R92!Q=64@;&5S('!E<G-O;FYE<R!V;VEE
M;G0@<75A;F0@(@HB96QL97,@;&ES96YT(&5T('+I<&]N9&5N="#@('9O<R!M
M97-S86=E<RXB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*
M;7-G:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O
M<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#;VYT
M86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB3&$@;6]D:69I
M8V%T:6]N(&1E('9O=')E(&UO="!D92!P87-S92!N)V5S="!P87,@<W5P<&]R
M=.EE(&%V96,@;&$@(@HB8V]N9FEG=7)A=&EO;B!A8W1U96QL92X@0V]N=&%C
M=&5Z('9O=')E(&%D;6EN:7-T<F%T975R+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*;7-G:60@(D-H87(B
M"FUS9W-T<B`B0VAA<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB
M"FUS9W-T<B`B5NE?<FEF:65R(&QE(&QI96XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED
M(")#:&EL92(*;7-G<W1R(")#:&EL:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H
M:6YA(@IM<V=S='(@(D-H:6YE(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#,*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R
M(")#:&EN;VES('-I;7!L:69IZ2`H1T(R,S$R*2(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@T"FUS9VED(")#:&EN97-E(%1R861I=&EO;F%L("A":6<U
M*2(*;7-G<W1R(")#:&EN;VES('1R861I=&EO;FYE;"`H0FEG-2DB"@HC.B!T
M96UP;&%T97,O<')E9G,O87!P+FEN8SHW"FUS9VED(")#:&]O<V4@07!P;&EC
M871I;VXZ(@IM<V=S='(@(D-H;VES:7(@;"=A<'!L:6-A=&EO;J`Z(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W,`IM<V=I9"`B0VAO
M;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B0VAO:7-I<B!U;B!M;W0@9&4@<&%S
M<V4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS
M9VED(")#:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R(")#:&]I<VER('5N(&YO
M;2!D92!C;VYN97AI;VXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`R
M"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@
M(D-H;VES:7(@;&4@;6]D92!D)V%F9FEC:&%G92!D97,@9&%T97.@.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E
M<F5D(&QI<W1S*2(*;7-G<W1R(")#:&]I<VER(&QE('-T>6QE(&1E(&QI<W1E
M("AP;W5R(&QE<R!L:7-T97,@;G5MZ7)I<75E<RDB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS
M9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(LYL97,@0VAR:7-T;6%S
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.CDQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D
M969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`B1.EF:6YI=&EO
M;B!D92!L82!C;&%S<V4@9&4@)7,@;F]N('1R;W5VZ64N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*;7-G:60@(D-L96%R
M(@IM<V=S='(@(D5F9F%C97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S
M(@IM<V=S='(@(DYE='1O>65R(&QE<R!B86QI<V5S($U3+4]F9FEC92(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,CD*;7-G:60@(D-L96%R(%%U97)Y(@IM
M<V=S='(@(D5F9F%C97(@;&$@<F5Q=>IT92(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V-L96%R+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R
M(&]U="!U<V5R.B`E<R(*;7-G<W1R(")2971I<F5R(&PG=71I;&ES871E=7(Z
M("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$Q"FUS
M9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(D5F9F%C97(@;"=U=&EL:7-A=&5U
M<B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T"FUS9VED
M(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`B169F86-E<B!L97,@9&]N;NEE
M<R!D92!L)W5T:6QI<V%T975R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,34*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T
M<B`BR6-L86ER8VEE<R!T87)D(&1A;G,@;&$@:F]U<F[I92(*"B,Z('1E;7!L
M871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C8P"FUS9VED(")#
M;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R(")#;&EQ=65R('!O=7(@<&]U<G-U
M:79R92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R
M(")#;&EC:V%T96QL('9I82!(5%10(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N
M<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED(")#
M;&]S92!7:6YD;W<B"FUS9W-T<B`B1F5R;65R(&QA(&9E;NIT<F4B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(U,0IM<V=I9"`B0VQO=61S(@IM<V=S='(@
M(DYU86=E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$V"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`B3G5A9V5S(&UA
M=&EN875X(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,3<*;7-G:60@(D-L;W5D>2(*;7-G<W1R(").=6%G975X(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C4V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-`IM<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS9W-T<B`B
MSFQE<R!#;V-O<R(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z
M,C,*;7-G:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`B4F5P;&EE<B!L
M82!B87)R92!D92!C]'3I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E
M<G,B"FUS9W-T<B`B4NED=6ER92!L97,@8F]R9',B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS
M9VED(")#;VQO;6)I82(*;7-G<W1R(")#;VQO;6)I92(*"B,Z(&QI8B]";&]C
M:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS
M9VED(")#;VQO<B(*;7-G<W1R(")#;W5L975R(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,S-0HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S,V"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HU,#,@<V5R=FEC97,O:6UA9V5S+V-O
M;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHT.0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHV-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHV-@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHX,0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHX,@IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@
M(E!A;&5T=&4@9&4@8V]U;&5U<G,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.#(U"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@(E/I
M;&5C=&EO;B!D)W5N92!C;W5L975R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@
M(D-O;'.@.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#,*;7-G
M:60@(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B5&ET<F5S(&1E(&-O;&]N;F4B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8V"FUS9VED(")#;VUI
M8W,B"FUS9W-T<B`B0BY$+B(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-@IM
M<V=I9"`B0V]M;6%N9"(*;7-G<W1R(")#;VUM86YD92(*"B,Z(&%D;6EN+V-M
M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R(")#
M;VUM86YD92!S:&5L;"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R(")#;VUM96YT86ER92(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38W"FUS9VED
M(")#;VUM;VX@3F%M92(*;7-G<W1R(").;VT@=7-U96PB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-`IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R(")#;VUO<F5S(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M
M<&%N>2(*;7-G<W1R(")3;V-IZ73I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`B3W)D:6YA=&5U<G,B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@V"FUS9VED(")#
M;VYD:71I;VXB"FUS9W-T<B`B0V]N9&ET:6]N(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-38*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B0V]N9&ET
M:6]N<R(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF
M:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S='(@(D1I9F;I<F5N8V5S(&1E
M(&-O;F9I9W5R871I;VXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30V
M"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@
M4VUA<G1P:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@(B(*(E-Y;F-H<F]N
M:7-A=&EO;B!D97,@87-S:7-T86YT<R!P97)S;VYN96QS+"`\23YS;6%R='!H
M;VYE<SPO23X@970@3W5T;&]O:RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3,U"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*
M;7-G<W1R("),82!C;VYF:6=U<F%T:6]N(&XG97-T('!A<R#@(&IO=7(N(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B0V]N9FEG=7)E<B`E<R(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-3$*;7-G:60@(D-O
M;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B0V]N9FER;65R(&QE(&UO="!D92!P
M87-S92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-34@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O(@IM<V=S='(@(D-O;F=O
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E
M<'5B;&EC(&]F('1H92(*;7-G<W1R(")2Z7!U8FQI<75E(&3I;6]C<F%T:7%U
M92!D=2!#;VYG;R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C$Y-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS,#@*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R("+)
M8VAE8R!D92!L82!C;VYN97AI;VXB"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S`X"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@
M(@IM<V=S='(@(LEC:&5C(&1E(&QA(&-O;FYE>&EO;J`Z("(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C=&EO
M;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")#
M;VYN97AI;VX@874@<V5R=F5U<B!D92!C;&5F<R!P=6)L:6,@<F5F=7/I92XB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B0V]N;F5X
M:6]N(&%U('-E<G9E=7(@9&4@8VQE9G,@<'5B;&EC(')E9G5SZ64N(%)A:7-O
M;J`Z("`E<R`H)7,I(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX
M-S8*;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM
M<V=S='(@(LEC:&5C(&1E(&QA(&-O;FYE>&EO;B!A=2!S97)V975R($944"(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(T(&-O;F9I9R]H;V]K
M<RYP:'`N9&ES=#HQ,#8W"FUS9VED(")#;VYT86-T<R(*;7-G<W1R(")#;VYT
M86-T<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@
M=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(D-E<R!C;VYT86-T<R!O
M;G0@8FEE;B#I=.D@86IO=73I<R#@('9O=')E(&-A<FYE="!D)V%D<F5S<V5S
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-C`*
M;7-G:60@(D-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z("(*;7-G
M<W1R(")4>7!E(&1E(&-O;G1E;G4@9'4@9FEC:&EE<B!C;VUP<F5S<^F@.B`B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4V(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;VYT96YT<R!O9B!<(B5S7"(B"FUS9W-T<B`B0V]N=&5N=2!D
M92"KH"5SH+LB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.2!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S,*;7-G:60@(D-O;G1I;G5E
M(@IM<V=S='(@(E!O=7)S=6EV<F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;V]K
M($ES;&%N9',B"FUS9W-T<B`BSFQE<R!#;V]K(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,R"FUS9VED(")#;V]K:64B"FUS9W-T<B`B5.EM;VEN("AC
M;V]K:64I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(Q"FUS9VED(")#;W!Y(@IM<V=S='(@(D-O<&EE<B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#<R"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R("+)8VAE8R!D92!L
M82!C;W!I9:`Z("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B
M4^EL96-T:6]N(&0G=6YE(&-O<&EE(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B260N
M(&-O^W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;W-T82!2:6-A(@IM<V=S='(@
M(D-O<W1A(%)I8V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;W1E(&0G279O:7)E
M(@IM<V=S='(@(D/T=&4@9"=)=F]I<F4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HY-S<*;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP
M="!M97-S86=E.B`B"FUS9W-T<B`B26UP;W-S:6)L92!D92!C:&EF9G)E<B!L
M92!M97-S86=EH#H@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,3`U-0IM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z("(*
M;7-G<W1R(")3:6=N871U<F4@4$=0(&1U(&UE<W-A9V4@:6UP;W-S:6)L9:`Z
M("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,SDS"FUS
M9VED(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T
M<B`B26UP;W-S:6)L92!D92!C:&EF9G)E<B!L92!M97-S86=E(&%V96,@4R]-
M24U%+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#8W
M"FUS9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS9W-T
M<B`B4VEG;F%T=7)E(%,O34E-12!D=2!M97-S86=E(&EM<&]S<VEB;&4N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ
M.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T
M+B`E<R(*;7-G<W1R(")!:F]U="!D=2!C;VYT86-T("5S(&EM<&]S<VEB;&4N
M("(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$R,0HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-#4W"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E
M<G9E<BXB"FUS9W-T<B`B3F4@<&5U="!S92!C;VYN96-T97(@874@<V5R=F5U
M<B!,1$%0+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,34V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C$W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`B5NER:69I8V%T:6]N(&1E
M(&QA(&)A;&%N8V4@)7,@:6UP;W-S:6)L92X@(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C0T,0IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@3$1!
M4"!S97)V97(N(@IM<V=S='(@(LEC:&5C(&1E(&QA(&-O;FYE>&EO;B!A=2!S
M97)V975R($Q$05`N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E
M<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R("+)8VAE8R!D92!L82!C
M;VYN97AI;VX@874@<V5R=F5U<B"KH"5SH+L@=FEA($944*`Z("5S(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B0W+I871I;VX@9&4@;&ES=&4@9&4@
M9&ES=')I8G5T:6]N(&EM<&]S<VEB;&4N("5S(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3$R.`IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y
M<'0@4$=0(&1A=&$Z("(*;7-G<W1R("));7!O<W-I8FQE(&1E(&3I8VAI9F9R
M97(@;&5S(&1O;F[I97,@4$=0H#H@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU,C,*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%,O
M34E-12!D871A+B(*;7-G<W1R("));7!O<W-I8FQE(&1E(&3I8VAI9F9R97(@
M;&5S(&1O;F[I97,@4R]-24U%+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B3F4@<&5U
M="!P87,@<W5P<')I;65R(&QE(&-O;G1A8W0@)7,B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<R(*;7-G<W1R(").92!P975T('!A<R!S=7!P<FEM97(@;&$@;&ES=&4@
M9&4@9&ES=')I8G5T:6]N("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S
M971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(DYE('!E=70@
M<&%S('-U<'!R:6UE<B!L92!S8W)I<'0@9&4@;6ES92#@(&IO=7(@JZ`E<Z"[
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU,PIM<V=I9"`B0V]U;&0@
M;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N
M(@IM<V=S='(@(D3I=&5R;6EN871I;VX@9&4@;"=A9')E<W-E(&1U(&1E<W1I
M;F%T86ER92!I;7!O<W-I8FQE+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#;W5L9"!N;W0@9F5T
M8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R(").92!P975T('+I
M8W5PZ7)E<B!T;W5T(&QE(&-A<FYE="!D)V%D<F5S<V4N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*;7-G:60@
M(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="XB
M"FUS9W-T<B`B3F4@<&5U="!RZ6-U<.ER97(@=&]U=&4@;&$@;&ES=&4@9&4@
M9&ES=')I8G5T:6]N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-#0V"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE
M(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R
M(").)V$@<&%S('!U('+I8W5PZ7)E<B!L82!L:7-T92!C;VUP;.AT92!D92!L
M:7-T97,@9&4@9&ES=')I8G5T:6]N+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2YP:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&QO860@<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R("));7!O<W-I8FQE(&1E
M(&-H87)G97(@;&$@<W1R873I9VEE(*N@)7.@NRXB"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z,3$P"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R("))
M;7!O<W-I8FQE(&1E(&-RZ65R(&QE('+I<&5R=&]I<F4@JZ`E<Z"[+B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Q.0IM<V=I9"`B0V]U
M;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB
M"FUS9W-T<B`B26UP;W-S:6)L92!D)V]B=&5N:7(@;&$@8VQE9B!P=6)L:7%U
M92#@('!A<G1I<B!D=2!S97)V975R(&1E(&-L969S+B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HQ,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P
M96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R(")/=79E<G1U<F4@9&4@
MJZ`E<Z"[(&EM<&]S<VEB;&4@96X@Z6-R:71U<F4N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R(")/=79E
M<G1U<F4@9&4@)7,@:6UP;W-S:6)L92XB"@HC.B!F<F%M97=O<FLO36%I;G1E
M;F%N8V4O36%I;G1E;F%N8V4N<&AP.C0R,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*
M;7-G<W1R("));7!O<W-I8FQE(&0G;W5V<FER(&QE(&UO9'5L92!-86EN=&5N
M86YC95]487-K("5S(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N
M(@IM<V=S='(@(D]U=F5R='5R92!D=2!D;W-S:65R(*N@)7.@NR!I;7!O<W-I
M8FQE+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3$@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C,W(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HT-S@*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C4Q-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C$R
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-38@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Y.0IM<V=I9"`B0V]U;&0@;F]T
M(')E86-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B26UP;W-S:6)L92!D
M)V%T=&5I;F1R92!L92!S97)V975R($Q$05`N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O3V)J96-T+G!H<#HR-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(')E860@)7,N(@IM<V=S='(@(DQE8W1U<F4@9&4@)7,@:6UP;W-S
M:6)L92X@(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G
M:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R
M97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@
M87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G
M<W1R("(B"B).)V$@<'4@<F5M971T<F4@X"!ZZ7)O(&QE(&UO="!D92!P87-S
M92!P;W5R(&PG=71I;&ES871E=7(@9&5M86YDZ2X@0V5R=&%I;G,@(@HB*&]U
M('1O=7,I(&QE<R!DZ71A:6QS(&YE('-O;G0@<&%S(&-O<G)E8W1S+B!2Z65S
M<V%Y97H@;W4@8V]N=&%C=&5Z('9O=')E("(*(F%D;6EN:7-T<F%T975R('!O
M=7(@9&4@;"=A:61E+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,P-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS,S@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S<U"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,X,0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS.#<*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B
M4NEC=7#I<F%T:6]N(&1E<R!!0TP@:6UP;W-S:6)L92(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN
M("5S(@IM<V=S='(@(DYE('!E=70@<NEC=7#I<F5R(&QE(&-A<FYE="!D)V%D
M<F5S<V5S+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3F4@
M<&5U="!RZ6-U<.ER97(@;&$@;&ES=&4@9&4@9&ES=')I8G5T:6]N+B`E<R(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-#,W"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D
M:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@(DYE('!E=70@<NEC=7#I
M<F5R(&QE<R!L:7-T97,@9&4@9&ES=')I8G5T:6]N+B`E<R(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y-PHC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3<*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(Q"FUS9VED(")#;W5L9"!N
M;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@(DYE
M('!E=70@<NEC=7#I<F5R(&QE<R!P;W-S:6)I;&ETZ7,@9'4@<V5R=F5U<B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@(D-O=6QD(&YO
M="!R979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B3F4@<&5U="!P87,@
M<F5V96YI<B#@(&QA(&-O;F9I9W5R871I;VX@<'+I8^ED96YT92XB"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDO8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`B169F86-E;65N="!D=2!D;W-S
M:65R(*N@)7.@NR!I;7!O<W-I8FQE+B`B"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V
M92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(").92!P975T('!A<R!E;G)E
M9VES=')E<B!L82!C;VYF:6=U<F%T:6]N("5S(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y"FUS9VED
M(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S
M='(@(DYE('!E=70@<&%S(&5N<F5G:7-T<F5R('5N92!S875V96=A<F1E(&1E
M(&QA(&-O;F9I9W5R871I;VXN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C8Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C
M:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B26UP;W-S:6)L92!D)V5N
M<F5G:7-T<F5R('5N92!C;W!I92!D92!L82!C;VYF:6=U<F%T:6]NH#H@)7,B
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T
M;SH@7"(E<UPB+B(*;7-G<W1R("));7!O<W-I8FQE(&0G96YR96=I<W1R97(@
M;&4@<V-R:7!T(&1E(&UI<V4@X"!J;W5R(&1A;G.@.B"KH"5SH+LN(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL
M92`E<RXB"FUS9W-T<B`B26UP;W-S:6)L92!D)V5N<F5G:7-T<F5R('5N92!C
M;W!I92!D=2!F:6-H:65R(&1E(&-O;F9I9W5R871I;VX@)7,N(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9
M;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A
M=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C
M;V1E(&)E;&]W('1O("5S+B(*;7-G<W1R("(B"B));7!O<W-I8FQE(&0G96YR
M96=I<W1R97(@;&4@9FEC:&EE<B!D92!C;VYF:6=U<F%T:6]N("5S+B!6;W5S
M('!O=79E>B!S;VET("(*(G5T:6QI<V5R('5N92!D97,@;W!T:6]N<R!P;W5R
M('-A=79E<B!L92!C;V1E('-U<B`E<R!S;VET(&-O<&EE<B!M86YU96QL96UE
M;G0@(@HB;&4@8V]D92!C:2UD97-S;W5S(&1A;G,@)7,N(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-#,*;7-G:60@(D-O=6QD(&YO="!S
M96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R(").92!P975T('!A<R!R
M96-H97)C:&5R(&QE('-E<G9E=7(@3$1!4"XB"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<
M(B5S7"(N(@IM<V=S='(@(E-U<'!R97-S:6]N(&1E(*N@)7.@NR!I;7!O<W-I
M8FQE+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A
M=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B36ES92#@(&IO=7(@9'4@8V]N=&%C
M="!I;7!O<W-I8FQE+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@
M(DYE('!E=70@;65T=')E(.`@:F]U<B!L82!L:7-T92!D92!D:7-T<FEB=71I
M;VXN("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O
M<B!<(B5S7"(Z("5S(@IM<V=S='(@(DYE('!E=70@<&%S(&5N<F5G:7-T<F5R
M(&QA(&-O;F9I9W5R871I;VX@<&]U<B"KH"5SH+N@.B`E<R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-S`*;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE
M($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P
M96XN(@IM<V=S='(@(DYE('!E=70@=')O=79E<B!L82!B87)R92!D92!-;WII
M;&QA+B`@07-S=7)E>BUV;W5S('%U)V5L;&4@97-T(&%C=&EV92XB"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T
M:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S
M(@IM<V=S='(@(B(*(DYE('!E=70@871T<FEB=65R(&-E<R!D<F]I=',@X"!L
M)W5T:6QI<V%T975R(*N@)7.@NR`@<W5R(&QE(&1O<W-I97(@JZ`E<Z"[H#H@
M(@HB)7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#$V"FUS9VED
M(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B5&5X=&4@8V]M<'3I(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@(D-O=6YT
M<GDB"FUS9W-T<B`B4&%Y<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR-S4*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B0V]U<G,B"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ
M,#`*;7-G:60@(D-R96%T92(*;7-G<W1R(")#<NEE<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I
M9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R(")#<NEE<B!U;B!L:65N(@H*(SH@
M=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY-`IM<V=I9"`B
M0W)E871E(&$@;F5W(&]N92(*;7-G<W1R(")#<NEE<B!U;B!N;W5V96%U(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3(*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@
M(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R(")#<NEE<B!U;B!S;W5S+61O
M<W-I97(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(T,`IM
M<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*;7-G<W1R(")097)M:7-S:6]N
M<R!$92!#<NEA=&5U<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R
M,#D*;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R(").=6WI<F\@
M9&4@8V%R=&4@9&4@8W+I9&ET(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(D-R;V%T
M:6$B"FUS9W-T<B`B0W)O871I92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B
M"FUS9W-T<B`B0W5B82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-@IM<V=I
M9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R("(T('!H87-E<R!C;W5R86YT
M97,B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*;7-G:60@(D-U<G)E;G0@
M4V5S<VEO;G,B"FUS9W-T<B`B4V5S<VEO;G,@96X@8V]U<G,B"@HC.B!L:6(O
M0FQO8VLO=&EM92YP:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@
M(D-U<G)E;G0@5&EM92(*;7-G<W1R(")(975R92!A8W1U96QL92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T<B`B3"=A9')E<W-E(%52
M3"!A8W1U96QL92!E<W0B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S4*;7-G
M:60@(D-U<G)E;G0@57-E<G,B"FUS9W-T<B`B571I;&ES871E=7)S(&%C='5E
M;',B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS9VED(")#=7)R96YT
M(%=E871H97(B"FUS9W-T<B`B3V)S97)V871I;VYS(&%C='5E;&QE<R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-C0*;7-G:60@(D-U<G)E
M;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`B0V]N9&ET:6]N(&%C='5E;&QEH#H@
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R(")3='EL92!C;W5R86YT
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@
M)7,N(@IM<V=S='(@(D3I9FEN:7(@;&5S('3B8VAE<R#@(&5F9F5C='5E<B!L
M;W)S(&1E(&QA(&-O;FYE>&EO;B#@("5S+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T
M(@IM<V=S='(@(D-O=7!E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I;VXB"FUS9W-T
M<B`B0V]U<&5R(&QA('/I;&5C=&EO;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-Y
M<')U<R(*;7-G<W1R(")#:'EP<F4B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X-0IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`B0WER:6QL
M:7%U92`H2T])."U2*2(*"B,@8V]N9FEG+VYL<RYP:'`N9&ES=#H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@(D-Y<FEL;&EC("A7:6YD;W=S
M+3$R-3$I(@IM<V=S='(@(D-Y<FEL;&EQ=64@*%=I;F1O=W,M,3(U,2DB"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-PIM<V=I9"`B0WER:6QL:6,O56MR
M86EN:6%N("A+3TDX+54I(@IM<V=S='(@(D-Y<FEL;&EQ=64O56MR86EN:65N
M("A+3TDX+54I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B
M"FUS9W-T<B`B4NEP=6)L:7%U92!48VCH<75E(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHU,`IM<V=I9"`B1$0B"FUS9W-T<B`B2DHB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,C8Y"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O
M<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN
M=')O+61S;BYP:'`I(@IM<V=S='(@(B(*(D133B`H0V8N(&AT='`Z+R]P96%R
M+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M
M9'-N+G!H<"DB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R(")#:&%Q=64@:F]U<B(*
M"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I9"`B1&%T851R964@0G)O
M=W-E<B(*;7-G<W1R(").879I9V%T975R(&1E($1A=&%4<F5E(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(V-PIM<V=I9"`B1&%T86)A<V4@3&]O
M:W5P(@IM<V=S='(@(D%L:6%S(&1E(&QA(&)A<V4B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(S.34*;7-G:60@(D1A=&4B"FUS9W-T<B`B1&%T92(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED(")$
M871E(%)E8V5I=F5D(@IM<V=S='(@(D1A=&4@9&4@<NEC97!T:6]N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<X-@IM<V=I9"`B1&%T92!S96QE
M8W1I;VXB"FUS9W-T<B`B4^EL96-T:6]N(&0G=6YE(&1A=&4B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Q(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS,3$*;7-G:60@(D1A>2(*;7-G<W1R(")*;W5R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,V"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G<W1R(")3=7!P<FEM97(@
M7VQA(&-O;&]N;F4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#$S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-3$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHW-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B1.EC96UB<F4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C$V"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B3F]M
M8G)E<R!DZ6-I;6%U>"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C`*;7-G:60@(D1E8W)E87-E($EN9&5N="(*;7-G<W1R
M(")$:6UI;G5E<B!L)VEN9&5N=&%T:6]N(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ.#<@;&EB+W!R969S+G!H<#HQ,3<*;7-G:60@(D1E
M9F%U;'0B"FUS9W-T<B`B1.EF875T(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-S<*;7-G:60@(D1E9F%U;'0@0V]L;W(B
M"FUS9W-T<B`B0V]U;&5U<B!P87(@9.EF875T(@H*(SH@9G)A;65W;W)K+TED
M96YT:71Y+TED96YT:71Y+G!H<#HY-@IM<V=I9"`B1&5F875L="!)9&5N=&ET
M>2(*;7-G<W1R("))9&5N=&ETZ2!P87(@9.EF875T(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C8W"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@
M(DEN=&5R<'+I=&5U<B!D92!C;VUM86YD92!P87(@9.EF875T(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I;FET:6]N<R(*;7-G
M<W1R(")$Z69I;FET:6]N<R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C8*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HT,C(@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HT,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C<P"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z.3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ.#(*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY.`HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*;7-G<W1R(")%9F9A8V5R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,R"FUS9VED(")$96QE=&4@0V5L;"(*;7-G<W1R(")%9F9A8V5R
M(&QA(&-E;&QU;&4B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G
M<F]U<',N<&AP.C(R-PIM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@(E-U
M<'!R:6UE<B!U;B!G<F]U<&4B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR-#D*;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T<B`B169F86-E<B!L
M82!T<F%C92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S<@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#$*;7-G:60@(D1E;&5T
M92!097)M:7-S:6]N(@IM<V=S='(@(E-U<'!R:6UE<B!U;F4@<&5R;6ES<VEO
M;B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDS
M"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(E-U
M<'!R:6UE<B!E="!P=7)G97(@;&5S(&UE<W-A9V5S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B
M1&5L971E(&-E;&PB"FUS9W-T<B`B169F86-E<B!L82!C96QL=6QE(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M,PIM<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R(")%9F9A8V5R(&QA(&-O
M;&]N;F4B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L
M971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R(")3=7!P
M<FEM97(@=6X@875T<F4@;6]DZ&QE(&5X:7-T86YT(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-30*;7-G:60@(D1E;&5T92!M
M97-S86=E<R(*;7-G<W1R(")3=7!P<FEM97(@;&5S(&UE<W-A9V5S(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T
M<B`B4W5P<')I;65R(&QE<R!P97)M:7-S:6]N<R!P;W5R(*N@)7.@NR(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(T"B,L('!H<"UF;W)M
M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A
M;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R("+*=&5S+79O=7,@8V5R=&%I
M;B!D92!V;W5L;VER(&5F9F%C97(@JZ`E<Z"[(&5T('-E<R!S;W5S+7!E<FUI
M<W-I;VYSH#\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@<F]W(@IM<V=S='(@(D5F
M9F%C97(@;&$@<F%N9^EE(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E;&5T96ED
M96YT:71Y+FEN8SHQ-0IM<V=I9"`B1&5L971E('-E;&5C=&5D(&ED96YT:71Y
M(@IM<V=S='(@(E-U<'!R:6UE<B!L)VED96YT:73I('/I;&5C=&EO;F[I92(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4S"FUS
M9VED(")$96QE=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B4W5P<')I;65R('5N
M('-O=7,M9&]S<VEE<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E('1H92!C=7)R
M96YT(&-O;'5M;B(*;7-G<W1R(")%9F9A8V5R(&QA(&-O;&]N;F4@86-T=65L
M;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS
M9W-T<B`B169F86-E<B!L82!R86YGZ64@86-T=65L;&4B"@HC.B!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HS-@HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE
M=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B4V-R
M:7!T(&1E(&-O;F9I9W5R871I;VX@9&4@;6ES92#@(&IO=7(@<W5P<')I;>D@
MJZ`E<Z"[+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-38S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3DU"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(R,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*;7-G:60@(D1E;&EV97)Y('1I;64B
M"FUS9W-T<B`B2&5U<F4@9&4@;&EV<F%I<V]N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I
M9"`B1&5N;6%R:R(*;7-G<W1R(")$86YE;6%R:R(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@4')O
M8FQE;2(*;7-G<W1R(")$Z6-R:7)E(&QE('!R;V)LZ&UE(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.3,U('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*;7-G:60@(D1E<V-R:7!T:6]N(@IM
M<V=S='(@(D1E<V-R:7!T:6]N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HR,#8*;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F
M:6QE*3HB"FUS9W-T<B`B1.ET86EL<R`H875S<VD@9&%N<R!L92!F:6-H:65R
M(&1E('1R86-E<R!D92!(;W)D92F@.B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,C$P"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@
M9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("),97,@9.ET86EL<R!O
M;G0@Z73I(&-O;G-I9V[I<R!P;W5R(&PG861M:6YI<W1R871E=7(N(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R,0IM<V=I9"`B1&5V96QO<&UE
M;G0B"FUS9W-T<B`B1.EV96QO<'!E;65N="(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C(T"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B4&]I;G0@9&4@
M<F]SZ64B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P,0IM<V=I9"`B1&5W
M(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")0;VEN="!D92!R;W/I
M92!P;W5R(&QA(&1E<FYIZ')E(&AE=7)EH#H@(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Q-@IM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T
M<B`B4&]I;G0@9&4@<F]SZ66@.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T
M;R!R:6=H="(*;7-G<W1R(")$92!G875C:&4@X"!D<F]I=&4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$
M:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R(")$92!D<F]I=&4@X"!G
M875C:&4B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER
M96-T;W)Y(@IM<V=S='(@(E+I<&5R=&]I<F4B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C<P"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM
M<V=S='(@(D%F9FEC:&5R('-U<B`R-"!H975R97.@/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,#`*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G
M<W1R(")/<'1I;VYS(&0G869F:6-H86=E(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C@Y"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C
M87-T(@IM<V=S='(@(D%F9FEC:&5R(&QA('!RZ79I<VEO;B!DZ71A:6QLZ64B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.CDR"FUS9VED(")$:7-P;&%Y(&9O
M<F5C87-T("A4048I(@IM<V=S='(@(D%F9FEC:&5R(&QA('!RZ79I<VEO;B`H
M5$%&*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W.38*;7-G:60@
M(D1I<W!L87D@9F]R;6%T(@IM<V=S='(@(D9O<FUA="!D)V%F9FEC:&%G92(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HQ.3$*;7-G:60@(D1I
M<W!O<VET:6]N($YO=&EF:6-A=&EO;B(*;7-G<W1R(")!=FES(&1E(&QI=G)A
M:7-O;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(D1J
M:6)O=71I(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(*
M;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B3F4@<&%S('-U<'!R:6UE
M<B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR-0IM<V=I9"`B1&\@
M;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'`B"FUS9W-T<B`B
M3F4@<&%S(&%C8^ED97(@9&ER96-T96UE;G0@X"!M86EN=&5N86YC92YP:'`B
M"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,B!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W
M(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@
M8F]X.B(*;7-G<W1R("(B"B),92!P<F5M:65R(&5N<F5G:7-T<F5M96YT(&-O
M;G1I96YT+6EL(&QE(&YO;2!D97,@8VAA;7!SH#\@1&%N<R`B"B)L)V%F9FER
M;6%T:79E+"!C;V-H97H@8V5T=&4@8F_N=&6@.B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HW,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G
M:60@(D1O;6EN:6-A(@IM<V=S='(@(D1O;6EN:7%U92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*
M;7-G:60@(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R(")2Z7!U8FQI<75E
M(&1O;6EN:6-A:6YE(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY
M-@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+B(*;7-G
M<W1R(")6;W5S(&XG879E>B!P87,@9&4@8V]M<'1EH#\@16YR96=I<W1R97HM
M=F]U<RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX
M-3$*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(E3I;.EC:&%R9V5R(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#4Q"B,L('!H<"UF
M;W)M870*;7-G:60@(D1O=VYL;V%D("5S(@IM<V=S='(@(E3I;.EC:&%R9V5R
M("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W
M;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB
M"FUS9W-T<B`B5.ELZ6-H87)G97(@;&$@8V]N9FEG=7)A=&EO;B!GZ6[I<NEE
M(&-O;6UE('5N('-C<FEP="!02%`B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,3`T"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R("),:7-T
M92!DZ7)O=6QA;G1E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,T"FUS
M9VED(")$<G5G<R(*;7-G<W1R(")$<F]G=65S(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")%+4UA:6PB"FUS9W-T<B`B
M0V]U<G)I97(@Z6QE8W1R;VYI<75E(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G
M871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI
M<R!S97)V:6-E+B(*;7-G<W1R("(B"B)0:6QO=&4@9&4@<&%S<V5R96QL92!C
M;W5R<FEE<B`O(%--4RP@<&]U<B!L97,@9F]U<FYI<W-E=7)S(&1E(&-E('-E
M<G9I8V4N(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I
M;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@
M(D524B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`BR7%U
M871E=7(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-2!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X
M,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*;7-G:60@(D5D:70B
M"FUS9W-T<B`B36]D:69I97(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M54DN<&AP.C4P"FUS9VED(")%9&ET($)L;V-K(@IM<V=S='(@(LED:71E<B!L
M92!B;&]C(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S
M+G!H<#HR,C8*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T<B`BR61I=&5R('5N
M(&=R;W5P92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S8@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#`*;7-G:60@(D5D:70@
M4&5R;6ES<VEO;B(*;7-G<W1R("+)9&ET97(@=6YE('!E<FUI<W-I;VXB"@HC
M.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"FUS9VED(")%9&ET(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(LED:71E<B!L97,@<&5R;6ES<VEO;G,B"@HC
M.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(LED:71E
M<B!L97,@<&5R;6ES<VEO;G,@<&]U<B"KH"5SH+LB"@HC.B!T96UP;&%T97,O
M<')E9G,O87!P+FEN8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G
M<W1R("+)9&ET97(@;&5S(&]P=&EO;G,@<&]U<J`Z(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M161I="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(LED:71E<B!L
M97,@<&5R;6ES<VEO;G,@<&]U<B"KH"5SH+LB"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R
M;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(LED:71E<B!L97,@<&5R;6ES<VEO
M;G,@<&]U<B`E<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0IM<V=I
M9"`B161U8V%T:6]N(@IM<V=S='(@(LED=6-A=&EO;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*
M;7-G:60@(D5G>7!T(@IM<V=S='(@(LEG>7!T92(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM
M<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B4V%L=F%D;W(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*
M;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`BR6SI;65N="XN+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED
M(")%;2(*;7-G<W1R(")%;2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HR,C0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V
M-@IM<V=I9"`B16UA:6PB"FUS9W-T<B`B061R97-S92#I;&5C=')O;FEQ=64B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$P"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C@*;7-G:60@(D5M86EL($%D9')E<W,B
M"FUS9W-T<B`B061R97-S92#I;&5C=')O;FEQ=64B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.38P"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S
M="!M871C:"XB"FUS9W-T<B`B3&5S(&%D<F5S<V5S(.EL96-T<F]N:7%U97,@
M9&]I=F5N="!C;W)R97-P;VYD<F4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3DX-@IM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M871I;VXB"FUS
M9W-T<B`B0V]U<G)I97(@879E8R!C;VYF:7)M871I;VXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA
M:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B4&%S<V5R96QL92!C;W5R<FEE
M<B`O(%--4R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR.3D*;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R("+);6]T:6/T;F5S
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`R"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R(")-97-S86=E
M('9I9&4N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(T
M,R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-C(@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R(")2Z7-U
M;'1A="!V:61E+B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H
M<#HQ,3,*;7-G:60@(D5M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R(")497)M
M97,@9&4@<F5C:&5R8VAE('9I9&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-30W"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M
M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R(")!8W1I=F5R(&PG
M:6YS97)T:6]N(&0G:6UA9V5S('9E;F%N="!D97,@86QB=6US('!H;W1O<R!D
M86YS(&QE('1E>'1EH#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(R
M"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*;7-G
M<W1R(")!8W1I=F5R(&QE(&UE;G4@8V]N=&5X='5E;"!A=F5C('5N(&-L:6,@
M9')O:72@/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.#4@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<Y,`IM<V=I9"`B16YD('EE87(B"FUS
M9W-T<B`B1FEN(&1E(&PG86YNZ64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*
M;7-G<W1R(")!9W)A;F1I<B!L)^ED:71E=7(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C(T"FUS9VED("(B"B)%;G1E<B!A('-E8W5R:71Y('%U97-T
M:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E
M<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@
M;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@HBR6-R:79E>B!U;F4@<75E<W1I
M;VX@9&4@<^EC=7)I=.D@<74G;VX@=F]U<R!P;W-E<F$@<VD@=F]U<R!D979E
M>B!R96UE='1R92#@("(*(GKI<F\@=F]T<F4@;6]T(&1E('!A<W-E+"!P87(@
M97AE;7!L92"K(%%U96P@97-T(&QE(&YO;2!D92!V;W1R92!A;FEM86P@(@HB
M<'+I9NERZ:`_H+N@.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE(&EM
M86=E(%523"!H97)E(@IM<V=S='(@(DEN<V-R:79E>B!L)V%D<F5S<V4@55),
M(&1E(&PG:6UA9V4@:6-I(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C@Y,@IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L
M;W<Z(@IM<V=S='(@(D5N=')E>B!L97,@;&5T=')E<R!C:2UD97-S;W5SH#HB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDY(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<V"FUS9VED(")%<75A=&]R:6%L($=U:6YE82(*;7-G<W1R
M(")'=6ENZ64@Z7%U871O<FEA;&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%<FET
M<F5A(@IM<V=S='(@(LER>71H<NEE(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+U9I97<N<&AP.CDT(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT.`HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,V"FUS9VED(")%<G)O<B(*;7-G<W1R(")%<G)E=7(B"@HC.B!F<F%M
M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,B"FUS9W-T<B`B17)R
M975R(&QO<G,@9&4@;&$@8W+I871I;VX@9'4@8FQO8Z`Z("5S(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S(@IM<V=S='(@(D5R
M<F5U<B!L;W)S(&1E(&QA('-U<'!R97-S:6]N(&1E(&PG86YC<F4@9&4@<WEN
M8VAR;VYI<V%T:6]NH#H@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S
M>6YC(&QO9SH@)7,B"FUS9W-T<B`B17)R975R(&QO<G,@9&4@;&$@<W5P<')E
M<W-I;VX@9'4@:F]U<FYA;"!D92!S>6YC:')O;FES871I;VZ@.B`E<R(*"B,Z
M(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8X"B,L('!H<"UF
M;W)M870*;7-G:60@(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS9W-T
M<B`B17)R975R(&QO<G,@9&4@;&$@<NEC=7#I<F%T:6]N(&1U(&-O;G1E;G6@
M.B`E<R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B
M"FUS9W-T<B`B17)R975R(&QO<G,@9&4@;&$@;6ES92#@(&IO=7(@9'4@;6]T
M(&1E('!A<W-EH#H@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@
M;65S<V%G92XB"FUS9W-T<B`B17)R975R(&%V96,@;&4@;65S<V%G92XB"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R
M<F]R('=R:71I;F<@7"(E<UPB+B(*;7-G<W1R(")%<G)E=7(@;&]R<R!D92!L
M)V5N<F5G:7-T<F5M96YT(&1E(*N@)7.@NRXB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED
M(")%<W1O;FEA(@IM<V=S='(@(D5S=&]N:64B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED
M(")%=&AI;W!I82(*;7-G<W1R("+)=&AI;W!I92(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S='(@(D5T:&YI<75E
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%
M=7)O<&4B"FUS9W-T<B`B175R;W!E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,T,PIM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R(")4;W5S
M(&QE<R`F9G)A8S$T.R!D)VAE=7)E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,Y,PIM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(E1O=71E
M<R!L97,@,B!M:6YU=&5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T
M,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")%=F5R>2`S,"!S
M96-O;F1S(@IM<V=S='(@(E1O=71E<R!L97,@,S`@<V5C;VYD97,B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0R(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS.30*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R(")4;W5T97,@
M;&5S(#4@;6EN=71E<R(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN
M=&5N86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S='(@(L`@
M8VAA<75E(&-O;FYE>&EO;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-#0*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R(")4;W5T97,@;&5S
M("9F<F%C,3([(&AE=7)E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-#$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,@IM<V=I9"`B179E<GD@;6EN
M=71E(@IM<V=S='(@(E1O=71E<R!L97,@;6EN=71E<R(*"B,Z('1E;7!L871E
M<R]D871A+V1A=&5M87`N:6YC.C(T"FUS9VED(")%>&%M<&QE('9A;'5E<SHB
M"FUS9W-T<B`B17AE;7!L92!D92!V86QE=7)SH#HB"@HC.B!A9&UI;B]P:'!S
M:&5L;"YP:'`Z.#(@861M:6XO8VUD<VAE;&PN<&AP.C4Q(&%D;6EN+W-Q;'-H
M96QL+G!H<#HQ,C@*;7-G:60@(D5X96-U=&4B"FUS9W-T<B`B17CI8W5T97(B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C8Q-`IM<V=I9"`B17AP86YD(@IM<V=S='(@(D3I=F5L;W!P97(B"@HC.B!T
M96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R"FUS9VED(")%>'!A;F0@
M4VED96)A<B(*;7-G<W1R(")$Z7!L:65R(&QA(&)A<G)E(&1E(&/T=.DB"@HC
M.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%
M>'!E8W1E9"`G*2<B"FUS9W-T<B`BJR`I(+L@871T96YD=64B"@HC.B!F<F%M
M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E
M9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@(E5N
M('-E=6P@;6]T(&]U(&5X<')E<W-I;VX@96YT<F4@9W5I;&QE;65T<R!A='1E
M;F1U<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM
M<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@(D1A=&4@9"=E>'!I<F%T
M:6]N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S<*
M;7-G:60@(D5X<&]N96YT(@IM<V=S='(@(E)E<'+I<V5N=&%N="(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S$*
M;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(D-O=6QE=7(@9"=A=F%N="UP;&%N
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I9"`B1E10('5P
M;&]A9"!O9B!S971U<"(*;7-G<W1R(")4Z6SI8VAA<F=E;65N="!V97)S(&QE
M('-E<G9E=7(@9&4@;&$@8V]N9FEG=7)A=&EO;B!P87(@1E10(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+W-Q;"YP:'`Z,C(P"FUS9VED(")&86EL960@
M<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`B3&5C='5R92!D97,@
M<'+I9NER96YC97,@:6UP;W-S:6)L92XB"@HC.B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N
M(@IM<V=S='(@(LEC:&5C(&1E(&QA(&-O;FYE>&EO;B!A=2!S97)V975R($Q$
M05`N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.CDX"FUS9VED
M(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*;7-G<W1R("+)
M8VAE8R!D92!L82!C;VYN97AI;VX@874@<V5R=F5U<B!334(N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,3<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@(LEC:&5C
M(&1E(&QA(&-O<&EE(&1E<'5I<R"KH"5SH+LN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HW,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D
M('1O(&-O<'D@=&\@7"(E<UPB+B(*;7-G<W1R("+)8VAE8R!D92!L82!C;W!I
M92!V97)S(""KH"5SH+LN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L
M+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN
M96-T:6]N+B(*;7-G<W1R("));7!O<W-I8FQE(&1E(&-RZ65R('5N92!N;W5V
M96QL92!C;VYN97AI;VX@4T%33"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z-3`Q(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4U"B,L('!H
M<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS
M9W-T<B`BR6-H96,@9'4@9.EP;&%C96UE;G0@=F5R<R"KH"5SH+LN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G<W1R("+)8VAE8R!L
M;W)S(&1E(&QA('+I8W5PZ7)A=&EO;J`Z("5S(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T
M<B`B0F5A=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML86YD($ES;&%N9',@
M*$UA;'9I;F%S*2(*;7-G<W1R("+.;&5S($9A;&ML86YD("A-86QO=6EN97,I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R("+.
M;&5S($;I<F_I(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(S.`IM<V=I
M9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@(D5R<F5U<B!F871A;&6@.B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G
M:60@(D9A>"(*;7-G<W1R(")&87@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S4Q"FUS9VED(")&87AE<R(*;7-G<W1R(")4Z6SI8V]P:65S(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,PHC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Q"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G
M:60@(D9E8G)U87)Y(@IM<V=S='(@(D;I=G)I97(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(R-PIM<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R(")496UP
MZ7)A='5R92!R97-S96YT:64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C(P"FUS9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B5&5M<.ER
M871U<F4@<F5S<V5N=&EEH#H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S='(@
M(E%U96QQ=65S(&%V97)S97,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G
M<W1R(")1=65L<75E<R!C:'5T97,@9&4@;F5I9V4B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.30Q"FUS9VED(")&:65L9"!M871R:7@B"FUS9W-T
M<B`B36%T<FEC92!D97,@8VAA;7!S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S,R,@IM<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS9W-T<B`B1FEG
M;&5T($-!4%1#2$$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(V
M"FUS9VED(")&:6=L970@9F]N="(*;7-G<W1R(")0;VQI8V4@9&4@;&$@/$D^
M9FEG;&5T/"])/B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B
M1FED:FDB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G
M:60@(D9I;&4B"FUS9W-T<B`B1FEC:&EE<B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z
M("5S(&9I;&4B"FUS9W-T<B`B3F]M8G)E(&1E(&9I8VAI97)SH#H@)7,B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R(").;VUB<F4@9&4@
M9FEC:&EE<G.@.B`E<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M,#D*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R(")'97-T:6]N;F%I<F4@
M9&4@9FEC:&EE<G,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C8S(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,@IM
M<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(DYO;2!D=2!F:6-H:65R(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDW-`IM<V=I9"`B1FEL92!S96QE
M8W1I;VXB"FUS9W-T<B`B0VAO:7@@9&4@9FEC:&EE<B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$T.#,*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S
M='(@(E3I;.EC:&%R9V5M96YT(&1E(&9I8VAI97(B"@HC.B!F<F%M97=O<FLO
M0G)O=W-E<B]"<F]W<V5R+G!H<#HY,#(*;7-G:60@(D9I;&4@=7!L;V%D<R!N
M;W0@<W5P<&]R=&5D+B(*;7-G<W1R("),)V5N=F]I(&1E(&9I8VAI97)S(&XG
M97-T('!A<R!P<FES(&5N(&-O;7!T92XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z.3$*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`B1FEL=')E<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S$*;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`B1FEN;&%N9&4B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED(")&:7)S="!(86QF
M(@IM<V=S='(@(E!R96UIZ')E(&1E;6EE(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A
M<G1E<B(*;7-G<W1R(")0<F5M:65R('%U87)T:65R(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U-PIM<V=I9"`B1FEX(')A
M=&EO(@IM<V=S='(@(D9I>&5R(&QE(')A=&EO(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,@IM<V=I9"`B1FQI<"(*;7-G
M<W1R(")2971O=7)N97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R(")&
M;&]T=&%N="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B0G)O=6EL;&%R9"(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C,W(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HQ,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S
M(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(D1O<W-I97(@)7,@:6YE>&ES=&%N
M="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(D-O=6QE=7(@9&4@<&]L
M:6-E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS9VED(")&;V]D
M(@IM<V=S='(@(DYO=7)R:71U<F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$R,PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C8*;7-G:60@(D9O<B!B
M<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@(E!O
M=7(@;&5S(&YA=FEG871E=7)S(&YE('-U<'!O<G1A;G0@<&%S(&QE<R!I;6%G
M97,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T,0IM<V=I9"`B1F]R96-A
M<W0@*%1!1BDB"FUS9W-T<B`B4'+I=FES:6]N("A4048I(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C<R"FUS9VED("(B"B)&;W)E8V%S="!$
M87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@
M8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O
M=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*(DIO=7)S
M(&1E('!RZ79I<VEO;B`H;F]T97H@<75E(&QE<R!P<NEV:7-I;VYS(&9O=7)N
M:65S(&1O;FYE;G0@;&4@:F]U<B!E="!L82`B"B)N=6ETH#L@=6X@9W)A;F0@
M;F]M8G)E(&EC:2!P975T(&9A:7)E('5N(&)L;V,@='+H<R!L87)G92(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3`R"FUS9VED(")&;W)G;W0@
M>6]U<B!P87-S=V]R9#\B"FUS9W-T<B`B5F]U<R!A=F5Z(&]U8FQIZ2!V;W1R
M92!M;W0@9&4@<&%S<V6@/R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT-C0*;7-G:60@(D9O<FUS(@IM<V=S='(@(D9O<FUU;&%I<F5S(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"FUS9VED(")&;W)T=6YE(@IM<V=S
M='(@(D-I=&%T:6]N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS
M9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B5'EP92!D92!C:71A=&EO;B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM<V=I9"`B1F]R='5N97,B
M"FUS9W-T<B`B0VET871I;VYS(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,Y"FUS9VED(")&;W)T=6YE<R`R(@IM<V=S='(@(D-I=&%T:6]N<R`R(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U-0IM<V=I9"`B1F]R=6US
M(@IM<V=S='(@(D9O<G5M<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ,3$*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(E)E9&ER96-T:6]N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,`IM
M<V=I9"`B1G(B"FUS9W-T<B`B5F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S"FUS9VED(")&<F%M97,B"FUS
M9W-T<B`B0V%D<F5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E(@IM<V=S
M='(@(D9R86YC92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,PIM<V=I9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B1G)A;F-E
M(&WI=')O<&]L:71A:6YE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U
M:6%N82(*;7-G<W1R(")'=7EA;F4@9G)A;N=A:7-E(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*
M;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B4&]L>6[I<VEE(&9R
M86[G86ES92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H97)N
M(%1E<G)I=&]R:65S(@IM<V=S='(@(E1E<G)E<R!A=7-T<F%L97,@970@86YT
M87)C=&EQ=65S(&9R86[G86ES97,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S='(@(D1E
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-R!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0Y"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS.34*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R(")$=2`B
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT.`IM<V=I9"`B
M1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R(")$97-C<FEP=&EO;B!C;VUP;.AT
M92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`B4&QE:6YE(&QU;F4B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C$@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHV,`IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@
M(DYO;2!C;VUP;&5T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1V%B;VXB"FUS9W-T
M<B`B1V%B;VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I
M;6%G92!F<F]M(@IM<V=S='(@(D%L8G5M(&0G;W)I9VEN92!D92!L)VEM86=E
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G<W1R(")!;&)U;:`Z
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-0IM<V=I9"`B1V%M8FEA(@IM<V=S='(@(D=A;6)I92(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R(")'Z6[I
M<F5R(&QA(&-O;F9I9W5R871I;VX@9&4@)7,B"@HC.B!T96UP;&%T97,O861M
M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I9"`B1V5N97)A=&5D($-O9&4B
M"FUS9W-T<B`B0V]D92!GZ6[I<NDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'96]R
M9VEA(@IM<V=S='(@(D?I;W)G:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")'97)M
M86YY(@IM<V=S='(@(D%L;&5M86=N92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=H
M86YA(@IM<V=S='(@(D=H86YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VEB<F%L
M=&%R(@IM<V=S='(@(D=I8G)A;'1A<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3<V"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@
M(E!RZ6YO;2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S4@
M=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3`*(SH@=&5M<&QA=&5S+W!R969S
M+V%P<"YI;F,Z,3D*;7-G:60@(D=L;V)A;"!/<'1I;VYS(@IM<V=S='(@(D]P
M=&EO;G,@9VQO8F%L97,B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ
M-PIM<V=I9"`B1V\B"FUS9W-T<B`B06QL97(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G<W1R(")';V5D96PB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$S,0IM
M<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B0V%R=&5S($=O;V=L92(*"B,Z
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R
M8V@B"FUS9W-T<B`B4F5C:&5R8VAE($=O;V=L92(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,S@*;7-G:60@(D=R87ES8V%L
M92(*;7-G<W1R(").:79E874@9&4@9W)I<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED
M(")'<F5E8V4B"FUS9W-T<B`B1W+H8V4B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X.`IM<V=I9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(D=R
M96,@*$E33RTX.#4Y+3<I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W)E96YL86YD
M(@IM<V=S='(@(D=R;^MN;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=R96YA
M9&$B"FUS9W-T<B`B1W)E;F%D92(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y
M"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES
M=')A=&EO;B!D97,@9W)O=7!E<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"YP:'`Z-3D@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$V.0IM
M<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS9W-T<B`B
M3&5S(&YO;7,@9&4@9W)O=7!E(&YE('!E=79E;G0@<&%S(.IT<F4@=FED97,B
M"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L('!H
M<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O
M=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R
M("(B"B)'<F]U<%]L9&%PH#H@:6UP;W-S:6)L92!D)V%J;W5T97(@;&4@9W)O
M=7!E("5S+B!#96-I(&5S="!L82!RZ7!O;G-E(&1U("(*(G-E<G9E=7*@.B(*
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3@@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D=R
M;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS9W-T<B`B
M1W)O=7!?;&1A<*`Z('-U<'!R97-S:6]N(&EM<&]S<VEB;&4@9'4@9W)O=7!E
M("5S(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,S."!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@
M)7,B"FUS9W-T<B`B1W)O=7!?;&1A<*`Z(&UO9&EF:6-A=&EO;B!I;7!O<W-I
M8FQE(&1U(&=R;W5P92`E<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,S$T(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS9W-T<B`B
M1W)O=7!E<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T
M<B`B1W5A9&5L;W5P92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S
M='(@(D=U86TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S
M='(@(D=U871E;6%L82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.3(*;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@(D=U97)N97-E>2(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C(V('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z.#@*;7-G:60@(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S
M='(@(E!E<FUI<W-I;VYS(&1E<R!I;G9I=.ES(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0W,@IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(DQI
M=G)E(&0G;W(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDW(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'=6EN96$B"FUS9W-T<B`B
M1W5I;NEE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=6EN96$M0FES<V%U(@IM
M<V=S='(@(D=U:6[I92U":7-S874B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U
M>6%N82(*;7-G<W1R(")'=7EA;F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HY-3<*;7-G:60@(DA434PB"FUS9W-T<B`B2%1-3"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G
M:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L
M87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R(")(5$U,07)E82!R969U<V4@8NIT
M96UE;G0@9&4@<W5P<')I;65R(&QA(&1E<FYIZ')E(&-E;&QU;&4@9&4@;&$@
M<F%N9^EE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E
M<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R
M(")(5$U,07)E82!R969U<V4@8NIT96UE;G0@9&4@<W5P<')I;65R(&QA(&1E
M<FYIZ')E(&-O;&]N;F4@9'4@=&%B;&5A=2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@(DA434Q!
M<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I
M;B!T86)L92XB"FUS9W-T<B`B2%1-3$%R96$@<F5F=7-E(&+J=&5M96YT(&1E
M('-U<'!R:6UE<B!L82!D97)N:>AR92!R86YGZ64@9'4@=&%B;&5A=2(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED(")(5%10
M($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:&5N=&EF
M:6-A=&EO;B!(5%10(&YO;B!T<F]U=NEE+B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I
M9"`B2&%I=&DB"FUS9W-T<B`B2&'O=&DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S
M='(@(D%L9V]R:71H;64@9&4@:&%C:&%G92(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@
M(D)R=6UE('/H8VAE(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3$V
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,3$*;7-G:60@(DAE861E<B(*
M;7-G<W1R(")%;BUTZG1E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E
M+W1A8FQE<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R(")%;BUT
MZG1E<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-
M8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(LYL97,@2&5A<F0@970@36-$;VYA
M;&0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M,PIM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R(")/<F%G97,@=FEO;&5N
M=',B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B2&5B<F5W
M("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(DCI8G)E=2`H25-/+3@X-3DM."U)
M*2(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C(R('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H
M="(*;7-G<W1R(")(875T975R(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+TAE;'`N<&AP.C$X-"!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z
M,3@V"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W('1E;7!L871E<R]H
M96QP+VEN9&5X+FEN8SHT"FUS9VED(")(96QP(@IM<V=S='(@(D%I9&4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Q"FUS
M9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R(")!:61E('!O=7(@;"?I
M9&ET975R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V.`IM<V=I
M9"`B2&5L<&5R(@IM<V=S='(@(D%I9&4B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`B2.EM:7-P:.AR92(*
M"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$P('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C$P"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI
M;F<@;V8@=&AE(&9I;&4Z(@IM<V=S='(@(E9O:6-I(&QE(&3I8G5T(&1U(&9I
M8VAI97*@.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C<Q"FUS9VED(")(:6=H(@IM<V=S='(@(DAA=71E(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C;VUM;VXM
M:&5A9&5R+FEN8SHU"FUS9VED(")(;U]M92(*;7-G<W1R(")!7V-C=65I;"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6871I8V%N($-I='D@
M4W1A=&4I(@IM<V=S='(@(D-I=.D@9'4@5F%T:6-A;B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,34T.`IM<V=I9"`B2&]M92(*;7-G<W1R(")!
M8V-U96EL(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$R,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,34U"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`B061R97-S92!P
M97)S;VYN96QL92(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-`IM<V=I
M9"`B2&]M92!$:7)E8W1O<GDB"FUS9W-T<B`B4NEP97)T;VER92!P97)S;VYN
M96PB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(E3I;.EP:&]N92!P97)S
M;VYN96PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@
M(DAO;F1U<F%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")(;VYG($MO;F<B"FUS
M9W-T<B`B2&]N9R!+;VYG(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C8W"FUS9VED(")(;W)D92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z-#4R"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN
M(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86*@.B!D;VYNZ65S(%A-
M3"`E<R!I;G9A;&ED97,@<F5T<F]U=NEE<R!D86YS(&QE(&UE<W-A9V4@)7,B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD
M<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86*@.B!A=6-U;B!M
M97-S86=E(&YE(&-O<G)E<W!O;F0@874@<W5J970@)7,B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C0T-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S
M<V%G92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8J`Z('!A<R!D)V]B:F5T(&1E
M('1Y<&4@)7,@=')O=7;I(&1A;G,@;&4@;65S<V%G92`E<R(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(U,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB
M(@IM<V=S='(@(DAO<F1E+TMO;&%BH#H@)7,@<W5P<')I;>D@JZ`E<Z"[(&%V
M96,@<W5C8^AS(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR,C,*
M;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E
M<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N(@IM<V=S='(@(B(*
M(DAO<F1E+TMO;&%BH#H@;&4@;6]T975R(&0G:6YTZ6=R871I;VX@;NEC97-S
M:71E(&PG97AT96YS:6]N("=D;VUX;6PG(&1E(%!(4"(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z-3$R"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@
M;V)J96-T("5S(@IM<V=S='(@(DAO<F1E+TMO;&%BH#H@:6UP;W-S:6)L92!D
M92!C<NEE<B!U;B!N;W5V96P@87)B<F4@6$U,('!O=7(@;"=O8FIE="`E<R(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(T.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<
M(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%BH#H@:6UP;W-S:6)L92!D
M)V5N;&5V97(@)7,@JZ`E<Z"[H#H@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C0X,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F
M('1Y<&4@)7,B"FUS9W-T<B`B(@HB2&]R9&4O2V]L86*@.B!I;7!O<W-I8FQE
M(&1E('+I8W5PZ7)E<B!L)VED96YT:69I86YT($U)344@<&]U<B!L82!P87)T
M:64@9&4@(@HB='EP92`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z,3$Y-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA
M8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R
M9&4O2V]L86*@.B!I;7!O<W-I8FQE(&1E('-Y;F-H<F]N:7-E<B`E<R"KH"5S
MH+N@.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3,S-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y
M;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86*@.B!I
M;7!O<W-I8FQE(&1E('-Y;F-H<F]N:7-E<B!L97,@<&%R=&%G97.@.B`E<R(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*
M;7-G<W1R(")(;W)D92]+;VQA8J`Z('!A<G1A9V4@:6YC;VYN=2"KH"5SH+LB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(T
M"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B3&EG;F4@:&]R:7IO
M;G1A;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B4F5M
M<&QI<W-A9V4@:&]R:7IO;G1A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S
M='(@(DAO<FEZ;VYT86R@.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I9"!Y;W4@
M9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B0V]M;65N="#J
M=&5S+79O=7,@87)R:7;I(&EC::`_("A35E`@<F%P<&]R=&5Z+6QEH"$I(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T
M;R!M97)G93\B"FUS9W-T<B`B0V]M8FEE;B!D92!C;VQO;FYE<R!V;W5L97HM
M=F]U<R!F=7-I;VYN97*@/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N
M:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T
M:&5R93\B"FUS9W-T<B`B0V]M8FEE;B!D92!C:&%M<',@*&-O;&]N;F5S*2!Y
M(&$M="UI;*`_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y
M;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B0V]M8FEE;B!D92!R86YGZ65S
M('9O=6QE>BUV;W5S(&9U<VEO;FYE<J`_(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(X.2!L:6(O0FQO8VLO;65T87(N<&AP.C(S-PIM<V=I
M9"`B2'5M:61I='DB"FUS9W-T<B`B2'5M:61I=.DB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C0X"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S
M='(@(DAU;6ED:73IH#H@(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q
M"FUS9VED(")(=6UO<FES=',B"FUS9W-T<B`B2'5M;W)I<W1E<R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R(")(;VYG<FEE(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<R(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`BR6-H
M96,@;&]R<R!D92!L82!C<NEA=&EO;B!D92!L82!B;^YT92!)34%0H#H@)7,B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,30@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y-0HC+"!P:'`M9F]R;6%T"FUS
M9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*;7-G<W1R
M("+)8VAE8R!L;W)S(&1E(&QA('-U<'!R97-S:6]N(&1E(&QA(&)O[G1E($E-
M05"@.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W
M.2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C0R"B,L('!H<"UF
M;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL
M960Z("5S(@IM<V=S='(@(LEC:&5C(&QO<G,@9&4@;&$@8W+I871I;VX@9'4@
M<75O=&$@<W5R(&QA(&)O[G1E($E-05"@.B`E<R(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$S,3,*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`B
M061R97-S92!)4"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP
M:'`Z-S<*;7-G:60@(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T
M<B`B061R97-S92!)4"!N;VX@9&ES<&]N:6)L92XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R97-S(&YO
M="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R(")!9')E<W-E
M($E0(&AO<G,@9'4@8FQO8R!#2412(&%L;&]UZ2XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@(DE0
M(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B5FEO;&%T:6]N(&1E(&)L
M;V-A9V4@25`N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B
M"FUS9W-T<B`B25]N<^ER97(@<F%N9^EE(&%V86YT(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R
M"FUS9VED("))8V5L86YD(@IM<V=S='(@(DES;&%N9&4B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S@P"FUS9VED("))8V]N<R!/;FQY(@IM<V=S='(@
M(DEC]&YE<R!S975L96UE;G0B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z
M-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@
M(DEC]&YE<R!P;W5R("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X
M,0IM<V=I9"`B26-O;G,@=VET:"!T97AT(@IM<V=S='(@(DEC]&YE<R!P;'5S
M('1E>'1E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,PIM<V=I9"`B
M261E;G1I='DG<R!N86UE.B(*;7-G<W1R(").;VT@9'4@8V]M<'1EH#HB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T
M;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R("(B
M"B)3:2!L)V%F9FEC:&%G92!N)V5S="!P87,@8V]R<F5C="P@)7,@<&]U<B!L
M)V]U=G)I<B!D86YS('5N92!N;W5V96QL92!F96[J=')E+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT-3D*;7-G:60@(B(*(DEF('EO=2!D;VXG="!S
M964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y
M(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R
M86YS<&%R96YC>2XB"FUS9W-T<B`B(@HB4VD@=F]U<R!N92!V;WEE>B!A=6-U
M;B!I8_1N92!E;B!U=&EL:7-A;G0@26YT97)N970@17AP;&]R97(L('9O=7,@
M<&]U=F5Z("(*(F%V;VER(.`@8V]C:&5R(&-E='1E(&-A<V4@<&]U<B!DZ7-A
M8W1I=F5R(&QA('1R86YS<&%R96YC92!D97,@4$Y'+B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ-S(*;7-G:60@(B(*(DEF
M('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E
M('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@
M>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"B)3:2!V;W5S('9O>65Z(&-E(&UE
M<W-A9V4@;6%I<R!A=6-U;F4@:6UA9V4L(&PG:6UA9V4@<75E('9O=7,@=F]U
M;&5Z(&5N=F]Y97(@(@HB;F4@<&5U="#J=')E(&%F9FEC:.EE('!A<B!V;W1R
M92!N879I9V%T975R+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B26UA9V4@4')E=FEE
M=SHB"FUS9W-T<B`B07!E<N=U(&1E(&PG:6UA9V6@.B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@
M(DEM86=E(%523"(*;7-G<W1R(")!9')E<W-E(%523"!D92!L)VEM86=E(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3@*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(D%D<F5S<V4@
M55),(&1E(&PG:6UA9V6@.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O
M;2!G86QL97)Y(@IM<V=S='(@(DEM86=E(&1E(&PG86QB=6TB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B26UA9V4@
M9&4@;"=A;&)U;:`Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<U
M.`IM<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(E3I;.EC:&%R9V5M96YT
M(&0G:6UA9V5S(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S<*;7-G:60@
M(DEM86=E<R(*;7-G<W1R("));6%G97,B"@HC.B!T96UP;&%T97,O9&%T82]T
M<W9I;F9O+FEN8SHW('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C<*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-"!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E
M<"`E9"(*;7-G<W1R("));7!O<G1A=&EO;BP@Z71A<&4@)60B"@HC.B!T96UP
M;&%T97,O9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED
M("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`B0VAA;7`@:6UP;W)TZ:`Z
M("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV-0IM<V=I9"`B
M26UP;W)T960@9FEE;&1S.B(*;7-G<W1R(")#:&%M<',@:6UP;W)TZ7.@.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T<B`B26Y?
M<^ER97(@<F%N9^EE(&%P<NAS(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+WII<"YP:'`Z,3,T"FUS9VED("));F-O<G)E8W0@86-T:6]N(&-O
M9&4@9VEV96XN(@IM<V=S='(@(D-O9&4@9"=A8W1I;VX@:6YC;W)R96-T+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,R"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D
M+B(*;7-G<W1R(").;VT@9"=U=&EL:7-A=&5U<B!E="]O=2!V;W1R92!M;W0@
M9&4@<&%S<V4@:6YC;W)R96-T+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C4Q"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT
M97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB
M861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S
M='(@(B(*(DYO;2!D)W5T:6QI<V%T975R(&]U(&%D<F5S<V4@86QT97)N871I
M=F4@:6YC;W)R96-T+B`@4NEE<W-A>65Z(&]U(&-O;G1A8W1E>B`B"B)V;W1R
M92!A9&UI;FES=')A=&5U<B!S>7-TZ&UE('!O=7(@9&4@;"=A:61E+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*;7-G
M:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R(")!=6=M96YT97(@;"=I;F1E
M;G1A=&EO;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B26YD:6$B"FUS9W-T<B`B
M26YD92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C4T('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS9VED("));F1I=FED=6%L
M(%5S97)S(@IM<V=S='(@(E5T:6QI<V%T975R<R!I;F1I=FED=65L<R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,`IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(DEN9&]NZ7-I
M92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-C<*;7-G:60@(DEN9F\B"FUS9W-T<B`B26YF;R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR-3D*;7-G:60@(DEN9F]R;6%T:6]N(@IM<V=S='(@
M(DEN9F]R;6%T:6]N<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS,3D*;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N
M(@IM<V=S='(@(DPG:6YF;W)M871I;VX@;B=E<W0@<&QU<R!D:7-P;VYI8FQE
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B"FUS9W-T
M<B`B26YSZ7)E<B!C7V]L;VYN92!A<'+H<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B
M26YS97)T($EM86=E(@IM<V=S='(@(DEN<^ER97(@:6UA9V4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED("))
M;G-E<G0@5&%B;&4B"FUS9W-T<B`B26YSZ7)E<B!U;B!T86)L96%U(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I
M9"`B26YS97)T(%=E8B!,:6YK(@IM<V=S='(@(DEN<^ER97(@=6X@;&EE;B!W
M96(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S0*;7-G:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G
M<W1R("));G/I<F5R(%]C;VQO;FYE(&%V86YT(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED("))
M;G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G
M<W1R("));G/I<F5R('5N92!N;W5V96QL92!C;VQO;FYE(&%P<NAS(&QA(&-O
M;&]N;F4@86-T=65L;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C
M;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("));G/I<F5R
M('5N92!N;W5V96QL92!C;VQO;FYE(&%V86YT(&QA(&-O;&]N;F4@86-T=65L
M;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE
M(&-U<G)E;G0@;VYE(@IM<V=S='(@(DEN<^ER97(@=6YE(&YO=79E;&QE(')A
M;F?I92!A<'+H<R!L82!R86YGZ64@86-T=65L;&4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@
M(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G
M<W1R("));G/I<F5R('5N92!N;W5V96QL92!R86YGZ64@879A;G0@;&$@<F%N
M9^EE(&%C='5E;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C<P"FUS9VED("));G-E<G0@82!P87)A9W)A
M<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("));G/I<F5R('5N
M('!A<F%G<F%P:&4@87!RZ',@;&4@;B9O96QI9SMU9"!A8W1U96PB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-CD*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E
M;G0@;F]D92(*;7-G<W1R("));G/I<F5R('5N('!A<F%G<F%P:&4@879A;G0@
M;&4@;B9O96QI9SMU9"!A8W1U96PB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R
M("));G/I<F5R('5N(&%U=')E(&UO9.AL92(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR-#(*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O
M('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G
M<W1R("(B"B));G-C<FEV97H@=6YE(&%D<F5S<V4@9&4@8V]U<G)I97(@X"!L
M87%U96QL92!V;W5S(')E8V5V<F5Z(&QE(&YO=79E874@;6]T(&1E("(*(G!A
M<W-EH#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4X"FUS9VED("));G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R
M("));G/I<F5R(&-E;&QU;&4@87!RZ',B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Y"FUS9VED("));G-E<G0@
M8V5L;"!B969O<F4B"FUS9W-T<B`B26YSZ7)E<B!C96QL=6QE(&%V86YT(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R("));G/I
M<F5R(&-O;&]N;F4@87!RZ',B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8U"FUS9VED("));G-E<G0@8V]L=6UN
M(&)E9F]R92(*;7-G<W1R("));G/I<F5R(&-O;&]N;F4@879A;G0B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,`HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS
M97)T(&UE<W-A9V5S(@IM<V=S='(@(DEN<^ER97(@;&5S(&UE<W-A9V5S(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0U"FUS9VED("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@
M(DEN<^ER97(@<&%R86=R87!H92!A<'+H<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS
M97)T('!A<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B26YSZ7)E<B!P87)A9W)A
M<&AE(&%V86YT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(')O=R!A9G1E<B(*;7-G
M<W1R("));G/I<F5R(')A;F?I92!A<'+H<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*;7-G:60@(DEN<V5R
M="!R;W<@8F5F;W)E(@IM<V=S='(@(DEN<^ER97(@<F%N9^EE(&%V86YT(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,PIM<V=I9"`B26YS97)T('1H
M92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.B(*
M;7-G<W1R("));G-C<FEV97H@;&$@<NEP;VYS92#@(&QA('%U97-T:6]N(&1E
M('/I8W5R:73IH#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(V"FUS9VED("));G-E<G0O36]D:69Y($EM86=E(@IM<V=S
M='(@(DEN<^ER97(O36]D:69I97(@=6YE(&EM86=E(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T
M+TUO9&EF>2!,:6YK(@IM<V=S='(@(DEN<^ER97(O36]D:69I97(@=6X@;&EE
M;B!W96(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T,PIM<V=I9"`B26YS=69F:6-I96YT(&-R961I="!T;R!S96YD
M('1O('1H92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B0W+I9&ET(&EN
M<W5F9FES86YT('!O=7(@96YV;WEE<B#@(&QA(&QI<W1E(&1E(&1I<W1R:6)U
M=&EO;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T
M<B`B0W+I9&ET(&EN<W5F9FES86YT+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$P-S(*;7-G:60@(DEN=&5G97(B"FUS9W-T<B`B16YT:65R(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$S,`IM<V=I9"`B26YT96=E
M<B!L:7-T(@IM<V=S='(@(DQI<W1E(&-O;7!LZ'1E(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("))
M;G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R(")51$@@
M*%5S97(@1&%T82!(96%D97(I(&EN=F%L:61E(@H*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,38W"B,Z(&9R86UE=V]R:R]#;VUP
M<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$Y-`HC.B!F<F%M97=O<FLO0V]M<')E
M<W,O0V]M<')E<W,O>FEP+G!H<#HR,3(*;7-G:60@(DEN=F%L:60@6DE0(&1A
M=&$B"FUS9W-T<B`B1&]N;NEE(%I)4"!I;G9A;&ED92XB"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N
M+B(*;7-G<W1R(")!<'!L:6-A=&EO;B!I;G9A;&ED92XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@
M(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(D=R;W5P92!)1"!I;G9A;&ED
M92XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#@T(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Q-34*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(R.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,CDV"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<*;7-G:60@(DEN
M=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@(D5N=F]I(&1E(&1O;F[I
M97,@:6YV86QI9&5S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P,`IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO
M;B!A9&1R97-S+B(*;7-G<W1R(")!9')E<W-E(&1E(&1E<W1I;F%T:6]N(&EN
M=F%L:61E+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N
M<&AP.C$P.0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H
M<#HQ,SD*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z
M,C0Q"FUS9VED("));G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@(D9O<FUA
M="!D92!F:6-H:65R(&EN=F%L:61E+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-C4*;7-G:60@(DEN=F%L:60@;&EC96YS92!K97DN(@IM
M<V=S='(@(D-L968@9&4@;&EC96YC92!I;G9A;&ED92XB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y"FUS9VED("));G9A;&ED(&QO8V%T
M:6]N('!R;W9I9&5D+B(*;7-G<W1R(")%;7!L86-E;65N="!I;F1I<77I(&EN
M=F%L:61E+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T
M<B`BJVUS9U]T>7!ENR!I;G9A;&ED92XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*;7-G:60@(DEN=F%L:60@
M;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(JMA<&E?:62[(&EN=F%L:61E
M(&]U(&UA;G%U86YT+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y-@IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG
M('!A<F%M971E<G,N(@IM<V=S='(@(E!A<F%MZ'1R97,@:6YV86QI9&5S(&]U
M(&UA;G%U86YT<RXB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z,C<*
M;7-G:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(E!E
M<FUI<W-I;VX@:6YV86QI9&4N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$V,0IM<V=I9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R
M("))9"X@9&4@<&%R=&5N86ER92!I;G9A;&ED92XB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,38S"FUS9VED("));G9A;&ED('!R;V1U8W0@
M8V]D92XB"FUS9W-T<B`B0V]D92!D92!P<F]D=6ET(&EN=F%L:61E+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B4')O=&]C;VQE
M(&EN=F%L:61E+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z.3,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HW,2!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C@P"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@<F5C:7!I96YT.B!<
M(B5S7"(B"FUS9W-T<B`B1&5S=&EN871A:7)E(&EN=F%L:61EH#H@JZ`E<Z"[
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,#@P(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z,3(V,PIM<V=I9"`B26YV86QI9"!S:&%R92!O
M8FIE8W0B"FUS9W-T<B`B3V)J970@9&4@<&%R=&%G92!I;G9A;&ED92(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M,0IM<V=I9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B061R
M97-S92!S;W5R8V4@:6YV86QI9&4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED('5N
M:6-O9&4@9&%T82XB"FUS9W-T<B`B1&]N;NEE(%5N:6-O9&4@:6YV86QI9&4N
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U.0IM<V=I9"`B26YV
M96YT;W)Y(@IM<V=S='(@(DEN=F5N=&%I<F4B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<X"FUS9VED("));G9E<G0@<V5L
M96-T:6]N(@IM<V=S='(@(DEN=F5R<V5R(&QA('/I;&5C=&EO;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,@IM<V=I9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G
M<W1R("))<F%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM<V=S='(@
M(DER86LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS9W-T<B`B
M27)L86YD92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$U"FUS
M9VED("))<VQE(&]F($UA;B(*;7-G<W1R("+.;&4@9&4@36%N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES
M;VQA=&5D(%0M4W1O<FUS(@IM<V=S='(@(E1E;7#J=&5S(&ES;VSI97,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#`*;7-G:60@(DES<F%E;"(*;7-G<W1R("))<W)AZVPB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R-@IM<V=I9"`B
M27-S=65R(@IM<V=S='(@(LEM971T975R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS9W-T
M<B`B271A;&EQ=64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DET86QY(@IM<V=S
M='(@(DET86QI92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G
M<W1R(")*86UA[W%U92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y(@IM<V=S='(@(DIA;G9I97(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#,*;7-G:60@(DIA<&%N(@IM<V=S='(@(DIA<&]N(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@(DIA<&%N97-E("A)
M4T\M,C`R,BU*4"DB"FUS9W-T<B`B2F%P;VYA:7,@*$E33RTR,#(R+4I0*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(R"FUS9VED(")*97)S
M97DB"FUS9W-T<B`B2F5R<V5Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*;W)D
M86XB"FUS9W-T<B`B2F]R9&%N:64B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`X"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R(")*=6EL
M;&5T(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P-PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B2G5I;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU
M<W1I9GDB"FUS9W-T<B`B2G5S=&EF:65R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I
M9GD@0V5N=&5R(@IM<V=S='(@(D-E;G1R97(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S
M=&EF>2!&=6QL(@IM<V=S='(@(DIU<W1I9FEE<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$T"FUS9VED(")*
M=7-T:69Y($QE9G0B"FUS9W-T<B`B06QI9VYE<B#@(&=A=6-H92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V
M"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(D%L:6=N97(@X"!D<F]I
M=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T<B`B
M2V%Z86MH<W1A;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR-C4*;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@(D=A
M<F1E<B!L)V]R:6=I;F%LH#\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DME;GEA
M(@IM<V=S='(@(DME;GEA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U
M+G!H<#HX-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R("),92!S97)V975R($ME<F)E<F]S(&$@<F5J
M973I(&PG875T:&5N=&EF:6-A=&EO;BXB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B:65S(@IM<V=S='(@(D3I8G5T
M86YT<R!D=2!N;WEA=2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q,0IM<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S='(@(D-RZ6%T:6]N
M(&1E(&-L968B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,30*;7-G:60@(DME>2!&:6YG97)P<FEN="(*;7-G<W1R(")%;7!R96EN=&4@
M9&4@;&$@8VQE9B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R("),;VYG=65U<B!D92!L
M82!C;&5F(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q
M"FUS9VED(")+97D@5'EP92(*;7-G<W1R(")4>7!E(&1E(&-L968B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.0IM<V=I9"`B2V5Y
M(%5S86=E(@IM<V=S='(@(E5T:6QI<V%T:6]N(&1E(&QA(&-L968B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW-#`*;7-G:60@(DME>2!A
M;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T
M<B`B3&$@8VQE9B!S92!T<F]U=F4@9.EJX"!S=7(@;&4@<V5R=F5U<B!D92!C
M;&5F<R!P=6)L:6,N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS
M9VED(")+:61S(@IM<V=S='(@(D5N9F%N=',B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G
M:60@(DMI<FEB871I(@IM<V=S='(@(DMI<FEB871I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U
M"FUS9VED(")+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O
M9B(*;7-G<W1R(")#;W+I92!D=2!.;W)D(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS9VED
M(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B0V]RZ64@9'4@4W5D(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@(DMO<F5A;B`H155#
M+4M2*2(*;7-G<W1R(")#;W+I96X@*$550RU+4BDB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*
M;7-G:60@(DMU=V%I="(*;7-G<W1R(")+;W=E[W0B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*
M;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B2VER9VAI>FES=&%N(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED("),85]Y;W5T(@IM
M<V=S='(@(E!RZ5]S96YT871I;VXB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C@S"FUS9VED("),86YG=6%G92(*;7-G<W1R("),86YG=64B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E
M<'5B;&EC(@IM<V=S='(@(DQA;W,B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,38Y"FUS9VED("),87-T($AA;&8B"FUS9W-T<B`B1&5R;FGH<F4@9&5M:64B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S8*;7-G:60@(DQA<W0@4&%S
M<W=O<F0@0VAA;F=E(@IM<V=S='(@(D1E<FYIZ')E(&UO9&EF:6-A=&EO;B!D
M=2!M;W0@9&4@<&%S<V4B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB
M+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED("),87-T(%%U87)T97(B"FUS9W-T
M<B`B1&5R;FEE<B!Q=6%R=&EE<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,34X"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(D1E<FYIZ')E(&UI
M<V4@X"!J;W5RH#HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,3<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`B
M1&5R;FGH<F4@8V]N;F5X:6]NH#H@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@
M)7,@9G)O;2`E<R(*;7-G<W1R(")$97)N:>AR92!C;VYN97AI;VZ@.B`E<R#@
M('!A<G1I<B!D92`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q
M-`IM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`B1&5R;FGH<F4@
M8V]N;F5X:6]NH#H@:F%M86ES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),871V
M:6$B"FUS9W-T<B`B3&5T=&]N:64B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#0*;7-G:60@(DQA=R(*;7-G<W1R("),;VDB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*;7-G:60@(DQA
M>6]U="(*;7-G<W1R(")0<NES96YT871I;VXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T
M>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@(DQA:7-S97(@=FED92!P;W5R(&YE
M('!A<R!A=F]I<B!D92!B;W)D=7)E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),
M96)A;F]N(@IM<V=S='(@(DQI8F%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"FUS9VED("),969T(@IM<V=S
M='(@(D=A=6-H92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,P.3@*
M;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(D5N=.IT92!G875C:&4B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,#DT"FUS9VED("),969T('9A
M;'5E<R(*;7-G<W1R(")686QE=7)S(&1E(&=A=6-H92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.`IM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("),97-O=&AO(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED("),979E;"(*;7-G<W1R
M(").:79E874B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI8F5R:6$B"FUS9W-T
M<B`B3&EBZ7)I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&EB>6%N($%R86(@
M2F%M86AI<FEY82(*;7-G<W1R("),:6)Y92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,30P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I
M9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("),:65C:'1E;G-T96EN(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@
M(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`B0G)U:6YE(&SI9^AR92(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"FUS9VED("),
M:6=H="!286EN(@IM<V=S='(@(E!L=6EE(&SI9^AR92(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!2
M86EN($5A<FQY(@IM<V=S='(@(E!L=6EE(&SI9^AR92!T]'0@9&%N<R!L82!J
M;W5R;NEE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R(")0;'5I92!L
MZ6?H<F4@=&%R9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R(")!
M=F5R<V5S(&SI9^AR97,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS,`IM<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B
M"FUS9W-T<B`B4&QU:64@;.EGZ')E(&%V96,@=&]N;F5R<F4B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B3&EG
M:'0@4VYO=R(*;7-G<W1R(").96EG92!I;G1E<FUI='1E;G1E(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI
M9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(D%V97)S92!D92!N96EG92!LZ6?H
M<F4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI;65R
M:6-K(@IM<V=S='(@(E)I;65S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@Q,0IM<V=I9"`B3&EN:R(*;7-G<W1R("),:65N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS
M9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B3&4@;&EE;B!P;VEN=&4@
M=F5R<Z`Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,@IM<V=I
M9"`B3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E
M('=H96X@9&ES<&QA>6EN9R(*;7-G<W1R("(B"B),:64@;"=A9')E<W-E(&1E
M(&-O=7)R:65L(.`@;&$@<&%G92!D92!C;VUP;W-I=&EO;B!D=2!M97-S86=E
M(&5N(&PG869F:6-H86YT(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I
M;'1E<B]H=&UL,G1E>'0N<&AP.C$X,@IM<V=I9"`B3&EN:W,B"FUS9W-T<B`B
M3&EE;G,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI
M;G5X($-O;VMI92(*;7-G<W1R(")":7-C=6ET($QI;G5X(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#8*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G:60@(DQI<W0@+2!U
M<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R("),:7-T92`M('5T:6QI
M<V%T975R('!E=70@=F]I<B!L92!D;W-S:65R(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C$S-`IM<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`B3&ES
M=&4@9&5S(&)A<V5S(&1E(&1O;F[I97,B"@HC.B!S97)V:6-E<R]H96QP+VEN
M9&5X+G!H<#HU,0IM<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R("))
M;F1E>"!D92!L)V%I9&4B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,S"FUS
M9VED("),:7-T(%1A8FQE<R(*;7-G<W1R(")!9F9I8VAE<B!L97,@=&%B;&5S
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.30*;7-G
M:60@(DQI<W0M07)C:&EV92(*;7-G<W1R(")!<F-H:79E<R!D92!L82!L:7-T
M92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3@Y"FUS
M9VED("),:7-T+4AE;'`B"FUS9W-T<B`B06ED92!D92!L82!L:7-T92(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DV"FUS9VED("),
M:7-T+4ED(@IM<V=S='(@(DED+B!D92!L82!L:7-T92(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),:7-T+4]W;F5R
M(@IM<V=S='(@(E!R;W!R:>ET86ER92!D92!L82!L:7-T92(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS9VED("),:7-T+5!O
M<W0B"FUS9W-T<B`B16YV;VD@X"!L82!L:7-T92(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O2&5A9&5R<RYP:'`Z-3DQ"FUS9VED("),:7-T+5-U8G-C<FEB
M92(*;7-G<W1R(")!8F]N;F5M96YT(.`@;&$@;&ES=&4B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,`IM<V=I9"`B3&ES="U5;G-U
M8G-C<FEB92(*;7-G<W1R(")$Z7-A8F]N;F5M96YT(&1E(&QA(&QI<W1E(@H*
M(SH@861M:6XO<V5S<VEO;G,N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@
M(DQI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R("+)8VAE8R!D
M92!L82!L:7-T92!D97,@<V5S<VEO;G.@.B`E<R(*"B,Z(&%D;6EN+W-E<W-I
M;VYS+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('5S97)S
M(&9A:6QE9#H@)7,B"FUS9W-T<B`BR6-H96,@9&4@;&$@;&ES=&4@9&5S('5T
M:6QI<V%T975R<Z`Z("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L
M:7-T+FEN8SHR"FUS9VED("),:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*
M;7-G<W1R("),)V%F9FEC:&%G92!D92!L82!L:7-T92!D97,@=71I;&ES871E
M=7)S(&5S="!DZ7-A8W1I=NDN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0W"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@(DQI='3I<F%T=7)E(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@Y"FUS9VED("),:71H=6%N:6$B"FUS9W-T<B`B3&ET=6%N
M:64B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I;6%G97,N<&AP
M.C<W"FUS9VED("),;V%D:6YG+BXN(@IM<V=S='(@(D-H87)G96UE;G0N+BXB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`P"FUS9VED("),
M;V-A;"!T:6UE.B`B"FUS9W-T<B`B2&5U<F4@;&]C86QEH#H@(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@V"FUS9VED("),;V-A;&4@86YD(%1I;64B
M"FUS9W-T<B`B2&5U<F4@970@;&]C86QE(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-S(@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C4W"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HR,B!L:6(O0FQO8VLO
M;65T87(N<&AP.C<R"FUS9VED("),;V-A=&EO;B(*;7-G<W1R("),:65U(@H*
M(SH@;&]G:6XN<&AP.C$X.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,C`P('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C,*(SH@=&5M<&QA=&5S
M+VQO9VEN+VUO8FEL92YI;F,Z,34@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHY,`IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(D-O;FYE>&EO;B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R
M979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R(")4<F%C92!D92!L82!D97)N
M:>AR92!S97-S:6]N(&1E('-Y;F-H<F]N:7-A=&EO;B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S:61E8F%R+G!H<#HQ.30*;7-G:60@(DQO9R!O=70B"FUS9W-T
M<B`B1.EC;VYN97AI;VXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-3D*
M;7-G:60@(DQO9VEN(@IM<V=S='(@(D-O;FYE>&EO;B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,3`*;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@
M(E3B8VAE<R!D92!C;VYN97AI;VXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HY.34*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E
M<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM
M<V=S='(@(B(*(DQA(&-O;FYE>&EO;B!E<W0@<F5F=7/I92X@26P@97-T('!R
M;V)A8FQE('%U92!V;W1R92!N;VT@9"=U=&EL:7-A=&5U<B!O=2`B"B)V;W1R
M92!M;W0@9&4@<&%S<V4@82#I=.D@;6%L('-A:7-I(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z.3DQ"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S
M='(@(LEC:&5C(&1E(&-O;FYE>&EO;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,S8R"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`B5&5X=&4@
M;&]N9R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`IM<V=I9"`B3&]V
M92(*;7-G<W1R(")!;6]U<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8Y"FUS9VED("),;W<B"FUS9W-T<B`B1F%I8FQE(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N
M9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R("),
M971T<F4@9W)E8W%U97,@;6EN=7-C=6QE<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO
M=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B3&5T=')E(&QA=&EN97,@;6EN
M=7-C=6QE<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B
M"FUS9W-T<B`B3F]M8G)E(')O;6%I;G,@;6EN=7-C=6QE<R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX.0IM<V=I9"`B3'5X96UB;W5R9R(*;7-G<W1R("),=7AE;6)O=7)G(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,0HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R(")-32(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#,*;7-G:60@(DU/5$0B
M"FUS9W-T<B`B365S<V%G92!D=2!J;W5R("A-3U1$*2(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,V"FUS9VED(")-4RU43D5&
M($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(DQA('!I
MZ&-E(&IO:6YT92!-4RU43D5&(&YE(&-O;G1E;F%I="!A=6-U;F4@9&]N;NEE
M+B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R(")-4T<B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA8V%O(@IM<V=S='(@(DUA8V%O(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDQ"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G
M;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T<B`B4NEP=6)L:7%U92!D92!-86/I
M9&]I;F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUA9&%G87-C87(B"FUS9W-T
M<B`B36%D86=A<V-A<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.0IM
M<V=I9"`B36%G:6,B"FUS9W-T<B`B36%G:64B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z.#,*;7-G:60@(DUA:6PB"FUS9W-T<B`B0V]U<G)I97(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3(T"FUS9VED(")-86EL
M($%D;6EN(@IM<V=S='(@(D%D;6EN:7-T<F%T:6]N(&1U(&-O=7)R:65L(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S='(@(D9A:7)E('5N
M(&QI95]N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QA=VDB"FUS9W-T<B`B
M36%L87=I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-86QA>7-I82(*;7-G<W1R
M(")-86QA:7-I92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS
M9W-T<B`B36%L9&EV97,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA;&DB"FUS
M9W-T<B`B36%L:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L=&$B"FUS9W-T
M<B`B36%L=&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.30*;7-G:60@
M(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O
M(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W
M:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*(D%D;6EN:7-T<F5Z
M(&QA(&QI<W1E(&1E(&-A=.EG;W)I97,@970@;&5S(&-O=6QE=7)S(&QIZ65S
M(.`@8V5S(&-A=.EG;W)I97,N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$Q-38*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R
M(")#87)T92"K($UA<#(T(+LB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3`X-PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3$W,0IM<V=I9"`B36%P475E<W0@;6%P(@IM<V=S
M='(@(D-A<G1E(*L@36%P<75E<W0@NR(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R
M(")#;W)R97-P;VYD86YC97,@96YR96=I<W1RZ65S+B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#0*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED(")-87)C:"(*
M;7-G<W1R(")-87)S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT,0IM<V=I9"`B36%R9VEN(@IM<V=S='(@(DUA
M<F=E(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z
M-#@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*
M;7-G:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R(")-
M87)Q=65R(&%V96,@9&5S(.ET:7%U971T97,@5G4O3F]N('9U(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#D*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@
M=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM
M<V=S='(@(DUA<G%U97(@879E8R!D)V%U=')E<R#I=&EQ=65T=&5S("AE>"XZ
M($EM<&]R=&%N="]2Z7!O;F1U*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,34R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%R
M<VAA;&P@27-L86YD<R(*;7-G<W1R("+.;&5S($UA<G-H86QL(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDS"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@(DUA<G1I;FEQ=64B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B36%T
M8VAI;F<@9FEE;&1S(@IM<V=S='(@(D-H86UP<R!A<'!A<F5N=.ES(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDS"FUS9VED(")-875R:71A;FEA(@IM<V=S='(@(DUA=7)I=&%N
M:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R("+.
M;&4@36%U<FEC92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E9&ET+B(*
M;7-G<W1R(")#<NED:70@;6%X:6UU;2!A;&QO=>DN(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-
M87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB"FUS9W-T<B`B3&EM:71E(&1U
M(&UE<W-A9V4@9.EP87-SZ64N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,3,*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R(")4
M96UPZ7)A='5R92!M87AI;6%L92!D97,@,C0@9&5R;FGH<F5S(&AE=7)E<Z`Z
M("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`U"FUS9VED(")-87@@=&5M
M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R(")496UPZ7)A='5R92!M87AI;6%L
M92!D97,@-B!D97)N:>AR97,@:&5U<F5SH#H@(@H*(SH@;&EB+V%P:2YP:'`Z
M.#8*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS
M9W-T<B`B3F]M8G)E(&UA>&EM=6T@9&4@8FQO8W,@9'4@<&]R=&%I;"(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-2!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C$T"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S8*
M;7-G:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(DQO;F=U975R(&UA>&EM
M=6TB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`V"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M.0IM<V=I9"`B36%Y(@IM<V=S='(@(DUA:2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G
M:60@(DUA>6]T=&4B"FUS9W-T<B`B36%Y;W1T92(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B3>ED:6-A
M;65N="(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,38*
M;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`B365M8G)E<R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.#(*;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B
M5'EP92!D92!M96YUH#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G
M<W1R(")&=7-I;VYN97(@;&5S(&-E;&QU;&5S(@H*(SH@9G)A;65W;W)K+TYO
M=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS
M,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DUE
M<W-A9V4B"FUS9W-T<B`B365S<V%G92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z,C$V"FUS9VED("(B"B)-97-S86=E(%9E<FEF:65D
M(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O
M=6QD(&YO="!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@HB5NER:69I8V%T
M:6]N(&1U(&UE<W-A9V4@<NEU<W-I92P@;6%I<R!L92!C97)T:69I8V%T(&1U
M('-I9VYA=&%I<F4@;B=A('!A<R!P=2`B"B+J=')E(';I<FEF:>DN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P
M"FUS9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(DUE<W-A9V4@97AP
M:7+I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-38Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C`R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(R-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR-C`*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G
M<W1R(")4>7!E(&1E(&UE<W-A9V4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,*;7-G:60@(DUE=&%R(%=E871H97(B"FUS9W-T<B`B3>ETZ6\@365T87(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W"FUS9VED(")-971A<B!B;&]C
M:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("),92!B;&]C(*L@365T87(@NR!N
M)V5S="!P87,@9&ES<&]N:6)L92XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$Q.0IM<V=I9"`B(@HB365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T
M86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB
M"FUS9W-T<B`B(@HB3&4@8FQO8R"K($UE=&%R(+L@;B=E<W0@<&%S(&1I<W!O
M;FEB;&4N("!,97,@9.ET86EL<R!O;G0@Z73I(&-O;G-I9V[I<R!P;W5R("(*
M(FPG861M:6YI<W1R871E=7(N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$U,PIM<V=I9"`B365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+B(*
M;7-G<W1R(")-971A<D1"(&XG97-T('!A<R!C;VYN96-TZ2XB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8W(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G
M<W1R(")-Z71H;V1E(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H
M<#HX,2!F<F%M97=O<FLO4E!#+U)00R]S;V%P+G!H<#HQ,3<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G
M<W1R("),82!MZ71H;V1E(*N@)7.@NR!N)V5S="!P87,@9.EF:6YI92(*"B,Z
M(&9R86UE=V]R:R]24$,O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF;W)M870*
M;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,B
M"FUS9W-T<B`B3>ET:&]D92!N;VX@9.EF:6YI92X@3>ET:&]D92!A<'!E;.EE
MH#H@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C<@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HX,@IM<V=I9"`B365T<FEC(@IM<V=S='(@(DWI
M=')I<75E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-97AI8V\B"FUS9W-T<B`B
M365X:7%U92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")-:6-R;VYE<VEA+"!&961E
M<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(LET871S(&;I9.ERZ7,@9&4@36EC
M<F]NZ7-I92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW-@IM<V=I9"`B36ED9&QE(@IM<V=S='(@(DUI;&EE=2(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS
M9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B5'EP92!-24U%(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS,3<*;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U
M<G,Z("(*;7-G<W1R(")496UPZ7)A='5R92!M:6YI;75M(&1E<R`R-"!D97)N
M:>AR97,@:&5U<F5SH#H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#D*
M;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(E1E;7#I
M<F%T=7)E(&UI;FEM=6T@9&5S(#8@9&5R;FGH<F5S(&AE=7)E<Z`Z("(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#,Y"FUS9VED(")-:6YI
M;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D(@IM<V=S='(@
M(DQA(&1U<NEE(&UI;FEM86QE(&1U(&UO="!D92!P87-S92!N)V$@<&%S(&5N
M8V]R92!E>'!I<NDB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C,U"FUS9VED(")-:7)R;W(B"FUS9W-T<B`B36ER;VER(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Q"FUS9VED(")-:7-C96QL86YE
M;W5S(@IM<V=S='(@(E9A<FGI<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!014%2
M('!A8VMA9V4@2%144%]297%U97-T+B(*;7-G<W1R("),92!P87%U971A9V4@
M2%144%]R97%U97-T(%!%05(@97-T(&UA;G%U86YT+B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ,34*;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A
M=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT
M('1O('5S92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"B)#;VYF
M:6=U<F%T:6]N(&EN97AI<W1A;G1E+B!6;W5S(&1E=F5Z(&QA(&?I;NER97(@
M;6%I;G1E;F%N="!S:2!V;W5S('9O=6QE>B`B"B)U=&EL:7-E<B!C971T92!A
M<'!L:6-A=&EO;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)1"XB
M"FUS9W-T<B`B240@9'4@;65S<V%G92!M86YQ=6%N="XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I
M9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"XB"FUS9W-T
M<B`B3&4@<&%Q=65T86=E(%!%05(@36%I;"!E<W0@;6%N<75A;G0N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDT
M"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM<V=S='(@(DE$(&1E('-E
M<W-I;VX@;6%N<75A;G0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`B3'4B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S8*;7-G:60@(DUO8FEL92!-86EL
M(@IM<V=S='(@(D-O=7)R:65L('-A;G,@9FEL(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*;7-G:60@(DUO9&5R871E(@IM
M<V=S='(@(DUO9.ERZ2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C8@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HW,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@U
M"FUS9VED(")-;V1I9FEE9"!$871E(@IM<V=S='(@(D1A=&4@9&4@;6]D:69I
M8V%T:6]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4S"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@(DUO
M9&EF:65R(&PG55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV-S0*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B36]D=6QO(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDP"FUS9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R
M(")-;VQD879I92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]N86-O(@IM<V=S
M='(@(DUO;F%C;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36]N9V]L:6$B"FUS
M9W-T<B`B36]N9V]L:64B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-3@Q"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R(")-;VES(&5T(&%N
M;NEE(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H
M<#HU-PIM<V=I9"`B36]N=&AL>2(*;7-G<W1R(")-96YS=65L;&5M96YT(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDT"FUS9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(DUO;G1S
M97)R870B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S='(@(E!H87-E<R!D
M92!L82!L=6YE(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3DV
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(X,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE
M(&5X<&5C=&5D("5D+B(*;7-G<W1R(")#:&%M<',@<W5P<&SI;65N=&%I<F5S
M('1R;W5VZ7,@X"!L82!L:6=N92`E9"`H871T96YD=7,@)60I+B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R(")-87)O8R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")-
M;W-T;'D@0VQE87(B"FUS9W-T<B`B1^ENZ7)A;&5M96YT(&5N<V]L96EL;.DB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-`IM
M<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R(")'Z6[I<F%L96UE;G0@;G5A
M9V5U>"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,U"FUS9VED(")-;W-T;'D@0VQO=61Y(&%N9"!7:6YD>2(*;7-G<W1R(")0
M<FEN8VEP86QE;65N="!N=6%G975X(&5T('9E;G1E=7@B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B36]S=&QY
M(%-U;FYY(@IM<V=S='(@(D?I;NER86QE;65N="!E;G-O;&5I;&SI(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-#@*
M;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R(")697)S(&QE(&)A<R(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C4R"FUS
M9VED(")-;W9E($QE9G0B"FUS9W-T<B`B1.EP;&%C97(@X"!G875C:&4B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U
M-@IM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R(")$Z7!L86-E<B#@(&1R;VET
M92(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP
M:'`Z-C0T"FUS9VED(")-;W9E(%5P(@IM<V=S='(@(E9E<G,@;&4@:&%U="(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C8*
M;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R(")697)S(&QE(&)A<R(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C4*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-@IM<V=I9"`B
M36]V92!U<"(*;7-G<W1R(")697)S(&QE(&AA=70B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*
M;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B36]Z86UB:7%U92(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#$*;7-G:60@(DUU;'1I+6QE=F5L
M(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R("),:7-T97,@9.ER;W5L86YT97,@
M;75L=&DM;FEV96%U>"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,#4Y"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS9W-T
M<B`B0V%R=&4@JZ!-=6QT:6UA<"!52Z"[(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C(S.0IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S
M='(@(E/I;&5C=&EO;B!M=6QT:7!L92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT,#(*;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T<B`B4&%R86WI
M=')A9V4@9'4@8V]M<'1E(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X
M"FUS9VED(")->2!!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(DUE<R!D
M;VYNZ65S('!E<G-O;FYE;&QE<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E
M>"YP:'`Z-#4*;7-G:60@(DUY(%!O<G1A;"(*;7-G<W1R(")-;VX@<&]R=&%I
M;"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HT,PIM<V=I9"`B37D@
M4&]R=&%L($QA>6]U="(*;7-G<W1R(")0<NES96YT871I;VX@9&4@;6]N('!O
M<G1A:6PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUY86YM87(B"FUS9W-T<B`B
M0FER;6%N:64B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N
M8V4N:'1M;#HU-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM<V=S='(@
M(DY/3BP@:F4@;B=A8V-E<'1E('!A<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0Q,2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3`R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N
M968N<&AP.C,X"FUS9VED(").86UE(@IM<V=S='(@(DYO;2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R(").86UI8FEE(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDW"FUS9VED(").875R=2(*;7-G<W1R(").875R=2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B3NEP86PB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(E!A>7,M0F%S(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3<*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@
M(D%N=&EL;&5S(&[I97)L86YD86ES97,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB
M"FUS9W-T<B`B55),(&1E(&)A<V4@9&4@3F5T<V-A<&4B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@
M0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B55),(&1E('+I=F]C871I;VX@
M9&4@;"=!+D,N($YE='-C87!E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!54DPB
M"FUS9W-T<B`B55),(&1E(&QA('!O;&ET:7%U92!D)T$N0RX@3F5T<V-A<&4B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-0IM<V=I
M9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B55),(&1E(')E;F]U
M=F5L;&5M96YT($YE='-C87!E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C87!E(%)E=F]C871I;VX@55),
M(@IM<V=S='(@(E523"!D92!RZ79O8V%T:6]N($YE='-C87!E(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C
M87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R(").;VT@9'4@<V5R=F5U<B!3
M4TP@3F5T<V-A<&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X.`IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*
M;7-G<W1R(")#;VUM96YT86ER92!D=2!C97)T:69I8V%T($YE='-C87!E(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@
M(DYE='-C87!E(&-E<G1I9FEC871E('1Y<&4B"FUS9W-T<B`B5'EP92!D=2!C
M97)T:69I8V%T($YE='-C87!E(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(U,PIM<V=I9"`B3F5T=V]R:R(*;7-G<W1R(")2Z7-E874B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,S.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDP"FUS
M9VED(").979E<B(*;7-G<W1R(")*86UA:7,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G
M:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B3F]U=F5L;&4M0V%LZ61O;FEE
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP
M:'`Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R(").;W5V96QL92!C
M873I9V]R:64B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K
M+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*;7-G:60@(DYE
M=R!-;V]N(@IM<V=S='(@(DYO=79E;&QE(&QU;F4B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@
M*&]P=&EO;F%L*2(*;7-G<W1R(").;W5V96%U(&YO;2!D92!C;VYN97AI;VX@
M*&9A8W5L=&%T:68I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(").97<@6F5A;&%N
M9"(*;7-G<W1R(").;W5V96QL92U:Z6QA;F1E(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C,W"FUS9VED(").97<@<&%S<W=O<F0B"FUS9W-T
M<B`B3F]U=F5A=2!M;W0@9&4@<&%S<V4B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W-Q;"YP:'`Z,C(W"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!P87-S
M=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS9W-T<B`B3&4@;F]U=F5A=2!M
M;W0@9&4@<&%S<V4@97AP:7)E<F$@;&4@)7@N(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C4R"FUS9VED(").97<@<&%S<W=O<F1S(&1O;B=T
M(&UA=&-H+B(*;7-G<W1R("),97,@;F]U=F5A=7@@;6]T<R!D92!P87-S92!D
M:69FZ')E;G0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R
M(").;W5V96QL92!F96[J=')E("A?8FQA;FLI(@H*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z-#`@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR.3$*;7-G:60@(DYE=W,B"FUS9W-T<B`B
M3F]U=F5L;&5S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-PIM
M<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R(")&;W)U;7,B"@HC.B!T96UP;&%T
M97,O9&%T82]T<W9I;F9O+FEN8SHQ-2!T96UP;&%T97,O9&%T82]D871E;6%P
M+FEN8SHT,0HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.2!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR-0IM<V=I9"`B3F5X="(*;7-G<W1R
M(")3=6EV86YT(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"FUS9VED(").
M97AT(#0@4&AA<V5S(@IM<V=S='(@(C0@<&AA<V5S('-U:79A;G1E<R(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8V(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,S<P"FUS9VED(").97AT(&]P=&EO;G,B"FUS
M9W-T<B`B3W!T:6]N<R!S=6EV86YT97,B"@HC.B!F<F%M97=O<FLO54DO54DO
M4&%G97(N<&AP.C$P,PIM<V=I9"`B3F5X=#XB"FUS9W-T<B`B4W5I=F%N=#XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.38*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R(").:6-A
M<F%G=6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R(@IM<V=S='(@(DYI
M9V5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<FEA(@IM<V=S='(@(DYI
M9V5R:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8Y"FUS
M9VED(").:6=H="(*;7-G<W1R(").=6ET(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED
M(").:75E(@IM<V=S='(@(DYI=64B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.38V"FUS9VED(").;R(*;7-G<W1R(").;VXB
M"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@
M(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F
M97)E;F-E<R!F;W(N(@IM<V=S='(@(B(*(E!A<R!D92!D;VYNZ65S(&1E(&-O
M;F9I9W5R871I;VX@<&]U<B!L97-Q=65L;&5S(&UO;G1R97(@;&5S(&1I9F;I
M<F5N8V5S+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<BYP:'`Z,3`V"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA
M:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R(")087,@9&4@<W1R873I9VEE(&1I
M<W!O;FEB;&4@<&]U<B!F86ER92!D97,@:6UA9V5S($E33RXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G
M:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R(")087,@9&4@9V%B87)I
M="!E;B!T<F%I=&5M96YT('!A<B!L;W0N(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,#$*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HS.#4*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT,#<*;7-G:60@(DYO
M(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S
M='(@(D%U8W5N(&)L;V,@;B=E>&ES=&4@X"!L82!P;W-I=&EO;B!D96UA;F3I
M92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-3`*;7-G:60@
M(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(E!A<R!D92!N;VT@9&4@8V%L96YD<FEE<B!F;W5R
M;FD@<&]U<B!L)V%U=&AE;G1I9FEC871I;VX@<&%R($U#04PN(@H*(SH@861M
M:6XO<V5T=7`O9&EF9BYP:'`Z-30*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T
M<B`B3F]N(&UO9&EF:>DN(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HQ-38*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T
M:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(D%U8W5N92!S;W5S+7!E<FUI<W-I
M;VX@;B=A(&)E<V]I;B!D)^IT<F4@86IO=73I92!S;W5S(&-E(&YI=F5A=2XB
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W."!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C4Q-PHC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H
M<#HW-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R(")!=6-U;F4@
M:6YF;W)M871I;VX@9&4@8V]N9FEG=7)A=&EO;B!S<.EC:69IZ64@<&]U<B`E
M<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@U-0IM<V=I9"`B
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($94
M4"!61E,N(@IM<V=S='(@(D%U8W5N92!I;F9O<FUA=&EO;B!D92!C;VYF:6=U
M<F%T:6]N(&9O=7)N:64@<&]U<B!&5%`@5D93+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z-C<R"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B075C
M=6YE(&EN9F]R;6%T:6]N(&1E(&-O;F9I9W5R871I;VX@9F]U<FYI92!P;W5R
M(%-13"!61E,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C<R-0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`B075C=6YE(&EN9F]R
M;6%T:6]N(&1E(&-O;F9I9W5R871I;VX@9F]U<FYI92!P;W5R(%-13"U&:6QE
M(%9&4RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,30*;7-G:60@(DYO(&-R961I="!L969T+B(*;7-G<W1R(")!
M=6-U;B!C<NED:70@9&ES<&]N:6)L92XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`IM<V=I9"`B3F\@9&5S=&EN
M871I;VX@<W5P<&QI960N(@IM<V=S='(@(D%U8W5N92!D97-T:6YA=&EO;B!T
M<F]U=NEE+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDR
M,`IM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R(")!=6-U;B!F:6-H
M:65R(&5N=F]YZ2(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HW,0IM<V=I
M9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@(D%U8W5N(&EC]&YE('1R;W5V
MZ2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$V(&QI8B]"
M;&]C:R]S=6YR:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$S
M,`IM<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R(")!=6-U;B!L
M:65U(&XG97-T('/I;&5C=&EO;F[I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$U-PIM<V=I9"`B3F\@;&]C871I;VX@<')O=FED960N(@IM
M<V=S='(@(D%U8W5N(&5M<&QA8V5M96YT(&XG97-T(&EN9&EQ=>DN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*
M;7-G:60@(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(D%U8W5N(&UE
M<W-A9V4@9F]U<FYI(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S8*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*
M;7-G<W1R(")!=6-U;B!N;VT@<W#I8VEF:>DN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*;7-G:60@(DYO(&YU
M;6)E<B!S<&5C:69I960N(@IM<V=S='(@(D%U8W5N(&YO;6)R92!S<.EC:69I
MZ2XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*;7-G:60@(DYO(&]F
M9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R(")087,@9"=A<&AO<FES;65S(&-H
M;W%U86YT<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z.3$*
M;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R(")!=6-U;B!M;W0@9&4@<&%S<V4@9F]U<FYI('!O
M=7(@;"=A=71H96YT:69I8V%T:6]N('!A<B!(5%10+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B075C
M=6X@;6]T(&1E('!A<W-E(&9O=7)N:2!P;W5R(&PG875T:&5N=&EF:6-A=&EO
M;B!P87(@24U!4"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP
M.C<R"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(D%U8W5N(&UO="!D92!P87-S92!F
M;W5R;FD@<&]U<B!L)V%U=&AE;G1I9FEC871I;VX@<&%R($ME<F)E<F]S+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z-S<@9G)A;65W;W)K
M+T%U=&@O075T:"]L;V=I;BYP:'`Z.#0*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]P86TN<&AP.C<U"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M3&]G:6X@875T:&5N=&EC871I;VXN(@IM<V=S='(@(D%U8W5N(&UO="!D92!P
M87-S92!S<.EC:69IZ2!P;W5R(&PG875T:&5N=&EF:6-A=&EO;BXB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W!A<W-W9"YP:'`Z,3,U"FUS9VED(").;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R(")!=6-U;B!M;W0@9&4@<&%S<V4@<W#I8VEF:>D@<&]U<B!L)V%U
M=&AE;G1I9FEC871I;VX@4$%34U=$+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<VUB+G!H<#HX-`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M(%--0B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B075C=6X@;6]T(&1E('!A
M<W-E('-PZ6-I9FGI('!O=7(@;"=A=71H96YT:69I8V%T:6]N(%--0BXB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R.#<*;7-G:60@
M(B(*(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4
M:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O<FL@=VET
M:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*(D%U8W5N(&-H96UI;B!V97)S
M(&QE(&)I;F%I<F4@3W!E;E-33"!F;W5R;FDN($QE(&)I;F%I<F4@9"=/<&5N
M4U-,(&5S="`B"B)NZ6-E<W-A:7)E('!O=7(@9F]N8W1I;VYN97(@879E8R!D
M97,@9&]N;NEE<R!02T-3(#$R+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS
M9W-T<B`B075C=6YE(&-O;F9I<FUA=&EO;B!E;B!A='1E;G1E(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C<V-@IM<V=I9"`B3F\@<75O=&$@<V5T+B(*
M;7-G<W1R(")087,@9&4@<75O=&$@<&]S:71I;VYNZ2XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0S"FUS9VED
M(").;R!R=6QE<R(*;7-G<W1R(")087,@9&4@<NAG;&5S(@H*(SH@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#@R"FUS9VED(").;R!S97!A<F%T;W(@
M<W!E8VEF:65D+B(*;7-G<W1R(")!=6-U;B!SZ7!A<F%T975R('-PZ6-I9FGI
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#0*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(E!A<R!D92!C]'3I
M<R(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@W"FUS9VED(").
M;R!S=6-H(&9I;&4B"FUS9W-T<B`B1FEC:&EE<B!I;F5X:7-T86YT(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$R-@IM<V=I9"`B3F\@=&5M
M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+B(*;7-G<W1R
M(")!=6-U;B!RZ7!E<G1O:7)E('1E;7!O<F%I<F4@97-T(&1I<W!O;FEB;&4@
M<&]U<B!L82!C86-H92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,C(Q"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S
M<W=O<F0@<V5N="XB"FUS9W-T<B`B075C=6X@;F]M(&0G=71I;&ES871E=7(@
M970@+V]U(&UO="!D92!P87-S92!E;G9O>>DN(@H*(SH@9G)A;65W;W)K+U)0
M0R]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO('9A;&ED(%A-3"!D871A
M(')E='5R;F5D(@IM<V=S='(@(D%U8W5N92!D;VYNZ64@6$U,('9A;&ED92!N
M)V$@Z73I(')E=&]U<F[I92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HY-S0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.CDX-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.3DU"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,#$R"FUS9VED(").;R!V86QU97,B"FUS9W-T<B`B4&%S
M(&1E('9A;&5U<B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C`*;7-G
M:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO
M;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B)087,@
M9&4@=F5R<VEO;B!T<F]U=NEE(&1A;G,@;&$@8V]N9FEG=7)A=&EO;B!O<FEG
M:6YA;&4N(%+I9^ENZ7)E>B!L82`B"B)C;VYF:6=U<F%T:6]N+B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E<G-I;VX@9F]U
M;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(B(*(E!A<R!D92!V97)S:6]N('1R;W5VZ64@9&%N
M<R!V;W1R92!C;VYF:6=U<F%T:6]N+B!2Z6?I;NER97H@;&$@8V]N9FEG=7)A
M=&EO;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDS
M"FUS9VED(").;VYE(@IM<V=S='(@(D%U8W5N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I9"`B3F]N92`H=7-E
M(&EM<&QI8VET*2(*;7-G<W1R(")!=6-U;B`H=71I;&ES97(@:6UP;&EC:71E
M;65N="DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,@IM<V=I9"`B3F]R
M9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T<B`B3F]R9&EQ=64@*$E33RTX.#4Y
M+3$P*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS
M9W-T<B`BSFQE($YO<F9O;&LB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@
M;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS9VED(").;W)T:&5R;B!(96UI<W!H
M97)E(@IM<V=S='(@(DCI;6ES<&CH<F4@3F]R9"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM
M<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S='(@(LYL97,@
M36%R:6%N;F5S(&1U(&YO<F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYO<G=A
M>2(*;7-G<W1R(").;W)VZ&=E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HV-#$*;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R(")087,@
M87!RZ',B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T
M,`IM<V=I9"`B3F]T($)E9F]R92(*;7-G<W1R(")087,@879A;G0B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,34*;7-G:60@(DYO="!A(&1I
M<F5C=&]R>2(*;7-G<W1R(")087,@=6X@9&]S<VEE<B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z-C,*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP
M:'`Z.#0*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q/=71P=713=')A=&5G>2YP:'`Z.34*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDN<&AP.C4Y"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@
M(DYO;B!I;7!LZ6UE;G3I+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-C@*;7-G:60@(DYO="!S970B"FUS9W-T<B`B26YA
M8W1I9B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N
M9&QE<BYP:'`Z,30U"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S
M:6]N2&%N9&QE<BYP:'`Z,38P"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE
M<B]397-S:6]N2&%N9&QE<BYP:'`Z,3<U"B,Z(&9R86UE=V]R:R]397-S:6]N
M2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R]3
M97-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,V(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HQ.3,*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(P
M."!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HR-3(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(V.0HC.B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,C@U(&9R86UE=V]R:R]61E,O5D93+G!H<#HS
M,#$*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,Q-B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z,S,S"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS-C8@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C0R-@HC.B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z-3`U(&9R86UE=V]R:R]61E,O5D93+G!H<#HU-S0*(SH@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C4Y,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-C8Y"FUS
M9VED(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R(").;VX@<')I<R!E;B!C;VUP
M=&4N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#@@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T-`HC.B!C;VYF:6<O
M:&]O:W,N<&AP+F1I<W0Z,3`U."!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,3@P"FUS9VED(").;W1E<R(*;7-G<W1R(").;W1E<R(*"B,Z('-E<G9I8V5S
M+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W
M<V4L(&=O(&)A8VLN(@IM<V=S='(@(E)I96X@X"!N879I9W5E<BP@<F5T;W5R
M;F5Z(&5N(&%R<FGH<F4N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S4*;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@(DYO=F5M
M8G)E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`T,PIM<V=I9"`B
M3G5M8F5R(@IM<V=S='(@(DYO;6)R92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T,C(*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S
M='(@(DYO;6)R92!D92!C87)A8W3H<F5S(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3,V-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(P"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#(@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O9B!C
M;VQU;6YS(@IM<V=S='(@(DYO;6)R92!D92!C;VQO;FYE<R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C0@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,30Q.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0P('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").
M=6UB97(@;V8@<F]W<R(*;7-G<W1R(").;VUB<F4@9&4@<F%N9^EE<R(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T
M"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN
M(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(").;VUB<F4@;F]N('-PZ6-I
M9FGI('!O=7(@;&$@;6ES92#@(&IO=7(@9&4@;&$@;&ES=&4@9&4@9&ES=')I
M8G5T:6]N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHV-`IM<V=I9"`B3TLB"FUS9W-T<B`B3TLB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")/8FIE8W0B
M"FUS9W-T<B`B3V)J970B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$Q,0IM<V=I9"`B3V)J96-T($-R96%T;W(B"FUS9W-T<B`B0W+I871E=7(@
M9"=O8FIE="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,#$*;7-G
M:60@(D]C=&%L(@IM<V=S='(@(D]C=&%L(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,0HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS9W-T
M<B`B3V-T;V)R92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I
M9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B1FEL=')E(&%N=&DM;V9F96YS
M86YT(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R.`IM<V=I9"`B
M3V9F:6-E(@IM<V=S='(@(D)U<F5A=2(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU
M<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R("),)V%N8VEE;B!E="!L92!N;W5V
M96%U(&UO=',@9&4@<&%S<V4@9&]I=F5N="#J=')E(&1I9F;I<F5N=',N(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V"FUS9VED(")/;&0@
M<&%S<W=O<F0B"FUS9W-T<B`B06YC:65N(&UO="!D92!P87-S92(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B3VQD('!A<W-W
M;W)D(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R("),)V%N8VEE;B!M;W0@9&4@
M<&%S<V4@97-T(&EN8V]R<F5C="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA
M;B(*;7-G<W1R(")/;6%N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O
M<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(E-E=6P@;&5S('-E<G9E=7)S
M($E-05`@<W5P<&]R=&5N="!L97,@9&]S<VEE<G,@<&%R=&%GZ7,N(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDU"FUS9VED(")/;FQY(&]F9F5N<VEV
M92!F;W)T=6YE<R(*;7-G<W1R(")3975L96UE;G0@;&5S(*N@9F]R='5N97.@
MNR!O9F9E;G-A;G1E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M-#@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DV.`IM<V=I9"`B3VYL>2!O
M;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R(")5;F4@<V5U;&4@
M861R97-S92!D92!C;W5R<FEE;"!P97)M:7-E+B(*"B,Z('-E<G9I8V5S+W-H
M87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@
M<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@
M;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@HB
M4V5U;',@;&4@<')O<')IZ71A:7)E(&]U(&PG861M:6YI<W1R871E=7(@<WES
M=.AM92!P975T(&UO9&EF:65R(&QE<R`B"B)P97)M:7-S:6]N<R!D)W5N('!A
M<G1A9V4N(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-#$@;&EB+T)L;V-K
M+VEF<F%M92YP:'`Z-#(*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM
M<V=S='(@(D]U=G)I<B!D86YS('5N92!N;W5V96QL92!F96[J=')E(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P
M96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N
M960@4R]-24U%('!A<G0N(@IM<V=S='(@(B(*(D5R<F5U<B!/<&5N4U-,H#H@
M:6UP;W-S:6)L92!D)V5X=')A:7)E(&QE<R!D;VYNZ65S(&1E(&QA('!A<G1I
M92!S:6=NZ64@4R]-24U%(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")/<&5N<R!T:&ES(&QI
M;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D]U=G)I<B!L97,@;&EE;G,@
M9&%N<R!U;F4@;F]U=F5L;&4@9F5NZG1R92(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R(")3
M>7-TZ&UE(&0G97AP;&]I=&%T:6]N(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I
M9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")/<'1I;VYS
M(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C,Q('1E;7!L871E<R]P<F5F<R]A
M<'`N:6YC.C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@9F]R("5S
M(@IM<V=S='(@(D]P=&EO;G,@<&]U<B`E<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES
M="(*;7-G<W1R("),:7-T92!N=6WI<F]TZ64B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N(@IM
M<V=S='(@(D]R9V%N:7-A=&EO;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-38Y"FUS9VED(")/<F=A;FES871I;VYA;"!5;FET(@IM
M<V=S='(@(E5N:73I(&]R9V%N:7-A=&EO;FYE;&QE(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$S-`IM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R
M(")/<F=A;FES871I;VXB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM
M<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`B
M36]DZ&QE(&]R:6=I;F%L(&0G87!P;&EC871I;VXB"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T
M96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(DUO9.AL97,@;W)I9VEN875X(&1A
M;G,@)7.@.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D@
M<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G<W1R
M(")!=71R92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.2!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3`Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-0HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3,T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#0*;7-G:60@
M(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(D%U=')E<R!I;F9O<FUA=&EO
M;G,B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,Q"FUS9VED(")/
M=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R(")097)M:7-S:6]N<R!D=2!P<F]P
M<FGI=&%I<F4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-SD*
M;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R("),)V%U=&AE;G1I9FEC871I;VX@4$%-(&XG97-T('!A<R!D:7-P
M;VYI8FQE+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M
M='`N<&AP.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM<V=S='(@
M(DUO9'5L92!014%2.CI-86EL(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3(W-@IM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM
M<V=S='(@(E-I9VYA='5R92!N=6WI<FEQ=64@4$=0(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,R,@IM<V=I9"`B4$=0($5N8W)Y<'1E
M9"!$871A(@IM<V=S='(@(D1O;F[I97,@4$=0(&-H:69F<NEE<R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-S0*;7-G:60@(E!'4"!0
M=6)L:6,@2V5Y(@IM<V=S='(@(D-L968@<'5B;&EQ=64@4$=0(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,U-@IM<V=I9"`B4$=0(%-I
M9VYE9"]%;F-R>7!T960@1&%T82(*;7-G<W1R(")$;VYNZ65S(%!'4"!S:6=N
MZ65S+V-H:69F<NEE<R(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV.0IM<V=I
M9"`B4$A0($-O9&4B"FUS9W-T<B`B0V]D92!02%`B"@HC.B!A9&UI;B]P:'!S
M:&5L;"YP:'`Z,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R("));G1E<G!R
MZ71E=7(@4$A0(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S@*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B4&QU:64@
M;.EGZ')E(&PG87!RZ',M;6ED:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,Y"FUS9VED(")032!286EN(@IM<V=S='(@(E!L
M=6EE(&PG87!RZ',M;6ED:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@(D%V
M97)S97,@;"=A<'+H<RUM:61I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#$*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`B3F5I
M9V4@;"=A<'+H<RUM:61I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R
M(")#:'5T97,@9&4@;F5I9V4@;"=A<'+H<RUM:61I(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#,*;7-G:60@(E!-(%-U;B(*
M;7-G<W1R(")3;VQE:6P@;"=A<'+H<RUM:61I(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E!-(%0M4W1O<FUS
M(@IM<V=S='(@(D]R86=E<R!L)V%P<NAS+6UI9&DB"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z,C<T"FUS9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES
M<VEN9R(*;7-G<W1R(")%>'1E;G-I;VX@4$]325@@86)S96YT92(*"B,Z(&QI
M8B]A<&DN<&AP.C$T.0IM<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R("));G1E
M<G!RZ71E=7(@4%](4"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B
M4F5M<&QI<W-A9V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A:VES=&%N(@IM
M<V=S='(@(E!A:VES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L874B
M"FUS9W-T<B`B0F5L874B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QE<W1I
M;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@(E!A;&5S=&EN92`H
M=&5R<FET;VER92!O8V-U<.DI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")086YA
M;6$B"FUS9W-T<B`B4&%N86UA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")087!U
M82!.97<@1W5I;F5A(@IM<V=S='(@(E!A<&]U87-I92U.;W5V96QL92U'=6EN
MZ64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")087)A9W5A>2(*;7-G<W1R(")0
M87)A9W5A>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,W"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S='(@(E!A<G1I96QL
M96UE;G0@;G5A9V5U>"(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU,S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,34Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(P,34*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW-R!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT,C4*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(DUO="!D
M92!P87-S92(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HX,@IM
M<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@
M(D-H86YG96UE;G0@9'4@;6]T(&1E('!A<W-E(&5F9F5C='7I+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3,R,PIM<V=I9"`B4&%S
M<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(DUO="!D92!P87-S92!I;F-O<G)E
M8W0B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,34R"FUS
M9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R(")-;W0@9&4@<&%S<V4@<F5Q=6ES('!O=7(@;"=A=71H
M96YT:69I8V%T:6]N(%)!1$E54RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,#4P"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*
M;7-G<W1R(")-;W0@9&4@<&%S<V4@879E8R!C;VYF:7)M871I;VXB"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@(E!A<W-W;W)D
M.B(*;7-G<W1R(")-;W0@9&4@<&%S<V6@.B(*"B,Z('1E;7!L871E<R]L;V=I
M;B]M;V)I;&4N:6YC.C$Q"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(DUO
M="!D92!P87-S9:`Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,#,Q"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*
M;7-G<W1R("),97,@;6]T<R!D92!P87-S92!D;VEV96YT(.IT<F4@:61E;G1I
M<75E<RXB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B
M4&%S=&4B"FUS9W-T<B`B0V]L;&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP
M8F]A<F0B"FUS9W-T<B`B0V]L;&5R(&1E<'5I<R!L92!P<F5S<V4M<&%P:65R
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`B0VAE;6EN(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F5Q=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB
M"FUS9W-T<B`B0V]N9FER;6%T:6]N<R!E;B!A='1E;G1EH#HB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-30*;7-G:60@(E!E;W!L92(*;7-G<W1R(")0
M97)S;VYN97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R(")0;W5R8V5N=&%G
M92(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL
M.C0Y"FUS9VED(")097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,B"FUS
M9W-T<B`B169F96-T=65R(&QE<R!O<.ER871I;VYS(&1E(&UA:6YT96YA;F-E
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Q,`IM<V=I9"`B4&5R9F]R
M;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R(")%
M9F9E8W1U97(@;&5S(&]PZ7)A=&EO;G,@9&4@;6%I;G1E;F%N8V4@X"!L82!C
M;VYN97AI;VZ@/R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,34V"FUS9VED(")097)M:7-S:6]N(@IM<V=S='(@(E!E<FUI<W-I;VXB"@HC
M.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G
M:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R("),
M82!P97)M:7-S:6]N(*N@)7.@NR!N)V5S="!P87,@<W5P<')I;>EE+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3DP"FUS9VED(")097)M:7-S
M:6]N($1E;FEE9"(*;7-G<W1R(")097)M:7-S:6]N(')E9G5SZ64B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T
M<B`B4&5R;6ES<VEO;G,B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#D@
M861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P"B,Z(&%D;6EN+W!E<FUS+VEN
M9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X"FUS9VED(")0
M97)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')A
M=&EO;B!D97,@<&5R;6ES<VEO;G,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C@*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(D1O
M;F[I97,@<&5R<V]N;F5L;&5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")097)U
M(@IM<V=S='(@(E#I<F]U(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U
M"FUS9VED(")0971S(@IM<V=S='(@(D%N:6UA=7@B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$X-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$W.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*
M;7-G:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(E!H:6QI<'!I;F5S(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I
M9"`B4&AO;F4B"FUS9W-T<B`B5.ELZ7!H;VYE(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0X,`IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(E!H;W1O
M<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DP(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A:7)N(@IM<V=S='(@(E!I
M=&-A:7)N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R(")0:7AE;',B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I='5D97,B"FUS
M9W-T<B`B4&QA=&ET=61E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I
M;G1O('-O;64@8V5L;"(*;7-G<W1R(")35E`@8VQI<75E>B!D86YS('5N92!C
M96QL=6QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO
M=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@(E-64"!C
M;VYF:7)M97H@;&$@<W5P<')E<W-I;VX@9&4@8V5T(.ELZ6UE;G2@.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U
M;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R(")35E`@8V]N9FER;65Z('%U
M92!V;W5S('9O=6QE>B!DZ6QI97(@8V5T(.ELZ6UE;G0N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C4U.0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@
M;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T<B`B5F5U:6QL97H@<V%I<VER('5N
M(&UO:7,@970@=6YE(&%N;NEE+B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C$R"FUS9VED(")0;&5A<V4@96YT97(@82!N
M86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R(")6975I;&QE>B!S
M86ES:7(@=6X@;F]M('!O=7(@;&$@;F]U=F5L;&4@8V%TZ6=O<FEEH#HB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,CDX"FUS9VED(")0;&5A<V4@
M96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R(")6975I;&QE>B!E
M;G1R97(@=6YE(&%D<F5S<V4@25`@=F%L:61E+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(V,S<*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED
M(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N
M(@IM<V=S='(@(B(*(E9E=6EL;&5Z(&5N=')E<B!U;F4@9&%T92!V86QI9&6@
M.R!VZ7)I9FEE>B!L92!N;VUB<F4@9&4@:F]U<G,@9'4@;6]I<RX@(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0T-`IM<V=I9"`B4&QE87-E(&5N
M=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`B5F5U:6QL97H@96YT<F5R('5N
M92!H975R92!V86QI9&4N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H
M92!P<F]B;&5M+B(*;7-G<W1R(")6975I;&QE>B!F;W5R;FER('5N('+I<W5M
MZ2!D=2!P<F]B;.AM92XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@(E!L96%S
M92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM<V=S='(@
M(E9E=6EL;&5Z(&9O=7)N:7(@=F]T<F4@;F]M(&0G=71I;&ES871E=7(@970@
M=F]T<F4@;6]T(&1E('!A<W-E(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C4X"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E
M>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@
M(@HB<WES=&5M+B(*;7-G<W1R("(B"B)6975I;&QE>B!L:7)E(&QE('1E>'1E
M('-U:79A;G0N(%9O=7,@9&5V97H@86-C97!T97(@;&5S(&-O;F1I=&EO;G,@
M<&]U<B`B"B)U=&EL:7-E<B!L92!S>7-TZ&UE+B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<P"FUS9VED(")0;&5A
M<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S='(@(E9E=6EL
M;&5Z(&5N=')E<B!L92!N;W5V96%U(&YO;:!D92!L82!C873I9V]R:66@.B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&]L86YD(@IM<V=S='(@(E!O;&]G;F4B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S
M(@IM<V=S='(@(E!O;&ET:7%U92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT.#D*;7-G:60@(E!O;&QS(@IM<V=S='(@(E-C<G5T:6YS(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,0IM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B4&]R='5G86PB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R
M-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B
M"FUS9W-T<B`B4&]S:71I;VX@9&4@8V5T=&4@:6UA9V4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S
M:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R(")0;W-I=&EO;B!D92!C
M92!T86)L96%U(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q
M-"YP:'`Z-3$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.3$*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E
M9"!B>2!)34%0*2(*;7-G<W1R(")%;G9O>65R(.`@8V4@9&]S<VEE<B`H;F]N
M(&%P<&QI<77I('!A<B!)34%0*2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C<S(&QI8B]";&]C:R]M971A<BYP:'`Z,C<X"B,L('!H<"UF;W)M870*;7-G
M:60@(E!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S
M='(@(E!RZ6-I<&ET871I;VYS('!O=7(@;&5S("5S(&1E<FYIZ')E<R!H975R
M97.@.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@W"FUS
M9VED(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(E!R;V)A
M8FEL:73I/&)R("\^9&4@<&QU:64B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O;&1A<"YP:'`Z.3@*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$
M05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?;&1A<*`Z
M(&5X=&5N<VEO;B!R97%U:7-E($Q$05`@;F]N('1R;W5VZ64N(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F
M<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(E!R969S7W-E<W-I;VZ@.B!E>'1E;G-I;VX@<F5Q=6ES
M92"KH'-E<W-I;VZ@NR!N;VX@=')O=7;I92XB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(S,@IM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B4')E<W-I;VXB
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V-@IM<V=I9"`B4')E<W-U<F4@
M870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B4')E<W-I;VX@874@;FEV96%U(&1E
M(&QA(&UE<J`Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,C0*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T<B`B4')E<W-I;VZ@.B`B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`S"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R(")!<&5RYW4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C0*;7-G:60@(E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O
M=R(*;7-G<W1R(")!<&5RYW4@9&4@;"=I;6%G92!D86YS('5N92!N;W5V96QL
M92!F96[J=')E(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS
M-38@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C`*;7-G:60@(E!R
M979I;W5S(&]P=&EO;G,B"FUS9W-T<B`B3W!T:6]N<R!P<NECZ61E;G1E<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*
M;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@(DEM<')I;65R(&QE(&1O
M8W5M96YT(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S
M"FUS9VED(")0<FEV871E($ME>2(*;7-G<W1R(")#;&5F('!R:7;I92(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-CD*;7-G:60@(E!R
M;V)L96TB"FUS9W-T<B`B4')O8FSH;64B"@HC.B!S97)V:6-E<R]P<F]B;&5M
M+G!H<#HQ,C<*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`B
M1&5S8W)I<'1I;VX@9'4@<')O8FSH;64B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S<Q"FUS9VED(")0<F]J96-T<R(*;7-G<W1R(")0<F]J971S
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P."!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,3@U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,R-S,*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S='(@(E1E>'1E(&-O=7)T
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED
M(")0=6)L:6,@2V5Y(@IM<V=S='(@(D-L968@<'5B;&EQ=64B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-@IM<V=I9"`B4'5B;&EC
M($ME>2!!;&=O<FET:&TB"FUS9W-T<B`B06QG;W)I=&AM92!D92!C;&5F('!U
M8FQI<75E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M-#4*;7-G:60@(E!U8FQI8R!+97D@26YF;R(*;7-G<W1R("));F9O<FUA=&EO
M;G,@<W5R(&QA(&-L968@<'5B;&EQ=64B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HR-#$*;7-G:60@(E!U8FQI8R]0<FEV871E(&ME>7!A
M:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(LEC:&5C
M(&1E(&QA(&?I;NER871I;VX@9&4@;&$@<&%I<F4@9&4@8VQE9G,@<'5B;&EQ
M=64O<')I=NEE+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DQ
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U97)T;R!2:6-O
M(@IM<V=S='(@(E!O<G1O(%)I8V\B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,T,S$T+G!H<#HU-0IM<V=I9"`B4'5R9V4@;65S<V%G97,B"FUS
M9W-T<B`B4'5R9V5R(&QE<R!M97-S86=E<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G
M:60@(E%A=&%R(@IM<V=S='(@(E%A=&%R(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C8T"FUS9VED(")1=65R>2(*;7-G<W1R(")297%UZG1E(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C<P"FUS9VED(")1=6]T82(*;7-G<W1R(")1
M=6]T82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C8T
M"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I
M(@IM<V=S='(@(D-L968@<'5B;&EQ=64@4E-!("@E9"!B:71S*2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C$*;7-G:60@(E)A9&EO('-E;&5C
M=&EO;B(*;7-G<W1R(")3Z6QE8W1I;VX@<F%D:6\B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I;B(*;7-G
M<W1R(")0;'5I92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0V"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@(E!L=6EE('3T
M="!L92!M871I;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0W"FUS9VED(")286EN($QA=&4B"FUS9W-T<B`B4&QU:64@=&%R
M9"!D86YS(&QA(&IO=7)NZ64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B
M079E<G-E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0Y"FUS9VED(")286EN(&%N9"!3;F]W(@IM<V=S='(@(E!L=6EE(&5T
M(&YE:6=E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-3`*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R(")0;'5I92!P=6ES
M(&YE:6=E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A
M;F1O;2!&;W)T=6YE(@IM<V=S='(@(D%P:&]R:7-M92!A=2!H87-A<F0B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8X(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO
M(@IM<V=S='(@(E1A=7@B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C,R-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-"!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$X,`IM<V=I9"`B4F5A9"(*;7-G<W1R("),:7)E(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#<*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*;7-G:60@(E)E860@
M;65S<V%G97,B"FUS9W-T<B`B365S<V%G97,@;'5S(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@
M(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U
M;F1O;F4N(@IM<V=S='(@(E-U<'!R97-S:6]N(&3I9FEN:71I=F4@9&4@)7.@
M/R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX"B,L('!H
M<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U
M<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G
M<W1R("(B"B)3=7!P<F5S<VEO;B!DZ69I;FET:79E(&1E<R!D;VYNZ65S('!O
M=7(@;"=U=&EL:7-A=&5U<B`E<Z`_($-E='1E(&]PZ7)A=&EO;B`B"B)E<W0@
M9.EF:6YI=&EV92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*
M;7-G<W1R(")297!R96YD<F4@=F]T<F4@9&5R;FGH<F4@86-T:6]N(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B4F%F<F'N8VAI<B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.34*;7-G:60@(E)E9G)E<V@@1'EN
M86UI8R!-96YU($5L96UE;G1S.B(*;7-G<W1R(")2869R8>YC:&ER(&QE<R#I
M;.EM96YT<R!D=2!M96YU(&1Y;F%M:7%U9:`Z(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,T-0IM<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB"FUS
M9W-T<B`B4F%F<F'N8VAI<B!L)^EC<F%N(&1U('-O;6UA:7)EH#HB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3$@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(Q,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,R"FUS
M9VED(")296=E>"(*;7-G<W1R(")%>'!R97-S:6]N(')A=&EO;FYE;&QE(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(R.`IM<V=I9"`B4F5L871I
M;VYS:&EP($)R;W=S97(B"FUS9W-T<B`B3F%V:6=A=&5U<B!R96QA=&EO;FYE
M;"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*;7-G:60@(E)E;&]A9"(*;7-G<W1R
M(")296-H87)G97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S,PIM<V=I
M9"`B4F5M87)K<R(*;7-G<W1R(")296UA<G%U97,B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3$W"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R
M(")397)V975R<R!D:7-T86YT<R(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHX-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M
M<&QE+F-O;2]H;W)D92DZ(@IM<V=S='(@(E523"!D:7-T86YT92`H:'1T<#HO
M+W=W=RYE>&5M<&QE+F-O;2]H;W)D92\IH#HB"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V5D:70N:6YC.C(R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U
M975E9"YI;F,Z,3,*;7-G:60@(E)E;6]V92(*;7-G<W1R(")2971I<F5R(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"FUS9VED(")296UO
M=F4@0FQO8VLB"FUS9W-T<B`B4F5T:7)E<B!L92!B;&]C(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U.0IM<V=I9"`B4F5M
M;W9E(&-O;'5M;B(*;7-G<W1R(")2971I<F5R(&QA(&-O;&]N;F4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0P"FUS9VED
M(")296UO=F4@9F]R;6%T=&EN9R(*;7-G<W1R(")2971I<F5R(&QE(&9O<FUA
M=&%G92(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(X"FUS9VED
M(")296UO=F4@<&%I<B(*;7-G<W1R(")2971I<F5R(&QA('!A:7)E(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E('-A=F5D
M('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM
M<V=S='(@(D5N;&5V97(@;&4@<V-R:7!T(&5N<F5G:7-T<ND@9'4@<NEP97)T
M;VER92!T96UP;W)A:7)E(&1U('-E<G9E=7(N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"FUS9VED(")2
M96UO=F4@=&AE(@IM<V=S='(@(E)E=&ER97(@;&4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@
M(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`B
M4F5T:7)E<B!C92!N;V5U9"!D=2!D;V-U;65N="(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*;7-G:60@(E)E;6]V92!U<V5R(@IM
M<V=S='(@(E)E=&ER97(@;"=U=&EL:7-A=&5U<B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V92YI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")2
M96UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B4F5T:7)E<B!L)W5T:6QI<V%T975R
MH#H@)7,B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$S.`IM
M<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@
M97)R;W)C;V1E.B`B"FUS9W-T<B`B075C=6YE('+I<&]N<V4@X"!V;W1R92!R
M97%UZG1E+B!#;V1E(&0G97)R975R(')E=&]U<F[IH#H@(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$T-0IM<V=I9"`B4F5Q=65S=&5D('-E
M<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*;7-G<W1R("),92!S97)V:6-E
M(&1E;6%N9.D@97-T(&EN=')O=79A8FQE+B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,3@U(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3(W
M"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E
M8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(DQE('!A
M<F%MZ'1R92!O8FQI9V%T;VER92"KH"5SH+L@;B=E<W0@<&%S('-PZ6-I9FGI
M(&1A;G,@;&$@8V]N9FEG=7)A=&EO;B`E<RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C8W."!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@V
M,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S,Q"B,L('!H
M<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D
M(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B),92!P87)A;>AT
M<F4@;V)L:6=A=&]I<F4@JZ`E<Z"[(&XG97-T('!A<R!S<.EC:69IZ2!D86YS
M(&QA(&-O;F9I9W5R871I;VX@9'4@(@HB5D93+B(*"B,Z(&9R86UE=V]R:R]5
M=&EL+U5T:6PN<&AP.C<W-@HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E
M9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R("(B"B),92!P87)A;>AT<F4@;V)L:6=A=&]I<F4@JZ`E<Z"[(&XG97-T
M('!A<R!S<.EC:69IZ2!D86YS(&QA(&-O;F9I9W5R871I;VXN(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S,U"FUS9VED(")297%U
M:7)E9"!&:65L9"(*;7-G<W1R(")#:&%M<"!O8FQI9V%T;VER92(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S-@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,C`*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,"!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(E+`6B(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"FUS9VED(")297-E
M="!087-S=V]R9"(*;7-G<W1R(")296UI<V4@X"!ZZ7)O(&1U(&UO="!D92!P
M87-S92(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W"FUS9VED
M(")297-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(E)E;65T=')E(.`@>NER
M;R!V;W1R92!M;W0@9&4@<&%S<V4B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3,Q"FUS9VED(")297-T;W)E($QA<W0@475E<GDB"FUS9W-T<B`B4F5V96YI
M<B#@(&QA(&1E<FYIZ')E(')E<77J=&4B"@HC.B!A9&UI;B]P:'!S:&5L;"YP
M:'`Z-S(@861M:6XO8VUD<VAE;&PN<&AP.C(Y(&%D;6EN+W-Q;'-H96QL+G!H
M<#HV-PIM<V=I9"`B4F5S=6QT<R(*;7-G<W1R(")2Z7-U;'1A=',B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E<R]P<F5F
M<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@
M(E)E=F5N:7(@875X(&]P=&EO;G,B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z,S@*;7-G:60@(E)E='EP92!N97<@<&%S<W=O<F0B"FUS9W-T
M<B`B4NDM96YT<F5R(&QE(&YO=79E874@;6]T(&1E('!A<W-E(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,@IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R(")2Z75N:6]N(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R(")2
M979E;FER(.`@;&$@8V]N9FEG=7)A=&EO;B!P<NECZ61E;G1E(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$S-0IM<V=I9"`B4FEC:"!497AT($5D:71O
M<B!/<'1I;VYS(@IM<V=S='(@(D]P=&EO;G,@9&4@;"?I9&ET975R(%)I8V@@
M5&5X="(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED
M9&QE<R(*;7-G<W1R(")$979I;F5T=&5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<P"FUS9VED(")2:6=H="(*
M;7-G<W1R(")$<F]I=&4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,3`P"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T<B`B16YTZG1E(&1E(&1R
M;VET92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,P.38*;7-G:60@
M(E)I9VAT('9A;'5E<R(*;7-G<W1R(")686QE=7)S(&-O<G)E8W1E<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR.`IM<V=I9"`B4F]?=R!0<F]P97)T:65S+BXN(@IM<V=S='(@(E!R;W!R
M:>ETZ7,@9&4@;&$@<F%N7V?I92`N+BXB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@
M(E+T;&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM<V=S='(@
M(E)O=6UA;FEE(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(R-@IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R(")0:79O=&5R
M(#$X,"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,C,*;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@(E!I=F]T97(@X"!G
M875C:&4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C(Y"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`B4&EV;W1E<B#@
M(&1R;VET92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0<F]P97)T:65S(@IM<V=S='(@
M(E!R;W!R:>ETZ7,@9&4@;&$@<F%N9^EE(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I9"`B4F]W('!R
M;W!E<G1I97,B"FUS9W-T<B`B4')O<')IZ73I<R!D92!L82!R86YGZ64B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,0IM
M<V=I9"`B4F]W<SHB"FUS9W-T<B`B4F%N9^EE<Z`Z(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PIM<V=I9"`B
M4G5L97,B"FUS9W-T<B`B4NAG;&5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,`IM<V=I9"`B4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(*;7-G<W1R
M(")$97,@9FEL971S(&%P<&%R8>YT<F]N="!E;G1R92!T;W5T97,@;&5S(')A
M;F?I97,@970@;&5S(&-O;&]N;F5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`B1&5S(&9I
M;&5T<R!A<'!A<F'N=')O;G0@96YT<F4@;&5S(&-O;&]N;F5S('-E=6QE;65N
M="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W
M<R!O;FQY(@IM<V=S='(@(D1E<R!F:6QE=',@87!P87)A[G1R;VYT(&5N=')E
M(&QE<R!R86YGZ65S('-E=6QE;65N="(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,C$*;7-G:60@(E)U;B(*;7-G<W1R("),86YC97(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`S"FUS9VED(")2=7-S:6%N($9E9&5R871I;VXB"FUS9W-T<B`B4G5S<VEE
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G=A;F1A(@IM<V=S='(@(E)W86YD
M82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C@U"FUS
M9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B
M4VEG;F%T=7)E(.EL96-T<F]N:7%U92!3+TU)344B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y
M<'1E9"!-97-S86=E(@IM<V=S='(@(DUE<W-A9V4@8VAI9F9RZ2!3+TU)344B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@Q"FUS9VED(")3
M05-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(DPG875T:&5N=&EF:6-A=&EO;B!305-,(&XG97-T('!A<R!D:7-P;VYI8FQE
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4P-@IM<V=I9"`B4TU3
M($UE<W-A9VEN9R(*;7-G<W1R(")-97-S86=E<FEE(%--4R(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(DEN
M=&5R<'+I=&5U<B!344PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,C<Q"FUS9VED(")344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM
M<V=S='(@(D]R9')E(%-13"!P;W5R(')E=&]U<FYE<B!L97,@=F%L975R<R(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S,*;7-G:60@(E-32"(*
M;7-G<W1R(")34T@B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#15-3
M(@IM<V=S='(@(E-50T/(4R(*"B,Z(&QI8B]A<&DN<&AP.C$U,PIM<V=I9"`B
M4U]13"!3:&5L;"(*;7-G<W1R("));G1E<G!RZ71E=7(@4U]13"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@
M(E-A(@IM<V=S='(@(E-A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@
M2&5L96YA(@IM<V=S='(@(E-A:6YT92U(Z6SH;F4B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*
M;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R(")386EN="U#
M:')I<W1O<&AE+65T+4YIZ7;H<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B4V%I
M;G0@3'5C:6$B"FUS9W-T<B`B4V%I;G1E+4QU8VEE(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R(")3
M86EN="U0:65R<F4@970@36EQ=65L;VXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED
M(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G<W1R(")3
M86EN="U6:6YC96YT+65T+6QE<R!'<F5N861I;F5S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F
M<F%M92`H7W-E;&8I(@IM<V=S='(@(DWJ;64@8V%D<F4@*%]S96QF*2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S='(@(E-A;6]A(&]C8VED
M96YT86QE<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-A;B!-87)I;F\B"FUS
M9W-T<B`B4V%I;G0M36%R:6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")386\@
M5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B4V%O+51O;>DM970M4')I;F-I
M<&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED
M(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B1F]U<FYI<W-E=7(@<V%T
M96QL:71E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM
M<V=S='(@(D%R86)I92!386]U9&ET92(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;&%Y;W5T+FEN8SHY.0IM<V=I9"`B4V%V92(*;7-G<W1R(")%;G)E9VES=')E
M<B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B16YR96=I
M<W1R97(@JZ`E<Z"[(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR
M,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R(")%;G)E
M9VES=')E<B`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G
M:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R(")%;G)E9VES=')E<B!L97,@;W!T
M:6]N<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C<*;7-G:60@(B(*
M(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T
M('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS
M9W-T<B`B(@HB16YR96=I<W1R97(@;&$@8V]N9FEG=7)A=&EO;B!GZ6[I<NEE
M(&-O;6UE('5N('-C<FEP="!02%`@9&%N<R!L92!RZ7!E<G1O:7)E("(*(G1E
M;7!O<F%I<F4@9&4@=F]T<F4@<V5R=F5U<BXB"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")%;G)E9VES=')E<B!L82!C;VYF:6=U
M<F%T:6]N(&1E("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I
M<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B4V-R:7!T(&1E(&UI<V4@X"!J;W5R
M(&1E(&-O;F9I9W5R871I;VX@96YR96=I<W1RZ2!S;W5SH#H@JR`E<Z"[(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G
M:60@(E-C871T97)E9"!4+5-T;W)M<R(*;7-G<W1R(")/<F%G97,@:7-O;.ES
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE;F-E
M(@IM<V=S='(@(E-C:65N8V4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L
M:7-T+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM
M<V=I9"`B4V5A<F-H(@IM<V=S='(@(E)E8VAE<F-H92(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS,C(*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM
M<V=S='(@(DUO=&5U<G,@9&4@<F5C:&5R8VAE(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,CDU,@IM<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S='(@
M(D-H;VES:7-S97H@;&5S(&9I8VAI97)S(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-0IM<V=I9"`B4V5L96-T(&$@9&%T
M92(*;7-G<W1R(")3Z6QE8W1I;VYN97H@=6YE(&1A=&4B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B4V5L96-T(&$@9W)O=7`@
M=&\@861D(@IM<V=S='(@(E/I;&5C=&EO;FYE>B!U;B!G<F]U<&4@X"!A:F]U
M=&5R(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B
M4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@(E/I;&5C=&EO;FYE>B!U;B!N
M;W5V96%U('!R;W!R:>ET86ER92(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(E/I
M;&5C=&EO;FYE>B!U;B!S97)V975R(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S
M='(@(E/I;&5C=&EO;FYE>B!U;B!U=&EL:7-A=&5U<B#@(&%J;W5T97(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<V"FUS
M9VED(")396QE8W0@86QL(@IM<V=S='(@(E1O=70@<^EL96-T:6]N;F5R(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8T,`IM<V=I9"`B4V5L96-T
M(&%L;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@(E/I;&5C=&EO;FYE>B!T
M;W5T97,@;&5S(&-O;7!O<V%N=&5S(&1E(&QA(&1A=&4N(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B4V5L
M96-T(&%N(&]B:F5C="(*;7-G<W1R(")#:&]I<VES<V5Z('5N(&]B:F5T(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-PIM
M<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B3F4@<^EL96-T:6]N;F5R(&%U
M8W5N(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W"FUS9VED("(B"B)3
M96QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@
M8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R
M;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B(@HB4^EL96-T:6]N;F5Z(&QE
M<R!C87)A8W3H<F5S(&1O;G0@=F]U<R!A=F5Z(&)E<V]I;B#@(&PG86ED92!D
M92!L)V]U=&EL(&-I+2(*(F1E<W-O=7,N(%9O=7,@<&]U=F5Z(&5N<W5I=&4@
M;&5S(&-O<&EE<B!E="!L97,@8V]L;&5R(&1A;G,@=F]T<F4@=&5X=&4N(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T
M:&4@9&%T92!D96QI;6ET97(Z(@IM<V=S='(@(E/I;&5C=&EO;FYE>B!L92!D
MZ6QI;6ET975R(&1E(&1A=&6@.B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R
M(")3Z6QE8W1I;VYN97H@;&4@9F]R;6%T(&1E(&1A=&6@.B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3`*;7-G:60@(E-E;&5C
M="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R(")3
MZ6QE8W1I;VYN97(@;&4@<')O9FEL('%U92!V;W5S(&3I<VER97H@;6]D:69I
M97(Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,38*;7-G:60@(E-E
M;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S='(@(E/I;&5C=&EO;FYE
M>B!L92!DZ6QI;6ET975R(&0G:&5U<F6@.B(*"B,Z('1E;7!L871E<R]D871A
M+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE('1I;64@9F]R;6%T.B(*
M;7-G<W1R(")3Z6QE8W1I;VYN97H@;&4@9F]R;6%T(&1E(&PG:&5U<F6@.B(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C
M="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R(")3Z6QE8W1I;VYN97H@
M9&5U>"!C:&%M<',@87!P87)E;G3I<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S$P"FUS9VED(")396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N(@IM
M<V=S='(@(E/I;&5C=&EO;FYE>B!V;W1R92!T:.AM92!D92!C;W5L975R<RXB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4R"FUS9VED(")396QE8W0@
M>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(E/I;&5C=&EO;FYE
M>B!V;W1R92!L86YG=64@<'+I9NERZ66@.B(*"B,Z('1E;7!L871E<R]P<F]B
M;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")396YD(%!R;V)L96T@4F5P;W)T
M(@IM<V=S='(@(D5N=F]Y97(@;&4@<F%P<&]R="!D)V%N;VUA;&EE(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-#(*;7-G
M:60@(E-E;F0@4TU3(@IM<V=S='(@(D5N=F]Y97(@4TU3(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R(")3Z6[I9V%L(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,C,*;7-G:60@(E-E;G-O<CH@(@IM<V=S='(@
M(E-O;F1EH#H@(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0Q,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-S,*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R(")397!T96UB<F4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I
M9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(E-E<F)I92!E="!-
M;VYT96YE9W)O(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HW,#(*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS9W-T<B`B3G5MZ7)O(&1E
M('/I<FEE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T.0IM
M<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B3&5S(&1O;F[I97,@9'4@<V5R=F5U<B!S;VYT(&9A=7-S97,@;W4@
M;F]N(&1I<W!O;FEB;&5S+B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR-PIM
M<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G<W1R(")!9&UI;FES=')A=&EO;B!D
M97,@<V5S<VEO;G,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E9"XB
M"FUS9W-T<B`B260N(&1E('-E<W-I;VX@97AP:7+I+B(*"B,Z(&QI8B]A<&DN
M<&AP.C$T-0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B4V5S<VEO;G,B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$Q"FUS9VED(")3970B"FUS
M9W-T<B`B4^EL96-T:6]N;F5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C<Y"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@
M>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N(@IM<V=S='(@
M(B(*(D-O;F9I9W5R97(@;&5S(&]P=&EO;G,@<&]U<B!V;W5S('!E<FUE='1R
M92!D92!R96UE='1R92#@('KI<F\@=F]T<F4@;6]T(&1E("(*(G!A<W-E('-I
M(&IA;6%I<R!V;W5S(&PG;W5B;&EE>BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3$X"FUS9VED(")3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y
M;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B
M0V]N9FEG=7)E<B!L97,@<V5R=F5U<G,@9&ES=&%N=',@86-C97-S:6)L97,@
M9&5P=6ES('9O=')E('!O<G1A:6PN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@W"FUS9VED(")3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I
M;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S='(@(B(*(E/I;&5C=&EO
M;FYE>B!V;W1R92!L86YG=64@<'+I9NERZ64L(&9U<V5A=2!H;W)A:7)E(&5T
M(&QE<R!O<'1I;VYS(&1E(&1A=&4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$P,0IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO
M;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B
M"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(B(*(D3I9FEN:7-S97H@;&$@
M<')E;6GH<F4@87!P;&EC871I;VX@;&%N8^EE+"!L92!T:.AM92!D92!C;W5L
M975R<RP@;&4@(@HB<F%F<F'N8VAI<W-E;65N="!D97,@<&%G97,L(&5T(&0G
M875T<F5S(&]P=&EO;G,@9"=A9F9I8VAA9V4N(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HW-PIM<V=I9"`B4V5T=7`B"FUS9W-T<B`B0V]N9FEG=7)A
M=&EO;B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,W
M"FUS9VED(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S
M='(@(E-C<FEP="!D92!C;VYF:6=U<F%T:6]N(&1E(&UI<V4@X"!J;W5R(&1I
M<W!O;FEB;&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<U
M"FUS9VED(")3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P
M87)A;65T97(Z("(*;7-G<W1R(")0;'5S:65U<G,@96YD<F]I=',@<&]S<VEB
M;&5S(&%V96,@;&4@<&%R86WH=')EH#H@(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I
M9"`B4V5Y8VAE;&QE<R(*;7-G<W1R(")397EC:&5L;&5S(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0Y.`IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T
M<B`B06-H870B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT
M,PIM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G<W1R(")2Z7-U;>DB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4P"FUS9VED(")3:&]U;&0@86-C97-S
M(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B1&]I
M="UO;B!DZ69I;FER(&1E<R!T;W5C:&5S(&1E(')A8V-O=7)C:7,@<&]U<B!L
M82!P;'5P87)T(&1E<R!L:65N<Z`_(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`B069F:6-H
M97(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,34U"FUS9VED("(B"B)3
M:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T
M:&4@;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(B(*(DUO;G1R97(@;&5S(&1I9F;I<F5N8V5S(&5N=')E(&QA(&-O;F9I9W5R
M871I;VX@96YR96=I<W1RZ64@86-T=65L;&5M96YT(&5T("(*(F-E;&QE(&YO
M=79E;&QE;65N="!GZ6[I<NEE+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT.30*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN
M9R!I;C\B"FUS9W-T<B`B36]N=')E<B!L)VAE=7)E(&1E(&QA(&1E<FYIZ')E
M(&-O;FYE>&EO;B#@(&PG96YT<NEEH#\B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-S8R"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I
M;F%L(@IM<V=S='(@(DUO;G1R97(@;"=O<'1I;VX@9&4@8V]N<V5R=F5R(&PG
M;W)I9VEN86PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-SDR"FUS
M9VED(")3:&]W('!I8VME<B(*;7-G<W1R(")-;VYT<F5R(&QE('/I;&5C=&5U
M<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S`*;7-G:60@(E-H;W<@
M=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B069F:6-H97(@
M;&$@8F%R<F4@9&4@;65N=2!D92!T86)L96%U>*`_(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H
M92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R(")!9F9I8VAE<B!L92!M
M96YU("5S(.`@9V%U8VAEH#\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A
M8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B069F:6-H97(@
M;&$@8F_N=&4@9&4@9&EA;&]G=64@=&%B;&5A=2!C96QL=6QE(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8T
M"FUS9VED(")3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9R(*;7-G
M<W1R(")!9F9I8VAE<B!L82!B;^YT92!D92!D:6%L;V=U92!D97,@<')O<')I
MZ73I<R!D=2!T86)L96%U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L
M92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B069F:6-H97(@;&$@
M8F_N=&4@9&4@9&EA;&]G=64@9&5S('!R;W!R:>ETZ7,@9&4@;&$@<F%N9^EE
M(&1U('1A8FQE874B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G:60@(E-H;W<@=&AE(&EM86=E('!R
M;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(D%F9FEC:&5R(&QA(&)O[G1E(&1E
M(&1I86QO9W5E(&1E<R!P<F]P<FGI=.ES(&1E(&PG:6UA9V4B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8P"FUS9VED(")3:&]W('5P;&]A9"(*
M;7-G<W1R(")!9F9I8VAE<B!L)V5N=F]I(&1E(&9I8VAI97(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4VAO
M=V5R<R(*;7-G<W1R(")!=F5R<V5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@16%R;'DB"FUS
M9W-T<B`B079E<G-E<R!T]'0@9&%N<R!L82!J;W5R;NEE(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-30*;7-G:60@(E-H;W=E
M<G,@3&%T92(*;7-G<W1R(")!=F5R<V5S('1A<F0@96X@:F]U<F[I92(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED
M(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R(")!=F5R<V5S(&%U
M>"!A;&5N=&]U<G,B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.C8Q.0IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(E)E<W-E
M<G)E<B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z.3$P"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z.3<R"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z,3`U.`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C$Q,C`*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HQ,3@S"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(R,PHC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R-3(*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C@U"FUS9VED(")3
M:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H
M92!W87D@9FER<W0B"FUS9W-T<B`B4F5S<V5R<F5R(&]U(&3I9V%G97(@9"=A
M8F]R9"!L92AS*2!B;&]C*',I('9O:7-I;BAS*2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*
M;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R(")3:65R<F$@3&5O;F4B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8V"FUS9VED(")3
M:6=N('5P(@IM<V=S='(@(E,G:6YS8W)I<F4B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,PIM<V=I9"`B4VEG;F%T=7)E(@IM<V=S
M='(@(E-I9VYA='5R92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-S$R"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S='(@
M(D%L9V]R:71H;64@9&4@<VEG;F%T=7)E(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I
M9"`B4VEN9V%P;W)E(@IM<V=S='(@(E-I;F=A<&]U<B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C4@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HW,@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C@T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y
M,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$R(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$R,S0*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C(T,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3`Y"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,Q,#(*;7-G:60@(E-I>F4B"FUS9W-T<B`B5&%I
M;&QE(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT
M;6PZ-3(*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B06YN=6QE
M<B!L82!M86EN=&5N86YC92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9A
M:VEA(@IM<V=S='(@(E-L;W9A<75I92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@
M(E-L;W9E;FEA(@IM<V=S='(@(E-L;W;I;FEE(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*;7-G:60@(E-N;W<B"FUS9W-T
M<B`B3F5I9V4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU-PIM<V=I9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B079E<G-E(&1E
M(&YE:6=E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-3@*;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R(")!=F5R<V5S(&1E
M(&YE:6=E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-3D*;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R(")!=F5R
M<V5S(&1E(&YE:6=E('3T="!D86YS(&QA(&IO=7)NZ64B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,`IM<V=I9"`B4VYO=R!3
M:&]W97)S($QA=&4B"FUS9W-T<B`B079E<G-E<R!D92!N96EG92!T87)D(&5N
M(&IO=7)NZ64B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X-0IM<V=I9"`B
M4VYO=R!D97!T:#H@(@IM<V=S='(@(DAA=71E=7(@9&4@;F5I9V6@.B`B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X.0IM<V=I9"`B4VYO=R!E<75I=F%L
M96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B475A;G1I=.D@9"=E874@Z7%U:79A
M;&5N=&4@X"!L82!Q=6%N=&ETZ2!D92!N96EG9:`Z("(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#,*;7-G:60@(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R("+.;&5S(%-A;&]M
M;VXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3;VUA;&EA(@IM<V=S='(@(E-O
M;6%L:64B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*;7-G:60@(E-O
M;F=S("8@4&]E;7,B"FUS9W-T<B`B0VAA;G-O;G,@970@<&_H;65S(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDP-0IM<V=I9"`B4V]R="!O<F1E
M<B!S96QE8W1I;VXB"FUS9W-T<B`B4^EL96-T:6]N(&1E(&PG;W)D<F4@9&4@
M=')I(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU-3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU.#D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C$W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(T-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C$V-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C$X.0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B
M061R97-S92!S;W5R8V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")3;W5T:"!!
M9G)I8V$B"FUS9W-T<B`B069R:7%U92!D=2!S=60B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$Y,PIM<V=I9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y
M+3,I(@IM<V=S='(@(E-U9"UE=7)O<.EE;B`H25-/+3@X-3DM,RDB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S<*;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!3
M86YD=VEC:"!)<VQA;F1S(@IM<V=S='(@(D?I;W)G:64M9'4M<W5D(&5T(.YL
M97,@4V%N9'=I8V@M9'4M<W5D(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S
M(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P
M:&5R92(*;7-G<W1R(")(Z6UI<W!HZ')E(%-U9"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B
M971W965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(D5S<&%C92!E;G1R92!C
M96QL=6QE<R!A9&IA8V5N=&5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E='=E96X@8V]N
M=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B17-P86-E(&5N=')E
M(&QE(&-O;G1E;G4@970@;&$@8F]R9'5R92!D86YS('5N92!C96QL=6QE(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#$R"FUS9VED(")3<&%C97(B
M"FUS9W-T<B`B17-P86-E=7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4U"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*;7-G:60@(E-P86-I;F<B"FUS9W-T
M<B`B17-P86-E;65N="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I;F<@86YD('!A9&1I
M;F<B"FUS9W-T<B`B17-P86-E;65N="!E="!R96UP;&ES<V%G92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<Q"FUS9VED(")3<&%I;B(*;7-G<W1R(")%<W!A9VYE(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P,`IM<V=I9"`B4W!A;2(*;7-G<W1R
M(")0;W5R<FEE;"(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I
M9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`B0V%R86-TZ')E
M<R!S<.EC:6%U>"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C(*;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`B
M4V-I;F1E<B!L82!C96QL=6QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L:70@8V]L=6UN
M(@IM<V=S='(@(E-C:6YD97(@;&$@8V]L;VYN92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@(E-P
M;&ET(')O=R(*;7-G<W1R(")38VEN9&5R(&QA(')A;F?I92(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV,0IM<V=I9"`B4W!O<G1S(@IM<V=S='(@(E-P
M;W)T<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@
M(E-R:2!,86YK82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV
M-B!L:6(O0FQO8VLO;65T87(N<&AP.C@Q"FUS9VED(")3=&%N9&%R9"(*;7-G
M<W1R(")3=&%N9&%R9"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@IM
M<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(E-T87(@5')E:R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(U.#,@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C<X.`IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R(")!;F[I92!D92!D
MZ6)U="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q
M"FUS9VED(")3=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R("+)=&%T(&]U('!R
M;W9I;F-E(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ
M,3(*;7-G:60@(E-T871U<R(*;7-G<W1R(")3=&%T=70B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-SDT"FUS9VED(")3=&]R86=E(&9O<FUA="(*
M;7-G<W1R(")&;W)M870@9&4@<V%U=F5G87)D92(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")3=')E970@061D<F5S
M<R(*;7-G<W1R(")2=64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q"FUS9VED(")3=')I:V5T:')O=6=H(@IM<V=S='(@
M(D)A<G+I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S,`IM<V=I
M9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B3&ES=&4@9&4@8VAA[FYE<R(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S`*;7-G:60@(E-T<FEP(&1O
M;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@(E)E=&ER97(@;&4@9&]M
M86EN92!D92!L)V%D<F5S<V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(S"FUS9VED(")3='EL92!;0U-372(*
M;7-G<W1R(")3='EL92!;0U-372(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@(E-U(@IM<V=S='(@(D1I(@H*
M(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G
M:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")3
M;W5S+7+I<&5R=&]I<F4@JZ`E<Z"[(&YO;B!T<F]U=NDB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J
M96-T(@IM<V=S='(@(E-U:F5T(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S(Y(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,Q-PIM
M<V=I9"`B4W5B;6ET(@IM<V=S='(@(D5N=F]I(@H*(SH@<VEG;G5P+G!H<#HT
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T
M;R!A9&0@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN
M('5N=&EL('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS
M9W-T<B`B(@HB3&$@9&5M86YD92!D)V%J;W5T(&1E(*N@)7.@NR!A=2!S>7-T
MZ&UE(&$@Z73I('-O=6UI<V4N(%9O=7,@;F4@<&]U<G)E>B!P87,@(@HB=F]U
M<R!C;VYN96-T97(@:G5S<74GX"!S;VX@87!P<F]B871I;VXN(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B
M4W5B<V-R:7!T(@IM<V=S='(@(DEN9&EC92(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I
M;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G
M<W1R(")3=6-CZ',B"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S
M>7-T96TN(@IM<V=S='(@(JN@)7.@NR!A(&)I96X@Z73I(&%J;W5TZ2AE*2XB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O
M;2!T:&4@<WES=&5M+B(*;7-G<W1R("),97,@9&]N;NEE<R!D92!L)W5T:6QI
M<V%T975R(*N@)7.@NR!O;G0@8FEE;B#I=.D@<F5T:7+I97,@9'4@<WES=.AM
M92XN(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI;B]P97)M<R]D96QE
M=&4N<&AP.C0V"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D
M96QE=&5D(%PB)7-<(BXB"FUS9W-T<B`BJZ`E<Z"[(&$@8FEE;B#I=.D@<W5P
M<')I;>DH92DN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M('1H
M92!S>7-T96TN(@IM<V=S='(@(JN@)7.@NR!A(&)I96X@Z73I(')E=&ERZ2AE
M*2XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C
M97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E
M92!C:&%N9V5S+B(*;7-G<W1R("(B"B)2971O=7(@X"!L82!C;VYF:6=U<F%T
M:6]N(&EN:71I86QE('+I=7-S:2X@(%)A9G)A[F-H:7(@;&$@<&%G92!P;W5R
M('9O:7(@;&5S("(*(FUO9&EF:6-A=&EO;G,N(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS9VED
M(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(D5N<F5G:7-T<F5M96YT(&1E(&QA(&-O;F9I9W5R871I;VX@9&4@
M;&$@<V%U=F5G87)D92!RZ75S<VDN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<V%V
M960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@
M(B(*(D5N<F5G:7-T<F5M96YT('+I=7-S:2!D92!L82!C;W!I92!D92!S875V
M96=A<F1E(&1U(&9I8VAI97(@9&4@8V]N9FEG=7)A=&EO;B`E(@HB<RXB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY('5P9&%T960@7"(E<UPB(@IM<V=S='(@(JN@)7.@NR!A(&)I
M96X@Z73I(&UI<RAE*2#@(&IO=7(N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@(LEC<FET
M=7)E(&1E("5S('+I=7-S:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U9&%N
M(@IM<V=S='(@(E-O=61A;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*;7-G:60@(E-U;6UA<GDB"FUS9W-T
M<B`B4V]M;6%I<F4B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C4*;7-G
M:60@(E-U;B!2:7-E(@IM<V=S='(@(DQE=F5R(&1U(%-O;&5I;"(*"B,Z(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*;7-G<W1R
M(")#;W5C:&5R(&1U(%-O;&5I;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8Q"FUS9VED(")3=6YN>2(*;7-G<W1R(")%;G-O
M;&5I;&SI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-0IM
M<V=I9"`B4W5N<FES92(*;7-G<W1R("),979E<B!D=2!3;VQE:6PB"@HC.B!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@(DQE=F5R+T-O=6-H
M97(@9'4@4V]L96EL(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(P-`IM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(DQE=F5R(&1U(%-O;&5I
M;#H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P.`IM<V=I
M9"`B4W5N<V5T(@IM<V=S='(@(D-O=6-H97(@9'4@4V]L96EL(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-PIM<V=I9"`B4W5N<V5T.B`B
M"FUS9W-T<B`B0V]U8VAE<B!D=2!3;VQE:6R@.B`B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S"FUS9VED(")3=7!E<G-C
M<FEP="(*;7-G<W1R(")%>'!O<V%N="(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS.#`*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B07-S:7-T86YC
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(E-U
M<FEN86T@;W4@1W5Y86YE(&AO;&QA;F1A:7-E(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S4*;7-G:60@(E-U<FYA;64B"FUS9W-T
M<B`B3F]M(&1E(&9A;6EL;&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L
M8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(LYL97,@4W9A;&)A<F0@970@
M2F%N($UA>65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B4W=A>FEL86YD(@IM
M<V=S='(@(E-W87II;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E
M;B(*;7-G<W1R(")3=>AD92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")3=VET>F5R
M;&%N9"(*;7-G<W1R(")3=6ES<V4B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HX-@IM<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G<W1R(")*
M;W5R;F%L(&1E('-Y;F-H<F]N:7-A=&EO;B!S=7!P<FEMZ2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-#4*;7-G:60@(E-Y;F--3"(*;7-G<W1R(")3
M>6YC34PB"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z.3<*
M;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B
M17)R975R(&1E('-Y;G1A>&4@9&%N<R!L97,@=&5R;65S(&1E(')E8VAE<F-H
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC
M(@IM<V=S='(@(E-Y<FEE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E0M4W1O<FTB"FUS9W-T<B`B3W)A9V5S
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*
M;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM<V=S='(@(D]R86=E(&5T('9E
M;G0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M-`IM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B3W)A9V5S(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C4*;7-G:60@(E0M4W1O
M<FUS($5A<FQY(@IM<V=S='(@(D]R86=E<R!M871I;F%U>"(*"B,Z(&9R86UE
M=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-C8*;7-G:60@(E135B!F:6QE(@IM
M<V=S='(@(D9I8VAI97(@5%-6(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@4')O<&5R
M=&EE<R(*;7-G<W1R(")0<F]P<FGI=.ES(&1U('1A8FQE874B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W"FUS9VED(")4
M86)L92!3970B"FUS9W-T<B`B5&%B;&5A=2!D92!V86QE=7)S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM
M<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R(")0<F]P<FGI=.ES(&1U
M('1A8FQE874B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-"!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")486EW86XB
M"FUS9W-T<B`B5&'O=V%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B
M"FUS9W-T<B`B5&'O=V%N+"!P<F]V:6YC92!D92!#:&EN92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B5&%J:6MI<W1A;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A;GIA;FEA+"!5;FET960@4F5P=6)L
M:6,@;V8B"FUS9W-T<B`B5&%N>F%N:64B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDU"FUS9VED(")487)G970Z(@IM<V=S
M='(@(D-I8FQEH#HB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS
M,B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`T.0HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3@Y"FUS9VED(")487-K<R(*;7-G<W1R(")4XF-H97,B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-`IM<V=I
M9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R(").=6WI<F\@9&4@=.ELZ7!H
M;VYE(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3<*;7-G:60@(E1E;7`@
M9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(E1E;7#I<F%T=7)E('!O=7(@;&$@
M9&5R;FGH<F4@:&5U<F6@.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R
M,0IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B5&5M<.ER871U<F4B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$R"FUS9VED(")496UP
M97)A='5R93H@(@IM<V=S='(@(E1E;7#I<F%T=7)EH#H@(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(X,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM
M<V=S='(@(E1E;7#I<F%T=7)E/&)R("\^*"5S2&$E<R\E<T)A)7,I("9D96<[
M)7,B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C8Y-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S7"(@;F]T(&9O=6YD
M+B(*;7-G<W1R(")0<F]F:6P@JZ`E<Z"[(&YO;B!T<F]U=NDB"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R
M871I;VXB"FUS9W-T<B`B061M:6YI<W1R871I;VX@9&5S(&UO9.AL97,B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C`X(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,S,C0*;7-G:60@(E1E>'0B"FUS9W-T<B`B5&5X=&4B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Y"FUS9VED(")497AT($]N;'DB
M"FUS9W-T<B`B5&5X=&4@<V5U;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G:60@(E1E>'0@86QI9VXB
M"FUS9W-T<B`B06QI9VYE;65N="!D=2!T97AT92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B
M"FUS9W-T<B`B5&5X=&4@96X@:&%U="(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(DIE
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.30*;7-G:60@(E1H86D@*%1)
M4RTV,C`I(@IM<V=S='(@(E1H8>\@*%1)4RTV,C`I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B5&AA[VQA;F1E(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-3$*;7-G:60@(E1H92!&5%`@97AT
M96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DPG97AT96YS:6]N
M($944"!N)V5S="!P87,@9&ES<&]N:6)L92XB"@HC.B!F<F%M97=O<FLO2&ES
M=&]R>2](:7-T;W)Y+G!H<#HU-0IM<V=I9"`B5&AE($AI<W1O<GD@<WES=&5M
M(&ES(&1I<V%B;&5D+B(*;7-G<W1R("),)VAI<W1O<FES871I;VX@97-T(&3I
M<V%C=&EVZ64N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T
M:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R("),
M92!M;W1E=7(@9"=I;G3I9W)A=&EO;B!(;W)D92]+;VQA8B!N92!S=7!P;W)T
M92!P87,@JZ`E<Z"[(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O0F]O
M:RYP:'`Z,3(Y.`IM<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I
M;FET:6%L:7IE9"XB"FUS9W-T<B`B3&4@:F]U<FYA;"!)35-0(&XG82!P87,@
M<'4@ZG1R92!I;FET:6%L:7/I+B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E
M+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO
M="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R("),82!C;&%S<V4@36%I;G1E
M;F%N8V4Z.B!N)V$@<&%S(.ETZ2!C:&%R9^EE(&-O<G)E8W1E;65N="(*"B,Z
M('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H
M92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R
M("),82!F96[J=')E(&1E<R!O<'1I;VYS(',G97-T(&9E<FWI92X@4V]R=&EE
M+B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,C$Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(S"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C8T
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4:&4@
M861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@
M4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R
M;6ES<VEO;G,N(@IM<V=S='(@(B(*(DPG861M:6YI<W1R871E=7(@9&]I="!C
M;VYF:6=U<F5R('5N(&)A8VME;F0@<&5R;6%N96YT('!O=7(@;&5S('!E<FUI
M<W-I;VYS("(*(G-I('9O=7,@=F]U;&5Z(&QE<R!E;7!L;WEE<BXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U
M"FUS9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R("),82!B;W)D
M=7)E(&1U(&)A<R!S975L96UE;G0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A
M8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R
M('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R("(B
M"B),)TE$(&1U(&-O;G1A8W0@;B=A('!A<R#I=.D@<W#I8VEF:>DL(&QA:7-S
MZ2!V:61E(&]U(&XG82!P87,@Z73I('1R;W5VZ2!D86YS("(*(FQA(&)A<V4@
M9&4@9&]N;NEE<RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z-3$*;7-G:60@(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L
M;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(D-E(&-O
M;G1A8W0@82!B:65N(.ETZ2!A:F]U=.D@X"!V;W1R92!C87)N970@9"=A9')E
M<W-E<RX@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$W
M,@IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@
M:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB"FUS
M9W-T<B`B(@HB3&4@8FQO8R!D92!S:6=N871U<F4@4$=0('/I<&%RZ2!E<W0@
M;NEC97-S86ER92!P;W5R(';I<FEF:65R(&QA('-I9VYA='5R92XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM
M<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@
M;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@
M=&AE(&1A=&%B87-E+B(*;7-G<W1R("(B"B),)TE$(&1E(&QA(&QI<W1E(&XG
M82!P87,@Z73I('-PZ6-I9FGI+"!L86ES<^D@=FED92!O=2!N;VX@=')O=7;I
M(&1A;G,@;&$@(@HB8F%S92!D92!D;VYNZ65S+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@
M9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@
M(DQA(&QI<W1E(&1E(&1I<W1R:6)U=&EO;B!N)V$@<&%S(.ETZ2!S<.EC:69I
MZ64N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+G!H<#HQ,38*;7-G:60@
M(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B
M(&-O;FYE8W1I;VXN(@IM<V=S='(@(DQE(&-H:69F<F5M96YT(&[I8V5S<VET
M92!U;F4@8V]N;F5X:6]N('/I8W5R:7/I92XB"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$X-B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4R
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N
M=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@(DQE(&9I8VAI97(@)7,@9&]I
M="!C;VYT96YI<B!L97,@;W!T:6]N<R`E<RXB"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$W.2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N
M=&%I;B!S;VUE("5S('-E='1I;F=S+B(*;7-G<W1R("),92!F:6-H:65R("5S
M(&1O:70@8V]N=&5N:7(@8V5R=&%I;F5S(&]P=&EO;G,@)7,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C(V"FUS9VED(")4:&4@9FEL92!C
M86YN;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+B(*;7-G<W1R("),92!F:6-H
M:65R(&YE('!E=70@<&%S(.IT<F4@8V]P:>D@<W5R(&QU:2UMZFUE+B(*"B,Z
M(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@
M8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(DQE(&9I8VAI97(@;F4@8V]N
M=&5N86ET(&%U8W5N92!D;VYNZ64N(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A
M<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G
M92XB"FUS9W-T<B`B0V4@<75I('-U:70@<V]N="!L97,@96XM=.IT97,@<&]U
M<B!C92!M97-S86=E(&UE<W-A9V4O4D9#.#(R+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F
M=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I
M=&@@26YT97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@
M=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H
M="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET
M;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@
M268@(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK
M96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R;W1E8W1I;VX@
M1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N
M('=A<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N
M="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS9W-T<B`B(@HB
M3&4@;6]D92!P;&5I;B#I8W)A;B!C875S92!D97,@<')O8FSH;65S(&%V96,@
M26YT97)N970@17AP;&]R97(@9/L@X"!D97,@(@HB8F]G=65S(&1U(&YA=FEG
M871E=7(@<75I(&XG;VYT('!U(.IT<F4@8V]N=&]U<F[I<RX@5F]U<R!P;W5V
M97H@ZG1R92`B"B)C;VYF<F]N=.ES(.`@9&4@;"=A9F9I8VAA9V4@9&4@8V%R
M86-TZ')E<R#I=')A;F=E<RP@874@;F]N+69O;F-T:6]N;F5M96YT("(*(F1E
M<R!C97)T86EN97,@9F]N8W1I;VYS(&5T+V]U(&%U('!L86YT86=E(&%LZ6%T
M;VER92!D=2!N879I9V%T975R+B!3:2!V;W1R92`B"B)S>7-TZ&UE(&5S="!U
M;B!7:6YD;W=S(#EX+"!I;"!E<W0@='+H<R!P;W-S:6)L92!Q=64@=F]U<R!A
M=7)E>B!U;F4@)T9A=71E("(*(F?I;NER86QE(&1E('!R;W1E8W1I;VXG(&5T
M('%U92!V;W5S(&1E=G)E>B!R963I;6%R<F5R('9O=')E(&]R9&EN871E=7(N
M7%QN(@HB7%QN5F]U<R!A=F5Z(.ETZ2!P<NEV96YU<RX@4U90(&%P<'5Y97H@
M<W5R($]+('-I('9O=7,@=F]U;&5Z('1O=6IO=7)S("(*(F5S<V%Y97(@;&4@
M;6]D92!P;&5I;B#I8W)A;B!D92!L)^ED:71E=7(B"@HC.B!S97)V:6-E<R]P
M<F5F<RYP:'`Z,3$Q"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!I9&5N=&ET
M>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B3"=I9&5N=&ET
MZ2"KH"5SH+L@(&$@Z73I('-U<'!R:6WI92XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4:&4@
M;&5F="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("),92!C]'3I(&=A=6-H92!S
M975L96UE;G0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y
M(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G
M<W1R("(B"B),)V5M<&QA8V5M96YT(&1U('!R;V=R86UM92!';G501R!D;VET
M(.IT<F4@9F]U<FYI(.`@;&$@8VQA<W-E($-R>7!T7W!G<#HZ+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O341.+G!H<#HR,#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U
M8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@
M;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O
M<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"B),92!M97-S86=E(&5N=F]YZ2!L
M92`E<R#@("5S(&%V96,@8V]M;64@<W5J970@JZ`E<Z"[(&$@Z73I(&%F9FEC
M:.DN(%QN(@HB26P@;B=Y(&$@875C=6YE(&=A<F%N=&EE('%U92!C92!M97-S
M86=E(&$@Z73I(&QU(&]U(&-O;7!R:7,N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@W-`IM<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN
M:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S='(@(DQE(&YO;2#@('5T
M:6QI<V5R(&5N(&QI86YT(.`@;&$@<&%G92!D92!C;VUP;W-I=&EO;B(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0W-`IM<V=I9"`B5&AE(&YU
M;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*;7-G<W1R("),92!N
M;VUB<F4@9&4@8VAA;7!S(&1O:70@ZG1R92!U;B!N;VUB<F4@=F%L:61E+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(S,@IM<V=I
M9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R
M9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B3&4@;6]D=6QE($]P
M96Y34TP@97-T(')E<75I<R!P;W5R(&QA(&-L87-S92!(;W)D95]#<GEP=%]S
M;6EM93HZ+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,CDU"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C
M;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T
M:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"B),82!P
M<NEFZ7)E;F-E(*N@)7.@NR!N)V$@<&%S('!U(.IT<F4@96YR96=I<W1RZ64@
M8V%R('-A('1A:6QL92!DZ7!A<W-E(&QE("(*(FUA>&EM=6T@875T;W)I<^DB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D96(N<&AP.C,R"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS-0HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP
M.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z
M,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<G!M+G!H<#HS,@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]W96)C<'`N<&AP.C,W"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H<#HS
M-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS
M,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D('1O
M('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H
M92!S>7-T96TN(@IM<V=S='(@(B(*(DQE('!R;V=R86UM92!U=&EL:7/I('!O
M=7(@=FES=6%L:7-E<B!C92!T>7!E(&1E(&1O;F[I97,@*"5S*2!N)V$@<&%S
M(.ETZ2`B"B)T<F]U=NDN(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z-#@W"FUS9VED(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE
M('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(DQE(&-A<F%C=.AR92!D92!P
M<F]T96-T:6]N(&1O:70@ZG1R92!U;B!C87)A8W3H<F4@=6YI<75E+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S<*;7-G:60@(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S
M='(@(DQE<R!C]'3I<R!G875C:&4@970@9')O:70@<V5U;&5M96YT(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M.`IM<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(DQE
M(&/T=.D@9')O:70@<V5U;&5M96YT(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z-#<Y"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE
M('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(DQE('/I<&%R871E=7(@9&]I
M="#J=')E('5N(&-A<F%C=.AR92!U;FEQ=64N(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E
M<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B3&4@<V5R
M=F5U<B"KH"5SH+L@82#I=.D@<W5P<')I;>DN(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E
M<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(DQE('-E<G9E
M=7(@JZ`E<Z"[(&$@Z73I(&5N<F5G:7-T<NDN(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S
M="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B3&$@<F5Q=>IT
M92!D)V5N<F5G:7-T<F5M96YT('!O=7(@)7,@82#I=.D@9.EP;&%CZ64N(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT
M-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@*"5D
M*2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B3&$@;&EG;F4@9&5M86YDZ64@
M*"5D*2!N)V5X:7-T92!P87,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HQ-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F
M:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B3&4@9FEC:&EE
M<B!T96UP;W)A:7)E(*L@)7.@NR!N)V5X:7-T92!P87,N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S(Y.0IM<V=I9"`B5&AE('1E>'0@>6]U(&5N
M=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+B(*
M;7-G<W1R("),92!T97AT92!E;G1RZ2!N92!C;W)R97-P;VYD('!A<R!A=2!T
M97AT92!S=7(@;"?I8W)A;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED(")4:&4@=&]P(&%N9"!B
M;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R("),92!H875T(&5T(&QE(&)A<R!S
M975L96UE;G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G
M<W1R("),92!H875T('-E=6QE;65N="(*"B,Z(&9R86UE=V]R:R]$871A+T1A
M=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@
M<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@(B(*(DQE<R!D;VYN
MZ65S('3I;.EC:&%R9^EE<R!V97)S(&QE('-E<G9E=7(@;VYT(.ETZ2!P97)D
M=65S(&1E<'5I<R!L)^ET87!E("(*(G!RZ6/I9&5N=&4N("(*"B,Z(&9R86UE
M=V]R:R]$871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A;65W;W)K+T1A=&$O1&%T
M82]T<W8N<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@
M;F]T(&)E('-A=F5D+B(*;7-G<W1R("),92!F:6-H:65R(.EM:7,@;B=A('!A
M<R!P=2#J=')E(&5N<F5G:7-T<NDN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C0Y(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,3`*
M;7-G:60@(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R("),92!B;&]C(*N@=V5A=&AE<BYC;VV@NR!N)V5S="!P87,@
M9&ES<&]N:6)L92XB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T
M(&9O=6YD+B(*;7-G<W1R(")2Z7!E<G1O:7)E(&1E<R!T:.AM97,@JZ`E<Z"[
M(&YO;B!T<F]U=NDB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C$W.`IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*
M;7-G<W1R("));"!N)WD@82!P87,@9"=O<'1I;VYS(&1I<W!O;FEB;&5S(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z,S0X"FUS9VED
M(")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN
M;&EN92XB"FUS9W-T<B`B075C=6YE('!A<G1I92!N92!P975T(.IT<F4@869F
M:6-HZ64@96X@;&EG;F4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3,Y.`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA
M;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D
M("5S(&-H87)A8W1E<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E
M<RXB"FUS9W-T<B`B(@HB26P@>2`@82!T<F]P(&1E(&-A<F%C=.AR97,@9&%N
M<R!C92!C:&%M<"X@5F]U<R!E;B!A=F5Z(&5N='+I("5SH#L@:6P@96X@9F%U
M="`B"B)M;VEN<R!D92`E<RXB"@HC.B!S:6=N=7`N<&AP.C4S(&%D;6EN+W5S
M97(N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R
M;V)L96T@861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R
M(")5;B!P<F]B;.AM92!E<W0@87!P87)U(&QO<G,@9&4@;"=A:F]U="!D92"K
MH"5SH+N@.B`E<R(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@
M9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(B(*
M(E5N('!R;V)LZ&UE(&5S="!A<'!A<G4@;&]R<R!D92!L82!S=7!P<F5S<VEO
M;B!D97,@9&]N;NEE<R!D92!L)W5T:6QI<V%T975R("(*(JN@)7.@NZ`Z("(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S
M>7-T96TZ("(*;7-G<W1R(")5;B!P<F]B;.AM92!E<W0@87!P87)U(&QO<G,@
M9&4@;&$@<W5P<')E<W-I;VX@9&4@JZ`E<Z"[H#H@(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,34Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R
M;V)L96T@=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R(")5;B!P<F]B;.AM
M92!E<W0@87!P87)U(&QO<G,@9&4@;&$@;6ES92#@(&IO=7(@9&4@JZ`E<Z"[
MH#H@)7,B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,C<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H
M('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R
M("(B"B)5;B!P<F]B;.AM92!E<W0@87!P87)U(&QO<G,@9&4@;"=E;G9O:2!D
M=2!F:6-H:65RH#H@875C=6X@)7,@;B=A(.ETZ2`B"B)T<F%N<VUI<RXB"@HC
M.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F
M:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU
M;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@HB56YE
M(&5R<F5U<B!E<W0@<W5R=F5N=64@;&]R<R!D92!L)V5N=F]I(&1U(&9I8VAI
M97*@.B!L92`E<R#I=&%I="!P;'5S(&=R;W,@(@HB<75E(&QE(&UA>&EM=6T@
M875T;W)I<^D@*"5D(&]C=&5T<RDN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O
M0G)O=W-E<BYP:'`Z.3,T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E
M('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W
M87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N(@IM<V=S='(@(B(*(E5N92!E
M<G)E=7(@97-T('-U<G9E;G5E(&QO<G,@9&4@;"=E;G9O:2!D=2!F:6-H:65R
MH#H@;&4@)7,@82#I=.D@=')A;G-M:7,@(@HB<&%R=&EE;&QE;65N="XB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A
M9V4@<&%R="(*;7-G<W1R("(B"B)5;F4@97)R975R(',G97-T('!R;V1U:71E
M(&QO<G,@9&4@;"=A9F9I8VAA9V4@9&4@8V5T=&4@<&%R=&4@9'4@;65S<V%G
M92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS
M.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A
M8W0@9&%T82XB"FUS9W-T<B`B(@HB56YE(&5R<F5U<B!S)V5S="!P<F]D=6ET
M92!L;W)S(&1E(&PG:6UP;W)T871I;VX@9&5S(&1O;F[I97,@9&4@8V4@8V]N
M=&%C="XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+VEM8RYP:'`Z,S$*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A
M<B!D871A+B(*;7-G<W1R("(B"B)5;F4@97)R975R(',G97-T('!R;V1U:71E
M(&QO<G,@9&4@;"=I;7!O<G1A=&EO;B!D92!C971T92!C87)T92!I0V%L96YD
M87(N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HX,@IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN
M(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM
M<V=S='(@(B(*(DEL('D@879A:70@=6YE(&5R<F5U<B!D86YS(&QE(&9O<FUU
M;&%I<F4@9&4@8V]N9FEG=7)A=&EO;BX@4&5U="WJ=')E(&%V97HM(@HB=F]U
M<R!L86ES<^D@=6X@8VAA;7`@<F5Q=6ES('9I9&4N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*
M(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@
M861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA
M=&5R+B(*;7-G<W1R("(B"B)5;F4@97)R975R(',G97-T('!R;V1U:71E(&QO
M<G,@9&4@;"=E>.EC=71I;VX@9&4@8V5T=&4@9F]N8W1I;VX@9'4@8V%R;F5T
M("(*(F0G861R97-S92X@4U90(&5S<V%Y97(@X"!N;W5V96%U('!L=7,@=&%R
M9"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8T,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG
M('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N
M(@IM<V=S='(@(B(*(DEL('D@82!E=2!U;F4@97)R975R(&QO<G,@9&4@;&$@
M;6ES92#@(&IO=7(@9&5S(&EN9F]R;6%T:6]N<R!S=7(@;&4@(@HB8V]N=&%C
M="X@(%9E=6EL;&5Z(&5S<V%Y97(@X"!N;W5V96%U+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(R"FUS9VED("(B"B)4
M:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L
M:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B));"!Y
M(&$@974@=6YE(&5R<F5U<B!L;W)S(&1E(&QA(&UI<V4@X"!J;W5R(&1E(&QA
M(&QI<W1E(&1E(&1I<W1R:6)U=&EO;BX@("(*(E9E=6EL;&5Z(&5S<V%Y97(@
M9&4@;F]U=F5A=2XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HQ-#@*;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@
M<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(DQE('!RZ7-E;G0@
M<V5R=F5U<B!)34%0(&YE('-U<'!O<G1E('!A<R!L92!P87)T86=E(&1E(&1O
M<W-I97)S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L
M:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(L=A(&YE('-E;6)L92!P87,@ZG1R
M92!U;F4@87)C:&EV92!205(@=F%L:61E+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@
M87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(L=A(&YE
M('-E;6)L92!P87,@ZG1R92!U;B!F:6-H:65R(%I)4"!V86QI9&4N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R-`IM<V=I9"`B5&AI<R!D;V5S
M(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@
M(L=A(&YE('-E;6)L92!P87,@ZG1R92!U;B!N=6WI<F\@9&4@8V%R=&4@=F%L
M:61E+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO
M+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!
M4$DB"FUS9W-T<B`B(@HB0V4@<&EL;W1E('!E<FUE="!L)V5N=F]I(&1E(&UE
M<W-A9V5S(.`@=')A=F5R<R!L82!P87-S97)E;&QE($-L:6-K871E;&P@(@HB
M*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@96X@=71I;&ES86YT(&PG05!)($A4
M5%`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S
M-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S
M<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@(@HB
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*(D-E('!I
M;&]T92!P97)M970@;"=E;G9O:2!D92!M97-S86=E<R!V:6$@;&$@<&%S<V5R
M96QL92!724X@*&AT='`Z+R]W:6YP;&,N(@HB8V]M*2!E;B!U=&EL:7-A;G0@
M;"=!4$D@2%144"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3$U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT
M='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%14
M4"!!4$DB"FUS9W-T<B`B(@HB0V4@<&EL;W1E('!E<FUE="!L)V5N=F]I(&1E
M(&UE<W-A9V5S(.`@=')A=F5R<R!L82!P87-S97)E;&QE('-M<S)E;6%I;"`B
M"B(H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&5N('5T:6QI<V%N="!L)T%022!(
M5%10(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?
M<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE
M($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@
M270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE
M($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*(D-E('!I
M;&]T92!P97)M970@;"=E;G9O:2!D92!M97-S86=E<R!P87(@4TU44"#@('1R
M879E<G,@;&$@<&%S<V5R96QL92`B"B)6;V1A9F]N92!)=&%L:64L('-E=6QE
M;65N="!A=7@@;G5MZ7)O<R!6;V1A9F]N92X@0V5L82!NZ6-E<W-I=&4@=6X@
M8V]M<'1E(&1E("(*(F-O=7)R:65L(%9O9&%F;VYE($ET86QI92`H:'1T<#HO
M+W=W=RXQ.3`N:70I+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDW
M-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#4T"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$P.#,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Q
M,@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3<Y(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$R-3,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3,P,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,SDU"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$U-30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3@S-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.34U(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(P,#(*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C`R-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#<U"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(Q.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#`U(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(T-#<*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C8S-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`W"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,38@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S(Y-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#`R(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,3`*;7-G:60@(E1H:7,@9FEE;&0@
M:7,@<F5Q=6ER960N(@IM<V=S='(@(D-E(&-H86UP(&5S="!O8FQI9V%T;VER
M92XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#8R"FUS9VED(")4
M:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@
M(D-E(&-H86UP(&YE(&1O:70@8V]N=&5N:7(@<75E(&1E<R!E;G1I97)S+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3,*;7-G:60@(E1H:7,@
M9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN
M(@IM<V=S='(@(D-E(&-H86UP(&YE(&1O:70@8V]N=&5N:7(@<75E(&1E<R!N
M;VUB<F5S(&5T(&QE<R!D975X+7!O:6YT<RXB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,#DQ"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O
M;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R(")#92!C:&%M<"!N92!D;VET
M(&-O;G1E;FER('%U92!D97,@=F%L975R<R!O8W1A;&5S+B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,C`*;7-G:60@(E1H:7,@9FEE;&0@;75S
M="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G
M97)S(@IM<V=S='(@(B(*(D-E(&-H86UP(&1O:70@8V]N=&5N:7(@=6YE(&QI
M<W1E(&0G96YT:65R<R!SZ7!A<NES('!A<B!D97,@=FER9W5L97,@;W4@9&5S
M("(*(F5S<&%C97,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY.#8*
M;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS
M9W-T<B`B0V4@8VAA;7`@9&]I="#J=')E('5N(&YO;6)R92!V86QI9&4N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-0IM<V=I9"`B(@HB5&AI
M<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@
M2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R
M("(B"B)#92!C:&%M<"!D;VET(&-O;G1E;FER('5N(&-O9&4@9&4@8V]U;&5U
M<B!A=2!F;W)M870@4D="(&AE>&%DZ6-I;6%L+"!P87(@(@HB97AE;7!L92`G
M(S$R,S1A9B<N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z-34X"FUS
M9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N(@IM
M<V=S='(@(D-E(&9O<FUU;&%I<F4@82!DZ6K@(.ETZ2!T<F%I=.DN(@H*(SH@
M=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B0R=E<W0@)7,N(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HT-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@
M=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@
M=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@
M1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I
M<VET("5S(@IM<V=S='(@(B(*(D-E8VD@97-T('5N(&]B:F5T($MO;&%B($=R
M;W5P=V%R92X@4&]U<B!V;VER(&-E="!O8FIE="P@=F]U<R!D979R97H@879O
M:7(@=6X@(@HB8VQI96YT(&1E(&-O=7)R:65L('%U:2!C;VUP<F5N9"!L92!F
M;W)M870@2V]L86(@1W)O=7!W87)E+B!0;W5R('5N92!L:7-T92!D92`B"B)C
M97,@8VQI96YT<R!D92!C;W5R<FEE;"P@=FES:71E>B`E<R(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T
M97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B(@HB
M0V4@;65S<V%G92!A(.ETZ2#I8W)I="!D86YS('5N(&-O9&4@9&4@8V%R86-T
MZ')E<R`H)7,I(&%U=')E('%U92!L92!V]'1R92XB"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S
M="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(D-E(&YO;6)R92!D;VET(.IT
M<F4@<W5PZ7)I975R(.`@=6XN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E<B!C86XG="!U
M;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`B0V4@<V5R
M=F5U<B!N92!P975T('!A<R!DZ6-O;7!R97-S97(@;&5S(&9I8VAI97)S(%I)
M4"!E="!G>FEP+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R
M>2YP:'`Z,3@Y"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A
M8W1I=F%T960N(@IM<V=S='(@(D-E('-Y<W3H;64@97-T('!RZ7-E;G1E;65N
M="!DZ7-A8W1I=NDN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS
M9W-T<B`B0V5T=&4@=F%L975R(&1O:70@ZG1R92!U;B!N;VUB<F4N(@H*(SH@
M<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM<V=I9"`B5&AI
M<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O
M=R(*;7-G<W1R(")#971T92!F96[J=')E(&1O:70@ZG1R92!A<'!E;.EE(&1E
M<'5I<R!U;F4@9F5NZG1R92!D97,@;W!T:6]N<R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V"FUS9VED(")4:'5N9&5R(@IM
M<V=S='(@(E1O;FYE<G)E(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(S-@IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R(")4:6-K971S(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0R,B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR-34*;7-G:60@(E1I;64B"FUS9W-T<B`B2&5U<F4B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@X"FUS9VED(")4:6UE(%1R86-K
M:6YG(@IM<V=S='(@(E-U:79I(&AO<F%I<F4B"@HC.B!L:6(O0FQO8VLO=&EM
M92YP:'`Z,3<*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(D9O<FUA="!D
M)VAE=7)E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4R.`IM<V=I
M9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B4^EL96-T:6]N(&1E(&PG:&5U
M<F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4:6UO<BU,97-T92(*;7-G<W1R
M(")4:6UO<B!O<FEE;G1A;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HR,CD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G
M:60@(E1I=&QE(@IM<V=S='(@(E1I=')E(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT
M:7`I.B(*;7-G<W1R(")4:71R92`H:6YF;V)U;&QE*:`Z(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B
M"FUS9W-T<B`BP"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HV-30*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I=&5M
M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C
M*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*(E!O=7(@<^EL
M96-T:6]N;F5R('!L=7-I975R<R!I=&5M<R#@(&QA(&9O:7,L(&UA:6YT96YE
M>B!E;F9O;F/I(&QE(&)O=71O;B`B"B*KH$-T<FR@NR`H4$,I(&]U(*N@0V]M
M;6%N9&6@NR`H36%C*2!E;B!C;&EQ=6%N="XB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S`P"FUS9VED(")4;V1A>2(*;7-G<W1R(")!=6IO
M=7)D)VAU:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R(")6
M;VER(&QA('-O=7)C92!(5$U,(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&]G
M;R(*;7-G<W1R(")4;V=O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA
M=2(*;7-G<W1R(")4;VME;&%U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,P,@IM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B1&5M86EN(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,CD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B5&]N9V$B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VMO;&%B+G!H<#HQ,#0*;7-G:60@(E1O
M;R!M86YY(&EN=F%L:60@;&]G:6YS(&1U<FEN9R!T:&4@;&%S="!M:6YU=&5S
M+B(*;7-G<W1R(")4<F]P(&1E(&-O;FYE>&EO;G,@:6YF<G5C='5E=7-E<R!D
M86YS(&QE<R!D97)N:>AR97,@;6EN=71E<RXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S<*;7-G:60@(E1O<"(*
M;7-G<W1R(")(875T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY,PIM<V=I9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R
M(")#861R92!D=2!H875T("A?=&]P*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV,PIM<V=I9"`B5')A;G-L871I;VYS(@IM<V=S='(@(E1R861U8W1I
M;VYS(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5')I;FED860@86YD(%1O8F%G
M;R(*;7-G<W1R(")4<FEN:73I+65T+51O8F%G;R(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$W.#<*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T
M<B`B5G)A:2!O=2!F875X(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T<B`B36$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$P"FUS9VED(")4=6YI<VEA(@IM<V=S='(@(E1U;FES:64B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T<B`B5'5R<75I92(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")4=7)K:7-H("A)
M4T\M.#@U.2TY*2(*;7-G<W1R(")4=7)C("A)4T\M.#@U.2TY*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3`*;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R(")4=7)K;>EN
M:7-T86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S
M($ES;&%N9',B"FUS9W-T<B`BSFQE<R!4=7)Q=65S(&5T($-A[W%U97,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B5'5V86QU(@H*
M(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R
M(&-H;VEC93H@(@IM<V=S='(@(D5N=')E>B!V;W1R92!C:&]I>*`Z("(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3@*;7-G:60@(E4N5BX@
M:6YD97@Z("(*;7-G<W1R("));F1I8V4@55:@.B`B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A
M;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@
M(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*
M;7-G<W1R(")54DP@<&]U<B!V;W1R92!R87!P;W)T(&1E(&QI=G)A:7-O;B!D
M=2!S8W)I<'0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.CDW"FUS9VED(")54DPZ(@IM<V=S='(@(E523#HB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$R"FUS9VED(")59V%N9&$B"FUS9W-T<B`B3W5G86YD82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3(*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B56MR86EN92(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0Q.0IM<V=I9"`B56YA8FQE
M('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("));7!O<W-I8FQE
M(&0G871T96EN9')E(&QE('+I<&5R=&]I<F4@5D93+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B56YA8FQE('1O(&%D
M9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"XB"FUS
M9W-T<B`B26UP;W-S:6)L92!D)V%J;W5T97(@9&5S(&EN9F]R;6%T:6]N<R!C
M;VUP;.EM96YT86ER97,@X"!L)VEN<V-R:7!T:6]N+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,SDS"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R("));7!O<W-I8FQE(&1E(&UO9&EF:65R(&QE<R!P97)M:7-S
M:6]N<R!P;W5R(&QE(&9I8VAI97(@5D93(*N@)7.@NRXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HS.3(@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA
M;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("))
M;7!O<W-I8FQE(&1E(&UO9&EF:65R(&QE<R!P97)M:7-S:6]N<R!P;W5R(&QE
M(&9I8VAI97(@5D93("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z-S@V"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N
M9V4@=&\@)7,N(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@8VAA;F=E<B!P;W5R
M("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C,W"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@
M7"(E<UPB+B(*;7-G<W1R("));7!O<W-I8FQE(&1E(';I<FEF:65R(&QA('1A
M:6QL92!D=2!F:6-H:65R(&1E(*N@)7.@NRXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HV.34@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ
M,#(X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HX-3`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O
M9B!<(B5S+R5S7"(N(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@=NER:69I97(@
M;&$@=&%I;&QE(&1U(&9I8VAI97(@9&4@JR`E<R\E<R"[+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HT,SD*;7-G:60@(E5N86)L92!T;R!C
M;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(D-O;FYE>&EO;B!I;7!O
M<W-I8FQE(&%U('-E<G9E=7(@4U%,+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z.#<P"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-3
M3"XB"FUS9W-T<B`B0V]N;F5X:6]N(&EM<&]S<VEB;&4@96X@4U-,(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C,R(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C(S-PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,C`T(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#D*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(Q-PIM<V=I9"`B
M56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(DEM<&]S<VEB;&4@
M9&4@8V]P:65R('5N(&9I8VAI97(@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,S<P"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DEM<&]S
M<VEB;&4@9&4@8W+I97(@=6X@<NEP97)T;VER92!61E,@JZ`E<Z"[+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,V,2!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,C4X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HR-C0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B26UP;W-S:6)L92!D92!C<NEE<B!U;B!RZ7!E<G1O
M:7)E(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3(T
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R("))
M;7!O<W-I8FQE(&1E(&-RZ65R(&QE(&9I8VAI97(@5D93+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@
M(DEM<&]S<VEB;&4@9&4@8W+I97(@;&4@<NEP97)T;VER92!61E,@JZ`E<Z"[
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(W,@IM<V=I9"`B
M56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T<B`B26UP
M;W-S:6)L92!D92!C<NEE<B!U;B!F:6-H:65R(%9&4R!V:61E+B`B"@HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O=&%R+G!H<#HW-@HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-SD*;7-G:60@(E5N
M86)L92!T;R!D96-O;7!R97-S(&1A=&$N(@IM<V=S='(@(D]U=F5R='5R92!I
M;7!O<W-I8FQE(&1E(&PG87)C:&EV92!C;VUP<F5S<^EE+B`B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(R."!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C,P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S
M='(@(E-U<'!R97-S:6]N(&EM<&]S<VEB;&4@9&4@JZ`E<Z"[+"!L92!D;W-S
M:65R(&XG97-T('!A<R!V:61E+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S@@
M861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM<V=S='(@(E-U<'!R
M97-S:6]N(&EM<&]S<VEB;&4@9&4@JZ`E<Z"[H#H@)7,N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,X(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z,SDU"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,3$@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y
M(&ES(&YO="!E;7!T>2(*;7-G<W1R(")3=7!P<F5S<VEO;B!I;7!O<W-I8FQE
M(&1E("5S+"!L92!D;W-S:65R(&XG97-T('!A<R!V:61E(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,U-B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,S8P"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(E-U<'!R97-S:6]N
M('+I8W5R<VEV92!D=2!D;W-S:65R(%9&4R!I;7!O<W-I8FQE+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,T-"!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HS,S4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T,PHC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4R"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(E-U<'!R97-S:6]N
M(&1U('+I<&5R=&]I<F4@5D93(&EM<&]S<VEB;&4N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HT,C`@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HT,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B26UP;W-S:6)L92!D92!S=7!P
M<FEM97(@;&4@<NEP97)T;VER92!61E.@.B`E<RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C(Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B4W5P<')E
M<W-I;VX@:6UP;W-S:6)L92!D=2!F:6-H:65R(%9&4R"KH"5SH+LN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S$P(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z,CDQ"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HQ-C<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X,`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@W(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HS.3$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C,Y.0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB
M"FUS9W-T<B`B4W5P<')E<W-I;VX@:6UP;W-S:6)L92!D=2!F:6-H:65R(%9&
M4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(T.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@7"(E
M<UPB+B(*;7-G<W1R(")3=7!P<F5S<VEO;B!I;7!O<W-I8FQE(&1U('+I<&5R
M=&]I<F4@5D93(*N@)7.@NRXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C0P.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(E-U<'!R97-S:6]N(%9&
M4R!RZ6-U<G-I=F4@:6UP;W-S:6)L9:`Z("5S+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z.#,T"FUS9VED(")5;F%B;&4@=&\@9&5T97)M:6YE
M(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R("));7!O<W-I8FQE(&1E(&3I
M=&5R;6EN97(@;&4@9&]S<VEE<B!C;W5R86YT+B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C`T"FUS9VED(")5;F%B;&4@=&\@97AT
M<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM<V=S='(@(DEM<&]S<VEB;&4@
M9"=E>'1R86ER92!L97,@9.ET86EL<R!D=2!C97)T:69I8V%T(@H*(SH@9G)A
M;65W;W)K+TYE=%])35-0+TE-4U`N<&AP.C0S-R!F<F%M97=O<FLO3F5T7TE-
M4U`O24U34"]!=71H+G!H<#HQ,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(DEM
M<&]S<VEB;&4@9&4@8VAA<F=E<B!L82!DZ69I;FET:6]N(&1E("5S+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P,R!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HR,#@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C$W-"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3<Y
M"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB"FUS9W-T<B`B26UP
M;W-S:6)L92!D92!DZ7!L86-E<B!L92!F:6-H:65R(%9&4RXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.CDS(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z,3`V"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-C4R(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("))
M;7!O<W-I8FQE(&0G;W5V<FER(&QE(&9I8VAI97(@5D93(*N@)7.@NRXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR.#0@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C$S.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,30Q"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL
M92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B26UP;W-S:6)L92!D)V]U=G)I<B!U
M;B!F:6-H:65R(%9&4R!E;B#I8W)I='5R92XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HX,R!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ
M,S<*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<V"FUS9VED
M(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB"FUS9W-T<B`B26UP;W-S:6)L
M92!D)V]U=G)I<B!U;B!F:6-H:65R(%9&4RXB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C0U"FUS9VED(")5;F%B;&4@=&\@;W!E
M;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@(D]U=F5R='5R92!I;7!O
M<W-I8FQE(&1E(&PG87)C:&EV92!C;VUP<F5S<^EE+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HX-38*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F
M:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(DEM<&]S<VEB;&4@
M9&4@;&ER92!L92!F:6-H:65R(%9&4R`HZ6-H96,@9&4@9FEL97-I>F4H*2DN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@X-PIM<V=I9"`B56YA8FQE
M('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2XB"FUS
M9W-T<B`B26UP;W-S:6)L92!D92!L:7)E(&QE(&9I8VAI97(@5D93("CI8VAE
M8R!D92!G971&:6QE4VEZ92@I*2XB"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA
M;F1L97(O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*;7-G:60@(E5N86)L
M92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R("));7!O<W-I8FQE(&1E(&QI<F4@
M;&4@9FEC:&EE<J`Z("(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C8W-@IM<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T
M;W)Y+B(*;7-G<W1R("),96-T=7)E(&1U('+I<&5R=&]I<F4@<F%C:6YE(%9&
M4R!I;7!O<W-I8FQE+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,3$P.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S
M('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS
M9W-T<B`B26UP;W-S:6)L92!D92!R96YO;6UE<B`E<R!E;B`E<Z`Z(&QE(&1O
M<W-I97(@8VEB;&4@97AI<W1E(&3I:N`B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,S`Q"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&
M4R!D:7)E8W1O<GDN(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@<F5N;VUM97(@
M;&4@<NEP97)T;VER92!61E,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HS,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M
M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B26UP;W-S:6)L92!D92!R
M96YO;6UE<B!L92!RZ7!E<G1O:7)E(%9&4Z`Z("5S+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z,C<Q(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,S0X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("));7!O<W-I8FQE(&1E(')E;F]M
M;65R(&QE(&9I8VAI97(@5D93(*N@)7.@NRXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HV,3<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C(R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE("5S+R5S+B(*;7-G<W1R("));7!O<W-I8FQE(&1E(')E;F]M;65R
M(&QE(&9I8VAI97(@5D93("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z,S(V(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,3,*
M(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0U,B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,CDS"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HS,#D*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93
M(&9I;&4N(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@<F5N;VUM97(@;&4@9FEC
M:&EE<B!61E,N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+VUK:7-O9G,N<&AP.C4P"FUS9VED(")5;F%B;&4@=&\@<G5N("=M:VES
M;V9S)RXB"FUS9W-T<B`B26UP;W-S:6)L92!D)V5XZ6-U=&5R("=M:VES;V9S
M)RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP
M.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U
M;65N="(*;7-G<W1R("));7!O<W-I8FQE(&1E('1R861U:7)E(&-E(&1O8W5M
M96YT(%=O<F0N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-30@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-3<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T
M<B`B26UP;W-S:6)L92!D)^EC<FER92!L92!F:6-H:65R(%9&4R"KH"5SH+LN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3@V"FUS9VED(")5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G
M<W1R("));7!O<W-I8FQE(&0GZ6-R:7)E(&QE<R!D;VYNZ65S(&1U(&9I8VAI
M97(@5D93("AC;W!Y*"D@:6UP;W-S:6)L92DN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,C@X(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HQ-#8*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$U
M,0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S
M='(@(DEM<&]S<VEB;&4@9"?I8W)I<F4@;&5S(&1O;F[I97,@9'4@9FEC:&EE
M<B!61E,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@V,@IM<V=I9"`B
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E
M9&5D+B(*;7-G<W1R("));7!O<W-I8FQE(&0GZ6-R:7)E(&QE(&9I8VAI97(@
M5D93+"!L92!Q=6]T82!S97)A:70@9.EP87-SZ2XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P"FUS9VED(")5;F1E<FQI
M;F4B"FUS9W-T<B`B4V]U;&EG;F5R(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N
M9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(D%N;G5L97(@
M;&5S(&-H86YG96UE;G1S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S="!A8W1I
M;VXB"FUS9W-T<B`B06YN=6QE('9O=')E(&1E<FYIZ')E(&%C=&EO;B(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,0HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#@*;7-G:60@
M(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO
M;CH@(@IM<V=S='(@(E+I<&]N<V4@:6YA='1E;F1U92!D=2!S97)V975R(&QO
M<G,@9&4@;&$@8V]N;F5X:6]NH#H@(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,C$W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,S.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS-S8*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S@R"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R
M;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B4NEP;VYS92!I;F%T=&5N9'5E(&1U
M('-E<G9E=7(@X*`Z("(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E
M9V]R>4UA;F%G97(N<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C8Q"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(DAO
M<G,@8V%TZ6=O<FEE(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.38*;7-G
M:60@(E5N:6-O9&4@*%541BTX*2(*;7-G<W1R(")5;FEC;V1E("A55$8M."DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS
M9W-T<B`BR6UI<F%T<R!!<F%B97,@56YI<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I
M9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T<B`B4F]Y875M92U5;FDB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S='(@(LET871S
M+55N:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S($UI
M;F]R($]U=&QY:6YG($ES;&%N9',B"FUS9W-T<B`BSFQE<R!E>'3I<FEE=7)E
M<R!D97,@R71A=',M56YI<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HV,B!L:6(O0FQO8VLO;65T87(N<&AP.C<X"FUS9VED(")5;FET<R(*
M;7-G<W1R(")5;FETZ7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,CD@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#,P"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-3@*;7-G:60@
M(E5N:VYO=VXB"FUS9W-T<B`B26YC;VYN=2(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W
M;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*;7-G<W1R(")A<&EM<V=I
M9"!I;F-O;FYU("A!4$D@365S<V%G92!)1"DN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN
M;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@(F-L
M:6US9VED(&EN8V]N;G4@*$-L:65N="!-97-S86=E($E$*2XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30W"FUS9VED(")5;FMN;W=N(&QO
M8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(")%;7!L86-E;65N="!SZ6QE8W1I
M;VYNZ2!I;F-O;FYU+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O
M<B!P87-S=V]R9"XB"FUS9W-T<B`B3F]M(&0G=71I;&ES871E=7(@;W4@;6]T
M(&1E('!A<W-E(&EN8V]N;G4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X"FUS9VED(")5;FQI;FL@=&AE
M(&-U<G)E;G0@96QE;65N="(*;7-G<W1R(")$Z6QI97(@;"?I;.EM96YT(&-O
M=7)A;G0B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,P
M,@IM<V=I9"`B56YN86UE9"(*;7-G<W1R(")386YS(&YO;2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*
M(E5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO
M4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS
M+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL
M82YO<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP
M="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@HB3&5S('-C
M<FEP=',@;F]N+7!R:79I;.EG:>ES(&YE('!E=79E;G0@86-CZ61E<B!A=7@@
M9F]N8W1I;VYS(&-O=7!E<B]C;W!I97(O(@HB8V]L;&5R('!O=7(@9&5S(')A
M:7-O;G,@9&4@<^EC=7)I=.DN($%P<'5Y97H@<W5R($]+('!O=7(@=F]I<B!U
M;F4@;F]T92`B"B)T96-H;FEQ=64@<W5R(&UO>FEL;&$N;W)G('%U:2!V;W5S
M(&5X<&QI<75E<F$@8V]M;65N="!A=71O<FES97(@=6X@<V-R:7!T(.`@(@HB
M=71I;&ES97(@;&4@<')E<W-E+7!A<&EE<G,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R"FUS9VED(")5;G-E
M="!C;VQO<B(*;7-G<W1R(")296UE='1R92!L82!C;W5L975R(.`@>NER;R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@W(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3(W"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z.3,S"FUS9VED(")5;G-U<'!O<G1E9"!%
M>'1E;G-I;VXB"FUS9W-T<B`B17AT96YS:6]N(&YO;B!P<FES92!E;B!C;VUP
M=&4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$Y-R!T96UP
M;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D871E(@IM
M<V=S='(@(DUO9&EF:65R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHR.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS
M9W-T<B`B36]D:69I97(@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C<V"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R(")-;V1I
M9FEE<B!L)W5T:6QI<V%T975R(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-#0@
M861M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E9&ET
M+G!H<#HR,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S7"(N
M(@IM<V=S='(@(DUI<V4@X"!J;W5R(&1E(*N@)7.@NRXB"@HC.B!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HX,PIM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L
M971E9"XB"FUS9W-T<B`B3&4@<V-R:7!T(&1E(&UI<V4@X"!J;W5R(&5S="!S
M=7!P<FEMZ2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S@@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y.`IM<V=I9"`B57!L
M;V%D(@IM<V=S='(@(D-H87)G97(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3@V"FUS9VED(")5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@
M9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T<B`B(@HB5&]U<R!L97,@9FEC
M:&EE<G,@9&4@8V]N9FEG=7)A=&EO;B!D97,@87!P;&EC871I;VYS(&]N="#I
M=.D@96YV;WGI<R!S=7(@;&4@(@HB<V5R=F5U<BXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(P"FUS9VED
M(")5<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@(DQE='1R97,@;&%T:6YE
M<R!M86IU<V-U;&5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B57!P97(@<F]M86X@;G5M
M8F5R<R(*;7-G<W1R(").;VUB<F5S(')O;6%I;G,@;6%J=7-C=6QE<R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B57)U9W5A>2(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP
M.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT.B`E<R(*;7-G
M<W1R(")%;7!L;WGI(&%C='5E;&QE;65N=*`Z("5S(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S
M92!34TPB"FUS9W-T<B`B571I;&ES97(@4U-,(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$R-PIM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@
M9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B(@HB571I;&ES
M97(@<VD@;&4@;F]M(&0G=71I;&ES871E=7(O;6]T(&1E('!A<W-E(&5S="!D
M:69FZ7)E;G0@9'4@<V5R=F5U<B!)35-0+B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O961I="YI;F,Z,C$*;7-G:60@(E5S97(B"FUS9W-T<B`B571I
M;&ES871E=7(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN
M<&AP.C<W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A
M=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B3"=U=&EL:7-A=&5U<B`E<R!N
M)V$@<&%S(&PG875T;W)I<V%T:6]N('!O=7(@)7,N(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,C`S"FUS9VED(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(D%D;6EN:7-T<F%T:6]N(&1E<R!U=&EL:7-A=&5U<G,B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C(T-0IM<V=I9"`B57-E<B!/<'1I;VYS
M(@IM<V=S='(@(E!RZ6;I<F5N8V5S('!E<G-O;FYE;&QE<R(*"B,Z('-I9VYU
M<"YP:'`Z-C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(D5N
M<F5G:7-T<F5M96YT(&1E<R!U=&EL:7-A=&5U<G,B"@HC.B!S:6=N=7`N<&AP
M.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE
M9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R("),)V5N<F5G:7-T<F5M96YT(&0G
M=71I;&ES871E=7(@97-T(&3I<V%C=&EVZ2!S=7(@8V4@<WES=.AM92XB"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#8Y"FUS9VED(")5<V5R(&%C8V]U
M;G0@;F]T(&9O=6YD(@IM<V=S='(@(D-O;7!T92!U=&EL:7-A=&5U<B!N;VX@
M=')O=7;I(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$W.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O
M;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HQ-3`@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z,S,*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,B!T96UP;&%T
M97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B
M"FUS9W-T<B`B3F]M(&0G=71I;&ES871E=7(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E5S
M97)N86UE(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B3&4@;F]M
M(&1E(&-O;FYE>&EO;B"KH"5SH+L@97AI<W1E(&3I:N`N(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@W"FUS9VED(")5<V5R;F%M93HB"FUS
M9W-T<B`B3F]M(&0G=71I;&ES871E=7*@.B(*"B,Z('1E;7!L871E<R]L;V=I
M;B]M;V)I;&4N:6YC.C@*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B3F]M
M(&0G=71I;&ES871E=7*@.B`B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L
M:7-T+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R
M(")5=&EL:7-A=&5U<G,@9.EF:6YI<Z`Z(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I
M9"`B57IB96MI<W1A;B(*;7-G<W1R(")/=7IBZ6MI<W1A;B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C$W,"!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HR-C(*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI
M<W0N(@IM<V=S='(@(E+I<&5R=&]I<F4@5D93(&EN97AI<W1A;G0N(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$R,`IM<V=I9"`B5F%C871I;VXB
M"FUS9W-T<B`B06)S96YC97,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HX-C,*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B
M"FUS9W-T<B`B3&5S(&5M<&QA8V5M96YT<R!V86QI9&5S('1R;W5VZ7,@:6YC
M;'5E;G2@.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8S.0IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B5F%L:61I=.DB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M-34*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@
M(E9A;&5U<B!E;B!M:6YU=&5S(.`@<&%R=&ER(&1E(&UA:6YT96YA;G0N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#4S(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Q-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@
M;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@(E9A;&5U
M<B!S=7#I<FEE=7)E(.`@;&$@;&]N9W5E=7(@;6%X:6UA;&4@9&4@)7,N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T,2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C8S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S
M,3,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDP-PHC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED(")686QU97,B
M"FUS9W-T<B`B5F%L975R<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q,#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X,PIM<V=I9"`B5F%L
M=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(E9A;&5U<G,@X"!SZ6QE8W1I
M;VYN97(@9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")686YU871U(@IM<V=S
M='(@(E9A;G5A='4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C,S"FUS9VED(")687)I86)L92(*;7-G<W1R(")687)I86)L92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R(")6Z6[I>G5E;&$B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I
M9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V
M92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(LEC:&5C(&1E(&QA(';I
M<FEF:6-A=&EO;B`F;61A<V@[(&-E(&UE<W-A9V4@82!P975T+>IT<F4@Z73I
M(&9A;'-I9FGI+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-S`Q"FUS9VED(")697)S:6]N(@IM<V=S='(@(E9E<G-I;VXB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(X"FUS9VED(")697)S:6]N($-O
M;G1R;VPB"FUS9W-T<B`B0V]N='+T;&4@9&4@=F5R<VEO;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G
M:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(D%L:6=N96UE;G0@=F5R=&EC
M86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@(E)E;7!L:7-S
M86=E('9E<G1I8V%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(E9E<G1I
M8V%LH#HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HW,@IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(E1RZ',@:&%U=&4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$V"FUS9VED(")6:65T($YA;2(*;7-G<W1R(")6:65T;F%M
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3<*;7-G:60@(E9I971N86UE
M<V4@*%9)4T-)22DB"FUS9W-T<B`B5FGJ="UN86UI96X@*%9)4T-)22DB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HY-CD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R(")6;VER("5S(@H*(SH@
M;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA
M;"!W96(@<&%G92(*;7-G<W1R(")6;VER('5N92!P86=E('=E8B!E>'1E<FYE
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#(X"B,L
M('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B5F]I<B!C
M;VUM92`E<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S
M+"!"<FET:7-H(@IM<V=S='(@(LYL97,@5FEE<F=E<R!B<FET86YN:7%U97,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@52Y3+B(*
M;7-G<W1R("+.;&5S(%9I97)G97,@9&5S(,ET871S+55N:7,B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(Q-@IM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R
M(")6:7-I8FEL:73I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(U,@IM<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(E9I<VEB:6QI=.F@
M.B`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S
M;71P+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS
M9W-T<B`B5F]D869O;F4@271A;'D@=FEA(%--5%`B"@HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP
M.C,V"FUS9VED(")705).(@IM<V=S='(@(DY/5$E#12(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)
M3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R
M(")!5%1%3E1)3TXA(2$@(%-54%!224U%4B!,12!30U))4%0@34%.545,3$5-
M14Y4($1%("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HQ,S,*;7-G:60@(E=)3B!V:6$@2%144"(*;7-G<W1R(")724X@=FEA
M($A45%`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")786QL:7,@86YD($9U='5N
M82(*;7-G<W1R(")786QL:7,@970@1G5T=6YA(@H*(SH@9G)A;65W;W)K+TYO
M=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR
M.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,C<@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@S"FUS9VED(")787)N:6YG(@IM<V=S
M='(@(D%T=&5N=&EO;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(DUE(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O
M<F5C87-T(@IM<V=S='(@(E!RZ79I<VEO;G,@;>ETZ6\B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#$V"FUS9VED(")796%T:&5R(&1A=&$@
M<')O=FED960@8GDB"FUS9W-T<B`B1&]N;NEE<R!MZ73I;R!F;W5R;FEE<R!P
M87(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.#D*;7-G:60@(E=E
M871H97(N8V]M(@IM<V=S='(@(E=E871H97(N8V]M(@H*(SH@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R(")796(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Y"FUS9VED(")796(@4VET92(*
M;7-G<W1R(")3:71E('=E8B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-
M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R(")#:&%Q
M=64@<V5M86EN92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X
M"FUS9VED(")796QC;VUE(@IM<V=S='(@(D)I96YV96YU92(*"B,Z('1E;7!L
M871E<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHU-PHC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM
M<V=S='(@(D)I96YV96YU92#@("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO
M8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H
M<"UF;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM<V=S='(@(D)I96YV96YU
M92P@)7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y.`IM<V=I9"`B5V5S
M=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B3V-C:61E;G1A;"`H25-/+3@X
M-3DM,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y.0IM<V=I9"`B5V5S
M=&5R;B`H25-/+3@X-3DM,34I(@IM<V=S='(@(D]C8VED96YT86P@*$E33RTX
M.#4Y+3$U*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R82(*
M;7-G<W1R(")386AA<F$@3V-C:61E;G1A;"(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A
M=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B
M475E;&QE(&%P<&QI8V%T:6]N("5S(&1O:70M:6P@<'+I<V5N=&5R(&%P<NAS
M(&QA(&-O;FYE>&EO;J`_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,30*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_
M(@IM<V=S='(@(E%U96P@97-T(&QE(&-A<F%C=.AR92!D92!SZ7!A<F%T:6]N
MH#\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B
M5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R(")1=65L(&5S
M="!L92!C87)A8W3H<F4@9&4@8VET871I;VZ@/R(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#8U"FUS9VED(")7:&5R96ES
M($%U<W1R86QI82!M87`B"FUS9W-T<B`B0V%R=&4@5VAE<F5I<R!!=7-T<F%L
M:64B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H
M87-E<R(*;7-G<W1R(")1=65L;&5S('!H87-E<R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,S8*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE
M(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B475E;&QE<R!E
M>'1E;G-I;VYS(&%C=&EV97(@<&]U<B!L)^ED:71E=7(@4FEC:"!497AT+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#0*;7-G:60@(E=I9'1H(@IM<V=S='(@(DQA<F=E=7(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3`T"FUS9VED(")7:61T:"!I;B!#4U,@
M=6YI=',B"FUS9W-T<B`B3&%R9V5U<B!E;B!U;FETZ7,@0U-3(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,V,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7
M:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T
M(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`B(@HB3&%R9V5U<B!D=2!M96YU
M(&1E(&=A=6-H92`E<R`@*&QA(&-O;F9I9W5R871I;VX@<')E;F1R82!E9F9E
M="#@(&QA('!R;V-H86EN92`B"B)C;VYN97AI;VXIH#HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED
M=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@(DQA<F=E=7(@9'4@=&%B;&5A=2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P
M"FUS9VED(")7:61T:"!U;FET(@IM<V=S='(@(E5N:73I(&1E(&QA<F=E=7(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M-0IM<V=I9"`B5VED=&@Z(@IM<V=S='(@(DQA<F=E=7*@.B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HU,34*;7-G:60@(E=I:VDB"FUS9W-T<B`B
M5VEK:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(E=I
M;F0B"FUS9W-T<B`B5F5N="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@(E9E
M;G0@=/1T(&QE(&UA=&EN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX-PIM
M<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R(")6:71E<W-E(&1U
M('9E;G0@96X@;B9O96QI9SMU9',B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$V,PIM<V=I9"`B5VEN9#HB"FUS9W-T<B`B5F5N=*`Z(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,0IM<V=I9"`B5VEN9#H@(@IM<V=S
M='(@(E9E;G2@.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G
M:60@(E=I<V1O;2(*;7-G<W1R(")386=E<W-E(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$Y.`IM<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`B3&ES
M=&4@9&4@=B9O96QI9SMU>"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV
M-0IM<V=I9"`B5V]R:R(*;7-G<W1R(")4<F%V86EL(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K($%D
M9')E<W,B"FUS9W-T<B`B061R97-S92!P<F]F97-S:6]N;F5L;&4B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DR"FUS9VED
M(")7;W)K(%!H;VYE(@IM<V=S='(@(E3I;.EP:&]N92!P<F]F97-S:6]N;F5L
M(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3DS(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C(Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7
M<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D
M+"!F;W5N9"`E9"XB"FUS9W-T<B`B3F]M8G)E(&1E(&-H86UP<R!I;F-O<G)E
M8W0@X"!L82!L:6=N92`E9"X@)60@871T96YD=7,L("5D('1R;W5VZ7,N(@H*
M(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S,R"B,L('!H<"UF;W)M
M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D
M+"!F;W5N9"`E9"XB"FUS9W-T<B`B3F]M8G)E(&1E(&-H86UP<R!I;F-O<G)E
M8W0N("5D(&%T=&5N9'5S+"`E9"!T<F]U=NES+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C$R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N
M9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*;7-G<W1R
M(")$Z6-A;&%G92`E9"!I;F-O<G)E8W0@;&]R<R!D92!L82!L96-T=7)E(&1E
M(&9I8VAI97(@5D93+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M-#4*;7-G:60@(E@M4F5F(@IM<V=S='(@(E@M4F5F(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!"87-I
M8R!#;VYS=')A:6YT<R(*;7-G<W1R(")#;VYT<F%I;G1E<R!B87-I<75E<R!8
M-3`Y=C,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y
M,PIM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R(")5
M=&EL:7-A=&EO;B!D92!C;.D@Z71E;F1U92!8-3`Y=C,B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U
M8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R(")!=71R92!N;VT@9'4@
M<W5J970@6#4P.78S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.38*;7-G:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R
M(@IM<V=S='(@(DED96YT:69I86YT(&1E(&-LZ2!D=2!S=6IE="!8-3`Y=C,B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X,PIM<V=I
M9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B17AT96YS:6]N<R!8-3`Y
M=C,B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T
M<B`B04$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#$T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-38*;7-G:60@(EE965DB"FUS9W-T<B`B04%!02(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3$Q"FUS9VED(")986AO
M;R$@;6%P(@IM<V=S='(@(D-A<G1E(*N@66%H;V^@(:"[(@H*(SH@9G)A;65W
M;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I9"`B665A
M<FQY(@IM<V=S='(@(D%N;G5E;&QE;65N="(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G
M:60@(EEE;65N(@IM<V=S='(@(EGI;65N(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV-@IM<V=I9"`B665S(@IM<V=S='(@
M(D]U:2(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH
M=&UL.C4V"FUS9VED(")997,L($D@06=R964B"FUS9W-T<B`B3W5I+"!J)V%C
M8V5P=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C4R"FUS9VED(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@
M6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T
M<B`B(@HB5F]U<R#J=&5S(&5N(&UO9&4@JZ!497AT9:"[+B!5=&EL:7-E>B!L
M92!B;W5T;VX@6SP^72!P;W5R(')E=F5N:7(@874@;6]D92`B"B*KH%=94TE7
M64>@NRXB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.C(S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A
M;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G<W1R
M(")6;W5S(&XGZG1E<R!P87,@875T;W)I<^D@X"!C<NEE<B!P;'5S(&1E("5D
M(&)L;V-S+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,30R-`IM
M<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC871E9"XB"FUS9W-T<B`B5F]U
M<R!N)^IT97,@<&%S(&%U=&AE;G1I9FGI+B(*"B,Z(&9R86UE=V]R:R])9&5N
M=&ET>2])9&5N=&ET>2YP:'`Z,S`X"FUS9VED(")9;W4@8V%N;F]T(&AA=F4@
M=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*;7-G<W1R
M(")6;W5S(&YE('!O=79E>B!P87,@879O:7(@;&4@8V%R86-TZ')E(*M<7+L@
M9&%N<R!V;W1R92!N;VT@8V]M<&QE="XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#4R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S(*;7-G
M:60@(EEO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB
M"FUS9W-T<B`B5F]U<R!N)V%V97H@<&%S('-A:7-I('5N92!A9')E<W-E(.EL
M96-T<F]N:7%U92!V86QI9&4N(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP
M:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P
M(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R
M<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*(E9O=7,@
M;B=A=F5Z('!A<R!A<W-O8VGI(&QE<R!C:&%M<',@9'4@9FEC:&EE<B!I;7!O
M<G3I(&%U>"!C:&%M<',@(@HB8V]R<F5S<&]N9&%N=',@9&%N<R`E<RXB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#<*;7-G:60@(EEO=2!H879E
M(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`B5F]U<R!A=F5Z(.ETZ2!DZ6-O
M;FYE8W3I+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-3@*;7-G
M:60@(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU
M;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R
M('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B
M"B)6;W5S(&1E=F5Z(&EN<V-R:7)E('5N(&YU;>ER;R!D92!C96QL=6QA:7)E
M('9A;&ED92P@<V5U;',@9&5S(&YO;6)R97,@970@=6X@(@HBJZ`KH+L@;W!T
M:6]N;F5L('!O=7(@;&5S(&%P<&5L<R!I;G1E<FYA=&EO;F%U>"XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@U"FUS9VED(")9;W4@:&%V92!T
M;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R(")6;W5S(&XG879E>B!P
M87,@<V%I<VD@=6YE(&5N='+I92!V86QI9&4N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@;75S="!C;VYF:6=U
M<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R
M("(B"B)6;W5S(&1E=F5Z(&-O;F9I9W5R97(@=6X@8F%C:V5N9"!$871A5')E
M92!P;W5R('5T:6QI<V5R(&QE<R!I;G-C<FEP=&EO;G,B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C0W,0IM<V=I9"`B66]U(&UU<W0@8V]N9FEG
M=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(E9O=7,@9&5V97H@8V]N9FEG
M=7)E<B!U;B!M;V1U;&4@5D93+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O
M8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB
M"FUS9W-T<B`B(@HB5F]U<R!D979E>B!DZ6-R:7)E(&QE('!R;V)LZ&UE(&%V
M86YT(&1E(&YO=7,@9F%I<F4@<&%R=F5N:7(@;&4@<F%P<&]R="XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED
M(")9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN
M=',@=&\B"FUS9W-T<B`B5F]U<R!D979E>B!E;G1R97(@=6YE(%523"!O^2!P
M;VEN=&4@9&4@;&EE;BXB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H
M<#HX,`IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D
M96QE=&5D+B(*;7-G<W1R("));"!F875T('/I;&5C=&EO;FYE<B!U;B!S97)V
M975R(.`@<W5P<')I;65R+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0IM<V=I
M9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB
M"FUS9W-T<B`B5F]U<R!D979E>B!S<.EC:69I97(@=6X@=71I;&ES871E=7(@
MX"!R971I<F5R+B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#`*;7-G:60@(EEO
M=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N(@IM<V=S='(@
M(E9O=7,@9&5V97H@<W#I8VEF:65R('5N('5T:6QI<V%T975R(.`@<F5T:7)E
M<BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S
M97)N86UE('1O(&%D9"XB"FUS9W-T<B`B5F]U<R!D979E>B!S<.EC:69I97(@
M=6X@=71I;&ES871E=7(@X"!A:F]U=&5R+B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$T-@IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@
M=7!D871E+B(*;7-G<W1R(")6;W5S(&1E=F5Z('-PZ6-I9FEE<B!L92!N;VT@
M9&4@;"=U=&EL:7-A=&5U<B#@(&UO9&EF:65R+B(*"B,Z(&9R86UE=V]R:R]#
M;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S.`IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R(")6;W5S
M(&1E=F5Z(&EN9&EQ=65R('%U96QL92!A8W1I;VX@86-C;VUP;&ER+B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q
M"FUS9VED(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM
M<V=S='(@(E9O=7,@9&5V97H@Z6-R:7)E('5N(&YO;2!P;W5R(&QA(&YO=79E
M;&QE(&-A=.EG;W)I92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D
M869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B66]U(&YE960@=&\@<')O
M=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*;7-G<W1R(")6;W5S(&1E
M=F5Z(&9O=7)N:7(@=6X@;K`@9&4@=.ELZ7!H;VYE(&ET86QI96XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HY-S4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@
M86=A:6XN(@IM<V=S='(@(E9O=')E('-E<W-I;VX@)7,@82!E>'!I<NDN(%9E
M=6EL;&5Z('9O=7,@<F5C;VYN96-T97(N(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z,S@*;7-G:60@(EEO=7(@16UA:6P@061D<F5S<R(*
M;7-G<W1R(")6;W1R92!A9')E<W-E(&1E(&-O=7)R:65L(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(Q-0IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S
M.B(*;7-G<W1R(")6;W1R92!A9')E<W-E(&1E(&-O=7)R:65L(*L@1&4Z(+N@
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-R!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-S<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@U"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY,@IM<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*
M;7-G<W1R(")6;W,@9&]N;NEE<R!P97)S;VYN96QL97,B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+G!H<#HY-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B
M96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO
M=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B
M"B)6;W1R92!A9')E<W-E($EN=&5R;F5T(&$@8VAA;F?I(&1E<'5I<R!L)V]U
M=F5R='5R92!D92!V;W1R92!S97-S:6]N("5S+B`@(@HB4&]U<B!V;W1R92!S
MZ6-U<FETZ2P@=F]U<R!D979E>B!V;W5S(')E8V]N;F5C=&5R+B(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED(")9;W5R($YA
M;64B"FUS9W-T<B`B5F]T<F4@;F]M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;F]A9&0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@
M8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U
M('=I<V@@=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O
M=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T
M:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*(E9O=')E(&UO9'5L92!D)V%U=&AE
M;G1I9FEC871I;VX@;F4@<W5P<&]R=&4@<&%S(&PG86IO=70@9"=U=&EL:7-A
M=&5U<G,L(%-I("(*(G9O=7,@<V]U:&%I=&5Z('5T:6QI<V5Z($AO<F1E('!O
M=7(@861M:6YI<W1R97(@;&5S(&-O;7!T97,@=71I;&ES871E=7)S+"`B"B)V
M;W5S(&1E=F5Z('5T:6QI<V5R('5N(&%U=')E(&UO9'5L92!D)V%U=&AE;G1I
M9FEC871I;VXN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN
M8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E
M<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B
M"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM
M<V=S='(@(B(*(E9O=')E(&UO9'5L92!D)V%U=&AE;G1I9FEC871I;VX@;B=E
M<W0@<&%S(&5N(&UE<W5R92!D)^ET86)L:7(@=6YE(&QI<W1E(&1E<R`B"B)U
M=&EL:7-A=&5U<G,L(&]U(&-E='1E(&9O;F-T:6]N(&$@Z73I(')E=&ERZ64@
M<&]U<B!U;F4@875T<F4@<F%I<V]N+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.CDX,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&)R;W=S
M97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN
M9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U<B!S96-U
M<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(E9O=')E
M(&YA=FEG871E=7(@<V5M8FQE(&%V;VER(&-H86YGZ2!D97!U:7,@;&4@9.EB
M=70@9&4@=F]T<F4@<V5S<VEO;B`E<RX@("(*(E!O=7(@=F]T<F4@<^EC=7)I
M=.DL('9O=7,@9&5V97H@=F]U<R!R96-O;FYE8W1E<BXB"@HC.B!L:6(O0FQO
M8VLO:69R86UE+G!H<#HU-PIM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T
M('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R(")6;W1R92!N879I9V%T
M975R(&YE('-U<'!O<G1E('!A<R!C971T92!O<'1I;VXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]P<FEN="YJ<SHT,@IM<V=I9"`B(@HB66]U<B!B<F]W
M<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S
M($-O;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*
M(E9O=')E(&YA=FEG871E=7(@;F4@<')E;F0@<&%S(&5N(&-O;7!T92!C971T
M92!O<'1I;VX@9"=I;7!R97-S:6]N+B!0<F5S<V5Z("(*(D-O;G1R]&QE+T-O
M;6UA;F1E("L@4"!P;W5R(&EM<')I;65R(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(V,0IM<V=I9"`B66]U<B!C=7)R96YT('1I;64@>F]N93HB"FUS
M9W-T<B`B5F]T<F4@9G5S96%U(&AO<F%I<F4@86-T=65LH#HB"@HC.B!S97)V
M:6-E<R]P<F5F<RYP:'`Z,3$W"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I
M='D@:&%S(&)E96X@8VAA;F=E9"XB"FUS9W-T<B`B5F]T<F4@<')O9FEL('!A
M<B!DZ69A=70@82#I=.D@;6]D:69IZ2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,38Q"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S
M='(@(E!R;V9I;"!P87(@9.EF875TH#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C`T"FUS9VED(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`B5F]T
M<F4@;F]M(&-O;7!L972@.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP
M.CDY.0IM<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T<B`B
M5F]T<F4@8V]M<'1E(&$@97AP:7+I+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A
M<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B5F]T<F4@;F]U=F5A=2!M
M;W0@9&4@<&%S<V4@<&]U<B`E<R!E<W2@.B5S(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ-30*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E
M(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO
M;BXB"FUS9W-T<B`B5F]S(&]P=&EO;G,@;VYT(.ETZ2!M:7-E<R#@(&IO=7(@
M<&]U<B!L82!D=7+I92!D92!C971T92!S97-S:6]N+B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,34V"FUS9VED(")9;W5R(&]P=&EO;G,@
M:&%V92!B965N('5P9&%T960N(@IM<V=S='(@(E9O<R!O<'1I;VYS(&]N="#I
M=.D@;6ES97,@X"!J;W5R+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C<U"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T(@IM
M<V=S='(@(E9O=')E(&UO="!D92!P87-S92!A(.ETZ2!R96UI<R#@('KI<F\B
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB
M66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I
M;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S
M='(@(B(*(E9O=')E(&UO="!D92!P87-S92!A(.ETZ2!R96UI<R#@('KI<F\L
M(';I<FEF:65R('9O=')E(&-O=7)R:65R(&5T(&-O;FYE8W1E>BTB"B)V;W5S
M(&%V97H@=F]T<F4@;F]U=F5A=2!M;W0@9&4@<&%S<V4N(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z-S,S"FUS9VED(")9;W5R('!A<W-W;W)D(&AA
M<R!E>'!I<F5D+B(*;7-G<W1R(")6;W1R92!M;W0@9&4@<&%S<V4@82!E>'!I
M<NDN(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED
M(")9;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R(")6;W,@<V5R=F5U<G,@
M9&ES=&%N='.@.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4T
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EEU9V]S
M;&%V:6$B"FUS9W-T<B`B66]U9V]S;&%V:64B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G<W1R("):8>]R
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R("):86UB
M:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")::6UB86)W92(*;7-G<W1R("):
M:6UB86)W92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B
M6FEP<'DB"FUS9W-T<B`B6FEP<'DB"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT
M97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1
M=6]T960@5&5X=%TB"FUS9W-T<B`B6T-A8VAE<B!L97,@8VET871I;VYS72(*
M"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C@Y"FUS9VED(");4')O8FQE;2!2
M97!O<G1=(@IM<V=S='(@(EM287!P;W)T(&1E('!R;V)LZ&UE72(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(");
M4VAO=R!1=6]T960@5&5X="`M(@IM<V=S='(@(EM!9F9I8VAE<B!L92!T97AT
M92!C:73I("TB"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI
M9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,L('!H<"UF;W)M870*;7-G:60@(EM3
M:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM<V=S='(@(EM!9F9I8VAE
M<B!L92!T97AT92!C:73I("T@)7,@;&EG;F5S72(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,C`T"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE
M("5S(&]F("5S72(*;7-G<W1R(");;&EG;F4@)7,@9&4@)7-=(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-34T('1E;7!L871E<R]P;W)T86PO
M;65N=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R(")?
M061M:6YI<W1R871I;VXB"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#
M3$DB"FUS9W-T<B`B3&EG;F4@9&4@7V-O;6UA;F1E(@H*(SH@;&EB+V%P:2YP
M:'`Z,30Q"FUS9VED(")?1&%T851R964B"FUS9W-T<B`B7T1A=&%4<F5E(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,Q"FUS9VED(")?1&5L971E(%)O=R(*;7-G<W1R(")3=7!P<FEM97(@
M;&$@7W)A;F?I92(*"B,Z(&QI8B]A<&DN<&AP.C$S,PIM<V=I9"`B7T=R;W5P
M<R(*;7-G<W1R(")?1W)O=7!E<R(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]-96YU+G!H<#HQ-S4*;7-G:60@(E](96QP(@IM<V=S='(@(E]!:61E(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")0
M<F]P<E]IZ73I<R!D92!L)VEM86=E+BXN(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+TUE;G4N<&AP.C$Y-`IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R(")?
M0V]N;F5X:6]N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP
M.C$Y,`IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`B7T3I8V]N;F5X:6]N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(T"FUS9VED(")?36]D:69Y($QI;FLN+BXB"FUS9W-T<B`B7TUO9&EF
M:65R('5N(&QI96X@=V5B+BXN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+TUE;G4N<&AP.C$V-`IM<V=I9"`B7T]P=&EO;G,B"FUS9W-T<B`B7T]P=&EO
M;G,B"@HC.B!L:6(O87!I+G!H<#HQ,S<*;7-G:60@(E]097)M:7-S:6]N<R(*
M;7-G<W1R(")?4&5R;6ES<VEO;G,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]296UO=F4@
M3&EN:RXN+B(*;7-G<W1R(")?4F5T:7)E<B!U;B!L:65N(@H*(SH@;&EB+V%P
M:2YP:'`Z,3(U"FUS9VED(")?4V5T=7`B"FUS9W-T<B`B7T-O;F9I9W5R871I
M;VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM<V=S
M='(@(E!R;W!R:>ETZ7,@9'4@7W1A8FQE874B"@HC.B!L:6(O87!I+G!H<#HQ
M,CD*;7-G:60@(E]5<V5R<R(*;7-G<W1R(")?571I;&ES871E=7)S(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C4*;7-G:60@(F%D9')E<W,@
M8F]O:R(*;7-G<W1R(")C87)N970@9"=A9')E<W-E<R(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,T"FUS9VED(")A9&1R97-S964@
M=6YK;F]W;B(*;7-G<W1R(")D97-T:6YA=&%I<F4@:6YC;VYN=2(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$W"FUS9VED(")C86QE;F1A<B(*
M;7-G<W1R(")A9V5N9&$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W.2!L
M:6(O0FQO8VLO;65T87(N<&AP.C,V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")C
M86QM(@IM<V=S='(@(F-A;&UE(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I
M;&4B"FUS9W-T<B`B:6UP;W-S:6)L92!D92!C<NEE<B!L92!F:6-H:65R(&1E
M('-O<G1I92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R(")I;7!O<W-I
M8FQE(&0G;W5V<FER(&PG96YT<NEE(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z-3DX"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@
M(F-L:7%U97H@:6-I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G
M<W1R(")E<G)E=7(@9"=U=&EL:7-A=&EO;B!D92!L82!L:6=N92!D92!C;VUM
M86YD92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<X
M"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(F5R<F5U<B!D
M92!C;VYF:6=U<F%T:6]N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ-30*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I
M;F<B"FUS9W-T<B`B86)S96YC92!C<FET:7%U92!D)W5N(&9I8VAI97(@<WES
M=.AM92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(V
M"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R(")E<G)E=7(@9&4@
M9F]R;6%T(&1E(&1O;F[I92(*"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI
M;F,Z,S`*;7-G:60@(F5D:70B"FUS9W-T<B`B;6]D:69I97(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$X,@IM<V=I9"`B96YT<GD@
M;F]T(&9O=6YD(@IM<V=S='(@(F5N='+I92!N;VX@=')O=7;I(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*;7-G:60@(F9A
M;&QI;F<B"FUS9W-T<B`B=&]M8F%N="(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R
M+T)R;W=S97(N<&AP.C@Y.`IM<V=I9"`B9FEL92(*;7-G<W1R(")F:6-H:65R
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#$@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS-C<@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R(")D
M97!U:7,@;&4@)7,@*"5S*2#@("5S("5S(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(S.0IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R(")E;B!R
M869A;&4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C4P"FUS9VED(")H.B(*;7-G<W1R(")HH#HB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4Y"FUS9VED(")H:"(*;7-G
M<W1R(")H:"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,3,X"FUS9VED(")H;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R(")N;VT@9"=H
M]'1E(&EN8V]N;G4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R
M(")I;6WI9&EA=&5M96YT(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(FEN;&EN92(*;7-G<W1R
M(")I;F-O<G!O<NEE(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R(")E
M<G)E=7(@9"=E;G1RZ64O<V]R=&EE(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R
M<F]R(@IM<V=S='(@(F5R<F5U<B!L;V=I8VEE;&QE(&EN=&5R;F4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B
M;&EN97-=(@IM<V=S='(@(FQI9VYE<UTB"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)
M4T\N(@IM<V=S='(@(F5R<F5U<B!M:VES;V9S(&-O9&4@)60@96X@8W+I86YT
M(&PG25-/(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C,W,`IM<V=I9"`B;6TB"FUS9W-T<B`B;6TB"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C(X-2!S97)V:6-E<R]P;W)T86PO<VED96)A
M<BYP:'`Z,3<P"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR-#$*
M;7-G:60@(FYA;64B"FUS9W-T<B`B;F]M(@H*(SH@9G)A;65W;W)K+U)00R]2
M4$,N<&AP.C$R-`IM<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(FYO
M;B!P<FES(&5N(&-O;7!T92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,3(R,`IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*;7-G
M<W1R(")P87,@96YC;W)E('!R:7,@96X@8V]M<'1E(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,#D*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B
M8FQO8RUN;W1E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B<&]U
M<F-E;G1A9V4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$W-`IM<V=I9"`B<&5R;6ES<VEO;B!D96YI960B"FUS9W-T<B`B<&5R;6ES
M<VEO;B!R969U<^EE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(G!I
M>&5L<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<P
M"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B97)R
M975R(&1I<W1A;G1E(&1A;G,@;&4@<')O=&]C;VQE(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S4*;7-G:60@(G)I<VEN9R(*
M;7-G<W1R(")S)^EL979A;G0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$T,@IM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G
M<W1R(")S97)V:6-E(&YO;B!D:7-P;VYI8FQE+B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z,3`Q"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S
M='(@(FUO;G1R97(@;&5S(&1I9F;I<F5N8V5S(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*;7-G:60@(G-M<S)E
M;6%I;"!V:6$@2%144"(*;7-G<W1R(")S;7,R96UA:6P@=FEA($A45%`B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@W"FUS
M9VED(")S<R(*;7-G<W1R(")S<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C<T"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B9FEX
M92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34P"FUS
M9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`B97)R975R('-Y<W3H;64B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS,PIM<V=I9"`B=&%S:R!L
M:7-T(@IM<V=S='(@(FQI<W1E(&1E('3B8VAE<R(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,38V"FUS9VED(")T96UP;W)A<GD@9F%I
M;'5R92(*;7-G<W1R("+I8VAE8R!T96UP;W)A:7)E(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,S8@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W,`IM
M<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G
M<W1R(")E;G1R97H@;&4@;6]T(&1E('!A<W-E(&1E=7@@9F]I<R!P;W5R(&-O
M;F9I<FUE<B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E
M='5P+V1I9F8N<&AP.C<Y"FUS9VED(")U;FEF:65D(@IM<V=S='(@(G5N:69I
MZ2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O4&%R="YP:'`Z,C<*;7-G:60@
M(G5N;F%M960B"FUS9W-T<B`B<V%N<R!N;VTB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(G5S
M97(@<V5L96-T(@IM<V=S='(@(E/I;&5C=&EO;B!D)W5T:6QI<V%T975R(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,U"FUS
M9VED(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR-#(*;7-G:60@(G<Z(@IM<V=S='(@
M(FR@.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED
M(")W96%T:&5R+F-O;2(*;7-G<W1R(")W96%T:&5R+F-O;2(*````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+V%R7U-9+G!O````````
M````````````````````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#8Q
M-C$U-R`Q,#4Q-30S,S<T,R`P,3<U-3,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````(R!(3U)$12!!<F%B:6,@=')A;G-L871I
M;VX*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@
M;&EC96YS92!A<R!T:&4@2&]R9&4@<&%C:V%G92X*(R!#;W!Y<FEG:'0@*$,I
M(#(P,#,@4&QA=&EN=6T@26YC+B`\<&Q`=&EN=6TN:6YF;SX*(R!#=7-T;VT@
M5V5B($%P<&QI8V%T:6]N<R`\:'1T<#HO+W!L871I;G5M+7-Y+F-O;3X*(R!0
M;&%T:6YU;2!$979E;&]P;65N="!496%M(#QD979T96%M0'!L871I;G5M+7-Y
M+FYE=#X*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO
M;CH@2$]21$4@=C(N,"XP7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V
M0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M
M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P,RTP
M-"TS,"`Q,CHP,"LP,C`P7&XB"B),87-T+51R86YS;&%T;W(Z(%!L871I;G5M
M($1E=F5L;W!M96YT(%1E86T@/&1E=G1E86U`<&QA=&EN=6TM<WDN;F5T/EQN
M(@HB3&%N9W5A9V4M5&5A;3H@07)A8FEC(#QI,3AN0&QI<W1S+FAO<F1E+F]R
M9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E
M>'0O:'1M;#L@8VAA<G-E=#U#4#$R-39<;B(*(D-O;G1E;G0M5')A;G-F97(M
M16YC;V1I;F<Z(#AB:71<;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ,S<P"B,L
M('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<W"B,L('!H<"UF;W)M
M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,PIM<V=I9"`B("AT;V1A>2DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-0IM<V=I9"`B
M("AT;VUO<G)O=RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C,W,0IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-38@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,V,0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-#`W"FUS9VED("(@870@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G:60@(EPB
M)7-<(B!I<R!N;W0@82!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#3$DO0TQ)+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HV-3D*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ,#0R"B,L('!H<"UF;W)M
M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R
M9&4@4F5G:7-T<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]4<F5E+U1R
M964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E92!R
M96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E
M9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<&5R;7,O861D8VAI;&0N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(EPB
M)7-<(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A
M9&1C:&EL9"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A
M<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E
M9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,W"B,L('!H<"UF;W)M870*
M;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C(V."!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-34W"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P
M87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C@U"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A
M>2!F;W)E8V%S="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T
M:6-E(@IM<V=S='(@(LKDR.WE(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HW,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R
M<')I;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT
M96YT<RYP:'`Z.#,S(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.C@S-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#D*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF
M:7)M871I;VXB"FUS9W-T<B`BRN3=[=`@VN/A[<?*(,?AU>W'Y,DB"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V,PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N(%5P(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!497)M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HT,C@@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HT.3`*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV-3$@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,34Y(&QI8B]";&]C:R]M971A<BYP:'`Z,38U(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C,Y"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S0U
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S4Q"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(&%T("5S("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<#HT.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@
M:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E
M<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*
M;7-G<W1R("+6VB#:X<?CR2#=[2#CT<C:(,?AVN/A[<D@*,?AVN/A[<?**2#'
MX<KM(,K1[<\@RN3=[=#EQR#-Q^''\"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S0P"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E<75I
M<F5D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@V"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S='(@
M(M_A(#4@S][MWLDB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C
M=&EO;BYP:'`Z,3(S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N
M;W0@9F]U;F0N(@IM<V=S='(@(MOMT2#CYLSFSR(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@(EO'X=/8T2`E<R#CY"`E<UTB
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR,@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B
MS]W*T2#:Y,?F[>0B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*
M;7-G<W1R("+#S.3/R2(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3`V"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO
M8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP
M.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M97-S86=E
M(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E
M(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED
M:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M-C4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q,`IM<V=I9"`B+"!G
M=7-T:6YG("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X
M."!L:6(O0FQO8VLO;65T87(N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(L(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L92!F
M<F]M("5S('1O("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,CDT(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,S0X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-CD@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C$R.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-S0Y"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P"B,L(&9U>GIY"FUS9VED
M("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R("+([<?DQ\K?.B(*"B,Z(&QI8B]"
M;&]C:R]T:6UE+G!H<#HQ.0HC+"!F=7IZ>0IM<V=I9"`B,C0@2&]U<B!&;W)M
M870B"FUS9W-T<B`BR.W'Y,?*WSHB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE
M+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@T\?:R2(*"B,Z
M(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z-CD*;7-G:60@(CQ0<F5V:6]U
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q.0IM<V=I
M9"`B02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L
M;V-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$V,`HC+"!F=7IZ>0IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R
M960B"FUS9W-T<B`B/&(^(,W5X2#.V,,Z("(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.CDS-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I
M<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V-0IM<V=I9"`B
M02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N
M960@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3`Y-PIM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@
M<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P,34*;7-G:60@(B(*(D$@<'5B
M;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S86=E+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4P-0IM<V=I
M9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A
M(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y
M+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G:60@(D$@<'5B
M;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G
M92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z.0IM<V=I9"`B04T@0VQO=61S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!
M32!,:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"FUS9VED(")!32!286EN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R
M"FUS9VED(")!32!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!32!3;F]W(%-H
M;W=E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z
M,CD*;7-G:60@(D%-+U!-(@IM<V=S='(@(N3EQ]''\"_A[>''\"(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM
M<V=I9"`B05!)($E$(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@961I
M=&]R(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4R
M"FUS9VED(")!8F]U="XN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T"FUS9VED(")!8G-B;W1T;VTB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED9&QE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-S`*;7-G:60@(D%C8V5S<R!D
M96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S
M(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G0@
M26YF;W)M871I;VXB"FUS9W-T<B`BR.W'Y,?*WSHB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-S4*(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G0@4&%S<W=O
M<F0B"FUS9W-T<B`BW^'CR2#'X>/1YM$B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*;7-G:60@(D%C8V]U;G0@
M9G)O>F5N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S,S"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(LKD
MW>W0.B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30X('1E
M;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B061D(@IM
M<V=S='(@(L?AVN3FQ^0B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI
M;B]G<F]U<',N<&AP.C(R-0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3@@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY.0IM<V=I9"`B061D($-H:6QD
M(%!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A
M9&0N:6YC.C4*(RP@9G5Z>GD*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R("+'
MX=KDYL?D(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O=7!S
M+G!H<#HR,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL
M9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!G<F]U
M<"!T;R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI
M;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34T
M"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,S0*;7-G:60@(D%D9"!N97<@;65M8F5R
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.CDU
M"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R("+#UMT@R^3'QNTB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D%D
M9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*
M(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@
M(L_=RM$@VN3'YNWD(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C<X"B,L(&9U>GIY"FUS9VED(")!9&0@=&\@;7D@861D<F5S
M<R!B;V]K(@IM<V=S='(@(L_=RM$@VN3'YNWD(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S$*(RP@9G5Z>GD*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(L/6W2#+
MY,?&[2(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@
M;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N
M(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B061D960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G
M(&EN(&YO=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;F]A9&0N:6YC.C(*;7-G:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$R-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3<S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#$*;7-G:60@
M(D%D9')E<W,B"FUS9W-T<B`BQ^':Y.;'Y"(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ,SD*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R("+/
MW<K1(-KDQ^;MY"(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.CDT"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS
M(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]I;F1E>"YP
M:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM<V=I9"`B
M061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,T,0HC+"!F=7IZ>0IM<V=I9"`B061S(@IM<V=S='(@(L?A
MVN3FQ^0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!9F=H86YI<W1A;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;&)A;FEA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S`*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P-PIM<V=I9"`B06QI
M87,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I9"`B06QI9VXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM
M<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R;W5P<RYP
M:'`Z,C(R"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+V1A=&%T<F5E+G!H<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S$*;7-G:60@(D%L
M;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3,T"FUS9VED(")!;&QO=R!S971T:6YG(&]F(&]R
M9&5R960@;&ES="!T>7!E/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T
M851R964O1&%T851R964O<W%L+G!H<#HU,#0*;7-G:60@(D%L<F5A9'D@97AI
M<W1S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C,*
M;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#<*;7-G:60@(D%L=&5R;F%T92!)35-0
M(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT.3D*;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"B,L(&9U>GIY
M"FUS9VED(")!;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R("+:Y.;'
MY"#(T>W/WR#'X<7AW\K1YN3M.B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M,30R"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z.34@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@
M=V%S('-P96-I9FEE9"XB"FUS9W-T<B`BRN,@RLW/[<\@WNWCR2#;[=$@X][(
MYN')(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-PHC+"!F
M=7IZ>0IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS
M9W-T<B`BS=7A(,[8PSHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O<G)A(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4W"FUS9VED(")!;F=U:6QL82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!;F]N>6UO
M=7,@4')O>'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X
M"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G
M:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B(@H*(SH@861M:6XO
M=&5M<&QA=&5S+G!H<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z,S4*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU."!T96UP;&%T97,O861M:6XO
M<V5T=7`O:6YD97@N:'1M;#HV"B,L(&9U>GIY"FUS9VED(")!<'!L:6-A=&EO
M;B(*;7-G<W1R("+'X<K8R.W>Q\H@Q^'CYLSFS\DZ("5S(@H*(SH@=71I;"]I
M8V]N7V)R;W=S97(N<&AP.C0R"B,L(&9U>GIY"FUS9VED(")!<'!L:6-A=&EO
M;B!,:7-T(@IM<V=S='(@(L?ARMC([=['RB#'X>/FS.;/R3H@)7,B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,30P"FUS9VED(")!<'!L:6-A=&EO;B!I
M<R!R96%D>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O($-H:6QD(%-H87)E<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM
M<V=I9"`B07!P<F]V92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HX,S,*;7-G:60@(D%P<')O>&EM871E(%-I>F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3<U"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HU.2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8V
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#$*;7-G
M:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HV-0HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C@P"FUS9VED(")!<F-H:79E($YA;64B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN
M8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A
M;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@
M=&\@9&5L971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4W"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3<V"FUS9VED(")!<FUE;FEA;B`H05)-4T-)22TX
M*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*;7-G
M:60@(D%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!<G5B82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U"FUS
M9VED(")!<V-E;G-I;VX@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@07)T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I
M82]086-I9FEC(%)E9VEO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#(U"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O
M<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`BRL/?
M[<\@Q^'8X<@@WLCA(,?AR,_!(,C:X^'MQ\H@Q^'5[<?DR;\B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$S"FUS9VED(")!<W-I9VYM96YT(&-O
M;'5M;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I
M9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z,CD*;7-G:60@
M(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED
M(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS
M9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C0@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,0HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@V"FUS9VED
M(")!='1R:6)U=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#@*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')A;&EA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3D*;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S
M<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3,U"FUS
M9VED(")!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER
M960@8V%P86)I;&ET97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER
M960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U=&A?
M9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL
M92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HV-`IM<V=I
M9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP
M:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@=7-E
M<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,U-PIM
M<V=I9"`B075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R
M=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-C,*;7-G:60@(D%U=&A?;&1A<#H@
M4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,S.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E
M<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF
M;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z-#DY"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE
M('1O('5P9&%T92!U<V5R("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z-#`U"FUS9VED(")!=71H7VQD87`Z(%5P9&%T
M:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O
M<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP
M:'`Z-#8*;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@
M<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*
M;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960N
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S
M+G!H<#HQ-S8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!
M1$E54R!S97)V97(N(@IM<V=S='(@(LKC(-'=UB#'X<K-WMX@X^0@Q^'EYNW)
M(./D(-[(X2#'X>/.S^,@T<?/[>;3+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z.#4Q"B,L(&9U>GIY"FUS9VED(")!=71H96YT:6-A=&EO;B!T
M;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`BS=7A(,[8PR#.X<?A(,?A
MQ<K5Q^$@R./.S^,@Q^'<($944"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C<P"B,L(&9U>GIY"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!T
M:&4@4TU"('-E<G9E<B!F86EL960N(@IM<V=S='(@(LW5X2#.V,,@SN''X2#'
MX<7*U<?A(,CCSL_C(,?AW"!&5%`N(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`B
MQ^'-WN;A(,?AX\KFW=').B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%Z97)B86EJ
M86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,P"FUS
M9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C
M:V=R;W5N9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#$*
M;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`BW^'CR2#C
MT>;1(-O(T2#CWLCFX<D@*-_MT<CMT>;3*2(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M
M92XB"FUS9W-T<B`BQ]/C(,?AX]/*SL_C(-O(T2#CWLCFX2`HW^W1R.W1YM,I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F%H86UA<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Q"FUS9VED(")"86AR86EN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3<W"FUS9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(B(*
M"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")"87-E(&=R87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S,*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C,*;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,`IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS
M9VED(")"96QI>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F5N
M:6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")":'5T86XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM
M<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B[>;C(,?AX^WAQ\\B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S4S"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S7"(@;V8@87!P;&EC871I
M;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`BX>,@[=K+T2#:X>P@Q^'C
MT\KCVB`E<RXB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.#D*
M;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I
M9"`B0F]L:79I82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C`U"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`HC
M+"!F=7IZ>0IM<V=I9"`B0F]R9&5R(@IM<V=S='(@(N7FT<_M(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B
M0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0HC+"!F=7IZ>0IM
M<V=I9"`B0F]R9&5R<R(*;7-G<W1R("+EYM'/[2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G
M:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED(")";W1H(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C,*;7-G:60@(D)O='-W86YA(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-0IM
M<V=I9"`B0F]T=&]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O
M=79E="!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@HC+"!F=7IZ>0IM
M<V=I9"`B0G)A>FEL(@IM<V=S='(@(L?AR-'MSR(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS
M9VED(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM
M<V=I9"`B0G5L;&5T960@3&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS
M9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I
M9"`B0G5R=6YD:2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#0T"B,L(&9U>GIY"FUS9VED(")#35,B"FUS9W-T<B`B0U93(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I
M9"`B0U)#(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3DW"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V
M,PIM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0X-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3@W"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ-34*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(L/,
MY,_)(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-@IM<V=I
M9"`B0V%L;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B0V%M8F]D
M:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G
M:60@(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N
M=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#86X@;F]T('=R:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E<W-I;VYS+G!H<#HR,@IM<V=I9"`B0V%N)W0@861M:6YI<W1E
M<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,S4@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)S<6PN<&AP.C,Q.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T
M<B`BX<?%X]_'Y.W)(.'AQ<K5Q^$@R,?AX\[/XR!,1$%0+B(*"B,Z(&9R86UE
M=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0Q,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")#86XG="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8T"B,L(&9U>GIY"FUS9VED(")#86YA9&$B"FUS9W-T<B`BP\SDS\DB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-0HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W)E;6]V92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L
M(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(L7AV\?!(,?AR.''VR#:Y"#CU-_A
MR2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$X"B,L('!H<"UF
M;W)M870*;7-G:60@(D-A;FYO="!D96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HT-@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C4R"FUS9VED(")#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O
M<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@
M)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HS,30*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T
M<B`BQ>34Q\$@Q^'CS.'/("5S(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A
M=&%4<F5E+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q
M;"YP:'`Z-C@P"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4L
M("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1&%T851R964O1&%T851R964O<W%L+G!H<#HV,#@*;7-G:60@(B(*(D-A;FYO
M="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O
M<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I
M9FEE9"!N=6UB97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A
M<&4@5F5R9&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`HC+"!F=7IZ>0IM<V=I9"`B0V%P
M=&EO;B(*;7-G<W1R("+.[<?1Q\HB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP"FUS9VED(")#871E
M9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G
M:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO
M;F4B"FUS9W-T<B`BQ^'EQ\K=(,?AS.;'X2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*(RP@9G5Z>GD*;7-G
M:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G<W1R("+'X>7'RMT@Q^',YL?A(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*
M;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B
M0V5L;"!P<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS9VED(")#96QL('-P86-I
M;F<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M-S0*(RP@9G5Z>GD*;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R("+'X>7'RMT@
MQ^',YL?A(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D-E
M;'1I8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E
M;G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F
M<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ-SD*;7-G:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-CDY"FUS9VED(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C$Q"FUS9VED
M(")#97)T:69I8V%T92!/=VYE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I9"`B0V5R=&EF:6-A=&4@
M4&]L:6-I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"B,L(&9U>GIY"FUS
M9VED(")#:&%D(@IM<V=S='(@(G9#87)D(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY
M-@HC+"!F=7IZ>0IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(LK1Q\S:(-KD(,?A
MRMOM[=''RB(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,0IM
M<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8V"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA
M;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D
M(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#:&%N
M9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@
M8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D;6EN
M:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*(RP@9G5Z>GD*;7-G:60@(D-H
M87(B"FUS9W-T<B`B=D-A<F0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK
M+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D-H
M:6QE(@IM<V=S='(@(L?AX=[((@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;F$B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@
M(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0VAI;F5S92!4<F%D:71I
M;VYA;"`H0FEG-2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V
M.`IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(Y.`IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D
M:7-P;&%Y(&1A=&5S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O
M<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,N<&AP.C(Y-"!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z.#DS"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T
M<B`BX>,@[=K+T2#:X>P@Q^'CT\KCVB`E<RXB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`HC+"!F=7IZ>0IM<V=I9"`B0VQE
M87(B"FUS9W-T<B`BP\SDS\DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*;7-G:60@
M(D-L96%R(%%U97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V-L96%R+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U
M="!U<V5R.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]C;&5A<BYI;F,Z,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L
M96%R('5S97(@9&%T82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N
M8V4N:'1M;#HV,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(L7;
MX<?>(,?AY,?=T,DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-`IM<V=I
M9"`B0VQO=61S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$V"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,3<*;7-G:60@(D-L;W5D>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED
M(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C(S"FUS9VED(")#;VQL87!S92!3
M:61E8F%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D
M97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O;&]M8FEA(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K
M+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#;VQO<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(T"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C4*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4P,"!S97)V
M:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0
M:6-K97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C@T-@IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PIM<V=I
M9"`B0V]L<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3DT-@IM<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8T"FUS9VED(")#;VUI8W,B"FUS
M9W-T<B`BT=/FX\?*(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(U"B,L(&9U
M>GIY"FUS9VED(")#;VUM86YD(@IM<V=S='(@(L?AP^;'X]$Z(@H*(SH@861M
M:6XO8VUD<VAE;&PN<&AP.C(P"B,L(&9U>GIY"FUS9VED(")#;VUM86YD(%-H
M96QL(@IM<V=S='(@(L?AP^;'X]$Z(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#$S"B,L(&9U>GIY"FUS9VED(")#;VUM96YT(@IM<V=S
M='(@(L?AP^;'X]$Z(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU-C8*;7-G:60@(D-O;6UO;B!.86UE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@T"B,L(&9U>GIY"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(M'3YN/'
MRB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR
M,SD*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`BQ^'4T=_)(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y-PHC+"!F=7IZ
M>0IM<V=I9"`B0V]N9&ET:6]N(@IM<V=S='(@(LKDW>W0(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR-#D*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R
M871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$T,PIM<V=I9"`B0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN
M9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,U"FUS9VED(")#;VYF
M:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3`P"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M;F9I9W5R92`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C4Q"B,L(&9U>GIY"FUS9VED(")#;VYF:7)M(%!A<W-W
M;W)D(@IM<V=S='(@(M_AX\D@Q^'CT>;1(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B
M0V]N9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HU,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V]N9V\L(%1H
M92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"B,L(&9U>GIY
M"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`BS=7A(,[8PR#.
MX<?A(,?AQ<K5Q^$@R./.S^,@Q^'<($944"XB"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"B,L(&9U>GIY"FUS9VED(")#;VYN
M96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(LW5X2#.V,,@SN''X2#'X<7*U<?A
M(,CCSL_C(,?AW"!&5%`N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-SDP"B,L(&9U>GIY"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@
M=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(LW5X2#.V,,@SN''
MX2#'X<7*U<?A(,CCSL_C(,?AW"!&5%`N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-SDR"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE
M8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N
M.B`E<R`H)7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z.#0U"B,L(&9U>GIY"FUS9VED(")#;VYN96-T:6]N('1O($944"!S
M97)V97(@9F%I;&5D+B(*;7-G<W1R("+-U>$@SMC#(,[AQ^$@Q^'%RM7'X2#(
MX\[/XR#'X=P@1E10+B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#$T
M"FUS9VED(")#;VYT86-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A8W1S('=E
M<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C4V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM
M<V=S='(@(N/-RN;MQ\H@)R5S)R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C(Y('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,PIM<V=I
M9"`B0V]N=&EN=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]O
M:R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS,@IM<V=I9"`B0V]O:VEE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0HC+"!F=7IZ
M>0IM<V=I9"`B0V]P>2(*;7-G<W1R("+'X=31W\DB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C0V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@(L?AS=[FX2#'X>/3RN;1S\DZ
M("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-S`*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@
M240B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;W1E(&0G279O:7)E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDW
M-@IM<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P-3,*
M;7-G:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I
M9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#8W"FUS
M9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HQ.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A
M9&0@8V]N=&%C="X@)7,B"FUS9W-T<B`BX<<@Q>/?Q^3MR2#AY-/.("5S(,7A
M["`E<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$R,0HC+"!F=7IZ>0IM<V=I
M9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(N''
MQ>/?Q^3MR2#AX<7*U<?A(,C'X>/.S^,@3$1!4"XB"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-#4W"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!L9&%P
M('-E<G9E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C$U-@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R
M("+AQR#%X]_'Y.W)(.'DT\X@)7,@Q>'L("5S(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C0T,0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE
M8W0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`BX<?%X]_'Y.W)(.'AQ<K5Q^$@
MR,?AX\[/XR!334(N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E
M<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,B"FUS9W-T<B`BX<?%X]_'Y.W)(.'%Y-3'P2#CS.'/
M(./-X>T@*&QO8V%L*2#CY"##S.$@X^'=(,?AX=O)("5S.B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q,C4*(RP@9G5Z>GD*;7-G:60@
M(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+B(*;7-G<W1R("+AQR#%X]_'
MY.W)(.'DT\X@)7,@Q>'L("5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU,C(*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%,O34E-
M12!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C(T-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R("+A
MQR#%X]_'Y.W)(.'DT\X@)7,@Q>'L("5S(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R
M861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.CDU,PIM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@
M<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"FUS
M9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C0Y,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E
M(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I9"`B0V]U
M;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO
M;B!L:7-T<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+G!H<#HX-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&QO860@<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R("+AQR#%X]_'Y.W)
M(.'DT\X@)7,@Q>'L("5S(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T
M<F%T96=Y+V1I<F5C="YP:'`Z,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S$Y"FUS9VED(")#;W5L9"!N;W0@;V)T
M86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM
M<V=S='(@(N''(,7CW\?D[<D@X>33SB`E<R#%X>P@)7,B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W-PHC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-C(*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G
M<W1R("+AQR#%X]_'Y.W)(.'DT\X@)7,@Q>'L("5S(@H*(SH@9G)A;65W;W)K
M+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HT,3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U
M;&4@)7,B"FUS9W-T<B`BX<?%X]_'Y.W)(.'=RLT@36%I;G1E;F%N8V5?5&%S
M:R#AX<C1[>/,("5S(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@
M7"(E<UPB+B(*;7-G<W1R("+AQR#%X]_'Y.W)(.'DT\X@)7,@Q>'L("5S(@H*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HR,S<@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C0W.`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M-3$V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z-CDY"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N
M;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R("+AQ\7CW\?D[<D@
MX>'%RM7'X2#(Q^'CSL_C($Q$05`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M3V)J96-T+G!H<#HR,S@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R96%D("5S+B(*;7-G<W1R("+AQR#%X]_'Y.W)(.'DT\X@)7,@
MQ>'L("5S(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G
M:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R
M97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@
M87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS,#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S0P"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W
M-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#,*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y"FUS
M9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@
M861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R("+AQ\7CW\?D[<D@X<7DU,?!(./,
MX<\@X\WA[2`H;&]C86PI(./D(,/,X2#CX=T@Q^'AV\D@)7,Z(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C(R,PIM<V=I9"`B0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A
M<&%B:6QI=&EE<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C4T"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5V97)T(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(N'C(.W*XR#%VL_'SR#EYM'/[2#(U-_A(-7-
M[<TB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S,*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(N'C(.W:R]$@VN'L("=P;W)T)R#=[2#%VL_'S\?*(%9&4RXB"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z-3D*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P
M(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R
M871I;VX@9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@
M<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE
M<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@
M8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O
M("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C$T,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@
M3$1!4"!S97)V97(N(@IM<V=S='(@(N''Q>/?Q^3MR2#AX<7*U<?A(,C'X>/.
MS^,@3$1!4"XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,C$Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D
M871E(&-O;G1A8W0N("5S(@IM<V=S='(@(N''(,7CW\?D[<D@X>33SB`E<R#%
MX>P@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C,Y-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D
M871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B!<(B5S7"(Z
M("5S(@IM<V=S='(@(N''Q>/?Q^3MR2#AQ>34Q\$@X\SASR#CS>'M("AL;V-A
M;"D@X^0@P\SA(./AW2#'X>';R2`E<SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S8V"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I
M9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ
M-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R
M(%PB)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<
M(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T,3D*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I9"`B0V]U
M;G1R>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C<S"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I
M9"`B0W)E871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B0W)E871E(&$@
M;&EN:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES
M96QE8W0N:6YC.CDT"FUS9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR
M"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-#`*;7-G:60@(D-R96%T;W(@
M4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S(S,`IM<V=I9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<Y"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C(V"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HT.`IM<V=I9"`B0W5R<F5N="!3
M97-S:6]N<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,R!L
M:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E;G0@5&EM92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS,PIM<V=I9"`B0W5R<F5N="!5
M<V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS
M9VED(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(W-0IM<V=I9"`B0W5R<F5N="!C;VYD:71I
M;VXZ("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O
M("5S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,U
M"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*
M;7-G:60@(D-Y<')U<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X,@IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(D-Y<FEL;&EC("A7
M:6YD;W=S+3$R-3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@T"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0U,2!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B1$0B"FUS
M9W-T<B`B[>;C("T@T=[C[>0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,C@Q"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T
M+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N
M86YC92YP:'`Z-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(NWFX^TB"@HC.B!A
M9&UI;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W.0IM
M<V=I9"`B1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,Y.0IM<V=I9"`B1&%T92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T
M92!296-E:79E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.#`W"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDR(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS,C(*(RP@9G5Z>GD*;7-G:60@(D1A>2(*;7-G
M<W1R("+MYN/M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,V"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#$R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-3`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I
M9"`B1&5C:6UA;"!N=6UB97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C`*;7-G:60@(D1E8W)E87-E
M($EN9&5N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C$X-R!L:6(O<')E9G,N<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I9"`B
M1&5F875L="(*;7-G<W1R("+'X<K-WMX@Q^''W<K1Q];M(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-S<*(RP@9G5Z>GD*
M;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`BQ]/*SL_C(,?AWNWC(,?A
MQ=W*T<?6[<DB"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP
M.CDQ"FUS9VED(")$969A=6QT($ED96YT:71Y(@IM<V=S='(@(L?ARLW>WB#'
MX<?=RM''UNTB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C<*(RP@9G5Z
M>GD*;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`BQ^'*S=[>(,?AQ]W*
MT<?6[2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B1&5F
M:6YI=&EO;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW,2!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,"!T96UP;&%T97,O861M:6XO
M=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS,@IM<V=I9"`B1&5L971E($-E;&PB"FUS9W-T<B`B(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR,C<*;7-G:60@(D1E
M;&5T92!'<F]U<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR-#D*;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-R!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$P,0IM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E(&-E;&PB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV,PIM<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L
M=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C0R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE
M=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B!A;F0@86YY('-U
M8BUP97)M:7-S:6]N<S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E
M(')O=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E
M;G1I='DN:6YC.C$U"B,L(&9U>GIY"FUS9VED(")$96QE=&4@<V5L96-T960@
M:61E;G1I='DB"FUS9W-T<B`BQ^'*S=[>(,?AQ]W*T<?6[2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM
M<V=I9"`B1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C,*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-38S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(R,0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*;7-G:60@(D1E;&EV97)Y('1I
M;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&5N;6%R:R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHR.0IM
M<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`BU-'-(,?AX]3?
MX<DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,S@@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`HC+"!F=7IZ
M>0IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`BQ^'4T<T@Q^'*W=7MX>TZ
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.34*;7-G:60@(D1E
M=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3D*;7-G:60@(D1E=&%I
M;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM
M<V=S='(@(LKC(,W=V2#'X<K=Q]7MX2#AX\_MT2#'X>39Q^,B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C$Y"FUS9VED(")$979E;&]P;65N="(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-PIM<V=I9"`B
M1&5W(%!O:6YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,CDT"FUS9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C<*;7-G:60@
M(D1E=R!P;VEN=#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L969T
M('1O(')I9VAT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T
M;R!L969T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y
M"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(V-@IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<*;7-G:60@
M(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R("+.[<?1Q\H@Q^':T=8B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@
M(D1I<W!L87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`BSNW'T<?*(,?A
MVM'6(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX-0IM<V=I9"`B1&ES<&QA
M>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.#$W"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(&9O<FUA
M="(*;7-G<W1R("+.[<?1Q\H@Q^':T=8B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TU$3BYP:'`Z,3DP"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC871I
M;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&II8F]U=&DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(*
M;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C
M97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R("+AQR#*S\[A(./(Q]31R?`@
MQ>'L(,?AX^'=(&UA:6YT96YA;F-E+G!H<"(*"B,Z('1E;7!L871E<R]D871A
M+W1S=FEN9F\N:6YC.C$R('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$R
M"FUS9VED(")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@
M;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-CD*;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HW,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S`*;7-G:60@(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDV"FUS9VED(")$;VXG="!H879E
M(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T-`IM<V=I9"`B1&]W;FQO860B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z.#0T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E
M<R(*;7-G<W1R("+#X]$@V^W1(./:T>;=("5S.B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ-C(*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF
M:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#<*;7-G:60@(D1R;W`@9&]W;B!L:7-T
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-`IM<V=I
M9"`B1')U9W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$S"B,L(&9U>GIY"FUS9VED(")%+4UA:6PB"FUS9W-T<B`B
MQ^'(T>W/(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT
M<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@
M9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-2!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-CD@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S
M.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,2!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z-S(*(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET
M+FEN8SHR-0IM<V=I9"`B161I="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO54DN<&AP.C4P('1E;7!L871E<R]P;W)T86PO961I="YI
M;F,Z,C4*;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T<B`B(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H<#HR,C8*;7-G:60@(D5D
M:70@1W)O=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HW-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,`IM
M<V=I9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHU"FUS9VED
M(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%
M9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%:71H97(@96YA8FQE(&ET('1H96XZ("5S+"!O<B!U<V4@=&AE(&)A
M<VEC($A434P@=F5R<VEO;CH@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED
M(")%;&5M96YT+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-CD*;7-G:60@(D5M86EL(@IM
M<V=S='(@(L?AR-'MSR#'X<7AW\K1YN3M(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-C4@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E
M9&ET+FEN8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C8X"B,L(&9U>GIY"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(MKD
MYL?D(,C1[<_?(,?AQ>'?RM'FY.TZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3DV,PIM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.#D*
M(RP@9G5Z>GD*;7-G:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S
M='(@(N/:X>;CQ\H@PL[1["(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G
M96YE<FEC7W-M='`N<&AP.CDQ"FUS9VED(")%;6%I;"UT;RU335,@1V%T97=A
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,CDX"B,L(&9U>GIY"FUS9VED(")%;6]T:6-O;G,B"FUS9W-T
M<B`BSNW'T<?*(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`R"B,L(&9U>GIY"FUS9VED(")%;7!T>2!M97-S86=E
M+B(*;7-G<W1R("+AQ\KFS,\@Y,K'QLPN(@H*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV
M-C(@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S
M=6QT+B(*;7-G<W1R("+AQ\KFS,\@Y,K'QLPN(@H*(SH@9G)A;65W;W)K+U-1
M3"]344PO2V5Y=V]R9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E
M<FUS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#,*
M;7-G:60@(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@
M1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,3@*;7-G:60@(D5N86)L92!R:6=H="!C;&EC:R!C;VYT
M97AT(&UE;G4_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(U.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,0IM<V=I9"`B
M16YD('EE87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%9&ET;W(B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R,0IM<V=I9"`B
M(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B
M92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D
M+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE(&EM86=E(%523"!H
M97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HX.3$*;7-G:60@(D5N=&5R('1H92!L971T97)S(&)E;&]W
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDY
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")%<75A=&]R:6%L($=U
M:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%<FET<F5A(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C0U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU
M-0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,V('-E<G9I8V5S+W!O<G1A;"]I
M;F1E>"YP:'`Z.#(*;7-G:60@(D5R<F]R(@IM<V=S='(@(L[8PR(*"B,Z(&9R
M86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8S"B,L('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP
M:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&=E='1I;F<@8V]N
M=&5N=#H@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T:6YG
M('!A<W-W;W)D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I
M=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B17-T;VYI82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%=&AI;W!I82(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T:&YI
M8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-34*;7-G:60@(D5U<F]P92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S,Y"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@
M(M_A(#$U(,_>[=[)(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X.0HC
M+"!F=7IZ>0IM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(M_A(#4@
MS][MWLDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,V(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.#<*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS
M9W-T<B`BW^$@,S`@S][MWLDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S,X(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3`*;7-G:60@(D5V97)Y(#4@
M;6EN=71E<R(*;7-G<W1R("+?X2`U(,_>[=[)(@H*(SH@9G)A;65W;W)K+TUA
M:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G
M:6XB"FUS9W-T<B`BW^$@S\[FX2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-#`*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R("+?X2#DU=T@
MT\?:R2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S<@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,X.`IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@
M(M_A(,_>[=[)(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C0*
M;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R("+#X\OAR2#:X>P@Q^'>
M[>,Z(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C@Q(&%D;6EN+V-M9'-H96QL
M+G!H<#HU,"!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(W"B,L(&9U>GIY"FUS9VED
M(")%>&5C=71E(@IM<V=S='(@(LKDW>W0.B(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C0W-0IM<V=I9"`B17AP86YD(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S(*;7-G:60@
M(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO
M4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3<U
M"FUS9VED(")%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T
M97)M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<V"FUS9VED(")%
M>'!O;F5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,Q"FUS9VED(")&1R!#;VQO<B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS9VED(")&
M5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]S<6PN<&AP.C(Q-@IM<V=I9"`B1F%I;&5D(')E=')I979I
M;F<@<')E9F5R96YC97,N(@IM<V=S='(@(N''Q>/?Q^3MR2#AX=K+YM$@VN'L
M(,?ARMW6[>''RBXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B
M1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(N''
MQ>/?Q^3MR2#AX<7*U<?A(,C'X>/.S^,@3$1!4"XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W-M8BYP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T
M('1O(%--0B!S97)V97(N(@IM<V=S='(@(N''Q>/?Q^3MR2#AX<7*U<?A(,C'
MX>/.S^,@4TU"+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C@V
M"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C8Y,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O
M<'D@=&\@7"(E<UPB+B(*;7-G<W1R("+AQ\7CW\?D[<D@X>'%RM7'X2#(Q^'C
MSL_C(%--0BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@W
M"FUS9VED(")&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DW
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S(T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S
M='(@(N''Q>/?Q^3MR2#AX<7*U<?A(,C'X>/.S^,@4TU"+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")&86EL960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(N''Q>/?
MQ^3MR2#AX=K+YM$@VN'L(,?ARMW6[>''RBXB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<R"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV
M:6YA<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C,X
M"B,L(&9U>GIY"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`BS=7A(,[8
MPSHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3@W"FUS9VED(")&87@B"FUS9W-T<B`BW<??TR(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS-#D*(RP@9G5Z>GD*;7-G:60@(D9A>&5S(@IM<V=S
M='(@(MW'W],B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,C`*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,0IM<V=I9"`B
M1F5E;',@;&EK93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$Y"FUS9VED(")&97<@4VAO=V5R<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR,`IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30T"FUS9VED(")&:65L9"!M871R
M:7@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S
M-`IM<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S,S.`IM<V=I9"`B1FEG;&5T(&9O;G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEJ:2(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G
M:60@(D9I;&4B"FUS9W-T<B`BQ^'AWL@B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E
M<R!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#<*
M;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8S(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S`*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HX-0HC+"!F=7IZ>0IM<V=I9"`B1FEL92!.86UE(@IM
M<V=S='(@(L?AQ]/C(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDY
M-0IM<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,30X-@IM<V=I9"`B1FEL92!U<&QO860B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4Y
M"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Y"FUS9VED(")&:6QT
M97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D9I;FQA;F0B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V-@IM<V=I9"`B1FER
M<W0@2&%L9B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@
M;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R=&5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR-38*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,Q"FUS9VED(")&
M;&EP(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS
M9VED(")&;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$P-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(V"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P
M;W)T(&EM86=E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,S-`IM<V=I9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<Y"FUS9VED("(B"B)&;W)E8V%S
M="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R
M;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E
M(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3`R"FUS9VED(")&;W)G;W0@
M>6]U<B!P87-S=V]R9#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0V,@IM<V=I9"`B1F]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"FUS9VED(")&;W)T=6YE(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N
M92!T>7!E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M.`HC+"!F=7IZ>0IM<V=I9"`B1F]R='5N97,B"FUS9W-T<B`BX^''S=G'RB(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@
M,B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4S
M"FUS9VED(")&;W)U;7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$P.0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,`IM<V=I
M9"`B1G(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PHC+"!F=7IZ>0IM<V=I9"`B1G)A;65S
M(@IM<V=S='(@(L?AQ]/C(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM
M<V=I9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-#@@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,V,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`V
M"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z-#@*(RP@9G5Z>GD*;7-G:60@(D9U;&P@1&5S
M8W)I<'1I;VXB"FUS9W-T<B`BQ^'4T<T@Q^'*W=7MX>TZ(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@
M(D9U;&P@36]O;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV,`HC+"!F
M=7IZ>0IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(L?3X]\Z(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,PIM<V=I9"`B1V%B;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,P"FUS9VED
M(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*
M;7-G:60@(D=A;6)I82(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@(D=E;F5R871E("5S($-O
M;F9I9W5R871I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E
M='5P+V-O;F9I9RYH=&UL.C@*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<U"FUS9VED(")':&%N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED
M(")':6)R86QT87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-S4*;7-G:60@(D=I=F5N($YA;64B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3(*;7-G:60@(D=O(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,`IM<V=I9"`B
M1V]E9&5L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,3(X"FUS9VED(")';V]G;&4@36%P<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G;V]G
M;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")';V]G
M;&4@4V5A<F-H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,S<*;7-G:60@(D=R87ES8V%L92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W)E96-E(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED(")'<F5E:R`H25-/+3@X
M-3DM-RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W)E96YL86YD
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=R96YA9&$B"FUS9W-T
M<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-SD*;7-G:60@(D=R;W5P($%D
M;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"YP:'`Z-3D@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$V
M.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,P-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D
M(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q
M."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3(T"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M,S,X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G
M<F]U<"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C,Q-"!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.`HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S<*;7-G:60@(D=U86TB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'=65R;G-E>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(R-B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED(")'=65S="!097)M:7-S:6]N
M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<P
M"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.CDY"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I
M9"`B1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5I
M;F5A+4)I<W-A=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U
M>6%N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY
M-C`*;7-G:60@(DA434PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R
M96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I
M;B!R;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R
M9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L
M92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@
M<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.C$U-PIM
M<V=I9"`B2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2&%I=&DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")(87-H
M+4%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR,@IM<V=I9"`B2&%Z92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,3D@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,CDS,@IM<V=I9"`B2&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-C$*;7-G:60@
M(DAE861E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(96%R
M9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C,*;7-G:60@
M(DAE879Y(%0M4W1O<FTB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#8*;7-G:60@(DAE8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,T"FUS9VED(")(96EG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$W.2!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O2&5L<"YP:'`Z,3@V"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP
M.C$W('1E;7!L871E<R]H96QP+VEN9&5X+FEN8SHS"FUS9VED(")(96QP(@IM
M<V=S='(@(L?AX]/'VL_)(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W,0HC+"!F
M=7IZ>0IM<V=I9"`B2&5L<&5R(@IM<V=S='(@(L?AX]/'VL_)(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$P('1E;7!L871E
M<R]D871A+V-S=FEN9F\N:6YC.C$P"FUS9VED(")(97)E(&ES('1H92!B96=I
M;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"FUS9VED(")(:6=H(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T
M97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B
M2&]?;64B"FUS9W-T<B`BQ^'(S\?MR2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@
M(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34S-0IM<V=I9"`B2&]M92(*
M;7-G<W1R("+'X<C/Q^W)(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$R,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,34U"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`B
MVN3FQ^0@Q^'CY-+A(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8T"FUS
M9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H
M;VYE(@IM<V=S='(@(N7'RMT@Q^'CY-+A(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED
M(")(;VYD=7)A<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO
M;F<@2V]N9R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-C4*;7-G:60@(DAO<F1E(@IM<V=S='(@(N7FT<_M(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HT-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@
M:6X@;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT,S4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E
M("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C4P"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR,C,*
M;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E
M<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-3`S"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!8
M34P@=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z,3(T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#<T"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T
M<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q.3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O
M;FES92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,3,S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS-#`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@
M7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@4G5L92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM
M<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q"FUS9VED(")(
M;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L
M:6ME('1O(&UE<F=E/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS
M*2!A<F4@=&AE<F4_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY
M(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,S`*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3D*;7-G:60@(DAU;6ED:71Y
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS
M9VED(")(=6UO<FES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED
M(")(=6YG87)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER=7,N<&AP.C$W,B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z
M,C,U"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO
M;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER=7,N<&AP.C(Q-"!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP
M:'`Z,CDU"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE
M=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER=7,N<&AP.C$W.2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q
M;"YP:'`Z,C0R"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q
M=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$S,38*(RP@9G5Z>GD*;7-G:60@(DE0($%D
M9')E<W,B"FUS9W-T<B`BQ^':Y.;'Y"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D9')E<W,@;F]T(&%V86EL
M86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A
M<VEC+G!H<#HX.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W
M960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))4"!L;V-K
M9&]W;B!V:6]L871I;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.0IM<V=I9"`B25]N
M<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I
M9"`B26-E;&%N9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S<V"FUS9VED("))8V]N<R!/;FQY(@IM<V=S='(@(L/MWN;DQ\H@W=[8
M(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M870*
M;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S<W"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T
M<B`BP^W>YN3'RB#CVB#DU>;5(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Y,`IM<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL
M("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4U"FUS9VED("(B"B))9B!Y;W4@
M9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@
M>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F
M(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ-S,*;7-G:60@(B(*(DEF('EO
M=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO
M=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U
M<B!B<F]W<V5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*;7-G:60@(DEM86=E
M(%!R979I97<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM86=E(%523#HB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDZ
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C$*
M;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T
M96UA<"YI;F,Z-PHC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4T('1E
M;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("+'X<W>YN$@Q^'C
MT\KFT<_).B`E<R(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C$V
M"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G
M<W1R("+'X<W>YN$@Q^'CT\KFT<_).B`E<R(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS9W-T
M<B`BQ^'-WN;A(,?AX]/*YM'/R3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@
M4F]W($%F=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]Z:7`N<&AP.C$S-0IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C
M;V1E(&=I=F5N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@HC+"!F=7IZ>0IM<V=I9"`B26YC
M;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`BSMC#
M(-WM(,?3XR#'X>/3RL[/XR#F+\/F(-_AX\D@Q^'3T2XB"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R96-T('5S
M97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N
M=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE
M<B!H96QP+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S92!);F1E;G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,38@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("));F1I82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U-"!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*(RP@9G5Z>GD*;7-G:60@(DEN
M9&]N97-I82(*;7-G<W1R("+*XR#(Y,S'S2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(DEN9F\B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U-PHC+"!F=7IZ
M>0IM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`BR.W'Y,?*WSHB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S,P"FUS9VED("));F9O<FUA
M=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*
M;7-G:60@(DEN<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR,`IM<V=I9"`B26YS97)T($EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN
M<V5R="!486)L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED("));G-E<G0@5V5B($QI;FLB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED("));G-E<G0@7T-O;'5M;B!"969O
M<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED("));G-E<G0@82!N97<@8V]L
M=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*
M;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT
M(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R
M;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM
M<V=I9"`B26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHW,`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H
M(&%F=&5R('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS
M9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO
M9&4B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G
M:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S.0IM<V=I9"`B26YS97)T(&%N(&5M
M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@
M<&%S<W=O<F0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL
M(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R="!C96QL(&)E
M9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L=6UN(&%F
M=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F
M;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.CDP"FUS9VED("));G-E<G0@;65S<V%G97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C0U"FUS9VED("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!B969O<F4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(')O=R!A9G1E<B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E9F]R92(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,P"FUS9VED("));G-E
M<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I
M;VXZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C0S"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE
M(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS
M=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3`W-0IM<V=I9"`B26YT96=E<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3,S"FUS9VED("));G1E9V5R
M(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("));G9A;&ED(%5$2"X@*%5S
M97(@1&%T82!(96%D97(I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ-S`*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+WII<"YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]Z:7`N<&AP.C(Q,`IM<V=I9"`B26YV86QI9"!:25`@9&%T
M82(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T"B,L
M(&9U>GIY"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R("+'
MX<K8R.W>Q\H@Q^'CYLSFS\DZ("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED("));G9A;&ED(&)A
M=&-H($E$+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,#@W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-3@*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C(S,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,CDY"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP
M:'`Z,S<*;7-G:60@(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P,`IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X
M+G!H<#HX,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H
M<#HQ,#`*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z
M,C(P"FUS9VED("));G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S<*;7-G:60@(DEN=F%L
M:60@;&EC96YS92!K97DN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-S$*;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O
M=FED960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?='EP
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`S"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@
M87!I7VED+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.38*;7-G:60@(DEN=F%L:60@;W(@;6ES
M<VEN9R!P87)A;65T97)S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]A
M9&1C:&EL9"YP:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I
M;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-S,*;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-0IM<V=I9"`B26YV
M86QI9"!P<F]D=6-T(&-O9&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B26YV
M86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY,PHC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C<Q(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI
M9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C$P-S8@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HQ,C8R"FUS9VED("));G9A;&ED('-H87)E(&]B:F5C="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#$*;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q,0IM<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3<*;7-G:60@(DEN
M=F5N=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-C<Y"FUS9VED("));G9E<G0@<V5L96-T:6]N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B27)A;BP@27-L86UI8R!2
M97!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DER
M87$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<F5L86YD(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$U"FUS
M9VED("))<VQE(&]F($UA;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O;&%T960@5"U3
M=&]R;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<W)A96PB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV,C4*;7-G:60@(DES<W5E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET86QI8R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*(RP@9G5Z>GD*;7-G:60@(DET86QY
M(@IM<V=S='(@(NWFX^TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I8V$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@S"FUS9VED(")*87!A;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X-PIM<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`IM<V=I
M9"`B(@HB2F%V87-C<FEP="!H87,@8F5E;B!D:7-A8FQE9"!O;B!Y;W5R(&)R
M;W=S97(@86YD('1H:7,@<&%G92!M87D@;F]T(&)E("(*(F1I<W!L87EI;F<@
M8V]R<F5C=&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R,@IM<V=I9"`B2F5R<V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,PIM<V=I9"`B2F]R9&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,#<*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C<P"FUS9VED(")*=6YE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I
M9GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,30*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M-@IM<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#8*;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(V-`IM<V=I9"`B2V5E<"!O
M<FEG:6YA;#\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP
M.C@U"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(L?AX\[/XR#?[='([='FTR#1W=8@Q^'*S=[>(./D
M(,?AY>;MR2XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@
M(DME<FYE;"!.97=B:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q-`IM
M<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,3$*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3DX"B,L(&9U>GIY"FUS9VED(")+97D@
M57-A9V4B"FUS9W-T<B`BS<SC(,?AQ]/*SL_'XSHB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW-#`*;7-G:60@(DME>2!A;')E861Y(&5X
M:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@1&5M;V-R871I8R!096]P;&4G
M<R!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@
M(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X.`IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*(RP@9G5Z>GD*;7-G:60@(DQA
M7WEO=70B"FUS9W-T<B`BSM'FS"(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(L?AX=O)(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@W"FUS9VED("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U
M8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS
M9VED("),87-T($AA;&8B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C<V"FUS9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN
M<&AP.C@X"FUS9VED("),87-T(%%U87)T97(B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ-3$*;7-G:60@(DQA<W0@57!D871E9#HB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<R,0HC+"!P:'`M9F]R;6%T"FUS
M9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q-@IM<V=I9"`B3&%S="!L;V=I;CH@
M3F5V97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),871V:6$B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED
M("),87<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<Y"B,L(&9U>GIY"FUS9VED("),87EO=70B
M"FUS9W-T<B`BSM'FS"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),96)A;F]N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHV.0IM<V=I9"`B3&5F="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$Y"FUS9VED("),969T(&AE861E<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$U"B,L
M(&9U>GIY"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R("+#X\OAR2#:X>P@
MQ^'>[>,Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),97-O=&AO(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ
M>0IM<V=I9"`B3&5V96PB"FUS9W-T<B`BP\C/Q_`B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*
M;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED
M("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM<V=I9"`B3&EG
M:'0@1')I>GIL92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR-@HC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@4F%I
M;B(*;7-G<W1R("+/SN;A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM<V=I9"`B3&EG
M:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@(DQI9VAT(%)A:6X@=VET
M:"!4:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H="!3;F]W(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R
M"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,30*(RP@9G5Z>GD*
M;7-G:60@(DQI;FLB"FUS9W-T<B`BS\[FX2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B3&EN
M:R!P;VEN=',@=&\Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$X-S4*;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@
M=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H=&UL,G1E>'0N<&AP
M.C$X,PIM<V=I9"`B3&EN:W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0V"FUS9VED("),:6YU>"!#;V]K:64B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G
M:60@(DQI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,S"FUS9VED("),:7-T($1A=&%B
M87-E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU
M,`IM<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R("+>Q\;CR2#:Y,?F
M[>0@Q^'CT\?:S\DB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,R"FUS9VED
M("),:7-T(%1A8FQE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4Y-`IM<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3@Y
M"B,L(&9U>GIY"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`BWL?&X\D@VN3'
MYNWD(,?AX]/'VL_)(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S
M+G!H<#HU.38*;7-G:60@(DQI<W0M260B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3(*;7-G:60@(DQI<W0M3W=N
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S
M+G!H<#HU.3,*;7-G:60@(DQI<W0M4&]S="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,0IM<V=I9"`B3&ES="U3
M=6)S8W)I8F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](
M96%D97)S+G!H<#HU.3`*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4P"B,L('!H<"UF;W)M870*
M;7-G:60@(DQI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3&ES=&EN9R!U<V5R<R!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN
M9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C0W"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.#,*(RP@
M9G5Z>GD*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`BRLWC[>$@Q^'CW\K(
MQ\HN+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Q"FUS
M9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C@S"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S$@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8T"B,Z(&QI8B]";&]C:R]S=6YR
M:7-E+G!H<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP.C8U"FUS9VED("),;V-A
M=&EO;B(*;7-G<W1R("(B"@HC.B!L;V=I;BYP:'`Z,3<R('-E<G9I8V5S+W!O
M<G1A;"]S:61E8F%R+G!H<#HQ.3$@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI
M;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-2!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.CDP"FUS9VED("),;V<@:6XB"FUS9W-T<B`B
MS\[FX2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I
M9"`B3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3@U"FUS9VED("),;V<@
M;W5T(@IM<V=S='(@(L[1YLPB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-3D*(RP@9G5Z>GD*;7-G:60@(DQO9VEN(@IM<V=S='(@(L_.YN$B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W"B,L(&9U>GIY"FUS9VED("),;V=I
M;B!487-K<R(*;7-G<W1R("+'X>/EX\?*(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z.3DV"B,L(&9U>GIY"FUS9VED("),;V=I;B!F86EL960@8F5C
M875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN
M8V]R<F5C=&QY+B(*;7-G<W1R("(B"B+-U>$@SMC#(.'3R,@@X\<@P\ODQ\$@
MQ^'/SN;A+B#:X>P@Q^'#T<S-(,/D(,?3XR#'X>/3RL[/XR##YB#?X>/)(,?A
MX]'FT>'MT\H@(@HBU<WMS<DB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HY.3(*(RP@9G5Z>GD*;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`B
MW=3A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-0HC+"!F=7IZ
M>0IM<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@(L[1YLPB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@(DQO=F4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@
M(DQO=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L:7-T='EP95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L
M971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN
M(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M
M86X@;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQU
M>&5M8F]U<F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#,X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS
M9VED(")-32(*;7-G<W1R("+4Y=$@+2#1WN/MY"(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR.#$*;7-G:60@(DU/5$0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@
M(DU3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C86\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDQ"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-
M861A9V%S8V%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT.0HC+"!F=7IZ>0IM<V=I9"`B36%G:6,B"FUS9W-T<B`BQ^'(T>W/(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Q"FUS9VED(")-86EL(@IM
M<V=S='(@(L?AR-'MSR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU
M,C(*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED
M(")-86ME(&QI;E]K+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F
M=7IZ>0IM<V=I9"`B36%L87=I(@IM<V=S='(@(L?AR-'MSR(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-0IM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT
M"FUS9VED(")-86QD:79E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*(RP@
M9G5Z>GD*;7-G:60@(DUA;&DB"FUS9W-T<B`BQ^'(T>W/(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDT"B,L(&9U>GIY"FUS9VED(")-86QT82(*;7-G<W1R("+'X<C1[<\B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$*;7-G:60@(B(*(DUA;F%G92!T
M:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US
M('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E(&-A
M=&5G;W)I97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,34S"FUS9VED(")-87`R-"!M87`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$P.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$Q-C@*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T
M;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*
M(RP@9G5Z>GD*;7-G:60@(DUA<F=I;B(*;7-G<W1R("+*Y,CMY2(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-
M87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA
M<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%R<VAA;&P@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA<G1I;FEQ
M=64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ
M,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R("+CV,?(WLD@Q^'-
MWN;A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-875R:71A;FEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#@*;7-G:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P-@IM<V=I9"`B36%X('1E
M;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,CDX"FUS9VED(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z("(*
M;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HX-@IM<V=I9"`B36%X:6UU;2!.
M=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HX.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3(Q-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y"FUS9VED(")-
M87AI;75M(&QE;F=T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3<*;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P"FUS9VED(")-961I8VEN92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V
M"B,L(&9U>GIY"FUS9VED(")-96UB97)S(@IM<V=S='(@(N/0W]''RB(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S@*;7-G:60@(DUE;G4@;6]D93HB
M"FUS9W-T<B`BYM;:(,?AX]#?T<?*.B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E
M;&QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E(@IM<V=S='(@
M(M'3Q^')(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR
M,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U
M="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E
M<FEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*(RP@9G5Z>GD*;7-G:60@(DUE<W-A
M9V4@97AP:7)E9"XB"FUS9W-T<B`BT=/'X<DB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V.0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"B,L
M(&9U>GIY"FUS9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`BT=/'X<DB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E871H97(B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B
M365T87(@8FQO8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ,3(*(RP@9G5Z>GD*;7-G:60@(B(*(DUE=&%R
M(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E
M9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(LKC(,W=V2#'X<K=
MQ]7MX2#AX\_MT2#'X>39Q^,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,38U"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C<@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-`IM
M<V=I9"`B365T:&]D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#
M+WAM;')P8RYP:'`Z.#$@9G)A;65W;W)K+U)00R]24$,O<V]A<"YP:'`Z,3$W
M"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E
M9FEN960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP
M:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D
M+B!#86QL960@;65T:&]D.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-0IM
M<V=I9"`B365T<FEC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B
M365X:6-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")-:6-R;VYE
M<VEA+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@HC+"!F
M=7IZ>0IM<V=I9"`B36ED9&QE(@IM<V=S='(@(L?AR-'MSR(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(")-:6UE
M(%1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3`*
M;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P,@IM<V=I9"`B36EN('1E;7`@;&%S
M="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HT,SD*;7-G:60@(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA
M<R!N;W0@>65T(&5X<&ER960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-`HC+"!F=7IZ>0IM<V=I9"`B
M36ER<F]R(@IM<V=S='(@(L[8PR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU,0IM<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W,@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#`*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-3`*;7-G
M:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q-0IM<V=I9"`B(@HB
M36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I
M="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC871I;VXN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I
M=&%L>5]S;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2
M('!A8VMA9V4@36%I;"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG
M('-E<W-I;VX@240N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW-`IM<V=I9"`B36]B:6QE
M($UA:6PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C@*;7-G:60@(DUO9&5R871E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,PHC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@X"FUS9VED(")-;V1I9FEE9"!$
M871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D:69Y(%523"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W
M,PIM<V=I9"`B36]D=6QU<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G
M:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,`IM<V=I9"`B36]N86-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM
M<V=I9"`B36]N9V]L:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C4Y-`IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU
M-PIM<V=I9"`B36]N=&AL>2(*;7-G<W1R("+4Y='MQ_`B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.30*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N
M(%!H87-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HQ-S(@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C4S"B,L('!H
M<"UF;W)M870*;7-G:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@
M=&AA;B!T:&4@97AP96-T960@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B36]S=&QY($-L96%R
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,T"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,U"FUS9VED
M(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z-3`Y"FUS9VED(")-;W9E($1O=VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$S
M"FUS9VED(")-;W9E($QE9G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$W"FUS9VED(")-;W9E(%)I9VAT(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C4P-0IM<V=I9"`B36]V92!5<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E(&1O
M=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C4R,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E('5P(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-0IM<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@T"FUS9VED(")-=6QT:2UL979E;"!D
M<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-34*;7-G:60@(DUU;'1I;6%P(%5+
M(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,C0R"FUS9VED(")-=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P,`IM<V=I9"`B37D@06-C;W5N
M="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*(RP@
M9G5Z>GD*;7-G:60@(DUY($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B
MR.W'Y,?*WSHB"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C4T"FUS
M9VED(")->2!0;W)T86PB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+V5D:70N<&AP.C$S-@IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUY86YM87(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3<*
M;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$P,@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B3F%M92(*;7-G<W1R("+'
MX<?3XR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW
M"FUS9VED(").971H97)L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM
M<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C
M87!E($)A<V4@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!#02!2979O8V%T
M:6]N(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4X-`IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G:60@
M(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").971S8V%P
M92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C87!E(&-E<G1I
M9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.#`*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC
M871E('1Y<&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(U,0IM<V=I9"`B3F5T=V]R:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,S-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V"FUS9VED(").
M979E<B(*;7-G<W1R("+#R,_'\"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F5W
M($-A;&5D;VYI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G;W)Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O
M96UA:6QS+G!H<#HX,0HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R
M+V5M86EL<RYP:'`Z.#<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E
M<B]E;6%I;',N<&AP.CDW"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT
M97(O96UA:6QS+G!H<#HQ,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W($UE
M<W-A9V4@=&\@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,3<T"FUS9VED(").97<@36]O;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@
M*&]P=&EO;F%L*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(DYE
M=R!:96%L86YD(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B3F5W('!A<W-W;W)D(@IM<V=S
M='(@(M_AX\D@Q^'CT>;1(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN
M<&AP.C(R-PHC+"!P:'`M9F]R;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL
M;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HU,@IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M
M871C:"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(X.0HC+"!F=7IZ>0IM<V=I9"`B3F5W<R(*;7-G<W1R("+CX<?-V<?*(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-0IM<V=I9"`B3F5W<V=R
M;W5P<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN
M8SHQ-2!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT,0HC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHR-0IM<V=I9"`B3F5X="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,C<*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S(@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HS-S8*(RP@9G5Z>GD*;7-G:60@(DYE>'0@
M;W!T:6]N<R(*;7-G<W1R("+:YL_)(,7A["#'X<[MQ]''RB(*"B,Z(&9R86UE
M=V]R:R]522]522]086=E<BYP:'`Z,3`S"FUS9VED(").97AT/B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(DYI9V5R(@IM<V=S='(@
M(L/(S\?P(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<FEA(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.#`*;7-G:60@
M(DYI9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PHC+"!F=7IZ>0IM<V=I
M9"`B3FEU92(*;7-G<W1R("+*Y,CMY2(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(DYO(@IM<V=S='(@(N''
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS9VED
M(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF
M9F5R96YC97,@9F]R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(N<&AP.C$P-0IM<V=I9"`B3F\@879A:6QA8FQE
M('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$S"FUS9VED(").;R!B871C:"!T96UP;&%T92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-SD@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C0U"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C(V-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S
M(&%T('1H92!R97%U97-T960@<&]S:71I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B
M3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`BX<?*YLS/(-_AX\D@X]'FT2#AX<K-WMX@4TU"/B(*
M"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4T"B,L(&9U>GIY"FUS9VED(").
M;R!C:&%N9V4N(@IM<V=S='(@(LK1Q\S:(-KD(,?ARMOM[=''RB(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED(").;R!C:&EL
M9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V-R!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C4P,@HC.B!F<F%M97=O<FLO571I;"]5=&EL
M+G!H<#HW-S,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T
M<B`BX<?*YLS/(./:X>;CQ\H@S>;A(,7:S\?/Q\H@Q^'<(%-13"!61E,N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,C0*;7-G:60@(DYO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93
M+B(*;7-G<W1R("+AQ\KFS,\@X]KAYN/'RB#-YN$@Q=K/Q\_'RB#'X=P@1E10
M(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8V.0IM<V=I
M9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M(%-13"!61E,N(@IM<V=S='(@(N''RN;,SR#CVN'FX\?*(,WFX2#%VL_'S\?*
M(,?AW"!344P@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HW,3<*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(N''RN;,SR#C
MVN'FX\?*(,WFX2#%VL_'S\?*(./AW<?*(%-13"!61E,N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$T"FUS9VED
M(").;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S0*;7-G:60@(DYO(&1E
M<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0G)O=W-E<B]"<F]W<V5R+G!H<#HX-S<*;7-G:60@(DYO(&9I;&4@=7!L;V%D
M960B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q"FUS
M9VED(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$R."!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,C,*;7-G:60@(DYO(&QO8V%T
M:6]N(&ES('-E="XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$V.0HC+"!F=7IZ>0IM<V=I9"`B3F\@;&]C871I;VX@<')O
M=FED960N(@IM<V=S='(@(N'C(.W*XR#*S<_MSR#AV\D@X\WA[<DN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*
M(RP@9G5Z>GD*;7-G:60@(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@
M(N'C(.W*XR#*S<_MSR#AV\D@X\WA[<DN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*(RP@9G5Z>GD*;7-G:60@
M(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R("+AXR#MRN,@RLW/[<\@X=O)
M(./-X>W)+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,W"B,L(&9U>GIY"FUS9VED(").;R!N=6UB97(@<W!E8VEF
M:65D+B(*;7-G<W1R("+AXR#MRN,@RLW/[<\@X=O)(./-X>W)+B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F96YS:79E(&9O
M<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T
M<"YP:'`Z.3$*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+AQ\KFS,\@W^'C
MR2#CT>;1(.'ARLW>WB!,1$%0+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:6UA<"YP:'`Z,3`X"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BX<?*YLS/
M(-_AX\D@X]'FT2#AX<K-WMX@3$1!4"XB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VMR8C4N<&AP.C<R"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(N''RN;,SR#?
MX>/)(./1YM$@X>'*S=[>(-_MT<CMT>;3(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]S87-L+G!H<#HW-R!F<F%M97=O<FLO075T:"]!=71H+VQO9VEN+G!H
M<#HX-`HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-S4*(RP@9G5Z
M>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`BX<?*YLS/(-_AX\D@X]'FT2#AX<K-WMX@
M3$1!4"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A<W-W9"YP:'`Z,3,U
M"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%3
M4U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+AQ\KFS,\@W^'CR2#CT>;1
M(.'ARLW>WB!334(^(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP
M.C@T"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R("+AQ\KFS,\@W^'CR2#CT>;1(.'ARLW>WB!3
M34(^(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C@V
M"FUS9VED("(B"B).;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V
M:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W
M;W)K('=I=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG
M('-I9VYU<',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HW-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0S"B,L(&9U>GIY"FUS9VED(").;R!R=6QE<R(*;7-G<W1R
M("+CX<?-V<?*(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Y
M"B,L(&9U>GIY"FUS9VED(").;R!S97!A<F%T;W(@<W!E8VEF:65D+B(*;7-G
M<W1R("+AXR#MRN,@RLW/[<\@X=O)(./-X>W)+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#0*(RP@9G5Z>GD*
M;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(N/AQ\W9Q\HB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C4X,PIM<V=I9"`B3F\@<W5C:"!F:6QE(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,S@*
M;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C
M86-H92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HR,C$*(RP@9G5Z>GD*;7-G:60@(DYO('5S97)N86UE
M(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R("+.V,,@W>T@Q]/C(,?A
MX]/*SL_C(.8OP^8@W^'CR2#'X=/1+B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#
M+WAM;')P8RYP:'`Z,30P"FUS9VED(").;R!V86QI9"!834P@9&%T82!R971U
M<FYE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.3<Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HY.#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.CDY,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3`P.0IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C`*;7-G:60@(DYO('9E<G-I;VX@
M9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3(X"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N
M9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDS"B,L
M(&9U>GIY"FUS9VED(").;VYE(@IM<V=S='(@(LKC(,CDS,?-(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I9"`B
M3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X.0IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").;W)F;VQK($ES;&%N9"(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K
M+VUO;VXN<&AP.C8P"FUS9VED(").;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)
M<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F]R=V%Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C0P"FUS9VED(").;W0@069T97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@(DYO="!"969O
M<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M-#`X"B,L(&9U>GIY"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B
MQ>34Q\$@Q^'CS.'/("5S(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+G!H<#HV,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX,PHC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y
M+G!H<#HY-`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*;7-G
M:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`HC+"!F=7IZ>0IM<V=I
M9"`B3F]T('-E="(*;7-G<W1R("+CX<?-V<?*(@H*(SH@9G)A;65W;W)K+U-E
M<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#,*(SH@9G)A;65W
M;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-3@*(SH@
M9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ
M-S,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R
M+G!H<#HQ.#<*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(
M86YD;&5R+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,N<&AP.C$Y,`HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,C`U(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(T."!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,C8U"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.#$@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C(Y-PHC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,S$R(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,CD*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C,V,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-#(R
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU,#$@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C4W,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3@W(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HV-C4*;7-G:60@(DYO="!S=7!P;W)T960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HR-#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,#4*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$W.`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B
MX^''S=G'RB(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM
M<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3$*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"B,L
M(&9U>GIY"FUS9VED(").;W9E;6)E<B(*;7-G<W1R("+#R,_'\"(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-#8*(RP@9G5Z>GD*;7-G:60@(DYU
M;6)E<B(*;7-G<W1R("+'X<?3XR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T,C4*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-CD@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30R,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-#0U('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`T"B,L(&9U>GIY"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R
M("+:S\\@Q^'#VN//R2#=[2#'X>/ASM4Z(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3,V-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(Q"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#,@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R
M;W=S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C0T"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I
M960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-C0*;7-G:60@(D]+(@IM<V=S='(@(N/FQ]W>(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B3V)J96-T(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS
M9VED(")/8FIE8W0@0W)E871O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,3`T"FUS9VED(")/8W1A;"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I
M9"`B3V-T;V)E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C8*;7-G:60@(D]F9FEC92(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G
M:60@(D]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V
M"B,L(&9U>GIY"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`BW^'CR2#'
MX>/1YM$B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*(RP@
M9G5Z>GD*;7-G:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS
M9W-T<B`BSMC#(-WM(,?3XR#'X>/3RL[/XR#F+\/F(-_AX\D@Q^'3T2XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@
M24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O
M9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3@U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<Q
M"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B
M(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y
M(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R
M(&$@<VAA<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z
M,S4*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/
M<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG
M;F5D(%,O34E-12!P87)T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P
M96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R871I;F<@4WES
M=&5M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ-3$*;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`BSNW'T<?*(@H*(SH@<V5R
M=FEC97,O<')E9G,N<&AP.C,Q('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$T
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*
M;7-G<W1R("+.[<?1Q\HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G
M:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N86P@
M56YI="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,3,R"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E
M;7!L871E<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T
M96UP;&%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@:6X@
M)7,Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE<B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$P-@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3$S(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C(*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$S,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30Q"FUS9VED
M(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R("+CVN'FX\?*(,+.T>PB"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,Q"FUS9VED(")/=VYE<B!0
M97)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W!A;2YP:'`Z-SD*;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@
M879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C
M:V5N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HQ,C<S"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,Q.0IM
M<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-S$*;7-G:60@(E!'4"!0=6)L
M:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$S-3,*;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8X"B,L(&9U>GIY
M"FUS9VED(")02%`@0V]D92(*;7-G<W1R("+EYM'/[2(*"B,Z(&%D;6EN+W!H
M<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED
M(")032!,:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")032!3:&]W97)S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,Y"FUS9VED(")032!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")032!3;F]W
M(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#$*;7-G:60@(E!-(%-U;B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I
M9"`B4$T@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C(W-`IM<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B
M"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H
M96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDY"FUS9VED(")086MI<W1A;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`Q"FUS9VED(")086QA=2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`Q"FUS9VED(")086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`HC+"!F=7IZ>0IM<V=I9"`B4&%N
M86UA(@IM<V=S='(@(L?AQ]/C(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")087!U
M82!.97<@1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@
M(E!A<F%G=6%Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU,S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,3DY"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,34Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,3@*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW-R!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C0S"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT,C,*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(M_AX\D@Q^'CT>;1(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED(")087-S
M=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,S(R"B,L(&9U>GIY"FUS
M9VED(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`BW^'CR2#'X>/1YM$B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,34R"B,L(&9U
M>GIY"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R("+AQ\KFS,\@W^'CR2#CT>;1(.'ARLW>WB#1
MQ\_MYM,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`U,PIM<V=I
M9"`B4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP"B,L(&9U>GIY"FUS9VED
M(")087-S=V]R9#HB"FUS9W-T<B`BW^'CR2#'X>/1YM$B"@HC.B!T96UP;&%T
M97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O
M<F0Z("(*;7-G<W1R("+?X>/)(,?AX]'FT2(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$U,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#,T"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M
M=7-T(&UA=&-H+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3$Y('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@
M9G)O;2!C;&EP8F]A<F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B
M4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(E!E;W!L92(*;7-G<W1R("+'
MX<_FT2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`W"FUS9VED(")097)C96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED(")097)F
M;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`BRN3=[=`@VN/A
M[<?*(,?AU>W'Y,DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#`V"B,L
M(&9U>GIY"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@
M;VX@;&]G:6X_(@IM<V=S='(@(LKDW>W0(-KCX>W'RB#'X=7MQ^3)(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(E!E<FUI
M<W-I;VXB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@
M9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HU.#8*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38Q(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,38T"FUS9VED(")097)M:7-S:6]N<R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#D@861M:6XO
M<&5R;7,O861D8VAI;&0N<&AP.C8P"B,Z(&%D;6EN+W!E<FUS+VEN9&5X+G!H
M<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X"FUS9VED(")097)M:7-S
M:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-C4*(RP@9G5Z>GD*;7-G:60@(E!E<G-O;F%L($EN9F]R
M;6%T:6]N(@IM<V=S='(@(N/:X>;CQ\H@PL[1["(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM
M<V=I9"`B4&5R=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-34*;7-G:60@(E!E=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS
M9VED(")0:&EL:7!P:6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G
M<W1R("+EQ\K=(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W.`IM
M<V=I9"`B4&AO=&]S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@
M(E!I=&-A:7)N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS9VED(")0;&%T:71U
M9&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O
M('-O;64@8V5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#D*;7-G:60@(E!L96%S92!C
M;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T
M('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U-S$*;7-G:60@(E!L96%S
M92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C$R"FUS9VED
M(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`Q"FUS
M9VED(")0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8P"FUS9VED(")0
M;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F
M(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-#4Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI
M9"!T:6UE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@
M=&AE('!R;V)L96TN(@IM<V=S='(@(L?AT<S'P2#*TN;MS^3'(./ASM4@Q^'C
MU-_AR2XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@(E!L96%S92!P<F]V:61E
M('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM<V=S='(@(L?AT<S'P2#*
MTN;MS^3'(,C'T^,@Q^'CT\K.S^,@YM_AX\D@Q^'3T2XB"@HC.B!S97)V:6-E
M<R]M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(B(*(E!L96%S92!R96%D('1H
M92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R
M;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<P"FUS9VED
M(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&]L86YD(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-PIM<V=I9"`B4&]L:71I8W,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X-PIM<V=I
M9"`B4&]L;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&]R
M='5G86PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W"FUS9VED(")0;W-I=&EO;FEN
M9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN
M9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O('1H:7,@
M9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S
M="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(Y.`IM<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H
M86YC92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O;&1A
M<"YP:'`Z.3@*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N
M.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(U"FUS9VED(")0<F5S
M<W5R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U.0IM
M<V=I9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-0IM<V=I9"`B4')E<W-U
M<F4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C`U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PIM<V=I9"`B4')E=FEE=R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C0*;7-G:60@(E!R979I97<@=&AE(&EM86=E(&EN
M(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C,V,B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C,V-@HC+"!F=7IZ>0IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R
M("+:YL_)(,7A["#'X<[MQ]''RB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R
M,PIM<V=I9"`B4')I=F%T92!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V.0HC+"!F=7IZ>0IM<V=I9"`B4')O
M8FQE;2(*;7-G<W1R(");RM[1[=$@Q^'CU-_AR5TB"@HC.B!S97)V:6-E<R]P
M<F]B;&5M+G!H<#HQ,C8*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS
M9W-T<B`BU-'-(,?AX]3?X<DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S8Y"FUS9VED(")0<F]J96-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,3$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q.#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X-0IM<V=I9"`B
M4')O;7!T('1E>'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED
M(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-`IM<V=I9"`B4'5B;&EC($ME
M>2!);F9O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@
M9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.38@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,@IM<V=I9"`B46%T87(B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C8S"FUS9VED(")1=65R>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-S`*;7-G:60@(E%U;W1A(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C8S"B,L('!H<"UF
M;W)M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C0*;7-G:60@(E)A
M9&EO('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B4F%I;B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM
M<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I;B!,871E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0V"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-PIM<V=I9"`B4F%I
M;B!A;F0@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")286YD
M;VT@1F]R='5N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,S(T('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,S0*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3$T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@P"FUS9VED(")296%D(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C@W"B,L(&9U>GIY"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@
M(M'3Q^')(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX
M"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@
M;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4
M:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T"FUS
M9VED(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")2969R97-H($1Y;F%M:6,@365N=2!%
M;&5M96YT<SHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,T,0IM<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DT(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$R,3,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S
M-0IM<V=I9"`B4F5G97@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S(T.0IM<V=I9"`B4F5L871I;VYS:&EP($)R;W=S97(B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`IM<V=I9"`B4F5L;V%D(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(V"FUS9VED(")2
M96UA<FMS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,30*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM<V=I9"`B4F5M;W1E(%523"`H
M:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B4F5M
M;W9E(@IM<V=S='(@(L72X<D@Q^'+Y,?&[2(*"B,Z('1E;7!L871E<R]P;W)T
M86PO;&%Y;W5T+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E($)L;V-K
M(@IM<V=S='(@(L72X<D@Q^'+Y,?&[2(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HU-3<*;7-G:60@(E)E;6]V92!C;VQU;6XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHT,`HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B
M"FUS9W-T<B`BQ=+AR2#'X<ODQ\;M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHQ,C@*;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@(L72X<D@
MQ^'+Y,?&[2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,#(*;7-G:60@
M(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@
M9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*(RP@9G5Z>GD*;7-G:60@
M(E)E;6]V92!T:&4B"FUS9W-T<B`BQ=+AR2#'X<ODQ\;M(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS
M9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*
M(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!U<V5R(@IM<V=S='(@(L72X<D@Q^'+
MY,?&[2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z-0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z("5S(@IM
M<V=S='(@(L72X<D@Q^'+Y,?&[2(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM
M;')P8RYP:'`Z,3,X"FUS9VED(")297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E
M<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W"FUS9VED(")297%U97-T960@
M<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<T(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z-3$R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U
M:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R("+AXR#MVLO1(-KA["`G<&]R="<@W>T@Q=K/Q\_'RB!61E,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-S4@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HX,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C<R,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q
M=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(N'C(.W:R]$@VN'L("=P;W)T)R#=[2#%VL_'S\?*(%9&
M4RXB"@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW.#$*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF
M:65D(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(N'C(.W:R]$@VN'L("=P
M;W)T)R#=[2#%VL_'S\?*(%9&4RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+U)E;F1E<F5R+G!H<#HS,S4*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,S.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H
M<#HS,C`@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<W"FUS9VED(")297-E="(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT-@HC
M+"!F=7IZ>0IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`BW^'CR2#'
MX>/1YM$B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I
M9"`B4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3,P"FUS9VED(")297-T;W)E($QA<W0@475E<GDB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C<Q(&%D;6EN+V-M9'-H
M96QL+G!H<#HR."!A9&UI;B]S<6QS:&5L;"YP:'`Z-C8*;7-G:60@(E)E<W5L
M=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C$P,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U<FX@
M=&\@3W!T:6]N<R(*;7-G<W1R("+:YL_)(,7A["#'X<[MQ]''RB(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS.`IM<V=I9"`B4F5T>7!E(&YE
M=R!P87-S=V]R9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2
M975N:6]N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O
M;F9I9W5R871I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$S,@HC+"!F=7IZ>0IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/<'1I
M;VYS(@IM<V=S='(@(MKFS\D@Q>'L(,?ASNW'T<?*(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4X"FUS9VED(")2:61D;&5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M,`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$R,0IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3<*;7-G:60@(E)I9VAT
M('9A;'5E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R
M=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(L?AS^;1
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(U"FUS
M9VED(")2;W1A=&4@,3@P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,C(*;7-G:60@(E)O=&%T92!,969T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,C@*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS
M9VED(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W<SHB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU,PHC+"!F=7IZ>0IM<V=I9"`B4G5L97,B"FUS9W-T
M<B`BQ^'/YM$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W
M965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G
M:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E
M96X@<F]W<R!O;FQY(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,C`*;7-G:60@(E)U;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS
M9VED(")2=7-S:6%N($9E9&5R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,PIM<V=I9"`B4G=A;F1A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y<'1O
M9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T
M960@365S<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W-A<VPN<&AP.C@Q"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HU,#0*(RP@9G5Z>GD*;7-G:60@(E--4R!-97-S86=I;F<B"FUS
M9W-T<B`BT=/'X<DB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@
M(E-13"!3:&5L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,C@S"FUS9VED(")344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K
M=7!S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M,S$*;7-G:60@(E-32"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I
M8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,U"FUS
M9VED(")354-#15-3(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$U,PIM
M<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")382(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")386EN="!(96QE;F$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")386EN="!+:71T<R!A;F0@3F5V
M:7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED(")386EN="!,=6-I
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")386EN="!0:65R
M<F4@86YD($UI<75E;&]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G
M:60@(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.3(*;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$W"FUS9VED(")386UO82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`V"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3871E
M;&QI=&4@4')O=FED97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I
M9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T
M86PO;&%Y;W5T+FEN8SHY.`IM<V=I9"`B4V%V92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L('!H<"UF;W)M
M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,C$V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")3879E("5S(@IM<V=S='(@(LW=V2#'X<[MQ]''RB(*"B,Z('1E;7!L
M871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G
M<W1R("+-W=D@Q^'.[<?1Q\HB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,38W"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S
M(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D
M:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.CDS"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@
M<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"FUS9VED(")38V%T=&5R960@
M5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4Y"FUS9VED(")38VEE;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI
M<W0N:6YC.C$V"FUS9VED(")396%R8V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,R,`IM<V=I9"`B4V5A<F-H($5N9VEN97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDW,PIM
M<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT.#0*(RP@9G5Z>GD*;7-G:60@
M(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`BQ\[*T2#*Y-/MWB#'X<K'T>W..B(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")396QE
M8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM
M<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,34V"FUS9VED(")396QE8W0@82!U<V5R('1O
M(&%D9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-C<W"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C,*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R("+'SLK1
M(,KDT^W>(,?ARL?1[<XZ(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-C<X"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]K97EB;V%R9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(B(*(E-E;&5C
M="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO
M=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T
M:&4@=&5X="!A<F5A+B(*;7-G<W1R("+-S\\@Q^'-T>;=+\?AT>/FTB#'X<KM
M(,K1[<_EQR##S^3'Y2X@YN/D(,OC(.WCW^0@Y-/.Y<?FX=7>Y<<@UN/D(,?A
MY-4N(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E
M;&5C="!T:&4@9&%T92!D96QI;6ET97(Z(@IM<V=S='(@(L?.RM$@Q^'=YL?5
MX2#AX<K'T>W..B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0T"FUS
M9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R("+'SLK1(,KD
MT^W>(,?ARL?1[<XZ(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L
M96-T+FEN8SHY,`IM<V=I9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N
M="!T;R!C:&%N9V4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I
M;64N:6YC.C$V"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L
M:6UI=&5R.B(*;7-G<W1R("+'SLK1(,?AW>;'U>$@X>'*Q]'MSCHB"@HC.B!T
M96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H92!T
M:6UE(&9O<FUA=#HB"FUS9W-T<B`BQ\[*T2#*Y-/MWB#'X>;>RCHB"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4W"FUS9VED(")396QE8W0@='=O
M(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`BQ<[*T2#-WN'MY"#CRN/'R^'M
MY"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`V"FUS9VED(")396QE
M8W0@>6]U<B!C;VQO<B!S8VAE;64N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR-#@*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E
M9"!L86YG=6%G93HB"FUS9W-T<B`BQ<[*T2#AV\K?(,?AX]W6X<DZ(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@
M4')O8FQE;2!297!O<G0B"FUS9W-T<B`BP]'3X2#*WM'MT<?P(,CCU-_AR2#-
MU>'*(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$P,SD*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#8*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,38*;7-G:60@(E-E;G-O<CH@(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")3
M97!T96UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R;R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C<P,0IM<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Q"FUS9VED(")397)V97(@9&%T
M82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z,C<*;7-G:60@(E-E<W-I;VX@061M:6XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDR"FUS9VED(")397-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]A<&DN<&AP.C$T-0HC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO
M;G,B"FUS9W-T<B`BS=W9(,?ASNW'T<?*(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C,Q-`IM<V=I9"`B4V5T(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW-@IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL
M;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R
M9V5T(&ET+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3$U"FUS9VED(")3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N
M="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T"B,L(&9U>GIY"FUS9VED(")3970@
M>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P
M=&EO;G,N(@IM<V=S='(@(L?.RM$@RLW/[<L@Q^'5W<W)(.;.[<?1Q\H@Q^'4
MQ]3)(,?AP\[1["XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*(RP@
M9G5Z>GD*;7-G:60@(B(*(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL
M(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB
M9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R("+'SLK1(,K-S^W+(,?AU=W-R2#F
MSNW'T<?*(,?AU,?4R2#'X</.T>PN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HW-0IM<V=I9"`B4V5T=7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*;7-G:60@(E-E='5P('5P9W)A
M9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$X-@IM<V=I9"`B4V5V97)A;"!L;V-A=&EO
M;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-`IM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DV"FUS9VED(")3:&]P<&EN
M9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHT,PHC+"!F=7IZ>0IM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G<W1R("+'
MX>3*[<S)(,?AX\[*U=').B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M-#8*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M
M;W-T(&QI;FMS/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C,R,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,S"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z-C<@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,R!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,34U"FUS9VED("(B"B)3:&]W(&1I9F9E
M<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@
M9V5N97)A=&5D("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3`*;7-G:60@(E-H;W<@;&%S="!L;V=I
M;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3<V-0IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@
M:V5E<"!O<FEG:6YA;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#$S"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(V"FUS9VED(")3:&]W('1A8FQE
M(&]P97)A=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T
M:&4@)7,@365N=2!O;B!T:&4@;&5F=#\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS
M9VED(")3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R
M=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8P"FUS9VED(")3:&]W('1H
M92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4R"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8S"FUS
M9VED(")3:&]W('5P;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I9"`B4VAO=V5R<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU,0IM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4VAO
M=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I
M;FET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HT.#`*;7-G:60@(E-H<FEN:R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW-S0@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z.#,V"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.CDR,B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HY.#0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z,3`T-R!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,#@W
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q,38@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$T.0IM<V=I9"`B4VAR
M:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@
M=V%Y(&9I<G-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-I
M97)R82!,96]N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,C8U"FUS9VED(")3:6=N('5P(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED(")3
M:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HW,3$*;7-G:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C4@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@W(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C@Y-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C$U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S<*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.3,P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C,*;7-G:60@
M(E-I>F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA
M:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS
M9W-T<B`BQ>7CX2#'X=7MQ^3)(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO
M=F%K:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F5N
M:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-30*;7-G:60@(E-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@(E-N;W<@
M4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4V"FUS9VED(")3;F]W(%-H;W=E<G,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*
M;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO
M=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR-S@*;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(X,@IM<V=I9"`B4VYO=R!E<75I=F%L96YT
M(&EN('=A=&5R.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B
M4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G
M:60@(E-O;6%L:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C8P"FUS9VED(")3;VYG<R`F(%!O96US(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C8*;7-G:60@(E-O<G0@;W)D97(@
M<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Q-PHC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-#<*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-C8*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.#D*(RP@9G5Z>GD*;7-G:60@
M(E-O=7)C92!A9&1R97-S(@IM<V=S='(@(MKDYL?D(,?AVN/A(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-34@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H
M25-/+3@X-3DM,RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")3
M;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K
M+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$S"FUS9VED(")3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O
M<F1E<B!I;B!C96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@Q-0IM<V=I9"`B4W!A8V5R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`IM<V=I
M9"`B4W!A8VEN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C:6YG(&%N
M9"!P861D:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")3<&%I
M;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3@*
M;7-G:60@(E-P86TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N
M<&AP.C$T"FUS9VED(")3<&5C:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R
M("+%S\['T2#-T>;=(,['U<DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8Q"B,L(&9U>GIY"FUS9VED(")3<&]R=',B"FUS
M9W-T<B`BQ]/*[=''SR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,30Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I($QA;FMA
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW
M,R!L:6(O0FQO8VLO;65T87(N<&AP.C<T"B,L(&9U>GIY"FUS9VED(")3=&%N
M9&%R9"(*;7-G<W1R("+#S.3/R2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(U.38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C@P.0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B4W1A=&4@;W(@
M4')O=FEN8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P
M+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$U"B,L(&9U>GIY"FUS9VED(")3
M=&]R86=E(&9O<FUA="(*;7-G<W1R("+([<?DQ\K?.B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<R"B,L(&9U>GIY"FUS9VED(")3
M=')E970@061D<F5S<R(*;7-G<W1R("+:Y.;'Y"#'X=KCX2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T
M<FEK971H<F]U9V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(S,PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,PIM<V=I9"`B4W1R:7`@9&]M
M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B
M4W1Y;&4@6T-34UTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T<B`B(@H*
M(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS
M9W-T<B`BX>,@[=K+T2#:X>P@Q^'CT\KCVB`E<RXB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J96-T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,B!F
M<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3<*;7-G:60@(E-U
M8FUI="(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C0Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"!<(B5S7"(@
M=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@;&]G(&EN('5N=&EL('EO=7(@
M(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I
M9"`B4W5B<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,#0*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R
M("+*XR#(Y,S'S2(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y
M<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R
M('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V
M"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE=&5D(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F
M<F]M('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF
M:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU.2!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HU-PIM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S
M879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L('!H<"UF;W)M870*;7-G
M:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O
M=&4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W5D86XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU-@HC+"!F=7IZ>0IM<V=I9"`B4W5M;6%R>2(*;7-G
M<W1R("+'X<[AQ]7)(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS
M9VED(")3=6X@4FES92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5N<FES
M92YP:'`Z-C@*;7-G:60@(E-U;B!3970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-U;FYY
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,38*;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3
M=6YR:7-E+U-U;G-E="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C$U"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.0IM<V=I9"`B4W5N
M<V5T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,3@*;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R
M<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS-S@*(RP@9G5Z>GD*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`BQ]/*[=''
MSR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#8*(RP@9G5Z>GD*;7-G:60@(E-U<FEN86UE(@IM
M<V=S='(@(L?AQ]/C(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU-S0*(RP@9G5Z>GD*;7-G:60@(E-U<FYA;64B"FUS9W-T<B`BQ^''
MT^,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA
M>65N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V"FUS9VED
M(")3>6YC(&QO9R!D96QE=&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-#(*;7-G:60@(E-Y;F--3"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A
M>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-PIM<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G
M:60@(E0M4W1O<FTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8R"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3
M=&]R;7,@16%R;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T
M82]T<W8N<&AP.C$V-@HC+"!F=7IZ>0IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T
M<B`BQ^'AWL@B"@HC.B!F<F%M97=O<FLO54DO54DO5&%B;&4N<&AP.C$S-`HC
M+"!F=7IZ>0IM<V=I9"`B5&%B;&4B"FUS9W-T<B`BQ^'AWL@B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S"FUS
M9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3<*;7-G:60@(E1A8FQE
M(%-E="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P97)T:65S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,T
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1A:7=A
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")486II:VES=&%N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A;GIA;FEA+"!5;FET960@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0HC+"!F=7IZ>0IM<V=I9"`B5&%R9V5T
M.B(*;7-G<W1R("+-S.,@Q^''T\K.S\?C.B(*"B,Z(&-O;F9I9R]H;V]K<RYP
M:'`N9&ES=#HY.38@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X-PIM<V=I
M9"`B5&%S:W,B"FUS9W-T<B`BQ^'CY>/'RB(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")496QE<&AO;F4@3G5M8F5R
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDP"FUS9VED
M(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(Q-`IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,PIM<V=I9"`B
M5&5M<&5R871U<F4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,CDS"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T
M=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HV.#<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@(E1E
M;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S,S-@HC+"!F=7IZ>0IM<V=I9"`B5&5X="(*;7-G<W1R("+DU2#=WM@B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<U"FUS9VED(")497AT($]N;'DB
M"FUS9W-T<B`BY-4@W=[8(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`HC+"!F=7IZ>0IM<V=I9"`B5&5X="!A
M;&EG;B(*;7-G<W1R("+DU2#=WM@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<Q"FUS9VED(")497AT=&]P(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-3D*;7-G:60@(E1H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3DQ"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`Y"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HY.#@*(RP@9G5Z>GD*;7-G:60@(E1H86YK
M('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2XB"FUS9W-T<B`BRN,@Q^'.T>;,
M(,CDS,?-+B`\8G(@+SX@U-_1Q_`@X<?3RL[/Q^/?XR#ET,<@Q^'DV<?C+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(P"FUS9VED(")4:&4@
M1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O
M97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?24U34"])35-0+T)O;VLN<&AP.C$R.3(*;7-G:60@(E1H92!)35-0
M(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT
M96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y
M"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN
M9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ
M.#D@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,#`*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HR,3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HR,C,*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,S0@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HR-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HR-C0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,#,*;7-G
M:60@(B(*(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A
M('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT
M('1O('5S92!097)M:7-S:6]N<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B
M5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*
M(E1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F
M="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C4Q"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY
M(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38Y"FUS9VED("(B"B)4
M:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T
M;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM
M<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@
M;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@
M=&AE(&1A=&%B87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R
M:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q,PIM<V=I9"`B5&AE(&5N
M8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HQ-S4@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S
M971T:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C$V."!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE
M("5S('-E='1I;F=S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HR,3D*;7-G:60@(E1H92!F:6QE(&-A;B!N;W0@8F4@8V]P
M:65D(&]N=&\@:71S96QF+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T
M82]$871A+G!H<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D
M871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@
M:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W
M;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D
M=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O
M('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E
M(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N
M9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I
M;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G
M1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O
M;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E
M<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E
M;B!E9&ET;W(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA
M<R!B965N(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L
M969T+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N
M(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y
M<'1?<&=P.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O341.+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB
M(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E
M('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<W
M"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C
M;VUP;W-E('!A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z-#0Q"B,L(&9U>GIY"FUS9VED(")4:&4@;G5M8F5R(&]F(&9I
M96QD<R!M=7-T(&)E(&YU;65R:6,N(@IM<V=S='(@(NW,R"##Y"#*W^;D(.70
MY2#'X=[MX\D@T=[C+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,3(S,0IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I
M<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+G!H<#HR.3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD
M(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B
M"B)M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D('1O('9I
M97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S
M>7-T96TN(@IM<V=S='(@(B(*(N'C(.W*XR#'X=K+YM$@VN'L(,?AR-'DQ^/,
M(,?AX]/*SL_C(.'%V>7'T2#'X='3Q\;A(./D(.3FVB`H)7,I(-;CY"#DV<?C
MWRXB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-30*;7-G:60@
M(E1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A
M8W1E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L
M969T('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I
M9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C0T-@IM<V=I9"`B5&AE('-E<&%R871O<B!M=7-T
M(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S879E
M9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E
M96X@<F5M;W9E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z,S,P"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R!D
M;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HQ-S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H
M92!T96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S
M='(@(L7D(./AW<?*(%!/(.'AV\D@)7,@V^W1(./FS.;/R2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,S,3$*;7-G:60@(E1H92!T97AT('EO=2!E
M;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I
M9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E
M(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z
M,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T
M:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A
M=&$O1&%T82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP
M:'`Z,3<R"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@
M<V%V960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HT-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-38*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q-2!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,3$Y"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@
M:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R
M;W=S97(N<&AP.C(U"B,L('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E
M8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-S@*(RP@9G5Z>GD*;7-G:60@(E1H
M97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92XB"FUS9W-T<B`BX<?*YLS/
M(,/MR2#*W=;MX<?*+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C,T,@IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N
M(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$T,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@
M66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S="!E
M;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z
M-3,@861M:6XO=7-E<BYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@7"(E<UPB('1O('1H92!S>7-T96TZ
M("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A
M=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H
M92!S>7-T96TZ("(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A
M=&EN9R!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W
M<V5R+T)R;W=S97(N<&AP.C@X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W
M87,@=7!L;V%D960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R
M+T)R;W=S97(N<&AP.C@X.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R
M92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@
M=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*(F%L;&]W960@<VEZ92`H
M)60@8GET97,I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"
M<F]W<V5R+G!H<#HX.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A
M<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A
M<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C,Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN
M9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1&%T82]$871A+VEM8RYP:'`Z,S$*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C@P"FUS9VED("(B"B)4:&5R92!W
M87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P
M<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,S@*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG
M('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@
M(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I
M;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(R"FUS9VED
M("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U
M=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*
M;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R
M:6YG(&9O;&1E<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P
M96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@
M(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q-#4*
M(RP@9G5Z>GD*;7-G:60@(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A
M;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R("+MS,@@P^0@RM_FY"#ET.4@Q^'>
M[>/)(-'>XRXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HQ.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT
M='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A4
M5%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,3,T"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W
M:6YP;&,N8V]M*2`B"B)G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU,34*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO
M+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%0
M22(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O
M;F5I=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL
M;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@
M5F]D869O;F4@271A;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N
M=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB
M5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3<X(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$P-3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3`X-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3$U"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Q.#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3(U-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`U(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S.3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,34U-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#,Y"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C`P-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#(Y(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(P-S@*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C$T.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C(Q"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3`@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C0U-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C4W(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,C@*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$S-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S`V"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,30@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S@R,@IM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V-0IM
M<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$X"FUS
M9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@
M=&AE(&-O;&]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,#DT"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@
M;V-T86P@=F%L=65S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,3(S"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM
M82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY.#D*(RP@9G5Z>GD*
M;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS
M9W-T<B`B[<S((,/D(,K?YN0@Y=#E(,?AWNWCR2#1WN,N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C@S-@IM<V=I9"`B(@HB5&AI<R!F:65L9"!M
M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA
M="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU-C$*;7-G:60@(E1H:7,@9F]R;2!H
M87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AI<R!I<R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HT-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A
M($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@
M>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T
M86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O
M9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T
M96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W
M;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE
M+B(*;7-G<W1R("+MS,@@P^0@[=_FY"#ET,<@Q^'1WN,@P]_(T2#CY"#'X=7=
MT2(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HT
M-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD
M(&=Z:7`@9FEL97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]296=I<W1R>2YP:'`Z,3@Y"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C
M=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E(&UU
M<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(NW,R"##Y"#*W^;D(.70Y2#'X=[M
MX\D@T=[C+B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z
M,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@
M3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*;7-G:60@(E1H=6YD97(B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S-`IM<V=I9"`B
M5&EC:V5T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-#(X('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ
M>0IM<V=I9"`B5&EM92(*;7-G<W1R("+'X>'>R"(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS.#8*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W"FUS9VED(")4:6UE(&9O
M<FUA="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-3,Y"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$P"FUS9VED(")4:6UO<BU,97-T92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C(P"FUS9VED(")4:71L92(*;7-G<W1R("+'X>'>R"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*
M;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C8U-`IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US
M+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I
M(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B5&]D87DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#D*(RP@9G5Z>GD*;7-G:60@(E1O9V\B"FUS9W-T<B`BSM'F
MS"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,PIM<V=I9"`B5&]M
M;W)R;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]N9V$B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<W"FUS9VED(")4;W`B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I9"`B
M5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W.3`*;7-G:60@
M(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(E1U<FMI<V@@*$E33RTX.#4Y
M+3DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U<FMM96YI
M<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K<R!A
M;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM
M<V=I9"`B5'5V86QU(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)
M+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8Y"FUS9VED(")5
M+E8N(&EN9&5X.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ
M-PIM<V=I9"`B55),(@IM<V=S='(@(MKDYL?D(,?AQ>3*T>3MRB(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS
M9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O
M<G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY-PHC+"!F=7IZ>0IM<V=I9"`B55),.B(*;7-G<W1R("+:
MY.;'Y"#'X<7DRM'D[<HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")59V%N9&$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56MR86EN92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,3(*(RP@
M9G5Z>GD*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2XB
M"FUS9W-T<B`BX<<@Q>/?Q^3MR2#AWM''P<D@X\SASR!V9G-R;V]T+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B56YA
M8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN
M9R!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HS.#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C
M:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M("+AQR#%X]_'Y.W)(.'*V^WMT2#'X=/CQ\WMQ\H@X>/AW2!61E,@)7,O)7,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S@U(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E
M<RXB"FUS9W-T<B`BX<<@Q>/?Q^3MR2#ARMOM[=$@Q^'3X\?-[<?*(.'CX=T@
M5D93("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4U
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E
M('1O("5S+B(*;7-G<W1R("+AQR#%X]_'Y.W)(.'AQ<K5Q^$@R./.S^,@4U%,
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C,R"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE
M(&]F(%PB)7-<(BXB"FUS9W-T<B`BX<<@RN;,SR#%X]_'Y.W)(.'*V^WMT2#'
MT^,@(./AW2#'X=P@5D93("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C8X."!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P,38*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C@S-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ
M92!O9B!<(B5S+R5S7"(N(@IM<V=S='(@(N''(,KFS,\@Q>/?Q^3MR2#ARMOM
M[=$@Q]/C("#CX=T@Q^'<(%9&4R`E<R\E<RXB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W-Q;"YP:'`Z-#,U"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T
M;R!344P@<V5R=F5R+B(*;7-G<W1R("+AQR#%X]_'Y.W)(.'AQ<K5Q^$@R./.
MS^,@4U%,+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,Y"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS
M9W-T<B`BX<<@Q>/?Q^3MR2#AX<7*U<?A(,CCSL_C(%-13"XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,C4@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P,0HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y"B,L(&9U>GIY"FUS
M9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`BX<<@RN;,
MSR#%X]_'Y.W)(.'*V^WMT2#'T^,@(./AW2#'X=P@5D93("5S+R5S+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S8U"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@
M7"(E<UPB+B(*;7-G<W1R("+AQR#%X]_'Y.W)(.'>T<?!R2#CS.'/('9F<W)O
M;W0N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S4T(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C(U-@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O
M(&-R96%T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("+AQR#%X]_'Y.W)(.'>
MT<?!R2#CS.'/('9F<W)O;W0N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C$R-`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!6
M1E,@9FEL92XB"FUS9W-T<B`BX<<@RN;,SR#%X]_'Y.W)(.'*V^WMT2#'T^,@
M(./AW2#'X=P@5D93("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z,C@V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@8W)E871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("+AQR#*YLS/
M(,7CW\?D[<D@X<K;[>W1(,?3XR`@X^'=(,?AW"!61E,@)7,O)7,N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C8U"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R("+A
MQR#*YLS/(,7CW\?D[<D@X<K;[>W1(,?3XR`@X^'=(,?AW"!61E,@)7,O)7,N
M(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+W1A<BYP:'`Z-S8*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"FUS
M9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(R-"!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C(Y.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@;F]T
M(&5M<'1Y+B(*;7-G<W1R("+AQR#%X]_'Y.W)(.'>T<?!R2#CS.'/('9F<W)O
M;W0N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW."!A9&UI;B]P97)M<R]D96QE
M=&4N<&AP.C0T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM<V=S='(@(N''(,KFS,\@Q>/?Q^3M
MR2#ARMOM[=$@Q]/C("#CX=T@Q^'<(%9&4R`E<R\E<RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HS,S$@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HS.3(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,Q,2!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S,T"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER
M96-T;W)Y(&ES(&YO="!E;7!T>2(*;7-G<W1R("+AQR#%X]_'Y.W)(.'>T<?!
MR2#CS.'/('9F<W)O;W0N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C,T."!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4R
M"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O
M<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(N''(,7CW\?D[<D@X=[1Q\')(./,
MX<\@=F9S<F]O="XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS
M,S<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,R,@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HS-#,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C,T-`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER
M96-T;W)Y+B(*;7-G<W1R("+AQR#%X]_'Y.W)(.'>T<?!R2#CS.'/('9F<W)O
M;W0N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,3<@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HT,CD*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N(@IM
M<V=S='(@(N''(,7CW\?D[<D@X=[1Q\')(./,X<\@=F9S<F]O="XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(P-PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N
M(@IM<V=S='(@(N''(,KFS,\@Q>/?Q^3MR2#ARMOM[=$@Q]/C("#CX=T@Q^'<
M(%9&4R`E<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS
M,#,@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR.#@*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C$V-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,X,PHC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDQ"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R("+AQR#*YLS/(,7C
MW\?D[<D@X<K;[>W1(,?3XR`@X^'=(,?AW"!61E,@)7,O)7,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-#0*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B!<(B5S7"(N
M(@IM<V=S='(@(N''(,KFS,\@Q>/?Q^3MR2#ARMOM[=$@Q]/C("#CX=T@Q^'<
M(%9&4R`E<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0P
M-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R("+AQR#*YLS/(,7CW\?D
M[<D@X<K;[>W1(,?3XR`@X^'=(,?AW"!61E,@)7,O)7,N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HX,#,*(RP@9G5Z>GD*;7-G:60@(E5N86)L
M92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(N''
M(,7CW\?D[<D@X=[1Q\')(./,X<\@=F9S<F]O="XB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8P,PIM<V=I9"`B56YA8FQE('1O(&5X
M=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z-#4Q(&9R86UE=V]R:R].971?24U3
M4"])35-0+T%U=&@N<&AP.C$Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S
M='(@(N''(,7CW\?D[<D@X=[1Q\')(./,X<\@=F9S<F]O="XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ-C8@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$W,0HC+"!F
M=7IZ>0IM<V=I9"`B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@
M(N''(,KFS,\@Q>/?Q^3MR2#ARMOM[=$@Q]/C("#CX=T@Q^'<(%9&4R`E<R\E
M<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.CDS(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z,3`R"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z-C0X(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.3@*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M(%PB)7-<(BXB"FUS9W-T<B`BX<<@RN;,SR#%X]_'Y.W)(.'*V^WMT2#'T^,@
M(./AW2#'X=P@5D93("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C(W-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,P
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S,*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG
M+B(*;7-G<W1R("+AQR#*YLS/(,7CW\?D[<D@X<K;[>W1(,?3XR`@X^'=(,?A
MW"!61E,@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M.#`@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,@HC+"!F=7IZ>0IM<V=I9"`B56YA
M8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@(N''(,KFS,\@Q>/?Q^3M
MR2#ARMOM[=$@Q]/C("#CX=T@Q^'<(%9&4R`E<R\E<RXB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C0U"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@
M(N''(,7CW\?D[<D@X>'%RM7'X2#(X\[/XR!344PN(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C@S-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E
M860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`BX<<@
MRN;,SR#%X]_'Y.W)(.'*V^WMT2#'T^,@(./AW2#'X=P@5D93("5S+R5S+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-C8*(RP@9G5Z>GD*;7-G:60@
M(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE
M9"DN(@IM<V=S='(@(N''(,KFS,\@Q>/?Q^3MR2#ARMOM[=$@Q]/C("#CX=T@
MQ^'<(%9&4R`E<R\E<RXB"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O
M4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*(RP@9G5Z>GD*;7-G:60@(E5N
M86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R("+AQR#*YLS/(,7CW\?D[<D@
MX<K;[>W1(,?3XR`@X^'=(,?AW"!61E,@)7,O)7,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z-C8Y"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T
M:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(N''(,7CW\?D[<D@X=[1
MQ\')(./,X<\@=F9S<F]O="XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C$Q,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M
M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HR.3,*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I
M<F5C=&]R>2XB"FUS9W-T<B`BX<<@Q>/?Q^3MR2#AWM''P<D@X\SASR!V9G-R
M;V]T+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(Y"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D
M:7)E8W1O<GDZ("5S+B(*;7-G<W1R("+AQR#*YLS/(,7CW\?D[<D@X<K;[>W1
M(,?3XR`@X^'=(,?AW"!61E,@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HR-C<@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-#,*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+AQR#*YLS/(,7CW\?D[<D@X<K;
M[>W1(,?3XR`@X^'=(,?AW"!61E,@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z-C$P(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HR,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!6
M1E,@9FEL92`E<R\E<RXB"FUS9W-T<B`BX<<@RN;,SR#%X]_'Y.W)(.'*V^WM
MT2#'T^,@(./AW2#'X=P@5D93("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z,S(S(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR
M,3,*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0U,B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C@U"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HS,#$*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T
M;R!R96YA;64@5D93(&9I;&4N(@IM<V=S='(@(N''(,KFS,\@Q>/?Q^3MR2#A
MRMOM[=$@Q]/C("#CX=T@Q^'<(%9&4R`E<R\E<RXB"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R("+A
MQR#*YLS/(,7CW\?D[<D@X<K;[>W1(,?3XR`@X^'=(,?AW"!61E,@)7,O)7,N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HU
M.0IM<V=I9"`B56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE
M;G0B"FUS9W-T<B`BV^W1(-['S]$@VN'L(,K1S./)(./3RN3/(,?AYM'/(.70
MQR(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,30Y(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,34R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M("+AQR#*YLS/(,7CW\?D[<D@X<K;[>W1(,?3XR`@X^'=(,?AW"!61E,@)7,O
M)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3<Y"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F
M86EL960I+B(*;7-G<W1R("+AQR#*YLS/(,7CW\?D[<D@X<K;[>W1(,?3XR`@
MX^'=(,?AW"!61E,@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C@Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S@*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$T,PHC+"!F=7IZ
M>0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S
M='(@(N''(,KFS,\@Q>/?Q^3MR2#ARMOM[=$@Q]/C("#CX=T@Q^'<(%9&4R`E
M<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#0Q"FUS9VED(")5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D
M960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`*;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG
M97,B"FUS9W-T<B`BRM''S-H@VN0@Q^'*V^WMT<?*(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PIM<V=I9"`B56YD;V5S
M('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y,`IM<V=I9"`B56YE>'!E8W1E9"!R
M97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,0HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S@*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@T"FUS9VED
M(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E
M<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N
M="YI;F,Z-C$*(RP@9G5Z>GD*;7-G:60@(E5N9FEL960B"FUS9W-T<B`BW=3A
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E5N:6-O9&4@
M*%541BTX*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI=&5D
M($%R86(@16UI<F%T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED
M(")5;FET960@2VEN9V1O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS
M9VED(")5;FET960@4W1A=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*
M;7-G:60@(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-CD@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HW,0IM<V=I9"`B56YI=',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(Y(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0S,`IM<V=I9"`B56YK;F]W;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%022!-
M97-S86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN;W=N(&-L
M:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3D*;7-G:60@(E5N:VYO=VX@
M;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,0HC+"!F=7IZ>0IM
M<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B
MSMC#(-WM(,?3XR#'X>/3RL[/XR#F+\/F(-_AX\D@Q^'3T2XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*
M;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,CDV"B,L(&9U
M>GIY"FUS9VED(")5;FYA;65D(@IM<V=S='(@(L?AQ]/C(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB
M56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]0
M87-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N
M("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA
M+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T
M('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R"FUS
M9VED(")5;G-E="!C;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8X-B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.CDR-@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.CDS,@IM<V=I9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3DW('1E;7!L
M871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHR
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-@IM<V=I9"`B
M57!D871E('5S97(B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ
M-#0@861M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E
M9&ET+G!H<#HR,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S
M"FUS9VED(")5<&=R861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ.3D*;7-G:60@(E5P;&]A9"(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5<&QO
M861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E
M<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T
M=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L:7-T='EP95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N
M=6UB97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U
M87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U
M<G)E;G0Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C0*;7-G:60@(E5S
M92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V
M97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I
M="YI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@(E5S97(B"FUS9W-T<B`BQ]/C(,?A
MX]/*SL_C(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H
M<#HW,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@875T
M:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C(P,PIM<V=I9"`B57-E<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(U,0IM<V=I9"`B57-E
M<B!/<'1I;VYS(@IM<V=S='(@(L[MQ]''RB#'X>/3RL[/XR(*"B,Z('-I9VYU
M<"YP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM
M<V=S='(@(L[MQ]''RB#'X>/3RL[/XR(*"B,Z('-I9VYU<"YP:'`Z,C(*;7-G
M:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T
M:&ES('-I=&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HT-CD*;7-G:60@(E5S97(@86-C;W5N="!N;W0@9F]U;F0B"FUS9W-T<B`B
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$W.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L
M>5]S;71P+G!H<#HY.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HQ-3`@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S,*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS9W-T
M<B`BQ]/C(,?AX]/*SL_C(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N
M=7`N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S
M7"(@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHX-PHC+"!F=7IZ>0IM<V=I9"`B57-E<FYA;64Z
M(@IM<V=S='(@(L?3XR#'X>/3RL[/XR(*"B,Z('1E;7!L871E<R]L;V=I;B]M
M;V)I;&4N:6YC.C@*(RP@9G5Z>GD*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T
M<B`BQ]/C(,?AX]/*SL_C(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B57IB96MI<W1A;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-C,@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,C4U"FUS9VED(")61E,@9&ER96-T;W)Y(&1O
M97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3$X"FUS9VED(")686-A=&EO;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-C8*;7-G:60@(E9A;&ED(&QO8V%T
M:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,S@*;7-G:60@(E9A;&ED:71Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3DW"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(U-0IM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M
M(&YO=RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.#4V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q-S<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@
M)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R
M-#0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,S$V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y
M,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU
M.0IM<V=I9"`B5F%L=65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Q,#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-@IM
M<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3<*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-`IM<V=I9"`B5F%R:6%B;&4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X
M"FUS9VED(")697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA
M>2!H879E(&)E96X@=&%M<&5R960@=VET:"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#`*;7-G:60@(E9E<G-I
M;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R
M-@IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G
M:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L
M('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P
M"FUS9VED(")697)Y($AI9V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM
M<V=I9"`B5FEE="!.86TB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.30*;7-G:60@(E9I971N86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.38R"B,L
M('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W
M96(@<&%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HX,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L
M86YD<RP@0G)I=&ES:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED
M(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(P.0IM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8S"FUS9VED(")6
M:7-I8FEL:71Y.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE
M($ET86QY('9I82!33510(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*
M;7-G:60@(E=!4DXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!214U/
M5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS9VED(")7
M24X@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B
M5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO
M=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR
M.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR-S(@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@S"FUS9VED(")787)N:6YG(@IM<V=S
M='(@(LKDR.WE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O<F5C87-T
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT
M,C<*;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3(*;7-G:60@(E=E871H
M97(N8V]M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V
M"FUS9VED(")796(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0S-PIM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B
M5V5E:VQY(@IM<V=S='(@(L/3R.;:[<?P(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+VUO8FEL92YP:'`Z,C@*(RP@9G5Z>GD*;7-G:60@(E=E;&-O;64B"FUS9W-T
M<B`BP^7AQR#FT^7AQR`E<R(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N
M:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(L/EX<<@R-_C(,7A
M["`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E;7!L
M871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7
M96QC;VUE+"`E<R(*;7-G<W1R("+#Y>''(.;3Y>''("5S(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$I
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS9VED
M(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@
M;&]G:6X_(@IM<V=S='(@(N/'(,?AR-'DQ^/,(,?AX\K1UB#:T=;E(./D(.7F
MT<_M(,C:SR#'X<_.YN&_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,30*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W
M"FUS9VED(")7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,#8Q"FUS9VED(")7:&5R96ES($%U<W1R86QI82!M87`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S97,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,PIM<V=I
M9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@
M961I=&]R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED(")7:61T:"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(U"FUS9VED(")7
M:61T:"!I;B!#4U,@=6YI=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T
M:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@
M;&]G+6EN*3HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q,`IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0IM
M<V=I9"`B5VED=&@Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HU,3,*;7-G:60@(E=I:VDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,"!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B5VEN9"(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@IM<V=I
M9"`B5VEN9"!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C@P"FUS9VED(")7:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34V"FUS9VED(")7:6YD.B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0R"B,L
M(&9U>GIY"FUS9VED(")7:6YD.B`B"FUS9W-T<B`BRN3([>4Z(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5VES
M:&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U
M"FUS9VED(")7;W)K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$V-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM
M<V=S='(@(MKDYL?D(,?AVN/A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R
M("+EQ\K=(,?AVN/A(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M,38Y(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(V,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N
M($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S`P"B,L('!H<"UF;W)M870*;7-G:60@
M(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,3$T"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL
M92!R96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR-#,*;7-G:60@(E@M4F5F(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED
M(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3(*;7-G:60@(E@U,#EV
M,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!3=6)J
M96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J
M96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C@R"FUS9VED(")8-3`Y=C,@97AT96YS
M:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I
M9"`B65DB"FUS9W-T<B`BT^3)("T@U]<B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-34*(RP@9G5Z>GD*;7-G:60@(EE965DB
M"FUS9W-T<B`BT^3)("T@U]<B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3$P.`IM<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP
M.C4V"FUS9VED(")996%R;'DB"FUS9W-T<B`BT^3F[<?P(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-PIM<V=I9"`B665M96XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV,PIM<V=I9"`B665S(@IM<V=S
M='(@(N3:XR(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC
M92YH=&UL.C4V"FUS9VED(")997,L($D@06=R964B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I
M9"`B66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N
M('1O('-W:71C:"!B86-K('1O(%=94TE764<N(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@
M8FQO8VMS+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C$T,3$*;7-G:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z
M,S`R"FUS9VED(")9;W4@8V%N(&YO="!H879E('1H92`G7%PG(&-H87)A8W1E
M<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3@U-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.3<U"FUS9VED(")9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D
M9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP
M.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A
M;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E
M<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HY.#@*(RP@9G5Z>GD*;7-G:60@(EEO=2!H
M879E(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`BRN,@RLW/[<L@Q^'.[<?1
MQ\HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8Q"FUS9VED("(B
M"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L
M(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@
M:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X.`IM<V=I9"`B66]U(&AA=F4@
M=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@;75S="!C
M;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0U-@IM
M<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS
M9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U
M(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B[<S((-31
MS2#'X>/4W^')(-[(X2#'T=/'X2#*WM'MT<?P(,CEQRXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@
M;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*
M;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E
M9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$Y"FUS9VED(")9
M;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#`*;7-G:60@(EEO=2!M=7-T
M('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@
M=&\@861D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#8*;7-G
M:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII
M<"YP:'`Z,3,X"FUS9VED(")9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N
M('1O('!E<F9O<FTN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"FUS9VED(")9;W4@;75S="!T
M>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S"FUS
M9VED(")9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M
M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R("5S('-E<W-I;VX@:&%S(&5X
M<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`BQ^3*Y<H@U>''
MS>W)(,?AQ\K5Q^$@)7,N(,?AT<S'P2#%VL?/R2#'X<_.YN$N(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*(RP@9G5Z>GD*;7-G:60@
M(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R("+:Y.;'Y"#(T>W/WR#'X<7A
MW\K1YN3M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,3(*(RP@9G5Z
M>GD*;7-G:60@(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`BVN3FQ^0@
MR-'MS]\@Q^'%X=_*T>;D[3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-C0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<T(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@(EEO
M=7(@26YF;W)M871I;VXB"FUS9W-T<B`BR.W'Y,?*WSHB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+G!H<#HY.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B
M96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO
M=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PHC+"!F=7IZ
M>0IM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@(L?3X]\Z(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T
M:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U
M<V5R<RX@268@>6]U('=I<V@@=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T
M97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*
M(F%U=&AE;G1I8V%T:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A
M=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN
M9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@
M9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+G!H<#HY.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H
M92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T
M('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU,`IM<V=I9"`B66]U<B!B
M<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]P<FEN="YJ<SHT,@IM<V=I
M9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN
M="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I
M;G0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3<*
M;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!R969S+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B66]U<B!D
M969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N(@IM<V=S='(@(LKC
M(,K-S^W+(,?ASNW'T<?*(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U
M.`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G
M<W1R("+'X<K-WMX@Q^''W<K1Q];M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(P,0HC+"!F=7IZ>0IM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S
M='(@(L?3X]\Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z,3`P,`HC
M+"!F=7IZ>0IM<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T
M<B`BRN,@RLW/[<L@Q^'.[<?1Q\HB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S
M=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,34T"B,L(&9U>GIY"FUS9VED(")9;W5R(&]P
M=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T
M:&ES('-E<W-I;VXN(@IM<V=S='(@(LKC(,K-S^W+(,?ASNW'T<?*(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@
M;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS9W-T<B`BRN,@RLW/[<L@
MQ^'.[<?1Q\HB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM
M<V=I9"`B66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB
M66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I
M;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<S,@IM<V=I9"`B
M66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9;W5R(')E;6]T
M92!S97)V97)S.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(U-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS
M9VED(")9=6=O<VQA=FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$X"FUS9VED(")::6UB86)W92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-C8*;7-G:60@(EII<'!Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S
M+G!H<#HQ-S(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N
M:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E9"!497AT72(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HX.`IM<V=I9"`B6U!R;V)L96T@4F5P
M;W)T72(*;7-G<W1R(");RM[1[=$@Q^'CU-_AR5TB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O
M=&5D(%1E>'0@+2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT
M97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,L('!H<"UF;W)M
M870*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DS"B,L('!H
M<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F("5S72(*;7-G<W1R(");Q^'3
MV-$@)7,@X^0@)7-=(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M-30Q('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,3$*;7-G:60@(E]!9&UI
M;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G
M:60@(E]#3$DB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS9VED
M(")?1&%T851R964B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED(")?1&5L971E
M(%)O=R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@(E]'
M<F]U<',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE
M;G4N<&AP.C$W-0HC+"!F=7IZ>0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`BQ^'C
MT\?:S\DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P97)T:65S+BXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ
M.30*(RP@9G5Z>GD*;7-G:60@(E],;V<@:6XB"FUS9W-T<B`BS\[FX2(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.3`*(RP@9G5Z>GD*
M;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(L[1YLPB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G:60@
M(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O365N=2YP:'`Z,38T"B,L(&9U>GIY"FUS9VED(")?3W!T:6]N
M<R(*;7-G<W1R("+.[<?1Q\HB"@HC.B!L:6(O87!I+G!H<#HQ,S<*;7-G:60@
M(E]097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*(RP@9G5Z>GD*;7-G
M:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R("+%TN')(,?AR^3'QNTB"@HC
M.B!L:6(O87!I+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,S,*;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]A<&DN<&AP.C$R.0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Q"B,L(&9U>GIY"FUS
M9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`BS]W*T2#:Y,?F[>0B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S-`IM<V=I9"`B861D
M<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,3,*(RP@9G5Z>GD*;7-G:60@(F-A;&5N9&%R(@IM<V=S
M='(@(L/,Y,_)(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S(@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$U.`IM<V=I9"`B8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S,`IM
M<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DR"FUS9VED(")C;&EC:R!H
M97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-S@*;7-G:60@(F-O;F9I9W5R871I;VX@97)R;W(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-30*;7-G:60@(F-R
M:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C8*;7-G:60@(F1A=&$@
M9F]R;6%T(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,3@R"B,L(&9U>GIY"FUS9VED(")E;G1R>2!N;W0@
M9F]U;F0B"FUS9W-T<B`BV^W1(./FS.;/(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*;7-G:60@(F9A;&QI;F<B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4U"B,L
M(&9U>GIY"FUS9VED(")F:6QE(@IM<V=S='(@(MW4X2(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,3<T(&QI8B]";&]C:R]M971A<BYP:'`Z,S8P(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S@V"B,L('!H<"UF;W)M870*;7-G:60@(F9R;VT@
M=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(U,`IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C0Y"FUS9VED(")H.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4X"FUS9VED(")H:"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I
M9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED
M(")I;6UE9&EA=&4B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP
M:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(FEN;&EN92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,30V"FUS9VED(")I
M;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B;&EN97-=
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES
M;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,V
M.0IM<V=I9"`B;6TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HR.3$@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W
M,`HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C,R"FUS9VED(")N
M86UE(@IM<V=S='(@(L?AQ]/C(@H*(SH@9G)A;65W;W)K+U)00R]24$,N<&AP
M.C$R,0IM<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(Q.0IM<V=I9"`B;F]T
M('EE="!I;7!L96UE;G1E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.CDP-0IM<V=I9"`B;F]T97!A9"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@X"FUS9VED(")P97)C96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,3<T"FUS9VED(")P97)M:7-S:6]N(&1E
M;FEE9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S`*;7-G
M:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,PHC+"!F=7IZ
M>0IM<V=I9"`B<FES:6YG(@IM<V=S='(@(LKDR.WE(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ-#(*;7-G:60@(G-E<G9I8V4@=6YA
M=F%I;&%B;&4B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HY.0IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM
M<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS.#4*;7-G:60@(G-S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C<R"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HS,#D*;7-G:60@(G-W:71C:"!O9F8@:F%V
M87-C<FEP="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Y"FUS9VED(")T87-K
M(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S`U"B,L(&9U>GIY
M"FUS9VED(")T<GD@86=A:6XB"FUS9W-T<B`BW^$@S\[FX2(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C,V(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR
M-CD*;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO
M<V5T=7`O9&EF9BYP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(G5N:69I960B"FUS
M9W-T<B`BW=3A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]087)T+G!H<#HR
M-PHC+"!F=7IZ>0IM<V=I9"`B=6YN86UE9"(*;7-G<W1R("+'X<?3XR(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(R,PIM<V=I9"`B=7-E<B!S96QE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R
M9"(*;7-G<W1R(")V0V%R9"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR-#$*;7-G:60@(G<Z(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED(")W96%T:&5R+F-O
M;2(*;7-G<W1R("(B"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O=6M?54$N<&\`
M````````````````````````````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P-C`U-38S(#$P-3$U-#,S-S0S(#`Q-S4T,0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````C($AO<F1E(%5K<F%I;FEA;B!+
M3TDX+54@=')A;G-L871I;VX*(R!#;W!Y<FEG:'0@*$,I(#(P,#(@06YD<FEY
M($MO<'ES='EA;G-K>2X*(R!!;F1R:7D@2V]P>7-T>6%N<VMY(#QA;G)I0'!O
M;'EN970N;'9I=BYU83XL(#(P,#(N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0
M<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E('8R+C%<;B(*(E)E<&]R="U-<V=I
M9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I
M;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO
M;BU$871E.B`R,#`R+3`Q+3`U(#$V.C$U*S`R,#!<;B(*(DQA<W0M5')A;G-L
M871O<CH@06YD<FEY($MO<'ES='EA;G-K>2`\86YR:4!P;VQY;F5T+FQV:78N
M=6$^7&XB"B),86YG=6%G92U496%M.B!5:W)A:6YI86X@/'=E8FUA<W1E<D!P
M;VQY;F5T+FQV:78N=6$^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N
M=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4M/23@M55QN(@HB0V]N
M=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@."UB:71<;B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(S-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E
M<R!D87ES(&%G;RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ,S<P"B,L('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y
M("5S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S<W"B,L('!H<"UF;W)M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,PIM<V=I9"`B
M("AT;V1A>2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C,W-0IM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,0IM<V=I9"`B("AY97-T97)D87DI
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-38@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,0HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`W"FUS9VED("(@870@(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C$U"B,L('!H<"UF
M;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E8W1O<GDN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H
M<#HV-3D*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ
M,#0R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG
M=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]4<F5E+U1R964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-38*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN
M(@IM<V=S='(@(O73T*;;SL\@Q,_$P<[/("<E<R<@Q,\@T\G3U,7-R2XB"@HC
M.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES
M=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4T(&%D;6EN
M+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED(")<
M(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(B4N
M,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,C8X(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HU-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I
M;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA
M:6YT96YA;F-E+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M($YO
M=&EC92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C<P-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HX,S,@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,U
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM
M<V=S='(@(N_0Q=+!PZ;1(-#2S\:FS,'+U,G>SL_'SR#/PM/,U<?/U]77P<[.
MT2`E<R`M(/"FQ-37Q=+$UL7.SM$B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,34*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]3:6=N=7`N<&AP.C(V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!3:6=N(%5P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E
M+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E
M96UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HT,C@@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3`*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HV-3$@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES
M=',N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Y(&QI
M8B]";&]C:R]M971A<BYP:'`Z,38U(&QI8B]";&]C:R]M971A<BYP:'`Z,C,Y
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S0U(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S4Q"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@=&\@<&5R9F]R
M;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#
M:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT
M('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("+WIL3-IM38U,4@
MS]#%TL.FP"BG*2P@T<NF(-/,IL0@VL2FRM/.R=3)(-<@P\7*(-[!TRXB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S0P"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C@V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&UI;G5T
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE
M8W1I;VXN<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U
M;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C(*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM
M<V=S='(@(N'$TL73SL$@R\[)Q\$B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDQ-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`V
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL
M92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C(W
M,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M97-S86=E(&UA
M>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F
M(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG
M('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C4@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q,`IM<V=I9"`B+"!G=7-T
M:6YG("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X."!L
M:6(O0FQO8VLO;65T87(N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(L
M(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L92!F<F]M
M("5S('1O("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,CDT(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S0X
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-CD@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C$R.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-S0Y"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P"FUS9VED("(Q,B!(;W5R($9O
M<FUA="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3D*;7-G
M:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D
M871A+W1I;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(R-"#'
MS\3)SLDB"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C8Y"FUS9VED
M("(\4')E=FEO=7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ,3D*;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F
M;W(@=&AI<R!B;&]C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ-C`*;7-G:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R
M<F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.CDS-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T
M;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V-0IM<V=I9"`B02!P=6)L:6,@4$=0
M(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3`Y-PIM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A
M("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$P,34*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL
M('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O('-I9VX@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4P-0IM<V=I9"`B(@HB02!P=6)L
M:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O
M34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N
M("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME
M>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0IM
M<V=I9"`B04T@0VQO=61S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!,:6=H="!286EN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$Q"FUS9VED(")!32!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED(")!32!3
M:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-
M+U!-(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*
M;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+VAE;'`O:6YD97@N<&AP.C4R"FUS9VED(")!8F]U="XN+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<T"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED
M9&QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL
M92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C,*;7-G
M:60@(D%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<U"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT(%!A
M<W-W;W)D(@IM<V=S='(@(O"FQ-37Q=+$UL7.SM$@T,'2S\S`(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS
M9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,S,PIM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T."!T96UP
M;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]A9&1C:&EL9"YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(D%D9"(*;7-G
M<W1R("+AQ-+%T\$B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G
M<F]U<',N<&AP.C(R-0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3@@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY.0IM<V=I9"`B061D($-H:6QD(%!E
M<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N
M:6YC.C4*(RP@9G5Z>GD*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R("+DS\3!
MU,D@R\_2R=/4U=?!WL$B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(Q."!A9&UI
M;B]G<F]U<',N<&AP.C(Q.0IM<V=I9"`B061D($YE=R!'<F]U<"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z.#@*;7-G:60@(D%D9"!.97<@4&5R
M;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V%D9&-H:6QD+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H
M:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!
M9&0@82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM
M<V=S='(@(N3/Q,'4R2#.S]?/Q\\@R\_2R=/4U=?!WL$Z(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-`IM<V=I9"`B061D
M(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V5D:70N:6YC.C,T"B,L(&9U>GIY"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B
M"FUS9W-T<B`BY,_$P=3)(,[/U\_'SR#+S]+)T]35U\'>P3HB"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@<&%I<B(*;7-G
M<W1R("+DS\3!U,D@T,'2U2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@
M36]Z:6QL82!3:61E8F%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B061D
M('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`BX<32Q=/.P2#+SLG'P2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW.`HC+"!F
M=7IZ>0IM<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O:R(*;7-G<W1R("+A
MQ-+%T\[!(,O.R<?!(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*;7-G:60@(D%D
M9"!U<V5R(@IM<V=S='(@(N3/Q,'4R2#+S]+)T]35U\'>P2(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D(%PB
M)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO
M;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@(B(*"B,Z
M('-I9VYU<"YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E
M<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G
M:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`BY,_$P=?!
MSL[1(,O/TLG3U-77P=ZFUR#:P<+/TL_.Q<[%+B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-#0Q"FUS9VED(")!9&1R97-S(@IM<V=S='(@(N'$TL73P2(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,SD*(RP@9G5Z>GD*;7-G
M:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R("+AQ-+%T\[!(,O.R<?!(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30*;7-G:60@
M(D%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ.2!S97)V:6-E<R]P
M;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED(")!9&UI;FES=')A=&EO;B(*
M;7-G<W1R("+AQ,VFSJ;3U-+5U\'.SM$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S0Q"B,L(&9U>GIY"FUS9VED(")!9',B"FUS9W-T<B`BX<32
MQ=/!(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B069G:&%N:7-T86XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-PHC+"!F=7IZ>0IM<V=I9"`B06QB86YI82(*;7-G<W1R
M("+PT\77Q,_.ILTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"B,L(&9U>GIY"FUS9VED(")!;&=E
M<FEA(@IM<V=S='(@(O#3Q=?$S\ZFS2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*;7-G:60@(D%L:6%S(@IM<V=S='(@
M(O#3Q=?$S\ZFS2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,38*(RP@9G5Z>GD*;7-G:60@(D%L:6=N(@IM<V=S
M='(@(O#3Q=?$S\ZFS2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N=#HB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C@W"FUS9VED(")!;&PB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,#<@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I
M8V%T960@57-E<G,B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS
M,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM<V=I9"`B06QL($=R;W5P<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDQ(&9R
M86UE=V]R:R]097)M<R]097)M<R]D871A=')E92YP:'`Z-S4*;7-G:60@(D%L
M;"!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$W"FUS9VED(")!;&P@9F]U
M<B!S:61E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.#<Q"FUS9VED(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S-`IM<V=I9"`B06QL
M;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS
M9VED(")!;')E861Y(&5X:7-T<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3(S"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`W"FUS9VED
M(")!;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#DY"FUS9VED(")!;'1E<FYA=&4@24U34"!5
M<V5R;F%M92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HS-0HC+"!F=7IZ>0IM<V=I9"`B06QT97)N871E(&5M86EL(&%D9')E
M<W,B"FUS9W-T<B`B]\';P2#!Q-+%T\$@Q2W0S]O4R3HB"@HC.B!A9&UI;B]T
M96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B06QT97)N871E('1E;7!L871E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$R,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;65R:6-A;B!386UO82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.CDU
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I
M;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C<*;7-G:60@(D%N('5N:VYO
M=VX@97)R;W(@:&%S(&]C8W5R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*
M;7-G:60@(D%N9&]R<F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B
M06YG;VQA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I;&QA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-@IM<V=I9"`B06YT:6=U82!A;F0@0F%R8G5D82(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D;6EN+W!H<'-H
M96QL+G!H<#HS-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4X
M('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*;7-G:60@(D%P
M<&QI8V%T:6]N(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H
M<#HT,@IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,30P"FUS9VED(")!<'!L:6-A=&EO;B!I
M<R!R96%D>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O($-H:6QD(%-H87)E<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM
M<V=I9"`B07!P<F]V92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HX,S,*;7-G:60@(D%P<')O>&EM871E(%-I>F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3<U"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HU.2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8V
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#$*;7-G
M:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HV-0HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C@P"FUS9VED(")!<F-H:79E($YA;64B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN
M8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A
M;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@
M=&\@9&5L971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4W"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3<V"FUS9VED(")!<FUE;FEA;B`H05)-4T-)22TX
M*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*;7-G
M:60@(D%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!<G5B82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U"FUS
M9VED(")!<V-E;G-I;VX@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@07)T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I
M82]086-I9FEC(%)E9VEO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#(U"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O
M<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q,PIM<V=I9"`B07-S:6=N
M;65N="!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M-S0*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R
M;W5P+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C(Y
M"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M
M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HX
M-PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI
M<W-I;VXN(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H
M<#HU,PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H
M87)E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C8T(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-S$*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX
M-@IM<V=I9"`B071T<FEB=71E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B075G=7-T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<FEA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@(D%U
M=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP
M.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E
M(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z
M(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]F='`N<&AP.C,V"FUS9VED("(B
M"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z
M-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@061D
M:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O
M<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HS-3<*;7-G:60@(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T
M('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C8S"FUS9VED(")!=71H
M7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,SD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D
M('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,X-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO
M=F4@=7-E<B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C0Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z
M(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P
M.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@
M1&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VUC86PN<&AP.C0V"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E
M<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDP"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z-C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N=&EC871I;VX@
M9F%I;&5D+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H96YT:6-A=&EO;B!R96IE8W1E
M9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C@U,0IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@
M1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-S`*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O('1H
M92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB
M"FUS9W-T<B`BY,_3U-70SJ8@T,_,T3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!
M>F5R8F%I:F%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS,`IM<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G
M:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#
M;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N
M<&AP.C@Q"FUS9VED(")"860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@
M(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,@IM<V=I9"`B0F%H86UA<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED
M(")"86AR86EN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3<W"FUS9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O
M;E]B<F]W<V5R+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R
M87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S,*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*
M;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B
M0F5L9VEU;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QI>F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F5N:6XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8S"FUS9VED(")":'5T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD
M87DB"FUS9W-T<B`BY,7.V"#.P=+/Q-;%SL[1(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,U,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")";&]C:R!<(B5S7"(@;V8@87!P;&EC871I;VX@7"(E<UPB(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N
M:6YC.C@Y"FUS9VED(")";&]C:R!3971T:6YG<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y
M<&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(P-0IM<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C`*(RP@9G5Z>GD*;7-G:60@(D)O<F1E<B(*;7-G<W1R(")(;W)D92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*
M;7-G:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*(RP@
M9G5Z>GD*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8P"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W1S=V%N82(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S4*;7-G:60@(D)O='1O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS
M9VED(")";W5V970@27-L86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HT,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*(RP@
M9G5Z>GD*;7-G:60@(D)R87II;"(*;7-G<W1R("))35`MT,_2U,',(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#$*;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<G5N96D@1&%R=7-S
M86QA;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=6QG87)I82(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Y"FUS9VED(")"=6QL971E9"!,:7-T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C$*;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Q"FUS9VED(")"=7)U;F1I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT-#0*(RP@9G5Z>GD*;7-G:60@(D--4R(*;7-G
M<W1R(")#5E,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-23"!$:7-T<FEB=71I
M;VX@4&]I;G1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-PIM<V=I9"`B0U]E;&P@4')O
M<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,38S"FUS9VED(")#86-H92!I;FET('=A<R!N;W0@8V]M<&QE
M=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#@T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.#<*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$U-0IM<V=I9"`B0V%L96YD87(B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T
M-@IM<V=I9"`B0V%L;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B
M0V%M8F]D:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O
M;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL
M>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#86X@;F]T('=R:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,@IM<V=I9"`B0V%N)W0@861M
M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,S4@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,Q.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT,3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V%N861A(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$P,2!A9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8U"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,2!T96UP;&%T97,O861M
M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E+FEN8SHQ,@IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@
M4')O8FQE;2!297!O<G0B"FUS9W-T<B`B]Z;$S:;.R=3)(-#/UZ;$S\W,Q<[.
MT2#0TL_"S,7-R2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$X
M"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D96QE=&4@9FEL92!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HT-@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T
M96=Y+V-O<'DN<&AP.C4R"FUS9VED(")#86YN;W0@9FEN9"!A('1E;7!O<F%R
M>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D
M('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964N<&AP.C$R
M."!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV.#`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@
M97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A
M5')E92]S<6PN<&AP.C8P.`IM<V=I9"`B(@HB0V%N;F]T(')E;W)D97(L(&YU
M;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T
M(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM<V=I
M9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0V%P92!697)D92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(T"B,L(&9U>GIY"FUS9VED(")#87!T:6]N(@IM<V=S='(@
M(OK"Q=+%Q]3)(,_0PZ:G(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E
M;F5R:6-?<VUT<"YP:'`Z,3`T"FUS9VED(")#87)R:65R(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,`IM<V=I9"`B0V%T96=O<FEE
M<R!A;F0@3&%B96QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")#
M87EM86X@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#96QL(%!H;VYE(@IM
M<V=S='(@(O/4ILS8SLG+S]?)RB#4Q<S%QL_.(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0HC+"!F=7IZ>0IM
M<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(O/4ILS8SLG+S]?)RB#4
MQ<S%QL_.(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS9VED(")#
M96QL('-P86-I;F<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R-S0*(RP@9G5Z>GD*;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R
M("+SU*;,V,[)R\_7R<H@U,7,Q<;/SB(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3<X"FUS9VED(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(V"FUS9VED(")#96YT97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HU-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C4Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM
M<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")#96YT<F%L($5U<F]P
M96%N("A)4T\M.#@U.2TR*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8Y.0IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T
M86EL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8Q,0IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G
M:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P.`IM<V=I9"`B0VAA9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.CDV"B,L(&9U>GIY"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B\\O!T]77P=3)
M(-K-IL[)(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,Q"B,L
M(&9U>GIY"FUS9VED(")#:&%N9V4@66]U<B!087-S=V]R9"(*;7-G<W1R("+P
MIL34U\72Q-;%SL[1(-#!TL_,P"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV-@IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H
M870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U
M<B`B"B)E;6%I;',N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U<B!P87-S=V]R
M9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A
M=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(W"FUS9VED(")#:&%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I
M9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PHC+"!F
M=7IZ>0IM<V=I9"`B0VAI;&4B"FUS9W-T<B`B],G4U<PB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W
M"FUS9VED(")#:&EN82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X,`IM<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#
M:&EN97-E(%1R861I=&EO;F%L("A":6<U*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"B,L(&9U>GIY"FUS9VED
M(")#:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R("+PIL34U\72Q-;%SL[1(-#!
MTL_,P"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C@*
M;7-G:60@(D-H;V]S92!A('5S97)N86UE(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR.3@*;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES
M<&QA>2!D871E<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E
M(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C@Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S
M<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*;7-G:60@
M(D-L96%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E('1A9W,B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.`IM<V=I9"`B
M0VQE87(@475E<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@;W5T
M('5S97(Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V-L96%R+FEN8SHQ,0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`IM<V=I9"`B0VQE
M87(@=7-E<B!D871A(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$U"FUS9VED(")#;&5A<FEN9R!,871E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC
M92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`B^L'+
MTLG4R2#7ILO.SR(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0T"FUS9VED
M(")#;&]U9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,38*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@
M(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P;W)T86PO<VED96)A<BYI;F,Z,C,*;7-G:60@(D-O;&QA<'-E(%-I
M9&5B87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E
M<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]L;VUB:6$B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO8VLO
M8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C0*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-0HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`P('-E<G9I
M8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R(%!I
M8VME<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.#0V"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"FUS9VED
M(")#;VQS.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.30V"FUS9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C0*;7-G:60@(D-O;6EC<R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*(RP@9G5Z>GD*;7-G
M:60@(D-O;6UA;F0B"FUS9W-T<B`BZ\_-T,'.IM$B"@HC.B!A9&UI;B]C;61S
M:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")#
M;VUM96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-38V"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-`IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#
M;VUP86YY(@IM<V=S='(@(NO/S=#!SJ;1(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y-PIM<V=I9"`B0V]N9&ET:6]N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0Y"FUS9VED
M(")#;VYD:71I;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N
M<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#,*;7-G:60@(D-O
M;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE
M<R!A;F0@3W5T;&]O:RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$S-0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T
M92XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$P,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,0IM<V=I9"`B
M0V]N9FER;2!087-S=V]R9"(*;7-G<W1R("+PIL34U\72Q-;%SL[1(-#!TL_,
MP"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-34@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C4*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O
M9B!T:&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDP"FUS9VED(")#;VYN
M96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE
M('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@T-0IM<V=I9"`B0V]N
M;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,30*;7-G:60@(D-O;G1A8W1S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D
M960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C<X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")#;VYT96YT<R!O9B!<(B5S7"(B"FUS9W-T<B`B]\VFT]0@)R5S)R(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HS,PIM<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]O:R!)<VQA;F1S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O:VEE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR,0HC+"!F=7IZ>0IM<V=I9"`B0V]P>2(*;7-G<W1R
M("+KS\W0P<ZFT2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8X
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@)7,B
M"FUS9W-T<B`BMLW0S]+4S]?!SL4@T,_,Q3H@)7,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,V"FUS9VED(")#;W!Y('-E
M;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C$W,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C$Y-0IM<V=I9"`B0V]S="!)1"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8W"FUS9VED(")#;W-T82!2:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C8*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3<V"FUS9VED(")#;W5L9"!N;W0@
M4$=0(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`U,PIM<V=I9"`B0V]U;&0@;F]T(%!'
M4"!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,SDS"FUS9VED(")#;W5L9"!N;W0@4R]-24U%
M(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD(&YO="!3+TU)
M344@<VEG;B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$X-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C$R,0IM<V=I9"`B0V]U;&0@;F]T(&)I
M;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HT-3<*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O(&QD87`@
M<V5R=F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0T,0IM<V=I9"`B0V]U;&0@;F]T(&-O
M;FYE8W0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C,R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E
M871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3(U"FUS9VED(")#;W5L9"!N
M;W0@9&5C<GEP="!01U`@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,C(*;7-G:60@(D-O=6QD(&YO="!D
M96-R>7!T(%,O34E-12!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(T-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE
M=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.C,X"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C,X,2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-3,*;7-G:60@
M(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A
M9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H
M(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*;7-G:60@
M(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M
M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T
M<'5T4W1R871E9WDN<&AP.C8X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO
M9&ER96-T+G!H<#HS,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M;6MD:7(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B
M;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W-PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP
M:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N($UA
M:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M;W!E;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$Q(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HQ-#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C(S-R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#<X
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HU,38@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z-C4V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HV.3D*;7-G:60@(D-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S
M97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+T]B:F5C
M="YP:'`Z,C,X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R96%D
M("5S+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HX-0IM<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F
M;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB
M9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T
M('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE
M;'`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,P.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS-#`*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S<W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,X,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS.#D*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E
M(&%D9')E<W,@8F]O:RX@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ
M.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PIM
M<V=I9"`B0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE
M<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"B,L
M(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(DAO<F1E(,[%(-/+S\[&IL?5TL_7P<[!(-#2P=?)S-C.SR(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z-3D*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P
M(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R
M871I;VX@9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@
M<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE
M<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@
M8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O
M("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C$T,PIM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V
M97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T
M92!C;VYT86-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@
M9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,V-@IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3
M:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,34T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E
M<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@
M7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#$Y"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D-O
M=6YT<GDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(W,PIM<V=I9"`B0V]U<G-E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.CDV"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*;7-G
M:60@(D-R96%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T92!A
M(&QI;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y
M<V5L96-T+FEN8SHY-`IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M,@IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A=&]R
M(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,R,S`*;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B0W)O871I82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8X"FUS9VED(")#=6)A(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HR-@IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-#@*;7-G:60@(D-U<G)E;G0@
M4V5S<VEO;G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@
M;&EB+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4T"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S,*;7-G:60@(D-U<G)E;G0@
M57-E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0IM
M<V=I9"`B0W5R<F5N="!796%T:&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-S4*;7-G:60@(D-U<G)E;G0@8V]N9&ET
M:6]N.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`X"B,L('!H<"UF;W)M
M870*;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T
M;R`E<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M-0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X
M"FUS9VED(")#>7!R=7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#(*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#>7)I;&QI8R`H
M5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X-`IM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-3$@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM
M<V=S='(@(N3D(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,0IM
M<V=I9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO
M96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP
M.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R("+]S\3%SL[/(@H*(SH@861M:6XO
M9&%T871R964N<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-SD*;7-G:60@
M(D1A=&%B87-E($QO;VMU<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S.3D*(RP@9G5Z>GD*;7-G:60@(D1A=&4B"FUS9W-T<B`B]\G4
MQ=+4R2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S
M"FUS9VED(")$871E(%)E8V5I=F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(X,#<*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3(@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,R,@HC+"!F=7IZ>0IM<V=I
M9"`B1&%Y(@IM<V=S='(@(OW/Q,7.SL\B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*(RP@9G5Z>GD*;7-G
M:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(O?)U,72U,DB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@IM<V=I9"`B1&5C
M96UB97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I9"`B1&5C:6UA;"!N=6UB
M97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C`*;7-G:60@(D1E8W)E87-E($EN9&5N="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$X-R!L:6(O
M<')E9G,N<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="(*;7-G<W1R
M("+WR=3%TM3)(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z-S<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS
M9W-T<B`B]\G+S]+)T]3/U]77P=3)(-K.P=[%SL[1(-K!(-K!S<_7WM77P<[.
MT<TB"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.CDQ"FUS
M9VED(")$969A=6QT($ED96YT:71Y(@IM<V=S='(@(N_3SL_7SL$@IM#/T]3!
MT]@B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C<*(RP@9G5Z>GD*;7-G
M:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`B[]/.S]?.P2"FT,_3U,'3V"(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B1&5F:6YI=&EO
M;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW,2!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0S
M.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHY,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O9&5L971E+FEN8SHQ,"!T96UP;&%T97,O861M:6XO=7-E<B]L
M:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S='(@(O?)U,72U,DB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,S(*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S='(@(O?)
MU,72U,DB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G<F]U<',N
M<&AP.C(R-PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@
M(O?)U,72U,DB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#D*
M(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T<B`B]\G4Q=+4R2(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S<@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#$*;7-G:60@(D1E;&5T92!097)M:7-S
M:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-3<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!C96QL
M(@IM<V=S='(@(O?)U,72U,DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8S"B,L(&9U>GIY"FUS9VED(")$96QE
M=&4@8V]L=6UN(@IM<V=S='(@(O?)U,72U,DB"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T
M96UP;&%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C0R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES
M<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C0R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE
M=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP97)M:7-S
M:6]N<S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E
M(')O=R(*;7-G<W1R("+WR=3%TM3)(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E
M;&5T96ED96YT:71Y+FEN8SHQ-0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E('-E
M;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@(N_3SL_7SL$@IM#/T]3!T]@B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C<*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,V"B,L('!H
M<"UF;W)M870*;7-G:60@(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4V,PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C$*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"B,L(&9U>GIY"FUS
M9VED(")$96QI=F5R>2!T:6UE(@IM<V=S='(@(O?)U,72U,DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Y"FUS9VED(")$96YM87)K(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@4')O
M8FQE;2(*;7-G<W1R("+OT,G;IM38(-#2S\+,Q<W5(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.3,X('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S`*(RP@9G5Z>GD*;7-G:60@(D1E<V-R:7!T
M:6]N(@IM<V=S='(@(O#/U\[)RB#/T,G3.B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,3DU"FUS9VED(")$971A:6QS("AA;'-O(&EN($AO<F1E
M)W,@;&]G9FEL92DZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,3DY"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@
M9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C$Y"FUS9VED(")$979E;&]P;65N="(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-PIM<V=I9"`B1&5W
M(%!O:6YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDT
M"FUS9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C<*;7-G:60@(D1E
M=R!P;VEN=#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L969T('1O
M(')I9VAT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L
M969T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS
M9VED(")$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(V-@IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<*(RP@9G5Z>GD*
M;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R("+ZPL72Q<?4R2#/T,.F
MIR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HY-@IM<V=I9"`B
M1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C@U"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T("A4
M048I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M,3<*;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O341.+G!H<#HQ.3`*;7-G:60@(D1I<W!O<VET:6]N
M($YO=&EF:6-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$
M:FEB;W5T:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C0R,@HC+"!F=7IZ>0IM<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G
M<W1R("+WR=3%TM3)(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(U
M"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H
M<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ
M,B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E<R!T
M:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L
M(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED
M(")$;VUI;FEC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")$;VUI
M;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHY-@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3
M:6=N('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HX-#0*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N;&]A9"!G96YE<F%T
M960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`W"FUS9VED(")$<F]P(&1O
M=VX@;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0Q,PHC+"!F=7IZ>0IM<V=I9"`B12U-86EL(@IM
M<V=S='(@(DE-4"W0S]+4P<PB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM=&\M4TU3(&=A=&5W
M87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E
M<G9I8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G:60@(D52
M4B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%8W5A9&]R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(U('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@Q
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@HC.B!T96UP;&%T97,O
M<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3`@=&5M<&QA=&5S+W!O
M<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="!";&]C:R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y."!A9&UI;B]G<F]U<',N<&AP.C(R
M-@IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C<V(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,3`P"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B161I="!0
M97)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I
M="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@4&5R;6ES<VEO
M;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N
M:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S8W"B,L('!H<"UF;W)M
M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T"B,L('!H<"UF
M;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0IM<V=I9"`B161U8V%T
M:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"B,L('!H
M<"UF;W)M870*;7-G:60@(D5I=&AE<B!E;F%B;&4@:70@=&AE;CH@)7,L(&]R
M('5S92!T:&4@8F%S:6,@2%1-3"!V97)S:6]N.B`E<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HW-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`W"FUS9VED(")%;"!386QV861O<B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#,*;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HR,C0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V.0IM<V=I
M9"`B16UA:6PB"FUS9W-T<B`BY2W0S]O4P2(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-38U('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M961I="YI;F,Z,3`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHV.`HC+"!F=7IZ>0IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R("+W
MP=O!(,'$TL73P2#%+=#/V]3).B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Y-C,*(RP@9G5Z>GD*;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T
M(&UA=&-H+B(*;7-G<W1R("+PP=+/S-@@S=73R=38(-/0IM?0P=/4R2XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3@Y"FUS9VED(")%;6%I;"!W
M:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M
M4TU3($=A=&5W87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(Y.`IM<V=I9"`B16UO=&EC;VYS(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P,@HC+"!F=7IZ>0IM<V=I9"`B16UP='D@;65S<V%G92XB"FUS
M9W-T<B`B\,_2S];.ILH@TL7:U<S8U,'4+B(*"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HR-#,@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C0X-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M-C8R(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW,#4*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-3`*;7-G:60@(D5M<'1Y(')E
M<W5L="XB"FUS9W-T<B`B\,_2S];.ILH@TL7:U<S8U,'4+B(*"B,Z(&9R86UE
M=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E
M87)C:"!T97)M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-30S"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M
M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3$X"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI
M8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-3DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3$*
M;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I
M=&]R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C$*
M;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U
M('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P
M87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G
M92!54DP@:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.#DQ"FUS9VED(")%;G1E<B!T:&4@;&5T=&5R
M<R!B96QO=SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B17%U871O
M<FEA;"!'=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I
M=')E82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HT-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-34*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-B!S97)V:6-E<R]P
M;W)T86PO:6YD97@N<&AP.C@R"FUS9VED(")%<G)O<B(*;7-G<W1R("+PS\W)
MS,O!(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@8W)E871I;F<@8FQO8VLZ("5S
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C<R
M"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC
M:&]R.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S
M>6YC(&QO9SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E;7!L871E
M+U1E;7!L871E+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M9V5T=&EN9R!C;VYT96YT.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R
M;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I
M9"`B17)R;W(@=VET:"!E;6%I;"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDO8V]P>2YP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R
M('=R:71I;F<@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED
M(")%<W1O;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T:&EO
M<&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-@IM
M<V=I9"`B171H;FEC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD*;7-G:60@(D5V97)Y(#$U(&UI;G5T
M97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X.0HC
M+"!F=7IZ>0IM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(NO/UL[/
MQ\\@U\C/Q-4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,V(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.#<*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S."!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,SDP"B,L(&9U>GIY"FUS9VED(")%=F5R>2`U
M(&UI;G5T97,B"FUS9W-T<B`BZ\_6SL_'SR#7R,_$U2(*"B,Z(&9R86UE=V]R
M:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y
M($QO9VEN(@IM<V=S='(@(NO/UL[/Q\\@U\C/Q-4B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S0P"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-R!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S@X"B,L(&9U>GIY"FUS9VED(")%=F5R>2!M:6YU=&4B
M"FUS9W-T<B`BZ\_6SL_'SR#7R,_$U2(*"B,Z('1E;7!L871E<R]D871A+V1A
M=&5M87`N:6YC.C(T"FUS9VED(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`B
MY,'.IB#$S-$@T-+)R\S!Q-4Z(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C@Q
M(&%D;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(W
M"FUS9VED(")%>&5C=71E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C0W-0IM<V=I9"`B17AP86YD(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S(*;7-G:60@
M(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO
M4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3<U
M"FUS9VED(")%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T
M97)M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<V"FUS9VED(")%
M>'!O;F5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,Q"FUS9VED(")&1R!#;VQO<B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS9VED(")&
M5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]S<6PN<&AP.C(Q-@IM<V=I9"`B1F%I;&5D(')E=')I979I
M;F<@<')E9F5R96YC97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HW-2!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E
M<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP
M.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8X-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV
M.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN
M<&AP.C@W"FUS9VED(")&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE
M8W1I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z-#DW(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S(T"B,L('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M.`IM<V=I9"`B1F%I<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&
M86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,PIM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0TQ)+T-,22YP:'`Z,C,X"B,L(&9U>GIY"FUS9VED(")&871A;"!%
M<G)O<CHB"FUS9W-T<B`B\,_-R<S+P2"VS=#/TM35.B`B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W"FUS9VED(")&87@B
M"FUS9W-T<B`BYL'+TR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M-#D*(RP@9G5Z>GD*;7-G:60@(D9A>&5S(@IM<V=S='(@(N;!R],B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`R"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM<V=I9"`B
M1F5B<G5A<GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,C`*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(S,0IM<V=I9"`B1F5E;',@;&EK93H@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$Y"FUS9VED(")&97<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B1F5W
M(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.30T"FUS9VED(")&:65L9"!M871R:7@B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S-`IM<V=I9"`B1FEG;&5T
M($-!4%1#2$$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S,S.`IM<V=I9"`B1FEG;&5T(&9O;G0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,@IM<V=I9"`B1FEJ:2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(D9I;&4B"FUS9W-T
M<B`B],G4U<PB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M
M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#<*;7-G:60@(D9I;&4@36%N
M86=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C8S(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-S`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX
M-0HC+"!F=7IZ>0IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(K;-8-$B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3DU"FUS9VED(")&:6QE('-E
M;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-#@V"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-3D*;7-G:60@(D9I;&4@=7!L
M;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z.#D*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,0IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP
M:'`Z-S8*;7-G:60@(D9I<G-T(%%U87)T97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U-@IM<V=I9"`B
M1FEX(')A=&EO(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,S$*;7-G:60@(D9L:7`B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(S-"!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3`W"B,L('!H<"UF;W)M870*;7-G:60@
M(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(R"FUS9VED(")&
M;VYT($-O;&]R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C8*;7-G:60@
M(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,T"FUS9VED(")&;W)E
M8V%S="`H5$%&*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-SD*;7-G:60@(B(*(D9O<F5C87-T($1A>7,@*&YO=&4@=&AA
M="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@
M;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN
M(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHQ,#(*;7-G:60@(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8R"FUS
M9VED(")&;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,C$*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.CDY"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,X"B,L(&9U>GIY"FUS9VED
M(")&;W)T=6YE<R(*;7-G<W1R("+NS]3!U,O)(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,Y"FUS9VED(")&;W)T=6YE<R`R(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-3,*;7-G:60@(D9O<G5M<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3`Y"FUS
M9VED(")&;W)W87)D<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,S"B,L(&9U>GIY"FUS9VED(")&<F%M97,B"FUS9W-T<B`BMLU@T2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@365T
M<F]P;VQI=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D9R96YC
M:"!'=6EA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R96YC
M:"!0;VQY;F5S:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&
M<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-`IM<V=I9"`B
M1G)O;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C0X(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C`*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0P-@IM<V=I9"`B1G)O;2!T:&4@
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C0X"B,L(&9U>GIY"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@
M(O#/U\[)RB#/T,G3.B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z-C`*(RP@9G5Z>GD*;7-G:60@(D9U;&P@3F%M
M92(*;7-G<W1R("+WP=O%(*;-)]$Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1V%B
M;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL97)Y('1O('1A
M:V4@:6UA9V4@9G)O;2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A
M;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=A;6)I82(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L('!H
M<"UF;W)M870*;7-G:60@(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL
M.C@*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.CDP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I
M9"`B1V5R;6%N>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':&%N
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDT
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':6)R86QT87(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-S4*;7-G:60@(D=I=F5N($YA;64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V%P<"YI;F,Z,3(*;7-G:60@(D=O(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT,`IM<V=I9"`B1V]E9&5L(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,3(X"FUS9VED(")';V]G;&4@36%P<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,S<*;7-G:60@(D=R87ES8V%L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.CDS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-@IM<V=I9"`B1W)E96-E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@U"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W)E96YL86YD(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S0*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HQ-SD*(RP@9G5Z>GD*;7-G:60@(D=R;W5P($%D;6EN:7-T
M<F%T:6]N(@IM<V=S='(@(N'$S:;.IM/4TM77P<[.T2(*"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"YP:'`Z-3D@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C$V.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP
M='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C,P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B
M;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C$Q."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3(T
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT,3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G
M<F]U<"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,S,X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS
M-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O
M('5P9&%T92!G<F]U<"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.`HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U86TB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'=65R;G-E>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(R
M-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED(")'=65S="!0
M97)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#<P"B,L(&9U>GIY"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`B
MX<32Q=/.P2#+SLG'P2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=U:6YE82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U:6YE82U":7-S874B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.38P"FUS9VED(")(5$U,
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#4*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E
M9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@V"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O
M(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#<*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L
M971E('1H92!L87-T(')O=R!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HQ-3<*;7-G:60@(DA45%`@075T
M:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#`*;7-G:60@(DAA:71I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.3$Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S(*
M;7-G:60@(DAE861E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"FUS9VED(")(96%D97)S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-
M8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"FUS9VED(")(96%V>2!4+5-T;W)M
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@V"FUS9VED
M(")(96)R97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM<V=I
M9"`B2&5I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92](96QP+G!H<#HQ-SD@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP
M.C$X-@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ-R!T96UP;&%T97,O
M:&5L<"]I;F1E>"YI;F,Z,PIM<V=I9"`B2&5L<"(*;7-G<W1R("+DS]#/S<_'
MP2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-S$*(RP@9G5Z>GD*;7-G:60@(DAE
M;'!E<B(*;7-G<W1R("+DS]#/S<_'P2(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHQ,`IM<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F
M:6QE.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV.0IM<V=I9"`B2&EG:"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO
M;BUH96%D97(N:6YC.C4*(RP@9G5Z>GD*;7-G:60@(DAO7VUE(@IM<V=S='(@
M(DAO<F1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L>2!3964@*%9A=&EC
M86X@0VET>2!3=&%T92DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ-3,U"B,L(&9U>GIY"FUS9VED(")(;VUE(@IM<V=S='(@
M(DAO<F1E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$R,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,34U"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`BY,_-P=O.T2#!
MQ-+%T\$B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*;7-G:60@(DAO
M;64@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS
M9W-T<B`BY,_-P=O.ILH@U,7,Q<;/SB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B
M2&]N9'5R87,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")(;VYG
M($MO;F<B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C8U"FUS9VED(")(;W)D92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z-#0R"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN
M(&UE<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HR.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#,U"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E
M<R!F;W5N9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z,3(U,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB
M)7-<(B(*;7-G<W1R("+UT]"FV\[/(-?)Q,',Q<[/("<E<R<@VB#3R=/4Q<W)
M+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S"FUS9VED(")(
M;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T
M:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@
M9F]R(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C$R-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0W-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)
M344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DS"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@
M7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C$S,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM
M<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO
M<FEZ;VYT86PZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I9"!Y
M;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M
M97)G93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H
M97)E/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N>2!R;W=S('=O
M=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C,P"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C4Y"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B2'5M
M;W)I<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H
M<#HQ-S(@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(S-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D
M.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S
M+G!H<#HR,30@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I
M;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G5S+G!H<#HQ-SD@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(T
M,@HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E
M871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,S$V"B,L(&9U>GIY"FUS9VED("))4"!!9&1R97-S(@IM
M<V=S='(@(N'$TL73P2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I
M8RYP:'`Z-S<*;7-G:60@(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HX
M.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B
M;&]C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W;B!V:6]L
M871I;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@
M0F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B26-E;&%N
M9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<V"FUS
M9VED("))8V]N<R!/;FQY(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W
M<V5R+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@)7,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-PIM<V=I
M9"`B26-O;G,@=VET:"!T97AT(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ.3`*;7-G:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DR
M"B,L('!H<"UF;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@
M8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U-0IM<V=I9"`B
M(@HB268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@
M17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T
M;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3<S"FUS9VED
M("(B"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H
M92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA
M>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(X"FUS
M9VED("));6%G92!0<F5V:65W.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,W"FUS9VED("))
M;6%G92!54DPB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Q"FUS9VED("));6%G92!5
M4DPZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G
M86QL97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O
M;2!G86QL97)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-S8Q"FUS9VED("));6%G92!U<&QO860B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW('1E;7!L871E
M<R]D871A+V1A=&5M87`N:6YC.C<*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHU-"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`B
MMLW0S]+4S]?!SL4@T,_,Q3H@)7,B"@HC.B!T96UP;&%T97,O9&%T82]D871E
M;6%P+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L
M9#H@)7,B"FUS9W-T<B`BMLW0S]+4S]?!SL4@T,_,Q3H@)7,B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C8U"FUS9VED("));7!O<G1E9"!F:65L
M9',Z(@IM<V=S='(@(K;-T,_2U,_7P<ZF(-#/S-$Z(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS9VED
M("));E]S97)T(%)O=R!!9G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S4*;7-G:60@(DEN8V]R<F5C
M="!A8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*(RP@9G5Z>GD*
M;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM
M<V=S='(@(N+5Q-@MS,'3R\$L(-?+P=:FU-@@SL':U]4@R\_2R=/4U=?!WL$@
MIB#0P=+/S-@B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM
M<V=I9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R
M97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T
M;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED
M("));F-R96%S92!);F1E;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS
M9VED("));F1I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C(U-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM
M<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#`*;7-G:60@(DEN9&]N97-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3<*;7-G
M:60@(DEN9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS,S`*;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E
M<B!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T
M($-?;VQU;6X@069T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS9VED("))
M;G-E<G0@26UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I9"`B26YS97)T(%1A8FQE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C4*;7-G:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,S0*;7-G:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C8*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE
M(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T
M(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV,@IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@
M8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@
M82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C<P"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U
M<G)E;G0@;F]D92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A
M('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L
M=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C,Y"FUS9VED("));G-E<G0@86X@96UA:6P@861D<F5S<R!T
M;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU.`IM<V=I9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU.0IM<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*
M;7-G:60@(DEN<V5R="!M97-S86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G
M:60@(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T
M"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8Y"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*
M;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR,S`*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER
M960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M-@IM<V=I9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED
M("));G-E<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN
M<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N
M(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("));G-U9F9I8VEE;G0@8W)E
M9&ET+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,#<U"FUS9VED("));G1E9V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q,S,*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.3<*;7-G:60@(DEN=F%L:60@541(+B`H57-E<B!$871A($AE861E
M<BDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]Z:7`N<&AP.C$W,`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M>FEP+G!H<#HR,#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII
M<"YP:'`Z,C$P"FUS9VED("));G9A;&ED(%I)4"!D871A(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@
M87!P;&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI9"!B
M871C:"!)1"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C`X-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,34X"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(R,S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(Y.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N
M<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B
M>"YP:'`Z.#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP
M:'`Z,3`P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP
M.C(R,`IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<W"FUS9VED("));G9A
M;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3<Q"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R
M;W9I9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y
M<&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG
M(&%P:5]I9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI
M<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O
M861D8VAI;&0N<&AP.C(W"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S
M:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3<S"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S4*;7-G:60@(DEN
M=F%L:60@<')O9'5C="!C;V1E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G:60@(DEN
M=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HW,2!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L
M:60@<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HQ,#<V(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z,3(V,@IM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`Q"FUS9VED("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4W"FUS9VED("))
M;G9E;G1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C8W.0IM<V=I9"`B26YV97)T('-E;&5C=&EO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DER86XL($ES;&%M:6,@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))
M<F%Q(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-0IM
M<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M
M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27-R865L
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C(U"FUS9VED("))<W-U97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"B,L(&9U>GIY"FUS9VED("))=&%L
M>2(*;7-G<W1R("+]S\3%SL[/(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,38*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED(")*86UA
M:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0S.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,PIM<V=I9"`B2F%P86XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#<*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*
M;7-G:60@(B(*(DIA=F%S8W)I<'0@:&%S(&)E96X@9&ES86)L960@;VX@>6]U
M<B!B<F]W<V5R(&%N9"!T:&ES('!A9V4@;6%Y(&YO="!B92`B"B)D:7-P;&%Y
M:6YG(&-O<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`V"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,X"FUS9VED(")*
M=7-T:69Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$U"FUS9VED(")*=7-T:69Y($-E;G1E
M<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y($QE9G0B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-C0*;7-G:60@(DME
M97`@;W)I9VEN86P_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B
M2V5N>6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U
M+G!H<#HX-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B:65S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y($-R
M96%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0Q-`IM<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B
M2V5Y($QE;F=T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DX"B,L(&9U>GIY
M"FUS9VED(")+97D@57-A9V4B"FUS9W-T<B`B[,G3U"(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@
M97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,CD@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L
M92=S(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I
M9"`B2V]R96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@X"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+=7=A:70B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@S"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S"FUS
M9VED("),86YG=6%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@
M(DQA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-CD*;7-G:60@(DQA<W0@2&%L9B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S8*;7-G:60@
M(DQA<W0@4&%S<W=O<F0@0VAA;F=E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HX-B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@*;7-G:60@(DQA
M<W0@475A<G1E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$U,0IM<V=I9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z-S(Q"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ
M("5S(&9R;VT@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z-S$V"FUS9VED("),87-T(&QO9VEN.B!.979E<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#D*;7-G:60@(DQA='9I82(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*;7-G:60@(DQA=R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-SD*(RP@9G5Z>GD*;7-G:60@(DQA>6]U="(*;7-G<W1R("+WR<K4R2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#8*
M;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@W"FUS9VED("),96)A;F]N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0IM
M<V=I9"`B3&5F="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,3$Y"FUS9VED("),969T(&AE861E<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$U"B,L(&9U>GIY"FUS9VED("),
M969T('9A;'5E<R(*;7-G<W1R("+DP<ZF(,3,T2#0TLG+S,'$U3HB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#@*;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED("),979E;"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@Y"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HR-0IM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@HC+"!F=7IZ
M>0IM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R("+WUZ;*U,DB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG
M:'0@4F%I;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B!,871E
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,`IM
M<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*;7-G:60@
M(DQI9VAT(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I
M9"`B3&EM97)I8VLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@Q-`HC+"!F=7IZ>0IM<V=I9"`B3&EN:R(*;7-G<W1R("+WUZ;*
MU,DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<U"FUS9VED("),:6YK
M('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D
M:7-P;&%Y:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E
M<B]&:6QT97(O:'1M;#)T97AT+G!H<#HQ.#,*;7-G:60@(DQI;FMS(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B3&EN
M=7@@0V]O:VEE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T("T@=7-E<B!C86X@<V5E
M('1H92!F;VQD97(B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$S,PIM<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3`*;7-G:60@(DQI<W0@2&5L<"!4;W!I
M8W,B"FUS9W-T<B`B\,72Q<RFRR#2S]K$ILRFUR#DS]#/S<_'R2(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,S(*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DT
M"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12](96%D97)S+G!H<#HU.#D*(RP@9G5Z>GD*;7-G:60@(DQI
M<W0M2&5L<"(*;7-G<W1R("+PQ=+%S*;+(-+/VL2FS*;7(.3/T,_-S\?)(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.38*;7-G:60@
M(DQI<W0M260B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](
M96%D97)S+G!H<#HU.3(*;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3,*;7-G:60@
M(DQI<W0M4&]S="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TAE861E<G,N<&AP.C4Y,0IM<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3`*
M;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5S<VEO;G,N<&AP.C4P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("),
M:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,B"FUS9W-T<B`B\,72Q<?,T<0@
MT]#)T\O5(,O/TLG3U-77P=ZFUR#:P<+/TL_.Q<[)RBXB"@HC.B!A9&UI;B]S
M97-S:6]N<RYP:'`Z,S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DQI
M<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R("+PQ=+%Q\S1Q"#3T,G3
MR]4@R\_2R=/4U=?!WJ;7(-K!PL_2S\[%SLG*+B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I
M<R!D:7-A8FQE9"XB"FUS9W-T<B`B\,72Q<?,T<0@T]#)T\O5(,O/TLG3U-77
MP=ZFUR#:P<+/TL_.Q<[)RBXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#<*;7-G:60@(DQI=&5R871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y
M"FUS9VED("),:71H=6%N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:6UA9V5S+G!H<#HX,PIM<V=I9"`B3&]A9&EN9RXN
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C$Q"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C@S"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-S$@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8T"B,Z(&QI8B]";&]C
M:R]S=6YR:7-E+G!H<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP.C8U"FUS9VED
M("),;V-A=&EO;B(*;7-G<W1R("(B"@HC.B!L;V=I;BYP:'`Z,3<R('-E<G9I
M8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.3$@=&5M<&QA=&5S+VQO9VEN+VUO
M8FEL92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-2!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDP"FUS9VED("),;V<@:6XB"FUS
M9W-T<B`B]]>FRM3)(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C0U"FUS9VED("),;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.#4*;7-G
M:60@(DQO9R!O=70B"FUS9W-T<B`B]\G*U,DB"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(DQO9VEN(@IM<V=S='(@(O?7
MILK4R2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<*;7-G:60@(DQO
M9VEN(%1A<VMS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.CDY-@IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R
M;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DR"FUS9VED
M("),;V=I;B!F86EL960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$S-C4*(RP@9G5Z>GD*;7-G:60@(DQO;F<@=&5X="(*;7-G
M<W1R("+WR<K4R2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`IM<V=I
M9"`B3&]V92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV-PIM<V=I9"`B3&]W(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C$W"FUS9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX.0IM<V=I9"`B3'5X96UB;W5R9R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`P"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,S@@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(NWM(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X,0IM<V=I9"`B34]41"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F
M+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N
M;R!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-
M4T<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86-A;R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA8V5D;VYI82P@5&AE($9O
M<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3`*;7-G:60@(DUA9&%G87-C87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0Y"B,L(&9U>GIY"FUS9VED(")-86=I8R(*;7-G
M<W1R("))35`MT,_2U,',(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C@Q"FUS9VED(")-86EL(@IM<V=S='(@(DE-4"W0S]+4P<PB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3(R"FUS9VED(")-86EL($%D;6EN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DUA;&%W:2(*;7-G
M<W1R("))35`MT,_2U,',(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-86QA>7-I
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&1I=F5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@HC+"!F=7IZ>0IM<V=I9"`B36%L:2(*
M;7-G<W1R("))35`MT,_2U,',(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"B,L(&9U>GIY"FUS
M9VED(")-86QT82(*;7-G<W1R("))35`MT,_2U,',(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDQ"FUS9VED("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@
M8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@
M8V]L;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3$U,PIM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#@T"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,38X"FUS9VED
M(")-87!1=65S="!M87`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S=&]R960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8W"FUS9VED(")-87)C:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q"B,L(&9U>GIY"FUS
M9VED(")-87)G:6XB"FUS9W-T<B`B]=?!Q\$B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E
M96XO56YS965N(&9L86=S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H
M97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")-
M871C:&EN9R!F:65L9',B"FUS9W-T<B`B]Z;$T,_7IL3.IB#0S\S1(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDS"FUS9VED(")-875R:71A;FEA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I
M9"`B36%X(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@
M(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,P-@IM<V=I9"`B36%X('1E;7`@;&%S="`R
M-"!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,CDX"FUS9VED(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("(B
M"@HC.B!L:6(O87!I+G!H<#HX-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@
M4&]R=&%L($)L;V-K<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HX.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-PHC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y"FUS9VED(")-87AI;75M(&QE
M;F=T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3<*;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4P"FUS9VED(")-961I8VEN92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED(")-
M96UB97)S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-S@*;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B
M365R9V4@8V5L;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DUE<W-A9V4B
M"FUS9W-T<B`B[,G3U"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,C$V"FUS9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F
M=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B
M92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"B,L(&9U>GIY"FUS9VED
M(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(NS)T]0B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V.0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C8P"B,L(&9U>GIY"FUS9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`B[,G3
MU"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B365T87(@5V5A
M=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W"FUS
M9VED(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q,@IM<V=I9"`B(@HB365T87(@8FQO
M8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O
M<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$V-0IM<V=I9"`B365T87)$0B!I<R!N;W0@
M8V]N;F5C=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C8W(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C@Q(&9R86UE=V]R:R]24$,O4E!#
M+W-O87`N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E
M<UPB(&ES(&YO="!D969I;F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]2
M4$,O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO
M9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<T(&QI8B]";&]C:R]M
M971A<BYP:'`Z-S4*;7-G:60@(DUE=')I8R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.34*;7-G:60@(DUE>&EC;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM
M<V=I9"`B36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S8*(RP@9G5Z>GD*;7-G:60@(DUI9&1L92(*;7-G<W1R("))35`M
MT,_2U,',(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP
M:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,Q,`IM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H;W5R
M<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`R"FUS
M9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0S.0IM<V=I9"`B36EN:6UU
M;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,T
M"B,L(&9U>GIY"FUS9VED(")-:7)R;W(B"FUS9W-T<B`B\,_-R<S+P2(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM<V=I9"`B36ES8V5L;&%N96]U
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8W,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS-#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E
M($A45%!?4F5Q=65S="XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$Q-0IM<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9
M;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E
M('1H:7,@(@HB87!P;&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B
M36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I9"`B
M36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-38*
M;7-G:60@(DUO(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HW-`IM<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*;7-G:60@(DUO
M9&5R871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C8@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HW,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C@X"FUS9VED(")-;V1I9FEE9"!$871E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM
M<V=I9"`B36]D:69Y(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8W,PIM<V=I9"`B36]D=6QU<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]N86-O(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36]N9V]L:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-`IM<V=I9"`B36]N
M=&@@86YD('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA
M;F-E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*;7-G<W1R
M("+]S\VFT]'#T2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36]N='-E<G)A="(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$W,B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HR-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!F
M:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,S"FUS9VED(")-;W-T;'D@0VQE87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*;7-G:60@(DUO<W1L
M>2!#;&]U9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S4*;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,#D*
M;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,3,*;7-G:60@(DUO=F4@3&5F="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU
M,3<*;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`U"FUS9VED(")-;W9E(%5P(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HU,C0*;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(S"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C0*;7-G:60@(DUO
M=F4@=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-;WIA;6)I
M<75E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M.#0*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3`U-0IM<V=I9"`B375L=&EM87`@54L@;6%P(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#(*;7-G:60@(DUU;'1I<&QE('-E
M;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#`P"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HR.`IM<V=I9"`B37D@06-C;W5N="!);F9O<FUA
M=&EO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP
M.C4T"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+V5D:70N<&AP.C$S-@IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUY86YM87(B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT
M;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P,@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B3F%M92(*;7-G
M<W1R("*VS6#1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").86UI8FEA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4W"FUS9VED(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B
M3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C87!E($-!(%)E
M=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P92!#02!P;VQI8WD@
M55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3@T"FUS9VED(").971S8V%P92!296YE=V%L(%523"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,@IM
M<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE
M='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@
M8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,`IM<V=I9"`B3F5T<V-A<&4@8V5R
M=&EF:6-A=&4@='EP92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C4Q"FUS9VED(").971W;W)K(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S,U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#8*;7-G
M:60@(DYE=F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F5W
M($-A;&5D;VYI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G;W)Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O
M96UA:6QS+G!H<#HX,0HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R
M+V5M86EL<RYP:'`Z.#<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E
M<B]E;6%I;',N<&AP.CDW"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT
M97(O96UA:6QS+G!H<#HQ,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W($UE
M<W-A9V4@=&\@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,3<T"FUS9VED(").97<@36]O;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@
M*&]P=&EO;F%L*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(DYE
M=R!:96%L86YD(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B3F5W('!A<W-W;W)D(@IM<V=S
M='(@(O#!TL_,V"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HR
M,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I;&P@97AP
M:7)E(&]N("5X+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z-3(*(RP@9G5Z>GD*;7-G:60@(DYE=R!P87-S=V]R9',@9&]N
M)W0@;6%T8V@N(@IM<V=S='(@(O#!TL_,V"#-U=/)U-@@T]"FU]#!T]3)+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3$*
M;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V=O;V=L92YP:'`Z-#`@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#D*(RP@9G5Z>GD*;7-G
M:60@(DYE=W,B"FUS9W-T<B`B[L_4P=3+R2(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS,#4*;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34@=&5M<&QA=&5S+V1A
M=&$O9&%T96UA<"YI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN
M8SHQ,CD@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4*;7-G:60@(DYE
M>'0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"FUS9VED
M(").97AT(#0@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,S<R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,S<V"B,L(&9U>GIY"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T<B`B
M\,_7Q=+.U=3)T]$@Q,\@[]##ILHB"@HC.B!F<F%M97=O<FLO54DO54DO4&%G
M97(N<&AP.C$P,PIM<V=I9"`B3F5X=#XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDV"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV
M"FUS9VED(").:6=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@
M(DYI9V5R:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,X,`IM<V=I9"`B3FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDW"FUS9VED(").:75E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(DYO(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM<V=I
M9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I
M9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+G!H<#HQ,#4*;7-G:60@(DYO(&%V86EL86)L
M92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<Y(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C(T-0HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-C<*;7-G:60@(DYO(&)L;V-K(&5X:7-T
M<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-3`*;7-G:60@(DYO(&-A;&5N
M9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4T"B,L(&9U>GIY
M"FUS9VED(").;R!C:&%N9V4N(@IM<V=S='(@(O/+P=/5U\'4R2#:S:;.R2(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED(").
M;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V-R!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P,@HC.B!F<F%M97=O<FLO571I
M;"]5=&EL+G!H<#HW-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R-`IM<V=I9"`B
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($94
M4"!61E,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z-C8Y"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<Q-PIM<V=I9"`B3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S0*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-S<*
M;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B(@H*(SH@=71I;"]I
M8V]N7V)R;W=S97(N<&AP.C<Q"FUS9VED(").;R!I8V]N<R!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$R."!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ,C,*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V.0IM<V=I9"`B3F\@
M;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").;R!M
M97-S86=E('-U<'!L:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@IM<V=I9"`B3F\@;F%M
M92!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS9VED(").;R!N=6UB97(@
M<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z.30*;7-G:60@(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.CDQ"FUS9VED(").
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HQ
M,#@*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VMR8C4N<&AP.C<R"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M2V5R8F5R;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z-S<@9G)A;65W;W)K+T%U=&@O075T
M:"]L;V=I;BYP:'`Z.#0*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP
M.C<U"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<&%S<W=D+G!H<#HQ,S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!005-35T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HX-`IM<V=I9"`B3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C@V"FUS
M9VED("(B"B).;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E
M9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K
M('=I=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]A<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I
M9VYU<',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HW
M-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0S"B,L(&9U>GIY"FUS9VED(").;R!R=6QE<R(*;7-G<W1R("+N
MS]3!U,O)(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Y"FUS
M9VED(").;R!S97!A<F%T;W(@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T
M"B,L(&9U>GIY"FUS9VED(").;R!S:61E<R(*;7-G<W1R("+NS]3!U,O)(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#,*;7-G:60@(DYO('-U
M8V@@9FEL92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,3,X"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL
M86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"B,L(&9U>GIY"FUS9VED(").
M;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`BXM7$
MV"W,P=/+P2P@U\O!UJ;4V"#.P=K7U2#+S]+)T]35U\'>P2"F(-#!TL_,V"(*
M"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED(").
M;R!V86QI9"!834P@9&%T82!R971U<FYE9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3<Q"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY.#$*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDY,@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`P.0IM<V=I9"`B3F\@
M=F%L=65S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M,C`*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG
M=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(X"FUS9VED(").;R!V97)S
M:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E
M;G1I='ES96QE8W0N:6YC.CDS"B,L(&9U>GIY"FUS9VED(").;VYE(@IM<V=S
M='(@(O3%S,7&S\XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDP"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(").;W)D
M:6,@*$E33RTX.#4Y+3$P*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G
M:60@(DYO<F9O;&L@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H
M97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED
M(").;W)T:&5R;B!-87)I86YA($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDW"FUS9VED(").;W)W87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!!9G1E<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8S.0IM<V=I9"`B3F]T($)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HT,#@*;7-G:60@(DYO="!A(&1I<F5C=&]R
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(N<&AP.C8S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C@S"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP
M.CDT"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2YP:'`Z-#@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HU.0IM<V=I9"`B
M3F]T(&EM<&QE;65N=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8X"B,L(&9U>GIY"FUS9VED(").
M;W0@<V5T(@IM<V=S='(@(N[/U,'4R\DB"@HC.B!F<F%M97=O<FLO4V5S<VEO
M;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$T,PHC.B!F<F%M97=O<FLO
M4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$U.`HC.B!F<F%M
M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$W,PHC
M.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP
M.C$X-PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L
M97(N<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,3DP"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HR,#4@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(S
M,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C0X(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HR-C4*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(X,2!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,CDW"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HS,3(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,R.0HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,S8R(&9R86UE=V]R:R]61E,O5D93+G!H<#HT,C(*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C4P,2!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z-3<P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU.#<@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C8V-0IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(T-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`P-0HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3<X"FUS9VED(").;W1E<R(*;7-G<W1R("+NS]3!
MU,O)(@H*(SH@<V5R=FEC97,O;V)R;W=S97(O:6YD97@N<&AP.C,V"FUS9VED
M(").;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,0HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S4*;7-G:60@
M(DYO=F5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$P-#8*(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B(*;7-G<W1R("*VS6#1
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R-0IM<V=I9"`B3G5M
M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3,V.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(S
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#4@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O
M9B!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$S-C<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,0HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0S('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@;V8@<F]W<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8T-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O
M<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8T"FUS
M9VED(")/2R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*;7-G:60@(D]B:F5C
M="!#<F5A=&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q,#0*;7-G:60@(D]C=&%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3`*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I
M9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,R-@IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N
M9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*(RP@9G5Z>GD*
M;7-G:60@(D]L9"!P87-S=V]R9"(*;7-G<W1R("+PP=+/S-@B"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*;7-G:60@(D]L9"!P87-S=V]R
M9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS
M9VED(")/;6%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S
M=7!P;W)T('-H87)E9"!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U
M;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW,0IM<V=I9"`B3VYL>2!O
M;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]S:&%R97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W
M;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S
M:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,U"FUS9VED(")/<&5N
M(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-33"!E<G)O<CH@
M0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R
M="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")/<&5N<R!T:&ES(&QI;FL@
M:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"B,L(&9U>GIY
M"FUS9VED(")/<'1I;VYS(@IM<V=S='(@(OK"Q=+%Q]3)(,_0PZ:G(@H*(SH@
M<V5R=FEC97,O<')E9G,N<&AP.C,Q('1E;7!L871E<R]P<F5F<R]A<'`N:6YC
M.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-PHC+"!F=7IZ>0IM<V=I
M9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(N'$S:;.IM/4TM77P<[.T2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38X"FUS9VED(")/
M<F=A;FES871I;VYA;"!5;FET(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ,S(*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B
M(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L
M(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E
M;7!L871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L
M('1E;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*
M;7-G:60@(D]T:&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,Q(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ-#$*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R
M(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<&%M+G!H<#HW.0IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B
M86-K96YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$R-S,*;7-G:60@(E!'4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S$Y
M"FUS9VED(")01U`@16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,W,0IM<V=I9"`B4$=0(%!U
M8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3,U,PIM<V=I9"`B4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T
M82(*;7-G<W1R("(B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-C@*(RP@9G5Z
M>GD*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(DAO<F1E(@H*(SH@861M:6XO
M<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*;7-G
M:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@(E!-(%-H;W=E<G,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,SD*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#`*;7-G:60@(E!-(%-N
M;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@4W5N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0R"FUS
M9VED(")032!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z,C<T"FUS9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN
M9R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#D*;7-G:60@(E!?2%`@
M4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A:VES=&%N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DR(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I
M960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")086YA;6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")087!U82!.97<@1W5I;F5A
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,V"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,3DY"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34Q
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,3@*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHW-R!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C0S"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C,*;7-G:60@
M(E!A<W-W;W)D(@IM<V=S='(@(O#!TL_,V"(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C
M97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,3,R,@HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0@:6YC
M;W)R96-T(@IM<V=S='(@(O#!TL_,V"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O
M<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(P-3,*;7-G:60@(E!A<W-W;W)D('=I=&@@
M8V]N9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHY,`HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S
M='(@(O#!TL_,V"(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q
M"B,L(&9U>GIY"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(O#!TL_,V"(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,#,T"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*
M;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G<W1R("+PP=+/S-@@
MS=73R=38(-/0IM?0P=/4R2XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3$Y
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O
M;2!C;&EP8F]A<F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B4&5N
M9&EN9R!3:6=N=7!S.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(E!E;W!L92(*;7-G<W1R("+RS\S8
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA
M:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@(E!E<F9O<FT@
M36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R("+WR<O/SL'4R2#0TL_&
MILS!R]3)WLZF(,_0Q=+!PZ:G(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0P-@HC+"!F=7IZ>0IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R
M871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R("+WR<O/SL'4R2#0TL_&ILS!R]3)
MWLZF(,_0Q=+!PZ:G(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HQ-38*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<&5R;7,O9&5L971E+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")097)M
M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#8*;7-G:60@(E!E<FUI<W-I;VX@
M1&5N:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,38Q(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38T"FUS
M9VED(")097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E
M9&ET+G!H<#HQ,#D@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P"B,Z(&%D
M;6EN+W!E<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP
M.C4X"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO
M;B(*;7-G<W1R("+AQ,VFSJ;3U-+5U\'.SM$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-C4*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G:60@(E!E=',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0:&EL:7!P:6YE<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3DV"FUS9VED(")0:&]N92(*;7-G<W1R("+TQ<S%QL_.(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0W.`IM<V=I9"`B4&AO=&]S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DP(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A:7)N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`X
M"FUS9VED(")0:7AE;',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4V"FUS9VED(")0;&%T:71U9&5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*
M;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-#D*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@
M=&\@<F5M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4V"FUS
M9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T
M:&ES(&5L96UE;G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(U-S$*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A
M('EE87(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C$R"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE
M(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,S`Q"FUS9VED(")0;&5A<V4@96YT97(@82!V
M86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-C8P"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!D
M871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4Q"FUS
M9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A
M<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@
M(N+5Q-@MS,'3R\$L(,3!RM3%(,O/TL_4R\G*(,_0R=,@T-+/PLS%S<DN(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S
M97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R("+BU<38+<S!T\O!+"#7R\'6
MIM38(,[!VM?5(,O/TLG3U-77P=[!(*8@T,'2S\S8(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C4X"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@
M9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS
M('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM<V=I9"`B
M4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3D*;7-G:60@(E!O;&%N9"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#<*;7-G:60@
M(E!O;&QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3DS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!O<G1U
M9V%L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S:71I;VYI;F<@
M;V8@=&AI<R!I;6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@
M;V8@=&AI<R!T86)L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES(&9O
M;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C8V(&QI8B]";&]C:R]M971A<BYP:'`Z,C<Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R(&QA<W0@
M)7,@:&]U<BAS*3H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR.3@*;7-G:60@(E!R96-I<&ET871I;VX\8G(@+SYC:&%N
M8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+VQD87`N
M<&AP.CDX"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@
M4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-0IM<V=I9"`B4')E<W-U
M<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3D*;7-G
M:60@(E!R97-S=7)E(&%T('-E82!L979E;#H@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S4*;7-G:60@(E!R97-S=7)E
M.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(P-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R979I97<B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(T"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A
M(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HS-C(@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS
M-C8*(RP@9G5Z>GD*;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`B
M\,_7Q=+.U=3)T]$@Q,\@[]##ILHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,C,*;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]-96YU+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@(E!R
M;V)L96TB"FUS9W-T<B`B6_#/UZ;$S\W,Q<[.T2#PTL_"S,7-R5TB"@HC.B!S
M97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C8*;7-G:60@(E!R;V)L96T@1&5S8W)I
M<'1I;VXB"FUS9W-T<B`B[]#)TR#0TL_"S,7-R2(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS-CD*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,3$@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C$X.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,C@U"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0T"FUS9VED
M(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I=F%T92!K
M97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`P"FUS9VED(")0=65R=&\@4FEC;R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`R"FUS9VED(")1871A<B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z-C,*;7-G:60@(E%U97)Y(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`IM<V=I9"`B475O=&$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I
M="DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V
M-`IM<V=I9"`B4F%D:6\@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0S"FUS9VED(")286EN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0T"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")2
M86EN($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0W
M"FUS9VED(")286EN(&%N9"!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")286EN('1O
M(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*
M;7-G:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C0@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*;7-G
M:60@(E)E860B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.#<*(RP@9G5Z>GD*;7-G:60@(E)E860@;65S<V%G
M97,B"FUS9W-T<B`B[,G3U"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E
M;6]V92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E
M("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@
M=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS-`IM<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HR-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B4F5F<F5S:"!$>6YA
M;6EC($UE;G4@16QE;65N=',Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-#$*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-"!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$S"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R,S4*(RP@9G5Z>GD*;7-G:60@(E)E9V5X(@IM<V=S='(@(N_>
MR=/4R=3)(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(T.0IM<V=I
M9"`B4F5L871I;VYS:&EP($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(P.`IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S(V"FUS9VED(")296UA<FMS(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,30*;7-G:60@(E)E;6]T92!3
M97)V97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHX-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE
M+F-O;2]H;W)D92DZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O961I="YI;F,Z,C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V
M92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D
M+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(@IM<V=S='(@(O?)U,72
MU,D@T,'2U2(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,0HC
M+"!F=7IZ>0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@(O?)U,72U,D@
MT,'2U2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HU-3<*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`HC+"!F=7IZ
M>0IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`B]\G4Q=+4R2#0
MP=+5(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,C@*;7-G:60@
M(E)E;6]V92!P86ER(@IM<V=S='(@(O?)U,72U,D@T,'2U2(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HR,#(*;7-G:60@(E)E;6]V92!S879E9"!S8W)I
M<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-#(*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T
M<B`B]\G4Q=+4R2#0P=+5(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO=F4@=&AI<R!N
M;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E)E
M;6]V92!U<V5R(@IM<V=S='(@(O?)U,72U,D@T,'2U2(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z-0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(O?)U,72U,D@T,'2
MU2(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED
M(")297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O
M<F-O9&4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,34W"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@
M8F4@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,3<T(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$R"B,L('!H
M<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D
M(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z-C<U(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z.#,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,C,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C
M:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<X,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E
M<F5R+G!H<#HS,S4*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C,Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,S.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,C`@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C<W"FUS9VED(")297-E="(*;7-G<W1R
M("+OWLG3U,G4R2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V
M"B,L(&9U>GIY"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R("+PP=+/
MS-@B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PHC+"!F=7IZ
M>0IM<V=I9"`B4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R("+PIL34U\72
MQ-;%SL[1(-#!TL_,P"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S`*;7-G
M:60@(E)E<W1O<F4@3&%S="!1=65R>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]P
M:'!S:&5L;"YP:'`Z-S$@861M:6XO8VUD<VAE;&PN<&AP.C(X(&%D;6EN+W-Q
M;'-H96QL+G!H<#HV-@HC+"!F=7IZ>0IM<V=I9"`B4F5S=6QT<R(*;7-G<W1R
M("+OWLG3U,G4R2(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ
M,#$@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O
M($]P=&EO;G,B"FUS9W-T<B`B\,_7Q=+.U=3)T]$@Q,\@[]##ILHB"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S@*;7-G:60@(E)E='EP92!N
M97<@<&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B
M4F5U;FEO;B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#
M;VYF:6=U<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,S(*(RP@9G5Z>GD*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@3W!T
M:6]N<R(*;7-G<W1R("+PS]?%TL[5U,G3T2#$SR#OT,.FRB(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,Q,C$*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$W"FUS9VED(")2
M:6=H="!V86QU97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X"FUS9VED(")2;U]W(%!R
M;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R("+R
MS\S8(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(U
M"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,C(*;7-G:60@(E)O=&%T92!,
M969T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,C@*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P
M"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W
M<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU,PHC+"!F=7IZ>0IM<V=I9"`B4G5L97,B"FUS
M9W-T<B`B\L_,V"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E
M='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM
M<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$R,`IM<V=I9"`B4G5N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3DY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*
M;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`S"FUS9VED(")2=V%N9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#<GEP
M=&]G<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y
M<'1E9"!-97-S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<V%S;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@
M;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C4P-`HC+"!F=7IZ>0IM<V=I9"`B4TU3($UE<W-A9VEN9R(*
M;7-G<W1R("+LR=/4(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS9VED
M(")344P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S(X,PIM<V=I9"`B4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O
M:W5P<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#,Q"FUS9VED(")34T@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF
M:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM
M<V=I9"`B4U5#0T534R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-3,*
M;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE
M=FES(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B4V%I;G0@3'5C
M:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE
M<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Y,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS
M9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDR"FUS9VED(")386UE(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-PIM<V=I9"`B4V%M;V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`W"FUS9VED(")386\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T
M96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G
M:60@(E-A=61I($%R86)I82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+VQA>6]U="YI;F,Z.3@*;7-G:60@(E-A=F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3879E(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4V%V92`E<R(*;7-G<W1R("+ZPL72Q<?4R2#/T,.FIR(*"B,Z('1E
M;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*
M;7-G<W1R("+ZPL72Q<?4R2#/T,.FIR(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-C<*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I
M;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y
M("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G
M<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*;7-G:60@(E-C871T
M97)E9"!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C:"(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(P"FUS9VED(")396%R8V@@16YG
M:6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.3<S"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-`HC+"!F=7IZ>0IM
M<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R("+WR<+%TJ;4V"#&S]+-P=0@
MQ,'4R3HB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I
M9"`B4V5L96-T(&$@9W)O=7`@=&\@861D(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O
M=VYE<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z-C`*;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U-@IM<V=I9"`B4V5L96-T(&$@
M=7-E<B!T;R!A9&0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C8W-PIM<V=I9"`B4V5L96-T(&%L;"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8S"B,L(&9U
M>GIY"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T
M<B`B]\G"Q=*FU-@@QL_2S<'4(,3!U,DZ(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B4V5L96-T(&%N(&]B
M:F5C="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-C<X"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@
M(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B
M;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H
M96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B+WR<+%TJ;4V"#.
MQ<_"R*;$SJ8@]\'-(-/)S=?/S,D@VB#0S\RFUR#.R=;>Q2X@]\D@VLW/UL74
MQ2#3R\_0IL#7P=3)(*?((*8@(@HBU]/4P=?)U,D@VB#0S\S1(-?7S\35(-3%
MR]/4U2XB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B
M4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`B]\G"Q=*FU-@@
MTL_:Q*;,P-?!WB#$P=3).B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R("+W
MR<+%TJ;4V"#&S]+-P=0@Q,'4R3HB"@HC.B!T96UP;&%T97,O<')E9G,O:61E
M;G1I='ES96QE8W0N:6YC.CDP"FUS9VED(")396QE8W0@=&AE(&ED96YT:71Y
M('EO=2!W86YT('1O(&-H86YG93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O=&EM92YI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@
M=&EM92!D96QI;6ET97(Z(@IM<V=S='(@(O?)PL72IM38(-+/VL2FS,#7P=X@
MQ,'4R3HB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B
M4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`B]\G"Q=*FU-@@QL_2
MS<'4(-[!T]4Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-PHC
M+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N(@IM
M<V=S='(@(O>FQ-#/UZ;$SJ8@T,_,T2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS,#8*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T.`IM<V=I9"`B
M4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N
M9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R("+WIL2FT\S!U,D@T,_7IL3/S<S%
MSL[1(-#2SR#0TL_"S,7-U2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,#,Y"FUS9VED(")396YD(%--4R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`V"FUS9VED(")396YE9V%L(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S$V"FUS9VED(")396YS;W(Z("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`Y"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW,PIM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD
M($UO;G1E;F5G<F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HW,#$*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,0IM<V=I
M9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(W"FUS9VED(")397-S:6]N
M($%D;6EN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I
M<F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#4*(RP@9G5Z>GD*
M;7-G:60@(E-E<W-I;VYS(@IM<V=S='(@(OK"Q=+%Q]3)(,_0PZ:G(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-`IM<V=I9"`B4V5T(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-@IM<V=I9"`B4V5T
M(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@
M:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED(")3970@=7`@<F5M;W1E('-E<G9E
M<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T"FUS9VED
M(")3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D
M871E(&]P=&EO;G,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY.`IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO
M;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B
M"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-S4*;7-G:60@(E-E='5P(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3971U
M<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ.#8*;7-G:60@(E-E=F5R86P@
M;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Y-@IM<V=I9"`B
M4VAO<'!I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z-#,*(RP@9G5Z>GD*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS
M9W-T<B`BZ\_2S]3+R<H@VLVFT]0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#0V"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F
M;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U-0IM<V=I9"`B(@HB4VAO=R!D
M:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE
M=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DP"FUS9VED(")3:&]W(&QA<W0@
M;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C4*;7-G:60@(E-H;W<@;W!T:6]N
M('1O(&ME97`@;W)I9VEN86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@Q,PIM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R-@IM<V=I9"`B4VAO=R!T
M86)L92!O<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S0Y"B,L('!H<"UF;W)M870*;7-G:60@(E-H
M;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO
M9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R
M;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I9"`B4VAO
M=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L
M;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V
M,PIM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3`*;7-G:60@(E-H;W=E<G,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-3$*;7-G:60@(E-H;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@
M(E-H;W=E<G,@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!I;B!T:&4@
M5FEC:6YI='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z-#@P"FUS9VED(")3:')I;FLB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-S<T(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C@S-@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HY,C(@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z.3@T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C$P-#<@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M,3`X-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,3$V
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q-#D*;7-G:60@
M(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@
M=&AE('=A>2!F:7)S="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED
M(")3:65R<F$@3&5O;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.C(V-0IM<V=I9"`B4VEG;B!U<"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM<V=I
M9"`B4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-S$Q"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C8U(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-R!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HX.38*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(Q-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,W"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#8@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,CDS,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(S"FUS
M9VED(")3:7IE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]M86EN=&5N86YC92YH=&UL.C4R"FUS9VED(")3:VEP($UA:6YT96YA;F-E
M(@IM<V=S='(@(O#2S]#5T]3)U,D@T-+/QJ;,P<O4R<O5(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-0IM<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-30*;7-G:60@(E-N;W<B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-34*;7-G:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V"FUS9VED(")3;F]W(%-H
M;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-3<*;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU.`IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S@*;7-G:60@(E-N;W<@9&5P=&@Z("(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X,@IM<V=I9"`B
M4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#8*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED(")3;VYG<R`F(%!O96US(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C8*;7-G
M:60@(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Q
M-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR-#<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ
M-C8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.#D*
M(RP@9G5Z>GD*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM<V=S='(@(O+/PL_>
MP2#!Q-+%T\$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")3;W5T:"!!9G)I8V$B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@
M(E-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S<*;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!3
M86YD=VEC:"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N
M($AE;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E96X@
M861J86-E;G0@8V5L;',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E='=E
M96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#$U"FUS9VED(")3<&%C97(B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@P"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*
M;7-G:60@(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S$*;7-G:60@(E-P86EN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HY.`IM<V=I9"`B4W!A;2(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@0VAA<F%C
M=&5R($EN<'5T(@IM<V=S='(@(O?7IL0@\]#%PZ;!S-C.R<@@T\G-U\_,IM<B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*;7-G
M:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI
M="!R;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Q
M"B,L(&9U>GIY"FUS9VED(")3<&]R=',B"FUS9W-T<B`BMLW0S]+4(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@X"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<S(&QI8B]";&]C:R]M971A<BYP
M:'`Z-S0*;7-G:60@(E-T86YD87)D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.38@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@P.0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I
M9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$U"FUS9VED
M(")3=&]R86=E(&9O<FUA="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4W,@HC+"!F=7IZ>0IM<V=I9"`B4W1R965T
M($%D9')E<W,B"FUS9W-T<B`B\L_"S][!(,'$TL73P2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK
M971H<F]U9V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(S,PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,PIM<V=I9"`B4W1R:7`@9&]M86EN
M(&9R;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y
M;&4@6T-34UTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T<B`B(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@
M(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S"FUS
M9VED(")3=6)J96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,S,B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS
M,3<*;7-G:60@(E-U8FUI="(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C0Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O
M(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@;&]G(&EN
M('5N=&EL('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].
M;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C
M8V5S<R(*;7-G<W1R("+UT]"FV\[/(@H*(SH@861M:6XO=7-E<BYP:'`Z.#4*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E
M9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B]=/0IMO.SR#$S\3!
MSL\@)R5S)R#$SR#3R=/4Q<W)+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R
M960@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G
M<W1R("+UT]"FV\[/(-?)Q,',Q<[/("<E<R<@VB#3R=/4Q<W)+B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T
M960@7"(E<UPB+B(*;7-G<W1R("+UT]"FV\[/(,3/Q,'.SR`G)7,G(,3/(-/)
MT]3%S<DN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O
M;2!T:&4@<WES=&5M+B(*;7-G<W1R("+UT]"FV\[/(-?)Q,',Q<[/("<E<R<@
MVB#3R=/4Q<W)+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G
M:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO
M860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HU.2!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU-PIM<V=I
M9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8R"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P
M(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,38X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C
M97-S9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`B]=/0IMO.SR#$S\3!
MSL\@)R5S)R#$SR#3R=/4Q<W)+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`B
M]=/0IMO.SR#$S\3!SL\@)R5S)R#$SR#3R=/4Q<W)+B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#0*;7-G:60@(E-U9&%N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*(RP@9G5Z>GD*;7-G
M:60@(E-U;6UA<GDB"FUS9W-T<B`BZ\_2S]3+R<H@VLVFT]0B"@HC.B!L:6(O
M0FQO8VLO<W5N<FES92YP:'`Z-C4*;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E
M="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU.0IM<V=I9"`B4W5N;GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-@IM<V=I9"`B4W5N<FES92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO
M<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,34*;7-G:60@
M(E-U;G)I<V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C$Y"FUS9VED(")3=6YS970B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.`IM<V=I9"`B4W5N<V5T.B`B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W.`HC+"!F=7IZ>0IM<V=I9"`B
M4W5P<&]R="(*;7-G<W1R("*VS=#/TM0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"B,L(&9U
M>GIY"FUS9VED(")3=7)I;F%M92(*;7-G<W1R("+NP=K7P2#+S]+)T]35U\'>
MP2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<T"B,L
M(&9U>GIY"FUS9VED(")3=7)N86UE(@IM<V=S='(@(N[!VM?!(,O/TLG3U-77
MP=[!(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-
M87EE;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA
M;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-38@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")3=VET>F5R;&%N9"(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@IM<V=I
M9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,30R"FUS9VED(")3>6YC34PB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3>6YT
M87@@97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#<*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS
M9VED(")4+5-T;W)M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8Q"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV,@IM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*;7-G:60@(E0M
M4W1O<FUS($5A<FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A
M=&$O='-V+G!H<#HQ-C8*(RP@9G5Z>GD*;7-G:60@(E135B!F:6QE(@IM<V=S
M='(@(O3)U-7,(@H*(SH@9G)A;65W;W)K+U5)+U5)+U1A8FQE+G!H<#HQ,S0*
M(RP@9G5Z>GD*;7-G:60@(E1A8FQE(@IM<V=S='(@(O3)U-7,(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM
M<V=I9"`B5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W"FUS9VED(")486)L
M92!3970B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")486EW
M86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDY-B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3@W"FUS9VED(")487-K<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,PIM<V=I9"`B
M5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(Y,`IM<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,30*;7-G:60@(E1E;7!E
M<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,C,*;7-G:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G
M.R5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T
M92YP:'`Z-C@W"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<
M(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP
M:'`Z,38Y"B,L(&9U>GIY"FUS9VED(")496UP;&%T92!!9&UI;FES=')A=&EO
M;B(*;7-G<W1R("+AQ,VFSJ;3U-+5U\'.SM$B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S8*
M;7-G:60@(E1E>'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,W-0IM<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G
M:60@(E1E>'0@86QI9VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y,0IM<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"FUS9VED(")4:&%N:R!Y;W4@
M9F]R('5S:6YG('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#(P"FUS9VED(")4:&4@1E10(&5X=&5N<VEO
M;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O
M<G0@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?24U34"])
M35-0+T)O;VLN<&AP.C$R.3(*;7-G:60@(E1H92!)35-0(&QO9R!C;W5L9"!N
M;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA
M:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA
M<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@
M3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.#D@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HR,#`*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HR,3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,C,*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,S0@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HR-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-C0@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A
M9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!0
M97)M:7-S:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S92!097)M
M:7-S:6]N<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S
M:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT86-T
M($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W
M87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4Q"FUS
M9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO
M=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,38Y"FUS9VED("(B"B)4:&4@9&5T86-H960@
M4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE
M('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B(@HB5&AE
M(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE
M9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T
M('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0N<&AP.C$Q,PIM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A
M='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S4@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V."!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR
M,3D*;7-G:60@(E1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S
M96QF+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR
M.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP
M.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@
M=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4V"FUS9VED
M("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P
M<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O
M=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N
M("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E(&1I<W!L87DL(&QA
M8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@
M8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G
M<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"`B"B)0
M<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U
M(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U
M('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T
M960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T+6AA;F0@<VED
M92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G50
M1R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA
M<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H
M<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N
M="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I
M<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE
M<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<W"FUS9VED(")4:&4@
M;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Q
M"FUS9VED(")4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,3(S,0IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D
M(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+G!H<#HR.3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO
M="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M
M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A
M=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#4T"FUS
M9VED(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C
M:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A
M;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H
M92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HT-#8*;7-G:60@(E1H92!S97!A<F%T;W(@
M;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@
M<V%V960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA
M<R!B965N(')E;6]V960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C,S,`IM<V=I9"`B5&AE('-P96-I9FEE9"!R
M;W<@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,3<W"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T
M96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,3$*;7-G:60@(E1H
M92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@
M=&AE('-C<F5E;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A
M;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B
M5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A
M=&$O1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@
M;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T1A=&$O1&%T82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T
M82]$871A+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C
M;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HT-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-38*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q-2!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$Y"FUS9VED(")4:&4@=V5A=&AE
M<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-S@*;7-G:60@
M(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z,S0R"FUS9VED
M(")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN
M;&EN92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA
M;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D
M("5S(&-H87)A8W1E<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E
M<RXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U<V5R+G!H
M<#HW,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@
M<')O8FQE;2!A9&1I;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S
M='(@(O32P=#)S,'3T2#0TL_"S,7-P2#0TLD@Q,_$P=?!SLZF("<E<R<@Q,\@
MT\G3U,7-R2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@
M9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T
M<B`B]-+!T,G,P=/1(-#2S\+,Q<W!(-#2R2#7R<3!S,7.SJ8@)R5S)R#:(-/)
MT]3%S<DN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG(%PB
M)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("+TTL'0R<S!T]$@T-+/
MPLS%S<$@T-+)(-?)Q,',Q<[.IB`G)7,G(-H@T\G3U,7-R2XB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ-3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R
M("+TTL'0R<S!T]$@T-+/PLS%S<$@T-+)(,3/Q,'7P<[.IB`G)7,G(,3/(-/)
MT]3%S<DN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@T
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@Y"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE
M(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y,0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P
M;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS
M,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A
M;&5N9&%R(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z.#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@
M8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A("(*
M(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE
M<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R
M97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C0P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I
M;B!L871E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HR,C(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E
M<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T
M<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T.`IM<V=I9"`B5&AI<R!)34%0('-E
M<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HT
M.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R
M87(@87)C:&EV92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E
M87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$T-0IM<V=I9"`B5&AI<R!D;V5S(&YO
M="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L
M:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HQ,S0*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI
M("(*(F=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q
M-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S
M<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M
M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M
M='`N<&AP.C@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN
M9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)
M=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET
M(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)
M=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HY-S@@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3`U-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#@V(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,34*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3$X,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C4V"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#4@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,Y.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-34W(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,SD*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3DU."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`U"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,CD@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`W.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,30Y
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,C$*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C0Q,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4T
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-3<@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@R.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,3,W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,#8*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S@Q-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M.#(R"FUS9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#8U"FUS9VED(")4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3@*;7-G:60@(E1H:7,@
M9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.30*
M;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU
M97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q
M,C,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E
M('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDX.0IM<V=I9"`B5&AI<R!F:65L9"!M
M=7-T(&)E(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.#,V"FUS9VED("(B"B)4:&ES(&9I96QD(&UU
M<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T
M+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C4V,0IM<V=I9"`B5&AI<R!F;W)M(&AA
M<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&ES(&ES("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C0U.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@
M2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y
M;W4@=VEL;"!N965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N9&5R<W1A
M;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F
M('-U8V@@96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DQ
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@;65S<V%G92!W87,@=W)I='1E
M;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G
M>FEP+G!H<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S
M<R!Z:7`@86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3@Y"FUS9VED(")4:&ES('-Y
M<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(T"FUS9VED(")4:&ES
M('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN
M9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C0*;7-G:60@(E1H=6YD97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(S-`IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#(X('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B5&EM92(*;7-G
M<W1R("+TR=35S"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#8*
M;7-G:60@(E1I;64@5')A8VMI;F<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W1I;64N<&AP.C$W"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3,Y"FUS9VED(")4:6UE('-E
M;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4:6UO
M<BU,97-T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P"FUS
M9VED(")4:71L92(*;7-G<W1R("+TR=35S"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L
M=&EP*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U-`IM<V=I9"`B
M(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O
M;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC
M:VEN9RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,Q,0IM<V=I9"`B5&]D87DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE
M($A434P@4V]U<F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@
M(E1O9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA
M=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S$S"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P
M"FUS9VED(")4;VYG82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S<*;7-G:60@(E1O<"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDS"FUS9VED(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I9"`B5')A;G-L871I;VYS
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N
M9"!4;V)A9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3<Y,`IM<V=I9"`B5')U92!O<B!F86QS92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED
M(")4=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=6YI<VEA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U<FME>2(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,@IM<V=I9"`B5'5R
M:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM
M<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*
M;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-,22]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC
M93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR-CD*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*
M;7-G:60@(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E
M<&]R="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CDW"B,L(&9U>GIY"FUS9VED(")54DPZ(@IM<V=S='(@
M(E523"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5G86YD82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$R"FUS9VED(")5:W)A:6YE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0Q,@IM<V=I9"`B56YA8FQE
M('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T
M;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S@X
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES
M<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS.#4@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(S,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z-C@X(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3`Q-@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z.#,T"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z
M-#,U"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S.0IM
M<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R-2!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#D*;7-G
M:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,V-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-30@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(U.`HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C4V"FUS9VED(")5;F%B;&4@=&\@8W)E
M871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HQ,C0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@
M5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z,C@V"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A
M=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(V-0IM<V=I9"`B56YA8FQE('1O(&-R96%T
M92!E;7!T>2!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+W1A<BYP:'`Z-S8*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"FUS9VED(")5;F%B;&4@=&\@9&5C
M;VUP<F5S<R!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C(R-"!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(Y.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@
M=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z-S@@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@
M)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C,S,2!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,Y,@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S$Q(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HS,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T."!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4R"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S-R!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HS,S4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C,T,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#$W(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z-#(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C`W"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,#,@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR.#@*(SH@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C$V-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,3@P"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,X,PHC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDQ"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C(T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0P-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#`S"FUS9VED
M(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8P
M,PIM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z
M-#4Q(&9R86UE=V]R:R].971?24U34"])35-0+T%U=&@N<&AP.C$Q.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO
M;B!O9B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P,0HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,38V(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HQ-S$*;7-G:60@(E5N86)L92!T;R!M;W9E
M(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.CDS(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,3`R"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-C0X(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P
M96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR-S<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,3,S"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN
M9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M.#`@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,@IM<V=I9"`B56YA8FQE('1O(&]P
M96X@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1G>BYP:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O
M;7!R97-S960@87)C:&EV92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C@S-0IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@
M*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C@V-@IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I
M;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP
M.C,X"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C8Y"FUS9VED(")5;F%B
M;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$P-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA
M=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(Y,PIM<V=I9"`B56YA8FQE
M('1O(')E;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(V-R!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C,T,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C$P(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HR,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,C,@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C(Q,PHC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z-#4R(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.#4*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,P,0IM<V=I9"`B56YA
M8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS
M9VED(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I
M9"`B56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-#D@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3<Y"FUS9VED(")5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR.#$@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S.`HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,30S"FUS9VED(")5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C@T,0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P"FUS9VED(")5
M;F1E<FQI;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI
M;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(O/+P=/5U\'4R2#:
MS:;.R2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R
M,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.3`*
M;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N
M;F5C=&EO;CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS-#$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S<X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,X-`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M
M('-E<G9E<B!T;SH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q"FUS9VED(")5;F9I;&5D(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS"FUS9VED(")5
M;FEC;V1E("A55$8M."DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@
M(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-`IM<V=I9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES
M;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C8Y(&QI8B]";&]C:R]M971A<BYP:'`Z-S$*;7-G:60@(E5N:71S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R
M.2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,S`*;7-G:60@(E5N
M:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P:6US9VED
M("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK
M;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y"FUS9VED(")5
M;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*;7-G
M:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HR
M.38*(RP@9G5Z>GD*;7-G:60@(E5N;F%M960B"FUS9W-T<B`B[L':U\$@R\_2
MR=/4U=?!WL$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN
M;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@
M(@HB<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN
M:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H
M;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@V(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3(V"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3,R"FUS9VED(")5;G-U<'!O<G1E
M9"!%>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HQ.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,S,*;7-G:60@(E5P9&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P
M9&%T92`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C<V"B,L(&9U>GIY"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G
M<W1R("+DS\3!U,D@R\_2R=/4U=?!WL$B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C$T-"!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC97,O<VAA<F5S
M+V5D:70N<&AP.C(S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S@@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y.0IM<V=I9"`B57!L;V%D(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#8*;7-G:60@(E5P
M;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R
M=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L:7-T='EP95]L86YG+FIS.C(P"FUS9VED(")5<'!E<B!L871I;B!L
M971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N
M(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B57)U
M9W5A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T
M96=O<GE-86YA9V5R+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@
M0W5R<F5N=#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S92!34TPB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-`IM<V=I9"`B
M57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E
M<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E
M9&ET+FEN8SHR,0HC+"!F=7IZ>0IM<V=I9"`B57-E<B(*;7-G<W1R("+NP=K7
MP2#+S]+)T]35U\'>P2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I
M<W1R>2YP:'`Z-S(S"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@
M;F]T(&%U=&AO<FES960@9F]R("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HR,#,*(RP@9G5Z>GD*;7-G:60@(E5S97(@061M:6YI<W1R871I
M;VXB"FUS9W-T<B`BX<3-ILZFT]32U=?!SL[1(,O/TLG3U-77P=ZFUR!(;W)D
M92(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C4Q"B,L(&9U
M>GIY"FUS9VED(")5<V5R($]P=&EO;G,B"FUS9W-T<B`B^L+%TL7'U,D@S]##
MIJ<B"@HC.B!S:6=N=7`N<&AP.C8R"B,L(&9U>GIY"FUS9VED(")5<V5R(%)E
M9VES=')A=&EO;B(*;7-G<W1R("+AQ,VFSJ;3U-+5U\'.SM$@R\_2R=/4U=?!
MWJ;7($AO<F1E(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I9"`B57-E<B!296=I
M<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0V.0IM<V=I9"`B
M57-E<B!A8V-O=6YT(&YO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.CDX
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U
M,"!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,PHC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C<R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O
M=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G<W1R("+NP=K7P2#+S]+)
MT]35U\'>P2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HQ
M,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E<UPB(&%L<F5A
M9'D@97AI<W1S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.#<*(RP@9G5Z>GD*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R
M("+NP=K7P2#+S]+)T]35U\'>P2(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C@*(RP@9G5Z>GD*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B
M[L':U\$@R\_2R=/4U=?!WL$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L
M:7-T+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R
M("+KS]+)T]35U\'>IB#7(-/)T]3%S:8Z(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I
M9"`B57IB96MI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HQ-C,@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C4U
M"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3$X"FUS9VED(")6
M86-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HX-C8*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV,S@*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0IM<V=I
M9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#4V(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Q-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@;W9E
M<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#0@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(V-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$V(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C@*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0IM<V=I9"`B5F%L=65S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#D@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-@IM<V=I9"`B5F%L=65S('1O('-E;&5C
M="!F<F]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E9A;G5A
M='4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(T-`IM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED(")697)I9FEC871I;VX@
M9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@
M=VET:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HW,#`*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R-@IM<V=I9"`B5F5R<VEO;B!#;VYT
M<F]L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L(&%L:6=N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PIM
M<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P"FUS9VED(")697)Y($AI9V@B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FEE="!.86TB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.30*;7-G:60@(E9I971N
M86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z.38R"B,L('!H<"UF;W)M870*;7-G:60@(E9I
M97<@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM
M<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,C$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@52Y3
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P.0IM<V=I
M9"`B5FES:6)I;&ET>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C8S"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT
M<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET86QY('9I82!33510(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($92
M3TT@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,3,S"FUS9VED(")724X@=FEA($A45%`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I
M;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]H=&UL+G!H<#HR-S(@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C@S"FUS9VED(")787)N:6YG(@IM<V=S='(@(O77P<?!(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y
M"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,C<*;7-G:60@(E=E871H97(@9&%T
M82!P<F]V:61E9"!B>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HX.3(*;7-G:60@(E=E871H97(N8V]M(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED(")796(B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S-PIM<V=I9"`B5V5B
M(%-I=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA
M:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM<V=S='(@(OW/U,G6
MSM$B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`HC+"!F=7IZ
M>0IM<V=I9"`B5V5L8V]M92(*;7-G<W1R("+WIM3!P"#WP=,L("5S(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C4W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")796QC
M;VUE('1O("5S(@IM<V=S='(@(O>FU,'`(/?!TRP@)7,B"@HC.B!S97)V:6-E
M<R]P;W)T86PO;6]B:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N
M:6YC.C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T
M<B`B]Z;4P<`@]\'3+"`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DU
M"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5V5S=&5R;B`H25-/+3@X
M-3DM,34I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")797-T97)N
M(%-A:&%R82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#,W"B,L('!H<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO
M=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T(&ES('1H
M92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O
M=&4@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V,0IM<V=I9"`B5VAE<F5I<R!!=7-T
M<F%L:6$@;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR
M,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,S,*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@96YA
M8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$R-0IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@
M*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS
M9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G:60@(E=I
M9'1H('5N:70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$S"FUS9VED(")7:6MI
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M,#`@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C4*;7-G
M:60@(E=I;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,`IM<V=I9"`B5VEN9"!S<&5E
M9"!I;B!K;F]T<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$U-@IM<V=I9"`B5VEN9#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(T,@IM<V=I9"`B5VEN9#H@(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.38*;7-G
M:60@(E=I<VAL:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D
M<F5S<R(*;7-G<W1R("+RS\+/WL$@P<32Q=/!(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N
M92(*;7-G<W1R("+RS\+/WLG*(-3%S,7&S\XB"@HC.B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HQ-CD@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M,C8R"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L
M9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,#`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T
M960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HQ,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@
M;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T,PIM<V=I9"`B6"U2
M968B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.3,*;7-G:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y
M,@IM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I
M9"`B6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I
M9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#(*;7-G:60@
M(E@U,#EV,R!E>'1E;G-I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R("+R\B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3,*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-0HC+"!F=7IZ>0IM<V=I
M9"`B65E962(*;7-G<W1R("+R\B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,3`X"FUS9VED(")986AO;R$@;6%P(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP
M:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G<W1R("+]S]*FWL[/(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-PIM<V=I9"`B665M96XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV,PIM<V=I9"`B665S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC
M92YH=&UL.C4V"FUS9VED(")997,L($D@06=R964B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I
M9"`B66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N
M('1O('-W:71C:"!B86-K('1O(%=94TE764<N(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@
M8FQO8VMS+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C$T,3$*;7-G:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z
M,S`R"FUS9VED(")9;W4@8V%N(&YO="!H879E('1H92`G7%PG(&-H87)A8W1E
M<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3@U-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.3<U"FUS9VED(")9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D
M9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP
M.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A
M;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E
M<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HY.#@*;7-G:60@(EEO=2!H879E(&)E96X@
M;&]G9V5D(&]U="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(V,0IM<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI
M9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO
M;F%L("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F
M:7@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q
M.#@*;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HS
M-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N
M9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HT-38*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A
M(%9&4R!B86-K96YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@=&AE
M('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O
M<G0N(@IM<V=S='(@(O?)(-#/U\G.SJ8@S]#)T\'4R2#0TL_"S,7-U2P@T,72
MVR#.IM8@UZ;$T\G,P=3)(-#/UZ;$S\W,Q<[.T2#0TL\@SL6G+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*;7-G:60@
M(EEO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT
M<R!T;R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H
M<#HX,`HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E
M<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R("+WP<T@T\RFQ"#7R\':P=3)(,[!
MVM?5(,O/TLG3U-77P=[!(,3,T2#7R<3!S,7.SM$N(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3$Y"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@
M=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R("+WP<T@T\RFQ"#7R\':
MP=3)(,[!VM?5(,O/TLG3U-77P=[!(,3,T2#7R<3!S,7.SM$N(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E
M<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R("+WP<T@T\RFQ"#7R\':P=3)(,[!
MVM?5(,O/TLG3U-77P=[!(,3,T2#7R<3!S,7.SM$N(@H*(SH@861M:6XO=7-E
M<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS
M9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM
M<V=S='(@(O?!S2#3S*;$(-?+P=K!U,D@SL':U]4@R\_2R=/4U=?!WL$@Q,S1
M(,3/Q,'7P<[.T2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#8*(RP@9G5Z>GD*
M;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T
M92XB"FUS9W-T<B`B]\'-(-/,IL0@U\O!VL'4R2#.P=K7U2#+S]+)T]35U\'>
MP2#$S-$@Q,_$P=?!SL[1+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]Z:7`N<&AP.C$S.`HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E
M8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R("+WP<T@T\RF
MQ"#7R\':P=3)(,[!VM?5(,O/TLG3U-77P=[!(,3,T2#7R<3!S,7.SM$N(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z
M-S$*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O
M<GD@;F%M92XB"FUS9W-T<B`B]\'-(-/,IL0@U\O!VL'4R2#.P=K7U2#+S]+)
MT]35U\'>P2#$S-$@U\G$P<S%SL[1+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S"FUS9VED(")9;W4@;F5E
M9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S
M92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z,S@*(RP@9G5Z>GD*;7-G:60@(EEO=7(@16UA:6P@
M061D<F5S<R(*;7-G<W1R("+WP=O!(,'$TL73P2#%+=#/V]3).B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR,3(*(RP@9G5Z>GD*;7-G:60@(EEO=7(@
M1G)O;3H@861D<F5S<SHB"FUS9W-T<B`B]\';P2#!Q-+%T\$@Q2W0S]O4R3HB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C0@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C<T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@(EEO=7(@26YF;W)M871I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@P"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H87,@
M8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO
M;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I
M;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z,S,*(RP@9G5Z>GD*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R
M("+WP=O%(*;-)]$Z(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N
M:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D
M;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@
M(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U
M(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N(&)A8VME
M;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES
M="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD
M(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U
M<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@
M=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E
M<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M
M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R
M86UE+G!H<#HU,`IM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O
M<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]P<FEN="YJ<SHT,@IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O
M97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R
M;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3<*;7-G:60@(EEO=7(@8W5R<F5N="!T
M:6UE('IO;F4Z(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY
M-@IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG
M960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3@*
M(RP@9G5Z>GD*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>3HB"FUS9W-T
M<B`B[]/.S]?.P2"FT,_3U,'3V"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,#$*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R
M("+WP=O%(*;-)]$Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z,3`P
M,`IM<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-`IM
M<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@
M9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I
M;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H
M87,@8F5E;B!R97-E="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E
M;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U
M<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.C<S,@IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP
M:7)E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C4X"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-"!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G
M:60@(EIA:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA
M;6)I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")::6UB86)W
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G
M:60@(EII<'!Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E
M<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U
M;W1E9"!497AT72(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H
M<#HX.`IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R(");\,_7IL3/
MS<S%SL[1(/#2S\+,Q<W)72(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U
M;W1E0FQO8VMS+FIS.C$S"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG
M:&QI9VAT<75O=&5S+G!H<#HQ-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H
M;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,34T,2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC
M.C$Q"B,L(&9U>GIY"FUS9VED(")?061M:6YI<W1R871I;VXB"FUS9W-T<B`B
MX<3-ILZFT]32U=?!SL[1(@H*(SH@;&EB+V%P:2YP:'`Z,34W"FUS9VED(")?
M0TQ)(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T,0IM<V=I9"`B7T1A
M=&%4<F5E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0HC+"!F=7IZ>0IM<V=I9"`B7T1E
M;&5T92!2;W<B"FUS9W-T<B`B]\G4Q=+4R2(*"B,Z(&QI8B]A<&DN<&AP.C$S
M,PIM<V=I9"`B7T=R;W5P<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O365N=2YP:'`Z,3<U"B,L(&9U>GIY"FUS9VED(")?2&5L<"(*
M;7-G<W1R("+DS]#/S<_'P2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R;W!E
M<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+TUE;G4N<&AP.C$Y-`HC+"!F=7IZ>0IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R
M("+WUZ;*U,DB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z
M,3DP"B,L(&9U>GIY"FUS9VED(")?3&]G(&]U="(*;7-G<W1R("+WR<K4R2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR-`IM<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-C0*(RP@9G5Z>GD*
M;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(OK"Q=+%Q]3)(,_0PZ:G(@H*(SH@
M;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?4&5R;6ES<VEO;G,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(V"B,L(&9U>GIY"FUS9VED(")?4F5M;W9E($QI;FLN+BXB"FUS
M9W-T<B`B]\G4Q=+4R2#0P=+5(@H*(SH@;&EB+V%P:2YP:'`Z,3(U"FUS9VED
M(")?4V5T=7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED(")?5&%B;&4@4')O
M<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,CD*;7-G
M:60@(E]5<V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDR,0HC+"!F=7IZ>0IM<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S
M='(@(N'$TL73SL$@R\[)Q\$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$S-`IM<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3,*;7-G:60@
M(F-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,3<R(&QI8B]";&]C:R]M971A<BYP:'`Z,S4X"B,L('!H<"UF;W)M870*;7-G
M:60@(F-A;&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I
M;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,@IM<V=I
M9"`B8VQI8VL@:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E
M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,3<X"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34T
M"FUS9VED(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(V"FUS
M9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$X,@IM<V=I9"`B96YT<GD@;F]T
M(&9O=6YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")F86QL:6YG(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U-0HC+"!F=7IZ>0IM
M<V=I9"`B9FEL92(*;7-G<W1R("+TR=35S"(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3<T(&QI8B]";&]C:R]M971A<BYP:'`Z,S8P(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S@V"B,L('!H<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S
M("@E<RD@870@)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(U,`IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0Y"FUS
M9VED(")H.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,S4X"FUS9VED(")H:"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B:&]S
M="!N86UE('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE
M9&EA=&4B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(FEN;&EN92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V,@IM
M<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,30V"FUS9VED(")I;G1E<FYA
M;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B;&EN97-=(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M
M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES;V9S(&5R
M<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,V.0IM<V=I
M9"`B;6TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HR.3$@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W,`HC.B!S
M97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C,R"B,L(&9U>GIY"FUS9VED
M(")N86UE(@IM<V=S='(@(K;-8-$B"@HC.B!F<F%M97=O<FLO4E!#+U)00RYP
M:'`Z,3(Q"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C$Y"FUS9VED(")N
M;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.3`U"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ-S0*;7-G:60@(G!E<FUI<W-I;VX@
M9&5N:65D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W,`IM
M<V=I9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"B,L(&9U
M>GIY"FUS9VED(")R:7-I;F<B"FUS9W-T<B`B]=?!Q\$B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T,@IM<V=I9"`B<V5R=FEC92!U
M;F%V86EL86)L92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.CDY"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$T
M"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-0IM<V=I9"`B
M<W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-S(*;7-G:60@(G-T96%D>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P.0IM<V=I9"`B<W=I=&-H(&]F9B!J
M879A<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,34P"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,CD*;7-G:60@(G1A
M<VL@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$V-@IM<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,#4*(RP@9G5Z
M>GD*;7-G:60@(G1R>2!A9V%I;B(*;7-G<W1R("+KS];.S\?/(-?(S\35(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,S8@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N
M=7`N<&AP.C(V.0IM<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@
M8V]N9FER;2(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV
M-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B=6YI9FEE9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U!A<G0N<&AP.C(W"FUS
M9VED(")U;FYA;65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B=7-E<B!S
M96QE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0Q"FUS9VED
M(")W.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P;R]I=%])5"YP;P``````````````````
M````````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`V-S$U-#0@,3`U
M,34T,S,W-#,@,#$W-30W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````",@271A;&EA;B!T<F%N<VQA=&EO;G,@9F]R(&AO<F1E
M('!A8VMA9V4N"B,@0V]P>7)I9VAT("A#*2`R,#`V($AO<F1E(%!R;VIE8W0*
M(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC
M96YS92!A<R!T:&4@:&]R9&4@<&%C:V%G92X*(R!!=71O;6%T:6-A;&QY(&=E
M;F5R871E9"P@,C`P-BX*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M
M260M5F5R<VEO;CH@:&]R9&4@,RXQ+C%<;B(*(E)E<&]R="U-<V=I9"U"=6=S
M+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T
M93H@,C`P-BTP-"TQ,R`Q-#HQ-BLP,C`P7&XB"B)03RU2979I<VEO;BU$871E
M.B`R,#`V+3`T+3$S(#$T.C$V*S`R,#!<;B(*(DQA<W0M5')A;G-L871O<CH@
M36%R8V\@4&ER;W9A;F\@/&UA<F-O+G!I<F]V86YO0'5N:6)O8V-O;FDN:70^
M7&XB"B),86YG=6%G92U496%M.B!I,3AN0&QI<W1S+FAO<F1E+F]R9UQN(@HB
M34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I
M;CL@8VAA<G-E=#U)4T\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R+45N
M8V]D:6YG.B`X8FET7&XB"B)0;'5R86PM1F]R;7,Z(&YP;'5R86QS/3([('!L
M=7)A;#TH;B`A/2`Q*3M<;B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S8Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@
M(B`H)7,@9VEO<FYI('-C;W)S:2DB"@HC.B!L:6(O2&]R9&4N<&AP.C$S.#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@
M(B`H0VAI879E(&1I(&%C8V5S<V\@)7,I(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(S-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*
M;7-G<W1R("(@*&EN("5S(&=I;W)N:2DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C,W,PIM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B("AO9V=I*2(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,S<U"FUS9VED("(@*'1O;6]R<F]W*2(*
M;7-G<W1R("(@*&1O;6%N:2DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W
M,0IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@(B`H:65R:2DB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0U(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS-3`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,Y-@IM<V=I9"`B(&%T("(*;7-G<W1R("(@82!A(@H*(SH@;&EB+U9&
M4R]S;6(N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@
M;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R(")<(B5S7"(@;F]N(.@@=6YA(&1I
M<F5C=&]R>2XB"@HC.B!L:6(O2&]R9&4O0TQ)+G!H<#HR-S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC92XB"FUS
M9W-T<B`B7"(E<UPB(&YO;B#H('5N82!S8V5L=&$@=F%L:61A+B(*"B,Z(&QI
M8B](;W)D92]296=I<W1R>2YP:'`Z-S$P(&QI8B](;W)D92]296=I<W1R>2YP
M:'`Z,3`Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&-O
M;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*;7-G<W1R(")<(B5S
M7"(@;F]N(.@@8V]N9FEG=7)A=&\@;F5I(%)E9VES=')I(&1I($AO<F1E+B(*
M"B,Z(&QI8B](;W)D92]4<F5E+G!H<#HQ-S$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R(")<
M(B5S7"(@86QB97)O(')E;F1E<F5R(&YO;B!T<F]V871O+B(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A
M<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B7"(E<UPB
M(.@@<W1A=&\@86=G:75N=&\@86D@9W)U<'!I(&1I('-I<W1E;6$N(@H*(SH@
M861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G
M:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E
M;2XB"FUS9W-T<B`B7"(E<UPB(.@@<W1A=&\@86=G:75N=&\@86D@<&5R;65S
M<VD@9&D@<VES=&5M82XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4T(&%D;6EN
M+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED(")<
M(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B7"(E<UPB(&YO
M;B#H('-T871O(&-R96%T;SH@)7,N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N
M,F9-0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B4N,F9-0B!U<V%T:2!D
M:2`E+C)F34(@9&ES<&]N:6)I;&D@*"4N,F8E)2DB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C(V"B,L('!H<"UF;W)M870*;7-G:60@(B5D
M("5S(&%N9"`E<R(*;7-G<W1R("(E9"`E<R!E("5S(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C4Y-"!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HR-C@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W
M;W)D(&5X<&ER97,N(@IM<V=S='(@(B5D(&=I;W)N:2!A;&QO('-C861E<F4@
M9&5L;&$@='5A('!A<W-W;W)D+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C
M87-T(@IM<V=S='(@(B5D+6=I;VYO('!R979I<VEO;F4B"@HC.B!S97)V:6-E
M<R]M86EN=&5N86YC92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M+2!.;W1I8V4B"FUS9W-T<B`B)7,@+2!.;W1I>FEA(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HW,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M1FEN9V5R<')I;G0B"FUS9W-T<B`B)7,@1FER;6$@1&EG:71A;&4B"@HC.B!L
M:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#0R(&QI8B](;W)D92]-24U%
M+T-O;G1E;G1S+G!H<#HX-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B
M"FUS9W-T<B`B)7,@2T(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T
M:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(E<R!/<&5R87II;VYI(&1I
M($UA;G5T96YZ:6]N92`M($-O;F9E<FUA(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$T"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B5S($EM<&]S=&%Z:6]N
M92(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8T"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B)7,@1FER;6$B"@HC
M.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S='(@(B5S(%1E<FUI
M;FD@9&D@06-C;W)D;R(*"B,Z(&QI8B]61E,O9G1P+G!H<#HV.3`@;&EB+U9&
M4R]F='`N<&AP.C<V,R!L:6(O5D93+W-M8BYP:'`Z-#0Q"B,Z(&QI8B]61E,O
M<VUB+G!H<#HU,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E
M>&ES=',N(@IM<V=S='(@(B5S(&=IX"!E<VES=&5N=&4N(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S(@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR-#8*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M-3(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B)7,@82`E<R`E<R(*"B,Z('-E<G9I
M8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R
M871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92`B"B)B;W@@9F]R(&%N
M>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I
M;64N(@IM<V=S='(@(B(*(B5S(.@@<')O;G1O('!E<B!E<V5G=6ER92!L92!O
M<&5R87II;VYI(&1I(&UA;G5T96YZ:6]N92!S;W1T;R!S96QE>FEO;F%T92X@
M(@HB4V5L97II;VYA(&QA(&-A<V5L;&$@<&5R(&]G;FD@;W!E<F%Z:6]N92AI
M*2!C:&4@=G5O:2!E<V5G=6ER92!O<F$N(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(S-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER960B
M"FUS9W-T<B`B)7,@Z"!R:6-H:65S=&\B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S
M='(@(B5S(&UI;G5T:2(*"B,Z(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N
M+G!H<#HQ,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*
M;7-G<W1R("(E<R!N;VX@=')O=F%T;RXB"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]L:7-T+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S
M(&]F("5S(@IM<V=S='(@(B5S(&$@)7,@9&D@)7,B"@HC.B!L:6(O2&]R9&4O
M2V]L86(N<&AP.CDR-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E
M<W,@0F]O:R(*;7-G<W1R(")2=6)R:6-A(&1I("5S(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HY,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE
M;F1A<B(*;7-G<W1R(")#86QE;F1A<FEO(&1I("5S(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HY,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E
M<&%D(@IM<V=S='(@(DYO=&4@9&D@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N
M<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM
M<V=S='(@(DQI<W1A($%T=&EV:73@(&1I("5S(@H*(SH@;&EB+TAO<F1E+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(E<SH@)7,B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O:'1M;"YP:'`Z,3(W"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@
M:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L
M:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N
M>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@HB)7,Z(%%U97-T
M;R!M97-S86=G:6\@<&]T<F5B8F4@;F]N(&%R<FEV92!D82!C:&D@9&EC:&EA
M<F$@9&D@97-S97)E+B`B"B)!='1E;GII;VYE(&%I(&QI;FL@<')E<V5N=&D@
M:6X@97-S;R!O(&9O<FYI<V-I(&]G;FD@:6YF;W)M87II;VYE(&%L(&UI='1E
M;G1E+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-30@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y.0IM<V=I9"`B+"!G=7-T:6YG
M("(*;7-G<W1R("(L('-O9F9I86YD;R`B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$Y-2!L:6(O0FQO8VLO;65T87(N<&AP.C(P,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(L(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B+"!S;V9F:6%N9&\@
M)7,@)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P.`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B
M+"!V87)I86)I;&4@9&$@)7,@82`E<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR,#8Y(&QI8B](;W)D92]&;W)M+G!H<#HR,3(X"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HW-#@@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HR.30*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS-#@*;7-G:60@
M(BTM('-E;&5C="`M+2(*;7-G<W1R("(M+2!S96QE>FEO;F$@+2TB"@HC.B!L
M:6(O0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM
M<V=S='(@(D9O<FUA=&\@,3(@;W)E(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP
M.C$Y"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R(")&;W)M871O(#(T
M(&]R92(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R
M-"!H;W5R<R(*;7-G<W1R("(R-"!O<F4B"@HC.B!L:6(O2&]R9&4O54DO4&%G
M97(N<&AP.C8Y"FUS9VED("(\4')E=FEO=7,B"FUS9W-T<B`B/%!R96-E9&5N
M=&4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R-@IM<V=I9"`B02!D871A
M8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G
M<W1R(")5;B!D871A8F%S92!D:2!B86-K96YD(.@@<FEC:&EE<W1O('!E<B!Q
M=65S=&\@8FQO8V-O+B(*"B,Z(&QI8B](;W)D92YP:'`Z,3<Q"FUS9VED(")!
M(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R(")%)R!A8V-A9'5T
M;R!U;B!E<G)O<F4@9F%T86QE(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O
M(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(")5;F$@8VAI879E('!U8F)L
M:6-A(%!'4"#H(')I8VAI97-T82!P97(@8VEF<F%R92!I;"!M97-S86=G:6\N
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$V.`IM<V=I9"`B02!P
M=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@
M;65S<V%G92XB"FUS9W-T<B`B(@HB56YA(&-H:6%V82!P=6)B;&EC82!01U`@
MZ"!R:6-H:65S=&$@<&5R('9E<FEF:6-A<F4@:6P@;65S<V%G9VEO(&9I<FUA
M=&\N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3`Y.0IM<V=I9"`B
M(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S
M<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*(FUE<W-A9V4N
M(@IM<V=S='(@(B(*(E5N82!C:&EA=F4@<'5B8FQI8V$@4$=0+"!U;F$@8VAI
M879E('!R:79A=&$@4$=0+"!E('5N82!P87-S=V]R9"!S;VYO("(*(G)I8VAI
M97-T92!P97(@9&5C:69R87)E('5N(&UE<W-A9V=I;R(*"B,Z(&QI8B](;W)D
M92]#<GEP="]P9W`N<&AP.C$P,38*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K
M97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O('-I9VX@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"B)5;F$@8VAI
M879E('!U8F)L:6-A(%!'4"P@=6YA(&-H:6%V92!P<FEV871A(%!'4"P@92!U
M;F$@<&%S<W=O<F0@<V]N;R`B"B)R:6-H:65S=&4@<&5R(&9I<FUA<F4@=6X@
M;65S<V%G9VEO(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU,#8*
M;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y
M<'0@82!M97-S86=E+B(*;7-G<W1R("(B"B)5;F$@8VAI879E('!U8F)L:6-A
M(%,O34E-12P@=6YA(&-H:6%V92!P<FEV871A(%,O34E-12!E('5N82!P87-S
M=V]R9"!S;VYO("(*(G)I8VAI97-T92!P97(@9&5C:69R87)E('5N82!M97-S
M86=G:6\N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G
M:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M
M97-S86=E+B(*;7-G<W1R("(B"B)5;F$@8VAI879E('!U8F)L:6-A(%,O34E-
M12P@=6YA(&-H:6%V92!P<FEV871A(%,O34E-12!E('5N82!P87-S=V]R9"!S
M;VYO("(*(G)I8VAI97-T92!P97(@9FER;6%R92!U;B!M97-S86=G:6\N(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G:60@(D$@<'5B
M;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G
M92XB"FUS9W-T<B`B56YA(&-H:6%V92!P=6)B;&EC82!3+TU)344@Z"!R:6-H
M:65S=&$@<&5R(&-I9G)A<F4@=6X@;65S<V%G9VEO+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.CD*;7-G:60@(D%-($-L;W5D
M<R(*;7-G<W1R(")!32!.=6)I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3`*;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS9W-T
M<B`B04T@4&EO9V=I82!,96=G97)A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3$*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B
M04T@4&EO9V=I82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$R"FUS9VED(")!32!3:&]W97)S(@IM<V=S='(@(D%-($%C<75A
M>GIO;FDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ,PIM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(D%-($YE=FEC
M871E(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-
M+U!-(@IM<V=S='(@(D%-+U!-(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G<W1R(")!4$D@240B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,P
M"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R(")2:6=U87)D;R!Q
M=65S=&\@961I=&]R(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3,*
M;7-G:60@(D%B;W5T+BXN(@IM<V=S='(@(E)I9W5A<F1O+BXN(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B
M06)S8F]T=&]M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R
M("(B"@HC.B!L:6(O5D93+VUU<W%L+G!H<#HR.#(*;7-G:60@(D%C8V5S<R!D
M96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B06-C97-S
M;R!N96=A=&\@8W)E86YD;R!L82!D:7)E8W1O<GD@5D93+B(*"B,Z(&QI8B]6
M1E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN
M9R!61E,@9FEL92XB"FUS9W-T<B`B06-C97-S;R!N96=A=&\@8W)E86YD;R!6
M1E,@9FEL92XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,PIM<V=I9"`B
M06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA>FEO;FD@06-C
M;W5N="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.`IM<V=I9"`B06-C
M;W5N="!087-S=V]R9"(*;7-G<W1R(")087-S;W=R9"!!8V-O=6YT(@H*(SH@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*;7-G:60@(D%C
M8V]U;G0@9G)O>F5N+B(*;7-G<W1R(")!8V-O=6YT(&-O;F=E;&%T;RXB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,U"FUS9VED(")!8V-O=6YT
M:6YG(@IM<V=S='(@(D%C8V]U;G1I;F<B"@HC.B!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C$T."!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z,3$*;7-G:60@(D%D
M9"(*;7-G<W1R(")!9V=I=6YG:2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T
M(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B
M"FUS9W-T<B`B06=G:75N9VD@1W)U<'!O($9I9VQI;R(*"B,Z(&QI8B](;W)D
M92]097)M<R]522YP:'`Z.3@@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HY.0IM
M<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`B06=G:75N9VD@
M4&5R;65S<VD@1FEG;&EO(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC
M.C4*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R(")!9V=I=6YG:2!Q=6DZ(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O=7!S+G!H<#HR,3D*
M;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B06=G:75N9VD@3G5O=F\@
M1W)U<'!O(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HX-R!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB
M"FUS9W-T<B`B06=G:75N9VD@3G5O=F\@4&5R;65S<V\B"@HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHW"B,L('!H<"UF;W)M870*
M;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R(")!
M9V=I=6YG:2!U;B!G<G5P<&\@9FEG;&EO(&$@7"(E<UPB(@H*(SH@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D
M(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B06=G:75N
M9VD@=6X@<&5R;65S<V\@9FEG;&EO(&$@7"(E<UPB(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R(")!9V=I
M=6YG:2!U;B!N=6]V;R!U=&5N=&4Z(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C4U-@IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R
M(")!9V=I=6YG:2!C;VQO;FYA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]E9&ET+FEN8SHS-`IM<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S='(@
M(D%G9VEU;F=I(&YU;W9I(&UE;6)R:2(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(D%G9VEU;F=I
M(&QA(&-O<'!I82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL
M82!3:61E8F%R(@IM<V=S='(@(D%G9VEU;F=I(&EL("5S($UE;G4@8V]M92!U
M;F$@36]Z:6QL82!3:61E8F%R(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HW,0IM<V=I9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS
M9W-T<B`B06=G:75N9VD@86QL82!R=6)R:6-A.B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*;7-G:60@(D%D9"!T;R!M>2!A9&1R
M97-S(&)O;VLB"FUS9W-T<B`B06=I=6YG:2!A;&QA(')U8G)I8V$@<&5R<V]N
M86QE(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*;7-G:60@(D%D9"!U<V5R(@IM
M<V=S='(@(D%G9VEU;F=I('5T96YT92(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@
M<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I
M;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@(B(*(D%G9VEU;G1I(%PB)7-<
M(B!A;"!S:7-T96UA+"!M82!N;VX@<VD@<&]S<V]N;R!A9V=I=6YG97)E('5L
M=&5R:6]R:2`B"B)I;F9O<FUA>FEO;FDZ("5S+B(*"B,Z('-I9VYU<"YP:'`Z
M-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E<UPB('1O('1H92!S
M>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`B06=G:75N=&\@
M7"(E<UPB(&%L('-I<W1E;6$N($]R82!P=6]I(&%C8V5D97)E+B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@
M=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(DPG86=G:75N=&$@9&D@=71E
M;G1I(.@@9&ES86)I;&ET871A+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M-#0Q(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S"FUS9VED(")!9&1R
M97-S(@IM<V=S='(@(DEN9&ER:7IZ;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ-#$*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R(")2=6)R
M:6-A(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT(&QI
M8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HU-@IM<V=I9"`B061M:6YI
M<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T
M<B`B06UM:6YI<W1R871O<F4@+2!I;7!O<W1A(&D@<&5R;65S<VD@<&5R(&%L
M=')I('5T96YT:2(*"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ.2!S97)V:6-E<R]P
M;W)T86PO<VED96)A<BYP:'`Z,3$W"FUS9VED(")!9&UI;FES=')A=&EO;B(*
M;7-G<W1R(")!;6UI;FES=')A>FEO;F4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S0S"FUS9VED(")!9',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.`IM<V=I9"`B069G
M:&%N:7-T86XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,0IM<V=I9"`B06QB86YI82(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<T
M"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C$V"FUS9VED(")!;&EG;B(*;7-G<W1R(")!;&QI;F5A(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B
M06QI9VYM96YT.B(*;7-G<W1R(")!;&QI;F5A;65N=&\Z(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C@W"FUS9VED(")!;&PB"FUS9W-T<B`B5'5T=&DB
M"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R
M<R(*;7-G<W1R(")4=71T:2!G;&D@=71E;G1I(&%U=&5N=&EC871I(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM<V=I
M9"`B06QL($=R;W5P<R(*;7-G<W1R(")4=71T:2!I(&=R=7!P:2(*"B,Z(&QI
M8B](;W)D92]097)M<R]D871A=')E92YP:'`Z-S4@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HY,0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(E1U
M='1I(&D@<&5R;65S<VDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*
M;7-G<W1R(")4=71T:2!E('%U871T<F\@:2!L871I(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$X-S$*;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E
M<R(*;7-G<W1R(")4=71T:2!G;&D@:6YD:7)I>GII(&UU;'1I<&QI(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S.`IM<V=I9"`B06QL;W<@<V5T=&EN
M9R!O9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B4&5R;65T=&5R92!L
M92!I;7!O<W1A>FEO;FD@9&D@;&ES=&4@;W)D:6YA=&4@<&5R('1I<&\_(@H*
M(SH@;&EB+TAO<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS9VED(")!;')E
M861Y(&5X:7-T<R(*;7-G<W1R(")%<VES=&4@9VG@(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$R-@IM<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB
M"FUS9W-T<B`B3&]G:6X@24U34"!A;'1E<FYA=&EV82(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,3$*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A<W-W
M;W)D(@IM<V=S='(@(E!A<W-W;W)D($E-4U`@86QT97)N871I=F$B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`S"FUS9VED(")!;'1E<FYA=&4@24U3
M4"!5<V5R;F%M92(*;7-G<W1R(")5=&5N=&4@24U04R!A;'1E<FYA=&EV;R(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED(")!;'1E
M<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R("));F1I<FEZ>F\@96UA:6P@
M86QT97)N871I=F\B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I
M9"`B06QT97)N871E('1E;7!L871E<R(*;7-G<W1R(")-87-C:&5R92!A;'1E
M<FYA=&EV92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R,@IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM
M<V=S='(@(E1E<W1O(&%L=&5R;F%T:79O.B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C4X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C<*;7-G:60@(D%M97)I8V%N(%-A
M;6]A(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z.34@
M;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@
M=F%L=64@=V%S('-P96-I9FEE9"XB"FUS9W-T<B`B12<@<W1A=&\@<W!E8VEF
M:6-A=&\@=6X@=F%L;W)E(&YO;B!V86QI9&\N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$U-0IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!H
M87,@;V-C=7)E9"XB"FUS9W-T<B`B17)R;W)E('-C;VYO<V-I=71O+B(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4U(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38*;7-G
M:60@(D%N9&]R<F$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR-`IM<V=I9"`B06YG;VQA(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4W(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C`*;7-G:60@(D%N9W5I;&QA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"FUS9VED
M(")!;G-W97(B"FUS9W-T<B`B4FES<&]S=&$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HU."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U"FUS9VED(")!;G1A<F-T:6-A
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4V(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3D*;7-G:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C,V(&%D;6EN+W1E;7!L871E
M<RYP:'`Z-S0@;&EB+TAO<F1E+T)L;V-K+U5)+G!H<#HU.`HC.B!T96UP;&%T
M97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HV"FUS9VED(")!<'!L:6-A=&EO
M;B(*;7-G<W1R(")!<'!L:6-A>FEO;F4B"@HC.B!U=&EL+VEC;VY?8G)O=W-E
M<BYP:'`Z-#(*;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`B3&ES
M=&$@07!P;&EC87II;VYI(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S
M.0IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@(DPG87!P
M;&EC87II;VYE(.@@<')O;G1A+B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T
M<B`B07!P;&EC82!A:2!F:6=L:2!C;VYD:79I<VDB"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*;7-G
M<W1R(")!<'!R;W9A(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP
M.C@T,@IM<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R(")$:6UE;G-I
M;VYE($%P<')O<W-I;6%T:79A(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P-2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(D%P<FEL92(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M
M,3(U-BDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-3D@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C8*;7-G:60@(D%R8VAI
M=F4@1FEL92!3:7IE(@IM<V=S='(@(D1I;65N<VEO;F4@9FEL92!I;B!A<F-H
M:79I;R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C4X(&QI
M8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<W"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8U"FUS9VED(")!<F-H:79E($YA;64B"FUS
M9W-T<B`B3F]M92!!<F-H:79I;R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W)E;6]V97%U975E9"YI;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E
M('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E
M<W0@9F]R("5S(#\B"FUS9W-T<B`B4V5I('-I8W5R;R!D:2!V;VQE<B!R:6UU
M;W9E<F4@;&4@<FEC:&EE<W1E(&9I<FUA=&4@<&5R("5S(#\B"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E(%PB)7-<
M(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(D%S96D@<VEC=7)O(&1I
M('9O;&5R(&5L:6UI;F%R92!<(B5S7"(@92!O9VYI('-O='1O+6=R=7!P;S\B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(V
M"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,@IM<V=I9"`B07)M96YI82(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B
M07)M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,`IM<V=I9"`B
M07)U8F$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U
M"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@07)T(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!<VEA
M+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT,CD*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R
M92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G<W1R("(B"B)2
M:6-H:65D97)E(&QA(&-O;F9E<FUA('!R:6UA(&1I(&5S96=U:7)E(&QE(&]P
M97)A>FEO;FD@9&D@;6%N=71E;GII;VYE/R(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HS,#DU"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS9W-T<B`B
M07-S96=N86UE;G1O(&-O;&]N;F4B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<T
M"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U
M<"XB"FUS9W-T<B`B4VD@Z"!C97)C871O(&1I(&5L:6UI;F%R92!U;B!G<G5P
M<&\@;F]N(&5S:7-T96YT92XB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP
M.C(Y"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P
M97)M:7-S:6]N+B(*;7-G<W1R(")3:2#H(&-E<F-A=&\@9&D@96QI;6EN87)E
M('5N('!E<FUE<W-O(&YO;B!E<VES=&5N=&4N(@H*(SH@861M:6XO<&5R;7,O
M961I="YP:'`Z.#<*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES
M=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")3:2#H(&-E<F-A=&\@9&D@<'5B
M8FQI8V%R92!U;B!P97)M97-S;R!N;VX@97-I<W1E;G1E+B(*"B,Z('-E<G9I
M8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I9"`B071T96UP="!T;R!E9&ET
M(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R(")3:2#H(&-E<F-A=&\@
M9&D@<'5B8FQI8V%R92!U;F$@8V]N9&EV:7-I;VYE(&YO;B!E<VES=&5N=&4N
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#,*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S$*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B
M071T<FEB=71I(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P.2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*
M;7-G:60@(D%U9W5S="(*;7-G<W1R(")!9V]S=&\B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HU.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Y"FUS9VED(")!=7-T<F%L
M:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR.`IM<V=I9"`B075S=')I82(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S
M<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B075T:%]C>7)S<6PZ(&5S=&5N<VEO;F4@:6UA<"!R:6-H:65S=&$@;F]N
M('1R;W9A=&$N(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$S-0IM
M<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I
M<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!I;"!B86-K
M96YD(&YO;B!H82!L92!C87!A8VETX"!R:6-H:65S=&4N(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q
M=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H
M7V-Y<G5S.B!E<W1E;G-I;VYE(&EM87`@<FEC:&EE<W1A(&YO;B!T<F]V871A
M+B(*"B,Z(&QI8B](;W)D92]!=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U
M=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M
M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS
M9W-T<B`B(@HB075T:%]F='`Z($5S=&5N<VEO;F4@1E10(')I8VAI97-T82!N
M;VX@=')O=F%T82X@0V]M<&EL82!02%`@8V]N(&PG;W!Z:6]N92`M+2(*(F5N
M86)L92UF='`N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:6UA<"YP:'`Z-C0*;7-G
M:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R(")!=71H7VEM87`Z("!%<W1E;G-I;VYE($E-05`@<FEC
M:&EE<W1A(&YO;B!T<F]V871A+B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N
M<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]K<F(U.B!%<W1E;G-I;VYE
M(&MR8C4@<FEC:&EE<W1A(&YO;B!T<F]V871A+B(*"B,Z(&QI8B](;W)D92]!
M=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@=7-E
M<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G
M<W1R(")!=71H7VQD87`Z(&PG86=G:75N=&$@9&D@=71E;G1I(&YO;B#H('-U
M<'!O<G1A=&$@<&5R($%C=&EV92!$:7)E8W1O<GDB"@HC.B!L:6(O2&]R9&4O
M075T:"]L9&%P+G!H<#HS-3<*;7-G:60@(D%U=&A?;&1A<#H@4F5M;W9I;F<@
M=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*
M;7-G<W1R("(B"B)!=71H7VQD87`Z(&QA(&-A;F-E;&QA>FEO;F4@9&D@=71E
M;G1I(&YO;B#H('-U<'!O<G1A=&$@<&5R($%C=&EV92!$:7)E8W1O<GDB"@HC
M.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HV,PIM<V=I9"`B075T:%]L9&%P
M.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(D%U=&A?;&1A<#H@17-T96YS:6]N92!,1$%0(')I8VAI97-T82!N;VX@=')O
M=F%T82XB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS,SD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@
M)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("(B
M"B)!=71H7VQD87`Z($EM<&]S<VEB:6QE(&%G9VEU;F=E<F4@;"=U=&5N=&4@
M)7,N(%%U97-T82#H(&QA(')I<W!O<W1A(&1E;"`B"B)S97)V97(Z(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*;7-G
M:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S
M='(@(D%U=&A?;&1A<#H@26UP;W-S:6)I;&4@8V%N8V5L;&%R92!L)W5T96YT
M92`E<R(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C0Y.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E
M<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z($EM<&]S<VEB:6QE(&%G9VEO<FYA
M<F4@;"=U=&5N=&4@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HT
M,#4*;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U
M<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB075T
M:%]L9&%P.B!L)V%G9VEO<FYA;65N=&\@9&5G;&D@=71E;G1I(&YO;B#H('-U
M<'!O<G1A=&\@<&5R($%C=&EV92`B"B)$:7)E8W1O<GDN(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O;6-A;"YP:'`Z-#8*;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER
M960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VUC
M86PZ(&5S=&5N<VEO;F4@34-!3"!R:6-H:65S=&$@;F]N('1R;W9A=&$N(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O<VUB+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A
M=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(D%U=&A?<VUB875T:#H@97-T96YS:6]N92!S;6)A=71H(')I8VAI
M97-T82!N;VX@=')O=F%T82XB"@HC.B!L:6(O2&]R9&4O24U!4"]!9&UI;BYP
M:'`Z,3`V"FUS9VED(")!=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F
M86EL960N(@IM<V=S='(@(DPG875T96YT:6-A>FEO;F4@86P@<V5R=F5R($E-
M05`@Z"!F86QL:71A+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDP"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T
M<B`B075T96YT:6-A>FEO;F4@9F%L;&ET82(*"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z-C<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H96YT:6-A=&EO
M;B!F86EL960N("5S(@IM<V=S='(@(D%U=&5N=&EC87II;VYE(&9A;&QI=&$N
M("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O<F%D:75S+G!H<#HQ-S8*;7-G:60@
M(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM
M<V=S='(@(D%U=&5N=&EC87II;VYE(')I9FEU=&%T82!D86P@<V5R=F5R(%)!
M1$E54RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#DU"FUS9VED(")!=71H96YT
M:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B075T96YT
M:6-A>FEO;F4@86P@<V5R=F5R($944"!F86QL:71A+B(*"B,Z(&QI8B]61E,O
M<VUB+G!H<#HW,`IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S
M97)V97(@9F%I;&5D+B(*;7-G<W1R(")!=71E;G1I8V%Z:6]N92!A;"!S97)V
M97(@4TU"(&9A;&QI=&$N(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN
M8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`B0V%M<&D@
M9&ES<&]N:6)I;&DZ(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HS,0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@(D)/1D@@17AC=7-E
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O=6YD(@IM<V=S='(@
M(E-F;VYD;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`B0V]L
M;W)E('-F;VYD;R(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C@Q"FUS
M9VED(")"860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(E!A<W-W;W)D
M(&ME<F)E<F]S(&YO;B!V86QI9&$N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B
M-2YP:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS9W-T
M<B`B571E;G1E(&ME<F)E<F]S(&YO;B!V86QI9&\N(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-0IM<V=I9"`B0F%H86UA
M<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C,X"FUS9VED(")"86AR86EN(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS9VED(")"86QT:6,@*$E33RTX.#4Y
M+3$S*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C,T"FUS9VED(")"86YG;&%D97-H(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S,*
M;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W
M<V5R+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S
M(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")$:7)E8W1O
M<GD@9W)A9FEC82!D:2!B87-E(%PB)7-<(B!N;VX@=')O=F%T82XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*
M;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#D*;7-G:60@(D)E;&%R=7,B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HS-0IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4P"FUS9VED(")"96QI
M>F4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,S"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HT,`IM<V=I9"`B0F5N:6XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C,T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,0IM<V=I9"`B
M0F5R;75D82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C0V"FUS9VED(")":'5T86XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G:60@
M(D)I<G1H9&%Y(@IM<V=S='(@(D-O;7!L96%N;F\B"@HC.B!L:6(O2&]R9&4O
M0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@
M(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD
M+B(*;7-G<W1R(")";&]C8V\@7"(E<UPB(&1E;&PG87!P;&EC87II;VYE(%PB
M)7-<(B!N;VX@=')O=F%T;RXB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U
M="YI;F,Z.3`*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(DEM<&]S
M=&%Z:6]N:2!";&]C8V\B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI
M;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B5&EP;R!";&]C8V\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*
M;7-G:60@(D)O;&0B"FUS9W-T<B`B1W)A<W-E='1O(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C,V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,PIM<V=I9"`B0F]L:79I
M82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`W
M"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`B4V5G;F%L:6)R:2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*
M;7-G:60@(D)O<F1E<B(*;7-G<W1R(")";W)D;R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T
M:&EC:VYE<W,Z(@IM<V=S='(@(E-P97-S;W)E(&1E;"!B;W)D;SHB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Q
M"FUS9VED(")";W)D97)S(@IM<V=S='(@(D)O<F1I(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C,W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,@IM<V=I9"`B0F]S;FEA
M(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R(")";W-N:6$@92!(97)Z96=O=FEN
M82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*
M;7-G<W1R(")%;G1R86UB92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-#@*;7-G:60@(D)O='-W86YA(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR,@IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(D)A<W-O(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C,Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-PIM<V=I9"`B0F]U
M=F5T($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C0T"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B
M0G)A<VEL92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3$W"FUS9VED(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O
M<GDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HT,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HS-PIM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T
M960@3&ES="(*;7-G<W1R(")%;&5N8V\@<'5N=&%T;R(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HT-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S8*;7-G:60@(D)U<FMI
M;F$@1F%S;R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C,Y"FUS9VED(")"=7)U;F1I(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#8*;7-G:60@(D--4R(*
M;7-G<W1R(")#35,B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H
M<#HW-0IM<V=I9"`B0U)#(@IM<V=S='(@(D-20R(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-3DX"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O
M:6YT<R(*;7-G<W1R(")0=6YT:2!$:7-T<FEB=7II;VYE($-23"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")0<F]P<FEE
M=.`@0U]E;&QE+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$U,0IM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS
M9W-T<B`B3&$@8V%C:&4@:6YI>FEA;&4@;F]N(.@@<W1A=&$@8V]M<&QE=&%T
M82XB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDQ-B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@U"B,Z(&-O;F9I9R]H;V]K<RYP:'`N
M9&ES=#HQ,#0P(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-3<*;7-G:60@
M(D-A;&5N9&%R(@IM<V=S='(@(D-A;&5N9&%R:6\B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C,U"FUS9VED(")#86QM(@IM<V=S='(@(D-A
M;&UO(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,C@*;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@(D-A;6)O9VEA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C0W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,`IM<V=I
M9"`B0V%M97)O;VXB"FUS9W-T<B`B(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR
M,S(@;&EB+U9&4R]F='`N<&AP.C8W-B!L:6(O5D93+W-M8BYP:'`Z-#,U"B,Z
M(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(P,PIM<V=I9"`B0V%N(&YO="!C;W!Y
M(&9I;&4H<RD@+2!S;W5R8V4@86YD(&1E<W1I;F%T:6]N(&%R92!T:&4@<V%M
M92XB"FUS9W-T<B`B(@HB26UP;W-S:6)I;&4@8V]P:6%R92!F:6QE*',I("T@
M;&$@<V]R9V5N=&4@92!L82!D97-T:6YA>FEO;F4@<V]N;R!U9W5A;&DN(@H*
M(SH@;&EB+U9&4R]F:6QE+G!H<#HR,#(@;&EB+U9&4R]F='`N<&AP.C<U,B!L
M:6(O5D93+W-M8BYP:'`Z-3`Q"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$V
M.`IM<V=I9"`B0V%N(&YO="!M;W9E(&9I;&4H<RD@+2!D97-T:6YA=&EO;B!I
M<R!W:71H:6X@<V]U<F-E+B(*;7-G<W1R("(B"B));7!O<W-I8FEL92!S<&]S
M=&%R92!I;"!F:6QE*',I("T@;&$@9&5S=&EN87II;VYE(.@@86QL)VEN=&5R
M;F\@9&5L;&$@(@HB<V]R9V5N=&4N(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T
M;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S
M='(@(B(*(DEM<&]S<VEB:6QE(')E:6UP;W-T87)E(&QA('!A<W-W;W)D(&%U
M=&]M871I8V%M96YT92P@8V]N=&%T=&$@(@HB;"=A;6UI;FES=')A=&]R92XB
M"@HC.B!L:6(O1FEL92]#4U8N<&AP.C,U,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#86X@;F]T('=R:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@(DEM<&]S
M<VEB:6QE('-C:79E<F4@;F5L(&9I;&4@7"(E<UPB(@H*(SH@861M:6XO<V5S
M<VEO;G,N<&AP.C(R"FUS9VED(")#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L
M('-E<W-I;VX@:&%N9&QE<G,N(@IM<V=S='(@(DEM<&]S<VEB:6QE(&=E<W1I
M<F4@<V5S<VEO;FD@97-T97)N92XB"@HC.B!L:6(O2&]R9&4O075T:"]C>7)S
M<6PN<&AP.C,Q.2!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,C,U"B,L('!H
M<"UF;W)M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z
M("5S(@IM<V=S='(@(DEM<&]S<VEB:6QE(&-O;&QE9V%R<VD@86P@<V5R=F5R
M($E-05`Z("5S(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HT-#8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M26UP;W-S:6)I;&4@87!R:7)E(&EL(&9I;&4@7"(E<UPB+B(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8T(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HT.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3$*;7-G:60@(D-A
M;F%D82(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO
M=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHV-2!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$*;7-G:60@(D-A;F-E;"(*
M;7-G<W1R(")#86YC96QL82(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B"FUS9W-T
M<B`B0V%N8V5L;&$@:6P@4F5P;W)T('!R;V)L96UA(@H*(SH@;&EB+U9&4R]F
M='`N<&AP.C,R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L971E
M(&9I;&4@7"(E<UPB+B(*;7-G<W1R("));7!O<W-I8FEL92!E;&EM:6YA<F4@
M:6P@9FEL92!<(B5S7"(N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U
M='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R"B,Z(&QI8B]61E,O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"FUS9VED(")#86YN;W0@
M9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(DEM<&]S<VEB
M:6QE('1R;W9A<F4@=6YA(&1I<F5C=&]R>2!T96UP;W)A;F5A+B(*"B,Z(&QI
M8B]61E,O25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T('!R;V-E960@
M=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R("));7!O
M<W-I8FEL92!P<F]C961E<F4@<V5N>F$@:6P@<&%R86UE=')O("=T87)G971&
M:6QE)RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,S$Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T
M<B`B26UP;W-S:6)I;&4@<FEM=6]V97)E(&QA(&1I<F5C=&]R>2`@7"(E<UPB
M+B(*"B,Z(&QI8B](;W)D92]$871A5')E92YP:'`Z,3(X(&QI8B](;W)D92]$
M871A5')E92]S<6PN<&AP.C8X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN
M;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`B26UP;W-S
M:6)I;&4@<FEM=6]V97)E+"!E<VES=&]N;R`E9"!F:6=L:2XB"@HC.B!L:6(O
M2&]R9&4O1&%T851R964O<W%L+G!H<#HV,#@*;7-G:60@(B(*(D-A;FYO="!R
M96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E
M<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R("(B
M"B));7!O<W-I8FEL92!R:6]R9&EN87)E+"!L)V5L96YC;R!F;W)N:71O(&YO
M;B!C;W)R:7-P;VYD92!C;VX@;"=E;&5N8V\@(@HB;65M;W)I>GIA=&\N(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@
M(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM
M<V=S='(@(DEM<&]S<VEB:6QE(&EN<W1R861A<F4@:6P@;65S<V%G9VEO(&%L
M(&YU;65R;R!S<&5C:69I8V%T;RXB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C8U"FUS9VED(")#87!E(%9E<F1E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C0*;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`B(@H*(SH@;&EB
M+TYE="]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B
M"FUS9W-T<B`B0V%R<FEE<F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3,*;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R(")#871E
M9V]R:64@92!%=&EC:&5T=&4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$S-0IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS
M9W-T<B`B27-O;&4@0V%Y;6%N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B0V5L
M;'5L87)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR-0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@
M(E!R;W!R:65TX"!#96QL92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S
M='(@(E)I96UP:6UE;G1O(&-E;&QE.B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O
M<&5R=&EE<R(*;7-G<W1R(")0<F]P<FEE=.`@8V5L;&4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L
M;"!S<&%C:6YG.B(*;7-G<W1R(")3<&%Z:6\@8V5L;&4Z(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$R-S0*;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R(")#
M96QL=6QA<F4B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B
M0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-@IM<V=I9"`B
M0V5N=&5R(@IM<V=S='(@(D-E;G1R;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-30*;7-G:60@(D-E;G1R86P@069R:6-A
M;B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X,@IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS
M9W-T<B`B175R;W!A($-E=')A;&4@*$E33RTX.#4Y+3(I(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#`*;7-G:60@(D-E<G1I9FEC871E($1E
M=&%I;',B"FUS9W-T<B`B1&5T=&%G;&D@9&5L($-E<G1I9FEC871O(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,3(*;7-G:60@(D-E<G1I9FEC
M871E($]W;F5R(@IM<V=S='(@(E!R;W!R:65T87)I;R!D96P@0V5R=&EF:6-A
M=&\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B
M0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B4&]L:71I8VAE(&1E;"!#
M97)T:69I8V%T;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P."!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(R,0IM<V=I9"`B0VAA9"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.CDV"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B0V%M8FEA(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,Q"FUS9VED(")#:&%N
M9V4@66]U<B!087-S=V]R9"(*;7-G<W1R(")#86UB:6$@;&$@='5A(%!A<W-W
M;W)D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Y"FUS9VED("(B"B)#
M:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H
M96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS
M9W-T<B`B(@HB0V%M8FEA(&EL(&YO;64@92!L)VEN9&ER:7IZ;R!C:&4@;&4@
M<&5R<V]N92!V961O;F\@<75A;F1O(&QE9V=O;F\@92`B"B)R:7-P;VYD;VYO
M(&%L;&4@='5E(&5M86EL+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N
M;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@
M("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B))
M;"!C86UB:6\@9&5L;&$@='5A('!A<W-W;W)D(&YO;B#H('-U<'!O<G1A=&\@
M8V]N(&QA(&-O;F9I9W5R87II;VYE("(*(F-O<G)E;G1E+B`@0V]N=&%T=&$@
M;"=A;6UI;FES=')A=&]R92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(W"FUS9VED(")#:&%R(@IM<V=S='(@
M(D-A<F)O;F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S
M='(@(D-H96-?:R!,:6YK+BXN(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HU.0IM<V=I9"`B0VAI;&4B"FUS9W-T<B`B0VEL
M92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-C$*;7-G:60@(D-H:6YA(@IM<V=S='(@(D-I;F$B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X,PIM<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S
M,3(I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@T"FUS
M9VED(")#:&EN97-E(%1R861I=&EO;F%L("A":6<U*2(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHW"FUS9VED(")#:&]O<V4@07!P
M;&EC871I;VXZ(@IM<V=S='(@(E-C96=L:2!L)V%P<&QI8V%Z:6]N93HB"@HC
M.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(W,`IM<V=I9"`B0VAO;W-E
M(&$@<&%S<W=O<F0B"FUS9W-T<B`B4V-E9VQI('5N82!P87-S=V]R9"(*"B,Z
M(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")#:&]O<V4@
M82!U<V5R;F%M92(*;7-G<W1R(")38V5G;&D@=6X@;F]M92!U=&5N=&4B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`R"FUS9VED(")#:&]O<V4@:&]W
M('1O(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(E-C96=L:2!C;VUE('9I<W5A
M;&EZ>F%R92!L82!D871A.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T
M('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R(")38V5G
M;&D@:6P@=&EP;R!D:2!S=&EL92!D96QL82!L:7-T82`H<&5R(&QI<W1E(&]R
M9&EN871E*2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8X(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-0HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-C8*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B(@H*
M(SH@;&EB+U9&4RYP:'`Z.3$T(&QI8B].970O4TU3+G!H<#HR.30*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U
M;F0N(@IM<V=S='(@(DQA(&1E9FEN:7II;VYE(&1I(&-L87-S92!D:2`E<R!N
M;VX@Z"!S=&%T82!T<F]V871A+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$T"FUS9VED(")#;&5A<B(*;7-G<W1R(")#:&EA
M<F\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,CD*;7-G:60@(D-L96%R(%%U97)Y(@IM
M<V=S='(@(D%N;G5L;&$@1&]M86YD82(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V-L96%R+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U
M="!U<V5R.B`E<R(*;7-G<W1R(")%;&EM:6YA(&PG=71E;G1E.B`E<R(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,0IM<V=I9"`B0VQE
M87(@=7-E<B(*;7-G<W1R(")%;&EM:6YA('5T96YT92(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T"FUS9VED(")#;&5A<B!U<V5R(&1A
M=&$B"FUS9W-T<B`B16QI;6EN82!I;F9O<FUA>FEO;FD@=71E;G1E(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,34*;7-G:60@
M(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B16QI;6EN87)E($1O<&\@(@H*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-C`*;7-G
M:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(D-L:6-K('!E<B!#;VYT
M:6YU87)E(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ
M.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`B0VAI=61I
M($9I;F5S=')A(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3$*;7-G:60@
M(D-L;W5D<R(*;7-G<W1R(").=6)I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,38*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G
M<W1R(").=6)I('!R97-T;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$W"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B3G5V;VQO
M<V\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C4R"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C(S"FUS9VED(")#
M;VQL87!S92!3:61E8F%R(@IM<V=S='(@(D-H:75D:2!3:61E8F%R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M.`IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B0VAI=61I(&D@
M8F]R9&DB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C8R"FUS9VED(")#;VQO;6)I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM
M<V=I9"`B0V]L;W(B"FUS9W-T<B`B0V]L;W)E(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4P,R!L:6(O2&]R9&4O0FQO8VLO0V]L
M;&5C=&EO;BYP:'`Z,S,X"B,Z(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N
M+G!H<#HS,SD@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT.0HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,`HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-0HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-@HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,@IM
M<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@(DUA<'!A($-O;&]R:2(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR.#(X"FUS9VED(")#;VQO=7(@<V5L96-T
M:6]N(@IM<V=S='(@(E-E;&5Z:6]N92!C;VQO<FDB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB
M"FUS9W-T<B`B0V]L;VYN93HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DT
M-@IM<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R(")4:71O;&\@8V]L;VYN
M92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C8*;7-G:60@(D-O
M;6EC<R(*;7-G<W1R(")#;VUI8VAE(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP
M.C(V"FUS9VED(")#;VUM86YD(@IM<V=S='(@(D-O;6%N9&\B"@HC.B!A9&UI
M;B]C;61S:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T
M<B`B3&EN96$@9&D@8V]M86YD;R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C0Q,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R(")#;VUM96YT;R(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-38W"FUS9VED(")#;VUM;VX@
M3F%M92(*;7-G<W1R(").;VUE($-O;75N92(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU.`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,P"FUS9VED(")#;VUO<F]S(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@(D%Z:65N9&$B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R
M(")#;VUP=71E<G,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C@V"FUS9VED(")#;VYD:71I;VXB"FUS9W-T<B`B0V]N9&EZ:6]N92(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C4V"FUS9VED(")#;VYD:71I;VYS(@IM
M<V=S='(@(D-O;F1I>FEO;FDB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HY
M-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*;7-G<W1R(")$
M:69F97)E;GIE(&YE;&QA(&-O;F9I9W5R87II;VYE(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$T-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!F;W(@<WEN
M8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+B(*;7-G
M<W1R("(B"B)#;VYF:6=U<F%Z:6]N92!P97(@;&$@<VEN8W)O;FEZ>F%Z:6]N
M92!C;VX@4$1!<RP@4VUA<G1P:&]N97,@92!/=71L;V]K+B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ,S0*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@
M;W5T(&]F(&1A=&4N(@IM<V=S='(@(DQA(&-O;F9I9W5R87II;VYE(.@@=F5C
M8VAI82XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`P"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R(")#;VYF:6=U<F$@
M)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"FUS
M9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(D-O;F9E<FUA(&QA(%!A
M<W-W;W)D(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HU-0IM<V=I9"`B0V]N9V\B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C8P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,PIM<V=I9"`B0V]N9V\L
M(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DW(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#@*;7-G:60@(D-O;FYE8W1I;VX@
M9F%I;&5D+B(*;7-G<W1R(")#;VQL96=A;65N=&\@9F%L;&ET;RXB"@HC.B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DW(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS,#@*;7-G:60@(D-O;FYE8W1I;VX@9F%I
M;&5D.B`B"FUS9W-T<B`B0V]L;&5G86UE;G1O(&9A;&QI=&\Z("(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R
M969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")#;VYN
M97-S:6]N92!A;"!K97ES97)V97(@;W5B8FQI8V\@<FEF:75T871A+B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<Y,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V
M97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R(")#;VYN97-S:6]N92!A;"!K
M97ES97)V97(@<'5B8FQI8V\@<FEF:75T871A+B!-;W1I=F\Z("5S("@E<RDB
M"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#@Y"FUS9VED(")#;VYN96-T:6]N('1O
M($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")#;VYN97-S:6]N92!A;"!S
M97)V97(@1E10(&9A;&QI=&$N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY
M,C0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-C<*;7-G:60@(D-O;G1A8W1S
M(@IM<V=S='(@(D-O;G1A='1I(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L
M;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(DD@8V]N
M=&%T=&D@<V]N;R!S=&%T:2!A9V=I=6YT:2!C;VX@<W5C8V5S<V\@86QL82!T
M=6$@<G5B<FEC82XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H
M<#HV,`IM<V=I9"`B0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@
M(@IM<V=S='(@(E1I<&\@9&D@8V]N=&5N=71O(&1E;"!F:6QE(&-O;7!R97-S
M;SH@(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-S4*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+WII<"YP:'`Z-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N
M=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@(D-O;G1E;G5T:2!D:2!<(B5S7"(B
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S,@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z,CD*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@
M(D-O;G1I;G5A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HU.`IM<V=I9"`B0V]O:R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O:VEE(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR,0IM<V=I9"`B0V]P>2(*;7-G<W1R(")#;W!I82(*"B,Z
M(&QI8B]61E,O<VUB+G!H<#HT.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P
M>2!F86EL960Z("5S(@IM<V=S='(@(D-O<&EA(&9A;&QI=&$Z("5S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I
M9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B0V]P:6$@<V5L97II;VYE(@H*
M(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$W,"!L:6(O3F5T+U--4R]W
M:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HV,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C,*;7-G
M:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-PIM<V=I9"`B0V]T92!D)TEV;VER
M92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY-S<*
M;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E.B`B"FUS9W-T
M<B`B3F]N('-I('!U\B!C:69R87)E(&EN(%!'4"!I;"!M97-S86=G:6\B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#4U"FUS9VED(")#;W5L9"!N
M;W0@4$=0('-I9VX@;65S<V%G93H@(@IM<V=S='(@(DYO;B!S:2!P=?(@9FER
M;6%R92!I;B!01U`@:6P@;65S<V%G9VEO(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP
M="!M97-S86=E+B(*;7-G<W1R(").;VX@<VD@<'7R(&-R:69R87)E(&EN(%,O
M34E-12!I;"!M97-S86=G:6\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C0V-PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N
M(@IM<V=S='(@(DYO;B!S:2!P=?(@9FER;6%R92!I;B!3+TU)344@:6P@;65S
M<V%G9VEO(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C$X
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A8W0N
M("5S(@IM<V=S='(@(DYO;B!S:2!P=?(@86=G:75N9V5R92!I;"!C;VYT871T
M;RX@)7,B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#@R(&QI8B](;W)D
M92]'<F]U<"]L9&%P+G!H<#HY-@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H
M<#HQ,C$*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(*
M;7-G<W1R(").;VX@<VD@<'7R(&EN=&5R<F]G87)E(&EL('-E<G9E<B!,1$%0
M+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@
M(DYO;B!S:2!P=?(@=F5R:69I8V%R92!L)V5Q=6EL:6)R:6\N("5S(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0V-@IM<V=I9"`B0V]U;&0@;F]T(&-O
M;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(DEM<&]S<VEB:6QE(&-O
M;&QE9V%R<VD@86P@<V5R=F5R($Q$05`N(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VYN
M96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R("))
M;7!O<W-I8FEL92!C;VQL96=A<G-I(&%L('-E<G9E<B!<(B5S7"(@=7-A;F1O
M($944#H@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,S(R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DEM<&]S<VEB:6QE(&-R96%R
M92!U;F$@;&ES=&$@9&D@9&ES=')I8G5Z:6]N92X@)7,B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HQ,3(X"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP
M="!01U`@9&%T83H@(@IM<V=S='(@(DEM<&]S<VEB:6QE(&1E8VEF<F%R92!I
M;"!D871O(&EN(&9O<FUA=&\@4$=0.B`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C4R,PIM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%
M(&1A=&$N(@IM<V=S='(@(DEM<&]S<VEB:6QE(&1E8VEF<F%R92!I;"!D871O
M(&EN(&9O<FUA=&\@4R]-24U%+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R("));7!O<W-I8FEL92!E;&EM
M:6YA<F4@:6P@8V]N=&%T=&\N("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("));7!O
M<W-I8FEL92!E;&EM:6YA<F4@;&4@;&ES=&$@9&D@9&ES=')I8G5Z:6]N92X@
M)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R
M:7!T(%PB)7-<(BXB"FUS9W-T<B`B(@HB26UP;W-I8FEL92!E;&EM:6YA<F4@
M;&\@<V-R:7!T(&1I(&%G9VEO<FYA;65N=&\@9&5L;"=I;7!O<W1A>FEO;F4@
M7"(E<UPB+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.CDU,R!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,X,0IM<V=I9"`B0V]U;&0@;F]T(&1E
M=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N(@IM<V=S
M='(@(DEM<&]S<VEB:6QE(&1E=&5R;6EN87)E(&=L:2!I;F1I<FEZ>FD@96UA
M:6P@9&5I(&1E<W1I;F%T87)I+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HR.#,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T
M92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(FE);7!O<W-I8FEL92!S8V%R:6-A
M<F4@:6X@;6]D;R!C;VUP;&5T;R!L82!R=6)R:6-A+B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*;7-G:60@(D-O=6QD(&YO="!F
M971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B26UP
M;W-S:6)I;&4@<V-A<FEC87)E(&EN(&UO9&\@8V]M<&QE=&\@;&$@;&ES=&$@
M9&D@9&ES=')I8G5Z:6]N92XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-#0V"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L
M971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R("(B"B))
M;7!O<W-I8FEL92!S8V%R:6-A<F4@:6X@;6]D;R!C;VUP;&5T;R!L82!L:7-T
M82!D96QL92!L:7-T92!D:2!D:7-T<FEB=7II;VYE+B(*"B,Z(&QI8B]61E,O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC.B!L:6(O5D93
M+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB
M"FUS9W-T<B`B26UP;W-S:6)I;&4@8V%R:6-A<F4@;&$@<W1R871E9VEA(%PB
M)7-<(BXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E
M9WDO9&ER96-T+G!H<#HS,`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S:6)I;&4@
M8W)E87)E(&QA(&1I<F5C=&]R>2!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z-S$Y"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI
M8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R("));7!O<W-I8FEL
M92!O='1E;F5R92!L82!C:&EA=F4@<'5B8FQI8V$@9&%L('-E<G9E<BXB"@HC
M.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HQ,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@7"(E
M<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R("));7!O<W-I8FEL92!A<')I<F4@
M7"(E<UPB('!E<B!L82!R:7-C<FET='5R82XB"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,T-2!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C<W"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HR-C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S
M='(@(DEM<&]S<VEB:6QE(&%P<FER92`E<RXB"@HC.B!L:6(O2&]R9&4O36%I
M;G1E;F%N8V4N<&AP.C0R,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*;7-G<W1R("))
M;7!O<W-I8FEL92!A<')I<F4@:6P@;6]D=6QO($UA:6YT96YA;F-E7U1A<VL@
M)7,B"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E
M;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("));7!O<W-I8FEL92!A<')I
M<F4@;&$@9&ER96-T;W)Y(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O1W)O=7`O
M;&1A<"YP:'`Z,3$Q(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@
M;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C(S-R!L:6(O2&]R9&4O1W)O=7`O
M;&1A<"YP:'`Z-#<X"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HU,38@
M;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!L:6(O2&]R9&4O1W)O
M=7`O;&1A<"YP:'`Z-C4V(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV.3D*
M;7-G:60@(D-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S
M='(@(DEM<&]S<VEB:6QE(&-O;G1A='1A<F4@:6P@<V5R=F5R($Q$05`N(@H*
M(SH@;&EB+U9&4R]/8FIE8W0N<&AP.C(T,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T<B`B26UP;W-S:6)I;&4@;&5G
M9V5R92`E<RXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM
M<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE
M(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL
M<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@
M861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM
M<V=S='(@(B(*(DEM<&]S<VEB:6QE(&%Z>F5R87)E(&QA('!A<W-W;W)D('!E
M<B!L)W5T96YT92!R:6-H:65S=&\N($%L8W5N:2!O('1U='1I(&D@(@HB9&5T
M=&%G;&D@;F]N('-O;F\@8V]R<F5T=&DN(%)I<')O=F$@86YC;W)A(&\@8V]N
M=&%T=&$@;"=A;6UI;FES=')A=&]R92!S92`B"B)N96-E<W-I=&D@9&D@=6QT
M97)I;W)E(&%I=71O+B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS,#<@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,S.`HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<U(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#$*(SH@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,X-PIM<V=I9"`B0V]U;&0@;F]T(')E=')I979E
M($%#3"(*;7-G<W1R("));7!O<W-I8FEL92!R96-U<&5R87)E($%#3"(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-S0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@
M)7,B"FUS9W-T<B`B26UP;W-S:6)I;&4@<F5C=7!E<F%R92!L82!R=6)R:6-A
M+B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("));7!O<W-I8FEL92!R96-U<&5R
M87)E(&QA(&QI<W1A(&1I(&1I<W1R:6)U>FEO;F4N("5S(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E
M<R(*;7-G<W1R("));7!O<W-I8FEL92!R96-U<&5R87)E(&QE(&QI<W1E(&1I
M(&1I<W1R:6)U>FEO;F4N("5S(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C$Y-R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,C$W"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C$*;7-G
M:60@(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B
M"FUS9W-T<B`B26UP;W-S:6)I;&4@<F5C=7!E<F%R92!L92!P;W-S:6)I;&ET
MX"!D96P@<V5R=F5R(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`IM
M<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M("));7!O<W-I8FEL92!I;G9E<G1I<F4@;&$@8V]N9FEG=7)A>FEO;F4N(@H*
M(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER(%PB
M)7-<(BXB"FUS9W-T<B`B26UP;W-S:6)I;&4@8V%N8V5L;&%R92!L82!D:7)E
M8W1O<GD@7"(E<UPB+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(DEM<&]S<VEB:6QE('-A;'9A<F4@;&$@8V]N
M9FEG=7)A>FEO;F4@9&D@)7,N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C8S(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y"FUS9VED(")#;W5L9"!N
M;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@(DEM<&]S
M<VEB:6QE('-A;'9A<F4@=6YA(&-O<&EA(&1E;&QA(&-O;F9I9W5R87II;VYE
M+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ
M("5S(@IM<V=S='(@(DEM<&]S<VEB:6QE('-A;'9A<F4@=6YA(&-O<&EA(&1E
M;&QA(&-O;F9I9W5R87II;VYE.B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E
M('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(B(*
M(DEM<&]S<VEB:6QE('-A;'9A<F4@;&\@<V-R:7!T(&1I(&%G9VEO<FYA;65N
M=&\@9&5L;&4@:6UP;W-T87II;VYI('-U.B!<(B5S7"(N(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB
M"FUS9W-T<B`B26UP;W-S:6)I;&4@<V%L=F%R92!I;"!F:6QE(&1I('-A;'9A
M=&%G9VEO(&1E;&QA(&-O;F9I9W5R87II;VYE(&1I("5S+B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U
M(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E
M('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D
M92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B(@HB26UP;W-S:6)I;&4@<V%L=F%R
M92!I;"!F:6QE(&1I(&-O;F9I9W5R87II;VYE(&1I("5S+B!0=6]I('5S87)E
M(&YA(&1E;&QE("(*(F]P>FEO;FD@<&5R('-A;'9A<F4@:6P@8V]D:6-E('-U
M("5S(&\@8V]P:6%R92!M86YU86QM96YT92!I;"!C;V1I8V4@<V]T=&\@<W4@
M(@HB)7,N(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,30S"FUS9VED
M(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B
M26UP;W-S:6)I;&4@9F%R92!U;F$@<G5C97)C82!N96P@<V5R=F5R($Q$05`N
M(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN
M:R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('5P9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R("));7!O<W-I8FEL92!A9V=I
M;W)N87)E(&EL(&-O;G1A='1O+B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B26UP
M;W-S:6)I;&4@86=G:6]R;F%R92!L82!L:7-T82!D:2!D:7-T<FEB=7II;VYE
M+B`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@
M7"(E<UPB.B`E<R(*;7-G<W1R("));7!O<W-I8FEL92!S8W)I=F5R92!L82!C
M;VYF:6=U<F%Z:6]N92!P97(@7"(E<UPB.B`E<R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-S`*;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL
M;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM
M<V=S='(@(DEM<&]S<VEB:6QE('1R;W9A<F4@;&$@4VED96)A<B!D:2!-;WII
M;&QA+B!!<W-I8W5R871I(&-H92!S:6$@87!E<G1A+B(*"B,Z(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T:&4@9F]L;&]W:6YG
M(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S(@IM<V=S='(@(B(*
M(DEM<&]S<VEB:6QE(&1A<F4@86QL)W5T96YT92!<(B5S7"(@:2!S96=U96YT
M:2!D:7)I='1I('!E<B!L82!C87)T96QL82!<(B5S(@HB7"(Z("5S(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$T,3D*;7-G:60@(D-O=6YT960@=&5X="(*
M;7-G<W1R(")497-T;R!C;VYT871O(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU-S`*;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`B3F%Z:6]N92(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-S4*;7-G:60@(D-O=7)S
M97,B"FUS9W-T<B`B0V]R<VDB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*
M;7-G<W1R(")#<F5A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED(")#<F5A=&4@82!L:6YK(@IM
M<V=S='(@(D-R96$@=6X@;&EN:R(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N
M=&ET>7-E;&5C="YI;F,Z.30*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS
M9W-T<B`B0W)E82!U;F\@;G5O=F\B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.3(@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP
M.C4R"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B0W)E87)E
M('-O='1O(&-A<G1E;&QE(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR
M-#`*;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B0W)E871O
M<F4@9&D@<&5R;65S<VDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(Q,@IM
M<V=I9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(DYU;65R;R!C87)T
M82!D:2!C<F5D:71O(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,#D*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C8U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-`IM<V=I
M9"`B0W5B82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*
M;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B0V]R<F5N=&4@-"!&
M87-I(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4P"FUS9VED(")#=7)R96YT
M(%-E<W-I;VYS(@IM<V=S='(@(E-E<W-I;VYI(&-O<G)E;G1I(@H*(SH@;&EB
M+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED
M(")#=7)R96YT(%1I;64B"FUS9W-T<B`B5&5M<&\@071T=6%L92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T<B`B3&$@55),(&%T='5A
M;&4@Z"(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-0IM<V=I9"`B0W5R<F5N
M="!5<V5R<R(*;7-G<W1R(")5=&5N=&D@071T=6%L:2(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R
M(")496UP;R!!='1U86QE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(V-`IM<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R(")#
M;VYD:7II;VYE(&-O<G)E;G1E.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM
M<V=S='(@(E-T:6QE(&-O<G)E;G1E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@
M=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(E!E<G-O;F%L:7IZ
M82!L92!O<&5R87II;VYI(&1A(&5S96=U:7)E(&%L;"=A=G9I;R!D:2`E<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(E1A9VQI82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@(D-U
M="!S96QE8W1I;VXB"FUS9W-T<B`B5&%G;&EA(&QA('-E;&5Z:6]N92(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HV-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C<*;7-G
M:60@(D-Y<')U<R(*;7-G<W1R(")#:7!R;R(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@U"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B0WER:6QL:6,@
M*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#<*;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C8X"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4R('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,S(W,@IM<V=I9"`B(@HB1%-.("AS964@:'1T
M<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD
M8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O36%I
M;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R(")':6]R;F%L
M;65N=&4B"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4
M<F5E($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C,R-S`*;7-G:60@(D1A=&%B87-E($QO;VMU<"(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C,Y."!L:6(O2&]R9&4O34E-12]6:65W97(O
M<F9C.#(R+G!H<#HW,@IM<V=I9"`B1&%T92(*;7-G<W1R(")$871A(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G:60@(D1A
M=&4@4F5C96EV960B"FUS9W-T<B`B1&%T82!2:6-E=G5T82(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR-S@Y"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G
M<W1R(")396QE>FEO;F$@;&$@9&%T82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR.#$@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q
M,0IM<V=I9"`B1&%Y(@IM<V=S='(@(D=I;W)N;R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@IM<V=I9"`B
M1&5?;&5T92!#;VQU;6XB"FUS9W-T<B`B15]L:6UI;F$@0V]L;VYN82(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3,@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$96-E;6)E
M<B(*;7-G<W1R(")$:6-E;6)R92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@
M;G5M8F5R<R(*;7-G<W1R(").=6UE<FD@9&5C:6UA;&DB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R
M96%S92!);F1E;G0B"FUS9W-T<B`B1&EM:6YU:7-C:2!L82!R:65N=')A;GIA
M(@H*(SH@;&EB+W!R969S+G!H<#HQ,3<@;&EB+TAO<F1E+U!R969S+U5)+G!H
M<#HQ.#<*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-S<*;7-G:60@(D1E9F%U
M;'0@0V]L;W(B"FUS9W-T<B`B0V]L;W)E('-T86YD87)D(@H*(SH@;&EB+TAO
M<F1E+TED96YT:71Y+G!H<#HY-@IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*
M;7-G<W1R("))9&5N=&ETX"!D:2!D969A=6QT(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C<U"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@(E-H
M96QL(&1I(&1E9F%U;'0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*
M;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S='(@(D1E9FEN:7II;VYI(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HW,2!L:6(O2&]R9&4O4&5R;7,N<&AP.C,R-B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C0R,@HC.B!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C0S.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHY,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.0HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$X,B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M-S,*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX('1E;7!L871E
M<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O9&5L971E+FEN8SHQ,`IM<V=I9"`B1&5L971E(@IM<V=S='(@(D5L
M:6UI;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S(*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S='(@(D5L
M:6UI;F$@0V5L;&$B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G
M<F]U<',N<&AP.C(R-PIM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@(D5L
M:6UI;F$@1W)U<'!O(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C0Y"FUS9VED(")$96QE=&4@3&]G(@IM<V=S='(@(D5L:6UI;F$@3&]G(@H*
M(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HW-R!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C$P,0IM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B
M16QI;6EN82!097)M97-S;R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY,PIM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*
M;7-G<W1R(")%;&EM:6YA<F4@92!S=G5O=&%R92!I(&UE<V%G9VDB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W
M"FUS9VED(")$96QE=&4@8V5L;"(*;7-G<W1R(")%;&EM:6YA(&-E;&QA(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV,PIM<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R(")%;&EM:6YA(&-O
M;&]N;F$B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L
M971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R(")%;&EM
M:6YA(&QA(&UA<V-H97)A(&%L=&5R;F%T:79A(&5S:7-T96YT92(*"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HU-`IM<V=I9"`B1&5L971E
M(&UE<W-A9V5S(@IM<V=S='(@(D5L:6UI;F$@:2!M97-S86=G:2(*"B,Z(&QI
M8B](;W)D92]097)M<R]522YP:'`Z-#(Q"B,L('!H<"UF;W)M870*;7-G:60@
M(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(D5L:6UI
M;F$@:2!P97)M97-S:2!P97(@7"(E<UPB(@H*(SH@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI
M<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM
M<V=S='(@(D5L:6UI;F$@:2!P97)M97-S:2!P97(@7"(E<UPB(&4@;V=N:2!S
M;W1T;RUP97)M97-S;S\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@<F]W(@IM<V=S
M='(@(D5L:6UI;F$@<FEG82(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I
M9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET
M>2(*;7-G<W1R(")%;&EM:6YA(&PG:61E;G1I=.`@<V5L97II;VYA=&$B"@HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3,*;7-G:60@(D1E
M;&5T92!S=6(@9F]L9&5R<R(*;7-G<W1R(")%;&EM:6YA(&QE('-O='1O(&-A
M<G1E;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L
M=6UN(@IM<V=S='(@(D5L:6UI;F$@;&$@8V]L;VYN82!C;W)R96YT92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV,PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O=R(*;7-G<W1R(")%
M;&EM:6YA(&QA(')I9V$@8V]R<F5N=&4B"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HS-@HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('-E='5P
M('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B16QI;6EN82!L;R!S
M8W)I<'0@9&D@86=G:6]R;F%M96YT;R!D96QL92!I;7!O<W1A>FEO;FD@9&D@
M7"(E<UPB+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C(Q(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C,@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4Y-0IM<V=I9"`B1&5L:79E<GD@=&EM92(*
M;7-G<W1R(")496UP;R!D)VEN=FEO(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HW,0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R
M(")$86YI;6%R8V$B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`B1&5S
M8W)I=FD@:6P@<')O8FQE;6$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3,X
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S`*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(D1E<V-R:7II;VYE(@H*
M(SH@;&EB+TAO<F1E+G!H<#HR,#8*;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@
M2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B1&5T=&%G;&D@*&%N8VAE(&YE
M;"!F:6QE(&1I(&QO9R!D:2!(;W)D92DZ(@H*(SH@;&EB+TAO<F1E+G!H<#HR
M,3`*;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(DD@9&5T=&%G;&D@<V]N;R!S=&%T:2!S
M8W)I='1I(&YE;"!F:6QE(&1I(&QO9R!P97(@;"=A;6UI;FES=')A=&]R92XB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(Q"FUS9VED(")$979E
M;&]P;65N="(*;7-G<W1R(")3=FEL=7!P;R(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C(T"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B4'5N=&\@9&D@
M<G5G:6%D82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`Q"FUS9VED(")$
M97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(E!U;G1O(&1I(')U
M9VEA9&$@<&5R(&PG=6QT:6UA(&]R83H@(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(Q-@IM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B
M4'5N=&\@9&D@<G5G:6%D83H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE9G0@=&\@
M<FEG:'0B"FUS9W-T<B`B1&ER97II;VYE(&1A('-I;FES=')A(&$@9&5S=')A
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT('1O(&QE9G0B"FUS9W-T<B`B1&ER
M97II;VYE(&1A(&1E<W1R82!A('-I;FES=')A(@H*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<P"FUS9VED(")$:7-P;&%Y(#(T+6AO
M=7(@=&EM97,_(@IM<V=S='(@(E9I<W5A;&EZ>F$@:6P@=&5M<&\@;F5L(&9O
M<FUA=&\@,C0@;W)E/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#`*
M;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R(")/<'II;VYI(&1I('9I
M<W5A;&EZ>F%Z:6]N92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HX.0IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R
M(")6:7-U86QI>GIA('!R979I<VEO;F4@9&5T=&%G;&EA=&$B"@HC.B!L:6(O
M8FQO8VLO;65T87(N<&AP.CDR"FUS9VED(")D:7-P;&%Y(&9O<F5C87-T("AT
M868I(@IM<V=S='(@(G9I<W5A;&EZ>F$@<')E=FES:6]N92`H=&%F*2(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR-SDY"FUS9VED(")$:7-P;&%Y(&9O<FUA
M="(*;7-G<W1R(")&;W)M871O(&1I('9I<W5A;&EZ>F%Z:6]N92(*"B,Z(&QI
M8B](;W)D92]-24U%+TU$3BYP:'`Z,3DQ"FUS9VED(")$:7-P;W-I=&EO;B!.
M;W1I9FEC871I;VXB"FUS9W-T<B`B3F]T:69I8V$@9&D@9&ES<&]S:7II;VYE
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW
M,`IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HT,C(*;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B
M3F]N(&5L:6UI;F%R92(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR
M-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP
M:'`B"FUS9W-T<B`B3F]N(&%C8V5D97)E(&1I<F5T=&%M96YT92!M86EN=&5N
M86YC92YP:'`B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,B!T
M96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E<R!T:&4@
M9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H
M96-K('1H:7,@8F]X.B(*;7-G<W1R("(B"B),87!R:6UA(')I9V$@8V]N=&EE
M;F4@:6P@8V%M<&\@9&5I(&YO;6D_(%-E('-I+"!S96QE>FEO;F$@<75E<W1A
M(&-A<V5L;&$Z(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HW,@IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C<Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,PIM<V=I9"`B
M1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N
M=#\@4VEG;B!U<"XB"FUS9W-T<B`B3F]N(&AA:2!U;B=U=&5N>F$_(&ES8W)I
M=FET:2XB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#4S"FUS
M9VED(")$;W=N;&]A9"(*;7-G<W1R(")38V%R:6-A(@H*(SH@;&EB+TAO<F1E
M+TU)344O0V]N=&5N=',N<&AP.C@U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")$
M;W=N;&]A9"`E<R(*;7-G<W1R(")38V%R:6-A("5S(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$V,0IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D(&-O
M;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`B3&$@8V]N9FEG
M=7)A>FEO;F4@9V5N97)A=&$@Z"!S=&%T82!S8V%R:6-A=&$@8V]M92!S8W)I
M<'0@4$A0+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,3`W"FUS9VED(")$
M<F]P(&1O=VX@;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(D1R;V=H92(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B12U-86EL(@IM<V=S
M='(@(B(*"B,Z(&QI8B].970O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G
M:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S
M('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*
M;7-G:60@(D524B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C<U"FUS9VED(")%8W5A9&]R(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV
M.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@IM<V=I9"`B161I="(*;7-G<W1R(")0
M=6)B;&EC82(*"B,Z(&QI8B](;W)D92]";&]C:R]522YP:'`Z-3`*;7-G:60@
M(D5D:70@0FQO8VLB"FUS9W-T<B`B5FES=6%L:7IZ82!B;&]C8V\B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C$Y."!A9&UI;B]G<F]U<',N<&AP.C(R-@IM<V=I
M9"`B161I="!'<F]U<"(*;7-G<W1R(")6:7-U86QI>GIA($=R=7!P;R(*"B,Z
M(&QI8B](;W)D92]097)M<R]522YP:'`Z-S8@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HQ,#`*;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R(")6:7-U
M86QI>GIA(%!E<FUE<W-O(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP
M.C(S-PIM<V=I9"`B161I="!097)M:7-S:6]N<R(*;7-G<W1R(")6:7-U86QI
M>GIA(%!E<FUE<W-I(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E
M<R(*;7-G<W1R(")6:7-U86QI>GIA(%!E<FUE<W-I('!E<B`E<R(*"B,Z('1E
M;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F
M;W(Z(@IM<V=S='(@(E9I<W5A;&EZ>F$@;&4@;W!Z:6]N:2!P97(Z(@H*(SH@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B161I="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(E9I<W5A
M;&EZ>F$@:2!P97)M97-I('!E<B!<(B5S7"(B"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R
M;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(E9I<W5A;&EZ>F$@:2!P97)M97-S
M:2!P97(@)7,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@
M(D5D=6-A=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C<W"FUS9VED(")%9WEP="(*;7-G<W1R(")%
M9VET=&\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,3<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M,PIM<V=I9"`B16QE;65N="XN+B(*;7-G<W1R(")%;&5M96YT;RXN+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS
M9VED(")%;2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@V
M.2!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(R-`IM<V=I9"`B
M16UA:6PB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU-C8@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV.`HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$P"FUS9VED(")%;6%I
M;"!!9&1R97-S(@IM<V=S='(@(DEN9&ER:7IZ;R!%;6%I;"(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ.38S"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S
M="!M871C:"XB"FUS9W-T<B`B3"=I;F1I<FEZ>F\@16UA:6P@9&5V92!C;W)R
M:7-P;VYD97)E+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.3@Y"FUS9VED
M(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")%;6%I;"!C;VX@
M8V]N9F5R;6$B"@HC.B!L:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ
M"FUS9VED(")%;6%I;"UT;RU335,@1V%T97=A>2(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDY"FUS9VED(")%
M;6]T:6-O;G,B"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#(*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@
M(DUE<W-A9V=I;R!V=6]T;RXB"@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP
M:'`Z,C0S(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HT.#0*(SH@;&EB+TAO
M<F1E+T=R;W5P+VQD87`N<&AP.C8V,B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP
M:'`Z-S`U"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B
M16UP='D@<F5S=6QT+B(*;7-G<W1R(")2:7-U;'1A=&\@=G5O=&\N(@H*(SH@
M;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S
M96%R8V@@=&5R;7,B"FUS9W-T<B`B4FEC97)C82!D96D@=&5R;6EN:2!V=6]T
M82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#<*;7-G:60@(D5N86)L
M92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN
M('1E>'0_(@IM<V=S='(@(B(*(D%B:6QI=&$@;"=I;G-E<FEM96YT;R!D:2!I
M;6UA9VEN:2!N96P@=&5S=&\@9&%L;&$@1V%L;&5R:6$@9&5L;&4@1F]T;V=R
M869I93\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(R"FUS9VED(")%
M;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R(")!8FEL
M:71A<F4@:6P@;65N=2!D:2!C;VYT97-T;R!C;&EC8V%N9&\@:6P@=&%S=&\@
M9&5S=')O(&1E;"!M;W5S93\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4X
M."!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y,PIM<V=I9"`B16YD('EE87(B"FUS
M9W-T<B`B1FEN92!A;FYO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%9&ET;W(B"FUS9W-T
M<B`B26YG<F%D:7-C:2!L)V5D:71O<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR,C0*;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@
M=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@
M>6]U<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y
M;W5R('!E=#\G.B(*;7-G<W1R("(B"B));G-E<FES8VD@=6YA(&1O;6%N9&$@
M<VEC=7)A(&-H92!T:2!V97)RX"!C:&EE<W1A('-E(&%V<F%I(&YE8V5S<VET
MX"!D:2`B"B)A>GIE<F%R92!L82!T=6$@<&%S<W=O<F0L(&5S("=Q=6%L)^@@
M:6P@;F]M92!D96P@='5O(&-U8V-I;VQO/R<Z(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(R"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"FUS9VED
M(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T<B`B26YS97)I<V-I
M(&PG55),(&1E;&PG:6UM86=I;F4@<75I(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C@Y,@IM<V=I9"`B16YT97(@=&AE(&QE='1E
M<G,@8F5L;W<Z(@IM<V=S='(@(DEN<V5R:7-C:2!L92!L971T97)E('-O='1O
M(')I<&]R=&%T93HB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.CDY"FUS9VED(")%<75A=&]R:6%L($=U:6YE82(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C<Y"FUS9VED(")%<FET<F5A(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S8@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0X"B,Z
M(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR
M-PHC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+U9I97<N<&AP.CDT"FUS9VED
M(")%<G)O<B(*;7-G<W1R(")%<G)O<F4B"@HC.B!L:6(O2&]R9&4O5&5M<&QA
M=&4N<&AP.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN
M9R!B;&]C:SH@)7,B"FUS9W-T<B`B17)R;W)E(&-R96%N9&\@:6P@8FQO8V-O
M.B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C<R"B,L('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E
M<R(*;7-G<W1R(")%<G)O<F4@96QI;6EN86YD;R!L)V%N8V]R82!D:2!S:6YC
M<F]N:6$Z("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z
M("5S(@IM<V=S='(@(D5R<F]R92!E;&EM:6YA;F1O(&EL(&QO9R!D:2!S:6YC
M<F]N:6$Z("5S(@H*(SH@;&EB+TAO<F1E+U1E;7!L871E+G!H<#HT-C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*
M;7-G<W1R(")%<G)O<F4@;W1T96YE;F1O(&EL(&-O;G1E;G5T;SH@)7,B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@
M(D5R<F]R92!A9V=I;W)N86YD;R!L82!P87-S=V]R9#H@)7,B"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@
M=VET:"!E;6%I;"!M97-S86=E+B(*;7-G<W1R(")%<G)O<F4@8V]N(&EL(&UE
M<W-A9V=I;R!E;6%I;"XB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(D5R<F]R92!S8W)I=F5N
M9&\@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-S8*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C<X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,0IM<V=I9"`B
M171H:6]P:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0S"FUS9VED(")%=F5R>2`Q-2!M:6YU
M=&5S(@IM<V=S='(@(D]G;FD@,34@;6EN=71I(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,Y,PIM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S='(@
M(D]G;FD@,B!M:6YU=&DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0P
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(D5V97)Y(#,P('-E
M8V]N9',B"FUS9W-T<B`B3V=N:2`S,"!S96-O;F1I(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,T,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDT"FUS
M9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B3V=N:2`U(&UI;G5T:2(*
M"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y
M($QO9VEN(@IM<V=S='(@(D%D(&]G;FD@86-C97-S;R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-#0*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G
M<W1R(")/9VYI(&UE>GHG;W)A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,T,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDR"FUS9VED(")%=F5R>2!M
M:6YU=&4B"FUS9W-T<B`B3V=N:2!M:6YU=&\B"@HC.B!T96UP;&%T97,O9&%T
M82]D871E;6%P+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V86QU97,Z(@IM<V=S
M='(@(E9A;&]R:2!D)V5S96UP:6\Z(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP
M.C4Q(&%D;6EN+W!H<'-H96QL+G!H<#HX,B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3(X"FUS9VED(")%>&5C=71E(@IM<V=S='(@(D5S96=U:2(*"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C$T"FUS9VED(")%>'!A
M;F0B"FUS9W-T<B`B17-P86YD:2(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED
M96)A<BYI;F,Z,S(*;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@(D5S
M<&%N9&D@4VED96)A<B(*"B,Z(&QI8B](;W)D92]344PO2V5Y=V]R9',N<&AP
M.C$V.`IM<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@(E!R979I<W1O("<I
M)R(*"B,Z(&QI8B](;W)D92]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B
M17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G
M<W1R(")I4&%R;VQA('!R979I<W1A(&\@=&5R;6EN92!C:71A=&\@9&D@<FEC
M97)C82(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B
M17AP:7)A=&EO;B!$871E(@IM<V=S='(@(D1A=&$@9&D@<V-A9&5N>F$B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8W-PIM<V=I9"`B17AP;VYE
M;G0B"FUS9W-T<B`B17-P;VYE;G1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B
M"FUS9W-T<B`B0V]L;W)E($9'(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$W-@IM<V=I9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R(")!9V=I
M;W)N86UE;G1O($944"!D96QL92!I;7!O<W1A>FEO;FDB"@HC.B!L:6(O2&]R
M9&4O4')E9G,O<W%L+G!H<#HR,C`*;7-G:60@(D9A:6QE9"!R971R:65V:6YG
M('!R969E<F5N8V5S+B(*;7-G<W1R(")496YT871I=F\@9F%L;&ET;R!N96P@
M<F5C=7!E<F\@9&5L;&4@<')E9F5R96YZ92XB"@HC.B!L:6(O2&]R9&4O1W)O
M=7`O;&1A<"YP:'`Z-S4@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z.3@*;7-G
M:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R
M(")#;VQL96=A;65N=&\@86P@<V5R=F5R($Q$05`@9F%L;&ET;RXB"@HC.B!L
M:6(O2&]R9&4O075T:"]S;6(N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N
M;F5C="!T;R!334(@<V5R=F5R+B(*;7-G<W1R(")#;VQL96=A;65N=&\@86P@
M<V5R=F5R(%--0B!F86QL:71O+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW,C4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S
M7"(N(@IM<V=S='(@(DYO;B#H(')I=7-C:71O(&$@8V]P:6%R92!D82!<(B5S
M7"(N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<S,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")&86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(DYO;B#H
M(')I=7-C:71O(&$@8V]P:6%R92!A(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O
M075T:"]S87-L+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@
M4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R(").;VX@Z"!R:75S8VET;R!A(&-R
M96%R92!U;F$@;G5O=F$@8V]N;F5S<VEO;F4@4T%33"XB"@HC.B!L:6(O5D93
M+V9T<"YP:'`Z-S8X(&QI8B]61E,O<VUB+G!H<#HU,30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R(").
M;VX@Z"!R:75S8VET;R!A('-P;W-T87)E(&$@7"(E<UPB+B(*"B,Z(&QI8B]6
M1E,O<VUB+G!H<#HT-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O
M(')E=')I979E.B`E<R(*;7-G<W1R(").;VX@Z"!R:75S8VET;R!A(')E8W5P
M97)A<F4Z("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T<B`B1VEU<W1O(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C<Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-`IM<V=I9"`B
M1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<S(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HX,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#8*;7-G:60@
M(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-,22YP
M:'`Z,C,X"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`B17)R;W)E($9A
M=&%L93HB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$X
M-PIM<V=I9"`B1F%X(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS-3$*;7-G:60@(D9A>&5S(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#,@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R>2(*;7-G
M<W1R(")&96)B<F%I;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(W"FUS
M9VED(")&965L<R!,:6ME(@IM<V=S='(@(E-I;6EL92!A(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,`IM<V=I9"`B1F5E;',@;&EK93H@
M(@IM<V=S='(@(E-I;6EL92!A.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$Y"FUS9VED(")&97<@4VAO=V5R<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M,`IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3DT-`IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,S(U"FUS9VED(")&:6=L
M970@0T%05$-(02(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,S,R.0IM<V=I9"`B1FEG;&5T(&9O;G0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C@Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,PIM<V=I9"`B1FEJ
M:2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M-34*;7-G:60@(D9I;&4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C`@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-SD*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R
M(")#;VYT96=G:6\@9FEL93H@)7,@9FEL92(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]R87(N<&AP.C8P(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN
M<&AP.C<Y"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,L
M('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S
M='(@(D-O;G1E9V=I;R!F:6QE.B`E<R!F:6QE<R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT,#D*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R
M(")'97-T:6]N92!&:6QE(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C,@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*;7-G:60@(D9I;&4@
M3F%M92(*;7-G<W1R(").;VUE($9I;&4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,CDW-PIM<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T<B`B4V5L97II
M;VYE(&9I;&4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30X-@IM<V=I9"`B
M1FEL92!U<&QO860B"FUS9W-T<B`B0V%R:6-A($9I;&4B"@HC.B!L:6(O2&]R
M9&4O0G)O=W-E<BYP:'`Z.3`P"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U
M<'!O<G1E9"XB"FUS9W-T<B`B0V%R:6-A;65N=&\@9FEL92!N;VX@<W5P<&]R
M=&%T;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY,0IM<V=I9"`B
M1FEL=&5R<R(*;7-G<W1R(")&:6QT<FDB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@R"FUS9VED(")&:6YL86YD(@IM<V=S
M='(@(D9I;FQA;F1I82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*;7-G
M:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B4')I;6\@365Z>F\B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED
M(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(E!R:6UO(%%U87)T;R(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR-3<*;7-G:60@(D9I
M>"!R871I;R(*;7-G<W1R(")287!P;W)T;R!F:7-S;R(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HR,S(*;7-G:60@(D9L:7`B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@(D9O
M9R(*;7-G<W1R(").96)B:6$B"@HC.B!L:6(O5D93+VUU<W%L+G!H<#HQ,#<@
M;&EB+U9&4R]S<6PN<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD
M97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B3&$@0V%R=&5L;&$@)7,@
M;F]N(&5S:7-T92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`B0V]L;W)E
M(&1E;&QA(&9O;G1E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS
M9VED(")&;V]D(@IM<V=S='(@(D-I8F\B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C8*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*;7-G:60@(D9O
M<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@
M(E!E<B!B<F]W<V5R(&-H92!N;VX@<W5P<&]R=&%N;R!L92!I;6UA9VEN:2(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S0Q"FUS9VED(")&;W)E8V%S="`H
M5$%&*2(*;7-G<W1R(")0<F5V:7-I;VYE("A4048I(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C<R"FUS9VED("(B"B)&;W)E8V%S="!$87ES
M("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T
M:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD
M(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z,3`R"FUS9VED(")&;W)G;W0@>6]U<B!P
M87-S=V]R9#\B"FUS9W-T<B`B2&%I(&1I;65N=&EC871O(&QA('!A<W-W;W)D
M/R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-C0*;7-G:60@(D9O
M<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0IM
M<V=I9"`B1F]R='5N92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*;7-G:60@(D9O<G1U;F5S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B1F]R
M='5N97,@,B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#4U"FUS9VED(")&;W)U;7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$Q,0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B
M26YO;'1R:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S='(@(E9E(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PIM<V=I9"`B
M1G)A;65S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z.#<*;7-G:60@(D9R86YC92(*;7-G<W1R(")&<F%N
M8VEA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R
M86YC92P@365T<F]P;VQI=&%N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX
M-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3$*;7-G:60@(D9R96YC:"!'
M=6EA;F$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ.#0*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C(R"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP
M:'`Z-S0*;7-G:60@(D9R;VTB"FUS9W-T<B`B1&$B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C,W(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS-#D*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y-0IM
M<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@(D1A(&EL("(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"FUS9VED(")&=6QL($1E<V-R:7!T
M:6]N(@IM<V=S='(@(D1E<V-R:7II;VYE($-O;7!L971A(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@
M(D9U;&P@36]O;B(*;7-G<W1R("),;F$@4&EE;F$B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-C4@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHV,`IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(DYO;64@0V]M<&QE=&\B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@X
M"FUS9VED(")'86)O;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A
M;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S='(@(D=A;&QE<FEA(&1A
M;&QA('%U86QE('!R96YD97)E(&QE(&EM;6%G:6YI(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS
M9VED(")'86QL97)Y.B(*;7-G<W1R(")'86QL97)I83HB"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDV"FUS9VED(")'86UB
M:6$B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N
M(@IM<V=S='(@(D=E;F5R82`E<R!#;VYF:6=U<F%Z:6]N92(*"B,Z('1E;7!L
M871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T
M960@0V]D92(*;7-G<W1R(")#;V1I8V4@1V5N97)A=&\B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDP"FUS9VED(")'96]R
M9VEA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B1V5R;6%N
M:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.CDS"FUS9VED(")':&%N82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDT"FUS9VED(")':6)R86QT87(B
M"FUS9W-T<B`B1VEB:6QT97)R82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3<V"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(DYO;64@1&%T
M;R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-SD@=&5M<&QA
M=&5S+W!R969S+V%P<"YI;F,Z,3`*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI
M;F,Z,3D*;7-G:60@(D=L;V)A;"!/<'1I;VYS(@IM<V=S='(@(D]P>FEO;FD@
M1VQO8F%L:2(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$W"FUS9VED
M(")';R(*;7-G<W1R(")686DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#`*;7-G:60@(D=O961E;"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$S,0IM<V=I9"`B1V]O9VQE($UA<',B
M"FUS9W-T<B`B36%P<&4@1V]O9VQE(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP
M:'`Z,R!L:6(O0FQO8VLO9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HT,0IM<V=I9"`B1V]O9VQE(%-E87)C:"(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,X"FUS9VED(")'
M<F%Y<V-A;&4B"FUS9W-T<B`B4V-A;&4@9&D@9W)I9VDB"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,`IM<V=I9"`B1W)E
M96-E(@IM<V=S='(@(D=R96-I82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@X"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.CDT"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY-0IM<V=I
M9"`B1W)E96YL86YD(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#D*;7-G:60@(D=R96YA9&$B"FUS9W-T
M<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-SD*;7-G:60@(D=R;W5P($%D
M;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%M;6EN:7-T<F%Z:6]N92!'<G5P<&DB
M"@HC.B!L:6(O2&]R9&4O1W)O=7`N<&AP.C4Y(&QI8B](;W)D92]'<F]U<"]L
M9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M
M<'1Y(@IM<V=S='(@(DD@;F]M:2!D96P@9W)U<'!O(&YO;B!D979O;F\@97-S
M97)R92!V=6]T:2(*"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HS,#<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D
M9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM
M<V=S='(@(B(*(D=R;W5P7VQD87`Z($EM<&]S<VEB:6QE(&%G9VEU;F=E<F4@
M:6P@9W)U<'!O("5S+B!1=65S=&$@Z"!L82!R:7-P;W-T82!D96P@(@HB<V5R
M=F5R.B`B"@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,3$X(&QI8B](
M;W)D92]'<F]U<"]L9&%P+G!H<#HQ,C0*(SH@;&EB+TAO<F1E+T=R;W5P+VQD
M87`N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5
M;F%B;&4@=&\@9&5L971E(&=R;W5P("5S(@IM<V=S='(@(D=R;W5P7VQD87`Z
M($EM<&]S<VED:6QE(&5L:6UI;F%R92!I;"!G<G5P<&\@)7,B"@HC.B!L:6(O
M2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,S,X(&QI8B](;W)D92]'<F]U<"]L9&%P
M+G!H<#HS-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA
M8FQE('1O('5P9&%T92!G<F]U<"`E<R(*;7-G<W1R(")'<F]U<%]L9&%P.B!)
M;7!O<W-I8FEL92!A9V=I;W)N87)E(&EL(&=R=7!P;R`E<R(*"B,Z(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C,X(&QI8B](;W)D92]097)M<R]522YP:'`Z,S$T
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<W"FUS9VED(")'<F]U
M<',B"FUS9W-T<B`B1W)U<'!I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HY.`IM<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$P,PIM<V=I9"`B1W5A;2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,@IM<V=I9"`B1W5A=&5M86QA
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,@IM<V=I
M9"`B1W5E<FYS97DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX.`IM<V=I9"`B
M1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B4&5R;65S<VD@9&5G;&D@;W-P
M:71I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W,@IM<V=I9"`B
M1W5E<W1B;V]K(@IM<V=S='(@(DQI8G)O(&1E9VQI(&]S<&ET:2(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HY.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3<*;7-G:60@
M(D=U:6YE82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,#0*;7-G:60@(D=U:6YE82U":7-S874B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3`U"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.CDV,`IM<V=I9"`B2%1-3"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U
M"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!C96QL(&EN(')O=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B
M2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@
M8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,
M07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@
M:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+VAT='`N
M<&AP.C$U-PIM<V=I9"`B2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#(*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$Q,`IM<V=I9"`B2&%I=&DB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")(87-H+4%L9V]R:71H
M;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR,@IM<V=I9"`B2&%Z92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z.3$Y(&QI8B](;W)D92]&;W)M+G!H<#HR.3$T"FUS9VED
M(")(96%D97(B"FUS9W-T<B`B26YT97-T87II;VYE(@H*(SH@;&EB+TAO<F1E
M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-C$*;7-G:60@(DAE861E<G,B"FUS
M9W-T<B`B26YT97-T87II;VYI(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3`W"FUS9VED(")(96%R9"!)<VQA;F0@86YD
M($UC1&]N86QD($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C,*;7-G:60@(DAE879Y(%0M4W1O
M<FTB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G
M:60@(DAE8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO:69R86UE+G!H<#HR,B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,T"FUS9VED(")(96EG:'0B"FUS9W-T<B`B
M06QT97IZ82(*"B,Z(&QI8B](;W)D92](96QP+G!H<#HQ.#0@;&EB+TAO<F1E
M+TAE;'`N<&AP.C$X-B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ-PHC.B!T
M96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z-`IM<V=I9"`B2&5L<"(*;7-G<W1R
M(")!:75T;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(D%I
M=71O('5S86YD;R!L)V5D:71O<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,S<Q"FUS9VED(")(96QP97(B"FUS9W-T<B`B06EU=&%N=&4B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`B
M16UI<V9E<F\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,"!T
M96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,`IM<V=I9"`B2&5R92!I<R!T
M:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R(")1=65S=&\@Z"!L
M)VEN:7II;R!D96P@9FEL93HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B2&EG:"(*;7-G<W1R(")!;'1O(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI
M;B]C;VUM;VXM:&5A9&5R+FEN8SHU"FUS9VED(")(;U]M92(*;7-G<W1R(")(
M;U]R9&4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,30@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C0S"FUS9VED(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E
M*2(*;7-G<W1R(")386YT82!3961E("A#:71T82<@9&5L(%9A=&EC86YO*2(*
M"B,Z(&QI8B](;W)D92YP:'`Z,34T.`IM<V=I9"`B2&]M92(*;7-G<W1R(")(
M;W)D92(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U"FUS9VED(")(
M;VUE($%D9')E<W,B"FUS9W-T<B`B26YD:7)I>GIO(&1I(&-A<V$B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*;7-G:60@(DAO;64@1&ER96-T;W)Y
M(@IM<V=S='(@(D1I<F5C=&]R>2!D:2!C87-A(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS
M9W-T<B`B5&5L969O;F\@9&D@8V%S82(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P.`IM<V=I9"`B2&]N9'5R87,B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3`V"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8W"FUS9VED(")(;W)D92(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0U,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O
M=6YT97)E9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0T-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@
M9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M2V]L86(N<&AP.C$R-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L
M86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX
M;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HU,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C0X"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E
M("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TMO;&%B
M+G!H<#HT.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E
M("5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3$Y-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y
M;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HQ,S,W"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(E)E
M9V]L82!O<FEZ>F]N=&%L92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*
M;7-G<W1R(")2:65M<&EM96YT;R!O<FEZ>F]N=&%L92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ
M;VYT86PZ(@IM<V=S='(@(D]R:7IZ;VYT86QE.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B
M2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T
M<B`B0V]M92!S96D@87)R:79A=&\@<75I/R`H4V5I('!R96=A=&\@9&D@9F%R
M92!U;B!R87!P;W)T;R$I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN
M<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B475A;G1E(&-O
M;&]N;F4@=G5O:2!U;FER93\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@
M=&AE<F4_(@IM<V=S='(@(E%U86YT:2!C86UP:2`H8V]L;VYN92D@8VD@<V]N
M;R`_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK
M92!T;R!M97)G93\B"FUS9W-T<B`B475A;G1E(')I9VAE('9U;VD@=6YI<F4_
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S<@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(X.0IM<V=I9"`B2'5M:61I='DB"FUS9W-T<B`B56UI
M9&ETX"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#@*;7-G
M:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B56UI9&ETX#H@(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED(")(=6UO<FES=',B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$P-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3$Q"FUS9VED(")(=6YG87)Y(@IM<V=S='(@(E5N9VAE<FEA(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR,S4@;&EB+TAO<F1E+T%U=&@O8WER
M=7,N<&AP.C$W,@HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@
M8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")#<F5A>FEO;F4@9&5L;&$@
M8V%S96QL82!)34%0(&9A;&QI=&$Z("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M8WER<W%L+G!H<#HR.34@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C(Q-`HC
M+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I
M;&5D.B`E<R(*;7-G<W1R(")#86YC96QL87II;VYE(&1E;&QA(&-A<V5L;&$@
M24U!4"!F86QL:71A.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP
M:'`Z,C0R(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ-SD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE
M9#H@)7,B"FUS9W-T<B`B0W)E87II;VYE(&1E;&QA('%U;W1A(&1E;&QA(&-A
M<V5L;&$@24U!4"!F86QL:71A.B`E<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,S$V"FUS9VED("))4"!!9&1R97-S(@IM<V=S='(@(DEN9&ER:7IZ;R!)
M4"(*"B,Z(&QI8B](;W)D92]!=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED("))
M4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DEN9&ER:7IZ;R!)
M4"!N;VX@9&ES<&]N:6)I;&4N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:7!B87-I
M8RYP:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D
M($-)1%(@8FQO8VLN(@IM<V=S='(@(DPG:6YD:7)I>GIO($E0(&YO;B#H(&%L
M;"=I;G1E<FYO(&1E;"!B;&]C8V\@0TE$4B!C;VYS96YT:71O+B(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))4"!L
M;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.0IM<V=I9"`B
M25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(DE?;G-E<FES8VD@;&$@4DEG
M82!P<FEM82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$R,`IM<V=I9"`B26-E;&%N9"(*;7-G<W1R("))<VQA;F1A(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,`IM<V=I9"`B26-O;G,@3VYL
M>2(*;7-G<W1R(")3;VQO($EC;VYE(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N
M<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G
M<W1R("))8V]N92!P97(@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S@Q"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B26-O;F4@8V]N
M('1E<W1O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,PIM<V=I9"`B
M261E;G1I='DG<R!N86UE.B(*;7-G<W1R(").;VUE(&1E;&PG261E;G1I=.`B
M"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z-C`P"B,L('!H<"UF
M;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY
M+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B(@HB
M4V4@;F]N(.@@<W1A=&\@=FES=6%L:7IZ871O(&-O<G)E='1A;65N=&4L("5S
M(&%P<FER92!I;B!U;F$@;G5O=F$@9FEN97-T<F$N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0U.0IM<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A
M;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E
M9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P
M87)E;F-Y+B(*;7-G<W1R("(B"B)392!N;VX@=F5D:2!N97-S=6YA(&EC;VYA
M('5S86YD;R!);G1E<FYE="!%>'!L;W)E<BP@<&]T<F5S=&D@9&]V97(@(@HB
M<V5L97II;VYA<F4@<75E<W1A(&-A<V5L;&$@<&5R(&%N;G5L;&%R92!L82!T
M<F%S<&%R96YZ82!D96QL92!I;6UA9VEN:2!03D<N(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W,@IM<V=I9"`B(@HB268@>6]U
M('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U
M('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE9"!B>2!Y;W5R
M(&)R;W=S97(N(@IM<V=S='(@(B(*(E-E('9E9&D@<75E<W1O(&UE<W-A9V=I
M;R!M82!N;VX@;"=I;6UA9VEN92P@;"=I;6%G:6YE(&-H92!V=6]I(&-A<FEC
M87)E(&YO;B`B"B)P=?(@97-S97)E('9I<W5A;&EZ>F%T82!D86P@='5O(&)R
M;W=S97(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3(U"FUS9VED("));6%G92!0<F5V:65W.B(*;7-G
M<W1R(")0<F4M5FES=6%L:7IZ87II;VYE(&1E;&PG26UM86=I;F4Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@(E523"!);6UA9VEN92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q.`IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R(")54DP@26UM86=I
M;F4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB"FUS
M9W-T<B`B26UM86=I;F4@9&%L;&$@9V%L;&5R:6$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S$*;7-G
M:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B26UM86=I;F4@9&%L
M;&$@9V%L;&5R:6$Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W-C$*;7-G
M:60@(DEM86=E('5P;&]A9"(*;7-G<W1R(")#87)I8V%M96YT;R!);6UA9VEN
M92(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B
M"FUS9W-T<B`B26UM86=I;FDB"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHW('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-30*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T96UA<"YI;F,Z-R!T96UP;&%T97,O9&%T82]T<W9I;F9O
M+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*
M;7-G<W1R("));7!O<G1A+"!087-S;R`E9"(*"B,Z('1E;7!L871E<R]D871A
M+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D
M(&9I96QD.B`E<R(*;7-G<W1R(")#86UP:2!I;7!O<G1A=&DZ("5S(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T960@
M9FEE;&1S.B(*;7-G<W1R(")#86UP:2!I;7!O<G1A=&DZ(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS
M9VED("));E]S97)T(%)O=R!!9G1E<B(*;7-G<W1R("));E]S97)I<V-I(')I
M9V$@9&]P;R(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C$S-`IM
M<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R(")#
M;V1I8V4@9&D@87II;VYE(&5R<F%T;R!D871O+B(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*;7-G:60@(DEN8V]R<F5C="!U<V5R
M;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(DYO;64@=71E;G1E(&4O
M;R!P87-S=V]R9"!N;VX@8V]R<F5T=&\N(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O
M<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U
M<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB
M"FUS9W-T<B`B(@HB3F]M92!U=&5N=&4@;R!I;F1I<FEZ>F\@86QT97)N871I
M=F\@;F]N('9A;&ED;RX@4FEP<F]V82!A;F-O<F$@;R!C;VYT871T82`B"B)L
M)V%M;6EN:7-T<F%T;W)E('-E(&YE8V5S<VET:2!D:2!U;'1E<FEO<F4@86EU
M=&\N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@(D%U;65N=&$@
M;&$@<FEE;G1R86YZ82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$Q-@IM<V=I9"`B26YD:6$B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`B
M571E;G1I($EN9&EV:61U86QI(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3$R"FUS9VED("));F1O;F5S:6$B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*
M;7-G:60@(DEN9F\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(U.0IM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M
M87II;VYE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q.0IM
M<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB"FUS9W-T
M<B`B26YF;W)M87II;VYE(&YO;B!P:?D@9&ES<&]N:6)I;&4N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,U
M"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R("));G-E<FES
M8VD@0U]O;&]N;F$@1&]P;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-PIM<V=I9"`B26YS97)T($EM
M86=E(@IM<V=S='(@(DEN<V5R:7-C:2!);6UA9VEN92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R
M="!486)L92(*;7-G<W1R("));G-E<FES8VD@5&%B96QL82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@(DEN
M<V5R="!796(@3&EN:R(*;7-G<W1R("));G-E<FES8VD@;&EN:R!W96(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,S0*;7-G:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R("))
M;G-E<FES8VD@7T-O;&]N;F$@4')I;6$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(DEN<V5R
M="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@
M(DEN<V5R:7-C:2!U;F$@;G5O=F$@8V]L;VYN82!D;W!O('%U96QL82!C;W)R
M96YT92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O
M<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DEN<V5R:7-C:2!U;F$@;G5O
M=F$@8V]L;VYN82!P<FEM82!D:2!Q=65L;&$@8V]R<F5N=&4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*
M;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE
M(@IM<V=S='(@(DEN<V5R:7-C:2!U;F$@;G5O=F$@<FEG82!D;W!O('%U96QL
M82!C;W)R96YT92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!B
M969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DEN<V5R:7-C:2!U;F$@
M;G5O=F$@<FEG82!P<FEM82!D:2!Q=65L;&$@8V]R<F5N=&4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-S`*
M;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N
M;V1E(@IM<V=S='(@(DEN<V5R:7-C:2!U;B!P87)A9W)A9F\@9&]P;R!I;"!N
M;V1O(&-O<G)E;G1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A9W)A
M<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B26YS97)I<V-I
M('5N('!A<F%G<F%F;R!P<FEM82!D96P@;F]D;R!C;W)R96YT92(*"B,Z(&%D
M;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS9VED("));G-E<G0@86QT97)N871E
M('1E;7!L871E(@IM<V=S='(@(DEN<V5R:7-C:2!U;F$@;6%S8VAE<F$@86QT
M97)N871I=F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0R"FUS9VED
M("));G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E
M8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B(@HB26YS97)I<V-I
M('5N(&EN9&ER:7IZ;R!E;6%I;"!A;"!Q=6%L92!P;W1R86D@<FEC979E<F4@
M;&$@;G5O=F$@<&%S<W=O<F0Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`IM<V=I9"`B26YS97)T(&-E;&P@
M869T97(B"FUS9W-T<B`B26YS97)I<V-I('5N82!C96QL82!D;W!O(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M.0IM<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(DEN<V5R:7-C
M:2!U;F$@8V5L;&$@<')I;6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L=6UN
M(&%F=&5R(@IM<V=S='(@(DEN<V5R:7-C:2!U;F$@8V]L;VYN82!D;W!O(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`B26YS
M97)I<V-I('5N82!C;VQO;FYA('!R:6UA(@H*(SH@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.CDP(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T
M+G!H<#HU,`IM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S='(@(DEN<V5R
M:7)E(&UE<W-A9V=I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("));G-E<G0@<&%R86=R87!H
M(&%F=&5R(@IM<V=S='(@(DEN<V5R:7-C:2!U;B!P87)A9W)A9F\@9&]P;R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!B969O<F4B"FUS9W-T
M<B`B26YS97)I<V-I('5N('!A<F%G<F%F;R!P<FEM82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*;7-G:60@
M(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`B26YS97)I<V-I('5N82!R:6=A
M(&1O<&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E9F]R92(*;7-G<W1R
M("));G-E<FES8VD@=6YA(')I9V$@<')I;6$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C,S"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E
M<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(DEN<V5R:7-C
M:2!L82!R:7-P;W-T82!R:6-H:65S=&$@86QL82!D;VUA;F1A(&1I('-I8W5R
M97IZ83HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(V"FUS9VED("));G-E<G0O36]D:69Y($EM86=E(@IM<V=S='(@(DEN
M<V5R:7-C:2]-3V1I9FEC82!L)VEM;6%G:6YE(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO
M9&EF>2!,:6YK(@IM<V=S='(@(DEN<V5R:7-C:2]-3V1I9FEC82!I;"!L:6YK
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I
M9"`B26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB
M=71I;VX@;&ES="XB"FUS9W-T<B`B0W)E9&ET:2!I;G-U9F9I8VEE;G1I('!E
M<B!S<&5D:7)E(&%L;&$@;&ES=&$@9&D@9&ES=')I8G5Z:6]N92XB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("));G-U
M9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R(")#<F5D:71I(&EN<W5F9FEC:65N
M=&DN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-S4*;7-G:60@(DEN=&5G
M97(B"FUS9W-T<B`B26YT97)O(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q
M,S,*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R("),:7-T82!I;G1E<F$B
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I
M9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B
M541((&YO;B!V86QI9&$@*%5S97(@1&%T82!(96%D97(I+B(*"B,Z(&QI8B](
M;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C$V-R!L:6(O2&]R9&4O0V]M<')E<W,O
M>FEP+G!H<#HQ.30*(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,C$R
M"FUS9VED("));G9A;&ED(%I)4"!D871A(@IM<V=S='(@(D1A=&$@6DE0(&YO
M;B!V86QI9&$B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T"FUS9VED
M("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R(")!<'!L:6-A>FEO;F4@
M;F]N('9A;&ED82XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q,@IM<V=I9"`B26YV86QI9"!B871C:"!)1"XB"FUS9W-T<B`B0F%T
M8V@@240@;F]N('9A;&ED;R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,#@W
M(&QI8B](;W)D92]&;W)M+G!H<#HR,34X(&QI8B](;W)D92]&;W)M+G!H<#HR
M,C,R"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,CDY(&QI8B](;W)D92]&;W)M
M+U1Y<&4O=&%B;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B
M;6ET=&5D+B(*;7-G<W1R(")I3"=I;F9O<FUA>FEO;F4@<V]T=&]M97-S82!N
M;VX@Z"!V86QI9&$N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB
M"FUS9W-T<B`B3"=I;F1I<FEZ>F\@9&D@9&1E<W1I;F%Z:6]N92!N;VX@Z"!V
M86QI9&\N(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP:'`Z,3`Y(&QI
M8B](;W)D92]#;VUP<F5S<R]D8G@N<&AP.C$S.0HC.B!L:6(O2&]R9&4O0V]M
M<')E<W,O9&)X+G!H<#HR-#$*;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B
M"FUS9W-T<B`B26P@9F]R;6%T;R!D96P@9FEL92!N;VX@Z"!V86QI9&\B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38U"FUS9VED("));G9A
M;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R("),82!C:&EA=F4@9&5L;&$@;&EC
M96YZ82!N;VX@Z"!V86QI9&$N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$U.0IM<V=I9"`B26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB
M"FUS9W-T<B`B26P@;&]G;R!F;W)N:71O(&YO;B#H('9A;&ED;RXB"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-PIM<V=I9"`B26YV
M86QI9"!M<V=?='EP92XB"FUS9W-T<B`B;7-G7W1Y<&4@;F]N('9A;&ED;RXB
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I
M9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`B87!I7VED
M(&YO;B!V86QI9&\@;R!M86YC86YT92XB"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y-@IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG
M('!A<F%M971E<G,N(@IM<V=S='(@(E!A<F%M971R;R!N;VX@=F%L:61O(&\@
M;6%N8V%N=&4N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C(W"FUS
M9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")097)M
M97-S;R!D96P@9V5N:71O<F4@;F]N('9A;&ED;RXB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,38Q"FUS9VED("));G9A;&ED('!A<G1N97(@
M:60N(@IM<V=S='(@(FED(&1E;"!P87)T;F5R(&YO;B!V86QI9&\N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,PIM<V=I9"`B26YV86QI
M9"!P<F]D=6-T(&-O9&4N(@IM<V=S='(@(D-O9&EC92!P<F]D;W1T;R!N;VX@
M=F%L:61O+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`V"FUS9VED("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R(")0<F]T;V-O
M;&QO(&YO;B!V86QI9&\N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.CDS(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HW,0HC.B!L:6(O
M3F5T+U--4R]W:6Y?:'1T<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R(")$97-T:6YA=&%R
M:6\@;F]N('9A;&ED;SH@7"(E<UPB(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HQ,#@P(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(V,PIM<V=I9"`B26YV86QI
M9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B3V=G971T;R!C;VYD:79I<V\@;F]N
M('9A;&ED;R(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`Q"FUS9VED("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R("))
M;F1I<FEZ>F\@<V]R9V5N=&4@;F]N('9A;&ED;RXB"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0IM<V=I9"`B26YV86QI9"!U;FEC
M;V1E(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS-3D*;7-G:60@(DEN=F5N=&]R>2(*;7-G<W1R("));G9E;G1A<FEO
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.`IM
M<V=I9"`B26YV97)T('-E;&5C=&EO;B(*;7-G<W1R("));G9E<G1I(&QA('-E
M;&5Z:6]N92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Q.0IM<V=I9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,3@*;7-G:60@(DER87$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$Q,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$S"FUS9VED("))
M<F5L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,34*;7-G:60@(DES;&4@;V8@36%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(T"FUS9VED("))<V]L871E
M9"!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,30*;7-G:60@(DES<F%E;"(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8R-@IM<V=I9"`B
M27-S=65R(@IM<V=S='(@(D5M:71T96YT92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$R,0IM<V=I9"`B271A;'DB"FUS9W-T<B`B271A;&EA(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$Q-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(S"FUS9VED
M(")*86UA:6-A(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#(@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C8U"FUS9VED(")*86YU87)Y(@IM<V=S='(@(D=E;FYA:6\B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C4*
M;7-G:60@(DIA<&%N(@IM<V=S='(@(D=I87!P;VYE(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.3`*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R,@IM<V=I
M9"`B2F5R<V5Y(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$R-`IM<V=I9"`B2F]R9&%N(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#@@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*
M=6QY(@IM<V=S='(@(DQU9VQI;R(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#<@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S='(@(D=I=6=N;R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*
M;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`B1VEU<W1I9FEC82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$U"FUS
M9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R(")':75S=&EF:6-A(&%L(&-E
M;G1R;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B1VEU
M<W1I9FEC82!T=71T;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y($QE9G0B"FUS
M9W-T<B`B1VEU<W1I9FEC82!A('-I;FES=')A(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Y"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,38*;7-G:60@(DIU
M<W1I9GD@4FEG:'0B"FUS9W-T<B`B1VEU<W1I9FEC82!A(&1E<W1R82(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@V(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,3D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-@IM
M<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C8U"FUS9VED(")+965P(&]R:6=I;F%L
M/R(*;7-G<W1R(")-86YT96YE<F4@;"=O<FEG:6YA;&4_(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$R,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(V"FUS9VED(")+
M96YY82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX
M-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R("));"!S97)V97(@2V5R8F5R;W,@:&$@<FEF:75T871O
M(&PG875T96YT:6-A>FEO;F4N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0R"FUS9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO;B(*
M;7-G<W1R(")#<F5A>FEO;F4@8VAI879E(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B
M26UP<F]N=&$@9&EG:71A;&4@9&5L;&$@8VAI879E(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N9W1H(@IM<V=S='(@
M(DQU;F=H97IZ82!D96QL82!C:&EA=F4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HT,3$*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(E1I<&\@9&5L
M;&$@8VAI879E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3D*
M;7-G:60@(DME>2!5<V%G92(*;7-G<W1R(")5<V\@9&5L;&$@8VAI879E(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-S0P"FUS9VED(")+97D@86QR
M96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@
M(DQA(&-H:6%V92#H(&=IX"!P<F5S96YT92!S=6P@:V5Y<V5R=F5R('!U8F)L
M:6-O+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I9"`B2VED
M<R(*;7-G<W1R(")"86UI8FEN:2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$R.0IM<V=I9"`B2VER:6)A=&DB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#4@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3,R"FUS9VED(")+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U
M8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,S,*;7-G:60@(DMO<F5A+"!297!U8FQI8R!O
M9B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM<V=I
M9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,C0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-`IM<V=I9"`B2W5W86ET
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$R-PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*;7-G:60@(DQA7WEO=70B
M"FUS9W-T<B`B1&E?<W!O<VEZ:6]N92(*"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(DQI;F=U86=G
M:6\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,S<*;7-G:60@(DQA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-CD*;7-G:60@
M(DQA<W0@2&%L9B(*;7-G<W1R(")5;'1I;6\@;65Z>F\B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z.#@*;7-G:60@(DQA<W0@4&%S<W=O<F0@0VAA;F=E
M(@IM<V=S='(@(E5L=&EM82!P;W-S:6)I;&ETX"!P97(@:6P@8V%M8FEO(&1E
M;&QA('!A<W-W;W)D(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@V(&QI8B]"
M;&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@
M(E5L=&EM;R!Q=6%R=&\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U.`IM
M<V=I9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R(")5;'1I;6\@86=G:6]R;F%M
M96YT;SHB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z-S$W"B,L('!H<"UF;W)M
M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(E5L=&EM82!C;VYN
M97-S:6]N93H@)7,B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z-S$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T
M<B`B56QT:6UA(&-O;FYN97-S:6]N93H@)7,@9&$@)7,B"@HC.B!L:6(O2&]R
M9&4O075T:"YP:'`Z-S$T"FUS9VED("),87-T(&QO9VEN.B!.979E<B(*;7-G
M<W1R(")5;'1I;6$@8V]N;F5S<VEO;F4Z($UA:2(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,C<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-@IM<V=I9"`B3&%T=FEA
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I
M9"`B3&%W(@IM<V=S='(@(DQE9V=E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"FUS9VED("),87EO=70B"FUS
M9W-T<B`B1&ES<&]S:7II;VYE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO
M(&)O<F1E<B(*;7-G<W1R("),87-C:6%L;R!V=6]T;R!P97(@879E<FQO('-E
M;GIA(&)O<F1I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3,X"FUS9VED("),96)A;F]N(@IM<V=S='(@(DQI8F%N;R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT,`IM<V=I9"`B3&5F="(*;7-G<W1R(")3:6YI<W1R82(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HS,3`Q"FUS9VED("),969T(&AE861E<B(*;7-G<W1R
M("));G1E<W1A>FEO;F4@9&D@<VEN:7-T<F$B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,S`Y-PIM<V=I9"`B3&5F="!V86QU97,B"FUS9W-T<B`B5F%L;W)I
M(&1I('-I;FES=')A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,30S"FUS9VED("),97-O=&AO(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B3&5V96PB
M"FUS9W-T<B`B3&EV96QL;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$T,@IM<V=I9"`B3&EB97)I82(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-#<*;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$S,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30P
M"FUS9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),:6=H="!$
M<FEZ>FQE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(V"FUS9VED("),:6=H="!286EN(@IM<V=S='(@(E!I
M;V=G:6$@;&5G9V5R82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!286EN($5A<FQY(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(X
M"FUS9VED("),:6=H="!286EN($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI9VAT
M(%)A:6X@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,P"FUS9VED("),:6=H="!286EN('=I=&@@
M5&AU;F1E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,@IM
M<V=I9"`B3&EG:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0U"FUS9VED("),:6UE<FEC:R(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@Q-`IM<V=I9"`B3&EN:R(*;7-G
M<W1R(")#;VQL96=A;65N=&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I;G1S
M('1O.B(*;7-G<W1R("));"!C;VQL96=A;65N=&\@<'5N=&$@83HB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3@W-0IM<V=I9"`B3&EN:R!T:&4@96UA:6P@
M861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(*
M;7-G<W1R("(B"B)#;VQL96=A(&PG:6YD:7)I>GIO(&5M86EL(&%L;&$@<&%G
M:6YA(&1I(&-O;7!O<VEZ:6]N92!Q=6%N9&\@=FEE;F4@(@HB=FES=6%L:7IZ
M871O(@H*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VAT;6PR=&5X="YP:'`Z
M,3@R"FUS9VED("),:6YK<R(*;7-G<W1R(")#;VQL96=A;65N=&DB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI92(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.#8@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C0V"FUS9VED("),
M:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B16QE;F-O
M("T@;"=U=&5N=&4@<'7R('9E9&5R92!L92!C87)T96QL92(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,S0*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S
M='(@(D5L96YC;R!D96D@9&%T86)A<V4B"@HC.B!S97)V:6-E<R]H96QP+VEN
M9&5X+G!H<#HU,0IM<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R(")%
M;&5N8V\@9&5I('-O9V=E='1I(&1E;&PG86EU=&\B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3,S"FUS9VED("),:7-T(%1A8FQE<R(*;7-G<W1R(")%;&5N
M8V\@5&%B96QL92(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C8P
M,0IM<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S='(@(D%R8VAI=FEO(&1E;&QA
M($QI<W1A(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DV"FUS
M9VED("),:7-T+4AE;'`B"FUS9W-T<B`B06EU=&\@9&5L;&$@3&ES=&$B"@HC
M.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HV,#,*;7-G:60@(DQI<W0M
M260B"FUS9W-T<B`B261E;G1I9FEC871I=F\@9&5L;&$@3&ES=&$B"@HC.B!L
M:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.3D*;7-G:60@(DQI<W0M3W=N
M97(B"FUS9W-T<B`B4')O<')I971A<FEO(&1E;&QA(&QI<W1A(@H*(SH@;&EB
M+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-C`P"FUS9VED("),:7-T+5!O<W0B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DX
M"FUS9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("))<V-R:7II;VYE(&%L
M;&$@3&ES=&$B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.3<*
M;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`B06YN=6QL82!L)VES
M8W)I>FEO;F4@86QL82!,:7-T82(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU
M,@HC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('-E<W-I;VYS(&9A:6QE
M9#H@)7,B"FUS9W-T<B`B3"=E;&5N8V\@9&5L;&4@<V5S<VEO;F4@Z"!F86QL
M:71O.B`E<R(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-PHC+"!P:'`M9F]R
M;6%T"FUS9VED("),:7-T:6YG('5S97)S(&9A:6QE9#H@)7,B"FUS9W-T<B`B
M3"=E;&5N8V\@9&5G;&D@=71E;G1I(.@@9F%L;&ET;SH@)7,B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@
M=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(DPG96QE;F-O(&1E9VQI('5T
M96YT:2#H(&1I<V%B:6QI=&%T;RXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#<*;7-G:60@(DQI=&5R871U<F4B"FUS9W-T<B`B3&5T=&5R871U<F$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-#0*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O:6UA9V5S+G!H<#HW-PIM<V=I9"`B3&]A9&EN9RXN+B(*
M;7-G<W1R(")#87)I8V%M96YT;RXN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,#`*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R(")/
M<F$@;&]C86QE.B`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#8*;7-G
M:60@(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R("),:6YG=6$@92!/<F$B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C<R(&QI8B]";&]C:R]S=6YR:7-E+G!H
M<#HR,@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-3<@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S(*;7-G:60@(DQO8V%T:6]N(@IM<V=S
M='(@(DQU;V=O(@H*(SH@;&]G:6XN<&AP.C$X.2!S97)V:6-E<R]P;W)T86PO
M<VED96)A<BYP:'`Z,C`T('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*
M(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,R!T96UP;&%T97,O;&]G
M:6XO;6]B:6QE+FEN8SHQ-0IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(D5N=')A
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U"FUS9VED("),
M;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.3@*;7-G:60@(DQO9R!O=70B
M"FUS9W-T<B`B17-C:2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV,0IM
M<V=I9"`B3&]G:6XB"FUS9W-T<B`B16YT<F$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3$P"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R(")/<&5R
M87II;VYI(&1I($%C8V5S<V\B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3DU
M"FUS9VED("),;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R
M('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R("(B
M"B),)V%C8V5S<V\@Z"!F86QL:71O('!E<F-HZ"!I;"!N;VUE('5T96YT92!O
M(&QA('!A<W-W;W)D(&EN<V5R:71I(&YO;B!S;VYO("(*(F-O<G)E='1I+B(*
M"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY.3$*;7-G:60@(DQO9VEN(&9A:6QE
M9"XB"FUS9W-T<B`B06-C97-S;R!F86QL:71O+B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,S8U"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`B5&5S=&\@
M;'5N9V\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@(DQO
M=F4B"FUS9W-T<B`B06UO<F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV.0IM<V=I9"`B3&]W(@IM<V=S='(@(D)A<W-O(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N
M9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R("),
M971T97)E(&=R96-H92!M:6YU<V-O;&4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E
M<B!L871I;B!L971T97)S(@IM<V=S='(@(DQE='1E<F4@;&%T:6YE(&UI;G5S
M8V]L92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS
M9W-T<B`B3G5M97)I(')O;6%N:2!M:6YU<V-O;&DB"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#4*;7-G:60@(DQU>&5M
M8F]U<F<B"FUS9W-T<B`B3'5S<V5M8G5R9V\B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Q(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,SD*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G
M:60@(DU-(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR.#,*;7-G:60@(DU/5$0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W1N968N<&AP.C,V"FUS9VED(")-4RU43D5&($%T=&%C:&UE
M;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(DU3+51.148@;"=A;&QE
M9V%T;R!N;VX@8V]N=&EE;F4@:6YF;W)M87II;VYI+B(*"B,Z(&QI8B](;W)D
M92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B
M35-'(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$U-PIM<V=I9"`B36%C86\B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3$@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$S-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34S"FUS
M9VED(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@
M;V8B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,34Q"FUS9VED(")-861A9V%S8V%R(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.0IM<V=I9"`B36%G:6,B"FUS
M9W-T<B`B36%G:6-O(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@S
M"FUS9VED(")-86EL(@IM<V=S='(@(E!O<W1A(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C4R-`IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R("))
M;F1I<FEZ>F\@86UM:6YI<W1R871O<F4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@
M;&EN7VLN+BXB"FUS9W-T<B`B0W)E82!C;VQL96=A;65N7W1O+BXN(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$S.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38U"FUS
M9VED(")-86QA=VDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38W"FUS9VED(")-86QA>7-I82(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-C0*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDR(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-#$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-`IM<V=I9"`B
M36%L:2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-C(*;7-G:60@(DUA;'1A(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-`IM<V=I9"`B(@HB36%N86=E('1H
M92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@
M=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T
M96=O<FEE<RXB"FUS9W-T<B`B(@HB1V5S=&ES8VD@;"=E;&5N8V\@9&5L;&4@
M8V%T96=O<FEE(&5T:6-H971T86YD;R!G;&D@87)T:6-O;&DL(&4@8V]N(&D@
M8V]L;W)I("(*(F%S<V]C:6%T:2!A;&QE(&-A=&5G;W)I92XB"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U-@IM<V=I9"`B36%P
M,C0@;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,#@W"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,3<Q"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-87!P
M:6YG<R!S=&]R960N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#0@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8W"FUS9VED(")-87)C:"(*;7-G<W1R(")-87)Z;R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#$*;7-G:60@(DUA<F=I;B(*;7-G<W1R(")-87)G:6YE(@H*(SH@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X(&QI8B](;W)D92])34%0+T%#
M3"]R9F,T,S$T+G!H<#HT.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N
M(&9L86=S(@IM<V=S='(@(D-O;G1R87-S96=N87)E(&-O;B!I(&9L86=S(%9I
M<W1O+TYO;E9I<W1O(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C@Y(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HT.0IM<V=I
M9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W
M97)E9"DB"FUS9W-T<B`B0V]N=')A<W-E9VYA<F4@8V]N(&%L=')I(&9L86=S
M("AE<SH@26UP;W)T86YT92]2:7-P;W-T;RDB"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3(*;7-G:60@(DUA<G-H86QL
M($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,34Y"FUS9VED(")-87)T:6YI<75E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED
M(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`B0V%M<&D@8V]R<FES<&]N9&5N
M=&DB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-C`*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$T-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38S"FUS9VED(")-
M875R:71I=7,B"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB"FUS
M9W-T<B`B0W)E9&ET;R!M87-S:6UO('!E<FUE<W-O+B(*"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-87@@;65S<V%G
M92!P87)T<R!E>&-E961E9"XB"FUS9W-T<B`B16-C961U=&4@;&$@<&%R=&D@
M;6%S<VEM92!D96P@;65S<V%G9VEO+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S$S"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T
M<B`B5&5M<&\@;6%S<VEM;R!U;'1I;64@,C0@;W)E.B`B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,P-0IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S
M.B`B"FUS9W-T<B`B5&5M<&\@;6%S<VEM;R!U;'1I;64@-B!O<F4Z("(*"B,Z
M(&QI8B]A<&DN<&AP.C@V"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!0;W)T
M86P@0FQO8VMS(@IM<V=S='(@(DYU;65R;R!M87-S:6UO(&1E;"!0;W)T82!"
M;&]C:W,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DX(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,C$W(&QI8B](;W)D92]&;W)M+G!H<#HQ,C,Y"FUS9VED(")-
M87AI;75M(&QE;F=T:"(*;7-G<W1R("),=6YG:&5Z>F$@;6%S<VEM82(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#8@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS
M9W-T<B`B36%G9VEO(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(U,PIM<V=I9"`B36%Y;W1T92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*;7-G:60@(DUE9&EC:6YE(@IM
M<V=S='(@(DUE9&EC:6YA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E
M9&ET+FEN8SHQ-@IM<V=I9"`B365M8F5R<R(*;7-G<W1R(")-96UB<FDB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@R"FUS9VED(")-96YU(&UO9&4Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@
M(E5N:7-C:2!L92!C96QL92(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO
M3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR-34*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`B365S<V%G9VEO
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*
M(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R
M)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G
M<W1R("(B"B));"!M97-S86=I;R#H('-T871O('9E<FEF:6-A=&\@8V]R<F5T
M=&%M96YT92P@;6$@:6P@9FER;6%T87)I;R!D96P@(@HB8V5R=&EF:6-A=&\@
M;F]N('!U\B!E<W-E<F4@=F5R:69I8V%T;RXB"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B365S<V%G92!E>'!I<F5D
M+B(*;7-G<W1R(")-97-S86=G:6\@<V-A9'5T;RXB"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-R!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(V,`HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-38Y(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*
M;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R(")4:7!O(&UE<W-A9V=I;R(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B365T87(@5V5A=&AE
M<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W"FUS9VED
M(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$Q.0IM<V=I9"`B(@HB365T87(@8FQO8VL@
M;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T
M:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$U,PIM<V=I9"`B365T87)$0B!I<R!N;W0@8V]N
M;F5C=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M<F%R+G!H<#HV-R!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW-`IM
M<V=I9"`B365T:&]D(@IM<V=S='(@(DUE=&]D;R(*"B,Z(&QI8B](;W)D92]2
M4$,O<V]A<"YP:'`Z,3$W(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HX,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D969I
M;F5D(@IM<V=S='(@(DEL(&UE=&]D;R`@7"(E<UPB(&YO;B#H(&1E9FEN:71O
M(@H*(SH@;&EB+TAO<F1E+U)00R]R97-T+G!H<#HX,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S
M(@IM<V=S='(@(DUE=&]D;R!N;VX@9&5F:6YI=&\N($UE=&]D;R!C:&EA;6%T
M83H@)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@R(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HV-PIM<V=I9"`B365T<FEC(@IM<V=S='(@(DUE
M=')I8V$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-C8*;7-G:60@(DUE>&EC;R(*;7-G<W1R(")-97-S:6-O(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$T.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#4*;7-G
M:60@(DUI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0R"FUS9VED(")-:61D;&4B"FUS9W-T<B`B365Z>F\B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q-PIM<V=I
M9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(E1E;7!O(&UI
M;FEM;R!U;'1I;64@,C0@;W)E.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,P.0IM<V=I9"`B36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B
M5&5M<&\@;6EN:6UO('5L=&EM92`V(&]R93H@(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O;&1A<"YP:'`Z-#,Y"FUS9VED(")-:6YI;75M('!A<W-W;W)D(&%G92!H
M87,@;F]T('EE="!E>'!I<F5D(@IM<V=S='(@(DEL('1E;7!O(&1I(&1U<F%T
M82!M:6YI;6\@9&5L;&$@<&%S=V]R9"!N;VX@Z"!S8V%D=71O(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-0IM<V=I9"`B36ER
M<F]R(@IM<V=S='(@(E-P96-C:&EO(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(E9A<FEO(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#`@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W,@HC.B!L:6(O3F5T+U--4R]W
M:6Y?:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(
M5%107U)E<75E<W0N(@IM<V=S='(@(DEL('!A8V-H971T;R!014%2($A45%!?
M4F5Q=65S="#H(&UA;F-A;G1E+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ,30*;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA
M=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES
M("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"B)#;VYF:6=U<F%Z:6]N92!M
M86YC86YT92X@1&5V:2!G96YE<F%R;F4@=6YA(&YU;W9A('-E('9U;VD@=7-A
M<F4@<75E<W1A("(*(F%P<&QI8V%Z:6]N92XB"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E
M($E$+B(*;7-G<W1R("))1"!D96P@;65S<V%G9VEO(&UA;F-A;G1E+B(*"B,Z
M(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@
M(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S='(@
M(DEL('!A8V-H971T;R!014%2($UA:6P@<FEC:&EE<W1O(.@@;6%N8V%N=&4N
M(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G
M:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`B240@9&5L;&$@<V5S
M<VEO;F4@;6%N8V%N=&4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`B3'4B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S8*;7-G:60@(DUO8FEL92!-86EL
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C<P"FUS9VED(")-;V1E<F%T92(*;7-G<W1R(")-;V1E<F%T;R(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8V(&QI8B](;W)D
M92]-24U%+U9I97=E<B]T9WHN<&AP.C@U"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<S"FUS9VED(")-;V1I9FEE9"!$871E(@IM<V=S='(@
M(D1A=&$@9&5L;&$@;6]D:69I8V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!5
M4DPB"FUS9W-T<B`B36]D:69I8V$@55),(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HV-S0*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B36]D=6QO
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$U,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,34P"FUS9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#D*
M;7-G:60@(DUO;F%C;R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-38*;7-G:60@(DUO;F=O;&EA(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3@T"FUS9VED(")-
M;VYT:"!A;F0@>65A<B(*;7-G<W1R(")-97-E(&4@86YN;R(*"B,Z(&QI8B](
M;W)D92]-86EN=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T
M<B`B365N<VEL;65N=&4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-C$*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP
M.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G<W1R(")&87-I(&QU;F%R:2(*
M"B,Z(&QI8B]&:6QE+T-35BYP:'`Z,3DV(&QI8B]&:6QE+T-35BYP:'`Z,C@P
M"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI
M;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N(@IM<V=S='(@(B(*(E-O;F\@
M<W1A=&D@=')O=F%T:2!P:?D@8V%M<&D@;F5L;&$@;&EN96$@)60@<FES<&5T
M=&\@82!Q=65L;&D@:7!R979I<W1I("5D+B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDP(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-30*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T.`IM<V=I9"`B36]R;V-C;R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS,PIM<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED(")-
M;W-T;'D@0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,U"FUS9VED(")-;W-T;'D@0VQO=61Y(&%N
M9"!7:6YD>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C0X
M"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B4W!O<W1A(%-O='1O(@H*(SH@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-3(*;7-G:60@
M(DUO=F4@3&5F="(*;7-G<W1R(")3<&]S=&$@82!3:6YI<W1R82(*"B,Z(&QI
M8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C4V"FUS9VED(")-
M;W9E(%)I9VAT(@IM<V=S='(@(E-P;W-T82!A($1E<W1R82(*"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C0T"FUS9VED(")-;W9E
M(%5P(@IM<V=S='(@(E-P;W-T82!3;W!R82(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HU,C8*;7-G:60@(DUO=F4@9&]W;B(*;7-G
M<W1R(")3<&]S=&$@<V]T=&\B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-3(U(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HU,C8*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`B4W!O<W1A('-O<')A
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$U-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,38X"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,3@T"FUS9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@
M;&ES=',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$P-3D*;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(T,@IM<V=I9"`B375L=&EP
M;&4@<V5L96-T:6]N(@IM<V=S='(@(E-E;&5Z:6]N92!M=6QT:7!L82(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#(*;7-G:60@(DUY($%C8V]U
M;G0B"FUS9W-T<B`B36EO($%C8V]U;G0B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z,C@*;7-G:60@(DUY($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T
M<B`B26YF;W)M87II;VYI(&1E;"!-:6\@06-C;W5N="(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]I;F1E>"YP:'`Z-#0*;7-G:60@(DUY(%!O<G1A;"(*;7-G<W1R
M(")-:6\@4&]R=&%L92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HT
M,@IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R(")$:7-P;W-I>FEO
M;F4@9&5L($UI;R!0;W)T86QE(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,34U"FUS9VED(")->6%N;6%R(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL
M.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B3D\L(&YO
M;B!S;VYO(&0G86-C;W)D;R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T
M;F5F+G!H<#HS."!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$P
M,@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DYA;64B
M"FUS9W-T<B`B3F]M92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$V.0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S@*
M;7-G:60@(DYA=7)U(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDW(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-PIM<V=I9"`B3F5P86PB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3<U"FUS9VED(").971H97)L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,PIM<V=I9"`B
M3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G:60@(DYE='-C87!E($)A<V4@55),
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@T
M"FUS9VED(").971S8V%P92!#02!2979O8V%T:6]N(%523"(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T
M<V-A<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!5
M4DPB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M.#,*;7-G:60@(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@W"FUS9VED(").971S
M8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU.#@*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC
M871E(&-O;6UE;G0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E('1Y<&4B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U,PIM
M<V=I9"`B3F5T=V]R:R(*;7-G<W1R(")2971E(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z-#(U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,`IM<V=I9"`B3F5V97(B"FUS9W-T
M<B`B36%I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3<P"FUS9VED(").97<@0V%L961O;FEA(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED
M(").97<@0V%T96=O<GDB"FUS9W-T<B`B3G5O=F$@0V%T96=O<FEA(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED(").97<@36]O;B(*;7-G<W1R
M("),=6YA($YU;W9A(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB"FUS9W-T
M<B`B3G5O=F\@3F]M92!5=&5N=&4@*&]P>FEO;F%L92DB"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#`*;7-G:60@(DYE
M=R!:96%L86YD(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HS-PIM<V=I9"`B3F5W('!A<W-W;W)D(@IM<V=S='(@(DYU;W9A
M('!A<W-W;W)D(@H*(SH@;&EB+TAO<F1E+T%U=&@O<W%L+G!H<#HR,C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N
M("5X+B(*;7-G<W1R("),82!N=6]V82!P87-S=V]R9"!S8V%D<N`@:6X@)7@N
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R"FUS9VED(").
M97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*;7-G<W1R("),82!N=6]V82!P
M87-S=V]R9"!N;VX@8V]R<FES<&]N9&4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H
M7V)L86YK*2(*;7-G<W1R(").=6]V82!F:6YI<W1R82`H7W9U;W1A*2(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,B!L:6(O0FQO8VLO9V]O9VQE+G!H
M<#HT,`HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,CDQ"FUS9VED(").
M97=S(@IM<V=S='(@(DYO=&EZ:64B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S`W"FUS9VED(").97=S9W)O=7!S(@IM<V=S='(@(D=R=7!P:2!D
M:2!.;W1I>FEE(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,CD*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T96UA<"YI;F,Z-#$@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z
M,34*;7-G:60@(DYE>'0B"FUS9W-T<B`B4')O<W-I;6\B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,C<*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B
M4')O<W-I;64@-"!&87-I(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS
M-C8@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-S`*;7-G:60@(DYE>'0@;W!T
M:6]N<R(*;7-G<W1R(")0<F]S<VEM92!O<'II;VYI(@H*(SH@;&EB+TAO<F1E
M+U5)+U!A9V5R+G!H<#HQ,#,*;7-G:60@(DYE>'0^(@IM<V=S='(@(E!R;W-S
M:6UO/B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$W-`IM<V=I9"`B3FEC87)A9W5A(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDV(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-C4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,0IM<V=I9"`B
M3FEG97(B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3<S"FUS9VED(").:6=E<FEA(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-CD*;7-G:60@(DYI
M9VAT(@IM<V=S='(@(DYO='1E(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3<Y"FUS9VED(").:75E(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY-C8*;7-G
M:60@(DYO(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D
M:69F+FAT;6PZ.0IM<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@
M9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`B(@HB3F]N
M('-O;F\@9&ES<&]N:6)I;&D@:6YF;W)M87II;VYI(')I9W5A<F1O(&QA(&-O
M;F9I9W5R87II;VYE('!E<B!M;W-T<F%R92!L92`B"B)D:69F97)E;GIE+B(*
M"B,Z(&QI8B]61E,O25-/5W)I=&5R+G!H<#HQ,#8*;7-G:60@(DYO(&%V86EL
M86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@
M(DYO;B#H(&1I<W!O;FEB:6QE('5N82!S=')A=&5G:6$@<&5R(&-R96%R92!I
M;6UA9VEN:2!)4T\N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$P,0HC
M.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C,X-0HC.B!L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C0P-PIM<V=I9"`B
M3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB"FUS
M9W-T<B`B3F]N(&5S:7-T92!U;B!B;&]C8V\@86QL82!P;W-I>FEO;F4@<FEC
M:&EE<W1A(@H*(SH@;&EB+TAO<F1E+T%U=&@O;6-A;"YP:'`Z-3`*;7-G:60@
M(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(DYO;B#H('-T871O(&9O<FYI=&\@:6P@;F]M92!D
M96P@8V%L96YD87)I;R!P97(@;"=A=71E;G1I8V%Z:6]N92!-0T%,+B(*"B,Z
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4T"FUS9VED(").;R!C:&%N9V4N(@IM
M<V=S='(@(DYE<W-U;F$@;6]D:69I8V$N(@H*(SH@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HQ-38*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T
M;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(DYE<W-U;B!F:6=L:6\@<'7R
M(&5S<V5R92!A9V=I=6YT;R!A('%U97-T;R!P97)M97-S;RXB"@HC.B!L:6(O
M2&]R9&4N<&AP.C$W."!L:6(O2&]R9&4N<&AP.C4Q-R!L:6(O2&]R9&4O571I
M;"YP:'`Z-S@R"B,L('!H<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B(@HB
M3F]N(.@@<W1A=&$@<W!E8VEF:6-A=&$@86QC=6YA(&EN9F]R;6%Z:6]N92!S
M=6QL82!C;VYF:6=U<F%Z:6]N92!P97(@)7,N(@H*(SH@;&EB+U9&4R]F='`N
M<&AP.C@V.`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R($944"!61E,N(@IM<V=S='(@(B(*(DYO;B#H('-T871A
M('-P96-I9FEC871A(&%L8W5N82!I;F9O<FUA>FEO;F4@<W5L;&$@8V]N9FEG
M=7)A>FEO;F4@<&5R($944"!61E,N(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C8X
M-`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R(%-13"!61E,N(@IM<V=S='(@(B(*(DYO;B#H('-T871A('-P96-I
M9FEC871A(&%L8W5N82!I;F9O<FUA>FEO;F4@<W5L;&$@8V]N9FEG=7)A>FEO
M;F4@<&5R(%-13"!61E,N(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S4S
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R("(B"B).;VX@Z"!S=&%T82!S
M<&5C:69I8V%T82!A;&-U;F$@:6YF;W)M87II;VYE('-U;&QA(&-O;F9I9W5R
M87II;VYE('!E<B!344PM(@HB1FEL92!61E,N(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO(&-R961I="!L969T
M+B(*;7-G<W1R(").;VX@Z"!R:6UA<W1O(&YE<W-U;B!C<F5D:71O+B(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S0*;7-G:60@(DYO
M(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G<W1R(").;VX@Z"!S=&%T82!F
M;W)N:71A(&QA(&1E<W1I;F%Z:6]N92XB"@HC.B!L:6(O2&]R9&4O0G)O=W-E
M<BYP:'`Z.3$X"FUS9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(DEL
M(&9I;&4@;F]N(.@@<W1A=&\@8V%R:6-A=&\B"@HC.B!U=&EL+VEC;VY?8G)O
M=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R(").
M;VX@<V]N;R!S=&%T92!T<F]V871E(&QE(&EC;VYE+B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,3,P(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$V"FUS9VED(").;R!L;V-A
M=&EO;B!I<R!S970N(@IM<V=S='(@(DYO;B#H('-T871O(&EM<&]S=&%T;R!L
M82!P;W-I>FEO;F4N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$U-PIM<V=I9"`B3F\@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(DYO
M;B#H('-T871O(&EN9&EC871O(&QA('!O<VEZ:6]N92XB"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").;R!M97-S86=E
M('-U<'!L:65D+B(*;7-G<W1R(").;VX@Z"!S=&%T;R!F;W)N:71O(&EL(&UE
M<W-A9V=I;RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,V"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B3F]N(.@@
M<W1A=&\@<W!E8VEF:6-A=&\@:6P@;F]M92XB"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS9VED(").;R!N=6UB97(@<W!E8VEF
M:65D+B(*;7-G<W1R(").;VX@Z"!S=&%T;R!S<&5C:69I8V%T;R!I;"!N=6UE
M<F\N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS9VED(").;R!O
M9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O:'1T<"YP:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").;VX@Z"!S=&%T82!F
M;W)N:71A(&QA('!A<W-W;W)D('!E<B!L)V%U=&5N=&EC87II;VYE($A45%`N
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B3F]N(.@@<W1A=&$@9F]R;FET82!L82!P87-S=V]R9"!P97(@;"=A
M=71E;G1I8V%Z:6]N92!)34%0+B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N
M<&AP.C<R"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R
M;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYO;B#H('-T871A(&9O<FYI
M=&$@;&$@<&%S<W=O<F0@<&5R(&PG875T96YT:6-A>FEO;F4@2V5R8F5R;W,N
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&]G:6XN<&AP.C@T(&QI8B](;W)D92]!
M=71H+W!A;2YP:'`Z-S4*(SH@;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'`Z-S<*
M;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B3F]N(.@@<W1A=&$@9F]R;FET82!L82!P87-S
M=V]R9"!P97(@;"=A=71E;G1I8V%Z:6]N92!,;V=I;BXB"@HC.B!L:6(O2&]R
M9&4O075T:"]P87-S=V0N<&AP.C$S-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3F]N
M(.@@<W1A=&$@9F]R;FET82!L82!P87-S=V]R9"!P97(@;"=A=71E;G1I8V%Z
M:6]N92!005-35T0N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<VUB+G!H<#HX-`IM
M<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`B3F]N(.@@<W1A=&$@9F]R;FET82!L82!P87-S=V]R
M9"!P97(@;"=A=71E;G1I8V%Z:6]N92!334(N(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HQ,C@W"FUS9VED("(B"B).;R!P871H('1O('1H92!/
M<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES
M(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I=&@@4$M#4R`Q,B!D871A+B(*;7-G
M<W1R("(B"B).;VX@Z"!D:7-P;VYI8FEL92!A;&-U;F$@<&%T8V@@<&5R(&QA
M('9E<G-I;VYE(&)I;F%R:6$@9&D@3W!E;E-33"X@3&$@(@HB=F5R<VEO;F4@
M8FEN87)I82!D:2!/<&5N4U-,(.@@;F5C97-S87)I;R!C:&4@;W!E<FD@8V]N
M(&QE(&EN9F]R;6%Z:6]N:2!02T-3("(*(C$R+B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@<VEG
M;G5P<RXB"FUS9W-T<B`B(@H*(SH@;&EB+U9&4RYP:'`Z-S8V"FUS9VED(").
M;R!Q=6]T82!S970N(@IM<V=S='(@(DYO;B#H('-T871A(&EM<&]S=&%T82!L
M82!Q=6]T82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0S"FUS9VED(").;R!R=6QE<R(*;7-G<W1R(").97-S
M=6YA(')E9V]L82(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z-#@R"FUS9VED(").
M;R!S97!A<F%T;W(@<W!E8VEF:65D+B(*;7-G<W1R(").;VX@Z"!S=&%T;R!S
M<&5C:69I8V%T;R!I;"!S97!A<F%T;W)E+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#0*;7-G:60@(DYO('-I
M9&5S(@IM<V=S='(@(DYE<W-U;F$@;&%T;R(*"B,Z(&QI8B]61E,O<VUB+G!H
M<#HV,#`*;7-G:60@(DYO('-U8V@@9FEL92(*;7-G<W1R(").97-S=6X@=&EP
M;R!D:2!F:6QE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$R
M-@IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R
M(&-A8VAE+B(*;7-G<W1R(").;VX@Z"!D:7-P;VYI8FEL92!U;F$@9&ER96-T
M;W)Y('1E;7!O<F%N96$@<&5R(&QA(&-A8VAE+B(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$@;&EB+TYE="]335,O=VEN7VAT='`N
M<&AP.C(R,0IM<V=I9"`B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E
M;G0N(@IM<V=S='(@(DYO;B#H('-T871A(&EN=FEA=&\@:6P@;F]M92!U=&5N
M=&4@92]O('!A<W-W;W)D+B(*"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C+G!H
M<#HQ-#`*;7-G:60@(DYO('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S
M='(@(DYO;B!S;VYO(')I=&]R;F%T92!I;F9O<FUA>FEO;FD@6$U,('9A;&ED
M92(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY-S0@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX-`HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3DU"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#$R"FUS9VED(").;R!V86QU
M97,B"FUS9W-T<B`B3F5S<W5N('9A;&]R92(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ,3D*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN
M86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R("(B"B).;VX@Z"!S=&%T82!T<F]V871A(&QA('9E<G-I;VYE(&YE
M;&QA(&-O;F9I9W5R87II;VYE(&]R:6=I;F%L92X@4FEG96YE<F$@;&$@(@HB
M8V]N9FEG=7)A>FEO;F4N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R
M-PIM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I
M;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB3F]N
M(.@@<W1A=&$@=')O=F%T82!L82!V97)S:6]N92!N96QL82!T=6$@8V]N9FEG
M=7)A>FEO;F4N(%)I9V5N97)A(&QA("(*(F-O;F9I9W5R87II;VYE+B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R-R!T96UP;&%T97,O<')E9G,O
M:61E;G1I='ES96QE8W0N:6YC.CDS"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*;7-G:60@(DYO;F4B"FUS9W-T
M<B`B3F5S<W5N;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T
M<B`B3F5S<W5N;R`O=7-O(&EM<&QI8VET;RDB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y,@IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3<R"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS
M9VED(").;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(D5M:7-F97)O(%-E
M='1E;G1R:6]N86QE(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,34X"FUS9VED(").;W)T:&5R;B!-87)I86YA($ES;&%N
M9',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3<V"FUS9VED(").;W)W87DB"FUS9W-T<B`B3F]R=F5G
M:6$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T,0IM<V=I9"`B
M3F]T($%F=&5R(@IM<V=S='(@(DYO;B!$;W!O(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!"969O<F4B"FUS9W-T<B`B
M3F]N(%!R:6UA(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HT,C$*;7-G:60@(DYO
M="!A(&1I<F5C=&]R>2(*;7-G<W1R(").;VX@=6YA(&1I<F5C=&]R>2(*"B,Z
M(&QI8B]61E,O25-/5W)I=&5R+G!H<#HV,R!L:6(O5D93+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2YP:'`Z-#@*(SH@;&EB+U9&4R])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"B,Z(&QI8B]61E,O25-/5W)I=&5R
M+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#0*(SH@;&EB+U9&4R])4T]7<FET
M97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-0IM<V=I9"`B3F]T(&EM<&QE
M;65N=&5D+B(*;7-G<W1R(").;VX@:6UP;&5M96YT871O(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`IM<V=I9"`B3F]T
M('-E="(*;7-G<W1R(").;VX@:6UP;W-T871O(@H*(SH@;&EB+U9&4RYP:'`Z
M,3DS(&QI8B]61E,N<&AP.C(P."!L:6(O5D93+G!H<#HR,S0@;&EB+U9&4RYP
M:'`Z,C4R"B,Z(&QI8B]61E,N<&AP.C(V.2!L:6(O5D93+G!H<#HR.#4@;&EB
M+U9&4RYP:'`Z,S`Q(&QI8B]61E,N<&AP.C,Q-@HC.B!L:6(O5D93+G!H<#HS
M,S,@;&EB+U9&4RYP:'`Z,S8V(&QI8B]61E,N<&AP.C0R-B!L:6(O5D93+G!H
M<#HU,#4*(SH@;&EB+U9&4RYP:'`Z-3<T(&QI8B]61E,N<&AP.C4Y,2!L:6(O
M5D93+G!H<#HV-CD*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ
M-#4@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ-C`*(SH@;&EB+TAO
M<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S4@;&EB+TAO<F1E+U-E<W-I;VY(
M86YD;&5R+G!H<#HQ.#D*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H
M<#HR,S8*;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(DYO;B!S=7!P
M;W)T871O+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3`X(&QI8B](;W)D
M92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T"B,Z(&-O;F9I9R]H;V]K<RYP
M:'`N9&ES=#HQ,#4X(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#`*;7-G
M:60@(DYO=&5S(@IM<V=S='(@(D%P<'5N=&DB"@HC.B!S97)V:6-E<R]O8G)O
M=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G
M;R!B86-K+B(*;7-G<W1R(").=6QL82!D82!V:7-U86QI>GIA<F4L('1O<FYA
M(&EN9&EE=')O+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,3(@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U
M,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U
M"FUS9VED(").;W9E;6)E<B(*;7-G<W1R(").;W9E;6)R92(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,#0V"FUS9VED(").=6UB97(B"FUS9W-T<B`B3G5M
M97)O(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C4*;7-G:60@(DYU;6)E
M<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(DYU;65R;R!D:2!C87)A='1E<FDB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,V.2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,30R,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,30T-0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R
M(&]F(&-O;'5M;G,B"FUS9W-T<B`B3G5M97)O(&1I(&-O;&]N;F4B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3,V-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R
M,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,30T,PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@IM<V=I9"`B3G5M8F5R(&]F(')O
M=W,B"FUS9W-T<B`B3G5M97)O(&1I(')I9VAE(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E
M8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS
M9W-T<B`B(@HB22!N=6UE<FD@;F]N('-O;F\@<W1A=&D@<W!E8VEF:6-A=&D@
M<&5R(&PG86=G:6]R;F%M96YT;R!N96QL82!L:7-T82!D:2`B"B)D:7-T<FEB
M=7II;VYE+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHV-`IM<V=I9"`B3TLB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B3V)J96-T(@IM<V=S
M='(@(D]G9V5T=&\B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q
M,0IM<V=I9"`B3V)J96-T($-R96%T;W(B"FUS9W-T<B`B0W)E871O<F4@9&5L
M;"=/9V=E='1O(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,#0*;7-G:60@
M(D]C=&%L(@IM<V=S='(@(D]T=&%L92(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,3$@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(D]T=&]B<F4B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@
M9FEL=&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS,C@*;7-G:60@(D]F9FEC92(*;7-G<W1R(")59F9I8VEO(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/;&0@86YD(&YE
M=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N(@IM<V=S='(@(DQE('!A
M<W-W;W)D('9E8V-H:64@92!N=6]V92!D979O;F\@97-S97)E(&1I9F9E<F5N
M=&DB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*;7-G:60@
M(D]L9"!P87-S=V]R9"(*;7-G<W1R(")696-C:&EA('!A<W-W;W)D(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C0V"FUS9VED(")/;&0@<&%S
M<W=O<F0@:7,@;F]T(&-O<G)E8W0N(@IM<V=S='(@(DQA('9E8V-H:6$@<&%S
M<W=O<F0@;F]N(.@@8V]R<F5T=&$N(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@Q"FUS9VED(")/;6%N(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HW,PIM<V=I
M9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RXB
M"FUS9W-T<B`B4V]L;R!I('-E<G9E<B!)34%0('-U<'!O<G1A;F\@;&4@8V%R
M=&5L;&4@8V]N9&EV:7-E+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY
M-0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-3$@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$Y-S$*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"XB
M"FUS9W-T<B`B12<@<&5R;65S<V\@<V]L;R!U;B!I;F1I<FEZ>F\@96UA:6PN
M(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C8U"FUS9VED("(B"B)/
M;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA
M;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B"B)P97)M:7-S:6]N<R!F;W(@82!S
M:&%R92(*;7-G<W1R("(B"B)3;VQO(&EL('!R;W!R:65T87)I;R!O(&PG86UM
M:6YI<W1R871O<F4@9&D@<VES=&5M82!P=?(@8V%M8FEA<F4@;&$@<')O<')I
M973@("(*(F\@:2!P97)M97-S:2!D96P@<')O<')I971A<FEO('!E<B!U;F$@
M8V]N9&EV:7-I;VYE(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-#$@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z-#(*;7-G:60@(D]P96X@:6X@82!N97<@=VEN
M9&]W(@IM<V=S='(@(D%P<F4@:6X@=6YA(&YU;W9A(&9I;FES=')A(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@
M97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-
M24U%('!A<G0N(@IM<V=S='(@(B(*(D5R<F]R92!/<&5N4U-,.B!N;VX@<VD@
M<&]S<V]N;R!E<W1R87)R92!L92!I;F9O<FUA>FEO;FD@9&%L;&$@<&%R=&4@
M9FER;6%T82`B"B)3+TU)344N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")/<&5N<R!T:&ES
M(&QI;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D%P<F4@<75E<W1O(&-O
M;&QE9V%M96YT;R!I;B!U;F$@;G5O=F$@9FEN97-T<F$B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-3,*;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS
M9W-T<B`B4VES=&5M82!/<&5R871I=F\B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<VED96)A<BYP:'`Z,34U"FUS9VED(")/<'1I;VYS(@IM<V=S='(@(D]P>FEO
M;FDB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S
M+V%P<"YI;F,Z,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@
M)7,B"FUS9W-T<B`B3W!Z:6]N:2!P97(@)7,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI
M<W0B"FUS9W-T<B`B16QE;F-O(&]R9&EN871O(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R
M(")/<F=A;FEZ>F%Z:6]N92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-38Y"FUS9VED(")/<F=A;FES871I;VYA;"!5;FET(@IM<V=S='(@(E5N
M:73@($]R9V%N:7IZ871I=F$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3,T"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(D%G96YD82(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L
M:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R(")-87-C:&5R82!O<FEG:6YA;&4@
M9&5L;"=A<&QI8V%Z:6]N92(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W
M"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E;7!L871E<R!I;B`E
M<SHB"FUS9W-T<B`B36%S8VAE<F$@;W)I9VEN86QE(&EN("5S.B(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP
M:'`Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S='(@(D%L=')O(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDY(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#D*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3(U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S0@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$T-`IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB
M"FUS9W-T<B`B06QT<F4@26YF;W)M87II;VYE(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHS,0IM<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS
M9W-T<B`B4&5R;65S<VD@9&5L('!R;W!R:65T87)I;R(*"B,Z(&QI8B](;W)D
M92]!=71H+W!A;2YP:'`Z-SD*;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I
M<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("),)V%U=&5N=&EC87II;VYE(%!!
M32!N;VX@Z"!D:7-P;VYI8FEL92XB"@HC.B!L:6(O3F5T+U--4R]G96YE<FEC
M7W-M='`N<&AP.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$R-S8*;7-G:60@
M(E!'4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HQ,S(R"FUS9VED(")01U`@16YC<GEP=&5D($1A
M=&$B"FUS9W-T<B`B26YF;W)M87II;VYE($-I9G)A=&$@4$=0(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3,W-`IM<V=I9"`B4$=0(%!U8FQI8R!+
M97DB"FUS9W-T<B`B0VAI879E(%!U8F)L:6-A(%!'4"(*"B,Z(&QI8B](;W)D
M92]#<GEP="]P9W`N<&AP.C$S-38*;7-G:60@(E!'4"!3:6=N960O16YC<GEP
M=&5D($1A=&$B"FUS9W-T<B`B26YF;W)M87II;VYE($9I<FUA=&$O0VEF<F%T
M82!01U`B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-CD*;7-G:60@(E!(4"!#
M;V1E(@IM<V=S='(@(D-O9&EC92!02%`B"@HC.B!A9&UI;B]P:'!S:&5L;"YP
M:'`Z,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R(")3:&5L;"!02%`B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.`IM<V=I
M9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B4$T@4F%I;B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT,`IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@4VYO
M=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT,@IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0S"FUS
M9VED(")032!3=6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.#8*;7-G:60@(E!/
M4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(D5S=&5N<VEO;F4@
M4$]325@@;6%N8V%N=&4B"@HC.B!L:6(O87!I+G!H<#HQ-#D*;7-G:60@(E!?
M2%`@4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G
M<W1R(")2:65M<&EM96YT;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDY(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$X-PIM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$Y-`IM<V=I9"`B4&%L874B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-S0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,@IM<V=I9"`B4&%L97-T
M:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#(*;7-G:60@
M(E!A;F%M82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.#4*;7-G:60@(E!A<'5A($YE=R!'=6EN96$B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S<*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$Y-0IM<V=I9"`B4&%R86=U87DB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*;7-G:60@
M(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B4&%R>FEA;&UE;G1E($YU=F]L;W-O
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$W.0HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.2!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z(&QI8B].970O
M4TU3+W=I;E]H='1P+G!H<#HQ-3$@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,3@*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW-R!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C0S"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT,C4*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA
M;F=E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(E!A<W-W;W)D(&-A;6)I871A
M(&-O;B!S=6-C97-S;RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C$S,C,*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G<W1R(")087-S
M;W=R9"!N;VX@8V]R<F5T=&$B"@HC.B!L:6(O2&]R9&4O075T:"]R861I=7,N
M<&AP.C$U,@IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B12<@<FEC:&EE<W1A(&QA('!A<W-W
M;W)D('!E<B!L)V%U=&5N=&EC87II;VYE(%)!1$E54RXB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C`U,PIM<V=I9"`B4&%S<W=O<F0@=VET:"!C;VYF:7)M
M871I;VXB"FUS9W-T<B`B4&%S<W=O<F0@8V]N(&-O;F9E<FUA(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP"FUS9VED(")087-S=V]R9#HB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*
M;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,34P(&QI8B](;W)D92]&;W)M+G!H<#HR,#,T"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M=7-T
M(&UA=&-H+B(*;7-G<W1R("),92!P87-S=V]R9"!D979O;F\@8V]R<FES<&]N
M9&5R92XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B
M4&%S=&4B"FUS9W-T<B`B26YC;VQL82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI
M<&)O87)D(@IM<V=S='(@(DEN8V]L;&$@9&%L;&$@8VQI<&)O87)D(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I
M9"`B4&%T:"(*;7-G<W1R(")097)C;W)S;R(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E<75E=65D+FEN8SHW"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-`IM<V=I9"`B4&5O
M<&QE(@IM<V=S='(@(E!E<G-O;F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R
M(")097)C96YT=6%L92(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN
M=&5N86YC92YH=&UL.C0Y"FUS9VED(")097)F;W)M($UA:6YT96YA;F-E($]P
M97)A=&EO;G,B"FUS9W-T<B`B17-E9W5I(&QE($]P97)A>FEO;FD@9&D@36%N
M=71E;GII;VYE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Q,`IM<V=I
M9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*
M;7-G<W1R(")%<V5G=6ER92!L92!O<&5R87II;VYI(&1I(&UA;G1U=&5N>FEO
M;F4@86QL)V%C8V5S<V\_(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ
M-38*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B4&5R;65S<V\B"@HC.B!A
M9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@
M(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R(")097)M
M97-S;R!<(B5S7"(@;F]N(&-A;F-E;&QA=&\N(@H*(SH@;&EB+U9&4R]S;6(N
M<&AP.C8P,PIM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`B4&5R
M;65S<V\@3F5G871O(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-C$@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-C0*;7-G:60@(E!E<FUI<W-I;VYS
M(@IM<V=S='(@(E!E<FUE<W-I(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N
M<&AP.C8P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3@*(SH@861M:6XO<&5R
M;7,O961I="YP:'`Z,3`Y(&%D;6EN+W!E<FUS+VEN9&5X+G!H<#HR,@IM<V=I
M9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VXB"FUS9W-T<B`B1V5S=&EO
M;F4@4&5R;65S<VDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@*;7-G
M:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%Z:6]N
M:2!097)S;VYA;&DB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY."!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ.#,*;7-G:60@(E!E<G4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0971S(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-SD*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X
M-@IM<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM<V=S
M='(@(E1E;&5F;VYO(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X
M,`IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(D9O=&]G<F%F:64B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$X,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DP"FUS9VED
M(")0:71C86ER;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX96QS(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B4&QA=&ET
M=61E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT
M;R!S;VUE(&-E;&PB"FUS9W-T<B`B4VD@<')E9V$@9&D@8VQI8V-A<F4@:6X@
M86QC=6YE(&-E;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER;2!T
M:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@
M(E-I('!R96=A(&1I(&-O;F9E<FUA<F4@8VAE('-I('9U;VQE(')I;75O=F5R
M92!Q=65S=&\@96QE;65N=&\Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N
M9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM
M<V=S='(@(E-I('!R96=A(&1I(&-O;F9E<FUA<F4@8VAE('-I('9U;VQE('-C
M;VQL96=A<F4@<75E<W1O(&5L96UE;G1O.B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR-38R"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y
M96%R+B(*;7-G<W1R(")3:2!P<F5G82!D:2!I;G-E<FER92!U;B!M97-E(&4@
M=6X@86YN;RXB"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M
M96YT+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE
M(&YE=R!C871E9V]R>3HB"FUS9W-T<B`B4VD@<')E9V$@9&D@:6YS97)I<F4@
M=6X@;F]M92!P97(@;&$@;G5O=F$@9V%T96=O<FEA.B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,S`Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!)
M4"!A9&1R97-S+B(*;7-G<W1R(")3:2!P<F5G82!D:2!I;G-E<FER92!U;B!I
M;F1I<FEZ>F\@25`@=F%L:61O+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M-C0P"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T
M:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G<W1R("(B"B)3
M:2!P<F5G82!D:2!I;G-E<FER92!U;F$@9&%T82!V86QI9&$L(&-O;G1R;VQL
M82!I;"!N=6UE<F\@9&D@9VEO<FYI(&YE;"!M97-E+B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR-#0W"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T
M:6UE+B(*;7-G<W1R(")3:2!P<F5G82!D:2!I;G-E<FER92!U;B=O<F$@=F%L
M:61A+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G
M:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB
M"FUS9W-T<B`B4VD@<')E9V$@9&D@9F]R;FER92!U;B!R:6%S<W5N=&\@9&5L
M('!R;V)L96UA+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE87-E('!R
M;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B4VD@
M<')E9V$@9&D@9F]R;FER92!I;"!P<F]P<FEO(&YO;64@=71E;G1E(&4@<&%S
M<W=O<F0B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@
M(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@
M86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM
M<V=S='(@(B(*(E-I('!R96=A(&1I(&QE9V=E<F4@:6P@<V5G=65N=&4@=&5S
M=&\N($1%5DD@97-S97)E(&0G86-C;W)D;R!C;VX@:2!T97)M:6YI("(*(F0G
M=7-O(&1E;"!S:7-T96UA+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R
M>4UA;F%G97(N<&AP.C<P"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A
M=&5G;W)Y(&YA;64Z(@IM<V=S='(@(E-I('!R96=A(&1I('-C<FEV97)E(&EL
M;F]M92!D96QL82!N=6]V82!C871E9V]R:6$Z(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X
M,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@X"FUS9VED(")0;VQA;F0B
M"FUS9W-T<B`B4&]L;VYI82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M-PIM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B4&]L:71I8V$B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@Y"FUS9VED(")0;VQL<R(*;7-G<W1R
M(")38W)U=&EN:6\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#$@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3DS"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R(")0;W)T
M;V=A;&QO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3(T"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES
M(&EM86=E(@IM<V=S='(@(E!O<VEZ:6]N86UE;G1O(&1I('%U97-T82!I;6UA
M9VEN92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S
M='(@(E!O<VEZ:6]N86UE;G1O(&1I('%U97-T82!T86)E;&QA(@H*(SH@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ(&QI8B](;W)D92])34%0
M+T%#3"]R9F,T,S$T+G!H<#HU,0IM<V=I9"`B4&]S="!T;R!T:&ES(&9O;&1E
M<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(E!O<W1A<F4@82!Q
M=65S=&$@8V%R=&5L;&$@*&YO;B!A<'!L:6-A=&\@9&$@24U!4"DB"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(W,R!L:6(O0FQO8VLO;65T87(N<&AP.C(W
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T
M("5S(&AO=7(H<RDZ("(*;7-G<W1R(")0<F5C:7!I=&%Z:6]N92!P97(@;"=U
M;'1I;6$@)7,@;W)A*&4I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(X-PIM<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H86YC92(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O4')E9G,O;&1A<"YP:'`Z.3@*;7-G:60@
M(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B4')E9G-?;&1A<#H@17-T96YS:6]N92!,1$%0(')I8VAI
M97-T82!N;VX@=')O=F%T82XB"@HC.B!L:6(O2&]R9&4O4')E9G,O<V5S<VEO
M;BYP:'`Z,S,*;7-G:60@(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I
M;VX@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?<V5S<VEO
M;CH@97-T96YS:6]N92!D96QL82!S97-S:6]N92!R:6-H:65S=&$@;F]N('1R
M;W9A=&$N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S(*;7-G:60@(E!R
M97-S=7)E(@IM<V=S='(@(E!R97-S:6]N92(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C8V"FUS9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ("(*;7-G
M<W1R(")0<F5S<VEO;F4@86P@;&EV96QL;R!D96P@;6%R93H@(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-`IM<V=I9"`B4')E<W-U<F4Z
M("(*;7-G<W1R(")0<F5S<VEO;F4Z("(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(S"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"FUS9VED(")0<F5V:65W
M(@IM<V=S='(@(D%N=&5P<FEM82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,0IM<V=I9"`B4')E=FEE
M=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D%N=&5P<FEM
M82!D96QL)VEM;6%G:6YE(&EN('5N82!N=6]V82!F:6YE<W1R82(*"B,Z(&QI
M8B](;W)D92]0<F5F<R]522YP:'`Z,S4V(&QI8B](;W)D92]0<F5F<R]522YP
M:'`Z,S8P"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S='(@(D]P>FEO
M;FD@<')E8V1E;G1I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B
M4W1A;7!A(&1O8W5M96YT;R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C0R,PIM<V=I9"`B4')I=F%T92!+97DB"FUS9W-T<B`B0VAI879E(%!R:79A
M=&$B"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,38Y"FUS9VED(")0<F]B;&5M
M(@IM<V=S='(@(E!R;V)L96UA(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z
M,3(W"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@(D1E<V-R
M:7II;VYE(&1E;"!P<F]B;&5M82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS-S$*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(E!R;V=E='1I(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,3$@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(Q.#@@;&EB+TAO<F1E+T9O<FTN<&AP.C,R-S8*;7-G:60@(E!R;VUP="!T
M97AT(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R
M,PIM<V=I9"`B4'5B;&EC($ME>2(*;7-G<W1R(")#:&EA=F4@4'5B8FQI8V$B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T-@IM<V=I9"`B4'5B
M;&EC($ME>2!!;&=O<FET:&TB"FUS9W-T<B`B06QG;W)I=&UO(&1E;&QA($-H
M:6%V92!0=6)B;&EC82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-C0U"FUS9VED(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`B26YF;W)M87II
M;VYI('-U;&QA($-H:6%V92!0=6)B;&EC82(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N
M;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B3&$@8V]P<&EA
M(&-H:6%V92!0=6)B;&EC82]0<FEV871A(&YO;B#H('-T871A(&=E;F5R871A
M(&-O;B!S=6-C97-S;RXB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,PHC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3DQ"FUS9VED(")0=65R=&\@4FEC;R(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-34*;7-G
M:60@(E!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(D5L:6UI;F$@:2!M97-S86=G
M:2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ.38*;7-G:60@(E%A=&%R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HV-`IM<V=I9"`B475E<GDB"FUS9W-T<B`B1&]M86YD82(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,`IM<V=I9"`B475O=&$B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-C0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-C0*;7-G:60@(E)A9&EO
M('-E;&5C=&EO;B(*;7-G<W1R(")396QE>FEO;F4@<F%D:6\B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I
M;B(*;7-G<W1R(")0:6]G9VEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E)A:6X@16%R;'DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*
M;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!3:&]W97(B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#D*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3`*;7-G:60@
M(E)A:6X@=&\@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U;F4B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO(@IM<V=S='(@(E)A
M<'!O<G1O(@H*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HS,C0@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*;7-G
M:60@(E)E860B"FUS9W-T<B`B3&5G9VDB"@HC.B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.#<@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N
M<&AP.C0W"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@(DQE9V=E<F4@
M:2!M97-S86=G:2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI
M;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E("5S/R!4
M:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R(")%;&EM
M:6YA<F4@<F5A;&UE;G1E("5S/R!,)V]P97)A>FEO;F4@;F]N('!U\B!E<W-E
M<F4@<F5C=7!E<F%T82XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A
M<BYI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@<F5M;W9E('5S
M97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E
M('5N9&]N92XB"FUS9W-T<B`B(@HB16QI;6EN87)E(')E86QM96YT92!L92!I
M;F9O<FUA>FEO;FD@<F5L871I=F4@86QL)W5T96YT92`E<S\@3"=O<&5R87II
M;VYE(&YO;B`B"B)P=?(@97-S97)E(')E8W5P97)A=&$N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B4F5D
M;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B4FEE<V5G=64@;&$@='5A
M('5L=&EM82!A>FEO;F4B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G
M<W1R(")!9V=I;W)N82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.34*
M;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G<W1R
M(")!9V=I;W)N82!G;&D@96QE;65N=&D@9&EN86UI8VD@9&5L(&UE;G4Z(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T-0IM<V=I9"`B4F5F<F5S:"!0
M;W)T86P@5FEE=SHB"FUS9W-T<B`B06=G:6]R;F%R92!L82!V:7-T82!D96P@
M<&]R=&%L93HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DT(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,C$S(&QI8B](;W)D92]&;W)M+G!H<#HQ,C,U"FUS9VED
M(")296=E>"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(S
M,0IM<V=I9"`B4F5L871I;VYS:&EP($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(P.`IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(E)I8V%R
M:6-A(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,S,*;7-G:60@(E)E;6%R
M:W,B"FUS9W-T<B`B3W-S97)V87II;VYI(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Q-PIM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B4V5R
M=F5R(')E;6]T:2(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX
M-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H
M;W)D92DZ(@IM<V=S='(@(E523"!R96UO=&$@*&AT='`Z+R]W=W<N97AA;7!L
M92YC;VTO:&]R9&4I.B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O
M=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E
M9"YI;F,Z,3,@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,@IM
M<V=I9"`B4F5M;W9E(@IM<V=S='(@(E)I;75O=FDB"@HC.B!T96UP;&%T97,O
M<&]R=&%L+VQA>6]U="YI;F,Z,3$*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G
M<W1R(")2:6UU;W9I(&EL(&)L;V-C;R(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HU-3D*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS
M9W-T<B`B4FEM=6]V:2!L82!C;VQO;FYA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`IM<V=I9"`B4F5M;W9E(&9O<FUA
M='1I;F<B"FUS9W-T<B`B4FEM=6]V:2!L82!F;W)M871T87II;VYE(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,C@*;7-G:60@(E)E;6]V92!P
M86ER(@IM<V=S='(@(E)I;75O=FD@;&$@8V]P<&EA(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C(P,0IM<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP="!F
M<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(E)I
M;75O=FD@;&\@<V-R:7!T('-A;'9A=&\@9&%L;&$@9&ER96-T;W)Y('1E;7!O
M<F%N96$@9&5L('-E<G9E<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*;7-G:60@(E)E;6]V92!T:&4B
M"FUS9W-T<B`B4FEM=6]V:2!I;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I9"`B4F5M;W9E('1H
M:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G<W1R(")2:6UU;W9I('%U
M97-T;R!N;V1O(&1A;"!D;V-U;65N=&\B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F4N:6YC.C$Q"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R
M(")2:6UU;W9I(&PG=71E;G1E(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R
M.B`E<R(*;7-G<W1R(")2:6UU;W9I(&PG=71E;G1E.B`E<R(*"B,Z(&QI8B](
M;W)D92]24$,O>&UL<G!C+G!H<#HQ,S@*;7-G:60@(E)E<75E<W0@8V]U;&1N
M)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@
M(DQA(')I8VAI97-T82!N;VX@<'7R(&5S<V5R92!E=F%S82X@0V]D:6-E(&1I
M(&5R<F]R92!D:2!R:71O<FYO.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,30U"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L9"!N
M;W0@8F4@9F]U;F0N(@IM<V=S='(@(DEL('-E<G9I>FEO(')I8VAI97-T;R!O
M;B!P=?(@97-S97)E('1R;W9A=&\N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ.#4@
M;&EB+TAO<F1E+G!H<#HU,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER
M960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B7"(E<UPB(')I8VAI97-T;R!N;VX@Z"!S<&5C:69I8V%T;R!N
M96QL82!C;VYF:6=U<F%Z:6]N92!D:2`E<RXB"@HC.B!L:6(O5D93+V9T<"YP
M:'`Z.#<T(&QI8B]61E,O<W%L+G!H<#HV.3`@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z-S4Y"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N
M;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")<
M(B5S7"(@<FEC:&EE<W1O(&YO;B#H('-P96-I9FEC871O(&YE;&QA(&-O;F9I
M9W5R87II;VYE(&1I(%9&4RXB"@HC.B!L:6(O2&]R9&4O571I;"YP:'`Z-SDP
M"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E
M8VEF:65D(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(EPB)7-<(B!R:6-H
M:65S=&\@;F]N(.@@<W!E8VEF:6-A=&\@;F5L;&$@8V]N9FEG=7)A>FEO;F4N
M(@H*(SH@;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,S-@IM<V=I9"`B
M4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B0V%M<&\@4FEC:&EE<W1O(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,S$@;&EB+TAO<F1E+T9O<FTN<&AP.C,S.0HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(P(&QI8B](;W)D
M92]&;W)M+U)E;F1E<F5R+G!H<#HS,C$*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C$P,"!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C<W"FUS9VED(")297-E="(*;7-G<W1R(")!>GIE<F$B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B4F5S970@4&%S<W=O<F0B
M"FUS9W-T<B`B07IZ97)A(&QA('!A<W-W;W)D(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z,C<*;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B
M"FUS9W-T<B`B07IZ97)A(&QA('1U82!P87-S=V]R9"(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,S$*;7-G:60@(E)E<W1O<F4@3&%S="!1=65R>2(*;7-G
M<W1R(")2:7!R:7-T:6YA(&PG=6QT:6UA(&1O;6%N9&$B"@HC.B!A9&UI;B]C
M;61S:&5L;"YP:'`Z,CD@861M:6XO<&AP<VAE;&PN<&AP.C<R(&%D;6EN+W-Q
M;'-H96QL+G!H<#HV-PIM<V=I9"`B4F5S=6QT<R(*;7-G<W1R(")2:7-U;'1A
M=&DB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L
M871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS
M(@IM<V=S='(@(E)I=&]R;F$@86QL92!/<'II;VYI(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED(")2971Y<&4@;F5W('!A<W-W
M;W)D(@IM<V=S='(@(E)I<V-R:79I(&QA(&YU;W9A('!A<W-W;W)D(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.#4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-PIM
M<V=I9"`B4F5U;FEO;B(*;7-G<W1R(")2:75N:6]N92(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`IM
M<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB"FUS9W-T<B`B26YV97)T:2!L
M82!#;VYF:6=U<F%Z:6]N92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,S4*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R(")/
M<'II;VYI('!E<B!I;"!2:6-H(%1E>'0@161I=&]R(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4X"FUS9VED(")2:61D;&5S(@IM<V=S='(@(DEN9&]V
M:6YE;&QI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0X"FUS9VED(")2:6=H="(*;7-G<W1R(")$97-T<F$B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P,PIM<V=I9"`B4FEG:'0@:&5A9&5R
M(@IM<V=S='(@(DEN=&5S=&%Z:6]N:2!D:2!D97-T<F$B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,S`Y.0IM<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@
M(E9A;&]R:2!D:2!D97-T<F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R
M=&EE<RXN+B(*;7-G<W1R(")0<F]P<FEE=.`@9&5L;&$@4FE?9V$N+BXB"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(S-`IM<V=I9"`B
M4F]L92(*;7-G<W1R(")296=O;&$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DX"FUS9VED(")2;VUA;FEA(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,C8*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B4F]U=&$@9&D@,3@P(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,PIM<V=I
M9"`B4F]T871E($QE9G0B"FUS9W-T<B`B4F]U=&$@82!S:6YI<W1R82(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,CD*;7-G:60@
M(E)O=&%T92!2:6=H="(*;7-G<W1R(")2;W5T82!A($1E<W1R82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*
M;7-G:60@(E)O=R!0<F]P97)T:65S(@IM<V=S='(@(E!R;W!R:65TX"!D96QL
M82!2:6=A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW,`IM<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`B
M4')O<')I973@(&1E;&QA(')I9V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`B
M4FEG:&4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU,PIM<V=I9"`B4G5L97,B"FUS9W-T<B`B4F5G;VQE(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W
M<R!A;F0@8V]L=6UN<R(*;7-G<W1R("),92!R96=O;&4@87!P87)I<F%N;F\@
M=')A('1U='1E(&QE(')I9VAE(&4@;&4@8V]L;VYN92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@
M(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S
M='(@(DQE(')E9V]L92!A<'!A<FER86YN;R!S;VQO('1R82!L92!C;VQO;FYE
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S
M(&]N;'DB"FUS9W-T<B`B3&4@<F5G;VQE(&%P<&%R:7)A;FYO('-O;&\@=')A
M(&QE(')I9VAE(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R,0IM<V=I9"`B
M4G5N(@IM<V=S='(@(D5S96=U:7)E(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y.0IM<V=I9"`B4G5S<VEA;B!&961E
M<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,#`*;7-G:60@(E)W86YD82(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-
M24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(D9I<FUA(&-I
M9G)A=&$@4R]-24U%(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS
M,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*;7-G<W1R(")-
M97-S86=G:6\@8VEF<F%T;R!3+TU)344B"@HC.B!L:6(O2&]R9&4O075T:"]S
M87-L+G!H<#HX,0IM<V=I9"`B4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@
M879A:6QA8FQE+B(*;7-G<W1R("),)V%U=&5N=&EC87II;VYE(%-!4TP@;F]N
M(.@@9&ES<&]N:6)I;&4N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C4P-@IM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R(")-97-S86=G:6\@
M4TU3(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS9VED(")344P@4VAE
M;&PB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R-S0*;7-G
M:60@(E-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',B"FUS9W-T<B`B
M1&EC:&EA<F%Z:6]N92!344P@<&5R(&EL('9A;&]R92!D:2!L;V]K<W5P(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S,PIM<V=I9"`B4U-((@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O
M;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R("(B"@HC.B!L
M:6(O87!I+G!H<#HQ-3,*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0IM
M<V=I9"`B4V$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(P-PIM<V=I9"`B4V%I;G0@2&5L96YA(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@T(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$S,0IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@W(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$S.0IM<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ.3(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X.0IM<V=I
M9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,34@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$Y,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0T"FUS
M9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDR"FUS9VED(")386UE(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B4W1E<W-A
M('-T<G5T='5R82`H7V%U=&\I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(U,0IM<V=I9"`B4V%M;V$B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(Q,@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$Y-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$V"FUS9VED(")3
M86\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3871E;&QI=&4@4')O=FED97(B
M"FUS9W-T<B`B<')O=FED97(@<V%T96QL:71A<F4B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$Y-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`Q"FUS9VED(")3875D
M:2!!<F%B:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO
M=70N:6YC.CDY"FUS9VED(")3879E(@IM<V=S='(@(E-A;'9A(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3879E(%PB)7-<(B(*;7-G<W1R(")386QV82!<(B5S7"(B"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3879E("5S(@IM<V=S='(@(E-A;'9A("5S(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S
M='(@(E-A;'9A(&QE($]P>FEO;FDB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,38V"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N
M(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B
M"B)D:7)E8W1O<GDN(@IM<V=S='(@(B(*(DQA(&-O;F9I9W5R87II;VYE(&=E
M;F5R871A(.@@<W1A=&$@<V%L=F%T82!C;VUE('-C<FEP="!02%`@;F5L;&$@
M9&ER96-T;W)Y("(*(G1E;7!O<F%N96$@9&5L('1U;R!S97)V97(N(@H*(SH@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B<V%L=F%T92`E
M<R!C;VYF:6=U<F%Z:6]N:2XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HY,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U<&=R861E
M('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(")386QV871O(&QO('-C<FEP
M="!D:2!A9V=I;W)N86UE;G1O(&1E;&QE(&EM<&]S=&%Z:6]N:2!I;CH@7"(E
M<UPB+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4Q"FUS9VED(")38V%T=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE;F-E(@IM<V=S
M='(@(E-C:65N>F$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN
M8SHQ-"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B
M4V5A<F-H(@IM<V=S='(@(E)I8V5R8V$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S(R"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R(")-
M;W1O<FD@9&D@4FEC97)C82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.34U
M"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B1FEL92!S96QE>FEO;F%T
M:2(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT.#4*
M;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B4V5L97II;VYA('5N82!D
M871A(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.3@*;7-G:60@
M(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R(")396QE>FEO;F$@=6X@
M9W)U<'!O(&1A(&%G9VEU;F=E<F4B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C0S"FUS9VED(")396QE8W0@82!N97<@;W=N97(B"FUS9W-T<B`B
M4V5L97II;VYA('5N(&YU;W9O('!R;W!R:65T87)I;R(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R
M(@IM<V=S='(@(E-E;&5Z:6]N82!U;B!S97)V97(B"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$U-@IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A
M9&0B"FUS9W-T<B`B4V5L97II;VYA('5N('5T96YT92!D82!A9V=I=6YG97)E
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-@IM
M<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R(")396QE>FEO;F$@='5T=&\B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C8T,PIM<V=I9"`B4V5L96-T(&%L;"!D
M871E(&-O;7!O;F5N=',N(@IM<V=S='(@(E-E;&5Z:6]N82!T=71T:2!I(&-O
M;7!O;F5N=&D@9&5L;&$@9&%T82XB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")396QE8W0@86X@;V)J96-T(@IM
M<V=S='(@(G-E;&5Z:6]N82!U;B!O9V=E='1O(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-PIM<V=I9"`B4V5L96-T(&YO;F4B
M"FUS9W-T<B`B3F5S<W5N82!S96QE>FEO;F4B"@HC.B!S97)V:6-E<R]K97EB
M;V%R9"YP:'`Z,S<*;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y
M;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O
M<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G
M<W1R("(B"B)396QE>FEO;F$@:2!C87)A='1E<FD@9&D@8W5I(&AA:2!B:7-O
M9VYO(&1A;&QE(&-A<V5L;&4@<V]T=&\@<FEP;W)T871E+B!0=6]I("(*(F-O
M<&EA<FQI(&4@:6YC;VQL87)L:2!D86QL)V%R96$@9&D@=&5S=&\N(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@
M9&%T92!D96QI;6ET97(Z(@IM<V=S='(@(E-E;&5Z:6]N82!I;"!T97)M:6YE
M(&1E;&QA(&1A=&$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*
M;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM<V=S='(@(E-E;&5Z
M:6]N82!I;"!F;W)M871O(&1E;&QA(&1A=&$Z(@H*(SH@=&5M<&QA=&5S+W!R
M969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L96-T('1H92!I
M9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(E-E;&5Z:6]N
M82!L)VED96YT:73@(&-H92!V=6]I(&UO9&EF:6-A<F4Z(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O=&EM92YI;F,Z,38*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D
M96QI;6ET97(Z(@IM<V=S='(@(E-E;&5Z:6]N82!I;"!L:6UI=&4@9&5L;"=O
M<F$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E
M;&5C="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(E-E;&5Z:6]N82!I;"!F
M;W)M871O(&1E;&PG;W)A.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z-3<*;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G
M<W1R(")396QE>FEO;F$@9'5E(&-A;7!I(&-H92!C;W)R:7-P;VYD;VYO+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,3`*;7-G:60@(E-E;&5C="!Y
M;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B4V5L97II;VYA(&QO('-C:&5M
M82!D96D@8V]L;W)I+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3(*
M;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T
M<B`B4V5L97II;VYA(&QA(&QI;F=U82!P<F5F97)I=&$Z(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE
M;2!297!O<G0B"FUS9W-T<B`B26YV:6$@:6P@4F5P;W)T(&1E;"!P<F]B;&5M
M82(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#0R
M"FUS9VED(")396YD(%--4R(*;7-G<W1R("));G9I82!335,B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$Y.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$S"FUS9VED
M(")396YE9V%L(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S(S"FUS9VED(")396YS;W(Z("(*;7-G<W1R(")396YS;W)E.B`B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I9"`B4V5P=&5M8F5R
M(@IM<V=S='(@(E-E='1E;6)R92(*"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R;R(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,@IM<V=I
M9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R(").=6UE<F\@9&D@4V5R:64B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30Y"FUS9VED(")397)V
M97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*;7-G<W1R("));F9O
M<FUA>FEO;F4@9&5L('-E<G9E<B!S8F%G;&EA=&$@;R!N;VX@9&ES<&]N:6)I
M;&4N(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(W"FUS9VED(")397-S:6]N
M($%D;6EN(@IM<V=S='(@(D%M;6EN:7-T<F%T;W)E(&1I('-E<W-I;VYE(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@
M(E-E<W-I;VX@240@97AP:7)E9"XB"FUS9W-T<B`B3&$@<V5S<VEO;F4@240@
MZ"!S8V%D=71A(@H*(SH@;&EB+V%P:2YP:'`Z,30U"FUS9VED(")397-S:6]N
M<R(*;7-G<W1R(")397-S:6]N:2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M,S$T"FUS9VED(")3970B"FUS9W-T<B`B26UP;W-T82(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW.0IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@
M>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T
M(&ET+B(*;7-G<W1R("(B"B));7!O<W1A(&QE(&]P>FEO;FD@<&5R('!E<FUE
M='1E<G1I(&1I(&%Z>F5R87)E(&QA('!A<W-W;W)D(&YE;"!C87-O(&1O=F5S
M<VD@(@HB9&EM96YT:6-A<G1E;&$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q.`IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U
M('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(DEM
M<&]S=&$@:6P@<V5R=F5R(')E;6]T;R!A;"!Q=6%L92!V=6]I(&%C8V5D97)E
M(&1A;"!T=6\@<&]R=&%L92XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#<*;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO
M;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B26UP;W-T82!L82!L:6YG
M=6$@<')E9F5R:71A(&4@;&4@;W!Z:6]N:2!P97(@;"=O<F$@92!L82!D871A
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#$*;7-G:60@(B(*(E-E
M="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G
M92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*
M;7-G<W1R("(B"B));7!O<W1A(&QE(&%P<&QI8V%Z:6]N:2!D:2!A=G9I;RP@
M;&\@<V-H96UA(&1E:2!C;VQO<FDL(&EL('1E;7!O(&1I("(*(F%G9VEO<FYA
M;65N=&\@9&5L;&$@<&%G:6YA(&4@86QT<F4@;W!Z:6]N:2!D:2!V:7-U86QI
M>GIA>FEO;F4N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-PIM<V=I
M9"`B4V5T=7`B"FUS9W-T<B`B26UP;W-T87II;VYE(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*;7-G:60@(E-E='5P('5P9W)A
M9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`B4V-R:7!T(&1I(&%G9VEO
M<FYA;65N=&\@9&5L;&4@:6UP;W-T87II;VYI(&1I<W!O;FEB:6QI(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-0IM<V=I9"`B4V5V97)A
M;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS
M9W-T<B`B1&EV97)S92!P;W-I>FEO;FD@9&ES<&]N:6)I;&D@8V]N(&EL('!A
M<F%M971R;SH@(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(P,PIM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DX"FUS9VED(")3:&]P<&EN
M9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHT,PIM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G<W1R(")"<F5V92!3;VUM
M87)I;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-3`*;7-G:60@(E-H
M;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*
M;7-G<W1R("),82!C:&EA=F4@9"=A8V-E<W-O(&1O=G+@(&5S<V5R92!D969I
M;FET82!P97(@<&GY(&-O;&QE9V%M96YT:3\B"@HC.B!L:6(O2&]R9&4O4&5R
M;7,N<&AP.C,R,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,S"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z-C<@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,R!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*;7-G<W1R(")-;W-T<F$B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,34T"FUS9VED("(B"B)3:&]W
M(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@
M;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*
M(DUO<W1R82!L92!D:69F97)E;GIE('1R82!L82!C;VYF:6=U<F%Z:6]N92!A
M='1U86QM96YT92!S86QV871A(&4@;&$@;G5O=F$@(@HB9V5N97)A=&$N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y-`IM<V=I9"`B4VAO=R!L87-T
M(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R(")-;W-T<F$@
M;"=O<F$@9&5L;"=U;'1I;6\@86-C97-S;R!Q=6%N9&\@96YT<FD_(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$W-C4*;7-G:60@(E-H;W<@;W!T:6]N('1O
M(&ME97`@;W)I9VEN86PB"FUS9W-T<B`B36]S=')A(&PG;W!Z:6]N92!P97(@
M;6%N=&5N97)E('%U96QL82!O<FEG:6YA;&4B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C<Y-0IM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B36]S=')A
M(&EL(')A8V-O9VQI=&]R92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,S`*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS
M9W-T<B`B36]S=')A<F4@;&$@=&%B96QL82!D96QL92!O<&5R87II;VYI(&1E
M;"!M96YU(&)A<C\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4S"B,L
M('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE
M9G0_(@IM<V=S='(@(DUO<W1R82!I;"!M96YU(&1I("5S('-U;&QA('-I;FES
M=')A/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P
M97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@
M=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M,`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O
M<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$W-C,*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(DUO<W1R82!I
M;"!C87)I8V%M96YT;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4R"FUS9VED(")3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3
M:&]W97)S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4T"FUS9VED(")3:&]W97)S($QA=&4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-34*;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C$Y
M"FUS9VED(")3:')I;FLB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HY,3`*(SH@;&EB+TAO<F1E+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HY-S(*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HQ,#4X"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z,3$R,`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.C$Q.#,*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA
M9V5R+G!H<#HQ,C(S"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z,3(U,@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.C$R.#4*;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B
M;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(P,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$Q"FUS
M9VED(")3:65R<F$@3&5O;F4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O4VEG;G5P+G!H<#HR-C8*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B0V]N
M=')A<W-E9VYA(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,3,*
M;7-G:60@(E-I9VYA='5R92(*;7-G<W1R(")&:7)M82(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED(")3:6=N871U<F4@06QG;W)I
M=&AM(@IM<V=S='(@(D%L9V]R:71M;R!D:2!F:7)M82(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#8*;7-G:60@(E-I
M;F=A<&]R92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DV
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,C$U(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,C,W"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C0V(&QI8B](;W)D92]&;W)M
M+G!H<#HR.3$R(&QI8B](;W)D92]&;W)M+G!H<#HS,3`U"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]R87(N<&AP.C8U(&QI8B](;W)D92]-24U%+U9I97=E
M<B]T9WHN<&AP.C@T"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<R"FUS9VED(")3:7IE(@IM<V=S='(@(D1I;65N<VEO;F4B"@HC.B!T96UP
M;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM<V=I9"`B
M4VMI<"!-86EN=&5N86YC92(*;7-G<W1R(")386QT82!L92!O<&5R87II;VYI
M(&1I(&UA;G5T96YZ:6]N92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,3`*;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,#@*;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V"FUS9VED(")3;F]W(@IM
M<V=S='(@(DYE=F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@
M(E-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU.0IM<V=I9"`B4VYO=R!3:&]W97)S($5A
M<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8P"FUS9VED(")3;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X-0IM<V=I9"`B4VYO=R!D
M97!T:#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@Y
M"FUS9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(P-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C`R"FUS9VED(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,#8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-`IM<V=I
M9"`B4V]M86QI82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(Y,#@*;7-G:60@(E-O<G0@;W)D97(@<V5L96-T
M:6]N(@IM<V=S='(@(D]R9&EN82!L)V]R9&EN86UE;G1O(&1I('-E;&5Z:6]N
M92(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4X.0HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z
M,38V(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ.#D*;7-G:60@(E-O=7)C
M92!A9&1R97-S(@IM<V=S='(@(DEN9&ER:7IZ;R!S;W)G96YT92(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-34*;7-G
M:60@(E-O=71H($%F<FEC82(*;7-G<W1R(")3=60@069R:6-A(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E-O=71H($5U<F]P96%N("A)
M4T\M.#@U.2TS*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,#$*;7-G:60@(E-O=71H($=E;W)G:6$@
M86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*
M;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B96UI<V9E<F\@
M365R:61I;VYA;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C
M96QL<R(*;7-G<W1R(")3<&%Z:6\@=')A(&-E;&QE(&%I9&%C96YT:2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS
M9VED(")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL
M(@IM<V=S='(@(E-P87II;R!T<F$@:6P@8V]N=&5N=71O(&4@:6P@8F]R9&\@
M:6X@=6YA(&-E;&QA(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Q-0IM<V=I
M9"`B4W!A8V5R(@IM<V=S='(@(D1I<W1A;GII871O<F4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*;7-G:60@
M(E-P86-I;F<B"FUS9W-T<B`B4W!A>FEA='5R82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@(E-P
M86-I;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B4W!A>FEA='5R82!E(')I96UP
M:6UE;G1O(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z.#`*;7-G:60@(E-P86EN(@IM<V=S='(@(E-P86=N82(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#`*;7-G:60@(E-P86TB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C
M:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R("));G-E<FEM96YT;R!#87)A
M='1E<FD@4W!E8VEA;&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S
M='(@(E-E<&%R82!L82!C96QL82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M
M;B(*;7-G<W1R(")397!A<F$@;&$@8V]L;VYN82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@(E-P
M;&ET(')O=R(*;7-G<W1R(")397!A<F$@;&$@<FEG:&$B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-C$*;7-G:60@(E-P;W)T<R(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX."!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#$*
M;7-G:60@(E-R:2!,86YK82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C@Q(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-@IM<V=I
M9"`B4W1A;F1A<F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C8R"FUS9VED(")3=&%R(%1R96LB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(U.#8@;&EB+TAO<F1E+T9O<FTN<&AP.C(W.3$*;7-G
M:60@(E-T87)T('EE87(B"FUS9W-T<B`B06YN;R!D:2!P87)T96YZ82(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<Q"FUS9VED(")3=&%T92!O
M<B!0<F]V:6YC92(*;7-G<W1R(")3=&%T;R!O(%!R;W9I;F-I82(*"B,Z('1E
M;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T
M=7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(W.3<*;7-G
M:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(D9O<FUA=&\@9&D@;65M;W)I
M>GIA>FEO;F4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,PIM
M<V=I9"`B4W1R965T($%D9')E<W,B"FUS9W-T<B`B26YD:7)I>GIO(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I
M9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3(S,PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S,*;7-G:60@(E-T<FEP(&1O;6%I;B!F
M<F]M('1H92!A9&1R97-S(@IM<V=S='(@(E1O9VQI(&EL(&1O;6EN:6\@9&%L
M;"=I;F1I<FEZ>F\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G<W1R
M(")3=&EL92!;0U-372(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C(*;7-G:60@(E-U(@IM<V=S='(@(D1O(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(E-U
M8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")3;W1T;V1I
M<F5C=&]R>2!<(B5S7"(@;F]N('1R;W9A=&$N(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T
M<B`B3V=G971T;R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,S(@;&EB+TAO
M<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,Q.`IM<V=I9"`B4W5B;6ET(@IM<V=S
M='(@(E-O='1O;65T=&DB"@HC.B!S:6=N=7`N<&AP.C0Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"!<(B5S7"(@
M=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L;V<@:6X@=6YT:6P@>6]U<B`B
M"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G<W1R("(B"B)%)R!S
M=&%T82!I;G9I871A(&QA(')I8VAI97-T82!P97(@86=G:75N9V5R92!<(B5S
M7"(@86P@<VES=&5M82X@3F]N('!U;VD@(@HB86-C961E<F4@9FEN=&%N=&\@
M(&-H92!L82!R:6-H:65S=&$@;F]N('9I96YE(&%P<')O=F%T82XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R"FUS9VED
M(")3=6)S8W)I<'0B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$P-2!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP
M:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E
M<BYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D
M9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G<W1R(")<(B5S7"(@Z"!S
M=&%T;R!A9V=I=6YT;R!C;VX@<W5C8V5S<V\@86P@<VES=&5M82XB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S
M<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@
M<WES=&5M+B(*;7-G<W1R("(B"B),92!I;F9O<FUA>FEO;FD@<F5L871I=F4@
M86QL)W5T96YT92!<(B5S7"(@<V]N;R!S=&%T92!C86YC96QL871E(&-O;B`B
M"B)S=7-S97-S;R!D86P@<VES=&5M82XB"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R(")<
M(B5S7"(@96QI;6EN871A(&-O;B!S=6-C97-S;RXB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E
M;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B7"(E<UPB
M(')I;6]S<V\@8V]N('-U8V-E<W-O(&1A;"!S:7-T96UA+B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E
M<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM
M<V=S='(@(B(*(D-O;F9I9W5R87II;VYE(&EN=F5R=&ET82!C;VX@<W5C8V5S
M<V\N(%)I8V%R:6-A('!E<B!V961E<F4@:2!C86UB:6%M96YT:2XB"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B0V]P:6$@9&5L;&$@8V]N9FEG=7)A>FEO;F4@
M<V%L=F%T82!C;VX@<W5C8V5S<V\N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<V%V
M960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@
M(D-O<&EA(&1E;"!F:6QE(&1I(&-O;F9I9W5R87II;VYE(&1I("5S('-A;'9A
M=&$@8V]N('-U8V-E<W-O+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=7!D871E9"!<(B5S7"(B
M"FUS9W-T<B`B06=G:6]R;F%T;R!C;VX@<W5C8V5S<V\@7"(E<UPB(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E
M("5S(@IM<V=S='(@(E-C<FET=&\@8V]N('-U8V-E<W-O("5S(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,3$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-`IM<V=I
M9"`B4W5D86XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@IM<V=I9"`B4W5M;6%R>2(*;7-G
M<W1R(")3;VUM87)I;R(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV-0IM
M<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;G)I
M<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Q"FUS9VED(")3=6YN
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C`U"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I9"`B
M4W5N<FES92]3=6YS970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(P-`IM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#@*;7-G:60@(E-U
M;G-E="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C`W"FUS9VED(")3=6YS970Z("(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S"FUS9VED(")3=7!E
M<G-C<FEP="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S@P"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(E-U<'!O<G1O(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,3(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-0IM
M<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU-S4*;7-G:60@(E-U<FYA;64B"FUS9W-T<B`B4V]P<F%N
M;F]M92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,#D*;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(Q.0IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#4*;7-G:60@
M(E-W961E;B(*;7-G<W1R(")3=F5Z:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-@IM<V=I9"`B4W=I='IE<FQA;F0B
M"FUS9W-T<B`B4W9I>GIE<F$B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HX-@IM<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30U"FUS9VED(")3>6YC34PB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z.3<*;7-G
M:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B17)R
M;W)E(&1I('-I;G1A<W-I(&YE:2!T97)M:6YI(&1I(')I8V5R8V$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(Q-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$X"FUS
M9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B5"U3
M=&]R;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C0*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")4+5-T;W)M<R!%
M87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1&%T82]T<W8N<&AP.C$V
M-@IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B5&%B
M;&4@4')O<&5R=&EE<R(*;7-G<W1R(")0<F]P<FEE=.`@9&5L;&$@5&%B96QL
M82(*"B,Z(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W"FUS
M9VED(")486)L92!3970B"FUS9W-T<B`B26UP;W-T87II;VYE(&1E;&QA(%1A
M8F5L;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P97)T:65S(@IM<V=S='(@
M(E!R;W!R:65TX"!D96QL82!T86)E;&QA(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$Q(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S0*;7-G:60@
M(E1A:7=A;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,C4*;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$R(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,C`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-0IM
M<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU
M"FUS9VED(")487)G970Z(@IM<V=S='(@(D]B:65T=&EV;SHB"@HC.B!L:6(O
M2&]R9&4O2V]L86(N<&AP.CDS,B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`T
M.0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@Y"FUS9VED(")487-K
M<R(*;7-G<W1R(")!='1I=FETX"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3<T"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(DYU
M;65R;R!D:2!T96QE9F]N;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDW
M"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")496UP97)A
M='5R82!P97(@;"=U;'1I;6$@;W)A.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(R,0IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B5&5M<&5R871U
M<F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$R"FUS9VED
M(")496UP97)A='5R93H@(@IM<V=S='(@(E1E;7!E<F%T=7)A.B`B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@R"B,L('!H<"UF;W)M870*
M;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[
M)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U1E;7!L871E+G!H<#HV.34*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N
M9"XB"FUS9W-T<B`B36%S8VAE<F$@7"(E<UPB(&YO;B!T<F]V871A+B(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y"FUS9VED(")496UP;&%T92!!9&UI
M;FES=')A=&EO;B(*;7-G<W1R(")'97-T:6]N92!-87-C:&5R82(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,C$Q(&QI8B](;W)D92]&;W)M+G!H<#HS,S(W
M"FUS9VED(")497AT(@IM<V=S='(@(E1E<W1O(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,W.0IM<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@(E-O;&\@
M5&5S=&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@(D%L;&EN
M96%M96YT;R!T97-T;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I
M9"`B5&@B"FUS9W-T<B`B1VDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y
M-`IM<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,C$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-`IM<V=I9"`B
M5&AA:6QA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@V-`IM
M<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B3"=E<W1E;G-I;VYE($944"!N;VX@Z"!D:7-P;VYI8FEL92XB"@HC
M.B!L:6(O2&]R9&4O2&ES=&]R>2YP:'`Z-34*;7-G:60@(E1H92!(:7-T;W)Y
M('-Y<W1E;2!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B3&$@8W)O;FES=&]R:6$@
M9&5L('-I<W1E;6$@Z"!D:7-A8FEL:71A=&$N(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HY,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO
M;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<
M(B(*;7-G<W1R("));"!M;W1O<F4@9&D@:6YT96=R87II;VYE($AO<F1E+TMO
M;&%B(&YO;B!S=7!P;W)T82!<(B5S7"(B"@HC.B!L:6(O3F5T+TE-4U`O0F]O
M:RYP:'`Z,3(Y.`IM<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I
M;FET:6%L:7IE9"XB"FUS9W-T<B`B26P@;&]G(&1I($E-4U`@;F]N('!U\B!E
M<W-E<F4@:6YI>FEA;&EZ>F%T;RXB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N
M;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B3&$@8VQA<W-E($UA:6YT
M96YA;F-E.CH@;F]N(.@@<W1A=&$@8V%R:6-A=&$@8V]N('-U8V-E<W-O(@H*
M(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I9"`B
M5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM<V=S
M='(@(DQA(&9I;FES=')A(&1E;&QE($]P>FEO;FD@<VD@Z"!C:&EU<V$N(%5S
M8VER92XB"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C$X.2!L:6(O2&]R9&4O
M4&5R;7,N<&AP.C(P,"!L:6(O2&]R9&4O4&5R;7,N<&AP.C(Q,0HC.B!L:6(O
M2&]R9&4O4&5R;7,N<&AP.C(R,R!L:6(O2&]R9&4O4&5R;7,N<&AP.C(S-"!L
M:6(O2&]R9&4O4&5R;7,N<&AP.C(U,@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP
M.C(V-"!L:6(O2&]R9&4O4&5R;7,N<&AP.C,P,PIM<V=I9"`B(@HB5&AE(&%D
M;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E
M<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI
M<W-I;VYS+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M('-I
M9&4@;VYL>2(*;7-G<W1R(")3;VQA;65N=&4@:6P@;&%T;R!I;F9E<FEO<F4B
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED
M("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L
M(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A
M<V4N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z-3$*;7-G:60@(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@
M861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(DEL(&-O;G1A
M='1O(.@@<W1A=&\@86=G:75N=&\@8V]N('-U8V-E<W-O(&%L;&$@='5A(')U
M8G)I8V$N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$W,@IM<V=I
M9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I
M9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T
M('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE
M(&1A=&%B87-E+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@
M=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@(DYO;B#H('-T871A('-P96-I
M9FEC871A(&QA(&QI<W1A(&1I(&1I<W1R:6)U>FEO;F4N(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+G!H<#HQ,38*;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E871U
M<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@
M(DQA(&9U;GII;VYE(&1I(&-I9G)A='5R82!R:6-H:65D92!U;F$@8V]N;F5S
M<VEO;F4@=V5B('-I8W5R82XB"@HC.B!L:6(O2&]R9&4N<&AP.C$X-B!L:6(O
M2&]R9&4N<&AP.C4R.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E
M<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@(DEL(&9I
M;&4@)7,@9&]V<F5B8F4@8V]N=&5N97)E('5N82`E<R!I;7!O<W1A>FEO;F4N
M(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-SD@;&EB+TAO<F1E+G!H<#HU,3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@
M<V]M92`E<R!S971T:6YG<RXB"FUS9W-T<B`B26P@9FEL92`E<R!D;W9R96)B
M92!C;VYT96YE<F4@86QC=6YE("5S(&EM<&]S=&%Z:6]N:2XB"@HC.B!L:6(O
M2&]R9&4O1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@
M;F\@9&%T82XB"FUS9W-T<B`B26P@9FEL92!N;VX@8V]N=&EE;F4@:6YF;W)M
M87II;VYI+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP
M.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@
M=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R("(B"B),92!S
M96=U96YT:2!S;VYO(&QE(&EN=&5S=&%Z:6]N:2!P97(@<75E<W1O(&UE<W-A
M9V=I;R]R9F,X,C(@;65S<V%G9VEO+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C
M<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT
M97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W
M92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E
M<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N
M8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB
M>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H
M870@>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G
M(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE
M9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T
M<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<')E9G,N<&AP.C$Q,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(DPG
M:61E;G1I=.`@7"(E<UPB(.@@<W1A=&$@8V%M8V5L;&%T82XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<V"FUS
M9VED(")4:&4@;&5F="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ-3<*;7-G:60@(B(*(E1H92!L;V-A
M=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE
M($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M34E-12]-1$XN<&AP.C(P,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@
M;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<(B5S7"(@
M:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R86YT964@
M=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<W"FUS9VED
M(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E
M('!A9V4B"FUS9W-T<B`B(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HT-S0*;7-G
M:60@(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS
M9W-T<B`B26P@;G5M97)O(&1E:2!C86UP:2!D979E(&5S<V5R92!D:2!T:7!O
M(&YU;65R:6-O+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(S
M,@IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T
M:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B26P@;6]D
M=6QO(&]P96YS<VP@Z"!R:6-H:65S=&\@<&5R(&QA(&-L87-S92!(;W)D95]#
M<GEP=%]S;6EM93HZ+B(*"B,Z(&QI8B](;W)D92]0<F5F<RYP:'`Z,CDU"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C
M;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T
M:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"B),82!P
M<F5F97)E;GIA(%PB)7-<(B!N;VX@<'7R(&5S<V5R92!S86QV871A('!E<F-H
MZ"!L)VEN9F]R;6%Z:6]N92!C;VYT96YU=&$@(@HB96-C961E(&QA(&UA<W-I
M;6$@9&EM96YS:6]N92!D:7-P;VYI8FEL92(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]D96(N<&AP.C,R(&QI8B](;W)D92]-24U%+U9I97=E<B]E;G-C
M<FEP="YP:'`Z,S4*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS97AC96PN
M<&AP.C,R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N
M<&AP.C,R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E
M("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R("(B
M"B));"!P<F]G<F%M;6$@=7-A=&\@<&5R('9I<W5A;&EZ>F%R92!Q=65S=&\@
M=&EP;R!D:2!I;F9O<FUA>FEO;F4@*"5S*2!N;VX@Z"`B"B)S=&%T;R!T<F]V
M871O(&YE;"!S:7-T96UA+B(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z-#@W"FUS
M9VED(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C
M:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A
M;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H
M92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!L:6(O1FEL
M92]#4U8N<&AP.C0W.0IM<V=I9"`B5&AE('-E<&%R871O<B!M=7-T(&)E(&]N
M92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("));"!S
M97)V97(@7"(E<UPB(.@@<W1A=&\@96QI;6EN871O+B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]R<&-S=6TN<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!S97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R("));"!S
M97)V97(@7"(E<UPB(.@@<W1A=&\@<V%L=F%T;RXB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U
M97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R("),82!R:6-H
M:65S=&$@9&D@:7-C<FEZ:6]N92!P97(@)7,@Z"!S=&%T82!R:6UO<W-A+B(*
M"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-#<P"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!S<&5C:69I960@<F]W("@E9"D@9&]E
M<R!N;W0@97AI<W0N(@IM<V=S='(@(DQA(')I9V$@<W!E8VEF:6-A=&$@*"5D
M*2!N;VX@97-I<W1E+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HQ-SD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S
M(&YO="!E>&ES="XB"FUS9W-T<B`B26P@9FEL92!T96UP;W)A;F5O(%PB)7-<
M(B!N;VX@97-I<W1E+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,S`R"FUS
M9VED(")4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T
M97AT(&]N('1H92!S8W)E96XN(@IM<V=S='(@(DEL('1E<W1O(&1I9VET871O
M(&YO;B!C;W)R:7-P;VYD92!A;"!T97-T;R!S=6QL;R!S8VAE<FUO+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-SD*;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]$871A+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO
M861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*
M;7-G<W1R("),)VEN9F]R;6%Z:6]N92!C87)I8V%T82#H('-T871A('!E<G-A
M('-I;B!D86QL)W5L=&EM;R!P87-S;RXB"@HC.B!L:6(O2&]R9&4O1&%T82]C
M<W8N<&AP.C(V,B!L:6(O2&]R9&4O1&%T82]T<W8N<&AP.C$W,@IM<V=I9"`B
M5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R
M("));"!F:6QE(&-A<FEC871O(&YO;B!P=?(@97-S97)E('-A;'9A=&\N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Y(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ,3`*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B
M;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!U=&EL+VEC
M;VY?8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE;65S
M(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("),82!D:7)E
M8W1O<GD@9&5I('1E;6D@7"(E<UPB(&YO;B#H('-T871A('1R;W9A=&$N(@H*
M(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ-S@*;7-G:60@(E1H97)E(&%R
M92!N;R!O<'1I;VYS(&%V86EL86)L92XB"FUS9W-T<B`B3F]N(&-I('-O;F\@
M;W!Z:6]N:2!D:7-P;VYI8FEL:2XB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT
M96YT<RYP:'`Z,S4P"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C
M86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B3F]N(&-I('-O;F\@
M<&%R=&D@8VAE('!O<W-O;F\@97-S97)E('9I<W5A;&EZ>F%T92!I;FQI;F4N
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,#$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI
M<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y
M;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*(D-I('-O
M;F\@=')O<'!I(&-A<F%T=&5R:2!I;B!Q=65S=&\@8V%M<&\N($AA:2!D:6=I
M=&%T;R`E<R!C87)A='1E<FD[(&1E=FD@(@HB9&EG:71A<F4@=6X@;G5M97)O
M(&1I(&-A<F%T=&5R:2!M:6YO<F4@9&D@)7,N(@H*(SH@<VEG;G5P+G!H<#HU
M,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@
M)7,B"FUS9W-T<B`B0VD@<V]N;R!A;&-U;FD@<')O8FQE;6D@;F5L;"=A9V=I
M=6YG97)E(%PB)7-<(B!A;"!S:7-T96UA.B`E<R(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B
M;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y
M<W1E;3H@(@IM<V=S='(@(B(*(D,GZ"!S=&%T;R!U;B!P<F]B;&5M82!N96P@
M8V%N8V5L;&%R92!L92!I;F9O<FUA>FEO;FD@<&5R(&PG=71E;G1E(%PB)7-<
M(B!D86P@(@HB<VES=&5M83H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I
M;F<@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(D,GZ"!S=&%T
M;R!U;B!P<F]B;&5M82!N96P@<FEM=6]V97)E(%PB)7-<(B!D86P@<VES=&5M
M83H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@7"(E<UPB.B`E<R(*
M;7-G<W1R(")#)^@@<W1A=&\@=6X@<')O8FQE;6$@;F5L;"=A9V=I;W)N86UE
M;G1O(&1I(%PB)7-<(CH@)7,B"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z
M.3(U"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@
M=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB"FUS
M9W-T<B`B(@HB0R?H('-T871O('5N('!R;V)L96UA(&-O;B!I;"!C87)I8V%M
M96YT;R!D96P@9FEL93H@3F5S<W5N("5S(.@@<W1A=&\@(@HB8V%R:6-A=&\N
M(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDS,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*
M(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B"B)#)^@@<W1A
M=&\@=6X@<')O8FQE;6$@8V]N(&EL(&-A<FEC86UE;G1O(&1E;"!F:6QE.B!)
M;"`E<R!E<F$@<&GY(&QU;F=O(&1E;&QA("(*(FUA<W-I;6$@9&EM96YS:6]N
M92!P97)M97-S82`H)60@8GET97,I+B(*"B,Z(&QI8B](;W)D92]"<F]W<V5R
M+G!H<#HY,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@
M<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY
M('!A<G1I86QL>2!U<&QO861E9"XB"FUS9W-T<B`B(@HB0R?H('-T871O('5N
M('!R;V)L96UA(&-O;B!I;"!C87)I8V%M96YT;R!D96P@9FEL93H@26P@)7,@
MZ"!S=&%T;R!C87)I8V%T;R`B"B)S;VQO('!A<GII86QM96YT92XB"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B
M"FUS9W-T<B`B(@HB0R?H('-T871O('5N(&5R<F]R92!N96QL82!V:7-U86QI
M>GIA>FEO;F4@9&D@<75E<W1A('!A<G1E(&1E;"!M97-S86=G:6\B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`B0R?H
M('-T871O('5N(&5R<F]R92!N96QL)VEM<&]R=&%R92!L92!I;F9O<FUA>FEO
M;FD@9&5L(&-O;G1A='1O+B(*"B,Z(&QI8B](;W)D92]$871A+VEM8RYP:'`Z
M,S$*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#
M86QE;F1A<B!D871A+B(*;7-G<W1R(")#)^@@<W1A=&\@=6X@97)R;W)E(&YE
M;&PG:6UP;W)T87)E(&QE(&EN9F]R;6%Z:6]N:2!D:2!I0V%L96YD87(N(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HX,@IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA
M<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@
M(B(*(D,GZ"!S=&%T;R!U;B!E<F]R92!N96QL82!F;W)M(&1I(&-O;F9I9W5R
M87II;VYE+B!0<F]B86)I;&UE;G1E(&AA:2`B"B)D:6UE;G1I8V%T;R!U;B!C
M86UP;R!R:6-H:65S=&\N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O
M<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L
M96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(D,GZ"!S=&%T
M;R!U;B!E<G)O<F4@;F5L;"=E<V5G=6ER92!L82!S<&5C:69I8V$@9G5N>FEO
M;F4@9&5L;&$@<G5B<FEC82X@4VD@(@HB<')E9V$@9&D@<FEP<F]V87)E('!I
M^2!T87)D:2XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C0P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE
M(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS
M9W-T<B`B(@HB0R?H('-T871O('5N(&5R<F]R92!N96QL)V%G9VEO<FYA;65N
M=&\@9&5I(&1E='1A9VQI(&1E;"!C;VYT871T;RX@4VD@<')E9V$@(@HB9&D@
M<')O=F%R92!P:?D@=&%R9&DN(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8T-2!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,C(R"FUS
M9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R
M:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R
M("(B"B)#)^@@<W1A=&\@=6X@97)R;W)E(&YE;&PG86=G:6]R;F%M96YT;R!D
M96QL82!L:7-T82!D:2!D:7-T<FEB=7II;VYE+B!3:2`B"B)P<F5G82!D:2!P
M<F]V87)E('!I^2!T87)D:2XB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,30X"FUS9VED(")4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T
M('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R(")1=65S=&\@<V5R
M=F5R($E-05`@;F]N('-U<'!O<G1A(&QA(&-O;F1I=FES:6]N92!D:2!C87)T
M96QL92XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HT.`IM
M<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@
M87)C:&EV92XB"FUS9W-T<B`B475E<W1O('-E;6)R82!N;VX@97-S97)E('5N
M(&%R8VAI=FEO(&1I('1I<&\@<F%R('9A;&ED;RXB"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO="!A
M<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B475E<W1O
M('-E;6)R82!N;VX@97-S97)E('5N(&9I;&4@9&D@=&EP;R!Z:7`@=F%L:61O
M+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3(W"FUS9VED(")4:&ES(&1O
M97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T
M<B`B475E<W1O(&YO;B!S96UB<F$@97-S97)E('5N(&YU;65R;R!D:2!C87)T
M82!V86QI9&\N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HQ.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C
M;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM
M<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ,S0*;7-G
M:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W
M87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"FUS9VED("(B"B)4:&ES(&1R
M:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S
M;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U
M<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O
M=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G
M:"!T:&4@5F]D869O;F4@271A;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A
M9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I
M=&@@(@HB5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDW."!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3`U-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`X-@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3$Q-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$X,B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3(U-@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3,P-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,Y."!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,34U-PHC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@S.2!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3DU."!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`P-0HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C`R.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`W."!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C$T.0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C(R,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0P."!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C0U,`HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C8S-R!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C@Q,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$Q.0HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,S(Y-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,S@P-2!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,S@Q,PIM<V=I9"`B5&AI<R!F:65L9"!I<R!R
M97%U:7)E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P
M-C4*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R
M<RXB"FUS9W-T<B`B(%%U97-T;R!C86UP;R!P=?(@8V]N=&5N97)E('-O;&\@
M:6YT97)I+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-#$V"FUS9VED(")4
M:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O
M;&]N+B(*;7-G<W1R("(@475E<W1O(&-A;7!O('!U\B!C;VYT96YE<F4@<V]L
M;R!N=6UE<FD@92!D=64@<'5N=&DN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$P.30*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A
M;"!V86QU97,N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,3(S"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C
M92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B"B)1=65S
M=&\@8V%M<&\@<'7R(&5S<V5R92!S;VQO('5N82!L:7-T82!D:2!I;G1E<FD@
M<V%P87)A=&D@9&$@=FER9V]L82!O('-P87II;R(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HY.#D*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED
M(&YU;6)E<BXB"FUS9W-T<B`B475E<W1O(&-A;7!O(&1E=F4@97-S97)E('5N
M(&YU;65R;R!V86QI9&\N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,3@*
M;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D
M92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S
M-&%F)RXB"FUS9W-T<B`B(@HB475E<W1O(&-A;7!O(&1E=F4@8V]N=&5N97)E
M('5N(&-O;&]R;R!I;B!F;W)M871O(%)'0B!E<V%D96-I;6%L92P@860@97-E
M;7!I;R`B"B(G(S$R,S1A9B<N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C4V
M,0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D
M+B(*;7-G<W1R(")1=65S=&$@9F]R;2#H(&=I82!S=&%T82!P<F]C97-S871A
M+B(*"B,Z('1E;7!L871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@(E%U97-T;R#H("5S+B(*
M"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#8Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V
M:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI
M96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M
M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S
M92!V:7-I="`E<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT
M96YT<RYP:'`Z-3DY"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@;65S<V%G
M92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T
M:&%N('EO=7(@;W=N+B(*;7-G<W1R("(B"B)1=65S=&\@;65S<V%G9VEO(.@@
M<W1A=&\@<V-R:71T;R!I;B!U;B!S970@9&D@8V%R871T97)I("@E<RD@9&EV
M97)S;R!D86P@='5O+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3(V
M"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS
M9W-T<B`B475E<W1O(&YU;65R;R!D979E(&5S<V5R92!U;FEC;RXB"@HC.B!L
M:6(O2&]R9&4O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R
M=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G
M<W1R(")1=65S=&\@<V5R=F5R(&YO;B!P=?(@9&5C;VUP<FEM97)E(&9I;&4@
M:6X@9F]R;6%T;R!Z:7`@92!G>FEP+B(*"B,Z(&QI8B](;W)D92]296=I<W1R
M>2YP:'`Z,3@Y"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A
M8W1I=F%T960N(@IM<V=S='(@(D%L(&UO;65N=&\@<75E<W1O('-I<W1E;6$@
M;F]N(.@@871T:79O+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3(T
M"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@
M(E%U97-T;R!V86QO<F4@9&5V92!E<W-E<F4@=6X@;G5M97)O+B(*"B,Z('-E
M<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@
M=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B
M"FUS9W-T<B`B475E<W1A(&9I;F5S=')A(&1E=F4@97-S97)E(&-H:6%M871A
M(&1A('5N82!F:6YE<W1R82!D96QL92!/<'II;VYI(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E1H=6YD97(B
M"FUS9W-T<B`B5'5O;F\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C,V"FUS9VED(")4:6-K971S(@IM<V=S='(@(D)I9VQI971T:2(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR-#(U('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(U-0IM<V=I9"`B5&EM92(*;7-G<W1R(")/<F$B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S@X"FUS9VED(")4:6UE(%1R86-K:6YG(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM
M92!F;W)M870B"FUS9W-T<B`B1F]R;6%T;R!D96QL)V]R82(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR-3,Q"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G
M<W1R(")396QE>FEO;F4@9&5L;"=O<F$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,P"FUS9VED(")4:6UO<BU,97-T
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HR,"!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(R.0IM<V=I9"`B5&ET;&4B
M"FUS9W-T<B`B5&ET;VQO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW
M-0IM<V=I9"`B5&\B"FUS9W-T<B`B02(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HV-30*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT
M:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M
M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*
M(E!E<B!S96QE>FEO;F5R92!P:?D@=F]C:2P@=&EE;FD@<')E;75T;R!I;"!T
M87-T;R!#;VYT<F]L("A00RD@;R!#;VUM86YD("(*(BA-86,I(&UE;G1R:2!S
M=&%I(&-L:6-C86YD;RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S`P"FUS9VED(")4;V1A>2(*;7-G<W1R(")/9V=I(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G
M9VQE($A434P@4V]U<F-E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C,*;7-G:60@(E1O9V\B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(R-@IM<V=I9"`B5&]K96QA=2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`R"FUS9VED(")4;VUO<G)O=R(*
M;7-G<W1R(")$;VUA;FDB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C(Y"FUS9VED(")4;VYG82(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O075T:"]K;VQA8BYP:'`Z,3`T"FUS9VED(")4;V\@;6%N
M>2!I;G9A;&ED(&QO9VEN<R!D=7)I;F<@=&AE(&QA<W0@;6EN=71E<RXB"FUS
M9W-T<B`B5')O<'!E(&%C8V5S<VD@;F]N('9A;&ED:2!D=7)E;G1E(&=L:2!U
M;'1I;6D@;6EN=71I+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX,0IM<V=I9"`B5&]P(@IM<V=S='(@(D%L=&\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS
M"FUS9VED(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I9"`B5')A;G-L871I;VYS(@IM<V=S
M='(@(E1R861U>FEO;FDB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C,R"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-SDP"FUS9VED
M(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@(E9E<F\@;R!F86QS;R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3<*;7-G:60@
M(E1U(@IM<V=S='(@(DUA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(R.`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(R.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C,Q"FUS9VED(")4=7)K97DB"FUS9W-T<B`B5'5R8VAI82(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY
M*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C(W"FUS9VED(")4=7)K;65N:7-T86XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(R,`IM<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,S,*;7-G:60@(E1U=F%L=2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R
M(")$:6=I=&$@;&$@='5A('-C96QT83H@(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(U.`IM<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W(&QI8B](;W)D92]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,C0Y"FUS9VED(")54DPB"FUS9W-T<B`B(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T,0IM<V=I9"`B
M55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.3<*;7-G:60@(E523#HB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,S(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-PIM<V=I9"`B56=A
M;F1A(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,S8*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B(@H*
M(SH@;&EB+U9&4R]F:6QE+G!H<#HT,C4*;7-G:60@(E5N86)L92!T;R!A8V-E
M<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B26UP;W-S:6)I;&4@86-C961E
M<F4@86QL82!D:7)E8W1O<GD@5D93+B(*"B,Z(&QI8B](;W)D92]!=71H+U-I
M9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I
M;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(B(*(DEM<&]S
M<VEB:6QE(&%G9VEU;F=E<F4@86QT<F4@:6YF;W)M87II;VYI('-U9VQI('5T
M96YT:2!M96YT<F4@9'5R86YT92!L82`B"B)S;W1T;W-C<FEZ:6]N92XB"@HC
M.B!L:6(O5D93+V9T<"YP:'`Z,SDV"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R("));7!O<W-I8FEL92!C86UB:6%R92!I('!E<FUE<W-I('!E
M<B!I;"!F:6QE(%9&4R!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS
M.3@@;&EB+U9&4R]M=7-Q;"YP:'`Z-#@P"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O
M)7,N(@IM<V=S='(@(DEM<&]S<VEB:6QE(&-A;6)I87)E(&D@<&5R;65S<VD@
M<&5R(&EL(&9I;&4@5D93("5S+R5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW
M.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E
M<RXB"FUS9W-T<B`B26UP;W-S:6)I;&4@8V%M8FEA<F4@82`E<RXB"@HC.B!L
M:6(O5D93+V9T<"YP:'`Z,C,W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<UPB+B(*;7-G<W1R("));7!O
M<W-I8FEL92!V97)I9FEC87)E(&QA(&1I;65N<VEO;F4@9&D@7"(E<UPB+B(*
M"B,Z(&QI8B]61E,O9FEL92YP:'`Z-S`W(&QI8B]61E,O<W%L+G!H<#HQ,#0P
M(&QI8B]61E,O<W%L7V9I;&4N<&AP.C@W.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS
M9W-T<B`B26UP;W-S:6)I;&4@=F5R:69I8V%R92!L82!D:6UE;G-I;VYE(&1I
M(%PB)7,O)7-<(BXB"@HC.B!L:6(O2&]R9&4O075T:"]S<6PN<&AP.C0S.0IM
M<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T
M<B`B26UP;W-S:6)I;&4@8V]N;F5T=&5R<VD@86P@<V5R=F5R(%-13"XB"@HC
M.B!L:6(O5D93+V9T<"YP:'`Z.#@S"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C
M="!W:71H(%-33"XB"FUS9W-T<B`B26UP;W-S:6)I;&4@8V]N;F5T=&5R<VD@
M8V]N(%-33"XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(S."!L:6(O5D93+V9I
M;&4N<&AP.C(T,R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR,30*(SH@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z,C$Y(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(R-PIM
M<V=I9"`B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(DEM<&]S
M<VEB:6QE(&-O<&EA<F4@:6P@9FEL92!61E,N(@H*(SH@;&EB+U9&4R]F='`N
M<&AP.C,W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E
M(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("));7!O<W-I8FEL92!C
M<F5A<F4@;&$@9&ER96-T;W)Y(%9&4R!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F
M:6QE+G!H<#HS-C<@;&EB+U9&4R]M=7-Q;"YP:'`Z,C<P(&QI8B]61E,O<W%L
M7V9I;&4N<&AP.C(W-`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER
M96-T;W)Y+B(*;7-G<W1R("));7!O<W-I8FEL92!C<F5A<F4@;&$@9&ER96-T
M;W)Y(%9&4RXB"@HC.B!L:6(O5D93+VUU<W%L+G!H<#HQ,C0*;7-G:60@(E5N
M86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(DEM<&]S<VEB:6QE
M(&-R96%R92!I;"!F:6QE(%9&4RXB"@HC.B!L:6(O5D93+W-M8BYP:'`Z,CDT
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9O
M;&1E<B!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<VEB:6QE(&-R96%R92!L82!C
M87)T96QL82!61E,@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C<X
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G
M<W1R("));7!O<W-I8FEL92!C<F5A<F4@:6P@9FEL92!61E,@=G5O=&\N(@H*
M(SH@;&EB+TAO<F1E+T-O;7!R97-S+V=Z:7`N<&AP.C<Y(&QI8B](;W)D92]#
M;VUP<F5S<R]T87(N<&AP.C<V"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S
M<R!D871A+B(*;7-G<W1R("));7!O<W-I8FEL92!D96-O;7!R:6UE<F4@;&4@
M:6YF;W)M87II;VYI+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS,#,@;&EB+U9&
M4R]S;6(N<&AP.C(R.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN(@IM
M<V=S='(@(DEM<&]S<VEB:6QE(&5L:6UI;F%R92!<(B5S7"(L(&QA(&1I<F5C
M=&]R>2!N;VX@Z"!V=6]T82XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D
M;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R("));7!O<W-I
M8FEL92!E;&EM:6YA<F4@7"(E<UPB.B`E<RXB"@HC.B!L:6(O5D93+V9I;&4N
M<&AP.C,T-"!L:6(O5D93+VUU<W%L+G!H<#HS,C,@;&EB+U9&4R]S<6PN<&AP
M.C0P-PHC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS-S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I
M<R!N;W0@96UP='DB"FUS9W-T<B`B26UP;W-S:6)I;&4@96QI;6EN87)E("5S
M+"!L82!D:7)E8W1O<GD@;F]N(.@@=G5O=&$B"@HC.B!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HS.#0@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S@X"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM
M<V=S='(@(DEM<&]S<VEB:6QE(&5L:6UI;F%R92!L82!D:7)E8W1O<GD@5D93
M(&EN(&UO9&\@<FEC;W)S:79O+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S4P
M(&QI8B]61E,O;75S<6PN<&AP.C,S-"!L:6(O5D93+VUU<W%L+G!H<#HS-#<*
M(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,S4U(&QI8B]61E,O<W%L7V9I;&4N<&AP
M.C,X,`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*
M;7-G<W1R("));7!O<W-I8FEL92!E;&EM:6YA<F4@;&$@9&ER96-T;W)Y(%9&
M4RXB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z-#,R(&QI8B]61E,O<W%L+G!H<#HT
M-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B26UP;W-S:6)I;&4@96QI;6EN87)E
M(&QA(&1I<F5C=&]R>2!61E,Z("5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HR
M,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M9FEL92!<(B5S7"(N(@IM<V=S='(@(DE-<&]S<VEB:6QE(&5L:6UI;F%R92!I
M;"!F:6QE(%9&4R!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS,38@
M;&EB+U9&4R]M=7-Q;"YP:'`Z,38W(&QI8B]61E,O;75S<6PN<&AP.C$X,`HC
M.B!L:6(O5D93+VUU<W%L+G!H<#HQ.#<@;&EB+U9&4R]S<6PN<&AP.C(Y,2!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HT,3D*(SH@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z-#(W"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G
M<W1R("));7!O<W-I8FEL92!E;&EM:6YA<F4@:6P@9FEL92!61E,N(@H*(SH@
M;&EB+U9&4R]S;6(N<&AP.C(T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("));7!O
M<W-I8FEL92!E;&EM:6YA<F4@;&$@8V%R=&5L;&$@5D93(%PB)7-<(BXB"@HC
M.B!L:6(O5D93+W-Q;"YP:'`Z-#(Q"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B
M26UP;W-S:6)I;&4@96QI;6EN87)E(%9&4R!I;B!M;V1O(')I8V]R<VEV;SH@
M)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@T-PIM<V=I9"`B56YA8FQE('1O
M(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`B26UP;W-S
M:6)I;&4@9&5T97)M:6YA<F4@;&$@9&ER96-T;W)Y(&%T='5A;&4N(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,#0*;7-G:60@(E5N86)L92!T
M;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B26UP;W-S
M:6)I;&4@97-T87)R92!I(&1E='1A9VQI(&1E;"!C97)T:69I8V%T;R(*"B,Z
M(&QI8B].970O24U34"YP:'`Z-#,W(&QI8B].970O24U34"]!=71H+G!H<#HQ
M,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E
M9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(DEM<&]S<VEB:6QE(&-A<FEC87)E
M(&QA(&1E9FEN:7II;VYE(&1I("5S+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z
M,C`X(&QI8B]61E,O9FEL92YP:'`Z,C$S(&QI8B]61E,O<W%L7V9I;&4N<&AP
M.C$W.0HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ.#0*;7-G:60@(E5N86)L
M92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R("));7!O<W-I8FEL92!S<&]S
M=&%R92!I;"!F:6QE(%9&4RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z.3@@;&EB
M+U9&4R]S;6(N<&AP.CDS(&QI8B]61E,O<VUB+G!H<#HQ,#8*(SH@;&EB+U9&
M4R]S;6(N<&AP.C8V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<VEB:6QE(&%P
M<FER92!I;"!F:6QE(%9&4R!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H
M<#HR.3`@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3,X(&QI8B]61E,O<W%L7V9I
M;&4N<&AP.C$T,0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R
M('=R:71I;F<N(@IM<V=S='(@(DEM<&]S<VEB:6QE(&%P<FER92!I;"!F:6QE
M(%9&4R!P97(@;&$@<V-R:71T=7)A+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z
M.#,@;&EB+U9&4R]F:6QE+G!H<#HQ,S<@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z
M-S8*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R("))
M;7!O<W-I8FEL92!A<')I<F4@:6P@9FEL92!61E,N(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O<&5N
M(&-O;7!R97-S960@87)C:&EV92XB"FUS9W-T<B`B26UP;W-S:6)I;&4@87!R
M:64@;"=A<F-H:79I;R!C;VUP<F5S<V\N(@H*(SH@;&EB+U9&4RYP:'`Z.#4V
M"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F
M86EL960I+B(*;7-G<W1R("));7!O<VEB:6QE(&QE9V=E<F4@:6P@9FEL92!6
M1E,@*&9I;&5S:7IE(&9I;&4H*2!F86EL960I+B(*"B,Z(&QI8B]61E,N<&AP
M.C@X-PIM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53
M:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B26UP;W-S:6)I;&4@;&5G9V5R92!I
M;"!F:6QE(%9&4R`H9V5T1FEL95-I>F4H*2!F86EL960I+B(*"B,Z(&QI8B](
M;W)D92]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`IM<V=I9"`B56YA8FQE
M('1O(')E860@9FEL93H@(@IM<V=S='(@(DEM<&]S<VEB:6QE(&QE9V=E<F4@
M:6P@9FEL93H@(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HV.#@*;7-G:60@(E5N
M86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M26UP;W-S:6)I;&4@;&5G9V5R92!L82!D:7)E8W1O<GD@=F9S<F]O="XB"@HC
M.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$Q,#D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L
M9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*(DEM<&]S<VEB:6QE(')I
M;F]M:6YA<F4@)7,@:6X@)7,Z(&QA(&-A<G1E;&QA(&1I(&1E<W1I;F%Z:6]N
M92#H(&=I82!P<F5S96YT92(*"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,R
M,PIM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G
M<W1R("));7!O<W-I8FEL92!R:6YO;6EN87)E(&QA(&1I<F5C=&]R>2!61E,N
M(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C,T-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R
M("));7!O<W-I8FEL92!R:6YO;6EN87)E(&QA(&1I<F5C=&]R>2!61E,Z("5S
M+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS-3$@;&EB+U9&4R]S;6(N<&AP.C(W
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S:6)I;&4@<FEN;VUI;F%R92!I
M;"!F:6QE(%9&4R!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HV,CD@
M;&EB+U9&4R]M=7-Q;"YP:'`Z,C0Q"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(DEM<&]S
M<VEB:6QE(')I;F]M:6YA<F4@:6P@9FEL92!61E,@)7,O)7,N(@H*(SH@;&EB
M+U9&4R]M=7-Q;"YP:'`Z,C$S(&QI8B]61E,O;75S<6PN<&AP.C0V-"!L:6(O
M5D93+W-Q;"YP:'`Z,S,X"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,Q-2!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HS,S<*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@5D93(&9I;&4N(@IM<V=S='(@(DEM<&]S<VEB:6QE(')I;F]M:6YA<F4@
M:6P@9FEL92!61E,N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O;6MI<V]F<RYP
M:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R
M("));7!O<W-I8FEL92!E<V5G=6ER92`G;6MI<V]F<R<N(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L92!T
M;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(DEM<&]S
M<VEB:6QE('1R861U<G)E('%U97-T;R!D;V-U;65N=&\@5V]R9"(*"B,Z(&QI
M8B](;W)D92]+;VQA8BYP:'`Z,3@Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@=')I9V=E<B!F<F5E+V)U<WD@=7!D871E(&9O<B`E<R(*;7-G
M<W1R("));7!O<W-I8FEL92!D87)E(&PG879V:6\@86QL)V%G9VEO<FYA;65N
M=&\@9G)E92]B=7-Y('!E<B`E<R(*"B,Z(&QI8B]61E,O9G1P+G!H<#HQ-30@
M;&EB+U9&4R]F='`N<&AP.C$U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("));7!O<W-I
M8FEL92!S8W)I=F5R92!I;"!F:6QE(%9&4R!<(B5S7"(N(@H*(SH@;&EB+U9&
M4R]F:6QE+G!H<#HQ.#8*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL
M92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(DEM<&]S<VEB:6QE('-C<FEV
M97)E(&EL(&9I;&4@5D93("AC;W!Y*"D@9F%I;&5D*2XB"@HC.B!L:6(O5D93
M+V9I;&4N<&AP.C(Y-"!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-#8@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z,34Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4@9&%T82XB"FUS9W-T<B`B26UP;W-S:6)I;&4@<V-R:79E<F4@;&4@
M:6YF;W)M87II;VYI(&YE;"!F:6QE(%9&4RXB"@HC.B!L:6(O5D93+G!H<#HX
M-C(*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL
M;"!B92!E>&-E961E9"XB"FUS9W-T<B`B26UP;W-S:6)I;&4@<V-R:79E<F4@
M:6P@9FEL92!61E,L(&QA('%U;W1A(&-O;G-E;G1I=&$@=F5R<N`@96-C961U
M=&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(E-O='1O;&EN96%T;R(*
M"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA
M;F=E<R(*;7-G<W1R(")!;FYU;&QA($UO9&EF:6-H92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E
M<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(DYO;B!F87)E(&QA('1U82!U
M;'1I;6$@87II;VYE(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C(R,2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@X"FUS
M9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE
M8W1I;VXZ("(*;7-G<W1R(")2:7-P;W-T82!I;F%T=&5S82!D86P@<V5R=F5R
M(&1U<F%N=&4@;&$@8V]N;F5S<VEO;F4Z("(*"B,Z(&QI8B](;W)D92])34%0
M+T%#3"]R9F,R,#@V+G!H<#HR,3<@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,S.0HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S<V(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#(*;7-G:60@
M(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R
M(")2:7-P;W-T82!I;F%T=&5S82!D86P@<V5R=F5R(&$Z("(*"B,Z(&QI8B](
M;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q"FUS9VED(")5;F9I
M;&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS
M9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(S-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<*;7-G:60@(E5N:71E
M9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S4*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S.`IM<V=I9"`B56YI=&5D($MI
M;F=D;VTB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S8*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(T,`IM<V=I9"`B56YI=&5D(%-T871E<R(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C,Y"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG
M($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HW
M."!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C(*;7-G:60@(E5N:71S
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP
M.C4X(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R.0HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HT,S`*;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`B4V-O
M;F]S8VEU=&\B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I
M+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A
M9V4@240I+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,30W"FUS9VED(")5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*
M;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS
M9W-T<B`B3F]M92!U=&5N=&4@92!P87-S=V]R9"!S8V]N;W-C:75T:2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B"FUS9W-T
M<B`B3F]N(&-O;&QE9V%R92!L)V5L96UE;G1O(&-O<G)E;G1E(@H*(SH@;&EB
M+TAO<F1E+TED96YT:71Y+G!H<#HS,#(*;7-G:60@(E5N;F%M960B"FUS9W-T
M<B`B4V5N>F$@;F]M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL96=E9"!S8W)I<'1S
M(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY
M(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@
M=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB<VAO=W,@
M>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B
M;V%R9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@IM<V=I9"`B56YS970@8V]L;W(B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV.#<@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HY,C<*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HY,S,*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*
M;7-G<W1R(")%<W1E;G-I;VYE(&YO;B!S=7!P;W)T871A(@H*(SH@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HQ.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z,S,*;7-G:60@(E5P9&%T92(*;7-G<W1R(")!9V=I;W)N82(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,CD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@(D%G9VEO<FYA("5S(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-@IM<V=I9"`B
M57!D871E('5S97(B"FUS9W-T<B`B06=G:6]R;F$@=71E;G1E(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@(D%G9VEO<FYA(%PB)7-<(BXB
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX,PIM<V=I9"`B57!G<F%D
M92!S8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B4V-R:7!T(&1I(&-A<FEC86UE
M;G1E(&5L:6UI;F%T82XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ.3@*;7-G:60@
M(E5P;&]A9"(*;7-G<W1R(")#87)I8V$B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3@U"FUS9VED(")5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T
M=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T<B`B8V%R:6-A=&D@='5T
M=&D@:2!F:6QE(&1I(&EM<&]S=&%Z:6]N92!D96QL92!A<'!L:6-A>FEO;FD@
M<W5L('-E<G9E<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C(P"FUS9VED(")5<'!E<B!L871I;B!L971T
M97)S(@IM<V=S='(@(F-A<F%T=&5R:2!L871I;FD@;6%I=7-C;VQI(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHQ.`IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R(").=6UE
M<FD@<F]M86YI(&UA:75S8V]L:2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR-#$*;7-G:60@(E5R=6=U87DB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z
M-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S
M='(@(G5S82!I;"!C;W)R96YT93H@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(E5S
M82!34TPB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(W"FUS9VED(")5
M<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R
M=F5R+B(*;7-G<W1R(")5<V$@<V4@:6P@;F]M92!U=&5N=&4O<&%S<W=O<F0@
MZ"!D:69F97)E;G1E(&1A('%U96QL82!D96P@<V5R=F5R($E-4U`N(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,0IM<V=I9"`B57-E
M<B(*;7-G<W1R(")5=&5N=&4B"@HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP
M.C<W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H
M;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B3'5T96YT92`E<R!N;VX@Z"!A=71O
M<FEZ>F%T;R!P97(@)7,N(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S"FUS9VED
M(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D=E<W1I;VYE(%5T96YT
M:2(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,C0U"FUS9VED(")5<V5R
M($]P=&EO;G,B"FUS9W-T<B`B3W!Z:6]N:2!5=&5N=&DB"@HC.B!S:6=N=7`N
M<&AP.C8R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R(")296=I
M<W1R87II;VYE(%5T96YT:2(*"B,Z('-I9VYU<"YP:'`Z,C(*;7-G:60@(E5S
M97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I
M=&4N(@IM<V=S='(@(DQA<F5G:7-T<F%Z:6]N92!D96=L:2!U=&5N=&D@Z"!S
M=&%T82!D:7-A8FEL:71A=&$@<&5R('%U97-T;R!S:71O+B(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HT.30*;7-G:60@(E5S97(@86-C;W5N="!N;W0@
M9F]U;F0B"FUS9W-T<B`B3F]M92!U=&5N=&4@;F]N('1R;W9A=&\B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8*(SH@;&EB+TYE="]335,O=F]D
M869O;F5I=&%L>5]S;71P+G!H<#HY."!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP
M:'`Z,34P"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,S('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z-S(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM<V=S='(@(DYO
M;64@571E;G1E(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HQ,C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E<UPB(&%L<F5A9'D@
M97AI<W1S+B(*;7-G<W1R(").;VUE(%5T96YT92!<(B5S7"(@Z"!G:6$@<')E
M<V5N=&4N(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@W"FUS
M9VED(")5<V5R;F%M93HB"FUS9W-T<B`B3F]M92!5=&5N=&4Z(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z("(*
M;7-G<W1R(").;VUE(%5T96YT93H@(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS
M9W-T<B`B571E;G1I(&YE;"!S:7-T96UA.B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#(*;7-G:60@(E5Z8F5K:7-T
M86XB"FUS9W-T<B`B(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ-S`@;&EB+U9&
M4R]F:6QE+G!H<#HR-C@*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@
M97AI<W0N(@IM<V=S='(@(DQA(&1I<F5C=&]R>2!61E,@;F]N(&5S:7-T92XB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3(P"FUS9VED(")686-A
M=&EO;B(*;7-G<W1R(")!<W-E;GIA(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C@V-@IM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*
M;7-G<W1R(")0;W-I>FEO;FD@=F%L:61E('1R;W9A=&4@:6YC;'5D;VYO.B`B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B5F%L
M:61I='DB"FUS9W-T<B`B5F%L:61I=.`B"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(U-2!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3DW"FUS9VED(")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*
M;7-G<W1R(")686QO<F4@:6X@;6EN=71I(&1A(&]R82XB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z.#4V(&QI8B](;W)D92]&;W)M+G!H<#HQ,3<W"B,L('!H
M<"UF;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N
M9W1H(&]F("5S+B(*;7-G<W1R("));"!V86QO<F4@Z"!M86=G:6]R92!D;&QA
M(&UA<W-I;6$@;'5N9VAE>GIA(&1I("5S+B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR,C0T(&QI8B](;W)D92]&;W)M+G!H<#HR,C8V(&QI8B](;W)D92]&
M;W)M+G!H<#HR,S$V"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.3$P(&QI8B](
M;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED(")686QU97,B
M"FUS9W-T<B`B5F%L;W)I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,#D@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(Q.#8*;7-G:60@(E9A;'5E<R!T;R!S96QE
M8W0@9G)O;2(*;7-G<W1R(")686QO<FD@9&%I('%U86QI('-E;&5Z:6]N87)E
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(T.0IM<V=I9"`B5F%N=6%T=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C,S"FUS9VED(")687)I86)L92(*;7-G<W1R
M(")687)I86)I;&4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,34@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C0U"FUS9VED(")696YE>G5E;&$B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF
M:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T
M86UP97)E9"!W:71H+B(*;7-G<W1R(")697)I9FEC82!F86QL:71A("T@<75E
M<W1O(&UE<W-A9V=I;R!P=?(@97-S97)E('-T871O(&%L=&5R871O(&-O;BXB
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B5F5R
M<VEO;B(*;7-G<W1R(")697)S:6]N92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR,C@*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R(")6
M97)S:6]N92!D:2!#;VYT<F]L;&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A
M;&EG;B(*;7-G<W1R(")!;&QI;F5A;65N=&\@=F5R=&EC86QE(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-`IM<V=I9"`B
M5F5R=&EC86P@<&%D9&EN9R(*;7-G<W1R(")2:65M<&EM96YT;R!V97)T:6-A
M;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`B5F5R=&EC86QE.B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED
M(")697)Y($AI9V@B"FUS9W-T<B`B36]L=&\@06QT;R(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#@*;7-G:60@(E9I
M970@3F%M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DW
M"FUS9VED(")6:65T;F%M97-E("A625-#24DI(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HY-S$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5FEE=R`E<R(*;7-G<W1R(")6:7-U86QI>GIA("5S(@H*(SH@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W
M96(@<&%G92(*;7-G<W1R(")6:7-U86QI>GIA('5N82!P86=I;F$@=V5B(&5S
M=&5R;F$B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#,P"B,L
M('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B5FES=6%L
M:7IZ82!C;VUE("5S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(T-@IM<V=I9"`B5FER9VEN($ES;&%N9',L($)R:71I
M<V@B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(T-PIM<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,38*;7-G:60@
M(E9I<VEB:6QI='DB"FUS9W-T<B`B5FES:6)I;&ETX"(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-3(*;7-G:60@(E9I<VEB:6QI='DZ("(*
M;7-G<W1R(")6:7-I8FEL:73@.B`B"@HC.B!L:6(O3F5T+U--4R]V;V1A9F]N
M96ET86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L>2!V:6$@
M4TU44"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T<B`B0514
M14Y:24].12(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L('!H
M<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y5
M04Q,62!&4D]-("5S+B(*;7-G<W1R(")!5%1%3EI)3TY%(2$A(%))355/5DD@
M3$\@4T-225!4($U!3E5!3$U%3E1%($1!("5S+B(*"B,Z(&QI8B].970O4TU3
M+W=I;E]H='1P+G!H<#HQ,S,*;7-G:60@(E=)3B!V:6$@2%144"(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C4P"FUS9VED(")786QL:7,@86YD($9U='5N82(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.34@;&EB+TAO<F1E+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]H=&UL+G!H<#HQ,C<*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B
M071T96YZ:6]N92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(DUE(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O<F5C
M87-T(@IM<V=S='(@(D)O;&QE='1I;F\@;65T96]R;VQO9VEC;R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,38*;7-G:60@(E=E871H97(@
M9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R(")";VQL971T:6YO(&UE=&5O<F]L
M;V=I8V\@9F]R;FET;R!D82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX.3(*
M;7-G:60@(E=E871H97(N8V]M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C,V"FUS9VED(")796(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0S.0IM<V=I9"`B5V5B(%-I=&4B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B
M5V5E:VQY(@IM<V=S='(@(E-E='1I;6%N86QM96YT92(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED(")796QC;VUE(@IM<V=S='(@
M(D)E;G9E;G5T;R(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-3<@
M=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(D)E;G9E;G5T;R!A("5S(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O
M<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64L
M("5S(@IM<V=S='(@(D)E;G9E;G5T;RP@)7,B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y.`IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3D*;7-G:60@(E=E<W1E
M<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW.`IM<V=I9"`B5V5S=&5R;B!3
M86AA<F$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L
M9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R(")1=6%L92!A<'!L
M:6-A>FEO;F4@9&]V<N`@=FES=6%L:7IZ87)E("5S(&1O<&\@;"=A8V-E<W-O
M/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7
M:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R(")1=6%L
M)^@@:6P@8V%R871T97)E(&1I(&1E;&EM:71A>FEO;F4_(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@:7,@=&AE('%U
M;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C4*;7-G:60@(E=H97)E:7,@075S=')A
M;&EA(&UA<"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*
M;7-G:60@(E=H:6-H('!H87-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3,V"FUS9VED(")7:&EC:"!P;'5G:6YS('1O(&5N86)L
M92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@(E%U86QE('!L
M=6=I;G,@86)I;&ET87)E('!E<B!I;"!2:6-H(%1E>'0@961I=&]R+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#0*;7-G:60@(E=I9'1H(@IM<V=S='(@(DQA<F=H97IZ82(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HS,3`W"FUS9VED(")7:61T:"!I;B!#4U,@=6YI=',B
M"FUS9W-T<B`B3&%R9VAE>GIA(&EN('5N:73@($-34R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@
M;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N
M97AT(&QO9RUI;BDZ(@IM<V=S='(@(B(*(DQA<F=H97IZ82!D96P@;65N=2!D
M:2`E<R!S=6QL82!S:6YI<W1R82`H879RX"!E9F9E='1O(&-O;"!P<F]S<VEM
M;R!A8V-E<W-O*3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM<V=S
M='(@(DQA<F=H97IZ82!D96QL82!T86)E;&QA(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G:60@(E=I9'1H('5N
M:70B"FUS9W-T<B`B56YI=.`@9&D@;&%R9VAE>GIA(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H
M.B(*;7-G<W1R("),87)G:&5Z>F$Z(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C4Q-0IM<V=I9"`B5VEK:2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Y(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8W"FUS9VED(")7:6YD(@IM<V=S='(@(E9E;G1O
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*
M;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HX-PIM<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R
M(")696QO8VETX"!D96P@=F5N=&\@:6X@;F]D:2(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,38S"FUS9VED(")7:6YD.B(*;7-G<W1R(")696YT;SHB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS9VED(")7:6YD
M.B`B"FUS9W-T<B`B5F5N=&\Z("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV-`IM<V=I9"`B5VES9&]M(@IM<V=S='(@(E-A9V=E>GIA(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y.`IM<V=I9"`B5VES:&QI<W0B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7
M;W)K(@IM<V=S='(@(DQA=F]R;R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3(T(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`B26YD:7)I>GIO
M(&1E;"!L879O<F\B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R(")496QE9F]N;R!D
M96P@;&%V;W)O(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HQ.3,@;&EB+T9I;&4O
M0U-6+G!H<#HR.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R
M(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N
M(@IM<V=S='(@(DYU;65R;R!D:2!C86UP:2!E<G)A=&\@;F5L;&$@;&EN96$@
M)60N($%T=&5S:2`E9"P@=')O=F%T:2`E9"XB"@HC.B!L:6(O1FEL92]#4U8N
M<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@
M9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(DYU;65R
M;R!D:2!C86UP:2!E<G)A=&\N($%T=&5S:2`E9"P@=')O=F%T:2`E9"XB"@HC
M.B!L:6(O5D93+V9I;&4N<&AP.C$R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7
M<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*;7-G
M<W1R(")#;VUP96YS87II;VYE('-B86=L:6%T82`E9"!D=7)A;G1E(&QA(&QE
M='1U<F$@9&D@=6X@9FEL92!61E,N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(T-0IM<V=I9"`B6"U2968B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!"87-I8R!#
M;VYS=')A:6YT<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME>2!5<V%G92(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM
M<V=I9"`B6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I9"`B
M6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV.#,*;7-G:60@(E@U,#EV,R!E
M>'1E;G-I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P
M"FUS9VED(")962(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#$T(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-38*;7-G:60@(EE965DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,3$*;7-G:60@(EEA:&]O
M(2!M87`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H
M<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@(D%N;G5A;&UE;G1E(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR-#<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,@IM
M<V=I9"`B665M96XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.CDV-@IM<V=I9"`B665S(@IM<V=S='(@(E-I(@H*
M(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*
M;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R(")3:2P@<V]N;R!D)V%C8V]R
M9&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C4R"FUS9VED(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^
M72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`B
M(@HB4V5I(&EN(&9O<FUA=&\@=&5S=&\N(%5S82!I;"!B;W1T;VYE(%L\/ET@
M<&5R('1O<FYA<F4@86P@9F]R;6%T;R!765-)5UE'+B(*"B,Z(&QI8B](;W)D
M92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,C,V"B,L('!H<"UF;W)M870*
M;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA
M;B`E9"!B;&]C:W,N(@IM<V=S='(@(DYO;B!H86D@:6P@<&5R;65S<V\@9&D@
M8W)E87)E('!I^2!D:2`E9"!B;&]C8VAI+B(*"B,Z(&QI8B](;W)D92YP:'`Z
M,30R-`IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC871E9"XB"FUS9W-T
M<B`B3F]N('1I('-E:2!A=71E;G1I8V%T;RXB"@HC.B!L:6(O2&]R9&4O261E
M;G1I='DN<&AP.C,P.`IM<V=I9"`B66]U(&-A;FYO="!H879E('1H92`G7%PG
M(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`B3F]N('!U
M;VD@879E<F4@:6P@8V%R871T97)E("=<7"<@;F5L('1U;R!N;VUE(&-O;7!L
M971O+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#4U(&QI8B](;W)D92]&
M;W)M+G!H<#HQ.3<U"FUS9VED(")9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED
M(&5M86EL(&%D9')E<W,N(@IM<V=S='(@(DYO;B!H86D@:6YS97)I=&\@=6X@
M:6YD:7)I>GIO(&5M86EL('9A;&ED;RXB"@HC.B!L:6(O2&]R9&4O1&%T82YP
M:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P
M(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R
M<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*(DYO;B!H
M86D@87-S;V-I871O(&YE<W-U;B!D96D@8V%M<&D@9&%L(&9I;&4@:6UP;W)T
M871O(&-O;B!I(&-A;7!I("(*(F-O<G)I<W!O;F1E;G1I(&EN("5S+B(*"B,Z
M(&QI8B](;W)D92]!=71H+G!H<#HY.#<*;7-G:60@(EEO=2!H879E(&)E96X@
M;&]G9V5D(&]U="XB"FUS9W-T<B`B4V5I('-T871O(&1I<V-O;FYE<W-O+B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C8Q"FUS9VED("(B"B)9;W4@:&%V
M92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O
M;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I
M;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B(@HB1&5V:2!I;G-E<FER
M92!U;B!N=6UE<F\@9&D@8V5L;'5L87)E('9A;&ED;RP@8V]N=&5N96YT92!S
M;VQO(&YU;65R:2!C;VX@(@HB;"=O<'II;VYE(&1E;"`G*R<@<&5R(&D@<')E
M9FES<VD@:6YT97)N87II;VYA;&DN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$Q.#@*;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N
M(@IM<V=S='(@(D1E=FD@:6YS97)I<F4@=6X@=F%L;W)E('9A;&ED;RXB"@HC
M.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@;75S
M="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S
M+B(*;7-G<W1R(")$979I(&-O;F9I9W5R87)E('5N(&)A8VME;F0@<&5R(&EL
M($1A=&%4<F5E('!E<B!U<V%R92!3:6=N=7!S+B(*"B,Z(&QI8B](;W)D92YP
M:'`Z-#<Q"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N
M9"XB"FUS9W-T<B`B1&5V:2!C;VYF:6=U<F%R92!U;B!B86-K96YD(%9&4RXB
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B
M66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@
M<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@(D1E=FD@<')I;6$@
M9&5S8W)I=F5R92!I;"!P<F]B;&5M82!P<FEM82!D:2!M86YD87)L;R!C;VUE
M(')E<&]R="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E
M('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`B1&5V:2!I;G-E<FER92!L
M)U523"!A;&QA('%U86QE('!U;G1A('%U97-T;R!C;VQL96=A;65N=&\B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`IM<V=I9"`B66]U(&UU
M<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R(")$
M979I('-E;&5Z:6]N87)E('5N('-E<G9E<B!D82!E;&EM:6YA<F4N(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3$Y"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@
M=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R(")$979I('-P96-I9FEC
M87)E('5N('5T96YT92!D82!A>GIE<F%R92XB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R
M96UO=F4N(@IM<V=S='(@(D1E=FD@<W!E8VEF:6-A<F4@=6X@=71E;G1E(&1A
M(')I;75O=F5R92XB"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P96-I
M9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`B1&5V:2!S<&5C:69I
M8V%R92!U;B!U=&5N=&4@9&$@86=G:75N9V5R92XB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ-#8*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE
M('1O('5P9&%T92XB"FUS9W-T<B`B1&5V:2!S<&5C:69I8V%R92!U;B!U=&5N
M=&4@9&$@86=G:6]R;F%R92XB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP
M+G!H<#HQ,S@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@
M=&\@<&5R9F]R;2XB"FUS9W-T<B`B1&5V:2!S<&5C:69I8V%R92!U;B=A>FEO
M;F4@9&$@97-E9W5I<F4N(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y
M36%N86=E<BYP:'`Z-S$*;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T
M96=O<GD@;F%M92XB"FUS9W-T<B`B1&5V:2!S<&5C:69I8V%R92!I;"!N;VUE
M(&1E;&QA(&YU;W9A(&-A=&5G;W)I82XB"@HC.B!L:6(O3F5T+U--4R]V;V1A
M9F]N96ET86QY7W-M='`N<&AP.C<S"FUS9VED(")9;W4@;F5E9"!T;R!P<F]V
M:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(@IM<V=S='(@(D1E=FD@:6YS
M97)I<F4@=6X@;G5M97)O(&1I('1E;&5F;VYO(&ET86QI86YO(@H*(SH@;&EB
M+TAO<F1E+T%U=&@N<&AP.CDW-0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R
M("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BXB
M"FUS9W-T<B`B3&$@='5A('-E<W-I;VYE("5S(.@@<V-A9'5T82X@4VD@<')E
M9V$@9&D@8V]L;&5G87)S:2!N=6]V86UE;G1E+B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED(")9;W5R($5M86EL($%D9')E
M<W,B"FUS9W-T<B`B26P@='5O(&EN9&ER:7IZ;R!%;6%I;"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR,34*;7-G:60@(EEO=7(@1G)O;3H@861D<F5S
M<SHB"FUS9W-T<B`B26P@8V%M<&\@1&$Z(&1E;"!T=6\@:6YD:7)I>GIO.B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-R!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@U"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY,@IM<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G
M<W1R("),92!T=64@:6YF;W)M87II;VYI(@H*(SH@;&EB+TAO<F1E+T%U=&@N
M<&AP.CDW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN=&5R;F5T
M($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y
M;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@
M>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(DEL('1U;R!I;F1I
M<FEZ>F\@26YT97)N970@Z"!C86UB:6%T;R!D86QL)VEN:7II;R!D96QL82!T
M=6$@<V5S<VEO;F4@)7,N(%!E<B`B"B)P<F]T96=G97)E(&QA('1U82!S:6-U
M<F5Z>F$L(&1E=FD@<FEC;VQE9V%R=&D@;G5O=F%M96YT92XB"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B66]U<B!.86UE
M(@IM<V=S='(@(DEL('1U;R!.;VUE(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;F]A9&0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@
M8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U
M('=I<V@@=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O
M=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T
M:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*(DEL('1U;R!B86-K96YD(&1I(&%U
M=&5N=&EC87II;VYE(&YO;B!S=7!P;W)T82!L)V%G9VEU;G1A(&1I(&YU;W9I
M('5T96YT:2X@4V4@(@HB=G5O:2!U<V%R92!(;W)D92!P97(@9V5S=&ER92!G
M;&D@=71E;G1I+"!D979I('5S87)E('5N(&)A8VME;F0@9&D@(@HB875T96YT
M:6-A>FEO;F4@9&EF9F5R96YT92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VYO;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B
M86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE
M(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@
M<F5A<V]N+B(*;7-G<W1R("(B"B));"!T=6\@8F%C:V5N9"!D:2!A=71E;G1I
M8V%Z:6]N92!N;VX@<W5P<&]R=&$@;"=E;&5N8V\@9&5G;&D@=71E;G1I+"!O
M(&QA("(*(F9U;GII;VYE(.@@<W1A=&$@9&ES86)I;&ET871A('!E<B!A;'1R
M92!R86=I;VYI+B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY.#,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V
M92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S
M:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO
M9VEN(&%G86EN+B(*;7-G<W1R("(B"B)396UB9G)A(&-H92!I;"!T=6\@8G)O
M=W-E<B!S:6$@8V%M8FEA=&$@9&%L;"=I;FEZ:6\@9&5L;&$@='5A('-E<W-I
M;VYE("5S+B`B"B)097(@<')O=&5G9V5R92!L82!T=6$@<VEC=7)E>GIA+"!D
M979I(&%C8V5D97)E(&YU;W9A;65N=&4N(@H*(SH@;&EB+T)L;V-K+VEF<F%M
M92YP:'`Z-3<*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T
M('1H:7,@9F5A='5R92XB"FUS9W-T<B`B26P@='5O(&)R;W=S97(@;F]N('-U
M<'!O<G1A('%U97-T82!F=6YZ:6]N92XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]P<FEN="YJ<SHT,@IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@
M;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO
M0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*(DEL('1U;R!B
M<F]W<V5R(&YO;B!S=7!P;W)T82!Q=65S=&$@;W!Z:6]N92!D:2!S=&%M<&$N
M(%!R96UI($-O;G1R;VPO0V]M;6%N9"`B"B(K(%`@<&5R('-T86UP87)E+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-C$*;7-G:60@(EEO=7(@8W5R
M<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@(DEL('1U;R!F=7-O(&]R87)I;SHB
M"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,3$W"FUS9VED(")9;W5R(&1E9F%U
M;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"XB"FUS9W-T<B`B3&$@='5A
M(&ED96YT:73@(&1I(&1E9F%U;'0@Z"!S=&%T82!M;V1I9FEC871A+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-C$*;7-G:60@(EEO=7(@9&5F875L
M="!I9&5N=&ET>3HB"FUS9W-T<B`B3&$@='5A(&ED96YT:73@(&1I(&1E9F%U
M;'0Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P-`IM<V=I9"`B66]U
M<B!F=6QL(&YA;64Z(@IM<V=S='(@(DEL('1U;R!N;VUE(&-O;7!L971O.B(*
M"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY.3D*;7-G:60@(EEO=7(@;&]G:6X@
M:&%S(&5X<&ER960N(@IM<V=S='(@(DQA('1U82!L;V=I;B#H('-C861U=&$N
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*
M;7-G<W1R("),82!T=6$@;G5O=F$@<&%S<W=O<F0@<&5R("5S(.@Z("5S(@H*
M(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ-30*;7-G:60@(EEO=7(@;W!T
M:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H
M:7,@<V5S<VEO;BXB"FUS9W-T<B`B3&4@='5E(&]P>FEO;FD@<V]N;R!S=&%T
M92!A9V=I;W)N871E('!E<B!L82!D=7)A=&$@9&D@<75E<W1A('-E<W-I;VYE
M+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,34V"FUS9VED(")9;W5R
M(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S='(@(DQE('1U92!O
M<'II;VYI('-O;F\@<W1A=&4@86=G:6]R;F%T92XB"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@
M8F5E;B!R97-E="(*;7-G<W1R("),82!T=6$@<&%S<W=O<F0@Z"!S=&%T82!A
M>GIE<F%T82(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<Y"FUS
M9VED("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y
M;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R`B"B)P87-S=V]R
M9"XB"FUS9W-T<B`B(@HB3&$@='5A('!A<W-W;W)D(.@@<W1A=&$@87IZ97)A
M=&$L(&-O;G1R;VQL82!L82!T=6$@96UA:6P@92!A8V-E9&D@8V]N(&QA('1U
M82`B"B)N=6]V82!P87-S=V]R9"XB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z
M-S,S"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+B(*;7-G<W1R
M("),82!T=6$@<&%S<W=O<F0@Z"!S8V%D=71A+B(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R
M<SHB"FUS9W-T<B`B22!T=6]I('-E<G9E<B!R96UO=&DZ(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$X(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M-30*;7-G:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(T.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4V
M"FUS9VED("):86UB:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#D*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-PIM<V=I9"`B6FEM8F%B=V4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED
M(")::7!P>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O
M:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E9"!497AT
M72(*;7-G<W1R(");3F%S8V]N9&D@:6P@=&5S=&\@8VET871O72(*"B,Z('-E
M<G9I8V5S+W!R;V)L96TN<&AP.C@Y"FUS9VED(");4')O8FQE;2!297!O<G1=
M(@IM<V=S='(@(EM297!O<G0@9&5L('!R;V)L96UA72(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(");4VAO=R!1
M=6]T960@5&5X="`M(@IM<V=S='(@(EM-;W-T<F$@:6P@=&5S=&\@8VET871O
M("TB"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O:&EG:&QI9VAT<75O=&5S
M+G!H<#HQ-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E
M>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B6TUO<W1R82!I;"!T97-T;R!C:71A
M=&\@+2`E<R!L:6YE95TB"@HC.B!L:6(O2&]R9&4N<&AP.C(P-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B6VQI;F5A
M("5S(&1I("5S72(*"B,Z(&QI8B](;W)D92YP:'`Z,34U-"!T96UP;&%T97,O
M<&]R=&%L+VUE;G4N:6YC.C$Q"FUS9VED(")?061M:6YI<W1R871I;VXB"FUS
M9W-T<B`B7T%M;6EN:7-T<F%Z:6]N92(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM
M<V=I9"`B7T-,22(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#$*;7-G
M:60@(E]$871A5')E92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*;7-G:60@(E]$96QE
M=&4@4F]W(@IM<V=S='(@(E]#86YC96QL82!2:6=A(@H*(SH@;&EB+V%P:2YP
M:'`Z,3,S"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(E]'<G5P<&DB"@HC.B!L
M:6(O2&]R9&4O365N=2YP:'`Z,3<U"FUS9VED(")?2&5L<"(*;7-G<W1R(")?
M06EU=&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P97)T:65S+BXN(@IM
M<V=S='(@(G!R;W!R:65TX"!D96QL)U]);6UA9VEN92XN+B(*"B,Z(&QI8B](
M;W)D92]-96YU+G!H<#HQ.30*;7-G:60@(E],;V<@:6XB"FUS9W-T<B`B7T5N
M=')A(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I9"`B7TQO9R!O
M=70B"FUS9W-T<B`B7T5S8VDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@3&EN
M:RXN+B(*;7-G<W1R(")?36]D:69I8V$@0V]L;&5G86UE;G1O+BXN(@H*(SH@
M;&EB+TAO<F1E+TUE;G4N<&AP.C$V-`IM<V=I9"`B7T]P=&EO;G,B"FUS9W-T
M<B`B7T]P>FEO;FDB"@HC.B!L:6(O87!I+G!H<#HQ,S<*;7-G:60@(E]097)M
M:7-S:6]N<R(*;7-G<W1R(")?4&5R;65S<VDB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]2
M96UO=F4@3&EN:RXN+B(*;7-G<W1R(")?16QI;6EN82!#;VQL96=A;65N=&\N
M+BXB"@HC.B!L:6(O87!I+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G<W1R
M(")?26UP;W-T87II;VYE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED(")?5&%B;&4@4')O<&5R
M=&EE<RXN+B(*;7-G<W1R(")0<F]P<FEE=.`@9&5L;&$@7U1A8F5L;&$N+BXB
M"@HC.B!L:6(O87!I+G!H<#HQ,CD*;7-G:60@(E]5<V5R<R(*;7-G<W1R(")5
M=&5N=&DB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDR-0IM<V=I9"`B861D
M<F5S<R!B;V]K(@IM<V=S='(@(G)U8G)I8V$B"@HC.B!L:6(O2&]R9&4O34E-
M12]-97-S86=E+G!H<#HQ,S0*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM
M<V=S='(@(FEN9&ER:7IZ:2!S8V]N;W-C:75T:2(*"B,Z(&QI8B](;W)D92]+
M;VQA8BYP:'`Z.3$W"FUS9VED(")C86QE;F1A<B(*;7-G<W1R(")C86QE;F1A
M<FEO(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-SD@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R
M(")C86QM;R(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$U.`IM
M<V=I9"`B8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(*;7-G<W1R(")N;VX@
M<&]S<V\@8W)E87)E(&EL(&9I;&4@9&D@;W5P=70B"@HC.B!L:6(O2&]R9&4O
M34E-12]-97-S86=E+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T
M(@IM<V=S='(@(FYO;B!P;W-S;R!A<')I<F4@;"=I;G!U="(*"B,Z(&QI8B](
M;W)D92]-24U%+T-O;G1E;G1S+G!H<#HV,#`*;7-G:60@(F-L:6-K(&AE<F4B
M"FUS9W-T<B`B<')E;6D@<75I(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G
M92YP:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS
M9W-T<B`B97)R;W)E(&YE;&PG=7-O(&1E;&QA(&QI;F5A(&1I(&-O;6%N9&\B
M"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-S@*;7-G:60@(F-O
M;F9I9W5R871I;VX@97)R;W(B"FUS9W-T<B`B97)R;W)E(&1I(&-O;F9I9W5R
M87II;VYE(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,34T"FUS
M9VED(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T
M82!F;W)M870@97)R;W(B"FUS9W-T<B`B97)R;W)E(&YE;"!F;W)M871O(&1E
M;&QA(&1A=&$B"@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C,P"FUS
M9VED(")E9&ET(@IM<V=S='(@(G!U8F)L:6-A(@H*(SH@;&EB+TAO<F1E+TU)
M344O365S<V%G92YP:'`Z,3@R"FUS9VED(")E;G1R>2!N;W0@9F]U;F0B"FUS
M9W-T<B`B96YT<GD@;F]N('1R;W9A=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HW,PIM<V=I9"`B9F%L;&EN9R(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.#DV"FUS9VED(")F:6QE
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@Q(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S8W(&QI8B]";&]C:R]M971A<BYP:'`Z,SDS"B,L
M('!H<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@)7,B
M"FUS9W-T<B`B9&%L("5S("@E<RD@86P@)7,@)7,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C,Y"FUS9VED(")G=7-T:6YG(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR-3`*
M;7-G:60@(F@Z(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HS-3D*;7-G:60@(FAH(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE
M('5N:VYO=VXB"FUS9W-T<B`B;F]M92!H;W-T('-C;VYO<V-I=71O(@H*(SH@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0IM<V=I9"`B:6UM961I871E(@IM
M<V=S='(@(FEM;65D:6%T;R(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,38R"FUS9VED
M(")I;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`B97)R;W)E(&1I(&EN<'5T
M+V]U='!U="(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$T-@IM
M<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B97)R;W)E
M(&EN=&5R;F\@9&5L('-O9G1W87)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R(")L
M:6YE95TB"@HC.B!L:6(O5D93+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI
M;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B97)R;W)E(&1I(&-O9&EC92`E9"!D
M:2!M:VES;V9S(&1U<F%N=&4@;&$@<V-R:71T;W)A($E33RXB"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<P"FUS9VED(")M;2(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C(X-2!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<T"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S:61E8F%R+G!H<#HR-#,*;7-G:60@(FYA;64B"FUS9W-T<B`B;F]M92(*
M"B,Z(&QI8B](;W)D92]24$,N<&AP.C$R-`IM<V=I9"`B;F]T(&EM<&QE;65N
M=&5D(@IM<V=S='(@(FYO;B!I;7!L96UE;G1A=&\B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C$R,C`*;7-G:60@(FYO="!Y970@:6UP;&5M96YT
M960B"FUS9W-T<B`B;F]N(&%N8V]R82!I;7!L96UE;G1A9&\B"@HC.B!L:6(O
M2&]R9&4O2V]L86(N<&AP.CDP.0IM<V=I9"`B;F]T97!A9"(*;7-G<W1R(")B
M;&]C8V\@;F]T92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B<&5R
M8V5N=&\B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-S0*;7-G
M:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(G!E<FUE<W-O(&YE9V%T
M;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O34E-12]-97-S86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I
M;B!P<F]T;V-O;"(*;7-G<W1R(")E<G)O<F4@<F5M;W1O(&YE;"!P<F]T;V-O
M;&QO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-S4*;7-G:60@(G)I<VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-
M12]-97-S86=E+G!H<#HQ-#(*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B
M"FUS9W-T<B`B<V5R=FEZ:6\@;F]N(&1I<W!O;FEB:6QE(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HQ,#$*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B
M"FUS9W-T<B`B;6]S=')A(&QE(&1I9F9E<F5N>F4B"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA
M($A45%`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,X-PIM<V=I9"`B<W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S0*;7-G:60@(G-T96%D
M>2(*;7-G<W1R(")C;W-T86YT92(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A
M9V4N<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S='(@(F5R<F]R
M92!D:2!S:7-T96UA(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,S,*;7-G
M:60@(G1A<VL@;&ES="(*;7-G<W1R(")E;&5N8V\@871T:79I=.`B"@HC.B!L
M:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R
M>2!F86EL=7)E(@IM<V=S='(@(F=U87-T;R!T96UP;W)A;F5O(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,S8@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-S`*
M;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS
M9W-T<B`B<V-R:79I(&QA('!A<W-W;W)D(&1U92!V;VQT92!P97(@8V]N9F5R
M;6%R92(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.C<Y"FUS9VED(")U;FEF:65D(@IM<V=S='(@(G5N:69I8V%T
M;R(*"B,Z(&QI8B](;W)D92]-24U%+U!A<G0N<&AP.C(W"FUS9VED(")U;FYA
M;65D(@IM<V=S='(@(G-E;GIA(&YO;64B"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(R,R!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-38U"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R(")U=&5N=&4@
M<V5L97II;VYA=&\B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0R"FUS9VED(")W.B(*;7-G<W1R
M(")W.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED
M(")W96%T:&5R+F-O;2(*;7-G<W1R(")W96%T:&5R+F-O;2(*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O:&]R9&4N
M<&]T````````````````````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P-3<U,38Q(#$P-3$U-#,S-S0S(#`R,#`R,@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````C(%-/344@1$530U))4%1)
M5D4@5$E43$4N"B,@0V]P>7)I9VAT("A#*2!914%2($AO<F1E(%!R;VIE8W0*
M(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC
M96YS92!A<R!T:&4@4$%#2T%'12!P86-K86=E+@HC($9)4E-4($%55$A/4B`\
M14U!24Q`041$4D534SXL(%E%05(N"B,*(RP@9G5Z>GD*;7-G:60@(B(*;7-G
M<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ(%!!0TM!1T4@5D524TE/3EQN
M(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<
M;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`W+3,Q(#$X.C$R*S`R,#!<
M;B(*(E!/+5)E=FES:6]N+41A=&4Z(%E%05(M34\M1$$@2$\Z34DK6D].15QN
M(@HB3&%S="U4<F%N<VQA=&]R.B!&54Q,($Y!344@/$5-04E,0$%$1%)%4U,^
M7&XB"B),86YG=6%G92U496%M.B!,04Y'54%'12`\3$Q`;&DN;W)G/EQN(@HB
M34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I
M;CL@8VAA<G-E=#U#2$%24T547&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D
M:6YG.B`X8FET7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S@W
M"B,L('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,W-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y-0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S.3$*;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S.3,*;7-G:60@(B`H=&]M
M;W)R;W<I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S.#D*;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0U(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS-3`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,Y-@IM<V=I9"`B(&%T("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C(R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M:7,@;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0TQ)+T-,22YP:'`Z,C@T"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I
M<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S`W"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3`Y-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E
M9VES=')Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5')E92]4<F5E+G!H
M<#HQ-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R964@<F5N9&5R
M97(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C4V"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@
M=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS
M+V%D9&-H:6QD+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-30@861M:6XO<&5R;7,O861D8VAI
M;&0N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T
M(&-R96%T960Z("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"('5S960@;V8@
M)2XR9DU"(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-@HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HR-C@@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4Y-`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O
M<F0@97AP:7)E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R
M96-A<W0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`U"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T,B!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E
M;F%N8V4N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S($UA:6YT96YA
M;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,C$T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-#4P(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z-3$V"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C@Y(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S8R"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$V,2!L:6(O0FQO8VLO;65T87(N<&AP.C$V-R!L:6(O
M0FQO8VLO;65T87(N<&AP.C(T,0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T
M-R!L:6(O0FQO8VLO;65T87(N<&AP.C,U,PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!A="`E<R`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N
M86YC92YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A
M9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C
M:V5D(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N
M*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S4X"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C@X"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&UI;G5T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+T-O;&QE8W1I;VXN<&AP.C$S,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY
M-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY-#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS-@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY-C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G
M<R!487-K;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T
M:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@
M=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@(@HB
M86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I
M=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4T(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS.3D*;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.3`@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`S"B,L('!H
M<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Y-"!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,T.`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#@W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M-#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<T
M.`IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y"FUS9VED("(R-"!(;W5R($9O
M<FUA="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR
M.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U!A9V5R+G!H<#HV.0IM<V=I9"`B/%!R979I;W5S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(V"FUS9VED(")!(&1A=&%B87-E
M(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<Q"FUS9VED(")!
M(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-#0*;7-G:60@(D$@<'5B;&EC
M(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q
M-S<*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R
M:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q,#@*;7-G:60@(B(*(D$@<'5B;&EC
M(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#(U"FUS9VED
M("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU,#8*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@
M4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*
M(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@
M4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S8T"FUS
M9VED(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP
M="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.CD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M,`IM<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@3&EG
M:'0@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@4F%I;B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PIM<V=I
M9"`B04T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`IM<V=I9"`B04T@4VYO=R!3:&]W97)S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS
M9VED(")!32]032(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU-`IM<V=I9"`B06)O=70N+BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW-`IM<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@
M(D%B<VUI9&1L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,C@Q"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&
M4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HQ,S4*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@
M5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HS"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.`IM<V=I9"`B06-C;W5N="!087-S
M=V]R9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3,*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,U"FUS
M9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,30X('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ
M-`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0IM
M<V=I9"`B061D(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C,Q
M(&%D;6EN+V=R;W5P<RYP:'`Z,C,R"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY
M."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDY"FUS9VED(")!9&0@
M0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D($AE<F4Z(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#8*;7-G:60@(D%D
M9"!-96UB97)S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T
M(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!9&0@3F5W($=R;W5P(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#<@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX.`IM<V=I9"`B061D($YE
M=R!097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O861D8VAI;&0N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D
M(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G
M:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E
M<CHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C4U-@IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@<&%I
M<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8T"B,L
M('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL
M;&$@4VED96)A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z-S$*;7-G:60@(D%D9"!T;R!A9&1R97-S(&)O
M;VLZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HW.`IM<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O:R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,0IM<V=I9"`B061D('5S
M97(B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O('1H92!S>7-T96TL(&)U
M="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N
M.B`B"B(E<RXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U
M(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I
M<V%B;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ-S,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T
M,0IM<V=I9"`B061D<F5S<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,30Q"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-38*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30*;7-G
M:60@(D%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S
M97)S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ.2!S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`Z,3$W"FUS9VED(")!9&UI;FES=')A=&EO
M;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0S
M"FUS9VED(")!9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B069G
M:&%N:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06QB86YI
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")!;&=E<FEA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,#<*;7-G:60@(D%L:6%S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*;7-G:60@(D%L
M:6=N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N=#HB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C@W"FUS9VED(")!;&PB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,#<@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-@IM<V=I9"`B06QL($%U=&AE;G1I
M8V%T960@57-E<G,B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS
M,R!A9&UI;B]G<F]U<',N<&AP.C(R.`IM<V=I9"`B06QL($=R;W5P<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDQ(&9R
M86UE=V]R:R]097)M<R]097)M<R]D871A=')E92YP:'`Z-S4*;7-G:60@(D%L
M;"!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$W"FUS9VED(")!;&P@9F]U
M<B!S:61E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.#@Y"FUS9VED(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S,0IM<V=I9"`B06QL
M;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`W"FUS
M9VED(")!;')E861Y(&5X:7-T<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3(V"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`T"FUS9VED
M(")!;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#DV"FUS9VED(")!;'1E<FYA=&4@24U34"!5
M<V5R;F%M92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HS-@IM<V=I9"`B06QT97)N871E(&5M86EL(&%D9')E<W,B"FUS9W-T
M<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*;7-G:60@(D%L=&5R
M;F%T92!T96UP;&%T97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(U"FUS9VED(")!
M;'1E<FYA=&4@=&5X=#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B
M06UE<FEC86X@4V%M;V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HY-2!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C$Q-0IM<V=I9"`B06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34U
M"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W
M"FUS9VED(")!;F=U:6QL82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-3$*;7-G
M:60@(D%N<W=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;G1A
M<F-T:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%N=&EG=6$@
M86YD($)A<F)U9&$B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H
M<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z,S8*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+U5)+G!H<#HU."!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N
M:'1M;#HV"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R("(B"@HC.B!U=&EL
M+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S.0IM<V=I
M9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,C$Y"FUS9VED(")!<'!L>2!T;R!#:&EL
M9"!3:&%R97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0R"FUS9VED(")!
M<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!<')I;"(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B07)A8FEC
M("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HV-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C<X"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4X
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW-PIM<V=I9"`B07)C
M:&EV92!.86UE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W)E;6]V97%U975E9"YI;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E
M('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E
M<W0@9F]R("5S(#\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]D96QE=&4N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO
M=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M
M9W)O=7!S/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!<F=E;G1I
M;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B07)M96YI82(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B07)M
M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G:60@(D%S8VEI
M($%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R,@IM<V=I9"`B07-K(&9O<B!C
M;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q
M,3,*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A
M(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R
M;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N
M;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<&5R;7,O961I="YP:'`Z.#<*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO
M;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]S:&%R97,O961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@961I="!A
M(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-"!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C<Q"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z.#,*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M.0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*
M;7-G:60@(D%U9W5S="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!
M=7-T<F%L:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')I
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP
M:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A8VME
M;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3(R"FUS
M9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O9G1P
M+G!H<#HS-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L
M92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VEM87`N<&AP.C8P"FUS9VED(")!=71H7VEM87`Z(%)E<75I<F5D
M($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U
M.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S`R"FUS9VED
M(")!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O
M<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z(%)E;6]V
M:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O
M<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HV,PIM<V=I9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A
M<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HS.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P
M.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,#4*
M;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O
M<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L
M.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HV,`IM<V=I9"`B
M075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O061M
M:6XN<&AP.C$P,PIM<V=I9"`B075T:&5N=&EC871I;VX@870@24U!4"!S97)V
M97(@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N(&9A:6QE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-PHC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!=71H96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-S8*;7-G:60@(D%U
M=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#DT"FUS9VED
M(")!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HW,`IM<V=I9"`B
M075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C<U"FUS9VED
M(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS
M9VED(")!>F5R8F%I:F%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS,`IM<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R
M;W5N9"!#;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VMR8C4N<&AP.C@Q"FUS9VED(")"860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#,*
M;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,@IM<V=I9"`B0F%H86UA<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q
M"FUS9VED(")"86AR86EN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@P"FUS9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(B(*"B,Z('5T
M:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"
M87-E(&=R87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-S,*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C,*;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM
M<V=I9"`B0F5L9VEU;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"
M96QI>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F5N:6XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8S"FUS9VED(")":'5T86XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B
M0FER=&AD87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+T-O;&QE8W1I;VXN<&AP.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")";&]C
M:R!<(B5S7"(@;V8@87!P;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDP"FUS
M9VED(")";&]C:R!3971T:6YG<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<&]R=&%L+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX"FUS9VED(")";VQD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@
M(D)O;&EV:6$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(P-PIM<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*;7-G
M:60@(D)O<F1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(Q"FUS9VED(")";W)D97)S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C`*;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED(")"
M;W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O='-W86YA(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C,*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,@IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS
M9VED(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM
M<V=I9"`B0G5L;&5T960@3&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS
M9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I
M9"`B0G5R=6YD:2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#0V"FUS9VED(")#35,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DX
M"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U,0IM<V=I9"`B0V%C
M:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY-#(@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0X-0HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I
M<W0Z,3`U,"!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,34W"FUS9VED(")#
M86QE;F1A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C,U"FUS9VED(")#86QM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S
M"FUS9VED(")#86UB;V1I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED
M(")#86UE<F]O;B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z
M,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H
M86YD;&5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)U<RYP:'`Z,C,U(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS
M,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0
M('-E<G9E<CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z-#0V"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&]P96X@
M9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-A
M;F%D82(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO
M=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHV-0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI
M;F,Z,3$@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G:60@(D-A;F-E
M;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#0T(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C(S-0HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C8W-2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C(R"FUS
M9VED(")#86YN;W0@8V]P>2!F:6QE*',I("T@<V]U<F-E(&%N9"!D97-T:6YA
M=&EO;B!A<F4@=&AE('-A;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,S(R"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO
M="!D96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HT-@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R"FUS9VED(")#86YN
M;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3$P(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C(P-0HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C<U,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3@W"FUS9VED
M(")#86YN;W0@;6]V92!F:6QE*',I("T@9&5S=&EN871I;VX@:7,@=VET:&EN
M('-O=7)C92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T('!R;V-E960@=VET
M:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92YP:'`Z,3(X(&9R
M86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8X,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES
M="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E
M+W-Q;"YP:'`Z-C$Q"FUS9VED("(B"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R
M(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T
M8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z,C$*;7-G:60@(D-A;FYO="!R97-E="!P87-S
M=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O
M<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@<F]U=&4@;65S<V%G
M92!T;R!S<&5C:69I960@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HS-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V%N;F]T('=R:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`IM<V=I
M9"`B0V%P=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS"FUS9VED(")#871E
M9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G
M:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO
M;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR-0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B
M0V5L;"!S<&%C:6YG.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C<T"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-E;'1I8R`H25-/+3@X
M-3DM,30I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L
M:6,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G
M:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED
M(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C$R"FUS9VED(")#97)T:69I8V%T
M92!/=VYE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4Y-PIM<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")#:&%D(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z.38*;7-G:60@(D-H86YG92(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*;7-G:60@(D-H
M86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV.0IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A
M9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P
M;'D@=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U
M<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@
M8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(W"FUS9VED(")#:&%R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C4S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-PIM<V=I9"`B0VAI;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I
M9"`B0VAI;F$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#,*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B0VAI;F5S
M92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V%P<"YI;F,Z-PIM<V=I9"`B0VAO;W-E($%P<&QI8V%T:6]N.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z
M,C<P"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")#:&]O
M<V4@82!U<V5R;F%M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,CDU"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE
M('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8X"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4RYP:'`Z,CDT(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HY,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO
M;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"FUS9VED(")#;&5A<B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,CD*;7-G:60@(D-L96%R(%%U97)Y
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN
M8SHU"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z
M,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L96%R('5S97(@9&%T
M82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ-@IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV,`IM
M<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS9VED
M(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C0V"FUS9VED(")#;&]U9',B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3<*;7-G:60@
M(D-L;W5D<R!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B0VQO=61Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C0*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z
M,C,*;7-G:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM
M<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-PIM<V=I9"`B0V]L;VUB:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V-O
M;&]R+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@
M(D-O;&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#
M;VQL96-T:6]N+G!H<#HS,S@*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O
M;&QE8W1I;VXN<&AP.C,S.0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-3`S('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP
M:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-#D*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-C4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-C8*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z.#$*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z.#(*;7-G:60@(D-O;&]R(%!I8VME<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#0V"FUS9VED(")#;VQO=7(@<V5L96-T
M:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38T"FUS9VED(")#;VQU;6X@=&ET
M;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M-C8*;7-G:60@(D-O;6EC<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]C;61S:&5L
M;"YP:'`Z,C8*;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`B(@H*(SH@861M:6XO
M8VUD<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I
M9"`B0V]M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B0V]M;6]N($YA;64B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#0*;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I
M9"`B0V]M<&%N>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@V"FUS9VED(")#;VYD:71I;VXB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3$*;7-G:60@(D-O
M;F1I=&EO;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z
M.3,*;7-G:60@(D-O;F9I9W5R871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-`IM<V=I9"`B0V]N9FEG
M=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF
M:6=U<F4@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHU,0IM<V=I9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;VYG;R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8U"FUS9VED(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@
M;V8@=&AE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C(P-`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS-#<*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HR,#0*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S0W"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y.0IM<V=I9"`B0V]N
M;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HX,#$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX.#@*;7-G:60@(D-O
M;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.34P(&-O;F9I9R]H;V]K<RYP
M:'`N9&ES=#HQ,#<W"FUS9VED(")#;VYT86-T<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@
M(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D
M<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C8P"FUS9VED(")#;VYT96YT('1Y<&4@;V8@8V]M
M<')E<W-E9"!F:6QE.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HU-B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C8S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@
M7"(E<UPB(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C,P('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,PIM<V=I9"`B
M0V]N=&EN=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]O:R!)
M<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M,@IM<V=I9"`B0V]O:VEE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0IM<V=I9"`B0V]P
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0X
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-S`*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@
M240B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;W1E(&0G279O:7)E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDX
M-@IM<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#8T
M"FUS9VED(")#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G93H@(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,SDS"FUS
M9VED(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT-C<*
M;7-G:60@(D-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C$X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O
M;G1A8W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HY-B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$R
M,`HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#@R"FUS9VED(")#;W5L9"!N
M;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#8V"FUS
M9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@
M=7-I;F<@1E10.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,3,W"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3(S
M"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T
M92!C;VYT86-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A
M9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HS.#$@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z.38R"FUS9VED(")#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R
M96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*;7-G
M:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@
M9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0V"FUS9VED(")#;W5L
M9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N
M(&QI<W1S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.`HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDN<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D
M('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C$Q,`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S$Y"FUS9VED(")#
M;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN
M9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!O<&5N("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E
M;F%N8V4O36%I;G1E;F%N8V4N<&AP.C0R,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q
M,2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR,S<@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-3$V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV
M,3(*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8U-B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-CDY"FUS9VED(")#;W5L9"!N
M;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z.#8*;7-G:60@(B(*(D-O=6QD(&YO="!R
M97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M
M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4
M<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U
M(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#4*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0V"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-PHC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HT,30*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z-#(P"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C0R-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E
M(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C`T"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R-`HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C@*;7-G:60@(D-O=6QD(&YO
M="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`IM<V=I9"`B0V]U;&0@;F]T
M(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M
M9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@
M)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y"FUS9VED
M(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I
M;VXZ("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('-E='5P
M('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O
M;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O
M9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@
M;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-#,*;7-G
M:60@(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B!<(B5S7"(Z
M("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C,*
M;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K
M92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H
M92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q.0IM
M<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED(")#;W5N=')Y(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-S4*;7-G:60@
M(D-O=7)S97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z
M.38*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3(*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@(D-R96%T
M92!S=6(@9F]L9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C(T,`IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C,P"FUS
M9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-SD*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I
M9"`B0W5B82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*
M;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5S<VEO;G,N<&AP.C4P"FUS9VED(")#=7)R96YT(%-E<W-I;VYS(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE
M+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5S<VEO;G,N<&AP.C,U"FUS9VED(")#=7)R96YT(%5S97)S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U<G)E;G0@
M5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C8T"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$Q,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T
M;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@(D-U="!S
M96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED
M(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X-@IM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*;7-G:60@
M(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Y"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4R('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,CDP"FUS9VED("(B"B)$4TX@*'-E
M92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B
M87-E+F1B+FEN=')O+61S;BYP:'`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3D*;7-G:60@(D1A:6QY
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I9"`B
M1&%T851R964@0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,C@X"FUS9VED(")$871A8F%S92!,;V]K=7`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$V"FUS9VED(")$871E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N
M:6YC.C$S"FUS9VED(")$871E(%)E8V5I=F5D(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#<*;7-G:60@(D1A=&4@<V5L96-T
M:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR.#$@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B
M1&%Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@IM<V=I9"`B1&5?;&5T92!#;VQU;6XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0Q,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#4Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*
M;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R
M96%S92!);F1E;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HQ.#<@;&EB+W!R969S+G!H<#HQ,3<*;7-G:60@(D1E9F%U
M;'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z-S<*;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+TED96YT:71Y+G!H<#HY.`IM<V=I9"`B
M1&5F875L="!)9&5N=&ET>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-S4*;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I;FET:6]N
M<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Q(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,S(W"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z-#(R(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#,Y
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S<@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHW,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.CDT('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$W"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,30P('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3@S"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,R!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3@*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]D96QE=&4N:6YC.C$P('1E;7!L871E<R]A9&UI;B]U<V5R+VQI
M<W0N:6YC.C,Q"FUS9VED(")$96QE=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"FUS
M9VED(")$96QE=&4@0V5L;"(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C(P-2!A9&UI;B]G<F]U<',N<&AP.C(S,PIM<V=I9"`B1&5L971E($=R
M;W5P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(U,0IM<V=I9"`B1&5L971E($QO9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<W(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,3`Q"FUS9VED(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M,PIM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4W"FUS9VED(")$96QE=&4@8V5L;"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8S"FUS
M9VED(")$96QE=&4@8V]L=6UN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z,30X"FUS9VED(")$96QE=&4@97AI<W1I;F<@86QT97)N871E
M('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S0S,30N<&AP.C4T"FUS9VED(")$96QE=&4@;65S<V%G97,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<
M(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I
M;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V1E;&5T96ED96YT:71Y+FEN8SHQ-0IM<V=I9"`B
M1&5L971E('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4S"FUS9VED(")$96QE
M=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W"FUS9VED(")$96QE
M=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,PIM<V=I
M9"`B1&5L971E('1H92!C=7)R96YT(')O=R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!P:'`M9F]R;6%T"FUS9VED(")$
M96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU.34*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(U,PIM<V=I9"`B1&5L:79E<GD@=&EM92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$96YM87)K(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C(Y"FUS9VED(")$97-C
M<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HY,S@@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HR,#8*;7-G:60@(D1E
M=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HR,3`*;7-G:60@(D1E=&%I
M;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,C$*;7-G
M:60@(D1E=F5L;W!M96YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C$Y"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR.38*;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S
M="!H;W5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(Q-@IM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I
M9"`B1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B
M1&ER96-T:6]N(')I9VAT('1O(&QE9G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C8R"FUS9VED(")$:7-P;&%Y
M(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,#`*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.#D*;7-G:60@(D1I
M<W!L87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HY,@IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$W
M"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TU$3BYP:'`Z,3DQ"FUS9VED(")$:7-P;W-I=&EO;B!.
M;W1I9FEC871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&II
M8F]U=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HT,C(*;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER
M96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,B!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A
M:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<P"FUS9VED(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY-@IM<V=I
M9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-3,*;7-G
M:60@(D1O=VYL;V%D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.C@U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N
M;&]A9"`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,38Q"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A
M<R!02%`@<V-R:7!T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,3(U"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q
M,PIM<V=I9"`B12U-86EL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDR"FUS9VED(")%36%I;"UT;RU3
M35,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E
M('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF
M:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM
M<V=I9"`B15)2(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5C=6%D
M;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS
M,C8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C<P('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M.3,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ.#(@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<R"FUS9VED
M(")%9&ET(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]5
M22YP:'`Z-3`*;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T<B`B(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HR,#0*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,`IM<V=I9"`B161I="!097)M:7-S
M:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR
M,S<*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<')E9G,O87!P+FEN8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O
M<B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS
M(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S4*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS
M9VED(")%9WEP="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(D5L
M(%-A;'9A9&]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM<V=I9"`B16QE;65N="XN
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R-"!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#@W"FUS9VED(")%;6%I;"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z-C@*;7-G:60@(D5M86EL($%D9')E<W,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DX,0IM<V=I
M9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,#<*;7-G:60@(D5M86EL('=I
M=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ"FUS9VED(")%;6%I;"UT;RU3
M35,@1V%T97=A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,CDY"FUS9VED(")%;6]T:6-O;G,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`R"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C0S(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT.#0*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C8V,B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z-S`U"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,34P
M"FUS9VED(")%;7!T>2!R97-U;'0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E87)C
M:"!T97)M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-30P"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H
M;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3$U"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@
M8V]N=&5X="!M96YU/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-C`V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3$*;7-G
M:60@(D5N9"!Y96%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,38*;7-G
M:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I
M;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S
M=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!5
M4DP@:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.#DR"FUS9VED(")%;G1E<B!T:&4@;&5T=&5R<R!B
M96QO=SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B17%U871O<FEA
M;"!'=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70O5FEE=RYP:'`Z.3(@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C0X"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S8*;7-G
M:60@(D5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]4
M96UP;&%T92YP:'`Z-#8S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&-R
M96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D
M96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8X"B,L('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF
M;W)M870*;7-G:60@(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,`IM<V=I9"`B17-T;VYI82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<Q"FUS9VED(")%=&AI;W!I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,V"FUS9VED
M(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.#8*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,S(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.#0*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-2!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S@W"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H
M<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,S-PIM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S0@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,X-0IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(T"FUS9VED
M(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE
M;&PN<&AP.C@R(&%D;6EN+V-M9'-H96QL+G!H<#HU,2!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3(X"FUS9VED(")%>&5C=71E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C$T"FUS9VED
M(")%>'!A;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y
M=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-S4*;7-G:60@
M(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R
M"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S<*;7-G:60@(D5X<&]N96YT
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S8*;7-G:60@(D944"!U<&QO
M860@;V8@<V5T=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+W-Q;"YP:'`Z,C(U"FUS9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F
M97)E;F-E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C<U(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z.3@*
M;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.3@*;7-G
M:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S(T"B,L('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#<*
M;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU,C,@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-C<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0X,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")&86EL960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Y"FUS9VED
M(")&86ER(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML86YD
M($ES;&%N9',@*$UA;'9I;F%S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS
M9VED(")&87)O92!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M3$DO0TQ)+G!H<#HR-#`*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W
M"FUS9VED(")&87@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,U,0IM<V=I9"`B1F%X97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,PHC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U
M87)Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(R"FUS
M9VED(")&965L<R!,:6ME(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,C`*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M,`IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@(D9E=R!3;F]W
M(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3DV,@IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S-#,*;7-G:60@(D9I9VQE="!#05!4
M0TA!(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S
M-#<*;7-G:60@(D9I9VQE="!F;VYT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HX,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*
M;7-G:60@(D9I:FDB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C4W"FUS9VED(")&:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D9I
M;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N
M=#H@)7,@9FEL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0P.0IM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,`HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"FUS9VED(")&:6QE($YA;64B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDY-0IM
M<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30X-@IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3`P"FUS
M9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDQ"FUS9VED(")&:6QT97)S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D9I;FQA;F0B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V-@IM<V=I9"`B1FER<W0@
M2&%L9B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB
M+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR-3<*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,R"FUS9VED(")&;&EP
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED
M(")&;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HR.#`@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$P-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(V"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T
M(&EM86=E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S
M-@IM<V=I9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C<R"FUS9VED("(B"B)&;W)E8V%S="!$
M87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@
M8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O
M=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3`R"FUS9VED(")&;W)G;W0@>6]U
M<B!P87-S=V]R9#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0V-`IM<V=I9"`B1F]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C(Q"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T
M>7!E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM
M<V=I9"`B1F]R='5N97,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,Y"FUS9VED(")&;W)T=6YE<R`R(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-34*;7-G:60@(D9O<G5M<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3$Q"FUS9VED
M(")&;W)W87)D<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,S"FUS9VED(")&<F%M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I
M9"`B1G)A;F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C,*;7-G:60@(D9R965Z:6YG($1R:7IZ;&4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,T.0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDU
M"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z-#@*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C
M:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C4@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHV,`IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS
M,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<U"FUS9VED(")'86UB:6$B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T
M92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T960@0V]D
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDP
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'96]R9VEA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-CD@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-0IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3<V"FUS9VED(")':79E;B!.86UE(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-SD@
M=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3`*(SH@=&5M<&QA=&5S+W!R969S
M+V%P<"YI;F,Z,3D*;7-G:60@(D=L;V)A;"!/<'1I;VYS(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$W"FUS9VED(")';R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O
M961E;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3$S,0IM<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE
M(%-E87)C:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C,X"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965C92(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B1W)E96L@*$E33RTX.#4Y
M+3<I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=R965N;&%N9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'<F5N861A(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3@U"FUS9VED(")'<F]U<"!!9&UI
M;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`N<&AP.C4Y(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-CD*
M;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G
M<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3@@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G
M:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,S
M."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O
M=7`@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR-#$@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS,30*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,S@@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S@*;7-G
M:60@(D=R;W5P<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'=6%D
M96QO=7!E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%M(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%T96UA;&$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,@IM<V=I9"`B
M1W5E<FYS97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX.0IM<V=I
M9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0W,@IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S4*;7-G:60@(D=U:6YE82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S@*;7-G:60@(D=U:6YE82U":7-S874B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<X"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.38P"FUS9VED(")(5$U,(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#4*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L
M971E('1H92!L87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS
M9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@
M(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T
M(')O=R!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]H='1P+G!H<#HQ-3<*;7-G:60@(DA45%`@075T:&5N=&EC871I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAA
M:71I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@
M(DAA>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.3$Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S(*;7-G:60@(DAE861E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B
M;&5S970N<&AP.C8Q"FUS9VED(")(96%D97)S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA
M;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(U"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(")(96)R97<@*$E3
M3RTX.#4Y+3@M22DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP
M:'`Z,C(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92](96QP+G!H<#HQ.#0@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+TAE;'`N<&AP.C$X-@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N
M=2YP:'`Z,3<U('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W"B,Z('1E;7!L
M871E<R]H96QP+VEN9&5X+FEN8SHT"FUS9VED(")(96QP(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*
M;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$S-S$*;7-G:60@(DAE;'!E<B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@(DAE;6ES<&AE
M<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z
M,3`@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3`*;7-G:60@(DAE<F4@
M:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*;7-G:60@
M(DAI9V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN
M8SHV('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHU"FUS9VED
M(")(;U]M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")(;VQY
M(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-34*;7-G:60@(DAO
M;64@061D<F5S<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-S`*;7-G:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3`*;7-G:60@
M(DAO;64@4&AO;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(
M;VYD=7)A<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@
M2V]N9R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-C<*;7-G:60@(DAO<F1E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z-#<X"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A
M9V4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HR.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&UE
M<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#<Q"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N
M9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,3(X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S"FUS9VED(")(
M;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T
M:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C4S.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@
M9F]R(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C$R.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C4P.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)
M344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C,T"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@
M7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C$S-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,S8V"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM
M<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO
M<FEZ;VYT86PZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I9"!Y
M;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M
M97)G93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H
M97)E/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N>2!R;W=S('=O
M=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Y(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C,R"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C0X"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B2'5M
M;W)I<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H
M<#HQ-S(@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(S-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D
M.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S
M+G!H<#HR,30@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I
M;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G5S+G!H<#HQ-SD@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(T
M,@HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E
M871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,S$V"FUS9VED("))4"!!9&1R97-S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@
M(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@061D
M<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<S"FUS9VED("))8V]N<R!/;FQY
M(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-`IM<V=I9"`B26-O;G,@=VET:"!T
M97AT(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#4*
M;7-G:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-C`P"B,L('!H<"UF;W)M870*
M;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T
M;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0U,@IM<V=I9"`B(@HB268@>6]U(&1O;B=T
M('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M
M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@
M=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3<R"FUS9VED("(B"B))9B!Y;W4@<V5E
M('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N
M="!T;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA>65D(&)Y('EO=7(@8G)O
M=W-E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(X"FUS9VED("));6%G92!0<F5V
M:65W.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,W"FUS9VED("));6%G92!54DPB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8Q"FUS9VED
M("));6%G92!U<&QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9&%T82]T<W9I;F9O+FEN8SHW('1E;7!L871E<R]D871A+V1A=&5M87`N
M:6YC.C<*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-"!T96UP;&%T
M97,O9&%T82]C<W9I;F9O+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(DEM
M<&]R="P@4W1E<"`E9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D
M871E;6%P+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F
M:65L9#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHV-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S-`IM<V=I
M9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M,@IM<V=I9"`B26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"XB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-3,*
M;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D
M<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI;FES=')A
M=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,0IM<V=I
M9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM
M<V=I9"`B26YD:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HR-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S4*
M;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@P"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B26YF;R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4Y"FUS
M9VED("));F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S$Y"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG
M97(@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V5D:70N:6YC.C,U"FUS9VED("));FAE<FET960@365M8F5R<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@(DEN<V5R="!#7V]L=6UN($%F=&5R
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B26YS97)T($EM86=E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED
M("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED("))
M;G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED
M("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@
M8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G
M:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!B969O
M<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM<V=I9"`B
M26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F
M;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA
M=&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S-`IM
M<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A
M;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*
M;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G
M:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED
M("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@
M(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4P"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED("));G-E<G0@;65S
M<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("));G-E<G0@<&%R86=R
M87!H(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A
M<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T
M(')O=R!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED("));G-E<G0@<F]W
M(&)E9F]R92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C(U"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@
M<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-
M;V1I9GD@26UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,
M:6YK(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET
M('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`W-0IM<V=I9"`B26YT96=E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3,S
M"FUS9VED("));G1E9V5R(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("))
M;G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ-C<*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3DT"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(Q,@IM<V=I9"`B
M26YV86QI9"!:25`@9&%T82(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#4@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C$W-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,C4P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,3<*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS-PIM<V=I9"`B26YV
M86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED("))
M;G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P.0HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,SD*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,C0Q"FUS9VED("));G9A
M;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-C4*;7-G:60@(DEN=F%L:60@;&EC96YS92!K97DN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-3D*;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`S"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.38*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z,C<*
M;7-G:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*;7-G:60@(DEN
M=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$V,PIM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O
M9&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HY,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C<Q(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z(%PB
M)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C$Q,3<@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,CDW"FUS9VED("))
M;G9A;&ED('-H87)E(&]B:F5C="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@(DEN
M=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0IM<V=I9"`B
M26YV86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS-3D*;7-G:60@(DEN=F5N=&]R>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-C<X"FUS9VED("));G9E<G0@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,@IM<V=I9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DER87$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@P"FUS9VED("))<F5L86YD(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA
M;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR-@IM<V=I9"`B27-O;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,30@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@P"FUS9VED("))<W)A96PB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C8*;7-G:60@(DES
M<W5E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CD*;7-G:60@(DET86QI8R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#(*;7-G:60@(DET86QY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,@IM<V=I9"`B2F%M86EC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`R"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#`*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIA<&%N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")*87!A;F5S92`H
M25-/+3(P,C(M2E`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(R"FUS9VED(")*97)S97DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@S"FUS9VED(")*;W)D86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.`HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P-PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S
M=&EF>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3<*;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$V"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C8U"FUS9VED(")+965P
M(&]R:6=I;F%L/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DME
M;GEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP
M:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0R"FUS9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A
M=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,30*;7-G:60@(DME>2!&:6YG97)P<FEN="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME
M>2!,96YG=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@5'EP92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.0IM<V=I9"`B2V5Y
M(%5S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@T"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*
M;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ
M"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@V"FUS9VED(")+=7=A:70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS
M9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T
M86PO;65N=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S"FUS9VED("),86YG=6%G92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G<R!$
M96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HQ-CD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z.#@*;7-G:60@(DQA<W0@4&%S<W=O<F0@
M0VAA;F=E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX-B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U,PIM<V=I9"`B3&%S
M="!5<&1A=&5D.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HW,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y"B,L
M('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$T"FUS9VED
M("),87-T(&QO9VEN.B!.979E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*
M;7-G:60@(DQA='9I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#0*;7-G:60@(DQA=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*;7-G:60@(DQA
M>6]U="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R
M9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&5B86YO;B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q.0IM<V=I9"`B3&5F="!H96%D97(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-0IM
M<V=I9"`B3&5F="!V86QU97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS
M9VED("),97-O=&AO(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(U-PIM<V=I9"`B3&5V96PB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@X"FUS9VED("),:6)E<FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.0IM<V=I9"`B3&EB>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#@*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G
M:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,CD*;7-G:60@(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*;7-G
M:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B3&EG:'0@4F%I
M;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N
M9&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,S"FUS9VED("),:6=H="!3;F]W(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED
M("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,30*;7-G:60@(DQI;FLB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q-PIM<V=I
M9"`B3&EN:R!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@S,@IM<V=I9"`B3&EN:R!A8V-E<W,@:V5Y(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU-PIM<V=I9"`B3&EN:R!P;VEN=',@=&\Z(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,C,*;7-G:60@(DQI;FL@=&%R
M9V5T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M,C`*;7-G:60@(DQI;FL@=&5X="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#DS"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R
M97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,CD*;7-G:60@
M(DQI;FL@=&ET;&4@871T<FEB=71E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]497AT7T9I;'1E<B]&:6QT97(O:'1M;#)T97AT+G!H<#HQ.#(*;7-G:60@
M(DQI;FMS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M-@IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C0V"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T("T@=7-E
M<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C$S-`IM<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3(*;7-G:60@(DQI<W0@
M2&5L<"!4;W!I8W,B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$S,PIM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12](96%D97)S+G!H<#HV,#$*;7-G:60@(DQI<W0M07)C
M:&EV92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E
M<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-C`S"FUS9VED("),:7-T
M+4ED(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R
M<RYP:'`Z-3DY"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-C`P"FUS9VED("),:7-T
M+5!O<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D
M97)S+G!H<#HU.3@*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DW"FUS9VED
M("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I
M;VYS+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('-E<W-I
M;VYS(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N
M<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I
M;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N
M;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-PIM<V=I
M9"`B3&ET97)A='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@
M(DQI=&AU86YI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I;6%G97,N<&AP.C<W"FUS9VED("),;V%D:6YG+BXN(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#`*;7-G
M:60@(DQO8V%L('1I;64Z("(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#8*;7-G:60@(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-3<*(SH@;&EB+T)L;V-K+W-U;G)I
M<V4N<&AP.C(R(&QI8B]";&]C:R]M971A<BYP:'`Z-S(*;7-G:60@(DQO8V%T
M:6]N(@IM<V=S='(@(B(*"B,Z(&QO9VEN+G!H<#HQ.#D@<V5R=FEC97,O<&]R
M=&%L+W-I9&5B87(N<&AP.C(P-"!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN
M8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z.3`*;7-G:60@(DQO9R!I;B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#<*;7-G:60@(DQO
M9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y.`IM<V=I9"`B3&]G(&]U="(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C$*;7-G:60@
M(DQO9VEN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,3`*;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.CDY-0IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U
M<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O
M<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP
M:'`Z.3DQ"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C4*;7-G:60@(DQO;F<@=&5X="(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@
M(DQO=F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-S$*;7-G:60@(DQO=R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(Q
M"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,0HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@S"FUS9VED(")-3U1$(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP
M.C,V"FUS9VED(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A
M=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA8V%O(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%C961O;FEA+"!4:&4@1F]R;65R
M(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#D*;7-G:60@(DUA9VEC(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX,PIM<V=I9"`B36%I;"(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3(T"FUS9VED(")-
M86EL($%D;6EN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,0IM<V=I9"`B36%K92!L:6Y?
M:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&%W:2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUA;&%Y<VEA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-30@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86QI(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-`IM<V=I9"`B36%L=&$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDT"FUS9VED("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@
M8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@
M8V]L;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3$U-@IM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#@W"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3<Q"FUS9VED
M(")-87!1=65S="!M87`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S=&]R960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8W"FUS9VED(")-87)C:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q"FUS9VED(")-87)G
M:6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M-#,Q-"YP:'`Z-#@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.#@*;7-G:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T
M+G!H<#HT.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HX.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R
M=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED
M(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM
M<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%U<FET86YI82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`X"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#@*;7-G:60@(DUA>"!T
M96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,P,`IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S.B`B
M"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3@Q"FUS9VED(")-87AI;75M
M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C@Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C$W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,SD*;7-G:60@
M(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#8*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B36%Y;W1T92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*;7-G:60@(DUE9&EC:6YE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z
M,38*;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,W-0IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N
M<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-PIM<V=I
M9"`B365S<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3
M=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L
M9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B
M365S<V%G92!E>'!I<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V.0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"FUS
M9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS"FUS9VED(")-971A<B!796%T:&5R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,3$Y"FUS9VED("(B"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$
M971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,34S"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B
M365T:&]D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P
M8RYP:'`Z.#$@9G)A;65W;W)K+U)00R]24$,O<V]A<"YP:'`Z,3$W"B,L('!H
M<"UF;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL
M960@;65T:&]D.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-C<@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,@IM<V=I9"`B
M365T<FEC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,38V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")-:6-R;VYE<VEA+"!&
M961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@IM<V=I9"`B36ED
M9&QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1N968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3(*;7-G:60@(DUI;B!T96UP(&QA<W0@
M,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,P-`IM<V=I9"`B36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,SD*;7-G:60@
M(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(S-0IM<V=I9"`B36ER<F]R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU,0IM<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8W,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS-#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q
M=65S="XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q
M-`IM<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T
M;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB
M87!P;&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M
M97-S86=E($E$+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R
M97%U:7)E9"!014%2('!A8VMA9V4@36%I;"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDT"FUS
M9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-38*;7-G:60@(DUO
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW-@IM
M<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S(*;7-G:60@(DUO9&5R871E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C8@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,PHC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@U"FUS9VED
M(")-;V1I9FEE9"!$871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D
M:69Y(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8W-`IM<V=I9"`B36]D=6QU<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3`*;7-G:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]N86-O(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY,@IM<V=I9"`B36]N9V]L:6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8P,@IM<V=I9"`B36]N=&@@86YD('EE
M87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT
M96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.30*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED
M(")-;V]N(%!H87-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HQ.38@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C@P
M"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI
M;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B36]S=&QY
M($-L96%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W
M"FUS9VED(")-;W-T;'D@0VQO=61Y(&%N9"!7:6YD>2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.`IM<V=I
M9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C0X"FUS9VED(")-;W9E($1O
M=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HV-3(*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C8U-@IM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8T-`IM<V=I9"`B
M36]V92!5<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-3(V"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R
M-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(V
M"FUS9VED(")-;W9E('5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I
M9"`B36]Z86UB:7%U92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,C`R"FUS9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES
M=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$P-3D*;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8P"FUS9VED(")-
M=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0P,@IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*;7-G:60@(DUY($%C8V]U
M;G0@26YF;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+VEN9&5X+G!H<#HT-`IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HT,@IM<V=I9"`B37D@4&]R=&%L
M($QA>6]U="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUY86YM
M87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT
M96YA;F-E+FAT;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P,@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B
M3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").875R=2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE<&%L(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3<*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@R"FUS
M9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@
M0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C87!E($-!('!O
M;&EC>2!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.#4*;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3@S"FUS9VED(").971S8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I
M9"`B3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@X"FUS9VED(").971S
M8V%P92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P
M92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR-3,*;7-G:60@(DYE='=O<FLB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(U(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS,S(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X
M,PIM<V=I9"`B3F5V97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED
M(").97<@0V%L961O;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED(").97<@0V%T
M96=O<GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI
M8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS
M9VED(").97<@36]O;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO
M;F%L*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$X,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(DYE=R!:96%L
M86YD(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HS-PIM<V=I9"`B3F5W('!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*;7-G:60@(DYE
M=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE
M=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z-#`@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR.3$*;7-G:60@(DYE=W,B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-PIM<V=I9"`B3F5W
M<V=R;W5P<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O
M+FEN8SHQ-2!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT,0HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T82]C<W9I
M;F9O+FEN8SHR-0IM<V=I9"`B3F5X="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,C<*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C8@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S`*;7-G:60@(DYE>'0@;W!T:6]N
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C$P
M-@IM<V=I9"`B3F5X=#XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED
M(").:6-A<F%G=6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").
M:6=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R:6$B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V
M.0IM<V=I9"`B3FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED
M(").:75E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HY-C8*;7-G:60@(DYO(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM<V=I9"`B3F\@879A
M:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S
M(&9O<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+G!H<#HQ,#8*;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G
M>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I
M9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3`Q"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,S@U"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-#`W"FUS
M9VED(").;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP
M.C4P"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D
M:69F+G!H<#HU,0IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B3F\@8VAI
M;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S@@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3$*(SH@9G)A;65W;W)K+U5T:6PO571I
M;"YP:'`Z-SDR"B,L('!H<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-C<*;7-G:60@(DYO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C<R
M-PIM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R(%-13"!61E,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HW-S(*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,T"FUS9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3$X"FUS9VED
M(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,38@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3,P
M"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*;7-G:60@(DYO(&QO8V%T
M:6]N('!R;W9I9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I9"`B3F\@;65S<V%G
M92!S=7!P;&EE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*;7-G:60@(DYO(&YA;64@<W!E
M8VEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S-PIM<V=I9"`B3F\@;G5M8F5R('-P96-I
M9FEE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT
M"FUS9VED(").;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`P"FUS
M9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U
M+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E
M<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W-A<VPN<&AP.C<W(&9R86UE=V]R:R]!=71H+T%U=&@O;&]G
M:6XN<&AP.C@T"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW-0IM
M<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A
M<W-W9"YP:'`Z,3,U"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X-PIM<V=I9"`B
M(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H
M92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H
M(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-S4S"FUS
M9VED(").;R!Q=6]T82!S970N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*;7-G:60@(DYO
M(')U;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C0X,@IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I9FEE9"XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT-`IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HV,#D*;7-G:60@(DYO('-U8V@@9FEL
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3(V"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F
M;W(@8V%C:&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"FUS9VED(").;R!U<V5R;F%M92!A;F0O
M;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)0
M0R]24$,O>&UL<G!C+G!H<#HQ-#8*;7-G:60@(DYO('9A;&ED(%A-3"!D871A
M(')E='5R;F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HY-S0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.CDX-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.3DU"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,#$R"FUS9VED(").;R!V86QU97,B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q.0IM<V=I9"`B3F\@=F5R
M<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R
M871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ,C<*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@>6]U
M<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R
M-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0U"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z
M.34*;7-G:60@(DYO;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM
M<&QI8VET*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y
M,@IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDV"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K+VUO;VXN<&AP.C8P
M"FUS9VED(").;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,PIM<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0Q"FUS9VED
M(").;W0@069T97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!"969O<F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#(T"FUS9VED(").
M;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4
M<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z,S0X"FUS9VED(").;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<BYP:'`Z-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#0*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.34*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+G!H<#HT.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"FUS9VED(").;W0@
M:6UP;&5M96YT960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*;7-G:60@(DYO="!S970B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD
M;&5R+G!H<#HQ-#@*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I
M;VY(86YD;&5R+G!H<#HQ-C,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R
M+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S@*(SH@9G)A;65W;W)K+U-E<W-I;VY(
M86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ.3(*(SH@9G)A;65W;W)K+U-E
M<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HR,S<@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C,Y
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-C4*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C(X,R!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S`P"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HS,38@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,S
M,@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S0W(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HS-C0*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,Y-R!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z-#4W"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HU,S8@9G)A;65W;W)K+U9&4R]61E,N<&AP.C8P-0HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z-C(R"FUS9VED(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS-"!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T"B,Z(&-O;F9I9R]H
M;V]K<RYP:'`N9&ES=#HQ,#8X(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ
M.#`*;7-G:60@(DYO=&5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V]B<F]W
M<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O
M(&)A8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0U,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<U"FUS9VED(").;W9E;6)E<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#0V"FUS9VED(").=6UB97(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R-0IM
M<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V.2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#(S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#4@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@
M(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$S-C<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R
M,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0S('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@
M;V8@<F]W<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E
M8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")/8FIE8W0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3(*;7-G
M:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q,#0*;7-G:60@(D]C=&%L(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3$*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS9VED
M(")/8W1O8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HY,@IM<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R.`IM<V=I9"`B3V9F:6-E(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I
M9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*
M;7-G:60@(D]L9"!P87-S=V]R9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z-#8*;7-G:60@(D]L9"!P87-S=V]R9"!I<R!N
M;W0@8V]R<F5C="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")/
M;6%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M,C8*;7-G:60@(D]N8VQI8VL@979E;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@
M24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O
M9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3@V.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3@Y
M"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B
M(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y
M(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R
M(&$@<VAA<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z
M-#$@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-#(*;7-G:60@(D]P96X@:6X@82!N
M97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N
M;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE
M=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4S"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-34*;7-G:60@(D]P=&EO;G,B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C,Q('1E;7!L871E
M<R]P<F5F<R]A<'`N:6YC.C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D]P=&EO
M;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V
M.`IM<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED(")/<F=A;FES871I
M;VYA;"!5;FET(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ,S0*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T
M:6]N('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP
M:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E;7!L871E
M<R!I;B`E<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T
M:&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.2!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-0HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3,T"FUS9VED(")/=&AE<B!);F9O<FUA=&EO;B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,R"FUS
M9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W!A;2YP:'`Z-SD*;7-G:60@(E!!32!A=71H96YT:6-A
M=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%
M05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,C@U"FUS9VED(")01U`@1&EG:71A;"!3:6=N
M871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3,S,0IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S.#,*;7-G
M:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C$S-C4*;7-G:60@(E!'4"!3:6=N960O16YC
M<GEP=&5D($1A=&$B"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP
M.C8Y"FUS9VED(")02%`@0V]D92(*;7-G<W1R("(B"@HC.B!A9&UI;B]P:'!S
M:&5L;"YP:'`Z,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,`IM<V=I9"`B
M4$T@3&EG:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@4F%I;B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M,@IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B4$T@4VYO=R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT-`IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED
M(")032!3=6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.#8*;7-G:60@(E!/4TE8
M(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN
M<&AP.C(Q-0IM<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0V"FUS
M9VED(")0861D:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B
M4&%K:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L
M874B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI
M86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3@*;7-G:60@(E!A;F%M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G
M:60@(E!A<'5A($YE=R!'=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,@IM<V=I9"`B4&%R86=U87DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,SD*;7-G:60@(E!A<G1L>2!#;&]U
M9'DB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$W.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4S-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HQ-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C`S-@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<W('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0R-0IM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED(")087-S=V]R
M9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,S(S"FUS9VED(")087-S=V]R
M9"!I;F-O<G)E8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]R861I=7,N<&AP.C$U,@IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R
M(%)!1$E54R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`W,0IM<V=I9"`B4&%S<W=O<F0@=VET:"!C
M;VYF:7)M871I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.CDP"FUS9VED(")087-S=V]R9#HB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*;7-G:60@(E!A<W-W;W)D
M.B`B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(P-3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED
M(")087-T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,W"FUS9VED(")087-T92!F<F]M(&-L:7!B;V%R
M9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C4Q"FUS9VED(")0871H(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O<F5M;W9E<75E=65D+FEN8SHW"FUS9VED(")096YD:6YG(%-I9VYU
M<',Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-`IM
M<V=I9"`B4&5O<&QE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH
M=&UL.C0Y"FUS9VED(")097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0P,PIM<V=I
M9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U
M-@IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M
M<R]D96QE=&4N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I
M;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C8Q,@IM<V=I9"`B4&5R;6ES<VEO;B!$96YI
M960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HQ-C$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C0*;7-G:60@
M(E!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N
M<&AP.C$P.2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C`*(SH@861M:6XO
M<&5R;7,O:6YD97@N<&AP.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3@*
M;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.`IM<V=I9"`B4&5R<V]N86P@
M26YF;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")0
M97)U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-0IM
M<V=I9"`B4&5T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!H
M:6QI<'!I;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#`*;7-G:60@(E!H;W1O
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0:71C86ER;B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P.`IM<V=I9"`B4&EX96QS(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T
M('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T
M;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-3@P"FUS9VED(")0;&5A<V4@96YT97(@82!M
M;VYT:"!A;F0@82!Y96%R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N
M=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P,0IM<V=I9"`B4&QE87-E
M(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8U.`IM<V=I9"`B4&QE87-E(&5N=&5R
M(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H
M92!M;VYT:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C0V-0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM
M<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@(E!L96%S92!P
M<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B(@HB4&QE
M87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W
M:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP
M:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M
M93HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0;VQA;F0B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4W"FUS9VED(")0
M;VQI=&EC<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#@Y"FUS9VED(")0;VQL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q
M"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C<*;7-G:60@
M(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@
M(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3$*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@(E!O<W0@
M=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V."!L:6(O0FQO8VLO;65T
M87(N<&AP.C(W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N
M(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@W"FUS9VED(")0<F5C:7!I=&%T:6]N
M/&)R("\^8VAA;F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]L9&%P+G!H<#HQ,#0*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D
M($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F
M<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(W"FUS
M9VED(")0<F5S<W5R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(V,0IM<V=I9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-`IM<V=I
M9"`B4')E<W-U<F4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`S"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PIM<V=I9"`B4')E
M=FEE=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*;7-G:60@(E!R979I97<@=&AE
M(&EM86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C,U-B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C,V,`IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@
M2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU
M+G!H<#HQ-CD*;7-G:60@(E!R;V)L96TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<')O8FQE;2YP:'`Z,3(W"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S$*
M;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Q,CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(P-@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,CDT"FUS9VED(")0<F]M<'0@
M=&5X="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#8*;7-G:60@(E!U8FQI
M8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y($EN9F\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,C0Q"FUS9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T
M960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS
M9VED(")0=65R=&\@4FEC;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU-0IM<V=I9"`B4'5R9V4@;65S<V%G
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B46%T87(B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C8T"FUS9VED(")1=65R
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#`*;7-G
M:60@(E%U;W1A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C8T"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L
M:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(R.#(*;7-G:60@(E)A9&EO('-E;&5C=&EO;B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M-PIM<V=I9"`B4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!%87)L>2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT.0IM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4P"FUS9VED(")286EN(%-H
M;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU,0IM<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM
M<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8X(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A
M=&EO(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,S(U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3@Q"FUS9VED(")296%D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C0W"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W"FUS9VED(")296%D(&UE<W-A
M9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E("5S
M/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E
M<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS-`IM<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30T('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C(Q,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR-#@*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,X.`IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC
M($UE;G4@16QE;65N=',Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS,S@*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-"!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C$S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R,S4*;7-G:60@(E)E9V5X(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,R-#D*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W
M<V5R(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C$T-"!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,3`*;7-G:60@(E)E
M;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R.`IM
M<V=I9"`B4F5M87)K<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3$W"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T
M92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(R('1E
M;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3,*;7-G:60@(E)E;6]V
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M,3$*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34Y"FUS9VED(")296UO
M=F4@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-#`*;7-G:60@(E)E;6]V92!F;W)M871T:6YG
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(X
M"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,C`Q"FUS9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R
M;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0R"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM
M<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$Q
M"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]24$,O
M4E!#+WAM;')P8RYP:'`Z,30T"FUS9VED(")297%U97-T(&-O=6QD;B=T(&)E
M(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30U"FUS9VED(")297%U
M97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3@U(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z-3(Q"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I
M<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-S,S
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#<S"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HW-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP
M.C@P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T
M('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,S8*;7-G:60@(E)E
M<75I<F5D($9I96QD(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S.0HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+U)E;F1E<F5R+G!H<#HS,C$*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(R,"!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z,3`P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C0X"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.`IM<V=I9"`B
M4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3,Q"FUS9VED(")297-T;W)E($QA<W0@475E<GDB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C<R(&%D;6EN+V-M9'-H96QL
M+G!H<#HR.2!A9&UI;B]S<6QS:&5L;"YP:'`Z-C<*;7-G:60@(E)E<W5L=',B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P
M,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U<FX@=&\@
M3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z,S@*;7-G:60@(E)E='EP92!N97<@<&%S<W=O<F0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@(E)I8V@@
M5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<P
M"FUS9VED(")2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,3(Q"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-PIM<V=I9"`B4FEG:'0@
M=F%L=65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?=R!0<F]P97)T
M:65S+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(V"FUS9VED(")2
M;W1A=&4@,3@P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,C,*;7-G:60@(E)O=&%T92!,969T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,CD*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS
M9VED(")2;W<@4')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2
M;W<@<')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W<SHB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU,PIM<V=I9"`B4G5L97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,`IM<V=I
M9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L
M=6UN<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4R"FUS9VED
M(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(Q"FUS9VED(")2=6XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G5S<VEA;B!&961E<F%T
M:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)W86YD82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C(X-0IM<V=I9"`B4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,S(S"FUS9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX,0IM<V=I9"`B
M4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3`V"FUS9VED(")3
M35,@365S<V%G:6YG(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,R.3(*;7-G:60@(E-13"!S=&%T96UE;G0@9F]R
M('9A;'5E(&QO;VMU<',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0S,PIM<V=I9"`B4U-((@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL
M92YP:'`Z,S4*;7-G:60@(E-50T-%4U,B"FUS9W-T<B`B(@H*(SH@;&EB+V%P
M:2YP:'`Z,C$Y"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@
M(E-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE
M;&5N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI
M='1S(&%N9"!.979I<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@
M(E-A:6YT($QU8VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@
M(E-A:6YT(%!I97)R92!A;F0@36EQ=65L;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-0IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN
M97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,38@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-PIM<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*
M;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`S"FUS9VED(")3875D:2!!<F%B:6$B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDY"FUS9VED(")3879E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-3<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,3<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E
M9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-@IM<V=I9"`B(@HB4V%V92!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U
M<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU,PIM<V=I9"`B4V-A='1E<F5D(%0M4W1O<FUS(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ
M-"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A
M<F-H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M,C(*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Y-S,*;7-G:60@(E-E;&5C="!&:6QE<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#@U"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DY"FUS9VED(")396QE8W0@
M82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHT-`IM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I
M9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,34W"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-C<V"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C$*;7-G:60@(E-E;&5C="!A
M;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")396QE8W0@
M86X@;V)J96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HV-S<*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HS-PIM<V=I9"`B(@HB
M4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S
M(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F
M<F]M('1H92!T97AT(&%R96$N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C,T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI
M=&5R.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M-`IM<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,@IM<V=I
M9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"FUS9VED
M(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H92!T
M:6UE(&9O<FUA=#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHU-PIM<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#,*;7-G
M:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T-`IM<V=I9"`B4V5L96-T('EO=7(@
M<')E9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E
M<&]R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3`T,@IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,Q.`IM<V=I9"`B4V5N<V]R.B`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S,*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-
M;VYT96YE9W)O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-S`R"FUS9VED(")397)I86P@3G5M8F5R(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#D*;7-G:60@
M(E-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR-PIM<V=I9"`B4V5S<VEO;B!!
M9&UI;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E
M9"XB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,C$Q"FUS9VED(")397-S
M:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S,R"FUS9VED(")3970B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C<Y"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@
M<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3@*;7-G:60@
M(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S
M<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#<*;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG
M=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,0IM<V=I9"`B(@HB4V5T('EO
M=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E
M9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S<*;7-G:60@(E-E
M='5P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E
M>"YH=&UL.C,W"FUS9VED(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA
M8FQE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-S4*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@
M=&AE('!A<F%M971E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G
M:60@(E-E>6-H96QL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0Y.`IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@(E-H;W)T
M(%-U;6UA<GDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0T,PIM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R
M(&UO<W0@;&EN:W,_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,S(T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3@P"FUS9VED(")3:&]W(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-30*;7-G:60@(B(*(E-H;W<@9&EF
M9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L
M>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0X-PIM<V=I9"`B4VAO=R!L87-T(&QO
M9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8U"FUS9VED(")3:&]W(&]P=&EO;B!T
M;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X,3,*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C,*;7-G:60@(E-H;W<@=&%B
M;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W
M('1H92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*
M;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L92!0<F]P
M97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@
M=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-3(*;7-G:60@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C,*
M;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4T"FUS9VED(")3:&]W97)S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4U"FUS9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V"FUS9VED(")3
M:&]W97)S($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I
M8VEN:71Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70O36%N86=E<BYP:'`Z-C$Y"FUS9VED(")3:')I;FLB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HY,3`*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HY-S(*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA
M9V5R+G!H<#HQ,#4X"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z,3$R,`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C$Q.#,*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HQ,C(S"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(U,@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R.#4*;7-G:60@(E-H<FEN
M:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A
M>2!F:7)S="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3:65R
M<F$@3&5O;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3
M:6=N=7`N<&AP.C(V-@IM<V=I9"`B4VEG;B!U<"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,PIM<V=I9"`B4VEG
M;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-S$R"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8U
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-"!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HX.38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3(Q-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,W"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(R-C0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,CDS,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(S"FUS9VED(")3
M:7IE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN
M=&5N86YC92YH=&UL.C4R"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS
M9VED(")3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M,`IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Q"FUS9VED(")3;F]W(%-H
M;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@P"FUS9VED
M(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR.#0*;7-G:60@(E-N;W<@97%U:79A;&5N="!I;B!W871E<CH@(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M;VX@27-L86YD
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3;VUA;&EA(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,`IM<V=I9"`B
M4V]N9W,@)B!0;V5M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.3(V"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,3@Y"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")3;W5T:"!!9G)I8V$B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E-O=71H
M($5U<F]P96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S<*;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC
M:"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS
M,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N($AE;6ES
M<&AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J86-E
M;G0@8V5L;',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E='=E96X@8V]N
M=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.#$U"FUS9VED(")3<&%C97(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@P"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@
M(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*
M;7-G:60@(E-P86EN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ,#`*;7-G:60@(E-P86TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C:6%L($-H87)A8W1E<B!)
M;G!U="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C8Q"FUS9VED(")3<&]R=',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@X"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8V(&QI8B]";&]C:R]M971A<BYP
M:'`Z.#$*;7-G:60@(E-T86YD87)D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V,#0@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@P.0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,0IM<V=I
M9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$U"FUS9VED
M(")3=&]R86=E(&9O<FUA="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4W,PIM<V=I9"`B4W1R965T($%D9')E<W,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,S"FUS9VED(")3=')I;F<@
M;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.#DQ"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS
M9VED(")3=2(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z
M,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R(&9R86UE=V]R:R]&
M;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,Q.`IM<V=I9"`B4W5B;6ET(@IM<V=S
M='(@(B(*"B,Z('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES
M=&5M+B!9;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@
M:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP
M="(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`U"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T
M871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO=7-E<BYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY(&%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T
M:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C@P
M(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU,0IM<V=I9"`B
M4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T
M;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS9VED(")3
M=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N
M9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P
M9&%T960@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`T"FUS9VED(")3=61A;B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"FUS
M9VED(")3=6UM87)Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8S"FUS
M9VED(")3=6YN>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C`U"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ
M-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-`IM<V=I9"`B4W5N<FES93H@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#@*
M;7-G:60@(E-U;G-E="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C`W"FUS9VED(")3=6YS970Z("(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S"FUS
M9VED(")3=7!E<G-C<FEP="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S@P"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#8*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<U"FUS9VED(")3=7)N
M86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-V86QB87)D
M(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I
M9"`B4W=A>FEL86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@
M(E-W961E;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I='IE
M<FQA;F0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z.#8*;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3>6YT
M87@@97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#<*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS
M9VED(")4+5-T;W)M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV-@IM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(E0M
M4W1O<FUS($5A<FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A
M=&$O='-V+G!H<#HQ-S`*;7-G:60@(E135B!F:6QE(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PIM<V=I9"`B
M5&%B;&4@4V5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E
M<G1I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S0@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B
M5&%I=V%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N
M:71E9"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU"FUS9VED(")487)G970Z(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.34X(&-O
M;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#4Y"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ.#D*;7-G:60@(E1A<VMS(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<T"FUS9VED(")496QE<&AO
M;F4@3G5M8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,CDR"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-@IM<V=I9"`B5&5M<&5R871U<F4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q
M,@IM<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@R"B,L('!H<"UF;W)M870*;7-G:60@
M(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HV
M.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*
M;7-G:60@(E1E;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3$@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S,T-0IM<V=I9"`B5&5X="(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S<R"FUS9VED(")497AT($]N;'DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW-`IM<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"FUS9VED
M(")497AT=&]P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")4:&%I("A425,M-C(P
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4:&%I;&%N9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@V,PIM
M<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAI<W1O<GDO2&ES=&]R>2YP:'`Z-34*
M;7-G:60@(E1H92!(:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY-C0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N
M9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7TE-4U`O24U34"]";V]K+G!H<#HQ,CDX"FUS9VED(")4
M:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,S$*;7-G:60@(E1H
M92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L
M;'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R
M+G!H<#HR.0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N
M($5X:71I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,3DP(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C`Q"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C$R(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,C(T"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C,U
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C4S"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,C8U(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,S`T"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF
M:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@
M(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*
M;7-G:60@(E1H92!B;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS
M9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I
M960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T
M86)A<V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E
M<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$X,0IM<V=I
M9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-#$*;7-G:60@(B(*(E1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@
M96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD
M("(*(FEN('1H92!D871A8F%S92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*;7-G:60@(E1H
M92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+G!H<#HQ,38*;7-G:60@
M(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B
M(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,3@V(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3(R"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN
M(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ-SD@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A
M:6X@<V]M92`E<R!S971T:6YG<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T1A=&$O1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@
M;F\@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@
M=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@
M:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E
M<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L
M92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R
M8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R
M(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I
M<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T
M(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@
M<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E("(*
M(G!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S
M8W)E96X@961I=&]R+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP
M:'`Z,3$Q"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S
M7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B
M5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C
M871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H
M92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-1$XN<&AP.C(P,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<
M(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R
M86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R
M<W1O;V0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X.34*;7-G:60@(E1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@
M=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HT-S0*;7-G:60@(E1H92!N=6UB97(@;V8@9FEE;&1S
M(&UU<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C,R"FUS9VED(")4:&4@;W!E;G-S;"!M
M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ
M(&-L87-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,N
M<&AP.C(X.`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')E9F5R96YC
M92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@
M97AC965D960@=&AE("(*(FUA>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O9&5B+G!H<#HS
M,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z
M,S4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-P;W=E<G!O:6YT
M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N
M<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)P;2YP:'`Z
M,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=V5B8W!P+G!H<#HS
M-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP
M:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-E>&-E;"YP
M:'`Z,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E
M9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O
M;B!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HT.#<*;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@;75S
M="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM
M<V=I9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'DB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW.`IM<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0W.0IM<V=I
M9"`B5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R
M+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@
M8F5E;B!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<G!C<W5M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R
M(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@
M<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT
M-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@*"5D
M*2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HR,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E
M;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R,`IM<V=I9"`B5&AE
M('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T
M:&4@<V-R965N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED(")4:&4@=&]P(&%N
M9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4
M:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T
M82]$871A+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A<R!L
M;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R86UE=V]R:R]$871A
M+T1A=&$O='-V+G!H<#HQ-S8*;7-G:60@(E1H92!U<&QO861E9"!F:6QE(&-O
M=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C0Y(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ,3`*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A
M:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z
M,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S
M7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C$W.`IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@
M879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HS-#D*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T
M:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#`Q"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@
M9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U
M(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B"@HC.B!S:6=N
M=7`N<&AP.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG(%PB)7-<(B!T;R!T:&4@
M<WES=&5M.B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A
M<FEN9R!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@
M9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,34Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L
M96T@=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,C4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@
M3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0G)O=W-E<B]"<F]W<V5R+G!H<#HY,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@
M5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D
M('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R
M;W=S97(O0G)O=W-E<BYP:'`Z.3,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H
M92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S
M<V%G92!P87)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HS.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T1A=&$O1&%T82]I;6,N<&AP.C,P"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HX,@IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN
M(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,X"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@<&5R
M9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@
M4&QE87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#`*;7-G
M:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C
M="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R
M,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D
M:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,30Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C(Y.0IM<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T
M('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO
M="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HU,@IM
M<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@
M9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S$T-0IM<V=I9"`B5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@
M8V%R9"!N=6UB97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D
M<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@
M0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y
M+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S0*;7-G:60@(B(*(E1H:7,@
M9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE
M(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W87DL('5S:6YG('1H
M92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS
M,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I
M;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U"FUS9VED("(B"B)4
M:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU4
M4"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY
M('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C
M8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N
M:70I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY
M-S@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`U-PHC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,#@V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q
M,34*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X,B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,C4V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$S,#4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Y.`HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-34W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X-3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW-B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,#(S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(P-#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`Y-@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,38W(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(R,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0R-B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#8X"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(V-34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@R.`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3,W(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,S,34*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@R,R!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#,Q"FUS9VED(")4:&ES(&9I96QD
M(&ES(')E<75I<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,#8U"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@:6YT96=E<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(T,S0*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I
M;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$P.30*;7-G:60@(E1H:7,@9FEE;&0@;6%Y
M(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE;&0@
M;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN
M=&5G97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.CDX.0IM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#,V
M"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O
M9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R
M,S1A9B<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C4V,0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S
M<V5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0Y-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C
M="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL
M("(*(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A
M<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI96YT
M<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]#;VYT96YT<RYP:'`Z-3DY"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@
M*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB
M97(@;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HT-0IM<V=I9"`B5&AI
M<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R
M>2YP:'`Z,3@V"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A
M8W1I=F%T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB
M97(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME
M<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R
M;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*;7-G:60@(E1H=6YD97(B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S-@IM
M<V=I9"`B5&EC:V5T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-#0S('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-PIM
M<V=I9"`B5&EM92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S@X"FUS9VED(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4T.0IM<V=I
M9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM
M<V=I9"`B5&EM;W(M3&5S=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE
M+G!H<#HR,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@
M*'1O;VQT:7`I.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C4T"FUS
M9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T
M:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y("(*(G=H:6QE
M(&-L:6-K:6YG+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S`P"FUS9VED(")4;V1A>2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(X"FUS9VED(")4
M;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM
M<V=I9"`B5&]G;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4
M;VME;&%U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS,#(*;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3`*;7-G:60@(E1O;F=A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O:V]L86(N<&AP.C$P-`IM<V=I9"`B5&]O(&UA;GD@:6YV86QI
M9"!L;V=I;G,@9'5R:6YG('1H92!L87-T(&UI;G5T97,N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW-PIM<V=I9"`B5&]P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O<"!F<F%M92`H
M7W1O<"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S
M"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,0IM<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-SDP"FUS9VED(")4<G5E(&]R(&9A
M;'-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DU"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=7)K;65N:7-T86XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)
M<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U=F%L
M=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<S"FUS
M9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(U.`IM<V=I9"`B52Y6+B!I;F1E>#H@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@(E52
M3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4T,0IM<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP="!D
M96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3<*;7-G:60@(E523#HB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A;F1A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#(X"FUS9VED(")5
M;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B56YA
M8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN
M9R!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HS.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P
M97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0P,2!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z-#<Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-SDX"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.3<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O
M9B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C8U(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z.30*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C8W"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z
M-#,Y"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@X,@IM
M<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(T,2!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR-#8*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C(S,R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,C,X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR-#8*;7-G
M:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,W,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-S`@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(V.0HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,CDS"FUS9VED(")5;F%B;&4@=&\@8W)E
M871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HQ,C,*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@
M5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z,S`S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A
M=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(X,0IM<V=I9"`B56YA8FQE('1O(&-R96%T
M92!E;7!T>2!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+W1A<BYP:'`Z-S4*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+V=Z:7`N<&AP.C4R"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]G>FEP+G!H<#HX,@IM<V=I9"`B56YA8FQE('1O(&1E8V]M
M<')E<W,@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HR,S$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H
M92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C<X(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS
M-#<@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT-3`*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C,R,B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,S@Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HT,#,@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C0P-PIM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-3,@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C,S,PHC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,S0V(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS
M-30*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,Y.0IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0W-2!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C0X-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(S-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S$Y(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S,T"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HQ-C8@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C$W.0HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@V(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HT,S@*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C0T-@IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HR-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HT-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@T-@IM<V=I9"`B
M56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,#0*
M;7-G:60@(E5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`N<&AP.C0S
M-R!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]!=71H+G!H<#HQ,C,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@
M;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(Q,2!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,38*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$Y."!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,C`S"FUS9VED(")5;F%B;&4@=&\@;6]V92!6
M1E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HY,R!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C$P-@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C8W-"!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C$R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E
M;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C(Y,R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,34W"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ
M-C`*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HX
M-B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-#`*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.CDU"FUS9VED(")5;F%B;&4@=&\@;W!E
M;B!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HT-0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M
M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z.#0S"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H
M9FEL97-I>F4H*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z.#<X"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL
M92`H<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]3
M97-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`IM<V=I
M9"`B56YA8FQE('1O(')E860@9FEL93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C8Y,0IM<V=I9"`B56YA8FQE('1O(')E
M860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q-#8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L
M9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HS-#(*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HS.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR.#`@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HS-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(')E;F%M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C8S,B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,C0P"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z,S@Q(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HR,3(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0V,R!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S,T"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-38*;7-G:60@(E5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA
M8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L
M92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3@S,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@=')I9V=E<B!F<F5E+V)U<WD@=7!D871E
M(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C$W."!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$X,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ
M.#D*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A
M:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(Y-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,38U"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-S`*;7-G:60@(E5N
M86)L92!T;R!W<FET92!61E,@9FEL92!D871A+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z.#4S"FUS9VED(")5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`*;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(X"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C0R-PIM<V=I
M9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T
M:6]N.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,C(T"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,W.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HT,34*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z-#(Q"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R
M=F5R('1O.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*;7-G:60@(E5N9FEL960B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.38*;7-G:60@(E5N:6-O
M9&4@*%541BTX*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI
M=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS
M9VED(")5;FET960@2VEN9V1O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S
M"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3,*;7-G:60@(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HW.`IM<V=I9"`B56YI=',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(Y(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0S,`HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C4X"FUS9VED(")5;FMN;W=N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)($UE
M<W-A9V4@240I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@(E5N:VYO=VX@8VQI
M;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T-PIM<V=I9"`B56YK;F]W;B!L
M;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED(")5;FMN
M;W=N('5S97)N86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*
M;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R])9&5N=&ET>2YP:'`Z,S`T"FUS9VED(")5
M;FYA;65D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL96=E9"!S8W)I
M<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A
M;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E
M(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB<VAO
M=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L
M:7!B;V%R9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@IM<V=I9"`B56YS970@8V]L;W(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV.#<@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,C<*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,S,*;7-G:60@(E5N
M<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C$Y-R!T96UP;&%T97,O861M:6XO=7-E<B]L
M:7-T+FEN8SHS,PIM<V=I9"`B57!D871E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,CD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B57!D871E("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z-S8*;7-G:60@(E5P9&%T92!U<V5R(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,30T(&%D;6EN+W!E<FUS+V5D
M:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,P"B,L('!H
M<"UF;W)M870*;7-G:60@(E5P9&%T960@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX,PIM<V=I9"`B57!G<F%D92!S
M8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$W-R!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3DX"FUS9VED(")5<&QO860B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$X-0IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T
M:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,C`*;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N
M9RYJ<SHQ.`IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$S"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0U
M"B,L('!H<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4S.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3(W"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R
M9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"FUS9VED(")5
M<V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I
M<W1R>2YP:'`Z-S<Q"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@
M;F]T(&%U=&AO<FES960@9F]R("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HR,#,*;7-G:60@(E5S97(@061M:6YI<W1R871I;VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR-#4*;7-G
M:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C8R
M"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!S:6=N
M=7`N<&AP.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D
M:7-A8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-#DT"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O
M=6YD(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-S@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.3@*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34P('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C,T"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S(@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S
M97)N86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG
M;G5P+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E
M<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"FUS9VED(")5
M<V5R;F%M93H@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3<S(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C(W,0IM<V=I9"`B5D93(&1I<F5C=&]R
M>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$R,`IM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8V"FUS9VED(")686QI9"!L
M;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(")686QI9&ET
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4Y-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR-34*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@
M9G)O;2!N;W<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C@U-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3<W"B,L('!H<"UF
M;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H
M(&]F("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,C8R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R.#0*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,S-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.3(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP
M:'`Z-3D*;7-G:60@(E9A;'5E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,3(W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R
M,#0*;7-G:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$W"FUS9VED(")686YU871U(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S,*;7-G:60@(E9A<FEA8FQE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G
M92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`Q"FUS9VED(")6
M97)S:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR,C@*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S
M"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T"FUS9VED(")697)T
M:6-A;"!P861D:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HW-`IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,38*;7-G:60@(E9I970@3F%M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DW"FUS9VED(")6:65T;F%M97-E("A625-#24DI(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.CDW
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N
M86P@=V5B('!A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z.#,P"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@
M87,@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN
M($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM
M<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,3$*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,@IM<V=I
M9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A
M9F]N92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP
M.C,V"FUS9VED(")705).(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@
M4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S,PIM<V=I
M9"`B5TE.('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G
M:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP
M:'`Z,CD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z
M,3(W(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HY-0IM<V=I9"`B5V%R;FEN9R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C4X"FUS9VED(")792(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H97(@1F]R96-A<W0B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q
M-@IM<V=I9"`B5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y,@IM<V=I9"`B5V5A=&AE
M<BYC;VTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*
M;7-G:60@(E=E8B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#,Y"FUS9VED(")796(@4VET92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4X"FUS9VED(")7
M965K;'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP
M:'`Z,C@*;7-G:60@(E=E;&-O;64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VUO8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C4W"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA
M=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E
M;&-O;64L("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DX"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y.0IM<V=I9"`B5V5S=&5R;B`H25-/
M+3@X-3DM,34I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")797-T
M97)N(%-A:&%R82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#,T"B,L('!H<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC871I;VX@
M<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T(&ES
M('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@
M<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V-0IM<V=I9"`B5VAE<F5I<R!!
M=7-T<F%L:6$@;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,S8*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@
M96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$R-0IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-30*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE
M9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V
M"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G:60@
M(E=I9'1H('5N:70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$U"FUS9VED(")7
M:6MI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR.#D@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*
M;7-G:60@(E=I;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-S`*;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX-PIM<V=I9"`B5VEN9"!S
M<&5E9"!I;B!K;F]T<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$U.`IM<V=I9"`B5VEN9#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(S,0IM<V=I9"`B5VEN9#H@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.3@*
M;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*;7-G:60@(E=O<FL@
M061D<F5S<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$Y,R!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HR.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E
M9"P@9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB
M97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$R-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A
M(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C0U"FUS9VED(")8+5)E9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S($)A
M<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@17AT96YD960@
M2V5Y(%5S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA
M=&EV92!.86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3DV"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+97D@261E
M;G1I9FEE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8X,PIM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,30*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0U-@IM<V=I9"`B65E962(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$Q,0IM<V=I9"`B66%H;V\A(&UA
M<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E
M;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-PIM<V=I9"`B665M96XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV-@IM<V=I9"`B665S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC
M92YH=&UL.C4V"FUS9VED(")997,L($D@06=R964B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I
M9"`B66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N
M('1O('-W:71C:"!B86-K('1O(%=94TE764<N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,C,V"B,L
M('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E
M871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,30Q-0IM<V=I9"`B66]U(&%R92!N;W0@
M875T:&5N=&EC871E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+TED96YT:71Y+G!H<#HS,3`*;7-G:60@(EEO=2!C86YN;W0@:&%V92!T:&4@
M)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S,@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3DY,PIM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V
M86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1&%T82]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U
M(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE
M('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@W"FUS9VED(")9
M;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R-C$*;7-G:60@(B(*(EEO=2!H879E('1O
M(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@
M=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L
M(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,3@X"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A
M;&ED('9A;'5E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A
M=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#8U"FUS9VED(")9;W4@;75S
M="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T
M(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE
M('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E
M;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*;7-G:60@
M(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$Y"FUS9VED(")9;W4@;75S
M="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P96-I
M9GD@82!U<V5R;F%M92!T;R!R96UO=F4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C8R('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#8*;7-G:60@(EEO
M=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z
M,3,X"FUS9VED(")9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E
M<F9O<FTN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#
M871E9V]R>4UA;F%G97(N<&AP.C<Q"FUS9VED(")9;W4@;75S="!T>7!E(&$@
M;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S"FUS9VED(")9
M;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N
M(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*;7-G:60@(EEO=7(@16UA:6P@061D
M<F5S<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`W
M"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-S<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@U"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY,@IM<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-SD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D
M('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B
M"B)P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHS,PIM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VYO861D+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE
M;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E
M<G,N($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R
M('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A
M=71H96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T
M:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@
M=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O
M<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z.3@S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO
M=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@
M8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y
M;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3<*;7-G:60@(EEO=7(@8G)O
M=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z-#(*;7-G:60@
M(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@
M;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT
M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4S"FUS
M9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P<F5F<RYP:'`Z,3$W"FUS9VED(")9;W5R(&1E9F%U;'0@:61E
M;G1I='D@:&%S(&)E96X@8VAA;F=E9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$U,PIM<V=I9"`B66]U<B!D969A=6QT(&ED96YT
M:71Y.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DV
M"FUS9VED(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z.3DY"FUS9VED(")9;W5R(&QO9VEN(&AA<R!E
M>'!I<F5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HW-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R
M9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B
M965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,34V"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V"FUS
M9VED(")9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@P"FUS9VED("(B"B)9
M;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL
M(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S,S"FUS9VED(")9
M;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G:60@(EEO=7(@<F5M;W1E
M('-E<G9E<G,Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C4T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G
M:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N
M<&AP.C(P,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ
M<SHQ,@IM<V=I9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!R;V)L96TN<&AP.C@Y"FUS9VED(");4')O8FQE;2!297!O
M<G1=(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E
M0FQO8VMS+FIS.C$S"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI
M9VAT<75O=&5S+G!H<#HR,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@
M475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HR,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T
M86PO;65N=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R
M("(B"@HC.B!L:6(O87!I+G!H<#HR,C,*;7-G:60@(E]#3$DB"FUS9W-T<B`B
M(@H*(SH@;&EB+V%P:2YP:'`Z,C`W"FUS9VED(")?1&%T851R964B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,Q"FUS9VED(")?1&5L971E(%)O=R(*;7-G<W1R("(B"@HC
M.B!L:6(O87!I+G!H<#HQ.3D*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DT"FUS9VED
M(")?3&]G(&EN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]-96YU+G!H<#HQ.3`*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR-`IM<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-C0*;7-G:60@(E]/<'1I
M;VYS(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C(P,PIM<V=I9"`B7U!E
M<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@IM<V=I9"`B7U)E;6]V92!,
M:6YK+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$Y,0IM<V=I9"`B
M7U-E='5P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E
M<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3DU"FUS9VED
M(")?57-E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HY-3$*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S-`IM<V=I9"`B861D
M<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY-#,*;7-G:60@(F-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3<T(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S8P"B,L('!H<"UF;W)M870*;7-G:60@(F-A;&TB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A
M;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O
M<&5N(&EN<'5T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C8P,`IM<V=I9"`B8VQI8VL@:&5R92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R,@IM<V=I
M9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<X"FUS9VED(")C;VYF
M:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED(")C<FET:6-A;"!S>7-T96T@
M9FEL92!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,3(V"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C,P"FUS
M9VED(")E9&ET(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,3@R"FUS9VED(")E;G1R>2!N;W0@9F]U;F0B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-S4*;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R
M;W=S97(O0G)O=W-E<BYP:'`Z.#DV"FUS9VED(")F:6QE(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<V(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S8R(&QI8B]";&]C:R]M971A<BYP:'`Z,S@X"B,L('!H<"UF;W)M870*
M;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S.0IM<V=I9"`B9W5S
M=&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C4P"FUS9VED(")H.B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4Y"FUS9VED(")H
M:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O9&EF9BYP:'`Z-C0@861M:6XO<V5T=7`O9&EF9BYP:'`Z-S8*;7-G
M:60@(FEN;&EN92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,30V"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM
M<V=I9"`B;&EN97-=(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E3
M3RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,W,`IM<V=I9"`B;6TB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HR.#4@<V5R=FEC97,O<&]R=&%L+W-I
M9&5B87(N<&AP.C$W-`HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,C0S"FUS9VED(")N86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]24$,O
M4E!#+G!H<#HQ,C0*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,C`*;7-G
M:60@(FYO="!Y970@:6UP;&5M96YT960B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S4*;7-G:60@(FYO=&5P860B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W-`IM<V=I9"`B<&5R;6ES
M<VEO;B!D96YI960B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,3<P"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S<*
M;7-G:60@(G)I<VEN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$T,@IM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L
M92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C$P,0IM
M<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B
M<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HS.#<*;7-G:60@(G-S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C<V"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDU.0IM
M<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,38V"FUS9VED(")T96UP;W)A<GD@9F%I;'5R
M92(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z,C<P"FUS9VED(")T>7!E('1H92!P87-S
M=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+V1I9F8N<&AP.C8T(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<V"FUS9VED
M(")U;FEF:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S
M"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR-#(*;7-G:60@(G<Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED(")W96%T:&5R+F-O;2(*;7-G<W1R
M("(B"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+VUK7TU++G!O````````````````
M````````````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#8Q,38T-B`Q
M,#4Q-30S,S<T,R`P,3<U,S(`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````(R!T<F%N<VQA=&EO;B!O9B!M:U]-2RYP;R!T;R!-
M86-E9&]N:6%N"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H
M92!S86UE(&QI8V5N<V4@87,@=&AE($AO<F1E('!A8VMA9V4N"B,@0V]P>7)I
M9VAT("A#*2`R,#`S($5U<F5K82!);F9O<FUA=&EK80HC(%-T;VIA;B!097-O
M=B`\<W-P0&5U<F5K82YC;VTN;6L^+"`R,#`S"B,*;7-G:60@(B(*;7-G<W1R
M("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ(&UK7TU+7&XB"B)297!O<G0M37-G
M:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T
M:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I
M;VXM1&%T93H@,C`P,RTP-BTR-B`Q-3HQ."LP,C`P7&XB"B),87-T+51R86YS
M;&%T;W(Z(%-T;VIA;B!097-O=B`\<W-P0&5U<F5K82YC;VTN;6L^7&XB"B),
M86YG=6%G92U496%M.B!-86-E9&]N:6%N(#QI,3AN0&QI<W1S+FAO<F1E+F]R
M9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E
M>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM-5QN(@HB0V]N=&5N="U4<F%N
M<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@HB6"U'96YE<F%T;W(Z($M"86)E;"`Q
M+C`N,5QN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,V.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S-S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M("AI;B`E<R!D87ES*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S<S"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<U"FUS9VED("(@*'1O;6]R<F]W
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<Q
M"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(U-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S8Q"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,#<*
M;7-G:60@(B!A="`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO
M="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#
M3$DN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T
M(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C8U.0HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O4F5G:7-T<GDN<&AP.C$P-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R
M>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1R964O5')E92YP:'`Z,3<Q
M"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T
M;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B)R5S)R#CX=_5Z-W>(-3>
MU-#4U=T@W=`@X=CAXM7<WN(N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N
M<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@
M=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E871E9#H@
M)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL
M;W=E9"`H)2XR9B4E*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C,W"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N
M9"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C(V."!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-34W"B,L('!H<"UF;W)M
M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C@U"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-C@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.C@S-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!+0B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T
M:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(E<R"^W]7@T.;8V"#7T"#>
MU.#6X]+0^M4@+2"_WN+2X-30(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$U"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HR-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M4VEG;B!5<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP
M:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M
M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M-#(X(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DP"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z-C4Q(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U.2!L:6(O
M0FQO8VLO;65T87(N<&AP.C$V-2!L:6(O0FQO8VLO;65T87(N<&AP.C(S.0HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T-2!L:6(O0FQO8VLO;65T87(N<&AP
M.C,U,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E<F9O<FT@
M=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE
M8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T
M;R!P97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`BLMK;X^?8(-#:WB#A
MT-K0Z"#4T"#8U]+@Z-CH(-W5VM[8(-[?U>#0YMC8(-+>(-S>W-7=XM[2+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;6EN
M=71E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L
M;&5C=&EO;BYP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR,@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB
M"FUS9W-T<B`BL-3@U>'0X"(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3$T"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,P"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H
M<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,C<R"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO
M="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L
M;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE
M('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V-2!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#$P"FUS9VED("(L(&=U<W1I;F<@
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@X(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@(BP@9W5S
M=&EN9R`E<R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@
M=&\@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HR.30@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-#@*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`V.2!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,3(X"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HW-#D*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO=7(@1F]R;6%T
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ.0IM<V=I9"`B
M,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T(.?0X=`B
M"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C8Y"FUS9VED("(\4')E
M=FEO=7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3D*
M;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI
M<R!B;&]C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ-C`*;7-G:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDS
M-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R
M>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3$V-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I
M<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Y-PIM
M<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*(FUE
M<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$P,34*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A
M=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I
M9VX@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4P-0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-
M24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS
M9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K
M97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@
M;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HS-C0*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R
M97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B
M04T@0VQO=61S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!,:6=H="!286EN(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$Q"FUS9VED(")!32!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED(")!32!3:&]W97)S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$S"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM
M<V=S='(@(D%-+U!-(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C`P"FUS9VED(")!4$D@240B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM
M<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O:&5L<"]I;F1E>"YP:'`Z-3(*;7-G:60@(D%B;W5T+BXN(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M:61D
M;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T
M;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,3,V"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,PIM<V=I
M9"`B06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-S4*(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G0@4&%S
M<W=O<F0B"FUS9W-T<B`BO][BTN#4V"#;WM?8W=K0(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!
M8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,S,PIM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T."!T96UP;&%T97,O
M<&]R=&%L+V%D9"YI;F,Z,30*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A
M9&1C:&EL9"YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(D%D9"(*;7-G<W1R("*P
MU.#5X=`B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G<F]U<',N
M<&AP.C(R-0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3@@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HY.0IM<V=I9"`B061D($-H:6QD(%!E<FUI<W-I
M;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*
M(RP@9G5Z>GD*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R("*TWM30U-@@VM[@
MV.'=V-HB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(Q."!A9&UI;B]G<F]U<',N
M<&AP.C(Q.0IM<V=I9"`B061D($YE=R!'<F]U<"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z.#@*;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO;B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD
M+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P
M('1O(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL
M9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S='(@(K3>
MU-#4V"#=WM(@VM[@V.'=V-HZ(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C4U-`IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,T"B,L
M(&9U>GIY"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`BM-[4T-38
M(-W>TB#:WN#8X=W8VCHB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.CDU"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R("*TWM30U-@@W]#@(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C<Q"B,L(&9U>GIY"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G
M<W1R("*PU.#5X=#@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C<X"B,L(&9U>GIY"FUS9VED(")!9&0@=&\@;7D@861D<F5S
M<R!B;V]K(@IM<V=S='(@(K#4X-7AT.`B"@HC.B!A9&UI;B]U<V5R+G!H<#HS
M,0IM<V=I9"`B061D('5S97(B"FUS9W-T<B`BM-[4T-38(-K>X-CAW=C:(@H*
M(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M061D960@7"(E<UPB('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D
M(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`B"B(E<RXB"FUS9W-T
M<B`B(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!
M9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI
M;F,Z,@IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R
M("*TWM30TM#ZU>+>(-W0(-K>X-CAW=CFV"#5(-[=U=+>U]S>UM7=WBXB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(V"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-S,@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,0IM<V=I9"`B061D<F5S<R(*;7-G
M<W1R("*PU.#5X=`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,Y
M"B,L(&9U>GIY"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`BL-3@U>'0
MX"(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT
M"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE
M<B!U<V5R<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R
M=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R
M871I;VXB"FUS9W-T<B`BL-3<V-W8X>+@T.;8^-`B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S0Q"B,L(&9U>GIY"FUS9VED(")!9',B"FUS9W-T
M<B`BL-3@U>'0(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B069G:&%N:7-T86XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU-PHC+"!F=7IZ>0IM<V=I9"`B06QB86YI82(*
M;7-G<W1R(")!;&EA<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*(RP@9G5Z>GD*;7-G:60@(D%L
M9V5R:6$B"FUS9W-T<B`B06QI87,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R(")!
M;&EA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,38*(RP@9G5Z>GD*;7-G:60@(D%L:6=N(@IM<V=S='(@(D%L
M:6%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R
M<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R
M;W5P<RYP:'`Z,C(R"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+V1A=&%T<F5E+G!H<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I
M;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S$*;7-G
M:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,T"FUS9VED(")!;&QO=R!S971T:6YG
M(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HU,#0*;7-G:60@(D%L<F5A
M9'D@97AI<W1S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,C,*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#<*;7-G:60@(D%L=&5R;F%T
M92!)35-0(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT.3D*;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"B,L
M(&9U>GIY"FUS9VED(")!;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R
M("*RT.C0($5M86EL(-#4X-7AT#HB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$T,@IM<V=I9"`B06QT97)N871E('1E;7!L871E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4X"FUS9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E
M('=A<R!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-C<*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@:&%S
M(&]C8W5R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%N9&]R
M<F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YG;VQA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I;&QA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N
M;VYY;6]U<R!0<F]X>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M-@IM<V=I9"`B06YT:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS-0HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4X('1E;7!L871E<R]A
M9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM
M<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@IM<V=I9"`B
M07!P;&EC871I;VX@3&ES="(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,30P"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,3@*;7-G
M:60@(D%P<&QY('1O($-H:6QD(%-H87)E<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B07!P<F]V
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HX,S,*;7-G:60@(D%P<')O>&EM871E(%-I>F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-`HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C@*;7-G
M:60@(D%P<FEL(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3<U"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU.2!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8V"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#$*;7-G:60@(D%R8VAI=F4@
M1FEL92!3:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-3@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HV-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C@P"FUS9VED(")!<F-H:79E($YA;64B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E
M('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E(%PB
M)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS
M9VED(")!<FUE;FEA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3<V"FUS9VED(")!<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!<G5B82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I
M;VX@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HR.0IM<V=I9"`B07-C:6D@07)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I9FEC(%)E
M9VEO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(U
M"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$Q,PIM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@(D%T
M=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C(Y"FUS9VED(")!='1E
M;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HX-PIM<V=I9"`B071T
M96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I9"`B
M071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8T
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-@IM<V=I9"`B071T
M<FEB=71E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`X"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B075G=7-T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4Y"FUS9VED(")!=7-T<FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L.B!2
M97%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$S-0IM<V=I9"`B
M075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A
M<&%B:6QI=&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM
M87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]F='`N<&AP.C,V"FUS9VED("(B"B)!=71H7V9T<#H@
M4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0
M('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z-C0*;7-G:60@(D%U
M=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C4Q
M"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES
M(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS-3<*;7-G:60@
M(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F
M;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C8S"FUS9VED(")!=71H7VQD87`Z(%)E<75I
M<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,SD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,X-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0Y
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!U
M<&1A=&4@=7-E<B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U
M<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C0V
M"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S
M;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U
M=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS9VED
M(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z
M,3<V"FUS9VED(")!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@
M<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C@U,0IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F
M86EL960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z-S`*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R
M(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`BM-[A
MXM#?W=@@W][;V/K0.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%Z97)B86EJ86XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,P"FUS9VED
M(")"3T9(($5X8W5S97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R
M;W5N9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#$*;7-G
M:60@(D)A9"!K97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D(&ME<F)E
M<F]S('5S97)N86UE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"
M86AA;6%S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)A:')A:6XB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S<*;7-G:60@
M(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*
M;7-G:60@(D)A;F=L861E<V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I
M9"`B0F%R8F%D;W,B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N
M<&AP.C,Q"B,L('!H<"UF;W)M870*;7-G:60@(D)A<V4@9W)A<&AI8W,@9&ER
M96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PIM<V=I
M9"`B0F%S96QI;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L
M87)U<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"96QG:75M(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&EZ92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8Q"FUS9VED(")"96YI;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8R"FUS9VED(")"97)M=61A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G
M:60@(D)H=71A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G<W1R
M("+`WM35W=35W2(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T
M:6]N+G!H<#HS-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB
M(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHX.0IM<V=I9"`B0FQO
M8VL@4V5T=&EN9W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L
M87EO=70N:6YC.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.`IM<V=I
M9"`B0F]L9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")";VQI=FEA
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,#4*
M;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(P"B,L(&9U>GIY"FUS
M9VED(")";W)D97(B"FUS9W-T<B`B2&]R9&4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI
M8VMN97-S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(Q"B,L(&9U>GIY"FUS9VED(")";W)D
M97)S(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA
M(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.38*;7-G:60@(D)O=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,PIM<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")";W1T
M;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"B,L(&9U>GIY"FUS9VED(")"<F%Z
M:6PB"FUS9W-T<B`BO][HXM`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES
M:"!);F1I86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HT,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C$*;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE
M=&5D($QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R:VEN
M82!&87-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0T-`HC
M+"!F=7IZ>0IM<V=I9"`B0TU3(@IM<V=S='(@(D-64R(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y
M-PIM<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C,*;7-G:60@(D-A
M8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#0@8V]N9FEG
M+VAO;VMS+G!H<"YD:7-T.CDX-PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,34U"FUS9VED(")#86QE;F1A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0V"FUS9VED(")#86QM(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8W"FUS9VED(")#86UE<F]O;B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N(&YO="!R97-E
M="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI
M<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-3
M5BYP:'`Z,S$X"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B!N;W0@=W)I=&4@
M=&\@9FEL92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N
M<&AP.C(R"FUS9VED(")#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I
M;VX@:&%N9&QE<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER=7,N<&AP.C(S-2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP
M:'`Z,S$Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN
M96-T('1O($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R("*]U>/AW]7HW=`@VM[=
MU=KFV/C0(.'>($Q$05`@X=7@TM7@WN(N(@H*(SH@9G)A;65W;W)K+T9I;&5?
M0U-6+T-35BYP:'`Z-#$S"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&]P
M96X@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HT.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@
M(D-A;F%D82(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M
M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHV-0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T
M92YI;F,Z,3$@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G:60@(D-A
M;F-E;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@
M(K[BVM#6V""_X-[1V]7<(,#5W][@XB(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z,S$X"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D96QE
M=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HT-@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R"FUS9VED(")#86YN;W0@9FEN
M9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A
M;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,30*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T
M851R964N<&AP.C$R."!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L
M+G!H<#HV.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@
M)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$
M871A5')E92]$871A5')E92]S<6PN<&AP.C8P.`IM<V=I9"`B(@HB0V%N;F]T
M(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R
M9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF
M:65D(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0V%P
M92!697)D92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(T"B,L(&9U>GIY"FUS9VED(")#87!T
M:6]N(@IM<V=S='(@(K?0Y^/2T/@@WM_FV-@B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP"FUS9VED
M(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#8*;7-G:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E
M;&P@4&AO;F4B"FUS9W-T<B`BO-[1V-O5W2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*(RP@9G5Z>GD*;7-G
M:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G<W1R("*\WM'8V]7=(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@
M(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P
M<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS9VED(")#96QL('-P86-I;F<Z(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-S0*(RP@
M9G5Z>GD*;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R("*\WM'8V]7=(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D-E;'1I8R`H25-/+3@X
M-3DM,30I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L
M:6,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G
M:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-CDY"FUS9VED
M(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C$Q"FUS9VED(")#97)T:69I8V%T
M92!/=VYE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4Y-@IM<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")#:&%D(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z.38*(RP@9G5Z>GD*;7-G:60@(D-H86YG92(*
M;7-G<W1R("*^XMK0UM@@T]@@W^#>W-7=V.+5(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C,Q"B,L(&9U>GIY"FUS9VED(")#:&%N9V4@66]U
M<B!087-S=V]R9"(*;7-G<W1R("*_WN+2X-38(-O>U]C=VM`B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M
M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@
M86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS+B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*;7-G:60@(B(*(D-H86YG
M:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C
M=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#;VYT86-T('EO=7(@861M:6YI
M<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PIM<V=I9"`B0VAA<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HU,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D-H:6QE(@IM<V=S='(@(KW0
MX=O>TB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS9VED(")#:&EN97-E(%-I;7!L
M:69I960@*$=",C,Q,BDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#$*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR
M-CD*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@
M(K_>XM+@U-@@V][7V-W:T"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG
M;G5P+G!H<#HR-C@*;7-G:60@(D-H;V]S92!A('5S97)N86UE(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.3@*;7-G:60@(D-H;V]S
M92!H;W<@=&\@9&ES<&QA>2!D871E<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,@IM
M<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES
M=',I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H<FES=&UA<R!)
M<VQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H
M<#HR.30@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@Y,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,30*;7-G:60@(D-L96%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U3
M3V9F:6-E('1A9W,B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$R.`IM<V=I9"`B0VQE87(@475E<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0VQE87(@;W5T('5S97(Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,0IM<V=I9"`B0VQE87(@=7-E<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS
M-`IM<V=I9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"FUS9VED(")#;&5A
M<FEN9R!,871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]M86EN=&5N86YC92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B
M"FUS9W-T<B`BM]#BTM[@V"#3WB#?X-[7WN#5YM[B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR-#0*;7-G:60@(D-L;W5D<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-@IM<V=I9"`B
M0VQO=61S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$W"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR
M,PIM<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(X"FUS
M9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W
M"FUS9VED(")#;VQO;6)I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO8V]L
M;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B
M0V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O
M;&QE8W1I;VXN<&AP.C,R-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L
M;&5C=&EO;BYP:'`Z,S(U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HU,#`@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H
M<#HQ-`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHT.0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHV-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHV-@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHX,0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHX,@IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(X-#8*;7-G:60@(D-O;&]U<B!S96QE8W1I
M;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#8*;7-G:60@(D-O;'5M;B!T:71L
M97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V
M-`IM<V=I9"`B0V]M:6-S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V-M9'-H96QL
M+G!H<#HR-0HC+"!F=7IZ>0IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R("+$V.#<
MT"(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M;6%N9"!3
M:&5L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,3,*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C8*;7-G:60@(D-O;6UO;B!.
M86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")#;VUO<F]S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HR,SD*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`BQ-C@W-`B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDW"FUS
M9VED(")#;VYD:71I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR-#D*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R871I;VX@1&EF
M9F5R96YC97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$T,PIM<V=I9"`B0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$
M07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,U"FUS9VED(")#;VYF:6=U<F%T:6]N
M(&ES(&]U="!O9B!D871E+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3`P"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C4Q"FUS9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(K_>XM+@
MU-@@V][7V-W:T"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-34@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C4*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!2
M97!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDP"FUS
M9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V
M97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C<Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(')E9G5S
M960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@T-0IM
M<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,30*;7-G:60@(D-O
M;G1A8W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S
M9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<X"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O9B!<(B5S7"(B"FUS9W-T<B`BP=[4
MX-;8W=`@W=`@)R5S)R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C(Y('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,PIM<V=I9"`B0V]N
M=&EN=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HU."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]O:R!)<VQA
M;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM
M<V=I9"`B0V]O:VEE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0HC+"!F=7IZ>0IM<V=I
M9"`B0V]P>2(*;7-G<W1R("+$V.#<T"(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z-#8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y
M(&9A:6QE9#H@)7,B"FUS9W-T<B`BN-S?WN#BV.#0W=X@W][;U3H@)7,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,V"FUS
M9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$W,`HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I9"`B0V]S="!)1"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;W-T82!2:6-A(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3<V"FUS9VED
M(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`U,PIM<V=I9"`B
M0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,SDS"FUS9VED(")#;W5L
M9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT-C<*;7-G:60@(D-O
M=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$X-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HY-B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$R,0HC+"!F=7IZ
M>0IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S
M='(@(KW5X^'?U>C=T"#:WMW5VN;8^-`@X=X@3$1!4"#AU>#2U>#>XBXB"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#4W"FUS9VED(")#;W5L9"!N;W0@
M8FEN9"!T;R!L9&%P('-E<G9E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$U-@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-#$*(RP@9G5Z
M>GD*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O(&QD87`@<V5R=F5R(@IM
M<V=S='(@(KW5X^'?U>C=T"#:WMW5VN;8^-`@X=X@3$1!4"#AU>#2U>#>XBXB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U<VEN
M9R!&5%`Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q,C4*
M;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R,@IM<V=I
M9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,C0V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@8V]N
M=&%C="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C
M<FEP="!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z,S@Q(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.CDU,PIM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I
M96YT)W,@92UM86EL(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#
M;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C0Y,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R
M:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I9"`B0V]U;&0@;F]T
M(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H
M<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A
M=&5G>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ
M,3`*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/
M=71P=713=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Q.0IM<V=I9"`B0V]U;&0@
M;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M;W!E;B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E
M+TUA:6YT96YA;F-E+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T
M<B`BO-[4X]O>XB#=T"#7T-30Y]#BT"#7T"#>U.#6X]+0^M4@)7,@W=4@W-[6
MU2#4T"#1V-35(-[BTM[@U=TB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C
M=&]R>2!<(B5S7"(N(@IM<V=S='(@(KS>U./;WN(@W=`@U]#4T.?0XM`@U]`@
MWM3@UN/2T/K5("5S(-W5(-S>UM4@U-`@T=C4U2#>XM+>X-7=(@H*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HR,S<@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C0W.`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z-CDY"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5A
M8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R("*]U>/AW]7HW=`@VM[=U=KF
MV/C0(.'>($Q$05`@X=7@TM7@WN(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M3V)J96-T+G!H<#HR,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(')E860@)7,N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W
M;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H
M92`B"B)D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O
M;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U<G1H
M97(@:&5L<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S`Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,T,`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS-S<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S@S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,X.0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T
M<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,C(S"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I
M;&ET:65S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-30*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B2&]R9&4@W=4@U2#?X-#2V-O=WB#:WMWDV-/CX-C@
MT-TB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C4Y"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF
M:6=U871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HV,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A
M8VMU<"!C;VYF:6=U871I;VXZ("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF
M:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@
M;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E
M:71H97(@=7-E(&]N92!O9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E('1H92!C
M;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO
M=R!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HQ-#,*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!S96%R8V@@
M=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R("*]U>/AW]7HW=`@VM[=U=KFV/C0
M(.'>($Q$05`@X=7@TM7@WN(N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A
M=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S8V"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII
M;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HQ-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV
M92!U<V5R(%PB)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O
M;&1E<B!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T,3D*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I
M9"`B0V]U;G1R>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C<S"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P
M,`IM<V=I9"`B0W)E871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B0W)E
M871E(&$@;&EN:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O:61E
M;G1I='ES96QE8W0N:6YC.CDT"FUS9VED(")#<F5A=&4@82!N97<@;VYE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.CDR"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-#`*;7-G:60@(D-R
M96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S(S,`IM<V=I9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")#<F]A=&EA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C(V"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HT.`IM<V=I9"`B0W5R
M<F5N="!397-S:6]N<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP
M:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E;G0@5&EM
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS,PIM<V=I9"`B0W5R
M<F5N="!5<V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(U"FUS9VED(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(W-0IM<V=I9"`B0W5R<F5N="!C
M;VYD:71I;VXZ("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO
M9V]N('1O("5S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,U"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C@*;7-G:60@(D-Y<')U<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X,@IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(D-Y<FEL
M;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@T"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M
M52DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WIE8V@@4F5P=6)L
M:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0U,2!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B
M1$0B"FUS9W-T<B`B1$0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,C@Q"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA
M;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC
M92YP:'`Z-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(K3=U=+=WB(*"B,Z(&%D
M;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I9"`B1&%T851R964@0G)O=W-E<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<Y"FUS
M9VED(")$871A8F%S92!,;V]K=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,SDY"B,L(&9U>GIY"FUS9VED(")$871E(@IM<V=S='(@
M(KC7T>#8Z-@B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN
M8SHQ,PIM<V=I9"`B1&%T92!296-E:79E9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`W"FUS9VED(")$871E('-E;&5C=&EO
M;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,CDR(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,C(*(RP@9G5Z>GD*
M;7-G:60@(D1A>2(*;7-G<W1R("*TW=72W=XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*(RP@9G5Z>GD*
M;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(KC7T>#8Z-@B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@IM<V=I9"`B
M1&5C96UB97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I9"`B1&5C:6UA;"!N
M=6UB97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C`*;7-G:60@(D1E8W)E87-E($EN9&5N="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$X-R!L
M:6(O<')E9G,N<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="(*;7-G
M<W1R("*XU]'@V.C8(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z-S<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0@0V]L;W(B
M"FUS9W-T<B`BNM[@V.'BV"#AXM#=U-#@U-W0(-+@U=3=WN'B(@H*(SH@9G)A
M;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HY,0IM<V=I9"`B1&5F875L
M="!)9&5N=&ET>2(*;7-G<W1R("+!XM#=U-#@U-7=(-C4U=WBV.+5XB(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B1&5F
M875L="!3:&5L;"(*;7-G<W1R("+!XM#=U-#@U-7=(-C4U=WBV.+5XB(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B1&5F:6YI=&EO;G,B
M"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW,2!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0S.0HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY
M,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O9&5L971E+FEN8SHQ,"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S='(@(KC7T>#8Z-@B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S(*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S='(@(KC7T>#8
MZ-@B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G<F]U<',N<&AP
M.C(R-PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@(KC7
MT>#8Z-@B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#D*(RP@
M9G5Z>GD*;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T<B`BN-?1X-CHV"(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S<@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ,#$*;7-G:60@(D1E;&5T92!097)M:7-S:6]N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-3<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!C96QL(@IM
M<V=S='(@(KC7T>#8Z-@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8S"B,L(&9U>GIY"FUS9VED(")$96QE=&4@
M8V]L=6UN(@IM<V=S='(@(KC7T>#8Z-@B"@HC.B!A9&UI;B]T96UP;&%T97,N
M<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP
M;&%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C0R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO
M;G,@9F]R(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C0R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@
M<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP97)M:7-S:6]N
M<S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV-PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E(')O
M=R(*;7-G<W1R("*XU]'@V.C8(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E;&5T
M96ED96YT:71Y+FEN8SHQ-0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E('-E;&5C
M=&5D(&ED96YT:71Y(@IM<V=S='(@(L'BT-W4T.#4U=T@V-35W>+8XM7B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8W"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O=R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU-C,*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.34*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PHC+"!F=7IZ>0IM
M<V=I9"`B1&5L:79E<GD@=&EM92(*;7-G<W1R("*XU]'@V.C8(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R
M;V)L96TB"FUS9W-T<B`BOM_8X2#=T"#?X-[1V]7<WN(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HY,S@@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`HC+"!F=7IZ>0IM<V=I9"`B1&5S8W)I
M<'1I;VXB"FUS9W-T<B`BNM[<W]O5XM7=(-[?V.$Z(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ.34*;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@
M2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ.3D*;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO
M9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,3D*;7-G:60@(D1E=F5L;W!M96YT
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$W"FUS9VED
M(")$97<@4&]I;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR.30*;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-PIM<V=I
M9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE
M9G0@=&\@<FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT
M('1O(&QE9G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C8V"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PHC+"!F
M=7IZ>0IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(K?0Y^/2T/@@
MWM_FV-@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.38*;7-G
M:60@(D1I<W!L87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HX-0IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S
M="`H5$%&*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.#$W"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,3DP"FUS9VED(")$:7-P;W-I
M=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I
M9"`B1&II8F]U=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HT,C(*(RP@9G5Z>GD*;7-G:60@(D1O(&YO="!D96QE=&4B
M"FUS9W-T<B`BN-?1X-CHV"(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC
M92YP:'`B"FUS9W-T<B`BO=4@W^#8X>+0W^/2T/@@U-C@U=KBW=X@U-X@;6%I
M;G1E;F%N8V4N<&AP(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z
M,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@
M=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S
M+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I
M9"`B1&]M:6YI8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&]M
M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@
M4VEG;B!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z.#0T"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO860@9V5N97)A
M=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P-PIM<V=I9"`B1')O<"!D
M;W=N(&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,T"FUS9VED(")$<G5G<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,3,*(RP@9G5Z>GD*;7-G:60@(D4M36%I;"(*
M;7-G<W1R("*_WNCBT"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE
M<FEC7W-M='`N<&AP.CDR"FUS9VED(")%36%I;"UT;RU335,@9V%T97=A>2!D
M<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I
M9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C4@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHS-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C8Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3(*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,34@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#$@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<R"B,Z('1E;7!L871E<R]P;W)T
M86PO961I="YI;F,Z,C4*;7-G:60@(D5D:70B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU,"!T96UP;&%T97,O<&]R=&%L
M+V5D:70N:6YC.C(U"FUS9VED(")%9&ET($)L;V-K(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z,3DX(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"FUS
M9VED(")%9&ET($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z-S8@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HQ,#`*;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"FUS9VED(")%9&ET(%!E<FUI
M<W-I;VYS(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H
M<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!097)M:7-S:6]N<R!F
M;W(@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z
M-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U"FUS9VED(")%9'5C871I;VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B16ET:&5R(&5N86)L92!I="!T:&5N.B`E<RP@;W(@=7-E
M('1H92!B87-I8R!(5$U,('9E<G-I;VXZ("5S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M,PIM<V=I9"`B16QE;65N="XN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C(R-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8Y"FUS9VED(")%
M;6%I;"(*;7-G<W1R("+5+=_>Z.+0(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-C4@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X
M"B,L(&9U>GIY"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(K+0Z-`@
M16UA:6P@T-3@U>'0.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y
M-C,*(RP@9G5Z>GD*;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H
M+B(*;7-G<W1R("*[WM?8W=K8XM4@W-[@T"#4T"#1V-30XB#8X>+8+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.#D*;7-G:60@(D5M86EL('=I
M=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ"FUS9VED(")%;6%I;"UT;RU3
M35,@1V%T97=A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,CDX"FUS9VED(")%;6]T:6-O;G,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`R"B,L(&9U>GIY"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G
M<W1R("*_X-#7U=T@X-77X]OBT.(N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-C(@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S=6QT
M+B(*;7-G<W1R("*_X-#7U=T@X-77X]OBT.(N(@H*(SH@9G)A;65W;W)K+U-1
M3"]344PO2V5Y=V]R9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E
M<FUS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#,*
M;7-G:60@(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@
M1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,3@*;7-G:60@(D5N86)L92!R:6=H="!C;&EC:R!C;VYT
M97AT(&UE;G4_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(U.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,0IM<V=I9"`B
M16YD('EE87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%9&ET;W(B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R,0IM<V=I9"`B
M(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B
M92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D
M+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE(&EM86=E(%523"!H
M97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HX.3$*;7-G:60@(D5N=&5R('1H92!L971T97)S(&)E;&]W
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDY
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")%<75A=&]R:6%L($=U
M:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%<FET<F5A(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C0U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU
M-0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,V('-E<G9I8V5S+W!O<G1A;"]I
M;F1E>"YP:'`Z.#(*;7-G:60@(D5R<F]R(@IM<V=S='(@(K/@U>C:T"(*"B,Z
M(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8S"B,L('!H<"UF
M;W)M870*;7-G:60@(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T
M92YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&=E='1I;F<@
M8V]N=&5N=#H@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T
M:6YG('!A<W-W;W)D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R
M('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B17-T;VYI
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%=&AI;W!I82(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T
M:&YI8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-34*;7-G:60@(D5U<F]P92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S,Y"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#D*(RP@9G5Z>GD*
M;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R("+!U=K>U2#?X-CXT-+C
MTM#ZU2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S8@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,X-PIM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,X(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.3`*(RP@9G5Z>GD*;7-G:60@(D5V97)Y(#4@;6EN
M=71E<R(*;7-G<W1R("+!U=K>U2#?X-CXT-+CTM#ZU2(*"B,Z(&9R86UE=V]R
M:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y
M($QO9VEN(@IM<V=S='(@(L'5VM[5(-_@V/C0TN/2T/K5(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,T,`IM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S<@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,X.`HC+"!F=7IZ>0IM<V=I9"`B179E<GD@;6EN
M=71E(@IM<V=S='(@(L'5VM[5(-_@V/C0TN/2T/K5(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T96UA<"YI;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*
M;7-G<W1R("*_X-C<U>`Z(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C@Q(&%D
M;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(W"FUS
M9VED(")%>&5C=71E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C0W-0IM<V=I9"`B17AP86YD(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S(*;7-G:60@(D5X
M<&%N9"!3:61E8F%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,
M+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS
M9VED(")%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<V"FUS9VED(")%>'!O
M;F5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,Q"FUS9VED(")&1R!#;VQO<B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS9VED(")&5%`@
M=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]S<6PN<&AP.C(Q-@HC+"!F=7IZ>0IM<V=I9"`B1F%I;&5D(')E
M=')I979I;F<@<')E9F5R96YC97,N(@IM<V=S='(@(KW5(-S>UM72(-30(-/8
M(-C7W-7=T-P@W][4U>'CTM#ZT.+0+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HW-2!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB
M"FUS9W-T<B`BO=7CX=_5Z-W0(-K>W=7:YMCXT"#AWB!,1$%0(.'5X-+5X-[B
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HY.`HC+"!F=7IZ
M>0IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS
M9W-T<B`BO=7CX=_5Z-W0(-K>W=7:YMCXT"#AWB!,1$%0(.'5X-+5X-[B+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C@V"B,L('!H<"UF;W)M
M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8Y,0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB
M+B(*;7-G<W1R("*]U>/AW]7HW=`@VM[=U=KFV/C0(.'>($Q$05`@X=7@TM7@
MWN(N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX-PHC+"!F
M=7IZ>0IM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T
M:6]N+B(*;7-G<W1R("),1$%0(-K>W=7:YMCXT.+0(-3>("5S(-4@W=7CX=_5
MZ-W0+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DW(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z-S(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(KW5
MX^'?U>C=T"#:WMW5VN;8^-`@X=X@3$1!4"#AU>#2U>#>XBXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")&86ER
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML86YD($ES;&%N
M9',@*$UA;'9I;F%S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&
M87)O92!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)
M+G!H<#HR,S@*(RP@9G5Z>GD*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R
M("*SX-7HVM`@W^#8(-C<W][@XCHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3@W"FUS9VED(")&87@B"FUS9W-T<B`BQ-#:
MX2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#D*(RP@9G5Z>GD*
M;7-G:60@(D9A>&5S(@IM<V=S='(@(L30VN$B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`R"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#`*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM<V=I9"`B1F5B<G5A<GDB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C`*;7-G:60@(D9E
M96QS($QI:V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(S,0IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Y"FUS9VED
M(")&97<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30T
M"FUS9VED(")&:65L9"!M871R:7@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S,S-`IM<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S.`IM<V=I
M9"`B1FEG;&5T(&9O;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B
M1FEJ:2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-34*(RP@9G5Z>GD*;7-G:60@(D9I;&4B"FUS9W-T<B`BO=#AV][2(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&
M:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#`W"FUS9VED(")&:6QE($UA;F%G97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV
M,R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*(RP@9G5Z>GD*
M;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R("*XW-4B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.3DU"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#@V"FUS9VED
M(")&:6QE('5P;&]A9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E
M<B]"<F]W<V5R+G!H<#HX-3D*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P
M<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z.#D*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM
M<V=I9"`B1FEN;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,38V"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@
M(D9I<G-T(%%U87)T97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U-@IM<V=I9"`B1FEX(')A=&EO(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR,S$*;7-G:60@(D9L:7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B
M1FQO870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,3`W"B,L('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D
M;V5S(&YO="!E>&ES="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(R"FUS9VED(")&;VYT($-O;&]R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B
M1F]O9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$R,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R
M<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S,T"FUS9VED(")&;W)E8V%S="`H5$%&*2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-SD*
M;7-G:60@(B(*(D9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N
M960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB
M;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C
M:RDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ
M,#(*;7-G:60@(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8R"FUS9VED(")&;W)M<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*;7-G:60@
M(D9O<G1U;F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.CDY"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,X"B,L(&9U>GIY"FUS9VED(")&;W)T=6YE<R(*
M;7-G<W1R("*WT-'5V]7HVM@B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0U,PIM<V=I9"`B1F]R=6US(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#D*;7-G:60@(D9O<G=A
M<F1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*(RP@
M9G5Z>GD*;7-G:60@(D9R86UE<R(*;7-G<W1R("*XW-4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S
M"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDQ(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H
M97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T."!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8P"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HT,#8*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT.`HC+"!F=7IZ
M>0IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R("*ZWMS?V]7BU=T@
MWM_8X3HB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K+VUO
M;VXN<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C8P"B,L(&9U>GIY"FUS9VED(")&=6QL($YA;64B"FUS9W-T
M<B`BLM#HU2#8W-4Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1V%B;VXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@
M9G)O;2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.38@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M870*
M;7-G:60@(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL.C@*;7-G:60@
M(D=E;F5R871E9"!#;V1E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@
M(D=E;W)G:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDS
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':&%N82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDT(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<U"FUS9VED(")':6)R86QT87(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S4*;7-G:60@
M(D=I=F5N($YA;64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P
M<"YI;F,Z,3(*;7-G:60@(D=O(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT,`IM<V=I9"`B1V]E9&5L(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3(X"FUS9VED
M(")';V]G;&4@36%P<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G
M;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S<*;7-G
M:60@(D=R87ES8V%L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B
M1W)E96-E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U
M"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-0IM<V=I9"`B1W)E96YL86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*
M;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HQ-SD*(RP@9G5Z>GD*;7-G:60@(D=R;W5P($%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(K#4W-C=V.'BX-#FV/C0(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+G!H<#HU.2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,38Y
M"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L
M('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@
M9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$X
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,C0*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS
M,S@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,W.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R
M;W5P("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,S$T(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-PIM<V=I9"`B1W5A;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.3(*;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C(V('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z.#@*;7-G:60@(D=U97-T(%!E<FUI<W-I;VYS
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S`*
M(RP@9G5Z>GD*;7-G:60@(D=U97-T8F]O:R(*;7-G<W1R("*PU.#5X=#@(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-0IM<V=I9"`B1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW.`IM<V=I9"`B1W5I;F5A+4)I<W-A=2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S@*;7-G:60@(D=U>6%N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HY-C`*;7-G:60@(DA434PB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@
M=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@
M(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T
M(&-O;'5M;B!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W
M(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VAT='`N<&AP.C$U-PIM<V=I9"`B2%144"!!=71H96YT:6-A=&EO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2&%I=&DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#$S"FUS9VED(")(87-H+4%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@IM<V=I9"`B2&%Z
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,3D@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,@IM<V=I9"`B2&5A9&5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E
M="YP:'`Z-C$*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C,*;7-G:60@(DAE879Y(%0M4W1O<FTB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@(DAE8G)E=R`H25-/+3@X
M-3DM."U)*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,T"FUS9VED(")(96EG:'0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$W.2!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3@V"B,Z('-E<G9I8V5S
M+VAE;'`O:6YD97@N<&AP.C$W('1E;7!L871E<R]H96QP+VEN9&5X+FEN8SHS
M"FUS9VED(")(96QP(@IM<V=S='(@(K_>W-[H(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN
M9R!E9&ET;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3,W,0HC+"!F=7IZ>0IM<V=I9"`B2&5L<&5R(@IM<V=S='(@(K_>W-[H
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H97)E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$P
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$P"FUS9VED(")(97)E(&ES
M('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"FUS9VED(")(
M:6=H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z
M-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-0HC+"!F=7IZ
M>0IM<V=I9"`B2&]?;64B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T
M"FUS9VED(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U,S4*(RP@9G5Z
M>GD*;7-G:60@(DAO;64B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-34*;7-G:60@(DAO;64@061D
M<F5S<R(*;7-G<W1R("*TWMS0Z-W0(-#4X-7AT#HB"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-C0*;7-G:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`BM-[<T.C5W2#BU=O5Y-[=
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N9R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C4*;7-G:60@(DAO<F1E(@IM<V=S
M='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@
M6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD
M<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HT,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C4P
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C
M8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@(B<E<R<@X^'?
MU>C=WB#>XN'BX-#=U>(@WM0@X=CAXM7<WN(N(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT
M96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT
M96YS:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z-3`S"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(T-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V
M92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z-#<T"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@
M;V8@='EP92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C$Q.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3,S-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N
M:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO
M<FEZ;VYT86P@4G5L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A
M9&1I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S
M92!R97!O<G0A*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C
M;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR,0IM<V=I9"`B2&]W(&UA
M;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S8*;7-G:60@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R
M9V4_(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS,#`@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S`*;7-G:60@(DAU;6ED:71Y
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-3D*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C0Q"FUS9VED(")(=6UO<FES=',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@P"FUS9VED(")(=6YG87)Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W,B!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G-Q;"YP:'`Z,C,U"B,L('!H<"UF;W)M870*;7-G:60@(DE-
M05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(Q-"!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G-Q;"YP:'`Z,CDU"B,L('!H<"UF;W)M870*;7-G:60@
M(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W.2!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C0R"B,L('!H<"UF;W)M870*;7-G
M:60@(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,38*(RP@
M9G5Z>GD*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`BL-3@U>'0(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B25`@
M061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R97-S
M(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@R"FUS9VED("))8V5L86YD(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S8*;7-G:60@(DEC;VYS($]N;'DB"FUS
M9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF
M;W)M870*;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S<W"FUS9VED("))8V]N<R!W:71H('1E>'0B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,`IM<V=I
M9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P
M96X@:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#4U"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E
M(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N
M965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N
M<W!A<F5N8WDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ-S,*;7-G:60@(B(*(DEF('EO=2!S964@=&AI
M<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O
M('5P;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$R-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*;7-G:60@(DEM86=E(%!R979I97<Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C$*;7-G:60@(DEM86=E(%523#HB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C$*;7-G:60@(DEM
M86=E('5P;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H
M<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D
M871A+W1S=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z
M-PHC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4T('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("*XW-_>X.+8X-#=WB#?WMO5.B`E
M<R(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF
M;W)M870*;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R("*XW-_>
MX.+8X-#=WB#?WMO5.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`BN-S?WN#B
MV.#0W=@@W][;V/K0.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2;W<@069T
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S
M+WII<"YP:'`Z,3,U"FUS9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV
M96XN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,R"B,L(&9U>GIY"FUS9VED("));F-O<G)E8W0@
M=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+B(*;7-G<W1R("*RU2#<WMO8W-4@
MW=#2U=35XM4@TM#HU2#:WN#8X=W8Y]K>(-C<U2#8(-O>U]C=VM`B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R
M96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@
M;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@
M9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S92!);F1E
M;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("));F1I82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U-"!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A
M;"!5<V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DEN9&]N
M97-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3<*;7-G:60@(DEN9F]R;6%T:6]N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M,S`*;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(P"FUS9VED("));G-E<G0@26UA9V4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P,`IM<V=I9"`B26YS97)T(%1A8FQE(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@
M(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G:60@(DEN
M<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@
M(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B
M969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,@IM<V=I
M9"`B26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@82!N97<@<F]W(&)E9F]R
M92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C<P"FUS9VED("))
M;G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!B969O
M<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T96UP;&%T
M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,Y"FUS
M9VED("));G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N
M(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`IM
M<V=I9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0IM<V=I
M9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G:60@
M(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B
M26YS97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*;7-G:60@(DEN<V5R="!M
M97-S86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G:60@(DEN<V5R="!P87)A
M9W)A<&@@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED("));G-E<G0@
M<&%R86=R87!H(&)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Y"FUS9VED("));G-E
M<G0@<F]W(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*;7-G:60@(DEN<V5R="!R
M;W<@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,S`*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H
M92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM<V=I9"`B26YS97)T
M+TUO9&EF>2!);6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("));G-E<G0O36]D:69Y
M($QI;FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D
M:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,U"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<U"FUS9VED("));G1E
M9V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q
M,S,*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G:60@
M(DEN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$W,`HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,#$*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C$P"FUS9VED
M("));G9A;&ED(%I)4"!D871A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P;&EC871I;VXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI9"!B871C:"!)1"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`X-R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,34X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(R,S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(Y.0HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C,W"FUS9VED("))
M;G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*;7-G:60@
M(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z.#$*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,3`P"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C(R,`IM<V=I9"`B26YV
M86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3<W"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3<Q"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P,PIM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R
M<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C(W
M"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<S"FUS9VED("))
M;G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-S4*;7-G:60@(DEN=F%L:60@<')O9'5C="!C
M;V1E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G:60@(DEN=F%L:60@<')O=&]C;VPN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z.3,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HW,2!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C@P"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@<F5C:7!I96YT.B!<
M(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HQ,#<V(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(V,@IM<V=I9"`B
M26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"FUS9VED("))
M;G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G:60@
M(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S4W"FUS9VED("));G9E;G1O<GDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C8W.0IM<V=I9"`B26YV97)T('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#(*;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-
M86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27-R865L(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C(U"FUS9VED("))
M<W-U97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@R"B,L(&9U>GIY"FUS9VED("))=&%L>2(*;7-G<W1R("*TW=72
MW=XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,0HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G
M:60@(DIA;G5A<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*
M87!A;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-PIM
M<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`IM<V=I9"`B(@HB2F%V87-C
M<FEP="!H87,@8F5E;B!D:7-A8FQE9"!O;B!Y;W5R(&)R;W=S97(@86YD('1H
M:7,@<&%G92!M87D@;F]T(&)E("(*(F1I<W!L87EI;F<@8V]R<F5C=&QY+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,@IM
M<V=I9"`B2F5R<V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B
M2F]R9&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#8*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*
M=6YE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G
M:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S
M=&EF>2!2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA
M>F%K:'-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(V-`IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@U"FUS9VED(")+
M97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R
M;F5L($YE=V)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$T"FUS9VED
M(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N9W1H(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM
M<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.3@*(RP@9G5Z>GD*;7-G:60@(DME>2!5<V%G
M92(*;7-G<W1R("*_WN#0VM`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HW-#`*;7-G:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U
M"FUS9VED(")+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O
M9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!297!U
M8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M.`IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM
M<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+VUE;G4N:6YC.C@*;7-G:60@(DQA7WEO=70B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),86\@4&5O<&QE)W,@
M1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,38Y"FUS9VED("),87-T($AA;&8B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<V"FUS9VED("),87-T(%!A<W-W;W)D
M($-H86YG92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#8@
M;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED("),87-T(%%U87)T97(B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3$*;7-G:60@(DQA
M<W0@57!D871E9#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<R,0HC
M+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q-@IM<V=I
M9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y
M"FUS9VED("),871V:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0T"FUS9VED("),87<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"B,L(&9U>GIY
M"FUS9VED("),87EO=70B"FUS9W-T<B`BN-?;U=<B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),96%V92!E
M;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM
M<V=I9"`B3&5B86YO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q.0IM<V=I
M9"`B3&5F="!H96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$Q-0HC+"!F=7IZ>0IM<V=I9"`B3&5F="!V86QU97,B"FUS
M9W-T<B`BO^#8W-7@.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,30S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&5S;W1H;R(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*
M;7-G:60@(DQE=F5L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B
M3&EB97)I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI8GEA
M;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS
M9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),:6=H="!$<FEZ
M>FQE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(V"B,L(&9U>GIY"FUS9VED("),:6=H="!286EN(@IM<V=S
M='(@(KO>T]C@T/K5(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*
M;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM<V=I9"`B3&EG:'0@
M4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4
M:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H="!3;F]W(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS
M9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,30*(RP@9G5Z>GD*;7-G
M:60@(DQI;FLB"FUS9W-T<B`BN][3V.#0^M4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI
M;FL@<&]I;G1S('1O.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#<U"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S('1O
M('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:'1M;#)T97AT+G!H
M<#HQ.#,*;7-G:60@(DQI;FMS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT-@IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS
M9VED("),:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,PIM<V=I9"`B3&ES="!$871A
M8F%S97,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z
M-3`*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`BN-?;V.'BT/@@
MXM7<V"#7T"#?WMS>Z"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S(*;7-G
M:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O2&5A9&5R<RYP:'`Z-3DT"FUS9VED("),:7-T+4%R8VAI=F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU
M.#D*(RP@9G5Z>GD*;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R("*XU]O8X>+0
M^"#BU=S8(-?0(-_>W-[H(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D
M97)S+G!H<#HU.38*;7-G:60@(DQI<W0M260B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3(*;7-G:60@(DQI<W0M
M3W=N97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D
M97)S+G!H<#HU.3,*;7-G:60@(DQI<W0M4&]S="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,0IM<V=I9"`B3&ES
M="U3=6)S8W)I8F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12](96%D97)S+G!H<#HU.3`*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4P"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,B
M"FUS9W-T<B`BN]CAXM#ZU>+>(-W0(-K>X-CAW=CFV"#5(-[=U=+>U]S>UM7=
MWBXB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S4*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R
M("*[V.'BT/K5XMX@W=`@VM[@V.'=V.;8(-4@WMW5TM[7W-[6U=W>+B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES
M=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`BN]CAXM#ZU>+>(-W0
M(-K>X-CAW=CFV"#5(-[=U=+>U]S>UM7=WBXB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-#<*;7-G:60@(DQI=&5R871U<F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@Y"FUS9VED("),:71H=6%N:6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6UA9V5S+G!H<#HX,PIM<V=I9"`B
M3&]A9&EN9RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C$Q"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@S"FUS9VED("),;V-A;&4@86YD
M(%1I;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-S$@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8T"B,Z
M(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP
M.C8U"FUS9VED("),;V-A=&EO;B(*;7-G<W1R("(B"@HC.B!L;V=I;BYP:'`Z
M,3<R('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.3$@=&5M<&QA=&5S
M+VQO9VEN+VUO8FEL92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE
M+FEN8SHQ-2!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDP"FUS9VED("),
M;V<@:6XB"FUS9W-T<B`BN][3V.#0^M4B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HR-#4*;7-G:60@(DQO9R!O9B!P<F5V:6]U<R!S>6YC('-E
M<W-I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N
M<&AP.C$X-0IM<V=I9"`B3&]G(&]U="(*;7-G<W1R("*XU]O5UR(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B3&]G:6XB
M"FUS9W-T<B`BN][3V.#0^M4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3`W"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+G!H<#HY.38*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A
M=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC
M;W)R96-T;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.CDY,@IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8U"B,L(&9U>GIY"FUS9VED("),
M;VYG('1E>'0B"FUS9W-T<B`BN-?;U=<B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#@*;7-G:60@(DQO=F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(DQO=R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M8F]U<F<B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#,X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*
M;7-G<W1R(")-32(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#$*
M;7-G:60@(DU/5$0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.148@071T86-H;65N
M="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H
M<#HS-PIM<V=I9"`B35-'(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I
M9"`B36%C86\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-86-E
M9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-861A9V%S8V%R(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.0HC+"!F=7IZ>0IM<V=I
M9"`B36%G:6,B"FUS9W-T<B`BO][HXM`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z.#$*;7-G:60@(DUA:6PB"FUS9W-T<B`BO][HXM`B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3(R"FUS9VED(")-86EL($%D;6EN
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DUA;&%W:2(*
M;7-G<W1R("*_WNCBT"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36%L87ES:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD:79E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@(DUA;&DB"FUS
M9W-T<B`BO][HXM`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DUA
M;'1A(@IM<V=S='(@(K_>Z.+0(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDQ"FUS9VED("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y
M;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S
M<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U,PIM
M<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HQ,#@T"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HQ,38X"FUS9VED(")-87!1=65S="!M
M87`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,3`U"FUS9VED(")-87!P:6YG<R!S=&]R960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#,*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED(")-
M87)C:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0Q"B,L(&9U>GIY"FUS9VED(")-87)G:6XB
M"FUS9W-T<B`BLMW8W-#=V-4B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N
M(&9L86=S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@9FQA9W,@
M*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3$*;7-G:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDS"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")-871C:&EN9R!F
M:65L9',B"FUS9W-T<B`BNM[@U>'?WMW4V.#0Y]K8(-_>V]CZT"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,PIM<V=I9"`B36%U<FET86YI82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.30*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@
M(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-
M87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@
M:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y
M.`IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+V%P:2YP:'`Z.#8*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F(%!O
M<G1A;"!";&]C:W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.#DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3<*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S.0IM<V=I9"`B36%X:6UU;2!L96YG
M=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$W"FUS9VED(")-87EO='1E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@IM<V=I9"`B365M
M8F5R<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<X
M"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*;7-G:60@(DUE
M<F=E(&-E;&QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I
M;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E(@IM
M<V=S='(@(K_>X-#:T"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,C$V"FUS9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F
M=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B
M92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"B,L(&9U>GIY"FUS9VED
M(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(K_>X-#:T"(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R
M-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR-C`*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R("*_
MWN#0VM`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R
M(%=E871H97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M-PIM<V=I9"`B365T87(@8FQO8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3(*;7-G:60@(B(*(DUE=&%R
M(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E
M9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C4*;7-G:60@(DUE=&%R1$(@:7,@
M;F]T(&-O;FYE8W1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV-R!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<T"FUS9VED(")-971H;V0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HX,2!F<F%M97=O<FLO4E!#
M+U)00R]S;V%P+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D
M(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4E!#+U)00R]R97-T+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-
M971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW-"!L:6(O0FQO
M8VLO;65T87(N<&AP.C<U"FUS9VED(")-971R:6,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDU"FUS9VED(")-97AI8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S(*;7-G:60@(DUI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<V"B,L(&9U>GIY"FUS9VED(")-:61D;&4B"FUS9W-T<B`B
MO][HXM`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H
M<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S$P"FUS9VED(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#(*;7-G
M:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#,Y"FUS9VED(")-:6YI;75M
M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S0*
M(RP@9G5Z>GD*;7-G:60@(DUI<G)O<B(*;7-G<W1R("*SX-7HVM`B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-S(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S0P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(
M5%107U)E<75E<W0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ,34*;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U
M(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T
M:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI
M<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI
M<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y-`IM<V=I9"`B36ES<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS
M9VED(")-;R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-S0*;7-G:60@(DUO8FEL92!-86EL(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")-;V1E
M<F%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C8V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-S,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX
M.`IM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*;7-G
M:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV-S,*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.30*;7-G:60@(DUO;G1H
M(&%N9"!Y96%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC
M92]-86EN=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`B
MO-7AU>?=WB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36]N='-E<G)A="(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$W,B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HR-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!F:65L
M9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S
M"FUS9VED(")-;W-T;'D@0VQE87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*;7-G:60@(DUO<W1L>2!#
M;&]U9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S4*;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,#D*;7-G
M:60@(DUO=F4@1&]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HU,3,*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,3<*
M;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`U"FUS9VED(")-;W9E(%5P(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HU,C0*;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(S"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C0*;7-G:60@(DUO=F4@
M=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-;WIA;6)I<75E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#0*
M;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U
M-0IM<V=I9"`B375L=&EM87`@54L@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#(*;7-G:60@(DUU;'1I<&QE('-E;&5C
M=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#`P"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HR.`IM<V=I9"`B37D@06-C;W5N="!);F9O<FUA=&EO
M;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C4T
M"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+V5D:70N<&AP.C$S-@IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUY86YM87(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ
M-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P,@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B3F%M92(*;7-G<W1R
M("*XW-4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDW"FUS9VED(").875R=2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3<*;7-G:60@(DYE<&%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*
M;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED(").971S
M8V%P92!"87-E(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@0T$@4F5V;V-A
M=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.#4*;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!54DPB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.#0*;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED
M(").971S8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A
M<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@W"FUS9VED(").971S8V%P92!C97)T
M:69I8V%T92!C;VUM96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3@P"FUS9VED(").971S8V%P92!C97)T:69I
M8V%T92!T>7!E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR-3$*;7-G:60@(DYE='=O<FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(U(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS,S4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X-@IM<V=I9"`B
M3F5V97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").97<@0V%L
M961O;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#
M871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED(").97<@0V%T96=O<GDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I
M;',N<&AP.C@Q"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA
M:6QS+G!H<#HX-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M
M86EL<RYP:'`Z.3<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E
M;6%I;',N<&AP.C$P,0HC+"!P:'`M9F]R;6%T"FUS9VED(").97<@365S<V%G
M92!T;R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@
M;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*
M;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T
M:6]N86PI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3F5W(%IE
M86QA;F0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C,W"B,L(&9U>GIY"FUS9VED(").97<@<&%S<W=O<F0B"FUS9W-T<B`B
MN][7V-W:T"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HR,C<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I;&P@97AP:7)E
M(&]N("5X+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z-3(*(RP@9G5Z>GD*;7-G:60@(DYE=R!P87-S=V]R9',@9&]N)W0@
M;6%T8V@N(@IM<V=S='(@(KO>U]C=VMCBU2#<WN#0(-30(-'8U-#B(-CAXM@N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X.0HC+"!F=7IZ>0IM
M<V=I9"`B3F5W<R(*;7-G<W1R("*WT-'5V]7HVM@B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S`U"FUS9VED(").97=S9W)O=7!S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$U('1E;7!L871E
M<R]D871A+V1A=&5M87`N:6YC.C0Q"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z,3(Y('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(U"FUS9VED
M(").97AT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PIM
M<V=I9"`B3F5X="`T(%!H87-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C,W,B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C,W-@HC+"!F=7IZ>0IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S
M='(@(KW0U]#4(-K>W2#>W^;8V.+5(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A
M9V5R+G!H<#HQ,#,*;7-G:60@(DYE>'0^(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-@IM<V=I9"`B3FEC87)A9W5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-@IM<V=I9"`B3FEG97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED
M(").:6=E<FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS.#`*;7-G:60@(DYI9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-PIM<V=I9"`B3FEU92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED(").;R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G
M:60@(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D
M:69F97)E;F-E<R!F;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z,3`U"FUS9VED(").;R!A=F%I;&%B
M;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW.2!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-#4*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C8W"FUS9VED(").;R!B;&]C:R!E>&ES
M=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C4P"B,L(&9U>GIY"FUS9VED
M(").;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R("*]U=S0(-C=Y-[@W-#FV-@@U]`@W][4U>'CTM#Z
MU2#=T"!344P@V-35W>+8XM7BV.+5+B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N
M<&AP.C4T"B,L(&9U>GIY"FUS9VED(").;R!C:&%N9V4N(@IM<V=S='(@(K[B
MVM#6V"#3V"#?X-[<U=W8XM4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$U-@IM<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O
M('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ-C<@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU
M,#(*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S<S"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@(KW5W-`@V-WDWN#<T.;8V"#7
MT"#?WM35X>/2T/K5(-W0(%-13"#:T.+5T][@V-CBU2XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C@R-`HC+"!F=7IZ>0IM<V=I9"`B3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N
M(@IM<V=S='(@(KW5W-`@V-WDWN#<T.;8V"#7T"#?WM35X>/2T/K5(-W0($Q$
M05`@W-[6W=[AXMCBU2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C8V.0HC+"!F=7IZ>0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S='(@(KW5W-`@V-WD
MWN#<T.;8V"#7T"#?WM35X>/2T/K5(-W0(%-13"#:T.+5T][@V-CBU2XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S$W"B,L(&9U>GIY
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R("*]U=S0(-C=Y-[@W-#FV-@@
MU]`@W][4U>'CTM#ZU2#=T"!344P@VM#BU=/>X-C8XM4N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$T"FUS9VED
M(").;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S0*;7-G:60@(DYO(&1E
M<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0G)O=W-E<B]"<F]W<V5R+G!H<#HX-S<*;7-G:60@(DYO(&9I;&4@=7!L;V%D
M960B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q"FUS
M9VED(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$R."!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,C,*;7-G:60@(DYO(&QO8V%T
M:6]N(&ES('-E="XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$V.0IM<V=I9"`B3F\@;&]C871I;VX@<')O=FED960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,S"FUS9VED(").;R!M97-S86=E('-U<'!L:65D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S-@IM<V=I9"`B3F\@;F%M92!S<&5C:69I960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,W"FUS9VED(").;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*;7-G:60@(DYO(&]F9F5N
M<VEV92!F;W)T=6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VAT='`N<&AP.CDQ"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@2%144"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]I;6%P+G!H<#HQ,#@*;7-G:60@(DYO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C<R"FUS9VED(").
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP
M:'`Z-S<@9G)A;65W;W)K+T%U=&@O075T:"]L;V=I;BYP:'`Z.#0*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<U"B,L(&9U>GIY"FUS9VED(").
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(KW5W-`@V-WDWN#<T.;8V"#7T"#?WM35X>/2T/K5(-W0(%-1
M3"#8U-7=XMCBU>+8XM4N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P87-S
M=V0N<&AP.C$S-0HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BO=7<T"#8
MW>3>X-S0YMC8(-?0(-_>U-7AX]+0^M4@W=`@4U%,(-C4U=WBV.+5XMCBU2XB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.#0*(RP@9G5Z>GD*
M;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(KW5W-`@V-WDWN#<T.;8V"#7T"#?WM35X>/2T/K5
M(-W0(%-13"#8U-7=XMCBU>+8XM4N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HQ,C@V"FUS9VED("(B"B).;R!P871H('1O('1H92!/
M<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES
M(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I=&@@4$M#4R`Q,B!D871A+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHV
M"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HW-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3F\@<75O=&$@<V5T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0S"B,L(&9U>GIY"FUS9VED
M(").;R!R=6QE<R(*;7-G<W1R("*WT-'5V]7HVM@B"@HC.B!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HT-#D*;7-G:60@(DYO('-E<&%R871O<B!S<&5C
M:69I960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#0*(RP@9G5Z>GD*;7-G:60@(DYO('-I
M9&5S(@IM<V=S='(@(K?0T=7;U>C:V"(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z-3@S"FUS9VED(").;R!S=6-H(&9I;&4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$S.`IM<V=I9"`B3F\@
M=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C(R,0HC+"!F=7IZ>0IM<V=I9"`B3F\@=7-E<FYA;64@86YD+V]R('!A
M<W-W;W)D('-E;G0N(@IM<V=S='(@(K+5(-S>V]C<U2#=T-+5U-7BU2#2T.C5
M(-K>X-CAW=CGVMX@V-S5(-@@V][7V-W:T"(*"B,Z(&9R86UE=V]R:R]24$,O
M4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED(").;R!V86QI9"!834P@9&%T82!R
M971U<FYE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.3<Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HY.#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.CDY,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3`P.0IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C`*;7-G:60@(DYO('9E<G-I
M;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T
M92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3(X"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@
M8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDS
M"B,L(&9U>GIY"FUS9VED(").;VYE(@IM<V=S='(@(L+5V]7DWMTB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP"FUS9VED
M(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@Y"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L86YD
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(").;W)T:&5R;B!-87)I86YA
M($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").;W)W
M87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV-#`*;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B3F]T($)E
M9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HT,#@*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C8S"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R
M871E9WDN<&AP.C@S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDT"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z
M-#@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+G!H<#HU.0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C8X"B,L(&9U>GIY"FUS9VED(").;W0@<V5T(@IM<V=S='(@(K?0
MT=7;U>C:V"(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N
M2&%N9&QE<BYP:'`Z,30S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]3
M97-S:6]N2&%N9&QE<BYP:'`Z,34X"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N
M9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3<S"B,Z(&9R86UE=V]R:R]397-S
M:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3@W"B,Z(&9R86UE=V]R
M:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,T(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HQ.3`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C(P-2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HR-#@@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(V-0HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,C@Q(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR.3<*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,Q,B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,S(Y"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS-C(@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C0R,@HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z-3`Q(&9R86UE=V]R:R]61E,O5D93+G!H<#HU-S`*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C4X-R!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-C8U
M"FUS9VED(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T(&-O;F9I9R]H;V]K
M<RYP:'`N9&ES=#HQ,#`U"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ
M-S@*;7-G:60@(DYO=&5S(@IM<V=S='(@(K?0T=7;U>C:V"(*"B,Z('-E<G9I
M8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B
M<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,3$*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED(").;W9E;6)E<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#0V"B,L(&9U
M>GIY"FUS9VED(").=6UB97(B"FUS9W-T<B`BN-S5(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30R-0IM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E
M<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V
M.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(S"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T-#4@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C<@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,30R,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#0S('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`R"FUS9VED(").=6UB97(@;V8@<F]W<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-`IM
M<V=I9"`B3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D
M:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.#<S"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,3$*;7-G:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,#0*;7-G:60@
M(D]C=&%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,3`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B3V9F96YS92!F:6QT
M97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R
M-@IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S
M(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z,S8*(RP@9G5Z>GD*;7-G:60@(D]L9"!P87-S
M=V]R9"(*;7-G<W1R("*[WM?8W=K0(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C0V"FUS9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E
M8W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HW,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@
M9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.CDU"FUS9VED(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4Q(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Y-S$*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E
M<W,@86QL;W=E9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D
M:70N<&AP.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@
M861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B
M"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO:69R86UE+G!H<#HS-0IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD
M;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R
M86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O
M=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*;7-G
M:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-I9&5B87(N<&AP.C$U,0HC+"!F=7IZ>0IM<V=I9"`B3W!T:6]N
M<R(*;7-G<W1R("*WT.?CTM#X(-[?YMC8(@H*(SH@<V5R=FEC97,O<')E9G,N
M<&AP.C,Q('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$T"B,L('!H<"UF;W)M
M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R
M9&5R960@3&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4V-PHC+"!F=7IZ>0IM<V=I9"`B3W)G86YI<V%T:6]N
M(@IM<V=S='(@(K#4W-C=V.'BX-#FV/C0(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N
M:70B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S
M,@IM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M
M<&QA=&4B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$Y('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,#8*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q
M,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(R"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,S$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,0IM<V=I9"`B
M3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHS,0IM<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<Y"FUS
M9VED(")004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT
M<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A8VME;F0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3(W,PIM<V=I
M9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,3D*;7-G:60@(E!'4"!%;F-R
M>7!T960@1&%T82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,S<Q"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S4S"FUS
M9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W!H<'-H96QL+G!H<#HV.`HC+"!F=7IZ>0IM<V=I9"`B4$A0($-O
M9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*
M;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-PIM<V=I9"`B4$T@3&EG:'0@4F%I
M;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS.`IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B
M4$T@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT,`IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0Q"FUS9VED(")032!3=6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E!-(%0M4W1O<FUS
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR-S0*;7-G
M:60@(E!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z
M(&QI8B]A<&DN<&AP.C$T.0IM<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0V"FUS9VED(")0861D:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M.0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM
M<V=I9"`B4&%L874B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B
M4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3@*;7-G:60@(E!A;F%M82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3D*;7-G:60@(E!A<'5A($YE=R!'=6EN96$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.34@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,@IM<V=I9"`B4&%R86=U87DB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S8*;7-G:60@(E!A
M<G1L>2!#;&]U9'DB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-PHC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3$@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`Q.`HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<W
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0R,PIM<V=I9"`B4&%S<W=O<F0B"FUS9W-T
M<B`BN][7V-W:T"(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HX
M,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3,R
M,@HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@
M(KO>U]C=VM`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z
M,34R"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,#4S"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*
M(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R("*[WM?8W=K0(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*(RP@9G5Z>GD*;7-G
M:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`BN][7V-W:T"(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$U,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#,T"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W
M;W)D<R!M=7-T(&UA=&-H+B(*;7-G<W1R("*[WM?8W=K8XM4@W-[@T"#4T"#1
MV-30XB#8X>+8+B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,3D@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R"FUS
M9VED(")087-T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,W"FUS9VED(")087-T92!F<F]M(&-L:7!B
M;V%R9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C4Q"FUS9VED(")0871H(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHW"FUS9VED(")096YD:6YG(%-I
M9VYU<',Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M-`HC+"!F=7IZ>0IM<V=I9"`B4&5O<&QE(@IM<V=S='(@(L/;WM/0(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*;7-G
M:60@(E!E<F-E;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+VUA:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E
M;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R("*XU]+@Z-@@WM_5X-#FV-@@U]`@
MWM3@UN/2T/K5(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0P-@HC+"!F
M=7IZ>0IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N
M(&QO9VEN/R(*;7-G<W1R("*XU]+@Z-@@WM_5X-#FV-@@U]`@WM3@UN/2T/K5
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@
M(E!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O9&5L971E
M+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<
M(B!N;W0@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HU.#8*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38Q(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38T"FUS9VED(")097)M:7-S
M:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#D@
M861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P"B,Z(&%D;6EN+W!E<FUS+VEN
M9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X"B,L(&9U>GIY
M"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R("*P
MU-S8W=CAXN#0YMCXT"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-0IM
M<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDX"FUS9VED(")097)U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU-0IM<V=I9"`B4&5T<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3D*;7-G:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H
M;VYE(@IM<V=S='(@(L+5V]7DWMTB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#<X"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G
M:60@(E!L871I='5D97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E
M(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I
M9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI
M<R!E;&5M96YT.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L96%S92!C
M;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4W,0IM
M<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z,3(*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@
M8V%T96=O<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$S,#$*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E
M<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V
M-C`*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H
M92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-3$*;7-G:60@(E!L96%S92!E
M;G1E<B!A('9A;&ED('1I;64N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@(E!L96%S92!P<F]V:61E(&$@
M<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS9W-T<B`BLM4@W-[;V-S5(-W0
MTM74U>+5(-/>(-_@WM';U=S>XBXB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@
M(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM
M<V=S='(@(K+5(-S>V]C<U2#=T-+5U-7BU2#2T.C5(-K>X-CAW=CGVMX@V-S5
M(-@@V][7V-W:T"(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.`IM
M<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@
M35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E
M;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@
M8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED
M(")0;VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#@W"FUS9VED(")0;VQL<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.3$*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B
M>2!)34%0*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V
M-B!L:6(O0FQO8VLO;65T87(N<&AP.C(W,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDX"FUS9VED
M(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?
M;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<V5S<VEO;BYP:'`Z
M,S,*;7-G:60@(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,C4*;7-G:60@(E!R97-S=7)E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C4Y"FUS9VED(")0<F5S<W5R92!A="!S96$@
M;&5V96PZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C,U"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,#4*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`IM<V=I
M9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8R(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8V"B,L(&9U>GIY"FUS9VED(")0
M<F5V:6]U<R!O<'1I;VYS(@IM<V=S='(@(KW0U]#4(-K>W2#>W^;8V.+5(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM
M<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0<FEV871E($ME>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z
M,38Y"B,L(&9U>GIY"FUS9VED(")0<F]B;&5M(@IM<V=S='(@(ENXU]+5Z.+0
M^"#7T"#?X-[1V]7<WN)=(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3(V
M"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@(K[?V.$@W=`@
MW^#>T=O5W-[B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,V.0IM
M<V=I9"`B4')O:F5C=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C$Q,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@X"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#4*;7-G:60@(E!R;VUP="!T
M97AT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0R,PIM<V=I9"`B4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC
M($ME>2!!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV-#0*;7-G:60@(E!U8FQI8R!+97D@26YF;R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HR
M-#$*;7-G:60@(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E
M9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G
M:60@(E!U97)T;R!2:6-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G
M:60@(E%A=&%R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HV
M,PIM<V=I9"`B475E<GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C<P"FUS9VED(")1=6]T82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8V,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")24T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8T"FUS9VED(")2861I;R!S96QE
M8W1I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#,*;7-G:60@(E)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E)A
M:6X@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM
M<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A:6X@86YD(%-N
M;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U
M;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HV."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<V"FUS9VED(")2871I;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$Q-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PHC
M+"!F=7IZ>0IM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R("*_WN#0VM`B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I
M;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E
M<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E
M9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS
M9VED(")2969R97-H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS.3$*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S
M.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q"FUS
M9VED(")2969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HX.30@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(Q,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,U"B,L(&9U
M>GIY"FUS9VED(")296=E>"(*;7-G<W1R(")297-E="(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,R-#D*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W
M<V5R(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*;7-G:60@(E)E
M;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R-@IM
M<V=I9"`B4F5M87)K<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3$T"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T
M92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(R('1E
M;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3,*(RP@9G5Z>GD*;7-G
M:60@(E)E;6]V92(*;7-G<W1R("*^U.'BX-#=V"#?T.`B"@HC.B!T96UP;&%T
M97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E)E;6]V
M92!";&]C:R(*;7-G<W1R("*^U.'BX-#=V"#?T.`B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34W"FUS9VED(")296UO=F4@
M8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-#`*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!F;W)M
M871T:6YG(@IM<V=S='(@(K[4X>+@T-W8(-_0X"(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z,3(X"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R
M("*^U.'BX-#=V"#?T.`B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R
M"FUS9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M
M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"B,L(&9U>GIY
M"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(K[4X>+@T-W8(-_0X"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU,`IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N
M="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N
M:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R("*^
MU.'BX-#=V"#?T.`B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N
M:6YC.C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R
M.B`E<R(*;7-G<W1R("*^U.'BX-#=V"#?T.`B"@HC.B!F<F%M97=O<FLO4E!#
M+U)00R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B
M92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-PIM<V=I9"`B4F5Q
M=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-"!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C4Q,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`BL=#@T-W8WN(@)W5I9"<@W=4@U2#=T-+5U-7=
M(-+>(-_>U-7AX]+0^M#BT"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C8W-2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S,`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(S"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I
M;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BL=#@T-W8WN(@)W5I9"<@
MW=4@U2#=T-+5U-7=(-+>(-_>U-7AX]+0^M#BT"XB"@HC.B!F<F%M97=O<FLO
M571I;"]5=&EL+G!H<#HW.#$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(K'0X-#=V-[B("=U:60G(-W5(-4@W=#2U=35W2#2WB#?
MWM35X>/2T/K0XM`N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E
M<BYP:'`Z,S,U"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HS,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S(P('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`B
M4F5S970B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT-@HC+"!F
M=7IZ>0IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`BN][7V-W:T"(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W"B,L(&9U>GIY"FUS
M9VED(")297-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(K_>XM+@U-@@V][7
MV-W:T"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S`*;7-G:60@(E)E<W1O
M<F4@3&%S="!1=65R>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]P:'!S:&5L;"YP
M:'`Z-S$@861M:6XO8VUD<VAE;&PN<&AP.C(X(&%D;6EN+W-Q;'-H96QL+G!H
M<#HV-@HC+"!F=7IZ>0IM<V=I9"`B4F5S=6QT<R(*;7-G<W1R(")297-E="(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@=&5M<&QA=&5S
M+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS
M9W-T<B`BO=#7T-0@VM[=(-[?YMC8XM4B"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z,S@*;7-G:60@(E)E='EP92!N97<@<&%S<W=O<F0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S(*(RP@9G5Z
M>GD*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R("*]
MT-?0U"#:WMT@WM_FV-CBU2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M.`IM<V=I9"`B4FED9&QE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*;7-G:60@(E)I9VAT
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C$*
M;7-G:60@(E)I9VAT(&AE861E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3$W"FUS9VED(")2:6=H="!V86QU97,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R("+#V][3T"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R-0IM<V=I9"`B4F]T871E(#$X
M,"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C(R"FUS9VED(")2;W1A=&4@3&5F="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(X"FUS
M9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W
M(%!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I9"`B4F]W('!R;W!E
M<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3,*(RP@9G5Z>GD*;7-G:60@(E)U;&5S(@IM<V=S='(@(L/;WM/0(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A
M;F0@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL
M(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4R
M"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P"FUS9VED(")2
M=6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G5S<VEA;B!&
M961E<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)W
M86YD82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T
M=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,S(S"FUS9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A9V4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX,0IM
M<V=I9"`B4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3`T"B,L
M(&9U>GIY"FUS9VED(")335,@365S<V%G:6YG(@IM<V=S='(@(K_>X-#:T"(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#,*;7-G
M:60@(E-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S,0IM<V=I9"`B4U-(
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-50T-%4U,B
M"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,34S"FUS9VED(")37U%,(%-H
M96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#0*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ=65L
M;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B4V%I;G0@5FEN
M8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B4V%M
M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G
M:60@(E-A;6]A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-A
M;B!-87)I;F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.38*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4V%O
M(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3875D:2!!<F%B
M:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC
M.CDX"FUS9VED(")3879E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O961I="YI;F,Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V
M92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHR,38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F4@)7,B
M"FUS9W-T<B`BM]#GX]+0^"#>W^;8V"(*"B,Z('1E;7!L871E<R]P<F5F<R]E
M;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R("*WT.?CTM#X
M(-[?YMC8(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-PIM<V=I9"`B
M(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I
M<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT.0IM<V=I9"`B4V-A='1E<F5D(%0M4W1O<FUS(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B
M4V-I96YC92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L
M:7-T+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM
M<V=I9"`B4V5A<F-H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS,C`*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y-S,*;7-G:60@(E-E;&5C
M="!&:6QE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#@T"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!D
M871E(@IM<V=S='(@(KC7T=7@V"#DWN#<T.(@U]`@U-#BX]S>XCHB"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B4V5L96-T(&$@
M9W)O=7`@=&\@861D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@
M(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$U-@IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C8W-PIM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8S"B,L(&9U>GIY"FUS9VED(")3
M96QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`BN-?1U>#8(.3>
MX-S0XB#7T"#4T.+CW-[B.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C8W.`IM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O:V5Y8F]A<F0N<&AP.C,W"B,L(&9U>GIY"FUS9VED("(B"B)396QE
M8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L
M;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@
M=&AE('1E>'0@87)E82XB"FUS9W-T<B`B(@HBN-?1U>#8(-K>V"#:T.#0VN+5
MX-@@XM@@XN#5T=#0XBX@O-[6U>@@W][BWM`@W=C2(-30(-/8(-CAVM[?V.#0
MZ"#>U"#?WMO5XMX@(@HBU]`@XM7:X>(N(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z
M(@IM<V=S='(@(KC7T=7@V"#AU=_0X-#BWN`@U]`@U-#BX]S>XCHB"@HC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT-`IM<V=I9"`B4V5L96-T('1H92!D
M871E(&9O<FUA=#HB"FUS9W-T<B`BN-?1U>#8(.3>X-S0XB#7T"#4T.+CW-[B
M.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3`*
M;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@HC
M+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB"FUS
M9W-T<B`BN-?1U>#8(.'5W]#@T.+>X"#7T"#4T.+CW-[B.B(*"B,Z('1E;7!L
M871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE('1I;64@
M9F]R;6%T.B(*;7-G<W1R("*XU]'5X-@@Y-[@W-#B(-?0(-+@U=S5XMXZ(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-PIM<V=I9"`B4V5L96-T
M('1W;R!M871C:&EN9R!F:65L9',N(@IM<V=S='(@(KC7T=7@V"#4TM4@WM33
MWM+0X-#GVM@@W][;V/K0+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M,#8*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T.`IM<V=I9"`B4V5L96-T
M('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B
M;&5M(%)E<&]R="(*;7-G<W1R("*_X-#BV"#8U]+5Z.+0^"#7T"#?X-[1V]7<
MWN(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3`S.0IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,Q-@IM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.0HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0W"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@(E-E
M<'1E;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-S`Q"FUS9VED(")397)I86P@3G5M8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*;7-G:60@(E-E<G9E<B!D871A
M('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HR-PIM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E9"XB"FUS9W-T<B`B
M(@H*(SH@;&EB+V%P:2YP:'`Z,30U"B,L(&9U>GIY"FUS9VED(")397-S:6]N
M<R(*;7-G<W1R("*WT.?CTM#X(-[?YMC8(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C,Q-`IM<V=I9"`B4V5T(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW-@IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL
M;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R
M9V5T(&ET+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3$U"FUS9VED(")3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N
M="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T"FUS9VED(")3970@>6]U<B!P<F5F
M97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.`IM<V=I9"`B
M(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE
M+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO
M;G,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*
M;7-G:60@(E-E='5P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S
M971U<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3971U<"!U<&=R861E('-C<FEP
M=',@879A:6QA8FQE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ.#8*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I
M8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0Y-@IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*(RP@
M9G5Z>GD*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`BNN#0XMK>(.#5
MU]C<U3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0V"FUS9VED(")3
M:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C,@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$U-0IM<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B971W
M965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B
M"B)C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#DP"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N
M(&QO9V=I;F<@:6X_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$W-C4*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN
M86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q
M,PIM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4R-@IM<V=I9"`B4VAO=R!T86)L92!O<&5R871I;VYS
M(&UE;G4@8F%R/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S0Y"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@
M;VX@=&AE(&QE9G0_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.0IM<V=I9"`B4VAO=R!T
M:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4F]W
M(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I9"`B
M4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,PIM<V=I9"`B4VAO=R!U
M<&QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-3`*;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@
M(E-H;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H;W=E<G,@3&%T92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#@P
M"FUS9VED(")3:')I;FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z-S<T(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C@S-@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HY,C(@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3@T
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$P-#<@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3`X-PHC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,3$V(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C$Q-#D*;7-G:60@(E-H<FEN:R!O<B!M;W9E
M(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3:65R<F$@3&5O;F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.C(V-0IM<V=I9"`B4VEG;B!U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM<V=I9"`B4VEG;F%T=7)E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-S$Q"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8U(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HX-R!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HX.38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,W"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R-#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(S"FUS9VED(")3:7IE(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH
M=&UL.C4R"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S='(@(K_@U>':
MWMK=V"#>U.#6X]+0^M4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V86MI
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V96YI82(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU-`IM<V=I9"`B4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VYO=R!3:&]W
M97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-38*;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I
M9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")3;F]W(%-H
M;W=E<G,@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(W.`IM<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C@R"FUS9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@
M=V%T97(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3;VQO
M;6]N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B
M4V]M86QI82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,CDR-@IM<V=I9"`B4V]R="!O<F1E<B!S96QE
M8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T-PHC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$V-@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C$X.0HC+"!F=7IZ>0IM<V=I9"`B4V]U
M<F-E(&%D9')E<W,B"FUS9W-T<B`BL-3@U>'0(-W0(.#0T=[BT"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3@*;7-G:60@(E-O=71H($%F<FEC82(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B4V]U=&@@175R;W!E86X@
M*$E33RTX.#4Y+3,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B
M4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C
M:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B
M;W)D97(@:6X@8V5L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HX,34*;7-G:60@(E-P86-E<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4U"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*;7-G
M:60@(E-P86-I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A
M;F0@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B4W!A
M:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDX
M"FUS9VED(")3<&%M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D
M+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T
M<B`BLMW5X>/2T/K5(-W0(.'?U>;8^-#;W=@@U]W0YM@B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8R"FUS9VED
M(")3<&QI="!C96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O
M;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Q"B,L(&9U>GIY"FUS
M9VED(")3<&]R=',B"FUS9W-T<B`BN-S?WN#B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS
M9VED(")3<FD@3&%N:V$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C<S(&QI8B]";&]C:R]M971A<BYP:'`Z-S0*;7-G:60@
M(E-T86YD87)D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(U.38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C@P.0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B4W1A=&4@;W(@
M4')O=FEN8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P
M+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$U"FUS9VED(")3=&]R86=E(&9O
M<FUA="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4W,@HC+"!F=7IZ>0IM<V=I9"`B4W1R965T($%D9')E<W,B"FUS
M9W-T<B`BL-3@U>'0(-W0(.#0T=[BT"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S,PIM
M<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3@W,PIM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE
M(&%D9')E<W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(E-U8F1I<F5C
M=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J
M96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S
M,B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3<*;7-G:60@
M(E-U8FUI="(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C0Y"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"!<(B5S
M7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@;&]G(&EN('5N=&EL('EO
M=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM
M<V=I9"`B4W5B<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I
M;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G
M<W1R("+#X=_5Z-W>(@H*(SH@861M:6XO=7-E<BYP:'`Z.#4*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@
M=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B)R5S)R#CX=_5Z-W>(-3>U-#4U=T@
MW=`@X=CAXM7<WN(N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A
M(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(B<E
M<R<@X^'?U>C=WB#>XN'BX-#=U>(@WM0@X=CAXM7<WN(N(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HX,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<
M(B5S7"(N(@IM<V=S='(@(B<E<R<@X^'?U>C=WB#4WM30U-7=(-W0(.'8X>+5
MW-[B+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R;VT@
M=&AE('-Y<W1E;2XB"FUS9W-T<B`B)R5S)R#CX=_5Z-W>(-[BX>+@T-W5XB#>
MU"#AV.'BU=S>XBXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS
M9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L
M;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G
M:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU
M<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY('5P9&%T960@7"(E<UPB(@IM<V=S='(@(B<E<R<@X^'?U>C=
MWB#4WM30U-7=(-W0(.'8X>+5W-[B+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T
M<B`B)R5S)R#CX=_5Z-W>(-3>U-#4U=T@W=`@X=CAXM7<WN(N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-`IM<V=I9"`B4W5D86XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@HC+"!F=7IZ
M>0IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R("*ZX-#BVMX@X-77V-S5.B(*"B,Z
M(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8X"FUS9VED(")3
M=6X@4V5T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3=6YN>2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$V"FUS9VED(")3=6YR:7-E
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]"
M;&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-0IM
M<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,3D*;7-G:60@(E-U;G-E="(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$X"FUS9VED(")3=6YS
M970Z("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$S"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<X"B,L(&9U>GIY"FUS
M9VED(")3=7!P;W)T(@IM<V=S='(@(KC<W][@XB(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*
M(RP@9G5Z>GD*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(KK>X-CAW=CGVMX@
MV-S5(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S0*
M(RP@9G5Z>GD*;7-G:60@(E-U<FYA;64B"FUS9W-T<B`BNM[@V.'=V.?:WB#8
MW-4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA
M>65N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V"FUS9VED
M(")3>6YC(&QO9R!D96QE=&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-#(*;7-G:60@(E-Y;F--3"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A
M>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-PIM<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G
M:60@(E0M4W1O<FTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8R"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3
M=&]R;7,@16%R;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T
M82]T<W8N<&AP.C$V-@HC+"!F=7IZ>0IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T
M<B`BO=#AV][2(@H*(SH@9G)A;65W;W)K+U5)+U5)+U1A8FQE+G!H<#HQ,S0*
M(RP@9G5Z>GD*;7-G:60@(E1A8FQE(@IM<V=S='(@(KW0X=O>TB(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*
M;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PIM<V=I9"`B5&%B
M;&4@4V5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E<G1I
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S0@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I
M=V%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N:71E
M9"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDU"FUS9VED(")487)G970Z(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.38@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$X-PIM<V=I9"`B5&%S:W,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@
M(E1E;&5P:&]N92!.=6UB97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR.3`*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$T"FUS9VED(")496UP
M97)A='5R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C(S"FUS9VED(")496UP97)A='5R93H@(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E
M9SLE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA
M=&4N<&AP.C8X-PHC+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S
M7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N
M<&AP.C$V.0HC+"!F=7IZ>0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R871I
M;VXB"FUS9W-T<B`BL-3<V-W8X>+@T.;8^-`B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S8*
M;7-G:60@(E1E>'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,W-0IM<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G
M:60@(E1E>'0@86QI9VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y,0IM<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"FUS9VED(")4:&%N:R!Y;W4@
M9F]R('5S:6YG('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#(P"FUS9VED(")4:&4@1E10(&5X=&5N<VEO
M;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O
M<G0@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?24U34"])
M35-0+T)O;VLN<&AP.C$R.3(*;7-G:60@(E1H92!)35-0(&QO9R!C;W5L9"!N
M;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA
M:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA
M<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@
M3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.#D@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HR,#`*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HR,3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,C,*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,S0@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HR-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-C0@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A
M9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!0
M97)M:7-S:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S92!097)M
M:7-S:6]N<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S
M:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT86-T
M($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W
M87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4Q"FUS
M9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO
M=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,38Y"FUS9VED("(B"B)4:&4@9&5T86-H960@
M4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE
M('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B(@HB5&AE
M(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE
M9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T
M('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0N<&AP.C$Q,PIM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A
M='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S4@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V."!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR
M,3D*;7-G:60@(E1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S
M96QF+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR
M.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP
M.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@
M=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4V"FUS9VED
M("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P
M<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O
M=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N
M("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E(&1I<W!L87DL(&QA
M8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@
M8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G
M<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"`B"B)0
M<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U
M(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U
M('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T
M960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T+6AA;F0@<VED
M92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G50
M1R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA
M<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H
M<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N
M="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I
M<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE
M<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<W"FUS9VED(")4:&4@
M;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Q
M"FUS9VED(")4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,3(S,0IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D
M(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+G!H<#HR.3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO
M="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M
M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A
M=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#4T"FUS
M9VED(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C
M:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A
M;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H
M92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HT-#8*;7-G:60@(E1H92!S97!A<F%T;W(@
M;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@
M<V%V960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA
M<R!B965N(')E;6]V960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C,S,`IM<V=I9"`B5&AE('-P96-I9FEE9"!R
M;W<@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,3<W"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T
M96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,3$*;7-G:60@(E1H
M92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@
M=&AE('-C<F5E;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A
M;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B
M5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A
M=&$O1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@
M;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T1A=&$O1&%T82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T
M82]$871A+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C
M;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HT-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-38*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q-2!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$Y"FUS9VED(")4:&4@=V5A=&AE
M<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-S@*(RP@9G5Z
M>GD*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92XB"FUS
M9W-T<B`BO=7<T"#4WN'BT-_=V"#?WM35X>/2T/K0+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C,T,@IM<V=I9"`B5&AE<F4@87)E
M(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,#$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E
M<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T
M97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@
M(B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@861D
M:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R("*]T.'BT-W0
M(-_@WM';U=P@W^#8(-3>U-#2T/K5(-W0("5S(-+>(.'8X>+5W-[B+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$R,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R
M(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("*]T.'BT-W0(-_@
MWM';U=P@W^#8(-[BX>+@T-WCTM#ZU2#=T"`E<R#>U"#AV.'BU=S>XBXB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,#,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R;VT@
M=&AE('-Y<W1E;3H@(@IM<V=S='(@(KW0X>+0W=`@W^#>T=O5W"#?X-@@WN+A
MXN#0W>/2T/K5(-W0("5S(-[4(.'8X>+5W-[B+B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$U.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z("5S(@IM<V=S='(@(KW0X>+0
MW=`@W^#>T=O5W"#?X-@@U-[4T-+0^M4@W=`@)7,@TMX@X=CAXM7<WN(N(@H*
M(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@T"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@
M(@HB86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y,0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN
M9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A
M=&$N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#`*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A
M=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D
M(&9I96QD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N
M(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@
M9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@
M=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HR,C(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A
M=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@
M;&%T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C$T.`IM<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S
M(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HT.`IM<V=I9"`B
M5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@
M82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$T-0IM<V=I9"`B5&AI<R!D;V5S(&YO="!S965M('1O
M(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I
M9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@
M=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN
M8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S0*;7-G
M:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W
M87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B
M(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR
M;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U
M"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G
M871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S
M(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T
M<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HY-S@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`U-PHC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#@V(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Q,34*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X
M,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C4V"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$S,#4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Y
M.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-34W(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$X,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3DU."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`U"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(P,CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C`W.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,30Y(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(R,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C0Q,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4T"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(V-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C@R.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3,W(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,S,#8*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S@Q-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#(R"FUS9VED
M(")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#8U"FUS9VED(")4:&ES(&9I96QD(&UA
M>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3@*;7-G:60@(E1H:7,@9FEE;&0@;6%Y
M(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.30*;7-G:60@(E1H
M:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,C,*;7-G:60@
M(E1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E
M9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.CDX.0IM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@
M=F%L:60@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#,V"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I
M;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA
M;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C4V,0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y
M(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:&5L
M<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0U
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O
M=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N
M965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+
M;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA
M:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DQ"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H
M87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-@IM<V=I
M9"`B5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HT
M-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD
M(&=Z:7`@9FEL97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]296=I<W1R>2YP:'`Z,3@Y"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C
M=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E(&UU
M<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VEM86=E
M<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@
M8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*;7-G
M:60@(E1H=6YD97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(S-`IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#(X('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B5&EM92(*;7-G<W1R("*]T.';
MWM(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@V"FUS9VED(")4
M:6UE(%1R86-K:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H
M<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C4S.0IM<V=I9"`B5&EM92!S96QE8W1I;VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S=&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B5&ET
M;&4B"FUS9W-T<B`BO=#AV][2(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C4T"FUS9VED("(B"B)4;R!S
M96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H
M4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Q
M"FUS9VED(")4;V1A>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3
M;W5R8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&]G;R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VME;&%U(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3,*;7-G
M:60@(E1O;6]R<F]W(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@
M(E1O;F=A(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW-PIM<V=I9"`B5&]P(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*
M;7-G:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8S"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5')I;FED860@86YD(%1O8F%G
M;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-SDP
M"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED(")4=7)K:7-H("A)
M4T\M.#@U.2TY*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4
M=7)K;65N:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B
M5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3$*;7-G:60@(E1U=F%L=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0TQ)+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V.0IM
M<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M
M92YP:'`Z,3<*;7-G:60@(E523"(*;7-G<W1R(")54DPB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T,0IM<V=I9"`B
M55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.3<*(RP@9G5Z>GD*;7-G:60@(E523#HB"FUS9W-T<B`B55),(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A;F1A(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3(*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z-#$R"B,L(&9U>GIY"FUS9VED(")5;F%B
M;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(KW5(-S>UM72
M(-30(.'5(-K>W=7:XMC@T-P@X=X@4U%,(.'5X-+5X-[B+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B56YA8FQE('1O
M(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS.#@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S
M:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C,X-2!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C
M:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4U"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*
M;7-G<W1R("*]U2#<WM;5TB#4T"#AU2#:WMW5VN+8X-#<(.'>(%-13"#AU>#2
MU>#>XBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(S,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z-C@X(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3`Q-@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z.#,T"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E
M<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP
M:'`Z-#,U"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R
M+B(*;7-G<W1R("*]U2#<WM;5TB#4T"#AU2#:WMW5VN+8X-#<(.'>(%-13"#A
MU>#2U>#>XBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S.0HC
M+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN(@IM
M<V=S='(@(KW5(-S>UM72(-30(.'5(-K>W=7:XMC@T-P@X=X@4U%,(.'5X-+5
MX-[B+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R-2!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR
M,#D*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*
M;7-G<W1R("*]U2#<WM;5TB#4T"#AU2#:WMW5VN+8X-#<(.'>(%-13"#AU>#2
MU>#>XBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,V-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O
M<GD@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HS-30@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(U.`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C4V"B,L(&9U>GIY
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(KW5(-S>UM72(-30(.'5(-K>W=7:XMC@T-P@X=X@4U%,(.'5X-+5X-[B
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@
M(KW5(-S>UM72(-30(.'5(-K>W=7:XMC@T-P@X=X@4U%,(.'5X-+5X-[B+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C@V"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(V
M-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@
M9FEL92XB"FUS9W-T<B`BO=4@W-[6U=(@U-`@X=4@VM[=U=KBV.#0W"#AWB!3
M44P@X=7@TM7@WN(N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S
M+W1A<BYP:'`Z-S8*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z
M:7`N<&AP.C<Y"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(R-"!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(Y.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I
M<R!N;W0@96UP='DN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M-S@@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S,2!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C,Y,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,S$Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,S0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE
M(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T."!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,S4R"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S-R!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS
M,S4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T,PHC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0T"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(KW5(-S>
MUM72(-30(.'5(-K>W=7:XMC@T-P@X=X@4U%,(.'5X-+5X-[B+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#$W(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z-#(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,C`W"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,#,@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HR.#@*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C$V-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P"B,Z
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,X,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,SDQ"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F
M:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C(T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C0P-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#`S"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G
M<W1R("*]U>/AW]7HW=X@X-73V.'BX-C@T/K5(-W0(-_>U-7AX]+0^M#BT"#2
MWB#AU>'8^-#BT"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8P,PIM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@
M9&5T86EL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U3
M4"YP:'`Z-#4Q(&9R86UE=V]R:R].971?24U34"])35-0+T%U=&@N<&AP.C$Q
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F
M:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P
M,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,38V(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-S$*(RP@9G5Z>GD*;7-G:60@
M(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R("*]U2#<WM;5TB#4
MT"#3V"#8U]S5W=#<(-_>U-7AX]+0^M#BT"XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.CDS(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,3`R
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-C0X(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-S<@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,3,S"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@
M=W)I=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z.#`@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3,P"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,@HC+"!F=7IZ>0IM<V=I
M9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@(KW5(-S>UM72
M(-30(.'5(-K>W=7:XMC@T-P@X=X@4U%,(.'5X-+5X-[B+B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*(RP@9G5Z>GD*;7-G
M:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92XB"FUS9W-T
M<B`BO=4@W-[6U=(@U-`@T]@@V-?<U=W0W"#?WM35X>/2T/K0XM`N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C@S-0IM<V=I9"`B56YA8FQE('1O(')E
M860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@V-@IM<V=I9"`B56YA8FQE('1O
M(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD
M;&5R+VYO;F4N<&AP.C,X"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C8Y
M"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$P
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O
M("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(Y,PHC
M+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y
M+B(*;7-G<W1R("*]U2#<WM;5TB#4T"#AU2#:WMW5VN+8X-#<(.'>(%-13"#A
MU>#2U>#>XBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E
M8W1O<GDZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C(V-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,T,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z-C$P(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,CD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS
M,C,@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(Q,PHC.B!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#4R(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HR.#4*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C,P,0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+VUK:7-O9G,N<&AP.C4P"FUS9VED(")5;F%B;&4@=&\@<G5N("=M:VES;V9S
M)RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M;7-W;W)D+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O('1R86YS;&%T92!T:&ES
M(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`BO=4@W-[6U=(@U-`@T]X@W^#5TM74
MT-P@WM+>^"!7;W)D(-3>VN/<U=WB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z,30Y(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,34R"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C$W.0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y
M*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,C@Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ
M,S@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$T,PIM<V=I
M9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-#$*;7-G:60@(E5N86)L92!T
M;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G
M<W1R("*^XMK0UM@@T]@@W^#>W-7=V.+5(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PIM<V=I9"`B56YD;V5S('EO=7(@
M;&%S="!A8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,Y,`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS
M92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,0HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S@*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@T"FUS9VED(")5;F5X
M<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z
M-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M-C$*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.3,*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")5;FET960@2VEN9V1O;2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T
M97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-CD@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HW,0IM<V=I9"`B56YI=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#(Y(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0S,`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G
M:60@(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDY"FUS9VED(")5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S
M<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-3D*;7-G:60@(E5N:VYO=VX@;&]C871I;VX@<')O=FED960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P
M87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X"FUS9VED(")5;FQI;FL@=&AE
M(&-U<G)E;G0@96QE;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E
M;G1I='DO261E;G1I='DN<&AP.C(Y-@HC+"!F=7IZ>0IM<V=I9"`B56YN86UE
M9"(*;7-G<W1R("*ZWN#8X=W8Y]K>(-C<U2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL
M96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O
M9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@
M3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI
M8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E
M<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@IM<V=I9"`B56YS
M970@8V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HV.#8@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HY,C8*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,S(*
M;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$Y-R!T96UP;&%T97,O861M
M:6XO=7-E<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D871E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,CD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S8*(RP@9G5Z>GD*;7-G:60@
M(E5P9&%T92!U<V5R(@IM<V=S='(@(K3>U-#4V"#:WN#8X=W8VB(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z,30T(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S
M97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,P"B,L('!H<"UF;W)M870*;7-G
M:60@(E5P9&%T960@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HX,PIM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E
M9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W."!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DY"FUS9VED
M(")5<&QO860B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$X-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I
M;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@
M(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I
M9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$S"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L('!H<"UF;W)M
M870*;7-G:60@(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I
M9"`B57-E(%-33"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3(T"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E
M;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"B,L(&9U>GIY"FUS9VED(")5<V5R
M(@IM<V=S='(@(KK>X-CAW=CGVMX@V-S5(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+U)E9VES=')Y+G!H<#HW,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PHC+"!F=7IZ>0IM<V=I9"`B57-E<B!!
M9&UI;FES=')A=&EO;B(*;7-G<W1R(")(;W)D92"PU-S8W=CAXN#0XM[@(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR-3$*(RP@9G5Z>GD*
M;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R("*WT.?CTM#X(-[?YMC8(@H*
M(SH@<VEG;G5P+G!H<#HV,@HC+"!F=7IZ>0IM<V=I9"`B57-E<B!296=I<W1R
M871I;VXB"FUS9W-T<B`B2&]R9&4@L-3<V-W8X>+@T.+>X"(*"B,Z('-I9VYU
M<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I
M<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HT-CD*;7-G:60@(E5S97(@86-C;W5N="!N;W0@9F]U
M;F0B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$W.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=F]D869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3`@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z,S,*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,B!T
M96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E
M<FYA;64B"FUS9W-T<B`BNM[@V.'=V.?:WB#8W-4B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@
M(E5S97)N86UE(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@W"B,L(&9U>GIY"FUS
M9VED(")5<V5R;F%M93HB"FUS9W-T<B`BNM[@V.'=V.?:WB#8W-4B"@HC.B!T
M96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"B,L(&9U>GIY"FUS9VED(")5
M<V5R;F%M93H@(@IM<V=S='(@(KK>X-CAW=CGVMX@V-S5(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@:6X@=&AE
M('-Y<W1E;3HB"FUS9W-T<B`BNM[@V.'=V.;8(-+>(.'8X>+5W-[B.B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,38S(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C(U-0IM<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO
M="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$Q.`IM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.#8V"FUS9VED(")686QI9"!L;V-A=&EO;G,@
M9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C,X"FUS9VED(")686QI9&ET>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4Y-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR-34*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@U-B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3<W"B,L('!H<"UF;W)M870*;7-G
M:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0T(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C8*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C,Q-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(X"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3D*;7-G
M:60@(E9A;'5E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,3`Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#8*;7-G:60@
M(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$W"FUS9VED(")686YU871U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-#0*;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I
M9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V
M92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED(")697)S:6]N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,C8*;7-G
M:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")6
M97)T:6-A;"!A;&EG;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D
M:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I
M9"`B5F5R>2!(:6=H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@
M(E9I970@3F%M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DT"FUS9VED(")6:65T;F%M97-E("A625-#24DI(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.CDV,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A
M9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.#(Q"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L
M($)R:71I<V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER
M9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,#D*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V,PIM<V=I9"`B5FES:6)I
M;&ET>3H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L
M>2!V:6$@4TU44"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T
M:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS9VED
M(")705).(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#
M4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S,PIM<V=I9"`B5TE.('9I
M82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E=A;&QI
M<R!A;F0@1G5T=6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,C<R(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HX,PIM<V=I9"`B5V%R;FEN9R(*;7-G<W1R("*R
MW=C<T-W8U2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#(W
M"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DR"FUS9VED(")796%T:&5R
M+F-O;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM
M<V=I9"`B5V5B(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT,S<*;7-G:60@(E=E8B!3:71E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E
M96ML>2(*;7-G<W1R("*]U=35V]W>(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO
M8FEL92YP:'`Z,C@*(RP@9G5Z>GD*;7-G:60@(E=E;&-O;64B"FUS9W-T<B`B
MM-[1X-74WOC4U2P@)7,B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN
M8SHT('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-3<*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`BM-[1X-74
MWOC4U2P@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.2!T
M96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`BM-[1X-74WOC4U2P@)7,B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-0IM<V=I9"`B5V5S=&5R;B`H25-/+3@X
M-3DM,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.38*
M;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO
M9VEN/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*
M;7-G:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P
M-C$*;7-G:60@(E=H97)E:7,@075S=')A;&EA(&UA<"(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S"FUS9VED
M(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E
M9&ET;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@(E=I9'1H(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C4*;7-G:60@(E=I
M9'1H(&EN($-34R!U;FET<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S4W"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H
M92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L
M;V<M:6XI.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS
M9VED(")7:61T:#HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C4Q,PIM<V=I9"`B5VEK:2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")7:6YD(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V"FUS9VED
M(")7:6YD($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z.#`*;7-G:60@(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-38*;7-G:60@(E=I;F0Z(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#(*;7-G
M:60@(E=I;F0Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C0*;7-G:60@(E=I<V1O;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3DV"FUS9VED(")7:7-H;&ES="(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G:60@(E=O<FLB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$R-`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`BL-3@U>'0(-W0
M(.#0T=[BT"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`BPM7;U>3>W2#=
MT"#@T-'>XM`B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-CD@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C8R"B,L('!H<"UF;W)M870*
M;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP
M96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HS,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O
M;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,30*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE(')E
M861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(T,PIM<V=I9"`B6"U2968B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U
M,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,@IM<V=I9"`B6#4P.78S($5X
M=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S(%-U8FIE8W0@
M06QT97)N871I=F4@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U8FIE8W0@
M2V5Y($ED96YT:69I97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV.#(*;7-G:60@(E@U,#EV,R!E>'1E;G-I;VYS
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")9
M62(*;7-G<W1R("*SLR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0U-0HC+"!F=7IZ>0IM<V=I9"`B65E962(*;7-G<W1R("*S
MLR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,3`X"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L
M>2(*;7-G<W1R("*SWM38Z-W>(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B665M
M96XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.CDV,PIM<V=I9"`B665S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4V"FUS9VED(")9
M97,L($D@06=R964B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I;B!415A4
M($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O
M(%=94TE764<N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET
M+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO
M=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T,3$*;7-G:60@(EEO
M=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`R"FUS9VED(")9;W4@8V%N
M(&YO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U
M-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<U"FUS9VED(")9;W4@9&ED
M(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE
M(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*
M(FEN("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HY.#@*;7-G:60@(EEO=2!H879E(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(V,0IM<V=I9"`B
M(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R
M+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F;W(@=&AE
M(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#@*;7-G:60@(EEO=2!H879E
M('1O(&5N=&5R(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@
M8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT-38*
M;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ,0IM
M<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO
M=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@(K[?V.C5
MXM4@T]X@W^#>T=O5W-[B(-_@U=0@U-`@V.'?X-#BU>+5(-C7TM7HXM#X+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*
M;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK
M('!O:6YT<R!T;R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C
M<W5M+G!H<#HX,`HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N
M('-E<G9E<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R("*]T-+5U-7BU2#:WM4@
MVM[@V.'=V.?:WB#8W-4@U-`@X=4@WN+AXN#0W=@N(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3$Y"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@
M=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R("*]T-+5U-7BU2#:WM4@
MVM[@V.'=V.?:WB#8W-4@U-`@X=4@WN+AXN#0W=@N(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3`P"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@
M=&\@<F5M;W9E+B(*;7-G<W1R("*]T-+5U-7BU2#:WM4@VM[@V.'=V.?:WB#8
MW-4@U-`@X=4@WN+AXN#0W=@N(@H*(SH@861M:6XO=7-E<BYP:'`Z-C(@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS9VED(")9;W4@;75S
M="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@(KW0TM74
MU>+5(-K>U2#:WN#8X=W8Y]K>(-C<U2#4T"#AU2#4WM30U-4N(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,30V"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S<&5C
M:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@(KW0TM74U>+5
M(-K>U2#:WN#8X=W8Y]K>(-C<U2#4T"#AU2#4WM30U-4N(@H*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,X"B,L(&9U>GIY"FUS
M9VED(")9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN
M(@IM<V=S='(@(KW0TM74U>+5(-K>U2#:WN#8X=W8Y]K>(-C<U2#4T"#AU2#>
MXN'BX-#=V"XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-
M86YA9V5R+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@='EP92!A
M(&YE=R!C871E9V]R>2!N86UE+B(*;7-G<W1R("*]T-+5U-7BU2#:WM4@VM[@
MV.'=V.?:WB#8W-4@U-`@X=4@WN+AXN#0W=@N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO
M=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<V"B,L('!H
M<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@
M4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHS.`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!%
M;6%I;"!!9&1R97-S(@IM<V=S='(@(K+0Z-`@16UA:6P@T-3@U>'0.B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,3(*(RP@9G5Z>GD*;7-G:60@(EEO
M=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`BLM#HT"!%;6%I;"#0U.#5X=`Z
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8T(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HW-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C@Y"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S
M(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I
M;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G
M:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C,S"B,L(&9U>GIY"FUS9VED(")9;W5R($YA;64B"FUS9W-T
M<B`BLM#HU2#8W-4Z(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N
M:6YC.C4*(RP@9G5Z>GD*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@
M8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U
M('=I<V@@=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O
M=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T
M:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*(K+0Z-C>XB#0TN+>X-C7T.;8WMW5
MW2#?X-[BWMK>VR#=U2#?WM3@UN/2T"#4WM30TM#ZU2#:WN#8X=W8YM@L(-C;
MV"#BT-`@(@HBW-[6W=[AXB#5(-[=U=+>U]S>UM7=T"#>U"#4X./3V"#?X-CG
MV-W8+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM
M<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T
M('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S
M(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R
M("(B"B*RT.C8WN(@T-+BWN#8U]#FV-[=U=T@W^#>XM[:WML@W=4@W][4X-;C
MTM`@V]CAXM#ZU2#:WN#8X=W8YM@L(-C;V"#BT-`@(@HBW-[6W=[AXB#5(-[=
MU=+>U]S>UM7=T"#>U"#4X./3V"#?X-CGV-W8+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.CDX-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R
M(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E
M9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U
M<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C4P"FUS9VED(")9;W5R(&)R;W=S
M97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"FUS9VED("(B
M"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P
M=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN="XB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U-PIM<V=I
M9"`B66]U<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<')E9G,N<&AP.CDV"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I
M='D@:&%S(&)E96X@8VAA;F=E9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$U.`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!D969A=6QT
M(&ED96YT:71Y.B(*;7-G<W1R("+!XM#=U-#@U-7=(-C4U=WBV.+5XB(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#$*(RP@9G5Z>GD*;7-G:60@(EEO
M=7(@9G5L;"!N86UE.B(*;7-G<W1R("*RT.C5(-C<U3HB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+G!H<#HQ,#`P"FUS9VED(")9;W5R(&QO9VEN(&AA<R!E
M>'!I<F5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R
M9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B
M965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,34V"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS
M9VED(")9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9
M;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL
M(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S,R"FUS9VED(")9
M;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G:60@(EEO=7(@<F5M;W1E
M('-E<G9E<G,Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C4T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G
M:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N
M<&AP.C$W,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ
M<SHQ,@IM<V=I9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!R;V)L96TN<&AP.C@X"FUS9VED(");4')O8FQE;2!297!O
M<G1=(@IM<V=S='(@(ENXU]+5Z.+0^"#7T"#?X-[1V]7<WN)=(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3
M:&]W(%%U;W1E9"!497AT("TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E
M>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S
M72(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-30Q('1E;7!L
M871E<R]P;W)T86PO;65N=2YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E]!9&UI
M;FES=')A=&EO;B(*;7-G<W1R("*PU-S8W=CAXN#0YMCXT"(*"B,Z(&QI8B]A
M<&DN<&AP.C$U-PIM<V=I9"`B7T-,22(*;7-G<W1R("(B"@HC.B!L:6(O87!I
M+G!H<#HQ-#$*;7-G:60@(E]$871A5')E92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*
M(RP@9G5Z>GD*;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(KC7T>#8Z-@B
M"@HC.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W-0HC+"!F
M=7IZ>0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`BO][<WN@B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G
M:60@(E]);6%G92!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.30*(RP@9G5Z>GD*;7-G:60@
M(E],;V<@:6XB"FUS9W-T<B`BN][3V.#0^M4B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O365N=2YP:'`Z,3DP"B,L(&9U>GIY"FUS9VED(")?3&]G(&]U
M="(*;7-G<W1R("*XU]O5UR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO9&EF>2!,:6YK
M+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU
M+G!H<#HQ-C0*(RP@9G5Z>GD*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(K?0
MY^/2T/@@WM_FV-@B"@HC.B!L:6(O87!I+G!H<#HQ,S<*;7-G:60@(E]097)M
M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*(RP@9G5Z>GD*;7-G:60@(E]2
M96UO=F4@3&EN:RXN+B(*;7-G<W1R("*^U.'BX-#=V"#?T.`B"@HC.B!L:6(O
M87!I+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*
M;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&QI
M8B]A<&DN<&AP.C$R.0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Q"B,L(&9U>GIY"FUS9VED(")A
M9&1R97-S(&)O;VLB"FUS9W-T<B`BL-3@U>'0X"(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,3,T"FUS9VED(")A9&1R97-S964@=6YK
M;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDQ,PIM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N;F]T(&-R96%T
M92!O=71P=70@9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z-3DR"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(R"FUS9VED(")C;VUM86YD
M(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ-S@*;7-G:60@(F-O;F9I9W5R871I;VX@
M97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ-30*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I
M;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ,C8*;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3@R"FUS9VED
M(")E;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*;7-G:60@(F9A;&QI;F<B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4U
M"B,L(&9U>GIY"FUS9VED(")F:6QE(@IM<V=S='(@(KW0X=O>TB(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3<T(&QI8B]";&]C:R]M971A<BYP:'`Z,S8P
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S@V"B,L('!H<"UF;W)M870*;7-G:60@
M(F9R;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,`IM<V=I9"`B9W5S=&EN9R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C0Y"FUS9VED(")H.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4X"FUS9VED(")H:"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S
M.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S
M"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(FEN
M;&EN92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,30V"FUS
M9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B
M;&EN97-=(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C,V.0IM<V=I9"`B;6TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HR.3$@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N
M<&AP.C$W,`HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C,R"B,L
M(&9U>GIY"FUS9VED(")N86UE(@IM<V=S='(@(KC<U2(*"B,Z(&9R86UE=V]R
M:R]24$,O4E!#+G!H<#HQ,C$*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R
M,3D*;7-G:60@(FYO="!Y970@:6UP;&5M96YT960B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#4*;7-G:60@(FYO=&5P860B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W-`IM<V=I9"`B
M<&5R;6ES<VEO;B!D96YI960B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX
M96QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,3<P"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-S,*(RP@9G5Z>GD*;7-G:60@(G)I<VEN9R(*;7-G<W1R("*RW=C<T-W8
MU2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,30R"FUS
M9VED(")S97)V:6-E('5N879A:6QA8FQE(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z.3D*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,S@U"FUS9VED(")S<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,@IM<V=I9"`B<W1E861Y(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S`Y"FUS9VED
M(")S=VET8V@@;V9F(&IA=F%S8W)I<'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E
M<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDR.0IM<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,38V"FUS9VED(")T96UP;W)A<GD@
M9F%I;'5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C,P-0HC+"!F=7IZ>0IM<V=I9"`B=')Y(&%G86EN(@IM<V=S='(@(L'5
MVM[5(-_@V/C0TN/2T/K5(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@9G)A;65W
M;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B='EP92!T:&4@
M<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM
M<V=I9"`B=6YI9FEE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U!A<G0N<&AP.C(W"FUS9VED(")U;FYA;65D(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(R,PIM<V=I9"`B=7-E<B!S96QE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C0Q"FUS9VED(")W.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS
M9W-T<B`B(@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]L=E],5BYP;P``
M````````````````````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`V,3$S-3(@,3`U,34T,S,W-#,@,#$W-34P`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````",@3&%T=FEA;B!T<F%N<VQA=&EO
M;B!F;W(@2&]R9&4N"B,@2V%S<&%R<R!+87!E;FEE:W,@/&MA<W!A<G-`<F-C
M+FQV/BP@,C`P,BX*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M
M5F5R<VEO;CH@2&]R9&4@,BXQ7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@
M9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P
M,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P
M,BTQ,2TR."`Q-#HP,"LP,C`P7&XB"B),87-T+51R86YS;&%T;W(Z($MA<W!A
M<G,@2V%P96YI96MS(#QK87-P87)S0')C8RYL=CY<;B(*(DQA;F=U86=E+51E
M86TZ($QA='9I86X@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-12U6
M97)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA
M<G-E=#U#4#$R-3=<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M
M8FET7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S8Y"B,L('!H
M<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,W,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@
M*&EN("5S(&1A>7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S-S,*;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S4*;7-G:60@(B`H=&]M;W)R;W<I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S$*
M;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C4V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS-C$*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0P-PIM
M<V=I9"`B(&%T("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T
M(&$@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,
M22YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@
M82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92]296=I<W1R>2YP:'`Z-C4Y"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]296=I<W1R>2YP:'`Z,3`T,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!2
M96=I<W1R>2XB"FUS9W-T<B`B)R5S)R!N878@;F]RXF3N=',@2&]R9&4@<F7L
M:7-T<N(B"@HC.B!F<F%M97=O<FLO5')E92]4<F5E+G!H<#HQ-S$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4V"B,L('!H<"UF
M;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S
M>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H
M<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O
M('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z-30@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-R96%T960Z("5S
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W
M960@*"4N,F8E)2DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A;F0@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HR-C@@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4U-PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X
M-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C8X"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`T"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S,R!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HX,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M2T(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S($UA:6YT96YA;F-E($]P97)A=&EO
M;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B)7,@57IT=7+G\&%N87,@;W!E
M<N)C:6IA<R`M(&%P<W1I<')I;N)J=6US(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$U"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N
M86YC92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@
M06=R965M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z-#(X(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DP"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C4Q(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@
M97AI<W1S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U
M.2!L:6(O0FQO8VLO;65T87(N<&AP.C$V-2!L:6(O0FQO8VLO;65T87(N<&AP
M.C(S.0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T-2!L:6(O0FQO8VLO;65T
M87(N<&AP.C,U,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E
M<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO
M=RX@0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@
M=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B071Z[FWG
M:FEE="!D87)B[F)A<RP@:V\@=N=L871I97,@=F5I:W0N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!I<R!R97%U:7)E9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(X-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E
M<R(*;7-G<W1R(")+871R87,@-2!M:6[[=&5S(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@(EMR:6YD82`E<R!N;R`E<UTB
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR,@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B
M2V]N=&%K=&DB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ-`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G
M<W1R(")+86QE;F3B<G,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDP-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M
M;V)I;&4N<&AP.CDV"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H
M<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,Z(%1H:7,@;65S<V%G
M92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R
M92!O9B!F;VQL;W=I;F<@(@HB86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I
M9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S8U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,3`*;7-G:60@(BP@
M9W5S=&EN9R`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M.#@@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@
M9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C(Y-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C,T.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#8Y(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Q,C@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C<T.0IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,`HC+"!F=7IZ>0IM<V=I
M9"`B,3(@2&]U<B!&;W)M870B"FUS9W-T<B`B2OMS=2!I;F9O<FWB8VEJ82(*
M"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ.0HC+"!F=7IZ>0IM<V=I9"`B,C0@
M2&]U<B!&;W)M870B"FUS9W-T<B`B2OMS=2!I;F9O<FWB8VEJ82(*"B,Z('1E
M;7!L871E<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G
M<W1R("(R-"!S='5N9&%S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H
M<#HV.0IM<V=I9"`B/%!R979I;W5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,3$Y"FUS9VED(")!(&1A=&%B87-E(&)A8VME;F0@:7,@
M<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,38P"B,L(&9U>GIY"FUS9VED(")!(&9A
M=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R("(\8CY)<B!N;W1I:W5S
M:2!K<FET:7-K82!K[_MM93H\+V(^(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E
M<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38U"FUS9VED(")!('!U
M8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M
M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ,#DW"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV
M871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D
M96-R>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Q-0IM<V=I9"`B(@HB02!P=6)L:6,@
M4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3`U"FUS9VED("(B
M"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S
M<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R
M:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@
M4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*;7-G:60@(D%-($QI
M9VAT(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3$*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G
M:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-N;W<@4VAO=V5R
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM
M<V=I9"`B04TO4$TB"FUS9W-T<B`B04TO4$TB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)
M1"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,@IM<V=I9"`B06)O
M=70N+BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*
M;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,C<P"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T
M:6YG(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E
M871I;F<@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HS"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N
M(@IM<V=S='(@(DK[<W4@:6YF;W)MXF-I:F$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-S4*(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B
M"FUS9W-T<B`B4&%R;VQE(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S,PIM
M<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$T."!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z
M,30*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z,3$*
M(RP@9G5Z>GD*;7-G:60@(D%D9"(*;7-G<W1R(")!9')E<V4B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G<F]U<',N<&AP.C(R-0IM<V=I9"`B
M061D($-H:6QD($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z.3@@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HY.0IM<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*(RP@9G5Z>GD*;7-G:60@
M(D%D9"!(97)E.B(*;7-G<W1R(")!9')E<V4B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q.0IM<V=I9"`B061D($YE=R!'
M<F]U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C@W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#@*;7-G:60@
M(D%D9"!.97<@4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHW"B,L('!H<"UF;W)M870*;7-G
M:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@
M;F5W('5S97(Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HU-30*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS-`IM
M<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@
M(E!I979I96YO="!PXG)I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-
M;WII;&QA(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")!9&0@
M=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R(")+;VYT86MT:2(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW.`HC+"!F=7IZ>0IM
M<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O:R(*;7-G<W1R(")+;VYT86MT
M:2(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"B,L(&9U>GIY"FUS9VED(")!9&0@
M=7-E<B(*;7-G<W1R(")0:65V:65N;W0@<.)R:2(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D(%PB)7-<(B!T
M;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I
M9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@(B(*"B,Z('-I9VYU
M<"YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E<UPB('1O
M('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G:60@(D%D
M9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T-#$*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`B061R
M97-E(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S.0HC+"!F=7IZ
M>0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(DMO;G1A:W1I(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30*;7-G:60@
M(D%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ.2!S97)V:6-E<R]P
M;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED(")!9&UI;FES=')A=&EO;B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Q"B,L
M(&9U>GIY"FUS9VED(")!9',B"FUS9W-T<B`B061R97-E(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M-@IM<V=I9"`B069G:&%N:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PHC
M+"!F=7IZ>0IM<V=I9"`B06QB86YI82(*;7-G<W1R(")!:7IS=.)J=N)R9',B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<P"B,L(&9U>GIY"FUS9VED(")!;&=E<FEA(@IM<V=S='(@
M(D%I>G-TXFIVXG)D<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ,#<*;7-G:60@(D%L:6%S(@IM<V=S='(@(D%I>G-TXFIV
MXG)D<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,38*(RP@9G5Z>GD*;7-G:60@(D%L:6=N(@IM<V=S='(@(D%I
M>G-TXFIVXG)D<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N=#HB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C@W"FUS9VED(")!;&PB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,#<@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T
M960@57-E<G,B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS,R!A
M9&UI;B]G<F]U<',N<&AP.C(R,@IM<V=I9"`B06QL($=R;W5P<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDQ(&9R86UE
M=V]R:R]097)M<R]097)M<R]D871A=')E92YP:'`Z-S4*;7-G:60@(D%L;"!0
M97)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C$W"FUS9VED(")!;&P@9F]U<B!S
M:61E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.#<Q"FUS9VED(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S-`IM<V=I9"`B06QL;W<@
M<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS9VED
M(")!;')E861Y(&5X:7-T<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3(S"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`W"FUS9VED(")!
M;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#DY"FUS9VED(")!;'1E<FYA=&4@24U34"!5<V5R
M;F%M92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HS-0HC+"!F=7IZ>0IM<V=I9"`B06QT97)N871E(&5M86EL(&%D9')E<W,B
M"FUS9W-T<B`B2OMS=2!E+7!A<W1A(&%D<F5S93HB"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C$T,@IM<V=I9"`B06QT97)N871E('1E;7!L871E<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;65R:6-A;B!386UO82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.CDU(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I;&QE
M9V%L('9A;'5E('=A<R!S<&5C:69I960N(@IM<V=S='(@(DYO<N)D[G1A(&YE
M9&5R[F=A(';G<G3N8F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,38W"B,L(&9U>GIY"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O
M8V-U<F5D+B(*;7-G<W1R("(\8CY)<B!N;W1I:W5S:2!K<FET:7-K82!K[_MM
M93H\+V(^(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B06YD;W)R82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0Y
M"FUS9VED(")!;G-W97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B
M06YT87)C=&EC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!;G1I
M9W5A(&%N9"!"87)B=61A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN<&AP.C,U"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R]522YP:'`Z-3@@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN
M9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`B(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,
M:7-T(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#`*
M;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@
M0VAI;&0@4VAA<F5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S,PIM<V=I
M9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S4*;7-G:60@(D%R
M86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4Y(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HX,0IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HU."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8U"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#`*;7-G:60@
M(D%R8VAI=F4@3F%M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F5Q=65U960N:6YC.C$P"B,L('!H<"UF;W)M870*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R
M97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O9&5L971E+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%R
M92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@
M<W5B+6=R;W5P<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B07)G
M96YT:6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%R;65N:6$B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S8*;7-G:60@
M(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HR.`IM<V=I9"`B07)T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3D*;7-G:60@(D%R=6)A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA;F0B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!
M<V-I:2!!<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4U"FUS9VED(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,C4*;7-G:60@(D%S:R!F
M;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R
M871I;VYS/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,3$S"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I9"`B071T96UP="!T;R!D96QE
M=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W!E<FUS+V1E;&5T92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E
M(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED(")!='1E;7!T('1O(&5D:70@
M82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E;7!T('1O(&5D
M:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HW,0HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C@V"FUS9VED(")!='1R:6)U=&5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I
M9"`B075S=')A;&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U
M<W1R:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S
M<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED(")!=71H7V-Y<G5S.B!"
M86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$R
M,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@
M97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE
M;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]I;6%P+G!H<#HV-`IM<V=I9"`B075T:%]I;6%P.B!297%U
M:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?
M:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,P,@IM
M<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E
M9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C,U-PIM<V=I9"`B075T:%]L9&%P.B!2
M96UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER
M96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z-C,*;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H
M7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H
M92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?
M;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#DY"B,L('!H<"UF;W)M
M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M-#`U"FUS9VED(")!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S
M=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-#8*;7-G:60@(D%U=&A?
M;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z-C`*;7-G
M:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N(&9A:6QE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-PHC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!=71H96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-S8*;7-G:60@(D%U
M=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#4Q"FUS9VED
M(")!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HW,`IM<V=I9"`B
M075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C<U"FUS9VED
M(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R(")0:65E:F%M:64@;&%U:VDZ
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@(D)/1D@@17AC=7-E
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O=6YD(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E
M<F]S('!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A:&%M87,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-PIM<V=I9"`B0F%L=&EC("A)4T\M
M.#@U.2TQ,RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%N9VQA
M9&5S:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"87)B861O<R(*
M;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@7"(E<UPB
M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S"FUS9VED(")"87-E;&EN92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QA<G5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C`*;7-G:60@(D)E;&=I=6TB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,PIM<V=I9"`B0F5L:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HS,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*
M;7-G:60@(D)E;FEN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)E
M<FUU9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(D1Z:6WP86YA<R!D
M:65N82(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H
M<#HS-3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D)L;V-K(%PB)7-<
M(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(").
M878@<W1R;V1A;7,@<&%Z:?)O:G5M=2!K;&%U<^YTXFIS("5S(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C@Y"FUS9VED(")";&]C:R!3971T
M:6YG<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI
M;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX"FUS9VED(")";VQD
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(P-0IM<V=I9"`B
M0F]O:VUA<FMS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*(RP@9G5Z>GD*;7-G:60@(D)O
M<F1E<B(*;7-G<W1R(")(;W)D92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE<W,Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C$*(RP@9G5Z>GD*;7-G:60@(D)O<F1E<G,B"FUS
M9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")";W-N:6$@86YD($AE
M<GIE9V]V:6YA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HY-@IM<V=I9"`B0F]T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED
M(")";W1S=V%N82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(R"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@(D)O='1O;2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V970@27-L86YD(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(D)R87II;"(*;7-G
M<W1R(")087-T<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")"<FET:7-H($EN9&EA
M;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I
M9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM
M<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0T"B,L(&9U>GIY
M"FUS9VED(")#35,B"FUS9W-T<B`B0U93(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED
M(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*
M;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,PIM<V=I9"`B0V%C:&4@:6YI
M="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-"!C;VYF:6<O:&]O:W,N
M<&AP+F1I<W0Z.3@W"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-34*
M;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(DMA;&5N9.)R<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#8*;7-G:60@(D-A;&TB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C<*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#86X@;F]T(')E
M<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI
M;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W<FET
M92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N
M<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S
M<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]C>7)U<RYP:'`Z,C,U(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L
M+G!H<#HS,3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&-O
M;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM<V=S='(@(DYE:7ID97;B<R!P
M:65S;.=G=&EE<R!,1$%0('-E<G9E<FEM+B(*"B,Z(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C0Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!O
M<&5N(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"B,L(&9U
M>GIY"FUS9VED(")#86YA9&$B"FUS9W-T<B`B2V%L96YDXG)S(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E<R]A9&UI;B]U
M<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO
M=F4N:6YC.C$R"FUS9VED(")#86YC96PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B
M;&5M(%)E<&]R="(*;7-G<W1R(")!=&-E;'0@<')O8FSG;6%S('!I971E:6MU
M;74B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y
M+G!H<#HU,@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T
M;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(N<&AP.CDQ"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T
M("=T87)G971&:6QE)R!P87)A;65T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$T"B,L('!H<"UF;W)M870*;7-G:60@
M(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+G!H<#HQ,C@@9G)A;65W
M;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L('!H<"UF;W)M
M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L
M+G!H<#HV,#@*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@
M96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N
M=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO
M="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR-`HC+"!F=7IZ>0IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R(")/<&-I:F%S
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z
M,3`T"FUS9VED(")#87)R:65R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY,`IM<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")#87EM86X@27-L86YD<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3DT"FUS9VED(")#96QL(%!H;VYE(@IM<V=S='(@(DUO8FEL86ES
M('3B;')U;FES(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR-0HC+"!F=7IZ>0IM<V=I9"`B0V5L;"!0<F]P97)T
M:65S(@IM<V=S='(@(DUO8FEL86ES('3B;')U;FES(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@
M<&%D9&EN9SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T
M:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$R"FUS9VED(")#96QL('-P86-I;F<Z(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-S0*(RP@9G5Z>GD*
M;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R(")-;V)I;&%I<R!TXFQR=6YI<R(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED(")#96QT:6,@*$E3
M3RTX.#4Y+3$T*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(V"FUS9VED(")#96YT97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E
M<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Y
M"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Y.0IM
M<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Q,0IM<V=I9"`B0V5R=&EF
M:6-A=&4@3W=N97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.38*;7-G:60@(D-E<G1I9FEC871E(%!O;&EC:65S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`HC+"!F=7IZ>0IM<V=I9"`B0VAA
M9"(*;7-G<W1R(")V0V%R9"(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHR-"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*(RP@9G5Z
M>GD*;7-G:60@(D-H86YG92(*;7-G<W1R(")!=&-E;'0@:7IM86GR87,B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*;7-G:60@(D-H86YG
M92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV-@IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R
M97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@
M=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U<B!P
M87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N
M9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(W"B,L(&9U>GIY"FUS9VED(")#:&%R(@IM<V=S='(@
M(G9#87)D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")#:&EL92(*;7-G<W1R
M(")6:7)S<F%K<W1S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;F$B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@(D-H:6YE
M<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H
M0FEG-2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N
M=7`N<&AP.C(V.0IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.`IM<V=I
M9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(Y.`IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y
M(&1A=&5S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES
M="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,N<&AP.C(Y-"!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z.#DS"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`B3F%V
M('-T<F]D86US('!A>FGR;VIU;74@:VQA=7/N=.)J<R`E<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"B,L(&9U>GIY"FUS
M9VED(")#;&5A<B(*;7-G<W1R(")+86QE;F3B<G,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-
M4T]F9FEC92!T86=S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,C@*;7-G:60@(D-L96%R(%%U97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHU"B,L('!H<"UF;W)M870*;7-G
M:60@(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3$*;7-G:60@(D-L96%R('5S97(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,S0*;7-G:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0IM<V=I9"`B0VQE
M87)I;F<@3&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N
M8V4O;6%I;G1E;F%N8V4N:'1M;#HV,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN
M=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W
M(@IM<V=S='(@(D%I>G;G<G0@;&]G=2(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C0T"FUS9VED(")#;&]U9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*;7-G:60@(D-L;W5D<R!%
M87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C0*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,C,*;7-G:60@
M(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L
M;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B
M0V]L;VUB:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ
M."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N
M+G!H<#HS,C0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN
M<&AP.C,R-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-3`P('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G
M:60@(D-O;&]R(%!I8VME<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.#0V"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.30V"FUS9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C0*;7-G:60@
M(D-O;6EC<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*
M(RP@9G5Z>GD*;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`B57KRYVUU;7,B"@HC
M.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#$S"FUS9VED(")#;VUM96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-38V"FUS9VED(")#;VUM;VX@3F%M92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@(E5Z\N=M=6US(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y-PIM<V=I
M9"`B0V]N9&ET:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C0Y"FUS9VED(")#;VYD:71I;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E
M<F5N8V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-#,*;7-G:60@(D-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S
M+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I
M<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHU,0HC+"!F=7IZ>0IM<V=I9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R
M(")087)O;&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;VYG;R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8U"FUS9VED(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P
M=6)L:6,@;V8@=&AE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I
M9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HW.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D
M('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-#4*;7-G
M:60@(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#$T"FUS9VED(")#;VYT
M86-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U
M;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4V(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@(B<E<R<@
M<V%T=7)S(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S"FUS9VED(")#;VYT:6YU92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;V]K($ES;&%N9',B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,R"FUS9VED(")#
M;V]K:64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"B,L(&9U>GIY"FUS9VED(")#;W!Y
M(@IM<V=S='(@(E5Z\N=M=6US(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HT-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O<'D@9F%I
M;&5D.B`E<R(*;7-G<W1R("))96SB9.=T86ES(&QA=6MS.B`E<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@
M(D-O<'D@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-S8*;7-G:60@(D-O
M=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#4S"FUS9VED(")#;W5L
M9"!N;W0@4$=0('-I9VX@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO
M="!3+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@
M;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.CDV
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"B,L(&9U>GIY"FUS
M9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B
M3F5I>F1E=N)S('!I97-LYV=T:65S($Q$05`@<V5R=F5R:6TN(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C0U-PIM<V=I9"`B0V]U;&0@;F]T(&)I;F0@
M=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#0Q"B,L(&9U>GIY"FUS
M9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E<B(*;7-G<W1R
M(").96EZ9&5VXG,@<&EE<VSG9W1I97,@3$1!4"!S97)V97)I;2XB"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,S(R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q,C4*;7-G:60@
M(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R,@IM<V=I9"`B0V]U
M;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,S@Q(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU
M,PIM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@
M92UM86EL(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#;W5L9"!N
M;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y
M,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO
M;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H
M('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713
M=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Q.0IM<V=I9"`B0V]U;&0@;F]T(&]B
M=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C<W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT
M96YA;F-E+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B3F5I
M>F1E=N)S(&%T=N=R="!-86EN=&5N86YC95]487-K(&UO9'5L:2`E<R(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B
M3F5I>F1E=N)S(&%T=N=R="!-86EN=&5N86YC95]487-K(&UO9'5L:2`E<R(*
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3$@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,C,W(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HT-S@*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C4Q-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-38@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C8Y.0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@
M;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3F5I>F1E=N)S
M('!I97-LYV=T:65S($Q$05`@<V5R=F5R:6TN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O3V)J96-T+G!H<#HR,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(')E860@)7,N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S970@=&AE
M('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL
M(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN
M(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D("(*
M(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,T,`HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS-S<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S@S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,X.0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#
M3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I
M8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,C(S"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@
M8V%P86)I;&ET:65S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R979E<G0@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B2&]R9&4@;F%V(&MO<F5K=&D@:V]N9FEG
M=7+G=&$B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C4Y"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C
M;VYF:6=U871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HV,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A
M(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C
M;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U
M;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A
M;B!E:71H97(@=7-E(&]N92!O9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E('1H
M92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B
M96QO=R!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HQ-#,*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!S96%R
M8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R(").96EZ9&5VXG,@<&EE<VSG
M9W1I97,@3$1!4"!S97)V97)I;2XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U
M<F%T:6]N(&9O<B!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-C8*;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO
M>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C$U-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG="!G
M:79E('5S97(@7"(E<UPB('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@
M9F]L9&5R(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,30Q.0IM<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38Y"FUS
M9VED(")#;W5N=')Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR-S,*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M,3`P"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED(")#
M<F5A=&4@82!L:6YK(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]I
M9&5N=&ET>7-E;&5C="YI;F,Z.30*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.3(*;7-G:60@(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(T,`IM<V=I9"`B
M0W)E871O<B!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,C,P"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(D-R;V%T:6$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B82(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,C8*;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C0X"FUS9VED(")#
M=7)R96YT(%-E<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE
M+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4
M:6UE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,S"FUS9VED(")#
M=7)R96YT(%5S97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C4*;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C<U"FUS9VED(")#=7)R96YT
M(&-O;F1I=&EO;CH@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@
M;&]G;VX@=&\@)7,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV.`IM<V=I9"`B0WEP<G5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@R"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B0WER
M:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#0*;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])
M."U5*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#>F5C:"!297!U
M8FQI8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#4Q('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED
M(")$1"(*;7-G<W1R(")$1"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,R.#$*;7-G:60@(B(*(D133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O
M;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA
M;F-E+G!H<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`B26MD:65N87,B"@HC
M.B!A9&UI;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W
M.0IM<V=I9"`B1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C,Y.0IM<V=I9"`B1&%T92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B
M1&%T92!296-E:79E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#`W"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDR(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,C(*(RP@9G5Z>GD*;7-G:60@(D1A>2(*
M;7-G<W1R(")):V1I96YA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@IM<V=I9"`B1&5?;&5T92!#;VQU
M;6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,38*;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$
M96-R96%S92!);F1E;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ.#<@;&EB+W!R969S+G!H<#HQ,3<*(RP@9G5Z>GD*
M;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B4&%R87-TXB!I9&5N=&ETXG1E(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#4*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-S<*
M(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B27IM86YT
M;W0@;F]K;'5SYW1O(';G<G3N8G4B"@HC.B!F<F%M97=O<FLO261E;G1I='DO
M261E;G1I='DN<&AP.CDQ"FUS9VED(")$969A=6QT($ED96YT:71Y(@IM<V=S
M='(@(E!A<F%S=.(@:61E;G1I=.)T92(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R
M(")087)A<W3B(&ED96YT:73B=&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S,*;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z-S$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C8*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HT,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHS-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C<P"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z.3,@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,38*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#(*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C<S('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHY.`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S(*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DY(&%D;6EN+V=R;W5P<RYP
M:'`Z,C(W"FUS9VED(")$96QE=&4@1W)O=7`B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0Y"FUS9VED(")$96QE=&4@3&]G
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M-S<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#$*;7-G:60@(D1E
M;&5T92!097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U
M<F=E(&UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3<*;7-G:60@(D1E;&5T92!C
M96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!C;VQU;6XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E
M;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<
M(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C<*;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V1E;&5T96ED96YT:71Y+FEN8SHQ-0HC+"!F=7IZ>0IM<V=I9"`B
M1&5L971E('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@(E!A<F%S=.(@:61E
M;G1I=.)T92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(&-O
M;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!T:&4@8W5R
M<F5N="!R;W<B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!S971U<"!U<&=R
M861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38S"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*
M;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM
M<V=I9"`B1&5N;6%R:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB
M"FUS9W-T<B`B07!R86MS=&EE="!P<F]B;.=M=2(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.CDS."!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,P"B,L(&9U>GIY"FUS9VED(")$97-C<FEP=&EO
M;B(*;7-G<W1R(")0:6QN<R!A<')A:W-T<SHB"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$Y-0IM<V=I9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D
M92=S(&QO9V9I;&4I.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C$Y.0IM<V=I9"`B1&5T86EL<R!H879E(&)E96X@;&]G9V5D
M(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B4^YKXFMA(&EN9F]R
M;>)C:6IA(&ER(&YO<_MT[G1A(&%D;6EN:7-T<F%T;W)A;2XB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C$Y"FUS9VED(")$979E;&]P;65N="(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-PIM<V=I9"`B
M1&5W(%!O:6YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,CDT"FUS9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C<*;7-G:60@
M(D1E=R!P;VEN=#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L969T
M('1O(')I9VAT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T
M;R!L969T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y
M"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(V-@IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<*;7-G:60@
M(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R(")%:W+B;F$@:65S=&%T[FIU;6DB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.38*(RP@9G5Z>GD*
M;7-G:60@(D1I<W!L87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`B16MR
MXFYA(&EE<W1A=.YJ=6UI(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX-0IM
M<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$W"B,L(&9U>GIY"FUS9VED(")$
M:7-P;&%Y(&9O<FUA="(*;7-G<W1R(")%:W+B;F$@:65S=&%T[FIU;6DB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,3DP"FUS9VED(")$:7-P
M;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM
M<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HT,C(*;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(U"FUS9VED(")$
M;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R
M(").878@=&EE\&%S('!I965J87,@;6%I;G1E;F%N8V4N<&AP(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN
M('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@
M(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0T"FUS9VED
M(")$;W=N;&]A9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HX-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO
M860@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V
M,@IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@
M4$A0('-C<FEP="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C$P-PIM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*
M(RP@9G5Z>GD*;7-G:60@(D4M36%I;"(*;7-G<W1R(")087-T<R(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDR"FUS9VED
M(")%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W
M:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B
M:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*
M;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-0HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,34@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C<R"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,C4*;7-G:60@
M(D5D:70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)
M+G!H<#HU,"!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%
M9&ET($)L;V-K(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DX
M(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"FUS9VED(")%9&ET($=R;W5P(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S8@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#`*;7-G:60@(D5D:70@4&5R
M;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP
M:'`Z,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS
M(&9O<CHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N
M<R!F;W(@7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S
M:6]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,U"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HS,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B16ET:&5R(&5N
M86)L92!I="!T:&5N.B`E<RP@;W(@=7-E('1H92!B87-I8R!(5$U,('9E<G-I
M;VXZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(D5L(%-A
M;'9A9&]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM<V=I9"`B16QE;65N="XN+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R-"!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.#8Y"FUS9VED(")%;6%I;"(*;7-G<W1R(")%+7!A<W1S
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C4@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"B,L(&9U>GIY"FUS9VED(")%;6%I
M;"!!9&1R97-S(@IM<V=S='(@(DK[<W4@92UP87-T82!A9')E<V4Z(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DV,PIM<V=I9"`B16UA:6P@861D
M<F5S<V5S(&UU<W0@;6%T8V@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Y.#D*(RP@9G5Z>GD*;7-G:60@(D5M86EL('=I=&@@
M8V]N9FER;6%T:6]N(@IM<V=S='(@(D-I=&$@:6YF;W)MXF-I:F$B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I
M9"`B16UA:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y.`HC+"!F=7IZ>0IM
M<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(D]P8VEJ87,B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*(RP@9G5Z
M>GD*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(E1U:_!S(')E>G5L
M=.)T<RXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C0S
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT.#0*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8V,B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z,34P"FUS9VED(")%;7!T>2!R97-U;'0N(@IM<V=S='(@(E1U:_!S
M(')E>G5L=.)T<RXB"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP
M:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T,PIM<V=I9"`B16YA8FQE(&EN
M<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X
M=#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q.`IM
M<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y."!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.#$Q"FUS9VED(")%;F0@>65A<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C(Q"FUS9VED("(B"B)%;G1E<B!A('-E8W5R
M:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N
M965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@
M=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(R
M"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Y,0IM
M<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A
M='5S+G!H<#HR-PHC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#4@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4U"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S8@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HX,@IM<V=I
M9"`B17)R;W(B"FUS9W-T<B`B2^_[9&$B"@HC.B!F<F%M97=O<FLO5&5M<&QA
M=&4O5&5M<&QA=&4N<&AP.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O
M<B!C<F5A=&EN9R!B;&]C:SH@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R
M;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@S"B,L('!H<"UF;W)M870*;7-G
M:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE<W-A
M9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%=7)O
M<&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S.0IM
M<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R(")+871R87,@,34@;6EN
M^W1E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#D*(RP@9G5Z>GD*
M;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R(")+871R87,@-2!M:6[[
M=&5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S@W"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S
M='(@(DMA=')A<R`S,"!S96MU;F1E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS,S@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,`IM<V=I9"`B179E
M<GD@-2!M:6YU=&5S(@IM<V=S='(@(DMA=')A<R`U(&UI;OMT97,B"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED
M(")%=F5R>2!,;V=I;B(*;7-G<W1R(")+871RXB!P:65S;.=G\&%NXG,@<F5I
M>N<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0P"FUS9VED(")%=F5R
M>2!H86QF(&AO=7(B"FUS9W-T<B`B2V%T<G4@<'5S<W1U;F1U(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,S-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S@X"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`B2V%T<G4@;6EN^W1I
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C0*;7-G:60@(D5X
M86UP;&4@=F%L=65S.B(*;7-G<W1R(")087)A=6=VYW)T[F)A<R(*"B,Z(&%D
M;6EN+W!H<'-H96QL+G!H<#HX,2!A9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M
M:6XO<W%L<VAE;&PN<&AP.C$R-PIM<V=I9"`B17AE8W5T92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT-S4*;7-G
M:60@(D5X<&%N9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I
M9&5B87(N:6YC.C,R"FUS9VED(")%>'!A;F0@4VED96)A<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED
M(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]3
M44PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP96-T960@8F%R92!W;W)D
M(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER871I;VX@
M1&%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8W-@IM<V=I9"`B17AP;VYE;G0B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM
M<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$W-PIM<V=I9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<W%L+G!H<#HR,38*;7-G
M:60@(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+B(*;7-G<W1R(").
M96EZ9&5VXG,@<V'R96UT(&EE<W1A=.YJ=6UU<RXB"@HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S
M97)V97(N(@IM<V=S='(@(DYE:7ID97;B<R!P:65S;.=G=&EE<R!,1$%0('-E
M<G9E<FEM+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HY.`HC
M+"!F=7IZ>0IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E
M<BXB"FUS9W-T<B`B3F5I>F1E=N)S('!I97-LYV=T:65S($Q$05`@<V5R=F5R
M:6TN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.#8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-CDQ"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!T;R!<
M(B5S7"(N(@IM<V=S='(@(DYE:7ID97;B<R!P:65S;.=G=&EE<R!,1$%0('-E
M<G9E<FEM+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#<*
M;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3<@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,C0*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T
M<B`B3F5I>F1E=N)S('!I97-LYV=T:65S($Q$05`@<V5R=F5R:6TN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C$*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`B
M3F5I>F1E=N)S('-A\F5M="!I97-T873N:G5M=7,N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H
M36%L=FEN87,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9A<F]E
M($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP
M.C(S.`HC+"!F=7IZ>0IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@(DEE
M;.)D97,@:VS[9&$Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@(D9A:W-S(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T.0HC+"!F=7IZ>0IM<V=I9"`B
M1F%X97,B"FUS9W-T<B`B1F%K<W,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`R"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C`*;7-G:60@(D9E96QS($QI
M:V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(S,0IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Y"FUS9VED(")&97<@
M4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30T"FUS9VED
M(")&:65L9"!M871R:7@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S,S-`IM<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S.`IM<V=I9"`B1FEG
M;&5T(&9O;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEJ:2(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*
M(RP@9G5Z>GD*;7-G:60@(D9I;&4B"FUS9W-T<B`B5FER<W)A:W-T<R(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G
M:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL
M92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0P-PIM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,`HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@U"B,L(&9U>GIY"FUS
M9VED(")&:6QE($YA;64B"FUS9W-T<B`B5N)R9',B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.3DU"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#@V"FUS9VED
M(")&:6QE('5P;&]A9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E
M<B]"<F]W<V5R+G!H<#HX-3D*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P
M<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z.#D*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM
M<V=I9"`B1FEN;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,38V"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@
M(D9I<G-T(%%U87)T97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U-@IM<V=I9"`B1FEX(')A=&EO(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR,S$*;7-G:60@(D9L:7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B
M1FQO870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,3`W"B,L('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D
M;V5S(&YO="!E>&ES="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(R"FUS9VED(")&;VYT($-O;&]R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B
M1F]O9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$R,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R
M<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S,T"FUS9VED(")&;W)E8V%S="`H5$%&*2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-SD*
M;7-G:60@(B(*(D9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N
M960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB
M;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C
M:RDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ
M,#(*;7-G:60@(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8R"FUS9VED(")&;W)M<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*;7-G:60@
M(D9O<G1U;F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.CDY"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,X"B,L(&9U>GIY"FUS9VED(")&;W)T=6YE<R(*
M;7-G<W1R(")0:65Z[FUE<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#4S"FUS9VED(")&;W)U;7,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P.0IM<V=I9"`B1F]R=V%R
M9',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PHC+"!F
M=7IZ>0IM<V=I9"`B1G)A;65S(@IM<V=S='(@(E;B<F1S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,PIM<V=I9"`B1G)A;F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E+"!-971R;W!O;&ET86XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3;W5T
M:&5R;B!497)R:71O<FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#@@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,`HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-#`V"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*(RP@9G5Z
M>GD*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`B4&EL;G,@87!R
M86MS=',Z(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M
M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHV,`HC+"!F=7IZ>0IM<V=I9"`B1G5L;"!.86UE(@IM<V=S
M='(@(DK[<W4@=N)R9',Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1V%B;VXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA
M9V4@9G)O;2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.38@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M
M870*;7-G:60@(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL.C@*;7-G
M:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G
M:60@(D=E;W)G:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDP
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R
M;6%N>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':&%N82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDT(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':6)R86QT87(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S4*;7-G
M:60@(D=I=F5N($YA;64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V%P<"YI;F,Z,3(*;7-G:60@(D=O(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT,`IM<V=I9"`B1V]E9&5L(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3(X"FUS
M9VED(")';V]G;&4@36%P<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S<*
M;7-G:60@(D=R87ES8V%L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.CDS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I
M9"`B1W)E96-E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@U"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.CDT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-0IM<V=I9"`B1W)E96YL86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HY-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S0*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HQ-SD*;7-G:60@(D=R;W5P($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"YP:'`Z-3D@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$V.0IM<V=I9"`B1W)O=7`@;F%M97,@
M;75S="!B92!N;VXM96UP='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C,P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")'
M<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H
M870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q."!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA
M8FQE('1O(&1E;&5T92!G<F]U<"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S,X(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HS-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?
M;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W
M-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HY-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@
M(D=U861E;&]U<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U
M86TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U871E;6%L82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDR"FUS
M9VED(")'=65R;G-E>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X
M"FUS9VED(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<P"B,L(&9U>GIY"FUS9VED(")'=65S
M=&)O;VLB"FUS9W-T<B`B2V]N=&%K=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'
M=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=6EN96$M
M0FES<V%U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDV,`IM
M<V=I9"`B2%1-3"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(5$U,07)E82!C
M;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O
M=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@
M<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U
M<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED
M(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@P"FUS9VED(")(86ET:2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA<V@M06QG
M;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDQ.2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.3,R"FUS9VED(")(96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0IM<V=I9"`B2&5A
M9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES
M;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PIM<V=I9"`B2&5A
M=GD@5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X-@IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S0*;7-G:60@(DAE:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3<Y(&9R86UE=V]R:R](;W)D92](;W)D
M92](96QP+G!H<#HQ.#8*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@
M=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C,*;7-G:60@(DAE;'`B"FUS9W-T
M<B`B4&%L[F1Z[F)A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W,0HC+"!F=7IZ
M>0IM<V=I9"`B2&5L<&5R(@IM<V=S='(@(E!A;.YD>NYB82(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHQ,`IM<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN
M:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.0IM<V=I9"`B2&EG:"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S
M+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C4*(RP@9G5Z>GD*;7-G:60@(DAO
M7VUE(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L
M>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-3,U"B,L(&9U>GIY"FUS9VED(")(
M;VUE(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$R,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,34U"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T
M<B`B3>)J87,@861R97-E(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8T
M"FUS9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE
M(%!H;VYE(@IM<V=S='(@(DWB:F%S('1E;&5F;VYS(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y
M"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G
M:60@(DAO;F<@2V]N9R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-C4*;7-G:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N
M=&5R960@:6X@;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT,S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O
M9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C4P"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<
M(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG
M:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-3`S"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E
M(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(T-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M-#<T"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q.3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S
M>6YC:')O;FES92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3,S-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS
M-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@
M<VAA<F4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@4G5L
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q"FUS
M9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD
M('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC
M;VQU;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO
M=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,S`*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3D*;7-G:60@(DAU
M;6ED:71Y.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0Q"FUS9VED(")(=6UO<FES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P
M"FUS9VED(")(=6YG87)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER=7,N<&AP.C$W,B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q
M;"YP:'`Z,C,U"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C
M<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER=7,N<&AP.C(Q-"!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G-Q;"YP:'`Z,CDU"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O
M>"!D96QE=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W.2!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G-Q;"YP:'`Z,C0R"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I
M;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,38*(RP@9G5Z>GD*;7-G:60@
M(DE0($%D9')E<W,B"FUS9W-T<B`B061R97-E(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B25`@061D<F5S<R!N;W0@
M879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@
M86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@(DE0
M(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED
M("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R
M"FUS9VED("))8V5L86YD(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-S8*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@
M(DEC;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S<W"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B261E;G1I='DG
M<R!N86UE.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HU.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@
M;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N
M97<@=VEN9&]W+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#4U"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U
M<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K
M("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ-S,*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U
M="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG
M="!B92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R
M-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C@*;7-G:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*
M;7-G:60@(DEM86=E(%523#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,R"FUS9VED
M("));6%G92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS
M9VED("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C$*;7-G:60@(DEM86=E('5P;&]A9"(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B
M26UA9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N
M:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-PHC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.C4T('1E;7!L871E<R]D871A+V-S=FEN9F\N
M:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E
M<"`E9"(*;7-G<W1R("))96SB9.=T86ES(&QA=6MS.B`E<R(*"B,Z('1E;7!L
M871E<R]D871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@
M(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R("))96SB9.=T86ES(&QA=6MS
M.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@
M(DEM<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`B265LXF3G=&EE(&QA=6MI.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,U"FUS
M9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,R"B,L(&9U>GIY"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R
M('!A<W-W;W)D+B(*;7-G<W1R("),^V1Z=2!N;W+B9&EE="!S879U(&QI971O
M=.)J82!VXG)D=2!U;B!P87)O;&DB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L
M=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*
M(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(Q"FUS9VED("));F-R96%S92!);F1E;G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@Q"FUS9VED("));F1I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U-"!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#`*;7-G:60@(DEN9&]N97-I82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS
M9VED("));F9O(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR-3<*(RP@9G5Z>GD*;7-G:60@(DEN9F]R;6%T:6]N(@IM<V=S='(@
M(DK[<W4@:6YF;W)MXF-I:F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S,P"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA
M8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@(DEN<V5R="!#7V]L=6UN
M($%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B26YS97)T($EM
M86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U
M"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS
M9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V
M"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT
M(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C
M;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@
M;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W(')O
M=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM
M<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO
M9&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A9W)A
M<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@
M=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(S.0IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@
M>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3D*;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T
M"FUS9VED("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*
M;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED("))
M;G-E<G0@;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("));G-E
M<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B
M26YS97)T('!A<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I
M9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED("))
M;G-E<G0@<F]W(&)E9F]R92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C,P"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E
M<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@
M(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T
M+TUO9&EF>2!,:6YK(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U9F9I8VEE
M;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`W-0IM<V=I
M9"`B26YT96=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,3,S"FUS9VED("));G1E9V5R(&QI<W0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW
M"FUS9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H
M<#HQ-S`*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z
M,C`Q"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(Q
M,`IM<V=I9"`B26YV86QI9"!:25`@9&%T82(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@240N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P.#<@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U.`HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C,R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R.3D*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS-PIM
M<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P
M"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C@Q
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P,`HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR,C`*;7-G
M:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-PIM<V=I9"`B26YV86QI9"!L:6-E
M;G-E(&ME>2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$W,0IM<V=I9"`B26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#,*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y-@IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A
M<F%M971E<G,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD
M+G!H<#HR-PIM<V=I9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W,PIM
M<V=I9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<U"FUS9VED("));G9A;&ED('!R
M;V1U8W0@8V]D92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED("));G9A;&ED('!R
M;W1O8V]L+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP
M:65N=#H@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,3`W-B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-C(*
M;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM
M<V=I9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q
M"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U-PIM<V=I9"`B26YV96YT;W)Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HV-SD*;7-G:60@(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@R"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC
M(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES
M;&4@;V8@36%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(T"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DES<F%E;"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R-0IM
M<V=I9"`B27-S=65R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,@HC+"!F=7IZ>0IM<V=I9"`B271A;'DB"FUS9W-T
M<B`B26MD:65N87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S
M"FUS9VED(")*87!A;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X-PIM<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`IM<V=I9"`B
M(@HB2F%V87-C<FEP="!H87,@8F5E;B!D:7-A8FQE9"!O;B!Y;W5R(&)R;W=S
M97(@86YD('1H:7,@<&%G92!M87D@;F]T(&)E("(*(F1I<W!L87EI;F<@8V]R
M<F5C=&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R,@IM<V=I9"`B2F5R<V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,PIM<V=I9"`B2F]R9&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#<*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P
M"FUS9VED(")*=6YE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,30*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM
M<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*
M;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(V-`IM<V=I9"`B2V5E<"!O<FEG
M:6YA;#\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@U
M"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM
M<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@0W)E871I;VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N
M9W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@*(RP@9G5Z>GD*;7-G:60@
M(DME>2!5<V%G92(*;7-G<W1R(")::?)A(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-S0P"FUS9VED(")+97D@86QR96%D>2!E>&ES=',@
M;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#0*;7-G:60@(DMI<FEB871I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P
M=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E
M82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#@*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED("),85]Y;W5T(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.#,*;7-G:60@(DQA
M;F=U86=E(@IM<V=S='(@(E9A;&]D82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B
M3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW-@IM<V=I9"`B
M3&%S="!087-S=V]R9"!#:&%N9V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S
M="!1=6%R=&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,34Q"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("),
M87-T(&QO9VEN.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HW,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@
M)7,@9G)O;2`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HW,38*;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW.0HC+"!F=7IZ>0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(DEZ:65T(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM
M<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#<*;7-G:60@(DQE8F%N;VXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"FUS
M9VED("),969T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,Q,3D*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,34*(RP@9G5Z>GD*;7-G:60@(DQE
M9G0@=F%L=65S(@IM<V=S='(@(E!A<F%U9W;G<G3N8F%S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@X"FUS9VED("),97-O=&AO(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B3&5V96PB"FUS
M9W-T<B`B3F5K860B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI8F5R:6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:6)Y86X@07)A8B!*86UA
M:&ER:7EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,30P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EE8VAT
M96YS=&5I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR-0IM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M-@HC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R(")0:65S;.=G
M=&EE<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(W"FUS9VED("),:6=H="!286EN($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),
M:6=H="!286EN($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI9VAT(%)A:6X@4VAO
M=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,P"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS,0IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B3&EG
M:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0U"FUS9VED("),:6UE<FEC:R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#$T"B,L(&9U>GIY"FUS9VED("),:6YK
M(@IM<V=S='(@(E!I97-LYV=T:65S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O
M:6YT<R!T;SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@W-0IM<V=I9"`B3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@
M8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@S
M"FUS9VED("),:6YK<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B
M3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*;7-G:60@(DQI<W0@1&%T86)A<V5S
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4P"FUS
M9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(E!A<N)D[G0@<&%L[F1Z
M[F)A<R!T96UA='5S(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,@IM<V=I
M9"`B3&ES="!486)L97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12](96%D97)S+G!H<#HU.30*;7-G:60@(DQI<W0M07)C:&EV92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4X
M.0HC+"!F=7IZ>0IM<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(E!A<N)D[G0@
M<&%L[F1Z[F)A<R!T96UA='5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](
M96%D97)S+G!H<#HU.38*;7-G:60@(DQI<W0M260B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3(*;7-G:60@(DQI
M<W0M3W=N97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](
M96%D97)S+G!H<#HU.3,*;7-G:60@(DQI<W0M4&]S="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,0IM<V=I9"`B
M3&ES="U3=6)S8W)I8F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12](96%D97)S+G!H<#HU.3`*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4P"B,L('!H<"UF
M;W)M870*;7-G:60@(DQI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B3&ES=&EN9R!U<V5R<R!F86EL960Z("5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B
M3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),:71E<F%T=7)E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z
M.#,*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(Q,0IM<V=I9"`B3&]C86P@=&EM93H@(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,PIM<V=I9"`B
M3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3<Q(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HV-`HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HV-0IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B(@H*(SH@
M;&]G:6XN<&AP.C$W,B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3DQ
M('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C,*(SH@=&5M<&QA=&5S+VQO
M9VEN+VUO8FEL92YI;F,Z,34@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY
M,`IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(E!I97-LYV=T:65S(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U"FUS9VED("),;V<@;V8@<')E
M=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S:61E8F%R+G!H<#HQ.#4*;7-G:60@(DQO9R!O=70B"FUS9W-T<B`B
M27II970B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-3D*(RP@9G5Z>GD*
M;7-G:60@(DQO9VEN(@IM<V=S='(@(E!I97-LYV=T:65S(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$P-PHC+"!F=7IZ>0IM<V=I9"`B3&]G:6X@5&%S
M:W,B"FUS9W-T<B`B57ID979U;6DB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HY.38*(RP@9G5Z>GD*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E
M('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R
M96-T;'DN(@IM<V=S='(@(E!I97-LYV=T:65S(&YE:7ID97;B<VDN3F5P87)E
M:7IS(&QI971O=.)J82!VXG)D<R!V86D@<&%R;VQE+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.CDY,@IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8U"B,L(&9U
M>GIY"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`B27II970B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@(DQO=F4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G
M:60@(DQO=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E
M:R!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA
M=&EN(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@
M<F]M86X@;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@
M(DQU>&5M8F]U<F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P,`HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#,X('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P
M"FUS9VED(")-32(*;7-G<W1R(")-32(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR.#$*;7-G:60@(DU/5$0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.
M148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,@IM<V=I9"`B36%C86\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ
M"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L
M:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-861A9V%S
M8V%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.0HC
M+"!F=7IZ>0IM<V=I9"`B36%G:6,B"FUS9W-T<B`B4&%S=',B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#$*;7-G:60@(DUA:6PB"FUS9W-T<B`B
M4&%S=',B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3(R"FUS9VED
M(")-86EL($%D;6EN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,0IM<V=I9"`B36%K92!L
M:6Y?:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G
M:60@(DUA;&%W:2(*;7-G<W1R(")087-T<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I
M9"`B36%L87ES:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-
M86QD:79E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*(RP@9G5Z>GD*;7-G
M:60@(DUA;&DB"FUS9W-T<B`B4&%S=',B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z
M>GD*;7-G:60@(DUA;'1A(@IM<V=S='(@(E!A<W1S(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDQ"FUS9VED("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@
M8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@
M8V]L;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3$U,PIM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#@T"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,38X"FUS9VED
M(")-87!1=65S="!M87`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S=&]R960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8W"FUS9VED(")-87)C:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q"B,L(&9U>GIY"FUS
M9VED(")-87)G:6XB"FUS9W-T<B`B0G+N9&ENXFIU;7,B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W
M:71H(%-E96XO56YS965N(&9L86=S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K('=I
M=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA<G-H86QL($ES;&%N9',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-87)T:6YI<75E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS
M9VED(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`B4V%S:V%N;_!I92!L875K
M:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%U<FET86YI82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.30*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X
M"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@(DUA>"!T96UP
M(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(Y.`IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z.#8*;7-G:60@(DUA>&EM=6T@3G5M
M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.#DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M,3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S.0IM<V=I9"`B36%X
M:6UU;2!L96YG=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P-0HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$W"FUS9VED(")-87EO='1E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@HC
M+"!F=7IZ>0IM<V=I9"`B365M8F5R<R(*;7-G<W1R(")496MS=&DB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<X"FUS9VED(")-96YU(&UO9&4Z(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C4U"FUS9VED(")-97-S86=E(@IM<V=S='(@(EII\F$B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S
M<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C
M97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q,`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!E>'!I<F5D+B(*;7-G
M<W1R(")::?)A(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,#(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C(W"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V,`HC+"!F=7IZ>0IM<V=I9"`B365S
M<V%G92!T>7!E(@IM<V=S='(@(EII\F$B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,*;7-G:60@(DUE=&%R(%=E871H97(B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO8VL@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M,3(*(RP@9G5Z>GD*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B
M;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T
M<F%T;W(N(@IM<V=S='(@(E/N:^)K82!I;F9O<FWB8VEJ82!I<B!N;W/[=.YT
M82!A9&UI;FES=')A=&]R86TN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$V-0IM<V=I9"`B365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C8W(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*
M;7-G:60@(DUE=&AO9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4E!#+U)0
M0R]X;6QR<&,N<&AP.C@Q(&9R86UE=V]R:R]24$,O4E!#+W-O87`N<&AP.C$Q
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D
M969I;F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+W)E<W0N
M<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE
M9"X@0V%L;&5D(&UE=&AO9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C<T(&QI8B]";&]C:R]M971A<BYP:'`Z-S4*
M;7-G:60@(DUE=')I8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@
M(DUE>&EC;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N
M97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S8*(RP@
M9G5Z>GD*;7-G:60@(DUI9&1L92(*;7-G<W1R(")087-T<R(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(")-:6UE
M(%1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3`*
M;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P,@IM<V=I9"`B36EN('1E;7`@;&%S
M="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HT,SD*;7-G:60@(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA
M<R!N;W0@>65T(&5X<&ER960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-`HC+"!F=7IZ>0IM<V=I9"`B
M36ER<F]R(@IM<V=S='(@(DOO^V1A(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T
M,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(U,`IM
M<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U"FUS9VED("(B
M"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E
M(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO
M;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`T"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@240N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N
M96ET86QY7W-M='`N<&AP.C4X"FUS9VED(")-:7-S:6YG(')E<75I<F5D(%!%
M05(@<&%C:V%G92!-86EL+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G:60@(DUI<W-I
M;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C<T"FUS9VED(")-;V)I
M;&4@36%I;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#@*;7-G:60@(DUO9&EF:65D
M($1A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4S"FUS9VED(")-;V1I9GD@55),(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C<S"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM
M<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR
M"FUS9VED(")-;VYG;VQI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-3DT"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP
M.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(DMA=')U(&WG;F5S:2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-`IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G
M:60@(DUO;VX@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C$W,B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR
M-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!F:65L9',@9F]U;F0@:6X@
M;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T
M;'D@0VQE87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S0*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S4*;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,#D*;7-G:60@(DUO=F4@1&]W
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HU,3,*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,3<*;7-G:60@(DUO=F4@
M4FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z-3`U"FUS9VED(")-;W9E(%5P(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C0*;7-G:60@
M(DUO=F4@9&]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-3(S"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HU,C0*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDU"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#0*;7-G:60@(DUU;'1I
M+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U-0IM<V=I9"`B375L
M=&EM87`@54L@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R-#(*;7-G:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`P"FUS9VED(")-
M>2!!8V-O=6YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HR.`HC+"!F=7IZ>0IM<V=I9"`B37D@06-C;W5N="!);F9O<FUA=&EO;B(*
M;7-G<W1R(")*^W-U(&EN9F]R;>)C:6IA(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+VEN9&5X+G!H<#HU-`IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HQ,S8*;7-G:60@(DUY(%!O<G1A
M;"!,87EO=70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-38*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")->6%N
M;6%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN
M=&5N86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R964B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@
M(DYA;64B"FUS9W-T<B`B5N)R9',B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$V.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYA
M;6EB:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").875R=2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE<&%L(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3<*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3@Q"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T
M<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#4*;7-G:60@(DYE='-C87!E
M($-!('!O;&EC>2!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.#0*;7-G:60@(DYE='-C87!E(%)E;F5W86P@
M55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3@R"FUS9VED(").971S8V%P92!2979O8V%T:6]N(%523"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X
M-@IM<V=I9"`B3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@W"FUS9VED
M(").971S8V%P92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@P"FUS9VED(").
M971S8V%P92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR-3$*;7-G:60@(DYE='=O<FLB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(U(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S4*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,X-@IM<V=I9"`B3F5V97(B"FUS9W-T<B`B3F5K860B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$V,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.34*;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3`*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,C8*;7-G
M:60@(DYE=R!#871E9V]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X
M=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.#$*(SH@9G)A;65W;W)K+U1E
M>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@W"B,Z(&9R86UE=V]R:R]4
M97AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HY-PHC.B!F<F%M97=O<FLO
M5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z,3`Q"B,L('!H<"UF;W)M
M870*;7-G:60@(DYE=R!-97-S86=E('1O("5S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB
M+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-0IM<V=I
M9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDX"FUS9VED(").97<@6F5A;&%N9"(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(DYE
M=R!P87-S=V]R9"(*;7-G<W1R(")087)O;&4B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W-Q;"YP:'`Z,C(W"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!P
M87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R"FUS9VED(").97<@<&%S<W=O
M<F1S(&1O;B=T(&UA=&-H+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@=VEN9&]W
M("A?8FQA;FLI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C0P(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C@Y"B,L(&9U>GIY"FUS9VED(").97=S(@IM<V=S='(@
M(E!I97KN;65S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-0IM
M<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T
M82]T<W9I;F9O+FEN8SHQ-2!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT
M,0HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.2!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHR-0IM<V=I9"`B3F5X="(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*;7-G:60@(DYE>'0@-"!0:&%S97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS
M-S(@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S8*(RP@9G5Z>GD*
M;7-G:60@(DYE>'0@;W!T:6]N<R(*;7-G<W1R(")!=&=R:65Z=&EE<R!P:64@
M;W!C:6KB;2(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z,3`S"FUS
M9VED(").97AT/B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI
M8V%R86=U82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*(RP@9G5Z>GD*;7-G
M:60@(DYI9V5R(@IM<V=S='(@(DYE:V%D(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED
M(").:6=E<FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS.#`*;7-G:60@(DYI9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-PIM<V=I9"`B3FEU92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED(").;R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G
M:60@(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D
M:69F97)E;F-E<R!F;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z,3`U"FUS9VED(").;R!A=F%I;&%B
M;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW.2!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-#4*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C8W"FUS9VED(").;R!B;&]C:R!E>&ES
M=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C4P"B,L(&9U>GIY"FUS9VED
M(").;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R(")344P@875T96YT:69I:^)C:6IA:2!N878@;F]R
MXF3N=&$@:V]N9FEG=7+B8VEJ87,@:6YF;W)MXF-I:F$N(@H*(SH@861M:6XO
M<V5T=7`O9&EF9BYP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(DYO(&-H86YG92XB
M"FUS9W-T<B`B071C96QT(&EZ;6%I\F%S(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A
M9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,38W(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z-3`R"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<W,PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R(")344P@:V%T96=O
M<FEJXFT@;F%V(&YO<N)D[G1A(&MO;F9I9W5RXF-I:F%S(&EN9F]R;>)C:6IA
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(T"B,L(&9U>GIY
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B3$1!4"!I97-T873N:G5M;W,@;F%V
M(&YO<N)D[G1A(&MO;F9I9W5RXF-I:F%S(&EN9F]R;>)C:6IA+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C8Y"B,L(&9U>GIY"FUS9VED(").
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,
M(%9&4RXB"FUS9W-T<B`B4U%,(&MA=&5G;W)I:N)M(&YA=B!N;W+B9.YT82!K
M;VYF:6=U<N)C:6IA<R!I;F9O<FWB8VEJ82XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z-S$W"B,L(&9U>GIY"FUS9VED(").;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@
M5D93+B(*;7-G<W1R(")344P@:V%T96=O<FEJXFT@;F%V(&YO<N)D[G1A(&MO
M;F9I9W5RXF-I:F%S(&EN9F]R;>)C:6IA+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E
M9&ET(&QE9G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED(").;R!D97-T:6YA=&EO
M;B!S=7!P;&EE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O
M0G)O=W-E<BYP:'`Z.#<W"FUS9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S
M='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HW,0IM<V=I9"`B3F\@
M:6-O;G,@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ,C@@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3(S"FUS9VED(").;R!L;V-A=&EO;B!I<R!S
M970N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-CD*;7-G:60@(DYO(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S,PIM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,S8*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PIM
M<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS9VED(").;R!O9F9E;G-I=F4@9F]R
M='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P
M+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C<W(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&]G:6XN<&AP.C@T"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<&%M+G!H<#HW-0HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M(")344P@875T96YT:69I:^)C:6IA:2!N878@;F]RXF3N=&$@:V]N9FEG=7+B
M8VEJ87,@:6YF;W)MXF-I:F$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P
M87-S=V0N<&AP.C$S-0HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B4U%,
M(&%U=&5N=&EF:6OB8VEJ86D@;F%V(&YO<N)D[G1A(&MO;F9I9W5RXF-I:F%S
M(&EN9F]R;>)C:6IA+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H
M<#HX-`HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M(%--0B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B4U%,(&%U=&5N=&EF:6OB
M8VEJ86D@;F%V(&YO<N)D[G1A(&MO;F9I9W5RXF-I:F%S(&EN9F]R;>)C:6IA
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X-@IM
M<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED
M960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R
M:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S
M:6=N=7!S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M-S4P"B,L('!H<"UF;W)M870*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT,PHC+"!F=7IZ>0IM<V=I9"`B3F\@<G5L97,B"FUS9W-T<B`B
M4&EE>NYM97,B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#D*
M;7-G:60@(DYO('-E<&%R871O<B!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#0*(RP@9G5Z>GD*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(E!I97KN;65S
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#,*;7-G:60@(DYO
M('-U8V@@9FEL92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,3,X"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V
M86EL86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"B,L(&9U>GIY"FUS9VED
M(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`B
M3/MD>G4@;F]RXF1I970@<V%V=2!L:65T;W3B:F$@=N)R9'4@=6X@<&%R;VQI
M(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@
M(DYO('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-S$*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX,0HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3DR"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#`Y"FUS9VED(").
M;R!V86QU97,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$R,`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF
M:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E
M<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0R-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0U"B,Z('1E;7!L871E<R]P<F5F<R]I
M9&5N=&ET>7-E;&5C="YI;F,Z.3,*(RP@9G5Z>GD*;7-G:60@(DYO;F4B"FUS
M9W-T<B`B5.)L<G5N:7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CDP"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(").
M;W)D:6,@*$E33RTX.#4Y+3$P*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*
M;7-G:60@(DYO<F9O;&L@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO
M<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS
M9VED(").;W)T:&5R;B!-87)I86YA($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDW"FUS9VED(").;W)W87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!!9G1E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8S.0IM<V=I9"`B3F]T($)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,#@*;7-G:60@(DYO="!A(&1I<F5C
M=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(N<&AP.C8S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C@S"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN
M<&AP.CDT"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2YP:'`Z-#@*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HU.0IM<V=I
M9"`B3F]T(&EM<&QE;65N=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8X"B,L(&9U>GIY"FUS9VED
M(").;W0@<V5T(@IM<V=S='(@(E!I97KN;65S(@H*(SH@9G)A;65W;W)K+U-E
M<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#,*(SH@9G)A;65W
M;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-3@*(SH@
M9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ
M-S,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R
M+G!H<#HQ.#<*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(
M86YD;&5R+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,N<&AP.C$Y,`HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,C`U(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(T."!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,C8U"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.#$@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C(Y-PHC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,S$R(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,CD*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C,V,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-#(R
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU,#$@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C4W,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3@W(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HV-C4*;7-G:60@(DYO="!S=7!P;W)T960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HR-#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,#4*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$W.`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B
M4&EE>NYM97,B"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*
M;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#D*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0HC
M+"!F=7IZ>0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B3F5K860B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#0V"B,L(&9U>GIY"FUS9VED(").
M=6UB97(B"FUS9W-T<B`B5N)R9',B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#(U"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8Y(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$T,C,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,30T-2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P-`IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-R!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-#(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#,@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G
M:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"FUS9VED(").=6UB
M97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO
M;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@
M(D]B:F5C="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$Q,0IM<V=I9"`B3V)J96-T($-R96%T;W(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$P-`IM<V=I9"`B3V-T86PB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0Q,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(V"FUS9VED(")/
M9F9I8V4B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C4X"FUS9VED(")/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D
M:69F97)E;G0N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HS-@HC+"!F=7IZ>0IM<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S
M='(@(E!A<F]L92(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT
M-@IM<V=I9"`B3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@
M(D]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B
M3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3@U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.3<Q"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM
M<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T
M;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO
M;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M
M92YP:'`Z,S4*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C0U"FUS
M9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R
M;VT@<VEG;F5D(%,O34E-12!P87)T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G
M:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R871I
M;F<@4WES=&5M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E
M8F%R+G!H<#HQ-3$*;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`B3W!C:6IA<R(*
M"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS,2!T96UP;&%T97,O<')E9G,O87!P
M+FEN8SHQ-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F
M;W(@)7,B"FUS9W-T<B`B3W!C:6IA<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4V-PIM<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES
M871I;VYA;"!5;FET(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ,S(*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B(@H*(SH@
M861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI
M8V%T:6]N('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E;7!L
M871E<R!I;B`E<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@
M(D]T:&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3,Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-#$*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(D-I=&$@:6YF
M;W)MXF-I:F$B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,Q"FUS
M9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W!A;2YP:'`Z-SD*;7-G:60@(E!!32!A=71H96YT:6-A
M=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%
M05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,C<S"FUS9VED(")01U`@1&EG:71A;"!3:6=N
M871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3,Q.0IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-S$*;7-G
M:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C$S-3,*;7-G:60@(E!'4"!3:6=N960O16YC
M<GEP=&5D($1A=&$B"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP
M.C8X"B,L(&9U>GIY"FUS9VED(")02%`@0V]D92(*;7-G<W1R(")(;W)D92(*
M"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,W"FUS9VED(")032!,:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")0
M32!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,Y"FUS9VED(")032!3;F]W(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS
M9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*;7-G:60@(E!-(%-U;B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT,@IM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C(W-`IM<V=I9"`B4$]325@@97AT96YS:6]N
M(&ES(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Y"FUS
M9VED(")07TA0(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I
M;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")086MI<W1A;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QA=2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QE<W1I;FEA;B!497)R:71O
M<GDL($]C8W5P:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B
M4&%N86UA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@
M3F5W($=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")0
M87)A9W5A>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3@P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3,W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#$X"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#(S"FUS9VED(")087-S=V]R9"(*;7-G<W1R(")087)O;&4B"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H
M86YG960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$S,C(*(RP@9G5Z>GD*;7-G:60@(E!A
M<W-W;W)D(&EN8V]R<F5C="(*;7-G<W1R(")087)O;&4B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,34R"FUS9VED(")087-S=V]R9"!R
M97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#4S"FUS9VED(")087-S
M=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*(RP@9G5Z>GD*;7-G:60@(E!A<W-W
M;W)D.B(*;7-G<W1R(")087)O;&4B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B
M:6QE+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R
M(")087)O;&4B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3`@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C`S-`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C$U"FUS9VED(")087-S=V]R9',@;75S="!M871C:"XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Q.2!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G:60@(E!A
M<W1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F5Q=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T"B,L(&9U
M>GIY"FUS9VED(")096]P;&4B"FUS9W-T<B`B3&]M82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")097)C
M96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN
M=&5N86YC92YH=&UL.C0Y"FUS9VED(")097)F;W)M($UA:6YT96YA;F-E($]P
M97)A=&EO;G,B"FUS9W-T<B`B27IP:6QD[G0@=7IT=7+G\&%N87,@;W!E<N)C
M:6IA<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,#8*(RP@9G5Z>GD*
M;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I
M;C\B"FUS9W-T<B`B27IP:6QD[G0@=7IT=7+G\&%N87,@;W!E<N)C:6IA<R(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED(")0
M97)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP
M:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@
M;F]T(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z-3@V"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R;6ES<VEO
M;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D
M;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,`HC.B!A9&UI;B]P97)M<R]I;F1E
M>"YP:'`Z,C(@861M:6XO<&5R;7,O9&5L971E+G!H<#HU.`IM<V=I9"`B4&5R
M;6ES<VEO;G,@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8U"B,L(&9U>GIY"FUS9VED(")097)S;VYA;"!)
M;F9O<FUA=&EO;B(*;7-G<W1R(")#:71A(&EN9F]R;>)C:6IA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDX"FUS9VED(")097)U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU-0IM<V=I9"`B4&5T<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3D*;7-G:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H
M;VYE(@IM<V=S='(@(E3B;')U;FES(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0W.`IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DP(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#`*;7-G:60@(E!I=&-A:7)N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE
M;',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS
M9VED(")0;&%T:71U9&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S
M92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#D*;7-G
M:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H
M:7,@96QE;65N=#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED(")0;&5A<V4@
M8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U-S$*
M;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C$R"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W
M(&-A=&5G;W)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,S`Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R
M97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-C8P"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T
M:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4Q"FUS9VED(")0;&5A<V4@
M96YT97(@82!V86QI9"!T:6UE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O=FED92!A
M('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@(DS[9'IU(&YO<N)D
M:65T('!R;V)LYVUA<R!A;F]TXF-I:G4N(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V"FUS
M9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R
M9"(*;7-G<W1R("),^V1Z=2!N;W+B9&EE="!S879U(&QI971O=.)J82!VXG)D
M=2!U;B!P87)O;&DB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*
M;7-G:60@(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U
M($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T
M96TN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E
M9V]R>4UA;F%G97(N<&AP.C<P"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W
M(&-A=&5G;W)Y(&YA;64Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I
M9"`B4&]L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU-PIM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0X-PIM<V=I9"`B4&]L;',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,0IM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(W"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.CDQ"FUS9VED(")0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@
M8GD@24U!4"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y.`IM<V=I
M9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O;&1A<"YP:'`Z.3@*;7-G:60@(E!R969S
M7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-E<W-I;VXN<&AP
M.C,S"FUS9VED(")0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C(U"FUS9VED(")0<F5S<W5R92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(U.0IM<V=I9"`B4')E<W-U<F4@870@<V5A
M(&QE=F5L.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(S-0IM<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`U"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*;7-G
M:60@(E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V,B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V-@HC+"!F=7IZ>0IM<V=I9"`B
M4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R(")!=&=R:65Z=&EE<R!P:64@;W!C
M:6KB;2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4')I=F%T
M92!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE
M;G4N<&AP.C$V.0HC+"!F=7IZ>0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R(");
M4')O8FSG;6%S('II\F]J=6US72(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP
M.C$R-@IM<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R(")0<F]B
M;.=M87,@87!R86MS=',B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S8Y"FUS9VED(")0<F]J96-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,3$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M.#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X-0IM<V=I9"`B4')O
M;7!T('1E>'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0
M=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-`IM<V=I9"`B4'5B;&EC($ME>2!)
M;F9O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N
M97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,@IM<V=I9"`B46%T87(B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C8S"FUS9VED(")1=65R>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-S`*;7-G:60@(E%U;W1A(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C8S"B,L('!H<"UF;W)M
M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C0*;7-G:60@(E)A9&EO
M('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B4F%I;B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I
M9"`B4F%I;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I;B!,871E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0V"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-PIM<V=I9"`B4F%I;B!A
M;F0@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")286YD;VT@
M1F]R='5N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-S8*;7-G:60@(E)A=&EO(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,S(T('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,S0*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3$T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@P"FUS9VED(")296%D(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C@W"B,L(&9U>GIY"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@(EII
M\F$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R
M871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@
M;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@
M(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V
M"FUS9VED(")2969R97-H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.3$*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE
M;G1S.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q
M"B,L(&9U>GIY"FUS9VED(")2969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R
M(")!=&IA=6YO="!K;W!S879I;&MU;6$@<VMA='4Z(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.#DT(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M,3,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-0IM<V=I9"`B4F5G
M97@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(T
M.0IM<V=I9"`B4F5L871I;VYS:&EP($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(P.`IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S(V"FUS9VED(")296UA<FMS(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,30*;7-G:60@(E)E
M;6]T92!397)V97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHX-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE
M>&%M<&QE+F-O;2]H;W)D92DZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M<75E=65D+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(@IM<V=S='(@
M(DEZ9'KG<W0@<.)R:2(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN
M8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@(DEZ
M9'KG<W0@<.)R:2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HU-3<*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`HC
M+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`B27ID
M>N=S="!PXG)I(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,C@*
M;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@(DEZ9'KG<W0@<.)R:2(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,#(*;7-G:60@(E)E;6]V92!S879E
M9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#(*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!T:&4B
M"FUS9W-T<B`B27ID>N=S="!PXG)I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO=F4@
M=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*(RP@9G5Z>GD*;7-G
M:60@(E)E;6]V92!U<V5R(@IM<V=S='(@(DEZ9'KG<W0@<.)R:2(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z-0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(DEZ9'KG
M<W0@<.)R:2(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X
M"FUS9VED(")297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE
M9"!E<G)O<F-O9&4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,34W"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L
M9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,3<T(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$R
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@
M;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")0
M:65P<F%S[G1A:7,@)W5I9"<@;F%V(&YO<N)D[G1S(&EE<W1A=.YJ=6UU(&MO
M;F9I9W5RXF-I:N(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV
M-S4@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,S`*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R,PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@5D93
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E!I97!R87/N=&%I<R`G=6ED)R!N
M878@;F]RXF3N=',@:65S=&%T[FIU;74@:V]N9FEG=7+B8VEJXBXB"@HC.B!F
M<F%M97=O<FLO571I;"]5=&EL+G!H<#HW.#$*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(E!I97!R87/N=&%I<R`G=6ED)R!N878@
M;F]RXF3N=',@:65S=&%T[FIU;74@:V]N9FEG=7+B8VEJXBXB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,S4*;7-G:60@(E)E<75I
M<F5D($9I96QD(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S.0HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+U)E;F1E<F5R+G!H<#HS,C`@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C$P,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<W
M"FUS9VED(")297-E="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HT-@HC+"!F=7IZ>0IM<V=I9"`B4F5S970@4&%S<W=O<F0B
M"FUS9W-T<B`B4&%R;VQE(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z,C<*;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,`IM<V=I9"`B4F5S=&]R92!,87-T
M(%%U97)Y(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HW,2!A
M9&UI;B]C;61S:&5L;"YP:'`Z,C@@861M:6XO<W%L<VAE;&PN<&AP.C8V"FUS
M9VED(")297-U;'1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I
M9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B071G<FEE>G1I97,@<&EE
M(&]P8VEJXFTB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S@*
M;7-G:60@(E)E='EP92!N97<@<&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,@IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*
M;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S(*(RP@9G5Z>GD*;7-G:60@(E)I8V@@
M5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R(")!=&=R:65Z=&EE<R!P:64@
M;W!C:6KB;2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B
M4FED9&QE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C$*;7-G:60@(E)I
M9VAT(&AE861E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,3$W"FUS9VED(")2:6=H="!V86QU97,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S-`IM<V=I
M9"`B4F]L92(*;7-G<W1R("),;VUA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B
M4F]M86YI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C(U"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,C(*;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C@*;7-G:60@(E)O=&%T
M92!2:6=H="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P,0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PHC+"!F=7IZ
M>0IM<V=I9"`B4G5L97,B"FUS9W-T<B`B3&]M82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U
M;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R,`IM<V=I9"`B4G5N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DY(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=V%N9&$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR.#4*
M;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,R,PIM
M<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#$*;7-G:60@(E-!4TP@
M875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4P-`HC+"!F=7IZ>0IM<V=I
M9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R(")::?)A(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C(Q"FUS9VED(")344P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,PIM<V=I9"`B4U%,('-T871E
M;65N="!F;W(@=F%L=64@;&]O:W5P<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#,Q"FUS9VED(")34T@B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R("(B"@HC
M.B!L:6(O87!I+G!H<#HQ-3,*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M,0IM<V=I9"`B4V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B
M4V%I;G0@2&5L96YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B
M4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-PIM<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$U"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@
M1W)E;F%D:6YE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")386UE(&9R86UE("A?<V5L
M9BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B4V%M;V$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")386\@5&]M92!A;F0@4')I
M;F-I<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R86)I82(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3@*;7-G:60@(E-A
M=F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E(%PB)7-<(B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R(")386=L
M86+B="!O<&-I:F%S(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-0IM
M<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@(E-A9VQA8N)T(&]P8VEJ87,B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38W"FUS9VED("(B"B)3879E
M(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y
M;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L('!H<"UF;W)M870*
M;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0Y"FUS9VED(")38V%T=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE;F-E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED(")3
M96%R8V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,R,`IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDW,PIM<V=I9"`B4V5L96-T($9I;&5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT.#0*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS
M9W-T<B`B27IVYVQI971I97,@9&%T=6UA(&9O<FWB='4Z(@H*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P
M('1O(&%D9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C0S"FUS9VED(")396QE8W0@82!N97<@;W=N97(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS9VED(")396QE
M8W0@82!S97)V97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HV-S<*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T
M(&%L;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@(DEZ=N=L:65T:65S(&1A
M='5M82!F;W)MXG1U.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HX-S,*;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C8W.`IM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O:V5Y8F]A<F0N<&AP.C,W"B,L(&9U>GIY"FUS9VED("(B"B)396QE8W0@
M=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N
M(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE
M('1E>'0@87)E82XB"FUS9W-T<B`B(@HB27IVYVQI971I97,@<VEM8F]L=7,@
M;F\@>F5MXFL@<F5D>F%M86KB;2!I>G;G;&[G;2X@4.=C('1A;2!J^W,@=FGR
M=7,@=F%R870@(@HB<.)R;F5S="!A<B!C;W!Y+W!A<W1E(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D
M96QI;6ET97(Z(@IM<V=S='(@(DEZ=N=L:65T:65S(&1A='5M82!A=&1A;.YT
MXFIU.B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0T"FUS9VED(")3
M96QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R("))>G;G;&EE=&EE<R!D
M871U;6$@9F]R;>)T=3HB"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES
M96QE8W0N:6YC.CDP"FUS9VED(")396QE8W0@=&AE(&ED96YT:71Y('EO=2!W
M86YT('1O(&-H86YG93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M=&EM92YI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D
M96QI;6ET97(Z(@IM<V=S='(@(DEZ=N=L:65T:65S(&1A='5M82!A=&1A;.YT
MXFIU.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")3
M96QE8W0@=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R("))>G;G;&EE=&EE<R!L
M86EK82!F;W)MXG1U.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M-3<*;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R
M("))>G;G;&EE=&EE<R!D:79U<R!S861E<NYG=7,@;&%U:W5S+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#8*;7-G:60@(E-E;&5C="!Y;W5R(&-O
M;&]R('-C:&5M92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(T.`IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E
M.B(*;7-G<W1R("))>G;G;&EE=&EE<R!V86QO9'4Z(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE;2!2
M97!O<G0B"FUS9W-T<B`B3F]S^W3N="!P<F]B;.=M87,@<&EE=&5I:W5M=2(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#,Y
M"FUS9VED(")396YD(%--4R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Y.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS
M9VED(")396YE9V%L(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S$V"FUS9VED(")396YS;W(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Y"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I9"`B4V5P=&5M
M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#$*
M;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$V,0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O
M;F<@;W(@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S
M<VEO;G,N<&AP.C(W"FUS9VED(")397-S:6]N($%D;6EN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R("(B"@HC
M.B!L:6(O87!I+G!H<#HQ-#4*(RP@9G5Z>GD*;7-G:60@(E-E<W-I;VYS(@IM
M<V=S='(@(E-A9VQA8N)T(&]P8VEJ87,B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S$T"FUS9VED(")3970B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<V"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO
M=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G
M970@:70N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,34*;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT
M('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0*(RP@9G5Z>GD*;7-G:60@(E-E="!Y
M;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T
M:6]N<RXB"FUS9W-T<B`B265S=.)D[G0@;&%P=6%T:F%U;F_P86[B<R!U;B!C
M:71A<R!E:W+B;F$@;W!C:6IA<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.3@*(RP@9G5Z>GD*;7-G:60@(B(*(E-E="!Y;W5R('-T87)T=7`@87!P
M;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@
M;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R("))97-TXF3N="!L
M87!U871J875N;_!A;N)S('5N(&-I=&%S(&5K<N)N82!O<&-I:F%S+B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*;7-G:60@(E-E='5P(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,W
M"FUS9VED(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ.#8*;7-G
M:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M
M971E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H
M96QL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0Y-@IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*(RP@9G5Z>GD*;7-G:60@(E-H;W)T
M(%-U;6UA<GDB"FUS9W-T<B`BSG-A(&%N;W3B8VEJ83HB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#0V"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@
M8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U-0IM<V=I
M9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E
M9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DP"FUS9VED
M(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C4*;7-G:60@
M(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,PIM<V=I9"`B4VAO=R!P:6-K
M97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R-@IM
M<V=I9"`B4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Y"B,L('!H<"UF;W)M
M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P
M97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@
M=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M,`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O
M<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3<V,PIM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3`*;7-G
M:60@(E-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@(E-H;W=E<G,@16%R;'DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-3(*;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,PIM<V=I9"`B4VAO
M=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#@P"FUS9VED(")3:')I;FLB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M-S<T(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C@S-@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY,C(@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3@T"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C$P-#<@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z,3`X-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HQ,3$V(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C$Q-#D*;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C
M:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`U"FUS9VED(")3:65R<F$@3&5O;F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V-0IM<V=I9"`B4VEG;B!U
M<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C<Q,@IM<V=I9"`B4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$Q"FUS9VED(")3:6=N871U
M<F4@06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@
M(E-I;F=A<&]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C8U(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HX-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.38*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C,W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#8@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,3(S"FUS9VED(")3:7IE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4R"FUS9VED(")3:VEP
M($UA:6YT96YA;F-E(@IM<V=S='(@(DEZ;&%I<W0@=7IT=7+G\&%N=2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4T"FUS9VED(")3;F]W
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C4U"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B
M4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS9VED(")3;F]W(%-H;W=E<G,@16%R
M;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-3@*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<X"FUS9VED(")3;F]W(&1E
M<'1H.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#(*
M;7-G:60@(E-N;W<@97%U:79A;&5N="!I;B!W871E<CH@(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3;VUA;&EA(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0
M;V5M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.3(V"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U
M.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,3@Y"B,L(&9U>GIY"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G<W1R
M(")$87)B82!A9')E<V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")3;W5T:"!!
M9G)I8V$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*
M;7-G:60@(E-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S<*;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3
M;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O
M=71H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E
M='=E96X@861J86-E;G0@8V5L;',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E
M(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#$U"FUS9VED(")3<&%C
M97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@P"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-30*;7-G:60@(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S$*;7-G:60@(E-P86EN(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HY.`IM<V=I9"`B4W!A;2(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@
M0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(LYP8?!O('-I;6)O;'4@:65V861E
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V"FUS
M9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L
M:70@<F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV
M,0HC+"!F=7IZ>0IM<V=I9"`B4W!O<G1S(@IM<V=S='(@(DEE;.)D92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX.`IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,R!L:6(O0FQO8VLO;65T87(N
M<&AP.C<T"B,L(&9U>GIY"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R(")+86QE
M;F3B<G,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G:60@(E-T
M87(@5')E:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-3DV(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#D*;7-G:60@(E-T
M87)T('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-S`*;7-G:60@(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R
M"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C@Q-0HC+"!F=7IZ>0IM<V=I9"`B4W1O<F%G92!F;W)M870B
M"FUS9W-T<B`B2OMS=2!I;F9O<FWB8VEJ82(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3<R"B,L(&9U>GIY"FUS9VED(")3=')E970@
M061D<F5S<R(*;7-G<W1R(")$87)B82!A9')E<V4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q"FUS9VED(")3=')I:V5T
M:')O=6=H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R,S,*;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S,*;7-G:60@(E-T<FEP(&1O;6%I;B!F
M<F]M('1H92!A9&1R97-S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE
M(%M#4U-=(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@(E-U(@IM<V=S='(@(B(*"B,Z('5T
M:6PO:6-O;E]B<F]W<V5R+G!H<#HS-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@
M(DYA=B!S=')O9&%M<R!P87II\F]J=6UU(&ML875S[G3B:G,@)7,B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S"FUS9VED
M(")3=6)J96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,S,B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3<*
M;7-G:60@(E-U8FUI="(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C0Y"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O(&%D
M9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@;&]G(&EN('5N
M=&EL('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,@IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I
M9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S
M<R(*;7-G<W1R(")696EK<VUE(@H*(SH@861M:6XO=7-E<BYP:'`Z.#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T
M;R!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@
M9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T
M92YP:'`Z-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E
M;&5T960@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@
M7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R
M=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C4W"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@
M8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S
M<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@7"(E<UPB(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F
M=6QL>2!W<F]T92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED
M(")3=61A;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4V"B,L(&9U>GIY"FUS9VED(")3=6UM
M87)Y(@IM<V=S='(@(DUA;G,@:V]P<V%V:6QK=6US(@H*(SH@;&EB+T)L;V-K
M+W-U;G)I<V4N<&AP.C8U"FUS9VED(")3=6X@4FES92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U;B!3970B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-3D*;7-G:60@(E-U;FYY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,38*;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I
M<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$U"FUS9VED(")3=6YR
M:7-E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(Q.0IM<V=I9"`B4W5N<V5T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,3@*;7-G:60@(E-U;G-E=#H@(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS-S@*(RP@9G5Z>GD*;7-G:60@(E-U<'!O
M<G0B"FUS9W-T<B`B265LXF1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@HC+"!F=7IZ>0IM
M<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`B3&EE=&]TXFIA(';B<F1S(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S0*(RP@9G5Z>GD*
M;7-G:60@(E-U<FYA;64B"FUS9W-T<B`B3&EE=&]TXFIA(';B<F1S(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-38@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8V"FUS9VED(")3=VET>F5R;&%N9"(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@IM<V=I9"`B4WEN8R!L
M;V<@9&5L971E9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,30R"FUS9VED(")3>6YC34PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U-13"]344PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3>6YT87@@97)R;W(@
M:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G
M:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS9VED(")4+5-T
M;W)M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8Q"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M,@IM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*;7-G:60@(E0M4W1O<FUS($5A
M<FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H
M<#HQ-C8*(RP@9G5Z>GD*;7-G:60@(E135B!F:6QE(@IM<V=S='(@(E9I<G-R
M86MS=',B"@HC.B!F<F%M97=O<FLO54DO54DO5&%B;&4N<&AP.C$S-`HC+"!F
M=7IZ>0IM<V=I9"`B5&%B;&4B"FUS9W-T<B`B5FER<W)A:W-T<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*
M;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PIM<V=I9"`B5&%B
M;&4@4V5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E<G1I
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S0@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I
M=V%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N:71E
M9"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDU"FUS9VED(")487)G970Z(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.38@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$X-PIM<V=I9"`B5&%S:W,B"FUS9W-T<B`B57ID
M979U;6DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W
M,PIM<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(Y,`IM<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,30*;7-G
M:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,C,*;7-G:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,
M;R5S*2`F9&5G.R5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]496UP;&%T
M92]496UP;&%T92YP:'`Z-C@W"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!L
M871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E
M;7!L871E<RYP:'`Z,38Y"FUS9VED(")496UP;&%T92!!9&UI;FES=')A=&EO
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$Q
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S8*;7-G:60@(E1E>'0B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-0IM<V=I9"`B
M5&5X="!/;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G:60@(E1E>'0@86QI9VXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4
M:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM<V=I
M9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM
M<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z.3@X"B,L(&9U>GIY"FUS9VED(")4:&%N:R!Y;W4@9F]R('5S
M:6YG('1H92!S>7-T96TN(@IM<V=S='(@(DK[<R!E<V%T(&EZ9^)J:7,@;F\@
M<VES=.=M87,N/&)R("\^4&%L9&EE<R!P87(@<VES=.=M87,@;&EE=&_P86YU
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(P"FUS9VED(")4
M:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE
M(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?24U34"])35-0+T)O;VLN<&AP.C$R.3(*;7-G:60@(E1H92!)
M35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA
M:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP
M.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI
M=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HQ.#D@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,#`*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HR,3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HR,C,*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,S0@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-3(*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HR-C0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,#,*
M;7-G:60@(B(*(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R
M92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2`B"B)W
M86YT('1O('5S92!097)M:7-S:6]N<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I
M9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@
M(B(*(E1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@
M;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C4Q"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U
M;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38Y"FUS9VED("(B
M"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E
M9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T
M,0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H
M97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB
M:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I
M<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q,PIM<V=I9"`B5&AE
M(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N
M;F5C=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ-S4@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E
M<R!S971T:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C$V."!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S
M;VUE("5S('-E='1I;F=S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HR,3D*;7-G:60@(E1H92!F:6QE(&-A;B!N;W0@8F4@
M8V]P:65D(&]N=&\@:71S96QF+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1&%T82]$871A+G!H<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N
M;R!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T
M:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K
M;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R
M+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE
M('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B
M86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@
M<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES
M(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@
M82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R
M96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB
M<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C
M<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H
M<#HY,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB
M(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H
M92!L969T+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T
M:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@
M0W)Y<'1?<&=P.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O341.+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E
M<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N
M=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T
M;V]D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.#<W"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H
M92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?
M0U-6+T-35BYP:'`Z-#0Q"B,L(&9U>GIY"FUS9VED(")4:&4@;G5M8F5R(&]F
M(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N(@IM<V=S='(@(M!A:2!VYW)T[F)A
M:2!I<B!JXF+[="!S:V%I=&QI;2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C$R,S$*;7-G:60@(E1H92!O<&5N<W-L(&UO9'5L92!I
M<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,CDP
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<
M(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E
M9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D96(N<&AP.C,R"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<G!M+G!H<#HS,@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]W96)C<'`N<&AP.C,W"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D('1O('9I
M97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S
M>7-T96TN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C0U-`IM<V=I9"`B5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N
M92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS9VED(")4
M:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X
M"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0V"FUS9VED(")4:&4@
M<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N(&1E
M;&5T960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN
M<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB
M(&AA<R!B965N('-A=F5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T
M(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HS,S`*;7-G:60@(E1H92!S
M<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$W-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S$Q
M"FUS9VED(")4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H
M92!T97AT(&]N('1H92!S8W)E96XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@
M(E1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]$871A+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D
M(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A
M;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A
M9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#8@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C4V"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ,34@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q.0IM<V=I9"`B
M5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S
M='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5M97,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,3<X"B,L(&9U>GIY"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I
M;&%B;&4N(@IM<V=S='(@(DEE<W1A=.YJ=6UI(&YA=B!P:65E:F%M:2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C,T,@IM<V=I9"`B
M5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI
M;F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T
M,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY
M(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E
M<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N
M(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z
M-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A
M9&1I;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB
M(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B
M;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H
M92!M87AI;75M("(*(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.3$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H
M('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U
M<&QO861E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+VEM8RYP:'`Z
M,S$*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#
M86QE;F1A<B!D871A+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C@P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@:6X@=&AE
M(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B
M"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*(E1H
M97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D
M<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8T,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R
M('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A
M:6X@;&%T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,C(R"FUS9VED("(B"B)4:&5R92!W87,@86X@
M97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@
M=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*;7-G:60@(E1H:7,@24U!4"!S
M97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@
M<F%R(&%R8VAI=F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P
M96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q-#4*(RP@9G5Z>GD*;7-G:60@(E1H
M:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*
M;7-G<W1R("+086D@=N=R=.YB86D@:7(@:N)B^W0@<VMA:71L:6TN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U
M"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA
M=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S
M-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S
M<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@(@HB
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"FUS
M9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E
M<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN
M8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY
M("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q
M=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY
M("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.CDW."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,#4W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.#8@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3$Q-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,3@R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-38*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3,P-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,SDX"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$U-3<@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3@S.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.34X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,#4*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`R.2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,#<X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-#D@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(R,0HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-#$P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-30*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8U-R!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,S<@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,P-@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS.#$T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,C(*
M;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C4*;7-G:60@(E1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q.`IM<V=I9"`B5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`Y-`IM<V=I
M9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$R,PIM
M<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P
M87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.3@Y"B,L(&9U>GIY"FUS9VED(")4:&ES(&9I
M96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@(M!A:2!VYW)T
M[F)A:2!I<B!JXF+[="!S:V%I=&QI;2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#,V"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I
M;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA
M;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C4V,0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y
M(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:&5L
M<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0U
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O
M=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N
M965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+
M;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA
M:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DQ"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H
M87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-@IM<V=I
M9"`B5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@
M(M!I;2!S:V%I=&QI;2!I<B!JXF+[="!V:7-M87H@,2XB"@HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@
M<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN
M<&AP.C$X.0IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T
M:79A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R
M+B(*;7-G<W1R("+086D@=N=R=.YB86D@:7(@:N)B^W0@<VMA:71L:6TN(@H*
M(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM<V=I9"`B
M5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I
M;F1O=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV-`IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,T"FUS9VED(")4:6-K971S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,C@@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")4
M:6UE(@IM<V=S='(@(E9I<G-R86MS=',B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S@V"FUS9VED(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4S.0IM
M<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R
M86UE+G!H<#HR,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`B5FER<W)A:W-T<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*
M;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C8U-`IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US
M+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I
M(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B5&]D87DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#D*;7-G:60@(E1O9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,`IM<V=I9"`B5&]K96QA=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S$S"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S<*;7-G:60@(E1O<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A;64@*%]T
M;W`I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM
M<V=I9"`B5')A;G-L871I;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*
M;7-G:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<Y,`IM<V=I9"`B5')U92!O<B!F86QS
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$P"FUS9VED(")4=6YI<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*
M;7-G:60@(E1U<FME>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$Y,@IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(V-`IM<V=I
M9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-CD*;7-G:60@(E4N5BX@:6YD97@Z("(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS9VED(")54DPB
M"FUS9W-T<B`B55),(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I<'0@
M9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW"B,L(&9U>GIY"FUS
M9VED(")54DPZ(@IM<V=S='(@(E523"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@
M(E5G86YD82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")5:W)A
M:6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C0Q,@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER
M96-T;W)Y+B(*;7-G<W1R(").878@:65S<.=J86US('!I97-LYV=T:65S(%-1
M3"!S97)V97)I;2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP
M:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA
M=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,S@X"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS
M.#4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0V.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&
M4R!F:6QE("5S+R5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C<U-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B3F%V(&EE<W#G:F%M<R!P
M:65S;.=G=&EE<R!344P@<V5R=F5R:6TN(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HR,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8X."!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C$P,38*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C@S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@
M9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]S<6PN<&AP.C0S-0IM<V=I9"`B56YA8FQE('1O(&-O
M;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B3F%V(&EE<W#G:F%M<R!P
M:65S;.=G=&EE<R!344P@<V5R=F5R:6TN(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HX,SD*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C;VYN
M96-T('=I=&@@4U-,+B(*;7-G<W1R(").878@:65S<.=J86US('!I97-LYV=T
M:65S(%-13"!S97)V97)I;2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HR,C4@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C,P"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,C`Y"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8V]P
M>2!61E,@9FEL92XB"FUS9W-T<B`B3F%V(&EE<W#G:F%M<R!P:65S;.=G=&EE
M<R!344P@<V5R=F5R:6TN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HS-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!6
M1E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,S4T(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HR-3@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(U
M-@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T
M;W)Y+B(*;7-G<W1R(").878@:65S<.=J86US('!I97-LYV=T:65S(%-13"!S
M97)V97)I;2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3(T
M"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*
M;7-G<W1R(").878@:65S<.=J86US('!I97-LYV=T:65S(%-13"!S97)V97)I
M;2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(X-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HR-C4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@
M5D93(&9I;&4N(@IM<V=S='(@(DYA=B!I97-PYVIA;7,@<&EE<VSG9W1I97,@
M4U%,('-E<G9E<FEM+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]T87(N<&AP.C<V"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G
M>FEP+G!H<#HW.0IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,C0@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR.3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@
M:7,@;F]T(&5M<'1Y+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C<X(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S$@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HS.3(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C,Q,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S,T
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H
M92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#@@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,U,@IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S<@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C,R,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,S,U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T-`HC+"!F=7IZ>0IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").878@
M:65S<.=J86US('!I97-LYV=T:65S(%-13"!S97)V97)I;2XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0Q-R!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C0R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C(P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S`S(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,C@X"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HQ-C<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X,`HC.B!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@W(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HS.#,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C,Y,0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR
M-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HT,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@P,PHC+"!F=7IZ>0IM<V=I9"`B
M56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B3F%V(&EE<W#G:F%M<R!S97-I:N(@<F7L:7-T<N=T(&EE<W1A=.YJ=6UU
M<RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8P,PIM
M<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z-#4Q
M(&9R86UE=V]R:R].971?24U34"])35-0+T%U=&@N<&AP.C$Q.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O
M9B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P,0HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,38V(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HQ-S$*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T
M;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R(").878@:65S<.=J86US('!I97-L
MYV=T:65S(%-13"!S97)V97)I;2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.CDS(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,3`R"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-C0X(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P
M96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR-S<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,3,S"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN
M9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M.#`@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,@HC+"!F=7IZ>0IM<V=I9"`B56YA
M8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@(DYA=B!I97-PYVIA;7,@
M<&EE<VSG9W1I97,@4U%,('-E<G9E<FEM+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*(RP@9G5Z>GD*;7-G:60@(E5N86)L
M92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92XB"FUS9W-T<B`B3F%V(&EE
M<W#G:F%M<R!P:65S;.=G=&EE<R!344P@<V5R=F5R:6TN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C@S-0IM<V=I9"`B56YA8FQE('1O(')E860@5D93
M(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C@V-@IM<V=I9"`B56YA8FQE('1O(')E860@
M5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+VYO
M;F4N<&AP.C,X"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C8Y"FUS9VED
M(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$P-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D
M97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(Y,PHC+"!F=7IZ
M>0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G
M<W1R(").878@:65S<.=J86US('!I97-LYV=T:65S(%-13"!S97)V97)I;2XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(V
M-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,T,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C$P(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,CD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,C,@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C(Q,PHC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z-#4R(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HR.#4*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,P,0IM
M<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N
M<&AP.C4P"FUS9VED(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H
M<#HU.0IM<V=I9"`B56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C
M=6UE;G0B"FUS9W-T<B`B3F%V(&EE<W#G:F%M<R!I;G1E<G!R973G="#P;R!7
M;W)D(&1O:W5M96YT=2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,30Y(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,34R"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$W.0IM
M<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D
M*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,C@Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S@*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$T,PIM<V=I9"`B56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HX-#$*;7-G:60@(E5N86)L92!T;R!W<FET92!6
M1E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,`IM
M<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R(")!=&-E
M;'0@:7IM86GR87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HR,C,*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,SDP"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R
M(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0Q"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,W.`HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS.#0*;7-G:60@(E5N97AP96-T960@<F5S<&]N
M<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV,0IM<V=I9"`B56YF
M:6QE9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM
M<V=I9"`B56YI8V]D92`H551&+3@I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V
M"FUS9VED(")5;FET960@07)A8B!%;6ER871E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S0*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,SD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L
M>6EN9R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HV.2!L:6(O0FQO8VLO;65T87(N<&AP.C<Q"FUS9VED(")5
M;FET<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,CD@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#,P"FUS
M9VED(")5;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A
M<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G
M:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U.0IM
M<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDQ"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-3@*;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M
M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET
M>2YP:'`Z,CDV"B,L(&9U>GIY"FUS9VED(")5;FYA;65D(@IM<V=S='(@(DQI
M971O=.)J82!VXG)D<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL96=E9"!S8W)I<'1S
M(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY
M(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@
M=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB<VAO=W,@
M>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B
M;V%R9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@IM<V=I9"`B56YS970@8V]L;W(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M.#8@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,C8*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,S(*;7-G:60@(E5N<W5P
M<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$Y-R!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHS,PIM<V=I9"`B57!D871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,CD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B57!D871E("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z-S8*;7-G:60@(E5P9&%T92!U<V5R(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,30T(&%D;6EN+W!E<FUS+V5D:70N
M<&AP.C$P,B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,P"B,L('!H<"UF
M;W)M870*;7-G:60@(E5P9&%T960@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX,PIM<V=I9"`B57!G<F%D92!S8W)I
M<'0@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$W."!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3DY"FUS9VED(")5<&QO860B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N
M('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,C`*;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHQ.`IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$S"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L
M('!H<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4S.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3(T"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I
M<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"B,L(&9U>GIY"FUS
M9VED(")5<V5R(@IM<V=S='(@(DQI971O=.)J82!VXG)D<R(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S(S"B,L('!H<"UF;W)M
M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S97(@
M061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HR-3$*;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R
M("),:65T;W3B:F$@;W!C:6IA<R(*"B,Z('-I9VYU<"YP:'`Z-C(*(RP@9G5Z
M>GD*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(DQI971O=.)J
M82!O<&-I:F%S(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I9"`B57-E<B!296=I
M<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0V.0IM<V=I9"`B
M57-E<B!A8V-O=6YT(&YO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.CDX
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U
M,"!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,PHC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C<R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O
M=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G<W1R("),:65T;W3B:F$@
M=N)R9',B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,3(T
M"B,L('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A;')E861Y
M(&5X:7-T<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C@W"B,L(&9U>GIY"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B
M3&EE=&]TXFIA(';B<F1S(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI
M;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R("),:65T
M;W3B:F$@=N)R9',B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN
M8SHR"FUS9VED(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$T"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$V,R!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HR-34*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N
M;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ,3@*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C@V-@IM<V=I9"`B5F%L:60@;&]C871I;VYS
M(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8S.`IM<V=I9"`B5F%L:61I='DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU.3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C4U"FUS9VED(")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-38@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$W-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-"!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8V"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(S,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR.`HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS
M9VED(")686QU97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C$P.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@V"FUS9VED
M(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C0T"FUS9VED(")687)I86)L92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")696YE>G5E;&$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,3@*;7-G
M:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA
M=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B5F5R<VEO;B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(V"FUS
M9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B
M5F5R=&EC86P@86QI9VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D
M9&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*;7-G
M:60@(E9E<GD@2&EG:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED
M(")6:65T($YA;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$Y-`IM<V=I9"`B5FEE=&YA;65S92`H5DE30TE)*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HY-C(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO:69R86UE+G!H<#HS"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P
M86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C@R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&%S("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S
M+"!"<FET:7-H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I
M<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C`Y"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-C,*;7-G:60@(E9I<VEB
M:6QI='DZ("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@271A
M;'D@=FEA(%--5%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I
M9"`B5T%23B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'(2$A(%)%34]612!3
M0U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G:60@(E=)3B!V
M:6$@2%144"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")786QL
M:7,@86YD($9U='5N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I
M8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C(W,B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z.#,*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B
M0G+N9&ENXFIU;7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H97(@1F]R96-A
M<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C0R-PIM<V=I9"`B5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y,@IM<V=I9"`B5V5A
M=&AE<BYC;VTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M,S8*;7-G:60@(E=E8B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#,W"FUS9VED(")796(@4VET92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4X"FUS9VED
M(")7965K;'DB"FUS9W-T<B`B2V%T<G4@;F5DY^]U(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+VUO8FEL92YP:'`Z,C@*(RP@9G5Z>GD*;7-G:60@(E=E;&-O;64B
M"FUS9W-T<B`B3&%I<&YI(&S[9'IM+"`E<R(*"B,Z('1E;7!L871E<R]L;V=I
M;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(DQA
M:7!N:2!L^V1Z86T@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H
M<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B3&%I<&YI(&S[9'IM+"`E
M<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")797-T97)N
M("A)4T\M.#@U.2TQ*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$Y-@IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,34I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,W"B,L('!H<"UF;W)M
M870*;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@
M869T97(@;&]G:6X_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA
M<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3`V,0IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@
M<&AA<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,S,*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC
M:"!497AT(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R-0IM
M<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED
M=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O
M;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T
M:&4@=&%B;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G:60@(E=I9'1H('5N:70B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-3$S"FUS9VED(")7:6MI(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C4*;7-G:60@(E=I;F0B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C8*;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HX,`IM<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U-@IM<V=I9"`B5VEN
M9#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(T,@IM<V=I9"`B5VEN9#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.38*;7-G:60@(E=I<VAL:7-T(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B
M5V]R:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R(")$
M87)B82!A9')E<V4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(D1A<F)A
M('3B;')U;FES(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,38Y
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(V,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X
M<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z,S`P"B,L('!H<"UF;W)M870*;7-G:60@(E=R
M;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3$T
M"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R
M96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR-#,*;7-G:60@(E@M4F5F(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED(")8
M-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3(*;7-G:60@(E@U,#EV,R!%
M>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!3=6)J96-T
M($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J96-T
M($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C@R"FUS9VED(")8-3`Y=C,@97AT96YS:6]N
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B
M65DB"FUS9W-T<B`B1T<B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-34*(RP@9G5Z>GD*;7-G:60@(EE965DB"FUS9W-T<B`B
M1T<B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3$P.`IM<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R
M;'DB"FUS9W-T<B`B2V%T<G4@9V%D=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@
M(EEE;65N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(EEE<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM<V=I
M9"`B665S+"!)($%G<F5E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@
M5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C
M:R!T;R!765-)5UE'+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO
M961I="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@
M86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#$Q"FUS9VED
M(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,P,@IM<V=I9"`B66]U
M(&-A;B!N;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL
M(&YA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X-34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW-0IM<V=I9"`B66]U
M(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M
M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD
M<R`B"B)I;B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z.3@X"B,L(&9U>GIY"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E
M9"!O=70N(@IM<V=S='(@(DK[<W4@;W!C:6IA<R!I<B!S86=L86+B=&%S+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-C$*;7-G:60@(B(*(EEO
M=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG
M:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E
M<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@X"FUS9VED(")9;W4@:&%V92!T;R!E
M;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I
M9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#4V"FUS9VED
M(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@
M(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N
M('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R(")!<')A:W-T:65T
M('!R;V)LYVUU('!I<FUS('!I971E:6MU;6$@<_MT[O!A;F%S+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*;7-G:60@
M(EEO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT
M<R!T;R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H
M<#HX,`IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D
M96QE=&5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*;7-G
M:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U
M(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHX"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R
M;F%M92!T;R!A9&0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T
M-@IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D
M871E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O>FEP+G!H<#HQ,S@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A
M8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*;7-G:60@(EEO=2!M
M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z
M-S,*;7-G:60@(EEO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N
M92!N=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP
M:'`Z.3<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H
M87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R(")*^W-U
M("5S('-E<VEJ82!I<B!B96EG=7-I97,N($S[9'IU('!I97-LYV1Z:65T:65S
M(&%T:^)R=&]T:2XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHS.`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S
M='(@(DK[<W4@92UP87-T82!A9')E<V4Z(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(Q,@HC+"!F=7IZ>0IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S
M.B(*;7-G<W1R(")*^W-U(&4M<&%S=&$@861R97-E.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S0@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX.0IM<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R(")*^W-U(&EN
M9F]R;>)C:6IA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@P"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H
M87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S
M<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L
M;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z,S,*(RP@9G5Z>GD*;7-G:60@(EEO=7(@3F%M92(*;7-G
M<W1R(")*^W-U(';B<F1S.B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO
M861D+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME
M;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H
M('1O("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L
M('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H96YT:6-A=&EO;B!B
M86-K96YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N
M;VQI<W0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C
M:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F
M96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E
M87-O;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M.3@T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E
M87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO
M=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y
M;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VEF<F%M92YP:'`Z-3`*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S
M=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O<')I;G0N:G,Z-#(*;7-G:60@(B(*(EEO=7(@8G)O=W-E
M<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#
M;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4W"FUS9VED(")9;W5R(&-U<G)E
M;G0@=&EM92!Z;VYE.B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP
M:'`Z.38*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>2!H
M87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R(")*^W-U(&]P8VEJ87,@:7(@<V%G
M;&%BXG1A<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34X"B,L(&9U
M>GIY"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@(E!A
M<F%S=.(@:61E;G1I=.)T92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,#$*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R(")*
M^W-U(';B<F1S.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C$P,#`*
M(RP@9G5Z>GD*;7-G:60@(EEO=7(@;&]G:6X@:&%S(&5X<&ER960N(@IM<V=S
M='(@(DK[<W4@;W!C:6IA<R!I<B!S86=L86+B=&%S+B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO
M=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-30*(RP@9G5Z>GD*;7-G
M:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U
M<F%T:6]N(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`B2OMS=2!O<&-I:F%S
M(&ER('-A9VQA8N)T87,N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E
M9"XB"FUS9W-T<B`B2OMS=2!O<&-I:F%S(&ER('-A9VQA8N)T87,N(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S
M<W=O<F0@:&%S(&)E96X@<F5S970B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@
M:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W
M:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HW,S(*;7-G:60@(EEO=7(@<&%S<W=O<F0@
M:&%S(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-30@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B675G;W-L879I
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$X"FUS9VED("):86ER92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS
M9VED("):86UB:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B
M6FEM8F%B=V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C8V"FUS9VED(")::7!P>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X
M=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");
M2&ED92!1=6]T960@5&5X=%TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')O
M8FQE;2YP:'`Z.#@*;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B
M6U!R;V)LYVUA<R!Z:?)O:G5M<UTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@
M+2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R
M+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,L('!H<"UF;W)M870*;7-G:60@
M(EM3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DS"B,L('!H<"UF;W)M870*
M;7-G:60@(EML:6YE("5S(&]F("5S72(*;7-G<W1R(");<FEN9&$@)7,@;F\@
M)7-=(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-30Q('1E;7!L
M871E<R]P;W)T86PO;65N=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES=')A=&EO
M;B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB
M"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS9VED(")?1&%T851R
M964B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED(")?1&5L971E(%)O=R(*;7-G
M<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@(E]'<F]U<',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W
M-0HC+"!F=7IZ>0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`B4&%L[F1Z[F)A(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DT"B,L(&9U
M>GIY"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(E!I97-LYV=T:65S(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y,`HC+"!F=7IZ>0IM
M<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`B27II970B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G:60@
M(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O365N=2YP:'`Z,38T"B,L(&9U>GIY"FUS9VED(")?3W!T:6]N
M<R(*;7-G<W1R(")/<&-I:F%S(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED
M(")?4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V"B,L(&9U>GIY"FUS
M9VED(")?4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`B27ID>N=S="!PXG)I(@H*
M(SH@;&EB+V%P:2YP:'`Z,3(U"FUS9VED(")?4V5T=7`B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,S"FUS9VED(")?5&%B;&4@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B
M"@HC.B!L:6(O87!I+G!H<#HQ,CD*;7-G:60@(E]5<V5R<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR,0HC+"!F=7IZ>0IM
M<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(DMO;G1A:W1I(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S0*;7-G:60@(F%D9')E
M<W-E92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z.3$S"B,L(&9U>GIY"FUS9VED(")C86QE;F1A<B(*;7-G<W1R
M(")+86QE;F3B<G,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,U.`HC+"!P:'`M9F]R;6%T"FUS9VED(")C86QM
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,34X"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,P
M"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3(*;7-G:60@(F-L:6-K
M(&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$W.`IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B
M8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T
M82!F;W)M870@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ.#(*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HW,0IM<V=I9"`B9F%L;&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-34*(RP@9G5Z>GD*;7-G:60@(F9I
M;&4B"FUS9W-T<B`B5FER<W)A:W-T<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,3<T(&QI8B]";&]C:R]M971A<BYP:'`Z,S8P(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S@V"B,L('!H<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S("@E
M<RD@870@)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(U,`IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0Y"FUS9VED
M(")H.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,S4X"FUS9VED(")H:"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N
M86UE('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA
M=&4B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M
M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(FEN;&EN92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V,@IM<V=I
M9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S
M;V9T=V%R92!E<G)O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B;&EN97-=(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES
M;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES;V9S(&5R<F]R
M(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,V.0IM<V=I9"`B
M;6TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HR.3$@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W,`HC.B!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C,R"B,L(&9U>GIY"FUS9VED(")N
M86UE(@IM<V=S='(@(E;B<F1S(@H*(SH@9G)A;65W;W)K+U)00R]24$,N<&AP
M.C$R,0IM<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(Q.0IM<V=I9"`B;F]T
M('EE="!I;7!L96UE;G1E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.CDP-0IM<V=I9"`B;F]T97!A9"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@X"FUS9VED(")P97)C96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,3<T"FUS9VED(")P97)M:7-S:6]N(&1E
M;FEE9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S`*;7-G
M:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,PHC+"!F=7IZ
M>0IM<V=I9"`B<FES:6YG(@IM<V=S='(@(D)R[F1I;N)J=6US(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#(*;7-G:60@(G-E<G9I
M8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HY.0IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS.#4*;7-G
M:60@(G-S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,#D*;7-G:60@(G-W:71C:"!O
M9F8@:F%V87-C<FEP="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Y"FUS9VED
M(")T87-K(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S`U"B,L
M(&9U>GIY"FUS9VED(")T<GD@86=A:6XB"FUS9W-T<B`B2V%T<N(@<&EE<VSG
M9_!A;N)S(')E:7KG(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@9G)A;65W;W)K
M+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B='EP92!T:&4@<&%S
M<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I
M9"`B=6YI9FEE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U!A<G0N<&AP.C(W"FUS9VED(")U;FYA;65D(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R
M,PIM<V=I9"`B=7-E<B!S96QE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*
M;7-G<W1R(")V0V%R9"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR-#$*;7-G:60@(G<Z(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED(")W96%T:&5R+F-O;2(*
M;7-G<W1R("(B"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O
M;FY?3D\N<&\`````````````````````````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P-C(T,S,W(#$P-3$U-#,S-S0S(#`Q-S4T-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````C($AO<F1E($YO
M<G=E9VEA;B!.>6YO<G-K('1R86YS;&%T:6]N"B,@0V]P>7)I9VAT("A#*2`R
M,#`R(%!E<BU3=&EA;B!6871N90HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E
M9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!(;W)D92!P86-K86=E
M+@HC(%!E<BU3=&EA;B!6871N92`\<'-V0&]R<W1A+F]R9SXL(#(P,#(N"B,@
M"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!(;W)D
M92`S+C`M8W9S7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S
M+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@
M,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P,BTP-BTP."`R
M,CHS,"LP,3`P7&XB"B),87-T+51R86YS;&%T;W(Z(%!E<BU3=&EA;B!6871N
M92`\<'-V0&]R<W1A+F]R9SY<;B(*(DQA;F=U86=E+51E86TZ($YO<G=E9VEA
M;B!.>6YO<G-K(#QN>6YO<G-K0&]R<W1A+F]R9SY<;B(*(DU)344M5F5R<VEO
M;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]
M:7-O+3@X-3DM,5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I
M=%QN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,V.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S-S`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(S-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI
M;B`E<R!D87ES*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S<S"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<U"FUS9VED("(@*'1O;6]R<F]W*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<Q"FUS
M9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(U-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S8Q"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,#<*;7-G
M:60@(B!A="`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN
M<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@
M=F%L:60@8VAO:6-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O4F5G:7-T<GDN<&AP.C8U.0HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O4F5G:7-T<GDN<&AP.C$P-#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G
M:7-T<GDN(@IM<V=S='(@(B<E<R<@97(@:6MK:F4@:V]N9FEG=7)E<G0@:2!R
M96=I<W1E<F5T('1I;"!(;W)D92XB"@HC.B!F<F%M97=O<FLO5')E92]4<F5E
M+G!H<#HQ-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R964@<F5N
M9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C4V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S
M(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R("(G)7,G('9A
M<G0@;&%G="!T:6P@9W)U<'!E<WES=&5M970N(@H*(SH@861M:6XO<&5R;7,O
M861D8VAI;&0N<&AP.C4R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<
M(B5S7"(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM
M<V=S='(@(B<E<R<@=F%R="!L86=T('1I;"!T:6QG86YG<W-Y<W1E;65T+B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-30@861M:6XO<&5R;7,O861D8VAI;&0N
M<&AP.C4P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S
M(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B)R5S)R!V87)T(&EK:VIE(&]P
M<')E='1A.B`E<R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E
M9"`H)2XR9B4E*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C,W"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N9"`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C(V."!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-34W"B,L('!H<"UF;W)M870*
M;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@U
M"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B)7,@+2!.;W1I<R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`T"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S,R!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@2T(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N
M8V4N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S($UA:6YT96YA;F-E
M($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B)7,@=F5D;&EK
M96AA;&1S;W!E<F%S:F]N87(@+2!3=&%D9F5S=&EN9R(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8S"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E
M<FUS(&]F($%G<F5E;65N="(*;7-G<W1R("(E<R!6:6QKY7(@9F]R(&%V=&%L
M92(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#(X(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z-#DP"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z-C4Q(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U.2!L:6(O0FQO8VLO;65T87(N
M<&AP.C$V-2!L:6(O0FQO8VLO;65T87(N<&AP.C(S.0HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,T-2!L:6(O0FQO8VLO;65T87(N<&AP.C,U,0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE("(*(F)O
M>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T
M('1H:7,@=&EM92XB"FUS9W-T<B`B2W)Y<W,@878@9F]R(&]P97)A<VIO;BAA
M<BD@9'4@=FEL(&OX>7)E(&YO+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER960B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#8*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(B5S(&UI;G5T97,B"FUS9W-T<B`B2W9A
M<G0@-2X@;6EN=71T(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE
M8W1I;VXN<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U
M;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F
M("5S(@IM<V=S='(@(EML:6YJ92`E<R!A=B`E<UTB"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDR,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B061R97-S96)O:R(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@(DMA;&5N9&5R
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#8*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R("(E<R`M
M($YO=&ES(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]M;V)I;&4N<&AP.CDV"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL
M+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,Z(%1H:7,@;65S
M<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E
M=V%R92!O9B!F;VQL;W=I;F<@(@HB86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R
M;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S8U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,3`*;7-G:60@
M(BP@9W5S=&EN9R`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ.#@@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B
M;&4@9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C(Y-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C,T.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#8Y(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,C@*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C<T.0IM<V=I9"`B+2T@<V5L96-T("TM(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,`HC+"!F=7IZ>0IM
M<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS9W-T<B`B1&EN(&EN9F]R;6%S:F]N
M(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y"B,L(&9U>GIY"FUS9VED("(R
M-"!(;W5R($9O<FUA="(*;7-G<W1R(")$:6X@:6YF;W)M87-J;VXB"@HC.B!T
M96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS
M9W-T<B`B,C0@=&EM87(B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP
M.C8Y"FUS9VED("(\4')E=FEO=7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ,3D*;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R
M97%U:7)E9"!F;W(@=&AI<R!B;&]C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C`*(RP@9G5Z>GD*;7-G:60@(D$@9F%T
M86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(CQB/D1E="!S:VIE9&1E
M(&5I;B!K871A<W1R;V9A;"!F96EL.CPO8CXB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@
M:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-C4*;7-G:60@
M(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG
M;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$P.3<*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL
M('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#$U"FUS9VED("(B"B)!('!U
M8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,#4*;7-G
M:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@
M82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME
M>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U
M8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A
M9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.CD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B
M04T@3&EG:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M,@IM<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B04T@4VYO=R!3
M:&]W97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC
M.C(Y"FUS9VED(")!32]032(*;7-G<W1R(")!32]032(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B
M05!)($E$(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4R"FUS9VED
M(")!8F]U="XN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<T"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW,@IM<V=I9"`B06)S;6ED9&QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI960@
M8W)E871I;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE
M9"!C<F5A=&EN9R!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G0@26YF;W)M
M871I;VXB"FUS9W-T<B`B1&EN(&EN9F]R;6%S:F]N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<U"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT(%!A<W-W
M;W)D(@IM<V=S='(@(E-T861F97-T('!A<W-O<F0B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*;7-G:60@(D%C
M8V]U;G0@9G)O>F5N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S,S"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30X('1E;7!L871E<R]P
M;W)T86PO861D+FEN8SHQ-`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D
M9&-H:6QD+FEN8SHQ,0IM<V=I9"`B061D(@IM<V=S='(@(DQE9V<@=&EL(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@861M:6XO9W)O=7!S+G!H<#HR,C4*
M(RP@9G5Z>GD*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R("),96=G
M('1I;"!U;F1E<F]R9&YA(&]B:F5K="(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z.3@@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY
M.0HC+"!F=7IZ>0IM<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T
M<B`B3&5G9R!T:6P@=6YD97)O<F1N82!O8FIE:W1T:6QG86YG('1I;"`G)7,G
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*(RP@9G5Z>GD*;7-G
M:60@(D%D9"!(97)E.B(*;7-G<W1R("),96=G('1I;"!B<G5K87(B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q.0IM<V=I
M9"`B061D($YE=R!'<F]U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z.#@*(RP@9G5Z>GD*;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO;B(*;7-G
M<W1R(")4:6QG86YG(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C
M:&EL9"YI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@
M8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(DQE9V<@=&EL('5N9&5R
M;W)D;F$@;V)J96MT9W)U<'!E('1I;"`G)7,G(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ-#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@
M(DQE9V<@=&EL('5N9&5R;W)D;F$@;V)J96MT=&EL9V%N9R!T:6P@)R5S)R(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E<CHB
M"FUS9W-T<B`B3&5G9R!T:6P@;GD@8G)U:V%R.B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HU-30*;7-G:60@(D%D9"!C;VQU
M;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHS-`HC+"!F=7IZ>0IM<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S
M='(@(DQE9V<@=&EL(&YY='0@;65D;&5M(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D('!A:7(B"FUS9W-T<B`B3&5G9R!T
M:6P@<&%R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I
M9&5B87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")!9&0@=&\@861D<F5S
M<R!B;V]K.B(*;7-G<W1R(")!9')E<W-E8F]K(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C<X"B,L(&9U>GIY"FUS9VED(")!
M9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(D%D<F5S<V5B;VLB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HS,0IM<V=I9"`B061D('5S97(B"FUS9W-T<B`B
M3&5G9R!T:6P@8G)U:V%R(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O('1H92!S>7-T96TL
M(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T
M:6]N.B`B"B(E<RXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@
M66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B061D:6YG('5S97)S(&ES
M(&1I<V%B;&5D+B(*;7-G<W1R("),96=G('1I;"!B<G5K87)A<B!E<B!S;.5T
M="!A=BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3(V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ-S,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,0IM<V=I9"`B061D
M<F5S<R(*;7-G<W1R(")!9')E<W-E(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$S.0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(D%D<F5S
M<V5B;VLB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HY-`HC+"!F=7IZ>0IM<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S
M:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`B16YD<F4@=&EL9V%N9R!F
M;W(@)R5S)R(*"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ.2!S97)V:6-E<R]P;W)T
M86PO<VED96)A<BYP:'`Z,3$S"FUS9VED(")!9&UI;FES=')A=&EO;B(*;7-G
M<W1R(")!9&UI;FES=')E<FEN9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS-#$*(RP@9G5Z>GD*;7-G:60@(D%D<R(*;7-G<W1R("),96=G('1I
M;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3<*(RP@9G5Z>GD*;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B
M06QI87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<P"B,L(&9U>GIY"FUS9VED(")!;&=E<FEA(@IM
M<V=S='(@(D%L:6%S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T<B`B06QI87,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C$V"B,L(&9U>GIY"FUS9VED(")!;&EG;B(*;7-G<W1R(")!;&EA<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G
M:60@(D%L:6=N;65N=#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C@W"FUS9VED(")!;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T
M<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP
M.C(R,@HC+"!F=7IZ>0IM<V=I9"`B06QL($=R;W5P<R(*;7-G<W1R(")'<G5P
M<&5R(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY,2!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O9&%T871R964N<&AP.C<U"B,L(&9U>GIY"FUS
M9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`B5&EL9V%N9R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3<*
M;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$X-S$*;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D
M9')E<W-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3,T"FUS9VED(")!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E
M/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O
M<W%L+G!H<#HU,#0*;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C,*;7-G:60@(D%L=&5R;F%T
M92!)35-0($QO9VEN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU,#<*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3D*;7-G:60@(D%L
M=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C,U"B,L(&9U>GIY"FUS9VED(")!;'1E<FYA
M=&4@96UA:6P@861D<F5S<R(*;7-G<W1R(")$:2!E+7!O<W1A9')E<W-E.B(*
M"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E<FYA=&4@
M=&5M<&QA=&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I9"`B06QT97)N
M871E('1E>'0Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%M97)I
M8V%N(%-A;6]A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z.34@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,34*
M;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB"FUS9W-T
M<B`B16EN('5L;W9L96<@=F5R9&D@=F%R="!S<&5S:69I<V5R="XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38W"B,L(&9U>GIY"FUS9VED
M(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+B(*;7-G<W1R("(\8CY$
M970@<VMJ961D92!E:6X@:V%T87-T<F]F86P@9F5I;#H\+V(^(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-0HC+"!F=7IZ>0IM<V=I9"`B06YD;W)R82(*;7-G<W1R(")&;F]R<F4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0Y
M"FUS9VED(")!;G-W97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B
M06YT87)C=&EC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!;G1I
M9W5A(&%N9"!"87)B=61A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN<&AP.C,U"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R]522YP:'`Z-3@@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN
M9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`B(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,
M:7-T(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#`*
M;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@
M0VAI;&0@4VAA<F5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S,PIM<V=I
M9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S4*;7-G:60@(D%R
M86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4Y(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HX,0IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HU."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8U"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#`*;7-G:60@
M(D%R8VAI=F4@3F%M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F5Q=65U960N:6YC.C$P"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S
M:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R(")%<B!D=2!S:6MK97(@
M<.4@870@9'4@=FEL('-L971T92`G)7,G/R(*"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O9&5L971E+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E(%PB)7-<(B!A
M;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(D5R(&1U('-I:VME<B!PY2!A
M="!D=2!V:6P@<VQE='1E("<E<R<_(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B07)G
M96YT:6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%R;65N:6$B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S8*;7-G:60@
M(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HR.`IM<V=I9"`B07)T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3D*;7-G:60@(D%R=6)A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA;F0B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!
M<V-I:2!!<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4U"FUS9VED(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,C4*;7-G:60@(D%S:R!F
M;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R
M871I;VYS/R(*;7-G<W1R(")3</AR(&]M('-T861F97-T:6YG(&;X<B!K^'ER
M:6YG(&%V('9E9&QI:V5H86QD<V]P97)A<VIO;F%R/R(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,Q,3,*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN
M<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<T"FUS9VED(")!
M='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T
M<B`B4'+X=F1E(.4@<VQE='1E(&5I(&EK:VIE+65K<VES=&5R86YD92!G<G5P
M<&4N(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B071T
M96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS
M9W-T<B`B4'+X=F1E(.4@<VQE='1E(&5I;B!I:VMJ92UE:W-I<W1E<F%N9&4@
M=&EL9V%N9RXB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HX-PIM<V=I9"`B
M071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM
M<V=S='(@(E!R^'9D92#E(&5N9')E(&5I;B!I:VMJ92UE:W-I<W1E<F%N9&4@
M=&EL9V%N9RXB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*(RP@
M9G5Z>GD*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S
M:&%R92XB"FUS9W-T<B`B4'+X=F1E(.4@96YD<F4@96EN(&EK:VIE+65K<VES
M=&5R86YD92!T:6QG86YG+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C0@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HW,0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C@V"FUS9VED(")!='1R:6)U=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#@*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R"B,L(&9U>GIY"FUS9VED
M(")!=6=U<W0B"FUS9W-T<B`B3'5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S
M=')A;&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP
M.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED(")!=71H7V-Y<G5S.B!"86-K96YD
M(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I
M9"`B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V9T<"YP
M:'`Z,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS
M:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M
M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]I;6%P+G!H<#HV-`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)
M34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@
M4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B
M075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@
M06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C,U-PIM<V=I9"`B075T:%]L9&%P.B!296UO=FEN
M9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M-C,*;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z
M(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@
M56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#DY"B,L('!H<"UF;W)M870*;7-G
M:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#`U"FUS
M9VED(")!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T
M960@9F]R($%C=&EV92!$:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-#8*;7-G:60@(D%U=&A?;6-A;#H@
M4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U
M=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A
M:6QE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HV-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!
M=71H96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE;G1I
M8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#4Q"FUS9VED(")!=71H
M96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HW,`IM<V=I9"`B075T:&5N
M=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C<U"FUS9VED(")!=F%I
M;&%B;&4@9FEE;&1S.B(*;7-G<W1R(")4:6QG:F5N9V5L96=E(&9E;'0Z(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@(D)/1D@@17AC=7-E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O=6YD(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C,*
M;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S
M('!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A:&%M87,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R
M(")"87)B:64B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-PIM<V=I9"`B
M0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM
M<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED
M(")"87)B861O<R(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP
M:'`Z,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E
M8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S"FUS9VED
M(")"87-E;&EN92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QA
M<G5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)E;&=I=6TB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L:7IE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C$*;7-G:60@(D)E;FEN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I
M9"`B0FAU=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@
M(D)U<G-D86<B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO
M;BYP:'`Z,S4S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")";&]C:R!<
M(B5S7"(@;V8@87!P;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T
M<B`B1F%N;B!I:VMJ92!V87)S96QL>71T87(@)7,N(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]L87EO=70N:6YC.C@Y"FUS9VED(")";&]C:R!3971T:6YG<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z-S0*
M;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(P-0IM<V=I9"`B0F]O:VUA
M<FMS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C`*(RP@9G5Z>GD*;7-G:60@(D)O<F1E<B(*
M;7-G<W1R(")(;W)D92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C$*(RP@9G5Z>GD*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B
M2&]R9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V
M:6YA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-@IM
M<V=I9"`B0F]T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"B,L(&9U>GIY"FUS
M9VED(")";W1S=V%N82(*;7-G<W1R(")"<G5N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")";W1T
M;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"B,L(&9U>GIY"FUS9VED(")"<F%Z
M:6PB"FUS9W-T<B`B12UP;W-T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(D)R:71I
M<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8R"FUS9VED(")"<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Q"FUS9VED(")"=6QG87)I82(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"FUS9VED(")"=6QL
M971E9"!,:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<FMI
M;F$@1F%S;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)U;F1I
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#0*
M(RP@9G5Z>GD*;7-G:60@(D--4R(*;7-G<W1R(")#5E,B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED(")#4D,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.3<*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38S"FUS9VED(")#
M86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@T(&-O;F9I
M9R]H;V]K<RYP:'`N9&ES=#HY.#<*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$U-0IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B2V%L96YD97(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0V"B,L(&9U>GIY"FUS
M9VED(")#86QM(@IM<V=S='(@(D%V8G)Y="(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED
M(")#86UB;V1I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#86UE
M<F]O;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HR,`IM<V=I9"`B0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A
M;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S$X"B,L('!H<"UF;W)M
M870*;7-G:60@(D-A;B!N;W0@=W)I=&4@=&\@9FEL92!<(B5S7"(B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(R"FUS9VED(")#86XG="!A
M9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(S-2!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,S$Y"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E
M<R(*;7-G<W1R(")+=6YN92!I:VMJ92!K;W!L92!T:6P@3$1!4"UT96YA<F5N
M+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0Q,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")#86XG="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8T"B,L(&9U>GIY"FUS9VED(")#86YA9&$B"FUS9W-T
M<B`B2V%L96YD97(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E
M<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHV-0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z
M,3$@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*
M;7-G<W1R(")!=F)R>70B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@
M(D%V8G)Y="!P<F]B;&5M<F%P<&]R="(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z,S$X"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D96QE
M=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HT-@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R"FUS9VED(")#86YN;W0@9FEN
M9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A
M;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,30*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T
M851R964N<&AP.C$R."!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L
M+G!H<#HV.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@
M)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$
M871A5')E92]$871A5')E92]S<6PN<&AP.C8P.`IM<V=I9"`B(@HB0V%N;F]T
M(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R
M9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF
M:65D(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0V%P
M92!697)D92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(T"B,L(&9U>GIY"FUS9VED(")#87!T
M:6]N(@IM<V=S='(@(D%L=&5R;F%T:78B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0*(RP@9G5Z>GD*;7-G:60@(D-A
M<G)I97(B"FUS9W-T<B`B0F%R8FEE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDP"FUS9VED(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#8*;7-G:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B36]B:6QT96QE9F]N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR-0HC+"!F=7IZ>0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@
M(DUO8FEL=&5L969O;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@IM
M<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,C<T"B,L(&9U>GIY"FUS9VED(")#96QL<&AO;F4B
M"FUS9W-T<B`B36]B:6QT96QE9F]N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ-S@*;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C4T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS
M9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D-E;G1R86P@175R;W!E
M86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-CDY"FUS9VED(")#97)T:69I8V%T92!$971A
M:6QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C$Q"FUS9VED(")#97)T:69I8V%T92!/=VYE<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I
M9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`X"B,L(&9U>GIY"FUS9VED(")#:&%D(@IM<V=S='(@(G9#87)D(@H*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHY-@HC+"!F=7IZ>0IM<V=I9"`B0VAA;F=E(@IM<V=S
M='(@(D%N9W)E(&5N9')I;F=A<B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O
M<F0B"FUS9W-T<B`B4W1A9&9E<W0@<&%S<V]R9"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV-@IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A
M9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P
M;'D@=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U
M<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@
M8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(W"B,L(&9U>GIY"FUS9VED(")#:&%R(@IM<V=S
M='(@(G9#87)D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")#:&EL92(*;7-G
M<W1R(")4:71T96PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EN82(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,`IM<V=I9"`B0VAI;F5S
M92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#:&EN97-E(%1R861I=&EO;F%L("A"
M:6<U*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU
M<"YP:'`Z,C8Y"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*
M;7-G<W1R(")3=&%D9F5S="!P87-S;W)D(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.C(V.`IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y.`IM<V=I
M9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D
M97)E9"!L:7-T<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR
M:7-T;6%S($ES;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,N<&AP.C(Y-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#DS"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D969I;FET:6]N(&]F("5S
M(&YO="!F;W5N9"XB"FUS9W-T<B`B1F%N;B!I:VMJ92!V87)S96QL>71T87(@
M)7,N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,30*(RP@9G5Z>GD*;7-G:60@(D-L96%R(@IM<V=S='(@(DMA;&5N9&5R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM
M<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,3(X"FUS9VED(")#;&5A<B!1=65R>2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$Q"FUS9VED
M(")#;&5A<B!U<V5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C,T"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,34*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-C`*;7-G:60@(D-L
M:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(DML:6MK(&9O<B#E(&AA;&1E(&9R
M86TB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`B
M3'5K:R!V:6YD875G970B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-`IM
M<V=I9"`B0VQO=61S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$V"FUS9VED(")#;&]U9',@16%R;'DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,3<*;7-G:60@(D-L;W5D>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS
M9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C(S"FUS9VED(")#;VQL87!S
M92!3:61E8F%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B
M;W)D97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O;&]M8FEA
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L
M;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#;VQO<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(T
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C4*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4P,"!S
M97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@R"FUS9VED(")#;VQO
M<B!0:6-K97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C@T-@IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PIM
M<V=I9"`B0V]L<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3DT-@IM<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8T"FUS9VED(")#;VUI8W,B
M"FUS9W-T<B`B(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(U"B,L(&9U>GIY
M"FUS9VED(")#;VUM86YD(@IM<V=S='(@(D9I<FUA(@H*(SH@861M:6XO8VUD
M<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B
M0V]M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4V-@IM<V=I9"`B0V]M;6]N($YA;64B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HU.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#0*;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B
M0V]M<&%N>2(*;7-G<W1R(")&:7)M82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3<*;7-G:60@(D-O;F1I=&EO;B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T.0IM<V=I9"`B
M0V]N9&ET:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H
M<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30S"FUS9VED(")#;VYF
M:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@
M86YD($]U=&QO;VLN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ,S4*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-3$*;7-G:60@(D-O
M;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B4W1A9&9E<W0@<&%S<V]R9"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-34@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C8*;7-G:60@(D-O;F=O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4*
M;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G
M:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDP"FUS9VED(")#;VYN96-T:6]N
M(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(D]P
M<&MO<&QI;F<@;6]T(&]F9F5N=&QE9R!N^&MK96QT96YA<B!N96MT82XB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(D]P
M<&MO<&QI;F<@;6]T(&]F9F5N=&QE9R!N^&MK96QT96YA<B!N96MT82XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@T-0IM<V=I9"`B0V]N;F5C
M=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VAO;VMS+G!H<"YD:7-T.C$P,30*;7-G:60@(D-O;G1A8W1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@
M=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C<X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;VYT96YT<R!O9B!<(B5S7"(B"FUS9W-T<B`B26YN:&%L9"!I("<E<R<B
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.2!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z,S,*(RP@9G5Z>GD*;7-G:60@(D-O;G1I;G5E
M(@IM<V=S='(@(DML:6MK(&9O<B#E(&AA;&1E(&9R86TB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V
M"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,R"FUS9VED(")#;V]K:64B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(Q"B,L(&9U>GIY"FUS9VED(")#;W!Y(@IM<V=S='(@(D9I<FUA(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C@*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R("));7!O<G1E
M<G1E(&9E;'0Z("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-S`*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G
M:60@(D-O<W0@240B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S
M=&$@4FEC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;W1E(&0G
M279O:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.CDW-@IM<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A
M9V4N(@IM<V=S='(@(DMU;FYE(&EK:VIE(%!'4"UK;V1E(&UE;&1I;F<N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`U,PIM<V=I9"`B
M0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(DMU;FYE(&EK
M:VIE(%!'4"US:6=N97)E(&UE;&1I;F<N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HS.3,*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO
M="!3+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R(")+=6YN92!I:VMJ
M92!01U`M:V]D92!M96QD:6YG+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-#8W"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@4R]-
M24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`B2W5N;F4@:6MK:F4@4$=0+7-I
M9VYE<F4@;65L9&EN9RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C$X-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R(")+=6YN92!I
M:VMJ92!D96MO9&4@4$=0+61A=&$N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.CDV(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M,3(Q"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E
M<G9E<BXB"FUS9W-T<B`B2W5N;F4@:6MK:F4@:V]P;&4@=&EL($Q$05`M=&5N
M87)E;BXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#4W"B,L(&9U>GIY
M"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E<B(*;7-G<W1R
M(")+=6YN92!I:VMJ92!S:V%F9F4@;V9F96YT;&5G(&[X:VME;"!F<N4@;OAK
M:V5L=&5N87)E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C$U-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HT-#$*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO
M="!C;VYN96-T('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(DMU;FYE(&EK:VIE
M(&MO<&QE('1I;"!,1$%0+71E;F%R96XN(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VYN
M96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C,R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3(U"FUS9VED(")#;W5L9"!N;W0@9&5C
M<GEP="!01U`@9&%T82XB"FUS9W-T<B`B2W5N;F4@:6MK:F4@9&5K;V1E(%!'
M4"UD871A+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3(R"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@
M9&%T82XB"FUS9W-T<B`B2W5N;F4@:6MK:F4@9&5K;V1E(%!'4"UD871A+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,C0V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L
M971E(&-O;G1A8W0N("5S(@IM<V=S='(@(DMU;FYE(&EK:VIE(&1E:V]D92!0
M1U`M9&%T82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HS.#$@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.34S"FUS
M9VED(")#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA
M:6P@861D<F5S<RXB"FUS9W-T<B`B2W5N;F4@:6MK:F4@879G:F5R92!M;W1T
M86MA<F5N('-I(&4M<&]S=&%D<F5S<V4N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*(RP@9G5Z>GD*;7-G:60@
M(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S
M='(@(DMU;FYE(&EK:VIE(&%V9VIE<F4@;6]T=&%K87)E;B!S:2!E+7!O<W1A
M9')E<W-E+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@
M9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0V"FUS9VED(")#;W5L
M9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N
M(&QI<W1S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.`HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDN<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D
M('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C$Q,`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S$Y"FUS9VED(")#
M;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R
M+B(*;7-G<W1R(")+=6YN92!I:VMJ92!S:V%F9F4@;V9F96YT;&5G(&[X:VME
M;"!F<N4@;OAK:V5L=&5N87)E;BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F
M;W(@=W)I=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B2W5N;F4@
M:6MK:F4@4$=0+6MO9&4@;65L9&EN9RXB"@HC.B!F<F%M97=O<FLO36%I;G1E
M;F%N8V4O36%I;G1E;F%N8V4N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*
M;7-G<W1R(")+=6YN92!I:VMJ92!O<&YE($UA:6YT96YA;F-E7U1A<VLM;6]D
M=6QE;B`E<R(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HW,`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<
M(BXB"FUS9W-T<B`B2W5N;F4@:6MK:F4@;W!N92!-86EN=&5N86YC95]487-K
M+6UO9'5L96X@)7,B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,3$Q(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(S-R!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#<X"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HU,38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C8Q,@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C4V
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV.3D*(RP@9G5Z>GD*
M;7-G:60@(D-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S
M='(@(DMU;FYE(&EK:VIE(&MO<&QE('1I;"!,1$%0+71E;F%R96XN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O3V)J96-T+G!H<#HR,S@*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R96%D("5S+B(*;7-G<W1R("(G
M)7,G('9A<G0@:6MK:F4@;W!P<F5T=&$Z("5S(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T
M:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A
M;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A
M:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@
M(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#D*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0P"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,W-PHC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS.#,*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S@Y"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@
M04-,(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,C<T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R
M(")+=6YN92!I:VMJ92!A=F=J97)E(&UO='1A:V%R96X@<VD@92UP;W-T861R
M97-S92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C0X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T
M<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB
M=71I;VX@;&ES=',N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE
M=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO
M="!R979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B2&]R9&4@97(@:6MK
M:F4@;W)D96YT;&5G(&MO;F9I9W5R97)T(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP
M.CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U;&0@
M;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E
M('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<U"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T
M:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE("(*
M(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@
M;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,30S"B,L(&9U>GIY"FUS
M9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T
M<B`B2W5N;F4@:6MK:F4@:V]P;&4@=&EL($Q$05`M=&5N87)E;BXB"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDO8V]P>2YP:'`Z.#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R(")+=6YN92!I:VMJ
M92!01U`M<VEG;F5R92!M96QD:6YG+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S
M='(@(DMU;FYE(&EK:VIE(&1E:V]D92!01U`M9&%T82XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I
M9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,V-@IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@
M36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E
M;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,34T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T
M(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H
M92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#$Y"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-CD*
M;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(W,PIM<V=I9"`B0V]U<G-E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@
M(D-R96%T92!A(&QI;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S
M+VED96YT:71Y<V5L96-T+FEN8SHY-`IM<V=I9"`B0W)E871E(&$@;F5W(&]N
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY,@IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C0P"B,L(&9U
M>GIY"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(E1I;&=A
M;F<B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C,P"FUS9VED(")#
M<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HV-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G
M:60@(D-R;V%T:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B
M82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*;7-G:60@
M(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO
M;G,N<&AP.C0X"FUS9VED(")#=7)R96YT(%-E<W-I;VYS(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS
M,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I
M9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO
M;G,N<&AP.C,S"FUS9VED(")#=7)R96YT(%5S97)S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U<G)E;G0@5V5A=&AE
M<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C<U"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G
M:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@
M=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I
M;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS9VED(")#>7)I
M;&QI8R`H2T])."U2*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X,PIM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@(D-Y<FEL
M;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y
M"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4Q('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R(")$1"(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#$*;7-G:60@(B(*(D133B`H<V5E(&AT
M='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N
M9&(N:6YT<F\M9'-N+G!H<"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA
M:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B1&%I;'DB"FUS
M9W-T<B`B1&%G;&5G(@H*(SH@861M:6XO9&%T871R964N<&AP.C8U"FUS9VED
M(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,R-SD*;7-G:60@(D1A=&%B87-E($QO;VMU<"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N
M<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S.3D*(RP@9G5Z>GD*
M;7-G:60@(D1A=&4B"FUS9W-T<B`B3W!P9&%T97(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E:79E
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`W
M"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDR(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS,C(*(RP@9G5Z>GD*;7-G:60@(D1A>2(*;7-G<W1R(")$86=L
M96<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S8*(RP@9G5Z>GD*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM
M<V=S='(@(E-L971T92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0U,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C<V"B,L(&9U>GIY"FUS9VED(")$96-E;6)E<B(*;7-G<W1R
M(")-961L96UM87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C$V"FUS9VED(")$96-I;6%L(&YU;6)E<G,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3@W(&QI8B]P<F5F
M<RYP:'`Z,3$W"B,L(&9U>GIY"FUS9VED(")$969A=6QT(@IM<V=S='(@(E-L
M971T92(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C<W"B,L(&9U>GIY"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@
M(D)R=6L@<W1A;F1A<F1V97)D:2(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])
M9&5N=&ET>2YP:'`Z.3$*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T
M<B`B4W1A;F1A<F1I9&5N=&ET970B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`B
M4W1A;F1A<F1I9&5N=&ET970B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S,*;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z-S$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C8*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HT,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHS-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C<P"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z.3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,38*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#(*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C<S('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY
M.`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*
M;7-G<W1R(")3;&5T=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S(*(RP@9G5Z>GD*;7-G:60@(D1E;&5T
M92!#96QL(@IM<V=S='(@(E-L971T92(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,3DY(&%D;6EN+V=R;W5P<RYP:'`Z,C(W"B,L(&9U>GIY"FUS9VED(")$96QE
M=&4@1W)O=7`B"FUS9W-T<B`B4VQE='1E(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C0Y"B,L(&9U>GIY"FUS9VED(")$96QE=&4@3&]G(@IM
M<V=S='(@(E-L971T92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z-S<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#$*(RP@9G5Z
M>GD*;7-G:60@(D1E;&5T92!097)M:7-S:6]N(@IM<V=S='(@(E1I;&=A;F<B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,PIM
M<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4W"B,L(&9U>GIY"FUS9VED(")$96QE=&4@8V5L;"(*;7-G<W1R(")3;&5T
M=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8S"B,L(&9U>GIY"FUS9VED(")$96QE=&4@8V]L=6UN(@IM<V=S
M='(@(E-L971T92(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS9VED
M(")$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(Q"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R
M(%PB)7-<(B(*;7-G<W1R(")%;F1R92!T:6QG86YG(&9O<B`G)7,G(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N
M>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*(RP@9G5Z>GD*
M;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T<B`B4VQE='1E(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V1E;&5T96ED96YT:71Y+FEN8SHQ-0HC+"!F=7IZ>0IM<V=I
M9"`B1&5L971E('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@(E-T86YD87)D
M:61E;G1I=&5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@
M8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E('1H92!C
M=7)R96YT(')O=R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HS-@HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('-E='5P('5P
M9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C,*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.34*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(Q"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U
M,PHC+"!F=7IZ>0IM<V=I9"`B1&5L:79E<GD@=&EM92(*;7-G<W1R(")3;&5T
M=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$96YM87)K(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C(Y"FUS9VED(")$97-C
M<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R(")3:VEL9')E('!R;V)L96UE="(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDS."!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,P"B,L(&9U>GIY"FUS
M9VED(")$97-C<FEP=&EO;B(*;7-G<W1R(")&=6QL('-K:6QD<FEN9SHB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y-0IM<V=I9"`B1&5T86EL
M<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y.0IM<V=I9"`B1&5T86EL<R!H
M879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T
M<B`B1&5T86QJ87(@97(@;&]G9V$@9F]R(&%D;6EN:7-T<F%T;W)E;BXB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C$Y"FUS9VED(")$979E;&]P
M;65N="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-PIM
M<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,CDT"FUS9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C<*
M;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO
M;B!L969T('1O(')I9VAT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R
M:6=H="!T;R!L969T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N
M<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(V-@IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I
M;65S/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<*
M;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R(")6:7-I;F=S86QT97)N
M871I=B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HY-@HC+"!F
M=7IZ>0IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R
M(")6:7-I;F=S86QT97)N871I=B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M.#4*;7-G:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-PHC+"!F=7IZ>0IM<V=I
M9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B5FES:6YG<V%L=&5R;F%T:78B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,3DP"FUS9VED(")$
M:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M.0IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HT,C(*(RP@9G5Z>GD*;7-G:60@(D1O(&YO="!D
M96QE=&4B"FUS9W-T<B`B4VQE='1E(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N
M8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT
M96YA;F-E+G!H<"(*;7-G<W1R(")):VMJ92!B<G5K(&UA:6YT96YA;F-E+G!H
M<"!D:7)E:W1E+B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$R
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$R"FUS9VED(")$;V5S('1H
M92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@
M8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@
M(D1O;6EN:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D1O;6EN
M:6-A;B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.CDV"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I
M9VX@=7`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C@T-`IM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0T"B,L('!H<"UF
M;W)M870*;7-G:60@(D1O=VYL;V%D("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ-C(*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E
M9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#<*;7-G:60@(D1R;W`@9&]W
M;B!L:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M-`HC+"!F=7IZ>0IM<V=I9"`B1')U9W,B"FUS9W-T<B`B3'5S(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"B,L(&9U>GIY"FUS9VED
M(")%+4UA:6PB"FUS9W-T<B`B12UP;W-T(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--
M4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@
M=&AI<R!S97)V:6-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I
M8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS
M9VED(")%4E(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U861O
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R
M-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY
M,@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$X,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="(*;7-G<W1R
M(")%;F1R92(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3`@
M=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="!";&]C
M:R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y."!A9&UI;B]G
M<F]U<',N<&AP.C(R-@HC+"!F=7IZ>0IM<V=I9"`B161I="!'<F]U<"(*;7-G
M<W1R(")'<G5P<&5R(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HW-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,`HC+"!F=7IZ
M>0IM<V=I9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@(E1I;&=A;F<B"@HC
M.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"B,L(&9U>GIY"FUS9VED
M(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(E1I;&=A;F<B"@HC.B!S97)V
M:6-E<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R(")%;F1R
M92!T:6QG86YG(&9O<B`G)7,G(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI
M;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T
M<B`B16YD<F4@=&EL9V%N9R!F;W(@)R5S)R(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,S8W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")%9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B16YD<F4@
M=&EL9V%N9R!F;W(@)R5S)R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES
M<VEO;G,@9F]R("5S(@IM<V=S='(@(D5N9')E('1I;&=A;F<@9F]R("<E<R<B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%:71H97(@96YA8FQE(&ET('1H96XZ("5S+"!O<B!U
M<V4@=&AE(&)A<VEC($A434P@=F5R<VEO;CH@)7,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C0S"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C(T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-CD*;7-G:60@
M(D5M86EL(@IM<V=S='(@(D4M<&]S="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-38U('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I
M="YI;F,Z,3`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV
M.`HC+"!F=7IZ>0IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R(")$:2!E
M+7!O<W1A9')E<W-E.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y
M-C,*(RP@9G5Z>GD*;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H
M+B(*;7-G<W1R(")087-S;W)D82!MY2!S86US=F%R92XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.3@Y"B,L(&9U>GIY"FUS9VED(")%;6%I;"!W
M:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")!;FYA;B!I;F9O<FUA<VIO;B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ
M"FUS9VED(")%;6%I;"UT;RU335,@1V%T97=A>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDX"B,L(&9U
M>GIY"FUS9VED(")%;6]T:6-O;G,B"FUS9W-T<B`B06QT97)N871I=B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M,@HC+"!F=7IZ>0IM<V=I9"`B16UP='D@;65S<V%G92XB"FUS9W-T<B`B5&]M
M="!R97-U;'1A="XB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,C0S(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT.#0*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8V,B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%;7!T>2!R97-U;'0N(@IM<V=S='(@
M(E1O;70@<F5S=6QT870N(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R
M9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#,*;7-G:60@(D5N86)L
M92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN
M('1E>'0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,3@*;7-G:60@(D5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.3@@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,0IM<V=I9"`B16YD('EE87(B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%9&ET;W(B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R,0IM<V=I9"`B(@HB16YT97(@82!S
M96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y
M;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T
M(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR,@IM<V=I9"`B16YT97(@=&AE(&EM86=E(%523"!H97)E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX
M.3$*;7-G:60@(D5N=&5R('1H92!L971T97)S(&)E;&]W.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDY(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<V"FUS9VED(")%<75A=&]R:6%L($=U:6YE82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%<FET<F5A(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+W-T871U<RYP:'`Z,C<*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C0U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-0HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,V('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z.#(*
M;7-G:60@(D5R<F]R(@IM<V=S='(@(D9E:6PB"@HC.B!F<F%M97=O<FLO5&5M
M<&QA=&4O5&5M<&QA=&4N<&AP.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@S"B,L('!H<"UF;W)M870*
M;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE
M<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%
M=7)O<&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S
M.0IM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R(")+=F%R="`Q-2X@
M;6EN=71T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X.0HC+"!F=7IZ
M>0IM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(DMV87)T(#4N(&UI
M;G5T="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S8@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,X-PIM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G
M<W1R(")+=F%R="`S,"X@<V5K=6YD(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,S."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDP"FUS9VED(")%=F5R
M>2`U(&UI;G5T97,B"FUS9W-T<B`B2W9A<G0@-2X@;6EN=71T(@H*(SH@9G)A
M;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B
M179E<GD@3&]G:6XB"FUS9W-T<B`B2W9A<B!I;FYL;V=G:6YG(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,T,`IM<V=I9"`B179E<GD@:&%L9B!H;W5R
M(@IM<V=S='(@(DMV87(@:&%L=F4@=&EM92(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS,S<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X.`IM<V=I9"`B
M179E<GD@;6EN=71E(@IM<V=S='(@(DMV87)T(&UI;G5T="(*"B,Z('1E;7!L
M871E<R]D871A+V1A=&5M87`N:6YC.C(T"FUS9VED(")%>&%M<&QE('9A;'5E
M<SHB"FUS9W-T<B`B16MS96UP96QV97)D:6%R.B(*"B,Z(&%D;6EN+W!H<'-H
M96QL+G!H<#HX,2!A9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE
M;&PN<&AP.C$R-PIM<V=I9"`B17AE8W5T92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT-S4*;7-G:60@(D5X<&%N
M9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC
M.C,R"FUS9VED(")%>'!A;F0@4VED96)A<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E
M9"`G*2<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R
M9',N<&AP.C$W-0IM<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E
M9"!S96%R8V@@=&5R;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER871I;VX@1&%T92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W
M-@IM<V=I9"`B17AP;VYE;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@
M0V]L;W(B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W
M-PIM<V=I9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O<W%L+G!H<#HR,38*;7-G:60@(D9A:6QE
M9"!R971R:65V:6YG('!R969E<F5N8V5S+B(*;7-G<W1R(")+=6YN92!I:VMJ
M92!H96YT92!I;FYS=&EL;&EN9V%R(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C<U(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*
M;7-G<W1R(")+=6YN92!I:VMJ92!K;W!L92!T:6P@3$1!4"UT96YA<F5N+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HY.`HC+"!F=7IZ>0IM
M<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T
M<B`B2W5N;F4@:6MK:F4@:V]P;&4@=&EL($Q$05`M=&5N87)E;BXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8X-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.3$*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS
M9W-T<B`B2W5N;F4@:6MK:F4@:V]P;&4@=&EL($Q$05`M=&5N87)E;BXB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@W"FUS9VED(")&86EL
M960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DW(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z-S(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(DMU;FYE(&EK
M:VIE(&MO<&QE('1I;"!,1$%0+71E;F%R96XN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HT-C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`B2W5N;F4@:6MK:F4@
M:&5N=&4@:6YN<W1I;&QI;F=A<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")&86ER(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S(*;7-G:60@(D9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&87)O92!)<VQA;F1S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR,S@*(RP@9G5Z
M>GD*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R("));7!O<G1F96EL.B`B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W
M"FUS9VED(")&87@B"FUS9W-T<B`B1F%K<R(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS-#D*(RP@9G5Z>GD*;7-G:60@(D9A>&5S(@IM<V=S='(@
M(D9A:W,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHV-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,C`*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,0IM<V=I9"`B1F5E
M;',@;&EK93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$Y"FUS9VED(")&97<@4VAO=V5R<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M,`IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30T"FUS9VED(")&:65L9"!M871R:7@B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S-`IM
M<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S,S.`IM<V=I9"`B1FEG;&5T(&9O;G0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEJ:2(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@
M(D9I;&4B"FUS9W-T<B`B5&ET=&5L(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@
M9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`W"FUS
M9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`B1FEL:&%N9'-A;6EN9R(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,`HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@U"B,L(&9U>GIY"FUS9VED(")&
M:6QE($YA;64B"FUS9W-T<B`B1FEL:&%N9'-A;6EN9R(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Y.34*;7-G:60@(D9I;&4@<V5L96-T:6]N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T.#8*;7-G
M:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W
M<V5R+T)R;W=S97(N<&AP.C@U.0IM<V=I9"`B1FEL92!U<&QO861S(&YO="!S
M=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HX.0IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q
M"FUS9VED(")&:6YL86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I
M9"`B1FER<W0@475A<G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4V"FUS9VED(")&:7@@<F%T:6\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(S,0IM<V=I9"`B1FQI<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,R"FUS9VED
M(")&;&]A="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C,T(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HQ,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S
M(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L;W(B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS9VED
M(")&;V]D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R;W=S
M97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS,S0*;7-G:60@(D9O<F5C87-T("A4048I
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW
M.0IM<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U
M<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B
M"B)L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L
M;V-K*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C$P,@IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-C(*;7-G:60@(D9O<FUS
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0HC+"!F
M=7IZ>0IM<V=I9"`B1F]R='5N92(*;7-G<W1R(")&;F]R<F4B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*(RP@9G5Z>GD*
M;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(DYO=&%T87(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U,PIM<V=I9"`B1F]R
M=6US(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ
M,#D*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S,*(RP@9G5Z>GD*;7-G:60@(D9R86UE<R(*;7-G<W1R(").
M86UN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,PHC+"!F=7IZ>0IM<V=I9"`B1G)A;F-E(@IM<V=S
M='(@(D]R86YS:F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI=&%N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S0*;7-G:60@(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0X(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS-C`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C0P-@IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"B,L(&9U>GIY"FUS9VED(")&=6QL
M($1E<V-R:7!T:6]N(@IM<V=S='(@(D9U;&P@<VMI;&1R:6YG.B(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<V"FUS
M9VED(")&=6QL($UO;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C8Q('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*
M(RP@9G5Z>GD*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R(")$:71T(&YA;6XZ
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,PIM<V=I9"`B1V%B;VXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@(D=E;F5R
M871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL.C@*;7-G:60@(D=E;F5R871E9"!#
M;V1E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDS(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<U"FUS9VED(")':&%N82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<U"FUS9VED(")':6)R86QT87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S4*;7-G:60@(D=I=F5N($YA;64B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3(*;7-G
M:60@(D=O(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M,`IM<V=I9"`B1V]E9&5L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HQ,3(X"FUS9VED(")';V]G;&4@36%P
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS
M9VED(")';V]G;&4@4V5A<F-H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,S<*;7-G:60@(D=R87ES8V%L
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@HC+"!F=7IZ>0IM<V=I9"`B1W)E
M96-E(@IM<V=S='(@(D=R^&XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M-0IM<V=I9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R(")'<OAN
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-`HC+"!F=7IZ>0IM<V=I9"`B1W)E;F%D82(*;7-G<W1R
M(")'<OAN(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-SD*;7-G:60@(D=R;W5P
M($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D=R=7!P96%D;6EN:7-T<F5R:6YG
M(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+G!H<#HU.2!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N86UE<R!M
M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L('!H<"UF;W)M870*;7-G:60@(D=R
M;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$X(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HQ,C0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C0Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A
M<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<R(*;7-G<W1R(")+=6YN92!I
M:VMJ92!S;&5T=&4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C,S."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,S<Y"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L
M92!T;R!U<&1A=&4@9W)O=7`@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HS,30@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R
M;W5P<R(*;7-G<W1R(")'<G5P<&5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDV
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W5A
M9&5L;W5P92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A;2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3(*(RP@9G5Z
M>GD*;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@(D=RY2(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,C(V('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z.#@*(RP@9G5Z>GD*;7-G:60@(D=U97-T(%!E<FUI<W-I;VYS(@IM
M<V=S='(@(E1I;&=A;F<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#<P"B,L(&9U>GIY"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`B061R97-S
M96)O:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=U:6YE82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S@*;7-G:60@(D=U:6YE82U":7-S874B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<X"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.38P"FUS9VED(")(5$U,(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#4*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@
M9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V
M"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G
M:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L
M87-T(')O=R!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]H='1P+G!H<#HQ-3<*;7-G:60@(DA45%`@075T:&5N=&EC871I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@
M(DAA:71I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G
M:60@(DAA>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z.3$Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S(*(RP@9G5Z>GD*
M;7-G:60@(DAE861E<B(*;7-G<W1R(")/=F5R<VMR:69T97(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"B,L(&9U>GIY
M"FUS9VED(")(96%D97)S(@IM<V=S='(@(D]V97)S:W)I9G1E<B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA
M;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(S"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@V"FUS9VED(")(96)R97<@*$E3
M3RTX.#4Y+3@M22DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM<V=I9"`B2&5I9VAT(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ
M-SD@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$X-@HC.B!S97)V
M:6-E<R]H96QP+VEN9&5X+G!H<#HQ-R!T96UP;&%T97,O:&5L<"]I;F1E>"YI
M;F,Z,PIM<V=I9"`B2&5L<"(*;7-G<W1R(")(:F5L<"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@
M=7-I;F<@961I=&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$S-S$*(RP@9G5Z>GD*;7-G:60@(DAE;'!E<B(*;7-G<W1R(")(
M:F5L<"(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B2&5M:7-P
M:&5R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN
M8SHQ,"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,`IM<V=I9"`B2&5R
M92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.0IM<V=I
M9"`B2&EG:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N
M:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C4*(RP@
M9G5Z>GD*;7-G:60@(DAO7VUE(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-`IM<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-3,U"B,L
M(&9U>GIY"FUS9VED(")(;VUE(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R,@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U"FUS9VED(")(;VUE
M($%D9')E<W,B"FUS9W-T<B`B061R97-S92P@<')I=F%T(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C8T"FUS9VED(")(;VUE($1I<F5C=&]R>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(E1E;&5F;VXL('!R
M:79A="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<X"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8U"FUS9VED(")(;W)D92(*
M;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M-#0R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED
M("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR.3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S
M<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z-#,U"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,3(U,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R(")&:F5R
M;F$@)R5S)R!F<N4@<WES=&5M970N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I
M;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-3`S
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(T-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<
M(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z-#<T"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5
M;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP
M92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C$Q.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!S>6YC:')O;FES92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3,S-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H
M87)E<SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N
M:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT
M86P@4G5L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4Q"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O
M<G0A*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS
M('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE
M;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G
M:60@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S`*;7-G:60@(DAU;6ED:71Y(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3D*;7-G
M:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0Q"FUS9VED(")(=6UO<FES=',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@P"FUS9VED(")(=6YG87)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W,B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G-Q;"YP:'`Z,C,U"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I
M;&)O>"!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(Q-"!F<F%M97=O<FLO075T:"]!
M=71H+V-Y<G-Q;"YP:'`Z,CDU"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@
M;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W.2!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G-Q;"YP:'`Z,C0R"B,L('!H<"UF;W)M870*;7-G:60@(DE-
M05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,38*(RP@9G5Z>GD*
M;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`B061R97-S92(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D9')E
M<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@061D<F5S<R!N;W0@
M=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS
M9VED("))4"!L;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S<V"FUS9VED("))8V]N<R!/;FQY(@IM<V=S='(@
M(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,W-PIM<V=I9"`B26-O;G,@=VET:"!T97AT(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3`*;7-G:60@(DED
M96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z-3DR"B,L('!H<"UF;W)M870*;7-G:60@(DEF
M(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET
M(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0U-0IM<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A;GD@
M:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T
M;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E
M;F-Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3<S"FUS9VED("(B"B))9B!Y;W4@<V5E('1H:7,@;65S
M<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO
M860@8V%N)W0@8F4@(@HB9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(X"FUS9VED("));6%G92!0<F5V:65W.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,W"FUS9VED("));6%G92!54DPB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3@*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS
M,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8Q"FUS9VED("));6%G92!U
M<&QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S<*
M;7-G:60@(DEM86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T
M<W9I;F9O+FEN8SHW('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C<*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-"!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("));7!O
M<G0L(%-T97`@)60B"FUS9W-T<B`B26UP;W)T97)T92!F96QT.B`E<R(*"B,Z
M('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*
M;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R("));7!O<G1E<G1E
M(&9E;'0Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV-0IM
M<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R("));7!O<G1E<G1E(&9E
M;'0Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,P"FUS9VED("));E]S97)T(%)O=R!!9G1E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ
M,S4*;7-G:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S(*(RP@9G5Z>GD*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A
M;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(E-K<FEV(&EN;B!D:71T(&)R=6MA
M<FYA;6X@;V<@<&%S<V]R9"(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C4Q"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N
M871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M
M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C$*;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#$*;7-G:60@(DEN9&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,C4T('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3,T"FUS9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,`IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@
M(DEN9F\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(U-PHC+"!F=7IZ>0IM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B1&EN
M(&EN9F]R;6%S:F]N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,S,`IM<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E
M<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G:60@(DEN<V5R="!);6%G92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`P"FUS9VED("));G-E<G0@5&%B;&4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I
M9"`B26YS97)T(%=E8B!,:6YK(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I9"`B
M26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I
M9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN
M(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R"FUS
M9VED("));G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F
M;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-S`*;7-G:60@
M(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E
M9F]R92!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E
M;7!L871E<RYP:'`Z,34P"FUS9VED("));G-E<G0@86QT97)N871E('1E;7!L
M871E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,SD*
M;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C
M86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X
M"FUS9VED("));G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Y"FUS
M9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`IM<V=I
M9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U"FUS9VED
M("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS97)T
M(&UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-0IM<V=I9"`B26YS97)T('!A
M<F%G<F%P:"!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R
M="!P87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*;7-G:60@(DEN
M<V5R="!R;W<@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T
M(')O=R!B969O<F4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(S,`IM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@
M=&AE('-E8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(V"FUS9VED("));G-E
M<G0O36]D:69Y($EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I
M9GD@3&EN:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B26YS=69F:6-I96YT(&-R
M961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S4*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-S4*;7-G:60@(DEN
M=&5G97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3$S,PIM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I
M9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3<P
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(P,0HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,3`*;7-G
M:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$R"FUS9VED("));G9A;&ED(&)A=&-H($E$+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#@W(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(S,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,CDY"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<*;7-G:60@
M(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,`IM<V=I
M9"`B26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HX,0HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,#`*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,C(P"FUS9VED("))
M;G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-S<*;7-G:60@(DEN=F%L:60@;&EC96YS92!K
M97DN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-S$*;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O=FED960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`S"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.38*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T
M97)S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z
M,C<*;7-G:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S,*;7-G:60@
M(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$W-0IM<V=I9"`B26YV86QI9"!P<F]D=6-T
M(&-O9&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O
M;"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HY,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C<Q(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z
M(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C$P-S8@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C8R"FUS9VED
M("));G9A;&ED('-H87)E(&]B:F5C="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@
M(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0IM<V=I
M9"`B26YV86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS-3<*;7-G:60@(DEN=F5N=&]R>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-C<Y"FUS9VED("));G9E<G0@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,@IM<V=I9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DER87$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@P"FUS9VED("))<F5L86YD(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F
M($UA;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O;&%T960@5"U3=&]R;7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,30@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<W)A96PB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C4*;7-G:60@
M(DES<W5E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET86QI8R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#(*(RP@9G5Z>GD*;7-G:60@(DET86QY(@IM<V=S='(@(D1A
M9VQE9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Q
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,SD*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM
M<V=I9"`B2F%N=6%R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@
M(DIA<&%N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W
M"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"FUS9VED("(B"B)*879A
M<V-R:7!T(&AA<R!B965N(&1I<V%B;&5D(&]N('EO=7(@8G)O=W-E<B!A;F0@
M=&AI<R!P86=E(&UA>2!N;W0@8F4@(@HB9&ES<&QA>6EN9R!C;W)R96-T;'DN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(R
M"B,L(&9U>GIY"FUS9VED(")*97)S97DB"FUS9W-T<B`B1W+E(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@S"FUS9VED(")*;W)D86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S
M=&EF>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3<*;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$V"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C8T"FUS9VED(")+965P
M(&]R:6=I;F%L/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*(RP@9G5Z>GD*
M;7-G:60@(DME;GEA(@IM<V=S='(@(DYE:W0B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VMR8C4N<&AP.C@U"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J
M96-T960@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS
M9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#$R"FUS9VED(")+97D@3&5N9W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0HC+"!F=7IZ>0IM<V=I9"`B2V5Y
M(%1Y<&4B"FUS9W-T<B`B34E-12UT>7!E(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.3@*(RP@9G5Z>GD*;7-G:60@(DME>2!5<V%G
M92(*;7-G<W1R(")-96QD:6YG(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-S0P"B,L(&9U>GIY"FUS9VED(")+97D@86QR96%D>2!E>&ES
M=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(D]P<&MO<&QI
M;F<@;6]T(&]F9F5N=&QE9R!N^&MK96QT96YA<B!N96MT82XB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,CD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@T"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E
M<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R
M96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@X"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@V"FUS9VED(")+=7=A:70B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@S"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P;W)T86PO;65N=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S"FUS9VED("),
M86YG=6%G92(*;7-G<W1R(")3<'+E:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B
M3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW-@IM<V=I9"`B
M3&%S="!087-S=V]R9"!#:&%N9V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S
M="!1=6%R=&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,34Q"B,L(&9U>GIY"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(D]P
M<&1A=&5R(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<R,0HC+"!P:'`M9F]R;6%T"FUS
M9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q-@IM<V=I9"`B3&%S="!L;V=I;CH@
M3F5V97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),871V:6$B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED
M("),87<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<Y"B,L(&9U>GIY"FUS9VED("),87EO=70B
M"FUS9W-T<B`B3&]G9R!U="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B
M;W)D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),96)A;F]N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B3&5F="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$Y"FUS9VED("),969T(&AE861E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$U
M"B,L(&9U>GIY"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R(")%:W-E;7!E
M;'9E<F1I87(Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),97-O=&AO(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F
M=7IZ>0IM<V=I9"`B3&5V96PB"FUS9W-T<B`B06QD<FDB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#@*;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS
M9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0HC+"!F=7IZ
M>0IM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R("),>7,@8FSE(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*(RP@9G5Z
M>GD*;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`B3&]G9R!I;FXB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B
M3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B!,
M871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M,`IM<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*(RP@
M9G5Z>GD*;7-G:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`B3'ES(&)LY2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED
M("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,30*(RP@9G5Z>GD*;7-G:60@
M(DQI;FLB"FUS9W-T<B`B3&]G9R!I;FXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@
M<&]I;G1S('1O.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.#<U"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H
M92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:'1M;#)T97AT+G!H<#HQ
M.#,*;7-G:60@(DQI;FMS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT-@IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED
M("),:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,PIM<V=I9"`B3&ES="!$871A8F%S
M97,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3`*
M;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B5FES(&5M;F4@9G+E
M($AJ96QP(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,@IM<V=I9"`B3&ES
M="!486)L97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](
M96%D97)S+G!H<#HU.30*;7-G:60@(DQI<W0M07)C:&EV92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4X.0HC+"!F
M=7IZ>0IM<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(E9I<R!E;6YE(&9RY2!(
M:F5L<"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DV
M"FUS9VED("),:7-T+4ED(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),:7-T+4]W;F5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DS
M"FUS9VED("),:7-T+5!O<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12](96%D97)S+G!H<#HU.3$*;7-G:60@(DQI<W0M4W5B<V-R:6)E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP
M:'`Z-3DP"FUS9VED("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(DQI
M<W1I;F<@878@8G)U:V%R87(@97(@<VSE='0@878N(@H*(SH@861M:6XO<V5S
M<VEO;G,N<&AP.C,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("),:7-T
M:6YG('5S97)S(&9A:6QE9#H@)7,B"FUS9W-T<B`B3&ES=&EN9R!A=B!B<G5K
M87)A<B!E<B!S;.5T="!A=BXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N
M;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N
M(@IM<V=S='(@(DQI<W1I;F<@878@8G)U:V%R87(@97(@<VSE='0@878N(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),:71E<F%T=7)E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&ET:'5A;FEA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEM86=E
M<RYP:'`Z.#,*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,0IM<V=I9"`B3&]C86P@=&EM
M93H@(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,PIM
M<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HV-`HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HV-0IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B
M(@H*(SH@;&]G:6XN<&AP.C$W,B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP
M:'`Z,3DQ('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C,*(SH@=&5M<&QA
M=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHY,`IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(DQO9V<@:6YN(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U"FUS9VED("),;V<@;V8@
M<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S:61E8F%R+G!H<#HQ.#4*;7-G:60@(DQO9R!O=70B"FUS9W-T
M<B`B3&]G9R!U="(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU.0HC+"!F
M=7IZ>0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`B3&]G9R!I;FXB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3`W"B,L(&9U>GIY"FUS9VED("),;V=I;B!4
M87-K<R(*;7-G<W1R(")/<'!GY79E<B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.CDY-@HC+"!F=7IZ>0IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U
M<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O
M<G)E8W1L>2XB"FUS9W-T<B`B(@HB2W5N;F4@878@96EN(&5L;&5R(&%N;F%N
M(&=R=6YN(&EK:VIE(&QO9V=E(&EN;BX@4V%N;G-Y;FQE9W9I<R!E<B!B<G5K
M87)N86UN("(*(F5L;&5R('!A<W-O<F0@=&%S=&$@:6YN(&9E:6PN(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DR"FUS9VED("),;V=I;B!F86EL
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S
M-C4*(RP@9G5Z>GD*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R("),;V=G('5T
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X"B,L(&9U>GIY"FUS9VED
M("),;W9E(@IM<V=S='(@(D9J97)N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(DQO=R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA
M;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,X
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R(")-
M32(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#$*;7-G:60@(DU/
M5$0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.148@071T86-H;65N="!C;VYT86EN
M960@;F\@9&%T82XB"FUS9W-T<B`B35,M5$Y%1BUV961L96=G(&EN;F5H96QD
M="!I;F=E;B!D871A+B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA8V%O(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%C961O;FEA+"!4:&4@1F]R;65R
M(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#D*(RP@9G5Z>GD*;7-G:60@(DUA9VEC(@IM<V=S='(@
M(D4M<&]S="(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX,0IM<V=I
M9"`B36%I;"(*;7-G<W1R(")%+7!O<W0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-3(R"FUS9VED(")-86EL($%D;6EN(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DUA;&%W:2(*;7-G<W1R(")%+7!O<W0B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.34*;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-30@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDR"B,L(&9U>GIY"FUS9VED(")-86QI(@IM<V=S='(@(D4M<&]S="(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B36%L=&$B"FUS9W-T<B`B
M12UP;W-T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ"FUS9VED("(B
M"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L
M86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@=VET
M:"!T:&]S92!C871E9V]R:65S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U,PIM<V=I9"`B36%P,C0@
M;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,#@T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,38X"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-
M87!P:6YG<R!S=&]R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#,*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED(")-87)C:"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0Q"B,L(&9U>GIY"FUS9VED(")-87)G:6XB"FUS9W-T<B`BQ71V
M87)I;F<B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L86=S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T
M86YT+T%N<W=E<F5D*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@
M(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS
M9VED(")-87)T:6YI<75E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")-871C:&EN9R!F:65L9',B"FUS9W-T
M<B`B4V%M<W9A<F%N9&4@9F5L="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%U
M<FET86YI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA=7)I
M=&EU<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I
M="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E
M>&-E961E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,#8*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y.`IM<V=I9"`B36%X('1E;7`@
M;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z.#8*
M;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DX(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R,3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(S.0IM<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-0HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0S"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*;7-G:60@
M(DUA>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")-87EO='1E
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,`IM<V=I
M9"`B365D:6-I;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]E9&ET+FEN8SHQ-@IM<V=I9"`B365M8F5R<R(*;7-G<W1R(")-961L
M96UM87(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<X"FUS9VED(")-
M96YU(&UO9&4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E(@IM<V=S='(@(DUE
M;&1I;F<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q
M-@IM<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T
M('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R
M:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q,`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G
M92!E>'!I<F5D+B(*;7-G<W1R(")-96QD:6YG(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V,`HC
M+"!F=7IZ>0IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(DUE;&1I;F<B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E871H
M97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I
M9"`B365T87(@8FQO8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3(*(RP@9G5Z>GD*;7-G:60@(B(*(DUE
M=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO
M9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(D1E=&%L:F%R
M(&5R(&QO9V=A(&9O<B!A9&UI;FES=')A=&]R96XN(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$V-0IM<V=I9"`B365T87)$0B!I<R!N;W0@
M8V]N;F5C=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C8W(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C@Q(&9R86UE=V]R:R]24$,O4E!#
M+W-O87`N<&AP.C$Q-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B365T
M:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R(")-971O9&4@)R5S
M)R!I:VMJ92!D969I;F5R="(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+W)E<W0N
M<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE
M9"X@0V%L;&5D(&UE=&AO9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C<T(&QI8B]";&]C:R]M971A<BYP:'`Z-S4*
M;7-G:60@(DUE=')I8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@
M(DUE>&EC;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N
M97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S8*(RP@
M9G5Z>GD*;7-G:60@(DUI9&1L92(*;7-G<W1R(")%+7!O<W0B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM
M92!4>7!E(@IM<V=S='(@(DU)344M='EP92(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S$P"FUS9VED(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#(*;7-G:60@(DUI
M;B!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#,Y"FUS9VED(")-:6YI;75M('!A<W-W
M;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S0*(RP@9G5Z
M>GD*;7-G:60@(DUI<G)O<B(*;7-G<W1R(")&96EL(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C<R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,T,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U
M97-T+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U
M"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O
M(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A
M<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`T"FUS9VED(")-:7-S:6YG(&UE
M<W-A9V4@240N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED(")-:7-S:6YG(')E
M<75I<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G
M:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C<T"FUS
M9VED(")-;V)I;&4@36%I;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B36]D97)A=&4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HV-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#@*;7-G:60@
M(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4S"FUS9VED(")-;V1I
M9GD@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C<S"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DT"FUS9VED(")-;VYT:"!A;F0@>65A
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E
M;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(DWE;F%D;&5G
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDT"FUS9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ
M-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z,3<R(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C(U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD<R!F;W5N
M9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@
M(DUO<W1L>2!#;&5A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS-`IM<V=I9"`B36]S=&QY($-L;W5D>2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS-0IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4P.0IM<V=I9"`B36]V
M92!$;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C4Q,PIM<V=I9"`B36]V92!,969T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4Q-PIM<V=I9"`B
M36]V92!2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HU,#4*;7-G:60@(DUO=F4@57`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`IM
M<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HU,C,*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`IM<V=I9"`B36]V92!U<"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-`IM<V=I9"`B
M375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#4U"FUS9VED
M(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C(T,@IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#`*;7-G
M:60@(DUY($%C8V]U;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C(X"B,L(&9U>GIY"FUS9VED(")->2!!8V-O=6YT($EN9F]R;6%T
M:6]N(@IM<V=S='(@(D1I;B!I;F9O<FUA<VIO;B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]I;F1E>"YP:'`Z-30*;7-G:60@(DUY(%!O<G1A;"(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z,3,V"FUS9VED(")->2!0
M;W)T86P@3&%Y;W5T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,34U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B
M37EA;FUA<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O
M;6%I;G1E;F%N8V4N:'1M;#HU-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E
M(@IM<V=S='(@(DY%22P@96<@97(@24M+2D4@<V%M9"(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,2!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3`R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(").86UE(@IM<V=S='(@(DYA;6XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDW"FUS9VED(").875R=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3<*;7-G:60@(DYE<&%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I
M9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@
M(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!"
M87-E(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!5
M4DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.#4*;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!54DPB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#0*
M;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S
M8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@4U-,
M('-E<G9E<B!N86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@W"FUS9VED(").971S8V%P92!C97)T:69I8V%T
M92!C;VUM96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@P"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!T
M>7!E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M-3$*;7-G:60@(DYE='=O<FLB"FUS9W-T<B`B3F5T='9E<FLB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,S-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V"FUS9VED
M(").979E<B(*;7-G<W1R(")!;&1R:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B
M3F5W($-A;&5D;VYI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G
M;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT
M97(O96UA:6QS+G!H<#HX,0HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL
M=&5R+V5M86EL<RYP:'`Z.#<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I
M;'1E<B]E;6%I;',N<&AP.CDW"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&
M:6QT97(O96UA:6QS+G!H<#HQ,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W
M($UE<W-A9V4@=&\@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,3<T"FUS9VED(").97<@36]O;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA
M;64@*&]P=&EO;F%L*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@
M(DYE=R!:96%L86YD(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B3F5W('!A<W-W;W)D(@IM
M<V=S='(@(E!A<W-O<F0B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP
M:'`Z,C(W"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!P87-S=V]R9"!W:6QL
M(&5X<&ER92!O;B`E>"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C4R"B,L(&9U>GIY"FUS9VED(").97<@<&%S<W=O<F1S
M(&1O;B=T(&UA=&-H+B(*;7-G<W1R(")087-S;W)D82!MY2!S86US=F%R92XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ
M"FUS9VED(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Y"B,L(&9U>GIY"FUS
M9VED(").97=S(@IM<V=S='(@(DYO=&%T87(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S`U"B,L(&9U>GIY"FUS9VED(").97=S9W)O=7!S(@IM
M<V=S='(@(D=R=7!P97(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN
M8SHQ-2!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT,0HC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHR-0IM<V=I9"`B3F5X="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,C<*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S(@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HS-S8*(RP@9G5Z>GD*;7-G:60@(DYE>'0@
M;W!T:6]N<R(*;7-G<W1R(")4:6QB86ME('1I;"!A;'1E<FYA=&EV(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HQ,#,*;7-G:60@(DYE>'0^(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEC87)A9W5A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B3FEG97(B"FUS
M9W-T<B`B06QD<FDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R:6$B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,X,`IM
M<V=I9"`B3FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").
M:75E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HY-C,*;7-G:60@(DYO(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM<V=I9"`B3F\@879A:6QA
M8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O
M<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+G!H<#HQ,#4*;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G>2!F
M;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B
M3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C<Y(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C(T-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HR-C<*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q
M=65S=&5D('!O<VET:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;6-A;"YP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(DYO(&-A;&5N9&%R
M(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(DEN9V5N(&MO;F9I9W5R87-J;VYS:6YF;W)M87-J;VX@<W!E<VEF:7-E
M<G0@9F]R(%-13"UA=71E;G1I<V5R:6YG+B(*"B,Z(&%D;6EN+W-E='5P+V1I
M9F8N<&AP.C4T"B,L(&9U>GIY"FUS9VED(").;R!C:&%N9V4N(@IM<V=S='(@
M(D%N9W)E(&5N9')I;F=A<B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,34V"B,L(&9U>GIY"FUS9VED(").;R!C:&EL9')E;B!C86X@8F4@
M861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R("(G)7,G('9A<G0@
M;&%G="!T:6P@=&EL9V%N9W-S>7-T96UE="XB"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$V-R!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P
M,@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW-S,*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B26YG96X@:V]N9FEG=7)A<VIO
M;G-I;F9O<FUA<VIO;B!S<&5S:69I<V5R="!F;W(@4U%,(%9&4RXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R-`HC+"!F=7IZ>0IM<V=I9"`B
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($94
M4"!61E,N(@IM<V=S='(@(DEN9V5N(&MO;F9I9W5R87-J;VYS:6YF;W)M87-J
M;VX@<W!E<VEF:7-E<G0@9F]R(%-13"!61E,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HV-CD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R("));F=E
M;B!K;VYF:6=U<F%S:F]N<VEN9F]R;6%S:F]N('-P97-I9FES97)T(&9O<B!3
M44P@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW
M,3<*(RP@9G5Z>GD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(DEN9V5N
M(&MO;F9I9W5R87-J;VYS:6YF;W)M87-J;VX@<W!E<VEF:7-E<G0@9F]R(%-1
M3"!61E,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,S0*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-S<*;7-G
M:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C<Q"FUS9VED(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$R."!L:6(O
M0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M,C,*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V.0IM<V=I9"`B3F\@;&]C
M871I;VX@<')O=FED960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").;R!M97-S
M86=E('-U<'!L:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@IM<V=I9"`B3F\@;F%M92!S
M<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS9VED(").;R!N=6UB97(@<W!E
M8VEF:65D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M.30*;7-G:60@(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.CDQ"FUS9VED(").;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HQ,#@*
M;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR
M8C4N<&AP.C<R"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R
M8F5R;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<V%S;"YP:'`Z-S<@9G)A;65W;W)K+T%U=&@O075T:"]L
M;V=I;BYP:'`Z.#0*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<U
M"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G
M:6X@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DEN9V5N(&MO;F9I9W5R87-J
M;VYS:6YF;W)M87-J;VX@<W!E<VEF:7-E<G0@9F]R(%-13"UA=71E;G1I<V5R
M:6YG+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%S<W=D+G!H<#HQ,S4*
M(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-3
M5T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DEN9V5N(&MO;F9I9W5R87-J
M;VYS:6YF;W)M87-J;VX@<W!E<VEF:7-E<G0@9F]R(%-13"UA=71E;G1I<V5R
M:6YG+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HX-`HC+"!F
M=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`B26YG96X@:V]N9FEG=7)A<VIO;G-I;F9O
M<FUA<VIO;B!S<&5S:69I<V5R="!F;W(@4U%,+6%U=&5N=&ES97)I;F<N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C@V"FUS9VED
M("(B"B).;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@
M5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I
M=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU
M<',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HW-3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0S"B,L(&9U>GIY"FUS9VED(").;R!R=6QE<R(*;7-G<W1R(").;W1A
M=&%R(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Y"FUS9VED
M(").;R!S97!A<F%T;W(@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T"B,L
M(&9U>GIY"FUS9VED(").;R!S:61E<R(*;7-G<W1R(").;W1A=&%R(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#,*;7-G:60@(DYO('-U8V@@
M9FEL92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3,X"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L
M92!F;W(@8V%C:&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"B,L(&9U>GIY"FUS9VED(").;R!U
M<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`B4VMR:78@
M:6YN(&1I='0@8G)U:V%R;F%M;B!O9R!P87-S;W)D(@H*(SH@9G)A;65W;W)K
M+U)00R]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO('9A;&ED(%A-3"!D
M871A(')E='5R;F5D(@IM<V=S='(@(DEN9V5N(&=Y;&1I9V4@6$U,+61A=&$@
M<F5T=7)N97)T(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.CDW,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.3@Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HY.3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$P,#D*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V97)S:6]N(&9O=6YD
M(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$R.`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R
M871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(W"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*(SH@
M=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,PHC+"!F=7IZ
M>0IM<V=I9"`B3F]N92(*;7-G<W1R(")496QE9F]N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I9"`B3F]N92`H
M=7-E(&EM<&QI8VET*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X.0IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDV"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K+VUO;VXN
M<&AP.C8P"FUS9VED(").;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,PIM<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0P
M"FUS9VED(").;W0@069T97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@(DYO="!"969O<F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#`X"FUS
M9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HV,PHC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H
M<#HX,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+G!H<#HY-`HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2YP:'`Z-3D*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV
M.`HC+"!F=7IZ>0IM<V=I9"`B3F]T('-E="(*;7-G<W1R(").;W1A=&%R(@H*
M(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H
M<#HQ-#,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD
M;&5R+G!H<#HQ-3@*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I
M;VY(86YD;&5R+G!H<#HQ-S,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R
M+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#<*(SH@9G)A;65W;W)K+U-E<W-I;VY(
M86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C`U(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C(T."!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C8U"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(Y-PHC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,S$R(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HS,CD*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,V,B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z-#(R"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU,#$@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C4W,`HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z-3@W(&9R86UE=V]R:R]61E,O5D93+G!H<#HV-C4*;7-G:60@(DYO
M="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR-#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T
M.C$P,#4*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$W.`IM<V=I9"`B
M3F]T97,B"FUS9W-T<B`B3F]T871A<B(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R
M+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A
M8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,3$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C<U"B,L(&9U>GIY"FUS9VED(").;W9E;6)E<B(*;7-G<W1R
M(")-961L96UM87(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#0V
M"B,L(&9U>GIY"FUS9VED(").=6UB97(B"FUS9W-T<B`B365D;&5M;6%R(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R-0IM<V=I9"`B3G5M8F5R
M(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3,V.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(S"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#4@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O9B!C
M;VQU;6YS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$S-C<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,0HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-#0S('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@;V8@<F]W<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U
M<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8T"FUS9VED
M(")/2R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.#<S"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*;7-G:60@(D]B:F5C="!#
M<F5A=&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Q,#0*;7-G:60@(D]C=&%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,3`*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B
M3V9F96YS92!F:6QT97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,R-@IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N
M97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*(RP@9G5Z>GD*;7-G
M:60@(D]L9"!P87-S=V]R9"(*;7-G<W1R(")087-S;W)D(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C0V"FUS9VED(")/;&0@<&%S<W=O<F0@
M:7,@;F]T(&-O<G)E8W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`HC+"!F
M=7IZ>0IM<V=I9"`B3VUA;B(*;7-G<W1R(")/<F%N<VIE(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@
M24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O
M9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3@U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<Q
M"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B
M(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y
M(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R
M(&$@<VAA<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z
M,S4*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/
M<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG
M;F5D(%,O34E-12!P87)T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P
M96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R871I;F<@4WES
M=&5M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ-3$*;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`B06QT97)N871I=B(*"B,Z
M('-E<G9I8V5S+W!R969S+G!H<#HS,2!T96UP;&%T97,O<')E9G,O87!P+FEN
M8SHQ-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@
M)7,B"FUS9W-T<B`B06QT97)N871I=B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4V-PHC+"!F=7IZ>0IM<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(D%D
M;6EN:7-T<F5R:6YG(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S,@HC+"!F=7IZ>0IM
M<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R(")/<F%N<VIE(@H*(SH@861M:6XO
M=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N
M('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E;7!L871E<R!I
M;B`E<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3`V"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3,Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#$*;7-G
M:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(D%N;F%N(&EN9F]R;6%S
M:F]N(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,0HC+"!F=7IZ
M>0IM<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B5&EL9V%N9R(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW.0IM<V=I9"`B4$%-
M(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P
M-0IM<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$R-S,*;7-G:60@(E!'4"!$
M:6=I=&%L(%-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,S$Y"FUS9VED(")01U`@16YC<GEP=&5D($1A
M=&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,3,W,0IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,U,PIM<V=I9"`B4$=0
M(%-I9VYE9"]%;F-R>7!T960@1&%T82(*;7-G<W1R("(B"@HC.B!A9&UI;B]P
M:'!S:&5L;"YP:'`Z-C@*(RP@9G5Z>GD*;7-G:60@(E!(4"!#;V1E(@IM<V=S
M='(@(DAO<F1E(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED(")0
M2%`@4VAE;&PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S<*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S@*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%-N;W<B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#`*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,0HC+"!F
M=7IZ>0IM<V=I9"`B4$T@4W5N(@IM<V=S='(@(E-O;"(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0R"FUS9VED(")032!4+5-T
M;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C<T
M"FUS9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9R(*;7-G<W1R("(B
M"@HC.B!L:6(O87!I+G!H<#HQ-#D*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3D*;7-G:60@(E!A:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G
M:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDX"FUS9VED(")086YA;6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDY"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED
M(")087)T;'D@0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34Q(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(P,3@*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHW-R!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C,*;7-G:60@(E!A<W-W;W)D(@IM
M<V=S='(@(E!A<W-O<F0B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C$S,C(*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G
M<W1R(")087-S;W)D(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N
M<&AP.C$U,@IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`U,PIM<V=I9"`B4&%S<W=O<F0@=VET:"!C;VYF:7)M871I
M;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.CDP"B,L(&9U>GIY"FUS9VED(")087-S=V]R9#HB"FUS9W-T<B`B4&%S<V]R
M9"(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"B,L(&9U>GIY
M"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(E!A<W-O<F0B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ-3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`S-`HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS9VED(")0
M87-S=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`B4&%S<V]R9&$@;>4@<V%M
M<W9A<F4N(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Q.2!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G:60@
M(E!A<W1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F5Q=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P
M<SHB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T"B,L
M(&9U>GIY"FUS9VED(")096]P;&4B"FUS9W-T<B`B4F]L;&4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B
M4&5R8V5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O
M;6%I;G1E;F%N8V4N:'1M;#HT.0IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC
M92!/<&5R871I;VYS(@IM<V=S='(@(DOX>7(@=F5D;&EK96AA;&1S;W!E<F%S
M:F]N87(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#`V"FUS9VED(")0
M97)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S
M='(@(DOX>7(@=F5D;&EK96AA;&1S;W!E<F%S:F]N87(@=F5D(&EN;FQO9V=I
M;F<_(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*(RP@
M9G5Z>GD*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B5&EL9V%N9R(*"B,Z
M(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@V"B,L(&9U>GIY"FUS
M9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R(")4:6QG86YG(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C$@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ-C0*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S
M='(@(E1I;&=A;F<B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#D@861M
M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P"B,Z(&%D;6EN+W!E<FUS+VEN9&5X
M+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X"FUS9VED(")097)M
M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")4:6QG86YG<V%D;6EN
M:7-T<F5R:6YG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U"B,L(&9U
M>GIY"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R(")!;FYA
M;B!I;F9O<FUA<VIO;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G:60@(E!E
M=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0:&EL:7!P:6YE
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G<W1R(")496QE9F]N(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W.`IM<V=I9"`B4&AO=&]S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DP
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A:7)N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4V"FUS9VED(")0;&%T:71U9&5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#D*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@
M>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O
M('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(U-S$*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO
M;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C$R"FUS9VED(")0;&5A<V4@96YT
M97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`Q"FUS9VED(")0;&5A<V4@
M96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8P"FUS9VED(")0;&5A<V4@96YT97(@
M82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE
M(&UO;G1H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-#4Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS
M9VED(")0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN
M(@IM<V=S='(@(E-K<FEV(&EN;B!E:70@<V%M86YD<F%G(&%V('!R;V)L96UE
M="XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO
M=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM<V=S='(@(E-K<FEV(&EN;B!D
M:71T(&)R=6MA<FYA;6X@;V<@<&%S<V]R9"(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HU.`HC+"!F=7IZ>0IM<V=I9"`B(@HB4&QE87-E(')E860@
M=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T
M97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B(@HB5F5R('9E
M;FQE9R!O9R!L97,@9OAL9VIA;F1E('1E:W-T+B!$=2!-Q2!V97)E('-A;60@
M;65D('9I;&OE<F$@9F]R(.4@8G)U:V4@(@HB<WES=&5M970N(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S`*;7-G
M:60@(E!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93HB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0;VQA;F0B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@W"FUS
M9VED(")0;VQL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0
M;W)T=6=A;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N
M:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N
M:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@(E!O<W0@=&\@=&AI
M<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V-B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L
M87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,CDX"FUS9VED(")0<F5C:7!I=&%T:6]N/&)R("\^
M8VAA;F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]L
M9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@(E!R969S7W-E<W-I
M;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C4*;7-G:60@(E!R
M97-S=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Y
M"FUS9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ("(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,U"FUS9VED(")0<F5S
M<W5R93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(S"FUS9VED(")0<F5V:65W(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@
M:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,S8R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,S8V"B,L(&9U>GIY"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S
M='(@(E!R97-E;G1A<VIO;F%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S
M"FUS9VED(")0<FEV871E($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O365N=2YP:'`Z,38Y"B,L(&9U>GIY"FUS9VED(")0<F]B
M;&5M(@IM<V=S='(@(EM0<F]B;&5M<F%P<&]R=%TB"@HC.B!S97)V:6-E<R]P
M<F]B;&5M+G!H<#HQ,C8*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS
M9W-T<B`B4VMI;&1R:6YG(&%V('!R;V)L96UE="(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS-CD*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,3$@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C$X.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,C@U"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0T"FUS9VED
M(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I=F%T92!K
M97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")/
M9F9E;G1L96<O<')I=F%T(&[X:VME;'!A<B!V87)T(&EK:VIE(&=E;F5R97)T
M+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DQ(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DV(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E%A=&%R(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HV,PIM<V=I9"`B475E<GDB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"FUS9VED(")1=6]T82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME>2`H)60@
M8FET*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,C8T"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#,*;7-G:60@(E)A
M:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#0*;7-G:60@(E)A:6X@16%R;'DB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@
M(E)A:6X@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#<*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@
M=&\@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,PIM<V=I9"`B4F%N9&]M($9O<G1U;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV."!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]Z:7`N<&AP.C<V"FUS9VED(")2871I;R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-"!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,0HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-"!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$S-PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,`IM
M<V=I9"`B4F5A9"(*;7-G<W1R("),97,B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HX-PHC+"!F=7IZ>0IM<V=I9"`B4F5A9"!M
M97-S86=E<R(*;7-G<W1R(")-96QD:6YG(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL
M>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN
M8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D
M871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD
M;VYE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C=&EO
M;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ
M-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")2969R
M97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,T,0HC+"!F=7IZ>0IM<V=I9"`B4F5F<F5S
M:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`B1G)I<VL@;W!P(&]V97)S:6MT=FES
M:6YG.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-"!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C$S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R,S4*(RP@9G5Z>GD*;7-G:60@(E)E9V5X(@IM<V=S='(@(DYU;&QS
M=&EL;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-#D*;7-G:60@
M(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR,#@*(RP@9G5Z>GD*;7-G:60@(E)E;&]A9"(*;7-G<W1R("),97,B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R-@IM<V=I9"`B4F5M87)K<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$T"B,L(&9U
M>GIY"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R(")&:F5R;B(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM<V=I9"`B4F5M;W1E
M(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,PIM<V=I9"`B4F5M;W9E
M(@IM<V=S='(@(D9J97)N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N
M:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")296UO=F4@0FQO8VLB"FUS9W-T<B`B
M1FIE<FXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-34W"B,L(&9U>GIY"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@
M(D9J97)N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHT,`HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS
M9W-T<B`B1FIE<FX@<&%R(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN
M8SHQ,C@*;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@(D9J97)N('!A<B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,#(*;7-G:60@(E)E;6]V92!S
M879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#(*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!T
M:&4B"FUS9W-T<B`B1FIE<FXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(E)E;6]V92!T:&ES
M(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B
M4F5M;W9E('5S97(B"FUS9W-T<B`B1FIE<FX@<&%R(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHU"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")296UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B1FIE<FX@<&%R(@H*
M(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ,S@*(RP@9G5Z>GD*
M;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D
M(&5R<F]R8V]D93H@(@IM<V=S='(@(DMU;FYE(&EK:VIE('-V87)E('#E(&;X
M<F5S<'5R;F%D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U
M-PHC+"!F=7IZ>0IM<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T
M(&)E(&9O=6YD+B(*;7-G<W1R(")+=6YN92!I:VMJ92!S=F%R92!PY2!F^')E
M<W!U<FYA9"(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<T(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$R"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E
M<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(").^&1V96YD:6<@)W1A8FQE)R!I
M:VMJ92!S<&5S:69I<V5R="!I(&MO;F9I9W5R87-J;VX@9F]R(%9&4RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8W-2!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C@S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z-S(S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E
M9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B3OAD=F5N9&EG("=T86)L92<@:6MK:F4@<W!E<VEF:7-E<G0@
M:2!K;VYF:6=U<F%S:F]N(&9O<B!61E,N(@H*(SH@9G)A;65W;W)K+U5T:6PO
M571I;"YP:'`Z-S@Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U
M:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R(").^&1V96YD:6<@)W1A8FQE)R!I:VMJ92!S<&5S:69I<V5R="!I
M(&MO;F9I9W5R87-J;VX@9F]R(%9&4RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+U)E;F1E<F5R+G!H<#HS,S4*;7-G:60@(E)E<75I<F5D($9I96QD(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,S.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R
M+G!H<#HS,C`@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<W"FUS9VED(")297-E
M="(*;7-G<W1R(").=6QL<W1I;&PB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HT-@HC+"!F=7IZ>0IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS
M9W-T<B`B4&%S<V]R9"(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C(W"B,L(&9U>GIY"FUS9VED(")297-E="!9;W5R(%!A<W-W;W)D(@IM<V=S
M='(@(E-T861F97-T('!A<W-O<F0B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3,P"FUS9VED(")297-T;W)E($QA<W0@475E<GDB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<&AP<VAE;&PN<&AP.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A
M9&UI;B]S<6QS:&5L;"YP:'`Z-C8*(RP@9G5Z>GD*;7-G:60@(E)E<W5L=',B
M"FUS9W-T<B`B3G5L;'-T:6QL(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C$P,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2
M971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R(")4:6QB86ME('1I;"!A;'1E<FYA
M=&EV(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED
M(")2971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#(*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS9VED
M(")2979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3,R"B,L(&9U>GIY"FUS9VED(")2:6-H(%1E>'0@
M161I=&]R($]P=&EO;G,B"FUS9W-T<B`B5&EL8F%K92!T:6P@86QT97)N871I
M=B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C$*;7-G:60@(E)I9VAT(&AE
M861E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,3$W"B,L(&9U>GIY"FUS9VED(")2:6=H="!V86QU97,B"FUS9W-T<B`B3'ES
M(&)LY2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?=R!0<F]P97)T:65S+BXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HR,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`B4F]L;&4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`R"FUS9VED(")2;VUA;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,C4*;7-G:60@(E)O=&%T92`Q
M.#`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(R,@IM<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R.`IM
M<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O
M=R!0<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P<F]P
M97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4S"B,L(&9U>GIY"FUS9VED(")2=6QE<R(*;7-G<W1R(")2;VQL92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@
M86YD(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R,`HC+"!F=7IZ
M>0IM<V=I9"`B4G5N(@IM<V=S='(@(E-O;"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G
M:60@(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`S"B,L(&9U>GIY"FUS9VED(")2=V%N9&$B"FUS9W-T<B`B3&5S(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O
M34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-
M24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T:&5N=&EC
M871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C4P-`HC+"!F=7IZ>0IM<V=I9"`B4TU3($UE
M<W-A9VEN9R(*;7-G<W1R(")-96QD:6YG(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C(Q"FUS9VED(")344P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,PIM<V=I9"`B4U%,('-T871E;65N="!F
M;W(@=F%L=64@;&]O:W5P<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#,Q"FUS9VED(")34T@B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B
M:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R("(B"@HC.B!L:6(O
M87!I+G!H<#HQ-3,*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0IM<V=I
M9"`B4V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@
M2&5L96YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B4V%I;G0@
M2VET=',@86YD($YE=FES(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I
M9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I
M9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$U"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D
M:6YE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CDR"FUS9VED(")386UE(&9R86UE("A?<V5L9BDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B4V%M;V$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`W"FUS9VED(")386\@5&]M92!A;F0@4')I;F-I<&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M.0IM<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R86)I82(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3@*(RP@9G5Z>GD*;7-G:60@
M(E-A=F4B"FUS9W-T<B`B3&%G<F4@)R5S)R(*"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O961I="YI;F,Z-#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(DQA9W)E("<E<R<B"@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R("),86=R92`G)7,G(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM
M<V=S='(@(DQA9W)E(&%L=&5R;F%T:78B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,38W"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T
M:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R
M>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.CDS"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P
M9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"FUS9VED(")38V%T
M=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4Y"FUS9VED(")38VEE;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C$V"FUS9VED(")396%R8V@B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R,`IM<V=I9"`B4V5A<F-H($5N
M9VEN97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,CDW,PIM<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#0*(RP@9G5Z>GD*
M;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B5F5L(&1A=&]F;W)M870Z
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.3@*;7-G:60@(E-E
M;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C0S"FUS9VED(")396QE8W0@82!N97<@;W=N97(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P
M"FUS9VED(")396QE8W0@82!S97)V97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C="!A('5S97(@
M=&\@861D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HV-S<*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,PHC+"!F=7IZ>0IM
M<V=I9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@(E9E
M;"!D871O9F]R;6%T.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HX-S,*;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C8W.`IM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O:V5Y8F]A<F0N<&AP.C,W"B,L(&9U>GIY"FUS9VED("(B"B)396QE8W0@
M=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N
M(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE
M('1E>'0@87)E82XB"FUS9W-T<B`B(@HB5F5L('1E:6MN82!D=2!T<F5N9R!F
M<N4@8F]K<V%N92!U;F1E<BX@1'4@:V%N('/E(&MO<&EE<F4@;V<@;&EM92!D
M96D@:6YN(&9RY2`B"B)T96MS=&)O:W-A+B(*"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C,T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R
M.B(*;7-G<W1R(")696P@<VMI;&IE=&5I:VX@9F]R(&1A=&\Z(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T
M92!F;W)M870Z(@IM<V=S='(@(E9E;"!D871O9F]R;6%T.B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3`*;7-G:60@(E-E;&5C
M="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I
M9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B5F5L('-K
M:6QJ971E:6MN(&9O<B!D871O.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N
M:6YC.C(U"FUS9VED(")396QE8W0@=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R
M(")696P@=&ED<V9O<FUA=#HB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C4W"FUS9VED(")396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS
M9W-T<B`B5F5L('1O('-A;7-V87)A;F1E(&9E;'0N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,P-@IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H
M96UE+B(*;7-G<W1R(")696P@9F%R9V5S:VIE;6$N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(T.`IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D
M(&QA;F=U86=E.B(*;7-G<W1R(")696P@^&YS:V$@<W!RY6LZ(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O
M8FQE;2!297!O<G0B"FUS9W-T<B`B4V5N9"!P<F]B;&5M<F%P<&]R="(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#,Y"FUS
M9VED(")396YD(%--4R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED
M(")396YE9V%L(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S$V"FUS9VED(")396YS;W(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Y"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PHC+"!F=7IZ>0IM<V=I9"`B
M4V5P=&5M8F5R(@IM<V=S='(@(DUE9&QE;6UA<B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD($UO
M;G1E;F5G<F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HW,#$*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,0IM<V=I9"`B
M4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(W"B,L(&9U>GIY"FUS9VED(")3
M97-S:6]N($%D;6EN(@IM<V=S='(@(E1I;&=A;F=S861M:6YI<W1R97)I;F<B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E9"XB"FUS9W-T<B`B(@H*
M(SH@;&EB+V%P:2YP:'`Z,30U"B,L(&9U>GIY"FUS9VED(")397-S:6]N<R(*
M;7-G<W1R(")4:6QG86YG(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C,Q-`IM<V=I9"`B4V5T(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HW-@IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O
M(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED
M(")3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E
M<W,@9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@T"B,L(&9U>GIY"FUS9VED(")3970@>6]U<B!P<F5F
M97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM
M<V=S='(@(E9E;"#X;G-K82!S<'+E:SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.3@*(RP@9G5Z>GD*;7-G:60@(B(*(E-E="!Y;W5R('-T87)T=7`@
M87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A
M;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R(")3970@9F%R
M9V5S:VIE;6$L('-I9&5O<'!F<FES:VEN9R!O9R!A;F1R92!V:7-I;F=S86QT
M97)N871I=BXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<U"FUS9VED
M(")3971U<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O
M:6YD97@N:'1M;#HS-PIM<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V
M86EL86)L92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,3@V"FUS9VED(")3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W
M:71H('1H92!P87)A;65T97(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T
M"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT.38*;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S"B,L(&9U>GIY
M"FUS9VED(")3:&]R="!3=6UM87)Y(@IM<V=S='(@(DMO<G0@<V%M86YD<F%G
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#8*;7-G:60@(E-H;W5L
M9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R,R!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C,S"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z-C<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,`HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,R!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$S-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W
M.0IM<V=I9"`B4VAO=R(*;7-G<W1R(")6:7,B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,34U"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E
M96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*
M(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT.3`*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@
M;&]G9VEN9R!I;C\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3<V-0IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA
M;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$S
M"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3(V"FUS9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@
M;65N=2!B87(_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O
M;B!T:&4@;&5F=#\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H
M92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV-`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@
M4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")3
M:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8S"FUS9VED(")3:&]W('5P
M;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R
M(")6:7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU,0IM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4VAO
M=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I
M;FET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HT.#`*;7-G:60@(E-H<FEN:R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW-S0@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z.#,V"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.CDR,B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HY.#0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z,3`T-R!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,#@W
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q,38@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$T.0IM<V=I9"`B4VAR
M:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@
M=V%Y(&9I<G-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-I
M97)R82!,96]N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,C8U"FUS9VED(")3:6=N('5P(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED(")3
M:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HW,3$*;7-G:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C4@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@W(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C@Y-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C$U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S<*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.3,P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C,*;7-G:60@
M(E-I>F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA
M:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS
M9W-T<B`B2&]P<"!O=F5R('9E9&QI:V5H86QD(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM
M<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I
M9"`B4VQO=F5N:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(E-N;W<B"FUS
M9W-T<B`B5FES(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-34*;7-G:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V"FUS9VED(")3
M;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S@*;7-G:60@(E-N;W<@9&5P
M=&@Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X,@IM
M<V=I9"`B4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED(")3;VYG<R`F(%!O
M96US(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y
M,C8*;7-G:60@(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3@Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Q-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR-#<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HQ.#D*(RP@9G5Z>GD*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM<V=S='(@
M(D%D<F5S<V4L(&%R8F5I9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(E-O=71H
M($%F<FEC82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y
M,`IM<V=I9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE
M(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM<V=I9"`B
M4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@
M8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A
M8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX,34*;7-G:60@(E-P
M86-E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4U"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#`*;7-G:60@(E-P86-I;F<B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDX"FUS9VED(")3<&%M(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA
M;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`B26YN=&%S=&EN9R!A=B!S<&5S
M:6%L=&5I:VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS
M9VED(")3<&QI="!R;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C8Q"B,L(&9U>GIY"FUS9VED(")3<&]R=',B"FUS9W-T<B`B26UP
M;W)T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@X"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<S(&QI8B]";&]C
M:R]M971A<BYP:'`Z-S0*(RP@9G5Z>GD*;7-G:60@(E-T86YD87)D(@IM<V=S
M='(@(B5S(%-T86YD87)D(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8R
M"FUS9VED(")3=&%R(%1R96LB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C4Y-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`Y
M"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED(")3=&%T92!O<B!0<F]V
M:6YC92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD
M97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(X,34*(RP@9G5Z>GD*;7-G:60@(E-T;W)A
M9V4@9F]R;6%T(@IM<V=S='(@(D1I;B!I;F9O<FUA<VIO;B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<R"B,L(&9U>GIY"FUS9VED
M(")3=')E970@061D<F5S<R(*;7-G<W1R(")!9')E<W-E+"!A<F)E:60B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q"FUS
M9VED(")3=')I:V5T:')O=6=H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$R,S,*;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S,*;7-G:60@(E-T
M<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*
M;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*(RP@9G5Z>GD*;7-G:60@
M(E-U(@IM<V=S='(@(E-O;"(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS
M-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB
M)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(D9A;FX@:6MK:F4@=F%R<V5L;'ET
M=&%R("5S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R
M,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S,R(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N
M9&5R97(N<&AP.C,Q-PIM<V=I9"`B4W5B;6ET(@IM<V=S='(@(B(*"B,Z('-I
M9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D
M(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N
M(&YO="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P
M<')O=F5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P-`HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X
M"FUS9VED(")3=6-C97-S(@IM<V=S='(@(E-U:W-E<W,B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HX-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S
M<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G<W1R("),
M82!T:6P@)R5S)R!T:6P@<WES=&5M970N(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,3(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M8VQE87)E9"!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TN
M(@IM<V=S='(@(D9J97)N82`G)7,G(&9RY2!S>7-T96UE="XB"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE=&5D
M(%PB)7-<(BXB"FUS9W-T<B`B4VQE='1A("<E<R<N(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3`U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S
M9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R
M(")&:F5R;F$@)R5S)R!F<N4@<WES=&5M970N(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O
M;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C4W"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*;7-G
M<W1R(")3;&5T=&$@)R5S)RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@(E-L
M971T82`G)7,G+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*(RP@9G5Z>GD*;7-G:60@(E-U
M9&%N(@IM<V=S='(@(E-O;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*(RP@9G5Z>GD*;7-G:60@(E-U;6UA
M<GDB"FUS9W-T<B`B36ET="!S86UA;F1R86<B"@HC.B!L:6(O0FQO8VLO<W5N
M<FES92YP:'`Z-C4*;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HV.`HC+"!F=7IZ>0IM<V=I9"`B4W5N(%-E
M="(*;7-G<W1R(")3;VPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B4W5N;GDB"FUS9W-T<B`B
M4V]L(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-@HC+"!F
M=7IZ>0IM<V=I9"`B4W5N<FES92(*;7-G<W1R(")3;VPB"@HC.B!L:6(O0FQO
M8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,38*;7-G
M:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,34*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Y"B,L(&9U
M>GIY"FUS9VED(")3=6YS970B"FUS9W-T<B`B4V]L(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(Q.`IM<V=I9"`B4W5N<V5T.B`B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,W.`HC+"!F=7IZ>0IM<V=I9"`B4W5P<&]R
M="(*;7-G<W1R("));7!O<G0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"B,L(&9U>GIY"FUS
M9VED(")3=7)I;F%M92(*;7-G<W1R(")"<G5K87)N86UN(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S0*(RP@9G5Z>GD*;7-G:60@
M(E-U<FYA;64B"FUS9W-T<B`B0G)U:V%R;F%M;B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*
M;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P.`IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,@IM<V=I
M9"`B4WEN8TU,(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME
M>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T
M97)M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")3>7)I86X@
M07)A8B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV,`IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M,0IM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E0M
M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8S"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,38V"B,L(&9U
M>GIY"FUS9VED(")44U8@9FEL92(*;7-G<W1R(")4:71T96PB"@HC.B!F<F%M
M97=O<FLO54DO54DO5&%B;&4N<&AP.C$S-`HC+"!F=7IZ>0IM<V=I9"`B5&%B
M;&4B"FUS9W-T<B`B5&ET=&5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@4')O<&5R
M=&EE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O
M=&%B;&5S970N<&AP.C4W"FUS9VED(")486)L92!3970B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-"!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$Q"FUS9VED(")486EW86XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A
M:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VAO
M;VMS+G!H<"YD:7-T.CDY-B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@W
M"FUS9VED(")487-K<R(*;7-G<W1R(")/<'!GY79E<B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")496QE<&AO;F4@
M3G5M8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDP
M"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(Q-`IM<V=I9"`B5&5M<&5R871U<F4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,PIM
M<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,CDS"B,L('!H<"UF;W)M870*;7-G:60@(E1E
M;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HV.#<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N
M9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*(RP@
M9G5Z>GD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(D)R=6MA<F%D;6EN:7-T<F5R:6YG(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(Q,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,V"FUS9VED
M(")497AT(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-S4*;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<T"FUS9VED(")4
M97AT(&%L:6=N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU
M.0IM<V=I9"`B5&@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.3$*;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#D*;7-G:60@(E1H86EL86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.CDX.`HC+"!F=7IZ>0IM<V=I9"`B5&AA;FL@
M>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+B(*;7-G<W1R(")$=2!E<B!L;V=G
M82!U="X\8G(@+SY486MK(&9O<B!A="!D=2!B<G5K87(@9&5T=&4@<WES=&5M
M970N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,C`*;7-G:60@
M(E1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,T"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I
M;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%])35-0+TE-4U`O0F]O:RYP:'`Z,3(Y,@IM<V=I9"`B5&AE
M($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@
M36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY
M(@IM<V=S='(@(DML87-S82!-86EN=&5N86YC93HZ('9A<G0@:6MK:F4@;&%S
M=&$@:6YN(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR
M.0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I
M;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,3@Y(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,C$Q(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,C(S"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C,T(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,C8T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S`S"FUS
M9VED("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@
M82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N
M="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@
M(E1H92!B;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B
M"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE
M9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL
M>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V.0IM<V=I9"`B(@HB
M5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@
M=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#$*
M;7-G:60@(B(*(E1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R
M(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN
M('1H92!D871A8F%S92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*;7-G:60@(E1H92!D:7-T
M<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+G!H<#HQ,3,*;7-G:60@(E1H92!E
M;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE
M8W1I;VXN(@IM<V=S='(@(DMR>7!T97)I;F=S9G5N:W-J;VYA;F4@:W)E=B!E
M:2!S:6MK97(@;F5T=&]P<&MO<&QI;F<N(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ-S4@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A
M:6X@82`E<R!S971T:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$V."!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N
M=&%I;B!S;VUE("5S('-E='1I;F=S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR,3D*;7-G:60@(E1H92!F:6QE(&-A;B!N
M;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1&%T82]$871A+G!H<#HR.#`*(RP@9G5Z>GD*;7-G:60@(E1H92!F
M:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")-4RU43D5&+79E9&QE
M9V<@:6YN96AE;&1T(&EN9V5N(&1A=&$N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN
M9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S
M<V%G92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO
M9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%
M>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N
M)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@
M(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@
M86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y
M<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G
M;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@86YD(&YE
M960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE
M87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@
M9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M<F5F<RYP:'`Z.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y
M(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<V"FUS
M9VED(")4:&4@;&5F="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ-3<*;7-G:60@(B(*(E1H
M92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@
M=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J
M96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO
M(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@
M=6YD97)S=&]O9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@W-PIM<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN
M9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C0T,0HC+"!F=7IZ>0IM<V=I9"`B5&AE(&YU
M;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*;7-G<W1R(")$96YN
M92!V97)D:65N(&WE('9E<F4@96ET('1A;"XB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S$*;7-G:60@(E1H92!O<&5N<W-L(&UO
M9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@
M8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP
M:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E
M(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E
M>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D96(N<&AP.C,R
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS
M-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N
M<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP
M:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<G!M+G!H<#HS
M,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]W96)C<'`N<&AP.C,W
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H
M<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<V5X8V5L+G!H
M<#HS,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R
M86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F
M;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R("(B"B)&86YN(&EK:VIE('!R
M;V=R86UM970@<V]M(&)R=6MA<W0@=&EL(.4@=FES92!D96YN92!T>7!E;B!M
M96QD:6YG87(@*"5S*2XB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HT-30*;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@
M<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE
M(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM
M<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T-@IM<V=I9"`B5&AE('-E
M<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE
M=&5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H
M<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H
M87,@8F5E;B!S879E9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F
M;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,S,P"FUS9VED(")4:&4@<W!E
M8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ-S<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Q,0IM
M<V=I9"`B5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@
M=&5X="!O;B!T:&4@<V-R965N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED(")4
M:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P
M"FUS9VED(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1&%T82]$871A+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO861E9"!D
M871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R86UE
M=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO861E
M9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0V(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HU-@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3$U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,3D*;7-G:60@(E1H
M92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R
M("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$W
M.`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA
M8FQE+B(*;7-G<W1R("));F=E;B!I;FYS=&EL;&EN9V%R(&5R('1I;&=J96YG
M96QE9V4N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z
M,S0R"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES
M<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,30P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A
M<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V
M92!E;G1E<F5D("5S(&-H87)A8W1E<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE
M<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI
M;B]U<V5R+G!H<#HW,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@7"(E<UPB('1O('1H92!S>7-T96TZ
M("5S(@IM<V=S='(@(E!R;V)L96T@;65D(.4@;&5G9V4@=&EL("<E<R<@=&EL
M('-Y<W1E;65T+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN
M9R!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G
M<W1R(")0<F]B;&5M('9E9"!F:F5R;FEN9R!A=B`G)7,G(&9RY2!S>7-T96UE
M="XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#,*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB
M(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(E!R;V)L96T@=F5D(&9J97)N
M:6YG(&%V("<E<R<@9G+E('-Y<W1E;65T+B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$U.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@
M<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z("5S(@IM<V=S='(@(E!R;V)L96T@
M;65D(.4@;&5G9V4@=&EL("<E<R<@=&EL('-Y<W1E;65T+B(*"B,Z(&9R86UE
M=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D
M.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D
M.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*(F%L;&]W
M960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0G)O=W-E<B]"<F]W<V5R+G!H<#HX.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@
M5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HS
M-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M
M97-S86=E('!A<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1&%T82]$871A+VEM8RYP:'`Z,S$*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C@P"FUS9VED("(B
M"B)4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R
M;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P
M97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N
M+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`IM
M<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT
M86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M,C(R"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE
M(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HQ-#@*;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P
M<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E
M<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@
M>FEP(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,Q-#4*(RP@9G5Z>GD*;7-G:60@(E1H:7,@9&]E<R!N;W0@<V5E;2!T
M;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R(")$96YN92!V97)D
M:65N(&WE('9E<F4@96ET('1A;"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*;7-G:60@(B(*(E1H:7,@9')I
M=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L
M:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@
M=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED("(B"B)4:&ES(&1R
M:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!7
M24X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y+"!U<VEN9R!T:&4@
M2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G:60@(B(*(E1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E
M;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG
M('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@
M=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@(@HB9V%T97=A>2P@;VYL>2!T
M;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O
M=6YT('=I=&@@(@HB5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET
M*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3<X
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-3<*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3`X-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3$U
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#(@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(U-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,S`U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S.3@*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,34U-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.#,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-3@@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C`P-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,#(Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-S@*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C$T.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,C(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3`@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C0U-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-C4W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,C@*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S-R!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,S`V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,30@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@R,@IM<V=I9"`B5&AI<R!F:65L9"!I
M<R!R97%U:7)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3`V-0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN
M(&EN=&5G97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-#$X"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@
M;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,#DT"FUS9VED(")4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(S"FUS9VED(")4:&ES(&9I96QD(&UU
M<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E
M9V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY
M.#D*(RP@9G5Z>GD*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED
M(&YU;6)E<BXB"FUS9W-T<B`B1&5N;F4@=F5R9&EE;B!MY2!V97)E(&5I="!T
M86PN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@S-@IM<V=I9"`B
M(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H
M92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU-C$*;7-G
M:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I
M97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE
M;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA
M="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E
M('9I<VET("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C4Y,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE
M<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H
M97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@
M8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R(")$971T92!T86QE="!MY2!V97)E
M(&UI;G-T(&5I;BXB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E
M<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$X.0IM<V=I9"`B5&AI<R!S
M>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI
M<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R(")$96YN92!V97)D
M:65N(&WE('9E<F4@96ET('1A;"XB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L
M;W)P:6-K97(N<&AP.C,U"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A
M;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4
M:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR,S0*;7-G:60@(E1I8VME=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C0R."!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-34*(RP@9G5Z>GD*;7-G:60@(E1I;64B"FUS9W-T<B`B5&ET=&5L(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X-@IM<V=I9"`B5&EM92!4
M<F%C:VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3<*
M;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(U,SD*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HR,CD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM
M<V=S='(@(E1I='1E;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U-`IM<V=I9"`B(@HB5&\@<V5L96-T
M(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O
M<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I
M9"`B5&]D87DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1O9V\B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA=2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$S"FUS9VED(")4
M;VUO<G)O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VYG
M82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S<*;7-G:60@(E1O<"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED
M(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B5')A;G-L871I;VYS(@IM
M<V=S='(@(E!R97-E;G1A<VIO;F%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B
M5')I;FED860@86YD(%1O8F%G;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-SDP"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G
M:60@(E1U;FES:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0HC+"!F=7IZ
M>0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(D=RY2(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DR"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=7)K;65N:7-T86XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B5'5R:W,@86YD($-A:6-O
M<R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U
M=F%L=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C8T
M"FUS9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V.0IM<V=I9"`B52Y6+B!I;F1E
M>#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@
M(E523"(*;7-G<W1R(")54DPB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4T,0IM<V=I9"`B55),(&9O<B!Y;W5R('-C
M<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3<*(RP@9G5Z
M>GD*;7-G:60@(E523#HB"FUS9W-T<B`B55),(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM
M<V=I9"`B56=A;F1A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*(RP@9G5Z
M>GD*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B3W)A;G-J92(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C0Q,@HC+"!F=7IZ>0IM<V=I9"`B56YA
M8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")+86X@:6MK
M:F4@:V]P;&4@=&EL(%-13"UT96YA<BXB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@
M=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S@X"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93
M(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HS.#4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0V
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI
M<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U-0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B2V%N
M(&EK:VIE(&MO<&QE('1I;"!344PM=&5N87(N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HR,S(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<UPB+B(*;7-G<W1R
M(")+=6YN92!I:VMJ92!S;&5T=&4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z-C@X(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z,3`Q-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z.#,T
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@
M9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`B2W5N;F4@:6MK:F4@
M<VQE='1E("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L
M+G!H<#HT,S4*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V
M97(N(@IM<V=S='(@(DMA;B!I:VMJ92!K;W!L92!T:6P@4U%,+71E;F%R+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,Y"B,L(&9U>GIY"FUS
M9VED(")5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`B2V%N
M(&EK:VIE(&MO<&QE('1I;"!344PM=&5N87(N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,C(U(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C(S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3DV(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#$*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P.0HC+"!F=7IZ>0IM<V=I9"`B56YA
M8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(DMA;B!I:VMJ92!K;W!L
M92!T:6P@4U%,+71E;F%R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,S8U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@
M5D93(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C,U-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,C4X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR
M-38*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B2V%N(&EK:VIE(&MO<&QE('1I;"!344PM=&5N87(N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$R-`HC+"!F=7IZ
M>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9FEL92XB"FUS9W-T<B`B
M2V%N(&EK:VIE(&MO<&QE('1I;"!344PM=&5N87(N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HR.#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S
M='(@(DMU;FYE(&EK:VIE('-L971T92`G)7,G.B`E<RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR-C4*(RP@9G5Z>GD*;7-G:60@(E5N86)L
M92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@(DMA;B!I:VMJ
M92!K;W!L92!T:6P@4U%,+71E;F%R+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]T87(N<&AP.C<V"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]G>FEP+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O
M(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B2W5N;F4@:6MK:F4@<VQE='1E
M("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C(T
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,CDX"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y
M(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM
M<V=S='(@(DMU;FYE(&EK:VIE('-L971T92`G)7,G.B`E<RXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S$@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HS.3(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,Q
M,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S,T"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O
M<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HS-#@@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C,U,@IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T
M;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HS,S<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C,R,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,T-`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")+=6YN92!I:VMJ92!S
M;&5T=&4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HT,3<@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,CD*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>3H@)7,N(@IM<V=S='(@(DMU;FYE(&EK:VIE('-L971T92`G)7,G.B`E
M<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(P-PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL
M92!<(B5S7"(N(@IM<V=S='(@(DMU;FYE(&EK:VIE('-L971T92`G)7,G.B`E
M<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,#,@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HR.#@*(SH@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C$V-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P
M"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,X,PHC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,SDQ"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R(")+=6YN92!I:VMJ92!S;&5T=&4@
M)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-#0*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(DMU;FYE(&EK:VIE('-L971T
M92`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0P
M-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R(")+=6YN92!I:VMJ92!S
M;&5T=&4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HX,#,*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@8W5R
M<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(DMA;B!I:VMJ92!R96=I<W1R97)E
M(&EN;G-T:6QL:6YG87(@:2#X:W1A+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-C`S"FUS9VED(")5;F%B;&4@=&\@97AT<F%C="!C
M97)T:69I8V%T92!D971A:6QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?24U34"])35-0+G!H<#HT-3$@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O
M075T:"YP:'`Z,3$X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B2W5N
M;F4@:6MK:F4@<VQE='1E("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR
M,#$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$V-B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3<Q"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB"FUS9W-T<B`B2V%N(&EK:VIE
M(&MO<&QE('1I;"!344PM=&5N87(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HY,R!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C$P,@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C8T."!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.CDX"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DMU;FYE(&EK
M:VIE('-L971T92`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HR-S<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S
M,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,S"FUS9VED
M(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z.#`@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HW,@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&]P
M96X@5D93(&9I;&4N(@IM<V=S='(@(DMA;B!I:VMJ92!K;W!L92!T:6P@4U%,
M+71E;F%R+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-#4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S
M960@87)C:&EV92XB"FUS9W-T<B`B2V%N(&EK:VIE(&MO<&QE('1I;"!344PM
M=&5N87(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@S-0IM<V=I9"`B
M56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@V-@IM<V=I
M9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I
M;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R
M+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`B2W5N;F4@:6MK:F4@<VQE
M='1E("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C8V.0IM<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T
M;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C$Q,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92`E
M<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR
M.3,*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B2V%N(&EK:VIE(&MO<&QE('1I;"!344PM=&5N87(N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,CD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR
M-C<@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-#,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8Q,"!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C(Y"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S
M+B(*;7-G<W1R(")+=6YN92!I:VMJ92!S;&5T=&4@)R5S)SH@)7,N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,C,@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C(Q,PHC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z-#4R(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.#4*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,P,0IM<V=I9"`B56YA
M8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T
M<B`B2W5N;F4@:6MK:F4@<VQE='1E("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L
M92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(DMA
M;B!I:VMJ92!O;7-E=&IE(&1E='1E(%=O<F0M9&]K=6UE;G1E="XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$T.2!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C$U,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B2W5N;F4@
M:6MK:F4@<VQE='1E("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C$W.0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,C@Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HQ,S@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$T
M,PIM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-#$*;7-G:60@(E5N
M86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E
M9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E
M<R(*;7-G<W1R(")!;F=R92!E;F1R:6YG87(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U
M<B!L87-T(&%C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,SDP"B,L(&9U>GIY"FUS9VED(")5;F5X<&5C
M=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G
M<W1R(")59WEL9&EG('-V87(@9G+E('1E;F%R(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,0HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS-S@*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S@T"B,L(&9U>GIY"FUS9VED(")5;F5X<&5C
M=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B56=Y;&1I
M9R!S=F%R(&9RY2!T96YA<B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#
M871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C8Q"FUS9VED(")5;F9I;&5D(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS"FUS9VED(")5;FEC;V1E
M("A55$8M."DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(E5N:71E
M9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I
M9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM
M<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S
M"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8Y
M(&QI8B]";&]C:R]M971A<BYP:'`Z-S$*;7-G:60@(E5N:71S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R.2!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,S`*;7-G:60@(E5N:VYO=VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P:6US9VED("A!4$D@
M365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C
M;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y"FUS9VED(")5;FMN;W=N
M(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*;7-G:60@(E5N
M:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HR.38*(RP@
M9G5Z>GD*;7-G:60@(E5N;F%M960B"FUS9W-T<B`B0G)U:V%R;F%M;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G
M:60@(B(*(E5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T
M+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R
M96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@
M;6]Z:6QL82YO<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A
M('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX,@IM<V=I9"`B56YS970@8V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#8@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HY,C8*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HY,S(*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$Y
M-R!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D
M871E(@IM<V=S='(@(D]P<&1A=&5R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHR.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M57!D871E("5S(@IM<V=S='(@(D]P<&1A=&5R=&4@)R5S)RXB"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"B,L(&9U>GIY"FUS9VED
M(")5<&1A=&4@=7-E<B(*;7-G<W1R(")/<'!D871E<B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z,30T(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E
M<R]S:&%R97,O961I="YP:'`Z,C,P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS9W-T<B`B3W!P9&%T97)T92`G)7,G
M+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS9VED(")5<&=R
M861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3<X(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ.3D*;7-G:60@(E5P;&]A9"(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5<&QO861E9"!A;&P@87!P
M;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP
M95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP
M:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C0*;7-G:60@(E5S92!I9B!N86UE+W!A
M<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$*(RP@
M9G5Z>GD*;7-G:60@(E5S97(B"FUS9W-T<B`B0G)U:V%R87(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<R,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S"FUS9VED(")5<V5R
M($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D)R=6MA<F%D;6EN:7-T<F5R:6YG
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR-3$*;7-G:60@
M(E5S97(@3W!T:6]N<R(*;7-G<W1R(")"<G5K87)A;'1E<FYA=&EV(@H*(SH@
M<VEG;G5P+G!H<#HV,@HC+"!F=7IZ>0IM<V=I9"`B57-E<B!296=I<W1R871I
M;VXB"FUS9W-T<B`B0G)U:V%R861M:6YI<W1R97)I;F<B"@HC.B!S:6=N=7`N
M<&AP.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A
M8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-#8Y"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O
M9&%F;VYE:71A;'E?<VUT<"YP:'`Z.3@*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34P('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C,S"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S(@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N
M86UE(@IM<V=S='(@(D)R=6MA<FYA;6XB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+U-I9VYU<"YP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E5S97)N
M86UE(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@W"B,L(&9U>GIY"FUS9VED(")5
M<V5R;F%M93HB"FUS9W-T<B`B0G)U:V%R;F%M;B(*"B,Z('1E;7!L871E<R]L
M;V=I;B]M;V)I;&4N:6YC.C@*(RP@9G5Z>GD*;7-G:60@(E5S97)N86UE.B`B
M"FUS9W-T<B`B0G)U:V%R;F%M;B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S
M='(@(D)R=6MA<F%R(&D@<WES=&5M970Z(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I
M9"`B57IB96MI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HQ-C,@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C4U
M"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3$X"FUS9VED(")6
M86-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HX-C8*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV,S@*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0IM<V=I
M9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#4V(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Q-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@;W9E
M<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#0@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(V-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$V(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C@*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0IM<V=I9"`B5F%L=65S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#D@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-@IM<V=I9"`B5F%L=65S('1O('-E;&5C
M="!F<F]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E9A;G5A
M='4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(T-`IM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED(")697)I9FEC871I;VX@
M9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@
M=VET:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HW,#`*(RP@9G5Z>GD*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`B
M5&EL9V%N9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,C8*;7-G
M:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")6
M97)T:6-A;"!A;&EG;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D
M:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I
M9"`B5F5R>2!(:6=H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@
M(E9I970@3F%M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DT"FUS9VED(")6:65T;F%M97-E("A625-#24DI(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.CDV,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A
M9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.#(Q"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L
M($)R:71I<V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER
M9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,#D*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V,PIM<V=I9"`B5FES:6)I
M;&ET>3H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L
M>2!V:6$@4TU44"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T
M:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS9VED
M(")705).(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#
M4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S,PIM<V=I9"`B5TE.('9I
M82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E=A;&QI
M<R!A;F0@1G5T=6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,C<R(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HX,PIM<V=I9"`B5V%R;FEN9R(*;7-G<W1R("+%
M='9A<FEN9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#(W
M"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DR"FUS9VED(")796%T:&5R
M+F-O;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM
M<V=I9"`B5V5B(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT,S<*;7-G:60@(E=E8B!3:71E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E
M96ML>2(*;7-G<W1R(")+=F%R('9E:V4B"@HC.B!S97)V:6-E<R]P;W)T86PO
M;6]B:6QE+G!H<#HR.`HC+"!F=7IZ>0IM<V=I9"`B5V5L8V]M92(*;7-G<W1R
M(")696QK;VUE;BP@)7,B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN
M8SHT('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-3<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R(")696QK;VUE;B!T:6P@
M)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.2!T96UP;&%T
M97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L
M8V]M92P@)7,B"FUS9W-T<B`B5F5L:V]M96XL("5S(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.34*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$I(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS9VED(")7
M97-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*
M;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A
M<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,30*;7-G
M:60@(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS9VED(")7
M:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#8Q"FUS9VED
M(")7:&5R96ES($%U<W1R86QI82!M87`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,PIM<V=I9"`B5VAI8V@@
M<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@T"FUS9VED(")7:61T:"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(U"FUS9VED(")7:61T:"!I;B!#
M4U,@=6YI=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N
M=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q,`IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0IM<V=I9"`B5VED
M=&@Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU
M,3,*;7-G:60@(E=I:VDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,P,"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV-0IM<V=I9"`B5VEN9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@IM<V=I9"`B5VEN9"!%
M87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@P"FUS
M9VED(")7:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,34V"FUS9VED(")7:6YD.B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0R"FUS9VED(")7:6YD
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS
M9VED(")7:7-D;VTB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$Y-@IM<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C0*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-`IM
M<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(D%D<F5S<V4L(&%R8F5I9"(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*
M;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`B5&5L969O;BP@87)B96ED(@H*
M(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,38Y(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N
M9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F
M;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-3
M5BYP:'`Z,S`P"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O
M9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3$T"B,L('!H<"UF;W)M
M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93
M(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR-#,*;7-G:60@(E@M4F5F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@0F%S:6,@
M0V]N<W1R86EN=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.3(*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@
M57-A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E
M($YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF
M:65R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C@R"FUS9VED(")8-3`Y=C,@97AT96YS:6]N<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T<B`B
MQ<4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#$S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-34*(RP@9G5Z>GD*;7-G:60@(EE965DB"FUS9W-T<B`BQ<4B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$P.`IM<V=I9"`B
M66%H;V\A(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N
M8V4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T<B`B
MQ7)L96<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$W"B,L(&9U>GIY"FUS9VED(")996UE;B(*
M;7-G<W1R(")'<OAN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.CDV,PIM<V=I9"`B665S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4V"FUS9VED(")9
M97,L($D@06=R964B"FUS9W-T<B`B2F$L(&5G(&5R('-A;60B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R"FUS9VED(")9
M;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@
M<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+V5D:70N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(EEO
M=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C
M:W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,30Q,0IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC871E9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS,#(*
M;7-G:60@(EEO=2!C86X@;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN
M('EO=7(@9G5L;"!N86UE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.#4U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S4*
M(RP@9G5Z>GD*;7-G:60@(EEO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA
M:6P@861D<F5S<RXB"FUS9W-T<B`B2W5N;F4@:6MK:F4@879G:F5R92!M;W1T
M86MA<F5N('-I(&4M<&]S=&%D<F5S<V4N(@H*(SH@9G)A;65W;W)K+T1A=&$O
M1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N
M)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T
M:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX.`HC+"!F=7IZ>0IM<V=I
M9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R(")!;'1E<FYA
M=&EV82!D:6YE(&AA<B!B;&ET="!O<'!D871E<G1E+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R-C$*;7-G:60@(B(*(EEO=2!H879E('1O(&5N
M=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET
M:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I
M86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,3@X"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED
M('9A;'5E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I
M9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4
M<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#4V"FUS9VED(")9;W4@;75S="!C
M;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E
M<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R
M;V)L96T@<F5P;W)T+B(*;7-G<W1R(")$=2!MY2!S:VEL9')E('!R;V)L96UE
M="!F^'(@9'4@:V%N('-E;F1E('!R;V)L96UR87!P;W)T96XN(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B
M66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S
M('1O(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP
M.C@P"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R
M('1O(&)E(&1E;&5T960N(@IM<V=S='(@(D1U(&WE('-P97-I9FES97)E(&5I
M="!B<G5K87)N86UN(.4@9FIE<FYE+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q
M.0HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE
M('1O(&-L96%R(&]U="XB"FUS9W-T<B`B1'4@;>4@<W!E<VEF:7-E<F4@96ET
M(&)R=6MA<FYA;6X@Y2!F:F5R;F4N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P
M"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E
M+B(*;7-G<W1R(")$=2!MY2!S<&5S:69I<V5R92!E:70@8G)U:V%R;F%M;B#E
M(&9J97)N92XB"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@
M=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`B1'4@;>4@<W!E<VEF:7-E
M<F4@96ET(&)R=6MA<FYA;6X@Y2!L96=G92!T:6PN(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,30V"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H
M92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@(D1U(&WE('-P97-I9FES
M97)E(&5I="!B<G5K87)N86UN(.4@;&5G9V4@=&EL+B(*"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S.`HC+"!F=7IZ>0IM<V=I
M9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*
M;7-G<W1R(")$=2!MY2!S<&5S:69I<V5R92!E:70@8G)U:V%R;F%M;B#E(&9J
M97)N92XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA
M9V5R+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE
M=R!C871E9V]R>2!N86UE+B(*;7-G<W1R(")$=2!MY2!S<&5S:69I<V5R92!E
M:70@8G)U:V%R;F%M;B#E(&9J97)N92XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B66]U(&YE
M960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-S8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A
M<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(MAK=&$@9&D@*"5S*2!H87(@9^5T
M="!U="!PY2!T:60N($QO9V<@:6YN('#E(&YY='0N(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*(RP@9G5Z>GD*;7-G:60@(EEO=7(@
M16UA:6P@061D<F5S<R(*;7-G<W1R(")$:2!E+7!O<W1A9')E<W-E.B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,3(*(RP@9G5Z>GD*;7-G:60@(EEO
M=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`B1&D@92UP;W-T861R97-S93HB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C0@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C<T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@(EEO=7(@26YF;W)M871I;VXB"FUS
M9W-T<B`B1&EN(&EN9F]R;6%S:F]N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z.3@P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N
M970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F
M('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y
M+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*(RP@9G5Z>GD*;7-G:60@(EEO
M=7(@3F%M92(*;7-G<W1R(")$:71T(&YA;6XZ(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;F]A9&0N:6YC.C4*(RP@9G5Z>GD*;7-G:60@(B(*(EEO=7(@
M875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN
M9R!U<V5R<RX@268@>6]U('=I<V@@=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN
M:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT
M("(*(F%U=&AE;G1I8V%T:6]N(&)A8VME;F0N(@IM<V=S='(@(D%U=&5N=&ES
M97)I;F=S8F%K9&5L;B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES
M="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD
M(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U
M<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N
M+B(*;7-G<W1R("(B"B),:7-T:6YG(&%V(&)R=6MA<F%R(&5R(&EK:VIE('-T
M^'1T82!A=B!B86MR92!A=71E;G1I<V5R:6YG+"!E;&QE<B!F=6YK<VIO;F5N
M("(*(FAA<B!A=B!E:6X@96QL97(@86YN86X@9W)U;FX@8FQI='0@<VSE='0@
M878N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@T"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@
M8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO
M;BX@(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I
M;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z
M-3`*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@
M9F5A='5R92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M<')I;G0N:G,Z-#(*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S
M=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA
M;F0@*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C4W"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE
M.B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.38*(RP@9G5Z
M>GD*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N
M9V5D+B(*;7-G<W1R(")!;'1E<FYA=&EV82!D:6YE(&AA<B!B;&ET="!O<'!D
M871E<G1E+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3@*(RP@9G5Z
M>GD*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>3HB"FUS9W-T<B`B4W1A
M;F1A<F1I9&5N=&ET970B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`Q
M"B,L(&9U>GIY"FUS9VED(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`B1&ET
M="!N86UN.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C$P,#`*(RP@
M9G5Z>GD*;7-G:60@(EEO=7(@;&]G:6X@:&%S(&5X<&ER960N(@IM<V=S='(@
M(D%L=&5R;F%T:79A(&1I;F4@:&%R(&)L:71T(&]P<&1A=&5R=&4N(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-`HC+"!F
M=7IZ>0IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O
M<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R(")!;'1E
M<FYA=&EV82!D:6YE(&AA<B!B;&ET="!O<'!D871E<G1E+B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34V"FUS9VED(")9;W5R(&]P=&EO
M;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S='(@(D%L=&5R;F%T:79A(&1I
M;F4@:&%R(&)L:71T(&]P<&1A=&5R=&4N(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@
M<F5S970B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L
M(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*
M(G!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HW,S(*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM
M<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-30@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q.`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R
M+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X
M=%TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#@*;7-G
M:60@(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B6U!R;V)L96UR87!P;W)T
M72(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S
M"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H
M<#HQ-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@
M+2`E<R!L:6YE<UTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@
M)7-=(@IM<V=S='(@(EML:6YJ92`E<R!A=B`E<UTB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$U-#$@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN
M8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(D%D;6EN:7-T<F5R:6YG(@H*(SH@;&EB+V%P:2YP:'`Z,34W"FUS9VED(")?
M0TQ)(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T,0IM<V=I9"`B7T1A
M=&%4<F5E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0HC+"!F=7IZ>0IM<V=I9"`B7T1E
M;&5T92!2;W<B"FUS9W-T<B`B4VQE='1E(@H*(SH@;&EB+V%P:2YP:'`Z,3,S
M"B,L(&9U>GIY"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(D=R=7!P97(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3<U"B,L(&9U>GIY
M"FUS9VED(")?2&5L<"(*;7-G<W1R(")(:F5L<"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B
M7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y-`HC+"!F=7IZ>0IM<V=I9"`B7TQO
M9R!I;B(*;7-G<W1R("),;V=G(&EN;B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]-96YU+G!H<#HQ.3`*(RP@9G5Z>GD*;7-G:60@(E],;V<@;W5T(@IM
M<V=S='(@(DQO9V<@=70B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@3&EN:RXN
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP
M:'`Z,38T"B,L(&9U>GIY"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R(")!;'1E
M<FYA=&EV(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"B,L(&9U>GIY"FUS9VED(")?
M4&5R;6ES<VEO;G,B"FUS9W-T<B`B5&EL9V%N9R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@HC+"!F=7IZ
M>0IM<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@(D9J97)N('!A<B(*
M"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y"B,L(&9U>GIY"FUS9VED(")?57-E<G,B
M"FUS9W-T<B`B0G)U:V%R87(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDR,0HC+"!F=7IZ>0IM<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@
M(D%D<F5S<V5B;VLB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$S-`IM<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3,*(RP@9G5Z>GD*;7-G
M:60@(F-A;&5N9&%R(@IM<V=S='(@(DMA;&5N9&5R(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N;F]T(&-R96%T
M92!O=71P=70@9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z-3DR"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(R"FUS9VED(")C;VUM86YD
M(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ-S@*;7-G:60@(F-O;F9I9W5R871I;VX@
M97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ-30*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I
M;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ,C8*;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3@R"FUS9VED
M(")E;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*;7-G:60@(F9A;&QI;F<B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4U
M"B,L(&9U>GIY"FUS9VED(")F:6QE(@IM<V=S='(@(E1I='1E;"(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3<T(&QI8B]";&]C:R]M971A<BYP:'`Z,S8P
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S@V"B,L('!H<"UF;W)M870*;7-G:60@
M(F9R;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,`IM<V=I9"`B9W5S=&EN9R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C0Y"FUS9VED(")H.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4X"FUS9VED(")H:"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S
M.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S
M"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(FEN
M;&EN92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,30V"FUS
M9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PHC+"!F=7IZ
M>0IM<V=I9"`B;&EN97-=(@IM<V=S='(@(D]V97)S:W)I9G1E<B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@
M=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,V.0IM<V=I9"`B;6TB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR.3$@<V5R
M=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W,`HC.B!S97)V:6-E<R]P;W)T
M86PO<VED96)A<BYP:'`Z,C,R"B,L(&9U>GIY"FUS9VED(")N86UE(@IM<V=S
M='(@(DYA;6XB"@HC.B!F<F%M97=O<FLO4E!#+U)00RYP:'`Z,3(Q"FUS9VED
M(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C$Y"FUS9VED(")N;W0@>65T(&EM<&QE
M;65N=&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3`U"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@
M(G!E<F-E;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ-S0*(RP@9G5Z>GD*;7-G:60@(G!E<FUI<W-I;VX@9&5N
M:65D(@IM<V=S='(@(E1I;&=A;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,PHC
M+"!F=7IZ>0IM<V=I9"`B<FES:6YG(@IM<V=S='(@(L5T=F%R:6YG(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#(*;7-G:60@(G-E
M<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HY.0IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS.#4*
M;7-G:60@(G-S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C<R"B,L(&9U>GIY"FUS9VED(")S=&5A9'DB"FUS
M9W-T<B`B3&5S(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,#D*
M;7-G:60@(G-W:71C:"!O9F8@:F%V87-C<FEP="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES
M=&5M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3(Y"FUS9VED(")T87-K(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O
M<F%R>2!F86EL=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,S`U"B,L(&9U>GIY"FUS9VED(")T<GD@86=A:6XB"FUS9W-T
M<B`B2W9A<B!I;FYL;V=G:6YG(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@9G)A
M;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B='EP92!T
M:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW
M.0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U!A<G0N<&AP.C(W"FUS9VED(")U;FYA;65D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(R,PIM<V=I9"`B=7-E<B!S96QE8W0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,U"FUS9VED(")V
M0V%R9"(*;7-G<W1R(")V0V%R9"(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR-#$*;7-G:60@(G<Z(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED(")W96%T:&5R
M+F-O;2(*;7-G<W1R("(B"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P;R]P;%]03"YP;P``````````````````````````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`V,C`P,34@,3`U,34T,S,W
M-#,@,#$W-3,P`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````",@2$]21$4@4&]L:7-H('1R86YS;&%T:6]N+@HC($-O<'ER:6=H
M="`H0RD@,C`P,2!-87)I=7-Z(%IY;F5L(#QM87)I=7-Z0&UI>F%R+F]R9SX*
M(R!-87)I=7-Z(%IY;F5L(#QM87)I=7-Z0&UA=&@N=7=B+F5D=2YP;#XL(#(P
M,#$N"B,@4&EO='(@4F]S>F%T>6-K:2`\9&5X=&5R0&1E8FEA;BYO<F<^+"`R
M,#`Q+@HC($MR>GES>G1O9B!+;WIL;W=S:VD@/&MO>FEK,4!O,BYP;#XL(#(P
M,#4N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ
M($AO<F1E(#,N,"UC=G-<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`
M;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ
M,2TR-"`R,#HU-BLP,3`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`U+3$Q
M+3(T(#(Q.C0V*S`Q,#!<;B(*(DQA<W0M5')A;G-L871O<CH@2W)Z>7-Z=&]F
M($MO>FQO=W-K:2`\:V]Z:6LQ0&\R+G!L/EQN(@HB3&%N9W5A9V4M5&5A;3H@
M4&]L:7-H(#QP;$!L:2YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB
M0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3)<
M;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET7&XB"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC.C$Q"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(B`F(S$U,3L@)7,@:7,@<F5A9'D@=&\@<&5R
M9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W
M+B(*;7-G<W1R("(E<R`M(&=O=&]W>2!D;R!W>6MO;F%N:6$@8WEK;&EC>FYY
M8V@@;W!E<F%C:FD@>F%Z;F%C>F]N>6-H('!O;FF_96HN(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(S-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D
M87ES(&%G;RDB"FUS9W-T<B`B("@E<R!D;FD@=&5M=2DB"@HC.B!L:6(O2&]R
M9&4N<&AP.C$R-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@
M)7,I(@IM<V=S='(@(BAK;'5C>B!D;W-TZG!U("5S*2(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,S<V"B,L('!H<"UF;W)M870*;7-G:60@(B`H:6X@)7,@
M9&%Y<RDB"FUS9W-T<B`B("AW(&-IL6=U("5S(&1N:2DB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C,W,@IM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B("AD
M>FFV*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S<T"FUS9VED("(@*'1O
M;6]R<F]W*2(*;7-G<W1R("(@*&IU=')O*2(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR,S<P"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B("AW8WIO
M<F%J*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#0@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,T.0HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,SDU"FUS9VED("(@870@(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]#3$DN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<
M(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R(")<(B5S7"(@
M;FEE(&IE<W0@<')A=VEDLV]W>6T@=WEB;W)E;2XB"@HC.B!L:6(O2&]R9&4O
M4F5G:7-T<GDN<&AP.C4U-"!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.CDS-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@
M:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*;7-G<W1R(")<(B5S7"(@;FEE(&IE
M<W0@<VMO;F9I9W5R;W=A;GD@=R!R96IE<W1R>F4@2&]R9&4N(@H*(SH@;&EB
M+TAO<F1E+U1R964N<&AP.C$V-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R("(E
M<R!N:65Z;F%L97II;VYY+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-3<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O
M=7!S('-Y<W1E;2XB"FUS9W-T<B`B561ALV\@<VGJ(&1O9&'F(%PB)7-<(B!D
M;R!G<G5P+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HX-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!P97)M
M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(E5D8;-O('-IZB!D;V1AYB!<(B5S
M7"(@9&\@=7!R87=N:67Q+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-34@861M
M:6XO<&5R;7,O861D8VAI;&0N<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@
M(EPB)7-<(B!W87,@;F]T(&-R96%T960Z("5S+B(*;7-G<W1R(")<(B5S7"(@
M;FEE('IO<W1ALR!U='=O<GIO;GDZ("5S+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@
M86YD("5S(@IM<V=S='(@(B5D("5S(&D@)7,B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C<S"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A
M>2!F;W)E8V%S="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N
M8V4O;F]T:6-E7W1O<"YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M
M($YO=&EC92(*;7-G<W1R("(E<R`M(%5W86=A(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V-O;6UO;BUH96%D97(N:6YC.C,R"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN:7-T<F%C:F$@)7,B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P-`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*;7-G<W1R("(E<R!O9&-I<VL@
M<&%L8V$B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#,P(&QI
M8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX,S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@2T(B"FUS9W-T<B`B)7,@:T(B"@HC.B!T96UP;&%T97,O;6%I
M;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*
M;7-G<W1R("(E<R`M(&]P97)A8VIE(&-Y:VQI8WIN92`M('!O='=I97)D>F5N
M:64B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HR,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B
M"FUS9W-T<B`B2V]N9FEG=7)A8VIA("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M4VEG;G5P+G!H<#HR-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5
M<"(*;7-G<W1R(")296IE<W1R86-J82`E<R(*"B,Z('1E;7!L871E<R]M86EN
M=&5N86YC92]A9W)E96UE;G1?=&]P+FEN8SHT"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*;7-G<W1R("(B"@HC.B!L:6(O
M5D93+V9T<"YP:'`Z-38X(&QI8B]61E,O9G1P+G!H<#HV,S8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B5S(&IU
MOR!I<W1N:65J92XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U.2!L:6(O
M0FQO8VLO;65T87(N<&AP.C$V-2!L:6(O0FQO8VLO;65T87(N<&AP.C(S.0HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T-2!L:6(O0FQO8VLO;65T87(N<&AP
M.C,U,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B
M"FUS9W-T<B`B)7,@9&\@)7,@>B`E<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR,S,Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM
M<V=S='(@(B5S(&IE<W0@=WEM86=A;GDB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(X-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S
M='(@(B5S(&UI;G5T(@H*(SH@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN
M<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM
M<V=S='(@(B5S(&YI97IN86QE>FEO;GDN(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E
M<R!O9B`E<R(*;7-G<W1R("(E<R!D;R`E<R!Z("5S(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HX.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R
M97-S($)O;VLB"FUS9W-T<B`B2W-IL;]K82!A9')E<V]W82`E<R(*"B,Z(&QI
M8B](;W)D92]+;VQA8BYP:'`Z.#@S"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M)W,@0V%L96YD87(B"FUS9W-T<B`B2V%L96YD87)Z("5S(@H*(SH@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HX-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.
M;W1E<&%D(@IM<V=S='(@(DYO=&%T;FEK("5S(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HX.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES
M="(*;7-G<W1R("),:7-T82!Z861A\2`E<R(*"B,Z(&QI8B](;W)D92].;W1I
M9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B)7,Z("5S(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,U,R!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,SDX"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3@X(&QI8B]";&]C:R]M971A<BYP:'`Z,3DS
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U<W1I;F<@)7,@)7,B
M"FUS9W-T<B`B)7,@9&\@)7,@>B`E<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E
M<R!T;R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`W
M,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$R.0HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-C@X"FUS9VED("(M+2!S96QE8W0@+2TB"FUS
M9W-T<B`B+2T@=WEB:65R>B`M+2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR
M,`IM<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS9W-T<B`B,3(M9V]D>FEN;GD@
M9F]R;6%T(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y"FUS9VED("(R-"!(
M;W5R($9O<FUA="(*;7-G<W1R("(R-"UG;V1Z:6YN>2!F;W)M870B"@HC.B!T
M96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS
M9W-T<B`B,C0@9V]D>BXB"@HC.B!L:6(O2&]R9&4O54DO4&%G97(N<&AP.C8Y
M"FUS9VED("(\4')E=FEO=7,B"FUS9W-T<B`B/%!O<')Z961N:2(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3$Y"B,L(&9U>GIY"FUS9VED(")!(&1A=&%B
M87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN(@IM<V=S
M='(@(D)R86L@:V]N9FEG=7)A8VII('=E=V[J=')Z;F5J(&1L82!T96=O(&AO
M<W1A(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-C`*;7-G:60@(D$@9F%T86P@97)R
M;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(DYA<W2Q<&FS(&*SL60@:W)Y='EC
M>FYY(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.3(P"FUS9VED(")!
M('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S
M86=E+B(*;7-G<W1R(")0;W1R>F5B;GD@:F5S="!K;'5C>B!P=6)L:6-Z;GD@
M4$=0(&1O('IA<WIY9G)O=V%N:6$@=VEA9&]M;[9C:2XB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HQ,30U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y
M(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(*;7-G
M<W1R("(B"B)0;W1R>F5B;GD@:F5S="!K;'5C>B!P=6)L:6-Z;GD@4$=0(&1O
M('-P<F%W9'IE;FEA('!O9'!I<V%N96H@=VEA9&]M;[9C:2XB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#<W"FUS9VED("(B"B)!('!U8FQI8R!0
M1U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB
M4&]T<GIE8FYE('.Q(&ML=6-Z('!U8FQI8WIN>2!01U`L(&ML=6-Z('!R>7=A
M=&YY(%!'4"!O<F%Z(&AA<[-O(&1O("(*(F]D<WIY9G)O=V%N:6$@=VEA9&]M
M;[9C:2XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY.34*;7-G:60@
M(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S86=E+B(*
M;7-G<W1R("(B"B)0;W1R>F5B;F4@<[$@:VQU8WH@<'5B;&EC>FYY(%!'4"P@
M:VQU8WH@<')Y=V%T;GD@4$=0(&]R87H@:&%SLV\@9&\@(@HB<&]D<&ES86YI
M82!W:6%D;VUOMF-I+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3`U"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O
M34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R`B"B)D
M96-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@HB4&]T<GIE8FYE('.Q(&ML
M=6-Z('!U8FQI8WIN>2!3+TU)344L(&ML=6-Z('!R>7=A=&YY(%,O34E-12!O
M<F%Z(&AA<[-O(&1O("(*(F]D<WIY9G)O=V%N:6$@=VEA9&]M;[9C:2XB"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB02!P
M=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S
M<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM
M<V=S='(@(B(*(E!O=')Z96)N92!SL2!K;'5C>B!P=6)L:6-Z;GD@4R]-24U%
M+"!K;'5C>B!P<GEW871N>2!3+TU)344@;W)A>B!H87.S;R!D;R`B"B)P;V1P
M:7-A;FEA('=I861O;6^V8VDN(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HS-C0*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E
M9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B4&]T<GIE8FYY(&IE
M<W0@:VQU8WH@<'5B;&EC>FYY(%--24U%(&1O('IA<WIY9G)O=V%N:6$@=VEA
M9&]M;[9C:2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HY"B,L(&9U>GIY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B6F%M
M:VYI:B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$P"B,L(&9U>GIY"FUS9VED(")!32!,:6=H="!286EN(@IM<V=S='(@(EIA
M;&]G=6HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ,0HC+"!F=7IZ>0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R(")/<W1R>F6_
M96YI92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$R"B,L(&9U>GIY"FUS9VED(")!32!3:&]W97)S(@IM<V=S='(@(DEM<&]R
M="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S
M"B,L(&9U>GIY"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B26UP
M;W)T(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-
M+U!-(@IM<V=S='(@(D%-+U!-(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED
M(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R(")/('1Y;2!E9'ET;W)Z92(*
M"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4R"FUS9VED(")!8F]U="XN
M+B(*;7-G<W1R(")/('!R;V=R86UI92XN+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<R"B,L(&9U>GIY"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B
M4W1A;F]W:7-K;R(*"B,Z(&QI8B]61E,O;75S<6PN<&AP.C(W,`HC+"!F=7IZ
M>0IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y
M+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R
M96T@4U%,+B(*"B,Z(&QI8B]61E,O;75S<6PN<&AP.C$S-@HC+"!F=7IZ>0IM
M<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92XB"FUS9W-T
M<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4*;7-G:60@(D%C8V]U;G0@
M4&%S<W=O<F0B"FUS9W-T<B`B2&%SLV\@9&\@:V]N=&$B"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N="!F
M<F]Z96XN(@IM<V=S='(@(DMO;G1O('IA8FQO:V]W86YE+B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS,3<*;7-G:60@(D%C8V]U;G1I;F<B"FUS
M9W-T<B`B2V]N=&$B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-30@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ,S(*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]A9&0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N
M:6YC.C$V"FUS9VED(")!9&0B"FUS9W-T<B`B1&]D86HB"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C(Q-"!A9&UI;B]G<F]U<',N<&AP.C(Q-0HC+"!F=7IZ>0IM
M<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S='(@(D1O9&%J(&YO=[$@9W)U
M<.HB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C@T(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z.#4*(RP@9G5Z>GD*;7-G:60@(D%D9"!#:&EL9"!097)M
M:7-S:6]N(@IM<V=S='(@(D1O9&%J(&YO=V4@=7!R87=N:65N:64B"@HC.B!T
M96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D($AE<F4Z(@IM
M<V=S='(@(D1O9&%J('1U=&%J.B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C`X
M(&%D;6EN+V=R;W5P<RYP:'`Z,C`Y"FUS9VED(")!9&0@3F5W($=R;W5P(@IM
M<V=S='(@(D1O9&%J(&YO=[$@9W)U<.HB"@HC.B!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C<S(&QI8B](;W)D92]097)M<R]522YP:'`Z-S0*;7-G:60@(D%D
M9"!.97<@4&5R;6ES<VEO;B(*;7-G<W1R(")$;V1A:B!N;W=E('5P<F%W;FEE
M;FEE(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z
M.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@9W)O
M=7`@=&\@7"(E<UPB(@IM<V=S='(@(D]P8VIE("5S(@H*(SH@861M:6XO<&5R
M;7,O861D8VAI;&0N<&AP.C4S(&QI8B](;W)D92]097)M<R]522YP:'`Z,3,Q
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!P97)M
M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R(")/<&-J92`E<R(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B
M1&]D86H@;F]W96=O('6_>71K;W=N:6MA.B(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HU,C8*;7-G:60@(D%D9"!C;VQU;6XB"FUS
M9W-T<B`B1&]D86H@:V]L=6UNZB(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O961I="YI;F,Z,S4*;7-G:60@(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R
M(")$;V1A:B!N;W=Y8V@@8WJS;VYK\W<B"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C$P,PIM<V=I9"`B061D('!A:7(B"FUS9W-T<B`B1&]D86H@
M<&%RZB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E
M8F%R(@IM<V=S='(@(D1O9&%J(&UE;G4@)7,@9&\@<&%S:V$@36]Z:6QL:2(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*;7-G:60@
M(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(D1O9&%J(&1O(&MS:;&_
M:VD@861R97-O=V5J.B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z-S@*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T
M<B`B1&]D86H@9&\@;6]J96H@:W-IL7IK:2!A9')E<V]W96HB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HS,0IM<V=I9"`B061D('5S97(B"FUS9W-T<B`B1&]D86H@
M=;]Y=&MO=VYI:V$B"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O('1H92!S>7-T
M96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R
M;6%T:6]N.B`B"B(E<RXB"FUS9W-T<B`B1&]D86YO(%PB)7-<(B!D;R!S>7-T
M96UU+B!-;[]E<WH@<VGJ('IA;&]G;W=AYBXB"@HC.B!S:6=N=7`N<&AP.C0U
M"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES
M=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(D1O9&%N;R!<(B5S
M7"(@9&\@<WES=&5M=2X@36^_97-Z('-IZB!Z86QO9V]W8>8N(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C0*;7-G:60@(D%D9&EN9R!U
M<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B1&]D87=A;FEE('6_>71K;W=N
M:6OS=R!J97-T('=YLV%C>F]N92XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,30T,R!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$W,PIM<V=I9"`B061D
M<F5S<R(*;7-G<W1R(")!9')E<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ,SD*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R(")+<VFQOVMA
M(&%D<F5S;W=A(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP
M.CDT"B,L(&9U>GIY"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I
M;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R(")/<&-J92`E<R(*"B,Z(&%D
M;6EN+VEN9&5X+G!H<#HQ.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,3$S"FUS9VED(")!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')A
M8VIA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,Y,@IM<V=I9"`B
M061S(@IM<V=S='(@(E)E:VQA;7DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!9F=H86YI<W1A;B(*;7-G
M<W1R(")!9F=A;FES=&%N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06QB86YI82(*;7-G<W1R(")!;&)A
M;FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<T(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW,`IM<V=I9"`B06QG97)I82(*;7-G<W1R(")!;&=I97)I82(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA
M<R(*;7-G<W1R(")!;&EA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*;7-G:60@(D%L:6=N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-C<*;7-G:60@(D%L:6=N;65N=#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C@W"FUS9VED(")!;&PB"FUS9W-T<B`B5W-Z>7-T:V\B
M"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,3@@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B
M"FUS9W-T<B`B5W-Z>7-C>2!U=VEE<GIY=&5L;FEE;FD@=;]Y=&MO=VYI8WDB
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C$R
M"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S='(@(E=S>GES=&MI92!G<G5P>2(*
M"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HS."!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C<W"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`B
M5W-Z>7-T:VEE('5P<F%W;FEE;FEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PHC+"!F=7IZ>0IM<V=I9"`B
M06QL(&9O=7(@<VED97,B"FUS9W-T<B`B57=A9VDB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3@W,@IM<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S
M(@IM<V=S='(@(E!O>G?S;"!N82!W:65L92!A9')E<_-W(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4R-@IM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O
M<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T1A
M=&%4<F5E+W-Q;"YP:'`Z-#`X"FUS9VED(")!;')E861Y(&5X:7-T<R(*;7-G
M<W1R(")*=;\@:7-T;FEE:F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3(S"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R(")!;'1E
M<FYA='EW;GD@;&]G:6X@24U34"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT.3D*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S='(@
M(D%L=&5R;F%T>7=N>2!H87.S;R!)35-0(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0Y,0IM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B"FUS
M9W-T<B`B06QT97)N871Y=VYA(&YA>G=A('6_>71K;W=N:6MA($E-4U`B"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS-0IM<V=I9"`B06QT97)N
M871E(&5M86EL(&%D9')E<W,B"FUS9W-T<B`B06QT97)N871Y=VYY(&%D<F5S
M(&5M86EL(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*(RP@9G5Z>GD*
M;7-G:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`B5'?S:B!A9')E
M<R!E+6UA:6PZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB
M"FUS9W-T<B`B06QT97)N871Y=VYY('1E:W-T.B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N
M(%-A;6]A(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z
M.34@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G
M86P@=F%L=64@=V%S('-P96-I9FEE9"XB"FUS9W-T<B`B6F]S=&&S82!P;V1A
M;F$@;FEE<')A=VEDLV]W82!W87)T;[;F+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-30*(RP@9G5Z>GD*;7-G:60@(D%N('5N:VYO=VX@
M97)R;W(@:&%S(&]C8W5R960N(@IM<V=S='(@(E!R;W-ZZB!P;V1AYB!N87IW
MZB!UOWET:V]W;FEK82!I(&AA<[-O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B06YD;W)R82(*;7-G<W1R
M(")!;F1O<F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B06YG;VQA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I
M9"`B06YG=6EL;&$B"FUS9W-T<B`B06YG=6EL;&$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G
M<W1R(")!;F]N:6UO=V4@4')O>'DB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@(D]D<&]W:65DO"(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@*
M;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`B06YT87)K='ED82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-38*;7-G:60@
M(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z,S4@;&EB+TAO<F1E
M+T)L;V-K+U5)+G!H<#HU.`HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD
M97@N:'1M;#HV"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R(")!<&QI:V%C
M:F$B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,Y"FUS9VED(")!<'!L
M:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`B07!L:6MA8VIA(&=O=&]W82(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L
M>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T
M<B`B6F%T=VEE<F2\(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP
M.C@S,`IM<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<W(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HT,30*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS
M9W-T<B`B2W=I96-I9?$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-0IM
M<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C4Y(&QI8B](;W)D92]-24U%
M+U9I97=E<B]Z:7`N<&AP.C8V"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T
M9WHN<&AP.C<X"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R(")7
M:65L:V^VYB!A<F-H:7=U;2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R
M87(N<&AP.C4X(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8U"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<W"FUS9VED(")!<F-H
M:79E($YA;64B"FUS9W-T<B`B3F%Z=V$@87)C:&EW=6TB"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.CD*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO
M=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(D-Z>2!N
M82!P97=N;R!C:&-E<WH@=7-U;K'F('3J(')E9W6SZC\B"@HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z.0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<
M(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R(")#>GD@;F$@<&5W
M;F\@8VAC97-Z('5S=6ZQYB!TZB!R96=UL^H_(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B07)G96YT:6YA
M(@IM<V=S='(@(D%R9V5N='EN82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B
M07)M96YI82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<V"FUS9VED(")!
M<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R="(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!
M<G5B82(*;7-G<W1R(")!<G5B82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B
M07-I82]086-I9FEC(%)E9VEO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#$W"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B
M969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`B
M4&]P<F^V(&\@<&]T=VEE<F1Z96YI92!P<GIE9"!W>6MO;F%N:65M(&]P97)A
M8VII(&-Y:VQI8WIN>6-H/R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3$R
M"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HW-0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N
M;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS
M+V1E;&5T92YP:'`Z,S@*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N
M+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E
M<FUS+V5D:70N<&AP.CDX"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM
M97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N
M;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R87(N<&AP.C8T(&QI8B](;W)D92]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<Q"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@S
M"FUS9VED(")!='1R:6)U=&5S(@IM<V=S='(@(D%T<GEB=71Y(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X,2!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$X"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G
M<W1R(")3:65R<&EE\2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR.2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R(")!=7-T
M<F%L:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C@@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C4Y"FUS9VED(")!=7-T<FEA(@IM<V=S='(@(D%U<W1R:6$B"@HC.B!L
M:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S
M<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B075T:%]C>7)U<SH@3FEE('IN86QE>FEO;F\@=WEM86=A;F5G;R!R;WIS
M>F5R>F5N:6$@:6UA<"XB"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z
M,3,U"FUS9VED(")!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@
M<F5Q=6ER960@8V%P86)I;&ET97,N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I
M<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C
M>7)U<SH@3FEE('IN86QE>FEO;F\@=WEM86=A;F5G;R!R;WIS>F5R>F5N:6$@
M:6UA<"XB"@HC.B!L:6(O2&]R9&4O075T:"]F='`N<&AP.C,V"FUS9VED("(B
M"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N
M(@IM<V=S='(@(B(*(D%U=&A?9G1P.B!.:64@>FYA;&5Z:6]N;R!W>6UA9V%N
M96=O(')O>G-Z97)Z96YI82!&5%`N(%-K;VUP:6QU:B!02%`@>B`B"B)P87)A
M;65T<F5M("TM96YA8FQE("XB"@HC.B!L:6(O2&]R9&4O075T:"]I;6%P+G!H
M<#HV-`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:6UA<#H@3FEE('IN86QE>FEO
M;F\@=WEM86=A;F5G;R!R;WIS>F5R>F5N:6$@24U!4"XB"@HC.B!L:6(O2&]R
M9&4O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E
M9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:W)B
M-3H@3FEE('IN86QE>FEO;F\@=WEM86=A;F5G;R!R;WIS>F5R>F5N:6$@:W)B
M-2XB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HU.`IM<V=I9"`B075T
M:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(D%U=&A?;&1A<#H@3FEE('IN86QE>FEO;F\@=WEM86=A;F5G;R!R
M;WIS>F5R>F5N:6$@3$1!4"XB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H
M<#HQ.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@
M56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E
M<B!S86ED.B`B"FUS9W-T<B`B6F%P:7-Z86YI92!S>FMI8W4@;FEE=61A;F4N
M(%-E<G=E<B!Z=W+S8VFS(&]D<&]W:65DO#H@)7,B"@HC.B!L:6(O2&]R9&4O
M075T:"]L9&%P+G!H<#HR,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L
M9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B075T:%]L
M9&%P.B!.:64@=61ALV\@<VGJ('5S=6ZQYB!UOWET:V]W;FEK82`E<R(*"B,Z
M(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C(X,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G
M<W1R(")!=71H7VQD87`Z($YI92!U9&&S;R!S:>H@=6%K='5A;&YIYB!UOWET
M:V]W;FEK82`E<R(*"B,Z(&QI8B](;W)D92]!=71H+VUC86PN<&AP.C0V"FUS
M9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B075T:%]M8V%L.B!.:64@>FYA;&5Z:6]N;R!W>6UA
M9V%N96=O(')O>G-Z97)Z96YI82!-0T%,+B(*"B,Z(&QI8B](;W)D92]!=71H
M+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB
M875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7W-M8F%U
M=&@Z($YI92!Z;F%L97II;VYO('=Y;6%G86YE9V\@<F]Z<WIE<GIE;FEA('-M
M8F%U=&@N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3`*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R(")5=VEE
M<GIY=&5L;FEE;FEE(&YI92!P;W=I;V2S;R!S:>HB"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N=&EC
M871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R(")5=VEE<GIY=&5L;FEE;FEE(&YI
M92!P;W=I;V2S;R!S:>HN("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O<F%D:75S
M+G!H<#HQ-S8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!
M1$E54R!S97)V97(N(@IM<V=S='(@(E5W:65R>GET96QN:65N:64@;V1R>G5C
M;VYE('!R>F5Z('-E<G=E<B!2041)55,N(@H*(SH@;&EB+U9&4R]F='`N<&AP
M.C<V.`IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL
M960N(@IM<V=S='(@(E5W:65R>GET96QN:65N:64@9&\@<V5R=V5R82!&5%`@
M;FEE('!O=VEO9+-O('-IZBXB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C@S"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R(")$;W-T
MZG!N92!P;VQA.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-3D*;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B07IE<F)E
M:F2_86XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@(D)/
M1D@@17AC=7-E<R(*;7-G<W1R(")7>6WS=VMI($)/1D@B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED
M(")"86-K9W)O=6YD(@IM<V=S='(@(E2S;R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@
M0V]L;W(B"FUS9W-T<B`B2V]L;W(@=+-A(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M:W)B-2YP:'`Z.#$*;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R9"XB"FUS
M9W-T<B`B6K-E(&AA<[-O($ME<F)E<F]S82XB"@HC.B!L:6(O2&]R9&4O075T
M:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N86UE+B(*
M;7-G<W1R("):LV$@;F%Z=V$@=;]Y=&MO=VYI:V$@2V5R8F5R;W-A(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I
M9"`B0F%H86UA<R(*;7-G<W1R(")7>7-P>2!"86AA;6$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"86AR
M86EN(@IM<V=S='(@(D)A:')A:FXB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$W-PIM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B0F&S
M='EC:VD@*$E33RTX.#4Y+3$S*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HS-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A;F=L861E<V@B"FUS9W-T
M<B`B0F%N9VQA9&5S>B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M,PHC+"!F=7IZ>0IM<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B3V1R>G5C;VYE
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0Y(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HS,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M,PIM<V=I9"`B0F5L87)U<R(*;7-G<W1R(")":6&S;W)UMB(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HS-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)E
M;&=I=6TB"FUS9W-T<B`B0F5L9VEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C4P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L:7IE(@IM<V=S='(@
M(D)E;&EZ92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C$*;7-G:60@(D)E;FEN(@IM<V=S='(@(D)E;FEN(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C0Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HS-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B
M0F5R;75D82(*;7-G<W1R(")"97)M=61Y(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C0V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S
M='(@(D)H=71A;B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G<W1R(")$871A('5R;V1Z96YI
M82(*"B,Z(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N
M(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M;W)T86PO;&%Y;W5T+FEN8SHX.0IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS
M9W-T<B`B57-T87=I96YI82!B;&]K=2(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R(")4>7`@
M8FQO:W4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@*(RP@9G5Z>GD*;7-G:60@(D)O;&0B"FUS9W-T<B`B5')EMN8B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#,@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C,V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS
M9VED(")";VQI=FEA(@IM<V=S='(@(D)O;&EW:6$B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3DQ"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`B
M6F%KLV%D:VDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(P"B,L(&9U>GIY"FUS9VED(")";W)D97(B"FUS9W-T
M<B`B2&]R9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(Q"B,L(&9U>GIY"FUS9VED(")";W)D97)S(@IM<V=S='(@(DAO<F1E
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,R(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HS-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R(")";[9N
M:6$@:2!(97)C96=O=VEN82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY
M-@IM<V=I9"`B0F]T:"(*;7-G<W1R(")/8F$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W1S=V%N82(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S4*;7-G:60@(D)O='1O;2(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C,Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"B,L(&9U
M>GIY"FUS9VED(")";W5V970@27-L86YD(@IM<V=S='(@(E=Y<W!Y($]W8WIE
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0T(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HT,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M,@IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(D)R87IY;&EA(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(D)R
M:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C0R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED
M(")"<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0S
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=6QG87)I
M82(*;7-G<W1R(")"=;-G87)I82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3D*(RP@9G5Z>GD*;7-G:60@(D)U;&QE=&5D
M($QI<W0B"FUS9W-T<B`B5WEB:65R>B!L:7-TZB(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HS-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<FMI;F$@
M1F%S;R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,SD@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)U;F1I(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#,*;7-G:60@(D--4R(*;7-G
M<W1R(")#35,B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW
M-0IM<V=I9"`B0U)#(@IM<V=S='(@(D-20R(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-3DW"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N
M+BXB"FUS9W-T<B`B5[-AMF-I=V^V8VD@:V]M\W)K:2XN+B`H7V,I(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U,`HC+"!F=7IZ>0IM<V=I
M9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T<B`B6F&S
ML6-Z;FEK(&YI92!Z;W-T8;,@>FYA;&5Z:6]N>2XB"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4V(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ-#@*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(DMA;&5N9&%R
M>B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S0*;7-G:60@
M(D-A;&TB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R
M."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@(DMA
M;6)O9+]A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8P(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B2V%M97)U;B(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#86X@;F]T
M(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B).:64@=61ALV\@<VGJ('IR97-E
M=&]W8>8@:&%SLV$@875T;VUA='EC>FYI92P@<VMO;G1A:W1U:B!S:>H@>B`B
M"B)A9&UI;FES=')A=&]R96TN(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N
M<&AP.C(S-2!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C,Q.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E
M<R(*;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R
M96T@24U!4#H@)7,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3$@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0X"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8T"FUS9VED(")#86YA9&$B"FUS9W-T<B`B2V%N861A(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$T('1E;7!L871E<R]A
M9&UI;B]U<V5R+V-L96%R+FEN8SHQ-PHC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F4N:6YC.C$W"FUS9VED(")#86YC96PB"FUS9W-T<B`B06YU;'5J
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@
M(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")!;G5L=6H@<F%P;W)T
M(&\@<')O8FQE;6EE(@H*(SH@;&EB+U9&4R]F='`N<&AP.C(U-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G
M<W1R(").:64@;6^_;F$@<VMA<V]W8>8@<&QI:W4@7"(E<UPB(@H*(SH@;&EB
M+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*
M(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C4R"FUS9VED(")#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O
M<GDN(@IM<V=S='(@(DYI92!U9&&S;R!S:>H@>FYA;&6\YB!K871A;&]G=2!T
M>6UC>F%S;W=E9V\N(@H*(SH@;&EB+U9&4R])4T]7<FET97(N<&AP.CDQ"FUS
M9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A
M;65T97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HR-3(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E
M<UPB+B(*;7-G<W1R(").:64@;6^_;F$@<VMA<V]W8>8@:V%T86QO9W4@7"(E
M<UPB(@H*(SH@;&EB+TAO<F1E+T1A=&%4<F5E+G!H<#HQ,3(@;&EB+TAO<F1E
M+T1A=&%4<F5E+W-Q;"YP:'`Z-3@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T
M<B`B3FEE(&UOOVYA('-K87-O=V'F(&MA=&%L;V=U(%PB)7-<(B(*"B,Z(&QI
M8B](;W)D92]$871A5')E92]S<6PN<&AP.C4Q,@IM<V=I9"`B(@HB0V%N;F]T
M(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R
M9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM<V=S='(@
M(B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS
M9VED(")#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R
M+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C4@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8X"FUS9VED(")#87!E(%9E<F1E(@IM<V=S='(@(E=Y<W!Y
M(%II96QO;F5G;R!0<GIY;+%D:V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T"B,L(&9U>GIY"FUS9VED(")#
M87!T:6]N(@IM<V=S='(@(D]P8VIE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDP"FUS9VED(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`B
M2V%T96=O<FEE(&D@;WIN86-Z96YI82(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@V"B,L(&9U>GIY"FUS9VED(")#87EM
M86X@27-L86YD<R(*;7-G<W1R(")7>7-P>2!386QO;6]N82(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#96QL(%!H
M;VYE(@IM<V=S='(@(E1E;"X@:V]M+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*;7-G:60@(D-E;&P@4')O
M<&5R=&EE<R(*;7-G<W1R(")7LV&V8VEW;[9C:2!K;VWS<FMI(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@
M(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P
M<F]P97)T:65S(@IM<V=S='(@(E>S8;9C:7=OMF-I(&MO;?-R:VDB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I
M9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3(W-`IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(E1E;"X@:V]M
M+B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED(")#96QT:6,@
M*$E33RTX.#4Y+3$T*2(*;7-G<W1R(")#96QT>6-K:2`H25-/+3@X-3DM,30I
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR-@HC+"!F=7IZ>0IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(E-T=_-R
M>B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C4*;7-G:60@(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R(")2
M97!U8FQI:V$@IG)O9&MO=V5J($%F<GEK:2(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3<Y"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR
M*2(*;7-G<W1R("*F<F]D:V]W;V5U<F]P96IS:VD@*$E33RTX.#4Y+3(I(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV.3D*;7-G:60@(D-E<G1I
M9FEC871E($1E=&%I;',B"FUS9W-T<B`B4WIC>F5G\[-Y(&-E<G1Y9FEK871U
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,3$*;7-G:60@(D-E
M<G1I9FEC871E($]W;F5R(@IM<V=S='(@(E>S8;9C:6-I96P@8V5R='EF:6MA
M='4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-@HC+"!F=7IZ
M>0IM<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B4WIC>F5G
M\[-Y(&-E<G1Y9FEK871U(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R
M,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")#:&%D(@IM<V=S='(@(D-Z860B
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.CDW"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B
M6FUI9?$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G:60@(B(*
M(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@
M=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS+B(*
M;7-G<W1R("):;6EE\2!I;6GJ+"!N87IW:7-K;R!I(&%D<F5S+"!K=/-R>2!I
M;FYI('=I9'JQ('<@5'=O:6-H(&QI<W1A8V@@96UA:6PN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PHC+"!F
M=7IZ>0IM<V=I9"`B0VAA<B(*;7-G<W1R(")+86QE;F1A<GHB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*
M;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(E-P<F%W9+P@;&EN:RXN
M+B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M7W1O<"YI;F,Z
M,3,*;7-G:60@(D-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@
M>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N(@IM<V=S='(@(EIA
M>FYA8WH@<&]Z>6-JZB!D;&$@:W3S<F5J(&-H8V5S>B!W>6MO;F'F(&]P97)A
M8VKJ+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C<*;7-G:60@(D-H:6QE(@IM<V=S='(@(D-H:6QE(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C8Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HU-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI
M;F$B"FUS9W-T<B`B0VAI;GDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M,`IM<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#:&EN97-E
M(%1R861I=&EO;F%L("A":6<U*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B
M"FUS9W-T<B`B4&]D86H@:&%SLV\B"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N
M=7`N<&AP.C(V.`IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B
M4&]D86H@;F%Z=^H@=;]Y=&MO=VYI:V$B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,CDP"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z
M(@IM<V=S='(@(E=Y8FEE<GH@<W!O<_-B('=YMG=I971L86YI82!D870Z(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N
M9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R
M9&5R960@;&ES=',I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HV-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-34*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H<FES=&UA<R!)<VQA
M;F0B"FUS9W-T<B`B5WES<&$@0F^_96=O($YA<F]D>F5N:6$B"@HC.B!L:6(O
M5D93+G!H<#HV,34@;&EB+TYE="]335,N<&AP.C(Y-`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U
M;F0N(@IM<V=S='(@(EIAL[%C>FYI:R!N:64@>F]S=&&S('IN86QE>FEO;GDN
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*
M(RP@9G5Z>GD*;7-G:60@(D-L96%R(@IM<V=S='(@(DMA;&5N9&%R>B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G
M:60@(D-L96%R($U33V9F:6-E('1A9W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R("):9&%L;F4@
M<V5R=V5R>2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ
M-@HC+"!F=7IZ>0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R(")+86QE;F1A
M<GHB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`HC+"!F
M=7IZ>0IM<V=I9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@(DMA;&5N9&%R
M>B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U
M"B,L(&9U>GIY"FUS9VED(")#;&5A<FEN9R!,871E(@IM<V=S='(@(DMA;&5N
M9&%R>B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]N;W1I8V5?8F]T=&]M
M+FEN8SHV"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R(")+;&EK
M;FEJ(&)Y(&MO;G1Y;G5O=V'F(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS
M9W-T<B`B6F%M:VYI:B!O:VYO(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-#0*(RP@9G5Z>GD*;7-G:60@(D-L;W5D<R(*;7-G<W1R("):86UK;FEJ(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*(RP@
M9G5Z>GD*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R(")+<O-T:VEE('-T
M<F5S>F-Z96YI92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$W"B,L(&9U>GIY"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B2W)A
M:B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C0*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(E=Y
M<W!Y($MO:V]S;W=E("A+965L:6YG82DB"@HC.B!T96UP;&%T97,O<&]R=&%L
M+W-I9&5B87(N:6YC.C0*;7-G:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T
M<B`B4V-H;W=A:B!P87-E:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*(RP@9G5Z>GD*;7-G:60@(D-O;&QA
M<'-E9"!B;W)D97)S(@IM<V=S='(@(EIW:?$@9F]L9&5R(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C8R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HU-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]L
M;VUB:6$B"FUS9W-T<B`B2V]L=6UB:6$B"@HC.B!L:6(O0FQO8VLO8V]L;W(N
M<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L
M;W(B"FUS9W-T<B`B2V]L;W(B"@HC.B!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C
M=&EO;BYP:'`Z,CDY(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HS
M,#`*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0W,B!S
M97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4Q"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4R"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8X"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Y"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@U"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@V"FUS9VED(")#;VQO
M<B!0:6-K97(B"FUS9W-T<B`B5WEB:65R>B!K;VQO<B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR.#0U"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S
M='(@(E=Y8O-R(&MO;&]R=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`S"B,L(&9U>GIY"FUS9VED(")#;VQS.B(*;7-G
M<W1R("):=VGQ(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-#<*;7-G:60@
M(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B5'ET=;-Y(&MO;'5M;B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#8*(RP@9G5Z>GD*;7-G:60@(D-O
M;6EC<R(*;7-G<W1R(")4=_-R>B(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR
M-0IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R(")+;VUE;F1A(@H*(SH@861M:6XO
M8VUD<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@
M(E!O=[-O:V$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,#(*;7-G
M:60@(D-O;6UE;G0B"FUS9W-T<B`B2V]M96YT87)Z(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU-C8*;7-G:60@(D-O;6UO;B!.86UE(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S`@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@T"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(DMO;6]R>2(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#;VUP
M86YY(@IM<V=S='(@(D9I<FUA(@H*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R
M+V5M86EL<RYP:'`Z.#$@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP
M:'`Z.#<*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z.3<@
M;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z,3`Q"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O;7!O<V4@365S<V%G92`H)7,I(@IM<V=S='(@(E-T
M=_-R>B!W:6%D;VUOMN8@*"5S*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS,0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(DMO;7!U=&5R>2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#4*(RP@9G5Z>GD*;7-G
M:60@(D-O;F1I=&EO;B(*;7-G<W1R(")787)U;FMI(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR-#D*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B5V%R
M=6YK:2(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF
M:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ,S0*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T
M(&]F(&1A=&4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HY.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T
M<B`B4VMO;F9I9W5R=6H@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C,W"FUS9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@
M(E!O='=I97)DO"!H87.S;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O(@IM<V=S='(@(DMO;F=O
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4S(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HV,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M-0IM<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H
M92(*;7-G<W1R(")$96UO:W)A='EC>FYA(%)E<'5B;&EK82!+;VYG;R(*"B,Z
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F
M86EL960N(@IM<V=S='(@(E!OL[%C>F5N:64@;FEE('!O=VEO9+-O('-IZBXB
M"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I
M;VX@9F%I;&5D.B`B"FUS9W-T<B`B4&^SL6-Z96YI92!N:64@<&]W:6]DLV\@
M<VGJ.B`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW-SD*;7-G:60@
M(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB
M"FUS9W-T<B`B3V1M\W=I;VYO('!OL[%C>F5N:6$@9&\@<'5B;&EC>FYE9V\@
M<V5R=V5R82XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW.#$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B3V1M
M\W=I;VYO('!OL[%C>F5N:6$@9&\@<'5B;&EC>FYE9V\@<V5R=V5R82X@4&]W
M\V0Z("5S("@E<RDB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S8R"FUS9VED(")#
M;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")"L[%D
M('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@1E10+B(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A
M8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B
M;V]K+B(*;7-G<W1R(")+;VYT86MT>2!Z;W-T8;-Y('!O;7FV;&YI92!D;V1A
M;F4@9&\@5'=O:F5J(&MS:;&_:VD@861R97-O=V5J+B(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]T9WHN<&AP.C8P"FUS9VED(")#;VYT96YT('1Y<&4@
M;V8@8V]M<')E<W-E9"!F:6QE.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C,*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z
M-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM
M<V=S='(@(EIA=V%R=&^VYB!<(B5S7"(B"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HR.0IM<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`B2V]N>6YU
M=6HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3@@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8V"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T<B`B5WES<'D@0V]O:V$B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S(*(RP@9G5Z>GD*;7-G:60@
M(D-O;VMI92(*;7-G<W1R(")4=_-R>B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0IM<V=I9"`B0V]P>2(*
M;7-G<W1R(")3:V]P:75J(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T
M<B`B4VMO<&EU:B!W>6+S<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4W(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HV,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M-@IM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HY-38*;7-G:60@(D-O=6QD(&YO="!01U`@96YC
M<GEP="!M97-S86=E+B(*;7-G<W1R(").:64@=61ALV\@<VGJ('IA<WIY9G)O
M=V'F("A01U`I('=I861O;6^V8VDN(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z,3`S,PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N
M(@IM<V=S='(@(DYI92!U9&&S;R!S:>H@<&]D<&ES8>8@*%!'4"D@=VEA9&]M
M;[9C:2XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I
M9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@
M(DYI92!U9&&S;R!S:>H@>F%S>GEF<F]W8>8@*%,O34E-12D@=VEA9&]M;[9C
M:2XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B
M0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(DYI92!U
M9&&S;R!S:>H@<&]D<&ES8>8@*%,O34E-12D@=VEA9&]M;[9C:2XB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S(@IM
M<V=S='(@(DYI92!M;[]N82!O='=O<GIYYB!M;V1ULW4@36%I;G1E;F%N8V5?
M5&%S:R`E<R(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C$Q,`IM<V=I
M9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(D*S
ML60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!,1$%0+B(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R
M(").:64@;6^_;F$@;W1W;W)Z>>8@)7,N(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VYN
M96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R(")"
ML[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@7"(E<UPB('!O
M<')Z97H@1E10.B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HS,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DAO<F1E
M(&YI92!J97-T('<@<&6S;FD@<VMO;F9I9W5R;W=A;F4N(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z,3$P-0IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y
M<'0@4$=0(&1A=&$N(@IM<V=S='(@(DYI92!U9&&S;R!S:>H@;V1S>GEF<F]W
M8>8@9&%N>6-H(%!'4"XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4R,@IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM
M<V=S='(@(DYI92!U9&&S;R!S:>H@;V1S>GEF<F]W8>8@9&%N>6-H(%,O34E-
M12XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&-O
M;G1A8W0N("5S(@IM<V=S='(@(DAO<F1E(&YI92!J97-T('<@<&6S;FD@<VMO
M;F9I9W5R;W=A;F4N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C,U-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B2&]R9&4@
M;FEE(&IE<W0@=R!P9;-N:2!S:V]N9FEG=7)O=V%N92XB"@HC.B!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HS-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="!<(B5S
M7"(N(@IM<V=S='(@(DYI92!M;[]N82!O='=O<GIYYB!M;V1ULW4@36%I;G1E
M;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M,S@Q(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.CDS.`IM<V=I9"`B0V]U;&0@
M;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N
M(@IM<V=S='(@(DYI92!U9&&S;R!S:>H@=7-T86QIYB!A9')E<W4@92UM86EL
M(&]D8FEO<F-Y+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HR.#,*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T
M92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(DYI92!M;[]N82!O='=O<GIYYB!M
M;V1ULW4@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HT.3,*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO
M="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B
M3FEE(&UOOVYA(&]T=V]R>GGF(&UO9'6S=2!-86EN=&5N86YC95]487-K("5S
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T-@HC+"!F
M=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T
M(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS9W-T<B`B3FEE(&UOOVYA(&]T
M=V]R>GGF(&UO9'6S=2!-86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB+U9&
M4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.`HC.B!L:6(O
M5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y
M(%PB)7-<(BXB"FUS9W-T<B`B3FEE(&UOOVYA(&]T=V]R>GGF(&UO9'6S=2!-
M86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z(&QI8B]61E,O25-/5W)I
M=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*
M;7-G<W1R(").:64@;6^_;F$@=71W;W)Z>>8@:V%T86QO9W4@7"(E<UPB(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-S`X"FUS9VED(")#;W5L9"!N
M;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G
M<W1R(").:64@=61ALV\@<VGJ('5Z>7-K8>8@>B!S97)W97)A(&ML=6-Z82!P
M8G5L:6-Z;F5G;RXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R(").:64@
M=61ALV\@<VGJ(&]T=V]R>GGF(%PB)7-<(B!D;R!Z87!I<W4N(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W-R!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B3FEE(&UOOVYA(&]T=V]R>GGF
M("5S+B(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z-#$X"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A
M<VL@;6]D=6QE("5S(@IM<V=S='(@(DYI92!M;[]N82!O='=O<GIYYB!M;V1U
MLW4@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B]61E,O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S
M='(@(DYI92!M;[]N82!O='=O<GIYYB!K871A;&]G=2!<(B5S7"(B"@HC.B!L
M:6(O5D93+T]B:F5C="YP:'`Z,C,X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T<B`B3FEE(&UOOVYA(&]T
M=V]R>GGF(&UO9'6S=2!-86EN=&5N86YC95]487-K("5S(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD(&YO="!R
M97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M
M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4
M<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U
M(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS-#`*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,W-R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@S
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#D*(RP@9G5Z
M>GD*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B3FEE
M(&UOOVYA(&]T=V]R>GGF(&UO9'6S=2!-86EN=&5N86YC95]487-K("5S(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&%D9')E
M<W,@8F]O:RX@)7,B"FUS9W-T<B`B2&]R9&4@;FEE(&IE<W0@=R!P9;-N:2!S
M:V]N9FEG=7)O=V%N92XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-#@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DAO
M<F1E(&YI92!J97-T('<@<&6S;FD@<VMO;F9I9W5R;W=A;F4N(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0S-PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO
M;B!L:7-T<RX@)7,B"FUS9W-T<B`B2&]R9&4@;FEE(&IE<W0@=R!P9;-N:2!S
M:V]N9FEG=7)O=V%N92XB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,3DY(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PHC+"!F=7IZ
M>0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI
M=&EE<R(*;7-G<W1R(")(;W)D92!N:64@:F5S="!W('!ELVYI('-K;VYF:6=U
M<F]W86YE+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*(RP@9G5Z
M>GD*;7-G:60@(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B2&]R9&4@;FEE(&IE<W0@=R!P9;-N:2!S:V]N9FEG=7)O=V%N92XB
M"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HY-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`B3FEE('5D8;-O('-IZB!S:V%S;W=A
M;FEE(&MA=&%L;V=U(%PB)7-<(BXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HW,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('-A=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B2&]R9&4@;FEE(&IE
M<W0@=R!P9;-N:2!S:V]N9FEG=7)O=V%N92XB"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*(RP@9G5Z
M>GD*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO
M;BXB"FUS9W-T<B`B2&]R9&4@;FEE(&IE<W0@=R!P9;-N:2!S:V]N9FEG=7)O
M=V%N92XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O
M;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B2&]R9&4@;FEE(&IE<W0@=R!P9;-N
M:2!S:V]N9FEG=7)O=V%N92XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HY,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A
M=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B
M3FEE(&UOOVYA(&]T=V]R>GGF(&UO9'6S=2!-86EN=&5N86YC95]487-K("5S
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF
M:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(DAO<F1E(&YI92!J97-T('<@
M<&6S;FD@<VMO;F9I9W5R;W=A;F4N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HW-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V
M92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U
M<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C
M:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S
M+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ,C`*
M(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R
M=F5R+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@<')Z97-Z=6MI=V%N:6$@>B!S
M97)W97)E;2!,1$%0+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R(").:64@=61ALV\@<VGJ
M('-K87-O=V'F('!L:6MU(%PB)7-<(BXB"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@(DYI92!M
M;[]N82!O='=O<GIYYB!M;V1ULW4@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S(@IM<V=S='(@(DYI92!M;[]N82!O='=O<GIYYB!M;V1U
MLW4@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B
M2&]R9&4@;FEE(&IE<W0@=R!P9;-N:2!S:V]N9FEG=7)O=V%N92XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4X"FUS9VED(")#;W5L9&XG="!F:6YD
M('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I
M<R!O<&5N+B(*;7-G<W1R(").:64@=61ALV\@<VGJ('IN86QEO.8@<&%S:V$@
M36]Z:6QL:2X@57!E=VYI:B!S:>HL(+]E(&IE<W0@;VX@;W1W87)T>2XB"@HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E
M<UPB('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<
M(CH@)7,B"FUS9W-T<B`B(@HB5;]Y=&MO=VYI:R!<(B5S7"(@<')A=VEDLV]W
M;R!Z9&5F:6YI;W=ALR!P<F%W82!D;W-TZG!U(&1O(&9O;&1E<F$@7"(E<UPB
M+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(Q"B,L(&9U>GIY"FUS9VED
M(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B5WEL;V=U:B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED(")#;W5N=')Y(@IM<V=S='(@
M(DMR86HB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C<P"B,L(&9U
M>GIY"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(JQR\V2S82(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.3<*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P
M,0IM<V=I9"`B0W)E871E(@IM<V=S='(@(E-T=_-R>B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I
M9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R(")3='?S<GH@;&EN:R(*"B,Z('1E
M;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3,*;7-G:60@(D-R
M96%T92!A(&YE=R!O;F4B"FUS9W-T<B`B4W1W\W)Z(&YO=[$B"@HC.B!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@
M(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R(")5='?S<GH@;F]W>2!F;VQD
M97(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,S8@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HR,30*(RP@9G5Z>GD*;7-G:60@(D-R96%T;W(@4&5R;6ES
M<VEO;G,B"FUS9W-T<B`B1&]M>;9L;F4@=7!R87=N:65N:6$B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,S(R.0IM<V=I9"`B0W)E9&ET(&-A<F0@;G5M8F5R
M(@IM<V=S='(@(DYU;65R(&MA<G1Y(&MR961Y=&]W96HB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3`Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HV-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B0W)O
M871I82(*;7-G<W1R(")#:&]R=V%C:F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#=6)A(@IM<V=S='(@
M(DMU8F$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*(RP@9G5Z>GD*;7-G
M:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B3V)E8VYY(&-Z87,B"@HC
M.B!L:6(O0FQO8VLO=&EM92YP:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z,S`*
M;7-G:60@(D-U<G)E;G0@5&EM92(*;7-G<W1R(")/8F5C;GD@8WIA<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU,PHC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T<B`B
M3V)E8VYY(&-Z87,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"B,L(&9U
M>GIY"FUS9VED(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`B3V)E8VYY(&-Z
M87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8S"B,L(&9U
M>GIY"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S='(@(D]B96-N
M>2!K871A;&]G.B`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S(*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@<W1Y;&4B
M"FUS9W-T<B`B3V)E8VYY(&-Z87,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3`X"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T
M;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B4W!E<G-O;F%L:7IU
M:B!Z861A;FEA('5R=6-H86UI86YE('!R>GD@;&]G;W=A;FEU(&1O("5S+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(E=Y=&YI:B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*(RP@9G5Z>GD*
M;7-G:60@(D-U="!S96QE8W1I;VXB"FUS9W-T<B`B4VMA<W5J('=Y8G)A;K$@
M=&^_<V%M;[;F(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8W(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HV-@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S(@IM<V=S='(@(D-Y<'(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X,@IM<V=I9"`B0WER:6QL:6,@*$M/23@M
M4BDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G
M:60@(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@T"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI
M86X@*$M/23@M52DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C8X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B
M"FUS9W-T<B`B4F5P=6)L:6MA($-Z96-H(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0R,R!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU
M,`IM<V=I9"`B1$0B"FUS9W-T<B`B1$0B"@HC.B!L:6(O2&]R9&4O36%I;G1E
M;F%N8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R(")#;V1Z:65N;FEE
M(@H*(SH@861M:6XO9&%T871R964N<&AP.C8U"B,L(&9U>GIY"FUS9VED(")$
M871A5')E92!"<F]W<V5R(@IM<V=S='(@(D1A=&$B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C,Y."!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HW,@IM<V=I9"`B1&%T92(*;7-G<W1R(")$871A(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(D1A
M=&4@4F5C96EV960B"FUS9W-T<B`B3W1R>GEM86YE(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(X,#8*(RP@9G5Z>GD*;7-G:60@(D1A=&4@<V5L96-T:6]N
M(@IM<V=S='(@(E-K87-U:B!W>6)R86ZQ('1OOW-A;6^VYB(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#`@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,Q,`HC+"!F=7IZ>0IM<V=I9"`B1&%Y(@IM<V=S='(@(D-O
M9'II96YN:64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S
M='(@(E]5<W7Q(&MO;'5M;NHB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,S@U(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B1W)U9'II9?$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C$V"B,L(&9U>GIY"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T
M<B`B1W)U9'II9?$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(P"B,L(&9U>GIY"FUS9VED(")$96-R96%S92!);F1E;G0B
M"FUS9W-T<B`B4F%P;W)T=6H@:F%K;R!N:65S>FMO9&QI=WDB"@HC.B!L:6(O
M<')E9G,N<&AP.C$Q,2!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$X-PHC+"!F
M=7IZ>0IM<V=I9"`B1&5F875L="(*;7-G<W1R(")$;VUYMFQN>2(*"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0W"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q"FUS9VED
M(")$969A=6QT($-O;&]R(@IM<V=S='(@(D1O;7FV;&YY(&MO;&]R(@H*(SH@
M;&EB+TAO<F1E+TED96YT:71Y+G!H<#HY,0IM<V=I9"`B1&5F875L="!)9&5N
M=&ET>2(*;7-G<W1R(")$;VUYMFQN82!T;[]S86UOMN8B"@HC.B!A9&UI;B]P
M97)M<R]E9&ET+G!H<#HQ,3D@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ.38*
M;7-G:60@(D1E9F%U;'0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B1&]M>;9L;F4@
M=7!R87=N:65N:6$B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$Y-PIM
M<V=I9"`B1&5F875L="!P97)M:7-S:6]N<R(*;7-G<W1R(")$;VUYMFQN92!U
M<')A=VYI96YI82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,PHC+"!F
M=7IZ>0IM<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`B4&6S;GD@;W!I<SHB
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<R(&%D;6EN+W!E<FUS+V1E;&5T92YP
M:'`Z-#8@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC.B!L:6(O2&]R9&4O
M4&5R;7,N<&AP.C(Y-2!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,Q-0HC.B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,S,B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C,V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,PHC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$Q-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.0HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z-S,*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.CDY('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,PHC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L
M971E(@IM<V=S='(@(E5S=?$B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$X.2!A
M9&UI;B]G<F]U<',N<&AP.C(Q-PIM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S
M='(@(E5S=?$@1W)U<.HB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C8S
M(&QI8B](;W)D92]097)M<R]522YP:'`Z.#<*;7-G:60@(D1E;&5T92!097)M
M:7-S:6]N(@IM<V=S='(@(E5S=?$@=7!R87=N:65N:6$B"@HC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@
M<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B57-U\2!I('=Y8WIYMN8@=VEA9&]M
M;[9C:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3<*;7-G:60@(D1E;&5T92!C96QL(@IM<V=S='(@(E5S=?$@
M:V]M\W)KZB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`B
M57-U\2!K;VQU;6[J(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*(RP@
M9G5Z>GD*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA
M=&4B"FUS9W-T<B`B5'?S:B!A9')E<R!E+6UA:6PZ(@H*(SH@861M:6XO<&5R
M;7,O9&5L971E+G!H<#HU,"!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,Q-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB
M)7-<(B(*;7-G<W1R(")3:V%S=6H@=7!R87=N:65N:6$@9&QA(%PB)7-<(B(*
M"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,S$W"B,L('!H<"UF;W)M870*
M;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A;GD@
M<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R(")3:V%S;W=AYB!U<')A=VYI96YI
M82!D;&$@7"(E<UPB(&D@=W-Z>7-T:VEE('!O9"UU<')A=VYI96YI83\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8W"FUS9VED(")$96QE=&4@<F]W(@IM<V=S='(@(E5S=?$@=VEE<G-Z(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V1E;&5T96ED96YT:71Y+FEN8SHQ-0IM<V=I
M9"`B1&5L971E('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@(E-K87-U:B!W
M>6)R86ZQ('1OOW-A;6^VYB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B1&5L971E('1H92!C
M=7)R96YT(&-O;'5M;B(*;7-G<W1R(")5<W7Q(&%K='5A;&ZQ(&MO;'5M;NHB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C(*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T
M<B`B57-U\2!A:W1U86QN>2!W:65R<WHB"@HC.B!A9&UI;B]P97)M<R]D96QE
M=&4N<&AP.C0X"FUS9VED(")$96QE=&4@=&AI<R!P97)M:7-S:6]N(&%N9"!A
M;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R(")3:V%S;W=AYB!T;R!U<')A
M=VYI96YI92!I('=S>GES=&MI92!P;V0M=7!R87=N:65N:6$_(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S4*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*
M;7-G<W1R(").:64@;6^_;F$@;W1W;W)Z>>8@;6]D=;-U($UA:6YT96YA;F-E
M7U1A<VL@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-38S(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.34*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C$@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*(RP@9G5Z>GD*;7-G:60@(D1E;&EV
M97)Y('1I;64B"FUS9W-T<B`B57-U\2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HW,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1E;FUA<FLB"FUS9W-T
M<B`B1&%N:6$B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,3`@<V5R=FEC
M97,O<')O8FQE;2YP:'`Z,3$T('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-`IM
M<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`B3W!I<WH@<')O
M8FQE;2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY,S@@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`HC+"!F=7IZ>0IM
M<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B4&6S;GD@;W!I<SHB"@HC.B!L
M:6(O2&]R9&4N<&AP.C$Y-0IM<V=I9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D
M92=S(&QO9V9I;&4I.B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4N<&AP.C$Y
M.0IM<V=I9"`B1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M
M:6YI<W1R871O<BXB"FUS9W-T<B`B4WIC>F5G\[-Y('IO<W1ALWD@>F%L;V=O
M=V%N92!D;&$@861M:6YI<W1R871O<F$N(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$Y.`HC+"!F=7IZ>0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS
M9W-T<B`B1'II8;,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-PIM<V=I
M9"`B1&5W(%!O:6YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,CDT"FUS9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,34*;7-G
M:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L
M969T('1O(')I9VAT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H
M="!T;R!L969T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C,Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T<B`B2V%T86QO9R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3@*;7-G:60@(D1I<W!L87D@,C0M:&]U
M<B!T:6UE<S\B"FUS9W-T<B`B5WFV=VEE=&P@8WIA<R!W(&9O<FUA8VEE(#(T
M+6=O9'II;FYY;3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<*;7-G
M:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R(")5<W1A=VEE;FEA('=Y9VRQ
M9'4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.#@*(RP@9G5Z
M>GD*;7-G:60@(D1I<W!L87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`B
M57-T87=I96YI82!W>6=LL61U(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX
M-0HC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G
M<W1R(")5<W1A=VEE;FEA('=Y9VRQ9'4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C@Q-@HC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T
M<B`B57-T87=I96YI82!W>6=LL61U(@H*(SH@;&EB+TAO<F1E+TU)344O341.
M+G!H<#HQ.3`*(RP@9G5Z>GD*;7-G:60@(D1I<W!O<VET:6]N($YO=&EF:6-A
M=&EO;B(*;7-G<W1R(")2;WIM:65S>F-Z96YI92(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HW,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I
M(@IM<V=S='(@(D2_:6)U=&DB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP
M.C0V(&QI8B](;W)D92]097)M<R]522YP:'`Z,S$U"FUS9VED(")$;R!N;W0@
M9&5L971E(@IM<V=S='(@(DYI92!K87-U:B(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HR-`IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M
M86EN=&5N86YC92YP:'`B"FUS9W-T<B`B0G)A:R!B97IP;[9R961N:65G;R!D
M;W-TZG!U(&1O(&UA:6YT96YA;F-E+G!H<"(*"B,Z('1E;7!L871E<R]D871A
M+W1S=FEN9F\N:6YC.C$Y('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$Y
M"FUS9VED(")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@
M;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G
M:60@(D1O;6EN:6-A(@IM<V=S='(@(D1O;6EN:6MA("A7<W#S;&YO=&$@1&]M
M:6YI:VDI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<S(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(D1O
M;6EN:6MA;F$@*%)E<'5B;&EK82!$;VUI;FEK8?%S:V$I(@H*(SH@;&EB+TAO
M<F1E+TU)344O0V]N=&5N=',N<&AP.C@T,0IM<V=I9"`B1&]W;FQO860B"FUS
M9W-T<B`BIF-IL6=N:6HB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP
M:'`Z.#0Q"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S(@IM<V=S
M='(@(J9C:;%G;FEJ("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V
M-0IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@
M4$A0('-C<FEP="XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(Q,#@*;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B1')U9W,B"FUS9W-T<B`B
M3F%R:V]T>6MI(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#`R"FUS
M9VED(")%+4UA:6PB"FUS9W-T<B`B12UM86EL(@H*(SH@;&EB+TAO<F1E+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<U(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G<W1R(")%:W=A9&]R(@H*
M(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR.30@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHS-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,34@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C<R"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI
M;F,Z,C(*;7-G:60@(D5D:70B"FUS9W-T<B`B161Y8VIA(@H*(SH@;&EB+TAO
M<F1E+T)L;V-K+U5)+G!H<#HU,"!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC
M.C(R"B,L(&9U>GIY"FUS9VED(")%9&ET($)L;V-K(@IM<V=S='(@(D5D>71U
M:B!C>F%R;K$@;&ES=.HB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$X."!A9&UI
M;B]G<F]U<',N<&AP.C(Q-@IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R(")5
M<W7Q($=R=7#J(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HV,B!L:6(O
M2&]R9&4O4&5R;7,O54DN<&AP.C@V"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB
M"FUS9W-T<B`B6FUI9?$@=7!R87=N:65N:64B"@HC.B!S97)V:6-E<R]S:&%R
M97,O961I="YP:'`Z,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S
M='(@(EIM:67Q('5P<F%W;FEE;FEA(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D
M:70N<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I
M;VYS(&9O<B`E<R(*;7-G<W1R("):;6EE\2!U<')A=VYI96YI82!D;&$@)7,B
M"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHU"FUS9VED(")%9&ET(&]P
M=&EO;G,@9F]R.B(*;7-G<W1R("):;6EE\2!U<W1A=VEE;FEA(&1L83HB"@HC
M.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HR,#0@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HR.#`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R
M;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R("):;6EE\2!U<')A=VYI96YI
M82!D;&$@)7,B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T"B,L
M('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM
M<V=S='(@(EIM:67Q('5P<F%W;FEE;FEA(&1L82`E<R(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS-0HC+"!F=7IZ>0IM<V=I9"`B161U8V%T:6]N(@IM
M<V=S='(@(D]P8VIE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`B16=I<'0B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HW-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#<*
M;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@(E-A;'=A9&]R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R
M"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W,"!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(R-`IM<V=I9"`B16UA:6PB"FUS9W-T
M<B`B16UA:6PB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V-2!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$R"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#`*;7-G:60@(D5M86EL($%D9')E
M<W,B"FUS9W-T<B`B061R97,@96UA:6PB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3DV-`IM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM
M<V=S='(@(D%D<F5S>2!E;6%I;"!M=7-ZL2!D;R!S:65B:64@<&%S;W=AYBXB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DY,`HC+"!F=7IZ>0IM<V=I9"`B
M16UA:6P@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B2&%SLV\B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C@P"FUS9VED(")%
M;6]T:6-O;G,B"FUS9W-T<B`B16UO=&EK;VYY(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*;7-G:60@(D5M<'1Y(&UE<W-A9V4N
M(@IM<V=S='(@(E!U<W1A('=I861O;6^VYBXB"@HC.B!L:6(O2&]R9&4O075T
M:"]L9&%P+G!H<#HQ,C@*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B
M0G)A:R!R97IU;'1A=/-W+B(*"B,Z(&QI8B](;W)D92]344PO2V5Y=V]R9',N
M<&AP.C$Q,PHC+"!F=7IZ>0IM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM
M<V=S='(@(D]P<O._;FEJ(&9O;&1E<B!K;W-Z82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,S4*;7-G:60@(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA
M9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3`*;7-G:60@(D5N86)L92!R
M:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@(E>SL6-Z>>8@;65N
M=2!K;VYT96MS=&]W92!P;V0@<')A=WEM('!R>GEC:7-K:65M(&UY<WIY/R(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3DW(&QI8B](;W)D92]&;W)M+G!H
M<#HR.#$P"B,L(&9U>GIY"FUS9VED(")%;F0@>65A<B(*;7-G<W1R(")2;WIW
M:?$@<&%S96LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$S"FUS9VED("(B"B)%;G1E<B!A
M('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF
M('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H
M870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDY(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW-@IM<V=I9"`B17%U871O<FEA;"!'=6EN96$B"FUS9W-T<B`B1W=I;F5A
M(%+S=VYI:V]W82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T<B`B17)Y=')E82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-R!L:6(O0FQO8VLO
M;65T87(N<&AP.C,V"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N
M97(O<W1A='5S+G!H<#HR-R!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C<Y
M"FUS9VED(")%<G)O<B(*;7-G<W1R(")"L[%D(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*(RP@9G5Z>GD*;7-G:60@(D5R<F]R
M('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B0G)A:R!F;VQD97)U('H@
M;F]W>6UI('=I861O;6^V8VEA;6DB"@HC.B!L:6(O5D93+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(D*SL60@<')Z
M>2!Z87!I<VEE(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%<W1O;FEA(@IM<V=S='(@(D5S
M=&]N:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<Q"FUS9VED(")%=&AI;W!I82(*;7-G<W1R(")%=&EO<&EA(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,V"B,L(&9U>GIY"FUS9VED(")%=&AN
M:6,B"FUS9W-T<B`B17-T;VYI82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B175R;W!A(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,S,0IM<V=I9"`B179E<GD@,34@;6EN=71E
M<R(*;7-G<W1R(")#;R!K8;]D92`Q-2!M:6YU="(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.#$*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R
M(")#;R!K8;]D92`R(&UI;G5T>2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS,C@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.0IM<V=I9"`B179E<GD@
M,S`@<V5C;VYD<R(*;7-G<W1R(")#;R!K8;]D92`S,"!S96MU;F0B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,P(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS.#(*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R(")#;R!K8;]D
M92`U(&UI;G5T(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HV,`IM
M<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T<B`B0V\@:V&_9&4@>F%L;V=O=V%N
M:64B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,R"FUS9VED(")%=F5R
M>2!H86QF(&AO=7(B"FUS9W-T<B`B0V\@:V&_9&4@</.S(&=O9'II;GDB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(Y(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS.#`*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R(")#;R!K8;]D
ML2!M:6YU=.HB"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR.`IM
M<V=I9"`B17AA;7!L92!V86QU97,Z(@IM<V=S='(@(E!R>GEKLV%D;W=E('=A
M<G1OMF-I.B(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3(X(&%D;6EN+W!H<'-H96QL+G!H<#HX,0IM<V=I9"`B17AE
M8W5T92(*;7-G<W1R(")7>6MO;F%J(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA
M>6]U="YP:'`Z,SDT"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B4F]Z=VGQ(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHS,0IM<V=I9"`B17AP
M86YD(%-I9&5B87(B"FUS9W-T<B`B4F]Z=VGQ('!A<V5K(@H*(SH@;&EB+TAO
M<F1E+U-13"]+97EW;W)D<RYP:'`Z,38X"B,L(&9U>GIY"FUS9VED(")%>'!E
M8W1E9"`G*2<B"FUS9W-T<B`B5WEK;VYA:B(*"B,Z(&QI8B](;W)D92]344PO
M2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R
M('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HT,#$*;7-G:60@(D5X<&ER871I;VX@1&%T92(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8W-@HC+"!F
M=7IZ>0IM<V=I9"`B17AP;VYE;G0B"FUS9W-T<B`B16MS<&]R="(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S$*
M(RP@9G5Z>GD*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(D1O;7FV;&YY(&MO
M;&]R(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`HC+"!F=7IZ>0IM
M<V=I9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R(")79W)Y=V%N:64@
M<&QI:_-W(&YI92!J97-T(&]B<[-U9VEW86YE+B(*"B,Z(&QI8B](;W)D92]0
M<F5F<R]S<6PN<&AP.C(Q-@HC+"!F=7IZ>0IM<V=I9"`B1F%I;&5D(')E=')I
M979I;F<@<')E9F5R96YC97,N(@IM<V=S='(@(D*SL60@<&]D8WIA<R!Z;6EA
M;GD@=7-T87=I9?$N(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,3`P
M"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS
M9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M($Q$
M05`N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<VUB+G!H<#HY.`HC+"!F=7IZ>0IM
M<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T
M<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M($Q$05`N
M(@H*(SH@;&EB+U9&4R]F='`N<&AP.C8P,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B0K.Q9"!P
M;V1C>F%S(&MO<&EO=V%N:6$@>B!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F='`N
M<&AP.C8P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!T
M;R!<(B5S7"(N(@IM<V=S='(@(D*SL60@<&]D8WIA<R!K;W!I;W=A;FEA(&1O
M(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O075T:"]S87-L+G!H<#HX-PHC+"!F
M=7IZ>0IM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T
M:6]N+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R
M=V5R96T@3$1!4"`E<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-C0Q"B,L('!H
M<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS
M9W-T<B`B0K.Q9"!P;V1C>F%S('!R>F5N;W-Z96YI82!D;R!<(B5S7"(N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*(RP@
M9G5Z>GD*;7-G:60@(D9A:7(B"FUS9W-T<B`B3V0B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z.#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<Y
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&86QK;&%N
M9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B1F%L:VQA;F1Y("A-86QW
M:6YY*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S,*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B5WES<'D@3W=C
M>F4B"@HC.B!L:6(O2&]R9&4O0TQ)+G!H<#HR,S@*;7-G:60@(D9A=&%L($5R
M<F]R.B(*;7-G<W1R(")"L[%D(&MR>71Y8WIN>3H@(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R
M(")&86MS(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C,W-2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G
M:60@(D9E8G)U87)Y(@IM<V=S='(@(DQU='DB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(R,`IM<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Y"FUS9VED(")&965L<R!L
M:6ME.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3D*(RP@9G5Z>GD*;7-G:60@(D9E=R!3:&]W97)S(@IM
M<V=S='(@(DEM<&]R="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(P"B,L(&9U>GIY"FUS9VED(")&97<@4VYO=R!3:&]W97)S
M(@IM<V=S='(@(DEM<&]R="(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.30U
M"FUS9VED(")&:65L9"!M871R:7@B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C@S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX
M,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEJ:2(*
M;7-G<W1R(")&:62_:2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N
M<&AP.C8P(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+WII<"YP:'`Z-C<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G
M>BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@
M9FEL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,T-@IM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S='(@(DUE;F5DOV5R('!L
M:6OS=R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8S(&QI
M8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]T9WHN<&AP.C@R"FUS9VED(")&:6QE($YA;64B"FUS9W-T
M<B`B3F%Z=V$@<&QI:W4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDY-`IM
M<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T<B`B5WEB\W(@<&QI:W4B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30X.`IM<V=I9"`B1FEL92!U<&QO860B
M"FUS9W-T<B`B5V=R>7=A;FEE('!L:6MU(@H*(SH@;&EB+TAO<F1E+T)R;W=S
M97(N<&AP.C@V,PIM<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N
M(@IM<V=S='(@(E=G<GEW86YI92!P;&EK\W<@;FEE(&IE<W0@;V)SLW5G:7=A
M;F4N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Y"FUS9VED(")&
M:6QT97)S(@IM<V=S='(@(D9I;'1R>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HX,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D9I;FQA;F0B"FUS9W-T
M<B`B1FEN;&%N9&EA(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$W,0HC+"!F
M=7IZ>0IM<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R("));6GJ(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@HC+"!F
M=7IZ>0IM<V=I9"`B1FER<W0@475A<G1E<B(*;7-G<W1R("));6GJ(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S.0IM<V=I9"`B
M1FEX(')A=&EO(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,30*;7-G:60@(D9L:7`B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R("(B
M"@HC.B!L:6(O5D93+VUU<W%L+G!H<#HQ,#<@;&EB+U9&4R]S<6PN<&AP.C$V
M,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@
M;F]T(&5X:7-T(@IM<V=S='(@(E6_>6-I92!F;VQD97)U(&YI92!J97-T(&%K
M='EN=V4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR,@HC+"!F=7IZ>0IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R(")$
M;VUYMFQN>2!K;VQO<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM
M<V=I9"`B1F]O9"(*;7-G<W1R(")*961Z96YI92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@HC+"!F
M=7IZ>0IM<V=I9"`B1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I
M;6%G97,B"FUS9W-T<B`B5WEM86=A;F$@:F5S="!O8G.S=6=A(&E&<F%M97,H
M<+-Y=V%JL6-Y8V@@<F%M96LI('!R>F5Z('!R>F5G;+%D87)KZB(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S,T"B,L(&9U>GIY"FUS9VED(")&;W)E8V%S
M="`H5$%&*2(*;7-G<W1R(")5<W1A=VEE;FEA('=Y9VRQ9'4B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S$*;7-G:60@(B(*(D9O<F5C87-T
M($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N
M<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@
M8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY.`IM<V=I9"`B1F]R9V]T('EO
M=7(@<&%S<W=O<F0_(@IM<V=S='(@(EIA<&]M;FEALV6V(&AA<[-A/R(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#D*(RP@9G5Z>GD*;7-G:60@
M(D9O<FUS(@IM<V=S='(@(E5W86=I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C(Q"B,L(&9U>GIY"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(E5W86=I
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY"B,L(&9U>GIY"FUS9VED
M(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B57=A9VDB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S@*(RP@9G5Z>GD*;7-G:60@(D9O<G1U;F5S(@IM<V=S
M='(@(E5W86=I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y"B,L(&9U
M>GIY"FUS9VED(")&;W)T=6YE<R`R(@IM<V=S='(@(E5W86=I(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P,`HC+"!F=7IZ>0IM<V=I9"`B1F]R
M=6US(@IM<V=S='(@(E5W86=I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$P.0HC+"!F=7IZ>0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B4')Z
M96MAOR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C`*(RP@9G5Z>GD*;7-G:60@(D9R(@IM<V=S='(@(D]D(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PHC
M+"!F=7IZ>0IM<V=I9"`B1G)A;65S(@IM<V=S='(@(DYA>G=A('6_>71K;W=N
M:6MA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@W(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW,PIM<V=I9"`B1G)A;F-E(@IM<V=S='(@(D9R86YC:F$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E+"!-971R;W!O
M;&ET86XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDQ
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R
M(")'=6IA;F$@1G)A;F-U<VMA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$X-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B
M"FUS9W-T<B`B4&]L:6YE>FIA($9R86YC=7-K82(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@V
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H
M(%-O=71H97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(D9R86YC=7-K:64@5&5R
M>71O<FEA(%!OLW5D;FEO=V4@:2!!;G1A<FMT>6-Z;F4B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*;7-G
M<W1R(")/9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S8@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,T.`HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,SDT"B,L(&9U>GIY"FUS9VED(")&<F]M('1H
M92`B"FUS9W-T<B`B3V0B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8SHT.`HC+"!F=7IZ>0IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G
M<W1R(")09;-N>2!O<&ES(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@R(&QI
M8B]";&]C:R]M;V]N+G!H<#HQ.#$*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,Y"B,L
M(&9U>GIY"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`B5'=O:F4@:6UIZB(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX."!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,*
M;7-G:60@(D=A8F]N(@IM<V=S='(@(D=A8F]N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,P"FUS9VED
M(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HY-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=A;6)I
M82(*;7-G<W1R(")'86UB:6$B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C0R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#
M;VYF:6=U<F%T:6]N(@IM<V=S='(@(DAO<F1E(&YI92!J97-T('<@<&6S;FD@
M<VMO;F9I9W5R;W=A;F4N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O
M;F9I9RYH=&UL.C$P"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C@Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<T
M"FUS9VED(")'96]R9VEA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HV.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS
M9W-T<B`B3FEE;6-Y(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDS(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`B1VAA;F$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.30@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.CDR"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U"FUS
M9VED(")':6)R86QT87(B"FUS9W-T<B`B1VEB<F%L=&%R(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S4*(RP@9G5Z>GD*;7-G:60@(D=I=F5N
M($YA;64B"FUS9W-T<B`B365N962_97(@<&QI:_-W(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V%P<"YI;F,Z,3(*;7-G:60@(D=O(@IM<V=S='(@(DEDO"(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,`IM<V=I9"`B1V]E9&5L(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O
M;V=L92!396%R8V@B"FUS9W-T<B`B5WES>G5K:7=A<FMA($=O;V=L92(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,C`*;7-G:60@
M(D=R87ES8V%L92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3`P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W)E96-E(@IM<V=S='(@
M(D=R96-J82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U"B,L(&9U>GIY
M"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`BIG)O9&MO=V]E
M=7)O<&5J<VMI("A)4T\M.#@U.2TR*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HY-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=R965N;&%N9"(*;7-G
M<W1R(")'<F5N;&%N9&EA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@Y
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1W)E;F%D82(*;7-G<W1R(")'<F5N
M861A(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-S`*(RP@9G5Z>GD*;7-G:60@
M(D=R;W5P($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN:7-T<F%C:F$B
M"@HC.B!L:6(O2&]R9&4O1W)O=7`N<&AP.C4X"FUS9VED(")'<F]U<"!N86UE
M<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M
M<R]E9&ET+G!H<#HR,#$@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR-S<*(RP@
M9G5Z>GD*;7-G:60@(D=R;W5P('!E<FUI<W-I;VYS(@IM<V=S='(@(D1O;7FV
M;&YE('5P<F%W;FEE;FEA(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3<V
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X(&QI8B](;W)D92]097)M<R]522YP
M:'`Z,C4P"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<W"FUS9VED
M(")'<F]U<',B"FUS9W-T<B`B1W)U<'D@9'ES:W5S>6IN92(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HY."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=U
M861E;&]U<&4B"FUS9W-T<B`B1W=A9&5L=7!A(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$P,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U86TB"FUS
M9W-T<B`B1W5A;2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<W"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B1W=A=&5M
M86QA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'=65R
M;G-E>2(*;7-G<W1R(")'=65R;G-E>2(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N
M<&AP.C$R-R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(P-0HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C@X"B,L(&9U>GIY"FUS9VED(")'=65S="!0
M97)M:7-S:6]N<R(*;7-G<W1R(")$;VUYMFQN92!U<')A=VYI96YI82(*"B,Z
M(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$R."!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.C(P-@HC+"!F=7IZ>0IM<V=I9"`B1W5E<W0@<&5R;6ES<VEO;G,B"FUS
M9W-T<B`B1&]M>;9L;F4@=7!R87=N:65N:6$B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#$W"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDW(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HY.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM
M<V=I9"`B1W5I;F5A(@IM<V=S='(@(D=W:6YE82(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P
M,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5I;F5A
M+4)I<W-A=2(*;7-G<W1R(")'=VEN96$@0FES<V%U(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$P-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=7EA
M;F$B"FUS9W-T<B`B1W5J86YA(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDV
M,`IM<V=I9"`B2%1-3"(*;7-G<W1R(")(5$U,(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L
M;"!I;B!R;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O
M=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T
M86)L92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D
M;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"]H='1P+G!H<#HQ-3<*(RP@
M9G5Z>GD*;7-G:60@(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")5=VEE<GIY=&5L;FEE;FEE(&YI92!P;W=I;V2S;R!S:>HB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$P(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*
M;7-G:60@(DAA:71I(@IM<V=S='(@(DAA:71I(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z-#`R"B,L(&9U>GIY"FUS9VED(")(87-H+4%L9V]R:71H
M;2(*;7-G<W1R(")!;&=O<GET;2!P;V1P:7-U(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDQ.2!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,CDS,0HC+"!F=7IZ>0IM<V=I9"`B2&5A9&5R(@IM<V=S='(@(DYA
M9[/S=VMI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES
M;&%N9',B"FUS9W-T<B`B5WES<'D@2&5A<F0@:2!-8T1O;F%L9&$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PHC+"!F=7IZ
M>0IM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R(")5=V%G:2(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@V"B,L(&9U>GIY"FUS9VED(")(96)R97<@
M*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`BIG)O9&MO=V]E=7)O<&5J<VMI("A)
M4T\M.#@U.2TR*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S0*(RP@9G5Z>GD*;7-G:60@(DAE:6=H="(*;7-G
M<W1R(")7>7-O:VDB"@HC.B!L:6(O2&]R9&4O2&5L<"YP:'`Z,3<Y(&QI8B](
M;W)D92](96QP+G!H<#HQ.#8@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<*
M(SH@=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C,*;7-G:60@(DAE;'`B"FUS
M9W-T<B`B4&]M;V,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,W,PHC+"!F=7IZ>0IM<V=I
M9"`B2&5L<&5R(@IM<V=S='(@(E!O;6]C(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C(Y"B,L(&9U>GIY"FUS9VED(")(96UI<W!H97)E(@IM<V=S='(@(E!O
M;6]C(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3<@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@(DAE<F4@:7,@=&AE(&)E
M9VEN;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DAI9V@B"FUS
M9W-T<B`B5WES;VMI(@H*(SH@;&EB+TAO<F1E+TAI<W1O<GDN<&AP.C,R,0IM
M<V=I9"`B2&ES=&]R>2!E;G1R>2!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@=&5M
M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C0*;7-G:60@(DAO7VUE
M(@IM<V=S='(@(E]3=&%R="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M-#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6871I8V%N
M($-I='D@4W1A=&4I(@IM<V=S='(@(E=A='EK86X@*%-T;VQI8V$@07!O<W1O
M;'-K82DB"@HC.B!L:6(O2&]R9&4N<&AP.C$T,S4*;7-G:60@(DAO;64B"FUS
M9W-T<B`B4&]C>K%T96LB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$R,B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$U
M-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(D%D<F5S(&1O;6]W>2(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS9VED
M(")(;VUE(%!H;VYE(@IM<V=S='(@(E1E;"X@9&]M+B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$P-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&]N
M9'5R87,B"FUS9W-T<B`B2&]N9'5R87,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3`V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N9R(*
M;7-G<W1R(")(;VYG2V]N9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HV-0IM<V=I9"`B2&]R9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!L:6(O2&]R
M9&4O2V]L86(N<&AP.C0R,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@
M:6X@;65S<V%G92`E<R(*;7-G<W1R(")59&&S;R!S:>H@=7-U;K'F(%PB)7-<
M(B!Z('-Y<W1E;74N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HR-S<*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S
M86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R(")59&&S;R!S
M:>H@=7-U;K'F(%PB)7-<(B!Z('-Y<W1E;74N(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HT,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C`X"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E
M9"`E<R!<(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(%5D8;-O('-IZB!U
M<W5NL>8@)7,@7"(E<UPB(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,34T
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C
M8V5S<V9U;&QY('-Y;F-H<F]N:7-E9"`E<R!<(B5S7"(B"FUS9W-T<B`B561A
MLV\@<VGJ('5S=6ZQYB!<(B5S7"(@>B!S>7-T96UU+B(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G
M<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N
M<VEO;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0X,0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T
M<B`B561ALV\@<VGJ('5S=6ZQYB!<(B5S7"(@>B!S>7-T96UU+B(*"B,Z(&QI
M8B](;W)D92]+;VQA8BYP:'`Z,3(P-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB
M.B`E<R(*;7-G<W1R(")59&&S;R!S:>H@=7-U;K'F(%PB)7-<(B!Z('-Y<W1E
M;74N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT-3(*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE
M=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R(")5
M9&&S;R!S:>H@=7-U;K'F(%PB)7-<(B!Z('-Y<W1E;74N(@H*(SH@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HQ,34Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<
M(CH@)7,B"FUS9W-T<B`B561ALV\@<VGJ('5S=6ZQYB!<(B5S7"(@>B!S>7-T
M96UU+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(X,@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC
M:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@(E5D8;-O('-IZB!U<W5NL>8@
M7"(E<UPB('H@<WES=&5M=2XB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C,Q
M.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N
M:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(E5D8;-O('-IZB!U<W5NL>8@
M7"(E<UPB('H@<WES=&5M=2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX,@IM<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*
M;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I9"`B
M2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@
M;&EK92!T;R!M97)G93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z,C@*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN
M<RD@87)E('1H97)E/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N
M>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@X(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C,P"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0W"FUS9VED(")(=6UI9&ET
M>3H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM
M<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R>2(*
M;7-G<W1R(")7ZF=R>2(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ
M-S(@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z
M("5S(@IM<V=S='(@(E!OL[%C>F5N:64@;FEE('!O=VEO9+-O('-IZCH@)7,B
M"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,C$T(&QI8B](;W)D92]!
M=71H+V-Y<G-Q;"YP:'`Z,CDU"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")0
M;[.Q8WIE;FEE(&YI92!P;W=I;V2S;R!S:>HZ("5S(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O8WER=7,N<&AP.C$W.2!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP
M.C(T,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X
M('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B57=I97)Z>71E
M;&YI96YI92!N:64@<&]W:6]DLV\@<VGJ+B`E<R(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,S$W"B,L(&9U>GIY"FUS9VED("))4"!!9&1R97-S(@IM<V=S
M='(@(D%D<F5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O:7!B87-I8RYP:'`Z-S<*
M(RP@9G5Z>GD*;7-G:60@(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B0FQO:R!<(DUE=&%R7"(@;FEE(&IE<W0@9&]S=.IP;GDN(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O:7!B87-I8RYP:'`Z.#D*(RP@9G5Z>GD*;7-G:60@
M(DE0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM
M<V=S='(@(D)L;VL@7")-971A<EPB(&YI92!J97-T(&1O<W3J<&YY+B(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))
M4"!L;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.0HC+"!F
M=7IZ>0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(E=P<F]W
M862\(&ML=6-Z('1U=&%J(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@R"FUS9VED("))8V5L86YD(@IM<V=S='(@(DES
M;&%N9&EA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V.`IM<V=I9"`B
M26-O;G,@3VYL>2(*;7-G<W1R(")4>6QK;R!I:V]N>2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-CD*;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G
M<W1R(")):V]N>2!Z('1E:W-T96TB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3@R"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@(DYA>G=A
M('1OOW-A;6^V8VDZ(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP
M.C4X.0HC+"!P:'`M9F]R;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA
M>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#<*;7-G
M:60@(B(*(DEF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R
M;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B
M;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$U.`IM<V=I
M9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T
M:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L
M87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`HC
M+"!F=7IZ>0IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B4&]D9VRQ
M9"!P;V-Z='DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,W"B,L(&9U>GIY"FUS9VED("));6%G92!54DPB"FUS
M9W-T<B`B1W)A9FEK82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,0HC+"!F=7IZ>0IM<V=I9"`B26UA
M9V4@55),.B(*;7-G<W1R(")'<F%F:6MA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,R"FUS9VED("))
M;6%G92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED
M("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ-S8R"B,L(&9U>GIY"FUS9VED("));6%G92!U<&QO860B
M"FUS9W-T<B`B5V=R>7=A;FEE('!L:6MU(@H*(SH@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R(")'<F%F:6MA(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O
M9&%T96UA<"YI;F,Z,3`*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU
M-R!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(DEM<&]R
M=&]W86YE('!O;&4Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI
M;F,Z,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S
M(@IM<V=S='(@(DEM<&]R=&]W86YE('!O;&4Z("5S(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHW,PIM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*
M;7-G<W1R("));7!O<G1O=V%N92!P;VQA.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`HC+"!F=7IZ>0IM
M<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T<B`B5W!R;W=A9+P@:VQU
M8WH@='5T86HB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ,S4*
M;7-G:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@HC+"!F
M=7IZ>0IM<V=I9"`B26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R
M9"XB"FUS9W-T<B`B4')O<WKJ('!O9&'F(&YA>G?J('6_>71K;W=N:6MA(&D@
M:&%SLV\B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I
M9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S
M+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@
M:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"B,L(&9U>GIY
M"FUS9VED("));F-R96%S92!);F1E;G0B"FUS9W-T<B`B4F%P;W)T=6H@:F%K
M;R!N:65S>FMO9&QI=WDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$V
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DEN9&EA(@IM<V=S='(@(DEN9&EE
M(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,30Q('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3,T"FUS9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3(@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX,`IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(DEN9&]N97IJ82(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED
M("));F9O(@IM<V=S='(@(DEN9F\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C0V"B,L(&9U>GIY"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R
M(")4=V]J92!I;F9O<FUA8VIE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,Q.`HC+"!F=7IZ>0IM<V=I9"`B26YF;W)M871I;VX@;F\@;&]N
M9V5R(&%V86EL86)L92XB"FUS9W-T<B`B26YF;W)M86-J92!O(&]S;V)I<W1Y
M;2!K;'5C>G4@<'5B;&EC>FYY;2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`HC+"!F=7IZ>0IM<V=I9"`B
M26YS97)T($-?;VQU;6X@069T97(B"FUS9W-T<B`B5W!R;W=A9+P@:VQU8WH@
M='5T86HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C`*;7-G:60@(DEN<V5R="!);6%G92(*;7-G<W1R
M(")7:VQE:B!O8G)A>F5K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P,`HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(%1A8FQE
M(@IM<V=S='(@(E!R>GEKLV%D;W=E('=A<G1OMF-I.B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*(RP@9G5Z>GD*;7-G
M:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("):;6EE\2!L:6YK+BXN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,S"B,L(&9U>GIY"FUS9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B
M"FUS9W-T<B`B5W!R;W=A9+P@:VQU8WH@='5T86HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*(RP@9G5Z
M>GD*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E
M;G0@;VYE(@IM<V=S='(@(E5S=?$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C0*(RP@9G5Z>GD*;7-G:60@
M(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N92(*
M;7-G<W1R(")5<W7Q(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8Q"B,L(&9U>GIY"FUS9VED("));G-E<G0@
M82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R(")5<W7Q
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8P"B,L(&9U>GIY"FUS9VED("));G-E<G0@82!N97<@<F]W(&)E
M9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B57-U\2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.0HC
M+"!F=7IZ>0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C
M=7)R96YT(&YO9&4B"FUS9W-T<B`B57-U\2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`HC+"!F=7IZ>0IM
M<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N
M;V1E(@IM<V=S='(@(E5S=?$B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U
M,`HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T96UP;&%T92(*
M;7-G<W1R(")4=_-J(&%D<F5S(&4M;6%I;#HB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C,Q"FUS9VED("));G-E<G0@86X@96UA:6P@861D<F5S<R!T
M;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU.`HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(&-E;&P@869T
M97(B"FUS9W-T<B`B0G)A:R!R97IU;'1A=/-W+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*(RP@9G5Z>GD*
M;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R(")7<')O=V%DO"!K
M;'5C>B!T=71A:B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C0*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!C;VQU
M;6X@869T97(B"FUS9W-T<B`B0G)A:R!R97IU;'1A=/-W+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*(RP@
M9G5Z>GD*;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(E=P
M<F]W862\(&ML=6-Z('1U=&%J(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.CDP"B,L(&9U>GIY"FUS9VED("));G-E<G0@;65S<V%G97,B
M"FUS9W-T<B`B0G)A:R!R97IU;'1A=/-W+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`HC+"!F=7IZ>0IM
M<V=I9"`B26YS97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R(")7<')O=V%D
MO"!K;'5C>B!T=71A:B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PHC+"!F=7IZ>0IM<V=I9"`B26YS97)T
M('!A<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B5W!R;W=A9+P@:VQU8WH@='5T
M86HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8Y"B,L(&9U>GIY"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM
M<V=S='(@(E=P<F]W862\(&ML=6-Z('1U=&%J(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`HC+"!F=7IZ>0IM
M<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`B5W!R;W=A9+P@:VQU
M8WH@='5T86HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(R"FUS9VED
M("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@
M<75E<W1I;VXZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C8*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="]-
M;V1I9GD@26UA9V4B"FUS9W-T<B`B6FUI9?$@;&EN:RXN+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#D*(RP@9G5Z>GD*
M;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*;7-G<W1R("):;6EE\2!L:6YK
M+BXN(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PHC
M+"!F=7IZ>0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O
M('1H92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B3FEE(&UOOVYA(&]T
M=V]R>GGF(&UO9'6S=2!-86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I
M96YT(&-R961I="XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$P-S4*(RP@9G5Z>GD*;7-G:60@(DEN=&5G97(B"FUS9W-T<B`B3V1W<O/F
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,S,*(RP@9G5Z>GD*;7-G:60@
M(DEN=&5G97(@;&ES="(*;7-G<W1R(")/9'=R\^8B"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI9"!51$@N
M("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T-O;7!R97-S+WII<"YP:'`Z,3<P(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N
M<&AP.C(P,0HC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HR,3`*(RP@
M9G5Z>GD*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`B061R97,@
M9&]M;W=Y(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`HC+"!F=7IZ
M>0IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`B1&]M>;9L
M;F4@=7!R87=N:65N:6$B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,Q,@HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!B871C:"!)1"XB
M"FUS9W-T<B`B3FEE<&]P<F%W;GD@240B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C`X."!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$U.2!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C(S,PHC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(Y.`IM<V=I9"`B
M26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`B5WESLV%N92!N:65P
M<F%W:62S;W=E(&1A;F4N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S
M<RXB"FUS9W-T<B`B3FEE<')A=VEDLV]W>2!A9')E<R!D;V-E;&]W>2XB"@HC
M.B!L:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HX,2!L:6(O2&]R9&4O0V]M
M<')E<W,O9&)X+G!H<#HQ,#`*(SH@;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP
M:'`Z,C(P"FUS9VED("));G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@(DYI
M97!R87=I9+-O=WD@9F]R;6%T('!L:6MU(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$V-`IM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME>2XB
M"FUS9W-T<B`B3FEE<')A=VEDLV]W>2!K;'5C>B!L:6-E;F-J:2XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34X"B,L(&9U>GIY"FUS9VED
M("));G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(").:65Z;F%N
M>2!A9')E<V%T(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#<*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S
M='(@(DYI97!O<')A=VYA(&YA>G=A(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#,*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@;W(@
M;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(D1O;7FV;&YE('5P<F%W;FEE;FEA
M(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.38*(RP@
M9G5Z>GD*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+B(*
M;7-G<W1R(")$;VUYMFQN92!U<')A=VYI96YI82(*"B,Z(&%D;6EN+W!E<FUS
M+V%D9&-H:6QD+G!H<#HT,PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!P87)E
M;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B1&]M>;9L;F4@=7!R87=N:65N:6$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38P"B,L(&9U>GIY
M"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(D1O;7FV;&YE
M('5P<F%W;FEE;FEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$V,@HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O9&4N(@IM
M<V=S='(@(D%D<F5S(&1O;6]W>2(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`V"B,L(&9U>GIY"FUS9VED("));G9A;&ED('!R;W1O
M8V]L+B(*;7-G<W1R(").:65P;W!R87=N>2!O8FIE8W1)9"(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY,PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R
M(").:65P;W!R87=N>2!W<&ES(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ
M,#0S(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(R,`HC+"!F=7IZ>0IM<V=I9"`B
M26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B3FEE<&]P<F%W;GD@;V)J
M96-T260B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M,0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS
M9W-T<B`B061R97,@9&]M;W=Y(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,3$*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@=6YI8V]D
M92!D871A+B(*;7-G<W1R(")!9')E<R!D;VUO=WDB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S(U"B,L(&9U>GIY"FUS9VED("));G9E;G1O<GDB
M"FUS9W-T<B`B3FEE<&]P<F%W;GD@=W!I<R(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B27)A;BP@27-L
M86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("))<F%N(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$Q."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q
M(@IM<V=S='(@(DER86LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$S
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS9W-T<B`B27)L
M86YD:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED("))
M<VQE(&]F($UA;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR-`HC+"!F=7IZ>0IM<V=I9"`B27-O;&%T960@
M5"U3=&]R;7,B"FUS9W-T<B`B57=A9VDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3$T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DES<F%E;"(*;7-G
M<W1R("))>G)A96PB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8R
M-0IM<V=I9"`B27-S=65R(@IM<V=S='(@(E=Y9&%W8V$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*(RP@9G5Z>GD*;7-G
M:60@(DET86QI8R(*;7-G<W1R(")7LV]C:'DB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3(Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,34*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DET86QY(@IM
M<V=S='(@(E>S;V-H>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C,@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G<W1R(")*86UA
M:FMA(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W
M-"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@
M(DIA;G5A<GDB"FUS9W-T<B`B4W1Y8WIE\2(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F%P86XB"FUS
M9W-T<B`B2F%P;VYI82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS
M9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,C(*(RP@9G5Z>GD*;7-G:60@(DIE<G-E
M>2(*;7-G<W1R(")'=65R;G-E>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F]R9&%N(@IM<V=S='(@
M(DIO<F1A;B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HS.#`@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS
M9VED(")*=6QY(@IM<V=S='(@(DQI<&EE8R(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HS-SD@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0Q-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S='(@(D-Z97)W:65C
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I
M9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Y"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3<*;7-G:60@(DIU
M<W1I9GD@1G5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,
M969T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$V"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S8@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R(")+87IA8VAS
M=&%N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T
M-@IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$R-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+
M96YY82(*;7-G<W1R(")+96YI82(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N
M<&AP.C@U"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#`P"FUS9VED(")+97D@0W)E871I;VXB
M"FUS9W-T<B`B5'=O<GIE;FEE(&ML=6-Z82(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C0P,PIM<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@
M(D]D8VES:R!K;'5C>F$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT
M,#$*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`B1+-U9V^VYB!K;'5C>F$B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,#`*;7-G:60@(DME>2!4
M>7!E(@IM<V=S='(@(E1Y<"!K;'5C>F$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C4Y.`HC+"!F=7IZ>0IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S
M='(@(E=I861O;6^VYB(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<R
M.0IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y
M<V5R=F5R+B(*;7-G<W1R(")+;'5C>B!J=;\@:7-T;FEE:F4@;F$@<'5B;&EC
M>FYY;2!S97)W97)Z92!K;'5C>GDN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0S"FUS9VED(")+:61S(@IM<V=S='(@(D1Z:65C:2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$R,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B
M2VER:6)A=&DB"FUS9W-T<B`B2VER:6)A=&DB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3,R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C(*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!$
M96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM<V=S='(@(DMO<F5A
M\7-K82!297!U8FQI:V$@3'5D;W=O+41E;6]K<F%T>6-Z;F$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3,S(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,C,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@
M(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R(")297!U8FQI:V$@2V]R96DB
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B2V]R96%N("A%
M54,M2U(I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@(DMU
M=V5J="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX,PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R(")+:7)G:7-T86XB
M"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*;7-G:60@(DQA7WEO
M=70B"FUS9W-T<B`B5WEG;+%D("A?>2DB"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C<Y"FUS9VED("),86YG=6%G92(*;7-G<W1R(")*ZGIY:R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$R-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS
M9W-T<B`B3&%O<R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*(RP@9G5Z
M>GD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R(").87IW:7-K;R(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HX."!L:6(O0FQO8VLO;6]O;BYP:'`Z.3`*(RP@
M9G5Z>GD*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R(").87IW:7-K;R(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Q"B,L(&9U>GIY"FUS9VED("),
M87-T(%5P9&%T960Z(@IM<V=S='(@(DYA>G=I<VMO(@H*(SH@;&EB+TAO<F1E
M+T%U=&@N<&AP.C8X-@HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN
M.B`E<R(*;7-G<W1R(")/<W1A=&YI92!L;V=O=V%N:64Z("5S(@H*(SH@;&EB
M+TAO<F1E+T%U=&@N<&AP.C8X.`HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T
M(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(D]S=&%T;FEE(&QO9V]W86YI
M93H@)7,@>B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HV.#,*;7-G:60@
M(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(D]S=&%T;FEE(&QO9V]W86YI
M93H@;FEG9'DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30V(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#D*;7-G:60@(DQA='9I82(*;7-G<W1R("*C;W1W82(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`HC+"!F=7IZ>0IM<V=I9"`B3&%W
M(@IM<V=S='(@(DYI<VMI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<Y"B,L(&9U>GIY"FUS9VED("),87EO=70B
M"FUS9W-T<B`B5WEL;V=U:B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B
M;W)D97(B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S
M."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@W"FUS9VED("),96)A;F]N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHV.0HC+"!F=7IZ>0IM<V=I9"`B3&5F="(*;7-G<W1R(")0<GIE<W7Q('<@
M;&5W;R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3$X"B,L(&9U>GIY"FUS
M9VED("),969T(&AE861E<B(*;7-G<W1R(")0<GIY:[-A9&]W92!W87)T;[9C
M:3HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$Q-`HC+"!F=7IZ>0IM<V=I
M9"`B3&5F="!V86QU97,B"FUS9W-T<B`B4')Z>6NS861O=V4@=V%R=&^V8VDZ
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@X"FUS9VED("),97-O=&AO(@IM<V=S='(@(DQE<V]T:&\B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,30R(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,S`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@
M(DQI8F5R:6$B"FUS9W-T<B`B3&EB97)I82(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S,0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&EB>6%N($%R
M86(@2F%M86AI<FEY82(*;7-G<W1R("),:6)I82(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S
M,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EE8VAT
M96YS=&5I;B(*;7-G<W1R("),:65C:'1E;G-T96EN(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*(RP@9G5Z>GD*;7-G:60@
M(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`B6F%L;V=U:B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"B,L(&9U>GIY"FUS9VED
M("),:6=H="!286EN(@IM<V=S='(@(EIA;&]G=6HB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B
M3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R("):86QO9W5J(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*(RP@9G5Z>GD*;7-G
M:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R("):86QO9W5J(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*(RP@9G5Z>GD*
M;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(EIA;&]G=6HB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,`HC+"!F
M=7IZ>0IM<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B
M6F%L;V=U:B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,Q"B,L(&9U>GIY"FUS9VED("),:6=H="!3;F]W(@IM<V=S='(@(EIA
M;&]G=6HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS,@HC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@4VYO=R!3:&]W97(B"FUS9W-T
M<B`B6F%L;V=U:B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0HC+"!F
M=7IZ>0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B3&EB97)I82(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ.#$U"B,L(&9U>GIY"FUS9VED("),:6YK(@IM
M<V=S='(@(EIA9&%N:6$@<')Z>2!L;V=O=V%N:74B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@
M(DQI;FL@<&]I;G1S('1O.B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3@W-@IM<V=I9"`B3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T
M:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O:'1M;#)T97AT+G!H<#HQ.#,*(RP@
M9G5Z>GD*;7-G:60@(DQI;FMS(@IM<V=S='(@(EIA9&%N:6$@<')Z>2!L;V=O
M=V%N:74B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*(RP@9G5Z>GD*
M;7-G:60@(DQI;G5X($-O;VMI92(*;7-G<W1R(")4=_-R>B(*"B,Z(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S
M97(@8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,S`*(RP@9G5Z>GD*;7-G:60@(DQI<W0@1&%T86)A<V5S
M(@IM<V=S='(@(E!R>GEKLV%D;W=E('=A<G1OMF-I.B(*"B,Z('-E<G9I8V5S
M+VAE;'`O:6YD97@N<&AP.C4P"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM
M<V=S='(@(E=YMG=I971L('1E;6%T>2!P;VUO8WDB"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3(Y"B,L(&9U>GIY"FUS9VED("),:7-T(%1A8FQE<R(*;7-G
M<W1R(")0<GIY:[-A9&]W92!W87)T;[9C:3HB"@HC.B!L:6(O2&]R9&4O34E-
M12](96%D97)S+G!H<#HU.30*(RP@9G5Z>GD*;7-G:60@(DQI<W0M07)C:&EV
M92(*;7-G<W1R(")5:W)Y:B!N:65S=6)S:W)Y8F]W86YE(@H*(SH@;&EB+TAO
M<F1E+TU)344O2&5A9&5R<RYP:'`Z-3@Y"B,L(&9U>GIY"FUS9VED("),:7-T
M+4AE;'`B"FUS9W-T<B`B5WFV=VEE=&P@=&5M871Y('!O;6]C>2(*"B,Z(&QI
M8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y-@HC+"!F=7IZ>0IM<V=I9"`B
M3&ES="U)9"(*;7-G<W1R(")7>;9W:65T;"!T96UA='D@<&]M;V-Y(@H*(SH@
M;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DR"B,L(&9U>GIY"FUS9VED
M("),:7-T+4]W;F5R(@IM<V=S='(@(E=YMG=I971L('1E;6%T>2!P;VUO8WDB
M"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.3,*(RP@9G5Z>GD*
M;7-G:60@(DQI<W0M4&]S="(*;7-G<W1R(")7>;9W:65T;"!T96UA='D@<&]M
M;V-Y(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DQ"B,L(&9U
M>GIY"FUS9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R(")5:W)Y:B!N:65S
M=6)S:W)Y8F]W86YE(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z
M-3DP"B,L(&9U>GIY"FUS9VED("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@
M(E5K<GEJ(&YI97-U8G-K<GEB;W=A;F4B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]N;VQI<W0N:6YC.C0*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES
M86)L960N(@IM<V=S='(@(DQI<W1O=V%N:64@=;]Y=&MO=VYI:_-W(&IE<W0@
M=WFSL6-Z;VYE+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-PHC+"!F
M=7IZ>0IM<V=I9"`B3&ET97)A='5R92(*;7-G<W1R(")0;V1P:7,B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30T(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,S,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G
M:60@(DQI=&AU86YI82(*;7-G<W1R("),:71W82(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]I;6%G97,N<&AP.CDR"FUS9VED("),;V%D:6YG+BXN(@IM
M<V=S='(@(J-A9&]W86YI92XN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ.3D*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R(")#>F%S
M(&QO:V%L;GDZ("(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,PIM<V=I
M9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(E5S=&%W:65N:6$@;&]K86QN
M92!I(&-Z87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-38@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z-C4@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S$*(RP@9G5Z>GD*
M;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(D]P8VIE(@H*(SH@;&]G:6XN<&AP
M.C$V,B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,38T('1E;7!L871E
M<R]L;V=I;B]M;V)I;&4N:6YC.C,*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL
M92YI;F,Z,34@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX-@IM<V=I9"`B
M3&]G(&EN(@IM<V=S='(@(EIA;&]G=6HB"@HC.B!S97)V:6-E<R]P;W)T86PO
M<VED96)A<BYP:'`Z,34X"FUS9VED("),;V<@;W5T(@IM<V=S='(@(E=Y;&]G
M=6HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W"FUS9VED("),;V=I
M;B!487-K<R(*;7-G<W1R("):861A;FEA('!R>GD@;&]G;W=A;FEU(@H*(SH@
M;&EB+TAO<F1E+T%U=&@N<&AP.CDS,0IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E
M8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I
M;F-O<G)E8W1L>2XB"FUS9W-T<B`B(@HB3&]G;W=A;FEE(&YI92!P;W=I;V2S
M;R!S:>HL('!O;FEE=V&_('!O9&&S9;8@;FEE<')A=VEDLV]W92!H87.S;R!L
M=6(@;F%Z=^H@(@HB=;]Y=&MO=VYI:V$N(@H*(SH@;&EB+TAO<F1E+T%U=&@N
M<&AP.CDR-PIM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R("),;V=O=V%N
M:64@;FEE('!O=VEO9+-O('-IZBXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3,V-PHC+"!F=7IZ>0IM<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@(E=Y;&]G
M=6HB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*(RP@9G5Z>GD*;7-G
M:60@(DQO=F4B"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!P;%]03"YP;R`H26YG
M;R!H,RTQ+C`N,2D@(",M(RTC+2,M(UQN(@HB4')Z97-U\5QN(@HB(RTC+2,M
M(RTC("!P;%]03"YP;R`H26UP(&@S+30N,"XS*2`@(RTC+2,M(RTC7&XB"B)0
M<GIE;FEEMEQN(@HB(RTC+2,M(RTC("!P;%]03"YP;R`H5'5R8F$@:#,M,BXP
M+C,I("`C+2,M(RTC+2-<;B(*(E!R>F5N:66V(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(DQO=R(*;7-G<W1R
M(").:7-K:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C$W"B,L(&9U>GIY"FUS9VED("),;W=E<B!R
M;VUA;B!N=6UB97)S(@IM<V=S='(@(D=R=61Z:67Q(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$T-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),=7AE
M;6)O=7)G(@IM<V=S='(@(DQU:W-E;6)U<F<B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<S(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,3`*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G
M:60@(DU-(@IM<V=S='(@(DU-(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(U,PIM<V=I9"`B34]41"(*;7-G<W1R(")-3U1$(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W1N968N<&AP.C,V"FUS9VED(")-4RU43D5&($%T
M=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM
M<V=I9"`B35-'(@IM<V=S='(@(DU31R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C86\B"FUS9W-T
M<B`B36%K874B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34S(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3$*;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O
M<VQA=B!297!U8FQI8R!O9B(*;7-G<W1R(")-86-E9&]N:6$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,34Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,S<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@
M(DUA9&%G87-C87(B"FUS9W-T<B`B36%D86=A<VMA<B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT.0HC+"!F=7IZ>0IM<V=I9"`B36%G:6,B"FUS9W-T
M<B`B4&]C>G1A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Q"FUS
M9VED(")-86EL(@IM<V=S='(@(E!O8WIT82(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT-S<*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0P"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$S.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I
M9"`B36%L87=I(@IM<V=S='(@(DUA;&%W:2(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36%L87ES:6$B
M"FUS9W-T<B`B36%L97IJ82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B
M36%L961I=WDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34T(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3(*;7-G:60@(DUA;&DB"FUS9W-T<B`B36%L:2(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$T,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I
M9"`B36%L=&$B"FUS9W-T<B`B36%L=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.3$*;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E9V]R
M:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@
M(@HB87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@
M(B(*(EIA<GJQ9'IA:B!L:7-TL2!K871E9V]R:6DL(&MT\W)Y;6D@8NID>FEE
M<WH@;WIN86-Z8;,@<&]Z>6-J92P@:2!K;VQO<F%M:2!Z("(*(FYI;6D@>G=I
ML7IA;GEM:2XB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3`S.0IM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY-S<*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-30*;7-G:60@(DUA<%%U97-T
M(&UA<"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,S<V(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,3,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHV-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`B36%R>F5C(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0IM<V=I
M9"`B36%R9VEN(@IM<V=S='(@(DUA<F=I;F5S(@H*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-87)K('=I=&@@4V5E;B]5
M;G-E96X@9FQA9W,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@9FQA9W,@
M*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,34R(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@
M(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`B5WES<'D@36%R<VAA;&QA(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U.2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDS
M"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@(DUA<G1Y;FEK82(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3$Q"FUS9VED(")-871C:&EN9R!F
M:65L9',B"FUS9W-T<B`B4&%S=6JQ8V4@<&]L82(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T
M-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%U<FET
M86YI82(*;7-G<W1R(")-875R971A;FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$V,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-875R:71I=7,B
M"FUS9W-T<B`B36%U<FET:75S(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#@*(RP@9G5Z>GD*;7-G:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D
M+B(*;7-G<W1R(")7:6%D;VUOMN8B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,P-@IM<V=I9"`B36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDX"FUS9VED(")-87@@=&5M
M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z.#DX(&QI8B](;W)D92]&;W)M+G!H<#HQ,C$W(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,C,Y"FUS9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<X(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,34*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y
M(@IM<V=S='(@(DUA:B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3,@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B36%J
M;W1T82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,`HC+"!F=7IZ>0IM
M<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B3V1R>G5C;VYE(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ.0HC+"!F=7IZ>0IM<V=I9"`B
M365M8F5R<R(*;7-G<W1R(")'<G5D>FEE\2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-S`*;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B5')Y8B!M
M96YU.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@(E!OL[%C
M>B!K;VWS<FMI(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]S=&%T=7,N<&AP.C,P"FUS9VED(")-97-S86=E(@IM<V=S='(@(E=I861O
M;6^VYB(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C$V"FUS9VED
M("(B"B)-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I
M9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92`B"B)V97)I9FEE9"XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,3`*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS9W-T
M<B`B5VEA9&]M;[;F(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4V.2!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"B,L(&9U>GIY"FUS9VED(")-
M97-S86=E('1Y<&4B"FUS9W-T<B`B5VEA9&]M;[;F(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS"B,L(&9U>GIY"FUS9VED(")-971A<B!796%T:&5R(@IM
M<V=S='(@(D]B96-N>2!C>F%S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M-PIM<V=I9"`B365T87(@8FQO8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
M0FQO:R!<(DUE=&%R7"(@;FEE(&IE<W0@9&]S=.IP;GDN(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ,3(*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A
M=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(D)L;VL@7")-971A<EPB(&YI92!J
M97-T(&1O<W3J<&YY+B!3>F-Z96?SLWD@>F1A<GIE;FEA('IO<W1ALWD@>F%L
M;V=O=V%N92!D;&$@(@HB861M:6YI<W1R871O<F$N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$U,@IM<V=I9"`B365T87)$0B!I<R!N;W0@
M8V]N;F5C=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O<F%R+G!H<#HV-R!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW
M-`HC+"!F=7IZ>0IM<V=I9"`B365T:&]D(@IM<V=S='(@(DQE<V]T:&\B"@HC
M.B!L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z.#$@;&EB+TAO<F1E+U)00R]S
M;V%P+G!H<#HQ,3<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DUE=&AO
M9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`B5;]Y8VEE(&9O;&1E
M<G4@;FEE(&IE<W0@86MT>6YW92XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-0HC+"!F=7IZ>0IM
M<V=I9"`B365T<FEC(@IM<V=S='(@(DUE:W-Y:R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T
M.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O
M(@IM<V=S='(@(DUE:W-Y:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<R"FUS9VED(")-:6-R;VYE<VEA+"!&961E<F%T
M960@4W1A=&5S(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@HC+"!F=7IZ>0IM<V=I9"`B
M36ED9&QE(@IM<V=S='(@(E-T86YO=VES:V\B"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*;7-G<W1R
M(")4>7`@36EM92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$P"FUS9VED
M(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,#(*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H
M;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,3<*(RP@9G5Z>GD*;7-G:60@(DUI<G)O<B(*;7-G<W1R
M(")"L[%D(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Q"FUS9VED(")-
M:7-C96QL86YE;W5S(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-S(@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS-#`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q
M=65S="XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q
M-`IM<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T
M;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB
M87!P;&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`T"B,L(&9U>GIY"FUS9VED(")-:7-S:6YG(&UE
M<W-A9V4@240N(@IM<V=S='(@(E=I861O;6^VYB!D;R(*"B,Z(&QI8B].970O
M4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@
M<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S='(@(B(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDT"B,L(&9U>GIY"FUS
M9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM<V=S='(@(DYI92!Z9&5F:6YI
M;W=A;F\@=&5K<W1U('<@;F]C:64@=V%K86-Y:FYE:BXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S0*(RP@
M9G5Z>GD*;7-G:60@(DUO8FEL92!-86EL(@IM<V=S='(@(DYO=V$@<&]C>G1A
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*
M(RP@9G5Z>GD*;7-G:60@(DUO9&5R871E(@IM<V=S='(@(D]S=&%T;FEA(&UO
M9'EF:6MA8VIA(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C8@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S,*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*;7-G:60@(DUO9&EF:65D($1A
M=&4B"FUS9W-T<B`B3W-T871N:6$@;6]D>69I:V%C:F$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G
M:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B6FUI9?$@;&EN:R(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-C<S"FUS9VED(")-;V1U;'5S(@IM<V=S
M='(@(DUOLV1A=VEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*
M;7-G<W1R(")297!U8FQI:V$@36^S9&%W:6DB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,30Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3$*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*
M;7-G<W1R(")-;VYA:V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34V
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(DUO
M;F=O;&EA(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U.3,*(RP@9G5Z>GD*
M;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@(E)O>G=I\2!P87-E:R(*
M"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO;G1H
M;'DB"FUS9W-T<B`B0V\@;6EE<VFQ8R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36]N='-E<G)A="(*
M;7-G<W1R(")-;VYT<V5R<F%T(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@
M;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G
M<W1R(")&87IY(&MS:>J_>6-A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$T."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@
M(DUA<F]K;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,S"FUS9VED(")-;W-T;'D@0VQE87(B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*(RP@9G5Z>GD*
M;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B2W)A:B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,U"FUS9VED(")-;W-T
M;'D@4W5N;GDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="YP:'`Z-#(X"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B4')Z97-U\2!W
M(&3SLR(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C0S,@IM<V=I
M9"`B36]V92!,969T(@IM<V=S='(@(E!R>F5S=?$@=R!L97=O(@H*(SH@;&EB
M+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-#,V"FUS9VED(")-;W9E(%)I9VAT
M(@IM<V=S='(@(E!R>F5S=?$@=R!P<F%W;R(*"B,Z(&QI8B](;W)D92]";&]C
M:R],87EO=70N<&AP.C0R-`IM<V=I9"`B36]V92!5<"(*;7-G<W1R(")0<GIE
M<W7Q('<@9_-RZB(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT.38*;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R(")0<GIE;FEEMB!W
M(&3SLR(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M.34@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Y-@IM<V=I
M9"`B36]V92!U<"(*;7-G<W1R(")0<GIE<W7Q('<@9_-RZB(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$U-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B
M36]Z86UB:7%U92(*;7-G<W1R(")-;WIA;6)I:R(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR,3@U"FUS9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES
M=',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-#,*(RP@
M9G5Z>GD*;7-G:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R(")3:V%S
M=6H@=WEB<F%NL2!T;[]S86UOMN8B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S,Q(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,S@*;7-G:60@
M(DUY($%C8V]U;G0B"FUS9W-T<B`B2V]N=&\B"@HC.B!S97)V:6-E<R]P;W)T
M86PO:6YD97@N<&AP.C4Q"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B3?-J
M('!O<G1A;"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HQ,C0*(RP@
M9G5Z>GD*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B4&]R='5G
M86QI82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-34@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY,@IM<V=I9"`B37EA;FUA<B(*;7-G<W1R(")":7)M82(*"B,Z('1E
M;7!L871E<R]M86EN=&5N86YC92]A9W)E96UE;G1?8F]T=&]M+FEN8SHW"FUS
M9VED(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W1N968N<&AP.C,X"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C0P,`IM<V=I9"`B3F%M92(*;7-G<W1R(").87IW:7-K;R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$U-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B
M3F%M:6)I82(*;7-G<W1R(").86UI8FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$W."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").875R=2(*;7-G
M<W1R(").875R=2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S<@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B3F5P86PB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<U(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-C`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*
M;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(DAO;&%N9&EA(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(S(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@
M(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@(D%N='EL92!(;VQE;F1E
M<G-K:64B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I
M9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C87!E($-!(%)E=F]C
M871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3@U"FUS9VED(").971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED
M(").971S8V%P92!296YE=V%L(%523"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@4F5V;V-A
M=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HU.#8*;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-PHC+"!F
M=7IZ>0IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G
M<W1R(")"<F%K(&]S;V)I<W1E9V\@8V5R='EF:6MA='4B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4X,`HC+"!F=7IZ>0IM<V=I9"`B3F5T<V-A
M<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R(")7<')O=V%DO"!K;'5C>B!T
M=71A:B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,SD*;7-G:60@
M(DYE='=O<FLB"FUS9W-T<B`B4VEEYB(*"B,Z(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C0Q-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(W"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-S@*;7-G:60@(DYE=F5R(@IM<V=S='(@(DYI
M9V1Y(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDU"FUS9VED(").97<@0V%L961O;FEA(@IM<V=S='(@(DYO=V$@2V%L
M961O;FEA(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP
M:'`Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z,C<*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R(").;W=A(&MA=&5G
M;W)I82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W.0HC+"!F=7IZ>0IM<V=I
M9"`B3F5W($UO;VXB"FUS9W-T<B`B3F]W>2!K;VYT86MT(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N
M86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$X,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38S"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(").97<@6F5A;&%N
M9"(*;7-G<W1R(").;W=A(%IE;&%N9&EA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H
M7V)L86YK*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT
M,"!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3(*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(V,0IM<V=I9"`B3F5W<R(*;7-G<W1R(")7:6%D;VUOMF-I
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Y-0HC+"!F=7IZ>0IM
M<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R(")'<G5P>2!D>7-K=7-Y:FYE(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,C$@=&5M<&QA=&5S+V1A
M=&$O9&%T96UA<"YI;F,Z-#8*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN
M8SHQ,S<@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,S(*;7-G:60@(DYE
M>'0B"FUS9W-T<B`B3F%S=.IP;F4B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,C<*(RP@9G5Z>GD*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B3F%S
M=.IP;F$@<W1R;VYA(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-S`@
M;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-S0*;7-G:60@(DYE>'0@;W!T:6]N
M<R(*;7-G<W1R(").87-TZG!N92!O<&-J92(*"B,Z(&QI8B](;W)D92]522]0
M86=E<BYP:'`Z,3`S"B,L(&9U>GIY"FUS9VED(").97AT/B(*;7-G<W1R(").
M87-TZG!N92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S0@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY-@IM<V=I9"`B3FEC87)A9W5A(@IM<V=S='(@(DYI:V%R86=U
M82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S$@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$V-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY-@IM<V=I9"`B3FEG97(B"FUS9W-T<B`B3FEG97(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3<S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI
M9V5R:6$B"FUS9W-T<B`B3FEG97)I82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS-C@*(RP@9G5Z>GD*;7-G:60@(DYI9VAT(@IM<V=S='(@
M(E=Y<V]K:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-SD@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY-PIM<V=I9"`B3FEU92(*;7-G<W1R(").:75E(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@X-0HC+"!F=7IZ>0IM
M<V=I9"`B3F\B"FUS9W-T<B`B3FEE(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E
M='5P+V1I9F8N:'1M;#HQ-@IM<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R
M871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+U9&4R])4T]7<FET97(N<&AP.C$P-0IM<V=I9"`B3F\@879A
M:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T
M<B`B(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*
M;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HW.2!L:6(O2&]R9&4O0FQO8VLO3&%Y
M;W5T+G!H<#HR,S`*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,C4R
M"FUS9VED(").;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I
M=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"]M8V%L+G!H<#HU
M,`HC+"!F=7IZ>0IM<V=I9"`B3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F
M;W(@34-!3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B0G)A:R!I;F9O<FUA
M8VII(&\@<V5R=V5R>F4@4U%,('H@=;]Y=&MO=VYI:V%M:2(*"B,Z(&%D;6EN
M+W-E='5P+V1I9F8N<&AP.C4T"FUS9VED(").;R!C:&%N9V4N(@IM<V=S='(@
M(D)E>B!Z;6EA;BXB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$T,`HC
M+"!F=7IZ>0IM<V=I9"`B3F\@8VAI;&0@<&5R;6ES<VEO;G,@87)E('1O(&)E
M(&%D9&5D(&)E;&]W('1H:7,@;&5V96PN(@IM<V=S='(@(E5D8;-O('-IZB!D
M;V1AYB!<(B5S7"(@9&\@=7!R87=N:67Q+B(*"B,Z(&%D;6EN+W!E<FUS+V%D
M9&-H:6QD+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B3F\@8VAI;&1R96X@8V%N
M(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B561ALV\@
M<VGJ(&1O9&'F(%PB)7-<(B!D;R!U<')A=VYI9?$N(@H*(SH@;&EB+TAO<F1E
M+G!H<#HQ-C<@;&EB+TAO<F1E+G!H<#HT-S<@;&EB+TAO<F1E+U5T:6PN<&AP
M.C<W-@HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@(D)R86L@:V]N
M9FEG=7)A8VII(&1L82`E<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S0Q"B,L
M(&9U>GIY"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B0G)A:R!I;F9O<FUA8VII
M(&\@<V5R=V5R>F4@3$1!4"!Z('5S=&%W:65N:6%M:2XB"@HC.B!L:6(O5D93
M+W-Q;"YP:'`Z-3DQ"B,L(&9U>GIY"FUS9VED(").;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B
M0G)A:R!I;F9O<FUA8VII(&\@<V5R=V5R>F4@4U%,('H@:V%T96=O<FEA;6DN
M(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S`T"B,L(&9U>GIY"FUS9VED
M(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M4U%,+49I;&4@5D93+B(*;7-G<W1R(")"<F%K(&EN9F]R;6%C:FD@;R!S97)W
M97)Z92!344P@>B!K871E9V]R:6%M:2XB"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,Q-`HC+"!F=7IZ>0IM<V=I9"`B3F\@8W)E9&ET
M(&QE9G0N(@IM<V=S='(@(DYI92!W>6=E;F5R;W=A;F\@OV%D;F5G;R!S:W)Y
M<'1U+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S0*
M(RP@9G5Z>GD*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G
M<W1R(")7:6%D;VUOMN8B"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.#@Q
M"FUS9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(DYI92!W9W)A;F\@
M<&QI:W4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$U(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$R,PHC+"!F=7IZ>0IM<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G
M<W1R(")!<&QI:V%C:F$@9V]T;W=A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$U-@HC+"!F=7IZ>0IM<V=I9"`B3F\@;&]C871I;VX@<')O
M=FED960N(@IM<V=S='(@(DYI97IN86YY(&%D<F5S870B"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"B,L(&9U>GIY"FUS9VED(").
M;R!M97-S86=E('-U<'!L:65D+B(*;7-G<W1R(")7:6%D;VUOMN8B"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"B,L(&9U>GIY"FUS
M9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B3FEE('=Y8G)A;F\@
M=;]Y=&MO=VYI:V$N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S-PHC+"!F=7IZ>0IM<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB
M"FUS9W-T<B`B3FEE('=Y8G)A;F\@=;]Y=&MO=VYI:V$N(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.CDT"B,L(&9U>GIY"FUS9VED(").;R!O9F9E;G-I
M=F4@9F]R='5N97,B"FUS9W-T<B`B3FEE('IN86QE>FEO;F\@:V]N=&%K=/-W
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O:'1T<"YP:'`Z.3$*;7-G:60@(DYO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R(").:64@<&]D86YO(&AA<[-A(&1L82!U=VEE<GIY=&5L;FEE;FEA($A4
M5%`N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B3FEE('!O9&%N;R!H87.S82!D;&$@=7=I97)Z>71E;&YI96YI
M82!)34%0+B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C<R"FUS9VED
M(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(DYI92!P;V1A;F\@:&%SLV$@9&QA('5W:65R>GET
M96QN:65N:6$@2V5R8F5R;W,N(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP
M:'`Z.30*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,1$%0(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").:64@<&]D86YO(&AA<[-A(&1L82!U
M=VEE<GIY=&5L;FEE;FEA($Q$05`N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<V%S
M;"YP:'`Z-S<@;&EB+TAO<F1E+T%U=&@O;&]G:6XN<&AP.C@T"B,Z(&QI8B](
M;W)D92]!=71H+W!A;2YP:'`Z-S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3FEE('!O
M9&%N;R!H87.S82!D;&$@=7=I97)Z>71E;&YI96YI82!,3T=)3BXB"@HC.B!L
M:6(O2&]R9&4O075T:"]P87-S=V0N<&AP.C$S-0IM<V=I9"`B3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B3FEE('!O9&%N;R!H87.S82!D;&$@=7=I97)Z>71E;&YI96YI82!005-3
M5T0N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<VUB+G!H<#HX-`IM<V=I9"`B3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B3FEE('!O9&%N;R!H87.S82!D;&$@=7=I97)Z>71E;&YI96YI82!3
M34(N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,C@V"FUS9VED
M("(B"B).;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@
M5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I
M=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU
M<',N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#,*(RP@9G5Z>GD*;7-G:60@(DYO(')U;&5S
M(@IM<V=S='(@(E5W86=I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`HC+"!F=7IZ>0IM<V=I9"`B3F\@<VED
M97,B"FUS9W-T<B`B57=A9VDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,3(U"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL
M86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,S$*(RP@9G5Z>GD*;7-G:60@(DYO('5S97)N
M86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R(")0<F]S>NH@<&]D
M8>8@;F%Z=^H@=;]Y=&MO=VYI:V$@:2!H87.S;R(*"B,Z(&QI8B](;W)D92]2
M4$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO('9A;&ED(%A-3"!D871A(')E
M='5R;F5D(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HX.3,@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.CDP,PHC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.3$T(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY,S$*(RP@
M9G5Z>GD*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R(")5=V%G:2(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ,3D*;7-G:60@(DYO('9E<G-I;VX@9F]U
M;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3(W"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG
M=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,38@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T
M97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDR"FUS9VED(").;VYE(@IM
M<V=S='(@(J]A9&YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0HC+"!F=7IZ>0IM
M<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T<B`BIG)O9&MO=V]E
M=7)O<&5J<VMI("A)4T\M.#@U.2TR*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA
M;F0B"FUS9W-T<B`B3F]R9F]L:R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS
M,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*(RP@9G5Z>GD*;7-G:60@(DYO<G1H
M97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B4&]M;V,B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,34X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-CD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H
M97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3<V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-S`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYO<G=A
M>2(*;7-G<W1R(").;W)W96=I82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-C0P"B,L(&9U>GIY"FUS9VED(").;W0@069T97(B"FUS9W-T<B`B
M57=A9VDB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8S.0HC+"!F
M=7IZ>0IM<V=I9"`B3F]T($)E9F]R92(*;7-G<W1R(")5=V%G:2(*"B,Z(&QI
M8B]61E,O9FEL92YP:'`Z,S,Q"B,L(&9U>GIY"FUS9VED(").;W0@82!D:7)E
M8W1O<GDB"FUS9W-T<B`B2V%T86QO9R(*"B,Z(&QI8B]61E,O25-/5W)I=&5R
M+G!H<#HV,R!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN
M<&AP.C@S"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G
M>2YP:'`Z.30*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDN<&AP.C0X"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+G!H<#HU.0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*;7-G<W1R(").
M:64@>F%I;7!L96UE;G1O=V%N;RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C8X"FUS9VED(").;W0@<V5T(@IM<V=S='(@
M(DYI975S=&%W:6]N92(*"B,Z(&QI8B]61E,N<&AP.C$W-2!L:6(O5D93+G!H
M<#HQ.3,@;&EB+U9&4RYP:'`Z,C$P(&QI8B]61E,N<&AP.C(R-@HC.B!L:6(O
M5D93+G!H<#HR-#(@;&EB+U9&4RYP:'`Z,C4W(&QI8B]61E,N<&AP.C(W-"!L
M:6(O5D93+G!H<#HS,#<*(SH@;&EB+U9&4RYP:'`Z,S8W(&QI8B]61E,N<&AP
M.C0T-B!L:6(O5D93+G!H<#HU,34@;&EB+U9&4RYP:'`Z-3,R"B,Z(&QI8B](
M;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,30S(&QI8B](;W)D92]397-S:6]N
M2&%N9&QE<BYP:'`Z,34X"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP
M:'`Z,3<S(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,3@W"B,Z(&QI
M8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,C,T"FUS9VED(").;W0@<W5P
M<&]R=&5D+B(*;7-G<W1R(").:65O8G.S=6=I=V%N92(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ-C0*;7-G:60@(DYO=&5S(@IM<V=S='(@(E5W86=I(@H*(SH@
M<V5R=FEC97,O;V)R;W=S97(O:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG
M('1O(&)R;W=S92P@9V\@8F%C:RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+V-O;F9I<FU?=&]P+FEN8SHQ,`IM<V=I9"`B3F]T:6-E
M(@IM<V=S='(@(E5W86=A(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,X-"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-S4*;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@(DQI<W1O<&%D(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$P-#8*(RP@9G5Z>GD*;7-G:60@(DYU;6)E
M<B(*;7-G<W1R("),:7-T;W!A9"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M-#(W"B,L(&9U>GIY"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G
M<W1R("),:6-Z8F$@=VEE<G-Z>2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,S<Q(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(U(&QI8B](;W)D92]&;W)M+G!H
M<#HQ-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`T"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R("),:6-Z
M8F$@:V]L=6UN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-CD@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$T,C,@;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#4*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G
M:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(DQI8WIB82!W:65R<WIY(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-`HC+"!F=7IZ
M>0IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I
M;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B4W1W;W)Z>;-EMB!L:7-T
MZB!D>7-T<GEB=6-Y:FZQ+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B3TLB"FUS9W-T<B`B3TLB"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#$Q"B,L(&9U>GIY
M"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B5&5M870B"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$Q,0HC+"!F=7IZ>0IM<V=I9"`B3V)J96-T($-R
M96%T;W(B"FUS9W-T<B`B1&]M>;9L;F4@=7!R87=N:65N:6$B"@HC.B!A9&UI
M;B]P97)M<R]E9&ET+G!H<#HQ,S<@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR
M,34*(RP@9G5Z>GD*;7-G:60@(D]B:F5C="!C<F5A=&]R('!E<FUI<W-I;VYS
M(@IM<V=S='(@(D1O;7FV;&YE('5P<F%W;FEE;FEA(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$Q,#0*;7-G:60@(D]C=&%L(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS.#,@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0R,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R(@IM
M<V=S='(@(E!AO&1Z:65R;FEK(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`Q"FUS9VED(")/9F9I8V4B"FUS9W-T
M<B`B0FEU<F\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@Q(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T<B`B3VUA;B(*"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HW,PHC+"!F=7IZ>0IM<V=I
M9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RXB
M"FUS9W-T<B`B5&5N('-E<G=E<B!N:64@;V)SLW5G=6IE('5D;W-TZG!N:6%N
M:6$@9F]L9&5R\W<N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDU"FUS
M9VED(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3@U,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DW
M,@IM<V=I9"`B3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G
M<W1R(")4=_-J(&IE9&5N(&%D<F5S(&4M;6%I;"!J97-T(&1O>G=O;&]N>2XB
M"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N
M;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N
M9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H
M87)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,U"FUS
M9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")/='?S<GH@=R!N
M;W=Y;2!O:VYI92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C0U
M"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A
M(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-30*
M(RP@9G5Z>GD*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD
M;W<B"FUS9W-T<B`B4&]B<F'F('!O8WITZB!W(&]S;V)N>6T@;VMN:64_(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R871I;F<@
M4WES=&5M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HQ-3$*;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`B3W!C:F4B"@HC.B!S
M97)V:6-E<R]P<F5F<RYP:'`Z,CD@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z
M,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T
M<B`B3W!C:F4@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$X"B,L(&9U>GIY"FUS9VED(")/<F1E<F5D($QI<W0B"FUS
M9W-T<B`B5WEB:65R>B!L:7-TZB(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-38W"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`B3W)G86YI
M>F%C:F$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I
M9"`B3W)G86YI<V%T:6]N86P@56YI="(*;7-G<W1R(")*961N;W-T:V$@;W)G
M86YI>F%C>6IN82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S(*
M;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B3W)G86YI>F%T;W(B"@HC.B!A
M9&UI;B]T96UP;&%T97,N<&AP.C$S-0HC+"!F=7IZ>0IM<V=I9"`B3W)I9VEN
M86P@87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`B1&]M>;9L;F4@=7!R
M87=N:65N:6$B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.2!S97)V:6-E
M<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S='(@(DEN;F4B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$P-@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$S(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,C(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S,0IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`B26YN92!I
M;F9O<FUA8VIE(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,0IM
M<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B26YN92!U<')A=VYI
M96YI82(*"B,Z(&QI8B](;W)D92]!=71H+W!A;2YP:'`Z-SD*;7-G:60@(E!!
M32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")5
M=VEE<GIY=&5L;FEE;FEE(%!!32!N:64@:F5S="!D;W-TZG!N92XB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,C4S"FUS9VED(")01U`@1&EG:71A
M;"!3:6=N871U<F4B"FUS9W-T<B`B0WEF<F]W>2!P;V1P:7,@4$=0(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3(Y.0IM<V=I9"`B4$=0($5N8W)Y
M<'1E9"!$871A(@IM<V=S='(@(E=I861O;6^VYB!Z87-Z>69R;W=A;F$@4$=0
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3,U,0IM<V=I9"`B4$=0
M(%!U8FQI8R!+97DB"FUS9W-T<B`B2VQU8WH@<'5B;&EC>FYY(%!'4"(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$S,S,*;7-G:60@(E!'4"!3:6=N
M960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B5VEA9&]M;[;F('IA<WIY9G)O
M=V%N82]P;V1P:7-A;F$@:VQU8WIE;2!01U`B"@HC.B!A9&UI;B]P:'!S:&5L
M;"YP:'`Z-C@*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(DMO9"!02%`B"@HC
M.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G
M<W1R(")0;W>S;VMA(%!(4"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,W"B,L(&9U>GIY"FUS9VED(")032!,:6=H="!286EN
M(@IM<V=S='(@(EIA;&]G=6HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS.`HC+"!F=7IZ>0IM<V=I9"`B4$T@4VAO=V5R<R(*
M;7-G<W1R("));7!O<G0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS.0HC+"!F=7IZ>0IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R
M(")0;VMAOR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0P"B,L(&9U>GIY"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T
M<B`B26UP;W)T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#$*;7-G:60@(E!-(%-U;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@HC+"!F=7IZ>0IM<V=I
M9"`B4$T@5"U3=&]R;7,B"FUS9W-T<B`B57=A9VDB"@HC.B!L:6(O87!I+G!H
M<#HQ,C@*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B4&]WLV]K82!07TA0
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT-@HC+"!F=7IZ>0IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R(")2;WIW
M:6IA;FEE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDY"FUS9VED(")086MI<W1A;B(*;7-G<W1R(")086MI<W1A;B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.30@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$W,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(E!A;&%U(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$Y,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L
M97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@R(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-S4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G
M:60@(E!A;F%M82(*;7-G<W1R(")086YA;6$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3@U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S8*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A<'5A($YE
M=R!'=6EN96$B"FUS9W-T<B`B4&%P=6$M3F]W82!'=VEN96$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3DU(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-S<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED
M(")087)A9W5A>2(*;7-G<W1R(")087)A9W=A:B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V"B,L(&9U>GIY"FUS9VED(")0
M87)T;'D@0VQO=61Y(@IM<V=S='(@(DMR86HB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@S"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HQ.3D*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,3D@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,PHC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C,V(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M-C(*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(DAA<[-O(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,S(R"FUS9VED(")087-S=V]R9"!I;F-O
M<G)E8W0B"FUS9W-T<B`B2&%SLV\@;FEE<')A=VEDLV]W92(*"B,Z(&QI8B](
M;W)D92]!=71H+W)A9&EU<RYP:'`Z,34R"B,L(&9U>GIY"FUS9VED(")087-S
M=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R(")"<F%K(&EN9F]R;6%C:FD@;R!S97)W97)Z92!344P@>B!UOWET:V]W
M;FEK86UI(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P-30*;7-G:60@(E!A
M<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(DAA<[-O('H@<&]T
M=VEE<F1Z96YI96TB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M.3`*;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R(")(87.S;SHB"@HC.B!T96UP
M;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0IM<V=I9"`B4&%S<W=O<F0Z("(*
M;7-G<W1R(")(87.S;SH@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&QI8B](
M;W)D92]&;W)M+G!H<#HR,#,U"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G
M<W1R(")(87.S;R!M=7-I('!A<V]W8>8N(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$R,"!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C(*;7-G:60@(E!A<W1E(@IM<V=S='(@(E=K;&5J(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I
M9"`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T<B`B5VML96H@>F4@<V-H
M;W=K82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-3$*(RP@9G5Z>GD*;7-G:60@(E!A=&@B"FUS9W-T<B`B5VML96HB"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-`IM<V=I9"`B4&5N9&EN
M9R!3:6=N=7!S.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-30*(RP@9G5Z>GD*;7-G:60@(E!E;W!L92(*;7-G<W1R(");4F%P;W)T
M(&\@<')O8FQE;6EE72(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`W"B,L(&9U>GIY"FUS9VED(")097)C96YT(@IM<V=S
M='(@(D1R=6MU:B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M
M7V)O='1O;2YI;F,Z-@IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R
M871I;VYS(@IM<V=S='(@(E=Y:V]N86H@8WEK;&EC>FYE(&]P97)A8VIE(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y.`IM<V=I9"`B4&5R9F]R;2!M
M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R(")7>6MO
M;F%J(&-Y:VQI8WIN92!O<&5R86-J92!P;V1C>F%S(&QO9V]W86YI83\B"@HC
M.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C$@861M:6XO<&5R;7,O861D
M8VAI;&0N<&AP.C8T"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV-PIM
M<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R(")5<')A=VYI96YI92(*"B,Z(&%D
M;6EN+W!E<FUS+V1E;&5T92YP:'`Z-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R
M(")"<F%K(&1O<W3J<'4B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HR,C0@
M861M:6XO<&5R;7,O861D8VAI;&0N<&AP.CDS"B,Z(&%D;6EN+W!E<FUS+VEN
M9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C<T"B,L(&9U>GIY
M"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!
M9&UI;FES=')A8VIA(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-#4@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-#@*(SH@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HQ-3(*;7-G:60@(E!E<FUI<W-I;VYS(&9O<B(*;7-G<W1R(")5
M<')A=VYI96YI82!D;&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4*
M;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%C
M:F4@;W-O8FES=&4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@S(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S@*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B4&5R=2(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-0IM<V=I9"`B4&5T<R(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@V(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3D*;7-G:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(D9I;&EP:6YY(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@
M(E!H;VYE(@IM<V=S='(@(E1E;&5F;VXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#(U"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,`IM<V=I
M9"`B4&ET8V%I<FXB"FUS9W-T<B`B4&ET8V%I<FXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX96QS
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I
M9"`B4&QA=&ET=61E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A<V4@
M8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0X"FUS9VED
M(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES
M(&5L96UE;G0Z(@IM<V=S='(@(DYA('!E=VYO('5S=6ZQYB!T96X@=WEB<F%N
M>2!E;&5M96YT.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA
M="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R(").
M82!P97=N;R!U<W5NL>8@=WEB<F%N>2!E;&5M96YT.B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR-3<P"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@96YT97(@
M82!M;VYT:"!A;F0@82!Y96%R+B(*;7-G<W1R(")0<F]S>NH@<&]D8>8@;F]W
ML2!N87IWZCHB"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M
M96YT+FEN8SHQ,@HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M
M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T<B`B4')O<WKJ('!O9&'F
M(&YA>G?J(&1L82!N;W=E9V\@9F]L9&5R=3HB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3,P,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D
M<F5S<RXB"FUS9W-T<B`B4')O<WKJ('!O9&'F('!O<')A=VYY(&%D<F5S($E0
M+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-C4Y"FUS9VED(")0;&5A<V4@
M96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@
M:6X@=&AE(&UO;G1H+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C0U,`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS
M9W-T<B`B4')O<WKJ('!O9&'F('!O<')A=VYY(&-Z87,N(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I
M9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R(")0<F]S>NH@
M;W!I<V'F('!R;V)L96TN(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHQ."!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R"FUS9VED(")0;&5A
M<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R
M(")0<F]S>NH@<&]D8>8@;F%Z=^H@=;]Y=&MO=VYI:V$@:2!H87.S;R(*"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]A9W)E96UE;G1?=&]P+FEN8SHQ,@HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W
M:6YG('1E>'0N("!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U
M<V4@=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!R
M969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(E!L
M96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B375S
M:7-Z(&]K<F6V;&GF('6_>71K;W=N:6MA+"!K=/-R96=O(&-H8V5S>B!U<W5N
ML>8N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X."!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDY"FUS9VED(")0;VQA;F0B"FUS9W-T<B`B4&]L<VMA(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4W"B,L(&9U>GIY"FUS9VED(")0;VQI=&EC
M<R(*;7-G<W1R("):=VGQ(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0S-`HC+"!F=7IZ>0IM<V=I9"`B4&]L;',B"FUS9W-T<B`B6G=I\2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3,@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$X,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#$*
M;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@(E!O<G1U9V%L:6$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED
M(")0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C8@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E8VEP
M:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-@IM<V=I9"`B4')E8VEP
M:71A=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M4')E9G,O;&1A<"YP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@(E!R969S7VQD87`Z
M(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M075T:%]L9&%P.B!.:64@>FYA;&5Z:6]N;R!W>6UA9V%N96=O(')O>G-Z97)Z
M96YI82!,1$%0+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]S97-S:6]N+G!H<#HS
M,PHC+"!F=7IZ>0IM<V=I9"`B4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S
M<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VEM<#H@
M5WEM86=A;F4@<F]Z<WIE<GIE;FEE($E-05`@;FEE('IN86QE>FEO;F4N(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C4*;7-G:60@(E!R97-S=7)E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Y"FUS9VED(")0
M<F5S<W5R92!A="!S96$@;&5V96PZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(S"FUS9VED(")0<F5S<W5R93H@(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ.#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@(E!O9&=L
ML60B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C0*(RP@9G5Z>GD*;7-G:60@(E!R979I97<@=&AE(&EM
M86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")7>;9W:65T;"!Z8;.Q8WIN
M:6L@=R!O<V]B;GEM(&]K;FEE(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H
M<#HS-C`@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-C0*(RP@9G5Z>GD*;7-G
M:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`B4')E>F5N=&%C:F4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0Q"FUS
M9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@
M(DML=6-Z('!R>7=A=&YY(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$V.0IM
M<V=I9"`B4')O8FQE;2(*;7-G<W1R(")0<F]B;&5M(@H*(SH@<V5R=FEC97,O
M<')O8FQE;2YP:'`Z,3(W"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM
M<V=S='(@(D]P:7,@<')O8FQE;74B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C$S"FUS9VED(")0<F]J96-T<R(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C$Q,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$X.0HC
M+"!F=7IZ>0IM<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`B5WEL;V=U:B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B4'5B;&EC
M($ME>2(*;7-G<W1R(")+;'5C>B!P=6)L:6-Z;GDB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET
M:&TB"FUS9W-T<B`B06QG;W)Y=&T@:VQU8WIA('!U8FQI8WIN96=O(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#0*;7-G:60@(E!U8FQI8R!+
M97D@26YF;R(*;7-G<W1R("));F9O<FUA8VIE(&\@:VQU8WIU('!U8FQI8WIN
M>6TB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HR,S`*;7-G:60@(E!U
M8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L
M;'DN(@IM<V=S='(@(E!A<F$@:VQU8WIY(&]S;V)I<W1Y8V@@;FEE('IO<W1A
MLV$@=WEG96YE<F]W86YA('!O;7FV;&YI92XB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3DQ(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#,*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0=65R=&\@
M4FEC;R(*;7-G<W1R(")0;W)T;W)Y:V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3DV(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")1871A<B(*;7-G
M<W1R(")+871A<B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HV,@IM<V=I9"`B
M475E<GDB"FUS9W-T<B`B6F%P>71A;FEE(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HV-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI
M8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B2VQU8WH@<'5B;&EC>FYY(%)302`H
M)60@8FET\W<I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-C4*(RP@9G5Z
M>GD*;7-G:60@(E)A9&EO('-E;&5C=&EO;B(*;7-G<W1R(")3:V%S=6H@=WEB
M<F%NL2!T;[]S86UOMN8B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT,PHC+"!F=7IZ>0IM<V=I9"`B4F%I;B(*;7-G<W1R(")/
M<W1R>F6_96YI92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0T"B,L(&9U>GIY"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@
M(EIA;&]G=6HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT-0HC+"!F=7IZ>0IM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(EIA
M;&]G=6HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT-@HC+"!F=7IZ>0IM<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B6F%L
M;V=U:B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0W"B,L(&9U>GIY"FUS9VED(")286EN(&%N9"!3;F]W(@IM<V=S='(@(EIA
M;&]G=6HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT.`HC+"!F=7IZ>0IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(EIA
M;&]G=6HB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,PHC+"!F=7IZ>0IM
M<V=I9"`B4F%N9&]M($9O<G1U;F4B"FUS9W-T<B`B57=A9VDB"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV."!L:6(O2&]R9&4O34E-12]6
M:65W97(O>FEP+G!H<#HW-@HC+"!F=7IZ>0IM<V=I9"`B4F%T:6\B"FUS9W-T
M<B`B3W!C:F4B"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(Y,R!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,0HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-"!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$S-PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,`HC
M+"!F=7IZ>0IM<V=I9"`B4F5A9"(*;7-G<W1R(")0<GIELV%D=6HB"@HC.B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*(RP@9G5Z>GD*;7-G
M:60@(E)E860@;65S<V%G97,B"FUS9W-T<B`B3F]W92!W:6%D;VUOMF-I(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO
M;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E
M<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*(RP@9G5Z>GD*
M;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(E=Z;O-W
M('-W;VJQ('-E<VKJ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,PIM
M<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z(@IM<V=S='(@
M(D]DMG=I9;\@9'EN86UI8WIN92!E;&5M96YT>2!M96YU.B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS,S,*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I
M97<Z(@IM<V=S='(@(D]DMG=I9;\@=VED;VL@<V5R=VES=3HB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z.#DT(&QI8B](;W)D92]&;W)M+G!H<#HQ,C$S(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,C,U"FUS9VED(")296=E>"(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(T.`IM<V=I9"`B4F5L871I;VYS
M:&EP($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS,C8*(RP@9G5Z>GD*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B1&%N:6$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$T"FUS9VED(")296UO=&4@
M4V5R=F5R<R(*;7-G<W1R("):9&%L;F4@<V5R=V5R>2(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T
M<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E<75E=65D+FEN8SHQ-0IM<V=I9"`B4F5M;W9E(@IM<V=S='(@
M(E5S=?$B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$*;7-G
M:60@(E)E;6]V92!";&]C:R(*;7-G<W1R(")5<W7Q(&)L;VLB"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(Y"FUS9VED(")296UO
M=F4@8V]L=6UN(@IM<V=S='(@(E5S=?$@:V]L=6UNZB(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*(RP@9G5Z>GD*;7-G
M:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(E5S=?$@<&%RZB(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3,V"FUS9VED(")296UO=F4@
M<&%I<B(*;7-G<W1R(")5<W7Q('!A<NHB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,C`U"FUS9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R
M=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Q
M"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(E5S=?$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#D*;7-G
M:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ-@IM
M<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`B57-U\2!UOWET:V]W;FEK82(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")296UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B6F1A;&YE
M('6_>71K;W=N:6MA.B`E<R(*"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C+G!H
M<#HQ,S@*;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E
M='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-#0*(RP@9G5Z>GD*;7-G:60@(E)E<75E<W1E
M9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T<B`BKV%D86YY
M(&]B:F5K="!N:65Z;F%L97II;VYY+B(*"B,Z(&QI8B](;W)D92YP:'`Z,3<T
M(&QI8B](;W)D92YP:'`Z-#@W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R(")"<F%K('=Y;6%G86YE:B!O<&-J:2`G=6ED)R!D
M;&$@:V]N9FEG=7)A8VII('5S=&%W:67Q+B(*"B,Z(&QI8B]61E,O9G1P+G!H
M<#HW-#<@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S$P(&QI8B]61E,O<W%L+G!H
M<#HU.3<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB
M)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R(")"<F%K('=Y;6%G86YE:B!O<&-J:2`G=6ED)R!D;&$@:V]N9FEG=7)A
M8VII('5S=&%W:67Q+B(*"B,Z(&QI8B](;W)D92]5=&EL+G!H<#HW.#0*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@
M<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D)R86L@=WEM
M86=A;F5J(&]P8VII("=U:60G(&1L82!K;VYF:6=U<F%C:FD@=7-T87=I9?$N
M(@H*(SH@;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,R.`IM<V=I9"`B
M4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,S$@;&EB+TAO<F1E+T9O<FTN<&AP.C,S.2!L:6(O2&]R9&4O1F]R;2]296YD
M97)E<BYP:'`Z,S$U"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ
M,#$@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT-`IM<V=I9"`B
M4F5S970B"FUS9W-T<B`B2V%S=6HB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HT-@IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`B5WEC
M>GFVYB!H87.S;R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W
M"FUS9VED(")297-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(E=Y8WIYMN8@
M5'=O:F4@:&%SLV\B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C@@861M:6XO
M<W%L<VAE;&PN<&AP.C8U(&%D;6EN+W!H<'-H96QL+G!H<#HW,0IM<V=I9"`B
M4F5S=6QT<R(*;7-G<W1R(")7>6YI:VDB"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,3`R('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G
M:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(E!O=W+S="!D;R!O<&-J
M:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3<@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$X-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#(*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B4F5U;FEO;B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HT.`HC+"!F=7IZ>0IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB"FUS
M9W-T<B`B2&]R9&4@;FEE(&IE<W0@=R!P9;-N:2!S:V]N9FEG=7)O=V%N92XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,R"FUS9VED(")2:6-H(%1E
M>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`B4F]Z8G5D;W=A;GD@961Y=&]R
M('1E:W-T=2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`HC+"!F=7IZ
M>0IM<V=I9"`B4FED9&QE<R(*;7-G<W1R(")3=&%N;W=I<VMO(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<P"B,L
M(&9U>GIY"FUS9VED(")2:6=H="(*;7-G<W1R(")7>7-O:VDB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,S$R,`HC+"!F=7IZ>0IM<V=I9"`B4FEG:'0@:&5A
M9&5R(@IM<V=S='(@(E!R>GEKLV%D;W=E('=A<G1OMF-I.B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HS,3$V"B,L(&9U>GIY"FUS9VED(")2:6=H="!V86QU
M97,B"FUS9W-T<B`B4')Z>6NS861O=V4@=V%R=&^V8VDZ(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X"B,L
M(&9U>GIY"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B5&5L
M+B!K;VTN(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR
M,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`B4W1A;F]W:7-K;R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$X-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@
M(E)O;6%N:6$B"FUS9W-T<B`B4G5M=6YI82(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR,#@*;7-G:60@(E)O=&%T92`Q.#`B"FUS
M9W-T<B`B3V)R\^8@;R`Q.#`@<W1O<&YI(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(P-0IM<V=I9"`B4F]T871E($QE9G0B"FUS
M9W-T<B`B3V)R\^8@=R!L97=O(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(Q,0IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@
M(D]B<O/F('<@<')A=V\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0Y"B,L(&9U>GIY"FUS9VED(")2;W<@4')O
M<&5R=&EE<R(*;7-G<W1R(")7LV&V8VEW;[9C:2!R>NID=2!0<F]P97)T:65S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW,`IM<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`B5[-AMF-I
M=V^V8VD@<GKJ9'4@4')O<&5R=&EE<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4S"B,L(&9U>GIY"FUS9VED(")2=6QE<R(*;7-G<W1R(")3=&%N
M;W=I<VMO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E
M;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED
M(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N
M(')O=W,@;VYL>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3(Q"FUS9VED(")2=6XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Y.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G5S<VEA;B!&
M961E<F%T:6]N(@IM<V=S='(@(E)O<VIA(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(P,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G=A;F1A(@IM
M<V=S='(@(E)U86YD82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M,C@U"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS,C,*;7-G
M:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*;7-G<W1R(")7:6%D;VUO
MMN8@>F%S>GEF<F]W86YA(%,O34E-12(*"B,Z(&QI8B](;W)D92]!=71H+W-A
M<VPN<&AP.C@Q"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A
M=F%I;&%B;&4N(@IM<V=S='(@(E5W:65R>GET96QN:65N:64@4T%33"!N:64@
M:F5S="!D;W-TZG!N92XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#4Y"B,L(&9U>GIY"FUS9VED(")335,@365S<V%G:6YG(@IM<V=S='(@(E=Y
MMG=I971L86YI92!W:6%D;VUOMF-I(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C(Q"FUS9VED(")344P@4VAE;&PB"FUS9W-T<B`B4&]W;&]K82!344PB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<P"FUS9VED(")34T@B"FUS
M9W-T<B`B4U-((@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(B(*"B,Z
M(&QI8B]A<&DN<&AP.C$S,@IM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R(")0
M;W>S;VMA(%-?44PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8Q"B,L(&9U>GIY"FUS9VED(")382(*;7-G<W1R("):87!I
M<WHB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`W(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`T"FUS9VED(")386EN="!(96QE;F$B"FUS9W-T<B`BIG=IZG1A($AE
M;&5N82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@
M(E-A:6YT($MI='1S(&D@3F5V:7,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3,Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU8VEA(@IM
M<V=S='(@(E-A:6YT($QU8VEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$X.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N
M9"!-:7%U96QO;B(*;7-G<W1R(")386EN="U0:65R<F4@:2!-:7%U96QO;B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#0@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Y,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,34*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM
M<V=S='(@(E-A:6YT(%9I;F-E;G0@:2!'<F5N861Y;GDB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")386UE
M(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(U,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B4V%M;V$B"FUS
M9W-T<B`B4V%M;V$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$R(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`V"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@(E-A
M;B!-87)I;F\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$V(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`W"FUS9VED(")386\@5&]M92!A;F0@4')I;F-I<&4B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Y"B,L(&9U
M>GIY"FUS9VED(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B5V]J97?S
M9+QT=V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`Q(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`S"FUS9VED(")3875D:2!!<F%B:6$B"FUS9W-T<B`B07)A8FEA
M(%-A=61Y:G-K82(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY
M.`IM<V=I9"`B4V%V92(*;7-G<W1R("):87!I<WHB"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E
M("5S(@IM<V=S='(@(EIA<&ES>B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O961I="YI;F,Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<
M(B5S7"(B"FUS9W-T<B`B6F%P:7-Z(%PB)7-<(B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R("):
M87!I<WH@;W!C:F4B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<P"FUS
M9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0
M('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O
M<GDN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C8Y
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R(")(;W)D92!N:64@:F5S="!W('!ELVYI('-K;VYF
M:6=U<F]W86YE+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDP"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U<&=R861E
M('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(").:64@;6^_;F$@;W1W;W)Z
M>>8@;6]D=;-U($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0HC+"!F=7IZ>0IM<V=I9"`B
M4V-A='1E<F5D(%0M4W1O<FUS(@IM<V=S='(@(E5W86=I(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4Y"B,L(&9U>GIY"FUS9VED(")38VEE;F-E(@IM
M<V=S='(@(DYA9&%W8V$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I
M9"`B4V5A<F-H(@IM<V=S='(@(E-Z=6MA:B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR-S@*(RP@9G5Z>GD*;7-G:60@(E-E87)C:"!%;F=I;F5S
M(@IM<V=S='(@(D]P8VIE('=Y<WIU:VEW86YI82(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR.3<R"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B5WEB
M:65R>B!P;&EK:2(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-38*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T
M<B`B5WEB:65R>B!F;W)M870@9&%T>3HB"@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$Y.`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@9W)O=7`@
M=&\@861D(@IM<V=S='(@(E-T=_-R>B!N;W>Q(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHT,PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@;F5W
M(&]W;F5R(@IM<V=S='(@(E-T=_-R>B!N;W>Q(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C8P"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!S
M97)V97(B"FUS9W-T<B`B4W1W\W)Z(&YO=[$B"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$U-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@=7-E
M<B!T;R!A9&0B"FUS9W-T<B`B4W1W\W)Z(&YO=[$B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C8V,@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%L;"!D871E
M(&-O;7!O;F5N=',N(@IM<V=S='(@(E=Y8FEE<GH@9F]R;6%T(&1A='DZ(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Q,0HC+"!F
M=7IZ>0IM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R(")3='?S<GH@
M;F]WL2(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HS-PHC+"!F=7IZ>0IM
M<V=I9"`B(@HB4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@
M=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S
M=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N(@IM<V=S='(@(B(*(E=Y8FEE
M<GH@>FYA:VD@>B!P;VYIOW-Z>6-H('#S;"!F;W)M=6QA<GIA+B!-;[]E<WH@
M:F4@<VMO<&EO=V'F(&D@=VML96GF('H@(@HB<&]L82!T96MS=&]W96=O+B(*
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS9VED(")396QE8W0@
M=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R(")7>6)I97)Z('IN86L@<&]D
M>FEALW4@9&%T>3HB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-`IM
M<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`B5WEB:65R
M>B!F;W)M870@9&%T>3HB"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES
M96QE8W0N:6YC.C@Y"FUS9VED(")396QE8W0@=&AE(&ED96YT:71Y('EO=2!W
M86YT('1O(&-H86YG93HB"FUS9W-T<B`B5WEB:65R>B!T;[]S86UOMN8@9&\@
M>FUI86YY.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"FUS9VED
M(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R(")7>6)I97)Z
M('IN86L@<&]D>FEALW4@9&%T>3HB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE
M+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T
M<B`B5WEB:65R>B!F;W)M870@8WIA<W4Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHV-`IM<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F:65L
M9',N(@IM<V=S='(@(E=Y8FEE<GH@9'=A('!A<W5JL6-E('!O;&$N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y.`IM<V=I9"`B4V5L96-T('EO=7(@
M8V]L;W(@<V-H96UE+B(*;7-G<W1R(")7>6)I97)Z('-C:&5M870@:V]L;W+S
M=RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0P"FUS9VED(")396QE
M8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(E=Y8FEE<GH@
M='?S:B!P<F5F97)O=V%N>2!JZGIY:SHB"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*
M;7-G<W1R(")7>;9L:6H@<F%P;W)T(&\@<')O8FQE;6EE(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV,0IM<V=I9"`B4V5N9"!3
M35,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R(")396YE
M9V%L(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,38*(RP@9G5Z>GD*;7-G
M:60@(E-E;G-O<CH@(@IM<V=S='(@(DYA>G=A('6_>71K;W=N:6MA(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X,B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@(E-E<'1E;6)E
M<B(*;7-G<W1R(")7<GIE<VEE\2(*"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R;R(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I
M9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R(").=6UE<B!S97)Y:FYY(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T.`HC+"!F=7IZ>0IM<V=I
M9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92XB"FUS9W-T
M<B`B0FQO:R!<(DUE=&%R7"(@;FEE(&IE<W0@9&]S=.IP;GDN(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3(*(RP@9G5Z>GD*;7-G
M:60@(E-E<W-I;VX@240@97AP:7)E9"XB"FUS9W-T<B`B5VEA9&]M;[;F(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S,3,*;7-G:60@(E-E="(*;7-G<W1R
M(")5<W1A=R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-@IM<V=I9"`B
M4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O
M<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED(")3970@=7`@<F5M;W1E('-E
M<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A
M;"XB"FUS9W-T<B`B57-T87<@>F1A;&YE('-E<G=E<GDL(&1O(&MT\W)Y8V@@
M8VAC97-Z(&UI9>8@9&]S=.IP('H@<V5R=VES=2XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#0*;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG
M=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B57-T
M87<@<')E9F5R;W=A;GD@:NIZ>6LL('-T<F5FZB!C>F%S;W>Q(&D@;W!C:F4@
M9&%T>2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*;7-G:60@(B(*
M(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@
M<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS
M+B(*;7-G<W1R("(B"B)5<W1A=R!U<[-U9^H@<&]C>K%T:V]WL2P@<V-H96UA
M="!K;VQO<O-W+"!O9+9W:66_86YI92!S=')O;GD@:2!I;FYE(&]P8VIE("(*
M(G=YMG=I971L86YI82(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S0*
M;7-G:60@(E-E='5P(@IM<V=S='(@(DMO;F9I9W5R86-J82(*"B,Z('1E;7!L
M871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,Y"B,L(&9U>GIY"FUS9VED
M(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S='(@(DYI
M92!M;[]N82!O='=O<GIYYB!M;V1ULW4@36%I;G1E;F%N8V5?5&%S:R`E<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S0*;7-G:60@(E-E
M=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T<B`B4WIE
M<WIE;&4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4Q"B,L(&9U
M>GIY"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R(")(:7-Z<&%N:6$B"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT,PIM<V=I9"`B4VAO<G0@
M4W5M;6%R>2(*;7-G<W1R(")+<O-T:VD@;W!I<R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT,S@*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D
M969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O4&5R;7,N<&AP.C(Y,B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,S
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C<@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$Q,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*;7-G<W1R(")0
M;VMAOR(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-3@*;7-G:60@(B(*
M(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD
M('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0X,@IM<V=I9"`B4VAO
M=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R(")0
M;VMA>GEW8>8@8WIA<R!O<W1A=&YI96=O('IA;&]G;W=A;FEA('!O(&QO9V]W
M86YI=3\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<V-@IM<V=I9"`B4VAO
M=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C@Q,@HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!P:6-K
M97(B"FUS9W-T<B`B26UP;W)T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4Q.`HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!T86)L92!O<&5R871I;VYS(&UE
M;G4@8F%R/R(*;7-G<W1R(")7>;9W:65T;&'F(&EK;V[J(&9I;'1E<O-W(&YA
M('!A<VMU('IA9&'Q/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@
M;&5F=#\B"FUS9W-T<B`B4&]K8;\@;65N=2`E<R!P;R!L97=E:C\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3@*(RP@9G5Z>GD*;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R
M=&EE<R!D:6%L;V<B"FUS9W-T<B`B5&5L+B!K;VTN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S"B,L(&9U
M>GIY"FUS9VED(")3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9R(*
M;7-G<W1R(")496PN(&MO;2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*(RP@9G5Z>GD*;7-G:60@(E-H
M;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")4
M96PN(&MO;2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3$*(RP@9G5Z>GD*;7-G:60@(E-H;W<@=&AE(&EM
M86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(E1E;"X@:V]M+B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8T"B,L(&9U>GIY"FUS9VED(")3:&]W
M('5P;&]A9"(*;7-G<W1R(")79W)Y=V%N:64@<&QI:W4B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`HC+"!F=7IZ>0IM<V=I
M9"`B4VAO=V5R<R(*;7-G<W1R("));7!O<G0B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,0HC+"!F=7IZ>0IM<V=I9"`B4VAO
M=V5R<R!%87)L>2(*;7-G<W1R(")+<O-T:VEE('-T<F5S>F-Z96YI92(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"B,L(&9U
M>GIY"FUS9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B26UP;W)T(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G:60@
M(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70N<&AP.C,Y.0HC+"!F=7IZ>0IM<V=I9"`B4VAR
M:6YK(@IM<V=S='(@(D)A:')A:FXB"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y
M;W5T+G!H<#HV.3(@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-S4T"B,Z
M(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C@Q,B!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+G!H<#HX-S0*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP
M:'`Z.3`Y(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.CDT-@HC.B!L:6(O
M2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HY-S0@;&EB+TAO<F1E+T)L;V-K+TQA
M>6]U="YP:'`Z,3`P-`IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R
M:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(P,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#4*;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R(")3:65R<F$@3&5O;F4B
M"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V-0HC+"!F=7IZ>0IM
M<V=I9"`B4VEG;B!U<"(*;7-G<W1R(")296IE<W1R86-J82`E<R(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3(*;7-G:60@(E-I9VX@=7`@:68@
M;F]T(')E9VES=&5R960B"FUS9W-T<B`B6F%R96IE<W1R=6H@<VGJ+"!J9;9L
M:2!J97-Z8WIE('1E9V\@;FEE('IR;V)ILV6V(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R(")0
M;V1P:7,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<Q,0IM<V=I
M9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R(")!;&=O<GET;2!P;V1P
M:7-U(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S='(@(E-I;F=A<'5R(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Y-B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3(Q-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(S-PHC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C(T-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDR.2!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,S$R,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H
M<#HV-2!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX-`IM<V=I9"`B4VEZ92(*;7-G
M<W1R(")7:65L:V^VYB(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF
M:7)M7V)O='1O;2YI;F,Z.0IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G
M<W1R(")0;VUI\2!O<&5R86-J92!C>6ML:6-Z;F4B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C$P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V
M86MI82(*;7-G<W1R(")3LV]W86-J82(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA(@IM
M<V=S='(@(E.S;W=E;FEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(E-N;W<B"FUS9W-T<B`B
M4&]K8;\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU-0HC+"!F=7IZ>0IM<V=I9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B26UP
M;W)T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-38*(RP@9G5Z>GD*;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R("));7!O
M<G0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M-PHC+"!F=7IZ>0IM<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S='(@
M(DMR\W1K:64@<W1R97-Z8WIE;FEE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(E-N;W<@4VAO
M=V5R<R!,871E(@IM<V=S='(@(DEM<&]R="(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C<X"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#(*;7-G:60@(E-N;W<@97%U:79A;&5N
M="!I;B!W871E<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M;VX@27-L
M86YD<R(*;7-G<W1R(")7>7-P>2!386QO;6]N82(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P
M-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-O;6%L
M:6$B"FUS9W-T<B`B4V]M86QI82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,CDR-0HC+"!F=7IZ>0IM<V=I9"`B4V]R="!O<F1E
M<B!S96QE8W1I;VXB"FUS9W-T<B`B4VMA<W5J('=Y8G)A;K$@=&^_<V%M;[;F
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U.2!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C0W"B,L(&9U>GIY"FUS9VED(")3;W5R8V4@861D<F5S
M<R(*;7-G<W1R(")!9')E<R!D;VUO=WDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C4U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")3;W5T:"!!9G)I
M8V$B"FUS9W-T<B`B4&^S=61N:6]W82!!9G)Y:V$B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$Y,`IM<V=I9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y
M+3,I(@IM<V=S='(@(E!OLW5D;FEO=V]E=7)O<&5J<VMI("A)4T\M.#@U.2TS
M*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#$@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(P.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W
M:6-H($ES;&%N9',B"FUS9W-T<B`B1V5O<F=I82!0;[-U9&YI;W=A(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@HC
M+"!F=7IZ>0IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(")0
M;VUO8R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$S"FUS9VED(")3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O
M<F1E<B!I;B!C96QL(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HX,34*(RP@9G5Z>GD*;7-G:60@(E-P86-E<B(*;7-G<W1R(")(:7-Z<&%N
M:6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#`*(RP@9G5Z>GD*;7-G:60@(E-P86-I;F<B"FUS9W-T<B`B2&ES
M>G!A;FEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#`@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW,0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`B2&ES>G!A;FEA(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDX"FUS9VED(")3<&%M(@IM<V=S
M='(@(E-P86TB"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@
M(E-P96-I86P@0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(D5D>6-J82!Z;F%K
M\W<@<W!E8VIA;&YY8V@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S
M='(@(E!O9'II96P@:V]M\W)KZB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M
M;B(*;7-G<W1R(")0;V1Z:65L(&MO;'5M;NHB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI
M="!R;W<B"FUS9W-T<B`B4&]D>FEE;"!W:65R<WHB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(E-P;W)T<R(*;7-G<W1R
M("));7!O<G0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30Q(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R(")3<FD@3&%N
M:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C4@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HW-`HC+"!F=7IZ>0IM<V=I9"`B4W1A;F1A<F0B"FUS
M9W-T<B`B2V%L96YD87)Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8R
M"B,L(&9U>GIY"FUS9VED(")3=&%R(%1R96LB"FUS9W-T<B`B4W1A<G0B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4Y-2!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C@P.`HC+"!F=7IZ>0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R(")3=&%R
M="(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED(")3
M=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R(")7;VIE=_-DO'1W;R!L=6(@<W1A
M;B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS
M9VED(")3=&%T=7,B"FUS9W-T<B`B4W1A='5S(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(X,30*(RP@9G5Z>GD*;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM
M<V=S='(@(D9O<FUA="!C>F%S=2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3<R"FUS9VED(")3=')E970@061D<F5S<R(*;7-G<W1R(")!9')E
M<R!D;VUO=WDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q"FUS9VED(")3=')I:V5T:')O=6=H(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,C,S"B,L(&9U>GIY"FUS9VED(")3=')I
M;F<@;&ES="(*;7-G<W1R(")5<W1A=VEE;FEA(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$X-S0*;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R
M97-S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C(*;7-G:60@(E-U(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J96-T(@IM<V=S='(@
M(E1E;6%T(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,B!L:6(O2&]R9&4O
M1F]R;2]296YD97)E<BYP:'`Z,S$R"FUS9VED(")3=6)M:70B"FUS9W-T<B`B
M5WFV;&EJ(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O('1H92!S
M>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E
M<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(*(RP@9G5Z>GD*;7-G
M:60@(E-U8G-C<FEP="(*;7-G<W1R(")09;-N>2!O<&ES.B(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,#4@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S='(@(E!O
M=V]D>F5N:64B"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S>7-T
M96TN(@IM<V=S='(@(E5D8;-O('-IZB!D;V1AYB!<(B5S7"(@9&\@<WES=&5M
M=2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@
M9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R(")59&&S;R!S:>H@=7-U;K'F(%PB
M)7-<(B!Z('-Y<W1E;74N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX,2!A9&UI
M;B]P97)M<R]D96QE=&4N<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G:60@(E-U
M8V-E<W-F=6QL>2!D96QE=&5D(%PB)7-<(BXB"FUS9W-T<B`B561ALV\@<VGJ
M('5S=6ZQYB!<(B5S7"(N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F
M<F]M('1H92!S>7-T96TN(@IM<V=S='(@(E5D8;-O('-IZB!U<W5NL>8@7"(E
M<UPB('H@<WES=&5M=2XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q
M"B,L(&9U>GIY"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG
M=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R(")(;W)D
M92!N:64@:F5S="!W('!ELVYI('-K;VYF:6=U<F]W86YE+B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HU.2!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU
M-0HC+"!F=7IZ>0IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")(;W)D92!N:64@:F5S="!W('!ELVYI
M('-K;VYF:6=U<F]W86YE+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S
M879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T
M<B`B2&]R9&4@;FEE(&IE<W0@=R!P9;-N:2!S:V]N9FEG=7)O=V%N92XB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY('5P9&%T960@7"(E<UPB(@IM<V=S='(@(E5D8;-O('-IZB!U
M86MT=6%L;FGF(%PB)7-<(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-S$@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`B561A
MLV\@<VGJ(&1O9&'F(%PB)7-<(B!D;R!S>7-T96UU+B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(Q,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U
M9&%N(@IM<V=S='(@(E-U9&%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@HC+"!F=7IZ>0IM<V=I9"`B4W5M
M;6%R>2(*;7-G<W1R(")+<O-T:VEE('-T<F5S>F-Z96YI93HB"@HC.B!L:6(O
M0FQO8VLO<W5N<FES92YP:'`Z-C8*(RP@9G5Z>GD*;7-G:60@(E-U;B!2:7-E
M(@IM<V=S='(@(DYA>G=A('6_>71K;W=N:6MA(@H*(SH@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")3=6X@4V5T(@IM<V=S='(@
M(DYA>G=A('6_>71K;W=N:6MA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-U;FYY(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#0*(RP@9G5Z>GD*;7-G
M:60@(E-U;G)I<V4B"FUS9W-T<B`B3F%Z=V$@=;]Y=&MO=VYI:V$B"@HC.B!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@(E=S8VCS9"]Z86-H
M\V0@<[-O\6-A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P
M,PHC+"!F=7IZ>0IM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(DYA>G=A('6_
M>71K;W=N:6MA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P
M-PHC+"!F=7IZ>0IM<V=I9"`B4W5N<V5T(@IM<V=S='(@(DYA>G=A('6_>71K
M;W=N:6MA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-@HC
M+"!F=7IZ>0IM<V=I9"`B4W5N<V5T.B`B"FUS9W-T<B`B3F%Z=V$@=;]Y=&MO
M=VYI:V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$S"B,L(&9U>GIY"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R(")0
M9;-N>2!O<&ES.B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#,*
M(RP@9G5Z>GD*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B26UP;W)T(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-@IM
M<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`B4W5R:6YA;2(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-3<T"B,L(&9U>GIY"FUS9VED(")3=7)N86UE
M(@IM<V=S='(@(DYA>G=A('6_>71K;W=N:6MA(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(P.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4W9A;&)A
M<F0@86YD($IA;B!-87EE;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C$Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,30*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA
M;F0B"FUS9W-T<B`B4W5A>FDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C`U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS9W-T<B`B
M4WIW96-J82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8V"FUS9VED(")3=VET>F5R;&%N9"(*;7-G<W1R(")3>G=A:F-A
M<FEA(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z.3<*(RP@9G5Z
M>GD*;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T
M<B`B3W!R\[]N:6H@9F]L9&5R(&MO<WIA(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(Q."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4WER:6%N($%R
M86(@4F5P=6)L:6,B"FUS9W-T<B`B4WER:6$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,`HC+"!F=7IZ>0IM<V=I9"`B5"U3
M=&]R;2(*;7-G<W1R(")5=V%G:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8Q"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV,@HC+"!F=7IZ>0IM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B57=A
M9VDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M,PHC+"!F=7IZ>0IM<V=I9"`B5"U3=&]R;7,@16%R;'DB"FUS9W-T<B`B2W+S
M=&MI92!S=')E<WIC>F5N:64B"@HC.B!L:6(O2&]R9&4O1&%T82]T<W8N<&AP
M.C$V-@HC+"!F=7IZ>0IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B5'ET=;,B
M"@HC.B!L:6(O2&]R9&4O54DO5&%B;&4N<&AP.C$S-@HC+"!F=7IZ>0IM<V=I
M9"`B5&%B;&4B"FUS9W-T<B`B5[.Q8WIO;F4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S"B,L(&9U>GIY"FUS
M9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(E1E;"X@:V]M+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S(*(RP@9G5Z>GD*;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS9W-T<B`B
M5&5L+B!K;VTN(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-"!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1A:7=A;B(*;7-G<W1R
M(")486IW86XB"@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X
M"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM<V=S='(@(E1A
M:G=A;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C4@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B5&%DOWEK:7-T
M86XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,U(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(E1A;GIA;FEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY-0HC+"!F=7IZ>0IM<V=I9"`B5&%R9V5T.B(*;7-G
M<W1R(")7:6%D;VUOMN8B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,3<S"FUS9VED(")487-K<R(*;7-G<W1R("):861A;FEA(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E1E;&5P:&]N92!.=6UB
M97(B"FUS9W-T<B`B3G5M97(@=&5L969O;G4B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(Y,`IM<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,30*(RP@9G5Z>GD*;7-G
M:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@(E!O9'!I<R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,3$*(RP@9G5Z>GD*;7-G:60@(E1E;7!E
M<F%T=7)E.B`B"FUS9W-T<B`B4&]D<&ES(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(X,0HC+"!P:'`M9F]R;6%T"FUS9VED(")496UP97)A
M='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]496UP;&%T92YP:'`Z,C$W"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G
M<W1R("(E<R!N:65Z;F%L97II;VYY+B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP
M:'`Z,38Y"B,L(&9U>GIY"FUS9VED(")496UP;&%T92!!9&UI;FES=')A=&EO
M;B(*;7-G<W1R(")!9&UI;FES=')A8VIA(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$R,3$*(RP@9G5Z>GD*;7-G:60@(E1E>'0B"FUS9W-T<B`B5'EL:V\@
M=&5K<W0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8W"FUS9VED(")4
M97AT($]N;'DB"FUS9W-T<B`B5'EL:V\@=&5K<W0B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<T"B,L(&9U>GIY
M"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@(E1Y;&MO('1E:W-T(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0HC+"!F
M=7IZ>0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R(")4>6QK;R!T96MS="(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G
M:60@(E1H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ
M"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C(T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4
M:&%I;&%N9"(*;7-G<W1R(")486IL86YD:6$B"@HC.B!L:6(O2&]R9&4O075T
M:"YP:'`Z.3(S"FUS9VED(")4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T
M96TN(@IM<V=S='(@(D1Z:>IK=6IE;7D@>F$@:V]R>GES=&%N:64@>B!S97)W
M:7-U+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW,S<*(RP@9G5Z>GD*;7-G:60@
M(E1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(E5W:65R>GET96QN:65N:64@;FEE('!O=VEO9+-O('-IZB(*"B,Z(&QI8B](
M;W)D92]+;VQA8BYP:'`Z.3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!(
M;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R
M="!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@;&EB+TYE="])35-0+T)O;VLN<&AP
M.C$R.30*(RP@9G5Z>GD*;7-G:60@(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@
M8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(E!O9'!I<R!N:64@;6^_92!B>>8@
M>F%S=+%P:6]N82XB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,CD*
M;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S
M=6-C97-S9G5L;'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O
M;&]R<&EC:V5R+G!H<#HR.0HC+"!F=7IZ>0IM<V=I9"`B5&AE($]P=&EO;G,@
M=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM<V=S='(@(E1W;W)Z;VYA
M('=I861O;6^VYB!Z;W-T8;-A('IA;6MN:>IT82X@5WEC:&]D>F5N:64N(@H*
M(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HQ-3@@;&EB+TAO<F1E+U!E<FUS+G!H
M<#HQ-CD@;&EB+TAO<F1E+U!E<FUS+G!H<#HQ.#`*(SH@;&EB+TAO<F1E+U!E
M<FUS+G!H<#HQ.3(@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,#,@;&EB+TAO<F1E
M+U!E<FUS+G!H<#HR,C$*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,S,@;&EB
M+TAO<F1E+U!E<FUS+G!H<#HR-S(*;7-G:60@(B(*(E1H92!A9&UI;FES=')A
M=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N
M<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N<RXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB
M"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@
M<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE
M("(*(F1A=&%B87-E+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C4Q"B,L(&9U>GIY"FUS9VED(")4:&4@8V]N=&%C
M="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K
M+B(*;7-G<W1R(")+;VYT86MT>2!Z;W-T8;-Y('!O;7FV;&YI92!D;V1A;F4@
M9&\@5'=O:F5J(&MS:;&_:VD@861R97-O=V5J+B(*"B,Z(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C$Q-#D*(RP@9G5Z>GD*;7-G:60@(B(*(E1H92!D971A
M8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF
M>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*(E!O=')Z96)N>2!J
M97-T(&ML=6-Z('!U8FQI8WIN>2!01U`@9&\@<W!R87=D>F5N:6$@<&]D<&ES
M86YE:B!W:6%D;VUOMF-I+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-#$*(RP@9G5Z>GD*;7-G:60@(B(*(E1H92!D:7-T<FEB=71I
M;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA
M;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D871A8F%S92XB"FUS9W-T<B`B
M5&$@;W!E<F%C:F$@;FEE(&IE<W0@;V)SLW5G:7=A;F$N(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,@HC+"!F=7IZ>0IM<V=I9"`B
M5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G
M<W1R(")482!O<&5R86-J82!N:64@:F5S="!O8G.S=6=I=V%N82XB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0N<&AP.C$Q,PHC+"!F=7IZ>0IM<V=I9"`B5&AE(&5N
M8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C
M=&EO;BXB"FUS9W-T<B`B3V)SLW5G82!O<V]B:7-T96=O(&ML=6-Z82!01U`@
M=WEM86=A(&)E>G!I96-Z;F5G;R!P;[.Q8WIE;FEA('=W=RXB"@HC.B!L:6(O
M2&]R9&4N<&AP.C$W-2!L:6(O2&]R9&4N<&AP.C0X.`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E
M<R!S971T:6YG+B(*;7-G<W1R("):;6EE\2!U<W1A=VEE;FEA('1R86MT;W=A
M;FEA('!L:6OS=R!I(&MA=&%L;V?S=RXB"@HC.B!L:6(O2&]R9&4N<&AP.C$V
M."!L:6(O2&]R9&4N<&AP.C0W.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG
M<RXB"FUS9W-T<B`B6FUI9?$@=7-T87=I96YI82!T<F%K=&]W86YI82!P;&EK
M\W<@:2!K871A;&]G\W<N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ-3(*;7-G
M:60@(E1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1&%T82YP:'`Z,C8P"FUS9VED(")4
M:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F
M;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C
M.#(R(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C
M<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT
M97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W
M92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E
M<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N
M8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB
M>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H
M870@>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G
M(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE
M9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T
M<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<')E9G,N<&AP.C@X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!I
M9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B5&^_
M<V%M;[;F(%PB)7-<(B!Z;W-T8;-A('5S=6YIZG1A+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@
M(E1H92!L969T+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C$T-@IM<V=I9"`B(@HB5&AE(&QO8V%T:6]N
M(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y
M<'1?<&=P.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%
M+TU$3BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!M97-S
M86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@
M8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T
M('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S@*;7-G:60@(E1H
M92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G
M92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R
M,S$*;7-G:60@(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@
M=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]0<F5F<RYP:'`Z,C@U"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@
M8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO
M=V%B;&4@<VEZ92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O9&5B+G!H<#HS,B!L:6(O2&]R9&4O34E-12]6:65W97(O96YS8W)I<'0N
M<&AP.C,U"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N
M<&AP.C,R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]W96)C<'`N<&AP.C,W"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I
M('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N
M(&1E;&5T960N(@IM<V=S='(@(E-E<G=E<B!<(B5S7"(@>F]S=&&S('5S=6YI
MZG1Y+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C0Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N('-A
M=F5D+B(*;7-G<W1R(")397)W97(@7"(E<UPB('IO<W1ALR!Z87!I<V%N>2XB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M
M;W9E9"XB"FUS9W-T<B`B2V]N=&\@7"(E<UPB('IO<W1ALV\@>F%P:7-A;F4N
M(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,CDP"B,L(&9U>GIY
M"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="XB"FUS
M9W-T<B`B3VMR9;9L;VYY('!L:6L@;FEE(&ES=&YI96IE+B(*"B,Z(&QI8B]6
M1E,O<W%L+G!H<#HQ,#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H
M92!T96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S
M='(@(D]K<F6V;&]N>2!P;&EK(&YI92!I<W1N:65J92XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED
M(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@P"FUS9VED(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O1&%T82YP:'`Z,S`W"FUS9VED(")4:&4@=7!L;V%D960@9&%T
M82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T1A=&$O8W-V+G!H<#HR-#`@;&EB+TAO<F1E+T1A
M=&$O='-V+G!H<#HQ-S(*(RP@9G5Z>GD*;7-G:60@(E1H92!U<&QO861E9"!F
M:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`B4&]D<&ES(&YI92!M
M;[]E(&)YYB!Z87-TL7!I;VYA+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HT."!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3`Y"FUS
M9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB
M"FUS9W-T<B`B0FQO:R!W96%T:&5R+F-O;2!N:64@:F5S="!D;W-TZG!N>2XB
M"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$W.`IM<V=I9"`B5&AE<F4@
M87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R(").:64@;6$@OV%D
M;GEC:"!D;W-TZG!N>6-H(&]P8VII+B(*"B,Z(&QI8B](;W)D92]-24U%+T-O
M;G1E;G1S+G!H<#HS-#$*(RP@9G5Z>GD*;7-G:60@(E1H97)E(&%R92!N;R!P
M87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R(").
M:64@;6$@OV%D;GEC:"!A;'1E<FYA='EW;GEC:"!C>NJV8VDL(&MT\W)E(&UO
M9[-Y8GD@>F]S=&'F('!O:V%Z86YE+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ-#`S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T;V\@
M;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R
M960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N
M("5S+B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C4S(&%D;6EN+W5S97(N
M<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L
M96T@861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R(")7
M>7-TL7!ILR!P<F]B;&5M('!R>GD@9&]D87=A;FEU(%PB)7-<(B!D;R!S>7-T
M96UU.B`E<R(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R
M('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(B(*(E=Y
M<W2Q<&FS('!R;V)L96T@<')Z>2!U<W5W86YI=2!D86YY8V@@9&QA('6_>71K
M;W=N:6MA(%PB)7-<(B!W('-Y<W1E;6EE.B`B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE
M;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B
M5WES=+%P:;,@<')O8FQE;2!P<GIY('5S=7=A;FEU(%PB)7-<(B!Z('-Y<W1E
M;74N(@H*(SH@861M:6XO=7-E<BYP:'`Z,34Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@7"(E<UPB.B`E<R(*
M;7-G<W1R(")7>7-TL7!ILR!P<F]B;&5M('!R>GD@=6%K='5A;&YI86YI=2!<
M(B5S7"(Z("5S(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.C@X.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE
M(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HX.3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P
M;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A
M;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T)R;W=S97(N<&AP.C@Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@
M)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A
M<G0B"FUS9W-T<B`B5WES=+%P:;,@8K.Q9"!P;V1C>F%S('=YMG=I971L86YI
M82!T96H@8WKJMF-I('=I861O;6^V8VDB"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C,Y(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`B5WES=+%P:;,@
M8K.Q9"!P;V-Z87,@:6UP;W)T;W=A;FEA(&1A;GEC:"!I0V%L96YD87(N(@H*
M(SH@;&EB+TAO<F1E+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S
M='(@(E=Y<W2Q<&FS(&*SL60@<&]C>F%S(&EM<&]R=&]W86YI82!D86YY8V@@
M:4-A;&5N9&%R+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-SD*(RP@
M9G5Z>GD*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N
M9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A("(*(G)E
M<75I<F5D(&9I96QD+B(*;7-G<W1R(")7>7-TL7!ILR!BL[%D('!O9&-Z87,@
M86MT=6%L:7IA8VII('1E9V\@=W!I<W4Z("5S(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S.`HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE
M<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R
M97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N
M(@IM<V=S='(@(E=Y<W2Q<&FS(&*SL60@<&]D8WIA<R!A:W1U86QI>F%C:FD@
M=&5G;R!W<&ES=3H@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C0P"B,L(&9U>GIY"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R
M;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A
M9V%I;B!L871E<BXB"FUS9W-T<B`B5WES=+%P:;,@8K.Q9"!P;V1C>F%S(&%K
M='5A;&EZ86-J:2!T96=O('=P:7-U.B`E<R(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-#4*(RP@9G5Z>GD*;7-G:60@(B(*(E1H97)E
M('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N
M(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(E=Y<W2Q<&FS(&*S
ML60@<&]D8WIA<R!A:W1U86QI>F%C:FD@=&5G;R!W<&ES=3H@)7,B"@HC.B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X"B,L(&9U>GIY"FUS
M9VED(")4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN
M9R!F;VQD97)S+B(*;7-G<W1R(")496X@<V5R=V5R(&YI92!O8G.S=6=U:F4@
M=61O<W3J<&YI86YI82!F;VQD97+S=RXB"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O<F%R+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@
M=&\@8F4@82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`B4&QI:R!N:64@
M=WEG;+%D82!N82!P;W!R87=N92!A<F-H:7=U;2!205(N(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N
M;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(E!L
M:6L@;FEE('=Y9VRQ9&$@;F$@<&]P<F%W;F4@87)C:&EW=6T@6DE0+B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HS,30T"B,L(&9U>GIY"FUS9VED(")4:&ES
M(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS
M9W-T<B`B9F]L9&5R("5S(&YI92!J97-T('!R87=I9+-O=WDN(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*;7-G:60@(B(*(E1H
M:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@
M=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@9V%T
M97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G:60@(B(*(E1H:7,@
M9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE
M('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL
M('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--
M4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U"FUS9VED("(B"B)4:&ES(&1R
M:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O
M=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O
M9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@
M=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3<X(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,#4W(&QI8B](;W)D92]&;W)M+G!H<#HQ,#@V"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,3$U(&QI8B](;W)D92]&;W)M+G!H<#HQ,3@R
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,C4V"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,S`U(&QI8B](;W)D92]&;W)M+G!H<#HQ-#`P(&QI8B](;W)D92]&;W)M
M+G!H<#HQ-34Y"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#0P(&QI8B](;W)D
M92]&;W)M+G!H<#HQ.34Y(&QI8B](;W)D92]&;W)M+G!H<#HR,#`V"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR,#,P(&QI8B](;W)D92]&;W)M+G!H<#HR,#<Y
M(&QI8B](;W)D92]&;W)M+G!H<#HR,34P"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR,C(R(&QI8B](;W)D92]&;W)M+G!H<#HR-#`Y(&QI8B](;W)D92]&;W)M
M+G!H<#HR-#4S"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-C4V(&QI8B](;W)D
M92]&;W)M+G!H<#HR.#(W(&QI8B](;W)D92]&;W)M+G!H<#HS,3,V"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HS-S(S(&QI8B](;W)D92]&;W)M+G!H<#HS-S,Q
M"FUS9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R(")4;R!P
M;VQE(&IE<W0@=WEM86=A;F4N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P
M-C4*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R
M<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,3<*;7-G
M:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T
M:&4@8V]L;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,#DT"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@
M=F%L=65S+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$R
M,PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@
M<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.CDX.0IM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E
M(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R(")4;R!P;VQE(&UU<VD@8GGF('!O
M<')A=VZQ(&QI8WIBL2XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@S-0IM
M<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E
M(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T
M868G+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z-38Q"FUS
M9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]+;VQA8BYP:'`Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H
M:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H
M870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O
M<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I
M="`E<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP
M:'`Z-3@X"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@;65S<V%G92!W87,@
M=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO
M=7(@;W=N+B(*;7-G<W1R(")7:6%D;VUOMN8@>F]S=&&S82!N87!I<V%N82!W
M(&EN;F5J(&YIOR!T=V]J82!S=')O;FEE(&MO9&]W96H@*"5S*2XB"@HC.B!L
M:6(O2&]R9&4O4')E9G,O54DN<&AP.C$R-@HC+"!F=7IZ>0IM<V=I9"`B5&AI
M<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(DUU<VES
M>B!W<')O=V%D>FGF('!R>GEN86IM;FEE:B!J961N96=O(&%D<F5S871A+B(*
M"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]G>FEP+G!H<#HT-0IM<V=I9"`B5&AI
M<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N
M(@IM<V=S='(@(E1E;B!S97)W97(@;FEE('!O=')A9FD@<F]Z<&%K;W=Y=V'F
M(&%R8VAI=_-W('II<"!I(&=Z:7`N(@H*(SH@;&EB+TAO<F1E+U)E9VES=')Y
M+G!H<#HQ-#<*(RP@9G5Z>GD*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E
M;G1L>2!D96%C=&EV871E9"XB"FUS9W-T<B`B4VMR>7!T(&1E86MT>7=O=V%N
M>2!P;W!R87=N:64N(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ,C0*
M(RP@9G5Z>GD*;7-G:60@(E1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BXB
M"FUS9W-T<B`B375S:7-Z('=P<F]W861Z:>8@;&EC>F+J+B(*"B,Z('-E<G9I
M8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*(RP@9G5Z>GD*;7-G:60@
M(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W
M:6YD;W<B"FUS9W-T<B`B5&\@;VMN;R!M=7-I('IO<W1AYB!W>7=OLV%N92!P
M<GIE>B!O:VYO(&MO;7!O>GET;W)A('=I861O;6^V8VDN(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*(RP@9G5Z>GD*;7-G
M:60@(E1H=6YD97(B"FUS9W-T<B`B3F%D87=C82(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR,C(*;7-G:60@(E1I8VME=',B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,C<*;7-G:60@(E1I;64B"FUS9W-T
M<B`B0WIA<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,#@*;7-G
M:60@(E1I;64@5')A8VMI;F<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I
M;64N<&AP.C$W"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R(")&;W)M870@
M8WIA<W4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4S.`HC+"!F=7IZ>0IM
M<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B4VMA<W5J('=Y8G)A;K$@
M=&^_<V%M;[;F(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HR,CD*;7-G:60@(E1I=&QE(@IM<V=S='(@(E1Y='6S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS
M9W-T<B`B1&\B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-C(V"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO
M;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y
M("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"B)!8GD@=WEB<F'F('=I
M96QO:W)O=&YE('!O;&$@<')Z>71R>GEM86H@<')Z>6-I<VL@0W1R;"`H4$,I
M(&QU8B!#;VUM86YD("A-86,I("(*(G!O9&-Z87,@:VQI:V%N:6$N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y.0IM<V=I9"`B5&]D87DB
M"FUS9W-T<B`B1'IIMB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(S(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`Y"FUS9VED(")4;V=O(@IM<V=S='(@(E1O9V\B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C(V(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED
M(")4;VME;&%U(@IM<V=S='(@(E1O:V5L874B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S`Q"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R(")*
M=71R;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,CD@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,3`*;7-G:60@(E1O;F=A(@IM<V=S='(@(E1O;F=A(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<W"B,L
M(&9U>GIY"FUS9VED(")4;W`B"FUS9W-T<B`B1&\B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A
M;64@*%]T;W`I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV,PHC+"!F=7IZ>0IM<V=I9"`B5')A;G-L871I;VYS(@IM<V=S='(@(E!R
M97IE;G1A8VIE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q,0IM<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G
M<W1R(")4<GEN:61A9"!I(%1O8F%G;R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ-SDQ"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@(E!R87=D82!L
M=6(@9F&S<WHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C(X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,C<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=6YI
M<VEA(@IM<V=S='(@(E1U;F5Z:F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C,Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C@*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T
M<B`B5'5R8VIA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@
M(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(E1U<F5C:VD@*$E33RTX
M.#4Y+3DI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(E1U<FMM
M96YI<W1A;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C`@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,S(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S$*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B5'5V86QU(@H*
M(SH@;&EB+TAO<F1E+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO
M:6-E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(U-PIM<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]I9G)A;64N<&AP.C$W(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,C0Y"FUS9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T,0IM<V=I9"`B55),(&9O
M<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.3<*;7-G:60@(E523#HB"FUS9W-T<B`B55),.B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S
M,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5G86YD
M82(*;7-G<W1R(")59V%N9&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C,V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")5:W)A:6YE(@IM<V=S='(@
M(E5K<F%I;F$B"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,S-0HC+"!F=7IZ>0IM
M<V=I9"`B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R
M(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,+B(*
M"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L
M92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@
M=7`N(@IM<V=S='(@(B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS,C8*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES
M<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")"L[%D('!O9&-Z
M87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,+B(*"B,Z(&QI8B]61E,O
M9FEL92YP:'`Z,S`X(&QI8B]61E,O;75S<6PN<&AP.C0V.`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N
M(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q
M8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O5D93+V9T<"YP
M:'`Z-C<R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@
M=&\@)7,N(@IM<V=S='(@(D*SL60@<&]D8WIA<R!Z;6EA;GD@9&\@)7,N(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O<W%L+G!H<#HS-S$*;7-G:60@(E5N86)L92!T
M;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(D*SL60@<&]D8WIA
M<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!344PN(@H*(SH@;&EB+U9&4R]F
M='`N<&AP.C<U-@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@
M=VET:"!34TPN(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@
M>B!S97)W97)E;2!344PN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ-3@@;&EB
M+U9&4R]F:6QE+G!H<#HQ-C,@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3@X"B,Z
M(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$Y,R!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HR,#$*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE
M+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R
M96T@4U%,+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS,#,*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R
M>2!<(B5S7"(N(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@
M>B!S97)W97)E;2!344PN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR-S<@;&EB
M+U9&4R]M=7-Q;"YP:'`Z,C4X(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(T.`HC
M+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y
M+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R
M96T@4U%,+B(*"B,Z(&QI8B]61E,O;75S<6PN<&AP.C$R-`HC+"!F=7IZ>0IM
M<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9FEL92XB"FUS9W-T<B`B0K.Q
M9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L
M:6(O5D93+V9I;&4N<&AP.C$Y.`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O
M(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S
M(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O2&]R9&4O
M0V]M<')E<W,O=&%R+G!H<#HW-B!L:6(O2&]R9&4O0V]M<')E<W,O9WII<"YP
M:'`Z-SD*;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N(@IM<V=S
M='(@(D*SL60@<&]D8WIA<R!R;WIP86MO=WEW86YI82!D86YY8V@N(@H*(SH@
M;&EB+U9&4R]F='`N<&AP.C(S-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@
M;F]T(&5M<'1Y+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ
M('H@<V5R=V5R96T@4U%,+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-SD@861M
M:6XO<&5R;7,O9&5L971E+G!H<#HU.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R(")"
ML[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,+B(*"B,Z
M(&QI8B]61E,O9FEL92YP:'`Z,C4T(&QI8B]61E,O;75S<6PN<&AP.C,Q,2!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HS,C8*(SH@;&EB+U9&4R]S<6PN<&AP.C,Q
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B0K.Q
M9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HS-#`@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z
M,S0T"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E
M8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z
M96YI82!S:>H@>B!S97)W97)E;2!344PN(@H*(SH@;&EB+U9&4R]F:6QE+G!H
M<#HR-C`@;&EB+U9&4R]M=7-Q;"YP:'`Z,S(R(&QI8B]61E,O;75S<6PN<&AP
M.C,S-0HC.B!L:6(O5D93+VUU<W%L+G!H<#HS-#,@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,S,V"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GDN(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S
M:>H@>B!S97)W97)E;2!344PN(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C,S.2!L
M:6(O5D93+W-Q;"YP:'`Z,S4Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R
M(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,+B(*
M"B,Z(&QI8B]61E,O9G1P+G!H<#HQ-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G
M<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,
M+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C(V(&QI8B]61E,O;75S<6PN<&AP
M.C$V-R!L:6(O5D93+VUU<W%L+G!H<#HQ.#`*(SH@;&EB+U9&4R]M=7-Q;"YP
M:'`Z,3@W(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,W,"!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HS-S@*(SH@;&EB+U9&4R]S<6PN<&AP.C(Q,`HC+"!F=7IZ>0IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS9W-T<B`B0K.Q
M9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L
M:6(O5D93+W-Q;"YP:'`Z,S(X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S
M='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!344PN
M(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<R,`HC+"!F=7IZ>0IM<V=I9"`B56YA
M8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8P,PHC+"!F=7IZ>0IM<V=I
M9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G
M<W1R(")3>F-Z96?SLWD@8V5R='EF:6MA='4B"@HC.B!L:6(O3F5T+TE-4U`N
M<&AP.C0U,2!L:6(O3F5T+TE-4U`O075T:"YP:'`Z,3$W"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO
M;B!O9B`E<RXB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z
M('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$R.2!L:6(O
M5D93+V9I;&4N<&AP.C$S-"!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-3@*(SH@
M;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,38S"B,L(&9U>GIY"FUS9VED(")5;F%B
M;&4@=&\@;6]V92!61E,@9FEL92XB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S('IM
M:6%N>2!U<W1A=VEE\2XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S8*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M(%PB)7-<(BXB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z
M('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(P-2!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HQ,C(@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3(U
M"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@
M=W)I=&EN9RXB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z
M('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C8W(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C<R"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92XB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA
M('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=&=Z+G!H<#HT-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&]P96X@
M8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@>FUI
M86YY('5S=&%W:67Q+B(*"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE<B]N
M;VYE+G!H<#HS.`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E860@9FEL
M93H@(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W
M97)E;2!344PN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HU.3(*(RP@9G5Z>GD*
M;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M
M(%-13"XB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$P-C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN
M871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]61E,O<W%L7V9I;&4N<&AP.C(X-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE
M('1O(')E;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")"L[%D('!O9&-Z
M87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,+B(*"B,Z(&QI8B]61E,O
M<W%L+G!H<#HR-3$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(D*SL60@
M<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!344PN(@H*(SH@;&EB
M+U9&4R]F='`N<&AP.C(X,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(')E;F%M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(D*S
ML60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!344PN(@H*(SH@
M;&EB+U9&4R]F:6QE+G!H<#HU,S,@;&EB+U9&4R]M=7-Q;"YP:'`Z,C(Y"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE("5S+R5S+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@
M<VGJ('H@<V5R=V5R96T@4U%,+B(*"B,Z(&QI8B]61E,O;75S<6PN<&AP.C(Q
M,R!L:6(O5D93+VUU<W%L+G!H<#HT-3(@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z
M,C<W"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(Y,R!L:6(O5D93+W-Q;"YP
M:'`Z,C0U"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R
M=V5R96T@4U%,+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+VUK:7-O9G,N<&AP
M.C4P"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB
M"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M
M(%-13"XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O;7-W;W)D+G!H<#HU
M.0IM<V=I9"`B56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE
M;G0B"FUS9W-T<B`B3FEE(&UOOVYA('!R>F5TLW5M86-Z>>8@=&5G;R!D;VMU
M;65N='4@5V]R9"UA(@H*(SH@;&EB+U9&4R]F='`N<&AP.C$R,B!L:6(O5D93
M+V9T<"YP:'`Z,3(U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")"L[%D('!O
M9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,+B(*"B,Z(&QI8B]6
M1E,O9FEL92YP:'`Z,3$R"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R(")"L[%D('!O
M9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,+B(*"B,Z(&QI8B]6
M1E,O9FEL92YP:'`Z,C`Y(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$S,"!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HQ,S4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T
M;R!W<FET92!61E,@9FEL92!D871A+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@
ML[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*(RP@9G5Z>GD*;7-G:60@
M(E5N9&5R;&EN92(*;7-G<W1R(")/9'1W\W)Z(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(D-O
M9FYI:B!Z;6EA;GDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,S"B,L(&9U>GIY"FUS9VED(")5;F1O97,@>6]U<B!L87-T
M(&%C=&EO;B(*;7-G<W1R(")7>F[S=R!S=V]JL2!S97-JZB(*"B,Z(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,Y,`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS
M92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.2!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0Q"B,Z(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS-S@@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,X-`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E
M<B!T;SH@(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R
M>4UA;F%G97(N<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C8T"B,L(&9U>GIY"FUS9VED(")5;F9I;&5D(@IM<V=S
M='(@(G!L:6LB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B
M56YI8V]D92`H551&+3@I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4V"FUS9VED(")5;FET960@07)A
M8B!%;6ER871E<R(*;7-G<W1R(")::F5D;F]C>F]N92!%;6ER871Y($%R86)S
M:VEE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S."!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<T"FUS9VED(")5;FET960@2VEN9V1O;2(*;7-G<W1R(")7:65L:V$@
M0G)Y=&%N:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S8*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S='(@(E53
M02(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,SD@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(S-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-C$@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,0IM<V=I9"`B56YI=',B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-3@@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$X"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C0Q.0IM<V=I9"`B56YK;F]W;B(*;7-G<W1R(").:65Z;F%N
M92(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS
M9VED(")5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM<V=S
M='(@(B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY
M"FUS9VED(")5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-#8*(RP@9G5Z>GD*;7-G:60@(E5N:VYO=VX@;&]C871I;VX@<')O=FED960N
M(@IM<V=S='(@(DYI97IN86YY(&%D<F5S870B"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y,0HC+"!F=7IZ>0IM<V=I9"`B56YK;F]W
M;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B4')O<WKJ('!O9&'F
M(&YA>G?J('6_>71K;W=N:6MA(&D@:&%SLV\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*(RP@9G5Z>GD*
M;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(E5S
M=?$B"@HC.B!L:6(O2&]R9&4O261E;G1I='DN<&AP.C(Y-@IM<V=I9"`B56YN
M86UE9"(*;7-G<W1R(")"97H@;F%Z=WDB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G
M960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R
M86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+
M('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H
M("(*(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S
M('1H92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*(RP@9G5Z>GD*;7-G
M:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@(D1O;7FV;&YY(&MO;&]R(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV.#8@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HY,C8*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HY
M,S(*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R(").:65O
M8G.S=6=I=V%N92!R;WIS>F5R>F5N:64B"@HC.B!A9&UI;B]P97)M<R]E9&ET
M+G!H<#HQ,#8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ.#,*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P9&%T92(*;7-G
M<W1R(")586MT=6%L;FEJ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHS,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B57!D871E
M("5S(@IM<V=S='(@(D1O9&%J('6_>71K;W=N:6MA(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,PHC+"!F=7IZ>0IM<V=I9"`B57!D
M871E('5S97(B"FUS9W-T<B`B1&]D86H@=;]Y=&MO=VYI:V$B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C$S-R!A9&UI;B]P97)M<R]E9&ET+G!H<#HR,3<@<V5R
M=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S,`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@(D1O9&%J('6_>71K
M;W=N:6MA(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#$*(RP@9G5Z
M>GD*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S='(@(DYI
M92!W>6=E;F5R;W=A;F\@OV%D;F5G;R!S:W)Y<'1U+B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ.#$@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$X,@IM<V=I9"`B57!L;V%D(@IM<V=S='(@(EIALV%D=6HB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@Y"FUS9VED(")5<&QO861E9"!A
M;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C$X"B,L(&9U>GIY"FUS9VED(")5<'!E<B!R;VUA
M;B!N=6UB97)S(@IM<V=S='(@(D=R=61Z:67Q(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(T,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B57)U9W5A
M>2(*;7-G<W1R(")5<G5G=V%J(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`Z-#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R(")5<W7Q(&]B96-N92!K;'5C>F4B
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED
M(")5<V4@4U-,(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,C0*;7-G:60@(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N
M="!F;W(@24U34"!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]2
M96=I<W1R>2YP:'`Z-C$X"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@
M:7,@;F]T(&%U=&AO<FES960@9F]R("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HR,#,*(RP@9G5Z>GD*;7-G:60@(E5S97(@061M:6YI<W1R
M871I;VXB"FUS9W-T<B`B061M:6YI<W1R86-J82!UOWET:V]W;FEK\W<@2&]R
M9&4B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C(U,0IM<V=I9"`B57-E
M<B!/<'1I;VYS(@IM<V=S='(@(D]P8VIE('6_>71K;W=N:6MA(@H*(SH@<VEG
M;G5P+G!H<#HV,@IM<V=I9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T<B`B
M4F5J97-T<F%C:F$@=;]Y=&MO=VYI:V$B"@HC.B!S:6=N=7`N<&AP.C(R"B,L
M(&9U>GIY"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A
M8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R(")/8G.S=6=A(&9I;'1R\W<@
M:F5S="!W>;.Q8WIO;F$@;F$@='EM('-Y<W1E;6EE+B(*"B,Z(&%D;6EN+W!E
M<FUS+V5D:70N<&AP.C$W,B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(T-@HC
M+"!F=7IZ>0IM<V=I9"`B57-E<B!P97)M:7-S:6]N<R(*;7-G<W1R(")$;VUY
MMFQN92!U<')A=VYI96YI82(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ.#(*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4S-B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N
M<&AP.CDX"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,S"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z-C@@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V
M92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM<V=S='(@(DYA>G=A('6_>71K
M;W=N:6MA(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HQ,C0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E<UPB(&%L<F5A9'D@97AI
M<W1S+B(*;7-G<W1R(")5OWET:V]W;FEK(&\@;F%Z=VEE(%PB)7-<(B!J=;\@
M:7-T;FEE:F4N(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@W
M"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B3F%Z=V$@=;]Y=&MO=VYI:V$Z
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`IM<V=I9"`B57-E
M<FYA;64Z("(*;7-G<W1R(").87IW82!UOWET:V]W;FEK83H@(@H*(SH@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HR,3D*(RP@9G5Z>GD*;7-G:60@(E5S97)S
M(@IM<V=S='(@(DYA>G=A('6_>71K;W=N:6MA(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E
M;3HB"FUS9W-T<B`B5;]Y=&MO=VYI8WD@=R!S>7-T96UI93HB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C0R(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED
M(")5>F)E:VES=&%N(@IM<V=S='(@(E5Z8F5K:7-T86XB"@HC.B!L:6(O5D93
M+V9I;&4N<&AP.C$P,2!L:6(O5D93+V9I;&4N<&AP.C$X.`HC+"!F=7IZ>0IM
M<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B
M3VMR9;9L;VYY('!L:6L@;FEE(&ES=&YI96IE+B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ,3@*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(E=A
M:V%C:F4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#8V"FUS9VED(")686QI
M9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C,X"FUS9VED(")686QI9&ET>2(*
M;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3DW(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U"FUS9VED
M(")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z.#4V(&QI8B](;W)D92]&;W)M+G!H<#HQ,3<W
M"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM
M=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C(T-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(V-R!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C,Q-0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDR-PHC+"!F
M=7IZ>0IM<V=I9"`B5F%L=65S(@IM<V=S='(@(E5W86=I(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(Q,3`@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q.#<*;7-G
M:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C0Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR-#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED
M(")686YU871U(@IM<V=S='(@(E9A;G5A='4B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C,R"B,L(&9U>GIY"FUS9VED(")687)I86)L92(*
M;7-G<W1R(")7>;.Q8WIO;F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C0U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")696YE>G5E;&$B"FUS9W-T
M<B`B5V5N97IU96QA(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR
M,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@
M;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B5F5R<VEO;B(*
M;7-G<W1R(")797)S:F$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C`U"B,L(&9U>GIY"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`B
M7U5P<F%W;FEE;FEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX,PHC+"!F=7IZ>0IM<V=I9"`B5F5R=&EC86P@
M86QI9VXB"FUS9W-T<B`B5'EL:V\@=&5K<W0B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T"B,L(&9U>GIY"FUS9VED(")6
M97)T:6-A;"!P861D:6YG(@IM<V=S='(@(E1Y;&MO('1E:W-T(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PHC+"!F=7IZ
M>0IM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(E1Y;&MO('1E:W-T(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*(RP@9G5Z
M>GD*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R(")7>7-O:VDB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C0X(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR-#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED
M(")6:65T($YA;2(*;7-G<W1R(")7:65T;F%M(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.30*;7-G:60@(E9I971N86UE<V4@*%9)4T-)22DB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.CDU.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(E=I9&]K("5S(@H*
M(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E
M<FYA;"!W96(@<&%G92(*;7-G<W1R(")0;VMAOR!S=')O;NH@5U=7(@H*(SH@
M;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@Q.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@(E!O:V&_(&IA:V\@)7,B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0V(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR-#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V
M"FUS9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R(")"<GET
M>6IS:VEE(%=Y<W!Y($1Z:65W:6-Z92(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR-#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA
M;F1S+"!5+E,N(@IM<V=S='(@(E=Y<W!Y($1Z:65W:6-Z92!3=&%N\W<@6FIE
M9&YO8WIO;GEC:"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Y"FUS9VED
M(")6:7-I8FEL:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-3$*;7-G:60@(E9I<VEB:6QI='DZ("(*;7-G<W1R("(B
M"@HC.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS
M9VED(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*
M;7-G:60@(E=!4DXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!214U/
M5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR-3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(T-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G
M:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(E=A;&QI<R!I($9U='5N
M82(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S
M+G!H<#HR.0IM<V=I9"`B5V%R;FEN9R(*;7-G<W1R(")/<W1R>F6_96YI92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3@*
M(RP@9G5Z>GD*;7-G:60@(E=E(@IM<V=S='(@(E=75R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S
M="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-#$U"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Y,@IM<V=I9"`B5V5A=&AE<BYC
M;VTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*;7-G
M:60@(E=E8B(*;7-G<W1R(")75U<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S<V"B,L(&9U>GIY"FUS9VED(")796(@4VET92(*;7-G<W1R(")5
M4DP@<W1R;VYY(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU.`IM
M<V=I9"`B5V5E:VQY(@IM<V=S='(@(D-O('1Y9'II9?$B"@HC.B!S97)V:6-E
M<R]P;W)T86PO;6]B:6QE+G!H<#HR.`IM<V=I9"`B5V5L8V]M92(*;7-G<W1R
M(")7:71A;7DB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R(")7:71A;7D@=R`E<R(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T86PO
M;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE+"`E<R(*
M;7-G<W1R(")7:71A;7DL("5S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.34*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$I(@IM<V=S='(@(EIA8VAO
M9&YI("A)4T\M.#@U.2TQ*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV
M"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B6F%C:&]D
M;FD@*$E33RTX.#4Y+3$U*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW
M."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G
M<W1R(")386AA<F$@6F%C:&]D;FEA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N
M('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R(")*86NQ
M(&%P;&EK86-JZB!M82`E<R!W>;9W:65T;&'F('!O('IA;&]G;W=A;FEU('-I
MZC\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR,0IM<V=I9"`B
M5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C0*;7-G:60@(E=H870@
M:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,PIM<V=I9"`B5VAI8V@@
M<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+B(*
M;7-G<W1R(")*86MI92!W='EC>FMI(&%K='EW;W=AYB!W(%)O>F)U9&]W86YY
M;2!E9'ET;W)Z92!T96MS='4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`HC+"!F=7IZ>0IM<V=I9"`B5VED
M=&@B"FUS9W-T<B`B3W-T<GIEOV5N:64B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,S$R-`HC+"!F=7IZ>0IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM
M<V=S='(@(DQI='=A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T
M:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T
M<B`B(@HB4WIE<F]K;[;F(&QE=V5G;R!M96YU("5S("AZ;6EA;F$@>F%C>FYI
M92!O8F]W:;%Z>7=AYB!P<GIY(&YA<W3J<&YY;2`B"B)L;V=O=V%N:74I.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V
M"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*(RP@9G5Z
M>GD*;7-G:60@(E=I9'1H('5N:70B"FUS9W-T<B`B3&ET=V$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0HC+"!F=7IZ
M>0IM<V=I9"`B5VED=&@Z(@IM<V=S='(@(D]S=')Z9;]E;FEE(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V.`IM<V=I9"`B5VEK:2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@X(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"B,L(&9U>GIY"FUS
M9VED(")7:6YD(@IM<V=S='(@(D]S=')Z9;]E;FEE(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*(RP@9G5Z>GD*;7-G:60@
M(E=I;F0@16%R;'DB"FUS9W-T<B`B3W-T<GIEOV5N:64B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C@P"FUS9VED(")7:6YD('-P965D(&EN(&MN;W1S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34V"B,L(&9U>GIY
M"FUS9VED(")7:6YD.B(*;7-G<W1R(")/<W1R>F6_96YI92(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S`*(RP@9G5Z>GD*;7-G:60@(E=I
M;F0Z("(*;7-G<W1R(")/<W1R>F6_96YI92(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#(*(RP@9G5Z>GD*;7-G:60@(E=I<VAL
M:7-T<R(*;7-G<W1R(")":6&S82!L:7-T82(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV-0HC+"!F=7IZ>0IM<V=I9"`B5V]R:R(*;7-G<W1R(")L=6(B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-"!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-`IM<V=I9"`B5V]R:R!!
M9&1R97-S(@IM<V=S='(@(D%D<F5S(&1O('!R86-Y(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO;F4B
M"FUS9W-T<B`B5&5L+B!D;R!P<F%C>2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR,S$*;7-G:60@(E@M4F5F(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@0F%S:6,@
M0V]N<W1R86EN=',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU.3(*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.30*
M;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@
M(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C@R"FUS9VED(")8-3`Y=C,@
M97AT96YS:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU
M,`IM<V=I9"`B65DB"FUS9W-T<B`B4E(B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,S@V(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,C<*;7-G:60@(EE965DB"FUS9W-T<B`B4E)24B(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#`Q"FUS9VED
M(")986AO;R$@;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-86EN=&5N
M86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G<W1R(")#;R!R;VLB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4R(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR-#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W
M"FUS9VED(")996UE;B(*;7-G<W1R(")*96UE;B(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HX.#4*;7-G:60@(EEE<R(*;7-G<W1R
M(")486LB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O86=R965M96YT7V)O
M='1O;2YI;F,Z-@IM<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(E1A:RP@
M>F=A9'IA;2!S:>HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C4R"FUS9VED(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S
M92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+G!H<#HQ,CDW"FUS9VED(")9;W4@
M87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O261E;G1I='DN<&AP.C,P,@IM<V=I9"`B66]U(&-A;B!N;W0@:&%V92!T
M:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#4V(&QI8B](;W)D92]&;W)M
M+G!H<#HQ.3<V"B,L(&9U>GIY"FUS9VED(")9;W4@9&ED(&YO="!E;G1E<B!A
M('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S='(@(E1W\VH@861R97,@92UM
M86EL.B(*"B,Z(&QI8B](;W)D92]$871A+G!H<#HR-S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H
M92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B
M"B)I;B`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDR
M,PIM<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R(")7
M>6QO9V]W8;-EMB!S:>HN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-C$*
M;7-G:60@(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE
M(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB
M9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$X.`HC+"!F=7IZ>0IM<V=I
M9"`B66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`B
M5'?S:B!A9')E<R!E+6UA:6PZ(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P
M+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@
M1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B0G)A
M:R!K;VYF:6=U<F%C:FD@=V5W;NIT<GIN96H@9&QA('1E9V\@:&]S=&$B"@HC
M.B!L:6(O2&]R9&4N<&AP.C0S,0HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@
M8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(D)R86L@:V]N9FEG
M=7)A8VII('=E=V[J=')Z;F5J(&1L82!T96=O(&AO<W1A(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E
M<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R
M;V)L96T@<F5P;W)T+B(*;7-G<W1R(")-=7-I<WH@;W!I<V'F('!R;V)L96T@
M>F%N:6T@9V\@=WFV;&5S>BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDX"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!E
M;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T
M<B`B375S:7-Z('=P<F]W861Z:>8@<')Z>6YA:FUN:65J(&IE9&YE9V\@861R
M97-A=&$N(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*(RP@
M9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@
M9&5L971E9"XB"FUS9W-T<B`B375S:7-Z(&]K<F6V;&GF('6_>71K;W=N:6MA
M+"!K=/-R96=O(&-H8V5S>B!U<W5NL>8N(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,3$Y"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA
M;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R(")-=7-I<WH@;VMR9;9L:>8@=;]Y
M=&MO=VYI:V$L(&MT\W)E9V\@8VAC97-Z('5S=6ZQYBXB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M
M92!T;R!R96UO=F4N(@IM<V=S='(@(DUU<VES>B!O:W)EMFQIYB!UOWET:V]W
M;FEK82P@:W3S<F5G;R!C:&-E<WH@=7-U;K'F+B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C8R('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I
M9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G
M<W1R(")-=7-I<WH@;VMR9;9L:>8@=;]Y=&MO=VYI:V$L(&MT\W)E9V\@8VAC
M97-Z(&1O9&'F+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@HC+"!F=7IZ>0IM
M<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E
M+B(*;7-G<W1R(")-=7-I<WH@;VMR9;9L:>8@=;]Y=&MO=VYI:V$L(&MT\W)E
M9V\@8VAC97-Z(&1O9&'F+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N
M<&AP.C$S.`HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T
M(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R(")-=7-I<WH@;VMR9;9L:>8@
M=;]Y=&MO=VYI:V$L(&MT\W)E9V\@8VAC97-Z('5S=6ZQYBXB"@HC.B!L:6(O
M2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,@HC+"!F=7IZ>0IM
M<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+B(*;7-G
M<W1R(")-=7-I<WH@;VMR9;9L:>8@=;]Y=&MO=VYI:V$L(&MT\W)E9V\@8VAC
M97-Z('5S=6ZQYBXB"@HC.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M
M='`N<&AP.C<S"FUS9VED(")9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI
M86X@<&AO;F4@;G5M8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H
M+G!H<#HY,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N
M(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED(")9
M;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`B5'?S:B!A9')E<R!E+6UA:6PB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`T"FUS9VED(")9;W5R($9R
M;VTZ(&%D9')E<W,Z(@IM<V=S='(@(E1W\VH@861R97,@3V0Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@Y"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(E1W
M;VIE(&EN9F]R;6%C:F4B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3$U"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H
M87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S
M<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L
M;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB5'?S:B!A9')E<R!I;G1E<FYE=&]W
M>2!S:>H@>FUI96YILR!O9"!P;V-ZL71K=2!S97-J:2`E<RX@5R!Z=VFQ>FMU
M('H@(@HB8F5Z<&EE8WIE\7-T=V5M(%1W;VIE9V\@:V]N=&$@;75S:7-Z('IA
M;&]G;W=AYB!S:>H@<&]N;W=N:64N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z,S,*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R(")4=V]J
M92!I;6GJ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.CD*
M;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO
M="!S=7!P;W)T(&%D9&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S
M(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R
M("(B"B)496X@<WES=&5M(&%U=&5N='EK86-J:2!N:64@;V)SLW5G=6IE(&1O
M9&%W86YI82!UOWET:V]W;FEK\W<L(&QU8B!T82!O<&-J82`B"B)Z;W-T8;-A
M('=YL[%C>F]N82XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N
M:6YC.CD*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D
M;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E
M("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB
M"FUS9W-T<B`B(@HB5&5N('-Y<W1E;2!A=71E;G1Y:V%C:FD@;FEE(&]B<[-U
M9W5J92!L:7-T;W=A;FEA('6_>71K;W=N:6OS=RP@;'5B('1A(&]P8VIA("(*
M(GIO<W1ALV$@=WFSL6-Z;VYA+B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY
M,3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E
M<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG
M(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R
M:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB5'?S:B!A
M9')E<R!I;G1E<FYE=&]W>2!S:>H@>FUI96YILR!O9"!P;V-ZL71K=2!S97-J
M:2`E<RX@5R!Z=VFQ>FMU('H@(@HB8F5Z<&EE8WIE\7-T=V5M(%1W;VIE9V\@
M:V]N=&$@;75S:7-Z('IA;&]G;W=AYB!S:>H@<&]N;W=N:64N(@H*(SH@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(EEO=7(@8G)O
M=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`B
M(@HB5'=O:F$@<')Z96=LL61A<FMA(&YI92!O8G.S=6=U:F4@=WFV=VEE=&QA
M;FEA('!L:6OS=R!G<F%F:6-Z;GEC:"!T96=O('1Y<'4N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z-#(*(RP@9G5Z>GD*;7-G:60@(B(*
M(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T
M:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT+B(*
M;7-G<W1R("(B"B)4=V]J82!P<GIE9VRQ9&%R:V$@;FEE(&]B<[-U9W5J92!T
M96H@;W!C:FD@9')U:V]W86YI82X@3F%J8VFV;FEJ($-T<FPO3W!C:F$@(@HB
M*R!0(&%B>2!W>61R=6MO=V'F+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-#D*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@
M(E1W;VIA(&]B96-N82!S=')E9F$@8WIA<V]W83HB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,34P"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ
M(@IM<V=S='(@(D1O;7FV;&YA('1OOW-A;6^VYCHB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3DS"FUS9VED(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T
M<B`B5'=O:F4@<&6S;F4@:6UIZB!I(&YA>G=I<VMO.B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO
M=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B5'=O:6T@
M;F]W>6T@:&%SLV5M('<@)7,@:F5S=#H@)7,B"@HC.B!L:6(O2&]R9&4O4')E
M9G,O54DN<&AP.C$U-`IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U
M<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G
M<W1R(")4=V]J92!U<W1A=VEE;FEA('IO<W1ALWD@=6%K='5A;&YI;VYE(&YA
M(&-Z87,@=')W86YI82!T96H@<V5S:FDN(@H*(SH@;&EB+TAO<F1E+U!R969S
M+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D
M871E9"XB"FUS9W-T<B`B5'=O:F4@=7-T87=I96YI82!Z;W-T8;-Y('5A:W1U
M86QN:6]N92XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-0HC
M+"!F=7IZ>0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="(*
M;7-G<W1R(")4=V]I;2!N;W=Y;2!H87.S96T@=R`E<R!J97-T.B`E<R(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R
M('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N
M9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9
M;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R(")4=V]J92!Z9&%L;F4@<V5R
M=V5R>3HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4T(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R
M(")*=6=O<[-A=VEA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X
M"FUS9VED("):86ER92(*;7-G<W1R("):86ER(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(U-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA
M(@IM<V=S='(@(EIA;6)I82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M-3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@
M(EII;6)A8G=E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED
M(")::7!P>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O
M:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E9"!497AT
M72(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HU-@IM<V=I
M9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R(");4F%P;W)T(&\@<')O8FQE
M;6EE72(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS
M.C$S"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]497AT+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M("5S
M(&QI;F5S72(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4N<&AP.C$Y,PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S
M='(@(B5S(&1O("5S('H@)7,B"@HC.B!L:6(O2&]R9&4N<&AP.C$T-#$@=&5M
M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(E]!9&UI;FES=')A8VIA(@H*(SH@;&EB+V%P:2YP:'`Z
M,3,V"FUS9VED(")?0TQ)(@IM<V=S='(@(E]#3$DB"@HC.B!L:6(O87!I+G!H
M<#HQ,C0*(RP@9G5Z>GD*;7-G:60@(E]$871A5')E92(*;7-G<W1R(")$871A
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,Q"FUS9VED(")?1&5L971E(%)O=R(*;7-G<W1R(")?57-U\2!W
M:65R<WHB"@HC.B!L:6(O87!I+G!H<#HQ,38*;7-G:60@(E]'<F]U<',B"FUS
M9W-T<B`B7T=R=7!Y(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$W-0IM<V=I
M9"`B7TAE;'`B"FUS9W-T<B`B7U!O;6]C(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S"B,L(&9U>GIY"FUS
M9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")496PN(&MO;2XB
M"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,3DT"FUS9VED(")?3&]G(&EN(@IM
M<V=S='(@(E]:86QO9W5J(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$Y,`IM
M<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`B7U=Y;&]G=6HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G
M:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R("):;6EE\2!L:6YK+BXN(@H*
M(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$V-`IM<V=I9"`B7T]P=&EO;G,B"FUS
M9W-T<B`B7T]P8VIE(@H*(SH@;&EB+V%P:2YP:'`Z,3(P"FUS9VED(")?4&5R
M;6ES<VEO;G,B"FUS9W-T<B`B7U5P<F%W;FEE;FEA(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V"FUS9VED
M(")?4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`B57-U\2!L:6YK+BXN(@H*(SH@
M;&EB+V%P:2YP:'`Z,3`X"FUS9VED(")?4V5T=7`B"FUS9W-T<B`B7TMO;F9I
M9W5R86-J82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS,@HC+"!F=7IZ>0IM<V=I9"`B7U1A8FQE(%!R;W!E
M<G1I97,N+BXB"FUS9W-T<B`B5&5L+B!K;VTN(@H*(SH@;&EB+V%P:2YP:'`Z
M,3$R"FUS9VED(")?57-E<G,B"FUS9W-T<B`B7U6_>71K;W=N:6-Y(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HX.3`*;7-G:60@(F%D9')E<W,@8F]O:R(*
M;7-G<W1R(")K<VFQOVMA(&%D<F5S;W=A(@H*(SH@;&EB+TAO<F1E+TMO;&%B
M+G!H<#HX.#(*;7-G:60@(F-A;&5N9&%R(@IM<V=S='(@(FMA;&5N9&%R>B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S4X"B,L('!H<"UF;W)M870*;7-G:60@(F-A;&TB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C4X.0IM<V=I9"`B8VQI
M8VL@:&5R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B9F%L;&EN9R(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.#4Y"FUS9VED(")F:6QE(@IM<V=S
M='(@(G!L:6LB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W-"!L:6(O0FQO
M8VLO;65T87(N<&AP.C,V,"!L:6(O0FQO8VLO;65T87(N<&AP.C,X-@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E
M<R`E<R(*;7-G<W1R("(E<R!D;R`E<R!Z("5S(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S.`HC+"!F=7IZ>0IM<V=I9"`B9W5S=&EN9R(*
M;7-G<W1R(")3:65R<&EE\2(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,S(*;7-G:60@(F@Z(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS,S$*;7-G:60@(FAH(@IM
M<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M-C4@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@
M(FEM;65D:6%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H
M<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B
M:6YL:6YE(@IM<V=S='(@(DYA9[/S=VMI(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*(RP@9G5Z>GD*;7-G:60@(FQI;F5S
M72(*;7-G<W1R(").86>S\W=K:2(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+VUK
M:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*;7-G:60@(FUK:7-O9G,@97)R
M;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S0R"FUS9VED(")M
M;2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C(X."!S
M97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C`U"FUS9VED(")N86UE(@IM
M<V=S='(@(DYA>G=I<VMO(@H*(SH@;&EB+TAO<F1E+U)00RYP:'`Z,3(Q"B,L
M(&9U>GIY"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`B56MO\6-Z
M;VYE(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,C$Y"B,L(&9U
M>GIY"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(E1A(&]P
M8VIA(&YI92!J97-T(&IE<WIC>F4@>F&SL6-Z;VYA+B(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z.#<T"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(FYO=&%T
M;FEK(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX.`HC+"!F=7IZ>0IM<V=I9"`B<&5R8V5N="(*;7-G<W1R(")$
M<G5K=6HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*(RP@9G5Z>GD*
M;7-G:60@(G)I<VEN9R(*;7-G<W1R(")/<F=A;FEZ871O<B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z.3@*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B
M"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS-3@*;7-G:60@
M(G-S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C<R"B,L(&9U>GIY"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B
M3F]T871N:6L@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C@Y.`HC+"!F
M=7IZ>0IM<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@(D-Z87)N82!L:7-T82(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&QI8B](;W)D92]!=71H+U-I9VYU<"YP
M:'`Z,C8Y"B,L(&9U>GIY"FUS9VED(")T>7!E('1H92!P87-S=V]R9"!T=VEC
M92!T;R!C;VYF:7)M(@IM<V=S='(@(DAA<[-O(@H*(SH@861M:6XO<V5T=7`O
M9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*(RP@9G5Z>GD*
M;7-G:60@(G5N:69I960B"FUS9W-T<B`B<&QI:R(*"B,Z(&QI8B](;W)D92]-
M24U%+U!A<G0N<&AP.C(W"FUS9VED(")U;FYA;65D(@IM<V=S='(@(F)E>B!N
M87IW>2(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*(RP@9G5Z>GD*
M;7-G:60@(G5S97(@<V5L96-T(@IM<V=S='(@(E=Y8O-R(&MO;&]R=2(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#
M87)D(@IM<V=S='(@(G9#87)D(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(R-`HC+"!F=7IZ>0IM<V=I9"`B=SHB"FUS9W-T<B`B
M1G=D.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED
M(")W96%T:&5R+F-O;2(*;7-G<W1R("(B"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P;R]K;5]+2"YP;P``````````````````````````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`V-#`W,C0@,3`U,34T,S,W-#,@,#$W
M-3(T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`",@4T]-12!$15-#4DE05$E612!4251,12X*(R!#;W!Y<FEG:'0@*$,I(%E%
M05(@2&]R9&4@4')O:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U
M;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!004-+04=%('!A8VMA9V4N
M"B,@3&5A;F<@0VAU;7-O8F5N(#QS;V)E;D!K:&UE<F]S+FEN9F\^+"`R,#`V
M+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!)
M35!<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`T+3$R+3`X(#$P.C(X*S`Q
M,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#4M,#8M,34@,3$Z-3,K,#<P
M,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!,96%N9R!#:'5M<V]B96X@/'-O8F5N
M0&MH;65R;W,N:6YF;SY<;B(*(DQA;F=U86=E+51E86TZ($MH;65R(#QS=7!P
M;W)T0&MH;65R;W,N:6YF;SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#
M;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]=71F+3A<;B(*(D-O
M;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(S-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E
M<R!D87ES(&%G;RDB"FUS9W-T<B`B("@E<R#AGI#AGY+AGH3AGX/B@(OAGH#A
MGI/AGY+AGIOAGH3B@(OAGI'AGX4I(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ,S@V"B,L('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y
M("5S*2(*;7-G<W1R("(@*.&>@N&?DN&>FN&>MN&>E.&?B^*`B^&>A>&>N^&>
MA>*`B^&>E>&?DN&>F^&>O.&>G.*`B^&>@.&>MN&>C^&?BR`E<RDB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S@U"B,L('!H<"UF;W)M870*;7-G
M:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,X,0IM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B("CA
MGI#AGY+AGH3AGX/B@(OAGI/AGX'AGX<I(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C,X,PIM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B("CA
MGI#AGY+AGH3AGX/B@(OAGI_AGY+AGJ+AGX+AGH`I(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C,W.0IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S
M='(@(B`HX9Z8X9^2X9Z?X9ZWX9Z;X9Z8X9^)X9ZWX9Z)*2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3`@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,U,PHC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,SDY"FUS9VED("(@870@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I
M<R!N;W0@82!D:7)E8W1O<GDN(@IM<V=S='(@(EPB)7-<(B#AGICAGK?AGI/B
M@(OAGICAGX+AGI/B@(OAGH?AGK;B@(OAGI#AGH_B@(OAGJ'AGK[AGIG"H.&?
ME"(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-S(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC92XB"FUS9W-T
M<B`B7"(E<UPB(.&>F.&>M^&>D^*`B^&>F.&?@N&>D^*`B^&>A^&>MN*`B^&>
MA^&>F.&?DN&>FN&>ON&>G^*`B^&>C^&?DN&>FN&>N>&>F.&>C^&?DN&>FN&>
MO.&>G.*`B^&>H>&>ON&>F<*@X9^4(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+U)E9VES=')Y+G!H<#HW,#,*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+U)E9VES=')Y+G!H<#HQ,#<R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<
M(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]4<F5E+U1R964N<&AP.C$W,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@9F]U
M;F0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S
M('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N
M<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@
M=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E871E9#H@
M)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL
M;W=E9"`H)2XR9B4E*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C,Q"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N
M9"`E<R(*;7-G<W1R("(E9"`E<R#AGI/AGK?AGH0@)7,B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C(V-R!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-34W"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U
M<B!P87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C<X"B,L('!H<"UF;W)M870*;7-G:60@(B5D
M+61A>2!F;W)E8V%S="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N
M86YC92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HW,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z
M.#0R(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T.`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(E<R!+0B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T,"!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@34(B"FUS9W-T<B`B)7,@X9Z8X9^!X9Z`X9ZVX9Z4X9^#(@H*(SH@
M<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(%-E='5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG
M;G5P+G!H<#HR-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#,R(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DT"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z-C@R(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4P"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,2!L:6(O0FQO8VLO;65T
M87(N<&AP.C$W-R!L:6(O0FQO8VLO;65T87(N<&AP.C(U,0HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,U-R!L:6(O0FQO8VLO;65T87(N<&AP.C,V,PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O
M<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI
M<R!T:6UE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S0X"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDX"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&UI;G5T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!
M9&1R97-S($)O;VLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HY,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP
M-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,CD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I
M;&4N<&AP.CDV"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R
M("(E<R#AGY8@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H
M=&UL+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,Z(%1H:7,@
M;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N
M($)E=V%R92!O9B!F;VQL;W=I;F<@(@HB86YY(&QI;FMS(&EN(&ET(&]R(&]F
M('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R
M;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S4W(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,#(*;7-G
M:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,#`@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C$S"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R
M:6%B;&4@9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C(Y-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C,T.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#<W(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,S8*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<T-@IM<V=I9"`B+2T@<V5L96-T("TM
M(@IM<V=S='(@(BTM(.&>A^&?DN&>FN&>ON&>GR`M+2(*"B,Z(&QI8B]";&]C
M:R]T:6UE+G!H<#HR-0IM<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS9W-T<B`B
MX9Z1X9^2X9Z:X9Z$X9^+X9Z1X9^2X9Z:X9ZVX9Z9(.&?H>&?HB#AGICAGXGA
MGX3AGH0B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C0*;7-G:60@(C(T($AO
M=7(@1F]R;6%T(@IM<V=S='(@(N&>D>&?DN&>FN&>A.&?B^&>D>&?DN&>FN&>
MMN&>F2#AGZ+AGZ0@X9Z8X9^)X9^$X9Z$(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(N&?HN&?I"#A
MGICAGXGAGX3AGH0B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C8Y
M"FUS9VED("(\4')E=FEO=7,B"FUS9W-T<B`B/.&>F.&>N^&>DR(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3,Q"FUS9VED(")!(&1A=&%B87-E(&)A8VME
M;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38R"FUS9VED(")!(&9A=&%L
M(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M261E;G1I='DO261E;G1I='DN<&AP.C0P-PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)!(&UE<W-A9V4@:&%S(&)E96X@<V5N="!T;R!<(B5S7"(@=&\@=F5R
M:69Y('1H870@=&AI<R!I<R!R96%L;'D@>6]U<B`B"B)A9&1R97-S+B!4:&4@
M;F5W(&5M86EL(&%D9')E<W,@:7,@86-T:79A=&5D(&%S('-O;VX@87,@>6]U
M(&-O;F9I<FT@=&AI<R`B"B)M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B;&EC
M(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q
M-C@*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R
M:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P.3D*;7-G:60@(B(*(D$@<'5B;&EC
M(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#$V"FUS9VED
M("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU,#8*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@
M4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*
M(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@
M4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S8T"FUS
M9VED(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP
M="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.CD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M,`IM<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I
M;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ,@IM<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B
M04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A
M+W1I;64N:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G
M:60@(D%022!)1"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O
M<B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,PIM
M<V=I9"`B06)O=70N+BXB"FUS9W-T<B`BX9ZBX9^&X9Z6X9ZXXH"++BXN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM
M<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C<P
M"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ
M,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS"FUS9VED(")!
M8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(N&>EN&?D.&>C^&?C.&>F.&>
MMN&>D^*`B^&>HN&?AN&>EN&>N.&>@N&>CN&>D^&>N"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW.`IM<V=I9"`B06-C;W5N="!087-S=V]R9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.3,*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Y"FUS9VED(")!8V-O
M=6YT:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,30X('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0IM<V=I9"`B061D
M(@IM<V=S='(@(N&>E.&>D^&?DN&>D.&?@N&>F"(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,C(T(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!9&0@0VAI
M;&0@1W)O=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HY."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDY"FUS
M9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D($AE<F4Z(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP
M:'`Z,C$Y"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HX.`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N
M:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@
M=&\@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD
M('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-`IM
M<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V5D:70N:6YC.C,T"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHY-0IM
M<V=I9"`B061D('!A:7(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE
M;G4@87,@82!-;WII;&QA(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<Q"FUS9VED(")!9&0@
M=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*;7-G:60@(D%D9"!T;R!M>2!A
M9&1R97-S(&)O;VLB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*
M;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(N&>E.&>D^&?DN&>D.&?@N&>F.*`
MB^*`B^*`B^&>HN&?DN&>D^&>@.*`B^&>E.&?DN&>FN&>OB(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D(%PB
M)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO
M;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@(B(*"B,Z
M('-I9VYU<"YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E
M<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G
M:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#D*;7-G:60@(D%D9')E<W,B"FUS9W-T
M<B`BX9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$T.`IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S
M='(@(N&>G^&?@.&>G.&>E^&?A>*`B^&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>
MMN&>DR(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.CDT"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O
M=&AE<B!U<V5R<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@
M<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI
M<W1R871I;VXB"FUS9W-T<B`BX9Z`X9ZVX9Z:XH"+X9Z"X9^2X9Z:X9Z4X9^+
MXH"+X9Z"X9^2X9Z:X9Z$(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,U-PIM<V=I9"`B061S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@
M(D%F9VAA;FES=&%N(@IM<V=S='(@(N&>HN&>MN&>H.&?DN&>@N&>MN&>D^&>
MN.&>G^&?DN&>D.&>MN&>DR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%L8F%N:6$B
M"FUS9W-T<B`BX9ZBX9ZVX9Z;X9^+X9Z4X9ZVX9Z3X9ZX(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,`IM<V=I9"`B06QG97)I82(*;7-G<W1R("+AGJ+AGK;AGIOAGXOAGJ#AGY+A
MGI_AGX'AGIKAGK@B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R("+AGHCAGY+AGICA
MGX3AGX?B@(OAGH#AGY+AGIOAGX+AGH3AGH#AGY+AGIOAGK;AGIDB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$V
M"FUS9VED(")!;&EG;B(*;7-G<W1R("+AGH_AGICAGY+AGIKAGKGAGI@B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8W"FUS
M9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HY,@IM<V=I9"`B06QL(@IM<V=S='(@(N&>D>&>MN&?AN&>A.*`
MB^&>HN&>G^&?BR(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,C`W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G:60@(D%L;"!!
M=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U
M<',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HY,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O9&%T871R964N<&AP.C<U"FUS
M9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B
M06QL(&9O=7(@<VED97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@W.0IM<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S@*;7-G
M:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP
M.C4Q.`IM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$R-@IM<V=I9"`B06QT97)N871E($E-4U`@
M3&]G:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q
M,0IM<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P,PIM<V=I9"`B06QT97)N871E
M($E-4U`@57-E<FYA;64B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z,S4*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S
M(@IM<V=S='(@(N&>E.&?DN&>BN&>O.&>FN*`B^&>HN&>MN&>G^&>F>&>BN&?
MDN&>B^&>MN&>D^*`B^&>HN&?BN&>N.&>F.&?@N&>FR(*"B,Z(&%D;6EN+W1E
M;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM
M<V=S='(@(N&>G^&>MN&>F.&>O.&>HN&>MB#AGJ+AGK;AGICAGX'AGIKAGK?A
MGH`B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.CDU(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L
M('9A;'5E('=A<R!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C`*;7-G:60@(D%N('5N:VYO=VX@97)R
M;W(@:&%S(&]C8W5R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@
M(D%N9&]R<F$B"FUS9W-T<B`BX9ZBX9Z$X9^+X9Z*X9Z\X9Z:X9^)X9ZV(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU.`IM<V=I9"`B06YG;VQA(@IM<V=S='(@(N&>HN&>A.&?B^&>
MH.&?DN&>@N&?A.&>H>&>MB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I;&QA
M(@IM<V=S='(@(N&>HN&>A.&?B^&>H.&?DN&>G^&?BN&>N.&>H>&>MB(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY
M;6]U<R!0<F]X>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3@*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`BX9Z7X9ZVX9Z"XH"+X9Z!
MX9ZVX9Z$XH"+X9Z/X9^2X9Z4X9Z\X9Z$(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B
M06YT:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R("+AGJ+AGH3AGXOAGI'AGKCA
MGJ#AGY+AGH+AGK8@X9Z3X9ZWX9Z$(.&>E.&>MN&>E.&?BN&>N^&>F>&>BN&>
MMB(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN
M<&AP.C,U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3@@=&5M
M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC
M871I;VXB"FUS9W-T<B`BX9Z`X9Z8X9^2X9Z8X9Z<X9ZWX9Z2X9ZX(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,
M:7-T(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#`*
M;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@
M0VAI;&0@4VAA<F5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T,"!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#(*;7-G:60@(D%P<')O
M>&EM871E(%-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P,PHC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(N&>
MF.&?@>&>G^&>MB(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Q"FUS9VED
M(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`BX9ZBX9ZVX9Z:X9^)
MX9ZVX9Z4X9^+("A7:6YD;W=S+3$R-38I(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C8V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z-S@*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-0HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<W"FUS9VED(")!<F-H
M:79E($YA;64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@
M>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S
M="!F;W(@)7,@/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V1E;&5T92YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U
M('-U<F4@>6]U('=I<V@@=&\@9&5L971E(%PB)7-<(B!A;F0@86YY('-U8BUG
M<F]U<',_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%R9V5N=&EN
M82(*;7-G<W1R("+AGJ+AGK;AGJ#AGY+AGI_AGH3AGXOAGI'AGKCAGI,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4W"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(N&>HN&>MN&>F.&?
M@>&>D^&>N"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<R"FUS9VED(")!
M<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S,*;7-G:60@(D%R="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4Y"FUS9VED(")!<G5B82(*;7-G<W1R("+AGJ+AGK;AGIKAGKSAGI3AGK8B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E
M;G-I;VX@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS-`IM<V=I9"`B07-C:6D@07)T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I9FEC
M(%)E9VEO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#(Y"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S$P-@IM<V=I9"`B07-S:6=N;65N="!C;VQU
M;6YS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@
M(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C(Y"FUS9VED(")!
M='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HX-PIM<V=I9"`B
M071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I
M9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C8T(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,PIM<V=I9"`B
M071T<FEB=71E<R(*;7-G<W1R("+AGH+AGKOAGH[AGIOAGH#AGY+AGH'AGH[A
MGX@B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`W"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M,@IM<V=I9"`B075G=7-T(@IM<V=S='(@(N&>G^&>N.&>H.&>MB(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R("+AGJ+AGKSAGI_AGY+A
MGH_AGY+AGIKAGK;AGIOAGK@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<FEA
M(@IM<V=S='(@(N&>HN&>O.&>D>&?DN&>FN&>N.&>GR(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS,38*;7-G:60@(D%U=&A?8WER<W%L
M.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$S,0IM<V=I
M9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D
M(&-A<&%B:6QI=&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+V-Y<G5S+G!H<#HR,S0*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D
M(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]F='`N<&AP.C4V"FUS9VED("(B"B)!=71H7V9T
M<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@
M4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`T"FUS9VED
M(")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H
M<#HW,PIM<V=I9"`B075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z,S`Q"FUS9VED(")!=71H7VQD87`Z($%D9&EN9R!U<V5R
M<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S4V"FUS
M9VED(")!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T
M960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY,@IM<V=I9"`B075T:%]L9&%P.B!2
M97%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S,X"B,L('!H<"UF
M;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S
M+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS.#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HT.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@
M=&\@=7!D871E('5S97(@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HT,#0*;7-G:60@(D%U=&A?;&1A<#H@57!D871I
M;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R
M>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H
M<#HV,@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<VUB+G!H<#HX-@IM<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S
M;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O061M:6XN<&AP.C$P-@IM<V=I9"`B075T:&5N
M=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3`*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R("+AGH#A
MGK;AGIKB@(OAGI7AGY+AGI'AGX#AGH3B@(OAGI7AGY+AGI'AGK;AGH_AGXOB
M@(OAGI?AGK;AGI;B@(OAGH_AGY+AGIKAGKGAGICB@(OAGH_AGY+AGIKAGKSA
MGISB@(OAGI3AGK;AGI/B@(OAGI3AGIKAGK;AGH?AGY#AGIDB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960N("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H
M<#HQ.#(*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E5
M4R!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z.#@R"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R
M(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HW,`IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V
M97(@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M
M87`N:6YC.C<U"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S='(@(N&>HN&>
MMN&>H.&?DN&>G^&?BN&?@N&>FN&>E.&?@N&>H.&?DN&>G^&>A.&?BR(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0IM<V=I9"`B0D]&2"!%>&-U<V5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`B
MX9Z5X9^2X9Z1X9^#XH"+X9Z!X9ZVX9Z$XH"+X9Z`X9^2X9Z:X9^$X9Z9(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM
M<V=I9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R("+AGI;AGH[AGXSB@(OA
MGI7AGY+AGI'AGX/B@(OAGH'AGK;AGH3B@(OAGH#AGY+AGIKAGX3AGIDB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@R"FUS9VED(")"860@
M:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O:W)B-2YP:'`Z.#0*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R
M;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F%H86UA<R(*
M;7-G<W1R("+AGI3AGK;AGJ#AGK;AGICAGXGAGK;AGI\B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q
M"FUS9VED(")"86AR86EN(@IM<V=S='(@(N&>E.&>MN&>FN&?B>&?@N&>DR(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<S"FUS9VED(")"86QT:6,@*$E3
M3RTX.#4Y+3$S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"86YG
M;&%D97-H(@IM<V=S='(@(N&>E.&>A.&?B^&>@.&?DN&>F^&>MN&>BN&?@>&>
MG^&?DN&>H"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@
M(N&>E.&>MN&>FN&>E.&>MN&>BN&>O.&>GR(*"B,Z('5T:6PO:6-O;E]B<F]W
M<V5R+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S
M(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$Y
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*
M;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@
M(D)E;&%R=7,B"FUS9W-T<B`BX9Z4X9^!X9ZAX9ZVX9Z:X9Z[X9Z?X9^2X9Z?
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R("+AGI3AGX+A
MGIOB@(OAGJ#AGY+AGI_AGXKAGK?AGH`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"
M96QI>F4B"FUS9W-T<B`BX9Z4X9^!X9Z;X9ZXX9Z@X9^2X9Z?(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,0IM<V=I9"`B0F5N:6XB"FUS9W-T<B`BX9Z4X9^!X9Z.X9ZVX9^&X9Z$
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R("+AGI3AGXKA
MGX'AGIKAGICAGKSAGHKAGK8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")":'5T86XB
M"FUS9W-T<B`BX9Z4X9^*X9Z\X9Z/X9ZVX9Z3(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD87DB
M"FUS9W-T<B`BX9Z0X9^2X9Z$X9^#X9Z`X9^&X9Z.X9Z^X9Z/(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,U.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S7"(@;V8@87!P;&EC871I;VX@7"(E
M<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]L87EO=70N:6YC.CDP"FUS9VED(")";&]C:R!3971T:6YG<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z-S(*;7-G:60@
M(D)L;V-K(%1Y<&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S='(@(N&>
MBN&>M^&>CR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B
MX9Z4X9Z\X9Z;X9ZXX9Z<X9ZX(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(R,0IM<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@(N&>@.&>D^&?DN&>
MF^&?@N&>A.*`B^&>A>&?AN&>CN&>MN&?AB(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*;7-G:60@(D)O<F1E
M<B(*;7-G<W1R("+AGI_AGXKAGKOAGI@B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN
M97-S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(Q"FUS9VED(")";W)D97)S(@IM<V=S='(@
M(N&>G^&?BN&>N^&>F.*`BR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)O<VYI82!A
M;F0@2&5R>F5G;W9I;F$B"FUS9W-T<B`BX9Z4X9Z\X9Z?X9^2X9Z3X9^*X9ZX
M(.&>D^&>M^&>A"#AGJ#AGKKAGJ#AGY+AGI_AGXKAGX'AGJ#AGY+AGH+AGX3A
MGISAGKCAGH[AGK8B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,3`Q"FUS
M9VED(")";W1H(@IM<V=S='(@(N&>D>&>MN&?AN&>A.*`B^&>EN&>N.&>FN*`
MBR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O='-W86YA(@IM<V=S='(@(N&>E.&>
MN^&>C^&>G^&?DN&>G.&>MN&>CN&>MB(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM
M<V=S='(@(N&>E.&>MN&>CR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O=79E="!)
M<VQA;F0B"FUS9W-T<B`BX9Z`X9^$X9^'XH"+X9Z4X9^*X9Z\X9Z<X9^)X9^"
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(N&>E.&?DN&>
MFN&?@>&>G^&?BN&>N.&>FR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")"<FET:7-H
M($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`BX9ZBX9ZVX9Z.X9ZV
MX9Z%X9Z`X9^2X9Z:XH"+X9Z?X9Z8X9Z[X9Z1X9^2X9Z:XH"+X9ZEX9Z.X9^2
MX9Z,X9ZV(.&>HN&>A.&?B^&>@N&?DN&>F^&?@>&>GR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HT,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*
M;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@(N&>E.&?DN&>FN&?
MBN&>N^&>F>&>CN&?@>*`B^&>BN&>MN&>FN&?BN&>N^&>F>&>G^&>MN&>H>&>
MMN&>F"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@(N&>
ME.&?BN&>N^&>F^&>H.&?DN&>@N&>MN&>FN&>N"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D
M($QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HS-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R:VEN82!&
M87-O(@IM<V=S='(@(N&>E.&?BN&>O.&>FN&>@N&>N.&>CN&>MN&>H.&?DN&>
MG.&>MN&>G^&>O"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,SD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T
M<B`BX9Z4X9^*X9Z\X9Z:X9Z[X9Z3X9Z,X9ZX(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0V,`IM<V=I9"`B0TU3(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-2
M0R(*;7-G<W1R(")#4D,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4Y.`IM<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-38*
M;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M.#,@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-34*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$V-`IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`BX9Z4
MX9^2X9Z:X9Z/X9ZWX9Z1X9ZWX9Z3(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(T,`IM<V=I9"`B0V%L;2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`BX9Z`X9Z8X9^2X9Z6X9Z[
MX9Z'X9ZV(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B
MX9Z`X9ZVX9Z8X9^)X9ZVX9Z:X9Z\X9Z3(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@
M875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,U,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#86X@;F]T('=R:71E('1O(&9I;&4@7"(E
M<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,@IM<V=I
M9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H
M<#HR-#$@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,S,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R
M.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HT-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HU,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V%N861A(@IM
M<V=S='(@(N&>@.&>MN&>CN&>MN&>BN&>MB(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$P,2!A9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O9&5L971E+FEN8SHQ,2!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI
M;F,Z,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,@IM
M<V=I9"`B0V%N8V5L(@IM<V=S='(@(N&>E.&?A.&?A^&>E.&>A.&?BR(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#86YC
M96P@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HS,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T
M(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C0V"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*;7-G:60@(D-A;FYO
M="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HY,0IM<V=I
M9"`B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE
M=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C,Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I<F5C
M=&]R>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A5')E
M92]$871A5')E92YP:'`Z,3(X(&9R86UE=V]R:R]$871A5')E92]$871A5')E
M92]S<6PN<&AP.C8Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M
M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C(R"FUS9VED("(B"B)#
M86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R
M(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S
M<&5C:69I960@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED
M(")#87!E(%9E<F1E(@IM<V=S='(@(N&>@.&>MN&>E.&>G.&?@N&>FB(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C0*;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`BX9Z%X9^&X9Z.X9Z$X9Z'X9Z^
MX9Z$(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP
M:'`Z,3`T"FUS9VED(")#87)R:65R(@IM<V=S='(@(N&>G.&>C^&?DN&>D.&>
MN^*`B^&>BN&>N>&>@.*`B^&>A^&>B>&?DN&>A^&>O.&>DR(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY,PIM<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B
M96QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")#87EM86X@27-L
M86YD<R(*;7-G<W1R("+AGH#AGX3AGX?B@(OAGH#AGX/AGICAGXGAGK;AGI,B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT
M"FUS9VED(")#96QL(%!H;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*;7-G:60@(D-E
M;&P@4')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(W.`IM<V=I9"`B0V5L;'!H;VYE
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<T"FUS9VED
M(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(V"FUS9VED
M(")#96YT97(B"FUS9W-T<B`BX9Z`X9Z.X9^2X9Z/X9ZVX9Z;(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C4Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@
M(N&>G^&>MN&>DN&>MN&>FN&>CN&>FN&>BN&?DN&>B^*`B^&>HN&>MN&>H.&?
MDN&>G.&?DN&>FN&>M^&>@.*`B^&>@.&>CN&?DN&>BN&>MN&>FR(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3<U"FUS9VED(")#96YT<F%L($5U<F]P96%N
M("A)4T\M.#@U.2TR*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8Q,@IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@
M(D-E<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M.`IM<V=I9"`B0VAA9"(*;7-G<W1R("+AGH;AGK;AGHHB"@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.CDV"FUS9VED(")#:&%N9V4B"FUS9W-T<B`BX9Z5X9^2X9Z;X9ZV
MX9Z?X9^+XH"+X9Z4X9^2X9Z/X9Z\X9Z:(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C,Q"FUS9VED(")#:&%N9V4@66]U<B!087-S=V]R9"(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-CD*;7-G:60@
M(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S
M964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS
M+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M,C0*;7-G:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U
M<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#
M;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PIM
M<V=I9"`B0VAA<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,
M:6YK+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6QE(@IM
M<V=S='(@(N&>B.&>N.&>F^&>N"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA
M(@IM<V=S='(@(N&>A>&>M^&>DR(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3<V"FUS9VED(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S<*;7-G:60@(D-H:6YE
M<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]A<'`N:6YC.C<*;7-G:60@(D-H;V]S92!!<'!L:6-A=&EO;CHB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.C(W,0IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W,`IM<V=I9"`B0VAO
M;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,P,@IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL
M92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C4U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R("+AGH#AGX3A
MGX?B@(OAGH+AGY+AGIKAGKCAGI_AGY+AGH_AGICAGXGAGK;AGI\B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,N<&AP.C(Y-"!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z.3$T"B,L('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN:71I
M;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`IM<V=I9"`B0VQE87(B"FUS
M9W-T<B`BX9Z'X9Z8X9^2X9Z:X9^'(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@
M=&%G<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"FUS
M9VED(")#;&5A<B!1=65R>2(*;7-G<W1R("+AGH?AGICAGY+AGIKAGX?B@(OA
MGI_AGX;AGH[AGKWAGIHB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A
M<BYI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@=7-E<CH@
M)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N
M:6YC.C$Q"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T"FUS9VED(")#;&5A<B!U<V5R
M(&1A=&$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,34*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ
M-C`*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM
M<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]K97EB;V%R9"YP:'`Z,30V('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3(*;7-G:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R("+AGI3AGK?AGI'B
M@(OAGI3AGH3AGY+AGJ+AGKWAGH4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(U-@IM<V=I9"`B0VQO=61S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$V"FUS9VED(")#;&]U9',@16%R
M;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3<*;7-G:60@(D-L;W5D>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8T"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R("+A
MGH#AGX3AGX?B@(OAGH#AGKSAGH#AGKP@*.&>@^&>N.&>F^&>N.&>A"DB"@HC
M.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C(T"FUS9VED(")#;VQL
M87!S92!3:61E8F%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E
M9"!B;W)D97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O;&]M
M8FEA(@IM<V=S='(@(N&>@.&>O.&>H>&>N^&?AN&>E.&?BN&>N"(*"B,Z(&QI
M8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(Y"FUS9VED(")#;VQO<B(*;7-G<W1R("+AGI;AGH[AGXPB"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S,P"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,S$*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4P,2!S97)V:6-E<R]I
M;6%G97,O8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K97(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@S.0IM
M<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L
M<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DU
M-`IM<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C@P"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B
M(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(U"FUS9VED(")#;VUM86YD(@IM
M<V=S='(@(N&>EN&>MN&>@.&?DN&>F>*`B^&>E.&>B>&?DN&>A^&>MB(*"B,Z
M(&%D;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,3,*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`BX9Z?X9^!X9Z%X9Z`X9^2X9Z/
MX9ZXXH"+XH"+X9ZBX9Z2X9ZWX9Z4X9^2X9Z4X9ZVX9Z9(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G:60@(D-O;6UO;B!.
M86UE(@IM<V=S='(@(N&>B.&?DN&>F.&?A.&?A^*`B^&>DN&>F.&?DN&>F.&>
MC^&>MB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(N&>
M@.&>N^&?AN&>F.&?B>&>O.&>FN&?B>&>O.&>GR(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@(D-O;7!A;GDB
M"FUS9W-T<B`BX9Z`X9^2X9Z:X9Z[X9Z8X9Z@X9^*X9Z[X9Z3(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS9VED(")#;VUP=71E<G,B"FUS9W-T
M<B`BX9Z`X9Z[X9^&X9Z6X9^2X9Z9X9Z\X9Z1X9^0X9Z:(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,`IM<V=I9"`B0V]N9&ET:6]N(@IM
M<V=S='(@(N&>F^&>@.&?DN&>@>&>@>&>CN&?DN&>C"(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C8Q"FUS9VED(")#;VYD:71I;VYS(@IM<V=S='(@(N&>
MF^&>@.&?DN&>@>&>@>&>CN&?DN&>C"(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N
M<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#8*;7-G:60@(D-O
M;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE
M<R!A;F0@3W5T;&]O:RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$S-0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T
M92XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$P,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O8V]N9FER;2YP:'`Z,S@*;7-G:60@(D-O;F9I<FT@16UA
M:6P@061D<F5S<R(*;7-G<W1R("+AGJ+AGX?AGJ+AGK;AGH3B@(OAGJ+AGK;A
MGI_AGIGAGHKAGY+AGHOAGK;AGI/B@(OAGJ+AGXKAGKCAGICAGX+AGILB"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"FUS9VED(")#
M;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])9&5N
M=&ET>2])9&5N=&ET>2YP:'`Z,S@U"FUS9VED(")#;VYF:7)M(&YE=R!E;6%I
M;"!A9&1R97-S(@IM<V=S='(@(N&>HN&?A^&>HN&>MN&>A.*`B^&>HN&>MN&>
MG^&>F>&>BN&?DN&>B^&>MN&>D^*`B^&>HN&?BN&>N.&>F.&?@N&>F^*`B^&>
MD.&?DN&>F.&>N"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-34@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O(@IM<V=S='(@
M(N&>@.&>N^&>A.&>H.&?DN&>@N&?A"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-O
M;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM
M<V=I9"`B0V]N;F5C=&EO;B!F86EL960N(@IM<V=S='(@(N&>@.&>MN&>FN*`
MB^&>C^&>E^&?DN&>A^&>MN&>E.&?B^*`B^&>E.&>MN&>D^*`B^&>E.&>FN&>
MMN&>A^&?D.&>F>*`B\*@X9^4(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW
M.3`*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME
M>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-SDR"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@
M<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H
M)7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.#<V"FUS9VED(")#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3$P,`IM<V=I
M9"`B0V]N=&%C=',B"FUS9W-T<B`B0V]N=&%C=',B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A8W1S
M('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C8P"FUS9VED(")#;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F
M:6QE.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HU-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C8S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z
M-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,PIM<V=I9"`B0V]N=&EN=64B
M"FUS9W-T<B`BX9Z4X9Z3X9^2X9Z/(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]O
M:R!)<VQA;F1S(@IM<V=S='(@(N&>@.&?A.&?A^*`B^&>@.&>O.&>@"(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B0V]O:VEE(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR,0IM<V=I9"`B0V]P>2(*;7-G<W1R("+AGH7AGICAGY+A
MGIOAGH0B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0W,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM
M<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R
M("+AGH#AGKSAGI_AGY+AGH_AGK;AGIKAGKCAGH#AGK8B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V
M"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.CDW-PIM<V=I9"`B0V]U;&0@;F]T(%!'
M4"!E;F-R>7!T(&UE<W-A9V4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#4U"FUS9VED(")#;W5L9"!N;W0@4$=0
M('-I9VX@;65S<V%G93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,SDS"FUS9VED(")#;W5L9"!N;W0@4R]-24U%
M(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD(&YO="!3+TU)
M344@<VEG;B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$X-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C$R,0IM<V=I9"`B0V]U;&0@;F]T(&)I
M;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HT-3<*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O(&QD87`@
M<V5R=F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0T,0IM<V=I9"`B0V]U;&0@;F]T(&-O
M;FYE8W0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C,R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E
M871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3(X"FUS9VED(")#;W5L9"!N
M;W0@9&5C<GEP="!01U`@9&%T83H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3(S"FUS9VED(")#;W5L9"!N;W0@
M9&5C<GEP="!3+TU)344@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L
M971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HS.#$@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.34S"FUS9VED
M(")#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@
M861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*;7-G:60@(D-O=6QD(&YO="!F971C
M:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"FUS9VED
M(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-#0V"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O
M;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U
M='!U=%-T<F%T96=Y+G!H<#HV.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y
M+V1I<F5C="YP:'`Z,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-S$Y"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U
M8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDO8V]P>2YP:'`Z,3,Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C8R
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N
M<&AP.C0R,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-
M86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HR,S<@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0W
M.`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-CDY"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@
M<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE
M8W0N<&AP.C(T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A
M9"`E<RXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z.#4*;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@
M9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*
M(F1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C
M="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H
M96QP+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS,#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S0P"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,W-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS.#,*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S@Y"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V
M92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q
M.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*
M;7-G:60@(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I
M97,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`IM
M<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C4Y"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF
M:6=U871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HV,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A
M8VMU<"!C;VYF:6=U871I;VXZ("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF
M:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@
M;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E
M:71H97(@=7-E(&]N92!O9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E('1H92!C
M;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO
M=R!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HQ-#,*;7-G:60@(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@
M<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U
M<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T
M:6]N(&9O<B!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-S`*;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL
M;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C$U-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E
M('5S97(@7"(E<UPB('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L
M9&5R(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,30R-PIM<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED
M(")#;W5N=')Y(@IM<V=S='(@(N&>E.&?DN&>FN&>D>&?@>&>GR(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#D*;7-G:60@(D-O=7)S97,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS9W-T<B`BX9Z4
MX9Z$X9^2X9Z`X9Z^X9Z/(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED(")#<F5A=&4@82!L:6YK
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C
M="YI;F,Z.30*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G
M:60@(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(T,`IM<V=I9"`B0W)E871O<B!097)M
M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,C(S"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-SD*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`BX9Z`X9^2X9Z:
MX9Z\X9ZBX9ZVX9Z/(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B82(*;7-G<W1R
M("+AGH+AGKOAGIGAGI3AGK8B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*
M;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5S<VEO;G,N<&AP.C4P"FUS9VED(")#=7)R96YT(%-E<W-I;VYS(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE
M+G!H<#HS-0IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(N&>EN&?@>&>
MF^*`B^&>G.&?@>&>F^&>MN*`B^&>E.&>A>&?DN&>A>&>N^&>E.&?DN&>E.&>
MD^&?DN&>DR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,U"FUS9VED(")#=7)R96YT
M(%5S97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`*
M;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8Y"FUS9VED(")#=7)R96YT(&-O;F1I
M=&EO;CH@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T
M<B`BX9Z:X9Z%X9Z3X9ZVX9Z4X9^0X9Z1X9^2X9Z8XH"+X9Z4X9Z%X9^2X9Z%
MX9Z[X9Z4X9^2X9Z4X9Z3X9^2X9Z3XH"+(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Q,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S
M:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(N&>E.&?DN&>
MC^&>O.&>FN*`B^&>E^&>MN&>FN&>@.&>M^&>A>&?DN&>A>*`B^&>BN&?@N&>
MF^*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>FN&>C^&?B^*`B^&>C^&>MN&>F.*`
MB^&>E.&?AN&>CN&>A"#AGJ+AGK;AGI_AGY+AGIKAGY#AGIGB@(OAGIOAGK[B
M@(OAGH#AGK;AGIKB@(OAGH7AGKSAGIOB@(OAGI'AGX7B@(L@)7,@X9^4(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`BX9Z`X9ZVX9Z/X9^+(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I
M9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED
M(")#>7!R=7,B"FUS9W-T<B`BX9Z?X9^*X9ZXX9Z6X9Z:X9^-(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I
M(@IM<V=S='(@(N&>G^&?BN&>N.&>FN&>N.&>F^&>N.&>@"`H2T])."U2*2(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")#>7)I;&QI8R`H
M5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R("+B@(OB@(OAGI_AGXKAGKCAGIKAGKCA
MGIOAGKCAGH`@*%=I;F1O=W,M,3(U,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X,`IM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM
M<V=S='(@(N&>G^&>MN&>DN&>MN&>FN&>CN*`B^&>FN&>BN&?DN&>B^*`B^&>
MAN&?@>&>@"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-3`@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM
M<V=S='(@(D1$(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,PIM
M<V=I9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO
M96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP
M.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R("+AGIKAGK;AGIOAGXOB@(OAGI#A
MGY+AGH3AGX,B"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A
M=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S(X,0IM<V=I9"`B1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0P-@IM<V=I9"`B1&%T92(*
M;7-G<W1R("+AGH#AGK;AGIOB@(OB@(OAGI3AGIKAGK?AGH7AGX'AGY+AGH;A
MGI$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM
M<V=I9"`B1&%T92!296-E:79E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.#`P"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@U(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,30*;7-G:60@(D1A>2(*;7-G
M<W1R("+AGI#AGY+AGH3AGX,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L
M=6UN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,3$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C<V"FUS9VED(")$96-E;6)E<B(*;7-G<W1R("+AGI+AGY+A
MGI/AGKPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C$V"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S='(@(N&>E.&>D^&?
MDN&>D.&>F2#AGH7AGKSAGIOB@(OAGI3AGI/AGY+AGI'AGK;AGH_AGXLB"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$X-R!L:6(O<')E9G,N
M<&AP.C$Q-PIM<V=I9"`B1&5F875L="(*;7-G<W1R("+AGIOAGX;AGI/AGK;A
MGX;AGHKAGK[AGI@B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHT-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHW-PIM<V=I9"`B1&5F875L="!#;VQO<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.CDV"FUS9VED
M(")$969A=6QT($ED96YT:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HV-PIM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*;7-G:60@(D1E9FEN:71I
M;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C8*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HT,C(@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT
M,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C<P"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z.3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ.#(*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY.`HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*;7-G<W1R("+AGIOAGKOAGI3B
M@(LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S(*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z,3DY(&%D;6EN+V=R;W5P<RYP:'`Z,C(W"FUS
M9VED(")$96QE=&4@1W)O=7`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,C0Y"FUS9VED(")$96QE=&4@3&]G(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S<@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#$*;7-G:60@(D1E;&5T92!097)M
M:7-S:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A
M9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3<*;7-G:60@(D1E;&5T92!C96QL(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`BX9Z;
MX9Z[X9Z4XH"+X9Z'X9Z]X9Z:XH"+X9Z(X9Z:(@H*(SH@861M:6XO=&5M<&QA
M=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@
M=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI
M<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L
M971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES
M<VEO;G,_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!R;W<B"FUS
M9W-T<B`BX9Z;X9Z[X9Z4XH"+X9Z'X9Z]X9Z:X9Z*X9^!X9Z`(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V1E;&5T96ED96YT:71Y+FEN8SHQ-0IM<V=I9"`B1&5L
M971E('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I
M9"`B1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C,*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-38S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3DU"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(R,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*;7-G:60@(D1E;&EV97)Y('1I;64B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R
M("+AGHKAGK;AGH[AGKKAGICAGXGAGK;AGH`B"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L
M96TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.30R
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S`*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(N&>@.&>MN&>FN&>EN&>
MM^&>EN&>CN&?C.&>D^&>MB(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,3DW"FUS9VED(")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL
M92DZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,C`Q"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C,U"FUS9VED(")$979E;&]P;65N="(*;7-G<W1R("+B@(OA
MGJ+AGI?AGK?AGISAGHSAGY+AGHTB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(R.0IM<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S`V"FUS9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U
M<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,C$*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I
M<F5C=&EO;B!L969T('1O(')I9VAT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C
M=&EO;B!R:6=H="!T;R!L969T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T<B`BX9Z0X9Z/
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W,`IM<V=I9"`B1&ES<&QA
M>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3`P"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.CDT"FUS9VED(")$
M:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z.3<*;7-G:60@(D1I<W!L87D@9F]R96-A<W0@*%1!
M1BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q
M,`IM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-1$XN<&AP.C$Y,`IM<V=I9"`B1&ES<&]S:71I;VX@
M3F]T:69I8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J
M:6)O=71I(@IM<V=S='(@(N&>H.&?DN&>G^&?BN&>N.&>E.&>O.&>D>&>N"(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R"FUS9VED(")$
M;R!N;W0@9&5L971E(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN
M=&5N86YC92YP:'`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V
M:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G
M:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE
M<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`BX9Z*X9Z\X9Z8X9ZXX9Z3
MX9ZXX9Z`X9ZV(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B
M;&EC(@IM<V=S='(@(N&>G^&>MN&>DN&>MN&>FN&>CN&>FN&>BN&?DN&>B^*`
MB^&>BN&>O.&>F.&>N.&>D^&>N.&>@.&?@N&>DR(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z.#@*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N
M=#\@4VEG;B!U<"XB"FUS9W-T<B`BX9Z8X9ZWX9Z3XH"+X9Z8X9ZVX9Z3XH"+
MX9Z"X9Z.X9Z3X9ZXPJ`_(.&>G^&>O.&>F.*`B^&>A>&>N^&?A^&>B.&?DN&>
MF.&?A.&?A\*@X9^4(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.#4X"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R("+AGI'AGK;AGHGA
MGIGAGH`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX
M-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO
M860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q-0IM<V=I
M9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,Y"FUS9VED(")$<G5G<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#,*;7-G:60@(D1Y;F%M:6,@36%I;"(*
M;7-G<W1R("+AGI_AGX;AGI3AGKOAGH_AGY+AGIKB@(OAGI#AGK;AGICAGISA
MGI/AGY+AGH\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,3,*;7-G:60@(D4M36%I;"(*;7-G<W1R("+AGJ+AGXKAGKCAGICAGX+AGILB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY
M,@IM<V=I9"`B14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R
M<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+VUO8FEL92YP:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<P"FUS9VED(")%8W5A9&]R(@IM<V=S='(@(N&>HN&?@>&>@.&?DN&>
MG.&>MN&>C.&?D.&>FB(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,S(U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@IM<V=I
M9"`B161I="(*;7-G<W1R("+AGH#AGX+B@(OAGI_AGICAGY+AGIKAGKWAGILB
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4P"FUS9VED(")%
M9&ET($)L;V-K(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DX
M(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"FUS9VED(")%9&ET($=R;W5P(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S8@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#`*;7-G:60@(D5D:70@4&5R
M;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP
M:'`Z,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS
M(&9O<CHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N
M<R!F;W(@7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S
M:6]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0P"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`BX9Z`X9ZVX9Z:XH"+
MX9ZBX9Z4X9^+X9Z:X9^&(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16=Y<'0B"FUS
M9W-T<B`BX9ZBX9^!X9Z@X9^2X9Z?X9^*X9ZXX9Z4(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W
M"FUS9VED(")%;"!386QV861O<B(*;7-G<W1R("+AGJ+AGX+AGIOAGI_AGK;A
MGIOAGXOAGISAGXGAGK;AGHSAGY#AGIHB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L96UE
M;G0N+BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-PIM<V=I9"`B16UA:6PB"FUS9W-T<B`B
MX9ZBX9^*X9ZXX9Z8X9^"X9Z;(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-C8@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN
M8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"FUS
M9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(N&>HN&>MN&>G^&>F>&>BN&?
MDN&>B^&>MN&>D^*`B^&>HN&?BN&>N.&>F.&?@N&>FR(*"B,Z('-E<G9I8V5S
M+V-O;F9I<FTN<&AP.C,P"FUS9VED(")%;6%I;"!A9&1R97-S97,@:&%V92!B
M965N(&QO8VME9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3DW,0IM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N
M(@IM<V=S='(@(N&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>D^*`B^&>HN&?
MBN&>N.&>F.&?@N&>F^*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>C^&?@N*`B^&>
MBN&>O.&>A>&>@N&?DN&>D^&>ML*@X9^4(@H*(SH@<V5R=FEC97,O8V]N9FER
M;2YP:'`Z,C,*;7-G:60@(D5M86EL(&%D9')E<W-E<R!T;R!C;VYF:7)M(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3DY-PIM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP
M:'`Z.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E=V%Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR.3<*
M;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R("+AGI_AGHGAGY+AGHGAGK;B@(OA
MGJ+AGK;AGIKAGICAGY+AGICAGH[AGXTB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*;7-G:60@(D5M<'1Y(&UE
M<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HR-#,@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0X
M-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C8R(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW,#4*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HQ-3`*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$Q
M,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#<*;7-G:60@(D5N86)L92!I;G-E<G1I
M;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C(*;7-G:60@
M(D5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.38@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@P-`IM<V=I9"`B16YD('EE87(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM
M<V=I9"`B16YL87)G92!%9&ET;W(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(R-`IM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q
M=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T
M;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N
M86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I
M9"`B16YT97(@=&AE(&EM86=E(%523"!H97)E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX.3`*;7-G:60@
M(D5N=&5R('1H92!L971T97)S(&)E;&]W.B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<V"FUS9VED(")%<75A=&]R:6%L($=U:6YE82(*;7-G<W1R("+AGJ#AGY+A
MGH+AGKCAGH[AGX'B@(OAGJ+AGX'AGH#AGY+AGISAGK;AGI'AGY#AGIHB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<Q"FUS9VED(")%<FET<F5A(@IM<V=S='(@(N&>HN&?@>&>FN&>
MN.&>D>&?DN&>FN&>MB(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="]6:65W+G!H<#HY-"!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-3,*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HT,0IM
M<V=I9"`B17)R;W(B"FUS9W-T<B`BX9Z`X9^&X9Z@X9Z[X9Z?(@H*(SH@9G)A
M;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B17)R;W(@8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C<R"B,L('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H
M<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT
M96YT.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=7!D871I;F<@
M<&%S<W=O<F0Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET
M:"!E;6%I;"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%<W1O;FEA(@IM
M<V=S='(@(N&>HN&?@>&>G^&?DN&>C^&>O.&>D^&>N"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*
M;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(N&>HN&?@>&>C^&?DN&>F>&>O.&>
MEN&>N"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B171H
M;FEC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(N&>HN&>NN&>FN&?B>&>N^&>
ME"(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,#$@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,T,PIM<V=I9"`B179E<GD@,34@;6EN=71E<R(*
M;7-G<W1R("+AGIKAGX#AGH3B@(OAGIKAGK;AGIOAGXOB@(L@X9^AX9^E(.&>
MD^&>MN&>D>&>N"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3,*;7-G
M:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<&]R=&%L+VQA>6]U="YI;F,Z.3@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T
M,`HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")%=F5R>2`S
M,"!S96-O;F1S(@IM<V=S='(@(N&>FN&?@.&>A.*`B^&>FN&>MN&>F^&?B^*`
MBR#AGZ/AGZ`@X9Z<X9ZWX9Z3X9ZVX9Z1X9ZX(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]L87EO=70N:6YC.C$P,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0R
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.30*;7-G:60@(D5V97)Y(#4@
M;6EN=71E<R(*;7-G<W1R("+AGIKAGX#AGH3B@(OAGIKAGK;AGIOAGXL@X9^E
M(.&>D^&>MN&>D>&>N"(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN
M=&5N86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,#(@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,T-`IM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S
M='(@(N&>FN&?@.&>A.*`B^&>FN&>MN&>F^&?B^*`B^&>@.&>D^&?DN&>F^&?
MA^*`B^&>F.&?B>&?A.&>A"(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T
M+FEN8SHQ,#,*;7-G:60@(D5V97)Y(&AO=7(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDY(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-#$*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,@IM<V=I9"`B
M179E<GD@;6EN=71E(@IM<V=S='(@(N&>FN&?@.&>A.*`B^&>FN&>MN&>F^&?
MB^&>D^&>MN&>D>&>N"(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC
M.C(T"FUS9VED(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<&AP<VAE;&PN<&AP.C@Q(&%D;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,3(W"FUS9VED(")%>&5C=71E(@IM<V=S='(@(N&>
ME.&?DN&>FN&>C^&>M^&>E.&>C^&?DN&>C^&>MR(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-#8V"FUS9VED(")%>'!A
M;F0B"FUS9W-T<B`BX9Z4X9Z3X9^2X9Z;X9ZVX9Z9(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]S:61E8F%R+FEN8SHS,0IM<V=I9"`B17AP86YD(%-I9&5B87(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP
M.C$V.`IM<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-S4*;7-G:60@(D5X<&5C=&5D
M(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")%
M>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV-S<*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@
M(N&>HN&?BN&>M^&>A>&>G^&?DN&>E.&>O.&>CN&>A.&?B^&>G^&?@N&>FR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-S<*;7-G:60@(D944"!U<&QO860@;V8@<V5T=7`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-Q;"YP:'`Z
M,C0U"FUS9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<U
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z.3@*;7-G:60@(D9A:6QE
M9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z,3`Q"FUS9VED(")&86EL960@
M=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C<Q-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,C(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@Y"FUS9VED(")&86EL
M960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3`Q(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z-S4U"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE
M9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HT-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I
M;&5D('1O(')E=')I979E.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-
M86QV:6YA<RDB"FUS9W-T<B`BX9Z`X9^$X9^'XH"+X9Z@X9^2X9Z<X9^)X9Z`
MX9ZAX9Z$X9^+("CAGICAGXGAGK;AGIOAGXOAGISAGKCAGH[AGK8I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R("+AGH#AGX3A
MGX?AGJ#AGY+AGISAGK;AGJ+AGX'AGIKAGKPB"@HC.B!F<F%M97=O<FLO0TQ)
M+T-,22YP:'`Z,C,X"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM
M<V=I9"`B1F%X(@IM<V=S='(@(N&>D>&>O.&>FN&>G^&>MN&>FB(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-C4*;7-G:60@(D9A>&5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0S.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8V"FUS9VED(")&96)R=6%R>2(*;7-G<W1R("+AGH#AGKOAGICAGY+AGI?A
MGX@B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(S,@IM<V=I9"`B1F5E;',@
M3&EK92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C(U"FUS9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E
M=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(P"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-3(*;7-G
M:60@(D9I96QD(&UA=')I>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,S,V"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S0P"FUS9VED(")&
M:6=L970@9F]N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&:6II
M(@IM<V=S='(@(N&>H.&?DN&>G.&>N.&>H.&?DN&>G^&?BN&>N"(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B1FEL92(*;7-G
M<W1R("+AGJ_AGH#AGI_AGK;AGIHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F
M:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C,*;7-G
M:60@(D9I;&4@36%N86=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C8S(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HX,@IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(N&>B.&?
MDN&>F.&?A.&?A^*`B^&>K^&>@.&>G^&>MN&>FB(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Y.#@*;7-G:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T.30*;7-G:60@
M(D9I;&4@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R
M+T)R;W=S97(N<&AP.C@X-0IM<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P
M;W)T960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HY.`IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R("+AGH_AGICAGY+AGIKAGH0B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<Q"FUS9VED(")&:6YL86YD(@IM<V=S='(@(N&>H.&?DN&>
MG.&>MN&?AN&>A.&>H>&>A.&?BR(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ
M-C8*;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER
M<W0@475A<G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C4U"FUS9VED(")&:7@@<F%T:6\B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(S,`IM<V=I9"`B1FQI<"(*;7-G<W1R("+AGH_AGY+AGIKAGJ'AGI3AGXLB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R("+AGI'AGI_AGI?AGK;AGH(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM
M<V=I9"`B1F]G(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z,C8P(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,#<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`BX9Z6X9Z.X9^,
MXH"+X9Z6X9Z[X9Z8X9^2X9Z6XH"+X9ZBX9Z`X9^2X9Z?X9Z:(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED(")&;V]D(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P
M<&]R="!I;6%G97,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS-#8*;7-G:60@(D9O<F5C87-T("A4048I(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW-PIM<V=I9"`B(@HB1F]R96-A
M<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U
M<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G92!N=6UB97(@:&5R
M92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDT"FUS9VED(")&;W)G;W0@
M>6]U<B!P87-S=V]R9#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0W.`IM<V=I9"`B1F]R;7,B"FUS9W-T<B`BX9Z?X9^&X9Z.
MX9Z[X9^&XH"+XH"+X9Z4X9^"X9Z4X9Z4X9Z1(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C(V"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HQ,#0*;7-G:60@(D9O<G1U;F4@='EP92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@
M(D9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT-`IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#8Y"FUS9VED(")&;W)U;7,B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q.`IM<V=I9"`B1F]R
M=V%R9',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PIM
M<V=I9"`B1G)A;65S(@IM<V=S='(@(N&>G^&?BN&>N^&>F"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S,*;7-G:60@(D9R86YC92(*;7-G<W1R("+AGI3AGK;AGIKAGK;AGX;AGH0B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R
M86YC92P@365T<F]P;VQI=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G
M:60@(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`BX9Z@X9^2X9Z"X9Z\X9ZBX9^*
MX9ZXX9Z9X9^)X9ZVX9Z.X9ZV(.&>E.&>MN&>FN&>MN&?AN&>A"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDX"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(N&>E.&?
MB>&>O.&>F^&>N.&>D^&?@>&>G^&?BN&>N.*`B^&>E.&>MN&>FN&>MN&?AN&>
MA"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I
M=&]R:65S(@IM<V=S='(@(N&>HN&>MN&>CN&>A>&>@.&?DN&>FN*`B^&>@>&>
MMN&>A.*`B^&>C^&?DN&>E.&>O.&>A"#AGI3AGK;AGIKAGK;AGX;AGH0B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS
M9VED(")&<F]M(@IM<V=S='(@(N&>EN&>N"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-#(@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,U,@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDX"FUS9VED
M(")&<F]M('1H92`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z-#@*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHV,`IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(N&>B.&?DN&>
MF.&?A.&?A^*`B^&>EN&?@>&>B2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D=A8F]N
M(@IM<V=S='(@(N&>H.&?DN&>@N&>MN&>E.&>N^&>A"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM
M<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<U"FUS9VED(")'86UB:6$B"FUS9W-T<B`BX9Z@X9^2X9Z`X9ZVX9^&X9Z4
MX9^*X9ZX(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX
M"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T
M"FUS9VED(")'96]R9VEA(@IM<V=S='(@(N&>H.&?DN&>G^&>@.&>H.&?DN&>
MG^&?BN&>N"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-CD@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B
MX9ZBX9ZVX9Z;X9^2X9Z;X9ZZX9Z8X9^)X9Z$X9^+(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.CDQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM
M<V=I9"`B1VAA;F$B"FUS9W-T<B`BX9Z@X9^2X9Z`X9ZVX9Z.X9ZV(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-0IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(N&>H.&?DN&>@N&>
MN.&>E.&?DN&>FN&>MN&>F^&?B^&>C^&>MB(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3<V"FUS9VED(")':79E;B!.86UE(@IM<V=S
M='(@(N&>D^&>MN&>F.&>@>&?DN&>F^&>O>&>DR(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S:61E8F%R+G!H<#HQ-S4@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z
M,3`*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3D*;7-G:60@(D=L;V)A
M;"!/<'1I;VYS(@IM<V=S='(@(N&>A^&>F.&?DN&>FN&>ON&>G^*`B^&>G^&>
M@.&>FR(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$W"FUS9VED(")'
M;R(*;7-G<W1R("+AGI'AGX4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#4*;7-G:60@(D=O961E;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$R.0IM<V=I9"`B1V]O9VQE($UA
M<',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM
M<V=I9"`B1V]O9VQE(%-E87)C:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,V"FUS9VED(")'<F%Y<V-A
M;&4B"FUS9W-T<B`BX9Z8X9ZVX9Z/X9^2X9Z:X9Z*X9^2X9Z+X9ZVX9Z3XH"+
MX9Z4X9^2X9Z:X9Z5X9^!X9^'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965C
M92(*;7-G<W1R("+AGH#AGY+AGIKAGK?AGH`B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X,0IM<V=I9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@
M(N&>@.&?DN&>FN&>M^&>@"`H25-/+3@X-3DM-RDB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS
M9VED(")'<F5E;FQA;F0B"FUS9W-T<B`BX9Z"X9^2X9Z:X9ZXX9ZAX9Z$X9^+
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-`IM<V=I9"`B1W)E;F%D82(*;7-G<W1R("+AGJ#AGY+A
MGH+AGY+AGIKAGKCAGH[AGK;AGHKAGK8B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C$W.0IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+G!H<#HU.2!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N86UE<R!M=7-T
M(&)E(&YO;BUE;7!T>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z,S`W"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P
M7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,3$X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HQ,C0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@
M=&\@9&5L971E(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C,W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P
M.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S$T(&QI8B]";&]C:R]G;V]G
M;&4N<&AP.C,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<W"FUS
M9VED(")'<F]U<',B"FUS9W-T<B`BX9Z`X9^2X9Z:X9Z[X9Z8(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-@IM<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R("+AGJ#AGY+AGH+AGKSA
MGJ+AGK;AGHKAGKKAGIOAGKSAGI3AGXGAGX$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.CDW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I
M9"`B1W5A;2(*;7-G<W1R("+AGJ#AGY+AGH+AGK;AGX;AGI@B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@(N&>H.&?DN&>@N&>MN&>
MC^&?@>&>F.&?B>&>MN&>H>&>MB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.3(*;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,C(V('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z.#@*;7-G:60@(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#8*;7-G:60@(D=U
M97-T8F]O:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'=6EN96$B
M"FUS9W-T<B`BX9Z@X9^2X9Z"X9ZXX9Z.X9^!(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS
M9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(N&>H.&?DN&>@N&>N.&>CN&?
M@>&>E.&?BN&>N.&>G^&?A2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA
M(@IM<V=S='(@(N&>H.&?DN&>@N&>N.&>F>&?B>&>MN&>CN&>MB(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDV-`IM<V=I9"`B2%1-3"(*;7-G<W1R
M(")(5$U,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E
M<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L
M971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@
M=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VAT='`N<&AP.C$U-`IM<V=I9"`B2%144"!!=71H96YT
M:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM
M<V=I9"`B2&%I=&DB"FUS9W-T<B`BX9Z@X9^#X9Z1X9ZX(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")(87-H+4%L9V]R
M:71H;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR,@IM<V=I9"`B2&%Z92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HY,C,@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,CDR-0IM<V=I9"`B2&5A9&5R(@IM<V=S='(@(N&>E.&>B^&>F.&>@.&>
MD.&>MN*`BR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E
M="YP:'`Z-C$*;7-G:60@(DAE861E<G,B"FUS9W-T<B`BX9Z4X9Z+X9Z8X9Z`
MX9Z0X9ZV(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@86YD
M($UC1&]N86QD($ES;&%N9',B"FUS9W-T<B`BX9Z`X9^$X9^'XH"+X9Z@X9^*
MX9Z^X9Z*(.&>D^&>M^&>A"#AGH#AGX3AGX?B@(OAGICAGXGAGK;AGH#AGHKA
MGKSAGH[AGK;AGIOAGXLB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR,PIM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,@IM<V=I9"`B2&5B<F5W("A)
M4T\M.#@U.2TX+4DI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*
M;7-G<W1R("+AGH#AGICAGY+AGI;AGI_AGXLB"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O2&5L<"YP:'`Z,3@Q(&9R86UE=V]R:R](;W)D92](;W)D92](
M96QP+G!H<#HQ.#(*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@=&5M
M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C0*;7-G:60@(DAE;'`B"FUS9W-T<B`B
MX9Z'X9^&X9Z3X9Z]X9Z9(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W.0IM<V=I
M9"`B2&5L<&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR
M.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHQ,`IM<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE
M.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HW,`IM<V=I9"`B2&EG:"(*;7-G<W1R("+AGH'AGY+AGI;AGI_A
MGXLB"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S
M+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C4*;7-G:60@(DAO7VUE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6871I8V%N
M($-I='D@4W1A=&4I(@IM<V=S='(@(N&>H.&>O.&>F^&>N.&>G^&?BN&>N"`H
MX9Z:X9Z*X9^2X9Z+XH"+X9Z`X9^2X9Z:X9Z[X9Z$XH"+X9Z<X9^)X9ZVX9Z1
MX9ZXX9Z`X9Z$X9^+*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,34U-0IM<V=I9"`B2&]M92(*;7-G<W1R("+AGH+AGX'AGJ#AGI'AGX;AGI;A
MGY#AGIHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3(R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ-34*;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R("+AGJ+AGK;AGI_A
MGIGAGHKAGY+AGHOAGK;AGI/B@(OAGI7AGY+AGI'AGX<B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-C0*;7-G:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S
M='(@(N&>D.&>C^&>E>&?DN&>D>&?AR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS
M9W-T<B`BX9Z1X9Z\X9Z:X9Z?X9^0X9Z6X9^2X9Z1XH"+X9Z5X9^2X9Z1X9^'
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R("+AGJ#A
MGKOAGH3AGHSAGKSAGIKAGXGAGK;AGI_AGXLB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G
M:60@(DAO;F<@2V]N9R(*;7-G<W1R("+AGJ#AGKOAGH3AGH#AGKOAGH0B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C<*;7-G:60@(DAO<F1E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#0R"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-
M3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR.3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@
M=&\@;V)J96-T("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z-#,U"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(T-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY
M(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN
M=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X
M=&5N<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C4P,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA
M8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-#,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO
M=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C0W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T
M(&]F('1Y<&4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HQ,3DR"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$S,S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O
M;FES92!S:&%R97,Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(T"FUS9VED(")(
M;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM<V=I9"`B2&]R:7IO;G1A;"!P
M861D:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A
M<V4@<F5P;W)T(2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@
M8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M
M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,V"FUS9VED(")(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE
M<F=E/R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,CDS(&QI8B]";&]C:R]M971A<BYP:'`Z,C0R"FUS9VED(")(=6UI9&ET
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C4S"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R("+AGJ#AGKOA
MGH3AGH+AGY+AGIKAGK@B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S
M+G!H<#HQ-S`@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(S-`HC
M+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I
M;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G5S+G!H<#HR,30@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y
M-@HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@
M9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G5S+G!H<#HQ-S<@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP
M.C(T,0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@
M8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,S(P"FUS9VED("))4"!!9&1R97-S(@IM<V=S='(@
M(N&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>D^*`BR!)4"(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D9')E
M<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@061D<F5S<R!N;W0@
M=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS
M9VED("))4"!L;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*;7-G<W1R("+AGJ+AGXKAGKCAGI_A
MGY+AGIOAGH3AGXLB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@P"FUS
M9VED("))8V]N<R!/;FQY(@IM<V=S='(@(N&>C^&?@N*`B^&>FN&>O.&>E.&>
MC^&?AN&>CN&>MN&>A"(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,0IM<V=I9"`B26-O;G,@=VET
M:"!T97AT(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M.3,*;7-G:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DU"B,L('!H<"UF;W)M
M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E
M<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U.0IM<V=I9"`B(@HB268@>6]U(&1O
M;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO
M=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!0
M3D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3<R"FUS9VED("(B"B))9B!Y;W4@
M<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@
M=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA>65D(&)Y('EO=7(@
M8G)O=W-E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(X"FUS9VED("));6%G92!0
M<F5V:65W.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,W"FUS9VED("));6%G92!54DPB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8Y"FUS
M9VED("));6%G92!U<&QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R("+AGIKAGKSAGI3A
MGI?AGK;AGI8B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW('1E
M;7!L871E<R]D871A+V1A=&5M87`N:6YC.C<*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHU-"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW"B,L
M('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P:'`M9F]R
M;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T960@
M9FEE;&1S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W
M($%F=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]Z:7`N<&AP.C$S-`IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E
M(&=I=F5N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S,@IM<V=I9"`B26YC;W)R96-T('5S97)N
M86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R
M;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A
M8W0@>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@
M:&5L<"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S
M='(@(N&>E.&>A.&?DN&>@.&>ON&>D^*`B^&>@.&>MN&>FN*`B^&>A>&>O.&>
MF^*`B^&>E.&>D^&?DN&>D>&>MN&>C^&?BR(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I
M9"`B26YD:6$B"FUS9W-T<B`BX9ZEX9Z.X9^2X9Z,X9ZV(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@P"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`BX9ZE
MX9Z.X9^2X9Z,X9Z\X9Z3X9^!X9Z?X9^*X9ZX(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B26YF;R(*;7-G
M<W1R("+AGI;AGY#AGH_AGXSAGICAGK;AGI,B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C<S"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R("+A
MGI;AGY#AGH_AGXSAGICAGK;AGI,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S(R"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A
M:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@(DEN<V5R="!#7V]L
M=6UN($%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B26YS97)T
M($EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R
M("+AGI3AGHGAGY+AGH7AGKSAGIOB@(OAGH_AGK;AGIKAGK;AGH0B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED
M("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED("))
M;G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED
M("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@
M8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G
M:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!B969O
M<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM<V=I9"`B
M26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F
M;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA
M=&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T,@IM
M<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A
M;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*
M;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G
M:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED
M("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@
M(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED("));G-E<G0@
M;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("));G-E<G0@<&%R
M86=R87!H(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T
M('!A<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I9"`B26YS
M97)T(')O=R!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED("));G-E<G0@
M<F]W(&)E9F]R92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C,S"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T
M:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN<V5R
M="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF
M>2!,:6YK(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U9F9I8VEE;G0@8W)E
M9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`W.0IM<V=I9"`B26YT
M96=E<B(*;7-G<W1R("+AGH7AGX;AGI/AGKWAGI/B@(OAGH+AGH_AGXLB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3,W"FUS9VED("));G1E9V5R
M(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("));G9A;&ED(%5$2"X@*%5S
M97(@1&%T82!(96%D97(I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ-C<*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+WII<"YP:'`Z,3DT"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]Z:7`N<&AP.C(Q,@IM<V=I9"`B26YV86QI9"!:25`@9&%T
M82(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T"FUS
M9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G
M:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(P.34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C$V-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0P(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(S,#<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4
M>7!E+W1A8FQE<V5T+G!H<#HS-PIM<V=I9"`B26YV86QI9"!D871A('-U8FUI
M='1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED("));G9A;&ED(&1E<W1I;F%T
M:6]N(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]D8G@N<&AP.C$P.0HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O9&)X+G!H<#HQ,SD*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+V1B>"YP:'`Z,C0Q"FUS9VED("));G9A;&ED(&9I;&4@9F]R;6%T
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-S`*;7-G:60@(DEN=F%L:60@;&EC96YS92!K97DN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C0*;7-G:60@(DEN=F%L
M:60@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-PIM<V=I9"`B
M26YV86QI9"!M<V=?='EP92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S"FUS9VED("));G9A
M;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.38*;7-G:60@
M(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z,C<*;7-G:60@(DEN=F%L:60@
M<&%R96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-C8*;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I
M9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$V.`IM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O9&4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY,PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C<Q(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z.#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$P-S4@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HQ,C4X"FUS9VED("));G9A;&ED('-H87)E(&]B
M:F5C="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D
M9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q,0IM<V=I9"`B26YV86QI9"!U;FEC;V1E
M(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS-S,*;7-G:60@(DEN=F5N=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<V"FUS9VED("));G9E
M<G0@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B
M27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#$*;7-G:60@(DER87$B"FUS9W-T<B`BX9ZBX9^*X9ZXX9Z:X9^)X9ZV
MX9Z`X9^+(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<F5L86YD(@IM<V=S='(@
M(N&>HN&?@.&>FN&>H>&>A.&?BR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B
M27-O;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS
M9VED("))<W)A96PB"FUS9W-T<B`BX9ZBX9^*X9ZXX9Z?X9^2X9Z:X9ZVX9ZB
MX9^"X9Z;(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M,C8*;7-G:60@(DES<W5E<B(*;7-G<W1R("+AGJ+AGY+AGI/AGH#B@(OAGH7A
MGX'AGHDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CD*;7-G:60@(DET86QI8R(*;7-G<W1R("+AGI'AGY+AGIKAGX'AGH\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#(*;7-G:60@(DET86QY(@IM<V=S='(@(N&>HN&?BN&>
MN.&>C^&>MN&>F^&>N"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*
M;7-G<W1R("+AGH7AGK;AGICAGXGAGX/AGH#AGK8B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`P"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,S@*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*
M;7-G<W1R("+AGICAGH#AGIKAGK8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIA
M<&%N(@IM<V=S='(@(N&>A^&>E.&?B>&>N^&>DR(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@S"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM
M<V=S='(@(N*`B^&>A^&>E.&?B>&>N^&>DR`H25-/+3(P,C(M2E`I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R
M("+AGJ#AGY+AGI_AGXKAGH#AGHKAGK;AGI/AGK@B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G
M<W1R("+AGH#AGH#AGY+AGH#AGHKAGK8B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R("+A
MGICAGK?AGI#AGKOAGI/AGK8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S
M='(@(N&>C^&>F.&?DN&>FN&>N>&>F.*`B^&>G^&>A.*`B^&>@>&>MN&>A"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$U"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$T"FUS9VED
M(")*=7-T:69Y($QE9G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Y"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I
M9GD@4FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+87IA
M:VAS=&%N(@IM<V=S='(@(N&>@.&>MN&>H.&?DN&>G^&>MN&>@.&?B^&>G^&?
MDN&>C^&>A.&?BR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR-C,*;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T<B`BX9Z`X9^"X9Z3
MX9Z9X9^)X9ZV(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX
M-@IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*
M;7-G:60@(DME<FYE;"!.97=B:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y($-R96%T:6]N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q-`IM<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE
M;F=T:"(*;7-G<W1R("+AGI3AGY+AGIKAGISAGX+AGH3B@(OAGH#AGKSAGI/A
MGI_AGX0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*
M;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(N&>E.&?DN&>FN&>E^&?@>&>D>*`
MB^&>@N&?DN&>FN&>MN&>E.&?B^*`B^&>A>&>N^&>A2(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DY"FUS9VED(")+97D@57-A9V4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-S0P"FUS9VED(")+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K
M97ES97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT.`IM<V=I9"`B2VED<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G
M:60@(DMI<FEB871I(@IM<V=S='(@(N&>@N&>M^&>FN&>M^&>E.&>MN&>D>&>
MN"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O
M<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS
M9VED(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G
M<W1R("+B@(OAGH#AGKSAGIKAGXGAGX$@*$550RU+4BDB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R("+AGH+AGKOAGIGB@(OAGISAGXGA
MGX+AGH\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T
M<B`BX9Z"X9^`X9Z:X9Z@X9^2X9Z"X9ZXX9Z?X9^2X9Z/X9Z$X9^+(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED("),85]Y;W5T(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S4*;7-G
M:60@(DQA;F=U86=E(@IM<V=S='(@(N&>E^&>MN&>G^&>MB(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B
M"FUS9W-T<B`BX9Z?X9ZVX9Z2X9ZVX9Z:X9Z.X9Z:X9Z*X9^2X9Z+XH"+X9Z4
MX9^2X9Z:X9Z'X9ZVX9Z2X9ZWX9Z4X9Z/X9^!X9Z9X9^2X9Z9XH"+X9Z4X9^2
MX9Z:X9Z'X9ZVX9Z8X9ZVX9Z3X9ZWX9Z/XH"+X9ZAX9ZVX9Z<(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW-@IM<V=I9"`B3&%S="!0
M87-S=V]R9"!#:&%N9V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R
M=&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,38S"FUS
M9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.C<Q-PHC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO
M9VEN.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O
M;2`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW
M,30*;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX.0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(N&>H>&>MN&>C^&>G.&>
MN.&>F>&?B>&>MB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.0IM<V=I
M9"`B3&%W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@
M(N&>E.&?DN&>F^&>A.&?B^*`BR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N
M;R!B;W)D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),96)A
M;F]N(@IM<V=S='(@(N&>F^&>N.&>E.&>A.&?BR(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B3&5F
M="(*;7-G<W1R("+AGH;AGY+AGISAGX'AGH0B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,3$R"FUS9VED("),969T(&AE861E<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3`X"FUS9VED("),969T
M('9A;'5E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQE<V]T
M:&\B"FUS9W-T<B`BX9ZAX9^!X9Z?X9Z\X9Z/X9Z\(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED("),979E;"(*;7-G<W1R("+A
MGH#AGICAGY+AGIKAGK?AGH\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI8F5R
M:6$B"FUS9W-T<B`BX9Z;X9ZXX9Z4X9^!X9Z:X9ZXX9Z9X9^)X9ZV(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@Y"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S
M='(@(N&>A>&>MN&>F.&?B>&>MN&>HN&?BN&>M^&>FN&>N.&>F>&?B>&>MN*`
MB^&>HN&>MN&>FN&?B>&>MN&>E.&?BR#AGIOAGKCAGI3AGXKAGK@B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#@*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`BX9Z;X9ZW
MX9Z%X9Z1X9^!X9Z3X9Z?X9^2X9Z/X9^"X9Z3(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@(DQI9VAT($1R:7IZ
M;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C8*;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@
M(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@
M3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR.0IM<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S`*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS
M9VED("),:6=H="!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED("),:6=H="!3;F]W(%-H
M;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*
M;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$X,C(*;7-G:60@(DQI;FLB"FUS9W-T<B`BX9Z/X9^&X9Z.
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@X,PIM<V=I9"`B3&EN:R!T
M:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES
M<&QA>6EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O
M1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@R"FUS9VED("),:6YK<R(*;7-G<W1R
M("+AGH_AGX;AGHXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G
M:60@(DQI;G5X($-O;VMI92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@
M8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HQ,S,*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4Q"FUS9VED("),:7-T($AE
M;'`@5&]P:6-S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,S(*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3`Y"FUS9VED("),:7-T+4%R8VAI
M=F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S
M+G!H<#HU,#0*;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Q,0IM<V=I9"`B3&ES="U)
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N
M<&AP.C4P-PIM<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4P.`IM<V=I9"`B3&ES="U0
M;W-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R
M<RYP:'`Z-3`V"FUS9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4P-0IM<V=I9"`B
M3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N
M<RYP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!S97-S:6]N
M<R!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H
M<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('5S97)S(&9A:6QE
M9#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L
M:7-T+FEN8SHR"FUS9VED("),:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3(*;7-G:60@
M(DQI=&5R871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),
M:71H=6%N:6$B"FUS9W-T<B`BX9Z;X9ZXX9Z1X9Z[X9Z9X9ZBX9ZVX9Z3X9ZX
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6UA9V5S+G!H<#HW
M-PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R("+AGH#AGX;AGI;AGKOAGH3B
M@(OAGI7AGY+AGI'AGKOAGH`N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C`U"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V"FUS9VED("),;V-A;&4@86YD
M(%1I;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-S(@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8R"B,Z
M(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP
M.C<W"FUS9VED("),;V-A=&EO;B(*;7-G<W1R("+AGI'AGKCAGH_AGK;AGX;A
MGH0B"@HC.B!L;V=I;BYP:'`Z,3@Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HR,#`@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,PHC.B!T96UP
M;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-2!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C@R"FUS9VED("),;V<@:6XB"FUS9W-T<B`BX9Z%X9Z\X9Z;(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U"FUS9VED("),;V<@
M;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.30*;7-G:60@(DQO9R!O=70B"FUS
M9W-T<B`BX9Z%X9^!X9Z)(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4Y
M"FUS9VED("),;V=I;B(*;7-G<W1R("+AGH7AGKSAGILB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3$P"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R
M("+AGI?AGK;AGIKAGH#AGK?AGH7AGY+AGH7B@(OAGH7AGKSAGILB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HY.34*;7-G:60@(DQO9VEN(&9A:6QE
M9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R
M960@:6YC;W)R96-T;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.CDY,0IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<S"FUS9VED("),;VYG
M('1E>'0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S
M"FUS9VED("),;W9E(@IM<V=S='(@(N&>G^&?@>&>A>&>@.&?DN&>C^&>N.*`
MB^&>G^&?DN&>FN&>H>&>MN&>B>&?BR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED("),;W<B"FUS9W-T<B`BX9Z1
MX9ZVX9Z4(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L971T97)S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E
M<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),=7AE;6)O=7)G
M(@IM<V=S='(@(N&>F^&>N^&>A>&>H.&?DN&>G^&?AN&>E.&>O>&>FB(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS.3D*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S-R!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B34TB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,CDW"FUS9VED(")-3U1$(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N
M<&AP.C,V"FUS9VED(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO
M(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU3
M1R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA8V%O(@IM<V=S
M='(@(N&>F.&?B>&>MN&>@.&>MN&>G"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,34S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B
M36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G
M<W1R("+AGICAGXGAGK;AGHKAGK;AGJ#AGY+AGH#AGK;AGI_AGY+AGH#AGK;A
MGIHB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*;7-G:60@(DUA9VEC
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY,`IM
M<V=I9"`B36%I;"(*;7-G<W1R("+AGI_AGX;AGI3AGKOAGH_AGY+AGIHB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3,X"FUS9VED(")-86EL($%D
M;6EN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&%W:2(*;7-G<W1R
M("+AGICAGXGAGK;AGJ'AGK;AGISAGX,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@
M(DUA;&%Y<VEA(@IM<V=S='(@(N&>F.&?B>&>MN&>H>&?@>&>G^&?BN&>N"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`BX9Z8X9^)
MX9ZVX9Z;X9^+X9Z,X9ZXX9Z<(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86QI
M(@IM<V=S='(@(N&>F.&?B>&>MN&>F^&>N"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I
M9"`B36%L=&$B"FUS9W-T<B`BX9Z8X9^)X9ZVX9Z;X9^+X9Z/X9ZV(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT"FUS9VED("(B"B)-86YA9V4@=&AE
M(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W
M:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S92!C871E
M9V]R:65S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3$U-`IM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,#@U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,38Y"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S=&]R
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8W"FUS9VED(")-87)C:"(*;7-G<W1R("+AGICAGKCAGI/A
MGK8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0Q"FUS9VED(")-87)G:6XB"FUS9W-T<B`BX9Z:X9ZYX9Z8XH"+
MX9Z1X9^&X9Z6X9^0X9Z:(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.#@*;7-G:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F
M;&%G<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE
M+F<N($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(N&>@.&?A.&?
MAR!-87)S:&%L;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R=&EN:7%U92(*
M;7-G<W1R("+AGICAGXGAGK;AGIKAGI'AGKCAGI/AGKCAGH(B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B36%T8VAI;F<@9FEE
M;&1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%U<FET86YI
M82(*;7-G<W1R("+AGICAGXGAGKSAGIKAGKCAGH_AGK;AGI/AGK@B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.30*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R("+AGICAGXGAGKSA
MGIKAGKCAGI'AGKOAGI\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I
M="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E
M>&-E961E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,3@*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,`IM<V=I9"`B36%X('1E;7`@
M;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z.#8*
M;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3`R(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(T,PIM<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-`HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*;7-G:60@
M(DUA>2(*;7-G<W1R("+AGJ?AGI_AGI?AGK8B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS
M9VED(")-87EO='1E(@IM<V=S='(@(N&>F.&?@^&>HN&>O.&>C^&?@2(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-0IM<V=I9"`B365D:6-I;F4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ
M-@IM<V=I9"`B365M8F5R<R(*;7-G<W1R("+AGI_AGICAGK;AGH?AGK?AGH`B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@R"FUS9VED(")-96YU(&UO
M9&4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E(@IM<V=S='(@(N&>G^&>MN&>
MFB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$V"FUS
M9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE
M('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92`B"B)V97)I9FEE
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S$P"FUS9VED(")-97-S86=E(&5X<&ER960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-38Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C`R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(R-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*;7-G:60@(DUE<W-A9V4@='EP92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE
M=&%R(%=E871H97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HT,@IM<V=I9"`B365T87(@8FQO8VL@;F]T(&%V86EL86)L92XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,C0*;7-G:60@(B(*(DUE
M=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO
M9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3@*;7-G:60@(DUE=&%R1$(@
M:7,@;F]T(&-O;FYE8W1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HV-R!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C<T"FUS9VED(")-971H;V0B"FUS9W-T<B`BX9Z<
MX9ZWX9Z2X9ZXX9Z?X9ZVX9Z?X9^2X9Z:X9^2X9Z/(@H*(SH@9G)A;65W;W)K
M+U)00R]24$,O>&UL<G!C+G!H<#HX,2!F<F%M97=O<FLO4E!#+U)00R]P:'!G
M=RYP:'`Z.#@*(SH@9G)A;65W;W)K+U)00R]24$,O<&AP9W<N<&AP.C@Y(&9R
M86UE=V]R:R]24$,O4E!#+W-O87`N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]24$,O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF;W)M
M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@
M)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C<R(&QI8B]";&]C:R]M971A<BYP:'`Z.#<*;7-G:60@(DUE=')I8R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUE>&EC;R(*;7-G<W1R("+A
MGICAGXGAGK?AGH7AGI_AGXKAGK?AGH`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B
M36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S8*;7-G:60@(DUI9&1L92(*;7-G<W1R("+AGH#AGH[AGY+AGH_AGK;AGILB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM
M<V=I9"`B36EM92!4>7!E(@IM<V=S='(@(N&>E.&?DN&>FN&>E^&?@>&>D2!-
M:6UE(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C(*;7-G:60@(DUI;B!T
M96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,Q-`IM<V=I9"`B36EN('1E;7`@;&%S="`V(&AO=7)S.B`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT
M,S@*;7-G:60@(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X
M<&ER960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(S,PIM<V=I9"`B36ER<F]R(@IM<V=S='(@(N&>AN&?
MDN&>F^&>N^&?AR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I
M9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R("+AGI7AGY+AGI_AGX'AGH3AGY?B
M@(LB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8W,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS-#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q
M=65S="XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q
M-0IM<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@;75S="!G
M96YE<F%T92!I="!B969O<F4@=7-I;F<@=&AI<R!A<'!L:6-A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`T"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@240N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY
M7W-M='`N<&AP.C4X"FUS9VED(")-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C
M:V%G92!-86EL+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S
M<VEO;B!)1"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C<V"FUS9VED(")-;V)I;&4@36%I
M;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV.0IM<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*;7-G:60@(DUO9&EF:65D($1A=&4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4S"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<T"FUS
M9VED(")-;V1U;'5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,34P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B
M36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP
M"FUS9VED(")-;VYA8V\B"FUS9W-T<B`BX9Z8X9^)X9Z\X9Z.X9ZVX9Z`X9Z\
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R("+AGICA
MGXGAGKOAGH3AGJ#AGY+AGH+AGX3AGIOAGK@B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-3DR"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R
M("+AGH'AGX(@X9Z3X9ZWX9Z$(.&>AN&?DN&>D^&>MN&?AB(*"B,Z(&9R86UE
M=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO
M;G1H;'DB"FUS9W-T<B`BX9Z:X9ZVX9Z;X9^+XH"+X9Z!X9^"(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDT"FUS9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(N&>F.&?B>&>N^&>
MA.&>G^&?@>&>FN&?B>&>MB(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI
M8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3DV(&9R86UE
M=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(X,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C
M=&5D("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO<F]C
M8V\B"FUS9W-T<B`BX9Z8X9^)X9ZVX9Z:X9^)X9Z[X9Z`(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO<W1L
M>2!#;&5A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS-`IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M-0IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-3`P"FUS9VED(")-
M;W9E($1O=VXB"FUS9W-T<B`BX9Z5X9^2X9Z;X9ZVX9Z?X9^+XH"+X9Z1X9ZX
MXH"+X9Z%X9Z[X9^'XH"+X9Z`X9^2X9Z:X9^$X9Z8(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HU,#0*;7-G:60@(DUO
M=F4@3&5F="(*;7-G<W1R("+AGI7AGY+AGIOAGK;AGI_AGXOB@(OAGI'AGKCB
M@(OAGI'AGX7B@(OAGH;AGY+AGISAGX'AGH0B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C4P.`IM<V=I9"`B36]V92!2
M:6=H="(*;7-G<W1R("+AGI7AGY+AGIOAGK;AGI_AGXOB@(OAGI'AGKCB@(OA
MGI'AGX7B@(OAGI_AGY+AGH_AGK;AGX8B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C0Y-@IM<V=I9"`B36]V92!5<"(*
M;7-G<W1R("+AGI7AGY+AGIOAGK;AGI_AGXOB@(OAGI'AGKCB@(OAGJ'AGK[A
MGH3B@(OAGIOAGKXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`BX9Z%X9Z[
MX9^'XH"+X9Z`X9^2X9Z:X9^$X9Z8(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C4R,PHC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E('5P(@IM<V=S='(@
M(N&>H>&>ON&>A.*`B^&>F^&>OB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36]Z
M86UB:7%U92(*;7-G<W1R("+AGICAGXGAGKSAGJ#AGY+AGI_AGK;AGX;AGI3A
MGXKAGK?AGH`B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3DR"FUS
M9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-38*
M;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,C4P"FUS9VED(")-=6QT:7!L92!S96QE8W1I
M;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Q
M-@IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z,C@*;7-G:60@(DUY($%C8V]U;G0@26YF;W)M871I;VXB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HV-@IM
M<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]E9&ET+G!H<#HQ,S4*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S='(@(N&>
MF.&>N.&>F>&?B>&>MN&>D^&?B^&>F.&?B>&>MB(*"B,Z('1E;7!L871E<R]M
M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$
M;R!.3U0@06=R964B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#$Q(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE
M9BYP:'`Z,S@*;7-G:60@(DYA;64B"FUS9W-T<B`BX9Z(X9^2X9Z8X9^$X9^'
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDU"FUS9VED(").86UI8FEA(@IM<V=S='(@(N&>CN&>
MMN&>F.&>N.&>E.&?BN&>N"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B
M"FUS9W-T<B`BX9Z.X9Z\X9Z:X9Z[(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").
M97!A;"(*;7-G<W1R("+AGI/AGX'AGI3AGXGAGK;AGIOAGXLB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(N*`B^&>H.&>N^&>
MF^&?DN&>F^&>A.&?BR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H97)L86YD
M<R!!;G1I;&QE<R(*;7-G<W1R("+AGJ+AGH3AGXOAGI'AGKCAGIGAGXWB@(OA
MGJ#AGKSAGIOAGY+AGIOAGH3AGXLB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.#0*;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@55),(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V"FUS
M9VED(").971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S
M8V%P92!296YE=V%L(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@4F5V;V-A
M=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X.`IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4X,0IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8W"FUS9VED(").
M971W;W)K(@IM<V=S='(@(N&>E.&>CN&?DN&>C^&>MN&>B2(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-2!T96UP;&%T97,O<&]R=&%L
M+VQA>6]U="YI;F,Z.3<*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S.2!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDP"FUS9VED(").979E<B(*;7-G<W1R
M("+AGH#AGKOAGX8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE9&]N
M:6$B"FUS9W-T<B`BX9Z3X9Z\X9Z<X9^"X9Z;X9Z`X9ZVX9Z;X9^!X9Z*X9Z\
MX9Z3X9ZX(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N
M86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.#0*
M(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@X
M"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HQ
M,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W($UE<W-A9V4@=&\@)7,B"FUS
M9W-T<B`BX9Z?X9ZVX9Z:XH"+X9Z0X9^2X9Z8X9ZXXH"+X9Z1X9^%("5S(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV
M."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED(").97<@36]O;B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,U
M"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3@*;7-G:60@(DYE=R!:96%L86YD(@IM<V=S='(@(N&>D^&>
MO.&>G.&?@N&>F^&>H.&?BN&?DN&>G^&?@>&>H>&>A.&?BR(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-PIM<V=I9"`B3F5W('!A<W-W;W)D
M(@IM<V=S='(@(N&>EN&>MN&>@.&?DN&>F>*`B^&>G^&>F.&?DN&>A.&>MN&>
MC^&?B^*`B^&>D.&?DN&>F.&>N"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<W%L+G!H<#HR-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D
M('=I;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z-3(*;7-G:60@(DYE=R!P87-S=V]R9',@9&]N
M)W0@;6%T8V@N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N
M:RDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4W"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS,#4*;7-G:60@(DYE=W,B"FUS9W-T<B`BX9Z6X9^0X9Z/X9^,X9Z8
MX9ZVX9Z3(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R,0IM<V=I
M9"`B3F5W<V=R;W5P<R(*;7-G<W1R("+AGISAGX'AGI'AGK?AGH#AGK;B@(OA
MGI;AGY#AGH_AGXSAGICAGK;AGI,B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I
M;F9O+FEN8SHQ-2!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT,0HC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHR-0IM<V=I9"`B3F5X="(*;7-G<W1R("+AGI3AGI/AGY+A
MGI'AGK;AGI3AGXLB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*;7-G:60@
M(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HS-C<@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HS-S$*;7-G:60@(DYE>'0@;W!T:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO4&%G97(N<&AP.C$P,PIM<V=I9"`B3F5X=#XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B
MX9Z3X9ZXX9Z`X9ZVX9Z:X9^)X9ZVX9Z@X9^2X9Z"X9^0X9Z:(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDV"FUS9VED(").:6=E<B(*;7-G<W1R("+AGI/AGKCAGJ#AGY+AGI_A
MGX'AGIHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`B
MX9Z3X9ZXX9Z@X9^2X9Z?X9^!X9Z:X9ZXX9Z9X9^)X9ZV(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,W,@IM<V=I9"`B3FEG:'0B"FUS9W-T
M<B`BX9Z9X9Z4X9^+(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").:75E(@IM<V=S
M='(@(N&>D^&>N.&>G"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HY-C0*;7-G:60@(DYO(@IM<V=S='(@(N&>D>&?@2(*"B,Z
M('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM<V=I9"`B3F\@
M879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N
M8V5S(&9O<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+G!H<#HQ,#8*;7-G:60@(DYO(&%V86EL86)L92!S=')A
M=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM
M<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-S8*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HR,S<*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HR-3D*
M;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET
M:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP
M:'`Z-C<*;7-G:60@(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#
M04P@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.C4T"FUS9VED(").;R!C:&%N9V4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED(").;R!C
M:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V.2!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4R,`HC.B!F<F%M97=O<FLO571I;"]5
M=&EL+G!H<#HW-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@U-0IM<V=I9"`B3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!6
M1E,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M-CDX"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C<R-0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,S0*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,#,*;7-G
M:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C<Q"FUS9VED(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$R,2!L:6(O
M0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M,S4*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,@IM<V=I9"`B3F\@;&]C
M871I;VX@<')O=FED960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").;R!M97-S
M86=E('-U<'!L:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@IM<V=I9"`B3F\@;F%M92!S
M<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS9VED(").;R!N=6UB97(@<W!E
M8VEF:65D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M.3D*;7-G:60@(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R.#<*;7-G:60@
M(B(*(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4
M:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O<FL@=VET
M:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@<VEG;G5P
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C<V-@IM
M<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0S"FUS9VED(").
M;R!R=6QE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HT.#(*;7-G:60@(DYO('-E<&%R871O<B!S<&5C:69I960N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#0*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@W"FUS9VED(").;R!S=6-H(&9I
M;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$S,0IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@
M9F]R(&-A8VAE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S,0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C(R,0IM<V=I9"`B3F\@=7-E<FYA;64@86YD
M+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]2
M4$,O4E!#+WAM;')P8RYP:'`Z,30P(&9R86UE=V]R:R]24$,O4E!#+W!H<&=W
M+G!H<#HQ-S4*;7-G:60@(DYO('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HY-S(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.CDX,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.3DS"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,#$P"FUS9VED(").;R!V86QU97,B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I
M;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M,C@*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T
M:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0U"B,Z('1E
M;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3,*;7-G:60@(DYO
M;F4B"FUS9W-T<B`BX9Z"X9^2X9Z8X9ZVX9Z3(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I9"`B3F]N92`H=7-E
M(&EM<&QI8VET*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X-0IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDV"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G<W1R("+A
MGH#AGX3AGX?B@(OAGH[AGXGAGJ#AGY+AGISAGXGAGH`B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS9VED(").
M;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM
M<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S='(@(N&>@.&?
MA.&?A^*`B^&>F.&?B>&>MN&>FN&?@.&>CN&>MN*`B^&>E^&>MN&>@N*`B^&>
M@>&>MN&>A.*`B^&>A^&>ON&>A"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F]R
M=V%Y(@IM<V=S='(@(N&>D^&?D.&>FN&>G.&?@N&>GR(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0Q"FUS9VED(").;W0@069T97(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV-#`*;7-G:60@(DYO="!"969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z-#$X"FUS9VED(").;W0@82!D:7)E8W1O
M<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+G!H<#HV,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX-`HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H
M<#HY-0HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*;7-G:60@
M(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`IM<V=I9"`B3F]T('-E="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO
M;DAA;F1L97(N<&AP.C$T-0HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O
M4V5S<VEO;DAA;F1L97(N<&AP.C$V,`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA
M;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$W-0HC.B!F<F%M97=O<FLO4V5S
M<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$X.0HC.B!F<F%M97=O
M<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C(S-B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR,#@@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(S-`HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,C4R(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-CD*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C(X-2!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,S`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,38@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C,S,PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S8V
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HT,C8*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C4P-2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3<T"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HU.3$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C8V
M.0HC.B!F<F%M97=O<FLO5D93+U9&4R]H;W)D92YP:'`Z.#(@9G)A;65W;W)K
M+U9&4R]61E,O:&]R9&4N<&AP.C$S,0HC.B!F<F%M97=O<FLO5D93+U9&4R]H
M;W)D92YP:'`Z,34Q(&9R86UE=V]R:R]61E,O5D93+VAO<F1E+G!H<#HQ-S`*
M(SH@9G)A;65W;W)K+U9&4R]61E,O:&]R9&4N<&AP.C$X.2!F<F%M97=O<FLO
M5D93+U9&4R]H;W)D92YP:'`Z,C`W"B,Z(&9R86UE=V]R:R]61E,O5D93+VAO
M<F1E+G!H<#HR,C<@9G)A;65W;W)K+U9&4R]61E,O:&]R9&4N<&AP.C,S,`IM
M<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T-"!C;VYF:6<O:&]O:W,N
M<&AP+F1I<W0Z,3`X-0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@W
M"FUS9VED(").;W1E<R(*;7-G<W1R("+AGH7AGX;AGH[AGK;AGX8B"@HC.B!S
M97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@
M=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B
M"FUS9W-T<B`BX9Z<X9ZWX9Z%X9^2X9Z&X9ZWX9Z`X9ZV(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3`U,`IM<V=I9"`B3G5M8F5R(@IM<V=S='(@
M(N&>F^&?@>&>@2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,S,*
M;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(N&>A>&?AN&>
MD^&>O>&>D^*`B^&>C^&>O>&>HN&>@.&?DN&>G^&>FB(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S-S<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30S,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#4S('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB
M97(@;V8@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,S<U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,CD*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30U,2!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@IM<V=I9"`B3G5M8F5R(&]F(')O
M=W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE
M9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV
M-`IM<V=I9"`B3TLB"FUS9W-T<B`BX9Z9X9Z;X9^+X9Z6X9^2X9Z:X9Z8(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,0IM
M<V=I9"`B3V)J96-T(@IM<V=S='(@(N&>G.&>C^&?DN&>D.&>NR(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E
M871O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,3`X"FUS9VED(")/8W1A;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Y"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G
M<W1R("+AGH_AGKOAGIOAGK8B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M.3<*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS-#(*;7-G:60@(D]F9FEC92(*;7-G<W1R
M("+AGH#AGK;AGIKAGK?AGIGAGK;AGIOAGY#AGIDB"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W
M;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V"FUS9VED(")/;&0@<&%S<W=O<F0B
M"FUS9W-T<B`BX9Z6X9ZVX9Z`X9^2X9Z9XH"+X9Z?X9Z8X9^2X9Z$X9ZVX9Z/
MX9^+XH"+X9Z%X9ZVX9Z?X9^+(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C0V"FUS9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*;7-G<W1R
M("+AGJ+AGKSAGICAGX+AGI,B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HW,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P
M<&]R="!S:&%R960@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C$P,`IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U
M.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<Y"FUS9VED(")/;FQY(&]N
M92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N
M97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H
M:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,SD@;&EB+T)L;V-K+VEF
M<F%M92YP:'`Z-#`*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S
M='(@(N&>E.&>ON&>@.*`B^*`B^&>@.&?DN&>D^&>N^&>A.*`B^*`B^&>E.&>
MA.&?DN&>HN&>O>&>A>*`B^&>D.&?DN&>F.&>N"(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R
M.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P
M87)T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@;&EN
M:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4X"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S='(@
M(N&>E.&?DN&>FN&>EN&?D.&>D^&?DN&>DN*`B^&>E.&?DN&>FN&>C^&>M^&>
ME.&>C^&?DN&>C^&>M^&>@.&>MN&>FB(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M:61E8F%R+G!H<#HQ-3$*;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`BX9Z'X9Z8
MX9^2X9Z:X9Z^X9Z?XH"+(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C,R('1E
M;7!L871E<R]P<F5F<R]A<'`N:6YC.C$Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED(")/<F=A
M;FES871I;VYA;"!5;FET(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ-#$*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B(@H*
M(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L(&%P
M<&QI8V%T:6]N('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E
M;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G
M:60@(D]T:&5R(@IM<V=S='(@(N&>E>&?DN&>G^&?@>&>A.&?ER(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3`Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,38@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$R-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,T(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#0*;7-G:60@(D]T:&5R($EN9F]R;6%T
M:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,S$*;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HX,`IM<V=I9"`B4$%-(&%U=&AE
M;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-0IM<V=I
M9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$R-S8*;7-G:60@(E!'4"!$:6=I=&%L
M(%-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,S(R"FUS9VED(")01U`@16YC<GEP=&5D($1A=&$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,W
M-`IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,U-@IM<V=I9"`B4$=0(%-I9VYE
M9"]%;F-R>7!T960@1&%T82(*;7-G<W1R("(B"@HC.B!A9&UI;B]P:'!S:&5L
M;"YP:'`Z-C@*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS
M9VED(")032!,:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")032!286EN(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,Y"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")032!3
M;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0Q"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#(*
M;7-G:60@(E!-(%-U;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B4$T@5"U3=&]R;7,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(W-`IM<V=I9"`B
M4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@;&EB
M+V%P:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`BX9Z%X9Z3X9^2X9Z;X9^$X9^'
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDY"FUS9VED(")086MI<W1A;B(*;7-G<W1R("+AGI3A
MGXGAGK;AGH+AGKCAGI_AGY+AGI#AGK;AGI,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS
M9VED(")086QA=2(*;7-G<W1R("+AGI3AGXGAGK;AGJ'AGKPB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`Q"FUS9VED(")086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&%N86UA(@IM<V=S
M='(@(N&>E.&?B>&>MN&>CN&>MN&>F.&?B>&>MB(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM
M<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R("+AGI3AGXGAGK;AGI;A
MGKSAGHGAGKSAGISAGJ#AGY+AGH+AGKCAGH[AGX$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$W-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R
M"FUS9VED(")087)A9W5A>2(*;7-G<W1R("+AGI3AGXGAGK;AGIKAGXGAGK;A
MGJ#AGY+AGH+AGK;AGIDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS-@IM<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3@P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3,W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C$U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#(V"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z-CD@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Y
M"FUS9VED(")087-S=V]R9"(*;7-G<W1R("+AGI;AGK;AGH#AGY+AGIGB@(OA
MGI_AGICAGY+AGH3AGK;AGH_AGXLB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U
M;&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C$S,C,*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,34W"FUS
M9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,#8Q"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@
M(E!A<W-W;W)D.B(*;7-G<W1R("+AGI;AGK;AGH#AGY+AGIGB@(OAGI_AGICA
MGY+AGH3AGK;AGH_AGXO"H.&?EB(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C$Q"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$U,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#0R
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G:60@
M(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3$Y('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`BX9Z4
MX9ZWX9Z1X9Z7X9^2X9Z'X9ZVX9Z4X9^+(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C
M;&EP8F]A<F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R("+AGI7A
MGY+AGIOAGKSAGIPB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E
M+FEN8SHR('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z
M-PIM<V=I9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@(E!E;W!L92(*;7-G<W1R("+A
MGICAGI/AGKOAGI_AGY+AGI\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R("+A
MGI?AGK;AGH+AGIKAGIDB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I
M;G1E;F%N8V4N:'1M;#HT.0IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/
M<&5R871I;VYS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT,3`*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O
M;B!L;V=I;C\B"FUS9W-T<B`BX9Z2X9^2X9Z<X9Z^XH"+X9Z4X9^2X9Z:X9Z/
MX9ZWX9Z4X9Z/X9^2X9Z/X9ZWX9Z`X9ZVX9Z:XH"+X9Z/X9^&X9Z@X9^"X9Z1
MX9ZVX9^&(.&>EN&?@>&>F^*`B^&>A>&>O.&>FR`_(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I;VXB"FUS
M9W-T<B`BX9Z?X9ZWX9Z1X9^2X9Z2X9ZW(@H*(SH@861M:6XO<&5R;7,O9&5L
M971E+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB
M)7-<(B!N;W0@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HU.3`*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38Q
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38T"FUS9VED(")097)M
M:7-S:6]N<R(*;7-G<W1R("+AGI_AGK?AGI'AGY+AGI+AGK<B"@HC.B!A9&UI
M;B]P97)M<R]E9&ET+G!H<#HQ,#D@861M:6XO<&5R;7,O861D8VAI;&0N<&AP
M.C8P"B,Z(&%D;6EN+W!E<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D
M96QE=&4N<&AP.C4X"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO
M;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@*;7-G
M:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(N&>EN&?D.&>C^&?
MC.&>F.&>MN&>D^*`B^&>E>&?DN&>D>&>MN&>F^&?B^*`B^&>@>&?DN&>F^&>
MO>&>DR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R("+AGI3A
MGXGAGX'AGIKAGXGAGKPB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*
M;7-G:60@(E!E=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0
M:&EL:7!P:6YE<R(*;7-G<W1R("+AGJ#AGY+AGISAGKCAGIOAGKCAGI;AGKCA
MGI,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3DV"FUS9VED(")0:&]N92(*;7-G<W1R("+AGI'AGKSAGIKAGI_AGY#AGI;A
MGY+AGI$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DT"FUS9VED
M(")0:&]T;W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4&ET
M8V%I<FXB"FUS9W-T<B`BX9Z6X9ZXX9Z/X9Z!X9ZVX9Z9X9Z:X9ZWX9Z3(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*
M;7-G:60@(E!I>&5L<R(*;7-G<W1R("+AGI?AGKCAGH#AGI_AGX+AGILB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*;7-G:60@(E!L871I='5D97,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M
M92!C96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I
M<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U
M('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4W,`IM<V=I9"`B4&QE87-E(&5N
M=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G:60@(E!L
M96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#4*;7-G:60@
M(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-3$*;7-G:60@(E!L96%S
M92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y
M<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(T-34*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED('1I
M;64N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C<*;7-G:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@
M<')O8FQE;2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0
M;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@
M(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@
M86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA
M;F%G97(N<&AP.C<P"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G
M;W)Y(&YA;64Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&]L
M86YD(@IM<V=S='(@(N&>E.&?B>&>O.&>H>&>O.&>B2(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4P,PIM<V=I9"`B4&]L;',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&]R='5G86PB"FUS
M9W-T<B`BX9Z6X9^0X9Z:X9Z1X9Z[X9Z9X9Z@X9^2X9Z"X9ZVX9Z;X9^+(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(W"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.CDQ"FUS9VED(")0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C
M960@8GD@24U!4"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR-S@@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,0IM
M<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O;&1A<"YP:'`Z,3,S"FUS9VED(")0
M<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C,W"FUS9VED
M(")0<F5S<W5R92(*;7-G<W1R("+AGI_AGICAGY+AGI;AGK;AGI(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(W,0IM<V=I9"`B4')E<W-U<F4@870@<V5A
M(&QE=F5L.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(R.0IM<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`T"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R("+AGICAGK[AGIOB@(OAGH?A
MGK;B@(OB@(OB@(OAGICAGKOAGI,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*;7-G:60@(E!R979I
M97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,U-R!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C,V,0IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!R
M:79A=&4@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]-96YU+G!H<#HQ-CD*;7-G:60@(E!R;V)L96TB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<')O8FQE;2YP:'`Z,3(W"FUS9VED(")0<F]B;&5M($1E<V-R
M:7!T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS.#4*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(N&>@N&>F.&?DN&>FN&?
MA.&>A"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,3D@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C$Y-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,C@W"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI
M8R!+97DB"FUS9W-T<B`BX9Z`X9Z\X9Z3X9Z?X9^$XH"+X9Z?X9ZVX9Z2X9ZV
MX9Z:X9Z.X9^((@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV-#8*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED
M(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I=F%T92!K
M97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`P"FUS9VED(")0=65R=&\@4FEC;R(*;7-G<W1R("+A
MGI;AGY#AGIKAGH_AGKSAGIKAGKCAGH#AGKPB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS
M9VED(")1871A<B(*;7-G<W1R("+AGH#AGK;AGH_AGK8B"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z-C,*;7-G:60@(E%U97)Y(@IM<V=S='(@(N&>G^&?AN&>
MCN&>O>&>FN*`BR(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`IM<V=I
M9"`B475O=&$B"FUS9W-T<B`BX9Z`X9Z\X9Z/X9ZV(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(W,@IM<V=I9"`B4F%D:6\@<V5L96-T
M:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0T"FUS9VED(")286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")286EN
M($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0V"FUS9VED(")286EN($QA=&4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G
M:60@(E)A:6X@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")286EN(&%N9"!3;F]W
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0Y"FUS9VED(")286EN('1O(%-N;W<B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A;F1O;2!&;W)T=6YE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW
M-@IM<V=I9"`B4F%T:6\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ.#`*;7-G:60@(E)E860B"FUS9W-T<B`BX9ZB
MX9ZVX9Z3(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.#<*;7-G:60@(E)E860@;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO
M="!B92!U;F1O;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R
M96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C
M86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U
M<B!L87-T(&%C=&EO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F
M<F5S:"(*;7-G<W1R("+AGI+AGY+AGISAGK[B@(OAGK+AGY+AGIGB@(OAGI_A
MGY+AGIKAGI_AGXLB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDU"FUS
M9VED(")2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T-0IM<V=I9"`B4F5F<F5S
M:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]L87EO=70N:6YC.CDT"FUS9VED(")2969R97-H(')A=&4Z(@IM<V=S='(@
M(N&>HN&>C^&?DN&>FN&>MN*`B^&>DN&?DN&>G.&>ON*`B^&>LN&?DN&>F>*`
MB^&>G^&?DN&>FN&>G^&?B\*@X9^6(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.#DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3<*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S.0IM<V=I9"`B4F5G97@B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(T,@IM<V=I9"`B
M4F5L871I;VYS:&EP($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(P.`IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(N&>E>&?DN&>D>&>N^&>
M@.*`B^&>H>&>ON&>A.*`B^&>G.&>M^&>B2(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S,X"FUS9VED(")296UA<FMS(@IM<V=S='(@(N&>@.&?AN&>CN&>
MC^&?B^*`B^&>G^&>F.&?DN&>@N&>MN&>F^&?BR(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,3<*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM<V=I9"`B
M4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHX('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,PIM<V=I9"`B4F5M;W9E(@IM<V=S
M='(@(N&>F>&>@.*`B^&>A>&?@>&>B2(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HU-3<*;7-G:60@(E)E;6]V92!C;VQU;6XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHT,`IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,C@*;7-G:60@(E)E
M;6]V92!P86ER(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HR,#(*;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G
M<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*;7-G
M:60@(E)E;6]V92!T:&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO
M=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*;7-G:60@(E)E
M;6]V92!U<V5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W)E;6]V92YI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@=7-E
M<CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C
M+G!H<#HQ,S@@9G)A;65W;W)K+U)00R]24$,O<&AP9W<N<&AP.C$W,PIM<V=I
M9"`B4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R
M;W)C;V1E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$U,`IM<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T
M(&)E(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C$W-B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4S,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE
M9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C<P-"!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C@V,0HC.B!F<F%M97=O<FLO5D93+U9&4R]H;W)D92YP:'`Z-#$@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<S,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5T:6PO
M571I;"YP:'`Z-S<V"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB
M)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,S-`IM
M<V=I9"`B4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,S$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S0S"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,Q.2!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,3`P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(N&>@.&?AN&>CN&>
MC^&?B^*`B^&>H>&>ON&>A.*`B^&>G.&>M^&>B2(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C0V"FUS9VED(")297-E="!087-S=V]R9"(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I
M9"`B4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3,P"FUS9VED(")297-T;W)E($QA<W0@475E<GDB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C<Q(&%D;6EN+V-M9'-H
M96QL+G!H<#HR."!A9&UI;B]S<6QS:&5L;"YP:'`Z-C8*;7-G:60@(E)E<W5L
M=',B"FUS9W-T<B`BX9Z;X9Z1X9^2X9Z2XH"+X9Z5X9Z;(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,2!T96UP;&%T97,O<')E9G,O96YD
M+FEN8SHW"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R("+AGH_A
MGY+AGIKAGJ'AGI3AGXOB@(OAGI'AGX7B@(OAGH?AGICAGY+AGIKAGK[AGI\B
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S@*;7-G:60@(E)E
M='EP92!N97<@<&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM
M<V=I9"`B4F5U;FEO;B(*;7-G<W1R("+AGIKAGKCAGJ+AGKOAGIGAGI/AGKCA
MGIGAGXGAGKOAGH0B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U
M<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,S4*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*;7-G:60@(E)I9&1L97,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<P"FUS9VED(")2:6=H="(*;7-G<W1R("+B@(OAGI_A
MGY+AGH_AGK;AGX8B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$T
M"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$Q,`IM<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?=R!0<F]P97)T:65S+BXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HR,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`BX9Z/X9Z]X9Z3X9ZVX9Z1X9ZX
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R("+AGIKA
MGKSAGICAGXGAGK;AGI/AGK@B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C(T"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,C$*;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@(N&>E.&>A.&?DN&>G.&>
MM^&>F^*`B^&>D>&?A>*`B^&>AN&?DN&>G.&?@>&>A"(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C<*;7-G:60@(E)O=&%T
M92!2:6=H="(*;7-G<W1R("+AGI3AGH3AGY+AGISAGK?AGIOB@(OAGI'AGX7B
M@(OAGI_AGY+AGHKAGK;AGX8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P,0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`BX9Z'X9Z]X9Z:XH"+X9Z*
MX9^!X9Z`PJ#AGY8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4S"FUS9VED(")2=6QE<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S
M(&%N9"!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I
M;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3(*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`*;7-G:60@
M(E)U;B(*;7-G<W1R("+AGIKAGH_AGXOB@(LB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS
M9VED(")2=7-S:6%N($9E9&5R871I;VXB"FUS9W-T<B`BX9Z?X9Z@X9Z6X9^0
MX9Z3X9^2X9Z2XH"+X9Z:X9Z[X9Z?X9^2X9Z?X9^*X9ZX(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,PIM<V=I9"`B4G=A;F1A(@IM<V=S='(@(N&>FN&>G.&?B>&>MN&>D^&?
MB^&>BN&>MB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,C@U"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS
M,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@R"FUS9VED(")3
M05-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,C`*;7-G:60@(E--
M4R!-97-S86=I;F<B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C(Q"FUS9VED(")344P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S(X-0IM<V=I9"`B4U%,('-T871E;65N="!F;W(@
M=F%L=64@;&]O:W5P<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#0W"FUS9VED(")34T@B"FUS9W-T<B`B4U-((@H*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B
M:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R("(B"@HC.B!L:6(O
M87!I+G!H<#HQ-3,*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0IM<V=I
M9"`B4V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@
M2&5L96YA(@IM<V=S='(@(N&>G^&>A.&?B^*`B^&>H.&?@>&>H>&?@>&>CN&>
MMB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES
M(@IM<V=S='(@(N&>G^&>A.&?B^&>@^&>N.&>CR#AGI/AGK?AGH0@X9Z3X9^!
MX9Z<X9ZXX9Z?(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,SD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED(")386EN="!,=6-I82(*
M;7-G<W1R("+AGI_AGH3AGXOAGIOAGKSAGI_AGXKAGKCAGIGAGXGAGK8B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`P"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N
M(@IM<V=S='(@(N&>G^&>A.&?B^*`B^&>EN&?DN&>F>&?@N&>FB#AGI/AGK?A
MGH0@X9Z8X9ZXX9Z"X9Z[X9Z9X9ZBX9^!X9ZAX9Z[X9Z$(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-0IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B
M"FUS9W-T<B`BX9Z?X9Z$X9^+X9Z<X9ZVX9^&X9Z$X9Z?X9Z$X9^+(.&>D^&>
MM^&>A"#B@(OAGJ#AGY+AGH+AGY+AGIKAGKCAGH[AGK;AGHSAGKCAGI,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS
M9VED(")386UE(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-PIM<V=I9"`B4V%M;V$B"FUS9W-T<B`BX9Z?X9ZVX9Z8X9Z\X9ZBX9ZV
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R("+A
MGI_AGK;AGI/AGXOAGICAGXGAGK;AGIKAGKCAGH[AGKPB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`W"FUS9VED(")386\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B4V%O
M(%1O;64@86YD(%!R:6YC:7!E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R86)I82(*;7-G<W1R
M("+AGJ+AGK;AGIKAGXGAGK;AGI3AGXOB@(OAGI3AGXKAGKCAGI_AGK;AGJ+A
MGKSAGHSAGK@B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$U
M"FUS9VED(")3879E(@IM<V=S='(@(N&>FN&>@.&?DN&>G^&>MN*`B^*`B^&>
MD>&>N^&>@.*`B^*`BR(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I
M="YI;F,Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS
M9W-T<B`BX9Z:X9Z`X9^2X9Z?X9ZVXH"+X9Z1X9Z[X9Z`XH"+(.&>A^&>F.&?
MDN&>FN&>ON&>GR(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C<*;7-G
M:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@
M<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R
M>2XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@
M=&\Z(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3`*;7-G:60@(E-C871T97)E9"!4+5-T;W)M
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G
M:60@(E-C:65N8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,38*;7-G:60@(E-E87)C:"(*;7-G<W1R("+AGI_AGY+AGISAGX+AGH3AGIKA
MGH`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,V"FUS9VED(")3
M96%R8V@@16YG:6YE<R(*;7-G<W1R("+AGICAGXGAGK;AGI_AGXKAGKCAGI/B
M@(OAGI_AGY+AGISAGX+AGH3AGIKAGH`B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.38V"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X,PIM
M<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R("+AGH?AGY+AGIKAGK[AGI_B
M@(OAGH#AGK;AGIOAGI3AGIKAGK?AGH7AGY+AGH;AGX'AGI$B"@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B4V5L96-T(&$@9W)O
M=7`@=&\@861D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@(E-E
M;&5C="!A('-E<G9E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$U-@IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C8W-`IM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R("+AGH?AGY+AGIKA
MGK[AGI_B@(OAGI'AGK;AGX;AGH3AGJ+AGI_AGXLB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-C4T"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M
M<&]N96YT<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C@W,0IM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C<U"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R("+AGH?AGY+A
MGIKAGK[AGI_B@(OAGH+AGY+AGICAGK;AGI,B"@HC.B!S97)V:6-E<R]K97EB
M;V%R9"YP:'`Z,S<*;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y
M;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O
M<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B
M4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T
M92!F;W)M870Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N
M=&ET>7-E;&5C="YI;F,Z.3`*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@
M>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9&%T82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM
M:71E<CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z
M,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C
M="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S$P"FUS9VED(")396QE8W0@>6]U<B!C;VQO<B!S
M8VAE;64N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M-3(*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*
M;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-#`*;7-G:60@
M(E-E;F0@4TU3(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E
M;F5G86PB"FUS9W-T<B`BX9Z?X9^!X9Z.X9^!X9Z@X9^2X9Z"X9ZVX9Z;X9^+
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C@*;7-G:60@(E-E;G-O<CH@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,#@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS9W-T<B`BX9Z`X9Z)X9^2
MX9Z)X9ZV(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R;R(*;7-G<W1R("+AGI_A
MGX+AGI3AGXKAGK@@X9Z3X9ZWX9Z$(.&>F.&?B>&>N^&>A.&>C^&?@>&>CN&?
M@>&>H.&?DN&>@.&?DN&>FN&>O"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-S`R"FUS9VED(")397)I86P@3G5M8F5R(@IM<V=S='(@
M(N&>F^&?@>&>@>*`B^&>G^&>F.&?DN&>@N&>MN&>F^&?BR(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-30*;7-G:60@(E-E<G9E<B!D871A
M('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HR-PIM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E9"XB"FUS9W-T<B`B
M(@H*(SH@;&EB+V%P:2YP:'`Z,30U"FUS9VED(")397-S:6]N<R(*;7-G<W1R
M("+AGI_AGICAGY#AGIDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S(R"FUS9VED(")3970B"FUS9W-T<B`BX9Z`X9^&X9Z.X9Z/X9^+(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y"FUS9VED(")3970@;W!T:6]N<R!T
M;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E
M<B!F;W)G970@:70N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,3@*;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO
M=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#<*;7-G:60@(E-E="!Y;W5R
M('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N
M<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,0IM
M<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@
M<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y
M(&]P=&EO;G,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-S<*;7-G:60@(E-E='5P(@IM<V=S='(@(N&>BN&?AN&>H>&>ON&>A"(*
M"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,W"FUS9VED
M(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ.#`*;7-G:60@(E-E
M=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B
M"FUS9W-T<B`BX9Z?X9ZXX9Z?X9^2X9Z@X9^"X9Z;(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C4Q,@IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@
M(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0U,`IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN
M960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,S(S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3$S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@
M(N&>E.&>A.&?DN&>H.&>MN&>B2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R
M96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0Y-`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG
M(&EN/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-S<S"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#8*;7-G:60@
M(E-H;W<@<&EC:V5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU,S`*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A
M<C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E<R!-96YU(&]N('1H92!L
M969T/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE
M($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8T"FUS
M9VED(")3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T
M:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G:60@(E-H;W<@=&AE
M(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$W-S$*;7-G:60@(E-H;W<@=7!L;V%D(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4Q"FUS9VED(")3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED(")3:&]W97)S
M($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-30*
M;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-#<Q
M"FUS9VED(")3:')I;FLB"FUS9W-T<B`BX9Z4X9Z$X9^2X9Z:X9Z]X9Z)(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HW
M-C(*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HX,C0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HY,3`*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA
M9V5R+G!H<#HY-S(*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-
M86YA9V5R+G!H<#HQ,#,U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70O36%N86=E<BYP:'`Z,3`W-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+TUA;F%G97(N<&AP.C$Q,#0*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,3,W"FUS9VED(")3:')I;FL@;W(@
M;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER
M<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE
M;VYE(@IM<V=S='(@(N&>G^&?@>&>FN&?B>&>MN&>H>&?@>&>HN&>O.&>DR(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C<*;7-G:60@
M(E-I9VX@=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HW,3,*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R("+AGJ#A
MGH_AGY+AGI#AGIOAGX'AGH'AGK8B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C<Q,@IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B"FUS
M9W-T<B`BX9Z?X9ZYX9Z$X9^2X9Z@X9Z4X9Z[X9Z:X9ZX(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-2!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]Z:7`N<&AP.C<R"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1G>BYP:'`Z.#0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.3`P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3D@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(T,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,C4T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C,*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-@IM<V=I9"`B4VEZ92(*;7-G<W1R("+A
MGI'AGX;AGJ#AGX8B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E
M;F%N8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V86MI82(*;7-G<W1R("+A
MGI_AGY+AGIOAGKSAGISAGXGAGK;AGH+AGK@B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS
M9VED(")3;&]V96YI82(*;7-G<W1R("+AGI_AGY+AGIOAGKSAGISAGXGAGK;A
MGI/AGK@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU-0IM<V=I9"`B4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R!3:&]W97(B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-3<*;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B
M4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3;F]W(%-H;W=E
M<G,@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y
M,`IM<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,CDT"FUS9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@=V%T
M97(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3;VQO;6]N
M($ES;&%N9',B"FUS9W-T<B`BX9Z`X9^$X9^'XH"+X9Z?X9Z\X9ZAX9Z\X9Z8
MX9^)X9Z\X9Z3(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,30@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V]M86QI82(*;7-G
M<W1R("+AGI_AGKSAGICAGXGAGK;AGIOAGK@B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-C4*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDQ.0IM<V=I9"`B4V]R="!O
M<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$V-@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$X.0IM<V=I9"`B4V]U
M<F-E(&%D9')E<W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B
M4V]U=&@@069R:6-A(@IM<V=S='(@(N&>HN&>MN&>H.&?DN&>FN&>M^&>@.*`
MB^*`B^&>@>&>MN&>A.*`B^&>C^&?DN&>E.&>O.&>A"(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@V"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X
M-3DM,RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")3;W5T:"!'
M96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R
M("+AGJ#AGY+AGI_AGH#AGJ#AGY+AGI_AGXKAGKCB@(OAGH'AGK;AGH3B@(OA
MGH_AGY+AGI3AGKSAGH0@X9Z3X9ZWX9Z$(.&>@.&?A.&?A^&>G^&>MN&?AN&>
MA.&>G.&>M^&>A>*`B^&>@>&>MN&>A.*`B^&>C^&?DN&>E.&>O.&>A"(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*
M;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@
M(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G
M:60@(E-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#$Y"FUS
M9VED(")3<&%C97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"FUS9VED(")3<&%C:6YG(@IM
M<V=S='(@(N&>@N&>F.&?DN&>F^&>MN&>CR(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I
M;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@
M(E-P86EN(@IM<V=S='(@(N&>HN&?@>&>G^&?B>&?DN&>E.&>MN&>B2(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#<*;7-G:60@(E-P86TB"FUS
M9W-T<B`BX9Z?X9ZVX9Z:XH"+X9ZEX9Z/XH"+X9Z4X9ZVX9Z3XH"+X9Z`X9ZV
MX9Z:(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C
M:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8R"FUS9VED(")3
M<&QI="!C96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")3<&]R=',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED(")3<FD@3&%N:V$B"FUS
M9W-T<B`BX9Z?X9^2X9Z:X9ZXX9Z;X9Z$X9^2X9Z`X9ZV(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C<Q(&QI8B]";&]C:R]M971A<BYP:'`Z
M.#8*;7-G:60@(E-T86YD87)D(@IM<V=S='(@(N&>@>&?DN&>D^&>MN&>C^*`
MB^&>@N&?AN&>FN&>O"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-PIM
M<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(U.30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P,@IM
M<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4W,0IM<V=I9"`B4W1A=&4@;W(@4')O=FEN
M8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X
M+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G<W1R("+AGI_AGY+AGI#AGK;A
MGI/AGI?AGK;AGI8B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`X
M"FUS9VED(")3=&]R86=E(&9O<FUA="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,PIM<V=I9"`B4W1R965T($%D
M9')E<W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R
M("+AGI3AGI/AGY+AGI'AGK;AGH_AGXOB@(OAGH;AGKSAGH\B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,W"FUS9VED(")3=')I;F<@;&ES="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#@Q"FUS
M9VED(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3
M=2(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U
M;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`BX9Z4X9^2
MX9Z:X9Z2X9ZVX9Z3XH"+X9Z4X9Z1(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S,V(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,Q
M-@IM<V=I9"`B4W5B;6ET(@IM<V=S='(@(N&>BN&>MN&>@.&?B^*`B^&>G^&?
MDN&>D^&>OB(*"B,Z('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@
M<WES=&5M+B!9;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E
M<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C
M<FEP="(*;7-G<W1R("+AGJ+AGH#AGY+AGI_AGIKB@(OAGH_AGKSAGH7B@(OA
MGH#AGY+AGIKAGX3AGI@B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`T"B,Z
M(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`BX9Z'X9^$
MX9Z"X9Z'X9^0X9Z9(@H*(SH@861M:6XO=7-E<BYP:'`Z.#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T:&4@
M<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F
M;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z
M-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB
M(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O
M;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C4W"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@7"(E<UPB(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W
M<F]T92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=61A
M;B(*;7-G<W1R("+AGI_AGXKAGKSAGHKAGH3AGXLB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"FUS9VED(")3
M=6UM87)Y(@IM<V=S='(@(N&>G^&>A.&?DN&>@>&?@>&>E"(*"B,Z(&QI8B]"
M;&]C:R]S=6YR:7-E+G!H<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8P"FUS9VED(")3=6YN>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$P"FUS9VED(")3=6YR:7-E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P.0IM<V=I9"`B
M4W5N<FES93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,3,*;7-G:60@(E-U;G-E="(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$R"FUS9VED(")3=6YS970Z("(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$S"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R("+AGJ+AGH#A
MGY+AGI_AGIKB@(OAGH_AGKSAGH7B@(OAGIOAGKXB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,SDT"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(N&>
M@N&>MN&?AN&>D>&?DN&>FB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C$U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-U<FEN
M86UE(@IM<V=S='(@(N&>G^&?BN&>O.&>FN&>N.&>CN&>MN&>F.&>N"(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<U"FUS9VED(")3
M=7)N86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-V86QB
M87)D(&%N9"!*86X@36%Y96XB"FUS9W-T<B`BX9Z?X9^2X9Z<X9ZVX9Z;X9^+
MX9Z4X9ZVX9Z/(.&>D^&>M^&>A"#AGJ#AGY+AGI_AGH3AGXOAGICAGXGAGK;A
MGIGAGX'AGI,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA;F0B"FUS
M9W-T<B`BX9Z?X9^2X9Z<X9ZVX9Z@X9^2X9Z?X9^*X9ZXX9ZAX9Z$X9^+(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM<V=S='(@(N&>G^&?BN&>
MN^&>F>&>HN&?@N&>BB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")3=VET>F5R;&%N
M9"(*;7-G<W1R("+AGI_AGY+AGISAGXKAGKCAGI\B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HX-@IM<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30U"FUS9VED
M(")3>6YC34PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y
M=V]R9',N<&AP.CDW"FUS9VED(")3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E
M<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-Y<FEA;B!!
M<F%B(%)E<'5B;&EC(@IM<V=S='(@(N&>G^&>MN&>DN&>MN&>FN&>CN&>FN&>
MBN&?DN&>B^*`B^&>HN&>MN&>FN&?B>&>MN&>E.&?BR#AGI_AGXKAGKCAGIKA
MGK@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M,0IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B5"U3=&]R;2!A;F0@
M5VEN9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C,*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED
M(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T
M82]$871A+W1S=BYP:'`Z,38V"FUS9VED(")44U8@9FEL92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5&%B;&4N<&AP.C$S-`IM<V=I9"`B5&%B
M;&4B"FUS9W-T<B`BX9Z/X9ZVX9Z:X9ZVX9Z$(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B5&%B
M;&4@4')O<&5R=&EE<R(*;7-G<W1R("+AGIOAGH#AGY+AGH'AGH[AGXCB@(OA
MGI_AGICAGY+AGI3AGH_AGY+AGH_AGK?B@(OAGH_AGK;AGIKAGK;AGH0B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W"FUS
M9VED(")486)L92!3970B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@
M<')O<&5R=&EE<R(*;7-G<W1R("+AGIOAGH#AGY+AGH'AGH[AGXCB@(OAGI_A
MGICAGY+AGI3AGH_AGY+AGH_AGK?B@(OAGIKAGI3AGI_AGXOB@(OB@(OAGH_A
MGK;AGIKAGK;AGH0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")486EW
M86XB"FUS9W-T<B`BX9Z/X9^#X9Z<X9^)X9ZVX9Z3X9^+(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@
M4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM
M<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R("+AGH_AGK;AGHKAGJ#AGY+AGI_A
MGXKAGKCAGH+AGKCAGI_AGY+AGH_AGH3AGXLB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS
M9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.34*
M;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VAO;VMS+G!H
M<"YD:7-T.C$P-S`@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y-@IM<V=I
M9"`B5&%S:W,B"FUS9W-T<B`BX9Z7X9ZVX9Z:X9Z`X9ZWX9Z%X9^2X9Z%(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S0*;7-G:60@
M(E1E;&5P:&]N92!.=6UB97(B"FUS9W-T<B`BX9Z;X9^!X9Z!XH"+X9Z1X9Z\
MX9Z:X9Z?X9^0X9Z6X9^2X9Z1(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,#(*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C(V"FUS9VED(")496UP97)A='5R92(*
M;7-G<W1R("+AGI_AGKCAGH_AGKOAGH[AGY+AGJ#AGI?AGK;AGI8B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$W"FUS9VED(")496UP97)A
M='5R93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&5R871U<F4\8G(@
M+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C8Y-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")496UP;&%T92!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I9"`B5&5M<&QA=&4@
M061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(Q-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,X"FUS
M9VED(")497AT(@IM<V=S='(@(N&>HN&>C^&?DN&>D.&>E.&>D2(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-SD*;7-G:60@(E1E>'0@3VYL>2(*;7-G
M<W1R("+AGH_AGX+AGJ+AGH_AGY+AGI#AGI3AGI$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<T"FUS9VED(")4
M97AT(&%L:6=N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU
M.0IM<V=I9"`B5&@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#<*;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#D*;7-G:60@(E1H86EL86YD(@IM<V=S='(@(N&>D.&?@R(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#4Q"FUS9VED(")4:&4@1E10
M(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&ES=&]R>2](:7-T;W)Y+G!H<#HV,PIM<V=I9"`B5&AE($AI
M<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T
M('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M24U34"])35-0+T)O;VLN<&AP.C$R.3@*;7-G:60@(E1H92!)35-0(&QO9R!C
M;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E
M.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED
M(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.#D@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,#`*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HR,3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,C,*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,S0@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HR-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HR-C0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,#,*;7-G:60@(B(*
M(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA
M;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S
M92!097)M:7-S:6]N<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O
M='1O;2!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C
M;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N
M:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C4Q"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D
M('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3<R"FUS9VED("(B"B)4:&4@9&5T
M86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I
M9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B
M(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P
M96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A
M=&%B87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO
M;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]C;VYF:7)M+G!H<#HR.`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&4@96UA:6P@861D<F5S<R`E<R!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R(&ED
M96YT:71I97,N(%EO=2!C86X@8VQO<V4@=&AI<R`B"B)W:6YD;W<@;F]W+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q-@IM
M<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R
M92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ-S<@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU
M,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O
M;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$W,"!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C4R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@
M8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,CD*;7-G:60@(E1H92!F:6QE(&-A
M;FYO="!B92!C;W!I960@;VYT;R!I='-E;&8N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]$871A+T1A=&$N<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N
M=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I
M;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE
M<W-A9V4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C<F5E;B!M
M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@
M17AP;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E
M;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E
M("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS
M(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S
M>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U
M)VQL(&=E="!A("='96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N
M965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L
M96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE
M(&9U;&P@<V-R965N(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<')E9G,N<&AP.C$R,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I
M='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*
M;7-G:60@(E1H92!L969T+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$U-PIM<V=I9"`B(@HB
M5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E
M;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O341.+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U
M8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@
M;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O
M<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#@U"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK
M:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<')E9G,N<&AP.CDT"FUS9VED(")4:&4@;F5W(&9R;VT@861D<F5S<R!C
M86XG="!B92!V97)I9FEE9"P@=')Y(&%G86EN(&QA=&5R.B`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#<T"FUS9VED(")4
M:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(S,@IM
M<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@
M2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+G!H<#HR.#,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S879E
M9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M87AI;75M(&%L
M;&]W86)L92!S:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H
M)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#@W"FUS9VED(")4:&4@
M<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A;F0@;&5F="!S
M:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H="UH
M86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HT-SD*;7-G:60@(E1H92!S97!A<F%T;W(@;75S="!B92!O
M;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E
M;6]V960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70O36%N86=E<BYP:'`Z,S(R"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!S<&5C:69I960@<F]W("@E9"D@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C`R"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!T96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N
M;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,S,3,*;7-G:60@(E1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@
M;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@
M=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E
M<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]C<W8N<&AP
M.C(V,B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,3<R"FUS9VED(")4
M:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-"!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$U"FUS9VED(")4:&4@=V5A=&AE<BYC
M;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O8V]N9FER;2YP:'`Z,3<@<V5R=FEC97,O8V]N9FER;2YP
M:'`Z,C$*;7-G:60@(E1H97)E(&%R92!N;R!E;6%I;"!A9&1R97-S97,@=&\@
M8V]N9FER;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HQ-S@*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL
M86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT
M96YT<RYP:'`Z,S0U"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C
M86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,30P.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD
M+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[("(*(GEO=2!M=7-T
M(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H
M<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E
M;3H@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@
M9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T
M<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R;VT@
M=&AE('-Y<W1E;3H@(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('5P
M9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R
M;W=S97(O0G)O=W-E<BYP:'`Z.3$P"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S
M('=A<R!U<&QO861E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S
M97(O0G)O=W-E<BYP:'`Z.3$U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E
M<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE
M("@E9"!B>71E<RDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R
M+T)R;W=S97(N<&AP.CDQ-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R
M92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@
M=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@
M<&%R="(*;7-G<W1R("+AGICAGK;AGI/B@(OAGH#AGX;AGJ#AGKOAGI_B@(OA
MGICAGKWAGID@X9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z`X9ZVX9Z:XH"+X9Z4X9Z$
MX9^2X9Z@X9ZVX9Z)XH"+X9Z5X9^2X9Z3X9^"X9Z`XH"+X9Z:X9Z4X9Z?X9^+
MXH"+X9Z?X9ZVX9Z:XH"+X9Z3X9^!X9^'(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1&%T82]$871A+VEM8RYP:'`Z,S$*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C@R"FUS9VED
M("(B"B)4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@
M9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O
M<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T
M:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T
M,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C
M;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,C(R"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@
M=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HQ-#@*;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@
M<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*;7-G:60@(E1H:7,@
M9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L
M:60@>FEP(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,Q,S@*;7-G:60@(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A
M('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*;7-G:60@(B(*
M(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U
M9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED("(B
M"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O
M=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y+"!U
M<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G:60@(B(*(E1H
M:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@
M=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W
M87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-0IM<V=I
M9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@
M=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@(@HB9V%T97=A
M>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E
M;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D869O;F4@271A;'D@*&AT='`Z+R]W
M=W<N,3DP+FET*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.3@R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C$*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`Y,"!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,3$Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#8@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(V,`HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,S`Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,#8*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34V-2!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#0W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C8@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`Q,PHC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,#,W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P.#8*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U-R!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C(Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T
M,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U.`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-C0X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S,"!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,S`X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,X,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@R-`IM<V=I9"`B5&AI
M<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3`V.0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL
M>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-#(T"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DX"FUS9VED(")4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(W"FUS9VED(")4:&ES
M(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES
M="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HY.3,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED
M(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C@R.0IM<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C
M;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@
M(@HB)R,Q,C,T868G+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HU-C4*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B965N
M('!R;V-E<W-E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O
M=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R
M92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A
M;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@
M1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*
M(F-L:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T
M97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H
M:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G
M:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP
M(&9I;&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M4F5G:7-T<GDN<&AP.C$X,@IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N
M=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E
M(&$@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L
M;W)P:6-K97(N<&AP.C,U"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A
M;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")4
M:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR-3`*;7-G:60@(E1I8VME=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C0S,R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-34*;7-G:60@(E1I;64B"FUS9W-T<B`BX9Z6X9^!X9Z;XH"+X9Z<X9^!
MX9Z;X9ZVXH"+(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P,@IM
M<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=&EM92YP:'`Z,C(*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(N&>D>&?
MDN&>FN&>A.&?B^*`B^&>D>&?DN&>FN&>MN&>F>*`B^*`B^*`B^*`B^&>EN&?
M@>&>F^*`B^*`B^&>G.&?@>&>F^&>MN*`BR(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(U,SD*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR
M,CD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S
M='(@(N&>A>&?AN&>CN&>A.*`B^&>A^&>ON&>A"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT
M;V]L=&EP*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`BX9Z1X9^%
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U
M,@IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O
M=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W
M:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,P,PIM<V=I9"`B5&]D87DB"FUS9W-T<B`BX9Z0X9^2
MX9Z$X9^#XH"+X9Z3X9^!X9^'(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1O9V\B"FUS9W-T
M<B`BX9Z/X9Z\X9Z@X9^2X9Z"X9^$(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B
M5&]K96QA=2(*;7-G<W1R("+AGH_AGKSAGH#AGX'AGJ'AGK;AGJ+AGXKAGKPB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`U"FUS9VED(")4
M;VUO<G)O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VYG
M82(*;7-G<W1R("+AGH_AGKOAGH3AGJ#AGY+AGH+AGX0B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Q"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S<*;7-G:60@
M(E1O<"(*;7-G<W1R("+AGH#AGX;AGI;AGKSAGILB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A
M;64@*%]T;W`I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV.`IM<V=I9"`B5')A;G-L871I;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`BX9Z1
MX9^2X9Z:X9ZXX9Z3X9ZXX9Z*X9ZVX9Z*(.&>D^&>M^&>A.*`B^*`BR#AGH_A
MGKSAGI3AGK;AGJ#AGY+AGH+AGX0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-SDX"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3<*;7-G
M:60@(E1U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U;FES
M:6$B"FUS9W-T<B`BX9Z1X9Z[X9Z9X9Z.X9^!X9Z?X9^*X9ZX(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(N&>D>&>O>&>FN&>@N&>
MN"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED(")4=7)K:7-H
M("A)4T\M.#@U.2TY*2(*;7-G<W1R("+AGI'AGKWAGIKAGH+AGK@@*$E33RTX
M.#4Y+3DI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES=&%N(@IM
M<V=S='(@(N&>D>&>O>&>@N&>F.&?@>&>D^&>N.&>G^&?DN&>C^&>A.&?BR(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD
M<R(*;7-G<W1R("+AGH#AGX3AGX?B@(OAGI'AGKWAGH`@X9Z3X9ZWX9Z$XH"+
M(.&>@.&?@^&>@.&>O.&>GR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U=F%L
M=2(*;7-G<W1R("+AGI'AGKOAGIGAGISAGXGAGK;AGIOAGKOAGIDB"@HC.B!F
M<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO
M:6-E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(V,PIM<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB+T)L
M;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@(E523"(*;7-G<W1R(")54DPB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T
M,0IM<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@
M<F5P;W)T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.3<*;7-G:60@(E523#HB"FUS9W-T<B`B55),.B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5G86YD82(*;7-G<W1R("+AGJ+AGXKA
MGKSAGJ#AGY+AGH+AGH3AGXOAGHKAGK8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED
M(")5:W)A:6YE(@IM<V=S='(@(N&>HN&?BN&>N^&>F>&>@.&?DN&>FN&?@N&>
MDR(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0R,@IM<V=I9"`B
M56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Y,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,SDU(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-C@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S
M:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HW.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8Y."!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C$P-C,*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C@U,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-S`*;7-G:60@(E5N86)L
M92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR,S4@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C0P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR
M,#0@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P.0HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C$W"FUS9VED(")5;F%B;&4@
M=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HS-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S8T(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C(V-`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER
M96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,3(T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Y,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD
M97(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HR-S4*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93
M(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]T87(N<&AP.C<V"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]G>FEP+G!H<#HW.0IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T
M82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR
M,C@@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,#,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O
M<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C<X(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-#$@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HT,3@*(SH@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C,Q,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,S0R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L
M('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-38@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,V,`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-#<@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C,R,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,S,U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,U,@IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0T,R!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C0U-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C(Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S$S(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,S$T"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HQ-C<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X,`HC.B!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@W(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HS.3$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C,Y.0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR
M-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HT,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S-`IM<V=I9"`B56YA8FQE('1O
M(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,#0*;7-G:60@(E5N
M86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`N<&AP.C0S-R!F<F%M97=O
M<FLO3F5T7TE-4U`O24U34"]!=71H+G!H<#HQ,C,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P-B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,3$*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C$W-"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,3<Y"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HY,R!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C$P-@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C8U,B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.CDX
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C@W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S@*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$T,0IM<V=I9"`B
M56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C@Q(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C@V"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C$T,"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S8*
M;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C0U"FUS9VED
M(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-38*;7-G:60@(E5N86)L
M92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX.#<*;7-G:60@(E5N
M86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S
M:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`IM<V=I9"`B56YA8FQE('1O(')E860@
M9FEL93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C8W.0IM<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER
M96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C$Q,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M
M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HS,#$*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS-34*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER
M96-T;W)Y.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HR-S$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-#@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C8R,"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C(Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O
M)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M,S0Y(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,3,*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C0U,B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,CDS"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HS,#D*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F
M<R<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI
M<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,34T(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,34W
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL
M92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C$X.0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC
M;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,CDQ(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ-#8*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$U,0IM
M<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-C(*;7-G:60@(E5N86)L
M92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(N&>@N&>O.&>
MG^*`B^&>E.&>D^&?DN&>D>&>MN&>C^&?B^*`B^&>@.&?DN&>FN&?A.&>F"(*
M"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA
M;F=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HR,C,*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,SDP"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R
M=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0Q"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W.`HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS.#0*;7-G:60@(E5N97AP96-T960@<F5S
M<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV,0IM<V=I9"`B
M56YF:6QE9"(*;7-G<W1R("+AGICAGK?AGI/B@(OAGI3AGK;AGI/B@(OAGIKA
MGX#AGI3AGH7AGX8B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM<V=I
M9"`B56YI8V]D92`H551&+3@I(@IM<V=S='(@(N&>F>&>O.&>D^&>N.&>@.&>
MO.&>BB`H551&+3@I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(E5N:71E9"!!<F%B
M($5M:7)A=&5S(@IM<V=S='(@(N&>HN&>MN&>FN&?B>&>MN&>E.&?B^*`B^&>
MFN&>O>&>F"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI;F=D;VTB
M"FUS9W-T<B`BX9Z%X9Z`X9^2X9Z:XH"+X9Z7X9Z6XH"+X9ZBX9Z$X9^+X9Z"
MX9^2X9Z;X9^!X9Z?(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T
M871E<R(*;7-G<W1R("+AGI_AGJ#AGIKAGHKAGY+AGHOAGJ+AGK;AGICAGX'A
MGIKAGK?AGH`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S
M($UI;F]R($]U=&QY:6YG($ES;&%N9',B"FUS9W-T<B`BX9Z`X9^$X9^'XH"+
MX9Z&X9^2X9Z$X9ZVX9Z9X9^7XH"+X9Z:X9Z4X9Z?X9^+XH"+X9Z?X9Z@X9Z:
MX9Z*X9^2X9Z+XH"+X9ZBX9ZVX9Z8X9^!X9Z:X9ZWX9Z`(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C8W(&QI8B]";&]C:R]M971A<BYP:'`Z
M.#,*;7-G:60@(E5N:71S(@IM<V=S='(@(N&>K^&>@.&>C^&>MB(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R.2!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,S`*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HU.`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R("+AGICA
MGK?AGI/B@(OAGI_AGY+AGH+AGK;AGIOAGXLB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO
M=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY
M"FUS9VED(")5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-3(*;7-G:60@(E5N:VYO=VX@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@
M96QE;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E
M;G1I='DN<&AP.C,P,@IM<V=I9"`B56YN86UE9"(*;7-G<W1R("+AGH+AGY+A
MGICAGK;AGI/B@(OAGHCAGY+AGICAGX3AGX<B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I
M;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R
M;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K
M($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H
M:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C
M97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N
M<V5T(&-O;&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C@W(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z.3(W"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3,S
M"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ.3<@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P9&%T92(*;7-G<W1R("+A
MGI+AGY+AGISAGK[B@(OAGK+AGY+AGIGB@(OAGI'AGK;AGI/AGXOB@(OAGI_A
MGICAGY#AGIDB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"FUS9VED
M(")5<&1A=&4@=7-E<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C$T-"!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC97,O<VAA<F5S
M+V5D:70N<&AP.C(S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S@@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y.`IM<V=I9"`B57!L;V%D(@IM<V=S
M='(@(N&>E>&?DN&>D>&>N^&>@.*`B^&>H>&>ON&>A"(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ.#8*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A
M=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C(P"FUS9VED(")5<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA
M;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R("+AGJ+A
MGXKAGKOAGIGAGIKAGXGAGK;AGJ#AGY+AGH+AGK;AGIDB"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*
M;7-G:60@(E5S92!34TPB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$R-PIM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF
M9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,0IM<V=I9"`B57-E<B(*;7-G
M<W1R("+AGJ+AGY+AGI/AGH#B@(OAGI3AGY+AGIKAGKXB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<V-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S"FUS9VED(")5<V5R($%D
M;6EN:7-T<F%T:6]N(@IM<V=S='(@(N&>@.&>MN&>FN*`B^&>@N&?DN&>FN&>
ME.&?B^&>@N&?DN&>FN&>A.*`B^&>HN&?DN&>D^&>@.*`B^&>E.&?DN&>FN&>
MOB(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C0U"FUS9VED
M(")5<V5R($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HV,@IM
M<V=I9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P
M+G!H<#HR,@IM<V=I9"`B57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES
M86)L960@9F]R('1H:7,@<VET92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C0V.0IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N
M9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.CDX"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C$U,"!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HS,PHC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C8T('1E
M;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R
M;F%M92(*;7-G<W1R("+AGHCAGY+AGICAGX3AGX?B@(OAGJ+AGY+AGI/AGH#B
M@(OAGI3AGY+AGIKAGKXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU
M<"YP:'`Z,3(U"B,L('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<
M(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C@W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B
MX9Z(X9^2X9Z8X9^$X9^'XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z4X9^2X9Z:X9Z^
MPJ#AGY8B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"FUS9VED
M(")5<V5R;F%M93H@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS
M9W-T<B`BX9ZBX9^*X9Z\X9Z@X9^2X9Z?X9Z4X9^!X9Z"X9ZXX9Z?X9^2X9Z/
MX9Z$X9^+(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3<S(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(V-0IM<V=I9"`B5D93(&1I<F5C
M=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$R-PIM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#<P"FUS9VED(")686QI
M9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(")686QI
M9&ET>2(*;7-G<W1R("+AGI_AGKOAGI;AGIOAGI?AGK;AGI8B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*
M;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@V,"!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,3@Q"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E(&ES
M(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C4R(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(R-S0*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,R
M-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(Q"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3D*;7-G:60@(E9A;'5E<R(*
M;7-G<W1R("+AGH_AGICAGY+AGIOAGX,B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,3$W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.30*;7-G
M:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$W"FUS9VED(")686YU871U(@IM<V=S='(@(N&>G.&?B>&>MN&>D^&>
MN^&>F>&>HN&>MN&>D>&>N^&>F2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,S@*;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@(N&>HN&>D.&?
M@>&>FB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R
M("+AGISAGX'AGH[AGX'AGJ#AGY+AGI_AGKOAGIGAGJ+AGX'AGJ'AGK8B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I9"`B
M5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B
M965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-S`Q"FUS9VED(")697)S:6]N(@IM<V=S
M='(@(N&>@.&?AN&>CN&?@B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR-#(*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R("+AGH#AGK;A
MGIKB@(OAGH_AGY+AGIKAGKWAGH_B@(OAGI;AGK?AGI/AGK?AGH_AGY+AGIGB
M@(OAGH#AGX;AGH[AGX(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A;&EG;B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*
M;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B5F5R>2!(:6=H(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I970@3F%M(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")6:65T
M;F%M97-E("A625-#24DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.CDW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")6
M:65W("5S(@IM<V=S='(@(N&>F.&>ON&>FR`E<R(*"B,Z(&QI8B]";&]C:R]I
M9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z.#(W"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L($)R
M:71I<V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN
M($ES;&%N9',L(%4N4RXB"FUS9W-T<B`BX9Z`X9^$X9^'XH"+X9Z<X9ZXX9Z'
MX9ZXX9Z3(.&>G^&>H.&>FN&>BN&?DN&>B^*`B^&>HN&>MN&>F.&?@>&>FN&>
MM^&>@"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(Q"FUS9VED(")6:7-I
M8FEL:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-3<*;7-G:60@(E9I<VEB:6QI='DZ("(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX
M-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HQ,S,*;7-G:60@(E=)3B!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$W"FUS9VED(")786QL:7,@86YD($9U='5N82(*;7-G<W1R("+A
MGISAGXGAGK;AGIOAGKCAGI\@X9Z3X9ZWX9Z$(.&>H.&?DN&>G.&?BN&>O.*`
MB^&>D>&>N^&>F>&>CN&>MB(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,3(T(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HX,PIM<V=I9"`B5V%R;FEN9R(*;7-G<W1R("+AGI;AGY+A
MGIKAGICAGK;AGI,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0*;7-G:60@(E=E871H97(@1F]R96-A
M<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C0Q.0IM<V=I9"`B5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-@IM<V=I9"`B5V5A
M=&AE<BYC;VTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M,S8*;7-G:60@(E=E8B(*;7-G<W1R("+AGISAGK?AGI0B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#4S"FUS9VED(")796(@4VET92(*;7-G<W1R
M("+AGH_AGX;AGI3AGI/AGXOAGI3AGH[AGY+AGH_AGK;AGHDB"@HC.B!F<F%M
M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4X"FUS9VED(")7
M965K;'DB"FUS9W-T<B`BX9Z:X9ZVX9Z;X9^+XH"+X9Z?X9Z4X9^2X9Z*X9ZV
MX9Z@X9^-(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*;7-G
M:60@(E=E;&-O;64B"FUS9W-T<B`BX9Z?X9Z\X9Z8XH"+X9Z?X9^2X9Z<X9ZV
MX9Z"X9Z8X9Z3X9^-(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z
M-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W"B,L('!H<"UF;W)M870*
M;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`BX9Z?X9Z\X9Z8XH"+X9Z?
MX9^2X9Z<X9ZVX9Z"X9Z8X9Z3X9^-XH"+X9Z8X9Z`XH"+X9Z`X9ZVX9Z3X9^+
M("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA
M=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E
M;&-O;64L("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DQ"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,@IM<V=I9"`B5V5S=&5R;B`H25-/
M+3@X-3DM,34I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")797-T
M97)N(%-A:&%R82(*;7-G<W1R("+AGI_AGK;AGJ#AGK;AGIKAGXGAGK;B@(OA
MGH'AGK;AGH3B@(OAGIOAGK?AGH4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#0Q"B,L('!H<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC871I;VX@
M<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T(&ES
M('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@
M<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V,@IM<V=I9"`B5VAE<F5I<R!!
M=7-T<F%L:6$@;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,S8*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@
M96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`BX9Z1X9Z1X9ZYX9Z$XH"+(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q.`IM<V=I9"`B5VED=&@@
M:6X@0U-3('5N:71S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S
M(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI
M;BDZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,3`*;7-G:60@(E=I9'1H('5N:70B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@
M(E=I9'1H.B(*;7-G<W1R("+AGI'AGI'AGKGAGH0@X9^6(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C4R.0IM<V=I9"`B5VEK:2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDS(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V"FUS9VED(")7:6YD(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8W"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z.3(*;7-G:60@(E=I;F0@<W!E960@:6X@:VYO=',B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C@*;7-G:60@
M(E=I;F0Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,S8*;7-G:60@(E=I;F0Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-CD*;7-G:60@(E=I<V1O;2(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C$R"FUS9VED(")7:7-H;&ES
M="(*;7-G<W1R("+AGI3AGHGAGY+AGH?AGKCB@(OAGI3AGY+AGIKAGK;AGI#A
MGY+AGI/AGK8B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-S`*;7-G:60@
M(E=O<FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`B
MX9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3XH"+X9Z`X9Z3X9^2X9Z;X9^"
MX9Z$XH"+X9Z2X9^2X9Z<X9Z^XH"+X9Z`X9ZVX9Z:(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0
M:&]N92(*;7-G<W1R("+AGI'AGKSAGIKAGI_AGY#AGI;AGY+AGI'B@(OB@(OB
M@(OAGH#AGI/AGY+AGIOAGX+AGH3B@(OB@(OB@(OAGI+AGY+AGISAGK[AGH#A
MGK;AGIHB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ.3,@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G
M:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T
M960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HS,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@
M;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,C0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I
M;F<@82!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(U.0IM<V=I9"`B6"U2968B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV
M,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S($5X=&5N
M9&5D($ME>2!5<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U8FIE8W0@06QT
M97)N871I=F4@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y
M($ED96YT:69I97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV.#,*;7-G:60@(E@U,#EV,R!E>'1E;G-I;VYS(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")962(*
M;7-G<W1R(")962(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0U-`IM<V=I9"`B65E962(*;7-G<W1R(")965E9(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,#D*;7-G:60@
M(EEA:&]O(2!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA
M;F-E+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@
M(N&>E.&?DN&>FN&>A>&>MN&?AN&>AN&?DN&>D^&>MN&?AB(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3<*;7-G:60@(EEE;65N(@IM<V=S='(@(N&>F>&?@>&>F.&?@N&>DR(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C0*
M;7-G:60@(EEE<R(*;7-G<W1R("+AGI3AGK;AGI$OX9Z%X9ZVX9Z?(@H*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G
M:60@(EEE<RP@22!!9W)E92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R"FUS9VED(")9;W4@87)E(&EN
M(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A
M8VL@=&\@5UE325=91RXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+V5D:70N<&AP.C@Q"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T
M(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,30R-0IM<V=I
M9"`B66]U(&%R92!N;W0@875T:&5N=&EC871E9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS,#@*;7-G:60@(EEO
M=2!C86YN;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL
M(&YA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+W!H<&=W
M+G!H<#HQ,3<*;7-G:60@(EEO=2!D:60@;F]T(&%U=&AE;G1I8V%T92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V,R!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3@S"FUS9VED(")9;W4@9&ED(&YO="!E
M;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]$871A+T1A=&$N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R
M=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#<*
M;7-G:60@(EEO=2!H879E(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS-S$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB66]U(&AA=F4@<F5Q=65S=&5D('1O(&%D9"!T
M:&4@96UA:6P@861D<F5S<R!<(B5S7"(@=&\@=&AE(&QI<W0@;V8@>6]U<B`B
M"B)P97)S;VYA;"!E;6%I;"!A9&1R97-S97,N7&XB"B)<;B(*(D=O('1O('1H
M92!F;VQL;W=I;F<@;&EN:R!T;R!C;VYF:7)M('1H870@=&AI<R!I<R!R96%L
M;'D@>6]U<B!A9&1R97-S.EQN(@HB)7-<;B(*(EQN(@HB268@>6]U(&1O;B=T
M(&MN;W<@=VAA="!T:&ES(&UE<W-A9V4@;65A;G,L('EO=2!C86X@9&5L971E
M(&ET+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C8U"FUS9VED("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP
M:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG
M("(*(F9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Y,@IM<V=I
M9"`B66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C,W"FUS9VED
M(")9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S
M92!3:6=N=7!S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C0W-`IM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A
M8VME;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE
M;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY.`IM<V=I9"`B66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T
M:&ES(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@
M<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$Q.0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE
M('1O(&-L96%R(&]U="XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,3`P"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M
M;W9E+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P
M96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`B(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U
M<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S.`IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW
M,0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I
M=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B66]U(&YE960@=&\@<')O=FED92!A
M;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+G!H<#HY-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U
M<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C,X"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q-0IM<V=I9"`B66]U<B!&<F]M.B!A
M9&1R97-S.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-C<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<W(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(*;7-G:60@(EEO
M=7(@26YF;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z.3<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT
M97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG
M(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R
M:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*;7-G:60@(EEO=7(@3F%M
M92(*;7-G<W1R("+AGHCAGY+AGICAGX3AGX?B@(OAGIKAGI3AGI_AGXOAGJ+A
MGY+AGI/AGH`B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z
M-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@
M;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R`B"B)U
M<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S
M="!U<V4@82!D:69F97)E;G0@(@HB875T:&5N=&EC871I;VX@8F%C:V5N9"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN
M8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E
M<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B
M"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX,PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H
M879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E
M<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@
M;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N
M<&AP.C4U"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T
M:&ES(&9E871U<F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+W!R:6YT+FIS.C0R"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N
M;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#
M;VUM86YD("L@4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(V,0IM<V=I9"`B66]U<B!C=7)R96YT('1I;64@
M>F]N93HB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C$R-@IM
M<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-C$*;7-G
M:60@(EEO=7(@9&5F875L="!I9&5N=&ET>3HB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(P-`IM<V=I9"`B66]U<B!F=6QL(&YA;64Z
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY.0IM
M<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-`IM<V=I
M9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R
M871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS
M(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@
M8F5E;B!R97-E="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R
M97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N
M97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.C<S,PIM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP:7)E
M9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C4X"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-"!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S='(@
M(N&>F>&>O.&>H.&?DN&>@N&?A.&>G^&?DN&>F^&>MN&>G.&>N"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM
M<V=S='(@(N&>G^&?@R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I82(*
M;7-G<W1R("+AGJ#AGY+AGI_AGK;AGX;AGI3AGXKAGK@B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$X"FUS9VED(")::6UB86)W92(*;7-G<W1R("+AGJ#AGY+AGI_AGXKAGKCA
MGICAGI3AGK;AGISAGXGAGX$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-S$*;7-G:60@(EII<'!Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT
M7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S0*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(
M:61E(%%U;W1E9"!497AT72(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F]B
M;&5M+G!H<#HX.0IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM
M<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z
M,3<T"B,L('!H<"UF;W)M870*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("T@
M)7,@;&EN97-=(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,3DU"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F("5S
M72(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U
M-C$@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHQ,0IM<V=I9"`B7T%D;6EN
M:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I
M9"`B7T-,22(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#$*;7-G:60@
M(E]$871A5')E92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*;7-G:60@(E]$96QE=&4@
M4F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$S,PIM<V=I9"`B7T=R
M;W5P<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N
M=2YP:'`Z,3<U"FUS9VED(")?2&5L<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G
M:60@(E]);6%G92!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.30*;7-G:60@(E],;V<@:6XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP
M.C$Y,`IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`B7TSAGH7AGX'AGHD@(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(T"FUS9VED(")?36]D:69Y($QI;FLN+BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V-`IM<V=I9"`B7T]P
M=&EO;G,B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?
M4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V"FUS9VED(")?4F5M;W9E
M($QI;FLN+BXB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3(U"FUS9VED
M(")?4V5T=7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED(")?5&%B;&4@4')O
M<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,CD*;7-G
M:60@(E]5<V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDR,`IM<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,T"FUS9VED(")A
M9&1R97-S964@=6YK;F]W;B(*;7-G<W1R("+AGICAGK?AGI/B@(OAGI_AGY+A
MGH+AGK;AGIOAGXOB@(OAGJ+AGY+AGI/AGH#B@(OAGI'AGI'AGKWAGIOB@(OA
MGI_AGX;AGI3AGKOAGH_AGY+AGIHB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDQ,@IM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ.#0@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-S`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N;F]T
M(&-R96%T92!O=71P=70@9FEL92(*;7-G<W1R("+AGICAGK?AGI/B@(OAGJ+A
MGK;AGH7B@(OAGI3AGH3AGY+AGH#AGK[AGH_B@(OAGJ_AGH#AGI_AGK;AGIKB
M@(OAGIOAGI'AGY+AGI+AGI7AGILB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B"FUS
M9W-T<B`BX9Z8X9ZWX9Z3XH"+X9ZBX9ZVX9Z%XH"+X9Z4X9Z^X9Z`XH"+X9Z6
MX9^0X9Z/X9^,X9Z8X9ZVX9Z3XH"+X9Z4X9Z)X9^2X9Z%X9Z\X9Z;(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DU"FUS9VED(")C
M;&EC:R!H97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R
M;W(B"FUS9W-T<B`BX9Z`X9^&X9Z@X9Z[X9Z?XH"+X9Z`X9ZVX9Z:XH"+X9Z4
MX9^2X9Z:X9Z^XH"+X9Z4X9Z3X9^2X9Z1X9ZVX9Z/X9^+XH"+X9Z6X9ZVX9Z`
MX9^2X9Z9X9Z4X9Z)X9^2X9Z'X9ZV(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-S@*;7-G:60@(F-O;F9I9W5R871I;VX@97)R;W(B
M"FUS9W-T<B`BX9Z`X9^&X9Z@X9Z[X9Z?XH"+X9Z`X9ZVX9Z:XH"+X9Z`X9^&
MX9Z.X9Z/X9^+XH"+X9Z:X9Z%X9Z3X9ZVX9Z?X9Z8X9^2X9Z6X9^0X9Z3X9^2
MX9Z2(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-30*
M;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B
MX9Z4X9ZVX9Z/X9^+XH"+X9ZOX9Z`X9Z?X9ZVX9Z:XH"+X9Z4X9^2X9Z:X9Z6
MX9^0X9Z3X9^2X9Z2XH"+X9Z?X9^&X9Z!X9ZVX9Z3X9^+XH"+X9Z4X9^&X9Z5
MX9Z[X9Z/(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M,C8*;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(N&>@.&?AN&>
MH.&>N^&>G^*`B^&>D>&?DN&>FN&>A.&?B^&>D>&?DN&>FN&>MN&>F>*`B^&>
MD>&>M^&>D^&?DN&>D^&>D^&?D.&>F2(*"B,Z('1E;7!L871E<R]P;W)T86PO
M961I="YI;F,Z,C@*;7-G:60@(F5D:70B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ.#(*;7-G:60@(F5N=')Y(&YO
M="!F;W5N9"(*;7-G<W1R("+AGIKAGH#B@(OAGICAGK?AGI/B@(OAGH/AGK[A
MGHGB@(OAGI+AGK;AGH_AGKOB@(OAGI3AGHGAGY+AGH7AGKSAGILB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,@IM<V=I9"`B
M9F%L;&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W
M<V5R+G!H<#HX.#$*;7-G:60@(F9I;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ.#8@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-S(@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B9G)O
M;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0T"FUS9VED(")G=7-T:6YG(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR-#@*;7-G:60@(F@Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HS-3<*;7-G:60@(FAH(@IM<V=S='(@
M(FAH(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S@*
M;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(N&>F.&>M^&>D^*`
MB^&>G^&?DN&>@N&>MN&>F^&?B^*`B^&>B.&?DN&>F.&?A.&?A^*`B^&>F.&?
MB>&>MN&>G^&?BN&>N.&>DR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E
M='5P+V1I9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G:60@(FEN
M<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R("+AGH#AGX;AGJ#AGKOAGI_B@(OA
MGI3AGHGAGY+AGH7AGX'AGHDOX9Z4X9Z)X9^2X9Z%X9Z\X9Z;(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN=&5R
M;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(N&>@.&?AN&>H.&>N^&>G^*`
MB^&>@.&>F.&?DN&>F.&>G.&>M^&>DN&>N.*`B^&>@>&>MN&>A.*`B^&>@.&?
MDN&>FN&?A2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS
M+FIS.C$S"FUS9VED(")L:6YE<UTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H
M<"UF;W)M870*;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M
M86MI;F<@25-/+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,S8X"FUS9VED(")M;2(*;7-G<W1R("+AGI@N
MX9Z8+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C@V('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S`*(SH@<V5R=FEC97,O<&]R
M=&%L+W-I9&5B87(N<&AP.C(T,0IM<V=I9"`B;F%M92(*;7-G<W1R("+AGHCA
MGY+AGICAGX3AGX<B"@HC.B!F<F%M97=O<FLO4E!#+U)00RYP:'`Z,3(T"FUS
M9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C(P"FUS9VED(")N;W0@>65T(&EM
M<&QE;65N=&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3`T"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G
M:60@(G!E<F-E;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-S0*;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM
M<V=S='(@(N&>G^&>M^&>D>&?DN&>DN&>M^*`B^&>C^&?DN&>FN&>O.&>G.*`
MB^&>E.&>MN&>D^*`B^&>E.&>BN&>M^&>G^&?@>&>DB(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@
M(G!I>&5L<R(*;7-G<W1R("+AGI?AGKCAGH#AGI_AGX+AGILB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I9"`B<F5M;W1E
M(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(N&>@.&?AN&>H.&>N^&>G^*`
MB^&>EN&>N.*`B^&>A>&>F.&?DN&>A.&>MN&>F>*`B^&>@.&?DN&>D^&>N^&>
MA.*`B^&>EN&>M^&>DN&>N.&>@.&>MN&>FB(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<T"FUS9VED(")R:7-I;F<B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#(*
M;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`BX9Z8X9ZWX9Z3
MXH"+X9ZBX9ZVX9Z%XH"+X9Z:X9Z`XH"+X9Z?X9^!X9Z<X9ZVXH"+X9Z4X9ZV
MX9Z3(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HQ,#(*;7-G:60@(G-H
M;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I
M;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,S@U"FUS9VED(")S<R(*;7-G<W1R(")S<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"FUS
M9VED(")S=&5A9'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R
M("+AGH#AGX;AGJ#AGKOAGI_B@(OAGI3AGY+AGIKAGI;AGY#AGI/AGY+AGI(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR.`IM<V=I9"`B=&%S
M:R!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,38V"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R
M("+AGI3AGIKAGK;AGH?AGY#AGIGB@(OAGI3AGH[AGY+AGHKAGX3AGX?AGJ+A
MGK;AGI_AGI/AGY+AGI,B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C<Q"FUS9VED(")T>7!E('1H92!P
M87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS
M9VED(")U;FEF:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+VAO<F1E+G!H<#HR-SD*;7-G:60@(G5N:VYO=VX@97)R;W(B"FUS9W-T<B`B
MX9Z8X9ZWX9Z3XH"+X9Z?X9^2X9Z"X9ZVX9Z;X9^+XH"+X9Z`X9^&X9Z@X9Z[
MX9Z?(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]087)T+G!H<#HR-PIM<V=I
M9"`B=6YN86UE9"(*;7-G<W1R("+AGH+AGY+AGICAGK;AGI/B@(OAGHCAGY+A
MGICAGX3AGX<B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS
M-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0P"FUS9VED(")W.B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I
M9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H`````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!O+VAE7TE,+G!O````````````````````````````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#8P,C`V-"`Q,#4Q-30S,S<T,R`P,3<U,#8`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````(R!(
M96)R97<@=')A;G-L871I;VYS(&9O<B!(;W)D92!P86-K86=E+@HC($-O<'ER
M:6=H="`H0RD@,C`P-B!-871T(%-E;'-K>2`\<V5L<VMY0&-O;'5M8FEA+F5D
M=3X*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@
M;&EC96YS92!A<R!T:&4@2&]R9&4@<&%C:V%G92X*(R!!=71O;6%T:6-A;&QY
M(&=E;F5R871E9"P@,C`P-BX*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE
M8W0M260M5F5R<VEO;CH@2&]R9&4@,RXR+6-V<UQN(@HB4F5P;W)T+4US9VED
M+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO
M;BU$871E.B`R,#`V+3`R+3`W(#`T.C`X+3`U,#!<;B(*(E!/+5)E=FES:6]N
M+41A=&4Z(#(P,#8M,#(M,#<@,#0Z,#@M,#4P,%QN(@HB3&%S="U4<F%N<VQA
M=&]R.B!-871T(%-E;'-K>2`\<V5L<VMY0&-O;'5M8FEA+F5D=3Y<;B(*(DQA
M;F=U86=E+51E86TZ(&DQ.&Y`;&ES=',N:&]R9&4N;W)G7&XB"B)-24U%+59E
M<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R
M<V5T/5541BTX7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET
M7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<W"B,L('!H<"UF
M;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,X-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN
M("5S(&1A>7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S.#$*;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(S.#,*;7-G:60@(B`H=&]M;W)R;W<I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-SD*;7-G
M:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C4P(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS-3,*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y.0IM<V=I
M9"`B(&%T("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C(Q,`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@
M9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP
M:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V
M86QI9"!C:&]I8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]296=I<W1R>2YP:'`Z-S`S"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]296=I<W1R>2YP:'`Z,3`W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S
M7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5')E92]4<F5E+G!H<#HQ-S$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O
M=6YD+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4U"B,L('!H
M<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE(&=R;W5P
M<R!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD
M+G!H<#HU,0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D
M('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z-3,@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C0Y
M"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-R96%T960Z
M("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"('5S960@;V8@)2XR9DU"(&%L
M;&]W960@*"4N,F8E)2DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(S,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A
M;F0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HR-C<@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4U-PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E
M<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(W.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C8X"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`U"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T,2!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HX-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@2T(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT
M96YT<RYP:'`Z.#,Y(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.C@T-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-0B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO
M;B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,P(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HR,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@4V5T=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3
M:6=N=7`N<&AP.C(V-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N(%5P
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE;G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.3`@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-#<*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HT,S0@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.#8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<Q(&QI8B]";&]C:R]M
M971A<BYP:'`Z,3<W(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Q"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S4W(&QI8B]";&]C:R]M971A<BYP:'`Z,S8S"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC
M92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92`B"B)B;W@@
M9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T
M:&ES('1I;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER960B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3,U"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDR,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S
M($%D9')E<W,@0F]O:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.CDQ,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N
M9&%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3`U"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO
M8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP
M.C$R,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M97-S86=E
M(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E
M(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED
M:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M-3<@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0P,@IM<V=I9"`B+"!G
M=7-T:6YG("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P
M,"!L:6(O0FQO8VLO;65T87(N<&AP.C(P-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(L(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L92!F
M<F]M("5S('1O("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HW-3`@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HR.30*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS
M-#@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`W-PHC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,3,V"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(U"FUS9VED("(Q,B!(;W5R
M($9O<FUA="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C0*
M;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C8Y"FUS9VED("(\4')E
M=FEO=7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,S$*
M;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI
M<R!B;&]C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ-C(*;7-G:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z
M-#(Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D$@;65S<V%G92!H87,@8F5E
M;B!S96YT('1O(%PB)7-<(B!T;R!V97)I9GD@=&AA="!T:&ES(&ES(')E86QL
M>2!Y;W5R("(*(F%D9')E<W,N(%1H92!N97<@96UA:6P@861D<F5S<R!I<R!A
M8W1I=F%T960@87,@<V]O;B!A<R!Y;W4@8V]N9FER;2!T:&ES("(*(FUE<W-A
M9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.CDS-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T
M;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V.`IM<V=I9"`B02!P=6)L:6,@4$=0
M(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3`Y.0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A
M("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$P,38*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL
M('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O('-I9VX@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4P-@IM<V=I9"`B(@HB02!P=6)L
M:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O
M34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N
M("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME
M>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0IM
M<V=I9"`B04T@0VQO=61S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!,:6=H="!286EN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$Q"FUS9VED(")!32!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED(")!32!3
M:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-
M+U!-(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*
M;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+VAE;'`O:6YD97@N<&AP.C4S"FUS9VED(")!8F]U="XN+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<T"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED
M9&QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL
M92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C,*;7-G
M:60@(D%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<X"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#D*;7-G:60@(D%C
M8V]U;G1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q"FUS9VED(")!
M9&0B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C(@861M:6XO
M9W)O=7!S+G!H<#HR,C,*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDX(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#:&EL9"!0
M97)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E
M>"YP:'`Z-S(*;7-G:60@(D%D9"!#;VYT96YT(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!9&0@2&5R93HB"FUS
M9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,38@861M:6XO9W)O=7!S
M+G!H<#HR,3<*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL
M9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!G<F]U
M<"!T;R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI
M;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,CD*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34X
M"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,S0*;7-G:60@(D%D9"!N97<@;65M8F5R
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.CDU
M"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S<Q"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@
M365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*;7-G:60@(D%D
M9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW.`IM<V=I9"`B061D('1O(&UY
M(&%D9')E<W,@8F]O:R(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS
M,`IM<V=I9"`B061D('5S97(B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP
M:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O
M('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG
M;G5P(&EN9F]R;6%T:6]N.B`B"B(E<RXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P
M+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@
M=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B061D
M:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-S,@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,30T.0IM<V=I9"`B061D<F5S<R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,30X"FUS9VED(")!9&1R97-S
M($)O;VLB"FUS9W-T<B`BUZ'7I->H(->;UZK7E=>1UY77JB(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4V"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT"FUS9VED(")!9&UI;FES
M=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED
M(")!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S4W"FUS9VED(")!9',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.`IM<V=I9"`B069G:&%N:7-T86XB"FUS9W-T<B`BUY#7I->2UZ#7F=>A
MUZK7GR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$*;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`BUY#7
MG->1UZ#7F=>4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW-`IM<V=I9"`B06QG97)I82(*;7-G<W1R
M("+7D-><UY+7J->9UY0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$V
M"FUS9VED(")!;&EG;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B
M06QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,C`W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G:60@(D%L
M;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z,S(@861M:6XO9W)O=7!S+G!H<#HR,C`*;7-G:60@(D%L;"!'
M<F]U<',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HY,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O9&%T871R964N<&AP.C<U
M"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I
M9"`B06QL(&9O=7(@<VED97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3@W.0IM<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S
M<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S<*
M;7-G:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN
M<&AP.C4Q.`IM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-@IM<V=I9"`B06QT97)N871E($E-
M4U`@3&]G:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4Q,0IM<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P,PIM<V=I9"`B06QT97)N
M871E($E-4U`@57-E<FYA;64B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z,S4*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R
M97-S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30Q"FUS
M9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C<*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z.34@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P
M96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$V,`IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-@IM<V=I9"`B06YD;W)R82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,`IM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S
M(%!R;WAY(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-0IM
M<V=I9"`B06YT87)C=&EC82(*;7-G<W1R("+7F=>1UZG7JN*`D]>0UZ#7F->0
MUZC7I]>8UYG7I]>4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.0IM<V=I9"`B06YT:6=U82!A;F0@
M0F%R8G5D82(*;7-G<W1R("(B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,S,@
M861M:6XO=&5M<&QA=&5S+G!H<#HW,PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO54DN<&AP.C4X('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL
M.C0*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O
M;E]B<F]W<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,30P"FUS9VED(")!
M<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O($-H:6QD(%-H
M87)E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R
M;W9E+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,SD@9G)A;65W;W)K+TU)
M344O34E-12]#;VYT96YT<RYP:'`Z.#0Q"FUS9VED(")!<'!R;WAI;6%T92!3
M:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8X"FUS9VED(")!<')I;"(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R
M-38I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-3D@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H
M<#HW.`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8V
M"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S<*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HV-0IM<V=I9"`B07)C:&EV92!.86UE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E
M9"YI;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO
M=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N
M:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W
M:7-H('1O(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(V"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B
MUY#7J->2UZ#7F->9UZ#7E"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(*;7-G:60@(D%R;65N:6$B
M"FUS9W-T<B`BUY#7J->>UZ#7F=>4(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#(*;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B07)T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,S`*;7-G:60@(D%R=6)A(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO
M;B!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,T"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!<VEA+U!A8VEF:6,@4F5G
M:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,CD*
M;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN
M=&5N86YC92!O<&5R871I;VYS/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3`V"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B
M"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW,PIM<V=I9"`B071T
M96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z,C@*;7-G:60@(D%T=&5M
M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@V"FUS9VED(")!='1E
M;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4R"FUS9VED(")!
M='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,PHC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q"FUS9VED(")!='1R
M:6)U=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,3$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR.0IM<V=I9"`B075S=')A;&EA(@IM<V=S='(@(M>0UY77H=>8UZC7
MG->9UY0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(X"FUS9VED(")!=7-T<FEA(@IM<V=S='(@(M>0
MUY77H=>8UZC7F=>4(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN
M<&AP.C,Q-@IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)U<RYP:'`Z,3,Q"FUS9VED(")!=71H7V-Y<G5S.B!"86-K
M96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(S-`IM
M<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V9T
M<"YP:'`Z-38*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT
M96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B
M;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]I;6%P+G!H<#HQ,#0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER
M960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C<S"FUS9VED(")!=71H7VMR
M8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,#$*;7-G
M:60@(D%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@
M9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HS-38*;7-G:60@(D%U=&A?;&1A<#H@4F5M
M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C
M=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.CDR"FUS9VED(")!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HS,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L
M9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C,X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD
M87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0Y.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0P
M-`IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P
M<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C8R"FUS9VED(")!=71H7VUC
M86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C@V"FUS9VED
M(")!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M9&UI;BYP:'`Z,3`V"FUS9VED(")!=71H96YT:6-A=&EO;B!A="!)34%0('-E
M<G9E<B!F86EL960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM<V=I9"`B075T:&5N=&EC
M871I;VX@9F%I;&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M870*
M;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$X,@IM<V=I9"`B
M075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-C`*;7-G
M:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C<P"FUS9VED
M(")!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G
M:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S$*
M;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,U"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"86-K
M9W)O=6YD($-O;&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:W)B-2YP:'`Z.#(*;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX
M-`IM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N86UE+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0U"FUS9VED(")"86AA;6%S(@IM<V=S='(@(M>0UYG7F>*`D]>1
MUY37GM>4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS.`IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R("+7
MD=>7UZC7F=>9UY\B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I
M9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS
M-`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R("+7D=>@UY+7G->3UZDB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,S"FUS9VED(")"87)B861O<R(*;7-G<W1R("(B"@HC.B!U=&EL
M+VEC;VY?8G)O=W-E<BYP:'`Z,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S
M92!G<F%P:&EC<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C$Y"FUS9VED(")"87-E;&EN92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C0Y"FUS9VED(")"96QA<G5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S4*;7-G
M:60@(D)E;&=I=6TB"FUS9W-T<B`BUY'7G->2UYG7E"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3`*
M;7-G:60@(D)E;&EZ92(*;7-G<W1R("+7D=><UYG7EB(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#`*
M;7-G:60@(D)E;FEN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#$*;7-G:60@(D)E
M<FUU9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-@IM<V=I9"`B0FAU=&%N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS-C4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<
M(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;&%Y;W5T+FEN8SHY,`IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<R"FUS9VED(")"
M;&]C:R!4>7!E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0S"FUS9VED(")";VQI=FEA(@IM<V=S='(@(M>1UY77G->9UY'7
MF=>4(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R,0IM<V=I9"`B
M0F]O:VUA<FMS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*;7-G:60@(D)O<F1E<B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(Q"FUS9VED(")";W)D97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S(*;7-G
M:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C$P,0IM<V=I9"`B0F]T:"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C0X"FUS9VED(")";W1S=V%N82(*;7-G<W1R("+7D=>5UZ;7
ME=>5UZ#7E"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR,@IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#<*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT-`IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(M>1UZC7EM>9UYPB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q-PIM<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#(*;7-G:60@(D)R=6YE:2!$87)U<W-A
M;&%M(@IM<V=S='(@(M>1UZC7E=>@UYG7F2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<*;7-G:60@
M(D)U;&=A<FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D($QI<W0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS-@IM<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,SD*;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`BUY'7
ME=>HUY77H->3UYDB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8W
M"FUS9VED(")#35,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DX"FUS9VED(")#
M4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G
M:60@(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-@IM<V=I9"`B0V%C:&4@:6YI="!W
M87,@;F]T(&-O;7!L971E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-R!C;VYF:6<O:&]O:W,N<&AP
M+F1I<W0Z,3`U,0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,38T"FUS
M9VED(")#86QE;F1A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C0P"FUS9VED(")#86QM(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3(X"FUS9VED(")#86UB;V1I82(*;7-G<W1R("+7I]>>UY'7E=>3UYG7
ME"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-C`*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(M>GUY[7
MJ->5UY\B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I
M9"`B0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT
M86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S4P"B,L('!H<"UF;W)M870*;7-G:60@
M(D-A;B!N;W0@=W)I=&4@=&\@9FEL92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5S<VEO;G,N<&AP.C(Q"FUS9VED(")#86XG="!A9&UI;FES=&5R
M(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS,S`@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)U<RYP:'`Z,C0Q"B,L('!H<"UF;W)M870*;7-G:60@(D-A
M;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#86XG="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C4Q"FUS9VED(")#86YA9&$B"FUS9W-T<B`BUZ?7H->3UY0B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,#`@861M:6XO=7-E<BYP:'`Z,3$Y"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-2!T96UP;&%T
M97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O<F5M;W9E+FEN8SHQ,B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E
M;&5T92YI;F,Z,3$*;7-G:60@(D-A;F-E;"(*;7-G<W1R("+7J=>@UY0B"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU,@IM<V=I9"`B0V%N
M8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,S(S"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO
M="!D96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO
M8V]P>2YP:'`Z-3(*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"FUS9VED(")#86YN
M;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z.3$*;7-G
M:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M
M971E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E
M8W1O<GD@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R
M964O1&%T851R964N<&AP.C$R."!F<F%M97=O<FLO1&%T851R964O1&%T851R
M964O<W%L+G!H<#HV.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E
M;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8R,@IM<V=I9"`B(@HB
M0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O
M<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@
M<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-0IM<V=I
M9"`B0V%P92!697)D92(*;7-G<W1R("+7I]>DUY0@UY77J->3UY0B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T
M"FUS9VED(")#87!T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R<FEE<B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,*;7-G:60@
M(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S
M-0IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L
M;"!0:&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(U"FUS9VED(")#96QL(%!R;W!E<G1I
M97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS
M9VED(")#96QL('-P86-I;F<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$R-S@*;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B0V5L=&EC("A)
M4T\M.#@U.2TQ-"DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-30*;7-G:60@(D-E;G1R86P@069R:6-A;B!2
M97!U8FQI8R(*;7-G<W1R("+7E->GUY37F=><UYG7F=>4(->4UY[7J->;UY;B
M@)/7D->DUZC7F=>GUZ#7F=>J(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#4*;7-G:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P
M"FUS9VED(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C$R"FUS9VED(")#97)T
M:69I8V%T92!/=VYE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Q"FUS9VED(")#:&%D(@IM<V=S
M='(@(M>FUY,B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"FUS9VED(")#:&%N9V4B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,Q
M"FUS9VED(")#:&%N9V4@66]U<B!087-S=V]R9"(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-CD*;7-G:60@(B(*(D-H86YG92!T:&4@
M;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E
M860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS+B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*;7-G:60@(B(*(D-H
M86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H
M92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#;VYT86-T('EO=7(@861M
M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PIM<V=I9"`B0VAA<B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-3D*;7-G:60@(D-H:6QE(@IM<V=S='(@(M>FUYG7G->9
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HV,0IM<V=I9"`B0VAI;F$B"FUS9W-T<B`BUZ'7F=>?(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@(D-H:6YE<V4@4VEM
M<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X-PIM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-PIM<V=I
M9"`B0VAO;W-E($%P<&QI8V%T:6]N.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C<Q"FUS9VED(")#:&]O<V4@82!P
M87-S=V]R9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I
M9VYU<"YP:'`Z,C<P"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`R"FUS9VED(")#:&]O
M<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*
M;7-G:60@(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI
M<W1S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V"FUS9VED(")#:')I<W1M87,@
M27-L86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HY
M-SD@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$T"FUS9VED(")#;&5A<B(*;7-G<W1R("+7J=>>UYG7G2#7D=>4UYG7
MJ->=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(V"FUS9VED(")#;&5A<B!1=65R>2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$Q
M"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C,T"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,34*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-C`*;7-G
M:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B
M0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K
M97EB;V%R9"YP:'`Z,30V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*
M;7-G:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(U-@IM<V=I9"`B0VQO=61S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$V"FUS9VED(")#
M;&]U9',@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3<*;7-G:60@(D-L;W5D>2(*;7-G<W1R("+7
MJ=>>UYG7G2#7GM>BUY77H->@UYG7G2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3(*;7-G:60@(D-O
M8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P;W)T86PO<VED96)A<BYI;F,Z,C0*;7-G:60@(D-O;&QA<'-E(%-I9&5B
M87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HV,@IM<V=I9"`B0V]L;VUB:6$B"FUS9W-T
M<B`BUZ?7E=><UY77GM>1UYG7E"(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP:'`Z
M,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#;VQO<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-3`U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N
M+G!H<#HS,S8*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN
M<&AP.C,S-R!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C$T"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0Y"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4P"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8U"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8V"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@R"FUS
M9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@S.0IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3DU-`IM<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@P"FUS9VED
M(")#;VUI8W,B"FUS9W-T<B`B(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(S
M"FUS9VED(")#;VUM86YD(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V-M9'-H96QL
M+G!H<#HQ.`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D-O;6UE
M;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU-C<*;7-G:60@(D-O;6UO;B!.86UE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C4X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,P"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@(D-O;7!A
M;GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS
M9VED(")#;VUP=71E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(Y,`IM<V=I9"`B0V]N9&ET:6]N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C8Q"FUS9VED(")#;VYD:71I;VYS
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED
M(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#8*;7-G:60@(D-O;F9I9W5R871I;VX@
M9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O
M:RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0IM
M<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,@IM<V=I9"`B0V]N9FER;2!087-S
M=V]R9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I
M='DN<&AP.C0P-PIM<V=I9"`B0V]N9FER;2!N97<@96UA:6P@861D<F5S<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4U"FUS9VED(")#;VYG;R(*;7-G<W1R("+7
MI]>5UZ#7DM>5(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU,PIM<V=I9"`B0V]N9V\L(%1H92!$96UO
M8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3<*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`X"FUS9VED(")#;VYN96-T
M:6]N(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,3DW"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,P.`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z
M("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HW.3`*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC
M(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-SDR"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I
M;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E
M<R`H)7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z.#4T"FUS9VED(")#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D
M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`Y-@IM
M<V=I9"`B0V]N=&%C=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C4S"FUS9VED(")#;VYT86-T<R!W97)E
M('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H
M<#HV,`IM<V=I9"`B0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-38@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW
M-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S,@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z,CD*;7-G:60@(D-O;G1I;G5E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-3@*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@(D-O;VMI
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O
M<'D@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C,*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`BUZ?7E=>A
MUYC7E"#7J->9UZ?7E"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3<*;7-G:60@(D-O=&4@9"=)=F]I
M<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z.3<W"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$P-34*;7-G:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E.B`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS
M.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C0V-PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A
M9&0@8V]N=&%C="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.CDV(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z,3(Q"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-3<*;7-G:60@(D-O
M=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ
M-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N
M8V4N("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT
M-#$*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB
M)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$Q,C@*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU,C,*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C(T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M9&5L971E(&-O;G1A8W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-3,@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HS.#$*;7-G:60@(D-O=6QD(&YO="!D971E<FUI;F4@
M=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X
M,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O
M:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HT.3,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP
M;&5T92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@
M(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB
M=71I;VX@;&ES=',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713
M=')A=&5G>2YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&QO860@<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y
M+V1I<F5C="YP:'`Z,S`*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW,3D*;7-G
M:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES
M97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W
M<FET:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-#(P"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HW,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E<UPB
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,3$Q(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(S-R!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#<X"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HU,38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C8Q,@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C4V
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV.3D*;7-G:60@(D-O
M=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+T]B:F5C="YP:'`Z,C0P"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!R96%D("5S+B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM<V=I9"`B(@HB0V]U;&0@
M;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R
M+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@;F]T(&-O<G)E
M8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I
M9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P-PHC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,S@*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<U"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,0HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#<*;7-G:60@(D-O=6QD(&YO
M="!R971R:65V92!!0TPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HT.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E
M=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0S-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I
M8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$W"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C(R,0IM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C4T"FUS9VED(")#;W5L9"!N;W0@<F5V97)T
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HU.2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,*;7-G:60@(D-O=6QD
M(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,3`Q"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('-E='5P('5P9W)A
M9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R
M871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@
M(@HB;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P
M>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-#,*;7-G:60@(D-O
M=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P
M9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B!<(B5S7"(Z("5S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S`*;7-G:60@
M(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E
M('1H92!S:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H92!F;VQL
M;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R-PIM<V=I9"`B
M0V]U;G1E9"!T97AT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED(")#;W5N=')Y(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#D*;7-G:60@(D-O=7)S
M97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8X"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.38*;7-G
M:60@(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3(*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@(D-R96%T92!S=6(@
M9F]L9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C(T,`IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C(S"FUS9VED(")#
M<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#D*;7-G
M:60@(D-R;V%T:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-`IM<V=I9"`B0W5B
M82(*;7-G<W1R("+7I]>5UY'7E"(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR
M-@IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z-#@*;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I
M;64N<&AP.C,U"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4T"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z,S,*;7-G:60@(D-U<G)E;G0@57-E<G,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,`IM<V=I9"`B0W5R<F5N
M="!796%T:&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-CD*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3$Q"B,L('!H<"UF;W)M870*;7-G:60@(D-U
M<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T
M('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8W"FUS9VED(")#>7!R
M=7,B"FUS9W-T<B`BUZ?7I->HUYG7H=>9UY\B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X.`IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(D-Y<FEL;&EC
M("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DP"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HV.`IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B
M"FUS9W-T<B`BUZ;7F]>9UY0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#4T('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS
M9VED(")$1"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,C@S"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T
M+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N
M86YC92YP:'`Z-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+V1A=&%T<F5E+G!H<#HV,PIM<V=I9"`B1&%T851R964@0G)O=W-E<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@Q"FUS9VED
M(")$871A8F%S92!,;V]K=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-#`V"FUS9VED(")$871E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED(")$871E(%)E
M8V5I=F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,#`*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#4@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,Q-`IM<V=I9"`B1&%Y(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M-@IM<V=I9"`B1&5?;&5T92!#;VQU;6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-0HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4S"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M
M8F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M8F5R
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ.#<@;&EB+W!R
M969S+G!H<#HQ,3<*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#4*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-S<*;7-G:60@
M(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TED96YT
M:71Y+TED96YT:71Y+G!H<#HY-@IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C<*;7-G:60@
M(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,X"FUS9VED(")$969I;FET:6]N<R(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C<P(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,S(V"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z-#,Y"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,S8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW,`HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3$V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3,Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHW,R!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z.3@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S$@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$P"FUS9VED(")$
M96QE=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"FUS9VED(")$96QE=&4@0V5L;"(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y-R!A9&UI;B]G<F]U
M<',N<&AP.C(R-0IM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T.0IM<V=I9"`B1&5L971E
M($QO9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C<W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`Q"FUS9VED
M(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,PIM<V=I9"`B1&5L971E(&%N
M9"!P=7)G92!M97-S86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W"FUS9VED(")$96QE
M=&4@8V5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@8V]L=6UN
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30W"FUS9VED
M(")$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4T
M"FUS9VED(")$96QE=&4@;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD
M(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*;7-G:60@
M(D1E;&5T92!R;W<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E
M;&5T96ED96YT:71Y+FEN8SHQ-0IM<V=I9"`B1&5L971E('-E;&5C=&5D(&ED
M96YT:71Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S0S,30N<&AP.C4S"FUS9VED(")$96QE=&4@<W5B(&9O;&1E<G,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L
M=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E('1H92!C=7)R
M96YT(')O=R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HS-@HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('-E='5P('5P9W)A
M9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(Q"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PHC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V,PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-0IM
M<V=I9"`B1&5L:79E<GD@=&EM92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Q"FUS
M9VED(")$96YM87)K(@IM<V=S='(@(M>3UZ#7F=>4(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z,C<*;7-G:60@(D1E<V-R:6)E('1H92!0
M<F]B;&5M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.CDT,B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,P"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y-PIM<V=I9"`B1&5T86EL<R`H86QS
M;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C(P,0IM<V=I9"`B1&5T86EL<R!H879E(&)E
M96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S-0IM<V=I9"`B1&5V96QO
M<&UE;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,CD*
M;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,P-@IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(Q
M"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I
M;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@
M<FEG:'0@=&\@;&5F="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR-S`*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T
M:6UE<S\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P
M,`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HY-`IM<V=I9"`B1&ES<&QA>2!D971A
M:6QE9"!F;W)E8V%S="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.CDW"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T("A4048I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3`*;7-G:60@(D1I
M<W!L87D@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O341.+G!H<#HQ.3$*;7-G:60@(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<P"FUS9VED(")$:FEB;W5T:2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,@IM
M<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M
M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O(&YO="!D:7)E8W1L>2!A8V-E
M<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C$R('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC
M.C$R"FUS9VED(")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE
M;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-S(*;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S,*;7-G:60@(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R("+7E->H
MUZ37E=>1UYS7F=>GUY0@UY37D]>5UY[7F=>@UYG7I]>@UYG7JB(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.#@*;7-G:60@(D1O;B=T(&AA=F4@
M86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#4W"FUS9VED(")$;W=N;&]A9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HX-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W
M;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q-0IM
M<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,Y"FUS9VED(")$<G5G<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#,*;7-G:60@(D1Y;F%M:6,@36%I
M;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,3,*;7-G:60@(D4M36%I;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM
M=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O
M=FED92!T:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z
M,S0*;7-G:60@(D524B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<U"FUS9VED(")%
M8W5A9&]R(@IM<V=S='(@(M>0UZ?7E=>5UY/7E=>H(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHS-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,34@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C<R"FUS9VED(")%9&ET(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3`*;7-G:60@(D5D:70@0FQO8VLB
M"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.38@861M:6XO9W)O
M=7!S+G!H<#HR,C0*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$P,`IM<V=I9"`B161I="!097)M:7-S:6]N(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S8*;7-G
M:60@(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<VAA<F5S+V5D:70N<&AP.C(S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET
M(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<')E9G,O87!P+FEN8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,V-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S
M7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G
M:60@(D5D=6-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<W"FUS9VED(")%
M9WEP="(*;7-G<W1R("+7GM>FUZC7F=>=(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$W"FUS9VED
M(")%;"!386QV861O<B(*;7-G<W1R("+7D-><XH"3UZ'7G->5UY77D]>5UZ@B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-#,*;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@
M(D5M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HR,C0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-PIM
M<V=I9"`B16UA:6PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-C8@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHV.0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$P
M"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y-S$*;7-G:60@(D5M86EL(&%D9')E<W-E<R!M
M=7-T(&UA=&-H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO
M261E;G1I='DN<&AP.C0U,`IM<V=I9"`B16UA:6P@861D<F5S<V5S('1O(&-O
M;F9I<FT@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.3DW"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I
M8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W87DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C,P,0IM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM<V=I
M9"`B16UP='D@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HV-C(@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP='D@
M<F5S=6QT+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW
M;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4U-`IM<V=I9"`B16YA
M8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@
M:6X@=&5X=#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4R,0IM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`T"FUS9VED(")%;F0@>65A<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(T"FUS9VED("(B"B)%;G1E<B!A
M('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF
M('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H
M870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C@Y-`IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.3D*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-SD*;7-G:60@(D5R:71R96$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O<W1A='5S+G!H<#HR-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+U9I97<N<&AP.CDT(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU
M,PHC.B!L:6(O0FQO8VLO;65T87(N<&AP.C0Q"FUS9VED(")%<G)O<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@
M)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!A
M;F-H;W(Z("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG
M('-Y;F,@;&]G.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA
M=&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O
M<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS
M9VED(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R
M;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S8*;7-G
M:60@(D5S=&]N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,0IM<V=I9"`B171H
M:6]P:6$B"FUS9W-T<B`BUY#7JM>9UY77I->9UY0B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#$*;7-G:60@(D5T:&YI8R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3`Q
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#,*;7-G:60@(D5V97)Y(#$U(&UI
M;G5T97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y
M,PIM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY."!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S0P"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(D5V
M97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]L87EO=70N:6YC.C$P,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0R"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.30*;7-G:60@(D5V97)Y(#4@;6EN
M=71E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I
M;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3`R(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-#0*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3`S"FUS
M9VED(")%=F5R>2!H;W5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T
M86PO;&%Y;W5T+FEN8SHY.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3(*;7-G:60@(D5V97)Y(&UI;G5T
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR
M-`IM<V=I9"`B17AA;7!L92!V86QU97,Z(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+V-M9'-H96QL+G!H<#HT."!A9&UI;B]P:'!S:&5L;"YP:'`Z-SD@861M:6XO
M<W%L<VAE;&PN<&AP.C$R-0IM<V=I9"`B17AE8W5T92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8Q
M-`IM<V=I9"`B17AP86YD(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T
M86PO<VED96)A<BYI;F,Z,S$*;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-C@*
M;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4U%,+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B87)E
M('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B17AP:7)A
M=&EO;B!$871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C<W"FUS9VED(")%>'!O;F5N="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,Q"FUS9VED(")&1R!#;VQO<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3<W"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S<6PN<&AP.C(T
M-0IM<V=I9"`B1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW-2!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.CDX"FUS9VED(")&86EL960@
M=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C$P,0IM<V=I9"`B1F%I;&5D('1O
M(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HW,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S`X"B,L('!H<"UF;W)M870*;7-G
M:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX.0IM<V=I9"`B1F%I;&5D
M('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U,B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C0Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@
M=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-#0V"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE
M9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HX-`IM<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L
M=FEN87,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#8*;7-G:60@(D9A<F]E($ES
M;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(S
M.`IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A>"(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S8U"FUS
M9VED(")&87AE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S(*;7-G:60@(D9E96QS($QI
M:V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(R-0IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Y"FUS9VED(")&97<@
M4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.34R"FUS9VED
M(")&:65L9"!M871R:7@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S,S-@IM<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,T,`IM<V=I9"`B1FEG
M;&5T(&9O;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,PIM<V=I9"`B1FEJ:2(*
M;7-G<W1R("+7I->9UY+7F2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(U-0IM<V=I9"`B1FEL92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1G>BYP:'`Z-SD*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HV-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O
M=6YT.B`E<R!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HW.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C8W"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S
M(&9I;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT,S`*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8S(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HW,`IM<V=I9"`B1FEL92!.86UE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y.#@*;7-G:60@
M(D9I;&4@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T.30*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDP-@IM<V=I9"`B
M1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY.`IM<V=I9"`B1FEL=&5R<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@R"FUS9VED(")&:6YL86YD(@IM<V=S='(@(M>D
MUYG7H-><UZ#7DR(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@
M(D9I<G-T($AA;&8B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A<G1E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C4U"FUS9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,`IM<V=I
M9"`B1FQI<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M,0IM<V=I9"`B1F]G(@IM<V=S='(@(M>BUZC7I-><(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C$P-R!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C(V,`HC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E<R!N
M;W0@97AI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(D9O;V0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(V"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA
M="!D;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,T-@IM<V=I9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<W"FUS9VED
M("(B"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O
M<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E
M(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.30*;7-G
M:60@(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@U"FUS9VED(")&;W)M<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C8*;7-G:60@(D9O<G1U
M;F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C$P-`IM
M<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT,PIM<V=I9"`B1F]R='5N97,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED(")&;W)T=6YE<R`R(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S8*;7-G
M:60@(D9O<G5M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,3$X"FUS9VED(")&;W)W87)D<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED(")&
M<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,S"FUS9VED(")&<F%M97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HX-PIM<V=I9"`B1G)A;F-E(@IM<V=S='(@(M>FUZC7I->J(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N
M8V4L($UE=')O<&]L:71A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDQ"FUS9VED
M(")&<F5N8V@@1W5I86YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@T"FUS9VED
M(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HX-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,@IM
M<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*
M;7-G:60@(D9R;VTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(T,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4R
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.3@*;7-G:60@(D9R
M;VT@=&AE("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHT,@IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K+VUO;VXN<&AP
M.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C8Q"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M.`IM<V=I9"`B1V%B;VXB"FUS9W-T<B`BUY+7D=>5UY\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*
M;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY-@IM<V=I9"`B1V%M8FEA(@IM<V=S='(@(M>2UY[7D=>9UY0B"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@
M(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL.C8*;7-G:60@(D=E;F5R
M871E9"!#;V1E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3`*;7-G:60@(D=E;W)G
M:6$B"FUS9W-T<B`BUY+7E=>HUY+7F=>4(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV.0IM<V=I9"`B
M1V5R;6%N>2(*;7-G<W1R("+7DM>HUY[7H->9UY0B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDS"FUS
M9VED(")':&%N82(*;7-G<W1R("+7DM>@UY0B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HY,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDT"FUS9VED
M(")':6)R86QT87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-S8*;7-G:60@(D=I=F5N($YA;64B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W-2!T96UP;&%T
M97,O<')E9G,O87!P+FEN8SHQ,`HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN
M8SHQ.0IM<V=I9"`B1VQO8F%L($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3<*;7-G:60@(D=O(@IM<V=S='(@(M><
MUYHB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*;7-G:60@(D=O961E
M;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3$S,PIM<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE+G!H
M<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE(%-E
M87)C:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C,V"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#`*;7-G:60@(D=R965C92(*;7-G<W1R("+7F=>5UY77GR(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ"FUS9VED(")'<F5E:R`H25-/
M+3@X-3DM-RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-0IM<V=I9"`B1W)E96YL
M86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#D*;7-G:60@(D=R96YA9&$B"FUS
M9W-T<B`BUY+7J->@UY/7E"(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<X"FUS
M9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`N<&AP.C4Y(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N
M+65M<'1Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HS,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@
M56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HQ,3@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C$R-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L
M('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE
M=&4@9W)O=7`@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C,S."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,S<Y"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L
M92!T;R!U<&1A=&4@9W)O=7`@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HS,30@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R
M;W5P<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX"FUS9VED(")'=6%D96QO=7!E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S"FUS9VED(")'=6%M(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3`R"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`BUY+7
ME=>0UYC7GM><UY0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDR
M"FUS9VED(")'=65R;G-E>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C@X"FUS9VED(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DS"FUS9VED(")'=65S=&)O;VLB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HY-PIM<V=I9"`B1W5I;F5A(@IM<V=S='(@
M(M>2UYG7H->0UY0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#0*;7-G:60@(D=U:6YE82U":7-S
M874B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`U"FUS9VED(")'=7EA;F$B"FUS
M9W-T<B`BUY+7F=>0UZ#7E"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.CDV-`IM<V=I9"`B2%1-3"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(5$U,
M07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL
M(&EN(')O=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@8V]W
M87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A
M8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C;W=A<F1L
M>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z,34T
M"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$P"FUS9VED(")(86ET:2(*;7-G<W1R("+7E->0
MUYG7F->9(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S
M"FUS9VED(")(87-H+4%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-30U"FUS9VED("(B"B)(879E(&$@8G5T=&]N(&EN
M('1H92!T;V]L8F%R('1H870@<&]P<R!U<"!A('=I;F1O=R!W:71H('-P96-I
M86P@8VAA<F%C=&5R<S\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3(S(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Y,C4*;7-G:60@(DAE861E<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"FUS
M9VED(")(96%D97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-PIM<V=I9"`B
M2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"FUS
M9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(M>AUY77I->JXH"3UZC7HM>>
MUYG7G2#7HM>6UY0B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,@IM<V=I
M9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G
M:60@(DAE:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O2&5L<"YP:'`Z,3@Q(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H
M<#HQ.#(*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@=&5M<&QA=&5S
M+VAE;'`O:6YD97@N:6YC.C0*;7-G:60@(DAE;'`B"FUS9W-T<B`BUZ+7EM>H
MUY0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<Y"FUS9VED(")(96QP97(B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI
M<W!H97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N
M:6YC.C$P('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$P"FUS9VED(")(
M97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P"FUS
M9VED(")(:6=H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M96YU+VUE;G4N
M:6YC.C<*;7-G:60@(DAO7VUE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#,*
M;7-G:60@(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I(@IM<V=S='(@
M(M>5UYC7F=>GUY\B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U
M-34*;7-G:60@(DAO;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$R,@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U"FUS9VED(")(;VUE($%D9')E<W,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8T"FUS9VED
M(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H;VYE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.`IM<V=I9"`B2&]N9'5R87,B"FUS
M9W-T<B`BUY37E=>@UY/7E=>HUZ$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#8*;7-G:60@(DAO
M;F<@2V]N9R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-C<*;7-G:60@(DAO<F1E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z-#0R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE
M<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HR.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO
M(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#,U"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F
M;W5N9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,3(T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S"FUS9VED
M(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E
M<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C4P,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R
M964@9F]R(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C$R-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0W,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E
M($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DR"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@
M)7,@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C$S,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<
M(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M,@IM<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@
M(DAO<FEZ;VYT86PZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I
M9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T
M;R!M97)G93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E
M('1H97)E/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N>2!R;W=S
M('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDS(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C0R"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R("+7G->7UY77JB(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3,*;7-G:60@(DAU;6ED
M:71Y.B`B"FUS9W-T<B`B.M><UY?7F=>J(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0V"FUS9VED(")(=6UO<FES=',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$Q"FUS9VED(")(=6YG87)Y(@IM<V=S='(@(M>4UY77H->2UZC7F=>4
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(S-"!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-S`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y-B!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(T
M,2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-S<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE
M9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3,R,`IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED("))4"!!9&1R97-S
M(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I
M=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I
M9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*
M;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C`*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`BUY#7F=>AUYS7H->3(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,`IM<V=I9"`B26-O;G,@3VYL
M>2(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#$*;7-G:60@(DEC;VYS('=I=&@@
M=&5X="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DS
M"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@
M=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT-3D*;7-G:60@(B(*(DEF('EO=2!D;VXG
M="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@
M;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'
M('1R86YS<&%R96YC>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W,@IM<V=I9"`B(@HB268@>6]U('-E
M92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A
M;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R
M;W=S97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B26UA9V4@4')E
M=FEE=SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V.0IM<V=I
M9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G
M;&4N<&AP.C,W"FUS9VED("));6%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C4T"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C<@=&5M<&QA
M=&5S+V1A=&$O='-V:6YF;RYI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("))
M;7!O<G0L(%-T97`@)60B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@
M9FEE;&0Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,P"FUS9VED("));E]S97)T(%)O=R!!9G1E<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S0*;7-G
M:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,S(*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q
M"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D
M9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M:6YI<W1R
M871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*;7-G
M:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,38*
M;7-G:60@(DEN9&EA(@IM<V=S='(@(M>4UY77D]>5(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$R"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`BUY#7F=>@
MUY/7E=>@UY;7F=>4(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F9C.#(R+G!H<#HV-PIM<V=I9"`B26YF;R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C<S"FUS9VED("));F9O<FUA=&EO;B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S(R
M"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S4*;7-G:60@(DEN<V5R="!#7V]L=6UN($%F=&5R(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B26YS97)T($EM86=E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED("))
M;G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED("));G-E
M<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED("))
M;G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F
M;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@
M(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!B969O<F4@
M=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM<V=I9"`B26YS
M97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E
M('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA
M=&5S+G!H<#HQ-#D*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T,@IM<V=I
M9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R
M96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*;7-G
M:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@
M(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED("))
M;G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN
M<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4P"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED("));G-E<G0@;65S<V%G
M97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("));G-E<G0@<&%R86=R87!H
M(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A<F%G
M<F%P:"!B969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(')O
M=R!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E
M9F]R92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,S
M"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C
M=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I
M9GD@26UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET('1O
M('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M-0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`W.0IM<V=I9"`B26YT96=E<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3,W"FUS
M9VED("));G1E9V5R(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("));G9A
M;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ-C<*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3DT"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(Q,@IM<V=I9"`B26YV
M86QI9"!:25`@9&%T82(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P.34@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C$V-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,C0P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,#<*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS-PIM<V=I9"`B26YV86QI
M9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED("));G9A
M;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P.0HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,SD*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,C0Q"FUS9VED("));G9A;&ED
M(&9I;&4@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-S`*;7-G:60@(DEN=F%L:60@;&EC96YS92!K97DN(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C0*
M;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S
M"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.38*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z,C8*;7-G
M:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C8*;7-G:60@(DEN=F%L
M:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$V.`IM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O9&4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HY,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C<Q(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z.#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<
M(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$P
M-S4@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C4X"FUS9VED("));G9A
M;&ED('-H87)E(&]B:F5C="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@(DEN=F%L
M:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0IM<V=I9"`B26YV
M86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS-S,*;7-G:60@(DEN=F5N=&]R>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C@P
M"FUS9VED("));G9E<G0@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Q.0IM<V=I9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R
M("+7D->9UZC7GR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q.`IM<V=I9"`B27)A<2(*;7-G<W1R
M("+7HM>9UZC7IR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,PIM<V=I9"`B27)E;&%N9"(*;7-G
M<W1R("+7D->9UZC7G->@UY,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES
M;VQA=&5D(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-`IM<V=I
M9"`B27-R865L(@IM<V=S='(@(M>9UZG7@=>HUY#7G"(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C(V"FUS9VED("))<W-U97(B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Q
M"FUS9VED("))=&%L>2(*;7-G<W1R("+7D->9UYC7G->9UY0B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,38*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C,*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`BUY+7GM>9UYG7I]>4(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-`HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G
M:60@(DIA;G5A<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(U"FUS9VED(")*
M87!A;B(*;7-G<W1R("+7F=>DUY\B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$Y,PIM<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,@IM<V=I9"`B2F5R
M<V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-`IM<V=I9"`B2F]R9&%N(@IM
M<V=S='(@(M>9UZC7D]>?(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0Q,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.0HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0W"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*;7-G:60@(DIU
M;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$U
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-#`*;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$T"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PIM<V=I
M9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,38*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Y"FUS9VED(")*=7-T
M:69Y(%)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-@IM<V=I9"`B2V%Z
M86MH<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C8S"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,C8*;7-G:60@(DME;GEA(@IM<V=S='(@(M>G
MUZ#7F=>4(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX-@IM
M<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G
M:60@(DME<FYE;"!.97=B:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y($-R96%T:6]N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q
M-`IM<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T
M:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,3$*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DY"FUS9VED(")+97D@57-A9V4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-S0P"FUS9VED(")+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K
M97ES97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT.`IM<V=I9"`B2VED<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,CD*;7-G
M:60@(DMI<FEB871I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,@IM<V=I9"`B
M2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3,S"FUS9VED(")+;W)E82P@4F5P=6)L:6,@;V8B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.30*;7-G:60@
M(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S0*;7-G
M:60@(DMU=V%I="(*;7-G<W1R("+7F]>5UY77F=>9UZHB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,C<*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHW-0IM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,W"FUS9VED("),86\@4&5O<&QE)W,@1&5M;V-R871I
M8R!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,38Y"FUS9VED("),87-T($AA;&8B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C<V"FUS9VED("),87-T(%!A<W-W;W)D($-H86YG92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K
M+VUO;VXN<&AP.C@X"FUS9VED("),87-T(%%U87)T97(B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C,*;7-G:60@(DQA<W0@57!D871E
M9#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$W
M"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q-`IM<V=I9"`B3&%S="!L
M;V=I;CH@3F5V97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30V"FUS9VED("),
M871V:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y
M"FUS9VED("),87<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"FUS9VED("),87EO=70B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S@*;7-G:60@(DQE8F%N;VXB"FUS9W-T<B`B
MUYS7D=>@UY77GR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT,`IM<V=I9"`B3&5F="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$R"FUS9VED("),969T(&AE861E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3`X
M"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#,*
M;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C4U"FUS9VED("),979E;"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#(*;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`BUYS7F=>1UZC7F=>4
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,30W"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA
M(@IM<V=S='(@(M><UY77D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,`IM<V=I9"`B3&EE8VAT
M96YS=&5I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR-0IM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M-@IM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I
M;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I9"`B
M3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*;7-G:60@(DQI9VAT
M(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,`IM<V=I9"`B3&EM
M97)I8VLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3@R,@IM<V=I9"`B3&EN:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI
M;FL@<&]I;G1S('1O.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#@S"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S('1O
M('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:'1M;#)T97AT+G!H
M<#HQ.#(*;7-G:60@(DQI;FMS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU,0IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C0V"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED
M("),:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,0IM<V=I9"`B3&ES="!$871A8F%S
M97,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3$*
M;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C$S,`IM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU,#D*;7-G
M:60@(DQI<W0M07)C:&EV92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TAE861E<G,N<&AP.C4P-`IM<V=I9"`B3&ES="U(96QP(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3$Q
M"FUS9VED("),:7-T+4ED(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O2&5A9&5R<RYP:'`Z-3`W"FUS9VED("),:7-T+4]W;F5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3`X
M"FUS9VED("),:7-T+5!O<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12](96%D97)S+G!H<#HU,#8*;7-G:60@(DQI<W0M4W5B<V-R:6)E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP
M:'`Z-3`U"FUS9VED("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED("),
M:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5S<VEO;G,N<&AP.C,U"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I
M;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@
M:7,@9&ES86)L960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU,@IM<V=I9"`B3&ET97)A='5R92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#0*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I;6%G97,N<&AP.C<W"FUS9VED("),;V%D
M:6YG+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,#4*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#8*;7-G:60@(DQO8V%L92!A;F0@5&EM
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4W,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C(*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HW-R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(*
M;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&QO9VEN+G!H<#HQ.#@@
M<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(P,"!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C@R"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC
M.C,@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34*;7-G:60@(DQO9R!I
M;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M-#4*;7-G:60@(DQO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y-`IM<V=I
M9"`B3&]G(&]U="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-3D*;7-G:60@(DQO9VEN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,3`*;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY-0IM<V=I9"`B3&]G:6X@
M9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@
M96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z.3DQ"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-S,*;7-G:60@
M(DQO;F<@=&5X="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-3,*;7-G:60@(DQO=F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*;7-G:60@(DQO=R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP
M95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#4*;7-G:60@(DQU>&5M8F]U<F<B"FUS
M9W-T<B`BUYS7E=>;UZ'7GM>1UY77J->2(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,PHC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Q('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C4P"FUS9VED(")-32(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,CDW"FUS9VED(")-3U1$(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,V"FUS9VED(")-4RU4
M3D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-3<*;7-G:60@(DUA8V%O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U
M,PIM<V=I9"`B36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,0IM<V=I9"`B36%D86=A
M<V-A<B(*;7-G<W1R("+7GM>3UY+7H=>GUZ@B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-30*;7-G:60@(DUA9VEC(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HY,`IM<V=I9"`B36%I;"(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-30U"FUS9VED(")-86EL
M($%D;6EN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C4*;7-G:60@(DUA;&%W:2(*;7-G
M<W1R("+7GM><UY77E=>9(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38W"FUS9VED(")-86QA>7-I
M82(*;7-G<W1R("+7GM><UYG7F=>6UYG7E"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-`IM<V=I
M9"`B36%L9&EV97,B"FUS9W-T<B`BUY37D->9UYG7G2#7E->>UYS7D]>9UY77
ME=>9UYG7G2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-`IM<V=I9"`B36%L:2(*;7-G<W1R("+7
MGM><UYDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-C(*;7-G:60@(DUA;'1A(@IM<V=S='(@(M>>
MUYS7F->4(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT"FUS9VED("(B
M"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L
M86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@=VET
M:"!T:&]S92!C871E9V]R:65S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U.`IM<V=I9"`B36%P,C0@
M;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,#@Y"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,3<S"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-
M87!P:6YG<R!S=&]R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#8*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED(")-87)C:"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0Q"FUS9VED(")-87)G:6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#@*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@(DUA<FL@=VET
M:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT.0HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H(&]T
M:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34R"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$U.0IM<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B
M36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,`IM<V=I
M9"`B36%U<FET86YI82(*;7-G<W1R("+7GM>0UY77J->9UYC7H->9UY0B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-C,*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R("+7GM>0UY77
MJ->9UZ;7F=>5UZ$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E>&-E
M961E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3@*
M;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,`IM<V=I9"`B36%X('1E;7`@;&%S
M="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z.#8*;7-G
M:60@(DUA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3`R(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$R,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3(T,PIM<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.`HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*;7-G:60@(DUA
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4S"FUS9VED(")-87EO='1E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-0IM<V=I9"`B
M365D:6-I;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]E9&ET+FEN8SHQ-@IM<V=I9"`B365M8F5R<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@R"FUS9VED(")-96YU(&UO9&4Z(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C4U"FUS9VED(")-97-S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$V"FUS9VED("(B"B)-97-S86=E
M(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I
M9FEC871E(&-O=6QD(&YO="!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$P"FUS9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M-C`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,#(*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E871H97(B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HT,@IM<V=I9"`B365T
M87(@8FQO8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ,C0*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A
M=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-3@*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HV-R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<T"FUS9VED(")-971H;V0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)0
M0R]24$,O<V]A<"YP:'`Z,3$W(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP
M:'`Z.#$*(SH@9G)A;65W;W)K+U)00R]24$,O<&AP9W<N<&AP.C@X(&9R86UE
M=V]R:R]24$,O4E!#+W!H<&=W+G!H<#HX.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")-971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]24$,O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF;W)M870*
M;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<R
M(&QI8B]";&]C:R]M971A<BYP:'`Z.#<*;7-G:60@(DUE=')I8R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-C8*;7-G:60@(DUE>&EC;R(*;7-G<W1R("+7GM>;
MUZ'7F=>GUY4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX-0IM<V=I9"`B36EC<F]N97-I82P@1F5D
M97)A=&5D(%-T871E<R!O9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*;7-G:60@(DUI9&1L
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S(R"FUS9VED(")-:6X@=&5M<"!L87-T(#(T
M(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,30*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#,X"FUS9VED(")-
M:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,S,*;7-G:60@(DUI<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-38*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S0P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C<R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,C4P"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E
M<W0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*
M;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&UU<W0@9V5N
M97)A=&4@:70@8F5F;W)E('5S:6YG('1H:7,@87!P;&EC871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S
M;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA
M9V4@36%I;"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E<W-I
M;VX@240N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW-@IM<V=I9"`B36]B:6QE($UA:6PB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-CD*;7-G:60@(DUO9&5R871E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HX-0HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C<S"FUS9VED(")-;V1I9FEE9"!$871E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D:69Y(%523"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-`IM<V=I
M9"`B36]D=6QU<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3`*;7-G:60@(DUO
M;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.0IM
M<V=I9"`B36]N86-O(@IM<V=S='(@(M>>UY77H->GUY4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-38*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(M>>UY77H->2UY77G->9UY0B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DR"FUS9VED(")-;VYT
M:"!A;F0@>65A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N
M8V4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$V,0IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C$Y-B!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HR.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!F:65L9',@9F]U
M;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,30X"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(M>>UZC7
ME=>GUY4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS,PIM<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED(")-;W-T
M;'D@0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HV-#@*;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U,@IM<V=I
M9"`B36]V92!,969T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z-C4V"FUS9VED(")-;W9E(%)I9VAT
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z-C0T"FUS9VED(")-;W9E(%5P(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C@*;7-G
M:60@(DUO=F4@9&]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(W"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HU,C@*;7-G:60@(DUO=F4@=7`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38X"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@
M(M>>UY77EM>>UY'7F=>G(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C$Y,@IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,#8P"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(U,`IM<V=I9"`B375L=&EP;&4@
M<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT,C,*;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C(X"FUS9VED(")->2!!8V-O=6YT($EN9F]R
M;6%T:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP
M:'`Z-C4*;7-G:60@(DUY(%!O<G1A;"(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]P;W)T86PO961I="YP:'`Z,S4*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34U"FUS9VED(")->6%N;6%R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH
M=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P,B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DYA;64B"FUS
M9W-T<B`BUZG7G2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V.0IM<V=I9"`B3F%M:6)I82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S@*;7-G:60@(DYA=7)U(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`BUZ#7I-><(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<U"FUS9VED(").971H97)L86YD<R(*;7-G<W1R("+7E->5
MUYS7H->3(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C,*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL
M;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3@R"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-`IM<V=I
M9"`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE
M='-C87!E($-!('!O;&EC>2!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#4*;7-G:60@(DYE='-C87!E(%)E
M;F5W86P@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!2979O8V%T:6]N(%52
M3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@X
M"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@Q"FUS
M9VED(").971S8V%P92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C<*;7-G:60@(DYE='=O<FLB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#(U('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY-PHC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S,Y(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3`*
M;7-G:60@(DYE=F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,`IM<V=I9"`B
M3F5W($-A;&5D;VYI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G
M;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT
M97(O96UA:6QS+G!H<#HX-`HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL
M=&5R+V5M86EL<RYP:'`Z.#@*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I
M;'1E<B]E;6%I;',N<&AP.C$Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(").97<@
M365S<V%G92!T;R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H
M<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S8*;7-G:60@(DYE=R!5<V5R;F%M
M92`H;W!T:6]N86PI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,`IM<V=I9"`B
M3F5W(%IE86QA;F0B"FUS9W-T<B`BUZ#7F=>5XH"3UY;7F=><UZ#7DR(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-PIM<V=I9"`B3F5W('!A
M<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L
M+G!H<#HR-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I
M;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z-3(*;7-G:60@(DYE=R!P87-S=V]R9',@9&]N)W0@
M;6%T8V@N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4W(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C0P"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS,#4*;7-G:60@(DYE=W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,R,0IM<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR-2!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C$R.0HC.B!T96UP;&%T97,O9&%T82]D871E;6%P
M+FEN8SHT,2!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ-0IM<V=I9"`B
M3F5X="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*;7-G
M:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HS-C(@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HS-C8*;7-G:60@(DYE>'0@;W!T:6]N<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C$P,PIM<V=I9"`B3F5X=#XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<T"FUS9VED(").:6-A<F%G=6$B"FUS9W-T
M<B`BUZ#7F=>GUZC7DM>5UY#7E"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,0IM<V=I9"`B3FEG
M97(B"FUS9W-T<B`BUZ#7F=>6UZ@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S,*;7-G:60@(DYI
M9V5R:6$B"FUS9W-T<B`BUZ#7F=>2UZC7F=>4(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,W,@IM<V=I9"`B3FEG:'0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<Y"FUS9VED(").:75E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C@*;7-G:60@(DYO
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT
M;6PZ.0IM<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T
M;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HQ,#8*;7-G:60@(DYO
M(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z,S@U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z-#`W"FUS9VED(").;R!B;&]C:R!E>&ES=',@870@=&AE
M(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VUC86PN<&AP.C8W"FUS9VED(").;R!C86QE;F1A<B!N86UE
M('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`IM<V=I9"`B3F\@8VAA;F=E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C$U-@IM<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@
M<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5T:6PO571I
M;"YP:'`Z-S8X(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38Y"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3(P"B,L('!H<"UF;W)M870*;7-G
M:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HX,S,*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C8Y.`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW-#<*;7-G:60@
M(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!3
M44PM1FEL92!61E,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET
M(&QE9G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED(").;R!D97-T:6YA=&EO;B!S
M=7!P;&EE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O
M=W-E<BYP:'`Z.3(T"FUS9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@
M(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HW,0IM<V=I9"`B3F\@:6-O
M;G,@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ,C$@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,S4*(SH@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C0P"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-C(*;7-G:60@(DYO(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M,PIM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*
M;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PIM<V=I
M9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED(").;R!O9F9E;G-I=F4@9F]R='5N
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HQ,C@W"FUS9VED("(B"B).;R!P871H('1O('1H92!/<&5N4U-,(&)I
M;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R
M>2!T;R`B"B)W;W)K('=I=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHV"FUS9VED(").
M;R!P96YD:6YG('-I9VYU<',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HX,3,*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT,PIM<V=I9"`B3F\@<G5L97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#@R"FUS9VED(").;R!S97!A<F%T;W(@
M<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T"FUS9VED(").;R!S:61E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4V,PIM
M<V=I9"`B3F\@<W5C:"!F:6QE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ,S$*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E
M8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C$*;7-G:60@
M(DYO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T,"!F<F%M97=O
M<FLO4E!#+U)00R]P:'!G=RYP:'`Z,3<U"FUS9VED(").;R!V86QI9"!834P@
M9&%T82!R971U<FYE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3<V"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HY.#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.CDY-PHC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3`Q-`IM<V=I9"`B3F\@=F%L=65S(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C`*;7-G:60@(DYO
M('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G
M96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3(X"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN
M('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,C<@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY-0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0U"FUS9VED(").;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I
M;7!L:6-I="DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.34*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W,@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV
M,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-3@*;7-G:60@(DYO<G1H97)N($UA<FEA;F$@27-L86YD<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S8*;7-G:60@(DYO<G=A>2(*;7-G<W1R("+7
MH->5UZC7E=>5UY+7F=>4(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV-#$*;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T
M($)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HT-#$*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C8S"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2YP:'`Z-#@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HU.0HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H
M<#HX-`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+G!H<#HY-0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C8X"FUS9VED(").;W0@<V5T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HQ.3,@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C(P.`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C,T(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HR-3(*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(V.2!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,S8S"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HS.#`@9G)A;65W;W)K+U9&4R]61E,N<&AP.C0Q,PHC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z-#<S(&9R86UE=V]R:R]61E,O5D93+G!H<#HU-3(*
M(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C8R,2!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z-C,X"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HW,38@9G)A;65W
M;W)K+U9&4R]61E,O:&]R9&4N<&AP.C@R"B,Z(&9R86UE=V]R:R]61E,O5D93
M+VAO<F1E+G!H<#HQ,S$@9G)A;65W;W)K+U9&4R]61E,O:&]R9&4N<&AP.C$U
M,0HC.B!F<F%M97=O<FLO5D93+U9&4R]H;W)D92YP:'`Z,3<P(&9R86UE=V]R
M:R]61E,O5D93+VAO<F1E+G!H<#HQ.#D*(SH@9G)A;65W;W)K+U9&4R]61E,O
M:&]R9&4N<&AP.C(P-R!F<F%M97=O<FLO5D93+U9&4R]H;W)D92YP:'`Z,C(W
M"B,Z(&9R86UE=V]R:R]61E,O5D93+VAO<F1E+G!H<#HS,S`*(SH@9G)A;65W
M;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#4*(SH@
M9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ
M-C`*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R
M+G!H<#HQ-S4*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(
M86YD;&5R+G!H<#HQ.#D*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E
M<W-I;VY(86YD;&5R+G!H<#HR,S8*;7-G:60@(DYO="!S=7!P;W)T960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HR-#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P.#$*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$X-PIM<V=I9"`B3F]T97,B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O;V)R;W=S97(O:6YD97@N<&AP.C,V"FUS9VED(").
M;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-`HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4R"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S4*;7-G:60@(DYO
M=F5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$P-3`*;7-G:60@(DYU;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#,S"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<W
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,S$*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,30U,R!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W-2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-#(Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T-3$@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"FUS
M9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I
M<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX
M-S4*;7-G:60@(D]B:F5C="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B3V)J96-T($-R96%T;W(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$P.`IM<V=I9"`B
M3V-T86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0Q,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#4Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDW"FUS9VED(")/9F9E;G-E(&9I;'1E
M<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0R
M"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/;&0@86YD(&YE=R!P87-S=V]R9',@
M;75S="!B92!D:69F97)E;G0N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HS-@IM<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT-@IM<V=I
M9"`B3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.#$*;7-G:60@(D]M86XB"FUS9W-T<B`BUZ+7E=>>UY#7GR(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S"FUS
M9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,3`P"FUS
M9VED(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4Y(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y-SD*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL
M;W=E9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP
M.C8T"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI
M<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B"B)P97)M
M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M:69R86UE+G!H<#HS.2!L:6(O0FQO8VLO:69R86UE+G!H<#HT,`IM<V=I9"`B
M3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@97)R
M;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%
M('!A<G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L
M:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3@*;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U,0IM<V=I
M9"`B3W!T:6]N<R(*;7-G<W1R("+7D->DUZG7J->5UYG7E=>J(@H*(SH@<V5R
M=FEC97,O<')E9G,N<&AP.C,R('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3@*;7-G:60@(D]R9&5R960@3&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T
M:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-38Y"FUS9VED(")/<F=A;FES871I;VYA;"!5;FET(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-#$*;7-G:60@(D]R
M9V%N:7II;F<B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M,S0*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$V"B,L('!H<"UF;W)M
M870*;7-G:60@(D]R:6=I;F%L('1E;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!S97)V:6-E
M<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S='(@(M>0UY?7
MJ"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.2!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3`Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,38@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$R-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3,T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#0*;7-G:60@(D]T:&5R
M($EN9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,S$*;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HX,`IM<V=I9"`B
M4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP
M.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$R-S8*;7-G:60@(E!'
M4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S(R"FUS9VED(")01U`@16YC<GEP=&5D
M($1A=&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3,W-`IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,U-@IM<V=I9"`B
M4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T82(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]P:'!S:&5L;"YP:'`Z-C8*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HQ.`IM<V=I9"`B4$A0(%-H96QL(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,W"FUS9VED(")032!,:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")0
M32!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,Y"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS
M9VED(")032!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"FUS9VED(")032!3;F]W(%-H;W=E<G,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#(*;7-G:60@(E!-(%-U;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B4$T@5"U3
M=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(W
M-`IM<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T<B`B
M(@H*(SH@;&EB+V%P:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@W"FUS9VED(")086MI<W1A;B(*;7-G<W1R("+7I->GUYG7H=>JUY\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DT"FUS9VED(")086QA=2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3DR"FUS9VED(")086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P
M:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,@IM<V=I9"`B4&%N86UA(@IM
M<V=S='(@(M>DUZ#7GM>4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@U"FUS9VED(")087!U82!.
M97<@1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.34*;7-G:60@(E!A
M<F%G=6%Y(@IM<V=S='(@(M>DUZC7DM>5UY#7F=>9(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S8*;7-G:60@(E!A<G1L>2!#
M;&]U9'DB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$X,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HQ-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C`R-@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C8Y('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#0*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0T-@IM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`BUZ'7
MF=>AUY[7D"(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HX,@IM
M<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3,R,PIM
M<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-3<*;7-G:60@(E!A<W-W;W)D
M(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-C$*;7-G:60@(E!A
M<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`IM<V=I9"`B4&%S<W=O<F0Z(@IM
M<V=S='(@(M>AUYG7H=>>UY`Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL
M92YI;F,Z,3$*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`BUZ'7F=>AUY[7
MD#H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,30Y(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P-#(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,3<@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,W"FUS9VED(")087-T92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C4Q"FUS9VED(")0871H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E<75E=65D+FEN8SHW"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4&5O
M<&QE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C0Y"FUS
M9VED(")097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Q,`IM<V=I9"`B4&5R9F]R
M;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B
M4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N
M<&AP.C4Q"B,L('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB
M(&YO="!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C4V-@IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C$@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C0*;7-G:60@(E!E<FUI<W-I
M;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU
M.2!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4W"B,Z(&%D;6EN+W!E<FUS+V5D
M:70N<&AP.C$P."!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C$*;7-G:60@(E!E
M<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HV.`IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I
M;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@S"FUS9VED(")097)U(@IM<V=S
M='(@(M>DUZC7E2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,`IM<V=I
M9"`B4&5T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-SD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#8*;7-G:60@(E!H:6QI
M<'!I;F5S(@IM<V=S='(@(M>DUYG7G->9UZ37F=>@UYG7F=>=(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B
M4&AO;F4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C4P,0IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3`*
M;7-G:60@(E!I=&-A:7)N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Q"FUS9VED(")0
M;&%T:71U9&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC
M:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#D*;7-G:60@(E!L
M96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE
M;65N=#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N9FER
M;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U-S`*;7-G:60@
M(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C$R
M"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G
M;W)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,S`U"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C4Q"FUS
M9VED(")0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M
M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4U"FUS9VED(")0;&5A<V4@96YT97(@
M82!V86QI9"!T:6UE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O=FED92!A('-U;6UA
M<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z,C(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR
M-@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S
M<W=O<F0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C4X"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N
M(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB
M<WES=&5M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM<V=I9"`B4&QE87-E('1Y<&4@=&AE
M(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#@*
M;7-G:60@(E!O;&%N9"(*;7-G<W1R("+7I->5UYS7F=>?(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$P"FUS9VED(")0;VQL
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DS"FUS9VED(")0;W)T=6=A;"(*
M;7-G<W1R("+7I->5UZC7F->5UY+7G"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S
M:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S
M:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,0HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T
M:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<X(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C@S"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R
M(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR.3$*;7-G:60@(E!R96-I<&ET871I;VX\8G(@
M+SYC:&%N8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+VQD87`N<&AP.C$S,PIM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(S-PIM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S$*;7-G:60@(E!R97-S=7)E(&%T
M('-E82!L979E;#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,CD*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P-`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C,*;7-G:60@(E!R979I97<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(T
M"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-3(@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-38*;7-G:60@(E!R979I
M;W5S(&]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#(S"FUS9VED(")0<FEV871E($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38Y"FUS9VED(")0<F]B;&5M(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-@IM<V=I9"`B
M4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S@U"FUS9VED(")0<F]J96-T<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3$Y(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Q.38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S(X-PIM<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C0V"FUS9VED(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I
M9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@
M:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y,0IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-34*
M;7-G:60@(E!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.38*;7-G:60@(E%A=&%R(@IM<V=S='(@(M>GUYC7J"(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HV,0IM<V=I9"`B475E<GDB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C<P"FUS9VED(")1=6]T82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8V-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C<R"FUS9VED
M(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E)A:6XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#4*;7-G:60@(E)A:6X@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E)A:6X@3&%T
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT-PIM<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@
M(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*;7-G:60@(E)A:6X@=&\@4VYO=R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B
M4F%N9&]M($9O<G1U;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV."!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<V"FUS9VED(")2871I;R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C,T"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C@@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$Q-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S
M-PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T
M,S$T+G!H<#HT-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HX-PIM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N
M;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O8VQE87(N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY
M(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N
M(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y
M;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED(")2
M969R97-H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.34*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0U"FUS9VED(")2
M969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<&]R=&%L+VQA>6]U="YI;F,Z.30*;7-G:60@(E)E9G)E<V@@<F%T93HB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DX(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(S.0IM<V=I9"`B4F5G97@B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S(T,@IM<V=I9"`B4F5L871I;VYS:&EP($)R
M;W=S97(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`IM<V=I9"`B
M4F5L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,X
M"FUS9VED(")296UA<FMS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,3<*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM<V=I9"`B4F5M
M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHX('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3,@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]E9&ET+FEN8SHR,@IM<V=I9"`B4F5M;W9E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU-C$*
M;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`IM<V=I9"`B4F5M;W9E
M(&9O<FUA='1I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHQ,C@*;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,#(*;7-G:60@(E)E;6]V92!S879E
M9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#(*;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4P"FUS9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O
M8W5M96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E
M;6]V92YI;F,Z,3$*;7-G:60@(E)E;6]V92!U<V5R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")296UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ,S@@9G)A;65W;W)K+U)00R]2
M4$,O<&AP9W<N<&AP.C$W,PIM<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B92!A
M;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U,`IM<V=I9"`B4F5Q=65S
M=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C4S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E
M9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S.2!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C<P-`HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z-S4S(&9R86UE=V]R:R]61E,O5D93+VAO<F1E
M+G!H<#HT,0HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@
M;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S<V"B,L('!H<"UF;W)M
M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTO4F5N9&5R97(N<&AP.C,S-`IM<V=I9"`B4F5Q=6ER960@1FEE;&0B"FUS
M9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S0S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N
M<&AP.C,Q.2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S@*;7-G:60@(E)E<V5T
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V
M"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S970@66]U<B!087-S
M=V]R9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"FUS
M9VED(")297-T;W)E($QA<W0@475E<GDB"FUS9W-T<B`B(@H*(SH@861M:6XO
M8VUD<VAE;&PN<&AP.C(V(&%D;6EN+W!H<'-H96QL+G!H<#HV.2!A9&UI;B]S
M<6QS:&5L;"YP:'`Z-C0*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,2!T96UP;&%T97,O<')E
M9G,O96YD+FEN8SHW"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S@*;7-G:60@
M(E)E='EP92!N97<@<&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y
M-PIM<V=I9"`B4F5U;FEO;B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*;7-G:60@
M(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@3W!T
M:6]N<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*
M;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0X"FUS9VED(")2:6=H="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$T"FUS
M9VED(")2:6=H="!H96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$Q,`IM<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR.`IM<V=I9"`B4F]?=R!0<F]P97)T:65S+BXN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR
M,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y.`IM<V=I
M9"`B4F]M86YI82(*;7-G<W1R("+7J->5UY[7H->9UY0B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(T"FUS9VED(")2;W1A
M=&4@,3@P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,C$*;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,C<*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED
M(")2;W<@4')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@
M<')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU,PIM<V=I9"`B4G5L97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,`IM<V=I9"`B
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4R"FUS9VED(")2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3$X"FUS9VED(")2=6XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y.0IM<V=I9"`B4G5S<VEA;B!&961E<F%T:6]N
M(@IM<V=S='(@(M>HUY77H=>9UY0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`P"FUS9VED(")2
M=V%N9&$B"FUS9W-T<B`BUZC7E=>0UZ#7D]>4(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G
M<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E
M9"!-97-S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<V%S;"YP:'`Z.#(*;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C4R-PIM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3D*;7-G:60@(E-13"!3:&5L;"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@U"FUS9VED
M(")344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-30*;7-G:60@(E-32"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM
M<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L
M;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8Q"FUS9VED(")382(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`W"FUS9VED(")386EN="!(96QE;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,Q"FUS9VED(")386EN="!+:71T<R!A;F0@3F5V:7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,Y"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@Y"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#0*;7-G:60@(E-A:6YT(%9I;F-E
M;G0@86YD('1H92!'<F5N861I;F5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A;64@
M9G)A;64@*%]S96QF*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q"FUS9VED
M(")386UO82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$R"FUS9VED(")386X@
M36%R:6YO(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.38*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,38*;7-G:60@(E-A;R!4
M;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3871E;&QI=&4@4')O=FED97(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,0IM<V=I9"`B4V%U9&D@07)A8FEA
M(@IM<V=S='(@(M>BUZC7D2#7E->AUZ+7E=>3UYG7JB(*"B,Z('1E;7!L871E
M<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,34*;7-G:60@(E-A=F4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3879E(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3879E("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]E
M;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,38W"FUS9VED("(B"B)3879E(&=E;F5R
M871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E
M<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G
M:60@(E-A=F5D("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.CDY"B,L('!H<"UF;W)M870*;7-G:60@
M(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4P"FUS9VED(")38V%T=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED(")38VEE;F-E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E
M;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED(")396%R8V@B
M"FUS9W-T<B`BUY?7F=>DUY77J2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS,S8*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y-C8*;7-G:60@(E-E;&5C="!&
M:6QE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#@W"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")3
M96QE8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV
M,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,34V"FUS9VED(")396QE8W0@82!U<V5R
M('1O(&%D9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-C<X"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-30*;7-G:60@(E-E
M;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<U"FUS9VED(")3
M96QE8W0@86X@;V)J96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HV-SD*;7-G:60@(E-E;&5C="!N;VYE
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HS-PIM<V=I
M9"`B(@HB4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE
M(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@
M=&AE;2!F<F]M('1H92!T97AT(&%R96$N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C,T"FUS9VED(")396QE8W0@=&AE(&1A=&4@
M9&5L:6UI=&5R.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT-`IM<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY
M,@IM<V=I9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N
M9V4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V
M"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L96-T
M('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHU-PIM<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F
M:65L9',N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M,3`*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U,@IM<V=I9"`B4V5L96-T
M('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU,0IM<V=I9"`B4V5N9"!0<F]B
M;&5M(%)E<&]R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3`T-`IM<V=I9"`B4V5N9"!335,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q,PIM<V=I9"`B4V5N96=A;"(*;7-G<W1R("+7
MH=>@UY+7G"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(X"FUS9VED(")3
M96YS;W(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#$R"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW,PIM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED
M(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#(*;7-G:60@(E-E<FEA;"!.
M=6UB97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$U-`IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL
M86)L92XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(V"FUS
M9VED(")397-S:6]N($%D;6EN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@IM<V=I9"`B4V5S
M<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ
M-#4*;7-G:60@(E-E<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S,C(*;7-G:60@(E-E="(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SD*;7-G:60@(E-E="!O<'1I;VYS('1O
M(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R
M(&9O<F=E="!I="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q.`IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U
M('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-PIM<V=I9"`B4V5T('EO=7(@
M<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS
M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Q"FUS
M9VED("(B"B)3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S
M8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@
M;W!T:6]N<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HW-PIM<V=I9"`B4V5T=7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S4*;7-G:60@(E-E='5P('5P9W)A9&4@
M<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$X,`IM<V=I9"`B4V5V97)A;"!L;V-A=&EO;G,@
M<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P,PIM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R("+7D->9UYGB
M@)/7H=>9UYG7J=><(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4Q
M.0IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z,S@*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U,`IM<V=I9"`B
M4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(S
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDP
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$S('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T
M=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@
M(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0Y-`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@=VAE
M;B!L;V=G:6YG(&EN/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-S<S"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I
M;F%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M,#8*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,CD*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T:6]N
M<R!M96YU(&)A<C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E<R!-96YU
M(&]N('1H92!L969T/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H;W<@
M=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO
M9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%)O
M=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G:60@
M(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-S$*;7-G:60@(E-H;W<@
M=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4Q"FUS9VED(")3:&]W97)S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED
M(")3:&]W97)S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W97)S($QA=&4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-30*;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z-C$Y"FUS9VED(")3:')I;FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HY,3`*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HY-S(*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,#4X
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z
M,3$R,`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.C$Q.#,*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA
M9V5R+G!H<#HQ,C(S"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z,3(U,@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C$R.#4*;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE
M:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$Q"FUS9VED(")3:65R<F$@3&5O;F4B"FUS
M9W-T<B`BUZ?7F=>9UZC7E"#7G->9UY#7E=>?(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]3:6=N=7`N<&AP.C(V-PIM<V=I9"`B4VEG;B!U<"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,PIM
M<V=I9"`B4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED(")3:6=N871U<F4@06QG;W)I
M=&AM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#8*;7-G:60@(E-I;F=A<&]R
M92(*;7-G<W1R("+7H=>9UZ#7DM>DUY77J"(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C4@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HX-`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDP,`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$Y(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R-#$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(U-"!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(S"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,Q,38*;7-G:60@(E-I>F4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@
M(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,`IM
M<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.`IM<V=I
M9"`B4VQO=F5N:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@(E-N;W<B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*;7-G
M:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS9VED(")3;F]W(%-H;W=E<G,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-3@*;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.0IM
M<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR.3`*;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-`IM<V=I9"`B4VYO=R!E
M<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M,@IM<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,30*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`BUZ'7E=>>UYS7F=>4(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")3;VYG<R`F(%!O
M96US(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y
M,3D*;7-G:60@(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Q
M-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR-#<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU-3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU.#D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HQ.#D*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-34*;7-G:60@(E-O=71H($%F<FEC82(*;7-G<W1R("+7D]>HUY77
MG>*`D]>0UZ37J->9UZ?7E"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV
M"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3`Q"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@
M4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3
M;W5T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B
M971W965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C
M92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Q.0IM<V=I9"`B4W!A
M8V5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU-0IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4T"FUS9VED(")3<&%C:6YG(&%N9"!P861D:6YG(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@P"FUS9VED(")3<&%I;B(*;7-G<W1R("+7H=>DUZC7DR(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#<*;7-G:60@(E-P86TB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED
M(")3<&5C:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8R"FUS
M9VED(")3<&QI="!C96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET
M(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")3
M<&]R=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Q"FUS9VED(")3<FD@3&%N
M:V$B"FUS9W-T<B`BUZ'7J->9(-><UZ#7I]>4(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C<Q(&QI8B]";&]C:R]M971A<BYP:'`Z.#8*;7-G
M:60@(E-T86YD87)D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV-PIM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(U.30@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C@P,@IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,0IM<V=I9"`B4W1A=&4@
M;W(@4')O=FEN8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E
M='5P+VEN9&5X+FAT;6PZ,3`*;7-G:60@(E-T871U<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`X"FUS9VED(")3=&]R86=E
M(&9O<FUA="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4W,PIM<V=I9"`B4W1R965T($%D9')E<W,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C,W"FUS9VED(")3=')I;F<@;&ES="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#@Q"FUS9VED
M(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*
M;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,V(&9R86UE=V]R:R]&;W)M+T9O<FTO
M4F5N9&5R97(N<&AP.C,Q-@IM<V=I9"`B4W5B;6ET(@IM<V=S='(@(B(*"B,Z
M('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET
M=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@
M8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@:&%S(&)E96X@
M87!P<F]V960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`R"B,Z(&9R86UE=V]R:R].
M;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z
M,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP
M:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D
M(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Y(&%D;6EN+W!E
M<FUS+V1E;&5T92YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S
M<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU,0IM<V=I9"`B4W5C8V5S<V9U
M;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA
M;F=E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M-3<@861M:6XO<V5T=7`O:6YD97@N<&AP.C4Y"FUS9VED(")3=6-C97-S9G5L
M;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO
M;B!F:6QE("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@7"(E
M<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@
M(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`T"FUS9VED(")3=61A;B(*;7-G<W1R("+7H=>5UY/7GR(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*;7-G
M:60@(E-U;6UA<GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N
M<&AP.C8U"FUS9VED(")3=6X@4FES92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U;B!3970B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G
M:60@(E-U;FYY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,3`*;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V
M"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`Y"FUS9VED(")3=6YR:7-E.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,PIM
M<V=I9"`B4W5N<V5T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,3(*;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G
M:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS.30*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q-0IM<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`BUZ'7E=>HUYG7
MH->=(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S4*
M;7-G:60@(E-U<FYA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.0IM<V=I
M9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C$Y"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`BUZ'7E=>5UY;7F=><
MUZ#7DR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,#4*;7-G:60@(E-W961E;B(*;7-G<W1R("+7
MJ=>5UY77D]>9UY0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-@IM<V=I9"`B4W=I='IE<FQA;F0B
M"FUS9W-T<B`BUZG7E=>5UYG7I2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C@V"FUS9VED(")3>6YC(&QO9R!D96QE=&5D(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#4*;7-G:60@(E-Y;F--3"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z
M.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q.`IM<V=I9"`B4WER:6%N($%R86(@4F5P=6)L
M:6,B"FUS9W-T<B`BUZ'7E=>HUYG7E"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8Q"FUS9VED(")4+5-T;W)M(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R
M"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3
M=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C0*;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-C8*;7-G:60@
M(E135B!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]486)L
M92YP:'`Z,3,T"FUS9VED(")486)L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S"FUS9VED
M(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3<*;7-G:60@(E1A8FQE(%-E
M="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P97)T:65S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S0*;7-G:60@(E1A:7=A;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C(U"FUS9VED(")486II:VES=&%N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,S4*;7-G:60@(E1A;GIA;FEA+"!5;FET960@4F5P
M=6)L:6,@;V8B"FUS9W-T<B`BUYC7H->6UZ#7F=>4(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T
M.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`V-B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DV"FUS9VED(")487-K<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W
M-`IM<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,P,@IM<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C8*;7-G
M:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,3<*;7-G:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,
M;R5S*2`F9&5G.R5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]496UP;&%T
M92]496UP;&%T92YP:'`Z-CDU"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!L
M871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E
M;7!L871E<RYP:'`Z,38X"FUS9VED(")496UP;&%T92!!9&UI;FES=')A=&EO
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$U
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S@*;7-G:60@(E1E>'0B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.0IM<V=I9"`B
M5&5X="!/;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G:60@(E1E>'0@86QI9VXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4
M:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-PIM<V=I
M9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-`IM
M<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`BUZK7D->9UYS7H->3(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,CD*;7-G:60@(E1H92!&5%`@97AT
M96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](:7-T;W)Y+TAI<W1O<GDN<&AP.C8S"FUS9VED(")4:&4@2&ES=&]R
M>2!S>7-T96T@:7,@9&ES86)L960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3,S"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P
M<&]R="!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%])35-0
M+TE-4U`O0F]O:RYP:'`Z,3(Y.`IM<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD
M(&YO="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C
M;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H
M92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$X.2!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C(P,`HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C(Q,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(R,PHC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(S-"!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C(U,@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(V
M-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,P,PIM<V=I9"`B(@HB5&AE
M(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT
M(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E
M<FUI<W-I;VYS+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M
M('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A
M8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R
M('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*
M;7-G:60@(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@
M>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C$Q-S(*;7-G:60@(B(*(E1H92!D971A8VAE
M9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T
M:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4
M:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF
M:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A
M<V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI
M<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z-#8S"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H92!E;6%I;"!A9&1R97-S("5S(&AA<R!B965N(&%D9&5D('1O
M('EO=7(@:61E;G1I=&EE<RX@66]U(&-A;B!C;&]S92!T:&ES("(*(G=I;F1O
M=R!N;W<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="YP
M:'`Z,3$V"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E
M(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-R!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C4S,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S
M:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<P(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z-3(Q"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S
M('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(T,@IM<V=I9"`B5&AE
M(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@
M9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B5&AE
M(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R
M9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@
M<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!)
M;G1E<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T
M('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X
M<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F
M=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B`B
M"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@
M=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&875L
M="<@86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R
M;F5D+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O
M('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P<F5F<RYP:'`Z,3$X"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,34W"FUS
M9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T
M(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C(P,@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S
M('=I=&@@<W5B:F5C="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB
M5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E
M;B!R96%D(&]R('5N9&5R<W1O;V0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$X.#4*;7-G:60@(E1H92!N86UE('1O('5S92!W
M:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P<F5F<RYP:'`Z,3`P"FUS9VED(")4:&4@;F5W(&9R;VT@
M861D<F5S<R!C86XG="!B92!V97)I9FEE9"P@=')Y(&%G86EN(&QA=&5R.B`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#<T
M"FUS9VED(")4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,3(S,@IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D
M(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+G!H<#HR.#,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO
M="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M
M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]W96)C<'`N<&AP.C,W"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A
M=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#@W"FUS
M9VED(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C
M:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A
M;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H
M92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HT-SD*;7-G:60@(E1H92!S97!A<F%T;W(@
M;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@
M<V%V960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA
M<R!B965N(')E;6]V960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-#<P"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!S<&5C:69I960@<F]W("@E9"D@9&]E<R!N;W0@97AI<W0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C`R
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T96UP;W)A<GD@9FEL92!<(B5S
M7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,S,3,*;7-G:60@(E1H92!T97AT('EO=2!E;G1E<F5D
M(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N
M;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,S(W"FUS
M9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E
M=FEO=7,@<W1E<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T
M82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,3<R
M"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU
M-"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$U"FUS9VED(")4:&4@
M=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
M(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HT
M-#0@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HT-#@*;7-G:60@
M(E1H97)E(&%R92!N;R!E;6%I;"!A9&1R97-S97,@=&\@8V]N9FER;2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-S@*
M;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z,S0U
M"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA
M>65D(&EN;&EN92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,30P.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A<F4@
M=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E
M;G1E<F5D("5S(&-H87)A8W1E<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@
M=&AA;B`E<RXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U
M<V5R+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P
M<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T
M<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(Q"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E
M<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3`R"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<
M(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E
M<BYP:'`Z.3,Q"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R
M;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP
M:'`Z.3,V"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R
M;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R
M('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B>71E<RDN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP
M.CDS.`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B
M;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R
M=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,SD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C0X
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT
M86-T(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O
M:6UC+G!H<#HS,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN
M9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z.#(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O
M<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T
M(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I
M9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A
M:6X@;&%T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0P"FUS9VED("(B"B)4:&5R92!W87,@
M86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E
M('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C(*;7-G:60@(B(*(E1H97)E
M('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N
M(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T.`IM<V=I9"`B5&AI
M<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@
M82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S
M(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S.`IM<V=I9"`B5&AI
M<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E
M;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T
M<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%14
M4"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HQ,S0*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I
M;G!L8RYC;VTI("(*(F=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O
M(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N
M96ET86QY7W-M='`N<&AP.C@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO
M=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6
M;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU
M;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6
M;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY.#(@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3`V,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,#DP(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,3D*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3$X-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C8P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#D@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30P-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-38U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-#<*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3DV-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,#$S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S<@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`X-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,34W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,CD*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q-B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-#4X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-#@@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@R,0HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,3,P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,#@*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@Q-B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS.#(T"FUS9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#8Y"FUS
M9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,C0*;7-G
M:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T
M:&4@8V]L;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$P.3@*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O
M8W1A;"!V86QU97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Q,C<*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA
M(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDY,PIM<V=I9"`B5&AI
M<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#(Y"FUS9VED("(B"B)4:&ES
M(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(
M97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C4V-0IM<V=I9"`B5&AI
M<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&ES(&ES("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C0U.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES
M(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T
M('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@
M82!L:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z-3DT"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@;65S<V%G92!W
M87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N
M('EO=7(@;W=N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B92!A="!L
M96%S="!O;F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]G>FEP+G!H<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@
M=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3@R"FUS9VED
M(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(T"FUS
M9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@
M(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W
M:6YD;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C4*;7-G:60@(E1H=6YD97(B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U,`IM<V=I9"`B5&EC:V5T<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#,S('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B5&EM92(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`R"FUS9VED
M(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE
M+G!H<#HR,@IM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4S.0IM<V=I9"`B5&EM92!S96QE8W1I
M;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,`IM<V=I9"`B5&EM;W(M3&5S
M=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B
M5&ET;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N
M<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C4V"FUS9VED("(B"B)4;R!S96QE
M8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I
M(&]R($-O;6UA;F0@*$UA8RD@:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`S"FUS
M9VED(")4;V1A>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R
M8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,PIM<V=I9"`B5&]G;R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(V"FUS9VED(")4;VME;&%U(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#4*;7-G:60@
M(E1O;6]R<F]W(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,CD*;7-G:60@(E1O
M;F=A(@IM<V=S='(@(M>GUY'7E=>FUZKB@)/7D->9UYGB@)/7F->5UZ#7DM>4
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@Q"FUS9VED(")4;W`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I9"`B5&]P(&9R86UE
M("A?=&]P*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C@*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,R"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S='(@(M>8UZC7
MF=>@UYG7D]>3(->5UYC7E=>1UY+7E2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$W.3@*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM
M<V=I9"`B5'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R.`IM<V=I9"`B5'5N
M:7-I82(*;7-G<W1R("+7F->5UZ#7F=>AUYG7E"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S$*
M;7-G:60@(E1U<FME>2(*;7-G<W1R("+7F->5UZC7I]>9UYG7E"(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DX"FUS9VED(")4=7)K:7-H("A)4T\M.#@U
M.2TY*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(W"FUS9VED(")4=7)K;65N
M:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,`IM<V=I9"`B5'5R:W,@
M86YD($-A:6-O<R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S,*
M;7-G:60@(E1U=F%L=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,
M22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V,PIM<V=I9"`B
M52Y6+B!I;F1E>#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M92YP:'`Z
M,3<*;7-G:60@(E523"(*;7-G<W1R("+7D->JUZ@B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T,0IM<V=I9"`B55),
M(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.3<*;7-G:60@(E523#HB"FUS9W-T<B`BUY#7JM>H.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S<*;7-G:60@(E5G86YD82(*;7-G<W1R("+7D->5UY+7H->3UY0B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,V"FUS9VED(")5:W)A:6YE(@IM<V=S='(@(M>0UY77I]>H
MUYG7F=>@UY0B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT-#4*
M;7-G:60@(E5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS.3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O
M<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C0Q."!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@
M<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S@S"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C,W"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HW,C$@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ,#8S"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HX-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S+R5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#0X"FUS9VED
M(")5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C4X(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C(V,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,C(V(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,S$*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(S.0IM<V=I9"`B
M56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,S<P"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,X-R!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C4X"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HR.#8*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@
M5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C$R-`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@
M9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HR.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!6
M1E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,CDX"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&5M
M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E
M<W,O0V]M<')E<W,O9WII<"YP:'`Z-SD*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+W1A<BYP:'`Z-S8*;7-G:60@(E5N86)L92!T;R!D96-O;7!R
M97-S(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z,S`S(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@
M9&ER96-T;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HW-R!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0S"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S8T
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,3$*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HT,3@@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C,V-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S<X(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.#(*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S<P(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HS,C(*(SH@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C,S-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S0S
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-S0*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT-#,@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HT-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S-B!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,38W"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HQ.#`@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C$X-PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,Q-"!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-#$S"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HT,C$*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE
M=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z-#,R"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,3(*;7-G:60@(E5N
M86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C`T"FUS
M9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+G!H<#HT,S<@
M9G)A;65W;W)K+TYE=%])35-0+TE-4U`O075T:"YP:'`Z,3(S"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F
M("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HR,3@@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C(S"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ.#4@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$Y,`IM<V=I9"`B56YA8FQE('1O(&UO=F4@5D93
M(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z.3@@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HY,PHC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C$P-B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C8R.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E;B!6
M1E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C,Q,"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,3,X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-#$*
M;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HX,2!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HX-@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HQ-#`@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C<V"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HT
M-0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.3`S"FUS9VED
M(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.3,T"FUS
M9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F
M86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L
M97(O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*;7-G:60@(E5N86)L92!T
M;R!R96%D(&9I;&4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HW,#(*;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V9G-R
M;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HQ,3`T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y
M(&5X:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,S(S"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E
M8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z,S4U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,S0X(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M,C8R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93
M(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HV-#,@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(R
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE("5S+R5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,C$S(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-3(*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS-#D@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,Q-0HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,S,Q"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@
M)VUK:7-O9G,G+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L
M871E('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C$U-"!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C$U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HQ.#D*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@
M9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C,Q-"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,30V"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ-3$*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.3`Y"FUS9VED
M(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC
M965D960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`*;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H
M86YG97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S="!A8W1I
M;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,X.`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E
M<G9E<B!O;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$W"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,S.0HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S8*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@R"FUS9VED(")5;F5X<&5C=&5D(')E
M<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*;7-G:60@
M(E5N9FEL960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.3D*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-PIM<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`BUY37
MD->>UYG7J->5UYG7E=>J(->4UY[7D->5UY?7D]>5UZHB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S@*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(M>4UY[7GM><UYO7
ME"#7E->>UY#7E=>7UY/7JB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#`*;7-G:60@(E5N:71E
M9"!3=&%T97,B"FUS9W-T<B`BUY#7J->FUY77JN*`D]>4UY'7J->9UZHB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,Y"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R($]U=&QY
M:6YG($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C8W(&QI8B]";&]C:R]M971A<BYP:'`Z.#,*;7-G:60@(E5N
M:71S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z-3@@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(Y
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0S,`IM<V=I9"`B
M56YK;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G
M:60@*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5
M;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3(*;7-G:60@
M(E5N:VYO=VX@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,0IM
M<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP
M.C,Q.0IM<V=I9"`B56YN86UE9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y"FUS9VED("(B"B)5;G!R
M:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E
M('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@($-L
M:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G
M('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@
M86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@
M(E5N<V5T(&-O;&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-C@W(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z.3(W"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M.3,S"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ.3<@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P9&%T92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,P"B,L
M('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<W"FUS9VED(")5<&1A
M=&4@=7-E<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$T,R!A
M9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#$@<V5R=FEC97,O<VAA<F5S+V5D:70N
M<&AP.C(R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#D*;7-G
M:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S@@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$Y.`IM<V=I9"`B57!L;V%D(@IM<V=S='(@(M>4
MUZ+7G->0UY0B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED
M(")5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE
M('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T
M:6X@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R
M;VUA;B!N=6UB97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#$*;7-G:60@
M(E5R=6=U87DB"FUS9W-T<B`BUY#7E=>HUY77DM>5UY77F2(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L('!H
M<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S
M.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3(W"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D
M:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"FUS9VED(")5<V5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP
M:'`Z-S8W"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U
M=&AO<FES960@9F]R("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HR,#(*;7-G:60@(E5S97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR-#4*;7-G:60@(E5S
M97(@3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C8R"FUS9VED
M(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP
M.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE
M9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-#8Y"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,T(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,3DX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.CDX"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,34P('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C,S"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-C0@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE
M(@IM<V=S='(@(M>GUY77DR#7EM>9UY37E=>9(->>UZG7JM>>UZDB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,3(U"B,L('!H<"UF;W)M
M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@W"FUS
M9VED(")5<V5R;F%M93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VUO8FEL92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5<V5R
M<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R"FUS
M9VED(")5>F)E:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C$W,R!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR
M.#@*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,C<*;7-G:60@
M(E9A8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C@W,`IM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z
M("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8S.0IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW"FUS
M9VED(")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-C`@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3$X,0HC+"!P:'`M9F]R;6%T"FUS9VED(")686QU92!I<R!O
M=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(U,B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,C<T"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,C0@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR,0HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED(")686QU97,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q-R!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3DT"FUS9VED(")686QU97,@=&\@<V5L
M96-T(&9R;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T.0IM<V=I9"`B5F%N
M=6%T=2(*;7-G<W1R("+7E=>@UY77D->8UY4B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C,X"FUS9VED(")687)I86)L92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0U"FUS9VED(")696YE>G5E;&$B"FUS9W-T<B`BUY77
MH->6UY77D-><UY0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S
M<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`Q"FUS9VED
M(")697)S:6]N(@IM<V=S='(@(M>2UYG7J->AUY0B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C0R"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI9VXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@S"FUS9VED(")6
M97)T:6-A;#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-S$*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0X"FUS9VED(")6:65T($YA;2(*;7-G<W1R("+7E=>9
MUYG7F.*`D]>@UYTB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C(P,`IM<V=I
M9"`B5FEE=&YA;65S92`H5DE30TE)*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HY-S4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5FEE=R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE
M+G!H<#HS"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@R
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#8*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#<*;7-G:60@(E9I<F=I;B!)<VQA
M;F1S+"!5+E,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C(Q"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-3<*;7-G:60@(E9I<VEB:6QI='DZ("(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I
M=&%L>5]S;71P+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--
M5%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I
M9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")705).24Y'(2$A(%)%34]612!30U))4%0@34%.
M54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G:60@(E=)3B!V:6$@2%144"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4P"FUS9VED(")786QL:7,@86YD($9U
M='5N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R,2!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z.#,*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B
M5V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,T"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,3D*;7-G:60@(E=E871H97(@
M9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HX.38*;7-G:60@(E=E871H97(N8V]M(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED(")796(B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V,`IM<V=I9"`B
M5V5B(%-I=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E
M+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED(")796QC
M;VUE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M-3<@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]I;F1E>"YP:'`Z-S0@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP
M:'`Z,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HR,#$*;7-G:60@(E=E<W1E
M<FX@*$E33RTX.#4Y+3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,C`R"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-S@*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA
M>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z,30*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM:71E<B!C
M:&%R86-T97(_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC.C$W"FUS9VED(")7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,#8V"FUS9VED(")7:&5R96ES($%U<W1R86QI82!M87`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC
M:"!P:&%S97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S-@IM<V=I9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2
M:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED(")7:61T
M:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$X
M"FUS9VED(")7:61T:"!I;B!#4U,@=6YI=',B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,V,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7
M:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T
M(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F
M('1H92!T86)L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q,`IM<V=I9"`B5VED=&@@=6YI="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P-0IM<V=I9"`B5VED=&@Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HU,S8*;7-G:60@(E=I:VDB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,R!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@IM<V=I9"`B5VEN9"(*;7-G
M<W1R("+7J->5UY<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV-PIM<V=I9"`B5VEN9"!%87)L>2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.CDR"FUS9VED(")7:6YD('-P965D(&EN(&MN
M;W1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,38X"FUS
M9VED(")7:6YD.B(*;7-G<W1R("+7J->5UY<Z(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S-@IM<V=I9"`B5VEN9#H@(@IM<V=S='(@(M>H
MUY77ESH@(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Y"FUS9VED(")7
M:7-D;VTB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(Q,@IM<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C<P"FUS9VED(")7;W)K(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C0*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-`IM<V=I9"`B
M5V]R:R!!9&1R97-S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO;F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3DS(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(Y-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C
M=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z,S,R"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG
M(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3(T"B,L
M('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D
M:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR-3D*;7-G:60@(E@M4F5F(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y
M=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV,R!%>'1E
M;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J96-T($%L
M=&5R;F%T:79E($YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G:60@(E@U,#EV,R!3=6)J96-T($ME
M>2!)9&5N=&EF:65R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-C@S"FUS9VED(")8-3`Y=C,@97AT96YS:6]N<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B65DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0Q-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#4X"FUS9VED(")965E9(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3$S"FUS9VED(")986AO
M;R$@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-
M86EN=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C4R"FUS9VED(")996UE;B(*;7-G<W1R("+7JM>9UY[7GR(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C@*
M;7-G:60@(EEE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N
M8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H
M92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.C(S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A
M;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T,C4*;7-G:60@
M(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S(U"FUS9VED(")9;W4@
M8V%N;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N
M86UE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]P:'!G=RYP
M:'`Z,3$W"FUS9VED(")9;W4@9&ED(&YO="!A=71H96YT:6-A=&4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-C,@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3DX,PIM<V=I9"`B66]U(&1I9"!N;W0@96YT
M97(@82!V86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1&%T82]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E
M9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@W"FUS
M9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,SDS"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(EEO=2!H879E(')E<75E<W1E9"!T;R!A9&0@=&AE
M(&5M86EL(&%D9')E<W,@7"(E<UPB('1O('1H92!L:7-T(&]F('EO=7(@(@HB
M<&5R<V]N86P@96UA:6P@861D<F5S<V5S+EQN(@HB7&XB"B)';R!T;R!T:&4@
M9F]L;&]W:6YG(&QI;FL@=&\@8V]N9FER;2!T:&%T('1H:7,@:7,@<F5A;&QY
M('EO=7(@861D<F5S<SI<;B(*(B5S7&XB"B)<;B(*(DEF('EO=2!D;VXG="!K
M;F]W('=H870@=&AI<R!M97-S86=E(&UE86YS+"!Y;W4@8V%N(&1E;&5T92!I
M="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(V
M-0IM<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO
M;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B
M"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.3(*;7-G:60@
M(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HS-PIM<V=I9"`B
M66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@
M4VEG;G5P<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HT-S0*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K
M96YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8SHQ,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@
M8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.3@*;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI
M<R!L:6YK('!O:6YT<R!T;R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<G!C<W5M+G!H<#HX,`IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E
M<G9E<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,3@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T
M;R!C;&5A<B!O=70N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.CDY
M"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HV,2!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P96-I
M9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,30U"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R
M;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP
M<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S.`IM<V=I9"`B66]U(&UU<W0@<W!E
M8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0IM
M<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L
M>5]S;71P+G!H<#HW,PIM<V=I9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)
M=&%L:6%N('!H;VYE(&YU;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HY-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E
M<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,T
M"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(Q-0IM<V=I9"`B66]U<B!&<F]M.B!A9&1R
M97-S.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C<@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<W(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(*;7-G:60@(EEO=7(@
M26YF;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z.3<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N
M970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F
M('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y
M+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S`*;7-G:60@(EEO=7(@3F%M92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z
M-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@
M;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R`B"B)U
M<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S
M="!U<V4@82!D:69F97)E;G0@(@HB875T:&5N=&EC871I;VX@8F%C:V5N9"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN
M8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E
M<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B
M"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX,PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H
M879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E
M<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@
M;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N
M<&AP.C4U"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T
M:&ES(&9E871U<F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+W!R:6YT+FIS.C0R"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N
M;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#
M;VUM86YD("L@4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(V,0IM<V=I9"`B66]U<B!C=7)R96YT('1I;64@
M>F]N93HB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C$R-`IM
M<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-C$*;7-G
M:60@(EEO=7(@9&5F875L="!I9&5N=&ET>3HB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(P-`IM<V=I9"`B66]U<B!F=6QL(&YA;64Z
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY.0IM
M<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-`IM<V=I
M9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R
M871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS
M(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@
M8F5E;B!R97-E="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R
M97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N
M97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.C<S,PIM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP:7)E
M9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C4X"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C4T"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S='(@
M(M>9UY77DM>5UZ'7G->1UYG7E"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-38*;7-G:60@(EIA;6)I82(*;7-G<W1R("+7EM>>UY'7F=>9UY0B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C4W"FUS9VED(")::6UB86)W92(*;7-G<W1R("+7EM>9UY[7
MD=>1UY77E=>4(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C<Q"FUS9VED
M(")::7!P>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O
M1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T
M960@5&5X=%TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z
M.#@*;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3
M:&]W(%%U;W1E9"!497AT("TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E
M>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S
M72(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-38Q"FUS9VED
M(")?061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z
M,34W"FUS9VED(")?0TQ)(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T
M,0IM<V=I9"`B7T1A=&%4<F5E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B
M7T1E;&5T92!2;W<B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3,S"FUS
M9VED(")?1W)O=7!S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]-96YU+G!H<#HQ-S4*;7-G:60@(E](96QP(@IM<V=S='(@(M>BUY;7
MJ->4(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DT
M"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92]-96YU+G!H<#HQ.3`*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@
M(M>4UZK7H->JUZ?7E=>J(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI;FLN
M+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N
M<&AP.C$V-`IM<V=I9"`B7T]P=&EO;G,B"FUS9W-T<B`BUY#7I->IUZC7E=>9
MUY77JB(*"B,Z(&QI8B]A<&DN<&AP.C$S-PIM<V=I9"`B7U!E<FUI<W-I;VYS
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR-@IM<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM
M<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?57-E<G,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C`*
M;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R("+7H=>DUZ@@UYO7JM>5UY'7
ME=>J(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S0*
M;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$R"FUS9VED(")C86QE;F1A<B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X-"!L:6(O0FQO8VLO
M;65T87(N<&AP.C,W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34X
M"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,P"FUS9VED
M(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.34*;7-G:60@(F-L:6-K(&AE<F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ,C(*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W.`IM
M<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC
M86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M
M870@97)R;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET
M+FEN8SHS,`IM<V=I9"`B961I="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$X,@IM<V=I9"`B96YT<GD@;F]T(&9O
M=6YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C<R"FUS9VED(")F86QL:6YG(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDP,@IM<V=I9"`B9FEL92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X-B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,W,B!L:6(O0FQO8VLO;65T87(N<&AP.C,Y.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#0*
M;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T.`IM<V=I9"`B:#HB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,V
M,0IM<V=I9"`B:&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(R,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4V-0IM<V=I9"`B:6UM961I871E(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N
M<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U='!U
M="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R;W(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C
M:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE
M(&UA:VEN9R!)4T\N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HS-S(*;7-G:60@(FUM(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C@Q('-E<G9I8V5S
M+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S`*(SH@<V5R=FEC97,O<&]R=&%L+W-I
M9&5B87(N<&AP.C(T,0IM<V=I9"`B;F%M92(*;7-G<W1R("+7J=>=(@H*(SH@
M9G)A;65W;W)K+U)00R]24$,N<&AP.C$R-`IM<V=I9"`B;F]T(&EM<&QE;65N
M=&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,3(R,`IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-`IM<V=I9"`B
M;F]T97!A9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED(")P97)C96YT(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<T
M"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS
M9VED(")P:7AE;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T
M;V-O;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HW-`IM<V=I9"`B<FES:6YG(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,30R"FUS9VED(")S97)V
M:6-E('5N879A:6QA8FQE(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z,3`R"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X.0IM
M<V=I9"`B<W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-S,*;7-G:60@(G-T96%D>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B
M<WES=&5M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z.3(X"FUS9VED(")T87-K(&QI<W0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E
M;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C,U(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-S$*;7-G:60@
M(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF
M9BYP:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O:&]R9&4N<&AP.C(W.0IM<V=I9"`B=6YK;F]W;B!E<G)O
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U!A<G0N<&AP
M.C(W"FUS9VED(")U;FYA;65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PHC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0IM<V=I9"`B
M=7-E<B!S96QE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0P
M"FUS9VED(")W.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O9&%?1$LN<&\`````
M````````````````````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`Q
M,3`Q,C0Q(#$P-3$U-#,S-S0S(#`Q-S0V,``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````C($1A;FES:"!T<F%N<VQA=&EO;G,@
M9F]R($AO<F1E('!A8VMA9V4*(R!$86YS:V4@;W9E<G/F='1E;'-E<B!F;W(@
M<&%K:V4@2&]R9&4N"B,@0V]P>7)I9VAT("A#*2`R,#`Q($UA<G1I;B!,:7-T
M+5!E=&5R<V5N+@HC($-O<'ER:6=H="`H0RD@,C`P-2TR,#`V($)R:6%N(%1R
M=65L<V5N+@HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@
M<V%M92!L:6-E;G-E(&%S('1H92!(;W)D92!P86-K86=E+@HC($UA<G1I;B!,
M:7-T+5!E=&5R<V5N(#QM87)T:6Y`;&ES="UP971E<G-E;BYD:SXL(#(P,#$N
M"B,@0G)I86X@5')U96QS96X@/&AO<F1E*VDQ.&Y`8G)I86YT<G5E;'-E;BYD
M:SXL(#(P,#4M,C`P-BX*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M
M260M5F5R<VEO;CH@2&]R9&4@,RXQ+C$M8W9S7&XB"B)297!O<G0M37-G:60M
M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N
M+41A=&4Z(#(P,#8M,#,M,3$@,3(Z,SDK,#$P,%QN(@HB4$\M4F5V:7-I;VXM
M1&%T93H@,C`P-BTP,RTQ,2`Q-CHU,BLP,3`P7&XB"B),87-T+51R86YS;&%T
M;W(Z($)R:6%N(%1R=65L<V5N(#QH;W)D92MI,3AN0&)R:6%N=')U96QS96XN
M9&L^7&XB"B),86YG=6%G92U496%M.B!$86YI<V@@/&DQ.&Y`;&ES=',N:&]R
M9&4N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP
M93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ7&XB"B)#;VYT96YT
M+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"B)0;'5R86PM1F]R;7,Z(&YP
M;'5R86QS/3([('!L=7)A;#TH;B`A/2`Q*3M<;B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S-CD@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-CD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS9W-T<B`B("@E
M<R!D86=E('-I9&5N*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,3,X,R!L:6(O2&]R9&4N<&AP.C$S.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B`H06-C97-S:V5Y("5S*2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S<@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(S-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*
M;7-G<W1R("(@*&]M("5S(&1A9V4I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C,W,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W,PIM<V=I9"`B("AT
M;V1A>2DB"FUS9W-T<B`B("AI(&1A9RDB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S<U(&QI8B](;W)D92]&;W)M+G!H<#HR,S<U"FUS9VED("(@
M*'1O;6]R<F]W*2(*;7-G<W1R("(@*&D@;6]R9V5N*2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(S-S$@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S$*
M;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(@*&D@9^5R*2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#4@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,U,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,SDV"FUS9VED("(@870@(@IM<V=S='(@(B!M960@(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HR,3D@;&EB+U9&4R]S;6(N<&AP.C(Q.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y
M+B(*;7-G<W1R(")<(B5S7"(@97(@:6MK92!E="!K871A;&]G+B(*"B,Z(&9R
M86UE=V]R:R]#3$DO0TQ)+G!H<#HR-S(@;&EB+TAO<F1E+T-,22YP:'`Z,C<R
M"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C
M:&]I8V4N(@IM<V=S='(@(EPB)7-<(B!E<B!I;G1E="!G>6QD:6=T('9A;&<N
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HW,3`*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ,#DX(&QI
M8B](;W)D92]296=I<W1R>2YP:'`Z-S$P"B,Z(&QI8B](;W)D92]296=I<W1R
M>2YP:'`Z,3`Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T
M(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*;7-G<W1R(")<
M(B5S7"(@97(@:6MK92!K;VYF:6=U<F5R970@:2!(;W)D97,@9F]R=&5G;F5L
M<V4N(@H*(SH@9G)A;65W;W)K+U1R964O5')E92YP:'`Z,3<Q(&QI8B](;W)D
M92]4<F5E+G!H<#HQ-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R
M964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R(")<(B5S7"(@='+F+6]P
M8GEG9V5R(&EK:V4@9G5N9&5T+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-38*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@
M9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B7"(E<UPB(&)L978@=&EL9OAJ970@
M:2!G<G5P<&4M<WES=&5M970N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N
M<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@
M=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B7"(E<UPB(&)L
M978@=&EL9OAJ970@=&EL;&%D96QS97,M<WES=&5M970N(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E871E9#H@)7,N
M(@IM<V=S='(@(EPB)7-<(B!B;&5V(&EK:V4@9&%N;F5T.B`E<RXB"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T
M<B`B)2XR9DU"(&)R=6=T('5D(&%F("4N,F9-0B!T:6QL861T("@E+C)F)24I
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B)60@)7,@;V<@
M)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C(V."!L:6(O
M2&]R9&4O075T:"]L9&%P+G!H<#HR-C@*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C4Y-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!D87ES('5N=&EL('EO
M=7(@<&%S<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`B)60@9&%G92!T:6P@9&ET
M(&MO9&5O<F0@=61L^&)E<BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S
M="(*;7-G<W1R("(E9"UD86=S('5D<VEG="(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC
M92(*;7-G<W1R("(E<R`M($YO=&ET<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-S`U(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-S`U"B,L('!H<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S
M='(@(B5S(&9I;F=E<F%F=')Y:R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C@T,B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HX-#0*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@T,B!L
M:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#0T"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S($M"(@IM<V=S='(@(B5S($M"(@H*(SH@<V5R=FEC97,O;6%I
M;G1E;F%N8V4N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S($UA:6YT
M96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B)7,@
M5F5D;&EG96AO;&1E;'-E("T@0F5K<N9F=&5L<V4B"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,34*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B)7,@;W!SYG1N
M:6YG(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V-"!L
M:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V-`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!3:6=N(%5P(@IM<V=S='(@(B5S(&]P<VMR:79N:6YG(@H*(SH@
M<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*;7-G<W1R("(E<R!B<G5G<V)E
M=&EN9V5L<V5R(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.#(@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-3`*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HT,S(@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT
M.30*(SH@;&EB+U9&4R]F='`N<&AP.C8X,B!L:6(O5D93+V9T<"YP:'`Z-S4P
M(&QI8B]61E,O<VUB+G!H<#HT,S(*(SH@;&EB+U9&4R]S;6(N<&AP.C0Y-`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T
M<B`B)7,@96MS:7-T97)E<B!A;&QE<F5D92XB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$V-B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(T-@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,U,B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,U.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A
M="`E<R`E<R(*;7-G<W1R("(E<R!V960@)7,@)7,B"@HC.B!S97)V:6-E<R]M
M86EN=&5N86YC92YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@
M:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E
M<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*
M;7-G<W1R("(B"B(E<R!E<B!P87)A="!T:6P@870@=61F^')E(&1E('9E9&QI
M9V5H;VQD96QS97-H86YD;&EN9V5R+"!S;VT@97(@;6%R:V5R970@(@HB;F5D
M96YF;W(N("!3YG0@:&%K('5D(&9O<B!D92!H86YD;&EN9V5R+"!S;VT@9'4@
M^&YS:V5R('5D9OAR="!N=2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S0P(&QI8B](;W)D92]&;W)M+G!H<#HR,S0P"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B5S(&MRYG9E="(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,CDS"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(&UI;G5T97,B"FUS9W-T<B`B)7,@;6EN=71T97(B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3,R(&QI8B](;W)D92]"
M;&]C:R]#;VQL96-T:6]N+G!H<#HQ,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(E<R!I:VME(&9U;F1E="XB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHT"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@(B5S('1I;"`E<R!A9B`E
M<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(V(&QI8B](;W)D
M92]+;VQA8BYP:'`Z.3(V"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@061D
M<F5S<R!";V]K(@IM<V=S='(@(B5S<R!A9')E<W-E:V%R=&]T96LB"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ."!L:6(O2&]R9&4O2V]L86(N
M<&AP.CDQ.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM
M<V=S='(@(B5S<R!K86QE;F1E<B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3$P(&QI8B](;W)D92]+;VQA8BYP:'`Z.3$P"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R("(E<W,@;F]T97-B;&]K
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S0@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!487-K
M;&ES="(*;7-G<W1R("(E<W,@;W!G879E<B(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*
M(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP
M.CDV"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(E<SH@
M)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HQ
M,C<@;&EB+TAO<F1E+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@
M9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN
M9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD
M97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*
M(B5S.B!$96YN92!B97-K960@97(@;75L:6=V:7,@:6MK92!F<F$@9&5N('!E
M<G-O;BP@<V]M(&1E;B!HYG9D97(@870@=N9R92`B"B)F<F$N("!6YG(@=F%R
M<V]M(&UE9"!A="!F^&QG92!H96YV:7-N:6YG97(@96QL97(@9F]R<WEN92!A
M9G-E;F1E<F5N(&UE9"`B"B)P97)S;VYL:6=E(&EN9F]R;6%T:6]N97(N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U-"!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,SDY"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S
M='(@(BP@9&ES970@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.34@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G
M=7-T:6YG("5S("5S(@IM<V=S='(@(BP@8FSF<V5N9&4@)7,@)7,B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(P.`HC+"!P:'`M9F]R;6%T"FUS9VED("(L
M('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B+"!S:W)I9G1E;F1E
M(&9R82`E<R!T:6P@)7,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-S0X(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,CDT"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S0X(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(P-CD*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C$R."!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`V.0HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C$R."!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-S0X"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,CDT(&QI8B](
M;W)D92]097)M<R]522YP:'`Z,S0X"FUS9VED("(M+2!S96QE8W0@+2TB"FUS
M9W-T<B`B+2T@=N9L9R`M+2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,`IM
M<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS9W-T<B`B,3(M=&EM97)S(&9O<FUA
M="(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ.0IM<V=I9"`B,C0@2&]U<B!&
M;W)M870B"FUS9W-T<B`B,C0M=&EM97)S(&9O<FUA="(*"B,Z('1E;7!L871E
M<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(R
M-"!T:6UE<B(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z-CD@;&EB
M+TAO<F1E+U5)+U!A9V5R+G!H<#HV.0IM<V=I9"`B/%!R979I;W5S(@IM<V=S
M='(@(CQ&;W)E9^5E;F1E(&1A9R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,3(V"FUS9VED(")!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R
M('1H:7,@8FQO8VLN(@IM<V=S='(@(D5N(&1A=&%B87-E+6)A8VME;F0@97(@
M:W+F=F5T(&9O<B!D96YN92!B;&]K+B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,3<Q(&QI8B](;W)D92YP:'`Z,3<Q"FUS9VED(")!(&9A=&%L
M(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R(")$97(@97(@;W!S=.5E="!E
M;B!G<F%V97)E;F1E(&9E:FPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HY,S4@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.3,U"FUS9VED
M(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M
M97-S86=E+B(*;7-G<W1R(")%;B!O9F9E;G1L:6<@4$=0+6[X9VQE(&5R(&MR
MYG9E="!F;W(@870@:W)Y<'1E<F4@96X@8F5S:V5D+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-C@@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z,3$V.`IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E
M9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B16X@;V9F
M96YT;&EG(%!'4"UN^&=L92!E<B!K<N9V970@9F]R(&%T('9E<FEF:6-E<F4@
M96X@<VEG;F5R970@8F5S:V5D+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$P.3D@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3`Y.0IM
M<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*(FUE
M<W-A9V4N(@IM<V=S='(@(B(*(D5N(&]F9F5N=&QI9R!01U`M;OAG;&4L('!R
M:79A="!01U`M;OAG;&4@;V<@970@;/AS96X@97(@:W+F=F5T(&9O<B!A="`B
M"B)D96MR>7!T97)E(&5N(&)E<VME9"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,#$V(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$P
M,38*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M
M97-S86=E+B(*;7-G<W1R("(B"B)%;B!O9F9E;G1L:6<@4$=0+6[X9VQE+"!P
M<FEV870@4$=0+6[X9VQE(&]G(&5T(&SX<V5N(&5R(&MRYG9E="P@9F]R(&%T
M("(*(G-I9VYE<F4@96X@8F5S:V5D+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3`V(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3`V"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O
M34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R`B"B)D
M96-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@HB16X@;V9F96YT;&EG(%,O
M34E-12UN^&=L92P@<')I=F%T(%,O34E-12UN^&=L92!O9R!E="!L^'-E;B!E
M<B!K<N9V970L(&9O<B!A="`B"B)D96MR>7!T97)E(&5N(&)E<VME9"XB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0S,2!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-
M24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*
M(D5N(&]F9F5N=&QI9R!3+TU)344M;OAG;&4L('!E<G-O;FQI9R!3+TU)344M
M;OAG;&4@;V<@;/AS96X@97(@:W+F=F5T(&9O<B!A="`B"B)S:6=N97)E(&5N
M(&)E<VME9"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C,V-"!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P
M=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S
M86=E+B(*;7-G<W1R(")%;B!O9F9E;G1L:6<@4R]-24U%+6[X9VQE(&5R(&MR
MYG9E="!F;W(@870@:W)Y<'1E<F4@96X@8F5S:V5D+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.CD*;7-G:60@(D%-($-L;W5D
M<R(*;7-G<W1R(")&;W)M:61D86<@4VMY970B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B04T@3&EG:'0@4F%I
M;B(*;7-G<W1R(")&;W)M:61D86<@3&5T(%)E9VXB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*
M;7-G<W1R(")&;W)M:61D86<@4F5G;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED(")!32!3:&]W97)S(@IM<V=S
M='(@(D9O<FUI9&1A9R!">6=E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS
M9W-T<B`B1F]R;6ED9&%G(%-N96)Y9V5R(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M=&EM92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM<V=S='(@(D%-+U!-(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`P
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`P"FUS9VED
M(")!4$D@240B"FUS9W-T<B`B05!)($E$(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E
M9&ET;W(B"FUS9W-T<B`B3VT@9&5N;F4@<VMR:6)E;G0B"@HC.B!S97)V:6-E
M<R]H96QP+VEN9&5X+G!H<#HU,PIM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B
M3VTN+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<T"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B06)S8F]T=&]M(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM
M<V=I9"`B06)S;6ED9&QE(@IM<V=S='(@(D%B<VUI9&1L92(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-S`@;&EB+U9&4R]M=7-Q;"YP:'`Z
M,C<P"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O
M<GDN(@IM<V=S='(@(D%D9V%N9R!NYF=T970@=F5D(&1A;FYE;'-E(&%F(%9&
M4RUK871A;&]G+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ
M,S8@;&EB+U9&4R]M=7-Q;"YP:'`Z,3,V"FUS9VED(")!8V-E<W,@9&5N:65D
M(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G<W1R(")!9&=A;F<@;N9G=&5T('9E
M9"!D86YN96QS92!A9B!61E,M9FEL+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HS"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(DMO
M;G1O+6EN9F]R;6%T:6]N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X
M"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@(DMO;G1O96YS(&MO
M9&5O<F0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.3,*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.3,*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R(")+;VYT;R!I
M;F1E9G)O<W-E="XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,U
M"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(DMO;G1E<FEN9RXB"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T."!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C$T.`HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z,3$*;7-G:60@
M(D%D9"(*;7-G<W1R(")4:6QF^&HB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R
M-"!A9&UI;B]G<F]U<',N<&AP.C(R-0IM<V=I9"`B061D($-H:6QD($=R;W5P
M(@IM<V=S='(@(E1I;&;X:B!U;F1E<F=R=7!P92(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z.3@@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HY.0HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.CDX(&QI8B](;W)D
M92]097)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N
M(@IM<V=S='(@(E1I;&;X:B!U;F1E<F]R9&YE9&4@=&EL;&%D96QS92(*"B,Z
M('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!9&0@2&5R93HB
M"FUS9W-T<B`B5&EL9OAJ(&AE<CHB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(Q
M."!A9&UI;B]G<F]U<',N<&AP.C(Q.0IM<V=I9"`B061D($YE=R!'<F]U<"(*
M;7-G<W1R(")4:6QF^&H@;GD@9W)U<'!E(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HX-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C@X"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z.#<@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HX.`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S
M='(@(E1I;&;X:B!N>2!R971T:6=H960B"@HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V%D9&-H:6QD+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%D
M9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R(")4:6QF^&H@=6YD
M97)G<G5P<&4@=&EL(%PB)7-<(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,30W(&QI8B](;W)D92]097)M<R]522YP:'`Z,30W"B,L('!H
M<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@7"(E
M<UPB(@IM<V=S='(@(E1I;&;X:B!E;B!U;F1E<G)E='1I9VAE9"!T:6P@7"(E
M<UPB(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U
M<V5R.B(*;7-G<W1R(")/<')E='1E(&5N(&YY(&)R=6=E<CHB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34V"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU-38*;7-G:60@(D%D9"!C
M;VQU;6XB"FUS9W-T<B`B5&EL9OAJ(&MO;&]N;F4B"@HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V5D:70N:6YC.C,T"FUS9VED(")!9&0@;F5W(&UE;6)E
M<G,B"FUS9W-T<B`B5&EL9OAJ(&YY92!M961L96UM97(B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R
M(")/<')E="!P87(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Q"B,L
M('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL
M;&$@4VED96)A<B(*;7-G<W1R(")4:6QF^&H@)7,M;65N=65N('-O;2!E;B!-
M;WII;&QA(%-I9&5B87(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z-S$@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HW,0IM<V=I9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B5&EL
M9OAJ('1I;"!A9')E<W-E:V%R=&]T96LZ(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C<X(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z-S@*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB
M"FUS9W-T<B`B5&EL9OAJ('1I;"!M:70@861R97-S96MA<G1O=&5K(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,S$*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(D]P
M<F5T(&)R=6=E<B(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@
M8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@
M(@HB)7,N(@IM<V=S='(@(B(*(DAA<B!T:6QF^&IE="!<(B5S7"(@=&EL('-Y
M<W1E;65T+"!M96X@:W5N;F4@:6MK92!T:6QF^&IE(&5K<W1R82`B"B)O<'-K
M<FEV;FEN9W-I;F9O<FUA=&EO;CH@)7,N(@H*(SH@<VEG;G5P+G!H<#HT-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E
M;2X@66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R(")4:6QF^&IE="!<(B5S
M7"(@=&EL('-Y<W1E;65T+B!$=2!K86X@;&]G9V4@:6YD(&YU+B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@
M=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(D]P<F5T=&5L<V4@868@8G)U
M9V5R92!E<B!S;.5E="!F<F$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ-S,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T
M,0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30T,2!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$R-@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$W,PIM<V=I9"`B061D<F5S<R(*;7-G<W1R(")!9')E<W-E
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$T,0IM<V=I9"`B061D
M<F5S<R!";V]K(@IM<V=S='(@(D%D<F5S<V5K87)T;W1E:R(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4V(&QI8B](;W)D92])34%0
M+T%#3"]R9F,T,S$T+G!H<#HU-@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.30*;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO
M;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S='(@(D%D;6EN:7-T<NER("T@:6YD
M<W1I;"!T:6QL861E;'-E<B!F;W(@86YD<F4@8G)U9V5R92(*"B,Z(&%D;6EN
M+VEN9&5X+G!H<#HQ.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S
M"FUS9VED(")!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')A=&EO
M;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#,*;7-G:60@(D%D
M<R(*;7-G<W1R(")296ML86UE<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B069G:&%N:7-T
M86XB"FUS9W-T<B`B069G:&%N:7-T86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%L8F%N
M:6$B"FUS9W-T<B`B06QB86YI96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-S0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D%L9V5R:6$B
M"FUS9W-T<B`B06QG97)I970B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3`W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R(")+86QD96YA=FXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C$V"FUS9VED(")!;&EG;B(*;7-G<W1R(")/<'-T:6QL:6YG(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I
M9"`B06QI9VYM96YT.B(*;7-G<W1R(")*=7-T97)I;F<Z(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C@W"FUS9VED(")!;&PB"FUS9W-T<B`B06QL92(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C`W(&QI8B](;W)D
M92]097)M<R]522YP:'`Z,C`W"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-C4*;7-G:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@
M(D%L;&4@YF=T961E(&)R=6=E<F4B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S
M(&%D;6EN+V=R;W5P<RYP:'`Z,C(R"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S
M='(@(D%L;&4@9W)U<'!E<B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z.3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+V1A=&%T<F5E+G!H<#HW
M-0HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.CDQ(&QI8B](;W)D92]097)M
M<R]D871A=')E92YP:'`Z-S4*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G
M<W1R(")!;&QE('1I;&QA9&5L<V5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@
M<VED97,B"FUS9W-T<B`B06QL92!F:7)E('-I9&5R(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3@W,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W,0IM
M<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(E1I;&QA
M9"!M=6QT:7!L92!A9')E<W-E<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU,S@*;7-G:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y
M<&4_(@IM<V=S='(@(E1I;&QA9"!A;F=I=F5L<V4@868@;W)D;F5T(&QI<W1E
M='EP93\B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H
M<#HU,#0@;&EB+TAO<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS9VED(")!
M;')E861Y(&5X:7-T<R(*;7-G<W1R(")%:W-I<W1E<F5R(&%L;&5R961E(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-@IM<V=I9"`B06QT97)N871E
M($E-4U`@3&]G:6XB"FUS9W-T<B`B06QT97)N871I=B!)35-0+6QO9VEN(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q,0IM<V=I9"`B06QT97)N871E
M($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B06QT97)N871I=B!)35-0+6MO9&5O
M<F0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`S"FUS9VED(")!;'1E
M<FYA=&4@24U34"!5<V5R;F%M92(*;7-G<W1R(")!;'1E<FYA=&EV($E-4U`M
M8G)U9V5R;F%V;B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U
M"FUS9VED(")!;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R(")$:6X@
M92UM86EL+6%D<F5S<V4B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM
M<V=I9"`B06QT97)N871E('1E;7!L871E<R(*;7-G<W1R(")!;'1E<FYA=&EV
M92!S:V%B96QO;F5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(U"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"FUS9VED(")!;'1E<FYA=&4@=&5X
M=#HB"FUS9W-T<B`B06QT97)N871I=B!T96MS=#HB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@
M(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(D%M97)I:V%N<VL@4V%M;V$B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,3$U"B,Z(&QI8B](;W)D92]0<F5F<R]522YP
M:'`Z.34@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL
M;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB"FUS9W-T<B`B1&5N(';F<F1I
M+"!D97(@8FQE=B!A;F=I=F5T+"!V87(@:6MK92!G>6QD:6<N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-0IM<V=I9"`B06X@=6YK;F]W
M;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B1&5R(&5R(&]P<W3E970@
M96X@=6ME;F1T(&9E:FPN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O<G)A(@IM<V=S
M='(@(D%N9&]R<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*;7-G<W1R(")!
M;F=O;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I;&QA(@IM<V=S='(@(D%N9W5I
M;&QA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X
M>2(*;7-G<W1R(")!;F]N>6UI<V5R96YD92!P<F]X>2(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T<B`B
M0F5S=F%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(E-Y
M9'!O;&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM
M<V=S='(@(D%N=&EG=6$@86YD($)A<F)U9&$B"@HC.B!A9&UI;B]P:'!S:&5L
M;"YP:'`Z,S8@861M:6XO=&5M<&QA=&5S+G!H<#HW-`HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO54DN<&AP.C4X(&QI8B](;W)D92]";&]C:R]522YP:'`Z
M-3@*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I
M9"`B07!P;&EC871I;VXB"FUS9W-T<B`B07!P;&EK871I;VXB"@HC.B!U=&EL
M+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B
M"FUS9W-T<B`B07!P;&EK871I;VYS;&ES=&4B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,30P"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS
M9W-T<B`B07!P;&EK871I;VX@97(@<&%R870N(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O($-H:6QD(%-H87)E
M<R(*;7-G<W1R(")0Y6;X<B!U;F1E<F1E;&EN9V5R(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS
M9W-T<B`B1V]D:V5N9"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C@T,B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#0R"FUS
M9VED(")!<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@(D-I<FMA<W3X<G)E;'-E
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0S
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#4@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!<')I
M;"(*;7-G<W1R(")!<')I;"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X
M"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`B07)A8FES
M:R`H5VEN9&]W<RTQ,C4V*2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-3D@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HW.`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C8V(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C4Y"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<X(&QI8B](;W)D92]-24U%+U9I
M97=E<B]Z:7`N<&AP.C8V"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G
M<W1R(")!<FMI=BUF:6QS=/AR<F5L<V4B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z-S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HV-2!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HU.`HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW-R!L:6(O2&]R9&4O
M34E-12]6:65W97(O>FEP+G!H<#HV-0IM<V=I9"`B07)C:&EV92!.86UE(@IM
M<V=S='(@(D%R:VEV;F%V;B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E
M;6]V97%U975E9"YI;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO
M=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@
M9F]R("5S(#\B"FUS9W-T<B`B17(@9'4@<VEK:V5R('#E+"!A="!D=2!V:6P@
M<VQE='1E(&]P<VMR:79N:6YG<V%N;6]D;FEN9V5N(&9O<B`E<R`_(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<
M(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R(")%<B!D=2!S:6MK
M97(L(&%T(&1U(/AN<VME<B!A="!S;&5T=&4@7"(E<UPB(&]G(&5N:'9E<B!U
M;F1E<F=R=7!P93\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C8@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R
M(")!<F=E;G1I;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B
M07)M96YI96XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B
M07)M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B07)M96YS:R`H05)-4T-)
M22TX*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.`IM<V=I9"`B07)T
M(@IM<V=S='(@(DMU;G-T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,P(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!<G5B82(*;7-G<W1R
M(")!<G5B82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD
M(@IM<V=S='(@(D%S8V5N<VEO;OAE;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HR.0IM<V=I9"`B07-C:6D@07)T(@IM<V=S='(@(D%30TE)($%R="(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-2!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I9FEC(%)E9VEO;B(*
M;7-G<W1R(")!<VEA=&ES:R]S=&EL;&5H879S<F5G:6]N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0R.0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I
M;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S
M='(@(E-P^')G(&5F=&5R(&)E:W+F9G1E;'-E(&;X<B!U9&;X<F5L<V4@868@
M=F5D;&EG96AO;&1E;'-E<VAA;F1L:6YG97(_(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S`Y-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S`Y-0IM<V=I
M9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(E1I;&1E;"!K;VQO;FYE
M<B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@(D%T=&5M<'0@=&\@
M9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R(")&;W)S^&<@
M<.4@870@<VQE='1E(&5N(&EK:V4M96MS:7-T97)E;F1E(&=R=7!P92XB"@HC
M.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C(Y"FUS9VED(")!='1E;7!T('1O
M(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")&
M;W)S^&<@<.4@870@<VQE='1E(&5N(&EK:V4M96MS:7-T97)E;F1E('1I;&QA
M9&5L<V4N(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*;7-G:60@(D%T
M=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G
M<W1R(")&;W)S^&<@<.4@870@YFYD<F4@96X@:6MK92UE:W-I<W1E<F5N9&4@
M=&EL;&%D96QS92XB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*
M;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB
M"FUS9W-T<B`B1F]R<_AG('#E(&%T(.9N9')E(&5N(&EK:V4M96MS:7-T97)E
M;F1E(&1E;&EN9RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C8T(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z
M.#,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,2!L
M:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV-`HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=&=Z+G!H<#HX,R!L:6(O2&]R9&4O34E-12]6:65W97(O
M>FEP+G!H<#HW,0IM<V=I9"`B071T<FEB=71E<R(*;7-G<W1R(")!='1R:6)U
M='1E<B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#D*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T-PHC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Y
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B
M075G=7-T(@IM<V=S='(@(D%U9W5S="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')A
M;&EA(@IM<V=S='(@(D%U<W1R86QI96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R
M:6$B"FUS9W-T<B`BV'-T<FEG(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)S<6PN<&AP.C$V."!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C$V.`IM
M<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)S<6PZ($MRYG9E="!)34%0+75D
M=FED9&5L<V4@:6MK92!F=6YD970N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)U<RYP:'`Z,3,U(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ,S4*
M;7-G:60@(D%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U
M:7)E9"!C87!A8FEL:71E<RXB"FUS9W-T<B`B075T:%]C>7)U<SH@0F%C:V5N
M9"!H87(@:6MK92!D92!N^&1V96YD:6=E(&5V;F5R+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER=7,N<&AP.C$R,B!L:6(O2&]R9&4O075T:"]C>7)U
M<RYP:'`Z,3(R"FUS9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER=7,Z($MRYG9E
M="!)34%0+75D=FED9&5L<V4@:6MK92!F=6YD970N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]F='`N<&AP.C,V(&QI8B](;W)D92]!=71H+V9T<"YP:'`Z
M,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N
M(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB
M9G1P('-W:71C:"XB"FUS9W-T<B`B(@HB075T:%]F='`Z($MRYG9E="!&5%`M
M=61V:61D96QS92!I:VME(&9U;F1E="X@3W9E<G/F="!02%`@;65D("TM96YA
M8FQE+69T<"TB"B)F;&%G970N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I
M;6%P+G!H<#HV-"!L:6(O2&]R9&4O075T:"]I;6%P+G!H<#HV-`IM<V=I9"`B
M075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(D%U=&A?:6UA<#H@2W+F=F5T($E-05`M=61V:61D96QS92!I
M:VME(&9U;F1E="XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP
M.C4Q(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR
M8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B075T:%]K<F(U.B!+<N9V970@2U)"-2UU9'9I9&1E;'-E(&EK:V4@9G5N
M9&5T+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S`R(&QI
M8B](;W)D92]!=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B075T:%]L9&%P.B!!
M9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C
M=&]R>2(*;7-G<W1R("(B"B)!=71H7VQD87`Z(%1I;&;X:F5L<V4@8G)U9V5R
M92!E<B!I:VME('5N9&5R<W3X='1E="!F;W(@06-T:79E($1I<F5C=&]R>2(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S4W(&QI8B](;W)D
M92]!=71H+VQD87`N<&AP.C,U-PIM<V=I9"`B075T:%]L9&%P.B!296UO=FEN
M9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y
M(@IM<V=S='(@(B(*(D%U=&A?;&1A<#H@4VQE=&YI;F<@868@8G)U9V5R92!E
M<B!I:VME('5N9&5R<W3X='1E="!V960@06-T:79E($1I<F5C=&]R>2(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-C,@;&EB+TAO<F1E+T%U
M=&@O;&1A<"YP:'`Z-C,*;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VQD87`Z($MR
MYG9E="!,1$%0+75D=FED9&5L<V4@:6MK92!F=6YD970N(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,SD@;&EB+TAO<F1E+T%U=&@O;&1A
M<"YP:'`Z,S,Y"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA
M8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED.B`B"FUS9W-T<B`B075T:%]L9&%P.B!+=6YN92!I:VME('1I;&;X:F4@
M8G)U9V5R("5S+B!397)V97)E;B!S86=D93H@(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HS.#4@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z
M,S@U"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O
M(')E;6]V92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@2V%N(&EK:V4@
M<VQE='1E(&)R=6=E<B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z-#DY(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C0Y.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E
M<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z($MA;B!I:VME(&]P9&%T97)E(&)R
M=6=E<B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#`U
M(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P
M.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@
M1&ER96-T;W)Y+B(*;7-G<W1R("(B"B)!=71H7VQD87`Z($]P9&%T97)I;F<@
M868@8G)U9V5R92!E<B!I:VME('5N9&5R<W3X='1E="!V960@06-T:79E($1I
M<F5C=&]R>2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C0V
M(&QI8B](;W)D92]!=71H+VUC86PN<&AP.C0V"FUS9VED(")!=71H7VUC86PZ
M(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M075T:%]M8V%L.B!+<N9V970@34-!3"UU9'9I9&1E;'-E(&EK:V4@9G5N9&5T
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HV,"!L:6(O2&]R
M9&4O075T:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E<75I
M<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T
M:%]S;6)A=71H.B!+<N9V970@4TU"05542"UU9'9I9&1E;'-E(&EK:V4@9G5N
M9&5T+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O061M:6XN<&AP.C$P-B!L
M:6(O2&]R9&4O24U!4"]!9&UI;BYP:'`Z,3`V"FUS9VED(")!=71H96YT:6-A
M=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N(@IM<V=S='(@(L9G=&YI;F<@
M=F5D($E-05`M<V5R=F5R(&9E:FQE9&4N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")!=71H96YT:6-A=&EO
M;B!F86EL960B"FUS9W-T<B`BQF=T;FEN9R!F96IL961E(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*(SH@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-R!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@
M(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`BQF=T;FEN9R!F
M96IL961E+B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H
M<#HQ-S8@;&EB+TAO<F1E+T%U=&@O<F%D:75S+G!H<#HQ-S8*;7-G:60@(D%U
M=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S
M='(@(L9G=&YI;F<@869V:7-T(&%F(%)!1$E54RUS97)V97(N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX.#(@;&EB+U9&4R]F='`N<&AP.C@X
M,@IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N
M(@IM<V=S='(@(L9G=&YI;F<@;W9E<F9O<B!&5%`M<V5R=F5R(&9E:FQE9&4N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HW,"!L:6(O5D93+W-M
M8BYP:'`Z-S`*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R
M=F5R(&9A:6QE9"XB"FUS9W-T<B`BQF=T;FEN9R!O=F5R9F]R(%--0BUS97)V
M97(@9F5J;&5D92XB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C<U
M"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R(")&96QT97(@=&EL
M('+E9&EG:&5D.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,2!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R
M(")!<V5R8F%I9&IA;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM
M<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(D)/1D@M=6YD<VMY;&1N:6YG
M97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C$X"FUS9VED(")"86-K9W)O=6YD(@IM<V=S='(@(D)A8VMG<F]U
M;F0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(D)A9V=R=6YD
M<V9A<G9E(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,2!L
M:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S
M('!A<W-W;W)D+B(*;7-G<W1R(")$Y7)L:6=T(&ME<F)E<F]S+6MO9&5O<F0N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,R!L:6(O2&]R
M9&4O075T:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N
M86UE+B(*;7-G<W1R(")$Y7)L:6=T(&ME<F)E<F]S+6)R=6=E<FYA=FXN(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0U(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8R"FUS9VED(")"86AA;6%S(@IM<V=S='(@(D)A:&%M82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HS."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M,0IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R(")"86AR86EN(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I
M(@IM<V=S='(@(D)A;'1I:W5M("A)4T\M.#@U.2TQ,RDB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,T
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,S0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`*;7-G
M:60@(D)A;F=L861E<V@B"FUS9W-T<B`B0F%N9VQA9&5S:"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HS,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM
M<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B0F%R8F%D;W,B"@HC.B!U=&EL+VEC
M;VY?8G)O=W-E<BYP:'`Z,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G
M<F%P:&EC<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B
M0F%S:7,@9W)A9FEK:V%T86QO9R!<(B5S7"(@:6MK92!F=6YD970N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$Y
M"FUS9VED(")"87-E;&EN92(*;7-G<W1R(")"87-I<VQI;FEE(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C0Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S
M"FUS9VED(")"96QA<G5S(@IM<V=S='(@(DAV:61E<G5S;&%N9"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HS-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M,`IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R(")"96QG:65N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C4P(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS
M9VED(")"96QI>F4B"FUS9W-T<B`B0F5L:7IE(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C0P(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"
M96YI;B(*;7-G<W1R(")"96YI;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#$@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C,T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT
M,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*
M;7-G<W1R(")"97)M=61A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0V(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")":'5T86XB"FUS9W-T
M<B`B0FAU=&%N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$Q,0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$Q,0IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B1OAD<V5L<V1A9R(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS-C<@;&EB
M+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,V-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")";&]C:R!<(B5S7"(@;V8@87!P;&EC871I;VX@7"(E<UPB(&YO
M="!F;W5N9"XB"FUS9W-T<B`B0FQO:R!<(B5S7"(@868@87!P;&EK871I;VX@
M7"(E<UPB(&EK:V4@9G5N9&5T+B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHY,`IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B0FQO
M:RUE9V5N<VMA8F5R(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC
M.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@(D)L;VMT>7!E(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX"FUS9VED
M(")";VQD(@IM<V=S='(@(D9E9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#,@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C,V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT
M,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F]L:79I82(*
M;7-G<W1R(")";VQI=FEE;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR,#<*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R(")";V=MYG)K97(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(P"FUS9VED(")";W)D97(B"FUS9W-T<B`B4F%N9"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E
M<B!T:&EC:VYE<W,Z(@IM<V=S='(@(E)A;6UE='EK:V5L<V4Z(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0IM
M<V=I9"`B0F]R9&5R<R(*;7-G<W1R(")286YD92(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HS,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B
M0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R(")";W-N:65N(&]G($AE
M<GIE9V]V:6YA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED
M(")";W1H(@IM<V=S='(@(D)E9V=E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT."!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C0X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W1S=V%N
M82(*;7-G<W1R(")";W1S=F%N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@IM<V=I9"`B0F]T=&]M(@IM<V=S
M='(@(D)U;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HS.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#<@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T
M<B`B0F]U=F5T^&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0T(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B
M0G)A<VEL:65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C0Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3<@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(D)R:71I<V@@26YD:6%N($]C
M96%N(%1E<G)I=&]R>2(*;7-G<W1R(")"<FET:7-K+4EN9&EE;B!/8V5A;F]M
M<N5D92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C0R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T
M<B`B0G)U;F5I($1A<G5S<V%L86TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,W(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,S<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U;&=A<FEA
M(@IM<V=S='(@(D)U;&=A<FEE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D($QI<W0B"FUS
M9W-T<B`B4'5N:W1L:7-T92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S8@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C0T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS-B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R:VEN82!&87-O
M(@IM<V=S='(@(D)U<FMI;F$@1F%S;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,SD@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HS.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R=6YD
M:2(*;7-G<W1R(")"=7)U;F1I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0T-@IM<V=I9"`B0TU3(@IM<V=S='(@(D--4R(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S4@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G<W1R(")#4D,B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y."!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4Y.`IM<V=I9"`B0U),($1I<W1R:6)U=&EO
M;B!0;VEN=',B"FUS9W-T<B`B0U),(&1I<W1R:6)U=&EO;G-S=&5D97(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B0V5L
M;&4M96=E;G-K86)E<BXN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-3$*;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N
M(@IM<V=S='(@(DEN:71I86QI<V5R:6YG(&%F(&UI9&QE<G1I9&EG="!L86=E
M<B!I:VME(&;F<F1I9V=J;W)T+B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT.#4@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,38*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,38@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-0HC.B!C;VYF:6<O:&]O:W,N<&AP
M+F1I<W0Z,3`T,"!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,34W"FUS9VED
M(")#86QE;F1A<B(*;7-G<W1R(")+86QE;F1E<B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,S4*;7-G:60@(D-A;&TB"FUS9W-T<B`B5FEN
M9'-T:6QL92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3(X(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HT-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(X(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R(")+
M86UB;V1I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C0W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,"!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B0V%M
M97)O=6XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I
M9"`B0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT
M86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B2V%N(&EK:V4@;G5L
M<W1I;&QE(&MO9&5O<F0@875T;VUA=&ES:SL@:V]N=&%K="!D:6X@861M:6YI
M<W1R871O<BXB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS-3`@
M;&EB+T9I;&4O0U-6+G!H<#HS-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N
M(&YO="!W<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R(")+86X@:6MK92!S
M:W)I=F4@=&EL(&9I;"!<(B5S7"(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z
M,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H
M86YD;&5R<RXB"FUS9W-T<B`B2V%N(&EK:V4@:.5N9'1E<F4@96MS=&5R;F4@
M<V5S<VEO;G-HY6YD=&%G+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M<W%L+G!H<#HS,3D@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C,U
M"B,Z(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,S$Y(&QI8B](;W)D92]!
M=71H+V-Y<G5S+G!H<#HR,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@
M8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`B2V%N(&EK:V4@
M9F]R8FEN9&4@=&EL($E-05`@<V5R=F5R+B`E<R(*"B,Z(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C0T-B!L:6(O1FEL92]#4U8N<&AP.C0T-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#86XG="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G
M<W1R(")+86X@:6MK92#E8FYE(&9I;"!<(B5S7"(N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C4Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8T"FUS9VED
M(")#86YA9&$B"FUS9W-T<B`B0V%N861A(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-C4@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE
M87(N:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z
M,3(@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q"FUS9VED
M(")#86YC96PB"FUS9W-T<B`B06YN=6QL97(B"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P
M;W)T(@IM<V=S='(@(D%F8G)Y9"!R97!O<G1E<FEN9R!A9B!P<F]B;&5M(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,C,@;&EB+U9&4R]F='`N
M<&AP.C,R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R(")+86X@:6MK92!S;&5T=&4@9FEL(%PB)7-<
M(BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HT-@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO
M8V]P>2YP:'`Z-3(*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDO8V]P>2YP:'`Z-#8*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M<&]R
M87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B2V%N(&EK:V4@9FEN9&4@970@;6ED
M;&5R=&ED:6=T(&MA=&%L;V<N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+G!H<#HY,2!L:6(O5D93+TE33U=R:71E<BYP:'`Z.3$*
M;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A
M<F%M971E<BXB"FUS9W-T<B`B2V%N(&EK:V4@9F]R='/F='1E('5D96X@)W1A
M<F=E=$9I;&4G+7!A<F%M971R96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HS,3D@;&EB+U9&4R]F='`N<&AP.C,Q.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S
M='(@(DMA;B!I:VME(&9J97)N92!K871A;&]G(%PB)7-<(BXB"@HC.B!F<F%M
M97=O<FLO1&%T851R964O1&%T851R964N<&AP.C$R."!F<F%M97=O<FLO1&%T
M851R964O1&%T851R964O<W%L+G!H<#HV.#`*(SH@;&EB+TAO<F1E+T1A=&%4
M<F5E+G!H<#HQ,C@@;&EB+TAO<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L
M('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N
M(&5X:7-T+B(*;7-G<W1R(")+86X@:6MK92!F:F5R;F4L("5D(&+X<FX@96MS
M:7-T97)E<BXB"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L
M+G!H<#HV,#@@;&EB+TAO<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED
M("(B"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI
M960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E
M9"XB"FUS9W-T<B`B(@HB2V%N(&EK:V4@;VUF;W)D96QE.R!A;G1A;&QE="!A
M9B!P=6YK=&5R(&%N9VEV970@=&EL(&]M9F]R9&5L:6YG('-V87)E<B!I:VME
M("(*(G1I;"!D970@;W!B979A<F5D92!A;G1A;"XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R
M;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(DMA
M;B!I:VME(&1I<FEG97)E(&)E<VME9"!T:6P@86YG:79N92!N=6UM97(N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8U(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8X"FUS9VED(")#87!E(%9E<F1E(@IM<V=S='(@(DMA<"!697)D92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C0*;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`B0FEL;&5D=&5K<W0B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0@
M;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I
M97(B"FUS9W-T<B`B561B>61E<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,PIM<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@(DMA
M=&5G;W)I97(@;V<@3>9R:V5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S4@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C4P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,S4@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(D-A>6UA;B!)
M<VQA;F1S(@IM<V=S='(@(D-A>6UA;OAE<FYE(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L;"!0:&]N92(*;7-G
M<W1R(")-;V)I;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C4*;7-G:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G
M<W1R(")#96QL92UE9V5N<VMA8F5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB
M"FUS9W-T<B`B0V5L;&5F;W)R:6YG.B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O
M<&5R=&EE<R(*;7-G<W1R(")#96QL92UE9V5N<VMA8F5R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E
M;&P@<W!A8VEN9SHB"FUS9W-T<B`B0V5L;&4M;65L;&5M<G5M.B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-S0@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$R-S0*;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R(")-;V)I;'1E;&5F;VXB
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0V5L=&EC("A)
M4T\M.#@U.2TQ-"DB"FUS9W-T<B`B2V5L=&ES:R`H25-/+3@X-3DM,30I(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR-@IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(D-E;G1RZ7(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-30@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C4*
M;7-G:60@(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R(")$96X@
M8V5N=')A;&%F<FEK86YS:V4@4F5P=6)L:6LB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X,@IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM
M,BDB"FUS9W-T<B`B0V5N=')A;"UE=7)O<.9I<VL@*$E33RTX.#4Y+3(I(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#`@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#`*;7-G:60@(D-E<G1I9FEC871E($1E
M=&%I;',B"FUS9W-T<B`B0V5R=&EF:6MA="UD971A;&IE<B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C$R(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-C$R"FUS9VED(")#97)T:69I8V%T92!/=VYE<B(*;7-G
M<W1R(")#97)T:69I:V%T+65J97(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4Y-R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y
M-PIM<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B0V5R=&EF
M:6MA="UP;VQI=&EK:V5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HU,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(Q
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B0VAA9"(*;7-G
M<W1R(")48VAA9"(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR
M-"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*;7-G:60@(D-H86YG
M92(*;7-G<W1R("+&;F1R92(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HS,0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B
MQFYD<F4@9&ET(&MO9&5O<F0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-CD*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T
M('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@
M(@HB96UA:6QS+B(*;7-G<W1R("(B"B)(97(@:V%N(&1U(.9N9')E(&1E="!N
M879N(&]G(&1E;B!A9')E<W-E+"!S;VT@86YD<F4@<V5R+"!NY7(@9&4@;.9S
M97(@;V<@(@HB<W9A<F5R('#E(&1I;F4@92UM86EL+B(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U
M<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@
M8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R
M+B(*;7-G<W1R("(B"B)+;V1E;W)D<^9N9')I;F<@97(@:6MK92!U;F1E<G-T
M^'1T970@868@9&5N(&YU=N9R96YD92!O<'/F=&YI;F<N("!+;VYT86MT("(*
M(F1I;B!A9&UI;FES=')A=&]R+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*;7-G:60@(D-H87(B"FUS9W-T
M<B`B5&5G;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T
M<B`B2&%K(&QI;FL@868N+BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Y(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HU,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3D@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6QE(@IM<V=S
M='(@(D-H:6QE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HV,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-30*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8Q(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EN82(*;7-G<W1R(")+:6YA
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(D-H:6YE<V4@
M4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R(")3:6UP;&EF:6-E<F5T(&MI
M;F5S:7-K("A'0C(S,3(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*
M;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S='(@(E1R
M861I=&EO;F5L="!K:6YE<VES:R`H0FEG-2DB"@HC.B!T96UP;&%T97,O<')E
M9G,O87!P+FEN8SHW"FUS9VED(")#:&]O<V4@07!P;&EC871I;VXZ(@IM<V=S
M='(@(E;F;&<@87!P;&EK871I;VXZ(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]3:6=N=7`N<&AP.C(W,"!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(W
M,`IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B5N9L9R!E="!K
M;V1E;W)D(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V
M.2!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B0VAO;W-E
M(&$@=7-E<FYA;64B"FUS9W-T<B`B5N9L9R!E="!B<G5G97)N879N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P,@IM<V=I9"`B0VAO;W-E(&AO=R!T
M;R!D:7-P;&%Y(&1A=&5S.B(*;7-G<W1R(")6YFQG(&AV;W)D86X@9&%T;V5R
M('-K86P@=FES97,Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y
M;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I(@IM<V=S='(@(E;F;&<@;&ES
M=&4M<W1I;"`H9F]R(&]R9&YE9&4@;&ES=&5R*2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C4U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C8@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HV-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B
M0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R(")*=6QE^&5N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.CDQ-"!F<F%M97=O<FLO3F5T7U--4R]335,N<&AP
M.C(Y-"!L:6(O5D93+G!H<#HY,30*(SH@;&EB+TYE="]335,N<&AP.C(Y-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D969I;FET:6]N(&]F("5S(&YO
M="!F;W5N9"XB"FUS9W-T<B`B2VQA<W-E9&5F:6YI=&EO;B!A9B`E<R!I:VME
M(&9U;F1E="XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ-`IM<V=I9"`B0VQE87(B"FUS9W-T<B`B2VQA<G0B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#
M;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(D9J97)N($U33V9F:6-E+6]P
M;>9R:VYI;F=E<B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,CD*;7-G:60@
M(D-L96%R(%%U97)Y(@IM<V=S='(@(DYU;'-T:6P@9F]R97-P^')G<V5L(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM<V=S='(@(E)E;G,@
M8G)U9V5R('5D.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R
M+FEN8SHQ,0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R(").=6QS=&EL(&)R
M=6=E<B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T"FUS
M9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`B5FES:R!B<G5G97)D871A
M('5D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,34*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B4V5N(&]P:VQA<FEN
M9R(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL
M.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R(")+;&EK(&9O
M<B!A="!F;W)T<^9T=&4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HQ.#0*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS
M9W-T<B`B0VQI8VMA=&5L;"!V:6$@2%144"(*"B,Z('-E<G9I8V5S+VME>6)O
M87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I
M9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(DQU:R!V:6YD=64B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(U,0IM<V=I9"`B0VQO=61S(@IM<V=S='(@(E-K
M>65R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,38*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R(")3:WEE<B!T:61L:6=T
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3<*
M;7-G:60@(D-L;W5D>2(*;7-G<W1R(")3:WEE="(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C4V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4V"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HU,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B
M0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS9W-T<B`B0V]C;W,@*$ME96QI
M;F<I(-AE<FYE(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR
M,PIM<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R(")&;VQD('-I9&5P
M86YE;"!S86UM96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(X"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*
M;7-G<W1R(")386UM96YF;VQD961E(')A;F1E(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C8R(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#
M;VQO;6)I82(*;7-G<W1R(")+;VQU;6)I96XB"@HC.B!L:6(O0FQO8VLO8V]L
M;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B
M0V]L;W(B"FUS9W-T<B`B1F%R=F4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-3`S"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R]#;VQL96-T:6]N+G!H<#HS,S@*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+T-O;&QE8W1I;VXN<&AP.C,S.0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-3`S(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H
M<#HS,S@*(SH@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,S.2!S
M97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@R"FUS9VED(")#;VQO
M<B!0:6-K97(B"FUS9W-T<B`B1F%R=F5VYFQG97(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.#(X(&QI8B](;W)D92]&;W)M+G!H<#HR.#(X"FUS
M9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@(D9A<G9E=F%L9R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"FUS
M9VED(")#;VQS.B(*;7-G<W1R(")+;VQS.B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Y-#8@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-#8*;7-G:60@
M(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B2V]L;VYN971I=&QE<B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C8*;7-G:60@(D-O;6EC<R(*;7-G
M<W1R(")496=N97-E<FEE<B(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-@IM
M<V=I9"`B0V]M;6%N9"(*;7-G<W1R(")+;VUM86YD;R(*"B,Z(&%D;6EN+V-M
M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R(")+
M;VUM86YD;VQI;FEE(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#$S(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B0V]M
M;65N="(*;7-G<W1R(")+;VUM96YT87(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4V-R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4V-PIM<V=I9"`B0V]M;6]N($YA;64B"FUS9W-T<B`B0V]M;6]N($YA;64B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,"!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX-`IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R(")#;VUO<F5R;F4B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED
M(")#;VUP86YY(@IM<V=S='(@(D9I<FUA(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`B0V]M<'5T97)E
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-@IM<V=I9"`B
M0V]N9&ET:6]N(@IM<V=S='(@(D9O<FAO;&0B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(U-@IM<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R(")"971I;F=E
M;'-E<B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF
M:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S='(@(DMO;F9I9W5R871I;VYS
M9F]R<VME;&QE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-@IM<V=I
M9"`B0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T
M<&AO;F5S(&%N9"!/=71L;V]K+B(*;7-G<W1R(")+;VYF:6=U<F%T:6]N('1I
M;"!S>6YK<F]N:7-E<FEN9R!M960@4$1!97(L(%-M87)T<&AO;F5S(&]G($]U
M=&QO;VLN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0IM<V=I9"`B
M0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B2V]N9FEG
M=7)A=&EO;F5N(&5R(&9O<N9L9&5T+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM
M<V=S='(@(DMO;F9I9W5RZ7(@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C4Q"FUS9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S
M='(@(D)E:W+F9G0@:V]D96]R9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-34@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU
M-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N9V\B"FUS
M9W-T<B`B2V]N9V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4S(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HV,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3,@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R
M871I8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B2V]N9V\L($1E;B!D96UO
M:W)A=&ES:V4@<F5P=6)L:6LB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S`X(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HQ.3<*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.`IM
M<V=I9"`B0V]N;F5C=&EO;B!F86EL960N(@IM<V=S='(@(D9O<F)I;F1E;'-E
M(&UI<VQY:VME9&5S+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C$Y-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS,#@@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y
M-PHC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`X"FUS9VED
M(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(D9O<F)I;F1E;'-E(&UI
M<VQY:VME9&5S.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HW.3`@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-SDP"FUS9VED(")#;VYN
M96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S
M='(@(D9O<F)I;F1E;'-E('1I;"!O9F9E;G1L:6<@;OAG;&5S97)V97(@;N9G
M=&5T+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R
M+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B1F]R8FEN9&5L<V4@=&EL(&]F
M9F5N=&QI9R!N^&=L97-E<G9E<B!NYF=T970N(,5R<V%G.B`E<R`H)7,I(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-S8@;&EB+U9&4R]F='`N
M<&AP.C@W-@IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE
M9"XB"FUS9W-T<B`B1F]R8FEN9&5L<V4@=&EL($944"US97)V97(@;6ES;'EK
M:V5D97,N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C0@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HY,C0*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T
M.C$P-C<*;7-G:60@(D-O;G1A8W1S(@IM<V=S='(@(DMO;G1A:W1E<B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,R!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C4S"FUS9VED(")#;VYT86-T
M<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O
M:RXB"FUS9W-T<B`B2V]N=&%K=&5R(&)L978@=&EL9OAJ970@=&EL(&1I="!A
M9')E<W-E:V%R=&]T96ME="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z-C`@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z
M-C`*;7-G:60@(D-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z("(*
M;7-G<W1R("));F1H;VQD<W1Y<&4@868@:V]M<')I;65R970@9FEL.B`B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4V(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S4*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV,R!L:6(O2&]R9&4O34E-12]6
M:65W97(O<F%R+G!H<#HU-@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z
M+G!H<#HW-2!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O9B!<(B5S7"(B"FUS9W-T<B`B
M26YD:&]L9"!A9B!<(B5S7"(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HR.2!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S,*;7-G:60@
M(D-O;G1I;G5E(@IM<V=S='(@(D9O<G1SYG0B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HV,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4X(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-3@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O
M;VL@27-L86YD<R(*;7-G<W1R(")#;V]K($ES;&%N9',B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R(")3;>5K
M86=E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(Q"FUS9VED(")#;W!Y(@IM<V=S='(@(DMO<&EE<B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#<R(&QI8B]61E,O<VUB+G!H
M<#HT-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z("5S(@IM
M<V=S='(@(DMO<&EE<FEN9R!M:7-L>6MK961E<SH@)7,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,V"FUS9VED(")#;W!Y
M('-E;&5C=&EO;B(*;7-G<W1R(")+;W!IZ7(@;6%R:V5R:6YG(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-S`*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.34@;&EB+TYE="]335,O
M=VEN7VAT='`N<&AP.C$W,`HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z
M,3DU"FUS9VED(")#;W-T($E$(@IM<V=S='(@(D=E8GER($E$(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C8S(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W
M"FUS9VED(")#;W-T82!2:6-A(@IM<V=S='(@(D-O<W1A(%)I8V$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-3<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C8*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B16QF96YB96YS:WES
M=&5N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3<W(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.CDW-PIM<V=I9"`B0V]U;&0@;F]T(%!'
M4"!E;F-R>7!T(&UE<W-A9V4Z("(*;7-G<W1R(")+=6YN92!I:VME(%!'4"UK
M<GEP=.ER92!B97-K960Z("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$P-34@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3`U-0IM<V=I
M9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z("(*;7-G<W1R(")+=6YN
M92!I:VME(%!'4"US:6=NZ7)E(&)E<VME9#H@(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3,@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S
M86=E+B(*;7-G<W1R(")+=6YN92!I:VME(%,O34E-12UK<GEP=&5R92!B97-K
M960N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT-C<@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD(&YO
M="!3+TU)344@<VEG;B!M97-S86=E+B(*;7-G<W1R(")+=6YN92!I:VME(%,O
M34E-12US:6=NZ7)E(&)E<VME9"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C$X-`HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!A9&0@8V]N=&%C="X@)7,B"FUS9W-T<B`B2W5N;F4@:6MK92!T:6QF
M^&IE(&MO;G1A:W0N("5S(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.CDV(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"B,Z
M(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HY-B!L:6(O2&]R9&4O075T:"]L
M9&%P+G!H<#HQ,C$*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0X,@IM<V=I
M9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(DMU
M;FYE(&EK:V4@:V]B;&4@=&EL($Q$05`M<V5R=F5R+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$U-@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R(")+=6YN92!I
M:VME(&MO;G1R;VQL97(@8F%L86YC92X@)7,B"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-#8V"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0
M('-E<G9E<BXB"FUS9W-T<B`B2W5N;F4@:6MK92!F;W)B:6YD92!T:6P@3$1!
M4"US97)V97(N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B!<
M(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R(")+=6YN92!I:VME(&9O<F)I
M;F1E('1I;"!S97)V97(@7"(E<UPB('9E9"!B<G5G(&%F($944#H@)7,B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R
M,@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S(@IM<V=S='(@(DMU;FYE(&EK:V4@;W!R971T92!D:7-T<FEB
M=71I;VYS;&ES=&4N("5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3$R."!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,3(X"FUS9VED
M(")#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@(@IM<V=S='(@(DMU;FYE
M(&EK:V4@9&5K<GEP=&5R92!01U`M9&%T83H@(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU,C,@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HU,C,*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A
M+B(*;7-G<W1R(")+=6YN92!I:VME(&1E:W)Y<'1E<F4@4R]-24U%+61A=&$N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HR-#8*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(T-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N
M("5S(@IM<V=S='(@(DMU;FYE(&EK:V4@<VQE='1E(&MO;G1A:W0N("5S(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS
M-38*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<R(*;7-G<W1R(")+=6YN92!I:VME('-L971T92!D:7-T<FEB
M=71I;VYS;&ES=&4N("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S971U
M<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(DMU;FYE(&EK:V4@
M<VQE='1E(#QE;3YS8W)I<'0\+V5M/B!<(B5S7"(@=&EL(&]P9W)A9&5R:6YG
M(&%F(&]P<^9T;FEN9RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HY-3,@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.#$*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS.#$@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z.34S"FUS9VED(")#;W5L9"!N;W0@9&5T97)M:6YE('1H
M92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T<B`B2W5N;F4@
M:6MK92!B97-T96UM92!M;V1T86=E<F5N<R!E+6UA:6PM861R97-S92XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X
M,PHC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED
M(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G
M<W1R(")+=6YN92!I:VME(&AE;G1E(&AE;&4@861R97-S96MA<G1O=&5K+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-#DS"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*;7-G
M:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES
M="XB"FUS9W-T<B`B2W5N;F4@:6MK92!H96YT92!H96QE(&1I<W1R:6)U=&EO
M;G-L:7-T92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C0T-@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-#0V"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI
M<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R(")+=6YN92!I:VME
M(&AE;G1E(&9U;&1S=.9N9&EG(&9O<G1E9VYE;'-E(&]V97(@9&ES=')I8G5T
M:6]N<VQI<W1E<BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP
M.C8X"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP
M:'`Z-C@*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN
M<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T
M<F%T96=Y(%PB)7-<(BXB"FUS9W-T<B`B2W5N;F4@:6MK92!H96YT92!S=')A
M=&5G:2!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U
M='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*(SH@;&EB+U9&4R])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(DMU
M;FYE(&EK:V4@;6MD:7(@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C<Q.2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW,3D*
M;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K
M97ES97)V97(N(@IM<V=S='(@(DMU;FYE(&EK:V4@:&5N=&4@;V9F96YT;&EG
M(&[X9VQE(&9R82!N^&=L97-E<G9E<BXB"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M,3,Y"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C$S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E
M;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S='(@(DMU;FYE(&EK:V4@Y6)N
M92!<(B5S7"(@9F]R('-K<FEV;FEN9RXB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-C(@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8W-PHC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,T-2!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R
M(")+=6YN92!I:VME(.5B;F4@)7,N(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA
M;F-E+TUA:6YT96YA;F-E+G!H<#HT,C`@;&EB+TAO<F1E+TUA:6YT96YA;F-E
M+G!H<#HT,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@
M36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B2W5N;F4@:6MK
M92#E8FYE(&UO9'5L('1I;"!V961L:6=E:&]L9&5L<V4@)7,B"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z-S`*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B2W5N;F4@
M:6MK92#E8FYE(&MA=&%L;V<@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HQ,3$@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C$T-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M,C,W(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C4Q-B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HV-38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C8Y.0HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,3$Q(&QI8B](;W)D
M92]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N
M<&AP.C(S-R!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-#<X"B,Z(&QI8B](
M;W)D92]'<F]U<"]L9&%P+G!H<#HU,38@;&EB+TAO<F1E+T=R;W5P+VQD87`N
M<&AP.C8Q,@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-C4V(&QI8B](
M;W)D92]'<F]U<"]L9&%P+G!H<#HV.3D*;7-G:60@(D-O=6QD(&YO="!R96%C
M:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(DMU;FYE(&EK:V4@;N4@3$1!
M4"US97)V97)E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP
M.C(T,"!L:6(O5D93+T]B:F5C="YP:'`Z,C0P"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!R96%D("5S+B(*;7-G<W1R(")+=6YN92!I:VME(&SF
M<V4@)7,N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G
M:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R
M97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@
M87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G
M<W1R("(B"B)+=6YN92!I:VME(&YU;'-T:6QL92!K;V1E;W)D970@9F]R(&1E
M;B!A;FUO9&5D92!B<G5G97(N("!.;V=L92!E;&QE<B!A;&QE("(*(F1E=&%L
M:F5R(&5R('5K;W)R96MT92X@4'+X=B!I9V5N(&5L;&5R(&MO;G1A:W0@9&EN
M(&%D;6EN:7-T<F%T;W(L(&AV:7,@9'4@(@HB:&%R(&)E:&]V(&9O<B!Y9&5R
M;&EG97)E(&AJYFQP+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,P-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS,S@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S<U"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,X,0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS.#<@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P-PHC.B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S,X(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS-S4*(SH@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,X,2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S@W"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@
M(DMU;FYE(&EK:V4@:&5N=&4@04-,(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-S0*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R(")+=6YN
M92!I:VME(&AE;G1E(&%D<F5S<V5K87)T;W1E:V5T+B`E<R(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<R(*;7-G<W1R(")+=6YN92!I:VME(&AE;G1E(&1I<W1R:6)U=&EO;G-L
M:7-T92X@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C0S-PHC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V
M92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@(DMU;FYE(&EK:V4@
M:&5N=&4@9&ES=')I8G5T:6]N<VQI<W1E<BX@)7,B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$W"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,2!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,3DW"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HR,3<@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,0IM
M<V=I9"`B0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE
M<R(*;7-G<W1R(")+=6YN92!I:VME(&AE;G1E('-E<G9E<G,@979N97(B"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"FUS9VED(")#;W5L9"!N;W0@
M<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DMU;FYE(&EK:V4@9V5N
M9&%N;F4@:V]N9FEG=7)A=&EO;BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*
M(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER(%PB
M)7-<(BXB"FUS9W-T<B`B2W5N;F4@:6MK92!R;61I<B!<(B5S7"(N(@H*(SH@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M2W5N;F4@:6MK92!G96UM92`E<RUK;VYF:6=U<F%T:6]N(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y
M"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN
M(@IM<V=S='(@(DMU;FYE(&EK:V4@9V5M;64@96X@8F%C:W5P+6MO;F9I9W5R
M871I;VXN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A
M=&EO;CH@)7,B"FUS9W-T<B`B2W5N;F4@:6MK92!G96UM92!E;B!B86-K=7`M
M:V]N9FEG=7)A=&EO;CH@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HY-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U
M<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(")+=6YN92!I
M:VME(&=E;6UE('-C<FEP="!T:6P@;W!G<F%D97)I;F<@868@;W!SYG1N:6YG
M('1I;#H@7"(E<UPB+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU
M<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(DMU;FYE(&EK:V4@
M9V5M;64@8F%C:W5P+6MO;F9I9W5R871I;VYS9FEL96X@)7,N(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9
M;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A
M=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C
M;V1E(&)E;&]W('1O("5S+B(*;7-G<W1R("(B"B)+=6YN92!I:VME(&=E;6UE
M(&MO;F9I9W5R871I;VYS9FEL96X@)7,N($1U(&MA;B!E;G1E;B!A;G9E;F1E
M(&5N(&%F("(*(FUU;&EG:&5D97)N92!F;W(@870@9V5M;64@:V]D96X@=&EL
M8F%G92!PY2`E<R!E;&QE<B!M86YU96QT(&MO<&EE<F4@:V]D96X@(@HB;F5D
M96YF;W(@=&EL("5S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z,30S(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C$T,PIM<V=I9"`B0V]U
M;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(DMU;FYE
M(&EK:V4@<_AG92!,1$%0+7-E<G9E<F5N+B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HX-@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HX-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL
M:6YK(%PB)7-<(BXB"FUS9W-T<B`B2W5N;F4@:6MK92`\96T^=6YL:6YK/"]E
M;3X@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,C$Y"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T
M92!C;VYT86-T+B`E<R(*;7-G<W1R(")+=6YN92!I:VME(&]P9&%T97)E(&MO
M;G1A:W0N("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HS.38*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C,Y-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")+=6YN92!I:VME(&]P
M9&%T97)E(&1I<W1R:6)U=&EO;G-L:7-T92X@)7,B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B
M2W5N;F4@:6MK92!S:W)I=F4@:V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E
M<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S`*;7-G:60@(D-O=6QD
M;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S
M:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(DMU;FYE(&EK:V4@9FEN9&4@36]Z
M:6QL82!3:61E8F%R+B!&;W)V:7,@9&EG(&]M(&%T('-I9&5B87)E;B!E<B#E
M8F5N+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C$U-"!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E<B!<(B5S7"(@
M=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB.B`E
M<R(*;7-G<W1R("(B"B)+=6YN92!I:VME(&=I=F4@8G)U9V5R(%PB)7-<(B!F
M^&QG96YD92!R971T:6=H961E<B!T:6P@;6%P<&5N(%PB)7-<(CH@)7,B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#$Y(&QI8B](;W)D92]&;W)M
M+G!H<#HQ-#$Y"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B3W!T86QT
M('1E:W-T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-S`@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@(D-O=6YT
M<GDB"FUS9W-T<B`B3&%N9"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR-S4*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B2W5R<V5R(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M,3`P"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B3W!R970B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G
M:60@(D-R96%T92!A(&QI;FLB"FUS9W-T<B`B3W!R970@96X@:&5N=FES;FEN
M9R(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.30*
M;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`B3W!R970@96X@;GDB
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,B!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3(*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.CDR"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E
M<G,B"FUS9W-T<B`B3W!R970@=6YD97)M87!P92(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,C0P(&QI8B](;W)D92]097)M<R]522YP:'`Z
M,C0P"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(E-K86)E
M<G,@<F5T=&EG:&5D97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,C$R(&QI8B](;W)D92]&;W)M+G!H<#HS,C$R"FUS9VED(")#<F5D:70@8V%R
M9"!N=6UB97(B"FUS9W-T<B`B2W)E9&ET:V]R="UN=6UM97(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$P.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$P.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M.0IM<V=I9"`B0W)O871I82(*;7-G<W1R(")+<F]A=&EE;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HV-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM
M<V=I9"`B0W5B82(*;7-G<W1R(")#=6)A(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C(V"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@(DYU=N9R
M96YD92`T(&9A<V5R(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4P"FUS9VED
M(")#=7)R96YT(%-E<W-I;VYS(@IM<V=S='(@(DEN9&5VYG)E;F1E('-E<W-I
M;VXB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,R!L:6(O0FQO8VLO=&EM92YP
M:'`Z,S`*;7-G:60@(D-U<G)E;G0@5&EM92(*;7-G<W1R(")!:W1U96P@=&ED
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4T"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G<W1R(").=7;F
M<F5N9&4@55),(&5R(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,U"FUS9VED
M(")#=7)R96YT(%5S97)S(@IM<V=S='(@(DYU=N9R96YD92!B<G5G97)E(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I9"`B0W5R<F5N="!796%T
M:&5R(@IM<V=S='(@(D%K='5E;'0@=F5J<B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-C0*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B
M"FUS9W-T<B`B3G5VYG)E;F1E('9E:G(Z("(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y
M;&4B"FUS9W-T<B`B06MT=65L('-T:6PB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3$Q"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K
M<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B5&EL<&%S(&]P
M9V%V97(L(&1E<B!B;&EV97(@=61F^')T+"!NY7(@9'4@;&]G9V5R(&EN9"!I
M("5S+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(DML:7`B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,U"FUS9VED
M(")#=70@<V5L96-T:6]N(@IM<V=S='(@(DML:7`@=F%L9R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8V"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HV-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM
M<V=I9"`B0WEP<G5S(@IM<V=S='(@(D-Y<&5R;B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@U"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R
M(")+>7)I;&QI<VL@*$M/23@M4BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X-@IM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`B
M2WER:6QL:7-K("A7:6YD;W=S+3$R-3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#<*;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*
M;7-G<W1R(")+>7)I;&QI<VLO56MR86EN<VL@*$M/23@M52DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C8X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-C@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*
M;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@(E1J96MK:65T(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4R('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R(")$1"(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-S(@;&EB+TAO<F1E+T9O<FTN<&AP
M.C,R-S(*;7-G:60@(B(*(D133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O
M;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB
M"FUS9W-T<B`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU
M86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*"B,Z
M(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3D@;&EB
M+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T
M<B`B1&%G;&EG(@H*(SH@861M:6XO9&%T871R964N<&AP.C8U"FUS9VED(")$
M871A5')E92!"<F]W<V5R(@IM<V=S='(@(D1A=&%4<F5E('-T:69I;F1E<B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-S`@;&EB+TAO<F1E+T9O
M<FTN<&AP.C,R-S`*;7-G:60@(D1A=&%B87-E($QO;VMU<"(*;7-G<W1R(")$
M871A8F%S92UO<'-L86<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S.3@*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S.3@@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)F8S@R,BYP:'`Z-S(*;7-G:60@(D1A=&4B"FUS9W-T<B`B1&%T;R(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED
M(")$871E(%)E8V5I=F5D(@IM<V=S='(@(DUO9'1A9V5L<V5S9&%T;R(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W.#D@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(W.#D*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM<V=S='(@(D1A=&]V
M86QG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X,2!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Q"FUS9VED(")$87DB"FUS9W-T
M<B`B1&%G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,V"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G<W1R
M(")3;&5T(&MO;&]N;F4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-3$*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0Q,R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#4Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(D1E8V5M8F5R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ
M-@IM<V=I9"`B1&5C:6UA;"!N=6UB97)S(@IM<V=S='(@(D1E8VEM86QT86PB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(P
M"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`B36EN9'-K(&EN9')Y
M:VYI;F<B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$X-R!L
M:6(O<')E9G,N<&AP.C$Q-PHC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$X
M-PIM<V=I9"`B1&5F875L="(*;7-G<W1R(")3=&%N9&%R9"(*"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"FUS9VED(")$
M969A=6QT($-O;&]R(@IM<V=S='(@(E-T86YD87)D9F%R=F4B"@HC.B!F<F%M
M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.CDV(&QI8B](;W)D92])9&5N
M=&ET>2YP:'`Z.38*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B
M4W1A;F1A<F0M:61E;G1I=&5T(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C<U"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@(E-T86YD87)D+7-K
M86PB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@(D1E9FEN
M:71I;VYS(@IM<V=S='(@(D1E9FEN:71I;VYE<B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-S$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C8*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HT,SD*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HS,C8@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,C(*(SH@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HT,SD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C<P('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z.3,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ.#(@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C<S"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY."!T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,0HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V1E;&5T92YI;F,Z,3`*;7-G:60@(D1E;&5T92(*;7-G<W1R(")3
M;&5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,R"FUS9VED(")$96QE=&4@0V5L;"(*;7-G<W1R(")3;&5T
M(&-E;&QE(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S
M+G!H<#HR,C<*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R(")3;&5T(&=R
M=7!P92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T.0IM<V=I
M9"`B1&5L971E($QO9R(*;7-G<W1R(")3;&5T(&QO9V)O9R(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z-S<@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HQ,#$*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HW-R!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$P,0IM<V=I9"`B1&5L971E(%!E<FUI
M<W-I;VXB"FUS9W-T<B`B4VQE="!T:6QL861E;'-E<B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDS(&QI8B](;W)D92])34%0
M+T%#3"]R9F,R,#@V+G!H<#HY,PIM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M
M97-S86=E<R(*;7-G<W1R(")&:F5R;B!O9R!U9'-L970@8F5S:V5D97(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4W"FUS9VED(")$96QE=&4@8V5L;"(*;7-G<W1R(")3;&5T(&-E;&QE(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV,PIM<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R(")3;&5T(&MO;&]N
M;F4B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E
M(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R(")3;&5T(&5K
M<VES=&5R96YD92P@86QT97)N871I=F4@<VMA8F5L;VXB"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU-"!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C-#,Q-"YP:'`Z-30*;7-G:60@(D1E;&5T92!M97-S86=E<R(*
M;7-G<W1R(")3;&5T(&)E<VME9&5R(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HT,C$@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,C$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S
M7"(B"FUS9W-T<B`B4VQE="!T:6QL861E;'-E<B!F;W(@7"(E<UPB(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C0@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E
M<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_
M(@IM<V=S='(@(E-L970@=&EL;&%D96QS97(@9F]R(%PB)7-<(B!O9R!A;&QE
M('5N9&5R;W)D;F5D92!T:6QL861E;'-E<C\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED(")$96QE
M=&4@<F]W(@IM<V=S='(@(E-L970@<N9K:V4B"@HC.B!T96UP;&%T97,O<')E
M9G,O9&5L971E:61E;G1I='DN:6YC.C$U"FUS9VED(")$96QE=&4@<V5L96-T
M960@:61E;G1I='DB"FUS9W-T<B`B4VQE="!V86QG=&4@:61E;G1I=&5T(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3,@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C4S"FUS9VED(")$96QE=&4@
M<W5B(&9O;&1E<G,B"FUS9W-T<B`B4VQE="!U;F1E<FUA<'!E<B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M-PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R(")3
M;&5T(&1E;B!A:W1U96QL92!K;VQO;FYE(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED(")$96QE
M=&4@=&AE(&-U<G)E;G0@<F]W(@IM<V=S='(@(E-L970@9&5N(&%K='5E;&QE
M('+F:VME(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<
M(B5S7"(N(@IM<V=S='(@(D]P9W)A9&5R:6YG<W-C<FEP="!<(B5S7"(@<VQE
M='1E="XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR,C$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C4S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-38S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU-C,@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4Y-0HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,2!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PIM<V=I9"`B1&5L
M:79E<GD@=&EM92(*;7-G<W1R("),979E<FEN9W-T:61S<'5N:W0B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C<Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-S$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-CD*;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`B1&%N;6%R:R(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T
M:&4@4')O8FQE;2(*;7-G<W1R(")"97-K<FEV('!R;V)L96UE="(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDS."!L:6(O2&]R9&4O1F]R;2YP:'`Z
M.3,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S`*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(D)E<VMR:79E
M;'-E(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HR,#8@;&EB+TAO
M<F1E+G!H<#HR,#8*;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L
M;V=F:6QE*3HB"FUS9W-T<B`B1&5T86QJ97(@*&]G<^4@:2!(;W)D92=S(&QO
M9V9I;"DZ(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HR,3`@;&EB
M+TAO<F1E+G!H<#HR,3`*;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO9V=E
M9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(D1E=&%L:F5R(&5R
M('-K<F5V970@=&EL(&QO9V)O9V5N(&%F(&AE;G-Y;B!T:6P@861M:6YI<W1R
M871O<F5N+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,C$*;7-G
M:60@(D1E=F5L;W!M96YT(@IM<V=S='(@(E5D=FEK;&EN9R(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C(T"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B
M1'5G<'5N:W0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P,0IM<V=I9"`B
M1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")$=6=P=6YK="!F
M;W(@<VED<W1E('1I;64Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,38*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(D1U9W!U;FMT
M.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R(")2
M971N:6YG('9E;G-T<F4@=&EL(&CX:G)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I
M9VAT('1O(&QE9G0B"FUS9W-T<B`B4F5T;FEN9R!H^&IR92!T:6P@=F5N<W1R
M92(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O
M<GDB"FUS9W-T<B`B2V%T86QO9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-S`*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B
M5FES('1I9"!M960@,C0@=&EM97(_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$P,`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(DEN9'-T
M:6QL:6YG97(@9F]R('9I<VYI;F<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z.#D*;7-G:60@(D1I<W!L87D@9&5T86EL960@9F]R96-A<W0B
M"FUS9W-T<B`B5FES('5D9'EB96YD92!V96IR=61S:6=T(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HY,@IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&
M*2(*;7-G<W1R(")6:7,@=F5J<G5D<VEG="`H5$%&*2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(W.3D@;&EB+TAO<F1E+T9O<FTN<&AP.C(W.3D*
M;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM<V=S='(@(E9I<VYI;F=S9F]R;6%T
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C$Y,2!L:6(O2&]R
M9&4O34E-12]-1$XN<&AP.C$Y,0IM<V=I9"`B1&ES<&]S:71I;VX@3F]T:69I
M8V%T:6]N(@IM<V=S='(@(D]V97)D<F%G96QS97-N;W1I=',B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C<P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-S`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*
M;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(D1J:6)O=71I(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HT,C(*;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B1F]R=')Y
M9"!S;&5T;FEN9R(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR-0IM
M<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'`B
M"FUS9W-T<B`B1'4@;>4@:6MK92!K86QD92!M86EN=&5N86YC92YP:'`@9&ER
M96MT92(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$R('1E;7!L
M871E<R]D871A+W1S=FEN9F\N:6YC.C$R"FUS9VED(")$;V5S('1H92!F:7)S
M="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@
M=&AI<R!B;W@Z(@IM<V=S='(@(DEN9&5H;VQD97(@9&5N(&;X<G-T92!RYFMK
M92!F96QT;F%V;F4_($AV:7,@:F$L(&UA<FOI<B!D96YN92!B;VMS.B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HW,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B1&5N(&1O;6EN:6MA;G-K
M92!297!U8FQI:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C<Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,R!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC
M(@IM<V=S='(@(D1E;B!D;VUI;FEK86YS:V4@4F5P=6)L:6LB"@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDV"FUS9VED(")$;VXG="!H879E(&%N
M(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@(DAA<B!D=2!I:VME(&YO9V5N
M(&MO;G1O/R!-96QD(&1I9R!T:6PN(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z.#4S(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H
M<#HX-3,*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(DAE;G0B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-3,@;&EB+TAO<F1E+TU)
M344O0V]N=&5N=',N<&AP.C@U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N
M;&]A9"`E<R(*;7-G<W1R(")(96YT("5S(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`B2&5N="!G96YE<F5R970@
M:V]N9FEG=7)A=&EO;B!N960@<V]M(%!(4"US8W)I<'0N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C$P-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$P
M-PIM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B4G5L;&5G87)D:6XM
M;&ES=&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R
M=6=S(@IM<V=S='(@(DUE9&EK86UE;G1E<B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0Q,R!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT
M,3,*;7-G:60@(D4M36%I;"(*;7-G<W1R(")%+6UA:6PB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,B!L:6(O3F5T+U--
M4R]G96YE<FEC7W-M='`N<&AP.CDR"FUS9VED(")%36%I;"UT;RU335,@9V%T
M97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@
M<V5R=FEC92XB"FUS9W-T<B`B(@HB14UA:6PM=&EL+5--4R!G871E=V%Y+61R
M:79E<BP@9F]R(&]P97)A=/AR97(L('-O;2!U9&)Y9&5R(&1E;FYE('-E<G9I
M8V4N(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O;6]B:6QE+G!H<#HS-`HC.B!L:6(O2&]R9&4O3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R
M(")%4E(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C<U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HW,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S4@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`B17%U861O
M<B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(U(&QI8B](;W)D
M92]097)M<RYP:'`Z,S(U"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,S4@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.0HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.CDR('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3$U"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3@Q"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHW,@IM<V=I9"`B161I="(*;7-G<W1R(")2961I9V5R(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU,"!L:6(O2&]R9&4O0FQO
M8VLO54DN<&AP.C4P"FUS9VED(")%9&ET($)L;V-K(@IM<V=S='(@(L9N9')E
M(&)L;VLB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y."!A9&UI;B]G<F]U<',N
M<&AP.C(R-@IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R("+&;F1R92!G<G5P
M<&4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<V(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`P"B,Z(&QI8B](;W)D92]097)M
M<R]522YP:'`Z-S8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ,#`*;7-G:60@
M(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R("+&;F1R92!T:6QL861E;'-E(@H*
M(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B161I="!0
M97)M:7-S:6]N<R(*;7-G<W1R("+&;F1R92!T:6QL861E;'-E<B(*"B,Z('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`BQFYD<F4@=&EL
M;&%D96QS97(@9F]R("5S(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z
M-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`BQFYD<F4@=F%L
M9R!F;W(Z(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-C<@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B161I="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(L9N9')E
M('1I;&QA9&5L<V5R(&9O<B!<(B5S7"(B"@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES
M<VEO;G,@9F]R("5S(@IM<V=S='(@(L9N9')E('1I;&QA9&5L<V5R(&9O<B`E
M<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0IM<V=I9"`B161U8V%T
M:6]N(@IM<V=S='(@(E5D9&%N;F5L<V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<W(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-S<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T
M(@IM<V=S='(@(L9G>7!T96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3<@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C<T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,3<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")%;"!386QV
M861O<B(*;7-G<W1R(")%;"!386QV861O<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM<V=I9"`B16QE
M;65N="XN+B(*;7-G<W1R(")%;&5M96YT+BXN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S
M='(@(D5M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C(R-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8Y"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ.#8Y(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C(T"FUS9VED(")%;6%I;"(*;7-G<W1R(")E36%I;"(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38V(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-38V"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z-C@@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ
M,`IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R(")E+6UA:6PM861R97-S
M92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C,@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$Y-C,*;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA
M=&-H+B(*;7-G<W1R(")%+6UA:6PM861R97-S97(@<VMA;"!P87-S92XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3@Y(&QI8B](;W)D92]&;W)M
M+G!H<#HQ.3@Y"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G
M<W1R(")%+6UA:6P@;65D(&)E:W+F9G1E;'-E(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3$@;&EB+TYE="]335,O9V5N
M97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W87DB
M"FUS9W-T<B`B16UA:6PM=&\M4TU3($=A=&5W87DB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDY"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR.3D*;7-G:60@(D5M;W1I8V]N<R(*
M;7-G<W1R(")3;6EL97ES(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`R"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`R"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R
M(")4;VT@8F5S:V5D+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HR-#,@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0X-`HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C8R(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW,#4*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HQ-3`@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C(T
M,PHC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-#@T(&QI8B](;W)D92]'
M<F]U<"]L9&%P+G!H<#HV-C(*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP
M.C<P-2!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ-3`*;7-G:60@(D5M<'1Y
M(')E<W5L="XB"FUS9W-T<B`B26YT970@<F5S=6QT870N(@H*(SH@9G)A;65W
M;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$Q,R!L:6(O2&]R9&4O4U%,+TME
M>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E87)C:"!T97)M<R(*;7-G
M<W1R(")4;VUT('5D=')Y:R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M-#<*;7-G:60@(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO
M=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S='(@(D%K=&EVZ7(@:6YD<^9T
M=&5L<V4@868@8FEL;&5D97(@9G)A($9O=&]G86QL97)I97(@:2!T96MS=#\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(R"FUS9VED(")%;F%B;&4@
M<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R(")!:W1I=NER(&CX
M:G)E+6ML:6L@8V]N=&5X="UM96YU/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(U.#@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<Y,PHC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C4X."!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y
M,PIM<V=I9"`B16YD('EE87(B"FUS9W-T<B`B4VQU="WE<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N
M;&%R9V4@161I=&]R(@IM<V=S='(@(D9O<G-T^'(@961I=&5R:6YG<W;F<FMT
M^&HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(T"FUS9VED("(B"B)%
M;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S
M:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N
M9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B
M(@HB26YD=&%S="!E="!S:6MK97)H961S<W#X<F=S;>5L+"!S;VT@9'4@=FEL
M(&)L:79E('-P=7)G="P@;N5R(&1U(&AA<B!B<G5G(&9O<B`B"B)A="#F;F1R
M92!D:70@:V]D96]R9"P@9G@@)VAV860@97(@9&ET(&OF;&5D>7)S(&YA=FX_
M)SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3D*;7-G:60@(D5N=&5R('1H92!I;6%G92!54DP@:&5R
M92(*;7-G<W1R("));F1T87-T(%523"!T:6P@8FEL;&5D(&AE<B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX.3(*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Y,@IM<V=I9"`B16YT
M97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S='(@(DEN9'1A<W0@8F]G<W1A
M=F5R(&YE9&5N9F]R.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3D@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C<U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY.2!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B17%U871O<FEA;"!'=6EN
M96$B"FUS9W-T<B`BQFMV871O<FEA;"!'=6EN96$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Y(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-SD@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@
M(D5R:71R96$B"FUS9W-T<B`BQG)I=')E82(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]6:65W+G!H<#HY-`HC
M.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z
M,C<*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]6:65W+G!H<#HY-"!L:6(O
M0FQO8VLO;65T87(N<&AP.C,V"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HT.`IM<V=I9"`B17)R;W(B"FUS9W-T<B`B1F5J;"(*"B,Z(&9R86UE
M=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8S(&QI8B](;W)D92]496UP
M;&%T92YP:'`Z-#8S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&-R96%T
M:6YG(&)L;V-K.B`E<R(*;7-G<W1R(")&96IL('9E9"!D86YN96QS92!A9B!B
M;&]K.B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C<R"B,L
M('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R
M.B`E<R(*;7-G<W1R(")&96IL('5N9&5R('-L971N:6YG(&%F('-Y;F,M:.9G
M=&4Z("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S
M(@IM<V=S='(@(D9E:FP@=6YD97(@<VQE=&YI;F<@868@<WEN8R!L;V<Z("5S
M(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C@@;&EB
M+TAO<F1E+U1E;7!L871E+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*;7-G<W1R(")&96IL('5N9&5R
M(&AE;G1N:6YG(&%F(&EN9&AO;&0Z("5S(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('5P
M9&%T:6YG('!A<W-W;W)D.B`E<R(*;7-G<W1R(")&96IL('5N9&5R(&]P9&%T
M97)I;F<@868@:V]D96]R9#H@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@
M;65S<V%G92XB"FUS9W-T<B`B1F5J;"!F;W)B=6YD970@;65D(&4M<&]S="!B
M97-K960N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC.B!L:6(O5D93+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@
M(D9E:FP@=6YD97(@<VMR:79N:6YG(&%F(%PB)7-<(BXB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HW-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<V
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-S8@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G
M:60@(D5S=&]N:6$B"FUS9W-T<B`B17-T;&%N9"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#$@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HX,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B
M171H:6]P:6$B"FUS9W-T<B`BQG1I;W!I96XB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R(")%=&YI<VLB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*;7-G<W1R(")%=7)O<&$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0S"FUS9VED(")%=F5R>2`Q
M-2!M:6YU=&5S(@IM<V=S='(@(DAV97(@:W9A<G1E<B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.3,*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G
M<W1R(")(=F5R="`R+B!M:6YU="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-#`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B179E<GD@
M,S`@<V5C;VYD<R(*;7-G<W1R(")(=F5R(&AA;'9E(&UI;G5T(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,T,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,SDT"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B2'9E<B`U+B!M
M:6YU="(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP
M:'`Z-C`@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E
M<GD@3&]G:6XB"FUS9W-T<B`B06QT:60@=F5D(&QO9VEN(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,T-`IM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM
M<V=S='(@(DAV97(@:&%L=F4@=&EM92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-#$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,@IM<V=I9"`B179E
M<GD@;6EN=71E(@IM<V=S='(@(DAV97(@;6EN=70B"@HC.B!T96UP;&%T97,O
M9&%T82]D871E;6%P+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V86QU97,Z(@IM
M<V=S='(@(D5K<V5M<&5L=N9R9&EE<CHB"@HC.B!A9&UI;B]C;61S:&5L;"YP
M:'`Z-3$@861M:6XO<&AP<VAE;&PN<&AP.C@R(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,C@*;7-G:60@(D5X96-U=&4B"FUS9W-T<B`B561F^'(B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8Q-"!L:6(O
M2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HT-S4*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HV,30*;7-G:60@(D5X<&%N9"(*;7-G<W1R
M(")59'9I9"(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S(*
M;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@(D9O;&0@<VED97!A;F5L
M('5D(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$V."!L
M:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D
M("<I)R(*;7-G<W1R(")&;W)V96YT961E("<I)R(*"B,Z(&9R86UE=V]R:R]3
M44PO4U%,+TME>7=O<F1S+G!H<#HQ-S4@;&EB+TAO<F1E+U-13"]+97EW;W)D
M<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D
M('-E87)C:"!T97)M(@IM<V=S='(@(D9O<G9E;G1E9&4@<F5N="!O<F0@96QL
M97(@8VET97)E="!S^&=E=&5R;2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0Q,B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G
M:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R(")&;W+F;&1E;'-E<V1A=&\B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-R!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8W-PIM<V=I9"`B17AP;VYE;G0B"FUS
M9W-T<B`B16MS<&]N96YT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T
M<B`B1D<M9F%R=F4B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS
M9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(D944"UL86=R:6YG
M(&%F(&]P<^9T;FEN9R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S<6PN
M<&AP.C(R,"!L:6(O2&]R9&4O4')E9G,O<W%L+G!H<#HR,C`*;7-G:60@(D9A
M:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+B(*;7-G<W1R(")+=6YN92!I
M:VME(.9N9')E(&EN9'-T:6QL:6YG97)N92XB"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HY.`HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-S4@;&EB+TAO
M<F1E+T%U=&@O;&1A<"YP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T
M('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(")+=6YN92!I:VME(&;E(&9O<F)I
M;F1E;'-E('1I;"!,1$%0('-E<G9E<F5N+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<VUB+G!H<#HY."!L:6(O2&]R9&4O075T:"]S;6(N<&AP.CDX"FUS
M9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*;7-G<W1R
M(")+=6YN92!I:VME(&9O<F)I;F1E('1I;"!334(M<V5R=F5R+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S$W(&QI8B]61E,O9G1P+G!H<#HW
M,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<
M(B5S7"(N(@IM<V=S='(@(D9E:FP@=6YD97(@:V]P:65R:6YG(&9R82!<(B5S
M7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,C(@;&EB+U9&
M4R]F='`N<&AP.C<R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@
M8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(DMU;FYE(&EK:V4@:V]P:65R92!T
M:6P@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z
M.#<@;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'`Z.#<*;7-G:60@(D9A:6QE9"!T
M;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`B2W5N;F4@
M:6MK92!E=&%B;&5R92!N>2!305-,+69O<F)I;F1E;'-E+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4U(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z-3`Q"B,Z(&QI8B]61E,O9G1P+G!H<#HW-34@;&EB+U9&4R]S;6(N
M<&AP.C4P,0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@;6]V92!T
M;R!<(B5S7"(N(@IM<V=S='(@(DMU;FYE(&EK:V4@9FQY='1E('1I;"!<(B5S
M7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C4@;&EB+U9&
M4R]S;6(N<&AP.C0V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@
M<F5T<FEE=F4Z("5S(@IM<V=S='(@(DMU;FYE(&EK:V4@:&5N=&4Z("5S(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*;7-G
M:60@(D9A:7(B"FUS9W-T<B`B4VUU:W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@T(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.#0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML
M86YD($ES;&%N9',@*$UA;'9I;F%S*2(*;7-G<W1R(")&86QK;&%N9'/X97)N
M92`H36%L=FEN87,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@V(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&87)O92!)<VQA;F1S(@IM
M<V=S='(@(D;F<OAE<FYE(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(S
M."!L:6(O2&]R9&4O0TQ)+G!H<#HR,S@*;7-G:60@(D9A=&%L($5R<F]R.B(*
M;7-G<W1R(")$^&1E;&EG(&9E:FPZ(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$X-PHC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@(D9A>"(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3$*;7-G:60@(D9A>&5S(@IM
M<V=S='(@(D9A:W-I;6EL97(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`S"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#$*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P,R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(D9E8G)U87(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(R-PIM<V=I9"`B1F5E;',@3&EK92(*;7-G
M<W1R(")&^&QE<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,C`*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R(")&^&QE<SH@(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@
M(D9E=R!3:&]W97)S(@IM<V=S='(@(D;E(&)Y9V5R(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W
M(%-H;W=E<G,B"FUS9W-T<B`B1N4@<VYE8GEG97(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.30T(&QI8B](;W)D92]&;W)M+G!H<#HQ.30T"FUS
M9VED(")&:65L9"!M871R:7@B"FUS9W-T<B`B1F5L=&UA=')I8V4B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(U(&QI8B](;W)D92]&;W)M+G!H
M<#HS,S(U"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R(")&:6=L970@
M0T%05$-(02(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,CD@;&EB
M+TAO<F1E+T9O<FTN<&AP.C,S,CD*;7-G:60@(D9I9VQE="!F;VYT(@IM<V=S
M='(@(D9I9VQE="!S:W)I9G1S='EP;V=R869I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C@S(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&
M:6II(@IM<V=S='(@(D9I:FDB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR-34*;7-G:60@(D9I;&4B"FUS9W-T<B`B1FEL(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-C<@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C`*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R(")!;G1A;"!F
M:6QE<CH@)7,@9FEL(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C<Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@
M)7,@9FEL97,B"FUS9W-T<B`B06YT86P@9FEL97(Z("5S(&9I;&5R(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P.0IM<V=I9"`B1FEL92!-86YA
M9V5R(@IM<V=S='(@(D9I;&CE;F1T97)I;F<B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C8S(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z.#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HW,"!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV
M,PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX,B!L:6(O2&]R
M9&4O34E-12]6:65W97(O>FEP+G!H<#HW,`IM<V=I9"`B1FEL92!.86UE(@IM
M<V=S='(@(D9I;&YA=FXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.3<W(&QI8B](;W)D92]&;W)M+G!H<#HR.3<W"FUS9VED(")&:6QE('-E;&5C
M=&EO;B(*;7-G<W1R(")&:6QV86QG(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,30X-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30X-@IM<V=I9"`B1FEL
M92!U<&QO860B"FUS9W-T<B`B1FEL;&%G<FEN9R(*"B,Z(&9R86UE=V]R:R]"
M<F]W<V5R+T)R;W=S97(N<&AP.CDP,B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z
M.3`R"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T
M<B`B1FEL;&%G<FEN9R!I:VME('5N9&5R<W3X='1E="XB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z.3$*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`B
M1FEL=')E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@R(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<Q"FUS9VED(")&:6YL86YD(@IM<V=S='(@(D9I;FQA
M;F0B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED(")&:7)S="!(
M86QF(@IM<V=S='(@(D;X<G-T92!H86QV9&5L(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@
M475A<G1E<B(*;7-G<W1R(")&^')S=&4@:W9A<G1A;"(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-3<*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U-PIM<V=I9"`B1FEX(')A=&EO
M(@IM<V=S='(@(D9I:W/I<B!S=/AR<F5L<V5S9F]R:&]L9"(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S(*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,@IM<V=I9"`B1FQI<"(*
M;7-G<W1R(")&;&EP(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B1FQY
M9&5N9&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR,0IM<V=I9"`B1F]G(@IM<V=S='(@(E3E9V4B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,3`W(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z,C,W"B,Z(&QI8B]61E,O;75S<6PN<&AP.C$P-R!L:6(O5D93+W-Q;"YP
M:'`Z,C,W"B,L('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO
M="!E>&ES="(*;7-G<W1R(")-87!P92`E<R!E:W-I<W1E<F5R(&EK:V4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(R"FUS
M9VED(")&;VYT($-O;&]R(@IM<V=S='(@(E1Y<&]G<F%F:69A<G9E(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S='(@
M(DUA9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$R,PIM<V=I9"`B1F]R(&)R;W=S97)S('1H870@9&]N
M)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B1F]R('=E8G!R;V=R86UM97(L
M('-O;2!I:VME('5N9&5R<W3X='1E<B!B:6QL961E<B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S0Q"FUS9VED(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R
M(")696IR=61S:6=T("A4048I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C<R"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@
M=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI
M9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A
M('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*(E5D<VEG='-D86=E("AB96WF<FL@
M870@9&5N(')E='5R;F5R92!V96IR=61S:6=T('9E9'+X<F5R(&+E9&4@9&%G
M(&]G(&YA=#L@970@(@HB<W1O<G0@86YT86P@:&5R(&MA;B!R97-U;'1E<F4@
M:2!E;B!M96=E="!B<F5D(&)L;VLI(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHQ,#(*;7-G:60@(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G
M<W1R(")';&5M="!D:70@:V]D96]R9#\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#8T"FUS9VED(")&;W)M<R(*;7-G<W1R(")&;W)M=6QA<F5R
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"FUS9VED(")&;W)T=6YE
M(@IM<V=S='(@(D]R9'-P<F]G(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.CDY"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B17!I9W)A;71Y<&4B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*;7-G:60@(D9O<G1U;F5S
M(@IM<V=S='(@(D5P:6=R86UM97(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B17!I9W)A;6UE<B`R
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U-0IM<V=I9"`B1F]R
M=6US(@IM<V=S='(@(D9O<F$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3$Q"FUS9VED(")&;W)W87)D<R(*;7-G<W1R(")6:61E<F5S96YD96QS
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-C`*;7-G:60@(D9R(@IM<V=S='(@(D9R92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*;7-G:60@(D9R86UE
M<R(*;7-G<W1R(")286UM97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@W(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HX,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#<@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92(*;7-G
M<W1R(")&<F%N:W)I9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E
M+"!-971R;W!O;&ET86XB"FUS9W-T<B`B1G)A;FMR:6<L($UE=')O<&]L:71A
M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@T
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,2!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R(")&<F%N
M<VL@1W5Y86YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C@U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#0@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B
M"FUS9W-T<B`B1G)A;G-K(%!O;'EN97-I96XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,C(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED
M(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B1G)A;G-K
M92!S>61L:6=E(%1E<G)I=&]R:65R(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F9C.#(R+G!H<#HW-`HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R(")&<F$B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,W(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS-#D*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,Y-0IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@(D9R82(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"FUS9VED(")&=6QL
M($1E<V-R:7!T:6]N(@IM<V=S='(@(D9U;&0@8F5S:W)I=F5L<V4B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-@IM
M<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(D9U;&1MY6YE(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C8U('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z-C`*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R(")&=6QD="!N879N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@X(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<S"FUS9VED(")'86)O;B(*;7-G<W1R(")'86)O;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T
M<B`B1V%L;&5R:2!H=F]R9G)A(&)I;&QE9&4@<VMA;"!T86=E<R!F<F$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(D=A;&QE<FDZ(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDV(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<U"FUS9VED(")'86UB:6$B"FUS9W-T<B`B1V%M8FEA(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'
M96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(D=E;F5RZ7(@)7,M
M:V]N9FEG=7)A=&EO;B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF
M:6<N:'1M;#HX"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G<W1R(")'96YE
M<F5R970@:V]D92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C@Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,"!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1V5O<F=I82(*;7-G<W1R(")'
M96]R9VEE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.CDP"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV.2!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R(")4>7-K
M;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.CDQ"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,R!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`B1VAA;F$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDT(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.30@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R(")':6)R86QT87(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4W-@IM<V=I9"`B1VEV96X@3F%M92(*;7-G
M<W1R(")&;W)N879N(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP
M.C$W-2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ,`HC.B!T96UP;&%T97,O
M<')E9G,O87!P+FEN8SHQ.0IM<V=I9"`B1VQO8F%L($]P=&EO;G,B"FUS9W-T
M<B`B1W)U;F1LYF=G96YD92!I;F1S=&EL;&EN9V5R(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V%P<"YI;F,Z,3<*;7-G:60@(D=O(@IM<V=S='(@(E5D9OAR(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D96PB"FUS
M9W-T<B`B1_9D96PB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3$S,0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3$S,0IM<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B1V]O9VQE
M($UA<',B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")'
M;V]G;&4@4V5A<F-H(@IM<V=S='(@(D=O;V=L92US^&=N:6YG(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S.`HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,X"FUS9VED(")'<F%Y
M<V-A;&4B"FUS9W-T<B`B1W+E=&]N97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HY,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$P,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W)E
M96-E(@IM<V=S='(@(D=RYFME;FQA;F0B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X.`IM<V=I9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(D=R
MYG-K("A)4T\M.#@U.2TW*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.34@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.CDT"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY-2!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W)E96YL86YD(@IM
M<V=S='(@(D=R^&YL86YD(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.34*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@Y(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'<F5N861A(@IM<V=S
M='(@(D=R96YA9&$B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W.0IM<V=I9"`B
M1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B1W)U<'!E+6%D;6EN:7-T
M<F%T:6]N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+G!H<#HU.2!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,38Y"B,Z(&QI8B](;W)D92]'
M<F]U<"YP:'`Z-3D@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$V.0IM<V=I
M9"`B1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS9W-T<B`B1W)U
M<'!E;F%V;F4@;>4@:6MK92!VYG)E('1O;6UE(@H*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C,P-R!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP
M:'`Z,S`W"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L
M92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60Z("(*;7-G<W1R(")'<F]U<%]L9&%P.B!+86X@:6MK92!T:6QF^&IE(&=R
M=7!P92`E<RX@4V5R=F5R96X@;65L9&5R.B`B"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,3$X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HQ,C0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C0Q."!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,3$X"B,Z(&QI8B](;W)D
M92]'<F]U<"]L9&%P+G!H<#HQ,C0@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP
M.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@
M=&\@9&5L971E(&=R;W5P("5S(@IM<V=S='(@(D=R;W5P7VQD87`Z($MA;B!I
M:VME('-L971T92!G<G5P<&4@)7,B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,S,X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HS-SD*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C,S."!L:6(O2&]R
M9&4O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L('!H<"UF;W)M870*;7-G:60@(D=R
M;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,B"FUS9W-T<B`B
M1W)O=7!?;&1A<#H@2V%N(&EK:V4@;W!D871E<F4@9W)U<'!E("5S(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS,30@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HS,30*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G
M<W1R(")'<G5P<&5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.38*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDX(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S
M='(@(D=U861E;&]U<&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,R!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A;2(*;7-G<W1R
M(")'=6%M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.CDX"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#(@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R(")'
M=6%T86UA;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDR(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T
M<B`B1W5E<FYS97DB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C(R-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(R-@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED(")'=65S="!097)M:7-S:6]N<R(*
M;7-G<W1R(")'YG-T971I;&QA9&5L<V5R(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0W,@IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(D?F<W1E
M8F]G(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDW(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<U"FUS9VED(")'=6EN96$B"FUS9W-T<B`B1W5I;F5A(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#`*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-"!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW.`IM<V=I9"`B1W5I;F5A+4)I<W-A=2(*;7-G<W1R(")'=6EN
M96$M0FES<V%U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,#$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-2!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA(@IM<V=S='(@
M(D=U>6%N82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDV,"!L:6(O
M2&]R9&4O1F]R;2YP:'`Z.38P"FUS9VED(")(5$U,(@IM<V=S='(@(DA434PB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@U"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E
M;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RXB"FUS9W-T<B`B2%1-3$%R96$@
M;N9G=&5R('#E(&9E:B!V:7,@870@<VQE='1E(&1E;B!S:61S=&4@8V5L;&4@
M:2!RYFMK92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@V"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U
M<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S
M='(@(DA434Q!<F5A(&[F9W1E<B!PY2!F96H@=FES(&%T('-L971T92!D96X@
M<VED<W1E(&MO;&]N;F4@:2!T86)E;"XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E
M82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@
M=&%B;&4N(@IM<V=S='(@(DA434Q!<F5A(&[F9W1E<B!PY2!F96H@=FES(&%T
M('-L971T92!D96X@<VED<W1E('+F:VME(&D@=&%B96PN(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]H='1P+G!H<#HQ-3<@;&EB+TAO<F1E+T%U=&@O:'1T
M<"YP:'`Z,34W"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B2%144"WF9W1N:6YG(&EK:V4@9G5N9&5T+B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,3`@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#`*;7-G:60@(DAA:71I(@IM<V=S='(@(DAA[W1I(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`B2&%S
M:"UA;&=O<FET;64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR,@IM<V=I9"`B2&%Z92(*;7-G<W1R(")$:7,B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HY,3D@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,CDQ-`HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3$Y(&QI8B](;W)D92]&
M;W)M+G!H<#HR.3$T"FUS9VED(")(96%D97(B"FUS9W-T<B`B5&]P=&5K<W0B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q
M"B,Z(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"FUS9VED
M(")(96%D97)S(@IM<V=S='(@(D]V97)S:W)I9G1E<B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,#<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD*
M;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G
M<W1R(")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PIM<V=I9"`B
M2&5A=GD@5"U3=&]R;2(*;7-G<W1R(")+<F%F=&EG('1O<F1E;B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(")(96)R97<@*$E33RTX.#4Y
M+3@M22DB"FUS9W-T<B`B2&5B<F%I<VL@*$E33RTX.#4Y+3@M22DB"@HC.B!L
M:6(O0FQO8VLO:69R86UE+G!H<#HR,B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,T"FUS9VED(")(96EG:'0B"FUS9W-T
M<B`B2/AJ9&4B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z
M,3@T(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ.#8*(SH@;&EB
M+TAO<F1E+TAE;'`N<&AP.C$X-"!L:6(O2&]R9&4O2&5L<"YP:'`Z,3@V('-E
M<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W"B,Z('1E;7!L871E<R]H96QP+VEN
M9&5X+FEN8SHT"FUS9VED(")(96QP(@IM<V=S='(@(DAJYFQP(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B
M2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`B2&KF;'`@=&EL(')E9&EG97)I
M;F=S=N9R:W3X:B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-S$@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$S-S$*;7-G:60@(DAE;'!E<B(*;7-G<W1R
M(")(:N9L<&5R(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(
M96UI<W!H97)E(@IM<V=S='(@(DAE;6ES9N9R92(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC
M.C$P"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z
M(@IM<V=S='(@(DAE<B!E<B!S=&%R=&5N(&%F(&9I;&5N.B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")(:6=H
M(@IM<V=S='(@(DCX:B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z
M-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-0IM<V=I9"`B
M2&]?;64B"FUS9W-T<B`B2&IE;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#,@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C0S(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L
M>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`B2&5L;&EG<_@@
M*%9A=&EK86YS=&%T96XI(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HQ-30X(&QI8B](;W)D92YP:'`Z,34T.`IM<V=I9"`B2&]M92(*;7-G<W1R
M(")(:F5M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$R,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,34U"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U"FUS9VED(")(
M;VUE($%D9')E<W,B"FUS9W-T<B`B4')I=F%T+6%D<F5S<V4B"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-S`*;7-G:60@(DAO;64@1&ER96-T;W)Y(@IM
M<V=S='(@(DAJ96UM96MA=&%L;V<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3DP"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(E!R
M:79A="UT96QE9F]N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,#4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P."!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&]N9'5R87,B"FUS
M9W-T<B`B2&]N9'5R87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#8@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$P-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`V
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<X"FUS9VED(")(;VYG($MO;F<B
M"FUS9W-T<B`B2&]N9R!+;VYG(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C8W"FUS9VED(")(;W)D92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#4R(&QI8B](;W)D92]+;VQA8BYP:'`Z
M-#4R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED
M("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z(%5G>6QD:6<@)7,@6$U,(&1A=&$@<.5T<G5F9F5T
M(&D@8F5S:V5D("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR
M.3D@;&EB+TAO<F1E+TMO;&%B+G!H<#HR.3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J
M96-T("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!);F=E;B!B97-K960@<W9A
M<F5R('1I;"!O8FIE:W0@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C0T-2!L:6(O2&]R9&4O2V]L86(N<&AP.C0T-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U
M;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@26YT970@
M;V)J96MT(&%F('1Y<&4@)7,@9G5N9&5T(&D@8F5S:V5D("5S(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C4Q(&QI8B](;W)D92]+;VQA8BYP
M:'`Z,3(U,0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C
M8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO
M;&%B.B!3;&5T=&5D92`E<R!<(B5S7"(B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C(R,R!L:6(O2&]R9&4O2V]L86(N<&AP.C(R,PIM<V=I9"`B
M2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@
M=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B2&]R9&4O2V]L
M86(Z($EN=&5G<F%T:6]N<VUA<VMI;F5N(&MRYG9E<B!02%`M=61V:61D96QS
M92`G9&]M>&UL)R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-3$R
M(&QI8B](;W)D92]+;VQA8BYP:'`Z-3$R"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F
M;W(@;V)J96-T("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!+86X@:6MK92!D
M86YN92!N>70@6$U,+71RYB!F;W(@;V)J96MT("5S(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HQ,C0X(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(T
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O
M(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!+
M86X@:6MK92!S;&5T=&4@)7,@7"(E<UPB.B`E<R(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z-#@S(&QI8B](;W)D92]+;VQA8BYP:'`Z-#@S"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T
M<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R
M(")(;W)D92]+;VQA8CH@2V%N(&EK:V4@:6YD:&5N=&4@34E-12U)1"!F;W(@
M9&5L96X@868@='EP92`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z,3$Y-R!L:6(O2&]R9&4O2V]L86(N<&AP.C$Q.3<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E
M<R!<(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!+86X@:6MK92!S
M>6YK<F]N:7-E<F4@)7,@7"(E<UPB.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,3,S-R!L:6(O2&]R9&4O2V]L86(N<&AP.C$S,S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC
M:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!+86X@
M:6MK92!S>6YK<F]N:7-E<F4@9&5L:6YG97(Z("5S(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HS-#`@;&EB+TAO<F1E+TMO;&%B+G!H<#HS-#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA
M<F4@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!5:V5N9'0@9&5L:6YG
M(%PB)7-<(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R(")686YD
M<F5T('-T<F5G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX,@IM<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@
M(E9A;F1R970@9F]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B5F%N
M9')E=#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H
M4&QE87-E(')E<&]R="$I(@IM<V=S='(@(DAV;W)D86X@8F%R(&1U(&1I9R!A
M9"!M960@870@:&%V;F4@:&5R/R`H26YD<F%P<&]R=.ER(2DB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,U"FUS
M9VED(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E
M/R(*;7-G<W1R(")(=F]R(&UA;F=E(&MO;&]N;F5R(/AN<VME<B!D=2!A="!S
M86UM96YLYF=G93\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR
M,0IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_
M(@IM<V=S='(@(DAV;W(@;6%N9V4@9F5L=&5R("AK;VQO;FYE<BD@97(@9&5R
M/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@
M=&\@;65R9V4_(@IM<V=S='(@(DAV;W(@;6%N9V4@<N9K:V5R(/AN<VME<B!D
M=2!A="!S86UM96YLYF=G93\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(S
M-R!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Y"FUS9VED(")(=6UI
M9&ET>2(*;7-G<W1R(")&=6=T:6=H960B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C0X"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@(D9U
M9W1I9VAE9#H@(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED
M(")(=6UO<FES=',B"FUS9W-T<B`B2'5M;W)I<W1E<B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,3$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*
M;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B56YG87)N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)S<6PN<&AP.C(S-2!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G5S+G!H<#HQ-S(*(SH@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR
M,S4@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$W,@HC+"!P:'`M9F]R;6%T
M"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G
M<W1R(")/<')E='1E;'-E(&%F($E-05`M;6%P<&4@9F5J;&5D93H@)7,B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,CDU(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER=7,N<&AP.C(Q-`HC.B!L:6(O2&]R9&4O075T:"]C
M>7)S<6PN<&AP.C(Y-2!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,C$T"B,L
M('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL
M960Z("5S(@IM<V=S='(@(E-L971N:6YG(&%F($E-05`M;6%P<&4@9F5J;&5D
M93H@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C0R
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W.0HC.B!L:6(O2&]R
M9&4O075T:"]C>7)S<6PN<&AP.C(T,B!L:6(O2&]R9&4O075T:"]C>7)U<RYP
M:'`Z,3<Y"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q=6]T
M82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(D1E9FEN97)I;F<@868@
M:W9O=&4@9F]R($E-05`M;6%P<&4@9F5J;&5D93H@)7,B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,S$V(&QI8B](;W)D92]&;W)M+G!H<#HQ,S$V
M"FUS9VED("))4"!!9&1R97-S(@IM<V=S='(@(DE0+6%D<F5S<V4B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C<W(&QI8B](;W)D92]!
M=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED("))4"!!9&1R97-S(&YO="!A=F%I
M;&%B;&4N(@IM<V=S='(@(DE0+6%D<F5S<V4@:6MK92!T:6QGYFYG96QI9V4N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HX.2!L:6(O
M2&]R9&4O075T:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@061D<F5S<R!N
M;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B25`M861R
M97-S92!I:VME(&EN9&5N9F]R($-)1%(M8FQO:RXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@(DE0(&QO8VMD
M;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B25`@;&]C:V1O=VX@=FEO;&%T:6]N
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@
M(DEN9'/F="!RYFMK92!F^'(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C`@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$P.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3(P(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R"FUS9VED("))8V5L86YD
M(@IM<V=S='(@(DES;&%N9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.#`*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B2W5N(&EK;VYE<B(*"B,Z
M('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("))8V]N<R!F;W(@)7,B"FUS9W-T<B`B26MO;F5R(&9O<B`E<R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#$*;7-G:60@(DEC;VYS('=I=&@@=&5X
M="(*;7-G<W1R(")):V]N97(@;65D('1E:W-T(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Y,PIM<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R
M("))9&5N=&ET971S;F%V;CHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HV,#`@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C8P
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D
M(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM
M<V=S='(@(DAV:7,@9&5N(&EK:V4@=FES="!K;W)R96MT+"`E<R!F;W(@870@
MY6)N92!D96X@:2!E="!N>70@=FEN9'5E+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT-3D*;7-G:60@(B(*(DEF('EO=2!D;VXG="!S964@86YY(&EC
M;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@
M8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC
M>2XB"FUS9W-T<B`B(@HB2'9I<R!D=2!I:VME('-E<B!N;V=E;B!I:V]N97(@
M=F5D(&)R=6<@868@26YT97)N970@17AP;&]R97(@<VMA;"!D=2!MY7-K92`B
M"B)H86MK92!D96YN92!B;VMS(&%F(&9O<B!A="!S;.4@4$Y'+71R86YS<&%R
M96YS(&9R82XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3<R"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ-S(*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N
M;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B
M92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"B)(
M=FES(&1U('-E<B!D96YN92!B97-K960@:2!S=&5D970@9F]R(&5T(&)I;&QE
M9&4L('/E('9I;"!D=2!I:VME(&MU;FYE('-E("(*(F1E="!I(&1I;B!N970M
M;.9S97(@969T97(@;W!LYF=N:6YG+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0IM<V=I9"`B26UA
M9V4@4')E=FEE=SHB"FUS9W-T<B`B0FEL;&5D+69O<FCE;F1S=FES;FEN9SHB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,W"FUS9VED("));6%G92!54DPB"FUS9W-T<B`B0FEL;&5D+5523"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q.`IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R(")":6QL960M
M55),.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM
M<V=S='(@(D)I;&QE9&4@9G)A(&=A;&QE<FDB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@
M(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B0FEL;&5D92!F<F$@9V%L
M;&5R:3HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8Q(&QI8B](
M;W)D92]&;W)M+G!H<#HQ-S8Q"FUS9VED("));6%G92!U<&QO860B"FUS9W-T
M<B`B0FEL;&5D+6]P;.9G;FEN9R(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C,W"FUS9VED("));6%G97,B"FUS9W-T<B`B0FEL;&5D97(B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z-30*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-R!T96UP
M;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@
M(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("));7!O<G1E<FEN9RP@=')I;B`E
M9"(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF
M;W)M870*;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R("));7!O
M<G1E<F5D92!F96QT97(Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHV-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R("));7!O
M<G1E<F5D92!F96QT97(Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS9VED("));E]S97)T(%)O=R!!
M9G1E<B(*;7-G<W1R("));F1SYG0@<N9K:V4@969T97(B"@HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S0@;&EB+TAO<F1E+T-O
M;7!R97-S+WII<"YP:'`Z,3,T"FUS9VED("));F-O<G)E8W0@86-T:6]N(&-O
M9&4@9VEV96XN(@IM<V=S='(@(D9E:FQA9W1I9R!H86YD;&EN9W-K;V1E(&%N
M9VEV970N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S(*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S,@IM<V=I9"`B26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R
M9"XB"FUS9W-T<B`B56MO<G)E:W0@8G)U9V5R;F%V;B!O9R]E;&QE<B!K;V1E
M;W)D+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED
M("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N
M(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M:6YI<W1R871O<B!I
M9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(E5K;W)R96MT
M(&)R=6=E<FYA=FX@96QL97(@86QT97)N871I=B!A9')E<W-E+B!0<OAV(&EG
M96X@96QL97(@:V]N=&%K="!D:6X@(@HB861M:6YI<W1R871O<BP@:'9I<R!D
M=2!H87(@8G)U9R!F;W(@>61E<FQI9V5R92!H:N9L<"XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R
M96%S92!);F1E;G0B"FUS9W-T<B`B1F]R^&<@:6YD<GEK;FEN9R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,38@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#$*;7-G:60@(DEN9&EA(@IM<V=S='(@(DEN9&EE;B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,C4T(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z,C4T"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS
M9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@(DEN9&EV:61U96QL92!B
M<G5G97)E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3$R(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,3`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@
M(DEN9&]N97-I96XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C8W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N
M<&AP.C8W"FUS9VED("));F9O(@IM<V=S='(@(DEN9F\B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C4Y"FUS9VED("));F9O<FUA=&EO;B(*;7-G
M<W1R("));F9O<FUA=&EO;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS,3D*;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B
M;&4N(@IM<V=S='(@(DEN9F]R;6%T:6]N(&EK:V4@;.9N9V5R92!T:6QGYFYG
M96QI9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B"FUS
M9W-T<B`B26YD<^9T(&MO;&]N;F4@969T97(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*;7-G:60@
M(DEN<V5R="!);6%G92(*;7-G<W1R("));F1SYG0@8FEL;&5D92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@
M(DEN<V5R="!486)L92(*;7-G<W1R("));F1SYG0@=&%B96PB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED("))
M;G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B26YD<^9T('=E8BUH96YV:7-N:6YG
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,T"FUS9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T
M<B`B26YD<^9T(&MO;&]N;F4@9OAR(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED("));G-E<G0@
M82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("))
M;F1SYG0@96X@;GD@:V]L;VYN92!E9G1E<B!D96X@86MT=65L;&4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R
M96YT(&]N92(*;7-G<W1R("));F1SYG0@96X@;GD@:V]L;VYN92!F^'(@9&5N
M(&%K='5E;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8R"FUS9VED("));G-E<G0@82!N97<@<F]W(&%F
M=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("));F1SYG0@96X@;GD@<N9K
M:V4@969T97(@9&5N(&%K='5E;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@
M82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B26YD
M<^9T(&5N(&YY('+F:VME(&;X<B!D96X@86MT=65L;&4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-S`*;7-G
M:60@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E
M(@IM<V=S='(@(DEN9'/F="!E;B!P87)A9W)A9B!E9G1E<B!D970@86MT=65L
M;&4@<'5N:W0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!B
M969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("));F1SYG0@96X@<&%R
M86=R868@9OAR(&1E="!A:W1U96QL92!P=6YK="(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z,34P"FUS9VED("));G-E<G0@86QT97)N871E('1E;7!L871E
M(@IM<V=S='(@(DEN9'/F="!A;'1E<FYA=&EV('-K86)E;&]N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(T,@IM<V=I9"`B26YS97)T(&%N(&5M86EL
M(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S
M<W=O<F0Z(@IM<V=S='(@(DEN9'1A<W0@96X@92UM86EL+6%D<F5S<V4L(&AV
M;W)T:6P@9'4@:V%N(&UO9'1A9V4@9&5T(&YY92!K;V1E;W)D.B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*
M;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(DEN9'/F="!C96QL
M92!E9G1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G
M<W1R("));F1SYG0@8V5L;&4@9OAR(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O
M;'5M;B!A9G1E<B(*;7-G<W1R("));F1SYG0@:V]L;VYN92!E9G1E<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C4*;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(DEN9'/F
M="!K;VQO;FYE(&;X<B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.CDP"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S
M,30N<&AP.C4P(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HU,`HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*;7-G:60@(DEN
M<V5R="!M97-S86=E<R(*;7-G<W1R("));F1SYG0@8F5S:V5D97(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-#4*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`B26YD
M<^9T('!A<F%G<F%F(&5F=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED("));G-E<G0@<&%R
M86=R87!H(&)E9F]R92(*;7-G<W1R("));F1SYG0@<&%R86=R868@969T97(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8Y"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(DEN9'/F
M="!RYFMK92!E9G1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C@*;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E
M(@IM<V=S='(@(DEN9'/F="!RYFMK92!F^'(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C,S"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E
M<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(DEN9'1A<W0@
M9&5T(&MRYG9E9&4@<W9A<B!T:6P@<VEK:V5R:&5D<W-P^')G<VWE;&5T.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*
M;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B26YD<^9T+^9N
M9')E(&)I;&QE9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@Y"FUS9VED("));G-E<G0O36]D:69Y($QI;FLB"FUS9W-T
M<B`B26YD<^9T+^9N9')E(&AE;G9I<VYI;F<B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PHC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U9F9I8VEE;G0@
M8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G
M<W1R(")5=&EL<W1RYFMK96QI9R!K<F5D:70@=&EL(&%T('-E;F1E('1I;"!D
M:7-T<FEB=71I;VYS;&ES=&5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70N
M(@IM<V=S='(@(E5T:6QS='+F:VME;&EG92!K<F5D:70N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3`W-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`W
M-0IM<V=I9"`B26YT96=E<B(*;7-G<W1R(")(96QT86PB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,3,S(&QI8B](;W)D92]&;W)M+G!H<#HQ,3,S
M"FUS9VED("));G1E9V5R(&QI<W0B"FUS9W-T<B`B2&5L=&%L<VQI<W1E(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDW"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS
M9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R
M(")59WEL9&EG(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$V-PHC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ.30*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C$R(&QI8B](;W)D92]#;VUP
M<F5S<R]Z:7`N<&AP.C$V-PHC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H
M<#HQ.30@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,C$R"FUS9VED("))
M;G9A;&ED(%I)4"!D871A(@IM<V=S='(@(E5G>6QD:6=E(%I)4"UD871A(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A
M<'!L:6-A=&EO;BXB"FUS9W-T<B`B56=Y;&1I9W0@87!P;&EK871I;VXN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$R"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS
M9VED("));G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R(")59WEL9&EG="!S:W)I
M<'0M240N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`X-R!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,34X"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R,S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(Y.0HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C,W(&QI8B](
M;W)D92]&;W)M+G!H<#HR,#@W"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,34X
M(&QI8B](;W)D92]&;W)M+G!H<#HR,C,R(&QI8B](;W)D92]&;W)M+G!H<#HR
M,CDY"B,Z(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C,W"FUS
M9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R(")59WEL9&EG
M92!D871A(&%F<V5N9'0N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`P"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`P"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D
M9')E<W,N(@IM<V=S='(@(E5G>6QD:6<@9&5S=&EN871I;VXN(@H*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,3`Y"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$S.0HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR-#$@;&EB+TAO<F1E+T-O
M;7!R97-S+V1B>"YP:'`Z,3`Y"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]D8G@N
M<&AP.C$S.2!L:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HR-#$*;7-G:60@
M(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B56=Y;&1I9W0@9FEL9F]R
M;6%T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-0IM<V=I
M9"`B26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS9W-T<B`B56=Y;&1I9R!L:6-E
M;G-N^&=L92XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y
M"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(")5
M9WEL9&EG('!L86-E<FEN9R!A;F=I=F5T+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-PHC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?
M='EP92XB"FUS9W-T<B`B56=Y;&1I9R!M<V=?='EP92XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*;7-G:60@(DEN=F%L
M:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(E5G>6QD:6<@96QL97(@
M;6%N9VQE;B!A<&E?:60N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDV"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R
M86UE=&5R<RXB"FUS9W-T<B`B56=Y;&1I9V4@96QL97(@;6%N9VQE;F1E('!A
M<F%M971R92XB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z,C<*;7-G
M:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(E5G>6QD
M:6=E(&9O<N9L9')E+71I;&QA9&5L<V5R+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-C$*;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB
M"FUS9W-T<B`B56=Y;&1I9R!P87)T;F5R+6ED+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-C,*;7-G:60@(DEN=F%L:60@<')O9'5C="!C
M;V1E+B(*;7-G<W1R(")59WEL9&EG('!R;V1U:W0M:V]D92XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*(SH@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G:60@(DEN
M=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(E5G>6QD:6<@<')O=&]K;VPN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY
M,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C<Q(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z.#`*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.CDS(&QI8B].970O4TU3+W=I;E]H
M='1P+G!H<#HW,0HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z.#`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*
M;7-G<W1R(")59WEL9&EG(&UO9'1A9V5R.B!<(B5S7"(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C$P.#`@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HQ,C8S"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3`X,"!L:6(O2&]R
M9&4O2V]L86(N<&AP.C$R-C,*;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J96-T
M(@IM<V=S='(@(E5G>6QD:6=T(&1E;&EN9W-O8FIE:W0B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@(DEN=F%L
M:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(E5G>6QD:6<@;W!R:6YD96QS
M97-A9')E<W-E+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,Q,0HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,Q,0IM<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S
M='(@(E5G>6QD:6<@=6YI8V]D92UD871A+B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS-3D*;7-G:60@(DEN=F5N=&]R>2(*;7-G<W1R("));F1B
M;R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV
M-S@*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.`IM
M<V=I9"`B26YV97)T('-E;&5C=&EO;B(*;7-G<W1R("));G9E<G3I<B!M87)K
M97)I;F<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$Q,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$Y(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@R"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(DER86XL($1E;B!I<VQA;6ES:R!R97!U8FQI:R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Q."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3@@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#$*;7-G:60@(DER87$B"FUS9W-T<B`B27)A:R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,3,@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS9W-T<B`B27)L86YD(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B36%N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@
M(DES;VQA=&5D(%0M4W1O<FUS(@IM<V=S='(@(E-T961V:7,@=&]R9&5N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,30*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-"!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX,`IM<V=I9"`B27-R865L(@IM<V=S='(@(DES<F%E;"(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C(V(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-C(V"FUS9VED("))<W-U97(B"FUS9W-T<B`B
M561S=&5D97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.CD*;7-G:60@(DET86QI8R(*;7-G<W1R("))=&%L:65N<VLB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(Q(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@R"FUS9VED("))=&%L>2(*;7-G<W1R("))=&%L:65N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3(S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R,R!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G<W1R(")*86UA:6-A(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#(@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y(@IM
M<V=S='(@(DIA;G5A<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C4@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIA<&%N(@IM<V=S
M='(@(DIA<&%N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@
M(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`B2F%P86YS:R`H25-/
M+3(P,C(M2E`I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C(@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R,@IM<V=I9"`B2F5R<V5Y(@IM<V=S
M='(@(DIE<G-E>2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C0@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R
M(")*;W)D96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`X"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#8*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P."!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G
M:60@(DIU;'DB"FUS9W-T<B`B2G5L:2(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#<*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`W(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R(")*=6YI(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`IM
M<V=I9"`B2G5S=&EF>2(*;7-G<W1R(")*=7-TZ7(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I9"`B
M2G5S=&EF>2!#96YT97(B"FUS9W-T<B`B0V5N='+I<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$W"FUS9VED
M(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B3&EG92!M87)G96YE<B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$T
M"FUS9VED(")*=7-T:69Y($QE9G0B"FUS9W-T<B`B5F5N<W1R96IU<W1E<F5T
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`B2/AJ<F5J
M=7-T97)E="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S8@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T
M<B`B2V%S86MH<W1A;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR-C4*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(V-0IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B0F5V
M87(@;W)I9VEN86P_(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(V(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,C`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T
M<B`B2V5N>6$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@U
M(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C@U"FUS9VED(")+97)B97)O<R!S
M97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DME<F)E
M<F]S('-E<G9E<B!A9G9I<W1E(&=O9&ME;F1E;'-E(&%F(&ED96YT:71E="XB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.
M97=B:65S(@IM<V=S='(@(DME<FYE+3QE;3Y.97=B:65S/"]E;3XB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`B
M3OAG;&4M<VMA8F5L<V4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,30@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$T"FUS9VED(")+
M97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B3OAG;&4M9FEN9V5R869T<GEK(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R(&QI8B](;W)D
M92]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R
M(").^&=L96SF;F=D92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q,2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME
M>2!4>7!E(@IM<V=S='(@(D[X9VQE='EP92(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3DY(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-3DY"FUS9VED(")+97D@57-A9V4B"FUS9W-T<B`B3OAG;&5A;G9E;F1E
M;'-E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S0P(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@
M97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(").^&=L
M92!E:W-I<W1E<F5R(&%L;&5R961E('#E(&1E;B!O9F9E;G1L:6=E(&[X9VQE
M<V5R=F5R+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I9"`B
M2VED<R(*;7-G<W1R(")"^')N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$R.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B2VER:6)A
M=&DB"FUS9W-T<B`B2VER:6)A=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S(@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3,R(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E
M82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9B(*;7-G<W1R(")3
M>61K;W)E82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S,@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!297!U8FQI8R!O
M9B(*;7-G<W1R(").;W)D:V]R96$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$Y,0IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@(FMO<F5A;G-K
M("A%54,M2U(I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,C0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-"!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@
M(DMU=V%I="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C<@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T
M<B`B2VER9VES:7-T86XB"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC
M.C@*;7-G:60@(DQA7WEO=70B"FUS9W-T<B`B561F;W)M;FEN9R(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.#,*;7-G:60@(DQA;F=U86=E(@IM
M<V=S='(@(E-P<F]G(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,C8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-R!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&%O(%!E;W!L92=S
M($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T<B`B3&%O<R(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HQ-CD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R(")3
M:61S=&4@:&%L=F1E;"(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX.`IM
M<V=I9"`B3&%S="!087-S=V]R9"!#:&%N9V4B"FUS9W-T<B`B4VED<W1E(&MO
M9&5O<F1SYFYD<FEN9R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX-B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R
M(")3:61S=&4@:W9A<G1A;"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34X
M"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(E-I9'-T(&]P9&%T97)E
M=#HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,3<@;&EB+TAO<F1E
M+T%U=&@N<&AP.C<Q-PHC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN
M.B`E<R(*;7-G<W1R(")3:61S=&4@;&]G:6XZ("5S(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z-S$Y(&QI8B](;W)D92]!=71H+G!H<#HW,3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G
M<W1R(")3:61S=&4@:6YD;&]G;FEN9SH@)7,@9G)A("5S(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z-S$T(&QI8B](;W)D92]!=71H+G!H<#HW,30*
M;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(E-I9'-T92!L;V=I
M;CH@06QD<FEG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30V(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,C<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@
M(DQE=&QA;F0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*;7-G:60@
M(DQA=R(*;7-G<W1R("),;W8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*;7-G:60@(DQA>6]U="(*;7-G<W1R
M("),87EO=70B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM
M<V=S='(@(E1O;2!V960@:6YG96X@<F%M;65R(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,X(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C@*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$S."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I
M9"`B3&5B86YO;B(*;7-G<W1R("),:6)A;F]N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0P"FUS9VED("),969T
M(@IM<V=S='(@(E9E;G-T<F4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,3`Q(&QI8B](;W)D92]&;W)M+G!H<#HS,3`Q"FUS9VED("),969T(&AE
M861E<B(*;7-G<W1R(")696YS=')E('1O<'1E:W-T(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S`Y-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,S`Y-PIM
M<V=I9"`B3&5F="!V86QU97,B"FUS9W-T<B`B5F5N<W1R92!VYG)D:65R(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,CD*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,R!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX.`IM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("),97-O=&\B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DQE=F5L
M(@IM<V=S='(@(DYI=F5A=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-#(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI8F5R:6$B
M"FUS9W-T<B`B3&EB97)I96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#<@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$S,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,30W(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:6)Y86X@
M07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(DQI8GEE;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-#`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*
M;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B3&EE8VAT96YS=&5I;B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U"FUS
M9VED("),:6=H="!$<FEZ>FQE(@IM<V=S='(@(E-T^'9R96=N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*;7-G:60@(DQI
M9VAT(%)A:6XB"FUS9W-T<B`B3&5T(')E9VXB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!%
M87)L>2(*;7-G<W1R("),970@<F5G;B!T:61L:6=T(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A
M:6X@3&%T92(*;7-G<W1R("),970@<F5G;B!S96YT(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI9VAT(%)A
M:6X@4VAO=V5R(@IM<V=S='(@(DQE="!B>6=E(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@(DQI9VAT(%)A:6X@
M=VET:"!4:'5N9&5R(@IM<V=S='(@(DQE="!B>6=E(&UE9"!T;W)D96XB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,0IM<V=I
M9"`B3&EG:'0@4VYO=R(*;7-G<W1R("),970@<VYE(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N
M;W<@4VAO=V5R(@IM<V=S='(@(DQE="!S;F4@8GEG92(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B5FET
M=&EG:&5D(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q-"!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3@Q-`IM<V=I9"`B3&EN:R(*;7-G<W1R(")(96YV
M:7-N:6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T
M<B`B1F]R8FEN9"!P=6YK=&5R('1I;#HB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#<U(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<U"FUS9VED("),
M:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE
M;B!D:7-P;&%Y:6YG(@IM<V=S='(@(D9O<F)I;F0@92UM86EL+6%D<F5S<V5N
M(&UE9"!I;F1S:W)I=FYI;F=S<VED96X@=F5D(&9R96UV:7-N:6YG(@H*(SH@
M9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X
M,@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O:'1M;#)T97AT+G!H<#HQ.#(*
M;7-G:60@(DQI;FMS(@IM<V=S='(@(DAE;G9I<VYI;F=E<B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S
M='(@(DQI;G5X+6MI:W,B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HX-@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T
M,S$T+G!H<#HT-B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#8*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),
M:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B3&ES=&4@
M+2!B<G5G97(@:V%N('-E(&UA<'!E;B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,S0*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(DQI<W0@9&%T
M86)A<V5R(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3$*;7-G:60@
M(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B3W!L:7-T;FEN9R!A9B!H:N9L
M<&5E;6YE<B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*;7-G:60@(DQI
M<W0@5&%B;&5S(@IM<V=S='(@(DQI<W0@=&%B96QL97(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-"!L:6(O2&]R9&4O34E-12](
M96%D97)S+G!H<#HU.30*;7-G:60@(DQI<W0M07)C:&EV92(*;7-G<W1R("),
M:7-T92U!<F-H:79E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S
M+G!H<#HU.#D@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3@Y"FUS9VED
M("),:7-T+4AE;'`B"FUS9W-T<B`B3&ES="U(96QP(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12](96%D97)S+G!H<#HU.38@;&EB+TAO<F1E+TU)344O2&5A
M9&5R<RYP:'`Z-3DV"FUS9VED("),:7-T+4ED(@IM<V=S='(@(DQI<W0M260B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,B!L:6(O
M2&]R9&4O34E-12](96%D97)S+G!H<#HU.3(*;7-G:60@(DQI<W0M3W=N97(B
M"FUS9W-T<B`B3&ES="U/=VYE<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M2&5A9&5R<RYP:'`Z-3DS(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y
M,PIM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(DQI<W0M4&]S="(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DQ(&QI8B](;W)D92]-
M24U%+TAE861E<G,N<&AP.C4Y,0IM<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS
M9W-T<B`B3&ES="U3=6)S8W)I8F4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TAE861E<G,N<&AP.C4Y,"!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU
M.3`*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`B3&ES="U5;G-U
M8G-C<FEB92(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,@HC+"!P:'`M9F]R
M;6%T"FUS9VED("),:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,B"FUS9W-T
M<B`B3&ES=&YI;F<@868@<V5S<VEO;G,@9F5J;&5D93H@)7,B"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN
M9R!U<V5R<R!F86EL960Z("5S(@IM<V=S='(@(DQI<W1N:6YG(&%F(&)R=6=E
M<F4@9F5J;&5D93H@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI
M<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM
M<V=S='(@(E9I<VYI;F<@868@8G)U9V5R92!E<B!S;.5E="!F<F$N(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),:71E<F%T=7)E(@IM
M<V=S='(@(DQI='1E<F%T=7(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#0@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$S,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,30T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:71H=6%N
M:6$B"FUS9W-T<B`B3&ET875E;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEM86=E<RYP:'`Z-S<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+VEM86=E<RYP:'`Z-S<*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`B2&5N
M=&5R+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P,`IM
M<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S='(@(DQO:V%L('1I9#HB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#8*;7-G:60@(DQO8V%L92!A;F0@5&EM
M92(*;7-G<W1R(")296=I;VYA;&1A=&$@;V<@=&ED(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S(@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU-S(*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,B!L:6(O0FQO
M8VLO<W5N<FES92YP:'`Z,C(*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C4W"FUS9VED("),;V-A=&EO;B(*;7-G<W1R(")3=&5D(@H*(SH@;&]G
M:6XN<&AP.C$X.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C`P('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*(SH@=&5M<&QA=&5S+VQO9VEN
M+VUO8FEL92YI;F,Z,R!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-0IM
M<V=I9"`B3&]G(&EN(@IM<V=S='(@(DQO9R!I;F0B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR-#4*;7-G:60@(DQO9R!O9B!P<F5V:6]U<R!S
M>6YC('-E<W-I;VXB"FUS9W-T<B`B3&]G(&%F('1I9&QI9V5R92!S>6YK<F]N
M:7-E<FEN9W-S97-S:6]N97(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A
M<BYP:'`Z,3DT"FUS9VED("),;V<@;W5T(@IM<V=S='(@(DQO9R!U9"(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV,0IM<V=I9"`B3&]G:6XB"FUS9W-T
M<B`B3&]G(&EN9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3`*;7-G
M:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@(DQO9VEN+6]P9V%V97(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HY.34@;&EB+TAO<F1E+T%U=&@N<&AP
M.CDY-0IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M
M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T
M<B`B(@HB3&]G(&EN9"!F96IL961E(&9O<F1I(&1I="!B<G5G97)N879N(&5L
M;&5R(&MO9&5O<F0@8FQE=B!A;F=I=F5T(&9O<FME<G0N(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z.3DQ(&QI8B](;W)D92]!=71H+G!H<#HY.3$*
M;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`B3&]G:6YD(&UI<VQY:VME
M9&5S+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C4@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$S-C4*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R("),
M86YG('1E:W-T(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED
M("),;W9E(@IM<V=S='(@(DOF<FQI9VAE9"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"FUS9VED("),;W<B"FUS9W-T<B`B
M3&%V(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G
M<W1R(")3;>4@9W+F<VME('1E9VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L
M871I;B!L971T97)S(@IM<V=S='(@(E-MY2!L871I;G-K92!T96=N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R(")3;>4@
M<F]M97)T86PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$S-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30U(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),=7AE;6)O=7)G(@IM<V=S
M='(@(DQU>&5M8F]R9R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0S.0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`Q(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,SD*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@
M(DU-(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X,PIM<V=I9"`B
M34]41"(*;7-G<W1R(")-3U1$(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&YE9BYP:'`Z,S8@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N968N
M<&AP.C,V"FUS9VED(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO
M(&1A=&$N(@IM<V=S='(@(DU3+51.148M8FEL86<@:6YD:&]L9'0@:6YG96X@
M9&%T82XB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"B,Z(&QI8B](;W)D92].;W1I9FEC
M871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S
M='(@(DU31R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3<@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA8V%O(@IM<V=S='(@(DUA
M8V%O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,S8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,R!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%C961O;FEA+"!4:&4@1F]R;65R
M(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUA:V5D;VYI96XL($1E
M;B!T:61L:6=E<F4@:G5G;W-L879I<VME(')E<'5B;&EK(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$U,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R(")-861A9V%S:V%R(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"FUS9VED(")-86=I8R(*;7-G<W1R
M(")-86=I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@S"FUS9VED
M(")-86EL(@IM<V=S='(@(D4M;6%I;"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HU,C0*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`B12UM86EL
M+6%D;6EN:7-T<F%T;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB
M"FUS9W-T<B`B1&%N(&AE;G9I<VYI;F<N+BXB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C4@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,38U(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS9VED
M(")-86QA=VDB"FUS9W-T<B`B36%L87=I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38W(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$V-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B
M36%L87ES:6$B"FUS9W-T<B`B36%L87ES:6$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C0@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,`HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,38T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS9VED
M(")-86QD:79E<R(*;7-G<W1R(")-86QD:79E<FYE(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$U-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,@IM
M<V=I9"`B36%L:2(*;7-G<W1R(")-86QI(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38R(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$V,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B
M36%L=&$B"FUS9W-T<B`B36%L=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.30*;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S
M('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@(@HB
M87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*
M(DCE;F1TZ7(@;&ES=&5N(&%F(&MA=&5G;W)I97(L('-O;2!D=2!S:V%L(&UA
M<FME<F4@96UN97(@;65D+"!O9R!F87)V97)N92P@(@HB9&5R('-K86P@:VYY
M='1E<R!T:6P@9&ES<V4@:V%T96=O<FEE<BXB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U-@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U-@IM<V=I9"`B36%P,C0@;6%P(@IM
M<V=S='(@(DUA<#(T+6MO<G0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3`X-PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3$W,0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3`X-PHC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3$W,0IM<V=I9"`B36%P475E<W0@;6%P(@IM<V=S='(@(DUA
M<%%U97-T+6MO<G0B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ
M,#4*;7-G:60@(DUA<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B2V]R=&SF9VYI
M;F<@9V5M="XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#(*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P-"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*;7-G
M:60@(DUA<F-H(@IM<V=S='(@(DUA<G1S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0IM<V=I9"`B36%R9VEN
M(@IM<V=S='(@(DUA<F=E;B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C@X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S0S,30N<&AP.C0X(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HT
M.`HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@
M(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R(")-87)KZ7(@
M;65D(%-E="]5<V5T+69L86<B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HX.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,T,S$T+G!H<#HT.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z
M-#D*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED
M(")-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E
M<F5D*2(*;7-G<W1R(")-87)KZ7(@;65D(&%N9')E(&9L86<@*&9X(%9I9W1I
M9R]"97-V87)E="DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3(@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$T,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34R(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA
M;F1S(@IM<V=S='(@(DUA<G-H86QL^&5R;F4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3D@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,34Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDS"FUS9VED
M(")-87)T:6YI<75E(@IM<V=S='(@(DUA<G1I;FEQ=64B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B36%T8VAI;F<@9FEE;&1S
M(@IM<V=S='(@(D]V97)E;G-P87-S96YD92!F96QT97(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,38P(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDS
M"FUS9VED(")-875R:71A;FEA(@IM<V=S='(@(DUA=7)I=&%N:65N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,R!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(DUA=7)I=&EU<R(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q-0HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM
M<V=I9"`B36%X(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R(")-87@@=&EL;&%D
M="!K<F5D:70N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`X"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`X"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB
M"FUS9W-T<B`B36%K<VEM=6T@8F5S:V5D+61E;&4@;W9E<G-K<F5D970N(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3,*;7-G:60@(DUA>"!T96UP(&QA
M<W0@,C0@:&]U<G,Z("(*;7-G<W1R(")-86MS+B!T96UP+B!S:61S="`R-"!T
M:6UE<CH@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#4*;7-G:60@(DUA
M>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(DUA:W,N('1E;7`N('-I
M9'-T92`V('1I;65R.B`B"@HC.B!L:6(O87!I+G!H<#HX-@IM<V=I9"`B36%X
M:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R(")-86MS:6UU
M;2!A;G1A;"!A9B!P;W)T86QB;&]K:V4B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HX.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-PHC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y(&QI8B](;W)D92]&;W)M+G!H
M<#HX.3@@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,3<*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$R,SD*;7-G:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(DUA
M:W-I;75M;.9N9V1E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0T"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#8@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y
M"FUS9VED(")-87DB"FUS9W-T<B`B36%J(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30W"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR-3,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED
M(")-87EO='1E(@IM<V=S='(@(DUA>6]T=&4B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-3`*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(DUE9&EC:6XB
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED
M(")-96UB97)S(@IM<V=S='(@(DUE9&QE;6UE<B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.#(*;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B365N
M=2UT:6QS=&%N9#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R
M(")&;W+I;B!C96QL97(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z(&QI8B](;W)D
M92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DUE<W-A9V4B"FUS
M9W-T<B`B0F5S:V5D(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HR,38@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G:60@
M(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG
M;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D+B(*
M;7-G<W1R("(B"B)"97-K960@<W5C8V5S9G5L9'0@=F5R:69I8V5R970@;65D
M('5N9&5R<VMR:79E<F5N<R!C97)T:69I:V%T(&MU;FYE(&EK:V4@(@HB=F5R
M:69I8V5R97,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$P"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S$P"FUS9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(D)E
M<VME9"!U9&SX8F5T+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(R-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4V.2!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C`R"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C(W(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"FUS
M9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`B0F5S:V5D='EP92(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B365T87(@5V5A=&AE<B(*;7-G
M<W1R(")-971A<B!796%T:&5R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M-PIM<V=I9"`B365T87(@8FQO8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
M365T87)B;&]K(&EK:V4@=&EL9^9N9V5L:6<N(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ,3D*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B
M;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T
M<F%T;W(N(@IM<V=S='(@(B(*(DUE=&%R8FQO:R!I:VME('1I;&?F;F=E;&EG
M+B!$971A;&IE<B!E<B!B;&5V970@;F]T97)E="!T:6P@8G)U9R!F;W(@(@HB
M861M:6YI<W1R871O<F5N+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-3,*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB"FUS
M9W-T<B`B365T87)$0B!E<B!I:VME(&9O<F)U;F1E="XB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8W(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C<@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R(")-971O9&4B"@HC.B!F<F%M97=O
M<FLO4E!#+U)00R]S;V%P+G!H<#HQ,3<@9G)A;65W;W)K+U)00R]24$,O>&UL
M<G!C+G!H<#HX,0HC.B!L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z.#$@;&EB
M+TAO<F1E+U)00R]S;V%P+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R(")-971O9&4@
M7"(E<UPB(&5R(&EK:V4@9&5F:6YE<F5T(@H*(SH@9G)A;65W;W)K+U)00R]2
M4$,O<F5S="YP:'`Z.#(@;&EB+TAO<F1E+U)00R]R97-T+G!H<#HX,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M
M971H;V0Z("5S(@IM<V=S='(@(DUE=&]D92!I:VME(&1E9FEN960N($UE=&]D
M92!K86QD=#H@)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@R(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-PIM<V=I9"`B365T<FEC(@IM<V=S
M='(@(DWE;&5E;FAE9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C8@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUE>&EC;R(*;7-G
M<W1R(")-97AI8V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-2!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I82P@1F5D
M97)A=&5D(%-T871E<R!O9B(*;7-G<W1R(")-:6MR;VYE<VEE;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S8*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@IM
M<V=I9"`B36ED9&QE(@IM<V=S='(@(DUI9'0B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T;F5F+G!H<#HS."!L:6(O2&]R9&4O34E-12]6:65W
M97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*;7-G<W1R(")-24U%
M+71Y<&4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q-PIM<V=I9"`B36EN
M('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(DUI;BX@=&5M<"X@<VED
M<W1E(#(T('1I;65R.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P.0IM
M<V=I9"`B36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B36EN+B!T
M96UP+B!S:61S=&4@-B!T:6UE<CH@(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HT,SD@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-#,Y"FUS
M9VED(")-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D
M(@IM<V=S='(@(DUI;FEM=6T@:V]D96]R9'-A;&1E<B!E<B!E;F1N=2!I:VME
M('5D<W3E970B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C,U"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,S4*;7-G:60@(DUI<G)O<B(*;7-G<W1R(")3<&5J;&4B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS
M9W-T<B`B1F]R<VME;&QI9W0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS-#`*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HR-3`@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8W,@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,T,"!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,C4P"FUS9VED(")-
M:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S='(@(DUA
M;F=L97(@4$5!4BUP86MK92!(5%107U)E<75E<W0N(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$Q-0IM<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T
M:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@
M=&\@=7-E('1H:7,@(@HB87!P;&EC871I;VXN(@IM<V=S='(@(B(*(DMO;F9I
M9W5R871I;VX@;6%N9VQE<BX@1'4@8FQI=F5R(&[X9'0@=&EL(&%T(&=E;F5R
M97)E(&1E;B!N=2P@:'9I<R!D=2#X;G-K97(@(@HB870@8G)U9V4@9&5N;F4@
M87!P;&EK871I;VXN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`T"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`T"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@240N(@IM<V=S
M='(@(DUA;F=L97(@8F5S:V5D+6ED+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"B,Z(&QI8B].970O4TU3
M+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q
M=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S='(@(DUA;F=L97(@:W+F
M=F5T(%!%05(M<&%K:V4@36%I;"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)
M1"XB"FUS9W-T<B`B36%N9VQE<B!S97-S:6]N+4E$+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-38*;7-G:60@(DUO(@IM
M<V=S='(@(DUA;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW-@IM
M<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`B36]B:6P@12UP;W-T(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*;7-G:60@
M(DUO9&5R871E(@IM<V=S='(@(DKF=FXB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C8V(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HW,R!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV-@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX-2!L:6(O2&]R9&4O
M34E-12]6:65W97(O>FEP+G!H<#HW,PIM<V=I9"`B36]D:69I960@1&%T92(*
M;7-G<W1R("+&;F1R:6YG<V1A=&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!5
M4DPB"FUS9W-T<B`BQFYD<F4@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV-S0@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV
M-S0*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B36]D=6QU<R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-3`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3`*;7-G:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUO;&1O
M=F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$U,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30Y(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B36]N86-O
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-3(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY,@IM<V=I9"`B36]N9V]L:6$B"FUS9W-T<B`B36]N9V]L
M:65N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4X-"!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C4X-`IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T
M<B`B3>5N960@;V<@Y7(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I
M;G1E;F%N8V4N<&AP.C4W(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z-3<*
M;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`B3>5N961L:6<B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,38Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT
M"FUS9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(DUO;G1S97)R870B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G
M:60@(DUO;VX@4&AA<V5S(@IM<V=S='(@(DWE;F5F87-E<B(*"B,Z(&9R86UE
M=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$Y-B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HR.#`*(SH@;&EB+T9I;&4O0U-6+G!H<#HQ.38@;&EB+T9I;&4O
M0U-6+G!H<#HR.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!F:65L9',@
M9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T
M<B`B1FQE<F4@9F5L=&5R(&9U;F1E="!I(&QI;FEE("5D(&5N9"!D970@9F]R
M=F5N=&5D92`E9"XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$U-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30X(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S
M='(@(DUA<F]K:V\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS,PIM<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@(DUE<W0@
M<VMY9G)I="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,T"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@(DUE<W0@<VMY
M970B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M-0IM<V=I9"`B36]S=&QY($-L;W5D>2!A;F0@5VEN9'DB"FUS9W-T<B`B365S
M="!S:WEE="!O9R!B;.9S96YD92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T
M<B`B365S="!S;VPB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.C8T."!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HU
M,#D*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-#@*
M;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R(")&;'ET(&YE9"(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C4R(&QI8B](
M;W)D92]";&]C:R],87EO=70N<&AP.C4Q,PHC.B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+TUA;F%G97(N<&AP.C8U,@IM<V=I9"`B36]V92!,969T(@IM<V=S
M='(@(D9L>70@=&EL('9E;G-T<F4B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U-B!L:6(O2&]R9&4O0FQO8VLO3&%Y
M;W5T+G!H<#HU,3<*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HV-38*;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`B36]D(&CX:G)E
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HV-#0@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-3`U"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C0T"FUS9VED(")-;W9E
M(%5P(@IM<V=S='(@(D9L>70@;W`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-3(V"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HU,C8*;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R(")&
M;'ET(&YE9"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HU,C4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C4R-@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-3(U(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU,C8*;7-G
M:60@(DUO=F4@=7`B"FUS9W-T<B`B1FQY="!O<"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V."!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-C@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G
M:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B36]C86UB:7%U92(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#0@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q
M.#0*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R
M(")-=6QT:2UN:79E874@<G5L;&5G87)D:6YS;&ES=&5R(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-3D*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-3D*;7-G:60@(DUU;'1I
M;6%P(%5+(&UA<"(*;7-G<W1R(")-=6QT:6UA<"!52R!K;W)T(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T,B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C(T,@IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@(DUU;'1I
M<&QE('9A;&<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`R"FUS
M9VED(")->2!!8V-O=6YT(@IM<V=S='(@(DUI;B!K;VYT;R(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HR.`IM<V=I9"`B37D@06-C;W5N="!);F9O<FUA
M=&EO;B(*;7-G<W1R(")-:6YE(&MO;G1O+6EN9F]R;6%T:6]N97(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C0T"FUS9VED(")->2!0;W)T86PB
M"FUS9W-T<B`B36EN(%!O<G1A;"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET
M+G!H<#HT,@IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R(")-:6X@
M4&]R=&%L+75D9F]R;6YI;F<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-38*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$U-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,34U(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR"FUS9VED(")->6%N;6%R
M(@IM<V=S='(@(DUY86YM87(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O
M;6%I;G1E;F%N8V4N:'1M;#HU-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E
M(@IM<V=S='(@(DY%2BP@:F5G(&5R($E+2T4@96YI9R(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#$Q"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T
M;F5F+G!H<#HS."!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$P
M,@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DYA;64B
M"FUS9W-T<B`B3F%V;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V.2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-CD@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS
M9W-T<B`B3F%M:6)I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W."!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S@@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S
M='(@(DYA=7)U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<W(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-3D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-R!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B
M3F5P86PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$V,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<U(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").971H97)L86YD<R(*;7-G<W1R
M(").961E<FQA;F1E;F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,R!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@
M06YT:6QL97,B"FUS9W-T<B`B2&]L;&%N9'-K92!!;G1I;&QE<B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@R(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P92!"87-E(%523"(*
M;7-G<W1R(").971S8V%P92!"87-E(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3@T(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-3@T"FUS9VED(").971S8V%P92!#02!2979O8V%T:6]N(%523"(*;7-G
M<W1R(").971S8V%P92!#02!2979O8V%T:6]N(%523"(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3@V"FUS9VED(").971S8V%P92!#02!P;VQI8WD@55),(@IM
M<V=S='(@(DYE='-C87!E($-!('!O;&EC>2!54DPB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-2!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T
M<B`B3F5T<V-A<&4@4F5N97=A;"!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4X,R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4X,PIM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B
M3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4X-R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4X-PIM<V=I9"`B3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@
M(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3@X(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-3@X"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM96YT(@IM
M<V=S='(@(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,2!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@
M='EP92(*;7-G<W1R(").971S8V%P92!C97)T:69I8W1E('1Y<&4B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4S"FUS9VED(").971W;W)K(@IM
M<V=S='(@(DYE=';F<FLB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,C4@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(U"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS,SD@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y
M,`IM<V=I9"`B3F5V97(B"FUS9W-T<B`B06QD<FEG(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<P
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$W,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM
M<V=I9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R(").>2!+86QE9&]N:65N(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z
M-3`*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3`*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,C8*
M;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R(").>2!K871E9V]R:2(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@
M;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB"FUS9W-T
M<B`B3GEMY6YE(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B
M3GET(&)R=6=E<FYA=FX@*'9A;&=F<FET*2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38S"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ.#`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@
M(DYE=R!:96%L86YD(@IM<V=S='(@(DYE=R!:96%L86YD(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,W"FUS9VED(").97<@<&%S<W=O<F0B
M"FUS9W-T<B`B3GET(&MO9&5O<F0B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W-Q;"YP:'`Z,C(W(&QI8B](;W)D92]!=71H+W-Q;"YP:'`Z,C(W"B,L('!H
M<"UF;W)M870*;7-G:60@(DYE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E
M>"XB"FUS9W-T<B`B3GET(&MO9&5O<F0@=FEL('5D;/AB92!D96X@)7@N(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R"FUS9VED(").97<@
M<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*;7-G<W1R(").>64@:V]D96]R9"!E
M<B!I:VME(&5N<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDQ"FUS9VED(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S
M='(@(DYY="!V:6YD=64@*%]B;&%N:RDB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3(@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(Y,0IM<V=I9"`B3F5W<R(*;7-G<W1R(").>6AE
M9&5R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-PIM<V=I9"`B
M3F5W<V=R;W5P<R(*;7-G<W1R(").>6AE9'-G<G5P<&5R(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHQ,CD*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$@=&5M
M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34*;7-G:60@(DYE>'0B"FUS9W-T
M<B`B3N9S=&4B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*;7-G:60@(DYE
M>'0@-"!0:&%S97,B"FUS9W-T<B`B3N9S=&4@-"!F87-E<B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8V(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,S<P"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S8V
M(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S<P"FUS9VED(").97AT(&]P=&EO
M;G,B"FUS9W-T<B`B3N9S=&4@=&EL=F%L9R(*"B,Z(&9R86UE=V]R:R]522]5
M22]086=E<BYP:'`Z,3`S(&QI8B](;W)D92]522]086=E<BYP:'`Z,3`S"FUS
M9VED(").97AT/B(*;7-G<W1R(").YG-T93XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S0@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3<T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"FUS9VED
M(").:6-A<F%G=6$B"FUS9W-T<B`B3FEC87)A9W5A(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C4*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$W,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@IM
M<V=I9"`B3FEG97(B"FUS9W-T<B`B3FEG97(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3<S(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"FUS9VED
M(").:6=E<FEA(@IM<V=S='(@(DYI9V5R:6$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S8Y"FUS9VED(").:6=H="(*;7-G<W1R(").870B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V
M-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<Y(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDW"FUS9VED(").:75E(@IM<V=S='(@(DYI=64B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38V"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY-C8*;7-G:60@(DYO
M(@IM<V=S='(@(DYE:B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F
M+FAT;6PZ.0IM<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T
M82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`B26YG96X@=&EL
M9^9N9V5L:6=E(&MO;F9I9W5R871I;VYD871A(&%T('9I<V4@9F]R<VME;&QE
M(&9O<BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N
M<&AP.C$P-B!L:6(O5D93+TE33U=R:71E<BYP:'`Z,3`V"FUS9VED(").;R!A
M=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G
M<W1R("));F=E;B!T:6QGYFYG96QI9R!S=')A=&5G:2!T:6P@870@;&%V92!)
M4T\M8FEL;&5D97(N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S$S"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S$S"FUS9VED(").;R!B871C:"!T96UP;&%T92XB"FUS9W-T
M<B`B26YG96X@<VMR:7!T+7-K86)E;&]N+B(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,S@U"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-#`W(&QI8B](;W)D
M92]";&]C:R],87EO=70N<&AP.C<Y"B,Z(&QI8B](;W)D92]";&]C:R],87EO
M=70N<&AP.C(T-2!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HR-C<*(SH@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,#$*(SH@;&EB
M+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HS.#4*(SH@;&EB+TAO
M<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT,#<*;7-G:60@(DYO(&)L
M;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S='(@
M(D1E<B!E:W-I<W1E<F5R(&EK:V4@;F]G96X@8FQO:R!PY2!D96X@9F]R97-P
M=7)G=&4@<&]S:71I;VXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN
M<&AP.C4P(&QI8B](;W)D92]!=71H+VUC86PN<&AP.C4P"FUS9VED(").;R!C
M86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R("));F=E;B!K86QE;F1E<B!A;F=I=F5T('1I;"!-0T%,+>9G
M=&YI;F<N(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-30*;7-G:60@(DYO
M(&-H86YG92XB"FUS9W-T<B`B26YG96X@YFYD<FEN9RXB"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-B!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.C$U-@IM<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H
M:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B1&5R(&MA;B!I:VME('1I;&;X:F5S
M(&+X<FX@=&EL(&1E;FYE('1I;&QA9&5L<V4N(@H*(SH@9G)A;65W;W)K+U5T
M:6PO571I;"YP:'`Z-S8X(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<X
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$W(&QI8B](;W)D92YP
M:'`Z,3<X(&QI8B](;W)D92YP:'`Z-3$W"B,Z(&QI8B](;W)D92]5=&EL+G!H
M<#HW-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R("));F=E;B!K
M;VYF:6=U<F%T:6]N+6EN9F]R;6%T:6]N(&%N9VEV970@9F]R("5S+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#4U(&QI8B]61E,O9G1P+G!H
M<#HX-34*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R("));F=E;B!K;VYF:6=U<F%T
M:6]N+6EN9F]R;6%T:6]N(&%N9VEV970@9F]R($944"!61E,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-S(@;&EB+U9&4R]S<6PN<&AP.C8W
M,@IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R(%-13"!61E,N(@IM<V=S='(@(DEN9V5N(&MO;F9I9W5R871I;VXM
M:6YF;W)M871I;VX@86YG:79E="!F;W(@4U%,(%9&4RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(U(&QI8B]61E,O<W%L7V9I;&4N
M<&AP.C<R-0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`B26YG96X@:V]N
M9FEG=7)A=&EO;BUI;F9O<FUA=&EO;B!A;F=I=F5T(&9O<B!344PM1FEL92!6
M1E,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S$T"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B2W)E9&ET('5D
M=/AM="XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S-`HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,T"FUS9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`B
M26YT970@8F5S=&5M;65L<V5S<W1E9"!A;F=I=F5T+B(*"B,Z(&9R86UE=V]R
M:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDR,"!L:6(O2&]R9&4O0G)O=W-E<BYP
M:'`Z.3(P"FUS9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(DEN9V5N
M(&9I;"!S96YD="(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HW,0IM<V=I
M9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@(D9A;F1T(&EN9V5N(&EK;VYE
M<BXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$S,"!L:6(O0FQO8VLO<W5N
M<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q
M-@IM<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R("));G1E="!S
M=&5D(&EN9'-T:6QL970N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$U-PIM<V=I9"`B3F\@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@
M(DEN=&5T('-T960@86YG:79E="XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S,PHC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").;R!M97-S86=E('-U<'!L:65D
M+B(*;7-G<W1R("));F=E;B!B97-K960@86YG:79E="XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS9VED(").;R!N86UE
M('-P96-I9FEE9"XB"FUS9W-T<B`B26YT970@;F%V;B!A;F=I=F5T+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*;7-G:60@
M(DYO(&YU;6)E<B!S<&5C:69I960N(@IM<V=S='(@(DEN=&5T(&YU;6UE<B!A
M;F=I=F5T+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B
M3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(DEN9V5N(&%N<W3X9&5L
M:6=E(&5P:6=R86UM97(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N
M<&AP.CDQ(&QI8B](;W)D92]!=71H+VAT='`N<&AP.CDQ"FUS9VED(").;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B26YT970@:V]D96]R9"!A;F=I=F5T('1I;"!B<G5G(&9O<B!(5%10
M+>9G=&YI;F<N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HQ
M,#@@;&EB+TAO<F1E+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B26YT970@:V]D96]R9"!A;F=I=F5T('1I;"!B<G5G(&9O<B!)34%0+>9G
M=&YI;F<N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW,B!L
M:6(O2&]R9&4O075T:"]K<F(U+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M("));G1E="!K;V1E;W)D(&%N9VEV970@=&EL(&)R=6<@9F]R($ME<F)E<F]S
M+>9G=&YI;F<N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L;V=I;BYP:'`Z
M.#0@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<U"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<V%S;"YP:'`Z-S<@;&EB+TAO<F1E+T%U=&@O;&]G:6XN
M<&AP.C@T"B,Z(&QI8B](;W)D92]!=71H+W!A;2YP:'`Z-S4@;&EB+TAO<F1E
M+T%U=&@O<V%S;"YP:'`Z-S<*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B26YT970@:V]D
M96]R9"!A;F=I=F5T(&9O<B!,;V=I;F0MYF=T;FEN9RXB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W!A<W-W9"YP:'`Z,3,U(&QI8B](;W)D92]!=71H+W!A
M<W-W9"YP:'`Z,3,U"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("));G1E="!K;V1E;W)D
M(&%N9VEV971T('1I;"!005-35T0MYF=T;FEN9RXB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W-M8BYP:'`Z.#0@;&EB+TAO<F1E+T%U=&@O<VUB+G!H<#HX
M-`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B26YT970@:V]D96]R9"!A;F=I=F5T(&9O<B!3
M34(MYF=T;FEN9RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C$R.#<@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,C@W"FUS9VED
M("(B"B).;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@
M5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I
M=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B"B)3=&D@=&EL($]P96Y34TPM
M8FEB;&EO=&5K970@;6%N9VQE<BX@($]P96Y34TPM8FEB;&EO=&5K970@97(@
M;OAD=F5N9&EG="!F;W(@(@HB870@:.5N9'1E<F4@4$M#4S$R+61A=&$N(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B
M3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R("));F=E;B!V96YT96YD92!O
M<'-K<FEV;FEN9V5R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HW-C8@
M;&EB+U9&4RYP:'`Z-S8V"FUS9VED(").;R!Q=6]T82!S970N(@IM<V=S='(@
M(DMV;W1E(&EK:V4@:6YD<W1I;&QE="XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0S"FUS9VED(").;R!R=6QE
M<R(*;7-G<W1R("));F=E;B!S=')E9V5R(@H*(SH@9G)A;65W;W)K+T9I;&5?
M0U-6+T-35BYP:'`Z-#@R(&QI8B]&:6QE+T-35BYP:'`Z-#@R"FUS9VED(").
M;R!S97!A<F%T;W(@<W!E8VEF:65D+B(*;7-G<W1R("));F=E;B!S:VEL;&5T
M96=N(&%N9VEV970N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT-`IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B
M26YG96X@<VED97(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X
M-R!L:6(O5D93+W-M8BYP:'`Z-3@W"FUS9VED(").;R!S=6-H(&9I;&4B"FUS
M9W-T<B`B26YG96X@<^5D86X@9FEL(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$R-@IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A
M=F%I;&%B;&4@9F]R(&-A8VAE+B(*;7-G<W1R(")$97(@;6%N9VQE<B!E="!M
M:61L97)T:61I9W0@:V%T86QO9R!T:6P@;65L;&5M;&%G97(N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C$@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,0HC.B!L:6(O3F5T+U--4R]W
M:6Y?:'1T<"YP:'`Z,C(Q"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S
M<W=O<F0@<V5N="XB"FUS9W-T<B`B26YT970@8G)U9V5R;F%V;B!O9R]E;&QE
M<B!K;V1E;W)D('-E;F1T+B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P
M8RYP:'`Z,30P(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@
M(DYO('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@(DEN9V5N(&=Y
M;&1I9V4@6$U,+61A=&$@<F5T=7)N97)E="(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HY-S0*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX-`HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3DU"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,#$R"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HY-S0@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.CDX-`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.3DU"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,#$R"FUS9VED(").;R!V86QU97,B"FUS9W-T<B`B26YG96X@=N9R9&EE
M<B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C`*;7-G:60@(DYO('9E
M<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE
M<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B)/<FEG:6YA;"!K;VYF
M:6=U<F%T:6]N(&UA;F=L97(@=F5R<VEO;G-N=6UM97(N(%)E9V5N97+I<B!K
M;VYF:6=U<F%T:6]N+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C@*
M;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N
M+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D1I;B!K;VYF
M:6=U<F%T:6]N(&UA;F=L97(@=F5R<VEO;G-N=6UM97(N(%)E9V5N97+I<B!K
M;VYF:6=U<F%T:6]N+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0R-R!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C<*(SH@=&5M<&QA
M=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0U"FUS9VED(").
M;VYE(@IM<V=S='(@(DEN9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET
M*2(*;7-G<W1R("));F=E;B`H8G)U9R!I;7!L:6-I="DB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$Y,@IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB
M"FUS9W-T<B`B3F]R9&ES:R`H25-/+3@X-3DM,3`I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$W,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@IM
M<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B3F]R9F]L:R(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G
M:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B3F]R9&QI9V4@:&%L
M=FMU9VQE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34X(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-CD*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U."!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)
M<VQA;F1S(@IM<V=S='(@(DYO<F1L:6=E($UA<FEA;F'X97(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3<V(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDW"FUS9VED(").;W)W87DB"FUS9W-T<B`B3F]R9V4B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,2!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C8T,0IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(DEK:V4@
M<V5N97)E(&5N9"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C0P(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0P"FUS9VED(").
M;W0@0F5F;W)E(@IM<V=S='(@(DEK:V4@9OAR(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z-#$U(&QI8B]61E,O9FEL92YP:'`Z-#$U"FUS9VED
M(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B26MK92!N;V=E="!K871A;&]G
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HV
M,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G
M>2YP:'`Z.#0*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.34*(SH@;&EB+U9&4R])4T]7<FET
M97(N<&AP.C8S(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G
M>2YP:'`Z.#0*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T
M96=Y+G!H<#HY-0HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2YP:'`Z-#@*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDN<&AP.C4Y"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@
M(DEK:V4@:6UP;&5M96YT97)E="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C8X"FUS9VED(").;W0@<V5T(@IM<V=S='(@
M(DEK:V4@:6YD<W1I;&QE="(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HQ
M.3,@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(P.`HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z,C,T(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-3(*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C(V.2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,C@U"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,#$@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C,Q-@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S,S(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HS-C8*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C0R-B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3`U"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HU-S0@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4Y,0HC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-C8Y(&9R86UE=V]R:R]397-S:6]N
M2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,30U"B,Z(&9R86UE=V]R:R]3
M97-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,38P"B,Z(&9R86UE
M=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3<U"B,Z
M(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z
M,3@Y"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE
M<BYP:'`Z,C,V(&QI8B]61E,N<&AP.C$Y,PHC.B!L:6(O5D93+G!H<#HR,#@@
M;&EB+U9&4RYP:'`Z,C,T(&QI8B]61E,N<&AP.C(U,B!L:6(O5D93+G!H<#HR
M-CD*(SH@;&EB+U9&4RYP:'`Z,C@U(&QI8B]61E,N<&AP.C,P,2!L:6(O5D93
M+G!H<#HS,38@;&EB+U9&4RYP:'`Z,S,S"B,Z(&QI8B]61E,N<&AP.C,V-B!L
M:6(O5D93+G!H<#HT,C8@;&EB+U9&4RYP:'`Z-3`U(&QI8B]61E,N<&AP.C4W
M-`HC.B!L:6(O5D93+G!H<#HU.3$@;&EB+U9&4RYP:'`Z-C8Y(&QI8B](;W)D
M92]397-S:6]N2&%N9&QE<BYP:'`Z,30U"B,Z(&QI8B](;W)D92]397-S:6]N
M2&%N9&QE<BYP:'`Z,38P(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z
M,3<U"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,3@Y(&QI8B](
M;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,C,V"FUS9VED(").;W0@<W5P<&]R
M=&5D+B(*;7-G<W1R(")):VME('5N9&5R<W3X='1E="XB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.3`X"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3`X
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T"B,Z(&-O;F9I
M9R]H;V]K<RYP:'`N9&ES=#HQ,#4X(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ.#`*;7-G:60@(DYO=&5S(@IM<V=S='(@(DYO=&5R(@H*(SH@<V5R=FEC
M97,O;V)R;W=S97(O:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R
M;W=S92P@9V\@8F%C:RXB"FUS9W-T<B`B26YT970@870@8G)O=W-E+"!V96YD
M('1I;&)A9V4N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#4P"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,3(@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS
M9VED(").;W9E;6)E<B(*;7-G<W1R(").;W9E;6)E<B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$P-#8@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-#8*
M;7-G:60@(DYU;6)E<B(*;7-G<W1R(")486PB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-#(U(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(U"FUS9VED
M(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R(")!;G1A;"!T96=N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V.2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-#(S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T
M-#4@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-CD*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$T,C,@;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#4*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E
M<B!O9B!C;VQU;6YS(@IM<V=S='(@(D%N=&%L(&MO;&]N;F5R(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-R!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#,@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$S-C<*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T
M,C$@;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#,*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R
M;W=S(@IM<V=S='(@(D%N=&%L('+F:VME<B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P
M96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM
M<V=S='(@(E1A;"!I:VME(&%N9VEV970@9F]R(&]P9&%T97)I;F<@:2!D:7-T
M<FEB=71I;VYS;&ES=&4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R(")/2R(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B3V)J
M96-T(@IM<V=S='(@(D]B:F5K="(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E871O<B(*;7-G<W1R(")/8FIE
M:W1D86YN97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`T(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,3`T"FUS9VED(")/8W1A;"(*;7-G<W1R(")/
M:W1A;"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,3$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T.0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#D*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B
M3V-T;V)E<B(*;7-G<W1R(")/:W1O8F5R(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R(")!;G-T
M^&1E;F1E(&9I;'1E<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M,C@*;7-G:60@(D]F9FEC92(*;7-G<W1R(")+;VYT;W(B"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A
M<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB"FUS9W-T<B`B1V%M;65L="!O
M9R!N>70@:V]D96]R9"!S:V%L(';F<F4@9F]R<VME;&QI9V4N(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V"FUS9VED(")/;&0@<&%S<W=O
M<F0B"FUS9W-T<B`B1V%M;65L="!K;V1E;W)D(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C0V"FUS9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T
M(&-O<G)E8W0N(@IM<V=S='(@(D=A;6UE;'0@:V]D96]R9"!E<B!I:VME(&MO
M<G)E:W0N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-S$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,2!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*;7-G<W1R(")/;6%N
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY
M($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+B(*;7-G<W1R
M(")$96QT92!M87!P97(@=6YD97)S=/AT=&5S(&MU;B!A9B!)34%0+7-E<G9E
M<F4N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDU"FUS9VED(")/;FQY
M(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R(")+=6X@86YS=/AD96QI9V4@
M97!I9W)A;6UE<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-3$@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW,0HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3@U,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DW,0IM<V=I9"`B3VYL
M>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R(")+=6X@Z6X@
M92UP;W-T+6%D<F5S<V4@=&EL;&%D="XB"@HC.B!S97)V:6-E<R]S:&%R97,O
M961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E
M;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R
M("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(B(*(D5N(&1E
M;&EN9W,@96IE<G-K86(@;V<@96IE<G1I;&QA9&5L<V5R(&WE(&MU;B#F;F1R
M92!A9B!E;B`B"B)S>7-T96UA9&UI;FES=')A=&]R(&5L;&5R(&5J97)E;B!S
M96QV(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-#$@;&EB+T)L;V-K+VEF
M<F%M92YP:'`Z-#(*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S
M='(@(L5B96X@:2!E="!N>70@=FEN9'5E(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HR-#4@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HR-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T
M(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@(D]P96Y3
M4TPM9F5J;#H@1&%T82!K=6YN92!I:VME('5D9')A9V5S(&9R82!S:6=N97)E
M="!3+TU)344M9&5L+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK
M(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("+%8F5N(&1E;FYE(&AE;G9I<VYI
M;F<@:2!E="!N>70@=FEN9'5E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4S"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S='(@(D]P97)A=&EV
M<WES=&5M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U,0IM
M<V=I9"`B3W!T:6]N<R(*;7-G<W1R("));F1S=&EL;&EN9V5R(@H*(SH@<V5R
M=FEC97,O<')E9G,N<&AP.C,Q('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@
M(DEN9'-T:6QL:6YG97(@9F]R("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM
M<V=S='(@(D]R9&YE="!L:7-T92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-38X(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-38X
M"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`B3W)G86YI<V%T:6]N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-CD@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D]R9V%N:7-A=&EO;F%L
M(%5N:70B"FUS9W-T<B`B3W)G86YI<V%T;W)I<VL@96YH960B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,T"FUS9VED(")/<F=A;FEZ:6YG(@IM
M<V=S='(@(D]R9V%N:7-E<FEN9R(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G
M<W1R(")/<')I;F1E;&EG(&%P<&QI:V%T:6]N<W-K86)E;&]N(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I
M9VEN86P@=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R(")/<')I;F1E;&EG92!S
M:V%B96QO;F5R(&D@)7,Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D*(SH@<V5R=FEC
M97,O:V5Y8F]A<F0N<&AP.C$Q-R!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G<W1R(")!;F1E;B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.2!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3`Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,38@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$R-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3,T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#0*;7-G:60@(D]T:&5R($EN
M9F]R;6%T:6]N(@IM<V=S='(@(D%N9&5N(&EN9F]R;6%T:6]N(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,0IM<V=I9"`B3W=N97(@4&5R;6ES
M<VEO;G,B"FUS9W-T<B`B16IE<G)E='1I9VAE9&5R(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]P86TN<&AP.C<Y(&QI8B](;W)D92]!=71H+W!A;2YP:'`Z
M-SD*;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R(")004TMYF=T;FEN9R!E<B!I:VME('1I;&?F;F=E;&EG92XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ
M,#4@;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%
M05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R(")014%2.CI-86EL+6UO=&]R(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3(W-B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HQ,C<V"FUS9VED(")01U`@1&EG:71A;"!3:6=N
M871U<F4B"FUS9W-T<B`B4$=0(&1I9VET86P@<VEG;F%T=7(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S(R(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C$S,C(*;7-G:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G
M<W1R(")01U`M:W)Y<'1E<F5T(&1A=&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,S<T(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$S
M-S0*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(D]F9F5N=&QI9R!0
M1U`M;OAG;&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,S4V(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$S-38*;7-G:60@(E!'4"!3
M:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B4$=0+7-I9VYE<F5T+VMR
M>7!T97)E="!D871A(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8Y"FUS9VED
M(")02%`@0V]D92(*;7-G<W1R(")02%`M:V]D92(*"B,Z(&%D;6EN+W!H<'-H
M96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(E!(4"US:V%L
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*
M;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B169T;2X@;&5T(')E9VXB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.0IM
M<V=I9"`B4$T@4F%I;B(*;7-G<W1R(")%9G1M+B!R96=N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#`*;7-G:60@(E!-(%-H
M;W=E<G,B"FUS9W-T<B`B169T;2X@8GEG97(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@4VYO=R(*;7-G
M<W1R(")%9G1M+B!S;F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@
M(D5F=&TN('-N96)Y9V5R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#,*;7-G:60@(E!-(%-U;B(*;7-G<W1R(")%9G1M+B!S
M;VPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M-`IM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T<B`B169T+B!T;W)D96XB"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@V"FUS9VED(")03U-)6"!E>'1E
M;G-I;VX@:7,@;6ES<VEN9R(*;7-G<W1R(")03U-)6"UU9'9I9&1E;'-E(&UA
M;F=L97(B"@HC.B!L:6(O87!I+G!H<#HQ-#D*;7-G:60@(E!?2%`@4VAE;&PB
M"FUS9W-T<B`B4$A0+7-K86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0V"FUS9VED(")0861D:6YG(@IM<V=S
M='(@(D9O<G)I;F<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$W,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@W(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDY"FUS9VED(")086MI<W1A;B(*;7-G
M<W1R(")086MI<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.30@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$W,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DT
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L874B"FUS
M9W-T<B`B4&%L874B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DR(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-S0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N
M(%1E<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B4&%LYG-T:6YA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY.`IM<V=I9"`B4&%N86UA(@IM<V=S='(@(E!A;F%M82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ.#4@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3D*;7-G:60@(E!A<'5A($YE=R!'=6EN96$B"FUS9W-T<B`B4&%P=6$@
M3GD@1W5I;F5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.34@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")087)A9W5A>2(*;7-G
M<W1R(")087)A9W5A>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,W"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S='(@(D1E
M;'9I<W0@<VMY970B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4S-PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C$U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,#$X"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*(SH@;&EB+TYE="]3
M35,O=VEN7VAT='`N<&AP.C$U,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`Q.`HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<W('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z-#,*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0R-0IM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`B2V]D96]R9"(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O
M<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(DMO9&5O<F0@YFYD
M<F5T+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3,R
M,R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$S,C,*;7-G:60@(E!A<W-W
M;W)D(&EN8V]R<F5C="(*;7-G<W1R(")+;V1E;W)D(&9O<FME<G0B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,34R(&QI8B](;W)D92]!
M=71H+W)A9&EU<RYP:'`Z,34R"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F
M;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")+;V1E;W)D(&MR
MYG9E="!V960@4D%$2553+>9G=&YI;F<N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`U,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`U,PIM<V=I9"`B
M4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B2V]D96]R9"!M
M960@8F5K<N9F=&5L<V4B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.3`*;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R(")+;V1E;W)D.B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"FUS9VED(")087-S=V]R
M9#H@(@IM<V=S='(@(DMO9&5O<F0Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U
M,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#,T(&QI8B](;W)D92]&;W)M
M+G!H<#HR,#,T"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M,34*;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")+;V1E
M;W)D96YE('-K86P@=N9R92!E;G,N(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$R,"!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C(*;7-G:60@(E!A<W1E(@IM<V=S='(@(DEN9'/F="(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@
M(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@(DEN9'/F="!F<F$@=61K
M;&EP<VAO;&1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`B4W1I(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M
M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG
M;G5P<SHB"FUS9W-T<B`B5F5N=&5N9&4@;W!S:W)I=FYI;F=E<CHB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*;7-G:60@(E!E;W!L92(*;7-G<W1R
M(")&;VQK(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`B4')O8V5N="(*"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C0Y"FUS
M9VED(")097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B
M561F^'(@=F5D;&EG96AO;&1E;'-E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0Q,`IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS
M(&]N(&QO9VEN/R(*;7-G<W1R(")59&;X<B!V961L:6=E:&]L9&5L<V4@=F5D
M(&QO9R!I;F0_(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ
M-38@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I
M;VXB"FUS9W-T<B`B5&EL;&%D96QS97(B"@HC.B!A9&UI;B]P97)M<R]D96QE
M=&4N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E
M<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R(")4:6QL861E;'-E(%PB)7-<(B!I
M:VME('-L971T970N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU
M.3`@;&EB+U9&4R]S;6(N<&AP.C4Y,`IM<V=I9"`B4&5R;6ES<VEO;B!$96YI
M960B"FUS9W-T<B`B5&EL;&%D96QS92!NYF=T970B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$V-`HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$V,2!L:6(O
M2&]R9&4O4&5R;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS
M9W-T<B`B5&EL;&%D96QS97(B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP
M:'`Z-C`@861M:6XO<&5R;7,O9&5L971E+G!H<#HU.`HC.B!A9&UI;B]P97)M
M<R]E9&ET+G!H<#HQ,#D@861M:6XO<&5R;7,O:6YD97@N<&AP.C(R"FUS9VED
M(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")4:6QL861E
M;'-E<RUA9&UI;FES=')A=&EO;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV.`IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`B4')O
M9FEL97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$W.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@S(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDX"FUS9VED(")097)U(@IM<V=S='(@(E!E<G4B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G:60@(E!E=',B"FUS
M9W-T<B`B2^9L961Y<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#8@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!H:6QI<'!I;F5S
M(@IM<V=S='(@(D9I;&EP<&EN97)N92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ.38*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM<V=S='(@(E1E;&5F
M;VXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@P"FUS9VED(")0
M:&]T;W,B"FUS9W-T<B`B1F]T;W,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DP(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$Y,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!I
M=&-A:7)N(@IM<V=S='(@(E!I=&-A:7)N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G
M<W1R(")0<FEK:V5R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS
M9VED(")0;&%T:71U9&5S(@IM<V=S='(@(D)A;F%L:71E=&5R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM
M<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S='(@(DML
M:6L@:2!E;B!C96QL92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@
M=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R
M(")"96MRYF9T(&%T(&1U(/AN<VME<B!A="!S;&5T=&4@9&5T=&4@96QE;65N
M=#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A
M;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B0F5K<N9F="!A
M="!D=2#X;G-K97(@870@869LYFYK92!D971T92!E;&5M96YT+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U-C(@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(U-C(*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N
M(@IM<V=S='(@(DEN9'1A<W0@96X@;>5N960@;V<@970@Y7)S=&%L+B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C$R"FUS
M9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y
M.B(*;7-G<W1R("));F1T87-T(&5T(&YA=FX@=&EL(&1E;B!N>64@:V%T96=O
M<FDZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P,2!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3,P,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@
M25`@861D<F5S<RXB"FUS9W-T<B`B26YD=&%S="!E;B!G>6QD:6<@25`M861R
M97-S92XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C0P(&QI8B](
M;W)D92]&;W)M+G!H<#HR-C0P"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI
M9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H
M+B(*;7-G<W1R("));F1T87-T(&5N(&=Y;&1I9R!D871O+"!T:F5K(&%N=&%L
M;&5T(&%F(&1A9V4@:2!MY6YE9&5N+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(T-#<@;&EB+TAO<F1E+T9O<FTN<&AP.C(T-#<*;7-G:60@(E!L
M96%S92!E;G1E<B!A('9A;&ED('1I;64N(@IM<V=S='(@(DEN9'1A<W0@96X@
M9WEL9&EG('1I9'-A;F=I=F5L<V4N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y
M(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R(")3:W)I=B!V96YL:6=S="P@:'9A
M9"!P<F]B;&5M970@9^5R('5D('#E(&]G(&AV860@9&5R('-K97(N(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C(V"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N
M86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R("));F1T87-T('9E;FQI9W-T(&)R
M=6=E<FYA=FX@;V<@:V]D96]R9"(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E
M+G!H<#HU.`IM<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T
M97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE
M("(*(G-Y<W1E;2XB"FUS9W-T<B`B(@HB3.9S(&;X;&=E;F1E('1E:W-T+B!$
M=2!32T%,(';F<F4@96YI9R!I(&)E=&EN9V5L<V5R;F4@9F]R(&%T(&)R=6=E
M('-Y<W1E;65T+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R
M>4UA;F%G97(N<&AP.C<P"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA
M;F%G97(N<&AP.C<P"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G
M;W)Y(&YA;64Z(@IM<V=S='(@(DEN9'1A<W0@9&5T(&YY92!K871E9V]R:6YA
M=FXZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3@X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.#$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X."!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&]L86YD(@IM<V=S='(@(E!O;&5N
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC
M<R(*;7-G<W1R(")0;VQI=&EK(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0X.0IM<V=I9"`B4&]L;',B"FUS9W-T<B`B365N:6YG<VWE;&EN9V5R
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3,@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R(")0;W)T
M=6=A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$R-`IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I
M;6%G92(*;7-G<W1R(")0;&%C97)I;F<@868@8FEL;&5D970B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B
M4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R(")0;&%C97)I;F<@
M868@9&5N;F4@=&%B96PB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HY,0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T
M,S$T+G!H<#HU,2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3$*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0
M;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS
M9W-T<B`B4V5N9"!T:6P@9&5N;F4@;6%P<&4@*&EK:V4@9V5N;F5M='9U;F=E
M="!A9B!)34%0*2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<S(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C<X"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I
M<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(DYE9&+X
M<B!G96YN96T@<V5N97-T("5S('1I;65R.B`B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C@W"FUS9VED(")0<F5C:7!I=&%T:6]N/&)R("\^
M8VAA;F-E(@IM<V=S='(@(DYE9&+X<CQB<B`O/F-H86YC92(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]L9&%P+G!H<#HY."!L:6(O2&]R9&4O4')E9G,O
M;&1A<"YP:'`Z.3@*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?;&1A<#H@2W+F
M=F5T($Q$05`M=61V:61D96P@:6MK92!F=6YD970N(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+W-E<W-I;VXN<&AP.C,S(&QI8B](;W)D92]0<F5F<R]S
M97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@
M<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]S
M97-S:6]N.B!+<N9V970@<V5S<VEO;BUU9'9I9&1E;'-E(&EK:V4@9G5N9&5T
M+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C,R"FUS9VED(")0<F5S<W5R
M92(*;7-G<W1R(")4<GEK(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C8*
M;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E;#H@(@IM<V=S='(@(E1R>6L@
M=F5D(&]V97)F;&%D96XZ("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,C0*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T<B`B5')Y:SH@(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P,PHC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`S"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$R,`IM<V=I9"`B4')E=FEE=R(*;7-G<W1R(")';&EM="(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R
M,0IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM
M<V=S='(@(D)E=')A9W0@8FEL;&5D970@:2!E="!N>70@=FEN9'5E(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-38@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HS-C`*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H
M<#HS-38@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-C`*;7-G:60@(E!R979I
M;W5S(&]P=&EO;G,B"FUS9W-T<B`B1F]R<FEG92!T:6QV86QG(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B
M4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B561S:W)I=B!D;VMU;65N="(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,R!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@
M(E!R:79A="!N^&=L92(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU
M+G!H<#HQ-CD@;&EB+TAO<F1E+TUE;G4N<&AP.C$V.0IM<V=I9"`B4')O8FQE
M;2(*;7-G<W1R(")0<F]B;&5M(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z
M,3(W"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@(E!R;V)L
M96UB97-K<FEV96QS92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M-S$*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(E!R;VIE:W1E<B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,3$@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C$X.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<V(&QI
M8B](;W)D92]&;W)M+G!H<#HR,3$Q"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M,3@X(&QI8B](;W)D92]&;W)M+G!H<#HS,C<V"FUS9VED(")0<F]M<'0@=&5X
M="(*;7-G<W1R(")3=&EK;W)D<W1E:W-T(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#(S(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R
M,PIM<V=I9"`B4'5B;&EC($ME>2(*;7-G<W1R(")/9F9E;G1L:6=E(&[X9VQE
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#8@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#8*;7-G:60@(E!U8FQI8R!+97D@
M06QG;W)I=&AM(@IM<V=S='(@(D]F9F5N=&QI9RUN^&=L92UA;&=O<FET;64B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-2!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!)
M;F9O(@IM<V=S='(@(D]F9F5N=&QI9R!N^&=L92!I;F9O<FUA=&EO;B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C(T,2!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HR-#$*;7-G:60@(E!U8FQI8R]0<FEV871E(&ME>7!A
M:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(D]F9F5N
M=&QI9R]P<FEV870M;OAG;&5SYG0M9V5N97)E<FEN9R!M:7-L>6MK961E<RXB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DQ(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M.#,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,2!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S='(@(E!U
M97)T;R!2:6-O(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q
M-"YP:'`Z-34@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C4U"FUS
M9VED(")0=7)G92!M97-S86=E<R(*;7-G<W1R(")59')E;G,@8F5S:V5D97(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DV(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M.#0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E%A=&%R(@IM<V=S='(@(E%A=&%R(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C8T"FUS9VED(")1=65R>2(*;7-G<W1R
M(")&;W)E<W#X<F=S96PB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#`*
M;7-G:60@(E%U;W1A(@IM<V=S='(@(DMV;W1E(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C0@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HV-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@
M*"5D(&)I="DB"FUS9W-T<B`B3V9F96YT;&EG(%)302UN^&=L92`H)60@8FET
M*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C0@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(R-C0*;7-G:60@(E)A9&EO('-E;&5C=&EO;B(*;7-G<W1R
M(")%;FME;'1V:7,@=F%L9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")286EN(@IM<V=S='(@(E)E9VXB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM<V=I
M9"`B4F%I;B!%87)L>2(*;7-G<W1R(")296=N('1I9&QI9W0B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-PIM<V=I9"`B4F%I
M;B!,871E(@IM<V=S='(@(E)E9VX@<V5N="(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")286EN(%-H;W=E<B(*
M;7-G<W1R(")296=N8GEG97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT.0IM<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R
M(")296=N(&]G('-N92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4P"FUS9VED(")286EN('1O(%-N;W<B"FUS9W-T<B`B4VQU
M9"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")286YD;VT@
M1F]R='5N92(*;7-G<W1R(")4:6QFYFQD:6=T(&5P:6=R86TB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8X(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C@@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP
M:'`Z-S8*;7-G:60@(E)A=&EO(@IM<V=S='(@(D9O<FAO;&0B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-"!L:6(O2&]R9&4O4&5R;7,N<&AP
M.C,R-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z-C@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHY,2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-`HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-R!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$X,`IM<V=I9"`B4F5A9"(*;7-G<W1R("),YG,B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PHC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT-R!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C-#,Q-"YP:'`Z-#<*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C@W"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@(DSF
M<R!B97-K961E<B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI
M;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E("5S/R!4
M:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R(")6:7)K
M96QI9R!S;&5T=&4@)7,_($1E;FYE(&]P97)A=&EO;B!K86X@:6MK92!B;&EV
M92!O;6=J;W)T+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN
M8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D
M871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD
M;VYE+B(*;7-G<W1R("(B"B)6:7)K96QI9R!S;&5T=&4@9&%T82!F;W(@8G)U
M9V5R("5S/R!$96YN92!O<&5R871I;VX@:V%N(&EK:V4@8FQI=F4@;VUG:F]R
M="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,T"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R(")/
M;6?X<B!D:6X@<VED<W1E(&AA;F1L:6YG(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P
M.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#8*;7-G:60@(E)E
M9G)E<V@B"FUS9W-T<B`B3W!D871E<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS.34*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S
M.B(*;7-G<W1R(")/<&9R:7-K(&1Y;F%M:7-K92!M96YU+65L96UE;G1E<CHB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0U"FUS9VED(")2969R97-H
M(%!O<G1A;"!6:65W.B(*;7-G<W1R(")'96YO<&9R:7-K('!O<G1A;'9I<VYI
M;F<Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DT(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R,3,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(S-2!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DT(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,C$S"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C,U"FUS9VED(")2
M96=E>"(*;7-G<W1R(")296=U;.9R="!U9'1R>6LB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,C,Q(&QI8B](;W)D92]&;W)M+G!H<#HS,C,Q"FUS
M9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R(")296QA=&EO;G-L
MYG-E<B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*;7-G:60@(E)E;&]A9"(*;7-G
M<W1R(")'96YO<&9R:7-K(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,S,*
M;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B3F]T97(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3$W"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R
M(")&:F5R;F4@<V5R=F5R92(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHX-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE
M+F-O;2]H;W)D92DZ(@IM<V=S='(@(D9J97)N(%523"`H:'1T<#HO+W=W=RYE
M:W-E;7!E;"YD:R]H;W)D92DZ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M<75E=65D+FEN8SHQ,R!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC
M.C(R"FUS9VED(")296UO=F4B"FUS9W-T<B`B4VQE="(*"B,Z('1E;7!L871E
M<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM
M<V=S='(@(E-L970@8FQO:R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HU-3D*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C4U.0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")&
M:F5R;B!K;VQO;FYE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHT,`IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T
M<B`B4VQE="!F;W)M871E<FEN9R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z,3(X"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R(")3;&5T('!A
M<B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,#(*;7-G:60@(E)E;6]V
M92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T
M;W)Y+B(*;7-G<W1R(")&:F5R;B!L86=R970@<VMR:7!T(&9R82!S97)V97)S
M(&UI9&QE<G1I9&EG92!K871A;&]G+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@IM<V=I9"`B4F5M;W9E
M('1H92(*;7-G<W1R(")&:F5R;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I9"`B4F5M;W9E('1H
M:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G<W1R(")&:F5R;B!D971T
M92!P=6YK="!F<F$@9&]K=6UE;G1E="(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V92YI;F,Z,3$*;7-G:60@(E)E;6]V92!U<V5R(@IM<V=S='(@
M(E-L970@8G)U9V5R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R.B`E<R(*
M;7-G<W1R(")3;&5T(&)R=6=E<CH@)7,B"@HC.B!F<F%M97=O<FLO4E!#+U)0
M0R]X;6QR<&,N<&AP.C$S."!L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z,3,X
M"FUS9VED(")297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE
M9"!E<G)O<F-O9&4Z("(*;7-G<W1R(")!;FUO9&YI;F<@:W5N;F4@:6MK92!B
M97-V87)E<RX@4F5T=7)N97)E="!F96IL:V]D93H@(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$T-0IM<V=I9"`B4F5Q=65S=&5D('-E<G9I
M8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*;7-G<W1R(")!;FUO9&5T('1J96YE
M<W1E(&MU;FYE(&EK:V4@9FEN9&5S+B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,3@U(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3(W"B,Z
M(&QI8B](;W)D92YP:'`Z,3@U(&QI8B](;W)D92YP:'`Z-3(W"B,L('!H<"UF
M;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN
M("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DMRYG9E9&4@)R5S)R!E<B!I
M:VME(&%N9VEV970@:2`E<RUK;VYF:6=U<F%T:6]N+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#8Q(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z-C<X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,S$@
M;&EB+U9&4R]F='`N<&AP.C@V,2!L:6(O5D93+W-Q;"YP:'`Z-C<X"B,Z(&QI
M8B]61E,O<W%L7V9I;&4N<&AP.C<S,0HC+"!P:'`M9F]R;6%T"FUS9VED(")2
M97%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B2W+F=F5T(%PB)7-<(B!E<B!I:VME(&%N9VEV970@
M:2!61E,@:V]N9FEG=7)A=&EO;BXB"@HC.B!F<F%M97=O<FLO571I;"]5=&EL
M+G!H<#HW-S8@;&EB+TAO<F1E+U5T:6PN<&AP.C<W-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R(")+<N9V961E(%PB)7-<(B!E<B!I:VME(&%N
M9VEV970@:2!K;VYF:6=U<F%T:6]N96XN(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2]296YD97)E<BYP:'`Z,S,V(&QI8B](;W)D92]&;W)M+U)E;F1E<F5R
M+G!H<#HS,S8*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@(DMRYG9E
M="!F96QT(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,`HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,SD@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z
M,S(Q"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,SD@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(R,`HC.B!L:6(O2&]R9&4O1F]R;2]296YD
M97)E<BYP:'`Z,S(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-PIM<V=I9"`B
M4F5S970B"FUS9W-T<B`B3G5L<W1I;"(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C0V"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R(").
M=6QS=&EL(&MO9&5O<F0B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HR-PIM<V=I9"`B4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R(").=6QS
M=&EL(&1I="!K;V1E;W)D(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,0IM
M<V=I9"`B4F5S=&]R92!,87-T(%%U97)Y(@IM<V=S='(@(D=E;G-K86(@<VED
M<W1E(&9O<F5S</AR9W-E;"(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR.2!A
M9&UI;B]P:'!S:&5L;"YP:'`Z-S(@861M:6XO<W%L<VAE;&PN<&AP.C8W"FUS
M9VED(")297-U;'1S(@IM<V=S='(@(E)E<W5L=&%T97(B"@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N
M:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(E1I;&)A
M9V4@=&EL(&EN9'-T:6QL:6YG97)N92(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HS.`IM<V=I9"`B4F5T>7!E(&YE=R!P87-S=V]R9"(*;7-G
M<W1R(")'96YT87-T(&YY="!K;V1E;W)D(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ.3<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED
M(")2975N:6]N(@IM<V=S='(@(E)E=6YI;VXB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*;7-G:60@
M(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(D=E;F1A;B!K;VYF:6=U
M<F%T:6]N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-0IM<V=I9"`B
M4FEC:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S='(@(DEN9'-T:6QL:6YG
M97(@9F]R(%)I8V@@5&5X="UR961I9V5R:6YG(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4X"FUS9VED(")2:61D;&5S(@IM<V=S='(@(D?E9&5R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0X"FUS9VED(")2:6=H="(*;7-G<W1R(")(^&IR92(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,Q,#,@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#,*
M;7-G:60@(E)I9VAT(&AE861E<B(*;7-G<W1R(")(^&IR92!T;W!T96MS="(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,P.3D@;&EB+TAO<F1E+T9O
M<FTN<&AP.C,P.3D*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R(")(^&IR
M92!VYG)D:65R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB
M"FUS9W-T<B`B4N9K:V4M96=E;G-K86)E<BXN+B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,S0*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`B
M4F5G96PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DX(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ.#8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y."!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`B
M4G5MYFYI96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C(V"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,C8*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B4F]TZ7(@,3@P(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,PHC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(S"FUS9VED
M(")2;W1A=&4@3&5F="(*;7-G<W1R(")2;W3I<B!V96YS=')E(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R.0HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(Y"FUS9VED(")2;W1A
M=&4@4FEG:'0B"FUS9W-T<B`B4F]TZ7(@:/AJ<F4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2
M;W<@4')O<&5R=&EE<R(*;7-G<W1R(")2YFMK92UE9V5N<VMA8F5R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M,`IM<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`B4N9K:V4M96=E;G-K
M86)E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R(")2YFMK97(Z(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PIM
M<V=I9"`B4G5L97,B"FUS9W-T<B`B4W1R96=E<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U
M;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B
M"FUS9W-T<B`B4W1R96=E<B!V:6P@;W!T<N9D92!M96QL96T@<N9K:V5R(&]G
M(&MO;&]N;F5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`B4W1R96=E<B!V:6P@:W5N(&]P
M='+F9&4@;65L;&5M(&MO;&]N;F5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`B4W1R96=E<B!V
M:6P@:W5N(&]P='+F9&4@;65L;&5M('+F:VME<B(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HQ,C$*;7-G:60@(E)U;B(*;7-G<W1R(")59&;X<B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DY(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P,PIM<V=I9"`B4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(E)U
M<VQA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`P(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ.#@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P,"!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)W86YD82(*;7-G<W1R(")2
M=V%N9&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(X
M-2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%
M($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(DMR>7!T;V=R869I
M<VL@4R]-24U%+7-I9VYA='5R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HS,C,@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS,C,*
M;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*;7-G<W1R(")3+TU)
M344M<VEG;F5R970@8F5S:V5D(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S
M87-L+G!H<#HX,2!L:6(O2&]R9&4O075T:"]S87-L+G!H<#HX,0IM<V=I9"`B
M4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R
M(")305-,+>9G=&YI;F<@97(@:6MK92!T:6QGYFYG96QI9RXB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3`V"FUS9VED(")335,@365S<V%G:6YG
M(@IM<V=S='(@(E--4R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I
M9"`B4U%,(%-H96QL(@IM<V=S='(@(E-13"UF;W)T;VQK97(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<T(&QI8B](;W)D92]&;W)M+G!H<#HS
M,C<T"FUS9VED(")344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM
M<V=S='(@(E-13"UU9'1R>6L@9F]R(&]P<VQA9R!A9B!VYG)D:65R(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S,PIM<V=I9"`B4U-((@IM<V=S
M='(@(E-32"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*(SH@;&EB+TAO<F1E+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#15-3
M(@IM<V=S='(@(E-50T-%4R(*"B,Z(&QI8B]A<&DN<&AP.C$U,PIM<V=I9"`B
M4U]13"!3:&5L;"(*;7-G<W1R(")344PM9F]R=&]L:V5R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B
M"FUS9W-T<B`B3/AR(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#<@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")386EN="!(96QE
M;F$B"FUS9W-T<B`B4VMT+B!(96QE;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S$@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3,Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@T"FUS9VED(")3
M86EN="!+:71T<R!A;F0@3F5V:7,B"FUS9W-T<B`B4VMT+B!+:71T<R!O9R!.
M979I<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DQ"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,SD@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S='(@
M(E-K="X@3'5C:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Y(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.3(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X.2!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I97)R
M92!A;F0@36EQ=65L;VXB"FUS9W-T<B`B4VMT+B!0:65R<F4@;V<@36EQ=65L
M;VXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.3,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-"!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H
M92!'<F5N861I;F5S(@IM<V=S='(@(E-K="X@5FEN8V5N="!O9R!'<F5N861I
M;F5R;F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDR"FUS9VED(")386UE(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B4V%M
M;64@<F%M;64@*%]S96QF*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.30*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3$@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C4Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B4V%M;V$B
M"FUS9W-T<B`B4V%M;V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$R(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ.34*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q
M,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-A;B!-87)I
M;F\B"FUS9W-T<B`B4V%N($UA<FEN;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.38*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,38@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C$V(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B
M4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S='(@(E-O82!4;VUE(&]G(%!R
M:6YC:7!E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(E-A=&5L;&ET92!0
M<F]V:61E<B(*;7-G<W1R(")3871E;&ET=61B>61E<B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C`Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(E-A=61I87)A8FEE;B(*
M"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY.0IM<V=I9"`B4V%V
M92(*;7-G<W1R(")'96TB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D
M:70N:6YC.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM
M<V=S='(@(D=E;2!<(B5S7"(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C(Q-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@
M(D=E;2!<(B5S7"(B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS
M9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`B1V5M;64@26YD<W1I;&QI;F=E
M<B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C<*;7-G:60@(B(*(E-A
M=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O
M('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T
M<B`B(@HB1V5M(&=E;F5R97)E="!K;VYF:6=U<F%T:6]N('-O;2!02%`M<VMR
M:7!T(&D@9&EN('-E<G9E<G,@;6ED;&5R=&ED:6=E("(*(FMA=&%L;V<N(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B1V5M="`E
M<RUK;VYF:6=U<F%T:6]N+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.CDS"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@
M<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(D=E;71E('-K<FEP="!F;W(@
M;W!G<F%D97)I;F<@868@;W!SYG1N:6YG('1I;#H@7"(E<UPB+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"FUS9VED(")3
M8V%T=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B4W!R961T('1O<F1E;B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G
M<W1R(")6:61E;G-K86(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I
M9"`B4V5A<F-H(@IM<V=S='(@(E/X9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS,C(*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(E/X
M9V5M87-K:6YE<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y-34@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(Y-34*;7-G:60@(E-E;&5C="!&:6QE<R(*
M;7-G<W1R(")6YFQG(&9I;&5R(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0X-0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#@U"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@
M(E;F;&<@96X@9&%T;R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3DX"FUS9VED(")396QE8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B5N9L
M9R!E;B!G<G5P<&4@870@=&EL9OAJ92(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R
M(")6YFQG(&5N(&YY(&5J97(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z-C`*;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R(")6YFQG
M(&5N('-E<G9E<B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,34V
M"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*;7-G<W1R(")6YFQG(&5N
M(&)R=6=E<B!A="!T:6QF^&IE(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C8W-@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-C<V"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(E;F
M;&<@86QL92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-#,@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(V-#,*;7-G:60@(E-E;&5C="!A;&P@9&%T92!C
M;VUP;VYE;G1S+B(*;7-G<W1R(")6YFQG(&%L;&4@9&%T;RUK;VUP;VYE;G1E
M<BXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.#<S"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*
M;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B5N9L9R!E="!O8FIE
M:W0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-C<W"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HV-S<*
M;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(E;F;&<@:6YG96XB"@HC.B!S
M97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*;7-G:60@(B(*(E-E;&5C="!T:&4@
M8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U
M(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X
M="!A<F5A+B(*;7-G<W1R("(B"B)6YFQG(&1E('1E9VX@9'4@:&%R(&)R=6<@
M9F]R(&9R82!K87-S97)N92!N961E;F9O<BX@1&4@:V%N('/E(&ML:7!P97,@
M;V<@(@HB:V]P:65R97,@9G)A('1E>'1F96QT970N(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D96QI
M;6ET97(Z(@IM<V=S='(@(E;F;&<@9&%T;RUA9'-K:6QL97)E;CHB"@HC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT-`IM<V=I9"`B4V5L96-T('1H92!D
M871E(&9O<FUA=#HB"FUS9W-T<B`B5N9L9R!D871O9F]R;6%T.B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3`*;7-G:60@(E-E
M;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R
M(")6YFQG(&1E;B!I9&5N=&ET970L('-O;2!D=2!V:6P@YFYD<F4Z(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,38*;7-G:60@(E-E;&5C="!T:&4@
M=&EM92!D96QI;6ET97(Z(@IM<V=S='(@(E;F;&<@=&ED<RUA9'-K:6QL97)E
M;CHB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L
M96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`B5N9L9R!T:61S9F]R;6%T
M.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E
M;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R(")6YFQG('1O(&9E
M;'1E<BP@9&5R('-V87)E<B!T:6P@:&EN86YD96XN(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,Q,`IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H
M96UE+B(*;7-G<W1R(")6YFQG(&1I;B!F87)V97-A;6UE;G/F=&YI;F<N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U,@IM<V=I9"`B4V5L96-T('EO
M=7(@<')E9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R(")6YFQG(&1I="!F;W)E
M=')U:VYE('-P<F]G.B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C4X"FUS9VED(")396YD(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(E-E
M;F0@<')O8FQE;6)E<VMR:79E;'-E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$P-#(*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$P-#(*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@
M(E-E;F0@4TU3(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DX"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3,@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")396YE9V%L(@IM<V=S
M='(@(E-E;F5G86PB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R,PIM<V=I
M9"`B4V5N<V]R.B`B"FUS9W-T<B`B1OAL97(Z("(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,3`*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW,PIM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(E-E
M<'1E;6)E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DY(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E
M<F)I82!A;F0@36]N=&5N96=R;R(*;7-G<W1R(")397)B:65N(&]G($UO;G1E
M;F5G<F\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P
M,B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,@IM<V=I9"`B4V5R:6%L
M($YU;6)E<B(*;7-G<W1R(")397)I96YU;6UE<B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-#D*;7-G:60@(E-E<G9E<B!D871A('=R;VYG
M(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(E-E<G9E<BUD871A(&9O<FME
M<G0@96QL97(@:6MK92!T:6QGYFYG96QI9RXB"@HC.B!A9&UI;B]S97-S:6]N
M<RYP:'`Z,C<*;7-G:60@(E-E<W-I;VX@061M:6XB"FUS9W-T<B`B4V5S<VEO
M;G-A9&UI;FES=')A=&]R(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDR"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")397-S:6]N($E$(&5X<&ER960N(@IM
M<V=S='(@(E-E<W-I;VXM240@=61L^&)E="XB"@HC.B!L:6(O87!I+G!H<#HQ
M-#4*;7-G:60@(E-E<W-I;VYS(@IM<V=S='(@(E-E<W-I;VYE<B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,30@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(S,30*;7-G:60@(E-E="(*;7-G<W1R(")-YFYG9&4B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-SD*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W
M('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E
M="!I="XB"FUS9W-T<B`B(@HB26YD<W1I;&QI;F=E<B!D97(@=&EL;&%D97(@
M9&EG(&%T(&YU;'-T:6QL92!D:70@:V]D96]R9"P@:'9I<R!D=2!N;V=E;G-I
M;F1E("(*(G-K=6QL92!G;&5M;64@9&5T+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,3@*;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T
M('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R
M("));F1S=&EL(&9J97)N92!S97)V97)E+"!S;VT@9'4@^&YS:V5R(&%T('1I
M;&?E(&9R82!D:6X@<&]R=&%L+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX-PIM<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE
M>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R("));F1S=&EL(&1I;B!F
M;W)E=')U:VYE('-P<F]G+2P@=&ED<WIO;F4M(&]G(&1A=&]V86QG+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#$*;7-G:60@(B(*(E-E="!Y;W5R
M('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R
M97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R
M("(B"B));F1S=&EL(&1I;F4@;W!S=&%R='-A<'!L:6MA=&EO;F5R+"!F87)V
M97-A;6UE;G/F=&YI;F<L('-I9&5O<&9R:7-K;FEN(&]G("(*(F%N9')E('9I
M<VYI;F=S=&EL=F%L9RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<W
M"FUS9VED(")3971U<"(*;7-G<W1R("));F1S=&EL;&EN9R(*"B,Z('1E;7!L
M871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3971U<"!U
M<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S='(@(E-K<FEP=',@=&EL
M(&]P9W)A9&5R:6YG(&%F(&]P<^9T;FEN9R!T:6QGYFYG96QI9V4B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<U"FUS9VED(")3979E<F%L
M(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*;7-G
M<W1R(")&;&5R92!S=&5D97(@;75L:6<@;65D('!A<F%M971E<F5N.B`B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#`*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P,R!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T<B`B4V5Y8VAE
M;&QE<FYE(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Y.`IM<V=I
M9"`B4VAO<'!I;F<B"FUS9W-T<B`B4VAO<'!I;F<B"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHT,PIM<V=I9"`B4VAO<G0@4W5M;6%R>2(*
M;7-G<W1R(")+;W)T(&]P<W5M;65R:6YG(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0U,`IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN
M960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@(E-K86P@:'5R=&EG+71A<W1E
M<B!D969I;F5R97,@9F]R(&1E(&9L97-T92!H96YV:7-N:6YG97(_("CW*2(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(S(&QI8B](;W)D92]0
M97)M<RYP:'`Z,S(S"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-PHC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.CDP('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$S
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(E9I<R(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@
M9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N
M97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB
M5FES(&9O<G-K96QL96YE(&UE;&QE;2!D96X@9V5M=&4@;V<@9&5N(&YY;&EG
M="!G96YE<F5R961E(&MO;F9I9W5R871I;VXN(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0Y-`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@=VAE
M;B!L;V=G:6YG(&EN/R(*;7-G<W1R(")6:7,@=&ED<W!U;FMT(&9O<B!S96YE
M<W1E('1I;&=A;F<@=F5D('#E;&]G;FEN9S\B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-S8U(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8U"FUS9VED
M(")3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(E9I<R!M
M=6QI9VAE9"!F;W(@870@8F5H;VQD92!O<')I;F1E;&EG(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C<Y-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y
M-0IM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B5FES('-N=7!P97(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,P"FUS9VED(")3:&]W('1A8FQE
M(&]P97)A=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(E9I<R!486)E;&]P97)A
M=&EO;F5R+6MN87!P96X@:2!M96YU96X_(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E<R!-
M96YU(&]N('1H92!L969T/R(*;7-G<W1R(")6:7,@)7,M;65N=65N('1I;"!V
M96YS=')E/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0
M<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")6:7,@9&EA;&]G=FEN9'5E(&UE
M9"!E9V5N<VMA8F5R(&9O<B!T86)E;&-E;&QE;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B
M4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B5FES
M(&1I86QO9W9I;F1U92!M960@96=E;G-K86)E<B!F;W(@=&%B96QL96XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I
M86QO9R(*;7-G<W1R(")6:7,@9&EA;&]G=FEN9'5E(&UE9"!E9V5N<VMA8F5R
M(&9O<B!T86)E;'+F:VME;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA
M9V4@<')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B5FES(&1I86QO9W9I;F1U
M92!M960@96=E;G-K86)E<B!F;W(@8FEL;&5D970B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-S8S(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8S"FUS
M9VED(")3:&]W('5P;&]A9"(*;7-G<W1R(")6:7,@869S96YD=&4B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B
M4VAO=V5R<R(*;7-G<W1R(")">6=E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W97)S($5A<FQY(@IM
M<V=S='(@(D)Y9V5R('1I9&QI9W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU-`IM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S
M='(@(D)Y9V5R('-E;G0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU-0IM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB
M"FUS9W-T<B`B0GEG97(@:2!NYG)H961E;B(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C$Y(&QI8B](;W)D92]";&]C
M:R],87EO=70N<&AP.C0X,`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.C8Q.0IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(E-K<G5M<"(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z
M.3$P"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP
M:'`Z.3<R"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z,3`U.`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.C$Q,C`*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HQ,3@S"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70O36%N86=E<BYP:'`Z,3(R,PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R-3(*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C@U"B,Z(&QI8B](;W)D92]"
M;&]C:R],87EO=70N<&AP.C<W-"!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H
M<#HX,S8*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z.3(R(&QI8B](
M;W)D92]";&]C:R],87EO=70N<&AP.CDX-`HC.B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+G!H<#HQ,#0W(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C$P
M.#<*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,3$Q-B!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+G!H<#HQ,30Y"B,Z(&QI8B](;W)D92]";&]C:R],
M87EO=70O36%N86=E<BYP:'`Z.3$P"B,Z(&QI8B](;W)D92]";&]C:R],87EO
M=70O36%N86=E<BYP:'`Z.3<R"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z,3`U.`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.C$Q,C`*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA
M9V5R+G!H<#HQ,3@S"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z,3(R,PHC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.C$R-3(*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HQ,C@U"FUS9VED(")3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO
M8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0B"FUS9W-T<B`B4VMR=6UP(&5L
M;&5R(&9L>70@;F%B;V)L;VMK92!A9B!V96IE;B!F^')S="(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C$Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P-0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(E-I97)R82!,96]N
M92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C8@;&EB
M+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-C8*;7-G:60@(E-I9VX@=7`B"FUS
M9W-T<B`B4VMR:78@:6YD(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HW,3,@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,3,*;7-G
M:60@(E-I9VYA='5R92(*;7-G<W1R(")5;F1E<G-K<FEF="(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$R(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-S$R"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM(@IM
M<V=S='(@(E-I9VYA='5R86QG;W)I=&UE(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,#8@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED
M(")3:6YG87!O<F4B"FUS9W-T<B`B4VEN9V%P;W)E(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-2!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C@T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DV
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,34@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(S-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,C0V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,3(*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$P-2!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DV(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,C$U"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,C,W(&QI8B](;W)D92]&;W)M+G!H<#HR,C0V(&QI8B](;W)D92]&;W)M+G!H
M<#HR.3$R"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3`U(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R87(N<&AP.C8U"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]T9WHN<&AP.C@T(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<R
M"FUS9VED(")3:7IE(@IM<V=S='(@(E-T^')R96QS92(*"B,Z('1E;7!L871E
M<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4R"FUS9VED(")3:VEP
M($UA:6YT96YA;F-E(@IM<V=S='(@(E-P<FEN9R!V961L:6=E:&]L9&5L<V4@
M;W9E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(P,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$P(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B
M4VQO=F%K:65T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#@@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V96YI82(*;7-G
M<W1R(")3;&]V96YI96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R(*;7-G<W1R(")3;F4B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B
M4VYO=R!3:&]W97(B"FUS9W-T<B`B4VYE8GEG92(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")3;F]W(%-H;W=E
M<G,B"FUS9W-T<B`B4VYE8GEG97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU.0IM<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY
M(@IM<V=S='(@(E-N96)Y9V5R('1I9&QI9W0B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,`IM<V=I9"`B4VYO=R!3:&]W97)S
M($QA=&4B"FUS9W-T<B`B4VYE8GEG97(@<V5N="(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C@U"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B4VYE
M9'EB9&4Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@Y"FUS9VED(")3
M;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R(")3;F7F:W9I=F%L
M96YT(&D@=F%N9#H@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#(@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3;VQO;6]N($ES
M;&%N9',B"FUS9W-T<B`B4V%L;VUO;OAE<FYE(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,30@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V"FUS
M9VED(")3;VUA;&EA(@IM<V=S='(@(E-O;6%L:6$B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B
M4V%N9V4@;V<@<&]E<VDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.3`X(&QI8B](;W)D92]&;W)M+G!H<#HR.3`X"FUS9VED(")3;W)T(&]R9&5R
M('-E;&5C=&EO;B(*;7-G<W1R(")3;W)T97)I;F=S=F%L9R(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Q-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-#<*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M-3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU.#D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ
M-C8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.#D@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U.0HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C$W"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C0W(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ-C8*(SH@
M;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$X.0IM<V=I9"`B4V]U<F-E(&%D
M9')E<W,B"FUS9W-T<B`B069S96YD97)A9')E<W-E(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR-34@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X
M"FUS9VED(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`B4WED869R:6MA(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E-O=71H($5U<F]P96%N
M("A)4T\M.#@U.2TS*2(*;7-G<W1R(")3>61E=7)O<.9I<VL@*$E33RTX.#4Y
M+3,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3`Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,#@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,2!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE
M(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B4WED($=E;W)G:6$@
M;V<@1&4@<WED;&EG92!386YD=VEC:/AE<B(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N
M($AE;6ES<&AE<F4B"FUS9W-T<B`B4WED;&EG92!H86QV:W5G;&4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I
M9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R("),=69T
M(&UE;&QE;2!N86)O8V5L;&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E='=E96X@8V]N
M=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B3'5F="!M96QL96T@
M:6YD:&]L9"!O9R!R86UM92!I(&-E;&QE(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.#$U(&QI8B](;W)D92]&;W)M+G!H<#HX,34*;7-G:60@(E-P
M86-E<B(*;7-G<W1R(")-96QL96UR=6US=&%N9V5T(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4U"FUS9VED(")3
M<&%C:6YG(@IM<V=S='(@(DUE;&QE;7)U;2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I
M;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B3'5F="!O9R!F;W)R:6YG(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#`@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S$*;7-G:60@(E-P86EN(@IM<V=S='(@(E-P86YI96XB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3`P"FUS9VED(")3<&%M(@IM<V=S='(@
M(E-K:61T<&]S="(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I
M9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`B26YD=&%S=&YI
M;F<@9F]R('-P96-I86QK87)A:W1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G:60@(E-P;&ET(&-E
M;&PB"FUS9W-T<B`B1&5L(&-E;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L:70@8V]L
M=6UN(@IM<V=S='(@(D1E;"!K;VQO;FYE(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@
M<F]W(@IM<V=S='(@(D1E;"!RYFMK92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV,0IM<V=I9"`B4W!O<G1S(@IM<V=S='(@(E-P;W)T(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,30Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$T,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX.`IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(E-R:2!,86YK82(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z.#$@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C8V"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R(")3=&%N9&%R9"(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K
M(@IM<V=S='(@(E-T87(@5')E:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(U.#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<Y,0HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C4X-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y,0IM
M<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R(")"96=Y;F1E;'-E<^5R(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S$@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU-S$*;7-G:60@(E-T871E(&]R(%!R;W9I;F-E
M(@IM<V=S='(@(D1E;'-T870@96QL97(@<')O=FEN<R(*"B,Z('1E;7!L871E
M<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS
M9W-T<B`B4W1A='5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<Y
M-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y-PIM<V=I9"`B4W1O<F%G92!F;W)M
M870B"FUS9W-T<B`B3&%G<FEN9W-F;W)M870B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4W,R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4W,PIM<V=I9"`B4W1R965T($%D9')E<W,B"FUS9W-T<B`B5F5J(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM
M<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R(")'96YN96US=')E9VYI;F<B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,S(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,C,S"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R("),:7-T
M92!A9B!S=')E;F=E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W
M,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W,PIM<V=I9"`B4W1R:7`@9&]M86EN
M(&9R;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`B1FIE<FX@9&]MYFYE(&9R82!A
M9')E<W-E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(E-T
M:6P@6T-34UTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R(")3^&XB"@HC.B!U=&EL+VEC
M;VY?8G)O=W-E<BYP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER
M96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(E5N9&5R:V%T86QO
M9R!<(B5S7"(@:6MK92!F=6YD970N(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F9C.#(R+G!H<#HW,PHC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R(")%;6YE
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R(&9R86UE=V]R:R]&
M;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,Q.`HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,S,R(&QI8B](;W)D92]&;W)M+U)E;F1E<F5R+G!H<#HS,3@*;7-G:60@
M(E-U8FUI="(*;7-G<W1R(")';V1K96YD(@H*(SH@<VEG;G5P+G!H<#HT.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T;R!A
M9&0@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N
M=&EL('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T
M<B`B(@HB06YM;V1N:6YG(&]M(&%T('1I;&;X:F4@7"(E<UPB('1I;"!S>7-T
M96T@869S96YD="X@($1U(&MA;B!I:VME(&QO9V=E('#E(&;X<B`B"B)D:6X@
M86YM;V1N:6YG(&5R(&)L979E="!A;F5R:V5N9'0N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R
M:7!T(@IM<V=S='(@(DQA=B!S:W)I9G0B"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3`U"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+W-T871U<RYP:'`Z,C@*(SH@;&EB+TAO<F1E+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C97-S(@IM
M<V=S='(@(E5D9OAR="(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE
M('-Y<W1E;2XB"FUS9W-T<B`B7"(E<UPB(&)L978@=&EL9OAJ970@=&EL('-Y
M<W1E;65T+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R(%PB
M)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(D1A=&$@9F]R(&)R=6=E
M<B!<(B5S7"(@8FQE=B!S;&5T=&5T(&9R82!S>7-T96UE="XB"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB
M+B(*;7-G<W1R(")<(B5S7"(@<VQE='1E="XB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V
M960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B7"(E<UPB('-L
M971T970@9G)A('-Y<W1E;65T+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T
M:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(DMO;F9I9W5R
M871I;VX@=&EL8F%G96;X<G0N($=E;FEN9&SF<R!F;W(@870@<V4@YFYD<FEN
M9V5R;F4N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C4W"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@
M8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E)E<V5R=F5K;VYF:6=U
M<F%T:6]N(&=E;70N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A
M8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(E)E<V5R=F5K
M;VYF:6=U<F%T:6]N9FEL("5S(&=E;70N(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,38X"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D
M(%PB)7-<(B(*;7-G<W1R(")<(B5S7"(@;W!D871E<F5T+B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R
M"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*
M;7-G<W1R(")<(B5S7"(@<VMR979E="XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`T(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(P-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@
M(E-U9&%N(@IM<V=S='(@(E-U9&%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@IM<V=I9"`B4W5M;6%R>2(*
M;7-G<W1R("));F1H;VQD(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U
M"FUS9VED(")3=6X@4FES92(*;7-G<W1R(")3;VQO<&=A;F<B"@HC.B!L:6(O
M0FQO8VLO<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U;B!3970B"FUS9W-T<B`B
M4V]L;F5D9V%N9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8Q"FUS9VED(")3=6YN>2(*;7-G<W1R(")3;VQR:6=T(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-0IM<V=I9"`B4W5N<FES
M92(*;7-G<W1R(")3;VQO<&=A;F<B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP
M:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O
M4W5N<V5T(@IM<V=S='(@(E-O;&]P9V%N9R]S;VQN961G86YG(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-`IM<V=I9"`B4W5N<FES93H@
M(@IM<V=S='(@(E-O;&]P9V%N9SH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(P.`IM<V=I9"`B4W5N<V5T(@IM<V=S='(@(E-O;&YE9&=A
M;F<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`W"FUS9VED
M(")3=6YS970Z("(*;7-G<W1R(")3;VQN961G86YG.B`B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S"FUS9VED(")3=7!E
M<G-C<FEP="(*;7-G<W1R(")(YG9E="!S:W)I9G0B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S@P"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(DAJ
MYFQP(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,34@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3=7)I;F%M92(*;7-G<W1R(")3
M=7)I;F%M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-S4@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S4*;7-G:60@(E-U<FYA
M;64B"FUS9W-T<B`B169T97)N879N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,#D@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3
M=F%L8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(E-V86QB87)D(&]G($IA
M;B!-87EE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(Q-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$Y(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B4W=A>FEL86YD(@IM<V=S
M='(@(E-W87II;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#4@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(Q-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`U
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM
M<V=S='(@(E-V97)I9V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B
M"FUS9W-T<B`B4V-H=V5I>B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C@V"FUS9VED(")3>6YC(&QO9R!D96QE=&5D(@IM<V=S='(@(E-Y;F,@
M;&]G('-L971T970B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30U"FUS
M9VED(")3>6YC34PB"FUS9W-T<B`B4WEN8TU,(@H*(SH@9G)A;65W;W)K+U-1
M3"]344PO2V5Y=V]R9',N<&AP.CDW(&QI8B](;W)D92]344PO2V5Y=V]R9',N
M<&AP.CDW"FUS9VED(")3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM
M<V=S='(@(E-Y;G1A:W-F96IL(&D@<_AG96QE9"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C$X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-PIM
M<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B4WER:65N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G
M:60@(E0M4W1O<FTB"FUS9W-T<B`B5&]R9&5N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*;7-G:60@(E0M4W1O<FT@86YD
M(%=I;F1Y(@IM<V=S='(@(E1O<F1E;B!O9R!V:6YD(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*;7-G:60@(E0M4W1O<FUS
M(@IM<V=S='(@(E1O<F1E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R
M(")4;W)D96X@=&ED;&EG="(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O='-V
M+G!H<#HQ-C8@;&EB+TAO<F1E+T1A=&$O='-V+G!H<#HQ-C8*;7-G:60@(E13
M5B!F:6QE(@IM<V=S='(@(E135BUF:6PB"@HC.B!L:6(O2&]R9&4O54DO5&%B
M;&4N<&AP.C$S-`IM<V=I9"`B5&%B;&4B"FUS9W-T<B`B5&%B96PB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S
M"FUS9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(E1A8F5L+65G96YS
M:V%B97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N
M<&AP.C4W"B,Z(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W
M"FUS9VED(")486)L92!3970B"FUS9W-T<B`B5&%B96QMYFYG9&4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<R
M"FUS9VED(")486)L92!P<F]P97)T:65S(@IM<V=S='(@(E1A8F5L+65G96YS
M:V%B97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,T"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,S0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED
M(")486EW86XB"FUS9W-T<B`B5&%I=V%N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(Q.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G
M<W1R(")486EW86XL($1E;B!K:6YE<VES:V4@<')O=FEN<R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C(U(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R(")4861J:6MI<W1A;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R
M,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,U(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI
M8R!O9B(*;7-G<W1R(")486YZ86YI82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T
M<B`B3>5L.B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,R(&QI
M8B](;W)D92]+;VQA8BYP:'`Z.3,R"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES
M=#HQ,#0Y(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#D*;7-G:60@(E1A
M<VMS(@IM<V=S='(@(D]P9V%V97(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4W-"!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W
M-`IM<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R(")496QE9F]N;G5M
M;65R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3<*;7-G:60@(E1E;7`@
M9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(E1E;7`N('-I9'-T92!T:6UE.B`B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R,0IM<V=I9"`B5&5M<&5R871U
M<F4B"FUS9W-T<B`B5&5M<&5R871U<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,3(*;7-G:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`B
M5&5M<&5R871U<CH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(X,@HC+"!P:'`M9F]R;6%T"FUS9VED(")496UP97)A='5R93QB<B`O/B@E
M<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@(E1E;7!E<F%T=7(\8G(@
M+SXH)7-(^&HE<R\E<TQA=B5S*2`F9&5G.R5S(@H*(SH@9G)A;65W;W)K+U1E
M;7!L871E+U1E;7!L871E+G!H<#HV.34@;&EB+TAO<F1E+U1E;7!L871E+G!H
M<#HV.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO
M="!F;W5N9"XB"FUS9W-T<B`B4VMA8F5L;VX@7"(E<UPB(&EK:V4@9G5N9&5T
M+B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y"FUS9VED(")496UP;&%T
M92!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")3:V%B96QO;BUA9&UI;FES=')A
M=&EO;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3$@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S,R-PHC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3(Q,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,R-PIM<V=I9"`B5&5X="(*;7-G
M<W1R(")496MS="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-SD*;7-G
M:60@(E1E>'0@3VYL>2(*;7-G<W1R(")296X@=&5K<W0B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<T"FUS9VED
M(")497AT(&%L:6=N(@IM<V=S='(@(E1E:W-T+6IU<W1E<FEN9R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@
M(E1E>'1T;W`B"FUS9W-T<B`B5&5K<W0M=&]P(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T
M<B`B5&]R(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.30*;7-G:60@(E1H
M86D@*%1)4RTV,C`I(@IM<V=S='(@(E1H86D@*%1)4RTV,C`I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,C0@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`Y"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R(")4:&%I;&%N9"(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#4Q(&QI8B]61E,O9G1P+G!H
M<#HX-3$*;7-G:60@(E1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B
M;&4N(@IM<V=S='(@(D944"UU9'9I9&1E;'-E;B!E<B!I:VME('1I;&?F;F=E
M;&EG+B(*"B,Z(&9R86UE=V]R:R](:7-T;W)Y+TAI<W1O<GDN<&AP.C4U(&QI
M8B](;W)D92](:7-T;W)Y+G!H<#HU-0IM<V=I9"`B5&AE($AI<W1O<GD@<WES
M=&5M(&ES(&1I<V%B;&5D+B(*;7-G<W1R(")(:7-T;W)I:RUS>7-T96UE="!E
M<B!S;.5E="!F<F$N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY
M,S@@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,S@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO
M="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8BUI;G1E9W)A
M=&EO;G-M;W1O<F5N('5N9&5R<W3X='1E<B!I:VME(%PB)7-<(B(*"B,Z(&9R
M86UE=V]R:R].971?24U34"])35-0+T)O;VLN<&AP.C$R.3@@;&EB+TYE="])
M35-0+T)O;VLN<&AP.C$R.3@*;7-G:60@(E1H92!)35-0(&QO9R!C;W5L9"!N
M;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(DE-4U`M;&]G9V5N(&MU;FYE
M(&EK:V4@:VQA<F?X<F5S+B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L
M;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R(")-86EN=&5N86YC93HZ+6ML87-S
M96X@8FQE=B!I:VME(&EN9&SF<W0B"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L
M;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S
M(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B5&EL=F%L9W-V:6YD=65T(&5R
M(&)L979E="!L=6MK970N($%F<VQU='1E<BXB"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C$X.2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(P
M,`HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(Q,2!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C(R,PHC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C(S-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(U,@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(V-"!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C,P,PHC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C$X.2!L:6(O2&]R
M9&4O4&5R;7,N<&AP.C(P,"!L:6(O2&]R9&4O4&5R;7,N<&AP.C(Q,0HC.B!L
M:6(O2&]R9&4O4&5R;7,N<&AP.C(R,R!L:6(O2&]R9&4O4&5R;7,N<&AP.C(S
M-"!L:6(O2&]R9&4O4&5R;7,N<&AP.C(U,@HC.B!L:6(O2&]R9&4O4&5R;7,N
M<&AP.C(V-"!L:6(O2&]R9&4O4&5R;7,N<&AP.C,P,PIM<V=I9"`B(@HB5&AE
M(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT
M(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E
M<FUI<W-I;VYS+B(*;7-G<W1R("(B"B)!9&UI;FES=')A=&]R96X@8FQI=F5R
M(&[X9'0@=&EL(&%T(&MO;F9I9W5R97)E(&5N('!E<FUA;F5N="!4:6QL861E
M;'-E<RTB"B)B86-K96YD+"!H=FES(&1U('9I;"!A;G9E;F1E(%1I;&QA9&5L
M<V5R+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T;VT@<VED92!O;FQY(@IM<V=S
M='(@(DMU;B!U;F1E<G-I9&5N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M
M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@
M9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R("(B"B)+;VYT86MT
M+4E$+6YU;6UE<F5T(&)L978@:6MK92!A;F=I=F5T+"!E9G1E<FQA9'0@=&]M
M="!E;&QE<B!B;&5V(&EK:V4@9G5N9&5T("(*(FD@9&%T86)A<V5N+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,2!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C4Q"FUS9VED(")4:&4@8V]N
M=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B
M;V]K+B(*;7-G<W1R(")+;VYT86MT96X@8FQE=B!T:6QF^&IE="!T:6P@9&ET
M(&%D<F5S<V5K87)T;W1E:V5T+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$Q-S(@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$W,@IM
M<V=I9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@
M<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T
M<B`B(@HB1&5N(&SX<V=J;W)T92!01U`M<VEG;F%T=7(M8FQO:R!E<B!K<N9V
M970@9F]R(&%T(&MU;FYE('9E<FEF:6-E<F4@9&5N("(*(G-I9VYE<F5D92!B
M97-K960N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-#$*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E
M:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@
M(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R("(B"B)$:7-T<FEB=71I;VYS
M;&ES=&4M240@97(@96YT96X@:6MK92!A;F=I=F5T+"!T;VUT(&5L;&5R(&EK
M:V4@9G5N9&5T(&D@(@HB9&%T86)A<V5N+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*;7-G:60@(E1H92!D:7-T<FEB=71I
M;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"XB"FUS9W-T<B`B1&ES=')I8G5T
M:6]N<VQI<W1E;B!I:VME(&%N9VEV970N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+G!H<#HQ,38@;&EB+TAO<F1E+T-R>7!T+G!H<#HQ,38*;7-G:60@
M(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B
M(&-O;FYE8W1I;VXN(@IM<V=S='(@(DMR>7!T97)I;F=S9F%C:6QI=&5T97)N
M92!K<N9V97(@96X@<VEK:V5R('=E8BUF;W)B:6YD96QS92XB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$X-B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C4R.`HC.B!L:6(O2&]R9&4N<&AP.C$X-B!L:6(O2&]R9&4N<&AP
M.C4R.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@
M8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@(D9I;&5N("5S(&+X<B!I
M;F1E:&]L9&4@96X@)7,M:6YD<W1I;&QI;F<N(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ-SD@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU
M,3@*(SH@;&EB+TAO<F1E+G!H<#HQ-SD@;&EB+TAO<F1E+G!H<#HU,3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@
M<V]M92`E<R!S971T:6YG<RXB"FUS9W-T<B`B1FEL96X@)7,@8OAR(&EN9&5H
M;VQD92!N;V=L92`E<RUI;F1S=&EL;&EN9V5R+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C(R-B!L:6(O5D93+V9I;&4N<&AP.C(R-@IM<V=I
M9"`B5&AE(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS
M9W-T<B`B1FEL96X@:V%N(&EK:V4@:V]P:65R97,@;W9E;G#E('-I9W-E;'8N
M(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,C@P(&QI8B](;W)D92]$
M871A+G!H<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A
M+B(*;7-G<W1R(")&:6QE;B!I;F1E:&]L9'0@:6YG96X@9&%T82XB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@
M9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F
M8S@R,B!M97-S86=E+B(*;7-G<W1R(")&^&QG96YD92!E<B!H;W9E9&5R;F4@
M9G)A(&1E;FYE(&UE<W-A9V4O<F9C.#(R+6)E<VME9"XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4
M:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M
M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B
M=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@
M;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@
M961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE
M<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y
M(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T
M:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@
M8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL
M('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@
M(B(*(D9U;&1S:^9R;7-T:6QS=&%N9"!V:61E<R!A="!V;VQD92!P<F]B;&5M
M97(@:2!);G1E<FYE="!%>'!L;W)E<B!G<G5N9&5T("(*(F)R;W=S97(M9F5J
M;"P@<V]M('9I(&EK:V4@:&%R(&MU;FYE="!O;6?E+B!$=2!V:6P@;75L:6=V
M:7,@;W!L979E("(*(F9O<G9A;G-K961E('9I<VYI;F=E<BP@;6%N9V5L('#E
M(&5D:71E<FEN9W-F=6YK=&EO;F5R(&]G+V5L;&5R('1I;&;F;&1I9V4@(@HB
M8G)O=W-E<BUN961B<G5D+B!(=FES(&1I="!S>7-T96T@97(@5VEN9&]W<R9N
M8G-P.SEX('9I;"!D=2!M960@:/AJ("(*(G-A;F1S>6YL:6=H960@;W!L979E
M("='96YE<F5L(&)E<VMY='1E;'-E<V9E:FPG(&]G('9I;"!B;&EV92!N^&1T
M('1I;"!A="`B"B)G96YS=&%R=&4@;6%S:VEN96XN7%QN7%QN1'4@97(@;G4@
M861V87)E="X@(%1R>6L@3TL@:'9I<R!D=2!S=&%D:6<@^&YS:V5R(&%T("(*
M(G!R^'9E="!F=6QD<VOF<FUS<F5D:6=E<FEN9RXB"@HC.B!S97)V:6-E<R]P
M<F5F<RYP:'`Z,3$Q"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!I9&5N=&ET
M>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B261E;G1I=&5T
M96X@7"(E<UPB(&5R('-L971T970N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M
M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B2W5N('9E;G-T<F4@<VED92XB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ-3<@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@
M=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P
M9W`Z.B!C;&%S<RXB"FUS9W-T<B`B4&QA8V5R:6YG96X@868@1VYU4$<M<')O
M9W)A;6UE="!S:V%L(&=I=F5S('1I;"!#<GEP=%]P9W`Z.BUK;&%S<V5N+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HR,#(@;&EB+TAO<F1E
M+TU)344O341.+G!H<#HR,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB
M(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E
M('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D
M+B(*;7-G<W1R("(B"B)"97-K961E;BP@<V]M(&5R('-E;F1T(&1E;B`E<R!T
M:6P@)7,@;65D(&5M;F5T(%PB)7-<(B!E<B!B;&5V970@=FES="Y<;B(*(D1E
M='1E(&5R(&EN9V5N(&=A<F%N=&D@9F]R+"!A="!B97-K961E;B!R96YT(&9A
M:W1I<VL@97(@8FQE=F5T(&SF<W0@96QL97(@(@HB9F]R<W3E970N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-R!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3@W-PIM<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T
M;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S='(@(DYA=FYE="P@9&5R('-K86P@
M8G)U9V4L(&[E<B!D97(@:&5N=FES97,@=&EL('-K<FEV97-I9&5N(@H*(SH@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#<T(&QI8B]&:6QE+T-35BYP
M:'`Z-#<T"FUS9VED(")4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU
M;65R:6,N(@IM<V=S='(@(D%N=&%L;&5T(&%F(&9E;'1E<B!S:V%L(';F<F4@
M970@=&%L+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,3(S,B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R,S(*;7-G:60@(E1H
M92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R
M>7!T7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@(F]P96YS<VPM;6]D=6QE="!E
M<B!K<N9V970@868@2&]R9&5?0W)Y<'1?<VUI;64Z.BUK;&%S<V5N+B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,CDU(&QI8B](;W)D92]0<F5F
M<RYP:'`Z,CDU"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E
M;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T
M82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G
M<W1R("(B"B)0<N9F97)E;F-E;B!<(B5S7"(@:W5N;F4@:6MK92!G96UM97,@
M9F]R9&D@9&5N<R!D871A(&]V97)S:W)I9&5R(&1E;B`B"B)M86MS:6UA;'0@
M=&EL;&%D=&4@<W3X<G)E;'-E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O9&5B+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]E;G-C<FEP="YP:'`Z,S4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O;7-E>&-E;"YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)P;2YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W=E8F-P<"YP:'`Z,S<@;&EB+TAO<F1E+TU)344O5FEE=V5R+V1E
M8BYP:'`Z,S(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H
M<#HS-2!L:6(O2&]R9&4O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=V5B8W!P+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@
M<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@
M;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(@IM<V=S='(@(B(*(E!R;V=R86UM
M970L(&1E<B!B<G5G97,@=&EL(&%T(&)E=')A9W1E(&1E;FYE(&1A=&%T>7!E
M("@E<RDL(&)L979E="!I:VME("(*(F9U;F1E="!PY2!S>7-T96UE="XB"@HC
M.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT.#<@;&EB+T9I;&4O0U-6
M+G!H<#HT.#<*;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O
M;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B0VET871I;VYS=&5G;F5T
M('-K86P@=N9R92!E="!E;FME;'0@=&5G;BXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS9VED(")4:&4@
M<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R(")+=6X@:/AJ<F4@
M;V<@=F5N<W1R92!S:61E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I9VAT+6AA;F0@
M<VED92!O;FQY(@IM<V=S='(@(DMU;B!S:61E;B!T:6P@:/AJ<F4B"@HC.B!F
M<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-SD@;&EB+T9I;&4O0U-6+G!H
M<#HT-SD*;7-G:60@(E1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE
M(&-H87)A8W1E<BXB"FUS9W-T<B`B061S:VEL;&5L<V5S=&5G;F5T('-K86P@
M=N9R92!E="!E;FME;'0@=&5G;BXB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C
M<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB
M)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")397)V97)E;B!<(B5S
M7"(@97(@<VQE='1E="XB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H
M<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H
M87,@8F5E;B!S879E9"XB"FUS9W-T<B`B4V5R=F5R96X@7"(E<UPB(&5R(&=E
M;70N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E
M9"XB"FUS9W-T<B`B3W!S:W)I=FYI;F=S86YM;V1N:6YG96X@9F]R("5S(&5R
M('-L971T970N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-
M86YA9V5R+G!H<#HT-S`*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA
M9V5R+G!H<#HT-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-P96-I9FEE
M9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B1&5N(&%N9VEV
M;F4@<N9K:V4@*"5D*2!E:W-I<W1E<F5R(&EK:V4N(@H*(SH@;&EB+TAO<F1E
M+T)L;V-K+TQA>6]U="YP:'`Z,S,P"FUS9VED(")4:&4@<W!E8VEF:65D(')O
M=R!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B1&5N(&%N9VEV;F4@<N9K:V4@
M96MS:7-T97)E<B!I:VME+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z,3<Y(&QI8B]61E,O<W%L+G!H<#HQ-SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB
M"FUS9W-T<B`B1&5N(&UI9&QE<G1I9&EG92!F:6P@7"(E<UPB(&9I;F1E<R!I
M:VME+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,#(@;&EB+TAO
M<F1E+T9O<FTN<&AP.C,S,#(*;7-G:60@(E1H92!T97AT('EO=2!E;G1E<F5D
M(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS9W-T
M<B`B1&5N('1E:W-T+"!S;VT@9'4@:6YD=&%S=&5D92P@<&%S<V5R(&EK:V4@
M=&EL('1E:W-T96X@<.4@<VOF<FUE;BXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED(")4:&4@=&]P
M(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R(")+=6X@=&]P(&]G(&)U
M;F0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R(")+
M=6X@=&]P(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,S(W(&QI8B](
M;W)D92]$871A+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A
M<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R(")$96X@
M869S96YD=&4@:6YF;W)M871I;VX@97(@=&%B="!S:61E;B!S:61S=&4@=')I
M;BXB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R86UE
M=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-S(*(SH@;&EB+TAO<F1E+T1A=&$O
M='-V+G!H<#HQ-S(@;&EB+TAO<F1E+T1A=&$O8W-V+G!H<#HR-C(*;7-G:60@
M(E1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T
M<B`B1&5N(&]V97)F^')T92!F:6P@:W5N;F4@:6MK92!G96UM97,N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Y(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ,3`*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B;&]C
M:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")W96%T:&5R+F-O;2UB;&]K
M:V5N(&5R(&EK:V4@=&EL9^9N9V5L:6<N(@H*(SH@=71I;"]I8V]N7V)R;W=S
M97(N<&AP.C(U"B,L('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E8W1O
M<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B5&5M82UK871A;&]G970@
M7"(E<UPB(&EK:V4@9G5N9&5T+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z,3<X(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3<X"FUS9VED
M(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@(DEN
M9V5N('1I;'9A;&<@=&EL('+E9&EG:&5D+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.C,U,"!L:6(O2&]R9&4O34E-12]#;VYT96YT
M<RYP:'`Z,S4P"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@
M8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B1&5R(&9O<F5F:6YD97,@
M:6YG96X@9&5L92P@<V]M(&MA;B!V:7-E<R!I;F1L96IR970N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30P,2!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,30P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA
M;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D
M("5S(&-H87)A8W1E<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E
M<RXB"FUS9W-T<B`B(@HB1&5R(&5R(&9O<B!M86YG92!T96=N(&D@9&5T=&4@
M9F5L="X@1'4@:&%R(&EN9'1A<W1E="`E<R!T96=N.R!D=2!S:V%L("(*(FEN
M9'1A<W1E(&UI;F1R92!E;F0@)7,N(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI
M;B]U<V5R+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS
M9W-T<B`B1&5R(&]P<W1O9"!E="!P<F]B;&5M('5N9&5R('1I;&;X:F5L<V5N
M(&%F("<E<R<@=&EL('-Y<W1E;65T.B`E<R(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M
M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E
M;3H@(@IM<V=S='(@(B(*(D1E<B!O<'-T;V0@970@<')O8FQE;2!U;F1E<B!F
M:F5R;F5L<V4@868@9&%T82!F;W(@8G)U9V5R(%PB)7-<(B!F<F$@(@HB<WES
M=&5M970Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F
M<F]M('1H92!S>7-T96TZ("(*;7-G<W1R(")$97(@;W!S=&]D(&5T('!R;V)L
M96T@=6YD97(@<VQE=&YI;F<@868@7"(E<UPB(&9R82!S>7-T96UE=#H@(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,34Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R
M(")$97(@;W!S=&]D(&5T('!R;V)L96T@=6YD97(@;W!D871E<FEN9R!A9B!<
M(B5S7"(Z("5S(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z
M.3(W(&QI8B](;W)D92]"<F]W<V5R+G!H<#HY,C<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R(")$97(@;W!S=&]D(&5T
M('!R;V)L96T@=6YD97(@9FEL;W9E<F;X<G-L96XZ($EN9V5N("5S(&)L978@
M;W9E<F;X<G0N(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z
M.3,R(&QI8B](;W)D92]"<F]W<V5R+G!H<#HY,S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P
M;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A
M;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@HB1&5R(&]P<W1O
M9"!E="!P<F]B;&5M('5N9&5R(&9I;&]V97)F^')S;&5N.B`E<R!V87(@<W3X
M<G)E(&5N9"!D96X@;6%K<VEM86QT("(*(G1I;&QA9'1E('-T^')R96QS92`H
M)60@8GET97,I+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP
M.CDS-"!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3,T"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N(@IM
M<V=S='(@(B(*(D1E<B!O<'-T;V0@970@<')O8FQE;2!U;F1E<B!F:6QO=F5R
M9OAR<VQE;CH@)7,@8FQE=B!K=6X@9&5L=FES="!O=F5R9OAR="XB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*
M;7-G<W1R(")$97(@;W!S=&]D(&5N(&9E:FP@=6YD97(@=FES;FEN9R!A9B!D
M96YN92!B97-K961D96PB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,SD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C0X(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,SD*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I
M9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D
M871A+B(*;7-G<W1R(")$97(@;W!S=&]D(&5N(&9E:FP@=6YD97(@:6UP;W)T
M97)I;F=E;B!A9B!K;VYT86MT:6YF;W)M871I;VXN(@H*(SH@9G)A;65W;W)K
M+T1A=&$O1&%T82]I;6,N<&AP.C,Q(&QI8B](;W)D92]$871A+VEM8RYP:'`Z
M,S$*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#
M86QE;F1A<B!D871A+B(*;7-G<W1R(")$97(@;W!S=&]D(&5N(&9E:FP@=6YD
M97(@:6UP;W)T97)I;F=E;B!A9B!I0V%L96YD87(@9&%T82XB"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C@R"FUS9VED("(B"B)4:&5R92!W87,@86X@
M97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@
M;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B(@HB1&5R
M(&]P<W1O9"!E;B!F96IL(&D@:V]N9FEG=7)A=&EO;G-F;W)M=6QA<F5N+B!.
M=6QI9W9I<R!H87(@9'4@=61E;&%D="!E="`B"B)K<N9V970@9F5L="XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M.`HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X"FUS9VED
M("(B"B)4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF
M:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I
M;B!L871E<BXB"FUS9W-T<B`B(@HB1&5R(&]P<W1O9"!E="!P<F]B;&5M('5N
M9&5R('5D9OAR96QS92!A9B!D96X@86YG:79N92`B"B)A9')E<W-E:V%R=&]T
M96MS9G5N:W1I;VXN(%!R^'8@:6=E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C0P"FUS9VED("(B"B)4:&5R92!W87,@86X@
M97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R
M>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B1&5R(&]P<W1O9"!E;B!F96IL('5N
M9&5R(&]P9&%T97)I;F<@868@:V]N=&%K="UD971A;&IE<FYE+B!0<OAV(&EG
M96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HR,C(@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-0HC.B!L
M:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,C(R"FUS9VED("(B"B)4:&5R92!W
M87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0
M;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R(")$97(@;W!S=&]D(&5N
M(&9E:FP@=6YD97(@;W!D871E<FEN9R!A9B!D:7-T<FEB=71I;VYS;&ES=&5N
M+B!0<OAV(&EG96XN(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,30X(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ
M-#@*;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S
M:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(D1E;FYE($E-05`M<V5R=F5R('5N
M9&5R<W3X='1E<B!I:VME(&1E;&EN9R!A9B!M87!P97(N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HT."!L:6(O2&]R9&4O34E-
M12]6:65W97(O<F%R+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E
M87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`B1&5T=&4@
M='ED97(@:6MK92!PY2!A="!VYG)E(&5T(&=Y;&1I9W0@<F%R+6%R:VEV+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-3(@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E
M<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@
M(D1E;FYE('1Y9&5R(&EK:V4@<.4@870@=N9R92!E;B!G>6QD:6<@>FEP+69I
M;"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(W(&QI8B](;W)D
M92]&;W)M+G!H<#HS,3(W"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@
M8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`B1&5T=&4@='ED97(@
M:6MK92!PY2!A="!VYG)E(&5T(&=Y;&1I9W0@:V]R=&YU;6UE<BXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*;7-G:60@
M(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H
M<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O
M;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*(D1E
M;FYE(&1R:79E<B!T:6QL861E<B!A9G-E;F1E;'-E(&%F(&)E<VME9&5R(&EG
M96YN96T@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2!A
M9&=A;F=S<'5N:W1E="!V960@8G)U9R!A9B!(5%10($%022(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,T(&QI8B].970O4TU3
M+W=I;E]H='1P+G!H<#HQ,S0*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO
M+W=I;G!L8RYC;VTI("(*(F=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*
M;7-G<W1R("(B"B)$96YN92!D<FEV97(@=&EL;&%D97(@869S96YD96QS92!A
M9B!B97-K961E<B!I9V5N;F5M(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*
M(F%D9V%N9W-P=6YK=&5T('9E9"!B<G5G(&%F($A45%`@05!)(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB
M5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G
M:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T
M97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*(D1E;FYE(&1R
M:79E<B!T:6QL861E<B!A9G-E;F1E;'-E(&%F(&)E<VME9&5R(&EG96YN96T@
M<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@861G86YG<W!U
M;FMT970@=F5D(&)R=6<@868@2%144"!!4$DB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-0HC.B!L:6(O3F5T
M+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U"FUS9VED("(B"B)4:&ES
M(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T
M:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O
M(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U
M;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I
M+B(*;7-G<W1R("(B"B)$96YN92!D<FEV97(@=&EL;&%D97(@869S96YD96QS
M92!A9B!B97-K961E<B!V:6$@4TU44"!I9V5N;F5M(%9O9&%F;VYE("(*(DET
M86QI96X@861G86YG<W!U;FMT970L(&1O9R!K=6X@=&EL(%9O9&%F;VYE+6YU
M;7)E+B!$96X@:W+F=F5R(&5N(&4M(@HB;6%I;&MO;G1O(&AO<R!6;V1A9F]N
M92!)=&%L:65N("AH='1P.B\O=W=W+C$Y,"YI="DN(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.3<X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P
M-3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`X-B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,3$U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Q.#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(U-@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,S`U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$S.3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34U-R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Y-3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P-0HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#(Y(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(P-S@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$T.2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(T,#@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U,`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C,W(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X,3`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q.2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,CDW"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,X,#4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@Q,PHC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3<X(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,#4W(&QI8B](;W)D92]&;W)M+G!H<#HQ,#@V"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,3$U(&QI8B](;W)D92]&;W)M+G!H<#HQ,3@R(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,C4V"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S`U(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,SDX(&QI8B](;W)D92]&;W)M+G!H<#HQ-34W"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ.#,Y(&QI8B](;W)D92]&;W)M+G!H<#HQ
M.34X(&QI8B](;W)D92]&;W)M+G!H<#HR,#`U"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR,#(Y(&QI8B](;W)D92]&;W)M+G!H<#HR,#<X(&QI8B](;W)D92]&
M;W)M+G!H<#HR,30Y"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C(Q(&QI8B](
M;W)D92]&;W)M+G!H<#HR-#`X(&QI8B](;W)D92]&;W)M+G!H<#HR-#4P"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR-C,W(&QI8B](;W)D92]&;W)M+G!H<#HR
M.#$P(&QI8B](;W)D92]&;W)M+G!H<#HS,3$Y"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HS,CDW(&QI8B](;W)D92]&;W)M+G!H<#HS.#`U(&QI8B](;W)D92]&
M;W)M+G!H<#HS.#$S"FUS9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(*
M;7-G<W1R(")$971T92!F96QT(&5R(&MRYG9E="XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,#8U(&QI8B](;W)D92]&;W)M+G!H<#HQ,#8U"FUS
M9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM
M<V=S='(@(D1E='1E(&9E;'0@;>4@:W5N(&EN9&5H;VQD92!H96QT86PN(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q-B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C0Q-@IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN
M(&YU;6)E<G,@86YD('1H92!C;VQO;BXB"FUS9W-T<B`B1&5T=&4@9F5L="!M
MY2!K=6X@:6YD96AO;&1E(&YU;7)E(&]G(&MO;&]N+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$P.30@;&EB+TAO<F1E+T9O<FTN<&AP.C$P.30*
M;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU
M97,N(@IM<V=S='(@(D1E='1E(&9E;'0@;>4@:W5N(&EN9&5H;VQD92!O:W1A
M;&4@=N9R9&EE<BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(S
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,3(S"FUS9VED(")4:&ES(&9I96QD(&UU
M<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E
M9V5R<R(*;7-G<W1R("(B"B)$971T92!F96QT('-K86P@=N9R92!E;B!K;VUM
M82T@96QL97(@;65L;&5M<G5M<V%D<VMI;&1T(&QI<W1E(&%F(&AE;'1A;"(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDX.2!L:6(O2&]R9&4O1F]R
M;2YP:'`Z.3@Y"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N
M=6UB97(N(@IM<V=S='(@(D1E='1E(&9E;'0@<VMA;"!VYG)E(&5T(&=Y;&1I
M9W0@;G5M;65R+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3@@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(X,3@*;7-G:60@(B(*(E1H:7,@9FEE;&0@
M;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M
M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T<B`B1&5T=&4@
M9F5L="!S:V%L(&EN9&5H;VQD92!E;B!F87)V96MO9&4@:2!21T(@:&5X+69O
M<FUA="P@9G@@)R,Q,C,T868G+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C4V,2!L:6(O2&]R9&4O1F]R;2YP:'`Z-38Q"FUS9VED(")4:&ES(&9O
M<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@(D1E;FYE
M(&9O<FUU;&%R(&5R(&%L;&5R961E('!R;V-E<W-E<F5T+B(*"B,Z('1E;7!L
M871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M:7,@:7,@)7,N(@IM<V=S='(@(D1E='1E(&5R("5S+B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z-#8Y(&QI8B](;W)D92]+;VQA8BYP:'`Z-#8Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U
M<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE
M960@86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO
M;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I
M;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R("(B"B)$971T
M92!E<B!E="!+;VQA8B!'<F]U<'=A<F4M;V)J96MT+B!&;W(@870@<V4@9&5T
M=&4@;V)J96MT(&AA<B!D=2!B<G5G(&9O<B`B"B)E;B!E+6UA:6PM:VQI96YT
M+"!S;VT@9F]R<W3E<B!+;VQA8B!'<F]U<'=A<F4M9F]R;6%T970N($)E<_AG
M("5S(&9O<B!E;B`B"B)L:7-T92!A9B!K;&EE;G1E<BXB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3D@;&EB+TAO<F1E+TU)344O
M0V]N=&5N=',N<&AP.C4Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE
M<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H
M97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B1&5N;F4@8F5S:V5D(&5R('-K
M<F5V970@;65D(&5T(&%N9&5T('1E9VYSYG0@*"5S*2!E;F0@9&ET(&5G970N
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C8@;&EB+TAO
M<F1E+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@
M8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R(")486QL970@<VMA;"!VYG)E(&UI
M;BX@,2XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP
M:'`Z-#4@;&EB+TAO<F1E+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4
M:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE
M<RXB"FUS9W-T<B`B1&5N;F4@<V5R=F5R(&MA;B!I:VME(&1E:V]M<')I;65R
M92!Z:7`M(&]G(&=Z:7`M9FEL97(N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+U)E9VES=')Y+G!H<#HQ.#D@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HQ
M.#D*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E
M9"XB"FUS9W-T<B`B1&5T=&4@<WES=&5M(&5R(&1E86MT:79E<F5T+B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(T(&QI8B](;W)D92]0
M<F5F<R]522YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N
M=6UB97(N(@IM<V=S='(@(D1E;FYE(';F<F1I('-K86P@=N9R92!E="!T86PN
M(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM<V=I
M9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS
M('=I;F1O=R(*;7-G<W1R(")$971T92!V:6YD=64@<VMA;"!K86QD97,@9G)A
M(&5T(%1I;'9A;&=S=FEN9'5E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E1H=6YD97(B"FUS9W-T<B`B5&]R
M9&5N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S-@IM<V=I9"`B
M5&EC:V5T<R(*;7-G<W1R(")386=E<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(T,C4@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,C4*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")4:6UE(@IM<V=S='(@
M(E1I9"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#@*;7-G:60@
M(E1I;64@5')A8VMI;F<B"FUS9W-T<B`B5&ED<V]P9_AR96QS92(*"B,Z(&QI
M8B]";&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T
M<B`B5&ED<V9O<FUA="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U
M,S$@;&EB+TAO<F1E+T9O<FTN<&AP.C(U,S$*;7-G:60@(E1I;64@<V5L96-T
M:6]N(@IM<V=S='(@(E1I9'-V86QG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,S`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4
M:6UO<BU,97-T92(*;7-G<W1R(")4:6UO<BU,97-T92(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@;&EB+T)L;V-K+VEF<F%M92YP
M:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@(E1I=&5L(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET
M;&4@*'1O;VQT:7`I.B(*;7-G<W1R(")4:71L92`H=&]O;'1I<"DZ(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B
M"FUS9W-T<B`B5&EL(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C8U-`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C4T"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L
M(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@
M:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"B)&;W(@870@=N9L
M9V4@;75L=&EP;&4@:6YD9V%N9V4@<VMA;"!#=')L+2`H4$,I(&5L;&5R($-O
M;6UA;F0@*$UA8RDM=&%S=&5N("(*(FAO;&1E<R!N961E(&UE9&5N<R!D97(@
M:VQI:VME<RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P
M"FUS9VED(")4;V1A>2(*;7-G<W1R("))($1A9R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(
M5$U,(%-O=7)C92(*;7-G<W1R(")3:VEF="!(5$U,+6MI;&1E(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,C,@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`Y"FUS9VED(")4;V=O(@IM<V=S='(@(E1O9V\B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C(V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(R-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3`*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B5&]K96QA=2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#(*;7-G:60@(E1O;6]R<F]W(@IM
M<V=S='(@(DD@;6]R9V5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R.2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,CD@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*
M;7-G<W1R(")4;VYG82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:V]L86(N
M<&AP.C$P-"!L:6(O2&]R9&4O075T:"]K;VQA8BYP:'`Z,3`T"FUS9VED(")4
M;V\@;6%N>2!I;G9A;&ED(&QO9VEN<R!D=7)I;F<@=&AE(&QA<W0@;6EN=71E
M<RXB"FUS9W-T<B`B1F]R(&UA;F=E('5G>6QD:6=E(&QO9VEN9"UF;W)S^&<@
M:2!L^&)E="!A9B!D92!S:61S=&4@;6EN=71T97(N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Q"FUS9VED(")4
M;W`B"FUS9W-T<B`B5&]P(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY,PIM<V=I9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G
M<W1R(")4;W`@9G)A;64@*%]T;W`I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C8S"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`B3W9E<G/F='1E
M;'-E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(R-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,R(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5')I;FED860@86YD(%1O8F%G
M;R(*;7-G<W1R(")4<FEN:61A9"!O9R!4;V)A9V\B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-SDP(&QI8B](;W)D92]&;W)M+G!H<#HQ-SDP"FUS
M9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@(E-A;F0@96QL97(@9F%L<VLB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W
M"FUS9VED(")4=2(*;7-G<W1R(")4:7(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(X(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(R."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@
M(E1U;FES:6$B"FUS9W-T<B`B5'5N97-I96XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Q(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C@*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(S,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G
M:60@(E1U<FME>2(*;7-G<W1R(")4>7)K:65T(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.34*;7-G:60@(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S
M='(@(E1Y<FMI<VL@*$E33RTX.#4Y+3DI(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,C<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED
M(")4=7)K;65N:7-T86XB"FUS9W-T<B`B5'5R:VUE;FES=&%N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,C`@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`X"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T
M<B`B5'5R:W,@;V<@0V%I8V]S(-AE<FYE(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,S,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED
M(")4=79A;'4B"FUS9W-T<B`B5'5V86QU(@H*(SH@9G)A;65W;W)K+T-,22]#
M3$DN<&AP.C(V-"!L:6(O2&]R9&4O0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@
M>6]U<B!C:&]I8V4Z("(*;7-G<W1R(")3:W)I=B!D:70@=F%L9SH@(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U.`IM<V=I9"`B52Y6+B!I
M;F1E>#H@(@IM<V=S='(@(E4N5BXM:6YD96MS.B`B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP
M.C$W"FUS9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4T,0IM<V=I9"`B55),(&9O<B!Y;W5R
M('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S='(@(E523"!F
M;W(@<VMR:7!T('1I;"!M;V1T86=E;'-E(&%F('-T871U<R!R87!P;W)T96XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW
M"FUS9VED(")54DPZ(@IM<V=S='(@(E523#HB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(S-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G
M:60@(E5G86YD82(*;7-G<W1R(")59V%N9&$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,V(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(S-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G
M:60@(E5K<F%I;F4B"FUS9W-T<B`B56MR86EN92(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C0Q.2!L:6(O5D93+V9I;&4N<&AP.C0Q.0IM<V=I
M9"`B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")+
M=6YN92!I:VME('1I;&?E(%9&4RUK871A;&]G+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O4VEG;G5P+G!H<#HY-B!L:6(O2&]R9&4O075T:"]3:6=N=7`N
M<&AP.CDV"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M
M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R(")+86X@:6MK92!T:6QF
M^&IE(&5K<W1R82!B<G5G97(@:6YF;W)M871I;VX@=6YD97(@;W!S:W)I=FYI
M;F<N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS.3,@;&EB+U9&
M4R]F='`N<&AP.C,Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T
M<B`B2V%N(&EK:V4@YFYD<F4@=&EL;&%D96QS97(@9F]R(%9&4RUF:6P@7"(E
M<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,Y,B!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#8X"B,Z(&QI8B]61E,O9FEL92YP
M:'`Z,SDR(&QI8B]61E,O;75S<6PN<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE
M("5S+R5S+B(*;7-G<W1R(")+86X@:6MK92#F;F1R92!T:6QL861E;'-E<B!F
M;W(@5D93+69I;"`E<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C<X-B!L:6(O5D93+V9T<"YP:'`Z-S@V"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@(DMA;B!I:VME
M('-K:69T92!T:6P@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HR,S<@;&EB+U9&4R]F='`N<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7-<(BXB"FUS9W-T
M<B`B2V%N(&EK:V4@=&IE:VME(&9I;'-T^')R96QS96X@868@7"(E<UPB+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8Y-2!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C$P,C@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C@U,"!L:6(O5D93+V9I;&4N<&AP.C8Y-0HC.B!L:6(O5D93
M+W-Q;"YP:'`Z,3`R."!L:6(O5D93+W-Q;%]F:6QE+G!H<#HX-3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<
M(B5S+R5S7"(N(@IM<V=S='(@(DMA;B!I:VME('1J96MK92!F:6QS=/AR<F5L
M<V5N(&%F(%PB)7,O)7-<(BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q
M;"YP:'`Z-#,Y(&QI8B](;W)D92]!=71H+W-Q;"YP:'`Z-#,Y"FUS9VED(")5
M;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+B(*;7-G<W1R(")+=6YN
M92!I:VME(&;E(&9O<F)I;F1E;'-E('1I;"!344P@<V5R=F5R96XN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-S`@;&EB+U9&4R]F='`N<&AP
M.C@W,`IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S
M='(@(DMA;B!I:VME(&;E(&9O<F)I;F1E;'-E(&UE9"!34TPN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C,R(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C(S-PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,C`T(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#D*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(Q-R!L:6(O5D93+V9I
M;&4N<&AP.C(S,@HC.B!L:6(O5D93+V9I;&4N<&AP.C(S-R!L:6(O5D93+W-Q
M;%]F:6QE+G!H<#HR,#0@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y"B,Z(&QI
M8B]61E,O<W%L7V9I;&4N<&AP.C(Q-PIM<V=I9"`B56YA8FQE('1O(&-O<'D@
M5D93(&9I;&4N(@IM<V=S='(@(DMA;B!I:VME(&MO<&EE<F4@5D93+69I;"XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,W,"!L:6(O5D93+V9T
M<"YP:'`Z,S<P"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A
M=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DMA;B!I:VME(&1A
M;FYE(%9&4RUK871A;&]G(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HS-C$@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(U
M.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C8T(&QI8B]6
M1E,O9FEL92YP:'`Z,S8Q"B,Z(&QI8B]61E,O;75S<6PN<&AP.C(U."!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HR-C0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@
M5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B2V%N(&EK:V4@9&%N;F4@5D93+6MA
M=&%L;V<N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$R-"!L
M:6(O5D93+VUU<W%L+G!H<#HQ,C0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@
M5D93(&9I;&4N(@IM<V=S='(@(DMA;B!I:VME(&QA=F4@5D93+69I;"XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Y,"!L:6(O5D93+W-M8BYP
M:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@
M5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(DMA;B!I:VME(&]P<F5T=&4@
M5D93+6UA<'!E(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HR-S(@;&EB+U9&4R]F:6QE+G!H<#HR-S(*;7-G:60@(E5N86)L92!T
M;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@(DMA;B!I:VME(&QA
M=F4@=&]M(%9&4RUF:6PN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+V=Z:7`N<&AP.C<Y"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]T87(N<&AP.C<V(&QI8B](;W)D92]#;VUP<F5S<R]G>FEP+G!H<#HW.0HC
M.B!L:6(O2&]R9&4O0V]M<')E<W,O=&%R+G!H<#HW-@IM<V=I9"`B56YA8FQE
M('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B2V%N(&EK:V4@9&5K;VUP
M<FEM97)E(&1A=&$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS
M,#,@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,C@*(SH@;&EB+U9&4R]F
M='`N<&AP.C,P,R!L:6(O5D93+W-M8BYP:'`Z,C(X"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y
M(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B2V%N(&EK:V4@<VQE='1E(%PB)7-<
M(CL@:V%T86QO9V5T(&5R(&EK:V4@=&]M="XB"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C<X(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R
M(")+86X@:6MK92!S;&5T=&4@7"(E<UPB.B`E<RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HS,S@@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C,Q,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,Y-2!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0R"B,Z(&QI8B]61E,O9FEL
M92YP:'`Z,S,X(&QI8B]61E,O;75S<6PN<&AP.C,Q,2!L:6(O5D93+W-Q;"YP
M:'`Z,SDU"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,T,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y
M(&ES(&YO="!E;7!T>2(*;7-G<W1R(")+86X@:6MK92!S;&5T=&4@)7,[(&MA
M=&%L;V=E="!E<B!I:VME('1O;70B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,S4V(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HS-C`*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S4V(&QI8B]61E,O<W%L
M7V9I;&4N<&AP.C,V,`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER
M96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R(")+86X@:6MK92!S;&5T=&4@
M5D93+6MA=&%L;V=E="!R96MU<G-I=G0N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,S0T(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS
M,C(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,S-2!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S0S"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HS-3(@;&EB+U9&4R]F:6QE+G!H<#HS-#0*(SH@;&EB
M+U9&4R]M=7-Q;"YP:'`Z,S(R(&QI8B]61E,O;75S<6PN<&AP.C,S-2!L:6(O
M5D93+VUU<W%L+G!H<#HS-#,*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S4R
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(DMA;B!I:VME('-L971T92!61E,M:V%T86QO9RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C0R,"!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C0S,@HC.B!L:6(O5D93+W-Q;"YP:'`Z-#(P(&QI8B]61E,O<W%L+G!H
M<#HT,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B2V%N(&EK:V4@<VQE='1E(%9&
M4RUK871A;&]G.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C(Q,B!L:6(O5D93+V9T<"YP:'`Z,C$R"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")+
M86X@:6MK92!S;&5T=&4@5D93+69I;"!<(B5S7"(N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,S$P(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HQ-C<*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X,"!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@W"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,CDQ(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HS.3$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,Y
M.2!L:6(O5D93+V9I;&4N<&AP.C,Q,`HC.B!L:6(O5D93+VUU<W%L+G!H<#HQ
M-C<@;&EB+U9&4R]M=7-Q;"YP:'`Z,3@P(&QI8B]61E,O;75S<6PN<&AP.C$X
M-PHC.B!L:6(O5D93+W-Q;"YP:'`Z,CDQ(&QI8B]61E,O<W%L7V9I;&4N<&AP
M.C,Y,2!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS.3D*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S='(@(DMA;B!I:VME('-L971T92!6
M1E,M9FEL+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C0X(&QI
M8B]61E,O<VUB+G!H<#HR-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EK
M:V4@<VQE='1E(%9&4RUM87!P92!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HT,#D@;&EB+U9&4R]S<6PN<&AP.C0P.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L
M>3H@)7,N(@IM<V=S='(@(DMA;B!I:VME('-L971T92!61E,@<F5K=7)S:79T
M.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S-"!L:6(O
M5D93+V9T<"YP:'`Z.#,T"FUS9VED(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U
M<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R(")+86X@:6MK92!B97-T96UM92!A
M:W1U96QT(&MA=&%L;V<N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV,#0@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,#0*;7-G
M:60@(E5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS
M9W-T<B`B2V%N(&EK:V4@=61D<F%G92!C97)T:69I:V%T+61E=&%L:F5R(@H*
M(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`N<&AP.C0S-R!F<F%M97=O<FLO
M3F5T7TE-4U`O24U34"]!=71H+G!H<#HQ,C,*(SH@;&EB+TYE="])35-0+G!H
M<#HT,S<@;&EB+TYE="])35-0+T%U=&@N<&AP.C$R,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB
M"FUS9W-T<B`B2V%N(&EK:V4@:6YD;.9S92!D969I;FET:6]N96X@868@)7,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C`S(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(P.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,3<T(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ-SD*(SH@;&EB+U9&4R]F:6QE+G!H<#HR,#,@;&EB+U9&4R]F:6QE+G!H
M<#HR,#@@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3<T"B,Z(&QI8B]61E,O<W%L
M7V9I;&4N<&AP.C$W.0IM<V=I9"`B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N
M(@IM<V=S='(@(DMA;B!I:VME(&9L>71T92!61E,M9FEL+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z.3@@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HY,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C$P-B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C8U,@HC.B!L:6(O5D93+V9T<"YP:'`Z
M.3@@;&EB+U9&4R]S;6(N<&AP.CDS(&QI8B]61E,O<VUB+G!H<#HQ,#8*(SH@
M;&EB+U9&4R]S;6(N<&AP.C8U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DMA;B!I:VME
M(.5B;F4@5D93+69I;"!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,C@T(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ
M,S@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$T,2!L:6(O
M5D93+V9I;&4N<&AP.C(X-`HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ,S@@
M;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,30Q"FUS9VED(")5;F%B;&4@=&\@;W!E
M;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B2V%N(&EK:V4@Y6)N
M92!61E,M9FEL('1I;"!S:W)I=FYI;F<N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z.#,@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3,W
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW-B!L:6(O5D93
M+V9I;&4N<&AP.C@S(&QI8B]61E,O9FEL92YP:'`Z,3,W"B,Z(&QI8B]61E,O
M<W%L7V9I;&4N<&AP.C<V"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL
M92XB"FUS9W-T<B`B2V%N(&EK:V4@Y6)N92!61E,M9FEL+B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W1G>BYP:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O
M;7!R97-S960@87)C:&EV92XB"FUS9W-T<B`B2V%N(&EK:V4@Y6)N92!K;VUP
M<FEM97)E="!A<FMI=BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#4V
M(&QI8B]61E,N<&AP.C@U-@IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I
M;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B2V%N(&EK:V4@;.9S
M92!61E,M9FEL("AF:6QE<VEZ92@I(&9E:FQE9&4I+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HX.#<@;&EB+U9&4RYP:'`Z.#@W"FUS9VED(")5;F%B
M;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+B(*
M;7-G<W1R(")+86X@:6MK92!LYG-E(%9&4RUF:6P@*&=E=$9I;&53:7IE*"D@
M9F5J;&5D92DN(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I
M;VY(86YD;&5R+VYO;F4N<&AP.C,X"B,Z(&QI8B](;W)D92]397-S:6]N2&%N
M9&QE<B]N;VYE+G!H<#HS.`IM<V=I9"`B56YA8FQE('1O(')E860@9FEL93H@
M(@IM<V=S='(@(DMA;B!I:VME(&SF<V4@9FEL.B`B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HV-S8@;&EB+U9&4R]F:6QE+G!H<#HV-S8*;7-G
M:60@(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS
M9W-T<B`B2V%N(&EK:V4@;.9S92!V9G-R;V]T+6MA=&%L;V=E="XB"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q,#D@;&EB+TAO<F1E+TMO;&%B
M+G!H<#HQ,3`Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T
M<R(*;7-G<W1R(")+86X@:6MK92!O;63X8F4@)7,@=&EL("5S.B!MY6QM87!P
M96X@9FEN9&5S(&%L;&5R961E(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C,P,2!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS,#$*;7-G:60@
M(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B2V%N
M(&EK:V4@;VUD^&)E(%9&4RUK871A;&]G+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z,S,R(&QI8B]61E,O<W%L+G!H<#HS,S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E
M<RXB"FUS9W-T<B`B2V%N(&EK:V4@;VUD^&)E(%9&4RUK871A;&]G.B`E<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,T."!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C(W,0HC.B!L:6(O5D93+V9T<"YP:'`Z,S0X(&QI
M8B]61E,O<VUB+G!H<#HR-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(')E;F%M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DMA;B!I:VME
M(&]M9/AB92!61E,M9FEL(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HV,3<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(R
M.0HC.B!L:6(O5D93+V9I;&4N<&AP.C8Q-R!L:6(O5D93+VUU<W%L+G!H<#HR
M,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@
M9FEL92`E<R\E<RXB"FUS9W-T<B`B2V%N(&EK:V4@;VUD^&)E(%9&4RUF:6P@
M)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(Q,R!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#4R"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,S(V(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HR.3,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,P
M.2!L:6(O5D93+VUU<W%L+G!H<#HR,3,*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z
M-#4R(&QI8B]61E,O<W%L+G!H<#HS,C8@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z
M,CDS"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,P.0IM<V=I9"`B56YA8FQE
M('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T<B`B2V%N(&EK:V4@;VUD^&)E
M(%9&4RUF:6PN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+VUK:7-O9G,N<&AP.C4P"B,Z(&QI8B]61E,O25-/5W)I=&5R+VUK:7-O
M9G,N<&AP.C4P"FUS9VED(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS
M9W-T<B`B2V%N(&EK:V4@869V:6ML92`G;6MI<V]F<R<N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O
M('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`B2W5N;F4@
M:6MK92!O=F5R<^9T=&4@9&5T=&4@5V]R9"!D;VMU;65N="(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,34T(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z,34W"B,Z(&QI8B]61E,O9G1P+G!H<#HQ-30@;&EB+U9&4R]F='`N
M<&AP.C$U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")+86X@:6MK92!S:W)I=F4@5D93
M+69I;"!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,3@V(&QI8B]61E,O9FEL92YP:'`Z,3@V"FUS9VED(")5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R(")+86X@:6MK
M92!S:W)I=F4@5D93+69I;"`H8V]P>2@I(&9E:FQE9&4I+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C(X."!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,30V"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HQ-3$@;&EB+U9&4R]F:6QE+G!H<#HR.#@*(SH@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z,30V(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$U,0IM<V=I9"`B
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@(DMA;B!I
M:VME('-K<FEV92!61E,M9FEL9&%T82XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z.#8R(&QI8B]61E,N<&AP.C@V,@IM<V=I9"`B56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(*;7-G<W1R
M(")+86X@:6MK92!S:W)I=F4@5D93+69I;#L@:W9O=&5N('9I;"!B;&EV92!O
M=F5R<VMR961E="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`B56YD97)L
M:6YI97)E="(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@
M(E5N9&\@0VAA;F=E<R(*;7-G<W1R(")&;W)T<GED(.9N9')I;F=E<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G
M:60@(E5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(D]M9_AR(&1I
M;B!S:61S=&4@:&%N9&QI;F<B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HR,C$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S@X(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HR,C$*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.`IM
M<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN
M96-T:6]N.B`B"FUS9W-T<B`B579E;G1E="!R96%K=&EO;B!F<F$@<V5R=F5R
M('#E(&9O<F)I;F1E;'-E;CH@(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,C$W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,S.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS-S8*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S@R(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR
M,3<*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,S.2!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<V"B,Z(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS.#(*;7-G:60@(E5N97AP96-T960@<F5S
M<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R(")5=F5N=&5T(')E86MT
M:6]N(&9R82!S97)V97(@<.4Z("(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]#871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z(&QI8B](;W)D92]0<F5F<R]#
M871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C8Q"FUS9VED(")5;F9I;&5D(@IM<V=S='(@
M(DEK:V4@86YB<F%G="(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS
M9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T<B`B56YI8V]D92`H551&+3@I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S
M-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-38*;7-G:60@(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S
M='(@(D9O<F5N961E($%R86)I<VME($5M:7)A=&5R(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,X
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(S."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM
M<V=I9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T<B`B4W1O<F)R:71T86YI96XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,S8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,"!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B
M55-!(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,SD@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R
M($]U=&QY:6YG($ES;&%N9',B"FUS9W-T<B`B55-!<R!U;F1E<F]R9&YE9&4@
M^&5R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HW."!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-C(*;7-G:60@(E5N:71S(@IM<V=S='(@(D5N:&5D
M97(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C4X
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R.0HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,S`@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W1G>BYP:'`Z-3@*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(Y
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0S,`IM<V=I9"`B56YK;F]W;B(*
M;7-G<W1R(")5:V5N9'0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3@*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%022!-
M97-S86=E($E$*2XB"FUS9W-T<B`B56ME;F1T(&%P:6US9VED("A!4$D@365S
M<V%G92!)1"DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDY"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDY"FUS9VED(")5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S
M<V%G92!)1"DN(@IM<V=S='(@(E5K96YD="!C;&EM<V=I9"`H0VQI96YT($UE
M<W-A9V4@240I+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-#<*;7-G:60@(E5N:VYO=VX@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@
M(E5K96YD="!S=&5D(&%N9VEV970N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S97)N86UE
M(&]R('!A<W-W;W)D+B(*;7-G<W1R(")5:V5N9'0@8G)U9V5R;F%V;B!E;&QE
M<B!K;V1E;W)D+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT
M(&5L96UE;G0B"FUS9W-T<B`B2.9G="!A:W1U96QT(&5L96UE;G0@868N(@H*
M(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS,#(@;&EB+TAO
M<F1E+TED96YT:71Y+G!H<#HS,#(*;7-G:60@(E5N;F%M960B"FUS9W-T<B`B
M26MK92!N879N9VEV970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R:7!T
M<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL
M>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A
M('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S
M('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP
M8F]A<F0N(@IM<V=S='(@(B(*(E5P<FEV:6QI9V5R961E('-K<FEP=&5R(&MA
M;B!I:VME('1I;&?E(&ML:7!P92]K;W!I+VEN9'/F="!P<F]G<F%M;>9S<VEG
M="!A9B`B"B)S:6MK97)H961SY7)S86=E<BX@($ML:6L@3TL@9F]R(&%T('-E
M(&5N('1E:VYI<VL@;F]T92!H;W,@;6]Z:6QL82YO<F<L('-O;2`B"B)V:7-E
M<B!D:6<L(&AV;W)D86X@9'4@:V%N('1I;&QA9&4@970@<VMR:7!T(&%T('1I
M;&?E('5D:VQI<'-H;VQD97)E;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C;VQO
M<B(*;7-G<W1R(")&87)V92!I:VME(&EN9'-T:6QL970B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X-R!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.CDR-PHC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.CDS,R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8X-PHC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.CDR-R!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.CDS,PIM<V=I9"`B56YS=7!P;W)T960@17AT96YS:6]N
M(@IM<V=S='(@(E5D=FED9&5L<V4@:6MK92!U;F1E<G-T^'1T970B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$Y-R!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C$Y-PHC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN
M8SHS,PIM<V=I9"`B57!D871E(@IM<V=S='(@(D]P9&%TZ7(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C(Y"B,L('!H<"UF;W)M870*
M;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R(")/<&1A=.ER("5S(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-@IM<V=I9"`B57!D871E
M('5S97(B"FUS9W-T<B`B3W!D873I<B!B<G5G97(B"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C$T-"!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC97,O
M<VAA<F5S+V5D:70N<&AP.C(S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A
M=&5D(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB(&]P9&%T97)E="XB"@HC.B!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX,PIM<V=I9"`B57!G<F%D92!S8W)I
M<'0@9&5L971E9"XB"FUS9W-T<B`B3W!G<F%D97)I;F=S+69O<F5S:W)I9G0@
M<VQE='1E="XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ.3@*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y.`IM<V=I9"`B57!L;V%D
M(@IM<V=S='(@(E5P;&]A9"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M.#8*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE
M<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R(")/<'/F=&YI;F=S9FEL97(@=&EL
M(&%L;&4@87!P;&EK871I;VYE<B!L86=T(&]P('#E('-E<G9E<BXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS
M.C(P"FUS9VED(")5<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@(E-T;W)E
M(&QA=&EN<VME(&)O9W-T879E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O
M;6%N(&YU;6)E<G,B"FUS9W-T<B`B4W1O<F4@<F]M97)T86PB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S@*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(T,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B57)U9W5A>2(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,Z
M(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L('!H
M<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R(")!;G9E
M;F0@;G5VYG)E;F1E.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B0G)U9R!3
M4TPB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(W"FUS9VED(")5<V4@
M:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R
M+B(*;7-G<W1R(")"<G5G(&AV:7,@;F%V;B]K;V1E;W)D(&5R(&9O<G-K96QL
M:6<@9F]R($E-4U`M<V5R=F5R+B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O961I="YI;F,Z,C$*;7-G:60@(E5S97(B"FUS9W-T<B`B0G)U9V5R(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HW-S0@;&EB
M+TAO<F1E+U)E9VES=')Y+G!H<#HW-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(D)R
M=6=E<B`E<R!I:VME(&)E;7EN9&EG970@=&EL("5S+B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R
M(")"<G5G97(M861M:6YI<W1R871I;VXB"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C(T-2!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C(T-0IM
M<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(D)R=6=E<FEN9'-T:6QL:6YG
M97(B"@HC.B!S:6=N=7`N<&AP.C8R"FUS9VED(")5<V5R(%)E9VES=')A=&EO
M;B(*;7-G<W1R(")"<G5G97(M<F5G:7-T<F5R:6YG(@H*(SH@<VEG;G5P+G!H
M<#HR,@IM<V=I9"`B57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L
M960@9F]R('1H:7,@<VET92XB"FUS9W-T<B`B0G)U9V5R+7)E9VES=')E<FEN
M9R!E<B!B;&5V970@<VSE970@9G)A('#E(&1E='1E('=E8G-T960N(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0Y-`IM<V=I9"`B57-E<B!A8V-O=6YT
M(&YO="!F;W5N9"(*;7-G<W1R(")"<G5G97)K;VYT;R!I:VME(&9U;F1E="(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M-SD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,3DX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3,V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET
M86QY7W-M='`N<&AP.CDX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,34P(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M,S8*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HY."!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.`HC.B!L:6(O3F5T
M+U--4R]W:6Y?:'1T<"YP:'`Z,34P('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C,S"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S(@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE
M(@IM<V=S='(@(D)R=6=E<FYA=FXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,3(T(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,3(T
M"B,L('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A;')E861Y
M(&5X:7-T<RXB"FUS9W-T<B`B0G)U9V5R;F%V;B!<(B5S7"(@9FEN9&5S(&%L
M;&5R961E+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PIM
M<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(D)R=6=E<FYA=FXZ(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z("(*
M;7-G<W1R(")"<G5G97)N879N.B`B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]L:7-T+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G
M<W1R(")"<G5G97)E(&D@<WES=&5M970Z(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR-#(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED
M(")5>F)E:VES=&%N(@IM<V=S='(@(E5S8F5K:7-T86XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HQ-S`@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C8R"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3<P(&QI8B]61E,O9FEL
M92YP:'`Z,C8R"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T
M+B(*;7-G<W1R(")61E,M:V%T86QO9R!E:W-I<W1E<F5R(&EK:V4N(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$R,`IM<V=I9"`B5F%C871I;VXB
M"FUS9W-T<B`B1F5R:64B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX
M-C8@;&EB+TAO<F1E+T9O<FTN<&AP.C@V-@IM<V=I9"`B5F%L:60@;&]C871I
M;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R(")'>6QD:6=E(&9U;F1E="!S
M=&5D97(@:6YK;'5D97)E<CHB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8S.2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8S.0IM
M<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B1WEL9&EG:&5D(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.3<@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*;7-G:60@(E9A;'5E(&EN(&UI
M;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(E;F<F1I(&5R(&UI;G5T=&5R(&9R
M82!N=2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-38@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3$W-PHC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M.#4V(&QI8B](;W)D92]&;W)M+G!H<#HQ,3<W"B,L('!H<"UF;W)M870*;7-G
M:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*
M;7-G<W1R(")6YG)D:2!E<B!M97)E(&5N9"!D96X@;6%K<VEM86QE(&SF;F=D
M92!A9B`E<RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0T(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C8*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C,Q-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3$P"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3D@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(R-#0*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R
M-C8@;&EB+TAO<F1E+T9O<FTN<&AP.C(S,38@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(Y,3`*(SH@;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3D*
M;7-G:60@(E9A;'5E<R(*;7-G<W1R(")6YG)D:65R(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C$P.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,3@V"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,3`Y(&QI8B](;W)D92]&;W)M
M+G!H<#HR,3@V"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T
M<B`B5N9R9&EE<BP@9&5R(&MA;B!VYFQG97,@:6)L86YD="(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C0Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R(")686YU871U(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,PIM<V=I9"`B5F%R:6%B;&4B
M"FUS9W-T<B`B4VMI9G1E;F1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-#4@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")696YE
M>G5E;&$B"FUS9W-T<B`B5F5N97IU96QA(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HR,3@@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A
M9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R(")%9G1E
M<G!R^'9N:6YG(&9E:FQE9&4@+2!D97(@97(@8FQE=F5T('!I;&QE="!V960@
M9&5N;F4@8F5S:V5D+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-S`Q(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`Q"FUS9VED
M(")697)S:6]N(@IM<V=S='(@(E9E<G-I;VXB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C(X"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T
M<B`B5F5R<VEO;G-K;VYT<F]L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI
M9VXB"FUS9W-T<B`B3&]D<F5T(&]P<W1I;&QI;F<B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T"FUS9VED(")697)T:6-A
M;"!P861D:6YG(@IM<V=S='(@(DQO9')E="!F;W)R:6YG(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R
M=&EC86PZ(@IM<V=S='(@(DQO9')E=#HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HW,@IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S
M='(@(DUE9V5T(&CX:B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#@@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(T,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0X
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FEE="!.86TB
M"FUS9W-T<B`B5FEE=&YA;2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DW
M"FUS9VED(")6:65T;F%M97-E("A625-#24DI(@IM<V=S='(@(E9I971N86UE
M<VES:R`H5DE30TE)*2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.CDW,2!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.3<Q"B,L
M('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B5FES("5S(@H*
M(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E
M<FYA;"!W96(@<&%G92(*;7-G<W1R(")392!PY2!E:W-T97)N('=E8G-I9&4B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S`@;&EB
M+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@S,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")6:65W(&%S("5S(@IM<V=S='(@(E9I<R!S;VT@)7,B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(T-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM<V=S='(@
M(DIO;69R=?AE<BP@0G)I=&ES:V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0W(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(T-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I
M<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@(DIO;69R=?AE<BP@06UE<FEK
M86YS:V4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-@IM<V=I9"`B5FES
M:6)I;&ET>2(*;7-G<W1R(")3>6YL:6=H960B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C4R"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T
M<B`B4WEN;&EG:&5D.B`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D
M869O;F5I=&%L>5]S;71P+G!H<#HX-`HC.B!L:6(O3F5T+U--4R]V;V1A9F]N
M96ET86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L>2!V:6$@
M4TU44"(*;7-G<W1R(")6;V1A9F]N92!)=&%L:65N('9I82!33510(@H*(SH@
M9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O
M;6]B:6QE+G!H<#HS-@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T<B`B5T%23B(*
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L('!H<"UF;W)M870*
M;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-
M("5S+B(*;7-G<W1R(")!1%9!4E-%3"$A(2!&2D523B!30U))4%0@34%.545,
M5"!&4D$@)7,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HQ,S,@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$S,PIM<V=I9"`B
M5TE.('9I82!(5%10(@IM<V=S='(@(E=)3B!V:6$@2%144"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C4P(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q-PIM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T<B`B5V%L;&ES
M(&]G($9U='5N82(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:'1M;"YP:'`Z,3(W"B,Z(&QI8B](;W)D92].;W1I
M9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O:'1M;"YP:'`Z,3(W(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HY-0IM<V=I9"`B5V%R;FEN9R(*;7-G<W1R(")!9'9A<G-E;"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@
M(E=E(@IM<V=S='(@(D]N<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R(")696IR
M=61S:6=T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q-@IM
M<V=I9"`B5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(E9E:G)I
M;F9O<FUA=&EO;B!S=&EL;&5T('1I;'+E9&EG:&5D(&%F(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.#DR(&QI8B](;W)D92]&;W)M+G!H<#HX.3(*
M;7-G:60@(E=E871H97(N8V]M(@IM<V=S='(@(E=E871H97(N8V]M(@H*(SH@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R(")7
M96(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Y"FUS9VED(")7
M96(@4VET92(*;7-G<W1R(")796)S:71E(@H*(SH@9G)A;65W;W)K+TUA:6YT
M96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU."!L:6(O2&]R9&4O36%I;G1E;F%N
M8V4N<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`B56=E;G1L:6<B"@HC
M.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`IM<V=I9"`B5V5L8V]M
M92(*;7-G<W1R(")696QK;VUM96XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C4W('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R(")696QK;VUM
M96X@=&EL("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@
M=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G
M:60@(E=E;&-O;64L("5S(@IM<V=S='(@(E9E;&MO;6UE;BP@)7,B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y.`IM<V=I9"`B5V5S=&5R;B`H25-/+3@X
M-3DM,2DB"FUS9W-T<B`B5F5S=&QI9R`H25-/+3@X-3DM,2DB"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y.0IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM
M,34I(@IM<V=S='(@(E9E<W1L:6<@*$E33RTX.#4Y+3$U*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C<X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C<X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q
M"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R(")697-T<V%H87)A(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R
M(&QO9VEN/R(*;7-G<W1R(")(=FEL:V5N(&%P<&QI:V%T:6]N('-K86P@)7,@
M=FES92!E9G1E<B!L;V=I;F0_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z,30*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T
M97(_(@IM<V=S='(@(DAV860@97(@<V5P87)A=&]R=&5G;F5T/R(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T(&ES('1H
M92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(DAV860@97(@8VET871I;VYS
M=&5G;F5T/R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,#8U"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,#8U"FUS9VED(")7:&5R96ES($%U<W1R86QI82!M87`B"FUS9W-T<B`B
M5VAE<F5I<R!!=7-T<F%L:65N+6MO<G0B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E<R(*;7-G<W1R(")(=FEL:V4@9F%S
M97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,V"FUS9VED(")7:&EC
M:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N
M(@IM<V=S='(@(DAV:6QK92!P;'5G:6YS('-K86P@86MT:79E<F5S(&9O<B!2
M:6-H(%1E>'0M=N9R:W3X:F5T+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@(E=I9'1H(@IM<V=S
M='(@(D)R961D92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,#<@
M;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#<*;7-G:60@(E=I9'1H(&EN($-34R!U
M;FET<R(*;7-G<W1R(")"<F5D9&4@:2!#4U,M96YH961E<B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED
M=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O
M;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@(D)R961D92!A9B`E<RUM96YU96X@
M=&EL('9E;G-T<F4@*&)L:79E<B!A:W1I=F5R970@=F5D(&[F<W1E(&QO9VEN
M9"DZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*;7-G<W1R(")"<F5D
M9&4@868@=&%B96QL96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q,`IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R(")"
M<F5D9&4M96YH960B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P-0IM<V=I9"`B5VED=&@Z(@IM<V=S='(@(D)R961D93HB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$U"FUS9VED(")7:6MI
M(@IM<V=S='(@(E=I:VDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C@Y(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W
M"FUS9VED(")7:6YD(@IM<V=S='(@(E9I;F0B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B5VEN9"!%87)L>2(*
M;7-G<W1R(")";.9S="!T:61L:6=T(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HX-PIM<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R(")6:6YD
M:&%S=&EG:&5D(&D@:VYO8B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,38S
M"FUS9VED(")7:6YD.B(*;7-G<W1R(")6:6YD.B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,S$*;7-G:60@(E=I;F0Z("(*;7-G<W1R(")6
M:6YD.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@(E=I
M<V1O;2(*;7-G<W1R(")6:7-D;VTB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,3DX"FUS9VED(")7:7-H;&ES="(*;7-G<W1R("+8;G-K96QI<W1E
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K(@IM
M<V=S='(@(D%R8F5J9&4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ-C0*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ,C0@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*
M;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R(")!9')E<W-E("AA<F)E:F1E
M*2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M.3(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G
M:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`B5&5L969O;B`H87)B96ID92DB"@HC
M.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ.3,@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z,CDT"B,Z(&QI8B]&:6QE+T-35BYP:'`Z,3DS(&QI
M8B]&:6QE+T-35BYP:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG
M(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O
M=6YD("5D+B(*;7-G<W1R(")&;W)K97)T(&%N=&%L(&9E;'1E<B!I(&QI;FEE
M("5D+B!&;W)V96YT961E("5D+"!F86YD="`E9"XB"@HC.B!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HS,S(@;&EB+T9I;&4O0U-6+G!H<#HS,S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP
M96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R(")&;W)K97)T(&%N=&%L(&9E
M;'1E<BX@1F]R=F5N=&5D92`E9"P@9F%N9'0@)60N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,3(Q(&QI8B]61E,O9FEL92YP:'`Z,3(Q"B,L
M('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D
M:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@(D9O<FME<G0@9F]R<VMY9&YI;F<@
M)60@=6YD97(@:6YD;.9S;FEN9R!A9B!E;B!61E,M9FEL+B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR-#4*;7-G:60@(E@M4F5F(@IM<V=S='(@
M(E@M4F5F(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.30@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV
M,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R(")8-3`Y=C,@0F%S:6,@0V]N
M<W1R86EN=',B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4Y,R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P
M.78S($5X=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R(")8-3`Y=C,@17AT96YD
M960@2V5Y(%5S86=E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.34@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@
M(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B6#4P
M.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M92(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3DV(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3DV"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE
M<B(*;7-G<W1R(")8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@S(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-C@S"FUS9VED(")8-3`Y=C,@97AT96YS:6]N
M<R(*;7-G<W1R(")8-3`Y=C,@=61V:61D96QS97(B"@HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T<B`BQ<4B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$T"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-38*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-"!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#4V"FUS9VED(")965E9(@IM<V=S='(@(L7%
MQ<4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3$Q,0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$Q
M,0IM<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R(")986AO;R$M:V]R="(*"B,Z
M(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-38@;&EB
M+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S
M='(@(L5R;&EG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3(@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")996UE;B(*;7-G<W1R
M(")996UE;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HY-C8*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.CDV-@IM<V=I9"`B665S(@IM<V=S='(@(DIA(@H*(SH@=&5M<&QA=&5S+VUA
M:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!
M9W)E92(*;7-G<W1R(")*82P@:F5G(&5R(&5N:6<B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R"FUS9VED(")9;W4@87)E
M(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H
M(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`B(@HB1'4@8F5F:6YD97(@9&EG
M(&D@5$5+4U0@34]$55,N("!"<G5G(%L\/ETM:VYA<'!E;B!T:6P@870@<VMI
M9G1E('1I;&)A9V4@=&EL("(*(E=94TE764<N(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HR,S8*(SH@;&EB+TAO<F1E
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HR,S8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N
M("5D(&)L;V-K<RXB"FUS9W-T<B`B1'4@:&%R(&EK:V4@=&EL;&%D96QS92!T
M:6P@870@;W!R971T92!M97)E(&5N9"`E9"!B;&]K:V4N(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#(T(&QI8B](;W)D92YP:'`Z,30R-`IM
M<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC871E9"XB"FUS9W-T<B`B1'4@
M97(@:6MK92#F9W1E="XB"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I
M='DN<&AP.C,P."!L:6(O2&]R9&4O261E;G1I='DN<&AP.C,P.`IM<V=I9"`B
M66]U(&-A;FYO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U
M;&P@;F%M92XB"FUS9W-T<B`B1'4@:V%N(&EK:V4@:&%V92`G7%PG+71E9VYE
M="!I(&1I="!F=6QD92!N879N+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$X-34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW-0HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3@U-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DW-0IM
M<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S
M+B(*;7-G<W1R(")$=2!I;F1T87-T961E(&EK:V4@96X@9WEL9&EG(&4M<&]S
M="UA9')E<W-E+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(Y,"!L
M:6(O2&]R9&4O1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@
M9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM
M<V=S='(@(B(*(D9O<B!A="!I;7!O<G1E<F4@<VMA;"!D=2!T:6QO<F1N92!F
M96QT97(@9G)A(&1E;B!F:6P@9'4@:6UP;W)T97)E<B!T:6P@9&4@(@HB=&EL
M<W9A<F5N9&4@9F5L=&5R(&D@)7,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z.3@W(&QI8B](;W)D92]!=71H+G!H<#HY.#<*;7-G:60@(EEO=2!H
M879E(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`B1'4@97(@8FQE=F5T(&QO
M9V=E="!U9"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8Q(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,C8Q"FUS9VED("(B"B)9;W4@:&%V92!T;R!E
M;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I
M=&@@86X@;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA;"!D
M:6%L:6YG('!R969I>"XB"FUS9W-T<B`B(@HB1'4@<VMA;"!I;F1T87-T92!E
M="!F=6YG97)E;F1E(&UO8FEL;G5M;65R.R!K=6X@8VEF<F4@;65D(&5T('9A
M;&=F<FD@)RLG(&9O<B`B"B)D96X@:6YT97)N871I;VYA;"!R971N:6YG<VMO
M9&4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X."!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3$X.`IM<V=I9"`B66]U(&AA=F4@=&\@96YT97(@82!V
M86QI9"!V86QU92XB"FUS9W-T<B`B1'4@<VMA;"!I;F1T87-T92!E;B!G>6QD
M:6<@=N9R9&DN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.C,W(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M
M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU
M<',N(@IM<V=S='(@(B(*(D1U('-K86P@:V]N9FEG=7)E<F4@96X@1&%T851R
M964M8F%C:V5N9"!F;W(@870@:W5N;F4@86YV96YD92!/<'-K<FEV;FEN9V5R
M+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#<Q(&QI8B](;W)D
M92YP:'`Z-#<Q"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C
M:V5N9"XB"FUS9W-T<B`B1'4@<VMA;"!K;VYF:6=U<F5R92!E;F0@5D93+6)A
M8VME;F0N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*
M;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y
M;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R("(B"B)$
M=2!B;&EV97(@;OAD('1I;"!A="!L879E(&5N('!R;V)L96UB97-K<FEV96QS
M92P@9OAR(&1U(&MA;B!S96YD92!D96X@:6YD+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M=7-T
M(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*;7-G
M<W1R(")$=2!S:V%L(&EN9'1A<W1E(&1E;B!54DP@:'9O<G1I;"!D96YN92!H
MYF=T92!S:V%L(&AE;G9I<V4B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M
M+G!H<#HX,`IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B
M92!D96QE=&5D+B(*;7-G<W1R(")$=2!S:V%L(';F;&=E(&1E;B!S97)V97(L
M('-O;2!S:V%L('-L971T97,N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$Y"FUS
M9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T
M+B(*;7-G<W1R(")$=2!S:V%L(&%N9VEV92!B<G5G97)N879N970L('-O;2!D
M=2!V:6P@9FIE<FYE+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B
M66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T
M<B`B1'4@<VMA;"!A;F=I=F4@8G)U9V5R;F%V;F5T+"!S;VT@9'4@=FEL(&9J
M97)N92XB"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE
M('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`B1'4@<VMA;"!A;F=I=F4@8G)U
M9V5R;F%V;F5T+"!S;VT@9'4@=FEL('1I;&;X:F4N(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,30V"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M
M92!T;R!U<&1A=&4N(@IM<V=S='(@(D1U('-K86P@86YG:79E(&)R=6=E<FYA
M=FYE="P@<V]M(&1U('9I;"!O<&1A=&5R92XB"@HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S@@;&EB+TAO<F1E+T-O;7!R97-S
M+WII<"YP:'`Z,3,X"FUS9VED(")9;W4@;75S="!S<&5C:69Y('=H870@86-T
M:6]N('1O('!E<F9O<FTN(@IM<V=S='(@(D1U('-K86P@86YG:79E(&1E;B!H
M86YD;&EN9RP@<V]M('-K86P@=61F^')E<RXB"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0HC.B!L:6(O2&]R9&4O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0IM<V=I9"`B66]U(&UU<W0@
M='EP92!A(&YE=R!C871E9V]R>2!N86UE+B(*;7-G<W1R(")$=2!S:V%L(&%N
M9VEV92!E="!N>70@:V%T96=O<FEN879N+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S"B,Z(&QI8B].970O
M4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D
M('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B
M1'4@8FQI=F5R(&[X9'0@=&EL(&%T(&%N9VEV92!E="!I=&%L:65N<VME('1E
M;&5F;VYN=6UM97(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-S4@
M;&EB+TAO<F1E+T%U=&@N<&AP.CDW-0HC+"!P:'`M9F]R;6%T"FUS9VED(")9
M;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I
M;BXB"FUS9W-T<B`B1&EN("5S('-E<W-I;VX@97(@=61L^&)E="X@3&]G('9E
M;FQI9W-T(&EN9"!I9V5N+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C,X"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`B
M1&EN(&4M<&]S="UA9')E<W-E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(Q-0IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R(")$:6X@
M1G)O;3H@861R97-S93HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C<@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<W(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(*;7-G:60@(EEO=7(@
M26YF;W)M871I;VXB"FUS9W-T<B`B1&EN92!I;F9O<FUA=&EO;F5R(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<Y(&QI8B](;W)D92]!=71H+G!H
M<#HY-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE="!!
M9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U
M<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I='DL('EO
M=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B)$:6X@26YT97)N970M
M861R97-S92!E<B!S:VEF=&5T('-I9&5N(&)E9WEN9&5L<V5N(&%F(&1I;B`E
M<RUS97-S:6]N+B!&;W(@870@(@HB8F5S:WET=&4@9&EN('-I:VME<FAE9"!B
M;&EV97(@9'4@;OAD="!T:6P@870@;&]G9V4@:6YD(&EG96XN(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*;7-G:60@(EEO=7(@3F%M
M92(*;7-G<W1R(")$:70@;F%V;B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VYO861D+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A
M8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W
M:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N
M=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H96YT:6-A=&EO
M;B!B86-K96YD+B(*;7-G<W1R("(B"B)$:6X@YF=T;FEN9W,M8F%C:V5N9"!U
M;F1E<G-T^'1T97(@:6MK92!T:6QF^&IE;'-E;B!A9B!B<G5G97)E+B!(=FES
M(&1U("(*(OAN<VME<B!A="!B<G5G92!(;W)D92!T:6P@870@861M:6YI<W1R
M97)E(&)R=6=E<FMO;G1I+"!B;&EV97(@9'4@;OAD="!T:6P@870@(@HB8G)U
M9V4@96X@86YD96X@YF=T;FEN9W,M8F%C:V5N9"XB"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N
M=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E
M<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S
M;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@HB1&EN(&%U=&]R:7-A=&EO
M;G,M8F%C:V5N9"!U;F1E<G-T^'1T97(@:6MK92!O<&QI<W1N:6YG96X@868@
M8G)U9V5R92!E;&QE<B!E<B`B"B)D96X@9G5N:W1I;VX@868@96X@96QL97(@
M86YD96X@9W)U;F0@8FQE=F5T('-LY65T(&9R82XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HY.#,@;&EB+TAO<F1E+T%U=&@N<&AP.CDX,PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H
M879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E
M<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@
M;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(D1I;B!B<F]W<V5R('-Y;F5S(&%T
M(';F<F4@<VMI9G1E="!S:61E;B!B96=Y;F1E;'-E;B!A9B!D:6X@)7,M<V5S
M<VEO;BX@1F]R("(*(F%T(&)E<VMY='1E(&1I;B!S:6MK97)H960L('-K86P@
M9'4@;&]G9V4@:6YD(&EG96XN(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z
M-3<*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@
M9F5A='5R92XB"FUS9W-T<B`B1&EN(&)R;W=S97(@=6YD97)S=/AT=&5R(&EK
M:V4@9&5N;F4@9G5N:W1I;VYA;&ET970N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O<')I;G0N:G,Z-#(*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S
M(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L
M+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R("(B"B)$:6X@8G)O
M=W-E<B!U;F1E<G-T^'1T97(@:6MK92!D96YN92!P<FEN="UM=6QI9VAE9"X@
M5')Y:R!#=')L+T-O;6UA;F0@*R!0("(*(F9O<B!A="!P<FEN=&4N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V,0IM<V=I9"`B66]U<B!C=7)R96YT
M('1I;64@>F]N93HB"FUS9W-T<B`B1&EN(&%K='5E;&QE('1I9'-Z;VYE.B(*
M"B,Z('-E<G9I8V5S+W!R969S+G!H<#HQ,3<*;7-G:60@(EEO=7(@9&5F875L
M="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R(")$:6X@9F]R
M=F%L9W1E(&ED96YT:71E="!E<B#F;F1R970N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$V,0IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*
M;7-G<W1R(")$:6X@<W1A;F1A<F0M:61E;G1I=&5T.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,#0*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G
M<W1R(")$:70@9G5L9&4@;F%V;CHB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HY.3D@;&EB+TAO<F1E+T%U=&@N<&AP.CDY.0IM<V=I9"`B66]U<B!L
M;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T<B`B1&ET(&QO9VEN9"!E<B!U9&SX
M8F5T+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H
M<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@
M)7,B"FUS9W-T<B`B1&ET(&YY92!K;V1E;W)D(&9O<B`E<R!E<CH@)7,B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-"!L:6(O2&]R9&4O
M4')E9G,O54DN<&AP.C$U-`IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E
M;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*
M;7-G<W1R(")$:6YE('1I;'9A;&<@97(@8FQE=F5T(&]P9&%T97)E="!F;W(@
M=F%R:6=H961E;B!A9B!D96YN92!S97-S:6]N+B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,34V(&QI8B](;W)D92]0<F5F<R]522YP:'`Z
M,34V"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM
M<V=S='(@(D1I;F4@=&EL=F%L9R!E<B!O<&1A=&5R970N(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@
M:&%S(&)E96X@<F5S970B"FUS9W-T<B`B1&ET(&MO9&5O<F0@97(@8FQE=F5T
M(&YU;'-T:6QL970B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW
M.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE
M8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S
M<W=O<F0N(@IM<V=S='(@(B(*(D1I="!K;V1E;W)D(&5R(&)L979E="!N=6QS
M=&EL;&4[(&MO;G1R;VQLZ7(@9&EN(&EN9&)A:VME(&]G(&QO9R!I;F0@;65D
M(&1I="`B"B)N>64@:V]D96]R9"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HW,S,@;&EB+TAO<F1E+T%U=&@N<&AP.C<S,PIM<V=I9"`B66]U<B!P
M87-S=V]R9"!H87,@97AP:7)E9"XB"FUS9W-T<B`B1&ET(&MO9&5O<F0@97(@
M=61L^&)E="XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*
M;7-G:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(D1I;F4@9FIE
M<FYE('-E<G9E<F4Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-`HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C4T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M.`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R(")*=6=O<VQA=FEE;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G<W1R("):8>]R92(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T
M.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4V(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(EIA;6)I82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T
M.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4W(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T<B`B6FEM8F%B
M=V4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G:60@(EII<'!Y
M(@IM<V=S='(@(EII<'!Y(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I
M;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC.B!L:6(O2&]R9&4O5&5X
M="]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S0*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U
M;W1E9"!497AT72(*;7-G<W1R(");4VMJ=6P@8VET97)E="!T96MS=%TB"@HC
M.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HX.0IM<V=I9"`B6U!R;V)L96T@4F5P
M;W)T72(*;7-G<W1R(");4')O8FQE;6)E<VMR:79E;'-E72(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(");4VAO
M=R!1=6]T960@5&5X="`M(@IM<V=S='(@(EM6:7,@8VET97)E="!T96MS="`M
M(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q
M=6]T97,N<&AP.C$W-`HC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O:&EG:&QI
M9VAT<75O=&5S+G!H<#HQ-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@
M475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B6U9I<R!C:71E<F5T
M('1E:W-T("T@)7,@;&EN:65R72(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,C`T(&QI8B](;W)D92YP:'`Z,C`T"B,L('!H<"UF;W)M870*;7-G
M:60@(EML:6YE("5S(&]F("5S72(*;7-G<W1R(");;&EN:64@)7,@=60@868@
M)7-=(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-34T(&QI8B](
M;W)D92YP:'`Z,34U-`HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q
M"FUS9VED(")?061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R871I
M;VXB"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T<B`B
M0TQ)(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS9VED(")?1&%T851R964B"FUS
M9W-T<B`B1&%T851R964B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*;7-G:60@(E]$96QE=&4@4F]W(@IM
M<V=S='(@(E-L970@<N9K:V4B"@HC.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@
M(E]'<F]U<',B"FUS9W-T<B`B1W)U<'!E<B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92]-96YU+G!H<#HQ-S4@;&EB+TAO<F1E+TUE;G4N<&AP.C$W-0IM
M<V=I9"`B7TAE;'`B"FUS9W-T<B`B2&KF;'`B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@(E])
M;6%G92!0<F]P97)T:65S+BXN(@IM<V=S='(@(D)I;&QE9"UE9V5N<VMA8F5R
M+BXN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y-"!L
M:6(O2&]R9&4O365N=2YP:'`Z,3DT"FUS9VED(")?3&]G(&EN(@IM<V=S='(@
M(DQO9R!I;F0B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z
M,3DP(&QI8B](;W)D92]-96YU+G!H<#HQ.3`*;7-G:60@(E],;V<@;W5T(@IM
M<V=S='(@(DQO9R!U9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO9&EF>2!,:6YK+BXN
M(@IM<V=S='(@(L9N9')I;F<@:&5N=FES;FEN9RXN+B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]-96YU+G!H<#HQ-C0@;&EB+TAO<F1E+TUE;G4N<&AP
M.C$V-`IM<V=I9"`B7T]P=&EO;G,B"FUS9W-T<B`B26YD<W1I;&QI;F=E<B(*
M"B,Z(&QI8B]A<&DN<&AP.C$S-PIM<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S
M='(@(E1I;&QA9&5L<V5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V"FUS9VED(")?4F5M;W9E($QI;FLN
M+BXB"FUS9W-T<B`B4VQE="!H96YV:7-N:6YG+BXN(@H*(SH@;&EB+V%P:2YP
M:'`Z,3(U"FUS9VED(")?4V5T=7`B"FUS9W-T<B`B3W!SYG1N:6YG(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,S"FUS9VED(")?5&%B;&4@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")486)E
M;"UE9V5N<VMA8F5R+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?
M57-E<G,B"FUS9W-T<B`B0G)U9V5R92(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z.3(U(&QI8B](;W)D92]+;VQA8BYP:'`Z.3(U"FUS9VED(")A
M9&1R97-S(&)O;VLB"FUS9W-T<B`B861R97-S96MA<G1O=&5K(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S0@;&EB+TAO<F1E+TU)
M344O365S<V%G92YP:'`Z,3,T"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*
M;7-G<W1R(")A9')E<W-E;G0@=6ME;F1T(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,3<@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,3<*;7-G:60@
M(F-A;&5N9&%R(@IM<V=S='(@(FMA;&5N9&5R(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ-SD@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R(")V:6YD<W1I;&QE(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3@@;&EB+TAO<F1E+TU)
M344O365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U
M="!F:6QE(@IM<V=S='(@(FMA;B!I:VME(&1A;FYE('5D9&%T82UF:6PB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S,"!L:6(O2&]R
M9&4O34E-12]-97-S86=E+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN
M<'5T(@IM<V=S='(@(FMA;B!I:VME(.5B;F4@:6YD9&%T82(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C8P,"!L:6(O2&]R9&4O34E-
M12]#;VYT96YT<RYP:'`Z-C`P"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@
M(FML:6L@:&5R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ,C(@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3(R"FUS9VED(")C
M;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T<B`B9F5J;"!V960@86YV
M96YD96QS92!A9B!K;VUM86YD;RUL:6YI92(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,3<X(&QI8B](;W)D92]-24U%+TUE<W-A9V4N
M<&AP.C$W.`IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R(")K
M;VYF:6=U<F%T:6]N<V9E:FPB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$U-"!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-30*
M;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B
M;6%N9VQE<B!K<FET:7-K('-Y<W1E;69I;"(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,3(V(&QI8B](;W)D92]-24U%+TUE<W-A9V4N
M<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B9F5J
M;"!I(&1A=&%F;W)M870B"@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC
M.C,P"FUS9VED(")E9&ET(@IM<V=S='(@(G)E9&EG97(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$X,B!L:6(O2&]R9&4O34E-12]-
M97-S86=E+G!H<#HQ.#(*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R
M(")I;F1G86YG(&EK:V4@9G5N9&5T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-S,*;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B
M9F%L9&5N9&4B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX
M.3@@;&EB+TAO<F1E+T)R;W=S97(N<&AP.C@Y.`IM<V=I9"`B9FEL92(*;7-G
M<W1R(")F:6PB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X,2!L:6(O0FQO
M8VLO;65T87(N<&AP.C,V-R!L:6(O0FQO8VLO;65T87(N<&AP.C,Y,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S(@IM
M<V=S='(@(F9R82`E<R`H)7,I(&UE9"`E<R`E<R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,SD*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B
M<W1O<FUF=6QD(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(U,`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C4P"FUS9VED(")H.B(*;7-G<W1R(")H.B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HS-3D*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U.0IM<V=I9"`B:&@B"FUS9W-T<B`B
M:&@B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S."!L
M:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@;F%M
M92!U;FMN;W=N(@IM<V=S='(@(G5K96YD="!M87-K:6YN879N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(FEM;65D:6%T
M92(*;7-G<W1R("+X:F5B;&EK:V5L:6=T(@H*(SH@861M:6XO<V5T=7`O9&EF
M9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(FEN;&EN
M92(*;7-G<W1R(")I;F1L96IR970B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$V,B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ
M-C(*;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R(")I;F1D871A
M+W5D9&%T82UF96IL(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-#8@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,30V"FUS9VED
M(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R(")I;G1E<FX@<V]F
M='=A<F4M9F5J;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO
M8VMS+FIS.C$S"FUS9VED(")L:6YE<UTB"FUS9W-T<B`B;&EN:65R72(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H
M<#HU,PHC.B!L:6(O5D93+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@
M;6%K:6YG($E33RXB"FUS9W-T<B`B;6MI<V]F<R!F96IL:V]D92`E9"!U;F1E
M<B!D86YN96QS92!A9B!)4T\N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C,W,`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,S<P"FUS9VED(")M;2(*;7-G<W1R(")M;2(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C@U(&QI8B](;W)D92]0<F5F
M<R]522YP:'`Z,C@U"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ
M-S`@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(T,0IM<V=I9"`B;F%M
M92(*;7-G<W1R(")N879N(@H*(SH@9G)A;65W;W)K+U)00R]24$,N<&AP.C$R
M-"!L:6(O2&]R9&4O4E!#+G!H<#HQ,C0*;7-G:60@(FYO="!I;7!L96UE;G1E
M9"(*;7-G<W1R(")I:VME(&EM<&QE;65N=&5R970B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,C`@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HQ,C(P"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S
M='(@(F5N9&YU(&EK:V4@:6UP;&5M96YT97)E="(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.3`Y(&QI8B](;W)D92]+;VQA8BYP:'`Z.3`Y"FUS
M9VED(")N;W1E<&%D(@IM<V=S='(@(FYO=&5S8FQO:R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@
M(G!E<F-E;G0B"FUS9W-T<B`B<')O8V5N="(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,3<T(&QI8B](;W)D92]-24U%+TUE<W-A9V4N
M<&AP.C$W-`IM<V=I9"`B<&5R;6ES<VEO;B!D96YI960B"FUS9W-T<B`B=&EL
M;&%D96QS92!NYF=T970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS9W-T<B`B
M<')I:VME<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,3<P(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I9"`B<F5M
M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(F9E:FP@:2!P<F]T;VMO
M;"!F<F$@9FIE<FX@<VED92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C<U"FUS9VED(")R:7-I;F<B"FUS9W-T<B`B<W1I9V5N
M9&4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T,B!L
M:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-#(*;7-G:60@(G-E<G9I8V4@
M=6YA=F%I;&%B;&4B"FUS9W-T<B`B=&IE;F5S=&4@=71I;&?F;F=E;&EG(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HQ,#$*;7-G:60@(G-H;W<@9&EF
M9F5R96YC97,B"FUS9W-T<B`B=FES(&9O<G-K96QL92(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$T"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I
M;"!V:6$@2%144"(*;7-G<W1R(")S;7,R96UA:6P@=FEA($A45%`B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@W"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS.#<*;7-G:60@(G-S
M(@IM<V=S='(@(G-S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-S0*;7-G:60@(G-T96%D>2(*;7-G<W1R(")S=&%B:6QT(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3`@;&EB+TAO
M<F1E+TU)344O365S<V%G92YP:'`Z,34P"FUS9VED(")S>7-T96T@97)R;W(B
M"FUS9W-T<B`B<WES=&5M9F5J;"(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3,S(&QI8B](;W)D92]+;VQA8BYP:'`Z.3,S"FUS9VED(")T87-K
M(&QI<W0B"FUS9W-T<B`B;W!G879E;&ES=&4B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$V-B!L:6(O2&]R9&4O34E-12]-97-S86=E
M+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(FUI
M9&QE<G1I9&EG(&9E:FQT:6QS=&%N9"(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-S`*(SH@;&EB+TAO
M<F1E+T%U=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@(G1Y<&4@=&AE('!A<W-W
M;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B:6YD=&%S="!K;V1E;W)D
M970@=&\@9V%N9V4@9F]R(&%T(&)E:W+F9G1E(@H*(SH@861M:6XO<V5T=7`O
M9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(G5N
M:69I960B"FUS9W-T<B`B<V%M;65N<VUE;'1E="(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O4&%R="YP:'`Z,C<@;&EB+TAO<F1E+TU)344O4&%R="YP:'`Z
M,C<*;7-G:60@(G5N;F%M960B"FUS9W-T<B`B=6YA=FYG:79E;B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V
M-0HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")U<V5R('-E
M;&5C="(*;7-G<W1R(")B<G5G97)V86QG(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C,U(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S='(@(G9#87)D(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T,@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0R"FUS9VED
M(")W.B(*;7-G<W1R(")W.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HV"FUS9VED(")W96%T:&5R+F-O;2(*;7-G<W1R(")W96%T:&5R+F-O
M;2(*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&\O8W-?0UHN<&\`````````````````````
M````````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P-S(Q,3<Q(#$P-3$U
M-#,S-S0S(#`Q-S4S,``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````C($-Z96-H('1R86YS;&%T:6]N<R!F;W(@2&]R9&4N"B,@
M0V]P>7)I9VAT("A#*2`R,#`T($AO<F1E(%!R;VIE8W0*(R!4:&ES(&9I;&4@
M:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC96YS92!A<R!T:&4@
M2&]R9&4@<&%C:V%G92X*(R!0879E;"!#:'ET:6P@/'!A=F5L0&-H>71I;"YT
M:SXL(#(P,#$M,C`P-"X*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M
M260M5F5R<VEO;CH@2&]R9&4@,RXP7&XB"B)297!O<G0M37-G:60M0G5G<RU4
M;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z
M(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@
M,C`P-"TP-RTR,B`Q,3HT.2TP-S`P7&XB"B),87-T+51R86YS;&%T;W(Z($UI
M;&]S(%=I;6UE<B`\=VEM;65R0'IC=2YC>CY<;B(*(DQA;F=U86=E+51E86TZ
M($-Z96-H(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO
M;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]
M25-/+3@X-3DM,EQN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I
M=%QN(@HB4&QU<F%L+49O<FUS.B!N<&QU<F%L<STS.R!P;'5R86P]*&XE,3`]
M/3$@)B8@;B4Q,#`A/3$Q(#\@,"`Z(&XE,3`^/3(@)B8@;B4B"B(Q,#P]-"`F
M)B`H;B4Q,#`\,3`@?'P@;B4Q,#`^/3(P*2`_(#$@.B`R*3M<;B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-CD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B("@E<R!D87ES(&%G;RDB"FUS9W-T<B`B("AP^&5D("5S(&1N>2DB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S-S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B`H4/CM<W1U<&]V
M_2!K;.WH("5S*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R("(@
M*'8@)7,@9&YE8V@I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W
M,PIM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B("AD;F5S*2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S4*;7-G:60@(B`H=&]M;W)R;W<I(@IM
M<V=S='(@(B`H>NUT<F$I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C,W,0IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@(B`H=NAE<F$I(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U-B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S8Q"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HT,#<*;7-G:60@(B!A="`B"FUS9W-T<B`B(')Y8VAL;W-T("(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C$U"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(*
M;7-G<W1R(").96[M(&%D<F5SX?AE;2(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)
M+G!H<#HR-S(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I
M<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(B5S(&YE;'IE('IV;VQI
M="XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C8U
M.0HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$P-#(*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N
M9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@(B<E<R<@
M;F5N[2!N86MO;F9I9W5R;W;A;B!V(')E9VES=')E8V@@2&]R9&4@<WES=.EM
M=2XB"@HC.B!F<F%M97=O<FLO5')E92]4<F5E+G!H<#HQ-S$*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F
M;W5N9"XB"FUS9W-T<B`B)R5S)R!P^&5K;&%D8>@@;F5B>6P@;F%L97IE;BXB
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4V"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M
M+B(*;7-G<W1R("(E<R<@8GEL('#X:63A;B!D;R!S>7-TZ6UU('-K=7!I;BXB
M"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE('!E<FUI
M<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B)R5S)R!B>6P@</AI9.%N(&1O('-Y
M<W3I;74@</CM<W1U<&]V_6-H('!RX78N(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HU-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3`*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-R96%T960Z("5S+B(*
M;7-G<W1R("(G)7,G(&YE8GEL('9Y='9O^&5N.B`E<RXB"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"
M('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B)60@)7,@82`E<R(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,C8X(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HU-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y
M<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@(B5D+61E;F[M('#X
M961P;W;L[R(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HV.`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R("(E<R`M(&]Z
M;N%M96[M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW
M,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T
M<B`B)7,@;W1I<VLB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HX,S,@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,U
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B5S($M"(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I
M;VXB"FUS9W-T<B`B)7,@;W!E<F%C92#Z9'*^8GD@+2!P;W1V<GIE;NTB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T
M<B`B)7,@;F%S=&%V96[M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N
M=7`N<&AP.C(V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N(%5P(@IM
M<V=S='(@(B5S(')E9VES=')A8V4B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R
M965M96YT(@IM<V=S='(@(B5S('!O9&WM;FMY('!O=;[M=N%N[2(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#(X(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z-#DP"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C4Q
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(E<R!J:;X@97AI
M<W1U:F4N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3D@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ-C4@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,SD*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS-#4@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B)7,@
M;F$@)7,@)7,B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E
M<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO
M=RX@0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@
M=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B3WIN8>AI
M="!RX6UEZ&5K('!R;R!VN65C:&YY(&]P97)A8V4L(&MT97+I(&-H8V5T92!T
M9>\@<')O=NES="XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S0P
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@
M(B5S(&IE('!OOF%D;W;A;F\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X
M-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S='(@(B5S
M(&UI;G5T(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN
M<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM
M<V=S='(@(B5S(&YE8GEL;R!N86QE>F5N;RXB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]L:7-T+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O
M("5S(&]F("5S(@IM<V=S='(@(B5S(&&^("5S('H@)7,B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.CDR,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R("(E<R!A9')E<^'X(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R("(E<R!K86QE;F3A^"(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`V"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R("(E<R!ZX7!I<V[M:R(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,P"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B)7,@<V5Z;F%M(/IK;VSY(@H*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B
M"FUS9W-T<B`B)7,Z("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:'1M;"YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4
M:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O
M(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O
M<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I
M;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,V-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#$P
M"B,L(&9U>GIY"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(BP@;N%R87IO
M=OT@)7,@)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X."!L:6(O0FQO
M8VLO;65T87(N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U<W1I
M;F<@)7,@)7,B"FUS9W-T<B`B+"!NX7)A>F]V_2`E<R`E<R(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R
M:6%B;&4@9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(L('!R;VWL;F[A(&]D("5S
M(&1O("5S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR.30@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-#@*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C`V.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,3(X"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HW
M-#D*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(M+2!V_6+L<B`M+2(*
M"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&;W)M
M870B"FUS9W-T<B`B,3(@:&]D:6YO=OT@9F]R;>%T(@H*(SH@;&EB+T)L;V-K
M+W1I;64N<&AP.C$Y"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R("(R
M-"!H;V1I;F]V_2!F;W)MX70B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN
M8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@:&]D:6XB"@HC.B!F
M<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C8Y"B,L(&9U>GIY"FUS9VED("(\
M4')E=FEO=7,B"FUS9W-T<B`B4/AE9&-H;WKM('-T<N%N:V$B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$Q.0IM<V=I9"`B02!D871A8F%S92!B86-K96YD
M(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R(")0<F\@=&5N
M=&\@8FQO:R!J92!V>;YA9&]VX6X@9&%T86+A>F]V_2!Z9')O:BXB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V,`IM<V=I9"`B02!F871A;"!E
M<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`B5GES:WET;&$@<V4@>N%V8;YN
MX2!C:'EB82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDS
M-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R
M>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B4')O('IAN6EF<F]VX6[M('IP<N%V
M>2!J92!N=71N;R!P;W6^[70@=F7X96IN_2!01U`@:VSMZ"XB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38U"FUS9VED(")!('!U8FQI
M8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S
M86=E+B(*;7-G<W1R(")0<F\@=F5R:69I:V%C:2!P;V1E<'-A;ND@>G!RX79Y
M(&IE(&YU=&YO('!O=;[M="!V9?AE:F[](%!'4"!K;.WH+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P.3<*;7-G:60@(B(*(D$@<'5B
M;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R
M("(B"B)0<F\@9&6Y:69R;W;A;NT@>G!RX79Y(&IE(&YU=&YO('!O=;[M="!V
M9?AE:F[](%!'4"!K;.WH+"!P<FEVX71N[2!01U`@:VSMZ"!A("(*(FAE<VQO
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P,34*;7-G
M:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S86=E
M+B(*;7-G<W1R("(B"B)0<F\@<&]D97!SX6[M('IP<N%V>2!J92!N=71N;R!P
M;W6^[70@=F7X96IN_2!01U`@:VSMZ"P@<')I=N%T;NT@4$=0(&ML[>@@82`B
M"B)H97-L;RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4P-0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3
M+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB
M9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*(E!R;R!D9;EI9G)O=N%N
M[2!Z<'+A=GD@:F4@;G5T;F\@<&]UONUT('9E^&5J;OT@4R]-24U%(&ML[>@L
M('!R:7;A=&[M(%,O34E-12`B"B)K;.WH(&$@:&5S;&\N(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B
M;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M97-S86=E+B(*;7-G
M<W1R("(B"B)0<F\@<&]D97!SX6[M('IP<N%V>2!J92!N=71N;R!P;W6^[70@
M=F7X96IN_2!3+TU)344@:VSMZ"P@<')I=N%T;NT@4R]-24U%("(*(FML[>@@
M82!H97-L;RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O
M(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(")0<F\@>F&Y:69R;W;A;NT@
M>G!RX79Y(&IE(&YU=&YO('!O=;[M="!V9?AE:F[](%,O34E-12!K;.WH+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.CD*(RP@
M9G5Z>GD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R("):871AOF5N;R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P"B,L(&9U
M>GIY"FUS9VED(")!32!,:6=H="!286EN(@IM<V=S='(@(D]D<&]L961N[2!L
M96AK_2!DZ;F[(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3$*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B4F%N;NT@9.FYNR(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R"FUS
M9VED(")!32!3:&]W97)S(@IM<V=S='(@(E)A;F[M('#X96CA\FMY(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@
M(D%-(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")286YN[2!S;NQH;W;I('#X96CA
M\FMY(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-
M+U!-(@IM<V=S='(@(D%-+U!-(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`P"FUS9VED(")!4$D@240B"FUS9W-T
M<B`B05!)($E$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`B
M26YF;W)M86-E(&\@=&]M=&\@961I=&]R=2(*"B,Z('-E<G9I8V5S+VAE;'`O
M:6YD97@N<&AP.C4R"FUS9VED(")!8F]U="XN+B(*;7-G<W1R("));F9O<FUA
M8V4N+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<T"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B5&5X="!D;VSY(&1O
M(&]B<N%Z:W4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<R"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B5&5X="!D;W!R
M;W-T^&5D(&]B<N%Z:W4B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,C<P"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E
M8W1O<GDN(@IM<V=S='(@(E9Y='9O^&5N[2!61E,@861R87/A^&4@;F5B>6QO
M('!O=F]L96YO+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ
M,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM
M<V=S='(@(E9Y='9O^&5N[2!61E,@<V]U8F]R=2!N96)Y;&\@<&]V;VQE;F\N
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C,*(RP@9G5Z>GD*;7-G:60@
M(D%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B5F&Y92!I;F9O<FUA8V4B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4*;7-G:60@(D%C8V]U;G0@
M4&%S<W=O<F0B"FUS9W-T<B`B5;YI=F%T96QS:^D@:&5S;&\B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*;7-G
M:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R(")5OFEV871E;&O](/KH970@
M8GEL('IA8FQO:V]VX6XN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,S,PIM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R(")5OFEV871E;&OI(/KH
M='DB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T."!T96UP
M;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]A9&1C:&EL9"YI;F,Z,3$*;7-G:60@(D%D9"(*;7-G<W1R(")6;&^^
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@861M:6XO9W)O=7!S+G!H<#HR
M,C4*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R(")0^&ED870@<&]D
M<VMU<&EN=2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3@@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY.0IM<V=I9"`B061D($-H
M:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`B4/AI9&%T('!O9"UP<N%V82(*"B,Z
M('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!9&0@2&5R93HB
M"FUS9W-T<B`B4/AI9&%T.B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$X(&%D
M;6EN+V=R;W5P<RYP:'`Z,C$Y"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S
M='(@(E#X:61A="!N;W9O=2!S:W5P:6YU(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HX-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB"FUS9W-T<B`B4/AI9&%T
M(&YO=N$@<'+A=F$B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H
M:6QD+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C
M:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B4/AI9&%T('!O9'-K=7!I
M;G4@9&\@)R5S)R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,30W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!P
M97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R(")0^&ED870@<&]D+7!RX79A
M(&1O("<E<R<B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@
M;F5W('5S97(Z(@IM<V=S='(@(E#X:61A="!N;W;I:&\@=;YI=F%T96QE.B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU-30*
M;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B4/AI9&%T('-L;W5P96,B"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,T"FUS9VED(")!
M9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`B4/AI9&%T(&YO=ND@Z&QE;GDB"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@<&%I
M<B(*;7-G<W1R(")0^&ED870@<.%R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@
M87,@82!-;WII;&QA(%-I9&5B87(B"FUS9W-T<B`B4/AI9&%T("5S(&UE;G4@
M:F%K;R!B;^AN[2!S;&]U<&5C($UO>FEL;'DB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*;7-G:60@(D%D9"!T;R!A9&1R
M97-S(&)O;VLZ(@IM<V=S='(@(E#X:61A="!D;R!A9')E<^'X93HB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*;7-G:60@
M(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`B4/AI9&%T(&1O(&WI
M:&\@861R97/A^&4B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,0IM<V=I9"`B061D
M('5S97(B"FUS9W-T<B`B4/AI9&%T('6^:79A=&5L92(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C<Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E
M9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D
M:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R("(B
M"B(G)7,G(&)Y;&\@</AI9.%N;R!D;R!S>7-TZ6UU+"!A;&4@;F5L>F4@</AI
M9&%T(&[A<VQE9'5J[6/M(&EN9F]R;6%C93H@)7,N(@H*(SH@<VEG;G5P+G!H
M<#HT-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E<UPB
M('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`B
M)R5S)R!B>6QO('#X:63A;F\@9&\@<WES=.EM=2X@3?F^971E('-E(&YY;NT@
M</AI:&SA<VET(&1O('-Y<W3I;74N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;F]A9&0N:6YC.C(*;7-G:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE
M9"XB"FUS9W-T<B`B4/AI9.%VX6[M('6^:79A=&5L^2!J92!Z86)L;VMO=N%N
M;RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3(V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M-S,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,0IM<V=I9"`B061D<F5S
M<R(*;7-G<W1R(")!9')E<V$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3,Y"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B061R97/A^"(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT"FUS
M9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U
M<V5R<R(*;7-G<W1R("(B"B)6>6MO;N%V870@861M:6YI<W1R86-I("T@;F%S
M=&%V96[M('#X[7-T=7!O=OUC:"!P<N%V('!R;R!O<W1A=&[M('6^:79A=&5L
M92(*"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ.2!S97)V:6-E<R]P;W)T86PO<VED
M96)A<BYP:'`Z,3$S"FUS9VED(")!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!
M9&UI;FES=')A8V4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Q
M"FUS9VED(")!9',B"FUS9W-T<B`B26YZ97+A='DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS
M9VED(")!9F=H86YI<W1A;B(*;7-G<W1R(")!9F=HX6YI<W3A;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3<*;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B06QBX6YI92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S`*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B06R^[7)S:V\B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED
M(")!;&EA<R(*;7-G<W1R(")0^&5Z9.UV:V$O06QI87,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$V"FUS9VED
M(")!;&EG;B(*;7-G<W1R("):87)O=FYA="(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N=#HB
M"FUS9W-T<B`B6F%R;W9NX6[M.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(E:Y92(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,C`W('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-C4*;7-G:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@
M(E:Y:6-H;FD@;W;L^&5N[2!UOFEV871E;.DB"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C(R"FUS9VED(")!;&P@1W)O=7!S
M(@IM<V=S='(@(E:Y96-H;GD@<VMU<&EN>2(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+V1A=&%T
M<F5E+G!H<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(E:Y
M96-H;F$@=;YI=F%T96QS:^$@<'+A=F$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$W"FUS9VED(")!;&P@9F]U
M<B!S:61E<R(*;7-G<W1R(")6N65C:&YY(.AT>?AI('-T<F%N>2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S$*;7-G:60@(D%L;&]W(&UU;'1I
M<&QE(&%D9')E<W-E<R(*;7-G<W1R(")0;W9O;&ET(';M8V4@861R97,B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,T"FUS9VED(")!;&QO=R!S971T
M:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R(")0;W9O;&ET(&YA
M<W1A=F5N[2!T>7!U('-E=/CM9.QN_2!S97IN86T_(@H*(SH@9G)A;65W;W)K
M+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS9VED(")!;')E861Y
M(&5X:7-T<R(*;7-G<W1R(")*:;X@97AI<W1U:F4B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3(S"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*
M;7-G<W1R(")!;'1E<FYA=&EV;NT@24U34"!P^&EH;.&Y96[M(&1O('-Y<W3I
M;74B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`W"FUS9VED(")!;'1E
M<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R(")!;'1E<FYA=&EV;NT@24U3
M4"!H97-L;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3D*;7-G:60@
M(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S='(@(D%L=&5R;F%T:79N
M[2!)35-0('6^:79A=&5L<VOI(&IMZ6YO(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z,S4*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S
M(@IM<V=S='(@(D%L=&5R;F%T:79N[2!E+6UA:6QO=N$@861R97-A(@H*(SH@
M861M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*;7-G:60@(D%L=&5R;F%T92!T96UP
M;&%T97,B"FUS9W-T<B`B06QT97)N871I=F[M('9Z;W)Y(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C(*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(U
M"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS9W-T<B`B06QT97)N871I=F[M
M('1E>'0Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@4V%M;V$B"FUS
M9W-T<B`B06UE<FEC:^$@4V%M;V$B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3$U
M"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N(@IM<V=S
M='(@(D)Y;&$@>F%DX6YA(&YE<&]V;VQE;N$@:&]D;F]T82XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38W"B,L(&9U>GIY"FUS9VED(")!
M;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+B(*;7-G<W1R(")N87-T86QA
M(&-H>6)A.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%N9&]R<F$B"FUS9W-T<B`B
M06YD;W)A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YG;VQA(@IM<V=S='(@(D%N
M9V]L82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I;&QA(@IM<V=S='(@(D%N
M9W5I;&QA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM
M<V=I9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S='(@(D%N;VYY;6[M('!R;WAY
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#D*;7-G:60@(D%N
M<W=E<B(*;7-G<W1R(")/9'!O=NSO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YT
M87)C=&EC82(*;7-G<W1R(")!;G1A<FMT:6MA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I
M9"`B06YT:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R(")!;G1I9W5A(&$@0F%R
M8G5D82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO<&AP<VAE
M;&PN<&AP.C,U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3@@
M=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P
M;&EC871I;VXB"FUS9W-T<B`B07!L:6MA8V4B"@HC.B!U=&EL+VEC;VY?8G)O
M=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`B
M4V5Z;F%M(&%P;&EK86/M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$T
M,`IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@(D%P;&EK
M86-E(&IE('#X:7!R879E;F$B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@
M(E!O=;[M="!P<F\@9.QD:>ANZ2!S9.UL96[M(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T
M<B`B4V-H=N%L:70B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HX,S,*;7-G:60@(D%P<')O>&EM871E(%-I>F4B"FUS9W-T<B`B4/AI
M8FQIOF[A('9E;&EK;W-T(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(D1U8F5N(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S4*;7-G:60@(D%R86)I8R`H5VEN
M9&]W<RTQ,C4V*2(*;7-G<W1R(")!<F%B<VMY("A7:6YD;W=S+3$R-38I(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU.2!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8V"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#$*;7-G:60@(D%R8VAI=F4@
M1FEL92!3:7IE(@IM<V=S='(@(E9E;&EK;W-T(&%R8VAI=F]V86[I:&\@<V]U
M8F]R=2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-3@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-0HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@P"FUS9VED(")!
M<F-H:79E($YA;64B"FUS9W-T<B`B2FWI;F\@87)C:&EV=2(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T
M:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B"FUS9W-T<B`B57+H:73L(&-H
M8V5T92!V>6UA>F%T(+[A9&]S="!O('#X:6ALX;EE;NT@9&\@)7,_(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D
M96QE=&4@7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS9W-T<B`B57+H
M:73L('-I('#X96IE=&4@=GEM87IA="`G)7,G(&$@<&]D<VMU<&EN>3\B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4X"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B07)G96YT:6YA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-PIM<V=I9"`B07)M96YI82(*;7-G<W1R(")!<FWI;FEE
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S8*;7-G:60@(D%R;65N:6%N
M("A!4DU30TE)+3@I(@IM<V=S='(@(D%R;>EN<VO]("A!4DU30TE)+3@I(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T
M<B`B56WL;NTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!<G5B82(*;7-G<W1R(")!
M<G5B82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34*;7-G:60@
M(D%S8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B07-C96YS:6]N($ES;&%N9"(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@07)T
M(@IM<V=S='(@(D%S8VEI('5M[&[M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4U"FUS9VED(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM<V=S
M='(@(D%S:64O<F5G:6]N(%1I8VCI:&\@;V-EX6YU(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0R-0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@
M8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@
M(E!OON%D870@;R!P;W1V<GIE;NT@</AE9"!P<F]V961E;NUM(&]P97)A8^T@
M^F1ROF)Y/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3,*;7-G
M:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R(")3;&]U<&-E(',@^FMO
M;'DB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E;7!T('1O
M(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B4&]K=7,@
M;R!V>6UA>N%N[2!N965X:7-T=6KM8^T@<VMU<&EN>2XB"@HC.B!A9&UI;B]P
M97)M<R]D96QE=&4N<&AP.C(Y"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A
M(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")0;VMU<R!O('9Y
M;6%ZX6[M(&YE97AI<W1U:NUC[6-H('6^:79A=&5L<VO]8V@@<'+A=BXB"@HC
M.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HX-PIM<V=I9"`B071T96UP="!T;R!E
M9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(E!O:W5S
M(&\@^G!R879U(&YE97AI<W1U:NUC[6-H('6^:79A=&5L<VO]8V@@<'+A=BXB
M"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*;7-G:60@(D%T=&5M
M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T<B`B4&]K
M=7,@;R#Z<')A=G4@;F5E>&ES='5J[6/M:&\@<V3M;&5NZ6AO(&]B:F5K='4N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-"!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#8*;7-G:60@(D%T=')I
M8G5T97,B"FUS9W-T<B`B071R:6)U='DB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B075G=7-T(@IM<V=S='(@
M(E-R<&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')A;&EA(@IM<V=S='(@
M(D%U<W1RX6QI92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R:6$B"FUS9W-T
M<B`B4F%K;W5S:V\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP
M:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G-Q;#H@3F5B>6QA
M(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM<&]N82!P<F\@:6UA<"XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?
M8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL
M:71E<RXB"FUS9W-T<B`B075T:%]C>7)U<SH@6F1R;VH@;F5MX2!P;[YA9&]V
M86[I('-C:&]P;F]S=&DN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U
M<RYP:'`Z,3(R"FUS9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER=7,Z($YE8GEL
M82!N86QE>F5N82!P;[YA9&]V86[A('#X[7!O;F$@<')O(&EM87`N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]F='`N<&AP.C,V"FUS9VED("(B"B)!=71H
M7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I
M;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S
M='(@(B(*(D%U=&A?9G1P.B!.96)Y;&$@;F%L97IE;F$@<&^^861O=F%NX2!P
M^.UP;VYA('!R;R!F='`N($MO;7!I;'5J=&4@4$A0(',@+2TB"B)E;F%B;&4M
M9G1P(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HV-`IM<V=I
M9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(D%U=&A?:6UA<#H@3F5B>6QA(&YA;&5Z96YA('!OOF%D
M;W9A;N$@</CM<&]N82!P<F\@24U!4"XB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR
M8C4@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]K<F(U.B!.
M96)Y;&$@;F%L97IE;F$@<&^^861O=F%NX2!P^.UP;VYA('!R;R!K<F(U+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S`R"FUS9VED(")!
M=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!
M8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z(%)E;6]V:6YG
M('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HV
M,PIM<V=I9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;&1A<#H@3F5B>6QA(&YA;&5Z96YA
M('!OOF%D;W9A;N$@</CM<&]N82!P<F\@3$1!4"(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M870*;7-G:60@(D%U
M=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@
M=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B075T:%]L9&%P.B!.96QZ92!P
M^&ED870@=;YI=F%T96QE("5S+B!(;.&Y96[M('-E<G9E<G4Z("(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*
M;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM
M<V=S='(@(D%U=&A?;&1A<#H@3F5L>F4@=GEM87IA="!UOFEV871E;&4@)7,B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0Y.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E
M<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z($YE;'IE(&%K='5A;&EZ;W9A="!U
MOFEV871E;&4@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C0P-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@
M<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C0V"FUS9VED(")!=71H
M7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B075T:%]M8V%L.B!.96)Y;&$@;F%L97IE;F$@<&^^861O=F%NX2!P
M^.UP;VYA('!R;R!-0T%,+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB
M+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?<VUB875T:#H@
M3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM<&]N82!P<F\@<VUB875T
M:"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.3`*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R
M(")/=NSX96[M('-E;&AA;&\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HV-PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")!=71H96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S='(@(D]V[/AE;NT@
M<V5L:&%L;RX@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP
M:'`Z,3<V"FUS9VED(")!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)
M55,@<V5R=F5R+B(*;7-G<W1R(")/=NSX96[M(&)Y;&\@>F%M[71N=71O(%)!
M1$E54R!S97)V97)E;2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C@U,0IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL
M960N(@IM<V=S='(@(E-E;&AA;&\@;W;L^&5N[2!&5%`@<V5V97)E;2XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C<P"B,L(&9U>GIY"FUS9VED
M(")!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N(@IM
M<V=S='(@(E-E;&AA;&\@;W;L^&5N[2!&5%`@<V5V97)E;2XB"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C<U"FUS9VED(")!=F%I;&%B;&4@9FEE
M;&1S.B(*;7-G<W1R(")$;W-T=7!NX2!P;VQE.B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G
M:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B07IE<F)A:F2^X6XB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@(D)/1D@@17AC=7-E<R(*;7-G
M<W1R(")"3T9((';];6QU=GDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O=6YD(@IM
M<V=S='(@(E!O>F%D[2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T
M<B`B0F%R=F$@<&]Z863M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U
M+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R
M("*I<&%T;ND@:&5S;&\@<')O(&ME<F)E<F]S+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R
M;F%M92XB"FUS9W-T<B`BJ7!A=&[I('6^:79A=&5L<VOI(&IMZ6YO('!R;R!K
M97)B97)O<RXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"86AA;6%S(@IM<V=S='(@
M(D)A:&%M>2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)A:')A:6XB"FUS9W-T<B`B
M0F%H<F%I;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<W"FUS9VED(")"
M86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R(")"86QT:6-KZ2`H25-/+3@X
M-3DM,3,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R
M(")"86YG;&%DZ;DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"87)B861O<R(*;7-G
M<W1R(")"87)B861O<R(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E
M8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B3F5B>6P@;F%L97IE
M;B!A9')E<^'X("<E<R<@<R!G<F%F:6MA;6DN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S"FUS9VED(")"87-E
M;&EN92(*;7-G<W1R("):X6ML860B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QA
M<G5S(@IM<V=S='(@(D+L;&]R=7-K;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)E
M;&=I=6TB"FUS9W-T<B`B0F5L9VEE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HU,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L
M:7IE(@IM<V=S='(@(D)E;&EZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HT,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F5N:6XB
M"FUS9W-T<B`B0F5N:6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"97)M=61A(@IM
M<V=S='(@(D)E<FUU9'DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")":'5T86XB"FUS
M9W-T<B`B0FCZ=.%N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B3F%R;WIE
M;FEN>2(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H
M<#HS-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P
M<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(DYE;'IE(&YA
M;.EZ="#HX7-T(%PB)7-<(B!A<&QI:V%C92!<(B5S7"(N(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]L87EO=70N:6YC.C@Y"FUS9VED(")";&]C:R!3971T:6YG
M<R(*;7-G<W1R(").87-T879E;NT@8FQO:W4B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B
M5'EP(&)L;VMU(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S='(@(E1UZ&[L(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,@IM<V=I9"`B0F]L:79I82(*;7-G<W1R(")";VSM=FEE(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(P-0IM<V=I9"`B0F]O:VUA<FMS(@IM
M<V=S='(@(EKA;&^^:WDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(P"FUS9VED(")";W)D97(B"FUS9W-T<B`B
M3VMR86HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G<W1R("*I[?AK
M82!O:W)A:F4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR,0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R(")/:W)A
M:F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8P"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA
M(@IM<V=S='(@(D)O<VYA(&$@2&5R8V5G;W9I;F$B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z.38*;7-G:60@(D)O=&@B"FUS9W-T<B`B3V)A(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,PIM<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B0F]T<W=A;F$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S4*;7-G:60@(D)O='1O;2(*;7-G<W1R(")$;VQN[2#HX7-T(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R(")";W5V970@27-L
M86YD(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(D)R87KM
M;&EE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N
M(%1E<G)I=&]R>2(*;7-G<W1R(")"<FET<VOA('1E<FET;W)I82!V($EN9&EC
M:^EM(&]C9>%N["(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A
M;&%M(@IM<V=S='(@(D)R=6YE:2!$87)U<W-A;&%M(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM
M<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B0G5L:&%R<VMO(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L
M;&5T960@3&ES="(*;7-G<W1R(")397IN86T@<R!O9'+AOFMA;6DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B0G5R:VEN82!&
M87-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R(")"=7)U
M;F1A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0T-`IM<V=I9"`B
M0TU3(@IM<V=S='(@(D--4R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G<W1R(")#4D,B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B0U),
M($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B0U),(&1I<W1R:6)UZ&[M
M(&)O9'DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS
M9W-T<B`B5FQA<W1N;W-T:2!B7W7R:WDN+BXB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,38S"B,L(&9U>GIY"FUS9VED(")#86-H92!I;FET
M('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R(").96)Y;"!U=F5D96X@9&ES
M=')I8G7H;NT@<V5Z;F%M+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT.#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDX-PHC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,34U"FUS9VED(")#86QE;F1A
M<B(*;7-G<W1R(")+86QE;F3A^"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-#8*;7-G:60@(D-A;&TB"FUS9W-T<B`B0F5Z=NQT^.TB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B2V%M8F]DOF$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8W"FUS9VED(")#86UE<F]O;B(*;7-G<W1R(")+86UE<G5N
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A
M;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(DAE<VQO(&YE;'IE(&YA
M<W1A=FET(&%U=&]M871I8VMY+"!P<F]S[6T@:V]N=&%K='5J=&4@5F&Y96AO
M('-Y<W3I;6]VZ6AO("(*(F%D;6EN:7-T<N%T;W)A+B(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C,Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V%N(&YO="!W<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R(").
M96QZ92!V>6UA>F%T('-O=6)O<B!<(B5S7"(N(@H*(SH@861M:6XO<V5S<VEO
M;G,N<&AP.C(R"FUS9VED(")#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E
M<W-I;VX@:&%N9&QE<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER=7,N<&AP.C(S-2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q
M;"YP:'`Z,S$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@
M=&\@24U!4"!S97)V97(Z("5S(@IM<V=S='(@(DYE;'IE('-E('#X:7!O:FET
M(&L@24U!4"!S97)V97)U.B`E<R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C0Q,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@
M;W!E;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3F5L>F4@=GEM87IA="!S;W5B
M;W(@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-A;F%D82(*;7-G<W1R
M(")+86YA9&$B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E<BYP
M:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHV-0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*;7-G
M<W1R(")3=&]R;F\B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(E-T
M;W)N;R!H;.&Y96[M('!R;V)LZ6UU(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T
M92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3F5L>F4@=GEM87IA="!S;W5B;W(@
M7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HT-@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C4R"FUS9VED(")#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E
M8W1O<GDN(@IM<V=S='(@(DYE;'IE(&YA:NUT(&1OZ&%S;OT@861R97/A^"XB
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.CDQ
M"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P
M87)A;65T97(N(@IM<V=S='(@(DYE;'IE('!O:W)AZ&]V870@8F5Z('!A<F%M
M971R=2`G=&%R9V5T1FEL92<N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HS,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D
M:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(").96QZ92!V>6UA>F%T(&%D<F5S
MX?@@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92YP
M:'`Z,3(X(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8X
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E+"`E9"!C:&EL
M9')E;B!E>&ES="XB"FUS9W-T<B`B3F5L>F4@=GEM87IA="P@<')O=&^^92!E
M>&ES='5J[2!P;V1S:W5P:6YY("5D+B(*"B,Z(&9R86UE=V]R:R]$871A5')E
M92]$871A5')E92]S<6PN<&AP.C8P.`IM<V=I9"`B(@HB0V%N;F]T(')E;W)D
M97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O
M97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM<V=S='(@(B(*(DYE
M;'IE('!R;W;I<W0@>FWL;G4@=7-P;_CA9.%N[2P@<&_H970@<&]S:WET;G5T
M_6-H('!O;&^^96L@<')O(&YO=ND@(@HB=7-P;_CA9.%N[2!N96]D<&]V[63A
M('!OZ'1U('5L;[YE;OUC:"!P;VQOOF5K+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B0V%N;F]T
M(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B
M3F5L>F4@>F%S;&%T('IP<N%V=2!N82!Z861A;ND@Z.US;&\N("(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B0V%P92!697)D92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C0*;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`B5&ET=6QK>2(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I
M9"`B0V%R<FEE<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.3`*;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R(")+
M871E9V]R:64@82!Z;F'H:WDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y;6%N
M($ES;&%N9',B"FUS9W-T<B`B2V%J;6%N<VOI(&]S=')O=GDB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#
M96QL(%!H;VYE(@IM<V=S='(@(DUO8FEL;NT@=&5L969O;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*;7-G
M:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G<W1R(")-;[YN;W-T:2!B=?)K>2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T
M"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(D]D<W1U<"!M97II(&)U
M\FMA;6DZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S='(@
M(E9L87-T;F]S=&D@8G7R:WDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G
M<W1R(")-97IE<GD@;65Z:2!B=?)K86UI.B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$R-S0*;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R(")-;V)I
M;&[M('1E;&5F;VXB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I
M9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B2V5L='-K_2`H25-/
M+3@X-3DM,30I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(E-T^&5D
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC
M(@IM<V=S='(@(E-T^&5D;V%F<FEC:^$@<F5P=6)L:6MA(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D-E;G1R86P@175R;W!E86X@*$E3
M3RTX.#4Y+3(I(@IM<V=S='(@(E-T^&5D;V5V<F]P<VO]("A)4T\M.#@U.2TR
M*2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-CDY"FUS
M9VED(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(E!O9')O8FYO<W1I
M(&-E<G1I9FEKX71U(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV,3$*(RP@9G5Z>GD*;7-G:60@(D-E<G1I9FEC871E($]W;F5R(@IM
M<V=S='(@(E!O9')O8FYO<W1I(&-E<G1I9FEKX71U(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G:60@(D-E<G1I9FEC871E
M(%!O;&EC:65S(@IM<V=S='(@(E!O9&WM;FMY(&-E<G1I9FEKX71U(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`X"FUS9VED(")#:&%D(@IM<V=S='(@(LAA9"(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.38*;7-G:60@(D-H86YG92(*;7-G<W1R("):;>QN:70B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*(RP@9G5Z>GD*;7-G
M:60@(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(E;]8VAO>NT@;F%S
M=&%V96[M(%9AN65H;R!H97-L82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV-@IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H
M870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U
M<B`B"B)E;6%I;',N(@IM<V=S='(@(B(*(DYA<W1A=F5N[2!J;>EN82!A(&5M
M86EL;W;I(&%D<F5S>2X@5'ET;R!P;VQOOFMY(&QI9.D@=79I9.TL(&MD>;X@
M<VD@Z'1O=2`B"B)N96)O(&]D<&]V[61A:NT@;F$@5F&Y92!Z<'+A=GDN(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#
M:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T
M:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*;7-G:60@(D-H87(B"FUS
M9W-T<B`B6FYA:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB"FUS
M9W-T<B`B6FMO;G1?<F]L;W9A="!O9&MA>BXN+B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G
M:60@(D-H:6QE(@IM<V=S='(@(D-H:6QE(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B
M0VAI;F$B"FUS9W-T<B`BR.UN82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@P"FUS9VED(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS9W-T
M<B`BR.UNN71I;F$@>FIE9&YO9'6Y96[A("A'0C(S,3(I(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@
M*$)I9S4I(@IM<V=S='(@(E1R861IZ&[M(.CM;KET:6YA("A":6<U*2(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(D-H
M;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(EIV;VQT92!H97-L;R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C@*;7-G:60@(D-H;V]S
M92!A('5S97)N86UE(@IM<V=S='(@(EIV;VQT92!UOFEV871E;'-KZ2!J;>EN
M;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.3@*;7-G:60@(D-H;V]S
M92!H;W<@=&\@9&ES<&QA>2!D871E<SHB"FUS9W-T<B`B5GEB<F%T('IO8G)A
M>F5N[2!D871U;74Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y
M;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I(@IM<V=S='(@(E9Y8G)A="!T
M>7`@<W1Y;'4@<V5Z;F%M=2`H<')O(/AA>F5NZ2!S97IN86UY*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C@*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B5N%N;^AN
M[2!O<W1R;W8B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,N<&AP.C(Y-"!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z.#DS"B,L('!H<"UF;W)M870*;7-G:60@
M(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R(").
M96)Y;&$@;F%L97IE;F$@9&5F:6YI8V4@=/CM9'D@)7,N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*;7-G:60@(D-L96%R
M(@IM<V=S='(@(E9YZ&ES=&ET(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G
M<R(*;7-G<W1R(")6>>AI<W1I="!Z;F'H:WD@>B!-4T]F9FEC92(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,C@*(RP@9G5Z>GD*;7-G:60@(D-L96%R(%%U
M97)Y(@IM<V=S='(@(D]D<W1R86YI="!UOFEV871E;&4B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B3V1S=')A;NQN[2!UOFEV
M871E;&4Z("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC
M.C$Q"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(D]D<W1R86YI="!UOFEV
M871E;&4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`IM
M<V=I9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@(D]D<W1R86[L;NT@^F1A
M:OD@;R!UOFEV871E;&DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ-0HC+"!F=7IZ>0IM<V=I9"`B0VQE87)I;F<@3&%T92(*
M;7-G<W1R(")0;WID;NT@9.FYNR(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]M86EN=&5N86YC92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU
M92(*;7-G<W1R(")+;&EK;NQT92!P<F\@<&]K<F'H;W;A;NTB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#0*;7-G
M:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T<B`B0VQI8VMA=&5L;"!P
M^&5S($A45%`B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I;F1O=R(*
M;7-G<W1R("):87;X[70@;VMN;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C0T"FUS9VED(")#;&]U9',B"FUS9W-T<B`B6F%T8;YE;F\B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-@HC+"!F=7IZ>0IM
M<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(D]B;&'H;F\B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-PIM<V=I9"`B0VQO
M=61Y(@IM<V=S='(@(D]B;&'H;F\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#;V-O
M<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R(")+;VMO<V]VZ2!O<W1R;W9Y
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR,PIM<V=I9"`B
M0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R(")3:VQA<&YO=70@8F_H;NT@;&FY
M='4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(X"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G<W1R(")3
M:VQA<&YO=70@;VMR86IE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]L;VUB:6$B
M"FUS9W-T<B`B2V]L=6UB:64B"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X
M(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B"FUS
M9W-T<B`B0F%R=F$B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C
M=&EO;BYP:'`Z,S(T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T
M:6]N+G!H<#HS,C4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C4P,"!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C$T
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0Y
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4P
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8U
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8V
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@R
M"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B5OUB['(@8F%R978B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#0V"FUS9VED(")#;VQO=7(@
M<V5L96-T:6]N(@IM<V=S='(@(E!A;&5T82!B87)E=B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS
M.B(*;7-G<W1R(")3;&]U<&-E.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Y-#8*;7-G:60@(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B3N%Z=GD@
M<VQO=7!C92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C0*;7-G
M:60@(D-O;6EC<R(*;7-G<W1R(")+;VUI:W-Y(@H*(SH@861M:6XO8VUD<VAE
M;&PN<&AP.C(U"FUS9VED(")#;VUM86YD(@IM<V=S='(@(E#X[6MA>B(*"B,Z
M(&%D;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*
M;7-G<W1R(")0^.UK87IO=N$@:V]N>F]L82(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R(")0
M;WINX6UK82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-38V"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R(")/8F5C;ND@:FWI;F\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX-`IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R(")+;VUO<F]S
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S
M.0IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R(")&:7)M82(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(E!O
MZ.UT8>AE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y-PHC
M+"!F=7IZ>0IM<V=I9"`B0V]N9&ET:6]N(@IM<V=S='(@(E!O9&WM;FMY(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#D*;7-G:60@(D-O;F1I=&EO;G,B
M"FUS9W-T<B`B4&]D;>UN:WDB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HY
M-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*;7-G<W1R(")2
M;WID[6QY('8@;F%S=&%V96[M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$T,PIM<V=I9"`B0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$
M07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,U"B,L(&9U>GIY"FUS9VED(")#;VYF
M:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*;7-G<W1R(")*92!T^&5B82!A
M:W1U86QI>F]V870@;F%S=&%V96[M+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM
M<V=S='(@(DYA<W1A=FET("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHU,0IM<V=I9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R
M(")0;W1V<F1I="!H97-L;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O(@IM
M<V=S='(@(DMO;F=O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V]N9V\L(%1H92!$
M96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R(")+;VYG;RP@1&5M
M;VMR871I8VOA(')E<'5B;&EK82(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*
M;7-G<W1R(")3<&]J96[M('-E;&AA;&\N(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL
M960Z("(*;7-G<W1R(")3<&]J96[M('-E;&AA;&\Z("(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R
M969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")">6QO
M('IA;>UT;G5T;R!S<&]J96[M(',@=F7X96IN_6T@:VSMZ&]V_6T@<V5R=F5R
M96TN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDR"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(D)Y
M;&\@>F%M[71N=71O('-P;VIE;NT@<R!V9?AE:F[];2!K;.WH;W;];2!S97)V
M97)E;2X@1/EV;V0@.B`E<R`H)7,I(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HX-#4*;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F
M86EL960N(@IM<V=S='(@(E-E;&AA;&\@<W!O:F5N[2!S($944"!S97)V97)E
M;2XB"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`Q-`IM<V=I9"`B0V]N
M=&%C=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C4S"FUS9VED(")#;VYT86-T<R!W97)E('-U8V-E<W-F
M=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B2V]N
M=&%K='D@8GEL>2#Z<W#LN6[L('#X:63A;GD@9&\@5F&Y96AO(&%D<F5SX?AE
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<X"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O9B!<(B5S7"(B"FUS9W-T<B`B
M3V)S86@@=B`G)7,G(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M,CD@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S"FUS9VED(")#;VYT
M:6YU92(*;7-G<W1R(")0;VMR8>AO=F%T(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C8Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B
M0V]O:R!)<VQA;F1S(@IM<V=S='(@(D-O;VMO=GD@;W-T<F]V>2(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O:VEE(@IM<V=S='(@
M(DMO;.'H96LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B2V]P[7)O
M=F%T(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C@*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R
M(")3<&]J96[M('-E;&AA;&\Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM
M<V=S='(@(DMO<.UR;W9A="!V_6+L<B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B2V]S=&%R
M:6MA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R
M(")0;V+X9;[M('-L;VYO=FEN>2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.CDW-@IM<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE
M<W-A9V4N(@IM<V=S='(@(EIP<N%V=2!N96QZ92"Y:69R;W9A="!P;VUO8^T@
M4$=0+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P-3,*
M;7-G:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+B(*;7-G<W1R("):
M<'+A=G4@;F5L>F4@<&]D97!S870@<&]M;V/M(%!'4"XB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@;F]T
M(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(EIP<N%V=2!N96QZ
M92"Y:69R;W9A="!P;VUO8^T@4R]-24U%+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L9"!N;W0@4R]-24U%
M('-I9VX@;65S<V%G92XB"FUS9W-T<B`B6G!RX79U(&YE;'IE('!O9&5P<V%T
M('!O;6]C[2!3+TU)344N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R(").96QZ92!P^&ED870@
M:V]N=&%K="X@)7,B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z.38@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ,C$*;7-G:60@
M(D-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(").96QZ
M92!S92!P^&EP;VII="!K($Q$05`@<V5R=F5R=2XB"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-#4W"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@8FEN
M9"!T;R!L9&%P('-E<G9E<B(*;7-G<W1R(").96QZ92!S92!P^&EP;VII="!K
M($Q$05`@<V5R=F5R=2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C$U-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@(DYE;'IE('IK
M;VYT<F]L;W9A="#ZZ&5T+B`E<R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HT-#$*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O(&QD
M87`@<V5R=F5R(@IM<V=S='(@(DYE;'IE('-E('#X:7!O:FET(&L@4TU"('-E
M<G9E<G4N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V
M97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS9W-T<B`B3F5L>F4@<V4@</AI
M<&]J:70@:R!S97)V97)U("<E<R<@<&]M;V/M($944#H@)7,B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<R(*;7-G<W1R(").96QZ92!V>71V;_AI="!D:7-T<FEB=>AN
M[2!S97IN86TN("5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,3$R-0IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N(@IM
M<V=S='(@(DYE;'IE(&1EN6EF<F]V870@4$=0(&1A=&$N(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,C(*;7-G:60@(D-O=6QD(&YO
M="!D96-R>7!T(%,O34E-12!D871A+B(*;7-G<W1R(").96QZ92!D9;EI9G)O
M=F%T(%,O34E-12!D871A+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,C0V"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B3F5L>F4@<VUA
M>F%T(&MO;G1A:W0N("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B
M3F5L>F4@<VUA>F%T(&1I<W1R:6)UZ&[M('-E>FYA;2X@)7,B"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HS.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="!<
M(B5S7"(N(@IM<V=S='(@(DYE;'IE('-M87IA="!N87-T879O=F%C[2!S:W)I
M<'0@<')O(&%K='5A;&EZ86-I("<E<R<N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HS.#$@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z.34S"FUS9VED(")#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I
M<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T<B`B3F5L>F4@>FII<W1I
M="!E+6UA:6QO=F]U(&%D<F5S=2!P^.UJ96UC92XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U
M;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B
M3F5L>F4@>NUS:V%T(/IP;&[](&%D<F5SX?@N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*;7-G:60@(D-O=6QD
M(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T
M<B`B3F5L>F4@>NUS:V%T(/IP;&[](&1I<W1R:6)UZ&[M('-E>FYA;2XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T
M-@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F
M(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS9W-T<B`B3F5L>F4@>NUS:V%T(/IP
M;&[]('-E>FYA;2!D:7-T<FEB=>AN[6-H('-E>FYA;?DN(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G
M>2YP:'`Z-C@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E<UPB+B(*;7-G
M<W1R(")3=')A=&5G:64@)R5S)R!J92!N961O<W1U<&[A+B(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HQ,3`*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB
M+B(*;7-G<W1R(").96QZ92!Z86QOOFET("<E<R<N(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S$Y"FUS9VED(")#;W5L9"!N;W0@;V)T
M86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R(").
M96QZ92!Z[7-K870@=F7X96IN_2!K;.WH('H@:VSMZ&]VZ6AO('-E<G9E<G4N
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*
M;7-G<W1R(").96QZ92!O=&5V^.UT("<E<R<@:R!ZX7!I<W4N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R
M(").96QZ92!O=&5V^.UT("5S+B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC
M92]-86EN=&5N86YC92YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S
M='(@(DYE;'IE('!R;W;I<W0@;W!E<F%C92#Z9'*^8GD@<')O(&UO9'5L("5S
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G
M<W1R(").96QZ92!O=&5V^.UT(&%D<F5SX?@@)R5S)RXB"@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$Q(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HQ-#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C(S-R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#<X
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HU,38@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z-C4V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HV.3D*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R96%C:"!T
M:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(DYE;'IE(&AL961A="!V($Q$05`@
M<V5R=F5R=2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(S
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS
M9W-T<B`B3F5L>F4@Z.US="`E<RXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HX-0IM<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S
M=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T
M:&4@(@HB9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C
M;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T
M:&5R(&AE;'`N(@IM<V=S='(@(B(*(DYE;'IE(')E<V5T;W9A="!H97-L;R!P
M<F\@9&%NZ6AO('6^:79A=&5L92X@5KEE8VAN>2!N96)O(&[L:W1E<ND@>B`B
M"B)P;V1R;V)N;W-T[2!N96)Y;'D@<W!RX79N["!Z863A;GDN(%IK=7-T92!T
M;R!Z;F]V=2!N96)O('!O:W5D('!O=/AE8G5J971E("(*(G!O;6]C+"!K;VYT
M86MT=6IT92!S<'+A=F-E('-Y<W3I;74N(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,T,`HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS-S<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S@S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,X.0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#
M3"(*;7-G<W1R(").96QZ92!Z[7-K870@04-,(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-S0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,B
M"FUS9W-T<B`B3F5L>F4@>NUS:V%T(&%D<F5SX?@N("5S(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<R(*;7-G<W1R(").96QZ92!Z[7-K870@9&ES=')I8G7H;NT@
M<V5Z;F%M+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@(DYE
M;'IE('KM<VMA="!D:7-T<FEB=>AN[2!S97IN86UY+B`E<R(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"FUS9VED(")#;W5L9"!N
M;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@(DYE
M;'IE('KM<VMA="!S8VAO<&YO<W1I('-E<G9E<G4B"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C4T"FUS9VED(")#;W5L9"!N;W0@<F5V97)T(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(DYE;'IE('#X97!N;W5T(&MO;F9I9W5R86-I
M+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`B3F5L
M>F4@;V1S=')A;G0@)R5S)RXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R(").96QZ92!U;&^^:70@:V]N9FEG=7)A
M8VD@<')O("5S+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,R!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U;&0@;F]T('-A=F4@
M82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R(").96QZ92!U;&^^:70@
M>N%L;[YN[2!K;VYF:6=U<F%C:2XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S
M879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B3F5L>F4@
M=6QOOFET('KA;&^^;NT@:V]N9FEG=7)A8VD@)7,N(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z.34*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S
M7"(N(@IM<V=S='(@(DYE;'IE('5L;[YI="!N87-T879O=F%C[2!S8W)I<'0@
M<')O(&%K='5A;&EZ86-I(&1O.B`G)7,G+B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A
M=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@
M(DYE;'IE('5L;[YI="!ZX6QO:'4@:V]N9FEG=7)AZ&[M:&\@<V]U8F]R=2`E
M<RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<U"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG
M=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H
M92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C
M;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*;7-G<W1R("(B
M"B).96QZ92!Z87!S870N($WYOF5T92!P;W6^[70@<VMR:7!T('!R;R!A:W1U
M86QI>F%C:2!N96)O(')UZ&[L('IK;W#M<F]V870@(@HB;NV^92!U=F5D96[]
M(&OS9"!D;R`E<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C$T,PIM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N
M(@IM<V=S='(@(DYE;'IE(&AL961A="!V($Q$05`@<V5R=F5R=2XB"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDO8V]P>2YP:'`Z.#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R(").96QZ92!O9'!O
M:FET("<E<R<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('5P9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R(").96QZ92!A:W1U86QI>F]V
M870@:V]N=&%K="X@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(").
M96QZ92!A:W1U86QI>F]V870@9&ES=')I8G7H;NT@<V5Z;F%M+B`E<R(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB
M)7-<(CH@)7,B"FUS9W-T<B`B3F5L>F4@=6QOOFET(&MO;F9I9W5R86-I('!R
M;R`G)7,G.B`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C8*;7-G
M:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S
M=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(B(*(DYE;'IE(&YA
M;.EZ="!B;^AN[2!L:;ET=2!P<F\@36]Z:6QL=2X@4')O<^UM('#X97-V[&3H
M=&4@<V4L(+YE(&IE(&]T97;X96[A+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T:&4@9F]L;&]W
M:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S(@IM<V=S='(@
M(E6^:79A=&5L:2`G)7,G(&YE;'IE('!O<VMY=&YO=70@;N%S;&5D=6KM8^T@
M<'+A=F$@<')O('-L;[YK=2`G)7,G.B`E<R(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T,3D*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R(")/
M9'!OZ.UT86[]('1E>'0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4V.0IM<V=I9"`B0V]U;G1R>2(*;7-G<W1R("):96WL(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W,PIM<V=I9"`B0V]U<G-E<R(*
M;7-G<W1R(")6>77H;W9A8^T@</AE9&WL='DB"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.CDV"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*;7-G:60@
M(D-R96%T92(*;7-G<W1R(")6>71V;_AI="(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B0W)E
M871E(&$@;&EN:R(*;7-G<W1R(")6>71V;_AI="!O9&MA>B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.30*;7-G:60@(D-R96%T
M92!A(&YE=R!O;F4B"FUS9W-T<B`B5GET=F_X:70@;F]V;W4B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B0W)E
M871E('-U8B!F;VQD97)S(@IM<V=S='(@(E9Y='9O^&ET('!O9'-L;[YK>2(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C0P"FUS9VED(")#
M<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(E1V^7)C92!P<N%V(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(S,`IM<V=I9"`B0W)E9&ET(&-A
M<F0@;G5M8F5R(@IM<V=S='(@(LCM<VQO(&MR961I=&[M(&MA<G1Y(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-SD*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B0VAO<G9A='-K;R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B2W5B82(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HR-@HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="`T
M(%!H87-E<R(*;7-G<W1R(")!:W1UX6QN[2!FX7IE(@H*(SH@861M:6XO<V5S
M<VEO;G,N<&AP.C0X"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(%-E<W-I;VYS
M(@IM<V=S='(@(E1V^7)C92!P<N%V(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP
M.C,@;&EB+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I;64B
M"FUS9W-T<B`B06MT=>%L;NT@Z&%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4T"FUS9VED(")#=7)R96YT
M(%523"!I<R(*;7-G<W1R(")!:W1UX6QN[2!54DP@:F4B"@HC.B!A9&UI;B]S
M97-S:6]N<RYP:'`Z,S,*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@57-E<G,B
M"FUS9W-T<B`B06MT=>%L;NT@9N%Z92(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C4*;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R(")!:W1UX6QN
M[2!P;^AA<^TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C<U
M"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S='(@(D%K='7A;&[M
M('!O9&WM;FMY.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@(DYY
M;NQJN>T@<W1Y;"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N
M(&QO9V]N('1O("5S+B(*;7-G<W1R(").87-T879E;NT@^FMO;/D@<')O=N%D
M[&[]8V@@</AI('#X:6ALX;EE;NT@9&\@)7,N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED(")#
M=70B"FUS9W-T<B`B5GES=/AI:&YO=70B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,U"FUS9VED(")#=70@<V5L96-T:6]N
M(@IM<V=S='(@(E9Y<W3X:6AN;W5T(';]8NQR(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I
M9"`B0WEP<G5S(@IM<V=S='(@(DMY<'(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X,@IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`B07IB
M=6MA("A+3TDX+5(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G
M:60@(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(D%Z8G5K82`H
M5VEN9&]W<RTQ,C4Q*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@T"FUS
M9VED(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"FUS9W-T<B`B07IB
M=6MA+U5K<F%J:6YA("A+3TDX+54I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WIE
M8V@@4F5P=6)L:6,B"FUS9W-T<B`BR&5S:^$@<F5P=6)L:6MA(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,2!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHU,`IM<V=I9"`B1$0B"FUS9W-T<B`B1$0B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@Q"FUS9VED("(B"B)$4TX@*'-E
M92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B
M87-E+F1B+FEN=')O+61S;BYP:'`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3D*;7-G:60@(D1A:6QY
M(@IM<V=S='(@(D1E;F[L(@H*(SH@861M:6XO9&%T871R964N<&AP.C8U"FUS
M9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@(D1A=&%4<F5E('!R;VAL
M[;YEZ"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-SD*;7-G:60@
M(D1A=&%B87-E($QO;VMU<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S.3D*;7-G:60@(D1A=&4B"FUS9W-T<B`B1&%T=6TB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T
M92!296-E:79E9"(*;7-G<W1R(")0^&EJ871O(&1N92(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(X,#<*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM
M<V=S='(@(E;]8NQR(&1A='5M=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR.3(@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,R,@IM
M<V=I9"`B1&%Y(@IM<V=S='(@(D1E;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@IM<V=I9"`B1&5?;&5T
M92!#;VQU;6XB"FUS9W-T<B`B4VUA7WIA="!S;&]U<&5C(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M
M8F5R(@IM<V=S='(@(E!R;W-I;F5C(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I9"`B1&5C:6UA
M;"!N=6UB97)S(@IM<V=S='(@(LCM<VQA(&1E<^UT:V]VZ2!S;W5S=&%V>2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C`*
M;7-G:60@(D1E8W)E87-E($EN9&5N="(*;7-G<W1R("):;65NN6ET(&]D<V%Z
M96[M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ.#<@;&EB
M+W!R969S+G!H<#HQ,3<*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B26UP;&EC
M:71N[2(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C<W"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(DEM<&QI8VET
M;NT@8F%R=F$B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP
M.CDQ"FUS9VED(")$969A=6QT($ED96YT:71Y(@IM<V=S='(@(DEM<&QI8VET
M;NT@:61E;G1I=&$B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C<*(RP@
M9G5Z>GD*;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`B26UP;&EC:71N
M[2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B1&5F:6YI
M=&EO;G,B"FUS9W-T<B`B1&5F:6YI8V4B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C<Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(V"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z-#(R(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z-#,Y"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S8@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW,`HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.CDS('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$V
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,Y('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3@R"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHW,R!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3@*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$P('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"FUS9VED(")$96QE=&4B"FUS9W-T<B`B
M4VUA>F%T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,R"B,L(&9U>GIY"FUS9VED(")$96QE=&4@0V5L;"(*
M;7-G<W1R(")3;6%Z870@8G7R:W4B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y
M.2!A9&UI;B]G<F]U<',N<&AP.C(R-PIM<V=I9"`B1&5L971E($=R;W5P(@IM
M<V=S='(@(E-M87IA="!S:W5P:6YU(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C0Y"B,L(&9U>GIY"FUS9VED(")$96QE=&4@3&]G(@IM<V=S
M='(@(E-M87IA="#XX61E:R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z-S<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#$*;7-G
M:60@(D1E;&5T92!097)M:7-S:6]N(@IM<V=S='(@(E-M87IA="!P<N%V82(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDS"FUS
M9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(E-M87IA
M="!A('9YZ&ES=&ET('IP<N%V>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3<*;7-G:60@(D1E;&5T92!C96QL
M(@IM<V=S='(@(E-M87IA="!B=?)K=2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!C
M;VQU;6XB"FUS9W-T<B`B4VUA>F%T('-L;W5P96,B"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T
M92!T96UP;&%T92(*;7-G<W1R(")3;6%Z870@97AI<W1U:NUC[2!A;'1E<FYA
M=&EV;NT@=GIO<B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M-#(Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES
M<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R(")3;6%Z870@<'+A=F$@<')O("<E
M<R<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R-`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O
M<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(E-M
M87IA="!P<N%V82!A('!O9'!RX79A('!R;R`G)7,G/R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*;7-G:60@
M(D1E;&5T92!R;W<B"FUS9W-T<B`B4VUA>F%T(/CA9&5K(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V1E;&5T96ED96YT:71Y+FEN8SHQ-0IM<V=I9"`B1&5L971E
M('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@(E-M87IA="!V>6)R86YO=2CI
M*2!I9&5N=&ET=2AY*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E('1H92!C=7)R
M96YT(&-O;'5M;B(*;7-G<W1R(")3;6%Z870@<V]UZ&%S;OT@<VQO=7!E8R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV,PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O=R(*;7-G<W1R
M(")3;6%Z870@<V]UZ&%S;OT@^.%D96LB"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HS-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E
M9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(DMO;F9I
M9W5R8>AN[2!S8W)I<'0@<')O(&%K='5A;&EZ86-I("<E<R<@8GEL('-M87KA
M;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4V,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4Y-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR,C$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C4S"FUS9VED(")$96QI=F5R>2!T:6UE(@IM<V=S
M='(@(LAA<R!D;W)UZ&5N[2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1E;FUA<FLB
M"FUS9W-T<B`B1.%N<VMO(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@
M(E!O<'-A="!P<F]B;.EM(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.3,X('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S`*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(E!O<&ES(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.34*;7-G:60@(D1E=&%I;',@
M*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B4&]D<F]B;F]S
M=&D@*'1A:^D@=B!L;V<@<V]U8F]R=2!(;W)D92DZ(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ.3D*;7-G:60@(D1E=&%I;',@:&%V92!B965N
M(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(E!O9')O
M8FYO<W1I(&)Y;'D@>F%Z;F%M96[A;GD@9&\@;&]G('-O=6)O<G4@<')O(&%D
M;6EN:7-T<N%T;W)A+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M,3D*;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S='(@(E;]=F]J(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,3<*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R
M(")2;W-N_2!B;V0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-`IM<V=I
M9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")2;W-N_2!B
M;V0@>F$@<&]S;&5D;NT@:&]D:6YU.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C(W"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R(")2
M;W-N_2!B;V0Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT(@IM
M<V=S='(@(E-M['(@>B!L979A(&1O<')A=F$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@
M<FEG:'0@=&\@;&5F="(*;7-G<W1R(")3;>QR('H@<')A=F$@9&]L979A(@H*
M(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*
M;7-G<W1R(")!9')E<^'X(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V
M-@IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R("):;V)R
M87II="`R-"UH;V1I;F]V_2#H87,_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDW"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B36^^;F]S
M=&D@>F]B<F%Z96[M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.CDV"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T
M(@IM<V=S='(@(EIO8G)A>FET('#X961P;W;L[R`H5$%&*2(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z.#4*;7-G:60@(D1I<W!L87D@9F]R96-A<W0@*%1!
M1BDB"FUS9W-T<B`B6F]B<F%Z:70@</AE9'!O=NSO("A4048I(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-PIM<V=I9"`B1&ES<&QA>2!F;W)M
M870B"FUS9W-T<B`B1F]R;>%T('IO8G)A>F5N[2(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O341.+G!H<#HQ.3`*;7-G:60@(D1I<W!O<VET:6]N($YO=&EF
M:6-A=&EO;B(*;7-G<W1R(")$:7-P;WIIZ&[M('5P;WIO<F[L;NTB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Y"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R(")$:FEB;W5T:2(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R"FUS9VED(")$;R!N
M;W0@9&5L971E(@IM<V=S='(@(DYE<VUA>F%T(@H*(SH@<V5R=FEC97,O;6%I
M;G1E;F%N8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S
M(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R(").97#X:7-T=7!O=F%T('#X[6UO
M(&1O(&UA:6YT96YA;F-E+G!H<"(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN
M9F\N:6YC.C$R('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$R"FUS9VED
M(")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_
M($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(B(*(D]B<V%H=6IE
M('!R=F[M(/CA9&5K(&[A>F5V('-L;W5P8_D_(%!O:W5D(&%N;RP@>F&Y:W)T
M;NQT92!T96YT;R!RX6UEZ&5K.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1O;6EN
M:6-A(@IM<V=S='(@(D1O;6EN:6MA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&]M
M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(D1O;6EN:6OA;G-KX2!R97!U8FQI
M:V$B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDV"FUS9VED(")$
M;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T-`IM<V=I9"`B
M1&]W;FQO860B"FUS9W-T<B`B4W1AOF5N[2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.C@T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$
M;W=N;&]A9"`E<R(*;7-G<W1R(")3=&&^96[M("5S(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D(&-O
M;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`B4W1A:&YO=70@
M9V5N97)O=F%N;W4@:V]N9FEG=7)A8VD@:F%K;R!02%`@<VMR:7!T+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#<*;7-G:60@(D1R;W`@9&]W
M;B!L:7-T(@IM<V=S='(@(E)O;&5T;W;]('-E>FYA;2(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B1')U9W,B"FUS9W-T<B`B1')O9WDB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@
M(D4M36%I;"(*;7-G<W1R(")%+6UA:6PB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM=&\M4TU3
M(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T
M:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G
M:60@(D524B(*;7-G<W1R(")%4E(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%8W5A
M9&]R(@IM<V=S='(@(D5K=N%D;W(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C,R-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$X,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M-S(*(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I
M="(*;7-G<W1R(")5<')A=FET(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+U5)+G!H<#HU,"!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED
M(")%9&ET($)L;V-K(@IM<V=S='(@(E5P<F%V:70@8FQO:R(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,3DX(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"FUS9VED(")%
M9&ET($=R;W5P(@IM<V=S='(@(E5P<F%V:70@<VMU<&EN=2(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z-S8@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HQ,#`*;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R
M(")5<')A=FET('!RX79A(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP
M.C(S-PIM<V=I9"`B161I="!097)M:7-S:6]N<R(*;7-G<W1R(")5<')A=FET
M('!RX79A(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G
M<W1R(")5<')A=FET('!RX79A('!R;R`E<R(*"B,Z('1E;7!L871E<R]P<F5F
M<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@
M(E5P<F%V:70@;6^^;F]S=&D@<')O.B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,S8W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%
M9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B57!R879I="!P
M<N%V82!P<F\@)7,B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T
M"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S
M(@IM<V=S='(@(E5P<F%V:70@<'+A=F$@<')O("5S(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,U"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B5OUU
M:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*;7-G<W1R(")%9WEP="(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"B,L('!H<"UF;W)M
M870*;7-G:60@(D5I=&AE<B!E;F%B;&4@:70@=&AE;CH@)7,L(&]R('5S92!T
M:&4@8F%S:6,@2%1-3"!V97)S:6]N.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`W"FUS9VED(")%;"!386QV861O<B(*;7-G<W1R(")%;"!386QV861O
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHT,PIM<V=I9"`B16QE;65N="XN+B(*;7-G<W1R(")0<G9E:RXN
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`Y"FUS9VED(")%;2(*;7-G<W1R(")%;2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@V.0IM<V=I9"`B16UA:6PB"FUS9W-T<B`B16UA:6PB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-2!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V5D:70N:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z-C@*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T
M<B`B16UA:6QO=N$@861R97-A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3DV,PIM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM
M<V=S='(@(D5M86EL;W;I(&%D<F5S>2!S92!M=7/M('-H;V1O=F%T+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.#D*;7-G:60@(D5M86EL('=I
M=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(D5M86EL(',@<&]T=G)Z96[M;2(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ
M"FUS9VED(")%;6%I;"UT;RU335,@1V%T97=A>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDX"FUS9VED
M(")%;6]T:6-O;G,B"FUS9W-T<B`B26MO;FMY(',@96UO8V5M:2(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM
M<V=I9"`B16UP='D@;65S<V%G92XB"FUS9W-T<B`B4'+A>F1NX2!Z<'+A=F$N
M(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(T,R!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HV-C(@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C<P-0HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C$U,`IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R(")0<N%Z9&[](';]
M<VQE9&5K+B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ
M,3,*;7-G:60@(D5M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R(")0<N%Z9&[]
M('1E<FWM;B!P<F\@=GEH;&5DX7;A;NTB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-30S"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F
M<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R(")0;W9O;&ET
M('9K;.%DX6[M(&]B<F%Z:_D@>B!F;W1O(&=A;&5R:>T@9&\@=&5X='4_(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q.`IM<V=I9"`B16YA8FQE(')I
M9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B06MT:79O=F%T('!R
M87;I(&ML:6MN=73M('!R;R!K;VYT97AT;W;I(&UE;G4_(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.#$Q"FUS9VED(")%;F0@>65A<B(*;7-G<W1R(")+;VYE8R!R;VMU(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM
M<V=I9"`B16YL87)G92!%9&ET;W(B"FUS9W-T<B`B6G;L=+EI="!E9&ET;W(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(Q"FUS9VED("(B"B)%;G1E
M<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D
M(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@
M)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@HB
M6F%D96IT92!B97IP9>AN;W-T;NT@;W3A>FMU+"!N82!K=&5R;W4@8G5D971E
M(&UU<V5T(&]D<&]V[&3L="!P;VMU9"!S:2`B"B)B=61E=&4@8VAT[70@<F5S
M971O=F%T('-VZ2!H97-L;RP@;F%P^"X@)TIA:^D@:F4@:FWI;F\@5F&Y96AO
M('!S83\G.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE(&EM86=E(%52
M3"!H97)E(@IM<V=S='(@(EID92!V;&^^:70@55),(&]B<N%Z:W4B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DQ"FUS9VED
M(")%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-@IM<V=I9"`B17%U871O<FEA;"!'=6EN96$B"FUS9W-T<B`B4F]V;NUK
M;W;A($=U:6YE82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T
M<B`B17)I=')E82(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C0U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HU-0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,V('-E<G9I8V5S+W!O<G1A
M;"]I;F1E>"YP:'`Z.#(*;7-G:60@(D5R<F]R(@IM<V=S='(@(D-H>6)A(@H*
M(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C,*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E
M<R(*;7-G<W1R(").87-T86QA(&-H>6)A('#X:2!O9&5S[6SA;NT@;V1P;W;L
M9&DZ("5S+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C<R"B,L
M('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R
M.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HX,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I
M;F<@<WEN8R!L;V<Z("5S(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@</AI(&]D
M97/M;.%N[2!O9'!O=NQD:3H@)7,N(@H*(SH@9G)A;65W;W)K+U1E;7!L871E
M+U1E;7!L871E+G!H<#HT-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS9W-T<B`B3F%S=&%L82!C
M:'EB82!P^&D@;V1E<^ULX6[M(&]D<&]V[&1I.B`E<RXB"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<R(*;7-G<W1R(").
M87-T86QA(&-H>6)A('#X:2!O9&5S[6SA;NT@;V1P;W;L9&DZ("5S+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M-0IM<V=I9"`B17)R;W(@=VET:"!E;6%I;"!M97-S86=E+B(*;7-G<W1R(").
M87-T86QA(&-H>6)A(',@<&^Y=&]V;NT@>G!RX79O=2XB"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z,30R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O
M<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B0VAY8F$@</AI('KA<&ES=2`G
M)7,G+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B17-T
M;VYS:V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%=&AI;W!I82(*;7-G<W1R(")%
M=&EO<&EE(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS9VED(")%
M=&AN:6,B"FUS9W-T<B`B171N:6-KZ2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(D5V<F]P82(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD*;7-G:60@(D5V97)Y(#$U
M(&UI;G5T97,B"FUS9W-T<B`B2V&^9/UC:"`Q-2!M:6YU="(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.#D*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*
M;7-G<W1R(")+8;YDZ2`R(&UI;G5T>2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS,S8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X-PIM<V=I9"`B179E
M<GD@,S`@<V5C;VYD<R(*;7-G<W1R(")+8;YD_6-H(#,P('-E:W5N9"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S@@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,Y,`IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(DMAOF3]
M8V@@-2!M:6YU="(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N
M86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S='(@(DMAOF3I
M('#X:6ALX;EE;NT@9&\@<WES=.EM=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-#`*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R(")+8;YD
M;W4@</EL(&AO9&EN=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S<@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X.`IM<V=I9"`B179E<GD@;6EN=71E
M(@IM<V=S='(@(DMAOF1O=2!M:6YU='4B"@HC.B!T96UP;&%T97,O9&%T82]D
M871E;6%P+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V86QU97,Z(@IM<V=S='(@
M(E9Z;W)O=OT@</CM:VQA9"!H;V1N;W0Z(@H*(SH@861M:6XO<&AP<VAE;&PN
M<&AP.C@Q(&%D;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3(W"FUS9VED(")%>&5C=71E(@IM<V=S='(@(E!R;W;I<W0B"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT-S4*;7-G:60@(D5X
M<&%N9"(*;7-G<W1R(")2;WIV:6YO=70B"@HC.B!T96UP;&%T97,O<&]R=&%L
M+W-I9&5B87(N:6YC.C,R"FUS9VED(")%>'!A;F0@4VED96)A<B(*;7-G<W1R
M(")2;WIB86QI="!B;^AN[2!L:;ET=2(*"B,Z(&9R86UE=V]R:R]344PO4U%,
M+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R
M(")/Z&5KX7;A;F$@)RDG(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R
M9',N<&AP.C$W-0IM<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E
M9"!S96%R8V@@=&5R;2(*;7-G<W1R(")/Z&5KX7;A;F\@<V%M;W-T871NZ2!S
M;&]V;R!N96)O(&AL961A;OT@=&5R;>UN('8@=79O>F]V:^%C:"(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B17AP:7)A
M=&EO;B!$871E(@IM<V=S='(@(D1A='5M('!R;R!K;VYE8R!P;&%T;F]S=&DB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-@IM<V=I
M9"`B17AP;VYE;G0B"FUS9W-T<B`B17AP;VYE;G0B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Q"FUS9VED(")&
M1R!#;VQO<B(*;7-G<W1R(")"87)V82!P;W#X963M(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$W-PIM<V=I9"`B1E10('5P;&]A9"!O9B!S971U<"(*
M;7-G<W1R(")0^&5N;W,@:V]N9FEG=7)A8V4@<&]M;V/M($944"(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]S<6PN<&AP.C(Q-@IM<V=I9"`B1F%I;&5D
M(')E=')I979I;F<@<')E9F5R96YC97,N(@IM<V=S='(@(E-E;&AA;&\@>NUS
M:^%N[2!M;[YN;W-T[2XB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY.`IM<V=I
M9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@
M(DYE;'IE('-E('#X:7!O:FET(&L@3$1!4"!S97)V97)U+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O
M;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`B3F5L>F4@<V4@</AI<&]J
M:70@:R!334(@<V5R=F5R=2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C8X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!F
M<F]M(%PB)7-<(BXB"FUS9W-T<B`B4V5L:&%L;R!K;W#M<F]VX6[M('H@7"(E
M<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-CDQ"B,L('!H
M<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS
M9W-T<B`B4V5L:&%L;R!K;W#M<F]VX6[M(&1O(%PB)7-<(BXB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@W"FUS9VED(")&86EL960@=&\@
M8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(E-E;&AA;&\@
M>F%L;[YE;NT@;F]VZ6AO(%-!4TP@<W!O:F5N[2XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C0Y-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C<R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@;6]V92!T;R!<
M(B5S7"(N(@IM<V=S='(@(E-E;&AA;&\@</AE<W5N=73M(&1O(%PB)7-<(BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V,0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G
M<W1R(")396QH86QO('#X97-U;G5T[2!D;R!<(B5S7"(N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A:7(B
M"FUS9W-T<B`B1&]B<NDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&86QK;&%N9"!)
M<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B1F%L:VQA;F1S:^D@;W-T<F]V
M>2`H36%L=FEN>2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&87)O92!)<VQA;F1S
M(@IM<V=S='(@(D9A<FEJ<VOI(&]S=')O=GDB"@HC.B!F<F%M97=O<FLO0TQ)
M+T-,22YP:'`Z,C,X"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`B6N%V
M8;YNX2!C:'EB83HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3@W"FUS9VED(")&87@B"FUS9W-T<B`B1F%X(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T.0HC+"!F=7IZ>0IM<V=I9"`B1F%X
M97,B"FUS9W-T<B`B1F%X(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(MIN;W(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R,`IM<V=I9"`B1F5E;',@3&EK
M92(*;7-G<W1R(")#[71I="!S92!J86MO(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(S,0IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@
M(D/M=&ET('-E(&IA:V\Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S='(@(D1R
M;V)NZ2!P^&5HX?)K>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(P"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@
M(D1R;V)NZ2!S;NQH;W;I('#X96CA\FMY(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3DT-`IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(DUA
M=&EC92!P;VQE(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S-`IM
M<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S,S.`IM<V=I9"`B1FEG;&5T(&9O;G0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEJ:2(*;7-G<W1R(")&:6II(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS
M9VED(")&:6QE(@IM<V=S='(@(G-O=6)O<B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z
M("5S(&9I;&4B"FUS9W-T<B`B4&_H970@<V]U8F]R^3H@)7,@<V]U8F]R(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`B4&_H970@<V]U
M8F]R^3H@)7,@<V]U8F]R^2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT,#<*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R(")3<'+A=F-E('-O
M=6)O<ODB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C8S(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-0IM<V=I9"`B
M1FEL92!.86UE(@IM<V=S='(@(D[A>F5V('-O=6)O<G4B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.3DU"FUS9VED(")&:6QE('-E;&5C=&EO;B(*
M;7-G<W1R(")6_6+L<B!S;W5B;W)U(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,30X-@IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`B4/AE;NES
M="!S;W5B;W(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX
M-3D*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R
M(")0^&5N;W,@<V]U8F]R^2!N96[M('!O9'!O<F]VX6XN(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C@Y"FUS9VED(")&:6QT97)S(@IM<V=S='(@
M(D9I;'1R>2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`B
M1FEN<VMO(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V-@IM<V=I9"`B1FER
M<W0@2&%L9B(*;7-G<W1R(")0<G9N[2!P;VQO=FEN82(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I
M<G-T(%%U87)T97(B"FUS9W-T<B`B4')V;NT@Z'1V<G1I;F$B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4V"FUS9VED(")&
M:7@@<F%T:6\B"FUS9W-T<B`B4&5V;ND@;>SX[71K;R(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S$*;7-G:60@(D9L:7`B
M"FUS9W-T<B`B4/AE:&]D:70B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R
M(")0;&]V;W5C[2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B36QH82(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C,T(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HQ,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O
M97,@;F]T(&5X:7-T(@IM<V=S='(@(E-L;[YK82`E<R!N965X:7-T=6IE(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM
M<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R(")"87)V82!P[7-M82(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R(")*
M[61L;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R;W=S97)S('1H870@9&]N
M)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B4')O('!R;VAL[;YEZ&4@;F5P
M;V1P;W)U:NUC[2!O8G+A>FMY(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,S0*;7-G:60@(D9O<F5C87-T("A4048I(@IM<V=S='(@(E#X961P;W;L[R`H
M5$%&*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW.0IM<V=I
M9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F
M;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G
M92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(*
M;7-G<W1R("(B"B)0^&5D<&]V[.\@<&_H87/M('!R;R!D;GD@*'!O>F[A;6MA
M.B!P^&5D<&]V[.\@:F4@<')O(&1N>2!I(&YO8VD[('1O=&\@;?F^92`B"B)V
M>71V;_AI="!P;VWL<F[L(&]B<^%H;/T@<V5Z;F%M+B(*"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z,3`R"FUS9VED(")&;W)G;W0@>6]U<B!P87-S
M=V]R9#\B"FUS9W-T<B`B6F%P;VUN[&QI(&IS=&4@5F&Y92!H97-L;S\B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8R"FUS9VED(")&;W)M<R(*
M;7-G<W1R(")&;W)M=6SA^&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,C$*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`BJ73L<W3M(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T
M<B`B5'EP(+ET['-T[2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM
M<V=I9"`B1F]R='5N97,B"FUS9W-T<B`BJ73L<W3M(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,Y"FUS9VED(")&;W)T=6YE<R`R(@IM<V=S='(@(JET
M['-T[2`R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U,PIM<V=I
M9"`B1F]R=6US(@IM<V=S='(@(D;S<F$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3`Y"FUS9VED(")&;W)W87)D<R(*;7-G<W1R(")0^&5P;W-L
MX6[M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`B4.$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S"FUS9VED(")&<F%M
M97,B"FUS9W-T<B`B4N%M>2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92(*
M;7-G<W1R(")&<F%N8VEE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R(")&
M<F%N8VEE+"!M971R;W!O;&ET;NTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N
M8V@@1W5I86YA(@IM<V=S='(@(D9R86YC;W5S:^$@1W5A:>%N82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDX"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(D9R86YC
M;W5S:^$@4&]L>6[I<VEE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@
M4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B1G)A;F-O=7-KX2!J:;YN
M[2!T97)I=&]R:6$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S='(@(D]D(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T."!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S8P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HT,#8*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R(")/9"(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"FUS9VED(")&=6QL($1E<V-R
M:7!T:6]N(@IM<V=S='(@(E!O9')O8F[]('!O<&ES(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U
M;&P@36]O;B(*;7-G<W1R("+:<&QN[&LB"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV,`IM
M<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(D-E;.D@:FWI;F\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<S"FUS9VED(")'86)O;B(*;7-G<W1R(")'86)O;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM
M<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B1V%L
M97)I92!P<F\@=OUB['(@;V)RX7IK^2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L
M;&5R>3HB"FUS9W-T<B`B1V%L97)I93HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'
M86UB:6$B"FUS9W-T<B`B1V%M8FEE(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#;VYF
M:6=U<F%T:6]N(@IM<V=S='(@(E9Y='9O^&ET("5S(&MO;F9I9W5R86-I(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL.C@*;7-G:60@
M(D=E;F5R871E9"!#;V1E(@IM<V=S='(@(E9Y9V5N97)O=F%N_2!K\V0B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDP(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<T"FUS9VED(")'96]R9VEA(@IM<V=S='(@(D=R=7KM;G-K;R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-CD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B3NQM96-K;R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S4*;7-G:60@(D=H86YA(@IM<V=S='(@(D=H86YA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-0IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(D=I8G)A;'1A<B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<U"FUS9VED
M(")':79E;B!.86UE(@IM<V=S='(@(DOX97-T;NT@:FWI;F\B"@HC.B!T96UP
M;&%T97,O<')E9G,O87!P+FEN8SHQ,@IM<V=I9"`B1V\B"FUS9W-T<B`B2F1I
M(&YA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D
M96PB"FUS9W-T<B`B1V]E9&5L(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$Q,C@*(RP@9G5Z>GD*;7-G:60@(D=O;V=L92!-
M87!S(@IM<V=S='(@(E9Y:&QE9.%VX6[M('!O;6]C[2!';V]G;'4B"@HC.B!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H
M(@IM<V=S='(@(E9Y:&QE9.%VX6[M('!O;6]C[2!';V]G;'4B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,W"FUS9VED(")'
M<F%Y<V-A;&4B"FUS9W-T<B`B4W1U<&[L(+EE9&DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.CDS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM
M<V=I9"`B1W)E96-E(@IM<V=S='(@(MAE8VMO(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#4*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R
M("+896-KZ2`H25-/+3@X-3DM-RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'<F5E
M;FQA;F0B"FUS9W-T<B`B1W+S;G-K;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=R
M96YA9&$B"FUS9W-T<B`B1W)E;F%D82(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,3<Y"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI
M;FES=')A8V4@<')O('-K=7!I;GDB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`N<&AP.C4Y(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-CD*
M;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@
M(DUU<^T@8OUT('IA9.%N;R!J;>EN;R!S:W5P:6YY(@H*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,P-PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(D%U=&A?
M;&1A<#H@3F5L>F4@</AI9&%T('6^:79A=&5L92`E<RX@2&SAN65N[2!S97)V
M97)U.B`B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$X
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,C0*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0Q.`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U
M<"`E<R(*;7-G<W1R(")!=71H7VQD87`Z($YE;'IE(&%K='5A;&EZ;W9A="!U
MOFEV871E;&4@)7,B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,S,X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T
M;R!U<&1A=&4@9W)O=7`@)7,B"FUS9W-T<B`B075T:%]L9&%P.B!.96QZ92!A
M:W1U86QI>F]V870@=;YI=F%T96QE("5S(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HS,30@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*
M;7-G<W1R(")3:W5P:6YY(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W5A9&5L;W5P
M92(*;7-G<W1R(")'=6%D96QO=7!E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U
M86TB"FUS9W-T<B`B1W5A;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%T96UA
M;&$B"FUS9W-T<B`B1W5A=&5M86QA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B1W5E<FYS97DB
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(R-B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED(")'=65S="!097)M:7-S:6]N
M<R(*;7-G<W1R(")0<N%V82!H;W-T^2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT-S`*;7-G:60@(D=U97-T8F]O:R(*;7-G<W1R(")+;FEH82!H
M;W-T^2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=U:6YE82(*;7-G<W1R(")'=6EN
M96$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U:6YE82U":7-S874B"FUS9W-T
M<B`B1W5I;F5A+4)I<W-A=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA
M(@IM<V=S='(@(D=U>6%N82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.CDV,`IM<V=I9"`B2%1-3"(*;7-G<W1R(")(5$U,(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B
M2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@
M8V5L;"!I;B!R;W<N(@IM<V=S='(@(DA434Q!<F5A('IB86+L;&4@;V1M[73A
M('-M87IA="!P;W-L961N[2!B=?)K=2!N82#XX61K=2XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS9VED
M(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(DA434Q!<F5A('IB86+L;&4@
M;V1M[73A('-M87IA="!P;W-L961N[2!B=?)K=2!V92!S;&]U<&-I('1A8G5L
M:WDN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T
M;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R(")(5$U,
M07)E82!Z8F%B[&QE(&]D;>UTX2!S;6%Z870@<&]S;&5D;NT@^.%D96L@=B!T
M86)U;&-E+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z,34W
M"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B3W;L^&]VX6[M('!O;6]C[2!(5%10(&YE8GEL;R!N86QE>F5N;RXB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#`*;7-G:60@(DAA:71I(@IM<V=S='(@(DAA:71I(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")(87-H
M+4%L9V]R:71H;2(*;7-G<W1R(")(87-H+6%L9V]R:71M=7,B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@IM<V=I9"`B2&%Z
M92(*;7-G<W1R(")-;&AA=F\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HY,3D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,@IM<V=I9"`B2&5A
M9&5R(@IM<V=S='(@(DAL879IZ&MA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B2&5A9&5R
M<R(*;7-G<W1R(")(;&%V:>AK82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&5A
M<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(DAE87)D
M($ES;&%N9"!A($UC1&]N86QD($ES;&%N9',B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PHC+"!F=7IZ>0IM<V=I9"`B2&5A
M=GD@5"U3=&]R;2(*;7-G<W1R(")";W7X:V$B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X-@IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S
M='(@(DAE8G)E:KET:6YA("A)4T\M.#@U.2TX+4DI(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM<V=I9"`B
M2&5I9VAT(@IM<V=S='(@(E;]N6MA(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+TAE;'`N<&AP.C$W.2!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP
M:'`Z,3@V"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W('1E;7!L871E
M<R]H96QP+VEN9&5X+FEN8SHS"FUS9VED(")(96QP(@IM<V=S='(@(D[A<&]V
M[&1A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`B3N%P;W;L
M9&$@<')O(&5D:71O<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S
M-S$*;7-G:60@(DAE;'!E<B(*;7-G<W1R(")0;VUO8V[M:R(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R(")(
M96UI<V;I<F$B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,`IM<V=I9"`B2&5R92!I<R!T
M:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R("):9&4@:F4@>F'H
MX71E:R!S;W5B;W)U.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8Y"FUS9VED(")(:6=H(@IM<V=S='(@(E9Y<V]KX2(*"B,Z
M('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T97,O861M:6XO
M8V]M;6]N+6AE861E<BYI;F,Z-0IM<V=I9"`B2&]?;64B"FUS9W-T<B`B7TAO
M<F1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L>2!3964@*%9A=&EC86X@
M0VET>2!3=&%T92DB"FUS9W-T<B`B4W9A=.D@3>QS=&\@*%9A=&EKX6XI(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-3,U"FUS9VED(")(;VUE
M(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$R,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,34U"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`B
M061R97-A(&1O;?DB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*(RP@
M9G5Z>GD*;7-G:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S='(@(D%D<F5SX?@B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP
M"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(E1E;&5F;VX@9&]M^2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW.0IM<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`B2&]N9'5R87,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N9R(*;7-G<W1R(")(;VYG
M($MO;F<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C4*;7-G:60@
M(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HT-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E
M<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@3F5P;&%T;ND@)7,@6$U,(&1A=&$@
M=F4@>G!RX7;L("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR
M.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&UE<W-A
M9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@(DAO<F1E+TMO
M;&%B.B"NX61NX2!Z<'+A=F$@<V4@;F5S:&]D=6IE(',@;V)J96MT96T@)7,B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0S-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@
M9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@3F5B
M>6P@;F%L97IE;B"^X61N_2!O8FIE:W0@='EP=2`E<R!V92!Z<'+A=NP@)7,B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D
M("5S(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@VG-P[+ENZ2!O9'-T
M<F%N[&[M("5S(%PB)7-<(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z,C(S"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N
M9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G
M<W1R(")(;W)D92]+;VQA8CH@26YT96=R8>AN[2!NX7-T<F]J('!O=/AE8G5J
M92!02%`@</CM<&]N=2`G9&]M>&UL)R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z-3`S"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S
M(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!.96QZ92!V>71V;_AI="!N;W;]('-T
M<F]M(%A-3"!P<F\@;V)J96MT("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HQ,C0W"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R
M9&4O2V]L86(Z($YE;'IE(&]D<W1R86YI="`E<R!<(B5S7"(Z("5S(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-S0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$
M(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B
M.B!.96QZ92!Z[7-K870@34E-12!)1"!P<F\@Z.%S="!T>7!U("5S(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DS"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@
M7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@3F5L>F4@<WEN8VAR
M;VYI>F]V870@)7,@7"(E<UPB.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,3,S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B
M2&]R9&4O2V]L86(Z($YE;'IE('-Y;F-H<F]N:7IO=F%T('-D[6QE;ND@;V)J
M96MT>3H@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C,T,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R
M92!<(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($YE>F[A;?T@<V3M;&5N
M_2!O8FIE:W0@7"(E<UPB(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S
M='(@(E9O9&]R;W9NZ2!P<F%V[71K;R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D
M9&EN9R(*;7-G<W1R(")(;W)I>F]N=.%L;NT@;V1S='5P(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R
M:7IO;G1A;#HB"FUS9W-T<B`B2&]R:7IO;G3A;&[M.B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I
M9"`B2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS
M9W-T<B`B2F%K(&IS=&4@<V4@<V5M(&1O<W1A;&D_("A:8;EL971E('!R;W/M
M;2!Z<'+A=G4A*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U
M;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(DMO;&EK('-L;W5P8_D@
M8VAC971E('-P;VII=#\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE
M<F4_(@IM<V=S='(@(DMO;&EK(&IE('1A;2!P;VSM("AS;&]U<&/Y*3\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,V"FUS9VED(")(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE
M<F=E/R(*;7-G<W1R(")+;VQI:R#XX61K^2!C:&-E=&4@<W!O:FET/R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,S`*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(E9L:&MO<W0B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4Y"FUS9VED(")(
M=6UI9&ET>3H@(@IM<V=S='(@(E9L:&MO<W0Z(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0Q"FUS9VED(")(=6UO<FES=',B"FUS9W-T<B`B2'5M;W)N
MZ2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R(")-8>]A
M<G-K;R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W,B!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C,U"B,L('!H<"UF;W)M
M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S(@IM
M<V=S='(@(E-E;&AA;&\@=GET=F_X96[M($E-05!O=ND@<V-H<N%N:WDZ("5S
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C$T(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T
M<B`B4V5L:&%L;R!S;6%ZX6[M($E-05!O=ND@<V-H<N%N:WDZ("5S(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<Y(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T
M<B`B4V5L:&%L;R!N87-T879E;NT@:W;S='D@<')O($E-05!O=F]U('-C:'+A
M;FMU.B`E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,38*;7-G
M:60@(DE0($%D9')E<W,B"FUS9W-T<B`B25`@861R97-A(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B25`@061D<F5S
M<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("))4"!A9')E<V$@;F5N[2!D;W-T
M=7!NX2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y
M"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L
M;V-K+B(*;7-G<W1R("))4"!A9')E<V$@;F5N[2!V('!O=F]L96[I;2!#2412
M(')O>G-A:'4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W;B!V:6]L871I;VXN
M(@IM<V=S='(@(E!O<G6Y96[M(&EN=&5G<FET>2!)4"XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*;7-G
M:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R(")67VQOOG1E(/CA9&5K
M('#X960B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B
M27-L86YD(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-@IM<V=I9"`B
M26-O;G,@3VYL>2(*;7-G<W1R(")0;W5Z92!I:V]N>2(*"B,Z('5T:6PO:6-O
M;E]B<F]W<V5R+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("))8V]N<R!F
M;W(@)7,B"FUS9W-T<B`B26MO;GD@<')O("5S(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,W-PIM<V=I9"`B26-O;G,@=VET:"!T97AT(@IM<V=S='(@
M(DEK;VYY(',@=&5X=&5M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y
M,`IM<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R(").X7IE=B!I9&5N
M=&ET>3HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU
M.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L87EE
M9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(*
M;7-G<W1R(")0;VMU9"!Z;V)R87IE;NT@;F5N[2!V('!O^.%D:W4L("5S(&]T
M97;X[70@=B!N;W;I;2!O:V[L+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT-34*;7-G:60@(B(*(DEF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S
M:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@
M(@HB=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS
M9W-T<B`B(@HB4&]K=60@<&]UONUVX71E($EN=&5R;F5T($5X<&QO<F5R(&$@
M;F5V:63M=&4@ON%D;ND@:6MO;GDL('KX96IM["!P;W3X96)U:F5T92`B"B)O
M>FYAZ&ET('1E;G1O('+A;67H96L@<')O('9Y<&YU=.T@4$Y'('1R86YS<&%R
M96YC92XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3<S"FUS9VED("(B"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@
M;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@
M8F4@(@HB9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@HB
M4&]K=60@=FED[71E('1U=&\@>G!RX79U(&WM<W1O(&]B<N%Z:W4L(&]B<N%Z
M96L@:W1E<OT@8VAC971E('#X96[I<W0@;F5L>F4@(@HB5F&Y[6T@<')O:&SM
MOF7H96T@>F]B<F%Z:70N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(X"FUS9VED("));6%G92!0<F5V
M:65W.B(*;7-G<W1R(").X6AL960@;V)RX7IK=3HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,W"FUS9VED("))
M;6%G92!54DPB"FUS9W-T<B`B55),(&]B<N%Z:W4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G
M:60@(DEM86=E(%523#HB"FUS9W-T<B`B55),(&]B<N%Z:W4Z(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B3V)RX7IE
M:R!Z(&=A;&5R:64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L
M;&5R>3HB"FUS9W-T<B`B3V)RX7IE:R!Z(&=A;&5R:64Z(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,0IM<V=I9"`B26UA9V4@=7!L;V%D(@IM
M<V=S='(@(E#X96YO<R!O8G+A>FMU(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP
M:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R(")/8G+A>FMY(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T82]D871E
M;6%P+FEN8SHW"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-30@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED
M("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`B26UP;W)T+"!K<F]K("5D(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(DEM<&]R=&]V
M86[I('!O;&4Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV
M-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R("));7!O<G1O=F%N
MX2!P;VQE.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS
M9W-T<B`B5FQOOFET(/CA9&MU('IA(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+WII<"YP:'`Z,3,U"FUS9VED("));F-O<G)E8W0@86-T:6]N
M(&-O9&4@9VEV96XN(@IM<V=S='(@(D)Y;"!Z863A;B!N97-P<N%V;OT@86OH
M;NT@:_-D+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,R"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R
M('!A<W-W;W)D+B(*;7-G<W1R(").97-P<N%V;NP@>F%D86[I('6^:79A=&5L
M<VOI(&IMZ6YO(&$O;F5B;R!H97-L;RXB"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R
M(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R
M("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*
M;7-G<W1R("(B"B).97-P<N%V;ND@=;YI=F%T96QS:^D@:FWI;F\@;F5B;R!A
M;'1E<FYA=&EV;NT@861R97-A+B!::W5S=&4@:F6Y=.P@:F5D;F]U("(*(FYE
M8F\@:V]N=&%K='5J=&4@5F&Y96AO('-Y<W3I;6]VZ6AO(&%D;6EN:7-T<N%T
M;W)A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C$*;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R("):=NQTN6ET
M(&]D<V%Z96[M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,38@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("));F1I82(*;7-G<W1R
M("));F1I92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C4T
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS9VED("));F1I=FED
M=6%L(%5S97)S(@IM<V=S='(@(DIE9&YO=&QI=NT@=;YI=F%T96SI(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@P"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`B26YD;V[I<VEE
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV
M-PIM<V=I9"`B26YF;R(*;7-G<W1R("));F9O<FUA8V4B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C4W"FUS9VED("));F9O<FUA=&EO;B(*;7-G
M<W1R("));F9O<FUA8V4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S,P"B,L(&9U>GIY"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@
M879A:6QA8FQE+B(*;7-G<W1R("*NX61NZ2!Z(&UOOFYO<W3M(&YE:G-O=2!D
M;W-T=7!NZ2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@(DEN<V5R="!#7V]L=6UN($%F=&5R
M(@IM<V=S='(@(E9L;[YI="!S7VQO=7!E8R!Z82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I
M9"`B26YS97)T($EM86=E(@IM<V=S='(@(E9L;[YI="!O8G+A>F5K(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I
M9"`B26YS97)T(%1A8FQE(@IM<V=S='(@(E9L;[YI="!T86)U;&MU(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I
M9"`B26YS97)T(%=E8B!,:6YK(@IM<V=S='(@(E9L;[YI="!W96)O=OT@;V1K
M87HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S0*;7-G:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G
M<W1R(")6;&^^:70@7W-L;W5P96,@</AE9"`B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(DEN
M<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S
M='(@(E9L;[YI="!N;W;]('-L;W5P96,@>F$@<V]UZ&%S;OTB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*
M;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT
M(&]N92(*;7-G<W1R(")6;&^^:70@;F]V_2!S;&]U<&5C('#X960@<V]UZ&%S
M;OTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE
M(&-U<G)E;G0@;VYE(@IM<V=S='(@(E9L;[YI="!N;W;](/CA9&5K('IA('-O
M=>AA<V[](@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@82!N97<@<F]W(&)E9F]R
M92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B5FQOOFET(&YO=OT@^.%D96L@
M</AE9"!S;W7H87-N_2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM<V=I9"`B26YS97)T(&$@<&%R86=R
M87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B5FQOOFET(&]D
M<W1A=F5C('IA('-O=>AA<V[]('5Z96PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R
M="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R
M(")6;&^^:70@;V1S=&%V96,@</AE9"!S;W7H87-N_2!U>F5L(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@
M=&5M<&QA=&4B"FUS9W-T<B`B5FQOOFET(&%L=&5R;F%T:79N[2!V>F]R(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S.0IM<V=I9"`B26YS97)T(&%N
M(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N
M97<@<&%S<W=O<F0Z(@IM<V=S='(@(E9L;[YT92!E;6%I;&]V;W4@861R97-U
M+"!N82!K=&5R;W4@;V)D<K[M=&4@;F]VZ2!H97-L;SHB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X"FUS9VED
M("));G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R(")6;&^^:70@8G7R:W4@>F$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4Y"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`B5FQO
MOFET(&)U\FMU('#X960B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L=6UN(&%F
M=&5R(@IM<V=S='(@(E9L;[YI="!S;&]U<&5C('IA(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B
M26YS97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`B5FQOOFET('-L;W5P96,@
M</AE9"(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.CDP"FUS9VED("));G-E<G0@;65S<V%G97,B"FUS9W-T<B`B5FQOOFET('IP
M<N%V>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHT-0IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!A9G1E<B(*
M;7-G<W1R(")6;&^^:70@;V1S=&%V96,@>F$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN
M<V5R="!P87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@(E9L;[YI="!O9'-T879E
M8R!P^&5D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R
M(")6;&^^:70@^.%D96L@>F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E
M9F]R92(*;7-G<W1R(")6;&^^:70@^.%D96L@</AE9"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,S`*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER960@
M86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B5FQO
MOG1E('!OOF%D;W9A;F]U(&]D<&]V[.\@;F$@8F5Z<&7H;F]S=&[M(&]TX7IK
M=3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(V"FUS9VED("));G-E<G0O36]D:69Y($EM86=E(@IM<V=S='(@(E9L;[YI
M="]U<')A=FET(&]B<N%Z96LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("));G-E<G0O36]D:69Y($QI;FLB
M"FUS9W-T<B`B5FQOOFET+W5P<F%V:70@;V1K87HB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B26YS
M=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@
M;&ES="XB"FUS9W-T<B`B3F5D;W-T871EZ&[](&MR961I="!K(&]D97-LX6[M
M('IP<N%V>2!N82!D:7-T<FEB=>AN[2!S97IN86TN(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@(DEN
M<W5F9FEC:65N="!C<F5D:70N(@IM<V=S='(@(DYE9&]S=&%T9>AN_2!K<F5D
M:70N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`W-0IM<V=I9"`B
M26YT96=E<B(*;7-G<W1R(")#96SI(.CM<VQO(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$S,PIM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S='(@
M(E-E>FYA;2!C96S]8V@@Z.US96PB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G:60@(DEN=F%L:60@541(
M+B`H57-E<B!$871A($AE861E<BDN(@IM<V=S='(@(DYE<W!RX79NZ2!51$@N
M("A5<V5R($1A=&$@2&5A9&5R*2XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O>FEP+G!H<#HQ-S`*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+WII<"YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]Z:7`N<&AP.C(Q,`HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!:25`@
M9&%T82(*;7-G<W1R(").97!L871NX2!D871A('5N:6-O9&4N(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L:6-A
M=&EO;BXB"FUS9W-T<B`B3F5P;&%T;N$@87!L:6MA8V4N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED
M("));G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R(").97!L871NZ2!I9&5N=&EF
M:6MAZ&[M(.CM<VQO("A)1"D@9.%V:WDN(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`X-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,34X"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,S(@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C(Y.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B
M;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*
M;7-G<W1R(")">6QA('IA9.%N82!N97!L871NX2!D871A(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED
M("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(DYE<&QA
M=&[A(&%D<F5S82!P^.UJ96UC92XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O9&)X+G!H<#HX,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M
M<')E<W,O9&)X+G!H<#HQ,#`*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+V1B>"YP:'`Z,C(P"FUS9VED("));G9A;&ED(&9I;&4@9F]R;6%T(@IM
M<V=S='(@(DYE<&QA=&[](&9O<FWA="!S;W5B;W)U(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$W-PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI
M9"!L:6-E;G-E(&ME>2XB"FUS9W-T<B`B3F5P;&%T;N$@87!L:6MA8V4N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W,0HC+"!F=7IZ>0IM
M<V=I9"`B26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B3F5P
M;&%T;N$@87!L:6MA8V4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US9U]T>7!E
M+B(*;7-G<W1R(").97!L871N_2!M<V=?='EP92XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*;7-G:60@(DEN
M=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(DYE<&QA=&[I(&YE
M8F\@8VAY8NQJ[6/M(&%P:5]I9"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.38*;7-G:60@(DEN=F%L:60@;W(@
M;6ES<VEN9R!P87)A;65T97)S+B(*;7-G<W1R(").97!L871NZ2!N96)O(&-H
M>6+L:NUC[2!P87)A;65T<GDN(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N
M<&AP.C(W"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G
M<W1R(").97!L871NX2!V;&%S=&YI8VOA('!RX79A+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S,*(RP@9G5Z>GD*;7-G:60@(DEN=F%L
M:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B3F5P;&%T;N$@=FQA<W1N:6-KX2!P
M<N%V82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<U"B,L
M(&9U>GIY"FUS9VED("));G9A;&ED('!R;V1U8W0@8V]D92XB"FUS9W-T<B`B
M3F5P;&%T;OT@<')O=&]K;VPN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED("));G9A;&ED('!R;W1O
M8V]L+B(*;7-G<W1R(").97!L871N_2!P<F]T;VMO;"XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HX,`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R(").
M97!L871N_2!P^.UJ96UC93H@)R5S)R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,3`W-B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-C(*
M;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S='(@(DYE<&QA=&[]
M('-D[6QE;OT@;V)J96MT(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"FUS9VED("));G9A;&ED('-O=7)C92!A
M9&1R97-S+B(*;7-G<W1R(").97!L871NX2!A9')E<V$@;V1E<^UL871E;&4N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S$Q"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T<B`B
M3F5P;&%T;N$@9&%T82!U;FEC;V1E+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS-3<*;7-G:60@(DEN=F5N=&]R>2(*;7-G<W1R("));G9E;G3A
M^"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV
M-SD*(RP@9G5Z>GD*;7-G:60@(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T<B`B
M5GES=/AI:&YO=70@=OUB['(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DER86XL
M($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`BS7+A;BP@27-LX6US:^$@
M<F5P=6)L:6MA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM<V=S='(@
M(DERX6LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS9W-T<B`B
M27)S:V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-0IM<V=I
M9"`B27-L92!O9B!-86XB"FUS9W-T<B`B3W-T<F]V(&UUOF4B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O
M;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B3VIE9&EN[&SI(&)O=?AK>2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,`IM<V=I9"`B27-R865L(@IM<V=S='(@(DES<F%E;"(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C(U"FUS9VED("))
M<W-U97(B"FUS9W-T<B`B4&]S:WET;W9A=&5L(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS
M9W-T<B`B2W5R>NUV82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B271A;'DB"FUS
M9W-T<B`B273A;&EE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED(")*86UA:6-A(@IM
M<V=S='(@(DIA;6%J:V$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R("),961E;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F%P86XB"FUS9W-T<B`B2F%P;VYS:V\B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-PIM<V=I9"`B2F%P86YE<V4@
M*$E33RTR,#(R+4I0*2(*;7-G<W1R(")*87!O;KET:6YA("A)4T\M,C`R,BU*
M4"DB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`IM<V=I9"`B
M(@HB2F%V87-C<FEP="!H87,@8F5E;B!D:7-A8FQE9"!O;B!Y;W5R(&)R;W=S
M97(@86YD('1H:7,@<&%G92!M87D@;F]T(&)E("(*(F1I<W!L87EI;F<@8V]R
M<F5C=&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R,@IM<V=I9"`B2F5R<V5Y(@IM<V=S='(@(E1R:6MO="(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,PIM<V=I9"`B2F]R9&%N(@IM<V=S='(@(DIO<F3A;G-K;R(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#<*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED
M(")*=6QY(@IM<V=S='(@(LAE<G9E;F5C(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B
MR&5R=F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R("):87)O=FYA
M="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$U"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R("):87)O
M=FYA="!N82!S=/AE9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS
M9W-T<B`B6F%R;W9N870@=GEP;&[L;NUM(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G:60@(DIU<W1I
M9GD@3&5F="(*;7-G<W1R("):87)O=FYA="!D;VQE=F$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I
M9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R("):87)O=FYA="!D;W!R879A(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@(DMA>F%C
M:'-TX6XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C8T"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G<W1R(")58VAO=F%T
M(&]R:6=I;N%L/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T
M<B`B2V7R82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#4*
M;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`B2V5R8F5R;W,@<V5R=F5R('IA;>UT;G5L(&]V[/AE;NTN
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED(")+97)N96P@
M3F5W8FEE<R(*;7-G<W1R(").;W;AZ&-I(&ME<FYE;'4B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO
M;B(*;7-G<W1R(")6>71V;_AE;NT@:VSMZ&4B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@(DME>2!&:6YG97)P<FEN="(*
M;7-G<W1R(")6>71V;_AE;NT@;W1I<VMU(&ML[>AE(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N9W1H(@IM
M<V=S='(@(D3I;&MA(&ML[>AE(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@5'EP92(*;7-G<W1R(")4>7`@:VSM
MZ&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.`IM
M<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(E6^:73M(&ML[>AE(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S0P"FUS9VED(")+97D@86QR
M96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@
M(DML[>@@:FF^(&5X:7-T=6IE(&YA('9E^&5J;NEM(&ML[>AO=NEM('-E<G9E
M<G4N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S
M(@IM<V=S='(@(D3L=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(DMI<FEB871I
M(@IM<V=S='(@(DMI<FEB871I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E
M82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9B(*;7-G<W1R(")+
M3$12(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@4F5P=6)L:6,@;V8B
M"FUS9W-T<B`B2V]R96$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM
M<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@(DMO<F5J<VMY("A%54,M
M2U(I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+=7=A:70B"FUS9W-T<B`B2W5V
M86IT(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S='(@
M(DMY<F=I>G-TX6XB"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*
M;7-G:60@(DQA7WEO=70B"FUS9W-T<B`B7U)O>FQOOF5N[2(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S
M='(@(DIA>GEK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),86\@4&5O<&QE)W,@
M1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("),86]S+"!,:61O=NP@1&5M
M;VMR871I8VMA(%)E<'5B;&EK82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ
M-CD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R(")$<G5HX2!P;VQO=FEN82(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW-@HC+"!F=7IZ>0IM<V=I9"`B
M3&%S="!087-S=V]R9"!#:&%N9V4B"FUS9W-T<B`B5OUC:&]Z[2!N87-T879E
M;NT@:&5S;&$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K
M+VUO;VXN<&AP.C@X"FUS9VED("),87-T(%%U87)T97(B"FUS9W-T<B`B4&]S
M;&5D;NT@Z'1V<G1I;F$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U,0IM
M<V=I9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R(")0;W-L961N[2!A:W1U86QI
M>F%C93HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`B4&]S;&5D
M;NT@</AI:&SAN65N[3H@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HW,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O
M;2`E<R(*;7-G<W1R(")0;W-L961N[2!P^&EH;.&Y96[M.B`E<R!Z("5S(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$V"FUS9VED("),87-T(&QO
M9VEN.B!.979E<B(*;7-G<W1R(")0;W-L961N[2!P^&EH;.&Y96[M.B!.:6MD
M>2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(DQI='9A
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED("),87<B"FUS
M9W-T<B`B4'+A=F\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-SD*;7-G:60@(DQA>6]U="(*;7-G<W1R(")2;WIL
M;[YE;NTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S
M='(@(DYE8VAA="!P<N%Z9&[I(&)E>B!O:W)A:F4B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*
M;7-G:60@(DQE8F%N;VXB"FUS9W-T<B`B3&EB86YO;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B
M3&5F="(*;7-G<W1R(")$;VQE=F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,3$Y"FUS9VED("),969T(&AE861E<B(*;7-G<W1R("),97;A(&AL
M879IZ&MA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-0IM<V=I
M9"`B3&5F="!V86QU97,B"FUS9W-T<B`B2&]D;F]T>2!N86QE=F\B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#@*;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`B3&5S;W1H;R(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I
M9"`B3&5V96PB"FUS9W-T<B`B3.%S:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@
M(DQI8F5R:6$B"FUS9W-T<B`B3&EBZ7)I92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,30W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I
M9"`B3&EB>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R("),:6)I92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("),:6-H
M=&5NN71E:FYS:V\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR-0IM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R("),96AK
MZ2!M<FAO;&5N[2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(V"FUS9VED("),:6=H="!286EN(@IM<V=S='(@(DQE:&O](&3I
MN;LB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R(")"<GIK_2!L96AK
M_2!DZ;F[(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R(")0;WID[&II
M(&QE:&O](&3IN;LB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR.0IM<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B
M3&5H:^D@9&6YNV]VZ2!S<N&^:WDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H
M=6YD97(B"FUS9W-T<B`B3&5H:_T@9.FYNR!S(&CX;>QN[6TB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B3&EG
M:'0@4VYO=R(*;7-G<W1R("),96AKZ2!S;NR^96[M(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N
M;W<@4VAO=V5R(@IM<V=S='(@(DQE:&OI('-N[&AO=ND@</AE:.'R:WDB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM
M<V=S='(@(DQI;65R:6-K(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3@Q-`IM<V=I9"`B3&EN:R(*;7-G<W1R(")/9&MA>B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I
M9"`B3&EN:R!P;VEN=',@=&\Z(@IM<V=S='(@(D]D:V%Z>2!U:V%Z=6KM(&YA
M.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S4*;7-G:60@(DQI
M;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N
M(&1I<W!L87EI;F<B"FUS9W-T<B`B(@HB4&]UONUT(&]D:V%Z>2!N82!E;6%I
M;&]VZ2!A9')E<WD@</AI('IO8G)A>F]VX6[M('-T<N%N:WD@<')O('!S86[M
M('IP<N%V(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H=&UL
M,G1E>'0N<&AP.C$X,PIM<V=I9"`B3&EN:W,B"FUS9W-T<B`B3V1K87IY(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0V"FUS9VED("),:6YU>"!#;V]K
M:64B"FUS9W-T<B`B3&EN=7AO=ND@8V]O:VEE(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G:60@(DQI<W0@+2!U<V5R
M(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R(")397IN86T@+2!UOFEV871E
M;"!M^;YE('9I9.QT('-L;[YK=2(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,S,*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(E-E>FYA;2!D871A
M8N%Z[2(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4P"FUS9VED("),
M:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(E-E>FYA;2!TZ6UA="!NX7!O=NQD
M>2(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S(*;7-G:60@(DQI<W0@5&%B
M;&5S(@IM<V=S='(@(E-E>FYA;2!T86)U;&5K(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12](96%D97)S+G!H<#HU.30*;7-G:60@(DQI<W0M07)C:&EV92(*
M;7-G<W1R(")397IN86TM07)C:&EV(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12](96%D97)S+G!H<#HU.#D*;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R(")3
M97IN86TM3N%P;W;L9&$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E
M<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U)9"(*;7-G<W1R(")397IN86TM260B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,@IM<V=I
M9"`B3&ES="U/=VYE<B(*;7-G<W1R(")397IN86TM5FQA<W1N[6LB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,PIM<V=I9"`B3&ES
M="U0;W-T(@IM<V=S='(@(E-E>FYA;2U/9&5S;.%N[2(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DQ"FUS9VED("),:7-T+5-U8G-C
M<FEB92(*;7-G<W1R(")397IN86TM4/AI:&SAN65N[2(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DP"FUS9VED("),:7-T+55N<W5B
M<V-R:6)E(@IM<V=S='(@(E-E>FYA;2U/9&ALX;EE;NTB"@HC.B!A9&UI;B]S
M97-S:6]N<RYP:'`Z-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DQI
M<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R(")6_7!I<R!UOFEV
M871E;/D@;F5N[2!D;W-T=7!N_2XB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z
M,S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@
M9F%I;&5D.B`E<R(*;7-G<W1R(")6_7!I<R!UOFEV871E;/D@;F5N[2!D;W-T
M=7!N_2XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C(*
M;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(E;]
M<&ES('6^:79A=&5L^2!N96[M(&1O<W1U<&[]+B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT-PIM<V=I9"`B3&ET97)A='5R92(*;7-G<W1R("),:71E
M<F%T=7)A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:71H=6%N:6$B"FUS9W-T
M<B`B3&]T>;ES:V\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M;6%G97,N<&AP.C@S"FUS9VED("),;V%D:6YG+BXN(@IM<V=S='(@(DYA:'+A
M=N%N[2XN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3$*
M;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R(")-[7-T;NT@Z&%S.B`B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@(DQO8V%L92!A;F0@
M5&EM92(*;7-G<W1R("),;V-A;&4@82#H87,B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4W,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-C0*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C
M:R]M971A<BYP:'`Z-C4*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(DWM<W1O
M(@H*(SH@;&]G:6XN<&AP.C$W,B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP
M:'`Z,3DQ('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C,*(SH@=&5M<&QA
M=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHY,`IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(E#X:6ALX7-I="!S92(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B3&]G
M(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3@U"FUS9VED("),;V<@;W5T(@IM
M<V=S='(@(D]D:&SAN65N[2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU
M.0HC+"!F=7IZ>0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`B4/AI:&SA<VET('-E
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-PIM<V=I9"`B3&]G:6X@
M5&%S:W,B"FUS9W-T<B`BVFMO;'D@<')O=N%D[&[I('#X:2!P^&EH;.&Y96[M
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DV"FUS9VED("),;V=I
M;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A
M<R!E;G1E<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R("(B"B)396QH86QO('#X
M:6ALX;EE;NT@9&\@<WES=.EM=2X@4')A=F3L<&]D;V)N["!68;EE('6^:79A
M=&5L<VOI(&IMZ6YO(&$O;F5B;R`B"B)H97-L;R!N96)Y;&\@<W!RX79N["!Z
M863A;F\N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DR"FUS9VED
M("),;V=I;B!F86EL960N(@IM<V=S='(@(E#X:6ALX;EE;NT@<V5L:&%L;RXB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8U"FUS9VED("),;VYG
M('1E>'0B"FUS9W-T<B`B1&QO=6C]('1E>'0B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-#@*;7-G:60@(DQO=F4B"FUS9W-T<B`B3.%S:V$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I9"`B
M3&]W(@IM<V=S='(@(D[M>FOA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E
M96L@;&5T=&5R<R(*;7-G<W1R(")-86SA(/AE8VOA('#M<VUE;F$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS
M.C$Y"FUS9VED("),;W=E<B!L871I;B!L971T97)S(@IM<V=S='(@(DUA;.$@
M=&ES:V%C[2!P[7-M96YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@
M;G5M8F5R<R(*;7-G<W1R(")-86SI(/CM;7-KZ2#H[7-L:6-E(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@Y"FUS9VED("),=7AE;6)O=7)G(@IM<V=S='(@(DQU8V5M8G5R<VMO
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,X
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R(")-
M32(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#$*;7-G:60@(DU/
M5$0B"FUS9W-T<B`B6G!RX79A(&1N92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1N968N<&AP.C,V"FUS9VED(")-4RU43D5&($%T=&%C:&UE
M;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(E#X:7!O:F5N_2!S;W5B
M;W(@35,M3E1%1B!N96]B<V%H=6IE(+[A9&[A(&1A=&$N(@H*(SH@9G)A;65W
M;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE
M+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S='(@(DU31R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,@IM<V=I9"`B36%C86\B"FUS9W-T<B`B36%K86\B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*
M;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI
M8R!O9B(*;7-G<W1R(")-86ME9&]N:64L(&+]=F%LX2!297!U8FQI:V$@2G5G
M;W-LX79I92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G
M<W1R(")-861A9V%S:V%R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y
M"FUS9VED(")-86=I8R(*;7-G<W1R(")-86=I92(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HX,0IM<V=I9"`B36%I;"(*;7-G<W1R(")0;[ET82(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,C(*;7-G:60@(DUA:6P@
M061M:6XB"FUS9W-T<B`B061M:6YI<W1RX71O<B!P;[ET>2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,0IM
M<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R(")6>71V;_AI="!O9%]K87HN
M+BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&%W:2(*;7-G<W1R(")-86QA
M=VDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@(DUA
M;&%J<VEE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD:79E<R(*;7-G<W1R
M(")-86QD:79Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-30@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86QI(@IM<V=S='(@
M(DUA;&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;'1A(@IM<V=S='(@(DUA
M;'1A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ"FUS9VED("(B"B)-
M86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E
M;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@=VET:"!T
M:&]S92!C871E9V]R:65S+B(*;7-G<W1R("(B"B)0<F\@=6UOOF[L;NT@;W9L
MX63A;NT@:V%T96=O<FGM(&IE('IA<&]T^&5B[2!O>FYAZ&ET('!O;&^^:WD@
M8F%R=F%M:2P@:W1E<ND@(@HB:G-O=2!P^&GX87IE;GD@:R!T[&UT;R!K871E
M9V]R:>UM+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,34S"FUS9VED(")-87`R-"!M87`B"FUS9W-T<B`B36%P82!-87`R
M-"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,#@T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,38X"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T<B`B36%P82!-87!1=65S
M="(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I9"`B
M36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS9W-T
M<B`B0OAE>F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT,0IM<V=I9"`B36%R9VEN(@IM<V=S='(@(D]K<F%J
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*
M;7-G:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R(")/
M>FYAZ&ET('IN8>AK;W4@4')O:&SI9&YU=&\O3F5P<F]H;.ED;G5T;R(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED
M(")-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E
M<F5D*2(*;7-G<W1R(")/>FYAZ&ET(&II;OUM:2!Z;F'H:V%M:2`H:F%K;R!$
M^6QEOFETZ2]/9'!O=NQZ96[I*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,34R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%R
M<VAA;&P@27-L86YD<R(*;7-G<W1R(")-87*Y86QS:^D@3W-T<F]V>2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY,PIM<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R(")-87)T:6YI
M<75E(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@
M(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R(")3:&]D=6KM8^T@<V4@<&]L92(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%U<FET86YI82(*;7-G<W1R(")-875R
M973A;FEE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-875R:71I=7,B"FUS9W-T
M<B`B36%U<FEC:75S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N
M(@IM<V=S='(@(DUA>&EM86QN[2!P;W9O;&5N_2!K<F5D:70B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G
M:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G<W1R(")">6QA
M('#X96MR;^AE;F$@;6%X:6UA;&[M(&3I;&MA('IP<N%V>2XB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,P-@IM<V=I9"`B36%X('1E;7`@;&%S="`R-"!H
M;W5R<SH@(@IM<V=S='(@(DYE:G9YN;GM('1E<&QO=&$@>F$@<&]S;&5D;NUC
M:"`R-"!H;V1I;CH@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3@*;7-G
M:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(DYE:G9YN;GM
M('1E<&QO=&$@>F$@<&]S;&5D;NUC:"`V(&AO9&EN.B`B"@HC.B!L:6(O87!I
M+G!H<#HX-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3@@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-PHC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C,Y"FUS9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R
M(")-87AI;>%L;NT@9.EL:V$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@(DMV['1E;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3<*;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B36%Y;W1T
M92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I
M;F4B"FUS9W-T<B`B365D:6/M;F$B"@HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V5D:70N:6YC.C$V"FUS9VED(")-96UB97)S(@IM<V=S='(@(LAL96YO
M=NDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<X"FUS9VED(")-96YU
M(&UO9&4Z(@IM<V=S='(@(DWS9'D@<')O(&UE;G4Z(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B
M365R9V4@8V5L;',B"FUS9W-T<B`B4W!O:FET(&)U\FMY(@H*(SH@9G)A;65W
M;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S
M+G!H<#HS,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G
M:60@(DUE<W-A9V4B"FUS9W-T<B`B6G!RX79A(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R
M:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A
M=&4@8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("):<'+A=F$@
M8GEL82!O=NSX96YA('8@<&_XX61K=2P@86QE(&YE;'IE(&]V[/AI="!P;V1P
M:7-O=OT@8V5R=&EF:6OA="XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*;7-G:60@(DUE<W-A9V4@97AP:7)E
M9"XB"FUS9W-T<B`B6G!RX79A('!R;W!A9&QA+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*
M;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R(")4>7`@>G!RX79Y(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS9VED(")-971A<B!796%T:&5R(@IM
M<V=S='(@(E!OZ&%S[2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G
M:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D)L;VL@
M;R!P;^AA<^T@;F5N[2!D;W-T=7!N_2XB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$Q,@IM<V=I9"`B(@HB365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@
M1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O
M<BXB"FUS9W-T<B`B(@HB0FQO:R!O('!OZ&%S[2!N96[M(&1O<W1U<&[]+B!0
M;V1R;V)N;W-T:2!B>6QY('IA>FYA;65NX6YY('!R;R!S>7-TZ6UO=NEH;R`B
M"B)A9&UI;FES='+A=&]R82!D;R!L;V=U+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-C4*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE
M8W1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HV-R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<T"FUS9VED(")-971H;V0B"FUS9W-T<B`B365T;V1A(@H*(SH@9G)A
M;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HX,2!F<F%M97=O<FLO4E!#+U)0
M0R]S;V%P+G!H<#HQ,3<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DUE
M=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`B365T;V1A("<E
M<R<@;F5N[2!D969I;F]VX6YA(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S
M="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I
M;F5D+B!#86QL960@;65T:&]D.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HW
M-0IM<V=I9"`B365T<FEC(@IM<V=S='(@(DUE=')I8VO](@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDU"FUS9VED(")-97AI8V\B"FUS9W-T<B`B365X:6MO(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S(*;7-G:60@(DUI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS
M9W-T<B`B36EK<F]NZ7-I92P@1F5D97)A8V4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0R"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S8*;7-G:60@(DUI9&1L
M92(*;7-G<W1R(")5<')O<W3X960B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S='(@
M(E1Y<"!-:6UE(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3`*;7-G:60@
M(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R(").96IN:;ZY[2!T
M97!L;W1A('IA('!O<VQE9&[M8V@@,C0@:&]D:6XZ("(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S`R"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z
M("(*;7-G<W1R(").96IN:;ZY[2!T97!L;W1A('IA('!O<VQE9&[M8V@@-B!H
M;V1I;CH@(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,SD*
M;7-G:60@(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER
M960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(S-`IM<V=I9"`B36ER<F]R(@IM<V=S='(@(EIR8V%D;&]V
M["(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM<V=I9"`B36ES8V5L
M;&%N96]U<R(*;7-G<W1R(")2^7INZ2(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!0
M14%2('!A8VMA9V4@2%144%]297%U97-T+B(*;7-G<W1R(")0<F]G<F%M;W;]
M(&)A;.UK($A45%!?4F5Q=65S="!C:'EB[2!V(%!%05(N(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$Q-0IM<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U
M<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A
M;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC871I;VXN(@IM<V=S='(@(B(*(D-H
M>6+L:NUC[2!K;VYF:6=U<F%C92X@4&]K=60@<VD@</AE:F5T92!P;W6^[79A
M="!T=71O(&%P;&EK86-I+"!M=7/M=&4@(@HB=GEG96YE<F]V870@:V]N9FEG
M=7)AZ&[M('-O=6)O<BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)
M1"XB"FUS9W-T<B`B0VAY8NQJ[6/M($E$('IP<N%V>2`H:61E;G1I9FEK8>AN
M[2#H[7-L;RDB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I
M=&%L>5]S;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2
M('!A8VMA9V4@36%I;"XB"FUS9W-T<B`B4&^^861O=F%N_2!P<F]G<F%M;W;]
M(&)A;.UK($UA:6P@8VAY8NT@=B!014%2+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES<VEN
M9R!S97-S:6]N($E$+B(*;7-G<W1R(")#:'EB[&KM8^T@240@<')O(')E;&%C
M:2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C4V"FUS9VED(")-;R(*;7-G<W1R(")0;R(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HW-`IM<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`B36]B
M:6QN[2!P;[ET82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8X"FUS9VED(")-;V1E<F%T92(*;7-G<W1R(")-[7)N_2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,PHC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@X"FUS9VED(")-;V1I9FEE9"!$
M871E(@IM<V=S='(@(D1A='5M('!O<VQE9&[M('IM[&YY(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4S"FUS
M9VED(")-;V1I9GD@55),(@IM<V=S='(@(EIM[/)I="!54DPB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W,PIM<V=I9"`B36]D=6QU
M<R(*;7-G<W1R(")-;V1U;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]L9&]V
M82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B36]L9.%V:64B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R(")-;VYA:V\B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(DUO;F=O;'-K;R(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.30*;7-G:60@(DUO;G1H(&%N9"!Y
M96%R(@IM<V=S='(@(DWL<^UC(&$@<F]K(@H*(SH@9G)A;65W;W)K+TUA:6YT
M96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*;7-G
M<W1R(")-['/MZ&[L(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-;VYT<V5R<F%T
M(@IM<V=S='(@(DUO;G-E<F%T(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@
M;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G
M<W1R(")&X7IE($WL<^UC92(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C$W,B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR-3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T
M:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP
M"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(DUA<F]K;R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@
M0VQE87(B"FUS9W-T<B`B4/AE=N&^;NP@:F%S;F\B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-`IM<V=I9"`B36]S=&QY($-L
M;W5D>2(*;7-G<W1R(")0^&5VX;YN["!O8FQAZ&YO(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*;7-G:60@(DUO<W1L>2!3
M=6YN>2(*;7-G<W1R(")0^&5VX;YN["!S;'5N9>AN;R(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4P.0IM<V=I9"`B36]V92!$;W=N
M(@IM<V=S='(@(E!O<W5N;W5T(&1O;/DB"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HU,3,*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R
M(")0;W-U;F]U="!D;VQE=F$B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HU,3<*;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`B4&]S
M=6YO=70@9&]P<F%V82(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C4P-0IM<V=I9"`B36]V92!5<"(*;7-G<W1R(")0;W-U;F]U="!N
M86AO<G4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-3(T"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B4&]S=6YO=70@9&]L
M^2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU
M,C,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R
M-`IM<V=I9"`B36]V92!U<"(*;7-G<W1R(")0;W-U;F]U="!N86AO<G4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.34*;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B36]S86UB
M:6LB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@T"FUS9VED(")-
M=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B5NUC92WZ<F]V
M\F]VZ2!R;VQE=&]VZ2!S97IN86UY(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$P-34*;7-G:60@(DUU;'1I;6%P(%5+(&UA
M<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0R
M"FUS9VED(")-=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B5NUC96[A<V]B
M;N$@<V5L96MC92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#`*
M;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T<B`B3?EJ(/KH970B"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z,C@*(RP@9G5Z>GD*;7-G:60@(DUY($%C8V]U
M;G0@26YF;W)M871I;VXB"FUS9W-T<B`B5F&Y92!I;F9O<FUA8V4B"@HC.B!S
M97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C4T"FUS9VED(")->2!0;W)T86PB
M"FUS9W-T<B`B3?EJ('!O<G3A;"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET
M+G!H<#HQ,S8*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B36]J
M92!R;WIL;[YE;NT@<&]R=.%L=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,34U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B37EA
M;FUA<B(*;7-G<W1R(")->6%N;6%R(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!
M9W)E92(*;7-G<W1R(").12P@3D533U5(3$%3S4TB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$P,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B3F%M92(*;7-G<W1R(")*;>EN;R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R(").86UI8FEE
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDW"FUS9VED(").875R=2(*;7-G<W1R(").875R=2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B3F5PX6PB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(DYI>F]Z
M96WM(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S
M(@IM<V=S='(@(DYI>F]Z96US:^D@06YT:6QY(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C87!E($)A<V4@
M55),(@IM<V=S='(@(DYE='-C87!E($)A<V4@55),(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C87!E($-!
M(%)E=F]C871I;VX@55),(@IM<V=S='(@(DYE='-C87!E($-!(%)E=F]C871I
M;VX@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.#4*;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!54DPB"FUS9W-T<B`B3F5T
M<V-A<&4@0T$@<&]L:6-Y(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P92!296YE=V%L(%523"(*
M;7-G<W1R(").971S8V%P92!296YE=V%L(%523"(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P92!2979O
M8V%T:6]N(%523"(*;7-G<W1R(").971S8V%P92!2979O8V%T:6]N(%523"(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED
M(").971S8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B2FWI;F\@3F5T
M<V-A<&4@4U-,('-E<G9E<G4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M
M;65N="(*;7-G<W1R(")0;WINX6UK82!K(&-E<G1I9FEKX71U($YE='-C87!U
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#`*;7-G
M:60@(DYE='-C87!E(&-E<G1I9FEC871E('1Y<&4B"FUS9W-T<B`B5'EP(&-E
M<G1I9FEKX71U($YE='-C87!U(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(U,0IM<V=I9"`B3F5T=V]R:R(*;7-G<W1R(")3[;LB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,S-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V"FUS9VED
M(").979E<B(*;7-G<W1R(").:6MD>2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B
M3F5W($-A;&5D;VYI82(*;7-G<W1R(").;W;A($MA;&5D;VYI92(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(V"FUS
M9VED(").97<@0V%T96=O<GDB"FUS9W-T<B`B3F]VX2!K871E9V]R:64B"@HC
M.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.#$*
M(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@W
M"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HY
M-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z
M,3`Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(").97<@365S<V%G92!T
M;R`E<R(*;7-G<W1R(")6>71V;_AI="!Z<'+A=G4@*"5S*2(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L
M;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`B3>QS
M[6,@=B!P<G9N[2#H='9R=&EN["(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T:6]N86PI
M(@IM<V=S='(@(DYO=ND@=;YI=F%T96QS:^D@:FWI;F\@*&YE<&]V:6YNZ2DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3@*;7-G:60@(DYE=R!:96%L86YD(@IM<V=S='(@(DYO
M=OT@6NEL86YD(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,W
M"B,L(&9U>GIY"FUS9VED(").97<@<&%S<W=O<F0B"FUS9W-T<B`B2&5S;&\B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z,C(W"B,L('!H<"UF
M;W)M870*;7-G:60@(DYE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R
M"B,L(&9U>GIY"FUS9VED(").97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*
M;7-G<W1R(")(97-L82!S92!M=7/M('-H;V1O=F%T+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W
M:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B3F]VZ2!O:VYO("A?<'+A>F1NZ2DB
M"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X.0IM<V=I
M9"`B3F5W<R(*;7-G<W1R(").;W9I;FMY(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,P-0IM<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R(").97=S
M9W)O=7!S(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34@=&5M
M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHQ,CD@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4*
M;7-G:60@(DYE>'0B"FUS9W-T<B`B1&%LN>TB"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T
M<B`B1&%LN>T@9N%Z92(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,S<R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<V"FUS9VED
M(").97AT(&]P=&EO;G,B"FUS9W-T<B`B1&%LN>T@;6^^;F]S=&DB"@HC.B!F
M<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C$P,PHC+"!F=7IZ>0IM<V=I9"`B
M3F5X=#XB"FUS9W-T<B`B1&%LN>TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI
M8V%R86=U82(*;7-G<W1R(").:6MA<F%G=6$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G
M:60@(DYI9V5R(@IM<V=S='(@(DYI9V5R(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED
M(").:6=E<FEA(@IM<V=S='(@(DYI9^ER:64B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S@P"FUS9VED(").:6=H="(*;7-G<W1R(").;V,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3<*;7-G:60@(DYI=64B"FUS9W-T<B`B3FEU92(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G
M:60@(DYO(@IM<V=S='(@(DYE(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P
M+V1I9F8N:'1M;#HY"FUS9VED(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO
M;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*;7-G<W1R("*N861N
MX2!K;VYF:6=U<F'H;NT@9&%T82!N96IS;W4@9&]S='5P;N$@<')O('IO8G)A
M>F5N[2!R;WID[6SY+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<BYP:'`Z,3`U"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@
M9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R(").96[M(&1O<W1U<&[A
M(+[A9&[A('-T<F%T96=I92!P<F\@='9O<F)U($E33R!O8G)A>ODN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S
M"FUS9VED(").;R!B871C:"!T96UP;&%T92XB"FUS9W-T<B`B0F5Z(&3A=FMO
M=NEH;R!V>F]R=2XB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HW.2!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-#4*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C8W"FUS9VED
M(").;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*
M;7-G<W1R(").82!P;[YA9&]V86[I('!O>FEC:2!N965X:7-T=6IE(+[A9&[]
M(&)L;VLB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C4P"FUS
M9VED(").;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R(").96)Y;&\@<&]S:WET;G5T;R"^X61NZ2!J
M;>EN;R!P<F\@:V%L96YDX?@@</AI(&]V[/AO=N%N[2!P;VUO8^T@34-!3"XB
M"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`IM<V=I9"`B3F\@8VAA;F=E
M+B(*;7-G<W1R(")"97H@>FWL;GDN(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HQ-38*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E
M9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(DYE;'IE('#X:61A=""^
MX61NX2!P;V0M<'+A=F$@:R!T[&UT;R!P<N%V^6TN(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ-C<@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HU,#(*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S<S"B,L('!H<"UF
M;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B3F5B>6QY('5V961E;GD@ON%D;ND@
M:V]N9FEG=7)AZ&[M(&EN9F]R;6%C92!P<F\@)7,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HX,C0*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R(").
M96)Y;'D@=79E9&5N>2"^X61NZ2!K;VYF:6=U<F'H;NT@:6YF;W)M86-E('!R
M;R!&5%`@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C8Y
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B3F5B>6QY('5V961E;GD@ON%D;ND@
M:V]N9FEG=7)AZ&[M(&EN9F]R;6%C92!P<F\@4U%,(%9&4RXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S$W"FUS9VED(").;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@
M5D93+B(*;7-G<W1R(").96)Y;'D@=79E9&5N>2"^X61NZ2!K;VYF:6=U<F'H
M;NT@:6YF;W)M86-E('!R;R!344PM1FEL92!61E,N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(").
M;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B3F5MX71E(+[A9&[](&MR961I="XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S-`IM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@
M(DYE8GEL('!O<VMY=&YU=""^X61N_2!C[6PN(@H*(SH@9G)A;65W;W)K+T)R
M;W=S97(O0G)O=W-E<BYP:'`Z.#<W"FUS9VED(").;R!F:6QE('5P;&]A9&5D
M(@IM<V=S='(@(J[A9&[]('-O=6)O<B!N96)Y;"!P^&5N97-E;B(*"B,Z('5T
M:6PO:6-O;E]B<F]W<V5R+G!H<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N
M(@IM<V=S='(@(DYE8GEL>2!N86QE>F5N>2"^X61NZ2!I:V]N>2XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(X(&QI8B]";&]C:R]S=6YR
M:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R,PIM<V=I9"`B
M3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R(").96)Y;&\@=GEB<N%N;R"^
MX61NZ2!M[7-T;RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,38Y"B,L(&9U>GIY"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS
M9W-T<B`B3F5B>6QO('9Y8G+A;F\@ON%D;ND@;>US=&\N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*;7-G:60@
M(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(DYE8GEL>2!P;W-K>71N
M=71Y(+[A9&[I('IP<N%V>2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S-@IM<V=I9"`B3F\@;F%M92!S<&5C:69I
M960N(@IM<V=S='(@(DYE8GEL;R!U=F5D96YO(+[A9&[I(&IMZ6YO+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W
M"FUS9VED(").;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R(").96)Y;&\@
M=79E9&5N;R"^X61NZ2#H[7-L;RXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z.30*;7-G:60@(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R(")"
M97H@;F5S;'6Y;OUC:"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP
M:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").96)Y;&\@<&]S:WET;G5T;R!H97-L
M;R!P<F\@;W;L^&5N[2!P;VUO8^T@2%144"XB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VEM87`N<&AP.C$P.`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($E-05`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYE8GEL;R!P
M;W-K>71N=71O(&AE<VQO('!R;R!O=NSX96[M('!O;6]C[2!)34%0+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-S(*;7-G:60@(DYO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B3F5B>6QO('!O<VMY=&YU=&\@:&5S;&\@<')O(&]V[/AE;NT@
M<&]M;V/M($ME<F)E<F]S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S
M;"YP:'`Z-S<@9G)A;65W;W)K+T%U=&@O075T:"]L;V=I;BYP:'`Z.#0*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<U"FUS9VED(").;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(DYE8GEL;R!P;W-K>71N=71O(&AE<VQO('!R;R!O=NSX96[M('#X:6AL
MX;EE;NT@<V4@9&\@<WES=.EM=2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W!A<W-W9"YP:'`Z,3,U"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").96)Y;&\@<&]S
M:WET;G5T;R!H97-L;R!P<F\@;W;L^&5N[2!P;VUO8^T@4$%34U=$+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HX-`IM<V=I9"`B3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B3F5B>6QO('!O<VMY=&YU=&\@:&5S;&\@<')O(&]V[/AE;NT@<&]M;V/M
M(%--0BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R
M.#8*;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R
M;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*
M(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*(DYE8GEL82!P
M;W-K>71N=71A(&-E<W1A(&L@8FENX7)N[6UU('-O=6)O<G4@3W!E;E-33"X@
M0FENX7)N[2!S;W5B;W(@3W!E;E-33"`B"B)J92!Z87!O=/AE8NT@<')O('!R
MX6-I(',@4$M#4R`Q,B!D871Y+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS
M9W-T<B`BKN%D;ND@;F5V>?CM>F5NZ2"^X61O<W1I(&\@</AI:&SAN65N[2XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-S4P"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(").;R!Q=6]T82!S970N(@IM<V=S='(@(DYE;NT@;F%S
M=&%V96YO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT,PIM<V=I9"`B3F\@<G5L97,B"FUS9W-T<B`B0F5Z('!R
M879I9&5L(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Y"B,L
M(&9U>GIY"FUS9VED(").;R!S97!A<F%T;W(@<W!E8VEF:65D+B(*;7-G<W1R
M(").96)Y;&\@=79E9&5N;R"^X61NZ2#H[7-L;RXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T"FUS9VED(").
M;R!S:61E<R(*;7-G<W1R(")"97H@;VMR86KY(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HU.#,*(RP@9G5Z>GD*;7-G:60@(DYO('-U8V@@9FEL
M92(*;7-G<W1R(")"97H@;VMR86KY(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$S.`IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A
M=F%I;&%B;&4@9F]R(&-A8VAE+B(*;7-G<W1R("*NX61N_2!Z(&1OZ&%S;OUC
M:"!A9')E<^'X^2!N96[M(&1O<W1U<&[]('!R;R!C86-H92XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,0IM<V=I9"`B
M3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(DYE
M8GEL;R!O9&5S;.%N;R"^X61NZ2!UOFEV871E;'-KZ2!J;>EN;R!A+VYE8F\@
M:&5S;&\N(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ-#`*
M;7-G:60@(DYO('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@(DYE
M8GEL82!N879RX6-E;F$@ON%D;N$@<&QA=&[A(%A-3"!D871A+B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-S$*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX,0HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3DR"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#`Y"FUS9VED(").
M;R!V86QU97,B"FUS9W-T<B`BKN%D;ND@:&]D;F]T>2(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ,C`*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@
M;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R(")6(&]R:6=I;N%L;NT@:V]N9FEG=7)A8VD@;F5B>6QA
M(&YA;&5Z96YA('9E<GIE+B!/8FYO=G1E(&MO;F9I9W5R86-I+B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E<G-I;VX@9F]U
M;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(E9E(%9AN>T@:V]N9FEG=7)A8VD@;F5B>6QA(&YA
M;&5Z96YA('9E<GIE+B!/8FYO=G1E(&MO;F9I9W5R86-I+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0U"B,Z('1E;7!L871E
M<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3,*;7-G:60@(DYO;F4B"FUS
M9W-T<B`BKN%D;OTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDP"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S
M='(@(J[A9&[]("AP;W6^:6IT92!I;7!L:6-I=&[M*2(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@Y"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*
M;7-G<W1R(")3979E<G-K_2`H25-/+3@X-3DM,3`I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV
M"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G<W1R(").;W)F;VQK<VOI(&]S
M=')O=GDB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K+VUO
M;VXN<&AP.C8P"FUS9VED(").;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@
M(E-E=F5R;NT@<&]L;VMO=6QE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-CD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(").;W)T
M:&5R;B!-87)I86YA($ES;&%N9',B"FUS9W-T<B`B4V5V97)N[2!-87)IX6YS
M:^D@;W-T<F]V>2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM<V=S
M='(@(DYO<G-K;R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C0P"FUS9VED(").;W0@069T97(B"FUS9W-T<B`B3F5N[2!P;R(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(").
M;W0@0F5F;W)E(@IM<V=S='(@(DYE;NT@</AE9"(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C0P.`IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM
M<V=S='(@(DYE;NT@861R97/A^&5M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+G!H<#HV,PHC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX,PHC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T
M<F%T96=Y+G!H<#HY-`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z
M-3D*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B3F5N[2!I;7!L
M96UE;G1O=N%N;RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C8X"FUS9VED(").;W0@<V5T(@IM<V=S='(@(DYE;NT@;F%S
M=&%V96YO(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(
M86YD;&5R+G!H<#HQ-#,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E
M<W-I;VY(86YD;&5R+G!H<#HQ-3@*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD
M;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S,*(SH@9G)A;65W;W)K+U-E<W-I
M;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#<*(SH@9G)A;65W;W)K
M+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HR,S0@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,C`U(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,S`*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C(T."!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C8U"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C(Y-PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S$R(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HS,CD*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,V,B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z-#(R"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HU,#$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4W,`HC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z-3@W(&9R86UE=V]R:R]61E,O5D93+G!H<#HV-C4*
M;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(DYE;NT@<&]D<&]R;W;A
M;F\N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(T-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`P-0HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3<X"FUS9VED(").;W1E<R(*;7-G<W1R(")0;WIN
MX6UK82(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I
M9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(DYI8R!K
M('!R;VALZ61N=73M+"!B[+YT92!Z<.QT+B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,3$*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED(").;W9E;6)E<B(*;7-G
M<W1R("),:7-T;W!A9"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P
M-#8*;7-G:60@(DYU;6)E<B(*;7-G<W1R("+([7-L;R(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$T,C4*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T
M97)S(@IM<V=S='(@(E!OZ&5T('IN86OY(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3,V.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(S"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#4@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O9B!C
M;VQU;6YS(@IM<V=S='(@(E!OZ&5T('-L;W5P8_DB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,S8W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T
M,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,R!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@IM<V=I9"`B3G5M8F5R
M(&]F(')O=W,B"FUS9W-T<B`B4&_H970@^.%D:_DB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B3G5M
M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I
M;VX@;&ES="XB"FUS9W-T<B`B3F5B>6QA('IA9.%N82#H[7-L82!P<F\@86MT
M=6%L:7IA8VD@9&ES=')I8G7H;NUH;R!S97IN86UU+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B3TLB"FUS
M9W-T<B`B3TLB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.#<S"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B3V)J96MT(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*;7-G:60@(D]B:F5C="!#
M<F5A=&]R(@IM<V=S='(@(E1V^7)C92!O8FIE:W3Y(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3$P-`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B3W-M
M:>AK;W;](@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0Q,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS9W-T<B`BV.UJ96XB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM
M<V=S='(@(D9I;'1R;W9A="!N97-L=;ENZ2(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS,C8*;7-G:60@(D]F9FEC92(*;7-G<W1R(")+86YC96SA
M^"(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B
M3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*(RP@
M9G5Z>GD*;7-G:60@(D]L9"!P87-S=V]R9"(*;7-G<W1R(")(97-L;R(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT-@HC+"!F=7IZ>0IM<V=I
M9"`B3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R(").97-P
M<N%V;ND@:&5S;&\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T
M<B`B3VWA;B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E
M9"!F;VQD97)S+B(*;7-G<W1R(")39.UL96[I('-L;[YK>2!J<V]U('!O<VMY
M=&]VX6YY('!O=7IE($E-05`@<V5R=F5R>2XB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM
M<V=S='(@(E!O=7IE(&YE<VQUN6[I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<Q"FUS9VED
M(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(DIE
M('!O=F]L96YA('!O=7IE(&IE9&YA(&4M;6%I;&]VX2!A9')E<V$N(@H*(SH@
M<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C8U"FUS9VED("(B"B)/;FQY('1H
M92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W
M;F5R<VAI<"!O<B!O=VYE<B`B"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*
M;7-G<W1R("(B"B)0;W5Z92!V;&%S=&[M:R!N96)O('-Y<W3I;6]V_2!A9&UI
M;FES='+A=&]R(&WYOF4@;>QN:70@<'+A=F$@<')O('-D[6QE;OT@(@HB;V)J
M96MT+B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,U"FUS9VED(")/<&5N
M(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")/=&5V^.UT('8@;F]VZ6T@;VMN
M["XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(T-0IM
M<V=I9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F
M<F]M('-I9VYE9"!3+TU)344@<&%R="XB"FUS9W-T<B`B0VAY8F$@3W!E;E-3
M3#H@3F5L>F4@>NUS:V%T(&1A=&$@>B!P;V1E<'-A;ND@Z.%S=&D@4R]-24U%
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I
M;F1O=R(*;7-G<W1R(")/=&5V^.UT('1E;G1O(&]D:V%Z('8@;F]VZ6T@;VMN
M["(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T
M:6YG(%-Y<W1E;2(*;7-G<W1R(")/<&5R8>AN[2!S>7-TZ6TB"@HC.B!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS(@IM
M<V=S='(@(DUOOFYO<W1I(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C,Q('1E
M;7!L871E<R]P<F5F<R]A<'`N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@
M(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@(DUOOFYO<W1I('!R;R`E<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G
M:60@(D]R9&5R960@3&ES="(*;7-G<W1R(")39?AA>F5N_2!S97IN86TB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B
M3W)G86YI<V%T:6]N(@IM<V=S='(@(D]R9V%N:7IA8V4B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T
M:6]N86P@56YI="(*;7-G<W1R(")/<F=A;FEZ8>AN[2!J961N;W1K82(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S(*;7-G:60@(D]R9V%N:7II
M;F<B"FUS9W-T<B`B3W)G86YI>F]VX6[M(@H*(SH@861M:6XO=&5M<&QA=&5S
M+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E
M(@IM<V=S='(@(D]R:6=I;N%L;NT@=GIO<B!P<F\@ON%D;W-T(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I
M9VEN86P@=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R(")/<FEG:6[A;&[M('9Z
M;W(@=B`E<SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y
M('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T
M<B`B3W-T871N[2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3`V"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3,Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#$*;7-G
M:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(D]S=&%T;NT@:6YF;W)M
M86-E(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,0IM<V=I9"`B
M3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B5;YI=F%T96QS:^$@<'+A=F$B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-SD*;7-G:60@(E!!
M32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")/
M=NSX96[M('!O;6]C[2!004T@;F5N[2!D;W-T=7!NZ2XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%
M05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,C<S"FUS9VED(")01U`@1&EG:71A;"!3:6=N
M871U<F4B"FUS9W-T<B`B4$=0(&1I9VETX6QN[2!P;V1P:7,B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S$Y"FUS9VED(")01U`@16YC
M<GEP=&5D($1A=&$B"FUS9W-T<B`B4$=0(+EI9G)O=F%NX2!D871A(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,W,0IM<V=I9"`B4$=0
M(%!U8FQI8R!+97DB"FUS9W-T<B`B5F7X96IN_2!01U`@:VSMZ"(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-3,*;7-G:60@(E!'4"!3
M:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B1&%T82!P;V1E<'-A;N$O
MN6EF<F]V86[A('!O;6]C[2!01U`B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z
M-C@*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(E!(4"!K\V0B"@HC.B!A9&UI
M;B]P:'!S:&5L;"YP:'`Z,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R(")0
M2%`@:V]N>F]L82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,W"FUS9VED(")032!,:6=H="!286EN(@IM<V=S='(@(D]D<&]L
M961N[2!L96AK_2!DZ;F[(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S@*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B3V1P
M;VQE9&[M('#X96CA\FMY(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`B3V1P;VQE
M9&[M('-N[+YE;NTB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT,`IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(D]D
M<&]L961N[2!S;NQH;W;I('#X96CA\FMY(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*(RP@9G5Z>GD*;7-G:60@(E!-(%-U
M;B(*;7-G<W1R(")/9'!O;&5D;NT@<V[LOF5N[2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0R"FUS9VED(")032!4+5-T;W)M
M<R(*;7-G<W1R(")/9'!O;&5D;NT@8F]U^&MY(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C(W-`IM<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I
M;F<B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Y"FUS9VED(")07TA0
M(%-H96QL(@IM<V=S='(@(E!?2%`@:V]N>F]L82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A
M9&1I;F<B"FUS9W-T<B`B3V1S='5P>2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B
M4&%K:7-T86XB"FUS9W-T<B`B4.%K:7-TX6XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS
M9VED(")086QA=2(*;7-G<W1R(")086QA=2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G
M:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B
M4&%L97-T:6YS:^D@=&5R:71O<FEU;2P@;VMU<&]V86[I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDX"FUS9VED(")086YA;6$B"FUS9W-T<B`B4&%N86UA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDY"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(E!A<'5A($YO
M=N$@1W5I;F5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.34@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4&%R86=U87DB"FUS
M9W-T<B`B4&%R86=U87DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS-@IM<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R(")-
M[7-T>2!Z871AOF5N;R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU,S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,34Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(P,3@*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW-R!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT,C,*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(DAE<VQO
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED(")0
M87-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,S(R"FUS9VED(")0
M87-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`B3F5S<'+A=F[I(&AE<VQO(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$U,@IM<V=I9"`B
M4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B4')O(&]V[/AE;NT@<&]M;V/M(%)!1%5)4R!J92!N=71N;R!Z
M861A="!H97-L;RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#4S
M"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")(
M97-L;R!S('!O='9R>F5N[6TB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z.3`*;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R(")(97-L;SHB"@HC
M.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0IM<V=I9"`B4&%S<W=O
M<F0Z("(*;7-G<W1R(")(97-L;SH@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S0*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@
M;6%T8V@N(@IM<V=S='(@(DAE<VQA('-E(&UU<^T@<VAO9&]V870N(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$Q.2!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G:60@(E!A<W1E(@IM<V=S
M='(@(E9L;[YI="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S
M='(@(E9L;[YI="!Z92!S8VARX6YK>2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`B
M0V5S=&$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I
M9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R("*NX61O<W1I(&\@</AI:&SA
MN65N[3HB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*;7-G:60@(E!E
M;W!L92(*;7-G<W1R("),:63I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`B
M4')O8V5N="(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC
M92YH=&UL.C0Y"FUS9VED(")097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO
M;G,B"FUS9W-T<B`B4')O=NES="!O<&5R86-E(/ID<KYB>2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT,#8*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`B4')O=NES="!O<&5R
M86-E(/ID<KYB>2!P^&D@</AI:&SAN65N[2!D;R!S>7-TZ6UU/R(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED(")097)M:7-S
M:6]N(@IM<V=S='(@(E!RX79A(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H
M<#HU,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<
M(B5S7"(@;F]T(&1E;&5T960N(@IM<V=S='(@(E!RX79O("<E<R<@;F5B>6QO
M('-M87KA;F\N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#8*
M(RP@9G5Z>GD*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(E!R
MX79A(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C$@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C0*(RP@9G5Z>GD*;7-G:60@
M(E!E<FUI<W-I;VYS(@IM<V=S='(@(E]0<N%V82(*"B,Z(&%D;6EN+W!E<FUS
M+V5D:70N<&AP.C$P.2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C`*(SH@
M861M:6XO<&5R;7,O:6YD97@N<&AP.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP
M:'`Z-3@*;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S
M='(@(D%D;6EN:7-T<F'H;NT@<'+A=F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C4*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@
M(D]S;V)N[2!I;F9O<FUA8V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!E<G4B
M"FUS9W-T<B`B4&5R=2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-0IM
M<V=I9"`B4&5T<R(*;7-G<W1R(")$;VWA8^T@>G;M^&%T82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY.0IM<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B1FEL:7#M;GDB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS
M9VED(")0:&]N92(*;7-G<W1R(")496QE9F]N(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0W.`IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(D9O=&]G
M<F%F:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0:71C86ER;B(*;7-G<W1R
M(")0:71C86ER;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T<B`B4&EX96SY(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS9VED(")0;&%T:71U9&5S
M(@IM<V=S='(@(D9RX7IE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN
M=&\@<V]M92!C96QL(@IM<V=S='(@(E!R;W/M;2!K;&EK;NQT92!N82!N[&IA
M:V]U(&)U\FMU(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T
M('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@(E!R
M;W/M;2!P;W1V<N]T92P@OF4@<VD@</AE:F5T92!O9'-T<F%N:70@=&5N=&\@
M<')V96LZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO
M=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(E!R;W/M
M;2!P;W1V<N]T92P@OF4@<VD@</AE:F5T92!O9'-T<F%N:70@=&5N=&\@<')V
M96LN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4W,0IM<V=I9"`B
M4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T<B`B4')O
M<^UM('IA9&5J=&4@;>QS[6,@82!R;VLN(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G:60@(E!L96%S92!E;G1E
M<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@(E!R;W/M
M;2!Z861E:G1E(&[A>F5V(&YO=ND@:V%T96=O<FEE.B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S,#$*;7-G:60@(E!L96%S92!E;G1E<B!A('9A
M;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(E!R;W/M;2!Z861E:G1E('-P<N%V
M;F]U($E0(&%D<F5S=2XN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C8V,`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@
M=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B4')O
M<^UM('IA9&5J=&4@<W!RX79N_2!D871U;2!A('IK;VYT<F]L=6IT92!P;^AE
M="!D;NT@=B!M['/M8VDN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C0U,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T
M<B`B4')O<^UM('IA9&5J=&4@<W!RX79N_2#H87,N(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@
M82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R(")0<F]S[6T@=79E
M[W1E('-H<FYU=.T@5F&Y96AO('!R;V)LZ6UU+B(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z,C(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR
M-@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S
M<W=O<F0B"FUS9W-T<B`B4')O<^UM('IA9&5J=&4@5F&Y92!UOFEV871E;'-K
MZ2!J;>EN;R!A(&AE<VQO(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C4X"B,L(&9U>GIY"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W
M:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S
M92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B"B)0<F]S[6T@</AEZ'3L=&4@
M<VD@;N%S;&5D=6KM8^T@=&5X="X@3553S51%('-O=6AL87-I="!S('!O9&WM
M;FMA;6D@<&]UONUVX6[M("(*(G-Y<W3I;74N(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S
M92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B4')O<^UM
M('IA9&5J=&4@;F]V_2!NX7IE=B!K871E9V]R:64Z(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY
M"FUS9VED(")0;VQA;F0B"FUS9W-T<B`B4&]L<VMO(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R(")0;VQI
M=&EK82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#<*;7-G:60@
M(E!O;&QS(@IM<V=S='(@(DAL87-O=N%N[2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G
M:60@(E!O<G1U9V%L(@IM<V=S='(@(E!O<G1U9V%L<VMO(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W
M"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(E5M
M[7-T[&[M('1O:&]T;R!O8G+A>FMU(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F
M('1H:7,@=&%B;&4B"FUS9W-T<B`B56WM<W3L;NT@=&%B=6QK>2(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0
M;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS
M9W-T<B`B6F%S;&%T(&1O('3I=&\@<VQOOFMY("AN96[M('!O<VMY=&YU=&\@
M24U!4&5M*2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C8V(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET
M871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(E-RX;YK>2!Z
M82!P;W-L961N[2AC:"D@)7,@:&]D:6XH=2DZ("(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR.3@*;7-G:60@(E!R96-I<&ET871I;VX\8G(@
M+SYC:&%N8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+VQD87`N<&AP.CDX"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S7VQD87`Z($YE
M8GEL82!N86QE>F5N82!P;[YA9&]V86[A('#X[7!O;F$@3$1!4"XB"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@(E!R
M969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B4')E9G-?<V5S<VEO;CH@3F5B>6QA(&YA;&5Z96YA
M('!OOF%D;W9A;N$@</CM<&]N82!S96MC92XB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(R-0IM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B0F%R;VUE=')I
M8VO]('1L86LB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U.0IM<V=I9"`B
M4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B0F%R;VUE=')I8VO]
M('1L86L@;F$@^G)O=FYI(&UO^&4Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,S4*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T<B`B0F%R
M;VUE=')I8VO]('1L86LZ(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(P-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R979I97<B"FUS
M9W-T<B`B3N%H;&5D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(T"FUS9VED(")0<F5V:65W('1H92!I
M;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B3N%H;&5D(&]B<N%Z:W4@
M=B!N;W;I;2!O:V[L(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HS-C(@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C8*;7-G:60@
M(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`B4/AE9&-H;WKM(&UOOFYO<W1I
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT
M,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B5&ES:VYO=70@9&]K
M=6UE;G0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*
M;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(E!R:7;A=&[M(&ML[>@B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38Y"FUS9VED(")0
M<F]B;&5M(@IM<V=S='(@(E!R;V)LZ6TB"@HC.B!S97)V:6-E<R]P<F]B;&5M
M+G!H<#HQ,C8*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`B
M4&]P:7,@<')O8FSI;74B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S8Y"FUS9VED(")0<F]J96-T<R(*;7-G<W1R(")0<F]J96MT>2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,3$@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C$X.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@U"FUS
M9VED(")0<F]M<'0@=&5X="(*;7-G<W1R(")0<F]M<'0@=&5X="(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4'5B;&EC
M($ME>2(*;7-G<W1R(")69?AE:F[](&ML[>@B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!!;&=O
M<FET:&TB"FUS9W-T<B`B06QG;W)I=&UU<R!P<F\@=F7X96IN_2!K;.WH(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#0*(RP@9G5Z
M>GD*;7-G:60@(E!U8FQI8R!+97D@26YF;R(*;7-G<W1R(")69?AE:F[](&ML
M[>@B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HR-#$*;7-G
M:60@(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C
M97-S9G5L;'DN(@IM<V=S='(@(E9E^&5J;OTO<')I=N%T;NT@:VSMZ&]V_2!P
MX7(@;F5B>6P@^G-P[+EN["!V>71V;_AE;BXB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS
M9VED(")0=65R=&\@4FEC;R(*;7-G<W1R(")0;W)T;W)I:V\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`R"FUS9VED(")1871A<B(*;7-G<W1R(")+871A<B(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HV,PIM<V=I9"`B475E<GDB"FUS9W-T<B`B5GEH;&5D
MX6[M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"B,L(&9U>GIY"FUS
M9VED(")1=6]T82(*;7-G<W1R(")+871A<B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C8S"B,L('!H<"UF;W)M870*;7-G:60@(E)3
M02!0=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@(E)302!V9?AE:F[](&ML
M[>@@*"5D(&)I=/DI(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V
M-`IM<V=I9"`B4F%D:6\@<V5L96-T:6]N(@IM<V=S='(@(E-P^&&^96[I('1L
M8>CM=&MO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#,*;7-G:60@(E)A:6XB"FUS9W-T<B`B1.FYNR(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")286EN($5A
M<FQY(@IM<V=S='(@(D)R>FO](&3IN;LB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I;B!,871E(@IM<V=S
M='(@(E!O>F1N[2!DZ;F[(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S='(@(D1E
MN;MO=ND@</AE:.'R:WDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT-PIM<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R(")$
MZ;F[('-E('-N[&AE;2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0X"FUS9VED(")286EN('1O(%-N;W<B"FUS9W-T<B`B1.FY
MNR!AOB!S;NUH(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@
M(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@(D[A:&]D;NP@=GEB<F%NZ2"Y=.QS
M=.TB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8X
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*;7-G:60@
M(E)A=&EO(@IM<V=S='(@(E!O;>QR(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ.#`*;7-G:60@(E)E860B"FUS9W-T<B`BR'1E8^TB
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PIM
M<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R(")0^&7H=&5NZ2!Z<'+A=GDB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I
M;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B3W!R879D=2!S;6%Z870@
M)7,_(%1A=&\@;W!E<F%C92!J92!N979R871NX2XB"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")2
M96%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R
M871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@HB3W!R879D=2!S
M;6%Z870@=;YI=F%T96QS:^$@9&%T82!P<F\@=;YI=F%T96QE("5S/R!4871O
M(&]P97)A8V4@:F4@;F5V<F%T;N$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B4F5D;V5S('EO=7(@;&%S
M="!A8W1I;VXB"FUS9W-T<B`B3W!A:V]V870@<&]S;&5D;NT@86MC:2(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C0V"FUS9VED(")2969R97-H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU
M($5L96UE;G1S.B(*;7-G<W1R(")/8FYO=FET(&1Y;F%M:6-KZ2!P<G9K>2!M
M96YU.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$*;7-G:60@(E)E
M9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(D]B;F]V82!Z;V)R87IE;NT@
M<&]R=.%L=3H@(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DT(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3,*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(S-0IM<V=I9"`B4F5G97@B"FUS9W-T<B`B4F5G97@B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C0Y"FUS9VED(")296QA=&EO
M;G-H:7`@0G)O=W-E<B(*;7-G<W1R(")0<F]H;.V^9>@@=GIT86CY(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(P.`HC+"!F=7IZ>0IM<V=I9"`B4F5L;V%D(@IM<V=S
M='(@(LAT96/M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C8*;7-G:60@
M(E)E;6%R:W,B"FUS9W-T<B`B2&]D;F]T>2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,30*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(E9Z
M9.%L96[I('-E<G9E<GDN(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C@T"FUS9VED(")296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N
M8V]M+VAO<F1E*3HB"FUS9W-T<B`B5GIDX6QE;N$@55),("AH='1P.B\O=W=W
M+F5X86UP;&4N8V]M+VAO<F1E*3HB"@HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V5D:70N:6YC.C(R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N
M:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI
M;F,Z,3,*;7-G:60@(E)E;6]V92(*;7-G<W1R(")/9'-T<F%N:70B"@HC.B!T
M96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$*;7-G:60@(E)E;6]V92!"
M;&]C:R(*;7-G<W1R(")/9'-T<F%N:70@8FQO:R(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HU-3<*;7-G:60@(E)E;6]V92!C
M;VQU;6XB"FUS9W-T<B`B3V1S=')A;FET('-L;W5P96,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0P"FUS9VED(")296UO
M=F4@9F]R;6%T=&EN9R(*;7-G<W1R(")/9'-T<F%N:70@9F]R;>%T;W;A;NTB
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B4F5M
M;W9E('!A:7(B"FUS9W-T<B`B3V1S=')A;FET('#A<B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HR,#(*;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@
M9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R(")/
M9'-T<F%T:70@=6QOOF5N_2!S:W)I<'0@>B!D;^AA<V[I:&\@861R97/A^&4@
M;F$@<V5R=F5R=2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#(*;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T
M<B`B3V1S=')A;FET(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO=F4@=&AI<R!N;V1E
M(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(D]D<W1R86YI="!T=71O(.CA
M<W0@9&]K=6UE;G1U(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M+FEN8SHQ,0IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`B3V1S=')A;FET
M('6^:79A=&5L92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI
M;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@=7-E<CH@)7,B"FUS
M9W-T<B`B3V1S=')A;FET('6^:79A=&5L93H@)7,B"@HC.B!F<F%M97=O<FLO
M4E!#+U)00R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q=65S="!C;W5L9&XG
M="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS9W-T<B`B
M3F5L>F4@;V1P;W;L9.QT(&YA('!OOF%D879E:RX@0VAY8F]VZ2!H;.&Y96[M
M.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W"B,L(&9U
M>GIY"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U
M;F0N(@IM<V=S='(@(E#X96YE<V5N_2!S;W5B;W(@;F5L>F4@=6QOOFET+B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<T(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z-3$R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R(")0;[YA9&]V86[I("<E<R<@;F5B>6QO('5V961E
M;F\@=B!K;VYF:6=U<F%C:2!P<F\@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HV-S4@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,S`*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R,PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C
M:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E!OOF%D;W9A
M;ND@)R5S)R!N96)Y;&\@=79E9&5N;R!V(&MO;F9I9W5R86-I('!R;R!61E,N
M(@H*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S@Q"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE
M9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")0;[YA9&]V86[I("<E<R<@
M;F5B>6QO('5V961E;F\@=B!K;VYF:6=U<F%C:2XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,S4*;7-G:60@(E)E<75I<F5D($9I
M96QD(@IM<V=S='(@(E!OOF%D;W9A;ND@<&]L92(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C,Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S.0HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,C`@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C$P,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C<W"FUS9VED(")297-E="(*;7-G<W1R(")6_6-H;WKM(&YA<W1A
M=F5N[2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"FUS9VED
M(")297-E="!087-S=V]R9"(*;7-G<W1R(")6_6-H;WKM(&YA<W1A=F5N[2!H
M97-L82(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W"FUS9VED
M(")297-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(E;]8VAO>NT@;F%S=&%V
M96[M(%9AN65H;R!H97-L82(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S`*
M(RP@9G5Z>GD*;7-G:60@(E)E<W1O<F4@3&%S="!1=65R>2(*;7-G<W1R(")0
M;W-L961N[2#H='9R=&EN82(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HW,2!A
M9&UI;B]C;61S:&5L;"YP:'`Z,C@@861M:6XO<W%L<VAE;&PN<&AP.C8V"FUS
M9VED(")297-U;'1S(@IM<V=S='(@(E;]<VQE9&MY(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C$P,2!T96UP;&%T97,O<')E9G,O96YD+FEN
M8SHW"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R(").X79R870@
M9&\@;6^^;F]S=.TB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M,S@*(RP@9G5Z>GD*;7-G:60@(E)E='EP92!N97<@<&%S<W=O<F0B"FUS9W-T
M<B`B5OUC:&]Z[2!N87-T879E;NT@:&5S;&$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS
M9VED(")2975N:6]N(@IM<V=S='(@(E)E=6YI;VXB"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*;7-G
M:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(E#X97!N;W5T(&MO
M;F9I9W5R86-I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,@IM<V=I
M9"`B4FEC:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S='(@(DUOOFYO<W1I
M(%)I8V@@5&5X="!E9&ET;W)U(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4X"FUS9VED(")2:61D;&5S(@IM<V=S='(@(DCA9&%N:WDB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0X"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*;7-G
M:60@(E)I9VAT(@IM<V=S='(@(D1O<')A=F$B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,3(Q"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T<B`B
M2&QA=FGH:V$@;F%P<F%V;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,3<*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R(")(;V1N;W1Y(&YA
M<')A=F\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G
M<W1R(")6;&%S=&YO<W1I(/CA7V1K=2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`B
MVFQO:&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM<V=S='(@
M(E)U;75N<VMO(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(R-0IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R(")/=&_H:70@
M;R`Q.#"P(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(R,@IM<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`B3W1OZ&ET(&1O
M;&5V82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,C@*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R(")/=&_H:70@9&]P
M<F%V82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0<F]P97)T:65S(@IM<V=S='(@(E9L
M87-T;F]S=&D@^.%D:W4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE<R(*
M;7-G<W1R(")6;&%S=&YO<W1I(/CA9&MU(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S
M='(@(MCA9&MY.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-3,*;7-G:60@(E)U;&5S(@IM<V=S='(@(E!R879I
M9&QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A
M;&P@<F]W<R!A;F0@8V]L=6UN<R(*;7-G<W1R(")0<F%V:61L82!S92!U<&QA
M=&[M(&UE>FD@=KEE;6D@^.%D:WD@82!S;&]U<&-I(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T
M<B`B4')A=FED;&$@<V4@=7!L871N[2!P;W5Z92!M97II('-L;W5P8VDB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL
M>2(*;7-G<W1R(")0<F%V:61L82!S92!U<&QA=&[M('!O=7IE(&UE>FD@^.%D
M:WDB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P"FUS9VED(")2=6XB"FUS
M9W-T<B`B4')O=NES="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)U<W-I86X@
M1F5D97)A=&EO;B(*;7-G<W1R(")2=7-KX2!F961E<F%C92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#,*;7-G:60@(E)W86YD82(*;7-G<W1R(")2=V%N9&$B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%
M($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(E,O34E-12"Y:69R
M;W9A;OT@<&]D<&ES(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*;7-G
M<W1R(")3+TU)344@N6EF<F]V86[A('IP<N%V82(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<V%S;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T:&5N=&EC871I
M;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3W;L^&5N[2!P;VUO8^T@
M4T%33"!N96[M(&1O<W1U<&[I+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HU,#0*;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T<B`B4TU3('IP
M<N%V>2(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B4U%,(%-H
M96QL(@IM<V=S='(@(E-13"!K;VYZ;VQA(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S(X,PIM<V=I9"`B4U%,('-T871E;65N="!F;W(@=F%L=64@
M;&]O:W5P<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#,Q"FUS9VED(")34T@B"FUS9W-T<B`B4U-((@H*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H
M<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R("+:4U#,0T@B"@HC.B!L:6(O
M87!I+G!H<#HQ-3,*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B4U]13"!K
M;VYZ;VQA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`B4V\B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T
M"FUS9VED(")386EN="!(96QE;F$B"FUS9W-T<B`B4W9A=.$@2&5L96YA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@T"FUS9VED(")386EN="!+:71T<R!A;F0@3F5V:7,B"FUS
M9W-T<B`B4W9A=/T@2VET=',@82!.979I<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I
M9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B4V%I;G0@3'5C:6$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`P"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S
M='(@(E-A:6YT(%!I97)R92!A;F0@36EQ=65L;VXB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U
M"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G
M<W1R(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@
M(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R(")3=&5J;OT@<N%M("A?<V5L
M9BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")386UO82(*;7-G<W1R(")386UO
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T<B`B
M4V%N($UA<FEN;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N
M9"!0<FEN8VEP92(*;7-G<W1R(")386\@5&]M92!A;F0@4')I;F-I<&4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3871E
M;&QI=&4@4')O=FED97(B"FUS9W-T<B`B5FQA<W1N[6L@<V%T96QI='4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`S"FUS9VED(")3875D:2!!<F%B:6$B"FUS9W-T<B`B4V%U
M9'-KX2!!<N%B:64B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M.3@*;7-G:60@(E-A=F4B"FUS9W-T<B`B56QOOFET(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B56QOOFET("5S(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4V%V92`E<R(*;7-G<W1R(")5;&^^:70@)7,B"@HC.B!T96UP;&%T
M97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T
M<B`B56QOOF5N[2!M;[YN;W-T[2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-C<*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@
M87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*
M(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB56QOOFET('9Y='9O^&5N_2!K;VYF
M:6=U<F'H;NT@4$A0('-K<FEP="!D;R!D;^AA<V[I:&\@861R97/A^&4@;F$@
M<V5R=F5R=2XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R(")+;VYF:6=U<F%C92`E<R!U;&^^96YA+B(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.CDS"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3
M879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R
M(")+;VYF:6=U<F'H;NT@<VMR:7!T('!R;R!A:W1U86QI>F%C:2!B>6P@=6QO
MOF5N(&1O.B`G)7,G+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0Y"B,L(&9U>GIY"FUS9VED(")38V%T=&5R960@5"U3=&]R
M;7,B"FUS9W-T<B`B3VIE9&EN[&SI(&)O=?AK>2(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R(")6[&1A(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C:"(*;7-G<W1R
M(")6>6AL961A="(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C`*
M;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(E9Y:&QE9.%V86/M(&[A
M<W1R;VIE(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDW,PIM<V=I
M9"`B4V5L96-T($9I;&5S(@IM<V=S='(@(E9Y8G)A="!S;W5B;W)Y(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-`IM<V=I
M9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R(")6>6)R870@9&%T=6TB"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B4V5L96-T(&$@
M9W)O=7`@=&\@861D(@IM<V=S='(@(E9Y8G)A="!S:W5P:6YU+"!K=&5RX2!B
M=61E('#X:63A;F$B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S
M"FUS9VED(")396QE8W0@82!N97<@;W=N97(B"FUS9W-T<B`B5GEB<F%T(&YO
M=NEH;R!V;&%S=&[M:V$B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z-C`*;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R(")6>6)R870@
M<V5R=F5R(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-38*;7-G
M:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S='(@(E9Y8G)A="!UOFEV
M871E;&4L(&MT97+](&)U9&4@</AI9.%N(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-PHC+"!F=7IZ>0IM<V=I9"`B4V5L
M96-T(&%L;"(*;7-G<W1R(")6>6)R870@<V]U8F]R>2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(V-C,*;7-G:60@(E-E;&5C="!A;&P@9&%T92!C
M;VUP;VYE;G1S+B(*;7-G<W1R(")6>6)R870@=KEE8VAN>2#HX7-T:2!D871U
M;74N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C@W,PIM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R(")6>6)R870@
M;V)J96MT(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C8W.`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B
M5GEB<F%T(&YO=NEH;R!V;&%S=&[M:V$B"@HC.B!S97)V:6-E<R]K97EB;V%R
M9"YP:'`Z,S<*;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@
M;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@
M86YD("(*(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R
M("(B"B)6>6)E<G1E('!O=/AE8F[I('IN86MY('H@;NV^92!U=F5D96[]8V@@
M8F]X^2X@4&]TZ2!J92!M^;YE=&4@:V]P[7)O=F%T(&$@(@HB=FQOOFET('H@
M=&5X=&]VZ2!O8FQA<W1I+B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C,T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R
M(")6>6)E<G1E(&]D9.QL;W9A8^T@>FYA:R!P<F\@9&%T=6TZ(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T
M92!F;W)M870Z(@IM<V=S='(@(E9Y8F5R=&4@9F]R;>%T(&1A='5M=3HB"@HC
M.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDP"FUS9VED
M(")396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93HB"FUS
M9W-T<B`B5GEB97)T92!I9&5N=&ET=2P@:W1E<F]U('-I('#X96IE=&4@>FWL
M;FET.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"FUS9VED(")3
M96QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R(")6>6)E<G1E(&]D
M9.QL;W9A8^T@>FYA:R!P<F\@Z&%S.B(*"B,Z('1E;7!L871E<R]D871A+W1I
M;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE('1I;64@9F]R;6%T.B(*;7-G
M<W1R(")6>6)E<G1E(&9O<FWA="#H87-U.B(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE
M;&1S+B(*;7-G<W1R(")6>6)E<G1E(&1V["!O9'!O=NUD86KM8^T@<&]L92XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`V"FUS9VED(")396QE8W0@
M>6]U<B!C;VQO<B!S8VAE;64N(@IM<V=S='(@(E9Y8F5R=&4@8F%R979N_2!M
M;W1I=BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0X"FUS9VED(")3
M96QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(E9Y8F5R
M=&4@5N%M:2!P<F5F97)O=F%N_2!J87IY:SHB"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R
M="(*;7-G<W1R(")0;W-L870@>G!RX79U(&\@<')O8FSI;74B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`S.0IM<V=I9"`B
M4V5N9"!335,B"FUS9W-T<B`B4&]S;&%T(%--4R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*
M;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B4V5N96=A;"(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S$V"FUS9VED(")396YS;W(Z("(*;7-G<W1R(")396YS
M;W(Z(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P.0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S,*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R("):X?CM(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I82!A
M;F0@36]N=&5N96=R;R(*;7-G<W1R(")3<F)S:V\@82#(97)NX2!(;W)A(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#$*;7-G:60@
M(E-E<FEA;"!.=6UB97(B"FUS9W-T<B`B4^ER:6]VZ2#H[7-L;R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*(RP@9G5Z>GD*;7-G:60@
M(E-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(D)L;VL@;R!P;^AA<^T@;F5N[2!D;W-T=7!N_2XB"@HC.B!A9&UI;B]S97-S
M:6]N<RYP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(E-E<W-I;VX@061M:6XB"FUS
M9W-T<B`B061M:6YI<W1R8>AN[2!P<N%V82(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@IM<V=I9"`B4V5S<VEO
M;B!)1"!E>'!I<F5D+B(*;7-G<W1R("))1"!S96MC92!Z86YI:VQO+B(*"B,Z
M(&QI8B]A<&DN<&AP.C$T-0HC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;G,B"FUS
M9W-T<B`B7U!RX79A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q
M-`IM<V=I9"`B4V5T(@IM<V=S='(@(DYA<W1A=FET(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<V"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y
M;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@
M:70N(@IM<V=S='(@(DYA<W1A=FET(&UOOFYO<W1I('!R;R!P;W9O;&5N[2!R
M97-E='4@:&5S;&$L('!O:W5D(&AO('IA<&]M96YE=&4N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$Q-0IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V
M97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN
M(@IM<V=S='(@(DYA<W1A=FET('9Z9.%L96[I('-E<G9E<GD@=&%K+""^92!B
M=61O=2!P^.US='5P;ND@>B!P;W)TX6QU+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX-`IM<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E
M+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R(").87-T879E
M;NT@5N%M:2!P<F5F97)O=F%NZ6AO(&IA>GEK82P@Z&%S;W;I:&\@<.%S;6$@
M82!T>7!U(&1A='5M=2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*
M;7-G:60@(B(*(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R
M('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA
M>2!O<'1I;VYS+B(*;7-G<W1R("(B"B).87-T879E;NT@<&_HX71EZ&[M(&%P
M;&EK86-E+"!B87)E=F[I:&\@;6]T:79U+"!O8FYO=F]VX6[M('-T<N%N96L@
M82!D86RY[6-H("(*(FUOOFYO<W3M('IO8G)A>F5N[2XB"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C<U"FUS9VED(")3971U<"(*;7-G<W1R(").87-T
M879E;NTB"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS
M-PIM<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G
M<W1R(").87-T879O=F%C[2!K;VYF:6=U<F'H;NT@<VMR:7!T>2!P<F\@86MT
M=6%L:7IA8VD@:G-O=2!D;W-T=7!NZ2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ.#8*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I
M8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(D[L:W1E<N$@;>US
M=&$@;'IE(&YA<W1A=FET(',@=.UM=&\@<&%R86UE=')E;3H@(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-`IM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R(")397EC:&5L;&5S
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Y-@IM<V=I9"`B4VAO
M<'!I;F<B"FUS9W-T<B`B3F%K=7!O=N%N[2(*"B,Z('1E;7!L871E<R]P<F]B
M;&5M+W!R;V)L96TN:6YC.C0S"FUS9VED(")3:&]R="!3=6UM87)Y(@IM<V=S
M='(@(DMRX71KZ2!S:')N=73M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0T-@IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R
M(&UO<W0@;&EN:W,_(@IM<V=S='(@(DWL;'D@8GD@8OUT('#X[7-T=7!O=ND@
M:VSMZ&4@9&5F:6YO=N%N>2!P<F\@=NQTN6EN=2!O9&MA>OD_(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B
M"FUS9W-T<B`B6F]B<F%Z:70B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,34U"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N
M=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(EIO8G)A>FET(')O>F3M;'D@;65Z:2!S;W7H87-N
M;W4@82!P^&5D8VAO>NT@:V]N9FEG=7)A8^TN(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0Y,`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@=VAE
M;B!L;V=G:6YG(&EN/R(*;7-G<W1R("):;V)R87II="#H87,@<&]S;&5D;NUH
M;R!P^&EH;.&Y96[M(&1O('-Y<W3I;74_(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3<V-0IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG
M:6YA;"(*;7-G<W1R("):;V)R87II="!M;[YN;W-T('5D<KYE;NT@;W)I9VEN
MX6QU(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,PIM<V=I9"`B
M4VAO=R!P:6-K97(B"FUS9W-T<B`B6F]B<F%Z:70@<V+L<F'H(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4R-@IM<V=I9"`B4VAO=R!T86)L92!O<&5R
M871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R("):;V)R87II="!M96YU(&]P97)A
MZ&[M(&QIN71U('!R;R!T86)U;&MY/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N
M=2!O;B!T:&4@;&5F=#\B"FUS9W-T<B`B6F]B<F%Z:70@)7,@;65N=2!N86QE
M=F\_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!486)L92!#96QL(%!R;W!E
M<G1I97,@9&EA;&]G(@IM<V=S='(@(EIO8G)A>FET(&1I86QO9R!P<F\@=FQA
M<W1N;W-T:2!B=6[L:R!V('1A8G5L:^%C:"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B4VAO
M=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B6F]B<F%Z
M:70@9&EA;&]G('9L87-T;F]S=.T@=&%B=6QE:R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I9"`B
M4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@
M(EIO8G)A>FET(&1I86QO9R!V;&%S=&YO<W3M(/CA9&5K('1A8G5L96LB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-3(*;7-G:60@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G
M(@IM<V=S='(@(EIO8G)A>FET(&1I86QO9R!V;&%S=&YO<W3M(&]B<N%Z:_DB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8S"FUS9VED(")3:&]W
M('5P;&]A9"(*;7-G<W1R("):;V)R87II="!P^&5N;W,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I9"`B4VAO=V5R
M<R(*;7-G<W1R(")0^&5HX?)K>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4Q"FUS9VED(")3:&]W97)S($5A<FQY(@IM<V=S
M='(@(D)R>FOI('#X96CA\FMY(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G<W1R
M(")0;WID;NT@</AE:.'R:WDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI
M='DB"FUS9W-T<B`B4/AE:.'R:WD@=B!O:V]L[2(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C0X,`IM<V=I9"`B4VAR:6YK(@IM<V=S
M='(@(EIM96ZY:70B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HW-S0@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.#,V
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.CDR,B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY.#0*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3`T-R!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HQ,#@W"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C$Q,38@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z,3$T.0IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG
M(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(EIM96ZY
M:70@;F5B;R!P;W-U;F]U="!D;R!S;W5S961N[6AO(&)L;VMU*/DI+"!Z(&-E
M<W1Y('!R=F[M;74B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3:65R<F$@3&5O
M;F4B"FUS9W-T<B`B4VEE<G)A($QE;VYE(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.C(V-0IM<V=I9"`B4VEG;B!U<"(*;7-G<W1R(")2
M96=I<W1R;W9A="!S92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-S$R"FUS9VED(")3:6=N871U<F4B"FUS9W-T<B`B4&]D<&ES(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3$*;7-G:60@
M(E-I9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`B06QG;W)I=&UU<R!P<F\@
M<&]D<&ES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S
M='(@(E-I;F=A<'5R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HV-2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#<@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DV"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$R,34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-PHC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0V(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Y,S`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R
M,PIM<V=I9"`B4VEZ92(*;7-G<W1R(")696QI:V]S="(*"B,Z('1E;7!L871E
M<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4R"FUS9VED(")3:VEP
M($UA:6YT96YA;F-E(@IM<V=S='(@(E9Y;F5C:&%T(/ID<KYB=2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#4*;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@(E-L;W9E;G-K;R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@(E-L;W9I
M;G-K;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4T"FUS9VED(")3;F]W(@IM<V=S='(@(E-N[+YE;NTB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VYO=R!3
M:&]W97(B"FUS9W-T<B`B4V[L:&]VX2!P^&5HX?)K82(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V"FUS9VED(")3;F]W(%-H
M;W=E<G,B"FUS9W-T<B`B4V[L:&]VZ2!P^&5HX?)K>2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS9VED(")3;F]W(%-H
M;W=E<G,@16%R;'DB"FUS9W-T<B`B4F%N;NT@<V[L:&]VZ2!P^&5HX?)K>2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS
M9VED(")3;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R(")0;WID;NT@<V[L:&]V
MZ2!P^&5HX?)K>2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<X"FUS9VED
M(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B4V[L:&]VX2!P;VMR_79K83HB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X,@IM<V=I9"`B4VYO=R!E<75I=F%L
M96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B5F]D;NT@96MV:79A;&5N="!P<F\@
M<V[M:#H@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)<VQA;F1S
M(@IM<V=S='(@(JEA;&%M;W5N;W9Y(&]S=')O=GDB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V
M"FUS9VED(")3;VUA;&EA(@IM<V=S='(@(E-O;>%L<VMO(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED(")3;VYG<R`F(%!O96US(@IM<V=S
M='(@(E#M<V[L(&$@8N%S;NPB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.3(V"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R(")3
M;>QR('3X[63L;NTB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"FUS9VED(")3;W5R8V4@861D<F5S<R(*
M;7-G<W1R("):9')O:F]VX2!A9')E<V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED
M(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`B2FF^;NT@069R:6MA(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@(E-O=71H($5U<F]P96%N("A)
M4T\M.#@U.2TS*2(*;7-G<W1R(")*:6AO979R;W!S:_T@*$E33RTX.#4Y+3,I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<W"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@
M4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R(")3;W5T:"!'96]R9VEA
M(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O
M=71H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B2FF^;NT@<&]L;VMO=6QE(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*
M;7-G:60@(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',B"FUS9W-T<B`B
M4')O<W1O<B!M97II('-O=7-E9&[M;6D@8G7R:V%M:2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C
M92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@
M(E!R;W-T;W(@;65Z:2!O8G-A:&5M(&$@:')A;FEC96UI('8@8G7R8V4B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX,34*;7-G:60@(E-P86-E<B(*
M;7-G<W1R(")-97IE<F[M:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R
M(")-97IE<GDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C:6YG(&%N9"!P861D:6YG(@IM
M<V=S='(@(D]D<W1U<'D@82!M97IE<GDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B
M4W!A:6XB"FUS9W-T<B`BJ7!A;NQL<VMO(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.CDX"FUS9VED(")3<&%M(@IM<V=S='(@(E-P86TB"@HC.B!S
M97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@0VAA<F%C
M=&5R($EN<'5T(@IM<V=S='(@(E9S='5P('!R;R!Z=FSAN71N[2!Z;F%K>2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C(*;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`B4F]Z9.QL:70@8G7R
M:W4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8V"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B4F]Z9.QL
M:70@<VQO=7!E8R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*;7-G<W1R(")2
M;WID[&QI="#XX61E:R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,0IM
M<V=I9"`B4W!O<G1S(@IM<V=S='(@(E-P;W)T(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS
M9VED(")3<FD@3&%N:V$B"FUS9W-T<B`B4W)I($QA;FMA(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C<S(&QI8B]";&]C:R]M971A<BYP:'`Z
M-S0*;7-G:60@(E-T86YD87)D(@IM<V=S='(@(E-T86YD87)D(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED(")3=&%R(%1R96LB"FUS9W-T
M<B`B4W1A<B!4<F5K(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y
M-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`Y"FUS9VED(")3=&%R="!Y
M96%R(@IM<V=S='(@(E)O:R!Z8>CA=&MU(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@(E-T871E(&]R(%!R;W9I;F-E
M(@IM<V=S='(@(E-TX70@Z&D@<')O=FEN8VEE(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G<W1R
M(")3=&%V(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-0IM<V=I
M9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`B1F]R;>%T('5L;[YE;NTB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,@IM<V=I9"`B
M4W1R965T($%D9')E<W,B"FUS9W-T<B`B56QI8V4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q"FUS9VED(")3=')I:V5T
M:')O=6=H(@IM<V=S='(@(E#X9;EK<G1N=73](@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(S,PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B
M4V5Z;F%M(/AE=.QZ8V4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.#<S"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G
M<W1R(")/9'-T<F%N:70@9&]MZ6YO=ND@:FWI;F\@>B!A9')E<WDB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(S
M"FUS9VED(")3='EL92!;0U-372(*;7-G<W1R(")3='EL(%M#4U-=(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM<V=I
M9"`B4W4B"FUS9W-T<B`B3F4B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z
M,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8F1I<F5C=&]R>2!<
M(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")0;V1A9')E<^'X("<E<R<@;F5B
M>6P@;F%L97IE;BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J96-T(@IM<V=S='(@(E#X961M['0B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(@9G)A;65W;W)K+T9O
M<FTO1F]R;2]296YD97)E<BYP:'`Z,S$W"FUS9VED(")3=6)M:70B"FUS9W-T
M<B`B4&]D870B"@HC.B!S:6=N=7`N<&AP.C0Y"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB
M('1O('1H92!S>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y;W5R
M("(*(G)E<75E<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*(D)Y
M;&$@<&]DX6YA(+[A9&]S="!O('#X:63A;NT@)R5S)R!D;R!S>7-TZ6UU+B!"
M=61E=&4@<V4@;6]C:2!P^&EH;.%S:70@8;X@<&\@(@HB:VQA9&[I;2!V>?CM
M>F5N[2!68;GM(+[A9&]S=&DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S='(@
M(D1O;&[M(&EN9&5X(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P-`HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S
M=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S='(@(MIS<.RY;NPB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M
M+B(*;7-G<W1R("(G)7,G(&)Y;"AA*2#Z<W#LN6[L('#X:63A;BAA*2!D;R!S
M>7-TZ6UU+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@
M=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R(")$871A('!R
M;R!UOFEV871E;&4@)7,@8GEL82#Z<W#LN6[L(&]D<W1R86[L;F$@>F4@<WES
M=.EM=2XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS+V1E
M;&5T92YP:'`Z-#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!D96QE=&5D(%PB)7-<(BXB"FUS9W-T<B`BVG-P[+EN["!O9'-T
M<F%N[&YA("<E<R<N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S
M7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("(G)7,G(/IS<.RY;NP@;V1S
M=')A;NQN*&$I('IE('-Y<W3I;74N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R
M871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B2V]N9FEG
M=7)A8V4@8GEL82#Z<W#LN6[L('IM[&[L;F$N($]B;F]V=&4@<W1RX6YK=2XB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BVG-P[+ENZ2!U;&^^96[M('KA;&^^
M;NT@:V]N9FEG=7)A8V4N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@=&AE
M(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(MIS<.RY
M;ND@=6QOOF5N[2!ZX6QO:'D@:V]N9FEG=7)AZ&[M:&\@<V]U8F]R=2`E<RXB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*;7-G<W1R("+:
M<W#LN6[A(&%K='5A;&EZ86-E('!R;R`G)7,G(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@
M(B5S(&)Y;&\@^G-P[+EN["!Z87!SX6YO(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I
M9"`B4W5D86XB"FUS9W-T<B`B4W5DX6XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"FUS9VED(")3=6UM87)Y
M(@IM<V=S='(@(E-H<FYU=.TB"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M-C4*;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@(E-V[73A;NTB"@HC.B!L:6(O
M0FQO8VLO<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U;B!3970B"FUS9W-T<B`B
M6N%P860@4VQU;F-E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-3D*;7-G:60@(E-U;FYY(@IM<V=S='(@(E-L=6YEZ&YO(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-@IM<V=I9"`B4W5N
M<FES92(*;7-G<W1R(")6_6-H;V0@4VQU;F-E(@H*(SH@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3
M=6YR:7-E+U-U;G-E="(*;7-G<W1R(")6_6-H;V0O>N%P860@4VQU;F-E(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-0IM<V=I9"`B4W5N
M<FES93H@(@IM<V=S='(@(E;]8VAO9"!3;'5N8V4Z("(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,3D*;7-G:60@(E-U;G-E="(*;7-G<W1R
M("):X7!A9"!3;'5N8V4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C$X"FUS9VED(")3=6YS970Z("(*;7-G<W1R("):X7!A9"!3;'5N8V4Z
M("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@(DAO<F[M(&EN9&5X(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W.`IM<V=I9"`B4W5P<&]R
M="(*;7-G<W1R(")0;V1P;W)A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4W5R
M:6YA;64B"FUS9W-T<B`B4W5R:6YA;64B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4W-`IM<V=I9"`B4W5R;F%M92(*;7-G<W1R(")0
M^.UJ;65N[2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-V86QB87)D(&%N9"!*
M86X@36%Y96XB"FUS9W-T<B`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R(")3=V%Z:6QS
M:V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS9W-T<B`BJ7;I
M9'-K;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-38@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")3=VET>F5R;&%N9"(*;7-G<W1R
M("*I=OUC87)S:V\B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX
M-@HC+"!F=7IZ>0IM<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G<W1R(").
M97-M87IA="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#(*;7-G:60@
M(E-Y;F--3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW
M;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R
M;7,B"FUS9W-T<B`B4WEN=&%X;W;A(&-H>6)A('8@:&QE9&%NZ6T@=&5X='4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`W"FUS9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*
M;7-G<W1R(")3_7)I92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8P"FUS9VED(")4+5-T;W)M(@IM<V=S='(@(D)O=?AK82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Q"FUS
M9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B5"U3=&]R
M;7,B"FUS9W-T<B`B0F]U^&MY(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(E0M4W1O<FUS($5A
M<FQY(@IM<V=S='(@(D)R>FOI('#X96CA\FMY(@H*(SH@9G)A;65W;W)K+T1A
M=&$O1&%T82]T<W8N<&AP.C$V-@IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B
M5%-6('-O=6)O<B(*"B,Z(&9R86UE=V]R:R]522]522]486)L92YP:'`Z,3,T
M"FUS9VED(")486)L92(*;7-G<W1R(")486)U;&MA(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B
M5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R(")6;&%S=&YO<W1I('1A8G5L:WDB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W
M"B,L(&9U>GIY"FUS9VED(")486)L92!3970B"FUS9W-T<B`B5&%B=6QK82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS9W-T<B`B5FQA<W1N
M;W-T:2!T86)U;&MY(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S0@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I
M=V%N(@IM<V=S='(@(E1A:7=A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H
M:6YA(@IM<V=S='(@(E1A:7=A;BP@<')O=FEN8VEE(,CM;GDB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`Y"FUS9VED(")486II:VES=&%N(@IM<V=S='(@(E1A9+YI:VES=.%N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!297!U
M8FQI8R!O9B(*;7-G<W1R(")486YZX6YI92P@4W!O:F5NX2!R97!U8FQI:V$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU
M"FUS9VED(")487)G970Z(@IM<V=S='(@(D/M;#HB"@HC.B!C;VYF:6<O:&]O
M:W,N<&AP+F1I<W0Z.3DV(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#<*
M;7-G:60@(E1A<VMS(@IM<V=S='(@(MIK;VQY(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E1E;&5P:&]N92!.=6UB
M97(B"FUS9W-T<B`B5&5L969O;F[M(.CM<VQO(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR.3`*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S
M='(@(E1E<&QO=&$@>F$@<&]S;&5D;NT@:&]D:6YU.B`B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(Q-`IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B
M5&5P;&]T82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C,*
M;7-G:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`B5&5P;&]T83H@(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G
M.R5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T
M92YP:'`Z-C@W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T
M92!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")6>F]R("<E<R<@;F5B>6P@
M;F%L97IE;BXB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I9"`B
M5&5M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`B5GIO<B!P<F\@861M
M:6YI<W1R86-I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,V"FUS9VED(")497AT(@IM<V=S
M='(@(E1E>'0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<U"FUS9VED
M(")497AT($]N;'DB"FUS9W-T<B`B4&]U>F4@=&5X="(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G:60@
M(E1E>'0@86QI9VXB"FUS9W-T<B`B6F%R;W9NX6[M('1E>'1U(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B
M5&5X='1O<"(*;7-G<W1R(")6<F-H('1E>'1U(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T
M<B`BR'0B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B5&AA
M:2`H5$E3+38R,"DB"FUS9W-T<B`B5&AA:G-K>2`H5$E3+38R,"DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`Y"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R(")4:&%J<VMO(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"FUS9VED(")4:&%N:R!Y
M;W4@9F]R('5S:6YG('1H92!S>7-T96TN(@IM<V=S='(@(D3L:W5J96UE('IA
M('!O=;[M=N%N[2!S>7-TZ6UU+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z.#(P"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A
M:6QA8FQE+B(*;7-G<W1R(")0^.UP;VYA('!R;R!&5%`@;F5N[2!D;W-T=7!N
MX2XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG
M:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(DEN=&5G<F'H
M;NT@86QG;W)I=&UY('8@2&]R9&4O2V]L86(@;F5P;V1P;W)U:NT@7"(E<UPB
M(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O0F]O:RYP:'`Z,3(Y,@HC
M+"!F=7IZ>0IM<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET
M:6%L:7IE9"XB"FUS9W-T<B`B4/AE;F5S96[]('-O=6)O<B!N96QZ92!U;&^^
M:70N(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4
M:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U
M;&QY(@IM<V=S='(@(DYE^G-P[+ENZ2!N8>AT96[M('3X[61Y($UA:6YT96YA
M;F-E.CHB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y
M"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN
M9RXB"FUS9W-T<B`B0GEL;R!U>F%V^&5N;R!O:VYO(',@;6^^;F]S=&UI+B!5
M:V]NZ&5N;RXB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$X.2!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(P,`HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C(Q,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(R
M,PHC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(S-"!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C(U,@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C(V-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,P,PIM<V=I9"`B
M(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R
M;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@=&\@
M=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B"B)!9&UI;FES='+M=&]R('!O
M=/AE8G5J92!N86MO;F9I9W5R;W9A="!T<G9A;.$@<'+A=F$@=B!S>7-TZ6UU
M+"!P;VMU9"!S:2`B"B)P^&5J971E('!O=;[M="!P<N%V82XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS
M9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R(")0;W5Z92!S<&]D
M;NT@<W1R86YA(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT86-T($E$(&YU;6)E
M<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O
M=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B(@HB3F5B>6QO('5V
M961E;F\@240@<')O(&MO;G1A:W0L(&YE8GEL;R!N86QE>F5N;R!V(&1A=&%B
MX7II(&YE8F\@8GEL;R#Z<&QN["`B"B)V>6YE8VCA;F\N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4Q"FUS9VED(")4:&4@
M8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S
M<R!B;V]K+B(*;7-G<W1R(")+;VYT86MT(&)Y;"#Z<W#LN6[L('#X:63A;B!D
M;R!68;EE:&\@861R97/A^&4N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3$V.0IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N
M871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@
M;65S<V%G92XB"FUS9W-T<B`B2R!O=NSX96[M('!O9&5P<V%NZ2!Z<'+A=GD@
M:F4@=/AE8F$@;V1D[&QE;OT@8FQO:R!S(%!'4"!P;V1P:7-E;2XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM
M<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@
M;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@
M=&AE(&1A=&%B87-E+B(*;7-G<W1R("(B"B).96)Y;&\@=79E9&5N;R!)1"!D
M:7-T<FEB=>AN[6AO('-E>FYA;74L(&YE8GEL;R!N86QE>F5N;R!V(&1A=&%B
MX7II(&YE8F\@(@HB8GEL;R#Z<&QN["!V>6YE8VCA;F\N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*;7-G:60@
M(E1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"XB"FUS
M9W-T<B`B3F5B>6P@=79E9&5N(&1I<W1R:6)UZ&[M('-E>FYA;2XB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q,PIM<V=I9"`B5&AE(&5N8W)Y
M<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO
M;BXB"FUS9W-T<B`B(@HBJ6EF<F]V86/M(&UOOFYO<W1I(&QZ92!V>76^[70@
M<&]U>F4@</AI(&)E>G!EZ&[I;2!S<&]J96[M(',@=V5B96T@*&AT='!S*2XB
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-2!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C4Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@
M(E-O=6)O<B`E<R!B>2!M[&P@;V)S86AO=F%T(&YA<W1A=F5N[2`E<RXB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V."!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL
M92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+B(*;7-G<W1R
M(")3;W5B;W(@)7,@8GD@;>QL(&]B<V%H;W9A="!N[&MT97+A('H@;F%S=&%V
M96[M("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(Q.0IM
M<V=I9"`B5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N
M(@IM<V=S='(@(E-O=6)O<B!N96QZ92!K;W#M<F]V870@<^%M(&1O('-E8F4N
M(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@
M9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B4V]U8F]R(&YE;V)S
M86AU:F4@ON%D;N$@9&%T82XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T
M:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*
M;7-G<W1R(").X7-L961U:NT@:&QA=FGH:WD@<')O(&UE<W-A9V4O<F9C.#(R
M('IP<N%V=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN
M;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L
M(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@
M=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A
M9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R
M86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@
M5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A
M("='96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E
M8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P
M<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R
M965N(&5D:71O<BXB"FUS9W-T<B`B(@HB2F4@>F[A;>DL(+YE(&WS9"!P^&5S
M(&-E;&]U(&]B<F%Z;W9K=2!V($EN=&5R;F5T($5X<&QO<F5R=2!P^7-O8NT@
M<')O8FSI;7DL("(*(G!R;W1OOF4@<V4@=B!N[&T@=GES:WET=6IE(&-H>6)A
M+"!K=&5RZ2!S92!N96QZ92!V>6AN;W5T+B!*86MO(&[A<VQE9&5K(&WYOF4@
M(@HB8OUT(&[A:&]D;ND@>FAR;W5C96[M('1O:&]T;R!P<F]G<F%M=2P@8VAY
M8NQJ[6/M(&9U;FMC92!E9&ET;W)U(&YE8F\@(@HB;F5S<'+A=F[I('IO8G)A
M>F]VX6[M+B!0;VMU9"!J92!6X;D@<WES=&5MZ6T@5VEN;V1W<R`Y>"P@:F4@
M=F5L;6D@(@HB<')A=F3L<&]D;V)NZ2P@OF4@<V4@;V)J97;M(&-H>6)O=ND@
M:&SAN65N[2`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A("(*(F)U9&5T
M92!M=7-E="!R97-T87)T;W9A="!P;^CM=&'H+EQ<;EQ<;D)Y;&D@:G-T92!V
M87)O=N%N:2X@4')O<^UM('-T:7-K;NQT92`B"B)/2R!P;VMU9"!S:2!P^&5J
M971E('!O:W)AZ&]V870@=B!M\V1U('#X97,@8V5L;W4@;V)R87IO=FMU+B(*
M"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S
M='(@(DED96YT:71A(%PB)7-<(B!B>6QA('-M87KA;F$N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I
M9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B4&]U>F4@;F$@
M;&5VZ2!S=')A;NPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN
M87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*
M;7-G<W1R(")5;>US=.QN[2!B:6[A<F[M:&\@<V]U8F]R=2!';G501R!M=7/M
M(&+]="!Z863A;F\@9&\@=/CM9'D@0W)Y<'1?<&=P.CHN(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-1$XN<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C
M="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G
M=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N
M9&5R<W1O;V0N(@IM<V=S='(@(B(*(EIP<N%V82!Z87-L86[A('8@)7,@:R`E
M<R!S('#X961M['1E;2!<(B5S7"(@8GEL82!Z;V)R87IE;F$N7&XB"B)4;W1O
M(&YE>F%R=>AU:F4L(+YE('IP<N%V82!B>6QA('#X9>AT96YA(&YE8F\@OF4@
M:NT@861R97/A="AK82D@<F]Z=6WL;"AA*2XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.#<W"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L
M:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B3N%Z978L(&MT
M97+](&)U9&4@<&]UOFET('#X:2!O9&MA>F]VX6[M(&YA('-T<N%N8V4@='9O
M<F)Y('IP<N%V(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Q
M"B,L(&9U>GIY"FUS9VED(")4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E
M(&YU;65R:6,N(@IM<V=S='(@(E1O=&\@<&]L92!M=7/M(&+]="!P;&%T;ND@
MZ.US;&\N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ
M,C,Q"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R
M('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R(")4^.UD
M82!(;W)D95]#<GEP=%]S;6EM93HZ('9YOF%D=6IE(&UO9'5L(&]P96YS<VPN
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+G!H<#HR.3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO
M="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M
M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*(DYE;'IE('5L;[YI
M="!N87-T879E;NT@7"(E<UPB+"!P<F]T;[YE(&IE:&\@=F5L:6MO<W0@</AE
M<^%H;&$@<&]V;VQE;OT@;&EM:70N(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O9&5B+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=V5B8W!P+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E
M<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R(").96)Y
M;&$@;F%L97IE;F$@87!L:6MA8V4@<')O(.AT96[M('1O:&]T;R!T>7!U(&1A
M="`H)7,I+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0U-`IM
M<V=I9"`B5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@
M8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@
M86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R(")0;W5Z92!N82!P<F%VZ2!A
M(&QE=ND@<W1R86[L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED
M92!O;FQY(@IM<V=S='(@(E!O=7IE(&YA('!R87;I('-T<F%N["(*"B,Z(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T-@IM<V=I9"`B5&AE('-E<&%R
M871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D
M+B(*;7-G<W1R(")397)V97(@7"(E<UPB(&)Y;"!V>6UA>N%N+B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R
M(")397)V97(@7"(E<UPB(&)Y;"!U;&^^96XN(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S
M="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B0GEL82!O9'-T
M<F%N[&YA(+[A9&]S="!O('#X:6ALX;EE;NT@<')O("5S+B(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C,S,`IM<V=I9"`B5&AE('-P
M96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(E!OOF%D;W9A
M;OT@^.%D96L@;F5E>&ES='5J92XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y
M(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")$;^AA<V[]
M('-O=6)O<B!<(B5S7"(@;F5E>&ES='5J92XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,S$Q"FUS9VED(")4:&4@=&5X="!Y;W4@96YT97)E9"!D
M:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY
M(@IM<V=S='(@(E!O=7IE(&YA:&_X92!A(&1O;&4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4
M:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R(")0;W5Z92!N86AO^&4B"@HC.B!F
M<F%M97=O<FLO1&%T82]$871A+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO861E
M9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G
M<W1R("):=')A=&EL82!S92!P^&5N97-E;N$@9&%T82!Z('#X961C:&]Z[6AO
M(&MR;VMU+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O8W-V+G!H<#HR-C(@
M9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$W,@IM<V=I9"`B5&AE('5P
M;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R(")0^&5N
M97-E;OT@<V]U8F]R(&YE;'IE('5L;[YI="XB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-#8@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C4V"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,34@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q.0IM<V=I9"`B5&AE('=E871H97(N
M8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D)L;VL@=V5A
M=&AE<BYC;VT@;F5N[2!D;W-T=7!N_2XB"@HC.B!U=&EL+VEC;VY?8G)O=W-E
M<BYP:'`Z,C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D
M:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B3F5B>6P@;F%L
M97IE;B!A9')E<^'X(',@=.EM871Y("<E<R<N(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ-S@*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I
M;VYS(&%V86EL86)L92XB"FUS9W-T<B`BKN%D;ND@>B!M;[YN;W-T[2!N96IS
M;W4@9&]S='5P;NDN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z,S0R"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@
M8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B3F5B>6QY(&YA;&5Z96YY
M(+[A9&[I(.CA<W1I+"!K=&5RZ2!B>2!B>6QO(&UOOFYO('IO8G)A>FET('8@
M^.%D:W4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30P,0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C
M=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A
M8W1E<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T
M<B`B(@HB4/CM;&FY(&UN;VAO('IN86OY('8@<&]L:2X@6F%D86QI(&IS=&4@
M)7,@>FYA:_D[(&UU<^UT92!Z861A="!MZ6[L(&YEOB`E<R`B"B)Z;F%K^2XB
M"@HC.B!S:6=N=7`N<&AP.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN
M9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`B3F%S=&%L82!C
M:'EB82!P^&D@</AI9.%VX6[M("<E<R<@9&\@<WES=.EM=3H@)7,B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<
M(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B3F%S=&%L82!C:'EB
M82!P^&D@;V1S=')A\F]VX6[M('6^:79A=&5L<VO]8V@@9&%T("<E<R<@>F4@
M<WES=.EM=3H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG
M(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R(").87-T86QA(&-H
M>6)A('#X:2!O9'-T<F'R;W;A;NT@)R5S)R!Z92!S>7-TZ6UU.B`B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ-3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G
M<W1R(").87-T86QA(&-H>6)A('#X:2!A:W1U86QI>F%C:2`G)7,G.B`E<R(*
M"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I
M;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(DYA<W1A
M;&$@8VAY8F$@</AI('#X96YO<W4@<V]U8F]R=3H@)7,@;F5B>6P@</AE;F5S
M96XN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@Y"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE
M(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@
M(B(*(DYA<W1A;&$@8VAY8F$@</AI('#X96YO<W4@<V]U8F]R=2X@)7,@;F5M
M^;YE(&+]="!V['2Y[2!N9;X@;6%X:6WA;&[M("(*(G!O=F]L96[A('9E;&EK
M;W-T("@E9"!B>73Y*2XB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R
M+G!H<#HX.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@
M<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY
M('!A<G1I86QL>2!U<&QO861E9"XB"FUS9W-T<B`B3F%S=&%L82!C:'EB82!P
M^&D@</AE;F]S=2!S;W5B;W)U.B!B>6QA('#X96YE<V5N82!J96X@Z.%S="!S
M;W5B;W)U("5S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y
M:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(D1ON6QO(&L@8VAY8NP@
M</AI('IO8G)A>F]VX6[M('3I=&\@Z.%S=&D@>G!RX79Y(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G
M<W1R(").87-T86QA(&-H>6)A('#X:2!I;7!O<G1O=N%N[2!K;VYT86MT=2XB
M"@HC.B!F<F%M97=O<FLO1&%T82]$871A+VEM8RYP:'`Z,S$*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A
M+B(*;7-G<W1R(")0^&D@:6UP;W)T;W;A;NT@:4-A;&5N9&%R(&1A="!D;[EL
M;R!K(&-H>6+L+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#`*;7-G
M:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO
M;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I
M96QD+B(*;7-G<W1R("(B"B)#:'EB82!V(&MO;F9I9W5R8>AN[6T@9F]R;75L
MX?AI+B!:^&5J;>P@:G-T92!V>6YE8VAA;&D@<&^^861O=F%NZ2!P;VQE+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,X"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T
M:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*
M(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB3F%S=&%L82!C:'EB82!P
M^&D@<')O=N%D[&[M('IA9&%NZ2!O<&5R86-E('8@861R97/A^&DN(%!R;W/M
M;2!Z:W5S=&4@=&\@(@HB<&]Z9.QJ:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L
M96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@
M</AI(&%K='5A;&EZ86-I(&MO;G1A:W1U+B!0<F]S[6T@>FMU<W1E('1O('!O
M>F3L:FDN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HR,C(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN
M9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T
M97(N(@IM<V=S='(@(B(*(DYA<W1A;&$@8VAY8F$@</AI(&%K='5A;&EZ86-I
M(&1I<W1R:6)UZ&[M:&\@<V5Z;F%M=2X@4')O<^UM('IK=7-T92!T;R`B"B)P
M;WID[&II+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C$T.`IM<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P
M;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B5&5N=&\@24U!4"!S97)V
M97(@;F5P;V1P;W)U:F4@<V3M;&5N[2!S;&^^96LN(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S
M(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T
M<B`B5&]T;R!N979Y<&%DX2!J86MO('!L871N_2!R87(@87)C:&EV+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@
M(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N
M(@IM<V=S='(@(E1O=&\@;F5V>7!A9.$@:F%K;R!P;&%T;OT@>FEP('-O=6)O
M<BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,30U"FUS9VED(")4
M:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BXB
M"FUS9W-T<B`B5&]T;R!N979Y<&%DX2!J86MO('!L871NZ2#H[7-L;R!K87)T
M>2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HQ.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG
M(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B
M"B)C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)
M(@IM<V=S='(@(B(*(E1E;G1O(&]V;&%D8>@@=6UOOO)U:F4@<&]S[6SA;NT@
M>G!RX78@<&]M;V/M($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+B(*
M(F-O;2D@8G+A;GD@</AI('!O=;YI=.T@2%144"!!4$DB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S-`HC+"!F=7IZ>0IM<V=I
M9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@
M=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@(@HB9V%T97=A
M>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*(E1E;G1O(&]V;&%D
M8>@@=6UOOO)U:F4@<&]S[6SA;NT@>G!RX78@<&]M;V/M('-M<S)E;6%I;"`H
M:'1T<#HO+W-M<S)E;6%I;"XB"B)C;VTI(&)RX6YY('#X:2!P;W6^:73M($A4
M5%`@05!)(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU,34*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO
M+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%0
M22(*;7-G<W1R("(B"B)496YT;R!O=FQA9&'H('5M;[[R=6IE('!O<^ULX6[M
M('IP<N%V('!O;6]C[2!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN(@HB
M8V]M*2!B<N%N>2!P^&D@<&]UOFET[2!(5%10($%022(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U"FUS9VED
M("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V
M:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y
M+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M
M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W
M=RXQ.3`N:70I+B(*;7-G<W1R("(B"B)496YT;R!O=FQA9&'H('5M;[[R=6IE
M('!O<^ULX6[M('IP<N%V('!O;6]C[2!33510(&1O(%9O9&%F;VYE($ET86QY
M(&)RX6YY("(*(G!O=7IE('!R;R#H[7-L82!P;W-K>71N=73I(%9O9&%F;VYE
M;2X@375S[71E(&WM="!E;6%I;&]V_2#ZZ&5T('4@5F]D869O;F4@(@HB271A
M;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HY-S@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`U-PHC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#@V(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Q,34*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X,B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C4V"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$S,#4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Y.`HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-34W(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$X,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DU
M."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`U"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(P,CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`W
M.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,30Y(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(R,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C0Q,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4T"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(V-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C@R.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3,W(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,S,#8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S@Q-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#(R"FUS9VED(")4
M:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R(")4;W1O('!O;&4@:F4@
M;G5T;ND@=GEP;&YI="XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,#8U"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E
M<G,N(@IM<V=S='(@(E1O=&\@<&]L92!M^;YE(&]B<V%H;W9A="!P;W5Z92!C
M96SA(.CM<VQA+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3@*
M;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N
M9"!T:&4@8V]L;VXN(@IM<V=S='(@(E1O=&\@<&]L92!M^;YE(&]B<V%H;W9A
M="!P;W5Z92!C96SA(.CM<VQA(&$@9'9O:G1EZ&MU+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$P.30*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N
M;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(E1O=&\@<&]L92!M
M^;YE(&]B<V%H;W9A="!P;W5Z92!O<VUIZ&MO=ND@Z.US;&$N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$R,PIM<V=I9"`B5&AI<R!F:65L9"!M
M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT
M96=E<G,B"FUS9W-T<B`B5&]T;R!P;VQE(&UU<^T@8OUT('-E>FYA;2!C96S]
M8V@@Z.US96P@;V1D[&QE;OUC:"#HX7)K;W4@;F5B;R!M97IE<F]U(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3@Y"FUS9VED(")4:&ES(&9I96QD
M(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@(E1O=&\@<&]L92!M
M=7/M(&+]="!P;&%T;ND@Z.US;&\N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C@S-@IM<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@
M82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP
M;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R("(B"B)4;W1O('!O;&4@;75S[2!P
M8G-A:&]V870@8F%R979N_2!K\V0@=B"Y97-T;N%C:V]VZ6T@4D="(&9O<FWA
M='4L(&YA</@N("(*(B<C,3(S-&%F)RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HU-C$*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B965N
M('!R;V-E<W-E9"XB"FUS9W-T<B`B5&5N=&\@9F]R;75LX?@@:FF^(&)Y;"!Z
M<')A8V]VX6XN(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B5&]T;R!J
M92`E<RXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0U.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E
M(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N
M(&5M86EL("(*(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'
M<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@(@HB
M8VQI96YT<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@HB5&]T;R!J92!O
M8FIE:W0@2V]L86(@1W)O=7!W87)U+B!+('IH;.ED;G5T[2!T;VAO=&\@;V)J
M96MT=2!J92!Z87!O=/AE8NT@;>UT("(*(G!ON71O=F[M:&\@:VQI96YT82P@
M:W1E<OT@<F]Z=6WM(&9O<FWA='4@2V]L86(@1W)O=7!W87)U+B!0<F\@<V5Z
M;F%M("(*(G1A:V]V_6-H(&ML:65N=/D@<')O<^UM(&YA=KET:79T92`E<R(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@
M82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS
M9W-T<B`B5&%T;R!Z<'+A=F$@8GEL82!N87!SX6YA('8@:FENZ2!Z;F%K;W;I
M('-A9.P@*"5S*2!N9;X@5F&Y[2X@(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@
M;&5A<W0@;VYE+B(*;7-G<W1R(")4;W1O(.CM<VQO(&UU<^T@8OUT(&YE:FWI
M;NP@:F5D;F$N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z
M:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S
M('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`B4V5R=F5R(&YE;?F^92!R
M;WIB86QI="!Z:7`@82!G>FEP('-O=6)O<GDN(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ.#D*;7-G:60@(E1H:7,@<WES=&5M
M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"XB"FUS9W-T<B`B5&5N=&\@<WES
M=.EM(&IE('8@<V]UZ&%S;F]S=&D@9&5A:W1I=F]V86[]+B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E
M(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(E1A=&\@:&]D;F]T82!M=7/M
M(&+]="#H[7-L;RXB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N
M<&AP.C,U"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M
M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S='(@(E1O=&\@;VMN;R!M=;YE(&+]
M="!V;VSA;F\@<&]U>F4@>B!O:VYA(&UOOFYO<W3M(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*;7-G:60@(E1H=6YD97(B
M"FUS9W-T<B`B2/AM[&[M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(S-`IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R("),[7-T:WDB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#(X('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(U-0IM<V=I9"`B5&EM92(*;7-G<W1R("+(87,B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@V"FUS9VED(")4:6UE(%1R86-K:6YG
M(@IM<V=S='(@(E-L961O=N%N[2#H87-U(@H*(SH@;&EB+T)L;V-K+W1I;64N
M<&AP.C$W"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R(")&;W)MX70@Z&%S
M=2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U,SD*;7-G:60@(E1I
M;64@<V5L96-T:6]N(@IM<V=S='(@(E;]8NQR(.AA<W4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$P"FUS9VED(")4:6UO<BU,97-T92(*;7-G<W1R(")4:6UO<BU,97-T92(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@
M;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@
M(E1I='5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R(")4:71U
M;"`H=&EP*3HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R(")+;VUU(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U-`IM<V=I9"`B(@HB
M5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R
M;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN
M9RXB"FUS9W-T<B`B(@HB4&]K=60@<VD@</AE:F5T92!V>6)R870@=NUC92!P
M;VQOOF5K+"!Z;>'H:V[L=&4@:VSA=F5S=2!#;VYT<F]L("A00RD@;F5B;R`B
M"B)#;VUM86YD("A-86,I(&$@:VQI:V[L=&4@;F$@<&]L;[YK=2XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Q"FUS9VED(")4;V1A>2(*
M;7-G<W1R(")$;F5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S
M='(@(E#X97!N;W5T(&YA($A434P@>F1R;VHB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS
M9VED(")4;V=O(@IM<V=S='(@(E1O9V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED
M(")4;VME;&%U(@IM<V=S='(@(E1O:V5L874B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S$S"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R("):
M[71R82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O;F=A(@IM<V=S='(@(E1O
M;F=A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<W"FUS9VED(")4;W`B"FUS9W-T<B`B5G)C:"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O
M<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B2&]R;NT@<N%M("A?=&]P*2(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I9"`B5')A;G-L871I;VYS
M(@IM<V=S='(@(E#X96ML861Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5')I
M;FED860@86YD(%1O8F%G;R(*;7-G<W1R(")4<FEN:61A9"!A(%1O8F%G;R(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W.3`*;7-G:60@(E1R=64@
M;W(@9F%L<V4B"FUS9W-T<B`B4W!RX79N["!N96)O(+EP871N["(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3<*;7-G:60@
M(E1U(@IM<V=S='(@(MIT(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5N:7-I
M82(*;7-G<W1R(")4=6YI<VMO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5R
M:V5Y(@IM<V=S='(@(E1U<F5C:V\B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$Y,@IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B5'5R
M96-K>2`H25-/+3@X-3DM.2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=7)K
M;65N:7-T86XB"FUS9W-T<B`B5'5R:VUE;FES=.%N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M.`IM<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S(@IM<V=S='(@(E1U
M<FMS(&$@0V%I8V]S(&]S=')O=GDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4
M=79A;'4B"FUS9W-T<B`B5'5V86QU(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN
M<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S='(@(DYA
M<&FY=&4@5F&Y:2!V;VQB=3HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C8Y"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS9W-T<B`B52Y6+B!I
M;F1E>#H@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM<V=I9"`B55),(@IM
M<V=S='(@(E523"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E
M;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B55),('!R;R!Z<'+A=G4@
M;R!S=&%V=2!Z87-L86[I:&\@<VMR:7!T=2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3<*;7-G:60@(E523#HB"FUS9W-T
M<B`B55),.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5G86YD82(*;7-G<W1R
M(")59V%N9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")5:W)A:6YE(@IM<V=S
M='(@(E5K<F%J:6YA(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M-#$R"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM
M<V=S='(@(E9&4R!A9')E<^'X(&IE(&YE</CM<W1U<&[]+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B56YA8FQE('1O
M(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"XB
M"FUS9W-T<B`B4/AI(')E9VES=')A8VD@;F5L>F4@</AI9&%T(&5X=')A('6^
M:79A=&5L<VOI(/ID86IE+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,S@X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@
M<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").96QZ
M92!Z;>QN:70@<'+A=F$@<')O(%9&4R!S;W5B;W(@7"(E<UPB+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,X-2!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S
M='(@(DYE;'IE('IM[&YI="!P<N%V82!P<F\@5D93('-O=6)O<B`E<R\E<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R(").
M96QZ92!Z;>QN:70@;F$@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HR,S(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<UPB+B(*;7-G<W1R(").96QZ92!P
M^&5S=6YO=70@5D93('-O=6)O<B!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z-C@X(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M,3`Q-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z.#,T"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL
M92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`B3F5L>F4@</AE:FUE;F]V
M870@5D93('-O=6)O<B`E<R\E<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W-Q;"YP:'`Z-#,U"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@
M<V5R=F5R+B(*;7-G<W1R(").96QZ92!S92!P^&EP;VII="!K(%-13"!S97)V
M97)U+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,Y"FUS9VED
M(")5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`B3F5L>F4@
M<V4@</AI<&]J:70@<&]M;V/M(%-33"XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HR,C4@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C,P
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ.38@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y"FUS9VED(")5;F%B;&4@=&\@8V]P>2!6
M1E,@9FEL92XB"FUS9W-T<B`B3F5L>F4@:V]P[7)O=F%T(%9&4R!S;W5B;W(N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-C4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB
M)7-<(BXB"FUS9W-T<B`B3F5L>F4@=GET=F_X:70@5D93(&%D<F5SX?@@7"(E
M<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,U-"!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C4X"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HR-38*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@
M5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F5L>F4@=GET=F_X:70@5D93(&%D
M<F5SX?@N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$R-`IM
M<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9FEL92XB"FUS9W-T<B`B3F5L
M>F4@=GET=F_X:70@5D93('-O=6)O<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C(X-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&-R96%T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B3F5L
M>F4@</AE:FUE;F]V870@5D93('-O=6)O<B!<(B5S7"(N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,C8U"FUS9VED(")5;F%B;&4@=&\@8W)E
M871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R(").96QZ92!V>71V;_AI="!P
M<N%Z9&[](%9&4R!S;W5B;W(N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+W1A<BYP:'`Z-S8*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+V=Z:7`N<&AP.C<Y"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D
M871A+B(*;7-G<W1R(").96QZ92!R;WIB86QI="!D871A+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z,C(T(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z,CDX"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE
M=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T
M<B`B3F5L>F4@=GEM87IA="!<(B5S7"(L('!R;W1OOF4@861R97/A^"!N96[M
M('!RX7ID;OTN(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW."!A9&UI;B]P97)M
M<R]D96QE=&4N<&AP.C0T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM<V=S='(@(DYE;'IE('9Y
M;6%Z870@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,S,Q(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,SDR"B,Z(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,3$@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C,S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(*;7-G
M<W1R(").96QZ92!V>6UA>F%T("5S+"!P<F]T;[YE(&%D<F5SX?@@;F5N[2!P
M<N%Z9&[]+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS
M-#@@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,U,@IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*
M;7-G<W1R(").96QZ92!R96MU<GII=NP@;V1S=')A;FET(%9&4R!A9')E<^'X
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S-R!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HS,S4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T
M,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0T"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYE
M;'IE('9Y;6%Z870@5D93(&%D<F5SX?@N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HT,3<@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,CD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER
M96-T;W)Y.B`E<RXB"FUS9W-T<B`B3F5L>F4@=GEM87IA="!61E,@861R97/A
M^#H@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,#<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(DYE;'IE('9Y;6%Z870@5D93('-O=6)O<B!<(B5S
M7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S`S(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C@X"B,Z(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HQ-C<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X
M,`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@W(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.#,*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,Y,0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@9FEL92XB"FUS9W-T<B`B3F5L>F4@=GEM87IA="!61E,@<V]U8F]R+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C0T"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@
M7"(E<UPB+B(*;7-G<W1R(").96QZ92!V>6UA>F%T(%9&4R!S;W5B;W(@7"(E
M<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#`V"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV
M96QY.B`E<RXB"FUS9W-T<B`B3F5L>F4@<F5K=7)Z:79N["!O9'-T<F%N:70@
M5D93.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@P,PIM
M<V=I9"`B56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B3F5L>F4@=7+H:70@86MT=>%L;NT@861R97/A^"XB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8P,PIM<V=I9"`B56YA
M8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R(").
M96QZ92!Z:FES=&ET('!O9')O8FYO<W1I(&\@8V5R=&EF:6OA='4N(@H*(SH@
M9G)A;65W;W)K+TYE=%])35-0+TE-4U`N<&AP.C0U,2!F<F%M97=O<FLO3F5T
M7TE-4U`O24U34"]!=71H+G!H<#HQ,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@
M(D1E9FEN:6-E("5S(&YE;NT@9&]S='5P;N$N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C(P,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,38V(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-S$*;7-G:60@(E5N86)L
M92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R(").96QZ92!P^&5S=6YO=70@
M5D93('-O=6)O<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.CDS
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,3`R"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-C0X(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R(").96QZ92!P^&5S=6YO=70@5D93('-O=6)O
M<B!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C<W
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S,PIM<V=I9"`B56YA8FQE('1O
M(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N(@IM<V=S='(@(E9&4R!S;W5B
M;W(@;F5L>F4@;W1E=OCM="!P<F\@>N%P:7,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z.#`@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,@IM<V=I
M9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@(DYE;'IE(&]T
M97;X[70@5D93('-O=6)O<BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T9WHN<&AP.C0U"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S
M<V5D(&%R8VAI=F4N(@IM<V=S='(@(DYE;'IE(&]T97;X[70@87)C:&EV;W9A
M;OT@<V]U8F]R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX,S4*(RP@
M9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ
M92@I(&9A:6QE9"DN(@IM<V=S='(@(DYE;'IE('IA<'-A="!D871A(&1O(%9&
M4R!S;W5B;W)U("AS96QH86QO(&-O<'DH*2DN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C@V-@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E860@
M5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B3F5L
M>F4@>F%P<V%T(&1A=&$@9&\@5D93('-O=6)O<G4@*'-E;&AA;&\@8V]P>2@I
M*2XB"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L
M97(O;F]N92YP:'`Z,S@*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96%D
M(&9I;&4Z("(*;7-G<W1R(").96QZ92!P^&5J;65N;W9A="!61E,@<V]U8F]R
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8V.0IM<V=I9"`B
M56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R
M(").96QZ92#H[7-T('H@=F9S<F]O="!A9')E<^'X92XB"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C$Q,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R
M(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(DYE;'IE('#X96IM96YO=F%T("5S
M(&YA("5S.B!C[6QO=N$@<VQOOFMA(&IIOB!E>&ES='5J92(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.3,*;7-G:60@(E5N86)L92!T
M;R!R96YA;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B5D93(&%D<F5SX?@@
M;F5L>F4@</AE:FUE;F]V870N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HS,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M
M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B5D93(&%D<F5SX?@@;F5L
M>F4@</AE:FUE;F]V870Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z,C8W(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S0S"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E
M<UPB+B(*;7-G<W1R(").96QZ92!P^&5J;65N;W9A="!61E,@<V]U8F]R(%PB
M)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV,3`@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(R.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R
M(").96QZ92!P^&5J;65N;W9A="!61E,@<V]U8F]R("5S+R5S+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(S(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HR,3,*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C0U,B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C@U"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,#$*;7-G:60@(E5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4N(@IM<V=S='(@(DYE;'IE('#X96IM96YO
M=F%T(%9&4R!S;W5B;W(N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS9VED(")5;F%B;&4@=&\@<G5N
M("=M:VES;V9S)RXB"FUS9W-T<B`B3F5L>F4@<')O=NES="`G;6MI<V]F<R<N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HU
M.0IM<V=I9"`B56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE
M;G0B"FUS9W-T<B`B5&5N=&\@9&]K=6UE;G0@5V]R9"!N96QZ92!P^&5L;[YI
M="(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,30Y(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,34R"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DYE;'IE
M('IA<'-A="!D;R!61E,@<V]U8F]R=2!<(B5S7"(N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,3<Y"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R(").96QZ92!Z87!S
M870@9&%T82!D;R!61E,@<V]U8F]R=2`H<V5L:&%L;R!C;W!Y*"DI+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(X,2!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,3,X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HQ-#,*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL
M92!D871A+B(*;7-G<W1R(").96QZ92!Z87!S870@9&%T82!D;R!61E,@<V]U
M8F]R=2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-#$*(RP@9G5Z>GD*
M;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B
M92!E>&-E961E9"XB"FUS9W-T<B`B3F5L>F4@>F%P<V%T(&1A=&$@9&\@5D93
M('-O=6)O<G4@*'-E;&AA;&\@8V]P>2@I*2XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B
M"FUS9W-T<B`B4&]D=')H;G5TZ2(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N
M:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R(")3=&]R;F\@>FWL
M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(E-T
M;W)N;W9A="!P;W-L96[M(&%K8VDB"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HR,C,*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,SDP"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E
M(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R(").96_H96OA
M=F%NX2!O9'!O=NSO('-E<G9E<G4@;F$@<W!O:F5N[3H@(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,0HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S@*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@T"FUS9VED(")5;F5X<&5C=&5D
M(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B3F5OZ&5KX79A
M;N$@;V1P;W;L[R!S97)V97)U.B`B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHV,0IM<V=I9"`B56YF:6QE9"(*;7-G
M<W1R(").979Y<&QN[&YO(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3,*
M;7-G:60@(E5N:6-O9&4@*%541BTX*2(*;7-G<W1R(")5;FEC;V1E("A55$8M
M."DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B
M"FUS9W-T<B`B4W!O:F5NZ2!!<F%B<VOI($5M:7+A='DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S0*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(E9E;&OA($)R:73A
M;FEE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R(*;7-G
M<W1R(")3<&]J96[I(%-TX71Y($%M97)I8VOI(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM
M<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM
M<V=S='(@(E-P;VIE;ND@4W3A='D@365NN6EN;W;]8V@@;W-T<F]V^2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV.2!L:6(O0FQO8VLO;65T
M87(N<&AP.C<Q"FUS9VED(")5;FET<R(*;7-G<W1R(")*961N;W1K>2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R.2!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,S`*;7-G:60@(E5N:VYO=VXB"FUS9W-T
M<B`B3F5Z;N%MZ2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)
M($UE<W-A9V4@240I+B(*;7-G<W1R(").97INX6WI(&%P:6US9VED("A!4$D@
M365S<V%G92!)1"DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN;W=N(&-L:6US9VED("A#
M;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@(DYE>F[A;>D@8VQI;7-G:60@
M*$-L:65N="!-97-S86=E($E$*2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,34Y"B,L(&9U>GIY"FUS9VED(")5;FMN;W=N(&QO8V%T:6]N
M('!R;W9I9&5D+B(*;7-G<W1R(").96)Y;&\@=GEB<N%N;R"^X61NZ2!M[7-T
M;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.3$*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N
M(@IM<V=S='(@(DYE>F[A;>D@=;YI=F%T96QS:^D@:FWI;F\@;F5B;R!H97-L
M;RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-3@*;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT
M(@IM<V=S='(@(D]D<&]J:70@<V]UZ&%S;OT@<')V96LB"@HC.B!F<F%M97=O
M<FLO261E;G1I='DO261E;G1I='DN<&AP.C(Y-@IM<V=I9"`B56YN86UE9"(*
M;7-G<W1R(")"97IE(&IMZ6YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D('-C
M<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I
M8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S
M964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"`B"B)S
M:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@
M8VQI<&)O87)D+B(*;7-G<W1R("(B"B).97!R:79I;&5G;W9A;ND@<VMR:7!T
M>2!N96UO:&]U('9Y=;[M=F%T(&9U;FMC82!6>6IM;W5T+TMO<.UR;W9A="]6
M;&^^('H@(@HB8F5Z<&7H;F]S=&[M8V@@9/EV;V3Y+B!+;&EK;NQT92!N82!/
M2R!A8GES=&4@=FED[&QI('1E8VAN:6-K;W4@>G!RX79U('H@(@HB;6]Z:6QL
M82YO<F<L(&MT97+A('9Y<W;L=&QU:F4L(&IA:R!N87-T879I="!S:W)I<'0@
M<')O('#X[7-T=7`@:V4@<V-H<N%N8V4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@IM<V=I9"`B56YS970@
M8V]L;W(B"FUS9W-T<B`B3F5N87-T879E;N$@8F%R=F$B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X-B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.CDR-@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.CDS,@IM<V=I9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM
M<V=S='(@(DYE<&]D<&]R;W9A;N$@</CM<&]N82(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,3DW('1E;7!L871E<R]A9&UI;B]U<V5R+VQI
M<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B06MT=6%L:7IO=F%T
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHR.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B06MT=6%L:7IO
M=F%T("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW
M-@IM<V=I9"`B57!D871E('5S97(B"FUS9W-T<B`B06MT=6%L:7IO=F%T('6^
M:79A=&5L92(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,30T(&%D;6EN+W!E<FUS
M+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,P"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS
M9W-T<B`B06MT=6%L:7IO=N%N>2`G)7,G+B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C@S"FUS9VED(")5<&=R861E('-C<FEP="!D96QE=&5D+B(*
M;7-G<W1R(")3:W)I<'0@<')O(&%K='5A;&EZ86-I(&)Y;"!V>6UA>N%N+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S@@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y.0IM<V=I9"`B57!L;V%D(@IM<V=S
M='(@(E#X96YO<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#8*;7-G
M:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T
M:&4@<V5R=F5R+B(*;7-G<W1R(")6N65C:&YY('-O=6)O<GD@<')O(&YA<W1A
M=F5N[2!A<&QI:V%C[2!B>6QY('#X96YE<V5N>2!N82!S97)V97(N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R(")696QK
MX2!T:7-K86/M('#M<VUE;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA
M;B!N=6UB97)S(@IM<V=S='(@(E9E;&OI(/CM;7-KZ2#H[7-L:6-E(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R(")5<G5G=6%Y(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z
M-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S
M='(@(E!O=;[M="!A:W1UX6QN[3H@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-33"(*
M;7-G<W1R(")0;W6^[70@4U-,(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$R-`IM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT
M(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B4&]UONUT('!O:W5D(&IMZ6YO
M+VAE<VQO(&IS;W4@:FENZ2!N9;X@<')O($E-4U`@<V5R=F5R+B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$*(RP@9G5Z>GD*;7-G
M:60@(E5S97(B"FUS9W-T<B`B5;YI=F%T96SI(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HW,C,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@
M(E6^:79A=&5L("5S(&YE;NT@;W!RX79N[&X@:R!P;W6^[7;A;NT@)7,N(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,C`S"FUS9VED(")5<V5R($%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(D%D;6EN:7-T<F%C92!UOFEV871E;/DB"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(U,0IM<V=I9"`B57-E<B!/<'1I
M;VYS(@IM<V=S='(@(E6^:79A=&5L<VOI(&UOOFYO<W1I(@H*(SH@<VEG;G5P
M+G!H<#HV,@IM<V=I9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T<B`B4F5G
M:7-T<F%C92!UOFEV871E;/DB"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5
M<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S
M:71E+B(*;7-G<W1R(").82!T;VUT;R!S97)V97)U(&YE;NT@;6^^;N$@<F5G
M:7-T<F%C92!UOFEV871E;/DN(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C0V.0HC+"!F=7IZ>0IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N9"(*
M;7-G<W1R("(E<R!N96)Y;&\@;F%L97IE;F\N(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W.0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3`@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S,*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHW,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN
M8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B5;YI=F%T96QS:^D@:FWI
M;F\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@86QR
M96%D>2!E>&ES=',N(@IM<V=S='(@(E6^:79A=&5L<VOI(&IMZ6YO("<E<R<@
M:FF^(&5X:7-T=6IE+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHX-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(E6^:79A=&5L<VOI(&IM
MZ6YO.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*;7-G:60@
M(E5S97)N86UE.B`B"FUS9W-T<B`B5;YI=F%T96QS:^D@:FWI;F\Z("(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S
M(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(E-E>FYA;2!UOFEV871E;/DZ(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-`IM<V=I9"`B57IB96MI<W1A;B(*;7-G<W1R(")5>F)E
M:VES=.%N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,38S(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(U-0IM<V=I9"`B5D93(&1I<F5C
M=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B5D93(&%D<F5SX?@@;F5E
M>&ES='5J92XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3$X"FUS
M9VED(")686-A=&EO;B(*;7-G<W1R(")$;W9O;&5NX2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C@V-@IM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O
M=6YD(&EN8VQU9&4Z("(*;7-G<W1R(").86QE>F5NX2!P;&%T;N$@;>US=&$@
M>F%H<FYU:NTZ("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C,X"FUS9VED(")686QI9&ET>2(*;7-G<W1R(")0;&%T;F]S="(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(U-0IM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T
M<B`B2&]D;F]T82!V(&UI;G5TX6-H+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@U-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3<W"B,L('!H
M<"UF;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N
M9W1H(&]F("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,C0T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C8*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.3(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E
M="YP:'`Z-3D*;7-G:60@(E9A;'5E<R(*;7-G<W1R(")(;V1N;W1Y(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P.2!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,3@V"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS
M9W-T<B`B5GEB<F%NZ2!H;V1N;W1Y('HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED
M(")686YU871U(@IM<V=S='(@(E9A;G5A='4B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C0T"FUS9VED(")687)I86)L92(*;7-G<W1R(")0
M<F]M[&YNZ2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*;7-G
M<W1R(")696YE>G5E;&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@
M;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@
M(E-E;&AA;&$@=F5R:69I:V%C92`M('1A=&\@>G!RX79A(&UO:&QA(&+]="!Z
M9F%LN6]VX6YA+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-S`P"FUS9VED(")697)S:6]N(@IM<V=S='(@(E9E<GIE(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R-@IM<V=I9"`B5F5R<VEO;B!#;VYT
M<F]L(@IM<V=S='(@(E9E<G-I;VX@0V]N=')O;"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G:60@(E9E
M<G1I8V%L(&%L:6=N(@IM<V=S='(@(E9E<G1I:^%L;NT@>F%R;W9NX6[M(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-`IM
M<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*;7-G<W1R(")697)T:6OA;&[M(&]D
M<W1U<"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R(")697)T:6OA;&[M.B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P"FUS
M9VED(")697)Y($AI9V@B"FUS9W-T<B`B5F5L;6D@=GES;VOA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-@IM<V=I9"`B5FEE="!.86TB"FUS9W-T<B`B5FEE=&YA;2(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")6:65T;F%M97-E("A6
M25-#24DI(@IM<V=S='(@(E9I971N86US:WD@*%9)4T-)22DB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HY-C(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R("):;V)R87II="`E<R(*"B,Z(&QI
M8B]";&]C:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@
M=V5B('!A9V4B"FUS9W-T<B`B6F]B<F%Z:70@97AT97)N[2!W96)S='+A;FMU
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#(Q"B,L
M('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B6F]B<F%Z
M:70@:F%K;R`E<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA
M;F1S+"!"<FET:7-H(@IM<V=S='(@(E!A;FYE;G-KZ2!/<W1R;W9Y+"!"<FET
M<VOI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L(%4N
M4RXB"FUS9W-T<B`B4&%N;F5N<VOI($]S=')O=GDL(%4N4RXB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(P.0IM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R
M(")6:61I=&5L;F]S="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR-C,*;7-G:60@(E9I<VEB:6QI='DZ("(*;7-G<W1R(")6:61I=&5L;F]S
M=#HB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S
M;71P+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS
M9W-T<B`B5F]D869O;F4@271A;'D@</AE<R!33510(@H*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H
M<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R(")54$]:3U).250B"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")7
M05).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS
M9W-T<B`B55!/6D]23LQ.S2$A(2!/1%-44D'25$4@4TM225!4(%)5R$[,(%H@
M)7,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ
M,S,*(RP@9G5Z>GD*;7-G:60@(E=)3B!V:6$@2%144"(*;7-G<W1R(")S;7,R
M96UA:6P@>F$@<&]UOFET[2!(5%10(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B
M5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T<B`B5V%L;&ES(&%N9"!&=71U;F$B
M"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VAT;6PN<&AP.C(W,B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#,*;7-G
M:60@(E=A<FYI;F<B"FUS9W-T<B`B57!O>F]R;NQN[2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM
M<V=S='(@(E-T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y
M"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM<V=S='(@(E#X961P;W;L[R!P
M;^AA<^TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#(W"FUS
M9VED(")796%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS9W-T<B`B1&%T82!O
M('!OZ&%S[2!P;W-K>71U:F4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HX.3(*;7-G:60@(E=E871H97(N8V]M(@IM<V=S='(@(E=E871H97(N8V]M
M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G
M<W1R(")796(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,W"FUS
M9VED(")796(@4VET92(*;7-G<W1R(")796(@<V5R=F5R(@H*(SH@9G)A;65W
M;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E
M:VQY(@IM<V=S='(@(E3]9&[L(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL
M92YP:'`Z,C@*;7-G:60@(E=E;&-O;64B"FUS9W-T<B`B5NUT96IT92(*"B,Z
M('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHU-PHC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O
M("5S(@IM<V=S='(@(E;M=&5J=&4@=B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]M;V)I;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE+"`E<R(*;7-G<W1R(")6[71E
M:G1E+"`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")7
M97-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R("):X7!A9&[M("A)4T\M.#@U
M.2TQ*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS9VED(")797-T
M97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B6N%P861N[2`H25-/+3@X-3DM
M,34I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S
M='(@(EKA<&%D;NT@4V%H87)A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H
M;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R(")+=&5R;W4@
M87!L:6MA8VD@;>$@)7,@>F]B<F%Z:70@<&\@</AI:&SAN65N[2!D;R!S>7-T
MZ6UU/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED
M(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R(")*
M86O](&IE(&]D9.QL;W9A8^T@>FYA:S\B"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C
M=&5R/R(*;7-G<W1R(")*86O](&IE('IN86L@<')O(&-I=&%C:3\B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V,0HC+"!F
M=7IZ>0IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S='(@(D%U
M<W1RX6QI92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI
M8V@@<&AA<V5S(@IM<V=S='(@(DMT97+I(&;A>F4B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3,S"FUS9VED(")7:&EC:"!P;'5G:6YS('1O(&5N86)L
M92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@(E9O;&)A(')O
M>KGM^&5N[2!P<F\@4FEC:"!497AT(&5D:71O<BXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED(")7
M:61T:"(*;7-G<W1R("*I[?AK82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,Q,C4*;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G<W1R("*I
M[?AK82!V($-34R!J961N;W1KX6-H(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@)7,@
M;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN
M*3HB"FUS9W-T<B`BJ>WX:V$@)7,@;65N=2!V;&5V;R`H>FWL;F$@<V4@;V)J
M97;M('#X:2!D86RY[6T@</AI:&SAN65N[2DZ(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F
M('1H92!T86)L92(*;7-G<W1R("*I[?AK82!T86)U;&MY(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G:60@(E=I
M9'1H('5N:70B"FUS9W-T<B`B2F5D;F]T:V$@N>WX:WDB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0IM<V=I9"`B5VED
M=&@Z(@IM<V=S='(@(JGM^&MA.B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HU,3,*;7-G:60@(E=I:VDB"FUS9W-T<B`B5VEK:2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C4*;7-G:60@(E=I;F0B"FUS9W-T<B`B5NUT
M<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V
M"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@(E)A;F[M(';M='(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C@P"FUS9VED(")7:6YD('-P965D(&EN(&MN
M;W1S(@IM<V=S='(@(E)Y8VAL;W-T(';L=')U('8@=7IL96-H(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ-38*;7-G:60@(E=I;F0Z(@IM<V=S='(@(E;M
M='(Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T,@IM<V=I
M9"`B5VEN9#H@(@IM<V=S='(@(E;M='(Z("(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M(@IM<V=S='(@(DUO=61R;W-T(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y-@HC+"!F=7IZ>0IM<V=I
M9"`B5VES:&QI<W0B"FUS9W-T<B`B4V5Z;F%M('#XX6[M(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K(@IM<V=S='(@(E!RX6-E
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R
M-`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,38T
M"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`B061R97-A(&1O('IA;>QS
M=&[A;NTB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(E1E;&5F;VX@9&\@
M>F%M['-T;N%N[2(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$V
M.2!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR-C(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%
M>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C,P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")7
M<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$Q
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D
M('=H:6QE(')E861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B5GET=F_X96[M
M(%9&4R!S;W5B;W)U(&YE8GEL;R!P;W9O;&5N;RXB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C0S"FUS9VED(")8+5)E9B(*;7-G<W1R(")8+5)E
M9B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DS"FUS
M9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T<B`B6#4P.78S
M('KA:VQA9&[M(&]M97IE;NTB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4Y,@IM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME>2!5<V%G
M92(*;7-G<W1R(")8-3`Y=C,@<F]ZN>WX96[I('!O=;YI=.T@:VSMZ&4B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B
M6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R(")8-3`Y
M=C,@86QT97)N871I=F[M(&IMZ6YO(&]S;V)Y(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J96-T
M($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(E@U,#EV,R!I9&5N=&EF:6OA=&]R
M(&ML[>AE(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M.#(*;7-G:60@(E@U,#EV,R!E>'1E;G-I;VYS(@IM<V=S='(@(E@U,#EV,R!R
M;WJY[?AE;NTB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B65DB
M"FUS9W-T<B`B4E(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#$S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-34*;7-G:60@(EE965DB"FUS9W-T<B`B4E)24B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3`X"FUS9VED
M(")986AO;R$@;6%P(@IM<V=S='(@(DUA<&$@66%H;V\A(@H*(SH@9G)A;65W
M;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I9"`B665A
M<FQY(@IM<V=S='(@(E)OZ&[L(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B665M
M96XB"FUS9W-T<B`B2F5M96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED(")997,B"FUS9W-T<B`B06YO(@H*
M(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*
M;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R(")!;F\L('-O=6AL87/M;2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*
M;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U
M='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R("(B"B)*
M<W1E('8@5$585$]6R4T@3=-$52X@4&]UOFEJ=&4@6SP^72!T;&'H[71K82!K
M('IP['1NZ6UU('#X97!N=73M(&1O(%=94TE764<N(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+V5D:70N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A
M<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,30Q
M,0IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC871E9"XB"FUS9W-T<B`B
M3F5B>6QI(&IS=&4@<W!RX79N["!O=NSX96YI+B(*"B,Z(&9R86UE=V]R:R])
M9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`R"FUS9VED(")9;W4@8V%N(&YO="!H
M879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS
M9W-T<B`B6FYA:R`G7%PG(&YE;?F^92!B_70@<V]UZ.%S=.T@5F&Y96AO(&IM
MZ6YA+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-34@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3DW-0IM<V=I9"`B66]U(&1I9"!N;W0@96YT
M97(@82!V86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R(")">6QA('IA9.%N
M82!N97!L871NX2!E+6UA:6QO=N$@861R97-A+B(*"B,Z(&9R86UE=V]R:R]$
M871A+T1A=&$N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@
M9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@
M=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R
M("(B"B).96UA<&]V86QI(&IS=&4@ON%D;N$@<&]L92!Z(&EM<&]R=&]V86[I
M:&\@<V]U8F]R=2!K(&]D<&]V[61A:NUC[6T@<&]L[6T@=B`E(@HB<RXB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#@*;7-G:60@(EEO=2!H879E
M(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`B0GEL:2!J<W1E(&]D:&SAN65N
M:2!Z92!S>7-TZ6UU+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M-C$*;7-G:60@(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H
M;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@
M(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G
M<W1R("(B"B)6;&^^=&4@Z.US;&\@;6]B:6QN[6AO('1E;&5F;VYU+"!P;W6^
M:6IT92!J96X@Z.US;&EC(&YE8F\@</CM<&%D;NP@)RLG('!R;R`B"B)M97II
M;N%R;V1N[2#H:7-L82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,3@X"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*
M;7-G<W1R(")-=7/M=&4@>F%D870@<&QA=&YO=2!H;V1N;W1U+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU
M<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P
M<RXB"FUS9W-T<B`B(@HB375S[71E(&MO;F9I9W5R;W9A="!D871A8N%Z:2!D
M870L('!O:W5D('-I('#X96IE=&4@<&]UONUV870@4F5G:7-T<F%C92XB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0U-@IM<V=I9"`B66]U(&UU
M<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(DUU<^UT92!K
M;VYF:6=U<F]V870@5D93(&)A8VME;F0N(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H
M92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P
M;W)T+B(*;7-G<W1R(")-=7/M=&4@;F5J9/CM=F4@<&]P<V%T('!R;V)LZ6T@
M82!P;W3I(&AO(&]D97-L870N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U(&UU<W0@96YT97(@=&AE
M(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@(DUU<^UT
M92!Z861A="!54DP@;F$@:W1E<ND@8G5D92!T96YT;R!O9&MA>B!U:V%Z;W9A
M="(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9
M;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S
M='(@(DUU<^UT92!V>6)R870@<V5R=F5R+"!K=&5R_2!B=61E('-M87KA;BXB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*;7-G:60@(EEO=2!M=7-T('-P96-I
M9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@(DUU<^UT92!V
M>6)R870@=;YI=F%T96QS:^D@:FWI;F\L(&MT97+I(&)U9&4@<VUA>N%N;RXB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P96-I
M9GD@82!U<V5R;F%M92!T;R!R96UO=F4N(@IM<V=S='(@(DUU<^UT92!Z861A
M="!UOFEV871E;'-KZ2!J;>EN;RP@:W1E<ND@8G5D92!O9'-T<F%N[&YO+B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA
M;64@=&\@861D+B(*;7-G<W1R(").975V961L:2!J<W1E('6^:79A=&5L<VOI
M(&IMZ6YO+"!K=&5RZ2!B=61E('#X:63A;F\N(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,30V"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T
M;R!U<&1A=&4N(@IM<V=S='(@(DYE=79E9&QI(&IS=&4@=;YI=F%T96QS:^D@
M:FWI;F\@<')O(&%K='5A;&EZ86-I+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]Z:7`N<&AP.C$S.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF
M>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R(")-=7/M=&4@>F%D
M870@86MC:2P@:W1E<N$@8G5D92!P<F]V961E;F$N(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*;7-G:60@(EEO
M=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T<B`B375S
M[71E('IA9&%T(&IMZ6YO(&YO=ND@:V%T96=O<FEE+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S"FUS9VED
M(")9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER
M960N(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B5F&Y92`E<R!R96QA
M8V4@8GEL82!U:V]NZ&5N82X@3W#L="!S92!P^&EH;&&Y=&4L('!R;W/M;2XB
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS.`IM<V=I9"`B
M66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(E9AN64@96UA:6QO=N$@861R
M97-A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q,@IM<V=I9"`B66]U
M<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R(")68;EE($]D+6MO:&\Z(&%D<F5S
M83HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C0@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C<T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@(EEO=7(@26YF;W)M871I;VXB
M"FUS9W-T<B`B5F&Y92!I;F9O<FUA8V4B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HY.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E
M<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@
M;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I
M='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B)6(')E;&%C
M:2`E<R!S92!Z;>QN:6QA(%9AN64@:6YT97)N971O=N$@861R97-A+B!:(&)E
M>G!EZ&YO<W1N[6-H(&3Y=F]D^2!S92`B"B)M=7/M=&4@;W#L="!P^&EH;.%S
M:70N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*;7-G
M:60@(EEO=7(@3F%M92(*;7-G<W1R(")68;EE(&IMZ6YO(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C4*(RP@9G5Z>GD*;7-G:60@(B(*
M(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T
M(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@(@HB=7-E($AO<F1E('1O
M(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF
M9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*
M(E;AN2!O=NSX;W9A8^T@<WES=.EM(&YE<&]D<&]R=6IE('#X:63A=N%N[2!U
MOFEV871E;/D@86YE8F\@=&%T;R!M;[YN;W-T(&YE;NT@(@HB</CM<W1U<&[A
M('H@:FEN_6-H(&3Y=F]D^2XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N
M;VQI<W0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C
M:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F
M96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E
M87-O;BXB"FUS9W-T<B`B(@HB5N&Y(&]V[/AO=F%C[2!S>7-TZ6T@;F5P;V1P
M;W)U:F4@=OUP:7,@=;YI=F%T96SY(&%N96)O('1A=&\@;6^^;F]S="!N96[M
M("(*(G#X[7-T=7!NX2!Z(&II;OUC:"!D^79O9/DN(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z.3@T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO
M=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@
M8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y
M;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B
M(@HB6F3A('-E+""^92!V('!R^6+L:'4@<F5L86-E("5S('-E('IM[&YI;"!6
MX;D@<')O:&SMOF7H+B!:(&)E>G!EZ&YO<W1N[6-H("(*(F3Y=F]D^2!S92!M
M=7/M=&4@;W#L="!P^&EH;.%S:70N(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP
M:'`Z-3`*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H
M:7,@9F5A='5R92XB"FUS9W-T<B`B5N&Y('!R;VAL[;YEZ"!N97!O9'!O<G5J
M92!T=71O(&UOOFYO<W0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I
M;G0N:G,Z-#(*(RP@9G5Z>GD*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S
M(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L
M+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R("(B"B)6X;D@<')O
M:&SMOF7H(&YE=6UOOO)U:F4@=&ES:R!T[6UT;R!Z</ES;V)E;2X@4')O=F5D
M96[M;2!S=&ES:VYU=.T@0W1R;"\B"B)/<'1I;VX@*R!0('-P=7-T[71E('1I
M<VLN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U-PIM<V=I9"`B66]U
M<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`B5F&Y92!S;W7H87-NZ2#H
M87-O=ND@<.%S;6\Z(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDV"B,L(&9U
M>GIY"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA
M;F=E9"XB"FUS9W-T<B`B5F&Y92!I;7!L:6-I=&[M(&ED96YT:71A(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U.`IM<V=I9"`B66]U<B!D969A=6QT
M(&ED96YT:71Y.B(*;7-G<W1R(")68;EE(&EM<&QI8VET;NT@:61E;G1I=&$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`Q"FUS9VED(")9;W5R(&9U
M;&P@;F%M93HB"FUS9W-T<B`B5F&Y92#Z<&QNZ2!J;>EN;SHB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HQ,#`P"B,L(&9U>GIY"FUS9VED(")9;W5R
M(&QO9VEN(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")68;EE(&YA<W1A=F5N[2!B
M>6QO(&%K='5A;&EZ;W;A;F\N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O
M<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R(")68;EE(&YO=ND@:&5S;&\@<')O
M("5S(&IE.B`E<R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,34T"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R
M('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@(E9AN64@
M;F%S=&%V96[M(&)Y;&\@86MT=6%L:7IO=N%N;R!P<F\@=')VX6[M('3I=&\@
M<F5L86-E+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34V
M"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S
M='(@(E9AN64@;F%S=&%V96[M(&)Y;&\@86MT=6%L:7IO=N%N;RXB"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S
M=V]R9"!H87,@8F5E;B!R97-E="(*;7-G<W1R(")68;EE(&AE<VQO(&)Y;&\@
M<F5S971O=N%N;RXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW
M.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE
M8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S
M<W=O<F0N(@IM<V=S='(@(B(*(E9AN64@:&5S;&\@8GEL;R!R97-E=&]VX6YO
M+"!Z:V]N=')O;'5J=&4@<VD@>G!RX79Y(&5L96MT<F]N:6-KZ2!P;[ET>2!A
M("(*(G#X:6AL8;ET92!S92!S(%9AN>UM(&YO=OUM(&AE<VQE;2XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HW,S(*(RP@9G5Z>GD*;7-G:60@(EEO
M=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S='(@(E9AN64@:&5S;&\@
M8GEL;R!R97-E=&]VX6YO+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`B
M5F&Y92!V>F3A;&5NZ2!S97)V97)Y.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C4T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*
M;7-G:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B2G5G;W-LX79I92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM
M<V=S='(@(EIA:7(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS
M9W-T<B`B6F%M8FEE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B
M"FUS9W-T<B`B6FEM8F%B=F4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C8*;7-G:60@(EII<'!Y(@IM<V=S='(@(EII<'!Y(@H*(SH@9G)A;65W;W)K
M+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I
M9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(EM5:W+]="!C:71O=F%N
M_2!T97AT72(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C@X"FUS9VED(");
M4')O8FQE;2!297!O<G1=(@IM<V=S='(@(EM(;.&Y96[M('!R;V)LZ6UU72(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS
M9VED(");4VAO=R!1=6]T960@5&5X="`M(@IM<V=S='(@(EM:;V)R87II="!C
M:71O=F%N_2!T97AT("TB"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL
M=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,L('!H<"UF;W)M870*;7-G
M:60@(EM3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM<V=S='(@(EM:
M;V)R87II="!C:71O=F%N_2!T97AT("T@)7,@^.%D:_E=(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(EOXX61E:R`E<R!Z("5S72(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34T,2!T96UP;&%T97,O<&]R
M=&%L+VUE;G4N:6YC.C$Q"FUS9VED(")?061M:6YI<W1R871I;VXB"FUS9W-T
M<B`B7T%D;6EN:7-T<F%C92(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I9"`B
M7T-,22(*;7-G<W1R(")?0TQ)(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS9VED
M(")?1&%T851R964B"FUS9W-T<B`B7T1A=&%4<F5E(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED
M(")?1&5L971E(%)O=R(*;7-G<W1R(")?4VUA>F%T(/CA9&5K(@H*(SH@;&EB
M+V%P:2YP:'`Z,3,S"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(E]3:W5P:6YY
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W-0IM<V=I
M9"`B7TAE;'`B"FUS9W-T<B`B7T[A<&]V[&1A(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S"FUS9VED(")?
M26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")?5FQA<W1N;W-T:2!O8G+A
M>FMU+BXN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y
M-`IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R(")?4/AI:&SAN65N[2(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.3`*;7-G:60@(E],;V<@
M;W5T(@IM<V=S='(@(E]/9&ALX;EE;NTB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I
M9GD@3&EN:RXN+B(*;7-G<W1R(")?36]D:69I:V]V870@;V1K87HN+BXB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38T"FUS9VED(")?
M3W!T:6]N<R(*;7-G<W1R(")?36^^;F]S=&DB"@HC.B!L:6(O87!I+G!H<#HQ
M,S<*;7-G:60@(E]097)M:7-S:6]N<R(*;7-G<W1R(")?4'+A=F$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C8*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R(")?3V1S=')A;FET
M(&]D:V%Z+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3(U"FUS9VED(")?4V5T=7`B
M"FUS9W-T<B`B7TYA<W1A=F5N[2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B7U1A8FQE(%!R
M;W!E<G1I97,N+BXB"FUS9W-T<B`B7U9L87-T;F]S=&D@=&%B=6QK>2XN+B(*
M"B,Z(&QI8B]A<&DN<&AP.C$R.0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(E]5
MOFEV871E;.DB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR,0IM
M<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(F%D<F5SX?@B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S-`HC+"!F=7IZ>0IM<V=I
M9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B861R97/A^"(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$S"FUS9VED(")C86QE;F1A<B(*
M;7-G<W1R(")K86QE;F3A^"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<R
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S4X"B,L('!H<"UF;W)M870*;7-G:60@
M(F-A;&TB"FUS9W-T<B`B8F5Z=NQT^.TB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N;F]T(&-R96%T92!O=71P
M=70@9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DR
M"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@(FML:6MN;W5T('ID92(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(R"FUS9VED(")C
M;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S@*(RP@9G5Z>GD*;7-G:60@
M(F-O;F9I9W5R871I;VX@97)R;W(B"FUS9W-T<B`B4F]Z9.UL>2!V(&YA<W1A
M=F5N[2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34T
M"FUS9VED(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(V"FUS
M9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$X,@HC+"!F=7IZ>0IM<V=I9"`B
M96YT<GD@;F]T(&9O=6YD(@IM<V=S='(@(FYE;F%L97IE;F\B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B9F%L
M;&EN9R(*;7-G<W1R(")S<N&^:WDB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"
M<F]W<V5R+G!H<#HX-34*;7-G:60@(F9I;&4B"FUS9W-T<B`B<V]U8F]R(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S0@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS-C`@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R(")Z("5S
M("@E<RD@<GEC:&QO<W3M("5S("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(U,`HC+"!F=7IZ>0IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R
M("(L(&[A<F%Z;W;]("5S("5S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(T.0IM<V=I9"`B:#HB"FUS9W-T<B`B:#HB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4X"FUS
M9VED(")H:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T<B`B;VMA;;YI
M=.PB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D
M:69F+G!H<#HW.0IM<V=I9"`B:6YL:6YE(@IM<V=S='(@(G8@^&%D["(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,38R"FUS9VED(")I
M;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN=&5R;F%L('-O9G1W
M87)E(&5R<F]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(")L:6YE<UTB"FUS9W-T<B`B^.%D
M:_E=(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK
M:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*;7-G:60@(FUK:7-O9G,@97)R
M;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R(")C:'EB;W;]
M(&OS9"!M:VES;V9S("5D('#X:2!V>71VX?AE;NT@25-/+B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-CD*;7-G:60@(FUM
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,CDQ('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S`*(SH@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C(S,@IM<V=I9"`B;F%M92(*;7-G<W1R
M(")J;>EN;R(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ,C$*;7-G:60@
M(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R(")N96[M(&EM<&QE;65N=&]VX6YO
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C$Y"FUS
M9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(FYE;NT@9&]S=60@
M:6UP;&5M96YT;W;A;F\B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDP-0IM<V=I9"`B;F]T97!A9"(*;7-G<W1R(")ZX7!I<V[M:R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*
M;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B<')O8V5N="(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<T"B,L(&9U>GIY"FUS9VED(")P
M97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R(")0<N%V82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@
M(G!I>&5L<R(*;7-G<W1R(")P:7AE;/DB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I9"`B<F5M;W1E(&5R<F]R(&EN('!R
M;W1O8V]L(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C<S"FUS9VED(")R:7-I;F<B"FUS9W-T<B`B<W1O=7!A
M:NUC[2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,30R
M"B,L(&9U>GIY"FUS9VED(")S97)V:6-E('5N879A:6QA8FQE(@IM<V=S='(@
M(D)L;VL@;R!P;^AA<^T@;F5N[2!D;W-T=7!N_2XB"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.CDY"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S
M='(@(GIO8G)A>FET(')O>F3M;'DB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I
M82!(5%10(@IM<V=S='(@(G-M<S)E;6%I;"!Z82!P;W6^:73M($A45%`B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@U"FUS
M9VED(")S<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HW,@IM<V=I9"`B<W1E861Y(@IM<V=S='(@(G9Y=')V
M86SI(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,#D*;7-G:60@
M(G-W:71C:"!O9F8@:F%V87-C<FEP="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R
M<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3(Y"FUS9VED(")T87-K(&QI<W0B"FUS9W-T<B`B<V5Z;F%M(/IK;VSY(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C8*;7-G:60@
M(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,S`U"B,L(&9U>GIY"FUS9VED(")T<GD@86=A:6XB
M"FUS9W-T<B`B2V&^9.D@</AI:&SAN65N[2!D;R!S>7-TZ6UU(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,S8@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.C(V.0IM<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER
M;2(*;7-G<W1R(")P<F\@<&]T=G)Z96[M(&YA<&FY=&4@:&5S;&\@9'9A:W+A
M="(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I
M9F8N<&AP.C<Y"FUS9VED(")U;FEF:65D(@IM<V=S='(@(G-J961N;V-E;OTB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U!A<G0N<&AP.C(W"FUS9VED(")U
M;FYA;65D(@IM<V=S='(@(F)E>B!NX7IV=2(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B=7-E
M<B!S96QE8W0B"FUS9W-T<B`B=GEB<F%T('6^:79A=&5L92(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I9"`B=D-A
M<F0B"FUS9W-T<B`B=D-A<F0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C0Q"FUS9VED(")W.B(*;7-G<W1R(")W.B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED(")W96%T:&5R
M+F-O;2(*;7-G<W1R(")W96%T:&5R+F-O;2(*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+W!T7T)2
M+G!O````````````````````````````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#<S,S<S-2`Q,#4Q-30S,S<T,R`P,3<U-#8`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````(R!T<F%N<VQA=&EO;B!O
M9B!H;W)D92YP;R!T;R!"<F%Z:6QI86X@4&]R='5G=65S90HC($-O<'ER:6=H
M="`H0RD@645!4B!(;W)D92!0<F]J96-T"B,@5&AI<R!F:6QE(&ES(&1I<W1R
M:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE($AO<F1E('!A
M8VMA9V4N"B,*(R!&86)I;R!';VUE<R`\9FQG;VUS0'5O;"YC;VTN8G(^+"`R
M,#`V+@IM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@
M2&]R9&5<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R
M9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ
M,BLP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`V+3`R+3$U(#$V.C4P
M+3`R,#!<;B(*(DQA<W0M5')A;G-L871O<CH@1F%B:6\@1V]M97,@/&9L9V]M
M<T!U;VPN8V]M+F)R/EQN(@HB3&%N9W5A9V4M5&5A;3H@0G)A>FEL:6%N(%!O
M<G1U9W5E<V4@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-12U697)S
M:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E
M=#U)4T\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X
M8FET7&XB"B)8+4=E;F5R871O<CH@2T)A8F5L(#$N,RXQ7&XB"B)0;'5R86PM
M1F]R;7,Z("!N<&QU<F%L<STR.R!P;'5R86P]*&X@/B`Q*3M<;B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B("@E<R!D87ES(&%G;RDB"FUS9W-T<B`B("@E<R!D:6%S(&%T<N%S*2(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,W-`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B("A496-L82!D
M92!!=&%L:&\@)7,I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,X
M,0HC+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@
M(B`H96T@)7,@9&EA<RDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S<W"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(@*&AO:F4I(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W.0IM<V=I9"`B("AT;VUO<G)O=RDB
M"FUS9W-T<B`B("AA;6%N:.,I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C,W-0IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@(B`H;VYT96TI
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-2!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4P"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS.38*;7-G:60@(B!A="`B"FUS9W-T<B`B(&$@(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B7"(E
M<UPB($[C;R#I('5M(&1I<F5T\W)I;RXB"@HC.B!F<F%M97=O<FLO0TQ)+T-,
M22YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@
M82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(B<E<R<@;N-O(.D@=6UA(&5S8V]L
M:&$@=N%L:61A+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R
M>2YP:'`Z-S$P"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP
M:'`Z,3`Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&-O
M;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*;7-G<W1R("(G)7,G
M(&[C;R!E<W3A(&-O;F9I9W5R861O(&YO(%)E9VES=')O(&1O($AO<F1E+B(*
M"B,Z(&9R86UE=V]R:R]4<F5E+U1R964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S
M='(@(G)E;F1E<FEZ861O<B!D92#A<G9O<F4@7"(E<UPB(&[C;R!E;F-O;G1R
M861O+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB
M"FUS9W-T<B`B7"(E<UPB(&9O:2!A9&EC:6]N861O(&%O('-I<W1E;6$@9&4@
M9W)U<&]S+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!P97)M
M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B!F;VD@861I8VEO;F%D
M;R!A;R!S:7-T96UA(&1E('!E<FUI<W/U97,N(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HU-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S
M='(@(EPB)R5S7"(@;N-O(&9O:2!C<FEA9&\Z("5S+B(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F34(@
M=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R("(E+C)F
M34(@=7-A9&]S(&1E)2XR9DU"('!E<FUI=&ED;W,@*"4N,F8E)2DB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(V"B,L('!H<"UF;W)M870*
M;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R("(E9"`E<R!E("5S(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HR-C@@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C4U-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!D87ES('5N
M=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`B)60@9&EA<R!A
M=.D@<W5A('-E;FAA(&5X<&ER87(N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R
M96-A<W0B"FUS9W-T<B`B)60@<')E=FESXV\@9&\@9&EA(@H*(SH@<V5R=FEC
M97,O;6%I;G1E;F%N8V4N<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M("T@3F]T:6-E(@IM<V=S='(@(B5S("T@079I<V\B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!&:6YG97)P<FEN="(*;7-G<W1R("));7!R97-SXV\@1&EG:71A;"!D
M92`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T
M,"!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B)7,@2T(B"@HC.B!S97)V
M:6-E<R]M86EN=&5N86YC92YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G
M<W1R("(E<R!/<&5R8>?U97,@9&4@36%N=71E;N?C;R`M($-O;F9I<FUAY^-O
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM
M<V=S='(@(D-O;F9I9W5R8>?C;R!D92`E<R(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HR-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M4VEG;B!5<"(*;7-G<W1R(")#861A<W1R;R!D92`E<R(*"B,Z('-E<G9I8V5S
M+VUA:6YT96YA;F-E+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!4
M97)M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`B)7,@5&5R;6]S(&1O($%C;W)D
M;R(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#,R(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z-#DT"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z-C@R(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4P"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(E
M<R!JX2!E>&ES=&4N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C8@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#8*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3(@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T
M<B`B)7,@82`E<R`E<R(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT
M.`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<R!I<R!R96%D>2!T;R!P97)F
M;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N
M($-H96-K('1H92`B"B)B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A
M;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N(@IM<V=S='(@(B(*(B5S(&5S
M=.$@<')O;G1O('!A<F$@97AE8W5T87(@87,@;W!E<F'G]65S(&1E(&UA;G5T
M96[GXV\@;6%R8V%D87,@86)A:7AO+B`B"B)-87)Q=64@82!C86EX82!P87)A
M('%U86QQ=65R(&]P97)AY^-O('%U92!V;V/J('%U96ER82!E>&5C=71A<B!D
M97-T82!V97HN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,T-`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("(E
M<R#I(&]B<FEG873S<FEO(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R("(E<R!M
M:6YU=&]S(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN
M<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM
M<V=S='(@(B5S(&[C;R!E;F-O;G1R861O+B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@
M)7,@;V8@)7,B"FUS9W-T<B`B)7,@82`E<R!D92`E<R(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3(Q"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M)W,@061D<F5S<R!";V]K(@IM<V=S='(@(D-A=.%L;V=O(&1E($5N9&5R9>=O
M<R!D92`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$S"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B06=E
M;F1A(&1E("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(D%N
M;W1AY_5E<R!D92`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3(Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T
M<B`B3&ES=&$@9&4@5&%R969A<R!D92`E<R(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@(B5S.B`E<R(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R,0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M97-S86=E(&UA>2!N
M;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O
M;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H
M92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN(@IM<V=S
M='(@(B(*(B5S.B!%<W1A(&UE;G-A9V5M('!O9&4@;N-O('-E<B!D92!Q=65M
M(&5L82!D:7H@<V5R+B!4;VUE(&-U:61A9&\@8V]M("(*(G%U86QQ=65R(&QI
M;FL@<')E<V5N=&4@;F5L82!O=2!E;2!F;W)N96-E<B!A;R!R96UE=&5N=&4@
M<75A;'%U97(@:6YF;W)M8>?C;R`B"B)P97-S;V%L+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS-30@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,Y.0IM<V=I9"`B+"!G=7-T:6YG("(*;7-G<W1R("(L(&)R:7-A
M("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3DU(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C`P"B,L('!H<"UF;W)M870*;7-G:60@(BP@9W5S=&EN9R`E<R`E
M<R(*;7-G<W1R("(L(&)R:7-A("5S("5S(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L92!F<F]M
M("5S('1O("5S(@IM<V=S='(@(BP@=F%R:>%V96P@9&4@)7,@<&%R82`E<R(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,CDT(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,S0X"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P-S,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$S,@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-S0V"FUS9VED
M("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B+2T@<V5L96-I;VYE("TM(@H*(SH@
M;&EB+T)L;V-K+W1I;64N<&AP.C(P"FUS9VED("(Q,B!(;W5R($9O<FUA="(*
M;7-G<W1R(")&;W)M871O(#$R($AO<F%S(@H*(SH@;&EB+T)L;V-K+W1I;64N
M<&AP.C$Y"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R(")&;W)M871O
M(#(T($AO<F%S(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G
M:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T(&AO<F%S(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U!A9V5R+G!H<#HV.0IM<V=I9"`B/%!R979I;W5S(@IM<V=S='(@
M(CQ0X6=I;F$@06YT97)I;W(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R
M-@IM<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T
M:&ES(&)L;V-K+B(*;7-G<W1R(")5;2!C;VYE8W1O<B!D92!B86YC;R!D92!D
M861O<R#I(&]B<FEG873S<FEO('!A<F$@97-T92!B;&]C;RXB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V,@IM<V=I9"`B02!F871A;"!E<G)O
M<B!H87,@;V-C=7)R960B"FUS9W-T<B`B56T@97)R;R!F871A;"!O8V]R<F5U
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3,U"FUS9VED
M(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M
M97-S86=E+B(*;7-G<W1R(")5;6$@8VAA=F4@</IB;&EC82!01U`@Z2!O8G)I
M9V%T\W)I82!P87)A(&-R:7!T;V=R869A<B!U;6$@;65N<V%G96TN(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V.`IM<V=I9"`B02!P
M=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@
M;65S<V%G92XB"FUS9W-T<B`B(@HB56UA(&-H879E('#Z8FQI8V$@4$=0(.D@
M;V)R:6=A=/-R:6$@<&%R82!V97)I9FEC87(@=6UA(&UE;G-A9V5M(&%S<VEN
M861A+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P.3D*
M;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M
M97-S86=E+B(*;7-G<W1R("(B"B)5;6$@8VAA=F4@<')I=F%D82!01U`@92!U
M;6$@<V5N:&$@<^-O(&]B<FEG873S<FEA<R!P87)A(&1E<V-R:7!T;V=R869A
M<B!U;6$@(@HB;65N<V%G96TN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3`Q-@IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I
M=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(E5M82!C:&%V92!P<FEV
M861A(%!'4"!E('5M82!S96YH82!SXV\@;V)R:6=A=/-R:6%S('!A<F$@87-S
M:6YA<B!U;6$@;65N<V%G96TN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU,#8*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL
M('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"B)5;6$@
M8VAA=F4@</IB;&EC82!3+TU)344L('5M82!C:&%V92!P<FEV861A(%,O34E-
M12!E('5M82!S96YH82!SXV\@(@HB;V)R:6=A=/-R:6%S('!A<F$@9&5S8W)I
M<'1O9W)A9F%R('5M82!M96YS86=E;2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%
M(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*(E5M
M82!C:&%V92!P^F)L:6-A(%,O34E-12P@=6UA(&-H879E('!R:79A9&$@4R]-
M24U%(&4@=6UA('-E;FAA('/C;R`B"B)O8G)I9V%T\W)I87,@<&%R82!A<W-I
M;F%R('5M82!M96YS86=E;2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E
M<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(")5;6$@8VAA
M=F4@</IB;&EC82!3+TU)344@Z2!O8G)I9V%T\W)I82!P87)A(&-R:7!T;V=R
M869A<B!U;6$@;65N<V%G96TN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B04T@0VQO=61S(@IM<V=S='(@(DYU
M=F5N<R!M871U=&EN87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ,`IM<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R(")#
M:'5V82!&<F%C82!697-P97)T:6YA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3$*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B
M0VAU=F$@;6%T=71I;F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R(")#:'5V
M87,@;6%T=71I;F%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G<W1R(").
M979A<V-A<R!-871U=&EN87,B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN
M8SHR.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`B04TO4$TB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@
M(D%022!)1"(*;7-G<W1R(")!4$D@240B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D
M:71O<B(*;7-G<W1R(")3;V)R92!E<W1E(&5D:71O<B(*"B,Z('-E<G9I8V5S
M+VAE;'`O:6YD97@N<&AP.C4S"FUS9VED(")!8F]U="XN+B(*;7-G<W1R(")3
M;V)R92XN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R(")!8G-B;W1T;VTB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R
M"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B06)S;6ED9&QE(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E
M;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")!8V5S<V\@
M;F5G861O(&%O(&-R:6%R(&1I<F5T\W)I;R!61E,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C
M<F5A=&EN9R!61E,@9FEL92XB"FUS9W-T<B`B06-E<W-O(&YE9V%D;R!A;R!C
M<FEA<B!A<G%U:79O(%9&4RXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M,PIM<V=I9"`B06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R(")3=6%S($EN
M9F]R;6'G]65S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X"FUS9VED
M(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@(E-E;FAA(&1A($-O;G1A(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDS"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`B0V]N=&$@9&5S
M871I=F%D82XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,U"FUS
M9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(D-O;G1A<R(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,30X('1E;7!L871E<R]P;W)T86PO861D
M+FEN8SHQ-`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN
M8SHQ,0IM<V=I9"`B061D(@IM<V=S='(@(D%D:6-I;VYA<B(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,C(T(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!
M9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B061I8VEO;F%R($=R=7!O(%-U8F]R
M9&EN861O(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY."!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDY"FUS9VED(")!9&0@0VAI
M;&0@4&5R;6ES<VEO;B(*;7-G<W1R(")!9&EC:6]N87(@4&5R;6ES<_5E<R!3
M=6)O<F1I;F%D87,B"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM
M<V=I9"`B061D($AE<F4Z(@IM<V=S='(@(D%D:6-I;VYE($%Q=6DZ(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O=7!S+G!H<#HR,3D*;7-G
M:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B061I8VEO;F%R($YO=F\@1W)U
M<&\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z.#@*;7-G:60@(D%D9"!.97<@4&5R
M;6ES<VEO;B(*;7-G<W1R(")!9&EC:6]N87(@3F]V82!097)M:7-SXV\B"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHW"B,L('!H
M<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*
M;7-G<W1R(")!9&EC:6]N87(@=6T@9W)U<&\@<W5B;W)D:6YA9&\@82`G)7,G
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R!<(B5S
M7"(B"FUS9W-T<B`B061I8VEO;F%R('5M82!P97)M:7-SXV\@<W5B;W)D:6YA
M9&$@82`G)7,G(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!A
M(&YE=R!U<V5R.B(*;7-G<W1R(")!9&EC:6]N87(@=6T@;F]V;R!U<W7A<FEO
M.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU
M-30*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B061I8VEO;F%R(&-O;'5N
M82(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,S0*;7-G
M:60@(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R(")!9&EC:6]N87(@;F]V;W,@
M;65M8G)O<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z.34*;7-G
M:60@(D%D9"!P86ER(@IM<V=S='(@(D%D:6-I;VYA<B!P87(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S<Q"B,L('!H<"UF;W)M870*;7-G:60@(D%D
M9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R(")!
M9&EC:6]N87(@;R!-96YU("5S(&-O;6\@=6UA($)A<G)A($QA=&5R86P@9&\@
M36]Z:6QL82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HW,0IM<V=I9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B
M061I8VEO;F%R(&%O(&-A=.%L;V=O(&1E(&5N9&5R9>=O<SHB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*;7-G:60@(D%D
M9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`B061I8VEO;F%R(&%O(&UE
M=2!C873A;&]G;R!D92!E;F1E<F7G;W,B"@HC.B!A9&UI;B]U<V5R+G!H<#HS
M,0IM<V=I9"`B061D('5S97(B"FUS9W-T<B`B061I8VEO;F%R('5S=>%R:6\B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A
M9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G
M<W1R("(B"B(G)7,G(&%D:6-I;VYA9&\@86\@<VES=&5M82P@;6%S(&[C;R!P
M=61E(&EN8VQU:7(@:6YF;W)M8>?U97,@861I8VEO;F%I<R!D;R`B"B)C861A
M<W1R;SH@)7,N(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@
M:6X@;F]W+B(*;7-G<W1R("(E<R!A9&EC:6]N861O(&%O('-I<W1E;6$N(%9O
M8^H@<&]D92!S92!C;VYE8W1A<B!A9V]R82XB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I
M<V%B;&5D+B(*;7-G<W1R(")!9&GGXV\@9&4@=7-UX7)I;W,@97-TX2!D97-A
M8FEL:71A9&$N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$R-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3<S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#4*;7-G:60@
M(D%D9')E<W,B"FUS9W-T<B`B16YD97)EYV\B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,30Q"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B
M0V%TX6QO9V\@9&4@16YD97)EYV]S(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.30*;7-G:60@(D%D;6EN:7-T97(@+2!S970@
M<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S='(@(D%D;6EN:7-T
M<F%R("T@8V]N9FEG=7)A('!E<FUI<W/U97,@<&%R82!O=71R;W,@=7-UX7)I
M;W,B"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I
M9&5B87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`B
M061M:6YI<W1R8>?C;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M-#,*;7-G:60@(D%D<R(*;7-G<W1R(")!;OIN8VEO<R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*
M;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@(D%F96=A;FES=.-O(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU-PIM<V=I9"`B06QB86YI82(*;7-G<W1R(")!;&+B;FEA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,`IM<V=I9"`B06QG97)I82(*;7-G<W1R(")!<F?I<FEA(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P-PIM<V=I
M9"`B06QI87,B"FUS9W-T<B`B07!E;&ED;R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*;7-G:60@(D%L:6=N
M(@IM<V=S='(@(D%L:6YH87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@
M(D%L:6YH86UE;G1O.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM
M<V=I9"`B06QL(@IM<V=S='(@(E1O9&]S(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV
M-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`B5&]D
M;W,@57-UX7)I;W,@075T96YT:6-A9&]S(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM<V=I9"`B06QL($=R;W5P<R(*
M;7-G<W1R(")4;V1O<R!'<G5P;W,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.CDQ(&9R86UE=V]R:R]097)M<R]097)M<R]D871A=')E92YP
M:'`Z-S4*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R(")4;V1A<R!0
M97)M:7-S]65S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS9W-T
M<B`B5&]D;W,@<75A=')O(&QA9&]S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@W-0IM<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM
M<V=S='(@(E!E<FUI=&ER(&WZ;'1I<&QO<R!E;F1E<F7G;W,B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3,X"FUS9VED(")!;&QO=R!S971T:6YG(&]F
M(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R(")097)M:71I<B!C;VYF:6=U
M<F%R(&\@=&EP;R!D92!L:7-T87,@;W)D96YA9&%S/R(*"B,Z(&9R86UE=V]R
M:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR96%D
M>2!E>&ES=',B"FUS9W-T<B`B2N$@97AI<W1E(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$R-@IM<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB"FUS
M9W-T<B`B3&]G:6X@24U34"!!;'1E<FYA=&EV;R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,3$*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D
M(@IM<V=S='(@(E-E;FAA($E-4U`@06QT97)N871I=F$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3`S"FUS9VED(")!;'1E<FYA=&4@24U34"!5<V5R
M;F%M92(*;7-G<W1R(")5<W7A<FEO($E-4U`@06QT97)N871I=F\B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS-0IM<V=I9"`B06QT97)N871E
M(&5M86EL(&%D9')E<W,B"FUS9W-T<B`B16YD97)EYV\@9&4@92UM86EL(&%L
M=&5R;F%T:79O(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*;7-G:60@
M(D%L=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`B36]D96QO<R!A;'1E<FYA
M=&EV;W,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*;7-G
M<W1R(")497AT;R!A;'1E<FYA=&EV;SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!
M;65R:6-A;B!386UO82(*;7-G<W1R(")386UO82!!;65R:6-A;F$B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A
M<R!S<&5C:69I960N(@IM<V=S='(@(E5M('9A;&]R(&EL96=A;"!F;VD@97-P
M96-I9FEC861O+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-34*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N(@IM<V=S
M='(@(D]C;W)R974@=6T@97)R;R!D97-C;VYH96-I9&\N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M-0IM<V=I9"`B06YD;W)R82(*;7-G<W1R(")!;F1O<G)A(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M.`IM<V=I9"`B06YG;VQA(@IM<V=S='(@(D%N9V]L82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*
M;7-G:60@(D%N9W5I;&QA(@IM<V=S='(@(D%N9W5I;&QA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R
M;WAY(@IM<V=S='(@(E!R;WAY(&%N]&YI;6\B"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@(E)E<W!O
M<W1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R(")!
M;G3A<G1I9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N9"!"87)B
M=61A(@IM<V=S='(@(D%N=&EG=6$@92!"87)B861O<R(*"B,Z(&%D;6EN+W1E
M;7!L871E<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN<&AP.C,U"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3@@=&5M<&QA=&5S+V%D;6EN+W-E
M='5P+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`B
M07!L:6-AY^-O(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R"FUS9VED
M(")!<'!L:6-A=&EO;B!,:7-T(@IM<V=S='(@(DQI<W1A(&1E($%P;&EC8>?U
M97,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,30P"FUS9VED(")!<'!L
M:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`B02!A<&QI8V'GXV\@97-TX2!P
M<F]N=&$N(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,3@*;7-G
M:60@(D%P<&QY('1O($-H:6QD(%-H87)E<R(*;7-G<W1R(")!<&QI8V%R(&%O
M<R!#;VUP87)T:6QH86UE;G1O<R!3=6)O<F1I;F%D;W,B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*
M;7-G<W1R(")!<')O=F%R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT
M96YT<RYP:'`Z.#0P"FUS9VED(")!<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@
M(E1A;6%N:&\@07!R;WAI;6%D;R(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!<')I;"(*;7-G<W1R(")!8G)I
M;"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<T"FUS9VED(")!<F%B:6,@
M*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`B07+A8FEC;R`H5VEN9&]W<RTQ,C4V
M*2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<X"FUS9VED(")!<F-H
M:79E($9I;&4@4VEZ92(*;7-G<W1R(")486UA;FAO(&1O($%R<75I=F\B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4X(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW-PIM<V=I9"`B07)C:&EV92!.
M86UE(@IM<V=S='(@(DYO;64@9&\@07)Q=6EV;R(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG
M;G5P(')E<75E<W0@9F]R("5S(#\B"FUS9W-T<B`B5F]CZB!T96T@8V5R=&5Z
M82!Q=64@<75E<B!R96UO=F5R(&$@<V]L:6-I=&'GXV\@9&4@8V%D87-T<F\@
M9&4@)7,_(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC
M.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H
M('1O(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R
M(")6;V/J('1E;2!C97)T97IA('%U92!D97-E:F$@97AC;'5I<B`G)7,G(&4@
M<V5U<R!S=6)G<G5P;W,_(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B07)G96YT:6YA
M(@IM<V=S='(@(D%R9V5N=&EN82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%R;65N
M:6$B"FUS9W-T<B`B07)MZFYI82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3<U"FUS9VED(")!<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R(")!<FWJ
M;FEO("A!4DU30TE)+3@I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X
M"FUS9VED(")!<G0B"FUS9W-T<B`B07)T92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@
M(D%R=6)A(@IM<V=S='(@(D%R=6)A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R("))
M;&AA($%S8V5N<^-O(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS
M9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B07)T92!!<V-I:2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I9FEC
M(%)E9VEO;B(*;7-G<W1R("+!<VEA+U)E9VGC;R!D;R!086/M9FEC;R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,CD*;7-G:60@(D%S:R!F;W(@8V]N
M9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS
M/R(*;7-G<W1R(")3;VQI8VET87(@8V]N9FER;6'GXV\@86YT97,@9&4@97AE
M8W5T87(@87,@;W!E<F'G]65S(&1E(&UA;G5T96[GXV\_(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S$P,@IM<V=I9"`B07-S:6=N;65N="!C;VQU
M;6YS(@IM<V=S='(@(D-O;'5N87,@9&4@9&5S:6=N8>?C;R(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z-S0*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N
M+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R(")496YT;W4@97AC;'5I<B!U;2!G
M<G5P;R!I;F5X:7-T96YT92XB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP
M.C(Y"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P
M97)M:7-S:6]N+B(*;7-G<W1R(")496YT;W4@97AC;'5I<B!U;6$@<&5R;6ES
M<^-O(&[C;R!E>&ES=&5N=&4N(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z
M.#<*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M
M:7-S:6]N+B(*;7-G<W1R(")496YT;W4@961I=&%R('5M82!P97)M:7-SXV\@
M;N-O(&5X:7-T96YT92XB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z
M-3,*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R
M92XB"FUS9W-T<B`B5&5N=&]U(&5D:71A<B!U;2!C;VUP87)T:6QH86UE;G1O
M(&[C;R!E>&ES=&5N=&4N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HV-"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<Q"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z
M.#,*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B071R:6)U=&]S(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@
M(D%U9W5S="(*;7-G<W1R(")!9V]S=&\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!
M=7-T<F%L:6$B"FUS9W-T<B`B075S='+A;&EA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I
M9"`B075S=')I82(*;7-G<W1R("+!=7-T<FEA(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E
M<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T
M:%]C>7)S<6PZ($[C;R!F;VD@96YC;VYT<F%D82!A(&5X=&5N<^-O(&EM87`@
M;F5C97-SX7)I82XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H
M<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V
M92!R97%U:7)E9"!C87!A8FEL:71E<RXB"FUS9W-T<B`B075T:%]C>7)U<SH@
M3R!C;VYE8W1O<B!NXV\@<&]S<W5I(&%S(&-A<&%C:61A9&5S(&YE8V5S<^%R
M:6%S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$R,@IM
M<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!.XV\@9F]I(&5N8V]N=')A
M9&$@82!E>'1E;G/C;R!I;6%P(&YE8V5S<^%R:6$N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]F='`N<&AP.C,V"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q
M=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I
M=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@(B(*(D%U
M=&A?9G1P.B!.XV\@9F]I(&5N8V]N=')A9&$@82!E>'1E;G/C;R!&5%`@;F5C
M97-SX7)I82X@0V]M<&EL92!O(%!(4"!C;VT@82`B"B)O<.?C;R`M+65N86)L
M92UF='`N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HV-`IM
M<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(D%U=&A?:6UA<#H@3N-O(&9O:2!E;F-O;G1R861A
M(&$@97AT96YSXV\@:6UA<"!N96-E<W/A<FEA+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q=6ER
M960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VMR
M8C4Z($[C;R!F;VD@96YC;VYT<F%D82!A(&5X=&5N<^-O(&MR8C4@;F5C97-S
MX7)I82XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,P,@IM
M<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E
M9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R(")!=71H7VQD87`Z($EN
M8VQU<^-O(&1E('5S=>%R:6]S(&[C;R#I('-U<&]R=&%D82!P87)A($%C=&EV
M92!$:7)E8W1O<GDB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C,U-PIM<V=I9"`B075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@
M<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(D%U=&A?
M;&1A<#H@17AC;'5SXV\@9&4@=7-UX7)I;W,@;N-O(.D@<W5P;W)T861A('!A
M<F$@06-T:79E($1I<F5C=&]R>2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z-C,*;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VQD87`Z($[C;R!F
M;VD@96YC;VYT<F%D82!A(&5X=&5N<^-O($Q$05`@;F5C97-SX7)I82XB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,S.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*(D%U
M=&A?;&1A<#H@26UP;W-S[79E;"!A9&EC:6]N87(@;R!U<W7A<FEO("5S+B!)
M<W1O(&9O:2!O('%U92!O('-E<G9I9&]R("(*(G)E<&]R=&]U.B`B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,X-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(*
M;7-G<W1R(")!=71H7VQD87`Z($EM<&]S<^UV96P@<F5M;W9E<B!O('5S=>%R
M:6\@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0Y.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A
M=&4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z($EM<&]S<^UV96P@871U
M86QI>F%R(&\@=7-UX7)I;R`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z-#`U"FUS9VED(")!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S
M(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN(@IM<V=S
M='(@(B(*(D%U=&A?;&1A<#H@071U86QI>F'GXV\@9&4@=7-UX7)I;W,@;N-O
M(.D@<W5P;W)T861A('!A<F$@06-T:79E($1I<F5C=&]R>2XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C0V"FUS9VED(")!=71H7VUC86PZ
M(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M075T:%]M8V%L.B!.XV\@9F]I(&5N8V]N=')A9&$@82!E>'1E;G/C;R!-0T%,
M(&YE8V5S<^%R:6$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP
M.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]S;6)A=71H.B!.XV\@
M9F]I(&5N8V]N=')A9&$@82!E>'1E;G/C;R!S;6)A=71H(&YE8V5S<^%R:6$N
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!9&UI;BYP:'`Z,3`V"FUS9VED
M(")!=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N(@IM<V=S
M='(@(D%U=&5N=&EC8>?C;R!N;R!S97)V:61O<B!)34%0(&9A;&AO=2XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3`*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R(")&86QH
M82!N82!A=71E;G1I8V'GXV\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HV-PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")!=71H96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S='(@(D9A;&AA(&YA
M(&%U=&5N=&EC8>?C;SH@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A
M9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B
M>2!2041)55,@<V5R=F5R+B(*;7-G<W1R(")!=71E;G1I8V'GXV\@<F5J96ET
M861A('!E;&\@<V5R=FED;W(@4D%$2553+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z.#@R"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!&5%`@
M<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B02!A=71E;G1I8V'GXV\@;F\@<V5R
M=FED;W(@1E10(&9A;&AO=2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C<P"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E
M<B!F86EL960N(@IM<V=S='(@(D$@875T96YT:6-AY^-O(&YO('-E<G9I9&]R
M(%--0B!F86QH;W4N(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW
M-0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`B0V%M<&]S(&1I
M<W!O;NUV96ES.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%Z97)B86EJ86XB"FUS
M9W-T<B`B07IE<F)A:6KC;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M,`IM<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(D1E<V-U;'!A<R!D;R!"
M3T9((@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R(")&=6YD;R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C,*
M;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`B0V]R(&1E($9U;F1O
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B
M0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R(")396YH82!K97)B97)O
M<R!I;F-O<G)E=&$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H
M<#HX,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N86UE+B(*;7-G<W1R(")5
M<W7A<FEO(&ME<F)E<F]S(&EN8V]R<F5T;RXB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED
M(")"86AA;6%S(@IM<V=S='(@(D)A:&%M87,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED
M(")"86AR86EN(@IM<V=S='(@(D)A:')A:6XB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$W-@IM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T
M<B`B0N%L=&EC;R`H25-/+3@X-3DM,3,I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B
M0F%N9VQA9&5S:"(*;7-G<W1R(")"86YG;&%D97-H(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM
M<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B0F%R8F%D;W,B"@HC.B!U=&EL+VEC
M;VY?8G)O=W-E<BYP:'`Z,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G
M<F%P:&EC<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B
M3N-O(&9O:2!E;F-O;G1R861O(&\@9&ER973S<FEO(&)A<V4@9&4@:6UA9V5N
M<R`G)7,G+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW,PIM<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B3&EN:&$@
M9&4@4&%R=&ED82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&%R=7,B"FUS9W-T
M<B`B0F5L;W+Z<W-I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)E;&=I=6TB"FUS
M9W-T<B`B0NEL9VEC82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&EZ92(*;7-G
M<W1R(")"96QI>F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"96YI;B(*;7-G<W1R
M(")"96YI;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B
M0F5R;75D87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")":'5T86XB"FUS9W-T<B`B
M0G5TXV\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G<W1R(")!;FEV97)SX7)I;R(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS-30*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T
M:6]N(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(D[C;R!F;VD@96YC;VYT
M<F%D;R!O(&)L;V-O(%PB)7-<(B!D82!A<&QI8V'GXV\@7"(E<UPB+B(*"B,Z
M('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY,`IM<V=I9"`B0FQO8VL@
M4V5T=&EN9W,B"FUS9W-T<B`B0V]N9FEG=7)AY_5E<R!D;R!";&]C;R(*"B,Z
M('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@
M5'EP92(*;7-G<W1R(")4:7!O(&1E($)L;V-O(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S
M='(@(DYE9W)I=&\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")";VQI=FEA(@IM<V=S
M='(@(D)O;.UV:6$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`W
M"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`B1F%V;W)I=&]S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`IM
M<V=I9"`B0F]R9&5R(@IM<V=S='(@(D)O<F1A(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H
M:6-K;F5S<SHB"FUS9W-T<B`B3&%R9W5R82!D82!B;W)D83HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Q"FUS
M9VED(")";W)D97)S(@IM<V=S='(@(D)O<F1A<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G
M:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B"FUS9W-T<B`B0O-S;FEA(&4@
M2&5R>F5G;W9I;F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.38*;7-G
M:60@(D)O=&@B"FUS9W-T<B`B06UB;W,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"
M;W1S=V%N82(*;7-G<W1R(")";W1S=6%N82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M
M(@IM<V=S='(@(E)O9&%PZ2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O=79E="!)
M<VQA;F0B"FUS9W-T<B`B26QH82!";W5V970B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED
M(")"<F%Z:6PB"FUS9W-T<B`B0G)A<VEL(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HT,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@
M(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R(")497)R
M:73S<FEO(&1O($]C96%N;R#-;F1I8V\@26YG;.IS(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM
M<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`B0G)U;F5I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B0G5L9^%R:6$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"FUS
M9VED(")"=6QL971E9"!,:7-T(@IM<V=S='(@(DQI<W1A(&-O;2!-87)C861O
M<F5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S='(@
M(D)U<FMI;F$@1F%S;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS
M9W-T<B`B0G5R=6YD:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M-#8*;7-G:60@(D--4R(*;7-G<W1R(")#35,B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B
M0U)#(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@*
M;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM<V=S='(@(E!O;G1O
M<R!D92!$:7-T<FEB=6GGXV\@0U),(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(W"FUS9VED(")#7V5L;"!0
M<F]P97)T:65S+BXN(@IM<V=S='(@(E!R;W!R:65D861E<R!D82!#Z5]L=6QA
M+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U,0IM<V=I
M9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T<B`B02!L
M:7-T82!D92!D:7-T<FEB=6GGXV\@;N-O(&9O:2!E<W!E8VEF:6-A9&$N(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X,R!C
M;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3@W"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ-3<*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(D%G96YD82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S4*;7-G:60@(D-A
M;&TB"FUS9W-T<B`B0V%L;6\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B0V%M8F]D
M:6$B"FUS9W-T<B`B0V%M8F]D:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#86UE
M<F]O;B(*;7-G<W1R(")#86UA<O5E<R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C(P"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U
M=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G
M<W1R("(B"B).XV\@Z2!P;W-S[79E;"!G97)A<B!U;6$@;F]V82!S96YH82!A
M=71O;6%T:6-A;65N=&4L(&5N=')E(&5M(&-O;G1A=&\@8V]M(&\@(@HB861M
M:6YI<W1R861O<BXB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS
M-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W<FET92!T;R!F:6QE
M(%PB)7-<(B(*;7-G<W1R(").XV\@8V]N<VEG;R!G<F%V87(@;R!A<G%U:79O
M(%PB)7-<(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,@IM<V=I9"`B0V%N
M)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+B(*;7-G
M<W1R(").XV\@Z2!P;W-S[79E;"!A9&UI;FES=')A<B!G97)E;F-I861O<F5S
M(&5X=&5R;F]S(&1E('-E<W/C;RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G5S+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP
M.C,Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-
M05`@<V5R=F5R.B`E<R(*;7-G<W1R(").XV\@Z2!P;W-S[79E;"!C;VYE8W1A
M<B!A;R!S97)V:61O<B!)34%0.B`E<R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C0T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!O<&5N
M(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").XV\@8V]N<VEG;R!A8G)I<B!O(&%R
M<75I=F\@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-A;F%D82(*;7-G
M<W1R(")#86YA9.$B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E
M<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHV-0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z
M,3$@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*
M;7-G<W1R(")#86YC96QA<B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B"FUS9W-T
M<B`B0V%N8V5L87(@4F5L873S<FEO(&1E(%!R;V)L96UA(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HS,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3N-O(.D@<&]S
M<^UV96P@97AC;'5I<B!O(&%R<75I=F\@7"(E<UPB+B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HT-@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R"FUS9VED(")#86YN
M;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(D[C;R#I
M('!O<W/M=F5L(&5N8V]N=')A<B!U;2!D:7)E=/-R:6\@=&5M<&]RX7)I;RXB
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.CDQ
M"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P
M87)A;65T97(N(@IM<V=S='(@(D[C;R#I('!O<W/M=F5L(&-O;G1I;G5A<B!S
M96T@;R!P87+B;65T<F\@)W1A<F=E=$9I;&4G+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,S$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO
M="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B3N-O(.D@<&]S
M<^UV96P@97AC;'5I<B!O(&1I<F5T\W)I;R!<(B5S7"(N(@H*(SH@9G)A;65W
M;W)K+T1A=&%4<F5E+T1A=&%4<F5E+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4
M<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L('!H<"UF;W)M870*;7-G:60@
M(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R(").
MXV\@Z2!P;W-S[79E;"!E>&-L=6ER+"`E9"!P;W-S=6D@<W5B;W)D:6YA9&]S
M+B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8P
M.`IM<V=I9"`B(@HB0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S
M('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B
M"B)S=&]R960N(@IM<V=S='(@(B(*(D[C;R#I('!O<W/M=F5L(')E;W)D96YA
M<BP@;OIM97)O(&1E(')E9VES=')O<R!F;W)N96-I9&]S('!A<F$@<F5O<F1E
M;F%R(&[C;R`B"B)C;W)R97-P;VYD92!A;R!N^FUE<F\@87)M87IE;F%D;RXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE
M9"!N=6UB97(N(@IM<V=S='(@(D[C;R#I('!O<W/M=F5L(')O=&5A<B!M96YS
M86=E;2!P87)A(&\@;OIM97)O(&5S<&5C:69I8V%D;RXB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X
M"FUS9VED(")#87!E(%9E<F1E(@IM<V=S='(@(D-A8F\@5F5R9&4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T
M"FUS9VED(")#87!T:6]N(@IM<V=S='(@(E3M='5L;R(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R
M<FEE<B(*;7-G<W1R(")/<&5R861O<F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.3,*;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R
M(")#871E9V]R:6%S(&4@3F]M97,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y
M;6%N($ES;&%N9',B"FUS9W-T<B`B26QH87,@0V%Y;6%N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L
M;"!0:&]N92(*;7-G<W1R(")496QE9F]N92!#96QU;&%R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0IM<V=I
M9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(E!R;W!R:65D861E<R!D82!#
MZ6QU;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R(")-87)G96T@
M9&$@8^EL=6QA.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G
M<W1R(")0<F]P<FEE9&%D97,@9&$@0^EL=6QA(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A
M8VEN9SHB"FUS9W-T<B`B17-P8>=A;65N=&\@9&$@8^EL=6QA.B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-S@*;7-G:60@(D-E;&QP:&]N92(*
M;7-G<W1R(")496QE9F]N92!C96QU;&%R(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ-S<*;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM,30I(@IM<V=S='(@
M(D/I;'1I8V\@*$E33RTX.#4Y+3$T*2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*
M;7-G<W1R(")#96YT<F\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F
M<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B4F5P^F)L:6-A(&1A(,%F<FEC82!#
M96YT<F%L(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D-E
M;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(D5U<F]P82!#
M96YT<F%L("A)4T\M.#@U.2TR*2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-S`P"FUS9VED(")#97)T:69I8V%T92!$971A:6QS(@IM
M<V=S='(@(D1E=&%L:&5S(&1O($-E<G1I9FEC861O(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3(*;7-G:60@(D-E<G1I9FEC871E
M($]W;F5R(@IM<V=S='(@(E!R;W!R:65TX7)I;R!D;R!#97)T:69I8V%D;R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED
M(")#97)T:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R(")0;VSM=&EC87,@9&\@
M0V5R=&EF:6-A9&\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(D-H860B"FUS9W-T
M<B`B5&-H861E(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@IM<V=I9"`B0VAA;F=E
M(@IM<V=S='(@(D%L=&5R87(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z,S$*;7-G:60@(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@
M(D%L=&5R92!3=6$@4V5N:&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-CD*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T
M('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@
M(@HB96UA:6QS+B(*;7-G<W1R("(B"B)!;'1E<F%R(&\@;F]M92!E(&\@96YD
M97)EYV\@<75E(&%S('!E<W-O87,@=NIE;2!Q=6%N9&\@96QA<R!LZF5M(&4@
M<F5S<&]N9&5M("(*(G-U87,@;65N<V%G96YS+B(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U<B!P
M87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N
M9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*
M;7-G<W1R("(B"B)!;'1E<F'GXV\@9&4@<V5N:&$@;N-O(.D@<W5P;W)T861A
M(&YA(&-O;F9I9W5R8>?C;R!A='5A;"X@($5N=')E(&5M(&-O;G1A=&\@(@HB
M8V]M(&\@861M:6YI<W1R861O<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(W"FUS9VED(")#:&%R(@IM<V=S
M='(@(D-H87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S
M='(@(E9E<FEF:6-A<B!,:6Y?:RXN+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H
M:6QE(@IM<V=S='(@(D-H:6QE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;F$B
M"FUS9W-T<B`B0VAI;F$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.0IM
M<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(D-H
M:6[J<R!3:6UP;&EF:6-A9&\@*$=",C,Q,BDB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X,`IM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB
M"FUS9W-T<B`B0VAI;NIS(%1R861I8VEO;F%L("A":6<U*2(*"B,Z('1E;7!L
M871E<R]P<F5F<R]A<'`N:6YC.C<*;7-G:60@(D-H;V]S92!!<'!L:6-A=&EO
M;CHB"FUS9W-T<B`B17-C;VQH82!A($%P;&EC8>?C;SHB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C<P"FUS9VED(")#:&]O<V4@82!P
M87-S=V]R9"(*;7-G<W1R(")%<V-O;&AA('5M82!S96YH82(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(D-H;V]S92!A
M('5S97)N86UE(@IM<V=S='(@(D5S8V]L:&$@=6T@=7-UX7)I;R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#(*;7-G:60@(D-H;V]S92!H;W<@=&\@
M9&ES<&QA>2!D871E<SHB"FUS9W-T<B`B17-C;VQH82!C;VUO(&5X:6)I<B!D
M871A<SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T>7!E
M("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B17-C;VQH82!O('1I<&\@
M9&4@97-T:6QO(&1E(&QI<W1A<R`H<&%R82!L:7-T87,@;W)D96YA9&%S*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HU-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C@*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B
M26QH87,@0VAR:7-T;6%S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H
M<#HR.30@9G)A;65W;W)K+U9&4R]61E,N<&AP.CDQ-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS
M9W-T<B`B3N-O(&9O:2!E;F-O;G1R861A(&$@9&5F:6YIY^-O(&1E(&-L87-S
M92!D92`E<RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ-`IM<V=I9"`B0VQE87(B"FUS9W-T<B`B3&EM<&%R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B
M0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R("),:6UP87(@=&%G<R!-4T]F
M9FEC92(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*;7-G:60@(D-L96%R
M(%%U97)Y(@IM<V=S='(@(D5X8VQU:7(@=7-UX7)I;R(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@
M(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R(")%>&-L=6ER('5S=>%R:6\Z
M("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$Q"FUS
M9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(D5X8VQU:7(@=7-UX7)I;R(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T"FUS9VED(")#;&5A
M<B!U<V5R(&1A=&$B"FUS9W-T<B`B17AC;'5I<B!D861O<R!D;R!U<W7A<FEO
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,34*
M;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B0^EU(&%B97)T;R!A(%1A
M<F1E(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT
M;6PZ-C`*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(D-L:7%U
M92!P87)A($-O;G1I;G5A<B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@
M2%144"(*;7-G<W1R(")#;&EC:V%T96QL('9I82!(5%10(@H*(SH@<V5R=FEC
M97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`B1F5C:&%R($IA;F5L
M82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Q"FUS9VED(")#;&]U9',B
M"FUS9W-T<B`B3G5V96YS(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,38*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R(").
M=6)L861O('!E;&$@36%N:.,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(DYU8FQA
M9&\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8T"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD
M<R(*;7-G<W1R("));&AA<R!D92!#;V-O<R(*"B,Z('1E;7!L871E<R]P;W)T
M86PO<VED96)A<BYI;F,Z,C,*;7-G:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS
M9W-T<B`B0V]N=')A:7(@0F%R<F$@3&%T97)A;"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O
M;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@(D-O;G1R86ER(&)O<F1A<R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C<*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(D-O;/1M8FEA(@H*
M(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP
M.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@(D-O<B(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C4*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`Q('-E<G9I8V5S+VEM
M86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R(%!I8VME<B(*
M;7-G<W1R(")086QH971A(&1E($-O<F5S(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C@S-0IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R
M(")396QEY^-O(&1E($-O<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R(")#;VQS
M.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-3`*;7-G:60@(D-O
M;'5M;B!T:71L97,B"FUS9W-T<B`B5.UT=6QO<R!D87,@0V]L=6YA<R(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C8*;7-G:60@(D-O;6EC<R(*
M;7-G<W1R(")1=6%D<FEN:&]S(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(U
M"FUS9VED(")#;VUM86YD(@IM<V=S='(@(D-O;6%N9&\B"@HC.B!A9&UI;B]C
M;61S:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B
M3&EN:&$@9&4@0V]M86YD;R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0Q,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R(")#;VUE;G1A<B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38W"FUS9VED
M(")#;VUM;VX@3F%M92(*;7-G<W1R(").;VUE(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G
M:60@(D-O;6]R;W,B"FUS9W-T<B`B0V]M;W)O<R(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@(D-O;7!A;GDB
M"FUS9W-T<B`B16UP<F5S82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M,0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(D-O;7!U=&%D;W)E<R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#8*;7-G:60@(D-O;F1I
M=&EO;B(*;7-G<W1R(")#;VYD:>?C;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C4V"FUS9VED(")#;VYD:71I;VYS(@IM<V=S='(@(D-O;F1IY_5E<R(*
M"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T
M:6]N($1I9F9E<F5N8V5S(@IM<V=S='(@(D1I9F5R96[G87,@9&4@0V]N9FEG
M=7)AY^-O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-@IM<V=I9"`B
M0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO
M;F5S(&%N9"!/=71L;V]K+B(*;7-G<W1R(")#;VYF:6=U<F'GXV\@9&4@<VEN
M8W)O;FEZ8>?C;R!C;VT@4$1!<RP@4VUA<G1P:&]N97,@92!/=71L;V]K+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S4*;7-G:60@(D-O;F9I9W5R
M871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@(D-O;F9I9W5R8>?C;R!N
M96-E<W-I=&$@9&4@871U86QI>F'GXV\N(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B
M"FUS9W-T<B`B0V]N9FEG=7)A<B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z-3$*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS
M9W-T<B`B0V]N9FER;64@82!396YH82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O
M;F=O(@IM<V=S='(@(D-O;F=O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V]N9V\L
M(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R(")#;VYG
M;RP@4F5P^F)L:6-A($1E;6]C<N%T:6-A(&1O(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F
M86EL960N(@IM<V=S='(@(D9A;&AA(&YA(&-O;F5XXV\N(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C
M=&EO;B!F86EL960Z("(*;7-G<W1R(")&86QH82!N82!C;VYE>.-O.B`B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3`*;7-G:60@(D-O
M;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS
M9W-T<B`B0V]N97CC;R!R96-U<V%D82!P96QO('-E<G9I9&]R(&1E(&-H879E
M<R!P^F)L:6-A<RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HW.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D
M('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS
M9W-T<B`B0V]N97CC;R!R96-U<V%D82!P96QO('-E<G9I9&]R(&1E(&-H879E
M<R!P^F)L:6-A<RX@36]T:79O.B`E<R`H)7,I(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HX-S8*;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10('-E
M<G9E<B!F86EL960N(@IM<V=S='(@(D$@8V]N97CC;R!A;R!S97)V:61O<B!&
M5%`@9F%L:&]U+B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#$T"FUS
M9VED(")#;VYT86-T<R(*;7-G<W1R(")#;VYT871O<R(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C
M=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O
M;VLN(@IM<V=S='(@(B(*(D]S(&-O;G1A=&]S(&9O<F%M(&%D:6-I;VYA9&]S
M(&-O;2!S=6-E<W-O(&%O('-E=2!C873A;&]G;R!D92!E;F1E<F7G;W,N(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HV,`IM<V=I
M9"`B0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@(@IM<V=S='(@
M(E1I<&4@9&4@8V]N=&7Z9&\@9&\@87)Q=6EV;R!C;VUP<FEM:61O.B`B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4V(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;VYT96YT<R!O9B!<(B5S7"(B"FUS9W-T<B`B0V]N=&7Z9&\@9&4@
M)R5S)R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,PIM<V=I9"`B0V]N=&EN=64B"FUS
M9W-T<B`B0V]N=&EN=6%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HU."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]O:R!)<VQA
M;F1S(@IM<V=S='(@(DEL:&%S($-O;VLB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R(")#;V]K:64B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B0V]P:6%R(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HT-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P
M>2!F86EL960Z("5S(@IM<V=S='(@(D9A;&AA(&YA(&/S<&EA.B`E<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G
M:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S='(@(D-O<&EA<B!S96QEY^-O(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-S`*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@
M(D-O<W0@240B"FUS9W-T<B`B240@9&4@0W5S=&\B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS
M9VED(")#;W-T82!2:6-A(@IM<V=S='(@(D-O<W1A(%)I8V$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8V"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(D-O<W1A(&1O($UA
M<F9I;2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDW-PIM
M<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z("(*;7-G<W1R
M("));7!O<W/M=F5L(&-R:7!T;V=R869A<B!A(&UE;G-A9V5M(&-O;2!01U`Z
M("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P-34*;7-G
M:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E.B`B"FUS9W-T<B`B26UP
M;W-S[79E;"!A<W-I;F%R(&$@;65N<V%G96T@8V]M(%!'4#H@(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD
M(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R(").XV\@9F]I
M('!O<W/M=F5L(&-R:7!T;V=R869A<B!A(&UE;G-A9V5M(&-O;2!3+TU)344N
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT-C<*;7-G
M:60@(D-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+B(*;7-G<W1R(").
MXV\@9F]I('!O<W/M=F5L(&%S<VEN87(@82!M96YS86=E;2!C;VT@4R]-24U%
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N
M=&%C="X@)7,B"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!A9&EC:6]N87(@
M8V]N=&%T;RX@)7,B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z.38@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ,C$*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C0U-PIM<V=I9"`B0V]U;&0@;F]T(&)I;F0@
M=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@8V]N
M96-T87(@86\@<V5R=FED;W(@3$1!4"XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$U-@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@
M(D[C;R!F;VD@<&]S<^UV96P@=F5R:69I8V%R(&\@<V%L9&\N("5S(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0T,0IM<V=I9"`B0V]U;&0@;F]T(&-O
M;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(DEM<&]S<^UV96P@8V]N
M96-T87(@86\@<V5R=FED;W(@3$1!4"XB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE
M8W0@=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(D[C
M;R!F;VD@<&]S<^UV96P@8V]N96-T87(@86\@<V5R=FED;W(@)R5S)R!U=&EL
M:7IA;F1O($944#H@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C,R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(").
MXV\@9F]I('!O<W/M=F5L(&-R:6%R(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O
M+B`E<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q,C@*
M;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B`B"FUS9W-T<B`B
M26UP;W-S[79E;"!D97-C<FEP=&]G<F%F87(@;W,@9&%D;W,@4$=0.B`B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R,PIM<V=I9"`B
M0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(D[C;R!F
M;VD@<&]S<^UV96P@9&5S8W)I<'1O9W)A9F%R(&\@9&%D;R!3+TU)344N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR
M-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT
M86-T+B`E<R(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&5X8VQU:7(@;R!C
M;VYT871O+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(D[C;R!F
M;VD@<&]S<^UV96P@97AC;'5I<B!A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@
M)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R
M:7!T(%PB)7-<(BXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!E>&-L=6ER
M(&\@<V-R:7!T(&1E(&%T=6%L:7IAY^-O(&1E(&-O;F9I9W5R8>?C;R`G)7,G
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU,PIM<V=I9"`B0V]U;&0@
M;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N
M(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@9&5T97)M:6YA<B!O(&5N9&5R
M9>=O(&1E(&4M;6%I;"!D;R!D97-T:6YA=.%R:6\N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*;7-G:60@(D-O
M=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S='(@
M(D[C;R!F;VD@<&]S<^UV96P@;V)T97(@8V]M<&QE=&%M96YT92!O(&-A=.%L
M;V=O(&1E(&5N9&5R9>=O<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C0Y,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H
M(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(").XV\@9F]I
M('!O<W/M=F5L(&]B=&5R(&-O;7!L971A;65N=&4@82!L:7-T82!D92!D:7-T
M<FEB=6GGXV\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M
M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(B(*
M(D[C;R!F;VD@<&]S<^UV96P@;V)T97(@8V]M<&QE=&%M96YT92!A(&QI<W1A
M(&1E(&QI<W1A<R!D92!D:7-T<FEB=6GGXV\N(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z
M-C@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@(D[C;R!F;VD@
M<&]S<^UV96P@8V%R<F5G87(@82!E<W1R873I9VEA("<E<R<N(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.C$Q,`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS
M9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!C<FEA<B!O(&1I<F5T\W)I;R`G)7,G
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Q.0IM<V=I
M9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E
M<G9E<BXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!A(&-H879E
M('#Z8FQI8V$@82!P87)T:7(@9&\@<V5R=FED;W(@9&4@8VAA=F5S+B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R(").XV\@
M9F]I('!O<W/M=F5L(&%B<FER("<E<R<@<&%R82!G<F%V8>?C;RXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W-PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S
M='(@(D[C;R!F;VD@<&]S<^UV96P@86)R:7(@)7,N(@H*(SH@9G)A;65W;W)K
M+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HT,C`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U
M;&4@)7,B"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!A8G)I<B!O(&WS9'5L
M;R`G36%I;G1E;F%N8V5?5&%S:R<@)7,B"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T
M;W)Y(%PB)7-<(BXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!A8G)I<B!O
M(&1I<F5T\W)I;R`G)7,G+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HQ,3$@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$T
M-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C,W(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C4Q-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-C$R"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HV-38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Y.0IM<V=I
M9"`B0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B
M3N-O(&9O:2!P;W-S[79E;"!P97-Q=6ES87(@;F\@<V5R=FED;W(@3$1!4"XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(T,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T<B`B3N-O
M(&9O:2!P;W-S[79E;"!L97(@)7,N(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S
M<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@
M=&AE("(*(F1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@
M8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R
M=&AE<B!H96QP+B(*;7-G<W1R("(B"B).XV\@9F]I('!O<W/M=F5L(&=E<F%R
M('5M82!N;W9A('-E;FAA('!A<F$@;R!U<W7A<FEO('-O;&EC:71A9&\N($%L
M9W5N<R!O=2`B"B)T;V1O<R!O<R!D971A;&AE<R!NXV\@97-TXV\@8V]R<F5T
M;W,N(%1E;G1E(&YO=F%M96YT92!O=2!E;G1R92!E;2!C;VYT871O("(*(F-O
M;2!O(&%D;6EN:7-T<F%D;W(@<V4@=F]CZB!N96-E<W-I=&$@9&4@;6%I<R!A
M:G5D82XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS,#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S0P"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W
M-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#,*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y"FUS
M9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(D[C;R!F;VD@
M<&]S<^UV96P@;V)T97(@82!!0TPB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R
M(").XV\@9F]I('!O<W/M=F5L(&]B=&5R(&\@8V%TX6QO9V\@9&4@96YD97)E
MYV]S+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R
M971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3N-O(&9O
M:2!P;W-S[79E;"!O8G1E<B!A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@)7,B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@
M9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R(").XV\@9F]I('!O<W/M
M=F5L(&]B=&5R(&%S(&QI<W1A<R!D92!D:7-T<FEB=6GGXV\N("5S(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*;7-G:60@(D-O
M=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T
M<B`B3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!A<R!C87!A8VED861E<R!D;R!S
M97)V:61O<B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@
M(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B3N-O
M(&9O:2!P;W-S[79E;"!R979E<G1E<B!A(&-O;F9I9W5R8>?C;RXB"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDO8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!R
M96UO=F5R(&\@9&ER973S<FEO("<E<R<N(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A
M=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E
M;"!S86QV87(@82!C;VYF:6=U<F'GXV\@)7,N(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y"FUS9VED
M(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S
M='(@(D[C;R!F;VD@<&]S<^UV96P@<V%L=F%R('5M(&)A8VMU<"!D82!C;VYF
M:6=U<F'GXV\N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I
M9W5A=&EO;CH@)7,B"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!S86QV87(@
M=6T@8F%C:W5P(&1A(&-O;F9I9W5R8>?C;SH@)7,B"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HY-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G
M<W1R("(B"B).XV\@9F]I('!O<W/M=F5L('-A;'9A<B!O('-C<FEP="!D92!A
M='5A;&EZ8>?C;R!D92!C;VYF:6=U<F'GXV\@96TZ("<E<R<N(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E
M<RXB"FUS9W-T<B`B3N-O(&-O;G-E9W5I('-A;'9A<B!O(&)A8VMU<"!D;R!A
M<G%U:79O(&1E(&-O;F9I9W5R8>?C;R`E<RXB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C<W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO
M="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET
M:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D
M92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@
M=&\@)7,N(@IM<V=S='(@(B(*(D[C;R!C;VYS96=U:2!S86QV87(@;R!A<G%U
M:79O(&1E(&-O;F9I9W5R8>?C;R`E<RX@5F]CZB!P;V1E(&]U('5T:6QI>F%R
M('5M82`B"B)D87,@;W#G]65S('!A<F$@<V%L=F%R(&\@8_-D:6=O(&1E('9O
M;'1A(&5M("5S(&]U(&-O<&EA<B!M86YU86QM96YT92!O("(*(F/S9&EG;R!A
M8F%I>&\@<&%R82`E<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C$T,PIM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V
M97(N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@<&5S<75I<V%R(&YO('-E
M<G9I9&]R($Q$05`N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R
M(").XV\@9F]I('!O<W/M=F5L(')E;6]V97(@;R!L:6YK("<E<R<N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT86-T
M+B`E<R(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&%T=6%L:7IA<B!O(&-O
M;G1A=&\N("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3N-O(&9O
M:2!P;W-S[79E;"!A='5A;&EZ87(@82!L:7-T82!D92!D:7-T<FEB=6GGXV\N
M("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B!<
M(B5S7"(Z("5S(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@9W)A=F%R(&$@
M8V]N9FEG=7)AY^-O(&1E("<E<R<Z("5S(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,W,`IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3
M:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB"FUS9W-T
M<B`B(@HB3N-O(&9O:2!P;W-S[79E;"!E;F-O;G1R87(@82!"87)R82!,871E
M<F%L(&1O($UO>FEL;&$N($-E<G1I9FEQ=64M<V4@<75E(&5L82`B"B)E<W3A
M(&%B97)T82XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HQ-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV
M92!U<V5R(%PB)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O
M;&1E<B!<(B5S7"(Z("5S(@IM<V=S='(@(B(*(D[C;R!F;VD@<&]S<^UV96P@
M9&%R(&%O('5S=>%R:6\@)7,@;W,@<V5G=6EN=&5S(&1I<F5I=&]S('!A<F$@
M82!P87-T82`G)7,G.B`E(@HB<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T,C,*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R(")497AT;R!C
M;VYT861O(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-S`*;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`B4&'M<R(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR-S4*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B
M0W5R<V]S(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B0W)I
M87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T92!A(&QI;FLB"FUS9W-T<B`B0W)I
M87(@=6T@;&EN:R(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C
M="YI;F,Z.30*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`B0W)I
M87(@=6UA(&YO=F$B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY,@IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@
M(D-R:6%R('-U8B!P87-T87,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C(T,`IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*;7-G<W1R
M(")097)M:7-S]65S(&1O(&-R:6%D;W(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,C$Y"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T
M<B`B3OIM97)O(&1O(&-A<G3C;R!D92!C<NED:71O(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*
M;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B0W)OX6-I82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*
M;7-G:60@(D-U8F$B"FUS9W-T<B`B0W5B82(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HR-@IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R("(T($9A
M<V5S($%T=6%I<R(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`IM<V=I9"`B
M0W5R<F5N="!397-S:6]N<R(*;7-G<W1R(")397-S]65S($%T=6%I<R(*"B,Z
M(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`IM
M<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(DAO<F$@071U86PB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-30*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@(D$@55),(&%T=6%L
M(.DB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S4*;7-G:60@(D-U<G)E;G0@
M57-E<G,B"FUS9W-T<B`B57-UX7)I;W,@;F\@;6]M96YT;R(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G
M<W1R(")#;&EM82!!='5A;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-C0*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`B
M0V]N9&GGXV\@871U86PZ("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T
M<B`B17-T:6QO(&%T=6%L(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N
M('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(D-U<W1O;6EZ82!T87)E9F%S
M(&$@<V5R96T@97AE8W5T861A<R!A;R!C;VYE8W1A<B!A("5S+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M,`IM<V=I9"`B0W5T(@IM<V=S='(@(D-O<G1A<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE
M8W1I;VXB"FUS9W-T<B`B0V]R=&%R('-E;&7GXV\B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS
M9VED(")#>7!R=7,B"FUS9W-T<B`B0VAI<')E(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#$*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@
M(D-I<NUL:6-O("A+3TDX+5(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#(*;7-G:60@(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(D-I
M<NUL:6-O("A7:6YD;W=S+3$R-3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#,*;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G
M<W1R(")#:7+M;&EC;R]58W)A;FEA;F\@*$M/23@M52DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y
M"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R(")297#Z8FQI8V$@5&-H
M96-A(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0U,"!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B1$0B"FUS9W-T
M<B`B1$0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<Y"FUS9VED
M("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P
M86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@IM<V=S='(@(B(*
M(D133B`H=F5J82!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K
M86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@H*(SH@9G)A;65W;W)K
M+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B1&%I;'DB
M"FUS9W-T<B`B1&EA<FEA;65N=&4B"@HC.B!A9&UI;B]D871A=')E92YP:'`Z
M-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B3F%V96=A9&]R
M(&1E($1A=&%4<F5E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W
M-PIM<V=I9"`B1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@(E!E<W%U:7-A(&YO
M($)A;F-O(&1E($1A9&]S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#`R
M"FUS9VED(")$871E(@IM<V=S='(@(D1A=&$B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E:79E9"(*
M;7-G<W1R(")$871A(&1E(%)E8V5B:6UE;G1O(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C<Y-@IM<V=I9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T
M<B`B4V5L9>?C;R!D92!D871A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(X,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Q"FUS
M9VED(")$87DB"FUS9W-T<B`B1&EA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,V"FUS9VED(")$95]L971E
M($-O;'5M;B(*;7-G<W1R(")%7WAC;'5I<B!#;VQU;F$B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#D*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@IM<V=I9"`B1&5C96UB
M97(B"FUS9W-T<B`B1&5Z96UB<F\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V"FUS9VED(")$96-I;6%L
M(&YU;6)E<G,B"FUS9W-T<B`B3OIM97)O<R!D96-I;6%I<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C`*;7-G:60@(D1E
M8W)E87-E($EN9&5N="(*;7-G<W1R(")296-U87(@261E;G1AY^-O(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ.#<@;&EB+W!R969S+G!H
M<#HQ,3<*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B4&%D<N-O(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#4*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-S<*;7-G:60@
M(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B0V]R(%!A9'+C;R(*"B,Z(&9R86UE
M=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z.38*;7-G:60@(D1E9F%U;'0@
M261E;G1I='DB"FUS9W-T<B`B261E;G1I9&%D92!0861RXV\B"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-C<*;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS
M9W-T<B`B4VAE;&P@4&%D<N-O(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,S"FUS9VED(")$969I;FET:6]N<R(*;7-G<W1R(")$969I;FGG]65S(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HW,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C,R-@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0S.0HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C,V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M-S`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,R!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$Q-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$S.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.CDX"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E
M+FEN8SHQ,"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I
M9"`B1&5L971E(@IM<V=S='(@(D5X8VQU:7(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S(*;7-G:60@(D1E
M;&5T92!#96QL(@IM<V=S='(@(D5X8VQU:7(@8^EL=6QA(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR,C<*;7-G:60@(D1E
M;&5T92!'<F]U<"(*;7-G<W1R(")%>&-L=6ER($=R=7!O(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0Y"FUS9VED(")$96QE=&4@3&]G(@IM
M<V=S='(@(D5X8VQU:7(@3&]G(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HW-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,0IM
M<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B17AC;'5I<B!097)M
M:7-SXV\B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HY,PIM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R
M(")%>&-L=6ER(&4@<'5R9V%R(&UE;G-A9V5N<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3<*;7-G:60@(D1E
M;&5T92!C96QL(@IM<V=S='(@(D5X8VQU:7(@8^EL=6QA(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I
M9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R(")%>&-L=6ER(&-O;'5N82(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS9VED(")$96QE=&4@97AI<W1I
M;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(D5X8VQU:7(@;6]D96QO
M('-U8G-T:71U=&\@97AI<W1E;G1E(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E
M<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B17AC;'5I<B!P97)M:7-S
M]65S('!A<F$@)R5S)R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z-#(T"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N
M<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R
M(")%>&-L=6ER('!E<FUI<W/U97,@<&%R82`G)7,G(&4@<75A;'%U97(@;W5T
M<F$@<W5B+7!E<FUI<W/C;S\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@<F]W(@IM
M<V=S='(@(D5X8VQU:7(@;&EN:&$B"@HC.B!T96UP;&%T97,O<')E9G,O9&5L
M971E:61E;G1I='DN:6YC.C$U"FUS9VED(")$96QE=&4@<V5L96-T960@:61E
M;G1I='DB"FUS9W-T<B`B17AC;'5I<B!I9&5N=&ED861E('-E;&5C:6]N861A
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8W"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM
M<V=S='(@(D5X8VQU:7(@82!C;VQU;F$@871U86PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@
M(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B17AC;'5I<B!A(&QI
M;FAA(&%T=6%L(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP
M="!<(B5S7"(N(@IM<V=S='(@(E-C<FEP="!D92!A='5A;&EZ8>?C;R!D92!C
M;VYF:6=U<F'GXV\@)R5S)R!E>&-L=>UD;RXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V,PHC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C$*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"FUS
M9VED(")$96QI=F5R>2!T:6UE(@IM<V=S='(@(DAO<F$@9&4@96YT<F5G82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-CD*;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`B1&EN86UA<F-A
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@
M(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(D1E<V-R979A(&\@<')O
M8FQE;6$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-#(@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`IM<V=I
M9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B1&5S8W)IY^-O(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3<*;7-G:60@(D1E=&%I;',@*&%L<V\@
M:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B1&5T86QH97,@*'1A;6+I
M;2!N;R!R96=I<W1R;R!D92!A=&EV:61A9&5S(&1O($AO<F1E*3HB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C(P,0IM<V=I9"`B1&5T86EL<R!H
M879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T
M<B`B3W,@9&5T86QH97,@9F]R86T@9W)A=F%D;W,@96T@;&]G('!A<F$@;R!A
M9&UI;FES=')A9&]R+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M,C$*;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S='(@(D1E<V5N=F]L=FEM96YT
M;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(T"FUS9VED(")$97<@4&]I
M;G0B"FUS9W-T<B`B4&]N=&\@9&4@3W)V86QH;R(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S`Q"FUS9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@
M(@IM<V=S='(@(E!O;G1O(&1E($]R=F%L:&\@<&%R82!A(/IL=&EM82!H;W)A
M.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$V"FUS9VED
M(")$97<@<&]I;G0Z("(*;7-G<W1R(")0;VYT;R!D92!/<G9A;&AO.B`B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS
M9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R(")$:7)EY^-O
M(&1A(&5S<75E<F1A('!A<F$@9&ER96ET82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R
M:6=H="!T;R!L969T(@IM<V=S='(@(D1I<F7GXV\@9&$@9&ER96ET82!P87)A
M(&5S<75E<F1A(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@
M(D1I<F5C=&]R>2(*;7-G<W1R(")$:7)E=/-R:6\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C<P"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_
M(@IM<V=S='(@(D5X:6)I<B!E;2!F;W)M871O(#(T(&AO<F%S/R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#`*;7-G:60@(D1I<W!L87D@3W!T:6]N
M<R(*;7-G<W1R(")/<.?U97,@9&4@17AI8FGGXV\B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z.#D*;7-G:60@(D1I<W!L87D@9&5T86EL960@
M9F]R96-A<W0B"FUS9W-T<B`B17AI8FER('!R979I<^-O(&1E=&%L:&%D82(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.3(*;7-G:60@(D1I<W!L87D@9F]R
M96-A<W0@*%1!1BDB"FUS9W-T<B`B17AI8FER('!R979I<^-O("A4048I(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P-@IM<V=I9"`B1&ES<&QA
M>2!F;W)M870B"FUS9W-T<B`B17AI8FER(&9O<FUA=&\B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TU$3BYP:'`Z,3DQ"FUS9VED(")$:7-P;W-I=&EO;B!.
M;W1I9FEC871I;VXB"FUS9W-T<B`B3F]T:69I8V'GXV\@9&4@1&ES<&]S:>?C
M;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(D1J:6)U
M=&DB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,@IM<V=I
M9"`B1&\@;F]T(&1E;&5T92(*;7-G<W1R(").XV\@97AC;'5I<B(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C
M=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'`B"FUS9W-T<B`B3N-O(&%C97-S
M92!D:7)E=&%M96YT92!M86EN=&5N86YC92YP:'`B"@HC.B!T96UP;&%T97,O
M9&%T82]T<W9I;F9O+FEN8SHQ,B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHQ,@IM<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I
M96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R("(B
M"B)!('!R:6UE:7)A(&QI;FAA(&-O;G3I;2!O<R!N;VUE<R!D;W,@8V%M<&]S
M/R!392!S:6TL(&-L:7%U92!N97-T82!C86EX83HB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS
M9VED(")$;VUI;FEC82(*;7-G<W1R(")$;VUI;FEC86YA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(E)E</IB;&EC
M82!$;VUI;FEC86YA(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY
M-@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+B(*;7-G
M<W1R(").XV\@=&5M('5M82!C;VYT83\@0V%D87-T<F4M<V4N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#4Q"FUS9VED(")$;W=N
M;&]A9"(*;7-G<W1R(")"86EX87(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HX-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO
M860@)7,B"FUS9W-T<B`B0F%I>&%R("5S(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`B0F%I>&%R(&$@8V]N9FEG
M=7)AY^-O(&=E<F%D82!C;VUO('5M('-C<FEP="!02%`N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q,0IM<V=I9"`B1')O<"!D;W=N(&QI<W0B
M"FUS9W-T<B`B3&ES=&$@9&4@<V5L9>?C;R(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS-`IM<V=I9"`B1')U9W,B"FUS9W-T<B`B1')O9V%S(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")%+4UA
M:6PB"FUS9W-T<B`B0V]R<F5I;R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]G96YE<FEC7W-M='`N<&AP.CDR"FUS9VED(")%36%I;"UT;RU335,@9V%T
M97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@
M<V5R=FEC92XB"FUS9W-T<B`B(@HB0V]N96-T;W(@9&\@9V%T97=A>2!%36%I
M;"UP87)A+5--4RP@<&%R82!O<&5R861O<F%S('%U92!D:7-P;VYI8FEL:7IA
M;2!E<W1E("(*(G-E<G9IYV\N(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B
M15)2(@IM<V=S='(@(D524B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B
M"FUS9W-T<B`B17%U861O<B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,S(U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@IM
M<V=I9"`B161I="(*;7-G<W1R(")%9&ET87(B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO54DN<&AP.C4P"FUS9VED(")%9&ET($)L;V-K(@IM<V=S='(@
M(D5D:71A<B!";&]C;R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DX(&%D;6EN
M+V=R;W5P<RYP:'`Z,C(V"FUS9VED(")%9&ET($=R;W5P(@IM<V=S='(@(D5D
M:71A<B!'<G5P;R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M-S8@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#`*;7-G:60@(D5D
M:70@4&5R;6ES<VEO;B(*;7-G<W1R(")%9&ET87(@4&5R;6ES<^-O(@H*(SH@
M<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B161I="!097)M
M:7-S:6]N<R(*;7-G<W1R(")%9&ET87(@4&5R;6ES<_5E<R(*"B,Z('-E<G9I
M8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B161I=&%R(%!E<FUI
M<W/U97,@<&%R82`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*
M;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@(D5D:71A<B!O<.?U
M97,@9&4Z(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-C<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@7"(E
M<UPB(@IM<V=S='(@(D5D:71A<B!P97)M:7-S]65S('!A<F$@)7,B"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G
M:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(D5D:71A<B!P
M97)M:7-S]65S('!A<F$@)7,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S4*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R(")%9'5C8>?C;R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S`*;7-G:60@(D5G>7!T(@IM<V=S='(@(D5G:71O(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HW-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`W"FUS9VED(")%;"!386QV861O<B(*;7-G<W1R(")%;"!386QV861O<B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHT,PIM<V=I9"`B16QE;65N="XN+B(*;7-G<W1R(")%;&5M96YT;RXN
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`Y"FUS9VED(")%;2(*;7-G<W1R(")%;2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@W,PIM<V=I9"`B16UA:6PB"FUS9W-T<B`B12UM86EL(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C8@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C8X"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S
M='(@(D5N9&5R9>=O(&1E($4M36%I;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y-C<*;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H
M+B(*;7-G<W1R(")/(&5N9&5R9>=O(&1E(&4M;6%I;"!D979E(&-O<G)E<W!O
M;F1E<BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3DS"FUS9VED
M(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")-96YS86=E;2!C
M;VT@8V]N9FER;6'GXV\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N
M97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W87DB
M"FUS9W-T<B`B1V%T97=A>2!D92!%36%I;"UP87)A+5--4R(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR.3<*;7-G:60@(D5M
M;W1I8V]N<R(*;7-G<W1R(")%;6]T:6-O;G,B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*;7-G:60@(D5M<'1Y
M(&UE<W-A9V4N(@IM<V=S='(@(DUE;G-A9V5M(&5M(&)R86YC;RXB"@HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C0S(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HT.#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C8V,B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-S`U"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,34P"FUS
M9VED(")%;7!T>2!R97-U;'0N(@IM<V=S='(@(E)E<W5L=&%D;R!E;2!B<F%N
M8V\N(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$Q,PIM
M<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@(E1E<FUO<R!D92!P
M97-Q=6ES82!E;2!B<F%N8V\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-30W"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H
M;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R(")(86)I;&ET87(@:6YS
M97+GXV\@9&4@:6UA9V5N<R!A('!A<G1I<B!D82!'86QE<FEA(&1E($EM86=E
M;G,@;F\@=&5X=&\_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R,@IM
M<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T
M<B`B2&%B:6QI=&%R(&UE;G4@9&4@8V]N=&5X=&\@8V]M(&\@8F]TXV\@9&ER
M96ET;S\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DR(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#`*;7-G:60@(D5N9"!Y96%R(@IM<V=S
M='(@(D9I;F%L(&1O(&%N;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S
M='(@(D%U;65N=&%R($5D:71O<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,C0*;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI
M8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U
M<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R
M('!E=#\G.B(*;7-G<W1R("(B"B)&;W)N9>=A('5M82!P97)G=6YT82!D92!S
M96=U<F%NYV$@82!Q=6%L('9O8^H@<V5RX2!P97)G=6YT861O('-E('9O8^H@
M(@HB;F5C97-S:71A<B!G97)A<B!U;6$@;F]V82!S96YH82P@97@N("=Q=6%L
M(&\@;F]M92!D;R!S974@8V%C:&]R<F\_)SHB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@
M(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(*;7-G<W1R(")&;W)N9>=A(&$@
M55),(&1A(&EM86=E;2!A<75I(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C@Y,`IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@
M8F5L;W<Z(@IM<V=S='(@(D1I9VET92!A<R!L971R87,@86)A:7AO.B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(D=U
M:6[I($5Q=6%T;W)I86PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%<FET<F5A(@IM
M<V=S='(@(D5R:71RZ6EA(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].
M;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+U9I97<N<&AP.CDT(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HT.`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,V
M"FUS9VED(")%<G)O<B(*;7-G<W1R(")%<G)O(@H*(SH@9G)A;65W;W)K+U1E
M;7!L871E+U1E;7!L871E+G!H<#HT-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M17)R;W(@8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S='(@(D5R<F\@86\@8W)I
M87(@8FQO8V\Z("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!A
M;F-H;W(Z("5S(@IM<V=S='(@(D5R<F\@86\@97AC;'5I<B#B;F-O<F$@9&4@
M<VEN8W)O;FEZ8>?C;SH@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S
M>6YC(&QO9SH@)7,B"FUS9W-T<B`B17)R;R!A;R!E>&-L=6ER(&QO9R!D92!S
M:6YC<F]N:7IAY^-O.B`E<R(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP
M;&%T92YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&=E='1I
M;F<@8V]N=&5N=#H@)7,B"FUS9W-T<B`B17)R;R!A;R!O8G1E<B!C;VYT9?ID
M;SH@)7,B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S
M(@IM<V=S='(@(D5R<F\@86\@871U86QI>F%R(&$@<V5N:&$Z("5S(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U
M"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM<V=S='(@(D5R
M<F\@;F$@;65N<V%G96TN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T
M<B`B17)R;R!G<F%V86YD;R`G)7,G+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S
M=&]N:6$B"FUS9W-T<B`B17-T]&YI82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T
M:&EO<&EA(@IM<V=S='(@(D5T:?-P:6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R("+)=&YI8V\B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*
M;7-G<W1R(")%=7)O<&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0S
M"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(D-A9&$@,34@;6EN
M=71O<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3,*;7-G:60@(D5V
M97)Y(#(@;6EN=71E<R(*;7-G<W1R(")#861A(#(@;6EN=71O<R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,Y,0IM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R(")#861A(#,P
M('-E9W5N9&]S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,SDT"FUS9VED(")%=F5R>2`U(&UI;G5T97,B
M"FUS9W-T<B`B0V%D82`U(&UI;G5T;W,B"@HC.B!F<F%M97=O<FLO36%I;G1E
M;F%N8V4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*
M;7-G<W1R(")#861A($-O;F5XXV\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S0T"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`B0V%D82!M
M96EA(&AO<F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.3(*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G
M<W1R(")#861A(&UI;G5T;R(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N
M:6YC.C(T"FUS9VED(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`B5F%L;W)E
M<R!D92!E>&5M<&QO.B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HX,2!A9&UI
M;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP.C$R-PIM<V=I
M9"`B17AE8W5T92(*;7-G<W1R(")%>&5C=71A<B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C$T"FUS9VED(")%>'!A
M;F0B"FUS9W-T<B`B17AP86YD:7(B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I
M9&5B87(N:6YC.C,R"FUS9VED(")%>'!A;F0@4VED96)A<B(*;7-G<W1R(")%
M>'!A;F1I<B!"87)R82!,871E<F%L(@H*(SH@9G)A;65W;W)K+U-13"]344PO
M2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@
M(D5S<&5R861O("<I)R(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S
M+G!H<#HQ-S4*;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@
M<V5A<F-H('1E<FTB"FUS9W-T<B`B17-P97)A9&\@=6UA('!A;&%V<F$@;W4@
M=&5R;6\@9&4@<&5S<75I<V$@96YT<F4@87-P87,B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER871I;VX@1&%T
M92(*;7-G<W1R(")$871A(&1E($5X<&ER8>?C;R(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C<W"FUS9VED(")%>'!O;F5N="(*;7-G
M<W1R(")%>'!O96YT92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@
M(D-O<B!D;R!P<FEM96ER;R!P;&%N;R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-S<*;7-G:60@(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B
M0V]N9FEG=7)AY^-O(&1E(&5N=FEO(&1E(&%R<75I=F]S($944"(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]S<6PN<&AP.C(R-0IM<V=I9"`B1F%I;&5D
M(')E=')I979I;F<@<')E9F5R96YC97,N(@IM<V=S='(@(D9A;&AA(&]B=&5N
M9&\@<')E9F5RZFYC:6%S+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HW-2!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.CDX"FUS
M9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T
M<B`B1F%L:&$@86\@8V]N96-T87(@86\@<V5R=FED;W(@3$1!4"XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.3@*;7-G:60@(D9A:6QE9"!T
M;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM<V=S='(@(D9A;&AA(&%O(&-O
M;F5C=&%R(&%O('-E<G9I9&]R(%--0BXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C<Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@
M8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B1F%L:&$@86\@8V]P:6%R(&1E
M(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!T;R!<(B5S7"(N
M(@IM<V=S='(@(D9A;&AA(&%O(&-O<&EA<B!P87)A(%PB)7-<(BXB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@W"FUS9VED(")&86EL960@
M=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(D9A;&AA
M(&%O(&-R:6%R('5M82!N;W9A(&-O;F5XXV\@4T%33"XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C4P,2!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C<U-0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@;6]V92!T
M;R!<(B5S7"(N(@IM<V=S='(@(D9A;&AA(&%O(&UO=F5R('!A<F$@7"(E<UPB
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8U"B,L('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`B
M1F%L:&$@86\@;V)T97(Z("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T<B`B2G5S=&\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<R"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA
M<RDB"FUS9W-T<B`B26QH87,@1F%L:VQA;F0@*$UA;'9I;F%S*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S,*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B26QH87,@1F%R
M;V4B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C,X"FUS9VED(")&871A
M;"!%<G)O<CHB"FUS9W-T<B`B17)R;R!&871A;#HB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W"FUS9VED(")&87@B"FUS
M9W-T<B`B1F%X(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U,0IM
M<V=I9"`B1F%X97,B"FUS9W-T<B`B1F%X97,B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Q"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,SD*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM<V=I9"`B1F5B<G5A<GDB"FUS
M9W-T<B`B1F5V97)E:7)O(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C<*
M;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B4V5N<V'GXV\@5.ER;6EC82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C`*;7-G:60@(D9E
M96QS(&QI:V4Z("(*;7-G<W1R(")396YS8>?C;R!TZ7)M:6-A.B`B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B
M1F5W(%-H;W=E<G,B"FUS9W-T<B`B4&%N8V%D87,@9&4@0VAU=F$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B
M1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R(").979E($9R86-A(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT.`IM<V=I9"`B1FEE;&0@;6%T<FEX
M(@IM<V=S='(@(DUA=')I>B!D;R!C86UP;R(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,S,S(*;7-G:60@(D9I9VQE="!#05!40TA!(@IM<V=S='(@
M(D9I9VQE="!#05!40TA!(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S,S-@IM<V=I9"`B1FEG;&5T(&9O;G0B"FUS9W-T<B`B1F]N=&4@1FEG;&5T
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEJ:2(*;7-G<W1R(")&:6II(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")&:6QE(@IM
M<V=S='(@(F%R<75I=F\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM
M<V=S='(@(D-O;G1A9V5M(&1E($%R<75I=F]S.B`E<R!A<G%U:79O(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`B0V]N=&%G96T@9&4@
M07)Q=6EV;W,Z("5S(&%R<75I=F]S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0P.0IM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S='(@(D=E<F5N
M8VEA9&]R(&1E($%R<75I=F]S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HV,R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<P"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#(*;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R(").;VUE(&1O($%R<75I
M=F\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3@T"FUS9VED(")&
M:6QE('-E;&5C=&EO;B(*;7-G<W1R(")396QEY^-O(&1E(&%R<75I=F\B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#DP"FUS9VED(")&:6QE('5P
M;&]A9"(*;7-G<W1R(")%;G9I;R!D92!A<G%U:79O(@H*(SH@9G)A;65W;W)K
M+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@U"FUS9VED(")&:6QE('5P;&]A9',@
M;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B16YV:6\@9&4@87)Q=6EV;W,@;N-O
M(.D@<W5P;W)T861O+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY
M,0IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R(")&:6QT<F]S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,0IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R(")&:6YLXFYD:6$B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@
M(E!R:6UE:7)A($UE=&%D92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW-"!L
M:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U87)T97(B"FUS
M9W-T<B`B4')I;65I<F\@475A<G1O(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(U-0IM<V=I9"`B1FEX(')A=&EO(@IM<V=S
M='(@(E1A>&$@9FEX82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,S`*;7-G:60@(D9L:7`B"FUS9W-T<B`B1VER87(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,R"FUS9VED(")&;&]A="(*;7-G<W1R(")$:7-P;W-IY^-O(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@(D9O
M9R(*;7-G<W1R(").Z79O82(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z,C,W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,#<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T(@IM<V=S
M='(@(E!A<W1A("5S(&[C;R!E>&ES=&4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(R"FUS9VED(")&;VYT($-O;&]R(@IM
M<V=S='(@(D-O<B!D82!&;VYT92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R(")#;VUI9&$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C8*
M;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S
M(@IM<V=S='(@(E!A<F$@;F%V96=A9&]R97,@<75E(&[C;R!S=7!O<G1A;2!I
M;6%G96YS(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#$*;7-G:60@(D9O
M<F5C87-T("A4048I(@IM<V=S='(@(E!R979I<^-O("A4048I(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<R"FUS9VED("(B"B)&;W)E8V%S
M="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R
M;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E
M(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*(D1I
M87,@4')E=FES=&]S("A.;W1E('%U92!A('!R979I<^-O(')E=&]R;F%D82!E
M>&EB92!A;6)O<R!D:6$@92!N;VET93L@=6T@(@HB;OIM97)O(&UU:71O(&%L
M=&\@87%U:2!P;V1E(')E<W5L=&%R(&5M('5M(&)L;V-O(&5X=&5N<V\I(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,#(*;7-G:60@(D9O<F=O
M="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R(")%<W%U96-E=2!A('-E;FAA/R(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-C0*;7-G:60@(D9O<FUS
M(@IM<V=S='(@(D9O<FUU;.%R:6]S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C(Q"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(E-O<G1E(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS
M9W-T<B`B5&EP;R!D92!3;W)T92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS.`IM<V=I9"`B1F]R='5N97,B"FUS9W-T<B`B4V]R=&5S(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,Y"FUS9VED(")&;W)T=6YE<R`R(@IM<V=S
M='(@(E-O<G1E<R`R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U
M-0IM<V=I9"`B1F]R=6US(@IM<V=S='(@(D;S<G5N<R(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ,3$*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@
M(E)E9&ER96-I;VYA;65N=&]S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`B4V5X(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS,PIM<V=I9"`B1G)A;65S(@IM<V=S='(@(E%U861R;W,B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<S"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B1G)A;N=A(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4L($UE=')O
M<&]L:71A;B(*;7-G<W1R(")&<F%NYV$@365T<F]P;VQI=&%N82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S0*;7-G:60@(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B1W5I86YA($9R
M86YC97-A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B
M"FUS9W-T<B`B4&]L:6[I<VEA($9R86YC97-A(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS
M9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B5&5R
M<FET\W)I;W,@1G)A;F-E<V5S(&1O(%-U;"(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB"FUS9W-T
M<B`B1&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,W(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-#D*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,Y-0IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@
M(D1O*&$I(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*
M;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`B1&5S8W)IY^-O($-O
M;7!L971A(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M
M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R("),=6$@0VAE
M:6$B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C$@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHV,`IM<V=I9"`B1G5L;"!.86UE(@IM<V=S
M='(@(DYO;64@0V]M<&QE=&\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")'86)O;B(*
M;7-G<W1R(")'86+C;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T
M86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B1V%L97)I82!D92!O;F1E(&]B=&5R
M(&%S(&EM86=E;G,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S
M='(@(D=A;&5R:6$Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1V%M8FEA(@IM<V=S
M='(@(D?B;6)I82(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*
M;7-G<W1R(")'97)A<B!A($-O;F9I9W5R8>?C;R!D92`E<R(*"B,Z('1E;7!L
M871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T
M960@0V]D92(*;7-G<W1R(")#\V1I9V\@1V5R861O(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM
M<V=I9"`B1V5O<F=I82(*;7-G<W1R(")'9?-R9VEA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.CDP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM
M<V=I9"`B1V5R;6%N>2(*;7-G<W1R(")!;&5M86YH82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*
M;7-G:60@(D=H86YA(@IM<V=S='(@(D=A;F$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED
M(")':6)R86QT87(B"FUS9W-T<B`B1VEB<F%L=&%R(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S8*;7-G:60@(D=I=F5N($YA;64B
M"FUS9W-T<B`B4')I;65I<F\@3F]M92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M:61E8F%R+G!H<#HQ-S4@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3`*(SH@
M=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3D*;7-G:60@(D=L;V)A;"!/<'1I
M;VYS(@IM<V=S='(@(D]PY_5E<R!';&]B86ES(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V%P<"YI;F,Z,3<*;7-G:60@(D=O(@IM<V=S='(@(DER(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D96PB"FUS9W-T<B`B
M1V]E9&5L(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$Q,CD*;7-G:60@(D=O;V=L92!-87!S(@IM<V=S='(@(D=O;V=L92!-
M87!A<R(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O
M;V=L92!396%R8V@B"FUS9W-T<B`B4&5S<75I<V%R(&YO($=O;V=L92(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S8*;7-G
M:60@(D=R87ES8V%L92(*;7-G<W1R(")%<V-A;&$@9&4@0VEN>F%S(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S8*;7-G:60@(D=R965C92(*;7-G<W1R(")'<NEC:6$B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B1W)E96L@*$E33RTX.#4Y
M+3<I(@IM<V=S='(@(D=R96=O("A)4T\M.#@U.2TW*2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*
M;7-G:60@(D=R965N;&%N9"(*;7-G<W1R(")'<F]E;.)N9&EA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-`IM<V=I9"`B1W)E;F%D82(*;7-G<W1R(")'<F%N861A(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HQ-SD*;7-G:60@(D=R;W5P($%D;6EN:7-T<F%T:6]N
M(@IM<V=S='(@(D%D;6EN:7-T<F'GXV\@9&4@1W)U<&]S(@H*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+G!H<#HU.2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE
M;7!T>2(*;7-G<W1R(").;VUE<R!D92!G<G5P;W,@;N-O(&1E=F5M(&5S=&%R
M(&5M(&)R86YC;R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HS,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE
M('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9#H@(@IM<V=S='(@(B(*(D=R;W5P7VQD87`Z($EM<&]S<^UV96P@861I8VEO
M;F%R(&=R=7!O("5S+B!)<W1O(.D@;R!Q=64@;R!S97)V:61O<B!D:7-S93H@
M(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q."!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<R(*;7-G<W1R
M(")'<F]U<%]L9&%P.B!);7!O<W/M=F5L(&5X8VQU:7(@9W)U<&\@)7,B"@HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S,X(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<R(*;7-G
M<W1R(")'<F]U<%]L9&%P.B!);7!O<W/M=F5L(&%T=6%L:7IA<B!G<G5P;R`E
M<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S$T(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS9W-T<B`B1W)U<&]S(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-@IM<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R(")'=6%D86QU<&4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-PIM<V=I9"`B1W5A;2(*;7-G<W1R(")'=6%M(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R(")'=6%T96QA;6$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'=65R;G-E
M>2(*;7-G<W1R(")'=65R;G-E>2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,C(V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*;7-G
M:60@(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(E!E<FUI<W/U97,@9&4@
M0V]N=FED861O(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W,@IM
M<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(DQI=G)O(&1E(%9I<VET87,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDW(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<U"FUS9VED(")'=6EN96$B"FUS9W-T<B`B1W5I;NDB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S@*;7-G:60@(D=U:6YE82U":7-S874B"FUS9W-T<B`B1W5I;NDM
M0FES<V%U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B
M1W5I86YA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.38T"FUS9VED
M(")(5$U,(@IM<V=S='(@(DA434PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(5$U,07)E82!C
M;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O
M=RXB"FUS9W-T<B`B2%1-3$%R96$@<V4@;F5G82!C;W9A<F1E;65N=&4@82!E
M>&-L=6ER(&$@^FQT:6UA(&/I;'5L82!D82!L:6YH82XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS9VED
M(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(DA434Q!<F5A('-E(&YE9V$@
M8V]V87)D96UE;G1E(&$@97AC;'5I<B!A(/IL=&EM82!C;VQU;F$@9&$@=&%B
M96QA+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@
M=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92XB"FUS9W-T<B`B2%1-
M3$%R96$@<V4@;F5G82!C;W9A<F1E;65N=&4@82!E>&-L=6ER(&$@^FQT:6UA
M(&QI;FAA(&1A('1A8F5L82XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT
M='`N<&AP.C$U-PIM<V=I9"`B2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(D%U=&5N=&EC8>?C;R!(5%10(&[C;R!E;F-O;G1R861A
M+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2&%I=&DB"FUS9W-T<B`B2&%I=&DB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@
M(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(D%L9V]R:71M;R!(87-H(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@
M(DAA>F4B"FUS9W-T<B`B3F5B;&EN82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.CDR,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(Q"FUS9VED
M(")(96%D97(B"FUS9W-T<B`B0V%B9>=A;&AO(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*
M;7-G<W1R(")#86)EYV%L:&\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D
M($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R("));&AA($AE
M87)D(&4@26QH87,@36-$;VYA;&0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR,PIM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G
M<W1R(")496UP97-T861E($9O<G1E(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#4*;7-G:60@(DAE8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R(")(
M96)R974@*$E33RTX.#4Y+3@M22DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T"FUS9VED(")(96EG:'0B"FUS
M9W-T<B`B06QT=7)A(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N
M<&AP.C$X-"!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3@V"B,Z
M('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W('1E;7!L871E<R]H96QP+VEN
M9&5X+FEN8SHT"FUS9VED(")(96QP(@IM<V=S='(@(D%J=61A(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B
M2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`B06IU9&$@9&\@961I=&]R(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W-0IM<V=I9"`B2&5L<&5R
M(@IM<V=S='(@(D%S<VES=&5N=&4B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`B2&5M:7-FZ7)I;R(*"B,Z
M('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A
M+V-S=FEN9F\N:6YC.C$P"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@
M;V8@=&AE(&9I;&4Z(@IM<V=S='(@(D%Q=6D@97-TX2!O(&EN[6-I;R!D;R!A
M<G%U:79O.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C<P"FUS9VED(")(:6=H(@IM<V=S='(@(D%L=&$B"@HC.B!T96UP;&%T
M97,O<&]R=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH
M96%D97(N:6YC.C4*;7-G:60@(DAO7VUE(@IM<V=S='(@(DE?;NUC:6\B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$T"FUS9VED(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T
M871E*2(*;7-G<W1R(")386YT82!3Z2`H0VED861E+45S=&%D;R!D;R!6871I
M8V%N;RDB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U,SD*;7-G
M:60@(DAO;64B"FUS9W-T<B`B26[M8VEO(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$R,@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U"FUS9VED(")(;VUE($%D9')E<W,B
M"FUS9W-T<B`B16YD97)EYV\@4F5S:61E;F-I86PB"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-C0*;7-G:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S='(@
M(D1I<F5T\W)I;R!097-S;V%L(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R
M(")&;VYE(%)E<VED96YC:6%L(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD
M=7)A<R(*;7-G<W1R(")(;VYD=7)A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B
M2&]N9R!+;VYG(@IM<V=S='(@(DAO;F<@2V]N9R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HV-PIM<V=I9"`B2&]R9&4B"FUS9W-T<B`B2&]R9&4B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0T,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E
M;F-O=6YT97)E9"!I;B!M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B
M.B!$861O(%A-3"`E<R!I;G;A;&ED;R!E;F-O;G1R861O(&YA(&UE;G-A9V5M
M("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR.3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S
M<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!.96YH
M=6UA(&UE;G-A9V5M(&-O<G)E<W!O;F1E(&%O(&]B:F5T;R`E<R(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#,U"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I
M;B!M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!.96YH=6T@;V)J
M971O(&1O('1I<&\@)7,@9F]I(&5N8V]N=')A9&\@;F$@;65N<V%G96T@)7,B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-#8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D
M("5S(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@4F5M;W9I9&\@8V]M
M('-U8V5S<V\@)7,@7"(E<UPB(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@
M96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N(@IM
M<V=S='(@(DAO<F1E+TMO;&%B.B!!(&5N9VEN92!D92!I;G1E9W)AY^-O(')E
M<75E<B!A(&5X=&5N<^-O(%!(4"`G9&]M>&UL)R(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z-3`R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J
M96-T("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!);7!O<W/M=F5L(&-R:6%R
M('5M82!N;W9A(.%R=F]R92!834P@<&%R82!O(&]B:F5T;R`E<R(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(T,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z
M("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!);7!O<W/M=F5L(')E;6]V97(@
M)7,@7"(E<UPB.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M-#<S"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*
M;7-G<W1R("(B"B)(;W)D92]+;VQA8CH@26UP;W-S[79E;"!O8G1E<B!A(&ED
M96YT:69I8V'GXV\@34E-12!P87)A(&$@<&%R=&4@9&\@=&EP;R`E<R(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$Y,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S
M(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($EM<&]S<^UV96P@
M<VEN8W)O;FEZ87(@)7,@7"(E<UPB.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,3,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z($EM<&]S<^UV96P@<VEN8W)O;FEZ87(@8V]M<&%R
M=&EL:&%M96YT;W,Z("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO
M=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!#;VUP87)T
M:6QH86UE;G1O(&1E<V-O;FAE8VED;R!<(B5S7"(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(T"FUS9VED(")(;W)I>F]N
M=&%L(%)U;&4B"FUS9W-T<B`B3&EN:&$@2&]R:7IO;G1A;"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO
M<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R(")-87)G96T@:&]R:7IO;G1A;"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*
M;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@(DAO<FEZ;VYT86PZ(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4Q"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O
M<G0A*2(*;7-G<W1R(")#;VUO('9O8^H@8VAE9V]U(&%Q=6D_("A0;W(@9F%V
M;W(@8V]M=6YI<75E(2DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS
M('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")1=6%N=&%S(&-O
M;'5N87,@=F]CZB!G;W-T87)I82!D92!M97-C;&%R/R(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@
M*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`B475A;G1O<R!C86UP;W,@
M*&-O;'5N87,I(&5X:7-T96T_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W
M<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B475A;G1A<R!L
M:6YH87,@=F]CZB!G;W-T87)I82!D92!M97-C;&%R/R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,S<*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(E5M:61A9&4B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0X"FUS9VED(")(=6UI9&ET>3H@
M(@IM<V=S='(@(E5M:61A9&4Z("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(DAU;6]R:7-T87,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B2'5N9W+M82(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W,B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C,U"B,L('!H<"UF;W)M870*;7-G
M:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@
M(D9A;&AA(&%O(&-R:6%R(&-A:7AA('!O<W1A;"!)34%0.B`E<R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(Q-"!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G-Q;"YP:'`Z,CDU"B,L('!H<"UF;W)M870*;7-G:60@(DE-
M05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM<V=S='(@(D9A;&AA
M(&%O(&5X8VQU:7(@8V%I>&$@<&]S=&%L($E-05`Z("5S(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<Y(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER<W%L+G!H<#HR-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M
M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B1F%L
M:&$@86\@8W)I87(@<75O=&$@9&$@8V%I>&$@<&]S=&%L($E-05`Z("5S(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,R,`IM<V=I9"`B25`@061D
M<F5S<R(*;7-G<W1R(")%;F1E<F7G;R!)4"(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D9')E<W,@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B16YD97)EYV\@25`@;N-O(&1I<W!O;NUV96PN
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HX.0IM<V=I
M9"`B25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB
M"FUS9W-T<B`B16YD97)EYV\@25`@;N-O(&5S=.$@;F\@8FQO8V\@<&5R;6ET
M:61O($-)1%(N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W;B!V:6]L871I;VXN
M(@IM<V=S='(@(E9I;VQAY^-O(&1O(&)L;W%U96EO($E0+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.0IM
M<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(DE?;G-I<F$@3&EN
M:&$@06YT97,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DEC96QA;F0B"FUS9W-T
M<B`B27-LXFYD:6$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@P"FUS
M9VED("))8V]N<R!/;FQY(@IM<V=S='(@(E-O;65N=&4@S6-O;F5S(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@
M(DEC;VYS(&9O<B`E<R(*;7-G<W1R("+-8V]N97,@<&%R82`E<R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#$*;7-G:60@(DEC;VYS('=I=&@@=&5X
M="(*;7-G<W1R("+-8V]N97,@92!T97AT;R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ.3,*;7-G:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B
M3F]M92!D82!I9&5N=&ED861E.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C4Y.0HC+"!P:'`M9F]R;6%T"FUS9VED("))9B!I="!I
M<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A
M(&YE=R!W:6YD;W<N(@IM<V=S='(@(E-E(&[C;R!F;W(@97AI8FED;R!C;W)R
M971A;65N=&4L("5S('!A<F$@86)R[2UL;R!E;2!U;6$@;F]V82!J86YE;&$N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U.0IM<V=I9"`B(@HB268@
M>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R
M97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N
M(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"B)392!V;V/J(&[C
M;R!VZB!N96YH=6T@[6-O;F4@86\@=71I;&EZ87(@;R!);G1E<FYE="!%>'!L
M;W)E<BP@=F]CZB!P;V1E("(*(F-H96-A<B!E<W1A(&-A:7AA('!A<F$@9&5S
M86)I;&ET87(@82!T<F%N<W!A<NIN8VEA(%!.1RXB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3<R"FUS9VED("(B"B))9B!Y
M;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y
M;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA>65D(&)Y('EO
M=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@HB4V4@=F]CZB!VZB!E<W1A(&UE;G-A
M9V5M(&UA<R!NXV\@82!I;6%G96TL(&$@:6UA9V5M('%U92!V;V/J('%U97(@
M96YV:6%R(&[C;R`B"B)P;V1E('-E<B!E>&EB:61A('!E;&\@<V5U(&YA=F5G
M861O<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C@*;7-G:60@(DEM86=E(%!R979I97<Z(@IM<V=S
M='(@(E!RZ2UV:7-U86QI>F'GXV\@9&$@26UA9V5M.B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@
M(DEM86=E(%523"(*;7-G<W1R(")54DP@9&$@26UA9V5M(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3@*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Q
M"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(E523"!D82!);6%G96TZ(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B
M26UA9V5M(&1A(&=A;&5R:6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@(DEM86=E(&9R
M;VT@9V%L;&5R>3HB"FUS9W-T<B`B26UA9V5M(&1A(&=A;&5R:6$Z(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V-0IM<V=I9"`B26UA9V4@=7!L
M;V%D(@IM<V=S='(@(D5N=FEO(&1E($EM86=E;2(*"B,Z(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B"FUS9W-T<B`B26UA9V5N<R(*
M"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A
M=&$O9&%T96UA<"YI;F,Z-PHC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C4T('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(DEM<&]R=&%R+"!0
M87-S;R`E9"(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C$V"B,L
M('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R
M(")#86UP;R!I;7!O<G1A9&\Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R(")#
M86UP;W,@:6UP;W)T861O<SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W
M($%F=&5R(@IM<V=S='(@(DEN7W-E<FER($QI;FAA($%P\W,B"@HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S0*;7-G:60@(DEN
M8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B0_-D:6=O(&1E
M(&'GXV\@9F]R;F5C:61O(&5S=.$@:6YC;W)R971O+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"FUS9VED("))
M;F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+B(*;7-G<W1R(")5
M<W7A<FEO(&4O;W4@<V5N:&$@:6YC;W)R971O<RXB"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R96-T('5S97)N
M86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C
M="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H
M96QP+B(*;7-G<W1R("(B"B)5<W7A<FEO(&]U(&5N9&5R9>=O(&%L=&5R;F%T
M:79O(&EN8V]R<F5T;W,N(%1E;G1E(&YO=F%M96YT92!O=2!E;G1R92!E;2`B
M"B)C;VYT871O(&-O;2!O(&%D;6EN:7-T<F%D;W(@<V4@=F]CZB!N96-E<W-I
M=&$@9&4@;6%I<R!A:G5D82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S92!);F1E;G0B"FUS
M9W-T<B`B075M96YT87(@261E;G1AY^-O(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED
M("));F1I82(*;7-G<W1R("+-;F1I82(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,C4T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T
M"FUS9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@(E5S=>%R:6]S(&EN
M9&EV:61U86ES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("));F1O;F5S:6$B"FUS
M9W-T<B`B26YD;V[I<VEA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B26YF;R(*;7-G<W1R("));F9O<FUA
MY^-O(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U.0IM<V=I9"`B
M26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M8>?C;R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,3D*;7-G:60@(DEN9F]R;6%T:6]N(&YO
M(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(D[C;R!E>&ES=&5M(&]PY_5E
M<R!D:7-P;V[M=F5I<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@(DEN<V5R="!#7V]L=6UN
M($%F=&5R(@IM<V=S='(@(DEN<V5R:7(@0U]O;'5N82!!</-S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(P"FUS9VED("));G-E<G0@26UA9V4B"FUS9W-T<B`B26YS97)I<B!);6%G
M96TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`P"FUS9VED("));G-E<G0@5&%B;&4B"FUS9W-T<B`B26YS97)I<B!486)E
M;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(U"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B26YS97)I<B!,
M:6YK(&1A(%=E8B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T(%]#;VQU;6X@0F5F
M;W)E(@IM<V=S='(@(DEN<V5R:7(@7T-O;'5N82!!;G1E<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM
M<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O
M;F4B"FUS9W-T<B`B26YS97)I<B!U;6$@;F]V82!C;VQU;F$@87#S<R!A(&%T
M=6%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8U"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R
M92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B26YS97)I<B!U;6$@;F]V82!C
M;VQU;F$@86YT97,@9&$@871U86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@(DEN<V5R="!A
M(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DEN<V5R
M:7(@=6UA(&YO=F$@;&EN:&$@87#S<R!A(&%T=6%L(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED
M("));G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS
M9W-T<B`B26YS97)I<B!U;6$@;F]V82!L:6YH82!A;G1E<R!D82!A='5A;"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHW,`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C
M=7)R96YT(&YO9&4B"FUS9W-T<B`B26YS97)I<B!U;2!P87+A9W)A9F\@87#S
M<R!O(&%T=6%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@
M8F5F;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B26YS97)I<B!U;2!P
M87+A9W)A9F\@86YT97,@9&\@871U86PB"@HC.B!A9&UI;B]T96UP;&%T97,N
M<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T96UP;&%T92(*;7-G
M<W1R("));G-E<FER('5M(&UO9&5L;R!A;'1E<FYA=&EV;R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR-#(*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A
M9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W
M;W)D.B(*;7-G<W1R(")&;W)N9>=A('5M(&5N9&5R9>=O(&1E(&4M;6%I;"!N
M;R!Q=6%L('9O8^H@<&]D92!R96-E8F5R(&$@;F]V82!S96YH83HB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X
M"FUS9VED("));G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R("));G-E<FER(&/I
M;'5L82!A</-S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU.0IM<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM
M<V=S='(@(DEN<V5R:7(@8^EL=6QA(&%N=&5S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`IM<V=I9"`B26YS
M97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R("));G-E<FER(&-O;'5N82!A</-S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`B
M26YS97)I<B!C;VQU;F$@86YT97,B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM
M<V=S='(@(DEN<V5R:7(@;65N<V%G96YS(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("));G-E
M<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(DEN<V5R:7(@<&%RX6=R869O
M(&%P\W,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@8F5F;W)E
M(@IM<V=S='(@(DEN<V5R:7(@<&%RX6=R869O(&%N=&5S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I
M9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R("));G-E<FER(&QI;FAA(&%P
M\W,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E9F]R92(*;7-G<W1R("))
M;G-E<FER(&QI;FAA(&%N=&5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(S,PIM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE
M('-E8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R(")&;W)N9>=A(&$@<F5S<&]S
M=&$@;V)R:6=A=/-R:6$@<&%R82!A('!E<F=U;G1A(&1E('-E9W5R86[G83HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(V
M"FUS9VED("));G-E<G0O36]D:69Y($EM86=E(@IM<V=S='(@(DEN<V5R:7(O
M06QT97)A<B!);6%G96TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@Y"FUS9VED("));G-E<G0O36]D:69Y($QI;FLB"FUS
M9W-T<B`B26YS97)I<B]!;'1E<F%R($QI;FLB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B26YS=69F
M:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES
M="XB"FUS9W-T<B`B0W+I9&ET;R!I;G-U9FEC:65N=&4@<&%R82!E;G9I87(@
M<&%R82!A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS
M=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`B0W+I9&ET;R!I;G-U9FEC:65N
M=&4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`W.0IM<V=I9"`B
M26YT96=E<B(*;7-G<W1R(").^FUE<F\@26YT96ER;R(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Q,S<*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G
M<W1R("),:7-T82!D92!);G1E:7)O<R(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI9"!5
M1$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B0T15("A#86)EYV%L
M:&\@9&4@1&%D;W,@9&4@57-UX7)I;RD@:6YVX6QI9&\N(@H*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,38W"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$Y-`HC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,3(*;7-G:60@(DEN=F%L:60@
M6DE0(&1A=&$B"FUS9W-T<B`B1&%D;W,@6DE0(&EN=N%L:61O<R(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P;&EC
M871I;VXN(@IM<V=S='(@(D%P;&EC8>?C;R!I;G;A;&ED82XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G
M:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(DED96YT:69I8V'GXV\@
M9&\@8F%T8V@@:6YVX6QI9&$N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C`Y,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,38R"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(R,S8@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C,P,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N
M<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R
M(")$861O<R!E;G9I861O<R!SXV\@:6YVX6QI9&]S+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,`IM<V=I9"`B
M26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R(")%;F1E<F7G
M;R!D92!D97-T:6YO(.D@:6YVX6QI9&\N(@H*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+V1B>"YP:'`Z,3`Y"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]D8G@N<&AP.C$S.0HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O9&)X+G!H<#HR-#$*;7-G:60@(DEN=F%L:60@9FEL92!F;W)M
M870B"FUS9W-T<B`B1F]R;6%T;R!D;R!A<G%U:79O(.D@:6YVX6QI9&\B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38U"FUS9VED("));G9A
M;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R(").^FUE<F\@9&4@;&EC96[G82!I
M;G;A;&ED;RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y
M"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("),
M;V-A;&EZ8>?C;R!F;W)N96-I9&$@Z2!I;G;A;&ED82XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@
M(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@(E1I<&\@9&$@;65N<V%G96T@
MZ2!I;G;A;&ED;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#,*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A
M<&E?:60N(@IM<V=S='(@(D%P:5]I9"#I(&EN=N%L:61O(&]U(&5S=.$@9F%L
M=&%N9&\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE
M=&5R<RXB"FUS9W-T<B`B4&%RXFUE=')O<R!I;G;A;&ED;W,@;W4@9F%L=&%N
M9&\N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C(W"FUS9VED("))
M;G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")097)M:7-S]65S
M(&1O('!A:2!SXV\@:6YVX6QI9&%S+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-C$*;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS
M9W-T<B`B4&5R;6ES<_5E<R!D;R!P86D@<^-O(&EN=N%L:61A<RXB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38S"FUS9VED("));G9A;&ED
M('!R;V1U8W0@8V]D92XB"FUS9W-T<B`B0_-D:6=O(&1O('!R;V1U=&\@Z2!I
M;G;A;&ED;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#8*;7-G:60@(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S
M='(@(E!R;W1O8V]L;R!I;G;A;&ED;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED
M(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S='(@(D1E<W1I;F%TX7)I;R!I;G;A
M;&ED;SH@)R5S)R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`W
M-2!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-3@*;7-G:60@(DEN=F%L
M:60@<VAA<F4@;V)J96-T(@IM<V=S='(@(D]B:F5T;R!C;VUP87)T:6QH861O
M(&EN=N%L:61O(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`Q"FUS9VED("));G9A;&ED('-O=7)C92!A9&1R97-S
M+B(*;7-G<W1R(")&;VYT92!D;R!E;F1E<F7G;R!I;G;A;&ED82XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*
M;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R(")$861O<R!U
M;FEC;V1E(&EN=N%L:61O<RXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S4Y"FUS9VED("));G9E;G1O<GDB"FUS9W-T<B`B26YV96YTX7)I;R(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-S8*
M;7-G:60@(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T<B`B26YV97)T97(@<V5L
M9>?C;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B27)A;BP@27-L86UI8R!297!U
M8FQI8R!O9B(*;7-G<W1R("))<N,L(%)E</IB;&EC82!)<VSB;6EC82!D;R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("))<F%Q=64B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS9W-T<B`B27)L86YD82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE
M(&]F($UA;B(*;7-G<W1R("));&AA(&1O($AO;65M(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D
M(%0M4W1O<FUS(@IM<V=S='(@(E1E;7!E<W1A9&5S($ES;VQA9&%S(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,30@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@P"FUS9VED("))<W)A96PB"FUS9W-T<B`B27-R865L(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C8*;7-G:60@(DES
M<W5E<B(*;7-G<W1R(")%;6ES<V]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS9W-T<B`B
M273A;&EC;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B271A;'DB"FUS9W-T<B`B
M273A;&EA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED(")*86UA:6-A(@IM<V=S='(@
M(DIA;6%I8V$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`P"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R(")*86YE:7)O(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@S"FUS9VED(")*87!A;B(*;7-G<W1R(")*87#C;R(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@V"FUS9VED(")*87!A;F5S92`H25-/+3(P
M,C(M2E`I(@IM<V=S='(@(DIA<&]NZG,@*$E33RTR,#(R+4I0*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(R"FUS9VED(")*97)S97DB"FUS
M9W-T<B`B2F5R<V5Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*;W)D86XB"FUS
M9W-T<B`B2F]R9.)N:6$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`V"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R(")*=6QH;R(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#4*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED
M(")*=6YE(@IM<V=S='(@(DIU;FAO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*
M;7-G<W1R(")*=7-T:69I8V%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N
M=&5R(@IM<V=S='(@(D%L:6YH87(@86\@0V5N=')O(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3<*;7-G:60@
M(DIU<W1I9GD@1G5L;"(*;7-G<W1R(")*=7-T:69I8V%R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G
M:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R(")!;&EN:&%R(.`@17-Q=65R9&$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R(")!;&EN:&%R
M(.`@1&ER96ET82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*
M;7-G<W1R(")#87IA<75I<W3C;R(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR-C,*;7-G:60@(DME97`@;W)I9VEN86P_(@IM
M<V=S='(@(DUA;G1E<B!O(&]R:6=I;F%L/R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I
M9"`B2V5N>6$B"FUS9W-T<B`B477J;FEA(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C
M=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")397)V:61O<B!K97)B97)O
M<R!R96IE:71O=2!A(&%U=&5N=&EC8>?C;RXB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B:65S(@IM<V=S='(@(DYO
M=F%T;W,@9&4@2V5R;F5L(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$Q"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`B0W)I8>?C
M;R!D92!#:&%V92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q-`IM<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(DEM<')E<W/C
M;R!$:6=I=&%L(&1A($-H879E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N9W1H(@IM<V=S='(@(E1A;6%N
M:&\@9&$@0VAA=F4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,3$*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(E1I<&\@9&$@0VAA=F4B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.0IM<V=I
M9"`B2V5Y(%5S86=E(@IM<V=S='(@(E5S;R!D82!#:&%V92(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A
M9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")#
M:&%V92!JX2!E>&ES=&4@;F\@<V5R=FED;W(@9&4@8VAA=F5S('#Z8FQI8V%S
M+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*
M;7-G<W1R(")#<FEA;N=A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B2VER:6)A
M=&DB"FUS9W-T<B`B2VER:6)A=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO
M<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM<V=S='(@
M(D-O<NEI82P@4F5P^F)L:6-A(%!O<'5L87(@1&5M;V-RX71I8V$@9&$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R
M(")#;W+I:6$L(%)E</IB;&EC82!D82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@W"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`B0V]R96%N
M;R`H155#+4M2*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S
M='(@(DMU=V%I="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2WER9WEZ<W1A;B(*
M;7-G<W1R(")1=6ER9W5I<W3C;R(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N
M=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R("),85]Y;W5T(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B
M"FUS9W-T<B`B261I;VUA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),86\@4&5O
M<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("),86\@4F5P^F)L
M:6-A($1E;6]C<N%T:6-A(%!O<'5L87(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,38Y"FUS9VED("),87-T($AA;&8B"FUS9W-T<B`BVFQT:6UA($UE=&%D
M92(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW-@IM<V=I9"`B3&%S="!0
M87-S=V]R9"!#:&%N9V4B"FUS9W-T<B`B1V5R87(@3F]V82!396YH82(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HX-B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@*
M;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R("+:;'1I;6\@475A<G1O(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3@*;7-G:60@(DQA<W0@57!D871E
M9#HB"FUS9W-T<B`BVFQT:6UA($%T=6%L:7IAY^-O.B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.C<Q-PHC+"!P:'`M9F]R;6%T"FUS9VED("),87-T
M(&QO9VEN.B`E<R(*;7-G<W1R("+:;'1I;6\@;&]G:6XZ("5S(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@
M(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T<B`BVFQT:6UO(&QO9VEN
M.B`E<R#@('!A<G1I<B!D92`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.C<Q-`IM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`BVFQT
M:6UO(&QO9VEN.B!.=6YC82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,30V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&%T=FEA
M(@IM<V=S='(@(DQE=/1N:6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#0*;7-G:60@(DQA=R(*;7-G<W1R("),96DB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*;7-G:60@(DQA>6]U
M="(*;7-G<W1R("),87EO=70B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@
M8F]R9&5R(@IM<V=S='(@(D1E:7AA('9A>FEO('-E('%U:7-E<B!S96T@8F]R
M9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQE8F%N;VXB"FUS9W-T<B`B3.UB
M86YO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C8Y"FUS9VED("),969T(@IM<V=S='(@(D5S<75E<F1A(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P.`IM<V=I9"`B3&5F="!H96%D
M97(B"FUS9W-T<B`B0V%B9>=A;&AO(&5S<75E<F1O(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$P-`IM<V=I9"`B3&5F="!V86QU97,B"FUS9W-T
M<B`B5F%L;W)E<R!D82!E<W%U97)D82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B
M3&5S;W1H;R(*;7-G<W1R("),97-O=&\B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HR-34*;7-G:60@(DQE=F5L(@IM<V=S='(@(D%M;W(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#@*;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B3&EBZ7)I82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&EB>6%N($%R86(@2F%M86AI<FEY82(*
M;7-G<W1R("),[6)I82#!<F%B92!*86UA:&ER:7EA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X
M"FUS9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@(DQI96-H=&5N<W1E:6XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM
M<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R(")#:&EV:7-C;T9R86-O(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*;7-G
M:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`B0VAU=F$@1G)A8V$B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG
M:'0@4F%I;B!%87)L>2(*;7-G<W1R(")#:'5V82!&<F%C82!-871U=&EN82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(X"FUS
M9VED("),:6=H="!286EN($QA=&4B"FUS9W-T<B`B0VAU=F$@1G)A8V$@5F5S
M<&5R=&EN82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R("),979E
M<R!086YC861A<R!D92!#:'5V82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,P"FUS9VED("),:6=H="!286EN('=I=&@@5&AU
M;F1E<B(*;7-G<W1R(")#:'5V87,@1G)A8V%S(&-O;2!4<F]V]65S(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*;7-G:60@
M(DQI9VAT(%-N;W<B"FUS9W-T<B`B3F5V92!&<F%C82(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED("),:6=H="!3
M;F]W(%-H;W=E<B(*;7-G<W1R(")"<F5V92!.979A<V-A(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0U"FUS9VED("),:6UE<FEC:R(*;7-G<W1R(")0
M;^IM87,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#$X"FUS9VED
M("),:6YK(@IM<V=S='(@(DQI;FLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I
M;G1S('1O.B(*;7-G<W1R("),:6YK(&%P;VYT82!P87)A.B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X-SD*;7-G:60@(DQI;FL@=&AE(&5M86EL
M(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B
M"FUS9W-T<B`B3&EG87(@;R!E;F1E<F7G;R!D92!E+6UA:6P@X"!PX6=I;F$@
M9&4@8V]M<&]S:>?C;R!A;R!E>&EB:7(B"@HC.B!F<F%M97=O<FLO5&5X=%]&
M:6QT97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@R"FUS9VED("),:6YK<R(*
M;7-G<W1R("),:6YK<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM
M<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(D-O;VMI92!D;R!,:6YU>"(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS
M9VED("),:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B
M3&ES=&%R("T@=7-UX7)I;R!P;V1E('9E<B!A('!A<W1A(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C$S,PIM<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T
M<B`B3&ES=&%R($)A;F-O<R!D92!$861O<R(*"B,Z('-E<G9I8V5S+VAE;'`O
M:6YD97@N<&AP.C4Q"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@
M(DQI<W1A<B!4\W!I8V]S(&1E($%J=61A(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$S,@IM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B3&ES=&%R(%1A
M8F5L87,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y
M-`IM<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S='(@(DQI<W0M07)C:&EV92(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3@Y"FUS9VED
M("),:7-T+4AE;'`B"FUS9W-T<B`B3&ES="U(96QP(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12](96%D97)S+G!H<#HU.38*;7-G:60@(DQI<W0M260B"FUS
M9W-T<B`B3&ES="U)9"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R
M<RYP:'`Z-3DR"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@(DQI<W0M3W=N
M97(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,PIM
M<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(DQI<W0M4&]S="(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DQ"FUS9VED("),:7-T+5-U
M8G-C<FEB92(*;7-G<W1R("),:7-T+5-U8G-C<FEB92(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DP"FUS9VED("),:7-T+55N<W5B
M<V-R:6)E(@IM<V=S='(@(DQI<W0M56YS=6)S8W)I8F4B"@HC.B!A9&UI;B]S
M97-S:6]N<RYP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!S
M97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(D$@;&ES=&%G96T@9&4@<V5S
M<_5E<R!F86QH;W4Z("5S(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,W"B,L
M('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*
M;7-G<W1R(")!(&QI<W1A9V5M(&1E('5S=>%R:6]S(&9A;&AO=3H@)7,B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI
M<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(DQI<W1A9V5M(&1E
M('5S=>%R:6]S(&5S=.$@9&5S86)I;&ET861A+B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT-PIM<V=I9"`B3&ET97)A='5R92(*;7-G<W1R("),:71E
M<F%T=7)A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:71H=6%N:6$B"FUS9W-T
M<B`B3&ET=>)N:6$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M;6%G97,N<&AP.C<W"FUS9VED("),;V%D:6YG+BXN(@IM<V=S='(@(D-A<G)E
M9V%N9&\N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`P
M"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B2&]R82!L;V-A;#H@(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V"FUS9VED("),;V-A;&4@86YD
M(%1I;64B"FUS9W-T<B`B3&]C86QI>F'GXV\@92!(;W)A(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S(@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C4W"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HR,B!L
M:6(O0FQO8VLO;65T87(N<&AP.C<R"FUS9VED("),;V-A=&EO;B(*;7-G<W1R
M(")296=IXV\B"@HC.B!L;V=I;BYP:'`Z,3@Y('-E<G9I8V5S+W!O<G1A;"]S
M:61E8F%R+G!H<#HR,#`@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,PHC
M.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-2!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.CDP"FUS9VED("),;V<@:6XB"FUS9W-T<B`B0V]N96-T
M87(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*;7-G:60@
M(DQO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B3&]G(&1A
M('-E<W/C;R!D92!S:6YC<F]N:7IAY^-O(&%N=&5R:6]R(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y-`IM<V=I9"`B3&]G(&]U="(*;7-G
M<W1R(")$97-C;VYE8W1A<B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU
M.0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`B0V]N96-T87(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3$P"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R
M(")487)E9F%S(&1E($-O;F5XXV\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HY.34*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E
M<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM
M<V=S='(@(D\@;&]G:6X@9F%L:&]U('!O<G%U92!S974@=7-UX7)I;R!O=2!S
M96YH82!E<W1A=F$@:6YC;W)R971A+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.CDY,0IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R(")&86QH
M82!D92!,;V=I;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8Y
M"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`B5&5X=&\@;&]N9V\B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@(DQO=F4B"FUS9W-T<B`B
M06UO<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8X"FUS9VED("),;W<B"FUS9W-T<B`B0F%I>&$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(Q"FUS9VED
M("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@(D%L9F%B971O(&=R96=O
M(&5M(&UI;OIS8W5L;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE
M='1E<G,B"FUS9W-T<B`B06QF86)E=&\@;&%T:6YO(&5M(&UI;OIS8W5L;R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA
M;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B
M3OIM97)O<R!R;VUA;F]S(&5M(&UI;OIS8W5L;R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM
M<V=I9"`B3'5X96UB;W5R9R(*;7-G<W1R("),=7AE;6)U<F=O(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,Y.0HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,W('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R(")-32(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#,*;7-G:60@(DU/5$0B"FUS9W-T
M<B`B34]41"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N
M<&AP.C,V"FUS9VED(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO
M(&1A=&$N(@IM<V=S='(@(D\@86YE>&\@35,M5$Y%1B!NXV\@8V]N=.EM(&1A
M9&]S+B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R(")-
M4T<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA8V%O(@IM<V=S='(@(DUA8V%O
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M97(@
M675G;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T<B`B36%C961O;FEA+"!!;G1I
M9V$@4F5P^F)L:6-A($EU9V]S;.%V:6$@9&$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G
M:60@(DUA9&%G87-C87(B"FUS9W-T<B`B36%D86=A<V-A<B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT.0IM<V=I9"`B36%G:6,B"FUS9W-T<B`B3>%G
M:6-O(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@S"FUS9VED(")-
M86EL(@IM<V=S='(@(D-O<G)E:6\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-3(T"FUS9VED(")-86EL($%D;6EN(@IM<V=S='(@(D%D;6EN:7-T
M<F%D;W(@9&\@0V]R<F5I;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN
M+B(*;7-G<W1R(")#<FEA<B!L:6Y?:RXN+B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I
M9"`B36%L87=I(@IM<V=S='(@(DUA;&%W:2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I
M9"`B36%L87ES:6$B"FUS9W-T<B`B36%LX7-I82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM
M<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B36%L9&EV87,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3(*;7-G:60@(DUA;&DB"FUS9W-T<B`B36%L:2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM
M<V=I9"`B36%L=&$B"FUS9W-T<B`B36%L=&$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.30*;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E
M9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO
M<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S
M='(@(D=E<F5N8VEA(&$@;&ES=&$@9&4@8V%T96=O<FEA<R!E(&%S(&-O<F5S
M(&%S<V]C:6%D87,@82!E;&%S+B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,34T"FUS9VED(")-87`R-"!M87`B"FUS9W-T
M<B`B36%P96%M96YT;R!-87`R-"(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,#@U"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,38Y"FUS9VED(")-87!1=65S="!M87`B"FUS
M9W-T<B`B36%P96%M96YT;R!-87!1=65S="(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G
M<W1R(")-87!E86UE;G1O<R!G<F%V861O<RXB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`R"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#`*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS9W-T
M<B`B36%RYV\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0Q"FUS9VED(")-87)G:6XB"FUS9W-T<B`B36%R9V5M
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*
M;7-G:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R(")-
M87)C87(@8V]M(&9L86=S($QI9&$O3N-O($QI9&$B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H
M(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T
M<B`B36%R8V%R(&-O;2!O=71R;W,@9FQA9W,@*&5X+B!);7!O<G1A;G1E+U)E
M<W!O;F1I9&$I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA
M;F1S(@IM<V=S='(@(DEL:&%S($UA<G-H86QL(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS
M9VED(")-87)T:6YI<75E(@IM<V=S='(@(DUA<G1I;FEC82(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")-871C:&EN9R!F:65L
M9',B"FUS9W-T<B`B0V%M<&]S(&-O<G)E<W!O;F1E;G1E<R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,PIM<V=I9"`B36%U<FET86YI82(*;7-G<W1R(")-875R:73B;FEA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDT"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`B36%U<NUC
M:6\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T<B`B
M0W+I9&ET;R!MX7AI;6\@<&5R;6ET:61O+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B36%X(&UE
M<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@(D[Z;65R;R!MX7AI;6\@
M9&4@<&%R=&5S(&1A(&UE;G-A9V5M(&5X8V5D974N(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,3,*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z
M("(*;7-G<W1R(")496UP97)A='5R82!MX7AI;6$@;F%S(/IL=&EM87,@,C0@
M:&]R87,Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`U"FUS9VED(")-
M87@@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R(")496UP97)A='5R82!M
MX7AI;6$@;F%S(/IL=&EM87,@-B!H;W)A<SH@(@H*(SH@;&EB+V%P:2YP:'`Z
M.#8*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS
M9W-T<B`B3OIM97)O($WA>&EM;R!D92!";&]C;W,@9&4@4&]R=&%L(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3`R(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(T,PIM
M<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T<B`B5&%M86YH;R!MX7AI;6\B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#(*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM
M<V=I9"`B36%Y(@IM<V=S='(@(DUA:6\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED
M(")-87EO='1E(@IM<V=S='(@(DUA>6]T=&4B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-3`*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(DUE9&EC:6YA
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@IM<V=I
M9"`B365M8F5R<R(*;7-G<W1R(")-96UB<F]S(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,X,@IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R(")-;V1O
M(&1O(&UE;G4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T<B`B
M365S8VQA<B!CZ6QU;&%S(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].
M;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DUE<W-A9V4B"FUS9W-T
M<B`B365N<V%G96TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C(Q-@IM<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L
M;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@
M(@HB=F5R:69I960N(@IM<V=S='(@(B(*(DUE;G-A9V5M(%9E<FEF:6-A9&$@
M8V]M(%-U8V5S<V\@;6%S(&\@8V5R=&EF:6-A9&\@9&\@87-S:6YA;G1E(&[C
M;R!P]&1E('-E<B`B"B)V97)I9FEC861O+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B365S<V%G
M92!E>'!I<F5D+B(*;7-G<W1R(")-96YS86=E;2!E>'!I<F%D82XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V.0HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8P
M,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C8P"FUS9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`B5&EP;R!D
M92!M96YS86=E;2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B
M365T87(@5V5A=&AE<B(*;7-G<W1R(")#;&EM82!-971A<B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I
M;&%B;&4N(@IM<V=S='(@(D)L;V-O($UE=&%R(&[C;R!D:7-P;V[M=F5L+B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED("(B"B)-971A<B!B
M;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@
M9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)";&]C;R!-971A
M<B!NXV\@9&ES<&]N[79E;"X@1&5T86QH97,@9F]R86T@9W)A=F%D;W,@96T@
M;&]G('!A<F$@;R`B"B)A9&UI;FES=')A9&]R+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-3,*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O
M;FYE8W1E9"XB"FUS9W-T<B`B3R!-971A<D1"(&[C;R!E<W3A(&-O;F5C=&%D
M;RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8W
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@
M(DUE=&AO9"(*;7-G<W1R(")-Z71O9&\B"@HC.B!F<F%M97=O<FLO4E!#+U)0
M0R]X;6QR<&,N<&AP.C@Q(&9R86UE=V]R:R]24$,O4E!#+W-O87`N<&AP.C$Q
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D
M969I;F5D(@IM<V=S='(@(DWI=&]D;R`G)7,G(&[C;R!E<W3A(&1E9FEN:61O
M(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D
M.B`E<R(*;7-G<W1R(")-Z71O9&\@;N-O(&1E9FEN:61O+B!-Z71O9&\@8VAA
M;6%D;SH@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C<@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HX,@IM<V=I9"`B365T<FEC(@IM<V=S='(@
M(DWI=')I8V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUE>&EC;R(*;7-G<W1R
M(")-Z7AI8V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I82P@1F5D
M97)A=&5D(%-T871E<R!O9B(*;7-G<W1R(")-:6-R;V[I<VEA+"!%<W1A9&]S
M($9E9&5R861O<R!D82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW-@IM<V=I9"`B36ED9&QE(@IM<V=S='(@(DUE
M:6\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS
M.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S='(@(E1I<&\@36EM92(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S$W"FUS9VED(")-:6X@=&5M<"!L87-T(#(T
M(&AO=7)S.B`B"FUS9W-T<B`B5&5M<&5R871U<F$@;>UN:6UA(&YA<R#Z;'1I
M;6%S(#(T(&AO<F%S.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P.0IM
M<V=I9"`B36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B5&5M<&5R
M871U<F$@;>UN:6UA(&YA<R#Z;'1I;6%S(#8@:&]R87,Z("(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#,Y"FUS9VED(")-:6YI;75M('!A
M<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D(@IM<V=S='(@(DED861E
M(&WM;FEM82!D82!S96YH82!A:6YD82!NXV\@97AP:7)O=2(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S,*;7-G:60@(DUI
M<G)O<B(*;7-G<W1R(")%<W!E;&AO(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(D1I=F5R<V]S
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-S(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S0P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,C4P"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E
M<W0N(@IM<V=S='(@(E!A8V]T92!014%2($A45%!?4F5Q=65S="!F86QT86YD
M;RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U"FUS9VED("(B"B)-
M:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET
M(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB
M"FUS9W-T<B`B(@HB0V]N9FEG=7)AY^-O(&9A;'1A;F1O+B!6;V/J('1E;2!Q
M=64@9V5R87(@96QA(&%G;W)A('-E('9O8^H@<75E<B!U=&EL:7IA<B`B"B)E
M<W1A(&%P;&EC8>?C;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)
M1"XB"FUS9W-T<B`B240@9&$@;65N<V%G96T@9F%L=&%N9&\N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*
M;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM
M<V=S='(@(E!A8V]T92!O8G)I9V%T\W)I;R!014%2($UA:6P@9F%L=&%N9&\N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM<V=S='(@(DE$
M(&1A('-E<W/C;R!F86QT86YD;RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R(")396<B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S8*;7-G:60@(DUO8FEL
M92!-86EL(@IM<V=S='(@(D-O<G)E:6\@3?-V96PB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.0IM<V=I9"`B36]D97)A=&4B
M"FUS9W-T<B`B36]D97)A<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C8@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HW,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C@U"FUS9VED(")-;V1I9FEE9"!$871E(@IM<V=S='(@(D1A=&$@36]D:69I
M8V%D82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D:69Y(%523"(*;7-G<W1R(")!;'1E
M<F%R(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C<T"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(DWS9'5L;R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B36]L
M9&]V82P@4F5P^F)L:6-A(&1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VYA
M8V\B"FUS9W-T<B`B3?1N86-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-;VYG
M;VQI82(*;7-G<W1R(")-;VYG\VQI82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(U.#@*;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@(DWJ
M<R!E(&%N;R(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC
M92YP:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`B365N<V%L;65N=&4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.30*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B36]N
M='-E<G)A="(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M
M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B1F%S97,@
M9&$@3'5A(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3DV(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(X,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X
M<&5C=&5D("5D+B(*;7-G<W1R(")-86ES(&-A;7!O<R!E;F-O;G1R861O<R!N
M82!L:6YH82`E9"!Q=64@;R!N^FUE<F\@97-P97)A9&\@)60N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(DUA<G)O8V]S(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@
M(DUO<W1L>2!#;&5A<B(*;7-G<W1R(")'<F%N9&4@4&%R=&4@3&EM<&$B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-`IM<V=I
M9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R(")'<F%N9&4@4&%R=&4@3G5B;&%D
M;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,U
M"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B1W)A;F1E(%!A<G1E($5N
M<V]L87)A9&\B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.C8T.`IM<V=I9"`B36]V92!$;W=N(@IM<V=S='(@(DUO=F5R
M($%B86EX;R(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z-C4R"FUS9VED(")-;W9E($QE9G0B"FUS9W-T<B`B36]V97(@
MX"!%<W%U97)D82(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z-C4V"FUS9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(DUO
M=F5R(.`@1&ER96ET82(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70O36%N86=E<BYP:'`Z-C0T"FUS9VED(")-;W9E(%5P(@IM<V=S='(@(DUO
M=F5R($%C:6UA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C4R-`IM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(D%B86EX;R(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C,*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`IM
M<V=I9"`B36]V92!U<"(*;7-G<W1R(")!8VEM82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM
M<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R(")-;^=A;6)I<75E(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X.`IM<V=I9"`B375L=&DM;&5V96P@
M9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(DQI<W1A<R!D92!S96QEY^-O(&1E
M(&WZ;'1I<&QO<R!N[79E:7,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3`U-@IM<V=I9"`B375L=&EM87`@54L@;6%P(@IM
M<V=S='(@(DUA<&%S($EN9VQE<V5S($UU;'1I;6%P(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C(T-@IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N
M(@IM<V=S='(@(E-E;&7GXV\@;?IL=&EP;&$B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#`R"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@(DUI
M;FAA($-O;G1A(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X"FUS9VED
M(")->2!!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(E-U87,@26YF;W)M
M8>?U97,B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C0U"FUS9VED
M(")->2!0;W)T86PB"FUS9W-T<B`B365U(%!O<G1A;"(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]E9&ET+G!H<#HT,PIM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*
M;7-G<W1R(")-974@3&%Y;W5T(&1E(%!O<G1A;"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM
M<V=I9"`B37EA;FUA<B(*;7-G<W1R(")":7)MXFYI82(*"B,Z('1E;7!L871E
M<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4W"FUS9VED(").3RP@
M22!$;R!.3U0@06=R964B"FUS9W-T<B`B3L-/+"!%=2!.PT\@0V]N8V]R9&\B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P,@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B3F%M92(*
M;7-G<W1R(").;VUE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").86UI8FEA(@IM
M<V=S='(@(DYA;>UB:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM
M<V=S='(@(DYA=7)U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G
M<W1R(").97!A;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B
M"FUS9W-T<B`B2&]L86YD82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H97)L
M86YD<R!!;G1I;&QE<R(*;7-G<W1R(")!;G1I;&AA<R!(;VQA;F1E<V%S(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G:60@
M(DYE='-C87!E($)A<V4@55),(@IM<V=S='(@(E523"!"87-E(&1O($YE='-C
M87!E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#0*
M;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@55),(@IM<V=S='(@(E52
M3"!D92!2979O9V'GXV\@9&4@0T$@9&\@3F5T<V-A<&4B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@
M0T$@<&]L:6-Y(%523"(*;7-G<W1R(")54DP@9&4@<&]L[71I8V%S(&1E($-!
M(&1O($YE='-C87!E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.#4*;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@
M(E523"!D92!296YO=F'GXV\@9&\@3F5T<V-A<&4B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@4F5V
M;V-A=&EO;B!54DPB"FUS9W-T<B`B55),(&1E(%)E=F]G8>?C;R!D;R!.971S
M8V%P92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@W
M"FUS9VED(").971S8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B3F]M
M92!D;R!S97)V:61O<B!34TP@9&\@3F5T<V-A<&4B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X.`IM<V=I9"`B3F5T<V-A<&4@8V5R
M=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R(")#;VUE;G3A<FEO(&1O(&-E<G1I
M9FEC861O(&1O($YE='-C87!E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E('1Y
M<&4B"FUS9W-T<B`B5&EP;R!D92!C97)T:69I8V%D;R!D;R!.971S8V%P92(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3,*;7-G:60@(DYE='=O
M<FLB"FUS9W-T<B`B4F5D92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0R-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Y"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.3`*;7-G:60@(DYE=F5R(@IM<V=S='(@(DYU
M;F-A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").97<@0V%L961O;FEA(@IM<V=S
M='(@(DYO=F$@0V%L963T;FEA(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z,C8*;7-G:60@(DYE=R!#871E9V]R>2(*
M;7-G<W1R(").;W9A($-A=&5G;W)I82(*"B,Z(&9R86UE=V]R:R]497AT7T9I
M;'1E<B]&:6QT97(O96UA:6QS+G!H<#HX,0HC.B!F<F%M97=O<FLO5&5X=%]&
M:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.#<*(SH@9G)A;65W;W)K+U1E>'1?
M1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.CDW"B,Z(&9R86UE=V]R:R]497AT
M7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HQ,#$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B3F5W($UE<W-A9V4@=&\@)7,B"FUS9W-T<B`B3F]V82!-96YS86=E
M;2!P87)A("5S(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C
M:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED(").
M97<@36]O;B(*;7-G<W1R("),=6$@3F]V82(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T
M:6]N86PI(@IM<V=S='(@(DYO=F\@57-UX7)I;R`H;W!C:6]N86PI(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDX"FUS9VED(").97<@6F5A;&%N9"(*;7-G<W1R(").;W9A(%IE
M;.)N9&EA(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,W"FUS
M9VED(").97<@<&%S<W=O<F0B"FUS9W-T<B`B3F]V82!S96YH82(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R
M(").;W9A('-E;FAA(&5X<&ER87+A(&5M("5X+B(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HU,@IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG
M="!M871C:"XB"FUS9W-T<B`B07,@;F]V87,@<V5N:&%S(&[C;R!SXV\@:6=U
M86ES+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B3F]V
M82!J86YE;&$@*%]B;&%N:RDB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT
M,"!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3(*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(Y,0IM<V=I9"`B3F5W<R(*;7-G<W1R(").;W3M8VEA<R(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,#<*;7-G:60@(DYE=W-G
M<F]U<',B"FUS9W-T<B`B1W)U<&]S(&1E($YO=.UC:6%S(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34@=&5M<&QA=&5S+V1A=&$O9&%T96UA
M<"YI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,CD@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4*;7-G:60@(DYE>'0B"FUS9W-T
M<B`B4'+S>&EM82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PIM<V=I9"`B
M3F5X="`T(%!H87-E<R(*;7-G<W1R(")0<O-X:6UA<R`T($9A<V5S(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C8@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HS-S`*;7-G:60@(DYE>'0@;W!T:6]N<R(*;7-G
M<W1R(")0<O-X:6UA<R!O<.?U97,B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G
M97(N<&AP.C$P,PIM<V=I9"`B3F5X=#XB"FUS9W-T<B`B4'+S>&EM83XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.38*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R(").:6-A<N%G
M=6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R(@IM<V=S='(@(DYI9V5R
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<FEA(@IM<V=S='(@(DYI9^ER
M:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8Y"FUS9VED
M(").:6=H="(*;7-G<W1R(").;VET92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B
M3FEU92(*;7-G<W1R(").:75E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.CDV-`IM<V=I9"`B3F\B"FUS9W-T<B`B3N-O(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS9VED(").
M;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R
M96YC97,@9F]R+B(*;7-G<W1R(").96YH=6T@9&%D;R!D92!C;VYF:6=U<F'G
MXV\@9&ES<&]N[79E;"!P87)A(&5X:6)I<B!A<R!D:69E<F5NYV%S+B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z,3`V"FUS
M9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA
M9V5S+B(*;7-G<W1R(").96YH=6UA(&5S=')A=.EG:6$@9&ES<&]N[79E;"!P
M87)A(&-R:6%R(&EM86=E;G,@25-/+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B3F\@8F%T8V@@
M=&5M<&QA=&4N(@IM<V=S='(@(DYE;FAU;2!M;V1E;&\@9&4@8F%T8V@N(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ
M,#$*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HS.#4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HT,#<*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S
M=&5D('!O<VET:6]N(@IM<V=S='(@(DYE;FAU;2!B;&]C;R!E>&ES=&4@;F$@
M<&]S:>?C;R!S;VQI8VET861A(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M
M8V%L+G!H<#HU,`IM<V=I9"`B3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F
M;W(@34-!3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3F5N:'5M(&YO;64@
M9&4@86=E;F1A(&9O<FYE8VED;R!P87)A(&$@875T96YT:6-AY^-O($U#04PN
M(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-30*;7-G:60@(DYO(&-H86YG
M92XB"FUS9W-T<B`B3F5N:'5M82!A;'1E<F'GXV\N(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(DYO(&-H:6QD<F5N(&-A
M;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(DYE;FAU
M;2!S=6)O<F1I;F%D;R!P;V1E('-E<B!A9&EC:6]N861O(&$@97-T82!P97)M
M:7-SXV\N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-CD@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#@*(SH@9G)A;65W;W)K+U5T:6PO
M571I;"YP:'`Z-S8X"B,L('!H<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B
M3F5N:'5M82!I;F9O<FUAY^-O(&1E(&-O;F9I9W5R8>?C;R!E<W!E8VEF:6-A
M9&$@<&%R82`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@U
M-0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R($944"!61E,N(@IM<V=S='(@(DYE;FAU;6$@:6YF;W)M8>?C;R!D
M92!C;VYF:6=U<F'GXV\@97-P96-I9FEC861A('!A<F$@1E10(%9&4RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8W,@IM<V=I9"`B3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N
M(@IM<V=S='(@(DYE;FAU;6$@:6YF;W)M8>?C;R!D92!C;VYF:6=U<F'GXV\@
M97-P96-I9FEC861A('!A<F$@4U%,(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z-S(U"FUS9VED(").;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G
M<W1R(").96YH=6UA(&EN9F]R;6'GXV\@9&4@8V]N9FEG=7)AY^-O(&5S<&5C
M:69I8V%D82!P87)A(%-13"U&:6QE(%9&4RXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO(&-R
M961I="!L969T+B(*;7-G<W1R(").96YH=6T@8W+I9&ET;R!R97-T86YT92XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S-`IM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@
M(DYE;FAU;2!D97-T:6YO(&9O<FYE8VED;RXB"@HC.B!F<F%M97=O<FLO0G)O
M=W-E<B]"<F]W<V5R+G!H<#HY,#,*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B
M"FUS9W-T<B`B3F5N:'5M(&%R<75I=F\@96YV:6%D;R(*"B,Z('5T:6PO:6-O
M;E]B<F]W<V5R+G!H<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S
M='(@(DYE;FAU;2#M8V]N92!E;F-O;G1R861O+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ,38@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3,P"FUS9VED(").;R!L;V-A=&EO
M;B!I<R!S970N(@IM<V=S='(@(DYE;FAU;6$@;&]C86QI>F'GXV\@8V]N9FEG
M=7)A9&$N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-PIM
M<V=I9"`B3F\@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(DYE;FAU;6$@
M;&]C86QI>F'GXV\@8V]N9FEG=7)A9&$N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*;7-G:60@(DYO(&UE<W-A
M9V4@<W5P<&QI960N(@IM<V=S='(@(DYE;FAU;6$@;65N<V%G96T@9F]R;F5C
M:61A+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,V"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B
M3F5N:'5M(&YO;64@97-P96-I9FEC861O+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS9VED(").;R!N=6UB
M97(@<W!E8VEF:65D+B(*;7-G<W1R(").96YH=6T@;OIM97)O(&5S<&5C:69I
M8V%D;RXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*;7-G:60@(DYO
M(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R(")396T@<V]R=&5S(&]F96YS
M:79A<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z.3$*;7-G
M:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R(").96YH=6UA('-E;FAA(&9O<FYE8VED82!P87)A(&$@
M875T96YT:6-AY^-O($A45%`N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I
M;6%P+G!H<#HQ,#@*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)
M34%0(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").96YH=6UA('-E;FAA(&9O
M<FYE8VED82!P87)A(&$@875T96YT:6-AY^-O($E-05`N(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M(").96YH=6UA('-E;FAA(&9O<FYE8VED82!P87)A(&$@875T96YT:6-AY^-O
M($ME<F)E<F]S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z
M-S<@9G)A;65W;W)K+T%U=&@O075T:"]L;V=I;BYP:'`Z.#0*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]P86TN<&AP.C<U"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYE
M;FAU;6$@<V5N:&$@9F]R;F5C:61A('!A<F$@82!A=71E;G1I8V'GXV\@3&]G
M:6XN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P87-S=V0N<&AP.C$S-0IM
M<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B3F5N:'5M82!S96YH82!F;W)N96-I9&$@<&%R
M82!A(&%U=&5N=&EC8>?C;R!005-35T0N(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]S;6(N<&AP.C@T"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").96YH=6UA('-E;FAA
M(&9O<FYE8VED82!P87)A(&$@875T96YT:6-AY^-O(%--0BXB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R.#<*;7-G:60@(B(*(DYO
M('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E
M;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O<FL@=VET:"!02T-3
M(#$R(&1A=&$N(@IM<V=S='(@(B(*(DYE;FAU;2!P871H('!A<F$@;R!B:6[A
M<FEO(&1O($]P96Y34TP@9F]I(&9O<FYE8VED;RX@3R!B:6[A<FEO(&1O($]P
M96Y34TP@Z2`B"B)N96-E<W/A<FEO('!A<F$@;6%N:7!U;&%R(&]S(&1A9&]S
M(%!+0U,@,3(N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI
M;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R(").96YH
M=6T@8V%D87-T<F\@<&5N9&5N=&4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C<V-@IM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R(")1=6]T82!N
MXV\@8V]N9FEG=7)A9&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PIM<V=I9"`B3F\@<G5L97,B"FUS9W-T
M<B`B4V5M(&QI;FAA<R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C0X,@IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I9FEE9"XB"FUS9W-T<B`B
M3F5N:'5M('-E<&%R861O<B!F;VD@97-P96-I9FEC861O+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#0*;7-G
M:60@(DYO('-I9&5S(@IM<V=S='(@(E-E;2!L861O<R(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z-3@W"FUS9VED(").;R!S=6-H(&9I;&4B"FUS
M9W-T<B`B07)Q=6EV;R!I;F5X:7-T96YT92(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ,C8*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O
M<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B3F5N:'5M(&1I<F5T
M\W)I;R!T96UP;W+A<FEO(&1I<W!O;NUV96P@<&%R82!O(&-A8VAE+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"FUS
M9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T
M<B`B3F5N:'5M('5S=>%R:6\@92]O=2!S96YH82!F;W)N96-I9&]S+B(*"B,Z
M(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED(").;R!V
M86QI9"!834P@9&%T82!R971U<FYE9"(*;7-G<W1R(").96YH=6T@9&%D;R!8
M34P@=N%L:61O(')E=&]R;F%D;R(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HY-S(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.CDX,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.3DS"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,#$P"FUS9VED(").;R!V86QU97,B"FUS9W-T<B`B
M4V5M('9A;&]R97,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS
M9VED(").;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I
M;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB3F5N
M:'5M('9E<G/C;R!E;F-O;G1R861A(&YA(&-O;F9I9W5R8>?C;R!O<FEG:6YA
M;"X@1V5R92!N;W9A;65N=&4@82`B"B)C;VYF:6=U<F'GXV\N(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$R.`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N
M9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B(@HB3F5N:'5M82!V97)SXV\@96YC;VYT<F%D82!N
M82!S=6$@8V]N9FEG=7)AY^-O+B!'97)E(&YO=F%M96YT92!A(&-O;F9I9W5R
M8>?C;RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDS
M"FUS9VED(").;VYE(@IM<V=S='(@(DYE;FAU;6$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP"FUS9VED(").;VYE("AU
M<V4@:6UP;&EC:70I(@IM<V=S='(@(DYE;FAU;6$@*'5S;R!I;7!L[6-I=&\I
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(DYO<F1I8R`H
M25-/+3@X-3DM,3`I(@IM<V=S='(@(D[S<F1I8V\@*$E33RTX.#4Y+3$P*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B
M26QH82!.;W)F;VQK(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]"
M;&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*
M;7-G<W1R(")(96UI<V;I<FEO($YO<G1E(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED
M(").;W)T:&5R;B!-87)I86YA($ES;&%N9',B"FUS9W-T<B`B26QH87,@36%R
M:6%N82!D;R!.;W)T92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM
M<V=S='(@(DYO<G5E9V$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8T,0IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(D[C;R!!</-S
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#`*;7-G
M:60@(DYO="!"969O<F4B"FUS9W-T<B`B3N-O($%N=&5S(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z-#$U"FUS9VED(").;W0@82!D:7)E8W1O
M<GDB"FUS9W-T<B`B3N-O(.D@=6T@9&ER973S<FEO(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HV,PHC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H
M<#HX-`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+G!H<#HY-0HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2YP:'`Z-3D*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B
M3N-O($EM<&QE;65N=&%D;RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C8X"FUS9VED(").;W0@<V5T(@IM<V=S='(@(D[C
M;R!C;VYF:6=U<F%D;R(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]3
M97-S:6]N2&%N9&QE<BYP:'`Z,30U"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N
M9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,38P"B,Z(&9R86UE=V]R:R]397-S
M:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3<U"B,Z(&9R86UE=V]R
M:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3@Y"B,Z(&9R
M86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,V
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HQ.3,*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C(P."!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C,T"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HR-3(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(V
M.0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C@U(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HS,#$*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,Q-B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,S,S"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HS-C8@9G)A;65W;W)K+U9&4R]61E,N<&AP.C0R-@HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z-3`U(&9R86UE=V]R:R]61E,O5D93+G!H<#HU-S0*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C4Y,2!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z-C8Y"FUS9VED(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R(").XV\@<W5P
M;W)T861O+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HR-#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,#4*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$X,`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B
M06YO=&'G]65S(@H*(SH@<V5R=FEC97,O;V)R;W=S97(O:6YD97@N<&AP.C,V
M"FUS9VED(").;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RXB"FUS9W-T<B`B
M3F%D82!P87)A(&5X:6)I<BP@=F]L=&4N(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,`HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-S4*;7-G:60@(DYO=F5M8F5R(@IM<V=S
M='(@(DYO=F5M8G)O(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`U
M,`IM<V=I9"`B3G5M8F5R(@IM<V=S='(@(D[Z;65R;R(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$T,CD*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T
M97)S(@IM<V=S='(@(D[Z;65R;R!D92!C87)A8W1E<F5S(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3,W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-#(W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#D@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU
M;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@(D[Z;65R;R!D92!C;VQU;F%S(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W,2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-#(U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T
M-#<@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*
M;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(D[Z;65R;R!D92!L:6YH
M87,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8T-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A
M=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B3OIM97)O(&[C
M;R!E<W!E8VEF:6-A9&\@<&%R82!A='5A;&EZ8>?C;R!N82!L:7-T82!D92!D
M:7-T<FEB=6GGXV\N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R(")/2R(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX-S$*;7-G:60@(D]B
M:F5C="(*;7-G<W1R(")/8FIE=&\B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$Q,0IM<V=I9"`B3V)J96-T($-R96%T;W(B"FUS9W-T<B`B0W)I
M861O<B!D;R!/8FIE=&\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,3`X"FUS9VED(")/8W1A;"(*;7-G<W1R(")/8W1A;"(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R
M(@IM<V=S='(@(D]U='5B<F\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@(D9I;'1R;R!O9F5N
M<VEV;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C@*;7-G:60@
M(D]F9FEC92(*;7-G<W1R(")%<V-R:73S<FEO(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/;&0@86YD(&YE=R!P87-S=V]R
M9',@;75S="!B92!D:69F97)E;G0N(@IM<V=S='(@(E-E;FAA<R!A;G1I9V$@
M92!N;W9A(&1E=F5M('-E<B!D:69E<F5N=&5S+B(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HS-@IM<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S
M='(@(E-E;FAA(&%N=&EG82(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HT-@IM<V=I9"`B3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*
M;7-G<W1R(")396YH82!A;G1I9V$@;N-O(&5S=.$@8V]R<F5T82XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T<B`B3VWC(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@
M24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@
M(E-O;65N=&4@<V5R=FED;W)E<R!)34%0('-U<&]R=&%M('!A<W1A<R!C;VUP
M87)T:6QH861A<RXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G
M:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(E-O;65N=&4@
M<V]R=&5S(&]F96YS:79A<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X-34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW-0IM<V=I9"`B3VYL
M>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R(")3;VUE;G1E
M('5M(&5N9&5R9>=O(&1E(&4M;6%I;"!P97)M:71I9&\N(@H*(SH@<V5R=FEC
M97,O<VAA<F5S+V5D:70N<&AP.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE
M<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI
M<"!O<B!O=VYE<B`B"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R
M("(B"B)3;VUE;G1E(&\@<')O<')I973A<FEO(&]U(&\@861M:6YI<W1R861O
M<B!D;R!S:7-T96UA('!O9&5M(&%L=&5R87(@87,@(@HB<&5R;6ES<_5E<R!D
M92!P<F]P<FEE9&%D92!O=2!P<F]P<FEE=.%R:6\@9&4@=6T@8V]M<&%R=&EL
M:&%M96YT;R(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,Y(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C0P"FUS9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*
M;7-G<W1R(")!8G)I<B!E;2!U;6$@;F]V82!J86YE;&$B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-33"!E
M<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)
M344@<&%R="XB"FUS9W-T<B`B17)R;R!D;R!/<&5N4U-,.B!.XV\@<'5D92!E
M>'1R86ER(&1A9&]S(&1A('!A<G1E(&%S<VEN861A(%,O34E-12XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-34*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS
M9W-T<B`B06)R92!E<W1E(&QI;FL@96T@=6UA(&YO=F$@:F%N96QA(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R871I;F<@4WES
M=&5M(@IM<V=S='(@(E-I<W1E;6$@3W!E<F%C:6]N86PB"@HC.B!S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS(@IM<V=S
M='(@(D]PY_5E<R(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS,2!T96UP;&%T
M97,O<')E9G,O87!P+FEN8SHQ.0HC+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I
M;VYS(&9O<B`E<R(*;7-G<W1R(")/<.?U97,@9&4@)7,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$X"FUS9VED(")/<F1E
M<F5D($QI<W0B"FUS9W-T<B`B3&ES=&$@3W)D96YA9&$B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T
M:6]N(@IM<V=S='(@(D]R9V%N:7IAY^-O(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N
M:70B"FUS9W-T<B`B56YI9&%D92!/<F=A;FEZ86-I;VYA;"(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S0*;7-G:60@(D]R9V%N:7II;F<B"FUS
M9W-T<B`B3W)G86YI>F%N9&\B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S
M-0IM<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T
M<B`B36]D96QO(&]R:6=I;F%L(&1E(&%P;&EC8>?C;R(*"B,Z(&%D;6EN+W1E
M;7!L871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L
M('1E;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B36]D96QO(&]R:6=I;F%L(&5M
M("5S.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R
M=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G<W1R(")/
M=71R;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.2!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3`Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,38@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-0HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3,T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#0*;7-G:60@(D]T
M:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(D]U=')A<R!);F9O<FUAY_5E<R(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R
M(%!E<FUI<W-I;VYS(@IM<V=S='(@(E!E<FUI<W/U97,@9&\@4')O<')I973A
M<FEO(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<Y"FUS9VED
M(")004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T
M<B`B075T96YT:6-AY^-O(%!!32!NXV\@97-TX2!D:7-P;V[M=F5L+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-0IM
M<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM<V=S='(@(D-O;F5C=&]R(%!%
M05(Z.DUA:6PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,C<V"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B07-S
M:6YA='5R82!$:6=I=&%L(%!'4"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$S,C(*;7-G:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G
M<W1R(")$861O<R!#<FEP=&]G<F%F861O<R!C;VT@4$=0(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,W-`IM<V=I9"`B4$=0(%!U8FQI
M8R!+97DB"FUS9W-T<B`B0VAA=F4@4/IB;&EC82!01U`B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S4V"FUS9VED(")01U`@4VEG;F5D
M+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(D1A9&]S($%S<VEN861O<R]#<FEP
M=&]G<F%F861O<R!C;VT@4$=0(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8X
M"FUS9VED(")02%`@0V]D92(*;7-G<W1R(")#\V1I9V\@4$A0(@H*(SH@861M
M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B
M3&EN:&$@9&4@0V]M86YD;R!02%`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS-PIM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G
M<W1R(")#:'5V82!&<F%C82!697-P97)T:6YA(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@(E!-(%)A:6XB"FUS
M9W-T<B`B0VAU=F$@5F5S<&5R=&EN82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,Y"FUS9VED(")032!3:&]W97)S(@IM<V=S
M='(@(D-H=79A<R!697-P97)T:6YA<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")032!3;F]W(@IM<V=S='(@
M(DYE=F4@5F5S<&5R=&EN82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0Q"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T
M<B`B3F5V87-C82!697-P97)T:6YA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E!-(%-U;B(*;7-G<W1R(").
M979E(%9E<W!E<G1I;F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT,PIM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T<B`B5')O
M=F]A9&%S(%9E<W!E<G1I;F%S(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C(W-`IM<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T
M<B`B17-TX2!F86QT86YD;R!A(&5X=&5N<^-O(%!/4TE8(@H*(SH@;&EB+V%P
M:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@(DQI;FAA(&1E
M($-O;6%N9&\@4%](4"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B
M36%R9V5M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")086MI<W1A;B(*;7-G<W1R
M(")087%U:7-TXV\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QA=2(*;7-G
M<W1R(")086QA=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DR
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N
M(%1E<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B4&%L97-T:6YO+"!497)R
M:73S<FEO($]C=7!A9&\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$X,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!A;F%M82(*
M;7-G<W1R(")086YA;>$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$X-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A<'5A($YE
M=R!'=6EN96$B"FUS9W-T<B`B4.%P=6$@3F]V82!'=6ENZ2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(E!A<F%G=6%I(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S8*;7-G:60@
M(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B4&%R8VEA;&UE;G1E($YU8FQA9&\B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3@P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3,W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C$U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#(R"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(U
M"FUS9VED(")087-S=V]R9"(*;7-G<W1R(")396YH82(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E
M9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(E-E;FAA(&%L=&5R861A(&-O;2!S
M=6-E<W-O+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,3,R,PIM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(E-E;FAA
M(&EN8V]R<F5T82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H
M<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(E-E;FAA(&]B<FEG873S<FEA('!A<F$@
M82!A=71E;G1I8V'GXV\@4D%$2553+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P-3<*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N
M(@IM<V=S='(@(E-E;FAA(&-O;2!C;VYF:7)M8>?C;R(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S
M='(@(E-E;FAA.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q
M"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(E-E;FAA.B`B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ-3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`S.`HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS9VED(")0
M87-S=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`B4V5N:&%S(&1E=F5M('-E
M<B!I9W5A:7,N(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Q.2!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G
M:60@(E!A<W1E(@IM<V=S='(@(D-O;&%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C
M;&EP8F]A<F0B"FUS9W-T<B`B0V]L87(@9&$@X7)E82!D92!T<F%N<V9E<NIN
M8VEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R(")0871H(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F5Q=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB
M"FUS9W-T<B`B0V%D87-T<F]S(%!E;F1E;G1E<SHB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-30*;7-G:60@(E!E;W!L92(*;7-G<W1R(")097-S;V%S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`B4&]R8V5N=&%G96TB"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0IM<V=I
M9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@(D5X
M96-U=&%R($]P97)AY_5E<R!D92!-86YU=&5NY^-O(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0Q,`IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O
M<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R(")%>&5C=71A<B!O<&5R8>?U
M97,@9&4@;6%N=71E;N?C;R!A;R!C;VYE8W1A<C\B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G
M<W1R(")097)M:7-SXV\B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R
M"B,L('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D
M96QE=&5D+B(*;7-G<W1R(")097)M:7-SXV\@7"(E<UPB(&[C;R!E>&-L=>UD
M82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4Y,`IM<V=I9"`B
M4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`B4&5R;6ES<^-O($YE9V%D82(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38Q(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,38T"FUS9VED(")097)M:7-S:6]N<R(*
M;7-G<W1R(")097)M:7-S]65S(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z
M,3`Y(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,`HC.B!A9&UI;B]P97)M
M<R]I;F1E>"YP:'`Z,C(@861M:6XO<&5R;7,O9&5L971E+G!H<#HU.`IM<V=I
M9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI
M<W1R8>?C;R!D92!097)M:7-S]65S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C8X"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R("))
M;F9O<FUAY_5E<R!097-S;V%I<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R
M=2(*;7-G<W1R(")097)U(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U
M"FUS9VED(")0971S(@IM<V=S='(@(D%N:6UA:7,@9&4@17-T:6UAY^-O(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDY"FUS9VED(")0:&EL:7!P:6YE<R(*;7-G<W1R(")&:6QI
M<&EN87,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G<W1R(")496QE9F]N92(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#`*;7-G:60@(E!H;W1O<R(*;7-G
M<W1R(")&;W1O<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DP
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A:7)N(@IM
M<V=S='(@(E!I=&-A:7)N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R(")0:7AE
M;',B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I
M='5D97,B"FUS9W-T<B`B0VQI8VCI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L
M:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S='(@(E!O<B!F879O<B!C;&EQ=64@
M96T@86QG=6UA(&/I;'5L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I
M<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G
M<W1R(")0;W(@9F%V;W(@8V]N9FER;64@<75E('9O8^H@<75E<B!R96UO=F5R
M(&5S=&4@96QE;65N=&\Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N9FER
M;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S
M='(@(E!O<B!F879O<B!C;VYF:7)M92!Q=64@=F]CZB!Q=65R(')E;6]V97(@
M;R!L:6YK(&1E<W1E(&5L96UE;G1O+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(U-C8*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A
M('EE87(N(@IM<V=S='(@(E!O<B!F879O<B!F;W)N9>=A('5M(&WJ<R!E('5M
M(&%N;RXB"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE
M=R!C871E9V]R>3HB"FUS9W-T<B`B4&]R(&9A=F]R(&9O<FYEYV$@=6T@;F]M
M92!P87)A(&$@;F]V82!C871E9V]R:6$Z(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3,P-0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@
M861D<F5S<RXB"FUS9W-T<B`B4&]R(&9A=F]R(&9O<FYEYV$@=6T@96YD97)E
MYV\@25`@=N%L:61O+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V
M-#<*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H
M92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(E!O<B!F
M879O<B!F;W)N9>=A('5M82!D871A(';A;&ED82P@=F5R:69I<75E(&\@;OIM
M97)O(&1E(&1I87,@;F\@;>IS+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(T-3$*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED('1I;64N(@IM
M<V=S='(@(E!O<B!F879O<B!F;W)N9>=A('5M82!H;W)A(';A;&ED82XB"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A
M<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@
M(E!O<B!F879O<B!F;W)N9>=A('5M(')E<W5M;R!D;R!P<F]B;&5M82XB"@HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E
M<FYA;64@86YD('!A<W-W;W)D(@IM<V=S='(@(E!O<B!F879O<B!F;W)N9>=A
M('-E=2!U<W7A<FEO(&4@<V5N:&$B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z-3@*;7-G:60@(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@
M=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H
M92`B"B)S>7-T96TN(@IM<V=S='(@(B(*(E!O<B!F879O<B!L96EA(&\@=&5X
M=&\@82!S96=U:7(N(%9O8^H@1$5612!C;VYC;W)D87(@8V]M(&]S('1E<FUO
M<R!D92!U<V\@9&\@(@HB<VES=&5M82XB"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM<V=I9"`B4&QE87-E('1Y
M<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R(")0;W(@9F%V;W(@
M9&EG:71E(&\@;F]M92!D82!N;W9A(&-A=&5G;W)I83HB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3D*;7-G:60@(E!O;&%N9"(*;7-G<W1R(")0;VST;FEA(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R(")0
M;VSM=&EC82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#D*;7-G
M:60@(E!O;&QS(@IM<V=S='(@(D5N<75E=&4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS
M9VED(")0;W)T=6=A;"(*;7-G<W1R(")0;W)T=6=A;"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM
M<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R(")0;W-I
MY^-O(&1E<W1A(&EM86=E;2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES
M('1A8FQE(@IM<V=S='(@(E!O<VGGXV\@9&5S=&$@=&%B96QA(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@(E!O
M<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G
M<W1R(")%;G9I92!P87)A(&5S=&$@<&%S=&$@*&[C;R#I(&]B<FEG861O('!E
M;&\@24U!4"DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W,R!L:6(O0FQO
M8VLO;65T87(N<&AP.C(W.`HC+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I
M=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R(")0<F5C:7!I
M=&'GXV\@<&%R82!A*',I(/IL=&EM82AS*2`E<R!H;W)A*',I.B`B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@W"FUS9VED(")0<F5C:7!I
M=&%T:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(E!R96-I<&ET8>?C;SQB<B`O
M/F-H86YC92(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]L9&%P+G!H<#HY
M.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]L9&%P.B!%>'1E;G/C;R!,1$%0
M(&]B<FEG873S<FEA(&[C;R!E;F-O;G1R861A+B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO
M;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R(")0<F5F<U]S97-S:6]N.B!%>'1E;G/C;R!D92!S97-SXV\@;V)R:6=A
M=/-R:6$@;N-O(&5N8V]N=')A9&$N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR,S(*;7-G:60@(E!R97-S=7)E(@IM<V=S='(@(E!R97-SXV\B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(V-@IM<V=I9"`B4')E<W-U<F4@870@<V5A
M(&QE=F5L.B`B"FUS9W-T<B`B4')E<W/C;R!E;2!N[79E;"!D;R!M87(Z("(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C0*;7-G:60@(E!R
M97-S=7)E.B`B"FUS9W-T<B`B4')E<W/C;SH@(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P-`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@
M(E!R979I97<B"FUS9W-T<B`B4'+I+79I<W5A;&EZ8>?C;R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM
M<V=S='(@(E!R979E<B!A(&EM86=E;2!E;2!U;6$@;F]V82!J86YE;&$B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,U-B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C,V,`IM<V=I9"`B4')E=FEO=7,@;W!T:6]N
M<R(*;7-G<W1R(")/<.?U97,@86YT97)I;W)E<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O
M8W5M96YT(@IM<V=S='(@(DEM<')I;6ER(&1O8W5M96YT;R(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+
M97DB"FUS9W-T<B`B0VAA=F4@4')I=F%D82(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92]-96YU+G!H<#HQ-CD*;7-G:60@(E!R;V)L96TB"FUS9W-T<B`B
M4')O8FQE;6$B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C<*;7-G:60@
M(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`B1&5S8W)IY^-O(&1O(%!R
M;V)L96UA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W,0IM<V=I
M9"`B4')O:F5C=',B"FUS9W-T<B`B4')O:F5T;W,B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,3$U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M.3(*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,PIM<V=I9"`B4')O
M;7!T('1E>'0B"FUS9W-T<B`B5&5X=&\@8G)E=F4B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS
M9W-T<B`B0VAA=F4@4/IB;&EC82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C0V"FUS9VED(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*
M;7-G<W1R(")!;&=O<FET;6\@9&$@0VAA=F4@4/IB;&EC82(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@
M2V5Y($EN9F\B"FUS9W-T<B`B0VAA=F4@4/IB;&EC82(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A
M=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T
M<B`B4&%R(&1E(&-H879E<R!0^F)L:6-A+U!R:79A9&$@;N-O(&9O<F%M(&=E
M<F%D;W,@8V]M('-U8V5S<V\N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E
M<G1O(%)I8V\B"FUS9W-T<B`B4&]R=&\@4FEC;R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3DV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*
M;7-G:60@(E%A=&%R(@IM<V=S='(@(E%A=&%R(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C8S"FUS9VED(")1=65R>2(*;7-G<W1R(")#;VYS=6QT87(B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*;7-G:60@(E%U;W1A(@IM<V=S
M='(@(E%A=&%R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D
M(&)I="DB"FUS9W-T<B`B0VAA=F4@4/IB;&EC82!24T$@*"5D(&)I="DB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8X"FUS9VED(")2861I;R!S
M96QE8W1I;VXB"FUS9W-T<B`B0F]T]65S(&1E('-E;&7GXV\B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4F%I
M;B(*;7-G<W1R(")#:'5V82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@(D-H
M=79A($UA='5T:6YA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#8*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R(")#:'5V82!6
M97-P97)T:6YA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#<*;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S='(@(E!A;F-A9&%S
M(&1E($-H=79A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#@*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B0VAU=F$@
M92!.979E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#D*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R(")#:'5V82!P87)A
M($YE=F4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N
M9&]M($9O<G1U;F4B"FUS9W-T<B`B4V]R=&4@06QE873S<FEA(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV."!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<V"FUS9VED(")2871I;R(*;7-G
M<W1R(")296QAY^-O(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS
M,C0@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ.#`*;7-G:60@(E)E860B"FUS9W-T<B`B3&5R(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*;7-G:60@(E)E860@
M;65S<V%G97,B"FUS9W-T<B`B3&5R(&UE;G-A9V5N<R(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@
M=6YD;VYE+B(*;7-G<W1R(")%>&-L=6ER(')E86QM96YT92`E<S\@17-T82!O
M<&5R8>?C;R!NXV\@<&]D92!S97(@9&5S9F5I=&$N(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E
M<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*(E)E;6]V97(@
M<F5A;&UE;G1E(&]S(&1A9&]S(&1O('5S=>%R:6\@)7,_($5S=&$@;W!E<F'G
MXV\@;N-O('!O9&4@<V5R("(*(F1E<V9E:71A+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y
M;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(E)E9F%Z('-U82#Z;'1I;6$@8>?C
M;R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C0V"FUS9VED(")2969R97-H(@IM<V=S='(@(D%T=6%L:7IA
M<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.34*;7-G:60@(E)E9G)E
M<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G<W1R(")!='5A;&EZ87(@
M365N=2!D92!%;&5M96YT;W,@1&ENXFUI8V]S.B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-#4*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM
M<V=S='(@(D%T=6%L:7IA<B!%>&EB:>?C;R!D;R!0;W)T86PZ(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DX(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R,3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S.0IM<V=I
M9"`B4F5G97@B"FUS9W-T<B`B4F5G97@B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,C,X"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G
M<W1R(").879E9V%D;W(@9&4@4F5L8>?U97,B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C`X"FUS9VED(")296QO860B"FUS9W-T<B`B3&5R(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,S,*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B3V)S97)V
M8>?U97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$W"FUS9VED(")2
M96UO=&4@4V5R=F5R<R(*;7-G<W1R(")397)V:61O<F5S(%)E;6]T;W,B"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T
M92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R
M(")54DP@4F5M;W1A("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(R('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3,*;7-G:60@(E)E;6]V92(*
M;7-G<W1R(")296UO=F5R(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N
M:6YC.C$Q"FUS9VED(")296UO=F4@0FQO8VLB"FUS9W-T<B`B4F5M;W9E<B!"
M;&]C;R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HU-3<*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B4F5M;W9E<B!C
M;VQU;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0P"FUS9VED(")296UO=F4@9F]R;6%T=&EN9R(*;7-G<W1R(")296UO
M=F5R(&9O<FUA=&'GXV\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`B4F5M;W9E<B!P87(B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R"FUS9VED(")296UO=F4@
M<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R
M>2XB"FUS9W-T<B`B4F5M;W9E<B!S8W)I<'0@9W)A=F%D;R!N;R!D:7)E=/-R
M:6\@=&5M<&]RX7)I;R!D;R!S97)V:61O<BXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*;7-G:60@(E)E
M;6]V92!T:&4B"FUS9W-T<B`B4F5M;W9E<B!O(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")2
M96UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(E)E
M;6]V97(@97-T92!N\R!D;R!D;V-U;65N=&\B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]R96UO=F4N:6YC.C$Q"FUS9VED(")296UO=F4@=7-E<B(*;7-G
M<W1R(")296UO=F5R('5S=>%R:6\B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F4N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S
M97(Z("5S(@IM<V=S='(@(E)E;6]V97(@=7-UX7)I;SH@)7,B"@HC.B!F<F%M
M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q=65S="!C
M;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS
M9W-T<B`B4V]L:6-I=&'GXV\@;N-O('#T9&4@<V5R(')E<W!O;F1I9&$N($/S
M9&EG;R!D92!E<G)O(')E=&]R;F%D;SH@(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$T-0IM<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U
M;&0@;F]T(&)E(&9O=6YD+B(*;7-G<W1R(")/('-E<G9IYV\@<F5Q=6ES:71A
M9&\@;N-O('!O9&4@<V5R(&5N8V]N=')A9&\N(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ-S8@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU
M,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S
M<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B)R5S)R!O
M8G)I9V%T\W)I;R!NXV\@9F]I(&5S<&5C:69I8V%D;R!N82!C;VYF:6=U<F'G
MXV\@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-S@@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-C$*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C<S,0HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U
M:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B)R5S)R!O8G)I9V%T\W)I;R!NXV\@9F]I(&5S<&5C:69I
M8V%D;R!N82!C;VYF:6=U<F'GXV\@5D93+B(*"B,Z(&9R86UE=V]R:R]5=&EL
M+U5T:6PN<&AP.C<W-@HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<
M(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M("(G)7,G(&]B<FEG873S<FEO(&[C;R!F;VD@97-P96-I9FEC861O(&YA(&-O
M;F9I9W5R8>?C;RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R
M+G!H<#HS,S4*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@(D-A;7!O
M($]B<FEG873S<FEO(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S0S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N
M9&5R97(N<&AP.C,R,"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@
M(E)E<V5T(@IM<V=S='(@(DQI;7!A<B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C0V"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R(")'
M97)A<B!.;W9A(%-E;FAA(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z,C<*;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B1V5R
M87(@3F]V82!396YH82(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S`*;7-G
M:60@(E)E<W1O<F4@3&%S="!1=65R>2(*;7-G<W1R("+:;'1I;6\@475A<G1O
M(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C<Q(&%D;6EN+V-M9'-H96QL+G!H
M<#HR."!A9&UI;B]S<6QS:&5L;"YP:'`Z-C8*;7-G:60@(E)E<W5L=',B"FUS
M9W-T<B`B4F5S=6QT861O<R(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T
M=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B4F5T;W)N87(@X"!/<.?U97,B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S@*;7-G:60@(E)E='EP
M92!N97<@<&%S<W=O<F0B"FUS9W-T<B`B1&EG:71E(&$@;F]V82!S96YH82!N
M;W9A;65N=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2975N:6]N(@IM<V=S
M='(@(E)E=6YIXV\B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U
M<F%T:6]N(@IM<V=S='(@(E)E=F5R=&5R($-O;F9I9W5R8>?C;R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@(E)I8V@@5&5X="!%9&ET
M;W(@3W!T:6]N<R(*;7-G<W1R(")/<.?U97,@9&\@161I=&]R(%)I8V@@5&5X
M="(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE
M<R(*;7-G<W1R(")#:&%R861A<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`IM<V=I9"`B4FEG:'0B"FUS9W-T
M<B`B1&ER96ET82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3`*
M;7-G:60@(E)I9VAT(&AE861E<B(*;7-G<W1R(")#86)EYV%L:&\@9&ER96ET
M;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,#8*;7-G:60@(E)I
M9VAT('9A;'5E<R(*;7-G<W1R(")686QO<F5S(&1A(&1I<F5I=&$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")0<F]P<FEE
M9&%D97,@9&$@7TQI;FAA+BXN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R(")&=6[G
MXV\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM<V=S='(@(E)O
M;>IN:6$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C(T"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@(D=I<F%R(#$X,"!G
M<F%U<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,C$*;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@(D=I<F%R('!A<F$@
M82!%<W%U97)D82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,C<*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R(")':7)A
M<B!P87)A(&$@1&ER96ET82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0<F]P97)T:65S
M(@IM<V=S='(@(E!R;W!R:65D861E<R!D82!,:6YH82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@
M(E)O=R!P<F]P97)T:65S(@IM<V=S='(@(E!R;W!R:65D861E<R!D82!L:6YH
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R("),:6YH87,Z(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PIM<V=I
M9"`B4G5L97,B"FUS9W-T<B`B3&EN:&%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,`IM<V=I9"`B4G5L97,@
M=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(*;7-G
M<W1R("),:6YH87,@87!A<F5C97+C;R!E;G1R92!T;V1A<R!A<R!L:6YH87,@
M92!C;VQU;F%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`B3&EN:&%S(&%P87)E8V5RXV\@
M<V]M96YT92!E;G1R92!C;VQU;F%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`B3&EN:&%S(&%P
M87)E8V5RXV\@<V]M96YT92!E;G1R92!L:6YH87,B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3(P"FUS9VED(")2=6XB"FUS9W-T<B`B17AE8W5T87(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`S"FUS9VED(")2=7-S:6%N($9E9&5R871I;VXB"FUS9W-T
M<B`B1F5D97)AY^-O(%)U<W-A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G=A
M;F1A(@IM<V=S='(@(E)U86YD82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3
M:6=N871U<F4B"FUS9W-T<B`B07-S:6YA='5R82!#<FEP=&]G<N%F:6-A(%,O
M34E-12(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S(S
M"FUS9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B365N
M<V%G96T@0W)I<'1O9W)A9F%D82!C;VT@4R]-24U%(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]S87-L+G!H<#HX,0IM<V=I9"`B4T%33"!A=71H96YT:6-A
M=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")!=71E;G1I8V'GXV\@
M4T%33"!NXV\@97-TX2!D:7-P;V[M=F5L+B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HU,#8*;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T<B`B
M0V]R<F5I;R!335,B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@
M(E-13"!3:&5L;"(*;7-G<W1R("),:6YH82!D92!C;VUA;F1O(%-13"(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#$*;7-G:60@(E-13"!S=&%T
M96UE;G0@9F]R('9A;'5E(&QO;VMU<',B"FUS9W-T<B`B4V5N=&5NYV$@4U%,
M('!A<F$@<&5S<75I<V%S(&1E('9A;&]R97,B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#,S"FUS9VED(")34T@B"FUS9W-T<B`B4U-((@H*(SH@
M9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O
M;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R(")354-%4U-/
M(@H*(SH@;&EB+V%P:2YP:'`Z,34S"FUS9VED(")37U%,(%-H96QL(@IM<V=S
M='(@(DQI;FAA(&1E(&-O;6%N9&\@4U]13"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@
M(E-A8B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G
M<W1R(")386YT82!(96QE;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(E-A:6YT
M($MI='1S(&%N9"!.979I<R(*;7-G<W1R(")3XV\@2VET=',@92!.979I<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX-PIM<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B4V%N
M=&$@3'5Z:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")386EN="!0:65R<F4@
M86YD($UI<75E;&]N(@IM<V=S='(@(E/C;R!0961R;R!E($UI<75E;&]N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-0IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R
M96YA9&EN97,B"FUS9W-T<B`B4^-O(%9I8V5N=&4@92!'<F%N861I;F%S(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM
M<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(DUE<VUO('%U861R
M;R`H7W-E;&8I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B4V%M;V$B"FUS9W-T
M<B`B4V%M;V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")386X@36%R:6YO(@IM
M<V=S='(@(E-A;B!-87)I;F\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")386\@
M5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B4^-O(%1O;>D@92!0<NUN8VEP
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@
M(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R(")0<F]V961O<B!D92!3873I
M;&ET92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R86)I82(*;7-G
M<W1R(")!<N%B:6$@4V%U9&ET82(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHY.0IM<V=I9"`B4V%V92(*;7-G<W1R(")386QV87(B"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L('!H<"UF;W)M
M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(E-A;'9A<B`E<R(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V"B,L('!H<"UF;W)M870*
M;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`B4V%L=F%R("5S(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S
M='(@(E-A;'9A<B!/<.?U97,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,38W"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S
M(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D
M:7)E8W1O<GDN(@IM<V=S='(@(B(*(E-A;'9A<B!C;VYF:6=U<F'GXV\@9V5R
M861A(&-O;6\@=6T@<V-R:7!T(%!(4"!P87)A(&\@9&ER973S<FEO('1E;7!O
M<N%R:6\@9&\@(@HB<V5U('-E<G9I9&]R+B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(D-O;F9I9W5R8>?C;R`E<R!S86QV82XB
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB
M+B(*;7-G<W1R(")38W)I<'0@9&4@871U86QI>F'GXV\@9&4@8V]N9FEG=7)A
MY^-O('-A;'9O(&5M.B`G)7,G+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4P"FUS9VED(")38V%T=&5R960@5"U3=&]R;7,B
M"FUS9W-T<B`B5&5M<&5S=&%D97,@27-O;&%D87,B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B0VGJ;F-I
M82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E;7!L
M871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED(")396%R8V@B"FUS
M9W-T<B`B4&5S<75I<V%R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,R,@IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T<B`B16YG:6YE<R!D
M92!097-Q=6ES82`B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.38R
M"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B4V5L96-I;VYE(&]S($%R
M<75I=F]S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0X,PIM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R(")396QE8VEO
M;F4@=6UA(&1A=&$B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y
M.`IM<V=I9"`B4V5L96-T(&$@9W)O=7`@=&\@861D(@IM<V=S='(@(E-E;&5C
M:6]N92!U;2!G<G5P;R!P87)A(&%D:6-I;VYA<B(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*
M;7-G<W1R(")396QE8VEO;F4@=6T@;F]V;R!M96UB<F\B"@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@(E-E;&5C="!A('-E<G9E
M<B(*;7-G<W1R(")396QE8VEO;F4@=6T@<V5R=FED;W(B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$U-@IM<V=I9"`B4V5L96-T(&$@=7-E<B!T
M;R!A9&0B"FUS9W-T<B`B4V5L96-I;VYE('5M('5S=>%R:6\@<&%R82!A9&EC
M:6]N87(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-C<T"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(E-E;&5C:6]N87(@
M=&]D;W,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C4P"FUS9VED
M(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`B4V5L96-I
M;VYE('1O9&]S(&]S(&-O;7!O;F5N=&5S(&1E(&1A=&$N(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,0IM<V=I9"`B4V5L
M96-T(&%N(&]B:F5C="(*;7-G<W1R(")396QE8VEO;F4@=6T@;V)J971O(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-0IM
M<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B3N-O('-E;&5C:6]N87(@;F5N
M:'5M(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W"FUS9VED("(B"B)3
M96QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@
M8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R
M;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B(@HB4V5L96-I;VYE(&]S(&-A
M<F%C=&5R97,@<75E('9O8^H@<')E8VES82!N82!C86EX82!A8F%I>&\N(%9O
M8^H@<&]D92!E;G3C;R`B"B)C;W!IX2UL;W,@92!C;VSA+6QO<R!N82#A<F5A
M(&1E('1E>'1O+B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS
M9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R(")396QE
M8VEO;F4@=6T@9&5L:6UI=&%D;W(@9&4@9&%T83HB"@HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT-`IM<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA
M=#HB"FUS9W-T<B`B4V5L96-I;VYE(&\@9F]R;6%T;R!D92!D871A.B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3`*;7-G:60@
M(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G
M<W1R(")396QE8VEO;F4@82!I9&5N=&ED861E('%U92!V;V/J('%U97(@86QT
M97)A<CHB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@IM<V=I9"`B
M4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B4V5L96-I;VYE
M('5M(&1E;&EM:71A9&]R(&1E(&AO<F$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM92!F;W)M870Z(@IM
M<V=S='(@(E-E;&5C:6]N92!O(&9O<FUA=&\@9&4@:&]R83HB"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C4W"FUS9VED(")396QE8W0@='=O(&UA
M=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`B4V5L96-I;VYE(&1O:7,@8V%M<&]S
M(&-O<G)E<W!O;F1E;G1E<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S$P"FUS9VED(")396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N(@IM<V=S='(@
M(E-E;&5C:6]N92!S974@97-Q=65M82!D92!C;W)E<RXB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C4R"FUS9VED(")396QE8W0@>6]U<B!P<F5F97)R
M960@;&%N9W5A9V4Z(@IM<V=S='(@(E-E;&5C:6]N92!S974@:61I;VUA('!R
M969E<FED;SHB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU
M.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")%;G9I87(@
M4F5L873S<FEO(&1E(%!R;V)L96UA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$P-#`*;7-G:60@(E-E;F0@4TU3(@IM<V=S
M='(@(D5N=FEA<B!335,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")396YE9V%L
M(@IM<V=S='(@(E-E;F5G86PB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R
M,PIM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`B4V5N<V]R.B`B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I9"`B4V5P
M=&5M8F5R(@IM<V=S='(@(E-E=&5M8G)O(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N
M96=R;R(*;7-G<W1R(")397)V:6$@92!-;VYT96YE9W)O(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#(*;7-G:60@(E-E<FEA;"!.
M=6UB97(B"FUS9W-T<B`B3OIM97)O(&1E(%/I<FEE(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$T.0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O
M;F<@;W(@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B1&%D;W,@9&\@<V5R=FED
M;W(@97)R861O<R!O=2!NXV\@9&ES<&]N[79E:7,N(@H*(SH@861M:6XO<V5S
M<VEO;G,N<&AP.C(W"FUS9VED(")397-S:6]N($%D;6EN(@IM<V=S='(@(D%D
M;6EN:7-T<F%D;W(@9&4@4V5S<^-O(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")397-S:6]N($E$
M(&5X<&ER960N(@IM<V=S='(@(DE$(&1A(%-E<W/C;R!E>'!I<F]U+B(*"B,Z
M(&QI8B]A<&DN<&AP.C$T-0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B4V5S
M<_5E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,3@*;7-G:60@
M(E-E="(*;7-G<W1R(")!:G5S=&%R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C<Y"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S
M970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N(@IM<V=S
M='(@(B(*(D-O;F9I9W5R82!A<R!O<.?U97,@<&%R82!P97)M:71I<B!V;V/J
M(&=E<F%R('5M82!N;W9A('-E;FAA('-E('9O8^H@97-Q=65CZBTB"B)L82XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$X"FUS9VED(")3970@=7`@
M<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y
M;W5R('!O<G1A;"XB"FUS9W-T<B`B(@HB0V]N9FEG=7)A(&]S('-E<G9I9&]R
M97,@<F5M;W1O<R!Q=64@=F]CZB!Q=65R(&%C97-S87(@X"!P87)T:7(@9&\@
M<&]R=&%L+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-PIM<V=I9"`B
M4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T
M92!O<'1I;VYS+B(*;7-G<W1R(")#;VYF:6=U<F$@<V5U(&ED:6]M82!P<F5F
M97)I9&\L(&9U<V\@:&]RX7)I;R!E(&]PY_5E<R!D92!D871A+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#$*;7-G:60@(B(*(E-E="!Y;W5R('-T
M87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H
M:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R("(B
M"B)#;VYF:6=U<F$@<W5A(&%P;&EC8>?C;R!I;FEC:6%L+"!E<W%U96UA(&1E
M(&-O<F5S+"!A='5A;&EZ8>?C;R!D92!PX6=I;F%S(&4@(@HB;W5T<F%S(&]P
MY_5E<R!D92!E>&EB:>?C;RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C<W"FUS9VED(")3971U<"(*;7-G<W1R(")#;VYF:6=U<F'GXV\B"@HC.B!T
M96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS-PIM<V=I9"`B4V5T
M=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R(")38W)I<'1S
M(&1E(&%T=6%L:7IAY^-O(&1E(&-O;F9I9W5R8>?C;R!D:7-P;V[M=F5I<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S4*;7-G:60@(E-E
M=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@
M(@IM<V=S='(@(D1I=F5R<V%S(&QO8V%L:61A9&5S('!O<W/M=F5I<R!C;VT@
M;R!P87+B;65T<F\Z("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL
M97,B"FUS9W-T<B`B4V5I8VAE;&5S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0Y.`IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B0V]M<')A<R(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S"FUS9VED(")3
M:&]R="!3=6UM87)Y(@IM<V=S='(@(E)E<W5M;R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT-3`*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D
M969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R(")496-L87,@9&4@871A
M;&AO(&1E=F5RXV\@<V5R(&1E9FEN:61A<R!P87)A(&$@;6%I;W)I82!D;W,@
M;&EN:W,_(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C,@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`B17AI8FER(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$U-0IM<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B
M971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E
M9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")%>&EB:7(@87,@9&EF97)E
M;N=A<R!E;G1R92!A(&-O;F9I9W5R8>?C;R!A='5A;"!E(&$@;F]V82!G97)A
M9&$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y-`IM<V=I9"`B4VAO
M=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R(")%
M>&EB:7(@9&%T82!E(&AO<F$@9&$@^FQT:6UA(&-O;F5XXV\@86\@<V4@8V]N
M96-T87(_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V.0IM<V=I
M9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R(")%>&EB
M:7(@82!O<.?C;R!D92!M86YT97(@;R!O<FEG:6YA;"(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(X,#(*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S
M='(@(D5X:6)I<B!S96QE=&]R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4S,`IM<V=I9"`B4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/R(*
M;7-G<W1R(")%>&EB:7(@8F%R<F$@9&4@;65N=2!C;VT@;W!E<F'G]65S(&1E
M('1A8F5L83\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4S"B,L('!H
M<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_
M(@IM<V=S='(@(D5X:6)I<B!O($UE;G4@)7,@X"!E<W%U97)D83\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L
M;V<B"FUS9W-T<B`B17AI8FER(&1IX6QO9V\@9&4@4')O<')I961A9&5S(&1E
M($/I;'5L87,@9&$@5&%B96QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8T"FUS9VED(")3:&]W('1H92!4
M86)L92!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")%>&EB:7(@9&GA;&]G
M;R!D92!0<F]P<FEE9&%D97,@9&$@5&%B96QA(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8P"FUS9VED(")3
M:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B
M17AI8FER(&1IX6QO9V\@9&4@4')O<')I961A9&5S(&1E($QI;FAA<R!D82!4
M86)E;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-3(*;7-G:60@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I
M97,@9&EA;&]G(@IM<V=S='(@(D5X:6)I<B!D:>%L;V=O(&1E('!R;W!R:65D
M861E<R!D92!I;6%G96TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-S8W"FUS9VED(")3:&]W('5P;&]A9"(*;7-G<W1R(")%>&EB:7(@=7!L;V%D
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*
M;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`B0VAU=F%S(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H;W=E<G,@
M16%R;'DB"FUS9W-T<B`B0VAU=F%S(&UA=&EN86ES(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@
M3&%T92(*;7-G<W1R(")#:'5V87,@5F5S<&5R=&EN87,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-`IM<V=I9"`B4VAO=V5R
M<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B0VAU=F%S(&YA<R!R961O;F1E
M>F%S(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HV,3D*;7-G:60@(E-H<FEN:R(*;7-G<W1R(")2961U>FER(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HY,3`*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HY
M-S(*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HQ,#4X"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z,3$R,`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.C$Q.#,*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HQ,C(S"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70O36%N86=E<BYP:'`Z,3(U,@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R.#4*;7-G:60@(E-H<FEN:R!O<B!M
M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S
M="(*;7-G<W1R(")0<FEM96ER86UE;G1E(')E9'5Z82!O=2!T:7)E(&1O(&-A
M;6EN:&\@;RAS*2!B;&]C;RAS*2!A9&IA8V5N=&4H<RDB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`U"FUS9VED(")3:65R<F$@3&5O;F4B"FUS9W-T<B`B4V5R<F$@3&5O82(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C8*;7-G:60@
M(E-I9VX@=7`B"FUS9W-T<B`B4F5G:7-T<F%R(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3,*;7-G:60@(E-I9VYA='5R92(*;7-G
M<W1R(")!<W-I;F%T=7)A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS9W-T
M<B`B06QG;W)I=&UO(&1A($%S<VEN871U<F$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS
M9VED(")3:6YG87!O<F4B"FUS9W-T<B`B0VEN9V%P=7)A(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-2!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]Z:7`N<&AP.C<R"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1G>BYP:'`Z.#0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.3`P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3D@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(T,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,C4P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,3D*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q,@IM<V=I9"`B4VEZ92(*;7-G<W1R(")4
M86UA;FAO(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E
M+FAT;6PZ-3(*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B26=N
M;W)A<B!-86YU=&5NY^-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K
M:6$B"FUS9W-T<B`B17-L;W;A<75I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@
M(E-L;W9E;FEA(@IM<V=S='(@(D5S;&]V96YI82(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3;F]W(@IM<V=S
M='(@(DYE=F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU-@IM<V=I9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B3F5V87-C82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS
M9VED(")3;F]W(%-H;W=E<G,B"FUS9W-T<B`B3F5V87-C87,B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO
M=R!3:&]W97)S($5A<FQY(@IM<V=S='(@(D-H=79A<R!M871I;F%I<R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED
M(")3;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R(").979A<V-A<R!697-P97)T
M:6YA<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@U"FUS9VED(")3;F]W
M(&1E<'1H.B`B"FUS9W-T<B`B4')O9G5N9&ED861E(&1A($YE=F4Z("(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C@Y"FUS9VED(")3;F]W(&5Q=6EV86QE
M;G0@:6X@=V%T97(Z("(*;7-G<W1R(")%<75I=F%L96YT92!D92!N979E(&5M
M(.%G=6$Z("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M;VX@27-L86YD
M<R(*;7-G<W1R("));&AA<R!386QO;>-O(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I
M9"`B4V]M86QI82(*;7-G<W1R(")3;VWA;&EA(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C8P"FUS9VED(")3;VYG<R`F(%!O96US(@IM<V=S='(@(D-A
M;N?U97,@)B!0;V5M87,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.3$U"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R(")/<F1E
M;F%R('-E;&7GXV\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"FUS9VED(")3;W5R8V4@861D<F5S<R(*
M;7-G<W1R(")%;F1E<F7G;R!D92!O<FEG96TB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS
M9VED(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`BP69R:6-A(&1O(%-U;"(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(")3;W5T:"!%=7)O<&5A
M;B`H25-/+3@X-3DM,RDB"FUS9W-T<B`B4W5L($5U<F]P974@*$E33RTX.#4Y
M+3,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T
M:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R(")3=6P@9&$@1V5O
M<F=I82!E(%-U;"!D87,@26QH87,@4V%N9'7M8VAE(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U
M=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(")(96UI<V;I<FEO(%-U;"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS
M9VED(")3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(D5S
M<&'G;R!E;G1R92!CZ6QU;&%S(&%D:F%C96YT97,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@
M8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R(")%
M<W!AYV\@96YT<F4@;R!C;VYT9?ID;R!E(&)O<F1A(&1A(&/I;'5L82(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Q.0IM<V=I9"`B4W!A8V5R(@IM
M<V=S='(@(D5S<&'G861O<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R
M(")%<W!AYV%M96YT;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I;F<@86YD('!A9&1I
M;F<B"FUS9W-T<B`B17-P8>=A;65N=&\@92!M87)G96TB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`B17-P86YH82(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ,#`*;7-G:60@(E-P86TB"FUS9W-T<B`B4W!A
M;2(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA
M;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`B16YT<F%D82!D92!#87)A8W1E
M<F5S($5S<&5C:6%I<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T
M<B`B1&EV:61I<B!CZ6QU;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI="!C;VQU;6XB
M"FUS9W-T<B`B1&EV:61I<B!C;VQU;F$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI="!R
M;W<B"FUS9W-T<B`B1&EV:61I<B!L:6YH82(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV,0IM<V=I9"`B4W!O<G1S(@IM<V=S='(@(D5S<&]R=&5S(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@X"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T<B`B4W)I($QA
M;FMA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8V(&QI8B]"
M;&]C:R]M971A<BYP:'`Z.#$*;7-G:60@(E-T86YD87)D(@IM<V=S='(@(E!A
M9'+C;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A
M<B!4<F5K(@IM<V=S='(@(E-T87(@5')E:R(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(U.3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<Y.`IM
M<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R(")!;F\@:6YI8VEA;"(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q"FUS9VED(")3=&%T
M92!O<B!0<F]V:6YC92(*;7-G<W1R(")%<W1A9&\@;W4@4')O=NUN8VEA(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@
M(E-T871U<R(*;7-G<W1R(")3:71U8>?C;R(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X,#0*;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@
M(D9O<FUA=&\@9&\@87)M87IE;F%M96YT;R(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")3=')E970@061D<F5S<R(*
M;7-G<W1R(").;VUE(&1A(%)U82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS
M9W-T<B`B5')AYV%D;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M,S<*;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@(DQI<W1A(&1E(&-A9&5I
M87,@9&4@8V%R86-T97)E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X-S<*;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM
M<V=S='(@(E)E=&ER87(@82!P87)T92!D;R!D;VWM;FEO(&1O(&5N9&5R9>=O
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B17-T:6QO(%M#
M4U-=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHV,@IM<V=I9"`B4W4B"FUS9W-T<B`B1&]M(@H*(SH@=71I;"]I8V]N7V)R
M;W=S97(N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(E-U8F1I<F5C=&]R
M>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")3=6)D:7)E=/-R:6\@)R5S
M)R!NXV\@96YC;VYT<F%D;RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J96-T(@IM<V=S='(@(D%S
M<W5N=&\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S8@9G)A;65W
M;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S$W"FUS9VED(")3=6)M:70B
M"FUS9W-T<B`B16YV:6%R(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB
M('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@
M(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B(@HB16YV
M:6%D82!A('-O;&EC:71AY^-O(&1E(&%D:6-I;VYA<B!<(B5S7"(@86\@<VES
M=&5M82X@5F]CZB!NXV\@<&]D92!C;VYE8W1A<BTB"B)S92!A=.D@<75E('-U
M82!S;VQI8VET8>?C;R!S96IA(&%P<F]V861A+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP
M="(*;7-G<W1R(")3=6)S8W)E=F5R(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$P-`HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S='(@
M(E-U8V5S<V\B"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S>7-T
M96TN(@IM<V=S='(@(B<E<R<@861I8VEO;F%D;R!C;VT@<W5C97-S;R!A;R!S
M:7-T96UA+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R(%PB
M)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(D]S(&1A9&]S(&1O('5S
M=>%R:6\@)R5S)R!F;W)A;2!R96UO=FED;W,@9&\@<VES=&5M82!C;VT@<W5C
M97-S;RXB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS+V1E
M;&5T92YP:'`Z-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R("(G)7,G(&5X8VQU[61O(&-O;2!S
M=6-E<W-O+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@
M<WES=&5M+B(*;7-G<W1R(")%>&-L=>UD;R`G)7,G(&1O('-I<W1E;6$@8V]M
M('-U8V5S<V\N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU,0IM<V=I
M9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A
M9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B0V]N9FEG=7)AY^-O(')E=F5R
M=&ED82!C;VT@<W5C97-S;RX@071U86QI>F4@<&%R82!V97(@87,@86QT97)A
MY_5E<RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B
M86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B0F%C:W5P(&1A(&-O;F9I
M9W5R8>?C;R!S86QV82!C;VT@<W5C97-S;RXB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL
M>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS
M9W-T<B`B3R!B86-K=7`@9&\@87)Q=6EV;R!D92!C;VYF:6=U<F'GXV\@)7,@
M9F]I('-A;'9O(&-O;2!S=6-E<W-O+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=7!D871E9"!<
M(B5S7"(B"FUS9W-T<B`B)R5S)R!A='5A;&EZ861O(&-O;2!S=6-E<W-O(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R
M;W1E("5S(@IM<V=S='(@(B5S(&=R879A9&\@8V]M('-U8V5S<V\B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`T"FUS9VED(")3=61A;B(*;7-G<W1R(")3=63C;R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*
M;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`B4F5S=6UO(@H*(SH@;&EB+T)L;V-K
M+W-U;G)I<V4N<&AP.C8U"FUS9VED(")3=6X@4FES92(*;7-G<W1R(")!;6%N
M:&5C97(B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U
M;B!3970B"FUS9W-T<B`B4/1R+61O+5-O;"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS9VED(")3=6YN>2(*;7-G<W1R
M(")%;G-O;&%R861O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(P-0IM<V=I9"`B4W5N<FES92(*;7-G<W1R(")!;6%N:&5C97(B"@HC.B!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@(D%M86YH96-E<B]0
M]'(M9&\M4V]L(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P
M-`IM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(D%M86YH96-E<CH@(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P.`IM<V=I9"`B4W5N<V5T
M(@IM<V=S='(@(E#T<BUD;RU3;VPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C`W"FUS9VED(")3=6YS970Z("(*;7-G<W1R(")0]'(M9&\M
M4V]L.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$S"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R(")3;V)R97-C<F5V
M97(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@P"FUS9VED(")3
M=7!P;W)T(@IM<V=S='(@(E-U<&]R=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED
M(")3=7)I;F%M92(*;7-G<W1R(")3=7)I;F%M92(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3<U"FUS9VED(")3=7)N86UE(@IM<V=S
M='(@(E-O8G)E;F]M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-V86QB87)D
M(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B4W9A;&)A<F0@92!*86X@36%Y96XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`B4W5A
M>FELXFYD:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS9W-T
M<B`B4W7I8VEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM
M<V=S='(@(E-U[>=A(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M.#8*;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B"FUS9W-T<B`B3N-O(&5X8VQU
M:7(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30U"FUS9VED(")3>6YC
M34PB"FUS9W-T<B`B4WEN8TU,(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y
M=V]R9',N<&AP.CDW"FUS9VED(")3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E
M<FUS(@IM<V=S='(@(D5R<F\@9&4@<VEN=&%X92!N;W,@=&5R;6]S(&1A('!E
M<W%U:7-A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4WER:6%N($%R86(@4F5P
M=6)L:6,B"FUS9W-T<B`B4F5P^F)L:6-A(,%R86)E(&1A(%/M<FEA(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@
M(E0M4W1O<FTB"FUS9W-T<B`B5&5M<&5S=&%D92(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS9VED(")4+5-T;W)M(&%N
M9"!7:6YD>2(*;7-G<W1R(")496UP97-T861E<R!E(%9E;G1A;FEA(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*;7-G:60@
M(E0M4W1O<FUS(@IM<V=S='(@(E1E;7!E<W1A9&5S(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*;7-G:60@(E0M4W1O<FUS
M($5A<FQY(@IM<V=S='(@(E1E;7!E<W1A9&5S($UA=&EN86ES(@H*(SH@9G)A
M;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$V-@IM<V=I9"`B5%-6(&9I;&4B
M"FUS9W-T<B`B07)Q=6EV;R!44U8B"@HC.B!F<F%M97=O<FLO54DO54DO5&%B
M;&4N<&AP.C$S-`IM<V=I9"`B5&%B;&4B"FUS9W-T<B`B5&%B96QA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M,PIM<V=I9"`B5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R(")0<F]P<FEE9&%D
M97,@9&$@5&%B96QA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A
M8FQE<V5T+G!H<#HU-PIM<V=I9"`B5&%B;&4@4V5T(@IM<V=S='(@(E1A8F5L
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS9W-T<B`B4')O
M<')I961A9&5S(&1A('1A8F5L82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G
M:60@(E1A:7=A;B(*;7-G<W1R(")486EW86XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC
M92!O9B!#:&EN82(*;7-G<W1R(")486EW86XL(%!R;W;M;F-I82!D82!#:&EN
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B
M5&%J:7%U:7-TXV\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@
M56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S='(@(E1A;GKB;FEA+"!297#Z8FQI
M8V$@9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDU"FUS9VED(")487)G970Z(@IM<V=S='(@(D%L=F\Z(@H*(SH@8V]N
M9FEG+VAO;VMS+G!H<"YD:7-T.CDY-B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3@Y"FUS9VED(")487-K<R(*;7-G<W1R(")487)E9F%S(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S0*;7-G:60@(E1E;&5P
M:&]N92!.=6UB97(B"FUS9W-T<B`B3OIM97)O(&1E(%1E;&5F;VYE(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3<*;7-G:60@(E1E;7`@9F]R(&QA<W0@
M:&]U<CH@(@IM<V=S='(@(E1E;7!E<F%T=7)A('!A<F$@82#Z;'1I;6$@:&]R
M83H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C$*;7-G:60@(E1E;7!E
M<F%T=7)E(@IM<V=S='(@(E1E;7!E<F%T=7)A(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Q,@IM<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G
M<W1R(")496UP97)A='5R83H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(X,@HC+"!P:'`M9F]R;6%T"FUS9VED(")496UP97)A='5R93QB
M<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@(E1E;7!E<F%T
M=7)A/&)R("\^*"5S06QT825S+R5S0F%I>&$E<RD@)F1E9SLE<R(*"B,Z(&9R
M86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-CDU"B,L('!H<"UF;W)M
M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@
M(DUO9&5L;R`G)7,G(&[C;R!E;F-O;G1R861O+B(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z,38Y"FUS9VED(")496UP;&%T92!!9&UI;FES=')A=&EO;B(*
M;7-G<W1R(")!9&UI;FES=')AY^-O(&1E($UO9&5L;W,B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C$U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,S,S0*;7-G:60@(E1E>'0B"FUS9W-T<B`B5&5X=&\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S<Y"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`B
M4V]M96YT92!497AT;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T
M<B`B06QI;FAA;65N=&\@9&4@5&5X=&\B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"FUS9VED(")497AT=&]P(@IM<V=S
M='(@(D)O<F1A('-U<&5R:6]R(&1O(%1E>'1O(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T
M<B`B475I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@(E1H
M86D@*%1)4RTV,C`I(@IM<V=S='(@(E1A:6QA;F3J<R`H5$E3+38R,"DB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`Y"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R(")486ELXFYD
M:6$B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@U,0IM<V=I9"`B
M5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
M02!E>'1E;G/C;R!&5%`@;N-O(&5S=.$@9&ES<&]N[79E;"XB"@HC.B!F<F%M
M97=O<FLO2&ES=&]R>2](:7-T;W)Y+G!H<#HU-0IM<V=I9"`B5&AE($AI<W1O
M<GD@<WES=&5M(&ES(&1I<V%B;&5D+B(*;7-G<W1R(")/(&AI<W3S<FEC;R!D
M;R!S:7-T96UA(&5S=.$@9&5S86)I;&ET861O+B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.3,S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!(
M;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R
M="!<(B5S7"(B"FUS9W-T<B`B02!E;F=I;F4@9&4@:6YT96=R8>?C;R!(;W)D
M92]+;VQA8B!NXV\@<W5P;W)T82!<(B5S7"(B"@HC.B!F<F%M97=O<FLO3F5T
M7TE-4U`O24U34"]";V]K+G!H<#HQ,CDX"FUS9VED(")4:&4@24U34"!L;V<@
M8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R(")/(&QO9R!)35-0
M(&[C;R!P;V1E('-E<B!I;FEC:6%L:7IA9&\N(@H*(SH@<V5R=FEC97,O;6%I
M;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S
M<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(D$@8VQA<W-E
M(%PB36%I;G1E;F%N8V5<(B!NXV\@9F]I(&-A<G)E9V%D82!C;VT@<W5C97-S
M;R(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G
M:60@(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*
M;7-G<W1R(")!(&IA;F5L82!D92!/<.?U97,@9F]I(&9E8VAA9&$N(%-A:6YD
M;RXB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$X.2!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C(P,`HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C(Q,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(R,PHC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(S-"!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C(U,@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(V
M-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,P,PIM<V=I9"`B(@HB5&AE
M(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT
M(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E
M<FUI<W-I;VYS+B(*;7-G<W1R("(B"B)/(&%D;6EN:7-T<F%D;W(@<')E8VES
M82!C;VYF:6=U<F%R('5M(&-O;F5C=&]R('!E<FUA;F5N=&4@9&4@4&5R;6ES
M<_5E<R!S92`B"B)V;V/J('%U97(@=71I;&EZ87(@4&5R;6ES<_5E<RXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<U"FUS9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R(")3;VUE
M;G1E(&\@;&%D;R!D92!B86EX;R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C
M="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@
M=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*
M(D\@;OIM97)O($E$(&1O(&-O;G1A=&\@;N-O(&9O:2!E<W!E8VEF:6-A9&\L
M(&1E:7AA9&\@96T@8G)A;F-O(&]U(&[C;R!F;VD@(@HB96YC;VYT<F%D;R!N
M;R!B86YC;R!D92!D861O<RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z-3$*;7-G:60@(E1H92!C;VYT86-T('=A<R!S=6-C
M97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@
M(D\@8V]N=&%T;R!F;VD@861I8VEO;F%D;R!C;VT@<W5C97-S;R!A;R!S974@
M8V%TX6QO9V\@9&4@96YD97)EYV]S+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$Q-S(*;7-G:60@(B(*(E1H92!D971A8VAE9"!01U`@
M<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG
M;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*(E!A<F$@=F5R:69I8V%R(&$@;65N
M<V%G96T@87-S:6YA9&$@Z2!N96-E<W/A<FEO('5M(&)L;V-O('-E<&%R861O
M(&1A("(*(F%S<VEN871U<F$@4$=0+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES
M=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L
M969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM
M<V=S='(@(B(*(D\@240@9&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O(&[C;R!F
M;VD@97-P96-I9FEC861O+"!D96EX861O(&5M(&)R86YC;R!O=2!NXV\@(@HB
M9F]I(&5N8V]N=')A9&\@;F\@8F%N8V\@9&4@9&%D;W,N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*;7-G:60@
M(E1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"XB"FUS
M9W-T<B`B02!L:7-T82!D92!D:7-T<FEB=6GGXV\@;N-O(&9O:2!E<W!E8VEF
M:6-A9&$N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+G!H<#HQ,38*;7-G
M:60@(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@
M=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(D%S(&9U;N?U97,@9&4@8W)I<'1O
M9W)A9FEA(')E<75E<F5M('5M82!C;VYE>.-O('=E8B!S96=U<F$N(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S<@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HU,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@
M)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R(")/(&%R
M<75I=F\@)7,@9&5V97)I82!C;VYT97(@=6UA(&-O;F9I9W5R8>?C;R!D92`E
M<RXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W,"!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C4P.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+B(*
M;7-G<W1R(")/(&%R<75I=F\@)7,@9&5V97)I82!C;VYT97(@86QG=6UA<R!C
M;VYF:6=U<F'G]65S(&1E("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C(R-@IM<V=I9"`B5&AE(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O
M;G1O(&ET<V5L9BXB"FUS9W-T<B`B3R!A<G%U:79O(&[C;R!P;V1E('-E<B!C
M;W!I861O('!A<F$@96QE(&UE<VUO+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A
M=&$N<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N
M(@IM<V=S='(@(D\@87)Q=6EV;R!NXV\@8V]N=.EM(&1A9&]S+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@
M(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A
M9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(E-E9W5E;2!O<R!C86)EYV%L
M:&]S(&1E<W1A(&UE;G-A9V5M+VUE;G-A9V5M(')F8S@R,BXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4V"FUS9VED("(B
M"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B
M;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E
M<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9
M;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E(&1I<W!L87DL(&QA8VL@
M;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A
M<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V
M97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"`B"B)0<F]T
M96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA
M=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U('-T
M:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S
M='(@(B(*(LD@<V%B:61O('%U92!O(&UO9&\@=&5L82!C:&5I82!C875S82!P
M<F]B;&5M87,@8V]M(&\@26YT97)N970@17AP;&]R97(L(&5M("(*(G9I<G1U
M9&4@9&4@8G5G<R!D;R!N879E9V%D;W(@<75E(&[S<R!NXV\@97-T86UO<R!A
M<'1O<R!A(&-O;G1O<FYA<BX@5F]CZB`B"B)P;V1E(&]B<V5R=F%R(&5R<F]S
M(&1E(&5X:6)IY^-O+"!F86QT82!D92!F=6[G]65S(&1O(&5D:71O<B!E+V]U
M('1R879A;65N=&]S("(*(F%L96%T\W)I;W,@9&\@;F%V96=A9&]R+B!392!S
M974@<VES=&5M82#I(%=I;F1O=W,@.7@@Z2!M=6ET;R!P<F]VX79E;"!Q=64@
M(@HB=F]CZB!R96-E8F$@=6T@97)R;R!D92`G1F%L:&$@1V5R86P@9&4@4')O
M=&7GXV\G(&4@<')E8VES87+A(')E:6YI8VEA<BX@7%QN(@HB7%QN(%9O8^H@
M9F]I(&%V:7-A9&\N(%!O<B!F879O<B!P<F5S<VEO;F4@3TL@<V4@=F]CZB!A
M:6YD82!Q=65R('1E;G1A<B!U<V%R("(*(F\@961I=&]R(&1E('1E;&$@8VAE
M:6$N(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C$P-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N
M(@IM<V=S='(@(D$@:61E;G1I9&%D92!<(B5S7"(@9F]I(&5X8VQU[61A+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S8*;7-G:60@(E1H92!L969T+6AA;F0@<VED92!O;FQY(@IM<V=S='(@
M(E-O;65N=&4@;R!L861O(&5S<75E<F1O(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@
M=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P
M9W`Z.B!C;&%S<RXB"FUS9W-T<B`B(@HB02!L;V-A;&EZ8>?C;R!D;R!B:6[A
M<FEO(&1O($=N=5!'(&1E=F4@<V5R(&9O<FYE8VED82#@(&-L87-S92!<(D-R
M>7!T7W!G<%PB+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HR
M,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O
M;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L
M87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A
M9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"B)!
M(&UE;G-A9V5M(&5N=FEA9&$@96T@)7,@<&%R82`E<R!C;VT@;R!A<W-U;G1O
M(%PB)7-<(B!F;VD@97AI8FED82Y<;B(*(DES=&\@;N-O(&=A<F%N=&4@<75E
M(&$@;65N<V%G96T@9F]I(&QI9&$@;W4@96YT96YD:61A+B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X.#$*;7-G:60@(E1H92!N86UE('1O('5S
M92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R(")/
M(&YO;64@=71I;&EZ861O(&%O('9I;F-U;&%R(&$@<.%G:6YA(&1E(&-O;7!O
M<VGGXV\B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-S0*;7-G
M:60@(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS
M9W-T<B`B3R!N^FUE<F\@9&4@8V%M<&]S(&1E=F4@<V5R(&YU;>ER:6-O+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(S,@IM<V=I
M9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R
M9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B3R!M\V1U;&\@;W!E
M;G-S;"#I(&]B<FEG873S<FEO('!A<F$@82!C;&%S<V4@7")(;W)D95]#<GEP
M=%]S;6EM95PB+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,C@S
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<
M(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E
M9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"B)!
M('!R969E<NIN8VEA(%PB)7-<(B!NXV\@<&]D92!S97(@<V%L=F$@<&]R<75E
M('-E=7,@9&%D;W,@97AC961E<F%M(&\@(@HB=&%M86YH;R!MX7AI;6\@<&5R
M;6ET:61O(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O9&5B+G!H
M<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]E;G-C<FEP="YP
M:'`Z,S4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-P;W=E<G!O
M:6YT+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O
M<F0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)P;2YP
M:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=V5B8W!P+G!H
M<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]S<F-H:6=H;&ET
M92YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-E>&-E
M;"YP:'`Z,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@
M=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N
M9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R("(B"B)/('!R;V=R86UA('5T:6QI
M>F%D;R!P87)A('9I<W5A;&EZ87(@97-T92!T:7!O(&1E(&1A9&\@*"5S*2!N
MXV\@9F]I("(*(F5N8V]N=')A9&\@;F\@<VES=&5M82XB"@HC.B!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HT.#<*;7-G:60@(E1H92!Q=6]T92!C:&%R
M86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B
M3R!C87)A8W1E<F4@<&%R82!C:71AY^-O(&1E('-E<B!A<&5N87,@=6TN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'DB"FUS
M9W-T<B`B4V]M96YT92!O<R!L861O<R!D:7)E:71O(&4@97-Q=65R9&\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B
M4V]M96YT92!O(&QA9&\@9&ER96ET;R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C0W.0IM<V=I9"`B5&AE('-E<&%R871O<B!M=7-T(&)E(&]N
M92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R(")/('-E<&%R861O<B!D979E
M('-E<B!U;2#Z;FEC;R!C87)A8W1E<F4N(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E
M<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B3R!S97)V:61O
M<B!<(B5S7"(@9F]I(&5X8VQU[61O+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R
M<&-S=6TN<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@
M7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R(")/('-E<G9I9&]R(%PB
M)7-<(B!F;VD@<V%L=F\N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S
M(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B02!S;VQI8VET8>?C;R!D92!C861A
M<W1R;R!D92`E<R!F;VD@97AC;'7M9&$N(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT-S`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES="XB
M"FUS9W-T<B`B02!L:6YH82!E<W!E8VEF:6-A9&$@*"5D*2!NXV\@97AI<W1E
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3<Y"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!T96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N
M;W0@97AI<W0N(@IM<V=S='(@(D\@87)Q=6EV;R!T96UP;W+A<FEO(%PB)7-<
M(B!NXV\@97AI<W1E+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S
M,#D*;7-G:60@(E1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@
M=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS9W-T<B`B3R!T97AT;R!Q=64@
M=F]CZB!D:6=I=&]U(&[C;R!C;W)R97-P;VYD92!A;R!T97AT;R!N82!T96QA
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY
M(@IM<V=S='(@(E-O;65N=&4@;W,@;&%D;W,@9&4@8VEM82!E(&1E(&)A:7AO
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B4V]M
M96YT92!O(&QA9&\@9&4@8VEM82(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N
M<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN
M8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@(D]S(&1A9&]S(&5N=FEA
M9&]S(&9O<F%M('!E<F1I9&]S(&1E<V1E(&\@<&%S<V\@86YT97)I;W(N(@H*
M(SH@9G)A;65W;W)K+T1A=&$O1&%T82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO
M1&%T82]$871A+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@=7!L;V%D960@9FEL
M92!C;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(D\@87)Q=6EV;R!E;G9I
M861O(&[C;R!P]&1E('-E<B!S86QV;RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-#D@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q
M,`IM<V=I9"`B5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B
M;&4N(@IM<V=S='(@(D\@8FQO8V\@7")W96%T:&5R+F-O;5PB(&[C;R!E<W3A
M(&1I<W!O;NUV96PN(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO
M="!F;W5N9"XB"FUS9W-T<B`B3R!D:7)E=/-R:6\@9&4@=&5M87,@)R5S)R!N
MXV\@9F]I(&5N8V]N=')A9&\N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HQ-S@*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL
M86)L92XB"FUS9W-T<B`B3N-O(&5X:7-T96T@;W#G]65S(&1I<W!O;NUV96ES
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C,T.0IM
M<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE
M9"!I;FQI;F4N(@IM<V=S='(@(D[C;R!E>&ES=&5M('!A<G1E<R!Q=64@<&]S
M<V%M('-E<B!E>&EB:61A<R!I;F-O<G!O<F%D87,N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30P-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9
M;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[("(*(GEO=2!M=7-T(&5N
M=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@HB17AI<W1E;2!M=6ET;W,@
M8V%R86-T97)E<R!N97-T92!C86UP;RX@5F]CZB!P<F5E;F-H974@8V]M("5S
M(&-A<F%C=&5R97,[("(*(G9O8^H@9&5V92!P<F5E;F-H97(@8V]M("5S(&]U
M(&UE;F]S+B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I
M;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@(DAO=79E('5M
M('!R;V)L96UA(&%D:6-I;VYA;F1O("<E<R<@86\@<VES=&5M83H@)7,B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R(%PB)7-<
M(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R(")(;W5V92!U;2!P<F]B;&5M
M82!A;R!E>&-L=6ER(&1O('-I<W1E;6$@;W,@9&%D;W,@9&\@=7-UX7)I;R`G
M)7,G.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O
M;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B2&]U=F4@=6T@<')O8FQE;6$@86\@
M97AC;'5I<B`G)7,G(&1O('-I<W1E;6$Z("(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$U.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M
M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]U=F4@=6T@<')O8FQE
M;6$@86\@871U86QI>F%R("<E<R<Z("5S(@H*(SH@9G)A;65W;W)K+T)R;W=S
M97(O0G)O=W-E<BYP:'`Z.3$P"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A
M<R!U<&QO861E9"XB"FUS9W-T<B`B2&]U=F4@=6T@<')O8FQE;6$@8V]M(&\@
M96YV:6\@9&\@87)Q=6EV;SH@3F5N:'5M("5S(&9O:2!E;G9I861O+B(*"B,Z
M(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDQ-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I
M;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M
M("(*(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B"B)(;W5V
M92!U;2!P<F]B;&5M82!C;VT@;R!E;G9I;R!D;R!A<G%U:79O+B!/("5S(&5R
M82!M86EO<B!Q=64@;R!T86UA;FAO("(*(FWA>&EM;R!P97)M:71I9&\@*"5D
M(&)Y=&5S*2XB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY
M,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE
M;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I
M86QL>2!U<&QO861E9"XB"FUS9W-T<B`B(@HB2&]U=F4@=6T@<')O8FQE;6$@
M8V]M(&\@96YV:6\@9&\@87)Q=6EV;RX@3R`E<R!F;VD@96YV:6%D;R!P87)C
M:6%L;65N=&4N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C
M.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI
M;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B2&]U=F4@=6T@97)R;R!A
M;R!E>&EB:7(@97-T82!P87)T92!D82!M96YS86=E;2(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.0HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T
M<B`B2&]U=F4@=6T@97)R;R!A;R!I;7!O<G1A<B!O<R!D861O<R!D;R!C;VYT
M871O+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS,0IM<V=I
M9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R
M(&1A=&$N(@IM<V=S='(@(DAO=79E('5M(&5R<F\@86\@:6UP;W)T87(@;W,@
M9&%D;W,@9&\@:4-A;&5N9&%R+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z.#(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N
M9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A("(*(G)E
M<75I<F5D(&9I96QD+B(*;7-G<W1R("(B"B)(;W5V92!U;2!E<G)O(&YO(&9O
M<FUU;.%R:6\@9&4@8V]N9FEG=7)AY^-O+B!486QV97H@=F]CZB!D96EX;W4@
M=6T@8V%M<&\@(@HB;V)R:6=A=/-R:6\@96T@8G)A;F-O+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X"FUS9VED
M("(B"B)4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF
M:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I
M;B!L871E<BXB"FUS9W-T<B`B(@HB2&]U=F4@=6T@97)R;R!A;R!E>&5C=71A
M<B!A(&9U;N?C;R!D92!C873A;&]G;R!D92!E;F1E<F7G;W,@97-P96-I9FEC
M861A+B`B"B)0;W(@9F%V;W(@=&5N=&4@;F]V86UE;G1E(&UA:7,@=&%R9&4N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T
M:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*
M;7-G<W1R("(B"B)(;W5V92!U;2!E<G)O(&%O(&%T=6%L:7IA<B!O<R!D971A
M;&AE<R!D;R!C;VYT871O+B!0;W(@9F%V;W(@=&5N=&4@;F]V86UE;G1E("(*
M(FUA:7,@=&%R9&4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HR,C(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U
M<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A
M:6X@;&%T97(N(@IM<V=S='(@(B(*(DAO=79E('5M(&5R<F\@86\@871U86QI
M>F%R(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O+B!0;W(@9F%V;W(@=&5N=&4@
M(@HB;F]V86UE;G1E(&UA:7,@=&%R9&4N(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS9VED(")4:&ES($E-05`@<V5R
M=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R
M(")%<W1E('-E<G9I9&]R($E-05`@;N-O('-U<&]R=&$@<&%S=&%S(&-O;7!A
M<G1I;&AA9&%S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@
M=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(D5S=&4@;N-O('!A<F5C92!S
M97(@=6T@87)Q=6EV;R!R87(@=N%L:61O+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@
M87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(D5S=&4@
M;N-O('!A<F5C92!S97(@=6T@87)Q=6EV;R!Z:7`@=N%L:61O+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,S0*;7-G:60@(E1H:7,@9&]E<R!N
M;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R(")%
M<W1E(&[C;R!P87)E8V4@<V5R('5M(&[Z;65R;R!D92!C87)TXV\@=N%L:61O
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*
M(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB
M"FUS9W-T<B`B(@HB17-T92!C;VYE8W1O<B!P97)M:71E(&5N=FEA<B!M96YS
M86=E;G,@871R87;I<R!D;R!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA
M=&5L;"YC;VTI+"!U=&EL:7IA;F1O(&$@05!)($A45%`B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S-`IM<V=I9"`B(@HB5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T
M:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@(@HB9V%T97=A>2P@=7-I;F<@
M=&AE($A45%`@05!)(@IM<V=S='(@(B(*(D5S=&4@8V]N96-T;W(@<&5R;6ET
M92!E;G9I87(@;65N<V%G96YS(&%T<F%VZ7,@9&\@9V%T97=A>2!S;7,R96UA
M:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2P@=71I;&EZ86YD;R!O($%0
M22!(5%10(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU,34*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO
M+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%0
M22(*;7-G<W1R("(B"B)%<W1E(&-O;F5C=&]R('!E<FUI=&4@96YV:6%R(&UE
M;G-A9V5N<R!A=')A=NES(&1O(&=A=&5W87D@<VUS,F5M86EL("AH='1P.B\O
M(@HB<VUS,F5M86EL+F-O;2DL('5T:6QI>F%N9&\@;R!!4$D@2%144"(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP
M.C@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B
M"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I
M<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H
M:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"B)%<W1E(&-O;F5C=&]R
M('!E<FUI=&4@96YV:6%R('5M82!M96YS86=E;2!V:6$@4TU44"!A=')A=NES
M(&1O(%9O9&%F;VYE("(*(DET86QI86YO+"!S;VUE;G1E('!A<F$@;OIM97)O
M<R!6;V1A9F]N92X@R2!O8G)I9V%T\W)I;R!P;W-S=6ER('5M82!C;VYT82!N
M;R`B"B)6;V1A9F]N92!)=&%L:6%N;R`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDX,B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,#8Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P
M.3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Q.0HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,3@V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M-C`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P.2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#`R"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$U-C$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@T,PHC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.38R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(P,#D*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`S,R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,#@R"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q-3,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(R-0HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$R(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(T-30*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8T-"!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$W"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,Q,C8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,P-`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#$R(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,X,C`*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM
M<V=S='(@(D5S=&4@8V%M<&\@Z2!O8G)I9V%T\W)I;RXB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,#8Y"FUS9VED(")4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@(D5S=&4@8V%M<&\@<&]D
M92!C;VYT97(@87!E;F%S(&[Z;65R;W,@:6YT96ER;W,N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C0R,`IM<V=I9"`B5&AI<R!F:65L9"!M87D@
M;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BXB"FUS9W-T<B`B
M17-T92!C86UP;R!P;V1E(&-O;G1E<B!A<&5N87,@;OIM97)O<R!E(';M<F=U
M;&$N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`Y.`IM<V=I9"`B
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS
M9W-T<B`B17-T92!C86UP;R!P;V1E(&-O;G1E<B!A<&5N87,@=F%L;W)E<R!O
M8W1A:7,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$R-PIM<V=I
M9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A
M=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T<B`B(@HB17-T92!C86UP;R!D
M979E('-E<B!U;6$@;&ES=&$@9&4@;OIM97)O<R!I;G1E:7)O<R!S97!A<F%D
M82!P;W(@=NUR9W5L87,@;W4@(@HB97-P8>=O<R(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.CDY,PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@
M=F%L:60@;G5M8F5R+B(*;7-G<W1R(")%<W1E(&-A;7!O(&1E=F4@<V5R('5M
M(&[Z;65R;R!VX6QI9&\N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C@R-0IM<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO
M<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB
M)R,Q,C,T868G+B(*;7-G<W1R("(B"B)%<W1E(&-A;7!O(&1E=F4@8V]N=&5R
M('5M(&/S9&EG;R!D92!C;W(@96T@9F]R;6%T;R!21T(@2&5X82P@<&]R(&5X
M96UP;&\@(@HB)R,Q,C,T868G+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C4V-0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O
M8V5S<V5D+B(*;7-G<W1R(")%<W1E(&9O<FUU;.%R:6\@:N$@9F]I('!R;V-E
M<W-A9&\N(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B27-T;R#I("5S
M+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#4Y"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J
M96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA
M:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P
M=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE
M;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R("(B"B)%<W1E(.D@=6T@;V)J
M971O($MO;&%B($=R;W5P=V%R92X@4&%R82!V:7-U86QI>F%R(&5S=&4@;V)J
M971O('9O8^H@<')E8VES87+A("(*(F1E('5M(&-L:65N=&4@9&4@8V]R<F5I
M;R!Q=64@96YT96YD82!O(&9O<FUA=&\@2V]L86(@1W)O=7!W87)E+B!087)A
M('5M82`B"B)L:7-T82!D92!C;&EE;G1E<R!D92!C;W)R96EO(&-O;2!E<W1A
M<R!F=6[G]65S('!O<B!F879O<B!V:7-I=&4@)7,B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E
M="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(B(*(D5S=&$@
M;65N<V%G96T@9F]I(&5S8W)I=&$@96T@=6T@8V]N:G5N=&\@9&4@8V%R86-T
M97)E<R`H)7,I('%U92!NXV\@Z2!O("(*(FUE<VUO('%U92!O('-E=2XB"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI
M<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(D5S=&4@
M;OIM97)O(&1E=F4@<V5R('!E;&\@;65N;W,@=6TN(@H*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E
M<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS
M9W-T<B`B17-T92!S97)V:61O<B!NXV\@<&]D92!D97-C;VUP<FEM:7(@87)Q
M=6EV;W,@>FEP(&4@9WII<"XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M4F5G:7-T<GDN<&AP.C$X.0IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N
M=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R(")%<W1E('-I<W1E;6$@97-TX2!A
M='5A;&UE;G1E(&1E<V%T:79A9&\N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@;75S="!B92!A(&YU
M;6)E<BXB"FUS9W-T<B`B17-T92!V86QO<B!D979E('-E<B!U;2!N^FUE<F\N
M(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM<V=I
M9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS
M('=I;F1O=R(*;7-G<W1R(")%<W1A(&IA;F5L82!D979E('-E<B!C:&%M861A
M(&$@<&%R=&ER(&1A(&IA;F5L82!D92!/<.?U97,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B5&AU;F1E<B(*
M;7-G<W1R(")286EO(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S
M-@IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R(")":6QH971E<R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(T,CD@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C4U"FUS9VED(")4:6UE(@IM<V=S='(@(DAO<F$B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@X"FUS9VED(")4:6UE(%1R86-K:6YG
M(@IM<V=S='(@(D%C;VUP86YH86UE;G1O(&1E($AO<N%R:6\B"@HC.B!L:6(O
M0FQO8VLO=&EM92YP:'`Z,3<*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@
M(D9O<FUA=&\@9&4@:&]R82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(U,S4*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@(E-E;&7GXV\@
M9&4@:&]R82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM
M<V=S='(@(E1I;6]R($QE<W1E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM
M<V=I9"`B5&ET;&4B"FUS9W-T<B`B5.UT=6QO(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O
M;VQT:7`I.B(*;7-G<W1R(")!<W-U;G1O("AD:6-A*3HB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED(")4;R(*
M;7-G<W1R(")087)A(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C8U,@IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET
M96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-
M86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B(@HB4&%R82!S
M96QE8VEO;F%R(&WZ;'1I<&QO<R#M=&5N<RP@<V5G=7)E(&$@=&5C;&$@0V]N
M=')O;"`H4$,I(&]U($-O;6UA;F0@(@HB*$UA8RD@86\@8VQI8V%R+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`*;7-G:60@(E1O9&%Y
M(@IM<V=S='(@(DAO:F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS
M9W-T<B`B5')O8V%R('!A<F$@8_-D:6=O($A434PB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y
M"FUS9VED(")4;V=O(@IM<V=S='(@(E1O9V\B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS
M9VED(")4;VME;&%U(@IM<V=S='(@(E1O:V5L874B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S`R"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R
M(")!;6%N:.,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G<W1R
M(")4;VYG82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW-PIM<V=I9"`B5&]P(@IM<V=S='(@(E1O<&\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED
M(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@(E%U861R;R!D;R!4;W!O("A?
M=&]P*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I9"`B5')A
M;G-L871I;VYS(@IM<V=S='(@(E1R861UY_5E<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*
M;7-G:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B5')I;F1A9&4@
M92!4;V)A9V\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-SDT"FUS
M9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@(E9E<F1A9&5I<F\@;W4@9F%L
M<V\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C4W"FUS9VED(")4=2(*;7-G<W1R(")497(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS
M9VED(")4=6YI<VEA(@IM<V=S='(@(E1U;NUS:6$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q
M"FUS9VED(")4=7)K97DB"FUS9W-T<B`B5'5R<75I82(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DQ"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY*2(*
M;7-G<W1R(")4=7)C;R`H25-/+3@X-3DM.2DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS
M9VED(")4=7)K;65N:7-T86XB"FUS9W-T<B`B5'5R8V]M96YI<W3C;R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*
M;7-G<W1R("));&AA<R!4=7)K<R!E($-A:6-O<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*
M;7-G:60@(E1U=F%L=2(*;7-G<W1R(")4=79A;'4B"@HC.B!F<F%M97=O<FLO
M0TQ)+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS
M9W-T<B`B4')E96YC:&$@8V]M('-U82!E<V-O;&AA.B`B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4X"FUS9VED(")5+E8N(&EN9&5X.B`B
M"FUS9W-T<B`BS6YD:6-E(%4N5BXZ("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M92YP:'`Z
M,3<*;7-G:60@(E523"(*;7-G<W1R(")54DPB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T,0IM<V=I9"`B55),(&9O
M<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S='(@
M(E523"!D;R!S974@<F5L873S<FEO(&1E('-I='5AY^-O(&1E(&5N=')E9V$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW
M"FUS9VED(")54DPZ(@IM<V=S='(@(E523#HB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS
M9VED(")59V%N9&$B"FUS9W-T<B`B56=A;F1A(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM
M<V=I9"`B56MR86EN92(*;7-G<W1R(")58W+B;FEA(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z-#$Y"FUS9VED(")5;F%B;&4@=&\@86-C97-S
M(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DEM<&]S<^UV96P@86-E<W-A<B!D
M:7)E=/-R:6\@5D93+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P
M+G!H<#HY-@IM<V=I9"`B56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R
M;6%T:6]N('=H96X@<VEG;FEN9R!U<"XB"FUS9W-T<B`B26UP;W-S[79E;"!A
M9&EC:6]N87(@:6YF;W)M8>?U97,@97AT<F%S(&1E('5S=>%R:6\@86\@<F5G
M:7-T<F%R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,SDS"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO
M;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("));7!O<W/M=F5L(&%L
M=&5R87(@<&5R;6ES<^-O(&1O(&%R<75I=F\@5D93(%PB)7-<(BXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS.3(@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G
M<W1R("));7!O<W/M=F5L(&%L=&5R87(@<&5R;6ES<^-O(&1O(&%R<75I=F\@
M5D93("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S@V
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N
M(@IM<V=S='(@(DEM<&]S<^UV96P@86QT97)A<B!P87)A("5S+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C,W"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<UPB+B(*;7-G
M<W1R("));7!O<W/M=F5L('9E<FEF:6-A<B!O('1A;6%N:&\@9&\@87)Q=6EV
M;R!D92!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M-CDU(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3`R.`HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z.#4P"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB+B(*
M;7-G<W1R("));7!O<W/M=F5L('9E<FEF:6-A<B!O('1A;6%N:&\@9&\@87)Q
M=6EV;R!D92!<(B5S+R5S7"(N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S
M<6PN<&AP.C0S.0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E
M<G9E<BXB"FUS9W-T<B`B26UP;W-S[79E;"!C;VYE8W1A<B!A;R!S97)V:61O
M<B!344PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-S`*;7-G
M:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R("));7!O
M<W/M=F5L(&-O;F5C=&%R('5T:6QI>F%N9&\@4U-,+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(S,B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HR,S<*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P
M-"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,3<*;7-G:60@(E5N86)L92!T
M;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R("));7!O<W/M=F5L(&-O<&EA<B!A
M<G%U:79O(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,W
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D
M:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("));7!O<W/M=F5L(&-R:6%R(&1I
M<F5T\W)I;R!61E,@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C,V,2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C4X"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR-C0*;7-G:60@(E5N
M86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B26UP;W-S
M[79E;"!C<FEA<B!D:7)E=/-R:6\@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HQ,C0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93
M(&9I;&4N(@IM<V=S='(@(DEM<&]S<^UV96P@8W)I87(@87)Q=6EV;R!61E,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR.3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R(%PB)7-<
M(BXB"FUS9W-T<B`B26UP;W-S[79E;"!R96YO;65A<B!A<G%U:79O(%9&4R!<
M(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C<R"FUS
M9VED(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R
M("));7!O<W/M=F5L(&-R:6%R(&%R<75I=F\@5D93('9A>FEO+B(*"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N<&AP.C<V"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HW.0IM<V=I9"`B56YA
M8FQE('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B26UP;W-S[79E;"!D
M97-C;VUP<FEM:7(@9&%D;W,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HR,C@@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,#,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D
M:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R("));7!O<W/M=F5L(&5X
M8VQU:7(@7"(E<UPB+"!O(&1I<F5T\W)I;R!NXV\@97-TX2!V87II;RXB"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z
M-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S
M7"(Z("5S+B(*;7-G<W1R("));7!O<W/M=F5L(&5X8VQU:7(@7"(E<UPB.B`E
M<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S@@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HS.34*(SH@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C,Q,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,S0R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L
M('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(DEM<&]S<^UV
M96P@97AC;'5I<B`E<RP@;R!D:7)E=/-R:6\@;N-O(&5S=.$@=F%Z:6\B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4V(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-C`*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B26UP
M;W-S[79E;"!E>&-L=6ER(')E8W5R<VEV86UE;G1E(&\@9&ER973S<FEO(%9&
M4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-#0@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C,R,@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,S,U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS
M-#,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,U,@IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("))
M;7!O<W/M=F5L(&5X8VQU:7(@9&ER973S<FEO(%9&4RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C0R,"!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C0S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("));7!O<W/M=F5L(&5X8VQU
M:7(@9&ER973S<FEO(%9&4SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HR,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<^UV96P@97AC
M;'5I<B!A<G%U:79O(%9&4R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,S$P(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,CDQ
M"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ-C<@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C$X,`HC.B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,3@W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS
M.3$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,Y.0IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS9W-T<B`B26UP;W-S
M[79E;"!E>&-L=6ER(&%R<75I=F\@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z,C0X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<^UV
M96P@97AC;'5I<B!A<G%U:79O(%9&4R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HT,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R("))
M;7!O<W/M=F5L(&5X8VQU:7(@5D93(')E8W5R<VEV86UE;G1E.B`E<RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S-`IM<V=I9"`B56YA8FQE
M('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`B26UP
M;W-S[79E;"!D971E<FUI;F%R(&\@9&ER973S<FEO(&%T=6%L+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C`T"FUS9VED(")5;F%B
M;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM<V=S='(@(DEM
M<&]S<^UV96P@97AT<F%I<B!D971A;&AE<R!D;R!C97)T:69I8V%D;R(*"B,Z
M(&9R86UE=V]R:R].971?24U34"])35-0+G!H<#HT,S<@9G)A;65W;W)K+TYE
M=%])35-0+TE-4U`O075T:"YP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R
M("));7!O<W/M=F5L(&-A<G)E9V%R(&$@9&5F:6YIY^-O(&1E("5S+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P,R!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HR,#@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C$W-"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3<Y
M"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB"FUS9W-T<B`B26UP
M;W-S[79E;"!M;W9E<B!O(&%R<75I=F\@5D93+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z.3,@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ
M,#8*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HV-3(@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HY.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<^UV
M96P@86)R:7(@87)Q=6EV;R!61E,@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C(X-"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,3,X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ
M-#$*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG
M+B(*;7-G<W1R("));7!O<W/M=F5L(&%B<FER(&%R<75I=F\@5D93('!A<F$@
M9W)A=F'GXV\N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z.#,@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3,W"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HW-@IM<V=I9"`B56YA8FQE('1O(&]P96X@
M5D93(&9I;&4N(@IM<V=S='(@(DEM<&]S<^UV96P@86)R:7(@87)Q=6EV;R!6
M1E,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HT
M-0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*
M;7-G<W1R("));7!O<W/M=F5L(&%B<FER(&%R<75I=F\@8V]M<')I;6ED;RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#4V"FUS9VED(")5;F%B;&4@
M=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+B(*;7-G<W1R
M("));7!O<W/M=F5L(&QE<B!A<G%U:79O(%9&4R`H9FEL97-I>F4H*2!F86QH
M;W4I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX.#<*;7-G:60@(E5N
M86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN
M(@IM<V=S='(@(DEM<&]S<^UV96P@;&5R(&%R<75I=F\@5D93("AG971&:6QE
M4VEZ92@I(&9A;&AO=2DN(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R
M+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"FUS9VED(")5;F%B;&4@=&\@
M<F5A9"!F:6QE.B`B"FUS9W-T<B`B26UP;W-S[79E;"!L97(@;R!A<G%U:79O
M.B`B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV-S8*;7-G:60@
M(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B26UP;W-S[79E;"!L97(@82!R86EZ(&1O(&1I<F5T\W)I;R!61E,N(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3`T"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T
M:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*;7-G<W1R("));7!O<W/M=F5L
M(')E;F]M96%R("5S('!A<F$@)7,Z(&$@<&%S=&$@9&4@9&5S=&EN;R!JX2!E
M>&ES=&4B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q
M"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(DEM<&]S<^UV96P@<F5N;VUE87(@;R!D:7)E=/-R:6\@5D93+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S,R"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM
M<V=S='(@(DEM<&]S<^UV96P@<F5N;VUE87(@9&ER973S<FEO(%9&4SH@)7,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-S$@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HS-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(')E;F%M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DEM<&]S
M<^UV96P@<F5N;VUE87(@87)Q=6EV;R!61E,@7"(E<UPB+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C8Q-R!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(DEM<&]S<^UV96P@<F5N
M;VUE87(@87)Q=6EV;R!61E,@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HS,C8@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(Q
M,PHC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#4R(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.3,*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,P.0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!6
M1E,@9FEL92XB"FUS9W-T<B`B26UP;W-S[79E;"!R96YO;65A<B!A<G%U:79O
M(%9&4RXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M;6MI<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G
M+B(*;7-G<W1R("));7!O<W/M=F5L(&5X96-U=&%R("=M:VES;V9S)RXB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS
M9VED(")5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N="(*
M;7-G<W1R("));7!O<W/M=F5L('1R861U>FER(&5S=&4@9&]C=6UE;G1O(%=O
M<F0B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$U-"!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C$U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("));7!O
M<W/M=F5L(&=R879A<B!A<G%U:79O(%9&4R!<(B5S7"(N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,3@V"FUS9VED(")5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R("));7!O<W/M
M=F5L(&=R879A<B!A<G%U:79O(%9&4R`H8V]P>2@I(&9A;&AO=2DN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@X(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HQ-#8*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C$U,0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M(&1A=&$N(@IM<V=S='(@(DEM<&]S<^UV96P@9W)A=F%R(&1A9&]S(&1O(&%R
M<75I=F\@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-C(*;7-G
M:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E
M>&-E961E9"XB"FUS9W-T<B`B26UP;W-S[79E;"!G<F%V87(@87)Q=6EV;R!6
M1E,L('%U;W1A(&5X8V5D97+A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`*;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R
M(")3=6)L:6YH861O(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM
M<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(D1E<V9A>F5R($%L=&5R8>?U
M97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R(")$
M97-F87H@<W5A(/IL=&EM82!AY^-O(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,Y,`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS
M92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`B4F5S<&]S
M=&$@:6YE<W!E<F%D82!D;R!S97)V:61O<B!D=7)A;G1E(&$@8V]N97CC;SH@
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,0HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S@*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@T"FUS9VED
M(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T
M<B`B4F5S<&]S=&$@:6YE<W!E<F%D82!D;R!S97)V:61O<B!P87)A.B`B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU
M-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV
M,0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R(")396T@8V%T96=O<FEA(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(E5N:6-O9&4@*%541BTX
M*2(*;7-G<W1R(")5;FEC;V1E("A55$8M."DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I
M9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B16UI<F%D;W,@P7)A
M8F5S(%5N:61O<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI;F=D
M;VTB"FUS9W-T<B`B4F5I;F\@56YI9&\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED
M(")5;FET960@4W1A=&5S(@IM<V=S='(@(D5S=&%D;W,@56YI9&]S(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,SD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN
M9R!)<VQA;F1S(@IM<V=S='(@(DEL:&%S(%!E<FEFZ7)I8V%S($UE;F]R97,@
M9&]S($5S=&%D;W,@56YI9&]S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C8R(&QI8B]";&]C:R]M971A<BYP:'`Z-S@*;7-G:60@(E5N:71S
M(@IM<V=S='(@(E5N:61A9&5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#(Y(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0S
M,`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C4X"FUS
M9VED(")5;FMN;W=N(@IM<V=S='(@(D1E<V-O;FAE8VED;R(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I
M9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*;7-G<W1R
M(")A<&EM<V=I9"!D97-C;VYH96-I9&\@*$%022!-97-S86=E($E$*2XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3D*;7-G:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$
M*2XB"FUS9W-T<B`B8VQI;7-G:60@9&5S8V]N:&5C:61O("A#;&EE;G0@365S
M<V%G92!)1"DN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T
M-PIM<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B
M3F5N:'5M82!L;V-A;&EZ8>?C;R!C;VYF:6=U<F%D82XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*;7-G:60@
M(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S='(@(E5S=>%R
M:6\@;W4@<V5N:&$@9&5S8V]N:&5C:61O<RXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@(E5N
M;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(D1E<W9I;F-U;&%R
M(&\@96QE;65N=&\@871U86PB"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E
M;G1I='DN<&AP.C,P,@IM<V=I9"`B56YN86UE9"(*;7-G<W1R(")396T@3F]M
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-3D*;7-G:60@(B(*(E5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E
M<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U
M<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO
M=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A
M;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T
M<B`B(@HB4V-R:7!T<R!NXV\@<')I=FEL96=I861O<R!NXV\@<&]D96T@=71I
M;&EZ87(@0V]R=&%R+T-O<&EA<B]#;VQA<B!P;W(@<F%Z]65S("(*(F1E('-E
M9W5R86[G82X@0VQI<75E(&5M($]+('!A<F$@=F5R(&$@;F]T82!TZ6-N:6-A
M(&5M(&UO>FEL;&$N;W)G(&$@<75A;"`B"B)E;G-I;F$@8V]M;R!P97)M:71I
M<B!S8W)I<'1S(&%C97-S87)E;2!A(.%R96$@9&4@=')A;G-F97+J;F-I82XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@R"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R(")$97-M87)C87(@
M8V]R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#<@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,C<*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,S,*;7-G:60@(E5N<W5P<&]R
M=&5D($5X=&5N<VEO;B(*;7-G<W1R(")%>'1E;G/C;R!.XV\@4W5P;W)T861A
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ.3<@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P9&%T92(*;7-G
M<W1R(")!='5A;&EZ87(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G
M<W1R("(E<R!A='5A;&EZ861O(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHW-@IM<V=I9"`B57!D871E('5S97(B"FUS9W-T<B`B071U
M86QI>F%R('5S=>%R:6\B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$T-"!A9&UI
M;B]P97)M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP
M.C(S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS
M9W-T<B`B)R5S)R!A='5A;&EZ861O+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C@S"FUS9VED(")5<&=R861E('-C<FEP="!D96QE=&5D+B(*;7-G
M<W1R(")38W)I<'0@9&4@871U86QI>F'GXV\@<F5M;W9I9&\N(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$W."!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3DX"FUS9VED(")5<&QO860B"FUS9W-T<B`B16YV
M:6%R(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X-@IM<V=I9"`B57!L
M;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V
M97(N(@IM<V=S='(@(B(*(E1O9&]S(&%R<75I=F]S(&1E("!C;VYF:6=U<F'G
M]65S(&1A<R!A<&QI8V'G]65S(&9O<F%M(&5N=FEA9&]S(&%O('-E<G9I9&]R
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T
M<B`B06QF86)E=&\@;&%T:6YO(&5M(&UA:?IS8W5L;R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G
M:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B3OIM97)O<R!R;VUA
M;F]S(&5M(&UA:?IS8W5L;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U
M87DB"FUS9W-T<B`B57)U9W5A:2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@
M(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R(")5=&EL:7IA<B!!='5A;#H@)7,B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4S.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R(")5=&EL:7IA<B!34TPB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(W"FUS9VED(")5<V4@:68@;F%M
M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G
M<W1R(")5=&EL:7IA<B!S92!O(&YO;64O<V5N:&$@Z2!D:69E<F5N=&4@;F\@
M<V5R=FED;W(@24U34"XB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D
M:70N:6YC.C(Q"FUS9VED(")5<V5R(@IM<V=S='(@(E5S=>%R:6]S(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HW-S0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@
M)7,N(@IM<V=S='(@(E5S=>%R:6\@)7,@;N-O(&5S=.$@875T;W)I>F%D;R!P
M87)A("5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!
M9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')AY^-O(&1E(%5S=>%R
M:6]S(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR-#4*;7-G
M:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R(")/<.?U97,@9&4@57-UX7)I;W,B
M"@HC.B!S:6=N=7`N<&AP.C8R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*
M;7-G<W1R(")296=I<W1R;R!D92!5<W7A<FEO<R(*"B,Z('-I9VYU<"YP:'`Z
M,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D
M(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(E)E9VES=')O(&1E(%5S=>%R:6]S
M(&5S=.$@9&5S86)I;&ET861O(&YE<W1E('-I=&4N(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C0V.0IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N
M9"(*;7-G<W1R(")#;VYT82!D92!U<W7A<FEO(&[C;R!E;F-O;G1R861A(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W
M.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4S-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S
M;71P+G!H<#HY.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HQ-3`@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S,*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,B!T96UP;&%T97,O861M:6XO
M=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B
M57-UX7)I;R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HQ
M,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E<UPB(&%L<F5A
M9'D@97AI<W1S+B(*;7-G<W1R(")5<W7A<FEO("<E<R<@:N$@97AI<W1E+B(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PIM<V=I9"`B57-E
M<FYA;64Z(@IM<V=S='(@(E5S=>%R:6\Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VUO8FEL92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R(")5<W7A
M<FEO.B`B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS
M9VED(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R(")5<W7A<FEO<R!N
M;R!S:7-T96UA.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB
M"FUS9W-T<B`B57IB97%U:7-TXV\B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HQ-S`@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C8R"FUS
M9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")/
M(&1I<F5T\W)I;R!61E,@;N-O(&5X:7-T92XB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3(P"FUS9VED(")686-A=&EO;B(*;7-G<W1R(")&Z7)I
M87,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-S`*;7-G:60@(E9A
M;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`B3&]C86QI
M>F'G]65S(';A;&ED87,@96YC;VYT<F%D87,@:6YC;'5E;3H@(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@(E9A;&ED
M:71Y(@IM<V=S='(@(E9A;&ED861E(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.3<*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U"FUS9VED(")686QU92!I
M;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R(")686QO<B!E;2!M:6YU=&]S
M(&$@<&%R=&ER(&1E(&%G;W)A+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C@V,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@Q"B,L('!H<"UF
M;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H
M(&]F("5S+B(*;7-G<W1R(")/('9A;&]R(&5S=.$@86-I;6$@9&\@=&%M86YH
M;R!MX7AI;6\@9&4@)7,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C(T."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C<P"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(S,C`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,CDQ-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP
M.C4Y"FUS9VED(")686QU97,B"FUS9W-T<B`B5F%L;W)E<R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,3,@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$Y,`IM<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@
M(E9A;&]R97,@<&%R82!S96QE8VEO;F%R(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I
M9"`B5F%N=6%T=2(*;7-G<W1R(")686YU871U(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S,PIM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B
M5F%R:>%V96PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")696YE>G5E;&$B"FUS
M9W-T<B`B5F5N97IU96QA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES
M(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R
M(")&86QH82!N82!V97)I9FEC8>?C;R`M(&5S=&$@;65N<V%G96T@<&]D92!T
M97(@<VED;R!A9'5L=&5R861A+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-S`Q"FUS9VED(")697)S:6]N(@IM<V=S='(@(E9E<G/C
M;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,C@*;7-G:60@(E9E
M<G-I;VX@0V]N=')O;"(*;7-G<W1R(")#;VYT<F]L92!D92!697)SXV\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@S"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G<W1R(")!;&EN:&%M96YT
M;R!V97)T:6-A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B
M36%R9V5M('9E<G1I8V%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(E9E
M<G1I8V%L.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C<Q"FUS9VED(")697)Y($AI9V@B"FUS9W-T<B`B375I=&\@06QT82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I970@3F%M(@IM<V=S='(@(E9I971N
MXR(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS"FUS9VED(")6:65T;F%M
M97-E("A625-#24DI(@IM<V=S='(@(E9I971N86UI=&$@*%9)4T-)22DB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HY-CD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R(")697(@)7,B"@HC.B!L
M:6(O0FQO8VLO:69R86UE+G!H<#HS"FUS9VED(")6:65W(&%N(&5X=&5R;F%L
M('=E8B!P86=E(@IM<V=S='(@(E9I<W5A;&EZ87(@=6UA('#A9VEN82!W96(@
M97AT97)N82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.C@R.`HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@
M(E9I<W5A;&EZ87(@8V]M;R`E<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I
M<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM<V=S='(@(DEL:&%S(%9I<F=E;G,L
M($)R:73B;FEC87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L
M86YD<RP@52Y3+B(*;7-G<W1R("));&AA<R!6:7)G96YS+"!%+E4N02XB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-@IM<V=I9"`B5FES:6)I;&ET>2(*
M;7-G<W1R(")6:7-I8FEL:61A9&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C4R"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B5FES
M:6)I;&ED861E.B`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O
M;F5I=&%L>5]S;71P+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA
M(%--5%`B"FUS9W-T<B`B5F]D869O;F4@271A;&EA;F\@=FEA(%--5%`B"@HC
M.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]M;V)I;&4N<&AP.C,V"FUS9VED(")705).(@IM<V=S='(@(D%414['PT\B
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/
M32`E<RXB"FUS9W-T<B`B051%3L?#3R$A(2!214U/5D$@3R!30U))4%0@34%.
M54%,345.5$4@1$4@)7,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HQ,S,*;7-G:60@(E=)3B!V:6$@2%144"(*;7-G<W1R(")7
M24X@=FEA($A45%`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")786QL:7,@86YD
M($9U='5N82(*;7-G<W1R(")786QL:7,@92!&=71U;F$B"@HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N
M<&AP.C(Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP
M.C$R,2!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#,*;7-G:60@(E=A<FYI;F<B
M"FUS9W-T<B`B071E;N?C;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(E%U82(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.0IM<V=I9"`B5V5A=&AE
M<B!&;W)E8V%S="(*;7-G<W1R(")0<F5V:7/C;R!D;R!496UP;R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,38*;7-G:60@(E=E871H97(@
M9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R(")$861O<R!D;R!#;&EM82!F;W)N
M96-I9&\@<&]R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DV"FUS
M9VED(")796%T:&5R+F-O;2(*;7-G<W1R(")796%T:&5R+F-O;2(*"B,Z(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED(")796(B"FUS9W-T<B`B5V5B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S.0IM<V=I9"`B5V5B
M(%-I=&4B"FUS9W-T<B`B4VET92!796(B"@HC.B!F<F%M97=O<FLO36%I;G1E
M;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T
M<B`B4V5M86YA;&UE;G1E(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP
M:'`Z,C@*;7-G:60@(E=E;&-O;64B"FUS9W-T<B`B0F5M+79I;F1O(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C4W"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@
M)7,B"FUS9W-T<B`B0F5M+79I;F1O(&%O("5S(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHR
M"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM<V=S='(@(D)E
M;2UV:6YD;RP@)7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I
M9"`B5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B3V-I9&5N=&%L("A)
M4T\M.#@U.2TQ*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED
M(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B3V-I9&5N=&%L("A)
M4T\M.#@U.2TQ-2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA
M<F$B"FUS9W-T<B`B4V%H87)A($]C:61E;G1A;"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L
M:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T
M<B`B475E(&%P;&EC8>?C;R`E<R!D979E<FEA(&5X:6)I<B!A</-S(&$@8V]N
M97CC;S\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-`IM<V=I
M9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B
M475A;"!O(&-A<F%C=&5R92!D96QI;6ET861O<C\B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@
M8VAA<F%C=&5R/R(*;7-G<W1R(")1=6%L(&\@8V%R86-T97)E(&1E(&-I=&'G
MXV\_(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$P-C(*;7-G:60@(E=H97)E:7,@075S=')A;&EA(&UA<"(*;7-G<W1R(")-
M87!A<R!!=7-T<F%L:6%N;W,@5VAE<F5I<R(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(E%U86ES(&9A
M<V5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-@IM<V=I9"`B5VAI
M8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R
M+B(*;7-G<W1R(")1=6%I<R!P;'5G:6YS(&AA8FEL:71A<B!P87)A(&\@961I
M=&]R(%)I8V@@5&5X="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED(")7:61T:"(*;7-G<W1R("),
M87)G=7)A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-`IM<V=I
M9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(DQA<F=U<F$@96T@=6YI
M9&%D97,@0U-3(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@
M;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`B
M3&%R9W5R82!D;R!M96YU("5S(&1O(&QA9&\@97-Q=65R9&\@*'1E<N$@969E
M:71O(&YA('!R\WAI;6$@8V]N97CC;RDZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H
M92!T86)L92(*;7-G<W1R("),87)G=7)A(&1A('1A8F5L82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7
M:61T:"!U;FET(@IM<V=S='(@(E5N:61A9&4@9&4@3&%R9W5R82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED
M(")7:61T:#HB"FUS9W-T<B`B3&%R9W5R83HB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-3$U"FUS9VED(")7:6MI(@IM<V=S='(@(E=I:VDB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Y(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V"FUS9VED(")7:6YD(@IM<V=S
M='(@(E9E;G1O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C<*;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`B5F5N=&]S('!E
M;&$@;6%N:.,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@W"FUS9VED(")7
M:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@(E9E;&]C:61A9&4@9&\@=F5N
M=&\@96T@;O-S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C,*;7-G:60@
M(E=I;F0Z(@IM<V=S='(@(E9E;G1O.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,S$*;7-G:60@(E=I;F0Z("(*;7-G<W1R(")696YT;SH@
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB
M"FUS9W-T<B`B4V%B961O<FEA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$Y.`IM<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`B3&ES=&$@9&4@<&5D
M:61O<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R
M:R(*;7-G<W1R(")4<F%B86QH;R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$V-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S
M='(@(D5N9&5R9>=O($-O;65R8VEA;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO;F4B"FUS
M9W-T<B`B1F]N92!#;VUE<F-I86PB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HQ.3,@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,CDT"B,L
M('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@
M;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R(").^FUE
M<F\@:6YC;W)R971O(&1E(&-A;7!O<R!N82!L:6YH82`E9"X@17-P97)A9&]S
M("5D+"!E;F-O;G1R861O<R`E9"XB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HS,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R
M(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R(").
M^FUE<F\@97)R861O(&1E(&-A;7!O<RX@17-P97)A9&]S("5D+"!E;F-O;G1R
M861O<R`E9"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE(')E
M861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B3V9F<V5T("5D(&EN8V]R<F5T
M;R!A;R!L97(@;R!A<G%U:79O(%9&4RXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C0U"FUS9VED(")8+5)E9B(*;7-G<W1R(")8+5)E9B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")8
M-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T<B`B4F5S=')IY_5E<R!"
MX7-I8V%S(%@U,#EV,R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@IM
M<V=S='(@(E5T:6QI>F'GXV\@9&4@0VAA=F4@17AT96YD:61A(%@U,#EV,R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED
M(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(DYO
M;64@06QT97)N871I=F\@9&4@07-S=6YT;R!8-3`Y=C,B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I9"`B6#4P.78S(%-U
M8FIE8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B261E;G1I9FEC861O<B!D
M82!#:&%V92!D92!!<W-U;G1O(%@U,#EV,R(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C@S"FUS9VED(")8-3`Y=C,@97AT96YS:6]N
M<R(*;7-G<W1R(")%>'1E;G/U97,@6#4P.78S(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@(D%!(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4T"FUS9VED(")965E9(@IM
M<V=S='(@(D%!04$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3$P.0IM<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R(")-87!A
M(%EA:&]O(2(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC
M92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G<W1R(")!;G5A;&UE;G1E(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-PIM<V=I9"`B665M96XB"FUS9W-T<B`B3.IM96XB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38T"FUS
M9VED(")997,B"FUS9W-T<B`B4VEM(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!9W)E92(*
M;7-G<W1R(")3:6TL($5U($-O;F-O<F1O(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I;B!4
M15A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K
M('1O(%=94TE764<N(@IM<V=S='(@(B(*(E9O8^H@97-TX2!E;2!-3T1/(%1%
M6%1/+B`@571I;&EZ82!O(&)O=.-O(%L\/ET@<&%R82!V;VQT87(@<&%R82!O
M(&UO9&\@(@HB5UE325=91RXB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+TUA;F%G97(N<&AP.C(S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9
M;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO
M8VMS+B(*;7-G<W1R(")6;V/J(&[C;R!E<W3A(&%U=&]R:7IA9&\@82!C<FEA
M<B!M86ES(&1E("5D(&)L;V-O<RXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C$T,34*;7-G:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N
M(@IM<V=S='(@(E9O8^H@;N-O(&5S=.$@875T96YT:6-A9&\N(@H*(SH@9G)A
M;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS,#@*;7-G:60@(EEO=2!C
M86YN;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA
M;64N(@IM<V=S='(@(E9O8^H@;N-O('!O9&4@=&5R(&\@8V%R86-T97(@7%P@
M;F\@<V5U(&YO;64N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U
M.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<Y"FUS9VED(")9;W4@9&ED
M(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S='(@(E9O
M8^H@;N-O(&9O<FYE8V5U('5M(&5N9&5R9>=O(&1E(&4M;6%I;"!VX6QI9&\N
M(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T
M:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@
M(@HB:6X@)7,N(@IM<V=S='(@(B(*(E9O8^H@;N-O(&UA<&5O=2!N96YH=6T@
M8V%M<&\@9&\@87)Q=6EV;R!I;7!O<G1A9&\@86]S(&-A;7!O<R!C;W)R97-P
M;VYD96YT97,@(@HB96T@)7,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP
M:'`Z.3@W"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S
M='(@(E9O8^H@9F]I(&1E<V-O;F5C=&%D;RXB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C8U"FUS9VED("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A
M('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@
M;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG
M('!R969I>"XB"FUS9W-T<B`B(@HB5F]CZB!D979E('!R965N8VAE<B!U;2!N
M^FUE<F\@9&4@=&5L969O;F4@8V5L=6QA<B!VX6QI9&\L('-O;65N=&4@9.UG
M:71O<R`B"B)C;VT@=6T@;W!C:6]N86P@)RLG('!A<F$@9&ES8V%G96T@9&4@
M<')E9FEX;R!I;G1E<FYA8VEO;F%L+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Q.3(*;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@
M=F%L=64N(@IM<V=S='(@(E9O8^H@9&5V92!P<F5E;F-H97(@=6T@=F%L;W(@
M=N%L:61O+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HS
M-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N
M9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B5F]CZB!D979E(&-O;F9I9W5R
M87(@=6T@8V]N96-T;W(@1&%T851R964@<&%R82!U=&EL:7IA<B!#861A<W1R
M;W,N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT-C(*;7-G:60@
M(EEO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+B(*;7-G<W1R(")6
M;V/J(&1E=F4@8V]N9FEG=7)A<B!U;2!C;VYE8W1O<B!61E,N(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T
M(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE
M('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R("(B"B)6;V/J(&1E=F4@9&5S8W)E
M=F5R(&\@<')O8FQE;6$@86YT97,@9&4@96YV:6%R(&\@<F5L873S<FEO(&1E
M('!R;V)L96UA+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE
M<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*;7-G<W1R(")6;V/J(&1E=F4@9F]R
M;F5C97(@82!54DP@;VYD92!O(&QI;FL@87!O;G1A(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W)P8W-U;2YP:'`Z.#`*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A
M;B!S97)V97(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B5F]CZB!D979E('-E
M;&5C:6]N87(@=6T@<V5R=FED;W(@<&%R82!S97(@97AC;'7M9&\N(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3$Y"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@
M=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R(")6;V/J(&1E=F4@97-P
M96-I9FEC87(@=6T@=7-UX7)I;R!P87)A(&5X8VQU:7(N(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA
M;64@=&\@<F5M;W9E+B(*;7-G<W1R(")6;V/J(&1E=F4@97-P96-I9FEC87(@
M=6T@=7-UX7)I;R!P87)A(')E;6]V97(N(@H*(SH@861M:6XO=7-E<BYP:'`Z
M-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS9VED(")9
M;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@
M(E9O8^H@9&5V92!E<W!E8VEF:6-A<B!U;2!U<W7A<FEO('!A<F$@861I8VEO
M;F%R+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*;7-G<W1R(")6;V/J
M(&1E=F4@97-P96-I9FEC87(@=6T@=7-UX7)I;R!P87)A(&%T=6%L:7IA<BXB
M"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S@*
M;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R
M;2XB"FUS9W-T<B`B5F]CZB!D979E(&5S<&5C:69I8V%R('5M82!AY^-O('!A
M<F$@97AE8W5T87(N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`Z-S$*;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N97<@
M8V%T96=O<GD@;F%M92XB"FUS9W-T<B`B5F]CZB!D979E('!R965N8VAE<B!U
M;2!N;VUE('!A<F$@82!N;W9A(&-A=&5G;W)I82XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B
M66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*
M;7-G<W1R(")6;V/J('!R96-I<V$@9F]R;F5C97(@=6T@;OIM97)O(&1E('1E
M;&5F;VYE(&ET86QI86YO(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M.3<U"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@
M97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R(")3=6$@<V5S
M<^-O("5S(&5X<&ER;W4N(%!O<B!F879O<BP@8V]N96-T92US92!N;W9A;65N
M=&4N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*;7-G
M:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R(")3974@16YD97)EYV\@
M9&4@12UM86EL(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q-0IM<V=I
M9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R(")3974@16YD97)EYV\@
M9&4@4F5M971E;G1E("A$93HI.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S<@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,@IM<V=I9"`B
M66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R(")3=6%S($EN9F]R;6'G]65S(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S
M:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB
M<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB
M"FUS9W-T<B`B(@HB4V5U($5N9&5R9>=O(&1E($EN=&5R;F5T(&UU9&]U(&1E
M<V1E(&\@:6[M8VEO(&1E('-U82!S97-SXV\@)7,N(%!A<F$@(@HB<')O=&5G
M97(@<W5A('-E9W5R86[G82!V;V/J(&1E=F4@8V]N96-T87(M<V4@;F]V86UE
M;G1E+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S"FUS
M9VED(")9;W5R($YA;64B"FUS9W-T<B`B4V5U($YO;64B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H
M96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S
M97)S+B!)9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R9&4@=&\@861M:6YI<W1E
M<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@(@HB
M875T:&5N=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T<B`B(@HB4V5U(&)A8VME
M;F0@9&4@875T96YT:6-AY^-O(&[C;R!S=7!O<G1A(&%D:>?C;R!D92!U<W7A
M<FEO<RP@;W4@82!F=6[GXV\@9F]I("(*(F1E<V%B:6QI=&%D82!P;W(@86QG
M=6UA(&]U=')A(')A>N-O+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO
M;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K
M96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E
M871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A
M<V]N+B(*;7-G<W1R("(B"B)3974@8F%C:V5N9"!D92!A=71E;G1I8V'GXV\@
M;N-O('-U<&]R=&$@;&ES=&%G96T@9&4@=7-UX7)I;W,L(&]U(&$@9G5NY^-O
M("(*(F9O:2!D97-A8FEL:71A9&$@<&]R(&%L9W5M82!O=71R82!R87KC;RXB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N
M9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B
M"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G
M86EN+B(*;7-G<W1R("(B"B)3974@;F%V96=A9&]R('!A<F5C92!T97(@86QT
M97)A9&\@9&5S9&4@;R!I;NUC:6\@9&4@<W5A('-E<W/C;R`E<RX@4&%R82`B
M"B)P<F]T96=E<B!S=6$@<V5G=7)A;N=A+"!V;V/J(&1E=F4@8V]N96-T87(M
M<V4@;F]V86UE;G1E+B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C4U"FUS
M9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U
M<F4N(@IM<V=S='(@(E-E=2!N879E9V%D;W(@;N-O('-U<&]R=&$@97-T82!F
M=6[GXV\N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z-#(*
M;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@
M<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O
M('!R:6YT+B(*;7-G<W1R("(B"B)3974@;F%V96=A9&]R(&[C;R!S=7!O<G1A
M(&5S=&$@;W#GXV\@9&4@:6UP<F5S<^-O+B!0<F5S<VEO;F4@0V]N=')O;"]/
M<'1I;VX@(@HB*R!0('!A<F$@:6UP<FEM:7(N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(V,0IM<V=I9"`B66]U<B!C=7)R96YT('1I;64@>F]N93HB
M"FUS9W-T<B`B4V5U(&9U<V\@:&]RX7)I;R!A='5A;#HB"@HC.B!S97)V:6-E
M<R]P<F5F<RYP:'`Z,3$Q"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='D@
M:&%S(&)E96X@8VAA;F=E9"XB"FUS9W-T<B`B4W5A(&ED96YT:61A9&4@<&%D
M<N-O(&9O:2!A;'1E<F%D82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,38Q"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@(E-U
M82!I9&5N=&ED861E('!A9'+C;SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C`T"FUS9VED(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`B4V5U(&YO
M;64@8V]M<&QE=&\Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DY
M"FUS9VED(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")3=6$@
M8V]N97CC;R!E>'!I<F]U+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D
M(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B4W5A(&YO=F$@<V5N:&$@<&%R82`E
M<R#I.B`E<R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34T
M"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H
M92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@(E-U87,@;W#G
M]65S(&9O<F%M(&%T=6%L:7IA9&%S('!O<B!C875S82!D82!D=7)AY^-O(&1E
M<W1A('-E<W/C;RXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*
M;7-G<W1R(")3=6%S(&]PY_5E<R!F;W)A;2!A='5A;&EZ861A<RXB"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S
M=V]R9"!H87,@8F5E;B!R97-E="(*;7-G<W1R(")3=6$@;F]V82!S96YH82!F
M;VD@9V5R861A(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*
M;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K
M('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W
M;W)D+B(*;7-G<W1R("(B"B)3=6$@;F]V82!S96YH82!F;VD@9V5R861A+"!V
M97)I9FEQ=64@<V5U(&4M;6%I;"!E(&-O;F5C=&4M<V4@8V]M('-U82!N;W9A
M("(*(G-E;FAA+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<S,PIM
M<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"XB"FUS9W-T<B`B4W5A
M('-E;FAA(&5X<&ER;W4N(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C4X"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R(")3
M975S('-E<G9I9&]R97,@<F5M;W1O<SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X
M"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S='(@(DEU9V]S;.%V:6$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*
M;7-G<W1R("):86ER92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I82(*
M;7-G<W1R("):XFUB:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")::6UB86)W
M92(*;7-G<W1R(")::6UB86)W92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B6FEP<'DB"@HC.B!F<F%M97=O
M<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS
M9VED(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T<B`B6T]C=6QT87(@5&5X
M=&\@0VET861O72(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C@Y"FUS9VED
M(");4')O8FQE;2!297!O<G1=(@IM<V=S='(@(EM296QA=/-R:6\@9&4@4')O
M8FQE;6%=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N
M:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS9W-T<B`B6T5X
M:6)I<B!497AT;R!#:71A9&\@+2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E
M<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T
M<B`B6T5X:6)I<B!497AT;R!#:71A9&\@+2`E<R!L:6YH87-=(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(EML:6YH82`E<R!D92`E<UTB
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U-#4@=&5M<&QA=&5S
M+W!O<G1A;"]M96YU+FEN8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(E]!9&UI;FES=')AY^-O(@H*(SH@;&EB+V%P:2YP:'`Z,34W"FUS
M9VED(")?0TQ)(@IM<V=S='(@(E]#3$DB"@HC.B!L:6(O87!I+G!H<#HQ-#$*
M;7-G:60@(E]$871A5')E92(*;7-G<W1R(")$871A7U1R964B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*
M;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(D5?>&-L=6ER($-O;'5N82(*
M"B,Z(&QI8B]A<&DN<&AP.C$S,PIM<V=I9"`B7T=R;W5P<R(*;7-G<W1R(")?
M1W)U<&]S(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W
M-0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`B05]J=61A(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S"FUS9VED
M(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")0<F]P<FEE9&%D97,@
M9&$@7TEM86=E;2XN+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU
M+G!H<#HQ.30*;7-G:60@(E],;V<@:6XB"FUS9W-T<B`B7T-O;F5C=&%R(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I9"`B
M7TQO9R!O=70B"FUS9W-T<B`B7T1E<V-O;F5C=&%R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED
M(")?36]D:69Y($QI;FLN+BXB"FUS9W-T<B`B05]L=&5R87(@3&EN:RXN+B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-C0*;7-G:60@
M(E]/<'1I;VYS(@IM<V=S='(@(E]/<.?U97,B"@HC.B!L:6(O87!I+G!H<#HQ
M,S<*;7-G:60@(E]097)M:7-S:6]N<R(*;7-G<W1R(")?4&5R;6ES<_5E<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR-@IM<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@(E]296UO
M=F5R($QI;FLN+BXB"@HC.B!L:6(O87!I+G!H<#HQ,C4*;7-G:60@(E]3971U
M<"(*;7-G<W1R(")#;VYF:6=U<F%?<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B7U1A8FQE
M(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B4')O<')I961A9&5S(&1A(%]486)E
M;&$N+BXB"@HC.B!L:6(O87!I+G!H<#HQ,CD*;7-G:60@(E]5<V5R<R(*;7-G
M<W1R(")?57-UX7)I;W,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDR,`IM<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(F-A=.%L;V=O(&1E
M(&5N9&5R9>=O<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,3,T"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R(")C873A
M;&]G;R!D92!E;F1E<F7G;W,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDQ,@IM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B86=E;F1A(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-SD@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R(")C86QM;R(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED
M(")C86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(FEM<&]S<^UV
M96P@8W)I87(@87)Q=6EV;R!D92!D97-T:6YO(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN
M<'5T(@IM<V=S='(@(FEM<&]S<^UV96P@86)R:7(@82!O<FEG96TB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3D*;7-G:60@(F-L
M:6-K(&AE<F4B"FUS9W-T<B`B8VQI<75E(&%Q=6DB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE
M('5S86=E(&5R<F]R(@IM<V=S='(@(F5R<F\@9&4@<VEN=&%X92!D82!L:6YH
M82!D92!C;VUA;F1O(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-S@*;7-G:60@(F-O;F9I9W5R871I;VX@97)R;W(B"FUS9W-T<B`B
M97)R;R!D92!C;VYF:6=U<F'GXV\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@
M;6ES<VEN9R(*;7-G<W1R(")U;2!A<G%U:79O(&-R[71I8V\@9&\@<VES=&5M
M82!E<W3A(&9A;'1A;F1O(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ,C8*;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@
M(F5R<F\@;F\@9F]R;6%T;R!D;W,@9&%D;W,B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+V5D:70N:6YC.C,P"FUS9VED(")E9&ET(@IM<V=S='(@(F5D:71A<B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3@R"FUS9VED
M(")E;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`B<F5G:7-T<F\@;N-O(&5N8V]N
M=')A9&\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HW,@IM<V=I9"`B9F%L;&EN9R(*;7-G<W1R(")Q=65D82(*"B,Z(&9R86UE
M=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X,0IM<V=I9"`B9FEL92(*;7-G
M<W1R(")A<G%U:79O(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#$@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS-C<@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E
M<R(*;7-G<W1R(")A('!A<G1I<B!D92`E<R`H)7,I(.`@)7,@)7,B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Y"FUS9VED(")G=7-T:6YG
M(@IM<V=S='(@(F)R:7-A(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(T.`IM<V=I9"`B:#HB"FUS9W-T<B`B:#HB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4W"FUS9VED
M(")H:"(*;7-G<W1R(")H:"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,3,X"FUS9VED(")H;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R
M(")N;VUE(&1O(&AO<W0@Z2!D97-C;VYH96-I9&\B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@
M(FEM;65D:6%T92(*;7-G<W1R(")I;65D:6%T;R(*"B,Z(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")I
M;FQI;F4B"FUS9W-T<B`B:6YC;W)P;W)A9&\B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R
M<F]R(@IM<V=S='(@(F5R<F\@9&4@96YT<F%D82]S8>UD82(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,30V"FUS9VED(")I;G1E<FYA
M;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R(")E<G)O(&EN=&5R;F\@9&\@<')O
M9W)A;6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ
M<SHQ,PIM<V=I9"`B;&EN97-=(@IM<V=S='(@(FQI;FAA<UTB"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H
M:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@(F/S9&EG;R!D92!E<G)O("5D(&1O
M(&UK:7-O9G,@96YQ=6%N=&\@9V5R879A(&$@25-/+B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-C@*;7-G:60@(FUM(@IM
M<V=S='(@(FUM(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR
M.#4@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W,`HC.B!S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`Z,C0Q"FUS9VED(")N86UE(@IM<V=S='(@
M(FYO;64B"@HC.B!F<F%M97=O<FLO4E!#+U)00RYP:'`Z,3(T"FUS9VED(")N
M;W0@:6UP;&5M96YT960B"FUS9W-T<B`B;N-O(&EM<&QE;65N=&%D;R(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(R,`IM<V=I9"`B
M;F]T('EE="!I;7!L96UE;G1E9"(*;7-G<W1R(")NXV\@:6UP;&5M96YT861O
M(&%I;F1A(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#0*;7-G
M:60@(FYO=&5P860B"FUS9W-T<B`B8FQO8V\@9&4@;F]T87,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS
M9VED(")P97)C96YT(@IM<V=S='(@(G!O<F-E;G1A9V5M(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S0*;7-G:60@(G!E<FUI<W-I
M;VX@9&5N:65D(@IM<V=S='(@(E!E<FUI<W/C;R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I
M>&5L<R(*;7-G<W1R(")P:7AE;',B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$W,`IM<V=I9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O
M8V]L(@IM<V=S='(@(F5R<F\@<F5M;W1O(&YO('!R;W1O8V]L;R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<T"FUS9VED(")R
M:7-I;F<B"FUS9W-T<B`B;F%S8V5N=&4B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$T,@IM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L
M92(*;7-G<W1R(")S97)V:>=O(&EN9&ES<&]N[79E;"(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z,3`Q"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM
M<V=S='(@(F5X:6)I<B!D:69E<F5NYV%S(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I
M;"!V:6$@2%144"(*;7-G<W1R(")S;7,R96UA:6P@=FEA($A45%`B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@U"FUS9VED
M(")S<R(*;7-G<W1R(")S<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C<S"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B97-TX79E
M;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34P"FUS
M9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`B97)R;R!D92!S:7-T96UA(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C@*;7-G:60@(G1A<VL@
M;&ES="(*;7-G<W1R(")L:7-T82!D92!T87)E9F%S(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F
M86EL=7)E(@IM<V=S='(@(F9A;&AA('1E;7!O<N%R:6$B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS-B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C<P
M"FUS9VED(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM
M<V=S='(@(G!R965N8VAA('-U82!S96YH82!D=6%S('9E>F5S('!A<F$@8V]N
M9FER;6%R(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T
M=7`O9&EF9BYP:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T<B`B=6YI9FEC
M861O(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]087)T+G!H<#HR-PIM<V=I
M9"`B=6YN86UE9"(*;7-G<W1R(")S96T@;F]M92(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B
M=7-E<B!S96QE8W0B"FUS9W-T<B`B<V5L9>?C;R!D92!U<W7A<FEO(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,U"FUS9VED
M(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR-#`*;7-G:60@(G<Z(@IM<V=S='(@(G<Z
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E
M871H97(N8V]M(@IM<V=S='(@(G=E871H97(N8V]M(@H`````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!O+W!T7U!4+G!O````````````````````````````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#<R,#4R,"`Q,#4Q-30S,S<T,R`P,3<U-3(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````(R!(;W)D
M92!0;W)T=6=A;"!0;W)T=6=U97-E('1R86YS;&%T:6]N+@HC($UA;G5E;"!-
M96YE>F5S(&1E(%-E<75E:7)A(#Q-86YU96PN4V5Q=65I<F$^+"`R,#`U+@HC
M($)A<V5D(&]N(&$@<')E=FEO=7,@=')A;G-L871I;VX@8GD@3G5N;R!,;W5R
M96ER;R`\;G5N;T!E=&@N<'0^+"`R,#`R+@HC"FUS9VED("(B"FUS9W-T<B`B
M(@HB4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C`M8W9S7&XB"B)297!O
M<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4
M+4-R96%T:6]N+41A=&4Z(#(P,#4M,3$M,C0@,#$Z,3@K,#`P,%QN(@HB4$\M
M4F5V:7-I;VXM1&%T93H@,C`P,BTP,2TR,2`Q.#HR,BTP,#`P7&XB"B),87-T
M+51R86YS;&%T;W(Z($YU;F\@3&]U<F5I<F\@/&YU;F]`971H+G!T/EQN(@HB
M3&%N9W5A9V4M5&5A;3H@4&]R='5G86P@4&]R='5G=65S92`\9&5V0&QI<W1S
M+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT
M+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,5QN(@HB0V]N
M=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C0Y"FUS9VED("(B"B(@("U-+"`M+6UE<W-A9V4]34534T%'
M12`@57-E('1H:7,@8V]M;6ET(&UE<W-A9V4@:6YS=&5A9"!O9B!T:&4@9&5F
M875L="!O;F5S+B(*;7-G<W1R("(B"B(@("U-+"`M+6UE<W-A9V4]345.4T%'
M14T@57-A<B!E<W1A(&UE;G-A9V5M(&1E(&-O;65T:6UE;G1O(&5M('9E>B!D
M85QN(@HB("`@("`@("`@("`@("`@("`@("`@("`@(&UE;G-A9V5M('!O<B!O
M;6ES<^-O+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HU,PIM<V=I9"`B(@HB
M("`M82P@+2UA9&0]1DE,12`@("`@("`@061D('1H:7,@4$\@9FEL92!T;R!T
M:&4@8V]M<&5N9&EU;2X@57-E9G5L('1O7&XB"B(@("`@("`@("`@("`@("`@
M("`@("`@("!I;F-L=61E(&$@8V]M<&5N9&EU;2!F<F]M(&$@9&EF9F5R96YT
M(&)R86YC:"!T;UQN(@HB("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&=E
M;F5R871E9"!C;VUP96YD:75M+B(*;7-G<W1R("(B"B(@("UA+"`M+6%D9#U!
M4E%5259/("`@("!!9&EC:6]N87(@97-T92!A<G%U:79O(%!/(&%O(&-O;7#J
M;F1I;RX@571I;"!P87)A7&XB"B(@("`@("`@("`@("`@("`@("`@("`@("!I
M;F-L=6ER('5M(&-O;7#J;F1I;R!D92!U;2!R86UO(&1I9F5R96YT92!N;UQN
M(@HB("`@("`@("`@("`@("`@("`@("`@("`@8V]M<.IN9&EO(&=E<F%D;RXB
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$S"FUS9VED("(B"B(@("UB+"`M
M+6)A<V4]+U!!5$@@($9U;&P@<&%T:"!T;R!T:&4@*$AO<F1E*2!B87-E(&1I
M<F5C=&]R>2!T:&%T('-H;W5L9"!B95QN(@HB("`@("`@("`@("`@("`@("`@
M("!U<V5D+B(*;7-G<W1R("(@("UB+"`M+6)A<V4]+T-!34D@($-A;6EN:&\@
M<&%R82!O(&1I<F5C=/-R:6\@8F%S92`H2&]R9&4I(&$@=7-A<BXB"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z-CD*;7-G:60@(B(*(B`@+6,L("TM8V]M<&5N
M9&EU;3U&24Q%("!-97)G92!N97<@=')A;G-L871I;VYS('1O('1H:7,@8V]M
M<&5N9&EU;2!F:6QE7&XB"B(@("`@("`@("`@("`@("`@("`@("`@("`@:6YS
M=&5A9"!O9B!T:&4@9&5F875L="!O;F4@*&-O;7!E;F1I=6TN<&\@:6X@=&AE
M7&XB"B(@("`@("`@("`@("`@("`@("`@("`@("`@:&]R9&4O<&\@9&ER96-T
M;W)Y+B(*;7-G<W1R("(B"B(@("UC+"`M+6-O;7!E;F1I=6T]05)152`@26YT
M96=R87(@;F]V87,@=')A9'7G]65S(&$@97-T92!A<G%U:79O(&1E("(*(F-O
M;7#J;F1I;UQN(@HB("`@("`@("`@("`@("`@("`@("`@("`@(&4@;N-O(&%O
M(&-O;7#J;F1I;R!P;W(@;VUI<W/C;R`H8V]M<&5N9&EU;2YP;R!N85QN(@HB
M("`@("`@("`@("`@("`@("`@("`@("`@('!A<W1A(&AO<F1E+W!O+B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HV,R!P;R]T<F%N<VQA=&EO;BYP:'`Z.#$@
M<&\O=')A;G-L871I;VXN<&AP.C@W"FUS9VED("(B"B(@("UC+"`M+6-O;7!E
M;F1I=6T]1DE,12`@57-E('1H:7,@8V]M<&5N9&EU;2!F:6QE(&EN<W1E860@
M;V8@=&AE(&1E9F%U;'1<;B(*(B`@("`@("`@("`@("`@("`@("`@("`@("!O
M;F4@*&-O;7!E;F1I=6TN<&\@:6X@=&AE(&AO<F1E+W!O(&1I<F5C=&]R>2DN
M(@IM<V=S='(@(B(*(B`@+6,L("TM8V]M<&5N9&EU;3U!4E%5("!5<V%R(&5S
M=&4@87)Q=6EV;R!D92!C;VUPZFYD:6\@96T@=F5Z(&1O(&%R<75I=F]<;B(*
M(B`@("`@("`@("`@("`@("`@("`@("`@("!P;W(@;VUI<W/C;R`H8V]M<&5N
M9&EU;2YP;R!N82!P87-T82!H;W)D92]P;RXB"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,3$T"FUS9VED("(@("UD+"`M+61E8G5G("`@("`@(%-H;W<@97)R
M;W(@;65S<V%G97,@9G)O;2!T:&4@97AE8W5T960@8FEN87)I97,N(@IM<V=S
M='(@(B`@+60L("TM9&5B=6<@("`@("`@36]S=')A<B!M96YS86=E;G,@9&4@
M97)R;R!D;W,@8FENX7)I;W,@97AE8W5T861O<RXB"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z-30*;7-G:60@(B`@+60L("TM9&ER96-T;W)Y/41)4B`@($-R
M96%T92!C;VUP96YD:75M(&EN('1H:7,@9&ER96-T;W)Y+B(*;7-G<W1R("(@
M("UD+"`M+61I<F5C=&]R>3U005-402!#<FEA<B!U;2!C;VUPZFYD:6\@;F5S
M=&$@<&%S=&$N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$Q-0IM<V=I9"`B
M("`M:"P@+2UH96QP("`@("`@("!3:&]W('1H:7,@:&5L<"!M97-S86=E+B(*
M;7-G<W1R("(@("UH+"`M+6AE;'`@("`@("`@($UO<W1R87(@97-T82!M96YS
M86=E;2!D92!A:G5D82XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#(@<&\O
M=')A;G-L871I;VXN<&AP.C8W('!O+W1R86YS;&%T:6]N+G!H<#HW-0IM<V=I
M9"`B("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S92!O;FQY('1H:7,@;&]C
M86QE+B(*;7-G<W1R("(@("UL+"`M+6QO8V%L93UL;%]#0R`@("`@57-A<B!A
M<&5N87,@97-T82!L;V-A;&EZ8>?C;RXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z-#<@<&\O=')A;G-L871I;VXN<&AP.C8Q('!O+W1R86YS;&%T:6]N+G!H
M<#HW.0HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#4*;7-G:60@(B`@+6PL("TM
M;&]C86QE/6QL7T-#("`@("!5<V4@=&AI<R!L;V-A;&4N(@IM<V=S='(@(B`@
M+6PL("TM;&]C86QE/6QL7T-#("`@("!5<V%R(&5S=&$@;&]C86QI>F'GXV\N
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C4U"FUS9VED("(@("UL+"`M+6QO
M8V%L93UL;%]#0R`@("!5<V4@=&AI<R!L;V-A;&4N(@IM<V=S='(@(B`@+6PL
M("TM;&]C86QE/6QL7T-#("`@(%5S87(@97-T82!L;V-A;&EZ8>?C;RXB"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C@*;7-G:60@(B`@+6TL("TM;6]D=6QE
M/4U/1%5,12`@("!"=6EL9"!-3R!F:6QE<R!O;FQY(&9O<B!T:&ES("A(;W)D
M92D@;6]D=6QE+B(*;7-G<W1R("(B"B(@("UM+"`M+6UO9'5L93U-TT153$\@
M("`@0V]N<W1R=6ER(&%R<75I=F]S($U/(&%P96YA<R!P87)A(&5S=&4@;?-D
M=6QO7&XB"B(@("`@("`@("`@("`@("`@("`@("`@("`@*$AO<F1E*2XB"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#,*;7-G:60@(B`@+6TL("TM;6]D=6QE
M/4U/1%5,12`@("!#;&5A;G5P(%!/(&9I;&5S(&]N;'D@9F]R('1H:7,@*$AO
M<F1E*2!M;V1U;&4N(@IM<V=S='(@(B(*(B`@+6TL("TM;6]D=6QE/4W31%5,
M3R`@("!,:6UP87(@87)Q=6EV;W,@4$\@87!E;F%S('!A<F$@97-T92!M\V1U
M;&]<;B(*(B`@("`@("`@("`@("`@("`@("`@("`@("`H2&]R9&4I+B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HT.`IM<V=I9"`B(@HB("`M;2P@+2UM;V1U
M;&4]34]$54Q%("`@($-O;6UI="!T<F%N<VQA=&EO;G,@;VYL>2!F;W(@=&AI
M<R`H2&]R9&4I(&UO9'5L92XB"FUS9W-T<B`B(@HB("`M;2P@+2UM;V1U;&4]
M3=-$54Q/("`@($-O;65T97(@87,@=')A9'7G]65S(&%P96YA<R!P87)A(&5S
M=&4@;?-D=6QO7&XB"B(@("`@("`@("`@("`@("`@("`@("`@("`@*$AO<F1E
M*2XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C(*;7-G:60@(B`@+6TL("TM
M;6]D=6QE/4U/1%5,12`@("!#<F5A=&4@82!03R!F:6QE(&]N;'D@9F]R('1H
M:7,@*$AO<F1E*2!M;V1U;&4N(@IM<V=S='(@(B(*(B`@+6TL("TM;6]D=6QE
M/4W31%5,3R`@("!#<FEA<B!O(&%R<75I=F\@4$\@87!E;F%S('!A<F$@97-T
M92!M\V1U;&]<;B(*(B`@("`@("`@("`@("`@("`@("`@("`@("`H2&]R9&4I
M+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HX,`IM<V=I9"`B("`M;2P@+2UM
M;V1U;&4]34]$54Q%("`@($UE<F=E(%!/(&9I;&5S(&]N;'D@9F]R('1H:7,@
M*$AO<F1E*2!M;V1U;&4N(@IM<V=S='(@(B(*(B`@+6TL("TM;6]D=6QE/4W3
M1%5,3R`@("!);G1E9W)A<B!A<G%U:79O<R!03R!A<&5N87,@<&%R82!E<W1E
M(&WS9'5L;UQN(@HB("`@("`@("`@("`@("`@("`@("`@("`@("A(;W)D92DN
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C<V"FUS9VED("(B"B(@("UM+"`M
M+6UO9'5L93U-3T153$4@("`@57!D871E(&AE;'`@9FEL97,@;VYL>2!F;W(@
M=&AI<R`H2&]R9&4I(&UO9'5L92XB"FUS9W-T<B`B(@HB("`M;2P@+2UM;V1U
M;&4]3=-$54Q/("`@($%C='5A;&EZ87(@87)Q=6EV;W,@9&4@86IU9&$@87!E
M;F%S('!A<F$@97-T95QN(@HB("`@("`@("`@("`@("`@("`@("`@("`@(&WS
M9'5L;R`H2&]R9&4I+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HX-@IM<V=I
M9"`B("`M;2P@+2UM;V1U;&4]34]$54Q%("`@(%5P9&%T92!O;FQY('1H:7,@
M*$AO<F1E*2!M;V1U;&4N(@IM<V=S='(@(B`@+6TL("TM;6]D=6QE/4U/1%5,
M12`@("!!8W1U86QI>F%R(&%P96YA<R!E<W1E(&WS9'5L;R`H2&]R9&4I+B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HU.`IM<V=I9"`B("`M;2P@+2UM;V1U
M;&4]34]$54Q%("!'96YE<F%T92!03U0@9FEL92!O;FQY(&9O<B!T:&ES("A(
M;W)D92D@;6]D=6QE+B(*;7-G<W1R("(B"B(@("UM+"`M+6UO9'5L93U-3T15
M3$4@("`@1V5R87(@87)C:&EV;R!03U0@87!E;F%S('!A<F$@97-T92!M\V1U
M;&]<;B(*(B`@("`@("`@("`@("`@("`@("`@("`@("`H2&]R9&4I+B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HW,`IM<V=I9"`B(@HB("`M;BP@+2UN;RUC
M;VUP96YD:75M("`@($1O;B=T(&UE<F=E(&YE=R!T<F%N<VQA=&EO;G,@=&\@
M=&AE(&-O;7!E;F1I=6TN(@IM<V=S='(@(B`@+6XL("TM;F\M8V]M<&5N9&EU
M;2`@("!.XV\@:6YT96=R87(@;F]V87,@=')A9'7G]65S(&YO(&-O;7#J;F1I
M;RXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C0@<&\O=')A;G-L871I;VXN
M<&AP.C@R('!O+W1R86YS;&%T:6]N+G!H<#HX.`IM<V=I9"`B("`M;BP@+2UN
M;RUC;VUP96YD:75M("`@($1O;B=T('5S92!A(&-O;7!E;F1I=6TN(@IM<V=S
M='(@(B`@+6XL("TM;F\M8V]M<&5N9&EU;2`@("!.XV\@=7-A<B!U;2!C;VUP
MZFYD:6\N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C<Q"FUS9VED("(@("US
M+"`M+7-T871I<W1I8W,@("`@("`@4V%V92!T<F%N<VQA=&EO;B!S=&%T:7-T
M:6-S(&EN(&$@;&]C86P@9FEL92XB"FUS9W-T<B`B(@HB("`M<RP@+2US=&%T
M:7-T:6-S("`@("`@($=U87)D87(@97-T873M<W1I8V%S(&1E('1R861UY^-O
M(&YU;2!F:6-H96ER;R!L;V-A;"XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,3$V"FUS9VED("(@("UT+"`M+71E<W0@("`@("`@(%-H;W<@=&AE(&5X96-U
M=&5D(&-O;6UA;F1S(&)U="!D;VXG="!R=6X@86YY=&AI;F<N(@IM<V=S='(@
M(B`@+70L("TM=&5S="`@("`@("`@36]S=')A<B!O<R!P<F]G<F%M87,@82!E
M>&5C=71A<B!M87,@;N-O(&\@9F%Z97(N(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C$P-0IM<V=I9"`B(@HB("!C;&5A;G5P("`@("!#;&5A;G,@=&AE(%!/
M(&9I;&5S('5P(&9R;VT@=6YT<F%N<VQA=&5D(&%N9"!O8G-O;&5T92!E;G1R
M:65S+B(*;7-G<W1R("(B"B(@(&-L96%N=7`@("`@($QI;7!A<B!O9B!A<G%U
M:79O<R!03R!D92!E;G1R861A<R!P;W(@=')A9'5Z:7(@;W4@;V)S;VQE=&%S
M+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#@*;7-G:60@(B`@8V]M;6ET
M("`@("`@0V]M;6ET('1R86YS;&%T:6]N<R!T;R!T:&4@0U93('-E<G9E<BXB
M"FUS9W-T<B`B("!C;VUM:70@("`@("!#;VUE=&5R(&%S('1R861UY_5E<R!N
M;R!S97)V:61O<B!#5E,N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P.0IM
M<V=I9"`B("!C;VUM:70M:&5L<"!#;VUM:70@:&5L<"!F:6QE<R!T;R!T:&4@
M0U93('-E<G9E<BXB"FUS9W-T<B`B("!C;VUM:70M:&5L<"!#;VUE=&5R(&%R
M<75I=F]S(&1E(&%J=61A(&YO('-E<G9I9&]R($-64RXB"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z.3D*;7-G:60@(B(*(B`@8V]M<&5N9&EU;2`@4F5B=6EL
M9"!T:&4@8V]M<&5N9&EU;2!F:6QE+B!787)N:6YG.B!4:&ES(&]V97)W<FET
M97,@=&AE7&XB"B(@("`@("`@("`@("`@(&-U<G)E;G0@8V]M<&5N9&EU;2XB
M"FUS9W-T<B`B(@HB("!C;VUP96YD:75M("!296-O;G-T<G5I<B!O(&%R<75I
M=F\@9&4@8V]M<.IN9&EO+B!!=&5NY^-O.B!/(&YO=F\@87)Q=6EV;UQN(@HB
M("`@("`@("`@("`@("!S;V)R97#U92US92!A;R!A;G1I9V\N(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C$P,`IM<V=I9"`B("!E>'1R86-T("`@("!'96YE
M<F%T92!03R!T96UP;&%T92`H+G!O="D@9FEL97,N(@IM<V=S='(@(B`@97AT
M<F%C="`@("`@1V5R87(@87)Q=6EV;W,@;6]D96QO(%!/("@N<&]T*2XB"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.3@*;7-G:60@(B`@:&5L<"`@("`@("`@
M4VAO=R!T:&ES(&AE;'`@;65S<V%G92XB"FUS9W-T<B`B("!H96QP("`@("`@
M("!-;W-T<F%R(&5S=&$@;65N<V%G96T@9&4@86IU9&$N(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C$P,0IM<V=I9"`B(@HB("!I;FET("`@("`@("!#<F5A
M=&4@;VYE(&]R(&UO<F4@4$\@9FEL97,@9F]R(&$@;F5W(&QO8V%L92X@5V%R
M;FEN9SH@5&AI<UQN(@HB("`@("`@("`@("`@("!O=F5R=W)I=&5S('1H92!E
M>&ES=&EN9R!03R!F:6QE<R!O9B!T:&ES(&QO8V%L92XB"FUS9W-T<B`B(@HB
M("!I;FET("`@("`@("!#<FEA<B!U;2!O=2!M86ES(&%R<75I=F]S(%!/('!A
M<F$@=6UA(&YO=F$@;&]C86QI>F'GXV\N7&XB"B(@("`@("`@("`@("`@($%T
M96[GXV\Z($]S(&YO=F]S(&%R<75I=F]S('-O<')E</5E;2US92!A;W,@86YT
M:6=O<RXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`V"FUS9VED("(@(&UA
M:V4@("`@("`@($)U:6QD(&)I;F%R>2!-3R!F:6QE<R!F<F]M('1H92!S<&5C
M:69I960@4$\@9FEL97,N(@IM<V=S='(@(B(*(B`@;6%K92`@("`@("`@0V]N
M<W1R=6ER(&%R<75I=F]S(&)I;N%R:6]S($U/(&$@<&%R=&ER(&1O<R!A<G%U
M:79O<UQN(@HB("`@("`@("`@("`@("!03R!E<W!E8VEF:6-A9&]S+B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HQ,#<*;7-G:60@(B(*(B`@;6%K92UH96QP
M("`@36%R:R!A;&P@96YT<FEE<R!I;B!T:&4@6$U,(&AE;'`@9FEL92!B96EN
M9R!U<"UT;RUD871E(&%N9%QN(@HB("`@("`@("`@("`@("!P<F5P87)E('1H
M92!F:6QE(&9O<B!T:&4@;F5X="!E>&5C=71I;VX@;V8@=7!D871E+6AE;'`N
M(%EO=5QN(@HB("`@("`@("`@("`@("!S:&]U;&0@;VYL>2!R=6X@;6%K92UH
M96QP($%&5$52('5P9&%T92UH96QP(&%N9"!R979I<VEN9R!T:&5<;B(*(B`@
M("`@("`@("`@("`@:&5L<"!F:6QE+B(*;7-G<W1R("(B"B(@(&UA:V4M:&5L
M<"`@($UA<F-A<B!T;V1A<R!A<R!E;G1R861A<R!N;R!A<G%U:79O(%A-3"!D
M92!A:G5D82!C;VUO(&5S=&%N9&]<;B(*(B`@("`@("`@("`@("`@86-T=6%L
M:7IA9&%S(&4@<')E<&%R87(@;R!A<G%U:79O('!A<F$@82!P<O-X:6UA(&5X
M96-UY^-O7&XB"B(@("`@("`@("`@("`@(&1E('5P9&%T92UH96QP+B!$979E
M+7-E(&5X96-U=&%R(&UA:V4M:&5L<"!$15!/25,@9&5<;B(*(B`@("`@("`@
M("`@("`@=7!D871E+6AE;'`@92!D92!R979E<B!O(&%R<75I=F\@9&4@86IU
M9&$N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P,@IM<V=I9"`B(@HB("!M
M97)G92`@("`@("!-97)G92!T:&4@8W5R<F5N="!03R!F:6QE('=I=&@@=&AE
M(&-U<G)E;G0@4$\@=&5M<&QA=&4@9FEL92XB"FUS9W-T<B`B(@HB("!M97)G
M92`@("`@("!);G1E9W)A<B!O(&%R<75I=F\@4$\@8V]R<F5N=&4@8V]M(&\@
M87)Q=6EV;R!M;V1E;&\@4$\@(@HB8V]R<F5N=&4N(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C$P,PIM<V=I9"`B("!U<&1A=&4@("`@("!2=6X@97AT<F%C
M="!A;F0@;65R9V4@<V5Q=65N="XB"FUS9W-T<B`B("!U<&1A=&4@("`@("!%
M>&5C=71A<B!E>'1R86-T(&4@;65R9V4@96T@<V5Q=>IN8VEA+B(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HQ,#0*;7-G:60@(B(*(B`@=7!D871E+6AE;'`@
M17AT<F%C="!A;&P@;F5W(&%N9"!C:&%N9V5D(&5N=')I97,@9G)O;2!T:&4@
M16YG;&ES:"!834P@:&5L<%QN(@HB("`@("`@("`@("`@("!F:6QE(&%N9"!M
M97)G92!T:&5M('=I=&@@=&AE(&5X:7-T:6YG(&]N97,N(@IM<V=S='(@(B(*
M(B`@=7!D871E+6AE;'`@17AT<F%I<B!T;V1A<R!A<R!E;G1R861A<R!N;W9A
M<R!E(&UO9&EF:6-A9&%S(&1O(&%R<75I=F\@9&5<;B(*(B`@("`@("`@("`@
M("`@86IU9&$@6$U,(&5M(&EN9VSJ<R!E(&EN=&5G<N$M;&%S(&-O;2!A<R!E
M>&ES=&5N=&4N(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?
M=&]P+FEN8SHQ,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(@)B,Q-3$[("5S
M(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@8VAE8VME9"!B96QO=RXB"FUS9W-T<B`B(@HB("8C,34Q.R`E<R!E<W3A
M('!R;VYT;R!P87)A(&5F96-T=6%R(&%S(&]P97)AY_5E<R!D92!M86YU=&5N
MY^-O(&UA<F-A9&%S("(*(F%B86EX;RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C,V.`HC+"!P:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@86=O*2(*
M;7-G<W1R("(@*"5S(&1I87,@871RX7,I(@H*(SH@;&EB+TAO<F1E+G!H<#HQ
M,C4V"B,L('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G
M<W1R("(@*$-H879E(&1E(&%C97-S;R`E<RDB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C,W-@HC+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I
M(@IM<V=S='(@(B`H9&5N=')O(&1E("5S(&1I87,I(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(S-S(*;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(B`H:&]J
M92DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W-`IM<V=I9"`B("AT;VUO
M<G)O=RDB"FUS9W-T<B`B("AA;6%N:.,I(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(S-S`*;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(@*&]N=&5M
M*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#0@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,T.0HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,SDU"FUS9VED("(@870@(@IM<V=S='(@(B!C;VT@(@H*
M(SH@;&EB+TAO<F1E+T-,22YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@
M(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(EPB)7-<
M(B!NXV\@Z2!U;6$@97-C;VQH82!VX6QI9&$N(@H*(SH@;&EB+TAO<F1E+U)E
M9VES=')Y+G!H<#HU-30@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HY,S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN
M('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B7"(E<UPB(&[C;R!E<W3A
M(&-O;F9I9W5R861O(&YO(%)E9VES=&\@9&\@2&]R9&4N(@H*(SH@;&EB+TAO
M<F1E+U1R964N<&AP.C$V-`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(EPB)7-<(B!R97!R
M97-E;G1A9&]R(&1E(.%R=F]R92!NXV\@96YC;VYT<F%D;RXB"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C4W"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W
M87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(EPB)7-<
M(B!F;VD@861I8VEO;F%D;R!A;R!S:7-T96UA(&1E(&=R=7!O<RXB"@HC.B!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M
M+B(*;7-G<W1R(")<(B5S7"(G(&9O:2!A9&EC:6]N861O(&%O('-I<W1E;6$@
M9&4@<&5R;6ES<_5E<RXB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4U(&%D;6EN
M+W!E<FUS+V%D9&-H:6QD+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")<
M(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B7"(E<UPB(&[C
M;R!F;VD@8W)I861O.B`E<RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C(U"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N9"`E<R(*
M;7-G<W1R("(E9"`E<R!E("5S(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$Q
M-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@8GET97,@=W)I='1E;BXB"FUS
M9W-T<B`B)60@8GET97,@97-C<FET;W,B"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z,3(X-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!O9B`E9"!E;G1R:65S
M(&UA<FME9"!A<R!U<"UT;RUD871E(@IM<V=S='(@(B5D(&1E("5D(&5N=')A
M9&$@;6%R8V%D87,@8V]M;R!A8W1U86QI>F%D87,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C<S"B,L('!H<"UF;W)M870*;7-G:60@(B5D
M+61A>2!F;W)E8V%S="(*;7-G<W1R(")P<F5V:7/C;R!D92`E9"!D:6%S(@H*
M(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VYO=&EC95]T;W`N:6YC.C0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B)7,@+2!.
M;W1I9FEC8>?C;R(*"B,Z('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R
M+FEN8SHS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!!9&UI;FES=')A=&EO
M;B(*;7-G<W1R("(E<R!!9&UI;FES=')AY^-O(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HW,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN
M9V5R<')I;G0B"FUS9W-T<B`B)7,@26UP<F5S<^-O($1I9VET86PB"@HC.B!L
M:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#,P(&QI8B](;W)D92]-24U%
M+T-O;G1E;G1S+G!H<#HX,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B
M"FUS9W-T<B`B)7,@2T(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N
M9FER;5]T;W`N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E
M;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(E<R!/
M<&5R8>?U97,@9&4@36%N=71E;N?C;R`M($-O;F9I<FUAY^-O(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,C$X"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(D-O
M;F9I9W5R87(@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V
M,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N(%5P(@IM<V=S='(@(B5S
M(%-U8G-C<F5V97(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O86=R965M
M96YT7W1O<"YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O
M9B!!9W)E96UE;G0B"FUS9W-T<B`B)7,@5&5R;6]S(&1O($%C;W)D;R(*"B,Z
M(&QI8B]61E,O9G1P+G!H<#HU-C@@;&EB+U9&4R]F='`N<&AP.C8S-@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B
M)7,@:N$@97AI<W1E+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Y(&QI
M8B]";&]C:R]M971A<BYP:'`Z,38U(&QI8B]";&]C:R]M971A<BYP:'`Z,C,Y
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S0U(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S4Q"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S
M='(@(B5S(&5M("5S("5S(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C(X-R!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,S$T"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&ES(&YO="!W<FET86)L92XB"FUS9W-T<B`B;N-O('-E('!O9&4@97-C<F5V
M97(@96T@)7,N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S,SD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`B)7,@Z2!O
M8G)I9V%T\W)I;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@V"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(&UI;G5T97,B"FUS9W-T<B`B)7,@;6EN=71O
M<R(*"B,Z(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,C,@<&\O
M=')A;G-L871I;VXN<&AP.C$S-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M;F]T(&9O=6YD+B(*;7-G<W1R("(E<R!NXV\@9F]I(&5N8V]N=')A9&\N(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C4X-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!N;W0@9F]U;F0N(%)U;B`G=')A;G-L871I;VX@97AT<F%C="<@9FER
M<W0N(@IM<V=S='(@(B5S(&[C;R!F;VD@96YC;VYT<F%D;RX@17AE8W5T87(@
M)W1R86YS;&%T:6]N(&5X=')A8W0G('!R:6UE:7)O+B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B)7,@82`E<R!D92`E<R(*"B,Z(&QI
M8B](;W)D92]+;VQA8BYP:'`Z.#DQ"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M)W,@061D<F5S<R!";V]K(@IM<V=S='(@(D-O;G1A8W1O<R!D92`E<R(*"B,Z
M(&QI8B](;W)D92]+;VQA8BYP:'`Z.#@S"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B0V%L96YDX7)I;R!D92`E<R(*"B,Z
M(&QI8B](;W)D92]+;VQA8BYP:'`Z.#<U"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S)W,@3F]T97!A9"(*;7-G<W1R(").;W1A<R!D92`E<R(*"B,Z(&QI8B](
M;W)D92]+;VQA8BYP:'`Z.#DY"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@
M5&%S:VQI<W0B"FUS9W-T<B`B5&%R969A<R!D92`E<R(*"B,Z(&QI8B](;W)D
M92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B)7,Z("5S(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U,R!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,SDX"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(BP@
M8V]M(')A:F%D87,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X."!L:6(O
M0FQO8VLO;65T87(N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U
M<W1I;F<@)7,@)7,B"FUS9W-T<B`B+"!C;VT@<F%J861A<R`E<R`E<R(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@
M(BP@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(L('9A<FGA=F5L
M(&1E("5S(&$@)7,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`W,"!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C$R.0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-C@X"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B
M+2T@97-C;VQH82`M+2(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,S(X('!O
M+W1R86YS;&%T:6]N+G!H<#HQ,S,P"FUS9VED("(M+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TB"FUS9W-T<B`B+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P"FUS9VED("(Q,B!(;W5R
M($9O<FUA="(*;7-G<W1R(")&;W)M871O(&1E(#$R(&AO<F%S("A!32]032DB
M"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3D*;7-G:60@(C(T($AO=7(@1F]R
M;6%T(@IM<V=S='(@(D9O<FUA=&\@9&4@,C0@:&]R87,B"@HC.B!T96UP;&%T
M97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B
M,C0@:&]R87,B"@HC.B!L:6(O2&]R9&4O54DO4&%G97(N<&AP.C8Y"FUS9VED
M("(\4')E=FEO=7,B"FUS9W-T<B`B/$%N=&5R:6]R(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C,T-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(\9V5T=&5X
M=#X@=&%G(&YO="!C;&]S960@:6X@9FEL92`E<RY<;B(*(D]P96YI;F<@=&%G
M(&9O=6YD(&EN(&QI;F4@)60N(@IM<V=S='(@(B(*(F5T:7%U971A(#QG971T
M97AT/B!P;W(@9F5C:&%R(&YO(&9I8VAE:7)O("5S+EQN(@HB06)R:6YD;R!A
M(&5T:7%U971A(&5N8V]N=')A9&$@;F$@;&EN:&$@)60N(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ,3D*;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I
M<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RXB"FUS9W-T<B`B17-T92!B;&]C
M;R!E>&EG92!U;2!M96-A;FES;6\@=7-A;F1O(&)A<V5S(&1E(&1A9&]S+B(*
M"B,Z(&QI8B](;W)D92YP:'`Z,38P"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA
M<R!O8V-U<G)E9"(*;7-G<W1R(")/8V]R<F5U('5M(&5R<F\@9F%T86PB"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY,C`*;7-G:60@(D$@<'5B;&EC
M(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM
M<V=S='(@(LD@;F5C97-SX7)I82!U;6$@8VAA=F4@</IB;&EC82!01U`@<&%R
M82!E;F-R:7!T87(@82!M96YS86=E;2XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HQ,30U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"B+)
M(&YE8V5S<^%R:6$@=6UA(&-H879E('#Z8FQI8V$@4$=0('!A<F$@=F5R:69I
M8V%R(&$@87-S:6YA='5R82!D92!U;6$@(@HB;65N<V%G96TB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#<W"FUS9VED("(B"B)!('!U8FQI8R!0
M1U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB
M4&%R82!D96-I9G)A<B!U;6$@;65N<V%G96T@<^-O(&YE8V5S<^%R:6%S('5M
M82!C:&%V92!P^F)L:6-A(%!'4"P@=6UA(&-H879E("(*(G!R:79A9&$@4$=0
M(&4@=6UA(&9R87-E+7!A<W-E+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.CDY-0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!0
M1U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A
M("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(E!A<F$@87-S:6YA<B!U;6$@;65N
M<V%G96T@<^-O(&YE8V5S<^%R:6%S('5M82!C:&%V92!P^F)L:6-A(%!'4"P@
M=6UA(&-H879E("(*(G!R:79A9&$@4$=0(&4@=6UA(&9R87-E+7!A<W-E+B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3`U"FUS9VED("(B"B)!
M('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G
M92XB"FUS9W-T<B`B(@HB4&%R82!D96-I9G)A<B!U;6$@;65N<V%G96T@<^-O
M(&YE8V5S<^%R:6%S('5M82!C:&%V92!P^F)L:6-A(%,O34E-12P@=6UA("(*
M(F-H879E('!R:79A9&$@4R]-24U%(&4@=6UA(&9R87-E+7!A<W-E+B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U
M8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS
M9W-T<B`B(@HB4&%R82!A<W-I;F%R('5M82!M96YS86=E;2!SXV\@;F5C97-S
MX7)I87,@=6UA(&-H879E('#Z8FQI8V$@4R]-24U%+"!U;6$@(@HB8VAA=F4@
M<')I=F%D82!3+TU)344@92!U;6$@9G)A<V4M<&%S<V4N(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G:60@(D$@<'5B;&EC(%--24U%
M(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T
M<B`BR2!N96-E<W/A<FEA('5M82!C:&%V92!P^F)L:6-A(%,O34E-12!P87)A
M(&5N8W)I<'1A<B!U;6$@;65N<V%G96TN(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B04T@0VQO=61S(@IM<V=S
M='(@(D[Z=F5N<R!D92!M86YHXR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!,:6=H="!286EN(@IM<V=S
M='(@(D-H=79I<V-O<R!D92!-86YHXR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"FUS9VED(")!32!286EN(@IM<V=S='(@
M(D-H=79A(&1E(&UA;FCC(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`B06=U
M86-E:7)O<R!D92!M86YHXR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T
M<B`B3F5V]65S(&1E(&UA;FCC(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI
M;F,Z,CD*;7-G:60@(D%-+U!-(@IM<V=S='(@(D%-+U!-(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*
M;7-G<W1R(")!4$D@240B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G
M<W1R(")!8V5R8V$@9&5S=&4@961I=&]R(@H*(SH@<V5R=FEC97,O:&5L<"]I
M;F1E>"YP:'`Z-3(*;7-G:60@(D%B;W5T+BXN(@IM<V=S='(@(D%C97)C82XN
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R(")"87-E<R!A;&EN:&%D87,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R
M"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B0V5N=')O<R!A;&EN:&%D;W,B
M"@HC.B!L:6(O5D93+VUU<W%L+G!H<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI
M960@8W)E871I;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B06-E<W-O(&YE
M9V%D;R!A;R!C<FEA<B!P87-T82!61E,N(@H*(SH@;&EB+U9&4R]M=7-Q;"YP
M:'`Z,3,V"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE
M+B(*;7-G<W1R(")!8V5S<V\@;F5G861O(&%O(&-R:6%R(&%R<75I=F\@5D93
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-0IM<V=I9"`B06-C;W5N
M="!087-S=V]R9"(*;7-G<W1R(")086QA=G)A+5!A<W-E(&1A($-O;G1A(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*;7-G:60@
M(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R(")#;VYT82!C;VYG96QA9&$N(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,Q-PIM<V=I9"`B06-C;W5N
M=&EN9R(*;7-G<W1R(")#;VYT86)I;&ED861E(@H*(SH@861M:6XO<&5R;7,O
M861D8VAI;&0N<&AP.C4T(&QI8B](;W)D92]097)M<R]522YP:'`Z,3,R"B,Z
M('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ-"!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V%D9&-H:6QD+FEN8SHQ-@IM<V=I9"`B061D(@IM<V=S='(@(D%D
M:6-I;VYA<B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$T(&%D;6EN+V=R;W5P
M<RYP:'`Z,C$U"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B061I
M8VEO;F%R($=R=7!O($9I;&AO(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HX-"!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C@U"FUS9VED(")!9&0@0VAI
M;&0@4&5R;6ES<VEO;B(*;7-G<W1R(")!9&EC:6]N87(@4&5R;6ES<^-O($9I
M;&AA(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*;7-G:60@(D%D
M9"!(97)E.B(*;7-G<W1R(")!8W)E<V-E;G1A<B!!<75I.B(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,C`X(&%D;6EN+V=R;W5P<RYP:'`Z,C`Y"FUS9VED(")!
M9&0@3F5W($=R;W5P(@IM<V=S='(@(D%D9&EC:6]N87(@3F]V;R!'<G5P;R(*
M"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-S,@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HW-`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@
M(D%D:6-I;VYA<B!.;W9A(%!E<FUI<W/C;R(*"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O861D8VAI;&0N:6YC.CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(D%D:6-I;VYA
M<B!U;2!G<G5P;R!F:6QH;R!A(%PB)7-<(B(*"B,Z(&%D;6EN+W!E<FUS+V%D
M9&-H:6QD+G!H<#HU,R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$S,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O(%PB
M)7-<(B(*;7-G<W1R(")!9&EC:6]N87(@=6UA('!E<FUI<W/C;R!F:6QH82!A
M(%PB)7-<(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED(")!9&0@82!N
M97<@=7-E<CHB"FUS9W-T<B`B061I8VEO;F%R(&YO=F\@=71I;&EZ861O<CHB
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(V"FUS
M9VED(")!9&0@8V]L=6UN(@IM<V=S='(@(D%D:6-I;VYA<B!C;VQU;F$B"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,U"FUS9VED(")!
M9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`B061I8VEO;F%R(&YO=F]S(&UE;6)R
M;W,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B
M061D('!A:7(B"FUS9W-T<B`B061I8VEO;F%R('!A<F-E:7)O(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,U.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!
M9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(B"FUS9W-T<B`B
M061I8VEO;F%R(&\@365N=2`E<R!C;VUO($)A<G)A($QA=&5R86P@36]Z:6QL
M82(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*;7-G
M:60@(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(D%D:6-I;VYA<B!A
M;W,@0V]N=&%C=&]S.B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z-S@*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T
M<B`B061I8VEO;F%R(&%O<R!M975S(&-O;G1A8W1O<R(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R(")!9&EC:6]N87(@
M=71I;&EZ861O<B(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@
M8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@
M(@HB)7,N(@IM<V=S='(@(B(*(D%D:6-I;VYE:2!<(B5S7"(@86\@<VES=&5M
M82P@;6%S(&[C;R!P=61E(&%D:6-I;VYA<B!I;F9O<FUAY^-O(&1E('-U8G-C
M<FGGXV\@(@HB861I8VEO;F%L.B`E<RXB"@HC.B!S:6=N=7`N<&AP.C0U"B,L
M('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M
M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(D%D:6-I;VYE:2!<(B5S
M7"(@86\@<VES=&5M82X@2N$@<&]D92!E;G1R87(N(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.CDV,@IM<V=I9"`B061D:6YG(&YE=R!F:6QE<R!T;R!R97!O
M<VET;W)Y.B(*;7-G<W1R(")!9&EC:6]N86YD;R!N;W9O<R!A<G%U:79O<R!A
M;R!R97!O<VET\W)I;SHB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D
M9"YI;F,Z-`IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G
M<W1R(")!(&%D:>?C;R!D92!U=&EL:7IA9&]R97,@97-TX2!D97-A8W1I=F%D
M82XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30T,R!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$W,PIM<V=I9"`B061D<F5S<R(*;7-G<W1R(")%;F1E
M<F7G;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,SD*;7-G:60@
M(D%D9')E<W,@0F]O:R(*;7-G<W1R(")#;VYT86-T;W,B"@HC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30*;7-G:60@(D%D;6EN:7-T97(@
M+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S='(@(D%D
M;6EN:7-T<F%R("T@871R:6)U:7(@<&5R;6ES<_5E<R!A(&]U=')O<R!U=&EL
M:7IA9&]R97,B"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R
M=&%L+W-I9&5B87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R871I;VXB"FUS
M9W-T<B`B061M:6YI<W1R8>?C;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS.3(*;7-G:60@(D%D<R(*;7-G<W1R(")!;OIN8VEO<R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-38*;7-G:60@
M(D%F9VAA;FES=&%N(@IM<V=S='(@(D%F96=A;FES=.-O(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06QB
M86YI82(*;7-G<W1R(")!;&+B;FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C<T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B06QG97)I82(*;7-G<W1R
M(")!<F?I;&EA(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,#<*;7-G:60@(D%L:6%S(@IM<V=S='(@(D%L8W5N:&$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$V"FUS
M9VED(")!;&EG;B(*;7-G<W1R(")!;&EN:&%R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI9VYM96YT
M.B(*;7-G<W1R(")!;&EN:&%M96YT;SHB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R(")4=61O(@H*(SH@861M:6XO
M<&5R;7,O961I="YP:'`Z,3$X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M-C4*;7-G:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(E1O
M9&]S(&]S(%5T:6QI>F%D;W)E<R!!=71E;G1I8V%D;W,B"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C$R"FUS9VED(")!;&P@
M1W)O=7!S(@IM<V=S='(@(E1O9&]S(&]S($=R=7!O<R(*"B,Z(&%D;6EN+W!E
M<FUS+V%D9&-H:6QD+G!H<#HS."!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C<W
M"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`B5&]D87,@87,@4&5R
M;6ES<_5E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@
M(E1O9&]S(&]S("AQ=6%T<F\I(&QA9&]S(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$X-S(*;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G
M<W1R(")097)M:71I<B!M^FQT:7!L;W,@96YD97)EYV]S(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4R-@IM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O
M<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B4&5R;6ET:7(@871R:6)U:>?C
M;R!D;R!T:7!O(&1E(&QI<W1A<R!O<F1E;F%D87,_(@H*(SH@;&EB+TAO<F1E
M+T1A=&%4<F5E+W-Q;"YP:'`Z-#`X"FUS9VED(")!;')E861Y(&5X:7-T<R(*
M;7-G<W1R(")*X2!E>&ES=&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3(S"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R(")%;G1R
M861A($E-4U`@06QT97)N871I=F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#DY"FUS9VED(")!;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R
M(")086QA=G)A+5!A<W-E($E-4U`@06QT97)N871I=F$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#DQ"FUS9VED(")!;'1E<FYA=&4@24U34"!5<V5R
M;F%M92(*;7-G<W1R(").;VUE(&1E(%5T:6QI>F%D;W(@24U34"!!;'1E<FYA
M=&EV;R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED
M(")!;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R(")%;F1E<F7G;R!I
M;G;A;&ED;R(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!
M;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(DUO9&5L;W,@86QT97)N871I
M=F]S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS9W-T
M<B`B5&5X=&\@86QT97)N871I=F\Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@4V%M;V$B
M"FUS9W-T<B`B4V%M;V$@06UE<FEC86YA(@H*(SH@;&EB+TAO<F1E+U!R969S
M+U5)+G!H<#HY-2!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B
M06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R(")&;VD@
M97-P96-I9FEC861O('5M('9A;&]R(&EN=N%L:61O+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-30*;7-G:60@(D%N('5N:VYO=VX@97)R
M;W(@:&%S(&]C8W5R960N(@IM<V=S='(@(D]C;W)R974@=6T@97)R;R!D97-C
M;VYH96-I9&\N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HU-0IM<V=I9"`B06YD;W)R82(*;7-G<W1R(")!;F1O<G)A(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.`IM
M<V=I9"`B06YG;VQA(@IM<V=S='(@(D%N9V]L82(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I;&QA
M(@IM<V=S='(@(D%N9W5I;&$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R(")%;G1R97!O
M<W1O("AP<F]X>2D@06[S;FEM;R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T<B`B4F5S<&]S=&$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X"FUS
M9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(D%N=.%R8W1I8V\B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!
M;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S='(@(D%N=.UG=6$@92!"87)B=61A
M(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HW-"!A9&UI;B]P:'!S:&5L;"YP
M:'`Z,S4@;&EB+TAO<F1E+T)L;V-K+U5)+G!H<#HU.`HC.B!T96UP;&%T97,O
M861M:6XO<V5T=7`O:6YD97@N:'1M;#HV"FUS9VED(")!<'!L:6-A=&EO;B(*
M;7-G<W1R(")!<&QI8V'GXV\B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3,Y"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`B07!L
M:6-AY^-O('!R;VYT82XB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@(D%P
M;&EC87(@82!087)T:6QH87,@1FEL:&%S(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B
M07!R;W9A<B(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX,S`*
M;7-G:60@(D%P<')O>&EM871E(%-I>F4B"FUS9W-T<B`B5&%M86YH;R!!<')O
M>&EM861O(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C,W-R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$T"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C@*;7-G
M:60@(D%P<FEL(@IM<V=S='(@(D%B<FEL(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ-S4*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R
M(")!<N%B:6-O("A7:6YD;W=S+3$R-38I(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-3D@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C8*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*;7-G
M:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@(E1A;6%N:&\@9&\@1FEC
M:&5I<F\@9&4@07)Q=6EV;R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R
M87(N<&AP.C4X(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8U"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<W"FUS9VED(")!<F-H
M:79E($YA;64B"FUS9W-T<B`B3F]M92!D;R!!<G%U:79O(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHY"B,L('!H<"UF;W)M
M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE
M('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(E1E;2!A(&-E<G1E
M>F$@<75E('%U97(@<F5M;W9E<B!O('!E9&ED;R!D92!S=6)S8W)IY^-O('!A
M<F$@)7,@/R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN
M8SHY"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES
M:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS9W-T
M<B`B5&5M(&$@8V5R=&5Z82!Q=64@<75E<B!R96UO=F5R(%PB)7-<(B!E('%U
M86ES<75E<B!S=6(M9W)U<&]S/R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R
M(")!<F=E;G1I;F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C4W"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(D%R;>EN:6$B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-@IM<V=I9"`B07)M96YI86X@
M*$%235-#24DM."DB"FUS9W-T<B`B07)MZ6YI;R`H05)-4T-)22TX*2(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.`IM<V=I9"`B07)T(@IM<V=S='(@
M(D%R=&4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S`@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C4Y"FUS9VED(")!<G5B82(*;7-G<W1R(")!<G5B82(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*
M;7-G<W1R("));&AA(&1E($%S8V5N<^-O(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B07)T92!!4T-)
M22(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!<VEA
M+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@(E)E9VGC;R#!<VEA+U!A8^UF:6-O
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Q-PIM<V=I9"`B07-K(&9O
M<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,_(@IM<V=S='(@(E!E9&ER(&-O;F9I<FUAY^-O(&%N=&5S(&1E(')E
M86QI>F%R(&]P97)AY_5E<R!D92!M86YU=&5NY^-O/R(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HS,3$R"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS
M9W-T<B`B0V]L=6YA<R!D92!A=')I8G5IY^-O(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HW-0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E
M;G0@9W)O=7`N(@IM<V=S='(@(E1E;G1A=&EV82!D92!R96UOY^-O(&1E('5M
M(&=R=7!O(&EN97AI<W1E;G1E+B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP
M:'`Z,S@*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT
M('!E<FUI<W-I;VXN(@IM<V=S='(@(E1E;G1A=&EV82!D92!R96UOY^-O(&1E
M('5M82!P97)M:7-SXV\@:6YE>&ES=&5N=&4N(@H*(SH@861M:6XO<&5R;7,O
M961I="YP:'`Z.3@*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES
M=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")496YT871I=F$@9&4@961IY^-O
M(&1E('5M82!P97)M:7-SXV\@:6YE>&ES=&5N=&4N(@H*(SH@<V5R=FEC97,O
M<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N
M;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(E1E;G1A=&EV82!D92!E9&GG
MXV\@9&4@=6UA('!A<G1I;&AA(&EN97AI<W1E;G1E+B(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]R87(N<&AP.C8T(&QI8B](;W)D92]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<Q"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP
M.C@S"FUS9VED(")!='1R:6)U=&5S(@IM<V=S='(@(D%T<FEB=71O<R(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS.#$@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q.`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B
M"FUS9W-T<B`B06=O<W1O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Y
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')A;&EA(@IM<V=S='(@(D%U
M<W1RX6QI82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR."!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-3D*;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`BP75S=')I82(*"B,Z
M(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y
M<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R(")!=71H7V-Y<G-Q;#H@02!E>'1E;G/C;R!I;6%P(&YE8V5S<^%R:6$@
M;N-O(&9O:2!E;F-O;G1R861A+B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S
M+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@
M:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB"FUS9W-T<B`B075T:%]C>7)U
M<SH@3R!M96-A;FES;6\@;N-O('1E;2!A<R!C87!A8VED861E<R!N96-E<W/A
M<FEA<RXB"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3(R"FUS9VED
M(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(D%U=&A?8WER=7,Z($$@97AT96YSXV\@:6UA<"!N96-E
M<W/A<FEA(&[C;R!F;VD@96YC;VYT<F%D82XB"@HC.B!L:6(O2&]R9&4O075T
M:"]F='`N<&AP.C,V"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM
M96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@(B(*(D%U=&A?9G1P.B!!
M(&5X=&5N<^-O($944"!N96-E<W/A<FEA(&[C;R!F;VD@96YC;VYT<F%D82X@
M0V]M<&EL92!O(%!(4"!C;VT@82`B"B)O<.?C;R`M+65N86)L92UF='`N(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O:6UA<"YP:'`Z-C0*;7-G:60@(D%U=&A?:6UA
M<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M(")!=71H7VEM87`Z($$@97AT96YSXV\@24U!4"!N96-E<W/A<FEA(&[C;R!F
M;VD@96YC;VYT<F%D82XB"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HU
M,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:W)B-3H@02!E>'1E;G/C;R!K<F(U
M(&YE8V5S<^%R:6$@;N-O(&9O:2!E;F-O;G1R861A+B(*"B,Z(&QI8B](;W)D
M92]!=71H+VQD87`N<&AP.C4X"FUS9VED(")!=71H7VQD87`Z(%)E<75I<F5D
M($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]L9&%P
M.B!!(&5X=&5N<^-O($Q$05`@;F5C97-SX7)I82!NXV\@9F]I(&5N8V]N=')A
M9&$N(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,3@T"B,L('!H<"UF
M;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S
M+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@HB
M075T:%]L9&%P.B!);7!O<W/M=F5L(&%D:6-I;VYA<B!U=&EL:7IA9&]R("5S
M+B!%:7,@;R!Q=64@;R!S97)V:61O<B!D:7-S93H@(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O;&1A<"YP:'`Z,C(R"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?
M;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@(D%U=&A?
M;&1A<#H@26UP;W-S[79E;"!R96UO=F5R(&\@=71I;&EZ861O<B`E<R(*"B,Z
M(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C(X,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G
M<W1R(")!=71H7VQD87`Z($EM<&]S<^UV96P@86-T=6%L:7IA<B!O('5T:6QI
M>F%D;W(@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]M8V%L+G!H<#HT-@IM<V=I
M9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(D%U=&A?;6-A;#H@02!E>'1E;G/C;R!-0T%,(&YE8V5S
M<^%R:6$@;N-O(&9O:2!E;F-O;G1R861A+B(*"B,Z(&QI8B](;W)D92]!=71H
M+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB
M875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7W-M8F%U
M=&@Z($$@97AT96YSXV\@<VUB875T:"!N96-E<W/A<FEA(&[C;R!F;VD@96YC
M;VYT<F%D82XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y,`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S='(@(D$@
M875T96YT:6-AY^-O(&9A;&AO=2(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z-C<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL
M960N("5S(@IM<V=S='(@(D$@875T96YT:6-AY^-O(&9A;&AO=2X@)7,B"@HC
M.B!L:6(O2&]R9&4O075T:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B075T:&5N
M=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS9W-T<B`B
M02!A=71E;G1I8V'GXV\@9F]I(')E:F5I=&%D82!P96QO('-E<G9I9&]R(%)!
M1$E54RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S8X"FUS9VED(")!=71H96YT
M:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B02!A=71E
M;G1I8V'GXV\@;F\@<V5R=FED;W(@1E10(&9A;&AO=2XB"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.C@S"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S
M.B(*;7-G<W1R(")#86UP;W,@9&ES<&]N[79E:7,Z(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C,Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07IE<F)A
M:6IA;B(*;7-G<W1R(")!>F5R8F%I:N-O(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,P"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B1&5S8W5L
M<&%S(%PB0D]&2%PB(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R
M(")&=6YD;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`B0V]R
M(&1O($9U;F1O(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z.#$*;7-G
M:60@(D)A9"!K97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`B4&%L879R82U0
M87-S92!K97)B97)O<R!E<G)A9&$N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B
M-2YP:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS9W-T
M<B`B3F]M92!D92!5=&EL:7IA9&]R(&ME<F)E<F]S(&5R<F%D;RXB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED
M(")"86AA;6%S(@IM<V=S='(@(D)A86UA<R(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HS."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)A:')A:6XB"FUS
M9W-T<B`B0F%RZ6TB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-PIM<V=I
M9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B0N%L=&EC;R`H25-/
M+3@X-3DM,3,I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,T(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R(")"86YG;&%D
M96-H92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(D)A<F)A9&]S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S
M"FUS9VED(")"87-E;&EN92(*;7-G<W1R("),:6YH82!B87-E(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C0Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HS,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B
M0F5L87)U<R(*;7-G<W1R(")":65L;W)R^G-S:6$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,Q
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"96QG:75M
M(@IM<V=S='(@(D+I;&=I8V$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QI>F4B"FUS9W-T<B`B0F5L
M:7IE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0P(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV,0IM<V=I9"`B0F5N:6XB"FUS9W-T<B`B0F5N:6TB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C,T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"97)M
M=61A(@IM<V=S='(@(D)E<FUU9&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")":'5T86XB"FUS9W-T<B`B
M0G5TXV\B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q
M,0IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B06YI=F5R<^%R:6\B"@HC.B!L
M:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(X"B,L('!H<"UF;W)M
M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@
M;F]T(&9O=6YD+B(*;7-G<W1R(")/(&)L;V-O(%PB)7-<(B!D82!A<&QI8V'G
MXV\@7"(E<UPB(&[C;R!F;VD@96YC;VYT<F%D;RXB"@HC.B!T96UP;&%T97,O
M<&]R=&%L+VQA>6]U="YI;F,Z.#D*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM
M<V=S='(@(D-O;F9I9W5R8>?U97,@9&4@0FQO8V]S(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S
M='(@(E1I<&\@9&4@0FQO8V\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T<B`B3F5G<FET
M;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B0F]L[79I82(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ.3$*;7-G:60@(D)O;VMM87)K<R(*;7-G
M<W1R(")-87)C861O<F5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`IM<V=I9"`B0F]R9&5R(@IM<V=S='(@
M(D)O<F1A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B17-P
M97-S=7)A(&1A(&)O<F1A.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T
M<B`B0F]R9&%S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,R(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G
M<W1R(")"\W-N:6$M2&5R>F5G;W9I;F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z.38*;7-G:60@(D)O=&@B"FUS9W-T<B`B06UB87,B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C,X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"
M;W1S=V%N82(*;7-G<W1R(")";W1S=6%N82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M
M(@IM<V=S='(@(D)A<V4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#<@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,Y"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V970@27-L86YD(@IM<V=S='(@
M(DEL:&$@0F]U=F5T(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0T(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(D)R87-I;"(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C0Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q
M"FUS9VED(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T
M<B`B5&5R<FET\W)I;R!"<FETXFYI8V\@9&\@3V-E86YO(,UN9&EC;R(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G
M:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@(D)R=6YE:2!$87)U<W-A
M;&%M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8V,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")"=6EL9&EN9R!-3R!F:6QE<R!F;W(@;6]D=6QE("5S+BXN(@IM
M<V=S='(@(D-O;G-T<G5I;F1O(&%R<75I=F]S($U/('!A<F$@;R!M\V1U;&\@
M)7,N+BXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C<S"B,L('!H<"UF;W)M
M870*;7-G:60@(D)U:6QD:6YG(&QO8V%L92`E<RXN+B`B"FUS9W-T<B`B0V]N
M<W1R=6EN9&\@;&]C86QI>F'GXV\@)7,N+BX@(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C,W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT,PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5L9V%R:6$B
M"FUS9W-T<B`B0G5L9^%R:6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Y"FUS9VED(")"=6QL971E9"!,:7-T(@IM<V=S
M='(@(DQI<W0@271E;6EZ861A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C,V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S
M='(@(D)U<G%U:6YA($9A<V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)U;F1I(@IM<V=S='(@(D)U
M<OIN9&DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@S"FUS9VED
M(")#35,B"FUS9W-T<B`B0TU3(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G<W1R(")#4D,B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B0U),($1I<W1R:6)U
M=&EO;B!0;VEN=',B"FUS9W-T<B`B4&]N=&]S(&1E($1I<W1R:6)U:>?C;R!#
M4DPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T
M<B`B4')O<')I961A9&5S(&1A*',I($/I7VQU;&$H<RDN+BXB"@HC(&,M9F]R
M;6%T"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3`*;7-G:60@
M(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@(DEN:6-I
M86QI>F'GXV\@9&$@7")C86-H95PB(&[C;R!F;VD@8V]N8VQU[61A+B(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-38@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$T.`IM<V=I9"`B0V%L96YD87(B"FUS9W-T
M<B`B0V%L96YDX7)I;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,S0*;7-G:60@(D-A;&TB"FUS9W-T<B`B0V%L;6\B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3(X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HT-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B0V%M
M8F]D:6$B"FUS9W-T<B`B0V%M8F]D:F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#86UE<F]O;B(*;7-G
M<W1R(")#86UA<O5E<R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C(P"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L
M;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B).
MXV\@<&]S<V\@<F5I;FEC:6%R(&$@<&%L879R82UP87-S92!A=71O;6%T:6-A
M;65N=&4L(&-O;G1A8W1E(&\@<V5U("(*(F%D;6EN:7-T<F%D;W(@9&4@<VES
M=&5M87,N(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C(S-2!L:6(O
M2&]R9&4O075T:"]C>7)S<6PN<&AP.C,Q.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R("))
M;7!O<W/M=F5L(&-O;F5C=&%R(&%O('-E<G9I9&]R($E-05`Z("5S(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4Q(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HT.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I
M9"`B0V%N861A(@IM<V=S='(@(D-A;F%DX2(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$P,2!A9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O9&5L971E+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI
M;F,Z,3<*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ-PIM
M<V=I9"`B0V%N8V5L(@IM<V=S='(@(D-A;F-E;&%R(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B;&5M
M(%)E<&]R="(*;7-G<W1R(")#86YC96QA<B!296QA=/-R:6\@9&4@4')O8FQE
M;6%S(@H*(SH@;&EB+U9&4R]F='`N<&AP.C(U-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").XV\@
M8V]N<VEG;R!R96UO=F5R(&\@9FEC:&5I<F\@7"(E<UPB+B(*"B,Z(&QI8B]6
M1E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"B,Z
M(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H
M<#HU,@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y
M+B(*;7-G<W1R(").XV\@8V]N<VEG;R!E;F-O;G1R87(@=6T@9&ER96-T\W)I
M;R!T96UP;W+A<FEO+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+G!H<#HY,0IM
M<V=I9"`B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R
M86UE=&5R+B(*;7-G<W1R("));7!O<W/M=F5L(&-O;G1I;G5A<B!S96T@;R!P
M87+B;65T<F\@)W1A<F=E=$9I;&4G+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HR
M-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O
M<GD@7"(E<UPB+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(')E;6]V97(@
M82!P87-T82!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T1A=&%4<F5E+G!H<#HQ
M,3(@;&EB+TAO<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-3@T"B,L('!H<"UF;W)M
M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*
M;7-G<W1R("));7!O<W/M=F5L(')E;6]V97(L(&5X:7-T96T@)60@9FEL:&]S
M+B(*"B,Z(&QI8B](;W)D92]$871A5')E92]S<6PN<&AP.C4Q,@IM<V=I9"`B
M(@HB0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D
M(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N
M(@IM<V=S='(@(B(*(D[C;R#I('!O<W/M=F5L(')E;W)D96YA<CH@;R!N^FUE
M<F\@9&4@96YT<F%D87,@9F]R;F5C:61A<R!NXV\@8V]R<F5S<&]N9&4@86\@
M(@HB;OIM97)O(&=U87)D861O+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@<F]U=&4@;65S<V%G92!T
M;R!S<&5C:69I960@;G5M8F5R+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L
M(&5N8V%M:6YH87(@82!M96YS86=E;2!P87)A(&\@;OIM97)O(&EN9&EC861O
M+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B4F5P^F)L:6-A(&1E($-A
M8F\@5F5R9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(T"FUS9VED(")#87!T:6]N(@IM<V=S='(@(DQE9V5N
M9&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`*;7-G:60@(D-A=&5G
M;W)I97,@86YD($QA8F5L<R(*;7-G<W1R(")#871E9V]R:6%S(&4@0V]R97,B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,U(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HU,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M-@IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B26QH87,@0V%I;>-O
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G
M:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B5&5L969O;F4@0V5L=6QA<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C4*;7-G:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G<W1R(")0<F]P<FEE9&%D
M97,@9&%S($/I;'5L87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R
M(")%;F-H:6UE;G1O(&1A<R!#Z6QU;&%S.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@
M<')O<&5R=&EE<R(*;7-G<W1R(")0<F]P<FEE9&%D97,@9&%S(&/I;'5L87,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R(")%<W!AYV%M96YT;R!D
M87,@8^EL=6QA<SHB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(W-`IM<V=I
M9"`B0V5L;'!H;VYE(@IM<V=S='(@(E1E;&5M\W9E;"(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3<X"FUS9VED(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*
M;7-G<W1R(")#Z6QT:6-O("A)4T\M.#@U.2TQ-"DB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(V"FUS9VED(")#
M96YT97(B"FUS9W-T<B`B0V5N=')A<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HU-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-E;G1R86P@069R:6-A
M;B!297!U8FQI8R(*;7-G<W1R(")297#Z8FQI8V$@0V5N=')O($%F<FEC86YA
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D-E;G1R86P@
M175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(D5U<F]P82!#96YT<F%L
M("A)4T\M.#@U.2TR*2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-CDY"FUS9VED(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(E!O<FUE
M;F]R97,@9&\@0V5R=&EF:6-A9&\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C8Q,0IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B
M1&]N;R!D;R!#97)T:69I8V%D;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3DV"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R
M(")0;VSM=&EC87,@9&4@0V5R=&EF:6-A9&\B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C(Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(D-H860B"FUS
M9W-T<B`B4F5P^F)L:6-A(&1O($-H861E(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY
M-PIM<V=I9"`B0VAA;F=E(@IM<V=S='(@(D%L=&5R87(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-C8*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92!A
M;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD
M(')E<&QY('1O('EO=7(@(@HB96UA:6QS+B(*;7-G<W1R("(B"B)!;'1E<F4@
M;R!N;VUE(&4@96YD97)EYV\@<75E(&%S('!E<W-O87,@=F5RXV\@<75A;F1O
M(&QE<F5M(&4@<F5S<&]N9&5R96T@X',@(@HB<W5A<R!M96YS86=E;G,N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR-PIM<V=I9"`B0VAA<B(*;7-G<W1R(")#87)A8W1E<F4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*
M;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(E9E<FE?9FEC87(@3&EG
M8>?C;RXN+B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M7W1O
M<"YI;F,Z,3,*;7-G:60@(D-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I
M;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N(@IM<V=S
M='(@(DUA<G%U92!A<R!O<&5R8>?U97,@<75E(&1E<V5J82!E>&5C=71A<B!N
M97-T92!M;VUE;G1O+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU.2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6QE(@IM<V=S='(@(E)E</IB;&EC
M82!D;R!#:&EL92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@(E)E</IB;&EC82!0
M;W!U;&%R(&1A($-H:6YA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*
M;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R(")#
M:&ENZG,@4VEM<&QI9FEC861O<R`H1T(R,S$R*2(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@Q"FUS9VED(")#:&EN97-E(%1R861I=&EO;F%L("A":6<U
M*2(*;7-G<W1R(")#:&ENZG,@5')A9&EC:6]N86P@*$)I9S4I(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(D-H;V]S92!A('!A
M<W-W;W)D(@IM<V=S='(@(D5S8V]L:&$@82!P86QA=G)A+7!A<W-E(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-C@*;7-G:60@(D-H;V]S92!A
M('5S97)N86UE(@IM<V=S='(@(D5S8V]L:&$@=6T@3F]M92!D92!5=&EL:7IA
M9&]R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y,`IM<V=I9"`B0VAO
M;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G<W1R(")%<V-O;&AA(&-O
M;6\@;6]S=')A<B!A<R!D871A<SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@
M;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B
M17-C;VQH82!O(&5S=&EL;R!D87,@;&ES=&$@*'!A<F$@;&ES=&%S(&]R9&5N
M861A<RDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C8@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8X"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(DEL:&$@
M9&\@3F%T86PB"@HC.B!L:6(O5D93+G!H<#HV,34@;&EB+TYE="]335,N<&AP
M.C(Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D969I;FET:6]N(&]F
M("5S(&YO="!F;W5N9"XB"FUS9W-T<B`B3N-O(&9O:2!E;F-O;G1R861A(&$@
M9&5F:6YIY^-O(&1A(&-L87-S92`E<RXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z.#4U"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%N:6YG('5P(%!/(&9I
M;&5S(&9O<B!M;V1U;&4@)7,N+BXB"FUS9W-T<B`B3&EM<&%N9&\@;W,@87)Q
M=6EV;W,@4$\@9&\@;?-D=6QO("5S+BXN(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C@V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A;FEN9R!U<"!L;V-A
M;&4@)7,N+BX@(@IM<V=S='(@(DQI;7!A;F1O(&$@;&]C86QI>F'GXV\@)7,N
M+BX@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,30*;7-G:60@(D-L96%R(@IM<V=S='(@(DQI;7!A<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R
M($U33V9F:6-E('1A9W,B"FUS9W-T<B`B3&EM<&%R(&5T:7%U971A<R!D;R!-
M4T]F9FEC92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHW
M"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G
M<W1R("),:6UP87(@9&%D;W,@9&\@=71I;&EZ861O<CH@)7,B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,38*;7-G:60@(D-L96%R('5S
M97(B"FUS9W-T<B`B3&EM<&%R(&1A9&]S(&1O('5T:6QI>F%D;W(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`IM<V=I9"`B0VQE87(@
M=7-E<B!D871A(@IM<V=S='(@(DQI;7!A<B!D861O<R!D;R!U=&EL:7IA9&]R
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,34*
M;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B3&EM<&$@5&%R9&4B"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;F]T:6-E7V)O='1O;2YI;F,Z-@IM
M<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B0VQI<75E('!A<F$@
M0V]N=&EN=6%R(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T<B`B0VQI
M8VMA=&5L;"!V:6$@2%144"(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ
M-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@
M5VEN9&]W(@IM<V=S='(@(D9E8VAA<B!J86YE;&$B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(T-`IM<V=I9"`B0VQO=61S(@IM<V=S='(@(D[Z=F5N<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$V"FUS
M9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`B3OIV96YS($UA=&EN86ES(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3<*;7-G
M:60@(D-L;W5D>2(*;7-G<W1R(")%;F5V;V%D;R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HU,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-O8V]S("A+
M965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(DEL:&%S($-O8V]S("A+965L:6YG
M*2(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z-`IM<V=I9"`B
M0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R(")#;VQA<'-A<B!"87)R82!,871E
M<F%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B
M0F]R9&%S($-O;&%P<V%D87,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;VQO;6)I82(*;7-G<W1R(")2
M97#Z8FQI8V$@9&$@0V]L]&UB:6$B"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP
M.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B
M"FUS9W-T<B`B0V]R97,B"@HC.B!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO
M;BYP:'`Z,CDY(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HS,#`*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0W,B!S97)V
M:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4Q"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4R"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8X"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Y"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@U"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@V"FUS9VED(")#;VQO<B!0
M:6-K97(B"FUS9W-T<B`B4&%L971E(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(X-#4*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B4V5L96/G
MXV\@9&4@8V]R97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`B0V]L=6YA<SHB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DT-PIM<V=I9"`B0V]L=6UN('1I
M=&QE<R(*;7-G<W1R(")4[71U;&]S(&1A<R!C;VQU;F%S(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(X-@IM<V=I9"`B0V]M:6-S(@IM<V=S='(@
M(D)$(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(U"FUS9VED(")#;VUM86YD
M(@IM<V=S='(@(D-O;6%N9&\B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C`*
M;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B0V]N<V]L82!D92!#;VUA
M;F1O<R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HS.`IM<V=I9"`B0V]M;6%N
M9"!O<'1I;VYS.B(*;7-G<W1R(")/<.?U97,@9&\@8V]M86YD;SHB"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z.3<*;7-G:60@(D-O;6UA;F1S.B(*;7-G<W1R
M(")#;VUA;F1O<SHB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,#(*
M;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B0V]M96YTX7)I;R(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HQ,#`P"FUS9VED(")#;VUM:71T:6YG.B(*;7-G<W1R
M(")#;VUE=&5N9&\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V
M-@IM<V=I9"`B0V]M;6]N($YA;64B"FUS9W-T<B`B3F]M92!#;VUU;2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C4X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@T"FUS
M9VED(")#;VUO<F]S(@IM<V=S='(@(D-O;6]R;W,B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G
M<W1R(")%;7!R97-A(@H*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL
M<RYP:'`Z.#$@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z.#<*
M(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z.3<@;&EB+TAO
M<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z,3`Q"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O;7!O<V4@365S<V%G92`H)7,I(@IM<V=S='(@(D5S8W)E=F5R
M("@E<RDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S$*;7-G:60@(D-O
M;7!U=&5R<R(*;7-G<W1R(")#;VUP=71A9&]R97,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C@U"FUS9VED(")#;VYD:71I;VXB"FUS9W-T
M<B`B0V]N9&GGXV\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T.0IM<V=I
M9"`B0V]N9&ET:6]N<R(*;7-G<W1R(")#;VYD:>?U97,B"@HC.B!A9&UI;B]S
M971U<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E
M;F-E<R(*;7-G<W1R(")$:69E<F5NYV%S(&1E($-O;F9I9W5R8>?C;R(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S0*;7-G:60@(D-O;F9I9W5R871I
M;VX@:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@(D$@8V]N9FEG=7)AY^-O(&5S
M=.$@9&5S86-T=6%L:7IA9&$B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@
M(D-O;F9I9W5R87(@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C,W"FUS9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(D-O
M;F9I<FUE(&$@4&%L879R82U087-S92(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HU-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O(@IM<V=S='(@
M(E)E</IB;&EC82!$96UO8W+A=&EC82!D;R!#;VYG;R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HU,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-O;F=O
M+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B4F5P
M^F)L:6-A($1E;6]C<N%T:6-A(&1O($-O;F=O(@H*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C$Y.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T
M<B`B0V]N97CC;R!F86QH;W4N(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C$Y.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(D-O;F5X
MXV\@9F%L:&]U.B`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW-SD*
M;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BXB"FUS9W-T<B`B0V]N97CC;R!A;R!S97)V:61O<B!D92!C:&%V97,@
M</IB;&EC87,@<F5C=7-A9&$N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z-S@Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E
M9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM
M<V=S='(@(D-O;F5XXV\@86\@<V5R=FED;W(@9&4@8VAA=F5S('#Z8FQI8V%S
M(')E8W5S861A+B!287KC;SH@)7,@*"5S*2(*"B,Z(&QI8B]61E,O9G1P+G!H
M<#HW-C(*;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N
M(@IM<V=S='(@(D-O;F5XXV\@86\@<V5R=FED;W(@1E10(')E8W5S861A+B(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@
M(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D
M<F5S<R!B;V]K+B(*;7-G<W1R(")#;VYT86-T;W,@861I8VEO;F%D;W,@8V]M
M('-U8V5S<V\@86\@<V5U(&QI=G)O(&1E(&5N9&5R9>=O<RXB"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HV,`IM<V=I9"`B0V]N=&5N="!T
M>7!E(&]F(&-O;7!R97-S960@9FEL93H@(@IM<V=S='(@(E1I<&\@9&4@8V]N
M=&7Z9&\@9&\@87)Q=6EV;R!C;VUP<FEM:61O.B`B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O<F%R+G!H<#HU-B!L:6(O2&]R9&4O34E-12]6:65W97(O
M>FEP+G!H<#HV,PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O9B!<(B5S7"(B"FUS
M9W-T<B`B0V]N=&7Z9&\@9&4@)7,B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HR.0IM<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`B0V]N=&EN=6%R
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HV,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M-@IM<V=I9"`B0V]O:R!)<VQA;F1S(@IM<V=S='(@(DEL:&%S($-O;VLB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G
M<W1R(")";VQI;FAO(&-H:6[J<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0IM<V=I9"`B0V]P>2(*;7-G
M<W1R(")#;W!I87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R(")#
M;W!I87(@<V5L96/GXV\B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`X-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y:6YG("5S('1O("5S(@IM<V=S='(@
M(D-O<&EA;F1O(&1E("5S('!A<F$@)7,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;W-T82!2:6-A(@IM
M<V=S='(@(E)E</IB;&EC82!D82!#;W-T82!2:6-A(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C4W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV
M,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]T92!D
M)TEV;VER92(*;7-G<W1R(")297#Z8FQI8V$@9&$@0V]S=&$@9&\@36%R9FEM
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.34V"FUS9VED(")#;W5L
M9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B3N-O(&9O:2!P
M;W-S[79E;"!E;F-R:7!T87(@82!M96YS86=E;2!C;VT@4$=0+B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C$P,S,*;7-G:60@(D-O=6QD(&YO="!0
M1U`@<VEG;B!M97-S86=E+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&%S
M<VEN87(@82!M96YS86=E;2!C;VT@4$=0+B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z,SDS"FUS9VED(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y
M<'0@;65S<V%G92XB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!E;F-R:7!A
M<B!A(&UE;G-A9V5M(&-O;2!3+TU)344N(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD(&YO="!3+TU)344@<VEG;B!M
M97-S86=E+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&%S<VEN87(@82!M
M96YS86=E;2!C;VT@4R]-24U%+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&%D
M:6-I;VYA<B!O(&-O;G1A8W1O+B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+VQD
M87`N<&AP.C$Q,`IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V
M97(N(@IM<V=S='(@(D9A;&AA(&YA(&QI9V'GXV\@*&)I;F0I(&%O('-E<G9I
M9&]R($Q$05`N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C$U-B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B
M"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!V97)I9FEC87(@;R!S86QD;RX@
M)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U
M<VEN9R!&5%`Z("5S(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@8V]N96-T
M87(@86\@<V5R=FED;W(@7"(E<UPB('5S86YD;R!&5%`Z("5S(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C$P.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&-O<'D@)7,@=&\@)7,B"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E
M;"!C;W!I87(@)7,@<&%R82`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3N-O(&9O
M:2!P;W-S[79E;"!C<FEA<B!L:7-T82!D92!D:7-T<FEB=6GGXV\N("5S(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C8X,2!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,3`W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&QO
M8V%L92!D:7)E8W1O<GD@9F]R(&QO8V%L92`E<SHB"FUS9W-T<B`B3N-O(&9O
M:2!P;W-S[79E;"!C<FEA<B!P87-T82!D92!L;V-A;&EZ8>?C;R!P87)A(&$@
M;&]C86QI>F'GXV\@)7,Z(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M,3$P-0IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N(@IM<V=S
M='(@(D[C;R!F;VD@<&]S<^UV96P@9&5S96YC<FEP=&%R(&]S(&1A9&]S(&-O
M;2!O(%!'4"XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4R,@IM
M<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@
M(D[C;R!F;VD@<&]S<^UV96P@9&5S96YC<FEP=&%R(&]S(&1A9&]S(&-O;2!3
M+TU)344N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(T
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&-O;G1A
M8W0N("5S(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!C;VYT
M86-T;RX@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@
M<F5M;W9E<B!L:7-T82!D92!D:7-T<FEB=6GGXV\N("5S(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM
M<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!O(%PB<V-R:7!T7"(@
M9&4@86-T=6%L:7IAY^-O(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C,X,2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY,S@*;7-G
M:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I
M;"!A9&1R97-S+B(*;7-G<W1R("(B"B).XV\@9F]I('!O<W/M=F5L(&1E=&5R
M;6EN87(@;R!E;F1E<F7G;R!D92!C;W)R96EO(&5L96-T<O-N:6-O(&1O("(*
M(F1E<W1I;F%TX7)I;RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,C@S"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D
M<F5S<R!B;V]K+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&]B=&5R(&\@
M;&EV<F\@9&4@96YD97)EYV]S(&-O;7!L971O+B(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*;7-G:60@(D-O=6QD(&YO="!F971C
M:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B3N-O(&9O
M:2!P;W-S[79E;"!O8G1E<B!A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;R!C;VUP
M;&5T82XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0V
M"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@
M9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L
M(&]B=&5R(&$@;&ES=&$@8V]M<&QE=&$@9&%S(&QI<W1A<R!D92!D:7-T<FEB
M=6GGXV\N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T
M96=Y+G!H<#HV.`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2YP:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO
M860@<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R("));7!O<W/M=F5L(&-A<G)E
M9V%R(&5S=')A=.EG:6$@7"(E<UPB+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!L:6(O5D93+TE3
M3U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G
M<W1R("));7!O<W/M=F5L(&UK9&ER(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HW,#@*;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B
M;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@(B(*(D[C;R!F
M;VD@<&]S<^UV96P@;V)T97(@82!C:&%V92!P^F)L:6-A(&$@<&%R=&ER(&1O
M('-E<G9I9&]R(&1E(&-H879E<R`B"B)P^F)L:6-A<RXB"@HC.B!L:6(O5D93
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W
M<FET:6YG+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&%B<FER(%PB)7-<
M(B!P87)A(&5S8W)I=&$N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8W-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS
M9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!A8G)I<B`E<RXB"@HC.B!L:6(O2&]R
M9&4O36%I;G1E;F%N8V4N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*;7-G
M<W1R(").XV\@9F]I('!O<W/M=F5L(&%B<FER(&\@;?-D=6QO(&1E($UA;G5T
M96[GXV\@9&4@5&%R969A<R`E<R(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@
M(D[C;R!F;VD@<&]S<^UV96P@86)R:7(@<&%S=&$@7"(E<UPB+B(*"B,Z(&QI
M8B]61E,O3V)J96-T+G!H<#HR,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(')E860@)7,N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@;&5R
M("5S+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED
M("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q
M=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R
M92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI
M;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T
M<B`B(@HB3N-O(&9O:2!P;W-S[79E;"!R96EN:6-I87(@82!P86QA=G)A+7!A
M<W-E(&1O('5T:6QI>F%D;W(@:6YD:6-A9&\N($%L9W5M(&]U("(*(G1O9&]S
M(&]S('!O<FUE;F]R97,@;N-O(&5S=&%V86T@8V]R<F5C=&]S+B!0;W(@9F%V
M;W(@=&5N=&4@9&4@;F]V;R!O=2`B"B)C;VYT86-T92!O('-E=2!A9&UI;FES
M=')A9&]R(&1E('-I<W1E;6%S('-E('!R96-I<V%R(&1E(&UA:7,@86IU9&$N
M(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.2!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0P"B,Z(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS-S<@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,X,PHC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S@Y"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@
M(D[C;R!F;VD@<&]S<^UV96P@;V)T97(@04-,(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R(").
MXV\@9F]I('!O<W/M=F5L(&]B=&5R(&QI=G)O(&1E(&5N9&5R9>=O<RX@)7,B
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I
M;VX@;&ES="X@)7,B"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!L
M:7-T82!D92!D:7-T<FEB=6GGXV\N("5S(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R
M(").XV\@9F]I('!O<W/M=F5L(&]B=&5R(&QI<W1A<R!D92!D:7-T<FEB=6GG
MXV\N("5S(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y
M.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*;7-G:60@(D-O=6QD(&YO
M="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`B3N-O
M(&9O:2!P;W-S[79E;"!O8G1E<B!A<R!C;VUP973J;F-I87,@9&\@<V5R=FED
M;W(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"FUS9VED(")#;W5L
M9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D[C;R!F;VD@
M<&]S<^UV96P@<F5V97)T97(@82!C;VYF:6=U<F'GXV\N(@H*(SH@;&EB+U9&
M4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER(%PB)7-<(BXB"FUS
M9W-T<B`B26UP;W-S[79E;"!R;61I<B!<(B5S7"(N(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B3N-O(&9O:2!P
M;W-S[79E;"!G=6%R9&%R(&$@8V]N9FEG=7)AY^-O(&1E("5S+B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HU-PIM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T
M:6]N+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&=U87)D87(@82!C;VYF
M:6=U<F'GXV\@9&4@<V%L=F%G=6%R9&$N(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E
M(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B3N-O(&9O:2!P
M;W-S[79E;"!G=6%R9&%R(&$@8V]N9FEG=7)AY^-O(&1E('-A;'9A9W5A<F1A
M.B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDR"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R
M:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@9W5A
M<F1A<B!O(%PB<V-R:7!T7"(@9&4@86-T=6%L:7IAY^-O(&5M.B!<(B5S7"(N
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I
M;VX@9FEL92`E<RXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!G=6%R9&%R
M(&$@8V]N9FEG=7)AY^-O(&1E('-A;'9A9W5A<F1A("5S+B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U
M(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E
M('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D
M92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B(@HB3N-O(&9O:2!P;W-S[79E;"!G
M=6%R9&%R(&\@87)Q=6EV;R!D92!C;VYF:6=U<F'GXV\@)7,N(%!O9&4@=7-A
M<B!U;6$@9&%S("(*(F]PY_5E<R!P87)A(&=U87)D87(@;R!C\V1I9V\@96T@
M)7,@;W4@8V]P:6%R(&UA;G5A;&UE;G1E(&\@8_-D:6=O(&%B86EX;R`B"B)P
M87)A("5S+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C$R,`IM<V=I
M9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@
M(D[C;R!F;VD@<&]S<^UV96P@<')O8W5R87(@;F\@<V5R=FED;W(@3$1!4"XB
M"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HX-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK
M(%PB)7-<(BXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!D97-L:6=A<B!<
M(B5S7"(N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(Q
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&-O;G1A
M8W0N("5S(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@86-T=6%L:7IA<B!C
M;VYT86-T;RX@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,SDV"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV
M96P@86-T=6%L:7IA<B!A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@)7,B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@
M)7,B"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!E<V-R979E<B!A(&-O;F9I
M9W5R8>?C;R!P87)A(%PB)7-<(CH@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S4X"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I
M9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R
M("(B"B).XV\@96YC;VYT<F5I(&$@0F%R<F$@3&%T97)A;"!D;R!-;WII;&QA
M+B!!<W-E9W5R92US92!Q=64@82!B87)R82!L871E<F%L("(*(F5S=.$@86)E
M<G1A+B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB
M)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S
M7"(Z("5S(@IM<V=S='(@(B(*(D[C;R!F;VD@<&]S<^UV96P@871R:6)U:7(@
M86\@=71I;&EZ861O<B!<(B5S7"(@;W,@<V5G=6EN=&5S(&1I<F5I=&]S('-O
M8G)E(&$@(@HB<&%S=&$@7"(E<UPB.B`E<R(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ-#(Q"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B5&5X=&\@
M0V]N=&%D;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-38Y"FUS
M9VED(")#;W5N=')Y(@IM<V=S='(@(E!A[7,B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C<P"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(D-U<G-O
M<R(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3<*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C$P,0IM<V=I9"`B0W)E871E(@IM<V=S='(@(D-R:6%R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8W"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@(D-R:6%R('5M
M82!L:6=AY^-O(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T
M+FEN8SHY,PIM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R(")#<FEA
M<B!U;6$@;F]V82(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HY,@IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(D-R:6%R
M('-U8BUP87-T87,B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,S8@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HR,30*;7-G:60@(D-R96%T;W(@4&5R;6ES
M<VEO;G,B"FUS9W-T<B`B4&5R;6ES<_5E<R!D;R!#<FEA9&]R(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C,R,CD*;7-G:60@(D-R961I="!C87)D(&YU;6)E
M<B(*;7-G<W1R(").^FUE<F\@9&\@8V%R=.-O(&1E(&-RZ61I=&\B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`Y(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HV-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I
M9"`B0W)O871I82(*;7-G<W1R(")297#Z8FQI8V$@9&$@0W)OX6-I82(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G
M:60@(D-U8F$B"FUS9W-T<B`B4F5P^F)L:6-A(&1E($-U8F$B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,C8*;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS
M9W-T<B`B475A=')O(&9A<V5S(&-O<G)E;G1E<R(*"B,Z(&QI8B]";&]C:R]T
M:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N
M="!4:6UE(@IM<V=S='(@(D1A=&$O2&]R82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B0W5R
M<F5N="!54DP@:7,B"FUS9W-T<B`B55),(&-O<G)E;G1E(.DB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(U"FUS9VED(")#=7)R96YT(%=E871H97(B"FUS
M9W-T<B`B17-T861O(&1O(%1E;7!O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(V,PIM<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G
M<W1R(")3:71U8>?C;R!A8W1U86PZ("(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B
M"FUS9W-T<B`B17-T:6QO(&%C='5A;"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS
M('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R(")097)S;VYA;&EZ
M87(@87,@=&%R969A<R!Q=64@<V5RXV\@97AE8W5T861A<R!A<75A;F1O(&\@
M;&]G:6X@;F\@)7,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`B0V]R
M=&%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS-0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R(")#;W)T87(@82!S
M96QE8^?C;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C@*;7-G:60@(D-Y<')U<R(*;7-G<W1R(")297#Z8FQI8V$@9&4@
M0VAI<')E(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G:60@(D-Y
M<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(D-I<NUL:6-O("A+3TDX+5(I(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(D-Y<FEL;&EC("A7
M:6YD;W=S+3$R-3$I(@IM<V=S='(@(D-I<NUL:6-O("A7:6YD;W=S+3$R-38I
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@(D-Y<FEL;&EC
M+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R(")#:7+M;&EC;R]58W)A;FEA
M;F\@*$M/23@M52DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C@@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8Y"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R(")2
M97#Z8FQI8V$@0VAE8V$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#(S('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")$
M1"(*;7-G<W1R(")$1"(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z
M-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(D1I87)I86UE;G1E(@H*(SH@861M
M:6XO9&%T871R964N<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM
M<V=S='(@(DYA=F5G861O<B!D92#!<G9O<F4@9&4@1&%D;W,B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C,Y."!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C
M.#(R+G!H<#HW,@IM<V=I9"`B1&%T92(*;7-G<W1R(")$871A(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G:60@(D1A=&4@
M4F5C96EV960B"FUS9W-T<B`B1&%T82!D92!296-E<.?C;R(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR.#`V"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G
M<W1R(")396QE8^?C;R!D92!D871A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(X,"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$P
M"FUS9VED(")$87DB"FUS9W-T<B`B1&EA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,U"FUS9VED(")$95]L
M971E($-O;'5M;B(*;7-G<W1R(")296UO=F5R($-O7VQU;F$B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@U(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,C(*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@IM<V=I9"`B1&5C96UB97(B"FUS
M9W-T<B`B1&5Z96UB<F\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L:7-T='EP95]L86YG+FIS.C$V"FUS9VED(")$96-I;6%L(&YU;6)E
M<G,B"FUS9W-T<B`B3OIM97)O<R!D96-I;6%I<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C`*;7-G:60@(D1E8W)E87-E
M($EN9&5N="(*;7-G<W1R(")2961U>FER(&EN9&5N=&'GXV\B"@HC.B!L:6(O
M<')E9G,N<&AP.C$Q,2!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$X-PIM<V=I
M9"`B1&5F875L="(*;7-G<W1R(")0;W(@3VUI<W/C;R(*"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0W"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q"FUS9VED(")$969A
M=6QT($-O;&]R(@IM<V=S='(@(D-O<B!0;W(@3VUI<W/C;R(*"B,Z(&QI8B](
M;W)D92])9&5N=&ET>2YP:'`Z.3$*;7-G:60@(D1E9F%U;'0@261E;G1I='DB
M"FUS9W-T<B`B261E;G1I9&%D92!0861RXV\B"@HC.B!A9&UI;B]P97)M<R]E
M9&ET+G!H<#HQ,3D@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ.38*;7-G:60@
M(D1E9F%U;'0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B4&5R;6ES<_5E<R!0;W(@
M3VUI<W/C;R(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,3DW"FUS9VED
M(")$969A=6QT('!E<FUI<W-I;VYS(@IM<V=S='(@(E!E<FUI<W/U97,@<&]R
M(&]M:7-SXV\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@
M(D1E9FEN:71I;VYS(@IM<V=S='(@(D1E9FEN:>?U97,B"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C<R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8@861M:6XO
M<&5R;7,O9&5L971E+G!H<#HU,@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(Y
M-2!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,Q-0HC.B!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C,S,B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHY,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q
M-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.0HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$X,B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z-S,*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDY('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,PHC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S='(@
M(E)E;6]V97(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$X.2!A9&UI;B]G<F]U
M<',N<&AP.C(Q-PIM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@(E)E;6]V
M97(@1W)U<&\B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C8S(&QI8B](
M;W)D92]097)M<R]522YP:'`Z.#<*;7-G:60@(D1E;&5T92!097)M:7-S:6]N
M(@IM<V=S='(@(E)E;6]V97(@4&5R;6ES<^-O(@H*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E
M(&UE<W-A9V5S(@IM<V=S='(@(E)E;6]V97(@92!P=7)G87(@;65N<V%G96YS
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU-PIM<V=I9"`B1&5L971E(&-E;&PB"FUS9W-T<B`B4F5M;W9E<B!C
MZ6QU;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@8V]L=6UN(@IM<V=S='(@(E)E
M;6]V97(@8V]L=6YA(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*;7-G
M:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T
M<B`B4F5M;W9E<B!M;V1E;&\@86QT97)N871I=F\@97AI<W1E;G1E(@H*(SH@
M861M:6XO<&5R;7,O9&5L971E+G!H<#HU,"!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.C,Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO
M;G,@9F]R(%PB)7-<(B(*;7-G<W1R(")296UO=F5R('!E<FUI<W/U97,@9&4@
M7"(E<UPB(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS,3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B`G)7,G(&%N
M9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R(")296UO=F5R('!E<FUI
M<W/U97,@<&%R82`G)7,G(&4@<75A:7-Q=65R('-U8BUP97)M:7-S]65S/R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C<*;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T<B`B4F5M;W9E<B!L:6YH
M82(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*
M;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET>2(*;7-G<W1R(")296UO
M=F5R(&ED96YT:61A9&4@<V5L96-C:6]N861A(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED(")$
M96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(E)E;6]V97(@82!C
M;VQU;F$@8V]R<F5N=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@(D1E;&5T92!T:&4@8W5R
M<F5N="!R;W<B"FUS9W-T<B`B4F5M;W9E<B!A(&QI;FAA(&-O<G)E;G1E(@H*
M(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HT.`IM<V=I9"`B1&5L971E('1H
M:7,@<&5R;6ES<VEO;B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T
M<B`B4F5M;W9E<B!E<W1A('!E<FUI<W/C;R!E('1O9&%S(&%S('-U87,@<W5B
M+7!E<FUI<W/U97,_(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C
M<FEP="!<(B5S7"(N(@IM<V=S='(@(EPB4V-R:7!T7"(@9&4@86-T=6%L:7IA
MY^-O(%PB)7-<(B!R96UO=FED;RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-38S(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU.34*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C$@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*;7-G:60@(D1E
M;&EV97)Y('1I;64B"FUS9W-T<B`B36]M96YT;R!D92!E;G1R96=A(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<Q(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HV.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I
M9"`B1&5N;6%R:R(*;7-G<W1R(")$:6YA;6%R8V$B"@HC.B!S97)V:6-E<R]P
M<F]B;&5M+G!H<#HQ,3`@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3$T('-E<G9I
M8V5S+W!R;V)L96TN<&AP.C$R-`IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L
M96TB"FUS9W-T<B`B1&5S8W)E=F$@;R!0<F]B;&5M82(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HY,S@@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B
M1&5S8W)IY^-O(@H*(SH@;&EB+TAO<F1E+G!H<#HQ.34*;7-G:60@(D1E=&%I
M;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B4&]R;65N
M;W)E<R`H=&%M8NEM(&YO(')E9VES=&\L(%PB;&]G7"(L(&1O($AO<F1E*3HB
M"@HC.B!L:6(O2&]R9&4N<&AP.C$Y.0IM<V=I9"`B1&5T86EL<R!H879E(&)E
M96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B3W,@
M9&5T86QH97,@9F]R86T@96YV:6%D;W,@<&%R82!O(&%D;6EN:7-T<F%D;W(@
M9&\@<VES=&5M82XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DX
M"FUS9VED(")$979E;&]P;65N="(*;7-G<W1R(")$97-E;G9O;'9I;65N=&\B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-PIM<V=I9"`B1&5W(%!O:6YT
M(@IM<V=S='(@(E!O;G1O(&1E($]R=F%L:&\B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(Y-`IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*
M;7-G<W1R(")0;VYT;R!D92!/<G9A;&AO(&YA(/IL=&EM82!H;W)A.B`B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$U"FUS9VED(")$97<@
M<&]I;G0Z("(*;7-G<W1R(")0;VYT;R!D92!O<G9A;&AO.B`B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED(")$
M:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R(")$:7)E8^?C;R!D82!E
M<W%U97)D82!P87)A(&$@9&ER96ET82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H
M="!T;R!L969T(@IM<V=S='(@(D1I<F5CY^-O(&1A(&1I<F5I=&$@<&%R82!A
M(&5S<75E<F1A(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@
M(D1I<F5C=&]R>2(*;7-G<W1R(")$:7)E8W3S<FEO(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(U.`IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S
M/R(*;7-G<W1R(")-;W-T<F%R('1E;7!O<R!C;VT@,C0@:&]R87,_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW"FUS9VED(")$:7-P;&%Y($]P=&EO
M;G,B"FUS9W-T<B`B3W#G]65S(&1E(%9I<W5A;&EZ8>?C;R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HX.`IM<V=I9"`B1&ES<&QA>2!D971A
M:6QE9"!F;W)E8V%S="(*;7-G<W1R(")-;W-T<F%R('!R979I<^-O('!O<FUE
M;F]R:7IA9&$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@U"FUS9VED(")$
M:7-P;&%Y(&9O<F5C87-T("A4048I(@IM<V=S='(@(DUO<W1R87(@<')E=FES
MXV\@*%1!1BDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@Q-@IM<V=I9"`B
M1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B1F]R;6%T;R!D92!V:7-U86QI>F'G
MXV\B"@HC.B!L:6(O2&]R9&4O34E-12]-1$XN<&AP.C$Y,`IM<V=I9"`B1&ES
M<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(DYO=&EF:6-AY^-O(&1E
M($1I<W!O<VGGXV\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8Y"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R(")$:FEB=71I
M(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-B!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C,Q-0IM<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G<W1R(").
MXV\@<F5M;W9E<B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR-`IM
M<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'`B
M"FUS9W-T<B`B3N-O('5T:6QI>F4@;R!M86EN=&5N86YC92YP:'`@9&ER96-T
M86UE;G1E(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3D@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3D*;7-G:60@(D1O97,@=&AE(&9I
M<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C
M:R!T:&ES(&)O>#HB"FUS9W-T<B`B(@HB02!P<FEM96ER82!L:6YH82!C;VYT
MZ6T@;W,@;F]M97,@9&]S(&-A;7!O<S\@4V4@<VEM+"!A<W-I;F%L87(@97-T
M82!C86EX83HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S(@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R(")$;VUI;FEC82(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*
M;7-G:60@(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R(")297#Z8FQI8V$@
M1&]M:6YI8V%N82(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX
M-#$*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(E)E8V5B97(B"@HC.B!L:6(O
M2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#0Q"B,L('!H<"UF;W)M870*;7-G
M:60@(D1O=VYL;V%D("5S(@IM<V=S='(@(E)E8V5B97(@)7,B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,38U"FUS9VED(")$;W=N;&]A9"!G96YE<F%T
M960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R(")$97-C
M87)R96=A<B!A(&-O;F9I9W5R8>?C;R!G97)A9&$@8V]M;R!U;2!<(G-C<FEP
M=%PB(%!(4"XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$P.`IM<V=I9"`B
M1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B3&ES=&$@9&4@9&5S96YR;VQA<B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B1')U9W,B"FUS
M9W-T<B`B1')O9V%S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#`R
M"FUS9VED(")%+4UA:6PB"FUS9W-T<B`B0V]R<F5I;R!E;&5C='+S;FEC;R(*
M"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H
M<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@(D524B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HW-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B
M"FUS9W-T<B`B4F5P^F)L:6-A(&1O($5Q=6%D;W(B"@HC.B!L:6(O2&]R9&4O
M4&5R;7,N<&AP.C(Y-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q
M-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$X,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z-S(*(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR,@IM<V=I9"`B
M161I="(*;7-G<W1R(")%9&ET87(B"@HC.B!L:6(O2&]R9&4O0FQO8VLO54DN
M<&AP.C4P('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,C(*;7-G:60@(D5D
M:70@0FQO8VLB"FUS9W-T<B`B161I=&%R($)L;V-O(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HQ.#@@861M:6XO9W)O=7!S+G!H<#HR,38*;7-G:60@(D5D:70@
M1W)O=7`B"FUS9W-T<B`B161I=&%R($=R=7!O(@H*(SH@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HV,B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C@V"FUS9VED
M(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`B161I=&%R(%!E<FUI<W/U97,B
M"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"FUS9VED(")%9&ET
M(%!E<FUI<W-I;VYS(@IM<V=S='(@(D5D:71A<B!097)M:7-S]65S(@H*(SH@
M<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R(")%9&ET87(@
M<&5R;6ES<_5E<R!D92`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC
M.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@(D5D:71A<B!O
M<.?U97,@9&4Z(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,C`T(&QI8B](
M;W)D92]097)M<R]522YP:'`Z,C@P"B,L('!H<"UF;W)M870*;7-G:60@(D5D
M:70@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R(")%9&ET87(@<&5R
M;6ES<_5E<R!D92!<(B5S7"(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@
M9F]R("5S(@IM<V=S='(@(D5D:71A<B!P97)M:7-S]65S(&1E("5S(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U"FUS9VED(")%9'5C871I;VXB"FUS
M9W-T<B`B161U8V'GXV\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S<@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*;7-G<W1R(")%9VEP=&\B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$W(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HW-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@(E)E</IB;&EC82!D92!%
M;"!386QV861O<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHT,@IM<V=I9"`B16QE;65N="XN+B(*;7-G<W1R
M(")%;&5M96YT;RXN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R(")%;2(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ.#<P(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,C(T"FUS9VED(")%;6%I;"(*;7-G<W1R(")#;W)R96EO($5L
M96-T<O-N:6-O(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-C4@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0P"FUS9VED(")%;6%I;"!!9&1R
M97-S(@IM<V=S='(@(D5N9&5R9>=O(&1E($-O<G)E:6\@16QE8W1R\VYI8V\B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DV-`IM<V=I9"`B16UA:6P@861D
M<F5S<V5S(&UU<W0@;6%T8V@N(@IM<V=S='(@(D]S(&5N9&5R9>=O<R!TZFT@
M<75E(&-O:6YC:61I<BXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DY,`IM
M<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B365N<V%G
M96T@8V]M(&-O;F9I<FUAY^-O(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(X,`IM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(E/M
M;6)O;&]S(&1E($5M;^?C;R(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`R"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R(")-
M96YS86=E;2!V87II82XB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ
M,C@*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B4V5M(')E<W5L=&%D
M;W,N(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED
M(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`B4V5M('1E<FUO<R!D92!P
M<F]C=7)A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S-0IM<V=I9"`B
M16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I
M97,@:6X@=&5X=#\B"FUS9W-T<B`B06-T:79A<B!I;G-E<N?C;R!D92!I;6%G
M96YS(&1E($=A;&5R:6%S($9O=&]G<N%F:6-A<R!N;R!T97AT;S\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$P"FUS9VED(")%;F%B;&4@<FEG:'0@
M8VQI8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R(")!8W1I=F%R(&UE;G4@9&4@
M8V]N=&5X=&\@;F\@8F]TXV\@9&ER96ET;R!D;R!R871O/R(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR-3DW(&QI8B](;W)D92]&;W)M+G!H<#HR.#$P"FUS
M9VED(")%;F0@>65A<B(*;7-G<W1R(")!;F\@9&4@9FEM(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL
M87)G92!%9&ET;W(B"FUS9W-T<B`B075M96YT87(@161I=&]R(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(Q,PIM<V=I9"`B(@HB16YT97(@82!S96-U
M<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@
M;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES
M('1H92!N86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*(DEN=')O9'5Z
M82!U;6$@<&5R9W5N=&$@9&4@<V5G=7)A;N=A('%U92!S97+A(&-O;G9I9&%D
M;R!A(')E<W!O;F1E<B!S92`B"B)P<F5C:7-A<B!D92!R96EN:6-I87(@82!S
M=6$@<&%L879R82UP87-S92P@92YG+BP@)V-O;6\@<V4@8VAA;6$@;R!S974@
M86YI;6%L("(*(F1E(&5S=&EM8>?C;S\G.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B
M16YT97(@=&AE(&EM86=E(%523"!H97)E(@IM<V=S='(@(DEN=')O9'5Z82!O
M(%523"!D82!I;6%G96T@87%U:2(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ
M,38S"B,L('!H<"UF;W)M870*;7-G:60@(D5N=')I97,Z("5D('1O=&%L+"`E
M9"!U<"UT;RUD871E+"`E9"!N97<L("5D(&-H86YG960L("5D('5N:VYO=VXB
M"FUS9W-T<B`B(@HB16YT<F%D87,Z("5D('1O=&%L+"`E9"!A8W1U86QI>F%D
M87,L("5D(&YO=F%S+"`E9"!A;'1E<F%D87,L("5D(&1E<V-O;FAE8VED87,B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3D@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C<U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<V
M"FUS9VED(")%<75A=&]R:6%L($=U:6YE82(*;7-G<W1R(")'=6ENZ2!%<75A
M=&]R:6%L(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<Y(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW,0IM<V=I9"`B17)I=')E82(*;7-G<W1R(")%<W1A9&\@9&$@17)I
M=')E:6$B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T
M871U<RYP:'`Z,C<*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0W
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S8*(SH@<V5R=FEC97,O<&]R=&%L+VEN
M9&5X+G!H<#HW.0IM<V=I9"`B17)R;W(B"FUS9W-T<B`B17)R;R(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED(")%<G)O
M<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM<V=S='(@(D5R<F\@;F$@;65N<V%G
M96T@9&4@8V]R<F5I;R!E;&5C='+S;FEC;RXB"@HC.B!L:6(O5D93+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(D5R
M<F\@86\@97-C<F5V97(@7"(E<UPB+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HT,3,@<&\O=')A;G-L871I;VXN<&AP.C4R,B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z,3,W-PHC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,30S."!P;R]T<F%N<VQA
M=&EO;BYP:'`Z,34P,0IM<V=I9"`B17)R;W(Z("(*;7-G<W1R(")%<G)O.B`B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S8@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C<W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P
M"FUS9VED(")%<W1O;FEA(@IM<V=S='(@(E)E</IB;&EC82!D82!%<W3S;FEA
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HW.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`B4F5P^F)L:6-A($1E;6]C<N%T
M:6-A($9E9&5R86P@9&$@171I\W!I82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S='(@(LET:6-O(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*;7-G<W1R
M(")%=7)O<&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Q"FUS9VED
M(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(D-A9&$@,34@;6EN=71O<R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#$*;7-G:60@(D5V97)Y(#(@
M;6EN=71E<R(*;7-G<W1R(")#861A(#(@;6EN=71O<R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS,C@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.0IM
M<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R(")#861A(#,P('-E9W5N
M9&]S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S,"!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S@R"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T
M<B`B0V%D82`U(&UI;G5T;W,B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N
M<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R(")#861A($5N=')A
M9&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,R"FUS9VED(")%=F5R
M>2!H86QF(&AO=7(B"FUS9W-T<B`B0V%D82!M96EA(&AO<F$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S(Y(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.#`*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R(")#861A(&UI;G5T;R(*
M"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(X"FUS9VED(")%>&%M
M<&QE('9A;'5E<SHB"FUS9W-T<B`B5F%L;W)E<R!E>&5M<&QO.B(*"B,Z(&%D
M;6EN+W!H<'-H96QL+G!H<#HX,2!A9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M
M:6XO<W%L<VAE;&PN<&AP.C$R.`IM<V=I9"`B17AE8W5T92(*;7-G<W1R(")%
M>&5C=71A<B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HR.3D@<&\O=')A;G-L
M871I;VXN<&AP.C,R,"!P;R]T<F%N<VQA=&EO;BYP:'`Z,S8R"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HT-#$@<&\O=')A;G-L871I;VXN<&AP.C4T,2!P;R]T
M<F%N<VQA=&EO;BYP:'`Z-C`Q"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW,#(@
M<&\O=')A;G-L871I;VXN<&AP.C<S-R!P;R]T<F%N<VQA=&EO;BYP:'`Z-SDX
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HX-S4@<&\O=')A;G-L871I;VXN<&AP
M.CDY-"!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`Q-@IM<V=I9"`B17AE8W5T:6YG
M.B(*;7-G<W1R(")%>&5C=71A;F1O.B(*"B,Z(&QI8B](;W)D92]";&]C:R],
M87EO=70N<&AP.C,Y-`IM<V=I9"`B17AP86YD(@IM<V=S='(@(D5X<&%N9&ER
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHS,0IM<V=I9"`B
M17AP86YD(%-I9&5B87(B"FUS9W-T<B`B36]S=')A<B!"87)R82!,871E<F%L
M(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%
M>'!E8W1E9"`G*2<B"FUS9W-T<B`B)RDG(&5S<&5R861O(@H*(SH@;&EB+TAO
M<F1E+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B87)E
M('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@(D5S<&5R879A
M('5M82!S:6UP;&5S('!A;&%V<F$@;W4@=6T@=&5R;6\@9&4@<')O8W5R82!E
M;G1R92!A<W!A<R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0P,0IM
M<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@(D1A=&$@9&4@17AP:7)A
MY^-O(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-S8*;7-G:60@
M(D5X<&]N96YT(@IM<V=S='(@(D5X<&]E;G1E(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%>'1R86-T:6YG(&9R
M;VT@)7,N+BX@(@IM<V=S='(@(D5X=')A:6YD;R!D92`E<RXN+B`B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Q
M"FUS9VED(")&1R!#;VQO<B(*;7-G<W1R(")#;W(@9&\@4')I;65I<F\@4&QA
M;F\B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P"FUS9VED(")&5%`@
M=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(D-A<G)E9V%R(&-O;F9I9W5R8>?C
M;R!D92!I;G-T86QAY^-O('!O<B!&5%`B"@HC.B!L:6(O2&]R9&4O4')E9G,O
M<W%L+G!H<#HR,38*;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N
M8V5S+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L('!U>&%R(&%S('!R969E
M<NIN8VEA<RXB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ,#`*;7-G
M:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R
M(")&86QH82!N82!L:6=AY^-O(&%O('-E<G9I9&]R($Q$05`N(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O<VUB+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE
M8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`B1F%L:&$@;F$@;&EG8>?C;R!A
M;R!S97)V:61O<B!334(N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C8P,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB
M"FUS9W-T<B`B1F%L:&$@86\@8V]P:6%R(&1E(%PB)7-<(BXB"@HC.B!L:6(O
M5D93+V9T<"YP:'`Z-C`X"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T
M;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`B1F%L:&$@86\@8V]P:6%R('!A
M<F$@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92]!=71H+W-A<VPN<&AP.C@W"FUS
M9VED(")&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM
M<V=S='(@(D9A;&AA(&%O(&-R:6%R('5M82!N;W9A(&-O;F5XXV\@4T%33"XB
M"@HC.B!L:6(O5D93+V9T<"YP:'`Z-C0Q"B,L('!H<"UF;W)M870*;7-G:60@
M(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B1F%L:&$@86\@
M;6]V97(@<&%R82!<(B5S7"(N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T<B`B0F]M(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@T(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HW.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,@IM
M<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@(DEL
M:&%S($9A;&ML86YD("A-86QV:6YA<RDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z.#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&87)O92!)<VQA;F1S
M(@IM<V=S='(@(DEL:&%S($9A<F]E(@H*(SH@;&EB+TAO<F1E+T-,22YP:'`Z
M,C,X"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`B17)R;R!&871A;#HB
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I
M9"`B1F%X(@IM<V=S='(@(D9A>"(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HS-S4@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0Q,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C8V"FUS9VED(")&96)R=6%R>2(*;7-G<W1R(")&979E<F5I<F\B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R,`IM<V=I9"`B1F5E;',@3&EK
M92(*;7-G<W1R(")!<&%R96YT82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,3D*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R(")!<&%R
M96YT83H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S='(@(D%L9W5N<R!!9W5A
M8V5I<F]S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B06QG=6YS
M($YE=O5E<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.30U"FUS9VED(")&
M:65L9"!M871R:7@B"FUS9W-T<B`B36%T<FEZ(&1E(&-A;7!O<R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HX,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@
M(D9I:FDB"FUS9W-T<B`B1FEJ:2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]R87(N<&AP.C8P(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8W
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B0V]N
M=&%G96T@9&4@07)Q=6EV;W,Z("5S(&%R<75I=F\B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O<F%R+G!H<#HV,"!L:6(O2&]R9&4O34E-12]6:65W97(O
M>FEP+G!H<#HV-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*
M;7-G<W1R(")#;VYT86=E;2!D92!!<G%U:79O<SH@)7,@87)Q=6EV;W,B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0V"FUS9VED(")&:6QE($UA
M;F%G97(B"FUS9W-T<B`B1V5S=.-O(&1E($9I8VAE:7)O<R(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8S(&QI8B](;W)D92]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<P"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN
M<&AP.C@R"FUS9VED(")&:6QE($YA;64B"FUS9W-T<B`B3F]M92!D;R!!<G%U
M:79O(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y.30*;7-G:60@(D9I;&4@
M<V5L96-T:6]N(@IM<V=S='(@(E-E;&5CY^-O(&1O(&%R<75I=F\B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,30X.`IM<V=I9"`B1FEL92!U<&QO860B"FUS
M9W-T<B`B0V%R<F5G86UE;G1O(&1E(&%R<75I=F\B"@HC.B!L:6(O2&]R9&4O
M0G)O=W-E<BYP:'`Z.#8S"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O
M<G1E9"XB"FUS9W-T<B`B0V%R<F5G86UE;G1O<R!D92!F:6-H96ER;W,@;N-O
M('/C;R!S=7!O<G1A9&]S+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HX.0IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R(")&:6QT<F]S(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C@R(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HX,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B
M1FEN;&%N9"(*;7-G<W1R(")&:6YLXFYD:6$B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,3<Q"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@(E%U87)T;R!#
M<F5S8V5N=&4B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K
M+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(E%U
M87)T;R!#<F5S8V5N=&4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C,Y"FUS9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B1FEX87(@
M<N%C:6\B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C$T"FUS9VED(")&;&EP(@IM<V=S='(@(DEN=F5R=&5R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I
M9"`B1FQO870B"FUS9W-T<B`B1FQU='5A;G1E(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R
M(").979O96ER;R(*"B,Z(&QI8B]61E,O<W%L+G!H<#HQ-C`@;&EB+U9&4R]M
M=7-Q;"YP:'`Z,3`W"B,L('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D
M;V5S(&YO="!E>&ES="(*;7-G<W1R(")!('!A<W1A("5S(&[C;R!E>&ES=&4N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R(")#;W(@9&\@5&5X=&\B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T
M<B`B0V]M:61A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(V"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA
M="!D;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R(")087)A(&YA=F5G861O
M<F5S('%U92!NXV\@<W5P;W)T86T@:6UA9V5N<R(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S,T"FUS9VED(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R(")0
M<F5V:7/C;R`H5$%&*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HW,0IM<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R
M971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@
M82`B"B)L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E
M(&)L;V-K*2(*;7-G<W1R("(B"B)$:6%S(&1E(%!R979I<^-O("AN;W1E+7-E
M('%U92!A<R!P<F5V:7/U97,@:6YC;'5E;2!T86YT;R!D:6%S(&-O;6\@;F]I
M=&5S.R`B"B)U;2!V86QO<B!D96UA<VEA9&\@9W)A;F1E('!O9&4@<F5S=6QT
M87(@;G5M(&)L;V-O(&UU:71O(&QA<F=O*2(*"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z.3@*;7-G:60@(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*
M;7-G<W1R(")%<W%U96-E=2US92!D82!P86QA=G)A+7!A<W-E/R(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#D*;7-G:60@(D9O<FUS(@IM<V=S
M='(@(DUO9&5L;W,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*;7-G
M:60@(D9O<G1U;F4B"FUS9W-T<B`B1&ET;W,B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R(")4:7!O
M(&1E(&1I=&]S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,X"FUS9VED
M(")&;W)T=6YE<R(*;7-G<W1R(")$:71O<R(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R(")$:71O<R`R
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P,`IM<V=I9"`B1F]R
M=6US(@IM<V=S='(@(D;S<G5N<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ,#D*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(E)E96YV:6]S(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C$T-3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1F]U;F0@87!P;&EC871I;VYS.B`E<R(*;7-G<W1R(")!<&QI8V'G]65S
M("AM\V1U;&]S*2!E;F-O;G1R861A<SH@)7,B"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,30U,@IM<V=I9"`B1F]U;F0@9&ER96-T;W)I97,Z(@IM<V=S='(@
M(E!A<W1A<R!E;F-O;G1R861A<SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R("(VJB(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S,*;7-G:60@(D9R86UE<R(*;7-G<W1R(")-;VQD=7)A<R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HX-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@
M(D9R86YC92(*;7-G<W1R(")297#Z8FQI8V$@1G)A;F-E<V$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E+"!-971R;W!O
M;&ET86XB"FUS9W-T<B`B1G)A;N=A+"!-971R;W!O;&ET86YA(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.CDQ(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HX-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B
M1G)E;F-H($=U:6%N82(*;7-G<W1R(")'=6EA;F$@1G)A;F-E<V$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@T(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HX-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I
M9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R(")0;VQI;NES:6$@1G)A;F-E
M<V$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(R(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#D*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*;7-G
M<W1R(")497)R87,@075S=')A:7,@92!!;G3A<F-T:6-A<R!&<F%N8V5S87,B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-`IM<V=I
M9"`B1G)O;2(*;7-G<W1R(")$92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,S8@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,T.`HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDT"FUS9VED(")&<F]M
M('1H92`B"FUS9W-T<B`B1&4@(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z-#@*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`B
M1&5S8W)IY^-O($-O;7!L971A(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@R
M(&QI8B]";&]C:R]M;V]N+G!H<#HQ.#$*;7-G:60@(D9U;&P@36]O;B(*;7-G
M<W1R("),=6$@0VAE:6$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C,Y"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`B3F]M92!#;VUP
M;&5T;R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV-3<*;7-G:60@(D9U>GIY
M(@IM<V=S='(@(D1I9G5S87,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M.#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@W"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<S"FUS9VED(")'86)O;B(*;7-G<W1R(")297#Z
M8FQI8V$@1V%B;VYE<V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@
M=&%K92!I;6%G92!F<F]M(@IM<V=S='(@(D=A;&5R:6$@9&4@;VYD92!R971I
M<F%R(&$@:6UA9V5M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G
M<W1R(")'86QE<FEA.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R(")297#Z8FQI
M8V$@9&$@1^)M8FEA(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N
M(@IM<V=S='(@(D=E<F%R($-O;F9I9W5R8>?C;R`E<R(*"B,Z('1E;7!L871E
M<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HQ,`IM<V=I9"`B1V5N97)A=&5D
M($-O9&4B"FUS9W-T<B`B0_-D:6=O($=E<F%D;R(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HT-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A=&EN9R!S
M=&%T=7,@9F]R(&UO9'5L92`E<RXN+B(*;7-G<W1R(")'97)A;F1O(&\@97-T
M861O(&1O(&WS9'5L;R`E<RXN+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HY,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T<B`B
M1V7S<F=I82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV.2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B4F5P^F)L:6-A($9E
M9&5R86P@9&$@06QE;6%N:&$B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,W
M,0IM<V=I9"`B1V5T;W!T($5R<F]R.B`B"FUS9W-T<B`B17)R;R!E;2!G971O
M<'0Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDS(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW-0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`B4F5P^F)L:6-A(&1O($=A;F$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.30@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.CDR"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U
M"FUS9VED(")':6)R86QT87(B"FUS9W-T<B`B1VEB<F%L=&%R(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S4*;7-G:60@(D=I=F5N($YA;64B
M"FUS9W-T<B`B3F]M92!0<O-P<FEO(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P
M<"YI;F,Z,3(*;7-G:60@(D=O(@IM<V=S='(@(DER(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D96PB"FUS9W-T<B`B1_9D96PB
M"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N
M<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@
M4V5A<F-H(@IM<V=S='(@(E!E<W%U:7-A($=O;V=L92(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HR,C`*;7-G:60@(D=R87ES8V%L
M92(*;7-G<W1R(").[79E:7,@9&4@8VEN>F5N=&\B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3`P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY
M,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W)E96-E
M(@IM<V=S='(@(D=RZ6-I82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U
M"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B1W)E9V\@*$E3
M3RTX.#4Y+3<I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDU(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW-0IM<V=I9"`B1W)E96YL86YD(@IM<V=S='(@(D=R;VYE;.)N
M9&EA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW-`IM<V=I9"`B1W)E;F%D82(*;7-G<W1R(")'<F%N861A(@H*(PHC.B!A
M9&UI;B]G<F]U<',N<&AP.C$W,`IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I
M;VXB"FUS9W-T<B`B061M:6YI<W1R8>?C;R!D92!'<G5P;W,B"@HC.B!L:6(O
M2&]R9&4O1W)O=7`N<&AP.C4X"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E
M(&YO;BUE;7!T>2(*;7-G<W1R(").;VUE<R!D92!G<G5P;W,@;N-O('!O9&5M
M(&5S=&%R('9A>FEO<R(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C(P,2!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(W-PIM<V=I9"`B1W)O=7`@<&5R;6ES
M<VEO;G,B"FUS9W-T<B`B4&5R;6ES<_5E<R!D92!G<G5P;R(*"B,Z(&%D;6EN
M+W!E<FUS+V5D:70N<&AP.C$W-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(U
M,"!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(D=R=7!O<R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY."!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8*
M;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B1W5A9&%L=7!E(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$P,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@
M(D=U86TB"FUS9W-T<B`B1W5A;2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%T96UA;&$B"FUS9W-T
M<B`B4F5P^F)L:6-A(&1A($=U871E;6%L82(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B1W5E<FYS97DB
M"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,C<@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HR,#4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX.`IM
M<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B4&5R;6ES<_5E<R!D
M87,@5FES:71A<R(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$R."!L:6(O
M2&]R9&4O4&5R;7,O54DN<&AP.C(P-@IM<V=I9"`B1W5E<W0@<&5R;6ES<VEO
M;G,B"FUS9W-T<B`B4&5R;6ES<_5E<R!D87,@5FES:71A<R(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT,3<*;7-G:60@(D=U97-T8F]O:R(*;7-G
M<W1R("),:79R;R!D92!6:7-I=&%S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.CDW(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W5I;F5A(@IM<V=S='(@
M(D=U:6[I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<X"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(D=U:6[I
M+4)I<W-A=2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#4@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(E)E</IB;&EC82!#
M;RUO<&5R871I=F$@9&$@1W5I86YA(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.CDV,`IM<V=I9"`B2%1-3"(*;7-G<W1R(")(5$U,(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B
M2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@
M8V5L;"!I;B!R;W<N(@IM<V=S='(@(D\@2%1-3$%R96$@<F5C=7-A+7-E(&-O
M8F%R9&5M96YT92!A(')E;6]V97(@82#Z;'1I;6$@8^EL=6QA(&1A(&QI;FAA
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@
M9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB"FUS9W-T<B`B3R!(
M5$U,07)E82!R96-U<V$M<V4@8V]B87)D96UE;G1E(&$@<F5M;W9E<B!A(/IL
M=&EM82!C;VQU;F$@9&$@=&%B96QA+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T
M86)L92XB"FUS9W-T<B`B3R!(5$U,07)E82!R96-U<V$M<V4@8V]B87)D96UE
M;G1E(&$@<F5M;W9E<B!A(/IL=&EM82!L:6YH82!D82!T86)E;&$N(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED(")(5%10($%U=&AE
M;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T96YT:6-AY^-O($A4
M4%`@;N-O(&9O:2!E;F-O;G1R861A+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2&%I=&DB"FUS9W-T
M<B`B4F5P^F)L:6-A(&1O($AA:71I(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z-#`R"FUS9VED(")(87-H+4%L9V]R:71H;2(*;7-G<W1R(")!;&=O
M<FET;6\@9&4@7")(87-H7"(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR,@IM<V=I9"`B2&%Z92(*;7-G<W1R(").96)L:6YA
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDQ.2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,CDS,0IM<V=I9"`B2&5A9&5R(@IM<V=S='(@(D-A8F7G86QH;R(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$P,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.0IM
M<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S
M='(@(DEL:&%S($AE87)D(&4@36-$;VYA;&0B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PIM<V=I9"`B2&5A=GD@5"U3=&]R
M;2(*;7-G<W1R(")496UP;W)A;"U4($9O<G1E(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#8*;7-G:60@(DAE8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G
M<W1R(")(96)R974@*$E33RTX.#4Y+3@M22DB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T"FUS9VED(")(96EG
M:'0B"FUS9W-T<B`B06QT=7)A(@H*(SH@;&EB+TAO<F1E+TAE;'`N<&AP.C$W
M.2!L:6(O2&]R9&4O2&5L<"YP:'`Z,3@V('-E<G9I8V5S+VAE;'`O:6YD97@N
M<&AP.C$W"B,Z('1E;7!L871E<R]H96QP+VEN9&5X+FEN8SHS"FUS9VED(")(
M96QP(@IM<V=S='(@(D%J=61A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B
M"FUS9W-T<B`B06IU9&$@<V]B<F4@;R!E9&ET;W(B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3,W,PIM<V=I9"`B2&5L<&5R(@IM<V=S='(@(D%J=61A(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.CDU"FUS9VED("(B"B)(96QP97(@87!P
M;&EC871I;VX@=&\@8W)E871E(&%N9"!M86EN=&%I;B!T<F%N<VQA=&EO;G,@
M9F]R('1H92!(;W)D95QN(@HB9G)A;65W;W)K(&%N9"!I=',@87!P;&EC871I
M;VYS+EQN(@HB1F]R(&%N(&EN=')O9'5C=&EO;B!R96%D('1H92!F:6QE(%)%
M041-12!I;B!T:&ES(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB07!L:6-AY^-O
M(&%U>&EL:6%R('!A<F$@8W)I87(@92!M86YT97(@=')A9'7G]65S(&1A('!L
M871A9F]R;6%<;B(*(DAO<F1E(&4@9&%S('-U87,@87!L:6-AY_5E<R`H;?-D
M=6QO<RDN7&XB"B)087)A('5M82!I;G1R;V1UY^-O(&QE<B!O(&9I8VAE:7)O
M(%)%041-12!N97-T82!P87-T82XB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`B2&5M:7-FZ7)I;R(*"B,Z
M('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$W('1E;7!L871E<R]D871A
M+V-S=FEN9F\N:6YC.C$W"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@
M;V8@=&AE(&9I;&4Z(@IM<V=S='(@(D%Q=6D@97-TX2!O(&EN[6-I;R!D;R!A
M<G%U:79O.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8Y"FUS9VED(")(:6=H(@IM<V=S='(@(D%L=&$B"@HC.B!L:6(O2&]R
M9&4O2&ES=&]R>2YP:'`Z,S(Q"FUS9VED(")(:7-T;W)Y(&5N=')Y(&YA;65S
M(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(DYO;65S(&1A<R!E;G1R861A
M<R!H:7-T\W)I87,@;N-O('!O9&5M(&5S=&%R('9A>FEO<R(*"B,Z('1E;7!L
M871E<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M;6]N
M+6AE861E<BYI;F,Z-`IM<V=I9"`B2&]?;64B"FUS9W-T<B`B0V%?<V$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0S(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$T
M"FUS9VED(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R
M(")%<W1A9&\@9&$@0VED861E(&1O(%9A=&EC86YO(@H*(SH@;&EB+TAO<F1E
M+G!H<#HQ-#,U"FUS9VED(")(;VUE(@IM<V=S='(@(D-A<V$B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R,B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM
M<V=S='(@(D5N9&5R9>=O(&1E($-A<V$B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R
M(")496QE9F]N92!D92!#87-A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$P."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R
M(")297#Z8FQI8V$@9&%S($AO;F1U<F%S(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$P-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<X"FUS9VED(")(;VYG($MO;F<B
M"FUS9W-T<B`B2&]N9W5E8V]N9W5E(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C8U"FUS9VED(")(;W)D92(*;7-G<W1R(")(;W)D92(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HQ,S(Y"FUS9VED(")(;W)D92!T<F%N<VQA=&EO
M;B!G96YE<F%T;W(B"FUS9W-T<B`B1V5R861O<B!D92!T<F%D=>?U97,@2&]R
M9&4B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0R,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O
M=6YT97)E9"!I;B!M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!$
M861O<R!834P@)7,@:6YVX6QI9&]S(&YA(&UE;G-A9V5M("5S(@H*(SH@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HR-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S
M(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!.96YH=6UA(&UE;G-A9V5M(&-O<G)E
M<W!O;F1E(&%O(&]B:F5C=&\@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.C0Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J
M96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(
M;W)D92]+;VQA8CH@3F5N:'5M(&]B:F5C=&\@9&\@=&EP;R`E<R!E;F-O;G1R
M861O(&YA(&UE;G-A9V5M("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ
M,C`X"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!3=6-C97-S
M9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(Z
M(%)E;6_GXV\@9&4@)7,@7"(E<UPB('1E=F4@<W5C97-S;R(*"B,Z(&QI8B](
M;W)D92]+;VQA8BYP:'`Z,3$U-`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@4W5C8V5S<V9U;&QY('-Y;F-H<F]N:7-E9"`E<R!<(B5S7"(B
M"FUS9W-T<B`B2&]R9&4O2V]L86(Z(%-I;F-R;VYI>F'GXV\@9&4@)7,@7"(E
M<UPB('1E=F4@<W5C97-S;R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,C(S
M"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R
M97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R(")(
M;W)D92]+;VQA8CH@3R!M;W1O<B!D92!I;G1E9W)AY^-O(')E<75E<B!A(&5X
M=&5N<^-O(%!(4"`G9&]M>&UL)R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z
M-#@Q"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@
M(B(*(DAO<F1E+TMO;&%B.B!.XV\@9F]I('!O<W/M=F5L(&-R:6%R('5M82!N
M;W9A(.%R=F]R97,@6$U,('!A<F$@;R!O8FIE8W1O("5S(@H*(SH@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HQ,C`U"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z($[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B`E<R!<
M(B5S7"(Z("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT-3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V
M92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S='(@(DAO
M<F1E+TMO;&%B.B!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&\@240@34E-12!P
M87)A(&$@<&%R=&4@9&4@=&EP;R`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP
M:'`Z,3$U,0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA
M8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R
M9&4O2V]L86(Z($[C;R!F;VD@<&]S<^UV96P@<VEN8W)O;FEZ87(@)7,@7"(E
M<UPB.B`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(X,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N
M:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($[C;R!F;VD@
M<&]S<^UV96P@<VEN8W)O;FEZ87(@<&%R=&EL:&%S.B`E<R(*"B,Z(&QI8B](
M;W)D92]+;VQA8BYP:'`Z,S$X"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+
M;VQA8CH@4&%R=&EL:&$@7"(E<UPB(&1E<V-O;FAE8VED82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO
M<FEZ;VYT86P@4G5L92(*;7-G<W1R(")4<F'G;R!(;W)I>F]N=&%L(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM<V=I
M9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(D5N8VAI;65N=&\@:&]R
M:7IO;G1A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@(DAO<FEZ;VYT
M86PZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4P"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L
M96%S92!R97!O<G0A*2(*;7-G<W1R(")#;VUO(&-H96=O=2!A<75I/R`H4&]R
M(&9A=F]R(')E<&]R=&4M;R$I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L
M=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B475A;G1A
M<R!C;VQU;F%S('!R971E;F1E(&IU;G1A<C\B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9I;F9O+FEN8SHR.`IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU
M;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@(E%U86YT;W,@8V%M<&]S("AC;VQU
M;F%S*2!E>&ES=&5M/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O=W,@=V]U
M;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(E%U86YT87,@;&EN:&%S
M('!R971E;F1E(&IU;G1A<C\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C@X(&QI8B]";&]C:R]M971A<BYP:'`Z,C,P"FUS9VED(")(=6UI
M9&ET>2(*;7-G<W1R(")(=6UI9&%D92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-#<*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B2'5M
M:61A9&4Z("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B
M2'5M;W)I<W1S(@IM<V=S='(@(DAU;6]R:7-T87,B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3$Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A
M<GDB"FUS9W-T<B`B4F5P^F)L:6-A(&1A($AU;F=R:6$B"@HC.B!L:6(O2&]R
M9&4O075T:"]C>7)U<RYP:'`Z,3<R(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP
M:'`Z,C,U"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A
M=&EO;B!F86EL960Z("5S(@IM<V=S='(@(D$@8W)I8>?C;R!D82!C86EX82!P
M;W-T86P@24U!4"!F86QH;W4Z("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER
M=7,N<&AP.C(Q-"!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C(Y-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D
M.B`E<R(*;7-G<W1R(")296UOY^-O(&1A(&-A:7AA('!O<W1A;"!)34%0(&9A
M;&AO=3H@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3<Y(&QI
M8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,C0R"B,L('!H<"UF;W)M870*;7-G
M:60@(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM
M<V=S='(@(D-R:6'GXV\@9&4@<75O=&$@9&4@8V%I>&$@<&]S=&%L($E-05`@
M9F%L:&]U.B`E<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S$W"FUS9VED
M("))4"!!9&1R97-S(@IM<V=S='(@(D5N9&5R9>=O($E0(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D9')E<W,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B16YD97)EYV\@25`@:6YD:7-P;V[M=F5L
M+B(*"B,Z(&QI8B](;W)D92]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))
M4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G
M<W1R(")%;F1E<F7G;R!)4"!F;W)A(&1O(&)L;V-O($-)1%(@<&5R;6ET:61O
M+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS
M9VED("))4"!L;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S='(@(E9I;VQAY^-O
M(&1E(&)L;W%U96EO(&1E($E0(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED("))7VYS97)T(%)O
M=R!"969O<F4B"FUS9W-T<B`B25]N<V5R:7(@3&EN:&$@06YT97,B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(P(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G
M:60@(DEC96QA;F0B"FUS9W-T<B`B4F5P^F)L:6-A(&1A($ES;.)N9&DB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8X"FUS9VED("))8V]N<R!/;FQY
M(@IM<V=S='(@(D%P96YA<R#-8V]N97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S8Y"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`BS6-O
M;F5S(&-O;2!497AT;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#(*
M;7-G:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B3F]M92!D82!I9&5N
M=&ED861E.B(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HU.#D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L87EE9"!C
M;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(*;7-G
M<W1R(")392!NXV\@9F]R(&UO<W1R861O(&-O<G)E8W1A;65N=&4L("5S('!A
M<F$@;R!A8G)I<B!N=6UA(&YO=F$@:F%N96QA+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT-#<*;7-G:60@(B(*(DEF('EO=2!D;VXG="!S964@86YY
M(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@
M=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R
M96YC>2XB"FUS9W-T<B`B(@HB4V4@;N-O('9I<B!Q=6%L<75E<B#M8V]N92!A
M;R!U<V%R(&\@26YT97)N970@17AP;&]R97(L('!O9&4@<')E8VES87(@9&4@
M(@HB<V5L96-C:6]N87(@97-T82!C86EX82!P87)A(&1E<VQI9V%R(&$@=')A
M;G-P87+J;F-I82XB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,34X"FUS9VED("(B"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B
M=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N
M)W0@8F4@(@HB9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B
M(@HB4V4@=FER(&5S=&$@;65N<V%G96T@;FUA<R!NXV\@82!I;6%G96T@<')O
M<')I86UE;G1E(&1I=&$L(&$@:6UA9V5M('%U92`B"B)P<F5T96YD92!C87)R
M96=A<B!NXV\@<&]D92!S97(@;6]S=')A9&$@<&5L;R!S974@;F%V96=A9&]R
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR.`IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B
M4')E=FESXV\@9&$@26UA9V5M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*
M;7-G<W1R(")54DP@9&$@:6UA9V5M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Q"FUS9VED("));6%G
M92!54DPZ(@IM<V=S='(@(E523"!D82!I;6%G96TZ(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,R"FUS
M9VED("));6%G92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B26UA9V5M(&1E(&=A
M;&5R:6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB
M"FUS9W-T<B`B26UA9V5M(&1E(&=A;&5R:6$Z(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$W-C(*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R(")#87)R
M96=A;65N=&\@9&$@:6UA9V5M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R("));6%G96YS(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O9&%T96UA
M<"YI;F,Z,3`*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-R!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`B26UP;W)T87(L(%!A<W-O("5D
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(D-A;7!O
M(&EM<&]R=&%D;SH@)7,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C<S"FUS9VED("));7!O<G1E9"!F:65L9',Z(@IM<V=S='(@(D-A;7!O<R!I
M;7!O<G1A9&]S.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2;W<@069T97(B
M"FUS9W-T<B`B26Y?<V5R:7(@3&EN:&$@1&5P;VES(@H*(SH@;&EB+TAO<F1E
M+T-O;7!R97-S+WII<"YP:'`Z,3,U"FUS9VED("));F-O<G)E8W0@86-T:6]N
M(&-O9&4@9VEV96XN(@IM<V=S='(@(D/S9&EG;R!D92!A8^?C;R!I;G1R;V1U
M>FED;R!E<W3A(&EN8V]R<F5C=&\N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S,@IM<V=I9"`B26YC;W)R96-T('5S97)N86UE(&%N
M9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`B3F]M92!D92!U=&EL:7IA9&]R(&]U
M('!A;&%V<F$M<&%S<V4@97)R861O<RXB"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R
M(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R
M("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*
M;7-G<W1R("(B"B).;VUE(&1E('5T:6QI>F%D;W(@;W4@96YD97)EYV\@86QT
M97)N871I=F\@97)R861O<RX@0V]N=&%C=&4@;R!S974@(@HB861M:6YI<W1R
M861O<B!D92!S:7-T96UA('!A<F$@;V)T97(@86IU9&$N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC
M<F5A<V4@26YD96YT(@IM<V=S='(@(D%U;65N=&%R(&$@26YD96YT8>?C;R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,38@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$P.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M,0IM<V=I9"`B26YD:6$B"FUS9W-T<B`B4F5P^F)L:6-A(&1A(,UN9&EA(@H*
M(SH@861M:6XO<&5R;7,O961I="YP:'`Z,30Q('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3,T"FUS9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@
M(E5T:6QI>F%D;W)E<R!);F1I=FED=6%I<R(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B26YD;VYE<VEA
M(@IM<V=S='(@(E)E</IB;&EC82!D82!);F1O;NES:6$B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B26YF;R(*;7-G
M<W1R("));F9O<FUAY^-O(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(T-@IM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M8>?C;R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3@*;7-G:60@(DEN
M9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(DEN9F]R
M;6'GXV\@:N$@;N-O(&5S=.$@9&ES<&]N[79E;"(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HU.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YI=&EA;&EZ:6YG
M(&UO9'5L92`E<RXN+B`B"FUS9W-T<B`B26YI8VEA;&EZ86YD;R!O(&WS9'5L
M;R`E<RXN+B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S0*;7-G:60@(DEN<V5R="!#7V]L=6UN($%F=&5R
M(@IM<V=S='(@(DEN<V5R:7(@0U]O;'5N82!$97!O:7,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*
M;7-G:60@(DEN<V5R="!);6%G92(*;7-G<W1R("));G-E<FER($EM86=E;2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*
M;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R("));G-E<FER(%1A8F5L82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*
M;7-G:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("));G-E<FER($QI9V'G
MXV\@X"!796(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@(DEN<V5R="!?0V]L=6UN($)E9F]R
M92(*;7-G<W1R("));G-E<FER(%]#;VQU;F$@06YT97,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G
M:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE
M(@IM<V=S='(@(DEN<VER:7(@=6UA(&YO=F$@8V]L=6YA(&1E<&]I<R!D82!C
M;W)R96YT92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B
M969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DEN<VER:7(@=6UA(&YO
M=F$@8V]L=6YA(&%N=&5S(&1A(&-O<G)E;G1E(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("))
M;G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R
M("));G-I<FER('5M82!N;W9A(&QI;FAA(&1E<&]I<R!D82!C;W)R96YT92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV,`IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U
M<G)E;G0@;VYE(@IM<V=S='(@(DEN<VER:7(@=6UA(&YO=F$@;&EN:&$@86YT
M97,@9&$@8V]R<F5N=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A<F%G
M<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(DEN<V5R:7(@
M=6T@<&%RX6=R869O(&%P\W,@;R!N\R!C;W)R96YT92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I
M9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E
M(@IM<V=S='(@(DEN<V5R:7(@=6T@<&%RX6=R869O(&%N=&5S(&1O(&[S(&-O
M<G)E;G1E(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN
M<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B26YS:7)I<B!M;V1E
M;&\@86QT97)N871I=F\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,Q
M"FUS9VED("));G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@
M8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B(@HB26YT
M<F]D=7IA('5M(&5N9&5R9>=O(&1E(&-O<G)E:6\@96QE8W1R\VYI8V\@;VYD
M92!P;W-S82!R96-E8F5R(&$@;F]V82`B"B)P86QA=G)A+7!A<W-E.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(DEN<VER:7(@
M8^EL=6QA(&%P\W,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4Y"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B
M"FUS9W-T<B`B26YS97)I<B!CZ6QU;&%S(&%N=&5S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`IM<V=I9"`B
M26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R("));G-E<FER(&/I;'5L82!D
M97!O:7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8U"FUS9VED("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G
M<W1R("));G-E<FER(&-O;'5N82!A;G1E<R(*"B,Z(&QI8B](;W)D92])34%0
M+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM
M<V=S='(@(DEN<V5R:7(@;65N<V%G96YS(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED("));G-E
M<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(DEN<V5R:7(@<&%RX6=R869O
M(&%N=&5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0S"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E9F]R
M92(*;7-G<W1R("));G-E<FER('!A<N%G<F%F;R!A;G1E<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*;7-G
M:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`B26YS97)I<B!L:6YH82!D
M97!O:7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E9F]R92(*;7-G<W1R
M("));G-E<FER(&QI;FAA(&%N=&5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(R,@IM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@
M=&AE('-E8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R("));G1R;V1U>F$@82!R
M97-P;W-T82!E>&EG:61A('!A<F$@82!P97)G=6YT82!D92!S96=U<F%NYV$Z
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M-@IM<V=I9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R("));G-E<FER
M+TUO9&EF:6-A<B!);6%G96TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("));G-E<G0O36]D:69Y($QI;FLB
M"FUS9W-T<B`B26YS97)I<B]-;V1I9FEC87(@3&EG8>?C;R(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC
M:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N
M(@IM<V=S='(@(D-RZ61I=&\@:6YS=69I8VEE;G1E('!A<F$@96YV:6%R('!A
M<F$@82!L:7-T82!D92!D:7-T<FEB=6GGXV\N(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R
M961I="XB"FUS9W-T<B`B0W+I9&ET;R!I;G-U9FEC:65N=&4N(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$P-S4*;7-G:60@(DEN=&5G97(B"FUS9W-T<B`B
M26YT96ER;R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3,S"FUS9VED("))
M;G1E9V5R(&QI<W0B"FUS9W-T<B`B3&ES=&$@9&4@:6YT96ER;W,B"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B26YV
M86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B541(("A5
M<V5R($1A=&$@2&5A9&5R*2!I;G;A;&ED;RXB"@HC.B!L:6(O2&]R9&4O0V]M
M<')E<W,O>FEP+G!H<#HQ-S`@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z
M,C`Q"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C(Q,`IM<V=I9"`B
M26YV86QI9"!:25`@9&%T82(*;7-G<W1R(")$861O<R!:25`@:6YVX6QI9&]S
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI
M9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`B07!L:6-AY^-O(&EN=N%L:61A+B(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED
M("));G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R("))1"!D92!L;W1E("A<(F)A
M=&-H7"(I(&EN=N%L:61O+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,#@X
M(&QI8B](;W)D92]&;W)M+G!H<#HR,34Y(&QI8B](;W)D92]&;W)M+G!H<#HR
M,C,S"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,CDX"FUS9VED("));G9A;&ED
M(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R(")/<R!D861O<R!S=6)M971I9&]S
M('/C;R!I;G;A;&ED;W,N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S
M<RXB"FUS9W-T<B`B16YD97)EYV\@9&4@9&5S=&EN;R!I;G;A;&ED;RXB"@HC
M.B!L:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HX,2!L:6(O2&]R9&4O0V]M
M<')E<W,O9&)X+G!H<#HQ,#`*(SH@;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP
M:'`Z,C(P"FUS9VED("));G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@(D9O
M<FUA=&\@9&\@87)Q=6EV;R!I;G;A;&ED;R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-C0*;7-G:60@(DEN=F%L:60@;&EC96YS92!K97DN
M(@IM<V=S='(@(D-H879E(&1A(&QI8V5NYV$@:6YVX6QI9&$N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U.`IM<V=I9"`B26YV86QI9"!L
M;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B3&]C86QI>F'GXV\@:6YVX6QI
M9&$@97-P96-I9FEC861A+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R
M(")M<V=?='EP92!I;G;A;&ED;RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P
M:5]I9"XB"FUS9W-T<B`B87!I7VED(&EN=N%L:61O(&]U(&5M(&9A;'1A+B(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED
M("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`B4&%R
MXFUE=')O<R!I;G;A;&ED;W,@;W4@96T@9F%L=&$N(@H*(SH@861M:6XO<&5R
M;7,O861D8VAI;&0N<&AP.C0S"FUS9VED("));G9A;&ED('!A<F5N="!P97)M
M:7-S:6]N+B(*;7-G<W1R(")097)M:7-SXV\@<&%R96YT86P@:6YVX6QI9&$N
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,`IM<V=I9"`B
M26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R("))1"!D92!P87)C96ER;R!I
M;G;A;&ED;RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38R
M"FUS9VED("));G9A;&ED('!R;V1U8W0@8V]D92XB"FUS9W-T<B`B0_-D:6=O
M(&1E('!R;V1U=&\@:6YVX6QI9&\N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#8*;7-G:60@(DEN=F%L:60@<')O=&]C;VPN(@IM
M<V=S='(@(E!R;W1O8V]L;R!I;G;A;&ED;RXB"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV
M86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R(")$97-T:6YA=.%R:6\@
M:6YVX6QI9&\Z(%PB)7-<(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3`T
M,R!L:6(O2&]R9&4O2V]L86(N<&AP.C$R,C`*;7-G:60@(DEN=F%L:60@<VAA
M<F4@;V)J96-T(@IM<V=S='(@(D]B:F5C=&\@9&4@<&%R=&EL:&$@:6YVX6QI
M9&\B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM
M<V=I9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B16YD97)E
MYV\@9&$@;W)I9V5M(&EN=N%L:61O+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T
M82XB"FUS9W-T<B`B1&%D;W,@=6YI8V]D92!I;G;A;&ED;W,N(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R-0IM<V=I9"`B26YV96YT;W)Y(@IM
M<V=S='(@(DEN=F5N=.%R:6\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3$Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DER86XL($ES;&%M:6,@4F5P
M=6)L:6,@;V8B"FUS9W-T<B`B4F5P^F)L:6-A($ES;.)M:6-A(&1O($ERXV\B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#$*;7-G:60@(DER87$B"FUS9W-T<B`B4F5P^F)L:6-A(&1O($ER87%U92(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3,@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Q,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M,`IM<V=I9"`B27)E;&%N9"(*;7-G<W1R(")297#Z8FQI8V$@9&$@27)L86YD
M82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@
M;V8@36%N(@IM<V=S='(@(DEL:&$@9&4@36%N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M
M4W1O<FUS(@IM<V=S='(@(E1E;7!O<F%I<RU4($ES;VQA9&]S(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P"FUS9VED
M("))<W)A96PB"FUS9W-T<B`B17-T861O(&1E($ES<F%E;"(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-C(U"FUS9VED("))<W-U97(B"FUS9W-T
M<B`B16UI<W-O<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(DETX6QI8V\B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(Q(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*
M;7-G:60@(DET86QY(@IM<V=S='(@(E)E</IB;&EC82!)=&%L:6%N82(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C,@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$Q-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@IM
M<V=I9"`B2F%M86EC82(*;7-G<W1R(")*86UA:6-A(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W-"!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#$Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B
M2F%N96ER;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C4@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX,PIM<V=I9"`B2F%P86XB"FUS9W-T<B`B2F%PXV\B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X-PIM<V=I9"`B2F%P86YE<V4@*$E33RTR
M,#(R+4I0*2(*;7-G<W1R(")*87!O;NIS("A)4T\M,C`R,BU*4"DB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(R"FUS9VED(")*97)S97DB"FUS9W-T
M<B`B2F5R<V5Y(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@S"FUS9VED(")*;W)D86XB"FUS9W-T<B`B4F5I;F\@2&%S
M:&5M:71A(&1A($IO<F3B;FEA(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C,X,"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`B2G5L:&\B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<Y(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,38*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R
M(")*=6YH;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`B2G5S=&EF
M:6-A<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$U"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R(")#
M96YT<F%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3<*;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R(")*
M=7-T:69I8V%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,30*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R
M(")*=7-T:69I8V%R(.`@17-Q=65R9&$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF
M>2!2:6=H="(*;7-G<W1R(")*=7-T:69I8V%R(.`@1&ER96ET82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$Q.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I
M9"`B2V%Z86MH<W1A;B(*;7-G<W1R(")297#Z8FQI8V$@9&\@0V%Z87%U:7-T
MXV\B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0V
M"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G<W1R(")0<F5S97)V87(@;R!O
M<FEG:6YA;#\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(V(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#,*;7-G:60@(DME;GEA(@IM<V=S='(@(E)E</IB;&EC82!D
M;R!1=>EN:6$B"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX-0IM<V=I
M9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R(")/('-E<G9I9&]R($ME<F)E<F]S(')E:F5I=&]U(&$@875T96YT
M:6-AY^-O+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B
M2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B3F]V871O<R!N;R!<(DME<FYE;%PB
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#`P"FUS9VED(")+97D@
M0W)E871I;VXB"FUS9W-T<B`B0W)I8>?C;R!D82!#:&%V92(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C0P,PIM<V=I9"`B2V5Y($9I;F=E<G!R:6YT
M(@IM<V=S='(@(DEM<')E<W/C;R!D:6=I=&%L(&1A(&-H879E(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#`Q"FUS9VED(")+97D@3&5N9W1H(@IM
M<V=S='(@(D-O;7!R:6UE;G1O(&1A(&-H879E(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z-#`P"FUS9VED(")+97D@5'EP92(*;7-G<W1R(")4:7!O
M(&1A($-H879E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3@*
M;7-G:60@(DME>2!5<V%G92(*;7-G<W1R(")5=&EL:7IAY^-O(&1A($-H879E
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-S(Y"FUS9VED(")+97D@
M86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S
M='(@(D$@8VAA=F4@:N$@97AI<W1E(&YO('-E<G9I9&]R(&1E(&-H879E<R!P
M^F)L:6-A<RXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@
M(DMI9',B"FUS9W-T<B`B36GZ9&]S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$R.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+:7)I8F%T:2(*;7-G
M<W1R(")1=6ER:6)A=&DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,R
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E
M;W!L92=S(%)E<'5B;&EC(&]F(@IM<V=S='(@(E)E</IB;&EC82!0;W!U;&%R
M($1E;6]C<N%T:6-A(&1A($-O<F5I82(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(E)E</IB;&EC82!D82!#;W)E:6$B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM
M<V=S='(@(D-O<F5A;F\@*$550RU+4BDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3,T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G
M<W1R(")+=7=A:70B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B4F5P
M^F)L:6-A(%%U:7)G=6EZ92(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI
M;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R(")?1&ES<&]S:>?C;R(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-SD@<&\O=')A;G-L871I;VXN
M<&AP.C8U-PIM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B261I;VUA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@W"FUS
M9VED("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R
M(")297#Z8FQI8V$@4&]P=6QA<B!$96UO8W+A=&EC82!,86\B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED("),87-T($AA;&8B"FUS9W-T<B`B
M475A<G1O($1E8W)E<V-E;G1E(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@X
M(&QI8B]";&]C:R]M;V]N+G!H<#HY,`IM<V=I9"`B3&%S="!1=6%R=&5R(@IM
M<V=S='(@(E%U87)T;R!$96-R97-C96YT92(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,34Q"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(MIL=&EM
M82!!8W1U86QI>F'GXV\Z(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C8X-@HC
M+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R("+:
M;'1I;6$@96YT<F%D83H@)7,B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z-C@X
M"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B
M"FUS9W-T<B`BVFQT:6UA(&5N=')A9&$Z("5S(&1E("5S(@H*(SH@;&EB+TAO
M<F1E+T%U=&@N<&AP.C8X,PIM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS
M9W-T<B`BVFQT:6UA(&5N=')A9&$Z($YU;F-A(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$T-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),871V:6$B
M"FUS9W-T<B`B4F5P^F)L:6-A(&1A($QE=/-N:6$B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#0*;7-G:60@(DQA=R(*;7-G<W1R("),96DB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*
M;7-G:60@(DQA>6]U="(*;7-G<W1R(")$:7-P;W-IY^-O(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A
M=F4@96UP='D@9F]R(&YO(&)O<F1E<B(*;7-G<W1R(")$96EX87(@=F%Z:6\@
M<&%R82!F:6-A<B!S96T@8F]R9&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3,X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C@*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQE8F%N;VXB"FUS9W-T
M<B`B3.UB86YO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C8Y"FUS9VED("),969T(@IM<V=S='(@(D5S<75E<F1A
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,3@*;7-G:60@(DQE9G0@:&5A
M9&5R(@IM<V=S='(@(D-A8F7G86QH;R!D82!E<W%U97)D82(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HS,3$T"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R
M(")686QO<F5S(.`@97-Q=65R9&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,30S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQE<V]T:&\B"FUS9W-T
M<B`B3&5S;W1O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@X"FUS9VED("),:6)E<FEA(@IM<V=S='(@(DQI8NER:6$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30W(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,S$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#D*;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B1W)A
M;F1E($IA;6%H:7)I>6$@4V]C:6%L:7-T82!0;W!U;&%R(,%R86)E(&1A($SM
M8FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@X"FUS9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@(DQI<W1E;G-T
M86EN92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(U"FUS9VED("),:6=H="!$<FEZ>FQE(@IM<V=S='(@(D-H=79A(%PB36]L
M:&$M5&]L;W-<(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(V"FUS9VED("),:6=H="!286EN(@IM<V=S='(@(D-H=79I<V-O
M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W
M"FUS9VED("),:6=H="!286EN($5A<FQY(@IM<V=S='(@(D-H=79I<V-O<R!-
M871I;F%I<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(X"FUS9VED("),:6=H="!286EN($QA=&4B"FUS9W-T<B`B0VAU=FES
M8V]S(%9E<W!E<G1I;F]S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S
M='(@(E!E<75E;F\@06=U86-E:7)O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4
M:'5N9&5R(@IM<V=S='(@(D-H=79I<V-O(&-O;2!4<F]V;V%D82(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),
M:6=H="!3;F]W(@IM<V=S='(@(E%U961A(&1E($YE=F4B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B3&EG:'0@
M4VYO=R!3:&]W97(B"FUS9W-T<B`B3F5V92(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B7"),:6UE<FEC
M:UPB(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X,34*;7-G:60@(DQI;FLB
M"FUS9W-T<B`B3&EG8>?C;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B3&EN:R!P;VEN=',@
M=&\Z(@IM<V=S='(@(DQI9V'GXV\@87!O;G1A('!A<F$Z(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$X-S8*;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D9')E
M<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T
M<B`B(@HB3&EG87(@;R!E;F1E<F7G;R!D92!C;W)R96EO(&5L96-T<O-N:6-O
M(.`@<.%G:6YA(&1E(&-O;7!O<VGGXV\@86\@;6]S=')A<B(*"B,Z(&QI8B](
M;W)D92]497AT+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,PIM<V=I9"`B3&EN
M:W,B"FUS9W-T<B`B3&EG8>?U97,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI92(*;7-G<W1R(")";VQI;FAO(&QI
M;G5XZG,B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*
M;7-G:60@(DQI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R
M("),:7-T82`M(&\@=71I;&EZ861O<B!P;V1E('9E<B!A('!A<W1A(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$S,`IM<V=I9"`B3&ES="!$871A8F%S97,B
M"FUS9W-T<B`B3&ES=&%R($)A<V5S(&1E($1A9&]S(@H*(SH@<V5R=FEC97,O
M:&5L<"]I;F1E>"YP:'`Z-3`*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS
M9W-T<B`B36]S=')A<B!4\W!I8V]S(&1E($%J=61A(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C$R.0IM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B3&ES
M=&%R(%1A8F5L87,B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU
M.30*;7-G:60@(DQI<W0M07)C:&EV92(*;7-G<W1R("),:7-T86=E;2U!<G%U
M:79O(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3@Y"FUS9VED
M("),:7-T+4AE;'`B"FUS9W-T<B`B3&ES=&%G96TM06IU9&$B"@HC.B!L:6(O
M2&]R9&4O34E-12](96%D97)S+G!H<#HU.38*;7-G:60@(DQI<W0M260B"FUS
M9W-T<B`B240@9&$@3&ES=&$B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S
M+G!H<#HU.3(*;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T<B`B3&ES=&%G96TM
M1&]N;R(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y,PIM<V=I
M9"`B3&ES="U0;W-T(@IM<V=S='(@(DQI<W1A9V5M+5-U8FUI<W/U97,B"@HC
M.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.3$*;7-G:60@(DQI<W0M
M4W5B<V-R:6)E(@IM<V=S='(@(DQI<W1A9V5M+5-U8G-C<FET87,B"@HC.B!L
M:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.3`*;7-G:60@(DQI<W0M56YS
M=6)S8W)I8F4B"FUS9W-T<B`B3&ES=&%G96TM3N-O('-U8G-C<FET87,B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C0*;7-G:60@(DQI
M<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(D$@;&ES=&%G96T@
M9&4@=71I;&EZ861O<F5S(&5S=.$@9&5S86-T:79A9&$N(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@
M(DQI=&5R871U<F$Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:71H=6%N:6$B"FUS9W-T<B`B4F5P
M^F)L:6-A(&1A($QI='7B;FEA(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$S
M,S@*;7-G:60@(DQO861I;F<@;&EB<F%R:65S+BXN(@IM<V=S='(@(D-A<G)E
M9V%N9&\@8FEB;&EO=&5C87,N+BXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O:6UA9V5S+G!H<#HY,@IM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R(")#
M87)R96=A;F1O+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$Y.0IM<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S='(@(E1E;7!O(&QO8V%L
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,PIM<V=I9"`B3&]C86QE
M(&%N9"!4:6UE(@IM<V=S='(@(DQO8V%L:7IAY^-O(&4@1G5S;R!(;W+A<FEO
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S$@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C4V"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H
M<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP.C8U"FUS9VED("),;V-A=&EO;B(*
M;7-G<W1R("),;V-A;&EZ8>?C;R(*"B,Z(&QO9VEN+G!H<#HQ-C(@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C$V-"!T96UP;&%T97,O;&]G:6XO;6]B
M:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.#8*;7-G:60@(DQO9R!I;B(*;7-G
M<W1R(")%;G1R87(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,34X"FUS9VED("),;V<@;W5T(@IM<V=S='(@(E-A:7(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3`W"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R
M(")487)E9F%S(&1E($5N=')A9&$B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z
M.3,Q"FUS9VED("),;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE
M(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R
M("(B"B)!(&%U=&5N=&EC8>?C;R!F86QH;W4@<&]R(&\@3F]M92!D92!5=&EL
M:7IA9&]R(&]U(&$@4&%L879R82U087-S92!E<W1A<F5M("(*(FEN8V]R<F5C
M=&]S+B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY,C<*;7-G:60@(DQO9VEN
M(&9A:6QE9"XB"FUS9W-T<B`B02!A=71E;G1I8V'GXV\@9F%L:&]U+B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,S8W"FUS9VED("),;VYG('1E>'0B"FUS
M9W-T<B`B5&5X=&\@;&]N9V\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#@*;7-G:60@(DQO=F4B"FUS9W-T<B`B06UO<B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W"FUS9VED("),;W<B"FUS9W-T
M<B`B0F%I>&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S
M(@IM<V=S='(@(DQE=')A<R!G<F5G87,@;6EN^G-C=6QA<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*
M;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B3&5T<F%S(&QA
M=&EN87,@;6EN^G-C=6QA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N
M(&YU;6)E<G,B"FUS9W-T<B`B3OIM97)O<R!R;VUA;F]S(&UI;OIS8W5L;W,B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30U(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,S0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#D*;7-G:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B3'5X96UB=7)G;R(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS-S,@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,`HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B34TB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C4S"FUS9VED(")-3U1$(@IM<V=S='(@(DU/
M5$0B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G
M:60@(DU3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS
M9W-T<B`B3R!A;F5X;R!-4RU43D5&(&[C;R!C;VYT:6YH82!D861O<RXB"@HC
M.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z
M,S<*;7-G:60@(DU31R(*;7-G<W1R(")-4T<B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,34W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S4*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA8V%O(@IM
M<V=S='(@(DUA8V%U(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M97(@
M675G;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T<B`B36%C963S;FEA+"!!;G1I
M9V$@4F5P^F)L:6-A($IU9V]S;&%V82!D82(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A
M<B(*;7-G<W1R(")-861A9^%S8V%R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0Y"FUS9VED(")-86=I8R(*;7-G<W1R(")-86=I82(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HX,0IM<V=I9"`B36%I;"(*;7-G<W1R(")#
M;W)R96EO(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W-PIM<V=I
M9"`B36%I;"!!9&UI;B(*;7-G<W1R(")!9&UI;FES=')AY^-O(&1E($-O<G)E
M:6\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-#`*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B1F%Z
M97(@;&E?9V'GXV\N+BXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,U-PIM
M<V=I9"`B36%K92!S=7)E('1H870@>6]U(&AA=F4@4$5!4B!I;G-T86QL960@
M86YD(&EN('EO=7(@:6YC;'5D92!P871H+B(*;7-G<W1R("(B"B)!<W-E9W5R
M92US92!D92!Q=64@=&5M(&\@4$5!4B!I;G-T86QA9&\@92!N;R!C86UI;FAO
M(&1E(&EN8VQU<_5E<R`H:6YC;'5D92`B"B)P871H*2XB"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z-C<X('!O+W1R86YS;&%T:6]N+G!H<#HQ,#<T"B,L('!H
M<"UF;W)M870*;7-G:60@(DUA:VEN9R!D:7)E8W1O<GD@)7,B"FUS9W-T<B`B
M0W)I86YD;R!A('!A<W1A("5S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$V-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QA=VDB"FUS9W-T<B`B
M36%L875I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDU"FUS9VED(")-86QA>7-I82(*;7-G<W1R(")-86SA<VEA(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT
M"FUS9VED(")-86QD:79E<R(*;7-G<W1R(")-86QD:79A<R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$T,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B
M36%L:2(*;7-G<W1R(")-86QI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$V,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QT82(*;7-G<W1R(")-
M86QT82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,0IM<V=I9"`B(@HB
M36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B
M96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@
M=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B(@HB1VER82!A(&QI<W1A(&1E
M(&-A=&5G;W)I87,@<75E('!O9&4@871R:6)U:7(@86]S(&ET96YS+"!B96T@
M8V]M;R!A<R!C;W)E<R`B"B)Q=64@;&AE<R!E<W3C;R!A<W-O8VEA9&%S+B(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#,Y"FUS
M9VED(")-87`R-"!M87`B"FUS9W-T<B`B36%P82!-87`R-"(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY-S<*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-30*;7-G:60@(DUA<%%U97-T
M(&UA<"(*;7-G<W1R(")-87!A($UA<%%U97-T(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W-B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#$S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@(DUA<N=O
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT,0IM<V=I9"`B36%R9VEN(@IM<V=S='(@(DUA<F=E;2(*"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W
M:71H(%-E96XO56YS965N(&9L86=S(@IM<V=S='(@(DUA<F-A<B!C;VUO($QI
M9&$O3N-O(&QI9&$B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O
M<G1A;G0O06YS=V5R960I(@IM<V=S='(@(DUA<F-A<B!D92!O=71R87,@9F]R
M;6%S("AE+F<N+"!);7!O<G1A;G1E+U!O<B!R97-P;VYD97(I(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$U,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDQ"FUS9VED
M(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(DEL:&%S($UA<G-H86QL(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U.2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDS
M"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@(DUA<G1I;FEC82(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3$Q"FUS9VED(")-871C:&EN9R!F
M:65L9',B"FUS9W-T<B`B0V%M<&]S('%U92!C;W)R97-P;VYD96TB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38P(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-#4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,*;7-G
M:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B36%U<FETXFYI82(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$T-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B
M36%U<FET:75S(@IM<V=S='(@(DUA=7+M8VEO(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R
M961I="XB"FUS9W-T<B`B3>%X:6UO(&-RZ61I=&\@<&5R;6ET:61O+B(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-
M87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB"FUS9W-T<B`B3>%X:6UO(&[Z
M;65R;R!D92!P87)T97,@;G5M82!M96YS86=E;2!E>&-E9&ED;RXB"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,P-@IM<V=I9"`B36%X('1E;7`@;&%S="`R
M-"!H;W5R<SH@(@IM<V=S='(@(E1E;7!E<F%T=7)A(&WA>&EM82!N87,@^FQT
M:6UA<R`R-"!H;W)A<SH@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3@*
M;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(E1E;7!E
M<F%T=7)A(&WA>&EM82!N87,@^FQT:6UA<R`V(&AO<F%S.B`B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z.#DX(&QI8B](;W)D92]&;W)M+G!H<#HQ,C$W(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,C,Y"FUS9VED(")-87AI;75M(&QE;F=T:"(*
M;7-G<W1R(")#;VUP<FEM96YT;R!MX7AI;6\B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<X(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@(DUA:6\B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4S(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W
M"FUS9VED(")-87EO='1E(@IM<V=S='(@(DUA>6]T=&4B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-3`*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(DUE
M9&EC:6YA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ
M.0IM<V=I9"`B365M8F5R<R(*;7-G<W1R(")-96UB<F]S(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,W,`IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R
M(")-;V1O(&1O(&UE;G4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS
M9W-T<B`B56YI<B!CZ6QU;&%S(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C4R
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")-97)G:6YG(&%L;"`E<RYP;R!F:6QE
M<R!T;R!T:&4@8V]M<&5N9&EU;2XN+B`B"FUS9W-T<B`B26YT96=R86YD;R!T
M;V1O<R!O<R!F:6-H96ER;W,@)7,N<&\@8V]M(&\@8V]M<.IN9&EO+BXN(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C0S.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")-97)G:6YG(&QO8V%L92`E<RXN+B`B"FUS9W-T<B`B26YT96=R86YD;R!A
M(&QO8V%L:7IAY^-O("5S+BXN("(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW
M.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B365R9VEN9R!T:&4@4$\@9FEL92!F
M;W(@)7,@=&\@=&AE(&-O;7!E;F1I=6TN+BX@(@IM<V=S='(@(DEN=&5G<F%N
M9&\@;R!A<G%U:79O(%!/(&1E("5S(&-O;2!O(&-O;7#J;F1I;RXN+B`B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#(U"B,L('!H<"UF;W)M870*;7-G:60@
M(DUE<F=I;F<@=')A;G-L871I;VX@9F]R(&UO9'5L92`E<RXN+B(*;7-G<W1R
M("));G1E9W)A;F1O(&$@=')A9'7GXV\@9&\@;?-D=6QO("5S+BXN(@H*(SH@
M;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P
M"FUS9VED(")-97-S86=E(@IM<V=S='(@(DUE;G-A9V5M(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R
M:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A
M=&4@8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"B)-96YS
M86=E;B!697)I9FEC861A(&-O;2!3=6-E<W-O+"!M87,@;R!C97)T:69I8V%D
M;R!D;R!S=6)S8W)I=&]R(&[C;R!P]&1E("(*(G-E<B!V97)I9FEC861O+B(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"FUS9VED
M(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(DUE;G-A9V5M(&5X<&ER;W4N
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V.2!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C8P"FUS9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`B
M5&EP;R!D92!M96YS86=E;2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM
M<V=I9"`B365T87(@5V5A=&AE<B(*;7-G<W1R(")-971E;W)O;&]G:6$@3454
M05(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W"FUS9VED(")-971A<B!B
M;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")";&]C;R!-151!4B!I;F1I
M<W!O;NUV96PN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3(*;7-G:60@
M(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B
M965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*
M(D)L;V-O($U%5$%2(&EN9&ES<&]N[79E;"X@3W,@<&]R;65N;W)E<R!F;W)A
M;2!R96=I<W1A9&]S('!A<F$@;R`B"B)A9&UI;FES=')A9&]R+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3(*;7-G:60@(DUE=&%R1$(@
M:7,@;F]T(&-O;FYE8W1E9"XB"FUS9W-T<B`B02!-971A<D1"(&[C;R!E<W3A
M(&-O;F5C=&%D82XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H
M<#HV-R!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B
M365T:&]D(@IM<V=S='(@(DWI=&]D;R(*"B,Z(&QI8B](;W)D92]24$,O>&UL
M<G!C+G!H<#HX,2!L:6(O2&]R9&4O4E!#+W-O87`N<&AP.C$Q-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D(@IM
M<V=S='(@(D\@;>ET;V1O(%PB)7-<(B!NXV\@97-TX2!D969I;FED;R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-B!L:6(O0FQO8VLO;65T
M87(N<&AP.C<U"FUS9VED(")-971R:6,B"FUS9W-T<B`B3>ET<FEC;R(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C8@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$T.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM
M<V=I9"`B365X:6-O(@IM<V=S='(@(DWI>&EC;R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HX-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<R"FUS9VED(")-:6-R;VYE
M<VEA+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(DUI8W)O;NES:6$L
M($5S=&%D;W,@1F5D97)A9&]S(&1A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"FUS9VED(")-:61D;&4B"FUS
M9W-T<B`B0V5N=')O(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N968N
M<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B5&EP;R!-24U%(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3`*;7-G:60@(DUI;B!T96UP(&QA
M<W0@,C0@:&]U<G,Z("(*;7-G<W1R(")496UP97)A='5R82!M[6YI;6$@;F%S
M(/IL=&EM87,@,C0@:&]R87,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P
M,@IM<V=I9"`B36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B5&5M
M<&5R871U<F$@;>UN:6UA(&YA<R#Z;'1I;6%S(#8@:&]R87,B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C$W"FUS9VED(")-:7)R
M;W(B"FUS9W-T<B`B17-P96QH;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU,0IM<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R(")-:7-C96SB;F5A
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W,B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,`IM<V=I9"`B36ES<VEN
M9R!014%2('!A8VMA9V4@2%144%]297%U97-T+B(*;7-G<W1R(")086-O=&4@
M2%144%]297%U97-T(&1O(%!%05(@96T@9F%L=&$N(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$Q-`IM<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T
M:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@
M=&\@=7-E('1H:7,@(@HB87!P;&EC871I;VXN(@IM<V=S='(@(B(*(D-O;F9I
M9W5R8>?C;R!E;2!F86QT82X@5&5RX2!D92!A(&=E<F%R(&%G;W)A('-E('%U
M:7-E<B!U<V%R(&5S=&$@87!L:6-AY^-O+B(*"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`T"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@
M240N(@IM<V=S='(@(DE$(&1A(&UE;G-A9V5M(&5M(&9A;'1A+B(*"B,Z(&QI
M8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI
M<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S='(@(E!A
M8V]T92!-86EL(&1O(%!%05(@96T@9F%L=&$N(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO
M;B!)1"XB"FUS9W-T<B`B240@9&$@<V5S<^-O(&5M(&9A;'1A+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-38*;7-G:60@
M(DUO(@IM<V=S='(@(C*J(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C<T"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R(")#;W)R96EO($WS=F5L
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*
M;7-G:60@(DUO9&5R871E(@IM<V=S='(@(DUO9&5R861O(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+WII<"YP:'`Z-S,*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#4*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B1&%T82!D92!-
M;V1I9FEC8>?C;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I9"`B36]D:69Y(%523"(*;7-G<W1R
M(")-;V1I9FEC87(@55),(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8U-PIM
M<V=I9"`B36]D=6QE(@IM<V=S='(@(DWS9'5L;R(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-C<S"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(DWS
M9'5L;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3`@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B
M4F5P^F)L:6-A(&1A($UO;&1O=F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,30Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R
M(")0<FEN8VEP861O(&1O($WS;F%C;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36]N9V]L:6$B"FUS
M9W-T<B`B36]N9_-L:6$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4Y,PIM
M<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B3>IS(&4@86YO(@H*(SH@
M;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*
M;7-G<W1R(")-96YS86QM96YT92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36]N='-E<G)A="(*;7-G
M<W1R(")-;VYT<V5R<F%T(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB
M+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G<W1R
M(")&87-E(&1A($QU82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R(")296EN
M;R!D92!-87)R;V-O<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@0VQE87(B"FUS9W-T<B`B4V]B
M<F5T=61O($QI;7!O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S0*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B4V]B
M<F5T=61O($5N979O861O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S4*;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R(")3
M;V)R971U9&\@4V]L87)E;F=O(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="YP:'`Z-#(X"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B1&5S8V5R(@H*
M(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-#,R"FUS9VED(")-;W9E
M($QE9G0B"FUS9W-T<B`B36]V97(@<&%R82!A($5S<75E<F1A(@H*(SH@;&EB
M+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-#,V"FUS9VED(")-;W9E(%)I9VAT
M(@IM<V=S='(@(DUO=F5R('!A<F$@82!$:7)E:71A(@H*(SH@;&EB+TAO<F1E
M+T)L;V-K+TQA>6]U="YP:'`Z-#(T"FUS9VED(")-;W9E(%5P(@IM<V=S='(@
M(E-U8FER(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Y-@IM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(D1E<V-E<B(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT.34@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Y-@IM<V=I9"`B36]V92!U<"(*
M;7-G<W1R(")3=6)I<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R(")2
M97#Z8FQI8V$@9&4@36_G86UB:7%U92(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR,3@U"FUS9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B"FUS
M9W-T<B`B3&ES=&%S(&1E(&1E<V5N<F]L87(@;75L=&DM;NUV96PB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C(T,PIM<V=I9"`B375L=&EP;&4@<V5L96-T
M:6]N(@IM<V=S='(@(E-E;&5CY^-O(&WZ;'1I<&QA(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,S,2!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S,X"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@(D$@36EN:&$@0V]N=&$B
M"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C4Q"FUS9VED(")->2!0
M;W)T86PB"FUS9W-T<B`B3R!-974@4&]R=&%L(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+V5D:70N<&AP.C$R-`IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G
M<W1R(")$:7-P;W-IY^-O(&1O(%!O<G1A;"(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B37EA;FUA<B(*
M;7-G<W1R(")5;FGC;R!D92!->6%N;6%R(@H*(SH@=&5M<&QA=&5S+VUA:6YT
M96YA;F-E+V%G<F5E;65N=%]B;W1T;VTN:6YC.C<*;7-G:60@(DY/+"!)($1O
M($Y/5"!!9W)E92(*;7-G<W1R(").XV\L(&[C;R!C;VYC;W)D;R(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C0P,"!L:6(O2&]R9&4O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$P,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&YE
M9BYP:'`Z,S@*;7-G:60@(DYA;64B"FUS9W-T<B`B3F]M92(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$U-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B
M3F%M:6)I82(*;7-G<W1R(")297#Z8FQI8V$@9&$@3F%M[6)I82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$U.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I
M9"`B3F%U<G4B"FUS9W-T<B`B3F%U<G4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3<W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE<&%L(@IM<V=S
M='(@(DYE<&%L(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDW"FUS9VED(").971H97)L86YD<R(*;7-G<W1R(")296EN
M;R!D;W,@4&'M<V5S($)A:7AO<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H97)L86YD<R!!;G1I
M;&QE<R(*;7-G<W1R(")!;G1I;&AA<R!(;VQA;F1E<V%S(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C87!E($)A<V4@
M55),(@IM<V=S='(@(E523"!D92!"87-E($YE='-C87!E(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C87!E($-!(%)E
M=F]C871I;VX@55),(@IM<V=S='(@(E523"!D92!2979O9V'GXV\@0T$@3F5T
M<V-A<&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-0IM<V=I
M9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R(")54DP@8V]M(&$@
M<&]L[71I8V$@9&4@0T$@3F5T<V-A<&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS
M9W-T<B`B55),(&1E(%)E;F]V8>?C;R!.971S8V%P92(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P92!2979O8V%T
M:6]N(%523"(*;7-G<W1R(")54DP@9&4@4F5V;V=AY^-O($YE='-C87!E(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C
M87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R(").;VUE(&1O('-E<G9I9&]R
M(%-33"!.971S8V%P92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3@W"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S
M='(@(D-O;65N=.%R:6\@9&4@8V5R=&EF:6-A9&\@3F5T<V-A<&4B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X,`IM<V=I9"`B3F5T<V-A<&4@
M8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R(")4:7!O(&1E(&-E<G1I9FEC861O
M($YE='-C87!E(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S.0IM
M<V=I9"`B3F5T=V]R:R(*;7-G<W1R(")2961E(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z-#$T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,C<*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.`IM<V=I9"`B3F5V97(B"FUS9W-T
M<B`B3G5N8V$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B3F]V
M82!#86QE9/-N:6$B"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA
M9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M
M96YT+FEN8SHR-PIM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(DYO=F$@
M0V%T96=O<FEA(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C
M:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<Y"FUS9VED(").
M97<@36]O;B(*;7-G<W1R("),=6$@3F]V82(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T
M:6]N86PI(@IM<V=S='(@(DYO=F\@3F]M92!D92!5=&EL:7IA9&]R("AO<&-I
M;VYA;"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@P(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3@*;7-G:60@(DYE=R!:96%L86YD(@IM<V=S='(@(DYO=F$@6F5L
MXFYD:6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDQ"FUS9VED(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(DYO
M=F$@:F%N96QA("A?8FQA;FLI(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M-#`@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR-C$*;7-G:60@(DYE=W,B"FUS9W-T<B`B3F]T[6-I87,B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,CDU"FUS9VED(").97=S
M9W)O=7!S(@IM<V=S='(@(D=R=7!O<R!D92!.;W3M8VEA<R(*"B,Z('1E;7!L
M871E<R]D871A+W1S=FEN9F\N:6YC.C(Q('1E;7!L871E<R]D871A+V1A=&5M
M87`N:6YC.C0V"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3,W('1E
M;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C,R"FUS9VED(").97AT(@IM<V=S
M='(@(E!R\WAI;6$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*;7-G:60@
M(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B4'+S>&EM87,@-"!&87-E<R(*"B,Z
M(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S<P(&QI8B](;W)D92]0<F5F<R]5
M22YP:'`Z,S<T"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T<B`B4'+S>&EM
M87,@;W#G]65S(@H*(SH@;&EB+TAO<F1E+U5)+U!A9V5R+G!H<#HQ,#,*;7-G
M:60@(DYE>'0^(@IM<V=S='(@(E!R\WAI;6$^(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$W-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6-A<F%G
M=6$B"FUS9W-T<B`B4F5P^F)L:6-A(&1A($YI8V%RX6=U82(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$V-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B
M3FEG97(B"FUS9W-T<B`B4F5P^F)L:6-A(&1O($[M9V5R(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$W,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"FUS9VED(").
M:6=E<FEA(@IM<V=S='(@(E)E</IB;&EC82!&961E<F%L(&1A($YI9V5R:6$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8X"FUS9VED(").
M:6=H="(*;7-G<W1R(").;VET92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3FEU92(*;7-G<W1R(").
M:75E(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@X
M-0IM<V=I9"`B3F\B"FUS9W-T<B`B3N-O(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W-E='5P+V1I9F8N:'1M;#HQ-@IM<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I
M9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T
M<B`B(@HB3N-O(&CA(&1A9&]S(&1E(&-O;F9I9W5R8>?C;R!D:7-P;V[M=F5I
M<R!E;2!R96QAY^-O(&%O<R!Q=6%I<R!M;W-T<F%R("(*(F1I9F5R96[G87,N
M(@H*(SH@;&EB+U9&4R])4T]7<FET97(N<&AP.C$P-0IM<V=I9"`B3F\@879A
M:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T
M<B`B3N-O(&CA(&YE;FAU;6$@97-T<F%TZ6=I82!D:7-P;V[M=F5L('!A<F$@
M<F5A;&EZ87(@:6UA9V5N<R!)4T\N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*
M;7-G<W1R(").XV\@:.$@;6]D96QO(&1E(&QO=&4@7")B871C:%PB+B(*"B,Z
M(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C<Y(&QI8B](;W)D92]";&]C
M:R],87EO=70N<&AP.C(S,`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H
M<#HR-3(*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D
M('!O<VET:6]N(@IM<V=S='(@(D[C;R!E>&ES=&4@8FQO8V\@;F$@<&]S:>?C
M;R!I;F1I8V%D82(*"B,Z(&QI8B](;W)D92]!=71H+VUC86PN<&AP.C4P"FUS
M9VED(").;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R(").XV\@9F]I(&9O<FYE8VED;R!U;2!N;VUE
M(&1E(&-A;&5N9.%R:6\@<&%R82!A(&%U=&5N=&EC8>?C;R!-0T%,+B(*"B,Z
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4T"FUS9VED(").;R!C:&%N9V4N(@IM
M<V=S='(@(E-E;2!M;V1I9FEC8>?U97,N(@H*(SH@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HQ-#`*;7-G:60@(DYO(&-H:6QD('!E<FUI<W-I;VYS(&%R92!T
M;R!B92!A9&1E9"!B96QO=R!T:&ES(&QE=F5L+B(*;7-G<W1R(").XV\@<V4@
M<&]D92!A9&EC:6]N87(@<&5R;6ES<_5E<R!D92!F:6QH;W,@86)A:7AO(&1E
M<W1E(&[M=F5L+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,0IM
M<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES
M<VEO;BXB"FUS9W-T<B`B3N-O('-E('!O9&4@861I8VEO;F%R(&9I;&AO<R!A
M(&5S=&$@<&5R;6ES<^-O+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,S<W
M"FUS9VED(").;R!C;VUM86YD('-P96-I9FEE9"XB"FUS9W-T<B`B3F5N:'5M
M(&-O;6%N9&\@97-P96-I9FEC861O+B(*"B,Z(&QI8B](;W)D92YP:'`Z,38W
M(&QI8B](;W)D92YP:'`Z-#<W(&QI8B](;W)D92]5=&EL+G!H<#HW-S8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R(").XV\@9F]I(&5S<&5C:69I
M8V%D82!A(&EN9F]R;6'GXV\@9&4@8V]N9FEG=7)AY^-O('!A<F$@)7,N(@H*
M(SH@;&EB+U9&4R]F='`N<&AP.C<T,0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N(@IM<V=S='(@
M(B(*(D[C;R!F;VD@97-P96-I9FEC861A(&$@:6YF;W)M8>?C;R!D92!C;VYF
M:6=U<F'GXV\@<&%R82!61E,@8F%S96%D;R!E;2!&5%`N(@H*(SH@;&EB+U9&
M4R]S<6PN<&AP.C4Y,0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S='(@(B(*(D[C;R!F
M;VD@97-P96-I9FEC861A(&$@:6YF;W)M8>?C;R!D92!C;VYF:6=U<F'GXV\@
M;F5C97-SX7)I82!P87)A(&\@5D93("(*(F)A<V5A9&\@96T@4U%,+B(*"B,Z
M(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<P-`IM<V=I9"`B3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB
M"FUS9W-T<B`B(@HB3N-O(&9O:2!E<W!E8VEF:6-A9&$@82!I;F9O<FUAY^-O
M(&1E(&-O;F9I9W5R8>?C;R!N96-E<W/A<FEA('!A<F$@;R!61E,@(@HB8F%S
M96%D;R!E;2!344PM1FEL92XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@
M(D-RZ61I=&\@97-G;W1O=2XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,T"FUS9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB
M"FUS9W-T<B`B3F5N:'5M(&1E<W1I;F%TX7)I;R!F;VD@9F]R;F5C:61O+B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,C<Q"B,L('!H<"UF;W)M870*;7-G
M:60@(DYO(&5N=')Y('=I=&@@=&AE(&ED(%PB)7-<(B!E>&ES=',@:6X@=&AE
M(&]R:6=I;F%L(&AE;'`@9FEL92XB"FUS9W-T<B`B(@HB3N-O(&5X:7-T92!Q
M=6%L<75E<B!E;G1R861A(&-O;2!O(&ED(%PB)7-<(B!N;R!A<G%U:79O(&1E
M(&%J=61A(&]R:6=I;F%L+B(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HX
M.#$*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B3N-O('-E(&-A
M<G)E9V]U(&YA9&$N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0Q,R!P;R]T
M<F%N<VQA=&EO;BYP:'`Z-3(R"FUS9VED(").;R!L;V-A;&4@<W!E8VEF:65D
M+B(*;7-G<W1R(").96YH=6UA(&QO8V%L:7IAY^-O(&5S<&5C:69I8V%D82XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$U(&QI8B]";&]C
M:R]S=6YR:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R,PIM
M<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R(")&86QT82!I;F1I
M8V%R('5M82!L;V-A;&EZ8>?C;RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,34V"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS
M9W-T<B`B02!L;V-A;&EZ8>?C;R!NXV\@9F]I(&5S<&5C:69I8V%D82XB"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").
M;R!M97-S86=E('-U<'!L:65D+B(*;7-G<W1R(").96YH=6UA(&UE;G-A9V5M
M(&9O:2!F;W)N96-I9&$N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S-@IM<V=I9"`B3F\@;F%M92!S<&5C:69I960N(@IM<V=S='(@
M(DYE;FAU;2!N;VUE(&5S<&5C:69I8V%D;RXB"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS9VED(").;R!N=6UB97(@<W!E8VEF
M:65D+B(*;7-G<W1R(").96YH=6T@;OIM97)O(&5S<&5C:69I8V%D;RXB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*;7-G:60@(DYO(&]F9F5N<VEV
M92!F;W)T=6YE<R(*;7-G<W1R(")396T@9&ET;W,@;V9E;G-I=F]S(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O:'1T<"YP:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").
MXV\@9F]I(&9O<FYE8VED82!P86QA=G)A+7!A<W-E('!A<F$@82!A=71E;G1I
M8V'GXV\@2%144"XB"@HC.B!L:6(O2&]R9&4O075T:"]I;6%P+G!H<#HQ,#@*
M;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R(").XV\@9F]I(&9O<FYE8VED82!P86QA=G)A+7!A
M<W-E('!A<F$@82!A=71E;G1I8V'GXV\@24U!4"XB"@HC.B!L:6(O2&]R9&4O
M075T:"]K<F(U+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").XV\@9F]I
M(&9O<FYE8VED82!P86QA=G)A+7!A<W-E('!A<F$@82!A=71E;G1I8V'GXV\@
M2V5R8F5R;W,N(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z.30*;7-G
M:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,1$%0(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R(").XV\@9F]I(&9O<FYE8VED82!P86QA=G)A+7!A<W-E
M('!A<F$@82!A=71E;G1I8V'GXV\@3$1!4"XB"@HC.B!L:6(O2&]R9&4O075T
M:"]S87-L+G!H<#HW-R!L:6(O2&]R9&4O075T:"]L;V=I;BYP:'`Z.#0*(SH@
M;&EB+TAO<F1E+T%U=&@O<&%M+G!H<#HW-0IM<V=I9"`B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").
MXV\@9F]I(&9O<FYE8VED82!P86QA=G)A+7!A<W-E('!A<F$@82!A=71E;G1I
M8V'GXV\@3&]G:6XN(@H*(SH@;&EB+TAO<F1E+T%U=&@O<&%S<W=D+G!H<#HQ
M,S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(D[C;R!F;VD@9F]R;F5C:61A('!A;&%V
M<F$M<&%S<V4@<&%R82!A(&%U=&5N=&EC8>?C;R!005-35T0N(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O<VUB+G!H<#HX-`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3N-O(&9O
M:2!F;W)N96-I9&$@<&%L879R82UP87-S92!P87)A(&$@875T96YT:6-AY^-O
M(%--0BXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R.#8*;7-G
M:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D
M+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O<FL@
M=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*(D[C;R!F;VD@:6YD:6-A
M9&\@8V%M:6YH;R!P87)A(&\@8FENX7)I;R!/<&5N4U-,+B!/(&)I;N%R:6\@
M3W!E;E-33"#I("(*(FYE8V5S<^%R:6\@<&%R82!T<F%B86QH87(@8V]M(&1A
M9&]S(%!+0U,@,3(N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V
M92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R(").
MXV\@:.$@<W5B<V-R:>?U97,@<&5N9&5N=&5S+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*;7-G:60@(DYO
M(')U;&5S(@IM<V=S='(@(E-E;2!T<F'G;W,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T"FUS9VED(").;R!S
M:61E<R(*;7-G<W1R(")396T@;&%D;W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,3(U"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T;W)Y
M(&%V86EL86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(D[C;R!HX2!P87-T82!T
M96UP;W+A<FEA(&1I<W!O;NUV96P@<&%R82!<(F-A8VAE7"(N(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,0IM<V=I9"`B3F\@=7-E
M<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(D[C;R!F;W)A
M;2!E;G9I861O<R!O(&YO;64@9&\@=71I;&EZ861O<B!O=2!A('!A;&%V<F$M
M<&%S<V4N(@H*(SH@;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I
M9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B3N-O(&9O
M<F%M(')E=&]R;F%D;W,@9&%D;W,@96T@6$U,(';A;&ED;W,B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DS(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HY,#,*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.CDQ-"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.3,Q"FUS9VED(").;R!V86QU97,B"FUS9W-T<B`B4V5M
M('9A;&]R97,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$Y"FUS9VED
M(").;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN
M(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB3N-O(&9O
M:2!E;F-O;G1R861A('9E<G/C;R!N82!C;VYF:6=U<F'GXV\@;W)I9VEN86PN
M(%)E9V5N97)A<B!C;VYF:6=U<F'GXV\N(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$R-PIM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O
M;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B3N-O(&9O:2!E;F-O;G1R861A('9E<G/C;R!N82!S=6$@8V]N9FEG=7)A
MY^-O+B!296=E;F5R87(@8V]N9FEG=7)AY^-O+B(*"B,Z(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C0Q-B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0U"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET
M>7-E;&5C="YI;F,Z.3(*;7-G:60@(DYO;F4B"FUS9W-T<B`B3F5N:'5M82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*
M;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B3F5N:'5M("AU
M<V%R(&EM<&SM8VET;RDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM
M<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T<B`B3O-R9&EC;R`H
M25-/+3@X-3DM,3`I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDV"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G<W1R
M("));&AA(&1E($YO<F9O;&LB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@
M;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS9VED(").;W)T:&5R;B!(96UI<W!H
M97)E(@IM<V=S='(@(DAE;6ES9NER:6\@3F]R=&4B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,34X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-CD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H
M97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R("));&AA<R!-87)I86YA<R!D
M;R!.;W)T92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S8@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM<V=S='(@(E)E:6YO(&1A($YO
M<G5E9V$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I
M9"`B3F]T($%F=&5R(@IM<V=S='(@(DYU;F-A($1E<&]I<R!D92(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(").;W0@0F5F;W)E
M(@IM<V=S='(@(DYU;F-A($%N=&5S(&1E(@H*(SH@;&EB+U9&4R]F:6QE+G!H
M<#HS,S$*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R(").XV\@Z2!U
M;2!D:7)E8W3S<FEO(@H*(SH@;&EB+U9&4R])4T]7<FET97(N<&AP.C8S(&QI
M8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#,*(SH@
M;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-`HC
M.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-#@*
M(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y
M"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@(D[C;R!I;7!L96UE
M;G1A9&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHV.`IM<V=I9"`B3F]T('-E="(*;7-G<W1R(")0;W(@871R:6)U:7(B
M"@HC.B!L:6(O5D93+G!H<#HQ-S4@;&EB+U9&4RYP:'`Z,3DS(&QI8B]61E,N
M<&AP.C(Q,"!L:6(O5D93+G!H<#HR,C8*(SH@;&EB+U9&4RYP:'`Z,C0R(&QI
M8B]61E,N<&AP.C(U-R!L:6(O5D93+G!H<#HR-S0@;&EB+U9&4RYP:'`Z,S`W
M"B,Z(&QI8B]61E,N<&AP.C,V-R!L:6(O5D93+G!H<#HT-#8@;&EB+U9&4RYP
M:'`Z-3$U(&QI8B]61E,N<&AP.C4S,@HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA
M;F1L97(N<&AP.C$T,R!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$U
M.`HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$W,R!L:6(O2&]R
M9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$X-PHC.B!L:6(O2&]R9&4O4V5S<VEO
M;DAA;F1L97(N<&AP.C(S-`IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T
M<B`B3N-O('-U<&]R=&%D;RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C(T-"!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,38T"FUS
M9VED(").;W1E<R(*;7-G<W1R(").;W1A<R(*"B,Z('-E<G9I8V5S+V]B<F]W
M<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O
M(&)A8VLN(@IM<V=S='(@(DYA9&$@<&%R82!N879E9V%R+"!V;VQT92!P87)A
M('1RX7,N(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?=&]P
M+FEN8SHQ,`IM<V=I9"`B3F]T:6-E(@IM<V=S='(@(DYO=&$B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@T(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,C$*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS
M9W-T<B`B3F]V96UB<F\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`T-@IM
M<V=I9"`B3G5M8F5R(@IM<V=S='(@(D[Z;65R;R(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ-#(W"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G
M<W1R(").^FUE<F\@9&4@8V%R86-T97)E<R(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,S<Q(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(U(&QI8B](;W)D92]&
M;W)M+G!H<#HQ-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R
M(").^FUE<F\@9&4@8V]L=6YA<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,S8Y(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(S(&QI8B](;W)D92]&;W)M+G!H
M<#HQ-#0U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`R"FUS9VED(").=6UB97(@;V8@<F]W<R(*;7-G<W1R(").^FUE<F\@
M9&4@;&EN:&%S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8T-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN
M9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@HB3F$@;&ES=&$@
M9&4@9&ES=')I8G5IY^-O(&CA(&[Z;65R;W,@<75E(&[C;R!F;W)A;2!E<W!E
M8VEF:6-A9&]S('!A<F$@(@HB86-T=6%L:7IAY^-O+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-"!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,30X"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,S0X"FUS9VED(")/
M2R(*;7-G<W1R(")/2R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HX,3$*;7-G:60@(D]B:F5C="(*;7-G<W1R(")/8FIE8W1O(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*;7-G:60@(D]B:F5C
M="!#<F5A=&]R(@IM<V=S='(@(D-R:6%D;W(@9&\@3V)J96-T;R(*"B,Z(&%D
M;6EN+W!E<FUS+V5D:70N<&AP.C$S-R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C(Q-0IM<V=I9"`B3V)J96-T(&-R96%T;W(@<&5R;6ES<VEO;G,B"FUS9W-T
M<B`B4&5R;6ES<_5E<R!D;R!C<FEA9&]R(&1O(&]B:F5C=&\B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3$P-`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B3V-T
M86PB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@S
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,C`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B
M3V-T;V)E<B(*;7-G<W1R(")/=71U8G)O(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R(")&:6QT
M<F\@9&4@;6%T97)I86P@;V9E;G-I=F\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S`Q"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B1V%B:6YE=&4B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-S$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3@*;7-G:60@(D]M86XB"FUS9W-T<B`B4W5L=&%N871O(&1O($]MXR(*"B,Z
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HW,PIM<V=I9"`B3VYL
M>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RXB"FUS9W-T
M<B`B4_,@;W,@<V5R=FED;W)E<R!)34%0('-U<&]R=&%M('!A<W1A<R!P87)T
M:6QH861A<RXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G:60@
M(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(D%P96YA<R!D:71O
M<R!O9F5N<VEV;W,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@U,B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3DW,@IM<V=I9"`B3VYL>2!O;F4@96UA:6P@861D
M<F5S<R!A;&QO=V5D+B(*;7-G<W1R(")3\R#I('!E<FUI=&ED;R!U;2!E;F1E
M<F7G;R!D92!C;W)R96EO(&5L96-T<O-N:6-O+B(*"B,Z('-E<G9I8V5S+W-H
M87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@
M<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@
M;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@HB
M07!E;F%S(&\@9&]N;R!O=2!U;2!A9&UI;FES=')A9&]R(&1E('-I<W1E;6%S
M('!O9&4@86QT97)A<B!A('1I='5L87)I9&%D92!D92`B"B)U;6$@<&%R=&EL
M:&$@;W4@87,@<&5R;6ES<_5E<R!D;R!S974@9&]N;R(*"B,Z(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C,U"FUS9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*
M;7-G<W1R(")!8G)E(&YU;6$@;F]V82!J86YE;&$B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-33"!E<G)O<CH@0V]U
M;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="XB
M"FUS9W-T<B`B(@HB17)R;R!/<&5N4U-,.B!.XV\@9F]I('!O<W/M=F5L(&5X
M=')A:7(@9&%D;W,@9&4@=6UA('!A<G1E(&%S<VEN861A(&-O;2!3+R(*(DU)
M344N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4T"FUS9VED(")/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@
M=VEN9&]W(@IM<V=S='(@(D%B<F4@97-T82!L:6=AY^-O(&YU;6$@;F]V82!J
M86YE;&$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*;7-G:60@(D]P
M97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B4VES=&5M82!/<&5R871I=F\B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I
M;VYS(@IM<V=S='(@(D]PY_5E<R(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HR
M.2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R(")/<.?U97,@9&\@)7,B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$R"FUS9VED(")/<'1I;VYS.B(*;7-G
M<W1R(")/<.?U97,Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(DQI
M<W1A($]R9&5N861A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M-C<*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R(")/<F=A;FEZ8>?C;R(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A
M;FES871I;VYA;"!5;FET(@IM<V=S='(@(E5N:61A9&4@3W)G86YI>F%C:6]N
M86PB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,R"FUS9VED(")/
M<F=A;FEZ:6YG(@IM<V=S='(@(D]R9V%N:7IAY^-O(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E
M;7!L871E(@IM<V=S='(@(DUO9&5L;R!O<FEG:6YA;"!D82!A<&QI8V'GXV\B
M"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(DUO9&5L
M;W,@;W)I9VEN86ES(&5M("5S.B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R
M(@IM<V=S='(@(D]U=')O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#8*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Q,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(R"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,S$*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N
M(@IM<V=S='(@(D]U=')A<R!);F9O<FUAY_5E<R(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM
M<V=S='(@(E!E<FUI<W/U97,@9&\@1&]N;R(*"B,Z(&QI8B](;W)D92]!=71H
M+W!A;2YP:'`Z-SD*;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@
M879A:6QA8FQE+B(*;7-G<W1R(")!=71E;G1I8V'GXV\@4$%-(&[C;R!E<W3A
M(&1I<W!O;NUV96PN(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3(U
M,PIM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S='(@(D%S<VEN
M871U<F$@1&EG:71A;"!01U`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HQ,CDY"FUS9VED(")01U`@16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B1&%D
M;W,@96YC<FEP=&%D;W,@4$=0(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z,3,U,0IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B0VAA=F4@
M4/IB;&EC82!01U`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,S,S
M"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(D1A
M9&]S($%S<VEN861O<R]%;F-R:7!T861O<R!C;VT@4$=0(@H*(SH@861M:6XO
M<&AP<VAE;&PN<&AP.C8X"FUS9VED(")02%`@0V]D92(*;7-G<W1R(")#\V1I
M9V\@4$A0(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@
M4VAE;&PB"FUS9W-T<B`B0V]M86YD;W,@4$A0(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*;7-G:60@(E!-($QI9VAT(%)A
M:6XB"FUS9W-T<B`B0VAU=FES8V]S('!E;&$@5&%R9&4B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.`IM<V=I9"`B4$T@4VAO
M=V5R<R(*;7-G<W1R(")!9W5A8V5I<F]S(&1E(%1A<F1E(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%-N
M;W<B"FUS9W-T<B`B3F5V92#@(%1A<F1E(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#`*;7-G:60@(E!-(%-N;W<@4VAO=V5R
M<R(*;7-G<W1R(").97;U97,@X"!487)D92(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"FUS9VED(")032!3=6XB"FUS9W-T
M<B`B4V]L(.`@5&%R9&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T<B`B5&5M
M<&]R86ES+50@X"!487)D92(*"B,Z(&QI8B]A<&DN<&AP.C$R.`IM<V=I9"`B
M4%](4"!3:&5L;"(*;7-G<W1R(")#;VUA;F1O<R!07TA0(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I
M9"`B4&%D9&EN9R(*;7-G<W1R(")%;F-H:6UE;G1O(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$X-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY"FUS9VED(")086MI
M<W1A;B(*;7-G<W1R(")297#Z8FQI8V$@27-LXFUI8V$@9&\@4&%Q=6ES=.-O
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P,0IM<V=I9"`B4&%L874B"FUS9W-T<B`B4F5P^F)L:6-A(&1E(%!A;&%U
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(*
M;7-G<W1R(")497)R:73S<FEO(%!A;&5S=&EN:6%N;R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ.#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$W-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&%N
M86UA(@IM<V=S='(@(E!A;F%MX2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ.#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE
M82(*;7-G<W1R(")087!U82!.;W9A($=U:6[I(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$Y-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4&%R86=U
M87DB"FUS9W-T<B`B4F5P^F)L:6-A(&1O(%!A<F%G=6%I(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S8*;7-G:60@(E!A<G1L
M>2!#;&]U9'DB"FUS9W-T<B`B4&%R8VEA;&UE;G1E($5N8V]B97)T;R(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#,@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(P,3D*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4S-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C$Y.0HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<S('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S8*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,V,@IM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`B4&%L
M879R82U087-S92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3,R
M,@IM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(E!A;&%V<F$M
M4&%S<V4@:6YC;W)R96-T82(*"B,Z(&QI8B](;W)D92]!=71H+W)A9&EU<RYP
M:'`Z,34R"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")086QA=G)A+5!A<W-E(&YE8V5S<^%R
M:6$@<&%R82!A=71E;G1I8V'GXV\@4D%$2553(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(P-30*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N
M(@IM<V=S='(@(E!A;&%V<F$M4&%S<V4@8V]M(&-O;F9I<FUAY^-O(@H*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP"FUS9VED(")087-S=V]R
M9#HB"FUS9W-T<B`B4&%L879R82U087-S93HB"@HC.B!T96UP;&%T97,O;&]G
M:6XO;6]B:6QE+FEN8SHQ,0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R(")0
M86QA=G)A+5!A<W-E.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3`@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(P,S4*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S
M='(@(D%S('!A;&%V<F%S+7!A<W-E('3J;2!D92!S97(@:6=U86ES+B(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T92(*;7-G
M<W1R(")#;VQA<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S
M='(@(D-O;&%R(&1E(')E8V]R=&5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R(")#
M86UI;FAO(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z
M,B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C0*;7-G
M:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`B4W5B<V-R:>?U97,@4&5N
M9&5N=&5S.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-`IM<V=I9"`B
M4&5O<&QE(@IM<V=S='(@(E!E<W-O87,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G
M<W1R(")097)C96YT86=E;2(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C
M;VYF:7)M7V)O='1O;2YI;F,Z-@IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC
M92!/<&5R871I;VYS(@IM<V=S='(@(D5X96-U=&%R($]P97)AY_5E<R!D92!-
M86YU=&5NY^-O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y.`IM<V=I
M9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*
M;7-G<W1R(")%>&5C=71A<B!O<&5R8>?U97,@9&4@;6%N=71E;N?C;R!A<75A
M;F1O(&1A(&5N=')A9&$_(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP
M.C8Q(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV-`HC.B!A9&UI;B]P97)M
M<R]A9&1C:&EL9"YP:'`Z-C<*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B
M4&5R;6ES<^-O(@H*(R!C+69O<FUA=`HC.B!A9&UI;B]P97)M<R]D96QE=&4N
M<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB
M(&YO="!D96QE=&5D+B(*;7-G<W1R(")!('!E<FUI<W/C;R!<(B5S7"(@;N-O
M(&9O:2!R96UO=FED82XB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HR,C0@
M861M:6XO<&5R;7,O861D8VAI;&0N<&AP.CDS"B,Z(&%D;6EN+W!E<FUS+VEN
M9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C<T"FUS9VED(")0
M97)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')A
MY^-O(&1E(%!E<FUI<W/U97,B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C$T-2!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$T.`HC.B!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.C$U,@IM<V=I9"`B4&5R;6ES<VEO;G,@9F]R(@IM<V=S
M='(@(E!E<FUI<W/U97,@9&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-C4*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R
M;6'G]65S(%!E<W-O86ES(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDX"FUS9VED(")097)U(@IM<V=S='(@(E!E<OHB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G:60@(E!E=',B"FUS
M9W-T<B`B06YI;6%I<R!D92!%<W1I;6'GXV\B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3@V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-SD*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!H:6QI<'!I
M;F5S(@IM<V=S='(@(D9I;&EP:6YA<R(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G<W1R(")496QE
M9F]N92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C4*;7-G:60@
M(E!H;W1O<R(*;7-G<W1R(")&;W1O9W)A9FEA<R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ.3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X
M,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A
M:7)N(@IM<V=S='(@(DEL:&%S(%!I=&-A:7)N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*
M;7-G<W1R(")0[7AE:7,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*
M;7-G:60@(E!L871I='5D97,B"FUS9W-T<B`B4&QA=&ET=61E<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*
M;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R(")0
M;W(@9F%V;W(@8VQI<75E('-O8G)E('5M82!CZ6QU;&$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#@*;7-G
M:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H
M:7,@96QE;65N=#HB"FUS9W-T<B`B4&]R(&9A=F]R(&-O;F9I<FUE('-E(')E
M86QM96YT92!P<F5T96YD92!R96UO=F5R(&5S=&4@96QE;65N=&\Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4U"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N
M;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(E!O<B!F879O<B!C;VYF:7)M
M92!S92!R96%L;65N=&4@<')E=&5N9&4@9&5S;&EG87(@97-T92!E;&5M96YT
M;RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4W,`IM<V=I9"`B4&QE87-E
M(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T<B`B4&]R(&9A=F]R
M(&EN=')O9'5Z82!U;2!MZG,@92!U;2!A;F\N(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G:60@(E!L96%S92!E
M;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@(E!O
M<B!F879O<B!I;G1R;V1U>F$@;R!N;VUE(&1A(&YO=F$@8V%T96=O<FEA.B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S`Q"FUS9VED(")0;&5A<V4@96YT
M97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R(")0;W(@9F%V;W(@:6YT
M<F]D=7IA('5M(&5N9&5R9>=O($E0(';A;&ED;RXB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C8U.0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T
M92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS
M9W-T<B`B(@HB4&]R(&9A=F]R(&EN=')O9'5Z82!U;6$@9&%T82!VX6QI9&$[
M('9E<FEF:7%U92!O(&[Z;65R;R!D92!D:6%S(&1O(&WJ<RXB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C0U,`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L
M:60@=&EM92XB"FUS9W-T<B`B4&]R(&9A=F]R(&EN=')O9'5Z82!U;6$@:&]R
M82!VX6QI9&$N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B
M;&5M+B(*;7-G<W1R(")0;W(@9F%V;W(L(&9O<FYEYV$@=6UA(&)R979E(&1E
M<V-R:>?C;R!D;R!P<F]B;&5M82XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C$X('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(*;7-G:60@
M(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM
M<V=S='(@(E!O<B!F879O<BP@:6YT<F]D=7IA(&\@<V5U($YO;64@9&4@571I
M;&EZ861O<B!E(&$@<W5A(%!A;&%V<F$M4&%S<V4B"@HC.B!T96UP;&%T97,O
M;6%I;G1E;F%N8V4O86=R965M96YT7W1O<"YI;F,Z,3(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B`@
M66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S
M>7-T96TN(@IM<V=S='(@(B(*(E!O<B!F879O<B!L96EA(&\@=&5X=&\@<V5G
M=6EN=&4N(%1E;2!D92!#3TY#3U)$05(@8V]M(&]S('1E<FUO<R!D97-T92!A
M8V]R9&\@(@HB<&%R82!U<V%R(&\@<VES=&5M82XB"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z,3<*;7-G:60@(E!L96%S92!R97!O<G0@86YY(&)U9W,@=&\@
M:3$X;D!L:7-T<RYH;W)D92YO<F<N(@IM<V=S='(@(E!O<B!F879O<B!R97!O
M<G1E(&]S(&5R<F]S('!A<F$@:3$X;D!L:7-T<RYH;W)D92YO<F<B"@HC.B!L
M:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0IM<V=I9"`B
M4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R(")0
M;W(@9F%V;W(@:6YT<F]D=7IA(&\@;F]M92!D82!N;W9A(&-A=&5G;W)I83HB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ.#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3D*;7-G:60@(E!O;&%N9"(*;7-G<W1R(")0;VSS;FEA(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R(")0
M;VSM=&EC82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S0*;7-G
M:60@(E!O;&QS(@IM<V=S='(@(E-O;F1A9V5N<R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ.3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X
M,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!O<G1U
M9V%L(@IM<V=S='(@(E)E</IB;&EC82!0;W)T=6=U97-A(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W
M"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(E!O
M<VEC:6]N86UE;G1O(&1E<W1A(&EM86=E;2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN
M9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(E!O<VEC:6]N86UE;G1O(&1E<W1A
M('1A8F5L82(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M,0IM<V=I9"`B4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y
M($E-05`I(@IM<V=S='(@(EPB4&]S=%PB('!A<F$@97-T82!P87-T82`H;N-O
M(.D@<F5Q=6ES:71O(&1O($E-05`I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS
M9W-T<B`B4')E8VEP:71AY^-O(&YA<R#Z;'1I;6%S("5S(&AO<F$H<RDZ("(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#8*;7-G:60@(E!R
M96-I<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B4')O8F%B:6QI9&%D
M92!D93QB<B`O/E!R96-I<&ET8>?C;R(*"B,Z(&QI8B](;W)D92]0<F5F<R]L
M9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]L9&%P.B!!(&5X
M=&5N<^-O($Q$05`@;F5C97-SX7)I82!NXV\@9F]I(&5N8V]N=')A9&$N(@H*
M(SH@;&EB+TAO<F1E+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F
M<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(E!R969S7W-E<W-I;VXZ($$@97AT96YSXV\@9&4@<V5S
M<^-O(&YE8V5S<^%R:6$@;N-O(&9O:2!E;F-O;G1R861A+B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C(U"FUS9VED(")0<F5S<W5R92(*;7-G<W1R(")0
M<F5S<^-O(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3D*;7-G:60@(E!R
M97-S=7)E(&%T('-E82!L979E;#H@(@IM<V=S='(@(E!R97-SXV\@86\@;NUV
M96P@9&\@;6%R.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C(S"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@(E!R97-SXV\Z("(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ.#@*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@(E!R979I<^-O(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(T"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B
M"FUS9W-T<B`B4')E=F5R(&$@:6UA9V5M(&YU;6$@;F]V82!J86YE;&$B"@HC
M.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,V,"!L:6(O2&]R9&4O4')E9G,O
M54DN<&AP.C,V-`IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R(")/
M<.?U97,@86YT97)I;W)E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S
M='(@(DEM<')I;6ER(&\@9&]C=6UE;G1O(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z-#$R"FUS9VED(")0<FEV871E($ME>2(*;7-G<W1R(")#:&%V
M92!0<FEV861A(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$V.0IM<V=I9"`B
M4')O8FQE;2(*;7-G<W1R(")0<F]B;&5M82(*"B,Z('-E<G9I8V5S+W!R;V)L
M96TN<&AP.C$R-PIM<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R
M(")$97-C<FGGXV\@9&\@4')O8FQE;6$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C$S"FUS9VED(")0<F]J96-T<R(*;7-G<W1R(")0<F]J96-T
M;W,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Q,B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C$X.0IM<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`B365N<V%G
M96TM<')O;G1O(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$R"FUS
M9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(D-H879E(%#Z8FQI8V$B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME
M>2!!;&=O<FET:&TB"FUS9W-T<B`B06QG;W)I=&UO(&1E($-H879E(%#Z8FQI
M8V$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T-`IM<V=I9"`B
M4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(DEN9F]R;6'GXV\@4V]B<F4@82!#
M:&%V92(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C(S,`IM<V=I9"`B
M4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F
M=6QL>2XB"FUS9W-T<B`B3R!P87(@9&4@8VAA=F5S(%!U8FQI8V$O4')I=F%D
M82!NXV\@9F]I(&=E<F%D82!C;VT@<W5C97-S;RXB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3DQ(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M.#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0=65R
M=&\@4FEC;R(*;7-G<W1R(")0;W)T;R!2:6-O(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$Y-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B46%T87(B
M"FUS9W-T<B`B17-T861O(&1O(%%A=&%R(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C8R"FUS9VED(")1=65R>2(*;7-G<W1R(")0961I9&\B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8V,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")24T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G<W1R(")#:&%V92!0^F)L
M:6-A(%)302`H)60@8FET*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C8U
M"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`B4V5L96/GXV\@7")R
MX61I;UPB(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#,*;7-G:60@(E)A:6XB"FUS9W-T<B`B0VAU=F$B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4F%I;B!%
M87)L>2(*;7-G<W1R(")#:'5V82!-871I;F%L(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6X@3&%T92(*
M;7-G<W1R(")#:'5V82!697-P97)T:6YA(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E)A:6X@4VAO=V5R(@IM
M<V=S='(@(D%G=6%C96ER;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")286EN(&%N9"!3;F]W(@IM<V=S='(@
M(D-H=79A(&4@3F5V92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0X"FUS9VED(")286EN('1O(%-N;W<B"FUS9W-T<B`B0VAU
M=F$@82!.979E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@
M(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@(D1I=&\@06QE873S<FEO(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO(@IM<V=S='(@(E)E
M;&'GXV\B"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(Y,R!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C,T"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-C@@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,0HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Q-"!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$S-PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,`IM<V=I
M9"`B4F5A9"(*;7-G<W1R("),97(B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.#<*;7-G:60@(E)E860@;65S<V%G97,B"FUS9W-T<B`B
M3&5R(&UE;G-A9V5N<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M92YI;F,Z,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E
M<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B
M475E<B!M97-M;R!R96UO=F5R("5S/R!%<W1A(&]P97)AY^-O(&[C;R!T96T@
M<F5G<F5S<V\N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC
M.C$R"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D
M871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD
M;VYE+B(*;7-G<W1R("(B"B)296UO=F5R(&UE<VUO(&]S(&1A9&]S(&1O('5T
M:6QI>F%D;W(@)7,_($5S=&$@;W!E<F'GXV\@;N-O('1E;2!R96=R97-S;RXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T
M"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R(")2969A
M>B!A('-U82#Z;'1I;6$@86/GXV\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S@S"FUS9VED(")2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB
M"FUS9W-T<B`B4F5F<F5S8V%R($5L96UE;G1O<R!D92!-96YU($1I;N)M:6-O
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S,*;7-G:60@(E)E9G)E
M<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(E)E9G)E<V-A<B!6:7-U86QI>F'G
MXV\@9&\@4&]R=&%L.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX.30@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$R,3,@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,S4*
M;7-G:60@(E)E9V5X(@IM<V=S='(@(D5X<')E<W/C;R!296=U;&%R(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C,R-#@*;7-G:60@(E)E;&%T:6]N<VAI<"!"
M<F]W<V5R(@IM<V=S='(@(DYA=F5G861O<B!D92!296QAY_5E<R(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S(V"FUS9VED(")296UA<FMS(@IM<V=S='(@
M(D]B<V5R=F'G]65S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-`IM
M<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B4V5R=FED;W)E<R!296UO
M=&]S(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED
M(")296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB
M"FUS9W-T<B`B55),(%)E;6]T;R`H:'1T<#HO+W=W=RYE>&5M<&QO+G!T+VAO
M<F1E*3HB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q
M('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,34*;7-G:60@(E)E
M;6]V92(*;7-G<W1R(")296UO=F5R(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L
M87EO=70N:6YC.C$Q"FUS9VED(")296UO=F4@0FQO8VLB"FUS9W-T<B`B4F5M
M;W9E<B!";&]C;R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HU,CD*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B4F5M;W9E
M<B!C;VQU;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C0P"FUS9VED(")296UO=F4@9F]R;6%T=&EN9R(*;7-G<W1R(")2
M96UO=F5R(&9O<FUA=&'GXV\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C$S-@IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`B4F5M;W9E<B!P
M87(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`U"FUS9VED(")296UO
M=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B4F5M;W9E<B!O(%PB<V-R:7!T7"(@9W5A<F1A9&\@
M9&$@<&%S=&$@=&5M<&]RX7)I82!D;R!S97)V:61O<BXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G
M:60@(E)E;6]V92!T:&4B"FUS9W-T<B`B4F5M;W9E<B!O(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS
M9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S
M='(@(E)E;6]V97(@97-T92!N\R!D;R!D;V-U;65N=&\B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$V"FUS9VED(")296UO=F4@=7-E
M<B(*;7-G<W1R(")296UO=F5R(%5T:6QI>F%D;W(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]R96UO=F4N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(E)E;6]V97(@=71I;&EZ861O<CH@
M)7,B"@HC.B!L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED(")2
M97%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O
M9&4Z("(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(')E<W!O;F1E<B!A;R!P
M961I9&\N($/S9&EG;R!D92!E<G)O(&1E=F]L=FED;SH@(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$T-`IM<V=I9"`B4F5Q=65S=&5D('-E
M<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*;7-G<W1R(")/('-E<G9IYV\@
M<&5D:61O(&[C;R!F;VD@96YC;VYT<F%D82XB"@HC.B!L:6(O2&]R9&4N<&AP
M.C$W-"!L:6(O2&]R9&4N<&AP.C0X-PHC+"!P:'`M9F]R;6%T"FUS9VED(")2
M97%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R(")<(B5S7"(@;V)R:6=A=/-R:6\@;N-O(&9O:2!E<W!E
M8VEF:6-A9&\@;F$@8V]N9FEG=7)AY^-O(&1E("5S+B(*"B,Z(&QI8B]61E,O
M<W%L+G!H<#HU.3<@;&EB+U9&4R]F='`N<&AP.C<T-R!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HW,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E
M<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(EPB)7-<(B!O8G)I9V%T\W)I;R!NXV\@9F]I(&5S<&5C:69I8V%D;R!N
M82!C;VYF:6=U<F'GXV\@5D93+B(*"B,Z(&QI8B](;W)D92]5=&EL+G!H<#HW
M.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S
M<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B7"(E<UPB(&]B
M<FEG873S<FEO(&[C;R!F;VD@97-P96-I9FEC861O(&YA(&-O;F9I9W5R8>?C
M;RXB"@HC.B!L:6(O2&]R9&4O1F]R;2]296YD97)E<BYP:'`Z,S(X"FUS9VED
M(")297%U:7)E9"!&:65L9"(*;7-G<W1R(")#86UP;R!/8G)I9V%T\W)I;R(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C,Q(&QI8B](;W)D92]&;W)M+G!H<#HS,SD@
M;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,Q-0HC.B!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z-#0*;7-G:60@(E)E<V5T(@IM<V=S='(@(DQI;7!A<B(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"FUS9VED(")297-E="!0
M87-S=V]R9"(*;7-G<W1R(")296EN:6-I87(@4&%L879R82U087-S92(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W"FUS9VED(")297-E="!9
M;W5R(%!A<W-W;W)D(@IM<V=S='(@(E)E:6YI8VEE(&$@4W5A(%!A;&%V<F$M
M4&%S<V4B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S$@861M:6XO8VUD<VAE
M;&PN<&AP.C(X(&%D;6EN+W-Q;'-H96QL+G!H<#HV-0IM<V=I9"`B4F5S=6QT
M<R(*;7-G<W1R(")297-U;'1A9&]S(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C@R,0IM<V=I9"`B4F5S=6QT<R`H:6YC;'5D:6YG($AO<F1E*3HB"FUS9W-T
M<B`B4F5S=6QT861O<R`H:6YC;'5I;F1O($AO<F1E*3HB"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z.#$Y"FUS9VED(")297-U;'1S.B(*;7-G<W1R(")297-U
M;'1A9&]S.B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#(@
M=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P
M=&EO;G,B"FUS9W-T<B`B5F]L=&%R(.!S($]PY_5E<R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ.3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$X-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)E
M=6YI;VXB"FUS9W-T<B`B4F5U;FGC;R(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V
M97)T($-O;F9I9W5R871I;VXB"FUS9W-T<B`B4D5V97)T97(@0V]N9FEG=7)A
MY^-O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,@IM<V=I9"`B4FEC
M:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S='(@(D]PY_5E<R!D92!%9&GG
MXV\@4FEC82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B
M4FED9&QE<R(*;7-G<W1R(")!9&EV:6YH87,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*;7-G:60@(E)I9VAT
M(@IM<V=S='(@(D1I<F5I=&$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$R
M,`IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(D-A8F7G86QH;R!D82!D
M:7)E:71A(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,38*;7-G:60@(E)I
M9VAT('9A;'5E<R(*;7-G<W1R(")686QO<F5S(.`@9&ER96ET82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M.`IM<V=I9"`B4F]?=R!0<F]P97)T:65S+BXN(@IM<V=S='(@(E!R;W!R:65D
M861E<R!D82!,:6Y?:&$N+BXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R(")296=R82(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3@@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$X-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*
M;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`B4F]MZ6YI82(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HR,#@*;7-G:60@(E)O=&%T92`Q
M.#`B"FUS9W-T<B`B4F]D87(@,3@P(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(P-0IM<V=I9"`B4F]T871E($QE9G0B"FUS9W-T
M<B`B4F]D87(@X"!%<W%U97)D82(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,3$*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R
M(")2;V1A<B#@(&1I<F5I=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE
M<R(*;7-G<W1R(")0<F]P<FEE9&%D97,@9&$@3&EN:&$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS9VED
M(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R(")0<F]P<FEE9&%D97,@9&$@;&EN
M:&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P,0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`B3&EN:&%S.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G
M:60@(E)U;&5S(@IM<V=S='(@(E1R8>=O<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS
M9W-T<B`B5')AYV]S(&%P87)E8V5RXV\@96YT<F4@=&]D87,@87,@;&EN:&%S
M(&4@8V]L=6YA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E
M='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(E1R8>=O<R!A<&%R96-E<N-O
M(&%P96YA<R!E;G1R92!A<R!C;VQU;F%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B4G5L97,@
M=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`B5')AYV]S
M(&%P87)E8V5RXV\@87!E;F%S(&5N=')E(&QI;FAA<R(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,C$*;7-G:60@(E)U;B(*;7-G<W1R(")%>&5C=71A<B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3D@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$X-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#,*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R(")&961E<F'G
MXV\@4G5S<V$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`S"FUS9VED(")2=V%N9&$B"FUS9W-T<B`B4F5P^F)L:6-A
M(&1O(%)U86YD82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C@U
M"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T
M<B`B07-S:6YA='5R82!#<FEP=&]G<N%F:6-A(%,O34E-12(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z,S(S"FUS9VED(")3+TU)344@16YC<GEP
M=&5D($UE<W-A9V4B"FUS9W-T<B`B365N<V%G96T@16YC<FEP=&%D82!C;VT@
M4R]-24U%(@H*(SH@;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'`Z.#$*;7-G:60@
M(E-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T
M<B`B075T96YT:6-AY^-O(%-!4TP@:6YD:7-P;V[M=F5L+B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT-3D*;7-G:60@(E--4R!-97-S86=I;F<B
M"FUS9W-T<B`B365N<V%G96YS(%--4R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(D-O;6%N9&]S(%-13"(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S`*;7-G:60@(E-32"(*
M;7-G<W1R(")34T@B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-50T-%4U,B"FUS9W-T<B`B4U5#
M15-33R(*"B,Z(&QI8B]A<&DN<&AP.C$S,@IM<V=I9"`B4U]13"!3:&5L;"(*
M;7-G<W1R(")#;VUA;F1O<R!37U%,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`B<^$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`W(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ.#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`T"FUS9VED(")386EN="!(96QE;F$B"FUS9W-T<B`B4V%N=&$@2&5L96YA
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@T"FUS9VED(")386EN="!+:71T<R!A;F0@3F5V:7,B"FUS9W-T<B`B4^-O
M($MI='1S(&4@3F5V:7,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,Y
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S='(@
M(E-A;G1A($SZ8VEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X.2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U
M96QO;B(*;7-G<W1R(")3XV\@4&5D<F\@92!-:7%U96QO;B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR-#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$Y,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@
M(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM<V=S='(@(E/C
M;R!6:6-E;G1E(&4@1W)E;F%D:6YE<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@*%]S
M96QF*2(*;7-G<W1R(")-97-M82!M;VQD=7)A("A?<V5L9BDB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C4Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ.30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED
M(")386UO82(*;7-G<W1R(")%<W1A9&\@26YD97!E;F1E;G1E(&1A(%-A;6]A
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P-@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R(")297#Z8FQI8V$@4V5R
M96[M<W-I;6$@9&4@4^-O($UA<FEN;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N
M9"!0<FEN8VEP92(*;7-G<W1R(")3XV\@5&]MZ2!E(%!R[6YC:7!E(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3871E;&QI=&4@
M4')O=FED97(B"FUS9W-T<B`B1F]R;F5C961O<B!D;R!3873I;&ET92(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#$@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$Y-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*
M;7-G:60@(E-A=61I($%R86)I82(*;7-G<W1R(")!<N%B:6$@4V%U9&ET82(*
M"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY.`IM<V=I9"`B4V%V
M92(*;7-G<W1R(")'=6%R9&%R(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHR,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R
M(")'=6%R9&%R("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E("<E<R<B"FUS9W-T
M<B`B1W5A<F1A<B`G)7,G(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z
M-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@(D=U87)D87(@3W#G]65S
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W,`IM<V=I9"`B(@HB4V%V
M92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@
M>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R
M("(B"B)'=6%R9&%R(&-O;F9I9W5R8>?C;R!G97)A9&$@8V]M;R!U;2!<(G-C
M<FEP=%PB(%!(4"!N;R!D:7)E8W3S<FEO('1E;7!O<N%R:6\@(@HB9&\@<V5U
M('-E<G9I9&]R+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C8Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(D=U87)D96D@8V]N9FEG=7)AY^-O("5S+B(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.CDP"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D
M('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(D=U
M87)D96D@;R!<(G-C<FEP=%PB(&1E(&%C='5A;&EZ8>?C;R!E;3H@7"(E<UPB
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y
M"FUS9VED(")38V%T=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B5&5M<&]R86ES
M+50@1&ES<&5R<V]S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS
M9VED(")38VEE;F-E(@IM<V=S='(@(D-IZFYC:6$B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E<B]L
M:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(E!R;V-U<F%R(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W.`IM<V=I9"`B4V5A<F-H
M($5N9VEN97,B"FUS9W-T<B`B36]T;W)E<R!D92!0<F]C=7)A(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C$T-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V5A
M<F-H:6YG($AO<F1E(&%P<&QI8V%T:6]N<R!I;B`E<R(*;7-G<W1R(")0<F]C
M=7)A;F1O(&%P;&EC8>?U97,@*&WS9'5L;W,I($AO<F1E(&5M("5S(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C$R,PIM<V=I9"`B4V5A<F-H:6YG(&=E='1E
M>'0@8FEN87)I97,N+BXB"FUS9W-T<B`B4')O8W5R86YD;R!O<R!B:6[A<FEO
M<R!D92!G971T97AT+BXN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y-S(*
M;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R(")396QE8V-I;VYA<B!!<G%U
M:79O<R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-38*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B4V5L96-C:6]N92!U
M;6$@9&%T82(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX"FUS
M9VED(")396QE8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B4V5L96-C:6]N
M92!U;2!G<G5P;R!A(&%C<F5S8V5N=&%R(@H*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S
M='(@(E-E;&5C8VEO;F%R('5M(&YO=F\@9&]N;R(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM
M<V=S='(@(E-E;&5C8VEO;F4@=6T@<V5R=FED;W(B"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$U-@IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A
M9&0B"FUS9W-T<B`B4V5L96-C:6]N92!U;2!U=&EL:7IA9&]R(&$@861I8VEO
M;F%R(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(V-C(*;7-G:60@(E-E;&5C
M="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R(")396QE8V-I;VYE('1O
M9&]S(&]S(&-O;7!O;F5N=&5S(&1A(&1A=&$N(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Q,0IM<V=I9"`B4V5L96-T(&%N(&]B
M:F5C="(*;7-G<W1R(")396QE8V-I;VYE('5M(&]B:F5C=&\B"@HC.B!S97)V
M:6-E<R]K97EB;V%R9"YP:'`Z,S<*;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA
M<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A
M;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A
M<F5A+B(*;7-G<W1R("(B"B)396QE8V-I;VYE(&]S(&-A<F%C=&5R97,@;F%S
M(&-A:7AA<R!A8F%I>&\N(%!O9&5RX2!E;G3C;R!C;W!IX2UL;W,@92!C;VSA
M+2(*(FQO<R!N82#A<F5A(&1E('1E>'1O+B(*"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C,T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R
M.B(*;7-G<W1R(")396QE8V-I;VYE(&\@9&5L:6UI=&%D;W(@9&$@9&%T83HB
M"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-`IM<V=I9"`B4V5L96-T
M('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`B4V5L96-C:6]N92!O(&9O<FUA
M=&\@9&$@9&%T83HB"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE
M8W0N:6YC.C@Y"FUS9VED(")396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT
M('1O(&-H86YG93HB"FUS9W-T<B`B4V5L96-C:6]N92!A(&ED96YT:61A9&4@
M<75E('!R971E;F1E(&%L=&5R87(Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM
M92YI;F,Z,38*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM
M<V=S='(@(E-E;&5C8VEO;F4@;R!D96QI;6ET861O<B!D87,@:&]R87,Z(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T
M:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(E-E;&5C8VEO;F4@;R!F;W)M871O
M(&1A(&AO<F$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV-`IM
M<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N(@IM<V=S='(@(E-E
M;&5C8VEO;F4@9&]I<R!C86UP;W,@<F5L86-I;VYA9&]S+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR.3@*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R
M('-C:&5M92XB"FUS9W-T<B`B17-C;VQH82!O('-E=2!C;VYJ=6YT;R!D92!C
M;W)E<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0P"FUS9VED(")3
M96QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(E-E;&5C
M8VEO;F4@;R!S974@:61I;VUA('!R969E<FED;SHB"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E
M<&]R="(*;7-G<W1R(")%;G9I87(@4F5L873S<FEO(&1E(%!R;V)L96UA<R(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY-C$*;7-G
M:60@(E-E;F0@4TU3(@IM<V=S='(@(D5N=FEA<B!335,B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C$S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.3@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3
M96YE9V%L(@IM<V=S='(@(E)E</IB;&EC82!D;R!396YE9V%L(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,38*;7-G:60@(E-E;G-O<CH@(@IM<V=S='(@
M(B!396YS;W(Z("(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HS.#(@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S
M"FUS9VED(")397!T96UB97(B"FUS9W-T<B`B4V5T96UB<F\B"@HC.B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD
M($UO;G1E;F5G<F\B"FUS9W-T<B`B4^ER=FEA(&4@36]N=&5N96=R;R(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`Q"FUS9VED(")397)I86P@
M3G5M8F5R(@IM<V=S='(@(D[Z;65R;R!D92!3Z7)I92(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#@*;7-G:60@(E-E<G9E<B!D871A('=R
M;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D1A9&]S(&1O('-E<G9I
M9&]R(&5R<F%D;W,@;W4@:6YD:7-P;V[M=F5I<RXB"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E
M>'!I<F5D+B(*;7-G<W1R("))1"!D92!S97-SXV\@97AP:7)O=2XB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C,Q,PIM<V=I9"`B4V5T(@IM<V=S='(@(D%T
M<FEB=6ER(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<V"FUS9VED(")3
M970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R
M9"!I9B!Y;W4@979E<B!F;W)G970@:70N(@IM<V=S='(@(B(*(D5S=&%B96QE
MYV$@;W#G]65S('%U92!L:&4@<&5R;6ET86T@<F5I;FEC:6%R(&$@<W5A('!A
M;&%V<F$M<&%S<V4@<V4@86QG=6UA("(*(G9E>B!D96QA('-E(&5S<75E8V5R
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*;7-G:60@(E-E="!U
M<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M
M('EO=7(@<&]R=&%L+B(*;7-G<W1R(")%<W!E8VEF:6-A<B!S97)V:61O<F5S
M(')E;6]T;W,@<75E(&1E<V5J82!A8V5D97(@;F\@<V5U('!O<G1A;"XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0*;7-G:60@(E-E="!Y;W5R('!R
M969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB
M"FUS9W-T<B`B(@HB4V5L96-C:6]N92!O('-E=2!I9&EO;6$@<')E9F5R:61O
M+"!O('-E=2!F=7-O(&AO<N%R:6\@92!A<R!S=6%S(&]PY_5E<R!D92`B"B)D
M871A<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*;7-G:60@(B(*
M(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@
M<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS
M+B(*;7-G<W1R("(B"B)%<V-O;&AA(&$@<W5A(&%P;&EC8>?C;R!I;FEC:6%L
M+"!O(&5S<75E;6$@9&4@8V]R97,L(&\@<F5F<F5S8V%M96YT;R!D92`B"B)P
MX6=I;F%S(&4@;W5T<F%S(&]PY_5E<R!D92!V:7-U86QI>F'GXV\N(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-`IM<V=I9"`B4V5T=7`B"FUS9W-T
M<B`B0V]N9FEG=7)A<B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E
M>"YH=&UL.C,Y"FUS9VED(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA
M8FQE(@IM<V=S='(@(EPB4V-R:7!T<UPB(&1E(&%C='5A;&EZ8>?C;R!D:7-P
M;V[M=F5I<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S0*
M;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A
M<F%M971E<CH@(@IM<V=S='(@(E;A<FEA<R!L;V-A;&EZ8>?U97,@<&]S<^UV
M96ES(&-O;2!O('!A<N)M971R;SH@(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(P,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V5Y8VAE;&QE<R(*
M;7-G<W1R(")396EC:&5L97,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#4Q"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R(")#;VUP<F%S(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@(E-H;W)T
M(%-U;6UA<GDB"FUS9W-T<B`B0G)E=F4@4W5MX7)I;R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT,S@*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B
M92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R(")$979E;2US92!D
M969I;FER('1E8VQA<R!D92!A8V5S<V\@<&%R82!A(&UA:6]R:6$@9&%S(&QI
M9V'G]65S/R(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,CDR('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3$S('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS
M9VED(")3:&]W(@IM<V=S='(@(DUO<W1R87(B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,34X"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E
M96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*
M(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(DUO<W1R87(@9&EF97)E;N=A
M<R!E;G1R92!A(&-O;F9I9W5R8>?C;R!G=6%R9&%D82!E(&%Q=64@9F]I(&%G
M;W)A(&=E<F%D82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#@R"FUS
M9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM
M<V=S='(@(DUO<W1R87(@;6]M96YT;R!D82#Z;'1I;6$@96YT<F%D82!N;R!S
M:7-T96UA/R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8V"FUS9VED(")3
M:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(DUO<W1R87(@
M;W#GXV\@<&%R82!P<F5S97)V87(@;R!O<FEG:6YA;"(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR.#$R"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R(")-
M;W-T<F%R('!A;&5T92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3@*
M;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T
M<B`B36]S=')A<B!A(&)A<G)A(&1E(&UE;G4@8V]M(&%S(&]P97)AY_5E<R!S
M;V)R92!T86)E;&%S/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@
M;&5F=#\B"FUS9W-T<B`B36]S=')A<B!O($UE;G4@)7,@X"!E<W%U97)D83\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3@*;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE
M<R!D:6%L;V<B"FUS9W-T<B`B36]S=')A<B!A(&-A:7AA(&1E(&1IX6QO9V\@
M9&%S(%!R;W!R:65D861E<R!D92!#Z6QU;&%S(&1E(%1A8F5L83\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C,*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G(@IM
M<V=S='(@(DUO<W1R87(@82!C86EX82!D92!D:>%L;V=O(&1A<R!0<F]P<FEE
M9&%D97,@9&4@5&%B96QA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.0IM<V=I9"`B4VAO=R!T:&4@5&%B
M;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(DUO<W1R87(@82!C
M86EX82!D92!D:>%L;V=O(&1A<R!0<F]P<FEE9&%D97,@9&4@3&EN:&%S(&1E
M(%1A8F5L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R
M=&EE<R!D:6%L;V<B"FUS9W-T<B`B36]S=')A<B!A(&-A:7AA(&1E(&1IX6QO
M9V\@9&%S(%!R;W!R:65D861E<R!D92!);6%G96TB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3<V-`IM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T<B`B36]S
M=')A<B!C87)R96=A;65N=&\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU,`IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R(")!9W5A
M8V5I<F]S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-3$*;7-G:60@(E-H;W=E<G,@16%R;'DB"FUS9W-T<B`B06=U86-E:7)O
M<R!-871I;F%I<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C4R"FUS9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B06=U86-E
M:7)O<R!697-P97)T:6YO<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET
M>2(*;7-G<W1R(")!9W5A8V5I<F]S(&YA(%9I>FEN:&%NYV$B"@HC.B!L:6(O
M2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HS.3D*;7-G:60@(E-H<FEN:R(*;7-G
M<W1R(")%;F-O;&AE<B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP
M.C8Y,B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HW-30*(SH@;&EB+TAO
M<F1E+T)L;V-K+TQA>6]U="YP:'`Z.#$R(&QI8B](;W)D92]";&]C:R],87EO
M=70N<&AP.C@W-`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HY,#D@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z.30V"B,Z(&QI8B](;W)D92]"
M;&]C:R],87EO=70N<&AP.CDW-"!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H
M<#HQ,#`T"FUS9VED(")3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO
M8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0B"FUS9W-T<B`B16YC;VQH82!O
M=2!M;W9A(&\H<RD@8FQO8V\H<RD@=FEZ:6YH;RAS*2!P<FEM96ER;R(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3$@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(P,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*
M;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R(")397)R82!,9>-O(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-C4*;7-G:60@(E-I9VX@=7`B
M"FUS9W-T<B`B4W5B<V-R979E<B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z.3(*;7-G:60@(E-I9VX@=7`@:68@;F]T(')E9VES=&5R960B"FUS
M9W-T<B`B4W5B<V-R979A+"!S92!A:6YD82!NXV\@97-TX2!R96=I<W1A9&\B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM<V=I9"`B4VEG
M;F%T=7)E(@IM<V=S='(@(D%S<VEN871U<F$B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C<Q,0IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*
M;7-G<W1R(")!;&=O<FET;6\@9&4@07-S:6YA='5R82(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(P,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-I
M;F=A<&]R92(*;7-G<W1R(")297#Z8FQI8V$@9&4@4VEN9V%P=7)A(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C@Y-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q
M-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(S-PHC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C(T-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDR.2!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,S$R,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV
M-2!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=&=Z+G!H<#HX-`IM<V=I9"`B4VEZ92(*;7-G<W1R
M(")486UA;FAO(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?
M8F]T=&]M+FEN8SHY"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S='(@
M(E-A;'1A<B!-86YU=&5NY^-O(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0S
M,2!P;R]T<F%N<VQA=&EO;BYP:'`Z-#@T('!O+W1R86YS;&%T:6]N+G!H<#HV
M-C8*(SH@<&\O=')A;G-L871I;VXN<&AP.C@V,"!P;R]T<F%N<VQA=&EO;BYP
M:'`Z,3(R,PIM<V=I9"`B4VMI<'!E9"XN+B(*;7-G<W1R(").XV\@<')O8V5S
M<V%D;RXN+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3`@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@(D5S;&]VX7%U
M:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`X(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`U"FUS9VED(")3;&]V96YI82(*;7-G<W1R(")297#Z8FQI8V$@9&$@
M17-L;W;I;FEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-30*;7-G:60@(E-N;W<B"FUS9W-T<B`B3F5V92(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3;F]W
M(%-H;W=E<B(*;7-G<W1R(").97;C;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4V"FUS9VED(")3;F]W(%-H;W=E<G,B"FUS
M9W-T<B`B3F5V]65S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-3<*;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R
M(").97;U97,@36%T:6YA:7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS
M9W-T<B`B3F5V]65S(%9E<W!E<G1I;F]S(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR-S@*;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R(")!;'1U<F$@
M9&4@;F5V93H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#(*;7-G:60@
M(E-N;W<@97%U:79A;&5N="!I;B!W871E<CH@(@IM<V=S='(@(DUO<W1R87(@
M97%U:79A;&5N=&4@;F$@X6=U83H@(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(P,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)<VQA
M;F1S(@IM<V=S='(@(DEL:&%S(%-A;&]MXV\B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C$T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#8*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3;VUA;&EA
M(@IM<V=S='(@(E-O;>%L:6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B0V%NY_5E<R!E(%!O
M96UA<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.3(U"FUS9VED(")3;W)T
M(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R(")396QE8^?C;R!D;R!S96YT:61O
M(&1A(&]R9&5N8>?C;R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU-3D@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Q-R!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T-PIM<V=I9"`B4V]U<F-E(&%D
M9')E<W,B"FUS9W-T<B`B16YD97)EYV\@9&4@;W)I9V5M(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(U-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B
M4V]U=&@@069R:6-A(@IM<V=S='(@(L%F<FEC82!D;R!3=6PB"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B4V]U=&@@175R;W!E86X@*$E3
M3RTX.#4Y+3,I(@IM<V=S='(@(D5U<F]P82!D;R!3=6P@*$E33RTX.#4Y+3,I
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<W"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I
M8V@@27-L86YD<R(*;7-G<W1R(")'9?-R9VEA(&1O(%-U;"!E($EL:&%S(%-A
M;F1W:6-H(&1O(%-U;"(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B
M"FUS9W-T<B`B2&5M:7-FZ7)I;R!3=6PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E
M;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R(")%<W!AYV\@96YT<F4@8^EL=6QA
M<R!A9&IA8V5N=&5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E='=E96X@8V]N=&5N="!A
M;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B17-P8>=O(&5N=')E(&\@8V]N
M=&7Z9&\@92!A(&)O<F1A(&1E('5M82!CZ6QU;&$B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z.#$U"FUS9VED(")3<&%C97(B"FUS9W-T<B`B17-P8>=A9&]R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@P"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(D5S<&'G86UE;G1O(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R(")%<W!A
MYV%M96YT;R!E(&5N8VAI;65N=&\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`B
M4F5I;F\@9&4@17-P86YH82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HY.`IM<V=I9"`B4W!A;2(*;7-G<W1R(")#;W)R96EO(&[C;R!S;VQI8VET
M861O(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C
M:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R("));G-E<FER($-A<F%C=&5R
M($5S<&5C:6%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R(")$
M:79I9&ER(&/I;'5L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G
M<W1R(")!9&EC:6]N87(@8V]L=6YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W
M(@IM<V=S='(@(D1I=FED:7(@;&EN:&$B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-C$*;7-G:60@(E-P;W)T<R(*;7-G<W1R(")$97-P;W)T;W,B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30Q(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*
M;7-G:60@(E-R:2!,86YK82(*;7-G<W1R(")297#Z8FQI8V$@1&5M;V-RX71I
M8V$@4V]C:6%L:7-T82!D;R!3<FD@3&%N:V$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-C4@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-`IM<V=I
M9"`B4W1A;F1A<F0B"FUS9W-T<B`B4&%D<N-O(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C8R"FUS9VED(")3=&%R(%1R96LB"FUS9W-T<B`B4W1A<B!4
M<F5K(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U.34@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(X,#@*;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B06YO(&1E
M(&EN[6-I;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<P"FUS
M9VED(")3=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R(")%<W1A9&\@;W4@4')O
M=NUN8VEA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ
M,3(*;7-G:60@(E-T871U<R(*;7-G<W1R(")3=&%T=7,B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z-#DQ"B,L('!H<"UF;W)M870*;7-G:60@(E-T871U<R!F
M;W(@;&]C86QE("5S+BXN("(*;7-G<W1R(")%<W1A9&\@9&$@;&]C86QI>F'G
MXV\@)7,N+BX@(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,30*;7-G:60@
M(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(D9O<FUA=&\@9&4@87)M87IE;F%M
M96YT;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<R"FUS9VED
M(")3=')E970@061D<F5S<R(*;7-G<W1R(")%;F1E<F7G;R!D92!2=6$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q"FUS
M9VED(")3=')I:V5T:')O=6=H(@IM<V=S='(@(E)A<W5R861O(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$R,S,*;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S
M='(@(DQI<W1A(&1E(&-A9&5I87,@9&4@8V%R86-T97)E<R(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ.#<T"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T
M:&4@861D<F5S<R(*;7-G<W1R(")2971I<F%R(&1O;>UN:6\@9&\@96YD97)E
MYV\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G<W1R(")%<W1I;&\@
M6T-34UTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R(")D;R(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J96-T(@IM<V=S
M='(@(D%S<W5N=&\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,R(&QI8B](
M;W)D92]&;W)M+U)E;F1E<F5R+G!H<#HS,3(*;7-G:60@(E-U8FUI="(*;7-G
M<W1R(")3=6)M971E<B(*"B,Z('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T
M;R!T:&4@<WES=&5M+B!9;W4@8V%N(&YO="!L;V<@:6X@=6YT:6P@>6]U<B`B
M"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G<W1R("(B"B)&;VD@
M<W5B;65T:61O('!E9&ED;R!P87)A(&%D:6-I;VYA<B!<(B5S7"(@86\@<VES
M=&5M82X@3N-O('!O9&5RX2!E;G1R87(@(@HB96YQ=6%N=&\@;R!S974@<&5D
M:61O(&[C;R!F;W(@87!R;W9A9&\N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S
M='(@(DEN9F5R:6]R(.`@;&EN:&$B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3`U(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H
M<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R(")3=6-E<W-O(@H*(SH@861M
M:6XO=7-E<BYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY(&%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G<W1R(")<(B5S
M7"(@861I8VEO;F%D;R!C;VT@<W5C97-S;R!A;R!S:7-T96UA+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S
M9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S
M>7-T96TN(@IM<V=S='(@(B(*(DQI;7!E>F$@9&\@<VES=&5M82!D;W,@9&%D
M;W,@9&\@=71I;&EZ861O<B!<(B5S7"(@<F5A;&EZ861A(&-O;2!S=6-E<W-O
M+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z.#$@861M:6XO<&5R;7,O9&5L971E
M+G!H<#HV,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L
M971E9"!<(B5S7"(N(@IM<V=S='(@(E)E;6_GXV\@9&4@7"(E<UPB(&-O;2!S
M=6-E<W-O+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@
M<WES=&5M+B(*;7-G<W1R(")296UOY^-O(&1E(%PB)7-<(B!D;R!S:7-T96UA
M(&-O;2!S=6-E<W-O+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*
M;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!2
M96QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(D-O;F9I9W5R8>?C;R!R
M979E<G1I9&$@8V]M('-U8V5S<V\N(%)E8V%R<F5G=64@<&%R82!V97(@87,@
M;75D86[G87,N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.C4U"FUS9VED(")3=6-C97-S9G5L;'D@<V%V
M960@8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D-O;F9I9W5R8>?C
M;R!D92!S86QV86=U87)D82!G=6%R9&%D82!C;VT@<W5C97-S;RXB"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@
M(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@
M9FEL92`E<RXB"FUS9W-T<B`B1FEC:&5I<F\@9&4@8V]N9FEG=7)AY^-O(&1E
M('-A;'9A9W5A<F1A("5S(&=U87)D861O(&-O;2!S=6-E<W-O+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S
M9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`B7"(E<UPB(&%C='5A;&EZ
M861O(&-O;2!S=6-E<W-O(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW
M,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@(B5S(&5S8W)I=&\@
M8V]M('-U8V5S<V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`T(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=61A;B(*;7-G<W1R(")297#Z8FQI
M8V$@9&\@4W5DXV\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4V"FUS9VED(")3=6UM87)Y(@IM<V=S='(@(E)E
M<W5M;R(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV-@IM<V=I9"`B4W5N
M(%)I<V4B"FUS9W-T<B`B3F%S8V5R(&1O(%-O;"(*"B,Z(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HW,0IM<V=I9"`B4W5N(%-E="(*;7-G<W1R(")0]'(@9&\@
M4V]L(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-3D*;7-G:60@(E-U;FYY(@IM<V=S='(@(E-O;&%R96YG;R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#0*;7-G:60@(E-U;G)I<V4B"FUS
M9W-T<B`B3F%S8V5R(&1O(%-O;"(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H
M<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3
M=6YS970B"FUS9W-T<B`B3F%S8V5R+U#T<B!D;R!3;VPB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`S"FUS9VED(")3=6YR:7-E.B`B"FUS
M9W-T<B`B3F%S8V5R(&1O(%-O;#H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(P-PIM<V=I9"`B4W5N<V5T(@IM<V=S='(@(E#T<B!D;R!3
M;VPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`V"FUS9VED
M(")3=6YS970Z("(*;7-G<W1R(")0]'(@9&\@4V]L.B`B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S"FUS9VED(")3=7!E
M<G-C<FEP="(*;7-G<W1R(")3=7!E<FEO<B#@(&QI;FAA(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0T,PIM<V=I9"`B4W5P<&]R="(*;7-G<W1R
M(")3=7!O<G1E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P-@IM<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`B4W5R:6YA
M;64B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W-`IM<V=I9"`B
M4W5R;F%M92(*;7-G<W1R(")!<&5L:61O(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(P.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@
M86YD($IA;B!-87EE;B(*;7-G<W1R(")3=F%L8F%R9"!E($IA;B!-87EE;B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3D@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(Q-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#@*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R(")296EN;R!D82!3=6%Z:6SB
M;F1I82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#4@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G<W1R(")296EN;R!D82!3=>EC
M:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-38@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`B4W7MYV$B"@HC.B!L
M:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R
M<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R(")%<G)O(&1E('-I;G1A>&4@
M;F]S('1E<FUO<R!D92!P<F]C=7)A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(Q."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4WER:6%N($%R86(@
M4F5P=6)L:6,B"FUS9W-T<B`B4F5P^F)L:6-A(,%R86)E(%/M<FEA(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G:60@
M(E0M4W1O<FTB"FUS9W-T<B`B5&5M<&]R86PM5"(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Q"FUS9VED(")4+5-T;W)M(&%N
M9"!7:6YD>2(*;7-G<W1R(")496UP;W)A;"U4(&4@5F5N=&]S;R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS9VED(")4
M+5-T;W)M<R(*;7-G<W1R(")496UP;W)A:7,M5"(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8S"FUS9VED(")4+5-T;W)M<R!%
M87)L>2(*;7-G<W1R(")496UP;W)A:7,M5"!-871I;F%I<R(*"B,Z(&QI8B](
M;W)D92]$871A+W1S=BYP:'`Z,38V"FUS9VED(")44U8@9FEL92(*;7-G<W1R
M(")!<G%U:79O(%135B(*"B,Z(&QI8B](;W)D92]522]486)L92YP:'`Z,3,V
M"FUS9VED(")486)L92(*;7-G<W1R(")486)E;&$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S"FUS9VED(")4
M86)L92!0<F]P97)T:65S(@IM<V=S='(@(E!R;W!R:65D861E<R!D82!486)E
M;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P97)T:65S(@IM<V=S='(@(E!R
M;W!R:65D861E<R!D82!T86)E;&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C,T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I
M=V%N(@IM<V=S='(@(D9O<FUO<V$B"@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA
M(@IM<V=S='(@(D9O<FUO<V$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C(U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")486II:VES=&%N(@IM<V=S
M='(@(E)E</IB;&EC82!D;R!4861J:7%U:7-TXV\B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C,U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,C`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ
M86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S='(@(E1A;GKB;FEA(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM
M<V=I9"`B5&%R9V5T.B(*;7-G<W1R(")!;'9O.B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ-S,*;7-G:60@(E1A<VMS(@IM<V=S='(@(E1A<F5F
M87,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,PIM<V=I9"`B
M5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R(").^FUE<F\@9&4@5&5L969O;F4B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y,`IM<V=I9"`B5&5M<"!F;W(@
M;&%S="!H;W5R.B`B"FUS9W-T<B`B5&5M<&5R871U<F$@9&$@^FQT:6UA(&AO
M<F$Z(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,30*;7-G:60@(E1E;7!E
M<F%T=7)E(@IM<V=S='(@(E1E;7!E<F%T=7)A(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Q,0IM<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G
M<W1R(")496UP97)A='5R83H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(X,0HC+"!P:'`M9F]R;6%T"FUS9VED(")496UP97)A='5R93QB
M<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@(E1E;7!E<F%T
M=7)A/&)R("\^*"5S06QT825S+R5S0F%I>&$E<RD@)F1E9SLE<R(*"B,Z(&QI
M8B](;W)D92]496UP;&%T92YP:'`Z,C$W"B,L('!H<"UF;W)M870*;7-G:60@
M(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(D\@;6]D96QO
M(%PB)7-<(B!NXV\@9F]I(&5N8V]N=')A9&\N(@H*(SH@861M:6XO=&5M<&QA
M=&5S+G!H<#HQ-CD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(D%D;6EN:7-T<F'GXV\@9&4@36]D96QO<R(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,C$Q"FUS9VED(")497AT(@IM<V=S='(@(E1E>'1O(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-PIM<V=I9"`B5&5X="!/;FQY
M(@IM<V=S='(@(D%P96YA<R!497AT;R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G:60@(E1E>'0@86QI
M9VXB"FUS9W-T<B`B06QI;FAA;65N=&\@9&\@=&5X=&\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"FUS9VED(")497AT
M=&]P(@IM<V=S='(@(E1O<&\@9&\@=&5X=&\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R
M("(UJB(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ"FUS9VED(")4:&%I
M("A425,M-C(P*2(*;7-G<W1R(")486EL86YDZG,@*%1)4RTV,C`I(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.0IM
M<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B4F5I;F\@9&$@5&%I;.)N9&EA(@H*
M(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDR,PIM<V=I9"`B5&AA;FL@>6]U(&9O
M<B!U<VEN9R!T:&4@<WES=&5M+B(*;7-G<W1R(")/8G)I9V%D;R!P;W(@=7-A
M<B!E<W1E('-I<W1E;6$N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P-CD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE("5S(&AE;'`@9FEL92!F;W(@)7,@
M9&]E<VXG="!Y970@97AI<W0N($-R96%T:6YG(&$@;F5W(&]N92XB"FUS9W-T
M<B`B3R!A<G%U:79O(&1E(&%J=61A("5S('!A<F$@)7,@;N-O(&5X:7-T92!A
M:6YD82X@0W)I86YD;R!U;2!N;W9O+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW
M,S<*;7-G:60@(E1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(D$@97AT96YSXV\@1E10(&[C;R!E<W3A(&1I<W!O;NUV96PN
M(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S
M(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R(")/(&5N9V5N:&\@9&4@:6YT
M96=R8>?C;R!(;W)D92]+;VQA8B!NXV\@<W5P;W)T82!<(B5S7"(B"@HC.B!L
M:6(O3F5T+TE-4U`O0F]O:RYP:'`Z,3(Y-`IM<V=I9"`B5&AE($E-4U`@;&]G
M(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B3R!R96=I<W1O
M("A<(FQO9UPB*2!)35-0(&[C;R!P]&1E('-E<B!I;FEC:6%L:7IA9&\N(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(Y"FUS9VED(")4:&4@36%I
M;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM
M<V=S='(@(D$@8VQA<W-E($UA:6YT96YA;F-E.CH@;N-O(&9O:2!C87)R96=A
M9&$@8V]M('-U8V5S<V\B"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K
M97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E
M9"X@17AI=&EN9RXB"FUS9W-T<B`B02!J86YE;&$@9&4@3W#G]65S(&9E8VAO
M=2X@4V'M;F1O+B(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,34X(&QI8B](
M;W)D92]097)M<RYP:'`Z,38Y(&QI8B](;W)D92]097)M<RYP:'`Z,3@P"B,Z
M(&QI8B](;W)D92]097)M<RYP:'`Z,3DR(&QI8B](;W)D92]097)M<RYP:'`Z
M,C`S(&QI8B](;W)D92]097)M<RYP:'`Z,C(Q"B,Z(&QI8B](;W)D92]097)M
M<RYP:'`Z,C,S(&QI8B](;W)D92]097)M<RYP:'`Z,C<R"FUS9VED("(B"B)4
M:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE
M;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@
M4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*(D\@861M:6YI<W1R861O<B!T96T@
M9&4@8V]N9FEG=7)A<B!U;2!M96-A;FES;6\@9&4@<&5R;6ES<_5E<R!P97)M
M86YE;G1E('-E("(*(G%U:7-E<B!U<V%R(%!E<FUI<W/U97,N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM
M<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T<B`B07!E;F%S(&\@
M;&%D;R!I;F9E<FEO<B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@
M;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN
M('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B(@HB3R!N^FUE<F\@9&4@240@
M9&\@8V]N=&%C=&\@;N-O(&9O:2!E<W!E8VEF:6-A9&\L(&9O:2!D96EX861O
M(&5M(&)R86YC;R!O=2`B"B)NXV\@9F]I(&5N8V]N=')A9&\@;F$@8F%S92!D
M92!D861O<RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C4Q"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D
M('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R(")/(&-O;G1A8W1O(&9O
M:2!A9&EC:6]N861O(.`@;&ES=&$@9&4@8V]N=&%C=&]S(&-O;2!S=6-E<W-O
M+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q-#D*;7-G:60@(B(*
M(E1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D
M('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*(D\@
M8FQO8V\@9&4@87-S:6YA='5R82!01U`@9&5S=&%C861O(.D@;F5C97-SX7)I
M;R!P87)A('9E<FEF:6-A<B!U;6$@;65N<V%G96T@(@HB87-S:6YA9&$N(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B
M(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P
M96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A
M=&%B87-E+B(*;7-G<W1R("(B"B)/($E$(&1A(&QI<W1A(&1E(&1I<W1R:6)U
M:>?C;R!NXV\@9F]I(&5S<&5C:69I8V%D;RP@9F]I(&1E:7AA9&\@96T@8G)A
M;F-O(&]U("(*(F[C;R!F;VD@96YC;VYT<F%D;R!N82!B87-E(&1E(&1A9&]S
M+B(*"B,@8RUF;W)M870*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@
M<W!E8VEF:65D+B(*;7-G<W1R(")!(&QI<W1A(&1E(&1I<W1R:6)U:>?C;R!N
MXV\@9F]I(&5S<&5C:69I8V%D82XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0N<&AP
M.C$Q,PIM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A
M('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B07,@9G5N8VEO;F%L
M:61A9&5S(&1E(&5N8W)I<'1AY^-O(&5X:6=E;2!U;6$@;&EG8>?C;R!S96=U
M<F$N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-S4@;&EB+TAO<F1E+G!H<#HT.#@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A
M:6X@82`E<R!S971T:6YG+B(*;7-G<W1R(")/(&%R<75I=F\@)7,@9&5V97)I
M82!C;VYT97(@=6T@871R:6)U=&\@)7,N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ
M-C@@;&EB+TAO<F1E+G!H<#HT-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS
M9W-T<B`B3R!A<G%U:79O("5S(&1E=F5R:6$@8V]N=&5R(&%L9W5N<R!A=')I
M8G5T;W,@)7,N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ-3(*;7-G:60@(E1H
M92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+B(*;7-G<W1R
M(")/(&9I8VAE:7)O(&[C;R!P;V1E('-E<B!C;W!I861O('!A<F$@<VD@<'+S
M<')I;RXB"@HC.B!L:6(O2&]R9&4O1&%T82YP:'`Z,C8P"FUS9VED(")4:&4@
M9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B3R!F:6-H96ER;R!N
MXV\@8V]N=.EM(&1A9&]S+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A
M9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R
M(")!8F%I>&\@97-TXV\@;W,@8V%B9>=A;&AO<R!D97-T82!M96YS86=E;2]M
M96YS86=E;2!R9F,X,C(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO
M9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%
M>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N
M)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@
M(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@
M86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y
M<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G
M;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@86YD(&YE
M960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE
M87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@
M9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R("(B"B)/(&UO9&\@9&4@96-R
MXR!I;G1E:7)O(&-A=7-A('!R;V)L96UA<R!N;R!);G1E<FYE="!%>'!L;W)E
M<BP@9&5V:61O(&$@97)R;W,@(@HB;F\@;F%V96=A9&]R('%U92!NXV\@8V]N
M<V5G=6EM;W,@=6QT<F%P87-S87(N("!0;V1E('-U<F=I<B!L:7AO+"!P;V1E
M;2`B"B)D97-A<&%R96-E<B!F=6YC:6]N86QI9&%D97,@9&\@961I=&]R(&4O
M;W4@;R!S974@;F%V96=A9&]R('!O9&4@86)O<G1A<BX@4V4@(@HB;R!S974@
M<VES=&5M82#I('5M(%=I;F1O=W,@.7@L(.D@;75I=&\@<')O=N%V96P@<75E
M(&]B=&5N:&$@=6T@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@92!P
M<F5C:7-E(&1E(')E:6YI8VEA<B!O('-I<W1E;6$N7%QN7%QN1F]I(&%V:7-A
M9&\N("!0;W(@(@HB9F%V;W(@<')E<W-I;VYE($]+('-E(&%I;F1A(&%S<VEM
M('%U:7-E<B!E>'!E<FEM96YT87(@;R!E9&ET;W(@9&4@96-RXR`B"B)I;G1E
M:7)O+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#DW('!O+W1R86YS;&%T
M:6]N+G!H<#HQ,C,U"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!H96QP(&9I
M;&4@)7,@9&ED;B=T('-T87)T('=I=&@@/#]X;6PB"FUS9W-T<B`B3R!F:6-H
M96ER;R!D92!A:G5D82`E<R!NXV\@8V]M9>=A(&-O;2`\/WAM;"(*"B,Z('-E
M<G9I8V5S+W!R969S+G!H<#HX.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(D$@
M:61E;G1I9&%D92!<(B5S7"(@9F]I(')E;6]V:61A+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@
M(E1H92!L969T+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(D%P96YA<R!O(&QA
M9&\@97-Q=65R9&\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ-#8*
M;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU
M<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R
M("(B"B)!(&QO8V%L:7IAY^-O(&1O(&%R<75I=F\@97AE8W5TX79E;"!D92!'
M;G501R!T96T@9&4@<V5R(&EN9&EC861A(.`@8VQA<W-E("(*(D-R>7!T7W!G
M<#HZ+B(*"B,Z(&QI8B](;W)D92]-24U%+TU$3BYP:'`Z,C`Q"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@
M=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4
M:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N
M(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@HB02!M96YS86=E;2!E
M;G9I861A(&5M("5S('!A<F$@)7,@8V]M(&%S<W5N=&\@7"(E<UPB(&9O:2!M
M;W-T<F%D82Y<;B(*(D[C;R!HX2!G87)A;G1I82!D92!Q=64@82!M96YS86=E
M;2!T96YH82!S:61O(')E86QM96YT92!L:61A(&]U(&-O;7!R965N9&ED82XB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W.`IM<V=I9"`B5&AE(&YA;64@
M=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S
M='(@(D\@;F]M92!A('5S87(@<75A;F1O(&QI9V%N9&\@X"!PX6=I;F$@9&4@
M8V]M<&]S:>?C;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(S
M,0IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T
M:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B3R!M\V1U
M;&\@;W!E;G-S;"#I(&YE8V5S<^%R:6\@<&%R82!A(&-L87-S92!(;W)D95]#
M<GEP=%]S;6EM93HZ+B(*"B,Z(&QI8B](;W)D92]0<F5F<RYP:'`Z,C@U"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C
M;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T
M:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"B)!(&]P
MY^-O(%PB)7-<(B!NXV\@</1D92!S97(@9W5A<F1A9&$L('!O:7,@;W,@<V5U
M<R!D861O<R!E>&-E9&5M(&$@9&EM96YSXV\@(@HB;>%X:6UA('!E<FUI=&ED
M82(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]D96(N<&AP.C,R(&QI8B](
M;W)D92]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)P;2YP:'`Z,S(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W=E8F-P
M<"YP:'`Z,S<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W-R8VAI9VAL:71E
M+G!H<#HS-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z
M,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T
M;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T
M:&4@<WES=&5M+B(*;7-G<W1R("(B"B)/('!R;V=R86UA('5S861O('!A<F$@
M=F5R(&5S=&4@=&EP;R!D92!D861O<R`H)7,I(&[C;R!F;VD@96YC;VYT<F%D
M;R!N;R`B"B)S:7-T96UA+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A;F0@
M;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(D%P96YA<R!O<R!L861O<R!E<W%U
M97)D;R!E(&1I<F5I=&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S
M:61E(&]N;'DB"FUS9W-T<B`B07!E;F%S(&\@;&%D;R!D:7)E:71O(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS
M9W-T<B`B3R!S97)V:61O<B!<(B5S7"(@9F]I(')E;6]V:61O+B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R
M(")/('-E<G9I9&]R(%PB)7-<(B!F;VD@9W5A<F1A9&\N(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@
M<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B3R!P
M961I9&\@9&4@<W5B<V-R:>?C;R!D92`E<R!F;VD@<F5M;W9I9&\N(@H*(SH@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,CDP"FUS9VED(")4:&4@<W!E
M8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B02!L:6YH82!I
M;F1I8V%D82!NXV\@97AI<W1E+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HQ,#@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<
M(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B3R!A<G%U:79O('1E;7!O<N%R
M:6\@7"(E<UPB(&[C;R!E>&ES=&4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A
M;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B07!E;F%S(&]S(&QA9&]S
M('-U<&5R:6]R(&4@:6YF97)I;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@=&]P('-I
M9&4@;VYL>2(*;7-G<W1R(")!<&5N87,@;R!L861O('-U<&5R:6]R(@H*(SH@
M;&EB+TAO<F1E+T1A=&$N<&AP.C,P-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A
M=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@
M(D]S(&1A9&]S(&-A<G)E9V%D;W,@<&5R9&5R86TM<V4@9&5S9&4@;R!P87-S
M;R!A;G1E<FEO<BXB"@HC.B!L:6(O2&]R9&4O1&%T82]C<W8N<&AP.C(T,"!L
M:6(O2&]R9&4O1&%T82]T<W8N<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D
M(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R(")/(&%R<75I=F\@
M8V%R<F5G861O(&[C;R!P]&1E('-E<B!G=6%R9&%D;RXB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#@@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$P.0IM<V=I9"`B5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(D\@8FQO8V\@=V5A=&AE<BYC;VT@;N-O
M(&5S=.$@9&ES<&]N[79E;"XB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP
M.C$W.`IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*
M;7-G<W1R(").XV\@:.$@;W#G]65S(&1I<W!O;NUV96ES+B(*"B,Z(&QI8B](
M;W)D92]-24U%+T-O;G1E;G1S+G!H<#HS-#$*;7-G:60@(E1H97)E(&%R92!N
M;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R
M(").XV\@:.$@<&%R=&5S('%U92!P;W-S86T@<V5R(&UO<W1R861A<R!E;2!L
M:6YH82XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30P,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I
M;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[
M("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@HB
M2.$@9&5M87-I861O<R!C87)A8W1E<F5S(&YE<W1E(&-A;7!O+B!);G1R;V1U
M>FEU("5S(&-A<F%C=&5R97,[('1E;2!D92`B"B)I;G1R;V1U>FER(&UE;F]S
M(&1O('%U92`E<RXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`V,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!D;V5S;B=T('EE="!E>&ES="!A(&AE
M;'`@9FEL92!F;W(@)7,N(@IM<V=S='(@(D[C;R!E>&ES=&4@86EN9&$@=6T@
M87)Q=6EV;R!D92!A:G5D82!P87)A("5S+B(*"B,Z('-I9VYU<"YP:'`Z-3,@
M861M:6XO=7-E<BYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&$@<')O8FQE;2!A9&1I;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S
M(@IM<V=S='(@(D]C;W)R974@=6T@<')O8FQE;6$@;F$@861IY^-O(&1E(%PB
M)7-<(B!A;R!S:7-T96UA.B`E<R(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R
M:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM
M<V=S='(@(B(*(D]C;W)R974@=6T@<')O8FQE;6$@86\@;&EM<&%R(&]S(&1A
M9&]S(&1O('5T:6QI>F%D;W(@7"(E<UPB(&1O('-I<W1E;6$N(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@
M(@IM<V=S='(@(D]C;W)R974@=6T@<')O8FQE;6$@;F$@<F5M;^?C;R!D92!<
M(B5S7"(@9&\@<VES=&5M82XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN
M9R!<(B5S7"(Z("5S(@IM<V=S='(@(D]C;W)R974@=6T@<')O8FQE;6$@86\@
M86-T=6%L:7IA<B!<(B5S7"(Z("5S+B(*"B,Z(&QI8B](;W)D92]"<F]W<V5R
M+G!H<#HX.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D
M+B(*;7-G<W1R("(B"B)(;W5V92!U;2!P<F]B;&5M82!C;VT@;R!C87)R96=A
M;65N=&\@9&\@9FEC:&5I<F\Z("5S(&[C;R!F;VD@8V%R<F5G861O+B(*"B,Z
M(&QI8B](;W)D92]"<F]W<V5R+G!H<#HX.3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO
M=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@HB3V-O<G)E=2!U;2!P
M<F]B;&5M82!C;VT@;R!C87)R96=A;65N=&\@9&\@87)Q=6EV;SH@3R`E<R!E
M>&-E9&4@;R!T86UA;FAO("(*(FWA>&EM;R!P97)M:71I9&\@*"5D(&)Y=&5S
M*2XB"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.#DU"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N
M(@IM<V=S='(@(B(*(D]C;W)R974@=6T@<')O8FQE;6$@8V]M(&\@8V%R<F5G
M86UE;G1O(&1O(&%R<75I=F\Z($\@)7,@9F]I(&%P96YA<R`B"B)P87)C:6%L
M;65N=&4@8V%R<F5G861O+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA
M>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R(")/8V]R<F5U('5M(&5R
M<F\@86\@;6]S=')A<B!E<W1A('!A<G1E(&1A(&UE;G-A9V5M(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.2!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(D]C;W)R
M974@=6T@97)R;R!A;R!I;7!O<G1A<B!D861O<R!D92!C;VYT86-T;RXB"@HC
M.B!L:6(O2&]R9&4O1&%T82]I;6,N<&AP.C,Q"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T
M<B`B3V-O<G)E=2!U;2!E<G)O(&%O(&EM<&]R=&%R(&1A9&]S(&E#86QE;F1A
M<BXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Y"FUS9VED("(B"B)4
M:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@
M4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS
M9W-T<B`B(@HB3V-O<G)E=2!U;2!E<G)O(&YO(&9O<FUU;.%R:6\@9&4@8V]N
M9FEG=7)AY^-O+B!486QV97H@=&5N:&$@;VUI=&ED;R!U;2!C86UP;R`B"B)O
M8G)I9V%T\W)I;RXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$P-R!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,3$Q,R!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(T-0HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(U,0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&5R92!W87,@86X@97)R;W(@;W!E;FEN9R!T:&4@9FEL92`E<RX@
M5')Y(')U;FYI;F<@=')A;G-L871I;VXN<&AP('=I=&@@=&AE("(*(F9L86<@
M+60@=&\@<V5E(&%N>2!E<G)O<B!M97-S86=E<R!F<F]M('1H92!X;6P@<&%R
M<V5R+B(*;7-G<W1R("(B"B)/8V]R<F5U('5M(&5R<F\@86\@86)R:7(@;R!A
M<G%U:79O("5S+B!%>'!E<FEM96YT92!E>&5C=71A<B!T<F%N<VQA=&EO;BYP
M:'`@(@HB8V]M(&$@;W#GXV\@+60@<&%R82!C;VYS96=U:7(@=F5R(&%S(&UE
M;G-A9V5N<R!D92!E<G)O(&1O(&%N86QI<V%D;W(@6$U,+B(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*(E1H97)E
M('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S
M<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*
M;7-G<W1R("(B"B)/8V]R<F5U('5M(&5R<F\@86\@<F5A;&EZ87(@82!F=6[G
MXV\@9&4@;&EV<F\@9&4@96YD97)EYV]S(&5S<&5C:69I8V%D82X@4&]R("(*
M(F9A=F]R('1E;G1E(&1E(&YO=F\@;6%I<R!T87)D92XB"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0P"FUS9VED("(B"B)4:&5R92!W
M87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE
M87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB3V-O<G)E=2!U;2!E
M<G)O(&%O(&%C='5A;&EZ87(@;W,@<&]R;65N;W)E<R!D;R!C;VYT86-T;RX@
M4&]R(&9A=F]R('1E;G1E(&1E("(*(FYO=F\@;6%I<R!T87)D92XB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U"FUS9VED("(B"B)4
M:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L
M:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B)/8V]R
M<F5U('5M(&5R<F\@86\@86-T=6%L:7IA<B!A(&QI<W1A(&1E(&1I<W1R:6)U
M:>?C;RX@4&]R(&9A=F]R('1E;G1E(&1E("(*(FYO=F\@;6%I<R!T87)D92XB
M"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS9VED
M(")4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F
M;VQD97)S+B(*;7-G<W1R(")%<W1E('-E<G9I9&]R($E-05`@;N-O('-U<&]R
M=&$@<&%R=&EL:&$@9&4@<&%S=&%S+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]R87(N<&AP.C0X"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T
M;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R(").XV\@<&%R96-E
M('-E<B!U;2!A<G%U:79O(')A<B!VX6QI9&\N(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P
M96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(D[C;R!P87)E
M8V4@<V5R('5M(&%R<75I=F\@>FEP(';A;&ED;RXB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,S$T-`IM<V=I9"`B5&AI<R!D;V5S(&YO="!S965M('1O(&)E
M(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@(D[C;R!P87)E8V4@<V5R
M('5M82!N^FUE<F\@9&4@8V%R=.-O(';A;&ED;RXB"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI
M8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U
M<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB17-T92!C;VYT<F]L861O
M<B!P97)M:71E(&\@96YV:6\@9&4@;65N<V%G96YS(&%T<F%VZ7,@9&\@0VQI
M8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2P@=7-A;F1O(&$@
M05!)($A45%`B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3$U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R
M96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T
M<B`B(@HB17-T92!C;VYT<F]L861O<B!P97)M:71E(&\@96YV:6\@9&4@;65N
M<V%G96YS(&%T<F%VZ7,@9&\@<VUS,FUA:6P@*&AT='`Z+R\B"B)S;7,R96UA
M:6PN8V]M*2P@=7-A;F1O(&$@05!)($A45%`B"@HC.B!L:6(O3F5T+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.C@U"FUS9VED("(B"B)4:&ES(&1R:79E
M<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H
M('1H92!6;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F
M;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET
M:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G
M<W1R("(B"B)%<W1E(&-O;G1R;VQA9&]R('!E<FUI=&4@;R!E;G9I;R!D92!M
M96YS86=E;G,@=FEA(%--5%`@871R87;I<R!D82!6;V1A9F]N92`B"B))=.%L
M:6$@92!A<&5N87,@<&%R82!N^FUE<F]S(%9O9&%F;VYE+B!%>&EG92!U;6$@
M8V]N=&$@9&4@8V]R<F5I;R`B"B)E;&5C='+S;FEC;R!N82!6;V1A9F]N92!)
M=.%L:6$@*&AT='`Z+R]W=W<N,3DP+FET*2XB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z.3<X(&QI8B](;W)D92]&;W)M+G!H<#HQ,#4W(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,#@V"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3$U(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,3@R(&QI8B](;W)D92]&;W)M+G!H<#HQ,C4V"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,S`U(&QI8B](;W)D92]&;W)M+G!H<#HQ
M-#`P(&QI8B](;W)D92]&;W)M+G!H<#HQ-34Y"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ.#0P(&QI8B](;W)D92]&;W)M+G!H<#HQ.34Y(&QI8B](;W)D92]&
M;W)M+G!H<#HR,#`V"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,#,P(&QI8B](
M;W)D92]&;W)M+G!H<#HR,#<Y(&QI8B](;W)D92]&;W)M+G!H<#HR,34P"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,C(R(&QI8B](;W)D92]&;W)M+G!H<#HR
M-#`Y(&QI8B](;W)D92]&;W)M+G!H<#HR-#4S"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR-C4V(&QI8B](;W)D92]&;W)M+G!H<#HR.#(W(&QI8B](;W)D92]&
M;W)M+G!H<#HS,3,V"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS-S(S(&QI8B](
M;W)D92]&;W)M+G!H<#HS-S,Q"FUS9VED(")4:&ES(&9I96QD(&ES(')E<75I
M<F5D+B(*;7-G<W1R(")%<W1E(&-A;7!O(.D@;V)R:6=A=/-R:6\N(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$P-C4*;7-G:60@(E1H:7,@9FEE;&0@;6%Y
M(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB"FUS9W-T<B`B17-T92!C86UP;R!P
M;V1E(&-O;G1E<B!A<&5N87,@:6YT96ER;W,N(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(T,3<*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I
M;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(D5S=&4@8V%M<&\@
M<&]D92!A<&5N87,@8V]N=&5R(&[Z;65R;W,@92!O('/M;6)O;&\@9&]I<RUP
M;VYT;W,N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P.30*;7-G:60@(E1H
M:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S
M='(@(D5S=&4@8V%M<&\@<&]D92!C;VYT97(@87!E;F%S('9A;&]R97,@;V-T
M86ES+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3(S"FUS9VED(")4:&ES
M(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES
M="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B"B)%<W1E(&-A;7!O('1E;2!D92!C
M;VYT97(@=6UA(&QI<W1A(&1E(&EN=&5I<F]S('-E<&%R861O<R!P;W(@97-P
M8>=O<R!O=2`B"B)V[7)G=6QA<RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M.3@Y"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N
M(@IM<V=S='(@(D5S=&4@8V%M<&\@=&5M(&1E('-E<B!U;2!N^FUE<F\@=N%L
M:61O+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#,U"FUS9VED("(B"B)4
M:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'
M0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S
M='(@(B(*(D5S=&4@8V%M<&\@=&5M(&1E(&-O;G1E<B!U;2!C\V1I9V\@9&4@
M8V]R(&YO(&9O<FUA=&\@4D="(&AE>&%D96-I;6%L+"!P;W(@(@HB97AE;7!L
M;R`G(S$R,S1A9B<N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C4V,0IM<V=I
M9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G
M<W1R(")%<W1E(&UO9&5L;R!JX2!F;VD@<')O8V5S<V%D;RXB"@HC.B!T96UP
M;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&ES(&ES("5S+B(*;7-G<W1R("))<W1O(.D@)7,N(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I
M<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE
M8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E
M<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES
M="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I<VET("5S(@IM
M<V=S='(@(B(*(D5S=&4@Z2!U;2!O8FIE8W1O($MO;&%B($=R;W5P=V%R92X@
M4&%R82!V97(@97-T92!O8FIE8W1O('!R96-I<V$@9&4@=6T@(@HB8VQI96YT
M92!D92!C;W)R96EO(&5L96-T<O-N:6-O('%U92!C;VYH9>=A(&\@9F]R;6%T
M;R!+;VQA8B!'<F]U<'=A<F4N(%!A<F$@(@HB=6UA(&QI<W1A(&1E(&-L:65N
M=&5S(&1E(&-O<G)E:6\@96QE8W1R\VYI8V\@;F5S<V%S(&-I<F-U;G-TXFYC
M:6%S('9I<VET92`E<R(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H
M<#HU.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W
M<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U
M<B!O=VXN(@IM<V=S='(@(D5S=&$@;65N<V%G96T@9F]I(&5S8W)I=&$@;G5M
M(&/S9&EG;R`H)7,I(&1I9F5R96YT92!D;R!S974N(@H*(SH@;&EB+TAO<F1E
M+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@
M870@;&5A<W0@;VYE+B(*;7-G<W1R(")%<W1E(&[Z;65R;R!P<F5C:7-A(&1E
M('-E<B!P96QO(&UE;F]S('5M+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ
M,S`T"FUS9VED(")4:&ES('-C<FEP="!M=7-T(&)E(')U;B!F<F]M('1H92!C
M;VUM86YD(&QI;F4N(@IM<V=S='(@(D5S=&4@7")S8W)I<'1<(B!T96T@<V5R
M(&5X96-U=&%D;R!A('!A<G1I<B!D92!U;6$@;&EN:&$@9&4@8V]M86YD;W,N
M(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4
M:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE
M<RXB"FUS9W-T<B`B17-T92!S97)V:61O<B!NXV\@8V]N<V5G=64@9&5S8V]M
M<')I;6ER(&%R<75I=F]S('II<"!O=2!G>FEP+B(*"B,Z(&QI8B](;W)D92]2
M96=I<W1R>2YP:'`Z,30W"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT
M;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(D5S=&4@<VES=&5M82!E;F-O;G1R
M82US92!D97-A8W1I=F%D;RXB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP
M.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G
M<W1R(")%<W1A('9A;&]R('1E;2!D92!S97(@=6T@;OIM97)O+B(*"B,Z('-E
M<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@
M=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B
M"FUS9W-T<B`B17-T82!J86YE;&$@=&5M(&1E('-E<B!C:&%M861A(&$@<&%R
M=&ER(&1E('5M82!J86YE;&$@9&4@3W#G]65S(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*;7-G:60@(E1H=6YD97(B"FUS
M9W-T<B`B5')O=F]A9&$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C(R"FUS9VED(")4:6-K971S(@IM<V=S='(@(D)I;&AE=&5S(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(T,C<*;7-G:60@(E1I;64B"FUS9W-T<B`B1&%T
M82](;W)A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P.`IM<V=I
M9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R(")396=U:6UE;G1O(%1E;7!O<F%L
M(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W"FUS9VED(")4:6UE(&9O<FUA
M="(*;7-G<W1R(")&;W)M871O(&1O('1E;7!O(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(U,S@*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@(E-E
M;&5CY^-O(&1A=&$O:&]R82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S
M='(@(E1I;6]R+4QE<W1E(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HR,CD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I
M=&QE(@IM<V=S='(@(E3M='5L;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB
M"FUS9W-T<B`B5.UT=6QO("AD:6-A*3HB"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`B4&%R82(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HV,C8*;7-G
M:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H
M92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@
M8VQI8VMI;F<N(@IM<V=S='(@(B(*(E!A<F$@<V5L96-C:6]N87(@;?IL=&EP
M;&]S(&ET96YS+"!C87)R96=U92!E;2!#;VYT<F]L("A00RD@;W4@0V]M;6%N
M9"`H36%C*2`B"B)E;G%U86YT;R!C;&EC87(N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Y.0IM<V=I9"`B5&]D87DB"FUS9W-T<B`B2&]J
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R(")4<F]C87(@
M1F]N=&4@2%1-3"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1O9V\B"FUS9W-T<B`B4F5P^F)L:6-A
M(%1O9V]L97-A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA=2(*;7-G<W1R(")4;W%U96QA
M=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#$*;7-G:60@
M(E1O;6]R<F]W(@IM<V=S='(@(D%M86YHXR(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O;F=A(@IM
M<V=S='(@(E)E:6YO(&1O(%1O;F=A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<W"FUS9VED(")4;W`B"FUS9W-T
M<B`B5&]P;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.3,*;7-G:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B36]L
M9'5R82!D92!T;W!O("A?=&]P*2(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV
M-3<*;7-G:60@(E1R86YS;&%T960B"FUS9W-T<B`B5')A9'5Z:61A<R(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I9"`B5')A;G-L871I;VYS
M(@IM<V=S='(@(E1R861UY_5E<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N9"!4
M;V)A9V\B"FUS9W-T<B`B5')I;F1A9&4@92!4;V)A9V\B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3<Y,0IM<V=I9"`B5')U92!O<B!F86QS92(*;7-G<W1R
M(")697)D861E:7)O(&]U(&9A;'-O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T<B`B,ZHB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,C<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$P"FUS9VED(")4=6YI<VEA(@IM<V=S='(@(E)E</IB;&EC82!D82!4=6[M
M<VEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q,0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(E)E</IB;&EC82!D82!4
M=7)Q=6EA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(E1U
M<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(E1U<F-O("A)4T\M.#@U.2TY
M*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C<@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(R.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3`*;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R(")4=7)Q=65M96YI
M<W3C;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C`@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G
M<W1R("));&AA<R!4=7)C87,@92!#86EC;W,B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C,S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S$*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B
M"FUS9W-T<B`B5'5V86QU(@H*(SH@;&EB+TAO<F1E+T-,22YP:'`Z,C8T"FUS
M9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`B17-C<F5V82!A('-U
M82!E<V-O;&AA.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-3<*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R("+-;F1I8V4@52Y6+CH@
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@(E523"(*;7-G<W1R(")54DPB
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED
M(")54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B
M"FUS9W-T<B`B55),(&1O('-E=2!R96QA=/-R:6\@9&4@97-T861O(&1O(&5N
M=FEO(&1E(%PB<V-R:7!T<UPB(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY-PIM<V=I9"`B55),.B(*;7-G<W1R(")54DPZ
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q,@IM<V=I9"`B56=A;F1A(@IM<V=S='(@(E)E</IB;&EC82!D;R!59V%N
M9&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,V(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$R"FUS9VED(")5:W)A:6YE(@IM<V=S='(@(E5C<N)N:6$B"@HC.B!L
M:6(O5D93+V9I;&4N<&AP.C,S-0IM<V=I9"`B56YA8FQE('1O(&%C8V5S<R!6
M1E,@9&ER96-T;W)Y+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&%C961E
M<B#@('!A<W1A(%9&4RXB"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP
M.CDV"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I
M;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R("(B"B).XV\@9F]I('!O<W/M
M=F5L(&%D:6-I;VYA<B!I;F9O<FUAY^-O(&1E('5T:6QI>F%D;W(@97AT<F$@
M87%U86YD;R!D82`B"B)S=6)S8W)IY^-O+B(*"B,Z(&QI8B]61E,O9G1P+G!H
M<#HS,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P
M97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(D[C;R!F
M;VD@<&]S<^UV96P@;75D87(@87,@<&5R;6ES<_5E<R!D;R!A<G%U:79O(%9&
M4R!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS,#@@;&EB+U9&4R]M
M=7-Q;"YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C
M:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@
M(D[C;R!F;VD@<&]S<^UV96P@;75D87(@87,@<&5R;6ES<_5E<R!D;R!A<G%U
M:79O(%9&4R`E<R\E<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-C<R"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N(@IM<V=S
M='(@(D[C;R!F;VD@<&]S<^UV96P@;75D87(@<&%R82`E<RXB"@HC.B!L:6(O
M2&]R9&4O075T:"]S<6PN<&AP.C,W,0IM<V=I9"`B56YA8FQE('1O(&-O;FYE
M8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!L
M:6=A<B!A;R!S97)V:61O<B!344PN(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<U
M-@IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S='(@
M(D[C;R!F;VD@<&]S<^UV96P@;&EG87(@=7-A;F1O(%-33"XB"@HC.B!L:6(O
M5D93+V9I;&4N<&AP.C$U."!L:6(O5D93+V9I;&4N<&AP.C$V,R!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HQ.#@*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3DS
M(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(P,0IM<V=I9"`B56YA8FQE('1O(&-O
M<'D@5D93(&9I;&4N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@8V]P:6%R
M(&\@87)Q=6EV;R!61E,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,P,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O
M<GD@7"(E<UPB+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&-R:6%R(&$@
M<&%S=&$@5D93(%PB)7-<(BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(W-R!L
M:6(O5D93+VUU<W%L+G!H<#HR-3@@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C0X
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(D[C;R!F;VD@<&]S<^UV96P@8W)I87(@82!P87-T82!61E,N(@H*(SH@
M;&EB+U9&4R]M=7-Q;"YP:'`Z,3(T"FUS9VED(")5;F%B;&4@=&\@8W)E871E
M(%9&4R!F:6QE+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&-R:6%R(&\@
M87)Q=6EV;R!61E,N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ.3@*;7-G:60@
M(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@(D[C
M;R!F;VD@<&]S<^UV96P@8W)I87(@=6T@87)Q=6EV;R!61E,@=F%Z:6\N(@H*
M(SH@;&EB+TAO<F1E+T-O;7!R97-S+W1A<BYP:'`Z-S8@;&EB+TAO<F1E+T-O
M;7!R97-S+V=Z:7`N<&AP.C<Y"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S
M<R!D871A+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&1E<V-O;7!R:6UI
M<B!O<R!D861O<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,C,V"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER
M96-T;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E
M;"!R96UO=F5R(%PB)7-<(BP@<&]I<R!A('!A<W1A(&[C;R!E<W3A('9A>FEA
M+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-SD@861M:6XO<&5R;7,O9&5L971E
M+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%PB)7-<(CH@)7,N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@<F5M;W9E
M<B!<(B5S7"(Z("5S+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C4T(&QI8B]6
M1E,O<W%L+G!H<#HS,30@;&EB+U9&4R]M=7-Q;"YP:'`Z,S$Q"B,Z(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C,R-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(*
M;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(')E;6]V97(@)7,L('!O:7,@82!P
M87-T82!NXV\@97-TX2!V87II82(*"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP
M.C,T,"!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS-#0*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B
M3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(&$@<&%S=&$@5D93(')E8W5R<VEV
M86UE;G1E+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C8P(&QI8B]61E,O;75S
M<6PN<&AP.C,R,B!L:6(O5D93+VUU<W%L+G!H<#HS,S4*(SH@;&EB+U9&4R]M
M=7-Q;"YP:'`Z,S0S(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,S-@IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").XV\@
M9F]I('!O<W/M=F5L(')E;6]V97(@82!P87-T82!61E,N(@H*(SH@;&EB+U9&
M4R]S<6PN<&AP.C,S.2!L:6(O5D93+W-Q;"YP:'`Z,S4Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N
M(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!A('!A<W1A(%9&
M4SH@)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C$W,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(&\@87)Q=6EV;R!61E,@
M7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C(V(&QI8B]61E,O<W%L
M+G!H<#HR,3`@;&EB+U9&4R]M=7-Q;"YP:'`Z,38W"B,Z(&QI8B]61E,O;75S
M<6PN<&AP.C$X,"!L:6(O5D93+VUU<W%L+G!H<#HQ.#<@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z,S<P"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,W.`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS9W-T<B`B3N-O(&9O
M:2!P;W-S[79E;"!R96UO=F5R(&\@87)Q=6EV;R!61E,N(@H*(SH@;&EB+U9&
M4R]S<6PN<&AP.C,R.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(D[C;R!F;VD@
M<&]S<^UV96P@<F5M;W9E<B!R96-U<G-I=F%M96YT93H@)7,N(@H*(SH@;&EB
M+U9&4R]F='`N<&AP.C<R,`IM<V=I9"`B56YA8FQE('1O(&1E=&5R;6EN92!C
M=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!D
M971E<FUI;F%R(&$@<&%S=&$@8V]R<F5N=&4N(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HV,#,*;7-G:60@(E5N86)L92!T;R!E>'1R86-T(&-E
M<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!E
M>'1R86ER(&]S('!O<FUE;F]R97,@9&\@8V5R=&EF:6-A9&\B"@HC.B!L:6(O
M3F5T+TE-4U`N<&AP.C0U,2!L:6(O3F5T+TE-4U`O075T:"YP:'`Z,3$W"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET
M:6]N(&]F("5S+B(*;7-G<W1R("));7!O<W/M=F5L(&QE<B!A(&1E9FEN:>?C
M;R!D92`E<RXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$R.2!L:6(O5D93+V9I
M;&4N<&AP.C$S-"!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-3@*(SH@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z,38S"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@
M9FEL92XB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!M;W9E<B!O(&%R<75I
M=F\@5D93+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S
M='(@(D[C;R!F;VD@<&]S<^UV96P@86)R:7(@;R!A<G%U:79O(%9&4R!<(B5S
M7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR,#4@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,3(R(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$R-0IM<V=I9"`B56YA
M8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N(@IM<V=S='(@(D[C
M;R!F;VD@<&]S<^UV96P@86)R:7(@;R!A<G%U:79O(%9&4R!P87)A(&5S8W)I
M=&$N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HV-R!L:6(O5D93+W-Q;%]F:6QE
M+G!H<#HW,@IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S
M='(@(D[C;R!F;VD@<&]S<^UV96P@86)R:7(@;R!A<G%U:79O(%9&4RXB"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HT-0IM<V=I9"`B56YA
M8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R(").XV\@
M9F]I('!O<W/M=F5L(&%B<FER(&\@87)Q=6EV;R!C;VUP<FEM:61O+B(*"B,Z
M(&QI8B](;W)D92]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`IM<V=I9"`B
M56YA8FQE('1O(')E860@9FEL93H@(@IM<V=S='(@(D[C;R!C;VYS:6=O(&QE
M<B!O(&%R<75I=F\Z("(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-3DR"FUS9VED
M(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S
M='(@(D[C;R!F;VD@<&]S<^UV96P@;&5R(&$@<&%S=&$@=F9S<F]O="XB"@HC
M.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$P-C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L
M9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@
M<F5N;VUE87(@)7,@8V]M;R`E<SH@82!P87-T82!D92!D97-T:6YO(&KA(&5X
M:7-T92(*"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(X-0IM<V=I9"`B56YA
M8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").XV\@9F]I
M('!O<W/M=F5L(')E;F]M96%R(&$@<&%S=&$@5D93+B(*"B,Z(&QI8B]61E,O
M<W%L+G!H<#HR-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E
M;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S
M[79E;"!R96YO;65A<B!A('!A<W1A(%9&4SH@)7,N(@H*(SH@;&EB+U9&4R]F
M='`N<&AP.C(X,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N
M86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E
M;"!R96YO;65A<B!O(&%R<75I=F\@5D93(%PB)7-<(BXB"@HC.B!L:6(O5D93
M+V9I;&4N<&AP.C4S,R!L:6(O5D93+VUU<W%L+G!H<#HR,CD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RXB
M"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!R96YO;65A<B!O(&%R<75I=F\@
M5D93("5S+R5S+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HR-#4@;&EB+U9&4R]M
M=7-Q;"YP:'`Z,C$S(&QI8B]61E,O;75S<6PN<&AP.C0U,@HC.B!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HR-S<@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,CDS"FUS
M9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R(").XV\@
M9F]I('!O<W/M=F5L(')E;F]M96%R(&%R<75I=F\@5D93+B(*"B,Z(&QI8B]6
M1E,O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS9VED(")5;F%B;&4@=&\@
M<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!E>&5C
M=71A<B`G;6MI<V]F<R<N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS
M=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7
M;W)D(&1O8W5M96YT(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@8V]N=F5R
M=&5R(&5S=&4@9&]C=6UE;G1O(%=O<F0B"@HC.B!L:6(O5D93+V9T<"YP:'`Z
M,3(R(&QI8B]61E,O9G1P+G!H<#HQ,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3N-O
M(&9O:2!P;W-S[79E;"!E<V-R979E<B!A<G%U:79O(%9&4R!<(B5S7"(N(@H*
M(SH@;&EB+U9&4R]F:6QE+G!H<#HQ,3(*;7-G:60@(E5N86)L92!T;R!W<FET
M92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(D[C;R!F;VD@
M<&]S<^UV96P@97-C<F5V97(@;R!A<G%U:79O(%9&4R`H8V]P>2@I(&9A;&AO
M=2DN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR,#D@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,3,P(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$S-0IM<V=I9"`B56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@(D[C;R!C;VYS
M:6=O(')E;6]V97(@)R5S)SH@)7,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S
M='(@(E-U8FQI;FAA9&\B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHV
M"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B1&5S9F%Z97(@06QT97)A
MY_5E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@
M(D1E<V9A>B!A('-U82#Z;'1I;6$@86/GXV\B"@HC.B!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,C(S(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS.3`*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S
M97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@(E)E<W!O<W1A(&EN97-P
M97)A9&$@9&\@<V5R=FED;W(@;F$@8V]N97CC;SH@(@H*(SH@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.2!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S0Q"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS-S@@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-`IM
M<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM
M<V=S='(@(E)E<W!O<W1A(&EN97-P97)A9&$@9&\@<V5R=FED;W(@83H@(@H*
M(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C0*;7-G
M:60@(E5N9FEL960B"FUS9W-T<B`B4V5M(&-A=&5G;W)I82(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DS"FUS9VED(")5;FEC;V1E("A55$8M."DB"FUS
M9W-T<B`B56YI8V]D92`H551&+3@I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(E5N:71E9"!!<F%B($5M
M:7)A=&5S(@IM<V=S='(@(D5M:7)A9&]S(,%R86)E<R!5;FED;W,B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,X(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,S4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G
M:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(E)E:6YO(%5N:61O(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,PIM
M<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R(")%<W1A9&]S(%5N:61O<R!D
M82!!;>ER:6-A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L
M>6EN9R!)<VQA;F1S(@IM<V=S='(@(DEL:&%S($UE;F]R97,@1&ES=&%N=&5S
M(&1O<R!%<W1A9&]S(%5N:61O<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HV,2!L:6(O0FQO8VLO;65T87(N<&AP.C<Q"FUS9VED(")5;FET
M<R(*;7-G<W1R(")5;FED861E<R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C0Q."!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3D*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-3@*;7-G:60@(E5N:VYO=VXB"FUS
M9W-T<B`B1&5S8V]N:&5C:61O(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%022!-
M97-S86=E($E$*2XB"FUS9W-T<B`B87!I;7-G:60@*$E$(&1E($UE;G-A9V5M
M(&1E($%022DN(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.3D*;7-G:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E
M($E$*2XB"FUS9W-T<B`B8VQI;7-G:60@9&5S8V]N:&5C:61O("A)1"!D92!-
M96YS86=E;2!D92!#;&EE;G1E*2XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,34P,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;FMN;W=N(&-O;6UA;F0Z("5S
M(@IM<V=S='(@(D-O;6%N9&\@9&5S8V]N:&5C:61O.B`E<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#8*;7-G:60@(E5N:VYO=VX@;&]C
M871I;VX@<')O=FED960N(@IM<V=S='(@(D9O:2!F;W)N96-I9&$@=6UA(&QO
M8V%L:7IAY^-O(&1E<V-O;FAE8VED82XB"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O
M<B!P87-S=V]R9"XB"FUS9W-T<B`B3F]M92!D92!U=&EL:7IA9&]R(&]U('!A
M;&%V<F$M<&%S<V4@97)R861O<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B56YL:6YK('1H
M92!C=7)R96YT(&5L96UE;G0B"FUS9W-T<B`B4F5M;W9E<B!L:6=AY^-O(&1O
M(&5L96UE;G1O(&-O<G)E;G1E(@H*(SH@;&EB+TAO<F1E+TED96YT:71Y+G!H
M<#HR.38*;7-G:60@(E5N;F%M960B"FUS9W-T<B`B4V5M(&YO;64B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y"FUS9VED
M("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#
M;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A
M<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO
M>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S
M8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*(E!O
M<B!R87KU97,@9&4@<V5G=7)A;N=A+"!<(G-C<FEP='-<(B!S96T@<')I=FEL
MZ6=I;R!NXV\@<&]D96T@86-E9&5R(&$@(@HB0V]R=&%R+T-O<&EA<B]#;VQA
M<B!P<F]G<F%M871I8V%M96YT92X@0V%R<F5G=64@96T@3TL@<&%R82!V97(@
M=6UA(&YO=&$@(@HB=.EC;FEC82!E;2!M;WII;&QA+F]R9R!Q=64@;&AE(&UO
M<W1R87+A(&-O;6\@875T;W)I>F%R('5M(%PB<V-R:7!T7"(@82`B"B)A8V5D
M97(@86]S(')E8V]R=&5S+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM
M<V=S='(@(E)E;6]V97(@8V]L;W)AY^-O(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HV.#8@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HY,C8*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HY,S(*;7-G:60@(E5N<W5P
M<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R(")%>'1E;G/C;R!NXV\@4W5P;W)T
M861A(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8U-PIM<V=I9"`B56YT<F%N
M<VQA=&5D(@IM<V=S='(@(E!O<B!T<F%D=7II<B(*"B,Z(&%D;6EN+W!E<FUS
M+V5D:70N<&AP.C$P-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$X,PHC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D871E
M(@IM<V=S='(@(DUO9&EF:6-A<B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E("5S
M(@IM<V=S='(@(D%C='5A;&EZ87(@)7,B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C0S"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R
M(")!8W1U86QI>F%R('5T:6QI>F%D;W(B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C$S-R!A9&UI;B]P97)M<R]E9&ET+G!H<#HR,3<@<V5R=FEC97,O<VAA<F5S
M+V5D:70N<&AP.C(S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB
M)7-<(BXB"FUS9W-T<B`B7"(E<UPB(&%C='5A;&EZ861O+B(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HQ,#DR('!O+W1R86YS;&%T:6]N+G!H<#HQ,C,P"B,L
M('!H<"UF;W)M870*;7-G:60@(E5P9&%T:6YG("5S(&AE;'`@9FEL92!F;W(@
M)7,N(@IM<V=S='(@(D%C='5A;&EZ86YD;R!A<G%U:79O(&1E(&%J=61A("5S
M('!A<F$@)7,N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#$*;7-G
M:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S='(@(EPB4V-R:7!T
M7"(@9&4@86-T=6%L:7IAY^-O(')E;6]V:61O+B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ.#$@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$X,@IM<V=I9"`B57!L;V%D(@IM<V=S='(@(E5P;&]A9"(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#D*;7-G:60@(E5P;&]A9&5D(&%L;"!A
M<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R
M(")#87)R96=A9&]S(&YO('-E<G9I9&]R('1O9&]S(&]S(&%R<75I=F]S(&1E
M(&EN<W1A;&'GXV\@9&4@87!L:6-AY_5E<RXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(P"FUS9VED(")5
M<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@(DQE=')A<R!L871I;F%S(&5M
M(&UA:?IS8W5L87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB
M97)S(@IM<V=S='(@(D[Z;65R;W,@<F]M86YO<R!E;2!M86GZ<V-U;&%S(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R(")297#Z8FQI8V$@3W)I96YT86P@
M9&\@57)U9W5A:2(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HS-2!P;R]T<F%N
M<VQA=&EO;BYP:'`Z.3(@<&\O=')A;G-L871I;VXN<&AP.CDS"FUS9VED(")5
M<V%G93HB"FUS9W-T<B`B571I;&EZ8>?C;SHB"@HC.B!L:6(O2&]R9&4O4')E
M9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`B57-A<B!O($-O<G)E;G1E.B`E
M<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G
M:60@(E5S92!34TPB"FUS9W-T<B`B57-A<B!34TPN(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$R-`IM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@
M:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B(@HB57-A
M<B!S92!O(&YO;64@9&4@=71I;&EZ861O<B!O=2!A('!A;&%V<F$M<&%S<V4@
M9F]R96T@9&EF97)E;G1E<R!N;R!S97)V:61O<B`B"B))35-0+B(*"B,Z(&QI
M8B](;W)D92]296=I<W1R>2YP:'`Z-C$X"B,L('!H<"UF;W)M870*;7-G:60@
M(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+B(*;7-G<W1R(")5
M=&EL:7IA9&]R("5S(&[C;R!E<W3A(&%U=&]R:7-A9&\@<&%R82`E<RXB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S97(@061M:6YI<W1R871I
M;VXB"FUS9W-T<B`B061M:6YI<W1R8>?C;R!D92!5=&EL:7IA9&]R97,B"@HC
M.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C(U,0IM<V=I9"`B57-E<B!/<'1I
M;VYS(@IM<V=S='(@(D]PY_5E<R!D;R!5=&EL:7IA9&]R(@H*(SH@<VEG;G5P
M+G!H<#HV,@IM<V=I9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T<B`B4F5G
M:7-T;R!D92!5=&EL:7IA9&]R97,B"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED
M(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI
M<R!S:71E+B(*;7-G<W1R(")/(%)E9VES=&\@9&4@571I;&EZ861O<F5S(&5S
M=.$@:6YA8W1I=F\N(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3<R(&QI
M8B](;W)D92]097)M<R]522YP:'`Z,C0V"FUS9VED(")5<V5R('!E<FUI<W-I
M;VYS(@IM<V=S='(@(E!E<FUI<W/U97,@9&\@=71I;&EZ861O<B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#(*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-B!L:6(O3F5T+U--
M4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.CDX"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,3DX('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C,S"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-C@@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE
M(@IM<V=S='(@(DYO;64@9&4@571I;&EZ861O<B(*"B,Z(&QI8B](;W)D92]!
M=71H+U-I9VYU<"YP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E5S97)N
M86UE(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B3R!.;VUE(&1E
M(%5T:6QI>F%D;W(@7"(E<UPB(&KA(&5X:7-T92XB"@HC.B!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R
M(").;VUE(&1E(%5T:6QI>F%D;W(Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO
M8FEL92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R(").;VUE(&1E
M(%5T:6QI>F%D;W(Z("(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,C$Y
M"FUS9VED(")5<V5R<R(*;7-G<W1R(")5=&EL:7IA9&]R97,B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T
M:&4@<WES=&5M.B(*;7-G<W1R(")5=&EL:7IA9&]R97,@9&\@<VES=&5M83HB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0R(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$T"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@(E)E</IB;&EC82!D;R!5
M>F)E<75I<W3C;R(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3`Q(&QI8B]61E,O
M9FEL92YP:'`Z,3@X"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X
M:7-T+B(*;7-G<W1R(")!('!A<W1A(%9&4R!NXV\@97AI<W1E+B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,3@*;7-G:60@(E9A8V%T:6]N(@IM
M<V=S='(@(D%U<^IN8VEA(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@V-@IM
M<V=I9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R
M(")!<R!L;V-A;&EZ8>?U97,@=N%L:61A<R!E;F-O;G1R861A<R!I;F-L=65M
M.B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C,X"FUS9VED(")6
M86QI9&ET>2(*;7-G<W1R(")686QI9&%D92XB"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3DW(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C4U"FUS9VED(")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W
M+B(*;7-G<W1R(")686QO<B!E;2!M:6YU=&]S(&$@<&%R=&ER(&1E<W1E(&EN
M<W1A;G1E+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX-38@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$Q-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@
M;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@(E9A;&]R
M(&5X8V5D92!O(&-O;7!R:6UE;G1O(&WA>&EM;R!D92`E<RXB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C(T-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(V-R!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C,Q-0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,CDR-PIM<V=I9"`B5F%L=65S(@IM<V=S='(@(E9A;&]R97,B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C$Q,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$X-PIM
M<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(E!O<W/M=F5L
M('9A;&]R97,@82!E<V-O;&AE<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E9A;G5A='4B"FUS9W-T
M<B`B5F%N=6%T=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,S(*;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@(E9A<FGA=F5L(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(T-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-0IM<V=I
M9"`B5F5N97IU96QA(@IM<V=S='(@(E9E;F5Z=65L82(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED(")697)I9FEC871I;VX@9F%I
M;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET
M:"XB"FUS9W-T<B`B5F5R:69I8V'GXV\@9F%L:&]U("T@97-T82!M96YS86=E
M;2!P;V1E('1E<B!S:61O(&%D=6QT97)A9&$N(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HW,#`*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`B5F5R
M<^-O(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(P-0IM<V=I9"`B
M5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(D-O;G1R;VQO(&1E(%9E<G/U97,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@S"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G<W1R(")!;&EN:&%M
M96YT;R!697)T:6-A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T
M<B`B0V%LYV\@5F5R=&EC86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`B
M5F5R=&EC86PZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-S`*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R(")-=6ET;R!!;'1O
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q-@IM<V=I9"`B5FEE="!.86TB"FUS9W-T<B`B4F5P^F)L:6-A(%-O8VEA
M;&ES=&$@9&\@5FEE=&YA;64B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y
M-`IM<V=I9"`B5FEE=&YA;65S92`H5DE30TE)*2(*;7-G<W1R(")6:65T;F%M
M:71A("A625-#24DI(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP
M.CDU.0HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(E9I
M<W5A;&EZ87(@)7,B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS"FUS9VED
M(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S='(@(E9E<B!U;6$@
M<.%G:6YA(&5X=&5R;F$B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP
M:'`Z.#$X"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T
M<B`B5FES=6%L:7IA<B!C;VUO("5S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(T-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N
M9',L($)R:71I<V@B"FUS9W-T<B`B26QH87,@5FER9V5N<R!"<FETXFYI8V%S
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B26QH
M87,@5FER9V5N<R!!;65R:6-A;F%S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR,#D*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B5FES:6)I;&ED861E
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,0IM<V=I9"`B
M5FES:6)I;&ET>3H@(@IM<V=S='(@(E9I<VEB:6QI9&%D93H@(@H*(SH@;&EB
M+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-`IM<V=I9"`B5F]D
M869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B5F]D869O;F4@273A;&EA
M('9I82!33510(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]M;V)I;&4N<&AP.C,V"FUS9VED(")705).(@IM<V=S='(@(D%625,B"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E
M<RXB"FUS9W-T<B`B051%3L?#3R$A(2!214U/5D$@3R!<(E-#4DE05%PB($U!
M3E5!3$U%3E1%($1%("5S+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M-3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA
M(@IM<V=S='(@(E=A;&QI<R!E($9U='5N82(*"B,Z(&QI8B](;W)D92].;W1I
M9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0IM<V=I9"`B5V%R;FEN
M9R(*;7-G<W1R(")!=FES;R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ-#4@
M<&\O=')A;G-L871I;VXN<&AP.C8X,2!P;R]T<F%N<VQA=&EO;BYP:'`Z-S$Q
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW,C4@<&\O=')A;G-L871I;VXN<&AP
M.C$P-C`@<&\O=')A;G-L871I;VXN<&AP.C$P-CD*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C$P-S<@<&\O=')A;G-L871I;VXN<&AP.C$P.#<@<&\O=')A;G-L
M871I;VXN<&AP.C$P.3<*(SH@<&\O=')A;G-L871I;VXN<&AP.C$Q,#<@<&\O
M=')A;G-L871I;VXN<&AP.C$Q,3,@<&\O=')A;G-L871I;VXN<&AP.C$R,S4*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C$R-#4@<&\O=')A;G-L871I;VXN<&AP
M.C$R-3$@<&\O=')A;G-L871I;VXN<&AP.C$R-S$*;7-G:60@(E=A<FYI;F<Z
M("(*;7-G<W1R(")!=FES;SH@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B-*HB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H
M97(@1F]R96-A<W0B"FUS9W-T<B`B4')E=FESXV\@9&\@5&5M<&\B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#$U"FUS9VED(")796%T:&5R
M(&1A=&$@<')O=FED960@8GDB"FUS9W-T<B`B1&%D;W,@;65T96]R;VSS9VEC
M;W,@9F]R;F5C:61O<R!P;W(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DR
M"FUS9VED(")796%T:&5R+F-O;2(*;7-G<W1R(")796%T:&5R+F-O;2(*"B,Z
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED(")796(B"FUS9W-T<B`B
M5V5B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W-@IM<V=I9"`B
M5V5B(%-I=&4B"FUS9W-T<B`B4.%G:6YA(@H*(SH@;&EB+TAO<F1E+TUA:6YT
M96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM<V=S='(@(E-E;6%N86QM
M96YT92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED
M(")796QC;VUE(@IM<V=S='(@(D)E;2UV:6YD82AO*2(*"B,Z('1E;7!L871E
M<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHU,PHC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S
M='(@(D)E;2UV:6YD82AO*2!A("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO
M8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H
M<"UF;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM<V=S='(@(D)E;2UV:6YD
M82AO*2P@)7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-0IM<V=I9"`B
M5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B3V-I9&5N=&%L("A)4T\M
M.#@U.2TQ*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS9VED(")7
M97-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B3V-I9&5N=&%L("A)4T\M
M.#@U.2TQ-2DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B4V%A
M<F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(Y"B,L('!H<"UF;W)M
M870*;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@
M869T97(@;&]G:6X_(@IM<V=S='(@(E%U92!A<&QI8V'GXV\@9&5V92!O("5S
M(&UO<W1R87(@87#S<R!A(&5N=')A9&$_(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z,C$*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM:71E<B!C
M:&%R86-T97(_(@IM<V=S='(@(E%U86P@Z2!O(&-A<F%C=&5R92!D96QI;6ET
M861O<C\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR-`IM<V=I
M9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R(")1=6%L
M(.D@;R!C87)A8W1E<F4@9&4@8VET8>?C;S\B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E<R(*;7-G<W1R(")1=64@9F%S
M97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S"FUS9VED(")7:&EC
M:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N
M(@IM<V=S='(@(E%U92!<(G!L=6=I;G-<(B!A8W1I=F%R('!A<F$@82!%9&GG
MXV\@4FEC82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@T"FUS9VED(")7:61T:"(*;7-G<W1R("),87)G=7)A
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,C0*;7-G:60@(E=I9'1H(&EN
M($-34R!U;FET<R(*;7-G<W1R("),87)G=7)A(&5M('5N:61A9&5S($-34R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S
M(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@(DQA<F=U<F$@9&\@
M365N=2`E<R#@(&5S<75E<F1A("AT96T@969E:71O(&YA('!R\WAI;6$@96YT
M<F%D82DZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*;7-G<W1R("),
M87)G=7)A(&1A('1A8F5L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET(@IM<V=S='(@
M(E5N:61A9&4@9&4@;&%R9W5R82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED(")7:61T:#HB"FUS9W-T<B`B
M3&%R9W5R83HB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8X"FUS
M9VED(")7:6MI(@IM<V=S='(@(E=I:VDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C@X(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8U"FUS9VED(")7:6YD(@IM<V=S='(@(E9E;G1O(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E=I
M;F0@16%R;'DB"FUS9W-T<B`B5F5N=&\@36%T:6YA;"(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z.#`*;7-G:60@(E=I;F0@<W!E960@:6X@:VYO=',B"FUS
M9W-T<B`B5F5L;V-I9&%D92!D;R!V96YT;R!E;2!N\W,B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$U-@IM<V=I9"`B5VEN9#HB"FUS9W-T<B`B5F5N=&\Z
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,`IM<V=I9"`B
M5VEN9#H@(@IM<V=S='(@(E9E;G1O.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-C0*;7-G:60@(E=I<V1O;2(*;7-G<W1R(")386)E9&]R:6$B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@R"FUS9VED(")7:7-H;&ES
M=',B"FUS9W-T<B`B3&ES=&%S(&1E($1E<V5J;W,B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-C4*;7-G:60@(E=O<FLB"FUS9W-T<B`B5')A8F%L:&\B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-"!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-`IM<V=I9"`B5V]R:R!!
M9&1R97-S(@IM<V=S='(@(D5N9&5R9>=O("A%;7!R96=O*2(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DR"FUS9VED(")7;W)K(%!H
M;VYE(@IM<V=S='(@(E1E;&5F;VYE("A%;7!R96=O*2(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HQ,38Y"B,L('!H<"UF;W)M870*;7-G:60@(E=R:71I;F<@
M=7!D871E9"!H96QP(&9I;&4@=&\@)7,N(@IM<V=S='(@(D5S8W)E=F5N9&\@
M87)Q=6EV;R!D92!A:G5D82!A8W1U86QI>F%D;R!P87)A("5S+B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,S$*;7-G:60@(E@M4F5F(@IM<V=S
M='(@(E)E9F5RZFYC:6%S(&-R=7IA9&%S(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT
M<R(*;7-G<W1R(")297-T<FGG]65S($+A<VEC87,@6#4P.78S(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3(*;7-G:60@(E@U,#EV,R!%>'1E
M;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B571I;&EZ8>?C;R!D92!#:&%V92!%
M>'1E;F1I9&$@6#4P.78S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU.30*;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64B
M"FUS9W-T<B`B3F]M92!!;'1E<FYA=&EV;R!D92!3=6IE:71O(%@U,#EV,R(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y
M=C,@4W5B:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R("))9&5N=&EF:6-A
M9&]R($-H879E(&1E(%-U:F5I=&\@6#4P.78S(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HV.#(*;7-G:60@(E@U,#EV,R!E>'1E;G-I;VYS(@IM
M<V=S='(@(D5X=&5N<_5E<R!8-3`Y=C,B"@HC.B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHU,`IM<V=I9"`B65DB"FUS9W-T<B`B04$B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@V(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,C<*;7-G:60@(EE965DB"FUS9W-T<B`B04%!02(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#`Q"FUS
M9VED(")986AO;R$@;6%P(@IM<V=S='(@(DUA<&$@66%H;V\A(@H*(SH@;&EB
M+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S
M='(@(D%N=6%L;65N=&4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4R
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#<*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")996UE;B(*;7-G<W1R("))Z6UE
M;B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX.#4*
M;7-G:60@(EEE<R(*;7-G<W1R(")3:6TB"@HC.B!T96UP;&%T97,O;6%I;G1E
M;F%N8V4O86=R965M96YT7V)O='1O;2YI;F,Z-@IM<V=I9"`B665S+"!)($%G
M<F5E(@IM<V=S='(@(E-I;2P@0V]N8V]R9&\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R"FUS9VED(")9;W4@87)E(&EN
M(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A
M8VL@=&\@5UE325=91RXB"FUS9W-T<B`B(@HB17-TX2!E;2!-3T1/(&1E(%1%
M6%0N("!5<V4@;R!B;W3C;R!;/#Y=('!A<F$@=')O8V%R('!A<F$@;R!M;V1O
M(%9)4U5!3"XB"@HC.B!L:6(O2&]R9&4N<&AP.C$R.3<*;7-G:60@(EEO=2!A
M<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(D[C;R!E<W3A(&%U=&5N
M=&EC861O+B(*"B,Z(&QI8B](;W)D92])9&5N=&ET>2YP:'`Z,S`R"FUS9VED
M(")9;W4@8V%N(&YO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R
M(&9U;&P@;F%M92XB"FUS9W-T<B`B3N-O('!O9&4@=&5R(&\@8V%R86-T97)E
M("=<7"<@;F\@<V5U(&YO;64@8V]M<&QE=&\N(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$X-38@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-S8*;7-G:60@(EEO
M=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T
M<B`B3N-O(&EN=')O9'5Z:74@=6T@96YD97)EYV\@9&4@8V]R<F5I;R!E;&5C
M='+S;FEC;R!VX6QI9&\N(@H*(SH@;&EB+TAO<F1E+T1A=&$N<&AP.C(W,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE
M;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I
M;F<@9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R("(B"B).XV\@;6%P96]U(&YE
M;FAU;2!C86UP;R!D;R!A<G%U:79O(&EM<&]R=&%D;R!P87)A(&]S(&-A;7!O
M<R!C;W)R97-P;VYD96YT97,@(@HB96T@)7,N(@H*(SH@;&EB+TAO<F1E+T%U
M=&@N<&AP.CDR,PIM<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*
M;7-G<W1R(")!8V%B;W4@9&4@<V%I<BXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3(V,0IM<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C
M96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L
M("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N
M(@IM<V=S='(@(B(*(E1E;2!D92!I;G1R;V1U>FER('5M(&[Z;65R;R!D92!T
M96QE;?-V96P@=N%L:61O+"!S\R!C;VT@9.UG:71O<RP@;6%S(&-O;2!U;2`B
M"B(G*R<@;W!C:6]N86P@<&%R82!O('!R969I>&\@:6YT97)N86-I;VYA;"XB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$X.`IM<V=I9"`B66]U(&AA=F4@
M=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`B5&5M(&1E(&EN=')O
M9'5Z:7(@=6T@=F%L;W(@=N%L:61O+B(*"B,Z(&QI8B](;W)D92]!=71H+U-I
M9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4
M<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(B(*(E1E;2!D
M92!C;VYF:6=U<F%R('5M(&UE8V%N:7-M;R!BX7-I8V\@<&%R82!$871A5')E
M92!S92!Q=6ES97(@=7-A<B`B"B)3=6)S8W)IY_5E<R(*"B,Z(&QI8B](;W)D
M92YP:'`Z-#,Q"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C
M:V5N9"XB"FUS9W-T<B`B5&5M(&1E(&-O;F9I9W5R87(@=6T@;65C86YI<VUO
M(&)A<V4@<&%R82!O(%9&4RXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHQ,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L
M96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N(@IM
M<V=S='(@(D1E=F4@9&5S8W)E=F5R(&\@<')O8FQE;6$@86YT97,@9&4@96YV
M:6%R(&\@<F5L873S<FEO+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H92!5
M4DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*;7-G<W1R(")496T@9&4@
M:6YT<F]D=7II<B!O(%523"!D;R!R96-U<G-O('%U92!E<W1A(&QI9V'GXV\@
M<V4@<F5F97)E(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*
M;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E
M9"XB"FUS9W-T<B`B5&5M(&1E('-E;&5C8VEO;F%R('5M('-E<G9I9&]R(&$@
M<F5M;W9E<BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*;7-G:60@(EEO=2!M
M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@
M(D1E=F4@97-P96-I9FEC87(@;R!U=&EL:7IA9&]R(&$@;&EM<&%R+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A
M('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B1&5V92!E<W!E8VEF:6-A
M<B!O(&YO;64@9&\@=71I;&EZ861O<B!A(')E;6]V97(N(@H*(SH@861M:6XO
M=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX
M"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N
M(@IM<V=S='(@(E1E;2!D92!E<W!E8VEF:6-A<B!O(&YO;64@9&\@=71I;&EZ
M861O<B!A(&%D:6-I;VYA<BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#8*;7-G
M:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB
M"FUS9W-T<B`B5&5M(&1E(&5S<&5C:69I8V%R(&\@=71I;&EZ861O<B!A(&%C
M='5A;&EZ87(N(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3,X
M"FUS9VED(")9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O
M<FTN(@IM<V=S='(@(E1E;2!D92!E<W!E8VEF:6-A<B!A(&%CY^-O(&$@9&5S
M96UP96YH87(N(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E
M<BYP:'`Z-S(*;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@
M;F%M92XB"FUS9W-T<B`B5&5M(&1E(&EN=')O9'5Z:7(@=6T@;F]V;R!N;VUE
M(&1E(&-A=&5G;W)I82XB"@HC.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY
M7W-M='`N<&AP.C<S"FUS9VED(")9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET
M86QI86X@<&AO;F4@;G5M8F5R(@IM<V=S='(@(E1E;2!D92!F;W)N96-E<B!U
M;2!N^FUE<F\@9&4@=&5L969O;F4@:71A;&EA;F\B"@HC.B!L:6(O2&]R9&4O
M075T:"YP:'`Z.3$Q"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S
M<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R
M(")!('-U82!S97-SXV\@)7,@97AP:7)O=2X@4&]R(&9A=F]R(&5N=')E(&1E
M(&YO=F\N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*
M;7-G:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R(")/('-E=2!%;F1E
M<F7G;R!D92!#;W)R96EO($5L96-T<O-N:6-O.B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR,#0*;7-G:60@(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS
M9W-T<B`B3R!S974@96YD97)EYV\@7")$93I<(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S0@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C@R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M.0IM<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R(")!('-U82!);F9O
M<FUAY^-O(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDQ-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG
M960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O
M("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A
M:6XN(@IM<V=S='(@(B(*(D\@<V5U(&5N9&5R9>=O($E0('!A<F5C92!T97(@
M;75D861O(&1E<V1E(&\@:6[M8VEO(&1A('-E<W/C;R`E<RX@4&%R82`B"B)G
M87)A;G1I<B!A('-U82!S96=U<F%NYV$L(&1E=F4@875T96YT:6-A<BUS92!D
M92!N;W9O+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S
M"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`B3R!3974@3F]M92(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHY"FUS9VED("(B"B)9;W5R
M(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I
M;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D
M(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@HB3R!S974@;65C
M86YI<VUO(&1E(&%U=&5N=&EC8>?C;R!NXV\@<W5P;W)T82!A9&GGXV\@9&4@
M=71I;&EZ861O<F5S(&]U(&5S=&$@(@HB;W#GXV\@9F]I(&1E<V%C=&EV861A
M('!O<B!A;&=U;2!O=71R;R!M;W1I=F\N(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;F]L:7-T+FEN8SHY"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T
M:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O
M<B!T:&4@9F5A='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O
M=&AE<B!R96%S;VXN(@IM<V=S='(@(B(*(D\@<V5U(&UE8V%N:7-M;R!D92!A
M=71E;G1I8V'GXV\@;N-O('-U<&]R=&$@;&ES=&%G96T@9&4@=71I;&EZ861O
M<F5S(&]U(&5S=&$@(@HB;W#GXV\@9F]I(&1E<V%C=&EV861A('!O<B!A;&=U
M;2!O=71R;R!M;W1I=F\N(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDQ.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&)R;W=S97(@87!P96%R<R!T
M;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S
M('-E<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU
M<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(D\@<V5U(&YA=F5G861O<B!P
M87)E8V4@=&5R(&UU9&%D;R!D97-D92!O(&EN[6-I;R!D82!S97-SXV\@)7,N
M(%!A<F$@9V%R86YT:7(@(@HB82!S=6$@<V5G=7)A;N=A+"!D979E(&%U=&5N
M=&EC87(M<V4@9&4@;F]V;RXB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU
M,`IM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F
M96%T=7)E+B(*;7-G<W1R(")/('-E=2!N879E9V%D;W(@;N-O('-U<&]R=&$@
M97-T82!F=6YC:6]N86QI9&%D92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]P<FEN="YJ<SHT,@IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T
M('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M
M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*(D\@<V5U(&YA=F5G
M861O<B!NXV\@<W5P;W)T82!E<W1A(&]PY^-O(&1E(&EM<')E<W/C;RX@4')E
M<W-I;VYE($-O;G1R;VPO(@HB0V]M;6%N9"`K(%`@<&%R82!I;7!R:6UI<BXB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0Y"FUS9VED(")9;W5R(&-U
M<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R(")&=7-O(&AO<N%R:6\@86-T=6%L
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3`*;7-G:60@(EEO=7(@
M9&5F875L="!I9&5N=&ET>3HB"FUS9W-T<B`B261E;G1I9&%D92!P861RXV\Z
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,PIM<V=I9"`B66]U<B!F
M=6QL(&YA;64Z(@IM<V=S='(@(DYO;64@8V]M<&QE=&\B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,30U"FUS9VED("(B"B)9;W5R(&=E='1E>'0@=F5R<VEO
M;B!I<R!T;V\@;VQD(&%N9"!D;V5S(&YO="!S=7!P;W)T(%!(4"!N871I=F5L
M>2Y<;B(*(DYO="!A;&P@<W1R:6YG<R!W:6QL(&)E(&5X=')A8W1E9"XB"FUS
M9W-T<B`B(@HB02!S=6$@=F5R<^-O(&1O(&=E='1E>'0@Z2!D96UA<VEA9&\@
M86YT:6=A+"!NXV\@<W5P;W)T86YD;R!02%`@9&4@9F]R;6$@(@HB;F%T:79A
M+B!.96T@=&]D87,@87,@8V%D96EA<R!D92!C87)A8W1E<F5S('-E<N-O(&5X
M=')A[61A<RXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@
M:7,Z("5S(@IM<V=S='(@(D$@<W5A(&YO=F$@<&%L879R82UP87-S92!P87)A
M("5S(.DZ("5S(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ-30*;7-G
M:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U
M<F%T:6]N(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`B07,@<W5A<R!O<.?U
M97,@9F]R86T@86QT97)A9&%S(&%TZ2!A;R!F:6YA;"!D97-T82!S97-SXV\N
M(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@
M;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS9W-T<B`B07,@<W5A<R!O
M<.?U97,@9F]R86T@86-T=6%L:7IA9&%S+B(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!B965N
M(')E<V5T(@IM<V=S='(@(D$@<W5A('!A;&%V<F$M<&%S<V4@9F]I(')E8W)I
M861A(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@
M(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@
M96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*
M;7-G<W1R("(B"B)!('-U82!P86QA=G)A+7!A<W-E(&9O:2!R96-R:6%D82P@
M=F5R:69I<75E(&\@<V5U(&-O<G)E:6\@96QE8W1R\VYI8V\@92`B"B)E;G1R
M92!C;VT@82!S=6$@;F]V82!P86QA=G)A+7!A<W-E+B(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R
M=F5R<SHB"FUS9W-T<B`B3W,@<V5U<R!S97)V:61O<F5S(')E;6]T;W,Z(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-"!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3@*;7-G:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B2G5G;W-L
MX79I82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B
M6F%I<F4B"FUS9W-T<B`B6F%I<F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C4V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS9W-T
M<B`B6N)M8FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T<B`B6FEM8F%B
M=>DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G:60@(EII<'!Y
M(@IM<V=S='(@(EII<'!Y(@H*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VAI
M9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB
M"FUS9W-T<B`B6T5S8V]N9&5R(%1E>'1O($-I=&%D;UTB"@HC.B!S97)V:6-E
M<R]P<F]B;&5M+G!H<#HU-@IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G
M<W1R(");4F5L873S<FEO(&1E(%!R;V)L96UA<UT@(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U
M;W1E9"!497AT("TB"FUS9W-T<B`B6TUO<W1R87(@5&5X=&\@0VET861O("TB
M"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H
M<#HQ-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@
M+2`E<R!L:6YE<UTB"FUS9W-T<B`B6TUO<W1R87(@5&5X=&\@0VET861O("T@
M)7,@;&EN:&%S72(*"B,Z(&QI8B](;W)D92YP:'`Z,3DS"B,L('!H<"UF;W)M
M870*;7-G:60@(EML:6YE("5S(&]F("5S72(*;7-G<W1R(");;&EN:&$@)7,@
M9&4@)7-=(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-#0Q('1E;7!L871E<R]P;W)T
M86PO;65N=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R
M(")?061M:6YI<W1R8>?C;R(*"B,Z(&QI8B]A<&DN<&AP.C$S-@IM<V=I9"`B
M7T-,22(*;7-G<W1R(")?0V]N<V]L82(*"B,Z(&QI8B]A<&DN<&AP.C$R-`IM
M<V=I9"`B7T1A=&%4<F5E(@IM<V=S='(@(L%R7W9O<F4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*;7-G
M:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(E]296UO=F5R($QI;FAA(@H*(SH@
M;&EB+V%P:2YP:'`Z,3$V"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(E]'<G5P
M;W,B"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,3<U"FUS9VED(")?2&5L<"(*
M;7-G<W1R(")!7VIU9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P97)T
M:65S+BXN(@IM<V=S='(@(E!R;W!R:65D861E<R!D82!?26UA9V5M(@H*(SH@
M;&EB+TAO<F1E+TUE;G4N<&AP.C$Y-`IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R
M(")?16YT<F%R(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I9"`B
M7TQO9R!O=70B"FUS9W-T<B`B7U-A:7(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I
M9GD@3&EN:RXN+B(*;7-G<W1R(")?36]D:69I8V%R($QI9V'GXV\B"@HC.B!L
M:6(O2&]R9&4O365N=2YP:'`Z,38T"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R
M(")?3W#G]65S(@H*(SH@;&EB+V%P:2YP:'`Z,3(P"FUS9VED(")?4&5R;6ES
M<VEO;G,B"FUS9W-T<B`B7U!E<FUI<W/U97,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]2
M96UO=F4@3&EN:RXN+B(*;7-G<W1R(")?4F5M;W9E<B!,:6=AY^-O+BXN(@H*
M(SH@;&EB+V%P:2YP:'`Z,3`X"FUS9VED(")?4V5T=7`B"FUS9W-T<B`B7T-O
M;F9I9W5R8>?C;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS,@IM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N
M+BXB"FUS9W-T<B`B4')O<')I961A9&5S(&1A(%]486)E;&$B"@HC.B!L:6(O
M87!I+G!H<#HQ,3(*;7-G:60@(E]5<V5R<R(*;7-G<W1R(")?571I;&EZ861O
M<F5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HX.3`*;7-G:60@(F%D9')E
M<W,@8F]O:R(*;7-G<W1R(")C;VYT86-T;W,B"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z-S$Q"FUS9VED(")A;B!E<G)O<B!H87,@;V-C=7)E9#HB"FUS9W-T
M<B`B;V-O<G)E=2!U;2!E<G)O.B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z
M.#@R"FUS9VED(")C86QE;F1A<B(*;7-G<W1R(")C86QE;F3A<FEO(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R(")C86QM;R(*
M"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HU.#D*;7-G:60@(F-L
M:6-K(&AE<F4B"FUS9W-T<B`B8VQI<75E(&%Q=6DB"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z-#0U('!O+W1R86YS;&%T:6]N+G!H<#HU-3`@<&\O=')A;G-L
M871I;VXN<&AP.C8Q,0HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S0Y('!O+W1R
M86YS;&%T:6]N+G!H<#HX,3`@<&\O=')A;G-L871I;VXN<&AP.C@X-PIM<V=I
M9"`B9&]N92(*;7-G<W1R(")F96ET;R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HU-3(@<&\O=')A;G-L871I;VXN<&AP.C4X-"!P;R]T<F%N<VQA=&EO;BYP
M:'`Z-C$S"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW-S@@<&\O=')A;G-L871I
M;VXN<&AP.C@Q,B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#DP"FUS9VED(")F86EL
M960B"FUS9W-T<B`B9F%L:&]U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-S$*;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B9&EM
M:6YU:6YD;R(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HX-3D*;7-G:60@
M(F9I;&4B"FUS9W-T<B`B9FEC:&5I<F\B"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z,3(Y"FUS9VED(")F;W5N9#H@(@IM<V=S='(@(F5N8V]N=')A9&\Z("(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<T(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S8P(&QI8B]";&]C:R]M971A<BYP:'`Z,S@V"B,L('!H<"UF;W)M870*
M;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B9&\@
M)7,@*"5S*2#@<R`E<R`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,S@*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B<F%J861A<R(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,S(*;7-G:60@
M(F@Z(@IM<V=S='(@(F@Z(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,S,0IM<V=I9"`B:&@B"FUS9W-T<B`B:&@B"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T
M<B`B:6UE9&EA=&\B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI
M;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B:6YL:6YE(@IM<V=S='(@(F5M
M(&QI;FAA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N
M:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R(")L:6YH87-=(@H*(SH@;&EB
M+U9&4R])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N
M(@IM<V=S='(@(D5R<F\@;6MI<V]F<R!C;VT@8_-D:6=O("5D(&%O(&-O;G-T
M<G5I<B!)4T\N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C,T,@IM<V=I9"`B;6TB"FUS9W-T<B`B;6TB"@HC.B!L:6(O2&]R9&4O
M4')E9G,O54DN<&AP.C(X."!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,C`U"FUS9VED(")N86UE(@IM<V=S='(@(FYO;64B"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z,S<X"FUS9VED(")N;W0@8VAA;F=E9"(*;7-G<W1R(")S96T@
M86QT97)AY_5E<R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,S$*;7-G:60@
M(FYO="!F;W5N9"(*;7-G<W1R(")NXV\@96YC;VYT<F%D;R(*"B,Z(&QI8B](
M;W)D92]24$,N<&AP.C$R,0IM<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S
M='(@(F[C;R!I;7!L96UE;G1A9&$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C$R,3D*;7-G:60@(FYO="!Y970@:6UP;&5M96YT960B"FUS9W-T
M<B`B86EN9&$@<&]R(&EM<&QE;65N=&%R(@H*(SH@;&EB+TAO<F1E+TMO;&%B
M+G!H<#HX-S0*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B8V%D97)N;R!D92!N
M;W1A<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B<&5R8V5N=&%G
M96TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS9W-T<B`B<.UX96ES(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*;7-G:60@
M(G)I<VEN9R(*;7-G<W1R(")S=6)I;F1O(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HY.`IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R(")M
M;W-T<F%R(&1I9F5R96[G87,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B"FUS9W-T
M<B`B<VUS,F5M86EL('9I82!(5%10(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C,U.`IM<V=I9"`B<W,B"FUS9W-T<B`B<W,B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,@IM<V=I
M9"`B<W1E861Y(@IM<V=S='(@(F5S=.%V96PB"@HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.C@Y.`IM<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@(FQI<W1A(&1E
M('1A<F5F87,B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S(U"B,L('!H<"UF
M;W)M870*;7-G:60@(G1H92!(;W)D92!03R!F:6QE(&9O<B!T:&4@;&]C86QE
M("5S(&1O97,@;F]T(&5X:7-T.B(*;7-G<W1R(")/(&9I8VAE:7)O(%!/('!A
M<F$@;R!L;V-A;&4@)7,@;N-O(&5X:7-T92XB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HS-B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B='EP
M92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R(")I;G1R
M;V1U>F$@82!P86QA=G)A+7!A<W-E(&1U87,@=F5Z97,L('!A<F$@8V]N9FER
M;6'GXV\B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U
M<"]D:69F+G!H<#HW.0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R(")U;FEF:6-A
M9&\B"@HC.B!L:6(O2&]R9&4O34E-12]087)T+G!H<#HR-PIM<V=I9"`B=6YN
M86UE9"(*;7-G<W1R(")S96T@;F]M92(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HS-S4*;7-G:60@(G5P9&%T960B"FUS9W-T<B`B86-T=6%L:7IA9&\B"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")U<V5R('-E;&5C
M="(*;7-G<W1R(")S96QE8V-I;VYA9&$@<&5L;R!U=&EL:7IA9&]R(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I9"`B=D-A
M<F0B"FUS9W-T<B`B=D-A<F0B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C(T"FUS9VED(")W.B(*;7-G<W1R(")2965N8SHB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE
M<BYC;VTB"FUS9W-T<B`B=V5A=&AE<BYC;VTB"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&\O;F)?3D\N<&\`````````````````````````````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P-C8U-#(V(#$P-3$U-#,S-S0S(#`Q-S4S-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````C($YO
M<G=E9VEA;B!(;W)D92!4<F%N<VQA=&EO;BX*(R!#;W!Y<FEG:'0@*$,I(#(P
M,#$M,C`P,B!(;W)D92!0<F]J96-T+@HC($]Y<W1E:6X@4W1E:6UL97(@/&]Y
M<W1E:6Y`<F5X=&$N;F5T/BP@,C`P,2X*(R!4;W)S=&5I;B!3+B!(86YS96X@
M/&AU;&5B;V5R0'1E8VAB964N;F\^+"`R,#`R+@HC($%N9')E87,@1W5N;&5I
M:W-K86%S(#QA;F1R96%S0&=U;FQE:6MS:V%A<RYN;SXL(#(P,#,N"B,@1V5I
M<B!/+B!(;V=B97)G(#QH;W)D94!S:WED:79E<BYN;SXL(#(P,#4N"B,*;7-G
M:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N
M,"XT7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E
M+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,#4M,3@@,3(Z-#,K
M,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P-2TP-2TQ."`Q-#HS-RLP
M,C`P7&XB"B),87-T+51R86YS;&%T;W(Z($=E:7(@3RX@2&]G8F5R9R`\:&]R
M9&5`<VMY9&EV97(N;F\^7&XB"B),86YG=6%G92U496%M.B!.;W)W96=I86X@
M*$)O:VUA;"D@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-12U697)S
M:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E
M=#UI<V\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X
M8FET7&XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#D*;7-G:60@(B(*(B`@
M+4TL("TM;65S<V%G93U-15-304=%("!5<V4@=&AI<R!C;VUM:70@;65S<V%G
M92!I;G-T96%D(&]F('1H92!D969A=6QT(&]N97,N(@IM<V=S='(@(B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HU,PIM<V=I9"`B(@HB("`M82P@+2UA9&0]
M1DE,12`@("`@("`@061D('1H:7,@4$\@9FEL92!T;R!T:&4@8V]M<&5N9&EU
M;2X@57-E9G5L('1O7&XB"B(@("`@("`@("`@("`@("`@("`@("`@("!I;F-L
M=61E(&$@8V]M<&5N9&EU;2!F<F]M(&$@9&EF9F5R96YT(&)R86YC:"!T;UQN
M(@HB("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&=E;F5R871E9"!C;VUP
M96YD:75M+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$S
M"FUS9VED("(B"B(@("UB+"`M+6)A<V4]+U!!5$@@($9U;&P@<&%T:"!T;R!T
M:&4@*$AO<F1E*2!B87-E(&1I<F5C=&]R>2!T:&%T('-H;W5L9"!B95QN(@HB
M("`@("`@("`@("`@("`@("`@("!U<V5D+B(*;7-G<W1R("(B"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z-CD*;7-G:60@(B(*(B`@+6,L("TM8V]M<&5N9&EU
M;3U&24Q%("!-97)G92!N97<@=')A;G-L871I;VYS('1O('1H:7,@8V]M<&5N
M9&EU;2!F:6QE7&XB"B(@("`@("`@("`@("`@("`@("`@("`@("`@:6YS=&5A
M9"!O9B!T:&4@9&5F875L="!O;F4@*&-O;7!E;F1I=6TN<&\@:6X@=&AE7&XB
M"B(@("`@("`@("`@("`@("`@("`@("`@("`@:&]R9&4O<&\@9&ER96-T;W)Y
M+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C,@<&\O=')A
M;G-L871I;VXN<&AP.C@Q('!O+W1R86YS;&%T:6]N+G!H<#HX-PIM<V=I9"`B
M(@HB("`M8RP@+2UC;VUP96YD:75M/49)3$4@(%5S92!T:&ES(&-O;7!E;F1I
M=6T@9FEL92!I;G-T96%D(&]F('1H92!D969A=6QT7&XB"B(@("`@("`@("`@
M("`@("`@("`@("`@("`@;VYE("AC;VUP96YD:75M+G!O(&EN('1H92!H;W)D
M92]P;R!D:7)E8W1O<GDI+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,3$T"FUS9VED("(@("UD+"`M+61E8G5G("`@("`@(%-H;W<@97)R
M;W(@;65S<V%G97,@9G)O;2!T:&4@97AE8W5T960@8FEN87)I97,N(@IM<V=S
M='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HU-`IM<V=I9"`B("`M9"P@
M+2UD:7)E8W1O<GD]1$E2("`@0W)E871E(&-O;7!E;F1I=6T@:6X@=&AI<R!D
M:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ
M,34*;7-G:60@(B`@+6@L("TM:&5L<"`@("`@("`@4VAO=R!T:&ES(&AE;'`@
M;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0R
M('!O+W1R86YS;&%T:6]N+G!H<#HV-R!P;R]T<F%N<VQA=&EO;BYP:'`Z-S4*
M;7-G:60@(B`@+6PL("TM;&]C86QE/6QL7T-#("`@("!5<V4@;VYL>2!T:&ES
M(&QO8V%L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0W
M('!O+W1R86YS;&%T:6]N+G!H<#HV,2!P;R]T<F%N<VQA=&EO;BYP:'`Z-SD*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C@U"FUS9VED("(@("UL+"`M+6QO8V%L
M93UL;%]#0R`@("`@57-E('1H:7,@;&]C86QE+B(*;7-G<W1R("(B"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z-34*;7-G:60@(B`@+6PL("TM;&]C86QE/6QL
M7T-#("`@(%5S92!T:&ES(&QO8V%L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C8X"FUS9VED("(@("UM+"`M+6UO9'5L93U-3T153$4@
M("`@0G5I;&0@34\@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L
M92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0S"FUS9VED
M("(@("UM+"`M+6UO9'5L93U-3T153$4@("`@0VQE86YU<"!03R!F:6QE<R!O
M;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+B(*;7-G<W1R("(B"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z-#@*;7-G:60@(B(*(B`@+6TL("TM;6]D=6QE
M/4U/1%5,12`@("!#;VUM:70@=')A;G-L871I;VYS(&]N;'D@9F]R('1H:7,@
M*$AO<F1E*2!M;V1U;&4N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HV,@IM<V=I9"`B("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($-R96%T
M92!A(%!/(&9I;&4@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92XB"FUS
M9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C@P"FUS9VED("(@("UM
M+"`M+6UO9'5L93U-3T153$4@("`@365R9V4@4$\@9FEL97,@;VYL>2!F;W(@
M=&AI<R`H2&]R9&4I(&UO9'5L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C<V"FUS9VED("(B"B(@("UM+"`M+6UO9'5L93U-3T153$4@
M("`@57!D871E(&AE;'`@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO
M9'5L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C@V"FUS
M9VED("(@("UM+"`M+6UO9'5L93U-3T153$4@("`@57!D871E(&]N;'D@=&AI
M<R`H2&]R9&4I(&UO9'5L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C4X"FUS9VED("(@("UM+"`M+6UO9'5L93U-3T153$4@($=E;F5R
M871E(%!/5"!F:6QE(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N(@IM
M<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW,`IM<V=I9"`B(@HB
M("`M;BP@+2UN;RUC;VUP96YD:75M("`@($1O;B=T(&UE<F=E(&YE=R!T<F%N
M<VQA=&EO;G,@=&\@=&AE(&-O;7!E;F1I=6TN(@IM<V=S='(@(B(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HV-"!P;R]T<F%N<VQA=&EO;BYP:'`Z.#(@<&\O
M=')A;G-L871I;VXN<&AP.C@X"FUS9VED("(@("UN+"`M+6YO+6-O;7!E;F1I
M=6T@("`@1&]N)W0@=7-E(&$@8V]M<&5N9&EU;2XB"FUS9W-T<B`B(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C<Q"FUS9VED("(@("US+"`M+7-T871I<W1I
M8W,@("`@("`@4V%V92!T<F%N<VQA=&EO;B!S=&%T:7-T:6-S(&EN(&$@;&]C
M86P@9FEL92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$Q
M-@IM<V=I9"`B("`M="P@+2UT97-T("`@("`@("!3:&]W('1H92!E>&5C=71E
M9"!C;VUM86YD<R!B=70@9&]N)W0@<G5N(&%N>71H:6YG+B(*;7-G<W1R("(B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`U"FUS9VED("(B"B(@(&-L96%N
M=7`@("`@($-L96%N<R!T:&4@4$\@9FEL97,@=7`@9G)O;2!U;G1R86YS;&%T
M960@86YD(&]B<V]L971E(&5N=')I97,N(@IM<V=S='(@(B(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HQ,#@*;7-G:60@(B`@8V]M;6ET("`@("`@0V]M;6ET
M('1R86YS;&%T:6]N<R!T;R!T:&4@0U93('-E<G9E<BXB"FUS9W-T<B`B(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C$P.0IM<V=I9"`B("!C;VUM:70M:&5L
M<"!#;VUM:70@:&5L<"!F:6QE<R!T;R!T:&4@0U93('-E<G9E<BXB"FUS9W-T
M<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.CDY"FUS9VED("(B"B(@(&-O
M;7!E;F1I=6T@(%)E8G5I;&0@=&AE(&-O;7!E;F1I=6T@9FEL92X@5V%R;FEN
M9SH@5&AI<R!O=F5R=W)I=&5S('1H95QN(@HB("`@("`@("`@("`@("!C=7)R
M96YT(&-O;7!E;F1I=6TN(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HQ,#`*;7-G:60@(B`@97AT<F%C="`@("`@1V5N97)A=&4@4$\@=&5M
M<&QA=&4@*"YP;W0I(&9I;&5S+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z.3@*;7-G:60@(B`@:&5L<"`@("`@("`@4VAO=R!T:&ES(&AE
M;'`@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C$P,0IM<V=I9"`B(@HB("!I;FET("`@("`@("!#<F5A=&4@;VYE(&]R(&UO
M<F4@4$\@9FEL97,@9F]R(&$@;F5W(&QO8V%L92X@5V%R;FEN9SH@5&AI<UQN
M(@HB("`@("`@("`@("`@("!O=F5R=W)I=&5S('1H92!E>&ES=&EN9R!03R!F
M:6QE<R!O9B!T:&ES(&QO8V%L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C$P-@IM<V=I9"`B("!M86ME("`@("`@("!"=6EL9"!B:6YA
M<GD@34\@9FEL97,@9G)O;2!T:&4@<W!E8VEF:65D(%!/(&9I;&5S+B(*;7-G
M<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`W"FUS9VED("(B"B(@
M(&UA:V4M:&5L<"`@($UA<FL@86QL(&5N=')I97,@:6X@=&AE(%A-3"!H96QP
M(&9I;&4@8F5I;F<@=7`M=&\M9&%T92!A;F1<;B(*(B`@("`@("`@("`@("`@
M<')E<&%R92!T:&4@9FEL92!F;W(@=&AE(&YE>'0@97AE8W5T:6]N(&]F('5P
M9&%T92UH96QP+B!9;W5<;B(*(B`@("`@("`@("`@("`@<VAO=6QD(&]N;'D@
M<G5N(&UA:V4M:&5L<"!!1E1%4B!U<&1A=&4M:&5L<"!A;F0@<F5V:7-I;F<@
M=&AE7&XB"B(@("`@("`@("`@("`@(&AE;'`@9FEL92XB"FUS9W-T<B`B(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C$P,@IM<V=I9"`B(@HB("!M97)G92`@
M("`@("!-97)G92!T:&4@8W5R<F5N="!03R!F:6QE('=I=&@@=&AE(&-U<G)E
M;G0@4$\@=&5M<&QA=&4@9FEL92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C$P,PIM<V=I9"`B("!U<&1A=&4@("`@("!2=6X@97AT<F%C
M="!A;F0@;65R9V4@<V5Q=65N="XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C$P-`IM<V=I9"`B(@HB("!U<&1A=&4M:&5L<"!%>'1R86-T
M(&%L;"!N97<@86YD(&-H86YG960@96YT<FEE<R!F<F]M('1H92!%;F=L:7-H
M(%A-3"!H96QP7&XB"B(@("`@("`@("`@("`@(&9I;&4@86YD(&UE<F=E('1H
M96T@=VET:"!T:&4@97AI<W1I;F<@;VYE<RXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?=&]P+FEN8SHQ,0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B(@)B,Q-3$[("5S(&ES(')E861Y('1O('!E<F9O
M<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RXB
M"FUS9W-T<B`B(@HB("8C,34Q.R`E<R!E<B!K;&%R(&9O<B#E('5T9OAR92!V
M961L:6ME:&]L9'-O<&5R87-J;VYE;F4@<V]M(&5R('9A;&=T("(*(FYE9&5N
M9F]R+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S4R"B,L('!H<"UF;W)M
M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B`H)7,@9&%G97(@
M<VED96XI(@H*(SH@;&EB+TAO<F1E+G!H<#HQ,C@S"B,L('!H<"UF;W)M870*
M;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(@*&AU<G1I9W1A<W0@
M)7,I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-C`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R("(@*&EN;F5N("5S(&1A
M9V5R*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S4V"FUS9VED("(@*'1O
M9&%Y*2(*;7-G<W1R("(@*&D@9&%G*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR,S4X"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(@*&D@;6]R9V5N
M*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S4T"FUS9VED("(@*'EE<W1E
M<F1A>2DB"FUS9W-T<B`B("AI(&?E<BDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C$T"FUS9VED("(@870@(@IM<V=S='(@(B!D96X@(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B)60@)7,@;V<@)7,B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$V-`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E9"!B>71E<R!W<FET=&5N+B(*;7-G<W1R("(E9"!B>71E<R!S:W)E
M=F5T+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,C8U"B,L('!H<"UF;W)M
M870*;7-G:60@(B5D(&]F("5D(&5N=')I97,@;6%R:V5D(&%S('5P+71O+61A
M=&4B"FUS9W-T<B`B)60@878@)60@;W!P9OAR:6YG97(@;6%R:V5T('-O;2!O
M<'!D871E<G0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0Q
M"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R
M("(E9"UD86=E<G,@=F%R<V5L(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E
M+VYO=&EC95]T;W`N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.
M;W1I8V4B"FUS9W-T<B`B)7,@+2!4:6P@:6YF;R(*"B,Z('1E;7!L871E<R]A
M9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHR.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(E<R!A9&UI;FES=')A<VIO
M;B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S(X"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B5S($9I;F=E
M<G!R:6YT(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@U-R!L
M:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#4Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S($M"(@IM<V=S='(@(B5S($M"(@H*(SH@=&5M<&QA=&5S+VUA
M:6YT96YA;F-E+V-O;F9I<FU?=&]P+FEN8SHT"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB
M"FUS9W-T<B`B)7,@=F5D;&EK96AO;&1S;W!E<F%S:F]N97(@+2!"96MR969T
M96QS92(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C(P.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U
M<"(*;7-G<W1R("(E<R!I;G-T:6QL:6YG97(B"@HC.B!L:6(O2&]R9&4O075T
M:"]3:6=N=7`N<&AP.C(W-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N
M(%5P(@IM<V=S='(@(B5S(')E9VES=')E<FEN9R(*"B,Z('1E;7!L871E<R]M
M86EN=&5N86YC92]A9W)E96UE;G1?=&]P+FEN8SHT"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*;7-G<W1R("(E<R!A=G1A
M;&5V:6QKY7(B"@HC.B!L:6(O5D93+V9T<"YP:'`Z-3DV(&QI8B]61E,O9G1P
M+G!H<#HV-C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES
M=',N(@IM<V=S='(@(B5S(&9I;FYE<R!A;&QE<F5D92XB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$U-R!L:6(O0FQO8VLO;65T87(N<&AP.C$V,R!L:6(O
M0FQO8VLO;65T87(N<&AP.C(S-PHC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T
M,R!L:6(O0FQO8VLO;65T87(N<&AP.C,T.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!A="`E<R`E<R(*;7-G<W1R("(E<R!PY2`E<R`E<R(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4S,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!H87,@8V%N8V5L;&5D("5S+B(*;7-G<W1R("(E<R!H
M87(@:V%N<V5L;&5R="`E<RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HT,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S
M(')E<&QI960@=&\@82!F<F5E+V)U<WD@<F5Q=65S="XB"FUS9W-T<B`B)7,@
M:&%R(&)E<W9A<G0@96X@9F]R97-P^')S96P@;VT@:6YF;W)M87-J;VX@86YG
MY65N9&4@;&5D:6<O;W!P=&%T="XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HU,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M:&%S(')E<&QI960@=&\@=&AE(&EN=FET871I;VX@=&\@)7,N(@IM<V=S='(@
M(B5S(&AA<B!S=F%R="!PY2!I;G9I=&%S:F]N96X@=&EL("5S+B(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0Q-@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!H87,@<V5N="!Y;W4@9G)E92]B=7-Y(&EN9F]R
M;6%T:6]N+B(*;7-G<W1R("(E<R!H87(@<V5N9'0@9&5G(&EN9F]R;6%S:F]N
M(&]M(&QE9&EG+V]P<'1A='0N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C(X
M-R!P;R]T<F%N<VQA=&EO;BYP:'`Z,S$T"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(&ES(&YO="!W<FET86)L92XB"FUS9W-T<B`B)7,@97(@<VMR:79E8F5S
M:WET=&5T+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S(R"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B5S(&5R('#E
M:W)E=F0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X-`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S='(@(B5S(&UI;G5T=&5R(@H*
M(SH@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R,R!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,3,S,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@
M9F]U;F0N(@IM<V=S='(@(B5S(&EK:V4@9G5N;F5T+B(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HU.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O
M=6YD+B!2=6X@)W1R86YS;&%T:6]N(&5X=')A8W0G(&9I<G-T+B(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT
M,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!F<F5E
M+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(B5S(&9O<F5S</AR(&EN9F]R
M;6%S:F]N(&]M(&[E<B!D=2!E<B!L961I9R]O<'1T871T+B(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4P.`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!R97%U97-T<R!Y;W5R('!R97-E;F-E(&%T("5S+B(*
M;7-G<W1R("(E<R!F;W)E<W#X<B!D:6X@9&5L=&%G96QS92!PY2`E<RXB"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHV"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@(B5S("T@)7,@878@
M)7,B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU
M,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O(&%D9"!T;R`E
M<RXB"FUS9W-T<B`B)7,@^&YS:V5R(.4@;&5G9V4@=&EL("5S+B(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4P,@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!W:7-H97,@=&\@;6%K92!Y;W4@87=A<F4@;V8@
M)7,N(@IM<V=S='(@(B5S(/AN<VME<B#E(&=J^')E(&1E9R!O<'!M97)K<V]M
M('#E("5S+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C4Q.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W:7-H97,@=&\@<F5C
M96EV92!T:&4@;&%T97-T(&EN9F]R;6%T:6]N(&%B;W5T("5S+B(*;7-G<W1R
M("(E<R#X;G-K97(@Y2!M;W1T82!D96X@<VES="!O<'!D871E<G1E(&EN9F]R
M;6%S:F]N96X@;VT@)7,N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,3(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T
M<B`B061D<F5S<V5B;VL@9F]R("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HY,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G
M<W1R(")+86QE;F1E<B!F;W(@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.C@Y-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T
M<B`B3F]T871B;&]K:R!F;W(@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.CDR,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S
M='(@(D]P<&=A=F5L:7-T92!F;W(@)7,B"@HC.B!L:6(O2&]R9&4O3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z.3<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,Z("5S(@IM<V=S='(@(B5S.B`E<R(*"B,Z(&QI8B](;W)D92]#
M3$DN<&AP.C(W,`HC+"!P:'`M9F]R;6%T"FUS9VED("(G)7,G(&ES(&YO="!A
M('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B)R5S)R!E<B!I:VME(&5T(&=Y;&1I
M9R!V86QG+B(*"B,Z(&QI8B](;W)D92]296=I<W1R>2YP:'`Z-3@R(&QI8B](
M;W)D92]296=I<W1R>2YP:'`Z.3@R"B,L('!H<"UF;W)M870*;7-G:60@(B<E
M<R<@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*
M;7-G<W1R("(G)7,G(&5R(&EK:V4@8V]N9FEG=7)E<G0@:2!(;W)D92!296=I
M<W1E<F5T+B(*"B,Z(&QI8B](;W)D92]4<F5E+G!H<#HQ-C`*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(B<E<R<@=')E92!R96YD97)E<B!N;W0@9F]U
M;F0N(@IM<V=S='(@(B5S(&EK:V4@9G5N;F5T+B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)R5S)R!W87,@861D960@
M=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(B5S(&)L92!L86=T('1I
M;"!G<G5P<&5S>7-T96UE="XB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP
M:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)R5S)R!W87,@861D960@=&\@
M=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B)R5S)R!B;&4@;&%G
M="!T:6P@<F5T=&EG:&5T<W-Y<W1E;65T+B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z-34@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C@S"B,L('!H<"UF;W)M
M870*;7-G:60@(B<E<R<@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B
M)7,@8FQE(&EK:V4@;W!P<F5T=&5T.B`E<RXB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$X-B!L:6(O0FQO8VLO;65T87(N<&AP.C$Y,0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S='(@(B5S
M('#E("5S("5S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B+"!V87)I86)L92!F<F]M("5S('1O("5S(@IM<V=S
M='(@(BP@=F%R:6%B96P@;65L;&]M("5S(&]G("5S(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(P-3,@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,3(*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8Y,0IM<V=I9"`B+2T@
M<V5L96-T("TM(@IM<V=S='(@(BTM('9E;&<@+2TB"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z,3,P.2!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,Q,0IM<V=I9"`B
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS
M9W-T<B`B,3(@5&EM97)S(&9O<FUA="(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H
M<#HQ.0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B,C0@5&EM97)S
M(&9O<FUA="(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(X"FUS9VED
M("(R-"!H;W5R<R(*;7-G<W1R("(R-"!T:6UE<B(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HS-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB/&=E='1E>'0^
M('1A9R!N;W0@8VQO<V5D(&EN(&9I;&4@)7,N7&XB"B)/<&5N:6YG('1A9R!F
M;W5N9"!I;B!L:6YE("5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$Q-PIM<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES(')E<75I
M<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R(")%;B!D871A8F%S96MO8FQI
M;F<@97(@<.5K<F5V9"!F;W(@9&5N;F4@8FQO:VME;BXB"@HC.B!L:6(O2&]R
M9&4N<&AP.C$V-@IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B
M"FUS9W-T<B`B16X@9F%T86P@9F5I;"!H87(@;W!P<W3E='0B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HY-#$*;7-G:60@(D$@<'5B;&EC(%!'4"!K
M97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@
M(D5N(&]F9F5N=&QI9R!01U`M;OAK:V5L(&5R('#E:W)E=F0@9F]R(.4@:W)Y
M<'1E<F4@;65L9&EN9V5N+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C$Q-C<*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@
M=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(D5N(&]F9F5N=&QI
M9R!01U`M;OAK:V5L(&5R('#E:W)E=F0@9F]R(.4@=F5R:69I<V5R92!S:6=N
M97)T(&UE;&1I;F<N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3`Y
M.`IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*
M(FUE<W-A9V4N(@IM<V=S='(@(B(*(D5N(&]F9F5N=&QI9R!01U`M;OAK:V5L
M+"!P<FEV870@4$=0+6[X:VME;"!O9R!P87-S<&AR87-E(&5R('#E:W)E=F0@
M9F]R(.4@(@HB9&5K<GEP=&5R92!E;B!M96QD:6YG+B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]P9W`N<&AP.C$P,3<*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K
M97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O('-I9VX@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"B)%;B!O9F9E
M;G1L:6<@4$=0+6[X:VME;"P@<')I=F%T(%!'4"UN^&MK96P@;V<@<&%S<W!H
M<F%S92!E<B!PY6MR979D(&9O<B#E("(*(G-I9VYE<F4@96X@;65L9&EN9RXB
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4R,PIM<V=I9"`B(@HB
M02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A(&UE<W-A
M9V4N(@IM<V=S='(@(B(*(D5N(&]F9F5N=&QI9R!3+TU)344M;OAK:V5L+"!P
M<FEV870@4R]-24U%+6[X:VME;"P@;V<@<&%S<W!H<F%S92!E<B!PY6MR979D
M("(*(F9O<B#E(&1E:W)Y<'1E<F4@96X@;65L9&EN9RXB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C0T.0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-
M24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*
M(D5N(&]F9F5N=&QI9R!3+TU)344M;OAK:V5L+"!P<FEV870@4R]-24U%+6[X
M:VME;"P@;V<@<&%S<W!H<F%S92!E<B!PY6MR979D("(*(F9O<B#E('-I9VYE
M<F4@96X@;65L9&EN9RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C,X,@IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O
M(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(")%;B!O9F9E;G1L:6<@4R]-
M24U%+6[X:VME;"!E<B!PY6MR979D(&9O<B#E(&MR>7!T97)E(&5N(&UE;&1I
M;F<N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,R-0HC+"!F
M=7IZ>0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R(")296=N('#E(&9O<FUI9&1A
M9V5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,R-@HC+"!F
M=7IZ>0IM<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R(")296=N8GEG97(@<.4@
M9F]R;6ED9&%G96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S(W"B,L(&9U>GIY"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B
M4V[X8GEG97(@<.4@9F]R;6ED9&%G96XB"@HC.B!T96UP;&%T97,O9&%T82]T
M:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`B04TO4$TB"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P-`IM<V=I9"`B05!)
M($E$(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S
M='(@(D]M(&1E;FYE(&5D:71O<F5N(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E
M>"YP:'`Z-3(*;7-G:60@(D%B;W5T+BXN(@IM<V=S='(@(D]M+BXN(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I
M9"`B06)S8F]T=&]M(@IM<V=S='(@(D%B<V]L=71T(&YE9&5R<W0B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED
M(")!8G-M:61D;&4B"FUS9W-T<B`B06)S;VQU='0@;6ED="(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8T,`IM<V=I9"`B06-C
M97!T(')E<75E<W0B"FUS9W-T<B`B1V]D:VIE;FX@9F]R97-P^')S96PB"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV.#$*;7-G
M:60@(D%C8V5P=&5D(@IM<V=S='(@(D=O9'1A='0B"@HC.B!L:6(O5D93+VUU
M<W%L+G!H<#HR.#4*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B5&EL9V%N9R!N96MT970@=F5D(&]P<')E
M='1E;'-E(&%V(%9&4R!K871A;&]G+B(*"B,Z(&QI8B]61E,O;75S<6PN<&AP
M.C$S.`IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92XB
M"FUS9W-T<B`B5&EL9V%N9R!N96MT970@=F5D(&]P<')E='1E;'-E(&%V(%9&
M4R!F:6PN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U"FUS9VED(")!
M8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@(DMO;G1O(%!A<W-O<F0B"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM<V=I9"`B06-C
M;W5N="!F<F]Z96XN(@IM<V=S='(@(DMO;G1O(&9R^'-E="XB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(P"FUS9VED(")!8V-O=6YT:6YG(@IM
M<V=S='(@(D)O:VAO;&1I;F<O06-C;W5N=&EN9R(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0U,0HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HV,C4*;7-G:60@(D%C=&EO;G,B"FUS
M9W-T<B`B2&%N9&QI;F=E<B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H
M<#HU-"!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$S-@HC.B!T96UP;&%T97,O
M<&]R=&%L+V%D9"YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C
M:&EL9"YI;F,Z,38*;7-G:60@(D%D9"(*;7-G<W1R("),96=G('1I;"(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z,C$T(&%D;6EN+V=R;W5P<RYP:'`Z,C$U"FUS
M9VED(")!9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B3&5G9R!T:6P@=6YD97)G
M<G5P<&4B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C@Q(&QI8B](;W)D
M92]097)M<R]522YP:'`Z.#(*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N
M(@IM<V=S='(@(DQE9V<@=&EL('5N9&5R<F5T=&EG:&5T97(B"@HC.B!T96UP
M;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D($AE<F4Z(@IM<V=S
M='(@(DQE9V<@=&EL(&AE<CHB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(P."!A
M9&UI;B]G<F]U<',N<&AP.C(P.0IM<V=I9"`B061D($YE=R!'<F]U<"(*;7-G
M<W1R("),96=G('1I;"!N>2!G<G5P<&4B"@HC.B!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C<P(&QI8B](;W)D92]097)M<R]522YP:'`Z-S$*;7-G:60@(D%D
M9"!.97<@4&5R;6ES<VEO;B(*;7-G<W1R("),96=G('1I;"!N>2!R971T:6=H
M970B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHY
M"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O("<E
M<R<B"FUS9W-T<B`B3&5G9R!T:6P@96X@=6YD97)G<G5P<&4@=&EL("<E<R<B
M"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3,@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HQ,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI
M;&0@<&5R;6ES<VEO;B!T;R`G)7,G(@IM<V=S='(@(DQE9V<@=&EL('5N9&5R
M<F5T=&EG:&5T('1I;"`G)7,G(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G
M:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R("),96=G('1I;"!N>2!B<G5K
M97(Z(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R
M.0IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R("),96=G('1I;"!K;VQO;FYE
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS-0IM<V=I
M9"`B061D(&YE=R!M96UB97)S(@IM<V=S='(@(DQE9V<@=&EL(&YY92!M961L
M96UM97(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I
M9"`B061D('!A:7(B"FUS9W-T<B`B3&5G9R!T:6P@<&%R(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@
M=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(B"FUS9W-T<B`B3&5G
M9R!T:6P@)7,@;65N>65N('-O;2!-;WII;&QA(%-I9&5B87(B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV,S$*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C,W"FUS9VED(")!9&0@
M=&AI<R!T;R!M>2!C86QE;F1A<B(*;7-G<W1R("),96=G('1I;"!I(&UI;B!K
M86QE;F1E<B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M-S0*;7-G:60@(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(DQE9V<@
M=&EL(&D@861D<F5S<V5B;VLZ(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HX,0IM<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O:R(*
M;7-G<W1R("),96=G('1I;"!I(&UI;B!A9&1R97-S96)O:R(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R("),96=G('1I
M;"!B<G5K97(B"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)!9&1E9"`G)7,G('1O('1H92!S>7-T96TL(&)U="!C;W5L
M9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`E(@HB
M<RXB"FUS9W-T<B`B(@HB3&$@=&EL("<E<R<@:2!S>7-T96UE="P@;65N(&MU
M;FYE(&EK:V4@;&5G9V4@=&EL(&5K<W1R82!R96=I<W1R97)I;F=S:6YF;SH@
M)2(*(G,N(@H*(SH@<VEG;G5P+G!H<#HT-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")!9&1E9"`G)7,G('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO
M=RXB"FUS9W-T<B`B3&$@)R5S)R!T:6P@<WES=&5M970N($1U(&MA;B!L;V=G
M92!I;FX@;N4N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.CDU-@IM<V=I9"`B
M061D:6YG(&YE=R!F:6QE<R!T;R!R97!O<VET;W)Y.B(*;7-G<W1R("),82!T
M:6P@;GEE(&9I;&5R(&D@<F5P;W-I=&]R>3HB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]N;V%D9"YI;F,Z-`IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I
M<V%B;&5D+B(*;7-G<W1R(")-=6QI9VAE="!F;W(@Y2!L96=G92!T:6P@;GEE
M(&)R=6ME<F4@97(@9&5A:W1I=F5R="XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,30S."!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R.0HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$W-@IM<V=I9"`B
M061D<F5S<R(*;7-G<W1R(")!9')E<W-E(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$S-`IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(D%D
M<F5S<V4@0F]K(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP
M.CDW"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O
M=&AE<B!U<V5R<R(*;7-G<W1R(")!9&UI;FES=')E<B`M('-E='0@<F5T=&EG
M:&5T97(@9F]R(&%N9')E(&)R=6ME<F4B"@HC.B!A9&UI;B]I;F1E>"YP:'`Z
M,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM<V=I9"`B061M
M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R87-J;VXB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`V"FUS9VED(")!9',B"FUS9W-T<B`B
M4F5K;&%M97(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C4W"FUS9VED(")!9F=H86YI<W1A;B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X"FUS9VED
M(")!;&)A;FEA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HW-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3`*;7-G
M:60@(D%L:6%S(@IM<V=S='(@(D%L:6%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I9"`B06QI9VXB
M"FUS9W-T<B`B2G5S=&5R92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N=#HB"FUS9W-T<B`B
M2G5S=&5R:6YG.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM<V=I
M9"`B06QL(@IM<V=S='(@(D%L;&4B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H
M<#HQ,3@@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-0IM<V=I9"`B06QL
M($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`B06QL92!A=71E;G1I<V5R
M=&4@8G)U:V5R92(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO9W)O
M=7!S+G!H<#HR,3(*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`B06QL92!'
M<G5P<&5R(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C,X(&QI8B](
M;W)D92]097)M<R]522YP:'`Z-S0*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*
M;7-G<W1R(")!;&QE(')E9&1I9VAE=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O
M=7(@<VED97,B"FUS9W-T<B`B06QL92!F:7)E('-I9&5R(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$X-34*;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E
M<W-E<R(*;7-G<W1R(")4:6QL871T(&9L97)E(&%D<F5S<V5R(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4R,PIM<V=I9"`B06QL;W<@<V5T=&EN9R!O
M9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B5&EL;&%T="!E;F1R:6YG
M(&%V(&9O<FUA=&5T('#E(&YU;6UE<F5R=&4@;&ES=&5R/R(*"B,Z(&QI8B](
M;W)D92]$871A5')E92]S<6PN<&AP.C0P,PIM<V=I9"`B06QR96%D>2!E>&ES
M=',B"FUS9W-T<B`B16MS:7-T97)E<B!A;&QE<F5D92(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,C(*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN
M(@IM<V=S='(@(D%L=&5R;F%T:78@24U34"!,;V=I;B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT.38*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A<W-W
M;W)D(@IM<V=S='(@(D%L=&5R;F%T:79T($E-4U`@<&%S<V]R9"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT.#@*;7-G:60@(D%L=&5R;F%T92!)35-0
M(%5S97)N86UE(@IM<V=S='(@(D%L=&5R;F%T:79T($E-4U`@8G)U:V5R;F%V
M;B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED(")!
M;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R(")!;'1E<FYA=&EV(&4M
M<&]S="!A9')E<W-E(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*;7-G
M:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`B06QT97)N871I=F4@
M;6%L97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*;7-G
M<W1R(")!;'1E<FYA=&EV('1E:W-T.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%M97)I8V%N(%-A;6]A
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z.3<@;&EB
M+TAO<F1E+U!R969S+U5)+G!H<#HQ,3<*;7-G:60@(D%N(&EL;&5G86P@=F%L
M=64@=V%S('-P96-I9FEE9"XB"FUS9W-T<B`B16X@=6QO=FQI9R!V97)D:2!V
M87(@;W!P9VET="XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C4V"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@
M(D%N9V]L82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;F=U:6QL82(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,C`*;7-G:60@(D%N;VYY
M;6]U<R!0<F]X>2(*;7-G<W1R(")!;F]N>6T@4')O>'DB"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@
M(E-V87(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C4Y"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N
M=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA
M=&5S+G!H<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z,S`@;&EB+TAO<F1E+T)L
M;V-K+U5)+G!H<#HU.0HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N
M:'1M;#HV"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R(")0<F]G<F%M(@H*
M(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO
M;B!,:7-T(@IM<V=S='(@(E!R;V=R86UL:7-T92(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ,S`*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*
M;7-G<W1R(")0<F]G<F%M;65T(&5R(&ML87)T+B(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R
M97,B"FUS9W-T<B`B3W!P9&%T97(@;V=SY2!R96MU<G-I=G0@;F5D;W9E<B!F
M;W(@=6YD97)M87!P97(O9FEL97(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]A<'!R;W9E+FEN8SHS,PIM<V=I9"`B07!P<F]V92(*;7-G<W1R(")';V1K
M:F5N;B(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-3<*;7-G
M:60@(D%P<')O>&EM871E(%-I>F4B"FUS9W-T<B`B3VUT<F5N=&QI9R!S=/AR
M<F5L<V4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,S<W(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,30*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I
M9"`B07!R:6PB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M-S$*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV,B!L:6(O2&]R9&4O
M34E-12]6:65W97(O>FEP+G!H<#HV-@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=&=Z+G!H<#HX,0IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T
M<B`B1FEL<W3X<G)E;'-E('#E(&%R:VEV970B"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O<F%R+G!H<#HV,2!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP
M+G!H<#HV-0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX,`IM
M<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(D%R:VEV;F%V;B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E
M('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R(")%<B!D=2!3
M24M+15(@<.4@870@9'4@=FEL(&9J97)N92!R96=I<W1R97)I;F=S9F]R97-P
M^')S96QE;B!F;W(@)7,_(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D
M96QE=&4N:6YC.CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E
M('EO=2!W:7-H('1O(&1E;&5T92`G)7,G(&%N9"!A;GD@<W5B+6=R;W5P<S\B
M"FUS9W-T<B`B17(@9'4@<VEK:V5R('#E(&%T(&1U('9I;"!S;&5T=&4@)R5S
M)R!O9R!D96YS('5N9&5R9W)U<'!E<C\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!<F=E;G1I;F$B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HU.`IM<V=I9"`B07)M96YI82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$W,@IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED
M(")!<G0B"FUS9W-T<B`B2W5N<W0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8P"FUS9VED(")!<G5B82(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO
M;B!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B07-C:6D@:W5N<W0B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B07-I82]086-I
M9FEC(%)E9VEO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#$U"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I
M;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`B0F4@;VT@8F5K
M<F5F=&5L<V4@9OAR(&=J96YN;VUF^')I;F<@878@=F5D;&EK96AO;&1S;W!E
M<F%S:F]N97(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S`Y.`IM<V=I9"`B
M07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(DMO;&]N;F5A;G9I<VYI;F<B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ-C8*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,C0Y"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C,Q.`IM<V=I
M9"`B071T86-H960@:7,@86X@:4-A;&5N9&%R(&9I;&4@<F5P;'D@=&\@82!R
M97%U97-T('EO=2!S96YT(@IM<V=S='(@(E9E9&QA9W0@:2!S=F%R970@97(@
M96X@:4-A;&5N9&%R(&9I;"!F;W(@96X@9F]R97-P^')S96P@9'4@<V5N9'1E
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-0IM<V=I9"`B071T96UP="!T;R!D
M96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(D9O<G/X:W1E
M(.4@<VQE='1E(&5N(&=R=7!P92!S;VT@:6MK92!E:W-I<W1E<F5R+B(*"B,Z
M(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z,S@*;7-G:60@(D%T=&5M<'0@=&\@
M9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(D9O
M<G/X:W1E(.4@<VQE='1E(&5N(')E='1I9VAE="!S;VT@:6MK92!E:W-I<W1E
M<F5R+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.CDX"FUS9VED(")!='1E
M;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T
M<B`B1F]R<_AK=&4@Y2!R961I9V5R92!E;B!R971T:6=H970@<V]M(&EK:V4@
M96MS:7-T97)E<BXB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*
M;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB
M"FUS9W-T<B`B1F]R<_AK=&4@Y2!R961I9V5R92!E;B!D96QT(')E<W-U<G,@
M<V]M(&EK:V4@96MS:7-T97)E<BXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HU-S<*;7-G:60@(D%T=&5N9&5E<R(*;7-G<W1R
M(")$96QT86=E<F4B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H
M<#HV-R!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,0HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX-@IM<V=I9"`B071T<FEB=71E
M<R(*;7-G<W1R(")!='1R:6)U="(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HS.#$@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B075S
M=')A;&EA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`BV'-T
M97)R:6ME(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HQ-C,*;7-G
M:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER<W%L.B!+86X@:6MK92!F:6YN92!D
M96X@;OAD=F5N9&EG92!)34%0('5T=FED96QS96XN(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O8WER=7,N<&AP.C$S-PIM<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N
M9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R
M(")!=71H7V-Y<G5S.B!"86-K96YD(&EN;F5H87(@:6MK92!N^&1V96YD:6<@
M9G5N:W-J;VYA;&ET970N(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP
M.C$R-`IM<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!+86X@:6MK92!F
M:6YN92!D96X@;OAD=F5N9&EG92!)34%0('5T=FED96QS96XN(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O9G1P+G!H<#HT,`IM<V=I9"`B(@HB075T:%]F='`Z(%)E
M<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W
M:71H('1H92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B"B)!
M=71H7V9T<#H@2V%N(&EK:V4@9FEN;F4@9&5N(&[X9'9E;F1I9V4@1E10('5T
M=FED96QS96XN($MO;7!I;&5R(%!(4"!M960@+2TB"B)E;F%B;&4M9G1P+B(*
M"B,Z(&QI8B](;W)D92]!=71H+VEM87`N<&AP.C8X"FUS9VED(")!=71H7VEM
M87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B075T:%]I;6%P.B!+86X@:6MK92!F:6YN92!D96X@;OAD=F5N9&EG92!)
M34%0('5T=FED96QS96XN(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z
M-3,*;7-G:60@(D%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VMR8C4Z($MA;B!I:VME(&9I;FYE
M(&1E;B!N^&1V96YD:6=E(&MR8C4@=71V:61E;'-E;BXB"@HC.B!L:6(O2&]R
M9&4O075T:"]L9&%P+G!H<#HV,0IM<V=I9"`B075T:%]L9&%P.B!297%U:7)E
M9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;&1A
M<#H@2V%N(&EK:V4@9FEN;F4@9&5N(&[X9'9E;F1I9V4@3$1!4"!U='9I9&5L
M<V5N+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C$X.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E
M<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(D%U
M=&A?;&1A<#H@2W5N;F4@:6MK92!L96=G92!T:6P@8G)U:V5R("5S+B!397)V
M97)E;B!S83H@(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,C(Y"B,L
M('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V
M92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@2W5N;F4@:6MK92!F:F5R
M;F4@8G)U:V5R96X@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HR
M.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@
M=7!D871E('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B!+=6YN92!I:VME
M(&]P<&1A=&5R92!B<G5K97(@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]M8V%L
M+G!H<#HU,`IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;6-A;#H@2V%N(&EK:V4@
M9FEN;F4@9&5N(&[X9'9E;F1I9V4@34-!3"!U='9I9&5L<V5N+B(*"B,Z(&QI
M8B](;W)D92]!=71H+W-M8BYP:'`Z-C4*;7-G:60@(D%U=&A?<VUB875T:#H@
M4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M(")!=71H7W-M8F%U=&@Z($MA;B!I:VME(&9I;FYE(&1E;B!N^&1V96YD:6=E
M('-M8F%U=&@@=71V:61E;'-E;BXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D
M(@IM<V=S='(@(D%U=&5N=&ES97)I;F<@9F5I;&5T(@H*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HV.2!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I
M8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`B075T96YT:7-E<FEN9R!F96EL
M970N("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O<F%D:75S+G!H<#HQ.#$*;7-G
M:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N
M(@IM<V=S='(@(D%U=&5N=&ES97)I;F<@;F5K=&5T(&%V(%)!1$E54R!T:F5N
M97(N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@P,`IM<V=I9"`B075T:&5N=&EC
M871I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(D%U=&5N=&ES
M97)I;F<@;6]T($944"!T:F5N97)E;B!F96EL970N(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHX,PIM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB
M"FUS9W-T<B`B5&EL9VIE;F=E;&EG92!F96QT.B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8Q-`IM<V=I9"`B07=A:71I;F<@
M4F5S<&]N<V4B"FUS9W-T<B`B5F5N=&5R('#E('-V87(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS9VED(")!>F5R
M8F%I:F%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M,`IM<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(D)/1D@@17AC=7-E<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`B0F%K9W)U;FXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(S"FUS
M9VED(")"86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(D)A:V=R=6YN<V9A<F=E
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@(D)A9"!K
M97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`B1F5I;"!K97)B97)O<R!P87-S
M;W)D+B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C@U"FUS9VED(")"
M860@:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@(D9E:6P@:V5R8F5R;W,@
M8G)U:V5R;F%V;BXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#4@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8S"FUS9VED(")"86AA;6%S(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HS."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@
M(D)A:')A:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M-S,*;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HS-"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G
M:60@(D)A;F=L861E<V@B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C,S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%R8F%D;W,B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U.3,*;7-G:60@(D)A
M<F4B"FUS9W-T<B`B0FQA;FLB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z
M,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O
M<GD@)R5S)R!N;W0@9F]U;F0N(@IM<V=S='(@(D)A<V5K871A;&]G(&9O<B!G
M<F%F:6MK("<E<R<@8FQE(&EK:V4@9G5N;F5T+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PIM<V=I9"`B0F%S
M96QI;F4B"FUS9W-T<B`B1W)U;FYL:6YJ92(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HT.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D)E;&%R=7,B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,U(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV,0IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R(")"96QI9V$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C,R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8T"FUS9VED
M(")"96QI>F4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C0P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5N:6XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0Q(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HS-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PIM
M<V=I9"`B0F5R;75D82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8T"FUS9VED(")":'5T86XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,30*
M;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(D)U<G-D86<B"@HC.B!L:6(O2&]R
M9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(V"B,L('!H<"UF;W)M870*;7-G
M:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O
M=6YD+B(*;7-G<W1R(")";&]K:R!<(B5S7"(@878@<')O9W)A;6UE="!<(B5S
M7"(@8FQE(&EK:V4@9G5N;F5T+B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHX.0IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B0FQO
M:VL@:6YN<W1I;&QI;F=E<B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T
M+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R(")";&]K:R!T>7!E
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M"FUS9VED(")";VQD(@IM<V=S='(@(D9E="(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HT,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O;&EV:6$B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X-@IM<V=I
M9"`B0F]O:VUA<FMS(@IM<V=S='(@(D)O:VUE<FME<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*;7-G:60@
M(D)O<F1E<B(*;7-G<W1R(")286UM92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE
M<W,Z(@IM<V=S='(@(E)A;6UE='EK:V5L<V4Z(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0IM<V=I9"`B0F]R
M9&5R<R(*;7-G<W1R(")286UM97(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")";W-N:6$@86YD($AE<GIE
M9V]V:6YA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY
M-@IM<V=I9"`B0F]T:"(*;7-G<W1R(")"96=G92(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HT."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D)O='-W86YA
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(D)U;FXB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C,Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8T
M"FUS9VED(")";W5V970@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HT-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)R87II
M;"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX,@IM<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R
M<FET;W)Y(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM
M<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV-C$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0G5I;&1I;F<@34\@9FEL97,@9F]R(&UO9'5L92`E<RXN
M+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C<S"B,L('!H
M<"UF;W)M870*;7-G:60@(D)U:6QD:6YG(&QO8V%L92`E<RXN+B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,W(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV,@IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T
M960@3&ES="(*;7-G<W1R(")0=6YK=&QI<W1E(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C,V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G5R:VEN82!&
M87-O(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS.2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C(*;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,Y-PIM<V=I9"`B0TU3(@IM<V=S
M='(@(D--4R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<U
M"FUS9VED(")#4D,B"FUS9W-T<B`B0U)#(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HV,C$*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S
M(@IM<V=S='(@(D-23"!$:7-T<FEB=7-J;VYS<'5N:W1E<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-PIM
M<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")%9V5N<VMA<&5R
M(&9O<B!C7V5L;&4N+BXB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#4V(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-#,*;7-G
M:60@(D-A;&5N9&%R(@IM<V=S='(@(DMA;&5N9&5R(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(P.0IM<V=I9"`B0V%L;2(*;7-G<W1R(")3
M=&EL;&4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(X(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX-`IM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C8P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HT-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0V%M
M97)O;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC
M86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(DMA
M;B!I:VME(&YU;&QS=&EL;&4@<&%S<V]R9"!A=71O;6%T:7-K+"!K;VYT86MT
M(&1I;B!A9&UI;FES=')A=&]R+B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S
M+G!H<#HR-#$@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HS,3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@
M)7,B"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL($E-05`@=&IE;F5R96XZ
M("5S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4Q(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV-0IM<V=I9"`B0V%N861A(@IM<V=S='(@(DMA;F%D82(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$P,2!A9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8U"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E
M<B]C;&5A<BYI;F,Z,3<*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M+FEN8SHQ-PIM<V=I9"`B0V%N8V5L(@IM<V=S='(@(D%V8G)Y="(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@
M4')O8FQE;2!297!O<G0B"FUS9W-T<B`B079B<GET('!R;V)L96UR87!P;W)T
M(@H*(SH@;&EB+U9&4R]F='`N<&AP.C(V.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")+86X@:6MK
M92!S;&5T=&4@9FEL96X@7"(E<UPB+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0W"B,Z(&QI8B]61E,O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU,PIM<V=I9"`B
M0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R(")+
M86X@:6MK92!F:6YN92!E;B!T96UP+6MA=&%L;V<N(@H*(SH@;&EB+U9&4R])
M4T]7<FET97(N<&AP.CDW"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T
M("=T87)G971&:6QE)R!P87)A;65T97(N(@IM<V=S='(@(DMA;B!I:VME(&9O
M<G1S971T92!U=&5N("=T87)G971&:6QE)R!P87)A;65T97(N(@H*(SH@;&EB
M+U9&4R]F='`N<&AP.C(V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@
M<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DMA;B!I:VME('-L
M971T92!K871A;&]G96X@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92]$871A5')E
M92YP:'`Z,3$R(&QI8B](;W)D92]$871A5')E92]S<6PN<&AP.C4W.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E
M>&ES="XB"FUS9W-T<B`B2V%N(&EK:V4@<VQE='1E+"`E9"!B87)N(&5K<VES
M=&5R97(N(@H*(SH@;&EB+TAO<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS
M9VED("(B"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P
M<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T
M;W)E9"XB"FUS9W-T<B`B(@HB2V%N(&EK:V4@96YD<F4@<F5K:V5F^&QG96XL
M(&%N=&%L;&5T(&]P<&;X<FEN9V5R('9A;&=T(&9O<B!O;7-O<G1E<FEN9R`B
M"B)S=&5M;65R(&EK:V4@;65D(&%N=&%L;&5T(&QA9W)E9&4@;W!P9OAR:6YG
M97(N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3@*
M;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB
M97(N(@IM<V=S='(@(DMA;B!I:VME('-E;F1E(&UE;&1I;F=E;B!T:6P@9&5T
M('-P97-I9FES97)T92!N=6UM97)E="XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#87!E(%9E<F1E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C0*;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`B571D<F%G
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP"FUS9VED(")#871E9V]R
M:65S(&%N9"!,86)E;',B"FUS9W-T<B`B2V%T96=O<FEE<B!O9R!E=&EK971T
M97(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,U(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX-PIM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3<*;7-G:60@(D-E;&P@
M4&AO;F4B"FUS9W-T<B`B36]B:6QT96QE9F]N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0IM<V=I9"`B0V5L
M;"!0<F]P97)T:65S(@IM<V=S='(@(D5G96YS:V%P97(@9F]R(&-E;&QE(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*
M;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B3'5F="!R=6YD="!I;FYH
M;VQD(&%V(&-E;&QE.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*
M;7-G<W1R(")%9V5N<VMA<&5R(&9O<B!C96QL92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS9VED(")#96QL('-P
M86-I;F<Z(@IM<V=S='(@(DQU9G0@<G5N9'0@8V5L;&5N.B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,C8V"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`B
M36]B:6QT96QE9F]N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S0*;7-G
M:60@(D-E;'1I8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*;7-G
M:60@(D-E;G1E<B(*;7-G<W1R(")396YT97(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#96YT<F%L($%F
M<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ-S4*;7-G:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S(S
M"FUS9VED(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(D1E=&%L:F5R
M(&9O<B!S97)T:69I:V%T(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HV,C`*;7-G:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(E)E
M='1N:6YG<VQI;FIE<B!F;W(@<V5R=&EF:6MA="(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4R
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B0VAA9"(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HU.38*;7-G:60@(D-H86ER(%!E<G-O;B(*;7-G<W1R(")/<F1S='ER
M97(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDW"FUS9VED(")#:&%N9V4B"FUS9W-T
M<B`B16YD<F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G:60@
M(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S
M964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS
M+B(*;7-G<W1R("(B"B)%;F1R92!N879N(&]G(&%D<F5S<V4@<V]M(&UO='1A
M:V5R92!S97(@;N5R(&1E(&QE<V5R(&]G('-V87)E<B!PY2!P;W-T96X@9&EN
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C<*;7-G:60@(D-H87(B"FUS9W-T<B`B5&5G;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM
M<V=I9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`B4VIE:U]K(&QI;FLN+BXB
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC.C$S
M"FUS9VED(")#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO
M=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R(")696QG
M(&1E(&]P97)A<VIO;F5N92!D=2!V:6P@=71F^')E(&[E+B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HU.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H
M:6QE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H:6YA(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3<V"FUS9VED(")#:&EN97-E(%-I;7!L:69I
M960@*$=",C,Q,BDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ-S<*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C@R"FUS9VED
M(")#:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R(")696QG(&5T="!P87-S;W)D
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR.#$*;7-G:60@(D-H
M;V]S92!A('5S97)N86UE(@IM<V=S='(@(E9E;&<@971T(&)R=6ME<FYA=FXB
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT-3(*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C(V"FUS
M9VED(")#:&]O<V4@86X@86-T:6]N.B(*;7-G<W1R(")696QG(&AA;F1L:6YG
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.#@*;7-G:60@(D-H;V]S
M92!H;W<@=&\@9&ES<&QA>2!D871E<SHB"FUS9W-T<B`B5F5L9R!H=F]R9&%N
M(&1U('9I;"!V:7-E(&1A=&]E<CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@
M;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B
M5F5L9R!S=&EL('#E(&QI<W1E='EP92`H9F]R(&YU;6UE<F5R=&4@;&ES=&5R
M*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-CD*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB
M+U9&4RYP:'`Z-C4U(&QI8B].970O4TU3+G!H<#HS,3$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM
M<V=S='(@(DML87-S961E9FEN:7-J;VX@9F]R("5S(&)L92!I:VME(&9U;FYE
M="XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#4U"B,L('!H<"UF;W)M870*
M;7-G:60@(D-L96%N:6YG('5P(%!/(&9I;&5S(&9O<B!M;V1U;&4@)7,N+BXB
M"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C@V-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;&5A;FEN9R!U<"!L;V-A;&4@)7,N+BX@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,C@*;7-G
M:60@(D-L96%R(@IM<V=S='(@(DML87)T(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I
M8V4@=&%G<R(*;7-G<W1R(")&:F5R;B!-4T]F9FEC92!T86=S(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM<V=S='(@(D9J97)N(&)R=6ME
M<CH@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,38*
M;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B1FIE<FX@8G)U:V5R(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S<*;7-G:60@(D-L96%R
M('5S97(@9&%T82(*;7-G<W1R(")&:F5R;B!B<G5K97)D871A(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+VYO=&EC95]B;W1T;VTN:6YC.C8*;7-G:60@
M(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(DML:6MK(&9O<B#E(&9O<G1S
M971T92(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@V
M"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(D-L:6-K871E
M;&P@=FEA($A45%`B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I;F1O
M=R(*;7-G<W1R("),=6MK('9I;F1U(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR-#(*;7-G:60@(D-L;W5D<R(*;7-G<W1R(")3:WEE<B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,CD*;7-G:60@(D-L;W5D>2(*;7-G
M<W1R(")3:WEE="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C4*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z-`IM
M<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R(")3;.4@<V%M;65N('-I
M9&5L:6YJ96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(X"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G
M<W1R(")386UM96YS;.5T="!R86UM92(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HV,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-O;&]M8FEA(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O
M;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(Y"FUS9VED(")#;VQO<B(*;7-G<W1R(")&87)G92(*
M"B,Z(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HR.3<@;&EB+TAO
M<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C(Y.`HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#<R('-E<G9I8V5S+VEM86=E<R]C;VQO
M<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z-3$*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z-3(*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z-C@*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z-CD*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z.#4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z.#8*;7-G:60@(D-O;&]R(%!I8VME<B(*;7-G<W1R(")&
M87)G979E;&=E<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#,U"FUS9VED
M(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@(D9A<F=E=F%L9R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"B,L(&9U
M>GIY"FUS9VED(")#;VQS.B(*;7-G<W1R(")+;VQO;FYE<CHB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3DS,`IM<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G
M<W1R(")+;VQO;FYE+71I=&QE<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR.#D*;7-G:60@(D-O;6EC<R(*;7-G<W1R(")496=N97-E<FEE<B(*
M"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-0IM<V=I9"`B0V]M;6%N9"(*;7-G
M<W1R(")+;VUM86YD;R(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I
M9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R(")+;VUM86YD;W9I;F1U(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C,X"FUS9VED(")#;VUM86YD(&]P=&EO;G,Z
M(@IM<V=S='(@(E9A;&<@9F]R(&MO;6UA;F1O.B(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HY-PIM<V=I9"`B0V]M;6%N9',Z(@IM<V=S='(@(DMO;6UA;F1O
M97(Z(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,SDY"FUS9VED(")#
M;VUM96YT(@IM<V=S='(@(DMO;6UE;G1A<B(*"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HY.34*;7-G:60@(D-O;6UI='1I;F<Z(@IM<V=S='(@(E-J96MK(&EN
M;CHB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y,`IM<V=I9"`B
M0V]M;6]N($YA;64B"FUS9W-T<B`B5F%N;&EG(&YA=FXB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3,P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HU.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B0V]M
M;W)O<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C(T,@IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R(")&:7)M82(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8Y-PIM<V=I
M9"`B0V]M<&QE=&5D(@IM<V=S='(@(D9E<F1I9R(*"B,Z(&QI8B](;W)D92]4
M97AT+T9I;'1E<B]E;6%I;',N<&AP.C@Q(&QI8B](;W)D92]497AT+T9I;'1E
M<B]E;6%I;',N<&AP.C@W"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]E;6%I
M;',N<&AP.CDW(&QI8B](;W)D92]497AT+T9I;'1E<B]E;6%I;',N<&AP.C$P
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VUP;W-E($UE<W-A9V4@*"5S*2(*
M;7-G<W1R(")3:W)I=B!M96QD:6YG("@E<RDB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R(")$871A;6%S
M:VEN97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-PIM<V=I9"`B0V]N
M9&ET:6]N<R(*;7-G<W1R(")6:6QKY7(B"@HC.B!A9&UI;B]S971U<"]D:69F
M+G!H<#HX.0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*;7-G
M<W1R(")&;W)S:VIE;&QE<B!I(&EN;G-T:6QL:6YG96YE(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$R-0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!N965D
M<R!U<&1A=&EN9RXB"FUS9W-T<B`B26YN<W1I;&QI;F=E<B!B96CX=F5R(&]P
M<&1A=&5R:6YG+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HY.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B2V]N9FEG
M=7)E<B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M,S<*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B0F5K<F5F="!P
M87-S;W)D(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4U(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV-PIM<V=I9"`B0V]N9V\B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C4S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV
M,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N9V\L
M(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C`V(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3D*;7-G:60@(D-O;FYE8W1I;VX@
M9F%I;&5D+B(*;7-G<W1R(")4:6QK;V)L:6YG(&UI<VQY:W1E<RXB"@HC.B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C`V(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS,3D*;7-G:60@(D-O;FYE8W1I;VX@9F%I
M;&5D.B`B"FUS9W-T<B`B5&EL:V]B;&EN9R!M:7-L>6MT97,Z("(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C<Y,PIM<V=I9"`B0V]N;F5C=&EO;B!R
M969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")+;V)L
M:6YG96X@=&EL(&1E;B!O9F9E;G1L:6=E(&[X:VME;'1J96YE<F5N(&9E:6QE
M="XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW.34*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B2V]B;&EN9V5N
M('1I;"!D96X@;V9F96YT;&EG92!N^&MK96QT:F5N97)E;B!F96EL970N(,5R
M<V%K.B`E<R`H)7,I(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<Y-`IM<V=I9"`B
M0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B2V]B
M;&EN9V5N('1I;"!&5%`@=&IE;F5R96X@;6ES;'EK=&5S+B(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-38*;7-G:60@(D-O;G1A8W1S
M('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K
M+B(*;7-G<W1R(")+;VYT86MT96YE(&)L92!L86=T('1I;"!A9')E<W-E8F]K
M96XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HU.2!L:6(O
M2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=&=Z+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT
M96YT<R!O9B`G)7,G(@IM<V=S='(@(DEN;FAO;&0@:2`G)7,G(@H*(SH@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD*;7-G:60@(D-O;G1I;G5E(@IM
M<V=S='(@(D9O<G1S971T(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4X
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]O:R!)<VQA;F1S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O:VEE
M(@IM<V=S='(@(D-O;VMI92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0IM<V=I9"`B0V]P>2(*;7-G<W1R
M(")+;W!I97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R(")+;W!I
M97(@=F%L9W0@;VURY61E(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P-S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P>6EN9R`E<R!T;R`E<R(*;7-G<W1R
M(")+;W!I97)E<B`E<R!T:6P@)7,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#;W-T82!2:6-A(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C<*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.3<W"FUS9VED(")#;W5L9"!N;W0@4$=0
M(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B2W5N;F4@:6MK92!01U`M:W)Y
M<'1E<F4@;65L9&EN9R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$P
M-34*;7-G:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+B(*;7-G<W1R
M(")+=6YN92!I:VME(%!'4"US:6=N97)E(&UE;&1I;F<B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C0Q,0IM<V=I9"`B0V]U;&0@;F]T(%,O34E-
M12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(DMU;FYE(&EK:V4@:W)Y<'1E
M<F4@;65L9&EN9V5N(&UE9"!3+TU)344N(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HT.#4*;7-G:60@(D-O=6QD(&YO="!3+TU)344@<VEG;B!M
M97-S86=E+B(*;7-G<W1R(")+=6YN92!I:VME('-I9VYE<F4@;65L9&EN9V5N
M(&UE9"!3+TU)344N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C$X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O
M;G1A8W0N("5S(@IM<V=S='(@(DMU;FYE(&EK:V4@;&5G9V4@=&EL(&MO;G1A
M:W0Z("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,3$S"FUS9VED
M(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B5&EL
M:V]B;&EN9R!T:6P@3$1!4"US97)V97(@9F5I;&5T+B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-30@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HQ-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@(DMU;FYE(&EK:V4@<VIE
M:VME('1I;&=J96YG96QI9R!K<F5D:71T+B`E<R(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M8V]N;F5C="!T;R!S97)V97(@)R5S)R!U<VEN9R!&5%`Z("5S(@IM<V=S='(@
M(DML87)T92!I:VME(.4@:V]B;&4@=&EL('1J96YE<F5N("<E<R<@=F5D(&)R
M=6L@878@1E10.B`E<R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#<U"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;W!Y("5S('1O("5S(@IM
M<V=S='(@(DMU;FYE(&EK:V4@:V]P:65R92`E<R!T:6P@)7,B"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S
M(@IM<V=S='(@(DMU;FYE(&EK:V4@;&%G92!D:7-T<FEB=7-J;VYS;&ES=&4N
M("5S(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8X,2!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,3`V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E
M871E(&QO8V%L92!D:7)E8W1O<GD@9F]R(&QO8V%L92`E<SHB"FUS9W-T<B`B
M2W5N;F4@:6MK92!O<'!R971T92!L;V-A;&4@:V%T86QO9R!F;W(@;&]C86QE
M("5S.B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q,C8*;7-G:60@
M(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+B(*;7-G<W1R(")+=6YN92!I
M:VME(&1E:W)Y<'1E<F4@4$=0(&UE;&1I;F<N(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU-#`*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%,O
M34E-12!D871A+B(*;7-G<W1R(")+=6YN92!I:VME(&1E:W)Y<'1E<F4@4R]-
M24U%(&UE;&1I;F<N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C(U,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E
M(&-O;G1A8W0N("5S(@IM<V=S='(@(DML87)T92!I:VME(.4@<VQE='1E(&MO
M;G1A:W0N("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C,V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")+;&%R=&4@:6MK92#E('-L
M971T92!D:7-T<FEB=7-J;VYS;&ES=&4N("5S(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="`G)7,G+B(*;7-G<W1R(")+
M=6YN92!I:VME('-L971T92!S971U<"!O<'!G<F%D97)I;F=S<V-R:7!T("<E
M<R<N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS.3D@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z.34Y"FUS9VED(")#;W5L9"!N;W0@9&5T97)M
M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T<B`B
M2W5N;F4@:6MK92!F:6YN92!M;W1T86ME<G,@92UP;W-T(&%D<F5S<V4N(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X.`IM<V=I9"`B
M0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T
M<B`B2W5N;F4@:6MK92!H96YT92!U="!H96QE(&%D<F5S<V5B;VME;BXB"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$P"FUS9VED(")#
M;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM
M<V=S='(@(DMU;FYE(&EK:V4@=70@:&5L92!D:7-T<FEB=7-J;VYS;&ES=&5N
M+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-C$*;7-G
M:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T
M<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(DMU;FYE(&EK:V4@:&5N=&4@=70@
M:&5L92!L:7-T96X@;65D(&1I<W1R:6)U<VIO;G-L:7-T97(N(@H*(SH@;&EB
M+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.0HC.B!L
M:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@)R5S
M)RXB"FUS9W-T<B`B2W5N;F4@:6MK92!L87-T92!I;FX@<W1R871E9VD@)R5S
M)RXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HQ,3$*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T
M<F%T96=Y+V1I<F5C="YP:'`Z,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&UK9&ER("<E<R<N(@IM<V=S='(@(DMU;FYE(&EK:V4@;W!P<F5T
M=&4@:V%T86QO9V5N("<E<R<N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z-S(P"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O
M;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R(")+=6YN92!I:VME(&AE;G1E('5T
M(&]F9F5N=&QI9R!N^&MK96P@9G)A(&[X:VME;'1J96YE<F5N+B(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HW,#(@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@(DMU;FYE(&EK:V4@Y7!N92`E
M<RXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HQ-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P
M96X@)R5S)R!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B2W5N;F4@:6MK92#E<&YE
M("<E<R<@9F]R('-K<FEV:6YG+B(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC
M92YP:'`Z-#$U"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N
M($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(DMA;B!I:VME
M(.5P;F4@36%I;G1E;F%N8V5?5&%S:RUM;V1U;&5N("5S(@H*(SH@;&EB+U9&
M4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y("<E
M<R<N(@IM<V=S='(@(DMU;FYE(&EK:V4@Y7!N92!K871A;&]G96X@)R5S)RXB
M"@HC.B!L:6(O5D93+T]B:F5C="YP:'`Z,C<P"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!R96%D("5S+B(*;7-G<W1R(")+=6YN92!I:VME(&QE
M<V4@)7,B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM<V=I
M9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E
M<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A
M<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M
M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S
M='(@(B(*(DMU;FYE(&EK:V4@;G5L;'-T:6QL92!P87-S;W)D970@9F]R(&1E
M;B!F;W)E<W!U<G1E(&)R=6ME<F5N+B!.;V5N(&5L;&5R(&%L;&4@(@HB9&5T
M86QJ96YE(&5R('5R:6MT:6=E+B!&;W)S^&L@:6=J96X@96QL97(@:V]N=&%K
M="!A9&UI;FES=')A=&]R96X@:'9I<R!D=2`B"B)T<F5N9V5R('ET=&5R;&EG
M97)E(&AJ96QP+B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS,3@@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T.0HC.B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@V(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS.3(*(SH@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,Y.`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#
M3"(*;7-G<W1R(")+=6YN92!I:VME(&AE;G1E('5T($%#3"(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-SD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,B"FUS
M9W-T<B`B2W5N;F4@:6MK92!H96YT92!U="!A9')E<W-E8F]K+B`E<R(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,#$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<R(*;7-G<W1R(")+=6YN92!I:VME(&AE;G1E('5T(&1I<W1R:6)U
M<VIO;G-L:7-T92X@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-#4R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R
M:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@(DMU;FYE(&EK
M:V4@:&5N=&4@=70@9&ES=')I8G5S:F]N<VQI<W1E+B`E<R(*"B,Z(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,#8@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C(R-@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,C,P"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R
M)W,@8V%P86)I;&ET:65S(@IM<V=S='(@(DMU;FYE(&EK:V4@:&5N=&4@=70@
M:6YF;W)M87-J;VX@;VT@=&IE;F5R96YS(&9U;FMS:F]N86QI=&5T97(B"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"FUS9VED(")#;W5L9"!N;W0@
M<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DMU;FYE(&EK:V4@<F5V
M97)T97)E(&MO;F9I9W5R87-J;VYE;F4N(@H*(SH@;&EB+U9&4R])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.34*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER("<E<R<N(@IM<V=S='(@(DMU;FYE
M(&EK:V4@9FIE<FYE(&MA=&%L;V=E;B`G)7,G+B(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!S879E("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DMU;FYE(&EK:V4@
M;&%G<F4@)7,@:V]N9FEG=7)A<VIO;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(D-O
M=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B
M2W5N;F4@:6MK92!L86=R92!E;B!B86-K=7`@:V]N9FEG=7)A<VIO;BXB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*
M;7-G<W1R(")+=6YN92!I:VME(&QA9W)E(&5N(&)A8VMU<"!C;VYF:6=U<F%S
M:F]N.B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDR"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@
M<V-R:7!T('1O.B`G)7,G+B(*;7-G<W1R(")+=6YN92!I:VME(&QA9W)E('-E
M='5P(&]P<&=R861E<FEN9W,M<V-R:7!T970@=&EL.B`G)7,G+B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N(@IM<V=S='(@(DMU;FYE(&EK:V4@;&%G<F4@8F%C:W5P(&MO;F9I9W5R
M87-J;VYS9FEL96X@)7,N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@
M8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE
M(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E
M<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*;7-G
M<W1R("(B"B)+=6YN92!I:VME(&QA9W)E(&MO;F9I9W5R87-J;VYS9FEL96X@
M)7,N($1U(&MA;B!E;G1E;B!B96YY='1E(&1E9R!A=B!E;B!A=B`B"B)M=6QI
M9VAE=&5N92!F;W(@Y2!L86=R92!D871A('1I;&)A:V4@=&EL("5S(&5L;&5R
M(&MO<&EE<F4@:V]D96X@=6YD97(@(@HB;6%N=65L="!T:6P@)7,N(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,3(S"FUS9VED(")#;W5L9"!N;W0@
M<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B2W5N;F4@:6MK92!U
M=&;X<F4@<_AK('#E($Q$05`@=&IE;F5R96XN(@H*(SH@;&EB+U9&4R])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R`G)7,G+B(*;7-G<W1R(")+
M=6YN92!I:VME(&9J97)N92`G)7,G+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HR,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('5P9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R(")+=6YN92!I:VME(&]P
M<&1A=&5R92!K;VYT86MT+B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HT,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B2W5N;F4@
M:6MK92!O<'!D871E<F4@9&ES=')I8G5S:F]N<VQI<W1E;BX@)7,B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R("<E<R<Z("5S(@IM
M<V=S='(@(DMU;FYE(&EK:V4@<VMR:79E(&MO;F9I9W5R87-J;VX@9F]R("<E
M<R<Z("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U-@IM<V=I9"`B
M0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@
M=&AE('-I9&5B87(@:7,@;W!E;BXB"FUS9W-T<B`B2W5N;F4@:6MK92!F:6YN
M92!-;WII;&QA(%-I9&5B87(N(%-J96MK(&%T(&1E;B!E<B#E<&5N+B(*"B,Z
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&1N)W0@9VEV92!U<V5R("<E<R<@=&AE(&9O;&QO
M=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@)R5S)SH@)7,B"FUS9W-T<B`B
M0G)U:V5R96X@)R5S)R!B;&4@9VET="!F^&QG96YD92!R971T:6=H971E<B!T
M:6P@;6%P<&5N("<E<R<Z("5S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T
M,38*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R(")486QT('1E:W-T(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(D-O=6YT
M<GDB"FUS9W-T<B`B3&%N9"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR-S,*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B2W5R<V5R(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHY-PHC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M,3`Q"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B3W!P<F5T="(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM
M<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R(")/<'!R971T(&5N(&QI;FLB
M"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.C@Y"FUS
M9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(D]P<')E='0@96X@;GDB
M"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.34*;7-G:60@
M(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R(")/<'!R971T('5N9&5R;6%P
M<&5R(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3,V(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,C(R"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM
M<V=S='(@(E)E='1I9VAE=&5R(&9O<B!E:65R(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C,R,34*;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R
M(")+<F5D:71T:V]R=&YU;6UE<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@P"FUS9VED(")#<F]A=&EA(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-CD*;7-G:60@(D-U8F$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C(V"FUS9VED(")#=7)R96YT(%!H87-E(@IM<V=S='(@(D=J96QD96YD
M92!F87-E(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I
M;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T<B`B1VIE;&1E
M;F1E('1I9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU,PHC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!54DP@
M:7,B"FUS9W-T<B`B1VIE;&1E;F1E(%523"!E<B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C4*;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R(")'
M:F5L9&5N9&4@=N9R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(S,PIM<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R(")':F5L
M9&5N9&4@=71S:6MT97(Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T
M<B`B1VIE;&1E;F1E('-T:6PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3`X"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R
M=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B5&EL<&%S<R!O<'!G879E
M<B!S;VT@:VKX<F5S('9E9"!I;FYL;V=G:6YG('1I;"`E<RXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*
M;7-G:60@(D-U="(*;7-G<W1R(")+;&EP<"!U="(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE
M8W1I;VXB"FUS9W-T<B`B2VQI<'`@=70@=F%L9W0@;VURY61E(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C8W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HV-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B
M0WEP<G5S(@IM<V=S='(@(DMY<')O<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3<X"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B0WER:6QL:6,@*%=I
M;F1O=W,M,3(U,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#`*;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C@@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<P"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#(S('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R(")$1"(*"B,Z(&QI
M8B](;W)D92]-86EN=&5N86YC92YP:'`Z,S@*;7-G:60@(D1A:6QY(@IM<V=S
M='(@(D1A9VQI9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C,*
M;7-G:60@(D1A=&$B"FUS9W-T<B`B1&%T82(*"B,Z(&%D;6EN+V1A=&%T<F5E
M+G!H<#HV-0IM<V=I9"`B1&%T851R964@0G)O=W-E<B(*;7-G<W1R(")$871A
M5')E('5T9F]R<VME<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S@R(&QI
M8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<W"FUS9VED(")$871E
M(@IM<V=S='(@(D1A=&\B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R
M;W9E+FEN8SHQ,@IM<V=I9"`B1&%T92!296-E:79E9"(*;7-G<W1R(")$871O
M($UO='1A='0B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y-@IM<V=I9"`B
M1&%T92!S96QE8W1I;VXB"FUS9W-T<B`B1&%T;R!V86QG(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(W-PIM<V=I9"`B1&%Y(@IM<V=S='(@
M(D1A9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS-0IM<V=I9"`B1&5?;&5T92!#;VQU;6XB"FUS9W-T<B`B
M4VQE='0@:V]L;VYN92(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HS.#4@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0R,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C<V"FUS9VED(")$96-E;6)E<B(*;7-G<W1R(")$97-E;6)E<B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,38*;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R(")$97-I;6%L=&%L
M;"(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8X
M-0IM<V=I9"`B1&5C;&EN960B"FUS9W-T<B`B079S;.5T="(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C`*;7-G:60@(D1E
M8W)E87-E($EN9&5N="(*;7-G<W1R(")2961U<V5R(&EN;G)Y:VLB"@HC.B!L
M:6(O<')E9G,N<&AP.C$P."!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$Y,0IM
M<V=I9"`B1&5F875L="(*;7-G<W1R(")3=&%N9&%R9"(*"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0W"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q"FUS9VED(")$969A
M=6QT($-O;&]R(@IM<V=S='(@(E-T86YD87)D(&9A<F=E(@H*(SH@;&EB+TAO
M<F1E+TED96YT:71Y+G!H<#HY,@IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*
M;7-G<W1R(")3=&%N9&%R9&ED96YT:71E="(*"B,Z(&%D;6EN+W!E<FUS+V5D
M:70N<&AP.C$Q.2!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(P-`IM<V=I9"`B
M1&5F875L="!097)M:7-S:6]N<R(*;7-G<W1R(")3=&%N9&%R9"!R971T:6=H
M971E<B(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,C`U"FUS9VED(")$
M969A=6QT('!E<FUI<W-I;VYS(@IM<V=S='(@(E-T86YD87)D(')E='1I9VAE
M=&5R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I
M;FET:6]N<R(*;7-G<W1R(")$969I;FES:F]N97(B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV-#,*;7-G:60@(D1E;&5G871E
M('!O<VET:6]N(@IM<V=S='(@(D1E;&5G97(@<&]S:7-J;VXB"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV.3,*;7-G:60@(D1E
M;&5G871E9"(*;7-G<W1R(")$96QE9V5R="(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z-S(@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-B!A9&UI;B]P97)M<R]D
M96QE=&4N<&AP.C4R"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,CDW(&QI8B](
M;W)D92]097)M<R]522YP:'`Z,S(W"B,Z(&QI8B](;W)D92]097)M<R]522YP
M:'`Z,S0W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S8*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHW,"!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.CDS"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$V('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3,Y"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3@R('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,PHC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3D@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$S"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C,T"FUS9VED(")$96QE=&4B"FUS9W-T<B`B4VQE='0B
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$X.2!A9&UI;B]G<F]U<',N<&AP.C(Q
M-PIM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@(E-L971T(&=R=7!P92(*
M"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-C`@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HX-`IM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B
M4VQE='0@<F5T=&EG:&5T(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.CDV"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM
M<V=S='(@(E-L971T(&]G(&9J97)N(&UE;&1I;F=E<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3<*;7-G:60@
M(D1E;&5T92!C96QL(@IM<V=S='(@(E-L971T(&-E;&QE(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I
M9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R(")3;&5T="!K;VQO;FYE(@H*(SH@
M861M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN
M9R!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B4VQE='0@96MS:7-T97)E
M;F1E(&%L=&5R;F%T:78@;6%L(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H
M<#HU,"!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,R-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R("<E<R<B"FUS9W-T<B`B
M1FIE<FX@<F5T=&EG:&5T96YE('1I;"`G)7,G(@H*(SH@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HS,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E
M<FUI<W-I;VYS(&9O<B`G)7,G(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*
M;7-G<W1R(")&:F5R;B!R971T:6=H971E;F4@=&EL("<E<R<@;V<@86QL92!U
M;F1E<BUR971T:6=H971E<C\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@<F]W(@IM
M<V=S='(@(E-L971T(')A9"(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I
M9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET
M>2(*;7-G<W1R(")3;&5T="!V86QG="!I9&5N=&ET970B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G
M:60@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`B4VQE='0@
M9VIE;&1E;F1E(&MO;&]N;F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@(D1E;&5T92!T:&4@
M8W5R<F5N="!R;W<B"FUS9W-T<B`B4VQE='0@9VIE;&1E;F1E(')A9"(*"B,Z
M(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#@*;7-G:60@(D1E;&5T92!T:&ES
M('!E<FUI<W-I;VX@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@
M(E-L971T92!D96YN92!R971T:6=H971E;B!O9R!A;&QE('5N9&5R+7)E='1I
M9VAE=&5R/R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,U"B,L('!H
M<"UF;W)M870*;7-G:60@(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@
M)R5S)RXB"FUS9W-T<B`B4VQE='0@<V5T=7`@;W!P9W)A9&5R:6YG<RUS8W)I
M<'0@)R5S)RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3@U(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,3D*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR-C$*;7-G:60@(D1E;&EV97)Y('1I;64B
M"FUS9W-T<B`B3&5V97)I;F=S=&ED(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C<Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R
M(")$86YM87)K(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-C0R"FUS9VED(")$96YY(')E<75E<W0B"FUS9W-T<B`B079S;.4@
M9F]R97-P^')S96PB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HT-S$*;7-G:60@(D1E;GD@<F5Q=65S="!F;W(@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N(@IM<V=S='(@(D%V<VSE(&9O<F5S</AR<V5L(&9O<B!L
M961I9R]O<'!T871T+6EN9F]R;6%S:F]N(@H*(SH@<V5R=FEC97,O<')O8FQE
M;2YP:'`Z.34@<V5R=FEC97,O<')O8FQE;2YP:'`Z.3D@<V5R=FEC97,O<')O
M8FQE;2YP:'`Z,3`Y"FUS9VED(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G
M<W1R(")"97-K<FEV('!R;V)L96UE="(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HY,S,@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-38U
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S`*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(D)E<VMR:79E;'-E
M(@H*(SH@;&EB+TAO<F1E+G!H<#HR,#$*;7-G:60@(D1E=&%I;',@*&%L<V\@
M:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B1&5T86QJ97(@*&]G<^4@
M:2!(;W)D92=S(&QO9V=F:6PI.B(*"B,Z(&QI8B](;W)D92YP:'`Z,C`U"FUS
M9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES
M=')A=&]R+B(*;7-G<W1R(")$971A;&IE<B!H87(@8FQI='0@;&]G9V5T(&9O
M<B!A9&UI;FES=')A=&]R96XN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$Y,PIM<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B571V:6ML:6YG
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,34*;7-G:60@(D1E=R!0;VEN
M="(*;7-G<W1R(")$;V=G<'5N:W0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(Y,@IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R
M(")$;V=G<'5N:W0@9F]R(&1E;B!S:7-T92!T:6UE;CH@(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$Y,`IM<V=I9"`B1&5W('!O:6YT.B`B
M"FUS9W-T<B`B1&]G9W!U;FMT.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T
M;R!R:6=H="(*;7-G<W1R(")2971N:6YG(&9R82!V96YS=')E(&UO="!H^'ER
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L969T(@IM<V=S='(@(E)E
M=&YI;F<@9G)A(&CX>7)E(&UO="!V96YS=')E(@H*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R(")+871A;&]G
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U-@IM<V=I9"`B1&ES<&QA
M>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R(")6:7,@,C0M=&EM97)S('1I9&5R
M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PIM<V=I9"`B1&ES<&QA
M>2!/<'1I;VYS(@IM<V=S='(@(E9I<VYI;F=S=F%L9R(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z.#,*;7-G:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB
M"FUS9W-T<B`B5FES(&9O<G9A<G-E;"`H5$%&*2(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR.#`V"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R(")6
M:7-N:6YG<V9O<FUA="(*"B,Z(&QI8B](;W)D92]-24U%+TU$3BYP:'`Z,C`S
M"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B365L
M9&EN9R!O;2!O<F1N:6YG(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<P
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-B!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C,R-PIM<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G<W1R(")):VME
M('-L971T(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(T"FUS9VED
M(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G
M<W1R(")):VME(.5P;F4@;6%I;F5N86YC92YP:'`@9&ER96MT92(*"B,Z('1E
M;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$Y('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C$Y"FUS9VED(")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I
M;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM
M<V=S='(@(DMR>7-S(&%V(&AE<B!H=FES(&1E;B!F^')S=&4@<F%D96X@:6YN
M96AO;&1E<B!F96QT+6YA=FYE=#HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")$;VUI;FEC82(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S,@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<Q"FUS9VED(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@V.`IM<V=I9"`B1&]W;FQO
M860B"FUS9W-T<B`B3&%S="!N960B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT
M96YT<RYP:'`Z.#8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N
M;&]A9"`E<R(*;7-G<W1R("),87-T(&YE9"`E<R(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ-38*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF
M:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(DQA<W0@;F5D(&=E
M;F5R97)T(&MO;F9I9W5R87-J;VX@<V]M(%!(4"!S8W)I<'0N(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(P.3$*;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM
M<V=S='(@(DYE9'1R96MK<VQI<W1E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G<W1R(")-961I<VEN97(B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HS.3D*;7-G:60@(D4M36%I;"(*;7-G
M<W1R(")%+7!O<W0B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(D524B(*;7-G<W1R(")%4E(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S4@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C<R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS
M9VED(")%8W5A9&]R(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]097)M<RYP
M:'`Z,CDV('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@HC
M.B!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(R"FUS9VED(")%9&ET(@IM
M<V=S='(@(E)E9&EG97(B"@HC.B!L:6(O2&]R9&4O0FQO8VLO54DN<&AP.C4Q
M('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,C(*;7-G:60@(D5D:70@0FQO
M8VLB"FUS9W-T<B`B4F5D:6=E<F4@8FQO:VLB"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C$X."!A9&UI;B]G<F]U<',N<&AP.C(Q-@IM<V=I9"`B161I="!'<F]U
M<"(*;7-G<W1R(")2961I9V5R($=R=7!P92(*"B,Z(&QI8B](;W)D92]097)M
M<R]522YP:'`Z-3D@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HX,PIM<V=I9"`B
M161I="!097)M:7-S:6]N(@IM<V=S='(@(E)E9&EG97(@<F5T=&EG:&5T97(B
M"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"FUS9VED(")%9&ET
M(%!E<FUI<W-I;VYS(@IM<V=S='(@(E)E9&EG97(@<F5T=&EG:'1E<B(*"B,Z
M('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B4F5D:6=E
M<B!R971T:6=H971E<B!F;W(@)7,B"@HC.B!T96UP;&%T97,O<')E9G,O87!P
M+FEN8SHY"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R(")2961I
M9V5R('9A;&<@9F]R.B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@
M)7,B"FUS9W-T<B`B4F5D:6=E<B!R971T:6=H971E<B!F;W(@)7,B"@HC.B!A
M9&UI;B]P97)M<R]E9&ET+G!H<#HR,#0@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HR.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F
M;W(@)R5S)R(*;7-G<W1R(")2961I9V5R(')E='1I9VAE=&5R(&9O<B`E<R(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0IM<V=I9"`B161U8V%T:6]N
M(@IM<V=S='(@(D]P<&SF<FEN9R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HW-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5G>7!T(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C<T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M.`IM<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"FUS9VED
M(")%;&5M96YT+BXN(@IM<V=S='(@(D5L96UE;G0N+BXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.0IM<V=I9"`B16TB
M"FUS9W-T<B`B16TB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@U,R!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(R-PIM<V=I9"`B16UA:6PB
M"FUS9W-T<B`B12UP;W-T(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU.#D@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0P"FUS9VED(")%;6%I
M;"!!9&1R97-S(@IM<V=S='(@(D4M<&]S=&%D<F5S<V4B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3DT-PIM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@
M;6%T8V@N(@IM<V=S='(@(D4M<&]S=&%D<F5S<V4@;>4@<W1E;6UE+B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ.3<S"FUS9VED(")%;6%I;"!W:71H(&-O
M;F9I<FUA=&EO;B(*;7-G<W1R(")%+7!O<W0@;65D(&)E:W)E9G1E;'-E(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(X,`IM<V=I
M9"`B16UO=&EC;VYS(@IM<V=S='(@(D;X;&5L<V5R(@H*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G:60@(D5M<'1Y(&UE<W-A
M9V4N(@IM<V=S='(@(E1O;2!M96QD:6YG+B(*"B,Z(&QI8B](;W)D92]!=71H
M+VQD87`N<&AP.C$S,0IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R(")4
M;VUT(')E<W5L=&%T+B(*"B,Z(&QI8B](;W)D92]344PO2V5Y=V]R9',N<&AP
M.C$Q-`IM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@(E3X;2!S
M^&ME:W)I=&5R:65R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S,@IM
M<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'
M86QL97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B06MT:79E<B!M=6QI9VAE="!F
M;W(@Y2!S971T92!I;FX@8FEL9&5R(&9R82!G86QL97)I97(@:2!T96MS=&5N
M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#<*;7-G:60@(D5N86)L
M92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@(D%K=&EV97)E
M(&CX>7)E:VQI:VL@;65N>3\B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HT-#@*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z-34S"FUS9VED(")%;F0B"FUS9W-T<B`B4VQU='0B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4Y,2!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C@P,`IM<V=I9"`B16YD('EE87(B"FUS9W-T<B`BQ7)S<VQU='0B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED
M(")%;FQA<F=E($5D:71O<B(*;7-G<W1R(")':OAR(&5D:71O<F5N('-T^')R
M92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,3$*;7-G:60@(B(*(D5N
M=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K
M960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S=V]R9"P@92YG
M+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B
M"B)3:W)I=B!I;FX@971T('-I:VME<FAE='-S</AR<VWE;"!S;VT@9'4@=FEL
M(&)L:2!S<'5R="!O;2!H=FES(&1U(/AN<VME<B#E("(*(FYU;&QS=&EL;&4@
M<&%S<V]R9&5T(&1I='0L(&8N96MS+B`G:'9A(&5R(&YA=FYE="!PY2!K:N9L
M961Y<F5T(&1I='0_)SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I
M;6%G92!54DP@:&5R92(*;7-G<W1R(")3:W)I=B!I;FX@861R97-S96X@=&EL
M(&)I;&1E="!H97(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$U,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%;G1R:65S.B`E9"!T;W1A;"P@)60@=7`M=&\M
M9&%T92P@)60@;F5W+"`E9"!C:&%N9V5D+"`E9"!U;FMN;W=N(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY.2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S<*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HW.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@
M(D5R:71R96$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HT,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-3$*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-B!S97)V:6-E<R]P;W)T86PO:6YD
M97@N<&AP.C<X"FUS9VED(")%<G)O<B(*;7-G<W1R(")&96EL(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3DU"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C(W.`HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HS-#<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B17)R;W(@<V5N9&EN9R!R97!L>3H@)7,N(@IM<V=S='(@(D9E
M:6P@=F5D('-E;F1I;F<@878@<W9A<CH@)7,B"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B17)R;W(@=VET:"!E;6%I
M;"!M97-S86=E+B(*;7-G<W1R(")&96EL(&UE9"!E+7!O<W0@;65L9&EN9V5N
M+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C$T,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG
M("<E<R<N(@IM<V=S='(@(D9E:6P@=F5D('-K<FEV:6YG('1I;"`G)7,G+B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT,3,@<&\O=')A;G-L871I;VXN<&AP
M.C4R,B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,U.`HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,30Q.2!P;R]T<F%N<VQA=&EO;BYP:'`Z,30X,@IM<V=I9"`B17)R
M;W(Z("(*;7-G<W1R(")&96EL.B`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%<W1O;FEA(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S(*;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C4V"FUS9VED(")%=7)O<&4B"FUS9W-T
M<B`B175R;W!A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,R.0IM<V=I
M9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R(")(=F5R="`Q-2X@;6EN=71T
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.0IM<V=I9"`B179E<GD@
M,B!M:6YU=&5S(@IM<V=S='(@(DAV97)T(#(N(&UI;G5T="(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS,C8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W
M-PIM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R(")(=F5R="`S,"X@
M<V5K=6YD(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,R."!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S@P"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS
M9W-T<B`B2'9E<G0@-2X@;6EN=71T(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA
M;F-E+G!H<#HS.0IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T<B`B2'9E<B!I
M;FYL;V=G:6YG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S,`IM<V=I
M9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(DAV97(@:&%L=G1I;64B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(W(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-S@*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R(")(=F5R="!M
M:6YU='0B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR.`IM<V=I
M9"`B17AA;7!L92!V86QU97,Z(@IM<V=S='(@(D5K<V5M<&5L=F5R9&EE<CHB
M"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S8@861M:6XO8VUD<VAE;&PN<&AP
M.C4P(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S8*;7-G:60@(D5X96-U=&4B"FUS
M9W-T<B`B2VKX<B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HR.3D@<&\O=')A
M;G-L871I;VXN<&AP.C,R,"!P;R]T<F%N<VQA=&EO;BYP:'`Z,S8R"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HT-#$@<&\O=')A;G-L871I;VXN<&AP.C4T,2!P
M;R]T<F%N<VQA=&EO;BYP:'`Z-C`Q"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW
M,#(@<&\O=')A;G-L871I;VXN<&AP.C<S-R!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-SDX"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HX-S4@<&\O=')A;G-L871I;VXN
M<&AP.CDX.2!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`Q,0IM<V=I9"`B17AE8W5T
M:6YG.B(*;7-G<W1R(")+:OAR97(Z(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA
M>6]U="YP:'`Z,S@V"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B571V:60B"@HC
M.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,Q"FUS9VED(")%>'!A
M;F0@4VED96)A<B(*;7-G<W1R(")5='9I9"!3:61E8F%R(@H*(SH@;&EB+TAO
M<F1E+U-13"]+97EW;W)D<RYP:'`Z,38Y"FUS9VED(")%>'!E8W1E9"`G*2<B
M"FUS9W-T<B`B1F]R=F5N=&5T("<I)R(*"B,Z(&QI8B](;W)D92]344PO2V5Y
M=V]R9',N<&AP.C$W-@IM<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U
M;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R(")&;W)V96YT970@8FQA;FMT(&]R
M9"!E;&QE<B!Q=6]T970@<_AK96MR:71E<FEE(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z,SDX"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T
M<B`B571L^'!S9&%T;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-S`P"FUS9VED(")%>'!O;F5N="(*;7-G<W1R(")%:W-P;VYE;G0B"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(D5X
M=')A8W1I;F<@9G)O;2`E<RXN+B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B
M1D<@0V]L;W(B"FUS9W-T<B`B1F]R9W)U;FYS9F%R9V4B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3<Q"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P
M(@IM<V=S='(@(D]P<&QA<W1I;F<@878@<V5T=7`@=FEA($944"(*"B,Z(&QI
M8B](;W)D92]0<F5F<R]S<6PN<&AP.C(T,`IM<V=I9"`B1F%I;&5D(')E=')I
M979I;F<@<')E9F5R96YC97,N(@IM<V=S='(@(E5T:&5N=&EN9R!A=B!I;G-T
M:6QL:6YG97(@9F5I;&5T+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP
M.C$P,PIM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N
M(@IM<V=S='(@(E1I;&MO8FQI;F<@=&EL($Q$05`M=&IE;F5R(&9E:6QE="XB
M"@HC.B!L:6(O2&]R9&4O075T:"]S;6(N<&AP.C$P,PIM<V=I9"`B1F%I;&5D
M('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`B5&EL:V]B;&EN
M9R!T:6P@4TU"+71J96YE<B!F96EL970N(@H*(SH@;&EB+U9&4R]F='`N<&AP
M.C8S,0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!F<F]M
M(%PB)7-<(BXB"FUS9W-T<B`B1F5I;&5T('9E9"!K;W!I97)I;F<@9G)A(%PB
M)7-<(BXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-C,V"B,L('!H<"UF;W)M870*
M;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`B1F5I
M;&5T('9E9"!K;W!I97)I;F<@=&EL(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O
M075T:"]S87-L+G!H<#HY,@IM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@
M4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R(")&96EL970@=F5D(&]P<')E='1E
M;'-E(&%V(&YY(%-!4TP@:V]B;&EN9RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z
M-C<Q"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB
M)7-<(BXB"FUS9W-T<B`B1F5I;&5T('9E9"!F;'ET=&EN9R!T:6P@7"(E<UPB
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,S`*;7-G:60@
M(D9A:7(B"FUS9W-T<B`B4&5N="!VYG(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z.#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&86QK;&%N9"!)<VQA
M;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C@V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1F%R;V4@27-L86YD
M<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0TQ)+G!H<#HR,S4*;7-G:60@
M(D9A=&%L($5R<F]R.B(*;7-G<W1R(")&871A;"!&96EL.B`B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B1F%X(@IM
M<V=S='(@(D9A>"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HS-S4@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q
M,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V
M"FUS9VED(")&96)R=6%R>2(*;7-G<W1R(")&96)R=6%R(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,3@*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B
M1OAL97,@<V]M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Y
M-`IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(D;X;&5S('-O;3H@(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,S,0IM<V=I9"`B1F5W
M(%-H;W=E<G,B"FUS9W-T<B`B1N4@8GEG97(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S,R"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM
M<V=S='(@(D;E('-N^&)Y9V5R(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y
M,C@*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R(")&96QT;6%T<FES92(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,*
M;7-G:60@(D9I:FDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C,@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z
M-C<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R(")!
M;G1A;&P@9FEL97(Z("5S(&9I;&5R(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C,@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z
M-C<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`B
M06YT86QL(&9I;&5R.B`E<R!F:6QE<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS-#D*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R(")&:6QB
M96AA;F1L97(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV
M-B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,`HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=&=Z+G!H<#HX-0IM<V=I9"`B1FEL92!.86UE(@IM
M<V=S='(@(D9I;&YA=FXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDX,`IM
M<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T<B`B1FEL=F%L9R(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ-#@S"FUS9VED(")&:6QE('5P;&]A9"(*;7-G
M<W1R("),87-T(&]P<"!F:6QE<B(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H
M<#HX-S0*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G
M<W1R(")/<'!L87-T:6YG(&%V(&9I;&5R('-T^'1T97,@:6MK92XB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#8*;7-G:60@(D9I;'1E<G,B"FUS
M9W-T<B`B1FEL=&5R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@R(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,3<Q"FUS9VED(")&:7)S="!(86QF(@IM<V=S
M='(@(D;X<G-T92!H86QV;>5N92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW
M-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U87)T97(B
M"FUS9W-T<B`B1OAR<W1E(&MV87)T;>5N92(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR,SD*;7-G:60@(D9I>"!R871I;R(*;7-G
M<W1R(")&87-T(&9O<FAO;&0B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C$T"FUS9VED(")&;&EP(@IM<V=S='(@(E-N=2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(D9L>70B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S,S"FUS9VED(")&;V<B"FUS9W-T<B`B5.5K
M92(*"B,Z(&QI8B]61E,O<W%L+G!H<#HQ-C,@;&EB+U9&4R]M=7-Q;"YP:'`Z
M,3`X"B,L('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E
M>&ES="(*;7-G<W1R(")-87!P96X@)7,@96MS:7-T97)E<B!I:VME(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I
M9"`B1F]N="!#;VQO<B(*;7-G<W1R(")&;VYT9F%R9V4B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`B36%T(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(V"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P
M;W)T(&EM86=E<R(*;7-G<W1R(")&;W(@;F5T=&QE<V5R92!S;VT@:6MK92!S
M=/AT=&5R(&)I;&1E<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,R"FUS
M9VED(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R(")&;W)V87)S96P@*%1!1BDB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S0*;7-G:60@(B(*
M(D9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A
M<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M
M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T
M<B`B(@HB06YT86QL(&1A9V5R<R!F;W)V87)S96P@*';F<B!O8G,@<.4@870@
M9&5T(')E='5R;F5R=&4@9F]R=F%R<VQE="!I;FYE:&]L9&5R("(*(F+E9&4@
M9&%G(&]G(&YA='0[(&5N('-T;W(@=F5R9&D@:&5R(&MA;B!R97-U;'1E<F4@
M:2!E;B!S=&]R(&)L;VMK*2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z.34*;7-G:60@(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R(")'
M;&5M="!P87-S;W)D970_(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0S,0IM<V=I9"`B1F]R;7,B"FUS9W-T<B`B4VMJ96UA97(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,C$*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`B
M4VMJ96)N92]L>6MK92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY.0IM
M<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S='(@(E1Y<&4@<VMJ96)N92]L>6MK
M92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM<V=I9"`B1F]R='5N
M97,B"FUS9W-T<B`B4VMJ96)N97(O;'EK:V4B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B4VMJ96)N
M97(O;'EK:V4@,B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,30*
M;7-G:60@(D9O<G5M<R(*;7-G<W1R(")&;W)U;65R(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,U.`IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B
M5FED97)E<V5N9'1E(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$T,SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1F]U;F0@87!P;&EC871I;VYS.B`E<R(*;7-G
M<W1R(")&86YT('!R;V=R86UM96YE.B`E<R(*"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HQ-#,S"FUS9VED(")&;W5N9"!D:7)E8W1O<FEE<SHB"FUS9W-T<B`B
M1F%N="!K871A;&]G96YE.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S='(@(D9R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M,PIM<V=I9"`B1G)A;65S(@IM<V=S='(@(E)A;6UE<B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HX-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D9R86YC
M92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM
M<V=I9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#$W"FUS9VED(")&
M<F5E+T)U<WD@26YF;W)M871I;VXB"FUS9W-T<B`B3&5D:6<O;W!P=&%T="UI
M;F9O<FUA<VIO;B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C0R-PIM<V=I9"`B1G)E92]"=7-Y(%)E<&QY(@IM<V=S='(@(DQE
M9&EG+V]P<'1A='0@<W9A<B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C0R,@IM<V=I9"`B1G)E92]"=7-Y(%)E<75E<W0B"FUS
M9W-T<B`B3&5D:6<O;W!P=&%T="!F;W)E<W#X<G-E;"(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C(W,@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HS-#$*;7-G:60@(D9R964O0G5S
M>2!297%U97-T(%)E<W!O;G-E(@IM<V=S='(@(E-V87(@<.4@;&5D:6<O;W!P
M=&%T="!F;W)E<W#X<G-E;"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY
M,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D9R96YC:"!'=6EA;F$B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3D*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS
M9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-SD*;7-G:60@
M(D9R;VTB"FUS9W-T<B`B1G)A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(Q,0IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@(D9R82`B"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT.`IM<V=I9"`B1G5L
M;"!$97-C<FEP=&EO;B(*;7-G<W1R(")&=6QL(&)E<VMR:79E;'-E(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C@R(&QI8B]";&]C:R]M;V]N+G!H<#HQ.#$*
M;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R(")&=6QL;>5N92(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,SD*;7-G:60@(D9U;&P@3F%M
M92(*;7-G<W1R(")&=6QL="!N879N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C8U-PIM<V=I9"`B1G5Z>GDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C@X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1V%B;VXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA
M9V4@9G)O;2(*;7-G<W1R(")'86QL97)I(&1U(/AN<VME<B#E(&AE;G1E(&)I
M;&1E(&9R82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B
M1V%L;&5R:3HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.38@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<V"FUS9VED(")'86UB:6$B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE
M<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(D=E;F5R97(@)7,@:V]N
M9FEG=7)A<VIO;B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N
M:'1M;#HQ,`IM<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B1V5N97)E
M<G0@:V]D92(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT-SD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1V5N97)A=&EN9R!S=&%T=7,@9F]R(&UO9'5L92`E<RXN
M+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<U"FUS9VED(")'96]R9VEA(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HV.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@
M(D=E<FUA;GDB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$S
M-3(*;7-G:60@(D=E=&]P="!%<G)O<CH@(@IM<V=S='(@(D=E=&]P="!&96EL
M.B`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3,@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<V"FUS9VED(")':&%N82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z.30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<V"FUS9VED(")':6)R86QT87(B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3D*
M;7-G:60@(D=I=F5N($YA;64B"FUS9W-T<B`B1VET="!.879N(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V%P<"YI;F,Z,38*;7-G:60@(D=O(@IM<V=S='(@(D=O
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D96PB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I
M9"`B1V]O9VQE(%-E87)C:"(*;7-G<W1R(")3^&L@<.4@1V]O9VQE(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,`IM<V=I9"`B
M1W)A>7-C86QE(@IM<V=S='(@(D=RY71O;F4B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3`P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W)E96-E(@IM
M<V=S='(@(DAE;&QA<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS
M9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.CDU(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HY-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W)E
M96YL86YD(@IM<V=S='(@(D=R^&YL86YD(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C@Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W)E;F%D82(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W,`IM<V=I9"`B1W)O=7`@
M061M:6YI<W1R871I;VXB"FUS9W-T<B`B1W)U<'!E(&%D;6EN:7-T<F%S:F]N
M(@H*(SH@;&EB+TAO<F1E+T=R;W5P+G!H<#HU-PIM<V=I9"`B1W)O=7`@;F%M
M97,@;75S="!B92!N;VXM96UP='DB"FUS9W-T<B`B1W)U<'!E;F%V;B!K86X@
M:6MK92!VYG)E('1O;6UE(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,C`Q
M(&QI8B](;W)D92]097)M<R]522YP:'`Z,C@U"FUS9VED(")'<F]U<"!P97)M
M:7-S:6]N<R(*;7-G<W1R(")'<G5P<&5R971T:6=H971E<B(*"B,Z(&%D;6EN
M+W!E<FUS+V5D:70N<&AP.C$W-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(U
M."!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(D=R=7!P97(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3@@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.CDV"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<W
M"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDW
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=6%M(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#(@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<X"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'=65R;G-E>2(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,C<@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HR,3,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX
M.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B4F5T=&EG:&5T
M97(@9F]R(&=J97-T(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3(X(&QI
M8B](;W)D92]097)M<R]522YP:'`Z,C$T"FUS9VED(")'=65S="!P97)M:7-S
M:6]N<R(*;7-G<W1R(")2971T:6=H971E<B!F;W(@9VIE<W0B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Y"FUS9VED(")'=65S=&)O;VLB"FUS
M9W-T<B`B1VIE<W1E8F]K(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDW
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W5I;F5A(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#0@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$P,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.0IM
M<V=I9"`B1W5I;F5A+4)I<W-A=2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3`U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(D=U>6%N
M82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,S,Q"FUS9VED(")(2"(*;7-G<W1R(")(2"(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HY-34*;7-G:60@(DA434PB"FUS9W-T<B`B2%1-3"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#4*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E
M('1H92!L87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R(")(5$U,07)E82!N96MT
M97(@Y2!S;&5T=&4@9&5N('-I<W1E(&-E;&QE;B!I(&5N(')A9"XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V
M"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(DA434Q!<F5A(&YE
M:W1E<B#E('-L971T92!D96X@<VES=&4@:V]L;VYN96X@:2!T86)E;&QE;BXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@W"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E
M;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@(DA434Q!<F5A
M(&YE:W1E<B#E('-L971T92!D96X@<VES=&4@<F%D96X@:2!T86)E;&QE;BXB
M"@HC.B!L:6(O2&]R9&4O075T:"]H='1P+G!H<#HQ-C0*;7-G:60@(DA45%`@
M075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")(5%10(&%U=&5N
M=&ES97)I;F<@:6MK92!F=6YN970N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")(86ET:2(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HS.3D*;7-G:60@(DAA
M<V@M06QG;W)I=&AM(@IM<V=S='(@(DAA<V@M86QG;W)I=&UE(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,S-`IM<V=I9"`B2&%Z92(*;7-G
M<W1R(")$:7,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3$T(&QI8B](;W)D
M92]&;W)M+G!H<#HR.3(Q"FUS9VED(")(96%D97(B"FUS9W-T<B`B2&]D92(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$P,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M,`IM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS9VED(")(
M96)R97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM<V=I9"`B
M2&5I9VAT(@IM<V=S='(@(DCX>61E(@H*(SH@;&EB+TAO<F1E+TAE;'`N<&AP
M.C$W.2!L:6(O2&]R9&4O2&5L<"YP:'`Z,3@V('-E<G9I8V5S+VAE;'`O:6YD
M97@N<&AP.C$W"B,Z('1E;7!L871E<R]H96QP+VEN9&5X+FEN8SHS"FUS9VED
M(")(96QP(@IM<V=S='(@(DAJ96QP(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET
M;W(B"FUS9W-T<B`B2&IE;'`@=&EL(&)R=6L@878@961I=&]R(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$S-C@*;7-G:60@(DAE;'!E<B(*;7-G<W1R(")(
M:F5L<&5R(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.CDU"FUS9VED("(B"B)(
M96QP97(@87!P;&EC871I;VX@=&\@8W)E871E(&%N9"!M86EN=&%I;B!T<F%N
M<VQA=&EO;G,@9F]R('1H92!(;W)D95QN(@HB9G)A;65W;W)K(&%N9"!I=',@
M87!P;&EC871I;VYS+EQN(@HB1F]R(&%N(&EN=')O9'5C=&EO;B!R96%D('1H
M92!F:6QE(%)%041-12!I;B!T:&ES(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM
M<V=S='(@(DAA;'9K=6QE(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI
M;F,Z,3<@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@(DAE
M<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B2&5R
M(&5R(&)E9WEN;F5L<V5N('#E(&9I;&5N.B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS-S8*;7-G:60@(DAI9V@B"FUS9W-T<B`B2/AY(@H*
M(SH@;&EB+TAO<F1E+TAI<W1O<GDN<&AP.C,R,@IM<V=I9"`B2&ES=&]R>2!E
M;G1R>2!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R(")(:7-T;W)I
M96]P<&;X<FEN9V5R('#E(&AA(&YA=FX@<V]M(&EK:V4@97(@=&]M;64B"@HC
M.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN
M+V-O;6UO;BUH96%D97(N:6YC.C0*;7-G:60@(DAO7VUE(@IM<V=S='(@(DAJ
M95]M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q-0IM<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-#8V"FUS9VED(")(;VUE
M(@IM<V=S='(@(DAJ96TB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$R-2!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$U
M.`IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(DAJ96UM96%D<F5S<V4B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,PIM<V=I
M9"`B2&]M92!0:&]N92(*;7-G<W1R(")496QE9F]N(&AJ96UM92(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$P-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I
M9"`B2&]N9'5R87,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$P-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(;VYG($MO;F<B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8R"FUS9VED
M(")(;W)D92(*;7-G<W1R(")(;W)D92(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HQ,S$P"FUS9VED(")(;W)D92!T<F%N<VQA=&EO;B!G96YE<F%T;W(B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT,C`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@
M96YC;W5N=&5R960@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+;VQA
M8CH@56=Y;&1I9R`E<R!834P@9&%T82!F=6YN970@:2!M96QD:6YG("5S(@H*
M(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HR-S<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J
M96-T("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!);F=E;B!M96QD:6YG('!A
M<W-E<B!M960@;V)J96MT970@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.C0Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J
M96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(
M;W)D92]+;VQA8CH@26YT970@;V)J96MT(&%V('1Y<&5N("5S(&9U;FYE="!I
M(&UE;&1I;F<@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$R,S8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R
M96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@1FIE<FYE
M="`E<R!<(B5S7"(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$Q.#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!S
M>6YC:')O;FES960@)7,@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!3
M>6YK<F]N:7-E<G1E("5S(%PB)7-<(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP
M:'`Z,C(S"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N
M9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G
M<W1R(")(;W)D92]+;VQA8CH@26YT96=R87-J;VYS;6]T;W)E;B!K<F5V97(@
M4$A0("=D;VUX;6PG('5T=FED96QS92(*"B,Z(&QI8B](;W)D92]+;VQA8BYP
M:'`Z-#@Q"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S(@IM<V=S
M='(@(DAO<F1E+TMO;&%B.B!+=6YN92!I:VME(&]P<')E='1E(&YY='0@6$U,
M('1R92!F;W(@;V)J96MT970@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.C$R,S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA
M8CH@2W5N;F4@:6MK92!F:F5R;F4@)7,@7"(E<UPB.B`E<R(*"B,Z(&QI8B](
M;W)D92]+;VQA8BYP:'`Z-#4R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A
M<G0@;V8@='EP92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@2W5N;F4@:6MK
M92!H96YT92!-24U%($E$(&9O<B!D96QE;B!A=B!T>7!E("5S(@H*(SH@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HQ,3<Y"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E
M<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@2W5N;F4@:6MK92!S>6YK<F]N:7-E
M<F4@)7,@7"(E<UPB.B`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3,Q
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O
M('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z
M($MU;FYE(&EK:V4@<WEN:W)O;FES97)E(&1E;'1E(')E<W-U<G-E<CH@)7,B
M"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z(%5K:F5N="!D96QT(')E<W-U<G,@7"(E<UPB(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM
M<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(DAO<FES;VYT86P@;&EN
M:F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B2&]R:7-O
M;G1A;"!P861D:6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B2&]R
M:7-O;G1A;#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E
M/R`H4&QE87-E(')E<&]R="$I(@IM<V=S='(@(DAV;W)D86X@:V]M(&1U(&AI
M=#\@*%9E;FYL:6=S="!R87!P;W)T97(A*2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M
M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@
M(DAV;W(@;6%N9V4@:V]L;VYN97(@^&YS:V5R(&1U(.4@<VSE('-A;6UE;C\B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR.`IM<V=I9"`B2&]W
M(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@(DAV
M;W(@;6%N9V4@9F5L=&5R("AK;VQO;FYE<BD@97(@9&5T/R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G
M:60@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM
M<V=S='(@(DAV;W(@;6%N9V4@<F%D97(@^&YS:V5R(&1U(.4@<VSE('-A;6UE
M;C\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R.`IM<V=I9"`B2'5M:61I
M='DB"FUS9W-T<B`B1G5K=&EG:&5T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Q-PIM<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R(")&=6MT
M:6=H970Z("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B
M2'5M;W)I<W1S(@IM<V=S='(@(DAU;6]R:7-T97(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3$Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DAU;F=A
M<GDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$W
M-B!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C(R,PHC+"!P:'`M9F]R;6%T
M"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G
M<W1R(")/<'!R971T96QS92!A=B!)34%0('!O<W1B;VMS(&9E:6QE=#H@)7,B
M"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,C(P(&QI8B](;W)D92]!
M=71H+V-Y<G-Q;"YP:'`Z,C@X"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@
M;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM<V=S='(@(E-L971T:6YG
M(&%V($E-05`@<&]S=&)O:W-E;B!F96EL970Z("5S(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O8WER=7,N<&AP.C$X,R!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP
M.C(S,`HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@
M8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")/<'!R971T96QS92!A=B!K
M=F]T92!PY2!)34%0('!O<W1B;VMS(&9E:6QE=#H@)7,B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3,Q,@IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R("))
M4"!!9')E<W-E(@H*(SH@;&EB+TAO<F1E+T%U=&@O:7!B87-I8RYP:'`Z.#(*
M;7-G:60@(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B25`@
M061R97-S92!I:VME('1I;&=J96YG96QI9RXB"@HC.B!L:6(O2&]R9&4O075T
M:"]I<&)A<VEC+G!H<#HY-`IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN
M(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B25`@061R97-S92!I:VME
M(&EN;F5N9F]R('1I;&%T=&4@0TE$4B!B;&]K:RXB"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B25`@;&]C:V1O=VX@
M=FEO;&%T:6]N+B(*;7-G<W1R(")"<G5D9"!PY2!)4"!L;V-K9&]W;BXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R(")37V5T
M="!I;FX@;GD@<F%D(&;X<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B26-E;&%N9"(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8V"FUS9VED("))8V]N<R!/
M;FQY(@IM<V=S='(@(DMU;B!I:V]N97(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E
M<BYP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM
M<V=S='(@(DEK;VYE<B!F;W(@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S8W"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B26MO;F5R
M(&UE9"!T96MS="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#`*;7-G
M:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B261E;G1I=&5T96YS(&YA
M=FXZ(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C8P.`HC+"!P
M:'`M9F]R;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E
M8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@
M(DAV:7,@9&5N(&EK:V4@=FES97,@<FEK=&EG+"`E<R!F;W(@Y2#E<&YE(&D@
M;GET="!V:6YD=2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0U"FUS
M9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E
M<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@
M8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*
M(DAV:7,@9'4@:6MK92!S97(@;F]E;B!I:V]N97(@;N5R(&1U(&)E;GET=&5R
M($EN=&5R;F5T($5X<&QO<F5R+"!K86X@9&5T("(*(FAE;F1E(&1U('1R96YG
M97(@Y2!K<GES<V4@878@9&5N;F4@8F]K<V5N(&9O<B#E('-K<G4@878@=')A
M;G-P87)E;G0@4$Y'+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ-3@*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E
M(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C
M86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R
M("(B"B)(=FES(&1U('-E<B!D96YN92!M96QD:6YG96X@;65N(&EN=&5T(&)I
M;&1E+"!K86X@9&5T(&AE;F1E(&%T(&)I;&1E="!D=2!V:6P@(@HB;&%S=&4@
M;W!P(&EK:V4@:V%N('9I<V5S(&D@9&EN(&YE='1L97-E<BXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C@*;7-G:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(D9O<FCE;F1S=FES
M;FEN9R!A=B!B:6QD93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,W"FUS9VED("));6%G92!54DPB"FUS9W-T
M<B`B0FEL9&5A9')E<W-E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ
M(@IM<V=S='(@(D)I;&1E861R97-S93HB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM
M86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R(")":6QD92!F<F$@9V%L;&5R:2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R
M(")":6QD92!F<F$@9V%L;&5R:3HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3<T.0IM<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(D]P<&QA<W1I;F<@
M878@8FEL9&4B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B
M26UA9V5S(@IM<V=S='(@(D)I;&1E<B(*"B,Z('1E;7!L871E<R]D871A+W1S
M=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C$P"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3
M=&5P("5D(@IM<V=S='(@(DEM<&]R=&5R:6YG+"!S=&5G("5D(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(DEM<&]R=&5R=&4@9F5L
M=#H@)7,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C<S"FUS9VED
M("));7!O<G1E9"!F:65L9',Z(@IM<V=S='(@(DEM<&]R=&5R=&4@9F5L=#HB
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HW,#$*
M;7-G:60@(DEN(%!R;V-E<W,B"FUS9W-T<B`B56YD97(@87)B96ED(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,P"FUS9VED("));E]S97)T(%)O=R!!9G1E<B(*;7-G<W1R(")?4V5T="!I
M;FX@<F%D(&5T=&5R(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z
M,30Q"FUS9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S
M='(@(D9E:6P@:&%N9&QI;F=S:V]D92!G:71T+B(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-3<*;7-G:60@(DEN8V]R<F5C="!U<V5R
M;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(E5G>6QD:6<@8G)U:V5R
M;F%V;B!O9R]E;&QE<B!P87-S;W)D+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C4Q"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@
M86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@
M(@HB861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM
M<V=S='(@(B(*(D9E:6P@8G)U:V5R;F%V;B!E;&QE<B!A;'1E<FYA=&EV(&%D
M<F5S<V4N(%9E;FYL:6=S="!F;W)S^&L@:6=J96X@96QL97(@(@HB:V]N=&%K
M="!S>7-T96UA9&UI;FES=')A=&]R96X@9&EN(&9O<B!Y='1E<FQI9V5R97)E
M(&AJ96QP+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C$*;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R("+8:R!I
M;FYR>6MK(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@R"FUS9VED("));F1I82(*;7-G<W1R("(B"@HC.B!A9&UI;B]P
M97)M<R]E9&ET+G!H<#HQ-#$@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`B26YD:79I9'5E
M;&QE(&)R=6ME<F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$R(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#$*;7-G:60@(DEN9&]N97-I82(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,@IM<V=I9"`B
M26YF;R(*;7-G<W1R("));F9O(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(T.0IM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M87-J
M;VXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-3@R"B,L('!H<"UF;W)M870*
M;7-G:60@(DEN:71I86QI>FEN9R!M;V1U;&4@)7,N+BX@(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS-`IM<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B"FUS9W-T<B`B
M4V5T="!I;FX@:U]O;&]N;F4@971T97(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G:60@(DEN
M<V5R="!);6%G92(*;7-G<W1R(")3971T(&EN;B!B:6QD92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN
M<V5R="!486)L92(*;7-G<W1R(")3971T(&EN;B!T86)E;&PB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED("))
M;G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B4V5T="!I;FX@=V5B;&EN:R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS,PIM<V=I9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(E-E
M='0@:6YN(%]K;VQO;FYE(&;X<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@
M;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B4V5T
M="!I;FX@96X@;GD@:V]L;VYN92!E='1E<B!D96X@9VIE;&1E;F1E(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8T"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R
M<F5N="!O;F4B"FUS9W-T<B`B4V5T="!I;FX@96X@;GD@:V]L;VYN92!F^'(@
M9&5N(&=J96QD96YD92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W(')O
M=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B4V5T="!I;FX@96X@
M;GD@<F%D(&5T=&5R(&1E;B!G:F5L9&5N9&4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(DEN
M<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R
M(")3971T(&EN;B!E;B!N>2!R860@9OAR(&1E;B!G:F5L9&5N9&4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-CD*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N
M="!N;V1E(@IM<V=S='(@(E-E='0@:6YN(&QI;FIE<VMI9G0@971T97(@9&5N
M(&=J96QD96YD92!N;V1E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(&$@<&%R
M86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(E-E='0@
M:6YN(&QI;FIE<VMI9G0@9OAR(&1E;B!G:F5L9&5N9&4@;F]D96XB"@HC.B!A
M9&UI;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T
M92!T96UP;&%T92(*;7-G<W1R(")3971T(&EN;B!A;'1E<FYA=&EV(&UA;"(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,CD*;7-G:60@(DEN<V5R="!A
M;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@
M;F5W('!A<W-W;W)D.B(*;7-G<W1R(")3971T(&EN;B!E;B!E+7!O<W0@861R
M97-S92!D=2#X;G-K97(@Y2!M;W1T82!D970@;GEE('!A<W-O<F1E="!PY3HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4X"FUS9VED("));G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R(")3971T
M(&EN;B!C96QL92!E='1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R="!C96QL(&)E
M9F]R92(*;7-G<W1R(")3971T(&EN;B!C96QL92!E='1E<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G
M:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`B4V5T="!I;FX@:V]L
M;VYN92!E='1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E
M(@IM<V=S='(@(E-E='0@:6YN(&MO;&]N;F4@9OAR(@H*(SH@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.CDS"FUS9VED("));G-E<G0@;65S<V%G
M97,B"FUS9W-T<B`B4V5T="!I;FX@;65L9&EN9V5R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED
M("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(E-E='0@:6YN(&QI
M;FIE<VMI9G0@971T97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(DEN<V5R="!P87)A9W)A
M<&@@8F5F;W)E(@IM<V=S='(@(E-E='0@:6YN(&QI;FIE<VMI9G0@9OAR(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV.0IM<V=I9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R(")3971T(&EN
M;B!R860@971T97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E9F]R92(*
M;7-G<W1R(")3971T(&EN;B!R860@9OAR(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(R,`IM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@
M=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R(")3971T(&EN;B!D
M970@<.5K<F5V9&4@<W9A<F5T('1I;"!F^&QG96YD92!S:6MK97)H971S<W#X
M<G-MY6PZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR-@IM<V=I9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R(")3
M971T(&EN;B]R961I9V5R92!B:6QD92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@
M3&EN:R(*;7-G<W1R(")3971T(&EN;B]R961I9V5R92!L:6YK(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8V.`IM<V=I9"`B26YS=69F
M:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES
M="XB"FUS9W-T<B`B26MK92!N;VL@:W)E9&ET="!F;W(@Y2!K=6YN92!S96YD
M92!T:6P@9&ES=')I8G5S:F]N<VQI<W1E;BXB"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C8P"FUS9VED("));G-U9F9I8VEE;G0@8W)E
M9&ET+B(*;7-G<W1R(")):VME(&YO:R!K<F5D:71T+B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,#<P"FUS9VED("));G1E9V5R(@IM<V=S='(@(DEN=&5G
M97(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$R.`HC+"!F=7IZ>0IM<V=I
M9"`B26YT96=E<B!L:7-T(@IM<V=S='(@(DEN=&5G97(@;&ES=&4B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HR.#,*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,S4R"FUS9VED("))
M;G9A;&ED($%C=&EO;B!S96QE8W1E9"!F;W(@=&AI<R!C;VUP;VYE;G0N(@IM
M<V=S='(@(E5G>6QD:6<@:&%N9&QI;F<@=F%L9W0@9F]R(&1E;FYE(&MO;7!O
M;F5N=&5N+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`V"FUS9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*
M;7-G<W1R(")59WEL9&EG(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P
M;&EC871I;VXN(@IM<V=S='(@(E5G>6QD:6<@<')O9W)A;2XB"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,R,0IM<V=I9"`B26YV86QI
M9"!B871C:"!)1"XB"FUS9W-T<B`B56=Y;&1I9R!B871C:"!)1"(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR,#<Q(&QI8B](;W)D92]&;W)M+G!H<#HR,30R
M(&QI8B](;W)D92]&;W)M+G!H<#HR,C$V"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR,C@Q"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R
M(")59WEL9&EG(&1A=&$@<V5N9'0N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@
M861D<F5S<RXB"FUS9W-T<B`B56=Y;&1I9R!M;W1T86ME<B!A9')E<W-E+B(*
M"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]D8G@N<&AP.C@T(&QI8B](;W)D92]#
M;VUP<F5S<R]D8G@N<&AP.C$P,PHC.B!L:6(O2&]R9&4O0V]M<')E<W,O9&)X
M+G!H<#HR,C,*;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B
M56=Y;&1I9R!F:6QF;W)M870B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,Q-@IM<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T
M<B`B56=Y;&1I9R!M96QD:6YG<W1Y<&4B"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG
M(&%P:5]I9"XB"FUS9W-T<B`B56=Y;&1I9R!E;&QE<B!M86YG;&5N9&4@87!I
M7VED+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U
M"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T
M<B`B56=Y;&1I9R!E;&QE<B!M86YG;&5N9&4@<&%R86UE=&5R92XB"@HC.B!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-#,*;7-G:60@(DEN=F%L:60@<&%R
M96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(E5G>6QD:6=E(')E='1I9VAE=&5R
M+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS
M9VED("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R(")59WEL9&EG('!R;W1O
M:V]L;"XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z("<E<R<B
M"FUS9W-T<B`B56=Y;&1I9R!M;W1T86ME<CH@)R5S)R(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z,3`W,2!L:6(O2&]R9&4O2V]L86(N<&AP.C$R-#@*;7-G
M:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S='(@(E5G>6QD:6<@9&5L
M="!O8FIE:W0B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q,`IM<V=I9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B
M56=Y;&1I9R!K:6QD96%D<F5S<V4B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,R,`IM<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A=&$N
M(@IM<V=S='(@(E5G>6QD:6<@=6YI8V]D92!D871A+B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS,C@*;7-G:60@(DEN=F5N=&]R>2(*;7-G<W1R
M("));FYH;VQD(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@S"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3@@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX,@IM<V=I9"`B27)A<2(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3$S(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@
M(DER96QA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,S-0IM<V=I9"`B27-O;&%T960@5"U3
M=&]R;7,B"FUS9W-T<B`B27-O;&5R=&4@=&]R9&5N+7-T;W)M97(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$T(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$*;7-G
M:60@(DES<F%E;"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C8T.0IM<V=I9"`B27-S=65R(@IM<V=S='(@(E5T9VEV97(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*;7-G
M:60@(DET86QI8R(*;7-G<W1R(")+=7)S:78B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3(Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,34*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DET86QY(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C,@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX,PIM<V=I9"`B2F%M86EC82(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<T(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,3$*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*;7-G
M<W1R(")*86YU87(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(U(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#0*;7-G:60@(DIA<&%N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED(")*87!A;F5S92`H25-/+3(P
M,C(M2E`I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3(T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3@*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(DIO<F1A;B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,S@P(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM
M<V=I9"`B2G5L>2(*;7-G<W1R(")*=6QI(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C,W.2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B2G5N:2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`B2G5S=&5R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G
M:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(DUI9'1S=&EL;"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$W
M"B,L(&9U>GIY"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B0FQO:VMJ
M=7-T97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ-`HC+"!F=7IZ>0IM<V=I9"`B2G5S=&EF>2!,969T(@IM
M<V=S='(@(E9E;G-T<F5J=7-T97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@HC+"!F=7IZ>0IM<V=I9"`B
M2G5S=&EF>2!2:6=H="(*;7-G<W1R(")(^'ER96IU<W1E<B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$Q.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B
M2V%Z86MH<W1A;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C0V"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G
M<W1R(")"96AO;&1E(&]R9VEN86P_(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$R-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+96YY82(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX-PIM<V=I9"`B2V5R
M8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M(")+97)B97)O<R!T:F5N97)E;B!A=G9I<W1E(&%U=&5N=&ES97)I;F=E;BXB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.
M97=B:65S(@IM<V=S='(@(DME<FYE;"!.>6)E9WEN;F5R92(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C,Y-PIM<V=I9"`B2V5Y($-R96%T:6]N(@IM
M<V=S='(@(D[X:VME;&=E;F5R97)I;F<B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HT,#`*;7-G:60@(DME>2!&:6YG97)P<FEN="(*;7-G<W1R(").
M^&MK96P@9FEN9V5R<')I;G0B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HS.3@*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`B3OAK:V5L(&QE;F=D
M92(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C,Y-PIM<V=I9"`B2V5Y
M(%1Y<&4B"FUS9W-T<B`B3OAK:V5L('1Y<&4B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C8R,@IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(D[X
M:VME;&)R=6LB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW-#,*;7-G
M:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E
M<BXB"FUS9W-T<B`B3OAK:V5L(&5K<VES=&5R97(@86QL97)E9&4@<.4@9&5N
M(&]F9F5N=&QI9V4@;OAK:V5L=&IE;F5R96XN(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S='(@(D)A<FXB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(Y(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#4*;7-G
M:60@(DMI<FEB871I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2V]R96$L($1E;6]C
M<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$S,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@V"FUS9VED
M(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#0*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,T(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#<*;7-G:60@(DMU=V%I="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3(W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(DMY<F=Y
M>G-T86XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN
M8SHX"FUS9VED("),85]Y;W5T(@IM<V=S='(@(E5T7W-E96YD92(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S8@<&\O=')A;G-L871I;VXN<&AP
M.C8U-PIM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B4W!RY6LB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3,W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@
M(DQA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*;7-G:60@(DQA<W0@2&%L9B(*
M;7-G<W1R(")3:7-T92!H86QT:6UE(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C@X(&QI8B]";&]C:R]M;V]N+G!H<#HY,`IM<V=I9"`B3&%S="!1=6%R=&5R
M(@IM<V=S='(@(E-I<W1E(&MV87)T97(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$T.0IM<V=I9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R(")3:7-T92!O
M<'!D871E<FEN9SHB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z-CDQ"B,L('!H
M<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(E-I<W1E
M(&EN;FQO9V=I;F<Z("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C8Y,PHC
M+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM
M<V=S='(@(E-I<W1E(&EN;FQO9V=I;F<Z("5S(&9R82`E<R(*"B,Z(&QI8B](
M;W)D92]!=71H+G!H<#HV.#@*;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM
M<V=S='(@(E-I<W1E(&EN;FQO9V=I;F<Z($%L9')I(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$T-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS9VED("),871V
M:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS
M9VED("),87<B"FUS9W-T<B`B3&]V(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"FUS9VED("),87EO=70B"FUS
M9W-T<B`B571S965N9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R
M9&5R(@IM<V=S='(@(MAN<VME<R!I;F=E;B!R86UM97(@;&%R(&1U(&9E;'1E
M="!VYG)E('1O;70B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,X(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C@*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#@*;7-G:60@(DQE8F%N;VXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y
M"FUS9VED("),969T(@IM<V=S='(@(E9E;G-T<F4B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,S$P-`IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B5F5N
M<W1R92!H;V1E(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#`*;7-G:60@
M(DQE9G0@=F%L=65S(@IM<V=S='(@(E9E;G-T<F4@=F5R9&EE<B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$R.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I
M9"`B3&5S;W1H;R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,30R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI8F5R:6$B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDP"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#`@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$S,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX.0IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S,V"FUS9VED("),:6=H="!$<FEZ
M>FQE(@IM<V=S='(@(DQE='0@9'5S:W)E9VXB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S,W"FUS9VED("),:6=H="!286EN(@IM<V=S='(@
M(DQE='0@<F5G;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M,S@*;7-G:60@(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B3&5T="!F;W)M
M:61D86=S<F5G;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M,SD*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R("),971T(&5T=&5R
M;6ED9&%G<W)E9VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S0P"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R("),971T92!R
M96=N8GEG97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0Q
M"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G<W1R("),971T
M(')E9VX@;65D('1O<F1E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS-#(*;7-G:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`B3&5T="!S;OAF
M86QL(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,T,PIM<V=I
M9"`B3&EG:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`B3&5T=&4@<V[X8GEG97(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K
M(@IM<V=S='(@(DQI;65R:6-K(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X
M,#(*;7-G:60@(DQI;FLB"FUS9W-T<B`B3&EN:R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B
M3&EN:R!P;VEN=',@=&\Z(@IM<V=S='(@(DQI;FL@<&5K97(@=&EL.B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ.#4Y"FUS9VED("),:6YK('1H92!E;6%I
M;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG
M(@IM<V=S='(@(DQI;FL@92UP;W-T(&%D<F5S<V5N('1I;"`G<VMR:78@;GDG
M+7-I9&4@=F5D('9I<VYI;F<B"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O
M:'1M;#)T97AT+G!H<#HQ.#$*;7-G:60@(DQI;FMS(@IM<V=S='(@(DQI;FME
M<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B3&EN=7@@
M0V]O:VEE(@IM<V=S='(@(DQI;G5X($-O;VMI92(*"B,Z(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B3&ES="`M('5S97(@8V%N
M('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(DQI<W0@+2!B<G5K97)E;B!K86X@
M<V4@;6%P<&5N(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S.`IM<V=I9"`B
M3&ES="!$871A8F%S97,B"FUS9W-T<B`B3&ES="!D871A8F%S97(B"@HC.B!S
M97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,`IM<V=I9"`B3&ES="!(96QP(%1O
M<&EC<R(*;7-G<W1R(")%;6YE<B!I($AJ96QP(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C$S-PIM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B3&ES="!T
M86)E;&QE<B(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C8S-PIM
M<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S='(@(DQI<W1E+6%R:VEV(@H*(SH@
M;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-C,R"FUS9VED("),:7-T+4AE
M;'`B"FUS9W-T<B`B3&ES=&5H:F5L<"(*"B,Z(&QI8B](;W)D92]-24U%+TAE
M861E<G,N<&AP.C8S.0IM<V=I9"`B3&ES="U)9"(*;7-G<W1R("),:7-T92U)
M9"(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C8S-0IM<V=I9"`B
M3&ES="U/=VYE<B(*;7-G<W1R(")%:65R(&%V(&QI<W1E(@H*(SH@;&EB+TAO
M<F1E+TU)344O2&5A9&5R<RYP:'`Z-C,V"FUS9VED("),:7-T+5!O<W0B"FUS
M9W-T<B`B3&ES=&4M<&]S="(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N
M<&AP.C8S-`IM<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS9W-T<B`B06)B;VYE
M<B!PY2!L:7-T92(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C8S
M,PIM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R(")3=&]P<"!A8F)O
M;FYE;65N="!PY2!L:7-T92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO
M;&ES="YI;F,Z-`IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB
M"FUS9W-T<B`B375L:6=H970@9F]R(.4@;&ES=&4@8G)U:V5R92!E<B!D96%K
M=&EV97)T+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-PIM<V=I9"`B
M3&ET97)A='5R92(*;7-G<W1R("),:71T97)A='5R(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$T-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS9VED("),:71H
M=6%N:6$B"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$S,3D*
M;7-G:60@(DQO861I;F<@;&EB<F%R:65S+BXN(@IM<V=S='(@(DQA<W1E<B!B
M:6)L:6]T96ME<BXN+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I;6%G
M97,N<&AP.C@V"FUS9VED("),;V%D:6YG+BXN(@IM<V=S='(@(DQA<W1E<BXN
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S0*;7-G:60@
M(DQO8V%L('1I;64Z("(*;7-G<W1R("),;VMA;"!T:60Z(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C@S"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS
M9W-T<B`B4W!RY6L@;V<@=&ED(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HU.34@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M-3<P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV,"!L:6(O0FQO
M8VLO<W5N<FES92YP:'`Z,C(*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HV,PIM
M<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B3&]K87-J;VXB"@HC.B!L;V=I;BYP
M:'`Z,34U('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-C0@=&5M<&QA
M=&5S+VQO9VEN+VUO8FEL92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO;6]B
M:6QE+FEN8SHQ-2!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S"FUS9VED
M("),;V<@:6XB"FUS9W-T<B`B3&]G9R!I;FXB"@HC.B!S97)V:6-E<R]P;W)T
M86PO<VED96)A<BYP:'`Z,34X"FUS9VED("),;V<@;W5T(@IM<V=S='(@(DQO
M9V<@=70B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W"FUS9VED("),
M;V=I;B!487-K<R(*;7-G<W1R("));FYL;V=G:6YG<V]P<&=A=F5R(@H*(SH@
M;&EB+TAO<F1E+T%U=&@N<&AP.CDU,@IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E
M8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I
M;F-O<G)E8W1L>2XB"FUS9W-T<B`B3&]G:6X@9F5I;&5T(&9O<F1I(&)R=6ME
M<FYA=FYE="!E;&QE<B!P87-S;W)D970@9'4@<VMR978@:6YN('9A<B!F96EL
M+B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY-#@*;7-G:60@(DQO9VEN(&9A
M:6QE9"XB"FUS9W-T<B`B3&]G:6X@9F5I;&5T+B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,S8R"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`B3&%N9R!T
M96MS="(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`IM<V=I9"`B3&]V
M92(*;7-G<W1R(")+:N9R;&EG:&5T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,W-`IM<V=I9"`B3&]W(@IM<V=S='(@(DQA=B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T<B`B4VWE(&=R
M97-K92!B;VMS=&%V97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L
M971T97)S(@IM<V=S='(@(E-MY2!L871I;G-K92!B;VMS=&%V97(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS
M.C$W"FUS9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#4@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$S-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,`IM
M<V=I9"`B3'5X96UB;W5R9R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S0R(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HS-S,*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0Q,"!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B
M34TB"FUS9W-T<B`B34TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C4V"FUS9VED(")-3U1$(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]T;F5F+G!H<#HS.0IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT
M(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z-#`*(RP@9G5Z>GD*
M;7-G:60@(DU31R(*;7-G<W1R(")#5E,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,34W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,*(RP@9G5Z>GD*;7-G:60@(DUA
M8V%O(@IM<V=S='(@(DQO:V%S:F]N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$U,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86-E9&]N:6$L(%1H
M92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDQ"FUS
M9VED(")-861A9V%S8V%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT.0HC+"!F=7IZ>0IM<V=I9"`B36%G:6,B"FUS9W-T<B`B12UP
M;W-T(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C<Q"FUS9VED(")-
M86EL(@IM<V=S='(@(DEN;F)O:W,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,3$T"FUS9VED(")-86EL($%D;6EN(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M,`IM<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,3,S.`IM<V=I9"`B36%K92!S=7)E('1H870@>6]U(&AA
M=F4@4$5!4B!I;G-T86QL960@86YD(&EN('EO=7(@:6YC;'5D92!P871H+B(*
M;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C<X('!O+W1R86YS
M;&%T:6]N+G!H<#HQ,#8R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")-
M86MI;F<@9&ER96-T;W)Y("5S(@IM<V=S='(@(E-O<G1E<FEN9W-R96MK96;X
M;&=E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDU"B,L(&9U>GIY"FUS9VED(")-86QA=VDB"FUS9W-T<B`B12UP;W-T
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDV"B,L(&9U>GIY"FUS9VED(")-86QA>7-I82(*;7-G<W1R(")%+7!O<W0B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38T(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.34*(RP@9G5Z>GD*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(E!O<W0B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34T(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,*
M(RP@9G5Z>GD*;7-G:60@(DUA;&DB"FUS9W-T<B`B4&]S="(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$T,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0HC+"!F=7IZ
M>0IM<V=I9"`B36%L=&$B"FUS9W-T<B`B12UP;W-T(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDQ"FUS9VED("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@
M8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@
M8V]L;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3`T,`IM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY-S@*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-34*;7-G:60@(DUA<%%U97-T
M(&UA<"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,S<V(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,3,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHV-PHC+"!F=7IZ>0IM<V=I9"`B36%R8V@B"FUS9W-T<B`B4_AK(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M,0HC+"!F=7IZ>0IM<V=I9"`B36%R9VEN(@IM<V=S='(@(D%D=F%R<V5L(@H*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")-
M87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR"FUS9VED(")-87)K('=I
M=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34R(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@(DUA<G-H86QL($ES;&%N9',B"FUS
M9W-T<B`B3W!P9&%T97(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34Y
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DUA<G1I;FEQ=64B
M"FUS9W-T<B`B061V87)S96PB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C$Q,0IM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(E-A;7-V
M87)E;F1E(&9E;'0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DUA=7)I=&%N:6$B"FUS
M9W-T<B`B061V87)S96PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38S
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.34*(RP@9G5Z>GD*;7-G:60@(DUA=7)I=&EU<R(*
M;7-G<W1R(")!9'9A<G-E;"(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S(T"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S
M='(@(B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$W
M"B,L(&9U>GIY"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB
M"FUS9W-T<B`B365L9&EN9V5N(&)L92!S;&5T=&5T+B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S`T"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.38*;7-G
M:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HX.3,@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,#D@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$R,S$*;7-G:60@(DUA>&EM=6T@;&5N9W1H
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HS-S@@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q
M-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y
M"B,L(&9U>GIY"FUS9VED(")-87DB"FUS9W-T<B`B1&%G;&EG(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(U,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.`HC+"!F
M=7IZ>0IM<V=I9"`B36%Y;W1T92(*;7-G<W1R(")5='-E96YD92(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B365D:6-I
M;F4B"FUS9W-T<B`B079S;.5T="(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C4S,0IM<V=I9"`B365E=&EN9R!#86YC96QL871I
M;VXB"FUS9W-T<B`B3?AT96%V;'ES;FEN9R(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C4P,PIM<V=I9"`B365E=&EN9R!);F9O
M<FUA=&EO;B(*;7-G<W1R(")-^'1E:6YF;W)M87-J;VXB"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,#D*;7-G:60@(DUE971I
M;F<@4')O<&]S86PB"FUS9W-T<B`B3?AT96EN;FMA;&QE;'-E(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3(U"FUS9VED(")-
M965T:6YG(%)E<&QY(@IM<V=S='(@(DWX=&5S=F%R(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3$T"FUS9VED(")-965T:6YG
M(%5P9&%T92(*;7-G<W1R(")-^'1E;W!P9&%T97)I;F<B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,3D*;7-G:60@(DUE971I
M;F<@57!D871E(%)E<75E<W0B"FUS9W-T<B`B1F]R97/X<G-E;"!O;2!M^'1E
M;W!P9&%T97)I;F<B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N
M:6YC.C$Y"B,L(&9U>GIY"FUS9VED(")-96UB97)S(@IM<V=S='(@(DUE;6\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8X"FUS9VED(")-96YU(&UO
M9&4Z(@IM<V=S='(@(DUE;GEM;V1U<SHB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P"B,L(&9U>GIY"FUS9VED
M(")-97)G92!C96QL<R(*;7-G<W1R(")-96QD:6YG<V9E;'0B"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z-3(W"B,L('!H<"UF;W)M870*;7-G:60@(DUE<F=I
M;F<@86QL("5S+G!O(&9I;&5S('1O('1H92!C;VUP96YD:75M+BXN("(*;7-G
M<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#,X"B,L('!H<"UF;W)M
M870*;7-G:60@(DUE<F=I;F<@;&]C86QE("5S+BXN("(*;7-G<W1R("(B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S@X"B,L('!H<"UF;W)M870*;7-G:60@
M(DUE<F=I;F<@=&AE(%!/(&9I;&4@9F]R("5S('1O('1H92!C;VUP96YD:75M
M+BXN("(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#(U"B,L
M('!H<"UF;W)M870*;7-G:60@(DUE<F=I;F<@=')A;G-L871I;VX@9F]R(&UO
M9'5L92`E<RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S(*;7-G:60@(DUE<W-A9V4B"FUS
M9W-T<B`B365L9&EN9R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M,C(V"FUS9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B
M=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92`B"B)V
M97)I9FEE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,3D*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@97AP:7)E
M9"XB"FUS9W-T<B`B365L9&EN9W-F96QT(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4Y,2!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C(V"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C,S(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8X"B,L(&9U
M>GIY"FUS9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`B365L9&EN9W-D871O
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"B,L(&9U>GIY"FUS9VED(")-
M971A<B!796%T:&5R(@IM<V=S='(@(E-T87)T(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B365T87(@8FQO8VL@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B1&5T(&5R(&EN9V5N(&UE;&1I;F=E<B!I(&1E
M;FYE('!O<W1B;VMS96XN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3`*
M(RP@9G5Z>GD*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N
M($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T
M;W(N(@IM<V=S='(@(D1E=&%L:F5R(&AA<B!B;&ET="!L;V=G970@9F]R(&%D
M;6EN:7-T<F%T;W)E;BXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R
M+G!H<#HW,"!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW-`HC+"!F
M=7IZ>0IM<V=I9"`B365T:&]D(@IM<V=S='(@(DQA=F5S="(*"B,Z(&QI8B](
M;W)D92]24$,O>&UL<G!C+G!H<#HX,B!L:6(O2&]R9&4O4E!#+W-O87`N<&AP
M.C$Q-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D("<E<R<@
M:7,@;F]T(&1E9FEN960B"FUS9W-T<B`B36%P<&5B<G5K(&5R(&EK:V4@=&EL
M9VIE;F=E;&EG+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV
M.2!L:6(O0FQO8VLO;65T87(N<&AP.C<S"FUS9VED(")-971R:6,B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDV"FUS9VED(")-97AI8V\B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C@U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(DUI8W)O
M;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"B,L
M(&9U>GIY"FUS9VED(")-:61D;&4B"FUS9W-T<B`B4VMJ=6QT(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP.C0Q"FUS9VED(")-:6UE(%1Y
M<&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#@*;7-G
M:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,P,`IM<V=I9"`B36EN('1E;7`@;&%S="`V
M(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(Q-PHC+"!F=7IZ>0IM<V=I9"`B36ER<F]R(@IM<V=S
M='(@(D9E:6PB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@
M(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8Y-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,T.0IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]2
M97%U97-T+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3`U"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E
M('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B
M"B)A<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,3,*(RP@9G5Z>GD*;7-G:60@(DUI<W-I;F<@
M;65S<V%G92!)1"XB"FUS9W-T<B`B1&5N;F4@;65L9&EN9V5N('1I;"(*"B,Z
M(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3<*;7-G:60@
M(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S='(@
M(B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S"B,L
M(&9U>GIY"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM<V=S='(@(D1E
M;FYE(&UE;&1I;F=E;B!T:6PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C4V"B,L(&9U>GIY"FUS9VED(")-;R(*;7-G<W1R
M(")&;'ET="(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,C(*(RP@
M9G5Z>GD*;7-G:60@(DUO8FEL92!-86EL(@IM<V=S='(@(DYY('!O<W0B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S<U"B,L(&9U>GIY"FUS
M9VED(")-;V1E<F%T92(*;7-G<W1R(")3:7-T(&UO9&EF:7-E<G0B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV.2!L:6(O2&]R9&4O34E-
M12]6:65W97(O>FEP+G!H<#HW,PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=&=Z+G!H<#HX.`HC+"!F=7IZ>0IM<V=I9"`B36]D:69I960@1&%T92(*;7-G
M<W1R(")3:7-T(&UO9&EF:7-E<G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*(RP@9G5Z>GD*;7-G:60@
M(DUO9&EF>2!54DPB"FUS9W-T<B`B16YD<F4B"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z-C4W"B,L(&9U>GIY"FUS9VED(")-;V1U;&4B"FUS9W-T<B`B4F]L
M;&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8Y-PHC+"!F=7IZ
M>0IM<V=I9"`B36]D=6QU<R(*;7-G<W1R(")2;VQL92(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$U,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36]L
M9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$T.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDQ"B,L(&9U>GIY"FUS9VED
M(")-;VYA8V\B"FUS9W-T<B`B3&]K87-J;VXB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,34V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3(*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,*(RP@9G5Z>GD*;7-G:60@
M(DUO;F=O;&EA(@IM<V=S='(@(E1I;"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR-3@W"B,L(&9U>GIY"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R
M(")3;'5T="!PY2!M96QD:6YG96XB"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N
M8V4N<&AP.C,V"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(DWE;F5D=&QI9R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$U,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-0IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO;VX@
M4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36]R;V-C;R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0T"B,L(&9U>GIY
M"FUS9VED(")-;W-T;'D@0VQE87(B"FUS9W-T<B`B2V]P:65R(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,T-0HC+"!F=7IZ>0IM<V=I9"`B
M36]S=&QY($-L;W5D>2(*;7-G<W1R(")+;W!I97(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S0V"B,L(&9U>GIY"FUS9VED(")-;W-T;'D@
M4W5N;GDB"FUS9W-T<B`B2V]P:65R(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA
M>6]U="YP:'`Z-#(P"B,L(&9U>GIY"FUS9VED(")-;W9E($1O=VXB"FUS9W-T
M<B`B9FQY='0@;F5D(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z
M-#(T"B,L(&9U>GIY"FUS9VED(")-;W9E($QE9G0B"FUS9W-T<B`B9FQY='0@
M;W!P(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-#(X"B,L(&9U
M>GIY"FUS9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(D9L>71T('1I;"!H^'ER
M92(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C0Q-@HC+"!F=7IZ
M>0IM<V=I9"`B36]V92!5<"(*;7-G<W1R(")F;'ET="!O<'`B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#DW"FUS9VED(")-;W9E
M(&1O=VXB"FUS9W-T<B`B9FQY='0@;F5D(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0Y-B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#DW"FUS9VED(")-;W9E('5P(@IM<V=S='(@(F9L>71T
M(&]P<"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C@@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R(")!
M9'9A<G-E;"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,38X"FUS9VED(")-
M=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(R,C8*(RP@9G5Z>GD*;7-G:60@(DUU;'1I<&QE
M('-E;&5C=&EO;B(*;7-G<W1R(")&:6QT97)I;FYS=&EL;&EN9V5R(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S-"!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S0Q"B,L(&9U>GIY"FUS9VED(")->2!!8V-O=6YT(@IM<V=S
M='(@(DMO;E]T;V5R(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HU
M,0IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]E9&ET+G!H<#HQ,C0*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDS"B,L(&9U>GIY"FUS9VED(")->6%N;6%R(@IM<V=S='(@(FYA
M=FXB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O86=R965M96YT7V)O='1O
M;2YI;F,Z-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C,Y-R!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$P-0HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=&YE9BYP:'`Z-#$@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-3@S"FUS9VED(").86UE(@IM<V=S='(@(DYA=FXB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,38Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-3<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G:60@
M(DYA;6EB:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$W."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(").875R=2(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HW,#8*
M;7-G:60@(DYE961S($%C=&EO;B(*;7-G<W1R(")4<F5N9V5R(&AA;F1L:6YG
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDX"B,L(&9U>GIY"FUS9VED(").97!A;"(*;7-G<W1R(").>2!P;W-T(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX
M"B,L(&9U>GIY"FUS9VED(").971H97)L86YD<R(*;7-G<W1R(").>2!P;W-T
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-3@*(RP@9G5Z>GD*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S
M='(@(DYY('!O<W0B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8P
M-0IM<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,#<*;7-G:60@(DYE='-C87!E($-!
M(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-C`Y"FUS9VED(").971S8V%P92!#02!P;VQI8WD@55),
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C`X
M"FUS9VED(").971S8V%P92!296YE=V%L(%523"(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8P-@IM<V=I9"`B3F5T<V-A<&4@
M4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HV,3`*;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M
M92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8Q
M,0HC+"!F=7IZ>0IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N
M="(*;7-G<W1R("));G1E="!P97)S;VYL:6<@<V5R=&EF:6MA="!T:6QG:F5N
M9V5L:6<N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,#0*(RP@
M9G5Z>GD*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E('1Y<&4B"FUS9W-T
M<B`B4V5T="!I;FX@<V5R=&EF:6MA="!H97(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C0R"B,L(&9U>GIY"FUS9VED(").971W;W)K(@IM<V=S
M='(@(DYY(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$Q(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS,C4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,W-@IM<V=I9"`B3F5V97(B"FUS9W-T<B`B06QD<FDB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3<P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-C(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*(RP@9G5Z>GD*
M;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B3&5G9R!T:6P@96X@;GD@
M:V]N=&%K="(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C4Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C(W"B,L(&9U>GIY"FUS9VED(").97<@0V%T96=O<GDB"FUS9W-T<B`B
M1FER;6%K871E9V]R:2(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W.0HC+"!F
M=7IZ>0IM<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`B3GD@<&]S="(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5
M<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ.#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V
M,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0HC+"!F=7IZ>0IM<V=I
M9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B3GD@<&]S="(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W
M:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z-#`@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR-C0*;7-G:60@(DYE=W,B"FUS9W-T<B`B3GEH
M971E<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#8*(RP@9G5Z
M>GD*;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T<B`B1W)U<'!E(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,C$@=&5M<&QA=&5S+V1A=&$O9&%T
M96UA<"YI;F,Z-#8*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,S<@
M=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,S(*;7-G:60@(DYE>'0B"FUS
M9W-T<B`B3F5S=&4B"@HC.B!L:6(O2&]R9&4O54DO4&%G97(N<&AP.C$Q-2!L
M:6(O2&]R9&4O54DO4&%G97(N<&AP.C$Q-@IM<V=I9"`B3F5X="!086=E(@IM
M<V=S='(@(DYE<W1E('-I9&4B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*
M(RP@9G5Z>GD*;7-G:60@(DYE>'0@4&AA<V4B"FUS9W-T<B`B3F5S=&4@<VED
M92(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S8V(&QI8B](;W)D92]0
M<F5F<R]522YP:'`Z,S<P"B,L(&9U>GIY"FUS9VED(").97AT(&]P=&EO;G,B
M"FUS9W-T<B`B5&EL8F%K92!T:6P@5F%L9R(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3FEC87)A9W5A
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S$@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY-PHC+"!F=7IZ>0IM<V=I9"`B3FEG97(B"FUS9W-T<B`B
M06QD<FDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<S(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-C8*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3<*(RP@9G5Z>GD*;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`B06QD
M<FDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Y"B,L(&9U
M>GIY"FUS9VED(").:6=H="(*;7-G<W1R(")(^'EE<W0B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3<Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-C<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*(RP@9G5Z>GD*
M;7-G:60@(DYI=64B"FUS9W-T<B`B3V)S(2(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HX.#@*;7-G:60@(DYO(@IM<V=S='(@(DYE
M:2(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ,38*;7-G
M:60@(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D
M:69F97)E;F-E<R!F;W(N(@IM<V=S='(@(B(*"B,Z(&QI8B]61E,O25-/5W)I
M=&5R+G!H<#HQ,3$*;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G>2!F;W(@
M;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S(R"FUS9VED(").;R!B871C:"!T96UP
M;&%T92XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP
M:'`Z-S@@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,C(T"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70N<&AP.C(T-@IM<V=I9"`B3F\@8FQO8VL@97AI
M<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O;6-A;"YP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(DYO
M(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(DEN9V5N(&MO;F9I9W5R87-J;VX@97(@<W!E<VEF:7-E
M<G0@9F]R(%-13"UA=71E;G1I<V5R:6YG+B(*"B,Z(&%D;6EN+W-E='5P+V1I
M9F8N<&AP.C4U"B,L(&9U>GIY"FUS9VED(").;R!C:&%N9V4N(@IM<V=S='(@
M(D%N9W)E(&5N9')I;F=E<B(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z
M,30T"FUS9VED(").;R!C:&EL9"!P97)M:7-S:6]N<R!A<F4@=&\@8F4@861D
M960@8F5L;W<@=&AI<R!L979E;"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R
M;7,O861D8VAI;&0N<&AP.C8Q"B,L(&9U>GIY"FUS9VED(").;R!C:&EL9')E
M;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R("(G
M)7,G(&)L92!L86=T('1I;"!R971T:6=H971S<WES=&5M970N(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C$S-3@*(RP@9G5Z>GD*;7-G:60@(DYO(&-O;6UA
M;F0@<W!E8VEF:65D+B(*;7-G<W1R("));F=E;B!B<G5K97(@=F%L9W0N(@H*
M(SH@;&EB+TAO<F1E+G!H<#HQ-S,@;&EB+TAO<F1E+G!H<#HT.3,@;&EB+TAO
M<F1E+U5T:6PN<&AP.C<U,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S
M+B(*;7-G<W1R("));F=E;B!K;VYF:6=U<F%S:F]N(&5R('-P97-I9FES97)T
M(&9O<B!344PM:V%T96=O<FEE<BXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S<S
M"B,L(&9U>GIY"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B26YG96X@:V]N9FEG
M=7)A<VIO;B!E<B!S<&5S:69I<V5R="!F;W(@3$1!4"UI;G-T:6QL:6YG96YE
M+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HU.34*(RP@9G5Z>GD*;7-G:60@(DYO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@
M5D93+B(*;7-G<W1R("));F=E;B!K;VYF:6=U<F%S:F]N(&5R('-P97-I9FES
M97)T(&9O<B!344PM:V%T96=O<FEE<BXB"@HC.B!L:6(O5D93+W-Q;%]F:6QE
M+G!H<#HW-3<*(RP@9G5Z>GD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@
M(DEN9V5N(&MO;F9I9W5R87-J;VX@97(@<W!E<VEF:7-E<G0@9F]R(%-13"UK
M871E9V]R:65R+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S(S"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8U.0HC+"!F=7IZ>0IM
M<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@(DEN9V5N
M(&UE;&1I;F=E<B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,C4R"B,L('!H
M<"UF;W)M870*;7-G:60@(DYO(&5N=')Y('=I=&@@=&AE(&ED("<E<R<@97AI
M<W1S(&EN('1H92!O<FEG:6YA;"!H96QP(&9I;&4N(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]"<F]W<V5R+G!H<#HX.3(*(RP@9G5Z>GD*;7-G:60@(DYO
M(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B5FES('-L971T961E(&5L96UE;G1E
M<B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HW,0HC+"!F=7IZ>0IM<V=I
M9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@(DEN9V5N('9E9&QE9V<@9G5N
M;F5T+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT,3,@<&\O=')A;G-L871I
M;VXN<&AP.C4R,@HC+"!F=7IZ>0IM<V=I9"`B3F\@;&]C86QE('-P96-I9FEE
M9"XB"FUS9W-T<B`B26YG96X@8G)U:V5R('9A;&=T+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ,38@;&EB+T)L;V-K+W-U;G)I<V4N<&AP
M.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(Q"B,L(&9U>GIY"FUS9VED
M(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(E-V87(@=&EL(&QI<W1E
M;B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-3@*(RP@
M9G5Z>GD*;7-G:60@(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(DEN
M9V5N(&UE;&1I;F=E<B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-C$*(RP@9G5Z>GD*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*
M;7-G<W1R("));F=E;B!B<G5K97(@=F%L9W0N(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8V,@HC+"!F=7IZ>0IM<V=I9"`B3F\@;G5M
M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`B26YG96X@8G)U:V5R('9A;&=T+B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B
M3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(DEN9V5N('9E9&QE9V<@
M9G5N;F5T+B(*"B,Z(&QI8B](;W)D92]!=71H+VAT='`N<&AP.CDS"B,L(&9U
M>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`B26YG96X@:V]N9FEG=7)A<VIO;B!E<B!S
M<&5S:69I<V5R="!F;W(@4U%,+6%U=&5N=&ES97)I;F<N(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O:6UA<"YP:'`Z,3$R"B,L(&9U>GIY"FUS9VED(").;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B26YG96X@:V]N9FEG=7)A<VIO;B!E<B!S<&5S:69I<V5R="!F;W(@4U%,
M+6%U=&5N=&ES97)I;F<N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z
M-S0*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+
M97)B97)O<R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B26YG96X@:V]N9FEG
M=7)A<VIO;B!E<B!S<&5S:69I<V5R="!F;W(@4U%,+6%U=&5N=&ES97)I;F<N
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z.3<*(RP@9G5Z>GD*;7-G
M:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,1$%0(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R("));F=E;B!K;VYF:6=U<F%S:F]N(&5R('-P97-I9FES
M97)T(&9O<B!344PM875T96YT:7-E<FEN9RXB"@HC.B!L:6(O2&]R9&4O075T
M:"]S87-L+G!H<#HX,B!L:6(O2&]R9&4O075T:"]L;V=I;BYP:'`Z.#@*(SH@
M;&EB+TAO<F1E+T%U=&@O<&%M+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R("));F=E;B!K;VYF:6=U<F%S:F]N(&5R('-P97-I9FES97)T(&9O
M<B!344PM875T96YT:7-E<FEN9RXB"@HC.B!L:6(O2&]R9&4O075T:"]P87-S
M=V0N<&AP.C$S.0HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B26YG96X@
M:V]N9FEG=7)A<VIO;B!E<B!S<&5S:69I<V5R="!F;W(@4U%,+6%U=&5N=&ES
M97)I;F<N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<VUB+G!H<#HX.0HC+"!F=7IZ
M>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B26YG96X@:V]N9FEG=7)A<VIO;B!E<B!S<&5S
M:69I<V5R="!F;W(@4U%,+6%U=&5N=&ES97)I;F<N(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HQ,S$X"FUS9VED("(B"B).;R!P871H('1O('1H
M92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y
M(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I=&@@4$M#4R`Q,B!D871A+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN
M8SHQ.0IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0S"B,L(&9U>GIY"FUS9VED(").;R!R=6QE<R(*;7-G<W1R(").;W1A=&5R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT-`HC+"!F=7IZ>0IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B26YG
M96X@;65L9&EN9V5R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$R-@IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@
M9F]R(&-A8VAE+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C4V"B,L(&9U>GIY"FUS9VED(").;R!U<V5R;F%M92!A
M;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`B5F5N;FQI<W0@<VMR:78@
M:6YN(&)R=6ME<FYA=FX@;V<@<&%S<V]R9"(*"B,Z(&QI8B](;W)D92]24$,O
M>&UL<G!C+G!H<#HQ-#$*(RP@9G5Z>GD*;7-G:60@(DYO('9A;&ED(%A-3"!D
M871A(')E='5R;F5D(@IM<V=S='(@(DEN9V5N('9#87)D(&1A=&$@9G5N;F5T
M+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX.38@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDP-@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3$W(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HY,S0*(RP@9G5Z>GD*;7-G:60@(DYO
M('9A;'5E<R(*;7-G<W1R("));F=E;B!M96QD:6YG97(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3$P"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN
M(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q
M.`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I
M;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C`T"FUS9VED
M(").;VX@4&%R=&EC:7!A;G0B"FUS9W-T<B`B26MK92!D96QT86=E<B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,R!L:6(O2&]R9&4O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HU-C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E
M9G,O:61E;G1I='ES96QE8W0N:6YC.C@X"FUS9VED(").;VYE(@IM<V=S='(@
M(DEN9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B3F]R9&EC("A)
M4T\M.#@U.2TQ,"DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$W,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDW"B,L(&9U>GIY"FUS9VED(").;W)F
M;VQK($ES;&%N9"(*;7-G<W1R(")/<'!D871E<B(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*(RP@9G5Z>GD*;7-G
M:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B2&IE;'`B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34X(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-CD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*;7-G
M:60@(DYO<G1H97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<V(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-S`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*(RP@
M9G5Z>GD*;7-G:60@(DYO<G=A>2(*;7-G<W1R(").;W)M86PB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8V-`HC+"!F=7IZ>0IM<V=I9"`B3F]T
M($%F=&5R(@IM<V=S='(@(DEK:V4@:VQA9&0B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C8V,PHC+"!F=7IZ>0IM<V=I9"`B3F]T($)E9F]R92(*
M;7-G<W1R(")):VME(&ML861D(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS-38*
M(RP@9G5Z>GD*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R(")3;W)T
M97)I;F=S<F5K:V5F^&QG92(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+G!H<#HV
M-R!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C@T
M"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z
M.34*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP
M.C0Y"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H
M<#HV,`HC+"!F=7IZ>0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*;7-G<W1R
M(")):VME('-L971T970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C8X"B,L(&9U>GIY"FUS9VED(").;W0@<V5T(@IM<V=S
M='(@(DEK:V4@<VQE='1E="(*"B,Z(&QI8B]61E,N<&AP.C$X-"!L:6(O5D93
M+G!H<#HR,#,@;&EB+U9&4RYP:'`Z,C(Q(&QI8B]61E,N<&AP.C(S.`HC.B!L
M:6(O5D93+G!H<#HR-34@;&EB+U9&4RYP:'`Z,C<Q(&QI8B]61E,N<&AP.C(X
M.2!L:6(O5D93+G!H<#HS,C4*(SH@;&EB+U9&4RYP:'`Z,S@X(&QI8B]61E,N
M<&AP.C0W,B!L:6(O5D93+G!H<#HU-#0@;&EB+U9&4RYP:'`Z-38R"B,L(&9U
M>GIY"FUS9VED(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R(")$96X@9F]R97-P
M=7)T92!O<'!G879E;B!E<B!I:VME('-T;W1T970N(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#<@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$U.0IM<V=I9"`B3F]T97,B"FUS9W-T<B`B3F]T871E<B(*"B,Z
M('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN
M9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M86EN=&5N86YC92]C;VYF:7)M7W1O<"YI;F,Z,3`*;7-G:60@(DYO=&EC
M92(*;7-G<W1R(")/8G,A(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,X-"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-S4*(RP@9G5Z>GD*;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@(D%L9')I
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-#$*(RP@9G5Z>GD*;7-G:60@
M(DYU;6)E<B(*;7-G<W1R(").879N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$T,C(*(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM
M<V=S='(@(C$P,"!T96=N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-C8@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C`@;&EB+TAO<F1E+T9O<FTN<&AP.C$T
M-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#0*(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@
M(D%N=&%L;"!K;VQO;FYE<B!I(&]P<'-U;6UE<FEN9W-V:7-N:6YG96XZ(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-C0@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$T,3@@;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#`*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*(RP@9G5Z>GD*;7-G:60@
M(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(D%N=&%L;"!K;VQO;FYE<B!I(&]P
M<'-U;6UE<FEN9W-V:7-N:6YG96XZ(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8V.0HC+"!F=7IZ>0IM<V=I9"`B3G5M8F5R<R!N;W0@
M<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB
M"FUS9W-T<B`B1'4@;&%G97(@96X@9&ES=')I8G5S:F]N<R!L:7-T92XB"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT.#,*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C8S"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-"!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,30X"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,S(Y"FUS
M9VED(")/2R(*;7-G<W1R(")/2R(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HX,30*(RP@9G5Z>GD*;7-G:60@(D]B:F5C="(*;7-G
M<W1R(")%;6YE(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*
M(RP@9G5Z>GD*;7-G:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(D]B:F5K
M=&5T(&)L92!I:VME(&9U;FYE="(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP
M.C$S-R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(R,PHC+"!F=7IZ>0IM<V=I
M9"`B3V)J96-T(&-R96%T;W(@<&5R;6ES<VEO;G,B"FUS9W-T<B`B3W)D<W1Y
M<F5R(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P.3D*(RP@9G5Z>GD*;7-G
M:60@(D]C=&%L(@IM<V=S='(@(D1A9VQI9R(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HS.#,@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B3V9F96YS92!F:6QT
M97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P
M-`IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(DMO;G1O<B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ.#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$W,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B3VUA
M;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z-S8*(RP@9G5Z>GD*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O
M<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(D1E;FYE('1J96YE<F5N('-T
M^'1T97(@:6MK92!D96QI;F<@878@;6%P<&5R+B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HY-0HC+"!F=7IZ>0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@
M9F]R='5N97,B"FUS9W-T<B`B26YG96X@=F5D;&5G9R!F=6YN970N(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$X,S4@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y
M-34*(RP@9G5Z>GD*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL
M;W=E9"XB"FUS9W-T<B`B17!O<W1A9')E<W-E;B!D:6XZ(@H*(SH@<V5R=FEC
M97,O<VAA<F5S+V5D:70N<&AP.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE
M<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI
M<"!O<B!O=VYE<B`B"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS-0HC+"!F=7IZ>0IM<V=I
M9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B5FES92!I;FYH;VQD
M(&D@970@96=E="!V:6YD=2XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C(U-PIM<V=I9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A
M8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4T"B,L(&9U>GIY"FUS9VED(")/<&5N<R!T:&ES(&QI;FL@:6X@82!N
M97<@=VEN9&]W(@IM<V=S='(@(DAE;G1E(&YY92!M96QD:6YG97(@:2!E="!E
M9V5T('9I;F1U/R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I
M9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV,#`*;7-G:60@(D]P=&EO;F%L
M(%!A<G1I8VEP86YT(@IM<V=S='(@(E9A;&=F<FD@9&5L=&%G97(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS
M(@IM<V=S='(@(E9A;&<B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,CD@=&5M
M<&QA=&5S+W!R969S+V%P<"YI;F,Z-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B5F%L9R(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HQ,3(*(RP@9G5Z>GD*;7-G:60@(D]P=&EO;G,Z(@IM
M<V=S='(@(E9A;&<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$X"B,L(&9U>GIY"FUS9VED(")/<F1E<F5D($QI<W0B"FUS
M9W-T<B`B5F5L9R!L:7-T92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-3DQ"B,L(&9U>GIY"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`B
M3W)G86YI<V5R:6YG(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M.3(*(RP@9G5Z>GD*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T
M<B`B3W)G86YI<V5R:6YG(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$R-PIM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R(")/<F=A;FES97)I;F<B
M"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0HC+"!F=7IZ>0IM<V=I9"`B
M3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`B2&%N9&QI
M;F=E<B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M
M870*;7-G:60@(D]R:6=I;F%L('1E;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3(P('-E<G9I8V5S+VME
M>6)O87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDV(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,#8*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,R!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3(Q"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,CD*;7-G
M:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(D%N;F5N(&EN9F]R;6%S
M:F]N(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,0HC+"!F=7IZ
M>0IM<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B3&%G<F4@5F%L
M9R(*"B,Z(&QI8B](;W)D92]!=71H+W!A;2YP:'`Z.#,*(RP@9G5Z>GD*;7-G
M:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R(")/;6%D<F5S<V5R:6YG(&9E:6QE="XB"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HQ,C<Y"B,L(&9U>GIY"FUS9VED(")01U`@1&EG:71A;"!3
M:6=N871U<F4B"FUS9W-T<B`B4VMY9V=E;&5G9R!S:6=N871U<C\B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,S(X"B,L(&9U>GIY"FUS9VED(")0
M1U`@16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B4$=0+6MR>7!T97(@;65L9&EN
M9R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$S.#<*(RP@9G5Z>GD*
M;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(D]F9F5N=&QI9R!01U`M
M;OAK:V5L<FEN9R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$S-C8*
M(RP@9G5Z>GD*;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS
M9W-T<B`B4$=0('-I9VYE<B]K<GEP=&5R(&UE;&1I;F<B"@HC.B!A9&UI;B]P
M:'!S:&5L;"YP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(E!(4"!#;V1E(@IM<V=S
M='(@(DAO<F1E(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED(")0
M2%`@4VAE;&PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,T.`HC+"!F=7IZ>0IM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G
M<W1R("),;V=G(&EN;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS-#D*(RP@9G5Z>GD*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B5FES
M="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-3`*(RP@9G5Z
M>GD*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`B5FES="(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS-3$*(RP@9G5Z>GD*;7-G:60@(E!-(%-N
M;W<@4VAO=V5R<R(*;7-G<W1R(")6:7-T(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,U,@HC+"!F=7IZ>0IM<V=I9"`B4$T@5"U3=&]R;7,B
M"FUS9W-T<B`B1G)A(@H*(SH@;&EB+V%P:2YP:'`Z,3(V"FUS9VED(")07TA0
M(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*(RP@9G5Z>GD*;7-G:60@(E!A9&1I
M;F<B"FUS9W-T<B`B571V:61E<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ.#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#`*(RP@9G5Z>GD*;7-G:60@(E!A:VES
M=&%N(@IM<V=S='(@(D1A=&\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3DT(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`R"B,L(&9U>GIY"FUS9VED(")086QA=2(*
M;7-G<W1R(")%+7!O<W0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DR
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")086QE<W1I;FEA;B!497)R:71O
M<GDL($]C8W5P:65D(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ.#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0HC+"!F=7IZ>0IM<V=I9"`B4&%N
M86UA(@IM<V=S='(@(FYA=FXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3@U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")087!U82!.97<@1W5I;F5A
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.34@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#,*(RP@9G5Z>GD*;7-G:60@(E!A<F%G=6%Y(@IM<V=S
M='(@(D4M<&]S="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M-#<*(RP@9G5Z>GD*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B2V]P
M:65R(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$W-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`P,@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34W(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C`S"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M-S`@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S8W"FUS9VED(")087-S=V]R9"(*;7-G
M<W1R(")087-S;W)D(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ
M,S4T"B,L(&9U>GIY"FUS9VED(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T
M<B`B4&%S<V]R9"(*"B,Z(&QI8B](;W)D92]!=71H+W)A9&EU<RYP:'`Z,34W
M"B,L(&9U>GIY"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("));F=E;B!K;VYF:6=U<F%S:F]N
M(&5R('-P97-I9FES97)T(&9O<B!344PM875T96YT:7-E<FEN9RXB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C`S-PHC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O
M<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B5FES(&UA:6QL:7-T92!I
M;F9O<FUA<VIO;B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY
M,`HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(E!A<W-O<F0B
M"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0HC+"!F=7IZ>0IM
M<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R(")087-S;W)D(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,34P(&QI8B](;W)D92]&;W)M+G!H<#HR,#$X"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*(RP@9G5Z>GD*;7-G:60@
M(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")087-S<&AR87-E('-T
M96UM97(@:6MK92!O=F5R96YS(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R
M."!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C(*(RP@9G5Z>GD*;7-G:60@(E!A<W1E(@IM<V=S='(@(D1A=&\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,W"FUS
M9VED(")087-T92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q"B,L(&9U>GIY
M"FUS9VED(")0871H(@IM<V=S='(@(D1A=&\B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHT('1E;7!L871E<R]A9&UI;B]U<V5R+W)E
M;6]V97%U975E9"YI;F,Z-`IM<V=I9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*(RP@9G5Z>GD*
M;7-G:60@(E!E;W!L92(*;7-G<W1R(")2;VQL92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"B,L(&9U>GIY"FUS9VED
M(")097)C96YT(@IM<V=S='(@(E-K<FEV('5T(@H*(SH@=&5M<&QA=&5S+VUA
M:6YT96YA;F-E+V-O;F9I<FU?8F]T=&]M+FEN8SHV"FUS9VED(")097)F;W)M
M($UA:6YT96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B571F^'(@=F5D;&EK
M96AO;&1S;W!E<F%S:F]N97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,SDV"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@
M;&]G:6X_(@IM<V=S='(@(E5T9OAR('9E9&QI:V5H;VQD<V]P97)A<VIO;F5R
M('9E9"!I;FYL;V=G:6YG/R(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H
M<#HV,2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C0*(SH@861M:6XO<&5R
M;7,O861D8VAI;&0N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N
M(@IM<V=S='(@(E!E<G-O;FQI9R(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP
M:'`Z-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@
M)R5S)R!N;W0@9&5L971E9"XB"FUS9W-T<B`B1&5N(&9O<F5S<'5R=&4@;W!P
M9V%V96X@97(@:6MK92!I;7!L96UE;G1E<G0N(@H*(SH@861M:6XO<&5R;7,O
M961I="YP:'`Z,C(T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HY,PHC.B!A
M9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@861M:6XO<&5R;7,O9&5L971E+G!H
M<#HW-`HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R871I
M;VXB"FUS9W-T<B`B)7,@4$=0(&%D;6EN:7-T<F%S:F]N(@H*(SH@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HQ-#D@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ
M-3(*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-38*(RP@9G5Z>GD*;7-G
M:60@(E!E<FUI<W-I;VYS(&9O<B(*;7-G<W1R(")097)S;VYL:6<B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4*;7-G:60@(E!E<G-O;F%L($EN9F]R
M;6%T:6]N(@IM<V=S='(@(E!E<G-O;FQI9R!I;F9O<FUA<VIO;B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ.#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$W.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I
M9"`B4&5R=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-34*;7-G:60@(E!E=',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$X-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4&AI;&EP<&EN
M97,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ.3D*;7-G:60@(E!H;VYE(@IM<V=S='(@(E1E;&5F;VXB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0W"FUS9VED(")0:&]T;W,B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P,0HC+"!F=7IZ>0IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B
M1&%T;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4V"FUS9VED(")0;&%T:71U9&5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#@*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!C;VYF:7)M
M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T
M<B`B17(@9'4@4TE+2T52('#E(&%T(&1U(/AN<VME<B#E('-L971T92!D92!V
M86QG=&4@;W!P9OAR:6YG96YE/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0HC+"!F=7IZ>0IM<V=I9"`B
M4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E
M;&5M96YT+B(*;7-G<W1R(")%<B!D=2!324M+15(@<.4@870@9'4@^&YS:V5R
M(.4@<VQE='1E(&1E('9A;&=T92!O<'!F^')I;F=E;F4_(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(U-38*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!E;G1E
M<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(E9E;FYL:6=S="!S:W)I
M=B!I;FX@9&5T(&YY92!N879N970Z(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*(RP@9G5Z>GD*;7-G:60@(E!L96%S
M92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@
M(E9E;FYL:6=S="!S:W)I=B!I;FX@;F%V;F5T('#E(&1E;B!N>64@;6%P<&5N
M.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,CDY"B,L(&9U>GIY"FUS9VED
M(")0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R(")6
M96YN;&EG<W0@<F5T="!T=F5T>61I9V4@96QL97(@=6=Y;&1I9V4@861R97-S
M97(N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(V-3(*;7-G:60@(E!L96%S
M92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y
M<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR-#,T"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI
M9"!T:6UE+B(*;7-G<W1R(")696YN;&EG<W0@<VMR:78@:6YN(&1E="!N>64@
M;F%V;F5T.B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*
M;7-G:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE
M;2XB"FUS9W-T<B`B5F5N;FQI9W-T(&=I(&5T('-A;6UE;F1R86<@878@<')O
M8FQE;65T+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3@@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,@IM<V=I9"`B4&QE87-E('!R;W9I
M9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B5F5N;FQI
M<W0@<VMR:78@:6YN(&)R=6ME<FYA=FX@;V<@<&%S<V]R9"(*"B,Z('1E;7!L
M871E<R]M86EN=&5N86YC92]A9W)E96UE;G1?=&]P+FEN8SHQ,@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E
M>'0N("!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE
M("(*(G-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C$W"FUS9VED(")0;&5A<V4@<F5P;W)T(&%N>2!B=6=S('1O(&DQ.&Y`;&ES
M=',N:&]R9&4N;W)G+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HU-#`*;7-G:60@(B(*(E!L96%S92!R979I
M97<@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO;BP@86YD('1H96X@<V5L96-T
M(&%N(&%C=&EO;B!F<F]M('1H92`B"B)M96YU(&)E;&]W+B(*;7-G<W1R("(B
M"B)696YN;&EG<W0@<V4@;W9E<B!D96X@9OAL9V5N9&4@:6YF;W)M87-J;VYE
M;BP@=F5L9R!SY2!E;B!H86YD;&EN9R!F<F$@;65N>65N("(*(FYE9&5N=6YD
M97(N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M-#,U"FUS9VED(")0;&5A<V4@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92!M
M96YU(&)E;&]W+B(*;7-G<W1R(")696YN;&EG<W0@=F5L9R!E;B!H86YD;&EN
M9R!F<F$@;65N>65N(&YE9&5N=6YD97(N(@H*(SH@;&EB+TAO<F1E+U!R969S
M+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S(*(RP@9G5Z>GD*;7-G:60@(E!L96%S
M92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B5F5N;FQI
M9W-T('-K<FEV(&EN;B!D970@;GEE(&YA=FYE=#HB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3@X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M.#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P"B,L(&9U>GIY"FUS
M9VED(")0;VQA;F0B"FUS9W-T<B`B1FER;6$B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-3<*(RP@9G5Z>GD*;7-G:60@(E!O;&ET:6-S(@IM<V=S='(@
M(E-LY2!S86UM96XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4V
M"B,L(&9U>GIY"FUS9VED(")0;VQL<R(*;7-G<W1R(")3;.4@<V%M;65N(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M,@IM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W"FUS9VED
M(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED
M(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B4&]S="!T
M;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C8T(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C8Y"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@
M9F]R(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]0<F5F<R]L9&%P+G!H<#HY.0HC+"!F=7IZ>0IM<V=I9"`B4')E9G-?;&1A
M<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M(")!=71H7VEM<#H@2V%N(&EK:V4@9FEN;F4@9&5N(&[X9'9E;F1I9V4@24U!
M4"!U='9I9&5L<V5N+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]S97-S:6]N+G!H
M<#HS-@HC+"!F=7IZ>0IM<V=I9"`B4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@
M<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VEM
M<#H@2V%N(&EK:V4@9FEN;F4@9&5N(&[X9'9E;F1I9V4@24U!4"!U='9I9&5L
M<V5N+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.3@*(RP@9G5Z
M>GD*;7-G:60@(E!R97-E;G1A=&EO;G,B"FUS9W-T<B`B1F]R<FEG92!M96QD
M:6YG(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C,*(RP@9G5Z>GD*;7-G
M:60@(E!R97-S=7)E(@IM<V=S='(@(E!A<W-O<F0B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(U-PHC+"!F=7IZ>0IM<V=I9"`B4')E<W-U<F4@870@<V5A
M(&QE=F5L.B`B"FUS9W-T<B`B4&%S<V]R9"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ.3@*(RP@9G5Z>GD*;7-G:60@(E!R97-S=7)E.B`B
M"FUS9W-T<B`B4&%S<V]R9"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ.#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S
M='(@(D9O<FCE;F1S=FES;FEN9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`HC+"!F=7IZ>0IM<V=I
M9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@
M(E9I<R!V961L96=G(&D@970@96=E="!V:6YD=2(*"B,Z(&QI8B](;W)D92]5
M22]086=E<BYP:'`Z-S$@;&EB+TAO<F1E+U5)+U!A9V5R+G!H<#HW,@IM<V=I
M9"`B4')E=FEO=7,@4&%G92(*;7-G<W1R(")&;W)R:6=E('-I9&4B"@HC.B!L
M:6(O2&]R9&4O4')E9G,O54DN<&AP.C,U-B!L:6(O2&]R9&4O4')E9G,O54DN
M<&AP.C,V,`HC+"!F=7IZ>0IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G
M<W1R(")&;W)R:6=E(&UE;&1I;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,#D*(RP@
M9G5Z>GD*;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(D1I;B!P<FEV871E
M(&[X:VME;"(*"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ-S4*(RP@9G5Z>GD*
M;7-G:60@(E!R;V)L96TB"FUS9W-T<B`B6U!R;V)L96UR87!P;W)T72(*"B,Z
M('-E<G9I8V5S+W!R;V)L96TN<&AP.C$Q,@IM<V=I9"`B4')O8FQE;2!$97-C
M<FEP=&EO;B(*;7-G<W1R(")0<F]B;&5M8F5S:W)I=F5L<V4B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C$V"FUS9VED(")0<F]J96-T<R(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`Y-2!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C$W,@HC+"!F=7IZ>0IM<V=I9"`B4')O;7!T('1E>'0B"FUS
M9W-T<B`B4F5T=&5T('1E:W-T(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z-#`Y"B,L(&9U>GIY"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(D1I
M;B!O9F9E;G1L:6=E(&[X:VME;"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-C8Y"B,L(&9U>GIY"FUS9VED(")0=6)L:6,@2V5Y($%L9V]R:71H
M;2(*;7-G<W1R(")/9F9E;G1L:6<@4$=0+6[X:VME;')I;F<B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HR,C,*(RP@9G5Z>GD*;7-G:60@(E!U8FQI
M8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN
M(@IM<V=S='(@(E!E<G-O;FQI9R!01U`M;OAK:V5L<&%R(&=E;F5R97)T+B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$X,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#$*(RP@9G5Z>GD*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S='(@(E!R;W1O
M:V]L;#HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DV(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`S"B,L(&9U>GIY"FUS9VED(")1871A<B(*;7-G<W1R(")3=&%R
M="(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HW,`IM<V=I9"`B475E<GDB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV.#<*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B
M:70I(@IM<V=S='(@(D]F9F5N=&QI9R!01U`M;OAK:V5L('1E:W-T(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(R-#@*(RP@9G5Z>GD*;7-G:60@(E)A9&EO
M('-E;&5C=&EO;B(*;7-G<W1R(")&:6QT97)I;FYS=&EL;&EN9V5R(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U,PHC+"!F=7IZ>0IM<V=I
M9"`B4F%I;B(*;7-G<W1R("),;VMA<VIO;B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS-30*(RP@9G5Z>GD*;7-G:60@(E)A:6X@16%R;'DB
M"FUS9W-T<B`B079S;.5T=#H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,U-0HC+"!F=7IZ>0IM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@
M(DQO9V<@:6YN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U
M-@HC+"!F=7IZ>0IM<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B5FES="(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-3<*(RP@9G5Z>GD*
M;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B5FES="(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-3@*(RP@9G5Z>GD*;7-G:60@(E)A
M:6X@=&\@4VYO=R(*;7-G<W1R(")6:7-T(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S
M='(@(DYO=&%T97(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H
M<#HW,2!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW-@HC+"!F=7IZ
M>0IM<V=I9"`B4F%T:6\B"FUS9W-T<B`B3&]K87-J;VXB"@HC.B!L:6(O2&]R
M9&4O4&5R;7,N<&AP.C(Y-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$Q-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$X,`HC+"!F=7IZ>0IM<V=I9"`B4F5A9"(*
M;7-G<W1R(")/<'!D871E<B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY,`HC+"!F=7IZ>0IM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G
M<W1R(").>64@;65L9&EN9V5R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E+FEN8SHQ,@HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L
M971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@
M9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S0*(RP@9G5Z>GD*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@
M86-T:6]N(@IM<V=S='(@(D=J96YO<'!T82!S97-J;VXB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S@Q"FUS9VED(")2969R97-H($1Y;F%M:6,@365N
M=2!%;&5M96YT<SHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,S,0HC+"!F=7IZ>0IM<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB
M"FUS9W-T<B`B3W!P9&%T97(@;6%P<&5V:7-N:6YG.B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HX.#D@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,#4@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$R,C<*(RP@9G5Z>GD*;7-G:60@(E)E9V5X(@IM<V=S
M='(@(DYU;&QS=&EL;"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C,T"FUS
M9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,R-`IM<V=I9"`B4F5M87)K<R(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT-3<*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#<V"FUS
M9VED(")296UE;6)E<B!T:&4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G
M<W1R(")(=7-K(&QE9&EG+V]P<'1A='0M:6YF;W)M87-J;VXN(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$Q-`HC+"!F=7IZ>0IM<V=I9"`B4F5M;W1E
M(%-E<G9E<G,B"FUS9W-T<B`B5&IE;F5R(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C@T"FUS9VED(")296UO=&4@55),("AH='1P.B\O=W=W
M+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,2!T96UP;&%T97,O861M:6XO=7-E
M<B]A<'!R;W9E+FEN8SHT,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO
M=F5Q=65U960N:6YC.C$U"B,L(&9U>GIY"FUS9VED(")296UO=F4B"FUS9W-T
M<B`B1FIE<FX@<&%R(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC
M.C$Q"B,L(&9U>GIY"FUS9VED(")296UO=F4@0FQO8VLB"FUS9W-T<B`B1FIE
M<FX@:VEL9&4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-3,R"B,L(&9U>GIY"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@
M(D9J97)N(&MI;&1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHT,`HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&9O<FUA='1I
M;F<B"FUS9W-T<B`B1FIE<FX@<&%R(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-C4X"B,L(&9U>GIY"FUS9VED(")296UO=F4@
M9G)O;2!M>2!C86QE;F1A<B(*;7-G<W1R(")3;&5T="!F<F$@:V%L96YD97)E
M;B!M:6XB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$S-@IM<V=I
M9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`B1FIE<FX@<&%R(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$Y-@IM<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP
M="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHT,0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R
M(")&:F5R;B!K:6QD92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4F5M;W9E('1H:7,@;F]D
M92!F<F]M('1H92!D;V-U;65N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]R96UO=F4N:6YC.C$V"B,L(&9U>GIY"FUS9VED(")296UO
M=F4@=7-E<B(*;7-G<W1R(")&:F5R;B!K:6QD92(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V92YI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(D9J97)N(&MI;&1E(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3DW"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C(X,`HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HS-#D*;7-G:60@
M(E)E<&QY(%-E;G0N(@IM<V=S='(@(E-V87(@<V5N9'0N(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#4Y"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0V.`HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT-S@*;7-G:60@(E)E<&QY('=I
M=&@@3F]T(%-U<'!O<G1E9"!-97-S86=E(@IM<V=S='(@(E-V87(@870@;65L
M9&EN9V5N(&EK:V4@<W3X='1E<R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C0V-@IM<V=I9"`B4F5P;'D@=VET:"!F<F5E+V)U
M<WD@9F]R(&YE>'0@,B!M;VYT:',N(@IM<V=S='(@(E-V87(@;65D(&QE9&EG
M+V]P<'1A='0@9F]R(&1E(&YE<W1E('1O(&WE;F5D96YE+B(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0V-0IM<V=I9"`B4F5P
M;'D@=VET:"!R97%U97-T960@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G
M<W1R(")3=F%R(&UE9"!D96X@9F]R97-P=7)T92!L961I9R]O<'!T871T+6EN
M9F]R;6%S:F]N96XN(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z,3@Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297!L
M>3H@)7,B"FUS9W-T<B`B4W9A<CHB"@HC.B!L:6(O2&]R9&4O4E!#+WAM;')P
M8RYP:'`Z,3,Y"FUS9VED(")297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D
M+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4N<&AP.C$X,"!L:6(O2&]R9&4N<&AP.C4P,PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B4F5Q=6ER960@)R5S)R!N;W0@<W!E8VEF:65D(&EN("5S
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E#E:W)E=F0@)W5I9"<@97(@:6MK
M92!S<&5S:69I<V5R="!I(&EN<W1I;&QI;F=S:V]N9FEG=7)A<VIO;F5N+B(*
M"B,Z(&QI8B]61E,O<W%L+G!H<#HV,#$@;&EB+U9&4R]F='`N<&AP.C<W.2!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HW-C,*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E)E<75I<F5D("<E<R<@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B4.5K<F5V9"`G=6ED)R!E<B!I:VME('-P
M97-I9FES97)T(&D@:6YS=&EL;&EN9W-K;VYF:6=U<F%S:F]N96XN(@H*(SH@
M;&EB+TAO<F1E+U5T:6PN<&AP.C<V,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4F5Q=6ER960@)R5S)R!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(E#E:W)E=F0@)W5I9"<@97(@:6MK92!S<&5S:69I
M<V5R="!I(&EN<W1I;&QI;F=S:V]N9FEG=7)A<VIO;F5N+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+U)E;F1E<F5R+G!H<#HS,CD*;7-G:60@(E)E<75I<F5D($9I
M96QD(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C4Y,@IM<V=I9"`B4F5Q=6ER960@4&%R=&EC:7!A;G0B"FUS
M9W-T<B`B3V)L:6=A=&]R:7-K(&1E;'1A9V5R(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S$@;&EB+TAO<F1E+T9O<FTN<&AP.C,S.2!L:6(O2&]R9&4O1F]R;2]2
M96YD97)E<BYP:'`Z,S$V"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHQ,#$@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT-`IM<V=I
M9"`B4F5S970B"FUS9W-T<B`B3G5L;'-T:6QL(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-#8*(RP@9G5Z>GD*;7-G:60@(E)E<V5T(%!A<W-W
M;W)D(@IM<V=S='(@(E!A<W-O<F0B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B4F5S970@66]U<B!087-S=V]R
M9"(*;7-G<W1R(")':F5N;W!P=&$@<V5S:F]N(@H*(SH@861M:6XO<&AP<VAE
M;&PN<&AP.C8V(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S<6QS:&5L
M;"YP:'`Z-S,*(RP@9G5Z>GD*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B4_AK
M97)E<W5L=&%T(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C@R,0IM<V=I9"`B
M4F5S=6QT<R`H:6YC;'5D:6YG($AO<F1E*3HB"FUS9W-T<B`B(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C@Q.0HC+"!F=7IZ>0IM<V=I9"`B4F5S=6QT<SHB
M"FUS9W-T<B`B4_AK97)E<W5L=&%T(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C$P,B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED
M(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R(")4:6QB86ME('1I;"!686QG
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P,PHC+"!F=7IZ>0IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R(")/8G-E<G9E
M<B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B4F5V97)T($-O;F9I9W5R
M871I;VXB"FUS9W-T<B`B0F4@;VT@;&5V97)I;F=S8F5K<F5F=&5L<V4B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,P"B,L(&9U>GIY"FUS9VED(")2
M:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`B5&EL8F%K92!T:6P@
M5F%L9R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`HC+"!F=7IZ>0IM
M<V=I9"`B4FED9&QE<R(*;7-G<W1R(")3:VIU;'0B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*(RP@9G5Z>GD*
M;7-G:60@(E)I9VAT(@IM<V=S='(@(DCX>65S="(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HS,3`V"B,L(&9U>GIY"FUS9VED(")2:6=H="!H96%D97(B"FUS
M9W-T<B`B16MS96UP96QV97)D:65R.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HS,3`R"B,L(&9U>GIY"FUS9VED(")2:6=H="!V86QU97,B"FUS9W-T<B`B
M16MS96UP96QV97)D:65R.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`HC+"!F=7IZ>0IM<V=I9"`B4F]?
M=R!0<F]P97)T:65S+BXN(@IM<V=S='(@(DQA=B!P<FEO<FET970B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(S-R!L:6(O2&]R9&4O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU.#,*;7-G:60@(E)O;&4B"FUS
M9W-T<B`B4F]L;&4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DX(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`S"B,L(&9U>GIY"FUS9VED(")2;VUA;FEA(@IM<V=S
M='(@(DYO<FUA;"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HR,#@*(RP@9G5Z>GD*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B
M9FQY='0@;W!P(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(P-0HC+"!F=7IZ>0IM<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`B
M9FQY='0@;W!P(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(Q,0HC+"!F=7IZ>0IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@
M(D9L>71T('1I;"!H^'ER92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*(RP@9G5Z>GD*;7-G:60@(E)O=R!0
M<F]P97)T:65S(@IM<V=S='(@(DQA=B!P<FEO<FET970B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P"B,L(&9U
M>GIY"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R("),878@<')I;W)I
M=&5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#$*(RP@9G5Z>GD*;7-G:60@(E)O=W,Z(@IM<V=S='(@(E-LY2!S86UM
M96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4S"B,L(&9U>GIY"FUS9VED(")2=6QE<R(*;7-G<W1R(")2;VQL
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL
M(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S
M(&]N;'DB"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.0HC
M+"!F=7IZ>0IM<V=I9"`B4G5N(@IM<V=S='(@(D]B<V5R=F5R(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$Y.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I
M9"`B4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$X.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*(RP@9G5Z>GD*
M;7-G:60@(E)W86YD82(*;7-G<W1R(")+86QE;F1E<B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z,S`P"FUS9VED(")3+TU)344@0W)Y<'1O9W)A
M<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HS-#$*(RP@9G5Z>GD*;7-G:60@(E,O34E-12!%;F-R>7!T
M960@365S<V%G92(*;7-G<W1R(")+<GEP=&5R(&UE9"!3+TU)344B"@HC.B!L
M:6(O2&]R9&4O075T:"]S87-L+G!H<#HX-@HC+"!F=7IZ>0IM<V=I9"`B4T%3
M3"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")/
M;6%D<F5S<V5R:6YG(&9E:6QE="XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#@Q"B,L(&9U>GIY"FUS9VED(")335,@365S<V%G:6YG(@IM<V=S
M='(@(DUE;&1I;F=S=FES;FEN9R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR
M,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HS-3@*;7-G:60@(E-3(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S4*;7-G:60@(E-3
M2"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+VUO8FEL92YP:'`Z,S@*;7-G:60@(E-50T-%4U,B"FUS9W-T<B`B(@H*
M(SH@;&EB+V%P:2YP:'`Z,3,P"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-C$*(RP@9G5Z>GD*;7-G:60@(E-A(@IM<V=S='(@(DQA9W)E('-O;2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$X.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*
M;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3,Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M.3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(E-A:6YT
M($MI='1S(&%N9"!.979I<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3,Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3$*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(E-A:6YT($QU
M8VEA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#D@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ
M=65L;VXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@
M=&AE($=R96YA9&EN97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H
M7W-E;&8I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M-3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*(RP@9G5Z>GD*;7-G:60@(E-A;6]A(@IM
M<V=S='(@(DQA9W)E('-O;2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#<*(RP@9G5Z>GD*;7-G:60@(E-A;B!-87)I
M;F\B"FUS9W-T<B`B061V87)S96PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C$V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")386\@5&]M92!A;F0@
M4')I;F-I<&4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3(P"B,L(&9U>GIY"FUS9VED(")3871E;&QI=&4@4')O=FED97(B"FUS
M9W-T<B`B4W1A="]&>6QK92`H07)B96ED*2(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A=61I($%R
M86)I82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI
M;F,Z.3@*;7-G:60@(E-A=F4B"FUS9W-T<B`B3&%G<F4@<V]M(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`B3&%G<F4@<V]M(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT.0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B4V%V92`G)7,G(@IM<V=S='(@(DQA9W)E('-O;2(*
M"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T
M:6]N<R(*;7-G<W1R("),86=R92!686QG(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$V,0IM<V=I9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A
M=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A
M<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HV.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V
M960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B4V5N9"!S:7-T92!I;F9O
M<FUA<VIO;B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDP"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U<&=R861E('-C
M<FEP="!T;SH@)R5S)RXB"FUS9W-T<B`B2W5N;F4@:6MK92!L86=E(%9&4RUB
M86-K96YD.B`E<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.0HC+"!F
M=7IZ>0IM<V=I9"`B4V-I96YC92(*;7-G<W1R(")3:6=N97)T(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,34@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z,3<*;7-G:60@(E-E87)C:"(*;7-G<W1R(")3^&LB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Q"B,L(&9U>GIY"FUS
M9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R(")3^&L@)7,B"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,30R.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B4V5A<F-H:6YG($AO<F1E(&%P<&QI8V%T:6]N<R!I;B`E<R(*;7-G<W1R
M("));FYS=&EL;&EN9V5R(&9O<B!S^&LB"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z,3(S"B,L(&9U>GIY"FUS9VED(")396%R8VAI;F<@9V5T=&5X="!B:6YA
M<FEE<RXN+B(*;7-G<W1R("));FYS=&EL;&EN9V5R(&9O<B!S^&LB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,CDU.`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T
M($9I;&5S(@IM<V=S='(@(E9E;&<@86QL92(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-38*;7-G:60@(E-E;&5C="!A(&1A=&4B
M"FUS9W-T<B`B5F5L9R!E;B!D871O(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ.3@*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O
M(&%D9"(*;7-G<W1R(")696QG(&5N(&MO;G1O(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHT,PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@;F5W
M(&]W;F5R(@IM<V=S='(@(E9E;&<@:6YG96XB"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z-C`*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A('-E
M<G9E<B(*;7-G<W1R(")696QG(&5N(&1A=&\B"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$U-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@=7-E
M<B!T;R!A9&0B"FUS9W-T<B`B5F5L9R!E="!F96QT(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(V-34*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;&P@9&%T
M92!C;VUP;VYE;G1S+B(*;7-G<W1R(")696QG(&5N(&1A=&\B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#$T"B,L(&9U>GIY"FUS
M9VED(")396QE8W0@86X@;V)J96-T(@IM<V=S='(@(E9E;&<@:6YG96XB"@HC
M.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(B(*
M(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE
M<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@
M9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B)696QG(&MA<F%K=&5R
M96YE(&1U('1R96YG97(@9G)A(&)O:W-E;B!U;F1E<BX@1'4@:V%N(&1E<F5T
M=&5R(&MO<&EE<F4@;V<@(@HB;&EM92!D96T@:6YN(&9R82!T96MS=&9E;'1E
M="XB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L
M96-T('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`B5F5L9R!D871O<VMI
M;&QE=&5G;CHB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-`IM<V=I
M9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`B5F5L9R!D871O
M9F]R;6%T(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN
M8SHX-0IM<V=I9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C
M:&%N9V4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC
M.C$V"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R
M.B(*;7-G<W1R(")696QG(&1A=&]S:VEL;&5T96=N.B(*"B,Z('1E;7!L871E
M<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE('1I;64@9F]R
M;6%T.B(*;7-G<W1R(")696QG('1I9'-F;W)M870Z(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHV-`IM<V=I9"`B4V5L96-T('1W;R!M871C:&EN
M9R!F:65L9',N(@IM<V=S='(@(E9E;&<@=&\@<V%M<W9A<F5N9&4@9F5L="XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDV"FUS9VED(")396QE8W0@
M>6]U<B!C;VQO<B!S8VAE;64N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR,S@*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L
M86YG=6%G93HB"FUS9W-T<B`B5F5L9R#X;G-K970@<W!RY6LZ(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C4S"FUS9VED(")3
M96YD($QA=&5S="!);F9O<FUA=&EO;B(*;7-G<W1R(")396YD('-I<W1E(&EN
M9F]R;6%S:F]N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M-3@*;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B4V5N9"!P
M<F]B;&5M<F%P<&]R="(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HY-C0*(RP@9G5Z>GD*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@
M(E-E;F0@;65L9&EN9R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3,@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,30*(RP@9G5Z>GD*;7-G:60@(E-E
M;G-O<CH@(@IM<V=S='(@(B`@("!%;6YE.B`B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@R(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW,PHC+"!F=7IZ>0IM<V=I9"`B4V5P=&5M8F5R(@IM
M<V=S='(@(DUE;6\B"@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DY"FUS9VED(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,C4*(RP@9G5Z>GD*;7-G
M:60@(E-E<FEA;"!.=6UB97(B"FUS9W-T<B`B3F%V;B(*"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"B,L(&9U>GIY"FUS9VED(")3
M97-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@(DUE;&1I;F=S9F5L="(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,CDV"B,L(&9U>GIY"FUS9VED(")3970B
M"FUS9W-T<B`B5F5L9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-@IM
M<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@
M<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED(")3970@=7`@<F5M
M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R
M('!O<G1A;"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@T"B,L(&9U>GIY"FUS9VED(")3970@>6]U<B!P<F5F97)R960@;&%N9W5A
M9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S='(@(E-E='0@
M<VED92!O<'!D871E<FEN9RP@;V<@=FES;FEN9W,@=F%L9RXB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3@*(RP@9G5Z>GD*;7-G:60@(B(*(E-E="!Y
M;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R
M969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G
M<W1R(")3971T('-I9&4@;W!P9&%T97)I;F<L(&]G('9I<VYI;F=S('9A;&<N
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-`HC+"!F=7IZ>0IM<V=I
M9"`B4V5T=7`B"FUS9W-T<B`B5F5L9R(*"B,Z('1E;7!L871E<R]A9&UI;B]S
M971U<"]I;F1E>"YH=&UL.C,X"FUS9VED(")3971U<"!U<&=R861E('-C<FEP
M=',@879A:6QA8FQE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-#D*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I
M8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(P,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@
M(E-E>6-H96QL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0W,PHC+"!F=7IZ>0IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B
M5FES="(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S"B,L
M(&9U>GIY"FUS9VED(")3:&]R="!3=6UM87)Y(@IM<V=S='(@(DMO<G0@<V%M
M;65N9')A9SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,V"FUS9VED
M(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK
M<S\B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR.30@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M-SD*(RP@9G5Z>GD*;7-G:60@(E-H;W<B"FUS9W-T<B`B5FES="(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#D*;7-G:60@(B(*(E-H;W<@9&EF9F5R
M96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G
M96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0X,`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN
M('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3<U,PIM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O
M<FEG:6YA;"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@P
M,@HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B5FES="(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,34*(RP@9G5Z>GD*;7-G:60@
M(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B5FES
M92!F:6QT97)I:V]N970@:2!M96YY96X_(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,S.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T
M:&4@)7,@365N=2!O;B!T:&4@;&5F=#\B"FUS9W-T<B`B5FES92!F:6QT97)I
M:V]N970@:2!M96YY96X_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X"B,L(&9U>GIY"FUS9VED(")3:&]W
M('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(D9O
M<FCE;F1S=FES;FEN9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,PHC+"!F=7IZ>0IM<V=I9"`B4VAO=R!T
M:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B1F]R:.5N9'-V
M:7-N:6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4Y"B,L(&9U>GIY"FUS9VED(")3:&]W('1H92!486)L
M92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B1F]R:.5N9'-V:7-N
M:6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4Q"B,L(&9U>GIY"FUS9VED(")3:&]W('1H92!I;6%G92!P
M<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")&;W)HY6YD<W9I<VYI;F<B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<U,0HC+"!F=7IZ>0IM<V=I9"`B4VAO
M=R!U<&QO860B"FUS9W-T<B`B5FES('-L971T961E(&5L96UE;G1E<B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-3D*(RP@9G5Z>GD*;7-G
M:60@(E-H;W=E<G,B"FUS9W-T<B`B5FES="(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS-C`*(RP@9G5Z>GD*;7-G:60@(E-H;W=E<G,@16%R
M;'DB"FUS9W-T<B`B5FES="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS-C$*(RP@9G5Z>GD*;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G<W1R
M(")6:7-T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,@IM
M<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,SDQ"B,L(&9U>GIY"FUS9VED
M(")3:')I;FLB"FUS9W-T<B`B3&]G9R!I;FXB"@HC.B!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+G!H<#HV.#0@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z
M-S0V"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C@P-"!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+G!H<#HX-C8*(SH@;&EB+TAO<F1E+T)L;V-K+TQA
M>6]U="YP:'`Z.3`Q(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.CDS.`HC
M.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HY-C8@;&EB+TAO<F1E+T)L
M;V-K+TQA>6]U="YP:'`Z.3DV"FUS9VED(")3:')I;FL@;W(@;6]V92!N96EG
M:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P-@IM<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C<X"B,L(&9U>GIY"FUS9VED(")3
M:6=N('5P(@IM<V=S='(@(E-I9VYE<G0B"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C@Y"FUS9VED(")3:6=N('5P(&EF(&YO="!R96=I<W1E<F5D
M(@IM<V=S='(@(E)E9VES=')E<B!D96<@;VT@:6MK92!R96=I<W1R97)T(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,S8*(RP@9G5Z>GD*;7-G
M:60@(E-I9VYA='5R92(*;7-G<W1R(")$:6X@<VEG;F%T=7(Z(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,S4*(RP@9G5Z>GD*;7-G:60@(E-I
M9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`B1&EN('-I9VYA='5R.B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#8@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(P,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*
M(RP@9G5Z>GD*;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R(")$:6X@<VEG;F%T
M=7(Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Y,2!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3(P-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(R.0HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C(S,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDQ.2!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,S$P.`HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M<F%R+G!H<#HV."!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX-PIM<V=I9"`B4VEZ
M92(*;7-G<W1R(")3=/AR<F5L<V4B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N
M8V4O8V]N9FER;5]B;W1T;VTN:6YC.CD*;7-G:60@(E-K:7`@36%I;G1E;F%N
M8V4B"FUS9W-T<B`B2&]P<"!O=F5R('9E9&QI:V5H;VQD(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C0S,2!P;R]T<F%N<VQA=&EO;BYP:'`Z-#@T('!O+W1R
M86YS;&%T:6]N+G!H<#HV-C8*(SH@<&\O=')A;G-L871I;VXN<&AP.C@V,"!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,3(P-`IM<V=I9"`B4VMI<'!E9"XN+B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$P(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`V"B,L(&9U>GIY"FUS9VED(")3;&]V86MI82(*;7-G<W1R(").
M;W)M86PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`X(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`V"B,L(&9U>GIY"FUS9VED(")3;&]V96YI82(*;7-G<W1R(").
M;W)M86PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8S"B,L
M(&9U>GIY"FUS9VED(")3;F]W(@IM<V=S='(@(E9I<W0B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8T"B,L(&9U>GIY"FUS9VED(")3;F]W
M(%-H;W=E<B(*;7-G<W1R(")6:7-T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,V-0HC+"!F=7IZ>0IM<V=I9"`B4VYO=R!3:&]W97)S(@IM
M<V=S='(@(E9I<W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S8V"B,L(&9U>GIY"FUS9VED(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T
M<B`B5FES="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C<*
M(RP@9G5Z>GD*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(E9I
M<W0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W-@HC+"!F=7IZ>0IM<V=I
M9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@(B`@("!%;6YE.B`B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(X,`IM<V=I9"`B4VYO=R!E<75I=F%L96YT(&EN
M('=A=&5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(P,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P-`HC+"!F=7IZ>0IM<V=I9"`B4V]L;VUO
M;B!)<VQA;F1S(@IM<V=S='(@(D]P<&1A=&5R(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(Q-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-PHC+"!F=7IZ>0IM<V=I
M9"`B4V]M86QI82(*;7-G<W1R(").;W)M86PB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,34*(RP@9G5Z>GD*;7-G:60@(E-O
M<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(E-O<G1E<FEN9W-R96MK96;X
M;&=E(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X,2!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C$S"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")3;W5R8V4@861D
M<F5S<R(*;7-G<W1R(")&:7)M86%D<F5S<V4B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C4U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#<*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3;W5T:"!!
M9G)I8V$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*
M;7-G:60@(E-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S@*;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC
M:"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS
M,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(E-O=71H
M97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B2&IE;'`B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@
M8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A
M8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#$U"B,L(&9U>GIY"FUS9VED
M(")3<&%C97(B"FUS9W-T<B`B3&%G<F4@<V]M(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"B,L(&9U>GIY"FUS
M9VED(")3<&%C:6YG(@IM<V=S='(@(E5T=FED97(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED(")3
M<&%C:6YG(&%N9"!P861D:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HX,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<R"B,L(&9U>GIY"FUS9VED
M(")3<&%I;B(*;7-G<W1R(")5='9I9&5R(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.CDU"B,L(&9U>GIY"FUS9VED(")3<&%M(@IM<V=S='(@(DQA
M9W)E('-O;2(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B
M4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`B4W!E<VEA;'1E9VYI
M;FYT87-T:6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV,@HC+"!F=7IZ>0IM<V=I9"`B4W!L:70@8V5L;"(*
M;7-G<W1R(")696QG(&%L;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8V"B,L(&9U>GIY"FUS9VED(")3<&QI
M="!C;VQU;6XB"FUS9W-T<B`B5F5L9R!A;&QE(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0HC+"!F=7IZ>0IM
M<V=I9"`B4W!L:70@<F]W(@IM<V=S='(@(E9E;&<@86QL92(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B4W!O<G1S(@IM
M<V=S='(@(E9I:W1I9R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#$@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX.0HC+"!F=7IZ>0IM<V=I9"`B4W)I($QA;FMA(@IM
M<V=S='(@(DQO9V<@:6YN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C8X(&QI8B]";&]C:R]M971A<BYP:'`Z-S(*(RP@9G5Z>GD*;7-G:60@
M(E-T86YD87)D(@IM<V=S='(@(DMA;&5N9&5R(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C8R"B,L(&9U>GIY"FUS9VED(")3=&%R(%1R96LB"FUS9W-T
M<B`B4W1A<G0B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HT-#,*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z-30X"FUS9VED(")3=&%R="(*;7-G<W1R(")3=&%R="(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR-3@Y(&QI8B](;W)D92]&;W)M+G!H<#HR-SDX"B,L
M(&9U>GIY"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@(E-T87)T(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.30*(RP@9G5Z>GD*;7-G:60@
M(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(E-T870O1GEL:V4@*$%R8F5I
M9"DB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU
M.#,@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@
M(E-T871U<R(*;7-G<W1R(")3=&%T=7,B"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z-#DQ"B,L('!H<"UF;W)M870*;7-G:60@(E-T871U<R!F;W(@;&]C86QE
M("5S+BXN("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@P
M-`HC+"!F=7IZ>0IM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`B1&EN
M(&EN9F]R;6%S:F]N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M.38*(RP@9G5Z>GD*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@(D9R
M82UA9')E<W-E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(R-0HC+"!F=7IZ>0IM<V=I9"`B4W1R
M:6YG(&QI<W0B"FUS9W-T<B`B4W9A<G1E;&ES=&4B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3@U-PIM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D
M9')E<W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R
M;W=S97(N<&AP.C,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D
M:7)E8W1O<GD@)R5S)R!N;W0@9F]U;F0N(@IM<V=S='(@(DYO=&ES(&QY='1E
M<B`E<R!I:VME(&9U;FYE="XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C8S-2!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW.`IM
M<V=I9"`B4W5B:F5C="(*;7-G<W1R(")%;6YE(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HV-C@*(RP@9G5Z>GD*;7-G:60@(E-U8FIE8W0@4'5B
M;&EC($ME>2!);F9O(@IM<V=S='(@(D1I;B!O9F9E;G1L:6=E(&[X:VME;"(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,S(@;&EB+TAO<F1E+T9O<FTO4F5N
M9&5R97(N<&AP.C,Q,PIM<V=I9"`B4W5B;6ET(@IM<V=S='(@(E-E;F0B"@HC
M.B!S:6=N=7`N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI
M='1E9"!R97%U97-T('1O(&%D9"`G)7,G('1O('1H92!S>7-T96TN(%EO=2!C
M86X@;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@:&%S(&)E96X@
M87!P<F]V960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(*(RP@9G5Z>GD*;7-G:60@(E-U8G-C<FEP
M="(*;7-G<W1R(")396YD(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Q,R!L
M:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*
M;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`B4W5K<V5S<R(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C@U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S
M9G5L;'D@861D960@)R5S)R!T;R!T:&4@<WES=&5M+B(*;7-G<W1R("(E<R!B
M;&4@;&%G="!T:6P@)7,N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D
M871A(&9O<B!U<V5R("<E<R<@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("(E
M<R!B;&4@;&%G="!T:6P@)7,N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX,2!A
M9&UI;B]P97)M<R]D96QE=&4N<&AP.C8Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"`G)7,G+B(*;7-G<W1R(")(
M96YD96QS96X@8FQE('-L971T970N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M
M;W9E9"`G)7,G(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B)7,@8FQE(&QA
M9W0@=&EL("5S+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*(RP@
M9G5Z>GD*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T
M:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(DMU;FYE(&EK
M:V4@;&%G92!61E,M8F%C:V5N9#H@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-34*(RP@9G5Z>GD*
M;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B2W5N;F4@:6MK92!L86=E(%9&4RUB86-K96YD.B`E<R(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O
M;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B2W5N;F4@:6MK92!L86=E
M(%9&4RUB86-K96YD.B`E<R(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@
M)R5S)R(*;7-G<W1R("));FYS=&EL;&EN9V5N92!B;&4@;W!P9&%T97)T+B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C<R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S
M9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`B)7,@8FQE(&QA9W0@=&EL("5S+B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#0@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(Q,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#4*(RP@9G5Z>GD*;7-G:60@(E-U9&%N(@IM<V=S='(@(E5T=FED97(B"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU-3@*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-38P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*
M;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`B4V%M;65N9')A9R(*"B,Z(&QI8B]"
M;&]C:R]S=6YR:7-E+G!H<#HV-@HC+"!F=7IZ>0IM<V=I9"`B4W5N(%)I<V4B
M"FUS9W-T<B`B16UN92(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HW,0HC
M+"!F=7IZ>0IM<V=I9"`B4W5N(%-E="(*;7-G<W1R(")%;6YE(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V.`IM<V=I9"`B4W5N;GDB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W.0HC
M+"!F=7IZ>0IM<V=I9"`B4W5N<FES92(*;7-G<W1R(")%;6YE(@H*(SH@;&EB
M+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V
M"B,L(&9U>GIY"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R(")%;6YE
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W.`HC+"!F=7IZ
M>0IM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(B`@("!%;6YE.B`B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3@R"B,L(&9U>GIY"FUS9VED
M(")3=6YS970B"FUS9W-T<B`B16UN92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ.#$*(RP@9G5Z>GD*;7-G:60@(E-U;G-E=#H@(@IM<V=S
M='(@(B`@("!%;6YE.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$S"B,L(&9U>GIY"FUS9VED(")3=7!E<G-C<FEP="(*
M;7-G<W1R(")"97-K<FEV96QS92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT-C4*(RP@9G5Z>GD*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B26UP
M;W)T97(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$U(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`W"B,L(&9U>GIY"FUS9VED(")3=7)I;F%M92(*;7-G<W1R(")N
M879N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3@*(RP@9G5Z
M>GD*;7-G:60@(E-U<FYA;64B"FUS9W-T<B`B;F%V;B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(Q,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-V
M86QB87)D(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(Q.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.0HC+"!F=7IZ>0IM
M<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(E/X:R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q
M-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*(RP@9G5Z>GD*;7-G
M:60@(E-W961E;B(*;7-G<W1R("),97-T(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C4V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(E-W
M:71Z97)L86YD(@IM<V=S='(@(E/X:R(*"B,Z(&QI8B](;W)D92]344PO2V5Y
M=V]R9',N<&AP.CDX"B,L(&9U>GIY"FUS9VED(")3>6YT87@@97)R;W(@:6X@
M<V5A<F-H('1E<FUS(@IM<V=S='(@(E3X;2!S^'!P96QK=7)V96XB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$X(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,3<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X"FUS
M9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8Y"B,L(&9U>GIY"FUS9VED(")4
M+5-T;W)M(@IM<V=S='(@(D9R82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS-S`*(RP@9G5Z>GD*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@
M(D9R82(*"B,Z(&QI8B](;W)D92]$871A+W1S=BYP:'`Z,3<Q"B,L(&9U>GIY
M"FUS9VED(")44U8@9FEL92(*;7-G<W1R(")4:71T96PB"@HC.B!L:6(O2&]R
M9&4O54DO5&%B;&4N<&AP.C$S-0HC+"!F=7IZ>0IM<V=I9"`B5&%B;&4B"FUS
M9W-T<B`B5&ET=&5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW,PHC+"!F=7IZ>0IM<V=I9"`B5&%B;&4@4')O
M<&5R=&EE<R(*;7-G<W1R(")&;W)HY6YD<W9I<VYI;F<B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<R"B,L(&9U
M>GIY"FUS9VED(")486)L92!P<F]P97)T:65S(@IM<V=S='(@(D9O<FCE;F1S
M=FES;FEN9R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S0@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$R"B,L(&9U>GIY"FUS9VED(")486EW86XB
M"FUS9W-T<B`B4_AK(@H*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(Q.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(U(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$P"B,L(&9U>GIY"FUS9VED(")486II:VES=&%N(@IM<V=S='(@(D1A
M=&\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,U(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$S"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.34*(RP@9G5Z>GD*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B0G)U
M:V5R;F%V;CHB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,38X"FUS
M9VED(")487-K<R(*;7-G<W1R(")/<'!G879E<B(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-3DW"B,L(&9U>GIY"FUS9VED(")496QE<&AO;F4@
M3G5M8F5R(@IM<V=S='(@(DYA=FXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(X.`IM<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,3(*(RP@9G5Z>GD*;7-G:60@(E1E
M;7!E<F%T=7)E(@IM<V=S='(@(D1I;B!S:6=N871U<CHB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3@V"B,L(&9U>GIY"FUS9VED(")496UP
M97)A='5R93H@(@IM<V=S='(@(D1I;B!S:6=N871U<CHB"@HC.B!L:6(O2&]R
M9&4O5&5M<&QA=&4N<&AP.C(Q,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&5M<&QA=&4@)R5S)R!N;W0@9F]U;F0N(@IM<V=S='(@(E9E9&QE9V=E
M="!B;&4@:6MK92!F=6YN970N(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M-CD*(RP@9G5Z>GD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(B5S(%!'4"!A9&UI;FES=')A<VIO;B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8T,0IM<V=I9"`B5&5N=&%T:79E
M;'D@06-C97!T(')E<75E<W0B"FUS9W-T<B`B1V]D=&$@9F]R97-P^')S96P@
M9F]R96SX<&EG(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-C@Y"FUS9VED(")496YT871I=F5L>2!!8V-E<'1E9"(*;7-G<W1R
M(")';V1T82!F;W)E;/AP:6<B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(P
M,PHC+"!F=7IZ>0IM<V=I9"`B5&5X="(*;7-G<W1R(")495]K<W0B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8U"FUS9VED(")497AT($]N;'DB"FUS
M9W-T<B`B2W5N('1E:W-T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`HC+"!F=7IZ>0IM<V=I9"`B5&5X="!A
M;&EG;B(*;7-G<W1R(").97-T92!S:61E(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0HC+"!F=7IZ>0IM<V=I9"`B5&5X
M='1O<"(*;7-G<W1R(")495]K<W0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-PIM<V=I9"`B5&AA:2`H5$E3+38R
M,"DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q,`HC+"!F=7IZ>0IM<V=I9"`B5&AA:6QA;F0B"FUS
M9W-T<B`B4_AK(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDT-`HC+"!F=7IZ
M>0IM<V=I9"`B5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+B(*;7-G
M<W1R(")$=2!H87(@8FQI="!L;V=G970@=70N(#QB<B`O/B!486MK(&9O<B!A
M="!D=2!B<G5K=&4@<WES=&5M970N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C$P-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE("5S(&AE;'`@9FEL92!F
M;W(@)7,@9&]E<VXG="!Y970@97AI<W0N($-R96%T:6YG(&$@;F5W(&]N92XB
M"FUS9W-T<B`B(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<V.0HC+"!F=7IZ>0IM
M<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B1&5T(&5R(&EN9V5N(&UE;&1I;F=E<B!I(&1E;FYE('!O<W1B;VMS
M96XN(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,C0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D
M;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]M86EN=&5N86YC92YP:'`Z,CD*;7-G:60@(E1H92!-86EN=&5N86YC93HZ
M(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0HC+"!F=7IZ
M>0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I
M;F<N(@IM<V=S='(@(DUE;&1I;F=E;B!S;VT@:&%R(&)L:71T('-K<F5V970@
M:&%R(&)L:71T('-T96YG="X@079S;'5T=&5R+B(*"B,Z(&QI8B](;W)D92]0
M97)M<RYP:'`Z,38P(&QI8B](;W)D92]097)M<RYP:'`Z,3<Q(&QI8B](;W)D
M92]097)M<RYP:'`Z,3@R"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,3DT(&QI
M8B](;W)D92]097)M<RYP:'`Z,C`U(&QI8B](;W)D92]097)M<RYP:'`Z,C(S
M"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,C,U(&QI8B](;W)D92]097)M<RYP
M:'`Z,C<T"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C
M;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y
M;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S4*;7-G:60@(E1H92!B;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0Y"FUS9VED
M(")4:&4@8V%L96YD87(@9&%T82!I<R!I;G9A;&ED(@IM<V=S='(@(DMA;&5N
M9&5R9&%T82!E<B!U9WEL9&EG(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8V-`HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@
M240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A
M<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R(")$96X@
M9F]R97-P=7)T92!O<'!G879E;B!E<B!I:VME('-T;W1T970N(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HU-`HC+"!F=7IZ>0IM<V=I
M9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R
M(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B3W!P9OAR:6YG96X@7"(E<UPB(&)L
M92!L86=T('1I;"!A9')E<W-E8F]K96XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HQ,3<Q"B,L(&9U>GIY"FUS9VED("(B"B)4:&4@9&5T86-H960@
M4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE
M('-I9VYE9"!M97-S86=E+B(*;7-G<W1R(")%;B!O9F9E;G1L:6<@4$=0+6[X
M:VME;"!E<B!PY6MR979D(&9O<B#E('9E<FEF:7-E<F4@<VEG;F5R="!M96QD
M:6YG+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-C8*
M(RP@9G5Z>GD*;7-G:60@(B(*(E1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W
M87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O
M=6YD("(*(FEN('1H92!D871A8F%S92XB"FUS9W-T<B`B1&5N(&9O<F5S<'5R
M=&4@;W!P9V%V96X@97(@:6MK92!S=&]T=&5T+B(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-C<*(RP@9G5Z>GD*;7-G:60@(E1H92!D
M:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"XB"FUS9W-T<B`B
M1&5N(&9O<F5S<'5R=&4@;W!P9V%V96X@97(@:6MK92!S=&]T=&5T+B(*"B,Z
M(&QI8B](;W)D92]#<GEP="YP:'`Z,3(W"B,L(&9U>GIY"FUS9VED(")4:&4@
M96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN
M96-T:6]N+B(*;7-G<W1R(")3^'1T92!F;W(@<&5R<V]N;&EG(%!'4"!N^&MK
M96QP87(@:W)E=F5R(&5N('-I:VME<B!W96(M=&EL:V]B;&EN9RXB"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HW.`HC+"!F=7IZ
M>0IM<V=I9"`B5&AE(&5V96YT(&AA<R!B965N(&%D9&5D('1O('EO=7(@8V%L
M96YD87(N(@IM<V=S='(@(DAE;F1E;'-E;B!B;&4@;&%G="!T:6P@:2!D:6X@
M:V%L96YD97(N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ.#$@;&EB+TAO<F1E+G!H
M<#HU,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD
M(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4N<&AP.C$W-"!L:6(O2&]R9&4N<&AP.C0Y-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I
M;F=S+B(*;7-G<W1R("(B"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$V-`IM<V=I
M9"`B5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]$871A+G!H<#HR-C0*;7-G:60@(E1H
M92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,@IM<V=I9"`B5&AE(&9O
M;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X
M,C(@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R
M965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E
M<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E
M('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R
M:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC
M=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y
M;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA
M="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@
M86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D
M+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R
M>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R("(B"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,3`X-2!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(Q-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:&5L<"!F:6QE("5S(&1I9&XG="!S
M=&%R="!W:71H(#P_>&UL(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S
M+G!H<#HX.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT
M:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("))9&5N=&ET
M971E;B!<(B5S7"(@8FQE('-L971T970N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE
M9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z,3,V"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE
M($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z
M.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O341.+G!H
M<#HR,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N
M="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I
M<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE
M<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@V,0IM<V=I9"`B5&AE(&YA;64@
M=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(U.0IM<V=I
M9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R
M9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+U!R969S+G!H<#HR.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E
M(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M87AI;75M(&%L;&]W86)L92!S
M:7IE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]D96(N
M<&AP.C,U(&QI8B](;W)D92]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S<*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S4*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z,S4@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W)P;2YP:'`Z,S4*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W=E8F-P<"YP:'`Z-#`*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W-R8VAI9VAL:71E+G!H<#HS.0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M;7-E>&-E;"YP:'`Z,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R
M;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO
M="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS9VED
M(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N
M(&1E;&5T960N(@IM<V=S='(@(DED96YT:71E=&5N(%PB)7-<(B!B;&4@<VQE
M='1E="XB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S
M(&)E96X@<V%V960N(@IM<V=S='(@(DED96YT:71E=&5N(%PB)7-<(B!B;&4@
M;&%G<F5T+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@
M8F5E;B!R96UO=F5D+B(*;7-G<W1R("))9&5N=&ET971E;B!<(B5S7"(@8FQE
M(&QA9W)E="XB"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HR.#0*
M(RP@9G5Z>GD*;7-G:60@(E1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X
M:7-T+B(*;7-G<W1R(")$96X@<W!E<VEF:7-E<G1E(&9I;&5N(&5K<VES=&5R
M97(@:6MK92XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HQ,#@*;7-G:60@(E1H92!T87-K(&AA<R!B965N(&%D9&5D('1O('EO
M=7(@=&%S:VQI<W0N(@IM<V=S='(@(DAA;F1L:6YG96X@:&%R(&)L:71T(&QA
M9W0@=&EL(&1I;B!L:7-T92!O=F5R(&AA;F1L:6YG97(N(@H*(SH@;&EB+U9&
M4R]S<6PN<&AP.C$Q,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T
M<B`B1&5N('-P97-I9FES97)T92!F:6QE;B!E:W-I<W1E<F5R(&EK:V4N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T1A=&$N<&AP.C,Q,0IM<V=I9"`B5&AE('5P
M;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]$871A+V-S=BYP:'`Z,C4P(&QI
M8B](;W)D92]$871A+W1S=BYP:'`Z,3<W"B,L(&9U>GIY"FUS9VED(")4:&4@
M=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(E-I
M9VYA='5R96X@:W5N;F4@:6MK92!E<G-T871T97,N(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z.3,*;7-G:60@(E1H92!U<V5R
M)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N('=A<R!S=6-E<W-F=6QL>2!S=&]R
M960N(@IM<V=S='(@(D)R=6ME<F5N<R!L961I9R]O<'!T871T(&EN9F]R;6%S
M:F]N(&)L92!L86=R970N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C0R(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU,@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3`S(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ,#<*(RP@9G5Z>GD*;7-G:60@(E1H92!W96%T:&5R+F-O
M;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")$970@97(@:6YG
M96X@;65L9&EN9V5R(&D@9&5N;F4@<&]S=&)O:W-E;BXB"@HC.B!U=&EL+VEC
M;VY?8G)O=W-E<BYP:'`Z,C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E1H96UE<R!D:7)E8W1O<GD@)R5S)R!N;W0@9F]U;F0N(@IM<V=S='(@(E9E
M9&QE9V=E="!B;&4@:6MK92!F=6YN970N(@H*(SH@;&EB+TAO<F1E+U!R969S
M+U5)+G!H<#HQ.#(*(RP@9G5Z>GD*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I
M;VYS(&%V86EL86)L92XB"FUS9W-T<B`B1&5T(&5R(&EN9V5N(&UE;&1I;F=E
M<B!I(&1E;FYE('!O<W1B;VMS96XN(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N
M=&5N=',N<&AP.C,T,`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@87)E(&YO('!A
M<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(D1E
M="!E<B!I;F=E;B!A;'1E<FYA=&EV92!D96QE<B!S;VT@:V%N('9I<V5S(&EN
M;&EN92XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,Y.`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I
M;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[
M("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C$P-#@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@9&]E<VXG="!Y970@97AI<W0@82!H96QP(&9I;&4@9F]R("5S
M+B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C4U"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`G)7,G
M('1O('1H92!S>7-T96TN("5S+B(*;7-G<W1R(")$970@;W!P<W1O9"!E="!P
M<F]B;&5M('5N9&5R('-L971T:6YG96X@878@)7,N($UE;&1I;F<@9G)A('-E
M<G9E<F5N(@H*(SH@861M:6XO=7-E<BYP:'`Z-S,*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG("<E<R<@
M=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`B1&5T(&]P<'-T;V0@970@<')O
M8FQE;2!U;F1E<B!S;&5T=&EN9V5N(&%V("5S+B!-96QD:6YG(&9R82!S97)V
M97)E;B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A
M(&9O<B!U<V5R("<E<R<@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B(@HB
M1&5T(&]P<'-T;V0@970@<')O8FQE;2!V960@9FIE<FYI;F<@878@<&]S=&)O
M:W-E;BX@365L9&EN9R!F<F$@<V5R=F5R96XB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ,#,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M('!R;V)L96T@<F5M;W9I;F<@)R5S)R!F<F]M('1H92!S>7-T96TZ("(*;7-G
M<W1R(")$970@;W!P<W1O9"!E="!P<F]B;&5M('5N9&5R('-L971T:6YG96X@
M878@)7,N($UE;&1I;F<@9G)A('-E<G9E<F5N(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,34Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M('5P9&%T:6YG("<E<R<Z("5S(@IM<V=S='(@(D1E="!O<'!S
M=&]D(&5N(&9E:6P@=6YD97(@;W!P9&%T97)I;F<@878@:&5N9&5L<V5N.B`E
M<R(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HX.3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P
M;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O0G)O=W-E<BYP:'`Z.3`T"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H
M92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E9"!S
M:7IE("@E9"!B>71E<RDN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]"<F]W
M<V5R+G!H<#HY,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S
M(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O
M;FQY('!A<G1I86QL>2!U<&QO861E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S@*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S
M='(@(D1E="!O<'!S=&]D(&5N(&9E:6P@=6YD97(@9F]R<_AK('#E(.4@=FES
M92!D96YN92!M96QD:6YG<V1E;&5N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HT,B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C4Q"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(D1E="!O<'!S=&]D
M(&5N(&9E:6P@=F5D(&EM<&]R=&5R:6YG(&%V(&AE;F1E;'-E;CH@)7,N(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-S4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN
M9R!T:&4@979E;G0Z("5S+B(*;7-G<W1R(")$970@;W!P<W1O9"!E;B!F96EL
M('5N9&5R(&EM<&]R=&5R:6YG(&%V(&AE;F1E;'-E;CH@)7,N(@H*(SH@;&EB
M+TAO<F1E+T1A=&$O:6UC+G!H<#HS,@HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM
M<V=S='(@(D1E="!O<'!S=&]D(&5N(&9E:6P@=6YD97(@:6UP;W)T97)I;F<@
M878@:&5N9&5L<V5N.B`E<RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@=&%S:SH@)7,N(@IM<V=S='(@
M(D1E="!O<'!S=&]D(&5N(&9E:6P@=F5D(&EM<&]R=&5R:6YG(&%V(&AE;F1E
M;'-E;CH@)7,N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N.B`E
M<RXB"FUS9W-T<B`B(@HB1&5T(&]P<'-T;V0@96X@9F5I;"!V960@:6UP;W)T
M97)I;F<@878@8G)U:V5R96YS(&QE9&EG+V]P<'1A='0M:6YF;W)M87-J;VXZ
M("4B"B)S(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW.0HC+"!F=7IZ
M>0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U
M<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q=6ER
M960@9FEE;&0N(@IM<V=S='(@(D1E="!O<'!S=&]D(&5N(&9E:6P@=6YD97(@
M;W!P9&%T97)I;F<@878@:&5N9&5L<V5N.B`E<R(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HQ,#DU('!O+W1R86YS;&%T:6]N+G!H<#HQ,3`Q('!O+W1R86YS
M;&%T:6]N+G!H<#HQ,C(V"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,C,R"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!O<&5N
M:6YG('1H92!F:6QE("5S+B!4<GD@<G5N;FEN9R!T<F%N<VQA=&EO;BYP:'`@
M=VET:"!T:&4@(@HB9FQA9R`M9"!T;R!S964@86YY(&5R<F]R(&UE<W-A9V5S
M(&9R;VT@=&AE('AM;"!P87)S97(N(@IM<V=S='(@(B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-C,*(RP@9G5Z>GD*;7-G:60@(B(*
M(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@
M861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA
M=&5R+B(*;7-G<W1R(")$970@;W!P<W1O9"!E;B!F96EL('5N9&5R(&]P<&1A
M=&5R:6YG(&%V(&AE;F1E;'-E;CH@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C8U"B,L(&9U>GIY"FUS9VED("(B"B)4:&5R92!W
M87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE
M87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B1&5T(&]P<'-T;V0@96X@
M9F5I;"!U;F1E<B!O<'!D871E<FEN9R!A=B!H96YD96QS96XZ("5S(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W,`HC+"!F=7IZ>0IM
M<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T
M<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T
M<B`B1&5T(&]P<'-T;V0@96X@9F5I;"!U;F1E<B!O<'!D871E<FEN9R!A=B!H
M96YD96QS96XZ("5S(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C$U,PHC+"!F=7IZ>0IM<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S
M(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B1&5N;F4@
M=&IE;F5R96X@<W3X='1E<B!I:VME(&1E;&EN9R!A=B!M87!P97(N(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z.#(*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z.38*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3$R"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C(P,`IM<V=I9"`B5&AI<R!A
M8W1I;VX@:7,@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B1&5N(&9O<F5S<'5R
M=&4@;W!P9V%V96X@97(@:6MK92!S=&]T=&5T+B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C$Q.`HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HS-3D*;7-G:60@(E1H:7,@86-T:6]N
M(&ES(&YO="!Y970@:6UP;&5M96YT960N(@IM<V=S='(@(D1E;B!F;W)E<W!U
M<G1E(&]P<&=A=F5N(&5R(&EK:V4@:6UP;&5M96YT97)T+B(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C4Q"B,L(&9U>GIY"FUS9VED(")4
M:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E
M+B(*;7-G<W1R("(E<R!S97(@:6MK92!U="!S;VT@96X@9WEL9&EG('!O<W1B
M;VMS+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C4U"B,L
M(&9U>GIY"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A
M;&ED('II<"!F:6QE+B(*;7-G<W1R("(E<R!S97(@:6MK92!U="!S;VT@96X@
M9WEL9&EG('!O<W1B;VMS+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3,P
M"B,L(&9U>GIY"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V
M86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`B)7,@<V5R(&EK:V4@=70@<V]M
M(&5N(&=Y;&1I9R!P;W-T8F]K<RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C$X-PIM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H
M:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@
M2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4S-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E
M;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P
M.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@
M05!)(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?
M<VUT<"YP:'`Z.#(*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE
M($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@
M270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE
M($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HY-S,@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-3(@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$P.#$*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$Q,3`@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q-S0@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$R-#@*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R.#(@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$S.34@;&EB+TAO<F1E+T9O<FTN<&AP.C$U-#<*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$X,C<@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-#(@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$Y.#D*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(P,3,@;&EB+TAO<F1E+T9O<FTN<&AP.C(P-C(@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(Q,S,*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R,#4@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(S.3,@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,S<*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(V-#D@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,3<@
M;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,C(*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C,V.3(@;&EB+TAO<F1E+T9O<FTN<&AP.C,W,#`*(RP@9G5Z>GD*;7-G:60@
M(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@(B5S(&AA<B!A=G-L
MY71T+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,#8P"FUS9VED(")4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-#`Q"FUS9VED(")4:&ES(&9I96QD
M(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`X.0IM<V=I9"`B5&AI
M<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,3@*;7-G:60@(E1H:7,@
M9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T
M(&]F(&EN=&5G97)S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HY.#0*(RP@9G5Z>GD*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A
M;&ED(&YU;6)E<BXB"FUS9W-T<B`B1&5T=&4@;>4@=N9R92!E="!T86QL+B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#(U"FUS9VED("(B"B)4:&ES(&9I
M96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@
M9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HU-C$*;7-G:60@(E1H:7,@9F]R;2!H
M87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AI<R!I<R`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B
M($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I
M;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T
M:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H
M(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HV,#<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA
M<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3(X"FUS9VED(")4:&ES
M(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T<B`B1&5T=&4@
M=&%L;&5T(&WE(';F<F4@;6EN<W0@,2XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z,3(X-0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!S8W)I<'0@;75S="!B92!R
M=6X@9G)O;2!T:&4@8V]M;6%N9"!L:6YE+B(*;7-G<W1R(")$971T92!V:6YD
M=65T(&WE(&)L:2#E<&YE="!F<F$@)TYY(&UE;&1I;F<G('9I;F1U970B"@HC
M.B!L:6(O2&]R9&4O0V]M<')E<W,O9WII<"YP:'`Z-#@*(RP@9G5Z>GD*;7-G
M:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP
M(&9I;&5S+B(*;7-G<W1R(")$96YN92!T:F5N97)E;B!S=/AT=&5R(&EK:V4@
M9&5L:6YG(&%V(&UA<'!E<BXB"@HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP
M.C$T-PIM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A
M=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$R
M-@IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R
M(")$971T92!MY2!VYG)E(&5T('1A;&PN(@H*(SH@<V5R=FEC97,O:6UA9V5S
M+V-O;&]R<&EC:V5R+G!H<#HS-0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!W:6YD
M;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G
M<W1R(")$971T92!V:6YD=65T(&WE(&)L:2#E<&YE="!F<F$@)TYY(&UE;&1I
M;F<G('9I;F1U970B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S<Q"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR,C4*;7-G:60@(E1I8VME=',B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,3$*(RP@9G5Z>GD*;7-G:60@(E1I
M;64B"FUS9W-T<B`B5&ET=&5L(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,Q,0IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=&EM92YP:'`Z,3<*(RP@9G5Z>GD*;7-G:60@(E1I;64@9F]R
M;6%T(@IM<V=S='(@(D9O<FUA="!PY2!N879N(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(U,C(*(RP@9G5Z>GD*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM
M<V=S='(@(D9I;'1E<FEN;G-T:6QL:6YG97(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C,P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C(*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4:6UO<BU,
M97-T92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C(S,B!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B5&ET
M;&4B"FUS9W-T<B`B5&ET=&5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HX,`IM<V=I9"`B5&\B"FUS9W-T<B`B5&EL(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8R.0HC+"!F=7IZ>0IM<V=I9"`B(@HB
M5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R
M;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN
M9RXB"FUS9W-T<B`B(@HB1F]R(.4@=F5L9V4@9FQE<F4L(&AO;&0@;F5D92!#
M;VYT<F]L("A00RD@96QL97(@0V]M;6%N9"`H36%C*2!M96YS(&1U(&ML:6MK
M97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4Q"B,L(&9U
M>GIY"FUS9VED(")4;V1A>2(*;7-G<W1R(")-96QD:6YG<W1E:W-T(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I
M9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(R,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*(RP@9G5Z>GD*
M;7-G:60@(E1O9V\B"FUS9W-T<B`B5&EL(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(R-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&]K96QA=2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4S
M"B,L(&9U>GIY"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R(").>2!M96QD:6YG
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R.2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q,0HC+"!F=7IZ>0IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B5&EL(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<W
M"B,L(&9U>GIY"FUS9VED(")4;W`B"FUS9W-T<B`B5&EL(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I9"`B5&]P
M(&9R86UE("A?=&]P*2(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z-C4W"B,L(&9U>GIY"FUS9VED(")4<F%N<VQA=&5D(@IM<V=S='(@(E5B
M97-V87)T(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S"B,L(&9U>GIY
M"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`B3W)G86YI<V5R:6YG(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M,@IM<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3<W.`IM<V=I9"`B5')U92!O<B!F86QS92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C(X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,C<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=6YI
M<VEA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S$@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,3(*(RP@9G5Z>GD*;7-G:60@(E1U<FME>2(*;7-G
M<W1R(")N^&MK96PB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I
M9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(R-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,0HC+"!F=7IZ
M>0IM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(D]B<V5R=F5R(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.0IM
M<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S,@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(S,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*
M;7-G:60@(E1U=F%L=2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0TQ)+G!H
M<#HR-C(*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(W"FUS9VED(")5+E8N
M(&EN9&5X.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HR-3(@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@
M(E523"(*;7-G<W1R(")54DPB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-38Q"FUS9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV
M97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PHC+"!F=7IZ>0IM<V=I9"`B
M55),.B(*;7-G<W1R(")54DPB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C,W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$S"B,L(&9U>GIY"FUS9VED(")59V%N9&$B
M"FUS9W-T<B`B2V%L96YD97(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C,V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$S"B,L(&9U>GIY"FUS9VED(")5:W)A:6YE
M(@IM<V=S='(@(D=J96YO<'!R971T(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS
M-C`*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-13'-E<G9E<F5N
M+B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,3`P"FUS9VED(")5
M;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N
M:6YG('5P+B(*;7-G<W1R("(B"@HC.B!L:6(O5D93+V9T<"YP:'`Z,S0V"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E
M<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EK
M:V4@:V]B;&4@=&EL(%-13'-E<G9E<F5N+B(*"B,Z(&QI8B]61E,O9FEL92YP
M:'`Z,S,P(&QI8B]61E,O;75S<6PN<&AP.C4P,@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!6
M1E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-1
M3'-E<G9E<F5N+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW,#0*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N(@IM
M<V=S='(@(DMA;B!I:VME(&MO8FQE('1I;"!344QS97)V97)E;BXB"@HC.B!L
M:6(O2&]R9&4O075T:"]S<6PN<&AP.C,W-0IM<V=I9"`B56YA8FQE('1O(&-O
M;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@
M=&EL(%-13'-E<G9E<F5N+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW.#@*(RP@
M9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G
M<W1R(")+86X@:6MK92!K;V)L92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB
M+U9&4R]F:6QE+G!H<#HQ-S`@;&EB+U9&4R]F:6QE+G!H<#HQ-S4@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z,3DW"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(P
M,B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR,3`*(RP@9G5Z>GD*;7-G:60@(E5N
M86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R(")+86X@:6MK92!K;V)L
M92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,R,`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!6
M1E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@
M=&EL(%-13'-E<G9E<F5N+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,CDU(&QI
M8B]61E,O;75S<6PN<&AP.C(W,R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR-S`*
M(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R
M>2XB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-13'-E<G9E<F5N+B(*
M"B,Z(&QI8B]61E,O;75S<6PN<&AP.C$R-@HC+"!F=7IZ>0IM<V=I9"`B56YA
M8FQE('1O(&-R96%T92!61E,@9FEL92XB"FUS9W-T<B`B2V%N(&EK:V4@:V]B
M;&4@=&EL(%-13'-E<G9E<F5N+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C$R
M"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F
M:6QE+B(*;7-G<W1R(")+86X@:6MK92!K;V)L92!T:6P@4U%,<V5R=F5R96XN
M(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+W1A<BYP:'`Z-SD@;&EB+TAO<F1E
M+T-O;7!R97-S+V=Z:7`N<&AP.C@R"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@
M=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R(")+;&%R=&4@:6MK92#E(&AE
M;G1E(&EN9F]R;6%S:F]N(&]M(&MV;W1E(@H*(SH@;&EB+U9&4R]F='`N<&AP
M.C(T.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G
M<W1R(")+86X@:6MK92!K;V)L92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB
M+U9&4R]F:6QE+G!H<#HR-S`@;&EB+U9&4R]S<6PN<&AP.C,R,R!L:6(O5D93
M+VUU<W%L+G!H<#HS,S4*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S8R"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E("5S
M+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(*;7-G<W1R(")+86X@:6MK
M92!K;V)L92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HW.2!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4Y"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E("<E<R<Z("5S+B(*;7-G
M<W1R(")+86X@:6MK92!K;V)L92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB
M+U9&4R]S<6Q?9FEL92YP:'`Z,S<X(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,X
M,@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T
M;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R(")+86X@:6MK92!K;V)L92!T:6P@
M4U%,<V5R=F5R96XN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR-S8@;&EB+U9&
M4R]M=7-Q;"YP:'`Z,S0X(&QI8B]61E,O;75S<6PN<&AP.C,V,0HC.B!L:6(O
M5D93+VUU<W%L+G!H<#HS-CD@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S<T"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN
M(@IM<V=S='(@(DMA;B!I:VME(&MO8FQE('1I;"!344QS97)V97)E;BXB"@HC
M.B!L:6(O5D93+W-Q;"YP:'`Z,S0X(&QI8B]61E,O<W%L+G!H<#HS-C`*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(DMA;B!I:VME(&MO8FQE('1I;"!3
M44QS97)V97)E;BXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,3<Y"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE
M(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-13'-E<G9E
M<F5N+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C0R(&QI8B]61E,O<W%L+G!H
M<#HR,3,@;&EB+U9&4R]M=7-Q;"YP:'`Z,3<S"B,Z(&QI8B]61E,O;75S<6PN
M<&AP.C$X-B!L:6(O5D93+VUU<W%L+G!H<#HQ.3,@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z-#$R"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C0R,`HC+"!F=7IZ
M>0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS9W-T<B`B
M2V%N(&EK:V4@:V]B;&4@=&EL(%-13'-E<G9E<F5N+B(*"B,Z(&QI8B]61E,O
M<W%L+G!H<#HS,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B2V%N
M(&EK:V4@:V]B;&4@=&EL(%-13'-E<G9E<F5N+B(*"B,Z(&QI8B]61E,O9G1P
M+G!H<#HW-3(*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@
M8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(DMA;B!I:VME(')E9VES=')E
M<F4@:6YS=&EL;&EN9V5N92!I(/AK=&5N+B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-C(W"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@97AT
M<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM<V=S='(@(E-E='0@:6YN('-E
M<G1I9FEK870@:&5R(@H*(SH@;&EB+TYE="])35-0+G!H<#HT-C`@;&EB+TYE
M="])35-0+T%U=&@N<&AP.C$Q.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S
M='(@(B5S(&AA<B!S=F%R="!PY2!I;G9I=&%S:F]N96X@=&EL("5S+B(*"B,Z
M(&QI8B]61E,O9FEL92YP:'`Z,3,Y(&QI8B]61E,O9FEL92YP:'`Z,30T(&QI
M8B]61E,O<W%L7V9I;&4N<&AP.C$V-0HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HQ-S`*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE
M+B(*;7-G<W1R(")+86X@:6MK92!K;V)L92!T:6P@4U%,<V5R=F5R96XN(@H*
M(SH@;&EB+U9&4R]F='`N<&AP.C<Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(DMA;B!I:VME(&MO8FQE('1I;"!344QS97)V97)E;BXB"@HC.B!L:6(O5D93
M+V9I;&4N<&AP.C(Q.2!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ,C<@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z,3,P"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B2V%N(&EK:V4@
M:V]B;&4@=&EL(%-13'-E<G9E<F5N+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z
M-S,@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S,*(RP@9G5Z>GD*;7-G:60@(E5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R(")+86X@:6MK92!K;V)L
M92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W1G>BYP:'`Z-#<*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O
M;7!R97-S960@87)C:&EV92XB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL
M(%-13'-E<G9E<F5N+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-C(R"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O
M<GDN(@IM<V=S='(@(DMA;B!I:VME(&MO8FQE('1I;"!344QS97)V97)E;BXB
M"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$P.34*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@
M9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*"B,Z(&QI8B]61E,O
M<W%L7V9I;&4N<&AP.C,Q-@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E
M;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")+86X@:6MK92!K;V)L92!T
M:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C(U-0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@
M9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-1
M3'-E<G9E<F5N+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HR.38*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@
M7"(E<UPB+B(*;7-G<W1R(")+86X@:6MK92!K;V)L92!T:6P@4U%,<V5R=F5R
M96XN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HU-C,@;&EB+U9&4R]M=7-Q;"YP
M:'`Z,C0Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R(")+86X@:6MK92!K;V)L
M92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C(T.2!L
M:6(O5D93+VUU<W%L+G!H<#HR,C(@;&EB+U9&4R]M=7-Q;"YP:'`Z-#@U"B,Z
M(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,P-2!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HS,C<*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I
M;&4N(@IM<V=S='(@(DMA;B!I:VME(&MO8FQE('1I;"!344QS97)V97)E;BXB
M"@HC.B!L:6(O5D93+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,0HC+"!F=7IZ
M>0IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@(DMA
M;B!I:VME(&MO8FQE('1I;"!344QS97)V97)E;BXB"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O;7-W;W)D+G!H<#HV,@IM<V=I9"`B56YA8FQE('1O('1R
M86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`B2V%N(&EK:V4@
M;W9E<G-E='1E(&1E='1E(%=O<F0M9&]K=6UE;G1E="(*"B,Z(&QI8B]61E,O
M9G1P+G!H<#HQ,C<@;&EB+U9&4R]F='`N<&AP.C$S,`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B2VQA<G1E(&EK:V4@Y2!H96YT92!I;F9O<FUA<VIO;B!O
M;2!K=F]T92(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3(P"B,L(&9U>GIY"FUS
M9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I
M+B(*;7-G<W1R(")+;&%R=&4@:6MK92#E(&AE;G1E(&EN9F]R;6%S:F]N(&]M
M(&MV;W1E(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR,C,@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z,3,U(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$T,`HC+"!F=7IZ
M>0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S
M='(@(DML87)T92!I:VME(.4@:&5N=&4@:6YF;W)M87-J;VX@;VT@:W9O=&4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M"B,L(&9U>GIY"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`B1VIE;F]P<')E
M='0B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O
M($-H86YG97,B"FUS9W-T<B`B06YG<F4@96YD<FEN9V5R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PHC+"!F=7IZ>0IM
M<V=I9"`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B1VIE;F]P
M<'1A('-E<VIO;B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HR,S`@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y.0IM<V=I
M9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T
M:6]N.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C(R-B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S4P
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#<@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y,PIM<V=I9"`B56YE>'!E8W1E
M9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4X"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8T"B,L(&9U>GIY
M"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(D4M<&]S="(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C,X-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;FAA;F1L960@8V]M<&]N96YT(&]F('1Y<&4Z("5S(@IM<V=S
M='(@(E5HY6YD=&5R="!K;VUP;VYE;G0@878@='EP96XZ("5S(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HU-PIM<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S."!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<U"FUS9VED(")5;FET960@2VEN9V1O;2(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0P(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,S8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$T"FUS
M9VED(")5;FET960@4W1A=&5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S
M-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5N:71E
M9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C4@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HV.0IM<V=I9"`B56YI=',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z-#$U(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C0Q-@HC+"!F=7IZ>0IM<V=I9"`B56YK;F]W;B(*;7-G<W1R(")5:VIE;G0@
M9&%T;R(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W
M"FUS9VED(")5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM
M<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`X"FUS9VED(")5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)
M1"DN(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ-#@R"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;FMN;W=N(&-O;6UA;F0Z("5S
M(@IM<V=S='(@(DQA<W0@;F5D(&UA<'!E;BAE*2(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"B,L(&9U>GIY"FUS9VED(")5;FMN
M;W=N('5S97)N86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R(")696YN;&ES="!S
M:W)I=B!I;FX@8G)U:V5R;F%V;B!O9R!P87-S;W)D(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"B,L(&9U
M>GIY"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(*;7-G<W1R
M(")3;&5T="!NY7;F<F5N9&4@;OAK;&5R(@H*(SH@;&EB+TAO<F1E+TED96YT
M:71Y+G!H<#HR.3@*;7-G:60@(E5N;F%M960B"FUS9W-T<B`B571E;B!N879N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU
M.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S
M<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R
M:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T
M92!A="!M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L
M;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@R"B,L(&9U>GIY"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R
M(")3971T(&EN;B!S97)T:69I:V%T(&AE<B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-S$P(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z.34R
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z.34X"B,L(&9U>GIY"FUS
M9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`B57-U<'!O<G1E
M<G0@:6YN:&]L9',M='EP92XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C4W
M"B,L(&9U>GIY"FUS9VED(")5;G1R86YS;&%T960B"FUS9W-T<B`B56)E<W9A
M<G0B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#8@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HQ.3$*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI
M;F,Z,S8*(RP@9G5Z>GD*;7-G:60@(E5P9&%T92(*;7-G<W1R(")3:7-T92!O
M<'!D871E<FEN9SHB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C,Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B
M"FUS9W-T<B`B4VES=&4@;W!P9&%T97)I;F<Z(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C0X"FUS9VED(")5<&1A=&4@<F5S
M<&]N9&5N="!S=&%T=7,B"FUS9W-T<B`B3W!P9&%T97(@<W1A='5S('#E(&%V
M<V5N9&5R92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-#,*(RP@9G5Z>GD*;7-G:60@(E5P9&%T92!U<V5R(@IM<V=S='(@(E-I<W1E
M(&]P<&1A=&5R:6YG.B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3,W(&%D;6EN
M+W!E<FUS+V5D:70N<&AP.C(Q-R!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z
M,C,P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D("<E<R<N
M(@IM<V=S='(@(E)E9&EG97(@)R5S)R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HQ,#@P('!O+W1R86YS;&%T:6]N+G!H<#HQ,C$Q"B,L('!H<"UF;W)M870*
M;7-G:60@(E5P9&%T:6YG("5S(&AE;'`@9FEL92!F;W(@)7,N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@Q"FUS9VED(")5<&=R
M861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3<R(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ.#(*;7-G:60@(E5P;&]A9"(*;7-G<W1R("),87-T(&]P<"(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*;7-G:60@(E5P;&]A9&5D(&%L
M;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C(P"FUS9VED(")5<'!E<B!L871I;B!L971T97)S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q-`IM<V=I9"`B57)U9W5A>2(*;7-G<W1R("(B"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,S4@<&\O=')A;G-L871I;VXN<&AP.CDR('!O
M+W1R86YS;&%T:6]N+G!H<#HY,PHC+"!F=7IZ>0IM<V=I9"`B57-A9V4Z(@IM
M<V=S='(@(D)R=6ME<FYA=FXZ(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`Z-#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R(")3;&5T="!NY7;F<F5N9&4@;OAK
M;&5R(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U.`IM
M<V=I9"`B57-E(%-33"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3(S"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F
M97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O4F5G:7-T<GDN<&AP.C8U,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R
M("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,C`T"B,L(&9U>GIY"FUS9VED(")5<V5R($%D;6EN
M:7-T<F%T:6]N(@IM<V=S='(@(B5S(%!'4"!A9&UI;FES=')A<VIO;B(*"B,Z
M(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,C4Q"FUS9VED(")5<V5R($]P=&EO
M;G,B"FUS9W-T<B`B3&%G<F4@5F%L9R(*"B,Z('-I9VYU<"YP:'`Z-C0*(RP@
M9G5Z>GD*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(DQA9W)E
M(%9A;&<B"@HC.B!S:6=N=7`N<&AP.C$Y"B,L(&9U>GIY"FUS9VED(")5<V5R
M(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E
M+B(*;7-G<W1R(")&:6QT97)S=/AT=&4@97(@879S;.5T="!I(&1E='1E('-Y
M<W1E;65T+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$W,B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C(U-`HC+"!F=7IZ>0IM<V=I9"`B57-E<B!P97)M
M:7-S:6]N<R(*;7-G<W1R("),86=R92!686QG(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W,PHC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34V(&QI8B].970O4TU3+W9O9&%F;VYE
M:71A;'E?<VUT<"YP:'`Z.3<*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR,#(@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S,*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHV-2!T96UP;&%T97,O861M:6XO
M=7-E<B]A<'!R;W9E+FEN8SHQ,0IM<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B
M0G)U:V5R;F%V;B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,3,Q
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92`G)7,G(&%L
M<F5A9'D@97AI<W1S+B(*;7-G<W1R(")-87!P96X@7"(E<UPB(&9I;FYE<R!A
M;&QE<F5D92(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PIM
M<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(D)R=6ME<FYA=FXZ(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B57-E
M<FYA;64Z("(*;7-G<W1R(")"<G5K97)N879N.B(*"B,Z(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,C(W"B,L(&9U>GIY"FUS9VED(")5<V5R<R(*;7-G<W1R
M(")"<G5K97)N879N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI
M;F,Z-`IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M-0HC+"!F=7IZ>0IM<V=I9"`B57IB96MI<W1A;B(*;7-G<W1R(")$871O(@H*
M(SH@;&EB+U9&4R]F:6QE+G!H<#HQ,#D@;&EB+U9&4R]F:6QE+G!H<#HR,#(*
M(RP@9G5Z>GD*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N
M(@IM<V=S='(@(D1E;B!S<&5S:69I<V5R=&4@9FEL96X@96MS:7-T97)E<B!I
M:VME+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#,*(RP@9G5Z
M>GD*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(DQO:V%S:F]N(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C@V,0IM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O
M=6YD(&EN8VQU9&4Z("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C8V,@IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8R,2!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V,PIM<V=I9"`B5F%L=64@:6X@;6EN
M=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(R,C@@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-3`@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(R.3@*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,3<*(RP@9G5Z
M>GD*;7-G:60@(E9A;'5E<R(*;7-G<W1R("));F=E;B!M96QD:6YG97(B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`Y,R!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C$W,`IM<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#D@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(T,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3@*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(P-PHC+"!F=7IZ>0IM<V=I9"`B5F%R:6%B;&4B
M"FUS9W-T<B`B5&ET=&5L(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C(X"FUS9VED(")6
M97)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E
M96X@=&%M<&5R960@=VET:"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HW,C0*(RP@9G5Z>GD*;7-G:60@(E9E<G-I;VXB"FUS
M9W-T<B`B4&5R<V]N;&EG(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(P,`HC+"!F=7IZ>0IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@
M(E!E<G-O;FQI9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#,*(RP@9G5Z>GD*;7-G:60@(E9E<G1I8V%L(&%L
M:6=N(@IM<V=S='(@(D9E=&-H;6%I;#H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-`HC+"!F=7IZ>0IM<V=I9"`B5F5R
M=&EC86P@<&%D9&EN9R(*;7-G<W1R(")&971C:&UA:6PZ("(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*(RP@9G5Z>GD*
M;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R(")&971C:&UA:6PZ("(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-S<*(RP@9G5Z>GD*;7-G:60@
M(E9E<GD@2&EG:"(*;7-G<W1R(")(^'DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C0X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"B,L(&9U>GIY"FUS9VED(")6
M:65T($YA;2(*;7-G<W1R(").879N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.3`*;7-G:60@(E9I971N86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.CDY-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(E9I<R`E<R(*"B,Z(&QI8B]"
M;&]C:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B
M('!A9V4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N
M<&AP.C@T-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E
M<R(*;7-G<W1R(")6:7,@)7,B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HW.0IM<V=I9"`B5FEE=R!E=F5N="(*;7-G<W1R(")6
M:7,@:&5N9&5L<V4B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HQ,#D*;7-G:60@(E9I97<@=&%S:R(*;7-G<W1R(")6:7,@:&%N
M9&QI;F=E<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#8@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3<*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3<*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`W"FUS9VED(")6:7-I
M8FEL:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,C$*;7-G:60@(E9I<VEB:6QI='DZ("(*;7-G<W1R("(B"@HC.B!L
M:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@Q"FUS9VED(")6
M;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,SD*;7-G:60@
M(E=!4DXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-2
M25!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR-3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(T-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(E=A
M;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].;W1I
M9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,0IM<V=I9"`B5V%R;FEN
M9R(*;7-G<W1R(")!9'9A<G-E;"(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ
M-#4@<&\O=')A;G-L871I;VXN<&AP.C8X,2!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-S$Q"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW,C4@<&\O=')A;G-L871I;VXN
M<&AP.C$P-#@@<&\O=')A;G-L871I;VXN<&AP.C$P-3<*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C$P-C4@<&\O=')A;G-L871I;VXN<&AP.C$P-S4@<&\O=')A
M;G-L871I;VXN<&AP.C$P.#4*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P.34@
M<&\O=')A;G-L871I;VXN<&AP.C$Q,#$@<&\O=')A;G-L871I;VXN<&AP.C$R
M,38*(SH@<&\O=')A;G-L871I;VXN<&AP.C$R,C8@<&\O=')A;G-L871I;VXN
M<&AP.C$R,S(@<&\O=')A;G-L871I;VXN<&AP.C$R-3(*(RP@9G5Z>GD*;7-G
M:60@(E=A<FYI;F<Z("(*;7-G<W1R(")!9'9A<G-E;"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-0IM
M<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`U"FUS9VED(")796%T:&5R(&1A=&$@
M<')O=FED960@8GDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C@X-PIM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,SDP"B,L(&9U>GIY"FUS9VED(")7
M96(@4VET92(*;7-G<W1R(")796)S:61E(&%D<F5S<V4B"@HC.B!L:6(O2&]R
M9&4O36%I;G1E;F%N8V4N<&AP.C,W"FUS9VED(")7965K;'DB"FUS9W-T<B`B
M56ME;G1L:6<B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`HC
M+"!F=7IZ>0IM<V=I9"`B5V5L8V]M92(*;7-G<W1R(")696QK;VUM96XB"@HC
M.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T
M;R`E<R(*;7-G<W1R(")696QK;VUM96X@=&EL("5S(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN
M8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM<V=S='(@
M(E9E;&MO;6UE;BP@)7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM
M<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y
M+3$U*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R-PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@
M9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B5FES;FEN9R!E;&QE<B!P
M;W-T8F]K<R!S;VT@<VMA;"!V:7-E<R!E='1E<B!I;FYL;V=G:6YG.B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")7:&%T(&ES
M('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR-`IM<V=I9"`B5VAA="!I<R!T:&4@
M<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,Q"FUS9VED(")7:&EC:"!P;'5G:6YS
M('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#0*(RP@9G5Z>GD*;7-G:60@(E=I9'1H(@IM<V=S='(@(E/X:R(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3$P"FUS9VED(")7:61T:"!I;B!#
M4U,@=6YI=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N
M=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q,`HC+"!F=7IZ>0IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R(")3^&LB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M-0HC+"!F=7IZ>0IM<V=I9"`B5VED=&@Z(@IM<V=S='(@(E/X:R(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.3`*;7-G:60@(E=I:VDB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,W,@HC+"!F
M=7IZ>0IM<V=I9"`B5VEN9"(*;7-G<W1R(")3^&LB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S<S"B,L(&9U>GIY"FUS9VED(")7:6YD($5A
M<FQY(@IM<V=S='(@(D%V<VSE='0Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z-S@*;7-G:60@(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-30*(RP@9G5Z>GD*;7-G:60@(E=I
M;F0Z(@IM<V=S='(@(E/X:R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,#4*(RP@9G5Z>GD*;7-G:60@(E=I;F0Z("(*;7-G<W1R(")!=G-L
MY71T.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*(RP@9G5Z>GD*
M;7-G:60@(E=I<V1O;2(*;7-G<W1R(")3^&LB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3<W"B,L(&9U>GIY"FUS9VED(")7:7-H;&ES=',B"FUS
M9W-T<B`B0F5T<F]D9&4@861R97-S97(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-C4*(RP@9G5Z>GD*;7-G:60@(E=O<FLB"FUS9W-T<B`B96QL97(B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-R!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-PIM<V=I9"`B5V]R:R!!
M9&1R97-S(@IM<V=S='(@(D9I<FUA861R97-S92(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DU"FUS9VED(")7;W)K(%!H;VYE(@IM
M<V=S='(@(D9I<FUA=&5L969O;B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ
M,34W"B,L('!H<"UF;W)M870*;7-G:60@(E=R:71I;F<@=7!D871E9"!H96QP
M(&9I;&4@=&\@)7,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR,S0*;7-G:60@(E@M4F5F(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-C$W"FUS9VED(")8-3`Y=C,@0F%S:6,@
M0V]N<W1R86EN=',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HV,38*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,3@*
M;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,3D*;7-G:60@
M(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`V"FUS9VED(")8-3`Y=C,@
M97AT96YS:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU
M,`IM<V=I9"`B65DB"FUS9W-T<B`BY>4B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,S@V(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,C<*(RP@9G5Z>GD*;7-G:60@(EE965DB"FUS9W-T<B`B
MY>4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`P
M,@IM<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M36%I;G1E;F%N8V4N<&AP.C,U"FUS9VED(")996%R;'DB"FUS9W-T<B`BY7)L
M:6<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4R(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR-#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$X"B,L(&9U>GIY"FUS9VED(")996UE;B(*;7-G<W1R("),97-T(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@X.`IM<V=I
M9"`B665S(@IM<V=S='(@(DIA(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E
M+V%G<F5E;65N=%]B;W1T;VTN:6YC.C8*;7-G:60@(EEE<RP@22!!9W)E92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C4R"FUS9VED(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T
M:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+G!H<#HQ,S(V"FUS9VED(")9;W4@87)E
M(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M261E;G1I='DN<&AP.C,P-`IM<V=I9"`B66]U(&-A;B!N;W0@:&%V92!T:&4@
M)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#,Y(&QI8B](;W)D92]&;W)M+G!H
M<#HQ.34Y"B,L(&9U>GIY"FUS9VED(")9;W4@9&ED(&YO="!E;G1E<B!A('9A
M;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S='(@(E9E;FYL:6=S="!R971T('1V
M971Y9&EG92!E;&QE<B!U9WEL9&EG92!A9')E<W-E<BXB"@HC.B!L:6(O2&]R
M9&4O1&%T82YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D
M:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T
M;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY-#0*(RP@9G5Z>GD*;7-G:60@
M(EEO=2!H879E(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`B1&EN92!V86QG
M(&AA<B!B;&ET="!O<'!D871E<G0B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3(U,PIM<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL
M<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K
M)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3@P"B,L(&9U>GIY
M"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G
M<W1R(")696YN;&EG<W0@<VMR:78@:6YN(&1E="!N>64@;F%V;F5T.B(*"B,Z
M(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,S@*(RP@9G5Z>GD*;7-G:60@
M(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E
M(%-I9VYU<',N(@IM<V=S='(@(DMU;FYE(&EK:V4@;&%G92!61E,M8F%C:V5N
M9#H@)7,B"@HC.B!L:6(O2&]R9&4N<&AP.C0T-PHC+"!F=7IZ>0IM<V=I9"`B
M66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(DMU
M;FYE(&EK:V4@;&%G92!61E,M8F%C:V5N9#H@)7,B"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I
M8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE
M;2!R97!O<G0N(@IM<V=S='(@(D1U(&WE(&)E<VMR:79E('!R;V)L96UE="!F
M^'(@9'4@:V%N('-E;F1E(&5N('!R;V)L96UR87!P;W)T+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*(RP@9G5Z>GD*
M;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK
M('!O:6YT<R!T;R(*;7-G<W1R(")$=2!MY2!H82!M:6YS="#I;B!M;W1T86ME
M<BXB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`HC+"!F=7IZ
M>0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE
M=&5D+B(*;7-G<W1R(")$=2!MY2!V96QG92!E;B!I9&5N=&ET970@<V]M('-K
M86P@<VQE='1E<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*(RP@9G5Z>GD*
M;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O
M=70N(@IM<V=S='(@(D1U(&WE('-P97-I9FES97)E(&5N(&UO='1A:V5R+B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU
M<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B1'4@
M;>4@<W!E<VEF:7-E<F4@96X@;6]T=&%K97(N(@H*(SH@861M:6XO=7-E<BYP
M:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"B,L(&9U
M>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A
M9&0N(@IM<V=S='(@(D1U(&WE(&;X<G-T('-P97-I9FES97)E(&9I;&5N('-O
M;2!S:V%L(&QE9V=E<R!V960N(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"B,L
M(&9U>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T
M;R!U<&1A=&4N(@IM<V=S='(@(D1U(&WE(&;X<G-T('-P97-I9FES97)E(&9I
M;&5N('-O;2!S:V%L(&QE9V=E<R!V960N(@H*(SH@;&EB+TAO<F1E+T-O;7!R
M97-S+WII<"YP:'`Z,30T"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S<&5C
M:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM<V=S='(@(D1U(&WE('-P
M97-I9FES97)E(&5N(&UO='1A:V5R+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]#
M871E9V]R>4UA;F%G97(N<&AP.C<S"B,L(&9U>GIY"FUS9VED(")9;W4@;75S
M="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(D1U(&WE('-P
M97-I9FES97)E(&5N(&UO='1A:V5R+B(*"B,Z(&QI8B](;W)D92]!=71H+G!H
M<#HY,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA
M<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(D1I;B`E
M<R!T:6QK;V)I;F<@:&%R(&?E='0@=70N(%9E;FYL:6=S="!L;V<@:6YN(&EG
M:F5N+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"B,L
M(&9U>GIY"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`B17!O
M<W1A9')E<W-E;B!D:6XZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P
M,@HC+"!F=7IZ>0IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R
M(")%<&]S=&%D<F5S<V5N(&1I;CHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<T(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@
M(EEO=7(@26YF;W)M871I;VXB"FUS9W-T<B`B1&EN(&EN9F]R;6%S:F]N(@H*
M(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDS-@HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@
M=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E
M8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S"FUS
M9VED(")9;W5R($YA;64B"FUS9W-T<B`B1G5L;'0@;F%V;B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHY"FUS9VED("(B"B)9;W5R(&%U
M=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@
M=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O
M<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHY"FUS9VED("(B"B)9;W5R(&%U=&AE
M;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S
M97)S+"!O<B!T:&4@9F5A='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@
M<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!
M=71H+G!H<#HY-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W
M<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI
M;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C
M=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO:69R86UE+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!B
M<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R
M(").971T;&5S97)E;B!D:6X@<W3X='1E<B!I:VME('9I<VYI;F<@878@9&5N
M;F4@='EP92!B:6QD97(@:6YL:6YE+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+W!R:6YT+FIS.C(W"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N
M;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]/
M<'1I;VX@*R!0('1O("(*(G!R:6YT+B(*;7-G<W1R("(B"B).971T;&5S97)E
M;B!D:6X@<W3X='1E<B!I:VME(&1E;FYE('5T<VMI9G1S;W!E<F%S:F]N96XN
M(%1R>6MK($MO;G1R;VQL+R(*(D]P<VIO;B`K(%`@9F]R(.4@<VMR:79E('5T
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#<*;7-G:60@(EEO=7(@
M8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-#@*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9&5F875L="!I
M9&5N=&ET>3HB"FUS9W-T<B`B4W1A;F1A<F1I9&5N=&ET970B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3DQ"B,L(&9U>GIY"FUS9VED(")9;W5R(&9U
M;&P@;F%M93HB"FUS9W-T<B`B3F%V;F5T(&1I='0Z(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C$T-0IM<V=I9"`B(@HB66]U<B!G971T97AT('9E<G-I;VX@
M:7,@=&]O(&]L9"!A;F0@9&]E<R!N;W0@<W5P<&]R="!02%`@;F%T:79E;'DN
M7&XB"B).;W0@86QL('-T<FEN9W,@=VEL;"!B92!E>'1R86-T960N(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H
M<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@
M)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ-38*
M(RP@9G5Z>GD*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E
M9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`B
M1&EN92!V86QG(&AA<B!B;&ET="!O<'!D871E<G0B"@HC.B!L:6(O2&]R9&4O
M4')E9G,O54DN<&AP.C$U.`IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E
M;B!U<&1A=&5D+B(*;7-G<W1R(")$:6YE('9A;&<@:&%R(&)L:71T(&]P<&1A
M=&5R="(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED
M(")9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R
M('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N
M9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"B,L(&9U>GIY
M"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R(")4:F5N97(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4T(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q.0IM<V=I9"`B675G;W-L879I82(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D*(RP@9G5Z>GD*;7-G:60@
M(EIA:7)E(@IM<V=S='(@(D9R82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(EIA;6)I82(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4W(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$Y"FUS9VED(")::6UB86)W92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-C8*;7-G:60@(EII<'!Y(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]497AT+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W
M,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM
M<V=I9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!R;V)L96TN<&AP.C4V"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM
M<V=S='(@(EM0<F]B;&5M<F%P<&]R=%TB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E
M>'0@+2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O:&EG
M:&QI9VAT<75O=&5S+G!H<#HQ-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H
M;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+G!H<#HQ.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@
M;V8@)7-=(@IM<V=S='(@(EML:6YJ92`E<R!A=B`E<UTB"@HC.B!L:6(O2&]R
M9&4N<&AP.C$T-S(@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHQ,0HC+"!F
M=7IZ>0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B5S(%!'4"!A
M9&UI;FES=')A<VIO;B(*"B,Z(&QI8B]A<&DN<&AP.C$S-`IM<V=I9"`B7T-,
M22(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,C(*(RP@9G5Z>GD*;7-G
M:60@(E]$871A5')E92(*;7-G<W1R(")$871O(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"B,L(&9U>GIY
M"FUS9VED(")?1&5L971E(%)O=R(*;7-G<W1R(")?4VQE='0B"@HC.B!L:6(O
M87!I+G!H<#HQ,30*(RP@9G5Z>GD*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B
M1W)U<'!E(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$X,0IM<V=I9"`B7TAE
M;'`B"FUS9W-T<B`B2&IE;'`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*(RP@9G5Z>GD*;7-G:60@(E])
M;6%G92!0<F]P97)T:65S+BXN(@IM<V=S='(@(D9O<FCE;F1S=FES;FEN9R(*
M"B,Z(&QI8B](;W)D92]-96YU+G!H<#HR,#`*(RP@9G5Z>GD*;7-G:60@(E],
M;V<@:6XB"FUS9W-T<B`B3&]G9R!I;FXB"@HC.B!L:6(O2&]R9&4O365N=2YP
M:'`Z,3DV"FUS9VED(")?3&]G(&]U="(*;7-G<W1R("),;V=G('5T(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(T"B,L(&9U>GIY"FUS9VED(")?36]D:69Y($QI;FLN+BXB"FUS9W-T<B`B
M1FIE<FX@<&%R(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$W,`IM<V=I9"`B
M7T]P=&EO;G,B"FUS9W-T<B`B5F%L9R(*"B,Z(&QI8B]A<&DN<&AP.C$Q.`HC
M+"!F=7IZ>0IM<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@(E!E<G-O;FQI
M9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR-@HC+"!F=7IZ>0IM<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM
M<V=S='(@(D9J97)N('!A<B(*"B,Z(&QI8B]A<&DN<&AP.C$P-@HC+"!F=7IZ
M>0IM<V=I9"`B7U-E='5P(@IM<V=S='(@(E9E;&<B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S(*(RP@9G5Z
M>GD*;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM<V=S='(@(D9O<FCE
M;F1S=FES;FEN9R(*"B,Z(&QI8B]A<&DN<&AP.C$Q,`HC+"!F=7IZ>0IM<V=I
M9"`B7U5S97)S(@IM<V=S='(@(D)R=6ME<FYA=FXB"@HC.B!L:6(O2&]R9&4O
M2V]L86(N<&AP.CDQ,0HC+"!F=7IZ>0IM<V=I9"`B861D<F5S<R!B;V]K(@IM
M<V=S='(@(D%D<F5S<V5B;VLB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S$Q
M"B,L(&9U>GIY"FUS9VED(")A;B!E<G)O<B!H87,@;V-C=7)E9#HB"FUS9W-T
M<B`B/&(^16X@9F%T86P@9F5I;"!H87(@;W!P<W3E='0Z/"]B/B(*"B,Z(&QI
M8B](;W)D92]+;VQA8BYP:'`Z.3`S"B,L(&9U>GIY"FUS9VED(")C86QE;F1A
M<B(*;7-G<W1R(")+86QE;F1E<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,3<P(&QI8B]";&]C:R]M971A<BYP:'`Z,S4V"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")C86QM(@IM<V=S='(@(D%V8G)Y="(*"B,Z(&QI8B](;W)D
M92]-24U%+T-O;G1E;G1S+G!H<#HV,#@*;7-G:60@(F-L:6-K(&AE<F4B"FUS
M9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0T-2!P;R]T<F%N<VQA
M=&EO;BYP:'`Z-34P('!O+W1R86YS;&%T:6]N+G!H<#HV,3$*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C<T.2!P;R]T<F%N<VQA=&EO;BYP:'`Z.#$P('!O+W1R
M86YS;&%T:6]N+G!H<#HX.#<*(RP@9G5Z>GD*;7-G:60@(F1O;F4B"FUS9W-T
M<B`B1F5R9&EG(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C4U,B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z-3@T('!O+W1R86YS;&%T:6]N+G!H<#HV,3,*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C<W."!P;R]T<F%N<VQA=&EO;BYP:'`Z.#$R('!O
M+W1R86YS;&%T:6]N+G!H<#HX.#D*(RP@9G5Z>GD*;7-G:60@(F9A:6QE9"(*
M;7-G<W1R(")%+7!O<W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S<X"FUS9VED(")F86QL:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]"<F]W<V5R+G!H<#HX-S`*(RP@9G5Z>GD*;7-G:60@(F9I;&4B"FUS9W-T
M<B`B1FEL(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$R.0HC+"!F=7IZ>0IM
M<V=I9"`B9F]U;F0Z("(*;7-G<W1R(")!=G-LY71T.B`B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U."!L:6(O
M0FQO8VLO;65T87(N<&AP.C,X-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R("(E<R!PY2`E
M<R`E<R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,S(*;7-G:60@(F@Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR,#@*;7-G:60@(FDQ.&XB"FUS9W-T<B`B(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X-R!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(R.0IM<V=I9"`B:6UM961I871E(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8X(&%D;6EN+W-E='5P+V1I
M9F8N<&AP.C<V"B,L(&9U>GIY"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B26YL
M:6YE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z
M,3,*(RP@9G5Z>GD*;7-G:60@(FQI;F5S72(*;7-G<W1R("));FQI;F4B"@HC
M.B!L:6(O5D93+TE33U=R:71E<B]M:VES;V9S+G!H<#HU-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG
M($E33RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HR
M.#@@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(P-@IM<V=I9"`B;F%M
M92(*;7-G<W1R(")N879N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C,W.`HC
M+"!F=7IZ>0IM<V=I9"`B;F]T(&-H86YG960B"FUS9W-T<B`B06YG<F4@96YD
M<FEN9V5R(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$S,0HC+"!F=7IZ>0IM
M<V=I9"`B;F]T(&9O=6YD(@IM<V=S='(@(D]B:F5K=&5T(&)L92!I:VME(&9U
M;FYE="(*"B,Z(&QI8B](;W)D92]24$,N<&AP.C$R,@HC+"!F=7IZ>0IM<V=I
M9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(D9E<F1I9R(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z,3(T-0HC+"!F=7IZ>0IM<V=I9"`B;F]T
M('EE="!I;7!L96UE;G1E9"(*;7-G<W1R(")$96X@9F]R97-P=7)T92!O<'!G
M879E;B!E<B!I:VME(&EM<&QE;65N=&5R="XB"@HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.C@Y-0HC+"!F=7IZ>0IM<V=I9"`B;F]T97!A9"(*;7-G<W1R(").
M;W1A=&)L;VMK(&9O<B`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*(RP@9G5Z>GD*;7-G:60@(G!E<F-E
M;G0B"FUS9W-T<B`B4VMR:78@=70B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,X,`HC
M+"!F=7IZ>0IM<V=I9"`B<FES:6YG(@IM<V=S='(@(D]R9V%N:7-E<FEN9R(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.3@*;7-G:60@(G-H;W<@9&EF
M9F5R96YC97,B"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4S,PIM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-SD*(RP@
M9G5Z>GD*;7-G:60@(G-T96%D>2(*;7-G<W1R(")/<'!D871E<B(*"B,Z(&QI
M8B](;W)D92]+;VQA8BYP:'`Z.3$Y"B,L(&9U>GIY"FUS9VED(")T87-K(&QI
M<W0B"FUS9W-T<B`B4W9A<G1E;&ES=&4B"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z-S(U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")T:&4@2&]R9&4@
M4$\@9FEL92!F;W(@=&AE(&QO8V%L92`E<R!D;V5S(&YO="!E>&ES=#HB"FUS
M9W-T<B`B1&5N('-P97-I9FES97)T92!F:6QE;B!E:W-I<W1E<F5R(&EK:V4N
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@;&EB+TAO<F1E+T%U=&@O4VEG;G5P
M+G!H<#HR.#(*(RP@9G5Z>GD*;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W
M:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B5FES(&UA:6QL:7-T92!I;F9O<FUA
M<VIO;B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8X(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.C<V"B,L(&9U>GIY"FUS9VED(")U;FEF:65D(@IM<V=S='(@
M(D4M<&]S="(*"B,Z(&QI8B](;W)D92]-24U%+U!A<G0N<&AP.C$W"B,L(&9U
M>GIY"FUS9VED(")U;FYA;65D(@IM<V=S='(@(E5T96X@;F%V;B(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HS-S4*(RP@9G5Z>GD*;7-G:60@(G5P9&%T960B
M"FUS9W-T<B`B4VES=&4@;W!P9&%T97)I;F<Z(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4X-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(R.0HC+"!F=7IZ>0IM<V=I9"`B=7-E<B!S96QE8W0B"FUS
M9W-T<B`B:6YG96X@;6%P<&4@=F%L9W0B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C,X"FUS9VED(")V0V%R9"(*;7-G<W1R(")V0V%R
M9"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,C0*
M(RP@9G5Z>GD*;7-G:60@(G<Z(@IM<V=S='(@(D9W9#HB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,PIM<V=I9"`B=V5A=&AE<BYC;VTB"FUS
M9W-T<B`B(@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]S
M=E]312YP;P``````````````````````````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#$Q,S$P-S4@,3`U,34T,S,W-#,@,#$W-30U`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````",@2&]R9&4@4W=E
M9&ES:"!T<F%N<VQA=&EO;@HC($-O<'ER:6=H="`H0RD@,C`P,BTR,#`V($AO
M<F1E(%!R;VIE8W0*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@
M=&AE('-A;64@;&EC96YS92!A<R!T:&4@2&]R9&4@<&%C:V%G92X*(R!*;V%Q
M=6EM($AO;7)I9VAA=7-E;B`\:F]H;T!W96)B<&QA='-E;BYS93XL(#(P,#8N
M"B,@06YD<F5A<R!$86ALZ6X@/&%N9')E87-`9&%H;&5N+G=S/BP@,C`P-2X*
M(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@2&]R
M9&4@,RXQ7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO
M<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#8M,#(M,34@,3$Z
M,C$K,#$P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP,BTQ-B`P,#HR
M-BLP,3`P7&XB"B),87-T+51R86YS;&%T;W(Z($IO87%U:6T@2&]M<FEG:&%U
M<V5N(#QJ;VAO0'=E8F)P;&%T<V5N+G-E/EQN(@HB3&%N9W5A9V4M5&5A;3H@
M4W=E9&ES:"`\:3$X;D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I
M;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T
M/6ES;RTX.#4Y+3%<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB
M:71<;B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M7W1O<"YI
M;F,Z,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB("8C,34Q.R`E<R!I<R!R
M96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H
M96-K960@8F5L;W<N(@IM<V=S='(@(B(*(B`F(S$U,3L@)7,@:V]M;65R(&%T
M="!U=&;V<F$@9&4@=6YD97)HY6QL<V%K=&EV:71E=&5R;F$@<V]M(&UA<FME
M<F%T<R!N961A;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S8Y
M(&QI8B](;W)D92]&;W)M+G!H<#HR,S<S"B,L('!H<"UF;W)M870*;7-G:60@
M(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B`H)7,@9&%G87(@<V5D86XI(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ,S(V(&QI8B](;W)D92YP
M:'`Z,3,W-`HC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB
M"FUS9W-T<B`B("AS;F%B8G1A;F=E;G0@)7,I(@H*(SH@=&5M<&QA=&5S+VQI
M;FMS+VQI;FMS+FEN8SHT"FUS9VED("(@*%)E860@;VYL>2DB"FUS9W-T<B`B
M("A3:W)I=G-K>61D860I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C,W-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,X,0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B`H;VT@)7,@9&%G87(I(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,R!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C,W-PIM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B("AI9&%G*2(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S4@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(S-SD*;7-G:60@(B`H=&]M;W)R;W<I(@IM<V=S='(@(B`H:6UO
M<F=O;BDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<Q(&QI8B](
M;W)D92]&;W)M+G!H<#HR,S<U"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T
M<B`B("AI9^5R*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U,`HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDV"FUS9VED("(@870@(@IM<V=S='(@
M(B!K;"`B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Q-2!L:6(O
M5D93+W-M8BYP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I
M<R!N;W0@82!D:7)E8W1O<GDN(@IM<V=S='(@(B<E<R<@Y'(@:6YT92!E;B!K
M871A;&]G+B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-S(@;&EB+TAO
M<F1E+T-,22YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I
M<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(B<E<R<@Y'(@:6YT92!E
M='0@9V]D:^1N="!V86PN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E
M9VES=')Y+G!H<#HV-38*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES
M=')Y+G!H<#HQ,#,Y(&QI8B](;W)D92]296=I<W1R>2YP:'`Z-S$P"B,Z(&QI
M8B](;W)D92]296=I<W1R>2YP:'`Z,3`Y.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES
M=')Y+B(*;7-G<W1R("(G)7,G(.1R(&EN=&4@:V]N9FEG=7)E<F%T(&D@2&]R
M9&5R96=I<W1R97)T+B(*"B,Z(&9R86UE=V]R:R]4<F5E+U1R964N<&AP.C$W
M,2!L:6(O2&]R9&4O5')E92YP:'`Z,3<Q"B,L('!H<"UF;W)M870*;7-G:60@
M(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B5'+D
M9&AA;G1E<F%R96X@9O9R("5S('-A:VYA<RXB"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C4V"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@
M=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(B<E<R<@;&%D97,@=&EL
M;"!I(&=R=7!P<WES=&5M970N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N
M<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@
M=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B)R5S)R!L861E
M<R!T:6QL(&D@8F5H]G)I9VAE='-S>7-T96UE="XB"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C4T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS
M9W-T<B`B)R5S)R!S:V%P861E<R!I;G1E.B`E<RXB"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"('5S
M960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T<B`B)2XR9DU"
M(&%N=N1N="!A=B`E+C)F34(@=&EL;.5T970@*"4R9B4E*2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)60@)7,@86YD("5S(@IM<V=S='(@(B5D("5S(&]C:"`E<R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,C8X(&QI8B](;W)D92]!=71H
M+VQD87`N<&AP.C(V.`HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-34W"B,L
M('!H<"UF;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R
M9"!E>'!I<F5S+B(*;7-G<W1R(")$:71T(&SV<V5N;W)D('5P<&CV<B!A='0@
M9^1L;&$@;VT@)60@9&%G87(N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A
M<W0B"FUS9W-T<B`B)60M9&%G<W!R;V=N;W,B"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z-C@@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VYO=&EC95]T
M;W`N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS
M9W-T<B`B)7,@+2!&]G(@:^1N;F5D;VTB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C<P-"!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C<P-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*;7-G
M<W1R(")&:6YG97)P<FEN="!F]G(@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HX,S(@9G)A;65W;W)K+TU)344O34E-12]#;VYT
M96YT<RYP:'`Z.#,T"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX
M-#$@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@T,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(E<R!+0B(*"B,Z('-E<G9I8V5S
M+VUA:6YT96YA;F-E+G!H<#HT.2!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N
M9FER;5]T;W`N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E
M;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(E<R!5
M;F1E<FCE;&QS9G5N:W1I;VX@+2!"96MRY&9T96QS92(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R("(E<R!3971U
M<"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C,@;&EB
M+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-C0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(E<R!A;FWD;&%N(@H*(SH@<V5R=FEC
M97,O;6%I;G1E;F%N8V4N<&AP.C4Y('1E;7!L871E<R]M86EN=&5N86YC92]A
M9W)E96UE;G1?=&]P+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E
M<FUS(&]F($%G<F5E;65N="(*;7-G<W1R(")4:N1N<W1E879T86P@9O9R("5S
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT,C@@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HT.3`*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HV-3$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,3D*(SH@;&EB
M+U9&4R]S;6(N<&AP.C0S,B!L:6(O5D93+W-M8BYP:'`Z-#DT(&QI8B]61E,O
M9G1P+G!H<#HV.#(*(SH@;&EB+U9&4R]F='`N<&AP.C<U,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B)7,@9FEN
M;G,@<F5D86XN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C8@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#8*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B
M)7,@:VP@)7,@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C4S,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@
M8V%N8V5L;&5D("5S+B(*;7-G<W1R("(E<R!H87(@86YN=6QL97)A="`E<RXB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C0R-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!H87,@<F5P;&EE9"!T;R!A
M(&9R964O8G5S>2!R97%U97-T+B(*;7-G<W1R("(E<R!H87(@<W9A<F%T('#E
M(&5N(&)E9^1R86X@;VT@:6YF;W)M871I;VX@86YGY65N9&4@;&5D:6<O=7!P
M=&%G96XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HU,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(')E<&QI
M960@=&\@=&AE(&EN=FET871I;VX@=&\@)7,N(@IM<V=S='(@(B5S(&AA<B!S
M=F%R870@<.4@:6YB:G5D86X@=&EL;"`E<RXB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0Q-@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!H87,@<V5N="!Y;W4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N
M+B(*;7-G<W1R("(E<R!H87(@<VMI8VMA="!D:6<@:6YF;W)M871I;VX@;VT@
M;&5D:6<O=7!P=&%G96XN(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C0X"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E
M<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO
M=RX@0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@
M=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B(@HB)7,@
M:V]M;65R(&%T="!U=&;V<F$@9&4@=6YD97)HY6QL<V%K=&EV:71E=&5R;F$@
M<V]M(&UA<FME<F%T<R!N961A;BX@36%R:V5R82`B"B)D92!A:W1I=FET971E
M<B!S;VT@9'4@=FEL;"!U=&;V<F$N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C,T,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,T-`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("(E<R!K<N1V<R(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDS"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&UI;G5T97,B"FUS9W-T<B`B)7,@;6EN=71E<B(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,C,@;&EB+TAO<F1E
M+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B5S('-A:VYA<RXB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0R,0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!R97%U97-T<R!Y;W5R(&9R964O8G5S>2!I
M;F9O<FUA=&EO;BXB"FUS9W-T<B`B)7,@969T97)F<N5G87(@:6YF;W)M871I
M;VX@;VT@;N1R(&1U(.1R(&QE9&EG+W5P<'1A9V5N+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3`X"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(')E<75E<W1S('EO=7(@<')E<V5N8V4@870@)7,N
M(@IM<V=S='(@(B5S(&5F=&5R9G+E9V%R(&1I;B!NY')V87)O('9I9"`E<RXB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHT"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@(B5S('1I;&P@
M)7,@878@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C4Q,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W:7-H97,@
M=&\@861D('1O("5S+B(*;7-G<W1R("(E<R!V:6QL(&SD9V=A('1I;&P@=&EL
M;"`E<RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C4P,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W:7-H97,@=&\@
M;6%K92!Y;W4@87=A<F4@;V8@)7,N(@IM<V=S='(@(B5S('9I;&P@9_9R82!D
M:6<@;65D=F5T96X@;VT@)7,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HU,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@=VES:&5S('1O(')E8V5I=F4@=&AE(&QA=&5S="!I;F9O<FUA=&EO;B!A
M8F]U="`E<RXB"FUS9W-T<B`B)7,@=FEL;"!E<FCE;&QA(&1E;B!S96YA<W1E
M(&EN9F]R;6%T:6]N96X@;VT@)7,N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HY,C(@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,C8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B061R97-S
M8F]K(&;V<B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$T
M(&QI8B](;W)D92]+;VQA8BYP:'`Z.3$X"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B2V%L96YD97(@9O9R("5S(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#8@;&EB+TAO<F1E+TMO;&%B
M+G!H<#HY,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM
M<V=S='(@(D%N=&5C:VYI;F=A<B!F]G(@)7,B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.CDS,"!L:6(O2&]R9&4O2V]L86(N<&AP.CDS-`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(E5P<&=I
M9G1E<B!F]G(@)7,B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,Z(&QI8B](;W)D92].
M;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B)7,Z("5S(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,C<R(&QI8B](;W)D92]-
M24U%+U9I97=E<B]H=&UL+G!H<#HQ,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C
M;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@(@HB86YY(&QI;FMS
M(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E
M<G-O;F%L(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"B(E<SH@365D9&5L86YD
M970@:V%N<VME(&EN=&4@Y'(@9G+E;B!D96X@<V]M(&1E="!V97)K87(N(%9A
M<B!F]G)S:6MT:6<@;65D("(*(F%T="!F]FQJ82!LY&YK87(@96QL97(@<VMI
M8VMA(&%V<^1N9&%R96X@<&5R<V]N;&EG(&EN9F]R;6%T:6]N+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-30@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,Y.0IM<V=I9"`B+"!G=7-T:6YG("(*;7-G<W1R("(L
M('-T;W)M8GEA<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3DU(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C`P"B,L('!H<"UF;W)M870*;7-G:60@(BP@9W5S
M=&EN9R`E<R`E<R(*;7-G<W1R("(L('-T;W)M8GEA<B`E<R`E<R(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C`X"B,L('!H<"UF;W)M870*;7-G:60@(BP@
M=F%R:6%B;&4@9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(L('9A<FEE<F%N9&4@
M;65L;&%N("5S(&]C:"`E<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,CDT(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S0X"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-CD@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C$R.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-S(S(&QI8B](;W)D92]&;W)M+G!H<#HR,#<S"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR,3,R(&QI8B](;W)D92]097)M<R]522YP:'`Z,CDT
M"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,S0X(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HW-#@*;7-G:60@(BTM('-E;&5C="`M+2(*
M;7-G<W1R("(M+2!VY&QJ("TM(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P
M"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R("(Q,BUT:6UM87)S9F]R
M;6%T(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y"FUS9VED("(R-"!(;W5R
M($9O<FUA="(*;7-G<W1R("(R-"UT:6UM87)S9F]R;6%T(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@
M(C(T('1I;6UA<B(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z-CD@
M;&EB+TAO<F1E+U5)+U!A9V5R+G!H<#HV.0IM<V=I9"`B/%!R979I;W5S(@IM
M<V=S='(@(CQ&]G)E9^5E;F1E(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M,C8*;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@
M=&AI<R!B;&]C:RXB"FUS9W-T<B`B16X@9&%T86)A<VMO<'!L:6YG(&MRY'9S
M(&;V<B!A:W1U96QL="!B;&]C:RXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C$V,"!L:6(O2&]R9&4N<&AP.C$V,@IM<V=I9"`B02!F871A;"!E
M<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`B171T(&9A=&%L="!F96P@:&%R
M(&EN='+D9F9A="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.CDR,"!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B
M;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N
M(@IM<V=S='(@(D5N('!U8FQI:R!01U`M;GEC:V5L(&MRY'9S(&;V<B!A='0@
M:W)Y<'1E<F$@971T(&UE9&1E;&%N9&4N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3$T-2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ
M,38X"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E
M<FEF>2!A('-I9VYE9"!M97-S86=E+B(*;7-G<W1R(")%;B!P=6)L:6L@4$=0
M+6YY8VME;"!K<N1V<R!F]G(@871T('9E<FEF:65R82!E='0@<VEG;F5R870@
M;65D9&5L86YD92XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,#<W(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$P.3D*;7-G:60@(B(*
M(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*
M;7-G<W1R("(B"B)%;B!P=6)L:6L@;V-H('!R:79A="!01U`M;GEC:V5L('-A
M;70@;/9S96YO<F0@:W+D=G,@9O9R(&%T="!D96MR>7!T97)A(&5T="`B"B)M
M961D96QA;F1E+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.CDY-2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#$V"FUS9VED("(B"B)!
M('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T
M<B`B(@HB16X@<'5B;&EK(&]C:"!P<FEV870@4$=0+6YY8VME;"!S86UT(&SV
M<V5N;W)D(&MRY'9S(&;V<B!A='0@<VEG;F5R82!E='0@(@HB;65D9&5L86YD
M92XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4P-2!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4P-@IM<V=I9"`B(@HB02!P=6)L
M:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM
M<V=S='(@(B(*(D5N('!U8FQI:R!O8V@@<')I=F%T(%,O34E-12UN>6-K96P@
M<V%M="!L]G-E;F]R9"!K<N1V<R!F]G(@871T(&1E:W)Y<'1E<F$@(@HB971T
M(&UE9&1E;&%N9&4N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HT,S$@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G:60@
M(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M97-S
M86=E+B(*;7-G<W1R("(B"B)%;B!P=6)L:6L@;V-H('!R:79A="!3+TU)344M
M;GEC:V5L('-A;70@;/9S96YO<F0@:W+D=G,@9O9R(&%T="!S:6=N97)A(&5T
M="`B"B)M961D96QA;F1E+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,S8T(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,S8T"FUS
M9VED(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP
M="!A(&UE<W-A9V4N(@IM<V=S='(@(D5N('!U8FQI:R!3+TU)344M;GEC:V5L
M(&MRY'9S(&;V<B!A='0@:W)Y<'1E<F$@971T(&UE9&1E;&%N9&4N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B
M04T@0VQO=61S(@IM<V=S='(@(D;V<FUI9&1A9W-M;VQN(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*;7-G:60@(D%-($QI
M9VAT(%)A:6XB"FUS9W-T<B`B3.1T="!F]G)M:61D86=S<F5G;B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"FUS9VED(")!
M32!286EN(@IM<V=S='(@(D;V<FUI9&1A9W-R96=N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D%-(%-H;W=E
M<G,B"FUS9W-T<B`B1O9R;6ED9&%G<W-K=7)A<B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!32!3;F]W(%-H
M;W=E<G,B"FUS9W-T<B`B1O9R;6ED9&%G<W-K=7)A<B!M960@<V[V(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM<V=S
M='(@(D%-+U!-(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C`P"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C`P"FUS9VED(")!4$D@240B"FUS9W-T<B`B05!)($E$(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I
M9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`B3VT@961I=&]R;B(*"B,Z
M('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4S"FUS9VED(")!8F]U="XN+B(*
M;7-G<W1R(")/;2XN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R(")";W1T
M96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<R"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B36ET=&5N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV-#`*;7-G
M:60@(D%C8V5P="!R97%U97-T(@IM<V=S='(@(D%C8V5P=&5R82!B96?D<F%N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HV.#$*;7-G:60@(D%C8V5P=&5D(@IM<V=S='(@(D%C8V5P=&5R860B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C<P(&QI8B]61E,O;75S
M<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@
M9&ER96-T;W)Y+B(*;7-G<W1R(")"96CV<FEG:&5T('-A:VYA<R!A='0@<VMA
M<&$@5D93+6UA<'`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C$S-B!L:6(O5D93+VUU<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI
M960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@(D)E:/9R:6=H970@<V%K
M;F%S(&%T="!S:V%P82!61E,M9FEL+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HS"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(DMO
M;G1O:6YF;W)M871I;VXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@*
M;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS9W-T<B`B3/9S96YO<F0@9O9R
M(&MO;G1O(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDS"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDS"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`B2V]N=&]T
M(&9R>7-T(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S-0IM<V=I
M9"`B06-C;W5N=&EN9R(*;7-G<W1R(")"=61G970B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0U,0HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8R-0IM<V=I9"`B
M06-T:6]N<R(*;7-G<W1R("+%=&?D<F1E<B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,30X(&QI8B](;W)D92]097)M<R]522YP:'`Z,30X
M"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ-"!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0IM<V=I9"`B061D(@IM<V=S='(@
M(DSD9V<@=&EL;"(*"B,Z('1E;7!L871E<R]L:6YK<R]L:6YK<RYI;F,Z,3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B061D("5S(@IM<V=S='(@(DSD9V<@=&EL
M;"`E<R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T(&%D;6EN+V=R;W5P<RYP
M:'`Z,C(U"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B3.1G9R!T
M:6QL('5N9&5R9W)U<'`B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.CDX(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3D*(SH@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HY."!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.CDY"FUS9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R(")LY&=G
M('1I;&P@=6YD97)B96CV<FEG:&5T(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A
M9&0N:6YC.C4*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R("),Y&=G('1I;&P@
M:.1R.B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP
M:'`Z,C$Y"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S='(@(DSD9V<@=&EL
M;"!N>2!G<G5P<"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX.`HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C@W(&QI8B](;W)D92]097)M<R]522YP:'`Z.#@*
M;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO;B(*;7-G<W1R("),Y&=G('1I;&P@
M;GD@8F5H]G)I9VAE="(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D
M8VAI;&0N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@
M9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(DSD9V<@=&EL;"!U;F1E<F=R=7!P
M('1I;&P@)R5S)R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,30W(&QI8B](;W)D92]097)M<R]522YP:'`Z,30W"B,L('!H<"UF;W)M870*
M;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S
M='(@(DSD9V<@=&EL;"!U;F1E<F)E:/9R:6=H970@=&EL;"`G)7,G(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G
M<W1R("),Y&=G('1I;&P@96X@;GD@86YVY&YD87)E.B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,CD*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-@IM<V=I9"`B061D(&-O;'5M
M;B(*;7-G<W1R("),Y&=G('1I;&P@:V]L=6UN(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHS-`IM<V=I9"`B061D(&YE=R!M96UB97)S
M(@IM<V=S='(@(DSD9V<@=&EL;"!N>6$@;65D;&5M;6%R(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D('!A:7(B"FUS9W-T
M<B`B3.1G9R!T:6QL('!A<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@
M36]Z:6QL82!3:61E8F%R(@IM<V=S='(@(DSD9V<@=&EL;"!M96YY;B!F]G(@
M)7,@<V]M($UO>FEL;&$@4VED96)A<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C,Q"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C,W"FUS9VED(")!9&0@=&AI
M<R!T;R!M>2!C86QE;F1A<B(*;7-G<W1R("),Y&=G('1I;&P@:2!M:6X@:V%L
M96YD97(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z-S$@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HW,0IM<V=I
M9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B3.1G9R!T:6QL(&D@
M861R97-S8F]K.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HW."!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C<X
M"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(DSD9V<@
M=&EL;"!I(&UI;B!A9')E<W-B;VLB"@HC.B!A9&UI;B]U<V5R+G!H<#HS,0IM
M<V=I9"`B061D('5S97(B"FUS9W-T<B`B3.1G9R!T:6QL(&%N=N1N9&%R92(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D
M9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S
M='(@(B(*(DQA9&4@=&EL;"`G)7,G('1I;&P@<WES=&5M970L(&UE;B!K=6YD
M92!I;G1E(&SD9V=A('1I;&P@97AT<F$@(&EN9F]R;6%T:6]N.B`E(@HB<RXB
M"@HC.B!S:6=N=7`N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&5D
M(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM
M<V=S='(@(DQA9&4@=&EL;"`G)7,G('1I;&P@<WES=&5M970N($1U(&MA;B!L
M;V=G82!I;B!N=2XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI
M;F,Z,@IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R
M(")5<'!LY&=G(&%V(&%N=N1N9&%R92#D<B!I;F%K=&EV97)A="XB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-S,@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,30T,0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,30T-2!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$W,PIM<V=I9"`B061D
M<F5S<R(*;7-G<W1R(")!9')E<W,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,30Q"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B061R97-S
M8F]K(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.30@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C4V"B,Z(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI<W1E
M<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`B
M061M:6YI<W1R871I;VX@+2!A;F=E(&)E:/9R:6=H970@9O9R(&%N9')A(&%N
M=N1N9&%R92(*"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ.2!S97)V:6-E<R]P;W)T
M86PO;65N=2YP:'`Z,3$S"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN:7-T
M<F%T:6]N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T,PIM<V=I
M9"`B061S(@IM<V=S='(@(E)E:VQA;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$X"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B069G:&%N
M:7-T86XB"FUS9W-T<B`B069G86YI<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(Q"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06QB
M86YI82(*;7-G<W1R(")!;&)A;FEE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C<T"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B06QG97)I
M82(*;7-G<W1R(")!;&=E<FEE="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,#<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ,#<*;7-G:60@(D%L:6%S(@IM<V=S='(@(D%L:6%S(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHQ-@IM<V=I9"`B06QI9VXB"FUS9W-T<B`B2G5S=&5R82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L
M:6=N;65N=#HB"FUS9W-T<B`B2G5S=&5R:6YG.B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(D%L;&$B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P-R!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C(P-PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8U
M"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*;7-G<W1R(")!;&QA
M(&%U=&5N=&ES97)A9&4@86YVY&YD87)E(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM<V=I9"`B06QL($=R;W5P<R(*
M;7-G<W1R(")!;&QA(&=R=7!P97(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.CDQ(&9R86UE=V]R:R]097)M<R]097)M<R]D871A=')E92YP
M:'`Z-S4*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HY,2!L:6(O2&]R9&4O
M4&5R;7,O9&%T871R964N<&AP.C<U"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B06QL82!B96CV<FEG:&5T97(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$W"FUS9VED(")!;&P@
M9F]U<B!S:61E<R(*;7-G<W1R(")!;&QA(&9Y<F$@<VED;W(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<Q(&QI8B](;W)D92]&;W)M+G!H<#HQ
M.#<U"FUS9VED(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`B
M5&EL;.5T(&9L97)A(&%D<F5S<V5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4S.`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@
M='EP93\B"FUS9W-T<B`B5&EL;.5T(&EN<W3D;&QN:6YG(&;V<B!S;W)T97)A
M9"!L:7-T83\B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L
M+G!H<#HU,#0@;&EB+TAO<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS9VED
M(")!;')E861Y(&5X:7-T<R(*;7-G<W1R(")&:6YN<R!R961A;B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C8*;7-G:60@(D%L=&5R;F%T92!)35-0
M($QO9VEN(@IM<V=S='(@(D%L=&5R;F%T:78@24U34"UI;FQO9V=N:6YG(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q,0IM<V=I9"`B06QT97)N871E
M($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B06QT97)N871I=G0@;/9S96YO<F0@
M9O9R($E-4U`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`S"FUS9VED
M(")!;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G<W1R(")!;'1E<FYA=&EV
M="!A;G;D;F1A<FYA;6X@9O9R($E-4U`B"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HS-0IM<V=I9"`B06QT97)N871E(&5M86EL(&%D9')E<W,B
M"FUS9W-T<B`B06QT97)N871I=B!E+7!O<W0@861R97-S(@H*(SH@861M:6XO
M=&5M<&QA=&5S+G!H<#HQ-#(*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T97,B
M"FUS9W-T<B`B06QT97)N871I=B!M86QL(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(U"FUS9VED(")!
M;'1E<FYA=&4@=&5X=#HB"FUS9W-T<B`B06QT97)N871I=B!T97AT.B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3@@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(W"B,Z(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HU.`IM<V=I9"`B06UE<FEC86X@4V%M;V$B"FUS9W-T<B`B06UE<FEK86YS
M:V$@4V%M;V$B"@HC.B!F<F%M97=O<FLO3&EN:W,O3&EN:W,N<&AP.C(T-PHC
M.B!F<F%M97=O<FLO4F5L871I;VYS:&EP+U)E;&%T:6]N<VAI<$UA;F%G97(N
M<&AP.C(T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!;B!E<G)O<B!O8V-U<G)E
M9"!F;VQL;W=I;F<@=&AI<R!L:6YK.B`E<R(*;7-G<W1R(")%='0@9F5L('5P
M<'-T;V0@;N1R(&SD;FME;B`H)7,I('-K=6QL92!A;G;D;F1A<R(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z.34@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ,34*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HY
M-2!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@:6QL96=A
M;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R(")%='0@9F5L86MT:6=T
M(';D<F1E(&%N9V%V<RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,34U"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+B(*
M;7-G<W1R(")%='0@;VOD;G0@9F5L(&AA<B!I;G1RY&9F870B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4U(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-@HC.B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-34*
M;7-G:60@(D%N9&]R<F$B"FUS9W-T<B`B06YD;W)R82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T"B,Z(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I
M9"`B06YG;VQA(@IM<V=S='(@(D%N9V]L82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(P"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG
M=6EL;&$B"FUS9W-T<B`B06YG=6EL;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.0IM
M<V=I9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S='(@(D%N;VYY;2!P<F]X>2(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W
M97(B"FUS9W-T<B`B4W9A<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(U"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ."!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YT87)C=&EC82(*
M;7-G<W1R(")!;G1A<FMT:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ.0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%N=&EG=6$@86YD
M($)A<F)U9&$B"FUS9W-T<B`B06YT:6=U82!O8V@@0F%R8G5D82(*"B,Z(&%D
M;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN<&AP.C,U"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3@@;&EB+TAO<F1E+T)L
M;V-K+U5)+G!H<#HU.`HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N
M:'1M;#HV"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R(")!<'!L:6MA=&EO
M;B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC
M871I;VX@3&ES="(*;7-G<W1R(")!<'!L:6MA=&EO;G-L:7-T82(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#`*;7-G:60@(D%P<&QI8V%T:6]N(&ES
M(')E861Y+B(*;7-G<W1R(")!<'!L:6MA=&EO;F5N(.1R(&ML87(N(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O
M($-H:6QD(%-H87)E<R(*;7-G<W1R(")697)K<W3D;&P@=&EL;"!U;F1E<G5T
M9&5L;FEN9V%R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI
M;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B1V]D:^1N;B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S,B!L:6(O2&]R9&4O
M34E-12]#;VYT96YT<RYP:'`Z.#0Q"FUS9VED(")!<'!R;WAI;6%T92!3:7IE
M(@IM<V=S='(@(E5N9V5FY')L:6<@<W1O<FQE:R(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HS.#`*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-PHC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`B87!R:6PB
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B07)A8FEC("A7
M:6YD;W=S+3$R-38I(@IM<V=S='(@(D%R86)I<VL@*%=I;F1O=W,M,3(U-BDB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4Y(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,2!L:6(O2&]R9&4O34E-
M12]6:65W97(O<F%R+G!H<#HU.0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M>FEP+G!H<#HV-B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW.`IM
M<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`B07)K:79F:6QS=&]R
M;&5K(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU
M."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8R"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#`@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+WII<"YP:'`Z-C4@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z
M-S<*;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R(")!<FMI=F9I;&YA;6XB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$P
M"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T
M;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@
M(L1R(&1E="!SY&ME<G0@871T(&1U('9I;&P@=&$@8F]R="!B96?D<F%N(&;V
M<B`E<S\B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@
M=&\@9&5L971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@
M(L1R(&1E="!SY&ME<G0@871T(&1U('9I;&P@<F%D97)A("<E<R<@;V-H(&5V
M96YT=65L;&$@=6YD97)G<G5P<&5R/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(V"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B07)G96YT
M:6YA(@IM<V=S='(@(D%R9V5N=&EN82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(R"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B07)M96YI
M82(*;7-G<W1R(")!<FUA;FEE;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3<Y"FUS9VED(")!<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R(")!<FUE
M;FES:R`H05)-4T-)22TX*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR
M.`IM<V=I9"`B07)T(@IM<V=S='(@(DMO;G-T(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.2!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,S`*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(R(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!
M<G5B82(*;7-G<W1R(")!<G5B82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,34@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E
M;G-I;VX@27-L86YD(@IM<V=S='(@(D%S8V5N<VEO;B!)<VQA;F0B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G
M<W1R(")!<V-I:2!K;VYS="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I
M82]086-I9FEC(%)E9VEO;B(*;7-G<W1R(")!<VEE;B]3=&EL;&$@:&%V<W)E
M9VEO;F5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R.0IM<V=I9"`B
M07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,_(@IM<V=S='(@(D9RY6=A(&5F=&5R(&)E:W+D9G1E;'-E
M(&EN;F%N('5N9&5R:.5L;'-A:W1I=FET971E<B!U=&;V<G,_(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q,R!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,S`Y.0IM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(E1I;&QD
M96QN:6YG<VMO;'5M;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z,38V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z,C0Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z,S$X"FUS9VED(")!='1A8VAE9"!I<R!A
M;B!I0V%L96YD87(@9FEL92!R97!L>2!T;R!A(')E<75E<W0@>6]U('-E;G0B
M"FUS9W-T<B`B0FEF;V=A9"#D<B!E;B!I0V%L96YD97(@9FEL(&UE9"!E='0@
M<W9A<B!PY2!E;B!B96?D<F%N('-O;2!D=2!S:VEC:V%T+"(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z-S0*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N
M+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R(")&]G)S]FL@=&EL;"!A='0@<F%D
M97)A(&5N(&=R=7!P('-O;2!I;G1E(&9I;FYS+B(*"B,Z(&%D;6EN+W!E<FUS
M+V1E;&5T92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N
M+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(D;V<G/V:R!T:6QL(&%T
M="!R861E<F$@96X@8F5H]G)I9VAE="!S;VT@:6YT92!F:6YN<RXB"@HC.B!A
M9&UI;B]P97)M<R]E9&ET+G!H<#HX-PIM<V=I9"`B071T96UP="!T;R!E9&ET
M(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(D;V<G/V:R!A
M='0@Y&YD<F$@96X@8F5H]G)I9VAE="!S;VT@:6YT92!F:6YN<RXB"@HC.B!S
M97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@
M961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T<B`B1O9R<_9K(&%T
M="#D;F1R82!E;B!U=&1E;&YI;F<@<V]M(&EN=&4@9FEN;G,N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU-S<*;7-G
M:60@(D%T=&5N9&5E<R(*;7-G<W1R(")$96QT86=A<F4B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8T(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-C@*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HX-B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R
M+G!H<#HV-`HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,2!L
M:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX,PIM<V=I9"`B071T<FEB
M=71E<R(*;7-G<W1R(")!='1R:6)U="(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HS.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0R,0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`Y(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHW,@IM<V=I9"`B075G=7-T(@IM<V=S='(@(F%U9W5S=&DB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4Y(&QI8B](;W)D92].3%,O=&QD+G!H<#HR.0HC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R(")!=7-T<F%L:65N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU.2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C@*(SH@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C4Y"FUS9VED(")!=7-T<FEA(@IM<V=S='(@(M9S=&5R<FEK92(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HQ-C@@;&EB+TAO<F1E
M+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L.B!297%U
M:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?
M8WER<W%L.B!)34%0+65X=&5N<VEO;B!S86MN87,N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)U<RYP:'`Z,3,U(&QI8B](;W)D92]!=71H+V-Y<G5S
M+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@
M:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB"FUS9W-T<B`B075T:%]C>7)S
M<6PZ($MO<'!L:6YG96X@<V%K;F%R(&9U;FMT:6]N97(@<V]M(&MRY'9S+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$R,B!L:6(O2&]R
M9&4O075T:"]C>7)U<RYP:'`Z,3(R"FUS9VED(")!=71H7V-Y<G5S.B!297%U
M:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?
M8WER=7,Z($E-05`M97AT96YS:6]N('-A:VYA<RXB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+V9T<"YP:'`Z,S8@;&EB+TAO<F1E+T%U=&@O9G1P+G!H<#HS
M-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92TB"B)F
M='`@<W=I=&-H+B(*;7-G<W1R(")!=71H7V9T<#H@1E10+71I;&SD9V<@<V%K
M;F%S+B!+;VUP:6QE<F$@4$A0(&UE9"!S=VET8VAE;B`M+65N86)L92UF='`N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HV-"!L:6(O2&]R
M9&4O075T:"]I;6%P+G!H<#HV-`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E
M9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:6UA
M<#H@24U!4"UE>'1E;G-I;VX@<V%K;F%S+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:W)B-2YP:'`Z-3$@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z-3$*
M;7-G:60@(D%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R(")!=71H7VMR8C4Z(&MR8C4M97AT96YS:6]N('-A
M:VYA<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,P,B!L
M:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@
M061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E
M8W1O<GDB"FUS9W-T<B`B075T:%]L9&%P.B!$970@9^5R(&EN=&4@871T(&SD
M9V=A('1I;&P@86YVY&YD87)E(&D@06-T:79E($1I<F5C=&]R>2(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S4W(&QI8B](;W)D92]!=71H
M+VQD87`N<&AP.C,U-PIM<V=I9"`B075T:%]L9&%P.B!296UO=FEN9R!U<V5R
M<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S
M='(@(D%U=&A?;&1A<#H@1&5T(&?E<B!I;G1E(&%T="!R861E<F$@86YVY&YD
M87)E(&9RY6X@06-T:79E($1I<F5C=&]R>2(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z-C,@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-C,*
M;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R(")!=71H7VQD87`Z($Q$05`M=&EL;.1G9R!S86MN
M87,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,SD@;&EB
M+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H
M870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B075T:%]L9&%P.B!+86X@
M:6YT92!LY&=G82!T:6QL(&%N=N1N9&%R92`G)7,G+B!397)V97)N('-V87)A
M9&4Z("(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S@U(&QI
M8B](;W)D92]!=71H+VQD87`N<&AP.C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R
M(")!=71H7VQD87`Z($MA;B!I;G1E(')A9&5R82!A;G;D;F1A<F4@)7,B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0Y.2!L:6(O2&]R9&4O
M075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L
M9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS9W-T<B`B075T:%]L
M9&%P.B!+86X@:6YT92!U<'!D871E<F$@86YVY&YD87)E("5S(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,#4@;&EB+TAO<F1E+T%U=&@O
M;&1A<"YP:'`Z-#`U"FUS9VED(")!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S
M(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN(@IM<V=S
M='(@(D%U=&A?;&1A<#H@1&5T(&?E<B!I;G1E(&%T="!U<'!D871E<F$@86YV
MY&YD87)E(&D@06-T:79E($1I<F5C=&]R>2XB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VUC86PN<&AP.C0V(&QI8B](;W)D92]!=71H+VUC86PN<&AP.C0V
M"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B075T:%]M8V%L.B!-0T%,+65X=&5N<VEO;B!S
M86MN87,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C8P(&QI
M8B](;W)D92]!=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T:#H@
M4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M(")!=71H7W-M8F%U=&@Z('-M8F%U=&@M97AT96YS:6]N('-A:VYA<RXB"@HC
M.B!L:6(O2&]R9&4O24U!4"]!9&UI;BYP:'`Z,3`V"FUS9VED(")!=71H96YT
M:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N(@IM<V=S='(@(D%U=&5N
M=&ES97)I;F<@=&EL;"!)34%0+7-E<G9E<B!M:7-S;'EC:V%D97,N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS9VED
M(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`B075T96YT:7-E<FEN
M9R!M:7-S;'EC:V%D97,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HV-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C8W(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I
M;&5D+B`E<R(*;7-G<W1R(")!=71E;G1I<V5R:6YG(&UI<W-L>6-K861E<RX@
M)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,3<V(&QI
M8B](;W)D92]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H96YT:6-A
M=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R(")!=71E
M;G1I<V5R:6YG(&%V=FES861E<R!A=B!2041)55,M<V5R=F5R;BXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@U,2!L:6(O5D93+V9T<"YP:'`Z
M.#@R"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE
M9"XB"FUS9W-T<B`B075T96YT:7-E<FEN9R!T:6QL($944"US97)V97(@;6ES
M<VQY8VMA9&5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-S`@
M;&EB+U9&4R]S;6(N<&AP.C<P"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!T
M:&4@4TU"('-E<G9E<B!F86EL960N(@IM<V=S='(@(D%U=&5N=&ES97)I;F<@
M=&EL;"!334(M<V5R=F5R(&UI<W-L>6-K861E<RXB"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C<U"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*
M;7-G<W1R(")4:6QL9^1N9VQI9V$@9N1L=#HB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8Q-`IM<V=I9"`B07=A:71I
M;F<@4F5S<&]N<V4B"FUS9W-T<B`B5N1N=&%R('#E('-V87(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4Y(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,0HC.B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C4@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D*
M;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B07IE<F)A:6IA;B(*"B,Z(&-O
M;F9I9R]T:&5M97,O87IU<BYP:'`Z.`IM<V=I9"`B07IU<B(*;7-G<W1R(")!
M>G5R8FSE(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"
M3T9(($5X8W5S97,B"FUS9W-T<B`B0D]&2"UU<G/D:W1E<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G
M:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`B0F%K9W)U;F0B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"86-K
M9W)O=6YD($-O;&]R(@IM<V=S='(@(D)A:V=R=6YD<V;D<F<B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@Q(&QI8B](;W)D92]!=71H+VMR
M8C4N<&AP.C@Q"FUS9VED(")"860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S
M='(@(D9E;&%K=&EG="!L]G-E;F]R9"!F]G(@2V5R8F5R;W,B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@S(&QI8B](;W)D92]!=71H+VMR
M8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S
M='(@(D9E;&%K=&EG="!A;G;D;F1A<FYA;6X@9O9R($ME<F)E<F]S(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#4*(SH@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(V(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8R"FUS9VED(")"86AA;6%S(@IM<V=S='(@(D)A:&%M87,B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Q(&QI8B](;W)D92].3%,O=&QD+G!H<#HS.`HC.B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*
M;7-G:60@(D)A:')A:6XB"FUS9W-T<B`B0F%H<F%I;B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@P"FUS9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*
M;7-G<W1R(")"86QT:7-K("A)4T\M.#@U.2TQ,RDB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HS-`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@
M(D)A;F=L861E<V@B"FUS9W-T<B`B0F%N9VQA9&5S:"(*"B,Z(&QI8B]";&]C
M:R]B87)T:6UE+G!H<#HT"FUS9VED(")"87(@5&EM92(*;7-G<W1R(")"87)T
M:60B"@HC.B!L:6(O0FQO8VLO8F%R=&EM92YP:'`Z,S4*;7-G:60@(D)A<B!T
M:6UE(@IM<V=S='(@(E)A9'1I9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C,S"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B
M"FUS9W-T<B`B0F%R8F%D;W,B"@HC.B!C;VYF:6<O=&AE;65S+V)A<F)I92YP
M:'`Z-@IM<V=I9"`B0F%R8FEE(@IM<V=S='(@(D)A<F)I92(*"B,Z('5T:6PO
M:6-O;E]B<F]W<V5R+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"87-E
M(&=R87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R
M(")"87-K871A;&]G("<E<R<@9O9R(&)I;&1E<B!H:71T861E<R!I;G1E+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW,PIM<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B0F%S;&EN:F4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8S(&QI8B](;W)D92].3%,O=&QD+G!H<#HT.0HC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C,*;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B5FET<GES<VQA;F0B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8P(&QI8B](;W)D92].3%,O=&QD+G!H<#HS-0HC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C`*;7-G:60@(D)E;&=I=6TB"FUS9W-T<B`B0F5L9VEE;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C,@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4P"B,Z(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HS,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PIM
M<V=I9"`B0F5L:7IE(@IM<V=S='(@(D)E;&EZ92(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C0P"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HS,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B
M0F5N:6XB"FUS9W-T<B`B0F5N:6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HT,0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)E<FUU9&$B
M"FUS9W-T<B`B0F5R;75D82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C0V"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-2!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S
M='(@(D)H=71A;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,3$*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(D;V9&5L<V5D86<B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S4R(&QI
M8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HS-C`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N
M;W0@9F]U;F0N(@IM<V=S='(@(D)L;V-K("<E<R<@9O9R(&%P<&QI:V%T:6]N
M("<E<R<@<V%K;F%S+B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN
M8SHY,`IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B0FQO8VMI;G-T
MY&QL;FEN9V%R(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<T
M"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@(D)L;V-K='EP(@H*(SH@8V]N
M9FEG+W1H96UE<R]B;'5E;6]O;BYP:'`Z-@IM<V=I9"`B0FQU92!-;V]N(@IM
M<V=S='(@(D)LY2!MY6YE(@H*(SH@8V]N9FEG+W1H96UE<R]B;'5E=VAI=&4N
M<&AP.C8*;7-G:60@(D)L=64@86YD(%=H:71E(@IM<V=S='(@(D)LY71T(&]C
M:"!V:71T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S='(@(D9E="(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HS-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0S"B,Z(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HS-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I
M9"`B0F]L:79I82(*;7-G<W1R(")";VQI=FEA(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(P-PIM<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@(D)O
M:VWD<FME;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C`*;7-G:60@(D)O<F1E<B(*;7-G<W1R(")286TB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@U"FUS
M9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G<W1R(")286UB<F5D9#HB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(Q"FUS9VED(")";W)D97)S(@IM<V=S='(@(E)A;6%R(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S(*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C,W(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS
M9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(D)O<VYI96X@
M;V-H($AE<GIE9V]V:6YA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV
M"FUS9VED(")";W1H(@IM<V=S='(@(D+E9&$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HT.`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O
M='-W86YA(@IM<V=S='(@(D)O='-W86YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")";W1T;VTB
M"FUS9W-T<B`B0F]T=&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,R!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-#<*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,Y(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V970@27-L86YD
M(@IM<V=S='(@(D)O=79E="!)<VQA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HT-`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R87II
M;"(*;7-G<W1R(")"<F%S:6QI96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,2!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3$W"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HT,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES
M:"!);F1I86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(D)R:71T:7-K82!T
M97)R:71O<FEE="!I($EN9&ES:V$@;V-E86YE;B(*"B,Z(&-O;F9I9R]T:&5M
M97,O8G)O=VXN<&AP.C8*;7-G:60@(D)R;W=N(@IM<V=S='(@(D)R=6XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8R(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,@HC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@(D)R=6YE
M:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C$@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,W"B,Z(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT,R!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B0G5L9V%R:65N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M.0IM<V=I9"`B0G5L;&5T960@3&ES="(*;7-G<W1R(")0=6YK=&QI<W1A(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S8*(SH@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C0T(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B0G5R:VEN82!&
M87-O(@H*(SH@8V]N9FEG+W1H96UE<R]B=7)N=&]R86YG92YP:'`Z.0IM<V=I
M9"`B0G5R;G0@3W)A;F=E(@IM<V=S='(@(D)RY&YD($]R86YG92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,SD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C$@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,Y"B,Z(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HT-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R(")"=7)U;F1I(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0T-@IM<V=I9"`B0TU3(@IM<V=S='(@(D--
M4R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S(@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*
M;7-G<W1R(")#4D,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4Y-R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y.`IM<V=I9"`B
M0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B0U),($1I<W1R:6)U
M=&EO;B!0;VEN=',B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N
M+BXB"FUS9W-T<B`B0U]E;&P@:6YS=.1L;&YI;F=A<BXN+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3$*;7-G:60@(D-A8VAE(&EN:70@
M=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@(D-A8VAE:6YI=&EE<FEN9R#D
M<B!I;G1E(&9U;&QS=.1N9&EG+B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-3D*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0X-2!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`T,`HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,34W"FUS9VED(")#86QE;F1A
M<B(*;7-G<W1R(")+86QE;F1E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,S4*;7-G:60@(D-A;&TB"FUS9W-T<B`B3'5G;G0B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(X"B,Z(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HT-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B2V%M8F]D:F$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8W(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,`HC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C<*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(DMA;65R=6XB"@HC.B!C;VYF
M:6<O=&AE;65S+V-A;6]U9FQA9V4N<&AP.C8*;7-G:60@(D-A;6]U9FQA9V4B
M"FUS9W-T<B`B2V%M;W5F;&%G92(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C(P"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M
M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R
M(")+86X@:6YT92!N;VQL<W3D;&QA(&SV<V5N;W)D(&%U=&]M871I<VMT+"!K
M;VYT86MT82!D:6X@861M:6YI<W1R873V<BXB"@HC.B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HS,3@@;&EB+T9I;&4O0U-6+G!H<#HS-3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W<FET92!T;R!F:6QE(%PB)7-<(B(*
M;7-G<W1R(")+86X@:6YT92!S:W)I=F$@=&EL;"!F:6P@)R5S)R(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HR,@IM<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E
M>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+B(*;7-G<W1R(")$970@9^5R(&EN
M=&4@871T(&%D;6EN:7-T<F5R82!E>'1E<FYA('-E<W-I;VYS:&%N=&5R87)E
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(S-2!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,S$Y"B,Z(&QI8B](;W)D92]!
M=71H+V-Y<G5S+G!H<#HR,S4@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HS
M,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0
M('-E<G9E<CH@)7,B"FUS9W-T<B`B2V%N(&EN=&4@:V]N=&%K=&$@24U!4"US
M97)V97)N.B`E<R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0Q
M,R!L:6(O1FEL92]#4U8N<&AP.C0T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M86XG="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")+86X@:6YT92#V<'!N
M82!F:6P@)R5S)R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C4Q"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT."!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V%N861A(@IM<V=S='(@(DMA
M;F%D82(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,2!A9&UI;B]U<V5R+G!H<#HQ
M,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT
M-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8U
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,2!T96UP
M;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O<F5M;W9E+FEN8SHQ,@IM<V=I9"`B0V%N8V5L(@IM<V=S='(@
M(D%V8G)Y="(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y
M"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B079B<GET
M('!R;V)L96UR87!P;W)T(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HS,3@@;&EB+U9&4R]F='`N<&AP.C,R,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")+86X@:6YT
M92!R861E<F$@)R5S)RXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2]C;W!Y+G!H<#HU,@HC.B!F<F%M97=O<FLO5D937TE33R])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#<*(SH@9G)A;65W;W)K
M+U9&4U])4T\O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H
M<#HU,PHC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HT-@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R
M871E9WDO8V]P>2YP:'`Z-3(*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M<&]R
M87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B2V%N(&EN=&4@:&ET=&$@96X@=&5M
M<'+D<B!M87!P+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<BYP:'`Z.3$@9G)A;65W;W)K+U9&4U])4T\O25-/5W)I=&5R+G!H<#HY
M-PHC.B!L:6(O5D93+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P
M<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T
M<B`B2V%N(&EN=&4@9F]R='/D='1A('5T86X@)VWE;&9I;"<M<&%R86UE=&5R
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$T(&QI8B]61E,O
M9G1P+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V
M92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")+86X@:6YT92!R861E<F$@
M;6%P<"`G)7,G+B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92YP
M:'`Z,3(X(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8X
M,`HC.B!L:6(O2&]R9&4O1&%T851R964N<&AP.C$R."!L:6(O2&]R9&4O1&%T
M851R964O<W%L+G!H<#HV.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T
M(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(DMA;B!I;G1E
M(')A9&5R83L@)60@8F%R;B!E>&ES=&5R87(N(@H*(SH@9G)A;65W;W)K+T1A
M=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X(&QI8B](;W)D92]$871A5')E
M92]S<6PN<&AP.C8P.`IM<V=I9"`B(@HB0V%N;F]T(')E;W)D97(L(&YU;6)E
M<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA
M=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B0V%N;F]T
M(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B
M2V%N(&EN=&4@9&ER:6=E<F$@;65D9&5L86YD92!T:6QL(&%N9VEV970@;G5M
M;65R+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C@@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8U"B,Z
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT.2!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV.`IM<V=I9"`B0V%P92!697)D92(*;7-G<W1R(")+87`@
M5F5R9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(T"FUS9VED(")#87!T:6]N(@IM<V=S='(@(E)U8G)I:R(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P
M-"!L:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R
M<FEE<B(*;7-G<W1R(")/<&5R873V<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY,PIM<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@
M(DMA=&5G;W)I97(@;V-H(')U8G)I:V5R(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$S-0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(D-A
M>6UA;B!)<VQA;F1S(@IM<V=S='(@(D-A>6UA;B!)<VQA;F1S(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L;"!0
M:&]N92(*;7-G<W1R(")-;V)I;'1E;&5F;VXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U"FUS9VED(")#96QL
M(%!R;W!E<G1I97,B"FUS9W-T<B`B0V5L;&EN<W3D;&QN:6YG87(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I
M9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R(")#96QL=71F>6QL;F%D.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R(")#96QL:6YS=.1L
M;&YI;F=A<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$R"FUS9VED(")#96QL('-P86-I;F<Z(@IM<V=S='(@(D-E;&QM
M96QL86YR=6TZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(W-"!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3(W.`IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S
M='(@(DUO8FEL=&5L969O;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q
M"FUS9VED(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*;7-G<W1R(")#96QT:7-K
M("A)4T\M.#@U.2TQ-"DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(V"FUS9VED(")#96YT97(B"FUS9W-T<B`B
M0V5N=')E<F%D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-30*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4Q(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P
M=6)L:6,B"FUS9W-T<B`B0V5N=')A;&%F<FEK86YS:V$@<F5P=6)L:6ME;B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS9VED(")#96YT<F%L($5U
M<F]P96%N("A)4T\M.#@U.2TR*2(*;7-G<W1R(")#96YT<F%L975R;W!E:7-K
M("A)4T\M.#@U.2TR*2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-CDY(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED
M(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(D-E<G1I9FEK871D971A
M;&IE<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C$Q
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C$R"FUS9VED(")#97)T:69I
M8V%T92!/=VYE<B(*;7-G<W1R(")#97)T:69I:V%TY&=A<F4B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B
M"FUS9W-T<B`B0V5R=&EF:6MA='!O;&EC:65S(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,C$*(SH@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C4R(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.`IM<V=I
M9"`B0VAA9"(*;7-G<W1R(")48VAA9"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3DV"FUS9VED(")#:&%I<B!097)S
M;VXB"FUS9W-T<B`B3W)D9O9R86YD92(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*
M;7-G:60@(D-H86YG92(*;7-G<W1R("+$;F1R82(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HS,0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O
M<F0B"FUS9W-T<B`BQ&YD<F$@9&ET="!L]G-E;F]R9"(*"B,Z('1E;7!L871E
M<R]P<F5F<R]C:&%N9V5D969A=6QT:61E;G1I='DN:6YC.C$S"FUS9VED(")#
M:&%N9V4@9&5F875L="!I9&5N=&ET>2(*;7-G<W1R("+$;F1R82!F]G)V86QD
M(&ED96YT:71E="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.0IM<V=I
M9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE
M('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I
M;',N(@IM<V=S='(@(B(*(L1N9')A(&YA;6X@;V-H(&%D<F5S<R!S;VT@;6]T
M=&%G87)N82!S97(@;N1R(&1E(&SD<V5R(&]C:"!S=F%R87(@<.4@9&EN82`B
M"B)M961D96QA;F1E;BXB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z,C0*;7-G:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T
M('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B
M"B)#;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB071T
M(&)Y=&$@;/9S96YO<F0@<W3V9',@:6YT92!M960@9&5N(&YU=F%R86YD92!K
M;VYF:6=U<F%T:6]N96XN("!687(@9V]D("(*(FMO;G1A:W1A(&%D;6EN:7-T
M<F%T]G)E;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(W"FUS9VED(")#:&%R(@IM<V=S='(@(E1K;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`B2V]N=')O;&QE
M<F$@;.1N:RXN+B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M
M7W1O<"YI;F,Z,3,*;7-G:60@(D-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R
M871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N(@IM
M<V=S='(@(DUA<FME<F$@9&4@86MT:79I=&5T97(@9'4@=FEL;"!U=&;V<F$@
M;G4N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3D*(SH@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4S(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8W"FUS9VED(")#:&EL92(*;7-G<W1R(")#:&EL92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C<@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8Q"B,Z(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HU-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV-PIM<V=I9"`B0VAI;F$B"FUS9W-T<B`B2VEN82(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#:&EN97-E(%-I;7!L:69I960@*$="
M,C,Q,BDB"FUS9W-T<B`B2VEN97-I<VMT(&;V<F5N:VQA="`H1T(R,S$R*2(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@T"FUS9VED(")#:&EN97-E(%1R
M861I=&EO;F%L("A":6<U*2(*;7-G<W1R(")+:6YE<VES:W0@=')A9&ET:6]N
M96QL="`H0FEG-2DB"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHW"FUS
M9VED(")#:&]O<V4@07!P;&EC871I;VXZ(@IM<V=S='(@(E;D;&H@87!P;&EK
M871I;VXZ(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V
M.2!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(W,`IM<V=I9"`B0VAO;W-E
M(&$@<&%S<W=O<F0B"FUS9W-T<B`B5N1L:B!L]G-E;F]R9"(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C@@;&EB+TAO<F1E+T%U=&@O
M4VEG;G5P+G!H<#HR-CD*;7-G:60@(D-H;V]S92!A('5S97)N86UE(@IM<V=S
M='(@(E;D;&H@86YVY&YD87)N86UN(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HT-3(*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV,C8*;7-G:60@(D-H;V]S92!A
M;B!A8W1I;VXZ(@IM<V=S='(@(E;D;&H@Y71GY')D.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS,#(*;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES<&QA
M>2!D871E<SHB"FUS9W-T<B`B5N1L:B!H=7(@9&%T=6T@<VMA;&P@=FES87,Z
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R
M(&]R9&5R960@;&ES=',I(@IM<V=S='(@(E;D;&H@;&ES='-T:6P@*&;V<B!S
M;W)T97)A9&4@;&ES=&]R*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C8V"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-2!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES
M;&%N9"(*;7-G<W1R(")*=6SV;B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4RYP:'`Z,CDT(&9R86UE=V]R:R]61E,O5D93+G!H<#HX.30@;&EB+U9&4RYP
M:'`Z.3$T"B,Z(&QI8B].970O4TU3+G!H<#HR.30*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S
M='(@(DML87-S9&5F:6YI=&EO;B!F]G(@)7,@<V%K;F%S+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS9VED(")#;&5A
M<B(*;7-G<W1R(")296YS82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E('1A9W,B
M"FUS9W-T<B`B4F5N<V$@35-/9F9I8V4M=&%G9V%R(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C$R.`IM<V=I9"`B0VQE87(@475E<GDB"FUS9W-T<B`B4F5N
M<V$@9G+E9V$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS
M9W-T<B`B4F5N<V$@86YVY&YD87)E.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V-L96%R+FEN8SHQ,0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R
M(")296YS82!A;G;D9&YA<F4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L
M:7-T+FEN8SHS-`IM<V=I9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@(E)E
M;G-A(&%N=N1N9&%R9&%T82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$U"FUS9VED(")#;&5A<FEN9R!,871E(@IM<V=S='(@
M(E-E;F%R92!U<'!K;&%R;F%N9&4B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N
M8V4O;F]T:6-E7V)O='1O;2YI;F,Z-@HC.B!T96UP;&%T97,O;6%I;G1E;F%N
M8V4O;6%I;G1E;F%N8V4N:'1M;#HV,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN
M=64B"FUS9W-T<B`B2VQI8VMA(&;V<B!A='0@9F]R='/D='1A(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS9VED(")#
M;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(D-L:6-K871E;&P@=FEA($A4
M5%`B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R
M(")3=.1N9R!F]FYS=&5R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3$*
M;7-G:60@(D-L;W5D<R(*;7-G<W1R(")-;VQN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*;7-G:60@(D-L;W5D<R!%87)L
M>2(*;7-G<W1R(")4:61I9V$@;6]L;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$W"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B
M36]L;FEN9W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8T(&QI8B](;W)D92].3%,O=&QD+G!H<#HU
M,@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-38@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA
M;F1S(@IM<V=S='(@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR,PIM<V=I9"`B0V]L;&%P<V4@
M4VED96)A<B(*;7-G<W1R(")+;VUP<FEM97)A('-I9&]FY&QT970B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(X
M"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G<W1R(")+;VUP<FEM97)A
M9&4@<F%M87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8W(&QI8B](;W)D92].3%,O=&QD+G!H<#HV
M,@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(DMO
M;&]M8FEA(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO8VLO
M8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@(D;D<F<B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(S
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C0*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0W-2!L
M:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S,Q"B,Z(&QI8B](;W)D
M92]";&]C:R]#;VQL96-T:6]N+G!H<#HS,S(@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C4P,PHC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P
M:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B1N1R
M9VAA;G1E<F%R92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X-#8@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(X,S(*;7-G:60@(D-O;&]U<B!S96QE8W1I
M;VXB"FUS9W-T<B`B1N1R9W9A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R(")+
M;VQU;6YE<CHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30V(&QI
M8B](;W)D92]&;W)M+G!H<#HQ.34P"FUS9VED(")#;VQU;6X@=&ET;&5S(@IM
M<V=S='(@(DMO;'5M;B!R=6)R:6ME<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR-C8*;7-G:60@(D-O;6EC<R(*;7-G<W1R("),=7-T:6=H971E
M<B(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-0IM<V=I9"`B0V]M;6%N9"(*
M;7-G<W1R(")+;VUM86YD;R(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR,`IM
M<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R(")+;VUM86YD;V;V;G-T97(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,#(@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")#;VUM96YT(@IM<V=S='(@
M(DMO;6UE;G1A<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-38V(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-38W"FUS9VED(")#
M;VUM;VX@3F%M92(*;7-G<W1R(").86UN(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$S,`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(D-O
M;6]R;W,B"FUS9W-T<B`B0V]M;W)O<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR,SD*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`B1O9R
M971A9R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-CDW"FUS9VED(")#;VUP;&5T960B"FUS9W-T<B`B4VQU=&;V<F0B
M"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z
M.#$*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP
M.C@W"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H
M<#HY-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP
M:'`Z,3`Q"B,Z(&9R86UE=V]R:R]497AT+U1E>'0O1FEL=&5R+V5M86EL<RYP
M:'`Z.#(*(SH@9G)A;65W;W)K+U1E>'0O5&5X="]&:6QT97(O96UA:6QS+G!H
M<#HX.`HC.B!F<F%M97=O<FLO5&5X="]497AT+T9I;'1E<B]E;6%I;',N<&AP
M.CDX"B,Z(&9R86UE=V]R:R]497AT+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z
M,3`R"B,L('!H<"UF;W)M870*;7-G:60@(D-O;7!O<V4@365S<V%G92`H)7,I
M(@IM<V=S='(@(E-K<FEV(&UE9&1E;&%N9&4@*"5S*2(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(D1A
M=&]R97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@V"FUS
M9VED(")#;VYD:71I;VXB"FUS9W-T<B`B5N1D97(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(U-@IM<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R(")6Y&1E
M<B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U
M<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S='(@(DMO;F9I9W5R871I;VYS<VMI
M;&QN861E<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#8*;7-G:60@
M(D-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H
M;VYE<R!A;F0@3W5T;&]O:RXB"FUS9W-T<B`B(@HB26YS=.1L;&YI;F=A<B!F
M]G(@871T('-Y;FMR;VYI<V5R82!M960@:&%N9&1A=&]R97(L('-M87)T82!T
M96QE9F]N97(@;V-H("(*(D]U=&QO;VLB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3,U"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E
M+B(*;7-G<W1R(")+;VYF:6=U<F%T:6]N(&)E:/9V97(@=7!P9&%T97)A<RXB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`P"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R(")+;VYF:6=U<F5R82`E<R(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-3$*;7-G:60@
M(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B0F5K<N1F=&$@;/9S96YO<F0B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8V(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-0HC.B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C8*;7-G:60@(D-O;F=O(@IM<V=S='(@(DMO;F=O(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3,*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C8P(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8U
M"FUS9VED(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE
M(@IM<V=S='(@(DMO;F=O(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,Q,"!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,3DW"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#@*;7-G
M:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R(")&]G)B:6YD96QS92!M
M:7-S;'EC:V%D97,N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,Q,"!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DW
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#@*;7-G:60@
M(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`B1O9R8FEN9&5L<V4@;6ES
M<VQY8VMA9&5S.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HW-SD@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-SDP"FUS9VED(")#;VYN
M96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S
M='(@(D;V<F)I;F1E;'-E(&UE9"!P=6)L:6L@;GEC:V5L<V5R=F5R(&YE:V%D
M97,N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S@Q(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C<Y,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N
M(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R(")&]G)B:6YD96QS92!M960@<'5B
M;&EK(&YY8VME;'-E<G9E<B!N96MA9&5S.B`E<R`H)7,I(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HX-#4@;&EB+U9&4R]F='`N<&AP.C@W-@IM
M<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T
M<B`B1O9R8FEN9&5L<V4@;65D($944"US97)V97(@;6ES<VQY8VMA9&5S+B(*
M"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#8W"FUS9VED(")#;VYT86-T
M<R(*;7-G<W1R(")+;VYT86MT97(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z-3,@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@
M861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(DMO;G1A:W1E
M<B!L861E<R!T:6QL(&D@9&EN(&%D<F5S<V)O:RXB"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=&=Z+G!H<#HV,`IM<V=I9"`B0V]N=&5N="!T>7!E(&]F
M(&-O;7!R97-S960@9FEL93H@(@IM<V=S='(@(DEN;F5HY6QL<W1Y<"!F]G(@
M:V]M<')I;65R860@9FEL.B`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C4V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-C`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H
M<#HW."!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HU-@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV,R!L:6(O2&]R9&4O34E-12]6
M:65W97(O=&=Z+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT
M<R!O9B!<(B5S7"(B"FUS9W-T<B`B26YN96CE;&P@:2`G)7,G(@H*(SH@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C,S"FUS9VED(")#;VYT:6YU92(*;7-G<W1R(")&;W)T<^1T
M="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C8@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4X"B,Z(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,2!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV-@IM<V=I9"`B0V]O:R!)<VQA;F1S(@IM<V=S='(@(D-O;VL@
M27-L86YD<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B
M0V]O:VEE(@IM<V=S='(@(D-O;VMI92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0IM<V=I9"`B0V]P>2(*
M;7-G<W1R(")+;W!I97)A(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HT-C@@;&EB+U9&4R]S;6(N<&AP.C0W,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`B2V]P:65R:6YG(&UI<W-L>6-K
M861E<SH@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R(")+;W!I
M97)A(&UA<FME<FEN9R(*"B,Z(&-O;F9I9R]T:&5M97,O8V]R;F9L;W=E<BYP
M:'`Z-@IM<V=I9"`B0V]R;F9L;W=E<B(*;7-G<W1R(")-86IS8FQO;6UA(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-S`*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.34@;&EB+TYE
M="]335,O=VEN7VAT='`N<&AP.C$W,`HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T
M<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S='(@(DMO<W1N861S+4E$
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C,*(SH@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8R(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8W"FUS9VED(")#;W-T82!2:6-A(@IM<V=S='(@(D-O<W1A(%)I
M8V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8V(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-PHC.B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C8*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B16QF
M96YB96YS:W5S=&5N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z.34V"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92XB
M"FUS9W-T<B`B2V%N(&EN=&4@4$=0+6MR>7!T97)A(&UE9&1E;&%N9&4N(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.3<W"FUS9VED(")#;W5L9"!N
M;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@(@IM<V=S='(@(DMA;B!I;G1E(%!'
M4"UK<GEP=&5R82!M961D96QA;F1E.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,#,S"FUS9VED(")#;W5L9"!N;W0@4$=0('-I9VX@
M;65S<V%G92XB"FUS9W-T<B`B2V%N(&EN=&4@4$=0+7-I9VYE<F$@;65D9&5L
M86YD92XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#4U"FUS9VED
M(")#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G93H@(@IM<V=S='(@(DMA;B!I
M;G1E(%!'4"US:6=N97)A(&UE9&1E;&%N9&4Z("(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,SDS(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z,SDS"FUS9VED(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S
M<V%G92XB"FUS9W-T<B`B2V%N(&EN=&4@4R]-24U%+6MR>7!T97)A(&UE9&1E
M;&%N9&4N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT
M-C<@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD
M(&YO="!3+TU)344@<VEG;B!M97-S86=E+B(*;7-G<W1R(")+86X@:6YT92!3
M+TU)344M<VEG;F5R82!M961D96QA;F1E+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R(")+86X@:6YT92!L
MY&=G82!T:6QL(&MO;G1A:W0N("5S(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.CDV(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M,3(Q"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HY-B!L:6(O2&]R9&4O
M075T:"]L9&%P+G!H<#HQ,C$*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0U
M-PIM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S
M='(@(DUI<W-L>6-K861E<R!A='0@:V]N=&%K=&$@3$1!4"!S97)V97(N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ
M-38*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,3<S"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S
M='(@(DMA;B!I;G1E('9E<FEF:65R82!K;VYT;W-A;&1O+B`E<R(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HT-#$*;7-G:60@(D-O=6QD(&YO="!C;VYN
M96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(")+=6YD92!I;G1E(&%N<VQU
M=&$@=&EL;"!,1$%0+7-E<G9E<BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@
M=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(DMA;B!I
M;G1E(&MO;G1A:W1A('-E<G9E<B`G)7,G('9I82!&5%`Z("5S(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<R(*;7-G<W1R(")+86X@:6YT92!S:V%P82!D:7-T<FEB=71I;VYS;&ES
M=&$N("5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$P
M-0IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N(@IM<V=S='(@
M(DMA;B!I;G1E(&1E:W)Y<'1E<F$@4$=0+61A=&$N(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z,3$R.`IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@
M4$=0(&1A=&$Z("(*;7-G<W1R(")+86X@:6YT92!D96MR>7!T97)A(%!'4"UD
M871A.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R
M,B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4R,PIM<V=I9"`B0V]U;&0@
M;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(DMA;B!I;G1E(&1E
M:W)Y<'1E<F$@4R]-24U%+61A=&$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C(T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@9&5L971E(&-O;G1A8W0N("5S(@IM<V=S='(@(DMA;B!I;G1E(')A
M9&5R82!K;VYT86MT+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B2V%N(&EN
M=&4@<F%D97)A(&1I<W1R:6)U=&EO;G-L:7-T82X@)7,B"@HC.B!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS
M9W-T<B`B2V%N(&EN=&4@<F%D97)A('5P<&=R861E<FEN9W-S8W)I<'0@=&EL
M;#H@)7,N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS
M.#$@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3,X"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z,S@Q(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.CDU,PIM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I
M96YT)W,@92UM86EL(&%D9')E<W,N(@IM<V=S='(@(DMA;B!I;G1E(&)E<W3D
M;6UA(&UO='1A9V%R96YS(&50;W-T+6%D<F5S<RXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PHC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#;W5L9"!N;W0@
M9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R(")+86X@:6YT
M92!HY&UT82!K;VUP;&5T="!A9')E<W-B;VLN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PIM<V=I9"`B0V]U;&0@;F]T(&9E
M=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(")+86X@
M:6YT92!HY&UT82!K;VUP;&5T="!D:7-T<FEB=71I;VYS;&ES=&$N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I9"`B
M0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U
M=&EO;B!L:7-T<RXB"FUS9W-T<B`B2V%N(&EN=&4@:.1M=&$@:V]M<&QE='0@
M;&ES=&$@]G9E<B!D:7-T<FEB=71I;VYS;&ES=&]R+B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN
M<&AP.C8X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2YP:'`Z.#0*(SH@;&EB+U9&4R])4T]7<FET97(O
M4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.`HC.B!L:6(O5D93+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R(")+
M86X@:6YT92!L861D82!S=')A=&5G:2`G)7,G+B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8Y"B,Z
M(&9R86UE=V]R:R]61E-?25-/+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2YP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@
M<W1R871E9WD@)R5S)RXB"FUS9W-T<B`B2V%N(&EN=&4@;&%D9&$@<W1R871E
M9VD@)R5S)RXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO
M9&ER96-T+G!H<#HS,`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EN
M=&4@<VMA<&$@;6%P<"`G)7,G+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3$*(SH@9G)A
M;65W;W)K+U9&4U])4T\O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]D
M:7)E8W0N<&AP.C,Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!M
M:V1I<B`G)7,G+B(*;7-G<W1R(")+86X@:6YT92!S:V%P82!M87!P("<E<R<N
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S`X(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C<Q.0IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I
M;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`B2V%N
M(&EN=&4@:.1M=&$@<'5B;&EK(&YY8VME;"!F<N5N(&YY8VME;'-E<G9E<FXN
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC.B!L:6(O5D93+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*
M;7-G<W1R(")+86X@:6YT92#V<'!N82`G)7,G(&;V<B!S:W)I=FEN9RXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W
M-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR
M-C(@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W-PHC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-2!L:6(O3F5T+U--4R]W
M:6Y?:'1T<"YP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!O<&5N("5S+B(*;7-G<W1R(")+86X@:6YT92#V<'!N82`E<RXB"@HC.B!F
M<F%M97=O<FLO5D937TE33R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z,30P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O
M<&5N("<E<R<@9F]R('=R:71I;F<N(@IM<V=S='(@(DMA;B!I;G1E(/9P<&YA
M("<E<R<@9O9R('-K<FEV:6YG+B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC
M92]-86EN=&5N86YC92YP:'`Z-#$X(&QI8B](;W)D92]-86EN=&5N86YC92YP
M:'`Z-#(P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N($UA
M:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(DMA;B!I;G1E(/9P
M<&YA($UA:6YT96YA;F-E7U1A<VL@;6]D=6P@)7,B"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z-S`*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EN=&4@]G!P
M;F$@;6%P<&5N("<E<R<B"@HC.B!F<F%M97=O<FLO5D937TE33R])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y("<E<R<N(@IM<V=S
M='(@(DMA;B!I;G1E(/9P<&YA(&UA<'`@)R5S)R(*"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3$@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C$T-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,C,W(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C4Q-B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HV-38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C8Y.0HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,3$Q(&QI8B](
M;W)D92]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@;&EB+TAO<F1E+T=R;W5P+VQD
M87`N<&AP.C(S-R!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-#<X"B,Z(&QI
M8B](;W)D92]'<F]U<"]L9&%P+G!H<#HU,38@;&EB+TAO<F1E+T=R;W5P+VQD
M87`N<&AP.C8Q,@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-C4V(&QI
M8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV.3D*;7-G:60@(D-O=6QD(&YO="!R
M96%C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(DMA;B!I;G1E(&MO;G1A
M:W1A($Q$05`@<V5R=F5R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+T]B:F5C
M="YP:'`Z,C,X(&QI8B]61E,O3V)J96-T+G!H<#HR-#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S='(@(DMA;B!I;G1E
M(&SD<V$@)7,N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*
M;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H
M92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I
M;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R
M(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*
M;7-G<W1R("(B"B)$970@9VEC:R!I;G1E(&%T="#E=&5R<W3D;&QA(&SV<V5N
M;W)D970@9O9R(&1E;B!A;F=I=FYA(&%N=N1N9&%R96XN($[E9V]N("(*(F5L
M;&5R(&[E9W)A(&%V('5P<&=I9G1E<FYA(.1R(&EN=&4@:V]R<F5K=&$N($;V
M<G/V:R!I9V5N(&5L;&5R(&MO;G1A:W1A("(*(F%D;6EN:7-T<F%T]G)E;B!O
M;2!D=2!B96CV=F5R(&AJY&QP+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,P.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS-#`*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S<W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,X,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS.#D@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P
M-PHC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S,X(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S4*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,X,2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S@W"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM
M<V=S='(@(DMA;B!I;G1E(&CD;71A($%#3"(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,B"FUS9W-T<B`B
M2V%N(&EN=&4@:.1M=&$@861R97-S8F]K+B`E<R(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*
M;7-G<W1R(")+86X@:6YT92!HY&UT82!D:7-T<FEB=71I;VYS;&ES=&$N("5S
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HT,S<*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0S-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I
M8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R(")+86X@:6YT92!HY&UT82!D:7-T
M<FEB=71I;VYS;&ES=&]R+B`E<R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,C(S(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HQ.3<*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q-R!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(Q"FUS9VED(")#;W5L
M9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@
M(DMA;B!I;G1E(&CD;71A(&1S97)V97)F=6YK=&EO;F5R(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HU-`IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")+86X@:6YT92#E=&5R<W3D;&QA(&MO
M;F9I9W5R871I;VYE;BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*(SH@;&EB
M+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER(%PB)7-<(BXB
M"FUS9W-T<B`B2V%N(&EN=&4@<F%D97)A(&UA<'`@)R5S)RXB"@HC.B!F<F%M
M97=O<FLO5D937TE33R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER
M("<E<R<N(@IM<V=S='(@(DMA;B!I;G1E(')A9&5R82!M87!P("<E<R<N(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B2V%N(&EN=&4@<W!A<F$@:V]N9FEG=7)A=&EO;B!F]G(@)7,N(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C4Y"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U
M871I;VXN(@IM<V=S='(@(DMA;B!I;G1E('-P87)A(&)A8VMU<"UK;VYF:6=U
M<F%T:6]N+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U
M871I;VXZ("5S(@IM<V=S='(@(DMA;B!I;G1E('-P87)A(&5N(&)A8VMU<"UK
M;VYF:6=U<F%T:6]N.B`E<RXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HY-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U
M<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(")+86X@:6YT
M92!S<&%R82!U<'!G<F%D97)I;F=S<V-R:7!T('1I;&PZ("5S+B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N(@IM<V=S='(@(DMA;B!I;G1E('-P87)A(&)A8VMU<"UK;VYF:6=U<F%T
M:6]N("5S+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R
M871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@
M(@HB;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P
M>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B(@HB
M2V%N(&EN=&4@<W!A<F$@:V]N9FEG=7)A=&EO;G-F:6QE;B`E<RX@1'4@:V%N
M(&%N=&EN9V5N(&%N=N1N9&$@96X@878@(@HB86QT97)N871I=F5N(&%T="!S
M<&%R82!K;V1E;B!T:6QL("5S(&5L;&5R(&MO<&EE<F$@:V]D96X@;F5D86X@
M=&EL;"`E<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$T
M,R!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ-#,*;7-G:60@(D-O=6QD(&YO
M="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R(")+86X@:6YT92!S
M]FMA(&D@3$1!4"UK871A;&]G96XN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V
M"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C@V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@
M7"(E<UPB+B(*;7-G<W1R(")+86X@:6YT92!R861E<F$@)R5S)RXB"@HC.B!F
M<F%M97=O<FLO5D937TE33R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N
M;&EN:R`G)7,G+B(*;7-G<W1R(")+86X@:6YT92!R861E<F$@)R5S)RXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(Q
M.0HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B
M"FUS9W-T<B`B2V%N(&EN=&4@=7!P9&%T97)A(&MO;G1A:W0N("5S(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<R(*;7-G<W1R(")+86X@:6YT92!U<'!D871E<F$@9&ES=')I8G5T
M:6]N<VQI<W1A+B`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A
M=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G<W1R(")+86X@:6YT82!S<&%R82!K
M;VYF:6=U<F%T:6]N(&;V<B`G)7,G.B`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-S`*;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@
M4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM<V=S
M='(@(DMA;B!I;G1E(&AI='1A($UO>FEL;&%S('-I9&]FY&QT+B!697)I9FEE
M<F$@871T('-I9&]FY&QT970@Y'(@]G!P970N(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HQ-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U
M;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F
M;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S(@IM<V=S='(@(DMA;B!I;G1E(&=E
M(&%N=N1N9&%R96X@)R5S)R!A;F=I=FYA('+D='1I9VAE=&5R('1I;&P@;6%P
M<&5N("<E<R<Z("5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q
M.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R,PIM<V=I9"`B0V]U;G1E9"!T97AT
M(@IM<V=S='(@(E+D:VYA9"!T97AT(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-CD@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M-S`*;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`B3&%N9"(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR-S4*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B
M2W5R<V5R(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B4VMA
M<&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T92!A(&QI;FLB"FUS9W-T<B`B4VMA
M<&$@;.1N:R(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI
M;F,Z.30*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`B4VMA<&$@
M;GDB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M,B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3(*(SH@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR"FUS9VED(")#<F5A=&4@<W5B
M(&9O;&1E<G,B"FUS9W-T<B`B4VMA<&$@=6YD97)M87!P(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-#`@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HR-#`*;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B
M0F5H]G)I9VAE=&5R(&;V<B#D9V%R82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,R,S`@;&EB+TAO<F1E+T9O<FTN<&AP.C,R,38*;7-G:60@(D-R
M961I="!C87)D(&YU;6)E<B(*;7-G<W1R(")+<F5D:71K;W)T<VYU;6UE<B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<Y(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#D*(SH@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8T(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<Y"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(DMR;V%T:65N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV."!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C0*(SH@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C8U(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8X"FUS9VED(")#=6)A(@IM<V=S='(@(DMU8F$B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,C8*;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T
M<B`B06MT=65L;&$@-"!F87-E<B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU
M,`IM<V=I9"`B0W5R<F5N="!397-S:6]N<R(*;7-G<W1R(")!:W1U96QL('-E
M<W-I;VXB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,R!L:6(O0FQO8VLO=&EM
M92YP:'`Z,S`*;7-G:60@(D-U<G)E;G0@5&EM92(*;7-G<W1R(")!:W1U96QL
M('1I9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T<B`B
M06MT=65L;"!54DP@Y'(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S4*;7-G
M:60@(D-U<G)E;G0@57-E<G,B"FUS9W-T<B`B06MT:79A(&%N=N1N9&%R92(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U<G)E;G0@5V5A
M=&AE<B(*;7-G<W1R(")!:W1U96QL="!VY&1E<B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-C0*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N
M.B`B"FUS9W-T<B`B06MT=65L;&$@=FEL;&MO<CH@(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N
M="!S='EL92(*;7-G<W1R(")!:W1U96QL('-T:6PB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3$Q"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ
M92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B4VMR
MY&1D87)S>2!A:W1I=FET971E<B!S;VT@:_9R<R!V:60@:6YL;V=N:6YG('1I
M;&P@)7,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`B2VQI<'`@=70B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,U
M"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(DML:7!P('5R=F%L(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV."!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C<*(SH@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C8V(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8X"FUS9VED(")#>7!R=7,B"FUS9W-T<B`B0WEP97)N(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#4*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I
M(@IM<V=S='(@(DMY<FEL;&ES:R`H2T])."U2*2(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@V"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*
M;7-G<W1R(")+>7)I;&QI<VL@*%=I;F1O=W,M,3(U,2DB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X-PIM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+
M3TDX+54I(@IM<V=S='(@(DMY<FEL;&ES:R]5:W)A:6YS:R`H2T])."U5*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-CD@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8X"B,Z(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HV-R!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV.0IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS9W-T<B`B5&IE8VMI
M96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#(V"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-3(@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(D1$
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,"!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,S(W-@IM<V=I9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N
M<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD
M<VXN<&AP*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O
M36%I;G1E;F%N8V4N<&AP.C4Y(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z
M-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(D1A9VQI9R(*"B,Z(&%D;6EN+V1A
M=&%T<F5E+G!H<#HV-0IM<V=I9"`B1&%T851R964@0G)O=W-E<B(*;7-G<W1R
M(")$871A5')E92!B;.1D9')A<F4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,C<X(&QI8B](;W)D92]&;W)M+G!H<#HS,C<T"FUS9VED(")$871A
M8F%S92!,;V]K=7`B"FUS9W-T<B`B1&%T86)A<W5P<'-L86<B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(S.3D*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(T
M,#(@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(*;7-G:60@
M(D1A=&4B"FUS9W-T<B`B1&%T=6TB"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E:79E9"(*;7-G<W1R
M(")$871U;2!M;W1T86=E="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,#<@;&EB+TAO<F1E+T9O<FTN<&AP.C(W.3,*;7-G:60@(D1A=&4@<V5L
M96-T:6]N(@IM<V=S='(@(D1A='5M=F%L(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(X,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S$Q"FUS9VED(")$87DB"FUS9W-T<B`B1&%G(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,V"FUS9VED(")$
M95]L971E($-O;'5M;B(*;7-G<W1R(")?4F%D97)A(&MO;'5M;B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS.#@*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0R-0HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-3$*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@IM<V=I9"`B1&5C96UB97(B"FUS
M9W-T<B`B9&5C96UB97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L:7-T='EP95]L86YG+FIS.C$V"FUS9VED(")$96-I;6%L(&YU;6)E
M<G,B"FUS9W-T<B`B1&5C:6UA;&5R(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HV.#4*;7-G:60@(D1E8VQI;F5D(@IM
M<V=S='(@(D%V8O9J="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C`*;7-G:60@(D1E8W)E87-E($EN9&5N="(*;7-G<W1R
M(")-:6YS:V$@:6YD<F%G(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HQ.#<@;&EB+W!R969S+G!H<#HQ,3<*(SH@;&EB+TAO<F1E+U!R969S
M+U5)+G!H<#HQ.#<*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B1O9R=F%L="(*
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0U
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C<W
M"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(D;V<G9A;&0@9N1R9R(*
M"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z.3$@;&EB+TAO
M<F1E+TED96YT:71Y+G!H<#HY-@IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*
M;7-G<W1R(")&]G)V86QD(&ED96YT:71E="(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HV-PIM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R(")&]G)V
M86QT('-K86PB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@
M(D1E9FEN:71I;VYS(@IM<V=S='(@(D1E9FEN:71I;VYE<B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C0S"FUS9VED
M(")$96QE9V%T92!P;W-I=&EO;B(*;7-G<W1R(")$96QE9V5R82!P;W-I=&EO
M;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z-CDS"FUS9VED(")$96QE9V%T960B"FUS9W-T<B`B1&5L96=E<F%D(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HW,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C,R-@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0S.0HC.B!F<F%M97=O<FLO
M3&EN:W,O3&EN:W,N<&AP.C(V,PHC.B!F<F%M97=O<FLO4F5L871I;VYS:&EP
M+U)E;&%T:6]N<VAI<$UA;F%G97(N<&AP.C(U."!L:6(O2&]R9&4O4&5R;7,N
M<&AP.C,R-@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C0R,B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C,V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$Q-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,"!T96UP
M;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM
M<V=S='(@(E)A9&5R82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@IM<V=I9"`B1&5L971E($-E;&PB"FUS
M9W-T<B`B4F%D97)A(&-E;&PB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y.2!A
M9&UI;B]G<F]U<',N<&AP.C(R-PIM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S
M='(@(E)A9&5R82!G<G5P<"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(T.0IM<V=I9"`B1&5L971E($QO9R(*;7-G<W1R(")2861E<F$@;&]G
M9R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S<@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#$*(SH@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HW-R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$P,0IM<V=I9"`B
M1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B4F%D97)A(&)E:/9R:6=H970B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,R!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E;&5T
M92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B4F%D97)A(&]C:"!R96YS
M82!M961D96QA;F1E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3<*;7-G:60@(D1E;&5T92!C96QL(@IM<V=S
M='(@(E)A9&5R82!C96QL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E(&-O;'5M;B(*
M;7-G<W1R(")2861E<F$@:V]L=6UN(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H
M<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA
M=&4B"FUS9W-T<B`B4F%D97)A(&)E9FEN=&QI9R!A;'1E<FYA=&EV;6%L;"(*
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HU-`IM<V=I9"`B
M1&5L971E(&UE<W-A9V5S(@IM<V=S='(@(E)A9&5R861E(&UE9&1E;&%N9&5N
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C$@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L
M971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B4F%D97)A(&)E
M:/9R:6=H970@9O9R("<E<R<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C0R-"!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C0R-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B!A
M;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T<B`B4F%D97)A(&)E:/9R
M:6=H970@9O9R("<E<R<@;V-H('5N9&5R8F5H]G)I9VAE=&5R/R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*
M;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T<B`B4F%D97)A(')A9"(*"B,Z('1E
M;7!L871E<R]P<F5F<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E
M;&5T92!S96QE8W1E9"!I9&5N=&ET>2(*;7-G<W1R(")2861E<F$@=F%L9"!I
M9&5N=&ET970B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z
M-3,*;7-G:60@(D1E;&5T92!S=6(@9F]L9&5R<R(*;7-G<W1R(")2861E<F$@
M=6YD97)M87!P87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N
M="!C;VQU;6XB"FUS9W-T<B`B4F%D97)A(&%K='5E;&P@:V]L=6UN(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8S"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM<V=S='(@(E)A
M9&5R82!A:W1U96QL(')A9"(*"B,Z(&9R86UE=V]R:R],:6YK<R],:6YK<RYP
M:'`Z,C8S"B,Z(&9R86UE=V]R:R]296QA=&EO;G-H:7`O4F5L871I;VYS:&EP
M36%N86=E<BYP:'`Z,C4X"FUS9VED(")$96QE=&4@=&AI<R!L:6YK(@IM<V=S
M='(@(E)A9&5R82!D96X@:.1R(&SD;FME;B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C,V"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R(")2861E<F%D92!U
M<'!G<F%D97)I;F=S<V-R:7!T970@)R5S)RXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V,PHC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C$*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C,@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(R,2!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(U,PIM<V=I9"`B1&5L:79E<GD@=&EM92(*;7-G<W1R("),979E
M<F%N<W1I9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-CD@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<Q
M"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV."!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R(")$86YM
M87)K(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HV-#(*;7-G:60@(D1E;GD@<F5Q=65S="(*;7-G<W1R(")!=G-LY2!B
M96?D<F%N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HT-S$*;7-G:60@(D1E;GD@<F5Q=65S="!F;W(@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N(@IM<V=S='(@(D%V<VSE(&)E9^1R86X@;VT@;&5D:6<O
M=7!P=&%G96XM:6YF;W)M871I;VXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS
M9W-T<B`B0F5S:W)I=B!P<F]B;&5M970B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4V-2!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HY,S@*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDT,B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,P"FUS9VED
M(")$97-C<FEP=&EO;B(*;7-G<W1R(")"97-K<FEV;FEN9R(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,3DU(&QI8B](;W)D92YP:'`Z,3DW"FUS
M9VED(")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S
M='(@(D1E=&%L:F5R("AO8VMSY2!I($AO<F1E<R!L;V=G9FEL*3HB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y.2!L:6(O2&]R9&4N<&AP.C(P
M,0IM<V=I9"`B1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M
M:6YI<W1R871O<BXB"FUS9W-T<B`B1&5T86QJ97(@:&%R(&QO9V=A=',@9O9R
M('-Y<W1E;6%D;6EN:7-T<F%T]G)E;BXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C(Q"FUS9VED(")$979E;&]P;65N="(*;7-G<W1R(")5='9E
M8VML:6YG(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C0*;7-G:60@(D1E
M=R!0;VEN="(*;7-G<W1R(")$86=G<'5N:W0B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,P,0IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*
M;7-G<W1R(")$86=G<'5N:W0@9O9R('-E;F%S=&4@=&EM;65N.B`B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$V"FUS9VED(")$97<@<&]I
M;G0Z("(*;7-G<W1R(")$86=G<'5N:W0Z("(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L
M969T('1O(')I9VAT(@IM<V=S='(@(E)I:W1N:6YG(';D;G-T97(@=&EL;"!H
M]F=E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L969T(@IM<V=S='(@
M(E)I:W1N:6YG(&CV9V5R('1I;&P@=N1N<W1E<B(*"B,Z(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T<B`B2V%T86QO
M9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-S`*;7-G:60@(D1I<W!L
M87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B5FES82`R-"UT:6UM87)S(&ML
M;V-K83\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`P"FUS9VED(")$
M:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B5FES;FEN9W-I;G-TY&QL;FEN9V%R
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C@Y"FUS9VED(")$
M:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM<V=S='(@(E9I<V$@9&5T86QJ
M97)A9"!F]G)U='/D9V5L<V4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.CDR
M"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T("A4048I(@IM<V=S='(@(E9I<V$@
M9O9R=71SY&=E;'-E("A4048I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C@Q-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@P,PIM<V=I9"`B1&ES<&QA
M>2!F;W)M870B"FUS9W-T<B`B5FES;FEN9W-F;W)M870B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TU$3BYP:'`Z,3DP(&QI8B](;W)D92]-24U%+TU$3BYP
M:'`Z,3DQ"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V1I=FED97(N<&AP.C0@;&EB+T)L;V-K+V1I
M=FED97(N<&AP.C0U"FUS9VED(")$:79I9&5R(@IM<V=S='(@(D%V<VMI;&IA
M<F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8Y(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,`HC.B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-CD@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(D1J:6)O=71I
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HT,C(*;7-G:60@(D1O(&YO="!D96QE=&4B"FUS
M9W-T<B`B4F%D97)A(&EN=&4B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP
M:'`Z,C4*;7-G:60@(D1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N
M8V4N<&AP(@IM<V=S='(@(D%N=N1N9"!I;G1E(&UA:6YT96YA;F-E+G!H<"!D
M:7)E:W0B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,B!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E<R!T:&4@9FER
M<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K
M('1H:7,@8F]X.B(*;7-G<W1R("));FYE:.5L;&5R(&;V<G-T82!R861E;B!F
MY&QT;F%M;F5N/R!/;2`G:F$G+"!M87)K97)A(&CD<CHB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,@HC.B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G
M:60@(D1O;6EN:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C<S"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HW,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&]M:6YI
M8V%N(%)E<'5B;&EC(@IM<V=S='(@(D1O;6EN:6MA;G-K82!R97!U8FQI:V5N
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY-@IM<V=I9"`B1&]N
M)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R(")(87(@9'4@
M:6YG970@:V]N=&\_(%)E9VES=')E<F$@9&EG+B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C@T,R!L:6(O2&]R9&4O34E-12]#;VYT
M96YT<RYP:'`Z.#4R"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R(")(Y&UT82(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T,R!L:6(O
M2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#4R"B,L('!H<"UF;W)M870*;7-G
M:60@(D1O=VYL;V%D("5S(@IM<V=S='(@(DCD;71A("5S(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D
M(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`B2.1M=&$@
M9V5N97)E<F%D(&MO;F9I9W5R871I;VX@<V]M(%!(4"US:W)I<'0N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P-R!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C$Q,0IM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B1')O<'!L
M:7-T82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B1')U
M9W,B"FUS9W-T<B`B1')O9V5R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#`R(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I
M9"`B12U-86EL(@IM<V=S='(@(D4M<&]S="(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDR(&QI8B].970O4TU3+V=E;F5R
M:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R
M:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E
M+B(*;7-G<W1R("(B"B)$<FEV<G5T:6X@9O9R($4M<&]S="!T:6QL(%--4RUB
M<GEG9V$[(&;V<B!O<&5R873V<F5R('-O;2!T:6QL:&%N9&%HY6QL97(@(@HB
M9&5N;F$@=&KD;G-T+B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*(SH@;&EB+TAO<F1E
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%
M4E(B"FUS9W-T<B`B1D5,(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,"!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-S4*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<R(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%8W5A9&]R(@IM<V=S
M='(@(D5K=6%D;W(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R
M-2!L:6(O2&]R9&4O4&5R;7,N<&AP.C,R-0HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C,U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-CD*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$Q-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S
M."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,0HC.B!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z-S(*;7-G:60@(D5D:70B"FUS9W-T<B`BQ&YD
M<F$B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4P(&QI8B](
M;W)D92]";&]C:R]522YP:'`Z-3`*;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T
M<B`BQ&YD<F$@8FQO8VLB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y."!A9&UI
M;B]G<F]U<',N<&AP.C(R-@IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R("+$
M;F1R82!G<G5P<"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M-S8@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#`*(SH@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HW-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$P
M,`IM<V=I9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@(L1N9')A(&)E:/9R
M:6=H970B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"FUS9VED
M(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(L1N9')A(&)E:/9R:6=H971E
M<B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B
MQ&YD<F$@8F5H]G)I9VAE=&5R(&;V<B`E<R(*"B,Z('1E;7!L871E<R]P<F5F
M<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@
M(L1N9')A(&EN<W3D;&QN:6YG87(@9O9R.B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,S8W(&QI8B](;W)D92]097)M<R]522YP:'`Z,S8W
M"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R(%PB
M)7-<(B(*;7-G<W1R("+$;F1R82!B96CV<FEG:&5T97(@9O9R("<E<R<B"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T"B,L('!H<"UF;W)M870*
M;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(L1N9')A
M(&)E:/9R:6=H971E<B!F]G(@)R5S)R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS-0IM<V=I9"`B161U8V%T:6]N(@IM<V=S='(@(E5T8FEL9&YI;F<B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<P(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-PHC.B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S`*;7-G:60@(D5G>7!T(@IM<V=S='(@(D5G>7!T96XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#<@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-PHC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`W"FUS9VED(")%;"!386QV861O<B(*;7-G<W1R(")%;"!386QV861O
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHT,PIM<V=I9"`B16QE;65N="XN+B(*;7-G<W1R(")%;&5M96YT
M+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@(D5M(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R-"!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#8Y"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<S(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T"FUS9VED(")%;6%I;"(*
M;7-G<W1R(")%+7!O<W0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4V-2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V-@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$P('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C@*;7-G:60@(D5M86EL($%D9')E<W,B
M"FUS9W-T<B`B12UP;W-T861R97-S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3DV,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DV-PIM<V=I9"`B16UA
M:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM<V=S='(@(D4M<&]S=&%D<F5S
M<V5R(&WE<W1E('-TY&UM82#V=F5R<F5N<RXB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.3@Y(&QI8B](;W)D92]&;W)M+G!H<#HQ.3DS"FUS9VED
M(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")%+7!O<W1M961D
M96QA;F1E(&UE9"!B96MRY&9T96QS92(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ(&QI8B].970O4TU3+V=E;F5R:6-?
M<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E=V%Y(@IM<V=S
M='(@(D4M<&]S="!T:6QL(%--4RUB<GEG9V$B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C@Q"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR.3D*;7-G:60@(D5M;W1I8V]N<R(*;7-G
M<W1R(")+Y&YS;&]I:V]N97(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#(*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S
M='(@(E1O;70@;65D9&5L86YD92XB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,C0S(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HT.#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8V,B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z,34P(&QI8B](;W)D92]'<F]U<"]L9&%P
M+G!H<#HR-#,*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C0X-"!L:6(O
M2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-C8R"B,Z(&QI8B](;W)D92]'<F]U<"]L
M9&%P+G!H<#HW,#4@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,34P"FUS9VED
M(")%;7!T>2!R97-U;'0N(@IM<V=S='(@(E1O;70@<F5S=6QT870N(@H*(SH@
M9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$Q,R!L:6(O2&]R9&4O
M4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E87)C:"!T97)M
M<R(*;7-G<W1R(")4;VUT('/V:VMR:71E<FEA(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4T-PIM<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G
M97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R,@IM<V=I9"`B16YA8FQE(')I
M9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT-#@*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU-3,*;7-G
M:60@(D5N9"(*;7-G<W1R(")3;'5T(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C4Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$Q"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR-3DR(&QI8B](;W)D92]&;W)M+G!H<#HR-SDW
M"FUS9VED(")%;F0@>65A<B(*;7-G<W1R(")3;'5T(.5R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL
M87)G92!%9&ET;W(B"FUS9W-T<B`B1O9R<W1O<F$@961I=&]R(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(R-`IM<V=I9"`B(@HB16YT97(@82!S96-U
M<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@
M;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES
M('1H92!N86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M,@IM<V=I9"`B16YT97(@=&AE(&EM86=E(%523"!H97)E(@IM<V=S='(@(D%N
M9V4@<_9K=N1G("A54DPI('1I;&P@8FEL9&5N(&CD<B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX-C,*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Y,@IM<V=I9"`B16YT97(@=&AE
M(&QE='1E<G,@8F5L;W<Z(@IM<V=S='(@(E-+<FEV(&)O:W-TY'9E<FYA(&YE
M9&%N.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S8@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDY"B,Z
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-2!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW-@IM<V=I9"`B17%U871O<FEA;"!'=6EN96$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-SD*(SH@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<V(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<Q"FUS9VED(")%<FET<F5A(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T
M871U<RYP:'`Z,C<*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O5FEE
M=RYP:'`Z.30@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0X"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S8*;7-G:60@(D5R<F]R(@IM<V=S='(@(D9E
M;"(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8S(&QI
M8B](;W)D92]496UP;&%T92YP:'`Z-#8S"B,L('!H<"UF;W)M870*;7-G:60@
M(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R(")&96P@=FED('-K
M87!A;F1E(&%V(&)L;V-K.B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG
M('-Y;F,@86YC:&]R.B`E<R(*;7-G<W1R(")&96P@=FED(')A9&5R:6YG(&%V
M('-Y;FMR;VYI<V5R:6YG<VWD<FME.B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E
M;&5T:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R(")&96P@=FED(')A9&5R:6YG
M(&%V('-Y;FMR;VYI<V5R:6YG<VQO9V<Z("5S(@H*(SH@9G)A;65W;W)K+U1E
M;7!L871E+U1E;7!L871E+G!H<#HT-C@@;&EB+TAO<F1E+U1E;7!L871E+G!H
M<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT
M96YT.B`E<R(*;7-G<W1R(")&96P@;N1R(&EN;F5HY6P@:.1M=&%D97,Z("5S
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HQ.34*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HR-S@*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HS-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@<V5N9&EN
M9R!R97!L>3H@)7,N(@IM<V=S='(@(D9E;"!U;F1E<B!SY&YD;FEN9R!A=B!S
M=F%R<VUE9&1E;&%N9&4Z("5S(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T:6YG
M('!A<W-W;W)D.B`E<R(*;7-G<W1R(")&96P@=FED('5P<&1A=&5R:6YG(&%V
M(&SV<V5N;W)D.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P-0HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET:"!E;6%I;"!M97-S86=E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,30R"B,Z(&QI8B]6
M1E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS
M9W-T<B`B1F5L('9I9"!S:W)I=FYI;F<@)R5S)RXB"@HC.B!F<F%M97=O<FLO
M5D937TE33R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M,30S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@)R5S)RXB
M"FUS9W-T<B`B1F5L('9I9"!S:W)I=FYI;F<@878@)R5S)RXB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<P(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-@HC.B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*
M;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B17-T;&%N9"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@Q"B,Z(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HW."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I
M9"`B171H:6]P:6$B"FUS9W-T<B`B171I;W!I96XB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R(")%=&YI<VLB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*;7-G<W1R(")%=7)O
M<&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0S"FUS9VED(")%=F5R
M>2`Q-2!M:6YU=&5S(@IM<V=S='(@(E9A<B`Q-3IE(&UI;G5T(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,Y,PIM<V=I9"`B179E<GD@,B!M:6YU=&5S
M(@IM<V=S='(@(E9A<F%N;F%N(&UI;G5T(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,T,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")%
M=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(E9A<B`S,#IE('-E:W5N9"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#(@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,Y-`IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(E9A<B`U
M.F4@;6EN=70B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C8P(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z-C`*;7-G:60@
M(D5V97)Y($QO9VEN(@IM<V=S='(@(E9A<FIE(&EN;&]G9VYI;F<B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0T"FUS9VED(")%=F5R>2!H86QF(&AO
M=7(B"FUS9W-T<B`B5F%R:F4@:&%L=G1I;6UE(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,T,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDR"FUS9VED
M(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`B5F%R:F4@;6EN=70B"@HC.B!T96UP
M;&%T97,O9&%T82]D871E;6%P+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V86QU
M97,Z(@IM<V=S='(@(D5X96UP96P@<.4@=N1R9&5N.B(*"B,Z(&%D;6EN+W!H
M<'-H96QL+G!H<#HX,2!A9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L
M<VAE;&PN<&AP.C$R-PIM<V=I9"`B17AE8W5T92(*;7-G<W1R(")+]G(B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT-S4@;&EB+TAO
M<F1E+T)L;V-K+TQA>6]U="YP:'`Z-#<U"B,Z(&QI8B](;W)D92]";&]C:R],
M87EO=70O36%N86=E<BYP:'`Z-C$T"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B
M17AP86YD97)A(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHS
M,@IM<V=I9"`B17AP86YD(%-I9&5B87(B"FUS9W-T<B`B17AP86YD97)A('-I
M9&]FY&QT(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$V
M."!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@(D5X<&5C
M=&5D("<I)R(*;7-G<W1R(")&]G)VY&YT861E("<I)R(*"B,Z(&9R86UE=V]R
M:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-S4@;&EB+TAO<F1E+U-13"]+97EW
M;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O
M=&5D('-E87)C:"!T97)M(@IM<V=S='(@(D;V<G;D;G1A9&4@96YS:VEL="!O
M<F0@96QL97(@8VET97)A="!S]FMB96=R97!P(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#`Q(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@(D;V<F9A;&QO
M9&%T=6TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W
M-B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8W-PIM<V=I9"`B17AP;VYE
M;G0B"FUS9W-T<B`B17AP;VYE;G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Q"FUS9VED(")&1R!#;VQO<B(*
M;7-G<W1R(")&]G)G<G5N9'-FY')G(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$W-PIM<V=I9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R("),
M861D82!U<'`@:V]N9FEG=7)A=&EO;B!V:6$@1E10+B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]S<6PN<&AP.C(Q-B!L:6(O2&]R9&4O4')E9G,O<W%L
M+G!H<#HR,C4*;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S
M+B(*;7-G<W1R(")-:7-S;'EC:V%D97,@871T(&CD;71A(&EN<W3D;&QN:6YG
M87(N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<U(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z.3@*(SH@;&EB+TAO<F1E+T=R
M;W5P+VQD87`N<&AP.C<U(&QI8B](;W)D92]!=71H+VQD87`N<&AP.CDX"FUS
M9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T
M<B`B36ES<VQY8VMA9&5S(&%T="!K;VYT86MT82!,1$%0('-E<G9E<BXB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.3@@;&EB+TAO<F1E+T%U
M=&@O<VUB+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"
M('-E<G9E<BXB"FUS9W-T<B`B36ES<VQY8VMA9&5S(&%T="!K;VYT86MT82!3
M34(@<V5R=F5R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C@V
M(&QI8B]61E,O9G1P+G!H<#HW,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I
M;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@(DUI<W-L>6-K861E
M<R!A='0@:V]P:65R82!F<N5N("<E<R<N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HV.3$@;&EB+U9&4R]F='`N<&AP.C<R,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@
M(DUI<W-L>6-K861E<R!A='0@:V]P:65R82!T:6QL("<E<R<N(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX-R!L:6(O2&]R9&4O075T:"]S
M87-L+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C
M;VYN96-T:6]N+B(*;7-G<W1R(")-:7-S;'EC:V%D97,@871T('-K87!A(&YY
M(%-!4TPM9O9R8FEN9&5L<V4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HT.3<@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,C0*(SH@;&EB
M+U9&4R]S;6(N<&AP.C4P,2!L:6(O5D93+V9T<"YP:'`Z-S4U"B,L('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T
M<B`B36ES<VQY8VMA9&5S(&%T="!F;'ET=&$@=&EL;"`G)7,G+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8Q(&QI8B]61E,O<VUB+G!H<#HT
M-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(')E=')I979E.B`E
M<R(*;7-G<W1R(")-:7-S;'EC:V%D97,@871T(&CD;71A.B`E<R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")&
M86ER(@IM<V=S='(@(D)R82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C@T"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW.2!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA;F0@27-L
M86YD<R`H36%L=FEN87,I(@IM<V=S='(@(D9A;&ML86YD<_9A<FYA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#8*(SH@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C@P(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<S"FUS9VED(")&87)O92!)<VQA;F1S(@IM<V=S='(@(D;D<O9A<FYA(@H*
M(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(S."!L:6(O2&]R9&4O0TQ)+G!H
M<#HR,S@*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R(")&871A;'0@9F5L
M.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M.#<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G
M:60@(D9A>"(*;7-G<W1R(")&87@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S4Q"FUS9VED(")&87AE<R(*;7-G<W1R(")&87AA<B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-S@*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-0HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM<V=I9"`B1F5B<G5A<GDB"FUS
M9W-T<B`B9F5B<G5A<FDB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-PIM
M<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R(")+Y&YN<R!S;VTB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(P"FUS9VED(")&965L<R!L:6ME
M.B`B"FUS9W-T<B`B2^1N;G,@<V]M.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS
M9W-T<B`B1N5T86QI9V$@<VMU<F%R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B
M"FUS9W-T<B`B1N5T86QI9V$@<V[V<VMU<F%R(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3DT-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DT.`IM<V=I
M9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(D;D;'1M871R:7,B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,S(&QI8B](;W)D92]&;W)M+G!H<#HS
M,S(Y"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R(")&:6=L970@0T%0
M5$-(02(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S<@;&EB+TAO
M<F1E+T9O<FTN<&AP.C,S,S,*;7-G:60@(D9I9VQE="!F;VYT(@IM<V=S='(@
M(D9I9VQE='1Y<'-N:71T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z.#,*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@Q(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@
M(D9I:FDB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G
M:60@(D9I;&4B"FUS9W-T<B`B1FEL(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C8T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#(@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C<@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W1G>BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL
M92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R(")!;G1A;"!F:6QE<CH@)7,@9FEL
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8T"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C`*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C<@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS
M9W-T<B`B06YT86P@9FEL97(Z("5S(&9I;&5R(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0P.0IM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S='(@
M(D9I;&AA;G1E<F%R92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C,@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@U
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8S"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]Z:7`N<&AP.C<P(&QI8B](;W)D92]-24U%+U9I97=E
M<B]T9WHN<&AP.C@R"FUS9VED(")&:6QE($YA;64B"FUS9W-T<B`B1FEL;F%M
M;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y.34@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(Y.#$*;7-G:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S='(@
M(D9I;'9A;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T.#8@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$T.3`*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S
M='(@(D9I;'5P<&QA9&1N:6YG(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O
M=W-E<BYP:'`Z.#4T(&QI8B](;W)D92]"<F]W<V5R+G!H<#HY,#(*;7-G:60@
M(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R(")&:6QU<'!L
M861D;FEN9R!S=/9D<R!I;G1E+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HY,0IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R(")&:6QT97(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<Q(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,@HC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S$*;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`B1FEN;&%N9"(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B
M1O9R<W1A(&AA;'9A;B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U87)T97(B"FUS9W-T
M<B`B1O9R<W1A(&MV87)T96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C,Y"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HR-3<*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C$T"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,S(*;7-G:60@
M(D9L:7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*
M;7-G:60@(D9O9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3`W"B,Z
M(&QI8B]61E,O<W%L+G!H<#HR,S<@;&EB+U9&4R]M=7-Q;"YP:'`Z,3`W"B,L
M('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*
M;7-G<W1R(")-87!P("5S(&5X:7-T97)A<B!I;G1E+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@
M0V]L;W(B"FUS9W-T<B`B1F]N=&;D<F<B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`B36%T(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V
M"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E
M<R(*;7-G<W1R(")&]G(@=V5B8FSD<V%R92!S;VT@:6YT92!S=/9D97(@8FEL
M9&5R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#$*;7-G:60@(D9O<F5C
M87-T("A4048I(@IM<V=S='(@(E!R;V=N;W,@*%1!1BDB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S(*;7-G:60@(B(*(D9O<F5C87-T($1A
M>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B
M;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@8V]U
M;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@HB06YT86P@
M9&%G87(@9O9R('!R;V=N;W,@*'9A<FIE(&1A9R!B971Y9&5R(&5N('!R;V=N
M;W,@9O9R(&1A9R!O8V@@96X@9O9R("(*(FYA='0I(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHQ,#(*;7-G:60@(D9O<F=O="!Y;W5R('!A<W-W
M;W)D/R(*;7-G<W1R(")';/9M="!D:71T(&SV<V5N;W)D/R(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT-C0*;7-G:60@(D9O<FUS(@IM<V=S='(@
M(D9O<FUU;.1R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"FUS9VED
M(")&;W)T=6YE(@IM<V=S='(@(E9I<VAE='-O<F0B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R(")4
M>7`@878@=FES:&5T<V]R9"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M.`IM<V=I9"`B1F]R='5N97,B"FUS9W-T<B`B5FES:&5T<V]R9"(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G
M<W1R(")6:7-H971S;W)D(#(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#4U"FUS9VED(")&;W)U;7,B"FUS9W-T<B`B1F]R=6TB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3$Q"FUS9VED(")&;W)W87)D<R(*;7-G
M<W1R(")6:61A<F)E9F]R9')A<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S='(@(D9R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS,PIM<V=I9"`B1G)A;65S(@IM<V=S='(@(E)A;6%R(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#<*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C@S(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S"FUS
M9VED(")&<F%N8V4B"FUS9W-T<B`B1G)A;FMR:6ME(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<S(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R(")&<F%N
M:W)I:V4L($UE=')O<&]L(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HT,3<*;7-G:60@(D9R964O0G5S>2!);F9O<FUA
M=&EO;B(*;7-G<W1R("),961I9R]5<'!T86=E;B!I;F9O<FUA=&EO;B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#(W
M"FUS9VED(")&<F5E+T)U<WD@4F5P;'DB"FUS9W-T<B`B3&5D:6<O57!P=&%G
M96X@<W9A<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-#(R"FUS9VED(")&<F5E+T)U<WD@4F5Q=65S="(*;7-G<W1R
M("),961I9R]U<'!T86=E;BUF]G)F<N5G86XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C(W,@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C,T,0IM<V=I9"`B1G)E
M92]"=7-Y(%)E<75E<W0@4F5S<&]N<V4B"FUS9W-T<B`B4W9A<B!PY2!L961I
M9R]U<'!T86=E;BUF]G)F<N5G86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HY,0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D9R96YC:"!'
M=6EA;F$B"FUS9W-T<B`B1G)A;G-K82!'=6EA;F$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$X-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY."!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@T"B,Z(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HX-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I
M9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R(")&<F%N<VMA(%!O;'EN97-I
M96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#D@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,@HC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET
M;W)I97,B"FUS9W-T<B`B1G)A;G-K82!S]F1R82!T97)R:71O<FEE<B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R
M;VTB"FUS9W-T<B`B1G+E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,S<@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,T.0HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDU"FUS9VED(")&<F]M('1H
M92`B"FUS9W-T<B`B1G+E;B!D96X@(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z-#@*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T
M<B`B1G5L;'-TY&YD:6<@8F5S:W)I=FYI;F<B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z.#$@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-@IM<V=I9"`B1G5L;"!-
M;V]N(@IM<V=S='(@(D9U;&QMY6YE(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C8Q('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*;7-G
M:60@(D9U;&P@3F%M92(*;7-G<W1R(")&=6QL<W3D;F1I9W0@;F%M;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S,@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@X"B,Z(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HX-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW,PIM<V=I9"`B1V%B;VXB"FUS9W-T<B`B1V%B;VXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*
M;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S='(@(D=A
M;&QE<FD@871T('1A(&)I;&0@9G+E;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L
M;&5R>3HB"FUS9W-T<B`B1V%L;&5R:3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HY-@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=A;6)I
M82(*;7-G<W1R(")'86UB:6$B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C0R"B,L('!H<"UF;W)M870*;7-G:60@(D=E;F5R871E("5S($-O;F9I9W5R
M871I;VXB"FUS9W-T<B`B1V5N97)E<F$@:V]N9FEG=7)A=&EO;B!F]G(@)7,B
M"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I
M9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B1V5N97)E<F%D(&MO9"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S0@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDP"B,Z(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HX.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW-`IM<V=I9"`B1V5O<F=I82(*;7-G<W1R(")'96]R9VEE;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-CD@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8Y"B,Z(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HY,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R(")4>7-K;&%N9"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HY,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S4@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDS"B,Z(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HY,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM
M<V=I9"`B1VAA;F$B"FUS9W-T<B`B1VAA;F$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HY-`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=I
M8G)A;'1A<B(*;7-G<W1R(")':6)R86QT87(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4W-2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4W-@IM<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R(")&]G)N86UN(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W-2!T96UP;&%T97,O
M<')E9G,O87!P+FEN8SHQ,`HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ
M.0IM<V=I9"`B1VQO8F%L($]P=&EO;G,B"FUS9W-T<B`B1VQO8F%L82!I;G-T
MY&QL;FEN9V%R(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3<*;7-G
M:60@(D=O(@IM<V=S='(@(D]+(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0P"FUS9VED(")';V5D96PB"FUS9W-T<B`B1V]E9&5L(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,#`*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,S$*;7-G:60@(D=O;V=L
M92!-87!S(@IM<V=S='(@(D=O;V=L96MA<G1O<B(*"B,Z(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`B
M1V]O9VQE<_9K;FEN9R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,C`*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(S.`IM<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@(D=RY7-K86QA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S8@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,`HC.B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S8*;7-G:60@(D=R965C92(*;7-G<W1R(")'<F5K:7-K("A)
M4T\M.#@U.2TW*2(*"B,Z(&-O;F9I9R]T:&5M97,O9W)E96XN<&AP.C8*;7-G
M:60@(D=R965N(@IM<V=S='(@(D=R]FXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HY-0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.30@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=R965N
M;&%N9"(*;7-G<W1R(")'<O9N;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C@Y"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HY-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1W)E;F%D
M82(*;7-G<W1R(")'<F%N861A(@H*(SH@8V]N9FEG+W1H96UE<R]G<F5Y+G!H
M<#HV"FUS9VED(")'<F5Y(@IM<V=S='(@(D=RY2(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,3<Y"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R
M(")'<G5P<&%D;6EN:7-T<F%T:6]N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+G!H<#HU.2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,38Y
M"B,Z(&QI8B](;W)D92]'<F]U<"YP:'`Z-3D@;&EB+TAO<F1E+T=R;W5P+VQD
M87`N<&AP.C$V.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP
M='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C,P-R!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L('!H<"UF
M;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@
M)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R(")'
M<F]U<%]L9&%P.B!+86X@:6YT92!LY&=G82!T:6QL(&=R=7!P("<E<R<N(%-E
M<G9E<FX@<W9A<F%D93H@(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C$Q."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3(T
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT,3@@;&EB+TAO
M<F1E+T=R;W5P+VQD87`N<&AP.C$Q.`HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A
M<"YP:'`Z,3(T(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HT,3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G
M<F]U<"`E<R(*;7-G<W1R(")'<F]U<%]L9&%P.B!+86X@:6YT92!R861E<F$@
M9W)U<'`@)R5S)R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,W.0HC.B!L
M:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,S,X(&QI8B](;W)D92]'<F]U<"]L
M9&%P+G!H<#HS-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@
M56YA8FQE('1O('5P9&%T92!G<F]U<"`E<R(*;7-G<W1R(")'<F]U<%]L9&%P
M.B!+86X@:6YT92!U<'!D871E<F$@9W)U<'`@)R5S)R(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,S$T(&QI8B](;W)D92]097)M<R]522YP
M:'`Z,S$T"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS9W-T<B`B1W)U
M<'!E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S8@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDX"B,Z
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`S"B,Z(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-R!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW-PIM<V=I9"`B1W5A;2(*;7-G<W1R(")'=6%M(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S<@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,@HC.B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S<*
M;7-G:60@(D=U871E;6%L82(*;7-G<W1R(")'=6%T96UA;&$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDR(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B1W5E<FYS97DB"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(R-B!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C(R-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X
M"FUS9VED(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R(")'Y'-T8F5H]G)I
M9VAE=&5R(@H*(SH@=&5M<&QA=&5S+V=U97-T+V=U97-T+FEN8SHQ,0IM<V=I
M9"`B1W5E<W0@4V5R=FEC97,B"FUS9W-T<B`B5&KD;G-T97(@9O9R(&?D<W1E
M<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S(*;7-G:60@(D=U
M97-T8F]O:R(*;7-G<W1R(")'Y'-T8F]K(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDY"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-2!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z.3<*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.CDY(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'=6EN
M96$B"FUS9W-T<B`B1W5I;F5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,#0*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$P,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5I;F5A
M+4)I<W-A=2(*;7-G<W1R(")'=6EN96$M0FES<V%U(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#4*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$P,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.`IM
M<V=I9"`B1W5Y86YA(@IM<V=S='(@(D=U:6YE82(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.CDV,"!L:6(O2&]R9&4O1F]R;2YP:'`Z.38T"FUS9VED
M(")(5$U,(@IM<V=S='(@(DA434PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(5$U,07)E82!C
M;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O
M=RXB"FUS9W-T<B`B2%1-3$%R96$@=N1G<F%R(&%T="!R861E<F$@<VES=&$@
M8V5L;&5N(&D@96X@<F%D+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R
M9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L
M92XB"FUS9W-T<B`B2%1-3$%R96$@=N1G<F%R(&%T="!R861E<F$@<VES=&$@
M:V]L=6UN96X@:2!E;B!T86)E;&PN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@
M8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A
M8FQE+B(*;7-G<W1R(")(5$U,07)E82!VY&=R87(@871T(')A9&5R82!S:7-T
M82!R861E;B!I(&5N('1A8F5L;"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VAT='`N<&AP.C$U-R!L:6(O2&]R9&4O075T:"]H='1P+G!H<#HQ-3<*;7-G
M:60@(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")(
M5%10($%U=&5N=&ES97)I;F<@<V%K;F%S+B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,"!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3$P"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,#(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@
M(DAA:71I(@IM<V=S='(@(DAA:71I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#`R(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,PIM
M<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`B2&%S:&%L9V]R:71M(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G
M:60@(DAA>F4B"FUS9W-T<B`B1&EM;6$B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HY,3D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z.3(S(&QI8B](;W)D92]&;W)M+G!H<#HR.3$X
M"FUS9VED(")(96%D97(B"FUS9W-T<B`B4G5B<FEK(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0HC.B!L:6(O2&]R9&4O
M1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*;7-G
M<W1R(")2=6)R:6ME<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.2!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3`W"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#,@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N
M9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R(")(96%R9"T@;V-H($UC
M1&]N86QD]F%R;F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR,PIM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R(")+<F%F
M=&EG82#E<VMS:W5R87(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM
M<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(DAE8G)E:7-K
M("A)4T\M.#@U.2TX+4DI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S='(@
M(DCV:F0B"@HC.B!L:6(O0FQO8VLO8F%R=&EM92YP:'`Z,C0@;&EB+T)L;V-K
M+V1I=FED97(N<&AP.C(T"FUS9VED(")(96EG:'0@*&EN('!I>&5L<RDB"FUS
M9W-T<B`B2/9J9"`H<&EX;&%R*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92](96QP+G!H<#HQ-SD@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP
M.C$X-@HC.B!L:6(O2&]R9&4O2&5L<"YP:'`Z,3@T(&QI8B](;W)D92](96QP
M+G!H<#HQ.#8@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<*(SH@=&5M<&QA
M=&5S+VAE;'`O:6YD97@N:6YC.C0*;7-G:60@(DAE;'`B"FUS9W-T<B`B2&KD
M;'`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R(")(:N1L<"!M
M960@961I=&]R;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-S$@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$S-S4*;7-G:60@(DAE;'!E<B(*;7-G<W1R
M(")(:N1L<&9U;FMT:6]N(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS
M9VED(")(96UI<W!H97)E(@IM<V=S='(@(DAE;6ES9N1R(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@
M9FEL93HB"FUS9W-T<B`B2.1R(.1R(&+V<FIA;B!A=B!F:6QE;CHB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I9"`B
M2&EG:"(*;7-G<W1R(")(]F<B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N
M:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C4*;7-G
M:60@(DAO7VUE(@IM<V=S='(@(DAE7VTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR-#,*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$P-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@
M(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,30Y,2!L:6(O2&]R9&4N<&AP
M.C$U,SD*;7-G:60@(DAO;64B"FUS9W-T<B`B2&5M(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R,@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,34U"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`B
M061R97-S+"!H96TB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*;7-G
M:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S='(@(DAE;6MA=&%L;V<B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE
M(%!H;VYE(@IM<V=S='(@(E1E;&5F;VXL(&AE;2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.2!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`X"B,Z(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,#4@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD*;7-G
M:60@(DAO;F1U<F%S(@IM<V=S='(@(DAO;F1U<F%S(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#8*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$P-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.`IM
M<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(DAO;F<@2V]N9R(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HV-PIM<V=I9"`B2&]R9&4B"FUS9W-T<B`B
M2&]R9&4B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0T,B!L:6(O
M2&]R9&4O2V]L86(N<&AP.C0U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M
M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!/9VEL=&EG="`E<R!8
M34PM9&%T82!PY71RY&9F861E<R!I(&UE9&1E;&%N9&4@)7,B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C(Y.2!L:6(O2&]R9&4O2V]L86(N<&AP
M.C(Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S
M<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O
M2V]L86(Z($EN9V5T(&UE9&1E;&%N9&4@;6%T8VAA<B!O8FIE:W1E="`E<R(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#,U(&QI8B](;W)D92]+
M;VQA8BYP:'`Z-#0U"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S(@IM
M<V=S='(@(DAO<F1E+TMO;&%N.B!);F=E="!O8FIE:W0@878@='EP96X@)7,@
M:&ET=&%D97,@:2!M961D96QA;F1E="`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,3(U,"!L:6(O2&]R9&4O2V]L86(N<&AP.C$R-3$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R
M96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@4F%D97)A
M9&4@)7,@)R5S)R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S
M(&QI8B](;W)D92]+;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D92]+;VQA8CH@
M5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@
M4$A0(&5X=&5N<VEO;B(*;7-G<W1R(")(;W)D92]+;VQA8CH@26YT96=R871I
M;VYS;6]T;W)N(&MRY'9E<B`G9&]M>&UL)RUT:6QLY&=G970@9O9R(%!(4"(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-3`S(&QI8B](;W)D92]+
M;VQA8BYP:'`Z-3$R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S
M(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!+86X@:6YT92!S:V%P82!N>71T(%A-
M3"UT<N1D(&;V<B!O8FIE:W0@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C$R-#<@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C0X"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S
M(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($MA;B!I;G1E(')A
M9&5R82`E<R`G)7,G.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z-#<T(&QI8B](;W)D92]+;VQA8BYP:'`Z-#@S"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)
M1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R(")(;W)D92]+;VQA
M8CH@2V%N(&EN=&4@:.1M=&$@34E-1$4M240@9O9R(&1E;&5N(&UE9"!T>7`@
M)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q.3,@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HQ,3DW"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*
M;7-G<W1R(")(;W)D92]+;VQA8CH@2V%N(&EN=&4@<WEN:W)O;FES97)A("5S
M("<E<R<Z("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,S,V
M(&QI8B](;W)D92]+;VQA8BYP:'`Z,3,S-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@
M)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($MA;B!I;G1E('-Y;FMR;VYI<V5R
M82!U=&1E;&YI;F=A<CH@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C,T,"!L:6(O2&]R9&4O2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS
M9W-T<B`B2&]R9&4O2V]L86(Z($]KY&YD('5T9&5L;FEN9R`G)7,G(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I
M9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(DAO<FES;VYT96QL(&QI;FIE
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M,@IM<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(DAO<FES;VYT
M96QL('5T9GEL;&YA9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@(DAO
M<FES;VYT96QL.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T(&AE
M<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B2'5R(&AA;6YA9&4@9'4@
M:.1R/R`H5F%R(&=O9"!R87!P;W)T97)A(&1E='1A(2DB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,U"FUS9VED
M(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*
M;7-G<W1R(")(=7(@;>5N9V$@:V]L=6UN97(@=FEL;"!D=2!S;.4@:6AO<#\B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR,0IM<V=I9"`B2&]W
M(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@(DAU
M<B!MY6YG82!FY&QT("AK;VQU;6YE<BD@9FEN;G,@9&5T/R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G
M:60@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM
M<V=S='(@(DAU<B!MY6YG82!R861E<B!V:6QL(&1U('-LY2!S86UM86X_(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X.2!L:6(O0FQO8VLO
M;65T87(N<&AP.C(S-PIM<V=I9"`B2'5M:61I='DB"FUS9W-T<B`B1G5K=&EG
M:&5T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T.`IM<V=I
M9"`B2'5M:61I='DZ("(*;7-G<W1R(")&=6MT:6=H970Z(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED(")(=6UO<FES=',B"FUS9W-T<B`B
M2'5M;W)I<W1E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,"!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3$Q"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#<@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T
M<B`B56YG97)N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z
M,3<R(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR,S4*(SH@;&EB
M+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$W,B!L:6(O2&]R9&4O075T:"]C>7)S
M<6PN<&AP.C(S-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@
M8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")3:V%P86YD92!A=B!)34%0
M+6UA<'`@;6ES<VQY8VMA9&4Z("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)U<RYP:'`Z,C$T(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H
M<#HR.34*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C(Q-"!L:6(O2&]R
M9&4O075T:"]C>7)S<6PN<&AP.C(Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("))
M34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")2861E
M<FEN9R!A=B!)34%0+6UA<'`@;6ES<VQY8VMA9&5S.B`E<R(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W.2!F<F%M97=O<FLO075T:"]!
M=71H+V-Y<G-Q;"YP:'`Z,C0R"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H
M<#HQ-SD@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE
M9#H@)7,B"FUS9W-T<B`B4VMA<&%N9&4@878@<75O=&$@9O9R($E-05`M;6%P
M<"!M:7-S;'EC:V%D97,Z("5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3,Q-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,R,`IM<V=I9"`B25`@061D
M<F5S<R(*;7-G<W1R("))4"UA9')E<W,B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VEP8F%S:6,N<&AP.C<W(&QI8B](;W)D92]!=71H+VEP8F%S:6,N<&AP
M.C<W"FUS9VED("))4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(DE0+6%D<F5S<R#D<B!I;G1E('1I;&QGY&YG;&EG+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z.#D@;&EB+TAO<F1E+T%U=&@O:7!B
M87-I8RYP:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO
M=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@(DE0+6%D<F5S<R#D<B!I;G1E(&EN
M;VT@9V]D:^1N="!#2412+6)L;V-K+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO
M;&%T:6]N+B(*;7-G<W1R(")&]G)S]FL@871T(&MR:6YG9^4@25`M;.5S+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(DE?
M;F9O9V$@<F%D(&;V<F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$R,`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R"FUS9VED("))8V5L86YD(@IM
M<V=S='(@(DES;&%N9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#`*
M;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B16YB87)T(&EK;VYE<B(*"B,Z
M('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("))8V]N<R!F;W(@)7,B"FUS9W-T<B`B26MO;F5R(&;V<B`E<R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#$*;7-G:60@(DEC;VYS('=I=&@@=&5X
M="(*;7-G<W1R(")):V]N97(@;65D('1E>'0B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3DS"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@
M(DED96YT:71E=&5N<R!N86UN.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C4Y,2!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z
M-3DY"B,L('!H<"UF;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y
M960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB
M"FUS9W-T<B`B3VT@9&5T(&EN=&4@=FES87,@:V]R<F5K="P@)7,@9O9R(&%T
M="#V<'!N82!I(&YY='0@9O9N<W1E<BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#4Y"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N
M<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H
M96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN
M(@IM<V=S='(@(B(*(D]M(&1U(&EN=&4@<V5R(&[E9W)A(&EK;VYE<B!NY'(@
M9'4@86YVY&YD97(@26YT97)N970@17AP;&]R97(L('/E(&MA;B!D=2`B"B)B
M96CV=F$@;6%R:V5R82!D96YN82!R=71A(&;V<B!A='0@<W3D;F=A(&%V(&=E
M;F]M<VMI;FQI9V$@4$Y'+6)I;&1F:6QE<BXB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,34X"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ-S(*;7-G:60@(B(*(DEF('EO=2!S964@
M=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT
M('1O('5P;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W
M<V5R+B(*;7-G<W1R("(B"B)/;2!D=2!S97(@9&5N;F$@=&5X="!M96X@:6YG
M96X@8FEL9"P@<^4@:V%N(&EN=&4@9&EN('=E8F)LY'-A<F4@=FES82!D96X@
M(@HB8FEL9"!D=2!F]G)S]FME<B!L861D82!U<'`N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(X"FUS
M9VED("));6%G92!0<F5V:65W.B(*;7-G<W1R(")&]G)H86YD<V=R86YS:V$@
M8FEL9#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,W"FUS9VED("));6%G92!54DPB"FUS9W-T<B`B0FEL9&%D
M<F5S<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R(")"
M:6QD861R97-S.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL
M97)Y(@IM<V=S='(@(D)I;&0@9G+E;B!G86QL97)I(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS
M9VED("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(D)I;&0@9G+E;B!G
M86QL97)I.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C$@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$W-C4*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G
M<W1R("),861D82!U<'`@8FEL9"(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C,W"FUS9VED("));6%G97,B"FUS9W-T<B`B0FEL9&5R(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T82]D871E;6%P
M+FEN8SHW"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-30@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("))
M;7!O<G0L(%-T97`@)60B"FUS9W-T<B`B26UP;W)T97)A+"!S=&5G("5D(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(DEM<&]R=&5R
M861E(&;D;'0Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV
M-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R("));7!O<G1E<F%D
M92!FY&QT.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-S`Q"FUS9VED("));B!0<F]C97-S(@IM<V=S='(@(E#E9^5E
M;F1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,P"FUS9VED("));E]S97)T(%)O=R!!9G1E<B(*;7-G<W1R
M("));E]F;V=A(')A9"!E9G1E<B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]Z:7`N<&AP.C$S-2!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H
M<#HQ,S0*;7-G:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS
M9W-T<B`B1F5L86MT:78@86MT:79I=&5T<VMO9"!S<&5C:69I8V5R860N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,S(*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@IM<V=I
M9"`B26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T
M<B`B1F5L86MT:6=T(&%N=N1N9&%R;F%M;B!O8V@O96QL97(@;/9S96YO<F0N
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*
M(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y
M(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF('EO
M=2!N965D(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB3V=I;'1I9W0@86YV
MY&YD87)N86UN(&5L;&5R(&%L=&5R;F%T:78@861R97-S+B!&]G)S]FL@:6=E
M;B!E;&QE<B!K;VYT86MT82`B"B)A9&UI;FES=')A=/9R96X@;VT@9'4@8F5H
M]G9E<B!H:N1L<"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S92!);F1E;G0B"FUS9W-T<B`B
MUFMA(&EN9')A9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,2!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3$V"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#D@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DEN9&EA(@IM<V=S='(@
M(DEN9&EE;B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C4T
M(&QI8B](;W)D92]097)M<R]522YP:'`Z,C4T"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3,T"FUS9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S
M='(@(DEN9&EV:61U96QL82!A;G;D;F1A<F4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$P(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P"FUS9VED
M("));F1O;F5S:6$B"FUS9W-T<B`B26YD;VYE<VEE;B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(DEN9F\B"FUS9W-T
M<B`B26YF;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3D*;7-G
M:60@(DEN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%T:6]N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q.0IM<V=I9"`B26YF;W)M871I
M;VX@;F\@;&]N9V5R(&%V86EL86)L92XB"FUS9W-T<B`B26YF;W)M871I;VX@
MY'(@:6YT92!T:6QL9^1N9VQI9R!LY&YG<F4N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,U"FUS9VED("))
M;G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R("));F9O9V$@:U]O;'5M;B!E
M9G1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B26YS97)T($EM86=E(@IM<V=S='(@
M(DEN9F]G82!B:6QD(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P,`IM<V=I9"`B26YS97)T(%1A8FQE(@IM<V=S='(@(DEN
M9F]G82!T86)E;&PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(U"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B
M26YF;V=A('=E8F)LY&YK(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED("));G-E<G0@7T-O;'5M
M;B!"969O<F4B"FUS9W-T<B`B26YF;V=A(%]K;VQU;6X@9O9R92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M-@IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N
M="!O;F4B"FUS9W-T<B`B26YF;V=A(&YY(&MO;'5M;B!E9G1E<B!A:W1U96QL
M(&MO;'5M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B
M969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DEN9F]G82!N>2!K;VQU
M;6X@9O9R92!A:W1U96QL(&MO;'5M;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,@IM<V=I9"`B26YS97)T
M(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B26YF
M;V=A(')A9"!E9G1E<B!A:W1U96QL(')A9"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS
M97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@
M(DEN9F]G82!N>2!R860@9O9R92!E:W1U96QL(')A9"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM<V=I
M9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B
M"FUS9W-T<B`B26YF;V=A('!A<F%G<F%F(&5F=&5R(&%K='5E;&P@;F]D(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C
M=7)R96YT(&YO9&4B"FUS9W-T<B`B26YF;V=A('!A<F%G<F%F(&;V<F4@86MT
M=65L;"!N;V0B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B
M26YS97)T(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("));F9O9V$@86QT
M97)N871I=B!M86QL(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T,@IM
M<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A
M;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*
M;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(DEN9F]G82!C96QL
M(&5F=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU.0IM<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S
M='(@(DEN9F]G82!C96QL(&;V<F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L
M=6UN(&%F=&5R(@IM<V=S='(@(DEN9F]G82!K;VQU;6X@969T97(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U
M"FUS9VED("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R("));F9O9V$@
M:V]L=6UN(&;V<F4B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY,"!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3`*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED("))
M;G-E<G0@;65S<V%G97,B"FUS9W-T<B`B26YF;V=A(&UE9&1E;&%N9&5N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0U"FUS9VED("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@
M(DEN9F]G82!P87)A9W)A9B!E9G1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T
M('!A<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B26YF;V=A('!A<F%G<F%F(&;V
M<F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8Y"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(DEN
M9F]G82!R860@969T97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E9F]R
M92(*;7-G<W1R("));F9O9V$@<F%D(&;V<F4B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C,S"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E
M<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(D%N9V4@97)F
M;W)D<F%T('-V87(@=&EL;"!SY&ME<FAE='-F<N5G86XZ(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM<V=I9"`B26YS
M97)T+TUO9&EF>2!);6%G92(*;7-G<W1R("));F9O9V$OQ&YD<F$@8FEL9"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#D*
M;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*;7-G<W1R("));F9O9V$OQ&YD
M<F$@;.1N:R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C0S"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T
M:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(D]T:6QL<N1C:VQI9R!K
M<F5D:70@9O9R(&%T="!S:VEC:V$@=&EL;"!D:7-T<FEB=71I;VYS;&ES=&$N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,S4*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM
M<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`B3W1I;&QRY&-K
M;&EG(&MR961I="XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<U
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,#<Y"FUS9VED("));G1E9V5R(@IM<V=S
M='(@(DAE;'1A;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,S,@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,S<*;7-G:60@(DEN=&5G97(@;&ES="(*
M;7-G<W1R(")(96QT86QS;&ES=&$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C(X,PHC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C,U,@IM<V=I9"`B26YV86QI9"!!
M8W1I;VX@<V5L96-T960@9F]R('1H:7,@8V]M<&]N96YT+B(*;7-G<W1R(")/
M9VEL=&EG(.5T9^1R9"!F]G(@9&5N(&CD<B!K;VUP;VYE;G1E;BXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G:60@
M(DEN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN(@IM<V=S='(@(D]G
M:6QT:6<@541(("@G=7-E<B!D871A(&AE861E<B<I+B(*"B,Z(&QI8B](;W)D
M92]#;VUP<F5S<R]Z:7`N<&AP.C$V-R!L:6(O2&]R9&4O0V]M<')E<W,O>FEP
M+G!H<#HQ.30*(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,C$R"FUS
M9VED("));G9A;&ED(%I)4"!D871A(@IM<V=S='(@(D]G:6QT:6=T(%I)4"UA
M<FMI=F1A=&$B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T"FUS9VED
M("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R(")&96QA:W1I9R!A<'!L
M:6MA=&EO;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,3(*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(D9E
M;&%K=&EG="!B871C:"U)1"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(P.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U.`HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,C,R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(R.3D*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H
M<#HS-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`Y,0HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C$V,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(S-B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C,P,PHC.B!L:6(O2&]R9&4O1F]R;2]4>7!E+W1A8FQE<V5T
M+G!H<#HS-PIM<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T
M<B`B1F5L86MT:6<@9&%T82!S:VEC:V%D+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,`HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,`IM<V=I9"`B26YV86QI9"!D97-T
M:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R(")&96QA:W1I9R!D97-T:6YA=&EO
M;G-A9')E<W,N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B
M>"YP:'`Z.#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP
M:'`Z,3`P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP
M.C(R,"!L:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HQ,#D*(SH@;&EB+TAO
M<F1E+T-O;7!R97-S+V1B>"YP:'`Z,3,Y(&QI8B](;W)D92]#;VUP<F5S<R]D
M8G@N<&AP.C(T,0IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R
M(")&96QA:W1I9W0@9FEL9F]R;6%T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$V-0IM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS
M9W-T<B`B3V=I;'1I9R!L:6-E;G-N>6-K96PN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$U.0IM<V=I9"`B26YV86QI9"!L;V-A=&EO;B!P
M<F]V:61E9"XB"FUS9W-T<B`B1F5L86MT:6<@;W)T('-P96-I9FEC97)A9"XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#<*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*
M;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@(D9E;&%K=&EG(&UE
M9&1E;&%N9&5?='EP+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P,PHC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P,PIM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I
M9"XB"FUS9W-T<B`B1F5L86MT:6<@96QL97(@<V%K;F%D(&%P:5]I9"XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.38*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.38*;7-G
M:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+B(*;7-G<W1R(")&
M96QA:W1I9W0@96QL97(@<V%K;F%D('!A<F%M971E<BXB"@HC.B!A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R96YT('!E
M<FUI<W-I;VXN(@IM<V=S='(@(D9E;&%K=&EG(/9V97)L:6=G86YD92!B96CV
M<FEG:&5T+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*
M;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B1F5L86MT:6=T
M('!A<G1N97(M:60N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$V,PIM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O9&4N(@IM<V=S='(@(D9E
M;&%K=&EG('!R;V1U:W1K;V0N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED("));G9A;&ED('!R;W1O8V]L+B(*
M;7-G<W1R(")&96QA:W1I9W0@<')O=&]K;VQL+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HW,2!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C@P"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HY,R!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z-S$*(SH@
M;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G
M:60@(DEN=F%L:60@<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`B1F5L86MT
M:6<@;6]T=&%G87)E.B`G)7,G(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HQ,#<V(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(V,@HC.B!L
M:6(O2&]R9&4O2V]L86(N<&AP.C$P.#`@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ
M,C8S"FUS9VED("));G9A;&ED('-H87)E(&]B:F5C="(*;7-G<W1R(")&96QA
M:W1I9W0@=71D96QN:6YG<V]B:F5K="(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B26YV86QI9"!S;W5R8V4@
M861D<F5S<RXB"FUS9W-T<B`B1F5L86MT:6<@879SY&YD87)A9')E<W,N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$Q"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS
M9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T<B`B1F5L86MT:6=T
M('5N:6-O9&4M9&%T82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M-3D*;7-G:60@(DEN=F5N=&]R>2(*;7-G<W1R("));G9E;G1A<FEE<B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-30*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.`IM<V=I9"`B
M26YV97)T('-E;&5C=&EO;B(*;7-G<W1R("));G9E<G1E<F$@=7)V86PB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#(@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q.0HC.B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@R"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(DER86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$Q.`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM<V=S='(@
M(DER86LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#`@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q
M,PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<F5L86YD(@IM<V=S='(@(DER
M;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$U(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@;V8@36%N(@IM<V=S
M='(@(DES;&4@;V8@36%N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM<V=S
M='(@(D5N<W1A:V$@Y7-K<VMU<F%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,30*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$Q-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27-R
M865L(@IM<V=S='(@(DES<F%E;"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C(U(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C(V
M"FUS9VED("))<W-U97(B"FUS9W-T<B`B571FY')D870@878B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET
M86QI8R(*;7-G<W1R(")+=7)S:78B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$R,0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$U(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R"FUS9VED("))=&%L
M>2(*;7-G<W1R("))=&%L:65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,38*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,C,*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$Q-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC
M82(*;7-G<W1R(")*86UA:6-A(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C,W-PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#$T"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#(@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8U"FUS9VED(")*86YU87)Y(@IM<V=S='(@(FIA;G5A<FDB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#,@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-0HC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@S"FUS9VED(")*87!A;B(*;7-G<W1R(")*87!A;B(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M
M2E`I(@IM<V=S='(@(DIA<&%N<VL@*$E33RTR,#(R+4I0*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(R(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R(")*97)S97DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#,@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-`HC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@S"FUS9VED(")*;W)D86XB"FUS9W-T<B`B2F]R9&%N:65N(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X,PHC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#(P"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#@@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@
M(FIU;&DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,S@R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,3D*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M-R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*;7-G:60@
M(DIU;F4B"FUS9W-T<B`B:G5N:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS
M9W-T<B`B2G5S=&5R82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$U"FUS9VED(")*=7-T:69Y($-E;G1E<B(*
M;7-G<W1R(")#96YT97)J=7-T97)A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3<*;7-G:60@(DIU<W1I9GD@
M1G5L;"(*;7-G<W1R(")*=7-T97)A(&KD;70B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S<*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-`IM<V=I9"`B2G5S
M=&EF>2!,969T(@IM<V=S='(@(E;D;G-T97)J=7-T97)A(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Y"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,38*;7-G
M:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`B2/9G97)J=7-T97)A(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@V(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S8*(SH@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q.2!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0V"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR-C4*;7-G:60@(DME97`@
M;W)I9VEN86P_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,R!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3(V"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,C`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DME;GEA
M(@IM<V=S='(@(DME;GEA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U
M+G!H<#HX-2!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R
M8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M(")+97)B97)O<W-E<G9E<FX@879V:7-A9&4@875T96YT:7-E<FEN9V5N+B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE
M=V)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#`P(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B
M2V5Y($-R96%T:6]N(@IM<V=S='(@(DYY8VME;"!S:V%P860B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,#,@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B
M1FEN9V5R<')I;G0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,#$@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@
M3&5N9W1H(@IM<V=S='(@(DYY8VME;&SD;F=D(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#`P(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B3GEC:V5L='EP(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU.3D*;7-G:60@(DME>2!5<V%G92(*;7-G<W1R
M(").>6-K96QA;G;D;F1A;F1E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-S(Y(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<T,`IM<V=I
M9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R
M+B(*;7-G<W1R(").>6-K96P@9FEN;G,@<F5D86X@<.4@9&5N('!U8FQI:V$@
M;GEC:V5L<V5R=F5R;BXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*
M;7-G:60@(DMI9',B"FUS9W-T<B`B0F%R;B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-"!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3(Y"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,C$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@
M(DMI<FEB871I(@IM<V=S='(@(DMI<FEB871I(@H*(SH@8V]N9FEG+W1H96UE
M<R]K;VQA8BYP:'`Z.0IM<V=I9"`B2V]L86(B"FUS9W-T<B`B2V]L86(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#4@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,@HC.B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@U"FUS9VED(")+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!2
M97!U8FQI8R!O9B(*;7-G<W1R(").;W)D:V]R96$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,PHC.B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(S(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@U"FUS
M9VED(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B4WED:V]R96$B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B2V]R96%N("A%54,M
M2U(I(@IM<V=S='(@(DMO<F5A;G-K("A%54,M2U(I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S0*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$R-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-@IM
M<V=I9"`B2W5W86ET(@IM<V=S='(@(DMU=V%I="(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,R!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(W"B,Z(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,C4@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G
M:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B2VER9VES=&%N(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED("),85]Y;W5T(@IM<V=S='(@
M(DQA7WEO=70B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S"FUS
M9VED("),86YG=6%G92(*;7-G<W1R(")3<'+E:R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-R!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,W"B,Z(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,C8@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<*;7-G
M:60@(DQA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@
M(DQA;W,B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),87-T
M($AA;&8B"FUS9W-T<B`B4VES=&$@:&%L=F%N(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C<V"FUS9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G
M<W1R("),]G-E;F]R9"#D;F1R861E<R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HX-B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E
M<B(*;7-G<W1R(")3:7-T82!K=F%R=&%L970B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$U.`IM<V=I9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R(")396YA
M<W0@=7!P9&%T97)A9#HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW
M,3D@;&EB+TAO<F1E+T%U=&@N<&AP.C<Q-PHC+"!P:'`M9F]R;6%T"FUS9VED
M("),87-T(&QO9VEN.B`E<R(*;7-G<W1R(")396YA<W1E(&EN;&]G9VYI;F<Z
M("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S(Q(&QI8B](;W)D
M92]!=71H+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I
M;CH@)7,@9G)O;2`E<R(*;7-G<W1R(")396YA<W1E(&EN;&]G9VYI;F<Z("5S
M(&9RY6X@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,38@;&EB
M+TAO<F1E+T%U=&@N<&AP.C<Q-`IM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B
M"FUS9W-T<B`B4V5N87-T92!I;FQO9V=N:6YG.B!!;&1R:6<B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#D@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-@HC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@Y"FUS9VED("),871V:6$B"FUS9W-T<B`B3&5T=&QA;F0B"@HC.B!C;VYF
M:6<O=&AE;65S+VQA=F5N9&5R+G!H<#HV"FUS9VED("),879E;F1E<B(*;7-G
M<W1R("),879E;F1E<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM
M<V=I9"`B3&%W(@IM<V=S='(@(DQA9R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0IM<V=I9"`B3&%Y;W5T(@IM
M<V=S='(@(DQA>6]U="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D
M97(B"FUS9W-T<B`B3.1M;F$@=&]M(&;V<B!A='0@<W3D;F=A(&%V(&MA;G1L
M:6YJ92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,X
M"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C@@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQE8F%N;VXB"FUS9W-T<B`B3&EB
M86YO;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHV.0IM<V=I9"`B3&5F="(*;7-G<W1R(")6Y&YS=&5R(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q.2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,S$P-0IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B5N1N<W1E<G)U
M8G)I:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,34@;&EB+TAO
M<F1E+T9O<FTN<&AP.C,Q,#$*;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@
M(E;D;G-T97)VY')D96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$T,PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X"FUS9VED("),97-O=&AO(@IM
M<V=S='(@(DQE<V]T:&\B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-34*;7-G:60@(DQE=F5L(@IM<V=S='(@(DYI=N4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#@@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,@HC.B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,P(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X
M"FUS9VED("),:6)E<FEA(@IM<V=S='(@(DQI8F5R:6$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#D@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-PHC.B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y
M"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(DQI8GEE
M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX."!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30P"B,Z
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S(@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B
M3&EE8VAT96YS=&5I;B(*"B,Z(&-O;F9I9R]T:&5M97,O;&EG:'1B;'5E+G!H
M<#HV"FUS9VED("),:6=H="!";'5E(@IM<V=S='(@(DQJ=7-B;.4B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM<V=I9"`B
M3&EG:'0@1')I>GIL92(*;7-G<W1R(")$=6=G<F5G;B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"FUS9VED("),:6=H="!2
M86EN(@IM<V=S='(@(DSD='0@<F5G;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!286EN($5A<FQY
M(@IM<V=S='(@(DSD='0@9O9R;6ED9&%G<W)E9VXB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I
M;B!,871E(@IM<V=S='(@(DSD='0@969T97)M:61D86=S<F5G;B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS9VED("),
M:6=H="!286EN(%-H;W=E<B(*;7-G<W1R("),Y'1T(')E9VYS:W5R(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@
M(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@(DSD='0@<F5G;B!M
M960@Y7-K82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,Q"FUS9VED("),:6=H="!3;F]W(@IM<V=S='(@(DSD='0@<V[V(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G
M:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(DSD='0@<V[V<VMU<B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB
M"FUS9W-T<B`B3&EM97)I8VLB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.#$T(&QI8B](;W)D92]&;W)M+G!H<#HQ.#$X"FUS9VED("),:6YK(@IM
M<V=S='(@(DSD;FLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*
M;7-G<W1R("),Y&YK96X@<&5K87(@<.4Z(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@W-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W.0IM<V=I9"`B
M3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H
M96X@9&ES<&QA>6EN9R(*;7-G<W1R("),Y&YK82!E+7!O<W1A9')E<W-E;B!T
M:6QL(&9U;FMT:6]N96X@9O9R(&%T="!S:V%P82!N>71T(&UE9&1E;&%N9&4B
M"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAT;6PR=&5X="YP
M:'`Z,3@S"B,Z(&9R86UE=V]R:R]497AT+U1E>'0O1FEL=&5R+VAT;6PR=&5X
M="YP:'`Z,34X"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]H=&UL,G1E>'0N
M<&AP.C$X,@IM<V=I9"`B3&EN:W,B"FUS9W-T<B`B3.1N:V%R(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0V"FUS9VED("),:6YU>"!#;V]K:64B"FUS
M9W-T<B`B2V%K82(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C@V(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HT-@HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G:60@(DQI
M<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R("),:7-T82`M
M(&%N=N1N9&%R92!K86X@<V4@;6%P<&5N(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$S,PIM<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`B5FES82!D
M871A8F%S97(B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,0IM<V=I
M9"`B3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R(")6:7-A(&AJY&QPY&UN96XB
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,R"FUS9VED("),:7-T(%1A8FQE
M<R(*;7-G<W1R("),:7-T82!T86)E;&QE<B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O2&5A9&5R<RYP:'`Z-3DT(&QI8B](;W)D92]-24U%+TAE861E<G,N
M<&AP.C4Y-`IM<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S='(@(DQI<W0M07)C
M:&EV92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3@Y
M(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4X.0IM<V=I9"`B3&ES="U(
M96QP(@IM<V=S='(@(DQI<W0M2&5L<"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O2&5A9&5R<RYP:'`Z-3DV(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP
M.C4Y-@IM<V=I9"`B3&ES="U)9"(*;7-G<W1R("),:7-T+4ED(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3(@;&EB+TAO<F1E+TU)
M344O2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@
M(DQI<W0M3W=N97(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N
M<&AP.C4Y,R!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.3,*;7-G:60@
M(DQI<W0M4&]S="(*;7-G<W1R("),:7-T+5!O<W0B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TAE861E<G,N<&AP.C4Y,2!L:6(O2&]R9&4O34E-12](96%D
M97)S+G!H<#HU.3$*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(DQI
M<W0M4W5B<V-R:6)E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S
M+G!H<#HU.3`@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DP"FUS9VED
M("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(DQI<W0M56YS=6)S8W)I8F4B
M"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(D1E="!G
M:6-K(&EN=&4@871T(&QI<W1A('-E<W-I;VYE<CH@)7,B"@HC.B!A9&UI;B]S
M97-S:6]N<RYP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!U
M<V5R<R!F86EL960Z("5S(@IM<V=S='(@(D1E="!G:6-K(&EN=&4@871T(&QI
M<W1A(&%N=N1N9&%R93H@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N
M;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N
M(@IM<V=S='(@(DQI<W1N:6YG(&%V(&%N=N1N9&%R92!A=F%K=&EV97)A9"XB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G:60@(DQI=&5R871U
M<F4B"FUS9W-T<B`B3&ET=&5R871U<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.2!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,30T"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,S,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI
M=&AU86YI82(*;7-G<W1R("),:71A=65N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6UA9V5S+G!H<#HX,PHC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O:6UA9V5S+G!H<#HW-PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R
M("),861D87(N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C`P"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B3&]K86P@=&ED.B`B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#8*;7-G:60@(DQO8V%L92!A
M;F0@5&EM92(*;7-G<W1R(")296=I;VYA;'0B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4W,0HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C4W,"!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4W,@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-3<@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z-S(*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(E!L871S(@H*(SH@;&]G
M:6XN<&AP.C$X.2!S97)V:6-E<R]P;W)T86PO;65N=2YP:'`Z,38S('-E<G9I
M8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,#`*(SH@=&5M<&QA=&5S+VQO9VEN
M+VUO8FEL92YI;F,Z,R!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-0HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDP('1E;7!L871E<R]G=65S
M="]G=65S="YI;F,Z,S`*;7-G:60@(DQO9R!I;B(*;7-G<W1R("),;V=G82!I
M;B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B
M3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO;65N=2YP:'`Z,34W('-E<G9I8V5S+W!O<G1A;"]S
M:61E8F%R+G!H<#HQ.30*;7-G:60@(DQO9R!O=70B"FUS9W-T<B`B3&]G9V$@
M=70B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-3D*;7-G:60@(DQO9VEN
M(@IM<V=S='(@(DQO9VEN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q
M,`IM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B3&]G:6YA:W1I=FET971E
M<B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY-B!L:6(O2&]R9&4O
M075T:"YP:'`Z.3DU"FUS9VED("),;V=I;B!F86EL960@8F5C875S92!Y;W5R
M('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY
M+B(*;7-G<W1R("(B"B));FQO9V=N:6YG(&UI<W-L>6-K861E<RX@5')O;&EG
M='9I<R!V87(@86YVY&YD87)N86UN(&5L;&5R(&SV<V5N;W)D("(*(F9E;&%K
M=&EG="XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.3(@;&EB+TAO
M<F1E+T%U=&@N<&AP.CDY,0IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R
M("));FQO9V=N:6YG(&UI<W-L>6-K861E<RXB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,S8U(&QI8B](;W)D92]&;W)M+G!H<#HQ,S8Y"FUS9VED
M("),;VYG('1E>'0B"FUS9W-T<B`B3.5N9R!T97AT(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C0X"FUS9VED("),;W9E(@IM<V=S='(@(DOD<FQE:R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS
M9VED("),;W<B"FUS9W-T<B`B3.5G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@
M9W)E96L@;&5T=&5R<R(*;7-G<W1R(")'<F5K:7-K82!G96UE;F5R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("),871I
M;G-K82!G96UE;F5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M
M8F5R<R(*;7-G<W1R(")3;>4@<F]M97)S:V$@<VEF9G)O<B(*"B,Z(&-O;F9I
M9R]T:&5M97,O;'5C+G!H<#HV"FUS9VED("),;WEO;&$B"FUS9W-T<B`B3&]Y
M;VQA(@H*(SH@8V]N9FEG+W1H96UE<R]L=6-B;'5E+G!H<#HV"FUS9VED("),
M;WEO;&$@0FQU92(*;7-G<W1R("),;WEO;&$@0FSE(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#4*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$S-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.0IM
M<V=I9"`B3'5X96UB;W5R9R(*;7-G<W1R("),=7AE;6)U<F<B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<V"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3,*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,2!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C4P"FUS9VED(")-32(*;7-G<W1R(")-32(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR.#,*;7-G:60@(DU/5$0B"FUS9W-T<B`B34]41"(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,V(&QI8B](
M;W)D92]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!
M='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")-4RU43D5&
M(&)I;&%G82!I;FYE:/9L;"!I;F=E;B!D871A+B(*"B,Z(&9R86UE=V]R:R].
M;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z
M,S<*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N
M<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B35-'(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3<*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$S-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,@IM
M<V=I9"`B36%C86\B"FUS9W-T<B`B36%C86\B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$U,PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,V(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDQ"FUS9VED
M(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B
M"FUS9W-T<B`B36%C961O;FEE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,34Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,"!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,34Q"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,S<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUA9&%G
M87-C87(B"FUS9W-T<B`B36%G86=A<VMA<B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT.0IM<V=I9"`B36%G:6,B"FUS9W-T<B`B36%G:7-K(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@S"FUS9VED(")-86EL(@IM<V=S
M='(@(D4M<&]S="(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,C0*
M;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`B12UP;W-T861M:6XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B4VMA<&$@;.1N:RXN
M+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38U"B,Z
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S@@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&%W:2(*;7-G<W1R(")-86QA=VDB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.34@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-PHC.B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDU"FUS9VED(")-86QA>7-I82(*;7-G<W1R(")-86QA>7-I
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38T"B,Z
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#`@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(DUA;&1I
M=F5R;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3(@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U
M-`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86QI(@IM<V=S='(@(DUA;&DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.30@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,@HC.B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDT"FUS9VED(")-86QT82(*;7-G<W1R(")-86QT82(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-`IM<V=I9"`B(@HB36%N86=E('1H
M92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@
M=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T
M96=O<FEE<RXB"FUS9W-T<B`B(@HB56YD97)HY6QL(&QI<W1A;B!M960@:V%T
M96=O<FEE<B!D=2!A;G;D;F1E<B!F]G(@871T(&MA=&5G;W)I<V5R82!P;W-T
M97(@;65D("(*(F]C:"!FY')G97)N82!S;VT@=&EL;&CV<B!D97-S82!K871E
M9V]R:65R+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,3(U"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,34V"FUS9VED(")-87`R-"!M87`B"FUS9W-T<B`B36%P,C0M:V%R=&$B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U
M-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$T
M,`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X-PHC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$W,0IM<V=I
M9"`B36%P475E<W0@;6%P(@IM<V=S='(@(DUA<%%U97-T+6MA<G1A(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG
M<R!S=&]R960N(@IM<V=S='(@(M9V97)SY'1T;FEN9V%R('-P87)A9&4N(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W.0HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$V"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#0@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED(")-87)C:"(*
M;7-G<W1R(")M87)S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT,0IM<V=I9"`B36%R9VEN(@IM<V=S='(@(DUA
M<F=I;F%L(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.#@@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C0X"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W
M:71H(%-E96XO56YS965N(&9L86=S(@IM<V=S='(@(D9L86=G82!S;VT@;.1S
M="]O;.1S="(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C@Y(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HT.0HC.B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@
M=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM
M<V=S='(@(D9L86=G82!M960@86YN86X@<W1A='5S("AT(&5X('9I:W1I9W0O
M8F5S=F%R870I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-3(*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,R!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%R<VAA;&P@27-L86YD
M<R(*;7-G<W1R(")-87)S:&%L;/9A<FYA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-3D*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$T-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B
M36%R=&EN:7%U92(*;7-G<W1R(")-87)T:6YI<75E(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*
M;7-G<W1R(")-871C:&%N9&4@9N1L="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,R!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,38P"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-#4@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA
M=7)I=&%N:6$B"FUS9W-T<B`B36%U<FET86YI96XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,PHC.B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30V(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS
M9VED(")-875R:71I=7,B"FUS9W-T<B`B36%U<FET:75S(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED(")-87@@
M86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(DUA>"!T:6QLY71E;B!K<F5D:70N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`X"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X
M"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB"FUS9W-T<B`B
M1W+D;G,@9O9R(&UA>"!A;G1A;"!D96QA<B!I(&UE9&1E;&%N9&4@]G9E<G-K
M<FED96XN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3,*;7-G:60@(DUA
M>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R(")(]F=S=&$@=&5M<&5R
M871U<F4@<V5N87-T92`R-"!T:6UM87)N83H@(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,#4*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM
M<V=S='(@(DCV9W-T82!T96UP97)A='5R92!S96YA<W1E(#8@=&EM;6%R;F$Z
M("(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS9VED(")-87AI;75M($YU;6)E<B!O
M9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@(DUA>&EM86QT(&%N=&%L('!O<G1A
M;&)L;V-K(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DX(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(S.2!L:6(O2&]R9&4O1F]R;2YP:'`Z.3`R(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,C(Q"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C0S"FUS9VED
M(")-87AI;75M(&QE;F=T:"(*;7-G<W1R(")-87AI;6%L(&SD;F=D(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X,0HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$X"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#8@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS9W-T
M<B`B;6%J(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C4S"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#<@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")-87EO='1E(@IM<V=S='(@
M(DUA>6]T=&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*;7-G:60@
M(DUE9&EC:6YE(@IM<V=S='(@(DUE9&EC:6XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4S,0IM<V=I9"`B365E=&EN
M9R!#86YC96QL871I;VXB"FUS9W-T<B`B079B;VMA(&WV=&4B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4P,PIM<V=I
M9"`B365E=&EN9R!);F9O<FUA=&EO;B(*;7-G<W1R(")-]G1E<VEN9F]R;6%T
M:6]N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HU,#D*;7-G:60@(DUE971I;F<@4')O<&]S86PB"FUS9W-T<B`B3?9T
M97-F]G)F<N5G86XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C4R-0IM<V=I9"`B365E=&EN9R!297!L>2(*;7-G<W1R
M(")-]G1E<W-V87(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C4Q-`IM<V=I9"`B365E=&EN9R!5<&1A=&4B"FUS9W-T
M<B`B3?9T97-U<'!D871E<FEN9R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3$Y"FUS9VED(")-965T:6YG(%5P9&%T
M92!297%U97-T(@IM<V=S='(@(E5P<&1A=&5R:6YG<V)E9^1R86X@;VT@;?9T
M92(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,38*;7-G
M:60@(DUE;6)E<G,B"FUS9W-T<B`B365D;&5M;6%R(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,X,@IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R(")-
M96YY;.1G93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R(")3
M;.4@:6AO<"!C96QL97(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z(&QI8B](;W)D
M92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DUE<W-A9V4B"FUS
M9W-T<B`B365D9&5L86YD92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,C$V(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C$V"FUS
M9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE
M('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92`B"B)V97)I9FEE
M9"XB"FUS9W-T<B`B(@HB365D9&5L86YD970@=F5R:69I97)A9&5S(&UE;B!D
M96X@<VEG;F5R861E<R!C97)T:69I:V%T(&MU;F1E(&EN=&4@=F5R:69I97)A
M<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,3`*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,3`*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS9W-T<B`B365D9&5L86YD
M92!GY&QL97(@:6YT92!LY&YG<F4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V,`HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Y(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,#(*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR,C<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR-C`*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R(")-961D96QA;F1E
M='EP(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS9VED(")-971A<B!7
M96%T:&5R(@IM<V=S='(@(DUE=&%R=N1D97(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,W"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R(")-971A<F)L;V-K970@Y'(@:6YT92!T:6QL9^1N9VQI="XB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q.0IM<V=I9"`B(@HB365T87(@8FQO
M8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O
M<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB365T87(M8FQO8VL@
M96H@=&EL;&?D;F=L:6=T+B!$971A;&IE<B!H87(@;&]G9V%T<R!F]G(@<WES
M=&5M861M:6YI<W1R873V<F5N+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-3,*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB
M"FUS9W-T<B`B365T87)$0B#D<B!I;G1E(&%N<VQU=&5N+B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HW,0HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O<F%R+G!H<#HV-R!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H
M<#HW-`IM<V=I9"`B365T:&]D(@IM<V=S='(@(DUE=&]D(@H*(SH@9G)A;65W
M;W)K+U)00R]24$,O>&UL<G!C+G!H<#HX,2!F<F%M97=O<FLO4E!#+U)00R]S
M;V%P+G!H<#HQ,3<*(SH@;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP.C@Q(&QI
M8B](;W)D92]24$,O<V]A<"YP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@
M(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`B365T;V1E
M;B`G)7,G(.1R(&EN=&4@9&5F:6YI97)A9"(*"B,Z(&9R86UE=V]R:R]24$,O
M4E!#+W)E<W0N<&AP.C8Q(&QI8B](;W)D92]24$,O<F5S="YP:'`Z.#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL960@
M;65T:&]D.B`E<R(*;7-G<W1R(")-971O9&5N(&AA<B!I;G1E(&1E9FEN97)A
M=',N($%N<F]P860@;65T;V0Z("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C8W(&QI8B]";&]C:R]M971A<BYP:'`Z.#(*;7-G:60@(DUE
M=')I8R(*;7-G<W1R(")-971R:7-K(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-C8*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$T."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X
M:6-O(@IM<V=S='(@(DUE>&EK;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HX-0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<R"FUS9VED(")-:6-R;VYE
M<VEA+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(DUI:W)O;F5S:65N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<V"FUS9VED(")-:61D;&4B"FUS9W-T<B`B36ET=&5N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS
M9W-T<B`B36EM971Y<"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$W"FUS
M9VED(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B3.1G<W1A
M('1E;7!E<F%T=7(@<V5N87-T92`R-"!T:6UM87)N83H@(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS,#D*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R
M<SH@(@IM<V=S='(@(DSD9W-T82!T96UP97)A='5R('-E;F%S=&4@-B!T:6UM
M87)N83H@(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,SD@
M;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-#,Y"FUS9VED(")-:6YI;75M('!A
M<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D(@IM<V=S='(@(DUI;G-T
M82!L]G-E;F]R9'/E;&1E<B!H87(@:6YT92!U<'!NY71T<R#D;B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,3<*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-0IM<V=I9"`B36ER
M<F]R(@IM<V=S='(@(E-P96=L82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU,0IM<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R(")$:79E<G-E(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-S(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S0P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M,C4P(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#`@;&EB+TYE="]335,O
M=VEN7VAT='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@
M2%144%]297%U97-T+B(*;7-G<W1R(")/8FQI9V%T;W)I<VMT('!A:V5T('-A
M:VYA<R`H4$5!4B!(5%107U)E<75E<W0I+B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ,34*;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@
M66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S
M92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"B)+;VYF:6=U<F%T
M:6]N('-A:VYA<RX@1'4@;>5S=&4@<VMA<&$@9&5N(&YU(&]M(&1U('9I;&P@
M86YVY&YD82!D96X@:.1R("(*(F%P<&QI:V%T:6]N96XN(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`T"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`T"FUS9VED(")-:7-S
M:6YG(&UE<W-A9V4@240N(@IM<V=S='(@(E-A:VYA<B!M961D96QA;F1E+4E$
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M
M='`N<&AP.C4X"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA
M:6PN(@IM<V=S='(@(D]B;&EG871O<FES:W0@<&%K970@<V%K;F%S("A014%2
M($UA:6PI+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y-`HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y-`IM<V=I9"`B36ES<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R(")3
M86MN87(@<V5S<VEO;G,M240N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`B3>4B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S8*;7-G:60@(DUO8FEL92!-
M86EL(@IM<V=S='(@(DUO8FEL(&4M<&]S="(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"FUS9VED(")-;V1E<F%T92(*;7-G
M<W1R(")-;V1E<F5R82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C8@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HW,`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@X
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8V"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]Z:7`N<&AP.C<S(&QI8B](;W)D92]-24U%+U9I97=E
M<B]T9WHN<&AP.C@U"FUS9VED(")-;V1I9FEE9"!$871E(@IM<V=S='(@(L1N
M9')A9"!D871U;2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D:69Y(%523"(*;7-G<W1R
M("+$;F1R82!LY&YK(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV-S,@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-S0*;7-G:60@
M(DUO9'5L=7,B"FUS9W-T<B`B36]D=6QU<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,"!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,34P"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-3`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@
M(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUO;&1A=FEE;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY,"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30Y"B,Z(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3$@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R(")-;VYA8V\B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3(@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-@HC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R(")-;VYG;VQI970B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DT(&QI8B](;W)D92]&;W)M
M+G!H<#HR-3@X"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R(")-Y6YA
M9"!O8V@@Y7(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C4W(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z-3<*;7-G:60@
M(DUO;G1H;'DB"FUS9W-T<B`B3>5N871L:6<B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$V,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$V,0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34S(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS9VED
M(")-;VYT<V5R<F%T(@IM<V=S='(@(DUO='-E<G)A="(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O
M;B!0:&%S97,B"FUS9W-T<B`B3>5N9F%S97(B"@HC.B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HQ-S(@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M,C4S"B,Z(&QI8B]&:6QE+T-35BYP:'`Z,3DV(&QI8B]&:6QE+T-35BYP:'`Z
M,C@P"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN
M(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N(@IM<V=S='(@(D9L97(@
M9N1L="!H:71T861E<R!PY2!R860@)60@Y&X@9&5T(&;V<G;D;G1A9&4@)60N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDP(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#@*(SH@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-"!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R(")-87)O8VMO
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*
M;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R(")-97-T861E;',@:VQA<G0B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-`IM
M<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R(")-97-T861E;',@;6]L;FEG
M="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,U
M"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B365S=&%D96QS('-O;&EG
M="(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4P.2!L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HU,#D*(SH@;&EB+TAO<F1E+T)L
M;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-#@*;7-G:60@(DUO=F4@1&]W;B(*
M;7-G<W1R(")&;'ET=&$@;F5D(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z-3$S(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C4Q
M,PHC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U,@IM
M<V=I9"`B36]V92!,969T(@IM<V=S='(@(D9L>71T82!VY&YS=&5R(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$W(&QI8B](;W)D
M92]";&]C:R],87EO=70N<&AP.C4Q-PHC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C8U-@IM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R
M(")&;'ET=&$@:/9G97(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HU,#4@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-3`U"B,Z
M(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C0T"FUS9VED
M(")-;W9E(%5P(@IM<V=S='(@(D9L>71T82!U<'`B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#DY"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HU,C8*;7-G:60@(DUO=F4@9&]W;B(*
M;7-G<W1R(")&;'ET=&$@;F5D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0Y.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#DY"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HU,C4@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C4R-@IM<V=I9"`B36]V92!U<"(*;7-G<W1R(")&;'ET=&$@=7!P(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDU(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C@*(SH@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-2!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY-0IM<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R(")-;^=A;6)I
M<75E(@H*(SH@8V]N9FEG+W1H96UE<R]M;WII;&QA+G!H<#HV"FUS9VED(")-
M;WII;&QA(@IM<V=S='(@(DUO>FEL;&$B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,3@T(&QI8B](;W)D92]&;W)M+G!H<#HR,3@X"FUS9VED(")-
M=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B1FQE<FYI=N5S
M;&ES=&$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3`R-PHC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3`U.`IM<V=I9"`B375L=&EM87`@54L@;6%P(@IM<V=S='(@(DUU;'1I;6%P
M(%-T;W)B<FET86YN:65N:V%R=&$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,C0R(&QI8B](;W)D92]&;W)M+G!H<#HR,C0V"FUS9VED(")-=6QT
M:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B1FQE<G9A;"(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT,#(*;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T
M<B`B36ET="!K;VYT;R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.`IM
M<V=I9"`B37D@06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R(")-:6X@:V]N
M=&]I;F9O<FUA=&EO;B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z
M-#4*;7-G:60@(DUY(%!O<G1A;"(*;7-G<W1R(")-:6X@<&]R=&%L(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C0S"FUS9VED(")->2!0;W)T86P@
M3&%Y;W5T(@IM<V=S='(@(DUI;B!P;W)T86QL87EO=70B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3(@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-0HC.B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34V(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR
M"FUS9VED(")->6%N;6%R(@IM<V=S='(@(DUY86YM87(B"@HC.B!T96UP;&%T
M97,O;6%I;G1E;F%N8V4O86=R965M96YT7V)O='1O;2YI;F,Z-PHC.B!T96UP
M;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-PIM<V=I9"`B
M3D\L($D@1&\@3D]4($%G<F5E(@IM<V=S='(@(DY%2BP@2F%G(&%C8V5P=&5R
M87(@:6YT92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0P
M,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3@S(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,0HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$P,B!L:6(O2&]R9&4O34E-12]6:65W97(O=&YE
M9BYP:'`Z,S@*;7-G:60@(DYA;64B"FUS9W-T<B`B3F%M;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38Y"B,Z(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-3<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.34*;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B3F%M:6)I82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<X"B,Z(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-3@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(DYA=7)U(@H*(SH@8V]N9FEG+W1H
M96UE<R].95A49W)E>2YP:'`Z-@IM<V=I9"`B3F585"(*;7-G<W1R(").95A4
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HW,#8*;7-G:60@(DYE961S($%C=&EO;B(*;7-G<W1R(")"96CV=F5R(.5T
M9^1R9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<W
M"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3D@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE<&%L(@IM<V=S='(@(DYE<&%L
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDW(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S4*(SH@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,"!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B3F5D
M97)LY&YD97)N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H97)L86YD<R!!;G1I
M;&QE<R(*;7-G<W1R(").961E<FSD;F1S:V$@06YT:6QL97)N82(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@Q(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P92!"87-E(%523"(*
M;7-G<W1R(").97-C87!E(&)A<RU54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4X,R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4X-`IM<V=I9"`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#4@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C87!E
M($-!('!O;&EC>2!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.#0@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU.#4*;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@(DYE
M='-C87!E(&;V<FYY96QS92U54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4X,B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X
M,PIM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B3F5T
M<V-A<&4@Y71E<FMA;&QE;'-E+5523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@V(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3@W"FUS9VED(").971S8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B
M3F5T<V-A<&4@4U-,+7-E<G9E<FYA;6XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4X-R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4X.`IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G
M<W1R(").971S87!E(&-E<G1I9FEK871S:V]M;65N=&%R(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#`@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E('1Y
M<&4B"FUS9W-T<B`B3F5T<V%P92!C97)T:69I:V%T<W1Y<"(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR-3,*;7-G:60@(DYE='=O<FLB"FUS9W-T
M<B`B3N1T=F5R:R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q-"!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C4*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,S.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDP"FUS
M9VED(").979E<B(*;7-G<W1R(")!;&1R:6<B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$W,`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38R(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED
M(").97<@0V%L961O;FEA(@IM<V=S='(@(DYY82!+86QE9&]N:65N(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3`*
M(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3`*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,C8*;7-G
M:60@(DYE=R!#871E9V]R>2(*;7-G<W1R(").>2!K871E9V]R:2(*"B,Z(&QI
M8B](;W)D92]497AT+T9I;'1E<B]E;6%I;',N<&AP.C@Q(&QI8B](;W)D92]4
M97AT+T9I;'1E<B]E;6%I;',N<&AP.C@W"B,Z(&QI8B](;W)D92]497AT+T9I
M;'1E<B]E;6%I;',N<&AP.CDW(&QI8B](;W)D92]497AT+T9I;'1E<B]E;6%I
M;',N<&AP.C$P,0HC+"!P:'`M9F]R;6%T"FUS9VED(").97<@365S<V%G92!T
M;R`E<R(*;7-G<W1R(").>71T(&UE9&1E;&%N9&4@=&EL;"`E<R(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB
M+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`B
M3GEMY6YE(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS
M-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B3GET
M="!A;G;D;F1A<FYA;6X@*'9A;&9R:71T*2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY."!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3@P"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-C,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@
M(DYE=R!:96%L86YD(@IM<V=S='(@(DYY82!:965L86YD(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,W"FUS9VED(").97<@<&%S<W=O<F0B
M"FUS9W-T<B`B3GET="!L]G-E;F]R9"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<W%L+G!H<#HR,C<@;&EB+TAO<F1E+T%U=&@O<W%L+G!H<#HR,C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N
M("5X+B(*;7-G<W1R(").>71T(&SV<V5N;W)D(&MO;6UE<B!A='0@9^4@=70@
M)7@N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R"FUS9VED
M(").97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*;7-G<W1R("),]G-E;F]R
M9"!MY7-T92!V87)A('-A;6UA+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N
M:RDB"FUS9W-T<B`B3GET="!F]FYS=&5R("A?8FQA;FLI(@H*(SH@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z-#`@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.3$*;7-G:60@(DYE=W,B"FUS
M9W-T<B`B3GEH971E<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M,#<*;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T<B`B3GEH971S9W)U<'!E<B(*
M"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$U('1E;7!L871E<R]D
M871A+V1A=&5M87`N:6YC.C0Q"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z,3(Y('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(U"FUS9VED(").
M97AT(@IM<V=S='(@(D[D<W1A(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W
M"FUS9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@(DMO;6UA;F1E(#0@9F%S
M97(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W,"!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W-`HC.B!L:6(O2&]R9&4O4')E
M9G,O54DN<&AP.C,V-B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,W,`IM<V=I
M9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@(D[D<W1A(&EN<W3D;&QN:6YG87(B
M"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C$P,R!L:6(O2&]R9&4O
M54DO4&%G97(N<&AP.C$P,PIM<V=I9"`B3F5X=#XB"FUS9W-T<B`B3N1S=&$^
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDV(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S0*(SH@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-"!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEC87)A9W5A(@IM<V=S='(@(DYI8V%R
M86=U82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<Q
M"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C4@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R(@IM<V=S='(@(DYI9V5R
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDV(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S,*(SH@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*;7-G<W1R(").:6=E<FEA
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V.0IM<V=I9"`B
M3FEG:'0B"FUS9W-T<B`B3F%T="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-R!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3<Y"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-C<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYI=64B
M"FUS9W-T<B`B3FEU92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HY,S4*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.CDV-@IM<V=I9"`B3F\B"FUS9W-T<B`B3F5J(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS9VED(").;R!A=F%I;&%B
M;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R
M+B(*;7-G<W1R(")$970@9FEN;G,@:6YG970@:V]N9FEG=7)A=&EO;G-D871A
M(&%T="!V:7-A('-K:6QL;F%D97(@9O9R+B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z,3`U"B,Z(&9R86UE=V]R:R]61E-?
M25-/+TE33U=R:71E<BYP:'`Z,3$Q(&QI8B]61E,O25-/5W)I=&5R+G!H<#HQ
M,#8*;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E3
M3R!I;6%G97,N(@IM<V=S='(@(DEN9V5N('1I;&QGY&YG;&EG('-T<F%T96=I
M(&;V<B!A='0@<VMA<&$@25-/+6EM86=E+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PHC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M
M<&QA=&4N(@IM<V=S='(@(DEN=&4@96X@8F%T8VAM86QL+B(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<Y(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C(T-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HR-C<@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z
M-SD*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,C0U(&QI8B](;W)D
M92]";&]C:R],87EO=70N<&AP.C(V-PHC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C$P,0HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.C,X-0HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.C0P-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R
M97%U97-T960@<&]S:71I;VXB"FUS9W-T<B`B1&5T(&9I;FYS(&EN9V5T(&)L
M;V-K('#E(&1E;B!B96?D<F1A('!O<VET:6]N96XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VUC86PN<&AP.C4P(&QI8B](;W)D92]!=71H+VUC86PN<&AP
M.C4P"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("));F=E="!K86QE;F1E<FYA;6X@
M9O9R($U#04P@875T96YT:7-E<FEN9R!A;F=I=F5T+B(*"B,Z(&%D;6EN+W-E
M='5P+V1I9F8N<&AP.C4T"FUS9VED(").;R!C:&%N9V4N(@IM<V=S='(@(DEN
M9V5N(.1N9')I;F<N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HQ-38@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(DYO(&-H
M:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S
M='(@(DEN9V$@=6YD97)B96CV<FEG:&5T97(@:V%N(&SD9V=A<R!T:6QL(&1E
M;B!HY'(@8F5H]G)I9VAE=&5N+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,38W(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#@R"B,Z(&9R
M86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<W,R!L:6(O2&]R9&4N<&AP.C$V.2!L
M:6(O2&]R9&4N<&AP.C4P.`HC.B!L:6(O2&]R9&4O571I;"YP:'`Z-S8X"B,L
M('!H<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B26YG96X@:V]N9FEG=7)E
M<FEN9W-I;F9O<FUA=&EO;B!A;F=I=F5N(&;V<B`E<RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C@R-"!L:6(O5D93+V9T<"YP:'`Z.#4U"FUS
M9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@1E10(%9&4RXB"FUS9W-T<B`B26YG96X@:V]N9FEG=7)E<FEN9W-I;F9O
M<FUA=&EO;B!A;F=I=F5N(&;V<B!&5%`@5D93+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z-C8Y(&QI8B]61E,O<W%L+G!H<#HV-S(*;7-G:60@
M(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!3
M44P@5D93+B(*;7-G<W1R("));F=E;B!K;VYF:6=U<F5R:6YG<VEN9F]R;6%T
M:6]N(&%N9VEV96X@9O9R(%-13"!61E,N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C<Q-R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HW,C4*
M;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(DEN9V5N(&MO;F9I9W5R97)I
M;F=S:6YF;W)M871I;VX@86YG:79E;B!F]G(@4U%,+69I;"!61E,N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$T
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$T"FUS9VED
M(").;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B26YG96X@:W)E9&ET(&MV87(N
M(@H*(SH@9G)A;65W;W)K+TQI;FMS+TQI;FMS+G!H<#HR-38*(SH@9G)A;65W
M;W)K+U)E;&%T:6]N<VAI<"]296QA=&EO;G-H:7!-86YA9V5R+G!H<#HR-3$*
M;7-G:60@(DYO(&1E<V-R:7!T:6]N(&9O=6YD(@IM<V=S='(@(D)E<VMR:79N
M:6YG('-A:VYA<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S-`HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,T"FUS9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS
M9W-T<B`B26YG96X@;6]T=&%G87)E(&%N9VEV96XN(@H*(SH@9G)A;65W;W)K
M+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#<R(&QI8B](;W)D92]"<F]W<V5R+G!H
M<#HY,C`*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B26YG96X@
M9FEL('5P<&QA9&1A9"(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HW,0IM
M<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@(DEN9V$@:6MO;F5R(&AI
M='1A9&5S+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,38@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,3,P"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(DEN
M9V5N(&]R="!A;F=I=F5N+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-3<*;7-G:60@(DYO(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R
M("));F=E;B!O<G0@86YG:79E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S,PHC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").;R!M97-S86=E('-U<'!L:65D
M+B(*;7-G<W1R("));F=E="!M961D96QA;F1E(&)I9F]G861E<RXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS9VED(").
M;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B26YG970@;F%M;B!A;F=I=F5T
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,W"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*
M;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I960N(@IM<V=S='(@(DEN9V5N(&YU
M;6UE<B!A;F=I=F5T+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-`IM
M<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(DEN9V$@;V;V
M<G-KY&UD82!V:7-H971S;W)D(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H
M='1P+G!H<#HY,2!L:6(O2&]R9&4O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(DEN9V5T(&SV<V5N;W)D(&;V<B!(5%10+6%U=&5N=&ES97)I
M;F<@86YG:79E="XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP
M.C$P."!L:6(O2&]R9&4O075T:"]I;6%P+G!H<#HQ,#@*;7-G:60@(DYO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R("));F=E="!L]G-E;F]R9"!F]G(@24U!4"UA=71E;G1I<V5R:6YG(&%N
M9VEV970N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW,B!L
M:6(O2&]R9&4O075T:"]K<F(U+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M("));F=E="!L]G-E;F]R9"!F]G(@2V5R8F5R;W,M875T96YT:7-E<FEN9R!A
M;F=I=F5T+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z-S<@
M9G)A;65W;W)K+T%U=&@O075T:"]L;V=I;BYP:'`Z.#0*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]P86TN<&AP.C<U(&QI8B](;W)D92]!=71H+W-A<VPN<&AP
M.C<W"B,Z(&QI8B](;W)D92]!=71H+VQO9VEN+G!H<#HX-"!L:6(O2&]R9&4O
M075T:"]P86TN<&AP.C<U"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@3&]G:6X@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DEN9V5T(&SV<V5N
M;W)D(&;V<B!,;V=I;BUA=71E;G1I<V5R:6YG(&%N9VEV970N(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]P87-S=V0N<&AP.C$S-2!L:6(O2&]R9&4O075T
M:"]P87-S=V0N<&AP.C$S-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B26YG970@;/9S
M96YO<F0@9O9R(%!!4U-71"UA=71E;G1I<V5R:6YG(&%N9VEV970N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C@T(&QI8B](;W)D92]!=71H
M+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!3
M34(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DEN9V5T(&SV<V5N;W)D(&;V
M<B!334(M875T96YT:7-E<FEN9R!A;F=I=F5T+B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X-B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C$R.#<*;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y34TP@
M8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S
M87)Y('1O("(*(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@
M(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS9W-T<B`B26YG82!VY&YT86YD92!R
M96=I<W1R97)I;F=A<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-S0X
M"FUS9VED(").;R!Q=6]T82!S970B"FUS9W-T<B`B26YG96X@:W9O=&$@86YG
M:79E;B(*"B,Z(&QI8B]61E,N<&AP.C<V-@IM<V=I9"`B3F\@<75O=&$@<V5T
M+B(*;7-G<W1R("));F=E;B!K=F]T82!A;F=I=F5N+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*;7-G:60@
M(DYO(')U;&5S(@IM<V=S='(@(DEN9V$@<F5G;&5R(@H*(SH@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z-#0Y(&QI8B]&:6QE+T-35BYP:'`Z-#@R"FUS
M9VED(").;R!S97!A<F%T;W(@<W!E8VEF:65D+B(*;7-G<W1R("));F=E;B!A
M=F=RY&YS87)E(&%N9VEV96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`IM<V=I9"`B3F\@<VED97,B"FUS
M9W-T<B`B26YG82!S:61O<B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z-3@S(&QI8B]61E,O<VUB+G!H<#HU.#<*;7-G:60@(DYO('-U8V@@9FEL
M92(*;7-G<W1R("));F=E;B!SY61A;B!F:6PB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3(V"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T
M;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(DEN9V5N('1E;7!O
M<N1R:V%T86QO9R!T:6QL9^1N9VQI9R!F]G(@8V%C:&4N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C$@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S,0HC.B!L:6(O3F5T+U--4R]W:6Y?
M:'1T<"YP:'`Z,C(Q"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O
M<F0@<V5N="XB"FUS9W-T<B`B26YG970@86YVY&YD87)N86UN(&]C:"]E;&QE
M<B!L]G-E;F]R9"!S:VEC:V%T+B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM
M;')P8RYP:'`Z,30P(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G
M:60@(DYO('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@(DEN9V5T
M(&=I;'1I9R!834PM9&%T82!R971U<FYE<F%D97,B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.30S"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HY-3,*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV-`HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@Q"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HY-S0@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.CDX-`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.3DU"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,#$R"FUS9VED(").;R!V86QU97,B"FUS9W-T<B`B26YG82!VY')D
M96XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V
M97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N
M97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB26YG96X@=F5R<VEO
M;B!H:71T861E<R!I(&1E;B!U<G-P<G5N9VQI9V$@:V]N9FEG=7)A=&EO;F5N
M+B#%=&5R<VMA<&$@(@HB:V]N9FEG=7)A=&EO;F5N+B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@
M>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(DEN9V5N('9E<G-I;VX@:&ET=&%D97,@:2!D:6X@:V]N9FEG
M=7)A=&EO;BX@Q71E<G-K87!A(&MO;F9I9W5R871I;VYE;BXB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8P-`IM<V=I
M9"`B3F]N(%!A<G1I8VEP86YT(@IM<V=S='(@(DEC:V4M9&5L=&%G87)E(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$V"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-38P(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C0R-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0U"B,Z('1E;7!L871E<R]P<F5F
M<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3,*;7-G:60@(DYO;F4B"FUS9W-T<B`B
M26YG96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDP"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(DEN
M9V5N("AA;G;D;F0@=6YD97)F]G)S=.5D9"DB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y,@IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDV(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S(*
M(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V."!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T
M<B`B3F]R9F]L:_9A<FYA(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI
M8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R
M92(*;7-G<W1R(").;W)R82!H96UI<V;D<F5N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-3@*(SH@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$V.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I
M9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S='(@(DYO<G)A($UA
M<FEA;F'V87)N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-R!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3<V"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S`@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYO<G=A>2(*;7-G<W1R
M(").;W)G92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C0P(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0Q"FUS9VED(").;W0@
M069T97(B"FUS9W-T<B`B26YT92!E9G1E<B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C,Y(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-C0P"FUS9VED(").;W0@0F5F;W)E(@IM<V=S='(@(DEN=&4@9O9R92(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0P."!L:6(O5D93+V9I
M;&4N<&AP.C0Q-0IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@(DEN
M=&4@96X@:V%T86QO9R(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<BYP:'`Z-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#,*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP
M:'`Z.30*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"B,Z(&9R
M86UE=V]R:R]61E-?25-/+TE33U=R:71E<BYP:'`Z-C<*(SH@9G)A;65W;W)K
M+U9&4U])4T\O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#0*
M(SH@9G)A;65W;W)K+U9&4U])4T\O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2YP:'`Z.34*(SH@9G)A;65W;W)K+U9&4U])4T\O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+G!H<#HT.0HC.B!F<F%M97=O<FLO5D937TE33R])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C8P"B,Z(&QI8B]61E,O
M25-/5W)I=&5R+G!H<#HV,R!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDN<&AP.C@T"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P
M=713=')A=&5G>2YP:'`Z.34*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDN<&AP.C0X"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+G!H<#HU.0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*
M;7-G<W1R(")%:B!I;7!L96UE;G1E<F%D+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*;7-G:60@(DYO="!S970B"FUS
M9W-T<B`B16H@86YG:79E;B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE
M<B]397-S:6]N2&%N9&QE<BYP:'`Z,30S"B,Z(&9R86UE=V]R:R]397-S:6]N
M2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,34X"B,Z(&9R86UE=V]R:R]3
M97-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3<S"B,Z(&9R86UE
M=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3@W"B,Z
M(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z
M,C,T(&9R86UE=V]R:R]61E,O5D93+G!H<#HQ.3`*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C(P-2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C,P"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HR-#@@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C(V-0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C@Q(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HR.3<*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,Q,B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,S(Y"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HS-C(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C0R,@HC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z-3`Q(&9R86UE=V]R:R]61E,O5D93+G!H<#HU-S`*
M(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4X-R!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z-C8U(&QI8B]61E,N<&AP.C$Y,PHC.B!L:6(O5D93+G!H<#HR,#@@
M;&EB+U9&4RYP:'`Z,C,T(&QI8B]61E,N<&AP.C(U,B!L:6(O5D93+G!H<#HR
M-CD*(SH@;&EB+U9&4RYP:'`Z,C@U(&QI8B]61E,N<&AP.C,P,2!L:6(O5D93
M+G!H<#HS,38@;&EB+U9&4RYP:'`Z,S,S"B,Z(&QI8B]61E,N<&AP.C,V-B!L
M:6(O5D93+G!H<#HT,C8@;&EB+U9&4RYP:'`Z-3`U(&QI8B]61E,N<&AP.C4W
M-`HC.B!L:6(O5D93+G!H<#HU.3$@;&EB+U9&4RYP:'`Z-C8Y(&QI8B](;W)D
M92]397-S:6]N2&%N9&QE<BYP:'`Z,30U"B,Z(&QI8B](;W)D92]397-S:6]N
M2&%N9&QE<BYP:'`Z,38P(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z
M,3<U"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,3@Y(&QI8B](
M;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,C,V"FUS9VED(").;W0@<W5P<&]R
M=&5D+B(*;7-G<W1R(")3=/9D<R!I;G1E+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HR-#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P
M-3@*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X,`IM<V=I9"`B3F]T
M97,B"FUS9W-T<B`B06YT96-K;FEN9V%R(@H*(SH@<V5R=FEC97,O;V)R;W=S
M97(O:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S92P@9V\@
M8F%C:RXB"FUS9W-T<B`B26YG96YT:6YG(&%T="!V:7-A+"!GY2!T:6QL8F%K
M82XB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC
M.C$P"FUS9VED(").;W1I8V4B"FUS9W-T<B`B3T)3(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-PHC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#(T"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,3(@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0U,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED(").;W9E;6)E<B(*;7-G<W1R(")N
M;W9E;6)E<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-#8@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$P-3`*;7-G:60@(DYU;6)E<B(*;7-G<W1R(").
M=6UM97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(U(&QI8B](
M;W)D92]&;W)M+G!H<#HQ-#(Y"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R
M<R(*;7-G<W1R(")!;G1A;"!T96-K96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,S8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C,*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T-2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3,W,PHC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R-R!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,30T.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T
M<B`B06YT86P@:V]L=6UN97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,S8W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C$*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,30T,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,W
M,0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R-2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,30T-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`B06YT86P@
M<F%D97(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T-`HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C0T"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG
M(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(").=6UM97(@:6YT92!S
M<&5C:69I8V5R861E(&;V<B!A='0@=7!P9&%T97)A(&D@9&ES=')I8G5T:6]N
M<VQI<W1A;BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C0X,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C8V,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM<V=S='(@(D]+(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@T-@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")/8FIE
M8W0B"FUS9W-T<B`B3V)J96MT(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,3$*;7-G:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(D]B:F5K
M='-K87!A<F4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`T(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,3`X"FUS9VED(")/8W1A;"(*;7-G<W1R(")/
M:W1A;"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HS.#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0R,PHC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#D*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B
M3V-T;V)E<B(*;7-G<W1R(")O:W1O8F5R(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R(")&:6QT
M97(@9O9R(&]F]G)S:^1M9&AE=&5R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,R.`IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(DMO;G1O<B(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N
M9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R(")'
M86UM86QT(&]C:"!N>71T(&SV<V5N;W)D(&;E<B!I;G1E('9A<F$@<V%M;6$N
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V"FUS9VED(")/
M;&0@<&%S<W=O<F0B"FUS9W-T<B`B1V%M;6%L="!L]G-E;F]R9"(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B3VQD('!A<W-W
M;W)D(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R(")'86UM86QT(&SV<V5N;W)D
M(.1R(&9E;&%K=&EG="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY."!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3@Q"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S$@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T
M<B`B3VUA;B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C<S(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HW,PIM<V=I
M9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RXB
M"FUS9W-T<B`B1&5L861E(&UA<'!A<B!S=/9D<R!E;F)A<G0@878@24U!4"US
M97)V<F%R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDU"FUS9VED(")/
M;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R(")%;F)A<G0@;V;V<G-K
MY&UD82!V:7-H971S;W)D(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3@U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<Q"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ.#4U(&QI8B](;W)D92]&;W)M+G!H<#HQ.3<U"FUS9VED
M(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(D5N
M9&%S="!E;B!E+7!O<W1A9')E<W,@=&EL;.5T96XN(@H*(SH@<V5R=FEC97,O
M<VAA<F5S+V5D:70N<&AP.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O
M<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O
M<B!O=VYE<B`B"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("(B
M"B)%;F1A<W0@Y&=A<F4@96QL97(@<WES=&5M861M:6YI<W1R873V<B!K86X@
MY&YD<F$@Y&=A<F4@96QL97(@8F5H]G)I9VAE=&5R('#E("(*(F5N('5T9&5L
M;FEN9R(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,Y(&QI8B]";&]C:R]I
M9G)A;64N<&AP.C0P"FUS9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G
M<W1R("+6<'!N82!I(&YY='0@9O9N<W1E<B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,C0U(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C
M="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*;7-G<W1R("(B"B)/
M<&5N4U-,+69E;#H@1&5T(&=I8VL@:6YT92!A='0@97AT<F%H97)A(&1A=&$@
M9G+E;B!S:6=N97)A9"!3+TU)344M9&5L+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E
M;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("+6<'!N82!L
MY&YK(&D@;GET="!F]FYS=&5R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4S"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S='(@(D]P97)A=&EV
M<WES=&5M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HV,#`*;7-G:60@(D]P=&EO;F%L(%!A<G1I8VEP86YT(@IM<V=S
M='(@(DEC:V4@;V)L:6=A=&]R:7-K82!D96QT86=A<F4B"@HC.B!S97)V:6-E
M<R]P;W)T86PO;65N=2YP:'`Z,34P('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HQ-3$*;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`B26YS=.1L;&YI;F=A
M<B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS,2!T96UP;&%T97,O<')E9G,O
M87!P+FEN8SHQ.0HC+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E
M<R(*;7-G<W1R("));G-TY&QL;FEN9V%R(&;V<B`E<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R
M960@3&ES="(*;7-G<W1R(")3;W)T97)A9"!L:7-T82(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38W(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`B3W)G
M86YI<V%T:6]N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU-C@@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D]R
M9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`B3W)G86YI<V%T:6]N<V5N:&5T
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S-`IM<V=I9"`B3W)G
M86YI>FEN9R(*;7-G<W1R(")/<F=A;FES97)A(@H*(SH@861M:6XO=&5M<&QA
M=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L
M871E(@IM<V=S='(@(E5R<W!R=6YG;&EG(&%P<&QI:V%T:6]N<VUA;&PB"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(E5R<W!R=6YG
M;&EG82!M86QL87(@:2`E<SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.0HC.B!S97)V
M:6-E<R]K97EB;V%R9"YP:'`Z,3$W('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S='(@(D%N;F%N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDY(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,#D*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3(U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-`IM<V=I9"`B3W1H97(@
M26YF;W)M871I;VXB"FUS9W-T<B`B06YD<F$@:6YS=.1L;&YI;F=A<B(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(L1G87)B96CV<FEG:&5T97(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-SD@;&EB+TAO<F1E+T%U=&@O<&%M
M+G!H<#HW.0IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I
M;&%B;&4N(@IM<V=S='(@(E!!32U!=71E;G1I<V5R:6YG(.1R(&EN=&4@=&EL
M;&?D;F=L:6<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?
M<VUT<"YP:'`Z,3`U(&QI8B].970O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`U
M"FUS9VED(")014%2.CI-86EL(&)A8VME;F0B"FUS9W-T<B`B4$5!4CHZ36%I
M;"UK;W!P;&EN9R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$R-3,@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3(W-@IM<V=I9"`B4$=0
M($1I9VET86P@4VEG;F%T=7)E(@IM<V=S='(@(E!'4"!$:6=I=&%L(%-I9VYA
M='5R92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$R.3D@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3,R,@IM<V=I9"`B4$=0($5N8W)Y
M<'1E9"!$871A(@IM<V=S='(@(E!'4"!%;F-R>7!T960@1&%T82(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-3$@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z,3,W-`IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T
M<B`B4'5B;&EK(%!'4"UN>6-K96PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,S,S(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$S-38*
M;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B4$=0
M(%-I9VYE9"]%;F-R>7!T960@1&%T82(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H
M<#HV.`IM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B4$A0+6MO9"(*"B,Z(&%D
M;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@
M(E!(4"US:V%L(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S<*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B3.1T="!F
M]G)M:61D86=S<F5G;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,X"FUS9VED(")032!286EN(@IM<V=S='(@(D;V<FUI9&1A
M9W-R96=N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,SD*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B169T97)M:61D86=S
M<VMU<F%R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#`*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`B169T97)M:61D86=S<V[V
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*
M;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")%9G1E<FUI9&1A9W-S
M:W5R87(@;65D('-N]B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0R"FUS9VED(")032!3=6XB"FUS9W-T<B`B169T97)M:61D
M86=S<V]L(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#,*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(L5S:W-K=7)A<B!P
MY2!E9G1E<FUI9&1A9V5N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(W
M-`IM<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T<B`B
M4$]325@M=&EL;.1G9R!S86MN87,B"@HC.B!L:6(O87!I+G!H<#HQ-#D*;7-G
M:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B4%](4"US:V%L(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I
M9"`B4&%D9&EN9R(*;7-G<W1R(")5=&9Y;&QN860Z(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#<*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$W,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM
M<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`B4&%K:7-T86XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`Q(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.30*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$W,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(E!A;&%U(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DR"B,Z(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-S0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q
M"FUS9VED(")086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S
M='(@(E!A;&5S=&EN82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY."!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3@R"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S4@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!A;F%M82(*;7-G
M<W1R(")086YA;6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$X-0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDY"FUS9VED(")087!U82!.97<@1W5I
M;F5A(@IM<V=S='(@(E!A<'5A+4YY82!'=6EN96$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$W-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.34*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$W-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*
M;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(E!A<F%G=6%Y(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S8*;7-G:60@(E!A<G1L
M>2!#;&]U9'DB"FUS9W-T<B`B1&5L=FES(&UO;&YI9W0B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#$X"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR,#(R(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*(SH@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D@;&EB+TYE="]3
M35,O=VEN7VAT='`N<&AP.C$U,0HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C<W('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R-0IM<V=I9"`B4&%S<W=O<F0B
M"FUS9W-T<B`B3/9S96YO<F0B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY
M+B(*;7-G<W1R("),]G-E;F]R9"#D;F1R861E<RXB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$S,C(@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HQ,S(S"FUS9VED(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T
M<B`B3/9S96YO<F0@9F5L86MT:6=T(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]R861I=7,N<&AP.C$U,B!L:6(O2&]R9&4O075T:"]R861I=7,N<&AP.C$U
M,@IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B3/9S96YO<F0@:W+D=G,@9O9R(%)!1$E54R!A
M=71E;G1I<V5R:6YG+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M-3,@;&EB+TAO<F1E+T9O<FTN<&AP.C(P-3<*;7-G:60@(E!A<W-W;W)D('=I
M=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(DSV<V5N;W)D(&UE9"!B96MRY&9T
M96QS92(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`IM<V=I
M9"`B4&%S<W=O<F0Z(@IM<V=S='(@(DSV<V5N;W)D.B(*"B,Z('1E;7!L871E
M<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"FUS9VED(")087-S=V]R9#H@(@IM<V=S
M='(@(DSV<V5N;W)D.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3`@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`S-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`S
M.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS9VED
M(")087-S=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`B3/9S96YO<F0@;>5S
M=&4@=F%R82!L:6MA+B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,3D@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R
M"FUS9VED(")087-T92(*;7-G<W1R(")+;&ES=')A(&EN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S
M=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T<B`B2VQI<W1R82!I;B!F<N5N('5R
M:VQI<'!S:&%N=&5R87)E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`B4_9K=N1G
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T96UP
M;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C<*;7-G:60@(E!E
M;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`B5N1N=&%N9&4@<F5G:7-T<F5R:6YG
M87(Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T"FUS9VED(")096]P
M;&4B"FUS9W-T<B`B3>1N;FES:V]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T
M<B`B4')O8V5N="(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M
M7V)O='1O;2YI;F,Z-@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E
M;F%N8V4N:'1M;#HT.0IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R
M871I;VYS(@IM<V=S='(@(E5T9O9R('5N9&5R:.5L;'-F=6YK=&EO;F5R(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Q,`IM<V=I9"`B4&5R9F]R;2!M
M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R(")5=&;V
M<B!U;F1E<FCE;&QS86MT:79I=&5T97(@=FED(&EN;&]G9VYI;F<_(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B0F5H
M]G)I9VAE="(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T960N
M(@IM<V=S='(@(D)E:/9R:6=H970@)R5S)R!R861E<F%D97,@:6YT92XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X-B!L:6(O5D93+W-M8BYP
M:'`Z-3DP"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("+%=&MO
M;7-T(&YE:V%D(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ
M-C$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C0*(SH@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HQ-C$@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ
M-C0*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@(F)E:/9R:6=H971E<B(*
M"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P.2!A9&UI;B]P97)M<R]A9&1C
M:&EL9"YP:'`Z-C`*(SH@861M:6XO<&5R;7,O:6YD97@N<&AP.C(R(&%D;6EN
M+W!E<FUS+V1E;&5T92YP:'`Z-3@*;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN
M:7-T<F%T:6]N(@IM<V=S='(@(D)E:/9R:6=H971S861M:6YI<W1R871I;VXB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@*;7-G:60@(E!E<G-O;F%L
M($EN9F]R;6%T:6]N(@IM<V=S='(@(E!E<G-O;FQI9R!I;F9O<FUA=&EO;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY."!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@S"B,Z(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S@@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B4&5R=2(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU-0IM<V=I9"`B4&5T<R(*;7-G<W1R(")(
M=7-D:G5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDY(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M.#8*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W.2!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T
M<B`B1FEL:7!P:6YE<FYA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$Y-@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$Y-@IM<V=I9"`B4&AO;F4B"FUS9W-T<B`B5&5L969O;B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#`*;7-G:60@(E!H;W1O<R(*
M;7-G<W1R(")&;W1O;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Y,`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4&ET8V%I<FXB
M"FUS9W-T<B`B4&ET8V%I<FXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX96QS(@IM<V=S='(@(E!I
M>&QA<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B4&QA
M=&ET=61E<R(*;7-G<W1R(")+;&EC:.EE<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S
M92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R(")687(@9V]D(&ML:6-K
M82!I(&5N(&-E;&PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#D*;7-G:60@(E!L96%S92!C;VYF:7)M('1H
M870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T<B`B
M0F5K<N1F=&$@871T(&1U('9I;&P@<F%D97)A('9A;&0@<&]S=#\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL
M:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B0F5K<N1F=&$@871T(&1U('9I
M;&P@<F%D97)A(&%K='5E;&QT(&5L96UE;G0N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C4W,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4V-@IM<V=I
M9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T<B`B
M5F%R(&=O9"!A;F=E(&WE;F%D(&]C:"#E<BXB"@HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N
M=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T<B`B5F%R
M(&=O9"!A;F=E(&YA;6X@9O9R(&MA=&5G;W)I;CHB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,S`Q(&QI8B](;W)D92]&;W)M+G!H<#HQ,S`U"FUS
M9VED(")0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R
M(")687(@9V]D(&%N9V4@9V]D:^1N9"!)4"UA9')E<W,N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C8T
M-`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE
M(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B5F%R(&=O
M9"!A;F=E(&5T="!G:6QT:6=T(&1A='5M.R!K;VYT<F]L;&5R82!A;G1A;&5T
M(&1A9V%R(&D@;>5N861E;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-#4Q(&QI8B](;W)D92]&;W)M+G!H<#HR-#4Q"FUS9VED(")0;&5A<V4@
M96YT97(@82!V86QI9"!T:6UE+B(*;7-G<W1R(")687(@9V]D(&%N9V4@96X@
M9V]D:^1N9"!T:60N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P
M<F]B;&5M+B(*;7-G<W1R(")687(@9V]D('-U;6UE<F$@9&ET="!P<F]B;&5M
M+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U
M<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B06YG92!D:71T(&%N
M=N1N9&%R;F%M;B!O8V@@;/9S96YO<F0N(@H*(SH@=&5M<&QA=&5S+VUA:6YT
M96YA;F-E+V%G<F5E;65N=%]T;W`N:6YC.C$R"FUS9VED("(B"B)0;&5A<V4@
M<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N("!9;W4@35535"!A9W)E92!W:71H
M('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B(@HB
M5F%R(&=O9"!LY',@:6=E;F]M(&;V;&IA;F1E('1E>'0N($1U($W%4U1%('-A
M;71Y8VMA(&UE9"!V:6QL:V]R96X@9O9R(&%T="`B"B)A;G;D;F1A('-Y<W1E
M;65T+B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B
M(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A
M9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB"FUS
M9W-T<B`B(@HB5F%R(&=O9"!LY',@:6=E;F]M(&;V;&IA;F1E('1E>'0N($1U
M($W%4U1%('-A;71Y8VMA(&UE9"!V:6QL:V]R96X@9O9R(&%T="`B"B)A;G;D
M;F1A('-Y<W1E;65T+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-30P"FUS9VED("(B"B)0;&5A<V4@<F5V:65W('1H
M92!F;VQL;W=I;F<@:6YF;W)M871I;VXL(&%N9"!T:&5N('-E;&5C="!A;B!A
M8W1I;VX@9G)O;2!T:&4@(@HB;65N=2!B96QO=RXB"FUS9W-T<B`B(@HB2V]N
M=')O;&QE<F$@9O9L:F%N9&4@:6YF;W)M871I;VX@;V-H(';D;&H@<V5D86X@
M96X@:&%N9&QI;F<@:2!M96YY;EQN(@HB;F5D86XN(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT,S4*;7-G:60@(E!L
M96%S92!S96QE8W0@86X@86-T:6]N(&9R;VT@=&AE(&UE;G4@8F5L;W<N(@IM
M<V=S='(@(E;D;&H@96X@:&%N9&QI;F<@9G+E;B!M96YY;B!N961A;BXB"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW
M,`HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM
M<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G
M<W1R(")!;F=E(&YY='0@:V%T96=O<FEN86UN.B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.2!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@X"B,Z(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.#$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G
M:60@(E!O;&%N9"(*;7-G<W1R(")0;VQE;B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU-PIM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B4&]L:71I:R(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#D*;7-G:60@(E!O;&QS
M(@IM<V=S='(@(E5N9&5R<_9K;FEN9V%R(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,2!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3DS"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ.#(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED
M(")0;W)T=6=A;"(*;7-G<W1R(")0;W)T=6=A;"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I
M9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R(")0;W-I=&EO
M;F5R:6YG(&%V(&)I;&1E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES
M('1A8FQE(@IM<V=S='(@(E!O<VET:6]N97)I;F<@878@=&%B96QL96XB"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,2!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3$*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O('1H:7,@9F]L
M9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B4VMR:78@=&EL
M;"!D96X@:.1R(&UA<'!E;B`H96H@='9I;F=A="!A=B!)34%0*2(*"B,Z(&-O
M;F9I9R]T:&5M97,O<&]S=&YU:V4N<&AP.C8*;7-G:60@(E!O<W1N=6ME(@IM
M<V=S='(@(E!O<W1N=6ME(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S,@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B
M3F5D97)B]G)D(&1E('-E;F%S=&4@)7,@=&EM;6%R;F$Z("(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#<*;7-G:60@(E!R96-I<&ET871I
M;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B0VAA;G,@=&EL;#QB<B\^;F5D97)B
M]G)D(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+VQD87`N<&AP.CDX(&QI
M8B](;W)D92]0<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@
M4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!
M=71H7VQD87`Z($Q$05`M=&EL;.1G9R!S86MN87,N(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+W-E<W-I;VXN<&AP.C,S(&QI8B](;W)D92]0<F5F<R]S
M97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@
M<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]S
M97-S:6]N.B!/8FQI9V%T;W)I<VMT('-E<W-I;VYS=&EL;.1G9R!H:71T861E
M<R!I;G1E+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C,R"FUS9VED(")0
M<F5S<W5R92(*;7-G<W1R(")4<GEC:R(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C8V"FUS9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ("(*;7-G<W1R
M("),=69T=')Y8VL@=FED(&AA=F5T.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C(T"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@(DQU
M9G1T<GEC:SH@(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$X.`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C`S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R(")&]G)H
M86YD<W9I<VYI;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*;7-G:60@(E!R979I97<@=&AE(&EM
M86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")&]G)H86YD<V=R86YS:V$@
M8FEL9"!I(&YY='0@9O9N<W1E<B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z,S8P(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8T
M"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S4V(&QI8B](;W)D92]0<F5F
M<R]522YP:'`Z,S8P"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S='(@
M(D;V<F5GY65N9&4@:6YS=.1L;&YI;F=A<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M
M96YT(@IM<V=S='(@(E-K<FEV('5T(&1O:W5M96YT(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+97DB"FUS9W-T<B`B4')I=F%T82!N
M>6-K96PB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38Y
M(&QI8B](;W)D92]-96YU+G!H<#HQ-CD*;7-G:60@(E!R;V)L96TB"FUS9W-T
M<B`B4')O8FQE;2(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-PIM<V=I
M9"`B4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R(")0<F]B;&5M8F5S:W)I
M=FYI;F<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<Q"FUS9VED
M(")0<F]J96-T<R(*;7-G<W1R(")0<F]J96MT(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C$Q,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@X
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#0@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(Q,34*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q.3(@;&EB+TAO
M<F1E+T9O<FTN<&AP.C,R.#`*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S='(@
M(E1E>'0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y
M(@IM<V=S='(@(E!U8FQI:R!N>6-K96PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8T-2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C8T-@IM<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET:&TB"FUS9W-T<B`B4'5B
M;&EK(&YY8VME;&%L9V]R:71M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HV-#0@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#4*
M;7-G:60@(E!U8FQI8R!+97D@26YF;R(*;7-G<W1R(")0=6)L:6L@;GEC:V5L
M:6YF;W)M871I;VXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HR,S`@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L
M:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY
M+B(*;7-G<W1R(")&96P@=FED(&=E;F5R97)I;F<@878@<'5B;&EK="]P<FEV
M870@;GEC:V5L<&%R+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Y,0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I
M8V\B"FUS9W-T<B`B4'5E<G1O(%)I8V\B"@HC.B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C-#,Q-"YP:'`Z-34*;7-G:60@(E!U<F=E(&UE<W-A9V5S(@IM<V=S
M='(@(E)E;G-A(&UE9&1E;&%N9&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3DV"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ.#0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")1
M871A<B(*;7-G<W1R(")1871A<B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HV
M,PIM<V=I9"`B475E<GDB"FUS9W-T<B`B1G+E9V$B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-S`*;7-G:60@(E%U;W1A(@IM<V=S='(@(DMV;W1A(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C,@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HV-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B4'5B;&EK(%)302UN
M>6-K96P@*"5D(&)I=&%R*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(R-C0@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-C@*;7-G:60@(E)A9&EO('-E
M;&5C=&EO;B(*;7-G<W1R(")%;G-K:6QT('9A;"(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")286EN(@IM<V=S
M='(@(E)E9VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT-0IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R(")4:61I9W0@<F5G
M;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0V
M"FUS9VED(")286EN($QA=&4B"FUS9W-T<B`B4V5N="!R96=N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A
M:6X@4VAO=V5R(@IM<V=S='(@(E)E9VYS:W5R87(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!A;F0@
M4VYO=R(*;7-G<W1R(")296=N(&]C:"!S;O8B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM<V=I9"`B4F%I;B!T;R!3;F]W
M(@IM<V=S='(@(E)E9VX@=&EL;"!S;O8B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U;F4B"FUS9W-T<B`B4VQU;7!M
MY'-S:6=T('9I<VAE='-O<F0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-S,*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO
M(@IM<V=S='(@(D;V<FCE;&QA;F1E(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HS,C0@;&EB+TAO<F1E+U!E<FUS+G!H<#HS,C0*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHS-"!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C8X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,S<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*;7-G
M:60@(E)E860B"FUS9W-T<B`B3.1S(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.#<@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S
M,30N<&AP.C0W"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX
M-PIM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R("),Y',@;65D9&5L86YD
M96XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R
M871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B4^1K97)T(&%T="!D
M=2!V:6QL(')A9&5R82`E<S\@4F%D97)I;F=E;B!K86X@:6YT92#E;F=R87,N
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S
M97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S
M='(@(B(*(E/D:V5R="!A='0@9'4@=FEL;"!R861E<F$@86YVY&YD87)D871A
M(&;V<B`E<S\@4F%D97)I;F=E;B!K86X@:6YT92#E;F=R87,N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B
M4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B1_9R(&]M(&1I;B!S
M96YA<W1E(&EN;6%T;FEN9R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED(")2969R97-H(@IM
M<V=S='(@(E5P<&1A=&5R82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.34*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G
M<W1R(")5<'!D871E<F$@9'EN86UI<VMA(&UE;GEE;&5M96YT.B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#4*;7-G:60@(E)E9G)E<V@@4&]R=&%L
M(%9I97<Z(@IM<V=S='(@(E5P<&1A=&5R82!P;W)T86QV>3HB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HX.30@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(Q,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,U(&QI8B](
M;W)D92]&;W)M+G!H<#HX.3@@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,3<*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$R,SD*;7-G:60@(E)E9V5X(@IM<V=S='(@
M(E)E9V5X(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(T.2!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,S(S-0IM<V=I9"`B4F5L871I;VYS:&EP($)R;W=S
M97(B"FUS9W-T<B`B5FES82!F]G)HY6QL86YD96XB"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C`X"FUS9VED(")296QO860B"FUS9W-T<B`B3&%D9&$@;VTB"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,S,PIM<V=I9"`B4F5M87)K<R(*;7-G<W1R
M(")+;VUM96YT87)E<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-#4W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-#<V"FUS9VED(")296UE;6)E<B!T:&4@9G)E
M92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R(")+;VT@:6CE9R!I;F9O<FUA
M=&EO;B!O;2!L961I9R]U<'!T86=E;BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3$W"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R(")&:N1R
M<G-E<G9R87(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*
M;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R
M9&4I.B(*;7-G<W1R(")54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R
M9&4I.B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,PIM<V=I9"`B4F5M
M;W9E(@IM<V=S='(@(E1A(&)O<G0B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA
M>6]U="YI;F,Z,3$*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R(")482!B
M;W)T(&)L;V-K(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C4S,@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-34Y"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(E1A(&)O<G0@
M:V]L=6UN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHT,`IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`B5&$@
M8F]R="!F;W)M871E<FEN9R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-C4X"FUS9VED(")296UO=F4@9G)O;2!M>2!C
M86QE;F1A<B(*;7-G<W1R(")482!B;W)T(&9RY6X@;6EN(&MA;&5N9&5R(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,C@*;7-G:60@(E)E;6]V
M92!P86ER(@IM<V=S='(@(E1A(&)O<G0@<&%R(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP="!F<F]M
M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(E)A9&5R
M82!S<&%R870@<VMR:7!T(&9RY6X@<V5R=F5R;G,@=&5M<&]RY')K871A;&]G
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHT,@IM<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R(")482!B;W)T
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4P"FUS9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O
M8W5M96YT(@IM<V=S='(@(E)A9&5R82!D96YN82!N;V0@9G+E;B!D;VMU;65N
M=&5T(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0IM
M<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`B5&$@8F]R="!A;G;D;F1A<F4B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(E1A(&)O
M<G0@86YVY&YD87)E.B`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z,3DW"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z,C@P"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,S0Y"FUS9VED(")297!L>2!396YT
M+B(*;7-G<W1R(")3=F%R('-K:6-K870N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT-3D*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT-C@*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT-S@*;7-G:60@(E)E
M<&QY('=I=&@@3F]T(%-U<'!O<G1E9"!-97-S86=E(@IM<V=S='(@(E-V87)A
M(&%T="!B96?D<F%N(&EN=&4@<W3V9',B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0V-@IM<V=I9"`B4F5P;'D@=VET
M:"!F<F5E+V)U<WD@9F]R(&YE>'0@,B!M;VYT:',N(@IM<V=S='(@(E-V87)A
M(&UE9"!I;F9O<FUA=&EO;B!O;2!L961I9R]U<'!T86=E;B!F]G(@:V]M;6%N
M9&4@=';E(&WE;F%D97(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HT-C4*;7-G:60@(E)E<&QY('=I=&@@<F5Q=65S
M=&5D(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B4W9A<F$@;65D
M(&1E;B!B96?D<F1A(&QE9&EG+W5P<'1A9V5N+6EN9F]R;6%T:6]N96XN(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ
M.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5P;'DZ("5S(@IM<V=S='(@(E-V
M87(Z("5S(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ,S@@
M;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q=65S="!C
M;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS
M9W-T<B`B0F5GY')A;B!K=6YD92!I;G1E(&)E<W9A<F%S+B!2971U<FYE<F%D
M(&9E;&MO9#H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T
M-0IM<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD
M+B(*;7-G<W1R(")$96X@969T97)F<N5G861E('1JY&YS=&5N(&MU;F1E(&EN
M=&4@:&ET=&%S+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<T
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#DR"B,Z(&QI8B](;W)D92YP
M:'`Z,3<V(&QI8B](;W)D92YP:'`Z-3$X"B,L('!H<"UF;W)M870*;7-G:60@
M(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(D5R9F]D<F%D("<E<R<@Y'(@:6YT92!A;F=I=F5N
M(&D@:V]N9FEG=7)A=&EO;F5N(&%V("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z-C<U(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,P
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,C,@;&EB+U9&
M4R]S<6PN<&AP.C8W."!L:6(O5D93+V9T<"YP:'`Z.#8Q"B,Z(&QI8B]61E,O
M<W%L7V9I;&4N<&AP.C<S,0HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E
M9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B17)F;V1R860@)R5S)R#D<B!I;G1E(&%N9VEV96X@:2!K;VYF
M:6=U<F5R:6YG96X@878@5D93+B(*"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN
M<&AP.C<X,2!L:6(O2&]R9&4O571I;"YP:'`Z-S<V"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(D5R9F]D<F%D("<E<R<@Y'(@:6YT92!A;F=I
M=F5N(&D@:V]N9FEG=7)E<FEN9V5N+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTO4F5N9&5R97(N<&AP.C,S-2!L:6(O2&]R9&4O1F]R;2]296YD97)E<BYP
M:'`Z,S,U"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R(")/8FQI9V%T
M;W)I<VMT="!FY&QT(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HU.3(*;7-G:60@(E)E<75I<F5D(%!A<G1I8VEP86YT
M(@IM<V=S='(@(D]B;&EG871O<FES:R!D96QT86=A<F4B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,SD*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S(P(&QI8B](;W)D92]&
M;W)M+G!H<#HS-#,*(SH@;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,R
M,"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(P"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`BQ71E
M<G-TY&QL(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#8*;7-G
M:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(L5T97)S=.1L;"!L]G-E;F]R
M9"(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W"FUS9VED(")2
M97-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(L5T97)S=.1L;"!L]G-E;F]R
M9"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S`*;7-G:60@(E)E<W1O<F4@
M3&%S="!1=65R>2(*;7-G<W1R("+%<W1E<G3D;&P@<V5N87-T92!F<N5G86XB
M"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S$@861M:6XO8VUD<VAE;&PN<&AP
M.C(X(&%D;6EN+W-Q;'-H96QL+G!H<#HV-@IM<V=I9"`B4F5S=6QT<R(*;7-G
M<W1R(")297-U;'1A="(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHQ,#$@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N
M('1O($]P=&EO;G,B"FUS9W-T<B`BQ71E<G;D;F0@=&EL;"!I;G-TY&QL;FEN
M9V%R(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED
M(")2971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(D%N9V4@;GET="!L]G-E
M;F]R9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DW(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#(@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y
M-PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R(")2
MZ75N:6]N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO
M;B(*;7-G<W1R("+%=&5R<W3D;&P@:V]N9FEG=7)A=&EO;B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@
M3W!T:6]N<R(*;7-G<W1R("));G-TY&QL;FEN9V%R(&;V<B!2:6-H(%1E>'0@
M161I=&]R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS9VED(")2
M:61D;&5S(@IM<V=S='(@(D?E=&]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<P"FUS9VED(")2:6=H="(*;7-G
M<W1R(")(]F=E<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C$@
M;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#<*;7-G:60@(E)I9VAT(&AE861E<B(*
M;7-G<W1R(")(]F=E<G)U8G)I:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,Q,3<@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#,*;7-G:60@(E)I9VAT
M('9A;'5E<R(*;7-G<W1R(")(]F=E<G;D<F1E;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B
M4F]?=R!0<F]P97)T:65S+BXN(@IM<V=S='(@(E)A7V1I;G-TY&QL;FEN9V%R
M+BXN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(S-`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C4X,PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(S
M-`IM<V=I9"`B4F]L92(*;7-G<W1R(")2;VQL(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DX"B,Z(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.#8@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R"FUS
M9VED(")2;VUA;FEA(@IM<V=S='(@(E)U;>1N:65N(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P.`HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(V"FUS9VED(")2;W1A=&4@,3@P
M(@IM<V=S='(@(E)O=&5R82`Q.#`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C`U"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,C,*;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@
M(E)O=&5R82!VY&YS=&5R(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(Q,0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C(Y"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`B4F]T
M97)A(&CV9V5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T
M<B`B4F%D:6YS=.1L;&YI;F=A<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P<F]P97)T
M:65S(@IM<V=S='(@(E)A9&EN<W3D;&QN:6YG87(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W<SHB
M"FUS9W-T<B`B4F%D97(Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PIM<V=I9"`B4G5L97,B"FUS9W-T<B`B
M3&EN:F5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E
M;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(*;7-G<W1R("),:6YJ97(@=FES87,@
M;65L;&%N(&%L;&$@<F%D97(@;V-H(&MO;'5M;F5R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T
M<B`B3&EN:F5R('9I<V%S(&5N8F%R="!M96QL86X@:V]L=6UN97(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4R
M"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(*
M;7-G<W1R("),:6YJ97(@=FES87,@96YB87)T(&UE;&QA;B!R861E<B(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`*;7-G:60@(E)U;B(*;7-G<W1R(")+
M]G(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`S(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3D*
M(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-R!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*
M;7-G<W1R(")2>7-S;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(P,`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G=A;F1A
M(@IM<V=S='(@(E)W86YD82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,C@U(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C@U"FUS
M9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B
M4R]-24U%('-I9VYA='5R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HS,C,@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS,C,*;7-G
M:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*;7-G<W1R(")3+TU)344M
M:W)Y<'1E<F%T(&UE9&1E;&%N9&4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W-A<VPN<&AP.C@Q(&QI8B](;W)D92]!=71H+W-A<VPN<&AP.C@Q"FUS9VED
M(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S
M='(@(E-!4TPM875T96YT:7-E<FEN9R#D<B!I;G1E('1I;&QGY&YG;&EG+B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,#8*;7-G:60@(E--4R!-
M97-S86=I;F<B"FUS9W-T<B`B4TU3(&UE9&1E;&%N9&5N(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C(Q"FUS9VED(")344P@4VAE;&PB"FUS9W-T<B`B4U%,
M+7-K86PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@R(&QI8B](
M;W)D92]&;W)M+G!H<#HS,C<X"FUS9VED(")344P@<W1A=&5M96YT(&9O<B!V
M86QU92!L;V]K=7!S(@IM<V=S='(@(E-13"US96MV96YS(&;V<B!U<'!S;&%G
M(&%V(';D<F1E;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S,*
M;7-G:60@(E-32"(*;7-G<W1R(")34T@B"@HC.B!F<F%M97=O<FLO3F]T:69I
M8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,U"B,Z
M(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS
M-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R("),64-+050B"@HC.B!L:6(O87!I
M+G!H<#HQ-3,*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B4U]13"US:V%L
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M,0IM<V=I9"`B4V$B"FUS9W-T<B`B3/8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,#<*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$X.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@
M(E-A:6YT($AE;&5N82(*;7-G<W1R(")386EN="!(96QE;F$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#0@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,0HC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@T"FUS9VED(")386EN="!+:71T<R!A;F0@3F5V:7,B"FUS9W-T<B`B4V%I
M;G0@2VET=',@;V-H($YE=FES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,SD*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$Y,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B4V%I;G0@
M3'5C:6$B"FUS9W-T<B`B4V%I;G0@3'5C:6$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ.#D*(SH@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$Y,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G
M:60@(E-A:6YT(%!I97)R92!A;F0@36EQ=65L;VXB"FUS9W-T<B`B4V%I;G0M
M4&EE<G)E(&]C:"!-:7%U96QO;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(T-`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DS(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B4V%I
M;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B4V%I;G0@
M5FEN8V5N="!O8V@@1W)E;F%D:6YE<FYA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H
M7W-E;&8I(@IM<V=S='(@(E-A;6UA(')A;2`H7W-E;&8I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4Q"B,Z(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ.30@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$W"FUS9VED(")386UO82(*;7-G<W1R(")386UO82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#8@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,@HC.B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DU(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M-@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R(")386X@36%R:6YO(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$V"B,Z(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.38@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`W"FUS9VED(")386\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T
M<B`B4V%O(%1O;64@;V-H(%!R:6YC:7!E(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D*
M;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R(")3871T96QI=&QE
M=F5R86YT]G(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,#$*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-R!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R86)I82(*
M;7-G<W1R(")3875D:6%R86)I96XB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA
M>6]U="YI;F,Z.3D*;7-G:60@(E-A=F4B"FUS9W-T<B`B4W!A<F$B"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L('!H<"UF;W)M
M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(E-P87)A("<E<R<B"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3879E("5S(@IM<V=S='(@(E-P87)A("5S(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S
M='(@(E-P87)A(&EN<W3D;&QN:6YG87(B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,38W"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T
M:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R
M>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@(B(*(E-P87)A(&=E;F5R97)A9"!K
M;VYF:6=U<F%T:6]N('-O;2!02%`M<VMR:7!T('1I;&P@9&EN('-E<G9E<G,@
M('1E;7`M:V%T86QO9RXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R(")3<&%R861E(&MO;F9I9W5R871I;VX@9O9R("5S+B(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L('!H<"UF;W)M870*;7-G
M:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM
M<V=S='(@(E-P87)A9&4@=7!P9W)A9&5R:6YG<W-C<FEP="!T:6QL.B`E<RXB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM
M<V=I9"`B4V-A='1E<F5D(%0M4W1O<FUS(@IM<V=S='(@(E-P<FED9&$@Y7-K
M<VMU<F%R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")3
M8VEE;F-E(@IM<V=S='(@(E9E=&5N<VMA<"(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C$V"FUS9VED(")396%R8V@B"FUS9W-T<B`B4_9K(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,R,@IM<V=I9"`B4V5A<F-H($5N9VEN97,B
M"FUS9W-T<B`B4_9K;6]T;W)E<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Y-S,@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y-3D*;7-G:60@(E-E;&5C
M="!&:6QE<R(*;7-G<W1R(")6Y&QJ(&9I;&5R(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U.0HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@U"FUS9VED(")396QE8W0@82!D871E
M(@IM<V=S='(@(E;D;&H@971T(&1A='5M(@H*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*
M;7-G<W1R(")6Y&QJ(&=R=7!P(&%T="!LY&=G82!T:6QL(@H*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W
M;F5R(@IM<V=S='(@(E;D;&H@;GD@Y&=A<F4B"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G
M<W1R(")6Y&QJ('-E<G9E<B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,34V"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*;7-G<W1R(")6
MY&QJ(&%N=N1N9&%R92!A='0@;.1G9V$@=&EL;"(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HV-3(*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-@IM<V=I9"`B4V5L96-T(&%L;"(*
M;7-G<W1R(")6Y&QJ(&%L;&$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-C8S(&QI8B](;W)D92]&;W)M+G!H<#HR-C0W"FUS9VED(")396QE8W0@
M86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`B5N1L:B!D871U;6MO;7!O
M;F5N=&5R+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HX-#8*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C@W,PIM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R(")6Y&QJ(&5T
M="!O8FIE:W0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C4S"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HV-S<*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(E;D;&H@:6YG96XB
M"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*;7-G:60@(B(*(E-E;&5C
M="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO
M=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T
M:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B)!;F=E(&1E('1E8VME;B!D=2!B
M96CV=F5R(&D@<G5T;W)N82!N961A;BX@1'4@:V%N('-E9&%N(&MO<&EE<F$@
M;V-H(&ML:7-T<F$@(@HB:6X@9&5M(&D@=&5X=&%R=71A;BXB"@HC.B!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H92!D871E
M(&1E;&EM:71E<CHB"FUS9W-T<B`B5N1L:B!A=F=RY&YS87)E(&;V<B!D871U
M;3HB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-`IM<V=I9"`B4V5L
M96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`B5N1L:B!D871U;69O<FUA
M=#HB"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDP
M"FUS9VED(")396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG
M93HB"FUS9W-T<B`B5N1L:B!I9&5N=&ET970@9'4@=FEL;"#D;F1R83HB"@HC
M.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H
M92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B5N1L:B!A=F=RY&YS87)E(&;V
M<B!T:60Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@
M(E-E;&5C="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(E;D;&H@=&ED<V9O
M<FUA=#HB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4W"FUS9VED
M(")396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`B5N1L:B!T
M=N4@;6%T8VAA;F1E(&;D;'0Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,Q,`IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R
M(")6Y&QJ(&1I='0@9N1R9W-C:&5M82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C4R"FUS9VED(")396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A
M9V4Z(@IM<V=S='(@(D%N9V4@9&ET="!F]G)V86QD82!S<'+E:SHB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8U,PIM
M<V=I9"`B4V5N9"!,871E<W0@26YF;W)M871I;VXB"FUS9W-T<B`B4VMI8VMA
M('-E;F%S=&4@:6YF;W)M871I;VYE;B(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C4X"FUS9VED(")396YD(%!R;V)L96T@4F5P;W)T(@IM
M<V=S='(@(E-K:6-K82!P<F]B;&5M<F%P<&]R="(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#$Q"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HQ,#0R"FUS9VED(")396YD(%--4R(*
M;7-G<W1R(")3:VEC:V$@4TU3(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C$S"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.3@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")396YE
M9V%L(@IM<V=S='(@(E-E;F5G86PB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,R,PIM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`B4V5N<V]R.B`B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@U"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,C(*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,"!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@(E-E<'1E;6)E<B(*
M;7-G<W1R(")S97!T96UB97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY
M"FUS9VED(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T<B`B4V5R8FEE
M;B!O8V@@36]N=&5N96=R;R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-S`Q(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`R"FUS
M9VED(")397)I86P@3G5M8F5R(@IM<V=S='(@(E-E<FEE;G5M;65R(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T.0IM<V=I9"`B4V5R=F5R
M(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B4V5R=F5R
M:6YS=.1L;&YI;F=A<B!F96QA:W1I9V$@96QL97(@:6YA:W1I=B!S97)V97(N
M(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(W"FUS9VED(")397-S:6]N($%D
M;6EN(@IM<V=S='(@(E-E<W-I;VYS861M:6YI<W1R871I;VXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3(*(SH@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E
M<W-I;VX@240@97AP:7)E9"XB"FUS9W-T<B`B4V5S<VEO;G,M240@:&%R(&?E
M='0@=70N(@H*(SH@;&EB+V%P:2YP:'`Z,30U"FUS9VED(")397-S:6]N<R(*
M;7-G<W1R(")397-S:6]N97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S$T(&QI8B](;W)D92]&;W)M+G!H<#HR,S$X"FUS9VED(")3970B"FUS
M9W-T<B`B4^1T="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.0IM<V=I
M9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S
M<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*;7-G<W1R("(B"B)+;VYF
M:6=U<F5R82!A;'1E<FYA=&EV('-O;2!M]FIL:6=G]G(@Y71E<G-TY&QL;FEN
M9R!A=B!B;W)T9VSV;70@;/9S96YO<F0N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Q.`IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@
M>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@
M(DMO;F9I9W5R97)A(&9JY')R<V5R=G)A<B!S;VT@9'4@=FEL;"!K;VUM82#E
M="!F<N5N(&1I;B!P;W)T86PN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@W"FUS9VED(")3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z
M;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S='(@(D%N9V4@9&ET="!F]G)V
M86QD82!S<'+E:RP@=&ED<WIO;B!C;V@@9&%T=6UI;G-TY&QL;FEN9V%R+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#$*;7-G:60@(B(*(E-E="!Y
M;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R
M969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G
M<W1R("(B"B)3Y'1T(&1I='0@:6YI=&EA;&$@87!P;&EK871I;VXL(&;D<F=S
M8VAE;6$L('-I9'5P<&1A=&5R:6YG(&]C:"!A;F1R82`B"B)V:7-N:6YG<VEN
M<W3D;&QN:6YG87(N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-PIM
M<V=I9"`B4V5T=7`B"FUS9W-T<B`B4V5T=7`B"@HC.B!T96UP;&%T97,O861M
M:6XO<V5T=7`O:6YD97@N:'1M;#HS-PIM<V=I9"`B4V5T=7`@=7!G<F%D92!S
M8W)I<'1S(&%V86EL86)L92(*;7-G<W1R(")+;VYF:6=U<F%T:6]N<W5P<&=R
M861E<FEN9W-S:W)I<'0@9FEN;G,@=&EL;&?D;F=L:6=A(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-0IM<V=I9"`B4V5V97)A;"!L;V-A
M=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T<B`B
M1&5T(&9I;FYS(&9L97)A(&]R=&5R(&UE9"!P87)A;65T97)N.B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#0@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P,PHC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P-`IM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R(")397EC:&5L;&5R
M;F$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DX"FUS9VED(")3
M:&]P<&EN9R(*;7-G<W1R(")(86YD96PB"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHT,PIM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G<W1R
M(")+;W)T('-U;6UE<FEN9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M-3`*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M
M;W-T(&QI;FMS/R(*;7-G<W1R(")3:V%L;"!G96YVY&=S=&%N9V5N=&5R(&1E
M9FEN97)A<R!F]G(@9&4@9FQE<W1A(&SD;FMA<C\B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C,R,R!L:6(O2&]R9&4O4&5R;7,N<&AP.C,R,PHC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,S('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z-C<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY
M,"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,PHC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$S-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$W.0IM<V=I9"`B4VAO=R(*;7-G<W1R(")6:7-A(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$U-0IM<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B
M971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E
M9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B)6:7-A('-K:6QL;F%D
M97(@;65L;&%N(&1E;B!A:W1U96QL82!O8V@@9&5N(&YY;&EG96X@<VMA<&%D
M92!K;VYF:6=U<F%T:6]N96XN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0Y-`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG
M(&EN/R(*;7-G<W1R(")6:7-A('-E;F%S=&4@:6YL;V=G;FEN9W-T:60@=FED
M(&EN;&]G9VYI;F<_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V
M-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<V.0IM<V=I9"`B4VAO=R!O<'1I;VX@
M=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R(")6:7-A(&EN<W3D;&QN:6YG(&;V
M<B!A='0@8F5HY6QL82!O<FEG:6YA;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X,3,@;&EB+TAO<F1E+T9O<FTN<&AP.C(W.3D*;7-G:60@(E-H
M;W<@<&EC:V5R(@IM<V=S='(@(E9I<V$@<&%L971T(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4S,`IM<V=I9"`B4VAO=R!T86)L92!O<&5R871I;VYS
M(&UE;G4@8F%R/R(*;7-G<W1R(")6:7-A("=T86)E;&QA:W1I=FET971E<B<@
M:2!M96YY;C\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4S"B,L('!H
M<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_
M(@IM<V=S='(@(E9I<V$@;65N>2!F]G(@)7,@=&EL;"!VY&YS=&5R/R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I
M86QO9R(*;7-G<W1R(")486)E;&QC96QL:6YS=.1L;&YI;F=A<B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M-`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS
M9W-T<B`B5&%B96QL:6YS=.1L;&YI;F=A<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I9"`B4VAO
M=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(E1A
M8F5L;&EN<W3D;&QN:6YG87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G:60@(E-H;W<@=&AE(&EM
M86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(E9I<V$@9&EA;&]G<G5T
M82!F]G(@8FEL9&5G96YS:V%P97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-S8S(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8W"FUS9VED(")3:&]W
M('5P;&]A9"(*;7-G<W1R(")6:7-A('5P<&QA9&1N:6YG(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@(E-H;W=E
M<G,B"FUS9W-T<B`B4VMU<F%R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H;W=E<G,@16%R;'DB"FUS9W-T
M<B`B5&ED:6=A('-K=7)A<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B
M4V5N82!S:W5R87(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU-`IM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS
M9W-T<B`B4VMU<F%R(&D@;N1R:&5T96XB"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HT.#`@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP
M:'`Z-#@P"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z
M-C$Y"FUS9VED(")3:')I;FLB"FUS9W-T<B`B1O9R;6EN<VMA(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-S<T(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C@S-@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HY,C(@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z.3@T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C$P-#<@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3`X
M-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,3$V(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q-#D*(SH@;&EB+TAO
M<F1E+T)L;V-K+TQA>6]U="YP:'`Z-S<T(&QI8B](;W)D92]";&]C:R],87EO
M=70N<&AP.C@S-@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HY,C(@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z.3@T"B,Z(&QI8B](;W)D92]"
M;&]C:R],87EO=70N<&AP.C$P-#<@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP
M:'`Z,3`X-PHC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HQ,3$V(&QI
M8B](;W)D92]";&]C:R],87EO=70N<&AP.C$Q-#D*(SH@;&EB+TAO<F1E+T)L
M;V-K+TQA>6]U="]-86YA9V5R+G!H<#HY,3`*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HY-S(*(SH@;&EB+TAO<F1E+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HQ,#4X"B,Z(&QI8B](;W)D92]";&]C:R],87EO
M=70O36%N86=E<BYP:'`Z,3$R,`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.C$Q.#,*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-
M86YA9V5R+G!H<#HQ,C(S"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z,3(U,@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.C$R.#4*;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN
M9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R(")+<GEM
M<"!E;&QE<B!F;'ET=&$@8F]R="!NY')L:6=G86YD92!B;&]C:R!F]G)S="(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#4@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,0HC.B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(E-I
M97)R82!,96]N92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H
M<#HR-C4@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-C8*;7-G:60@(E-I
M9VX@=7`B"FUS9W-T<B`B4F5G:7-T<F5R82(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-S$R(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-S$S"FUS9VED(")3:6=N871U<F4B"FUS9W-T<B`B4VEG;F%T=7(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,2!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM<V=I9"`B4VEG;F%T=7)E($%L9V]R
M:71H;2(*;7-G<W1R(")3:6=N871U<F%L9V]R:71M(@H*(SH@8V]N9FEG+W1H
M96UE<R]S:6UP;&5X+G!H<#HV"FUS9VED(")3:6UP;&5X(@IM<V=S='(@(E-I
M;7!L97@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`T(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,#8*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R
M(")3:6YG87!O<F4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C8U(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-CD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-R!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.38*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(Q-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,W"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#8@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,CDS,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(S
M(&QI8B](;W)D92]&;W)M+G!H<#HY,#`@;&EB+TAO<F1E+T9O<FTN<&AP.C$R
M,3D*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-#$@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(R-3`@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,38*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C,Q,#D@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C4*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S(@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#0*;7-G:60@(E-I>F4B"FUS9W-T
M<B`B4W1O<FQE:R(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M
M7V)O='1O;2YI;F,Z.0HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E
M;F%N8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R
M(")!=F)R>70@=6YD97)HY6QL(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-2!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C$P"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,#,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V
M86MI82(*;7-G<W1R(")3;&]V86MI96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,#@*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(P-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@
M(E-L;W9E;FEA(@IM<V=S='(@(E-L;W9E;FEE;B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3;F]W(@IM<V=S
M='(@(E-N]B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4V"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R(")3;O9S:W5R(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G
M:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R(")3;O9S:W5R87(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO
M=R!3:&]W97)S($5A<FQY(@IM<V=S='(@(E1I9&EG82!S;O9S:W5R87(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.0IM<V=I
M9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B4V5N82!S;O9S:W5R87(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X-0IM<V=I9"`B4VYO=R!D97!T
M:#H@(@IM<V=S='(@(E-N]F1J=7`Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C@Y"FUS9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G
M<W1R(")-;W1S=F%R86YD92!S;O8@:2!V871T96XZ("(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#,@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P,@HC.B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`U(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M,PIM<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(E-A;&]M;V[V87)N
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#8@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-`HC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V]M86QI82(*;7-G<W1R(")3;VUA
M;&EA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED(")3;VYG
M<R`F(%!O96US(@IM<V=S='(@(E/E;F=E<B!O8V@@9&EK=&5R(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR-B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,CDQ,@IM<V=I9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`B4V]R
M=&5R:6YG<VEO<F1N:6YG<W9A;"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Q-PHC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-#<*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-C8*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.#D@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4U.0HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3@Y(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C$W"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W(&QI
M8B].970O4TU3+W=I;E]H='1P+G!H<#HQ-C8*(SH@;&EB+TYE="]335,O=VEN
M7VAT='`N<&AP.C$X.0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B
M:^1L;&%D<F5S<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(U-0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A
M(@IM<V=S='(@(E-Y9&%F<FEK82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DS"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<W(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#$*
M(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P."!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE
M(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B4_9D<F$@1V5O<F=I
M82!O8V@@4WES<V%N9'=I8VCV87)N82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N($AE
M;6ES<&AE<F4B"FUS9W-T<B`B4^1D<F$@:&5M:7-FY')E;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3
M<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(E5T<GEM;64@
M;65L;&%N(&EN=&EL;&EG9V%N9&4@8V5L;&5R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E
M='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B571R
M>6UM92!M96QL86X@:6YN96CE;&P@;V-H(&MA;G1E;B!I(&-E;&QE;B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Q-2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z.#$Y"FUS9VED(")3<&%C97(B"FUS9W-T<B`B365L;&%N<G5M(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P
M"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(DUE;&QA;G)U;2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G
M:60@(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B365L;&%N<G5M(&]C
M:"!U=&KD;6YI;F<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,2!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.#`*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P.2!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`B
M4W!A;FEE;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#`*;7-G
M:60@(E-P86TB"FUS9W-T<B`B4W!A;2(*"B,Z('-E<G9I8V5S+VME>6)O87)D
M+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T
M<B`B26YM871N:6YG(&%V('-P96-I96QL82!T96-K96XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8R"FUS9VED
M(")3<&QI="!C96QL(@IM<V=S='(@(D1E;&$@8V5L;"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*;7-G:60@
M(E-P;&ET(&-O;'5M;B(*;7-G<W1R(")$96QA(&MO;'5M;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G
M:60@(E-P;&ET(')O=R(*;7-G<W1R(")$96QA(')A9"(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV,0IM<V=I9"`B4W!O<G1S(@IM<V=S='(@(E-P;W)T
M97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#@@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,0HC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@X"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T<B`B4W)I
M($QA;FMA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8V(&QI
M8B]";&]C:R]M971A<BYP:'`Z.#$*;7-G:60@(E-T86YD87)D(@IM<V=S='(@
M(E-T86YD87)D(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED
M(")3=&%R(%1R96LB"FUS9W-T<B`B4W1A<B!4<F5K(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT-#,*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU-#@*;7-G:60@
M(E-T87)T(@IM<V=S='(@(E-T87)T(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C4Y-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`Y"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR-3DP(&QI8B](;W)D92]&;W)M+G!H<#HR-SDU
M"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@(E-T87)TY7(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,"!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C4W,0IM<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS
M9W-T<B`B4W1A="!E;&QE<B!R96=I;VXB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4X,PHC.B!T96UP;&%T97,O861M
M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S(@IM<V=S='(@
M(E-T871U<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,34@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(X,#$*;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM
M<V=S='(@(DQA9W)I;F=S9F]R;6%T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-S(@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M-S,*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@(D=A='5A9')E<W,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M"FUS9VED(")3=')I:V5T:')O=6=H(@IM<V=S='(@(D=E;F]M<W1R=6ME;B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S,@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$R,S<*;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@(E-T<N1N
M9VQI<W1A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,R!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3@W-PIM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@
M=&AE(&%D9')E<W,B"FUS9W-T<B`B5&$@8F]R="!D;VWD;B!F<N5N(&%D<F5S
M<V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B4W1I;"!;
M0U-372(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C(*;7-G:60@(E-U(@IM<V=S='(@(E/V(@H*(SH@=71I;"]I8V]N7V)R
M;W=S97(N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(E-U8F1I<F5C=&]R
M>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")+86X@:6YT92!H:71T82!U
M;F1E<FMA=&%L;V<@)R5S)RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C<S"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J96-T(@IM<V=S='(@(L1R96YD92(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,B!F<F%M97=O<FLO1F]R
M;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3<*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C,S-B!L:6(O2&]R9&4O1F]R;2]296YD97)E<BYP:'`Z,S$W"FUS9VED(")3
M=6)M:70B"FUS9W-T<B`B4VMI8VMA(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@
M7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL
M('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B
M(@HB1&EN(&)E9^1R86X@871T(&SD9V=A('1I;&P@7"(E<UPB('1I;&P@<WES
M=&5M970@:&%R('-K:6-K871S+B!$=2!K86X@:6YT92`B"B)L;V=G82!I;B!I
M;FYA;B!D:6X@8F5GY')A;B!H87(@86-C97!T97)A=',N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B
M<V-R:7!T(@IM<V=S='(@(DYE9'/D;FMT(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$P-`HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"B,Z(&QI8B](;W)D92].;W1I9FEC
M871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*
M;7-G<W1R("),>6-K870B"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H
M92!S>7-T96TN(@IM<V=S='(@(B<E<R<@;&%D97,@=&EL;"!I('-Y<W1E;65T
M+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R(%PB)7-<(B!F
M<F]M('1H92!S>7-T96TN(@IM<V=S='(@(E)A9&5R861E(&EN9F]R;6%T:6]N
M(&]M(&%N=N1N9&%R92`G)7,G+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z.#`@
M861M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N(@IM<V=S='(@(B<E<R<@
M<F%D97)A9&5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T
M:&4@<WES=&5M+B(*;7-G<W1R("(G)7,G('1O9W,@8F]R="!F<N5N('-Y<W1E
M;65T+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U
M8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@
M<V5E(&-H86YG97,N(@IM<V=S='(@(B(*(DMO;F9I9W5R871I;VYE;B!H87(@
MY71E<G-TY&QL=',N($QA9&1A(&]M('-I9&%N(&;V<B!A='0@<V4@9O9RY&YD
M<FEN9V%R+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU.2!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HU-PIM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D
M(&)A8VMU<"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")3<&%R861E(&)A8VMU
M<&MO;F9I9W5R871I;VXN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@=&AE
M(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(E-P87)A
M9&4@8F%C:W5P:V]N9FEG=7)A=&EO;B`E<RXB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T
M960@7"(E<UPB(@IM<V=S='(@(B<E<R<@=7!P9&%T97)A9&5S+B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C<R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E
M<R(*;7-G<W1R(")3:W)E=B`E<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(P-`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W5D
M86XB"FUS9W-T<B`B4W5D86XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C4U.`HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C4V,`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"FUS9VED(")3=6UM87)Y
M(@IM<V=S='(@(E-A;6UA;G-TY&QL;FEN9R(*"B,Z(&QI8B]";&]C:R]S=6YR
M:7-E+G!H<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B4V]L=7!P9^5N
M9R(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E
M="(*;7-G<W1R(")3;VQN961GY6YG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E-U;FYY(@IM<V=S='(@(E-O
M;&EG="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#4*;7-G
M:60@(E-U;G)I<V4B"FUS9W-T<B`B4V]L=7!P9^5N9R(*"B,Z(&QI8B]";&]C
M:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I
M9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`B4V]L=7!P9^5N9R]N961GY6YG
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-`IM<V=I9"`B
M4W5N<FES93H@(@IM<V=S='(@(E-O;'5P<&?E;F<Z("(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,#@*;7-G:60@(E-U;G-E="(*;7-G<W1R
M(")3;VQN961GY6YG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(P-PIM<V=I9"`B4W5N<V5T.B`B"FUS9W-T<B`B4V]L;F5D9^5N9SH@(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PIM
M<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`B57!P:/9J9"(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS.#`*;7-G:60@(E-U<'!O<G0B"FUS9W-T
M<B`B4W5P<&]R="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(Q-0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4W5R:6YA;64B"FUS
M9W-T<B`B4W5R:6YA;64B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4W-"!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W-0IM<V=I
M9"`B4W5R;F%M92(*;7-G<W1R(")%9G1E<FYA;6XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#D*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(Q,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*
M;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B4W9A;&)A
M<F0@;V-H($IA;B!-87EE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(Q.0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B4W=A>FEL
M86YD(@IM<V=S='(@(E-W87II;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(P-0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$U(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B
M4W=E9&5N(@IM<V=S='(@(E-V97)I9V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-38*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(Q-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I
M='IE<FQA;F0B"FUS9W-T<B`B4V-H=V5I>B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C@V"FUS9VED(")3>6YC(&QO9R!D96QE=&5D(@IM<V=S
M='(@(E-Y:W)O;FES97)I;F=S;&]G9R!R861E<F%D(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$T-0IM<V=I9"`B4WEN8TU,(@IM<V=S='(@(E-Y;F--
M3"(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HY-R!L:6(O
M2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R<F]R
M(&EN('-E87)C:"!T97)M<R(*;7-G<W1R(")3>6YT87AF96P@:2!S]FMK<FET
M97)I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#<@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q
M.`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4WER:6%N($%R86(@4F5P=6)L
M:6,B"FUS9W-T<B`B4WER:65N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E0M4W1O<FTB"FUS9W-T<B`BQ7-K
M<VMU<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8R"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G<W1R("+%<VMS:W5R
M87(@;V-H(&)LY7-I9W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`BQ7-K<VMU
M<F%R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C0*;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM<V=S='(@(E1I9&EG82#E<VMS
M:W5R87(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,38V(&QI
M8B](;W)D92]$871A+W1S=BYP:'`Z,38V"FUS9VED(")44U8@9FEL92(*;7-G
M<W1R(")44U8M9FEL(@H*(SH@9G)A;65W;W)K+U5)+U5)+U1A8FQE+G!H<#HQ
M,S0@;&EB+TAO<F1E+U5)+U1A8FQE+G!H<#HQ,S0*;7-G:60@(E1A8FQE(@IM
M<V=S='(@(E1A8F5L;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B
M"FUS9W-T<B`B5&%B96QL:6YS=.1L;&YI;F=A<B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3<*(SH@;&EB+TAO<F1E+T9O
M<FTO5'EP92]T86)L97-E="YP:'`Z-3<*;7-G:60@(E1A8FQE(%-E="(*;7-G
M<W1R(")486)E;&QU<'!SY'1T;FEN9R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE('!R
M;W!E<G1I97,B"FUS9W-T<B`B5&%B96QL:6YS=.1L;&YI;F=A<B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,T(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-"!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1A:7=A;B(*;7-G
M<W1R(")486EW86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X"FUS9VED
M(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM<V=S='(@(E1A:7=A;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#D@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-0HC.B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R(")486II
M:VES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C,U"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C`@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(E1A;GIA;FEA(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T
M.B(*;7-G<W1R(")-Y6PZ(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P
M-#D@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X.0IM<V=I9"`B5&%S:W,B
M"FUS9W-T<B`B57!P9VEF=&5R(@H*(SH@8V]N9FEG+W1H96UE<R]G96YN979I
M;&QI97)S+G!H<#HQ-`IM<V=I9"`B5&5A;"(*;7-G<W1R(")496%L(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S,@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU-S0*;7-G:60@(E1E;&5P:&]N92!.=6UB97(B
M"FUS9W-T<B`B5&5L969O;FYU;6UE<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,CDW"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")(
M]F=S=&$@=&5M<&5R871U<B!S96YA<W1E('1I;6UE;CH@(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,C$*;7-G:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@
M(E1E;7!E<F%T=7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C$R"FUS9VED(")496UP97)A='5R93H@(@IM<V=S='(@(E1E;7!E<F%T=7(Z
M("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E
M<RD@)F1E9SLE<R(*;7-G<W1R(")496UP97)A='5R/&)R("\^*"5S36%X)7,O
M)7--:6XE<RD@)F1E9SLE<R(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP
M;&%T92YP:'`Z-C@W(&QI8B](;W)D92]496UP;&%T92YP:'`Z-CDU"B,L('!H
M<"UF;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM
M<V=S='(@(DMA;B!I;G1E(&AI='1A(&UA;&P@)7,N(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ-CD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T<F%T:6]N
M(@IM<V=S='(@(D%N=N1N9&%R861M:6YI<W1R871I;VXB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8T,0IM<V=I9"`B
M5&5N=&%T:79E;'D@06-C97!T(')E<75E<W0B"FUS9W-T<B`B1V]D:^1N;B!B
M96?D<F%N('!R96QI;6ENY')T(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HV.#D*;7-G:60@(E1E;G1A=&EV96QY($%C
M8V5P=&5D(@IM<V=S='(@(E!R96QI;6ENY')T(&%C8V5P=&5R870B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$Q(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,S,S4*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,34@;&EB+TAO
M<F1E+T9O<FTN<&AP.C,S,S$*;7-G:60@(E1E>'0B"FUS9W-T<B`B5&5X="(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-SD*;7-G:60@(E1E>'0@3VYL
M>2(*;7-G<W1R(")%;F)A<G0@=&5X="(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G:60@(E1E>'0@86QI
M9VXB"FUS9W-T<B`B5&5X=&IU<W1E<FEN9R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B"FUS
M9W-T<B`B5&5X='1O<"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(E1O(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.30*;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM
M<V=S='(@(E1H86D@*%1)4RTV,C`I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.2!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C(T"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,C$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4
M:&%I;&%N9"(*;7-G<W1R(")4:&%I;&%N9"(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.CDX.`IM<V=I9"`B5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@
M<WES=&5M+B(*;7-G<W1R(")486-K(&;V<B!A='0@9'4@86YVY&YD97(@<WES
M=&5M970N(@H*(SH@<V5R=FEC97,O;&EN:W,O9&5L971E+G!H<#HS-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@)7,@;&EN:R!T;R`E<R!H87,@8F5E;B!R
M96UO=F5D+B(*;7-G<W1R("),Y&YK96X@)7,@=&EL;"`E<R!H87(@<F%D97)A
M=',N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,C`@;&EB+U9&
M4R]F='`N<&AP.C@U,0IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B1E10+71I;&SD9V=E="#D<B!I;G1E('1I
M;&QGY&YG;&EG="XB"@HC.B!L:6(O2&]R9&4O2&ES=&]R>2YP:'`Z-34*;7-G
M:60@(E1H92!(:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B
M2&ES=&]R:6MS>7-T96UE="#D<B!A=F%K=&EV97)A="XB"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.CDS-"!L:6(O2&]R9&4O2V]L86(N<&AP.CDS
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R
M871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@
M(DAO<F1E+TMO;&%B+6EN=&5G<F%T:6]N<V=RY&YS<VYI='1E="!S=/9D97(@
M:6YT92!<(B5S7"(B"@HC.B!L:6(O3F5T+TE-4U`O0F]O:RYP:'`Z,3(Y.`IM
M<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"XB
M"FUS9W-T<B`B24U34"UL;V=G96X@:W5N9&4@:6YT92!I;FET:65R87,N(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@36%I
M;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM
M<V=S='(@(DML87-S96X@36%I;G1E;F%N8V4Z.B!K=6YD92!I;G1E(&QA9&1A
M<R(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G
M:60@(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*
M;7-G<W1R("));G-TY&QL;FEN9W-F]FYS=')E="!H87(@<W3D;F=T<RX@079S
M;'5T87(N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.#D@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,#`*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HR,3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,C,*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,S0@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HR-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HR-C0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,#,*(SH@;&EB+TAO
M<F1E+U!E<FUS+G!H<#HQ.#D@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,#`@;&EB
M+TAO<F1E+U!E<FUS+G!H<#HR,3$*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR
M,C,@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,S0@;&EB+TAO<F1E+U!E<FUS+G!H
M<#HR-3(*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR-C0@;&EB+TAO<F1E+U!E
M<FUS+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A9&UI;FES=')A=&]R(&YE961S
M('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD
M(&EF('EO=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N<RXB"FUS9W-T<B`B
M(@HB061M:6YI<W1R873V<F5N(&WE<W1E(&MO;F9I9W5R97)A(&5N('!E<FUA
M;F5N="!"96CV<FEG:&5T<RUK;W!P;&EN9R!O;2!D=2`B"B)V:6QL(&%N=N1N
M9&$@0F5H]G)I9VAE=&5R+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T;VT@<VED
M92!O;FQY(@IM<V=S='(@(D5N8F%R="!N961R92!S:61A;B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#D*;7-G:60@
M(E1H92!C86QE;F1A<B!D871A(&ES(&EN=F%L:60B"FUS9W-T<B`B2V%L96YD
M97)I;F9O<FUA=&EO;F5N(.1R(&9E;&%K=&EG(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A
M8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R
M('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R(")+
M;VYT86MT96YS($E$(&%N9V%V<R!I;G1E(&5L;&5R(&MU;F1E(&EN=&4@:&ET
M=&%S(&D@9&%T86)A<V5N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HU,2!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C4Q"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D
M9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R(")+;VYT86MT96X@
M;&%D97,@=&EL;"!I(&%D<F5S<V)O:V5N+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$Q-#D@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M,3$W,@IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO
M8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB
M"FUS9W-T<B`B(@HB1&5N(&SV<V=J;W)D82!01U`M<VEG;F%T=7)E;B!K<N1V
M<R!F]G(@871T('9E<FEF:65R82!D970@<VEG;F5R861E("(*(FUE9&1E;&%N
M9&5T+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C0Q"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-#$*;7-G:60@(B(*(E1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET
M:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*
M(FEN('1H92!D871A8F%S92XB"FUS9W-T<B`B(@HB1&ES=')I8G5T:6]N<VQI
M<W1A;G,@240@86YG879S(&EN=&4@96QL97(@:W5N9&4@:6YT92!H:71T87,@
M:2!D871A8F%S96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#(*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N
M;W0@<W!E8VEF:65D+B(*;7-G<W1R(")$:7-T<FEB=71I;VYS;&ES=&%N(&AA
M<B!I;G1E(&%N9VEV:71S+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="YP
M:'`Z,3$S(&QI8B](;W)D92]#<GEP="YP:'`Z,3$V"FUS9VED(")4:&4@96YC
M<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T
M:6]N+B(*;7-G<W1R(")+<GEP=&5R:6YG<V9U;FMT:6]N97)N82!K<N1V97(@
M96X@<^1K97(@=V5B9O9R8FEN9&5L<V4@*$A45%!3*2XB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C<X"FUS9VED(")4
M:&4@979E;G0@:&%S(&)E96X@861D960@=&\@>6]U<B!C86QE;F1A<BXB"FUS
M9W-T<B`B2.1N9&5L<V5N(&QA9&5S('1I;&P@:2!K86QE;F1E<FXN(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S4@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HT.3,*(SH@;&EB+TAO<F1E+G!H<#HQ-S<@;&EB+TAO<F1E
M+G!H<#HU,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO
M=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R(")&:6QE;B`E<R!S
M:V%L;"!I;FYE:.5L;&$@96X@:6YS=.1L;&YI;F<@9O9R("5S+B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38X(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z-#@S"B,Z(&QI8B](;W)D92YP:'`Z,3<P(&QI8B](;W)D92YP
M:'`Z-3`Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L
M9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(D9I;&5N("5S
M('-K86QL(&EN;F5HY6QL82!I;G-TY&QL;FEN9V%R(&;V<B`E<RXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,3D*;7-G:60@(E1H92!F:6QE
M(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+B(*;7-G<W1R(")&:6QE
M;B!K86X@:6YT92!K;W!I97)A<R!T:6QL('-I9R!S:N1L=BXB"@HC.B!L:6(O
M5D93+V9I;&4N<&AP.C(R-@IM<V=I9"`B5&AE(&9I;&4@8V%N;F]T(&)E(&-O
M<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B1FEL96X@:V%N(&EN=&4@:V]P
M:65R87,@=&EL;"!S:6<@<VKD;'8N(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T
M82YP:'`Z,C@P(&QI8B](;W)D92]$871A+G!H<#HR.#`*;7-G:60@(E1H92!F
M:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")&:6QE;B!I;FYE:/9L
M;"!I;F=E;B!I;F9O<FUA=&EO;BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C8W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@
M:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G
M<W1R(")(=79U9&;D;'0@9O9R(&1E='1A(&UE9&1E;&%N9&4O<F9C.#(R;65D
M9&5L86YD92!F]FQJ97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D
M92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X
M<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG
M="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B
M"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A
M;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES
M=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L
M;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E
M9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A
M<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F
M=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R
M969S+G!H<#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y
M(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("))9&5N=&ET971E
M;B`G)7,G(')A9&5R861E<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD
M('-I9&4@;VYL>2(*;7-G<W1R(")"87)A(';D;G-T97(@<VED82(*"B,Z('-E
M<G9I8V5S+VQI;FMS+V1E;&5T92YP:'`Z,S<*;7-G:60@(E1H92!L:6YK(&AA
M<R!B965N(')E;6]V960B"FUS9W-T<B`B3.1N:V5N(&AA<B!T86=I=',@8F]R
M="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$T-B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO
M;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R
M>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R("(B"B)3]FMVY&=E;B!T:6QL($=N
M=5!'+7!R;V=R86UM970@;>5S=&4@=F%R82!A;F=I=F5N('1I;&P@:VQA<W-E
M;B!#<GEP=%]P9W`Z.BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP
M:'`Z,C`Q(&QI8B](;W)D92]-24U%+TU$3BYP:'`Z,C`R"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET
M:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES
M(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E
M860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@HB365D9&5L86YD970@<VMI
M8VMA="`E<R!T:6QL("5S(&UE9"#D<F5N9&4@7"(E<UPB(&AA<B!V:7-A=',N
M7&XB"B)$971T82#D<B!I;F=E;B!G87)A;G1I(&;V<B!A='0@;65D9&5L86YD
M970@:&%R(&SD<W1S+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M-S<@;&EB+TAO<F1E+T9O<FTN<&AP.C$X.#$*;7-G:60@(E1H92!N86UE('1O
M('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R
M(").86UN970@<V]M('-K86QL(&%N=N1N9&%S(&;V<B!A='0@;.1N:V$@=&EL
M;"!S:V%P82US:61A;B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C0T,2!L:6(O1FEL92]#4U8N<&AP.C0W-`IM<V=I9"`B5&AE(&YU;6)E<B!O
M9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*;7-G<W1R(")!;G1A;"!FY&QT
M(&WE<W1E('9A<F$@971T(&YU;65R:7-K="!VY')D92XB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S$@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HQ,C,R"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@
M<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*
M;7-G<W1R(")-;V1U;&5N(&]P96YS<VP@:W+D=G,@878@:VQA<W-E;B!(;W)D
M95]#<GEP=%]S;6EM93HZ+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP
M:'`Z,CDP(&QI8B](;W)D92]0<F5F<RYP:'`Z,C@S"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@
M<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU
M;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"B));G-TY&QL;FEN9V5N(%PB
M)7-<(B!K=6YD92!I;G1E('-P87)A<R!PY2!G<G5N9"!A=B!A='0@9&%T86WD
M;F=D96X@(@HB]G9E<G-K<FEV97(@9&5N(&UA>&EM86QT('1I;&SE=&YA(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O9&5B+G!H<#HS,@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS
M,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=V5B8W!P+G!H<#HS-PHC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O;7-W;W)D+G!H<#HS,B!L:6(O2&]R9&4O34E-12]6:65W97(O
M<G!M+G!H<#HS,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=V5B8W!P+G!H
M<#HS-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP
M.C,W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D('1O('9I
M97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S
M>7-T96TN(@IM<V=S='(@(B(*(E!R;V=R86UM970@<V]M(&%N=N1N9',@9O9R
M(&%T="!V:7-A(&1E;B!HY'(@;65D9&5L86YD971Y<&5N("@E<RD@<V%K;F%S
M('#E("(*(G-Y<W1E;65T+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C0U-"!L:6(O1FEL92]#4U8N<&AP.C0X-PIM<V=I9"`B5&AE('%U;W1E
M(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G
M<W1R(")496-K;F5T(&;V<B!C:71E<FEN9R!MY7-T92!V87)A(&5T="!T96-K
M96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N
M;'DB"FUS9W-T<B`B0F%R82!H]F=E<B!O8V@@=N1N<W1E<B!S:61O<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S@*;7-G:60@(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R(")"
M87)A(&CV9V5R('-I9&$B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HT-#8@;&EB+T9I;&4O0U-6+G!H<#HT-SD*;7-G:60@(E1H92!S97!A<F%T
M;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B4V5P
M87)A=&]R;B!MY7-T92!V87)A(&5T="!T96-K96XN(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B4V5R
M=F5R("<E<R<@<F%D97)A9&5S+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S
M=6TN<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E
M<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R(")397)V97(@)R5S)R!S<&%R
M861E<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO
M=F5D+B(*;7-G<W1R(")0<F5N=6UE<F%T:6]N<V)E9^1R86X@9O9R("5S(&AA
M<B!T86=I=',@8F]R="XB"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.C0W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<W!E8VEF
M:65D(')O=R`H)60I(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")!;F=I=F5N
M(')A9"`H)60I(&9I;FYS(&EN=&4N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z,S,P(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP
M.C,S,`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N
M(@IM<V=S='(@(D%N9VEV96X@<F%D(&5X:7-T97)A<B!I;G1E+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3`X"FUS
M9VED(")4:&4@=&%S:R!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R('1A<VML:7-T
M+B(*;7-G<W1R(")5<'!G:69T96X@:&%R(&QA9W1S('1I;&P@:2!D:6X@=7!P
M9VEF='-L:7-T82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$W
M-R!L:6(O5D93+W-Q;"YP:'`Z,3<Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!T96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S
M='(@(E1E;7!O<N1R(&9I;"`G)7,G(&9I;FYS(&EN=&4N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S,Q,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,P
M-@IM<V=I9"`B5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T
M:&4@=&5X="!O;B!T:&4@<V-R965N+B(*;7-G<W1R(")497AT96X@9'4@;6%T
M870@:6X@<W3D;6UE<B!I;G1E(/9V97)E;G,@;65D('1E>'1E;B!PY2!S:^1R
M;65N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N
M;'DB"FUS9W-T<B`B0F%R82!T;W!P(&]C:"!B;W1T96X@<VED82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*
M;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(D)A<F$@=&]P<'-I
M9&$B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HS,C<@;&EB+TAO<F1E
M+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO
M<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@(E5P<&QA9&1A
M="!D871A(&;V<G-V86YN('-E9&%N(&;V<F5GY65N9&4@<W1E9RXB"@HC.B!F
M<F%M97=O<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R86UE=V]R:R]$871A
M+T1A=&$O='-V+G!H<#HQ-S(*(SH@;&EB+TAO<F1E+T1A=&$O8W-V+G!H<#HR
M-C(@;&EB+TAO<F1E+T1A=&$O='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO
M861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`B1&5N('5P
M<&QA9&1A9&4@9FEL96X@:W5N9&4@:6YT92!S<&%R87,N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HY,PIM<V=I9"`B
M5&AE('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M871I;VX@=V%S('-U8V5S<V9U
M;&QY('-T;W)E9"XB"FUS9W-T<B`B3&5D:6<O=7!P=&%G96XM:6YF;W)M871I
M;VX@9O9R(&%N=N1N9&%R96X@:&%R('-P87)A=',N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C0Y(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ,3`*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@
M879A:6QA8FQE+B(*;7-G<W1R(")796%T:&5R+F-O;2UB;&]C:V5T(.1R(&EN
M=&4@=&EL;&?D;F=L:6=T+B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HR
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER96-T;W)Y(%PB)7-<
M(B!N;W0@9F]U;F0N(@IM<V=S='(@(E1E;6%K871A;&]G("<E<R<@9FEN;G,@
M:6YT92XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$W."!L
M:6(O2&]R9&4O4')E9G,O54DN<&AP.C$W.`IM<V=I9"`B5&AE<F4@87)E(&YO
M(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R("));F=A(&EN<W3D;&QN:6YG
M87(@=&EL;&?D;F=L:6=A+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C,T,2!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z,S0Y
M"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA
M>65D(&EN;&EN92XB"FUS9W-T<B`B1&5T(&9I;FYS(&EN9V$@86QT97)N871I
M=F$@9&5L87(@<V]M(&MA;B!V:7-A<R!I;FQI;F4N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30P,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,30P-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA
M<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H
M87)A8W1E<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS
M9W-T<B`B(@HB1O9R(&WE;F=A('1E8VME;B!I(&;D;'1E="X@1'4@:&%R(&%N
M9V5T="`E<R!T96-K96X[(&UA>&EM86QT(&%N=&%L('1E8VME;B#D<B`B"B(E
M<RXB"@HC.B!S:6=N=7`N<&AP.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG(%PB
M)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R(")0<F]B;&5M(&UE9"!A
M='0@;.1G9V$@=&EL;"`G)7,G('1I;&P@<WES=&5M970Z("5S(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3(R"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O
M;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B4')O8FQE;2!M960@871T(')E;G-A
M(&EN9F]R;6%T:6]N(&]M(&%N=N1N9&%R92`G)7,G(&9RY6X@<WES=&5M970Z
M("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H
M92!S>7-T96TZ("(*;7-G<W1R(")0<F]B;&5M(&UE9"!A='0@=&$@8F]R="`G
M)7,G(&9RY6X@<WES=&5M970Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('5P9&%T
M:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B4')O8FQE;2!V:60@=7!P9&%T97)I
M;F<@878@)R5S)SH@)7,B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R
M+G!H<#HX-SD@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDR-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(E!R;V)L96T@
M=FED('5P<&QA9&1N:6YG(&%V(&9I;&5N+B!);F=A("5S(&QA9&1A9&5S('5P
M<"XB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#0@;&EB
M+TAO<F1E+T)R;W=S97(N<&AP.CDS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4
M:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*(F%L;&]W960@
M<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B"B)$970@=7!P<W1O9"!P<F]B
M;&5M('9I9"!U<'!L861D;FEN9R!A=B!F:6QE;CH@)7,@Y'(@<W3V<G)E(.1N
M(&UA>&EM86QT("(*(G1I;&SE=&5N('-T;W)L96L@*"5D(&)Y=&5S*2XB"@HC
M.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#8@;&EB+TAO<F1E
M+T)R;W=S97(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R
M92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@
M=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R("(B"B)$970@
M=7!P<W1O9"!P<F]B;&5M('9I9"!U<'!L861D;FEN9R!A=B!F:6QE;CH@)7,@
M;&%D9&%D97,@96YB87)T('5P<"!D96QV:7,N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F9C.#(R+G!H<#HS-0HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B1&5T
M('5P<'-T;V0@971T(&9E;"!V:60@=FES;FEN9R!A=B!M961D96QA;F1E9&5L
M96XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C,Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HT
M."!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T
M<B`B1F5L('9I9"!I;7!O<G0@878@:V]N=&%K=&1A=&$N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HW-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H
M92!E=F5N=#H@)7,N(@IM<V=S='(@(D9E;"!V:60@:6UP;W)T(&%V(&CD;F1E
M;'-E;CH@)7,N(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]I;6,N<&AP.C,Q
M(&QI8B](;W)D92]$871A+VEM8RYP:'`Z,S$*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R
M(")&96P@=FED(&EM<&]R="!A=B!I0V%L96YD87(@9&%T82XB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C$P-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG
M('1H92!T87-K.B`E<RXB"FUS9W-T<B`B1F5L('9I9"!I;7!O<G0@878@=7!P
M9VEF=&5N.B`E<RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.CDQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=7-E<B=S(&9R964O8G5S>2!I;F9O<FUA
M=&EO;CH@)7,N(@IM<V=S='(@(D9E;"!V:60@:6UP;W)T(&%V(&EN9F]R;6%T
M:6]N(&]M(&QE9&EG+W5P<'1A9V5N.B`E<RXB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C@R"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@:6X@
M=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@
M82`B"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B(@HB171T(&9E;"!PY71R
MY&9F861E<R!I(&9O<FUU;.1R970N($MO;G1R;VQL97)A(&%T="!D=2!I;G1E
M(&=L]FUT(&9Y;&QA(&D@971T("(*(F]B;&EG871O<FES:W0@9N1L="XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M.`HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X"FUS9VED
M("(B"B)4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF
M:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I
M;B!L871E<BXB"FUS9W-T<B`B(@HB1&5T(&=I8VL@:6YT92!A='0@=71F]G)A
M(&1E;B!B96?D<F1A(&%D<F5S<V)O:W-F=6YK=&EO;F5N+B!687(@9V]D(&;V
M<G/V:R`B"B)S96YA<F4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-#`*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8T,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P
M9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@
M;&%T97(N(@IM<V=S='(@(D9E;"!V:60@=7!P9&%T97)I;F<@878@:V]N=&%K
M='5P<&=I9G1E<BX@1O9R<_9K(&EG96X@<V5N87)E+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(R(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4*(SH@;&EB+TYE="]335,O=VEN7VAT
M='`N<&AP.C(R,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T
M:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L
M871E<BXB"FUS9W-T<B`B1F5L('9I9"!U<'!D871E<FEN9R!A=B!D:7-T<FEB
M=71I;VYS;&ES=&%N+B!&]G)S]FL@:6=E;B!S96YA<F4N(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*;7-G:60@(E1H:7,@24U!4"!S97)V
M97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@
M(D1I;B!)34%0+7-E<G9E<B!S=/9D97(@:6YT92!D96QA9&4@;6%P<&%R+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M.#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HY-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C$Q,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C(P,`IM<V=I9"`B5&AI<R!A8W1I;VX@:7,@;F]T('-U<'!O<G1E
M9"XB"FUS9W-T<B`B1&5N;F$@:&%N9&QI;F<@<W3V9',@:6YT92XB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C$Q.`HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C,U
M.0IM<V=I9"`B5&AI<R!A8W1I;VX@:7,@;F]T('EE="!I;7!L96UE;G1E9"XB
M"FUS9W-T<B`B1&5N;F$@9G5N:W1I;VX@Y'(@:6YT92!I;7!L96UE;G1E<F%D
M(.1N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-#@@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*;7-G:60@(E1H
M:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N
M(@IM<V=S='(@(D9I;&5N('9E<FMA<B!I;G1E('9A<F$@971T(&=I;'1I9W0@
M4D%2+6%R:VEV+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-3(@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G
M:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I
M;&4N(@IM<V=S='(@(D9I;&5N('9E<FMA<B!I;G1E('9A<F$@971T(&=I;'1I
M9W0@6DE0+6%R:VEV+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q
M-#4@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,S$*;7-G:60@(E1H:7,@9&]E<R!N
M;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R(")&
M96QA:W1I9W0@:V]R=&YU;6UE<BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HQ.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E
M;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@
M=&AE($A45%`@05!)(@IM<V=S='(@(B(*(D1E;FYA(&1R:79R=71I;B!G]G(@
M9&5T(&WV:FQI9W0@871T('-K:6-K82!M961D96QA;F1E;B!V:6$@0VQI8VMA
M=&5L;"TB"B)B<GEG9V%N("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&=E;F]M
M(&%T="!A;G;D;F1A($A45%`@05!).G0N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HQ,S0@;&EB+TYE="]335,O=VEN7VAT='`N
M<&AP.C$S-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O
M;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*
M(D1E;FYA(&1R:79R=71I;B!G]G(@9&5T(&WV:FQI9W0@871T('-K:6-K82!M
M961D96QA;F1E;B!V:6$@5TE.+6)R>6=G86X@(@HB*&AT='`Z+R]W:6YP;&,N
M8V]M*2!G96YO;2!A='0@86YVY&YD82!(5%10($%023IT(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T
M:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A
M>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*(D1E;FYA(&1R:79R
M=71I;B!G]G(@9&5T(&WV:FQI9W0@871T('-K:6-K82!M961D96QA;F1E;B!V
M:6$@<VUS,F5M86EL+6)R>6=G86X@(@HB*&AT='`Z+R]S;7,R96UA:6PN8V]M
M*2!G96YO;2!A='0@86YVY&YD82!(5%10($%023IT(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*(SH@;&EB
M+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB
M5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--
M5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@(@HB9V%T97=A>2P@;VYL
M>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A
M8V-O=6YT('=I=&@@(@HB5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP
M+FET*2XB"FUS9W-T<B`B(@HB1&5N;F$@9')I=G)U=&EN(&?V<B!D970@;?9J
M;&EG="!A='0@<VMI8VMA(&UE9&1E;&%N9&5N('9I82!33510(&=E;F]M("(*
M(E9O9&%F;VYE($ET86QI96XM8G)Y9V=A;B`H96YB87)T('1I;&P@5F]D869O
M;FYU;6UE<BDN($1R:79R=71I;F5N(&MRY'9E<B!E='0@(@HB92UP;W-T:V]N
M=&\@:&]S(%9O9&%F;VYE($ET86QI96X@*&AT='`Z+R]W=W<N,3DP+FET*2XB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-S@@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3`U-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,#@V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,34*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3$X,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C4V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#4@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3,Y.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-34W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,SD*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3DU."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,#`U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,CD@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`W.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,30Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,C$*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q,"!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-#4T"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-3<@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@R.`HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,3,W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,#4*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@Q,R!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS.#(Q"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY.#(@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$P-C$@;&EB+TAO<F1E+T9O<FTN<&AP.C$P.3`*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,3D@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q
M.#8@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-C`*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$S,#D@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,#(@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$U-C$*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-#,@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$Y-C(@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,#D*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(P,S,@;&EB+TAO<F1E+T9O<FTN<&AP.C(P
M.#(@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q-3,*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(R,C4@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,3(@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(T-30*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(V-#$@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(X,30@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,C,*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C,S,#$@;&EB+TAO<F1E+T9O<FTN<&AP.C,X
M,#D@;&EB+TAO<F1E+T9O<FTN<&AP.C,X,3<*;7-G:60@(E1H:7,@9FEE;&0@
M:7,@<F5Q=6ER960N(@IM<V=S='(@(D;D;'1E="!MY7-T92!V87)A(&EF>6QL
M="XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#8U(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,#8Y"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O
M;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@(D;D;'1E="!FY7(@96YB87)T(&EN
M;F5HY6QL82!H96QT86PN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C0Q."!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0R,`IM<V=I9"`B5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BXB"FUS
M9W-T<B`B1N1L=&5T(&;E<B!E;F)A<G0@:6YN96CE;&QA('-I9F9R;W(@;V-H
M(&MO;&]N+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.30@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$P.3@*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N
M;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(D;D;'1E="!FY7(@
M96YB87)T(&EN;F5HY6QL82!O:W1A;&$@=&%L+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q,C,@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,C<*;7-G
M:60@(E1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R
M871E9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S='(@(B(*(D;D;'1E="!S:V%L
M;"!V87)A(&5N(&MO;6UA+2!E;&QE<B!M96QL86YS;&%G<W-E<&%R87)A9"!L
M:7-T82!M960@:&5L=&%L(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.3@Y(&QI8B](;W)D92]&;W)M+G!H<#HY.3,*;7-G:60@(E1H:7,@9FEE;&0@
M;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`B1N1L=&5T(&WE<W1E
M('9A<F$@971T(&=O9&OD;G0@=&%L+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X,S8@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,C(*;7-G:60@(B(*
M(E1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@
M4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS
M9W-T<B`B(@HB1&5T=&$@9N1L="!MY7-T92!I;FYE:.5L;&$@96X@4D="+6;D
M<F=K;V0@:2!H97AA9&5C:6UA;'0@9F]R;6%T+"!T(&5X("(*(B<C,3(S-&%F
M)RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU-C$@;&EB+TAO<F1E
M+T9O<FTN<&AP.C4V-0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E
M96X@<')O8V5S<V5D+B(*;7-G<W1R(")$971T82!F;W)M=6SD<B!H87(@<F5D
M86X@8F5A<F)E=&%T<RXB"@HC.B!T96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S+B(*;7-G<W1R(")$
M970@:.1R(.1R("5S+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M-#4Y(&QI8B](;W)D92]+;VQA8BYP:'`Z-#8Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V
M:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI
M96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M
M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S
M92!V:7-I="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HU.3`@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP
M.C4Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R
M:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R
M(&]W;BXB"FUS9W-T<B`B365D9&5L86YD970@<VMR979S(&D@96X@86YN86X@
M=&5C:V5N=7!P<^1T=&YI;F<@*"5S*2#D;B!D:6X@96=E;BXB"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-B!L:6(O2&]R9&4O4')E9G,O
M54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S
M="!O;F4N(@IM<V=S='(@(D1E="!HY'(@;G5M<F5T(&WE<W1E('9A<F$@;6EN
M<W0@971T+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP
M+G!H<#HT-2!L:6(O2&]R9&4O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@
M(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I
M;&5S+B(*;7-G<W1R(")397)V97)N(&MA;B!I;G1E('!A8VMA('5P<"!Z:7`@
M;V-H(&=Z:7`@9FEL97(N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E
M9VES=')Y+G!H<#HQ.#8@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HQ.#D*;7-G
M:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"XB"FUS
M9W-T<B`B4WES=&5M970@Y'(@9O9R('1I;&QFY&QL970@879A:W1I=F5R870N
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C0@;&EB+TAO
M<F1E+U!R969S+U5)+G!H<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@;75S="!B
M92!A(&YU;6)E<BXB"FUS9W-T<B`B1&5T(&CD<B!VY')D970@;>5S=&4@=F%R
M82!N=6UE<FES:W0N(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R
M+G!H<#HS-0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O
M;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R(")$971T82!F]FYS=&5R(&WE
M<W1E(&%N<F]P87,@9G+E;B!E='0@:V]N9FEG=7)A=&EO;G-F]FYS=&5R(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C4*;7-G
M:60@(E1H=6YD97(B"FUS9W-T<B`BQ7-K82(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR,S8*;7-G:60@(E1I8VME=',B"FUS9W-T<B`BQ')E;F1E
M;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,C@@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(T,CD*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C4U"FUS9VED(")4:6UE(@IM<V=S='(@(E1I9"(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS.#@*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS9W-T
M<B`B5&ED<W)E9&]V:7-N:6YG(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W
M"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R(")4:61S9F]R;6%T(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4S.2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C4S-0IM<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B5&ED<W9A
M;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3`@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,`HC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS9W-T<B`B
MUG-T=&EM;W(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C(Y"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P"FUS9VED(")4:71L92(*;7-G
M<W1R(")2=6)R:6LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@
M(E)U8G)I:R`H=&]O;'1I<"DZ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HW-0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`B5&EL;"(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV,CD*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U-`IM<V=I9"`B(@HB
M5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R
M;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN
M9RXB"FUS9W-T<B`B(@HB1O9R(&%T="!M87)K97)A(&9L97)A('9A;"P@:.5L
M;"!N960@0W1R;"`H4$,I(&5L;&5R($-O;6UA;F0@*$UA8RD@=&%N9V5N=&5N
M("(*(F[D<B!D=2!K;&EC:V%R+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS,#`*;7-G:60@(E1O9&%Y(@IM<V=S='(@(DED86<B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(X"FUS9VED
M(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T<B`B5FES82!(5$U,+6OD;&QA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P.2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(S"B,Z
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C,@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4;V=O(@IM<V=S='(@(E1O9V\B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$P(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C8*(SH@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-"!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3`*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B5&]K96QA=2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#(*;7-G:60@(E1O
M;6]R<F]W(@IM<V=S='(@(DEM;W)G;VXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,CD*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(R-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@
M(E1O;F=A(@IM<V=S='(@(E1O;F=A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<W"FUS9VED(")4;W`B"FUS9W-T
M<B`B5&]P(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY,PIM<V=I9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R(")4;W`@
M9G)A;64@*%]T;W`I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S"FUS
M9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`BUG9E<G/D='1N:6YG87(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$Q(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S(*(SH@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T
M<B`B5')I;FED860@;V-H(%1O8F%G;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$W.3`@;&EB+TAO<F1E+T9O<FTN<&AP.C$W.30*;7-G:60@(E1R
M=64@;W(@9F%L<V4B"FUS9W-T<B`B4V%N="!E;&QE<B!F86QS:W0B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED
M(")4=2(*;7-G<W1R(")4:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(R.`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(W(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5N:7-I
M82(*;7-G<W1R(")4=6YI<VEE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(S,0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5R
M:V5Y(@IM<V=S='(@(E1U<FMI970B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$Y-0IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B5'5R
M:VES:R`H25-/+3@X-3DM.2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,C<*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(R.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U<FMM
M96YI<W1A;B(*;7-G<W1R(")4=7)K;65N:7-T86XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C`*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(S,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#@*
M;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R(")4=7)K
M<RT@;V-H($-A:6-O<_9A<FYA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,2!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C,S"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,S$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=79A
M;'4B"FUS9W-T<B`B5'5V86QU(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP
M.C(V-"!L:6(O2&]R9&4O0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C
M:&]I8V4Z("(*;7-G<W1R(")!;F=E(&1I='0@=F%L.B`B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4X"FUS9VED(")5+E8N(&EN9&5X.B`B
M"FUS9W-T<B`B558M:6YD97@Z("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HR-#D*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@
M(E523"(*;7-G<W1R(")54DPB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4T,0HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E
M;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B55),(&;V<B!D:71T(&QE
M=F5R86YS<F%P<&]R=&5R:6YG<W-K<FEP="(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3<*;7-G:60@(E523#HB"FUS9W-T
M<B`B55),.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(S-PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A;F1A(@IM<V=S='(@
M(E5G86YD82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(S-@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56MR86EN92(*;7-G<W1R
M(")5:W)A:6YA(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#$R
M(&QI8B]61E,O9FEL92YP:'`Z-#$Y"FUS9VED(")5;F%B;&4@=&\@86-C97-S
M(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DMA;B!I;G1E(&SD<V$@5D93+6UA
M<'`N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.CDV(&QI
M8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A
M9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM
M<V=S='(@(B(*(D1E="!G:6-K(&EN=&4@871T(&SD9V=A('1I;&P@=73V:V%D
M(&%N=N1N9&%R:6YF;W)M871I;VX@=FED(')E9VES=&5R:6YG+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S@X(&QI8B]61E,O9G1P+G!H<#HS
M.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M
M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DMA;B!I;G1E
M(.1N9')A(&)E:/9R:6=H970@9O9R(%9&4RUF:6P@)7,N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,S@U(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HT-C@*(SH@;&EB+U9&4R]F:6QE+G!H<#HS.3(@;&EB+U9&4R]M
M=7-Q;"YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C
M:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@
M(DMA;B!I;G1E(.1N9')A(&)E:/9R:6=H970@9O9R(%9&4RUF:6P@)7,O)7,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-34@;&EB+U9&4R]F
M='`N<&AP.C<X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA
M;F=E('1O("5S+B(*;7-G<W1R(")+86X@:6YT92#D;F1R82!T:6QL("5S+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8X.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE("5S+R5S(@IM
M<V=S='(@(DMA;B!I;G1E(&MO;G1R;VQL97)A(&9I;'-T;W)L96L@)7,O)7,B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(S,B!L:6(O5D93+V9T
M<"YP:'`Z,C,W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C
M:R!F:6QE('-I>F4@;V8@7"(E<UPB+B(*;7-G<W1R(")+86X@:6YT92!K;VYT
M<F]L;&5R82!F:6QS=&]R;&5K('#E("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z,3`Q-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z.#,T"B,Z(&QI8B]61E,O9FEL92YP:'`Z-CDU(&QI8B]61E,O<W%L+G!H
M<#HQ,#(X(&QI8B]61E,O<W%L7V9I;&4N<&AP.C@U,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<
M(BXB"FUS9W-T<B`B2V%N(&EN=&4@:V]N=')O;&QE<F$@9FEL<W1O<FQE:R!P
MY2`E<R\E<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z-#,U
M(&QI8B](;W)D92]!=71H+W-Q;"YP:'`Z-#,Y"FUS9VED(")5;F%B;&4@=&\@
M8V]N;F5C="!T;R!344P@<V5R=F5R+B(*;7-G<W1R(")+86X@:6YT92!K;VYT
M86MT82!344PM<V5R=F5R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z.#,Y(&QI8B]61E,O9G1P+G!H<#HX-S`*;7-G:60@(E5N86)L92!T;R!C
M;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R(")+86X@:6YT92!K;VYT86MT82!V
M:6$@4U-,+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R-2!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,S`*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HR,#D@;&EB+U9&4R]F:6QE+G!H<#HR,S(*(SH@;&EB+U9&4R]F:6QE+G!H
M<#HR,S<@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C`T(&QI8B]61E,O<W%L7V9I
M;&4N<&AP.C(P.0HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR,3<*;7-G:60@
M(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R(")+86X@:6YT92!K
M;W!I97)A(%9&4RUF:6PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HS-C4@;&EB+U9&4R]F='`N<&AP.C,W,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G
M<W1R(")+86X@:6YT92!S:V%P82!61E,M;6%P<"`E<RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HS-30@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C(U.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,C4V(&QI8B]61E,O9FEL92YP:'`Z,S8Q"B,Z(&QI8B]61E,O;75S<6PN<&AP
M.C(U."!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR-C0*;7-G:60@(E5N86)L92!T
M;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B2V%N(&EN=&4@<VMA
M<&$@5D93+6UA<'`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C$R-"!L:6(O5D93+VUU<W%L+G!H<#HQ,C0*;7-G:60@(E5N86)L92!T;R!C
M<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(DMA;B!I;G1E('-K87!A(%9&4RUF
M:6PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR.#8@;&EB+U9&
M4R]S;6(N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M8W)E871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(")+86X@:6YT92!S
M:V%P82!61E,M;6%P<"`G)7,G+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C(V-2!L:6(O5D93+V9I;&4N<&AP.C(W,@IM<V=I9"`B56YA8FQE
M('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T<B`B2V%N(&EN=&4@
M<VMA<&$@=&]M(%9&4RUF:6PN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+W1A<BYP:'`Z-S8*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+V=Z:7`N<&AP.C<Y(&QI8B](;W)D92]#;VUP<F5S<R]T87(N<&AP.C<V
M"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]G>FEP+G!H<#HW.0IM<V=I9"`B56YA
M8FQE('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B2V%N(&EN=&4@<&%C
M:V$@=7!P(&1A=&$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR
M,C0@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR.3@*(SH@;&EB+U9&4R]S
M;6(N<&AP.C(R."!L:6(O5D93+V9T<"YP:'`Z,S`S"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y
M(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B2V%N(&EN=&4@<F%D97)A("5S+"!M
M87!P96X@Y'(@:6YT92!T;VTN(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW."!A
M9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T<B`B2V%N(&EN
M=&4@<F%D97)A("<E<R<Z("5S(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,S,Q(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,SDR"B,Z(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,3$@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,S-`HC.B!L:6(O5D93+V9I;&4N<&AP.C,S."!L
M:6(O5D93+W-Q;"YP:'`Z,SDU(&QI8B]61E,O;75S<6PN<&AP.C,Q,0HC.B!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HS-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP
M='DB"FUS9W-T<B`B2V%N(&EN=&4@<F%D97)A("5S+"!M87!P96X@Y'(@:6YT
M92!T;VTN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T
M."!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4R"B,Z(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C,U-B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS-C`*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I
M=F5L>2XB"FUS9W-T<B`B2V%N(&EN=&4@<F%D97)A(%9&4RUM87!P(')E:W5R
M<VEV="XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S<@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,R,@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HS-#,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T-"!L
M:6(O5D93+V9I;&4N<&AP.C,T-`HC.B!L:6(O5D93+VUU<W%L+G!H<#HS,C(@
M;&EB+U9&4R]M=7-Q;"YP:'`Z,S,U(&QI8B]61E,O;75S<6PN<&AP.C,T,PHC
M.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS-3(*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B2V%N(&EN=&4@<F%D97)A
M(%9&4RUM87!P+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#$W
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#(Y"B,Z(&QI8B]61E,O<W%L
M+G!H<#HT,C`@;&EB+U9&4R]S<6PN<&AP.C0S,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G
M<W1R(")+86X@:6YT92!R861E<F$@5D93+6UA<'`Z("5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,C`W(&QI8B]61E,O9G1P+G!H<#HR,3(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL
M92!<(B5S7"(N(@IM<V=S='(@(DMA;B!I;G1E(')A9&5R82!61E,M9FEL("5S
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,P,R!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C(X.`HC.B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,38W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#`*
M(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X-R!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S@S"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HS.3$@;&EB+U9&4R]F:6QE+G!H<#HS,3`@;&EB+U9&
M4R]S<6PN<&AP.C(Y,0HC.B!L:6(O5D93+VUU<W%L+G!H<#HQ-C<@;&EB+U9&
M4R]M=7-Q;"YP:'`Z,3@P(&QI8B]61E,O;75S<6PN<&AP.C$X-PHC.B!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HS.3$@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,SDY
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R(")+
M86X@:6YT92!R861E<F$@5D93+69I;"XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C(T-"!L:6(O5D93+W-M8BYP:'`Z,C0X"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B!<(B5S7"(N
M(@IM<V=S='(@(DMA;B!I;G1E(')A9&5R82!61E,M;6%P<"`G)7,G+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#`V(&QI8B]61E,O<W%L+G!H
M<#HT,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R(")+86X@:6YT92!R861E<F$@
M5D93(')E:W5R<VEV=#H@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX,#,@;&EB+U9&4R]F='`N<&AP.C@S-`IM<V=I9"`B56YA8FQE('1O
M(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`B2V%N(&EN
M=&4@879G]G)A(&%K='5E;&P@;6%P<"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8P,R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C8P-`IM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T
M86EL<R(*;7-G<W1R(")+86X@:6YT92!E>'1R86AE<F$@0V5R=&EF:6MA='-D
M971A;&IE<B(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+G!H<#HT-3$@
M9G)A;65W;W)K+TYE=%])35-0+TE-4U`O075T:"YP:'`Z,3$X"B,Z(&QI8B].
M970O24U34"YP:'`Z-#,W(&QI8B].970O24U34"]!=71H+G!H<#HQ,C,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I
M;VX@;V8@)7,N(@IM<V=S='(@(DMA;B!I;G1E(&QA9&1A(&1E9FEN:71I;VYE
M;B!A=B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ.38@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HQ-C8@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C$W,0HC.B!L:6(O5D93+V9I;&4N<&AP.C(P,R!L:6(O5D93
M+V9I;&4N<&AP.C(P."!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-S0*(SH@;&EB
M+U9&4R]S<6Q?9FEL92YP:'`Z,3<Y"FUS9VED(")5;F%B;&4@=&\@;6]V92!6
M1E,@9FEL92XB"FUS9W-T<B`B2V%N(&EN=&4@9FQY='1A(%9&4RUF:6PN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HY,R!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C$P,@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C8T."!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.CDX"B,Z(&QI8B]61E,O
M<VUB+G!H<#HY,R!L:6(O5D93+W-M8BYP:'`Z,3`V(&QI8B]61E,O<VUB+G!H
M<#HV-3(*(SH@;&EB+U9&4R]F='`N<&AP.CDX"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M2V%N(&EN=&4@]G!P;F$@5D93+69I;"`E<RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HR-S<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,S
M(&QI8B]61E,O9FEL92YP:'`Z,C@T"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP
M.C$S."!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-#$*;7-G:60@(E5N86)L92!T
M;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R(")+86X@:6YT
M92#V<'!N82!61E,M9FEL(&;V<B!S:W)I=FYI;F<N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z.#`@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,B!L
M:6(O5D93+V9I;&4N<&AP.C@S(&QI8B]61E,O9FEL92YP:'`Z,3,W"B,Z(&QI
M8B]61E,O<W%L7V9I;&4N<&AP.C<V"FUS9VED(")5;F%B;&4@=&\@;W!E;B!6
M1E,@9FEL92XB"FUS9W-T<B`B2V%N(&EN=&4@]G!P;F$@5D93+69I;"XB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C0U(&QI8B](
M;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C0U"FUS9VED(")5;F%B;&4@=&\@
M;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@(DMA;B!I;G1E(/9P
M<&YA(&MO;7!R:6UE<F%T(&%R:VEV+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HX,S8@;&EB+U9&4RYP:'`Z.#4V"FUS9VED(")5;F%B;&4@=&\@<F5A
M9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+B(*;7-G<W1R(")+86X@
M:6YT92!LY'-A(%9&4RUF:6P@*&9I;&5S:7IE*"D@;6ES<VQY8VMA9&5S*2XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#8W(&QI8B]61E,N<&AP.C@X
M-PIM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE
M*"D@9F%I;&5D*2XB"FUS9W-T<B`B2V%N(&EN=&4@;.1S82!61E,M9FEL("AG
M971&:6QE4VEZ92@I(&UI<W-L>6-K861E<RDN(@H*(SH@9G)A;65W;W)K+U-E
M<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"B,Z(&QI
M8B](;W)D92]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`IM<V=I9"`B56YA
M8FQE('1O(')E860@9FEL93H@(@IM<V=S='(@(DMA;B!I;G1E(&SD<V$@9FEL
M.B`B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV-CD@;&EB+U9&
M4R]F:6QE+G!H<#HV-S8*;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V9G-R
M;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`B2V%N(&EN=&4@;.1S82!K871A;&]G
M96X@9O9R("=V9G-R;V]T)RXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C$Q,#4@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,3`Y"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T
M:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*;7-G<W1R(")+86X@:6YT92!B
M>71A(&YA;6X@<.4@)7,@=&EL;"`E<SH@9&5S=&EN871I;VYS;6%P<"!F:6YN
M<R!R961A;B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR
M.3,@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DMA;B!I;G1E(&)Y=&$@
M;F%M;B!PY2!61E,M;6%P<"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C,R.2!L:6(O5D93+W-Q;"YP:'`Z,S,R"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S
M='(@(DMA;B!I;G1E(&)Y=&$@;F%M;B!PY2!61E,M;6%P<#H@)7,N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-C<@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HS-#,*(SH@;&EB+U9&4R]S;6(N<&AP.C(W,2!L:6(O5D93
M+V9T<"YP:'`Z,S0X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")+86X@:6YT92!B>71A
M(&YA;6X@<.4@5D93+69I;"`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HV,3`@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(R.0HC
M.B!L:6(O5D93+V9I;&4N<&AP.C8Q-R!L:6(O5D93+VUU<W%L+G!H<#HR,CD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL
M92`E<R\E<RXB"FUS9W-T<B`B2V%N(&EN=&4@8GET82!N86UN('#E(%9&4RUF
M:6P@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,C,@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(Q,PHC.B!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z-#4R(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HR.#4*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C,P,2!L:6(O5D93+W-Q;"YP:'`Z,S(V"B,Z(&QI8B]61E,O;75S<6PN<&AP
M.C(Q,R!L:6(O5D93+VUU<W%L+G!H<#HT-3(@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z,CDS"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,P.0IM<V=I9"`B56YA
M8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T<B`B2V%N(&EN=&4@8GET
M82!N86UN('#E(%9&4RUF:6PN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"B,Z(&9R86UE=V]R:R]61E-?
M25-/+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,2!L:6(O5D93+TE33U=R:71E
M<B]M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F
M<R<N(@IM<V=S='(@(DMA;B!I;G1E(&OV<F$@)VUK:7-O9G,G+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L
M92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(DMA
M;B!I;G1E(/9V97)SY'1T82!7;W)D9&]K=6UE;G1E="(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,30Y(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,34R"B,Z(&QI8B]61E,O9G1P+G!H<#HQ-30@;&EB+U9&4R]F='`N<&AP
M.C$U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")+86X@:6YT92!S:W)I=F$@=&EL;"!6
M1E,M9FEL("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$W
M.2!L:6(O5D93+V9I;&4N<&AP.C$X-@IM<V=I9"`B56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B2V%N(&EN=&4@
M<VMR:79A('1I;&P@5D93+69I;"`H8V]P>2@I(&UI<W-L>6-K861E<RDN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@Q(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S@*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C$T,R!L:6(O5D93+V9I;&4N<&AP.C(X.`HC.B!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HQ-#8@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,34Q
M"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T
M<B`B2V%N(&EN=&4@<VMR:79A(&1A=&$@=&EL;"!61E,M9FEL+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HX-#(@;&EB+U9&4RYP:'`Z.#8R"FUS9VED
M(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC
M965D960N(@IM<V=S='(@(DMA;B!I;G1E('-K<FEV82!T:6QL(%9&4RUF:6PL
M(&MV;W1A('-K=6QL92#V=F5R<VMR:61A<RXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B
M"FUS9W-T<B`B56YD97)S=')U:V5N(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N
M9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(L5N9W)A(.1N
M9')I;F=A<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S
M='(@(L5N9W)A<B!D:6X@<V5N87-T92#E=&?D<F0B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,SDP(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HR,C$*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,X.`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E
M<G9E<B!O;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`B3W;D;G1A="!S=F%R(&9R
MY6X@<V5R=F5R('#E(&;V<F)I;F1E;'-E.B`B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0Q"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,W.`HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS.#0@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C(Q-PHC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S,Y(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S8*(SH@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,@IM<V=I9"`B56YE>'!E
M8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@(D]VY&YT
M870@<W9A<B!F<N5N('-E<G9E<B!T:6QL.B`B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC.B!L:6(O2&]R9&4O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV,0IM<V=I9"`B56YF:6QE9"(*
M;7-G<W1R(")%:B!K871E9V]R:7-E<F%D(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HS.#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YH86YD;&5D(&-O;7!O;F5N="!O9B!T>7!E.B`E<R(*;7-G<W1R
M("))8VME(&AA;G1E<F%D(&MO;7!O;F5N="!A=B!T>7`Z("5S(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.38*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*
M;7-G<W1R(")5;FEC;V1E("A55$8M."DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3<*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(S-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI
M=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B1O9R96YA9&4@07)A8F5M:7)A
M=&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<T(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S@*
M(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-2!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T
M<B`B4W1O<F)R:71A;FYI96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR-#`*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(S-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E
M9"!3=&%T97,B"FUS9W-T<B`B1O9R96YT82!3=&%T97)N82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3,@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S.0HC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA
M;F1S(@IM<V=S='(@(D%M97)I:V%N<VMA(%-T:6QL86AA=G/V87)N82(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV,B!L:6(O0FQO8VLO;65T
M87(N<&AP.C<X"FUS9VED(")5;FET<R(*;7-G<W1R(")%;FAE=&5R(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$X(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0Q.0HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HT,CD@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#,P"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C4X"FUS9VED(")5;FMN;W=N(@IM
M<V=S='(@(D]KY&YD(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDX"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P:6US9VED("A!4$D@365S
M<V%G92!)1"DN(@IM<V=S='(@(D]KY&YT(&=RY&YS<VYI='1S;65D9&5L86YD
M96ED("AA<&EM<V=I9"DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDY"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN;W=N(&-L:6US9VED("A#;&EE
M;G0@365S<V%G92!)1"DN(@IM<V=S='(@(D]KY&YT(&ML:65N=&UE9&1E;&%N
M9&5I9"`H8VQI;7-G:60I+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-#<*;7-G:60@(E5N:VYO=VX@;&]C871I;VX@<')O=FED960N(@IM
M<V=S='(@(D]KY&YD(&]R="!S<&5C:69I8V5R860N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N
M('5S97)N86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R(")/:^1N="!A;G;D;F1A
M<FYA;6X@96QL97(@;/9S96YO<F0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X"FUS9VED(")5;FQI;FL@
M=&AE(&-U<G)E;G0@96QE;65N="(*;7-G<W1R(")482!B;W)T(&SD;FME;B!F
M<N5N(&YU=G)A;F1E(&5L96UE;G0B"@HC.B!F<F%M97=O<FLO261E;G1I='DO
M261E;G1I='DN<&AP.C(Y-B!L:6(O2&]R9&4O261E;G1I='DN<&AP.C,P,@IM
M<V=I9"`B56YN86UE9"(*;7-G<W1R(").86UN;/9S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP
M<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T
M92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N("!#
M;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R
M9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O
M(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"B))8VME+7!R:79I
M;&EG97)A9&4@<VMR:7!T(&MA;B!I;G1E(&MO;6UA(.5T($ML:7!P('5T+TMO
M<&EE<F$O2VQI<W1R82TB"B)F=6YK=&EO;F5R;F$@878@<^1K97)H971S<VOD
M;"X@2VQI8VMA($]+(&;V<B!A='0@<V4@96X@=&5K;FES:R!B97-K<FEV;FEN
M9R`B"B)F<N5N(&UO>FEL;&$N;W)G(&]M(&AU<B!D=2!K86X@=&EL;.5T82!A
M='0@<VMR:7!T(&MO;6UE<B#E="!U<FML:7!P+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N
M<V5T(&-O;&]R(@IM<V=S='(@(E1A(&)O<G0@9N1R9R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@V(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z.3(V"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z.3,R(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C@W"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z.3(W(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z.3,S"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB
M"FUS9W-T<B`B5&EL;.1G9V5T('-T]F1S(&EN=&4B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C$Y-R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C$Y-PHC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,PIM<V=I
M9"`B57!D871E(@IM<V=S='(@(E5P<&1A=&5R82(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M57!D871E("5S(@IM<V=S='(@(E5P<&1A=&5R82`E<R(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C0X"FUS9VED(")5
M<&1A=&4@<F5S<&]N9&5N="!S=&%T=7,B"FUS9W-T<B`B57!P9&%T97)A('-T
M871U<R!PY2!S=F%R86YD92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z-S8*;7-G:60@(E5P9&%T92!U<V5R(@IM<V=S='(@(E5P<&1A
M=&5R82!A;G;D;F1A<F4B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$T-"!A9&UI
M;B]P97)M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP
M.C(S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS
M9W-T<B`B57!P9&%T97)A9&4@)R5S)RXB"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HX,PIM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS
M9W-T<B`B57!P9&%T97)I;F=S<V-R:7!T(')A9&5R870N(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$W."!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3@R"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ.3@*;7-G:60@(E5P;&]A9"(*;7-G<W1R("),861D82!U<'`B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5<&QO861E
M9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB
M"FUS9W-T<B`B3&%D9&%D92!U<'`@86QL82!K;VYF:6=U<F%T:6]N<V9I;&5R
M('1I;&P@<V5R=F5R;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L:7-T='EP95]L86YG+FIS.C(P"FUS9VED(")5<'!E<B!L871I;B!L
M971T97)S(@IM<V=S='(@(E9E<G-A;&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B57!P
M97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R(")2;VUE<G-K82!S:69F<F]R(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0Q"B,Z(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S@@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$S"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(E5R=6=U87DB
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H
M<#HT-0HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T
M<B`B06YVY&YD(&%K='5E;&PZ("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R(")!
M;G;D;F0@4U-,(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-PIM<V=I
M9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0
M('-E<G9E<BXB"FUS9W-T<B`B06YVY&YD(&]M(&YA;6XO;/9S96YO<F0@Y'(@
M86YN;W)L=6YD82!F]G(@24U34"US97)V97(N(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHR,0IM<V=I9"`B57-E<B(*;7-G<W1R(")!
M;G;D;F1A<F4B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN
M<&AP.C<R,"!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C<W-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB
M"FUS9W-T<B`B06YVY&YD87)E("5S(.1R(&EN=&4@8F5H]G)I9R!F]G(@)7,N
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S"FUS9VED(")5<V5R($%D;6EN:7-T
M<F%T:6]N(@IM<V=S='(@(D%N=N1N9&%R861M:6YI<W1R871I;VXB"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(U,"!L:6(O2&]R9&4O4')E
M9G,O54DN<&AP.C(T-0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(D%N
M=N1N9&%R:6YS=.1L;&YI;F=A<B(*"B,Z('-I9VYU<"YP:'`Z-C(*;7-G:60@
M(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(D%N=N1N9&%R<F5G:7-T<F5R
M:6YG(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I9"`B57-E<B!296=I<W1R871I
M;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92XB"FUS9W-T<B`B
M06YVY&YD87)R96=I<W1R97)I;F<@:&%R(&%V86MT:79E<F%T<RXB"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-#8Y"FUS9VED(")5<V5R(&%C8V]U;G0@
M;F]T(&9O=6YD(@IM<V=S='(@(D%N=N1N9&%R:V]N=&]T(&AI='1A9&5S(&EN
M=&4B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3,V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET
M86QY7W-M='`N<&AP.CDX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C$U,"!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3,V"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z
M.3@@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@*(SH@;&EB
M+TYE="]335,O=VEN7VAT='`N<&AP.C$U,"!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HS,PHC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<R('1E
M;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R
M;F%M92(*;7-G<W1R(")!;G;D;F1A<FYA;6XB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+U-I9VYU<"YP:'`Z,3(T(&QI8B](;W)D92]!=71H+U-I9VYU<"YP
M:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A
M;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B06YVY&YD87)N86UN("5S(&9I;FYS
M(')E9&%N+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PIM
M<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(D%N=N1N9&%R;F%M;CHB"@HC.B!T
M96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"FUS9VED(")5<V5R;F%M93H@
M(@IM<V=S='(@(D%N=N1N9&%R;F%M;CH@(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB
M"FUS9W-T<B`B06YVY&YD87)E(&D@<WES=&5M970Z(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0R"B,Z(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,SD@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$T
M"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@(E5Z8F5K:7-T86XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-C,@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,C4U"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3<P(&QI8B]6
M1E,O9FEL92YP:'`Z,C8R"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T
M(&5X:7-T+B(*;7-G<W1R(")61E,M;6%P<"!E>&ES=&5R87(@:6YT92XB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3(P"FUS9VED(")686-A=&EO
M;B(*;7-G<W1R(")396UE<W1E<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C@V-B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#<P"FUS9VED(")686QI9"!L
M;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(D=I;'1I9V$@<&QA
M='-E<B!S;VT@:&ET=&%D97,@:6YK;'5D97)A<CH@(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,S@@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HV,SD*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(D=I;'1I9VAE
M="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3DW"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(U-0HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3DW(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U"FUS9VED
M(")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R(")-:6YU=&5R
M(&9RY6X@;G4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-38@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$W-PHC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z.#8P(&QI8B](;W)D92]&;W)M+G!H<#HQ,3@Q"B,L('!H<"UF;W)M870*
M;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S
M+B(*;7-G<W1R(")6Y')D970@]G9E<G-T:6=E<B!D970@:/9G<W1A('1I;&SE
M=&YA("@E<RDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0T(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C8*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C,Q-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(X"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3D@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(R-#@*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R
M-S`@;&EB+TAO<F1E+T9O<FTN<&AP.C(S,C`@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(Y,30*(SH@;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3D*
M;7-G:60@(E9A;'5E<R(*;7-G<W1R(")6Y')D96XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,3`Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M.#8*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,3,@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(Q.3`*;7-G:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R
M(")6Y')D96X@871T(';D;&IA(&9RY6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR-#D*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(T,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@
M(E9A;G5A='4B"FUS9W-T<B`B5F%N=71A=2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,S,*;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@(E9A
M<FEA8F5L(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C0U"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#$@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")696YE>G5E;&$B"FUS9W-T
M<B`B5F5N97IU96QA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HR,3@@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR,3@*;7-G:60@
M(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@
M8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R(")697)I9FEE<FEN9R!M:7-S
M;'EC:V%D97,@+2!M961D96QA;F1E="!K86X@:&$@;6%N:7!U;&5R871S+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-S`Q"FUS9VED(")697)S:6]N(@IM<V=S
M='(@(E9E<G-I;VXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(X
M"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`B5F5R<VEO;FAA;G1E
M<FEN9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(E9E
M<G1I:V%L(&IU<W1E<FEN9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS
M9W-T<B`B5F5R=&EK86P@=71F>6QL;F%D(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM
M<V=S='(@(E9E<G1I:V%L.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")697)Y($AI9V@B"FUS9W-T<B`B5N1L
M9&EG="!H]F<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-#@*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I970@3F%M(@IM<V=S
M='(@(E9I971N86TB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-PIM<V=I
M9"`B5FEE=&YA;65S92`H5DE30TE)*2(*;7-G<W1R(")6:65T;F%M97-I<VL@
M*%9)4T-)22DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HY-C$@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.CDW,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(E9I<V$@)7,B"@HC.B!L
M:6(O0FQO8VLO:69R86UE+G!H<#HS"FUS9VED(")6:65W(&%N(&5X=&5R;F%L
M('=E8B!P86=E(@IM<V=S='(@(E9I<V$@96X@97AT97)N('=E8F)S:61A(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#(P(&QI8B](
M;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX,CD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5FEE=R!A<R`E<R(*;7-G<W1R(")6:7-A('-O;2`E<R(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-SD*;7-G:60@
M(E9I97<@979E;G0B"FUS9W-T<B`B5FES82!HY&YD96QS92(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3`Y"FUS9VED
M(")6:65W('1A<VLB"FUS9W-T<B`B5FES82!U<'!G:69T(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0V"B,Z(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR-#,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R(")*
M=6YG9G)U]F%R;F$L($)R:71T:7-K82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(T-PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B
M5FER9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B2G5N9V9R=?9A<FYA+"!!
M;65R:6MA;G-K82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$V"FUS9VED
M(")6:7-I8FEL:71Y(@IM<V=S='(@(E-I:W0B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C4R"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T
M<B`B4VEK=#HB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I
M=&%L>5]S;71P+G!H<#HX-`HC.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY
M7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*
M;7-G<W1R(")6;V1A9F]N92!)=&%L:65N('9I82!33510(@H*(SH@9G)A;65W
M;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE
M+G!H<#HS-@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO
M8FEL92YP:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T<B`B5D%23B(*"B,Z(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@
M(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*
M;7-G<W1R(")605).24Y'(2$A(%)!1$5202!32U))4%1%5"!-04Y514Q,5"!&
M4L5.("5S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,3,S(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G:60@(E=)
M3B!V:6$@2%144"(*;7-G<W1R(")724X@=FEA($A45%`B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$W(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3`*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(T-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3<*;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(E=A;&QI<R!O
M8V@@1G5T=6YA(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC
M871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]H=&UL+G!H<#HR-S(*(SH@;&EB+TAO<F1E+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]H=&UL+G!H<#HQ,C<@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C@S"FUS9VED(")787)N:6YG(@IM<V=S='(@(E9A<FYI;F<B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")7
M92(*;7-G<W1R(")/;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R(")6Y&1E<G!R
M;V=N;W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#$V"FUS
M9VED(")796%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS9W-T<B`B5N1D97)D
M871A(&9RY6XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3(@;&EB
M+TAO<F1E+T9O<FTN<&AP.C@Y-@IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T
M<B`B=V5A=&AE<BYC;VTB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM
M<V=I9"`B5V5B(@IM<V=S='(@(E=E8F(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#,Y"FUS9VED(")796(@4VET92(*;7-G<W1R(")796)B<&QA
M=',B"@HC.B!C;VYF:6<O=&AE;65S+W=E8F)P;&%T<V5N+7-O8F5R+G!H<#HQ
M-@IM<V=I9"`B5V5B8G!L871S96X@+2!3;V)E<B(*;7-G<W1R(")796)B<&QA
M='-E;B`M(%-O8F5R(@H*(SH@8V]N9FEG+W1H96UE<R]W96)B<&QA='-E;BUS
M;V)E<E]N97<N<&AP.C8*;7-G:60@(E=E8F)P;&%T<V5N("T@4V]B97(@3D57
M(@IM<V=S='(@(E=E8F)P;&%T<V5N("T@4V]B97(@3EDB"@HC.B!F<F%M97=O
M<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4X(&QI8B](;W)D92]-
M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R(")696-K
M;W9I<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED
M(")796QC;VUE(@IM<V=S='(@(E;D;&MO;6UE;B(*"B,Z('1E;7!L871E<R]L
M;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@
M(E;D;&MO;6UE;B!T:6QL("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL
M92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF
M;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM<V=S='(@(E;D;&MO;6UE;BP@
M)7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y.`IM<V=I9"`B5V5S=&5R
M;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B5N1S=&5R;.1N9'-K("A)4T\M.#@U
M.2TQ*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DY"FUS9VED(")797-T
M97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B5N1S=&5R;.1N9'-K("A)4T\M
M.#@U.2TQ-2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-S@*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS
M9W-T<B`B5N1S=')A(%-A:&%R82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S
M:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B5FEL:V5N
M(&%P<&QI:V%T:6]N('-K86QL("5S('9I<V$@969T97(@:6YL;V=G;FEN9S\B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA
M="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B5FEL:V5N
M(.1R(&%V9W+D;G-N:6YG<W1E8VMN970_(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A
M8W1E<C\B"FUS9W-T<B`B5FEL:V5T(.1R('1E8VMN970@9O9R(&-I=&5R860@
M=&5X=#\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3`S,PHC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3`V-`IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S='(@(E=H
M97)E:7,@075S=')A;&EE;FMA<G1A(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C(S"FUS9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B5FEL:V$@9F%S97(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,V"FUS9VED(")7:&EC:"!P
M;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM
M<V=S='(@(E9I;&MA('!L=6=I;B!S:V%L;"!A:W1I=F5R87,@9O9R(%)I8V@@
M5&5X="!E9&ET;W)N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@(E=I9'1H(@IM<V=S='(@(D)R
M961D(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R-2!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,S$Q,0IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM
M<V=S='(@(D)R961D(&D@0U-3+75N:71S(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,V,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@
M)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G
M+6EN*3HB"FUS9W-T<B`B0G)E9&0@<.4@;65N>6X@9O9R("<E<R<@=&EL;"!V
MY&YS=&5R("AGY&QL97(@9G+E;B!NY'-T82!I;FQO9V=N:6YG(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@
M(E=I9'1H(&]F('1H92!T86)L92(*;7-G<W1R(")486)E;&QB<F5D9"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS
M9VED(")7:61T:"!U;FET(@IM<V=S='(@(D)R961D96YH970B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0IM<V=I9"`B
M5VED=&@Z(@IM<V=S='(@(D)R961D.B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HU,34*;7-G:60@(E=I:VDB"FUS9W-T<B`B5VEK:2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E=I;F0B"FUS9W-T<B`B
M5FEN9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8W"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@(E1I9&EG('9I;F0B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C@W"FUS9VED(")7:6YD('-P965D(&EN
M(&MN;W1S(@IM<V=S='(@(E9I;F1H87-T:6=H970@:2!K;F]P(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ-C,*;7-G:60@(E=I;F0Z(@IM<V=S='(@(E9I
M;F0Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,0IM<V=I
M9"`B5VEN9#H@(@IM<V=S='(@(E9I;F0Z("(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M(@IM<V=S='(@(E9I<V1O;2(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.3@*;7-G:60@(E=I<VAL:7-T
M(@IM<V=S='(@(M9N<VME;&ES=&$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C4*;7-G:60@(E=O<FLB"FUS9W-T<B`B07)B971E(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,38T"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T
M<B`B061R97-S+"!A<F)E=&4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3DR"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(E1E;&5F
M;VXL(&%R8F5T92(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$V
M.2!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR-C(*(SH@;&EB+T9I;&4O
M0U-6+G!H<#HQ.3,@;&EB+T9I;&4O0U-6+G!H<#HR.30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%
M>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(D9E;"!A;G1A;"!FY&QT
M('#E(')A9"`E9"X@1O9R=N1N=&%D92`E9"P@:&ET=&%D92`E9"XB"@HC.B!F
M<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,#`@;&EB+T9I;&4O0U-6+G!H
M<#HS,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I
M96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R(")&96P@86YT
M86P@9N1L="X@1O9R=N1N=&%D92`E9"P@:&ET=&%D92`E9"XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,30@;&EB+U9&4R]F:6QE+G!H<#HQ
M,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE
M(')E861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B1F5L('!O<VET:6]N("5D
M('9I9"!LY'-N:6YG(&%V(%9&4RUF:6PN(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(T-0IM<V=I9"`B6"U2968B"FUS9W-T<B`B6"U2968B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,R!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S($)A<VEC($-O
M;G-T<F%I;G1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3DR(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DS
M"FUS9VED(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(E@U
M,#E6,R!5=/9K860@;GEC:V5L86YVY&YD;FEN9R(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3DT(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.
M86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3DU(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED
M(")8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X,B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C8X,PIM<V=I9"`B6#4P.78S(&5X=&5N<VEO
M;G,B"FUS9W-T<B`B6#4P.58S+71I;&SD9V<B"@HC.B!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T<B`B65DB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@Y"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,S`*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-"!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#4V"FUS9VED(")965E9(@IM<V=S='(@(EE965DB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X
M,`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$Q,0IM
M<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R(")986AO;R$@;6%P(@H*(SH@9G)A
M;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-B!L:6(O2&]R
M9&4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T<B`B
MQ7)L:6<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$W(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M-3(*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-R!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(EEE;65N(@IM<V=S='(@(EEE
M;65N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.CDS-0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38V
M"FUS9VED(")997,B"FUS9W-T<B`B2F$B"@HC.B!T96UP;&%T97,O;6%I;G1E
M;F%N8V4O86=R965M96YT7V)O='1O;2YI;F,Z-@HC.B!T96UP;&%T97,O;6%I
M;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM<V=I9"`B665S+"!)($%G
M<F5E(@IM<V=S='(@(DIA+"!J86<@<V%M='EC:V5R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R
M92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C
M:"!B86-K('1O(%=94TE764<N(@IM<V=S='(@(D1U(&AA<B!A:W1I=F5R870@
M=&5X=&SD9V4N($%N=N1N9"!;/#Y=(&;V<B!A='0@Y71E<F?E('1I;&P@5UE3
M25=91RXB"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C(S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D
M('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G<W1R(")$=2!H
M87(@:6YT92!B96CV<FEG:&5T('-K87!A(&9L97(@Y&X@)60@8FQO8VLN(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ,S8W(&QI8B](;W)D92YP
M:'`Z,30Q-0IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC871E9"XB"FUS
M9W-T<B`B1'4@Y'(@:6YT92!A=71E;G1I<V5R860N(@H*(SH@9G)A;65W;W)K
M+TED96YT:71Y+TED96YT:71Y+G!H<#HS,#(*;7-G:60@(EEO=2!C86X@;F]T
M(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*
M;7-G<W1R(")$=2!K86X@:6YT92!A;G;D;F1A("=<7"<@:2!D:71T(&YA;6XB
M"@HC.B!L:6(O2&]R9&4O261E;G1I='DN<&AP.C,P.`IM<V=I9"`B66]U(&-A
M;FYO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M
M92XB"FUS9W-T<B`B1'4@:V%N(&EN=&4@86YVY&YD82`G7%PG(&D@9&ET="!N
M86UN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U-2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.3<U"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M.#4Y(&QI8B](;W)D92]&;W)M+G!H<#HQ.3<Y"FUS9VED(")9;W4@9&ED(&YO
M="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S='(@(D1U(&%N
M9V%V(&EN=&4@96X@9V]D:^1N9"!E+7!O<W1A9')E<W,N(@H*(SH@9G)A;65W
M;W)K+T1A=&$O1&%T82YP:'`Z,CDP(&QI8B](;W)D92]$871A+G!H<#HR.3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M87`@86YY(&9I
M96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD
M:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z.3@X(&QI8B](;W)D92]!=71H+G!H<#HY.#<*;7-G
M:60@(EEO=2!H879E(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`B1'4@Y'(@
M=71L;V=G860N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(V,2!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3(V-0IM<V=I9"`B(@HB66]U(&AA=F4@=&\@
M96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W
M:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@
M9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@(B(*(D1U(&WE<W1E(&%N9V4@971T
M(&=I;'1I9W0@;6]B:6QN=6UM97([(&5N8F%R="!S:69F<F]R(&]C:"!E='0@
M)RLG(&;V<F4@(@HB:6YT97)N871I;VYE;&QT('!R969I>"XB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@X(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,3DR"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*
M;7-G<W1R(")$=2!A;F=A=B!I;G1E(&5T="!G;V1KY&YT(';D<F1E+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HS-R!L:6(O2&]R9&4O
M075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@
M82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R("(B
M"B)$=2!MY7-T92!K;VYF:6=U<F5R82!E;B!$871A5'+D9',M:V]P<&QI;F<@
M9O9R(&%T="!A;G;D;F1A(')E9VES=')E<FEN9R(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z-#,V(&QI8B](;W)D92YP:'`Z-#8R"FUS9VED(")9
M;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B1'4@
M;>5S=&4@:V]N9FEG=7)E<F$@96X@5D93+6MO<'!L:6YG(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E
M<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R
M;V)L96T@<F5P;W)T+B(*;7-G<W1R(")$=2!MY7-T92!B97-K<FEV82!P<F]B
M;&5M96XL(&EN;F%N(&1U(&MA;B!R87!P;W)T97)A(&5T="!P<F]B;&5M+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*
M;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK
M('!O:6YT<R!T;R(*;7-G<W1R(")$=2!MY7-T92!A;F=E(&5N(%523"!S;VT@
M;.1N:V5N('!E:V%R('#E(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP
M:'`Z.#`*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@
M9&5L971E9"XB"FUS9W-T<B`B1'4@;>5S=&4@86YG92!E;B!S97)V97(@<V]M
M('-K86QL(')A9&5R87,N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$Y"FUS9VED
M(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*
M;7-G<W1R(")$=2!MY7-T92!A;F=E(&5T="!A;G;D;F1A<FYA;6X@<V]M('-K
M86QL(')E;G-A<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#`*;7-G:60@(EEO
M=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N(@IM<V=S='(@
M(D1U(&WE<W1E(&%N9V4@971T(&%N=N1N9&%R;F%M;B!S;VT@<VMA;&P@<F%D
M97)A<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE
M('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`B1'4@;>5S=&4@86YG92!E='0@
M86YVY&YD87)N86UN('-O;2!S:V%L;"!LY&=G87,@=&EL;"XB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ-#8*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S
M97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`B1'4@;>5S=&4@86YG92!E='0@
M86YVY&YD87)N86UN('-O;2!S:V%L;"!U<'!D871E<F%S+B(*"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S."!L:6(O2&]R9&4O
M0V]M<')E<W,O>FEP+G!H<#HQ,S@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@
M=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B1'4@;>5S=&4@86YG
M92!E;B#E=&?D<F0@<V]M('-K86QL('5T9O9R87,N(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*(SH@;&EB+TAO
M<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*;7-G:60@(EEO=2!M
M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T<B`B1'4@;>5S
M=&4@86YG92!E='0@;GET="!K871E9V]R:6YA;6XN(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*(SH@;&EB
M+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B66]U
M(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*;7-G
M<W1R(")$=2!MY7-T92!A;F=E(&5T="!I=&%L:65N<VMT('1E;&5F;VYN=6UM
M97(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-S8@;&EB+TAO<F1E
M+T%U=&@N<&AP.CDW-0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R("5S('-E
M<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T
M<B`B1&EN("5S('-E<W-I;VX@:&%R('5P<&CV<G0N(%9A<B!G;V0@;&]G9V$@
M:6X@:6=E;BXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS
M.`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(D1I;B!E+7!O
M<W1A9')E<W,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$U"FUS9VED
M(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@(D1I;B!&<N5N.B!A9')E
M<W,Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HW-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDR"FUS9VED(")9;W5R($EN9F]R;6%T:6]N
M(@IM<V=S='(@(D1I;B!I;F9O<FUA=&EO;B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.CDX,"!L:6(O2&]R9&4O075T:"YP:'`Z.3<Y"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA
M;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@
M5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A
M9V%I;BXB"FUS9W-T<B`B(@HB1&EN(&EN=&5R;F5T861R97-S(&AA<B#D;F1R
M871S(&5F=&5R(&%T="!D=2!L;V=G870@:6X@=&EL;"`G)7,G+B!&]G(@871T
M("(*(G-K>61D82!D:6<L(&WE<W1E(&1U(&QO9V=A(&EN(&EG96XN(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*;7-G:60@(EEO=7(@
M3F%M92(*;7-G<W1R(")$:71T(&YA;6XB"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]N;V%D9"YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO
M;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y
M;W4@=VES:"!T;R`B"B)U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C
M8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@(@HB875T:&5N=&EC
M871I;VX@8F%C:V5N9"XB"FUS9W-T<B`B(@HB1&EN(&%U=&5N=&ES97)I;F=S
M:V]P<&QI;F<@<W3V9&5R(&EN=&4@=7!P;.1G9R!A=B!A;G;D;F1A<F4N($]M
M(&1U('9I;&P@(@HB86YVY&YD82!(;W)D92!F]G(@871T(&%D;6EN:7-T<F5R
M82!A;G;D;F1A<F4@<^4@;>5S=&4@9'4@86YVY&YD82!E;B!A;FYA;B`B"B)A
M=71E;G1I<V5R:6YG<VMO<'!L:6YG+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO
M;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@
M=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H
M97(@<F5A<V]N+B(*;7-G<W1R("(B"B)$:71T(&%U=&5N=&ES97)I;F=S:V]P
M<&QI;F<@<W3V9&5R(&EN=&4@;&ES=&YI;F<@878@86YVY&YD87)E+"!E;&QE
M<B!SY2#D<B`B"B)F=6YK=&EO;F5N(&%V<W3D;F=D+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.CDX-"!L:6(O2&]R9&4O075T:"YP:'`Z.3@S"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O
M(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@
M<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S
M="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB1&EN('=E8F)LY'-A<F4O:6YT
M97)N971A9')E<W,@:&%R(.1N9')A=',@969T97(@871T(&1U(&QO9V=A="!I
M;B!T:6QL("<E<R<N("(*(D;V<B!A='0@<VMY9&1A(&1I9RP@;>5S=&4@9'4@
M;&]G9V$@:6X@:6=E;BXB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU-0IM
M<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T
M=7)E+B(*;7-G<W1R(")$:6X@=V5B8FSD<V%R92!S=/9D97(@:6YT92!D96X@
M:.1R(&9U;FMT:6]N96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I
M;G0N:G,Z-#(*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@
M*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R("(B"B)$:6X@=V5B8FSD<V%R92!S
M=/9D97(@:6YT92!U='-K<FEF='-F=6YK=&EO;F5N+B!4<GEC:R!#=')L+T]P
M=&EO;B`K(%`@9O9R("(*(F%T="!S:W)I=F$@=70N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(V,0IM<V=I9"`B66]U<B!C=7)R96YT('1I;64@>F]N
M93HB"FUS9W-T<B`B1&EN(&%K='5E;&QA('1I9'-Z;VXZ(@H*(SH@<V5R=FEC
M97,O<')E9G,N<&AP.C$Q-PIM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y
M(&AA<R!B965N(&-H86YG960N(@IM<V=S='(@(D1I;B!F]G)V86QD82!I9&5N
M=&ET970@:&%R(.1N9')A=',N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$V,0IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R(")$
M:6X@9O9R=F%L9&$@:61E;G1I=&5T.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR,#0*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R(")$:71T
M(&9U;&QS=.1N9&EG82!N86UN.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.C$P,#`@;&EB+TAO<F1E+T%U=&@N<&AP.CDY.0IM<V=I9"`B66]U<B!L
M;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T<B`B1&EN(&EN;&]G9VYI;F<@:&%R
M(&?E='0@=70N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S
M(&ES.B`E<R(*;7-G<W1R(")$:71T(&YY82!L]G-E;F]R9"!F]G(@)7,@Y'(Z
M("5S(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-30@;&EB
M+TAO<F1E+U!R969S+U5)+G!H<#HQ-30*;7-G:60@(EEO=7(@;W!T:6]N<R!H
M879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S
M<VEO;BXB"FUS9W-T<B`B1&EN82!I;G-TY&QL;FEN9V%R(&AA<B!U<'!D871E
M<F%T<R!F]G(@9&5N(&CD<B!S97-S:6]N96XN(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ-38@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ
M-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS
M9W-T<B`B1&EN82!I;G-TY&QL;FEN9V%R(&AA<B!U<'!D871E<F%T<RXB"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P
M87-S=V]R9"!H87,@8F5E;B!R97-E="(*;7-G<W1R(")$:71T(&SV<V5N;W)D
M(&AA<B!B;&EV:70@Y71E<G-TY&QL="(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B965N
M(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R
M(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@HB1&ET="!L]G-N;W)D(&AA
M<B#E=&5R<W3D;&QT<RP@:V]N=')O;&QE<F$@9&EN(&4M<&]S="!O8V@@;&]G
M9V$@:6X@;65D(&1I='0@(@HB;GEA(&SV<V5N;W)D+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.C<S,B!L:6(O2&]R9&4O075T:"YP:'`Z-S,S"FUS
M9VED(")9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")$:71T
M(&SV<V5N;W)D(&AA<B!GY71T('5T+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS
M9W-T<B`B1&EN82!F:N1R<G-E<G9R87(Z(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-30@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4T(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q.`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R(")*=6=O
M<VQA=FEE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G
M<W1R("):86ER92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(U-@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S
M='(@(EIA;6)I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(U-PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS
M9W-T<B`B6FEM8F%B=V4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*
M;7-G:60@(EII<'!Y(@IM<V=S='(@(EII<'!Y(@H*(SH@9G)A;65W;W)K+U1E
M>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC.B!F
M<F%M97=O<FLO5&5X="]497AT+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP
M.C$V.0HC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O:&EG:&QI9VAT<75O=&5S
M+G!H<#HQ-S0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N
M:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E9"!497AT72(*;7-G<W1R(");1_9M
M(&-I=&5R860@=&5X=%TB"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HX.0IM
M<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R(");1F5L<F%P<&]R=%TB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM
M<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R(");5FES82!C:71E
M<F%D('1E>'0@+2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O
M:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+U1E>'0O5&5X
M="]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-CD*(SH@;&EB+TAO<F1E
M+U1E>'0O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,L('!H<"UF
M;W)M870*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM
M<V=S='(@(EM6:7-A(&-I=&5R860@=&5X="`M("5S(')A9&5R72(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DS(&QI8B](;W)D92YP:'`Z,3DU
M"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F("5S72(*;7-G<W1R
M(");<F%D("5S(&%V("5S72(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,30Y-R!L:6(O2&]R9&4N<&AP.C$U-#4*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]M96YU+FEN8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(E]!9&UI;FES=')A=&EO;B(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I9"`B
M7T-,22(*;7-G<W1R(")?0TQ)(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS9VED
M(")?1&%T851R964B"FUS9W-T<B`B7T1A=&%4<N1D(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED
M(")?1&5L971E(%)O=R(*;7-G<W1R(")?4F%D97)A(')A9"(*"B,Z(&QI8B]A
M<&DN<&AP.C$S,PIM<V=I9"`B7T=R;W5P<R(*;7-G<W1R(")?1W)U<'!E<B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-S4@;&EB+TAO
M<F1E+TUE;G4N<&AP.C$W-0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`B7TAJY&QP
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R
M(")?0FEL9&EN<W3D;&QN:6YG87(N+BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O365N=2YP:'`Z,3DT(&QI8B](;W)D92]-96YU+G!H<#HQ.30*;7-G
M:60@(E],;V<@:6XB"FUS9W-T<B`B7TQO9V=A(&EN(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y,"!L:6(O2&]R9&4O365N=2YP:'`Z
M,3DP"FUS9VED(")?3&]G(&]U="(*;7-G<W1R(")?3&]G9V$@=70B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C0*;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R("+$7VYD<F$@;.1N
M:RXN+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-C0@
M;&EB+TAO<F1E+TUE;G4N<&AP.C$V-`IM<V=I9"`B7T]P=&EO;G,B"FUS9W-T
M<B`B7TEN<W3D;&QN:6YG87(B"@HC.B!L:6(O87!I+G!H<#HQ,S<*;7-G:60@
M(E]097)M:7-S:6]N<R(*;7-G<W1R(")?0F5H]G)I9VAE=&5R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V
M"FUS9VED(")?4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`B7U1A(&)O<G0@;.1N
M:RXN+B(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM<V=S
M='(@(E]3971U<"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N
M+BXB"FUS9W-T<B`B7U1A8F5L;&EN<W3D;&QN:6YG87(N+BXB"@HC.B!L:6(O
M87!I+G!H<#HQ,CD*;7-G:60@(E]5<V5R<R(*;7-G<W1R(")?06YVY&YD87)E
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C$@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HY,C4*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R(")A
M9')E<W-B;VLB"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ,S0*
M;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(F]KY&YD(&UO='1A
M9V%R92(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$S(&QI8B](
M;W)D92]+;VQA8BYP:'`Z.3$W"FUS9VED(")C86QE;F1A<B(*;7-G<W1R(")K
M86QE;F1E<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<Y(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S8U"FUS9VED(")C86QM(@IM<V=S='(@(FQU9VYT(@H*
M(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN
M;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(FMA;B!I;G1E('-K87!A
M('5T9FEL(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3,P"FUS
M9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R(")K86X@:6YT92#V<'!N
M82!I;F1A=&$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HU.3$@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C4Y.0IM<V=I9"`B
M8VQI8VL@:&5R92(*;7-G<W1R(")K;&EC:V$@:.1R(@H*(SH@;&EB+T)L;V-K
M+V)A<G1I;64N<&AP.C4V"FUS9VED(")C;&]C:R(*;7-G<W1R(")K;&]C:V$B
M"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O
M;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R(")K;VUM86YD;W)A9'-F
M96PB"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-S@*;7-G:60@
M(F-O;F9I9W5R871I;VX@97)R;W(B"FUS9W-T<B`B:V]N9FEG=7)A=&EO;G-F
M96PB"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-30*;7-G:60@
M(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B:W)I=&ES
M:R!S>7-T96UF:6P@<V%K;F%S(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G
M92YP:'`Z,3(V"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R(")D
M871A9F]R;6%T9F5L(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHS
M,`IM<V=I9"`B961I="(*;7-G<W1R("+D;F1R82(*"B,Z(&QI8B](;W)D92]-
M24U%+TUE<W-A9V4N<&AP.C$X,@IM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM
M<V=S='(@(G!O<W1E;B!K=6YD92!I;G1E(&AI='1A<R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")F86QL:6YG
M(@IM<V=S='(@(F9A;&QA;F1E(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O
M=W-E<BYP:'`Z.#4P(&QI8B](;W)D92]"<F]W<V5R+G!H<#HX.3@*;7-G:60@
M(F9I;&4B"FUS9W-T<B`B9FEL(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M.#$@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C<@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A
M="`E<R`E<R(*;7-G<W1R(")F<N5N(&1E;B`E<R`H)7,I(&ML("5S("5S(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S.0IM<V=I9"`B9W5S
M=&EN9R(*;7-G<W1R(")S=&]R;6)Y87(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,R"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR-3`*;7-G:60@(F@Z(@IM<V=S='(@(F@Z(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,S-`HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4Y"FUS9VED
M(")H:"(*;7-G<W1R(")H:"(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N
M<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B;VOD
M;F0@=N1R9&1A=&]R(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C(S"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU-C4@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,C,*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R(")G96YA<W0B"@HC.B!A
M9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW
M.0IM<V=I9"`B:6YL:6YE(@IM<V=S='(@(FEN;&EN92(*"B,Z(&QI8B](;W)D
M92]-24U%+TUE<W-A9V4N<&AP.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R
M<F]R(@IM<V=S='(@(F)E87)B971N:6YG<V9E;"(*"B,Z(&QI8B](;W)D92]-
M24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@
M97)R;W(B"FUS9W-T<B`B26YT97)N="!A<'!L:6MA=&EO;G-F96PB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B
M;&EN97-=(@IM<V=S='(@(G)A9&5R72(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC.B!F<F%M97=O<FLO
M5D937TE33R])4T]7<FET97(O;6MI<V]F<RYP:'`Z-30@;&EB+U9&4R])4T]7
M<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI
M<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@
M(F9E;&MO9"`E9"!F<N5N(&UK:7-O9G,B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S0U"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HS-S`*;7-G:60@(FUM(@IM<V=S='(@(FUM(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR.3`@;&EB+TAO<F1E
M+U!R969S+U5)+G!H<#HR.#4*(SH@<V5R=FEC97,O<&]R=&%L+VUE;G4N<&AP
M.C(Q,B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR-#$*;7-G:60@(FYA;64B"FUS9W-T
M<B`B;F%M;B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ,C$@;&EB+TAO
M<F1E+U)00RYP:'`Z,3(T"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T
M<B`B:6YT92!I;7!L96UE;G1E<F%D(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HQ,C$Y(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M,3(R,`IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*;7-G<W1R(")I;G1E
M(&EM<&QE;65N=&5R860B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDP-2!L:6(O2&]R9&4O2V]L86(N<&AP.CDP.0IM<V=I9"`B;F]T97!A9"(*
M;7-G<W1R(")A;G1E8VMN:6YG<V)L;V-K(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.`IM<V=I9"`B<&5R8V5N
M="(*;7-G<W1R(")P<F]C96YT(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G
M92YP:'`Z,3<T"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R("+E
M=&MO;7-T(&YE:V%D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(G!I
M>&QA<B(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I
M9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(G!R;W1O:V]L
M;&9E;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C<T"FUS9VED(")R:7-I;F<B"FUS9W-T<B`B<W1I9V%N9&4B"@HC.B!L:6(O
M2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-#(*;7-G:60@(G-E<G9I8V4@=6YA
M=F%I;&%B;&4B"FUS9W-T<B`B5&KD;G-T96X@Y'(@96H@=&EL;&?D;F=L:6<B
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C$P,0IM<V=I9"`B<VAO=R!D
M:69F97)E;F-E<R(*;7-G<W1R(")V:7-A('-K:6QL;F%D97(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-`HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R
M96UA:6P@=FEA($A45%`B"FUS9W-T<B`B<VUS,F5M86EL('9I82!(5%10(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,V,0HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@W"FUS9VED
M(")S<R(*;7-G<W1R(")S<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C<S"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B<W1A9&EG
M="(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B
M<WES=&5M(&5R<F]R(@IM<V=S='(@(G-Y<W1E;69E;"(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3(Y(&QI8B](;W)D92]+;VQA8BYP:'`Z.3,S
M"FUS9VED(")T87-K(&QI<W0B"FUS9W-T<B`B=7!P9VEF='-L:7-T82(*"B,Z
M(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$V-@IM<V=I9"`B=&5M<&]R
M87)Y(&9A:6QU<F4B"FUS9W-T<B`B=&EL;&;D;&QI9W0@9F5L(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,S8@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.C(V.0HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(W,`IM<V=I9"`B
M='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R(")A
M;F=E(&SV<V5N;W)D970@=';E(&?E;F=E<B!F]G(@871T(&)E:W+D9G1A(@H*
M(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP
M:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T<B`B96YA9"(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O4&%R="YP:'`Z,C<@;&EB+TAO<F1E+TU)344O4&%R
M="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS9W-T<B`B;F%M;FSV<R(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(R,PHC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")U<V5R
M('-E;&5C="(*;7-G<W1R(")A;G;D;F1A<G9A;"(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS-2!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V0V%R
M9"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,C0*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T,@IM
M<V=I9"`B=SHB"FUS9W-T<B`B=SHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B=V5A=&AE
M<BYC;VTB"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]T<E]44BYP;P``
M````````````````````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`W,C`R-S0@,3`U,34T,S,W-#,@,#$W-38T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````",@5'5R:VES:"!T<F%N<VQA=&EO
M;G,@9F]R($AO<F1E('!A8VMA9V4*(R!(;W)D92!P86ME=&D@:>=I;B!4_')K
MYV4@QV5V:7)I;&5R+@HC($-O<'ER:6=H="`H0RD@,C`P-2!(;W)D92!0<F]J
M96-T"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE
M(&QI8V5N<V4@87,@=&AE($AO<F1E('!A8VMA9V4N"B,@1V5N97)A=&5D(&)Y
M"B,@4V5R=F5T($?\;F5Y(#QS9W5N97E`;65T=2YE9'4N='(^"B,@06AM970@
MUGIT_')K(#QO86AM971`;65T=2YE9'4N='(^"B,*;7-G:60@(B(*;7-G<W1R
M("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E=C,N,"XT7&XB"B)297!O
M<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4
M+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M
M4F5V:7-I;VXM1&%T93H@,C`P-2TP-BTR."`Q-#HT."LP,S`P7&XB"B),87-T
M+51R86YS;&%T;W(Z($%U=&]M871I8V%L;'D@9V5N97)A=&5D7&XB"B),86YG
M=6%G92U496%M.B!I,3AN0&QI<W1S+FAO<F1E+F]R9UQN(@HB34E-12U697)S
M:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E
M=#U)4T\M.#@U.2TY7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X
M8FET7&XB"B)0;'5R86PM1F]R;7,Z(&YP;'5R86QS/3$[('!L=7)A;#TP.UQN
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,V.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(@*"5S(&?\;B#V
M;F-E*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,W,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B*$5R
M:?YI;2!!;F%H=&%R_2`E<RDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S<W"B,L('!H<"UF;W)M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS
M9W-T<B`B("@E<R!G_&YD92DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S<S"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(@*&)U9_QN*2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S4*;7-G:60@(B`H=&]M;W)R
M;W<I(@IM<V=S='(@(B`H>6%R_6XI(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C,W,0IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@(B`H9/QN
M*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-38@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,0HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-#`W"FUS9VED("(@870@(@IM<V=S='(@(B!D92AD82D@
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,34*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E8W1O<GDN
M(@IM<V=S='(@(D1I>FEN(&1E\&EL(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN
M<&AP.C(W,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES
M(&YO="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B)R5S)R!I<R!G9>=E<FQI
M(&)I<B!S9>=E;F5K(&1E\&EL+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]296=I<W1R>2YP:'`Z-C4Y"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]2
M96=I<W1R>2YP:'`Z,3`T,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R
M>2XB"FUS9W-T<B`B)R5S)R!(;W)D92!+87G]=&QA<OUN9&$@>6%P_6QA;F3]
M<OUL;6%M_?XN(@H*(SH@9G)A;65W;W)K+U1R964O5')E92YP:'`Z,3<Q"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E92!R96YD97)E
M<B!N;W0@9F]U;F0N(@IM<V=S='(@(B<E<R<@8?!AYR#G979I<FEC:7-I(&)U
M;'5N86UA9/TN(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O
M=7!S('-Y<W1E;2XB"FUS9W-T<B`B)R5S)R!G<G5P('-I<W1E;6EN92!E:VQE
M;F1I+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@
M<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R("(G)7,G(&EZ:6X@<VES=&5M
M:6YE(&5K;&5N9&DN(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`Z-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(EPB)7-<(B!W87,@;F]T(&-R96%T960Z("5S+B(*;7-G<W1R("(G)7,G
M>6%R873];&%M863].B`E<R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@
M86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C,W"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S
M(&%N9"`E<R(*;7-G<W1R("(E9"`E<R!V92`E<R(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z,C8X(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU
M-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A
M<W-W;W)D(&5X<&ER97,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y
M(&9O<F5C87-T(@IM<V=S='(@(B5D+6?\;FS\:R!H879A('1A:&UI;FDB"@HC
M.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B)7,@+2!":6QD:7)I;2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`T"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B5S(%!A<FUA
M:R#=>FDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX
M,S,@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,U"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B5S($M"(@H*(SH@<V5R
M=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS
M9W-T<B`B)7,@0F%K_6T@W?YL96UL97)I("T@3VYA>6QA;6$B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR
M,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B)7,@
M07EA<FQA<B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR
M-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(E
M<R!':7)I_B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE;G0B"FUS9W-T
M<B`B)7,@06YL8?YM82!+;_YU;&QA<OTB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C0R."!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y,`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8U,2!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E
M861Y(&5X:7-T<RXB"FUS9W-T<B`B)7,@>F%T96X@=F%R+B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,34Y(&QI8B]";&]C:R]M971A<BYP:'`Z,38U(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C,Y"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S0U(&QI8B]";&]C:R]M971A<BYP:'`Z,S4Q"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B5S(&1E("5S("5S(@H*(SH@<V5R
M=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0X"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N
M86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92`B"B)B
M;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A
M="!T:&ES('1I;64N(@IM<V=S='(@(B(*(D=E<N=K9?YT:7)I;&UE<VEN:2!I
M<W1E9&GP:6YI>B!I_FQE;6QE<B!IYVEN(&]N87D@:W5T=6QA<OUN_2!I_F%R
M971L97EI;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S0P"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B5S
M(&ES=&5N;65K=&5D:7(N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R("(E<R!D
M86MI:V$B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP
M:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&YO="!F;W5N9"XB"FUS
M9W-T<B`B)7,@8G5L=6YA;6%D_2XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]L:7-T+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F
M("5S(@IM<V=S='(@(B5S("T@)7,@+R`E<R`B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.CDR,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D
M9')E<W,@0F]O:R(*;7-G<W1R("(E<R!!9')E<R!$969T97)I(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R("(E<R!486MV:6TB"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-@HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R=S($YO=&5P860B"FUS9W-T<B`B)7,@3F]T($1E9G1E<FDB"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(B5S($?V<F5V($QI<W1E<VDB
M"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]M;V)I;&4N<&AP.CDV"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E
M<R(*;7-G<W1R("(E<SH@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]H=&UL+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,Z
M(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@
M=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@(@HB86YY(&QI;FMS(&EN(&ET
M(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L
M(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S8U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT
M,3`*(RP@9G5Z>GD*;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B+"!F_7)T
M_6YA;/T@)7,@)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X."!L:6(O
M0FQO8VLO;65T87(N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U
M<W1I;F<@)7,@)7,B"FUS9W-T<B`B+"!F_7)T_6YA;/T@)7,@)7,B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(L
M('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B+"!D9?!I_FEM("5S
M("T^("5S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR.30@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-#@*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C`V.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,3(X"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HW
M-#D*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(M+2!39><@+2TB"@HC
M.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO=7(@1F]R;6%T
M(@IM<V=S='(@(C$R(%-A871L:6L@6F%M86X@0FGG:6UI(@H*(SH@;&EB+T)L
M;V-K+W1I;64N<&AP.C$Y"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R
M("(R-"!386%T;&EK(%IA;6%N($)IYVEM:2(*"B,Z('1E;7!L871E<R]D871A
M+W1I;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(R-"!S86%T
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0HC+"!F=7IZ>0IM
M<V=I9"`B/%!R979I;W5S(@IM<V=S='(@(M9N8V5K:2!387EF82(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED(")!(&1A=&%B87-E(&)A8VME
M;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@(D)U(/9B
M96L@:>=I;B!V97)I=&%B86[]('-O;B!U>F%N=/US_2!G97)E:VUE:W1E9&ER
M+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38P"FUS9VED(")!
M(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R(")/;G5L;6%Z(&)I
M<B!H871A(&]L=?YT=2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.CDS-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T
M;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`BW6QE=&EY:2#^:69R96QE
M>65B:6QM96L@:>=I;B!01U`@8>?]:R!A;F%H=&%R_2!G97)E:VUE:W1E9&ER
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-C4*;7-G
M:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@
M<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*(MUM>F%L86YM_?X@:6QE=&EY
M:2!D;_!R=6QU\'5N=2!S8?!L86UA:R!IYVEN(%!'4"!AY_UK(&%N86AT87+]
M(&=E<F5K;65K=&5D:7(N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3`Y-PIM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T
M92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C
M<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(MUL971I;FEN(/YI9G)E
M<VEN:2#G]GIM96L@:>=I;B!AY_UK(%!'4"!A;F%H=&%R_2SV>F5L(%!'4"!A
M;F%H=&%R_2!V92!G9>=I_B`B"B)T_&UC96-I\&D@9V5R96MM96MT961I<BXB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#$U"FUS9VED
M("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB
M"FUS9W-T<B`B(@HBW6QE=&EY:2!I;7IA;&%M86L@:>=I;B!AY_UK(%!'4"!A
M;F%H=&%R_2SV>F5L(%!'4"!A;F%H=&%R_2!V92!G9>=I_B`B"B)T_&UC96-I
M\&D@9V5R96MM96MT961I<BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4P-0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@
M<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*(MUL971I
M;FEN(/YI9G)E<VEN:2#G]GIM96L@:>=I;B!AY_UK(%,O34E-12!A;F%H=&%R
M_2P@]GIE;"!3+TU)344@86YA:'1A<OT@=F4@(@HB9V7G:?X@=/QM8V5C:?!I
M(&=E<F5K;65K=&5D:7(N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R
M:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B"B+=;&5T:7EI(&EM
M>F%L86UA:R!IYVEN(&'G_6L@4R]-24U%(&%N86AT87+]+"#V>F5L(%,O34E-
M12!A;F%H=&%R_2!V92!G9>=I_B`B"B)T_&UC96-I\&D@9V5R96MM96MT961I
M<BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,V-`IM
M<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y
M<'0@82!M97-S86=E+B(*;7-G<W1R("+=;&5T:7EI(/YI9G)E;&5Y96)I;&UE
M:R!IYVEN(&'G_6L@4TU)344@86YA:'1A<OT@9V5R96MM96MT961I<BXB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HY"B,L(&9U
M>GIY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B0G5L=71L87(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`HC+"!F=7IZ
M>0IM<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R("+64R!(869I9B!98?!M
M=7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M,0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R("+6UB!98?!M=7(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@
M4VAO=V5R<R(*;7-G<W1R("+6UB!38?!N86LB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B04T@4VYO=R!3:&]W
M97)S(@IM<V=S='(@(M;6($AA9FEF($MA<B(*"B,Z('1E;7!L871E<R]D871A
M+W1I;64N:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R("+6UB_64R(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P
M,`IM<V=I9"`B05!)($E$(@IM<V=S='(@(D%022!)1"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T
M('1H:7,@961I=&]R(@IM<V=S='(@(D3\>F5N;&5Y:6-I(&AA:VO];F1A(@H*
M(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3(*;7-G:60@(D%B;W5T+BXN
M(@IM<V=S='(@(DAA:VO];F1A+BXN+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G
M<W1R(")%;F%L="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R(")/<G1A>6$B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C<P"FUS9VED(")!
M8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@
M(E9&4R!D:7II;FD@>6%R873]<FME;B!E<FG^:6T@96YG96QL96YD:2XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3,V"FUS9VED(")!8V-E
M<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G<W1R(")61E,@9&EZ
M:6YI('EA<F%T_6S]<FME;B!E<FG^:6T@96YG96QL96YD:2XB"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B06-C;W5N="!)
M;F9O<FUA=&EO;B(*;7-G<W1R(")":6QG:6QE<FEN:7HB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-S4*;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS
M9W-T<B`B2&5S87`@4&%R86QO<_TB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*;7-G:60@(D%C8V]U;G0@9G)O
M>F5N+B(*;7-G<W1R(")(97-A<"!$;VYD=7)U;&1U+B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS,S,*;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T
M<B`B2&5S87!L86[]>6]R(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q"FUS9VED(")!9&0B
M"FUS9W-T<B`B16ML92(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T(&%D;6EN
M+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B"FUS9W-T
M<B`B06QT($=R=7`@14ML92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z.3@@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY.0IM<V=I
M9"`B061D($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`B06QT(-UZ:6X@14ML
M92(*"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!9&0@
M2&5R93HB"FUS9W-T<B`B0G5R87EA($5K;&4Z(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HR,3@@861M:6XO9W)O=7!S+G!H<#HR,3D*;7-G:60@(D%D9"!.97<@
M1W)O=7`B"FUS9W-T<B`B665N:2!'<G5P($5K;&4B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z.#@*;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO;B(*;7-G<W1R(")9
M96YI(-UZ:6X@16ML92(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D
M8VAI;&0N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D9"!A
M(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R(")!;'0@9W)U8G4@)R5S
M)R!IYVEN92!E:VQE(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HQ-#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD
M('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@(B<E<R<@_'IE<FEN9&4@
M86QT(&EZ:6X@96ML92(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED(")!
M9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B665N:2!K=6QL86[]8_T@96ML93HB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34T
M"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S='(@(DMO;&]N($5K;&4B"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,T"FUS9VED(")!9&0@
M;F5W(&UE;6)E<G,B"FUS9W-T<B`B665N:2#\>64@96ML92(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM<V=S
M='(@(MUK:6QI($5K;&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8W
M"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO
M>FEL;&$@4VED96)A<B(*;7-G<W1R("(E<R!-96[\<_QN_"!-;WII;&QA($ME
M;F%R(,=U8G7P=2!/;&%R86L@16ML92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HW,0IM<V=I9"`B061D('1O(&%D9')E<W,@
M8F]O:SHB"FUS9W-T<B`B061R97,@9&5F=&5R:6YE(&5K;&4Z(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<X"FUS9VED(")!
M9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(D%D<F5S(&1E9G1E<FEM
M92!E:VQE(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*;7-G:60@(D%D9"!U<V5R
M(@IM<V=S='(@(DMU;&QA;OUC_2!%:VQE(@H*(SH@861M:6XO=7-E<BYP:'`Z
M-SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D(%PB)7-<
M(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L
M('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@(B<E<R<@<VES
M=&5M92!E:VQE;F1I+"!A;6$@:&5R:&%N9VD@96L@8FER(&=I<FG^(&)I;&=I
M<VD@96ML96YE;65D:3H@)7,B"@HC.B!S:6=N=7`N<&AP.C0U"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E
M;2X@66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R("(G)7,G('-I<W1E;64@
M96ML96YD:2X@WFEM9&D@9VER:?X@>6%P86)I;&ER<VEN:7HN(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G:60@(D%D9&EN9R!U
M<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B2W5L;&%N_6/](&5K;&5M92!S
M9>=I;&5M97H@:_UL_6YD_2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ-S,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T
M,0IM<V=I9"`B061D<F5S<R(*;7-G<W1R(")!9')E<R(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ,SD*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G
M<W1R(")!9')E<R!$969T97)I(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.30*;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R
M;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S='(@(EGV;F5T:6TM+41I
M\&5R(&MU;&QA;OUL87(@:>=I;B!I>FEN;&5R:2!B96QI<FQE>6EN(@H*(SH@
M861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(EGV;F5T:6TB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Q"FUS9VED(")!9',B
M"FUS9W-T<B`B061S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B069G:&%N:7-T86XB
M"FUS9W-T<B`B069G86YI<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%L8F%N
M:6$B"FUS9W-T<B`B07)N879U=&QU:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D%L
M9V5R:6$B"FUS9W-T<B`B0V5Z87EI<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*;7-G:60@(D%L:6%S(@IM<V=S='(@
M(M9T96MI(&%D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I9"`B06QI9VXB"FUS9W-T<B`B2&EZ86QA
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV
M-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R(")(:7IA;&%M86LZ(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C@W"FUS9VED(")!;&PB"FUS9W-T<B`B
M5/QM_"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C`W('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G:60@(D%L;"!!=71H96YT
M:6-A=&5D(%5S97)S(@IM<V=S='(@(E3\;2!$;_!R=6QA;FW]_B!+=6QL86[]
M8_UL87(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R;W5P<RYP
M:'`Z,C(R"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S='(@(E3\;2!'<G5P;&%R
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY,2!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O9&%T871R964N<&AP.C<U"FUS9VED(")!;&P@4&5R
M;6ES<VEO;G,B"FUS9W-T<B`B5/QM(-UZ:6YL97(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$W"FUS9VED(")!
M;&P@9F]U<B!S:61E<R(*;7-G<W1R(")4_&T@9/9R="!Y_'HB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<Q"FUS9VED(")!;&QO=R!M=6QT:7!L
M92!A9&1R97-S97,B"FUS9W-T<B`BQV]K;'4@861R97-L97)E(&EZ:6X@=F5R
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S-`IM<V=I9"`B06QL;W<@
M<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B4_UR86QA
M;FW]_B!L:7-T92!T_'+\;OP@87EA<FQA;6%Y82!I>FEN('9E<FEL<VEN(&UI
M/R(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C4P
M-`IM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`B6F%T96X@=F%R(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,PIM<V=I9"`B06QT97)N871E
M($E-4U`@3&]G:6XB"FUS9W-T<B`BUG1E:VD@24U34"!':7)I_FDB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`W"FUS9VED(")!;'1E<FYA=&4@24U3
M4"!087-S=V]R9"(*;7-G<W1R("+6=&5K:2!)35-0(%!A<F]L87/](@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y.0IM<V=I9"`B06QT97)N871E($E-
M4U`@57-E<FYA;64B"FUS9W-T<B`BUG1E:VD@24U34"!+=6QL86[]8_T@063]
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*;7-G:60@(D%L
M=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@(M9T96MI(&5L96MT<F]N
M:6L@<&]S=&$@861R97-I(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*
M;7-G:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`BUG1E:VD@=&%S
M;&%K;&%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS
M9W-T<B`BUG1E:VD@;65T:6XZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC
M86X@4V%M;V$B"FUS9W-T<B`B06UE<FEK86X@4V%M;V$B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C
M:69I960N(@IM<V=S='(@(D=EYV5R<VEZ(&1E\&5R(&)E;&ER=&EL9&DN(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-PHC+"!F=7IZ>0IM
M<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B
M8FER(&AA=&$@;VQU_G1U.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%N9&]R<F$B
M"FUS9W-T<B`B06YD;W)A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YG;VQA(@IM
M<V=S='(@(D%N9V]L82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I;&QA(@IM
M<V=S='(@(D%N9W5I;&QA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S='(@(D%N;VYI
M;2!0<F]X>2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"FUS
M9VED(")!;G-W97(B"FUS9W-T<B`B0V5V87`B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED
M(")!;G1A<F-T:6-A(@IM<V=S='(@(D%N=&%R=&EK82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*
M;7-G:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B06YT:6=U82!V
M92!"87)B=61A(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HW-"!A9&UI;B]P
M:'!S:&5L;"YP:'`Z,S4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H
M<#HU."!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HV"FUS9VED
M(")!<'!L:6-A=&EO;B(*;7-G<W1R(")5>6=U;&%M82(*"B,Z('5T:6PO:6-O
M;E]B<F]W<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*;7-G
M<W1R(")5>6=U;&%M82!,:7-T97-I(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$T,`IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@
M(E5Y9W5L86UA($AA>OUR(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHR,3@*;7-G:60@(D%P<&QY('1O($-H:6QD(%-H87)E<R(*;7-G<W1R(")!
M;'0@<&%Y;&'^_6UL87)A('5Y9W5L82(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(D]N
M87EL82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S
M,PIM<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R(")986ML8?[]:R!"
M;WEU="(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8X"FUS9VED(")!<')I;"(*;7-G<W1R(").:7-A;B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3<U"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB
M"FUS9W-T<B`B07)A<.=A("A7:6YD;W=S+3$R-38I(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z.#$*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM
M<V=S='(@(D)E;&=E;&EK($1O<WEA($)U>75T=2(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HV-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T9WHN<&AP.C@P"FUS9VED(")!<F-H:79E($YA;64B"FUS9W-T<B`B
M0F5L9V5L:6L@063](@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M<75E=65D+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U
M<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@
M)7,@/R(*;7-G<W1R("(E<R!IYVEN(&=I<FG^(&ES=&7P:6YI(&MA;&3]<FUA
M:R!I<W1E9&GP:6YZ92!E;6EN(&UI<VEN:7H_(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@7"(E<UPB
M(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS9W-T<B`B)R5S)R!V92!T_&T@86QT
M(&=R=7!L87+];OT@<VEL;65K(&ES=&EY;W(@;75S=6YU>C\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4X"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B07)J86YT:6XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4W"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(D5R;65N:7-T86XB"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-@IM<V=I9"`B07)M96YI86X@*$%2
M35-#24DM."DB"FUS9W-T<B`B17)M96YI8V4@*$%235-#24DM."DB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R="(*;7-G<W1R(")3
M86YA="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%R=6)A(@IM<V=S='(@(D%R=6)A
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C
M96YS:6]N($ES;&%N9"(*;7-G<W1R(")!<V-E;G-I;VX@061A;&%R_2(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@07)T(@IM
M<V=S='(@(D%S8VEI(%-A;F%T_2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I9FEC(%)E9VEO;B(*;7-G<W1R
M(")!<WEA+U!A<VEF:6L@0O9L9V5S:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT,C4*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D
M;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G<W1R(")"86O];2!I
M_FQE;6QE<FEN9&5N(/9N8V4@9&_P<G5L86UA('-O<G5L<W5N(&UU/R(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3,*;7-G:60@(D%S<VEG;FUE
M;G0@8V]L=6UN<R(*;7-G<W1R(")!=&%M82!+;VQO;FQA<OTB"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO
M;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B5F%R(&]L;6%Y86X@8FER(&=R
M=6)U('-I;&UE(&=I<FG^:6UI+B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP
M:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT
M('!E<FUI<W-I;VXN(@IM<V=S='(@(E9A<B!O;&UA>6%N(&)I<B!I>FYI('-I
M;&UE(&=I<FG^:6UI+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS
M9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO
M;BXB"FUS9W-T<B`B5F%R(&]L;6%Y86X@8FER(&=R=6)U(&3\>F5N;&5M92!G
M:7)I_FEM:2XB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*;7-G
M:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS
M9W-T<B`B5F%R(&]L;6%Y86X@8FER('!A>6QA_OUM_2!D_'IE;FQE;64@9VER
M:?YI;6DN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HV-"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#8*;7-G:60@
M(D%T=')I8G5T97,B"FUS9W-T<B`BUGIN:71E;&EK;&5R(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.`HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S
M="(*;7-G<W1R(")!\'5S=&]S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')A
M;&EA(@IM<V=S='(@(D%V=7-T=7)A;'EA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B
M075S=')I82(*;7-G<W1R(")!=G5S='5R>6$B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G-Q;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q
M=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H
M7V-Y<G-Q;#H@W7-T96YE;B!I;6%P('5Z871A=/US_2!B=6QU;F%M863]+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$S-0IM<V=I9"`B
M075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A
M<&%B:6QI=&5S+B(*;7-G<W1R(")!=71H7V-Y<G5S.B#=<W1E;F5N('EE=&5N
M96ML97)E('-A:&EP(&1E\&EL+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA
M<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G5S.B#=
M<W1E;F5N(&EM87`@=7IA;G3]<_T@8G5L=6YA;6%D_2XB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!2
M97%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@
M=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B(@HB
M075T:%]F='`Z(-US=&5N96X@1E10('5Z86YT_7/](&)U;'5N86UA9/TN(%!(
M4"=Y:2`M+65N86)L92UF='`@<W=I=&-H("(*(F1E\&G^=&ER9V5S:7EL92!D
M97)L97EI;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C8T
M"FUS9VED(")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B075T:%]I;6%P.B#=<W1E;F5N($E-05`@=7IA
M;G3]<_T@8G5L=6YA;6%D_2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR
M8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]K<F(U.B#=<W1E;F5N
M(&MR8C4@=7IA;G3]<_T@8G5L=6YA;6%D_2XB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@
M=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,U
M-PIM<V=I9"`B075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P
M<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-C,*;7-G:60@(D%U=&A?;&1A
M<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M(")!=71H7VQD87`Z(-US=&5N96X@3$1!4"!U>F%N=/US_2!B=6QU;F%M863]
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R
M("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B
M075T:%]I;6%P.B`E<R!K=6QL86[]8_US_2!E:VQE;F5M961I+B!3=6YU8W4Z
M("(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H
M<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U
M<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@)7,@:W5L;&%N_6/]<_T@<VEL
M:6YE;65D:2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#DY
M"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P
M9&%T92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@)7,@:W5L;&%N_6/]
M<_T@9_QN8V5L;&5N96UE9&DB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I
M<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C0V"FUS9VED
M(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B075T:%]M8V%L.B#=<W1E;F5N($U#04P@=7IA;G3]<_T@
M8G5L=6YA;6%D_2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z
M-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7W-M8F%U=&@Z(-US=&5N
M96X@<VUB875T:"!U>F%N=/US_2!B=6QU;F%M863]+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM<V=I9"`B
M075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S='(@(D1O\')U;&%M82!B8?YA
M<OUS_7H@;VQD=2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HV-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H
M96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S='(@(D1O\')U;&%M82!B8?YA
M<OUS_7H@;VQD=2X@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU
M<RYP:'`Z,3<V"FUS9VED(")!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2
M041)55,@<V5R=F5R+B(*;7-G<W1R(")$;_!R=6QA;6$@4D%$2553('-U;G5C
M=7-U('1A<F%F_6YD86X@9V5R:2#G979R:6QD:2XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C@U,0IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@
M1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(D944"!S=6YU8W5S=6YA(&1O
M\')U;&%M82!B8?YA<OUS_7H@;VQD=2XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C<P"B,L(&9U>GIY"FUS9VED(")!=71H96YT:6-A=&EO;B!T
M;R!T:&4@4TU"('-E<G9E<B!F86EL960N(@IM<V=S='(@(D944"!S=6YU8W5S
M=6YA(&1O\')U;&%M82!B8?YA<OUS_7H@;VQD=2XB"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C<U"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*
M;7-G<W1R(")+=6QL86[];/UR(&%L86YL87(Z(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I
M9"`B07IE<F)A:6IA;B(*;7-G<W1R(")!>F5R8F%Y8V%N(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T
M<B`B0D]&2"!!Y_UK;&%M86QA<OTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O=6YD
M(@IM<V=S='(@(D%R=&%L86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM
M<V=S='(@(D%R=&%L86X@4F5N9VDB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VMR8C4N<&AP.C@Q"FUS9VED(")"860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM
M<V=S='(@(DOV=/P@:V5R8F5R;W,@<&%R;VQA<_TN(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S
M97)N86UE+B(*;7-G<W1R(")+]G3\(&ME<F)E<F]S(&MU;&QA;OUC_2!A9/TN
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F%H86UA<R(*;7-G<W1R(")"86AA;6%L
M87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"86AR86EN(@IM<V=S='(@(D)A:')E
M>6XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-PIM<V=I9"`B0F%L=&EC
M("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B0F%L=/UK("A)4T\M.#@U.2TQ,RDB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H(@IM<V=S='(@(D)A;F=L
M861E_B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(D)A
M<F)A9&]S(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S(&1I<F5C=&]R>2!<
M(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")486)A;B!G<F%F:6L@9&EZ:6YI
M("<E<R<@8G5L=6YA;6%D_2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C$Y"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*;7-G:60@(D)A<V5L:6YE(@IM<V=S
M='(@(E1A8F%N(.=I>F=I<VDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QA<G5S
M(@IM<V=S='(@(D)E>6%Z(%)U<WEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F5L
M9VEU;2(*;7-G<W1R(")"96SG:6MA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HU,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L
M:7IE(@IM<V=S='(@(D)E;&EZ92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)E;FEN
M(@IM<V=S='(@(D)E;FEN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*
M;7-G<W1R(")"97)M=61A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM
M<V=S='(@(D)H=71A;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(D1O\'5M
M9_QN_"(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H
M<#HS-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P
M<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(E5Y9W5L86UA
M(%PB)7-<(B!S86AI<"!O;&1U\'4@7"(E<UPB(/9B9?!I(&)U;'5N86UA9/TN
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C@Y"FUS9VED(")"
M;&]C:R!3971T:6YG<R(*;7-G<W1R("+68F5K($%Y87)L87+](@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C:R!4>7!E
M(@IM<V=S='(@(M9B96L@5/QR_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G<W1R(")+;WEU
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F]L:79I82(*;7-G<W1R(")";VQI=GEA
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(P-0IM<V=I9"`B0F]O
M:VUA<FMS(@IM<V=S='(@(EEE<B#=;6QE<FDB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(P"FUS9VED(")";W)D
M97(B"FUS9W-T<B`B4_UN_7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*
M;7-G<W1R(")3_6[]<B!+86S];FS]\/TZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0IM<V=I9"`B0F]R9&5R
M<R(*;7-G<W1R(")3_6[]<FQA<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)O<VYI
M82!A;F0@2&5R>F5G;W9I;F$B"FUS9W-T<B`B0F]S;F$@2&5R<V5K(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED(")";W1H(@IM<V=S='(@
M(DAE<B!):VES:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O='-W86YA(@IM<V=S
M='(@(D)O='-V86YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")";W1T;VTB"FUS9W-T<B`B06QT
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R(")"
M;W5V970@061A;&%R_2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R87II;"(*;7-G
M<W1R(")"<F5Z:6QY82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")"<FET:7-H($EN
M9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B0G)I=&%N>6$@2&EN="!/
M:WEA;G5S=2!"]FQG97-I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A
M<G5S<V%L86TB"FUS9W-T<B`B0G)U;F5I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B
M0G5L9V%R:6$B"FUS9W-T<B`B0G5L9V%R:7-T86XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"FUS9VED(")"=6QL971E
M9"!,:7-T(@IM<V=S='(@(DUA9&1E(-UM;&D@3&ES=&4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q
M"FUS9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B0G5R:VEN82!&87-O(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R(")"=7)U;F1I(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0T-`IM<V=I9"`B0TU3(@IM
M<V=S='(@(D--4R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G<W1R(")#4E,B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B0U),($1I<W1R
M:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B0U),($1A\/UT_6T@3F]K=&%L87+]
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@
M(E](_&-R92#6>F5L;&EK;&5R:2XN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-C,*(RP@9G5Z>GD*;7-G:60@(D-A8VAE(&EN:70@=V%S
M(&YO="!C;VUP;&5T960N(@IM<V=S='(@(D1A\/UT_6T@;&ES=&5S:2!B96QI
M<FQE;F5M961I+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT.#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDX-PHC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,34U"FUS9VED(")#86QE;F1A<B(*;7-G
M<W1R(")486MV:6TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C0V"FUS9VED(")#86QM(@IM<V=S='(@(D1U<F=U;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S
M"FUS9VED(")#86UB;V1I82(*;7-G<W1R(")+86UB;^=Y82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HT-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C<*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(DMA;65R=6XB"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N(&YO="!R97-E
M="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI
M<W1R871O<BXB"FUS9W-T<B`B(@HB4&%R;VQA(/9Z9&5V:6YI;6QI(&]L87)A
M:R!S_6;]<FQA;F%M86UA:W1A9/UR+"!L_'1F96X@>?9N971I8VEN:7IL92!G
M]G+\_OQN+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,Q.`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W<FET92!T;R!F
M:6QE(%PB)7-<(B(*;7-G<W1R(")<(B5S7"(@9&]S>6%S_2!S:6QI;F5M961I
M+B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,@IM<V=I9"`B0V%N)W0@861M
M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,S4@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,Q.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R
M("))34%0('-U;G5C=7-U;F$@8F'P;&%N_6QA9/TZ("5S(@H*(SH@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#$S"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#86XG="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")<(B5S
M7"(@9&]S>6%S_2!S:6QI;F5M961I+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-A
M;F%D82(*;7-G<W1R(")+86YA9&$B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@
M861M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHV-0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E
M;&5T92YI;F,Z,3$@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G:60@
M(D-A;F-E;"(*;7-G<W1R("+=<'1A;"(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B
M"FUS9W-T<B`B4V]R=6X@4F%P;W)U;G4@W7!T86P@170B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")<(B5S7"(@9&]S
M>6%S_2!S:6QI;F5M961I+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HT-@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C4R"FUS9VED(")#86YN;W0@9FEN9"!A('1E;7!O
M<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(D=EYVEC:2!D:7II;B!B=6QU;F%M
M863]+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP
M:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I
M;&4G('!A<F%M971E<BXB"FUS9W-T<B`B)W1A<F=E=$9I;&4G(&1E\&G^=&ER
M9V5S:2!O;&UA9&%N(&1E=F%M(&5D:6QE;65Z+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,S$T"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO
M="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB(&1I
M>FEN:2!K86QD_7+];&%M863]+B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$
M871A5')E92YP:'`Z,3(X(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S
M<6PN<&AP.C8X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E
M+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`B2V%L9/UR_6QA;6%D_2`L
M)60@86QT('EA</T@=F%R+B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A
M5')E92]S<6PN<&AP.C8P.`IM<V=I9"`B(@HB0V%N;F]T(')E;W)D97(L(&YU
M;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T
M(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM<V=S='(@(B(*(EEE;FED96X@
M9/QZ96YL96UE9&DL('EE;FED96X@9/QZ96YL96UE(&GG:6X@<V'P;&%N86X@
M:V%Y_71L87+];B!S87G]<_T@:6QE("(*(F1E<&]L86YM_?X@;VQA;FQA<OUN
M('-A>?US_2!E_FQE_FUE;65K=&5D:7(N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@
M<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+B(*;7-G<W1R(")"
M96QI<G1I;&UI_B!N=6UA<F%Y82!I;&5T:2!Y]FYL96YD:7)I;&5M961I+B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B0V%P92!6
M97)D92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C0*;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`B0F'^;/UK(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`T
M"FUS9VED(")#87)R:65R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY,`IM<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S
M='(@(DMA=&5G;W)I;&5R('9E($5T:6ME=&QE<B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS
M9VED(")#87EM86X@27-L86YD<R(*;7-G<W1R(")#87EM86X@061A;&%R_2(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*
M;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B0V5P(%1E;&5F;VYU(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M-0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(DC\8W)E(-9Z96QL
M:6ML97)I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B2/QC<F4@
M>6%S=/UK;&%M87/].B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*
M;7-G<W1R(")(_&-R92#6>F5L;&EK;&5R:2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS9VED(")#96QL('-P86-I
M;F<Z(@IM<V=S='(@(DC\8W)E($)O_FQU:VQA<OTZ(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(W-`IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@
M(D-E<"!496QE9F]N=2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS
M9VED(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*;7-G<W1R(")+96QT:6L@*$E3
M3RTX.#4Y+3$T*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R(")/<G1A
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC
M(@IM<V=S='(@(D]R=&$@069R:6MA($-U;6AU<FEY971I(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D-E;G1R86P@175R;W!E86X@*$E3
M3RTX.#4Y+3(I(@IM<V=S='(@(D]R=&$@079R=7!A("A)4T\M.#@U.2TR*2(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-CDY"FUS9VED
M(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(D]N87D@0F5L9V5S:2!!
M>7+];G3];&%R_2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C$Q"B,L(&9U>GIY"FUS9VED(")#97)T:69I8V%T92!/=VYE<B(*;7-G
M<W1R(")/;F%Y($)E;&=E<VD@07ER_6YT_6QA<OTB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I9"`B0V5R=&EF:6-A=&4@
M4&]L:6-I97,B"FUS9W-T<B`B3VYA>2!"96QG97-I($MU<F%L;&%R_2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P.`IM<V=I9"`B0VAA9"(*;7-G<W1R("+'860B"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.CDV"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B1&7P:?YT:7(B
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*(RP@9G5Z>GD*
M;7-G:60@(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(E!A<F]L86[]
M>OT@<_UF_7)L87G];B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@IM
M<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O
M<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E
M;6%I;',N(@IM<V=S='(@(B(*(MUN<V%N;&%R_6X@<VEZ9&5N(&=E;&5N(&5L
M96MT<F]N:6L@<&]S=&%L87+](&]K=7)K96X@=F4@8V5V87!L87)K96X@(@HB
M9_9R9/QK;&5R:2!A9"!V92!A9')E<VEN:7II(&1E\&G^=&ER:6XN(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#:&%N
M9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@
M8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D;6EN
M:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*;7-G:60@(D-H87(B"FUS9W-T
M<B`B2V%R86MT97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM
M<V=S='(@(D)A\&QA;G3]>?T@1&5?;F5T;&4N+BXB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS
M9VED(")#:&EL92(*;7-G<W1R("+>:6QI(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B
M0VAI;F$B"FUS9W-T<B`BQVEN(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#`*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R
M(")"87-I=&QE_G1I<FEL;6G^(,=I;F-E("A'0C(S,3(I(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@
M*$)I9S4I(@IM<V=S='(@(D=E;&5N96MS96P@QVEN8V4@*$)I9S4I(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B0VAO
M;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B4&%R;VQA('-EYVEN(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.`IM<V=I9"`B0VAO;W-E
M(&$@=7-E<FYA;64B"FUS9W-T<B`B2W5L;&%N_6/](&%D_2!S9>=I;B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.3@*;7-G:60@(D-H;V]S92!H;W<@
M=&\@9&ES<&QA>2!D871E<SHB"FUS9W-T<B`B5&%R:6AL97)I;B!N87/];"!G
M]G-T97)I;&5C9?!I;FD@<V7G:6XZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E
M(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I(@IM<V=S='(@
M(DQI<W1E($)IYV5M(%3\<OQN_"!39>=I;B`H<_UR86QA;FW]_B!L:7-T96QE
M<B!IYVEN*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B
M"FUS9W-T<B`B0VAR:7-T;6%S($%D86QA<_TB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,N<&AP.C(Y-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#DS"B,L
M('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T
M(&9O=6YD+B(*;7-G<W1R(")3_6[]9B!T86[];?T@8G5L=6YA;6%D_3HE<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS
M9VED(")#;&5A<B(*;7-G<W1R(")496UI>FQE(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/
M9F9I8V4@=&%G<R(*;7-G<W1R(")-4T]F9FEC92!B:>=I;2!I;6QE<FEN:2!T
M96UI>FQE(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.`HC+"!F=7IZ>0IM
M<V=I9"`B0VQE87(@475E<GDB"FUS9W-T<B`B2W5L;&%N_6/]('1E;6EZ;&4B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B2W5L
M;&%N_6/]>?T@=&5M:7IL93H@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]C;&5A<BYI;F,Z,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B2W5L
M;&%N_6/]('1E;6EZ;&4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHS-`IM<V=I9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@(DMU;&QA
M;OUC_2!V97)I<VD@=&5M:7IL92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$U"B,L(&9U>GIY"FUS9VED(")#;&5A<FEN9R!,
M871E(@IM<V=S='(@(D=EYR!386%T;&5R9&4@66'P;75R(@H*(SH@=&5M<&QA
M=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-C`*;7-G:60@(D-L
M:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(D1E=F%M(&5T;65K(&GG:6X@=/UK
M;&%Y_6XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T
M<B`B2%144"!Y;VQU>6QA($-L:6-K871E;&PB"@HC.B!S97)V:6-E<R]K97EB
M;V%R9"YP:'`Z,30V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G
M:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R(")096YC97)E>6D@2V%P870B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-`IM<V=I9"`B0VQO=61S(@IM<V=S
M='(@(D)U;'5T;&%R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,38*(RP@9G5Z>GD*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G
M<W1R(")"=6QU=&QU(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3<*;7-G:60@(D-L;W5D>2(*;7-G<W1R(")"=6QU=&QU(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-`IM<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS
M9W-T<B`B0V]C;W,@061A;&%R_2(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED
M96)A<BYI;F,Z,C,*;7-G:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`B
M2V5N87(@QW5B=?!U;G4@1&%R86QT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D
M(&)O<F1E<G,B"FUS9W-T<B`B1&%R86QT_6QM_?X@4_UN_7)L87(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8W"FUS9VED(")#;VQO;6)I82(*;7-G<W1R(")+;VQO;6)I>6$B"@HC
M.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z
M,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`B4F5N:R(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C0*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-0HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`P('-E<G9I8V5S+VEM
M86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R(%!I8VME<B(*
M;7-G<W1R(")296YK(%-EYVEC:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(X-#8*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B4F5N
M:R!39>=I;6DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`B2V]L;VYL87(Z(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-@IM<V=I9"`B0V]L=6UN
M('1I=&QE<R(*;7-G<W1R(")+;VQO;B!"8?YL_6ML87+](@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(V-`IM<V=I9"`B0V]M:6-S(@IM<V=S='(@
M(DMO;6EK(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(U"FUS9VED(")#;VUM
M86YD(@IM<V=S='(@(DMO;75T(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P
M"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@(DMO;75T($MA8G7P=2(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B
M0V]M;65N="(*;7-G<W1R(")!Y_UK;&%M82(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-38V"FUS9VED(")#;VUM;VX@3F%M92(*;7-G
M<W1R(")/<G1A:R!!9/TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B0V]M;W)O<R(*
M;7-G<W1R(")#;VUO<F]S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R("+>:7)K
M970B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S$*;7-G:60@(D-O;7!U
M=&5R<R(*;7-G<W1R(")":6QG:7-A>6%R;&%R(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Y-PHC+"!F=7IZ>0IM<V=I9"`B0V]N9&ET:6]N
M(@IM<V=S='(@(DMO_G5L;&%R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-#D*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B2V_^=6QL87(B"@HC.B!A
M9&UI;B]S971U<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$
M:69F97)E;F-E<R(*;7-G<W1R(")987#];&%N9/UR;6$@1F%R:VQA<OTB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30S"FUS9VED(")#;VYF:6=U<F%T
M:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U
M=&QO;VLN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M,S4*(RP@9G5Z>GD*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A
M=&4N(@IM<V=S='(@(EEA</UL86YD_7)M86[];B!G_&YC96QL96YM97-I(&=E
M<F5K;65K=&5D:7(N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$P,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B66%P
M_6QA;F3]<CHE<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z-3$*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B4&%R86QO
M>?T@1&_P<G5L82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-34@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O(@IM<V=S='(@
M(DMO;F=O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A
M=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R(")$96UO:W)A=&EK($MO;F=O
M($-U;6AU<FEY971I(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960N(@IM<V=S='(@
M(D)A\&QA;G3](&)A_F%R_7/]>B!O;&1U+B(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I
M;&5D.B`B"FUS9W-T<B`B0F'P;&%N=/T@8F'^87+]<_UZ(&]L9'4Z(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDP"FUS9VED(")#;VYN
M96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S
M='(@(D'G_6L@86YA:'1A<B!S=6YU8W5S=6YA(&)A\&QA;G3](')E9&1E9&EL
M9&DN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDR"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(D'G
M_6L@86YA:'1A<B!S=6YU8W5S=6YA(&)A\&QA;G3](')E9&1E9&EL9&DN(%-E
M8F5B.B`E<R`H)7,I(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX
M-#4*;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM
M<V=S='(@(D944"!S=6YU8W5N82!B8?!L86YT_2!B8?YA<OUS_7H@;VQD=2XB
M"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`Q-`IM<V=I9"`B0V]N=&%C
M=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C4S"FUS9VED(")#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL
M>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`BW6QE=&G^
M:6T@;F]K=&%L87+](&)A_F%R_7EL82!A9')E<R!D969T97)I;FEZ92!E:VQE
M;F1I+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-38@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<X"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O9B!<(B5S7"(B"FUS9W-T
M<B`BW>=E<FEK.B`G)7,G(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z,CD@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S"FUS9VED(")#
M;VYT:6YU92(*;7-G<W1R(")$979A;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O
M;VL@27-L86YD<R(*;7-G<W1R(")#;V]K($%D86QA<OTB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R("+'97)E
M>B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR,0IM<V=I9"`B0V]P>2(*;7-G<W1R(")+;W!Y86QA(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C@*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R(")"8?!L86YT
M_2!B8?YA<OUS_7H@;VQD=3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G
M<W1R(")39>=I;6D@2V]P>6%L82(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B2V]S=&$@4FEK
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B
M0V]T92!D)TEV;VER92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.CDW-@IM<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N
M(@IM<V=S='(@(MUL971I(%!'4"!I;&4@_FEF<F5L96YE;65D:2XB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#4S"FUS9VED(")#;W5L
M9"!N;W0@4$=0('-I9VX@;65S<V%G92XB"FUS9W-T<B`BW6QE=&D@4$=0(&EL
M92!I;7IA;&%N86UA9/TN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M
M97-S86=E+B(*;7-G<W1R("+=;&5T:2!3+TU)344@:6QE('-I9G)E;&5N96UE
M9&DN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT-C<*
M;7-G:60@(D-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+B(*;7-G<W1R
M("+=;&5T:2!3+TU)344@:6QE(&EM>F%L86YA;6%D_2XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$X-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S(@IM<V=S
M='(@(MUL971I_FEM(&YO:W1A<_T@96ML96YE;65D:2X@)7,B"@HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z.38@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HQ,C$*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$
M05`@<V5R=F5R+B(*;7-G<W1R("),1$%0('-U;G5C=7-U;F$@8F'P;&%N_6QA
M;6%D_2XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#4W"B,L(&9U>GIY
M"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E<B(*;7-G<W1R
M("),1$%0('-U;G5C=7-U;F$@8F'P;&%N_6QA;6%D_2XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$U-@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S
M(@IM<V=S='(@(D)A:VEY92!D96YE=&QE;F5M961I+B`E<R(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HT-#$*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO
M="!C;VYN96-T('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(E--0B!S=6YU8W5S
M=6YA(&)A\&QA;G3](&)A_F%R_7/]>BXB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z-#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G
M<W1R("(G)7,G('-U;G5C=6YA($944"!Y;VQU>6QA(&)A\&QA;OUL86UA9/TZ
M("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B1&'P_73];2!L:7-T
M97-I('EA<F%T_6QA;6%D_2X@)7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,3(U"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!01U`@
M9&%T82XB"FUS9W-T<B`B4$=0('9E<FES:6YI;B#^:69R97-I(.?V>OQL96UE
M9&DN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,C(*
M;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+B(*;7-G<W1R
M(")3+TU)344@=F5R:7-I;FEN(/YI9G)E<VD@Y_9Z_&QE;65D:2XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(T-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N
M("5S(@IM<V=S='(@(MUL971I_FEM(&YO:W1A<_T@<VEL:6YE;65D:2X@)7,B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C,U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")$8?#]=/UM(&QI<W1E<VD@
M<VEL:6YE;65D:2X@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS
M.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T
M92!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(D%Y87(@
M9_QN8V5L;&5M92!B971I\&D@)R5S)R!S:6QI;F5M961I(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.#$@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z.34S"FUS9VED(")#;W5L9"!N;W0@9&5T97)M:6YE
M('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T<B`B06S]
M8_UN_6X@96QE:W1R;VYI:R!P;W-T82!A9')E<VD@8F5L:7)L96YE;65D:2XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C(X,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@
M8F]O:RXB"FUS9W-T<B`B061R97,@9&5F=&5R:2!T86UA;65N(&=E=&ER:6QE
M;65D:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C0Y,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I
M<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(")$8?#]=/UM(&QI<W1E<VD@=&%M
M86UE;B!G971I<FEL96UE9&DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C
M:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM
M<V=S='(@(D1A\/UT_6T@;&ES=&5L97)I;FEN(&QI<W1E<VD@=&%M86UE;B!G
M971I<FQE;65D:2XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.`HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP
M.C@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A
M9"!S=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@(E-T<F%T96II("<E<R<@>?QK
M;&5N96UE9&DN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y
M+V1I<F5C="YP:'`Z,S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(FUK9&ER("<E<R<@8F'^
M87+]<_UZ(&]L9'4N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-S$Y"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O
M;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R(")!;F%H=&%R('-U;G5C=7-U;F1A
M;B!AY_UK(&%N86AT87(@961I;FEL96UE9&DN(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C$S.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R("(G)7,G('EA>OUL
M;6%K(&GG:6X@8>?];&%M863]+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B)7,@8>?];&%M863]+B(*
M"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-#$X
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N($UA:6YT96YA
M;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(DUA:6YT96YA;F-E7U1A<VL@
M8FER:6UI("5S(&'G_6QA;6%D_2XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I
M<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(B<E<R<@9&EZ:6YI(&'G_6QA;6%D
M_2XB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$Q(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(S-R!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z-#<X"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HU,38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Q,@HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C4V(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV.3D*(RP@9G5Z>GD*;7-G:60@(D-O
M=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(DQ$05`@
M<W5N=6-U<W4@87)A;F%M863]+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+T]B
M:F5C="YP:'`Z,C,X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R
M96%D("5S+B(*;7-G<W1R("(E<R!O:W5N86UA9/TN(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD(&YO="!R97-E
M="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O
M<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@
M86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE
M960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B+=<W1E;F5N(&MU;&QA
M;F/](&GG:6X@<&%R;VQA('/]9OUR;&%N86UA9/TN($)A>OT@>6%D82!T_&T@
M87ER_6YT_6QA<B!D;_!R=2`B"B)D9?!I;"X@665N:61E;B!D96YE>6EN('EA
M9&$@9&%H82!F87IL82!Y87)D_6T@:>=I;B!S:7-T96T@>?9N971I;FEZ;&4@
M(@HB9_9R_/[\;BXB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS,#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S0P"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,W-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS.#,*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S@Y"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(D%#
M3"!E<FG^:6QE;65D:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R(")!9')E
M<R!D969T97)I;F4@97)I_FEL96UE9&DN("5S(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<R(*;7-G<W1R(")$8?#]=/UM(&QI<W1E<VEN92!E<FG^:6QE;65D:2X@
M)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE
M=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R(")$8?#]=/UM(&QI
M<W1E;&5R:6YE(&5R:?YI;&5M961I+B`E<R(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE
M=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@(E-U;G5C=6YU;B!Y
M971E;F5K;&5R:6YE(&5R:?YI;&5M961I+B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-30*;7-G:60@(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B66%P_6QA;F3]<FUA(&=E<FD@9/9N9/QR_&QE;65D
M:2XN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R(")R
M;61I<B`E<R#G86S]_G3]<OUL86UA9/TN(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A
M=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B)7,@>6%P_6QA;F3]<FUA
M(&MA>61E9&EL96UE9&DN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y"FUS9VED(")#;W5L9"!N;W0@
M<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@(EEE9&5K(&)I
M<B!Y87#];&%N9/UR;6$@:V%Y9&5D:6QE;65D:2XB"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R(")9961E
M:R!B:7(@>6%P_6QA;F3]<FUA(&MA>61E9&EL96UE9&DZ("5S(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.34*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O
M.B!<(B5S7"(N(@IM<V=S='(@(D%Y87(@9_QN8V5L;&5M92!B971I\&D@:V%Y
M9&5D:6QE;65D:3H@)R5S)RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C8T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('1H92!B
M86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R(")9961E:R!Y
M87#];&%N9/UR;6$@9&]S>6%S_2`E<R!K87ED961I;&5M961I+B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@
M66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@(@HB;W!T:6]N<R!T;R!S
M879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@
M8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B(@HB66%P_6QA;F3]<FUA(&1O
M<WEA<_T@)7,@:V%Y9&5D:6QE;65D:2X@0G4@9'5R=6UD82P@:V]D=2!T96MR
M87(@)7,@:>=I;F4@(@HB:V%Y9&5T;65K('EA9&$@=&%K:7`@961E;B!K;V1U
M(&5L(&EL92`E<R!IYVEN92!K;W!Y86QA;6%K+"!S9>=E;F5K;&5R:6YI("(*
M(FMU;&QA;F%B:6QI<G-I;FEZ+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z,30S"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0
M('-E<G9E<BXB"FUS9W-T<B`B3$1!4"!S=6YU8W5S=2!A<F%N86UA9/TN(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB"FUS9W-T<B`B0F'P(.?V
M>OQL96UE9&DZ("<E<R<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R("+=;&5T:?YI;2!N
M;VMT87/](&?\;F-E;&QE;F5M961I+B`E<R(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S
M(@IM<V=S='(@(D1A\/UT_6T@;&ES=&5S:2!G_&YC96QL96YE;65D:2X@)7,B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O
M<B!<(B5S7"(Z("5S(@IM<V=S='(@(B<E<R<@:>=I;B!Y87#];&%N9/UR;6$@
M>6%Z_6QA;6%D_3H@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8V
M"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA
M:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R("(B"B)-;WII
M;&QA(&ME;F%R(.=U8G7P=2!B=6QU;F%M863]+B!+96YA<B#G=6)U\'5N=6X@
M8>?]:R!O;&1U\'5N9&%N(&5M:6X@;VQU;BXB"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O
M;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G
M<W1R("(G)7,G(&1I>FEN:2!IYVEN("<E<R<@:W5L;&%N_6/]<_T@=&%K:7`@
M961E;B!H86ML87+]('9E<F5M961I.B`E<R(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T,3D*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R(")3
M87G];&W]_B!M971I;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-38Y"FUS9VED(")#;W5N=')Y(@IM<V=S='(@(MQL:V4B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C<S"FUS9VED(")#;W5R<V5S(@IM
M<V=S='(@(D1E<G-L97(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G
M<W1R(")987)A="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G
M<W1R(")"8?!L86YT_2!Y87)A="(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N
M=&ET>7-E;&5C="YI;F,Z.30*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS
M9W-T<B`B665N:2!987)A="(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.CDR"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS
M9W-T<B`B06QT(&1I>FEN('EA<F%T(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HR-#`*;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS
M9W-T<B`B66%R873]8_T@W7II;FQE<FDB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,C,P"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T
M<B`B2W)E9&D@:V%R="!N=6UA<F%S_2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")#
M<F]A=&EA(@IM<V=S='(@(DC]<G9A=&ES=&%N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I
M9"`B0W5B82(*;7-G<W1R(")+_&)A(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C(V"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@
M(MYU($%N9&%K:2!%=G)E(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C0X"B,L
M(&9U>GIY"FUS9VED(")#=7)R96YT(%-E<W-I;VYS(@IM<V=S='(@(EEA<F%T
M_6/](-UZ:6YL97)I(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L
M;V-K+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T<B`B
MWG4@06YD86MI(%IA;6%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4T"FUS9VED(")#=7)R96YT(%523"!I
M<R(*;7-G<W1R("+>=2!A;F1A:VD@55),(@H*(SH@861M:6XO<V5S<VEO;G,N
M<&AP.C,S"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(%5S97)S(@IM<V=S='(@
M(MYU($%N9&%K:2!%=G)E(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0IM
M<V=I9"`B0W5R<F5N="!796%T:&5R(@IM<V=S='(@(MYU($%N9&%K:2!(879A
M($1U<G5M=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-S4*
M;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`BWG4@06YD86MI
M(-YA<G1L87(Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R(")9_'+\
M<FS\:W1E:VD@<VET:6PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`X
M"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@
M=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B)7,@92!G:7)I_G1E(.=A;/W^
M86-A:R!G]G)E=FQE<FD@:VG^:7-E;&QE_G1I<FEN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED
M(")#=70B"FUS9W-T<B`B2V5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G
M<W1R("+>9>=I;&D@;VQA;FQA<OT@:V5S(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C8V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B
M0WEP<G5S(@IM<V=S='(@(DO]8G+]<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@R"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R(")+:7)I
M;"`H2T])."U2*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED
M(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R(")+:7)I;"`H5VEN
M9&]W<RTQ,C4Q*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@T"FUS9VED
M(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"FUS9W-T<B`B2VER:6PO
M56MR87EN82`H2T])."U5*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H(%)E
M<'5B;&EC(@IM<V=S='(@(L=E:R!#=6UH=7)I>65T:2(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3$@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(D='(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,0IM<V=I9"`B(@HB1%-.("AS964@:'1T
M<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD
M8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I
M;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G
M<W1R(")'_&YL_&LB"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C4*;7-G:60@
M(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B5F5R:2!!\&%C_2!487)A>?UC
M_7/](@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W.0IM<V=I9"`B
M1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C,Y.0IM<V=I9"`B1&%T92(*;7-G<W1R(")487)I:"(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED(")$871E
M(%)E8V5I=F5D(@IM<V=S='(@(D=E;&G^(%1A<FEH:2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(X,#<*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM
M<V=S='(@(E1A<FEH(%-EYVEM:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR.3(@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,R,@IM
M<V=I9"`B1&%Y(@IM<V=S='(@(D?\;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@IM<V=I9"`B1&5?;&5T
M92!#;VQU;6XB"FUS9W-T<B`B2U]O;&]N=2!3:6PB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@IM<V=I9"`B1&5C96UB97(B
M"FUS9W-T<B`B07)A;/UK(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I9"`B1&5C:6UA;"!N=6UB
M97)S(@IM<V=S='(@(D]N9&%L_6L@<V%Y_6QA<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C`*;7-G:60@(D1E8W)E87-E
M($EN9&5N="(*;7-G<W1R(")':7)I;G1I>6D@07IA;'0B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$X-R!L:6(O<')E9G,N<&AP.C$Q-PIM
M<V=I9"`B1&5F875L="(*;7-G<W1R("+6;B!T86[];6S](@H*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-S<*;7-G:60@(D1E
M9F%U;'0@0V]L;W(B"FUS9W-T<B`BUFX@5&%N_6UL_2!296YK(@H*(SH@9G)A
M;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HY,0IM<V=I9"`B1&5F875L
M="!)9&5N=&ET>2(*;7-G<W1R("+6;B!486[];6S]($MI;6QI:R(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L
M="!3:&5L;"(*;7-G<W1R("+6;B!T86[];6S](@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,S"FUS9VED(")$969I;FET:6]N<R(*;7-G<W1R(")486[]
M;6QA<B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HS,C8*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HT,C(@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,SD*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C<P"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3,@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,SD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#(*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHY.`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V1E;&5T92YI;F,Z,3`@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,S$*;7-G:60@(D1E;&5T92(*;7-G<W1R(")3:6PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S(*(RP@9G5Z
M>GD*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S='(@(DC\8W)E(%-I;"(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z,3DY(&%D;6EN+V=R;W5P<RYP:'`Z,C(W"FUS
M9VED(")$96QE=&4@1W)O=7`B"FUS9W-T<B`B1W)U<"!3:6PB"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#D*(RP@9G5Z>GD*;7-G:60@(D1E
M;&5T92!,;V<B"FUS9W-T<B`B4V%T_7+]('-I;"(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z-S<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HQ,#$*;7-G:60@(D1E;&5T92!097)M:7-S:6]N(@IM<V=S='(@(MUZ
M:6X@4VEL(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T
M<B`BW6QE=&EL97)I('-I;"!V92!T96UI>FQE(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L
M971E(&-E;&PB"FUS9W-T<B`B2/QC<F4@4VEL(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L
M971E(&-O;'5M;B(*;7-G<W1R(")+;VQO;B!3:6PB"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T
M92!T96UP;&%T92(*;7-G<W1R(")687)O;&%N(/9T96MI('1A<VQA\/T@<VEL
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C$*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@
M7"(E<UPB(@IM<V=S='(@(B<E<R<@:>=I;B!I>FEN;&5R:2!S:6PB"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R-`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@
M86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(B<E<R<@:>=I;B!I
M>FEN;&5R('9E(&%L="!I>FEN;&5R('-I;&EN<VEN(&UI/R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*;7-G
M:60@(D1E;&5T92!R;W<B"FUS9W-T<B`B4V%T_7+]('-I;"(*"B,Z('1E;7!L
M871E<R]P<F5F<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E;&5T
M92!S96QE8W1E9"!I9&5N=&ET>2(*;7-G<W1R(")39>=I;&UI_B!K:6UL:?!I
M('-I;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(&-O;'5M
M;B(*;7-G<W1R("+>=2!A;F1A:VD@:V]L;VYU('-I;"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,PIM<V=I
M9"`B1&5L971E('1H92!C=7)R96YT(')O=R(*;7-G<W1R("+>=2!A;F1A:VD@
M<V%T_7+]('-I;"(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,V"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('-E='5P('5P9W)A
M9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B2W5R=6QU;2!G_&YC96QL96UE
M(&)E=&GP:2`G)7,G('-I;&EN9&DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C,*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.34*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(Q"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PIM<V=I9"`B
M1&5L:79E<GD@=&EM92(*;7-G<W1R(")497-L:6T@>F%M86[](@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R(")$86YI;6%R:V$B"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I
M8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`B4V]R=6YU(%1A;OUM;&%Y_6XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,S@@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I
M<'1I;VXB"FUS9W-T<B`B0>?]:VQA;6$B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C$Y-0IM<V=I9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D92=S
M(&QO9V9I;&4I.B(*;7-G<W1R(")!>7+];G3];&%R("A!>6[]('IA;6%N9&$@
M2&]R9&4G=6X@9_QN;/QK(&1O<WEA<_UN_6X@:>=I;F1E*3HB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y.0IM<V=I9"`B1&5T86EL<R!H879E
M(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B
M07ER_6YT_6QA<B!Y]FYE=&EC:2!IYVEN(&?\;FS\:R!O;&%R86L@:V%Y9&5D
M:6QD:2XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C$Y"FUS9VED
M(")$979E;&]P;65N="(*;7-G<W1R(")'96QI_FEM(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,3<*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R(").96T@
M36EK=&%R_2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDT"FUS9VED(")$
M97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(E-O;B!S86%T=&5K
M:2!N96T@;6EK=&%R_3H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(R-PIM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B3F5M(&UI:W1A
M<OTZ("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT(@IM<V=S='(@
M(E-O;&1A;B!S8?!A('GV;FS\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT('1O
M(&QE9G0B"FUS9W-T<B`B4V'P9&%N('-O;&$@>?9N;/PB"@HC.B!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(D1I
M>FEN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V-@IM<V=I9"`B1&ES
M<&QA>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R("(R-"!S86%T;&EK('IA;6%N
M(&W](&?V<W1E<FEL<VEN/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M-PIM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(D?V<OQN=/QL96UE
M(%-EYV5N96ML97)I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.CDV"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T
M(@IM<V=S='(@(DAA=F$@=&%H;6EN:6YI(&?V<OQN=/QL92`H5$%&*2(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z.#4*;7-G:60@(D1I<W!L87D@9F]R96-A
M<W0@*%1!1BDB"FUS9W-T<B`B2&%V82!T86AM:6YI;FD@9_9R_&YT_&QE("A4
M048I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-PIM<V=I9"`B
M1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B1_9R_&YT_&QE;64@0FGG:6UI(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C$Y,`IM<V=I9"`B1&ES
M<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(D3\>F5N($)I;&1I<FEM
M:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(D-I8G5T
M:2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R"FUS9VED
M(")$;R!N;W0@9&5L971E(@IM<V=S='(@(E-I;&UE>6EN(@H*(SH@<V5R=FEC
M97,O;6%I;G1E;F%N8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@
M86-C97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R(")M86EN=&5N86YC92YP
M:'`@9&]S>6%S_6YA(&1O\')U9&%N(&5R:?YM97EI;BXB"@HC.B!T96UP;&%T
M97,O9&%T82]T<W9I;F9O+FEN8SHQ,B!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHQ,@IM<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE
M(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R
M("+=;&L@<V%T_7(@86QA;B!A9&QA<OUN_2!IYV5R:7EO<B!M=3\@179E="!I
M<V4@8G4@:W5T=7EU('-EYVEN.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1O;6EN
M:6-A(@IM<V=S='(@(D1O;6EN:6LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")$;VUI
M;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B1&]M:6YI:R!#=6UH=7)I>65T:2(*
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T
M(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0T"FUS9VED(")$;W=N
M;&]A9"(*;7-G<W1R("+=;F1I<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C@T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A
M9"`E<R(*;7-G<W1R("(E<R#=;F1I<B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-C(*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T
M:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(D]L=?YT=7)U;&%N('EA</UL
M86YD_7)M87G](%!(4"!B971I\&D@;VQA<F%K(&EN9&ER+B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#<*;7-G:60@(D1R;W`@9&]W;B!L:7-T
M(@IM<V=S='(@(D'^8?#](&'G_6S]<B!L:7-T92(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS-`IM<V=I9"`B1')U9W,B"FUS9W-T<B`BW6QAYVQA<B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B
M12U-86EL(@IM<V=S='(@(D4M4&]S=&$B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM=&\M4TU3
M(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T
M:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G
M:60@(D524B(*;7-G<W1R(")%4E(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%8W5A
M9&]R(@IM<V=S='(@(D5K=F%T;W(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C,R-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$X,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M-S(*(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I
M="(*;7-G<W1R(")$_'IE;FQE(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+U5)+G!H<#HU,"!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED
M(")%9&ET($)L;V-K(@IM<V=S='(@(D)L;VL@1/QZ96YL92(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,3DX(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"FUS9VED(")%
M9&ET($=R;W5P(@IM<V=S='(@(D=R=7`@1/QZ96YL92(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z-S8@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HQ,#`*;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R("+=
M>FEN($3\>F5N;&4B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W
M"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(MUZ:6YL97)I($3\
M>F5N;&4B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S
M='(@(B5S(-WG:6X@W7II;FQE<FD@1/QZ96YL92(*"B,Z('1E;7!L871E<R]P
M<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S
M='(@(E-EYV5N96ML97)I(&3\>F5N;&4Z(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HS-C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D5D:70@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R("(E<R!IYVEN
M(&EZ:6YL97)I(&3\>F5N;&4B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@
M9F]R("5S(@IM<V=S='(@(B5S(&GG:6X@:7II;FQE<FD@9/QZ96YL92(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0IM<V=I9"`B161U8V%T:6]N(@IM
M<V=S='(@(D7P:71I;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T(@IM<V=S
M='(@(DW]<_UR(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B16ET:&5R(&5N86)L92!I="!T:&5N.B`E
M<RP@;W(@=7-E('1H92!B87-I8R!(5$U,('9E<G-I;VXZ("5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@
M(D5L(%-A;'9A9&]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM<V=S
M='(@(M;P92XN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R(")%;2(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3@V.0IM<V=I9"`B16UA:6PB"FUS9W-T<B`B16QE
M:W1R;VYI:R!0;W-T82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-38U('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3`*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV.`IM<V=I9"`B
M16UA:6P@061D<F5S<R(*;7-G<W1R(")%;&5K=')O;FEK(%!O<W1A($%D<F5S
M:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C,*;7-G:60@(D5M
M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")%;&5K=')O;FEK
M('!O<W1A(&%S<F5S;&5R:2!E_FQE_FUE;&DN(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3DX.0IM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M871I
M;VXB"FUS9W-T<B`B3VYA>6S](&5L96MT<F]N:6L@<&]S=&$B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B
M16UA:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y.`IM<V=I9"`B16UO=&EC
M;VYS(@IM<V=S='(@(D1U>6=U('-I;6=E<FQE<FDB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*;7-G:60@(D5M
M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(D)O_B!I;&5T:2XB"@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C0S(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HT.#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C8V,B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S`U
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%
M;7!T>2!R97-U;'0N(@IM<V=S='(@(D)O_B!S;VYUYRXB"@HC.B!F<F%M97=O
M<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R
M8V@@=&5R;7,B"FUS9W-T<B`B0F_^(&%R86UA('1E<FEM;&5R:2(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#,*;7-G:60@(D5N86)L92!I;G-E<G1I
M;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM
M<V=S='(@(B(*(D9O=&_P<F%F($=A;&5R:7-I;F1E;B!M971I;FQE<FEN(&GG
M97)I<VEN92!G]G+\;G3\(&5K;&5M92!E=&MI;FQE_G1I<FEL<VEN("(*(FUI
M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3@*;7-G:60@(D5N86)L
M92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@(E-A\"!T_6L@
M:>=E<FEK(&UE;OQS_"!E=&MI;FQE_G1I<FEL<VEN(&UI/R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(U.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C@Q,0IM<V=I9"`B16YD('EE87(B"FUS9W-T<B`B0FET:?X@>?UL_2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*
M;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@(D3\>F5N;&5Y:6-I>6D@
M1V5N:?YL970B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(Q"FUS9VED
M("(B"B)%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL
M(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O
M<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS
M9W-T<B`B(@HB4&%R;VQA;OUZ_2!S_6;]<FQA;6%K(&ES=&5D:?!I;FEZ9&4@
M<V]R=6QM86L@_'IE<F4@8FER(&?\=F5N;&EK('-O<G5S=2`B"B)G:7)I;BP@
MUG(N("=%=F-I;"!H87EV86[];OUZ_6X@863](&YE9&ER/R<Z(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T<B`B
M1_9R_&YT_"!A9')E<VEN:2!B=7)A>6$@9VER:6XB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DQ"FUS9VED(")%;G1E<B!T
M:&4@;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I
M9"`B17%U871O<FEA;"!'=6EN96$B"FUS9W-T<B`B16MV871O<B!':6YE<VDB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<Q"FUS9VED(")%<FET<F5A(@IM<V=S='(@(D5R:71R92(*
M"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+W-T871U<RYP:'`Z,C<*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C0U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-0HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,V('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z
M.#(*;7-G:60@(D5R<F]R(@IM<V=S='(@(DAA=&$B"@HC.B!F<F%M97=O<FLO
M5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V,PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B17)R;W(@8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S='(@(EEA
M;OUT_2!G]FYD97)M961E(&AA=&$Z("5S+B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E
M;&5T:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HX,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S(@IM<V=S='(@(EEA
M;OUT_2!G]FYD97)M961E(&AA=&$Z("5S+B(*"B,Z(&9R86UE=V]R:R]496UP
M;&%T92]496UP;&%T92YP:'`Z-#8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@(EEA;OUT
M_2!G]FYD97)M961E(&AA=&$Z("5S+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HW-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B17)R
M;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(EEA;OUT_2!G]FYD
M97)M961E(&AA=&$Z("5S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET:"!E;6%I
M;"!M97-S86=E+B(*;7-G<W1R(")%;&5T<F]N:6L@<&]S=&$@9/9N9&5R;65D
M92!H871A+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@7"(E<UPB+B(*;7-G<W1R
M("(G)7,G('EA>F%R:V5N(&AA=&$N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B17-T
M;VYI82(*;7-G<W1R(")%<W1O;GEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B171H
M:6]P:6$B"FUS9W-T<B`B171I>6]P>6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R(")%=&YI:R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM
M<V=S='(@(D%V<G5P82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD*
M;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`B2&5R(#$U(&1A:VEK
M82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#D*;7-G:60@(D5V97)Y
M(#(@;6EN=71E<R(*;7-G<W1R(")(97(@,B!D86MI:V$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S,V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#<*
M;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B2&5R(#,P('-A;FEY
M92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S@@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,Y,`IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@
M(DAE<B`U(&1A:VEK82(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN
M=&5N86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S='(@(DAE
M<B!':7)I_G1E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,`IM<V=I
M9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(DAE<B!Y87+];2!S86%T(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-R!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S@X"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`B2&5R(&1A
M:VEK82(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(T"FUS9VED
M(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`BUG)N96L@9&7P97)L97(Z(@H*
M(SH@861M:6XO<&AP<VAE;&PN<&AP.C@Q(&%D;6EN+V-M9'-H96QL+G!H<#HU
M,"!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(W"FUS9VED(")%>&5C=71E(@IM<V=S
M='(@(L=A;/W^=/UR(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z-#<U"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B1V5N:?YL970B"@HC
M.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R"FUS9VED(")%>'!A
M;F0@4VED96)A<B(*;7-G<W1R(")+96YA<B#'=6)U\'5N=2!'96YI_FQE="(*
M"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@
M(D5X<&5C=&5D("<I)R(*;7-G<W1R("(G*2<@0F5K;&5N:7EO<B(*"B,Z(&9R
M86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-S4*;7-G:60@(D5X<&5C
M=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB"FUS9W-T<B`B
M4V%D92!K96QI;64@=F5Y82!A;/UN=/T@87)A;6$@=&5R:6UI(&)E:VQE;FEY
M;W(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G
M:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R(")'9>=E<FQI;&EK(%-O;B!4
M87)I:&DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W
M-@IM<V=I9"`B17AP;VYE;G0B"FUS9W-T<B`BW'-T(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B
M1D<@0V]L;W(B"FUS9W-T<B`BUFX@06QA;B!296YG:2(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-S<*;7-G:60@(D944"!U<&QO860@;V8@<V5T=7`B
M"FUS9W-T<B`B07EA<FQA<B!IYVEN($944"!Y_&ML96UE<VDB"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O<W%L+G!H<#HR,38*;7-G:60@(D9A:6QE9"!R
M971R:65V:6YG('!R969E<F5N8V5S+B(*;7-G<W1R(")497)C:6AL97)I;B!G
M971I;&UE<VD@8F'^87+]<_UZ+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HW-2!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.CDX
M"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS
M9W-T<B`B3$1!4"!S=6YU8W5S=6YA(&)A\&QA;G3](&)A_F%R_7/]>BXB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.3@*;7-G:60@(D9A:6QE
M9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM<V=S='(@(E--0B!S=6YU
M8W5S=6YA(&)A\&QA;G3](&)A_F%R_7/]>BXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C8X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@
M=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB(&MO;G5M=6YD
M86X@:V]P>6%L86UA(&)A_F%R_7/]>BXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C8Y,0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@
M8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(EPB)7-<(B!K;VYU;75N82!K;W!Y
M86QA;6$@8F'^87+]<_UZ+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S
M;"YP:'`Z.#<*;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N
M;F5C=&EO;BXB"FUS9W-T<B`B665N:2!305-,(&)A\&QA;G3]<_T@;VQU_G1U
M<G5L86UA9/TN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3<@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,C0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R(")<(B5S
M7"(@:V]N=6UU;F$@=&'^_6UA(&)A_F%R_7/]>BXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C0V,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G<W1R(")<(B5S7"(@:V]N
M=6UU;F$@=&'^_6UA(&)A_F%R_7/]>BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R(")5
M>6=U;B!(879A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA;F0@27-L86YD
M<R`H36%L=FEN87,I(@IM<V=S='(@(D9A;&ML86YD($%D86QA<OT@*$UA;'9I
M;F$I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R
M(")&87)O92!!9&%L87+](@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(S
M.`IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@(D]N=6QM87H@2&%T83HB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W
M"FUS9VED(")&87@B"FUS9W-T<B`B1F%K<R(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS-#D*(RP@9G5Z>GD*;7-G:60@(D9A>&5S(@IM<V=S='(@
M(D9A:W,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHV-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`BWG5B870B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(R,`IM<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R
M(")(:7-S961I;&EY;W(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C,Q"FUS9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B2&ES<V5D:6QI
M>6]R.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ.0IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B2&%F:68@4V'P86YA
M:R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P
M"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(DAA9FEF($MA<B!3
M8?!A;F'P_2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#0*;7-G
M:60@(D9I96QD(&UA=')I>"(*;7-G<W1R(")!;&%N(&UA=')I<VDB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,T"FUS9VED(")&:6=L970@0T%0
M5$-(02(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,S,X"FUS9VED(")&:6=L970@9F]N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R
M"FUS9VED(")&:6II(@IM<V=S='(@(D9I:FDB"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(D9I;&4B"FUS9W-T
M<B`B9&]S>6$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@
M(D1O<WEA(%-A>?US_3H@)7,@9&]S>6$B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E
M<R!F:6QE<R(*;7-G<W1R(")$;W-Y82!387G]<_TZ("5S(&1O<WEA(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P-PIM<V=I9"`B1FEL92!-86YA
M9V5R(@IM<V=S='(@(D1O<WEA(%GV;F5T:6-I<VDB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8S(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S`*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HX-0IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(D1O
M<WEA($%D_2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y.34*;7-G
M:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S='(@(D1O<WEA('-EYVEM:2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T.#8*;7-G:60@(D9I;&4@=7!L
M;V%D(@IM<V=S='(@(D1O<WEA('G\:VQE;64B"@HC.B!F<F%M97=O<FLO0G)O
M=W-E<B]"<F]W<V5R+G!H<#HX-3D*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@
M<W5P<&]R=&5D+B(*;7-G<W1R(")$;W-Y82!Y_&ML96UE(&1E<W1E:VQE;FUI
M>6]R+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX.0IM<V=I9"`B
M1FEL=&5R<R(*;7-G<W1R(")3_'IG9>=L97(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED
M(")&:6YL86YD(@IM<V=S='(@(D9I;FQA;F1I>6$B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,38V"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@(MUL:R!9
M87+](@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M;V]N
M+G!H<#HW-@IM<V=I9"`B1FER<W0@475A<G1E<B(*;7-G<W1R("+=;&L@QV5Y
M<F5K(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(U-@IM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@(D]R86[]('-A8FET;&4B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,Q
M"FUS9VED(")&;&EP(@IM<V=S='(@(L=E=FER(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO
M870B"FUS9W-T<B`B2V%Y86XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G(@IM<V=S='(@(E-I<R(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C,T(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HQ,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R
M("5S(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(B5S(&1I>FEN:2!Y;VLB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(R"FUS
M9VED(")&;VYT($-O;&]R(@IM<V=S='(@(EEA>OT@4F5N9VDB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`B665M
M96LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$R,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T
M('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@(D?V<OQN=/QL97)I(&1E<W1E:VQE
M;65Y96X@=&%R87G]8_UL87(@:>=I;B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S,T"FUS9VED(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R(")486AM:6X@
M*%1!1BDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-SD*;7-G
M:60@(B(*(D9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@
M9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R
M9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB
M"FUS9W-T<B`B(@HB5&%H;6EN($?\;FQE<FD@*$YO=#H@1V5R:2!D]F[\;&5C
M96ML97(@:&5M(&?\;B!H96T@9V5C92!O;&%R86L@9/9N_&QE8V5K.R`I(@HB
M8OQY_&L@8FER('-A>?T@9V5N:?X@8FER(/9B96ML92!S;VYUYVQA;F%C86MT
M_7(I(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,#(*;7-G:60@
M(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R(")087)O;&%N_7K](&W]
M('5N='1U;G5Z/R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-C(*
M;7-G:60@(D9O<FUS(@IM<V=S='(@(D9O<FUL87(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,C$*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`B1&5Y:?XB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@
M='EP92(*;7-G<W1R(")$97EI_B!T_'+\(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,X"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R(")$97EI_FQE<B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@
M,B(*;7-G<W1R(")$97EI_FQE<B`R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0U,PIM<V=I9"`B1F]R=6US(@IM<V=S='(@(D9O<G5M;&%R(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P.0IM<V=I9"`B1F]R=V%R
M9',B"FUS9W-T<B`B6?9N;&5N9&ER;65L97(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R
M(")#=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S,*;7-G:60@(D9R86UE<R(*;7-G<W1R("+'97+G979E;&5R
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E(@IM<V=S='(@(D9R86YS82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A
M;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B1G)A;G-A+"!-97)T;W!O;&ET
M86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDQ(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA(@IM<V=S='(@
M(D9R86YS_7H@1W5Y86YA<_TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B1G)E;F-H
M(%!O;'EN97-I82(*;7-G<W1R(")&<F%N<_UZ(%!O;&EN97IY87/](@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B
M"FUS9W-T<B`B1G)A;G/]>B!'_&YE>2!"]FQG97-I(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*
M;7-G<W1R(")+:6UD96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C0X(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C`*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0P-@IM<V=I9"`B1G)O;2!T:&4@
M(@IM<V=S='(@(DMI;61E;B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C0X"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(E1A
M;2!"971I;6QE;64B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L
M;V-K+VUO;VXN<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(D1O
M;'5N87DB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C$@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHV,`IM<V=I9"`B1G5L;"!.86UE(@IM
M<V=S='(@(D'G_6L@060B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")'86)O;B(*;7-G
M<W1R(")'86)O;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME
M(&EM86=E(&9R;VTB"FUS9W-T<B`B1_9R_&YT_&QE<FEN(&%L_6YA8V'P_2!G
M86QE<FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(D=A
M;&5R:3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDV(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'86UB:6$B"FUS9W-T<B`B1V%M
M8FEY82(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R
M("(E<R!987#];&%N9/UR;6%S_6[]($]L=?YT=7(B"@HC.B!T96UP;&%T97,O
M861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I9"`B1V5N97)A=&5D($-O
M9&4B"FUS9W-T<B`B3VQU_G1U<G5L86X@2V]D(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I
M9"`B1V5O<F=I82(*;7-G<W1R(")'_')C:7-T86XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS
M9VED(")'97)M86YY(@IM<V=S='(@(D%L;6%N>6$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS
M9VED(")':&%N82(*;7-G<W1R(")'86YA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B
M1VEB<F%L=&%R(@IM<V=S='(@(D-E8F5L:71A<OUK(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S4*;7-G:60@(D=I=F5N($YA;64B
M"FUS9W-T<B`B5F5R:6QE;B!!9"(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N
M:6YC.C$R"FUS9VED(")';R(*;7-G<W1R(")':70B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G<W1R(")';V5D96PB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$R
M.`HC+"!F=7IZ>0IM<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B1V]O9VQE
M($%R86UA(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B
M1V]O9VQE(%-E87)C:"(*;7-G<W1R(")';V]G;&4@07)A;6$B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,W"FUS9VED(")'
M<F%Y<V-A;&4B"FUS9W-T<B`B4VEY86@@0F5Y87HB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.CDS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM
M<V=I9"`B1W)E96-E(@IM<V=S='(@(EEU;F%N:7-T86XB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM
M<V=S='(@(EEU;F%N8V$@*$E33RTX.#4Y+3<I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.CDT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I
M9"`B1W)E96YL86YD(@IM<V=S='(@(D=R]FYL86YD(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM
M<V=I9"`B1W)E;F%D82(*;7-G<W1R(")'<F5N861A(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HQ-SD*;7-G:60@(D=R;W5P($%D;6EN:7-T<F%T:6]N(@IM<V=S
M='(@(D=R=7`@6?9N971I;6DB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`N
M<&AP.C4Y(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-CD*;7-G
M:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(D=R
M=7`@:7-I;6QE<FD@9&]L=2!O;&UA;/UD_7(B"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES
M(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B075T:%]I;6%P
M.B`E<R!K=6QL86[]8_US_2!E:VQE;F5M961I+B!3=6YU8W4Z("(*"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3@@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z-#$X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")'
M<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S(@IM<V=S='(@
M(D%U=&A?;&1A<#H@)7,@:W5L;&%N_6/]<_T@9_QN8V5L;&5N96UE9&DB"@HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S,X(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@
M)7,B"FUS9W-T<B`B075T:%]L9&%P.B`E<R!K=6QL86[]8_US_2!G_&YC96QL
M96YE;65D:2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S$T
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS9W-T<B`B1W)U<&QA<B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B1W5A9&%L
M=7`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A;2(*;7-G<W1R(")'=6%M(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R(")'=6%T96UA
M;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'
M=65R;G-E>2(*;7-G<W1R(")'=65R;G-E>2(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,C(V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M.#@*;7-G:60@(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(DMO;G5K(-UZ
M:6YL97)I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W,`IM<V=I
M9"`B1W5E<W1B;V]K(@IM<V=S='(@(DMO;G5K($1E9G1E<FDB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<U"FUS9VED(")'=6EN96$B"FUS9W-T<B`B1VEN92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M.`IM<V=I9"`B1W5I;F5A+4)I<W-A=2(*;7-G<W1R(")'=6EN92!":7-S874B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U>6%N82(*;7-G<W1R(")'=7EA;F$B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-C`*;7-G:60@(DA434PB
M"FUS9W-T<B`B2%1-3"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY
M(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+B(*;7-G
M<W1R(")(5$U,07)E82!S873]<F1A:VD@<V]N(&C\8W)E>6D@<VEL;65Y:2!R
M961D961I>6]R+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E
M9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB"FUS
M9W-T<B`B2%1-3$%R96$@YVEZ96QG961E:VD@<V]N(&MO;&]N=2!S:6QM97EI
M(')E9&1E9&EY;W(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@
M<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G
M<W1R(")(5$U,07)E82#G:7IE;&=E9&5K:2!S;VX@<V%T_7+]('-I;&UE>6D@
M<F5D9&5D:7EO<BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP
M.C$U-PIM<V=I9"`B2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(DA45%`@2VEM;&EK($1E;F5T:6UI(&)U;&%N86UA9/TN(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@P"FUS9VED(")(86ET:2(*;7-G<W1R(")(86ET:2(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!
M;&=O<FET:&TB"FUS9W-T<B`B2&%S:"!!;&=O<FET;6%S_2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE
M(@IM<V=S='(@(DAA9FEF(%-I<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.CDQ.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,R"FUS9VED(")(
M96%D97(B"FUS9W-T<B`B0F'^;/UK(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B2&5A9&5R
M<R(*;7-G<W1R(")"8?YL_6LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D
M($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R(")(96%R9"!!
M9&%S_2!V92!-8T1O;F%L9"!!9&%L87+](@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C,*(RP@9G5Z>GD*;7-G:60@(DAE879Y
M(%0M4W1O<FTB"FUS9W-T<B`B1_9K(&?\<OQL=/QL_"!F_7)T_6YA(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@(DAE8G)E=R`H25-/+3@X
M-3DM."U)*2(*;7-G<W1R("+=8G)A;FEC92`H25-/+3@X-3DM."U)*2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S0*;7-G:60@(DAE:6=H="(*;7-G<W1R(")9_&MS96ML:6LB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3<Y(&9R86UE=V]R:R](;W)D
M92](;W)D92](96QP+G!H<#HQ.#8*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP
M:'`Z,3<@=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C,*;7-G:60@(DAE;'`B
M"FUS9W-T<B`B66%R9/UM(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS
M9W-T<B`B1/QZ96YL97EI8VD@:W5L;&%R86L@>6%R9/UM(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3,W,0IM<V=I9"`B2&5L<&5R(@IM<V=S='(@
M(EEA<F3];6/](@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(
M96UI<W!H97)E(@IM<V=S='(@(EEA<OUK_')E(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z
M,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93HB
M"FUS9W-T<B`B1&]S>6%N_6X@8F'^;&%N9_UC_3H@(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DAI9V@B"FUS
M9W-T<B`B6?QK<V5K(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV
M('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHU"FUS9VED(")(
M;U]M92(*;7-G<W1R(")?06YA<V%Y9F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED
M(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R(")6871I
M:V%N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-3,U"FUS9VED
M(")(;VUE(@IM<V=S='(@(D%N87-A>69A(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$R,@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U"FUS9VED(")(;VUE($%D9')E<W,B
M"FUS9W-T<B`B178@061R97-I(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C8T"B,L(&9U>GIY"FUS9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R(")$
M:7II;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B178@5&5L969O;G4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@(DAO;F1U
M<F%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`B
M2&]N9R!+;VYG(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8U"FUS
M9VED(")(;W)D92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z-#0R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A
M9V4@)7,B"FUS9W-T<B`B(@HB2&]R9&4O2V]L86(Z($)U(&UE<V%J(&GG:6YD
M92!G9>=E<G-I>B`E<R!834P@=F5R:7-I(&EL92!K87+^_6QA_OUL9/TZ("5S
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR.3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N
M9',@=&\@;V)J96-T("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B`E<R!N97-N
M97-I(&EL92!I;&=I;&D@8FER(&EL971I(&)U;'5N86UA9/TB"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C0S-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@
M;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@)7,@=/QR_&YD92!H
M:><@8FER(&YE<VYE("5S(&UE<V%J_2!IYVEN9&4@>6]K+B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(U,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB
M(@IM<V=S='(@(DAO<F1E+TMO;&%B.B`E<R!<(B5S7"(@8F'^87+](&EL92!S
M:6QI;F1I(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR,C,*;7-G
M:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I
M<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N(@IM<V=S='(@(B(*(DAO
M<F1E+TMO;&%B.B!"_'3\;FQE;64@;6]T;W)U("=D;VUX;6PG(%!(4"!U>F%N
M=/US_6YA(&EH=&EY8><@9'5Y;6%K=&%D_7(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C
M="`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@)7,@;F5S;F5S:2!IYVEN('EE
M;FD@6$U,(&'P86/](&]L=?YT=7)U;&%M_7EO<B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,3(T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM<V=S
M='(@(DAO<F1E+TMO;&%B.B!3:6QI;F5M961I("5S(%PB)7-<(CH@)7,B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0W-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@
M240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L
M86(Z("5S('3\<OQN9&5K:2!K_7/];2!IYVEN($U)344@240@8G5L=6YA;6%D
M_2(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$Y,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N
M:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($7^;&5N
M96UE9&D@)7,@7"(E<UPB.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,3,S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B4&%Y
M;&'^_6UL87(@9?YL96YE;65D:3H@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B0FEL:6YM97EE;B!P
M87EL8?[];2!<(B5S7"(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T
M<B`B66%T87D@QVEZ9VDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS
M9W-T<B`B66%T87D@>6%S=/UK;&%M82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM
M<V=S='(@(EEA=&%Y.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T
M(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B0G5R87EA(&YA<_UL
M(&=E;&1I;FEZ/R`H3/QT9F5N(')A<&]R(&5D:6XA*2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@
M(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM
M<V=S='(@(DMAYR!A9&5T(&MO;&]N=2!B:7)L9?YT:7)M96L@:7-T:7EO<G-U
M;G5Z/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED
M(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T
M<B`B2V'G(&%L86X@*&MO;&]N*2!V87(_(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA
M;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B2V'G
M(&%D970@<V%T_7+](&)I<FQE_G1I<FUE:R!I<W1I>6]R<W5N=7H_(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,"!L:6(O0FQO8VLO;65T
M87(N<&AP.C(S,`IM<V=I9"`B2'5M:61I='DB"FUS9W-T<B`B3F5M(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U.0IM<V=I9"`B2'5M:61I
M='DZ("(*;7-G<W1R(").96TZ("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(DUI>F%HY_UL87(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B36%C87)I<W1A
M;B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W,B!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C,U"B,L('!H<"UF;W)M870*
M;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S
M='(@(DE-05`@<&]S=&$@:W5T=7-U(&]L=?YT=7)U;&%M863].B`E<R(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(Q-"!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G-Q;"YP:'`Z,CDU"B,L('!H<"UF;W)M870*;7-G:60@
M(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM<V=S='(@(DE-
M05`@<&]S=&$@:W5T=7-U('-I;&EN96UE9&DZ("5S(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<Y(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER<W%L+G!H<#HR-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL
M8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B24U!4"!P
M;W-T82!K=71U<W4@:V]T87/](&]L=?YT=7)U;&%M863].B`E<R(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,38*;7-G:60@(DE0($%D9')E<W,B
M"FUS9W-T<B`B25`@061R97-I(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I
M<&)A<VEC+G!H<#HW-PIM<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R("))4"!A9')E<VD@;65V8W5T(&1E\&EL+B`B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R
M97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("))
M4"!!9')E<VD@:7II;B!V97)I;&5N($-)1%(@8FQO\'4@:>=I;F1E(&1E\&EL
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R
M("))4"!K:6QI=&QE;64@:6AL86QI+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.0IM<V=I9"`B25]N<V5R
M="!2;W<@0F5F;W)E(@IM<V=S='(@(M9N7V-E>64@4V%T_7(@665R;&7^=&ER
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@R"FUS9VED("))8V5L86YD(@IM<V=S='(@(MUZ;&%N
M9&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<V"FUS9VED("))8V]N
M<R!/;FQY(@IM<V=S='(@(E-A9&5C92!3:6UG96QE<B(*"B,Z('5T:6PO:6-O
M;E]B<F]W<V5R+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("))8V]N<R!F
M;W(@)7,B"FUS9W-T<B`B)7,@:>=I;B!S:6UG96QE<B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-S<*;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G
M<W1R(")-971I;B!I;&4@8FER;&EK=&4@<VEM9V5L97(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3DP"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM
M<V=S='(@(DMI;6QI\&EN(&%D_3HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HU.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@
M:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@
M82!N97<@=VEN9&]W+B(*;7-G<W1R(")%\&5R(&1O\')U(&?V<OQN=/QL96YE
M;6EY;W)S82P@>65N:2!P96YC97)E9&4@8>=M86L@:>=I;B!T_6ML87G];B`E
M<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4U"FUS9VED("(B"B))
M9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L
M;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U
M<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*(D7P97(@26YT
M97)N970@17AP;&]R97(@:6QE('-I;6=E;&5R:2!G]G)E;6EY;W)S86[]>B!B
M=2!K=71U>74@<V7G97)E:R!03D<@(@HB<V%Y9&%M;/WP_6[](&MA<&%T;6%N
M_7H@9V5R96MI<BXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3<S"FUS9VED("(B"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G
M92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@
M8V%N)W0@8F4@(@HB9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T
M<B`B(@HB1_9R_&YT_&QE<FD@9_9R96UI>6]R(&9A:V%T(&)U(&UE<V%J_2!G
M]G)E8FEL:7)Y;W)S86[]>BP@>?QK;&5M96L@(@HB:7-T961I\&EN:7H@9_9R
M_&YT_"!T87)A>?UC_6[]>B!T87)A9OUN9&%N(&?V<W1E<FEL96UE;65K=&5D
M:7(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(X"FUS9VED("));6%G92!0<F5V:65W.B(*;7-G<W1R
M(")']G+\;G3\(-9N:7IL96UE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),(@IM
M<V=S='(@(D?V<OQN=/P@55),(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Q"FUS9VED("));6%G92!5
M4DPZ(@IM<V=S='(@(D?V<OQN=/P@55),.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,@IM<V=I9"`B
M26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@(E-E<F=I9&5N(&?V<OQN=/PB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T
M<B`B4V5R9VED96X@9_9R_&YT_#HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-S8Q"FUS9VED("));6%G92!U<&QO860B"FUS9W-T<B`B1_9R_&YT
M_"!Y_&ML96UE:R(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED
M("));6%G97,B"FUS9W-T<B`B1_9R_&YT_&QE<B(*"B,Z('1E;7!L871E<R]D
M871A+W1S=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z
M-PHC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4T('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T
M+"!3=&5P("5D(@IM<V=S='(@(MWG97)I($%K=&%R+"!!9/UM("5D(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(MWG97)I(&%K=&%R
M_6QA;B!A;&%N.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`BW>=E<FD@86MT
M87+];&%N(&%L86YL87(Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS9VED("));E]S97)T(%)O=R!!
M9G1E<B(*;7-G<W1R(")3;VY?<F%Y82!3873]<B!%:VQE(@H*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,U"FUS9VED("));F-O
M<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(EEA;FS]_B!E>6QE
M;2!K;V1U(&=I<FEL9&DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,S(*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M
M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(EEA;FS]_B!K=6QL86[]8_T@
M863]('9E+W9E>6$@<&%R;VQA+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C4Q"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT
M97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB
M861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S
M='(@(B(*(EEA;FS]_B!K=6QL86[]8_T@863]('9E>6$@]G1E:VD@861R97,N
M665N:61E;B!D96YE>6EN('9E>6$@9&%H82!F87IL82!Y87)D_6T@(@HB:>=I
M;B!Y]FYE=&EC:6YI>FQE(&?V<OS^_&XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD
M96YT(@IM<V=S='(@(D=I<FEN=&EY:2!!<G1T_7(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*
M;7-G:60@(DEN9&EA(@IM<V=S='(@(DAI;F1I<W1A;B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,C4T('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3,T"FUS9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@(D)I
M<F5Y<V5L($MU;&QA;OUC_6QA<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B26YD
M;VYE<VEA(@IM<V=S='(@(D5N9&]N97IY82(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(DEN9F\B"FUS9W-T
M<B`B0FEL9VDB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4W"FUS
M9VED("));F9O<FUA=&EO;B(*;7-G<W1R(")":6QG:2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,S`*(RP@9G5Z>GD*;7-G:60@(DEN9F]R
M;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(DAIYV)I<B!S
M9>=E;F5K(&UE=F-U="!D9?!I;"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@(DEN<V5R="!#
M7V]L=6UN($%F=&5R(@IM<V=S='(@(E-O;G)A>6$@2V]?;&]N($5K;&4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C`*;7-G:60@(DEN<V5R="!);6%G92(*;7-G<W1R(")']G+\;G3\
M(%EE<FQE_G1I<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R("+':7IE
M;&=E(%EE<FQE_G1I<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C4*;7-G:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R
M(")796(@0F'P;&%N=/US_2!997)L9?YT:7(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G:60@(DEN
M<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R("+6;F-E>64@2V]L;U]N($5K
M;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C8*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@
M=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(EEE;FD@:V]L;VYU(/YU(&%N9&%K
M:2!K;VQO;F1A;B!S;VYR82!Y97)L9?YT:7(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN
M<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G
M<W1R(")996YI(&MO;&]N=2#^=2!A;F1A:VD@:V]L;VYD86X@]FYC97EE('EE
M<FQE_G1I<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV,@IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!A9G1E
M<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B665N:2!S873]<OT@_G4@86YD
M86MI('-A=/UR9&%N('-O;G)A>6$@>65R;&7^=&ER(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED
M("));G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS
M9W-T<B`B665N:2!S873]<OT@_G4@86YD86MI('-A=/UR9&%N(/9N8V5Y92!Y
M97)L9?YT:7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-S`*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!A
M9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(EEE;FD@<&%R86=R86;]
M(/YU(&%N9&%K:2!D_/#\;61E;B!S;VYR87EA('EE<FQE_G1I<B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N
M="!N;V1E(@IM<V=S='(@(EEE;FD@<&%R86=R86;](/YU(&%N9&%K:2!D_/#\
M;61E;B#V;F-E>64@>65R;&7^=&ER(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H
M<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T
M<B`BUG1E:VD@=&%S;&%K('EE<FQE_G1I<B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,SD*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O
M('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G
M<W1R(")996YI(&)I<B!P87)A;&]Y_2!A;&%B:6QE8V7P:6YI>B!B:7(@96QE
M:W1R;VYI:R!P;W-T82!A9')E<VD@9VER:6XZ(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`IM<V=I9"`B26YS
M97)T(&-E;&P@869T97(B"FUS9W-T<B`B2/QC<F5Y:2!S;VYR87/];F$@>65R
M;&7^=&ER(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU.0IM<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S
M='(@(DC\8W)E>6D@]FYC97-I;F4@>65R;&7^=&ER(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`IM<V=I9"`B
M26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R(")+;VQO;G4@<V]N<F%S_6YA
M('EE<FQE_G1I<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E
M(@IM<V=S='(@(DMO;&]N=2#V;F-E<VEN92!Y97)L9?YT:7(B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS
M97)T(&UE<W-A9V5S(@IM<V=S='(@(DUE<V%J(&=I<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-0IM<V=I
M9"`B26YS97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R(")087)A9W)A9OT@
M<V]N<F%S_6YA('EE<FQE_G1I<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A
M<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B4&%R86=R86;](/9N8V5S:6YE('EE
M<FQE_G1I<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T
M<B`B4V%T_7+]('-O;G)A<_UN82!Y97)L9?YT:7(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED("))
M;G-E<G0@<F]W(&)E9F]R92(*;7-G<W1R(")3873]<OT@]FYC97-I;F4@>65R
M;&7^=&ER(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,`IM<V=I9"`B
M26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U
M97-T:6]N.B(*;7-G<W1R(")'_'9E;FQI:R!S;W)U<W5N=6X@8V5V86+].B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*
M;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B1_9R_&YT_'G\
M(%EE<FQE_G1I<B]$9?!I_G1I<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN
M:R(*;7-G<W1R(")"8?!L86YT_2!997)L9?YT:7(O1&7P:?YT:7(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM
M<V=I9"`B26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T
M<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B1&'P_73];2!L:7-T97-I(&?V;F1E
M<FUE:R!IYVEN('EE=&5R<VEZ(&MR961I+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("));G-U9F9I
M8VEE;G0@8W)E9&ET+B(*;7-G<W1R(")9971E<G-I>B!K<F5D:2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-S4*;7-G:60@(DEN=&5G97(B"FUS
M9W-T<B`B5&%M<V%Y_2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q
M,S,*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R(")486US87G](&QI<W1E
M<VDB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.3<*;7-G:60@(DEN=F%L:60@541(+B`H57-E<B!$871A($AE861E
M<BDN(@IM<V=S='(@(D=EYV5R<VEZ(%5$2"X@*$MU;&QA;OUC_2!697)I($)A
M_FS]:R!":6QG:7-I*2(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]Z:7`N<&AP.C$W,`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M>FEP+G!H<#HR,#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII
M<"YP:'`Z,C$P"B,L(&9U>GIY"FUS9VED("));G9A;&ED(%I)4"!D871A(@IM
M<V=S='(@(D=EYV5R<VEZ('5N:6-O9&4@=F5R:7-I+B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P;&EC871I;VXN
M(@IM<V=S='(@(D=EYV5R<VEZ('5Y9W5L86UA+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV
M86QI9"!B871C:"!)1"XB"FUS9W-T<B`B1V7G97)S:7H@>?WP_6X@:VEM;&GP
M:2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#@W(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Q-3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(S,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,CDY"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<*;7-G:60@(DEN
M=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@(D=EYV5R<VEZ('9E<FD@
M9_9N9&5R:6QD:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@
M861D<F5S<RXB"FUS9W-T<B`B1V7G97)S:7H@=&5S;&EM(&%D<F5S:2(*"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C@Q"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P,`HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR,C`*;7-G:60@(DEN
M=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B1V7G97)S:7H@9&]S>6$@8FGG
M:6UI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-PHC+"!F
M=7IZ>0IM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS9W-T<B`B1V7G
M97)S:7H@=7EG=6QA;6$N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$W,0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!L;V-A=&EO;B!P<F]V
M:61E9"XB"FUS9W-T<B`B1V7G97)S:7H@=7EG=6QA;6$N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED
M("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R(")'9>=E<G-I>B!M<V=?='EP
M92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P,PIM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS
M9W-T<B`B1V7G97)S:7H@>6%D82!A=&QA;FW]_B!A<&E?:60B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.38*;7-G
M:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+B(*;7-G<W1R(")'
M9>=E<G-I>B!Y861A(&%T;&%N;?W^(&1E\&G^=&ER9V5L97(B"@HC.B!A9&UI
M;B]P97)M<R]A9&1C:&EL9"YP:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R96YT
M('!E<FUI<W-I;VXN(@IM<V=S='(@(D=EYV5R<VEZ(/QS="!I>FEN+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S,*(RP@9G5Z>GD*;7-G
M:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B1V7G97)S:7H@_'-T
M(&EZ:6XN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-0HC
M+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O9&4N(@IM<V=S='(@
M(D=EYV5R<VEZ(&EL971I_FEM(&MU<F%L;&%R_2(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B26YV
M86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B1V7G97)S:7H@:6QE=&G^:6T@:W5R
M86QL87+](@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HY,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C<Q(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z.#`*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@<F5C:7!I96YT
M.B!<(B5S7"(B"FUS9W-T<B`B1V7G97)S:7H@86S]8_TZ("<E<R<B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$P-S8@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HQ,C8R"FUS9VED("));G9A;&ED('-H87)E(&]B:F5C="(*
M;7-G<W1R(")'9>=E<G-I>B!P87EL8?[];&%N(&YE<VYE(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"FUS9VED
M("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R(")'9>=E<G-I>B!K
M87EN86L@861R97-I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,Q,0IM<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A
M=&$N(@IM<V=S='(@(D=EYV5R<VEZ('5N:6-O9&4@=F5R:7-I+B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3<*;7-G:60@(DEN=F5N=&]R>2(*
M;7-G<W1R(")3=&]K(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C8W.0HC+"!F=7IZ>0IM<V=I9"`B26YV97)T('-E;&5C=&EO
M;B(*;7-G<W1R("+>9>=I;&D@;VQA;FQA<OT@:V5S(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R
M"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM<V=S='(@(MUR
M86X@W7-L86T@0W5M:'5R:7EE=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DER
M87$B"FUS9W-T<B`B27)A:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N
M9"(*;7-G<W1R("+=<FQA;F1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,34*;7-G:60@(DES;&4@;V8@36%N(@IM<V=S='(@(DUA;B!!9&$@
M1&5V;&5T:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(T"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R(")986S]
M=/UL;?W^(&?V:R!G_'+\;'3\;/P@9OUR=/UN82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM
M<V=I9"`B27-R865L(@IM<V=S='(@(MUS<F%I;"(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C(U"FUS9VED("))<W-U97(B"FUS9W-T
M<B`BQ_UK87)A;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(MUT86QI:R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,@IM<V=I9"`B271A;'DB"FUS9W-T<B`BW71A;'EA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@R"FUS9VED(")*86UA:6-A(@IM<V=S='(@(DIA;6%I:V$B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Q"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,SD*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I
M9"`B2F%N=6%R>2(*;7-G<W1R(")/8V%K(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED
M(")*87!A;B(*;7-G<W1R(")*87!O;GEA(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#<*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T
M<B`B2F%P;VYC82`H25-/+3(P,C(M2E`I(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HS,3`*;7-G:60@(B(*(DIA=F%S8W)I<'0@:&%S(&)E96X@
M9&ES86)L960@;VX@>6]U<B!B<F]W<V5R(&%N9"!T:&ES('!A9V4@;6%Y(&YO
M="!B92`B"B)D:7-P;&%Y:6YG(&-O<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*
M;7-G<W1R(")*97)S97DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*
M;7-G<W1R("+<<F3\;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@(E1E;6UU>B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#8*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED
M(")*=6YE(@IM<V=S='(@(DAA>FER86XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y
M(@IM<V=S='(@(EEA<VQA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R
M(@IM<V=S='(@(D]R=&%Y82!987-L82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$W"FUS9VED(")*=7-T:69Y
M($9U;&PB"FUS9W-T<B`B5&%M86UE;B!987-L82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$T"FUS9VED(")*
M=7-T:69Y($QE9G0B"FUS9W-T<B`B4V]L82!987-L82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V"FUS9VED
M(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(E-A\&$@66%S;&$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#8*;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T<B`B2V%Z86MI<W1A;B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-C0*
M;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@(M9Z9_QN(&]L86X@<V%K
M;&%N<_UN(&W]/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T
M<B`B2V5N>6$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@U
M"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(DME<F)E<F]S('-U;G5C=2!D;_!R=6QA;6%Y_2!R961D
M971T:2XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(DME
M<FYE;"!.97=B:65S(@IM<V=S='(@(L=E:VER9&5K($%C96UI;&5R:2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y
M($-R96%T:6]N(@IM<V=S='(@(D%N86AT87(@66%R870B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@(DME>2!&:6YG97)P
M<FEN="(*;7-G<W1R(")!;F%H=&%R(%!A<FUA:VEZ:2(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*
M;7-G<W1R(")!;F%H=&%R(%5Z=6YL=?!U(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@5'EP92(*;7-G<W1R(")!
M;F%H=&%R(%1I<&DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4Y.`IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(D%N86AT87(@2W5L
M;&%N_6W](@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S0P
M"FUS9VED(")+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES
M97)V97(N(@IM<V=S='(@(D'G_6L@86YA:'1A<B!S=6YU8W5S=6YD82!A;F%H
M=&%R('IA=&5N('9A<BXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*
M;7-G:60@(DMI9',B"FUS9W-T<B`BQV]C=6ML87(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*
M;7-G:60@(DMI<FEB871I(@IM<V=S='(@(DMI<FEB871I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@U"FUS9VED(")+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI
M8R!O9B(*;7-G<W1R(")+=7IE>2!+;W)E(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS9VED
M(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B1_QN97D@2V]R92(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED(")+;W)E86X@*$550RU+
M4BDB"FUS9W-T<B`B2V]R96-E("AE=6,M2U(I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS
M9VED(")+=7=A:70B"FUS9W-T<B`B2W5V97ET(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS
M9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(DO]<F?]>FES=&%N(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED("),85]Y;W5T(@IM<V=S
M='(@(E-A>69A(%]$_'IE;FDB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C@S"FUS9VED("),86YG=6%G92(*;7-G<W1R(")$:6PB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC
M(@IM<V=S='(@(DQA;R!$96UO:W)A=&EC($AA;&L@0W5M:'5R:7EE=&DB"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),87-T($AA;&8B"FUS
M9W-T<B`B4V]N($3V<F3\;B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW
M-@HC+"!F=7IZ>0IM<V=I9"`B3&%S="!087-S=V]R9"!#:&%N9V4B"FUS9W-T
M<B`B4&%R;VQA>?T@<_UF_7)L82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX
M-B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E<B(*
M;7-G<W1R("+>:?YK:6X@07DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U
M,0IM<V=I9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R(")3;VX@1_QN8V5L;&5M
M93HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`B4V]N($=I<FG^
M.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<R,0HC+"!P:'`M
M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@
M(E-O;B!':7)I_CH@)7,@_'IE<FEN9&5N("5S(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z-S$V"FUS9VED("),87-T(&QO9VEN.B!.979E<B(*;7-G
M<W1R(")3;VX@1VER:?XZ($%S;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQA
M='9I82(*;7-G<W1R("),971O;GEA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0T"FUS9VED("),87<B"FUS9W-T<B`B66%S82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0IM<V=I9"`B
M3&%Y;W5T(@IM<V=S='(@(D3\>F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R
M(&YO(&)O<F1E<B(*;7-G<W1R(")(:>=B:7(@<_UN_7(@:>=I;B!B;_X@8OUR
M86MM82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R("),
M_&)N86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B"FUS9W-T<B`B4V]L(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q.0IM<V=I9"`B3&5F="!H96%D97(B
M"FUS9W-T<B`B4V]L(&)A_FS]:R!B:6QG:7-I(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$Q-0IM<V=I9"`B3&5F="!V86QU97,B"FUS9W-T<B`B
M4V]L9&%K:2!D9?!E<FQE<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,30S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&5S;W1H
M;R(*;7-G<W1R("),97-O=&AO(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED("),979E;"(*;7-G<W1R(")!_FLB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B3&EB97)Y
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&EB>6%N($%R86(@2F%M86AI<FEY
M82(*;7-G<W1R("),:6)Y82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,30P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EE8VAT
M96YS=&5I;B(*;7-G<W1R("),:65C:'1E;G-T96EN(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@(DQI9VAT($1R
M:7IZ;&4B"FUS9W-T<B`BQVES96QI>6]R(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*;7-G:60@(DQI9VAT(%)A:6XB"FUS
M9W-T<B`B2&%F:68@66'P;75R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@16%R;'DB"FUS
M9W-T<B`B17)K96X@4V%A=&QE<F1E($AA9FEF(%EA\&UU<B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),:6=H
M="!286EN($QA=&4B"FUS9W-T<B`B1V7G(%-A871L97)D92!(869I9B!98?!M
M=7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M.0IM<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B2&%F:68@66'P
M;75R(%-A\&%N8?#](@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S`*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM
M<V=S='(@(D?V:R!G_'+\;'3\;/P@:&%F:68@>6'P;75R(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*;7-G:60@(DQI9VAT
M(%-N;W<B"FUS9W-T<B`B2&%F:68@2V%R(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO
M=V5R(@IM<V=S='(@(DAA9FEF($MA<B!38?!A;F'P_2(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B3OQK
M=&5L:2#>:6ER(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q-`IM
M<V=I9"`B3&EN:R(*;7-G<W1R(")"8?!L86YT_2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B
M3&EN:R!P;VEN=',@=&\Z(@IM<V=S='(@(D)A\&QA;G3](&YO:W1A<_TZ(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-0IM<V=I9"`B3&EN:R!T
M:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES
M<&QA>6EN9R(*;7-G<W1R(")']G+\;G3\;&5R:V5N(&5L96MT<F]N:6L@<&]S
M=&$@861R97-I;FD@;VQU_G1U<FUA('-A>69A<_UN82!B8?!L82(*"B,Z(&9R
M86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:'1M;#)T97AT+G!H<#HQ.#,*
M;7-G:60@(DQI;FMS(@IM<V=S='(@(D)A\&QA;G3];&%R(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0V"FUS9VED("),:6YU>"!#;V]K:64B"FUS9W-T
M<B`B3&EN=7@@QV5R97II(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.#8*;7-G:60@(DQI<W0@+2!U<V5R(&-A;B!S964@=&AE
M(&9O;&1E<B(*;7-G<W1R("),:7-T96QE("T@:W5L;&%N_6/](&1I>FEN:2!G
M]G)E8FEL:7(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,S"FUS9VED("),
M:7-T($1A=&%B87-E<R(*;7-G<W1R(")697)I(%1A8F%N;&%R_6[]($QI<W1E
M;&4B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,`IM<V=I9"`B3&ES
M="!(96QP(%1O<&EC<R(*;7-G<W1R(")987)D_6T@2V]N=6QA<OUN_2!,:7-T
M96QE(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,@IM<V=I9"`B3&ES="!4
M86)L97,B"FUS9W-T<B`BQVEZ96QG96QE<FD@3&ES=&5L92(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DT"FUS9VED("),:7-T+4%R
M8VAI=F4B"FUS9W-T<B`B3&ES=&5L92U!<OYI=B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O2&5A9&5R<RYP:'`Z-3@Y"FUS9VED("),:7-T+4AE;'`B"FUS
M9W-T<B`B3&ES=&5L92U987)D_6TB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TAE861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U)9"(*;7-G<W1R("),:7-T
M96QE+4ED(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU
M.3(*;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T<B`B3&ES=&5L92U386AI<"(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS9VED
M("),:7-T+5!O<W0B"FUS9W-T<B`B3&ES=&5L92U']FYD97)I;&UI_B#6\&5L
M97(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,0IM
M<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS9W-T<B`B3&ES=&5L92U3_')D_'+\
M;6/\;&5R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU
M.3`*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`B3&ES=&5L92U3
M_')D_'+\;6/\($]L;6%Y86YL87(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z
M-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@<V5S<VEO
M;G,@9F%I;&5D.B`E<R(*;7-G<W1R(")+=6QL86[]8_T@;&ES=&5L96UE('-E
MYVEL96UE>B!K_6S];F3]+B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!U<V5R<R!F86EL
M960Z("5S(@IM<V=S='(@(DMU;&QA;OUC_2!L:7-T96QE;64@<V7G:6QE;65Z
M(&O];/UN9/TN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN
M8SHR"FUS9VED("),:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R
M(")+=6QL86[]8_T@;&ES=&5L96UE('-EYVEL96UE>B!K_6S];F3]+B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-PIM<V=I9"`B3&ET97)A='5R92(*
M;7-G<W1R(")%9&5B:7EA="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,30T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&ET:'5A
M;FEA(@IM<V=S='(@(DQI='9A;GEA(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6UA9V5S+G!H<#HX,PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G
M<W1R(")9_&ML96YI>6]R+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(Q,0IM<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S='(@(EEE<F5L
M('IA;6%N.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,PIM<V=I9"`B
M3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(EEE<B!V92!:86UA;B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HV-`HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HV-0IM<V=I9"`B3&]C871I;VXB"FUS
M9W-T<B`B665R(@H*(SH@;&]G:6XN<&AP.C$W,B!S97)V:6-E<R]P;W)T86PO
M<VED96)A<BYP:'`Z,3DQ('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C,*
M(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHY,`IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(D=I<FG^
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U"FUS9VED("),
M;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.#4*;7-G:60@(DQO9R!O=70B
M"FUS9W-T<B`BQ_UK_?XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-3D*
M(RP@9G5Z>GD*;7-G:60@(DQO9VEN(@IM<V=S='(@(D=I<FG^(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$P-PIM<V=I9"`B3&]G:6X@5&%S:W,B"FUS
M9W-T<B`B1VER:?X@1_9R979L97)I(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z.3DV"FUS9VED("),;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S
M97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+B(*
M;7-G<W1R(")+=6QL86[]8_T@863]('9E>6$@<&]R;VQA(&1O\')U(&]L;6%D
M_?#](&GG:6X@9VER:?X@8F'^87+]<_UZ(&]L9'4N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z.3DR"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S
M='(@(D=I<FG^(&)A_F%R_7/]>B!O;&1U+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$S-C4*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R(")5>G5N
M(&UE=&EN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED("),
M;W9E(@IM<V=S='(@(D'^:R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8W"FUS9VED("),;W<B"FUS9W-T<B`B1/S^_&LB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@(DO\
MY_QK('EU;F%N(&AA<F9L97)I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T
M:6X@;&5T=&5R<R(*;7-G<W1R(")+_.?\:R!L871I;B!H87)F;&5R:2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B2_SG
M_&L@<F]M82!R86MA;6QA<OTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M
M8F]U<F<B"FUS9W-T<B`B3/QK<V5M8G5R9R(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#`*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S."!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B04$B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C@Q"FUS9VED(")-3U1$(@IM<V=S='(@(DU/5$0B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I
M9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G
M<W1R(")-4RU43D5&($5K:2!V97)I(&GG97)M96UE:W1E9&ER+B(*"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO
M8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R(")-4T<B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3(*;7-G:60@(DUA8V%O(@IM<V=S='(@(DUA8V%O(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDQ"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P
M=6)L:6,@;V8B"FUS9W-T<B`B36%K961O;GEA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS
M9VED(")-861A9V%S8V%R(@IM<V=S='(@(DUA9&%G87-K87(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#D*;7-G:60@(DUA9VEC(@IM<V=S='(@(D+\
M>?PB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#$*;7-G:60@(DUA
M:6PB"FUS9W-T<B`B4&]S=&$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-3(R"FUS9VED(")-86EL($%D;6EN(@IM<V=S='(@(E!O<W1A(%GV;F5T
M:6-I<VDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B
M0F'P;&%?;G3](%EA<F%T+BXN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QA
M=VDB"FUS9W-T<B`B36%L879I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,SD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-86QA
M>7-I82(*;7-G<W1R(")-86QE>GEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-
M86QD:79E<R(*;7-G<W1R(")-86QD:79L97(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G
M:60@(DUA;&DB"FUS9W-T<B`B36%L:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B
M36%L=&$B"FUS9W-T<B`B36%L=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.3$*;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S
M('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@(@HB
M87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*
M(M;P96QE<FD@971I:V5T;&5Y96-E\&EN:7H@:V%T96=O<FD@;&ES=&5S:6YI
M('9E(&MA=&5G;W)I;&5R:2`B"B)I;&G^:VEL96YD:7)E8V7P:6YI>B!R96YK
M;&5R:2!Y]FYE=&EN+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,34S"FUS9VED(")-87`R-"!M87`B"FUS9W-T<B`B36%P
M,C0@:&%R:71A<_TB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3`X-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3$V.`IM<V=I9"`B36%P475E<W0@;6%P(@IM<V=S='(@(DUA
M<%%U97-T(&AA<FET87/](@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S=&]R960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#,*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED
M(")-87)C:"(*;7-G<W1R(")-87)T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0IM<V=I9"`B36%R9VEN(@IM
M<V=S='(@(DME;F%R(&)O_FQU\'4B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS
M965N(&9L86=S(@IM<V=S='(@(D]K=6YM=?XO3VMU;FUA;?W^(&]L87)A:R!I
M_F%R971L92(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP
M;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R(")$:?!E<B!I;&5T:2!I_F%R971L
M97)I>6QE(&G^87)E=&QE("CV<FYE:SH@UFYE;6QI+T-E=F%P;&%N;?W^*2`B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T
M<B`B36%R<VAA;&P@061A;&%R_2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,34Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R
M=&EN:7%U92(*;7-G<W1R(")-87)T:6YI:R(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")-871C:&EN9R!F:65L9',B"FUS9W-T
M<B`B1?YL96QE;B!A;&%N;&%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-875R
M:71A;FEA(@IM<V=S='(@(DUO<FET86YY82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I
M9"`B36%U<FET:75S(@IM<V=S='(@(DUA=7)I='5S(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED(")-
M87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(MUZ:6X@=F5R:6QE;B!E;B!Y
M_&MS96L@:W)E9&DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E
M>&-E961E9"XB"FUS9W-T<B`B16X@>?QK<V5K(&UE<V%J('!A<N=A<_T@<V%Y
M_7/](&'^_6QD_2XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P-@IM<V=I
M9"`B36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(E-O;B`R-"!S
M86%T=&5K:2!E;B!Y_&MS96L@<_UC86ML_6LZ("(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,CDX"FUS9VED(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z("(*
M;7-G<W1R(")3;VX@-B!S86%T=&5K:2!E;B!Y_&MS96L@<_UC86ML_6LZ("(*
M"B,Z(&QI8B]A<&DN<&AP.C@V"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!0
M;W)T86P@0FQO8VMS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$W"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,SD*;7-G:60@(DUA>&EM=6T@;&5N
M9W1H(@IM<V=S='(@(D5N('G\:W-E:R!U>G5N;'5K(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-0HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G
M<W1R(")-87G]<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(DUA>6]T=&4B"FUS
M9W-T<B`B36%Y;W1T92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,`IM
M<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B5/UP(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@IM<V=I9"`B365M8F5R<R(*;7-G<W1R
M("+<>65L97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<X"FUS9VED
M(")-96YU(&UO9&4Z(@IM<V=S='(@(DUE;OP@2VEP:3HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P"FUS9VED
M(")-97)G92!C96QL<R(*;7-G<W1R(")(_&-R96QE<FD@8FER;&7^=&ER(@H*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-34*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`BW6QE=&DB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S
M<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C
M97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@
M(B(*(MUL97)I(&)A_F%R_7EL82!D;_!R=6QA;F3](&%M82!I;7IA;&%Y_6/]
M;OUN(&]N87D@8F5L9V5S:2!D;_!R=6QA;F%M863]+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B
M365S<V%G92!E>'!I<F5D+B(*;7-G<W1R(")-97-A:OUN('/\<F5S:2!B:71T
M:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4V.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8P,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR,C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C8P"FUS9VED(")-97-S86=E('1Y<&4B"FUS9W-T
M<B`B365S86H@=&EP:2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I
M9"`B365T87(@5V5A=&AE<B(*;7-G<W1R(")(879A(%)A<&]R=2(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A
M=F%I;&%B;&4N(@IM<V=S='(@(DAA=F$@<F%P;W)U(/9B9?!I(&MU;&QA;OUL
M86)I;&ER(&1E\&EL+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$R"FUS
M9VED("(B"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA
M=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R
M("(B"B)(879A(')A<&]R=2#V8F7P:2!K=6QL86[];&%B:6QI<B!D9?!I;"X@
M07ER_6YT_6QA<B!Y]FYE=&EC:2!IYVEN(&?\;FS\:VQE;F1I(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-0IM<V=I9"`B365T87)$0B!I
M<R!N;W0@8V]N;F5C=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C8W(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R(")9]FYT
M96TB"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C@Q(&9R86UE
M=V]R:R]24$,O4E!#+W-O87`N<&AP.C$Q-PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R
M(")9]FYT96T@)R5S)R!T86[];6QA;FUA;?W^(@H*(SH@9G)A;65W;W)K+U)0
M0R]24$,O<F5S="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D
M(&YO="!D969I;F5D+B!#86QL960@;65T:&]D.B`E<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S0@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HW-0IM<V=I9"`B365T<FEC(@IM<V=S='(@(DUE=')I:R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O(@IM<V=S='(@(DUE:W-I:V$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E
M<R!O9B(*;7-G<W1R(")-:6MR;VYE<WEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"FUS9VED(")-:61D;&4B
M"FUS9W-T<B`B3W)T82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1N968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B36EM92!4
M_'+\(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3`*;7-G:60@(DUI;B!T
M96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R(")3;VX@,C0@<V%A='1E:VD@
M96X@9/S^_&L@<_UC86ML_6LZ("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S`R"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R(")3
M;VX@-B!S86%T=&5K:2!E;B!D_/[\:R!S_6-A:VS]:SH@(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,SD*;7-G:60@(DUI;FEM=6T@<&%S
M<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-`IM<V=I
M9"`B36ER<F]R(@IM<V=S='(@(EEA;G/](@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(DUU:'1E
M;&EF(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-S(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S0P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E
M<75E<W0N(@IM<V=S='(@(D)U;'5N86UA>6%N(%!%05(@<&%K971I.B!(5%10
M7U)E<75E<W0N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q-0IM<V=I
M9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE
M<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC
M871I;VXN(@IM<V=S='(@(B(*(D%T;&%N;?W^('EA</UL86YD_7)M82X@0G4@
M=7EG=6QA;6%Y_2!K=6QL86YM86L@:7-T:7EO<G-A;OUZ('EA</UL86YD_7)M
M87G]("(*(OQR971M96L@>F]R=6YD87/];OUZ+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B36ES
M<VEN9R!M97-S86=E($E$+B(*;7-G<W1R(")!=&QA;FW]_B!M97-A:B!)1"XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P
M+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@
M36%I;"XB"FUS9W-T<B`B071L86YM_?X@;VQA;B!G97)E:VQI(%!%05(@<&%K
M971I($UA:6PN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM
M<V=S='(@(D%T;&%N;?W^(&]T=7)U;6$@86ET($E$+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-38*;7-G:60@(DUO(@IM
M<V=S='(@(E!Z="(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW-`IM
M<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`B1V5Z:6-I(%!O<W1A(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*;7-G:60@
M(DUO9&5R871E(@IM<V=S='(@(E-A:VEN(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV-B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#@*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B1&7P
M:?YI;2!487)I:&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T
M<B`B1&7P:?YT:7(Z55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV-S,*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B36]D(%1A8F%N
M_2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B
M"FUS9W-T<B`B36]L9&]V>6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;F%C
M;R(*;7-G<W1R(")-;VYA8V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O
M;&EA(@IM<V=S='(@(DUO\&]L:7-T86XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-3DT"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R(")!
M>2!V92!Y_6PB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(D%Y;/UK(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDT"FUS9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(DUO;G1S97)R
M870B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S='(@(D%Y($5V<F5L97)I
M(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3<R(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C(U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")-
M;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D
M("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO<F]C8V\B
M"FUS9W-T<B`B1F%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S,*;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R(")'96YE
M;&QI:VQE($'G_6LB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS-`IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R(")'96YE
M;&QI:VQE($)U;'5T;'4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS-0IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@(D=E
M;F5L;&EK;&4@1_QN9?YL:2(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C4P.0IM<V=I9"`B36]V92!$;W=N(@IM<V=S='(@(D'^8?#]
M(%1A_OTB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU
M,3,*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R(")3;VQA(%1A_OTB"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,3<*;7-G:60@(DUO
M=F4@4FEG:'0B"FUS9W-T<B`B4V'P82!48?[](@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`U"FUS9VED(")-;W9E(%5P(@IM<V=S
M='(@(EEU:V%R_2!48?[](@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C4R-`IM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(D'^
M8?#]('1A_OTB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-3(S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HU,C0*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`B675K87+]('1A_OTB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.34*;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B36]Z
M86UB:6LB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@T"FUS9VED
M(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`BQV]K;'4@
M9/QZ97D@8?YA\/T@8>?];/UR(&QI<W1E;&5R(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-34*;7-G:60@(DUU;'1I;6%P
M(%5+(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,C0R"FUS9VED(")-=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`BQV]K
M;'4@4V7G:6TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`P"FUS
M9VED(")->2!!8V-O=6YT(@IM<V=S='(@(DAE<V%B_6TB"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z,C@*(RP@9G5Z>GD*;7-G:60@(DUY($%C8V]U;G0@
M26YF;W)M871I;VXB"FUS9W-T<B`B0FEL9VEL97)I;FEZ(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+VEN9&5X+G!H<#HU-`IM<V=I9"`B37D@4&]R=&%L(@IM<V=S
M='(@(E!O<G1A;/UM(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C$S
M-@IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R(")0;W)T86P@1/QZ
M96YI;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B37EA;FUA<B(*;7-G<W1R(")-
M>6%N;6%R(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E
M+FAT;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R(")+
M86)U;"!%5$U)64]254TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,3$@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$P,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS
M.`IM<V=I9"`B3F%M92(*;7-G<W1R(")!9"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I
M9"`B3F%M:6)I82(*;7-G<W1R(").86UI8GEA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS
M9VED(").875R=2(*;7-G<W1R(").875R=2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I
M9"`B3F5P86PB"FUS9W-T<B`B3F5P86PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@
M(DYE=&AE<FQA;F1S(@IM<V=S='(@(DAO;&QA;F1A(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*
M;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@(DAO;&QA;F1A
M($%N=&EL;&5R:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3@Q"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R(").971S
M8V%P92!486)A;B!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB
M"FUS9W-T<B`B3F5T<V-A<&4@0T$@W7!T86P@55),(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#4*;7-G:60@(DYE='-C87!E($-!
M('!O;&EC>2!54DPB"FUS9W-T<B`B3F5T<V-A<&4@0T$@:W5R86P@55),(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#0*;7-G:60@
M(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@(DYE='-C87!E(%EE;FEL
M96UE(%),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.#(*;7-G:60@(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@(DYE
M='-C87!E(-UP=&%L(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3@V"FUS9VED(").971S8V%P92!34TP@<V5R=F5R(&YA;64B
M"FUS9W-T<B`B3F5T<V-A<&4@4U-,('-U;G5C=2!A9/TB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@
M8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R(").971S8V%P92!O;F%Y(&)E
M;&=E<VD@8>?]:VQA;6%S_2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3@P"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!T>7!E
M(@IM<V=S='(@(DYE='-C87!E(&]N87D@8F5L9V5S:2!T_'+\(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U,0IM<V=I9"`B3F5T=V]R:R(*;7-G
M<W1R(")!\"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R
M-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,U"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.#8*;7-G:60@(DYE=F5R(@IM<V=S='(@(D%S;&$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B665N:2!+
M86QE9&]N>6$B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-
M86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(EEE
M;FD@2V%T96=O<FDB"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R
M+V5M86EL<RYP:'`Z.#$*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E
M<B]E;6%I;',N<&AP.C@W"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT
M97(O96UA:6QS+G!H<#HY-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL
M=&5R+V5M86EL<RYP:'`Z,3`Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(").97<@365S<V%G92!T;R`E<R(*;7-G<W1R("+=;&5T:2!/;'7^='5R("@E
M<RDB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN
M<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N
M(@IM<V=S='(@(EEE;FD@07DB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*
M;7-G<W1R(")996YI($MU;&QA;OUC_2!!9/T@*%-EYVEM;&DI(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDX"FUS9VED(").97<@6F5A;&%N9"(*;7-G<W1R(")996YI(%IE;&QA
M;F1A(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,W"B,L(&9U
M>GIY"FUS9VED(").97<@<&%S<W=O<F0B"FUS9W-T<B`B4&%R;VQA(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C(R-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(").97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU,@HC+"!F
M=7IZ>0IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"XB"FUS9W-T
M<B`B4&%R;VQA;&%R(&7^;&7^;65K('IO<G5N9&%D_7(N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W
M('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R(")996YI(%!E;F-E<F4@*%]B;_XI
M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4R"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#D*;7-G
M:60@(DYE=W,B"FUS9W-T<B`B2&%B97)L97(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S`U"FUS9VED(").97=S9W)O=7!S(@IM<V=S='(@(DAA
M8F5R($=R=7!L87+](@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z
M,34@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHQ,CD@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,C4*;7-G:60@(DYE>'0B"FUS9W-T<B`B4V]N<F%K:2(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B3F5X="`T(%!H87-E
M<R(*;7-G<W1R(")3;VYR86MI($5V<F4B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C,W,B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C,W-@IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@(E-O;G)A:VD@4V7G
M96YE:VQE<B(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z,3`S"B,L
M(&9U>GIY"FUS9VED(").97AT/B(*;7-G<W1R(")3;VYR86MI(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDV"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B3FEK87)A9W5A(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDV"FUS9VED(").:6=E<B(*;7-G<W1R(").:6IE<GEA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDV"FUS9VED(").:6=E<FEA(@IM<V=S='(@(DYI:F5R>6$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S@P"FUS9VED(").
M:6=H="(*;7-G<W1R(")'96-E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").:75E
M(@IM<V=S='(@(DYI=64B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.38S"FUS9VED(").;R(*;7-G<W1R(")(87G]<B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM<V=I9"`B3F\@
M879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N
M8V5S(&9O<BXB"FUS9W-T<B`B1F%R:VQA<OUN(&?V<W1E<FEL96)I;&5C9?!I
M(&MU;&QA;OUL86)I;&ER('EA</UL86YD_7)M82!V97)I<VD@>6]K+B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z,3`U"FUS
M9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA
M9V5S+B(*;7-G<W1R("))4T\@:6UA:FQA<OT@;W7^='5R;6%K(&GG:6X@:W5L
M;&%N_6QA8FEL:7(@8FER('GV;G1E;2!Y;VLN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").;R!B
M871C:"!T96UP;&%T92XB"FUS9W-T<B`B6?WP_6X@=&%S;&'P_2!Y;VLN(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-SD@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C0U"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C(V-PIM<V=I9"`B3F\@8FQO8VL@97AI
M<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB"FUS9W-T<B`BW7-T96YE
M;B!K;VYU;61A(&AIYV)I<B#V8F5K(&)U;'5N;6%M86MT863]<B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-3`*;7-G:60@(DYO(&-A;&5N
M9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(DU#04P@9&_P<G5L86UA<_T@:>=I;B!H:>=B:7(@=&%K=FEM(&%D
M_2!S8?!L86YM86W]_G3]<BX@(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z
M-30*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T<B`B1&7P:?YI:VQI:R!9;VLB
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B
M3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB
M"FUS9W-T<B`B0G4@:7IN92!H:>=B:7(@86QT(&EZ:6X@96ML96YE;65Y96-E
M:W1I<BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V-R!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P,@HC.B!F<F%M97=O<FLO571I;"]5
M=&EL+G!H<#HW-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R("(E
M<R!IYVEN(&AIYV)I<B!Y87#];&%N9/UR;6$@8FEL9VES:2!B96QI<G1I;&UE
M9&DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,C0*;7-G:60@
M(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&
M5%`@5D93+B(*;7-G<W1R(")&5%`@5D93(&GG:6X@:&GG8FER('EA</UL86YD
M_7)M82!B:6QG:7-I(&)E;&ER=&EL;65D:2XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C8V.0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S='(@(E-13"!6
M1E,@:>=I;B!H:>=B:7(@>6%P_6QA;F3]<FUA(&)I;&=I<VD@8F5L:7)T:6QM
M961I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,3<*
M;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(E-13"U&:6QE(%9&4R!IYVEN
M(&AIYV)I<B!Y87#];&%N9/UR;6$@8FEL9VES:2!B96QI<G1I;&UE9&DN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B2W)E9&D@>6]K
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,T"FUS9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T
M<B`B2&GG8FER('1E<VQI;2!N;VMT87/](&)E;&ER=&EL;65M:?YT:7(N(@H*
M(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#<W"FUS9VED(").
M;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(DAIYV)I<B!D;W-Y82!Y_&ML96YE
M;65D:2(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HW,0IM<V=I9"`B3F\@
M:6-O;G,@9F]U;F0N(@IM<V=S='(@(DAIYV)I<B!S:6UG92!B=6QU;F%M863]
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C@@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(S
M"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(DAIYV)I<B!Y
M97(@8F5L:7)T:6QM961I+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@(DYO(&QO8V%T:6]N('!R;W9I9&5D
M+B(*;7-G<W1R(")(:>=B:7(@>65R(&)E;&ER=&EL;65D:2XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I
M9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`B2&GG8FER(&UE<V%J
M('-A\&QA;FUA9/TN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S8*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*
M;7-G<W1R(")!9"!B96QI<G1I;&UE9&DN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*;7-G:60@(DYO(&YU;6)E
M<B!S<&5C:69I960N(@IM<V=S='(@(DYU;6%R82!B96QI<G1I;&UE9&DN(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS9VED(").;R!O9F9E;G-I
M=F4@9F]R='5N97,B"FUS9W-T<B`B4V%L9/UR9V%N(&1E>6G^(&MU;&QA;FUA
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(DA45%`@9&_P<G5L86UA<_T@:>=I;B!P87)O;&$@9VER:6QM
M961I+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`X"FUS
M9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`B24U!4"!D;_!R=6QA;6%S_2!IYVEN('!A<F]L82!G
M:7)I;&UE9&DN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW
M,@IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")+97)B97)O<R!D;_!R=6QA;6%S_2!I
MYVEN('!A<F]L82!G:7)I;&UE9&DN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]S87-L+G!H<#HW-R!F<F%M97=O<FLO075T:"]!=71H+VQO9VEN+G!H<#HX
M-`HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-S4*;7-G:60@(DYO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B3&]G:6X@9&_P<G5L86UA<_T@:>=I;B!P87)O;&$@9VER:6QM
M961I+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%S<W=D+G!H<#HQ,S4*
M;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(E!!4U-71"!D;_!R=6QA;6%S_2!IYVEN('!A
M<F]L82!G:7)I;&UE9&DN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N
M<&AP.C@T"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")334(@9&_P<G5L86UA<_T@:>=I;B!P
M87)O;&$@9VER:6QM961I+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,3(X-@IM<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-3
M3"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E
M<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B
M(@HB3W!E;E-33"!I:VEL:7-I;F4@:&GG8FER('EO;"!B=6QU;F%M863]+D]P
M96Y34TP@:6MI;&ES:2!02T-3(#$R('9E<FES:7EL92`B"B)C86S]_FUA:R!I
MYVEN(&=E<F5K;&DN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V
M92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R("+<
M>64@;VQM86L@:>=I;B!B96ML97EE;B!Y;VLN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C<U,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3F\@
M<75O=&$@<V5T+B(*;7-G<W1R(")"96QI<G1I;&UE;6G^(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PIM<V=I
M9"`B3F\@<G5L97,B"FUS9W-T<B`B2W5R86P@>6]K(@H*(SH@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z-#0Y"B,L(&9U>GIY"FUS9VED(").;R!S97!A
M<F%T;W(@<W!E8VEF:65D+B(*;7-G<W1R(").=6UA<F$@8F5L:7)T:6QM961I
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#0*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(EEA;B!Y;VLB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X,PHC+"!F=7IZ>0IM<V=I
M9"`B3F\@<W5C:"!F:6QE(@IM<V=S='(@(EEA;B!Y;VLB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3,X"FUS9VED(").;R!T96UP;W)A<GD@
M9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(M9N8F5L
M;&5K(&GG:6X@9V7G:6-I(&1I>FEN(&)U;'5N86UA9/TN(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C$*;7-G:60@(DYO
M('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R(")+=6QL
M86[]8_T@863]('9E+W9E>6$@<&%R;VQA(&?V;F1E<FEL;65D:2XB"@HC.B!F
M<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L
M:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B1V7G97)L:2!834P@=F5R
M:7-I(&=E<FD@9/9N;65D:2XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.3<Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HY.#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.CDY,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3`P.0IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(D1E
M\&5R('EO:R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C`*;7-G:60@
M(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@
M4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+6>F?\;B!Y87#]
M;&%N9/UR;6%D82!S_'+\;2!B=6QU;F%M863]+EEA</UL86YD_7)M87G]('1E
M:W)A<B#\<F5T:6XN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R.`IM
M<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN
M(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BUGIG_&X@>6%P
M_6QA;F3]<FUA;OUZ9&$@<_QR_&T@8G5L=6YA;6%D_2Y987#];&%N9/UR;6%Y
M_2!T96MR87(@_')E=&EN+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0R-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0U"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E
M;&5C="YI;F,Z.3,*;7-G:60@(DYO;F4B"FUS9W-T<B`B2&GG8FER:2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G
M:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B2&GG8FER:2`HUG)T
M_&S\(&MU;&QA;OUN*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS
M9VED(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*;7-G<W1R(")+=7IE>2!!=G)U
M<&%L_2`H25-/+3@X-3DM,3`I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").;W)F
M;VQK($ES;&%N9"(*;7-G<W1R(").;W)F;VQK($%D87/](@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B
M3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(")+=7IE>2!987+];6O\<F4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N($UA<FEA;F$@27-L86YD
M<R(*;7-G<W1R(")+=7IE>2!-87)I86YA($%D86QA<OTB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3<*;7-G:60@(DYO<G=A>2(*;7-G<W1R(").;W)V9><B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T($%F=&5R
M(@IM<V=S='(@(E-O;G)A<_UN9&$@1&7P:6PB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B3F]T($)E9F]R92(*;7-G
M<W1R("+6;F-E<VEN9&4@1&7P:6PB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HT,#@*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R(")$
M:7II;B!D9?!I;"(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<BYP:'`Z-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#,*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z
M.30*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"FUS9VED(").
M;W0@:6UP;&5M96YT960N(@IM<V=S='(@(D=E<N=E:VQE_G1I<FEL;65M:?XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8X
M"FUS9VED(").;W0@<V5T(@IM<V=S='(@(D)E;&ER=&EL;65M:?XB"@HC.B!F
M<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$T
M,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N
M<&AP.C$U.`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA
M;F1L97(N<&AP.C$W,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S
M<VEO;DAA;F1L97(N<&AP.C$X-PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L
M97(O4V5S<VEO;DAA;F1L97(N<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,3DP"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,#4@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C0X
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-C4*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,CDW"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HS,3(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,R
M.0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S8R(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HT,C(*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4P,2!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z-3<P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HU.#<@9G)A;65W;W)K+U9&4R]61E,N<&AP.C8V-0IM<V=I9"`B3F]T('-U
M<'!O<G1E9"XB"FUS9W-T<B`B1&5S=&5K;&5N;6EY;W(N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T-"!C;VYF:6<O:&]O
M:W,N<&AP+F1I<W0Z,3`P-0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,3<X"FUS9VED(").;W1E<R(*;7-G<W1R(").;W1L87(B"@HC.B!S97)V:6-E
M<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O
M=W-E+"!G;R!B86-K+B(*;7-G<W1R(")']GH@873];&%C86L@8FER_F5Y('EO
M:RP@9V5R:2!D]F[\;BXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B2V%S_6TB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#0V"FUS9VED(").=6UB
M97(B"FUS9W-T<B`B4V%Y_2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$T,C4*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(DMA
M<F%K=&5R('-A>?US_2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S
M-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,PHC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#0U('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*;7-G
M<W1R(")+;VQO;B!S87G]<_TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,S8W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C$*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,30T,R!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS
M9W-T<B`B4V%T_7(@<V%Y_7/](@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P
M96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM
M<V=S='(@(D1A\/UT_6T@;&ES=&5L97)I;FEN(&?\;F-E;&QE;FUE<VD@:>=I
M;B!N=6UA<F%L87(@8F5L:7)T:6QM96UI_BXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM<V=S='(@
M(D5V970B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.#<S"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B3F5S;F4B"@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B3V)J96-T($-R96%T
M;W(B"FUS9W-T<B`B3F5S;F4@66%R873]8_US_2(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q,#0*;7-G:60@(D]C=&%L(@IM<V=S='(@(E-E:VEZ
M;&EK(%-I<W1E;2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,3`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(D5K:6TB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R
M(@IM<V=S='(@(E-A;&3]<F=A;FS]:R!S_'IG96-I(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,R-@IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(D]F
M:7,B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G:60@
M(D]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V"B,L
M(&9U>GIY"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`B4&%R;VQA(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C0V"B,L(&9U>GIY"FUS
M9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N(@IM<V=S='(@(EEA
M;FS]_B!P87)O;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T
M<B`B56UM86XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HW,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R
M960@9F]L9&5R<RXB"FUS9W-T<B`B4V%D96-E($E-05`@<W5N=6-U;&%R_2!P
M87EL8?[];&%N(&1I>FEN;&5R:2!D97-T96ML96UE:W1E9&ER+B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@
M9F]R='5N97,B"FUS9W-T<B`B4V%D96-E('-A;&3]<F=A;B!D97EI_FQE<B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-3$@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3DW,0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@861D<F5S
M<R!A;&QO=V5D+B(*;7-G<W1R(")3861E8V4@8FER(&5L96MT<F]N:6L@<&]S
M=&$@861R97-I;F4@:7II;B!V97)I;&UE:W1E9&ER+B(*"B,Z('-E<G9I8V5S
M+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@
M;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@
M;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B
M(@HB0FER('!A>6QA_OUM_6X@<V%H:7!L:?!I;FD@=F5Y82!S86AI8FEN:2!S
M861E8V4@<VES>65M('GV;F5T:6-I<VD@=F5Y82`B"B)S86AI8FD@9&7P:?YT
M:7)E8FEL:7(N(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,S4*;7-G:60@
M(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(EEE;FD@<&5N8V5R961E
M(&'G(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR-#4*
M;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@
M9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@(D]P96Y34TP@:&%T
M87/].MUM>F%L86YM_?X@4R]-24U%('!A<N=A<_UN9&%N('9E<FD@<V7G:7`@
MY_UK873];&%M863]+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK
M(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")"=2!B8?!L86YT_7G]('EE;FD@
M<&5N8V5R961E(&'G(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS
M9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S='(@(MW^;&5T:6T@4VES=&5M
M:2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3$*;7-G:60@
M(D]P=&EO;G,B"FUS9W-T<B`B4V7G96YE:VQE<B(*"B,Z('-E<G9I8V5S+W!R
M969S+G!H<#HS,2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R("(E<R!IYVEN
M('-EYV5N96ML97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B4_UR
M86QA;FW]_B!,:7-T92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-38W"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`B2W5R=6QU
M_B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38X"FUS
M9VED(")/<F=A;FES871I;VYA;"!5;FET(@IM<V=S='(@(DMU<G5M<V%L($)I
M<FEM(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S,@IM<V=I9"`B
M3W)G86YI>FEN9R(*;7-G<W1R(")$_'IE;FQE;64B"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M
M<&QA=&4B"FUS9W-T<B`BUGIG_&X@=7EG=6QA;6$@=&%S;&'P_2(*"B,Z(&%D
M;6EN+W1E;7!L871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R
M:6=I;F%L('1E;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B)7,@:>=I;F1E:VD@
M]GIG_&X@=&%S;&%K;&%R.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE
M<B(*;7-G<W1R(")$:?!E<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3,Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-#$*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(D1I\&5R($)I
M;&=I;&5R(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,0IM<V=I
M9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B4V%H:7`@:7II;FQE<FDB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-SD*;7-G:60@(E!!
M32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")0
M04T@9&_P<G5L86UA<_T@;65V8W5T(&1E\&EL+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-0IM<V=I9"`B4$5!4CHZ
M36%I;"!B86-K96YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$R-S,*;7-G:60@(E!'4"!$:6=I=&%L(%-I9VYA='5R
M92(*;7-G<W1R(")01U`@4V%Y_7-A;"#=;7IA(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3,Q.0IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$
M871A(@IM<V=S='(@(E!'4"#>:69R96QE;FUI_B!697)I(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,W,0IM<V=I9"`B4$=0(%!U8FQI
M8R!+97DB"FUS9W-T<B`B4$=0($'G_6L@06YA:'1A<OTB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S4S"FUS9VED(")01U`@4VEG;F5D
M+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(E!'4"!I;&4@W6UZ86QA;FW]_B_>
M:69R96QE;FUI_B!697)I(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8X"FUS
M9VED(")02%`@0V]D92(*;7-G<W1R(")02%`@2V]D=2(*"B,Z(&%D;6EN+W!H
M<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(E!(4"!+
M86)U\'4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS-PIM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R("+64R!(869I9B!9
M8?!M=7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS.`IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R("+64R!38?!A;F%K;&%R
M_2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Y
M"FUS9VED(")032!3;F]W(@IM<V=S='(@(M93($MA<B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")032!3;F]W
M(%-H;W=E<G,B"FUS9W-T<B`BUE,@2V%R(%-A\&%N86ML87+](@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*(RP@9G5Z>GD*
M;7-G:60@(E!-(%-U;B(*;7-G<W1R("+64R!+87(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@5"U3=&]R
M;7,B"FUS9W-T<B`BUE,@1_9K(&?\<OQL=/QL_"!F_7)T_6YA(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C(W-`IM<V=I9"`B4$]325@@97AT96YS:6]N
M(&ES(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Y"FUS
M9VED(")07TA0(%-H96QL(@IM<V=S='(@(E!?2%`@2V%B=?!U(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM
M<V=I9"`B4&%D9&EN9R(*;7-G<W1R(")987-T_6ML86UA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDY"FUS9VED(")086MI<W1A;B(*;7-G<W1R(")086MI<W1A;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(E!A;&%U(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE
M9"(*;7-G<W1R("+=_F=A;"!%9&EL;6G^($9I;&ES=&EN($+V;&=E<VDB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3@*;7-G:60@(E!A;F%M82(*;7-G<W1R(")086YA;6$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3D*;7-G:60@(E!A<'5A($YE=R!'=6EN96$B"FUS9W-T<B`B
M4&%P=6$@665N:2!':6YE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4&%R86=U
M87DB"FUS9W-T<B`B4&%R86=U87DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G
M<W1R(")+_7-M96X@0G5L=71L=2(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34Q(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P,3@*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW-R!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT,C,*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@
M(E!A<F]L82(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HX,@IM
M<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3,R,@IM
M<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(EEA;FS]_B!P87)O
M;&$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,34R"FUS
M9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R(")2041)55,@9&_P<G5L86UA<_T@:>=I;B!P87)O;&$@
M9V5R96MM96MT961I<BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,#4S"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R
M(")/;F%Y;/T@4&%R;VQA(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.CDP"FUS9VED(")087-S=V]R9#HB"FUS9W-T<B`B4&%R;VQA.B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"FUS9VED(")087-S=V]R
M9#H@(@IM<V=S='(@(E!A<F]L83HB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3`@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`S-`HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS9VED(")087-S=V]R9',@;75S="!M
M871C:"XB"FUS9W-T<B`B4&%R;VQA;&%R(&7^;&7^;65K('IO<G5N9&%D_7(N
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Q.2!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G:60@(E!A<W1E
M(@IM<V=S='(@(EEA</W^=/UR(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A
M<F0B"FUS9W-T<B`B4&%N;V1A;B!Y87#]_G3]<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS
M9W-T<B`B66]L(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI
M;F,Z,B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C<*
M;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`B0F5K;&5Y96X@W'EE
M;&EK;&5R.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-`IM<V=I9"`B
M4&5O<&QE(@IM<V=S='(@(MUN<V%N;&%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*;7-G:60@(E!E<F-E;G0B"FUS
M9W-T<B`B6?QZ9&4B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E
M;F%N8V4N:'1M;#HT.0IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R
M871I;VYS(@IM<V=S='(@(D)A:_UM(-W^;&5M;&5R:6YI($=E<N=E:VQE_G1I
M<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,#8*;7-G:60@(E!E<F9O
M<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`B
M0F%K_6T@:?YL96UL97)I(&=I<FG^=&4@9V5RYV5K;&7^=&ER:6QS:6X@;6D_
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@
M(E!E<FUI<W-I;VXB"FUS9W-T<B`BW7II;B(*"B,Z(&%D;6EN+W!E<FUS+V1E
M;&5T92YP:'`Z-3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E!E<FUI
M<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R("+=>FEN("<E<R<@
M<VEL:6YE;65D:2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X
M-@HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`B
MW7II;B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38Q(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38T"B,L(&9U>GIY"FUS9VED
M(")097)M:7-S:6]N<R(*;7-G<W1R(")?2&%K;&%R(@H*(SH@861M:6XO<&5R
M;7,O961I="YP:'`Z,3`Y(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,`HC
M.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@861M:6XO<&5R;7,O9&5L971E
M+G!H<#HU.`IM<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VXB"FUS
M9W-T<B`BW7II;B!9]FYE=&EM:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV-0IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`B2VG^
M:7-E;"!":6QG:6QE<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G
M<W1R(")097)U(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED
M(")0971S(@IM<V=S='(@(D5V8VEL($AA>79A;FQA<B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M.0IM<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B1FEL:7!I;FQE<B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G
M:60@(E!H;VYE(@IM<V=S='(@(E1E;&5F;VXB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#<X"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B1F]T;_!R
M869L87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0:71C86ER;B(*;7-G<W1R
M(")0:71C86ER;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T<B`B4F5S:6T@0FER
M:6UI(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS9VED(")0;&%T
M:71U9&5S(@IM<V=S='(@(D)E>6QI:R!3]GIL97(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0
M;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B3/QT9F5N(&)I
M<FMAYR!H_&-R97EE('3]:VQA>?UN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@
M8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z
M(@IM<V=S='(@(DS\=&9E;B!B=2#V\&5Y:2#G_6MA<FUA:R!I<W1E9&GP:6YI
M>FD@9&_P<G5L87G];CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L96%S92!C;VYF:7)M
M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T
M<B`B3/QT9F5N(&)U(/;P96YI;B!B8?#];OT@Y_9Z;65K(&ES=&5D:?!I;FEZ
M(&1O\')U;&%Y_6XN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4W
M,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS
M9W-T<B`B3/QT9F5N(&)I<B!A>2!V92!B:7(@>?UL(&=I<FEN+B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C$R"FUS9VED
M(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*
M;7-G<W1R("),_'1F96X@>65N:2!K871E9V]R:6YI;B!A9/UN_2!G:7)I;CHB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`Q"FUS9VED(")0;&5A
M<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R("),_'1F96X@
M9V7G97)L:2!B:7(@25`@861R97-I(&=I<FEN+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(V-C`*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED
M(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N
M(@IM<V=S='(@(DS\=&9E;B!G9>=E<FQI(&)I<B!G_&X@9VER:6XL(&%Y9&%K
M:2!G_&X@<V%Y_7/];OT@:V]N=')O;"!E9&EN+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(T-3$*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED
M('1I;64N(@IM<V=S='(@(DS\=&9E;B!G9>=E<FQI(&)I<B!Z86UA;B!G:7)I
M;BXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED
M(")0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM
M<V=S='(@(DS\=&9E;B!S;W)U;G5N(&)I<B#V>F5T:6YI('EA</UN+B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R
M;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B3/QT9F5N(&MU;&QA;OUC_2!A
M9/T@=F4@<&%R;VQA;OUZ_2!G:7)I;B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<#HU.`HC+"!F=7IZ>0IM<V=I9"`B(@HB4&QE87-E(')E860@=&AE
M(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M
M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B(@HB3/QT9F5N(&UE
M=&YI(&]K=7EU;BX@4VES=&5M:2!K=6QL86YA8FEL;65K(&GG:6X@:W5L;&%N
M_6T@:V_^=6QL87+];OT@2T%"54P@(@HB971M96L@>F]R=6YD87/];OUZ+B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP
M.C<P"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z
M(@IM<V=S='(@(DS\=&9E;B!Y96YI(&MA=&5G;W)I;FD@863](&=I<FEN.B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&]L86YD(@IM<V=S='(@(E!O;&]N>6$B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S
M(@IM<V=S='(@(E!O;&ET:6MA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0X-PIM<V=I9"`B4&]L;',B"FUS9W-T<B`B3WEL86UA;&%R(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,0IM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B4&]R=&5K:7HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R
M-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B
M"FUS9W-T<B`B1_9R_&YT_"!K;VYU;6QA;F3]<OUL_7EO<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0
M;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(L=I>F5L9V4@:V]N
M=6UL86YD_7+];/UY;W(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T
M(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(D)U(&1I>FEN92!G]FYD97(@
M*$E-05`@=&%R86;];F1A;B!Z;W)L86YM86UA:W1A9/UR*2(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C8V(&QI8B]";&]C:R]M971A<BYP:'`Z,C<Q"B,L
M('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@
M:&]U<BAS*3H@(@IM<V=S='(@(E-O;B`E<R!S86%T=&4@9/S^96X@>6'P;75R
M('9E(&MA<B!M:6MT87+].B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.3@*;7-G:60@(E!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+VQD87`N<&AP.CDX
M"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(E!R969S7VQD87`Z(-US=&5N96X@3$1!4"!U
M>F%N=/US_2!B=6QU;F%M863]+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@4F5Q=6ER
M960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F
M<U]S97-S:6]N.B#=<W1E;F5N(&]T=7)U;2!U>F%N=/US_2!B=6QU;F%M863]
M+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(U"FUS9VED(")0<F5S<W5R
M92(*;7-G<W1R(")"87/];N<B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U
M.0IM<V=I9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B1&5N
M:7H@<V5V:7EE<VEN9&5K:2!B87/];N<Z(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(S-0IM<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R(")"
M87/];N<Z(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(P-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R979I97<B"FUS9W-T<B`BUFYI
M>FQE;64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C0*;7-G:60@(E!R979I97<@=&AE(&EM86=E(&EN
M(&$@;F5W('=I;F1O=R(*;7-G<W1R(")']G+\;G3\>?P@>65N:2!P96YC97)E
M9&4@]FYI>FQE(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS
M-C(@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C8*;7-G:60@(E!R
M979I;W5S(&]P=&EO;G,B"FUS9W-T<B`BUFYC96MI('-EYV5N96ML97(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0Q"FUS
M9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R(")"96QG97EI('EA>F3]<B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B
M4')I=F%T92!+97DB"FUS9W-T<B`BUGIE;"!!;F%H=&%R(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V.0IM<V=I9"`B4')O8FQE;2(*
M;7-G<W1R(")3;W)U;B(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-@IM
M<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R(")3;W)U;B!486[]
M;6QA;6%S_2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-CD*;7-G
M:60@(E!R;VIE8W1S(@IM<V=S='(@(E!R;VIE;&5R(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C$Q,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,3@X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#4*;7-G:60@(E!R
M;VUP="!T97AT(@IM<V=S='(@(DUE=&EN(&)I;&=I(&ES=&5M:2(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4'5B;&EC
M($ME>2(*;7-G<W1R(")!Y_UK($%N86AT87(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!!;&=O
M<FET:&TB"FUS9W-T<B`B0>?]:R!!;F%H=&%R(&%L9V]R:71M87/](@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#0*(RP@9G5Z>GD*
M;7-G:60@(E!U8FQI8R!+97D@26YF;R(*;7-G<W1R(")!Y_UK($%N86AT87(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HR-#$*;7-G:60@
M(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S
M9G5L;'DN(@IM<V=S='(@(D'G_6LOUGIE;"!A;F%H=&%R(&EK:6QI<VD@8F'^
M87+]>6QA('EA<F%T_6QA;6%D_2XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0
M=65R=&\@4FEC;R(*;7-G<W1R(")0;W)T;R!2:6MO(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,@IM<V=I9"`B46%T87(B"FUS9W-T<B`B2V%T87(B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z-C,*;7-G:60@(E%U97)Y(@IM<V=S='(@(E-O<F=U(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"B,L(&9U>GIY"FUS9VED(")1=6]T
M82(*;7-G<W1R(")+871A<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C8S"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@
M2V5Y("@E9"!B:70I(@IM<V=S='(@(E)302!!Y_UK($%N86AT87+]("@E9"!B
M:70I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-`IM<V=I9"`B
M4F%D:6\@<V5L96-T:6]N(@IM<V=S='(@(E)A9'EO(%-EYVEM:2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0S"FUS9VED(")2
M86EN(@IM<V=S='(@(EEA\&UU<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@
M(D5R:V5N(%-A871L97)D92!98?!M=7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I;B!,871E(@IM<V=S
M='(@(D=EYR!386%T;&5R9&4@66'P;75R(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E)A:6X@4VAO=V5R(@IM
M<V=S='(@(E-A\&%N86L@66'P_?XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT-PIM<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G
M<W1R(")98?!M=7(@=F4@2V%R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R
M(")+87)A(&3V;OS^96-E:R!Y8?!M=7(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U;F4B"FUS9W-T<B`B4F%S=&=E
M;&4@1&5Y:?XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*
M;7-G:60@(E)A=&EO(@IM<V=S='(@(D]R86XB"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$Q-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A9"(*;7-G<W1R(")/
M:W5M82(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C@W"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@(MUL971I;&5R:2!/
M:W4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R
M871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@HB4VEL;65K(&ES
M=&5D:?!I;FEZ92!G97+G96MT96X@96UI;B!M:7-I;FEZ/RA"=2!I_FQE;2!G
M97)I(.=E=G)I;&5M97HI.B5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M8VQE87(N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V
M92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO
M="!B92!U;F1O;F4N(@IM<V=S='(@(B(*(DMU;&QA;OUC_2`E<R!E(&%I="!K
M=6QL86[]8_T@=F5R:6QE<FEN:2!S:6QM96L@:7-T961I\&EN:7IE(&5M:6X@
M;6ES:6YI>BX@0G4@(@HB:?YL96T@9V5R:2#G979R:6QE;65Z+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@
M(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(E-O;B!E>6QE;6D@
M=&5K<F%R;&$B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")2969R97-H
M($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B1&5V:6YG96X@365N
M_"#6\&5L97)I;FD@5&%Z96QE.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-#$*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(E!O
M<G1A;"!']G+\;OQM_&[\(%1A>F5L93HB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HX.30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,PHC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,U"FUS9VED(")296=E>"(*;7-G
M<W1R(")$_'IE;FQI(-UF861E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S(T.0IM<V=I9"`B4F5L871I;VYS:&EP($)R;W=S97(B"FUS9W-T<B`B
MW6QI_FMI(%1A<F%Y_6/](@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`HC+"!F=7IZ
M>0IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(D]K=6UA(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,C8*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B0>?]:VQA
M;6%L87(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$T"FUS9VED(")2
M96UO=&4@4V5R=F5R<R(*;7-G<W1R(")5>F%K=&%K:2!3=6YU8W5L87(B"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T
M92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R
M(")5>F%K=&%K:2!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I
M.B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,PIM<V=I9"`B4F5M;W9E
M(@IM<V=S='(@(E-I;"(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN
M8SHQ,0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@(M9B9?!I(%-I;"(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU-3<*
M;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B2V]L;VYU(%-I;"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*;7-G
M:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(D)IYVEM;&5M97EI(%-I
M;"(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(X"FUS9VED(")2
M96UO=F4@<&%I<B(*;7-G<W1R(")):VEL:7EI(%-I;"(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HR,#(*;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@
M9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R(")+
M87ED961I;&UI_B!B971I\&D@<W5N=6-U;G4@9V7G:6-I(&1I>FEN:6YD96X@
M<VEL+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHT,@IM<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R(")3:6PB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3`*;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C
M=6UE;G0B"FUS9W-T<B`B0G4@<&%RYV%Y_2!B96QG961E;B#G_6MA<G0B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$Q"FUS9VED(")2
M96UO=F4@=7-E<B(*;7-G<W1R(")+=6QL86[]8_T@4VEL(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHU"B,L('!H<"UF;W)M870*;7-G
M:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R(")+=6QL86[]8_UY_2!S:6PZ
M("5S(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ,S@*;7-G
M:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R
M<F]R8V]D93H@(@IM<V=S='(@(MUS=&5K(&-E=F%P;&%N86UA9/TN1/9N_&QE
M;B!H871A(&MO9'4Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-3<*(RP@9G5Z>GD*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD
M(&YO="!B92!F;W5N9"XB"FUS9W-T<B`B6?QK;&5N96X@9&]S>6$@:V%Y9&5D
M:6QE;65D:2XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-"!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@
M)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B1V5R96ME;B`G)7,G("5S('EA
M</UL86YD_7)M87/];F1A(&)E;&ER=&EL;65M:?XN(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HV-S4@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HX,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R,PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO
M="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D=E
M<F5K96X@)R5S)R!61E,@>6%P_6QA;F3]<FUA<_UN9&$@8F5L:7)T:6QM96UI
M_BXB"@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW.#$*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF
M:65D(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D=E<F5K96X@)R5S)R!Y
M87#];&%N9/UR;6%D82!B96QI<G1I;&UE;6G^+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I9"`B4F5Q=6ER960@1FEE
M;&0B"FUS9W-T<B`B1V5R96ME;B!!;&%N(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,S$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Y"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,R,"!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z,3`P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(E1E;6EZ;&4B"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B4F5S970@4&%S<W=O
M<F0B"FUS9W-T<B`B4&%R;VQA>?T@<_UF_7)L82(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C(W"FUS9VED(")297-E="!9;W5R(%!A<W-W;W)D
M(@IM<V=S='(@(E!A<F]L86[]>OT@<_UF_7)L87G];B(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,S`*(RP@9G5Z>GD*;7-G:60@(E)E<W1O<F4@3&%S="!1
M=65R>2(*;7-G<W1R("+>:?YK:6X@07DB"@HC.B!A9&UI;B]P:'!S:&5L;"YP
M:'`Z-S$@861M:6XO8VUD<VAE;&PN<&AP.C(X(&%D;6EN+W-Q;'-H96QL+G!H
M<#HV-@IM<V=I9"`B4F5S=6QT<R(*;7-G<W1R(")3;VYUYVQA<B(*"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S
M+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B
M4V7G96YE:VQE<F4@1/9N_&XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z,S@*(RP@9G5Z>GD*;7-G:60@(E)E='EP92!N97<@<&%S<W=O<F0B
M"FUS9W-T<B`B4&%R;VQA>?T@<_UF_7)L82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G
M:60@(E)E=6YI;VXB"FUS9W-T<B`B4F5U;FEO;B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`IM<V=I
M9"`B4F5V97)T($-O;F9I9W5R871I;VXB"FUS9W-T<B`B66%P_6QA;F3]<FUA
M>?T@1V5R:2!$]FYD_'(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,R
M"FUS9VED(")2:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`B6F5N
M9VEN($UE=&EN($3\>F5N;&5Y:6-I<VD@4V7G96YE:VQE<FDB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B
M0FEL;65C96QE<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW,`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`B4V'P(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,0IM<V=I9"`B4FEG:'0@
M:&5A9&5R(@IM<V=S='(@(E-A\"!B8?YL_6L@8FEL9VES:2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3<*;7-G:60@(E)I9VAT('9A;'5E<R(*
M;7-G<W1R(")$;_!R=2!D9?!E<FQE<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?=R!0
M<F]P97)T:65S+BXN(@IM<V=S='(@(E-A7W3]<B#6>F5L;&EK;&5R:2XN+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,S0*
M;7-G:60@(E)O;&4B"FUS9W-T<B`B1_9R978B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS
M9VED(")2;VUA;FEA(@IM<V=S='(@(E)O;6%N>6$B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(U"FUS9VED(")2;W1A=&4@
M,3@P(@IM<V=S='(@(C$X,"!D97)E8V4@9/9N9/QR(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,@IM<V=I9"`B4F]T871E
M($QE9G0B"FUS9W-T<B`B4V]L82!$]FYD_'(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(X"FUS9VED(")2;W1A=&4@4FEG
M:'0B"FUS9W-T<B`B4V'P82!$]FYD_'(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@4')O
M<&5R=&EE<R(*;7-G<W1R(")3873]<B#6>F5L;&EK;&5R:2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G
M:60@(E)O=R!P<F]P97)T:65S(@IM<V=S='(@(E-A=/UR(/9Z96QL:6ML97)I
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#$*;7-G:60@(E)O=W,Z(@IM<V=S='(@(E-A=/UR;&%R.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G
M:60@(E)U;&5S(@IM<V=S='(@(L=I>F=I;&5R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,`IM<V=I9"`B4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(*
M;7-G<W1R("+':7IG:6QE<B!T_&T@<V%T_7(@=F4@:V]L;VYL87(@87)A<_UN
M9&$@8F5L:7)E8V5K=&ER(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E
M87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`BQVEZ9VEL97(@<V%D
M96-E(&MO;&]N;&%R(&%R87/];F1A(&)E;&ER96-E:W1I<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G
M:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S
M='(@(L=I>F=I;&5R('-A9&5C92!S873]<FQA<B!A<F%S_6YD82!B96QI<F5C
M96MT:7(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P"FUS9VED(")2=6XB
M"FUS9W-T<B`BQV%L_?YT_7(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S
M:6%N($9E9&5R871I;VXB"FUS9W-T<B`B4G5S>6$@1F5D97)A<WEO;G4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`S"FUS9VED(")2=V%N9&$B"FUS9W-T<B`B4G5A;F1A(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@
M(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R(")3+TU)
M344@WFEF<F5L96UE(-UM>F%S_2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,S(S"FUS9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A
M9V4B"FUS9W-T<B`B4R]-24U%(&EL92#>:69R96QE;FUI_B#=;&5T:2(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#$*;7-G:60@(E-!4TP@
M875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B4T%3
M3"!D;_!R=6QA;6%S_2!M979C=70@9&7P:6PN(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C4P-`IM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R
M(")335,@365S86IL8?YM82(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM
M<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(E-13"!+86)U\'4B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@S"FUS9VED(")344P@<W1A=&5M96YT
M(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT,S$*;7-G:60@(E-32"(*;7-G<W1R(")34T@B"@HC
M.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(D)!WD%2
M24Q)(@H*(SH@;&EB+V%P:2YP:'`Z,34S"FUS9VED(")37U%,(%-H96QL(@IM
M<V=S='(@(E-?44P@2V%B=?!U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`B0W1S(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@(E-A
M:6YT($AE;&5N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@
M86YD($YE=FES(@IM<V=S='(@(E-A:6YT($MI='1S('9E($YE=FES(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,SD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@W"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R(")386EN="!,
M=6-I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@
M36EQ=65L;VXB"FUS9W-T<B`B4V%I;G0@4&EE<G)E('9E($UI<75E;&]N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-0IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R
M96YA9&EN97,B"FUS9W-T<B`B4V%I;G0@5FEN8V5N="!V92!'<F5N861I;F5S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(D%Y;OT@YV5R
MYV5V92`H:V5N7V1I<VDI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B4V%M;V$B
M"FUS9W-T<B`B4V%M;V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")386X@36%R
M:6YO(@IM<V=S='(@(E-A;B!-87)I;F\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED
M(")386\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B4V%O(%1O;64@=F4@
M4')I;F-I<&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y
M"FUS9VED(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B57ED=2!38?!L
M87G]8_TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3875D:2!!<F%B:6$B"FUS
M9W-T<B`B4W5U9&D@07)A8FES=&%N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L
M87EO=70N:6YC.CDX"FUS9VED(")3879E(@IM<V=S='(@(DMA>61E="(*"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#4*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(DMA>61E
M="`E<R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V"B,L('!H
M<"UF;W)M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`B2V%Y9&5T("5S(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I
M;VYS(@IM<V=S='(@(E-EYV5N96ML97)I($MA>61E="(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-C<*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O
M;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@
M=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB3VQU_G1U<G5L
M86X@>6%P_6QA;F3]<FUA>?T@4$A0(&)E=&GP:2!O;&%R86L@<W5N=6-U;G5N
M(&=EYVEC:2!D:7II;FEN92`B"B)K87ED970N(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@)7,@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B)7,@>6%P_6QA;F3]<FUA<_T@:V%Y
M9&5D:6QD:2XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B07EA<B!G_&YC96QL96UE(&)E
M=&GP:2!K87ED961I;&1I.B`G)7,G+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"B,L(&9U>GIY"FUS9VED(")38V%T=&5R
M960@5"U3=&]R;7,B"FUS9W-T<B`B66%L_73];&W]_B!G]FL@9_QR_&QT_&S\
M(&;]<G3];F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@
M(E-C:65N8V4B"FUS9W-T<B`B0FEL:6TB"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN
M8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(D%R86UA(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,R,`IM<V=I9"`B4V5A<F-H($5N9VEN97,B
M"FUS9W-T<B`B07)A;6$@36]T;W)L87+](@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,CDW,PIM<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S='(@(D1O
M<WEA;&%R_2!39><B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#@T"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(D)I
M<B!T87)I:"!S9>=I;B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3DX"FUS9VED(")396QE8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B16ML
M96UE:R!IYVEN(&)I<B!G<G5P('-EYVEN(@H*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S
M='(@(EEE;FD@<V%H:6)I('-EYVEN(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C8P"FUS9VED(")396QE8W0@82!S97)V97(B"FUS9W-T<B`B
M0FER('-U;G5C=2!S9>=I;B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,34V"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*;7-G<W1R(")%
M:VQE;65K(&GG:6X@8FER(&MU;&QA;OUC_2!S9>=I;B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-S<*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!A;&PB"FUS9W-T<B`B1&]S>6%L87+](%-EYR(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C,*;7-G:60@(E-E;&5C="!A;&P@
M9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R(")"_'3\;B!T87)I:"!B:6QE_F5N
M;&5R:6YI('-EYVEN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C@W,PIM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R
M(")":7(@;F5S;F4@<V7G:6XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-C<X"B,L(&9U>GIY"FUS9VED(")396QE8W0@;F]N
M92(*;7-G<W1R(")996YI('-A:&EB:2!S9>=I;B(*"B,Z('-E<G9I8V5S+VME
M>6)O87)D+G!H<#HS-PIM<V=I9"`B(@HB4V5L96-T('1H92!C:&%R86-T97)S
M('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@
M8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N(@IM
M<V=S='(@(B(*(MUS=&5D:?!N:7H@:V%R86MT97)L97)I(&'^8?#]9&%K:2!K
M=71U;&%R9&%N('-EYVEN+B!$86AA('-O;G)A(&UE=&EN("(*(F%L86[];F1A
M;B!K;W!Y86QA>?UP('EA</W^=/UR86)I;&ER<VEN:7HN(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D
M96QI;6ET97(Z(@IM<V=S='(@(E1A<FEH('/];OUR;&%Y_6/]<_UN_2!S9>?]
M;CHB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-`IM<V=I9"`B4V5L
M96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`B5&%R:6@@8FGG:6UI;FD@
M<V7G:6XZ(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN
M8SHY,`IM<V=I9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C
M:&%N9V4Z(@IM<V=S='(@(D1E\&G^=&ER;65K(&ES=&5D:?!I;FEZ(&MI;6QI
M\&D@<V7G:6XZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,38*;7-G
M:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S='(@(E-A870@
M<_UN_7)L87G]8_US_6[]('-EYVEN.B(*"B,Z('1E;7!L871E<R]D871A+W1I
M;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE('1I;64@9F]R;6%T.B(*;7-G
M<W1R(")386%T(&)IYVEM:6YI('-EYVEN.B(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE
M;&1S+B(*;7-G<W1R(")%_FQE_F5N(&EK:2!A;&%N_2!S9>=I;BXB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`V"FUS9VED(")396QE8W0@>6]U<B!C
M;VQO<B!S8VAE;64N(@IM<V=S='(@(E)E;FL@9/QZ96YI;FEZ:2!S9>=I;BXB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0X"FUS9VED(")396QE8W0@
M>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(E1E<F-I:"!E='1I
M\&EN:7H@9&EL:2!S9>=I;CHB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R
M(")3;W)U;B!287!O<G4@1_9N9&5R(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$P,SD*;7-G:60@(E-E;F0@4TU3(@IM<V=S
M='(@(E--4R!']FYD97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")396YE9V%L
M(@IM<V=S='(@(E-E;F5G86PB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q
M-@IM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`B06QG_6QA>?UC_3HB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Y"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I9"`B
M4V5P=&5M8F5R(@IM<V=S='(@(D5Y;/QL(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N
M96=R;R(*;7-G<W1R(")3_7)B:7-T86X@=F4@36]N=&5N96=R;R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`Q"FUS9VED(")397)I
M86P@3G5M8F5R(@IM<V=S='(@(E-E<FD@3G5M87)A<_TB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Q"B,L(&9U>GIY"FUS9VED(")397)V
M97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")(879A
M(')A<&]R=2#V8F7P:2!K=6QL86[];&%B:6QI<B!D9?!I;"XB"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(E-E<W-I;VX@061M
M:6XB"FUS9W-T<B`BW7II;B!9]FYE=&EM:2(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@IM<V=I9"`B4V5S<VEO
M;B!)1"!E>'!I<F5D+B(*;7-G<W1R(")/='5R=6T@:VEM;&GP:6YI;B!S_')E
M<VD@9&]L9'4N(@H*(SH@;&EB+V%P:2YP:'`Z,30U"B,L(&9U>GIY"FUS9VED
M(")397-S:6]N<R(*;7-G<W1R(")?2&%K;&%R(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,Q-`IM<V=I9"`B4V5T(@IM<V=S='(@(D)E;&ER="(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-@IM<V=I9"`B4V5T(&]P=&EO
M;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U
M(&5V97(@9F]R9V5T(&ET+B(*;7-G<W1R("(B"B)087)O;&%N_7K];OT@=6YU
M='5R<V%N_7H@<_UF_7)L86UA;OUZ82!I>FEN('9E<F5C96L@<V7G96YE:VQE
M<FD@8F5L:7)T:6XN("(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*
M;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O
M(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R(")5;&'^;6%K(&ES
M=&7P:6YI>B!U>F%K=&%K:2!S=6YU8W5L87+](&)E;&ER;&5Y:6XN(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T"FUS9VED(")3970@>6]U<B!P<F5F
M97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM
M<V=S='(@(E1E<F-I:"!E='1I\&EN:7H@9&EL+"!S86%T(&1I;&EM:2!V92!T
M87)I:"!S9>=E;F5K;&5R:6YI(&)E;&ER;&5Y:6XN(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDX"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P(&%P
M<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD
M(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B(@HB0F'^;&%N
M9_WG('5Y9W5L86UA;OUZ_2P@<F5N:R!D_'IE;FEN:7II+"!S87EF82!T87IE
M;&5M92P@=F4@9&GP97(@9_9R_&YT_"`B"B)S9>=E;F5K;&5R:6YI(&)E;&ER
M;&5Y:6XN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0IM<V=I9"`B
M4V5T=7`B"FUS9W-T<B`B07EA<FQA<B(*"B,Z('1E;7!L871E<R]A9&UI;B]S
M971U<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3971U<"!U<&=R861E('-C<FEP
M=',@879A:6QA8FQE(@IM<V=S='(@(DMU<G5L=6T@9_QN8V5L;&5M92!B971I
M:VQE<FD@:W5L;&%N_6QA8FEL:7(@9'5R=6UD82XB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,3@V"FUS9VED(")3979E<F%L(&QO8V%T:6]N
M<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*;7-G<W1R(")$9?!I
M_G1I<F=E(&EL92!B:7)D96X@9F%Z;&$@>65R(&W\;6O\;CH@(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-`IM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R(")397G^96PB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DV"FUS9VED(")3:&]P<&EN
M9R(*;7-G<W1R(")!;/W^('9E<FG^(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z-#,*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`B
M2_US82#6>F5T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T-@IM<V=I
M9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN
M:W,_(@IM<V=S='(@(L=O\'4@8F'P;&%N=/T@:>=I;B!E<FG^:6T@86YA:'1A
M<OT@=&%N_6UL86YS_6X@;?T_(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`B1_9S=&5R(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U-0IM<V=I9"`B(@HB4VAO=R!D
M:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE
M=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B)(
M86QE;B!K87G]=&S](&]L86X@>6%P_6QA;F3]<FUA(&EL92!Y96YI('EA<F%T
M_6QA;B!Y87#];&%N9/UR;6$@87)A<_UN9&%K:2`B"B)F87)K;&%R_2!G]G-T
M97(N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y,`IM<V=I9"`B4VAO
M=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R(")'
M:7)I_G1E(&5N('-O;B!G:7)I_B!T87)I:&D@9_9S=&5R:6QS:6X@;6D_(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V-0IM<V=I9"`B4VAO=R!O
M<'1I;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R("+6>F?\;B!O;&%N_2!S
M86ML86UA('-EYV5N9?!I;FD@9_9S=&5R(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C@Q,PIM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B4V7G
M:6-I>6D@9_9S=&5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R-@IM
M<V=I9"`B4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R
M("+':7IE;&=E(&G^;&5M;&5R:2!M96[\(.=U8G7P=6YD82!G]G-T97)I;'-I
M;B!M:3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Y"B,L('!H<"UF
M;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM
M<V=S='(@(B5S($UE;OQS_"!S;VQD82!G]G-T97)I;'-I;B!M:3\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L
M;V<B"FUS9W-T<B`B5&%B;&\@2/QC<F4@UGIE;&QI:VQE<FD@2W5T=7-U;G4@
M9_9S=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L92!0<F]P97)T
M:65S(&1I86QO9R(*;7-G<W1R(")486)L;R#6>F5L;&EK;&5R:2!+=71U<W5N
M=2!G]G-T97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%)O=R!0
M<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")486)L;R!3873]<B#6>F5L;&EK
M;&5R:2!+=71U<W5N=2!G]G-T97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G:60@(E-H;W<@=&AE
M(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(D?V<OQN=/P@]GIE
M;&QI:VQE<FD@:W5T=7-U;G4@9_9S=&5R(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3<V,PIM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T<B`B6?QK
M;&5M97EI(&?V<W1E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4P"FUS9VED(")3:&]W97)S(@IM<V=S='(@(E-A\&%N86LB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,0IM
M<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R(")%<FME;B!386%T;&5R9&4@
M4V'P86YA:R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4R"FUS9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B1V7G(%-A871L
M97)D92!38?!A;F%K(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM
M<V=S='(@(L=E=G)E9&4@4V'P86YA:R(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C0X,`IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(DO\
MY_QL="(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<W
M-"!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HX,S8*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3(R(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.CDX-`HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HQ,#0W(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C$P.#<*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z,3$Q-B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ
M,30Y"FUS9VED(")3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH
M<RD@;W5T(&]F('1H92!W87D@9FER<W0B"FUS9W-T<B`BW6QK(&]L87)A:R!K
M;VW^=2#V\&5L97(@:_SG_&QT<_QN('EA9&$@=&'^_6YS_6XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`U"FUS9VED(")3:65R<F$@3&5O;F4B"FUS9W-T<B`B4VEE<G)A($QE
M;VYE(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V-0IM
M<V=I9"`B4VEG;B!U<"(*;7-G<W1R("+<>64@;VPB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM<V=I9"`B4VEG;F%T=7)E(@IM
M<V=S='(@(MUM>F$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C<Q,0IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R("+=
M;7IA($%L9V]R:71M87/](@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P
M;W)E(@IM<V=S='(@(E-I;F=A<'5R(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV-2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DV"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R,34@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(S-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0V(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S`*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S$R,PIM<V=I9"`B4VEZ92(*;7-G<W1R(")";WEU="(*"B,Z('1E
M;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4R"FUS9VED
M(")3:VEP($UA:6YT96YA;F-E(@IM<V=S='(@(D)A:_UM_2!!=&QA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B4VQO=F%K>6$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V96YI82(*;7-G<W1R(")3;&]V
M96YY82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4T"FUS9VED(")3;F]W(@IM<V=S='(@(DMA<B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3;F]W(%-H;W=E
M<B(*;7-G<W1R(")+87(@4V'P86YA\/TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R!3:&]W97)S(@IM
M<V=S='(@(DMA<B!38?!A;F%K;&%R_2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS9VED(")3;F]W(%-H;W=E<G,@16%R
M;'DB"FUS9W-T<B`B17)K96X@4V%A=&QE<F1E($MA<B!38?!A;F%K;&%R_2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS
M9VED(")3;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R(")'9><@4V%A=&QE<F1E
M($MA<B!38?!A;F%K;&%R_2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<X
M"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B2V%R($1E<FEN;&GP:3H@
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#(*;7-G:60@(E-N;W<@97%U
M:79A;&5N="!I;B!W871E<CH@(@IM<V=S='(@(EEA\&%N(&MA<OUN('-U(&7^
M:71I.B`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3;VQO;6]N($ES;&%N9',B
M"FUS9W-T<B`B4V]L;VUO;B!!9&%L87+](@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I
M9"`B4V]M86QI82(*;7-G<W1R(")3;VUA;&DB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`BWF%R
M:_UL87(@)B#>:6ER;&5R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,CDR-@IM<V=I9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`B4_UR
M86QA;6$@9/QZ96YI('-EYVEM:2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Q-PHC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-#<*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-C8*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.#D*;7-G:60@(E-O=7)C92!A
M9&1R97-S(@IM<V=S='(@(DMA>6YA:R!A9')E<VDB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X
M"FUS9VED(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`B1_QN97D@069R:6MA(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@(E-O=71H($5U<F]P
M96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R(")'_&YE>2!!=G)U<&$@*$E33RTX
M.#4Y+3,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")3;W5T:"!'96]R9VEA(&%N
M9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R(")'_&YE>2!'
M96]R9VEA('9E($?\;F5Y(%-A;F1W:6-H($%D86QA<OTB"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3
M;W5T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(D?\;F5Y(%EA<OUM:_QR92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S
M"FUS9VED(")3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@
M(D)I=&G^:6L@:/QC<F5L97(@87)A<_UN9&%K:2!B;_YL=6LB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B
M4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G
M<W1R(")(_&-R961E:VD@<_UN_7(@=F4@:>=E<FEK(&%R87/];F1A:VD@8F_^
M;'5K(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#$U"FUS9VED(")3
M<&%C97(B"FUS9W-T<B`B0F_^;'5K($%Y87)L87G]8_TB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4U"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*;7-G:60@
M(E-P86-I;F<B"FUS9W-T<B`B07)A;/UK(&+]<F%K;6$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED
M(")3<&%C:6YG(&%N9"!P861D:6YG(@IM<V=S='(@(D%R86S]:R!B_7)A:VUA
M('9E('EA<W3]:VQA;6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B4W!A:6XB"FUS
M9W-T<B`BW7-P86YY82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY
M.`IM<V=I9"`B4W!A;2(*;7-G<W1R("+=<W1E;FUE>65N(-UL971I(@H*(SH@
M<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C:6%L($-H87)A
M8W1E<B!);G!U="(*;7-G<W1R("+6>F5L($MA<F%K=&5R($=I<FG^:2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C(*;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`B2/QC<F5Y:2!B]FPB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8V"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B2V]L;VYU(&+V;"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*;7-G<W1R(")3873]<OT@8O9L(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Q"FUS9VED(")3<&]R=',B"FUS
M9W-T<B`B4W!O<FQA<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,30Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I($QA;FMA
M(@IM<V=S='(@(E-R:2!,86YK82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HW,R!L:6(O0FQO8VLO;65T87(N<&AP.C<T"FUS9VED(")3=&%N
M9&%R9"(*;7-G<W1R(")3=&%N9&%R="(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(E5Z87D@66]L=2(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.38@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@P.0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R(")"
M8?YL86YG_><@>?UL_2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3<P"FUS9VED(")3=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R(")%
M>6%L970@=F5Y82#=;"(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E
M>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B1'5R=6TB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$U"FUS9VED(")3=&]R86=E(&9O
M<FUA="(*;7-G<W1R(")$97!O;&%M82!B:>=I;6DB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,@IM<V=I9"`B4W1R965T($%D9')E
M<W,B"FUS9W-T<B`B4V]K86L@061R97-I(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G
M:"(*;7-G<W1R("+<<W3\(.=I>F=I;&DB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C,S"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R(")$:7IG
M:2!L:7-T97-I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,PIM
M<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`B
M061R97-T96X@86QA;B!A9/UN_2#G_6MA<G0B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(S"FUS9VED(")3='EL
M92!;0U-372(*;7-G<W1R(")3:71I;"!;0U-372(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@(E-U(@IM<V=S
M='(@(E!Z<B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS-PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N;W0@
M9F]U;F0N(@IM<V=S='(@(D%L=&1I>FEN("<E<R<@8G5L=6YA;6%D_2XB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S"FUS
M9VED(")3=6)J96-T(@IM<V=S='(@(DMO;G4B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,S(@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP
M:'`Z,S$W"FUS9VED(")3=6)M:70B"FUS9W-T<B`B1_9N9&5R(@H*(SH@<VEG
M;G5P+G!H<#HT.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B
M;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9
M;W4@8V%N(&YO="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B
M965N(&%P<')O=F5D+B(*;7-G<W1R("(B"B(G)7,G(&EN('-I<W1E;64@96ML
M96YM97-I(&ES=&7P:6YI>B!G]FYD97)I;&1I+B#=<W1E\&EN:7H@;VYA>6QA
M;F$@:V%D87(@(@HB9VER:?X@>6%P86UA>G/];OUZ+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C
M<FEP="(*;7-G<W1R(")!;'1S:6UG92(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,#0*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R
M(")"8?YA<OTB"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T
M:&4@<WES=&5M+B(*;7-G<W1R("(G)7,G(&)A_F%R_7EL82!S:7-T96UE(&5K
M;&5N9&DN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U
M<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(B<E<R<@:>=I
M;B!O;&%N('9E<FD@8F'^87+]>6QA('-I<W1E;61E;B!T96UI>FQE;FUI_G1I
M<BXB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T
M92YP:'`Z-#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F
M=6QL>2!D96QE=&5D(%PB)7-<(BXB"FUS9W-T<B`B0F'^87+]>6QA('-I;&EN
M9&D@)R5S)RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F
M<F]M('1H92!S>7-T96TN(@IM<V=S='(@(E-I<W1E;61E;B!B8?YA<OUY;&$@
M<VEL:6YD:2`G)7,G+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*
M;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!2
M96QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(B(*(EEA</UL86YD_7)M
M82!B8?YA<OUY;&$@9V5R:2!D]FYD_'+\;&3\+B!$9?!I_FEK;&EK;&5R:2!G
M]G)M96L@:>=I;B!Y96YI9&5N("(*(GG\:VQE>6EN+B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HU.2!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU-PIM
M<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R(")9961E:R!Y87#];&%N9/UR;6$@8F'^87+]>6QA(&MA>61E
M9&EL9&DN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C
M;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(EEE9&5K('EA</UL86YD
M_7)M82!D;W-Y87/]("5S(&)A_F%R_7EL82!K87ED961I;&1I+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY('5P9&%T960@7"(E<UPB(@IM<V=S='(@(B<E<R<@8F'^
M87+]>6QA(&?\;F-E;&QE;F1I(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@(B5S(&)A_F%R
M_7EL82!Y87K];&3]+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U9&%N(@IM
M<V=S='(@(E-U9&%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU-@IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R("+6
M>F5T(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED(")3=6X@
M4FES92(*;7-G<W1R(")'_&X@1&_P=6UU(@H*(SH@;&EB+T)L;V-K+W-U;G)I
M<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(D?\;B!B873];?TB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.0IM
M<V=I9"`B4W5N;GDB"FUS9W-T<B`B1_QN9?YL:2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,38*;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`B
M1_QN(&1O\'5M=2(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]"
M;&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS
M9W-T<B`B1_QN(&1O\'5M=2]'_&X@8F%T_6W](@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Q-0IM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@
M(D?\;B!D;_!U;74Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,3D*;7-G:60@(E-U;G-E="(*;7-G<W1R(")'_&X@8F%T_6W](@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.`IM<V=I9"`B4W5N<V5T
M.B`B"FUS9W-T<B`B1_QN(&)A=/UM_3H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B
M"FUS9W-T<B`BW'-T<VEM9V4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S<X"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(D1E<W1E:R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#8*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(E-U<FEN86TB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-`IM<V=I9"`B
M4W5R;F%M92(*;7-G<W1R(")3;WEA9/TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED
M(")3=F%L8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(E-V86QB87)D('9E
M($IA;B!-87EE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*
M;7-G<W1R(")3=F%Z:6QA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=V5D
M96XB"FUS9W-T<B`BW7-V9><B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I='IE
M<FQA;F0B"FUS9W-T<B`BW7-V:>=R92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C@V"B,L(&9U>GIY"FUS9VED(")3>6YC(&QO9R!D96QE=&5D
M(@IM<V=S='(@(E-I;&UE>6EN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$T,@IM<V=I9"`B4WEN8TU,(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]3
M44PO4U%,+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN
M('-E87)C:"!T97)M<R(*;7-G<W1R(")!<F%M82!T97)I;6QE<FEN9&4@<_9Z
M9&EZ:6T@:&%T87/](@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4WER:6%N($%R
M86(@4F5P=6)L:6,B"FUS9W-T<B`B4W5R:7EE(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E0M4W1O<FTB"FUS
M9W-T<B`B1_9K(&?\<OQL=/QL_"!F_7)T_6YA(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E0M4W1O<FT@86YD
M(%=I;F1Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8R"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R(")']FL@
M9_QR_&QT_&S\(&;]<G3];F%L87(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B5"U3=&]R;7,@
M16%R;'DB"FUS9W-T<B`B17)K96X@4V%A=&QE<F1E(%-A\&%N86LB"@HC.B!F
M<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,38V"FUS9VED(")44U8@9FEL
M92(*;7-G<W1R(")44U8@9&]S>6%S_2(*"B,Z(&9R86UE=V]R:R]522]522]4
M86)L92YP:'`Z,3,T"FUS9VED(")486)L92(*;7-G<W1R("+':7IE;&=E(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW,PIM<V=I9"`B5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R("+'27IE;&=E
M(-9Z96QL:6ML97)I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A
M8FQE<V5T+G!H<#HU-PHC+"!F=7IZ>0IM<V=I9"`B5&%B;&4@4V5T(@IM<V=S
M='(@(L=I>F5L9V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P97)T:65S(@IM
M<V=S='(@(L=I>F5L9V4@]GIE;&QI:VQE<FDB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(S-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$Q"FUS9VED(")486EW86XB"FUS9W-T<B`B5&%Y=F%N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@
M4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`B5&%Y=F%N+"#':6X@97EA;&5T
M:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B
M5&%C:6MI<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A;GIA;FEA+"!5
M;FET960@4F5P=6)L:6,@;V8B"FUS9W-T<B`B5&%N>F%N>6$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU"FUS9VED(")4
M87)G970Z(@IM<V=S='(@(DAE9&5F.B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N
M9&ES=#HY.38@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X-PIM<V=I9"`B
M5&%S:W,B"FUS9W-T<B`B1_9R979L97(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4W,PIM<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*
M;7-G<W1R(")496QE9F]N($YU;6%R87/](@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR.3`*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@
M(E-O;B!S86%T(&GG:6X@<_UC86ML_6LZ("(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C$T"FUS9VED(")496UP97)A='5R92(*;7-G<W1R(")3_6-A:VS]
M:R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C,*;7-G:60@
M(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`B4_UC86ML_6LZ("(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP
M.C8X-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E
M<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B)R5S)R!T87-L8?#](&)U;'5N86UA
M9/TN(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@(E1E;7!L
M871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E1A<VQA:R!9]FYE=&EM:2(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3$@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S,S-@IM<V=I9"`B5&5X="(*;7-G<W1R(")-971I;B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S4*;7-G:60@(E1E>'0@3VYL
M>2(*;7-G<W1R(")3861E8V4@365T:6XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L
M:6=N(@IM<V=S='(@(DUE=&EN(&AI>F%L86UA<_TB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"FUS9VED(")497AT=&]P
M(@IM<V=S='(@(DUE=&YI;B#<<W3\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T<B`B4'+^
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@(E1H86D@*%1)
M4RTV,C`I(@IM<V=S='(@(E1A:2`H5$E3+38R,"DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y
M"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R(")487EL86YD(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z.3@X"FUS9VED(")4:&%N:R!Y;W4@9F]R('5S
M:6YG('1H92!S>7-T96TN(@IM<V=S='(@(E-I<W1E;6D@:W5L;&%N_63]\/UN
M_7H@:>=I;B!T9?YE:VO\<B!E9&5R:7HN(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HX,C`*;7-G:60@(E1H92!&5%`@97AT96YS:6]N(&ES(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(D944"!U>F%N=/US_2!K=6QL86[];&%B
M:6QI<B!D=7)U;61A(&1E\&EL+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3,T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!(;W)D92]+;VQA
M8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B
M"FUS9W-T<B`B2&]R9&4O2V]L86(@8OQT_&YL9?YT:7)M92!M;W1O<G4@9&5S
M=&5K;&5M96UE:W1E9&ER.B!<(B5S7"(B"@HC.B!F<F%M97=O<FLO3F5T7TE-
M4U`O24U34"]";V]K+G!H<#HQ,CDR"B,L(&9U>GIY"FUS9VED(")4:&4@24U3
M4"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R(")9_&ML
M96YE;B!D;W-Y82!K87ED961I;&5M961I+B(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@
M9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R(")"86O];3HZ('/]
M;OUF(&)A_F%R_7EL82!Y_&ML96YE;65D:2XB"@HC.B!S97)V:6-E<R]I;6%G
M97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD
M;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`BWF7G96YE:VQE<B!P
M96YC97)E<VD@:V%P86YD_2['_6O]_B!Y87#];/UY;W(N(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.#D@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HR,#`*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,3$@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,C,*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HR,S0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-3(*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-C0@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A9&UI;FES=')A=&]R
M(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B
M86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N<RXB"FUS
M9W-T<B`B(@HB1?!E<B!I>FEN;&5R:2!K=6QL86YM86L@:7-T:7EO<G-A;OUZ
M('GV;F5T:6-I;FEZ:6X@W7II;B!S:7-T96UI;FD@(@HB>6%P_6QA;F3]<FUA
M<_T@9V5R96MM96MT961I<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M('-I
M9&4@;VYL>2(*;7-G<W1R(")3861E8V4@86QT('1A<F%F(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@
M(B(*(E1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@
M;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S
M92XB"FUS9W-T<B`B(@HBW6QE=&G^:6T@;F]K=&%S_6[];B!)1"=S:2!B96QI
M<FQE;F5M961I+"!B;_X@8OUR86O];&W]_B!V97EA('9E<FD@=&%B86[];F1A
M("(*(F)U;'5N86UA9/TN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C4Q"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S
M<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("+=
M;&5T:?YI;2!N;VMT87/](&)A_F%R_7EL82!A9')E<R!D969T97)I;FEZ92!E
M:VQE;F1I+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q
M-CD*;7-G:60@(B(*(E1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K
M(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM
M<V=S='(@(B(*(L?]:V%R=/UL;?W^(%!'4"!I;7IA(/9B9?!I(&EM>F%L86YM
M_?X@:6QE=&EN:6X@9&_P<G5L=?!U;G5N('-A\&QA;FUA<_T@:>=I;B`B"B)G
M97)E:VUE:W1E9&ER+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I8G5T:6]N
M(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK
M(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@(B(*
M(D1A\/UT_6T@;&ES=&5S:2!)1"=S:2!B96QI<FQE;F5M961I+"!B;_X@8OUR
M86O];&W]_B!V97EA('9E<FD@=&%B86[];F1A("(*(F)U;'5N86UA9/TN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-#(*;7-G:60@(E1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I
M9FEE9"XB"FUS9W-T<B`B1&'P_73];2!L:7-T97-I(&)E;&ER;&5N96UE9&DN
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+G!H<#HQ,3,*;7-G:60@(E1H
M92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O
M;FYE8W1I;VXN(@IM<V=S='(@(MYI9G)E;&5M92#V>F5L;&EK;&5R:2!G_'9E
M;FQI(&)I<B!W96(@8F'P;&%N=/US_2!G97)E:W1I<FUE:W1E9&ER+B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<U(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z-3$S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE
M("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B)7,@
M9&]S>6%S_2`E<R!A>6%R_2!IYV5R;65L:61I<BXB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$V."!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C4P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@
M8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+B(*;7-G<W1R("(E<R!D;W-Y87/]
M("5S(&%Y87)L87+](&GG97)M96QI9&ER+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C(Q.0IM<V=I9"`B5&AE(&9I;&4@8V%N(&YO="!B92!C
M;W!I960@;VYT;R!I='-E;&8N(@IM<V=S='(@(D1O<WEA(&ME;F1I(/QZ97)I
M;F4@:V]P>6%L86YA;6%Z+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP
M.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S
M='(@(D1O<WEA('9E<FD@:>=E<FUI>6]R+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I
M;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE
M<W-A9V4N(@IM<V=S='(@(E1A:VEP(&5D96YL97(@8G4@:6QE=&DO<F9C.#(R
M(&EL971I<VD@:>=I;B!B8?YL_6L@8FEL9VEL97)I9&ER+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*
M(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L
M96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R
M(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO
M=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O
M9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S
M:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E
M<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R;W1E
M8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V
M92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I
M;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS9W-T
M<B`B(@HB0?YA;6%D_?#];?UZ('1A<F%Y_6/](&AA=&%L87+]('-E8F5B:7EL
M92!T86T@96MR86X@:VEP:6YI;B!);G1E<FYE="`B"B)%>'!L;W)E<B=L82!B
M:7)L:6MT92!S;W)U;B#G_6MA<F3]\/T@8FEL:6YM96MT961I<BX@06YL86US
M_7H@9_9R_&YT_&QE<FQE+"`B"B+G86S]_FUA>6%N(&UE=&EN(&3\>F5N;&5Y
M:6-I(&G^;&5R:7EL92!V92]V97EA('1A<F%Y_6/];OUN(')A<W1G96QE("(*
M(N?V:VUE<VEY;&4@:V%R_OUL8?YA8FEL:7)S:6YI>BX@1?!E<B!S:7-T96UI
M;FEZ(%=I;F1O=W,@.7@@:7-E('G\:W-E:R`B"B)I:'1I;6%L("='96YE<F%L
M(%!R;W1E8W1I;VX@1F%U;'0G(&AA=&%S_2!A;/UP('-I<W1E;6D@>65N:61E
M;B!B8?YL871M86[]>B`B"B)G97)E:V5C96LN7%QN7%QN0G4@8FER('5Y87+]
M>63]+B!%\&5R(&AA;&$@=&%M(&5K<F%N(&UE=&EN(&3\>F5N;&5Y:6-I<VEN
M:2`B"B)D96YE;65K(&ES=&EY;W)S86[]>B!%=F5T)VD@=/UK;&%Y_6XN(@H*
M(SH@<V5R=FEC97,O<')E9G,N<&AP.CDP"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T
M<B`B2VEM;&EK(%PB)7-<(B!S:6QI;F1I+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L
M969T+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(E-A9&5C92!S;VP@=&%R868B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ-3<*;7-G:60@
M(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@
M9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R(")#<GEP
M=%]P9W`Z.B!S_6[]9OUN82!';G501R!I:VEL:7-I;FEN(&MO;G5M=2!V97)I
M;&UE:R!Z;W)U;F1A9/UR+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.
M+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@
M<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N
M(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE
M(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R
M("(B"B(E<R!T87)I:&EN9&4@)7,@92!G]FYD97)I;&5N(%PB)7-<(B!K;VYU
M;'4@:6QE=&D@9_9R_&YT_&QE;F1I+EQN(@HB0G4@:6QE=&EN:6X@;VMU;F1U
M\'4@=F5Y82!A;FQA_OUL9/WP_6[](&=A<F%N=&EL96UE;65K=&5D:7(N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-PIM<V=I9"`B5&AE(&YA
M;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM
M<V=S='(@(D]L=?YT=7(@<&5N8V5R97-I;F4@8F'P;&%N_7)K96X@:W5L;&%N
M_6QA8V%K(&ES:6TB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT
M-#$*(RP@9G5Z>GD*;7-G:60@(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@
M8F4@;G5M97)I8RXB"FUS9W-T<B`B0G4@86QA;B!G9>=E<FQI(&)I<B!N=6UA
M<F$@;VQM86S]9/UR+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,3(S,0IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I
M<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T
M<B`B2&]R9&5?0W)Y<'1?<VEM93HZ('/];OUF_2!O<&5N<W-L(&)I<FEM:2!I
MYVEN(&=E<F5K;65K=&5D:7(N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N
M8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A
M(&5X8V5E9&5D('1H92`B"B)M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S
M='(@(B(*(EPB)7-<(B!T97)C:6AI('9E<FES:2!I>FEN('9E<FEL96X@96X@
M>?QK<V5K(&)O>75T=2!G9>=T:?!I(&GG:6X@(@HB:V%Y9&5D:6QE;65M96MT
M961I<BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D96(N<&AP
M.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H
M<#HS-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W!O=V5R<&]I
M;G0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R
M9"YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<G!M+G!H
M<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]W96)C<'`N<&AP
M.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W-R8VAI9VAL:71E
M+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<V5X8V5L
M+G!H<#HS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A;2!U
M<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD
M(&]N('1H92!S>7-T96TN(@IM<V=S='(@(B(*(D)U('9E<FD@>6%P<_UN_2@E
M<RD@9_9S=&5R;65K(&GG:6X@:W5L;&%N_6QA;B!P<F]G<F%M('-I<W1E;61E
M("(*(F)U;'5N;6%M86MT863]<BXB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HT-30*;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@;75S="!B
M92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I
M9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'DB"FUS9W-T<B`B4V%D
M96-E('-O;"!V92!S8?`@=&%R869L87(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG
M:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B4V%D96-E('-A\"!T87)A9B(*
M"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T-@IM<V=I9"`B5&AE
M('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D
M96QE=&5D+B(*;7-G<W1R(")<(B5S7"(@<W5N=6-U<W4@<VEL:6YD:2XB"@HC
M.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS
M9W-T<B`B7"(E<UPB('-U;G5C=7-U(&MA>61E9&EL9&DN(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@
M<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B)7,@
M:>=I;B!O;&%N(/QY96QI:R!I<W1E\&D@<VEL:6YD:2XB"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HS,S`*;7-G:60@(E1H92!S<&5C
M:69I960@<F]W(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")"96QI<G1I;&5N
M('-A=/UR(&)U;'5N;6%M86MT863]<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R
M87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")'9>=I
M8VD@9&]S>6$@7"(E<UPB(&)U;'5N;6%M86MT863]<BXB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,S$Q"FUS9VED(")4:&4@=&5X="!Y;W4@96YT
M97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S:61E
M<R!O;FQY(@IM<V=S='(@(E-A9&5C92#\<W0@=F4@86QT('1A<F%F;&%R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B4V%D96-E
M(/QS="!T87)A9B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C,R-PIM
M<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R
M979I;W5S('-T97`N(@IM<V=S='(@(D)I<B#V;F-E:VD@863];2!S_7)A<_UN
M9&$@>?QK;&5N96X@=F5R:2!K87EB961I;&1I+B(*"B,Z(&9R86UE=V]R:R]$
M871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N
M<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E
M('-A=F5D+B(*;7-G<W1R(")9_&ML96YE;B!D;W-Y82!K87ED961I;&5M961I
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-38*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$Q-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$Y
M"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L
M92XB"FUS9W-T<B`B=V5A=&AE<BYC;VT@:W5L;&%N_6QA8FEL:7(@9&7P:6PN
M(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U
M;F0N(@IM<V=S='(@(E1E;6$@9&EZ:6YI("<E<R<@8G5L=6YA;6%D_2XB"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$W.`IM<V=I9"`B5&AE
M<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R(")(:>=B:7(@
M<V7G96YE:R!M979C=70@9&7P:6PN(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z,S0R"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@
M=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B365T;F4@
M9_9M_&S\(&]L87)A:R!G]G-T97)I;&5B:6QE8V5K(&O]<_UM('EO:R(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,#$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI
M<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y
M;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*(D)U(&%L
M86YD82#G;VL@9F%Z;&$@:V%R86MT97(@=F%R+B5S('1A;F4@:V%R86MT97(@
M9VER9&EN:7H[("5S('1A;F5D96X@87H@(@HB9VER;65N:7H@9V5R96MI<F1I
M+B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@861D
M:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R("(G)7,G('-I
M<W1E;64@96ML96YI<FME;B!B:7(@<V]R=6X@;VQU_G1U.B`E<R(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$R,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R(%PB
M)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("(G)7,G(&MU;&QA;OUC
M_6[];B!V97)I;&5R:6YI;B!S:7-T96UD96X@<VEL:6YM97-I;F1E('-O<G5N
M('9A<CH@(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG(%PB
M)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("(G)7,G(&MU;&QA;OUC
M_7/];OT@<VES=&5M9&5N(.?]:V%R=/UL;6%S_6YD82!S;W)U;B!V87(Z("(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z("5S
M(@IM<V=S='(@(B<E<R<@9_QN8V5L;&5N:7)K96X@<V]R=6X@;VQU_G1U.B`E
M<R(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE
M(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(D1O
M<WEA("AK87+^_61A;BD@>?QK;&5N;65S:6YD92!S;W)U;B!V87(Z("5S('G\
M:VQE;F5M961I+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP
M.C@X.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B
M;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T
M:&%N('1H92!M87AI;75M("(*(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*
M;7-G<W1R("(B"B)$;W-Y82!Y_&ML96YI<FME;B!B:7(@<V]R=6X@;VQU_G1U
M.B`E<R!E;B!B_'G\:R!I>FEN('9E<FEL96X@8F]Y=71T86X@*"5D("(*(F)Y
M=&4I(&1A:&$@8OQY_&LN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E
M<BYP:'`Z.#DQ"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A
M('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL
M>2!P87)T:6%L;'D@=7!L;V%D960N(@IM<V=S='(@(D1O<WEA('G\:VQE;FER
M:V5N(&)I<B!S;W)U;B!O;'7^='4Z("5S('-A9&5C92!K_7-M:2!O;&%R86L@
M>?QK;&5N9&DN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C
M.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI
M;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B26QE=&EN:6X@8G4@:_US
M;?UN_2!G]G+\;G3\;&5N;65S:6YD92!H871A(&]L=?YT=2XB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM
M<V=S='(@(MUL971I_FEM(&YO:W1A<_UN_6X@=F5R:6QE<FD@*&GG97)I*2!A
M:W1A<OUL_7)K96X@:&%T82!O;'7^='4N(@H*(SH@9G)A;65W;W)K+T1A=&$O
M1&%T82]I;6,N<&AP.C,Q"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`B:4-A;&5N9&%R
M('9E<FES:2`H:>=E<FDI(&%K=&%R_6S]<FME;B!H871A(&]L=?YT=2XB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C@P"FUS9VED("(B"B)4:&5R92!W
M87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P
M<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B
M(@HB66%P_6QA;F3]<FUA(&9O<FUU;F1A(&)I<B!H871A('9A<BX@1V5R96ML
M:2!B:7(@86QA;OT@9&]L9'5R;6%M_?X@(@HB;VQA8FEL:7)S:6YI>BXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M.`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE
M('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T
M<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(D)E;&ER=&EL96X@861R97,@
M9&5F=&5R:2!I_FQE=FEN:6X@9V5RYV5K;&7^=&ER:6QM97-I('/]<F%S_6YD
M82!S;W)U;B`B"B)O;'7^='4N($S\=&9E;B!D86AA('-O;G)A('1E:W)A<B!D
M96YE>6EN+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C0P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D
M871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L
M871E<BXB"FUS9W-T<B`B(@HBW6QE=&G^:6T@;F]K=&%S_6[];B!A>7+];G3]
M;&%R_6[](&?\;F-E;&QE<FME;B!H871A(&]L=?YT=2X@3/QT9F5N(&1A:&$@
M(@HB<V]N<F$@=&5K<F%R(&1E;F5Y:6XN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C(*;7-G:60@(B(*(E1H97)E('=A
M<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L
M96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(D1A\/UT_6T@;&ES
M=&5S:6YI(&?\;F-E;&QE<FME;B!B:7(@:&%T82!O;'7^='4N($S\=&9E;B!D
M86AA('-O;G)A('1E:W)A<B`B"B)D96YE>6EN+B(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T.`IM<V=I9"`B5&AI<R!)34%0
M('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS
M9W-T<B`B0G4@24U!4"!S=6YU8W5S=2!P87EL8?[];&%N(&1I>FEN;&5R:2!D
M97-T96ML96UI>6]R+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E
M(&$@=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(D)U(&=EYV5R;&D@8FER
M(')A<B!A<OYI=FD@9&7P:6PN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@
M=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B0G4@9V7G97)L:2!B
M:7(@>FEP(&1O<WEA<_T@9&7P:6PN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S$T-0IM<V=I9"`B5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@
M=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@(D)U(&=EYV5R;&D@8FER(&MA
M<G0@;G5M87)A<_T@9&7P:6PN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R:79E
M<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC
M:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S
M:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"B)"=2!S_'+\8_P@0VQI8VMA
M=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!A\"!G9>=I9&D@_'IE<FEN
M9&5N($A45%`@05!)("(*(FMU;&QA;F%R86L@;65S86H@871M86[]>F$@:7II
M;B!V97)I<BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C$S-`HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O
M=VEN<&QC+F-O;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM
M<V=S='(@(B(*(D)U('/\<OQC_"!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA
M:6PI(&'P(&=EYVED:2#\>F5R:6YD96X@2%144"!!4$D@(@HB:W5L;&%N87)A
M:R!M97-A:B!A=&UA;OUZ82!I>FEN('9E<FER+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"FUS9VED("(B"B)4
M:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H
M('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G871E
M=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB0G4@<_QR_&/\
M('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"D@8?`@9V7G:61I(/QZ97)I
M;F1E;B!(5%10($%022`B"B)K=6QL86YA<F%K(&UE<V%J(&%T;6%N_7IA(&EZ
M:6X@=F5R:7(N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE
M:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O
M9&%F;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M
M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O
M9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*
M(D)U('/\<OQC_"!33510('EO;'5Y;&$@5F]D869O;F4@271A;'D@8?`@9V7G
M:61I(/QZ97)I;F1E;BP@<V%D96-E(%9O9&5F;VYE("(*(FYU;6%R86QA<OUN
M82!M97-A:B!A=&UA;OUZ82!I>FEN('9E<FER+B!6;V1E9F]N92!)=&%L>2`H
M:'1T<#HO+W=W=RXQ.3`N:70I("(*(F5L96MT<F]N:6L@<&]S=&$@861R97-I
M(&=E<F5K=&ER;65K=&5D:7(N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z.3<X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-3<*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3`X-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,3$U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#(@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(U-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,S`U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S.3@*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34U-R!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.#,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-3@@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P-0HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,#(Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-S@*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$T.2!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,C(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3`@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U-`HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-C4W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,C@*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S-R!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,S`V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X
M,30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@R,@IM<V=I9"`B5&AI<R!F
M:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B0G4@9V5R96ML:2!B:7(@86QA
M;F3]<BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#8U"FUS9VED
M(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S
M='(@(D)U(&%L86X@<V%D96-E('-A>?T@:>=E<FUE;&ED:7(N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q.`IM<V=I9"`B5&AI<R!F:65L9"!M
M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BXB"FUS9W-T
M<B`B0G4@86QA;B!S861E8V4@<V%Y_2!V92!I:VD@;F]K=&$@_'-T_'-T92!I
M_F%R971I(&GG97)E8FEL:7(N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3`Y-`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C
M=&%L('9A;'5E<RXB"FUS9W-T<B`B0G4@86QA;B!S861E8V4@<V5K:7IL:6L@
M<V%Y_2!S:7-T96UI;F1E;B!D9?!E<FQE(&GG97)E8FEL:7(N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$R,PIM<V=I9"`B5&AI<R!F:65L9"!M
M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT
M96=E<G,B"FUS9W-T<B`B0G4@86QA;B!V:7)G_&P@=F5Y82!B;_YL=6ML82!A
M>7+];&W]_B!S87G](&QI<W1E(&]L;6%L_63]<BXB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HY.#D*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A
M('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`B0G4@86QA;B!G9>=E<FQI(&)I<B!N
M=6UA<F$@;VQM86S]9/UR+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,S8*;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L
M;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*
M(B<C,3(S-&%F)RXB"FUS9W-T<B`B0G4@86QA;B!21T(@2&5X(&)IYVEM:6YD
M92!B:7(@<F5N:R!K;V1U(&GG97)M96QI9&ER+"#V<FYE:SH@)R,Q,C,T868G
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z-38Q"FUS9VED(")4:&ES
M(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@(D)U
M(&9O<FT@>F%T96X@:?YL96YD:2XB"@HC.B!T96UP;&%T97,O:&5L<"]A8F]U
M="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S+B(*;7-G
M<W1R(")"=2`E<RXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0U
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O
M=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N
M965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+
M;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA
M:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@HB0G4@
M8FER($MO;&%B($=R;W5P=V%R92!N97-N97-I9&ER+B!"=2!N97-N97EI(&?V
M<F5B:6QM96L@:>=I;B!+;VQA8B`B"B)'<F]U<'=A<F4@8FGG:6UI;FD@86YL
M87EA8FEL96X@8FER(&5L96MT<F]N:6L@<&]S=&$@:7-T96UC:7-I;F4@9V5R
M96L@=F%R+D)U("(*(F5L96MT<F]N:6L@:7-T96UC:2!L:7-T97-I(&GG:6X@
M)7,@861R97-I;F4@=?!R87G];BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HU.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!M
M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T
M:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(D)U(&EL971I('-I>FEN(&MA
M<F%K=&5R(&O\;65N:7ID96X@9F%R:VS](&]L87)A:R@E<RD@>6%Z_6QM_?YT
M_7(N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C8*;7-G
M:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R
M(")"=2!N=6UA<F$@96X@87K];F1A;B!B:7(@;VQM86S]9/UR+B(*"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HT-0IM<V=I9"`B
M5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL
M97,N(@IM<V=S='(@(D)U('-U;G5C=2!Z:7`@=F4@9WII<"!D;W-Y86QA<OUN
M_2!AYV%M86UA:W1A9/UR+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]2
M96=I<W1R>2YP:'`Z,3@Y"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT
M;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(E-I<W1E;6EN(&5T:VEN;&GP:2!K
M86QD_7+];&W]_G3]<BXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*
M;7-G<W1R(")"=2!D9?!E<B!B:7(@<V%Y_2!O;&UA;/UD_7(N(@H*(SH@<V5R
M=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM<V=I9"`B5&AI<R!W
M:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=R(*
M;7-G<W1R(")"=2!P96YC97)E(%-EYV5N96ML97(@<&5N8V5R97-I;F1E;B#G
M8?!R_6QM86S]9/UR+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8T"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(D?V:R!G_'+\
M;'3\<_PB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,T"FUS9VED
M(")4:6-K971S(@IM<V=S='(@(D)I;&5T;&5R(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C0R."!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M-34*;7-G:60@(E1I;64B"FUS9W-T<B`B6F%M86XB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S@V"FUS9VED(")4:6UE(%1R86-K:6YG(@IM<V=S
M='(@(EIA;6%N(-UZ;&5M92(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PIM
M<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`B6F%M86X@0FGG:6UI(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4S.0IM<V=I9"`B5&EM92!S96QE
M8W1I;VXB"FUS9W-T<B`B6F%M86X@4V7G:6UI(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM
M<V=I9"`B5&EM;W(M3&5S=&4B"FUS9W-T<B`B5&EM;W(M3&5S=&4B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]"
M;&]C:R]I9G)A;64N<&AP.C(P"FUS9VED(")4:71L92(*;7-G<W1R(")"8?YL
M_6LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@(D)A_FS]:R`H
M8>?]:VQA;6$I.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(DMI;64B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C4T"FUS9VED("(B
M"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N
M=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y("(*(G=H:6QE(&-L:6-K
M:6YG+B(*;7-G<W1R("(B"B+';VML=2#V\&4@<V7G:6UI(&GG:6XL('3]:VQA
M<FME;B!#;VYT<F]L("A00RD@=F5Y82!#;VUM86YD("A-86,I('1U_G5N82`B
M"B)B87/];BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Q
M"FUS9VED(")4;V1A>2(*;7-G<W1R(")"=6?\;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(
M5$U,(%-O=7)C92(*;7-G<W1R(")(5$U,($MA>6YA\/UN82!'9>=I;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#D*;7-G:60@(E1O9V\B"FUS9W-T<B`B5&]G;R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3`*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B5&]K96QA=2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3,*;7-G:60@(E1O;6]R
M<F]W(@IM<V=S='(@(EEA<OUN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]N
M9V$B"FUS9W-T<B`B5&]N9V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S<*;7-G:60@(E1O<"(*;7-G<W1R("+<
M<W0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDS"FUS9VED(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@(MQS="#'97+G
M979E("C<7W-T*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I
M9"`B5')A;G-L871I;VYS(@IM<V=S='(@(L=E=FER:6QE<B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B5')I
M;FED860@=F4@5&]B86=O(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3<Y,`IM<V=I9"`B5')U92!O<B!F86QS92(*;7-G<W1R(")$;_!R=2!V97EA
M(%EA;FS]_B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(E-A(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R(")4=6YU<R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3$*;7-G:60@(E1U<FME>2(*;7-G<W1R(")4_')K:7EE(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(E1U<FMI<V@@*$E33RTX.#4Y+3DI
M(@IM<V=S='(@(E3\<FOG92`H25-/+3@X-3DM.2DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P
M"FUS9VED(")4=7)K;65N:7-T86XB"FUS9W-T<B`B5/QR:VUE;FES=&%N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P.`IM<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S
M(@IM<V=S='(@(E1U<FMS('9E($-A:6-O<R!!9&%L87+](@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,0IM<V=I9"`B5'5V86QU(@IM<V=S='(@(E1U=F%L=2(*"B,Z(&9R86UE
M=V]R:R]#3$DO0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z
M("(*;7-G<W1R(")39>=I;6EN:7II(&=I<FEN.B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-CD*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G
M<W1R(")5+E8N(&5N9&5K<SH@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM
M<V=I9"`B55),(@IM<V=S='(@(E523"(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@9F]R('EO
M=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B0F5T
M:6ML97)I;B!D=7)U;2!R87!O<FQA<OUN_6X@=&5S;&EM(&5D:6QE8V7P:2!5
M4DPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDW"FUS9VED(")54DPZ(@IM<V=S='(@(E523#HB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R
M"FUS9VED(")59V%N9&$B"FUS9W-T<B`B56=A;F1A(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,@IM<V=I9"`B56MR86EN92(*;7-G<W1R(")5:W)A>6YA(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z-#$R"FUS9VED(")5;F%B;&4@=&\@86-C
M97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(E9&4R!D:7II;FEN92!E<FG^
M:6QE;65M:7EO<BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP
M:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA
M=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(MQY92!O;'5R:V5N(&5K
M(&MU;&QA;OUC_2!B:6QG:7-I(&5K;&5N96UI>6]R+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,S@X"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R(")<(B5S7"(@5D93(&1O<WEA<_UN_6X@:7II;FQE<FD@9&7P
M:?YT:7)I;&5M:7EO<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HS.#4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0V.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R
M(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("(E<R\E<R!61E,@9&]S>6%S_6[]
M;B!I>FEN;&5R:2!D9?!I_G1I<FEL96UI>6]R+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z-S4U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@(B5S(&1E\&G^=&ER:6QE;65D
M:2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(S,@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ
M92!O9B!<(B5S7"(N(@IM<V=S='(@(E9&4R!D;W-Y87/](%PB)7-<(B!AY_UL
M86W]>6]R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8X."!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P,38*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C@S-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S+R5S7"(N
M(@IM<V=S='(@(B5S+R5S(%9&4R!D;W-Y87/]('EE;FED96X@861L86YD_7+]
M;&%M_7EO<BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z-#,U
M"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+B(*;7-G
M<W1R(")344P@<W5N=6-U<W5N82!B8?!L86[];&%M_7EO<BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S.0IM<V=I9"`B56YA8FQE('1O(&-O
M;FYE8W0@=VET:"!34TPN(@IM<V=S='(@(E-33"!I;&4@8F'P;&%N_6QA;?UY
M;W(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C(U(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P
M.0IM<V=I9"`B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(E9&
M4R!D;W-Y87/](&MO<'EA;&%N86W]>6]R+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,S8U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(EPB)7-<
M(B!61E,@9&EZ:6YI('EA<F%T_6QA;?UY;W(N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,S4T(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HR-3@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(U-@IM
M<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R
M(")61E,@9&EZ:6YI('EA<F%T_6QA;?UY;W(N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C$R-`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!6
M1E,@9FEL92XB"FUS9W-T<B`B5D93(&1O<WEA<_T@>6%R873];&%M_7EO<BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(X-@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R
M(%PB)7-<(BXB"FUS9W-T<B`B5D93(&1O<WEA<_T@7"(E<UPB('EE;FED96X@
M861L86YD_7+];&%M_7EO<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HR-C4*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I
M;&4N(@IM<V=S='(@(D)O_B!61E,@9&]S>6%S_2!Y87)A=/UL86W]>6]R+B(*
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N<&AP.C<V"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HW.0IM<V=I
M9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B5F5R:2!S
M_6O]_G3]<OUL86W]>6]R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z,C(T(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,CDX"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER
M96-T;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B7"(E<UPB(&1I>FEN:2!S
M:6QI;F5M:7EO<BP@9&EZ:6X@8F_^(&1E\&EL+B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-S@@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S
M+B(*;7-G<W1R("(G)7,G('-I;&EN96UI>6]R.B`E<RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HS,S$@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HS.3(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,Q,2!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S,T"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@
M:7,@;F]T(&5M<'1Y(@IM<V=S='(@(B5S('-I;&EN96UI>6]R+"!D:7II;B!B
M;_X@9&7P:6PB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,S0X(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-3(*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB
M"FUS9W-T<B`B5D93(&1I>FEN:2#V>GEI;F5L:2!O;&%R86L@<VEL:6YE;6EY
M;W(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,W(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,C(*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C,S-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,S0S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#0*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M5D93(&1I>FEN:2!S:6QI;F5M:7EO<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C0Q-R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0R.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E
M8W1O<GDZ("5S+B(*;7-G<W1R(")61E,@9&EZ:6YI('-I;&EN96UI>6]R.B`E
M<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(P-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B5D93(&1O<WEA<_T@7"(E<UPB('-I;&EN96UI>6]R+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,P,R!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C(X.`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,38W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#`*(SH@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X-R!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,S@S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HS.3$*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I
M;&4N(@IM<V=S='(@(E9&4R!D;W-Y87/]('-I;&EN96UI>6]R+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C0T"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@7"(E<UPB
M+B(*;7-G<W1R(")61E,@9&]S>6%S_2!<(B5S7"(@<VEL:6YE;6EY;W(N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S
M+B(*;7-G<W1R(")61E,@]GIY:6YE;&D@;VQA<F%K('-I;&EN96UI>6]R.B`E
M<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@P,PIM<V=I9"`B
M56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B6?QR_')L_&MT96MI(&1I>FEN92!K87)A<B!V97)I;&5M:7EO<BXB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8P,PIM<V=I9"`B
M56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R
M(")/;F%Y(&)E;&=E<VD@87ER_6YT_6QA<OT@Y_UK87)T_6QA;?UY;W(B"@HC
M.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z-#4Q(&9R86UE=V]R:R].
M971?24U34"])35-0+T%U=&@N<&AP.C$Q.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T
M<B`B5&%N_6W]('G\:VQE;F5M:7EO<CH@)7,B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-C8@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$W,0IM<V=I9"`B56YA8FQE
M('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(E9&4R!D;W-Y87/]('1A_OUN
M86W]>6]R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z.3,@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ,#(*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HV-#@@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HY.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(E9&4R!D;W-Y87/](%PB)7-<(B!AY_UL86W]>6]R
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(W-R!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HQ,S,*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&
M4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R(")61E,@9&]S>6%S_2!Y86UA
M:R!IYVEN(&'G_6QA;?UY;W(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z.#`@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3,P"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,@IM<V=I9"`B56YA8FQE
M('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@(E9&4R!D;W-Y87/](&'G_6QA
M;?UY;W(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H
M<#HT-0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E
M+B(*;7-G<W1R(")3_6O]_G3];/UM_?X@87+^:78@8>?];&%M_7EO<BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#,U"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+B(*
M;7-G<W1R(")61E,@9&]S>6%S_2!Y87K];&%M_7EO<B`H8V]P>2@I(&)A_F%R
M_7/]>B!O;&1U*2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#8V"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL
M95-I>F4H*2!F86EL960I+B(*;7-G<W1R(")61E,@9&]S>6%S_2!Y87K];&%M
M_7EO<B`H8V]P>2@I(&)A_F%R_7/]>B!O;&1U*2XB"@HC.B!F<F%M97=O<FLO
M4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*(RP@
M9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R(")6
M1E,@9&]S>6%S_2!Y96YI9&5N(&%D;&%N9/UR_6QA;?UY;W(N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C8Y"FUS9VED(")5;F%B;&4@=&\@
M<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(E9F<W)O;W0@
M9&EZ:6YI(&]K=6YA;?UY;W(N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HQ,3`U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T
M<R(*;7-G<W1R("(E<RT^)7,@;VQA<F%K('EE;FED96X@861L86YD_7+];&%M
M_7EO<CH@:&5D968@9&EZ:6X@>F%T96X@=F%R+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HR.3,*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B5D93(&1I>FEN:2!Y96YI9&5N
M(&%D;&%N9/UR_6QA;?UY;W(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HS,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M
M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B5D93(&1I>FEN:2!Y96YI
M9&5N(&%D;&%N9/UR_6QA;?UY;W(Z("5S(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HR-C<@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL
M92!<(B5S7"(N(@IM<V=S='(@(E9&4R!D;W-Y87/](%PB)7-<(B!Y96YI9&5N
M(&%D;&%N9/UR_6QA;?UY;W(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z-C$P(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,CD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E
M<R\E<RXB"FUS9W-T<B`B)7,O)7,@5D93(&1O<WEA<_T@>65N:61E;B!A9&QA
M;F3]<OUL86W]>6]R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M,S(S(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,3,*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C0U,B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,C@U"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HS,#$*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N(@IM
M<V=S='(@(E9&4R!D;W-Y87/]('EE;FED96X@861L86YD_7+];&%M_7EO<BXB
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F
M<RYP:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G
M<W1R("(G;6MI<V]F<R<@YV%L_?YT_7+];&%M_7EO<BXB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B
M;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R(")"
M=2!7;W)D(&)E;&=E<VD@YV5V:7)I;&EL96UI>6]R+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,30Y(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,34R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W<FET92!6
M1E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(E9&4R!D;W-Y87/](%PB)7-<(B!Y
M87K];&%M_7EO<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ
M-SD*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A
M:6QE9"DN(@IM<V=S='(@(E9&4R!D;W-Y87/]('EA>OUL86W]>6]R("AC;W!Y
M*"D@8F'^87+]<_UZ(&]L9'4I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,X
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-#,*;7-G:60@
M(E5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+B(*;7-G<W1R(")61E,@
M9&]S>6$@=F5R:7-I('EA>OUL86W]>6]R+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HX-#$*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!W<FET92!6
M1E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"XB"FUS9W-T<B`B5D93
M(&1O<WEA<_T@>6%Z_6QA;?UY;W(@*&-O<'DH*2!B8?YA<OUS_7H@;VQD=2DN
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(D%L=/UN_2#G:7HB"@HC.B!T
M96UP;&%T97,O<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B
M"FUS9W-T<B`B1&7P:?YI:VQI:VQE<FD@1V5R:2!!;"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E
M<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(E-O;B!E>6QE;6D@9V5R:2!A
M;"(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R
M,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.3`*
M;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N
M;F5C=&EO;CH@(@IM<V=S='(@(D)A\&QA;G3]9&$@<W5N=6-U9&%N(&)E:VQE
M;FUE>65N('EA;OUT.B`B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S0Q"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,W.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS.#0*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V
M97(@=&\Z("(*;7-G<W1R(")3=6YU8W5D86X@8F5K;&5N;65Y96X@>6%N_70Z
M("(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C8Q"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(D1O;&1U<G5L;6%M_?XB
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B56YI8V]D92`H
M551&+3@I(@IM<V=S='(@(E5N:6-O9&4@*%541BTX*2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V
M"FUS9VED(")5;FET960@07)A8B!%;6ER871E<R(*;7-G<W1R(")":7)L9?YI
M:R!!<F%P($5M:7)L:6ML97)I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")5;FET
M960@2VEN9V1O;2(*;7-G<W1R(")":7)L9?YI:R!+<F%L;/UK(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R(")!;65R:6MA
M($)I<FQE_FEK($1E=FQE=&QE<FDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5
M;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',B"FUS9W-T<B`B
M06UE<FEK82!":7)L9?YI:R!$979L971L97)I;FEN($O\Y_QK(%5Z86L@061A
M;&%R_2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV.2!L:6(O
M0FQO8VLO;65T87(N<&AP.C<Q"FUS9VED(")5;FET<R(*;7-G<W1R(")":7)I
M;6QE<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R.2!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,S`*;7-G:60@(E5N:VYO
M=VXB"FUS9W-T<B`B0FEL:6YM97EE;B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A
M<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*;7-G<W1R(")":6QI;FUE>65N
M(&%P:6US9VED("A!4$D@365S86H@240I(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN;W=N
M(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@(D)I;&EN
M;65Y96X@8VQI;7-G:60@*-US=&5M8VD@;65S86H@240I(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$U.0HC+"!F=7IZ>0IM<V=I9"`B56YK
M;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B2&GG8FER('EE<B!B
M96QI<G1I;&UE9&DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R
M('!A<W-W;W)D+B(*;7-G<W1R(")":6QI;FUE>65N(&MU;&QA;OUC_2!A9/T@
M=F5Y82!P87)O;&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E
M;G0@96QE;65N="(*;7-G<W1R("+>=2!A;FMI(/;P96YI;B!B8?#];OT@Y_9Z
M(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HR.38*;7-G
M:60@(E5N;F%M960B"FUS9W-T<B`BW7-I;7-I>B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I
M=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@
M<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI
M8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@
M=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A
M8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@HB07ER_6-A;/UK<_UZ
M(&)E=&EK;&5R('!R;V=R86US86P@;VQA<F%K($ME<R]+;W!Y86QA+UEA</W^
M=/UR)V$@9_QV96YL:6L@(@HB;F5D96YI>6QE(&5R:?YE;65Z;&5R+B!"971I
M:VQE<FEN('!A;F]Y82!N87/];"!U;&'^86-A\/UN_2!G]G-T97)E;B!M;WII
M;&QA+B(*(F]R9R!T96MN:6L@;F]T=6YU(&?V<FUE:R!IYVEN($56150@:2!T
M_6ML87G];BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R(")"
M96QI<G1I;&UI_B!R96YK=&5N('9A>F=EYR(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C@V(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z.3(V"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z.3,R"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`B
M1&5S=&5K;&5N;65Y96X@57IA;G3](@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HQ.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,S,*;7-G:60@(E5P9&%T92(*;7-G<W1R(")'_&YC96QL92(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,CD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B57!D871E("5S(@IM<V=S='(@(D?\;F-E;&QE.B`E<R(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S8*;7-G:60@(E5P9&%T
M92!U<V5R(@IM<V=S='(@(DMU;&QA;OUC_7G](&?\;F-E;&QE(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E5P9&%T960@7"(E<UPB+B(*;7-G<W1R(")'_&YC96QL96YD
M:3H@)R5S)R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS9VED
M(")5<&=R861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R(")9_&MS96QT;64@
M8F5T:?!I('-I;&EL;F1I+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M-S@@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y.0IM
M<V=I9"`B57!L;V%D(@IM<V=S='(@(EG\:VQE(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N
M('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(D+\=/QN('5Y
M9W5L86UA;&%R_6X@87EA<B!D;W-Y86QA<OT@<W5N=6-U>6$@>?QK;&5N9&DN
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R
M(")"_'G\:R!L871I;B!H87)F;&5R:2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R
M(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B0OQY_&L@<F]M82!R86MA;6QA<OTB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$S"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(E5R=6=U
M87DB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R
M+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@)7,B
M"FUS9W-T<B`B2W5L;&%N.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S
M='(@(E-33"!K=6QL86XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T
M"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R
M($E-4U`@<V5R=F5R+B(*;7-G<W1R(")+=6QL86[]8_T@863];OUZ+W!A<F]L
M86[]>B!)35-0('-U;G5C=2!IYVEN(&9A<FML_2!I<V4@:W5L;&%N_6XN(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,0HC+"!F=7IZ
M>0IM<V=I9"`B57-E<B(*;7-G<W1R(")+=6QL86[]8_UL87(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<R,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB
M"FUS9W-T<B`B)7,@:W5L;&%N_6/]<_T@)7,@:>=I;B!D;_!R=6QA;F%M863]
M+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!9&UI;FES
M=')A=&EO;B(*;7-G<W1R(")+=6QL86[]8_T@6?9N971I;6DB"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(U,0IM<V=I9"`B57-E<B!/<'1I
M;VYS(@IM<V=S='(@(DMU;&QA;OUC_2!39>=E;F5K;&5R:2(*"B,Z('-I9VYU
M<"YP:'`Z-C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(DMU
M;&QA;OUC_2!+87G]="(*"B,Z('-I9VYU<"YP:'`Z,C(*;7-G:60@(E5S97(@
M4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N
M(@IM<V=S='(@(D)U('-I=&4@:>=I;B!K=6QL86[]8_T@:V%Y9/T@<V7G:6QM
M97H@:_UL_6YM_?YT_7(N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0V
M.0HC+"!F=7IZ>0IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N9"(*;7-G
M<W1R("(E<R!B=6QU;F%M863]+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.3@*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34P('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C,S"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z-S(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G
M:60@(E5S97)N86UE(@IM<V=S='(@(DMU;&QA;OUC_2!!9/TB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@86QR96%D>2!E>&ES=',N
M(@IM<V=S='(@(DMU;&QA;OUC_2`G)7,G('IA=&5N('9A<BXB"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*
M;7-G<W1R(")+=6QL86[]8_T@063].B(*"B,Z('1E;7!L871E<R]L;V=I;B]M
M;V)I;&4N:6YC.C@*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B2W5L;&%N
M_6/](&%D_3H@(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`B4VES=&5M
M9&5K:2!K=6QL86[]8_UL87(Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,SD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B57IB
M96MI<W1A;B(*;7-G<W1R("+6>F)E:VES=&%N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,38S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C(U-0IM<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS
M9W-T<B`B5D93(&1I>FEN:2!Y;VLN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$Q.`IM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B5&%T:6PB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-C8*;7-G:60@(E9A;&ED(&QO
M8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`B1V7G97)L:2!K;VYU
M;6QA<OUN(&GG97)D:6ML97)I.B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C,X"FUS9VED(")686QI9&ET>2(*;7-G<W1R(")'9>=E
M<FQI;&EK(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU.3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C4U"FUS9VED(")686QU92!I;B!M:6YU=&5S(&9R;VT@
M;F]W+B(*;7-G<W1R("+>=2!A;F1A;B!I=&EB87)E;B!D86MI:V$@9&7P97)I
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#4V(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@
M:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#0@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C(V-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S$V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C@*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0IM<V=I9"`B5F%L=65S
M(@IM<V=S='(@(D1E\&5R;&5R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$P.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@V"FUS9VED(")6
M86QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B1&7P97)L97)I;B!S9>=I
M;&5C9?!I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R
M(")686YU871U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T
M-`IM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B1&7P:?YK96XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$U"FUS9VED(")696YE>G5E;&$B"FUS9W-T<B`B5F5N97IU96QL82(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED
M(")697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E
M(&)E96X@=&%M<&5R960@=VET:"XB"FUS9W-T<B`B1&_P<G5L86UA(&)A_F%R
M_7/]>B!O;&1U("T@8G4@:6QE=&D@:W5R8V%L86YM_?X@;VQA8FEL:7(N("`B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,`IM<V=I
M9"`B5F5R<VEO;B(*;7-G<W1R(")3_'+\;2(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR,C8*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R
M(")3_'+\;2!+;VYT;VS\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI9VXB
M"FUS9W-T<B`B1/S^97D@2&EZ82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B
M"FUS9W-T<B`B1/S^97D@>6%S=/UK;&%M82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*
M;7-G<W1R(")$_/YE>3HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HW,`IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(L=O:R!9
M_&MS96LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:65T($YA;2(*;7-G<W1R
M(")6:65T;F%M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.30*;7-G:60@
M(E9I971N86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B5FEE=&YA;6-A("A625-#
M24DI(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.38R
M"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B1_9R_&YT
M_&QE("5S(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE
M=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*;7-G<W1R(")":7(@9/W^('=E8B!S
M87EF87/](&?V<OQN=/QL92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C@R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&%S("5S
M(@IM<V=S='(@(B5S(&]L87)A:R!G]G+\;G3\;&4B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V
M"FUS9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R(")"<FET
M86YY82=Y82!A:70@5FER9VEN($%D86QA<OTB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS
M9VED(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R(")!;65R:6MA($)I
M<FQE<OYI:R!$979L971L97)I)VYE(&%I="!6:7)G:6X@061A;&%R_2(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Y"FUS9VED(")6:7-I8FEL:71Y(@IM
M<V=S='(@(D?V<OS^(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(V,PIM<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(D?V<OS^.B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP
M.C@T"FUS9VED(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R(")3
M3510('EO;'5Y;&$@5F]D869O;F4@W71A;'EA(@H*(SH@9G)A;65W;W)K+TYO
M=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS
M-@IM<V=I9"`B5T%23B(*;7-G<W1R(")705).(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A
M(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(E59
M05))(2$A)7,@W<?=3D1%3B!"153=T-T@14P@W4Q%(,=)2T%25$E.+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"B,L(&9U
M>GIY"FUS9VED(")724X@=FEA($A45%`B"FUS9W-T<B`B2%144"!Y;VQU>6QA
M('-M<S)E;6%I;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E=A;&QI<R!A;F0@
M1G5T=6YA(@IM<V=S='(@(E=A;&QI<R!V92!&=71U;F$B"@HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N
M<&AP.C(Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP
M.C(W,B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#,*;7-G:60@(E=A<FYI;F<B
M"FUS9W-T<B`B57EA<OTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G<W1R("+'<OXB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H97(@
M1F]R96-A<W0B"FUS9W-T<B`B2&%V82!486AM:6YI(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C0R-PIM<V=I9"`B5V5A=&AE<B!D871A('!R
M;W9I9&5D(&)Y(@IM<V=S='(@(DAA=F$@=F5R:7-I('-A\&QA>?UC_7/](@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DR"FUS9VED(")796%T:&5R
M+F-O;2(*;7-G<W1R(")796%T:&5R+F-O;2(*"B,Z(&QI8B]";&]C:R]G;V]G
M;&4N<&AP.C,V"FUS9VED(")796(B"FUS9W-T<B`B5V5B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0S-PIM<V=I9"`B5V5B(%-I=&4B"FUS9W-T
M<B`B5V5B(%-I=&5S:2(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN
M=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R(")(869T86S]
M:R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED(")7
M96QC;VUE(@IM<V=S='(@(DAO_F=E;&1I;FEZ(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VUO8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W
M"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B
M)7,@2&_^9V5L9&EN:7HB"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H
M<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B2&_^9V5L9&EN:7HL("5S
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@(E=E<W1E<FX@
M*$E33RTX.#4Y+3$I(@IM<V=S='(@(D)A=/T@*$E33RTX.#4Y+3$I(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.38*;7-G:60@(E=E<W1E<FX@*$E33RTX
M.#4Y+3$U*2(*;7-G<W1R(")"873]("A)4T\M.#@U.2TQ-2DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B0F%T_2!386AR
M82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,S<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A
M9G1E<B!L;V=I;C\B"FUS9W-T<B`B)7,@9VER:?YT96X@<V]N<F$@:&%N9VD@
M=7EG=6QA;6%Y_2!G]G+\;G3\;&5S:6X_(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z,30*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM:71E<B!C
M:&%R86-T97(_(@IM<V=S='(@(E/];OUR;&%Y_6/](&MA<F%K=&5R(&YE9&ER
M/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS9VED(")7
M:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(D%K=&%R_6T@
M:V%R86MT97)I(&YE9&ER/R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,#8Q"B,L(&9U>GIY"FUS9VED(")7:&5R96ES($%U
M<W1R86QI82!M87`B"FUS9W-T<B`B079U<W1U<F%L>6$B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E<R(*;7-G<W1R(")(
M86YG:2!%=G)E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,PIM<V=I
M9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@
M961I=&]R+B(*;7-G<W1R("(B"B):96YG:6X@365T:6X@9/QZ96YL97EI8VES
M:2!IYVEN(&AA;F=I('5Y=6UL=2!E:VQE<B!S9>=I;&5B:6QI<B!K_6S];G/]
M;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@T"FUS9VED(")7:61T:"(*;7-G<W1R(")'96YI_FQI:R(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C4*;7-G:60@(E=I9'1H(&EN
M($-34R!U;FET<R(*;7-G<W1R(")#4U,@8FER:6UI>6QE(&=E;FG^;&EK(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@
M969F96-T(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`B4V]L9&%K:2`E<R!M
M96[\<_QN_&X@9V5N:?YL:?!I("AB:7(@<V]N<F%K:2!G:7)I_G1E(&5T:VEN
M(&]L86-A:RDZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*;7-G<W1R
M("+':7IE;&=E;FEN(&=E;FG^;&GP:2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET(@IM
M<V=S='(@(D=E;FG^;&EK(&)I<FEM:2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED(")7:61T:#HB"FUS9W-T
M<B`B1V5N:?YL:6LZ(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4Q
M,PIM<V=I9"`B5VEK:2(*;7-G<W1R(")7:6MI(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,P,"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV-0IM<V=I9"`B5VEN9"(*;7-G<W1R(")2_'IG87(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@IM<V=I
M9"`B5VEN9"!%87)L>2(*;7-G<W1R(")%<FME;B!386%T;&5R9&4@4OQZ9V%R
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,`IM<V=I9"`B5VEN9"!S<&5E
M9"!I;B!K;F]T<R(*;7-G<W1R(")+;F]T(&)I<FEM:6YD92!R_'IG87(@:/UZ
M_2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34V"FUS9VED(")7:6YD.B(*
M;7-G<W1R(")2_'IG87(Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(T,@IM<V=I9"`B5VEN9#H@(@IM<V=S='(@(E+\>F=A<CH@(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB"FUS9W-T
M<B`B0FEL9V5L:6LB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DV
M"B,L(&9U>GIY"FUS9VED(")7:7-H;&ES="(*;7-G<W1R("+=<W1E:R!,:7-T
M97-I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K
M(@IM<V=S='(@(MW^(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`BW?X@
M061R97-I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R("+=_B!496QE9F]N
M=2(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$V.2!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E
M9"P@9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C,P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB
M97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$Q-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE(')E
M861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B5D93(&1I>FEN:2!Y87)A=/UL
M_7)K96X@97)I_FEM(&5N9V5L;&5N9&DN(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(T,PIM<V=I9"`B6"U2968B"FUS9W-T<B`B6"U2968B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B
M6#4P.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(E@U,#EV,R!496UE
M;"!+_7/]=&QA;6%L87+](@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.3(*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B
M"FUS9W-T<B`B6#4P.78S($=E;FG^;&5T:6QM:?X@06YA:'1A<B!+=6QL86[]
M;?TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM
M<V=I9"`B6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R
M(")8-3`Y=C,@UG1E:VD@2V]N=2!!9/TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y
M($ED96YT:69I97(B"FUS9W-T<B`B6#4P.78S($MO;G4@06YA:'1A<B!486[]
M=/UC_7/](@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M.#(*;7-G:60@(E@U,#EV,R!E>'1E;G-I;VYS(@IM<V=S='(@(E@U,#EV,R!U
M>F%N=/UL87+](@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9
M(@IM<V=S='(@(EE9(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0Q,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#4U"FUS9VED(")965E9(@IM<V=S='(@(EE965DB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$P.`IM<V=I
M9"`B66%H;V\A(&UA<"(*;7-G<W1R(")986AO;R$@:&%R:71A<_TB"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED
M(")996%R;'DB"FUS9W-T<B`B6?UL;/UK(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I
M9"`B665M96XB"FUS9W-T<B`B665M96XB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED(")997,B"FUS9W-T<B`B
M179E="(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH
M=&UL.C4V"FUS9VED(")997,L($D@06=R964B"FUS9W-T<B`B179E="P@2V%B
M=6P@161I>6]R=6TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C4R"FUS9VED(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S
M92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB
M"FUS9W-T<B`B(@HB3454W4X@34]$54Y$05-)3DE:+B!;/#Y=(&3\\&UE;&5R
M:6YI(&MU;&QA;F%R86L@5UE325=91R!G]G+\;OQM_&YE(&3V;OQN+B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@
M)60@8FQO8VMS+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C$T,3$*;7-G:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N
M(@IM<V=S='(@(D1O\')U;&%N86UA9/UN_7HN(@H*(SH@9G)A;65W;W)K+TED
M96YT:71Y+TED96YT:71Y+G!H<#HS,#(*;7-G:60@(EEO=2!C86X@;F]T(&AA
M=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*;7-G
M<W1R("(G7%PG(&MA<F%K=&5R:2!T86T@863];OUZ9&$@8G5L=6YA;6%Z+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-34@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3DW-0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V
M86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R(")'9>=E<FQI(&)I<B!E;&5K
M=')O;FEK('!O<W1A(&%D<F5S:2!G:7)M961I;FEZ+B(*"B,Z(&9R86UE=V]R
M:R]$871A+T1A=&$N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9
M;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I
M;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S+B(*;7-G
M<W1R("(B"B(E<R!IYVEN9&4@:V%R_OUL_6L@9V5L96X@86QA;FQA<FQA("AI
MYV5R:2D@86MT87+];&%N(&1O<WEA9&%K:2!A;&%N;&%R_2`B"B)E_FQE_G1I
M<FUE9&EN:7HN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"FUS
M9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(L?]:_W^
M('EA<&UA9/UN_7HN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(V
M,0IM<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO
M;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B
M"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S
M='(@(B(*(D=EYV5R;&D@8FER(&-E<"!T96QE9F]N=2!N=6UA<F%S_2!G:7)M
M96QI<VEN:7HL('-A>?UL87(@=F4@<V7G96YE:VQI(&]L87)A:R`B"B)U;'5S
M;&%R87)A<_T@87)A;6$@]FYE:VD@)RLG("(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Q.#@*;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@=F%L
M:60@=F%L=64N(@IM<V=S='(@(D=EYV5R;&D@8FER(&1E\&5R(&=I<FUE;&ES
M:6YI>BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,S<*
M;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@
M=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(MQY92!K87ED_2!Y87!A8FEL;65K
M(&GG:6X@8FER(%9E<FE!\&%C_2!Y87#];&%N9/UR;6%L_7/];OUZ+B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#4V"FUS9VED(")9;W4@;75S
M="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B5D93('-O;B!A
M_F%M87/];OT@>6%P_6QA;F3]<FUA;/US_6[]>BXB"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I
M8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE
M;2!R97!O<G0N(@IM<V=S='(@(E!R;V)L96T@<F%P;W)U(&?V;F1E<FUE9&5N
M(/9N8V4@<V]R=6YU('1A<F9I(&5T;65L:7-I;FEZ+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M
M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*
M;7-G<W1R(")"=2!B8?!L86YT_6[];B!G]G-T97)D:?!I(&)I<B!54DP@9VER
M;65L:7-I;FEZ(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*
M;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E
M9"XB"FUS9W-T<B`B4VEL:6YM97-I(&GG:6X@8FER('-U;G5C=2!S9>=M96QI
M<VEN:7HN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$Y"FUS9VED(")9;W4@;75S
M="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R(")4
M96UI>FQE;FUE<VEN(&GG:6X@8FER(&MU;&QA;OUC_2!A9/T@8F5L:7)T;65L
M:7-I;FEZ+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU
M<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B4VEL
M:6YM97-I(&GG:6X@8FER(&MU;&QA;OUC_2!A9/T@8F5L:7)T;65L:7-I;FEZ
M+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E
M<FYA;64@=&\@861D+B(*;7-G<W1R(")%:VQE;FUE<VD@:>=I;B!B:7(@:W5L
M;&%N_6/](&%D_2!B96QI<G1M96QI<VEN:7HN(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,30V"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T
M;R!U<&1A=&4N(@IM<V=S='(@(D?\;F-E;&QE;FUE<VD@:>=I;B!B:7(@:W5L
M;&%N_6/](&%D_2!B96QI<G1M96QI<VEN:7HN(@H*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,X"FUS9VED(")9;W4@;75S="!S
M<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM<V=S='(@(D=E<N=E
M:VQE_G1I<FEL96-E:R!B:7(@97EL96T@8F5L:7)T;65L:7-I;FEZ+B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q
M"FUS9VED(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM
M<V=S='(@(EEE;FD@:V%T96=O<GD@863](&=I<FUE;&ES:6YI>BXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW
M,PIM<V=I9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE
M(&YU;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HY-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA
M<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(B5S(&]T
M=7)U;75N=6X@<_QR97-I(&1O;&1U+B!,_'1F96X@=&5K<F%R(&=I<FG^('EA
M</UN+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"FUS
M9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`B16QE:W1R;VYI:R!0
M;W-T82!!9')E<VEN:7HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$R
M"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@(DMI;61E;CH@
M861R97,Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8T(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y"FUS9VED(")9;W5R($EN9F]R;6%T
M:6]N(@IM<V=S='(@(D)I;&=I;&5R:6YI>B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.CDX,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN
M=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN
M9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U
M<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(B5S(&]T
M=7)U;75N=7IU;B!B8?YL86YG_6/];F1A(-UN=&5R;F5T($%D<F5S:6YI;FEZ
M(&1E\&G^=&DN($?\=F5N;&GP:6YI>FD@(@HB:V]R=6UA:R!IYVEN+"!Y96YI
M9&5N(&=I<FG^('EA<&UA;/US_6[]>BXB"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@(D%D
M_6[]>B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHU"B,L
M(&9U>GIY"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@
M9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O
M("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO
M=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H96YT:6-A=&EO;B!B86-K
M96YD+B(*;7-G<W1R("(B"B)+:6UL:6L@9&5N971I;6EN:7H@:W5L;&%N_6/]
M(&5K;&5M97EI(&1E<W1E:VQE;65M96MT961I<BP@=F5Y82!B=2#V>F5L;&EK
M("(*(F)I<B!N961E;B!Y_'K\;F1E;B!S9>=I;&5M97H@:_UL_6YM_?YT_7(N
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHU"FUS9VED
M("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P
M<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B"B)H87,@8F5E
M;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S='(@(B(*
M(DMI;6QI:R!D96YE=&EM:6YI>B!K=6QL86[]8_T@;&ES=&5L96UE>6D@9&5S
M=&5K;&5M96UE:W1E9&ER('9E>6$@8G4@]GIE;&QI:R`B"B)B:7(@;F5D96X@
M>?QZ_&YD96X@<V7G:6QE;65Z(&O];/UN;?W^=/UR+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.CDX-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9
M;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE
M(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E8W0@
M>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@
M(B(*(B5S(&]T=7)U;75N=7IU;B!B8?YL86YG_6/];F1A('1A<F%Y_6/];OUZ
M(&1E\&G^=&DN($?\=F5N;&GP:6YI>FD@:V]R=6UA:R`B"B)IYVEN+"!Y96YI
M9&5N(&=I<FG^('EA<&UA;/US_6[]>BXB"@HC.B!L:6(O0FQO8VLO:69R86UE
M+G!H<#HU,`IM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@
M=&AI<R!F96%T=7)E+B(*;7-G<W1R(")487)A>?UC_6[]>B!B=2#V>F5L;&GP
M:2!D97-T96ML96UE;65K=&5D:7(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O<')I;G0N:G,Z-#(*(RP@9G5Z>GD*;7-G:60@(B(*(EEO=7(@8G)O=W-E
M<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#
M;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R("(B"B)4
M87)A>?UC_6[]>B!B=2!Y87ID_7)M82!T97)C:6AI;FD@9&5S=&5K;&5M96UE
M:W1E9&ER+EEA>F3]<FUA:R!IYVEN($-O;G1R;VPO(@HB3W!T:6]N("L@4"!T
M=?YL87+];F$@8F%S_6XN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U
M-PIM<V=I9"`B66]U<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`B6F%M
M86X@1&EL:6UI;FEZ.B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY-@HC+"!F
M=7IZ>0IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H
M86YG960N(@IM<V=S='(@(M9N('1A;OUM;/T@:VEM;&GP:6YI>CHB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34X"FUS9VED(")9;W5R(&1E9F%U;'0@
M:61E;G1I='DZ(@IM<V=S='(@(M9N('1A;OUM;/T@:VEM;&GP:6YI>CHB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`Q"FUS9VED(")9;W5R(&9U;&P@
M;F%M93HB"FUS9W-T<B`B5&%M($%D_6[]>CHB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HQ,#`P"B,L(&9U>GIY"FUS9VED(")9;W5R(&QO9VEN(&AA
M<R!E>'!I<F5D+B(*;7-G<W1R(")39>=E;F5K;&5R:6YI>B!G_&YC96QL96YD
M:2XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S
M(@IM<V=S='(@(B5S(&GG:6X@>65N:2!P87)O;&%N_7HZ("5S(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-30*;7-G:60@(EEO=7(@;W!T
M:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H
M:7,@<V5S<VEO;BXB"FUS9W-T<B`B4V7G96YE:VQE<FEN:7H@8G4@;W1U<G5M
M=6X@<_QR97-I(&GG:6YD92!G_&YC96QL96YD:2XB"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA
M=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R(")39>=E;F5K;&5R:6YI>B!G_&YC
M96QL96YD:2XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM
M<V=I9"`B66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="(*;7-G<W1R(")0
M87)O;&%N_7H@<_UF_7)L86YD_2XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R
M97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N
M97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*(E!A<F]L86[]>B!S_6;]<FQA
M;F3]+"!E;&5K=')O;FEK('!O<W1A;OUZ_2!K;VYT;VP@961I;B!V92!Y96YI
M('!A<F]L86[]>FQA("(*(F=I<FG^('EA</UN+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.C<S,@HC+"!F=7IZ>0IM<V=I9"`B66]U<B!P87-S=V]R
M9"!H87,@97AP:7)E9"XB"FUS9W-T<B`B4&%R;VQA;OUZ('/]9OUR;&%N9/TN
M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9
M;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R(")5>F%K=&%K:2!S=6YU8W5L
M87+];OUZ.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4T(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EEU9V]S;&%V
M:6$B"FUS9W-T<B`B675G;W-L879Y82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@(EIA:7)E(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-38@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(EIA;6)I82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(EII;6)A
M8G9E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P
M>2(*;7-G<W1R(")(_7IL_2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&
M:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E
M9"!497AT72(*;7-G<W1R(");06S];G3]($UE=&YI(%-A:VQA72(*"B,Z('-E
M<G9I8V5S+W!R;V)L96TN<&AP.C@X"FUS9VED(");4')O8FQE;2!297!O<G1=
M(@IM<V=S='(@(EM0<F]B;&5M(%)A<&]R=5TB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D
M(%1E>'0@+2(*;7-G<W1R(");06S];G3]($UE=&YI($?V<W1E<B`M(@H*(SH@
M9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N
M<&AP.C$W,@HC+"!P:'`M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T960@5&5X
M="`M("5S(&QI;F5S72(*;7-G<W1R(");06S];G3]($UE=&YI($?V<W1E<B`M
M("5S('-A=/UR72(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DS
M"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F("5S72(*;7-G<W1R
M("(E<R\E<R!S873]<B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,34T,2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q"FUS9VED(")?061M
M:6YI<W1R871I;VXB"FUS9W-T<B`B7UGV;F5T:6TB"@HC.B!L:6(O87!I+G!H
M<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T<B`B7T-,22(*"B,Z(&QI8B]A<&DN
M<&AP.C$T,0IM<V=I9"`B7T1A=&%4<F5E(@IM<V=S='(@(E]697)I0?!A8_TB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S$*;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(E-A=/UR_2!?
M4VEL(@H*(SH@;&EB+V%P:2YP:'`Z,3,S"FUS9VED(")?1W)O=7!S(@IM<V=S
M='(@(E]'<G5P;&%R(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N
M<&AP.C$W-0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`B66%R7V3];2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M,PIM<V=I9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B1_9R_&YT
M_"#67WIE;&QI:VQE<FDN+BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M365N=2YP:'`Z,3DT"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(D=I7W)I_B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.3`*;7-G:60@
M(E],;V<@;W5T(@IM<V=S='(@(L?]7VO]_B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO
M9&EF>2!,:6YK+BXN(@IM<V=S='(@(E]"8?!L86YT_7G]($1E\&G^=&ER+BXN
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V-`IM<V=I
M9"`B7T]P=&EO;G,B"FUS9W-T<B`B7U-EYV5N96ML97(B"@HC.B!L:6(O87!I
M+G!H<#HQ,S<*;7-G:60@(E]097)M:7-S:6]N<R(*;7-G<W1R(")?2&%K;&%R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(V"FUS9VED(")?4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`B0F'P
M;&%?;G3]>?T@4VEL+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3(U"FUS9VED(")?
M4V5T=7`B"FUS9W-T<B`B7T%Y87)L87(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L
M92!0<F]P97)T:65S+BXN(@IM<V=S='(@(L=I>F5?;&=E(-9Z96QL:6ML97)I
M+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?57-E<G,B"FUS9W-T
M<B`B2U]U;&QA;OUC_6QA<B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3(Q"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`B861R97,@9&5F
M=&5R:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,T
M"B,L(&9U>GIY"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R(")A
M9')E<R!D969T97)I(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY
M,3,*;7-G:60@(F-A;&5N9&%R(@IM<V=S='(@(G1A:W9I;2(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A<BYP:'`Z,S4X"B,L
M('!H<"UF;W)M870*;7-G:60@(F-A;&TB"FUS9W-T<B`B_6S];6S](@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A
M;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O
M<&5N(&EN<'5T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C4Y,@IM<V=I9"`B8VQI8VL@:&5R92(*;7-G<W1R(")B
M=7)A>6$@=/UK;&%Y_6XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,3<X"B,L(&9U>GIY"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S
M='(@(EEA</UL86YD_7)M82!&87)K;&%R_2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED(")C<FET:6-A;"!S>7-T96T@
M9FEL92!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,3(V"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$X,@HC+"!F=7IZ>0IM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S='(@
M(F)U;'5N86UA9/TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HW,0IM<V=I9"`B9F%L;&EN9R(*;7-G<W1R(")D_/[\>6]R(@H*
M(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4U"FUS9VED(")F
M:6QE(@IM<V=S='(@(F1O<WEA(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C`@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A
M="`E<R`E<R(*;7-G<W1R("(E<R`H)7,I(&1E;B`E<R`E<R!D92(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3`*(RP@9G5Z>GD*;7-G:60@
M(F=U<W1I;F<B"FUS9W-T<B`B+"!F_7)T_6YA;/T@)7,@)7,B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0Y"FUS9VED(")H
M.B(*;7-G<W1R(")H.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HS-3@*;7-G:60@(FAH(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,X"FUS9VED(")H;W-T(&YA
M;64@=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(FEM;65D:6%T
M92(*;7-G<W1R(")!8VEL(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(FEN;&EN92(*;7-G<W1R
M(")-971N92!G]FW\;/PB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,30V"FUS
M9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B
M;&EN97-=(@IM<V=S='(@(G-A=/UR;&%R72(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG
M($E33RXB"FUS9W-T<B`B;6MI<V]F<R!)4T\@>6%P87)K96X@:&%T82!K;V1U
M.B5D+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HS-CD*;7-G:60@(FUM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,CDQ('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ-S`*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(S,@IM<V=I
M9"`B;F%M92(*;7-G<W1R(")A9"(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H
M<#HQ,C$*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R(")G97+G96ML
M9?YT:7)I;&UE9&DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C$R,3D*;7-G:60@(FYO="!Y970@:6UP;&5M96YT960B"FUS9W-T<B`B
M:&5N_'H@9V5RYV5K;&7^=&ER:6QM961I(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,#4*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B;F]T(&1E
M9G1E<FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@X"FUS9VED(")P97)C96YT(@IM<V=S='(@(GG\>F1E(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S0*(RP@9G5Z
M>GD*;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(MUZ:6XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@Y"FUS9VED(")P:7AE;',B"FUS9W-T<B`B<F5S:6T@8FER:6UI(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S`*;7-G:60@(G)E
M;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,PIM<V=I9"`B<FES:6YG
M(@IM<V=S='(@(GG\:W-E;&EY;W(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$T,@HC+"!F=7IZ>0IM<V=I9"`B<V5R=FEC92!U;F%V
M86EL86)L92(*;7-G<W1R(")(879A(')A<&]R=2#V8F7P:2!K=6QL86[];&%B
M:6QI<B!D9?!I;"XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.CDY"FUS
M9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@(F9A<FML87+](&?V<W1E
M<B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B"FUS9W-T<B`B2%14
M4"!Y;VQU>6QA('-M<S)E;6%I;"(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HS.#4*;7-G:60@(G-S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED
M(")S=&5A9'DB"FUS9W-T<B`B<V%B:70B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C,P.0IM<V=I9"`B<W=I=&-H(&]F9B!J879A<V-R:7!T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,34P"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,CD*;7-G:60@(G1A<VL@;&ES="(*;7-G
M<W1R(")G]G)E=B!L:7-T97-I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S`U"B,L(&9U
M>GIY"FUS9VED(")T<GD@86=A:6XB"FUS9W-T<B`B2&5R($=I<FG^=&4B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HS-B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU
M<"YP:'`Z,C8Y"FUS9VED(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C
M;VYF:7)M(@IM<V=S='(@(G!A<F]L87G](&1O\')U;&%M86L@:>=I;B!I:VD@
M9&5F82!G:7)I;B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN
M+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")U;FEF:65D(@IM<V=S='(@(F)I
M<FQE_G1I<FEL;6G^(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]087)T+G!H
M<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G<W1R(")A9&QA;F3]<OUL;6%M_?XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,C,*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S='(@(FMU;&QA;OUC
M_2!S9>=I;6DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S='(@(G9#87)D(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T,0IM<V=I9"`B
M=SHB"FUS9W-T<B`B=SHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B=V5A=&AE<BYC;VTB
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+V5L7T=2+G!O
M````````````````````````````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#4V,#8W,2`Q,#4Q-30S,S<T,R`P,3<U,C4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````(R!(;W)D92!'<F5E:R!T<F%N
M<VQA=&EO;BX*(R!#;W!Y<FEG:'0@*$,I(#(P,#(@4W1E9F%N;W,@22X@1&EM
M:71R:6]U+@HC(%-T969A;F]S($DN($1I;6ET<FEO=2`\<W5P<&]R=%]W96)M
M86EL0'1E:6%T:"YG<CXL(#(P,#(N"B,@4VEL;&EG87)D;W,@6')I<W1O9F]R
M;W,L(#(P,#(N"B,@06YA9VYO<W1O<&]U;&]S($%P;W-T;VQI<RP@,C`P,BX*
M(R!-:6QO<VES($,N($MO;G-T86YT:6YO<RP@,C`P-2X*(PIM<V=I9"`B(@IM
M<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4Z(#,N,"UC=G-<
M;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G
M7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P,BTQ,2TP-R`Q,CHP-BLP,C`P
M7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`U+3`T+3(V(#$Q.C$S*S`R,#!<
M;B(*(DQA<W0M5')A;G-L871O<CH@2V]N<W1A;G1I;F]S($,N($UI;&]S:7,@
M/&MM:6QO<VES0'EA:&]O+F-O;3Y<;B(*(DQA;F=U86=E+51E86TZ($=R965K
M(#QD979`;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<
M;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U
M.2TW7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X+6)I=%QN(@H*
M(RP@8RUF;W)M870*;7-G:60@(B(*(B`F(S$U,3L@)7,@:7,@<F5A9'D@=&\@
M<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E
M;&]W+B(*;7-G<W1R("(B"B(@)B,Q-3$[("5S(,7?[>'I(.<@\_3IX^S>(.WA
M(./?[>_U[2#OZ2#KY>GT[_7QX]_E\B#S]>WTWO'G\^?R(/#O]2#EW^WAZ2`B
M"B+E\.GKY>/LW>WE\B#PX?'AZMST^2XB"@IM<V=I9"`B("!4:&4@;6%I;&)O
M>"!T<F%S:"!I<R!A;')E861Y(&5M<'1Y+B(*;7-G<W1R("(@(,<@X_'A[.SA
M]._H]?'?Y.$@)^K<Y._R)R#EW^WAZ2#>Y.<@W.3EZ>$N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,U,0IM<V=I9"`B("@E<R!D87ES(&%G;RDB
M"FUS9W-T<B`B("CP\>GM(.'P_"`E<R#G[-WQY?(I(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ,C<W"FUS9VED("(@*$%C8V5S<VME>2`E<RDB
M"FUS9W-T<B`B("C*Z^7IY-\@\/'\\^+A\^?R("5S*2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(S-3D*;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS
M9W-T<B`B("CSY2`E<R#G[-WQY?(I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C,U-0IM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B("CSWNSE\>$I
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,U-PIM<V=I9"`B("AT
M;VUO<G)O=RDB"FUS9W-T<B`B("CA_?'I[RDB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,S4S"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B
M("CWZ.7R*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#`*
M;7-G:60@(B!A="`B"FUS9W-T<B`B(//TZ?(@(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$X-@IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S
M='(@(B5D("5S(.KAZ2`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,C<*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R("(E9"WL
MY?'G(/#Q_.+KY?CG(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VYO=&EC
M95]T;W`N:6YC.C0*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B5S("T@
MT^?LY=_Y\^<B"@HC.B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI
M;F,Z,CD*;7-G:60@(B5S($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B5S+<3I
MX??EW_'I\^<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C<R.`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B)7,@Q.'J]/7K
MZ>K\(.'P[_3]\/GLX2(*"B,L(&,M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N
M86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B5S(,OE
MZ?3O]?'CW^7R(-/U[?3>\>?SY_(@+2#%\.GBY>+AW_GSYR(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P
M.0IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B)7,MT.'QX>SE]/'O\._?Y_/G
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W-@IM<V=I
M9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(E<R#%X^/QX?;>(@H*(SH@=&5M<&QA
M=&5S+VUA:6YT96YA;F-E+V%G<F5E;65N=%]T;W`N:6YC.C0*;7-G:60@(B5S
M(%1E<FUS(&]F($%G<F5E;65N="(*;7-G<W1R("(E<R#/\>_I(/?QWO/G\B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-3DV(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z-C8V"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB
M"FUS9W-T<B`B)7,@WN3G(/7PW/'WY>DN(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ-3<@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C,@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,S<*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#,@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS-#D*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@
M(B5S(//E("5S("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HU,S`*;7-G:60@(B5S(&AA<R!C86YC96QL960@)7,N
M(@IM<V=S='(@(B5S(.'J]?'^Z.?JY2`E<RXB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0R-@IM<V=I9"`B)7,@:&%S
M(')E<&QI960@=&\@82!F<F5E+V)U<WD@<F5Q=65S="XB"FUS9W-T<B`B)7,@
MX?#<[?3G\^4@\^4@Y?'^].?LX2#DZ>'HY?/I[/STY_3A\BXB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4R-`IM<V=I
M9"`B)7,@:&%S(')E<&QI960@=&\@=&AE(&EN=FET871I;VX@=&\@)7,N(@IM
M<V=S='(@(B5S(.'PW.WTY_/E(//TY^T@\/'\\^KKY_/G(./IX2`E<RXB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0Q
M-@IM<V=I9"`B)7,@:&%S('-E;G0@>6]U(&9R964O8G5S>2!I;F9O<FUA=&EO
M;BXB"FUS9W-T<B`B)7,@\^'R(-WS].7IZ^4@\.OG\>_V[_'?Y?(@Y.GAZ.7S
MZ>S\].?TX?(N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,R,0IM
M<V=I9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`B)7,@Y=_MX>D@X?#AZ?3O
M_>SE[>\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X-`IM<V=I9"`B)7,@
M;6EN=71E<R(*;7-G<W1R("(E<R#KY?#TW"(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#(Q"FUS9VED("(E<R!R97%U
M97-T<R!Y;W5R(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B)7,@
M\^'R(.;>].?SY2#PZ^?Q[_;O\=_E\B#DZ>'HY?/I[/STY_3A\BXB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4P.`IM
M<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!P<F5S96YC92!A="`E<RXB"FUS9W-T
M<B`B)7,@YM[TY_/E(/3G[2#PX?'O]?/?X2#SX?(@\_3I\B`E<RXB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHV"FUS9VED("(E<R!T;R`E
M<R!O9B`E<R(*;7-G<W1R("(E<R#Y\B`E<R#A\/P@)7,B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4Q,PIM<V=I9"`B
M)7,@=VES:&5S('1O(&%D9"!T;R`E<RXB"FUS9W-T<B`B)7,@Y?#IZ/7LY=\@
M].?M(/#Q[_/HWNKG(//T[R`E<RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C4P,@IM<V=I9"`B)7,@=VES:&5S('1O
M(&UA:V4@>6]U(&%W87)E(&]F("5S+B(*;7-G<W1R("(E<R#E\.GH]>SEWR#M
MX2#SX?(@Y>WG[.7Q_O/EZ2#CZ>$@)7,N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,3@*;7-G:60@(B5S('=I<VAE
M<R!T;R!R96-E:79E('1H92!L871E<W0@:6YF;W)M871I;VX@86)O=70@)7,N
M(@IM<V=S='(@(B5S(.7PZ>CU[.7?(.WA(.O<XN7I(/3I\B#TY>OE]?3AW^7R
M(/#KY_'O]N_QW^7R(./IX2`E<RXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDQ,@IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B
M)7,G<R#$Z>7UZ/7M\^GOX_'<]N_R(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HY,#0*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B)7,G
M<R#'[.7Q[^O\X^GO(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HX
M.38*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R("(E<W,@T^?LY>GY[.'T
MW/'I[R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(P"FUS9VED
M("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(B5S<R#+W_/TX2#%\>/A\^G^[2(*
M"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-S`*;7-G:60@(B<E<R<@:7,@
M;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R("(G)7,G(.3E[2#EW^WAZ2#=
MX^KU\><@Y?#IZ^_CWBXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G
M:7-T<GDN<&AP.C4X,@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T
M<GDN<&AP.CDX,@IM<V=I9"`B)R5S)R!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T
M:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@(B<E<R<@Y.7M(-WWY>D@\?7H
M[.GS].7?(//T[R!R96=I<W1R>2#TY_(@Y?;A\>SOX][R($AO<F1E(@H*(SH@
M9G)A;65W;W)K+U1R964O5')E92YP:'`Z,38P"FUS9VED("(G)7,G('1R964@
M<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R("(E<R#A[>'PX?'A\_3<].?R
M(.3E[>3QZ>K>\B#D[^S>\B#DY>T@XO'=Z.?JY2XB"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C4W"FUS9VED("(G)7,G('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S
M('-Y<W1E;2XB"FUS9W-T<B`B)R5S)R#P\>_S]-WHY^KE(//TZ?(@[^S<Y.7R
M(//U\_3>[.'T[_(N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C@U
M"FUS9VED("(G)7,G('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES
M=&5M+B(*;7-G<W1R("(G)7,G(/#Q[_/TW>CGZN4@\_3I\B#<Y.7IY?(@]._U
M(//U\_3>[.'T[_(N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-2!A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`Z.#,*;7-G:60@(B<E<R<@=V%S(&YO="!C<F5A
M=&5D.B`E<RXB"FUS9W-T<B`B)R5S)R#DY>T@Y.?LZ>_U\>/>Z.?JY3H@)7,N
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#8@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ.3$*;7-G:60@(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(L(&=U
M<W1I;F<@)7,@)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Y.0IM<V=I
M9"`B+"!V87)I86)L92!F<F]M("5S('1O("5S(@IM<V=S='(@(BP@[.7TX>+K
MY_3>(.'P_"`E<R#SY2`E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(P-3(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q,0HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-CDQ"FUS9VED("(M+2!S
M96QE8W0@+2TB"FUS9W-T<B`B+2T@Y?#IZ^_CWB`M+2(*"B,Z(&QI8B]";&]C
M:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS9W-T<B`B
M,3+Y\><@[._Q]MXB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3D*;7-G:60@
M(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(C(T^?'G(.SO\?;>(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S
M='(@(C(T(/[QY?(B"@IM<V=I9"`B/&(^02!F871A;"!E<G)O<B!H87,@;V-C
M=7)R960Z/"]B/B(*;7-G<W1R("(\8C[0X?'O]?/IW//TY^KE(-WMX2#S[^+A
M\?P@Z]SH[_(Z/"]B/B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,38V"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R
M("+0X?'O]?/IW//HY^KE(.KQW_/I[.\@Z]SH[_(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-#$*;7-G:60@(D$@<'5B;&EC(%!'4"!K
M97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@
M(L'PX>GTY=_TX>D@Y.?L_//I[R#JZ^7IY-\@4$=0(./IX2#TY^T@ZO'U\/3O
MX_'<]N?SYR#E[?SR(.SG[?WLX?3O\BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,38W"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES
M(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(*;7-G<W1R
M("(B"B+!\.'I].7?].'I(.3G[/SSZ>\@ZNOEZ>3?(%!'4"#CZ>$@Y?#IXN7B
MX=_Y\^<@Y>W\\B#U\._CY>/QX>SLW>WO]2#LY^W][.'T[_(N(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Y.`IM<V=I9"`B(@HB02!P
M=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S
M='(@(B(*(L'PX>GTY=_TX>D@Y.?L_//I[RP@\/'O\_GPZ>K\(%!'4"#JZ^7I
MY-\@ZN'I(.O=[N<MZOGDZ>K\\B#CZ>$@[>$@(@HBX?#OZO'U\/3OX_'A]M[S
MY?3E(-WMX2#LWNWU[.$N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3`Q-PIM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T
M92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG
M;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(L'PX>GTY=_TX>D@Y.?L_//I
M[RP@\/'O\_GPZ>K\(%!'4"#JZ^7IY-\@ZN'I(.O=[N<MZOGDZ>K\\B#CZ>$@
M[>$@]?#OX_'<^.7TY2`B"B+XY_;IX>K<(-WMX2#LWNWU[.$N(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,C,*;7-G:60@(B(*(D$@
M<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E
M+B(*;7-G<W1R("(B"B+!\.'I].7?].'I(.3G[/SSZ>\L(/#Q[_/Y\.GJ_"!3
M+TU)344@ZNOEZ>3?(.KAZ2#KW>[G+>KYY.GJ_/(@X^GA(.WA("(*(N'P[^KQ
M]?#T[^/QX?;>\^7TY2#=[>$@[-[M]>SA+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-#0Y"FUS9VED("(B"B)!('!U8FQI8R!3+TU)
M344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@HB
MP?#AZ?3EW_3AZ2#DY^S\\^GO+"#P\>_S^?#IZOP@4R]-24U%(.KKY>GDWR#J
MX>D@Z]WNYRWJ^>3IZOSR(./IX2#MX2`B"B+U\._C\=SXY?3E(/CG]NGAZMP@
MW>WA(.S>[?7LX2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C,X,@IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D
M('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("+!\.'I].7?].'I(.3G
M[/SSZ>\@ZNOEZ>3?(%,O34E-12#CZ>$@].?M(.KQ]?#T[^/QW/;G\^<@Y>W\
M\B#LY^W][.'T[_(N(@H*;7-G:60@(D%-+U!-(@IM<V=S='(@(O#L+^SL(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM
M<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`BT.7QWR#A]?3O_2#T
M[_4@RN7I[.7M[^/QW/;O]2(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP
M.C4R"FUS9VED(")!8F]U="XN+B(*;7-G<W1R("+0Y?'?+BXN(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B
M06)S8F]T=&]M(@IM<V=S='(@(L'P_.OU].\@]-WK[_(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M
M:61D;&4B"FUS9W-T<B`BP?#\Z_7TYR#,W?/G(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV-#`*;7-G:60@(D%C8V5P
M="!R97%U97-T(@IM<V=S='(@(L'P[^3O]]X@X>GTWNSA]._R(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV.#$*;7-G
M:60@(D%C8V5P=&5D(@IM<V=S='(@(L7CZ>WE(.'P[^3EZO3\(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(X-0IM<V=I9"`B06-C97-S(&1E
M;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("+'(/#Q_//B
MX?/G(.'P[_'QW_;HY^KE(.KA]-P@].<@Y.?LZ>_U\>/?X2!61E,@ZN'TX>O\
MX^_U+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,S@*;7-G
M:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@
M(L<@\/'\\^+A\^<@X?#O\?'?]NCGZN4@ZN'TW"#TYR#DY^SI[_7QX]_A(%9&
M4R#A\??EW^_U+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-0IM<V=I
M9"`B06-C;W5N="!087-S=V]R9"(*;7-G<W1R("+*^>3IZOSR(,OOX^'QZ>'S
M[._](@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`R"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`BSR#K
M[^/A\>GA\^S\\B#PW./Y\^4N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,R,`IM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R("+*X?3AX_'A]MXB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C0U,0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C8R-0IM<V=I9"`B06-T:6]N<R(*;7-G<W1R("+%[=WQX^7IY?(B"@HC
M.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-30@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ,S8*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC
M.C$T('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$V"FUS
M9VED(")!9&0B"FUS9W-T<B`BT/'O\^C>ZN<B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C(Q-"!A9&UI;B]G<F]U<',N<&AP.C(Q-0IM<V=I9"`B061D($-H:6QD
M($=R;W5P(@IM<V=S='(@(M#Q[_/HWNKG(/7P[^_LW.3A\B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z.#$@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HX,@IM<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB"FUS
M9W-T<B`BT/'O\^C>ZN<@W.3EZ>'R(/7P[^_LW.3A\B`H8VAI;&0@<&5R;6ES
M<VEO;BDB"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM<V=I9"`B
M061D($AE<F4Z(@IM<V=S='(@(M#Q[_/HWNKG(.7D_CHB"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C(P."!A9&UI;B]G<F]U<',N<&AP.C(P.0IM<V=I9"`B061D
M($YE=R!'<F]U<"(*;7-G<W1R("+0\>_SZ-[JYR#-W>'R(,_LW.3A\B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S`@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HW,0IM<V=I9"`B061D($YE=R!097)M:7-S:6]N
M(@IM<V=S='(@(M#Q[_/HWNKG(.W=X?(@W.3EZ>'R(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z.0IM<V=I9"`B061D(&$@8VAI
M;&0@9W)O=7`@=&\@)R5S)R(*;7-G<W1R("+0\>_SZ-[JYR#U\._O[-SDX?(@
M\_3O("<E<R<B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3,@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,S4*;7-G:60@(D%D9"!A(&-H
M:6QD('!E<FUI<W-I;VX@=&\@)R5S)R(*;7-G<W1R("+0\>_SZ-[JYR#<Y.7I
MX?(@*'!E<FUI<W-I;VXI(/7P[^_LW.3A\B#S].\@)R5S)R(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B
MT/'O\^C>ZN<@[=WO]2#W\=[S].<Z(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C4R.0IM<V=I9"`B061D(&-O;'5M;B(*;7-G
M<W1R("+0\>_SZ-[JYR#S]-[KY_(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V5D:70N:6YC.C,U"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T
M<B`BT/'O\^C>ZN<@[=WO]2#LW>OO]?(B"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C$P,PIM<V=I9"`B061D('!A:7(B"FUS9W-T<B`BT/'O\^C>
MZN<@YN7]X^_U\B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3$*;7-G
M:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G
M<W1R("+0\>_SZ-[JYR#T[_4@)7,@\_3O(.SE[>_](/3O]2!-;WII;&QA(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV
M,S$*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HV,S<*;7-G:60@(D%D9"!T:&ES('1O(&UY(&-A;&5N9&%R(@IM<V=S='(@
M(M#Q[_/HWNKG(.'U]._](//T[R#G[.7Q[^O\X^G\(.SO]2(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW-`IM<V=I9"`B061D
M('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`BT/'O\^C>ZN<@\_3O(,3IY?7H
M]>WSZ>_C\=SV[SHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z.#$*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS
M9W-T<B`BT/'O\^C>ZN<@\_3O(,3IY?7H]>WSZ>_C\=SV[R#L[_4B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HS,0IM<V=I9"`B061D('5S97(B"FUS9W-T<B`BT/'O
M\^C>ZN<@]_'>\_3G(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*;7-G:60@(B(*
M(D%D9&5D("<E<R<@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@
M861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("4B"B)S+B(*;7-G<W1R
M("(B"B+0\>_S]-WHY^KE("<E<R<@\_3O(//]\_3G[.$L(.'KZ]P@Y.7M(.SP
M_/'E\^$@[>$@\/'O\^C=\_D@\_7L\.OG\?GLX?3IZMWR("(*(O#KY_'O]N_Q
MW^7R(@H*(SH@<VEG;G5P+G!H<#HT-@IM<V=I9"`B061D960@)R5S)R!T;R!T
M:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(M#Q[_/T
MW>CGZN4@)R5S)R#S].\@\_WS].?LX2X@S/#O\>7?].4@[>$@\_7MY.7HY=_T
MY2#T_O'A+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHT
M"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(L<@
M\/'O\^C>ZN<@]_'G\_3^[2#=]^7I(.'PY>WE\>/O\._IY^CEWRXB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(Y"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-S8@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,30S-PIM<V=I9"`B061D<F5S<R(*;7-G<W1R
M("+$Z>7]Z/7M\^<B"@IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(L3I
MY?7H]>WSZ>_C\=SV[_(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HY-PIM<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S
M:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`BQ.GA]^7?\>GSYR`M(,3^
M\_3E(.3IZN'I_NSA].$@\^4@W.OK[_7R(/?QWO/TY?(B"@HC.B!A9&UI;B]I
M;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM
M<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`BQ.GA]^7?\>GSYR(*"FUS
M9VED(")!:W1I;VX@06ER<&]R="(*;7-G<W1R("+!Y?'OZ^GLW>WA\B#!ZO3?
M[_4B"@IM<V=I9"`B06QE>&%N9')O=7!O;&D@06ER<&]R="(*;7-G<W1R("+!
MY?'OZ^GLWNT@P>OE[N'MY/'O_?#OZ^?R(@H*;7-G:60@(D%L:6%S(@IM<V=S
M='(@(MCE]>3^[?7L[R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,38*;7-G:60@(D%L:6=N(@IM<V=S='(@(L7U
MZ/7C\=SL[.GSY2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N=#HB"FUS9W-T<B`BQ?7H]>/Q
MW.SLZ?/G.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM<V=I9"`B
M06QL(@IM<V=S='(@(L_KX2(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$Q
M."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C<Q"FUS9VED(")!;&P@075T
M:&5N=&EC871E9"!5<V5R<R(*;7-G<W1R("+/Z^_I(._I(-WCZO7Q[^D@]_'>
M\_3E\B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H
M<#HR,3(*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`BS^OE\B#OZ2#/[-SD
MY?(B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z,S@@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HW-`IM<V=I9"`B06QL(%!E<FUI<W-I;VYS
M(@IM<V=S='(@(L_KX2#TX2#DZ>KAZ?[LX?3A(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL
M(&9O=7(@<VED97,B"FUS9W-T<B`BRN'I(._I(/3=\_/E\>GR("@T*2#PZ^7U
M\=WR(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U-`IM<V=I9"`B
M06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(LWA(.7PZ?3QW?#O
M[?3AZ2#P[^OKX?#KW?(@Y.GE]>C][?/EZ?(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3$W"FUS9VED(")!;&QO=R!S971T:6YG(&]F(&]R9&5R960@
M;&ES="!T>7!E/R(*;7-G<W1R("+-X2#E\.GT\=WP[^WTX>D@\?7H[-_SY>GR
M(/3A[NGM[^SI[-WM^>T@Z^GS]/[M.R(*"B,Z(&9R86UE=V]R:R]$871A5')E
M92]$871A5')E92]S<6PN<&AP.C0P,0IM<V=I9"`B06QR96%D>2!E>&ES=',B
M"FUS9W-T<B`BQ^3G(/7PW/'WY>DB"@IM<V=I9"`B06QT97)N871E($E-4U`@
M3&]G:6XB"FUS9W-T<B`BQ>WAZ^OAZO3IZMX@24U34"#%W_/OY._R(@H*;7-G
M:60@(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S='(@(L7MX>OKX>KT
MZ>K\\B!)35-0(,KYY.GJ_/(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#@R"FUS9VED(")!;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G<W1R("+%
M[>'KZ^'J].GJ_"!)35-0(+SM[^SA(-?QWO/TYR(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED(")!;'1E<FYA=&4@96UA:6P@861D
M<F5S<R(*;7-G<W1R("+%[>'KZ^'J].GJWB#DZ>7]Z/7M\^<@96UA:6PB"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B06QT97)N871E('1E
M;7!L871E<R(*;7-G<W1R("+%[>'KZ^'J].GJW"#P\?ST]?#A(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C(*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS9W-T<B`BQ>WAZ^OAZO3I
MZOP@ZN7?[.7M[SHB"@IM<V=I9"`B06X@:6QL96=A;"!V86QU92!W87,@<W!E
M8VEF:65D+B(*;7-G<W1R("+/\=_S].?JY2#LW^$@[.<@Y?#I]/'E\/SLY>WG
M(/3I[-XN(@H*;7-G:60@(D%N8VAI86QO<R!!:7)P;W)T(@IM<V=S='(@(L'E
M\>_KZ>S=[>'R(,'C]]_AZ^_U+B(*"FUS9VED(")!;F1R879I9&$@06ER<&]R
M="(*;7-G<W1R("+!Y?'OZ^GLW>WA\B#![>3QX>+?Y.'R+B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,C`*;7-G:60@(D%N;VYY;6]U<R!0
M<F]X>2(*;7-G<W1R("+![?[M]>SO\B#$Z>'L[.7S[^OAXN?TWO(@*%!R;WAY
M*2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"FUS9VED(")!
M;G-W97(B"FUS9W-T<B`BP?#<[?3G\^<B"@HC.B!A9&UI;B]T96UP;&%T97,N
M<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS,`HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO54DN<&AP.C4Y('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E
M>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(L7VX?'L[^/>
M(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R"FUS9VED(")!<'!L:6-A
M=&EO;B!,:7-T(@IM<V=S='(@(LO?\_3A(,7VX?'L[^/>\B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ,S`*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E
M861Y+B(*;7-G<W1R("+'(.7VX?'L[^/>(.7?[>'I(-WT[^GLYRXB"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(R-`IM<V=I9"`B07!P;'D@=&\@
M0VAI;&0@4VAA<F5S(@IM<V=S='(@(L7VX?'L[^/>(.KAZ2#S].$@Y>[A\?3^
M[.7MX2#J[^GM_/?QY_/TX2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C,S"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(L7CZO'?[?DB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<W
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,30*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM
M<V=I9"`B07!R:6PB"FUS9W-T<B`BP?#QW^OI[_(B"@IM<V=I9"`B07)A>&]S
M($%I<G!O<G0B"FUS9W-T<B`BP>7Q[^OI[-WMX?(@P?'<[N_U(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8V"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z.#$*;7-G:60@(D%R8VAI=F4@1FEL92!3
M:7IE(@IM<V=S='(@(LS=X^7H[_(@X?'WY=_O]2#A\??EZ>_HW?3G\^?R(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,2!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8U"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#`*;7-G:60@(D%R8VAI=F4@
M3F%M92(*;7-G<W1R("+/[>_LX2#A\??EW^_U(.'Q]^7IZ-WTY_/G\B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z.0IM<V=I
M9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P
M(')E<75E<W0@9F]R("5S(#\B"FUS9W-T<B`BQ=_S].4@\]_C[_7QYR#CZ>$@
M].<@Y.GAX_'A]MX@].?R(.'?].?SY_(@]?#OX_'A]M[R(./IX2`E<R`_(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.CD*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@)R5S)R!A;F0@86YY
M('-U8BUG<F]U<',_(@IM<V=S='(@(L7?\_3E(//?X^_U\>_I(/STZ2#HW>OE
M].4@[>$@Y.GAX_'<^.7TY2`G)7,G(.KAZ2#\Z^7R(/3I\B#U\._O[-SDY?(_
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS
M9W-T<B`BU-WW[><B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G
M:60@(D%S8VEI($%R="(*;7-G<W1R(")!4T-)22#4W??MYR(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT,#D*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T
M:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G
M<W1R("+-X2#FY_3EW_3E(.7PZ>+EXN'?^?/G(/#QW^T@X?#\(.K<Z.4@Y>W=
M\>/EZ>$@Y.GA]^7?\>GSY_([(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S`Y-PIM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(L'M
MW.CE\^<@\_3GZ_[M(@H*;7-G:60@(D%T:&EN86D@06ER<&]R="(*;7-G<W1R
M("+!Y?'OZ^GLW>WA\B#!Z.?M_NTB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C$V-@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C(T.0HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C,Q.`IM<V=I9"`B071T86-H
M960@:7,@86X@:4-A;&5N9&%R(&9I;&4@<F5P;'D@=&\@82!R97%U97-T('EO
M=2!S96YT(@IM<V=S='(@(M3O(//U[>?L[-WM[R#EW^WAZ2#=[>$@X?'WY=_O
M(.?LY?'OZ^_CW^_U(//E(.'PW.WTY_/G(.'I]-[LX?3\\B#SX?(B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C<U"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A
M(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`BT/'O\_#<Z.7IX2#DZ>'C
M\>'VWO(@[.<@]?#A\>KTWO(@[^S<Y.'R+B(*"B,Z(&%D;6EN+W!E<FUS+V1E
M;&5T92YP:'`Z,S@*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X
M:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(M#Q[_/PW.CEZ>$@Y.GAX_'A
M]M[R(.SG(/7PX?'J]._](.3IZN'I_NSA]._R+B(*"B,Z(&%D;6EN+W!E<FUS
M+V5D:70N<&AP.CDX"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI
M<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`BT/'O\_#<Z.7IX2#E\.7NY?'C
MX?/?X?(@[.<@]?#A\>KT[_T@Y.GJX>G^[.'T[_(N(@H*(SH@<V5R=FEC97,O
M<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N
M;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(M#Q[_/PW.CEZ>$@Y?#E[N7Q
MX^'SW^'R(.SG(/7PX?'J]._](.3IX>SOZ?'A\^S=[>_U+B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3<W"FUS9VED
M(")!='1E;F1E97,B"FUS9W-T<B`BT.'QY?7QZ?/J_.SE[>_I(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-R!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z.#8*;7-G:60@(D%T=')I8G5T97,B"FUS
M9W-T<B`BR>3I_/3G].7R(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C,X,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R("+!_>/O]?/T
M[_(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.3D*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R
M("+'(.'UZ.7M].GJ[_#OW^?SYR#A\-WT]??E(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-CD*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S@*;7-G:60@(D%U
M=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`BQR#A]>CE[?3IZN_P
M[]_G\^<@X?#=]/7WY2X@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A
M9&EU<RYP:'`Z,3@Q"FUS9VED(")!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B
M>2!2041)55,@<V5R=F5R+B(*;7-G<W1R("+'(.'UZ.7M].GJ[_#OW^?SYR#A
M\._Q\=_VZ.?JY2#A\/P@]._M(%)!1$E54R!S97)V97(N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HX,#`*;7-G:60@(D%U=&AE;G1I8V%T:6]N
M('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("+'(.'UZ.7M].GJ[_#O
MW^?SYR#S]._M($944"U397)V97(@X?#=]/7WY2XB"@IM<V=I9"`B079A:6QA
M8FQE(&9I96QD<SHB"FUS9W-T<B`BQ.GAZ-WSZ>SA(-#EY-_A.B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C$T"FUS
M9VED(")!=V%I=&EN9R!297-P;VYS92(*;7-G<W1R("+![>'LW>WO[?3A\B#A
M\-SM].?SYR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`BU?#\
MXN'H\>\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(M?Q_NSA
M(/7P_.+AZ/'O]2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z
M.#,*;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`BR]SH
M[_(@2V5R8F5R;W,MZOGDZ>K\\BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VMR8C4N<&AP.C@U"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM
M<V=S='(@(LO<Z._R($ME<F)E<F]S+;SM[^SA(-?QWO/TYRXB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DR"FUS9VED(")"87)E(@IM<V=S='(@
M(L'DY>GO(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"FUS9VED(")"
M87-E(&=R87!H:6-S(&1I<F5C=&]R>2`G)7,G(&YO="!F;W5N9"XB"FUS9W-T
M<B`BSR#J_?'I[_(@ZN'TW.OOX^_R(./QX?;IZO[M("<E<R<@Y.7M(.+QW>CG
MZN4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHQ.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<S"FUS9VED(")"87-E;&EN92(*;7-G<W1R("+"X?/IZMX@X_'A
M[.S>(@H*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(L/E[=WHZ^GA(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C@Y"FUS9VED(")";&]C:R!3
M971T:6YG<R(*;7-G<W1R("+1]>CLW_/EZ?(@].S>[.'T[_(B"@HC.B!T96UP
M;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B
M"FUS9W-T<B`BU/WP[_(@].S>[.'T[_(B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(V"FUS9VED(")";&]C:R!<(B5S7"(@
M;V8@87!P;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`BU.\@
M].S>[.$@7"(E<UPB(/3G\B#E]N'Q[._CWO(@7"(E<UPB(.3E[2#B\=WHY^KE
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.`IM<V=I9"`B0F]L9"(*;7-G<W1R("*X[?3O[>$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Q"FUS9VED(")"
M;W)D97)S(@IM<V=S='(@(KSQZ>$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z.38*;7-G:60@(D)O=&@B"FUS9W-T<B`BRN'I(/3A(.3][R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-0IM
M<V=I9"`B0F]T=&]M(@IM<V=S='(@(LKA]/[TX?3O(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T
M960@3&ES="(*;7-G<W1R("++W_/TX2#LY2#TY>OEW^7R(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C$*;7-G:60@(D-23"!$:7-T
M<FEB=71I;VX@4&]I;G1S(@IM<V=S='(@(M/G[.7?X2#DZ>'M[^S>\B!#4DPB
M"@IM<V=I9"`B0U93(@IM<V=S='(@(L'Q]^7?[R#JY>GLW>WO]2#W^?'I\^S=
M[>\@[.4@ZOSL[.$@*$-64RDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E
M<G1I97,N+BXB"FUS9W-T<B`BR>3I_/3G].7R(,KEZ^G^[2XN+B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-38@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$T,PIM<V=I9"`B0V%L96YD87(B"FUS9W-T
M<B`BQ^SE\>_K_./I[R(*"FUS9VED(")#86QE;F1A<CHB"FUS9W-T<B`BQ^SE
M\>_K_./I[SHB"@IM<V=I9"`B0V%L96YD87(@4W5M;6%R>2(*;7-G<W1R("+0
MY?'?Z^?XYR#'[.7Q[^O\X^GO]2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ.34*;7-G:60@(D-A;&TB"FUS9W-T<B`BQ_'E[-_A(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@
M<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(L'D_>WA].<@YR#A\??IZN_P[]_G
M\^<@]._U(.KYY.GJ[_T@X?7T_.SA].$L(.7PZ>KOZ>WY[=[S].4@[.4@].\@
MY.GA]^7I\>GS]-XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H
M<#HR-#$@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,Q,@IM<V=I
M9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`B
MP>3][>'TYR#G(//][>3E\^<@[.4@]._M($E-05`M4V5R=F5R.B`E<R(*"FUS
M9VED(")#86YC96PB"FUS9W-T<B`BP>K]\?GSYR(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!2
M97!O<G0B"FUS9W-T<B`BP>K]\?GSYR#![>'V[_'<\B#0\>_BZ][LX?3O\B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C8Y"FUS9VED(")#86YN
M;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+!Y/WMX?3G(.<@Y.GA
MX_'A]MX@]._U(.'Q]^7?[_4@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HT-PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4S"FUS9VED(")#86YN;W0@9FEN
M9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(L3E(.+QW_/J^2#P
M\>_S^?'I[?P@]MSJY>OO("AT96UP(&1I<BDN(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HY-PIM<V=I9"`B0V%N;F]T('!R
M;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R
M("+!Y/WMX?3G(.<@\_7MW??EZ>$@]_GQW_(@].?M(/#A\=SLY?3Q[R!<(G1A
M<F=E=$9I;&5<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(V
M-0IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G
M<W1R("+!Y/WMX?3G(.<@Y.GAX_'A]MX@]._U(/;AZMWK[_4@7"(E<UPB+B(*
M"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92YP:'`Z,3$R(&9R86UE
M=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C4W-@IM<V=I9"`B0V%N
M;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(L'D_>WA
M].<@YR#DZ>'C\>'VWBP@)60@]?#VW.KEZ^_R(/7PW/'WY>DN(@H*(SH@9G)A
M;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`R"FUS9VED("(B
M"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@
M9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB
M"FUS9W-T<B`B(@HBP>3][>'TYR#G(.7PX>WA].'NZ>W\[.?SYRP@[R#A\>GH
M[/SR(/3Y[2#EX^/QX?;^[2#P[_4@Y/[SX?3E(./IX2`B"B+E\.'MX?3A[NGM
M_.SG\^<L(.3E[2#TX>GQZ=SFY>D@[.4@]._M(.'QZ>CL_"#T^>T@X?#OZ.?J
MY?7LW>WY[2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,3@*;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O
M('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(L3E(.SP[_'^(.WA(.3Q[^SO
MZ^_CWO/Y(.S>[?7LX2#S]._M(.'QZ>CL_"#P[_4@[_'?\^'TY2XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T
M"FUS9VED(")#87!T:6]N(@IM<V=S='(@(L7PZ>KE]N'KW^3A(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDP"FUS9VED(")#871E9V]R:65S(&%N9"!,
M86)E;',B"FUS9W-T<B`BRN'TY^/O\=_E\B#JX>D@Q?3IZMWTY?(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DW"FUS9VED
M(")#96QL(%!H;VYE(@IM<V=S='(@(LKI[>?T_"#4Y^O=]OGM[R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*
M;7-G:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G<W1R("+)Y.G\].?TY?(@RN7K
MZ>_](@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`BP]WLZ?/LX2#*
MY>OI[_TZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S='(@
M(LGDZ?STY_3E\B#*Y>OI[_TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G
M<W1R("+$Z=SJY>WO(,KEZ^G^[3HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C8U"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`BRNGMY_3\(-3G
MZ]WV^>WO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(LK=[?3Q[R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S(S"FUS9VED
M(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(LOE\/3O[-WQY>GE\B#0
MZ?/T[_#OZ>?TZ>KO_2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C(P"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R
M("+0[^OI].GJWB#0Z?/T[_#OZ>?TZ>KO_2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3DV(#\_/PIM<V=I9"`B0VAA
M:7(@4&5R<V]N(@IM<V=S='(@(M#Q_.7D\>_R(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHY-PIM<V=I9"`B0VAA;F=E(@IM<V=S='(@(L'KZ^'CWB(*"FUS9VED(")#
M:&%N9V4@4&%S<W=O<F0B"FUS9W-T<B`BP>OKX>/>(.KYY.GJ[_TB"@IM<V=I
M9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE
M('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I
M;',N(@IM<V=S='(@(B(*(L'KZ]SN].4@].\@_.WO[.$@ZN'I(/3G(.3IY?WH
M]>WSYR#P[_4@Z.$@XNO=\._U[2#\].'M(.3IX>+<YN_U[2#>(.'PX>WT[_WM
M("(*(O/E(.SG[?WLX?3<(//A\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*;7-G:60@(D-H87(B"FUS9W-T
M<B`BU^'QX>KTWO'A\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB
M"FUS9W-T<B`BN.OEX_?O\B#S_>WDY?/G\BXN+B(*"B,Z('1E;7!L871E<R]M
M86EN=&5N86YC92]C;VYF:7)M7W1O<"YI;F,Z,3,*;7-G:60@(D-H96-K('1H
M92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R
M;2!A="!T:&ES('1I;64N(@IM<V=S='(@(B(*(M/G[.7I_O/TY2#T[R#TY?3Q
MX>/Y[=_DZ>\@X^GA(._P[^GAY-[P[_3E(.7QX^'SW^$HY?(I(.C=Z^7TY2#M
MX2#EZO3EZ^7S]._][2`B"B+A]?3>(/3G(//TZ>/LWBXB"@IM<V=I9"`B0VAI
M;W,@06ER<&]R="(*;7-G<W1R("+!Y?'OZ^GLW>WA\B#7W^_U(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V%P<"YI;F,Z-PIM<V=I9"`B0VAO;W-E($%P<&QI8V%T
M:6]N.B(*;7-G<W1R("+%\.GKW>[TY2#%]N'Q[._CWCHB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C@R"FUS9VED(")#:&]O<V4@82!P
M87-S=V]R9"(*;7-G<W1R("+%\.GKW>[TY2#J^>3IZOPB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C@Q"FUS9VED(")#:&]O<V4@82!U
M<V5R;F%M92(*;7-G<W1R("+%\.GKW>[TY2#\[>_LX2#W\=[S].<B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0U,@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8R
M-@IM<V=I9"`B0VAO;W-E(&%N(&%C=&EO;CHB"FUS9W-T<B`BQ?#IZ]WN].4@
M[.GA(.7MW?'CY>GA.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.#(*
M;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SHB"FUS9W-T<B`B
MQ?#IZ]WN].4@\/GR(.CA(.7L]N'MW^;O[?3AZ2#OZ2#G[.7Q[^SG[=_E\CHB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@
M;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`BQ?#IZ]WN].4@]/WP[R#KW_/TX?(@
M*./IX2#TX>[I[>_LY^S=[>7R(.O?\_3E\BDB"@IM<V=I9"`B0VAR>7-O=7!O
M;&D@06ER<&]R="(*;7-G<W1R("+!Y?'OZ^GLW>WA\B#7\?7S[_WP[^OG\B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4RYP:'`Z,S$Q(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HV-34*;7-G:60@(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@
M;F]T(&9O=6YD+B(*;7-G<W1R("+$Y>T@XO'=Z.?JY2#O\>GS[/SR(.KKW//G
M\B#T[_4@)7,N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q
M-`IM<V=I9"`B0VQE87(B"FUS9W-T<B`BRN'HW/'I\^4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A
M<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(LKAZ.'QZ?/L_/(@Y?3IZN7T_NT@
M*'1A9W,I($U3+4]F9FEC92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L
M96%R+FEN8SHW"FUS9VED(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B
M)\'DY>GA\^SA)R#7\=[S].<Z("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O8VQE87(N:6YC.C$V"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(LKA
MZ.'QZ?/L_/(@U_'>\_3G(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z,S<*;7-G:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R("+*X>CA
M\>GS[/SR(.3EY._LW>WY[2#W\=[S].<B"@HC.B!T96UP;&%T97,O;6%I;G1E
M;F%N8V4O;F]T:6-E7V)O='1O;2YI;F,Z-@IM<V=I9"`B0VQI8VL@=&\@0V]N
M=&EN=64B"FUS9W-T<B`BRMSM].4@ZNOIZB#CZ>$@\_7MW??EZ>$B"@IM<V=I
M9"`B0VQO<V4@2&5L<"!7:6YD;W<B"FUS9W-T<B`BRNOEW_/I[.\@T.'QW.CU
M\>_U(,+OWNCEZ>'R(@H*;7-G:60@(D-L;W-E($AE;'`B"FUS9W-T<B`BRNOE
MW_/I[.\@PN_>Z.7IX?(B"@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@
M(LKKY=_SZ>SO(-#A\=SH]?'O]2(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED
M96)A<BYI;F,Z-`IM<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R("+!
M[>'DW_#K^?/G(-#KY?7QZ>K>\B#,\-SQX?(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(X"FUS9VED(")#;VQL
M87!S960@8F]R9&5R<R(*;7-G<W1R("+![>'DZ?#K^>S=[>$@T.7QZ>C^\>GA
M(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N
M<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@(M?Q_NSA(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C(Y-PHC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,CDX"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-S(@<V5R=FEC
M97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,0HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,@HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV.`HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV.0HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX-0HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX-@IM<V=I9"`B0V]L;W(@4&EC
M:V5R(@IM<V=S='(@(L7PZ>O=ZO3G\B#7\?[LX?3O\B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(X,S0*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB
M"FUS9W-T<B`BQ?#IZ^_CWB#7\?[LX?3O\B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G
M<W1R("+3]-[KY?(Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DR
M.0IM<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R("+4W_3K[^D@T_3GZ_[M
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X.0IM<V=I9"`B0V]M
M:6-S(@IM<V=S='(@(D-O;6EC<R(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR
M-0IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R("+%[?3OZ]XB"@HC.B!A9&UI;B]C
M;61S:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B
MRMWK]?;O\B#%[?3OZ_[M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,SDY"FUS9VED(")#;VUM96YT(@IM<V=S='(@(M/W_.OI[R(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DP"FUS9VED(")#
M;VUM;VX@3F%M92(*;7-G<W1R("+*[^GM_""\[>_LX2(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#(*;7-G:60@(D-O;7!A
M;GDB"FUS9W-T<B`BQ?3AZ?'EW^$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C8Y-PIM<V=I9"`B0V]M<&QE=&5D(@IM
M<V=S='(@(L_K[^KKY_'^Z.?JY2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E
M<B]&:6QT97(O96UA:6QS+G!H<#HX,0HC.B!F<F%M97=O<FLO5&5X=%]&:6QT
M97(O1FEL=&5R+V5M86EL<RYP:'`Z.#<*(SH@9G)A;65W;W)K+U1E>'1?1FEL
M=&5R+T9I;'1E<B]E;6%I;',N<&AP.CDW"B,Z(&9R86UE=V]R:R]497AT7T9I
M;'1E<B]&:6QT97(O96UA:6QS+G!H<#HQ,#$*;7-G:60@(D-O;7!O<V4@365S
M<V%G92`H)7,I(@IM<V=S='(@(M/][>CE\^<@S.?M_>SA]._R("@E<RDB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*
M;7-G<W1R("+5\._K[^/I\_3=\B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C0W"FUS9VED(")#;VYD:71I;VYS(@IM<V=S='(@(M/U[>C>ZN7R(@H*(SH@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z.#D*;7-G:60@(D-O;F9I9W5R871I;VX@
M1&EF9F5R96YC97,B"FUS9W-T<B`BQ.GA]N_QW?(@T.'QX>SE]/'O\._?Y_/G
M\B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#8*;7-G:60@(D-O;F9I
M9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A
M;F0@3W5T;&]O:RXB"FUS9W-T<B`BQ?#IZ^_CW?(@X^GA(//UX_?Q[^WI\^S\
M(.SE(%!$07,L(-WN]?#MX2#4Y^O=]OGMX2#JX>D@3W5T;&]O:RXB"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,U"FUS9VED(")#;VYF:6=U<F%T:6]N
M(&ES(&]U="!O9B!D871E+B(*;7-G<W1R(")$:64@2V]N9FEG=7)A=&EO;B!M
M=7-S(&%K='5A;&ES:65R="!W97)D96XN(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$R-0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!N965D<R!U<&1A=&EN
M9RXB"FUS9W-T<B`BQR#PX?'A[.7T\>_P[]_G\^<@]_'EZ=SFY?3AZ2#E[>?L
MW?'Y\^<N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.CDY"FUS9VED(")#
M;VYF:6=U<F4@)7,B"FUS9W-T<B`BT.'QX>SE]/'O\._?Y_/G("5S(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-PIM<V=I9"`B0V]N
M9FER;2!087-S=V]R9"(*;7-G<W1R("+%\.GBY>+AW_GSYR#*^>3IZN_](@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C`V"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q.0IM<V=I
M9"`B0V]N;F5C=&EO;B!F86EL960N(@IM<V=S='(@(L<@\_WMY.7SYR#A\-WT
M]??E+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C(P-@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M,3D*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`BQR#S_>WD
MY?/G(.'PW?3U]^4Z("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C<Y,PIM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("+!\>WG\^<@\_WMY.7SY_(@X?#\(/3O
M(.3G[/SSZ>\@Y>[U\.?QY?3G]-X@ZNOEZ>3I_NTN(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDU"FUS9VED(")#;VYN96-T:6]N(')E
M9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S
M*2(*;7-G<W1R("+!\>WG\^<@\_WMY.7SY_(@X?#\(/3O(.3G[/SSZ>\@Y>[U
M\.?QY?3G]-X@ZNOEZ>3I_NTN(,O\X^_R(#H@)7,@*"5S*2(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z-SDT"FUS9VED(")#;VYN96-T:6]N('1O
M($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("+'(//][>3E\^<@[.4@].\@
M1E10+5-E<G9E<B#A\-WT]??E+B(*"FUS9VED(")#;VYT86-T(%-E87)C:"(*
M;7-G<W1R("+![>'FWO3G\^<@Q?#A]M[R(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C4V"FUS9VED(")#;VYT86-T<R!W97)E
M('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS
M9W-T<B`BS^D@Y?#A]MWR(/#Q[_/TW>CGZN'M(.7PZ?3U]_[R(//T[R#$Z>7U
MZ/7M\^GOX_'<]N\@\^'R+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-3D@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HV,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C<X"FUS9VED(")#;VYT96YT<R!O9B`G)7,G(@IM<V=S='(@(M#E\>GE]_SL
MY>WA(/3O]2`G)7,G(@H*;7-G:60@(D-O;G1E;G1S(&]F('1H92!205(@87)C
M:&EV92(*;7-G<W1R("+0Y?'IY??\[.7MX2#T^>T@X?'WY=_Y[2!205(B"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.0IM<V=I9"`B0V]N=&EN
M=64B"FUS9W-T<B`BT_7MW??EZ>$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS
M9W-T<B`BP>WTZ>/QX?;>(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T
M<B`BP>WTZ>/QX?;>(,7PZ>OOX][R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z.3<W"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@
M;65S<V%G92XB"FUS9W-T<B`BP>3][>'TYR#G(.KQ]?#T[^/QW/;G\^<@]._U
M(.SG[?WLX?3O\B#LY2!01U`N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3`U-0IM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A
M9V4N(@IM<V=S='(@(L'D_>WA].<@YR#U\._C\>'VWB#T[_4@[.?M_>SA]._R
M(.SE(%!'4"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C0Q,0IM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N
M(@IM<V=S='(@(L'D_>WA].<@YR#J\?7P]._C\=SVY_/G(/3O]2#LY^W][.'T
M[_(@[.4@4R]-24U%+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-#@U"FUS9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G
M92XB"FUS9W-T<B`BP>3][>'TYR#G(/7P[^/QX?;>(/3O]2#LY^W][.'T[_(@
M[.4@4R]-24U%+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,3@T"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A8W0N
M("5S(@IM<V=S='(@(L3E[2#L\/SQY?/A(.WA(/#Q[_/HW?/Y(/3G[2#E\.'V
MWBX@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$Q,PIM
M<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@
M(L'D_>WA].<@YR#S_>WDY?/G(.SE(/3O($Q$05`M4V5R=F5R+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34T"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W
M,PIM<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@
M(L'D_>WA]._R(.\@W>OEX^_R(/7P[^OOW_#O]2X@)7,B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-#@*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O
M('-E<G9E<B`G)7,G('5S:6YG($944#H@)7,B"FUS9W-T<B`BP>3][>'TYR#G
M(//][>3E\^<@\_3O[2#E[O7PY_'E].?TWB`G)7,G(/?QY_/I[/#OZ?[M].'R
M($944#H@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C,R.0IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,B"FUS9W-T<B`BP>3][>'TYR#G(.3G[.GO]?'CW^$@
MZ]_S].'S(.3IX>WO[-[R+B`E<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$Q,C8*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D
M871A+B(*;7-G<W1R("+!Y/WMX?3G(.<@X?#OZO'U\/3OX_'<]N?SYR!01U`@
MY.7D[^S=[?GM+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-30P"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB
M"FUS9W-T<B`BP>3][>'TYR#G(.'P[^KQ]?#T[^/QW/;G\^<@4R]-24U%(.3E
MY._LW>WY[2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C(U,`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T
M+B`E<R(*;7-G<W1R("+!Y/WMX?3G(.<@Y.GAX_'A]MX@Y?#A]M[R+B`E<R(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,S8U"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<R(*;7-G<W1R("+!Y/WMX?3G(.<@Y.GAX_'A]MX@Z]_S].'R(.3IX>WO
M[-[R+B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,W"FUS9VED
M(")#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T("<E<R<N
M(@IM<V=S='(@(L'D_>WA].<@YR#DZ>'C\>'VWB!S971U<"!U<&=R861E('-C
M<FEP="`G)7,G("XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C,Y.2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-3D*;7-G
M:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I
M;"!A9&1R97-S+B(*;7-G<W1R("+$Y2#L\._Q_B#MX2#DZ>7UZO'I[=[S^2#T
MYR#DZ>7]Z/7M\^<@]._U(/#A\>'KWO#TYRXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X.`IM<V=I9"`B0V]U;&0@
M;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`BP>3]
M[>'TYR#G(/#KWO'G\B#P\?SSXN'SYR#T[_4@Q.GE]>CU[?/I[^/QW/;O]2XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4Q,`IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U
M=&EO;B!L:7-T+B(*;7-G<W1R("+!Y/WMX?3G(.<@\.O>\>?R(/#Q_//BX?/G
M(/3G\B#KW_/TX?(@Y.GA[>_LWO(N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-C$*;7-G:60@(D-O=6QD(&YO="!F
M971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N
M(@IM<V=S='(@(L'D_>WA].<@YR#PZ][QY_(@\/'\\^+A\^<@Z]_S].'R(.'P
M_"#KW_/TY?(@Y.GA[>_LWO(N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-CD*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+G!H<#HX-0IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@)R5S
M)RXB"FUS9W-T<B`BP>3][>'T[R#T[R#V_/'T^>SA(//T\>'TY^/IZM[R(%PB
M)7-<(BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$Q"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO9&ER
M96-T+G!H<#HS,0IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER("<E<R<N(@IM<V=S
M='(@(L'D_>WA].<@YR#DY^SI[_7QX]_A(/;AZMWK[_4@7"(E<UPB+B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<R,`IM<V=I9"`B0V]U
M;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB
M"FUS9W-T<B`BP>3][>'TYR#G(.'MW.KTY_/G(.3G[/SSZ>_U(.KKY>GDZ>_]
M(.'P_"#T[^T@Y>[U\.?QY?3G]-X@Q.?L+LKKY>GDZ?[M+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-S`R"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,U-`IM
M<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@(L'D_>WA].\@].\@
MW.WOZ>/LX2`E<RXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,30P"FUS9VED(")#
M;W5L9"!N;W0@;W!E;B`G)7,G(&9O<B!W<FET:6YG+B(*;7-G<W1R("+!Y/WM
MX?3O(/3O(-SM[^GC[.$@7"(E<UPB(./IX2#EX^/QX?;>+B(*"B,Z(&9R86UE
M=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-#$U(&,M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L
M92`E<R(*;7-G<W1R("+!Y/WMX?3O(/3O(-SM[^GC[.$@]._U(.S=\>_U\B#$
MZ>'WY=_QZ?/G\B`E<R(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HW,0IM<V=I9"`B
M0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y("<E<R<N(@IM<V=S='(@(L3E[2#L
M\._Q_B#MX2#A[>_?[OD@].\@]MSJY>OO(%PB)7-<(BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(W,`IM<V=I9"`B0V]U;&0@;F]T(')E
M860@)7,N(@IM<V=S='(@(L3E[2#L\._Q_B#MX2#DZ>'BW//Y("5S+B(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L
M9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S
M97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@8V]R
M<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R
M(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HBP>3]
M[>'TYR#G(.'Q]^GJ[_#OW^?SYR#T[_4@ZOGDZ>KO_2#CZ>$@]._M(.'I]._]
M[.7M[R#W\=[S].<N(,K<\._IX2#>(/SKY?(@(@HB[^D@Z^7P]._LW?'EZ>7R
M(.3E[2#EW^WAZ2#S^?/TW?(N(,[A[>'D[^KI[-SS].4@WB#E\.GJ[^GM^>W>
M\_3E(.SE(/3O(.3IX??EZ2TB"B+QZ?/TWB#A[2#W\>7IW//E\^CE(/#E\>GS
M\_STY?'G(.+OWNCEZ>$N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S$X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,T.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS.#8*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,SDR"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,Y.`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R
M("+!Y/WMX?3G(.<@X>W<ZO3G\^<@R]_S].'R(,KA[?SM^>T@T/'\\^+A\^?R
M("A!0TPI(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HR-SD*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S
M(&)O;VLN("5S(@IM<V=S='(@(L'D_>WA].<@YR#A[=SJ].?SYR#$Z>7UZ/7M
M\^GOX_'<]N_U+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3`Q"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(L'D_>WA].<@YR#A[=SJ
M].?SYR#+W_/TX?(@Q.GA[>_LWO(N("5S(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-3(*;7-G:60@(D-O=6QD(&YO
M="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@(L'D
M_>WA].<@YR#A[=SJ].?SYR#+Z?/T_NT@Q.GA[>_LWO(N("5S(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(V"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(S,`IM<V=I9"`B0V]U
M;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R
M("+!Y/WMX?3G(.<@X>W<ZO3G\^<@]/GM(.GDZ>_TWO3Y[2#T[_4@Y>[U\.?Q
MY?3G]-XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"FUS9VED(")#
M;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(L'D_>WA
M].<@YR#E\.'MX?;O\=P@\?7H[-_SY?GM+B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HY-0IM<V=I9"`B0V]U;&0@;F]T(')M9&ER("<E<R<N(@IM<V=S='(@(L'D
M_>WA].<@YR#DZ>'C\>'VWB#VX>K=Z^_U("AR;61I<BD@7"(E<UPB+B(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<Q"FUS9VED(")#;W5L9"!N;W0@
M<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+$Y2#L\._Q_B#MX2#A
M\._HY^KE_?/Y("5S(/'UZ.S?\^7I\BXB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(D-O
M=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B
MQ.4@[/#O\?X@[>$@ZMSM^2#E]N7D\>GJ_"#A[?3?X_'A]N\@]/GM(/'UZ.S?
M\^7Y[2XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*;7-G:60@(D-O
M=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T
M<B`BQ.4@[/#O\?X@[>$@ZMSM^2#E]N7D\>GJ_"#A[?3?X_'A]N\@]/GM(/'U
MZ.S?\^7Y[3H@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,@IM
M<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z
M("<E<R<N(@IM<V=S='(@(L3E(.SP[_'^(.WA(.'P[^CGZN7]\_D@\/'\X_'A
M[.SA(.7MY^S=\?GSY_(@\_3O("<E<R<N(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HV-`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C
M;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(L3E(.SP[_'^(.WA(.'P
M[^CGZN7]\_D@Y?;EY/'IZOP@X?'WY=_O(/'UZ.S?\^7Y[2`E<RXB"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C<T"FUS9VED("(B"B)#;W5L9"!N;W0@
M<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE
M<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@
M8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O
M("5S+B(*;7-G<W1R("(B"B+$Y2#L\._Q_B#MX2#A\._HY^KE_?/Y(/3O(.'Q
M]^7?[R#Q]>CLW_/E^>T@)7,N(,SP[_'EW_3E(.7?].4@[>$@]_'G\^GL[_#O
MZ=XM(@HB\^7TY2#LZ>$@X?#\(/3I\B#E\.GK[^/=\B#CZ>$@[>$@X?#OZ.?J
MY?WSY?3E(/#?\_D@\_3O("5S(-X@X>WTZ>/QW/CTY2#LY2#T[R`B"B+WW?'I
M(/3O[2#J_N3IZN$@\-_S^2#S].\@)7,N(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HQ,C,*;7-G:60@(D-O=6QD(&YO="!S96%R8V@@=&AE
M($Q$05`@<V5R=F5R+B(*;7-G<W1R("+!Y/WMX?3G(.<@X>WAYM[TY_/G(//T
M[^T@Y>[U\.?QY?3G]-X@3$1!4"XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#<*
M;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@)R5S)RXB"FUS9W-T<B`BQ.4@[/#O
M\?X@[>$@X?#O\_7MY-WS^2!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,C$*;7-G:60@(D-O=6QD(&YO
M="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`BQ.4@[/#O\?X@[>$@Y>WG
M[.7Q_O/Y(/3G[2#E\.'VWBX@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C0P.0IM<V=I9"`B0V]U;&0@;F]T('5P
M9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`BQ.4@[/#O\?X@
M[>$@Y>WG[.7Q_O/Y(/3G(,O?\_3A(,3IX>WO[-[R+B`E<R(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HW,`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O
M;F9I9W5R871I;VX@9F]R("<E<R<Z("5S(@IM<V=S='(@(L3E(.SP[_'^(.WA
M(./QW/CY(/3I\B#Q]>S?\^7I\B#CZ>$@)R5S)SH@)7,B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S4P"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-
M;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N
M+B(*;7-G<W1R("(B"B+$Y2#L\._Q_B#MX2#B\?X@].<@\.OE]?'IZMX@[/#<
M\>$@]._U($UO>FEL;&$N(,+EXN'I^>CEW_3AZ2#\].D@Y=_MX>D@(@HBX>WO
MZ>KTWBXB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HQ-3D*;7-G:60@(D-O=6QD;B=T(&=I=F4@=7-E<B`G)7,G('1H92!F;VQL
M;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R("<E<R<Z("5S(@IM<V=S='(@
M(B(*(L3E(.SP[_'^(.WA(.3^\_D@\_3O(/?QWO/TYR`G)7,G(/3A(/#A\>'J
MW/3Y(.3IZN'I_NSA].$@\_3O(/;<ZN7K[R`G)7,G.B`E<R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T,34*;7-G:60@(D-O=6YT960@=&5X="(*
M;7-G<W1R("+,Y?3QY^S=[>\@ZN7?[.7M[R(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED(")#;W5N=')Y(@IM<V=S='(@
M(M?^\>$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C<S"FUS9VED
M(")#;W5R<V5S(@IM<V=S='(@(M#O\>7?Y?(B"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.CDW"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$*;7-G:60@
M(D-R96%T92(*;7-G<W1R("+$Y^SI[_7QX]_A(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W"FUS9VED(")#
M<F5A=&4@82!L:6YK(@IM<V=S='(@(L3G[.GO]?'CW^$@Y>W\\B#S]>WDW?/L
M[_4B"@IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R("+$Y^SI[_7Q
MX]_A(.SIX?(@[=WA\B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.CDU"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T
M<B`BQ.?LZ>_U\>/?X2#U\._VX>K=Z_GM(@H*(SH@861M:6XO<&5R;7,O961I
M="YP:'`Z,3,V(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C(R"FUS
M9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(L7N[_7SZ>_D[_3>
M\^7I\B#$Y^SI[_7QX^_](@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S(Q-`IM<V=I9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(L'QZ>CL
M_/(@T.GS]/GTZ>K>\B#*W/'TX?(B"@IM<V=I9"`B0W)E9&ET<R(*;7-G<W1R
M("+%]??A\>GS]-_E\B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-@IM<V=I
M9"`B0W5R<F5N="!0:&%S92(*;7-G<W1R("+4\=WW[_7SX2#6W//G(@H*(SH@
M;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I;64N<&AP.C,P"FUS
M9VED(")#=7)R96YT(%1I;64B"FUS9W-T<B`BU/'=]^_U\^$@_O'A(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4S"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G<W1R("+4[R#T\=WW[^T@
M55),(.7?[>'I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I9"`B
M0W5R<F5N="!796%T:&5R(@IM<V=S='(@(M3QW??O[2#*X>GQ_/(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Y"FUS9VED(")#=7)R96YT
M(&-O;F1I=&EO;CH@(@IM<V=S='(@(M3QW??O]?/A(//U[>C>ZN<Z("(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G
M:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`BU/'=]_GM(//T_>LB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`X"FUS9VED(")#=7-T;VUI>F4@=&%S
M:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(M#A\>'LY?3Q
M[_#OW^?SYR#DZ>'DZ>KA\^G^[2#P[_4@Y>KTY>OO_>WTX>D@ZN'TW"#TY^T@
MY=_S[^3O("5S+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(L'P[^KO
M\-XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,U"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(L'P[^KO\-X@Y?#I
MZ^_CWO(B"@IM<V=I9"`B1$0B"FUS9W-T<B`BS,PB"@IM<V=I9"`B1&%I;'DB
M"FUS9W-T<B`BQ^SE\=[SZ>$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#(S"FUS9VED(")$871A(@IM<V=S='(@(L3EY._LW>WA(@H*(SH@861M
M:6XO9&%T871R964N<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM
M<V=S='(@(L7L]MSMZ?/G("A"<F]W<V5R*2!$871A5')E92(*"FUS9VED(")$
M871A8F%S92!Q=65R>2!F86EL960N(@IM<V=S='(@(L<@X>WAYM[TY_/G(//T
MYR#"W//G(,3EY._LW>WY[2#A\-WT]??E+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S<@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C,X,0IM<V=I9"`B1&%T92(*;7-G<W1R("+'[.7Q[^SG[=_A(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G:60@
M(D1A=&4@4F5C96EV960B"FUS9W-T<B`BQ^SE\>_LY^W?X2#PX?'AZ^'BWO(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-SDU"FUS9VED(")$871E
M('-E;&5C=&EO;B(*;7-G<W1R("+%\.GK[^/>(,?LY?'O[.?MW^'R(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V,PIM<V=I9"`B1&%Y(@IM
M<V=S='(@(L?LW?'A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,U"FUS9VED(")$95]L971E($-O;'5M;B(*
M;7-G<W1R("+$Z>'C\>'VWB#3]-[KY_(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@U"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T
M<B`BQ.7JW>SB\>GO\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M8F5R
M<R(*;7-G<W1R("+$Y>KAY.GJ[]\@X?'IZ.SOWR(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C@U"FUS9VED(")$96-L
M:6YE9"(*;7-G<W1R("*X]^_U[2#A\>WGZ.7?(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@
M26YD96YT(@IM<V=S='(@(LSEW_GSYR#0Y?'IZ/GQW^_U(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HQ.3(@;&EB+W!R969S+G!H<#HQ,#@*
M;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`BT/'OZN'H[_'I\^S=[>\B"@HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT-PHC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0IM<V=I
M9"`B1&5F875L="!#;VQO<B(*;7-G<W1R("+0\>_E\.GKY>/LW>WO(-?Q_NSA
M(@H*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`BT/'OY?#IZ^7C
M[-WMYR#4X?7T_/3G].$B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,3D@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,#0*;7-G:60@(D1E9F%U
M;'0@4&5R;6ES<VEO;G,B"FUS9W-T<B`BT/'OZN'H[_'I\^S=[>7R(,7N[_7S
MZ>_D[_3>\^7I\B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,C`U"FUS9VED(")$969A=6QT('!E<FUI<W-I;VYS(@IM<V=S='(@(M#Q[^KA
MZ._QZ?/LW>WE\B#%[N_U\^GOY._TWO/EZ?(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S,*;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S='(@(L_QZ?/L
M[]\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C8T,PIM<V=I9"`B1&5L96=A=&4@<&]S:71I;VXB"FUS9W-T<B`BR-WS
MYR#A[?3I\/'O\_[P[_4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C8Y,PIM<V=I9"`B1&5L96=A=&5D(@IM<V=S='(@
M(L'M].GP\>_S^?#G[-WM[R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S(@861M
M:6XO<&5R;7,O9&5L971E+G!H<#HT-B!A9&UI;B]P97)M<R]D96QE=&4N<&AP
M.C4R"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,CDW(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,S(W"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,S0W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-#(*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW-B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.CDY"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3(R('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30U"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3@X('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHW,PHC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3D@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$S"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T"FUS9VED(")$96QE=&4B"FUS9W-T
M<B`BQ.GAX_'A]MXB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$X.2!A9&UI;B]G
M<F]U<',N<&AP.C(Q-PIM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@(L3I
MX>/QX?;>(,_LW.3A\B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z-C`@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX-`IM<V=I9"`B
M1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`BQ.GAX_'A]MX@Q>[O]?/I[^3\
M].?SY_(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HY-@IM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R
M("+$Z>'C\>'VWB#JX>D@Y>KJW>WY\^<@[.?M]>S<]/GM(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I
M9"`B1&5L971E(&-E;&PB"FUS9W-T<B`BQ.GAX_'A]MX@ZN7KZ>_](@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M,PIM<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R("+$Z>'C\>'VWB#3]-[K
MY_(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E
M(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("+$Z>'C\>'V
MWB#U\-SQ]^_M]._R(.7MX>OKX>KTZ>KO_2#P\>_T_?#O]2(*"B,Z(&%D;6EN
M+W!E<FUS+V1E;&5T92YP:'`Z-3`@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HS,C8*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@)R5S)R(*
M;7-G<W1R("+$Z>'C\>'VWB#E[N_U\^GOY._TWO/E^>T@X^GA("<E<R<B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,R.0IM<V=I9"`B1&5L
M971E('!E<FUI<W-I;VYS(&9O<B`G)7,G(&%N9"!A;GD@<W5B+7!E<FUI<W-I
M;VYS/R(*;7-G<W1R("+$Z>'C\>'VWB#E[N_U\^GOY._TWO/E^>T@X^GA("<E
M<R<@ZN'I(.K<Z.4@]?#O+>7N[_7SZ>_D_/3G\^<[(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PIM<V=I9"`B
M1&5L971E(')O=R(*;7-G<W1R("+$Z>'C\>'VWB#S]-[KY_(B"@HC.B!T96UP
M;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U"FUS9VED(")$96QE
M=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`BT/'OY?#IZ^7C[-WMYR#4
MX?7T_/3G].$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!C
M;VQU;6XB"FUS9W-T<B`BQ.GAX_'A]MX@]/'=]^_U\^'R(//TWNOG\B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV,@IM<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O=R(*;7-G<W1R("+$
MZ>'C\>'VWB#T\=WW[_7SX?(@X_'A[.S>\B(*"B,Z(&%D;6EN+W!E<FUS+V1E
M;&5T92YP:'`Z-#@*;7-G:60@(D1E;&5T92!T:&ES('!E<FUI<W-I;VX@86YD
M(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(L3IX>/QX?;>(.'U]-[R
M(/3G\B#E[N_U\^GOY/STY_/G\B#JX>D@ZMSHY2#U\.\MY>[O]?/I[^3\].?S
MY_([(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S4*;7-G:60@(D1E
M;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@)R5S)RXB"FUS9W-T<B`BQ.GA
MX_'<]N?JY2#T[R!S971U<"!U<&=R861E('-C<FEP="`G)7,G+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@U"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C$Y
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(R-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR-C$*;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`BO_'A(-SV
MZ>[G\B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-C0R"FUS9VED(")$96YY(')E<75E<W0B"FUS9W-T<B`BP?'MY_/G
M(.'I]-[LX?3O\B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z-#<Q"FUS9VED(")$96YY(')E<75E<W0@9F]R(&9R964O
M8G5S>2!I;F9O<FUA=&EO;B(*;7-G<W1R("+!\>WG\^<@X>GTWNSA]._R(./I
MX2#PZ^?Q[_;O\=_E\B#DZ>'HY?/I[/STY_3A\B(*"B,Z('-E<G9I8V5S+W!R
M;V)L96TN<&AP.CDU('-E<G9I8V5S+W!R;V)L96TN<&AP.CDY('-E<G9I8V5S
M+W!R;V)L96TN<&AP.C$P.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB
M"FUS9W-T<B`BT.7QZ>/QX?;>(/3O]2#0\>_BZ][LX?3O\B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-38U(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.CDS,@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,P"FUS9VED(")$97-C<FEP=&EO
M;B(*;7-G<W1R("+0Y?'IX_'A]MXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C(P,0IM<V=I9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO
M9V9I;&4I.B(*;7-G<W1R("++Y?#T[^S=\>7IY?(@*.7PW_/G\B#JX>D@\_3O
M(.'Q]^7?[R#JX?3AX_'A]M[R(/3O]2!(;W)D92DZ(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HR,#4*;7-G:60@(D1E=&%I;',@:&%V92!B965N
M(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(L_I(.OE
M\/3O[-WQY>GE\B#=]^_U[2#JX?3AX_'A]N7?(./IX2#T[^T@Y.GA]^7I\>GS
M]-XN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y,PIM<V=I9"`B
M1&5V96QO<&UE;G0B"FUS9W-T<B`BP>W<\/3U[N<B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(Q-0IM<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@(M/G[.7?
M[R#$\>_SZ=SR(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W
M-@IM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`BT^?LY=_O(,3Q[_/IW/(Z
M("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDR"FUS9VED(")$97<@4&]I
M;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(M/G[.7?[R#$\>_SZ=SR(./I
MX2#TY^T@].7KY?7TX=_A(/[QX3H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE9G0@
M=&\@<FEG:'0B"FUS9W-T<B`BRN'TY?WH]>WSYR#A\/P@X?'I\_3E\=P@\/'O
M\B#TX2#DY>[IW"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L969T(@IM
M<V=S='(@(LKA].7]Z/7M\^<@X?#\(/3A(.3E[NG<(/#Q[_(@].$@X?'I\_3E
M\=PB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T
M;W)Y(@IM<V=S='(@(LKA]-SK[^/O\B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR-3`*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T
M<B`BQ>SVW.WI\^<@_O'A\B#SY2`R-/GQYR#L[_'VWCLB"@IM<V=I9"`B1&ES
M<&QA>2!/<'1I;VYS(@IM<V=S='(@(L7PZ>OOX]WR(,7L]MSMZ?/G\B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z.#,*;7-G:60@(D1I<W!L87D@9F]R96-A
M<W0@*%1!1BDB"FUS9W-T<B`BQ>SVW.WI\^<@\/'OXNO=^.7Y[2`H5$%&*2(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#4*;7-G:60@(D1I<W!L
M87D@9F]R;6%T(@IM<V=S='(@(LSO\?;>(,7L]MSMZ?/G\B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O341.+G!H<#HR,#,*;7-G:60@(D1I<W!O<VET:6]N
M($YO=&EF:6-A=&EO;B(*;7-G<W1R("+%[>?LW?'Y\^<@Q.G<].'NY_(B"@HC
M.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,S(W"FUS9VED(")$;R!N;W0@9&5L971E(@IM<V=S='(@
M(LSG(.3IX>/QW/;EZ?(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M,C0*;7-G:60@(D1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N
M<&AP(@IM<V=S='(@(LSG[2#E\.GWY>GQWO/E].4@[>$@X>WOW^[E].4@X?#E
M]>CEW^'R(/3O(.'Q]^7?[R!M86EN=&5N86YC92YP:'`B"@HC.B!T96UP;&%T
M97,O9&%T82]T<W9I;F9O+FEN8SHQ.2!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHQ.0IM<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE
M(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R
M("+0Y?'IW??EZ2#G(/#Q_O3G(./QX>SLWB#O[?SLX?3A(/#EY-_Y[3L@P>T@
M[>'I(/3SY>K<\>7TY2#A]?3\.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C@V-@IM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`BRN'T
MW>+A\^SA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z
M.#8V"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G<W1R("+*X?3=XN'S[.$@)7,B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,34V"FUS9VED(")$;W=N;&]A
M9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G
M<W1R("+*X?3=XN'S[.$@]._U(.'Q]^7?[_4@\.'QX>S=]/'Y[2#SX>T@4$A0
M+7-C<FEP="XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#DP"FUS
M9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R("++W_/TX2#*X?3A\=SJ].?R
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*
M;7-G<W1R("+6W/'LX>KA+>WA\>KY].GJW"(*"FUS9VED(")%9&ET(@IM<V=S
M='(@(L7PY>[E\>/A\]_A(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)
M+G!H<#HU,2!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(R"FUS9VED(")%
M9&ET($)L;V-K(@IM<V=S='(@(L7PY>[E\>/A\]_A($)L;V-K(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HQ.#@@861M:6XO9W)O=7!S+G!H<#HR,38*;7-G:60@
M(D5D:70@1W)O=7`B"FUS9W-T<B`BQ?#E[N7QX^'SW^$@S^S<Y.'R(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HU.2!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C@S"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS
M9W-T<B`BQ?#E[N7QX^'SW^$@Q>[O]?/I[^3\].?SY_(B"@HC.B!S97)V:6-E
M<R]S:&%R97,O961I="YP:'`Z,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS
M(@IM<V=S='(@(L7PY>[E\>/A\]_A(,7N[_7SZ>_D[_3>\^7Y[2(*"B,Z('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*;7-G:60@(D5D:70@4&5R;6ES
M<VEO;G,@9F]R("5S(@IM<V=S='(@(L7PY>[E\>/A\]_A(,7N[_7SZ>_D[_3>
M\^7Y[2#CZ>$@)7,B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHY"FUS
M9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R("+%\.7NY?'CX?/?X2#E
M\.GK[^/^[2#CZ>$Z(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M-`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`BQ?#E
M[N7QX^'SW^$@Q>[O]?/I[^3O]-[SY?GM(./IX2`E<R(*"B,Z(&%D;6EN+W!E
M<FUS+V5D:70N<&AP.C(P-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C(X.`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)R5S)R(*;7-G<W1R
M("+%\.7NY?'CX?/?X2#%[N_U\^GOY._TWO/E^>T@X^GA("<E<R<B"@IM<V=I
M9"`B16QE9G-I<R!!:7)P;W)T(@IM<V=S='(@(L'E\>_KZ>S=[>'R(,7KY?7S
MW^WA\B(*"FUS9VED(")(97)A:VQI;VX@06ER<&]R="(*;7-G<W1R("+!Y?'O
MZ^GLW>WA\B#'\>'JZ^7?[_4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*;7-G:60@(D5L96UE;G0N+BXB
M"FUS9W-T<B`BT_3OZ??EW^\N+BXB"@IM<V=I9"`B16UA:6PB"FUS9W-T<B`B
MP>OKY^OOX_'A]M_A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.#D@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0P"FUS9VED(")%
M;6%I;"!!9&1R97-S(@IM<V=S='(@(L3IY?WH]>WSYR!%;6%I;"(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#8*;7-G:60@(D5M86EL(&%D9')E
M<W-E<R!M=7-T(&UA=&-H+B(*;7-G<W1R("+'(.3IY?WH]>WSYR!%;6%I;"#P
M\=WPY>D@[>$@].'I\>G<YN7I+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Y-S(*;7-G:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S
M='(@(LS>[?7LX2#LY2#Q]>CLW_/EZ?(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C@P"FUS9VED(")%;6]T:6-O;G,B"FUS
M9W-T<B`BP>GSZ-[LX?3A(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED(")%;7!T>2!M97-S86=E+B(*
M;7-G<W1R("+*Y>W\(.S>[?7LX2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C$S,0IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R("+$
MY>T@Y?#I\_3QW/;GZN'M(,'P[_3EZ]WS[.'TX2XB"@HC.B!F<F%M97=O<FLO
M4U%,+U-13"]+97EW;W)D<RYP:'`Z,3$T"FUS9VED(")%;7!T>2!S96%R8V@@
M=&5R;7,B"FUS9W-T<B`BP>3EZ>7R(//U[>C>ZN7R(.'MX>;>].?SY_(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(V"FUS9VED(")%;F%B;&4@:6YS
M97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT
M/R(*;7-G<W1R("+%[>7QX^_P[]_G\^<@Y>GSX>/YX][R(.7IZOSM^>T@X?#O
M(%!H;W1O($-A;&QE<FEE=R#S].\@ZN7?[.7M[SLB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3`Q"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N
M=&5X="!M96YU/R(*;7-G<W1R("+-X2#E[>7QX^_P[^GGZ.7?(/3O(.SE[>_]
M(.SE(.3E[M\@ZNOIZCLB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C0T.`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C4U,PIM<V=I9"`B16YD(@IM<V=S='(@(M3=
MZ^_R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y,"!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-SDY"FUS9VED(")%;F0@>65A<B(*;7-G<W1R
M("*X]._R(-3=Z^_U\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@
M(LSEX]WMZ/7SYR#*Y>GLY>WOX_'<]N_U(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(P-0IM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO
M;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E
M="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F
M('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*(L3^\_3E(.SIX2#E\?[TY_/G(.'S
M]N'KY=_A\BP@YR#O\._?X2#HX2#SX?(@YN?TY^CEWR#A[2#W\>7IX?/HY=\@
M[>$@X>OKW.[E+2(*(O3E(/3O[2#J^>3IZOP@\^'R+"#P+O<N("?0[^G\(.7?
M[>'I(/3O(/SM[^SA(/3O]2#JX?3OZ>KIY-_O]2#SX?([)SHB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(*;7-G<W1R("+$
M_O/TY2#TYR#S_>WDY?/G(/3G\B#EZ>K\[>'R(.7D_B(*"FUS9VED(")%<G)O
M<B(*;7-G<W1R("++W.CO\B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z,3DU"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z,C<X"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,S0W"FUS9VED(")%<G)O<B!S96YD
M:6YG(')E<&QY.B`E<RXB"FUS9W-T<B`BR]SH[_(@X?#O\_3=Z^OO[?3A\B#A
M\-SM].?SYSH@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S
M<V%G92XB"FUS9W-T<B`BR]SH[_(@[.4@[-[M]>SA(&5M86EL+B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2]C;W!Y+G!H<#HQ-#,*;7-G:60@(D5R<F]R('=R:71I;F<@)R5S)RXB
M"FUS9W-T<B`BR]SH[_(@X_'<]N_M].'R(%PB)7-<(BXB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R("+%Z.WI
MZOPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@
M(D5U<F]P92(*;7-G<W1R("+%]?'^\.<B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S(S"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(LK<
MZ.4@,34@Z^7P]-PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<S"FUS
M9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`BRMSHY2`R(,OE\/3<(@H*
M;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`BRMSHY2`S,"#DY?7T
MY?'\Z^7P].$B"@IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(LK<
MZ.4@-2#KY?#TW"(*"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R("+*W.CE
M(/;O\=P@\._U(.SPX=_MY?3E(//TY^T@]?#G\>7SW^$B"@IM<V=I9"`B179E
M<GD@:&%L9B!H;W5R(@IM<V=S='(@(LK<Z.4@[.GSWB#^\>$B"@IM<V=I9"`B
M179E<GD@;6EN=71E(@IM<V=S='(@(LK<Z.4@Z^7P]/PB"@IM<V=I9"`B17AA
M;7!L92!V86QU97,Z(@IM<V=S='(@(M#A\>'DY>GC[.'TZ>K=\B#TZ>S=\CHB
M"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S8@861M:6XO8VUD<VAE;&PN<&AP
M.C4P(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S8*;7-G:60@(D5X96-U=&4B"FUS
M9W-T<B`BQ>KTW>OE\^<B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HS.#8*;7-G:60@(D5X<&%N9"(*;7-G<W1R("+%\-WJ].'SYR(*
M"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S$*;7-G:60@(D5X
M<&%N9"!3:61E8F%R(@IM<V=S='(@(L7PW>KTX?/G(-#KY?7QZ>K>\B#,\-SQ
MX?(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,38Y"FUS
M9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`BP>WA[-WM[^WTX>T@)RDG(@H*
M(SH@8RUF;W)M870*;7-G:60@(D5X<&5C=&5D(%PB0D5'24Y<(B!I;B!T:&4@
M;&EN92`E9"XB"FUS9W-T<B`BP>WA[.7M_.SE[>\@7")"14=)3EPB(//TYR#C
M\>'L[-X@)60N(@H*(SH@8RUF;W)M870*;7-G:60@(D5X<&5C=&5D(%PB14Y$
M.B5S7"(@:6X@;&EN92`E9"XB"FUS9W-T<B`BP>WA[.7M_.SE[>\@7")%3D0Z
M)7-<(B#S].<@X_'A[.S>("5D+B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME
M>7=O<F1S+G!H<#HQ-S8*;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q
M=6]T960@<V5A<F-H('1E<FTB"FUS9W-T<B`BP>WA[-WM[^WTX>T@X?#KWB#K
MW>[G(-X@\_7MZ-[JYR#A[>'FWO3G\^?R(//E(.7I\^'C^>/IZMPB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HS.3@*;7-G:60@(D5X<&ER
M871I;VX@1&%T92(*;7-G<W1R("+'[.7Q[^SG[=_A(,O>[N?R(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#`*;7-G:60@(D5X<&]N
M96YT(@IM<V=S='(@(L7JZ-WTY_(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Q"FUS9VED(")&1R!#;VQO<B(*
M;7-G<W1R("+7\?[LX2#P\>_SZM[MZ>_U(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$W,0IM<V=I9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R
M("+1]>CLW_/EZ?(@X^GA($944"!U<&QO860B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O<W%L+G!H<#HR-#`*;7-G:60@(D9A:6QE9"!R971R:65V:6YG
M('!R969E<F5N8V5S+B(*;7-G<W1R("+!\._T]???X2#JX?3<(/3G[2#P\>_S
M\-SHY>GA(.'MW.KTY_/G\B#T^>T@\/'O].GLWO/E^>TN(@H*;7-G:60@(D9A
M:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R("+!\._T
M]???X2#S_>WDY?/G\B#S]._M(.3IX>KO[.GS]-X@RN'TX>O\X^_U+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HQ,#,*;7-G:60@(D9A:6QE
M9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM<V=S='(@(L'P[_3U]]_A
M(//][>3E\^?R(//T[^T@4TU"+5-E<G9E<BXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C8S,0IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<
M(B5S7"(N(@IM<V=S='(@(L'P[_3U]]_A(.'M].GC\>'VWO(@X?#\(%PB)7-<
M(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8S-@IM<V=I9"`B
M1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*;7-G<W1R("+!\._T]???X2#A
M[?3IX_'A]M[R(//E(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W-A<VPN<&AP.CDR"FUS9VED(")&86EL960@=&\@8W)E871E(&YE=R!305-,
M(&-O;FYE8W1I;VXN(@IM<V=S='(@(L'P[_3U]]_A(.3G[.GO]?'CW^'R(//]
M[>3E\^?R(%-!4TPN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV
M-S$*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B
MP?#O]/7WW^$@[.7TX?;O\=SR(//E(%PB)7-<(BXB"@IM<V=I9"`B1F%I;'5R
M92!I;B!C:&%N9VEN9R!P87-S=V]R9"!F;W(@=7-E<B`E<R!F<F]M(&-L:65N
M="`E<RP@<F5A<V]N("5S(@IM<V=S='(@(B(*(L'P[_3U]]_A(.KA]-P@].?M
M(.'KZ^'CWB#J^>3IZN_](./IX2#T[^T@]_'>\_3G("5S(.'P_"#T[R#S].'H
M[/P@)7,L(.O\X^_R("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,Q-@IM<V=I9"`B1F%I<B(*;7-G<W1R("+!W^CQZ>_R(@H*(SH@9G)A
M;65W;W)K+T-,22]#3$DN<&AP.C(S-0IM<V=I9"`B1F%T86P@17)R;W(Z(@IM
M<V=S='(@(M#OZ_T@\^_BX?'\(,O<Z._R.B(*"FUS9VED(")&87@B"FUS9W-T
M<B`BUL'.(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C,W-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#$R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(M;EXO'O]=SQZ>_R(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,3@*;7-G:60@(D9E96QS($QI:V4B
M"FUS9W-T<B`BQ.G<Z.7SYR#CZ>$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,3@P"FUS9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`BQ.G<
MZ.7SYR#CZ>$Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M,3<*;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S='(@(LO?X^7R(.+Q[_?=\B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3@*;7-G:60@(D9E
M=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`BR]_CY?(@]^GO[>_P]/[SY>GR(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DR-PIM<V=I9"`B1FEE;&0@
M;6%T<FEX(@IM<V=S='(@(M#?[>'JX?(@T.7DW^_U(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,R!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z.#(*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B
M"FUS9W-T<B`BP?'IZ.S\\B#A\??EW^_U.B`E<R#A\??EW^\B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8S(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HX,@IM<V=I9"`B1FEL92!#;W5N=#H@)7,@
M9FEL97,B"FUS9W-T<B`BP?'IZ.S\\B#A\??EW^_U.B`E<R#A\??EW^$B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Y"FUS9VED(")&:6QE($UA
M;F%G97(B"FUS9W-T<B`BQ.GA]^7I\>GS]-[R(,'Q]^7?^>TB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8V(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HX-0IM<V=I9"`B1FEL92!.86UE(@IM<V=S
M='(@(KSM[^SA(,'Q]^7?[_4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.3<Y"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R("+%\.GK[^/>
M(,'Q]^7?[_4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#@R"FUS
M9VED(")&:6QE('5P;&]A9"(*;7-G<W1R("(GP>W=XN'S[.$G(,'Q]^7?[_4B
M"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-S0*;7-G:60@
M(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(GP>W=XN'S
M[.$G(,'Q]^7?[_4@Y.7M(/7P[_/TY_'?YN7TX>DN(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C@V"FUS9VED(")&:6QT97)S(@IM<V=S='(@(M;?
MZ_3QX2(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S$*;7-G:60@(D9I<G-T
M($AA;&8B"FUS9W-T<B`BT/'^].\@S.GS_"(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U
M87)T97(B"FUS9W-T<B`BT/'^].\@U-WTX?'T[R(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,SD*;7-G:60@(D9I>"!R871I
M;R(*;7-G<W1R("+3].'HY?'\\B#K_./O\B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,30*;7-G:60@(D9L:7`B"FUS9W-T
M<B`B1FQI<"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(D9L;V%T(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q.0IM<V=I9"`B1F]G
M(@IM<V=S='(@(L_LW_?KYR(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z,38S(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,#@*;7-G:60@
M(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*;7-G<W1R("+/(/;<ZN7K[_(@
M)7,@Y.7M(/7PW/'WY>DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(M?Q
M_NSA(./QW.SLX?3O\B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM
M<V=I9"`B1F]O9"(*;7-G<W1R("+4\>_VWB(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B
M1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T
M<B`BP^GA($)R;W=S97)S+"#P[_4@Y.7M(/7P[_/TY_'?YN_U[2#EZ>K\[>7R
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY-0IM<V=I9"`B1F]R
M9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@(L[E]]SSX?3E(/3O[2#J^>3I
MZOP@\^'R.R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S$*;7-G
M:60@(D9O<FUS(@IM<V=S='(@(M;\\>SE\B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*;7-G<W1R("+0\?SBZ^7XYR(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T
M>7!E(@IM<V=S='(@(M3]\._R(-#Q_.+KY?CG\B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS.`IM<V=I9"`B1F]R='5N97,B"FUS9W-T<B`BT/'OXNO=
M^.7I\B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B1F]R
M='5N97,@,B(*;7-G<W1R("+0\>_BZ]WXY>GR(#(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#$T"FUS9VED(")&;W)U;7,B"FUS9W-T<B`B1F]R
M=6US(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U.`IM<V=I9"`B
M1F]R=V%R9',B"FUS9W-T<B`BT/'O^>C>\^7I\B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S
M='(@(M#A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS,PIM<V=I9"`B1G)A;65S(@IM<V=S='(@(M#KX=_SZ>$B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C0Q-PIM<V=I9"`B1G)E92]"=7-Y($EN9F]R;6%T:6]N(@IM<V=S='(@(M#K
MY_'O]N_QW^7R(,3IX>CE\^GL_/3G].'R(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT,C<*;7-G:60@(D9R964O0G5S
M>2!297!L>2(*;7-G<W1R("+!\-SM].?SYR#$Z>'HY?/I[/STY_3A\B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#(R
M"FUS9VED(")&<F5E+T)U<WD@4F5Q=65S="(*;7-G<W1R("+!W_3G[.$@Q.GA
MZ.7SZ>S\].?TX?(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C(W,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C,T,0IM<V=I9"`B1G)E92]"=7-Y(%)E<75E<W0@
M4F5S<&]N<V4B"FUS9W-T<B`BP?#<[?3G\^<@\^4@X=_TY^SA(,3IX>CE\^GL
M_/3G].'R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R
M+G!H<#HW.0IM<V=I9"`B1G)O;2(*;7-G<W1R("+!\/PB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3DW"FUS9VED(")&<F]M('1H92`B"FUS
M9W-T<B`BP?#\(/3O("(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C0X"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(L'MX>OU
M].GJWB#0Y?'IX_'A]MXB"@IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;CHB"FUS
M9W-T<B`BP>WAZ_7TZ>K>(-#E\>GC\>'VWCHB"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z.#(@;&EB+T)L;V-K+VUO;VXN<&AP.C$X,0IM<V=I9"`B1G5L;"!-
M;V]N(@IM<V=S='(@(M#KWO'G\B#3Y>O>[><B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C,Y"FUS9VED(")&=6QL($YA;64B"FUS9W-T
M<B`BT.O>\>7R(+SM[^SA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL97)Y('1O
M('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R(")'86QL97)Y(.'P_"#TY^T@[_#O
MW^$@Z.$@\.'?\>WO[?3AZ2#OZ2#EZ>K\[>7R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED
M(")'86QL97)Y.B(*;7-G<W1R(")'86QL97)Y.B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3DY"FUS9VED(")':79E;B!.86UE(@IM
M<V=S='(@(LSIZO'\(+SM[^SA(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$W-2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ,`HC.B!T96UP
M;&%T97,O<')E9G,O87!P+FEN8SHQ.0IM<V=I9"`B1VQO8F%L($]P=&EO;G,B
M"FUS9W-T<B`BP^7MZ>K=\B#%\.GK[^/=\B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]A<'`N:6YC.C$V"FUS9VED(")';R(*;7-G<W1R("+,Y?3<XN'SYR(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<W"FUS9VED(")'<F5E8V4B"FUS9W-T<B`BQ>OKW.3A(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D=R965K("A)4T\M.#@U
M.2TW*2(*;7-G<W1R("+%Z^OG[>GJW"`H25-/+3@X-3DM-RDB"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C$W,`IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB
M"FUS9W-T<B`BQ.GA]^7?\>GSYR#/[-SD^>TB"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`N<&AP.C4W"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO
M;BUE;7!T>2(*;7-G<W1R("+4X2#O[?SLX?3A(/3Y[2#O[-SD^>T@Y.7M(/#Q
MW?#EZ2#MX2#EW^WAZ2#JY>W<(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z
M,C`Q(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C@U"FUS9VED(")'
M<F]U<"!P97)M:7-S:6]N<R(*;7-G<W1R("+%[N_U\^GOY._TWO/EZ?(@S^S<
MY/GM(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3<V(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,C4X"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C,X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@S"FUS9VED(")'<F]U
M<',B"FUS9W-T<B`BS^S<Y.7R(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z
M,3(W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C$S"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z.30*;7-G:60@(D=U97-T(%!E<FUI<W-I
M;VYS(@IM<V=S='(@(LGDZ?STY_3E\B!'=65S="(*"B,Z(&%D;6EN+W!E<FUS
M+V5D:70N<&AP.C$R."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Q
M-`IM<V=I9"`B1W5E<W0@<&5R;6ES<VEO;G,B"FUS9W-T<B`BR>3I_/3G].7R
M($=U97-T(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S.0IM<V=I
M9"`B1W5E<W1B;V]K(@IM<V=S='(@(D=U97-T8F]O:R(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O:'1T<"YP:'`Z,38T"FUS9VED(")(5%10($%U=&AE;G1I
M8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`BU.\@\_WS].?LX2#A]>CE[?3I
MZN_P[]_G\^?R($A45%`@Y.4@XO'=Z.?JY2XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T"FUS9VED(")(96EG
M:'0B"FUS9W-T<B`BOOCO\B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92](
M96QP+G!H<#HQ-SD@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$X
M-@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ-R!T96UP;&%T97,O:&5L
M<"]I;F1E>"YI;F,Z,PIM<V=I9"`B2&5L<"(*;7-G<W1R("+"[][HY>GA(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM
M<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`BPN_>Z.7IX2#CZ>$@
M].<@]_'>\^<@]._U(.KEZ>SE[>_C\=SV[_4B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,S8W"FUS9VED(")(96QP97(B"FUS9W-T<B`BPN_GZ/SR
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H97)E
M(@IM<V=S='(@(L?LZ?/VX=_QZ>\B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I
M;F9O+FEN8SHQ-R!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I
M9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R
M("+%Y/X@Y=_MX>D@YR#A\??>(/3O]2#A\??EW^_U.B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS-C$*;7-G:60@(DAI9V@B"FUS9W-T<B`B
MV.?KW"(*"B,Z(&9R86UE=V]R:R](:7-T;W)Y+TAI<W1O<GDN<&AP.C,R,@IM
M<V=I9"`B2&ES=&]R>2!E;G1R>2!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*
M;7-G<W1R("+'(.7CX_'A]MX@Z?/T[_'IZN_](.3E[2#P\=WPY>D@[>$@Y=_M
MX>D@ZN7MWB(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP
M;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-`IM<V=I9"`B2&]?;64B
M"FUS9W-T<B`BP?'WZ>K>(-/EZ]_DX2(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,30V,`IM<V=I9"`B2&]M92(*;7-G<W1R("+!\??IZMX@T^7K
MW^3A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$R-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,34X"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`BQ.GE_>CU[?/G(-/P
MZ?3I[_TB"@IM<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R("+4Y^O=]OGM[R#3
M\.GTZ>_](@H*;7-G:60@(DAO<F1E(@IM<V=S='(@(L'Q]^GJWB#3Y>O?Y.$B
M"@IM<V=I9"`B2&]R9&4@3&]G:6XB"FUS9W-T<B`BQ=_S[^3O\B#S].?M(-7P
MY_'E\]_A(,?+Y>KT\>_MZ>KO_2#4X??UY/'O[.7?[_4B"@IM<V=I9"`B2&]R
M9&4@4WES=&5M(@IM<V=S='(@(M/]\_3G[.$@)TAO<F1E)R(*"FUS9VED(")(
M;W)D92!7:7)E;&5S<R(*;7-G<W1R("(G2&]R9&4G(,'S_?'LX?3G(@H*;7-G
M:60@(DAO<F1E(&ES(&YO="!P<F]P97)L>2!C;VYF:6=U<F5D(@IM<V=S='(@
M(M3O(/#Q_./QX>SLX2`G2&]R9&4G(.3E[2#=]^7I(/'UZ.SI\_3EWR#S^?/T
MW"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C0*;7-G:60@(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R("+/\>GF_.WTZ>_R
M(,KA[?SMX?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B
MS_'IYOSM].GO("?CW>SI\^SA)R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S
M='(@(L_QZ>;\[?3I[SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(DAO=R!D:60@>6]U(&=E
M="!H97)E/R`H4&QE87-E(')E<&]R="$I(@IM<V=S='(@(M#Y\B#VZ-SSX?3E
M(.7D_CL@*/#A\>'JX>O^(.WA(/3O(.'MX?;=\>7TY2#S].\@Y.GA]^7I\>GS
M]-XA*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U
M(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(M#\\^7R(//TWNOE\B#HW>OE].4@
M[>$@Y>WO\._IWO/E].4[(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,C@*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H
M97)E/R(*;7-G<W1R("+0_//A(/#EY-_A("CS]-[KY?(I(.7?[>'I(.7JY=\[
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T
M;R!M97)G93\B"FUS9W-T<B`BT/SSY?(@X_'A[.S=\B#HW>OE].4@[>$@Y>WO
M\._IWO/E].4[(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C@*;7-G:60@
M(DAU;6ED:71Y(@IM<V=S='(@(M7C\>'SW^$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C`S"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@
M(M7C\>'SW^$Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED
M(")(=6UO<FES=',B"FUS9W-T<B`BU^GO]>SO\=_S].'R(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<V(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER<W%L+G!H<#HR,C,*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO
M;B!F86EL960Z("5S(@IM<V=S='(@(L<@Q.?LZ>_U\>/?X2#C\>'L[.'T[^CU
M\=_DX?(@24U!4"#A\-WT]??E.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER=7,N<&AP.C(R,"!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP
M:'`Z,C@X"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E
M<R(*;7-G<W1R("+'(.3IX>/QX?;>(./QX>SLX?3OZ/7QW^3A\B!)34%0(.'P
MW?3U]^4Z("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z
M,3@S(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR,S`*;7-G:60@
M(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S
M='(@(L<@Q.?LZ>_U\>/?X2#PY>GQ[_'I\^S^[2`H<75O=&$I(./QX>SLX?3O
MZ/7QW^3A\B!)34%0(.'PW?3U]^4Z("5S(@H*;7-G:60@(DE.0D]8(@IM<V=S
M='(@(L7I\^7Q]_SLY>WA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3,Q,0IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R("))4"W$Z>7]Z/7M\^<B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C@R"FUS9VED
M("))4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DE0+<3IY?WH
M]>WSYR#DY>T@Y=_MX>D@Y.GAZ-WSZ>SG+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:7!B87-I8RYP:'`Z.30*;7-G:60@(DE0($%D9')E<W,@;F]T('=I
M=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@(DE0+<3IY?WH]>WS
MYR#LYR#E\.GT\>7P]-X@[-WSX2#SY2!#2412+4)L;V-K+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I
M9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R("+*Z^7?Y/GLX2W0
MX?'AXM_A\^<@25`N(@H*;7-G:60@(DE?;F)O>"(*;7-G<W1R("+%Z?/E\??\
M[.7MX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S
M='(@(L7I\^'C^>/>(,/QX>SLWO(@T/'I[2(*"FUS9VED("))8V]N<R!/;FQY
M(@IM<V=S='(@(LS\[>\@Q>GJ[^W?Y.GA(@H*(SH@=71I;"]I8V]N7V)R;W=S
M97(N<&AP.C0Y"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T<B`BQ>GJ[^W?
MY.GA(./IX2`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C$*;7-G
M:60@(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R("+%Z>KO[=_DZ>$@ZN'I(,KE
MW^SE[>\B"@IM<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R("+/[>_L
MX2#TX?7T_/3G].'R.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C8P.`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R
M96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R
M("+![2#DY>T@Y>SVX>W?YN7TX>D@\_GS]-PL("5S(./IX2#MX2#A[>_?[N7I
M(//E(.W=[R#PX?'<Z/7Q[RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#,Y"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN
M9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*
M(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S
M='(@(B(*(L'M(.3E(.+KW?#E].4@ZN'MW>WA(.7IZN_MW^3I[R#W\>?SZ>SO
M\._I_NWTX?(@]._M($EN=&5R;F5T($5X<&QO<F5R+"#?\_GR("(*(O#QW?#E
MZ2#MX2#T\^7JW/'E].4@Y>3^(./IX2#MX2#A\.7MY?'C[_#OZ=[SY?3E(/3G
M(.3IX?;<[>7IX2!03D<N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$U.`IM<V=I9"`B(@HB268@>6]U('-E92!T:&ES(&UE
M<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L
M;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM
M<V=S='(@(B(*(L'M(.+KW?#E].4@X?7T_"#T[R#LWNWU[.$@]_GQW_(@Y>GJ
M_.WA+"#G(.7IZOSMX2#P[_4@Z-WKY?3E(.WA(.KA].7BW//E].4@Y.4@(@HB
M[/#O\>7?(.WA(.7L]N'MZ?/HY=\@X?#\(/3O[2!B<F]W<V5R(//A\BXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C@*;7-G:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(M#Q[^7P
MZ?/J_/#I\^<@Q>GJ_.WA\CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,W"FUS9VED("));6%G92!54DPB"FUS
M9W-T<B`B55),(,7IZOSMX?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R
M;VT@9V%L;&5R>2(*;7-G<W1R("+%Z>K\[>$@X?#\($=A;&QE<GDB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`BQ>GJ
M_.WA(.'P_"!'86QL97)Y.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$W-#@*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R("+!\._S]._KWB#%
MZ>K\[>'R(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S<*;7-G:60@(DEM
M86=E<R(*;7-G<W1R("+%Z>K\[>7R(@H*;7-G:60@(DEM<&]R="(*;7-G<W1R
M("+%Z?/AX_GCWB(*"FUS9VED("));7!O<G0@17)R;W(Z("(*;7-G<W1R("++
MW.CO\B#JX?3<(/3G[2#%Z?/AX_GCWCH@(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,3`*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-R!T96UP;&%T97,O9&%T
M82]C<W9I;F9O+FEN8SHQ,`IM<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S
M='(@(L7I\^'C^>/>+"#"WNSA("5D(@H*(R!T96UP;&%T97,O9&%T82]D871E
M;6%P+FEN8SHR,"P@8RUF;W)M870*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA
M<"YI;F,Z,C`*;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R("+0
MY>3?[R#P[_4@Y>GSWO?HYSH@)7,B"@IM<V=I9"`B26UP;W)T960@9FEE;&1S
M.B(*;7-G<W1R("+0Y>3?X2#P[_4@Y>GSWO?HY_/A[3HB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C<P,0IM<V=I9"`B
M26X@4')O8V5S<R(*;7-G<W1R("+3Y2#%\.7NY?'CX?/?X2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM
M<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T<B`BQ>GSX>/YX]X@P_'A
M[.S>\B#,Y?3<(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII
M<"YP:'`Z,30Q"FUS9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN
M(@IM<V=S='(@(L3\Z.?JY2#KW.CO\B#J^>3IZOSR(.7MW?'CY>GA\BXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8U
M-PIM<V=I9"`B26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"XB
M"FUS9W-T<B`BR]SH[_(@_.WO[.$@]_'>\_3G(-XOZN'I(.KYY.GJ_/(N(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN
M8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G
M86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N
M965D(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HBR]SH[_(@_.WO[.$@]_'>
M\_3G(-X@Y>WAZ^OAZO3IZMX@Y.GE_>CU[?/G+B#.X>WAY._JZ>S<\_3E(-X@
MY?#IZN_I[?GMWO/TY2#LY2`B"B+T[R#DZ>'WY>GQZ?/TWB#CZ>$@\.7QX>GT
MW?'Y(.+OWNCEZ>$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@
M(L'][N?SYR#0Y?'IZ/GQW^_U(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z
M,30Q('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30P"FUS9VED("));F1I
M=FED=6%L(%5S97)S(@IM<V=S='(@(LGDZ>'?].7Q[^D@U_'>\_3E\B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(*;7-G
M:60@(DEN9F\B"FUS9W-T<B`BT.OG\>_V[_'?Y?(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C0Y"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R
M("+0Z^?Q[_;O\=_E\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T($-?;VQU;6X@
M069T97(B"FUS9W-T<B`BQ>GSX>/YX]X@T_3>Z^?R(,SE]-PB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C`*;7-G:60@(DEN<V5R="!);6%G92(*;7-G<W1R("+%Z?/AX_GCWB#%Z>K\
M[>'R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P,`IM<V=I9"`B26YS97)T(%1A8FQE(@IM<V=S='(@(L7I\^'C^>/>(-#?
M[>'JX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C4*;7-G:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("+%Z?/AX_GC
MWB#S_>WDY?/G\B!796(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@(DEN<V5R="!?0V]L=6UN
M($)E9F]R92(*;7-G<W1R("+%Z?/AX_GCWB#3]-[KY_(@T/'I[2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N
M="!O;F4B"FUS9W-T<B`BQ>GSX>/YX]X@[=WA\B#S]-[KY_(@[.7TW"#TY^T@
M]/'=]^_U\^$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@
M8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("+%Z?/AX_GCWB#MW>'R
M(//TWNOG\B#P\>GM(.'P_"#TY^T@]/'=]^_U\^$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@
M(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S
M='(@(L7I\^'C^>/>(.W=X?(@X_'A[.S>\B#LY?3<(/3G[2#T\=WW[_7SX2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV,`IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U
M<G)E;G0@;VYE(@IM<V=S='(@(L7I\^'C^>/>(.W=X?(@X_'A[.S>\B#LY?3<
M(/3G[2#T\=WW[_7SX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R86=R
M87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`BQ>GAX_GCWB#P
MX?'AX_'<]N_U(.SE]-P@]._M(/3QW??O[?3A(.K\[.+O(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"FUS
M9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO
M9&4B"FUS9W-T<B`BQ>GSX>/YX]X@\.'QX>/QW/;O]2#P\>GM(/3O[2#T\=WW
M[^WTX2#J_.SB[R(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS9VED
M("));G-E<G0@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(L7I\^'C^>/>
M(.7MX>OKX>KTZ>KO_2#P\>_T_?#O]2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR,C,*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H
M:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R
M("(B"B+$_O/TY2!E;6%I;"#DZ>7]Z/7M\^<@\_3G[2#O\._?X2#E\.GH]>SE
MW_3E(.WA(/#A\>'KW.+E].4@].\@[=WO(//A\B#J^>3IZOPZ(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`IM
M<V=I9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T<B`BQ>GSX>/YX]X@ZN7K
MZ>_](.SE]-PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4Y"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS
M9W-T<B`BQ>GSX>/YX]X@ZN7KZ>_](/#QZ>TB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED("));G-E
M<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@(L7I\^'C^>/>(//TWNOG\B#LY?3<
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`B
MQ>GSX>/YX]X@\_3>Z^?R(/#QZ>TB"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HY,PIM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM
M<V=S='(@(L7I\^'C^>/>(.SG[?WLX?3O\B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS
M97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R("+%Z?/AX_GCWB#PX?'AX_'<
M]N_U(.SE]-PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@8F5F
M;W)E(@IM<V=S='(@(L7I\^'C^>/>(/#A\>'C\=SV[_4@\/'I[2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*
M;7-G:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`BQ>GSX>/YX]X@X_'A
M[.S>\B#LY?3<(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS
M9W-T<B`BQ>GSX>/YX]X@X_'A[.S>\B#P\>GM(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(Q-`IM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W
M97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R("+%Z?/AX_GC
MWB#TY_(@X?#AZ?3O_>SE[>?R(.'PW.WTY_/G\B#S].?M(.7Q_O3G\^<@X?/V
MX>OEW^'R.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B
MQ>GSX>/YX]XOQ.G\\>CY\^<@Q>GJ_.WA\B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I
M9GD@3&EN:R(*;7-G<W1R("+%Z?/AX_GCWB_$Z?SQZ/GSYR#3_>WDY?/G\B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C8X"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE
M(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("+,YR#E\.'QZMWR(/7P_.OO
MZ?#O(./IX2#A\._S]._KWB#S].<@Z]_S].$@Y.GA[>_LWO(N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-C`*;7-G
M:60@(DEN<W5F9FEC:65N="!C<F5D:70N(@IM<V=S='(@(LSG(.7PX?'JW?(@
M]?#\Z^_I\.\N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V.0IM
M<V=I9"`B26YT96=E<B(*;7-G<W1R("+!ZMWQX>GO\B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Q,C<*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G
M<W1R("++W_/TX2#!ZN7QX=_Y[2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z,C@S"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,S4R"FUS9VED("));G9A;&ED($%C
M=&EO;B!S96QE8W1E9"!F;W(@=&AI<R!C;VUP;VYE;G0N(@IM<V=S='(@(L7P
MZ>O=[N'TY2#+W.CO\B#%[=WQX^7IX2#CZ2<@X?7T_"#T[R#S]?/TX?3IZOPN
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`V"FUS9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I
M+B(*;7-G<W1R("+!ZO7Q[R!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P
M<&QI8V%T:6]N+B(*;7-G<W1R("+,YR#=X^KU\><@Y?;A\>SOX]XN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S(Q
M"FUS9VED("));G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R("+!ZO7Q[R!"871C
M:"U)1"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#<P(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-#$*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(Q-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C@P"FUS9VED
M("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R("+3]-SKZ.?JX>T@
MZ]SH[_(@Y.7D[^S=[>$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED("));G9A;&ED(&1E<W1I;F%T
M:6]N(&%D9')E<W,N(@IM<V=S='(@(L'J]?'G(.3IY?WH]>WSYR#P\>_O\>GS
M[._]+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP
M.C@T"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P
M,PHC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR,C,*
M;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`BS.<@W>/J]?'G
M(.SO\?;>(.'Q]^7?[_4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,38*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N
M(@IM<V=S='(@(LSG(-WCZO7Q[R!M<V=?='EP92XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN
M=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(LSG(-WCZO7Q[R#>
M(.OEW_#EZ2!A<&E?:60N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED("));G9A;&ED(&]R(&UI<W-I
M;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`BS.<@W>/J]?'E\B#>(.7KZ^GPY=_R
M(/#A\=SLY?3Q[^DN(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C0S
M"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R("))
M;G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B26YV86QI
M9"!P<F]T;V-O;"XB"FUS9W-T<B`BS.<@W>/J]?'O(/#Q^?3\ZN_KZ^\N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY
M,0IM<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z("<E<R<B"FUS9W-T<B`BS.<@
MW>/J]?'O\B#PX?'AZ][P].?R.B`G)7,G(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HQ,#<Q(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(T
M.`IM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`BS.<@W>/J
M]?'O(.KOZ>W\]_'G\_3O(.'M].GJY=_LY>WO(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"FUS9VED("));G9A
M;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R("+,YR#=X^KU\><@X?'WZ>K>
M(.3IY?WH]>WSYRXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,C`*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A
M+B(*;7-G<W1R("+,YR#=X^KU\>$@Y.7D[^S=[>$@56YI8V]D92XB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(X"FUS9VED("));G9E;G1O<GDB
M"FUS9W-T<B`BRN'TW.OOX^_R(-7PX?'W_.WT^>TB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET86QI8R(*
M;7-G<W1R("+0Z^'CZ>$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,S<T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,3$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R("+)X>WO]=SQ
MZ>_R(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C,X,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`BR>_]Z^GO\B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-SD*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM
M<V=S='(@(LGO_>WI[_(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S='(@
M(L7UZ/7C\=SL[.GSYR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$U"FUS9VED(")*=7-T:69Y($-E;G1E<B(*
M;7-G<W1R("+%]>CUX_'<[.SI\^<@\_3O(,K=[?3Q[R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$W"FUS9VED
M(")*=7-T:69Y($9U;&PB"FUS9W-T<B`BT.O>\>?R(,7UZ/7C\=SL[.GSYR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$T"FUS9VED(")*=7-T:69Y($QE9G0B"FUS9W-T<B`BQ?7H]>/QW.SL
MZ?/G(,'QZ?/TY?'<(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS
M9W-T<B`BQ?7H]>/QW.SLZ?/G(,3E[NG<(@H*;7-G:60@(DMA;&%M871A($%I
M<G!O<G0B"FUS9W-T<B`BP>7Q[^OI[-WMX?(@RN'KX>S<].'R(@H*;7-G:60@
M(DMA<G!A=&AO<R!!:7)P;W)T(@IM<V=S='(@(L'E\>_KZ>S=[>'R(,KA\?#<
MZ._U(@H*;7-G:60@(DMA<W1O<FEA($%I<G!O<G0B"FUS9W-T<B`BP>7Q[^OI
M[-WMX?(@RN'S]._QZ=SR(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(T-@IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T
M<B`BS>$@ZO'A]-[S^2#T[R#A]>CE[?3IZOP[(@H*;7-G:60@(DME9F%L:&YI
M82!!:7)P;W)T(@IM<V=S='(@(L'E\>_KZ>S=[>'R(,KE]N'K[^WIW/(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@W"FUS9VED(")+97)B
M97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(DME<F)E<F]S+5-E<G9E<B#A\>W>Z.?JY2#TY^T@X?7HY>WTZ>KO\._?Y_/G
M+B(*"FUS9VED(")+97)K>7)A($%I<G!O<G0B"FUS9W-T<B`BP>7Q[^OI[-WM
MX?(@RMWQZO7QX?(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G
M:60@(DME<FYE;"!.97=B:65S(@IM<V=S='(@(LW=X2#A\/P@2V5R;F5L(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,SDW"FUS9VED(")+
M97D@0W)E871I;VXB"FUS9W-T<B`BQ.?LZ>_U\>/?X2#*Z^7IY.GO_2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0P,`IM<V=I9"`B2V5Y
M($9I;F=E<G!R:6YT(@IM<V=S='(@(L'P[_3]\/GLX2#*Z^7IY.GO_2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C,Y.`IM<V=I9"`B2V5Y
M($QE;F=T:"(*;7-G<W1R("+,WNKO\B#*Z^7IY.GO_2(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C,Y-PIM<V=I9"`B2V5Y(%1Y<&4B"FUS
M9W-T<B`BU/WP[_(@RNOEZ>3I[_TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8R,@IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(M?Q
MWO/G(,KKY>GDZ>_](@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-S0S"FUS9VED(")+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI
M8R!K97ES97)V97(N(@IM<V=S='(@(M3O(.KKY>GDWR#U\-SQ]^7I(-[DYR#S
M]._M(.7N]?#G\>7TY_3>(.3G[/SSZ?GM(.KKY>GDZ?[M+B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G<W1R("+0X>GD
MZ=PB"@IM<V=I9"`B2V]S($%I<G!O<G0B"FUS9W-T<B`BP>7Q[^OI[-WMX?(@
MRODB"@IM<V=I9"`B2V]Z86YI($%I<G!O<G0B"FUS9W-T<B`BP>7Q[^OI[-WM
MX?(@RN_FW.WG\B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z.`IM
M<V=I9"`B3&%?>6]U="(*;7-G<W1R("+$Z=STX>[G(@H*;7-G:60@(DQA<FES
M82!!:7)P;W)T(@IM<V=S='(@(L'E\>_KZ>S=[>'R(,O<\>GSX?(B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED("),87-T($AA;&8B"FUS9W-T
M<B`BU.7KY?7TX=_O(,SI\_PB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@@
M;&EB+T)L;V-K+VUO;VXN<&AP.CDP"FUS9VED("),87-T(%%U87)T97(B"FUS
M9W-T<B`BU.7KY?7TX=_O(-3=].'Q].\B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$T.0IM<V=I9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R("+4Y>OE]?3A
MW^$@Q>WG[-WQ^?/G.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C8Y
M,0IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`BU.7KY?7TX=_A(,7?
M\^_D[_(@\_3G[2#U\.?QY?/?X3H@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HV.3,*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS
M9W-T<B`BU.7KY?7TX=_A(,7?\^_D[_(@\_3G[2#U\.?QY?/?X3H@)7,@X?#\
M("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-C@X"FUS9VED("),
M87-T(&QO9VEN.B!.979E<B(*;7-G<W1R("+4Y>OE]?3AW^$@Q=_S[^3O\B#S
M].?M(/7PY_'E\]_A.B#0[_3=(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0T"FUS9VED("),87<B"FUS9W-T<B`BS?SL[_(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*;7-G:60@(DQA
M>6]U="(*;7-G<W1R("+$Z=STX>[G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R
M(&YO(&)O<F1E<B(*;7-G<W1R("+!]M[S].4@ZN7M_"#CZ>$@[>$@[.?M(/7P
MW/'W[_7M(/#E\>GH_O'IX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B3&5F="(*;7-G<W1R("+!
M\>GS].7QW"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,#,*;7-G
M:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(L'QZ?/TY?'>(,7PZ>KE]N'KW^3A
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S`Y.0IM<V=I9"`B3&5F
M="!V86QU97,B"FUS9W-T<B`BP?'I\_3E\=WR(-3I[-WR(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0U"FUS9VED("),:6UE<FEC:R(*;7-G<W1R("+0
MY>WTW//TZ??O(@H*;7-G:60@(DQI;6YO<R!!:7)P;W)T(@IM<V=S='(@(L'E
M\>_KZ>S=[>'R(,O>[.WO]2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X,#$*;7-G:60@(DQI;FLB"FUS9W-T<B`BT_WMY.7SYR(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM
M<V=I9"`B3&EN:R!P;VEN=',@=&\Z(@IM<V=S='(@(M/][>3E\^<@\._U(.3E
MW_?MY>D@\^4Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U.`IM
M<V=I9"`B3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P
M86=E('=H96X@9&ES<&QA>6EN9R(*;7-G<W1R("+3_>WDY?/G(/3G\B#DZ>7]
MZ/7M\^<@X^GA(-SM[^GC[.$@\.'QX>C]\>_U(//][>CE\^?R.R(*"B,Z(&9R
M86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:'1M;#)T97AT+G!H<#HQ-C(*
M;7-G:60@(DQI;FMS(@IM<V=S='(@(M/U[>3=\^7I\B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@
M(DQI;G5X+4-O;VMI92(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C@Y"FUS9VED("),:7-T("T@=7-E<B!C86X@<V5E('1H92!F
M;VQD97(B"FUS9W-T<B`B3&ES="`M(,\@]_'>\_3G\B#L\._QY=\@[>$@Y.7?
M(/3O(/;<ZN7K[R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S@*;7-G:60@
M(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(LO?\_3A(,+<\^7Y[2#$Y>3O[-WM
M^>TB"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,`IM<V=I9"`B3&ES
M="!(96QP(%1O<&EC<R(*;7-G<W1R("++W_/TX2#HY>S<]/GM(,+OWNCEZ>'R
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S-PIM<V=I9"`B3&ES="!486)L
M97,B"FUS9W-T<B`BR]_S].$@T.GMW.KY[2(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VYO;&ES="YI;F,Z-`IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D
M:7-A8FQE9"XB"FUS9W-T<B`BQR#DY^SI[_7QX]_A(.O?\_3A\B#W\>?S]/[M
M(-WWY>D@X?#E[>7QX^_P[^GGZ.7?+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEM86=E<RYP:'`Z.#8*;7-G:60@(DQO861I;F<N+BXB"FUS
M9W-T<B`BUOSQ]/GSYRXN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-C`*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R("+4[_#IZMX@
MO_'A.B`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@(DQO
M8V%L92!A;F0@5&EM92(*;7-G<W1R("+4_/#O\B#JX>D@_O'A(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.34*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU-S`@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C4P"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H
M<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP.C8S"FUS9VED("),;V-A=&EO;B(*
M;7-G<W1R("+4_/#OZ.7SW^$B"@IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(L7?
M\^_D[_(B"@IM<V=I9"`B3&]G(&]U="(*;7-G<W1R("*X[N_D[_(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W"FUS9VED("),;V=I;B!487-K<R(*
M;7-G<W1R("+$Z>7QX^'SW^7R(.7I\_SD[_4B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HY-3(*;7-G:60@(B(*(DQO9VEN(&9A:6QE9"!F;W(@<V]M
M92!R96%S;VXN($UO<W0@;&EK96QY('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O
M<F0@=V%S("(*(F5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@(B(*(L<@
MY=_S[^3O\B#!\-WT]??E+B#0Z>CA[?STX?3A(.3\Z.?JY2#KW.CO\B#T[R"\
M[>_LX2#7\=[S].<@WB#O(,KYY.GJ_/(N(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z.30X"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S='(@(L7?
M\^_D[_(@P?#=]/7WY2XB"@IM<V=I9"`B3&]G;W5T(@IM<V=S='(@(KCN[^3O
M\B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C$*;7-G:60@(DQO
M;F<@=&5X="(*;7-G<W1R("+,Y>/<Z^\@RN7?[.7M[R(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT.`IM<V=I9"`B3&]V92(*;7-G<W1R("+!X]SPYR(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-3D*;7-G:60@(DQO
M=R(*;7-G<W1R("+7X>SGZ_PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E
M:R!L971T97)S(@IM<V=S='(@(LSIZO'<(,7KZ^?MZ>K<(./QW.SLX?3A(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N
M9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("+,
MZ>KQW"#KX?3I[>GJW"#C\=SL[.'TX2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R
M(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`BS.GJ\=P@T?GLX?KJWB#!\=_H[.?S
MYR(*"FUS9VED(")-32(*;7-G<W1R("+,S"(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT.0IM<V=I9"`B36%G:6,B"FUS9W-T<B`BS.'CZ>K\(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C<Q"FUS9VED(")-86EL(@IM<V=S
M='(@(L'KZ^?K[^/QX?;?X2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ,30*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`BQ.GA]^7?\>GSYR!%
M;6%I;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHT,`IM<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R("+$
MY^SI[_7QX]_A(-/][>3E\^?R+BXN(@H*;7-G:60@(B(*(DUA;F%G92!T:&4@
M;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I
M=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G
M;W)I97,N(@IM<V=S='(@(L3IX??EW_'I\^<@ZN'TY^/O\>G^[2#JX>D@]_'Y
M[-ST^>T@\._U(.CA(.7L]N'MW^;O[?3AZ2#A]?3=\BXB"@IM<V=I9"`B36%N
M=6%L(@IM<V=S='(@(L7C]^7I\=_DZ>\B"@IM<V=I9"`B36%P($1A=&4@86YD
M(%1I;64@1FEE;&1S(@IM<V=S='(@(M#EY-_A(,?LY?'O[.?MW^'R(.KAZ2"_
M\>'R(@H*;7-G:60@(DUA<"!);7!O<G0@1FEE;&1S(@IM<V=S='(@(M#EY-_A
M(.7I\^'C^>/>\B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HS-S8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0Q,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C8W"FUS9VED(")-87)C:"(*;7-G<W1R("+,W/'TZ>_R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M,0IM<V=I9"`B36%R9VEN(@IM<V=S='(@(KSQZ>\B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B36%R:R!W:71H
M(%-E96XO56YS965N(&9L86=S(@IM<V=S='(@(LSA\>K<\>GS[.$@[.4@W>WD
MY>GNYR#![>'C[?GS[-WM[_4OS.<@X>WAX^WY\^S=[>_U(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@(DUA<FL@
M=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM
M<V=S='(@(LSA\>K<\>GS[.$@[.4@W.OKYR#=[>3EZ>[G("CP+O<N(-/G[.'M
M].GJ_"_!\.'M].?LW>WO*2(*"FUS9VED(")-871C:&EN9R!F:65L9',B"FUS
M9W-T<B`BT.7DW^$@\._U(/3AZ?'IW.;O]>TB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,C0*;7-G:60@(DUA>"!A
M;&QO=V5D(&-R961I="XB"FUS9W-T<B`BS-WCZ?/TYR#E\.GT\>7P]-X@\-_S
M]/GSYRXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,3<*;7-G:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D
M+B(*;7-G<W1R("+5\-WQXN'SYR#O\=_O]2#LY^W][.'T[_(N(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,#0*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@
M:&]U<G,Z("(*;7-G<W1R("+,W>/I\_3G(.CE\>SOZO'A\]_A(/3EZ^7U].'?
M^>T@,C0@^?'^[3H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.38*;7-G
M:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(LS=X^GS].<@
MZ.7Q[._J\>'SW^$@].7KY?7TX=_Y[2`V(/GQ_NTZ("(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C@Y,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C`X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S`*;7-G:60@(DUA
M>&EM=6T@;&5N9W1H(@IM<V=S='(@(LS=X^GS].\@[-[J[_(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<X"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,34*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y
M(@IM<V=S='(@(LS<Z>_R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HU,S$*;7-G:60@(DUE971I;F<@0V%N8V5L;&%T
M:6]N(@IM<V=S='(@(L'J_?'Y\^<@T_7MW.WTY_/G\B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3`S"FUS9VED(")-
M965T:6YG($EN9F]R;6%T:6]N(@IM<V=S='(@(M#KY_'O]N_QW^7R(-/U[=SM
M].?SY_(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C4P.0IM<V=I9"`B365E=&EN9R!0<F]P;W-A;"(*;7-G<W1R("+0
M\?STX?/G(./IX2#3]>W<[?3G\^<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C4R-0IM<V=I9"`B365E=&EN9R!297!L
M>2(*;7-G<W1R("+!\-SM].?SYR#CZ>$@T_7MW.WTY_/G(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,30*;7-G:60@
M(DUE971I;F<@57!D871E(@IM<V=S='(@(L7MY^S=\?GSYR#CZ>$@T_7MW.WT
MY_/G(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HU,3D*;7-G:60@(DUE971I;F<@57!D871E(%)E<75E<W0B"FUS9W-T
M<B`BP=_TY^SA(.7MY^S=\?GSY_(@X^GA(-/U[=SM].?SYR(*"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3D*;7-G:60@(DUE;6)E<G,B
M"FUS9W-T<B`BS-WKYR(*"FUS9VED(")-96UO<R(*;7-G<W1R("+3Y^SEZ?[S
MY>GR(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V,@IM<V=I9"`B365N
M=2!M;V1E.B(*;7-G<W1R("+*X?3<\_3A\^<@S.7M[_TZ(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I
M9"`B365R9V4@8V5L;',B"FUS9W-T<B`BT_7C]_[MY?7SYR#JY>OI_NTB"@HC
M.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]S=&%T=7,N<&AP.C,R"FUS9VED(")-97-S86=E(@IM<V=S='(@(LS>[?7L
MX2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C(V"FUS
M9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE
M('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92`B"B)V97)I9FEE
M9"XB"FUS9W-T<B`B(@HBU.\@[-[M]>SA(.7PZ>+EXN'I_NCGZN4@Y?#I]/7W
M_O(L(.'KZ]P@].\@\.GS]._P[^GG].GJ_"#T[_4@]?#OX_'<]N_M].$@Y.4@
M(@HB[/#O\>7?(.WA(.7PZ>+EXN'I^>CEWRXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3D*;7-G:60@(DUE<W-A
M9V4@97AP:7)E9"XB"FUS9W-T<B`BU.\@[-[M]>SA(-WKY^[E+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DQ"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C(V
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(S,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR-C@*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R("+4_?#O\B#L
MY^W][.'T[_(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE
M=&%R(%=E871H97(B"FUS9W-T<B`BRN'I\?SR(.'P_"!-971A<B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A
M=F%I;&%B;&4N(@IM<V=S='(@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3`*;7-G:60@(B(*(DUE=&%R
M(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E
M9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(DUE=&%R(&)L
M;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F
M;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HW,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<T"FUS9VED(")-971H;V0B"FUS9W-T<B`BS-WH[^3O\B(*
M"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z.#(@9G)A;65W;W)K
M+U)00R]24$,O<V]A<"YP:'`Z,3$W"FUS9VED(")-971H;V0@)R5S)R!I<R!N
M;W0@9&5F:6YE9"(*;7-G<W1R("+'(,S=Z._D[_(@)R5S)R#DY>T@[_'?\^CG
MZN4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-3D@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HW,PIM<V=I9"`B365T<FEC(@IM<V=S='(@(LSE]/'I
MZOPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S8*;7-G:60@(DUI9&1L92(*;7-G<W1R("+,Y?/AW^\B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HT,0IM<V=I9"`B
M36EM92!4>7!E(@IM<V=S='(@(DUI;64@5'EP92(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S`X"FUS9VED(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B`B
M"FUS9W-T<B`BS.GJ\?STY?'G(.CE\>SOZO'A\]_A(/3EZ^7U].'?^>T@,C0@
M^?'^[3H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#`*;7-G:60@(DUI
M;B!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(LSIZO'\].7QYR#HY?'L
M[^KQX?/?X2#TY>OE]?3AW_GM(#8@^?'^[3H@(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Q-PIM<V=I9"`B36ER<F]R(@IM
M<V=S='(@(LKAZ/'=\/3G\B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M,0IM<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R("+$Z=SV[_'A(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV.3<*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S0Y"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N
M(@IM<V=S='(@(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`U"FUS9VED("(B"B)-:7-S
M:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO
M=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB"FUS
M9W-T<B`B(@HBR^7?\.7I(/3O(&-O;F9I9W5R871I;VXN(-#QW?#EZ2#MX2#T
M[R#DY^SI[_7QX][SY?3E(.'M(.C=Z^7TY2#MX2#W\>?SZ2TB"B+L[_#OZ=[S
MY?3E(.'U]-X@].?M(.7VX?'L[^/>+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B36ES<VEN9R!M
M97-S86=E($E$+B(*;7-G<W1R("++Y=_PY>D@].\@240@]._U(.SG[?WLX?3O
M\BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S
M;71P+G!H<#HU-PIM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA
M9V4@36%I;"XB"FUS9W-T<B`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA
M9V4@36%I;"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#,*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS
M9W-T<B`BR^7?\.7I(/3O($E$(/3G\B#S_>WDY?/G\BXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*
M;7-G<W1R("+$Y2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,C(*
M;7-G:60@(DUO8FEL92!-86EL(@IM<V=S='(@(D5M86EL(,KI[>?TWO(@U.?K
MY?;Y[=_A\B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C`*
M;7-G:60@(DUO9&5R871E(@IM<V=S='(@(LS=]/'I[_(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8Y(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S,*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HX.`IM<V=I9"`B36]D:69I960@1&%T92(*;7-G
M<W1R("+'[.7Q[^SG[=_A(/3Q[_#O\._?Y_/G\B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I9"`B
M36]D:69Y(%523"(*;7-G<W1R("+4\>_P[_#OW^?SYR!54DPB"@IM<V=I9"`B
M36]N=&@@5FEE=R(*;7-G<W1R("+%[/;<[>GSYR#,WNWA(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C4X-@IM<V=I9"`B36]N=&@@86YD('EE87(B
M"FUS9W-T<B`BS-[MX?(@ZN'I(-WT[_(B"@IM<V=I9"`B36]N=&AL>2!%=F5N
M=',@3&ES="(*;7-G<W1R("+,Y^WIX=_A(,O?\_3A(,/EX^_M_/3Y[2(*"B,Z
M(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z,S8*;7-G
M:60@(DUO;G1H;'DB"FUS9W-T<B`BS.?MZ>'?X2(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0
M:&%S97,B"FUS9W-T<B`BUMSSY>GR(-/EZ][MY_(B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT,C`*;7-G:60@(DUO=F4@1&]W;B(*
M;7-G<W1R("+*W^WG\^<@ZMST^2(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C0R-`IM<V=I9"`B36]V92!,969T(@IM<V=S='(@(LK?
M[>?SYR#A\>GS].7QW"(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C0R.`IM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R("+*W^WG\^<@
MY.7NZ=PB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT
M,38*;7-G:60@(DUO=F4@57`B"FUS9W-T<B`BRM_MY_/G(/#<[?DB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#DW"FUS9VED
M(")-;W9E(&1O=VXB"FUS9W-T<B`BRM_MY_/G(.K<]/DB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#DV"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.3<*;7-G:60@(DUO=F4@
M=7`B"FUS9W-T<B`BRM_MY_/G(/#<[?DB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,38W"FUS9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES
M=',B"FUS9W-T<B`BT._KZ^'PZ]WR(.O?\_3E\B#E\.GK[^/>\B`HZN'TX?'Q
MW.KTY?(I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(R-0IM<V=I
M9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@(M#OZ^OA\.O>(.7PZ>OO
MX]XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,T(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS-#$*;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T
M<B`BSR#+[^/A\>GA\^S\\B#L[_4B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD
M97@N<&AP.C4Q"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`BSR#I\_3\]._P
M_/(@[._U("AP;W)T86PI(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP
M.C$R-`IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R("+'(.7L]MSM
MZ?/G(/3O]2#I\_3\]._P[_T@[._U("AP;W)T86PI(@H*;7-G:60@(DUY(%-U
M;6UA<GDB"FUS9W-T<B`BQR#0Y?'?Z^?XYR#L[_4Z(@H*;7-G:60@(DUY=&EL
M:6YI($%I<G!O<G0B"FUS9W-T<B`BP>7Q[^OI[-WMX?(@S/7TY^O>[>?R(@H*
M(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V%G<F5E;65N=%]B;W1T;VTN:6YC
M.C<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R("+/U\DL(,3%
M(//U[/;Y[?XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HS
M.3<@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P-0HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HT,0HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4X,PIM
M<V=I9"`B3F%M92(*;7-G<W1R("*\[>_LX2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-S`V"FUS9VED(").965D<R!!
M8W1I;VXB"FUS9W-T<B`BP?#AZ?3EW_3AZ2#E[=WQX^7IX2(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR-#(*;7-G:60@(DYE='=O<FLB"FUS9W-T
M<B`BQ-_J]/7O(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#$Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,3D*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,W,`IM<V=I9"`B3F5V97(B"FUS9W-T<B`BT._TW2(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4Q
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(W
M"FUS9VED(").97<@0V%T96=O<GDB"FUS9W-T<B`BS=WA(,KA].?C[_'?X2(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W.0IM<V=I9"`B3F5W($UO;VXB"FUS
M9W-T<B`BS=WA(-/EZ][MYR(*"FUS9VED(").97<@4&%S<W=O<F0B"FUS9W-T
M<B`BS=WO\B#*^>3IZOSR(@H*;7-G:60@(DYE=R!087-S=V]R9"`H86=A:6XI
M(@IM<V=S='(@(LW=[_(@ROGDZ>K\\B`H[N'MW"DB"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@
M*&]P=&EO;F%L*2(*;7-G<W1R("+-W>\@_.WO[.$@U_'>\_3G("CP\>_AZ?'E
M].GJ_"DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDQ"FUS9VED(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(LW=
M[R#PX?'<Z/7Q[R`HZN7M_"DB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT
M,"!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3(*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(V-`IM<V=I9"`B3F5W<R(*;7-G<W1R("+-W>$B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3`V"FUS9VED(").97=S9W)O=7!S
M(@IM<V=S='(@(L_LW.3E\B#CZ>$@[=WA("AN97=S9W)O=7!S*2(*"B,Z('1E
M;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C(Q('1E;7!L871E<R]D871A+V1A
M=&5M87`N:6YC.C0V"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3,W
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C,R"FUS9VED(").97AT(@IM
M<V=S='(@(L7P_.SE[>\B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP
M.C$Q-2!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C$Q-@IM<V=I9"`B3F5X
M="!086=E(@IM<V=S='(@(L7P_.SE[><@T^7KW^3A(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C(W"FUS9VED(").97AT(%!H87-E(@IM<V=S='(@(L7P_.SE
M[><@UMSSYR(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8V
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<P"FUS9VED(").97AT
M(&]P=&EO;G,B"FUS9W-T<B`BQ?#\[.7MY?(@Q?#IZ^_CW?(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#@X"FUS9VED(").
M;R(*;7-G<W1R("+/]^DB"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF
M9BYH=&UL.C$V"FUS9VED(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D
M871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*;7-G<W1R("+$Y>T@]?#<
M\??EZ2#DZ>'HW?/I[.\@8V]N9FEG=7)A=&EO;B#CZ>$@[>$@Y.7?[OD@Y.GA
M]N_QW?(N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+G!H<#HQ,3$*;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K
M:6YG($E33R!I;6%G97,N(@IM<V=S='(@(L3E[2#U\-SQ]^7I(.3IX>C=\^GL
MYR#S]/'A].?CZ>K>(./IX2#DY^SI[_7QX]_A($E33R!I;6%G97,N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S(R
M"FUS9VED(").;R!B871C:"!T96UP;&%T92XB"FUS9W-T<B`BQ.7M(/7PW/'W
MY>D@\/'\]/7P[R#CZ>$@0F%T8V@N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z-S@@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z,C(T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C(T-@IM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@
M<&]S:71I;VXB"FUS9W-T<B`BQ.7M(/7PW/'WY>D@0FQO8VL@\_3G[2#AZ?3O
M_>SE[><@Z-WSYR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z
M-30*;7-G:60@(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(L3E(.3\Z.?JY2#\[>_LX2#CZ>$@
MX?7HY>WTZ>KO\._?Y_/G($U#04PN(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP
M:'`Z-34*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T<B`BQ.7M(/7PW/'W[_7M
M(.'KZ^'CW?(N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ
M-#0*;7-G:60@(DYO(&-H:6QD('!E<FUI<W-I;VYS(&%R92!T;R!B92!A9&1E
M9"!B96QO=R!T:&ES(&QE=F5L+B(*;7-G<W1R("+$Y2#L\._Q[_WM(.WA(/#Q
M[_/TY>CO_>T@Y>[O]?/I[^3O]-[SY>GR(.K<]/D@X?`G(.'U]/P@].\@Y?#?
M\.7D[RXB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C$*;7-G:60@
M(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN
M(@IM<V=S='(@(L3E[2#L\._Q[_WM(.WA(/#Q[_/TY>CO_>T@]?#OZN'TY^/O
M\=_E\B#SY2#A]?3>(/3G[2#E[N_U\^GOY/STY_/G+B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,3<S(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z-#DS"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<U,PIM<V=I9"`B
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S
M+B(*;7-G<W1R("+$Y>T@[_'?\^CGZN'M(/#KY_'O]N_QW^7R(/'UZ.S?\^7Y
M[2#CZ>$@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-S,*
M;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B!&5%`@5D93+B(*;7-G<W1R("+$Y>T@[_'?\^CGZN'M(/#KY_'O]N_Q
MW^7R(/'UZ.S?\^7Y[2#CZ>$@1E10(%9&4RXB"@IM<V=I9"`B3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($Q$05`@4')E9F5R
M96YC97,N(@IM<V=S='(@(L3E[2#=]^_U[2#Q]>CLZ?/TY=\@[^D@\.OG\>_V
M[_'?Y?(@X^GA(/3G[2#U\.?QY?/?X2#*X?3AZ_SC[_4N(@H*;7-G:60@(DYO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@
M0V%T96=O<FEE<RXB"FUS9W-T<B`BQ.7M(-WW[_7M(/'UZ.SI\_3EWR#OZ2#P
MZ^?Q[_;O\=_E\B#CZ>$@].GR(.KA].?C[_'?Y?(@].?R(%-13"XB"@IM<V=I
M9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M(%-13"!0<F5F97)E;F-E<RXB"FUS9W-T<B`BQ.7M(-WW[_7M(/'UZ.SI\_3E
MWR#OZ2#PZ^?Q[_;O\=_E\B#CZ>$@].GR(/#Q[_3I[-[SY>GR(/3G\B!344PN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HU.34*;7-G:60@(DYO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@
M5D93+B(*;7-G<W1R("+$Y>T@W??O]>T@\?7H[.GS].7?(._I(/#KY_'O]N_Q
MW^7R(./IX2!344P@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HW-#D*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(L3E[2#=
M]^_U[2#Q]>CLZ?/TY=\@[^D@\.OG\>_V[_'?Y?(@X^GA(%-13"U&:6QE(%9&
M4RXB"@IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R(%-13"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BQ.7M(-WW
M[_7M(/'UZ.SI\_3EWR#OZ2#PZ^?Q[_;O\=_E\B#CZ>$@].?M(.'UZ.7M].GJ
M[_#OW^?SYR#S].?M(%-13"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,C,*;7-G:60@(DYO(&-R961I="!L969T
M+B(*;7-G<W1R("+$Y>T@W>SEZ>WE(/#?\_3Y\^<N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-3D*;7-G:60@(DYO
M(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G<W1R("+$Y2#D_O/A].4@\/'O
M[_'I\^S\+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y
M,@IM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R("+$Y2#V[_'T_NCG
MZN'M(.'Q]^7?X2(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HW,0IM<V=I
M9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@(L3E(.+QW>CGZN'M(.7IZN_M
MW^3IX2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3`R(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$R,0IM<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R("+$Y>T@
M[_'?\^CGZN4@]._P[^CE\]_A+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C4X"FUS9VED(").;R!M97-S86=E('-U
M<'!L:65D+B(*;7-G<W1R("+$Y2#D_O/A].4@[-[M]>SA+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C8Q"FUS9VED
M(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`BQ.7M(._QW_/HY^KE(/SM
M[^SA+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C8R"FUS9VED(").;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R
M("+$Y>T@[_'?\^CGZN4@X?'IZ.S\\BXB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z.30*;7-G:60@(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R
M("+$Y>T@]?#<\??O]>T@Y/7SW/'E\_3E\B#P\>_BZ]WXY>GR(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3D*;7-G:60@(DYO('!E
M;F1I;F<@<VEG;G5P<RXB"FUS9W-T<B`BQ.7M(.7JZO'E[._][2#EW_/OY._I
M+B(*"FUS9VED(").;R!P<F5F97)E;F-E<R!A<F4@879A:6QA8FQE+B(*;7-G
M<W1R("+/Z2#P\>_TZ>S>\^7I\B#DY>T@Y=_MX>D@Y.GAZ-WSZ>SE\BXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0S"FUS9VED(").;R!R=6QE<R(*;7-G<W1R("+$Y>T@]?#<\??O]>T@ZN'M
M_.WE\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#0*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(L3E[2#U\-SQ
M]^_U[2#PZ^7U\=WR(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$Q,@IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@
M9F]R(&-A8VAE+B(*;7-G<W1R("+$Y>T@]?#<\??EZ2#P\>_S^?'I[?SR(/?^
M\>_R(./IX2#L[=[LYR!C86-H92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8U-@IM<V=I9"`B3F\@=7-E<FYA;64@
M86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(L3E[2#D_.CGZN4@_.WO
M[.$@]_'>\_3G(-XOZN'I(.KYY.GJ_/(N(@H*(SH@9G)A;65W;W)K+U)00R]2
M4$,O>&UL<G!C+G!H<#HQ-#$*;7-G:60@(DYO('9A;&ED(%A-3"!D871A(')E
M='5R;F5D(@IM<V=S='(@(L3E[2#E\.GS]/'<]N?JX>T@W>/C]?'A(%A-3"#D
MY>3O[-WMX2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HX.38*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.CDP-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.3$W"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HY,S0*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R("+$Y>T@]?#<\??O]>T@
M].GLW?(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$P"FUS9VED(").
M;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E
M9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BQ.4@XO'=Z.?JY2#=
MZN3O\^<@\_3O(.'Q]^GJ_"!C;VYF:6=U<F%T:6]N+B#.X>WAY.?LZ>_U\>/>
M\_3E(/3O+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,3@*;7-G:60@
M(DYO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E
M;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(L3E(.+QW>CGZN4@W>KD
M[_/G(//T[R#A\??IZOP@\^'R(&-O;F9I9W5R871I;VXN(,[A[>'DY^SI[_7Q
MX][S].4@].\N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HV,#0*;7-G:60@(DYO;B!087)T:6-I<&%N="(*;7-G<W1R
M("+*X>W=[>'R(-/U[.SE]-WW^>TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,3,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HU-C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E
M;G1I='ES96QE8W0N:6YC.C@X"FUS9VED(").;VYE(@IM<V=S='(@(LKA[.S?
MX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T<B`BRN'MW>WA
M("C7\=[SYR#P\>_JX>CO\>GS[-WM[_4I(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@
M2&5M:7-P:&5R92(*;7-G<W1R("+"_/'EZ>\@Q^SI\_;AW_'I[R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C8T"FUS9VED(").;W0@
M069T97(B"FUS9W-T<B`BO/?I(,SE]-PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8V,PIM<V=I9"`B3F]T($)E9F]R92(*;7-G<W1R
M("*\]^D@T/'I[2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,U
M-PIM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@(L3E[2#EW^WAZ2#J
MX?3<Z^_C[_(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(N<&AP.C8W"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C@T"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDU
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2YP:'`Z-#D*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HV,`IM<V=I9"`B3F]T
M(&EM<&QE;65N=&5D+B(*;7-G<W1R("+$Y>T@W??EZ2#OZ^_JZ^?Q^>CEWRXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8X
M"FUS9VED(").;W0@<V5T(@IM<V=S='(@(L3E[2#=]^GE(/3EZ.7?(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C$X-"!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,C`S"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,C$@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C(S.`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C4U
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-S$*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C(X.2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S(U"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HS.#@@9G)A;65W;W)K+U9&4R]61E,N<&AP.C0W
M,@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-30T(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HU-C(*;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(L3E
M[2#U\._S].?QW^;E].4N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C(T-R!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,34Y
M"FUS9VED(").;W1E<R(*;7-G<W1R("+3Y^SEZ?[SY>GR(@H*;7-G:60@(DYO
M=&5S.B(*;7-G<W1R("+3Y^SEZ?[SY>GR.B(*"FUS9VED(").;W1E<R!3=6UM
M87)Y(@IM<V=S='(@(M/G[.7I_O/EZ?(@+2#0Y?'?Z^?XYR(*"FUS9VED("(B
M"B).;W1E<R!I<R!A;B!A<'!L:6-A=&EO;B!W:&EC:"!A;&QO=W,@>6]U('1O
M(&-R96%T92!T:&4@8V]M<'5T97(@97%U:79A;&5N="`B"B)O9B!S=&EC:WD@
M;F]T97,N($YO=&5S(&-A;B!B92!C<F5A=&5D+"!M;V1I9FEE9"P@9&5L971E
M9"P@86YD('!R:6YT960N(%EO=2`B"B)C86X@86QS;R!S96%R8V@@;VX@>6]U
M<B!N;W1E<R!T;R!L;V-A=&4@:6YF;W)M871I;VXN(%-U<'!O<G0@9F]R(&EM
M<&]R=&EN9R`B"B)A;F0@97AP;W)T:6YG(&YO=&5S(&ES(&%L<V\@879A:6QA
M8FQE+B(*;7-G<W1R("(B"B+/Z2#SY^SEZ?[SY>GR(.7?[>'I(.SIX2#E]N'Q
M[._CWB#P[_4@\^'R(.7PZ?3QW?#EZ2#MX2#DY^SI[_7QX][SY?3E(/3O("(*
M(N'M]-_S]._I]^\@]/GM(.K?]/'I[?GM(.SIZO'^[2#WX?'TZ?[M(//T[^T@
M]?#OZ^_CZ?/TWBX@S/#O\>7?].4@[>$@(@HBY.?LZ>_U\>/>\^7TY2P@[>$@
M]/'O\._P[^G>\^7TY2P@[>$@Y.GAX_'<^.7TY2#JX>D@[>$@]/7P_O/E].4N
M(,SP[_'EW_3E("(*(N7PW_/G\B#MX2#XW.[E].4@\_3I\B#SY^SEW_GSY>GR
M(//A\B#CZ>$@[>$@Y>WT[_#?\^7TY2#LZ>$@\.OG\>_V[_'?X2X@(@HBU?#O
M\_3G\=_FY?3AZ2#JX>D@Y>GSX>/YX]X@+2#E[N'C^>/>(/3Y[2#SY^SEZ?[S
MY?GM+B(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I
M9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(M3?\._T
MX2#CZ>$@Y>SVW.WI\^<L(.7PZ?/T\>_VWBXB"@HC.B!T96UP;&%T97,O;6%I
M;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC.C$P"FUS9VED(").;W1I8V4B"FUS
M9W-T<B`BP>WAZN_I[?[SY>GR(@H*(RP@8RUF;W)M870*;7-G:60@(DYO=&EF
M:6-A=&EO;B!L:7-T96YE<B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(M3O(/#Q
M_./QX>SLX2#P[_4@Y.GA]^7I\=_FY?3AZ2#TZ?(@Y>GD[_#OZ=[SY>GR("5S
M(.3E[2#B\=WHY^KE+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HS.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C<U"FUS9VED(").;W9E;6)E<B(*;7-G<W1R("+-[]WLXO'I
M[_(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#0P"FUS9VED(").
M=6UB97(B"FUS9W-T<B`BP?'IZ.S\\B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T,C$*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S
M='(@(L'QZ>CL_/(@]^'QX>KTWO'Y[2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$S-C4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q.0HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0Q('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB97(@;V8@8V]L
M=6UN<R(*;7-G<W1R("+!\>GH[/SR(//TY^O^[2(*"FUS9VED(").=6UB97(@
M;V8@8V]L=6UN<R!I;B!T:&4@<W5M;6%R>2!V:65W.B(*;7-G<W1R("+!\>GH
M[/SR(//TY^O^[2#S].?M(.7L]MSMZ?/G(/3G\B#PY?'?Z^?XY_(Z(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V,R!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-#$W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,SD@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G
M:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(L'QZ>CL_/(@X_'A[.S^[2(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C8Y"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG
M(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("+$Y>T@[_'?\^CGZN4@
MX?'IZ.S\\B#CZ>$@Y>WG[-WQ^?/G(/3Y[2#KZ?/T_NT@Y.GA[>_LWO(N(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Q-`IM
M<V=I9"`B3V)J96-T(@IM<V=S='(@(L'M].GJY=_LY>WO(@H*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3<*;7-G:60@(D]B:F5C="!#<F5A=&]R
M(@IM<V=S='(@(L3G[.GO]?'C_/(@P>WTZ>KEZ>S=[>_U(@H*(SH@861M:6XO
M<&5R;7,O961I="YP:'`Z,3,W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,C(S"FUS9VED(")/8FIE8W0@8W)E871O<B!P97)M:7-S:6]N<R(*;7-G
M<W1R("+%[N_U\^GOY._TWO/EZ?(@Q.?LZ>_U\>/O_2#![?3IZN7I[-WM[_4B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DX"FUS9VED(")/8W1A
M;"(*;7-G<W1R("+/ZO3AY.GJ_/(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,S@S"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R("+/
MZO3^XO'I[_(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3(*;7-G:60@
M(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@(M;?Z_3Q[R#P\>_SXN_K_NTB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`T"FUS9VED(")/9F9I8V4B
M"FUS9W-T<B`BP_'A]N7?[R(*"FUS9VED(")/;&0@4&%S<W=O<F0B"FUS9W-T
M<B`BT.'KZ?SR(,KYY.GJ_/(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HW-@IM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P
M<&]R="!S:&%R960@9F]L9&5R<RXB"FUS9W-T<B`BS/SM[R!)34%0+5-E<G9E
M<G,@]?#O\_3G\=_F[_7M(.KO]>W\]_'G\_3O]?(@]N'JW>OK[_7R+B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I
M=F4@9F]R='5N97,B"FUS9W-T<B`BS/SM[R#D]?/<\>7S].7R(/#Q[^+KW?CE
MZ?(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#,T(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y-30*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D
M9')E<W,@86QL;W=E9"XB"FUS9W-T<B`BS/SM[R#LZ>$@16UA:6P@Y.GE_>CU
M[?/G(.7PZ?3QW?#E].'I+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H
M<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN
M:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R
M;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@HBS/SM[R#O(.GDZ>_J
M]-[TY_(@WB#O(.3IX??EZ?'I\_3>\B#S]?/TWNSA]._R(.SP[_'EWR#MX2#A
MZ^O<[N7I(/3G[2`B"B+IY.GOZO3G\]_A(-X@].GR(.7N[_7SZ>_D[_3>\^7I
M\B#T[_4@Z>3I[^KTWO3G(./IX2#J[^GMWB#W\=[SYRXB"@HC.B!L:6(O0FQO
M8VLO:69R86UE+G!H<#HS-0IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B
M"FUS9W-T<B`BP>WOZ>/LX2#SY2#MW>\@\.'QW.CU\>\B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(U-PIM<V=I9"`B3W!E;E-33"!E
M<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)
M344@<&%R="XB"FUS9W-T<B`B(@HB3W!E;E-33"W+W.CO\CH@Q.7M(.SP[_'^
M(.WA(.+CW.OY(.3EY._LW>WA(.'P_"!3+TU)344@]?#OX^7C\>'L[-WM[R#L
MW?'O\BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-30*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE
M=R!W:6YD;W<B"FUS9W-T<B`BP>WOZ>/LX2#A]?3>\B#TY_(@\_WMY.7SY_(@
M\^4@[=WO(/#A\=SH]?'O(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S
M"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S='(@(LOEZ?3O]?'CZ>K\
M(-/]\_3G[.$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C8P,`IM<V=I9"`B3W!T:6]N86P@4&%R=&EC:7!A;G0B"FUS
M9W-T<B`BT/'OY?'AZ?3IZOSR(-/U[.SE]-WW^>TB"@HC.B!S97)V:6-E<R]P
M;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS(@IM<V=S='(@
M(L7PZ>OOX]WR(@H*;7-G:60@(D]P=&EO;G,@9F]R(@IM<V=S='(@(L7PZ>OO
MX]WR(./IX2(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HR.2!T96UP;&%T97,O
M<')E9G,O87!P+FEN8SHT"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R
M("+%\.GK[^/=\B#CZ>$@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T
M<B`BU.'NZ>WO[.?LW>WG(,O?\_3A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.3$*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R
M("+/\>/A[>GS[/SR(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.3(*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`B
MU.S>[.$@S_'CX>WI\^SO_2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ,C<*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`BS_'CW.WY\^<B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P
M;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`BP?7HY>WTZ>K\(/#Q_/3U\.\@
MY?;A\>SOX][R(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*;7-G:60@
M(D]R:6=I;F%L('1E;7!L871E<R!I;B`E<SHB"FUS9W-T<B`BP?7HY>WTZ>K<
M(/#Q_/3U\.$@\V4@)7,Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$R,"!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R
M(@IM<V=S='(@(L'KZ^\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3$S(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C$*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$R.0IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB
M"FUS9W-T<B`BP>OKY?(@T.OG\>_V[_'?Y?(B"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C,W"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G
M<W1R("+%[N_U\^GOY._TWO/EZ?(@R>3I[^KTWO3G(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]P86TN<&AP.C@S"FUS9VED(")004T@875T:&5N=&EC871I
M;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`BQR#!]>CE[?3IZN_P[]_G
M\^<@4$%-(.3E[2#EW^WAZ2#DZ>'HW?/I[.<N(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3(W.0IM<V=I9"`B4$=0($1I9VET86P@4VEG
M;F%T=7)E(@IM<V=S='(@(MCG]NGAZMX@U?#OX_'A]MX@4$=0(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,R.`IM<V=I9"`B4$=0($5N
M8W)Y<'1E9"!$871A(@IM<V=S='(@(LKQ]?#T[^/QX?;G[-WMX2#DY>3O[-WM
MX2!01U`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S@W
M"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G<W1R("+$Y^S\\^GO(,KKY>GD
MWR!01U`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S8V
M"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(M7P
M[^/EX_'A[.S=[>$ORO'U\/3OX_'A]N?LW>WA(%!'4"#DY>3O[-WMX2(*"B,Z
M(&%D;6EN+W!H<'-H96QL+G!H<#HV,PIM<V=I9"`B4$A0($-O9&4B"FUS9W-T
M<B`B4$A0(,K^Y.GJX?(B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*;7-G
M:60@(E!(4"!3:&5L;"(*;7-G<W1R(")02%`@RMWK]?;O\B(*"B,Z(&QI8B]A
M<&DN<&AP.C$R-@IM<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R(")02%`@RMWK
M]?;O\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`BP]WLZ?/LX2(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M-S0*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C`S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,#$*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,"!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C,V"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M-C<*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(LKYY.GJ_/(B"@IM<V=I9"`B
M4&%S<W=O<F0@8VAA;F=E9"!F;W(@=7-E<B`E<R!F<F]M(&-L:65N="`E<R(*
M;7-G<W1R("+/(.KYY.GJ_/(@W.OKX>[E(./IX2#T[^T@]_'>\_3G("5S(.'P
M_"#T[R#S].'H[/P@)7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C$S-30*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G<W1R
M("++W.CO\B#J^>3IZOSR(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I
M=7,N<&AP.C$U-PIM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E5
M4R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BP?#AZ?3EW_3AZ2#J^>3IZOSR
M(./IX2#A]>CE[?3IZN_P[]_G\^<@4D%$2553+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(P,S8*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER
M;6%T:6]N(@IM<V=S='(@(LKYY.GJ_/(@[.4@Y?#IXN7BX=_Y\^<B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@(E!A<W-W;W)D
M.B(*;7-G<W1R("+*^>3IZOSR.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C$Q"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(LKYY.GJ_/(Z
M("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,#$W"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M,34*;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G<W1R("+/(.KY
MY.GJ_/(@\/'=\.7I(.WA(/3AZ?'IW.;EZ2XB"@IM<V=I9"`B4&%S="!%=F5N
M=',@3&ES="(*;7-G<W1R("++W_/TX2#0Y?'A\^S=[?GM(./EX^_M_/3Y[2(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T92(*
M;7-G<W1R("+%\.GJ_.OKY_/G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A
M<F0B"FUS9W-T<B`BQ?#IZOSKZ^?SYR#A\/P@].\@8VQI<&)O87)D(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I
M9"`B4&%T:"(*;7-G<W1R("+$Z>'D\>_LWB(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V%P<')O=F4N:6YC.C0@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E<75E=65D+FEN8SHT"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S
M='(@(L7?\^_D[^D@\._U(.7JZO'E[._][3HB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-30*;7-G:60@(E!E;W!L92(*;7-G<W1R("+![>CQ^?#OZ2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W
M"FUS9VED(")097)C96YT(@IM<V=S='(@(M#O\^_S]/PB"@HC.B!T96UP;&%T
M97,O;6%I;G1E;F%N8V4O8V]N9FER;5]B;W1T;VTN:6YC.C8*;7-G:60@(E!E
M<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R("+%ZO3=Z^7S
MYR#+Y>GT[_7QX^G^[2#3]>WTWO'G\^?R(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,Y,`IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I
M;VYS(&]N(&QO9VEN/R(*;7-G<W1R("+%ZO3=Z^7SYR#+Y>GT[_7QX^G^[2#3
M]>WTWO'G\^?R(.KA]-P@].?M(.7?\^_D[SLB"@HC.B!A9&UI;B]P97)M<R]A
M9&1C:&EL9"YP:'`Z-C$@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8T"B,Z
M(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV-PIM<V=I9"`B4&5R;6ES<VEO
M;B(*;7-G<W1R("+%[N_U\^GOY/STY_/G(@H*(SH@861M:6XO<&5R;7,O9&5L
M971E+G!H<#HV.`IM<V=I9"`B4&5R;6ES<VEO;B`G)7,G(&YO="!D96QE=&5D
M+B(*;7-G<W1R("+%[N_U\^GOY/STY_/G(./IX2`G)7,G(.3E(.3IX>/QW/;G
MZN4N(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,C(T(&%D;6EN+W!E<FUS
M+V%D9&-H:6QD+G!H<#HY,PHC.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@
M861M:6XO<&5R;7,O9&5L971E+G!H<#HW-`IM<V=I9"`B4&5R;6ES<VEO;G,@
M061M:6YI<W1R871I;VXB"FUS9W-T<B`BQ.GA]^7?\>GSYR#%[N_U\^GOY._T
MWO/E^>TB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T.2!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U,@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B4&5R;6ES<VEO;G,@9F]R
M(@IM<V=S='(@(L7N[_7SZ>_D[_3>\^7I\B#CZ>$B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-C4*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM
M<V=S='(@(M#Q[_/Y\.GJW?(@\.OG\>_V[_'?Y?(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-34*;7-G:60@(E!E=',B"FUS9W-T<B`BRN'T[^GJW^3I
MX2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M.3D*;7-G:60@(E!H;VYE(@IM<V=S='(@(M3GZ]WV^>WO(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0T-PIM<V=I9"`B4&AO=&]S(@IM<V=S='(@
M(M;Y]._C\>'VW^7R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R("+%Z>KO[>_S
M]._I]^7?X2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B
M4&QA=&ET=61E<R(*;7-G<W1R("+*[^GM[_3U\-_E\B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@
M(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R("+0X?'AZN'K
M_B#JW.WTY2#JZ^GJ(//E(.K<\._I[R#JY>O?(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0X"FUS9VED(")0
M;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L
M96UE;G0Z(@IM<V=S='(@(M#A\>'JX>O^(.7PZ>+EXN'I_O/TY2#\].D@Z-WK
MY?3E(.WA(.3IX>/QW/CE].4@X?7T_"#T[R#S]._I]^7?[SHB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*
M;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK
M('1H:7,@96QE;65N="XB"FUS9W-T<B`BT.'QX>KAZ_X@Y?#IXN7BX>G^\_3E
M(/STZ2#HW>OE].4@[>$@X?#O\_7MY-WSY?3E(.'U]/P@].\@\_3OZ??EW^\N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4U-0IM<V=I9"`B4&QE
M87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T<B`BT.'QX>KA
MZ_X@Y/[S].4@[-[MX2#JX>D@W?3O\BXB"@HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N=&5R
M(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T<B`BT.'QX>KA
MZ_X@Y/[S].4@W>WA(/SM[^SA(./IX2#TYR#MW>$@ZN'TY^/O\=_A.B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R.3@*;7-G:60@(E!L96%S92!E
M;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(M#A\>'JX>O^(.3^
M\_3E(.SIX2#=X^KU\><@25`@Y.GE_>CU[?/G+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(V-3$*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED
M(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N
M(@IM<V=S='(@(B(*(M#A\>'JX>O^(.3^\_3E(.SIX2#=X^KU\><@Y^SE\>_L
MY^W?X2P@Y>O=[O3E(/3O[2#A\>GH[/P@]/GM(.?LY?'^[2#T[_4@[-[MX2XB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#,S"FUS9VED(")0;&5A
M<V4@96YT97(@82!V86QI9"!T:6UE+B(*;7-G<W1R("+0X?'AZN'K_B#D_O/T
MY2#=X^KU\><@_O'A+B(*"FUS9VED(")0;&5A<V4@<')O=FED92!A(&YE=R!P
M87-S=V]R9"(*;7-G<W1R("+0X?'AZN'K_B#D_O/TY2#T[R#MW>\@ZOGDZ>K\
M(//A\B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G
M:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB
M"FUS9W-T<B`BT.'QX>KAZ_X@Y/[S].4@[.GA(/#E\=_KY_CG(/3O]2#P\>_B
MZ][LX?3O\BXB"@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!P87-S=V]R
M9"(*;7-G<W1R("+0X?'AZN'K_B#D_O/TY2#T[^T@ZOGDZ>K\(//A\B(*"FUS
M9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(@IM<V=S='(@(M#A
M\>'JX>O^(.3^\_3E(/3O(+SM[^SA(-?QWO/TYR(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z,3@@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR
M,@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S
M<W=O<F0B"FUS9W-T<B`BT.'QX>KAZ_X@Y/[S].4@].\@_.WO[.$@ZN'I(/3O
M[2#J^>3IZOP@\^'R(@H*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E
M<FYA;64@=VET:"!`9&]M86EN(@IM<V=S='(@(M/U[/#KY_'^\_3E(/3O(/SM
M[^SA(/?QWO/TYR#LY2#T[^T@]._LW>$@*$!E<FUI<RYY9'0I(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+V%G<F5E;65N=%]T;W`N:6YC.C$R"FUS9VED
M("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N("!9;W4@3553
M5"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB
M"FUS9W-T<B`B(@HBT.'QX>KAZ_X@Y.GAXMSS].4@].\@X>K\Z^_UZ.\@ZN7?
M[.7O[2X@T/'=\.7I(.WA(//U[/;Y[>7?].4@[.4@]._U\B#\\>_U\B`B"B+C
MZ>$@[>$@]_'G\^GL[_#OZ=[SY?3E(.'U]/P@].\@\_WS].?LX2XB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4T,`IM
M<V=I9"`B(@HB4&QE87-E(')E=FEE=R!T:&4@9F]L;&]W:6YG(&EN9F]R;6%T
M:6]N+"!A;F0@=&AE;B!S96QE8W0@86X@86-T:6]N(&9R;VT@=&AE("(*(FUE
M;G4@8F5L;W<N(@IM<V=S='(@(B(*(M#A\>'JX>O^(.3EW_3E(/3I\B#AZOSK
M[_7HY?(@\.OG\>_V[_'?Y?(@ZN'I(.7PZ>O=[O3E(.SIX2#E[=WQX^7IX2#A
M\/P@].\@(@HB\.'QX>K<]/D@[.7M[_TN(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT,S4*;7-G:60@(E!L96%S92!S
M96QE8W0@86X@86-T:6]N(&9R;VT@=&AE(&UE;G4@8F5L;W<N(@IM<V=S='(@
M(M#A\>'JX>O^(.7PZ>O=[O3E(.SIX2#E[=WQX^7IX2#A\/P@].\@\.'QX>K<
M]/D@[.7M[_TN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y
M36%N86=E<BYP:'`Z-S(*;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@8V%T
M96=O<GD@;F%M93HB"FUS9W-T<B`BT.'QX>KAZ_X@Y/[S].4@].\@_.WO[.$@
M].?R(.W=X?(@ZN'TY^/O\=_A\CHB"@IM<V=I9"`B4&QE87-E('9E<FEF>2!Y
M;W5R(&YE=R!P87-S=V]R9"(*;7-G<W1R("+0X?'AZN'K_B#E\.GBY>+AZ?[S
M].4@].\@[=WO(.KYY.GJ_"#SX?(B"@IM<V=I9"`B4')E8V5D92!Y;W5R('-I
M9VYA='5R92!W:71H(&1A<VAE<R`H)RTM("<I/R(*;7-G<W1R("+-X2#P\>_T
MW//S[^WTX>D@Y/WO(/#A_>OE\B#P\=_M(/3G[2#U\._C\>'VWB#SX?(@*"<M
M+2<I.R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I
M;6%G92(*;7-G<W1R("+(W?/G(.'U]-[R(/3G\B#EZ>K\[>'R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@
M(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`BU._P[^CE]/[M
M].'R(.'U]/P@]._M(/#?[>'JX2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.CDT"FUS9VED(")0;W-T('1O('1H:7,@9F]L9&5R
M("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`BP?#O\_3OZ]X@\^4@
MX?7T_"#T[R#VW.KEZ^\@*.3E[2#U\._S].?QW^;E].'I(.'P_"#T[R!)34%0
M*2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C8T(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C8Y"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO
M=7(H<RDZ("(*;7-G<W1R("+*X?3AZO'>[.WI\^<@X^GA(/3I\B#TY>OE]?3A
MW^7R("5S(/[QX2CE\BDZ("(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]L
M9&%P+G!H<#HY.0IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]L9&%P.B#$Y2#B
M\=WHY^KE(.<@X?#AZ?3O_>SE[><@Y?#=ZO3A\^<@3$1!4"XB"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O<V5S<VEO;BYP:'`Z,S8*;7-G:60@(E!R969S
M7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B4')E9G-?<V5S<VEO;CH@Q.4@XO'=Z.?JY2#G(.'PX>GT
M[_WLY>WG(.7PW>KTX?/G(//U[>7D\=_A\BXB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,CDX"FUS9VED(")0<F5S96YT871I;VYS(@IM<V=S='(@
M(M#A\>_U\^G<\^7I\B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(S"FUS
M9VED(")0<F5S<W5R92(*;7-G<W1R("+0W^7SYR(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C4W"FUS9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ("(*
M;7-G<W1R("+0W^7SYR#S].\@Y?#?\.7D[R#TY_(@Z-SKX?/SX?(Z("(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ.#0*;7-G:60@(E!R97-S
M=7)E.B`B"FUS9W-T<B`BT-_E\^<Z("(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ.#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(S"FUS9VED(")0<F5V
M:65W(@IM<V=S='(@(M#Q[^7PZ?/J_/#I\^<B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*;7-G:60@
M(E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("+0
M\>_E\.GSZOSPZ?/G(/3G\B#EZ>K\[>_A\B#SY2#MW>\@\.'QW.CU\>\B"@HC
M.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C<Q(&9R86UE=V]R:R]522]5
M22]086=E<BYP:'`Z-S(*;7-G:60@(E!R979I;W5S(%!A9V4B"FUS9W-T<B`B
MT/'OY^/O_>SE[><@T^7KW^3A(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HS-38@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C`*
M;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`BT/'OY^/O_>SE[>7R
M(,7PZ>OOX]WR(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`BQ>KT
M_?#Y\^<@Y>/C\=SV[_4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,#D*;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(M#Q[_/Y\.GJ
M_"#*Z^7IY-\B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z
M,3<U"FUS9VED(")0<F]B;&5M(@IM<V=S='(@(M#Q_.+KY^SA(@H*(SH@<V5R
M=FEC97,O<')O8FQE;2YP:'`Z,3$R"FUS9VED(")0<F]B;&5M($1E<V-R:7!T
M:6]N(@IM<V=S='(@(M#E\>GC\>'VWB#0\>_BZ][LX?3O\B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR,38*;7-G:60@(E!R;VIE8W1S(@IM<V=S
M='(@(KCQX^\@*'!R;VIE8W0I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C`Y-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3<Q"FUS9VED(")0
M<F]M<'0@=&5X="(*;7-G<W1R("+*Y=_LY>WO(/#Q[_3Q[_#>\B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0P.0IM<V=I9"`B4'5B;&EC
M($ME>2(*;7-G<W1R("+$Y^S\\^GO(,KKY>GDWR(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C8Y"FUS9VED(")0=6)L:6,@2V5Y($%L
M9V]R:71H;2(*;7-G<W1R("+!Z^/\\>GH[._R(,3G[/SSZ>_U(,KKY>GDZ>_]
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C(S"FUS9VED
M(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S
M<V9U;&QY+B(*;7-G<W1R("+4[R#FY?WC[_(@Q.?L_//I[_4OT/'O\_GPZ>KO
M_2#JZ^7IY.GO_2#DY2#DY^SI[_7QX][HY^KE(.7PZ?3U]_[R+B(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HW,`IM<V=I9"`B475E<GDB"FUS9W-T<B`BQ?'^
M].?SYR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@W
M"FUS9VED(")24T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G<W1R("+$Y^S\
M\^GO(,KKY>GDWR!24T$@*"5D($)I="DB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,C0W"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`B
MQ?#IZ^_CWR#E[?SR(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G
M:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@(M3U]^'?X2#0\?SBZ^7XYR(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-S$@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-@IM<V=I9"`B4F%T
M:6\B"FUS9W-T<B`BR_SC[_(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C(Y-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C0P"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-S0@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHY-PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R,"!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T,PHC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$X-@IM<V=I9"`B4F5A9"(*;7-G<W1R("+![=SC[?GSYR(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS
M9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@(L'MW./M^?/G(.SG[?WLX?3O
M\B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G
M:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B
M92!U;F1O;F4N(@IM<V=S='(@(L7?\_3E(.+=XN'I[_(@X^GA(/3G(.3IX>/Q
MX?;>("5S.R#!]?3\(.3E[2#L\._QY=\@[>$@Y?#A[=WKZ.7I+B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@IM<V=I9"`B4F5A;&QY
M(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N
M(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*(L7?\_3E(//?X^_U\>_R
M(./IX2#TYR#DZ>'C\>'VWB#T^>T@Y.7D[^S=[?GM(/3O]2#W\=[S].<@)7,[
M(,'U]/P@Y.7M(.SP[_'EWR`B"B+MX2#E\.'MW>OHY>DN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B4F5D
M;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`BQ?#A[>7J]-WKY?/G(/3G
M\B#TY>OE]?3AW^'R(.7QX^'SW^'R(//A\B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-S4*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE
M;G1S.B(*;7-G<W1R("+![>'MW?GSYR#T^>T@Y/7MX>SIZO[M(//T[^GWY=_Y
M[2#T[_4@S.7M[_TZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,R-0IM
M<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`BP>WA[=WY\^<@
M].?R(.7L]MSMZ?/G\B#T[_4@4&]R=&%L.B(*"FUS9VED(")2969R97-H(%-U
M;6UA<GD@5FEE=SHB"FUS9W-T<B`BP>WA[=WY\^<@].?R(-#Q[^+OZ][R(-#E
M\=_KY_CG\CHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.#@@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(P-`HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C(V"FUS9VED(")296=E>"(*;7-G<W1R(")296=E>"(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R,S,*;7-G:60@(E)E;&%T:6]N
M<VAI<"!"<F]W<V5R(@IM<V=S='(@(L7L]MSMZ?/G(-/WW?/E^>TB"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,R-`IM<V=I9"`B4F5M87)K<R(*;7-G<W1R
M("+3]_SKZ>$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C0U-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C0W-@IM<V=I9"`B4F5M96UB97(@=&AE(&9R964O8G5S
M>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`BP?#O[.WG[/SMY?7SYR#PZ^?Q[_;O
M\>G^[2#DZ>'HY?/I[/STY_3A\BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$T"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R("+!\._LX>KQ
M]?/LW>WOZ2#%[O7PY_'E].?TW?(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA
M;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R("+!\._LX>KQ]?/LW>WG(.3IY?WH
M]>WSYR`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,2!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHT,`HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F5Q=65U960N:6YC.C$U"FUS9VED(")296UO=F4B"FUS9W-T<B`B
MP?;AW_'E\^<B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$*
M;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R("+!]N'?\>7SYR#,\.O\ZB(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,S(*
M;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`BP?;AW_'E\^<@T_3>Z^?R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT
M,`IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`BP?;AW_'E\^<@
M[._Q]N_P[]_G\^?R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HV-3@*;7-G:60@(E)E;6]V92!F<F]M(&UY(&-A;&5N
M9&%R(@IM<V=S='(@(L'VX=_QY?/G(.'P_"#T[R#G[.7Q[^O\X^G\(.SO]2(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3,V"FUS9VED(")296UO
M=F4@<&%I<B(*;7-G<W1R("+!]N'?\>7SYR#FY?WC[_7R(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$Y-@IM<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP
M="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@
M(B(*(L'VX=_QY?/G(.'P[^CGZN7U[-WM[_4@<V-R:7!T(.'P_"#T[^T@\/'O
M\_GQZ>W\(.KA]-SK[^/O(/3O]2#E[O7PY_'E].?TWBXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G
M:60@(E)E;6]V92!T:&4B"FUS9W-T<B`BP?;AW_'E\^<@]._U(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y
M"FUS9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM
M<V=S='(@(L'VX=_QY?/G(.'U]._](/3O]2#J_.SB[_4@X?#\(/3O(-WCX_'A
M]N\B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$V"FUS
M9VED(")296UO=F4@=7-E<B(*;7-G<W1R("+$Z>'C\>'VWB#W\=[S].<B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C<*;7-G:60@(E)E
M;6]V92!U<V5R.B`E<R(*;7-G<W1R("+$Z>'C\>'VWB#7\=[S].<Z("5S(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ
M.3<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HR.#`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HS-#D*;7-G:60@(E)E<&QY(%-E;G0N(@IM<V=S='(@(M/TW.OHY^KE
M(,'PW.WTY_/G+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z-#4Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-#8X"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-#<X"FUS9VED(")297!L>2!W:71H($YO="!3
M=7!P;W)T960@365S<V%G92(*;7-G<W1R("+!\-SM].?SYR#LY2#,QR#U\._S
M].?QZ>;\[.7M[R#LWNWU[.$N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HT-C8*;7-G:60@(E)E<&QY('=I=&@@9G)E
M92]B=7-Y(&9O<B!N97AT(#(@;6]N=&AS+B(*;7-G<W1R("+!\-SM].?SYR#L
MY2#PZ^?Q[_;O\=_E\B#DZ>'HY?/I[/STY_3A\B#CZ>$@]._U\B#E\/SLY>WO
M]?(@Y/WO(.S>[>7R+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-#8U"FUS9VED(")297!L>2!W:71H(')E<75E<W1E
M9"!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(L'PW.WTY_/G(.SE
M(/3I\B#FY_3O_>SE[>7R(/#KY_'O]N_QW^7R(.3IX>CE\^GL_/3G].'R+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M,3@Y"FUS9VED(")297!L>3H@)7,B"FUS9W-T<B`BP?#<[?3G\^<Z("5S(@H*
M(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ,SD*;7-G:60@(E)E
M<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D
M93H@(@IM<V=S='(@(M3O(.'?].?LX2#DY2#L\._QY=\@[>$@X?#A[?3GZ.7?
M+B#%\.GS]/'E]OSLY>WO\B#J^>3IZOSR(.O<Z._U\CH@(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.#`@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HU,#,*;7-G:60@(E)E<75I<F5D("<E<R<@;F]T('-P96-I9FEE9"!I
M;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+4[R#A\.'I]._][.7M[R`G
M)7,G(.3E[2#JX>CO\=_SZ.?JY2#S].\@)7,@8V]N9FEG=7)A=&EO;BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8P,2!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C<W.0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z-S4U"FUS9VED(")297%U:7)E9"`G)7,G(&YO="!S<&5C:69I960@
M:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(M3O(.'PX>GT[_WLY>WO
M("<E<R<@Y.7M(.KAZ._QW_/HY^KE(//T[R!61E,@8V]N9FEG=7)A=&EO;BXB
M"@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW-C$*;7-G:60@(E)E<75I
M<F5D("<E<R<@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R("+4[R#A\.'I]._][.7M[R`G)7,G(.3E[2#JX>CO\=_SZ.?JY2#S].\@
M8V]N9FEG=7)A=&EO;BXB"@IM<V=I9"`B4F5Q=6ER960@)V)A<V5D;B<@;F]T
M('-P96-I9FEE9"!I;B!A=71H96YT:6-A=&EO;B!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R("(B"B+4[R#A\.'I]._][.7M[R`G8F%S961N)R#DY>T@W??EZ2#J
MX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR(.'UZ.7M].GJ[_#OW^?SY_(N(@H*
M;7-G:60@(E)E<75I<F5D("=B87-E9&XG(&YO="!S<&5C:69I960@:6X@<')E
M9F5R96YC97,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HBU.\@X?#AZ?3O
M_>SE[>\@)V)A<V5D;B<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?
M\^7I\B#T^>T@\/'O].GLWO/E^>TN(@H*;7-G:60@(E)E<75I<F5D("=D871A
M8F%S92<@;F]T('-P96-I9FEE9"!I;B!A=71H96YT:6-A=&EO;B!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R("(B"B+4[R#A\.'I]._][.7M[R`G9&%T86)A<V4G
M(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@(@HBX?7HY>WT
MZ>KO\._?Y_/G\BXB"@IM<V=I9"`B4F5Q=6ER960@)V1A=&%B87-E)R!N;W0@
M<W!E8VEF:65D(&EN(&-A=&5G;W)I97,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B(@HBU.\@X?#AZ?3O_>SE[>\@)V1A=&%B87-E)R#DY>T@W??EZ2#JX>CO
M\>GS].7?(//TZ?(@\?7H[-_SY>GR(.KA].?C[_'I_NTN(@H*;7-G:60@(E)E
M<75I<F5D("=D871A8F%S92<@;F]T('-P96-I9FEE9"!I;B!P<F5F97)E;F-E
M<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B+4[R#A\.'I]._][.7M[R`G
M9&%T86)A<V4G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@
M]/GM(/#Q[_3I[-[SY?GM+B(*"FUS9VED(")297%U:7)E9"`G:&]S='-P96,G
M(&YO="!S<&5C:69I960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B(@HBU.\@X?#AZ?3O_>SE[>\@)VAO<W1S<&5C)R#DY>T@
MW??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR("(*(N'UZ.7M].GJ[_#O
MW^?SY_(N(@H*;7-G:60@(E)E<75I<F5D("=H;W-T<W!E8R<@;F]T('-P96-I
M9FEE9"!I;B!C871E9V]R:65S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*
M(M3O(.'PX>GT[_WLY>WO("=H;W-T<W!E8R<@Y.7M(-WWY>D@ZN'H[_'I\_3E
MWR#S].GR(/'UZ.S?\^7I\B#JX?3GX^_QZ?[M+B(*"FUS9VED(")297%U:7)E
M9"`G:&]S='-P96,G(&YO="!S<&5C:69I960@:6X@<')E9F5R96YC97,@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HBU.\@X?#AZ?3O_>SE[>\@)VAO<W1S
M<&5C)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR(/3Y[2#P
M\>_TZ>S>\^7Y[2XB"@IM<V=I9"`B4F5Q=6ER960@)W!A<W-W;W)D)R!N;W0@
M<W!E8VEF:65D(&EN(&%U=&AE;G1I8V%T:6]N(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(B(*(M3O(.'PX>GT[_WLY>WO("=P87-S=V]R9"<@Y.7M(-WWY>D@
MZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B`B"B+A]>CE[?3IZN_P[]_G\^?R
M+B(*"FUS9VED(")297%U:7)E9"`G<&%S<W=O<F0G(&YO="!S<&5C:69I960@
M:6X@8V%T96=O<FEE<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B+4[R#A
M\.'I]._][.7M[R`G<&%S<W=O<F0G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I
M\B#Q]>CLW_/EZ?(@ZN'TY^/O\>G^[2XB"@IM<V=I9"`B4F5Q=6ER960@)W!A
M<W-W;W)D)R!N;W0@<W!E8VEF:65D(&EN('!R969E<F5N8V5S(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(B(*(M3O(.'PX>GT[_WLY>WO("=P87-S=V]R9"<@
MY.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#T^>T@\/'O].GL
MWO/E^>TN(@H*;7-G:60@(E)E<75I<F5D("=P:'!T>7!E)R!N;W0@<W!E8VEF
M:65D(&EN(&%U=&AE;G1I8V%T:6]N(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(B(*(M3O(.'PX>GT[_WLY>WO("=P:'!T>7!E)R#DY>T@W??EZ2#JX>CO\>GS
M].7?(//TZ?(@\?7H[-_SY>GR(.'UZ.7M].GJ[_#OW^?SY_(N(@H*;7-G:60@
M(E)E<75I<F5D("=P:'!T>7!E)R!N;W0@<W!E8VEF:65D(&EN(&-A=&5G;W)I
M97,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HBU.\@X?#AZ?3O_>SE[>\@
M)W!H<'1Y<&4G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@
MZN'TY^/O\>G^[2XB"@IM<V=I9"`B4F5Q=6ER960@)W!H<'1Y<&4G(&YO="!S
M<&5C:69I960@:6X@<')E9F5R96YC97,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B(@HBU.\@X?#AZ?3O_>SE[>\@)W!H<'1Y<&4G(.3E[2#=]^7I(.KAZ._Q
MZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@]/GM(/#Q[_3I[-[SY?GM+B(*"FUS9VED
M(")297%U:7)E9"`G=&%B;&4G(&YO="!S<&5C:69I960@:6X@875T:&5N=&EC
M871I;VX@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HBU.\@X?#AZ?3O_>SE
M[>\@)W1A8FQE)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR
M(.'UZ.7M].GJ[_#OW^?SY_(N(@H*;7-G:60@(E)E<75I<F5D("=T86)L92<@
M;F]T('-P96-I9FEE9"!I;B!C871E9V]R:65S(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(M3O(.'PX>GT[_WLY>WO("=T86)L92<@Y.7M(-WWY>D@ZN'H[_'I
M\_3EWR#S].GR(/'UZ.S?\^7I\B#JX?3GX^_QZ?[M+B(*"FUS9VED(")297%U
M:7)E9"`G=&%B;&4G(&YO="!S<&5C:69I960@:6X@<')E9F5R96YC97,@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HBU.\@X?#AZ?3O_>SE[>\@)W1A8FQE
M)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR(/3Y[2#P\>_T
MZ>S>\^7Y[2XB"@IM<V=I9"`B4F5Q=6ER960@)W5I9"<@;F]T('-P96-I9FEE
M9"!I;B!A=71H96YT:6-A=&EO;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B
M"B+4[R#A\.'I]._][.7M[R`G=6ED)R#DY>T@W??EZ2#JX>CO\>GS].7?(//T
MZ?(@\?7H[-_SY>GR(.'UZ.7M].GJ[_#OW^?SY_(N(@H*;7-G:60@(E)E<75I
M<F5D("=U:60G(&YO="!S<&5C:69I960@:6X@<')E9F5R96YC97,@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B(@HBU.\@X?#AZ?3O_>SE[>\@)W5I9"<@Y.7M
M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#T^>T@\/'O].GLWO/E
M^>TN(@H*;7-G:60@(E)E<75I<F5D("=U<V5R;F%M92<@;F]T('-P96-I9FEE
M9"!I;B!A=71H96YT:6-A=&EO;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B
M"B+4[R#A\.'I]._][.7M[R`G=7-E<FYA;64G(.3E[2#=]^7I(.KAZ._QZ?/T
MY=\@\_3I\B#Q]>CLW_/EZ?(@(@HBX?7HY>WTZ>KO\._?Y_/G\BXB"@IM<V=I
M9"`B4F5Q=6ER960@)W5S97)N86UE)R!N;W0@<W!E8VEF:65D(&EN(&-A=&5G
M;W)I97,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HBU.\@X?#AZ?3O_>SE
M[>\@)W5S97)N86UE)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_S
MY>GR(.KA].?C[_'I_NTN(@H*;7-G:60@(E)E<75I<F5D("=U<V5R;F%M92<@
M;F]T('-P96-I9FEE9"!I;B!P<F5F97)E;F-E<R!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R("(B"B+4[R#A\.'I]._][.7M[R`G=7-E<FYA;64G(.3E[2#=]^7I
M(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@]/GM(/#Q[_3I[-[SY?GM+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,R.`IM<V=I
M9"`B4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`BP?#AZ?3O_>SE[>\@T.7DW^\B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C4Y,@IM<V=I9"`B4F5Q=6ER960@4&%R=&EC:7!A;G0B"FUS9W-T<B`BP?#A
MZ?3O_>SE[>_R(-/U[.SE]-WW^>TB"@HC.B!A9&UI;B]U<V5R+G!H<#HS,2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,SD*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2]296YD97)E<BYP:'`Z,S$U('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHQ,#$*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT
M-`IM<V=I9"`B4F5S970B"FUS9W-T<B`BQ?#A[>'V[_'<(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z-#8*;7-G:60@(E)E<V5T(%!A<W-W;W)D
M(@IM<V=S='(@(L'KZ^'CWB#*^>3IZN_](@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z,C<*;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS
M9W-T<B`BP>OKW.[TY2#T[^T@ROGDZ>K\(//A\B(*"B,Z(&%D;6EN+W!H<'-H
M96QL+G!H<#HV-B!A9&UI;B]C;61S:&5L;"YP:'`Z,C@@861M:6XO<W%L<VAE
M;&PN<&AP.C<S"FUS9VED(")297-U;'1S(@IM<V=S='(@(L'P[_3EZ]WS[.'T
MX2(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#(@=&5M<&QA
M=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B
M"FUS9W-T<B`BQ?#I\_3Q[_;>(//TZ?(@Q?#IZ^_CW?(B"@IM<V=I9"`B4F5T
M=7)N('1O(&UA:6PB"FUS9W-T<B`BQ?#I\_3Q[_;>(//TY^T@X>OKY^OOX_'A
M]M_A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4F5U;FEO;B(*;7-G<W1R("+%
M\.'MW>WY\^<B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T
M:6]N(@IM<V=S='(@(L7PX>WA]N_QW"!#;VYF:6=U<F%T:6]N(@H*;7-G:60@
M(E)H;V1E<R!!:7)P;W)T(@IM<V=S='(@(L'E\>_KZ>S=[>'R(-'\Y._U(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,`IM<V=I9"`B4FEC:"!497AT
M($5D:71O<B!/<'1I;VYS(@IM<V=S='(@(L7PZ>OOX]WR(.7PY>[E\>/A\_3>
M(.7L\.OO]?3I\^S=[>_U(.KEZ>S=[>_U(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4X"FUS9VED(")2:61D;&5S(@IM<V=S='(@(L'I[=_C[.'TX2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW,`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`BQ.7NZ=PB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,3`U"FUS9VED(")2:6=H="!H96%D97(B"FUS
M9W-T<B`BQ.7NZ=P@Y?#IZN7VX>O?Y.$B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,3`Q"FUS9VED(")2:6=H="!V86QU97,B"FUS9W-T<B`BQ.7N
MZ=WR(/3I[-WR(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB
M"FUS9W-T<B`BR>3I_/3G].7R(./QX>SLWO(N+BXB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,W"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3@S"FUS9VED(")2;VQE
M(@IM<V=S='(@(M'\Z^_R(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(P.`IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R("+0
MY?'I\_3Q[_;>(#$X,+`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C`U"FUS9VED(")2;W1A=&4@3&5F="(*;7-G<W1R("+0
MY?'I\_3Q[_;>(,'QZ?/TY?'<(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(Q,0IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S
M='(@(M#E\>GS]/'O]MX@Q.7NZ=PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R
M=&EE<R(*;7-G<W1R("+)Y.G\].?TY?(@P_'A[.S>\B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@
M(E)O=R!P<F]P97)T:65S(@IM<V=S='(@(LGDZ?STY_3E\B##\>'L[-[R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*
M;7-G:60@(E)O=W,Z(@IM<V=S='(@(L/QX>SLW?(Z(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PIM<V=I9"`B
M4G5L97,B"FUS9W-T<B`BRN'M_.WE\B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I
M;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T
M<B`BS^D@ZN'M_.WE\B#HX2#E[/;A[=_F[^WTX>D@[.7TX>[](/SK^>T@]/GM
M(./QX>SL_NT@ZN'I(/3Y[2#S].?K_NTB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W
M:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R("+/Z2#J
MX>W\[>7R(.CA(.7L]N'MW^;O[?3AZ2#LY?3A[OT@]/GM(//TY^O^[2#L_.WO
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S
M(&]N;'DB"FUS9W-T<B`BS^D@ZN'M_.WE\B#HX2#E[/;A[=_F[^WTX>D@[.7T
MX>[](/3Y[2#C\>'L[/[M(.S\[>\B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3(Y"FUS9VED(")2=6XB"FUS9W-T<B`BQ>KTW>OE\^<B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,P,`IM<V=I9"`B4R]-24U%($-R
M>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(M7P[^/QX?;>(,KQ]?#T
M[^/QW/;G\^?R(%,O34E-12(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,S0Q"FUS9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A9V4B
M"FUS9W-T<B`BRO'U\/3OX_'A]N?LW>WO(.S>[?7LX2!3+TU)344B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@V"FUS9VED(")305-,(&%U
M=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(L<@X?7H
MY>WTZ>KO\._?Y_/G(%-!4TP@Y.7M(.7?[>'I(.3IX>C=\^GLYRXB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@Q"FUS9VED(")335,@365S<V%G
M:6YG(@IM<V=S='(@(LSG[?WLX?3A(%--4R(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(E-13"#*W>OU]N_R
M(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES
M=&5N97(O;6]B:6QE+G!H<#HS.`IM<V=I9"`B4U5#0T534R(*;7-G<W1R("+%
MT,G4U=?9TR(*"B,Z(&QI8B]A<&DN<&AP.C$S,`IM<V=I9"`B4U]13"!3:&5L
M;"(*;7-G<W1R(")37U%,(,K=Z_7V[_(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")382(*;7-G<W1R("+3
MX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.3(*;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R("*ZY.GO(/#K
MX=_SZ>\@*%]S96QF*2(*"FUS9VED(")386UO<R!!:7)P;W)T(@IM<V=S='(@
M(L'E\>_KZ>S=[>'R(-/<[._U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$R,`IM<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R(@IM<V=S='(@
M(M#<\>_W[_(@Q._Q]?;\\>_U(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO
M=70N:6YC.CDX"FUS9VED(")3879E(@IM<V=S='(@(L'P[^C>ZN7U\^<B"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(R,@IM<V=I9"`B4V%V92`E
M<R(*;7-G<W1R("+!\._HWNKE]?/G("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]E9&ET+FEN8SHT.0IM<V=I9"`B4V%V92`G)7,G(@IM<V=S='(@
M(L'P[^C>ZN7U\^<@)R5S)R(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC
M.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R("+!\._HWNKE]?/G(,7P
MZ>OOX_[M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V,0IM<V=I9"`B
M(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I
M<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*
M;7-G<W1R("(B"B+!\._HWNKE]?/G(/3O]2!C;VYF:6=U<F%T:6]N(/#O]2#D
MY^SI[_7QX][HY^KE(//A[2!02%`@4V-R:7!T(//T[^T@\/'O\_GQZ>W\("(*
M(NKA]-SK[^/O(/3O]2#E[O7PY_'E].?TWBXB"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HV.0IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`BP?#OZ.?JY?7LW>WO("5S(&-O;F9I9W5R871I;VXN(@H*(SH@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3`*;7-G:60@(E-A=F5D('-E='5P
M('5P9W)A9&4@<V-R:7!T('1O.B`G)7,G+B(*;7-G<W1R("+4[R!S8W)I<'0@
MY>WG[-WQ^?/G\B#T[R!S971U<"#A\._HY^KE_>CGZN4@\_3O.B`G)7,G+B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*
M;7-G<W1R("+%\.GS]-[LYR(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI
M<W0N:6YC.C$U('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$W"FUS
M9VED(")396%R8V@B"FUS9W-T<B`BP>WAYM[TY_/G(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(X,0IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS
M9W-T<B`BS.?WX>W=\B#![>'FWO3G\^?R(@H*;7-G:60@(E-E87)C:"!-86EL
M(@IM<V=S='(@(L'MX>;>].?SYR#,Y^WU[-ST^>TB"@IM<V=I9"`B4V5A<F-H
M(%)E<W5L=',B"FUS9W-T<B`BP?#O].7KW?/LX?3A(,'MX>;>].?SY_(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.34W"FUS9VED(")396QE8W0@
M1FEL97,B"FUS9W-T<B`BQ?#IZ^_CWB#!\??EW_GM(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-@IM<V=I9"`B4V5L96-T
M(&$@9&%T92(*;7-G<W1R("+%\.GKW>[TY2#LZ>$@Y^SE\>_LY^W?X2(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C`T"FUS9VED(")396QE8W0@
M82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`BQ?#IZ]WN].4@[^S<Y.$@X^GA(/#Q
M[_/HWNKG(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT.0IM<V=I
M9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@(L7PZ>O=[O3E(.W=[R#)
MY.GOZO3>].<B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*
M;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R("+%\.GKW>[TY2#E[O7P
MY_'E].?TWB(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,38R"FUS
M9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*;7-G<W1R("+%\.GKW>[TY2#W
M\=[S].<@X^GA(/#Q[_/HWNKG(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C8U-`IM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM
M<V=S='(@(L7PZ>OOX]X@_.OY[2#T^>T@Y^SE\>_LY^WI_NTN(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Q-`IM<V=I9"`B
M4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R("+%\.GK[^/>(.7M_/(@X>WTZ>KE
MZ>S=[>_U(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W"FUS9VED("(B
M"B)396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X
M97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M
M(&9R;VT@=&AE('1E>'1A<F5A+B(*;7-G<W1R("(B"B+%\.GKW>[TY2#T[_7R
M(/?A\>'J]-[QY?(@\._U(.C=Z^7TY2#A\/P@].GR(/#A\>'JW/3Y(.O?\_3E
M\BX@RN'T_/#I[>SP[_'EW_3E("(*(NWA(/3A(.'M].GC\=SXY?3E(.KAZ2#M
MX2#TX2#E\.GJ[^OKWO/E].4@\_3O(.S>[?7LX2#SX?(N(@H*;7-G:60@(E-E
M;&5C="!T:&4@9&%T92!D96QI;6ET97(Z(@IM<V=S='(@(L7PZ>OOX]X@]._U
M(.3IX??Y\>GS]-X@Y^SE\>_LY^W?X?(Z(@H*;7-G:60@(E-E;&5C="!T:&4@
M9&%T92!F;W)M870Z(@IM<V=S='(@(L7PZ>OOX]X@].?R(.SO\?;>\B#P[_4@
MZ.$@W??EZ2#G(.?LY?'O[.?MW^$Z(@H*;7-G:60@(E-E;&5C="!T:&4@:61E
M;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R("+%\.GKW>[TY2#T
MYR#TX?7T_/3G].$@\._U(.C=Z^7TY2#MX2#AZ^O<[N7TY3HB"@HC.B!T96UP
M;&%T97,O9&%T82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H92!T:6UE
M(&1E;&EM:71E<CHB"FUS9W-T<B`BQ?#IZ]WN].4@].\@Y.GA]_GQZ?/TWB#^
M\>'R.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")3
M96QE8W0@=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R("+%\.GKW>[TY2#TYR#L
M[_'VWB#P[_4@Z.$@W??EZ2#G(/[QX3HB"@IM<V=I9"`B4V5L96-T('1W;R!M
M871C:&EN9R!F:65L9',N(@IM<V=S='(@(L7PZ>O=[O3E(.3][R#PY>3?X2#P
M[_4@].'I\>G<YN_U[2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDP
M"FUS9VED(")396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N(@IM<V=S='(@(L7P
MZ>O=[O3E(/3O(/?Q^>SA].GJ_"`G\_?>[.$G+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR,S(*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L
M86YG=6%G93HB"FUS9W-T<B`BQ?#IZ]WN].4@].<@X^O^\_/A(//A\CHB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8U
M,PIM<V=I9"`B4V5N9"!,871E<W0@26YF;W)M871I;VXB"FUS9W-T<B`BP?#O
M\_3OZ]X@]/GM(/#I[R#P\?SS]N'T^>T@\.OG\>_V[_'I_NTB"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B
M;&5M(%)E<&]R="(*;7-G<W1R("+!\._S]._KWB#![>'V[_'<\B#0\>_BZ][L
MX?3O\B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HY-C0*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(L'P[_/T[^O>(%--4R(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$T"FUS9VED(")396YS;W(Z("(*
M;7-G<W1R("+!Z?/HY_3>\>'R.B`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,S@R"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@
M(M/E\/3=[.+QZ>_R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HW,C4*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS9W-T<B`BT^7I\>GA
MZOSR(,'QZ>CL_/(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@(E-E<W-I;VX@240@97AP:7)E9"XB
M"FUS9W-T<B`BU.\@240@].?R(//][>3E\^?R(-WKY^[E+B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(R.34*;7-G:60@(E-E="(*;7-G<W1R("+(
MW?/E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<V"FUS9VED(")3970@
M;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I
M9B!Y;W4@979E<B!F;W)G970@:70N(@IM<V=S='(@(B(*(LC=\_3E(.7PZ>OO
MX]WR(/#O]2#HX2#SX?(@Y?#I]/'=\._U[2#MX2#AZ^O<YN7TY2#T[^T@ZOGD
MZ>K\(//A\BP@X>K\[.<@ZN'I("(*(N'M(/3O[2#=]^7TY2#NY??<\^7I+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*;7-G:60@(E-E="!U<"!R
M96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO
M=7(@<&]R=&%L+B(*;7-G<W1R("+0X?'A[.7T\>_P[]_G\^<@X?#O[.'J\?7S
M[-WM^>T@Y>[U\.?QY?3G]/[M(/#O]2#HW>OE].4@\/'\\^+A\^<N(@H*;7-G
M:60@(E-E="!Y;W5R('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L
M87D@;W!T:6]N<RXB"FUS9W-T<B`B(@HBT?7H[-_S].4@Y.G<]N_QY?(@Y?#I
MZ^_CW?(@Y>SVW.WI\^?R(.KAZ2#T[R#W\?SM[R#A[>'MW?GSY_(@]/GM(//E
MZ]_D^>TN(@H*;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!D:7-P;&%Y(&QA
M;F=U86=E+B(*;7-G<W1R("+%\.GK[^/>(/3G\B#P\>_TZ>SO_>SE[>?R(./K
M_O/SX?(N(@H*;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@
M=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`BRN'H[_'?\_3E
M(/3G[2#P\>_TZ>S^[.7MYR#CZ_[S\^$L(.;^[><@_O'A\B#JX>D@[._Q]MX@
MY^SE\>_LY^W?X?(N(@H*;7-G:60@(B(*(E-E="!Y;W5R('-T87)T=7`@87!P
M;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@
M;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R("(B"B+*X>CO\=_S
M].4@].?M(.7VX?'L[^/>(.7JZM_MY_/G\BP@].$@\/'O].GL_NSE[>$@]_'^
M[.'TX2P@].<@\.7QW^_D[R`B"B+A[>'MW?GSY_(@].?R(//EZ]_DX?(@ZN'I
M(-SKZ^7R(.7PZ>OOX]WR(.7L]MSMZ?/G\BXB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C<T"FUS9VED(")3971U<"(*;7-G<W1R("+1_>CLZ?/G(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S@*;7-G:60@
M(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`BQ=_M
MX>D@Y.GAZ-WSZ>SA(%-C<FEP=',@Y>WG[-WQ^?/G\B#Q]>CLW_/E^>TB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3,U"FUS9VED(")3979E
M<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*
M;7-G<W1R("+0[^OKW?(@]._P[^CE\]_E\B#EW^WAZ2#PZ>CA[=WR(.SE(.'U
M]-X@].<@\.'QW.SE]/'O.B`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#<S"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R("+!X^_QW?(B"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT,PIM<V=I9"`B4VAO<G0@
M4W5M;6%R>2(*;7-G<W1R("+3_>WT[^SG(-#E\=_KY_CG(@H*;7-G:60@(E-H
M;W)T(%-U;6UA<GDZ(@IM<V=S='(@(M/][?3O[.<@T.7QW^OG^.<Z(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S,`IM<V=I9"`B4VAO=6QD(&%C8V5S
M<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@(M#Q
MW?#EZ2#T[R#JZ^7IY-\@\/'\\^+A\^?R(.WA(._QZ?/HY=\@X^GA(/#E\>GS
M\_STY?'E\B#S]>WDW?/EZ?([(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HR.30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS.0HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C<S('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z.38*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3D@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-#(*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ.#4*;7-G:60@(E-H;W<B"FUS9W-T<B`BQ>SVW.WI\^<B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,30Y"FUS9VED("(B"B)3:&]W
M(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@
M;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*
M(L7L]MSMZ?/G(.3IX?;O\?[M(.SE].'N_2#T[_4@X?#OZ.?JY?7LW>WO]2#J
MX>D@]._U(.3G[.GO]?'CY^C=[?3O\B`B"B)C;VYF:6=U<F%T:6]N+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-S0*;7-G:60@(E-H;W<@;&%S="!L
M;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`BQ>SVW.WI\^<@
M].?R(/[QX?(@].7KY?7TX=_A\B#EZ?/\Y._U(/STX>T@[/#AW^WO]>SE(//T
M[R#S_?/TY^SA.R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-3(*
M;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS9W-T<B`B
MQ>SVW.WI\^<@Y?#IZ^_CWO(@X^GA(.'P[^C>ZN7U\^<@]._U(.'UZ.7M].GJ
M[_TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`Q"FUS9VED(")3
M:&]W('!I8VME<B(*;7-G<W1R("+%[/;<[>GSYR#S]>OKW>KTYR(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#D*;7-G:60@(E-H;W<@=&%B;&4@;W!E
M<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`BS>$@Y>SVX>W?YN7TX>D@].\@
M[.7M[_T@[.4@Y?'CX?/?Y?(@\-_MX>KA.R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS,S,*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE
M9G0_(@IM<V=S='(@(L7L]MSMZ?/G(/3O]2`E<R#,Y>WO_2#S].$@X?'I\_3E
M\=P[(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4X"FUS9VED(")3:&]W('1H92!486)L92!#96QL(%!R;W!E
M<G1I97,@9&EA;&]G(@IM<V=S='(@(L7L]MSMZ?/G(/3O]2#DZ>'K_./O]2#)
MY.GO]-[T^>T@RN7KZ?[M(-#?[>'JX2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,PIM<V=I9"`B4VAO=R!T
M:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`BQ>SVW.WI\^<@
M]._U(.3IX>O\X^_U(,GDZ>_TWO3Y[2#0W^WAZN$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@
M(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R
M("+%[/;<[>GSYR#T[_4@Y.GAZ_SC[_4@R>3I[_3>]/GM(,/QX>SL_NT@T-_M
MX>KA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4Q"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S
M(&1I86QO9R(*;7-G<W1R("+%[/;<[>GSYR#T[_4@Y.GAZ_SC[_4@R>3I[_3>
M]/GM(,7IZOSMX?(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S4P
M"FUS9VED(")3:&]W('5P;&]A9"(*;7-G<W1R("+%[/;<[>GSYR#V_/'T^?/G
M\B`H=7!L;V%D*2(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C,Y,0IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(M/U\?'?ZNWY\^<B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HV.#0@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-S0V"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C@P-"!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HX-C8*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z.3`Q(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.CDS.`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY-C8@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3DV"FUS9VED(")3
M:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H
M92!W87D@9FER<W0B"FUS9W-T<B`BT/'^].$@\_7Q\=_J[?GSYR#>(.SE].'J
MW^WG\^<@X^7I]._MZ>K^[2#T[.?LW/3Y[2(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HR-S@*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B
MQ=_S[^3O\BW5\._C\>'VWB(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z.#D*;7-G:60@(E-I9VX@=7`@:68@;F]T(')E9VES=&5R960B"FUS9W-T
M<B`BQR#%W_/OY._R+=7P[^/QX?;>(.3E[2#=]^7I(.KA].'W^?'GZ.7?+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S,V"FUS9VED
M(")3:6=N871U<F4B"FUS9W-T<B`BU?#OX_'A]MXB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<S-0IM<V=I9"`B4VEG;F%T=7)E($%L
M9V]R:71H;2(*;7-G<W1R("+!Z^/\\>GH[._R(-7P[^/QX?;>\B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C@W(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C@Y,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C`V(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(R.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3$X"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,#<*;7-G:60@(E-I>F4B"FUS9W-T
M<B`BS-WCY>CO\B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M
M7V)O='1O;2YI;F,Z.0IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R
M("+!ZOWQ^?/G(-/U[?3>\>?SY_(B"@IM<V=I9"`B4V]M92!O9B!(;W)D92=S
M(&-O;F9I9W5R871I;VX@9FEL97,@87)E(&UI<W-I;F<Z(@IM<V=S='(@(LSE
M\>GJW"#A\/P@].$@X?'WY=_A(.3IX??EW_'I\^?R(/3O]2!(;W)D92#=]^_U
M[2#WX>CEWSHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3$T"FUS
M9VED(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R("+%\.GK[^/>(.KA
M].7]Z/7M\^?R(/3A[NGM_.SG\^?R(@H*;7-G:60@(E-O=61A($%I<G!O<G0B
M"FUS9W-T<B`BP>7Q[^OI[-WMX?(@T^_]Y.'R(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#$*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,3,*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0IM
M<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`BQ.GE_>CU[?/G(-#GX][R
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H
M<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("+-_/3I
M[R#'[.GS]N'?\>GO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J86-E;G0@
M8V5L;',B"FUS9W-T<B`BQ.G<\_3G[.$@[.7TX>[](./EZ?3O[>GJ_NT@ZN7K
MZ?[M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,34*;7-G:60@(E-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R
M(&EN(&-E;&PB"FUS9W-T<B`BQ.G<\_3G[.$@[.7TX>[](/#E\>GE]^_LW>WO
M]2#JX>D@X_'A[.S>\B#JY>OI_NTB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HX,30*;7-G:60@(E-P86-E<B(*;7-G<W1R("+0Z][J]/'O(,3IX?/T
MWNSA]._R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@P"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(L'QX=_Y\^<B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4T"FUS9VED(")3<&%C:6YG(&%N9"!P861D:6YG(@IM<V=S='(@(L'Q
MX=_Y\^<@ZN'I(./=[.GS[.$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z.34*;7-G:60@(E-P86TB"FUS9W-T<B`B4W!A;2(*"B,Z('-E<G9I8V5S
M+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@26YP
M=70B"FUS9W-T<B`BQ>GSX>/YX]X@Q>GDZ>K^[2#7X?'AZO3>\?GM(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R("+$Z>'?\>7SYR#JY>OI[_TB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8V"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`BQ.GAW_'E\^<@
M\_3>Z^?R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S='(@(L3IX=_Q
MY?/G(./QX>SLWO(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*;7-G
M:60@(E-P;W)T<R(*;7-G<W1R("+!Z.O>[.'TX2(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#0S"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-30X"FUS9VED(")3
M=&%R="(*;7-G<W1R("*X[>'Q[N<B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-3@X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W.3<*;7-G:60@
M(E-T87)T('EE87(B"FUS9W-T<B`BN/3O\B"X[>'Q[N?R(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E-T871E(&]R
M(%!R;W9I;F-E(@IM<V=S='(@(M#OZ^GTY=_A(-X@Q?#A\???X2(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3@S"B,Z
M('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3
M=&%T=7,B"FUS9W-T<B`BRN'TW//TX?/G(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C@P,PIM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`B
MS._Q]MX@X?#OZ-[JY?7SY_(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4Y-@IM<V=I9"`B4W1R965T($%D9')E<W,B"FUS9W-T<B`B
MQ.GE_>CU[?/G+<_D_/(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q"FUS9VED(")3=')I:V5T:')O=6=H(@IM<V=S='(@
M(L3IX>/QX>SLZ?/LW>WA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3(R-`IM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`BR]_S].$@Z]WNY?GM
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U-@IM<V=I9"`B4W1R
M:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`BP?;AW_'E\^<@
M]._U(&1O;6%I;B#A\/P@].<@Y.GE_>CU[?/G(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y
M;&4@6T-34UTB"FUS9W-T<B`BT_3]ZR!;0U-372(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@(E-U(@IM<V=S
M='(@(LKU(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"FUS9VED(")3
M=6)D:7)E8W1O<GD@)R5S)R!N;W0@9F]U;F0N(@IM<V=S='(@(L\@]?#O]MSJ
MY>OO\B`G)7,G(.3E(.+QW>CGZN4N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV,S4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HW.`IM<V=I9"`B4W5B:F5C="(*;7-G<W1R("+(W>SA
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C@*;7-G
M:60@(E-U8FIE8W0@4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(LC=[.$@)]#K
MY_'O]N_QW^7R(,3G[/SSZ>_U(,KKY>GDZ>_])R(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,S,B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R
M+G!H<#HS,3(*;7-G:60@(E-U8FUI="(*;7-G<W1R("+!\._S]._KWB(*"B,Z
M('-I9VYU<"YP:'`Z-3`*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O
M(&%D9"`G)7,G('1O('1H92!S>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U
M;G1I;"!Y;W5R("(*(G)E<75E<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S
M='(@(B(*(M3O(.'?].?LX2#CZ>$@\/'O\^C>ZN<@)R5S)R#S].\@\_WS].?L
MX2#A\.7S]-SKYRX@Q.4@[/#O\>7?].4@[>$@[N'MX>SPY=_TY2`B"B+LW??Q
MZ2#MX2#EX^KQZ>CEWR#T[R#AW_3G[-P@\^'R+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP
M="(*;7-G<W1R("+5\._DY=_J].?R(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$Q,PHC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]S=&%T=7,N<&AP.C,P"FUS9VED(")3=6-C97-S(@IM<V=S='(@
M(L7PZ?3U]]_A(@H*(SH@861M:6XO=7-E<BYP:'`Z.#4*;7-G:60@(E-U8V-E
M<W-F=6QL>2!A9&1E9"`G)7,G('1O('1H92!S>7-T96TN(@IM<V=S='(@(L7P
MZ?3U]][R(/#Q[_/HWNKG("<E<R<@\_3O(//]\_3G[.$N(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3(T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A
M(&9O<B!U<V5R("<E<R<@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("+4X2#D
MY>3O[-WMX2#T[_4@]_'>\_3G("<E<R<@Y.GAX_'<]N?JX>T@Y?#I]/7W_O(@
MX?#\(/3O(//]\_3G[.$N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX,2!A9&UI
M;B]P97)M<R]D96QE=&4N<&AP.C8Q"FUS9VED(")3=6-C97-S9G5L;'D@9&5L
M971E9"`G)7,G+B(*;7-G<W1R("+%\.GT]??>\B#DZ>'C\>'VWB`G)7,G+B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E
M;6]V960@)R5S)R!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(L7PZ?3U]][R
M(.3IX>/QX?;>("<E<R<@X?#\(/3O(//]\_3G[.$N(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D
M(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T
M<B`B(@HBS^D@\?7H[-_SY>GR(.7PX>WA]MWQZ.?JX>T@Y?#I]/7W_O(N(,K<
M[?3E(.7PX>WA]OSQ]/GSYR#CZ>$@[>$@Y.7?].4@].GR("(*(N'KZ^'CW?(N
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C4U"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(L7PZ?3U]][R(.7P[^C>ZN7U\^<@
MY?;EY/'IZN_](&-O;F9I9W5R871I;VXN(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HV,@IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K
M=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R("+%\.GT]??>\B#A
M\._HWNKE]?/G(/3O]2#E]N7D\>GJ[_T@X?'WY=_O]2!C;VYF:6=U<F%T:6]N
M("5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`IM<V=I9"`B4W5C8V5S<V9U
M;&QY('5P9&%T960@)R5S)R(*;7-G<W1R("+%\.GT]??>\B#E[>?LW?'Y\^<@
M)R5S)R(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C<R"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B
M"FUS9W-T<B`BQ?#I]/7WWO(@Y>/C\>'VWB`E<R(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-34X"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-38P"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*;7-G
M:60@(E-U;6UA<GDB"FUS9W-T<B`BT_WM[_CG("T@T.7QW^OG^.<B"@HC.B!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z-C8*;7-G:60@(E-U;B!2:7-E(@IM<V=S
M='(@(L'MX?3OZ]XB"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-S$*;7-G
M:60@(E-U;B!3970B"FUS9W-T<B`BQ/WSYR(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-C4*;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`BP>WA
M]._KWB(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`B
MP>WA]._KWB_$_?/G(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$V-`IM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(L'MX?3OZ]XZ("(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C@*;7-G:60@(E-U;G-E
M="(*;7-G<W1R("+$_?/G(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$V-PIM<V=I9"`B4W5N<V5T.B`B"FUS9W-T<B`BQ/WSYSH@(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I
M9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`BU?#E\>3EW^KTY?(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8U"FUS9VED(")3=7!P;W)T(@IM<V=S
M='(@(M7P[_/TWO'I[N<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4Y.`IM<V=I9"`B4W5R;F%M92(*;7-G<W1R("+%\-_HY?3O(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*;7-G:60@(E-Y;F,@
M;&]G(&1E;&5T960B"FUS9W-T<B`BU.\@X?'WY=_O(.KA].'C\>'VWO(@\_7C
M]_'O[>GS[._](.3IX>/QW/;GZN4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,30U"FUS9VED(")3>6YC34PB"FUS9W-T<B`B4WEN8TU,(@H*(SH@9G)A
M;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.CDX"FUS9VED(")3>6YT87@@
M97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@(LO<Z._R(//][?3A[N?R
M(//T[_7R(/SQ[_7R(.'MX>;>].?SY_(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5&%B;&4N<&AP.C$S-0IM<V=I9"`B5&%B;&4B"FUS9W-T<B`BT-_MX>KA\B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`BR>3I_/3G
M].7R(-#?[>'JX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS
M9W-T<B`BR>3I_/3G].7R(-#?[>'JX2(*"FUS9VED(")486YA9W)A($%I<G!O
M<G0B"FUS9W-T<B`BP>7Q[^OI[-WMX?(@U.'MW./QX?(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU"FUS9VED(")487)G
M970Z(@IM<V=S='(@(M/T_/?O\CHB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,38X"FUS9VED(")487-K<R(*;7-G<W1R("+%\>/A\]_E\B(*"FUS
M9VED(")4871O:2!!:7)P;W)T(@IM<V=S='(@(L'E\>_KZ>S=[>'R(-3A]._Z
M[_4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM
M<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R("+!\>GH[/SR(-3GZ^7V
M_NWO]2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@X"FUS9VED(")496UP
M(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("+(Y?'L[^KQX?/?X2#TY^T@].7K
MY?7TX=_A(/[QX3H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,3(*;7-G
M:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@(LCE\>SOZO'A\]_A(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W,@IM<V=I9"`B5&5M<&5R871U
M<F4Z("(*;7-G<W1R("+(Y?'L[^KQX?/?X3H@(@H*(SH@9G)A;65W;W)K+U1E
M;7!L871E+U1E;7!L871E+G!H<#HR,3$*;7-G:60@(E1E;7!L871E("<E<R<@
M;F]T(&9O=6YD+B(*;7-G<W1R("+4[R#P\?ST]?#O("<E<R<@Y.4@XO'=Z.?J
MY2XB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I9"`B5&5M<&QA
M=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`BQ.GA]^7?\>GSYR#0\>_T_?#O
M]2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z-C0Q"FUS9VED(")496YT871I=F5L>2!!8V-E<'0@<F5Q=65S="(*;7-G
M<W1R("+0\>_S^?'I[=X@P?#OY._WWB#AZ?3>[.'T[_(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8X.0IM<V=I9"`B
M5&5N=&%T:79E;'D@06-C97!T960B"FUS9W-T<B`BT/'O\_GQZ>W<(,'P[^3E
MZO3\(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(P,@IM<V=I9"`B
M5&5X="(*;7-G<W1R("+*Y=_LY>WO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,U.0IM<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@(LS\[>\@RN7?[.7M
M[R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S0*;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T<B`BT_3OW_?G\^<@
MZN7I[-WM[_4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<Q"FUS9VED(")497AT=&]P(@IM<V=S='(@(LKO\?7VWB#JY>GL
MW>WO]2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(M3E(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z.30T"FUS9VED(")4:&%N:R!Y;W4@9F]R('5S:6YG('1H
M92!S>7-T96TN(@IM<V=S='(@(L7U]^'QZ?/T[_WLY2#P[_4@]_'G\^GL[_#O
MZ=[SX?3E(/3O(-/]\_3G[-P@[.'R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z-S8Y"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@
M879A:6QA8FQE+B(*;7-G<W1R("+'(.7PW>KTX?/G($944"#DY>T@Y=_MX>D@
MX>K\[.<@Y.GAZ-WSZ>SG+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3(T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG
M:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(M3O(//]\_3G
M[.$@2&]R9&4O2V]L86(@Y.7M(/7P[_/TY_'?YN7I(%PB)7-<(B(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR.0IM<V=I9"`B5&AE($UA:6YT96YA
M;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R
M("+$Z>'WY=_QZ?/G.CH@QR#JZ]SSYR#DY2#V[_'T_NCGZN4@Y?#I]/7W_O(B
M"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED
M(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS
M9W-T<B`BU.\@\.'QW.CU\>\@Y?#IZ^_C_NT@W>KKY>GSY2X@N.[OY._R+B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,38P(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,3<Q"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,3@R(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,3DT"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,C`U(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C,U(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C<T"FUS9VED("(B"B)4:&4@861M
M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R
M;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES
M<VEO;G,N(@IM<V=S='(@(B(*(L\@Y.GA]^7I\>GS]-[R(/#QW?#EZ2#MX2#Q
M]>CLW_/EZ2#=[>$@[/SMZ>SO(/#KX=_SZ>\@Q>[O]?/I[^3O]-[SY?GM+"#C
MZ>$@[>$@(@HB[/#O\>7?].4@[>$@]_'G\^GL[_#OZ=[SY?3E(.7N[_7SZ>_D
M[_3>\^7I\BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*
M;7-G<W1R("+'(.K<]/D@\.OE]?'<(.S\[>\B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0Y"FUS9VED(")4:&4@8V%L
M96YD87(@9&%T82!I<R!I;G9A;&ED(@IM<V=S='(@(M3A(.3EY._LW>WA(.?L
MY?'OZ^_CW^_U(.3E[2#EW^WAZ2#=X^KU\>$B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8V-`IM<V=I9"`B(@HB5&AE
M(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L
M86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G
M<W1R("(B"B+4[R!)1"#TY_(@Y?#A]M[R(.3E[2#JX>CO\=_SZ.?JY2P@WO3A
M[2#JY>W\(-X@Y.4@XO'=Z.?JY2#S].<@XMSSYR#DY>3O[-WM^>TN(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4T"FUS9VED
M(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@
M861D<F5S<R!B;V]K+B(*;7-G<W1R("+'(.7PX?;>(/#Q[_/TW>CGZN4@Y?#I
M]/7W_O(@\_3O(,3IY?7H]>WSZ>_C\=SV[R#SX?(N(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$W,0IM<V=I9"`B(@HB5&AE(&1E=&%C
M:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y
M('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@HBU.\@].S>[.$@4$=0
M(/#O]2#A\._S\-SSZ.?JY2#A\.'I].7?].\@X^GA(/3G[2#E\.'KWNCE]?/G
M(/3O]2#U\._CY>/QX>SLW>WO]2`B"B+LY^W>[.'T[_(N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-C8*;7-G:60@
M(B(*(E1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S
M<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D
M871A8F%S92XB"FUS9W-T<B`B(@HBU.\@240@].?R(.O?\_3A\B#DZ>'M[^S>
M\B#DY>T@[_'?\^CGZN4L(-[TX>T@ZN7M_"#>(.3E(.+QW>CGZN4@\_3G(.+<
M\^<@(@HBY.7D[^S=[?GM+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C8W"FUS9VED(")4:&4@9&ES=')I8G5T:6]N
M(&QI<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@(L<@Z]_S].$@Y.GA
M[>_LWO(@Y.7M(.KAZ._QW_/HY^KE+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="YP:'`Z,3(W"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R
M97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("+/Z2#D
M]>WA]/STY_3E\B#J\?7P]._C\=SVY_/G\B#A\.'I]._][2#A\_;AZ]X@\_WM
MY.7SYR!714(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HW.`IM<V=I9"`B5&AE(&5V96YT(&AA<R!B965N(&%D9&5D
M('1O('EO=7(@8V%L96YD87(N(@IM<V=S='(@(M3O(./EX^_M_/(@\/'O\_3=
MZ.?JY2#S].\@Y^SE\>_K_./I_"#SX?(N(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ.#$@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#0*
M;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN
M9RXB"FUS9W-T<B`BU.\@X?'WY=_O("5S(/#QW?#EZ2#MX2#PY?'IW??EZ2#L
MZ>$@)7,@\?WH[.GSYRXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$W-"!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0Y-`IM<V=I9"`B5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS
M9W-T<B`BU.\@X?'WY=_O("5S(/#QW?#EZ2#MX2#PY?'IW??EZ2#JW/#OZ>7R
M("5S(/'UZ.S?\^7I\BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HQ-C4*;7-G:60@(E1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@
M:71S96QF+B(*;7-G<W1R("+4[R#A\??EW^\@Y.4@[/#O\>7?(.WA(.'M].GC
M\>'VY=\@\_3O[2#EX?7T_"#T[_4N(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T
M82YP:'`Z,C8T"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB
M"FUS9W-T<B`BU.\@X?'WY=_O(.3E[2#PY?'IW??EZ2#DY>3O[-WMX2XB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R"FUS
M9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M
M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R("+4X2#PX?'AZMST^2#E
MW^WAZ2#E\.GJY?;AZ]_DY?(@X^GA(.'U]/P@].\@[-[M]>SA+W)F8S@R,B#L
MWNWU[.$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO
M=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@
M9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T
M;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G
M92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A
M;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7
M:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@
M)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B
M;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E("(*(G!R
M97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E
M96X@961I=&]R+B(*;7-G<W1R("(B"B+'(.KA]-SS].'SYR#PZ][Q[_7R(._H
M_.WG\B#EW^WAZ2#C[?GS]/P@_/3I(.3G[.GO]?'CY=\@\/'\XNOG[.$@[.4@
M]._M("(*(DEN=&5R;F5T($5X<&QO<F5R+"#E[N'I]-_A\B#P\>_BZ^?LW/3Y
M[2`H8G5G<RD@]._U(&)R;W=S97(L(/3A(._P[]_A(.3E[2`B"B+EW^'I(.3U
M[>'T_"#MX2#NY?#E\>'SZ._][2X@S/#O\>7?(.WA(.3EW_3E("?SZN_U\-_D
MZ>$G(//TY^T@[^C\[><L("(*(O#Q[^+KWNSA].$@\_3G(.OEZ?3O]?'CW^$@
M]._U(&)R;W=S97(@WB#JX>D@ZOSKY^S<(/3O]2X@P>T@].\@\_WS].?LW"#S
MX?(@(@HBY=_MX>D@5VEN9&]W(#EX(.7?[>'I(/#OZ_T@\.GHX>W\(.WA(.3E
MW_3E("?#Y>WIZMX@P?#O]/7WW^$@T/'O\_3A\]_A\B<@ZN'I("(*(NWA(/#Q
MW?#EZ2#MX2#E\.'MY>KJZ>W>\^7TY2`H<F5B;V]T*2Y<7&Y<7,'U]-X@Y=_M
MX>D@\/'OY>GD[_#OW^?SYRX@T.'TWO/TY2`B"B+/RB#A[2#HW>OE].4@X>K\
M[.<@[>$@Y._UZ]WXY?3E(//E(.KA]-SS].'SYR#PZ][Q[_7R(._H_.WG\BXB
M"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.#@*;7-G:60@(E1H92!I9&5N=&ET
M>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`BQR#TX?7T_/3G
M].$@7"(E<UPB(.3IX>/QW/;GZN4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M
M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`BQR#A\>GS].7QWB#PZ^7U\=P@[/SM
M[R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-@IM<V=I
M9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B
M92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM<V=S='(@(B(*
M(L<@Z-WSYR#T[_4@\/'OX_'<[.SA]._R($=N=5!'(/#QW?#EZ2#MX2#D[^CE
MWR#CZ>$@].<@0W)Y<'1?<&=P.CH@ZNO<\^<N(@H*;7-G:60@(E1H92!M86EL
M8F]X('1R87-H(&ES(&%L<F5A9'D@96UP='DN(@IM<V=S='(@(L<@X_'A[.SA
M]._H]?'?Y.$@)^K<Y._R)R#EW^WAZ2#>Y.<@W.3EZ>$N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-1$XN<&AP.C(Q-`IM<V=I9"`B(@HB5&AE(&UE<W-A
M9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B
M965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@
M=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G
M<W1R("(B"B+4[R#LWNWU[.$@\._U(//TW.OHY^KE(//TZ?(@)7,@\_3O[2`E
M<R#LY2#HW>SA("5S(.7L]N'MW_/HY^KE+EQN(@HBP?7T_"#DY>T@X?#O].7K
MY=\@Y?#IXN7BX=_Y\^<@_/3I(.3IX>+<\^CGZN4@ZN'I(-WCZ>WE(.KA].'M
M[^?T_"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8P"FUS9VED
M(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E
M('!A9V4B"FUS9W-T<B`BU.\@_.WO[.$@\._U(.CA(/?QY_/I[._P[^GEW_3A
MZ2#\].'M(//U[>3=Y?/TY2#S].<@\^7KW^3A(//][>CE\^?R+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(U.0IM<V=I9"`B5&AE
M(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y
M<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`BQR#BZ>+KZ>_HWNKG($]P96Y3
M4TP@X?#AZ?3EW_3AZ2#CZ>$@2&]R9&5?0W)Y<'1?<VUI;64Z.B#JZ]SSYRXB
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,N<&AP.C(Y,0IM<V=I9"`B(@HB
M5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S879E9"!B96-A
M=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M87AI;75M(&%L;&]W86)L
M92!S:7IE(@IM<V=S='(@(B(*(L<@\/'O]-_LY_/G(%PB)7-<(B#DY>T@[/#\
M\>7SY2#MX2#A\._HY^KE]>CEWR#CZ>'TWR#TX2#DY>3O[-WMX2#TY_(@(@HB
M]?#E\>+AW^WO]>T@].\@[-WCZ?/T[R#E\.GT\>7P]/P@[-WCY>CO\B(*"B,@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S4L(&,M
M9F]R;6%T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V1E8BYP:'`Z
M,S4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O96YS8W)I<'0N<&AP
M.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS<&]W97)P;VEN
M="YP:'`Z,S4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D
M+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R<&TN<&AP
M.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z
M-#`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<W)C:&EG:&QI=&4N
M<&AP.C,Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS97AC96PN
M<&AP.C,U"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI
M<R!M97-S86=E('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T
M96TN(@IM<V=S='(@(B(*(M3O(/#Q_./QX>SLX2#P[_4@]_'G\^GL[_#OZ>7?
M].4@X^GA(/3G[2#E[/;<[>GSYR#A]?3O_2#T[_4@Y=_D[_7R(.SG[?7LW/3Y
M[2`B"B(H)7,I(.3E[2#B\=WHY^KE(//T[R#S_?/TY^SA+B(*"FUS9VED("(B
M"B)4:&4@<F5G:7-T<GD@:7,@:&]W($AO<F1E(&%P<&QI8V%T:6]N<R!F:6YD
M(&]U="!H;W<@=&\@=&%L:R!T;R!E86-H(&]T:&5R+B`B"B)9;W4@<VAO=6QD
M(&QI<W0@86YY(&EN<W1A;&QE9"!(;W)D92!A<'!L:6-A=&EO;G,@=&AA="!Y
M;W4@:&%V92!H97)E+B(*;7-G<W1R("(B"B+'(')E9VES=')Y(.7?[>'I(.\@
M]/'\\._R(.SE(/3O[2#O\._?[R#OZ2#E]N'Q[._CW?(@]._U($AO<F1E(.7P
MZ>KOZ>WY[>_][2X@(@HB[.7TX>[](/3O]?(N(,7D_B#P\=WPY>D@[>$@X_'<
M^.7TY2#\].D@Y?;A\>SOX]WR(/3O]2!(;W)D92#=]^7TY2`B"B+EX^KA].'S
M]-[SY>DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S
M(&]N;'DB"FUS9W-T<B`BQR#A\>GS].7QWB#JX>D@Y.7NZ=P@\.OE]?'=\B#L
M_.WO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM
M<V=S='(@(L<@Y.7NZ=P@\.OE]?'<(.S\[>\B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<G!C<W5M+G!H<#HW.`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S
M(&)E96X@9&5L971E9"XB"FUS9W-T<B`BSR#E[O7PY_'E].?TWO(@7"(E<UPB
M(.3IX>/QW.?JY2XB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT
M.0IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM
M<V=S='(@(L\@Y>[U\.?QY?3>\B!<(B5S7"(@X?#OZ.?JY?WHY^KE+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$Y.`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T
M(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R("+4[R#AW_3G[.$@
MY>GS_.3O]2#CZ>$@)7,@Y.GAX_'<]N?JY2XB"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HR.#0*;7-G:60@(E1H92!S<&5C:69I960@
M<F]W(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("+'(./QX>SLWB#P[_4@[_'?
M\^'TY2#DY>T@]?#<\??EZ2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C$P.`IM<V=I9"`B5&AE('1A<VL@:&%S(&)E
M96X@861D960@=&\@>6]U<B!T87-K;&ES="XB"FUS9W-T<B`BQR#E\>/A\]_A
M(/#Q[_/TW>CGZN4@\_3G(.O?\_3A(.7QX^'SZ?[M(//A\BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$Q,0IM<V=I9"`B5&AE('1E;7!O<F%R
M>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`BU.\@\/'O
M\_GQZ>W\(.'Q]^7?[R!<(B5S7"(@Y.7M(/7PW/'WY>DN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I
M9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`BQR#P
MW.WY(.KAZ2#JW/3Y(/#KY?7QW?(@[/SM[R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G:60@(E1H92!T
M;W`@<VED92!O;FQY(@IM<V=S='(@(L<@\-SM^2#PZ^7U\=P@[/SM[R(*"B,Z
M(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C,Q,0IM<V=I9"`B5&AE('5P;&]A
M9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM
M<V=S='(@(M3A(.3EY._LW>WA(/#O]2#S]-WK[>'TY2#WW.CGZN'M(.'P_"#T
M[R#P\>_GX^_][.7M[R#BWNSA+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O
M8W-V+G!H<#HR-3`@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$W-PIM
M<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*
M;7-G<W1R("+4[R#A\??EW^\@\._U(//TY=_KX?3E(.3E(.SP_/'E\^4@[>$@
M\_GHY=\N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HY,PIM<V=I9"`B5&AE('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M
M871I;VX@=V%S('-U8V5S<V9U;&QY('-T;W)E9"XB"FUS9W-T<B`BS^D@\.OG
M\>_V[_'?Y?(@Y.GAZ.7SZ>S\].?TX?(@X?#OZ.?JY?WHY^KA[2#E\.GT]??^
M\BXB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*;7-G:60@(E1H96UE
M<R!D:7)E8W1O<GD@)R5S)R!N;W0@9F]U;F0N(@IM<V=S='(@(L\@ZN'TW.OO
MX^_R(.CE[-ST^>T@)R5S)R#DY2#B\=WHY^KE+B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,3@S"FUS9VED(")4:&5R92!A<F4@;F\@;W!T
M:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@(L3E[2#U\-SQ]^_U[2#%\.GK[^/=
M\B#DZ>'HW?/I[.7R+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C,T,`IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N
M(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(L3E[2#U\-SQ]^_U[2#T
M[-[LX?3A(/#O]2#DY2#L\._Q[_WM(.WA(.7L]N'MZ?/H[_WM(.7M\_GLX?3Y
M[-WMX2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,SDW"FUS9VED
M("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I
M96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[("(*(GEO=2!M
M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@HBU?#<\??O]>T@
M\._KZ^_?(/?A\>'J]-[QY?(@\^4@X?7T_"#T[R#PY>3?[RX@Q>GSX>/<X^'T
MY2`E<R#WX?'AZO3>\>7R+"`B"B+P\=WPY>D@[>$@]?#<\??O]>T@Z^GC_/3E
M\>_I(.'P_"`E<RXB"@HC.B!S:6=N=7`N<&AP.C4U"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M(&%D9&EN9R`G)7,G('1O('1H92!S>7-T96TN("5S+B(*
M;7-G<W1R("+0\?SBZ^?LX2#JX?3<(/3G[2#P\>_SZ-[JYR`G)7,G(//T[R#S
M_?/TY^SA+B`E<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HW,PIM<V=I9"`B5&AE
M<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@)R5S)R!T;R!T:&4@<WES=&5M.B`E
M<R(*;7-G<W1R("+0\?SBZ^?LX2#JX?3<(/3G[2#P\>_SZ-[JYR`G)7,G(//T
M[R#S_?/TY^SA.B`E<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C(*;7-G:60@
M(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B`G
M)7,G(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(M#Q_.+KY^SA(.KA]-P@
M].<@Y.GAX_'A]MX@Y.7D[^S=[?GM(/3O]2#W\=[S].<@)R5S)R#A\/P@].\@
M\_WS].?LX3H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"FUS9VED(")4:&5R
M92!W87,@82!P<F]B;&5M(')E;6]V:6YG("<E<R<@9G)O;2!T:&4@<WES=&5M
M.B`B"FUS9W-T<B`BT/'\XNOG[.$@ZN'TW"#TYR#DZ>'C\>'VWB`G)7,G(.'P
M_"#T[R#S_?/TY^SA.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*;7-G:60@
M(E1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@)R5S)SH@)7,B"FUS9W-T
M<B`BT/'\XNOG[.$@ZN'TW"#TY^T@Y>WG[-WQ^?/G("<E<R<Z("5S(@H*(SH@
M9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#DY"FUS9VED(")4:&5R
M92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W
M87,@=7!L;V%D960N(@IM<V=S='(@(M#Q_.+KY^SA(.KA]-P@].?M(.'P[_/T
M[^O>(.'Q]^7?[_4Z(,3E[2#S]-SKZ.?JY2`E<RXB"@HC.B!F<F%M97=O<FLO
M0G)O=W-E<B]"<F]W<V5R+G!H<#HY,#0*;7-G:60@(B(*(E1H97)E('=A<R!A
M('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R
M9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B>71E
M<RDN(@IM<V=S='(@(B(*(M#A\>_U\^G<\^CGZN4@\/'\XNOG[.$@ZN'TW"#T
MY^T@X?#O\_3OZ]X@]._U(.'Q]^7?[_4Z(-3O("5S(.7?[>'I(.SEX^'K_?3E
M\>\@(@HBX?#\(/3O(.S=X^GS].\@Y?#I]/'E\/SLY>WO(.S=X^7H[_(@*"5D
M($)Y=&5S*2XB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY
M,#8*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N
M(@IM<V=S='(@(B(*(M#A\>_U\^G<\^CGZN4@\/'\XNOG[.$@ZN'TW"#TY^T@
MX?#O\_3OZ]X@]._U(.'Q]^7?[_4Z(-/TW.OHY^KE(.S\[>\@W>WA("(*(O3L
MWNSA(/3O]2`E<RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C,X"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA
M>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R("(B"B+0X?'O]?/IW//H
MY^KE(//VW.OLX2#JX?3<(/3G[2#E[/;<[>GSYR#A]?3O_2#T[_4@].S>[.'T
M[_(@]._U(.SG[?WLX?3O\BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z-#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C4Q"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(M#A\>_U\^G<\^CG
MZN4@\_;<Z^SA(.KA]-P@].?M(.7I\^'C^>/>(.3EY._LW>WY[2#$Z>7UZ/7M
M\^GOX_'<]N_U+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z-S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O
M<G1I;F<@=&AE(&5V96YT.B`E<RXB"FUS9W-T<B`BT.'Q[_7SZ=SSZ.?JY2#S
M]MSK[.$@ZN'TW"#TY^T@Y>GSX>/YX]X@]._U(./EX^_M[_3O\CH@)7,N(@H*
M(SH@9G)A;65W;W)K+T1A=&$O1&%T82]I;6,N<&AP.C,R"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB
M"FUS9W-T<B`BT.'Q[_7SZ=SSZ.?JY2#S]MSK[.$@ZN'TW"#TY^T@Y>GSX>/Y
MX]X@Y.7D[^S=[?GM(.?LY?'OZ^_CW^_U+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3`U"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!T87-K.B`E<RXB"FUS9W-T<B`B
MT.'Q[_7SZ=SSZ.?JY2#S]MSK[.$@ZN'TW"#TY^T@Y>GSX>/YX]X@].?R(.7Q
MX^'SW^'R.B`E<RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.CDQ"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M871I;VXZ("5S+B(*;7-G
M<W1R("+0X?'O]?/IW//HY^KE(//VW.OLX2#JX?3<(/3G[2#EZ?/AX_GCWB#P
MZ^?Q[_;O\>G^[2#DZ>'HY?/I[/STY_3A\CH@)7,N(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HW.0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R
M(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@
M;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(B(*(M#A\>_U\^G<
M\^CGZN4@\_;<Z^SA(//TYR#V_/'LX2#Q]>CLW_/E^>TN(+KS^?(@X?;>\^'T
MY2#JY>W\(.K<\._I[R`B"B+A\.'I]._][.7M[R#PY>3?[RXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8V,PIM<V=I
M9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I
M9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A
M:6X@;&%T97(N(@IM<V=S='(@(B(*(M#A\>_U\^G<\^CGZN4@\_;<Z^SA(//T
MY^T@Y>KTW>OE\^<@].?R(.KAZ._QZ?/LW>WG\B#KY>GT[_7QX]_A\B#T[_4@
M(@HBQ.GE]>CU[?/I[^/QW/;O]2X@T.'QX>KAZ_X@Y._JZ>S<\_3E(.'QX_ST
MY?'A+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C8U"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I
M;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E
M<BXB"FUS9W-T<B`B(@HB0F5I(&1E<B!!:W1U86QI<VEE<G5N9R!D97(@2V]N
M=&%K=&1E=&%I;',@:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XN($)I='1E
M("(*(G9E<G-U8VAE;B!3:64@97,@<W#D=&5R(&YO8V@@96EN;6%L+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<P
M"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I
M<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G
M<W1R("(B"B+0X?'O]?/IW//HY^KE(//VW.OLX2#JX?3<(/3G[2#E[>?LW?'Y
M\^<@].?R(.O?\_3A\B#DZ>'M[^S>\BX@T.'QX>KAZ_X@(@HBY._JZ>S<\_3E
M(.'QX_STY?'A+B(*"FUS9VED(")4:&5S<V%L;VYI:VD@06ER<&]R="(*;7-G
M<W1R("+!Y?'OZ^GLW>WA\B#(Y?/SX>OO[=_JY_(B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-3,*;7-G:60@(E1H:7,@24U!
M4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM
M<V=S='(@(L\@Y>[U\.?QY?3G]-[R($E-05`@Y.7M(/7P[_/TY_'?YN7I(.KO
MZ>W\]_'G\_3O]?(@]N'JW>OO]?(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HX,@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.CDV"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3$R"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,C`P"FUS9VED(")4:&ES
M(&%C=&EO;B!I<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("+!]?3>(.<@Y>W=
M\>/EZ>$@Y.7M(/7P[_/TY_'?YN7TX>DN(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HS-3D*;7-G:60@(E1H:7,@
M86-T:6]N(&ES(&YO="!Y970@:6UP;&5M96YT960N(@IM<V=S='(@(L'U]-X@
MYR#KY>GT[_7QX]_A(.3E[2#=]^7I(._K[^KKY_'YZ.7?(.'J_.SG+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3$*;7-G:60@
M(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI
M=F4N(@IM<V=S='(@(L'U]/P@Y.4@]N'?[>7TX>D@[>$@Y=_MX>D@W>/J]?'O
M(.'Q]^7?[R!R87(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HU-0IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@
M82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`BP?7T_"#DY2#VX=_MY?3AZ2#M
MX2#EW^WAZ2#=X^KU\>\@X?'WY=_O('II<"XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,3(Y"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@
M8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`BP?7T_"#DY2#VX=_M
MY?3AZ2#MX2#EW^WAZ2#=X^KU\>_R(.'QZ>CL_/(@ZMSQ].'R+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-PIM
M<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G
M97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E
M;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B
M(@HBP?7T_/(@[R#OY.?C_/(@\^'R(.7PZ?3QW?#EZ2#MX2#S]-WK[>7TY2#L
MY^W][.'TX2#LW?/Y($-L:6-K871E;&PM*&AT='`Z+R\B"B)C;&EC:V%T96QL
M+F-O;2D@[-WS^2!(5%10+4%022XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4S-`IM<V=I9"`B(@HB5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS
M,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I
M;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*(L'U]/SR(.\@[^3GX_SR(//A
M\B#E\.GT\=WPY>D@[>$@\_3=Z^WE].4@[.?M_>SA].$@[-WS^2!S;7,R96UA
M:6PM*&AT='`Z+R\B"B)S;7,R;6%I;"YC;VTI(.S=\_D@2%144"U!4$DN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z.#(*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY
M("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q
M=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY
M("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*(L'U]/SR(.\@[^3G
MX_SR(//A\B#E\.GT\=WPY>D@[>$@\_3=Z^WE].4@[.?M_>SA].$@[-WS^2!3
M3510("#JX>D@].?R("(*(E9O9&%F;VYE+4ET86QY(.S\[>\@\^4@X?'IZ.SO
M_?(@5F]D869O;F4N(,'PX>GTY=\@W>WA(.OOX^'QZ>'S[/P@96UA:6P@\_3G
M("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$W,R!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C0W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R.#$@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Y-`HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-30V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,C8*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT,2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.3@X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M,3(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`V,0HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,3,R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R
M,#0*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y,B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-#,V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(V-#@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,3(Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,S.#8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Y-`IM<V=I9"`B
M5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`BU.\@\.7DW^\@X?7T
M_"#A\.'I].7?].'I+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P
M-3D*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R
M<RXB"FUS9W-T<B`BU.\@\.7DW^\@X?7T_"#L\._QY=\@[>$@W??EZ2#L_.WO
M(.'JW?'AZ>_U\BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#`P
M"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A
M;F0@=&AE(&-O;&]N+B(*;7-G<W1R("(B"B+!]?3\(/3O(/#EY-_O]2#L\._Q
MY=\@[>$@\.7QZ=WWY>D@[/SM[R#A\>GH[._]\B#JX>D@W.WY(.K<]/D@].7K
MY=_A("@Z*2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#@X"FUS
M9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S
M+B(*;7-G<W1R("+!]?3\(/3O(/#EY-_O(.SP[_'EWR#MX2#PY?'IW??EZ2#L
M_.WO(._J].'DZ>K=\B#TZ>S=\BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,3$W"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O
M<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B
M"B+!]?3\(/3O(/#EY-_O(.SP[_'EWR#MX2#PY?'IW??EZ2#L_.WO(.O?\_3A
M(.'QZ>CL_NT@]_GQZ?/LW>WY[2#LY2#JY>W\(-X@(@HBY>OKY^WIZOP@Y?'Y
M].?LX?3IZOPB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY.#,*;7-G
M:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T
M<B`BP?7T_"#T[R#PY>3?[R#P\=WPY>D@[>$@Y=_MX>D@W>WA\B#=X^KU\>_R
M(.'QZ>CL_/(N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@R-`IM
M<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E
M(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T
M868G+B(*;7-G<W1R("(B"B+!]?3\(/3O(/#EY-_O(/#QW?#EZ2#MX2#PY?'I
MW??EZ2#J^>3IZOP@]_'^[.'T[_(@\^4@4D="(.3EZN'E[N'DZ>K>(.SO\?;>
M+"#P+B(*(O<N("<C,3(S-&%F)RXB"@IM<V=I9"`B(@HB5&AI<R!F:6QE(&-O
M;G1R;VQS('1H92!G;&]B86P@<V5T(&]F($U)344@9')I=F5R<R!F;W(@=&AE
M($AO<F1E(&9R86UE=V]R:RP@(@HB86QL;W=I;F<@87!P;&EC871I;VYS('1O
M(&UA:V4@=7-E(&]F('!R;V=R86US('-U8V@@87,@96YS8W)I<'0@;W(@;7-W
M;W)D=FEE=R`B"B)T;R!R96YD97(@8V]N=&5N="!I;G1O($A434P@9F]R('9I
M97=I;F<@:6X@82!B<F]W<V5R+B(*;7-G<W1R("(B"B+!]?3\(/3O(.'Q]^7?
M[R#PY?'IW??EZ2#T[_7R($U)344@9')I=F5R<R#P[_4@]_'G\^GL[_#OZ>_]
M[?3AZ2#A\/P@].?M("(*(O7PY_'E\]_A(.7PZ?3QW?#O[?3A\B#DZ=SV[_'A
M(/#Q[^/QW.SLX?3A(.WA(.3IX??EZ?'?YN_M].'I(/3A(/#E\>GE]_SLY>WA
M("(*(O3Y[2!E;6%I;"#JX>D@[>$@].$@Y>SVX>W?YN_U[2#LY2#T[^T@ZN'T
MW.OKY^OO(/3Q_/#O+B(*"FUS9VED("(B"B)4:&ES(&9I;&4@8V]N=')O;',@
M=&AE('-T>6QE<VAE970@=&AA="!I<R!U<V5D('1O('-E="!C;VQO<G,@86YD
M(&9O;G1S(&9O<B`B"B)T:&4@2&]R9&4@9G)A;65W;W)K(&%N9"!A;&P@87!P
M;&EC871I;VYS('1H870@9&\@;F]T('!R;W9I9&4@=&AE:7(@;W=N("(*(G-E
M='1I;F=S+B(*;7-G<W1R("(B"B+!]?3\(/3O(.'Q]^7?[R#EZ]WC]^7I(/3I
M\B#Q]>CLW_/EZ?(@]/GM(/?Q^>S<]/GM(.KAZ2#T^>T@X_'A[.SA]._SY>GQ
M_NT@X^GA("(*(OSKX2#T[R#P\?SC\>'L[.$@]._U($AO<F1E+"#JX>D@X^GA
M(/3I\B#E]N'Q[._CW?(@\._U(.7?[>'I(.7CZN'TY?/TY^S=[>7R("(*(O/E
M(.'U]/P@ZN'I(.3E[2#PX?'=]^_U[2#DZ>K=\B#T[_7R(.7PZ>OOX]WR(./I
MX2#A]?3=\B#TZ?(@\?7H[-_SY>GR+B(*"FUS9VED("(B"B)4:&ES(&9I;&4@
M;6%P<R!F:6QE(&5X=&5N<VEO;G,@=&\@;&]G:6-A;"!-24U%('1Y<&5S+"!E
M;F%B;&EN9R!(;W)D92`B"B)A<'!L:6-A=&EO;G,@=&\@9FEG=7)E(&]U="!H
M;W<@=&\@:&%N9&QE('-O;64@8V]N=&5N="!S=6-H(&%S(&5M86EL("(*(F%T
M=&%C:&UE;G1S(&]R($-64R!C:&5C:V]U=',N(@IM<V=S='(@(B(*(L'U]/P@
M].\@X?'WY=_O(.KA].'C\=SVY>D@].GR(.7PY>KTW//EZ?(@]/GM(/3]\/GM
M(,S)S,4L(/[S].4@].$@\.7QZ>7W_.SE[>$@(@HB[_'I\^S=[?GM(&UA:6P@
M[>$@Y>SVX>W?YN_M].'I(.SE(/3O[2#JX?3<Z^OGZ^\@]/'\\.\N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z-38R"FUS9VED(")4:&ES(&9O<FT@
M:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@(L'U]-X@YR#V
M_/'LX2#=]^7I(-[DYR#E\.7NY?'CX?/HY=\N(@H*(SH@=&5M<&QA=&5S+VAE
M;'`O86)O=70N:6YC.C$*;7-G:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@(L'U
M]/P@Y=_MX>D@)7,N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT
M,S<*;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T
M+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@
M(@HB8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R
M92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S
M('!L96%S92!V:7-I="`E<R(*;7-G<W1R("(B"B+!]?3\(.7?[>'I($MO;&%B
M($=R;W5P=V%R92!O8FIE8W0N(,/IX2#MX2#DY=_TY2#T[R#A[?3IZN7?[.7M
M[R#A]?3\("(*(O?QY>G<YN7SZ.4@W>WA(/#Q_./QX>SLX2!E;6%I;"#P[_4@
MZN'TX>OAXN'?[>7I(.'U]-X@].<@[._Q]MXN(,/IX2#KW_/TX2`B"B+TW?3O
MZ?GM(/#Q[^/QX>SLW/3Y[2#L\._QY=_TY2#MX2#E\.GSZN7UZ.7?].4@].\@
M)7,B"@IM<V=I9"`B(@HB5&AI<R!I<R!T:&4@;6%I;B!(;W)D92!C;VYF:6=U
M<F%T:6]N(&9I;&4N($ET(&-O;G1A:6YS('!A=&AS(&%N9"!B87-I8R!I=&5M
M<R`B"B)T:&%T(&%P<&QY('1O('1H92!C;W)E(&9R86UE=V]R:R!A;F0@86QL
M($AO<F1E(&%P<&QI8V%T:6]N<RXB"FUS9W-T<B`B(@HBP?7T_"#EW^WAZ2#T
M[R#BX?/IZOP@X?'WY=_O(/'UZ.S?\^7Y[2#T[_4@\/'OX_'<[.SA]._R("=(
M;W)D92<N(-#E\>G=]^7I(/3A("(*(NSO[>_PW/3IX2#JX>D@].$@XN'SZ>K<
M(.S=\><@\._U(/?QY_/I[._P[^GO_>WTX>D@X?#\(/3O[2#P]?'>[>$@ZN'I
M(/3I\B`B"B+E]N'Q[._CW?(@]._U(//U\_3>[.'T[_(N("(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C8P-PIM<V=I9"`B5&AI<R!M
M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T
M:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(B(*(M3O(.S>[?7LX2#A]?3\
M(./QW/;HY^KE(.SE(.KYY.GJ[_/EZ]_DX2`H)7,I(.3IX?;O\>7TZ>K>(.'P
M_"#TYR#DZ>K>(//A\BXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C$R.0IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O
M;F4N(@IM<V=S='(@(L'U]/SR(.\@X?'IZ.S\\B#P\=WPY>D@[>$@Y=_MX>D@
M]._UZ]SWZ?/T[^T@W>WA+B(*"FUS9VED("(B"B)4:&ES('!R;V)L96T@<F5P
M;W)T('=A<R!R96-E:79E9"!F<F]M("5S+B!4:&4@=7-E<B!C;&EC:V5D('1H
M92!P<F]B;&5M("(*(G)E<&]R="!L:6YK(&9R;VT@=&AE(&9O;&QO=VEN9R!L
M;V-A=&EO;CHE<R!A;F0@:7,@=7-I;F<@=&AE(&9O;&QO=VEN9R`B"B)B<F]W
M<V5R.B5S(@IM<V=S='(@(B(*(M3O(/#Q_.+KY^SA(.'U]/P@X>WA]MWQZ.?J
MY2#A\/P@)7,N(,\@]_'>\_3G\B#JW.OE\^4@].?M/&)R+S[A[>'V[_'<("(*
M(O#Q[^+KWNSA]._R(.'P_"#T[R#PX?'AZMST^2!54DPZ/&)R+SXE<R#JX>D@
M]_'G\^GL[_#OZ>7?(/3O[2#AZOSK[_7H[R`B"B)B<F]W<V5R.CQB<B\^)7,B
M"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#@*
M;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G
M>FEP(&9I;&5S+B(*;7-G<W1R("+!]?3\\B#O(.7N]?#G\>7TY_3>\B#DY2#L
M\._QY=\@[>$@X?#O\_7L\.G=\^7I('II<"#JX>D@9WII<"#A\??EW^$N(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ-#<*;7-G
M:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"XB"FUS
M9W-T<B`BU.\@\_WS].?LX2#A]?3\(-WWY>D@X?#E[>7QX^_P[^GGZ.7?+B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(W"FUS9VED(")4
M:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(L'U]-X@YR#T
MZ>S>(/#QW?#EZ2#MX2#EW^WAZ2#A\>GH[/SR+B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR,C4*;7-G:60@(E1I8VME=',B"FUS9W-T<B`BQ>GS
MZ?3>\>GA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q,`IM<V=I
M9"`B5&EM92(*;7-G<W1R("+9\>$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S$Q"FUS9VED(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(LGW[>?K
MX?3^[?3A\B#TY^T@_O'A(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W"FUS
M9VED(")4:6UE(&9O<FUA="(*;7-G<W1R("+,[_'VWB#^\>'R(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4R,0IM<V=I9"`B5&EM92!S96QE8W1I
M;VXB"FUS9W-T<B`BQ?#IZ^_CWB#^\>'R(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(S,B!L:6(O0FQO8VLO:69R86UE+G!H
M<#HR,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`BU-_TZ^_R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET
M;&4@*'1O;VQT:7`I.B(*;7-G<W1R("+4W_3K[_(@*%1O;VQT:7`I.B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z.#`*;7-G
M:60@(E1O(@IM<V=S='(@(M#Q_/(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-C(Y"FUS9VED("(B"B)4;R!S96QE8W0@;75L
M=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O
M;6UA;F0@*$UA8RD@:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B
M"B+#Z>$@[>$@ZO'A]-[SY?3E(/#OZ^OA\.O<(.'M].GJY=_LY>WA+"#J\>'T
MWO/TY2#PX?3G[-SM[R#T[R!#;VYT<F]L("A00RD@WB`B"B+T[R!#;VUM86YD
M("A-86,I(/#KWNKT\>\L(.7M_B#JW.WE].4@ZNOIZBXB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,W"FUS9VED(")4;V1A>2(*;7-G<W1R
M("+3WNSE\>$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T<B`B
MQ>WAZ^OAX]X@\^4@\.?CX=_O($A434PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C,Y"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R("+!_?'I
M[R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW-PIM<V=I9"`B5&]P(@IM<V=S='(@(LKO\?7VWB(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O
M<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`BT-SM^2#PZ^'?\^GO("A?=&]P*2(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I9"`B5')A;G-L871I
M;VYS(@IM<V=S='(@(LSE].'V\=SSY>GR(@H*;7-G:60@(E1R:7!O;&ES($%I
M<G!O<G0B"FUS9W-T<B`BP>7Q[^OI[-WMX?(@U/'?\._KY_(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S<W"FUS9VED(")4<G5E(&]R(&9A;'-E
M(@IM<V=S='(@(L'KY^C=\B#>(/CE]>3=\B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@
M(M3Q(@H*;7-G:60@(E1Y<&4@;6ES;6%T8V@N(@IM<V=S='(@(LOA[>CA\^S=
M[>_R(/3]\._R(.3EY._LW>WY[2XB"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP
M:'`Z,C8R"FUS9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`BT.OG
MZO3Q[^OOX][S].4@].?M(.7PZ>OOX]X@\^'R.B`B"@IM<V=I9"`B55),(@IM
M<V=S='(@(L?KY>KT\>_MZ>K>(,3IY?WH]>WSYR(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Q"FUS9VED(")54DP@
M9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T
M<B`B(@HBQ^OEZO3Q[^WIZMX@Q.GE_>CU[?/G(./IX2#E\.GS]/'O]MX@X>WA
M]N_QW/(@ZN'TW//TX?/G\B#T[_4@\/'OX_'<[.SA]/SR(//A\B(*"FUS9VED
M(")54DPZ(@IM<V=S='(@(L?KY>KT\>_MZ>K>(,3IY?WH]>WSYSHB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-C$*;7-G:60@(E5N86)L92!T
M;R!A8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`BP>3][>'TYR#G(/#Q
M_//BX?/G(//T[^T@5D93(.KA]-SK[^/O+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HQ,#`*;7-G:60@(E5N86)L92!T;R!A9&0@97AT
M<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@
M(L'D_>WA].<@YR#P\>_SZ-[JY2#E\.GPZ]WO[2#PZ^?Q[_;O\>G^[2#JX?3<
M(/3G[2#EW_/OY.\@]._U(/?QWO/TYRXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C,T-@IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S
M:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(L'D_>WA].<@YR#A
MZ^OAX]X@Y>[O]?/I[^3O]-[SY?GM(./IX2#T[R!61E,@X?'WY=_O(%PB)7-<
M(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S$@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C4P,@IM<V=I9"`B56YA8FQE('1O(&-H
M86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B
MP>3][>'TYR#G(.'KZ^'CWB#E[N_U\^GOY._TWO/E^>T@X^GA(/3O(%9&4R#A
M\??EW^\@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW
M,#0*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@(L'D
M_>WA].<@YR#AZ^OAX]X@]._U("5S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<W%L+G!H<#HS-S4*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-1
M3"!S97)V97(N(@IM<V=S='(@(L3E[2#EW^WAZ2#D]>WA]-X@YR#S_>WDY?/G
M(//T[R#DZ>'J[^SI\_3>(%-13"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C<X.`IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN
M(@IM<V=S='(@(L3E[2#EW^WAZ2#D]>WA]-X@YR#S_>WDY?/G(.SE(%-33"XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-S$@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,3<V"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C(P,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y"FUS
M9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`BP>3][>'T
MYR#G(.'M].GC\>'VWB!61E,@X?'WY=_O]2XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C,R,`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@
M9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`BP>3][>'TYR#G(.3G[.GO]?'C
MW^$@ZN'TX>O\X^_U(%9&4R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,CDV(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR
M-S,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(V.0IM<V=I
M9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("+!
MY/WMX?3G(.<@Y.?LZ>_U\>/?X2#JX?3AZ_SC[_4@5D93+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C8*;7-G:60@(E5N86)L92!T;R!C
M<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(L'D_>WA].<@YR#DY^SI[_7QX]_A
M(%9&4R#A\??EW^_U+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C(Q,PIM<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB
M"FUS9W-T<B`BP>3][>'TYR#G(.3G[.GO]?'CW^$@ZN7M[_T@5D93(.'Q]^7?
M[_4N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+W1A<BYP:'`Z
M-SD*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C@R
M"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R("+!
MY/WMX?3G(.<@X?#O\_7L\-_E\^<@Y.7D[^S=[?GM+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,C0Y"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S='(@
M(L'D_>WA].<@YR#DZ>'C\>'VWB!<(B5S7"(L(.\@]MSJY>OO\B#DY>T@Y=_M
MX>D@ZN7M_/(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C<Q
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(S"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HS,S4@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C,V,0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I
M<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`BP>3][>'TYR#G(.3IX>/Q
MX?;>("5S+"#O(/;<ZN7K[_(@Y.7M(.7?[>'I(.KE[?SR(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HW.2!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4Y"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E("<E<R<Z("5S+B(*;7-G<W1R("+!Y/WMX?3G
M(.<@Y.GAX_'A]MX@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C,W-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,S@Q"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@
M<F5C=7)S:79E;'DN(@IM<V=S='(@(L'D_>WA].<@YR#DZ>'C\>'VWB#JX?3A
MZ_SC[_4@5D93(.7PX>WAZ^SBX>W\[.7MX2`H<F5C=7)S:79E;'DI+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(W-R!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,S0X"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HS-C$@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,V.0HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S<S"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(L'D_>WA].<@
MYR#DZ>'C\>'VWB#JX?3AZ_SC[_4@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z,S0X(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S8P
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*
M;7-G<W1R(")$87,@5D93+59E<GIE:6-H;FES(&MO;FYT92!N:6-H="!G96SV
M<V-H="!W97)D96XZ("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,3<Y"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`BP>3][>'TYR#G(.3IX>/QX?;>(/3O]2!61E,@X?'WY=_O
M]2!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C0S
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C$S"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HQ-S,@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C$X-@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3DS(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HT,3$*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C0Q.0IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@9FEL92XB"FUS9W-T<B`BP>3][>'TYR#G(.3IX>/QX?;>(/3O
M]2!61E,@X?'WY=_O]2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C,S-PIM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ
M("5S+B(*;7-G<W1R("+!Y/WMX?3G(.<@Y.GAX_'A]MX@5D93(.7PX>WAZ^'L
MXN'M_.SE[>$@*')E8W5R<VEV96QY*3H@)7,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HW-3(*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@
M8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(L3E(.SP[_'^(.WA(/#Q[_/D
MZ>_QW_/Y(/3O[2#T\=WW[^WTX2#JX?3<Z^_C[RXB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R-PIM<V=I9"`B56YA8FQE('1O(&5X
M=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R("+$Y2#L\._Q_B#M
MX2#E[MSC^2#PZ^?Q[_;O\=_E\B#PZ?/T[_#OZ>?TZ>KO_2(*"B,Z(&9R86UE
M=V]R:R].971?24U34"])35-0+G!H<#HT-C`@9G)A;65W;W)K+TYE=%])35-0
M+TE-4U`O075T:"YP:'`Z,3$Y"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@
M9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`BP>3][>'TYR#G(/;\\?3Y\^<@
M[_'I\^SO_2#T[_4@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,30P(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$T-0HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,38T(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HQ-CD*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&
M4R!F:6QE+B(*;7-G<W1R("+!Y/WMX?3G(.<@[.7TX>K?[>?SYR#T[_4@5D93
M(.'Q]]_O]2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<Y"FUS
M9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(L'D_>WA].\@].\@W.WOZ>/LX2#T[_4@5D93(.'Q]^7?[_4@7"(E<UPB+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R,"!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3(W"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HQ,S`*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F
M:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R("+!Y/WMX?3O(/3O(-SM[^GC[.$@
M]._U(%9&4R#A\??EW^_U(./IX2#C\=SXZ>SO+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C<T(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HW,PIM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S
M='(@(L'D_>WA].\@].\@W.WOZ>/LX2#T[_4@5D93(.'Q]^7?[_4N(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HT-PIM<V=I9"`B
M56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R("+$
MY2#L\._Q_B#MX2#A[>_?[OD@].\@\_7L\.GE\^S=[>\@X?'WY=_O+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8R,PIM<V=I9"`B56YA8FQE
M('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R("+$Y2#L
M\._Q_B#MX2#DZ>'BW//Y(/3O[2#J_?'I[R#JX?3<Z^_C[R!61E,@*'9F<W)O
M;W0I+B(*"FUS9VED(")5;F%B;&4@=&\@<F5G:7-T97(@<')E9F5R96YC97,@
M:6X@<V5S<VEO;BXB"FUS9W-T<B`BQ.7M(.7?[>'I(.3U[>'T_.T@[>$@ZN'T
MX??Y\>?H[_WM(._I(/#Q[_3I[-[SY>GR(./IX2#A]?3>(/3G[2#S_>WDY?/G
M+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`Y-0IM<V=I9"`B
M56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R
M(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(L'D_>WA].<@YR#LY?3O[>_LX?/?
MX2#T[_4@)7,@\^4@)7,Z(.\@]MSJY>OK[_(@]?#<\??EZ2#>Y.<B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S$U"FUS9VED(")5;F%B
M;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(L'D_>WA].<@
MYR#LY?3O[>_LX?/?X2#T[_4@5D93(.KA].'K_./O]2XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C(U-0IM<V=I9"`B56YA8FQE('1O(')E;F%M
M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`BP>3][>'TYR#G(.SE]._M
M[^SA\]_A(/3O]2!61E,@ZN'TX>O\X^_U.B`E<RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C(Y-@IM<V=I9"`B56YA8FQE('1O(')E;F%M92!6
M1E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(L'D_>WA].<@YR#LY?3O[>_LX?/?
MX2#T[_4@5D93(.'Q]^7?[_4@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C4V-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,C0Q"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+B(*
M;7-G<W1R("+!Y/WMX?3G(.<@[.7T[^WO[.'SW^$@]._U(%9&4R#A\??EW^_U
M("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C0Y(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,C(*(SH@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C0X-2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,S`T"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS
M,C8*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N(@IM<V=S='(@
M(L'D_>WA].<@YR#LY?3O[>_LX?/?X2#T[_4@5D93(.'Q]^7?[_4N(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP
M.C4Q"FUS9VED(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B
MP>3][>'TYR#G(.7J]-WKY?/G(/3O]2!<(FUK:7-O9G-<(BXB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C8R"FUS9VED(")5
M;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R
M("+$Y>T@[/#\\>7SY2#MX2#LY?3A]O'A\_3EWR#A]?3\(/3O(-WCX_'A]N\@
M5V]R9"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,3(W(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,3,P"FUS9VED(")5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+$Y2#L\._Q_B#MX2#C\=SX
M^2#S].\@5D93(.'Q]^7?[R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,3(Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R("+$Y2#L\._Q_B#MX2#C\=SX
MYR#S].\@5D93(.'Q]^7?[R`H8V]P>2@I(.'PW?3U]^4I+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R-"!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,3,T"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HQ,SD*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A
M+B(*;7-G<W1R("+$Y2#L\._Q_B#MX2#C\=SX^2#DY>3O[-WMX2#T[_4@5D93
M(.'Q]^7?[_4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(M7P[^/QX>SL
MZ?/LW>WA(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B
M56YD;R!#:&%N9V5S(@IM<V=S='(@(L'J_?'Y\^<@P>OKX>/^[2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@
M(E5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(L'J]?'^[>7I(/3G
M(/3EZ^7U].'?X2#SX?(@Y>W=\>/EZ>$B"@IM<V=I9"`B56YE>'!E8W1E9"!E
M;F0@;V8@9FEL92XB"FUS9W-T<B`BS.<@X>WA[.7M_.SE[>\@]-WK[_(@]._U
M(.'Q]^7?[_4N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,C,P"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,Y.0IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E
M<B!O;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`BS.<@X>WA[.7M_.SE[><@X?#<
M[?3G\^<@X?#\(/3O[2#E[O7PY_'E].?TWB#S].<@\_WMY.7SYSH@(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(V"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,U,`HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#<*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,SDS"FUS9VED(")5;F5X
M<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`BS.<@
MX>WA[.7M_.SE[><@X?#<[?3G\^<@X?#\(/3O[2#E[O7PY_'E].?TWB#S].\Z
M("(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C4X"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C8T"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(LSG(,'Q]^7I[^CE].?L
MW>WO(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HS.#0*;7-G:60@(E5N:&%N9&QE9"!C;VUP;VYE;G0@;V8@='EP93H@
M)7,B"FUS9W-T<B`BS.<@]^7I\>GF_.SE[>\@\_3OZ??EW^\@]/WP[_4Z("5S
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4U(&QI8B]";&]C
M:R]M971A<BYP:'`Z-CD*;7-G:60@(E5N:71S(@IM<V=S='(@(LSO[=SDY?(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,34@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$V"FUS9VED(")5;FMN;W=N(@IM
M<V=S='(@(L'C[?GS].\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@
M*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B56YK;F]W;B!A<&EM<V=I9"`H
M05!)($UE<W-A9V4@240I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B56YK;F]W;B!C;&EM<V=I
M9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R(")5;FMN;W=N(&-L:6US
M9VED("A#;&EE;G0@365S<V%G92!)1"DN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED(")5;FMN;W=N
M('5S97)N86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R("+!X^WY\_3O(/SM[^SA
M(/?QWO/TYR#>(.KYY.GJ_/(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED(")5;FQI;FL@=&AE
M(&-U<G)E;G0@96QE;65N="(*;7-G<W1R("+!\._S_>WDY?/G(/3QW??O[?3O
M\B#S]._I]^7?[_4B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN
M<&AP.C(Y.`IM<V=I9"`B56YN86UE9"(*;7-G<W1R("+![?[M]>SO(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I
M9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O
M0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E
M87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M
M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@
M<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"B+,
MYR#E[N_U\^GOY._TY^S=[>$@\/'OX_'<[.SA].$@Y.4@[/#O\>_][2#MX2#=
M]^_U[2#P\?SSXN'SYR#SY2#KY>GT[_7QX]_E\B`B"B+A\._J[_#>\B_A[?3I
MX_'A]M[R+^7PZ>K\Z^?SY_(@X^GA(.O\X^_U\B#A\_;AZ^7?X?(N(-#A]-[S
M].4@S\H@X^GA(.WA(.3EW_3E("(*(O3E]^WIZMWR(//G[.7I_O/EZ?(@\_3O
M(&UO>FEL;&$N;W)G(/#O]2#SX?(@Y.7?]^WO]>T@\/GR(.WA(.7PZ?3QW?CE
M].4@\^4@(@HB\/'OX_'<[.SA].$@].<@\/'\\^+A\^<@\_3O(&-L:7!B;V%R
M9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@(LSG(._QZ?/L
MW>WO(/?Q_NSA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HW,3`@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY-3(*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY-3@*;7-G:60@(E5N
M<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R("+,YR#U\._S].?QZ>;\[.7M
MYR#E\-WJ].'SYR(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P-B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$Y,0HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]L:7-T+FEN8SHS-@IM<V=I9"`B57!D871E(@IM<V=S='(@(L7M
MY^S=\?GSYR(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M,S$*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R("+%[>?LW?'Y\^<@)7,B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8T
M.`IM<V=I9"`B57!D871E(')E<W!O;F1E;G0@<W1A='5S(@IM<V=S='(@(L7M
MY^S=\?GSYR#JX?3<\_3A\^?R(.'PX>WTY^S=[>_U(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,PIM<V=I9"`B57!D871E('5S97(B
M"FUS9W-T<B`BQ>WG[-WQ^?/G(/?QWO/TYR(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,3,W(&%D;6EN+W!E<FUS+V5D:70N<&AP.C(Q-R!S97)V:6-E<R]S:&%R
M97,O961I="YP:'`Z,C,P"FUS9VED(")5<&1A=&5D("<E<R<N(@IM<V=S='(@
M(B<E<R<@Q>WG[.7Q_NCGZN4N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z.#$*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S='(@
M(M3O(/#Q_./QX>SLX2#A[>'BW.CLZ?/G\B#DZ>'C\=SVY^KE+B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S(@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$X,@IM<V=I9"`B57!L;V%D(@IM<V=S='(@(L'P
M[_/T[^O>(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`IM<V=I9"`B
M57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S
M97)V97(N(@IM<V=S='(@(L'P[_/T[^O>(/SK^>T@]/GM(.'Q]^7?^>T@\?7H
M[-_SY?GM(//T[^T@Y>[U\.?QY?3G]-XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P
M97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("+*Y?;AZ^'?X2#KX?3I[>GJW"#C
M\=SL[.'TX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B
M"FUS9W-T<B`BT?GLX?KJ[]\@X?'IZ.SOWRW*Y?;AZ^'?X2(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0V"FUS9VED
M(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`BU_'>\^<@]/'=]^_M]._R.B`E
M<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-34X"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(M?QWO/G(%-33"(*"FUS
M9VED(")5<V4@1&5F875L="!686QU92(*;7-G<W1R("+-X2#W\>?SZ>SO\._I
MY^CEWR#G(/#Q[^7PZ>OEX^S=[><@].GLWB(*"FUS9VED(")5<V4@:68@;F%M
M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G
M<W1R("+7\>?SZ>SO\._IY=_TX>D@X>T@].\@_.WO[.$OZOGDZ>K\\B#EW^WA
MZ2#DZ>'V[_'E].GJW"XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G
M:7-T<GDN<&AP.C8U,0IM<V=I9"`B57-E<B`E<R!I<R!N;W0@875T:&]R:7-E
M9"!F;W(@)7,N(@IM<V=S='(@(L\@]_'>\_3G\B`E<R#DY>T@Y=_MX>D@Y>[O
M]?/I[^3O].?LW>WO\B#CZ>$@)7,N(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`T
M"FUS9VED(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(L3IX??EW_'I
M\^<@U_'G\_3^[2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,C4Q"FUS9VED(")5<V5R($]P=&EO;G,B"FUS9W-T<B`BQ?#IZ^_CW?(@U_'>
M\_3G(@H*(SH@<VEG;G5P+G!H<#HV-`IM<V=I9"`B57-E<B!296=I<W1R871I
M;VXB"FUS9W-T<B`BQ>/C\>'VWB#7\=[S].<B"@HC.B!S:6=N=7`N<&AP.C$Y
M"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F
M;W(@=&AI<R!S:71E+B(*;7-G<W1R("+'(.7CX_'A]MX@]_'>\_3G(-WWY>D@
MX?#E[>7QX^_P[^GGZ.7?(./I)R#A]?3\(/3O('-I=&4N(@H*;7-G:60@(E5S
M97(@<&%S<W=O<F0@8VAA;F=E(@IM<V=S='(@(L'KZ^'CWB#J^>3IZN_](/?Q
MWO/TYR(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$W,B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C(U-`IM<V=I9"`B57-E<B!P97)M:7-S:6]N
M<R(*;7-G<W1R("+%[N_U\^GOY._TWO/EZ?(@U_'>\_3G(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`R('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,S"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z-C4@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z
M,3$*;7-G:60@(E5S97)N86UE(@IM<V=S='(@(KSM[^SA(-?QWO/TYR(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HQ,S$*;7-G:60@(E5S
M97)N86UE("<E<R<@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(M3O(/SM[^SA
M(/?QWO/TYR`G)7,G(/7PW/'WY>D@WN3G+B(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHX-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(KSM
M[^SA(-?QWO/TYSHB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX
M"FUS9VED(")5<V5R;F%M93H@(@IM<V=S='(@(KSM[^SA(-?QWO/TYSH@(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C<*;7-G:60@(E5S
M97)S(@IM<V=S='(@(M?QWO/TY?(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]L:7-T+FEN8SHT"FUS9VED(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G
M<W1R("+7\=[S].7R(//T[R#3_?/TY^SA.B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C$Q,"!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR
M,#,*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM<V=S
M='(@(L\@ZN'TW.OOX^_R(%9&4R#DY>T@]?#<\??EZ2XB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S@S"FUS9VED(")686-A=&EO;B(*;7-G<W1R
M("+$Z>'J[_#=\B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@V,`IM
M<V=I9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R
M("*XX^KU\>7R(/3O\._HY?/?Y?(@\._U(.+QW>CGZN'M(//U[/#E\>GKX>SB
MW.WO[?3AZ3H@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV-C(*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(L7CZO7Q_/3G].$B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8R
M,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR-C,*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S
M='(@(M3I[-X@\^4@Z^7P]-P@X?#\(/3^\>$N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C(R-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0Y
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R.3<@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,CDQ-@IM<V=I9"`B5F%L=65S(@IM<V=S='(@(M3I[-WR
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`Y,B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,38Y"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R
M;VTB"FUS9W-T<B`BQ/[S].4@].GLW?(@X^GA(.WA(.7PZ>O=[ODB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3DS"FUS9VED(")687)I86)L
M92(*;7-G<W1R("+,Y?3AXNOG]-XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C(R.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M
M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM
M<V=S='(@(L<@Y?#IXN7BX=_Y\^<@X?#=]/7WY2`M(.'U]/P@].\@[-[M]>SA
M(.SP[_'EWR#MX2#<Z^OA[N4@[.4N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HW,C0*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`BN.KD
M[_/G(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(P,`IM<V=I9"`B
M5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(KCKY>/W[_(@N.KD[_/G\B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#,*;7-G:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(LK<Z.7TYR#%]>CU
MX_'<[.SI\^<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@(LK<
MZ.7T[R#CW>SI\^SA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(LK<Z.7T
MX3HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8R"FUS9VED
M(")697)Y($AI9V@B"FUS9W-T<B`BT._K_2#XY^O>(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z.3DR"FUS9VED(")6:65W("5S(@IM
M<V=S='(@(L7L]MSMZ?/G("5S(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z
M,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*;7-G<W1R("+%
M[/;<[>GSYR#E[OGTY?'IZM[R(.GS]._SY>O?Y.'R(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0U"FUS9VED(")6:65W(&%S("5S
M(@IM<V=S='(@(L7L]MSMZ?/G(//A[2`E<R(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-SD*;7-G:60@(E9I97<@979E
M;G0B"FUS9W-T<B`BQ>SVW.WI\^<@X^7C[^W\]._R(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ,#D*;7-G:60@(E9I
M97<@=&%S:R(*;7-G<W1R("+%[/;<[>GSYR#E\>/A\]_A\B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C`W"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S='(@
M(L_QX?3\].?TX2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,#<*;7-G:60@(E9I<VEB:6QI='DZ("(*;7-G<W1R("+/\>'T_/3G].$Z(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z.#$*;7-G:60@(E9O9&%F;VYE($ET86QY('9I82!33510(@IM<V=S='(@
M(E9O9&%F;VYE(,GTX>O?X?(@[-WS^2!33510(@H*(SH@9G)A;65W;W)K+TYO
M=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS
M.0IM<V=I9"`B5T%23B(*;7-G<W1R("+0T<_3S]?'(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z.#,*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#
M4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R("+0T<_3S]?'(2$A(,'6
MP<G1Q=/4Q2#4SR#0T<_#T<',S,$@S,_-S\D@T\'3(,'0SR`E<RXB"@HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S
M=&%T=7,N<&AP.C,Q"FUS9VED(")787)N:6YG(@IM<V=S='(@(M#Q[^7IY._P
M[]_G\^<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C4X"FUS9VED(")792(*;7-G<W1R("+4Y2(*"B,Z(&9R86UE=V]R:R]-
M86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z,S<*;7-G:60@(E=E96ML>2(*
M;7-G<W1R("+%XN3O[.'DZ>'?X2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I
M;&4N<&AP.C(X"FUS9VED(")796QC;VUE(@IM<V=S='(@(LKAZ_GSWNOHX?3E
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z-"!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C4P"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S
M='(@(LKAZ_GSWNOHX?3E(//T[R`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M
M;V)I;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@IM<V=I
M9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`BRN'K^?/>Z^CA].4L("5S(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R,0IM<V=I9"`B5VAA="!A<'!L:6-A
M=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B
MT._IW"#E]N'Q[._CWB#HX2#E[/;A[-_FY>D@].\@)7,@X?;O_2#S]>WDY>CE
MW_3E(//TY^T@]?#G\>7SW^$[(@H*;7-G:60@(E=H870@87!P;&EC871I;VX@
M<VAO=6QD($AO<F1E(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@(M#O
MZ>$@Y?;A\>SOX]X@[>$@Y>SVX>W?YN7TX>D@X?;O_2#S]>WDY>CEW_3E(//T
MY^T@]?#G\>7SW^$[(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z
M,C$*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_(@IM
M<V=S='(@(M#OZ?SR(.7?[>'I(.\@Y.GA]_GQZ?/TZ>K\\B#WX?'AZO3>\>'R
M.R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(T"FUS9VED(")7
M:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(M#OZ?SR(.7?
M[>'I(.\@]^'QX>KTWO'A\B#EZ?/AX_GCZ>K^[3LB"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E<R(*;7-G<W1R("+0[^G=
M\B#6W//EZ?(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,Q"FUS9VED
M(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E
M9&ET;W(N(@IM<V=S='(@(B(*(LKAZ._QW_/TY2#P[^G<(/#Q_//HY?3A(.CA
M(.7MY?'C[_#OZ>?H[_WM(//T[^T@Y?#E[N7QX^'S]-X@Y>SPZ^_U].GS[-WM
M[_4@(@HBZN7I[-WM[_4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`B
MT.O<]._R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P.0IM<V=I
M9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(M#KW/3O\B#SY2#L[^W<
MY.7R($-34R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$*;7-G:60@
M(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E
M8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R("+0Z]ST[_(@]._U("5S(.SE
M[>_](//TX2#A\>GS].7QW"`HZ.$@Y?;A\>SO\^CEWR#S].?M(.7P_.SE[><@
MY=_S[^3O*3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@
M(M#KW/3O\B#T[_4@\-_MX>KA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G:60@(E=I9'1H('5N:70B"FUS9W-T
M<B`BS._MW.3A(/#KW/3O]?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P-0IM<V=I9"`B5VED=&@Z(@IM<V=S='(@(M#K
MW/3O\CHB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C<X"FUS9VED(")7:6YD
M('-P965D(&EN(&MN;W1S(@IM<V=S='(@(KCM].'SYR#A[=WL[_4@\^4@ZOSL
MXN_U\B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34T"FUS9VED(")7:6YD
M.B(*;7-G<W1R("+![>7L[_(Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$Y,0IM<V=I9"`B5VEN9#H@(@IM<V=S='(@(L'MY>SO\CH@(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB"FUS
M9W-T<B`BT^_VW^$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3<W
M"FUS9VED(")7:7-H;&ES=',B"FUS9W-T<B`BR]_S].$@Y?#IZ/7LZ?[M(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K(@IM<V=S
M='(@(L7QX^'SW^$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3(W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ-C<*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R("+$Z>7]
MZ/7M\^<@Q?'CX?/?X?(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3DU"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(M3G
MZ]WV^>WO(,7QX^'SW^'R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(S-`IM<V=I9"`B6"U2968B"FUS9W-T<B`B6"U2968B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Q-PIM<V=I9"`B6#4P.78S($)A
M<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(E@U,#EV,R#"X?/IZN_?(-#E\>GO
M\>GS[._?(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M,38*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B
M6#4P.78S(-?QWO/G(.7PY>KTX>S=[>_U(.KKY>GDZ>_](@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3@*;7-G:60@(E@U,#EV,R!3
M=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B6#4P.78S(,7MX>OA
MZO3IZOP@O.WO[.$@R-WLX?3O\B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C$Y"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+97D@261E
M;G1I9FEE<B(*;7-G<W1R(")8-3`Y=C,@P>WAX^WY\>GS].GJ_"#*Z^7IY-\@
MR-WLX?3O\B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-S`V"FUS9VED(")8-3`Y=C,@97AT96YS:6]N<R(*;7-G<W1R(")8-3`Y=C,@
MQ?#EZO3<\^7I\B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")9
M62(*;7-G<W1R("+%Q2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HS.#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0R-PIM<V=I9"`B65E962(*;7-G<W1R("+%Q<7%(@H*(SH@
M9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HS-0IM<V=I
M9"`B665A<FQY(@IM<V=S='(@(L7TWO/IX2(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HX.#@*;7-G:60@(EEE<R(*;7-G<W1R
M("+-X=\B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O86=R965M96YT7V)O
M='1O;2YI;F,Z-@IM<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(LWAZ2P@
MT_7L]OGM_B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H
M92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G
M<W1R("(B"B+%W_/TY2#SY2#JX?3<\_3A\^<@RL7)S,7-S]4N(-?QY_/I[._P
M[^GEW_/TY2#T[R!;/#Y=(/#KWNKT\>\@X^GA(.WA("(*(N7PZ?/T\=WXY?3E
M(//E(.KA]-SS].'SYR!765-)5TE'+B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,3,R,`IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC871E
M9"XB"FUS9W-T<B`BQ.7M(-WWY?3E(.'UZ.7M].GJ[_#OZ>?HY=\N(@H*(SH@
M9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS,#0*;7-G:60@(EEO
M=2!C86X@;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L
M;"!N86UE+B(*;7-G<W1R("+$Y>T@Y?#I]/'=\.7TX>D@[>$@W??E].4@].\@
M]^'QX>KTWO'A("=<7"<@\_3O(+SM[^S<(//A\BXB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#,X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y
M-3@*;7-G:60@(EEO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D
M<F5S<RXB"FUS9W-T<B`BQ.4@Y/[SX?3E(-WCX_7QYR#DZ>7]Z/7M\^<@96UA
M:6PN(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,C<T"FUS9VED("(B
M"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D
M(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S+B(*
M;7-G<W1R("(B"B+$Y>T@X>WTZ?/T[^GWW_/A].4@ZN'MW>WA(/#EY-_O(.'P
M_"#T[R#A\??EW^\@Y>GSX>/YX][R(//E(.'M]-_S]._I]^$@\.7DW^$@(@HB
M\_3O("5S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDT-`IM<V=I
M9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R("*X]^7TY2#A
M\._S]>WDY>CEWRXB"@IM<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T
M+CQB<B`O/E1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2XB"FUS9W-T
M<B`BN/?E].4@X?#O\_7MY.7HY=\N/&)R("\^Q?7WX?'I\_3O_>SE(/#O]2#W
M\>?SZ>SO\._IWO/A].4@].?M(/7PY_'E\]_A+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q-SD*;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@
M=F%L:60@=F%L=64N(@IM<V=S='(@(M#QW?#EZ2#MX2#D_O/E].4@[.GA(-WC
MZO7QYR#TZ>S>+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H
M<#HS.`IM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C
M:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`BT/'=\.7I(.WA(/'UZ.S?
M\^7TY2#T[R!$871A5')E92#CZ>$@[>$@]_'G\^GL[_#OZ>7?].4@4VEG;G5P
M<RXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0T-PIM<V=I9"`B
M66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(M#Q
MW?#EZ2#MX2#Q]>CLW_/E].4@].\@5D93+4)A8VME;F0N(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E
M<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R
M;V)L96T@<F5P;W)T+B(*;7-G<W1R("+0\=WPY>D@[>$@\.7QZ>/QW/CE].4@
M].\@\/'\XNOG[.$@\/'I[2#S].7?Z^7TY2#A[>'V[_'<(./IX2#A]?3\+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*
M;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK
M('!O:6YT<R!T;R(*;7-G<W1R("+0\=WPY>D@[>$@\_7L\.OG\?[SY?3E(/3O
M(%523"#P[_4@Y.7?]^WEZ2#A]?3>(.<@\_WMY.7SYR(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9;W4@;75S="!S96QE8W0@
M86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(M#QW?#EZ2#MX2#E
M\.GKW>[E].4@]._M(.7N]?#G\>7TY_3>(./IX2#DZ>'C\>'VWBXB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,3D*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U
M<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@(M#QW?#EZ2#MX2#O\=_S
MY?3E(-WMX2#\[>_LX2#W\=[S].<@X^GA(.3IX>/QX?;>+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N
M86UE('1O(')E;6]V92XB"FUS9W-T<B`BT/'=\.7I(.WA(._QW_/E].4@W>WA
M(/SM[^SA(/?QWO/TYR#CZ>$@Y.GAX_'A]MXN(@H*(SH@861M:6XO=7-E<BYP
M:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS9VED
M(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S
M='(@(M#QW?#EZ2#MX2#O\=_SY?3E(-WMX2#\[>_LX2#W\=[S].<@X^GA(/#Q
M[_/HWNKG+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@IM<V=I9"`B66]U(&UU
M<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*;7-G<W1R("+0
M\=WPY>D@[>$@[_'?\^7TY2#=[>$@_.WO[.$@]_'>\_3G(./IX2#E[>?LW?'Y
M\^<N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z
M,30T"FUS9VED(")9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E
M<F9O<FTN(@IM<V=S='(@(M#QW?#EZ2#MX2#O\=_SY?3E(.SIX2#E[=WQX^7I
MX2#CZ>$@Y>KTW>OE\^<N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A
M=&5G;W)Y36%N86=E<BYP:'`Z-S,*;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N
M97<@8V%T96=O<GD@;F%M92XB"FUS9W-T<B`BT/'=\.7I(.WA(.3^\^7TY2#=
M[>$@_.WO[.$@X^GA(/3G(.W=X2#JX?3GX^_QW^$N(@H*(R!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HY,S(L(&,M9F]R;6%T"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.CDS,@IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I
M<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(L<@\_WMY.7SYR#S
MX?(@)7,@Y.GAZOSPY^KE+B#0X?'AZN'K_B#D[^KI[-SS].4@[>$@[N'MX?/U
M[>3EZ.7?].4N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M,S@*;7-G:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R("+'(,?KY>KT
M\>_MZ>K>(//A\B#$Z>7]Z/7M\^<B"@IM<V=I9"`B66]U<B!%;6%I;"!!9&1R
M97-S.B(*;7-G<W1R("+'(,?KY>KT\>_MZ>K>(//A\B#$Z>7]Z/7M\^<Z(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y-@IM<V=I9"`B66]U<B!&<F]M
M.B!A9&1R97-S.B(*;7-G<W1R("+'(,'P_#H@Q.GE_>CU[?/G.B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX.0IM<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R("+/
MZ2#0Z^?Q[_;O\=_E\B#SX?(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HY,S8*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA
M;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@
M5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A
M9V%I;BXB"FUS9W-T<B`B(@HBQR!);G1E<FYE="#DZ>7]Z/7M\]X@\^'R(-SK
MZ^'NY2#A\/P@].?M(-WMX?'NYR#TY_(@)7,@\_WMY.7SWO(@\^'R+B##Z>$@
M].?M("(*(O#Q[_/TX?/?X2#TY_(@X?/VW.OEZ>'R(/#QW?#EZ2#MX2#NX>WA
M\_7MY.7HY=_TY2XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHS,PIM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@(M3O(/SM[^S<(//A\B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHY"FUS9VED("(B
M"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R
M="!A9&1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I
M<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@HBU.\@
M\_WS].?LX2#A]>CE[?3IZN_P[]_G\^?R(.3E[2#U\._S].?QW^;EZ2#P\>_S
MZ-[JYR#W\>?S]/[M+"#>(.<@Z^7I]._U\>/?X2`B"B+A]?3>(-WWY>D@X?#E
M[>7QX^_P[^GGZ.7?(./IX2#JW/#OZ>\@Z_SC[RXB"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]N;VQI<W0N:6YC.CD*;7-G:60@(B(*(EEO=7(@875T:&5N
M=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E
M<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S
M;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@HBU.\@\_WS].?LX2#A]>CE
M[?3IZN_P[]_G\^?R(.3E[2#U\._S].?QW^;EZ2#KW_/TX2#W\>?S]/[M+"#>
M(.<@Z^7I]._U\>/?X2`B"B+A]?3>(-WWY>D@X?#E[>7QX^_P[^GGZ.7?(./I
MX2#JW/#OZ>\@Z_SC[RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M-#`*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA
M;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@
M(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A
M9V%I;BXB"FUS9W-T<B`B(@HBSR!"<F]W<V5R(//A\B#VX=_MY?3AZ2#MX2#=
M]^7I(.'KZ]SNY>D@X?#\(/3G[2#=[>'Q[N<@].?R("5S(//][>3E\][R(//A
M\BX@(@HBP^GA(/3G[2#P\>_S].'SW^$@].?R(.'S]MSKY>GA\BP@Z.$@\/'=
M\.7I(.WA(.[A[>'S]>WDY>CEW_3E+B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N
M<&AP.C4P"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T
M:&ES(&9E871U<F4N(@IM<V=S='(@(L\@0G)O=W-E<B#SX?(@Y.7M(/7P[_/T
MY_'?YN7I(.'U]-X@].<@Z^7I]._U\>/?X2XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]P<FEN="YJ<SHR-PIM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O
M97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R
M;VPO3W!T:6]N("L@4"!T;R`B"B)P<FEN="XB"FUS9W-T<B`B(@HBSR!"<F]W
M<V5R(//A\B#DY>T@]?#O\_3G\=_FY>D@X?7TWB#TY^T@Y?#IZ^_CWB#EZO3]
M\/GSY_(N(-#A]-[S].4@0V]N=')O;"\B"B)/<'1I;VX@*R!0(./IX2#EZO3]
M\/GSYRXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0Q"FUS9VED(")9
M;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R("+'(/3QW??O]?/A(.;^
M[><@_O'A\CHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30X"FUS9VED
M(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@(L<@\/'OZN'H[_'I
M\^S=[><@\^'R(/3A]?3\].?TX3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3@W"FUS9VED(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`BU.\@\.O>
M\>7R(/SM[^S<(//A\CHB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HW-@IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*
M;7-G<W1R("+/(.W=[_(@\^'R(.KYY.GJ_/(@X^GA("5S(.7?[>'I.B`E<R(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34W"FUS9VED(")9
M;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO
M;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@(L_I(.7PZ>OOX]WR(//A\B#=
M]^_U[2#E[>?LY?'YZ.7?(./IX2#TYR#DZ=SQZN7IX2#A]?3>\B#TY_(@\_WM
MY.7SY_(N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-3D*
M;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS9W-T
M<B`BS^D@Y?#IZ^_CW?(@\^'R(-WW[_7M(.7MY^SE\?GHY=\N(@H*;7-G:60@
M(EEO=7(@<&%S<W=O<F1S(&1O(&YO="!M871C:"(*;7-G<W1R("+/Z2#MW>_I
M(.KYY.GJ[]\@Y.7M(/3AZ?'IW.;O]>TB"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@8F5E;B!R
M97-E="(*;7-G<W1R("+/(.KYY.GJ_/(@\^'R(-SKZ^'NY2(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W
M;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@
M:6X@=VET:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@HBSR#J
M^>3IZOSR(//A\B#<Z^OA[N4L(.7KW>/N].4@].$@[.?M_>SA]-P@\^'R(.KA
MZ2#JW.WTY2#EW_/OY.\@[.4@].\@[=WO(//A\B`B"B+J^>3IZOPN(@H*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9;W5R(')E
M;6]T92!S97)V97)S.B(*;7-G<W1R("+/Z2#A\._LX>KQ]?/LW>WOZ2#SX?(@
MY>[U\.?QY?3G]-WR.B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT
M97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E9"!4
M97AT72(*;7-G<W1R(");P?#\ZO'U^.<@ZN7I[-WM[_4@\^4@Y>GSX>/YX^GJ
MW%TB"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HU-@IM<V=I9"`B6U!R;V)L
M96T@4F5P;W)T72(*;7-G<W1R(");P>WA]N_QW"#0\>_BZ][LX?3O\ETB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I
M9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R(");Q>SVW.WI\^<@ZN7I
M[-WM[_4@\^4@Y>GSX>/YX^GJW"`M(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL
M=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@IM<V=I9"`B6U-H
M;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B6\7L]MSMZ?/G
M(.KEZ>S=[>_U(//E(.7I\^'C^>/IZMP@+2`E<R#C\>'L[-WR72(*"B,@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3DL(&,M9F]R;6%T"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,3DY"FUS9VED(");;&EN92`E<R!O9B`E
M<UTB"FUS9W-T<B`B6^/QX>SLWB`E<R#A\/P@)7-=(@H*;7-G:60@(E]!9&UI
M;FES=')A=&EO;B(*;7-G<W1R("+$Z>'WY=_QZ?/G(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED
M(")?1&5L971E(%)O=R(*;7-G<W1R("+$Z>'C\>'VWB##\>'L[-[R(@H*(SH@
M;&EB+V%P:2YP:'`Z,3$T"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(L_LW.3E
M\B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.#$*;7-G
M:60@(E](96QP(@IM<V=S='(@(L+OWNCEZ>$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@(E])
M;6%G92!0<F]P97)T:65S+BXN(@IM<V=S='(@(LGDZ?STY_3E\B#%Z>K\[>'R
M+BXN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C(P,`IM
M<V=I9"`B7TQO9R!I;B(*;7-G<W1R("+%W_/OY._R(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y-@IM<V=I9"`B7TQO9R!O=70B"FUS
M9W-T<B`BQ>[OY._R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI;FLN+BXB
M"FUS9W-T<B`BU/'O\._P[]_G\^<@T_WMY.7S[._U+BXN(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W,`IM<V=I9"`B7T]P=&EO;G,B
M"FUS9W-T<B`BQ?#IZ^_CW?(B"@HC.B!L:6(O87!I+G!H<#HQ,3@*;7-G:60@
M(E]097)M:7-S:6]N<R(*;7-G<W1R("+%[N_U\^GOY._TWO/EZ?(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C8*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R("+$Z>'C\>'VWB#3
M]>WDW?/L[_4N+BXB"@HC.B!L:6(O87!I+G!H<#HQ,#8*;7-G:60@(E]3971U
M<"(*;7-G<W1R("+1]>CLW_/EZ?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S(*;7-G:60@(E]486)L92!0
M<F]P97)T:65S+BXN(@IM<V=S='(@(LGDZ?STY_3E\B#0W^WAZN$N+BXB"@HC
M.B!L:6(O87!I+G!H<#HQ,3`*;7-G:60@(E]5<V5R<R(*;7-G<W1R("+7\=[S
M].7R(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3$*;7-G:60@
M(F%D9')E<W,@8F]O:R(*;7-G<W1R("+$Z>7UZ/7M\^GOX_'<]N_R(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#,*;7-G:60@(F-A;&5N9&%R
M(@IM<V=S='(@(L?LY?'OZ_SCZ>\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$W,"!L:6(O0FQO8VLO;65T87(N<&AP.C,U-@IM<V=I9"`B8V%L;2(*;7-G
M<W1R("+G\>7LW^$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HV,#@*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B\.'TWO/TY2#E
MY/XB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-S`*;7-G
M:60@(F9I;&4B"FUS9W-T<B`BX?'WY=_O(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS.#0*;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@)7,B
M"FUS9W-T<B`BX?#\(/3O("5S("@E<RD@\_3I\B`E<R`E<R(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S(*;7-G:60@(F@Z
M(@IM<V=S='(@(F@Z(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU.#<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C(Y"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T
M<B`BW.SE\^$B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV."!A9&UI;B]S
M971U<"]D:69F+G!H<#HW-@IM<V=I9"`B:6YL:6YE(@IM<V=S='(@(N7M\_GL
MX?3Y[-WM[R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS
M+FIS.C$S"FUS9VED(")L:6YE<UTB"FUS9W-T<B`BX_'A[.S=\ETB"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z
M-30*;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@
M25-/+B(*;7-G<W1R(")M:VES;V9S+>KYY.GJ_/(@Z]SH[_7R("5D(.KA]-P@
M].<@Y.?LZ>_U\>/?X2!)4T\N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HR.#@@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(P-@IM
M<V=I9"`B;F%M92(*;7-G<W1R("+\[>_LX2(*"B,Z(&9R86UE=V]R:R]24$,O
M4E!#+G!H<#HQ,C(*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R("+D
MY>T@W??EZ2#EX^KA].'S].'HY=\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C$R-#4*;7-G:60@(FYO="!Y970@:6UP;&5M96YT960B
M"FUS9W-T<B`BY.7M(-WWY>D@Y>/JX?3A\_3AZ.7?(.'J_.SG(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HX.34*;7-G:60@(FYO=&5P860B"FUS
M9W-T<B`B\^?LY>GY[.'TW/'I[R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS
M9W-T<B`B]._I\B#EZN'T_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R
M("+EZ>KO[>_S]._I]^7?X2(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M.3@*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T<B`BY>SVW.WI\^<@
MY.GA]N_Q_NTB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4S,PIM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S
M='(@(G-M<R#SY2!E;6%I;"#LW?/Y($A45%`B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S8T"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B\_3A
MZ.7Q_/(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ.0IM<V=I
M9"`B=&%S:R!L:7-T(@IM<V=S='(@(NO?\_3A(.7QX^'SZ?[M(@H*;7-G:60@
M(G1R87-H(@IM<V=S='(@(NK<Y._R(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(X,@IM<V=I9"`B='EP
M92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R("+#\=SX
M].4@]._M(.KYY.GJ_"#D_>\@]N_QW?(@X^GA(.7PZ>+EXN'?^?/G(@H*(SH@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z-C@@861M:6XO<V5T=7`O9&EF9BYP:'`Z
M-S8*;7-G:60@(G5N:69I960B"FUS9W-T<B`BY>WO\._IY^S=[>$B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U!A<G0N<&AP.C$W"FUS9VED(")U;FYA;65D
M(@IM<V=S='(@(N'M_NWU[.$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4X-PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,CD*;7-G:60@(G5S97(@<V5L96-T
M(@IM<V=S='(@(N7PZ>OOX]X@]_'>\_3G(@H*;7-G:60@(G9#87)D(@IM<V=S
M='(@(MCG]NGAZMX@RMSQ].$B"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O:V]?2U(N<&\`````````````
M````````````````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P-C4P,#`S
M(#$P-3$U-#,S-S0S(#`Q-S4R-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````C($MO<F5A;B!T<F%N<VQA=&EO;G,@9F]R(&AO
M<F1E('!A8VMA9V4*(R!H;W)D92#&T,6PP?:_H2"TZ\?1(,?1L;F^[B"Y^+^J
MN:XN"B,@0V]P>7)I9VAT("A#*2`R,#`U($AO<F1E(%!R;VIE8W0*(R!4:&ES
M(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC96YS92!A
M<R!T:&4@:&]R9&4@<&%C:V%G92X*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R
M;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@,RXP+6-V<UQN(@HB4F5P;W)T+4US
M9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A
M=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES
M:6]N+41A=&4Z(#(P,#$M,3$M,#D@,38Z,CDK,#DP,%QN(@HB3&%S="U4<F%N
M<VQA=&]R.B!*:6YH>6]K($AE;R`\;F]V96UB<F5`;W5R;F%T=7)E+F]R9SY<
M;B(*(DQA;F=U86=E+51E86TZ(&DQ.&Y`;&ES=',N:&]R9&4N;W)G7&XB"B)-
M24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN
M.R!C:&%R<V5T/4550RU+4EQN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN
M9SH@.&)I=%QN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,V.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S-S`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B`HM-S#X,6P
M("5S*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<S"FUS9VED("(@*'1O9&%Y*2(*
M;7-G<W1R("(@*+_`M,,I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C,W-0IM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B("BSN\#/*2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S$*;7-G:60@(B`H>65S=&5R
M9&%Y*2(*;7-G<W1R("(@*+[NP:8I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(U-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8Q
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,#<*;7-G:60@(B!A
M="`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR
M,34*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@
M82!D:7)E8W1O<GDN(@IM<V=S='(@(K7PM[K%Y+BN(@H*(SH@9G)A;65W;W)K
M+T-,22]#3$DN<&AP.C(W,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M7"(E<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`BO\.YV;BE
M(+#+N_8@N?S!UKBF(,#4M\+'S[R\O^0N(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+U)E9VES=')Y+G!H<#HV-3D*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+U)E9VES=')Y+G!H<#HQ,#0R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E
M9VES=')Y+B(*;7-G<W1R("(E<R?`S"BPH2D@2&]R9&4@M[G!]KVZQJZXKK^A
MO*T@O+/!I+7'ONX@P-;!]B"^RKW`M,^TV2XB"@HC.B!F<F%M97=O<FLO5')E
M92]4<F5E+G!H<#HQ-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R
M964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C4V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S
M7"(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R("(G
M)7,GL*$@O<.]NL7;OZ$@P]^PH;7'OOJ]P+3/M-DN(@H*(SH@861M:6XO<&5R
M;7,O861D8VAI;&0N<&AP.C4R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN
M(@IM<V=S='(@(B<E<R>PH2"]P[VZQ=N_H2##W["AM<>^^KW`M,^TV2XB"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C4T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H
M<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A
M=&5D.B`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C<P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N,F9-
M0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R("(E9"`O("5D("BXWKW#P?8Z("5D
M*2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,C8X(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HU-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@
M9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HV.`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`BPOS!MB(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`T"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S,R!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HX,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M2T(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S($UA:6YT96YA;F-E($]P97)A=&EO
M;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B)7,@P*_!]K#\N*X@P-N^]R`M
M(,BNP,XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T
M=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N
M<&AP.C(V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N(%5P(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT,C@@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HT.3`*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HV-3$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(EPB
M)7-<(K3"(,#,N<P@P-:]P+3/M-DN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ-3D@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C4@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,SD*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#4@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS-3$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S
M(&%T("5S("5S(@IM<V=S='(@(B5D("\@)60@*+C>O</!]CH@)60I(@H*(SH@
M<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0X"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN
M=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92`B
M"B)B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R
M;2!A="!T:&ES('1I;64N(@IM<V=S='(@(L'VL=T@O/;'X,?2(,#;OO?`NR"\
ML<7#Q\^\O+_D+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#8*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(B5S(&UI;G5T97,B"FUS9W-T<B`B-;K0(+BVM-DB"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3(S"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S
M='(@(L7KP?8@N*Z]NK/*("5SP+LHN*8I(,.CP+L@O/8@OOB]P+3/M-DN(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B)60@
M+R`E9"`HN-Z]P\'V.B`E9"DB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDR,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R
M97-S($)O;VLB"FUS9W-T<B`BP=:\TK?/(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S
M)W,@0V%L96YD87(B"FUS9W-T<B`BM-ZWPB(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z.3`V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R=S($YO=&5P860B"FUS9W-T<B`BP-#!]B"^RL"Z(+C>P,\B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS,`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("*\]KW%L,6ZSB(*"B,Z
M(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+VUO8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN
M<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M97-S
M86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W
M87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O
M=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I
M;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS-C4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q,`IM<V=I9"`B
M+"!G=7-T:6YG("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$X."!L:6(O0FQO8VLO;65T87(N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(L(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L
M92!F<F]M("5S('1O("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,CDT(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,S0X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-CD@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C$R.`HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-S0Y"B,L(&9U>GIY"FUS9VED("(M+2!S96QE
M8W0@+2TB"FUS9W-T<B`BL=3$HBBW_"D@O+'%PR"_P+?Y(@H*(SH@;&EB+T)L
M;V-K+W1I;64N<&AP.C(P"B,L(&9U>GIY"FUS9VED("(Q,B!(;W5R($9O<FUA
M="(*;7-G<W1R("+!I+JX(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y"B,L
M(&9U>GIY"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R("+!I+JX(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S
M(@IM<V=S='(@(C(T(+W#L*,B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N
M<&AP.C8Y"B,L(&9U>GIY"FUS9VED("(\4')E=FEO=7,B"FUS9W-T<B`BP,S`
M_"#&Y,#,P?8B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q.0IM<V=I9"`B
M02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V
M,`HC+"!F=7IZ>0IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B
M"FUS9W-T<B`B/&(^Q*&X[<#[P,X@O\"W^2"YW[O].CPO8CXB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B;&EC
M(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q
M-C4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R
M:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P.3<*;7-G:60@(B(*(D$@<'5B;&EC
M(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#$U"FUS9VED
M("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU,#4*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@
M4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*
M(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@
M4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S8T"FUS
M9VED(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP
M="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.CD*(RP@9G5Z>GD*;7-G:60@(D%-($-L;W5D
M<R(*;7-G<W1R("*ZN;OG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3`*(RP@9G5Z>GD*;7-G:60@(D%-($QI9VAT(%)A:6XB
M"FUS9W-T<B`BM\ZQU\#.(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3$*(RP@9G5Z>GD*;7-G:60@(D%-(%)A:6XB"FUS9W-T
M<B`BL*'`Y<#:N*XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ,@IM<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B
M04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A
M+W1I;64N:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R("*_P,#\+[_`R,0B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,#`*;7-G:60@(D%022!)1"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T
M:&ES(&5D:71O<B(*;7-G<W1R("+`S""_H;7PQ<VTPB(*"B,Z('-E<G9I8V5S
M+VAE;'`O:6YD97@N<&AP.C4R"FUS9VED(")!8F]U="XN+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T
M"B,L(&9U>GIY"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T<B`BOL:WH2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*(RP@
M9G5Z>GD*;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R("*PH;_NM:4B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C<P"B,L(&9U>GIY"FUS9VED
M(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(G9F<W)O;W0@M?"WNL7DN*ZXIB#`T,"[(+SV(+[XO<"TS[39+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,S8*(RP@9G5Z>GD*;7-G
M:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@
M(E9&4R#&Q,#/("5S+R5SP+LHN*8I(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B06-C
M;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R("+!I+JX(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<U"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT(%!A<W-W
M;W)D(@IM<V=S='(@(K[/R*,@R*[`SB(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PHC+"!F=7IZ>0IM<V=I9"`B
M06-C;W5N="!F<F]Z96XN(@IM<V=S='(@(K_`N*?"][SX(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,S,PHC+"!F=7IZ>0IM<V=I9"`B06-C;W5N
M=&EN9R(*;7-G<W1R("*_P+BGPO>\^"(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,30X('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0IM<V=I
M9"`B061D(@IM<V=S='(@(L/?L*$B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R
M-"!A9&UI;B]G<F]U<',N<&AP.C(R-0IM<V=I9"`B061D($-H:6QD($=R;W5P
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M.3@@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY.0HC+"!F=7IZ>0IM
M<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`BL+/`SB"XWL#/
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*(RP@9G5Z>GD*;7-G
M:60@(D%D9"!(97)E.B(*;7-G<W1R("*[Y[_KP-H@P]^PH2(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP:'`Z,C$Y"FUS9VED(")!
M9&0@3F5W($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX
M.`HC+"!F=7IZ>0IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@
M(K"SP,X@N-[`SR(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI
M;&0N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H
M:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R("),1$%0(+RMN?8@P:*\TR"]
MQ\;0(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#<*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I
M;VX@=&\@7"(E<UPB(@IM<V=S='(@(B5S(+''Q]$@O/;!I"(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B
MN_6WSK_N(+OGO^O`VB##W["A.B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HU-30*(RP@9G5Z>GD*;7-G:60@(D%D9"!C;VQU
M;6XB"FUS9W-T<B`BOZT@NM#'TB(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O961I="YI;F,Z,S0*(RP@9G5Z>GD*;7-G:60@(D%D9"!N97<@;65M8F5R
M<R(*;7-G<W1R("*[];?.O^X@N^>_Z\#:(,/?L*$Z(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D('!A:7(B"FUS9W-T<B`B
MQN2^[BAP86ER*2##W["A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-
M;WII;&QA(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")!9&0@
M=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R("(H)7,IN*8@P=:\TK?/OZ$@P]^P
MH2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW
M.`HC+"!F=7IZ>0IM<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O:R(*;7-G
M<W1R("(H)7,IN*8@P=:\TK?/OZ$@P]^PH2(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R("*[Y[_KP-H@P]^PH2(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%D
M9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A
M9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@
M(B(*"B,Z('-I9VYU<"YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D
M960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC
M.C(*;7-G:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B
MN^>_Z\#:(,/?L*$@N^>_Z[[(Q]0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ-S,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30T,0IM<V=I9"`B061D<F5S<R(*;7-G<W1R("+!UKS2(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$S.0IM<V=I9"`B061D<F5S<R!";V]K(@IM
M<V=S='(@(L'6O-*WSR(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.CDT"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I
M;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]I;F1E
M>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM<V=I
M9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`BL/RXKB(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS-#$*(RP@9G5Z>GD*;7-G:60@(D%D<R(*;7-G
M<W1R("+#W["A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@HC+"!F=7IZ>0IM<V=I9"`B069G:&%N
M:7-T86XB"FUS9W-T<B`BM-S#O"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*(RP@9G5Z>GD*;7-G
M:60@(D%L8F%N:6$B"FUS9W-T<B`BOO.V\\#,ONZ]NB(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*
M(RP@9G5Z>GD*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`BOO.V\\#,ONZ]NB(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*
M;7-G:60@(D%L:6%S(@IM<V=S='(@(K[SMO/`S+[NO;HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$V"FUS9VED
M(")!;&EG;B(*;7-G<W1R("+!I+?$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G
M<W1R("+!I+?$.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM<V=I
M9"`B06QL(@IM<V=S='(@(KCPM<X@O+'%PR(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,C`W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M-C4*(RP@9G5Z>GD*;7-G:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(@IM
M<V=S='(@(KC>P,\@P/RTWB"_P+?Y.B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*(RP@9G5Z>GD*;7-G:60@(D%L;"!'
M<F]U<',B"FUS9W-T<B`BN^C!IB(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+V1A=&%T<F5E+G!H
M<#HW-0HC+"!F=7IZ>0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@
M(L7DM]`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G<W1R("*X
M\+7G(#2XZ2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S$*;7-G
M:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,T"FUS9VED(")!;&QO=R!S971T:6YG
M(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HU,#0*(RP@9G5Z>GD*;7-G
M:60@(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@(EPB)7-<(K3"(,#,N<P@P-:]
MP+3/M-DN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,PIM<V=I9"`B
M06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4P-PHC+"!F=7IZ>0IM<V=I9"`B06QT97)N871E($E-
M4U`@4&%S<W=O<F0B"FUS9W-T<B`BOL_(HR#(KL#.(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0Y.0IM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA
M;64B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M,S4*(RP@9G5Z>GD*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM
M<V=S='(@(L#?N/BUR"#`S+C>P,\@P=:\TB(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z,30R"B,L(&9U>GIY"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S
M(@IM<V=S='(@(K3KP[P@L=LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T
M92!T97AT.B(*;7-G<W1R("*TZ\.\(+';(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B
M06UE<FEC86X@4V%M;V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HY-2!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C$Q-0IM<V=I9"`B06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*
M;7-G<W1R("+`W[CXM<@@N:[`VK"A(,#6O<"TS[39+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C<*(RP@9G5Z>GD*;7-G:60@(D%N('5N
M:VYO=VX@97)R;W(@:&%S(&]C8W5R960N(@IM<V=S='(@(CQB/L2AN.W`^\#.
M(+_`M_D@N=^[_3H\+V(^(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B06YD;W)R82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM
M;W5S(%!R;WAY(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C0Y"B,L(&9U>GIY"FUS9VED(")!;G-W97(B"FUS9W-T<B`BR+B]
MQ<?1(+C>P,\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%N=&EG=6$@86YD($)A<F)U9&$B
M"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HW-"!A9&UI;B]P
M:'!S:&5L;"YP:'`Z,S4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H
M<#HU."!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HV"B,L(&9U
M>GIY"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R("*]Q\?@(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C0R"B,L(&9U>GIY"FUS9VED(")!<'!L:6-A
M=&EO;B!,:7-T(@IM<V=S='(@(KW'Q^`B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,30P"B,L(&9U>GIY"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D
M>2XB"FUS9W-T<B`BO<?'X"(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G
M:60@(D%P<')O=F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z.#,S"FUS9VED(")!<'!R;WAI;6%T92!3:7IE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8X"FUS9VED(")!<')I;"(*;7-G<W1R("(TO_DB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$W-0IM<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R-38I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-3D@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV
M-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@Q"FUS
M9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HX,`HC+"!F=7IZ>0IM<V=I9"`B07)C:&EV92!.
M86UE(@IM<V=S='(@(L?*M>7`S+BG(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG
M;G5P(')E<75E<W0@9F]R("5S(#\B"FUS9W-T<B`BL.B\TR#!^,?@Q\^]P[#:
MO<"TS['N/R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN
M8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@
M>6]U('=I<V@@=&\@9&5L971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_
M(@IM<V=S='(@(L#,(+C>O</!]KBF(+^UO_C(]R"[Z,&FQ\^]P[#:O<"TS['N
M/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(D%R9V5N=&EN82(*;7-G
M<W1R("*^\[;SP,R^[KVZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B07)M96YI82(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-@IM<V=I9"`B
M07)M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G:60@(D%S
M8VEI($%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R-0IM<V=I9"`B07-K(&9O
M<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,_(@IM<V=S='(@(L"OP?:P_+BNO<?'X,#\(,BNP,['S['B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q,PHC+"!F=7IZ>0IM<V=I9"`B
M07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(K^M(+K0Q](B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO
M;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O
M9&5L971E+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM
M97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R
M;7,O961I="YP:'`Z.#<*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE
M>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S
M:&%R97,O961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO
M;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HV-"!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C<Q"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#8*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.`HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G
M:60@(D%U9W5S="(*;7-G<W1R("(XO_DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"B,L(&9U>GIY
M"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B.+_Y(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0HC
M+"!F=7IZ>0IM<V=I9"`B075S=')I82(*;7-G<W1R("(XO_DB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y
M<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,S4*
M;7-G:60@(D%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U
M:7)E9"!C87!A8FEL:71E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)U<RYP:'`Z,3(R"FUS9VED(")!=71H7V-Y<G5S.B!297%U
M:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB075T
M:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP
M:6QE(%!(4"!W:71H('1H92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C8T"FUS
M9VED(")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U
M+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z,S`R"FUS9VED(")!=71H7VQD87`Z($%D9&EN9R!U
M<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S4W
M"FUS9VED(")!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P
M;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HV,PIM<V=I9"`B075T:%]L9&%P
M.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!A
M9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM
M<V=S='(@(L#3O<.ZN+#\Q]0@P/K`Y2"_P+?Y+B"\K;GVP,<@O\"W^2"XWKW#
MP?8Z("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS.#4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M
M;W9E('5S97(@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HT.3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%U
M=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S(@IM<V=S='(@(L#3
MO<.ZN+#\Q]0@P/K`Y2"_P+?Y+B"\K;GVP,<@O\"W^2"XWKW#P?8Z("5S(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,#4*;7-G:60@(D%U
M=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@
M06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E
M9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A
M=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y,`HC+"!F=7IZ>0IM<V=I9"`B075T:&5N=&EC871I;VX@
M9F%I;&5D(@IM<V=S='(@(KOHP:8@O<?&T"(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960N("5S(@IM
M<V=S='(@(KC>P,\@P/RTWB"_P+?Y.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<F%D:75S+G!H<#HQ-S8*(RP@9G5Z>GD*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S='(@(F9T<""\
MK;GV(+^LL.$@O\"W^2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C@U,0HC+"!F=7IZ>0IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@1E10('-E
M<G9E<B!F86EL960N(@IM<V=S='(@(F9T<""\K;GV(+^LL.$@O\"W^2XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C<P"B,L(&9U>GIY"FUS9VED
M(")!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N(@IM
M<V=S='(@(F9T<""\K;GV(+^LL.$@O\"W^2XB"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C<U"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G
M<W1R("*PH;3)Q]$@Q\JUY3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I
M:F%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM
M<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A
M8VMG<F]U;F0B"FUS9W-T<B`BN>BPYB(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L
M;W(B"FUS9W-T<B`BN>BPYB"[]K'R(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@S
M"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(D)A:&%M87,B"FUS9W-T<B`BP,RX
MIR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(D)A:')A:6XB"FUS9W-T
M<B`BP*6XWL#/(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S<*;7-G:60@
M(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*
M;7-G:60@(D)A;F=L861E<V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I
M9"`B0F%R8F%D;W,B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N
M<&AP.C,Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H
M:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("+%Z\'V
M(+BNO;JSRB`E<\"[*+BF*2##H\"[(+SV(+[XO<"TS[39+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PHC+"!F
M=7IZ>0IM<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`BQ:FQXB(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C,*;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`HC+"!F
M=7IZ>0IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R("+%J;'B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,PHC+"!F=7IZ>0IM<V=I9"`B0F5L:7IE(@IM<V=S='(@(L6IL>(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Q"FUS9VED(")"96YI;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS
M9VED(")"97)M=61A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H
M=71A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G<W1R("*[_<#/
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,U
M,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F
M(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(L7KP?8@
MN*Z]NK/*("5SP+LHN*8I(,.CP+L@O/8@OOB]P+3/M-DN(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]L87EO=70N:6YC.C@Y"FUS9VED(")";&]C:R!3971T:6YG
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX"FUS9VED(")";VQD(@IM
M<V=S='(@(K&]L-0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")";VQI=FEA(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,#4*;7-G:60@
M(D)O;VMM87)K<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(P"FUS9VED(")";W)D97(B"FUS
M9W-T<B`BL.:PZ"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM<V=S='(@
M(K#FL.@@M<ZRLB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`BL.:P
MZ"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C`*;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED
M(")";W1H(@IM<V=S='(@(KCPM<XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W1S
M=V%N82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@(D)O='1O;2(*;7-G<W1R("*^
MQK>A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8R"B,L(&9U>GIY"FUS9VED(")"<F%Z:6PB"FUS9W-T
M<B`BP*6XWL#/(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(D)R:71I<V@@26YD:6%N
M($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED
M(")"<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"B,L
M(&9U>GIY"FUS9VED(")"=6QG87)I82(*;7-G<W1R("*^\[;SP,R^[KVZ(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM
M<V=I9"`B0G5L;&5T960@3&ES="(*;7-G<W1R("*QXLBC(+BNO;K&KB(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C$*;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Q"FUS9VED(")"=7)U;F1I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT-#0*(RP@9G5Z>GD*;7-G:60@(D--4R(*;7-G
M<W1R(")#5E,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-23"!$:7-T<FEB=71I
M;VX@4&]I;G1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-PIM<V=I9"`B0U]E;&P@4')O
M<&5R=&EE<RXN+B(*;7-G<W1R(")?9;R_(+S3O+HN+BXB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38S"FUS9VED(")#86-H92!I;FET('=A
M<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@T(&-O;F9I9R]H;V]K<RYP:'`N
M9&ES=#HY.#<*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$U-0IM<V=I
M9"`B0V%L96YD87(B"FUS9W-T<B`BM-ZWPB(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-#8*(RP@9G5Z>GD*;7-G:60@(D-A;&TB"FUS9W-T
M<B`BP^N\TB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")#86UE<F]O;B(*;7-G
M<W1R("*PL\#.(+C>P,\B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HR,`IM<V=I9"`B0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A
M;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S$X"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#86X@;F]T('=R:71E('1O(&9I;&4@7"(E<UPB
M(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5SP+LHN*8I(+JOL.;'TB"\]B"^^+W`
MM,^TV2XB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T
M(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C,U(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS,3D*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z
M("5S(@IM<V=S='(@(DQ$05`@O*VY]B#!HKS3(+W'QM`B"@HC.B!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HT,3,*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D-A;B=T(&]P96X@9FEL92!<(B5S7"(N(@IM<V=S='(@(E9&4R#&
MQ,#/("5S+R5SP+LHN*8I(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8T"B,L(&9U>GIY"FUS9VED(")#86YA9&$B"FUS9W-T<B`BM-ZWPB(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$P,2!A9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8U"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,2!T96UP;&%T97,O861M
M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E+FEN8SHQ,@IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(L/KO-(B"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N
M8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(K_`M_D@NKBP[<?/L>(@P^N\
MTB(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$X"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]
MP+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO8V]P
M>2YP:'`Z-3(*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T('!R;V-E960@=VET:&]U
M="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q-`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G
M<W1R(")-86EN=&5N86YC95]487-K(+CPM>(@)7/`NRBXIBD@OZT@O/8@OOB]
MP+3/M-DN(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+G!H<#HQ
M,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L
M('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N
M(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T
M851R964O<W%L+G!H<#HV,#@*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N
M=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO
M="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G
M:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR-`IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R("+$N+S'(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`T
M"FUS9VED(")#87)R:65R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY,`IM<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")#87EM86X@27-L86YD<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3DT"FUS9VED(")#96QL(%!H;VYE(@IM<V=S='(@(LC>M.O&^2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C4*;7-G:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G<W1R("*\OR"\T[RZ(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*
M;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`BO+\@QN2U^2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C$*
M;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R("*\OR"\T[RZ(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G
M:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`BO+\@L*.PW2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R-S0*;7-G:60@(D-E;&QP:&]N92(*;7-G
M<W1R("+(WK3KQODB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I
M9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-@IM<V=I
M9"`B0V5N=&5R(@IM<V=S='(@(K"AO^ZUI2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@
M(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H
M25-/+3@X-3DM,BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV.3D*;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV,3$*;7-G:60@(D-E<G1I9FEC871E($]W;F5R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")#
M97)T:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C4R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*
M(RP@9G5Z>GD*;7-G:60@(D-H860B"FUS9W-T<B`B=D-A<F0B"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.CDV"FUS9VED(")#:&%N9V4B"FUS9W-T<B`BNJ^PYB(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,0HC+"!F=7IZ>0IM<V=I
M9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`BOL_(HR#(KL#.(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V"B,L(&9U>GIY"FUS9VED("(B
M"B)#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E
M('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB
M"FUS9W-T<B`BN-[`S\"[(+JXL[ZVIR"[Y[_KQ](@P,RXIRP@P=:\TBP@O*VX
M[<"[(+JOL.;'U;3/M-DN(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C(T"FUS9VED("(B"B)#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO
M="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@
M(@HB0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C<*(RP@9G5Z>GD*;7-G:60@(D-H87(B"FUS9W-T<B`B=D-A<F0B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C4*;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(E]KN+7%J2"PR[OG
M+BXN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B0VAI;&4B"FUS9W-T
M<B`BP::X\2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@(L'?
ML;DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,`IM<V=I9"`B0VAI;F5S
M92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#:&EN97-E(%1R861I=&EO;F%L("A"
M:6<U*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU
M<"YP:'`Z,C8Y"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*
M;7-G<W1R("*^S\BC(,BNP,XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I
M9VYU<"YP:'`Z,C8X"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@82!U<V5R;F%M
M92(*;7-G<W1R("*XWKW#P?8@P-N\NB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR.3@*;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SHB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&ES='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@
M='EP92`H9F]R(&]R9&5R960@;&ES=',I(@IM<V=S='(@(KSXO*T@N*Z]NL:N
M(,&^M_D@O+'%PR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H<FES=&UA<R!)<VQA
M;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<#HR
M.30@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@Y,PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N
M(@IM<V=S='(@(L7KP?8@N*Z]NK/*("5SP+LHN*8I(,.CP+L@O/8@OOB]P+3/
MM-DN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,30*(RP@9G5Z>GD*;7-G:60@(D-L96%R(@IM<V=S='(@(K3>M\(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED
M(")#;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(DU3O\#'Q[VZ(,77L=<@
MP?:_[+'B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.`HC+"!F=7IZ>0IM
M<V=I9"`B0VQE87(@475E<GDB"FUS9W-T<B`BL,N[]L?7N/$@P\JQXLBM(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C4*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R
M("*PR[OVQ]>X\2##RK'BR*TB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C
M;&5A<BYI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(D-L96%R('5S97(B"FUS9W-T
M<B`BL,N[]L?7N/$@P\JQXLBM(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;&ES="YI;F,Z,S0*(RP@9G5Z>GD*;7-G:60@(D-L96%R('5S97(@9&%T82(*
M;7-G<W1R("*PR[OVQ]>X\2##RK'BR*TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0HC+"!F=7IZ>0IM<V=I9"`B0VQE87)I
M;F<@3&%T92(*;7-G<W1R("*PR[OVQ]>X\2##RK'BR*TB"@HC.B!T96UP;&%T
M97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV,`IM<V=I9"`B0VQI
M8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T
M96QL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D
M+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I9"`B
M0VQO<V4@5VEN9&]W(@IM<V=S='(@(L.B(+3=L>(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(T-`HC+"!F=7IZ>0IM<V=I9"`B0VQO=61S(@IM<V=S='(@
M(KJYN^<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ-@HC+"!F=7IZ>0IM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(KJY
MN^<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M-PHC+"!F=7IZ>0IM<V=I9"`B0VQO=61Y(@IM<V=S='(@(KJYN^<B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8T"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C(S"FUS9VED
M(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@(K_>PLJXM[3K(+3=L>(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(X"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G<W1R("+'U</$P?@@
ML.:PZ"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D-O;&]M8FEA(@IM
M<V=S='(@(KOVL?(B"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]"
M;&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`B
MN_:Q\B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H
M<#HS,C0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP
M.C,R-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-3`P('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@
M(D-O;&]R(%!I8VME<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#0V"B,L(&9U>GIY"FUS9VED(")#;VQO=7(@<V5L96-T:6]N
M(@IM<V=S='(@(KRQQ<.[Y\?7.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R("*_
MK3HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30V"FUS9VED(")#
M;VQU;6X@=&ET;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR-C0*;7-G:60@(D-O;6EC<R(*;7-G<W1R(")#;VUI8W,B"@HC
M.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*(RP@9G5Z>GD*;7-G:60@(D-O;6UA
M;F0B"FUS9W-T<B`BR+B[YR(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR,`HC
M+"!F=7IZ>0IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R("+(N+OG(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"B,L(&9U>GIY
M"FUS9VED(")#;VUM96YT(@IM<V=S='(@(LBXN^<B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-@HC+"!F=7IZ>0IM<V=I9"`B0V]M
M;6]N($YA;64B"FUS9W-T<B`BP,RXISHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`HC+"!F=7IZ
M>0IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R("*[]2"XWL#/(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M
M<&%N>2(*;7-G<W1R("+(N+OG(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,Q"B,L(&9U>GIY"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`BN_4@N-[`
MSR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3<*(RP@9G5Z
M>GD*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R("*PX;?0(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR-#D*(RP@9G5Z>GD*;7-G:60@(D-O;F1I=&EO;G,B
M"FUS9W-T<B`BL.&WT"(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS
M9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#,*;7-G:60@(D-O;F9I9W5R871I
M;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T
M;&]O:RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S
M-0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,0IM<V=I9"`B0V]N9FER;2!0
M87-S=V]R9"(*;7-G<W1R("*^S\BC(,BNP,XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"B,L(&9U
M>GIY"FUS9VED(")#;VYG;R(*;7-G<W1R("*YWK3"(+OGMO<B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8U"FUS9VED(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@
M=&AE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS,3`*(RP@9G5Z>GD*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D
M+B(*;7-G<W1R("*[Z,&F(+W'QM`B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S$P"B,L(&9U>GIY"FUS9VED(")#;VYN96-T:6]N
M(&9A:6QE9#H@(@IM<V=S='(@(KOHP:8@O<?&T"(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C<Y,`HC+"!F=7IZ>0IM<V=I9"`B0V]N;F5C
M=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R
M(")F='`@O*VY]B"_K+#A(+_`M_DN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-SDR"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E
M87-O;CH@)7,@*"5S*2(*;7-G<W1R(")F='`@O*VY]B"_K+#A(+_`M_DN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-#4*(RP@9G5Z>GD*;7-G
M:60@(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@
M(F9T<""\K;GV(+^LL.$@O\"W^2XB"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I
M<W0Z,3`Q-`IM<V=I9"`B0V]N=&%C=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4S"B,L(&9U>GIY"FUS
M9VED(")#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R
M(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`BQ]>X\2!<(B5S7"*PH2#!UKS2M\^_
MH2##W["AM<>^^KW`M,^TV2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C4V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-C,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H
M<#HW.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@
M7"(E<UPB(@IM<V=S='(@(B<E<R?`QR"SN[_K(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z,CD@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C,S"B,L(&9U>GIY"FUS9VED(")#;VYT:6YU92(*;7-G<W1R("*PX;?0(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-@IM<V=I9"`B0V]O:R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@HC+"!F=7IZ>0IM<V=I9"`B0V]O
M:VEE(@IM<V=S='(@(KOU(+C>P,\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS
M9W-T<B`BNKF[YR(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8X
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@)7,B
M"FUS9W-T<B`BN^C!IB"]Q\;0(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS
M9W-T<B`BNKF[YR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*
M;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I
M9"`B0V]T92!D)TEV;VER92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HY-S8*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO
M="!01U`@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("(QL+/`QR"[];?.O^X@
MN-Z]P\'VL*$@P-:]P+3/M-DN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3`U,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(%!'4"!S
M:6=N(&UE<W-A9V4N(@IM<V=S='(@(C&PL\#'(+OUM\Z_[B"XWKW#P?:PH2#`
MUKW`M,^TV2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C,Y,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T
M(&UE<W-A9V4N(@IM<V=S='(@(KC>O</!]B#`_+S;(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT-C<*(RP@9G5Z>GD*;7-G:60@(D-O
M=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+B(*;7-G<W1R("(QL+/`QR"[
M];?.O^X@N-Z]P\'VL*$@P-:]P+3/M-DN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,B"FUS9W-T
M<B`B)7.XIB"_L;3/M-D_(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.CDV(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"B,L
M(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB
M"FUS9W-T<B`B3$1!4""\K;GV(,&BO-,@O<?&T"(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HT-3<*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!B:6YD
M('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(DQ$05`@O*VY]B#!HKS3(+W'QM`B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C$U-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HQ-S,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R("(E<[BF(+^QM,^TV3\B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#0Q"B,L(&9U>GIY"FUS9VED(")#
M;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E<B(*;7-G<W1R("),1$%0
M(+RMN?8@P:*\TR"]Q\;0(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C0X
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C
M="!T;R!S97)V97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS9W-T<B`B3$1!
M4""\K;GV(,&BO-,@O<?&T"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*
M;7-G<W1R("*^LK'BL*&TR<?1(,'6O-*WS\#,(+[XO<"TS[39+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q,C4*;7-G:60@(D-O=6QD
M(&YO="!D96-R>7!T(%!'4"!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R,@IM<V=I9"`B0V]U;&0@;F]T
M(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N
M("5S(@IM<V=S='(@(DAO<F1EL*$@N=FXH[#4(+RSP:2UQ\'V(+[*OM*]P+3/
MM-DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HS-38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DAO<F1E
ML*$@N=FXH[#4(+RSP:2UQ\'V(+[*OM*]P+3/M-DN(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU,PHC+"!F=7IZ>0IM
M<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM
M86EL(&%D9')E<W,N(@IM<V=S='(@(L#?N/BUR"#`S+C>P,\@P=:\TB(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S
M"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D
M<F5S<R!B;V]K+B(*;7-G<W1R("*^LK'BL*&TR<?1(,'6O-*WS\#,(+[XO<"T
MS[39+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-#DS"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M
M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(DUA:6YT96YA;F-E
M7U1A<VL@N/"UXB`E<\"[*+BF*2"_K2"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I
M9"`B0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R
M:6)U=&EO;B!L:7-T<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+G!H<#HX-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R("(E<[BF
M(+^QM,^TV3\B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO
M9&ER96-T+G!H<#HS,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B)7.XIB"_L;3/M-D_(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S$Y"B,L(&9U>GIY
M"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@
M:V5Y<V5R=F5R+B(*;7-G<W1R("),1$%0(+RMN?8@P:*\TR"]Q\;0(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R
M("(E<[BF(+^QM,^TV3\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8W-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HR-C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R("(E<[BF(+^QM,^TV3\B
M"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C0Q
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N
M86YC95]487-K(&UO9'5L92`E<R(*;7-G<W1R(")-86EN=&5N86YC95]487-K
M(+CPM>(@)7,@N*8@OZT@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M;W!E;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")-86EN=&5N86YC95]4
M87-K(+CPM>(@)7/`NRBXIBD@OZT@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HR,S<@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0W
M.`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-CDY"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@
M=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R("),1$%0(+RMN?8@P:*\TR"]Q\;0
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O3V)J96-T+G!H<#HR,S@*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R96%D("5S+B(*;7-G
M<W1R("(E<[BF(+^QM,^TV3\B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HX-0HC+"!F=7IZ>0IM<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H
M92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L
M;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I
M;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B
M"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(L/?L*''S[3"M:4@O\"W^;"A
M(+G?N_W'W[W`M,^TV2X@O<.]NL7;L/RXKL#:OZ&PU""UM;_RP+L@O^3#N\?/
MO<.QXB"YV;;XM,^TV2XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS,#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S0P"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,W-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS.#,*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S@Y"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,
M(@IM<V=S='(@(KZRL>*PH;3)Q]$@P=:\TK?/P,P@OOB]P+3/M-DN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-S0*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V
M92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(KZRL>*PH;3)Q]$@P=:\TK?/
MP,P@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HT.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS
M9W-T<B`BOK*QXK"AM,G'T2#!UKS2M\_`S""^^+W`M,^TV2XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0S-PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I
M<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`BOK*QXK"AM,G'T2#!UKS2
MM\_`S""^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C(R,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E
M('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R("*^LK'BL*&TR<?1(,'6
MO-*WS\#,(+[XO<"TS[39+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-30*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B2&]R9&6PH2"YV;BCL-0@O+/!I+7'P?8@OLJ^TKW`
MM,^TV2XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S='(@
M(B5SN*8@O[&TS[39/R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E
M<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")61E,@O+/!I"#!I+JXOZ&\K2`G
M<&]R="?`S""^^+W`M,^TV2XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@
M(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T
M<B`B5D93(+RSP:0@P:2ZN+^AO*T@)W!O<G0GP,P@OOB]P+3/M-DN(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ
M("5S(@IM<V=S='(@(E9&4R"\L\&D(,&DNKB_H;RM("=P;W)T)\#,(+[XO<"T
MS[39+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDU"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R
M:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*
M;7-G<W1R(")61E,@O+/!I"#!I+JXOZ&\K2`G<&]R="?`S""^^+W`M,^TV2XB
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<U"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I
M;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO
M;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L
M;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,30S"B,L(&9U>GIY"FUS9VED(")#
M;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3$1!
M4""\K;GV(,&BO-,@O<?&T"(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S
M7"(N(@IM<V=S='(@(B5SN*8@O[&TS[39/R(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM
M<V=S='(@(B5SN*8@O[&TS[39/R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<R(*;7-G<W1R(")-86EN=&5N86YC95]487-K(+CPM>(@)7/`NRBXIBD@OZT@
MO/8@OOB]P+3/M-DN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N
M9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D9;"A(+G9
MN*.PU""\L\&DM<?!]B"^RK[2O<"TS[39+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-C8*;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@
M4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C$U-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S
M97(@7"(E<UPB('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R
M(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,30Q.0HC+"!F=7IZ>0IM<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S
M='(@(K&SP:2UR""YKL#:OZTB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4V.0HC+"!F=7IZ>0IM<V=I9"`B0V]U;G1R>2(*;7-G<W1R
M("*[]2"XWL#/(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W,PHC
M+"!F=7IZ>0IM<V=I9"`B0V]U<G-E<R(*;7-G<W1R("*[]2"XWL#/(@H*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS9W-T<B`BN+BUZ;'B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X
M"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@(KBUQ:D@N+BUZ;'B(@H*
M(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY-`HC+"!F
M=7IZ>0IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R("+(WL'VQ>L@
MN_6WSB"XN+7IL>(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY,@HC+"!F=7IZ>0IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S
M(@IM<V=S='(@(KOUQOJT]2"XN+7IL>(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C(T,`HC+"!F=7IZ>0IM<V=I9"`B0W)E871O<B!097)M
M:7-S:6]N<R(*;7-G<W1R("*[Y[_KP-H@L<?'T2(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,R,S`*(RP@9G5Z>GD*;7-G:60@(D-R961I="!C87)D
M(&YU;6)E<B(*;7-G<W1R("*\_<#:(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*(RP@9G5Z>GD*
M;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`BN+BUZ;'B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C8U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM
M<V=I9"`B0W5B82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,C8*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B
MQ_;`YR"]NL6XP,\B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-#@*(RP@9G5Z
M>GD*;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B"FUS9W-T<B`BQ_;`YR!54DS`
MNB(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H
M<#HS,`HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(K&S
MP:2UR""YKL#:OZTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM
M<V=S='(@(L?VP.<@55),P+HB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S,*
M(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@57-E<G,B"FUS9W-T<B`BQ_;`YR"]
MNL6XP,\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"B,L(&9U>GIY"FUS
M9VED(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`BQ_;`YR"]NL6XP,\B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C<U"B,L(&9U>GIY"FUS
M9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S='(@(K#AM]`B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,R"FUS9VED
M(")#=7)R96YT('-T>6QE(@IM<V=S='(@(L?VP.<@O;K%N,#/(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$P.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S
M+B(*;7-G<W1R("))35`@M\ZQU[_"O<,@O</`V[7'M,(@P-N^]\"[(+RSP:3'
MU;3/M-DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`BP-JXH['B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM
M<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R("+`VKBCL>(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8X"FUS9VED(")#>7!R=7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#(*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#>7)I;&QI
M8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X-`IM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*(RP@9G5Z>GD*;7-G:60@(D-Z96-H
M(%)E<'5B;&EC(@IM<V=S='(@(K3KQ]&YSK&Y(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,2!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHU,`IM<V=I9"`B1$0B"FUS9W-T<B`B1$0B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,C@Q"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O
M<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN
M=')O+61S;BYP:'`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N
M86YC92]-86EN=&5N86YC92YP:'`Z-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@
M(L#/NK`B"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C4*(RP@9G5Z>GD*;7-G
M:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`BP,_`VB(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,R-SD*;7-G:60@(D1A=&%B87-E($QO;VMU
M<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S.3D*;7-G
M:60@(D1A=&4B"FUS9W-T<B`BLZ_"I2(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC.C$S"B,L(&9U>GIY"FUS9VED(")$871E(%)E8V5I
M=F5D(@IM<V=S='(@(KSVO<4@LZ_"I3HB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#`W"B,L(&9U>GIY"FUS9VED(")$871E('-E;&5C=&EO;B(*
M;7-G<W1R("+`VKBCL>(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,CDR(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,C(*(RP@9G5Z
M>GD*;7-G:60@(D1A>2(*;7-G<W1R("+`S[JP(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,V"FUS9VED(")$
M95]L971E($-O;'5M;B(*;7-G<W1R(")?;+^M(+OHP:8B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@IM<V=I9"`B1&5C96UB
M97(B"FUS9W-T<B`B,3*_^2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M
M8F5R<R(*;7-G<W1R("*\_<#:(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT(@IM
M<V=S='(@(K.[ONZ^LK'B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HQ.#<@;&EB+W!R969S+G!H<#HQ,3<*;7-G:60@(D1E9F%U;'0B"FUS
M9W-T<B`BL>*ZNR(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C<W"B,L(&9U>GIY"FUS9VED(")$969A=6QT($-O;&]R(@IM
M<V=S='(@(K'BNKNPJB"[Y[_K(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED
M96YT:71Y+G!H<#HY,0IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*;7-G<W1R
M("*QXKJ[(+W$NK#`VB(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-PHC
M+"!F=7IZ>0IM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R("*QXKJ[(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"B,L(&9U>GIY"FUS9VED(")$
M969I;FET:6]N<R(*;7-G<W1R("*QU,2B(,&DP,<B"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C<Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(V"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z-#,Y"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,S8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW,`HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.CDS('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3$V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,Y('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3@R"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHW,R!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3@*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$P('1E;7!L
M871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"FUS9VED(")$96QE=&4B"FUS
M9W-T<B`BN^C!IB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS,@HC+"!F=7IZ>0IM<V=I9"`B1&5L971E($-E
M;&PB"FUS9W-T<B`BO+\@N^C!IB(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DY
M(&%D;6EN+V=R;W5P<RYP:'`Z,C(W"B,L(&9U>GIY"FUS9VED(")$96QE=&4@
M1W)O=7`B"FUS9W-T<B`BN^C!IB(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(T.0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E($QO9R(*;7-G<W1R
M("+'X""[Z,&F(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW
M-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,0HC+"!F=7IZ>0IM
M<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`BN-Z]P\'V(+OHP:8B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,PHC
M+"!F=7IZ>0IM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G
M<W1R("*[Z,&FM<@@N-[`SR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3<*;7-G:60@(D1E;&5T92!C96QL(@IM
M<V=S='(@(KR_(+OHP:8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@8V]L=6UN(@IM
M<V=S='(@(K^M(+OHP:8B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T.`IM
M<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS
M(&9O<B!<(B5S7"(B"FUS9W-T<B`B)7,@L<?'T2"\]L&D(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M
M<&5R;6ES<VEO;G,_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!R
M;W<B"FUS9W-T<B`BQ^`@N^C!IB(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE
M=&5I9&5N=&ET>2YI;F,Z,34*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!S96QE
M8W1E9"!I9&5N=&ET>2(*;7-G<W1R("*]Q+JPP-H@O+'%PR(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM
M<V=I9"`B1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R("+']L#G
M(+^M(,'VO_(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R
M;W<B"FUS9W-T<B`BQ_;`YR#'X"#!]K_R(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!S971U
M<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38S"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R
M,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR-3,*(RP@9G5Z>GD*;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`B
MN^C!IB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E
M<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(K_`M_D@O+.X[2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDS."!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,P"FUS9VED(")$97-C<FEP=&EO
M;B(*;7-G<W1R("*\L[CM.B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,3DU"FUS9VED(")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL
M92DZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,3DY"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R("*\O+K.P:2ZN+"A(+#\N*[`VKBF(,"G
MQ]@@L>*WS[7'ON[!L[W`M,^TV2XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C$Y"FUS9VED(")$979E;&]P;65N="(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(Q-PIM<V=I9"`B1&5W(%!O:6YT(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDT"FUS9VED(")$97<@
M4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,C<*;7-G:60@(D1E=R!P;VEN=#H@(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L969T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O
M<GDB"FUS9W-T<B`BM?"WNL7DN*XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C8V"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_
M(@IM<V=S='(@(LBMN.D@O+/!I"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY-PIM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(LBMN.D@O+/!
MI"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HY-@HC+"!F=7IZ
M>0IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R("+(
MK;CI(+RSP:0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@U"B,L(&9U>GIY
M"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T("A4048I(@IM<V=S='(@(LBMN.D@
MO+/!I"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3<*(RP@9G5Z
M>GD*;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM<V=S='(@(LBMN.D@O+/!I"(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HQ.3`*;7-G:60@(D1I
M<W!O<VET:6]N($YO=&EF:6-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y
M"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C0R,@HC+"!F=7IZ>0IM<V=I9"`B1&\@;F]T(&1E
M;&5T92(*;7-G<W1R("*ZN;&X(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA
M;F-E+G!H<"(*;7-G<W1R(")M86EN=&5N86YC92YP:'"_H2#!]\&B(,&BL=G'
MS\'V(+BVO+R_Y"XB"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ
M,B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E<R!T
M:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L
M(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R("+#N;GXPK`@Q^#`NB#'U[CQ(,#,
MN*?`NR"PKK#M(,#6O<"TS['N/R"QU[>XM-FXZ2P@OZFQXKBF(,.\Q:G'S[R\
MO^0Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,`HC+"!F=7IZ>0IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC
M(@IM<V=S='(@(K3KQ]&YSK&Y(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHY-@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HX-#0*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(K.[M\&YWK'B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0T"B,L('!H
M<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S(@IM<V=S='(@(B5S(+.[M\&Y
MWK'B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W
M;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P-PIM
M<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,T"B,L(&9U>GIY"FUS9VED(")$<G5G<R(*;7-G<W1R
M("*Y^K>YM>DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,3,*(RP@9G5Z>GD*;7-G:60@(D4M36%I;"(*;7-G<W1R("+`I;C>P,\B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM
M<V=I9"`B14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE
M<G,@=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+VUO8FEL92YP:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<P"FUS9VED(")%8W5A9&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,S4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3$U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHW,@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS
M9VED(")%9&ET(@IM<V=S='(@(KSVP:0B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO54DN<&AP.C4P('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,C4*
M;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H<#HR,C8*(RP@9G5Z>GD*;7-G:60@
M(D5D:70@1W)O=7`B"FUS9W-T<B`BN^C!IB(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z-S8@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HQ,#`*(RP@9G5Z>GD*;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R
M("*PL\#.(+C>P,\B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W
M"B,L(&9U>GIY"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(B5S
M(+''Q]$@O/;!I"(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B
M"FUS9W-T<B`B)7,@L<?'T2"\]L&D(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P
M<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`BO+'%
MP[OGQ]<@O/;!I#HB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C,V-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S
M:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(B5S(+''Q]$@O/;!I"(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(B5S
M(+''Q]$@O/;!I"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0HC+"!F
M=7IZ>0IM<V=I9"`B161U8V%T:6]N(@IM<V=S='(@(KS2L+,B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<P"FUS9VED(")%9WEP="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C,Q,`HC+"!P:'`M9F]R;6%T"FUS9VED(")%:71H97(@
M96YA8FQE(&ET('1H96XZ("5S+"!O<B!U<V4@=&AE(&)A<VEC($A434P@=F5R
M<VEO;CH@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B16P@
M4V%L=F%D;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M96YT+BXN
M(@IM<V=S='(@(K_DO-(N+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B96TB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-CD*;7-G:60@(D5M86EL(@IM<V=S
M='(@(L#,N-[`SR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-38U('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3`*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV.`HC+"!F=7IZ>0IM
M<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R("+`S+C>P,\@P=:\TCHB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38S"B,L(&9U>GIY"FUS9VED
M(")%;6%I;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS9W-T<B`BOL_(H["A
M(,#/Q*''S\'V(+[*O<"TS[39+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Y.#D*(RP@9G5Z>GD*;7-G:60@(D5M86EL('=I=&@@8V]N9FER;6%T
M:6]N(@IM<V=S='(@(K'BQ;@@P:2ZN"(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ"FUS9VED(")%;6%I;"UT;RU335,@
M1V%T97=A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,CDX"FUS9VED(")%;6]T:6-O;G,B"FUS9W-T<B`B
MP,RX\,:\Q-PB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#(*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(&UE<W-A9V4N
M(@IM<V=S='(@(L'?O^3'T2"XWL#/(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-C(@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S=6QT
M+B(*;7-G<W1R("*PX;#Z(+[XP+TB"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+
M97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T,PIM<V=I9"`B
M16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I
M97,@:6X@=&5X=#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4Q.`IM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N
M=3\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y
M."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$Q"B,L(&9U>GIY"FUS9VED
M(")%;F0@>65A<B(*;7-G<W1R("*_WL+*N+>TZR#(KL#E(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL
M87)G92!%9&ET;W(B"FUS9W-T<B`BQNW!_;'B(,BNM.LB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C(Q"FUS9VED("(B"B)%;G1E<B!A('-E8W5R:71Y
M('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D
M('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE
M(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(R"FUS
M9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T<B`BL=>XLB!5
M4DP@P-2WPB(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HX.3$*;7-G:60@(D5N=&5R('1H92!L971T97)S(&)E;&]W.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDY(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")%<75A=&]R:6%L($=U:6YE82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%<FET<F5A(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C0U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-0HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,V('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP
M:'`Z.#(*;7-G:60@(D5R<F]R(@IM<V=S='(@(K_`M_DB"@HC.B!F<F%M97=O
M<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@S"B,L('!H<"UF
M;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z
M("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!U<&1A=&EN9R!P87-S
M=V]R9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H(&5M
M86EL(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ
M-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS
M9VED(")%=7)O<&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,S.0IM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R("(Q-;K0
M(+BVM-DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Y"B,L(&9U>GIY
M"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`B-;K0(+BVM-DB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,V(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS.#<*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B,S##
MRB"XMK39(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S."!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,SDP"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS
M9W-T<B`B-;K0(+BVM-DB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I
M;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R("*X
M\+7G(+?.L=?`SB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`*;7-G
M:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R("(S,+K0(+BVM-DB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,W(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS.#@*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R("*XQ;K0(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C0*;7-G:60@(D5X86UP;&4@
M=F%L=65S.B(*;7-G<W1R("*_N3HB"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z
M.#$@861M:6XO8VUD<VAE;&PN<&AP.C4P(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,C<*;7-G:60@(D5X96-U=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#<U"B,L(&9U>GIY"FUS9VED(")%>'!A
M;F0B"FUS9W-T<B`BN/"USB#(KL#E(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S
M:61E8F%R+FEN8SHS,@IM<V=I9"`B17AP86YD(%-I9&5B87(B"FUS9W-T<B`B
MO]["RKBWM.L@R*[`Y2(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S
M+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E
M8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I
M9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C<V"B,L(&9U>GIY"FUS9VED(")%>'!O
M;F5N="(*;7-G<W1R("*_HKVZQO?&KB(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R
M(@IM<V=S='(@(L#\L.:[]B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M-S<*;7-G:60@(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+W-Q;"YP:'`Z,C$V"FUS9VED(")&86EL
M960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`BR*^PYKRSP:0@
MP-"QXB"_P+?Y+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HW-2!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.CDX"FUS9VED(")&
M86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3$1!
M4""\K;GV(,&BO-,@O<?&T"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB
M+G!H<#HY.`HC+"!F=7IZ>0IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@
M4TU"('-E<G9E<BXB"FUS9W-T<B`B3$1!4""\K;GV(,&BO-,@O<?&T"(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C@V"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS
M9W-T<B`B3$1!4""\K;GV(,&BO-,@O<?&T"(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z-CDQ"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&
M86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(DQ$05`@O*VY]B#!
MHKS3(+W'QM`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@W
M"B,L(&9U>GIY"FUS9VED(")&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O
M;FYE8W1I;VXN(@IM<V=S='(@(DQ$05`@OZRPX2`E<R"]Q\;0(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3<@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HW,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE
M9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B3$1!4""\K;GV(,&BO-,@
MO<?&T"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8Q"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@<F5T<FEE=F4Z("5S
M(@IM<V=S='(@(DQ$05`@O*VY]B#!HKS3(+W'QM`B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`HC+"!F=7IZ>0IM<V=I9"`B
M1F%I<B(*;7-G<W1R("+'RL7-(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA
M;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*
M(RP@9G5Z>GD*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`BP-#!]B"^
MRL"Z(+C>P,\B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C,X"B,L(&9U
M>GIY"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`BP-"^[K_`L>(HP-/&
M]\:N*2"_P+?Y.B`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3@W"FUS9VED(")&87@B"FUS9W-T<B`BQM&]NB(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#D*(RP@9G5Z>GD*;7-G:60@(D9A
M>&5S(@IM<V=S='(@(L;1O;HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`R"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B,K_Y
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C`*;7-G:60@(D9E96QS($QI
M:V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(S,0IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Y"FUS9VED(")&97<@
M4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30T"FUS9VED
M(")&:65L9"!M871R:7@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S,S-`IM<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S.`IM<V=I9"`B1FEG
M;&5T(&9O;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEJ:2(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*
M(RP@9G5Z>GD*;7-G:60@(D9I;&4B"FUS9W-T<B`BP::X\2(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I
M;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N
M=#H@)7,@9FEL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0P-PIM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S='(@(L;$P,\@
ML/RXKL#:(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HV,R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*(RP@9G5Z
M>GD*;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R("+'RK7EP,RXIR(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y.34*(RP@9G5Z>GD*;7-G:60@(D9I
M;&4@<V5L96-T:6]N(@IM<V=S='(@(K'4Q*(HM_PI(+RQQ<,@O\"W^2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T.#8*(RP@9G5Z>GD*;7-G:60@
M(D9I;&4@=7!L;V%D(@IM<V=S='(@(L?*M>4B"@HC.B!F<F%M97=O<FLO0G)O
M=W-E<B]"<F]W<V5R+G!H<#HX-3D*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@
M<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z.#D*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`BQ\K%S2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`BPZ.QXB(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*(RP@9G5Z>GD*;7-G:60@(D9I
M<G-T($AA;&8B"FUS9W-T<B`BP[G&Y,#,P?8B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"B,L(&9U>GIY"FUS9VED
M(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(L.YQN3`S,'V(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U-@IM<V=I9"`B1FEX
M(')A=&EO(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,S$*;7-G:60@(D9L:7`B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(S-"!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,3`W"B,L('!H<"UF;W)M870*;7-G:60@(D9O
M;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(R"FUS9VED(")&;VYT
M($-O;&]R(@IM<V=S='(@(K';P-H@N_:Q\B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C8*
M(RP@9G5Z>GD*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O
M<G0@:6UA9V5S(@IM<V=S='(@(KKJMO._[,#ZL*$@P,P@L>*TR<"[(,'VO_C'
MS\'V(+[*O<"TS[39+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,T"FUS
M9VED(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-SD*;7-G:60@(B(*(D9O<F5C87-T($1A>7,@
M*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H
M(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@
M<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,#(*(RP@9G5Z>GD*;7-G:60@(D9O<F=O
M="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R("*^S\BC(,BNP,XB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8R"B,L(&9U>GIY"FUS9VED(")&;W)M
M<R(*;7-G<W1R("+`I\2A(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q
M"B,L(&9U>GIY"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(L+\P;8B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*(RP@9G5Z>GD*;7-G:60@(D9O<G1U
M;F4@='EP92(*;7-G<W1R("+"_,&V(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,X"B,L(&9U>GIY"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R("+"_,&V
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y"B,L(&9U>GIY"FUS9VED
M(")&;W)T=6YE<R`R(@IM<V=S='(@(L+\P;8B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#4S"B,L(&9U>GIY"FUS9VED(")&;W)U;7,B"FUS9W-T
M<B`BN-[`S\?4(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P.0HC
M+"!F=7IZ>0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`BP/RTWB(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*(RP@9G5Z
M>GD*;7-G:60@(D9R(@IM<V=S='(@(L"GQ*$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S"FUS9VED(")&<F%M
M97,B"FUS9W-T<B`BQ\&WN<#3(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PHC+"!F=7IZ>0IM<V=I
M9"`B1G)A;F-E(@IM<V=S='(@(L/KO-(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI=&%N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D9R96YC:"!'=6EA;F$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@4V]U=&AE
M<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R
M("+`I\2A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T."!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8P"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HT,#8*(RP@9G5Z>GD*;7-G:60@(D9R;VT@=&AE
M("(*;7-G<W1R("+`I\2A(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z-#@*(RP@9G5Z>GD*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS
M9W-T<B`BP/S#O""\L[CM.B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*(RP@9G5Z>GD*;7-G:60@(D9U;&P@
M3F%M92(*;7-G<W1R("+`S+BG.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D=A8F]N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME
M(&EM86=E(&9R;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED(")'86QL
M97)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'86UB:6$B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO
M;B(*;7-G<W1R("*XWL#/(+RMN?8@P:2ZN+OGQ]<B"@HC.B!T96UP;&%T97,O
M861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I9"`B1V5N97)A=&5D($-O
M9&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1V5O<F=I82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")'97)M86YY(@IM<V=S='(@(K6V
MP,\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDS(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<U"B,L(&9U>GIY"FUS9VED(")':&%N82(*;7-G<W1R
M("+!W[&Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<U"B,L
M(&9U>GIY"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(L?*M>7`S+BG(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3(*;7-G:60@(D=O(@IM<V=S
M='(@(K"AL>(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@
M(D=O961E;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3$R.`HC+"!F=7IZ>0IM<V=I9"`B1V]O9VQE($UA
M<',B"FUS9W-T<B`BL,N[]L?7N/$@P\JQXLBM(@H*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HT,0HC+"!F=7IZ>0IM<V=I9"`B1V]O9VQE(%-E87)C:"(*
M;7-G<W1R("*PR[OVQ]>X\2##RK'BR*TB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,W"FUS9VED(")'<F%Y<V-A;&4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965C92(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B1W)E96L@*$E3
M3RTX.#4Y+3<I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*(RP@9G5Z>GD*;7-G
M:60@(D=R965N;&%N9"(*;7-G<W1R("+`T,'V(+[*P+H@N-[`SR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S0*(RP@9G5Z>GD*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`BP-#!]B"^
MRL"Z(+C>P,\B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W.0HC+"!F=7IZ>0IM
M<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`BL/RXKB(*"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"YP:'`Z-3D@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C$V.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B
M92!N;VXM96UP='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C,P-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(L#3O<.ZN+#\Q]0@P/K`
MY2"_P+?Y+B"\K;GVP,<@O\"W^2"XWKW#P?8Z("5S(@H*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q."!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HT,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD
M87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS9W-T<B`B5D93(,;$
MP,\@)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,S@@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C,W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U
M<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S$T(&QI8B]";&]C
M:R]G;V]G;&4N<&AP.C,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3<W"FUS9VED(")'<F]U<',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.CDV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I
M9"`B1W5A9&5L;W5P92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PHC+"!F=7IZ
M>0IM<V=I9"`B1W5A;2(*;7-G<W1R("(VO_DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.CDX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I
M9"`B1W5A=&5M86QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@
M(K6VP,\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(R-B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"B,L(&9U>GIY"FUS9VED(")'
M=65S="!097)M:7-S:6]N<R(*;7-G<W1R("*XWKW#P?8@N^C!IB(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S`*(RP@9G5Z>GD*;7-G:60@(D=U
M97-T8F]O:R(*;7-G<W1R("+!UKS2M\\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"B,L(&9U>GIY
M"FUS9VED(")'=6EN96$B"FUS9W-T<B`B-K_Y(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"B,L
M(&9U>GIY"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(C:_^2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW.`HC+"!F=7IZ>0IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(C:_
M^2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDV,`IM<V=I9"`B2%1-
M3"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R
M969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T
M;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@W"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E
M;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z,34W"B,L(&9U>GIY"FUS9VED
M(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`BN^C!
MIB"]Q\;0(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(86ET:2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@
M(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"B,L(&9U>GIY"FUS9VED(")(87IE
M(@IM<V=S='(@(L?LM>6V\\#.(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z.3$Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S(*(RP@9G5Z>GD*
M;7-G:60@(DAE861E<B(*;7-G<W1R("+'[+7EMO/`SB(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-C$*(RP@9G5Z>GD*;7-G
M:60@(DAE861E<G,B"FUS9W-T<B`BQ^RUY;;SP,XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*
M;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR,PIM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX
M+4DI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*;7-G<W1R("*S
M],#,(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$W.2!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3@V"B,Z('-E<G9I8V5S
M+VAE;'`O:6YD97@N<&AP.C$W('1E;7!L871E<R]H96QP+VEN9&5X+FEN8SHS
M"FUS9VED(")(96QP(@IM<V=S='(@(K6UO_*XNR(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I
M;F<@961I=&]R(@IM<V=S='(@(K6UO_*XNR(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$S-S$*(RP@9G5Z>GD*;7-G:60@(DAE;'!E<B(*;7-G<W1R
M("*UM;_RN+LB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,CD*(RP@9G5Z>GD*
M;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`BM;6_\KB[(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@
M9FEL93HB"FUS9W-T<B`BQL3`S\#'(+W#P-O`S""TV<"]L/H@L+"]P+3/M-DZ
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*
M(RP@9G5Z>GD*;7-G:60@(DAI9V@B"FUS9W-T<B`BL_3`S"(*"B,Z('1E;7!L
M871E<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M;6]N
M+6AE861E<BYI;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B2&]?;64B"FUS9W-T<B`B
M2&]R9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")(;VQY(%-E92`H5F%T:6-A
M;B!#:71Y(%-T871E*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C$U,S4*(RP@9G5Z>GD*;7-G:60@(DAO;64B"FUS9W-T<B`B
M2&]R9&4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3(R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ-34*;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R("+!_2#!UKS2(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8T"B,L(&9U>GIY"FUS9VED(")(
M;VUE($1I<F5C=&]R>2(*;7-G<W1R("*U\+>ZQ>2XKB(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3`*;7-G:60@(DAO;64@
M4&AO;F4B"FUS9W-T<B`BP?T@P/S(K;GXR*,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G
M:60@(DAO;F1U<F%S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B
M2&]N9R!+;VYG(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HV-0IM<V=I9"`B2&]R9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C0T,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E
M9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0S-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y
M<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-3`*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E
M<R!<(B5S7"(B"FUS9W-T<B`BN-[`S\?4(%PB)7-<(L#,(%PB)7-<(K?.(+JO
ML.:UQ[[ZO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,C(S"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN
M92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C4P,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N
M97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-#<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB
M)7-<(CH@)7,B"FUS9W-T<B`BN-[`S\?4(%PB)7-<(L#,(%PB)7-<(K?.(+JO
ML.:UQ[[ZO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M-#<T"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q.3,*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")<(B5S
M7"(@N-[`S\?4P+L@N^>_Z\?5M,^TV2XB"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C$S,S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*
M;7-G<W1R(")<(B5S7"(@N-[`S\?4P+L@N^>_Z\?5M,^TV2XB"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M-`IM<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(KSVQO*\L2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G
M:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R("*PH;?.(,.DO_(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Q"FUS
M9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R("*PH;?..B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I
M9"`B2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y
M;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`BQ]7$H;#M(+W-P+H@OZW`QR"\
M]B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(
M;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`B
MQ]>X\2B_K2G`QR"\]C\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N>2!R;W=S('=O
M=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R("+'U<2AL.T@O<W`NB#'
MX,#'(+SV(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,"!L
M:6(O0FQO8VLO;65T87(N<&AP.C(S,`IM<V=I9"`B2'5M:61I='DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U.0IM<V=I
M9"`B2'5M:61I='DZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<R(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER<W%L+G!H<#HR,S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DE-
M05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(KC>P,\@
MP/RTWB"_P+?Y.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP
M.C(Q-"!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,CDU"B,L('!H
M<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N
M<&AP.C$W.2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C0R"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@
M8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("*XWL#/(,#\M-X@O\"W^3HB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S$V"B,L(&9U>GIY"FUS
M9VED("))4"!!9&1R97-S(@IM<V=S='(@(L'6O-(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VEP8F%S:6,N<&AP.C<W"B,L(&9U>GIY"FUS9VED("))4"!!
M9&1R97-S(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(L#,O^NPH;3)Q]$@O+'%
MP[OGQ]?`S""^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP
M8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL
M;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@(DE0(&QO
M8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED("))
M7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B7VZ^U;^A(,?@(,/?L*$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#(*(RP@9G5Z>GD*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B
MP-#!]B"^RL"Z(+C>P,\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<V
M"FUS9VED("))8V]N<R!/;FQY(@IM<V=S='(@(K[&P,S$W"(*"B,Z('5T:6PO
M:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B26-O;G,@9F]R("5S(@IM<V=S='(@(B5SOZ&PU""\TK"S(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,W-PIM<V=I9"`B26-O;G,@=VET:"!T97AT
M(@IM<V=S='(@(K[&P,S$W+#Z(+FNP-HB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3DP"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@(KW$
MNK#`VB#`S+BG.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C4Y,@HC+"!P:'`M9F]R;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES
M<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD
M;W<N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-34*
M;7-G:60@(B(*(DEF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN
M=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI
M<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W
M,PIM<V=I9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM
M86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*
M(F1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR.`IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T<B`BL=>XLB"YS+BN
MNKBQXCHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,W"FUS9VED("));6%G92!54DPB"FUS9W-T<B`BL=>XLB!5
M4DPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM86=E(%523#HB"FUS9W-T<B`BL=>X
MLB!54DPZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A;&QE
M<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W
M-C$*(RP@9G5Z>GD*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R("+'RK7E
M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@
M(DEM86=E<R(*;7-G<W1R("*QU[BR(%523"(*"B,Z('1E;7!L871E<R]D871A
M+W1S=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-PHC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4T('1E;7!L871E<R]D871A
M+V-S=FEN9F\N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DEM
M<&]R="P@4W1E<"`E9"(*;7-G<W1R("*PH<&NO\"QXBP@M-RPZ"`E<R(*"B,Z
M('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*
M;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R("*PH<&NO\(@Q]>X
M\3H@)7,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C8U"FUS9VED
M("));7!O<G1E9"!F:65L9',Z(@IM<V=S='(@(K"AP:Z_PB#'U[CQ.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS,`IM<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T<B`B7W.TV<"]
MOZ$@Q^`@P]^PH2(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z
M:7`N<&AP.C$S-0IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S,@HC+"!F=7IZ>0IM<V=I9"`B26YC;W)R96-T('5S
M97)N86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`BN^>_Z\#:P,RXI[#Z
M(+[/R*.XIB#`U+?"Q\^\O+_D(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z-3$*(RP@9G5Z>GD*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M
M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@
M>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L
M<"XB"FUS9W-T<B`B(@HBP]^PH<?/M,*UI2"_P+?YL*$@N=^[_<??O<"TS[39
M+B"]P[VZQ=NP_+BNP-J_H;#4(+6UO_+`NR"_Y,.[Q\^]P['B(+G9MOBTS[39
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C$*;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R("*UZ;^IOK*QXB(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,0HC+"!F=7IZ>0IM<V=I9"`B26YD:6$B"FUS9W-T<B`B
MOOC`O2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C4T('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS9VED("));F1I=FED=6%L
M(%5S97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`HC+"!F=7IZ>0IM<V=I
M9"`B26YD;VYE<VEA(@IM<V=S='(@(K[XP+TB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"B,L(&9U>GIY"FUS9VED("))
M;F9O(@IM<V=S='(@(KFKO<,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C4W"B,L(&9U>GIY"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R("+!
MI+JX(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,S,`HC+"!F
M=7IZ>0IM<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB
M"FUS9W-T<B`BP,R_Z["AM,G'T2"\L<7#N^?'U\#,(+[XO<"TS[39+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS-0IM<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B"FUS9W-T<B`B7V^T
MV<"]OZ$@OZT@P]^PH2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B26YS97)T($EM86=E
M(@IM<V=S='(@(K'7N+(@P]^PH2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G
M<W1R("+'I2##W["A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E8B!,:6YK(@IM<V=S='(@
M(L"E(+BUQ:D@P]^PH2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T(%]#;VQU;6X@
M0F5F;W)E(@IM<V=S='(@(E]COM6_H2"_K2##W["A(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED
M("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*
M;7-G<W1R("+']L#G(+^M(+7:OZ$@N_4@OZT@P]^PH2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I
M9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE
M(@IM<V=S='(@(L?VP.<@OZT@OM6_H2"[]2"_K2##W["A(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R"FUS
M9VED("));G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(*
M;7-G<W1R("+']L#G(,?@(+7:OZ$@N_4@Q^`@P]^PH2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I
M9"`B26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM
M<V=S='(@(L?VP.<@Q^`@OM6_H2"[]2#'X"##W["A(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C<P"FUS9VED
M("));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(*
M;7-G<W1R("+']L#G(,'VP:$@M=J_H2"TW+;T(,/?L*$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G
M:60@(DEN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D
M92(*;7-G<W1R("+']L#G(,'VP:$@OM6_H2"TW+;T(,/?L*$B"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C$U,`HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(&%L
M=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("*TZ\.\(+';(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(S.0IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D
M9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O
M<F0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R
M(@IM<V=S='(@(K7:OZ$@O+\@P]^PH2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R="!C
M96QL(&)E9F]R92(*;7-G<W1R("*^U;^A(+R_(,/?L*$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED
M("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@(K7:OZ$@OZT@P]^PH2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C4*;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(K[5
MOZ$@OZT@P]^PH2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.CDP"B,L(&9U>GIY"FUS9VED("));G-E<G0@;65S<V%G97,B"FUS
M9W-T<B`BR+B]Q<?1(+C>P,\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G:60@(DEN<V5R="!P87)A
M9W)A<&@@869T97(B"FUS9W-T<B`BM=J_H2"TW+;T(,/?L*$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*
M;7-G:60@(DEN<V5R="!P87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@(K[5OZ$@
MM-RV]"##W["A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(')O=R!A9G1E<B(*;7-G
M<W1R("*UVK^A(,?@(,/?L*$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E
M9F]R92(*;7-G<W1R("*^U;^A(,?@(,/?L*$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C,P"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E
M<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@
M(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`BL=>XLB##W["A+[SVP:0B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y
M"FUS9VED("));G-E<G0O36]D:69Y($QI;FLB"FUS9W-T<B`BN+7%J2##W["A
M+[SVP:0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T,PIM<V=I9"`B26YS=69F:6-I96YT(&-R961I="!T;R!S96YD
M('1O('1H92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G
M:60@(DEN<W5F9FEC:65N="!C<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$P-S4*(RP@9G5Z>GD*;7-G:60@(DEN=&5G
M97(B"FUS9W-T<B`BL*&_[K6E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3$S,PIM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM
M<V=I9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z
M,3<P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(P
M,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,3`*
M(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`BP-^X
M^+7((,#,N*<N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`HC+"!F
M=7IZ>0IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`BP-^X
M^+7((,#,N*<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$R"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&)A=&-H
M($E$+B(*;7-G<W1R("+`W[CXM<@@P,RXIRXB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,#@W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-3@*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(S,B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,CDY"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T
M86)L97-E="YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@9&%T82!S
M=6)M:71T960N(@IM<V=S='(@(L#?N/BUR"#`S+BG+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,`HC+"!F=7IZ
M>0IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R
M("+`W[CXM<@@P,RXWL#/(,'6O-(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O9&)X+G!H<#HX,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M
M<')E<W,O9&)X+G!H<#HQ,#`*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+V1B>"YP:'`Z,C(P"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&9I;&4@
M9F]R;6%T(@IM<V=S='(@(L#?N/BUR"#`S+BG+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-S<*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@
M;&EC96YS92!K97DN(@IM<V=S='(@(L#?N/BUR"#`S+BG+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S$*(RP@9G5Z>GD*;7-G:60@(DEN
M=F%L:60@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(L#?N/BUR"#`S+BG
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P-PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS
M9W-T<B`BP-^X^+7((,#,N*<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S"B,L(&9U>GIY"FUS9VED("));G9A
M;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*;7-G<W1R("+`W[CXM<@@P,RXIRXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.38*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A
M;65T97)S+B(*;7-G<W1R("+`W[CXM<@@P,RXIRXB"@HC.B!A9&UI;B]P97)M
M<R]A9&1C:&EL9"YP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@<&%R
M96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(L#?N/BUR"#!UKS2M\\B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<S"B,L(&9U>GIY"FUS9VED
M("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(L#?N/BUR"#!UKS2M\\B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<U"B,L(&9U>GIY
M"FUS9VED("));G9A;&ED('!R;V1U8W0@8V]D92XB"FUS9W-T<B`BP-^X^+7(
M(,'6O-*WSR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P-@HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!P<F]T;V-O
M;"XB"FUS9W-T<B`BP-^X^+7((,'6O-*WSR(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HW,2!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L
M:60@<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HQ,#<V(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z,3(V,@HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B
M"FUS9W-T<B`BP-^X^+7((,#,N*<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"B,L(&9U>GIY"FUS9VED("))
M;G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R("+`W[CXM<@@P,RXWL#/
M(,'6O-(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,3$*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D
M871A+B(*;7-G<W1R("+`W[CXM<@@P,RXIRXB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S4W"FUS9VED("));G9E;G1O<GDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.0HC
M+"!F=7IZ>0IM<V=I9"`B26YV97)T('-E;&5C=&EO;B(*;7-G<W1R("+`VKBC
ML>(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#(*(RP@9G5Z>GD*;7-G:60@(DER86XL($ES;&%M
M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`BM.O'T;G.L;DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#$*;7-G:60@(DER87$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"B,L(&9U
M>GIY"FUS9VED("))<F5L86YD(@IM<V=S='(@(L#0P?8@OLK`NB"XWL#/(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@
M;V8@36%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(T"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#`*(RP@9G5Z>GD*;7-G:60@(DES<F%E;"(*
M;7-G<W1R("+`T,'V(+[*P+H@N-[`SR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-C(U"FUS9VED("))<W-U97(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS
M9VED("))=&%L:6,B"FUS9W-T<B`BL>*_[\#,L>(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*
M(RP@9G5Z>GD*;7-G:60@(DET86QY(@IM<V=S='(@(L#/NK`B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,0HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB
M"FUS9W-T<B`B,;_Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*87!A;B(*;7-G
M<W1R("+`S[J[(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*;7-G:60@
M(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`BP,^ZN[[N("A)4T\M
M,C`R,BU*4"DB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`IM
M<V=I9"`B(@HB2F%V87-C<FEP="!H87,@8F5E;B!D:7-A8FQE9"!O;B!Y;W5R
M(&)R;W=S97(@86YD('1H:7,@<&%G92!M87D@;F]T(&)E("(*(F1I<W!L87EI
M;F<@8V]R<F5C=&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R,@IM<V=I9"`B2F5R<V5Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,PIM<V=I9"`B2F]R9&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#<*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM
M<V=S='(@(C>_^2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S='(@(C:_^2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G
M:60@(DIU<W1I9GDB"FUS9W-T<B`BP:2WQ"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$U"FUS9VED(")*=7-T
M:69Y($-E;G1E<B(*;7-G<W1R("*PH;_NM:4@P:2WQ"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$W"FUS9VED
M(")*=7-T:69Y($9U;&PB"FUS9W-T<B`BON?"RB#!I+?$(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G
M:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R("*_WL+*(,&DM\0B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM
M<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R("*_P+BEPLH@P:2WQ"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C8T"FUS9VED
M(")+965P(&]R:6=I;F%L/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G
M:60@(DME;GEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0R"FUS9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*(RP@9G5Z>GD*
M;7-G:60@(DME>2!#<F5A=&EO;B(*;7-G<W1R("+$N+S'(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R
M<')I;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N9W1H(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y(%1Y
M<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.3@*(RP@9G5Z>GD*;7-G:60@(DME>2!5<V%G92(*;7-G<W1R("*X
MWKW#P?8B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW-#`*
M(RP@9G5Z>GD*;7-G:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B
M;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B9G1P(+RMN?8@OZRPX2"_P+?Y+B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(DMI<FEB871I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-0HC+"!F=7IZ>0IM<V=I9"`B2V]R96$L($1E;6]C
M<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`BM.O'T;G.L;DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G
M<W1R("*TZ\?1N<ZQN2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS
M9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`BQ]&QN;[N("A%54,M2U(I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@V"FUS9VED(")+=7=A:70B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@S"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P;W)T86PO;65N=2YI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B3&%?
M>6]U="(*;7-G<W1R("*WSK'7OL:_]"(*"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(K[PONXB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E
M<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-CD*
M(RP@9G5Z>GD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R("*XML'VN+<@QN3`
MS,'V(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<V"B,L(&9U>GIY"FUS
M9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R("*^S\BC(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX.`HC
M+"!F=7IZ>0IM<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@(KBVP?:XMR#&
MY,#,P?8B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U,0HC+"!F=7IZ>0IM
M<V=I9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R("*XML'VN+<@QN3`S,'V(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*
M;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(KBVP?:XMR"WSK'7P,XZ
M("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S(Q"B,L('!H<"UF
M;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T<B`B
MN+;!]KBW(+?.L=?`SCH@)7,L(,&BO-,@P*?$H3H@)7,B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+G!H<#HW,38*;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R
M(@IM<V=S='(@(KBVP?:XMR"WSK'7P,XZ(+[XP+TB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*
M(RP@9G5Z>GD*;7-G:60@(DQA='9I82(*;7-G<W1R("*XN+7IL>(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*;7-G:60@(DQA=R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-SD*;7-G:60@(DQA>6]U="(*;7-G<W1R("*WN<#,OL:_]"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@
M(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@W"FUS9VED("),96)A;F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B
M3&5F="(*;7-G<W1R("*_WL+*(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S$Q.0HC+"!F=7IZ>0IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B
MO[DZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-0HC+"!F=7IZ
M>0IM<V=I9"`B3&5F="!V86QU97,B"FUS9W-T<B`BO[DZ(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@X"FUS9VED("),97-O=&AO(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B3&5V96PB"FUS
M9W-T<B`BP,RUOR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EB97)I82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H
M:7)I>6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:65C:'1E
M;G-T96EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(U"B,L(&9U>GIY"FUS9VED("),:6=H="!$<FEZ>FQE
M(@IM<V=S='(@(K?.L=?`SB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(V"B,L(&9U>GIY"FUS9VED("),:6=H="!286EN(@IM
M<V=S='(@(K?.L=?`SB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(W"B,L(&9U>GIY"FUS9VED("),:6=H="!286EN($5A<FQY
M(@IM<V=S='(@(K?.L=?`SB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(X"B,L(&9U>GIY"FUS9VED("),:6=H="!286EN($QA
M=&4B"FUS9W-T<B`BM\ZQU\#.(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,CD*(RP@9G5Z>GD*;7-G:60@(DQI9VAT(%)A:6X@
M4VAO=V5R(@IM<V=S='(@(K?.L=?`SB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,P"B,L(&9U>GIY"FUS9VED("),:6=H="!2
M86EN('=I=&@@5&AU;F1E<B(*;7-G<W1R("*WSK'7P,XB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,0HC+"!F=7IZ>0IM<V=I
M9"`B3&EG:'0@4VYO=R(*;7-G<W1R("*WSK'7P,XB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B3&EG:'0@4VYO
M=R!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0U"FUS9VED("),:6UE<FEC:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#$T"B,L(&9U>GIY"FUS9VED("),:6YK(@IM<V=S
M='(@(K?.L=?`SB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B3&EN:R!P;VEN=',@=&\Z(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S4*;7-G
M:60@(DQI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G
M92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E
M>'1?1FEL=&5R+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,PHC+"!F=7IZ>0IM
M<V=I9"`B3&EN:W,B"FUS9W-T<B`BM\ZQU\#.(+W#P-O`V[[W(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0V"B,L(&9U>GIY"FUS9VED("),:6YU>"!#
M;V]K:64B"FUS9W-T<B`BN_4@N-[`SR(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T("T@=7-E<B!C86X@
M<V5E('1H92!F;VQD97(B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$S,PHC+"!F=7IZ>0IM<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T
M<B`BN+;!]KBW(,;DP,S!]B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP
M.C4P"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(K6UO_*^RR"X
M\<+W(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,@HC+"!F=7IZ>0IM<V=I
M9"`B3&ES="!486)L97,B"FUS9W-T<B`BN+;!]KBW(,;DP,S!]B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DT"B,L(&9U>GIY"FUS
M9VED("),:7-T+4%R8VAI=F4B"FUS9W-T<B`BN^>_Z\?/P?8@OLJTPB"XWL#/
MQ]0@O/NQZ"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z
M-3@Y"B,L(&9U>GIY"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`BM;6_\K[+
M(+CQPO<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y
M-@HC+"!F=7IZ>0IM<V=I9"`B3&ES="U)9"(*;7-G<W1R("*UM;_ROLL@N/'"
M]R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DR"B,L
M(&9U>GIY"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@(K6UO_*^RR"X\<+W
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3,*;7-G
M:60@(DQI<W0M4&]S="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4Y,0HC+"!F=7IZ>0IM<V=I9"`B3&ES="U3=6)S
M8W)I8F4B"FUS9W-T<B`BN^>_Z\?/P?8@OLJTPB"XWL#/Q]0@O/NQZ"(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DP"B,L(&9U>GIY
M"FUS9VED("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(KOGO^O'S\'V(+[*
MM,(@N-[`S\?4(+S[L>@B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@<V5S<VEO;G,@9F%I
M;&5D.B`E<R(*;7-G<W1R("*[Y[_KQ](@O/8@OOBTPB"[Y[_KP-H@N/&WSRXB
M"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S4*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R("*[
MY[_KQ](@O/8@OOBTPB"[Y[_KP-H@N/&WSRXB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@
M9&ES86)L960N(@IM<V=S='(@(KOGO^O'TB"\]B"^^+3"(+OGO^O`VB"X\;?/
M+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-PHC+"!F=7IZ>0IM<V=I
M9"`B3&ET97)A='5R92(*;7-G<W1R("*\K;CM.B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0HC
M+"!F=7IZ>0IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(K/*NO$@M-S`IR(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.#,*
M;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Q,0HC+"!F=7IZ>0IM<V=I9"`B3&]C86P@=&EM
M93H@(@IM<V=S='(@(KW'Q^`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#,*;7-G:60@(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,2!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-C0*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R
M(&QI8B]";&]C:R]M971A<BYP:'`Z-C4*(RP@9G5Z>GD*;7-G:60@(DQO8V%T
M:6]N(@IM<V=S='(@(KW'Q^`B"@HC.B!L;V=I;BYP:'`Z,3<R('-E<G9I8V5S
M+W!O<G1A;"]S:61E8F%R+G!H<#HQ.3$@=&5M<&QA=&5S+VQO9VEN+VUO8FEL
M92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-2!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDP"FUS9VED("),;V<@:6XB"FUS9W-T
M<B`BM\ZQU\#.(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U
M"FUS9VED("),;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.#4*;7-G:60@
M(DQO9R!O=70B"FUS9W-T<B`BM\ZQU[[&O_0B"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(DQO9VEN(@IM<V=S='(@(K?.
ML=?`SB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<*;7-G:60@(DQO
M9VEN(%1A<VMS(@IM<V=S='(@(K?.L=?`SB"]P\#;P-N^]R(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.CDY-@HC+"!F=7IZ>0IM<V=I9"`B3&]G:6X@
M9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@
M96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B(@HBONZVLB#`S,"OM\X@
MM\ZQU\#.P,P@O<?&T,??O<"TS[39+B"TZ[K.NM#`QR"PYK_L(+OGO^O`VB#`
MS+BG(+;'M,(@OL_(H["A(,#?(@HBN/@@P-2WPK7((+#FO^P@N=^[_<?5M,^T
MV2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.3(*(RP@9G5Z>GD*
M;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`BN^C!IB"]Q\;0(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-0HC+"!F=7IZ>0IM<V=I9"`B
M3&]N9R!T97AT(@IM<V=S='(@(K?.L=>^QK_T(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0X"B,L(&9U>GIY"FUS9VED("),;W9E(@IM<V=S='(@(L#,
MM;\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M-PIM<V=I9"`B3&]W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R
M(&=R965K(&QE='1E<G,B"FUS9W-T<B`BL=>XKKVZ(+S2N:[`VB(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`BMO/&OB"\
MTKFNP-HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C$W"FUS9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM
M<V=S='(@(K?.N+8@O-*YKL#:(+S]P-HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@
M(DQU>&5M8F]U<F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P,`HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#,X('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P
M"FUS9VED(")-32(*;7-G<W1R(")-32(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR.#$*;7-G:60@(DU/5$0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*(RP@9G5Z>GD*;7-G
M:60@(DU3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS
M9W-T<B`BQL3`S[^A(+[&N:NWL2#`VK?AL*$@OOB]P+3/M-DN(@H*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B
M:6QE+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B35-'(@IM<V=S='(@(D-64R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,@HC+"!F=7IZ>0IM<V=I9"`B36%C86\B"FUS9W-T<B`B
M,[_Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M
M97(@675G;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDP"FUS9VED(")-861A9V%S8V%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT.0HC+"!F=7IZ>0IM<V=I9"`B36%G:6,B"FUS9W-T
M<B`BP*6XWL#/(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Q"FUS
M9VED(")-86EL(@IM<V=S='(@(KC>P,\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-3(R"FUS9VED(")-86EL($%D;6EN(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R(")?:[BUQ:D@N+BU
MZ;'B+BXN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDT"B,L(&9U>GIY"FUS9VED(")-86QA=VDB
M"FUS9W-T<B`BP*6XWL#/(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"B,L(&9U>GIY"FUS9VED
M(")-86QA>7-I82(*;7-G<W1R("+`I;C>P,\B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$V-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*(RP@
M9G5Z>GD*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(KC>P,\@Q\K%S2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY,@HC+"!F=7IZ>0IM<V=I9"`B36%L:2(*;7-G<W1R("+`I;C>
MP,\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DUA;'1A(@IM<V=S
M='(@(L"EN-[`SR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,0IM<V=I
M9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@
M=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D
M('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-3,*;7-G:60@(DUA
M<#(T(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3`X-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3$V.`IM<V=I9"`B36%P475E<W0@;6%P(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I
M9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#$*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS
M9W-T<B`B,[_Y(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT,0IM<V=I9"`B36%R9VEN(@IM<V=S='(@(K"AP.7`
MVKBN(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.#@*;7-G:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX
M.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N
M="]!;G-W97)E9"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-
M87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PHC+"!F
M=7IZ>0IM<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R("*PH<#EP-JXKB(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")-871C:&EN
M9R!F:65L9',B"FUS9W-T<B`BP,_$H<?/M,(@Q]>X\2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,38P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,PHC+"!F=7IZ>0IM<V=I9"`B36%U<FET86YI82(*;7-G<W1R("*PH<#EP-JX
MKB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#@*(RP@9G5Z>GD*;7-G:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D
M+B(*;7-G<W1R("*XWKW#P?8@Q]>X\2(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S`V"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3@*;7-G:60@(DUA>"!T
M96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP
M.C@V"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y."!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$W"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R,SD*;7-G:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#4*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS
M9VED(")-87DB"FUS9W-T<B`B-;_Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PHC+"!F=7IZ
M>0IM<V=I9"`B36%Y;W1T92(*;7-G<W1R("(UO_DB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(DUE9&EC:6YE(@IM<V=S
M='(@(KOHP::UR""XWL#/(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E
M9&ET+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B365M8F5R<R(*;7-G<W1R("(Q
M,;_Y(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.`IM<V=I9"`B365N
M=2!M;V1E.B(*;7-G<W1R("*XWK2Z(+CPM>4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G
M92!C96QL<R(*;7-G<W1R("*\OR#'U<2AL>(B"@HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S
M<V%G92(*;7-G<W1R("*XWKW#P?8B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3
M=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L
M9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`HC+"!F=7IZ
M>0IM<V=I9"`B365S<V%G92!E>'!I<F5D+B(*;7-G<W1R("*XWKW#P?8@Q]>X
M\2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-38Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C`R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(R-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR-C`*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@='EP
M92(*;7-G<W1R("*XWKW#P?8@P,_`VB(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,PIM<V=I9"`B365T87(@5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,W"B,L(&9U>GIY"FUS9VED(")-971A<B!B;&]C
M:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("+`S+_KL*&TR<?1(+RQQ<.[Y\?7
MP,P@OOB]P+3/M-DN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3(*(RP@
M9G5Z>GD*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E
M=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N
M(@IM<V=S='(@(KR\NL[!I+JXL*$@L/RXKL#:N*8@P*?'V""QXK?/M<>^[L&S
MO<"TS[39+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C4*
M;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-R!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<T"FUS9VED(")-971H
M;V0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H
M<#HX,2!F<F%M97=O<FLO4E!#+U)00R]S;V%P+G!H<#HQ,3<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]R97-T+G!H<#HX,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M
M971H;V0Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HW-"!L:6(O0FQO8VLO;65T87(N<&AP.C<U"FUS9VED(")-971R
M:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-97AI8V\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O;F5S:6$L($9E9&5R
M871E9"!3=&%T97,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"FUS9VED(")-:61D;&4B
M"FUS9W-T<B`BL*&_[K6E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,`IM<V=I9"`B36EN('1E;7`@;&%S
M="`R-"!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S`R"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0S.0IM<V=I
M9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C,T"B,L(&9U>GIY"FUS9VED(")-:7)R;W(B"FUS9W-T<B`BO\"W
M^2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM<V=I9"`B36ES8V5L
M;&%N96]U<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8W,@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#`*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P
M86-K86=E($A45%!?4F5Q=65S="XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$Q-0IM<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T
M:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@
M=&\@=7-E('1H:7,@(@HB87!P;&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`HC
M+"!F=7IZ>0IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R("*X
MWKW#P?8@P,RUO\?/L>(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D
M869O;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E
M9"!014%2('!A8VMA9V4@36%I;"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDT"B,L(&9U>GIY
M"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM<V=S='(@(KC>O</!]B#`
MS+6_Q\^QXB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-38*(RP@9G5Z>GD*;7-G:60@(DUO(@IM<V=S='(@(L#,M;\B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S0*(RP@9G5Z>GD*;7-G:60@
M(DUO8FEL92!-86EL(@IM<V=S='(@(KOU(+C>P,\B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B36]D97)A=&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HV-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<S
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#@*;7-G
M:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4S"FUS9VED(")-
M;V1I9GD@55),(@IM<V=S='(@(E523""\]L&D(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S,*(RP@9G5Z>GD*;7-G:60@(DUO9'5L
M=7,B"FUS9W-T<B`BOZK'TB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`HC+"!F=7IZ>0IM<V=I
M9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`BM.O'T;G.L;DB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3`*(RP@9G5Z>GD*;7-G:60@(DUO;F%C;R(*;7-G<W1R("(S
MO_DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.30*;7-G:60@(DUO;G1H
M(&%N9"!Y96%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC
M92]-86EN=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`B
MN,6_^2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$W,B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HR-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!F:65L9',@
M9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS
M9VED(")-;W-T;'D@0VQE87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*(RP@9G5Z>GD*;7-G:60@(DUO
M<W1L>2!#;&]U9'DB"FUS9W-T<B`BNKF[YR(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z-3`Y"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`BOL:WH;?.(,#,M;\B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,3,*(RP@
M9G5Z>GD*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R("+`I[?.(,#,M;\B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,3<*(RP@9G5Z
M>GD*;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`BO\"XI<+*(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`U"FUS9VED(")-;W9E
M(%5P(@IM<V=S='(@(L"GM\X@P,RUOR(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HU,C0*(RP@9G5Z>GD*;7-G:60@(DUO=F4@
M9&]W;B(*;7-G<W1R("*^QK>AM\X@P,RUOR(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HU,C,*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`HC+"!F=7IZ>0IM<V=I9"`B36]V
M92!U<"(*;7-G<W1R("+`I[?.(,#,M;\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@
M(DUO>F%M8FEQ=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C$X-`IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,#4U"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T,@HC+"!F=7IZ>0IM
M<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@(K'4Q*(HM_PI(+RQ
MQ<,@O\"W^2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#`*(RP@
M9G5Z>GD*;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T<B`BO\"XI\+WO/@B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*(RP@9G5Z>GD*;7-G:60@(DUY
M($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`BP:2ZN"(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-30*;7-G:60@(DUY(%!O<G1A;"(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z,3,V"FUS9VED
M(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@HC
M+"!F=7IZ>0IM<V=I9"`B37EA;FUA<B(*;7-G<W1R("+`S+BG(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3<*;7-G:60@
M(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$P,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B3F%M92(*;7-G<W1R("+`S+BG(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDU"FUS9VED(").86UI8FEA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW
M"B,L(&9U>GIY"FUS9VED(").97!A;"(*;7-G<W1R("*[]2"XWL#/(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDW"B,L(&9U>GIY"FUS9VED(").971H97)L86YD<R(*;7-G<W1R
M("*[]2"XWL#/(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(DYE=&AE<FQA;F1S($%N
M=&EL;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,PIM
M<V=I9"`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#4*;7-G:60@
M(DYE='-C87!E($-!('!O;&EC>2!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#0*;7-G:60@(DYE='-C87!E
M(%)E;F5W86P@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P92!2979O8V%T:6]N
M(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3@W"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@P
M"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3$*;7-G:60@(DYE='=O
M<FLB"FUS9W-T<B`BL]?&KK_VQ:DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-0HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V"FUS9VED(").979E<B(*;7-G<W1R
M("*[Y[_KOLC'U"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F5W($-A;&5D;VYI
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O
M<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H
M<#HX,0HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP
M:'`Z.#<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N
M<&AP.CDW"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS
M+G!H<#HQ,#$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S
M86=E('1O("5S(@IM<V=S='(@(KC>O</!]B#`V[RZ("@E<RDB"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]"
M;&]C:R]M;V]N+G!H<#HQ-S0*(RP@9G5Z>GD*;7-G:60@(DYE=R!-;V]N(@IM
M<V=S='(@(KOU(+C>P,\B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C,U"B,L(&9U>GIY"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO
M;F%L*2(*;7-G<W1R("*UM;_RN+LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*(RP@9G5Z>GD*
M;7-G:60@(DYE=R!:96%L86YD(@IM<V=S='(@(KOU(+C>P,\B"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(DYE
M=R!P87-S=V]R9"(*;7-G<W1R("*^S\BC(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]S<6PN<&AP.C(R-PHC+"!P:'`M9F]R;6%T"FUS9VED(").97<@<&%S
M<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU,@HC+"!F=7IZ>0IM<V=I9"`B3F5W
M('!A<W-W;W)D<R!D;VXG="!M871C:"XB"FUS9W-T<B`BOL_(H["A(,#/Q*''
MS\'V(+[*O<"TS[39+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS
M9W-T<B`BN_4@PZ(H7V)L86YK*2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C0P(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C@Y"B,L(&9U>GIY"FUS9VED(").97=S(@IM<V=S='(@
M(KOU(+C>P,\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`U"FUS
M9VED(").97=S9W)O=7!S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A
M+W1S=FEN9F\N:6YC.C$U('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0Q
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C(U"FUS9VED(").97AT(@IM<V=S='(@(K39P+TB
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(DYE
M>'0@-"!0:&%S97,B"FUS9W-T<B`BM-G`O2#&Y,#,P?8B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C,W,B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C,W-@HC+"!F=7IZ>0IM<V=I9"`B3F5X="!O<'1I;VYS(@IM
M<V=S='(@(K_)O,?`N+?.(+6YOL:PH;'B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U!A9V5R+G!H<#HQ,#,*(RP@9G5Z>GD*;7-G:60@(DYE>'0^(@IM<V=S='(@
M(K39P+TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(DYI9V5R(@IM<V=S
M='(@(KOGO^N^R,?4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"B,L(&9U>GIY"FUS9VED(").
M:6=E<FEA(@IM<V=S='(@(KOGO^N^R,?4(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,X,`HC+"!F=7IZ>0IM<V=I9"`B3FEG:'0B"FUS9W-T
M<B`BO\"XI<+*(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-SD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"B,L(&9U>GIY"FUS9VED(").:75E
M(@IM<V=S='(@(L+\P;8B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.38S"FUS9VED(").;R(*;7-G<W1R("*^QK3/O\`B"@HC
M.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO
M(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E
M;F-E<R!F;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<BYP:'`Z,3`U"FUS9VED(").;R!A=F%I;&%B;&4@<W1R
M871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*
M;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW.2!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-#4*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z,C8W"FUS9VED(").;R!B;&]C:R!E>&ES=',@870@
M=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VUC86PN<&AP.C4P"B,L(&9U>GIY"FUS9VED(").;R!C
M86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R(")344P@P,[!]2"\L\&DP:2ZN+"A(+[XO<"TS[39+B(*"B,Z
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4T"B,L(&9U>GIY"FUS9VED(").;R!C
M:&%N9V4N(@IM<V=S='(@(KJOL.:[Y\?7(+7'M;FXKK'B(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(DYO(&-H:6QD<F5N
M(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38W(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z-3`R"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP
M.C<W,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R(")3
M44P@5D93(+RSP:3!I+JXL*$@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HX,C0*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R(")&5%`@
M5D93N*8@P*?'T2"\L\&DP:2ZN+"A(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z-C8Y"FUS9VED(").;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B
M4U%,(%9&4R"\L\&DP:2ZN+"A(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HW,3<*;7-G:60@(DYO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM
M<V=S='(@(E-13"U&:6QE(%9&4R"\L\&DP:2ZN+"A(+[XO<"TS[39+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q
M-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"B,L(&9U
M>GIY"FUS9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`B
MN_4@N-[`SR(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@W
M-PHC+"!F=7IZ>0IM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R("+'
MRK7E(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q"FUS9VED(").;R!I
M8V]N<R!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$R."!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ,C,*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E
M="XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$V.0HC+"!F=7IZ>0IM<V=I9"`B3F\@;&]C871I;VX@<')O=FED960N(@IM
M<V=S='(@(L;ZM/6XIB"\L<7#Q\^\O+_D(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*(RP@9G5Z>GD*;7-G:60@
M(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(KOU(+C>P,\B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@HC
M+"!F=7IZ>0IM<V=I9"`B3F\@;F%M92!S<&5C:69I960N(@IM<V=S='(@(KFN
MP-J_K2#`U+?"(+_`M_DB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S-PHC+"!F=7IZ>0IM<V=I9"`B3F\@;G5M8F5R
M('-P96-I9FEE9"XB"FUS9W-T<B`BN:[`VK^M(,#4M\(@O\"W^2(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F96YS:79E(&9O
M<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T
M<"YP:'`Z.3$*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")344P@P,[!]2"\
ML\&DP:2ZN+"A(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:6UA<"YP:'`Z,3`X"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B4U%,(,#.
MP?4@O+/!I,&DNKBPH2"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VMR8C4N<&AP.C<R"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(E-13"#`SL'U(+RSP:3!I+JXL*$@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]S87-L+G!H<#HW-R!F<F%M97=O<FLO075T:"]!=71H+VQO
M9VEN+G!H<#HX-`HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-S4*
M(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I
M;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B4U%,(,#.P?4@O+/!I,&DNKBP
MH2"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A<W-W9"YP
M:'`Z,3,U"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")344P@P,[!]2"\
ML\&DP:2ZN+"A(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<VUB+G!H<#HX-`HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R(%--0B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B4U%,(,#.P?4@
MO+/!I,&DNKBPH2"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C$R.#8*;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P
M96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@
M;F5C97-S87)Y('1O("(*(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*
M;7-G:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C<U,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R("+!IKCQ(+[XP+TB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0S
M"B,L(&9U>GIY"FUS9VED(").;R!R=6QE<R(*;7-G<W1R("+"_,&V(@H*(SH@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Y"B,L(&9U>GIY"FUS9VED
M(").;R!S97!A<F%T;W(@<W!E8VEF:65D+B(*;7-G<W1R("*YKL#:OZT@P-2W
MPB"_P+?Y(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT-`HC+"!F=7IZ>0IM<V=I9"`B3F\@<VED97,B"FUS9W-T
M<B`BPOS!MB(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@S"B,L
M(&9U>GIY"FUS9VED(").;R!S=6-H(&9I;&4B"FUS9W-T<B`BPOS!MB(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,S@*;7-G:60@(DYO('1E
M;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HR,C$*(RP@9G5Z>GD*;7-G:60@(DYO('5S97)N86UE(&%N9"]O<B!P87-S
M=V]R9"!S96YT+B(*;7-G<W1R("*[Y[_KP-K`S+BGL/H@OL_(H[BF(,#4M\+'
MS[R\O^0B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T,`IM
M<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW,0HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@Q"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY.3(*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,#D*(RP@
M9G5Z>GD*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R("+"_,&V(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N
M9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ,C@*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U
M<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0U"B,Z
M('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3,*;7-G:60@
M(DYO;F4B"FUS9W-T<B`BO+'%P\?/P?8@OLK`O2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S
M92!I;7!L:6-I="DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#D*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H
M<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N($UA<FEA;F$@27-L86YD<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*(RP@9G5Z>GD*;7-G:60@(DYO<G=A
M>2(*;7-G<W1R("+`_+3>(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV-#`*(RP@9G5Z>GD*;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R
M("+`T[W#NKBP_+7'P?8@OLK`NB"XWL#/(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV,SD*(RP@9G5Z>GD*;7-G:60@(DYO="!"969O
M<F4B"FUS9W-T<B`BP-.]P[JXL/RUQ\'V(+[*P+H@N-[`SR(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C0P.`HC+"!F=7IZ>0IM<V=I9"`B3F]T
M(&$@9&ER96-T;W)Y(@IM<V=S='(@(K7PM[K%Y+BN(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HV,PHC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H
M<#HX,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+G!H<#HY-`HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2YP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB
M"FUS9W-T<B`BN^C!IK7'P?8@OLK`NB"XWL#/(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`HC+"!F=7IZ>0IM<V=I9"`B
M3F]T('-E="(*;7-G<W1R("+!IKCQ(+[XP+TB"@HC.B!F<F%M97=O<FLO4V5S
M<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$T,PHC.B!F<F%M97=O
M<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$U.`HC.B!F
M<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$W
M,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N
M<&AP.C$X-PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA
M;F1L97(N<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,3DP"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HR,#4@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C(S,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C0X(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HR-C4*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(X,2!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,CDW"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HS,3(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,R.0HC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z,S8R(&9R86UE=V]R:R]61E,O5D93+G!H<#HT,C(*
M(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4P,2!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z-3<P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU.#<@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C8V-0HC+"!F=7IZ>0IM<V=I9"`B3F]T('-U<'!O
M<G1E9"XB"FUS9W-T<B`BN^C!IK7'P?8@OLK`NB"XWL#/(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T-"!C;VYF:6<O:&]O
M:W,N<&AP+F1I<W0Z,3`P-0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,3<X"FUS9VED(").;W1E<R(*;7-G<W1R("+"_,&V(@H*(SH@<V5R=FEC97,O
M;V)R;W=S97(O:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S
M92P@9V\@8F%C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,0HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S4*;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@
M(C$QO_DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#0V"B,L(&9U
M>GIY"FUS9VED(").=6UB97(B"FUS9W-T<B`B,3&_^2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$T,C4*(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B!O
M9B!C:&%R86-T97)S(@IM<V=S='(@(L?@P,<@O/8B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,S8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T
M,C,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T-2!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R
M(&]F(&-O;'5M;G,B"FUS9W-T<B`BOZW`QR"\]B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$S-C<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R
M,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0S('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@
M;V8@<F]W<R(*;7-G<W1R("+'X,#'(+SV(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@
M;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI
M<W0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHV-`IM<V=I9"`B3TLB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PHC+"!F=7IZ>0IM
M<V=I9"`B3V)J96-T(@IM<V=S='(@(L&FN/$B"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$Q,0HC+"!F=7IZ>0IM<V=I9"`B3V)J96-T($-R96%T
M;W(B"FUS9W-T<B`BP::X\2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Q,#0*(RP@9G5Z>GD*;7-G:60@(D]C=&%L(@IM<V=S='(@(L#/NK`B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I
M9"`B3V-T;V)E<B(*;7-G<W1R("(Q,+_Y(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(V"B,L(&9U>GIY"FUS9VED
M(")/9F9I8V4B"FUS9W-T<B`BP::X\2(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU
M<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z,S8*(RP@9G5Z>GD*;7-G:60@(D]L9"!P87-S=V]R
M9"(*;7-G<W1R("*^S\BC(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C0V"B,L(&9U>GIY"FUS9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O
M<G)E8W0N(@IM<V=S='(@(K[/R*,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D]M
M86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@
M<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U,2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<Q"B,L(&9U>GIY"FUS9VED(")/;FQY
M(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(L#?N/BUR"#`
MS+C>P,\@P=:\TB(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM
M<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T
M;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO
M;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M
M92YP:'`Z,S4*(RP@9G5Z>GD*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W
M(@IM<V=S='(@(KOU(,.BOZ$@N+7%J2"_K;'B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z
M($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A
M<G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK
M(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("*[]2##HK^A(+BUQ:D@OZVQXB(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T:6YG
M(%-Y<W1E;2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A
M<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS(@IM<V=S='(@(KRQQ<.[Y\?7(@H*
M(SH@<V5R=FEC97,O<')E9G,N<&AP.C,Q('1E;7!L871E<R]P<F5F<R]A<'`N
M:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM
M<V=S='(@(B5S(+RQQ<.[Y\?7(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S
M='(@(KS]P-H@N/&WSR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-38W"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`BM-S#O"(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38X"B,L(&9U
M>GIY"FUS9VED(")/<F=A;FES871I;VYA;"!5;FET(@IM<V=S='(@(K3<P[PB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,R"B,L(&9U>GIY"FUS
M9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(K3<P[PB"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C$S-0HC+"!F=7IZ>0IM<V=I9"`B3W)I9VEN86P@87!P;&EC
M871I;VX@=&5M<&QA=&4B"FUS9W-T<B`BP-^X^+7((,#,N*<N(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I
M9VEN86P@=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O87)D+G!H
M<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`BL>+%N"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3,@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$R,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,Q(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-#$*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM
M<V=S='(@(K'BQ;@@P:2ZN"(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,S$*(RP@9G5Z>GD*;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S
M='(@(KOGO^O`VB"QQ\?1(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN
M<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")004T@875T:&5N=&EC871I;VX@:7,@
M;F]T(&%V86EL86)L92XB"FUS9W-T<B`BN^C!IB"]Q\;0(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")0
M14%2.CI-86EL(&)A8VME;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3(W,PHC+"!F=7IZ>0IM<V=I9"`B4$=0($1I
M9VET86P@4VEG;F%T=7)E(@IM<V=S='(@(KRMN.TZ(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,Q.0IM<V=I9"`B4$=0($5N8W)Y<'1E
M9"!$871A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$S-S$*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-3,*;7-G:60@
M(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<&AP<VAE;&PN<&AP.C8X"B,L(&9U>GIY"FUS9VED(")02%`@0V]D92(*
M;7-G<W1R(")(;W)D92(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I
M9"`B4$A0(%-H96QL(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,W"B,L(&9U>GIY"FUS9VED(")032!,:6=H
M="!286EN(@IM<V=S='(@(K?.L=?`SB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")032!3:&]W97)S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,Y"FUS9VED(")032!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")032!3;F]W(%-H
M;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#$*;7-G:60@(E!-(%-U;B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B
M4$T@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C(W-`IM<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS
M9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H96QL
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`BQN2U
M^2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.0HC+"!F=7IZ>0IM<V=I9"`B4&%K:7-T86XB"FUS
M9W-T<B`BNMG`S+'B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0HC+"!F=7IZ>0IM<V=I9"`B
M4&%L874B"FUS9W-T<B`BP*6XWL#/(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B
M4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@(E!A;F%M82(*;7-G<W1R("+`
MS+BG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,V"B,L(&9U>GIY"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S='(@(KJY
MN^<B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3@P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3,W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#$X"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#(S"FUS9VED(")087-S=V]R9"(*;7-G<W1R("*^S\BC(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED(")087-S=V]R9"!C:&%N
M9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,S(R"B,L(&9U>GIY"FUS9VED(")087-S
M=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`BOL_(HR(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<F%D:75S+G!H<#HQ-3(*(RP@9G5Z>GD*;7-G:60@(E!A<W-W
M;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(E-13"#`SL'U(+RSP:3!I+JXL*$@OOB]P+3/M-DN(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`U,PHC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O
M<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`BL>+%N"#!I+JX(@H*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP"B,L(&9U>GIY"FUS9VED
M(")087-S=V]R9#HB"FUS9W-T<B`BOL_(HR(*"B,Z('1E;7!L871E<R]L;V=I
M;B]M;V)I;&4N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")087-S=V]R9#H@(@IM
M<V=S='(@(K[/R*,B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3`@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C`S-`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C$U"FUS9VED(")087-S=V]R9',@;75S="!M871C:"XB"FUS
M9W-T<B`BOL_(H["A(,#/Q*''S\'V(+[*O<"TS[39+B(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,3D@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T92(*;7-G<W1R("*ZV<#,
ML>(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,W"FUS9VED(")087-T92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R("+%K+BS
MNKBUY;^AO*T@NMG`S+'B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R("*PYK?.(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T
M97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C<*;7-G:60@(E!E;F1I
M;F<@4VEG;G5P<SHB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4T"B,L(&9U>GIY"FUS9VED(")096]P;&4B"FUS9W-T<B`BOZK'TB(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W
M"FUS9VED(")097)C96YT(@IM<V=S='(@(L;;O+[&KB(*"B,Z('1E;7!L871E
M<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED(")097)F
M;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`BP*_!]B"P_+BN
M(,#;OO<@O<?'X"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,#8*(RP@
M9G5Z>GD*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O
M;B!L;V=I;C\B"FUS9W-T<B`BP*_!]B"P_+BN(,#;OO<@O<?'X"(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"B,L(&9U>GIY"FUS9VED
M(")097)M:7-S:6]N(@IM<V=S='(@(K"SP,X@N-[`SR(*"B,Z(&%D;6EN+W!E
M<FUS+V1E;&5T92YP:'`Z-3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R("*]Q+JP
MP-H@7"(E<UPB(+"A(+OHP::UQ[[ZO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-3@V"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N
M($1E;FEE9"(*;7-G<W1R("*PL\#.(+C>P,\B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C$V-`HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B
MQ>2WT"(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P.2!A9&UI;B]P97)M
M<R]A9&1C:&EL9"YP:'`Z-C`*(SH@861M:6XO<&5R;7,O:6YD97@N<&AP.C(R
M(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(E!E
M<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(K#\N*XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4*;7-G:60@(E!E<G-O;F%L($EN9F]R
M;6%T:6]N(@IM<V=S='(@(K"SP,X@P:2ZN"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I
M9"`B4&5R=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-34*(RP@9G5Z>GD*;7-G:60@(E!E=',B"FUS9W-T<B`BQ\B\OR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY.0IM<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B
M4&AO;F4B"FUS9W-T<B`BP/S(K;GXR*,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#<X"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I
M>&5L<R(*;7-G<W1R("+'R+R_(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4V"FUS9VED(")0;&%T:71U9&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@
M(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-#D*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M
M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED(")0
M;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L
M96UE;G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(U-S$*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N
M9"!A('EE87(N(@IM<V=S='(@(KOUM\Z_[B#`S+BGP+L@P-2WPL?/O+R_Y#HB
M"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ
M,@HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE
M(&YE=R!C871E9V]R>3HB"FUS9W-T<B`B7%QNN_6WSK_N(+C>P,_'U,#'(,#,
MN*?`NR#`U+?"Q\^\O+_D.EQ<;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$S,#$*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED
M($E0(&%D9')E<W,N(@IM<V=S='(@(K_#N=FXI2"PR[OV(+G\P=:XIB#`U+?"
MQ\^\O+_D+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C`*;7-G
M:60@(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB
M97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(T-3$*(RP@9G5Z>GD*;7-G:60@(E!L96%S
M92!E;G1E<B!A('9A;&ED('1I;64N(@IM<V=S='(@(K_#N=FXI2"PR[OV(+G\
MP=:XIB#`U+?"Q\^\O+_D+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C<*;7-G:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T
M:&4@<')O8FQE;2XB"FUS9W-T<B`BN:[!IK^A(+3KQ]$@O^2^X,"[(,#4M\+'
MV"#!UKR\O^0N(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0;&5A<V4@<')O
M=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R("*[Y[_K
MP-K`S+BGL/H@OL_(H[BF(,#4M\+'S[R\O^0B"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z-3@*;7-G:60@(B(*(E!L96%S92!R96%D('1H92!F;VQL
M;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@
M=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<P"B,L(&9U>GIY"FUS
M9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S
M='(@(KOUM\Z_[B#`S+BGP+L@P-2WPL?/O+R_Y#HB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$X."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*
M(RP@9G5Z>GD*;7-G:60@(E!O;&%N9"(*;7-G<W1R("+(N+OG(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@W"B,L(&9U>GIY
M"FUS9VED(")0;VQL<R(*;7-G<W1R("*_K3HB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS
M9VED(")0;W)T=6=A;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$R-`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C<*;7-G:60@(E!O
M<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*(RP@9G5Z>GD*
M;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`BQZ7`
MQR"SRKKQ(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.3$*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E
M9"!B>2!)34%0*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(V-B!L:6(O0FQO8VLO;65T87(N<&AP.C(W,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDX"FUS
M9VED(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E
M9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<V5S<VEO;BYP
M:'`Z,S,*;7-G:60@(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,C4*;7-G:60@(E!R97-S=7)E(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Y"FUS9VED(")0<F5S<W5R92!A="!S
M96$@;&5V96PZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C,U"B,L(&9U>GIY"FUS9VED(")0<F5S<W5R93H@(@IM<V=S
M='(@(K[/R*,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C`U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R("*Y
MS+BNNKBQXB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@
M:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(KOU(,.BOZ$@N<RXKKJXL>(B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V,B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C,V-@HC+"!F=7IZ>0IM<V=I9"`B4')E=FEO
M=7,@;W!T:6]N<R(*;7-G<W1R("+`S,#\(+C>O</!]B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT
M(&1O8W5M96YT(@IM<V=S='(@(KFNO*T@P,Z\XB(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+97DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V
M.0HC+"!F=7IZ>0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R("*YKL&F(+G?N_T_
M(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3(V"FUS9VED(")0<F]B;&5M
M($1E<V-R:7!T:6]N(@IM<V=S='(@(KFNP:8@O+.X[2(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS-CD*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,3$@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C$X.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,C@U"B,L(&9U>GIY"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R("*Q
ML\&DM<@@N:[`VK^M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@
M2V5Y($%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8T-`IM<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C(T
M,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D
M('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I
M9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@HC+"!F
M=7IZ>0IM<V=I9"`B46%T87(B"FUS9W-T<B`BP,_`VB(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HV,PIM<V=I9"`B475E<GDB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C<P"FUS9VED(")1=6]T82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8V,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8T"B,L(&9U
M>GIY"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`BO<.PHR"\L\&D
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#,*
M(RP@9G5Z>GD*;7-G:60@(E)A:6XB"FUS9W-T<B`BL*'`Y<#:N*XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B
M4F%I;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0V
M"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-PIM<V=I9"`B4F%I;B!A;F0@
M4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"B,L(&9U>GIY"FUS9VED(")2
M86YD;VT@1F]R='5N92(*;7-G<W1R("+"_,&V(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HV."!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C<V"B,L(&9U>GIY"FUS9VED(")2871I;R(*;7-G
M<W1R("+$N+S'(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C0@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ.#`*(RP@9G5Z>GD*;7-G:60@(E)E860B"FUS9W-T<B`BP-#!]B"^RL"Z
M(+C>P,\B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HX-PHC+"!F=7IZ>0IM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R("*[
M]2"XWL#/(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX
M"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@
M;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4
M:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T"FUS
M9VED(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("*XML'VN+<@
MN.VWR2"YW;JY(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B4F5F<F5S
M:"!$>6YA;6EC($UE;G4@16QE;65N=',Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-#$*(RP@9G5Z>GD*;7-G:60@(E)E9G)E<V@@
M4&]R=&%L(%9I97<Z(@IM<V=S='(@(KC>P,_'U""[];?.(,#0L>(Z(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DT(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R,3,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-0HC
M+"!F=7IZ>0IM<V=I9"`B4F5G97@B"FUS9W-T<B`BP.>\L\&D(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(T.0IM<V=I9"`B4F5L871I;VYS:&EP
M($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`HC+"!F
M=7IZ>0IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(L#0P?8@OLK`NB"XWL#/(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C8*;7-G:60@(E)E;6%R:W,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-`HC+"!F=7IZ
M>0IM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`BO+'%P[7((+C>P,\@
MN^C!IB(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM<V=I
M9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI
M;F,Z,C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,PHC+"!F
M=7IZ>0IM<V=I9"`B4F5M;W9E(@IM<V=S='(@(L;DONXH<&%I<BD@N^C!IB(*
M"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,0HC+"!F=7IZ>0IM
M<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@(KRQQ<.UR""XWL#/(+OHP:8B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34W
M"B,L(&9U>GIY"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(K[&MZ&W
MSB#`S+6_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHT,`HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS
M9W-T<B`BOL:WH;?.(,#,M;\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`BQN2^[BAP86ER
M*2"[Z,&F(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B
M4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D
M:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@HC+"!F=7IZ>0IM<V=I9"`B
M4F5M;W9E('1H92(*;7-G<W1R("*\L<7#M<@@N-[`SR"[Z,&F(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P
M"FUS9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z
M,3$*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!U<V5R(@IM<V=S='(@(L;DONXH
M<&%I<BD@N^C!IB(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI
M;F,Z-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z
M("5S(@IM<V=S='(@(L;DONXH<&%I<BD@N^C!IB(*"B,Z(&9R86UE=V]R:R]2
M4$,O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED(")297%U97-T(&-O=6QD;B=T
M(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W"B,L(&9U>GIY
M"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N
M(@IM<V=S='(@(KRMN.W`NR"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S0@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HU,3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I
M<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(E9&4R"\L\&D(,&DNKB_H;RM("=P;W)T)\#,(+[XO<"TS[39
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C<U(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HW,C,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E
M<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R(")61E,@O+/!I"#!I+JXOZ&\K2`G<&]R="?`S""^^+W`
MM,^TV2XB"@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW.#$*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E
M8VEF:65D(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E9&4R"\L\&D(,&D
MNKB_H;RM("=P;W)T)\#,(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I9"`B4F5Q=6ER960@1FEE;&0B
M"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R
M97(N<&AP.C,R,"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@(E)E
M<V5T(@IM<V=S='(@(L#4M\(@P^N\TB(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C0V"B,L(&9U>GIY"FUS9VED(")297-E="!087-S=V]R9"(*
M;7-G<W1R("*^S\BC(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M,C<*(RP@9G5Z>GD*;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T
M<B`BOL_(HR#(KL#.(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,`HC+"!F
M=7IZ>0IM<V=I9"`B4F5S=&]R92!,87-T(%%U97)Y(@IM<V=S='(@(KBVP?:X
MMR#&Y,#,P?8B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S$@861M:6XO8VUD
M<VAE;&PN<&AP.C(X(&%D;6EN+W-Q;'-H96QL+G!H<#HV-@HC+"!F=7IZ>0IM
M<V=I9"`B4F5S=6QT<R(*;7-G<W1R("*PR[OV(+#AL/HB"@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N
M:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(K_)O,?`
MN+?.(+6YOL:PH;'B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C,X"B,L(&9U>GIY"FUS9VED(")2971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S
M='(@(K[/R*,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2975N:6]N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B4F5V97)T($-O;F9I
M9W5R871I;VXB"FUS9W-T<B`BN-[`SR"\K;GV(,&DNKB[Y\?7(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$S,@HC+"!F=7IZ>0IM<V=I9"`B4FEC:"!4
M97AT($5D:71O<B!/<'1I;VYS(@IM<V=S='(@(K_)O,?`N+?.(+6YOL:PH;'B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X"B,L(&9U>GIY"FUS9VED
M(")2:61D;&5S(@IM<V=S='(@(K"AO^ZUI2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`IM<V=I9"`B4FEG:'0B
M"FUS9W-T<B`BO\"XI<+*(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S$R,0IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3<*(RP@9G5Z>GD*;7-G:60@(E)I9VAT
M('9A;'5E<R(*;7-G<W1R("*_N3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O
M<&5R=&EE<RXN+B(*;7-G<W1R(")?=\?@(+S3O+HN+BXB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE
M(@IM<V=S='(@(K^JQ](B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,C4*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,@HC+"!F
M=7IZ>0IM<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`BP*>WSB#`S+6_(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R.`IM
M<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O
M=R!0<F]P97)T:65S(@IM<V=S='(@(L?@(+S3O+HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2
M;W<@<')O<&5R=&EE<R(*;7-G<W1R("+'X""\T[RZ(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z
M(@IM<V=S='(@(L?@.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3,*(RP@9G5Z>GD*;7-G:60@(E)U;&5S(@IM
M<V=S='(@(K^JQ](B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*
M;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E
M='=E96X@<F]W<R!O;FQY(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,C`*;7-G:60@(E)U;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S
M"FUS9VED(")2=7-S:6%N($9E9&5R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,PHC+"!F=7IZ>0IM<V=I9"`B4G=A;F1A(@IM<V=S='(@(K3>M\(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I
M9"`B4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S(S"B,L(&9U
M>GIY"FUS9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B
MN-Z]P\'V(,#\O-LB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP
M.C@Q"B,L(&9U>GIY"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(KOHP:8@O<?&T"(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HU,#0*(RP@9G5Z>GD*;7-G:60@(E--4R!-97-S
M86=I;F<B"FUS9W-T<B`BN-Z]P\'V(+JXL>(B"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@S"FUS9VED(")344P@<W1A=&5M96YT
M(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT,S$*;7-G:60@(E-32"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M
M;V)I;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(B(*"B,Z(&QI
M8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"B,L
M(&9U>GIY"FUS9VED(")382(*;7-G<W1R("+`^L#E(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-PIM<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")386EN="!6:6YC96YT
M(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")386UE(&9R
M86UE("A?<V5L9BDB"FUS9W-T<B`BL+#`NB#'P;>YP-,H7W-E;&8I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-PIM<V=I9"`B4V%M;V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-@HC+"!F=7IZ>0IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R("*PH<#E
MP-JXKB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN
M8VEP92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$Y"FUS9VED(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY.`IM<V=I9"`B4V%V
M92(*;7-G<W1R("+`^L#E(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E
M9&ET+FEN8SHT-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<
M(B5S7"(B"FUS9W-T<B`BM-FXI<#,N*?`N+?.(,#ZP.4B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4V%V92`E<R(*;7-G<W1R("*TV;BEP,RXI\"XM\X@P/K`Y2(*"B,Z
M('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N
M<R(*;7-G<W1R("*\L<7#N^?'UR#`^L#E(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$V-PIM<V=I9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A
M=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A
M<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HW,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V
M960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B5D93(+RSP:0@P:2ZN+^A
MO*T@)W!O<G0GP,P@OOB]P+3/M-DN(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G
M<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*;7-G:60@(E-C871T
M97)E9"!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C:"(*;7-G<W1R("*PR[OV(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R,`HC+"!F=7IZ>0IM<V=I
M9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T<B`BL,N[]B"PX;#Z(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDW,PHC+"!F=7IZ>0IM<V=I9"`B4V5L
M96-T($9I;&5S(@IM<V=S='(@(KCPM<X@O+'%PR(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT.#0*(RP@9G5Z>GD*;7-G:60@
M(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`BO<2ZL,#:(+RQQ<,B"@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`HC+"!F=7IZ>0IM<V=I9"`B4V5L
M96-T(&$@9W)O=7`@=&\@861D(@IM<V=S='(@(KFNP-J_K2"\L<7#.B(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-#,*(RP@9G5Z>GD*;7-G:60@
M(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R("*\L<7#(,/KO-(B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*(RP@9G5Z>GD*;7-G:60@
M(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R("*YKL#:OZT@O+'%PSHB"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U-@HC+"!F=7IZ>0IM<V=I9"`B
M4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`BN:[`VK^M(+RQQ<,Z(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-PHC
M+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R("*X\+7.(+RQQ<,B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8S"B,L(&9U>GIY"FUS
M9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`BLZ_`
MVB#'_+W$(+RQQ<,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.#<S"B,L(&9U>GIY"FUS9VED(")396QE8W0@86X@;V)J96-T
M(@IM<V=S='(@(KRQQ<,@P^N\TB(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HV-S@*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!N
M;VYE(@IM<V=S='(@(KRQQ<,@P^N\TB(*"B,Z('-E<G9I8V5S+VME>6)O87)D
M+G!H<#HS-PIM<V=I9"`B(@HB4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N
M965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A
M;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N(@IM<V=S='(@
M(K[&MZ$@N_/`VK^AO*T@Q\J_Y,?1(+FNP-JXIB"\L<7#Q\^P[2"ZN;OGQ\^_
MJ2"ZV;^IL];`N+R\O^0N(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z(@IM<V=S='(@
M(K.OP-H@L;BZT,>EO<,@O+'%PSHB"@HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT-`IM<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T
M<B`BLZ_`VB#'_+W$(+RQQ<,B"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I
M='ES96QE8W0N:6YC.CDP"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE(&ED
M96YT:71Y('EO=2!W86YT('1O(&-H86YG93HB"FUS9W-T<B`BP-/&]\:NQ](@
MP*?$H2"\L<7#.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"B,L
M(&9U>GIY"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G
M<W1R("*SK\#:(+&XNM#'I;W#(+RQQ<,Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM92!F;W)M870Z(@IM
M<V=S='(@(KW#L*,@Q_R]Q""\L<7#(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHU-PIM<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N
M(@IM<V=S='(@(K7.L+/`QR#`S\2AQ\^TPB#'U[CQ(+RQQ<,B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S`V"FUS9VED(")396QE8W0@>6]U<B!C;VQO
M<B!S8VAE;64N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-#@*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB
M"FUS9W-T<B`BP-K!UKOGO^O'S[3"(+[PONZXIB"\L<7#Q\^\O+_D+B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")396YD
M(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(KFNP::YW[O](+JXL.V\K2#`_+S;
MQ\^QXB(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,#,Y"B,L(&9U>GIY"FUS9VED(")396YD(%--4R(*;7-G<W1R("*XWKW#
MP?8@P/R\VR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E;F5G86PB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,38*(RP@9G5Z>GD*;7-G
M:60@(E-E;G-O<CH@(@IM<V=S='(@(B#!IKCQ.B`B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Y"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I9"`B4V5P=&5M8F5R
M(@IM<V=S='(@(CF_^2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#$*
M(RP@9G5Z>GD*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS9W-T<B`BO/W`VB(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*(RP@9G5Z>GD*
M;7-G:60@(E-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(L#,O^NPH;3)Q]$@O+'%P[OGQ]?`S""^^+W`M,^TV2XB"@HC.B!A
M9&UI;B]S97-S:6]N<RYP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(E-E<W-I;VX@
M061M:6XB"FUS9W-T<B`BL/RXKB(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@HC+"!F=7IZ>0IM<V=I9"`B4V5S
M<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R("*XWKW#P?8@Q]>X\2(*"B,Z(&QI
M8B]A<&DN<&AP.C$T-0HC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T
M<B`BQ>2WT"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,30*(RP@
M9G5Z>GD*;7-G:60@(E-E="(*;7-G<W1R("*XWKW#P?8@O+'%PR(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HW-@IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@
M86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@
M9F]R9V5T(&ET+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$U"FUS9VED(")3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@
M=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T"B,L(&9U>GIY"FUS9VED(")3
M970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E
M(&]P=&EO;G,N(@IM<V=S='(@(L;DP,S!]B"PN[W%P=:QXB"YUR"QXL6X(,BM
MN.D@O+/!I,"[(,?/O+R_Y"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3@*(RP@9G5Z>GD*;7-G:60@(B(*(E-E="!Y;W5R('-T87)T=7`@87!P;&EC
M871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H
M97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R("+&Y,#,P?8@L+N]Q<'6
ML>(@N=<@L>+%N"#(K;CI(+RSP:3`NR#'S[R\O^0N(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HW-0HC+"!F=7IZ>0IM<V=I9"`B4V5T=7`B"FUS9W-T
M<B`BN-Z]P\'V(+RQQ<,B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD
M97@N:'1M;#HS-PIM<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL
M86)L92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3@V"FUS9VED(")3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H
M('1H92!P87)A;65T97(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS
M9VED(")397EC:&5L;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT.38*(RP@9G5Z>GD*;7-G:60@(E-H;W!P:6YG(@IM<V=S
M='(@(K#%N*XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT
M,PHC+"!F=7IZ>0IM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G<W1R("*PH[3<
MQ]$@O^2^X#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0V"FUS9VED
M(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK
M<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS
M,C,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$U-0IM<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B
M971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E
M9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#DP"B,L(&9U>GIY"FUS9VED(")3:&]W(&QA<W0@;&]G
M:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S='(@(K?.L=?`SKW#(,/6
MP;X@M\ZQU\#.(+W#L*,@NKB_J<'6L>(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-S8U"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I
M;F%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M,3,*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,C8*(RP@9G5Z>GD*;7-G:60@(E-H;W<@=&%B;&4@
M;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`BQZ4@O-.\NL.B(+JXL>(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Y"B,L('!H<"UF;W)M870*
M;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T
M:65S(&1I86QO9R(*;7-G<W1R("*\OR"\T[RZPZ(@NKBQXB(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM
M<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T
M<B`BQZ4@O-.\NL.B(+JXL>(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A
M8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("*_K2"\T[RZPZ(@
MNKBQXB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE
M<R!D:6%L;V<B"FUS9W-T<B`BL=>XLB"\T[RZPZ(@NKBQXB(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C,*(RP@9G5Z>GD*;7-G:60@(E-H;W<@
M=7!L;V%D(@IM<V=S='(@(K.[M\&YWK'B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(E-H;W=E
M<G,B"FUS9W-T<B`BP-"^[K_`L>(HP-/&]\:N*2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"B,L(&9U>GIY"FUS9VED(")3
M:&]W97)S($5A<FQY(@IM<V=S='(@(K"CM-S'T2"_Y+[@.B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED(")3:&]W
M97)S($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN
M:71Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C0X,`HC+"!F=7IZ>0IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(K?.
ML=?`SB(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<W
M-"!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HX,S8*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3(R(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.CDX-`HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HQ,#0W(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C$P.#<*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z,3$Q-B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ
M,30Y"FUS9VED(")3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH
M<RD@;W5T(&]F('1H92!W87D@9FER<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C4*(RP@9G5Z>GD*;7-G:60@
M(E-I9VX@=7`B"FUS9W-T<B`BO*VX[3HB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C<Q,@HC+"!F=7IZ>0IM<V=I9"`B4VEG;F%T=7)E
M(@IM<V=S='(@(KRMN.TZ(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HW,3$*(RP@9G5Z>GD*;7-G:60@(E-I9VYA='5R92!!;&=O<FET
M:&TB"FUS9W-T<B`BO*VX[3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"B,L(&9U>GIY"FUS
M9VED(")3:6YG87!O<F4B"FUS9W-T<B`BO*VX[3HB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8U(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HX-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.38*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C,W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R
M-#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3(S"FUS9VED(")3:7IE(@IM<V=S='(@(L6IL>(B
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU
M,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R("+`K\'VL/RXKB"[
M_;>K(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-30*;7-G
M:60@(E-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V
M"FUS9VED(")3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G:60@(E-N;W<@4VAO
M=V5R<R!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S@*(RP@9G5Z
M>GD*;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R("(@P::X\3H@(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#(*;7-G:60@(E-N;W<@97%U:79A;&5N
M="!I;B!W871E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@
M(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS
M9VED(")3;VUA;&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(V"B,L(&9U>GIY"FUS9VED(")3
M;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R("+!I+?$(+GFN?TB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U.0HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X
M.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,38V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M,3@Y"B,L(&9U>GIY"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G<W1R("+!
M]\#E(,'6O-(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")3;W5T:"!!9G)I8V$B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@
M(E-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S<*;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!3
M86YD=VEC:"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N
M($AE;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E96X@
M861J86-E;G0@8V5L;',B"FUS9W-T<B`BO+^PH[#=(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E
M(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B
MO+\@L.:PZ+_-(+.[O^L@N^?`S,#'(+"CL-TB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HX,34*(RP@9G5Z>GD*;7-G:60@(E-P86-E<B(*;7-G<W1R
M("+`^L#E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@P"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(K#%N*XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4T"FUS9VED(")3<&%C:6YG(&%N9"!P861D:6YG(@IM<V=S='(@(K#%N*Z_
MS2##I+_LL>(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B4W!A:6XB
M"FUS9W-T<B`BL,6XKB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY
M.`HC+"!F=7IZ>0IM<V=I9"`B4W!A;2(*;7-G<W1R("+`^L#E(@H*(SH@<V5R
M=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C:6%L($-H87)A8W1E
M<B!);G!U="(*;7-G<W1R("+&K[SV(+FNP-H@P-2WPB(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G:60@
M(E-P;&ET(&-E;&PB"FUS9W-T<B`BO+\@NM#'TB(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P
M;&ET(&-O;'5M;B(*;7-G<W1R("*_K2"ZT,?2(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L
M:70@<F]W(@IM<V=S='(@(L?@(+K0Q](B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(E-P;W)T<R(*;7-G<W1R("+`T+[N
MO\"QXBC`T\;WQJXI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED(")3<FD@3&%N:V$B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<S
M(&QI8B]";&]C:R]M971A<BYP:'`Z-S0*(RP@9G5Z>GD*;7-G:60@(E-T86YD
M87)D(@IM<V=S='(@(K3>M\(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C(*;7-G:60@(E-T87(@5')E:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-3DV(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M,#D*;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@(E-T871E(&]R(%!R
M;W9I;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I
M;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-0HC+"!F=7IZ>0IM<V=I9"`B4W1O
M<F%G92!F;W)M870B"FUS9W-T<B`BN-[`SR"\K;GV(,&DNKB[Y\?7(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S(*(RP@9G5Z>GD*
M;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@(L'WP.4@P=:\TB(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G
M:60@(E-T<FEK971H<F]U9V@B"FUS9W-T<B`BL*&_[K6EP=DB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,S"B,L(&9U>GIY"FUS9VED(")3=')I
M;F<@;&ES="(*;7-G<W1R("*\]KW%L,6ZSB(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$X-S,*;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A
M9&1R97-S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM
M<V=S='(@(KVZQ;C`SUM#4U-=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T<B`B(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T
M<B`BQ>O!]B"XKKVZL\H@)7/`NRBXIBD@PZ/`NR"\]B"^^+W`M,^TV2XB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S"FUS
M9VED(")3=6)J96-T(@IM<V=S='(@(L&FN/$B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,S(@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP
M:'`Z,S$W"FUS9VED(")3=6)M:70B"FUS9W-T<B`BP:;#XB(*"B,Z('-I9VYU
M<"YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D(')E
M<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&YO
M="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O
M=F5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$R"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`BOL:W
MH<.WP-HB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`T"B,Z(&9R86UE=V]R
M:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP
M:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`BO+JP^"(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C@U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C
M97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S>7-T96TN(@IM<V=S='(@
M(B<E<R>PH2"]P[VZQ=N_H2##W["AM<>^^KW`M,^TV2XB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE
M('-Y<W1E;2XB"FUS9W-T<B`B)R5S)["A(+W#O;K%V[^AO*T@N^C!IK7'OOJ]
MP+3/M-DN(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI;B]P97)M<R]D
M96QE=&4N<&AP.C0V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C
M97-S9G5L;'D@9&5L971E9"!<(B5S7"(N(@IM<V=S='(@(B<E<R>PH2"]P[VZ
MQ=N_H2##W["AM<>^^KW`M,^TV2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#4*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO
M=F5D(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(B<E<R>PH2"]
MP[VZQ=N_H;RM(+OHP::UQ[[ZO<"TS[39+B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF
M:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU.2!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HU-PHC+"!F=7IZ>0IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D
M(&)A8VMU<"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")61E,@O+/!I"#!I+JX
MOZ&\K2`G<&]R="?`S""^^+W`M,^TV2XB"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S
M879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T
M<B`B)R5S)["A(+W#O;K%V[^A(,/?L*&UQ[[ZO<"TS[39+B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O
M=&4@)7,B"FUS9W-T<B`B)R5S)["A(+W#O;K%V[^A(,/?L*&UQ[[ZO<"TS[39
M+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U9&%N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-38*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`BO^2^X"(*"B,Z(&QI8B]";&]C
M:R]S=6YR:7-E+G!H<#HV-0HC+"!F=7IZ>0IM<V=I9"`B4W5N(%)I<V4B"FUS
M9W-T<B`BP::X\2(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV.`HC+"!F
M=7IZ>0IM<V=I9"`B4W5N(%-E="(*;7-G<W1R("+!IKCQ(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-U;FYY
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,38*(RP@9G5Z>GD*;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`BP::X\2(*"B,Z
M(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H
M<#HQ-@HC+"!F=7IZ>0IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`B
MP::X\2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,34*(RP@
M9G5Z>GD*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R("(@P::X\3H@(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.0HC+"!F=7IZ>0IM<V=I
M9"`B4W5N<V5T(@IM<V=S='(@(L&FN/$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C$X"B,L(&9U>GIY"FUS9VED(")3=6YS970Z("(*;7-G
M<W1R("(@P::X\3H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`BP*W#
MM\#:(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W.`HC+"!F=7IZ
M>0IM<V=I9"`B4W5P<&]R="(*;7-G<W1R("+`T+[NO\"QXBC`T\;WQJXI(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,34@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-@HC+"!F=7IZ>0IM<V=I9"`B4W5R:6YA;64B"FUS9W-T
M<B`BP,RXIR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3<T"B,L(&9U>GIY"FUS9VED(")3=7)N86UE(@IM<V=S='(@(L#,N*<B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA>65N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*(RP@9G5Z>GD*;7-G:60@(E-W87II
M;&%N9"(*;7-G<W1R("+#H['B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,34*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`HC+"!F=7IZ>0IM
M<V=I9"`B4W=E9&5N(@IM<V=S='(@(L#0P+H@N-[`SR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V
M"FUS9VED(")3=VET>F5R;&%N9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HX-@HC+"!F=7IZ>0IM<V=I9"`B4WEN8R!L;V<@
M9&5L971E9"(*;7-G<W1R("*ZN;&X(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$T,@IM<V=I9"`B4WEN8TU,(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]344PO4U%,+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R<F]R
M(&EN('-E87)C:"!T97)M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS
M9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,`IM<V=I9"`B5"U3
M=&]R;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV,0IM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C(*(RP@9G5Z>GD*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(L"GQ*$B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I
M9"`B5"U3=&]R;7,@16%R;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A
M=&$O1&%T82]T<W8N<&AP.C$V-@HC+"!F=7IZ>0IM<V=I9"`B5%-6(&9I;&4B
M"FUS9W-T<B`BP::X\2(*"B,Z(&9R86UE=V]R:R]522]522]486)L92YP:'`Z
M,3,T"B,L(&9U>GIY"FUS9VED(")486)L92(*;7-G<W1R("+!IKCQ(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M,PIM<V=I9"`B5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R("+'I2"\T[RZ(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PHC
M+"!F=7IZ>0IM<V=I9"`B5&%B;&4@4V5T(@IM<V=S='(@(L&FN/$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<R
M"FUS9VED(")486)L92!P<F]P97)T:65S(@IM<V=S='(@(L>E(+S3O+HB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-"!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")486EW86XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@
M(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$R"B,L(&9U>GIY"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(K3KQ]&YSK&Y(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0HC+"!F=7IZ>0IM<V=I9"`B5&%R
M9V5T.B(*;7-G<W1R("*XWKW#P?8B"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I
M<W0Z.3DV(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#<*;7-G:60@(E1A
M<VMS(@IM<V=S='(@(L#;OO<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4W,PIM<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y,`IM<V=I9"`B5&5M<"!F
M;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,30*;7-G:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C,*;7-G:60@(E1E;7!E<F%T
M=7)E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")496UP97)A='5R93QB<B`O
M/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-C@W"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G
M<W1R("+%Z\'V(+BNO;JSRB`E<\"[*+BF*2##H\"[(+SV(+[XO<"TS[39+B(*
M"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y"B,L(&9U>GIY"FUS9VED(")4
M96UP;&%T92!!9&UI;FES=')A=&EO;B(*;7-G<W1R("*P_+BN(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,S,V"FUS9VED(")497AT(@IM<V=S='(@(KFNP-J_K2(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S4*;7-G:60@(E1E>'0@3VYL>2(*;7-G
M<W1R("*YKL#:(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW-`IM<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R("*Y
MKL#:(,&DM\0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<Q"B,L(&9U>GIY"FUS9VED(")497AT=&]P(@IM<V=S='(@(KFN
MP-J_K2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DQ"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`Y"B,L(&9U>GIY"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R
M("+#H['B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"FUS9VED
M(")4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN(@IM<V=S='(@(KOG
MO^O'V,'6O,6\K2"PJ+OGQ]6TS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z.#(P"B,L(&9U>GIY"FUS9VED(")4:&4@1E10(&5X=&5N<VEO
M;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("+`S+_KL*&TR<?1(+RQQ<.[
MY\?7P,P@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN
M=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]";V]K+G!H<#HQ
M,CDR"B,L(&9U>GIY"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E
M(&EN:71I86QI>F5D+B(*;7-G<W1R("*\K;CMP+L@NJ^PYL?2(+SV(+[XO<"T
MS[39+B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B
M5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F
M=6QL>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K
M97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E
M9"X@17AI=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HQ.#D@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,#`*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,3$@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HR,C,*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR
M,S0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-3(*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HR-C0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HS,#,*;7-G:60@(B(*(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O
M;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO
M=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N<RXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*
M;7-G:60@(B(*(E1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I
M9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92`B"B)D
M871A8F%S92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C4Q"B,L(&9U>GIY"FUS9VED(")4:&4@8V]N=&%C
M="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K
M+B(*;7-G<W1R("+'U[CQ(%PB)7-<(K"A(,'6O-*WS[^A(,/?L*&UQ[[ZO<"T
MS[39+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-CD*
M;7-G:60@(B(*(E1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES
M(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@
M=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F
M;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED
M(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="YP:'`Z,3$S"FUS
M9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E
M('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$W-2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N
M=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,38X(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M-3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C
M;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C(Q.0HC+"!F=7IZ>0IM<V=I9"`B5&AE
M(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N(@IM<V=S='(@
M(L;$P,^_H2"^QKFKM[$@P-JWX;"A(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R
M:R]$871A+T1A=&$N<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D
M(&YO(&1A=&$N(@IM<V=S='(@(L;$P,^_H2"^QKFKM[$@P-JWX;"A(+[XO<"T
MS[39+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP
M:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O
M<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(K[&MZ&T
MPB#`S"!M97-S86=E+W)F8S@R,B#&[<'VP,<@N-.XM+B[P-2TS[39+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G
M:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E
M('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B
M<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N
M9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@
M;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E
M<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I
M="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L("(*
M(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9
M;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y
M;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDP"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L
M971E9"XB"FUS9W-T<B`BO<2ZL,#:(%PB)7-<(B"PH2"[Z,&FM<>^^KW`M,^T
MV2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I9&4@;VYL>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ-3<*
M;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU
M<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,C`Q"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@
M)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB
M"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B
M965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-PIM<V=I9"`B5&AE(&YA;64@=&\@=7-E
M('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T,0HC+"!F=7IZ>0IM
M<V=I9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*
M;7-G<W1R("+`S""PJL"Z(+S]P-J_J;[?(,?5M,^TV2XB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S$*;7-G:60@(E1H92!O<&5N
M<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M
M:6UE.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<RYP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F
M97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@
M9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D96(N
M<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V5N<V-R:7!T
M+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W!O=V5R
M<&]I;G0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS
M=V]R9"YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<G!M
M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]W96)C<'`N
M<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W-R8VAI9VAL
M:71E+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<V5X
M8V5L+G!H<#HS,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S
M(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R("+`S""XWKW#P?8@
MQ_S%PB@E<RFXIB"ZN+'B(,"GQ]$@Q\&WSK'7MZ7`NR##H\"[(+SV(+[XO<"T
MS[39+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0U-`IM<V=I
M9"`B5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA
M<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@86YD
M(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@
M<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z-#0V"FUS9VED(")4:&4@<V5P87)A=&]R(&UU
M<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D
M+B(*;7-G<W1R("*]Q+JPP-H@7"(E<UPB(+"A(+OHP::UQ[[ZO<"TS[39+B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C0Y"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S
M879E9"XB"FUS9W-T<B`BO<2ZL,#:(%PB)7-<(B"PH2#`^L#EM<>^^KW`M,^T
MV2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@
M<F5M;W9E9"XB"FUS9W-T<B`BO<2ZL,#:(%PB)7-<(B"PH2#`^L#EM<>^^KW`
MM,^TV2XB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HS
M,S`*;7-G:60@(E1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$W-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB
M(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,S$Q"FUS9VED(")4:&4@=&5X="!Y;W4@96YT97)E9"!D
M:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C,R-PIM<V=I
M9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I
M;W5S('-T97`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O
M8W-V+G!H<#HR-C(@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$W,@HC
M+"!F=7IZ>0IM<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E
M('-A=F5D+B(*;7-G<W1R("*\K;CMP+L@NJ^PYL?2(+SV(+[XO<"TS[39+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-38*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$Q-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$Y"B,L
M(&9U>GIY"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`BP,R_Z["AM,G'T2"\L<7#N^?'U\#,(+[XO<"T
MS[39+B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T
M(&9O=6YD+B(*;7-G<W1R("+%Z\'V(+BNO;JSRB`E<\"[*+BF*2##H\"[(+SV
M(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,3<X"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM
M<V=S='(@(L#,O^NPH;3)Q]$@O+'%P[OGQ]?`S""^^+W`M,^TV2XB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HS-#(*(RP@9G5Z>GD*
M;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y
M960@:6YL:6YE+B(*;7-G<W1R("+`S+_KL*&TR<?1(+RQQ<.[Y\?7P,P@OOB]
MP+3/M-DN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30P,0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C
M=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A
M8W1E<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T
M<B`B(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A
M9&1I;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@(B<E<R>X
MIB"]P[VZQ=N_H2##W["AQ](@O/8@OOB]P+3/M-DN(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R
M;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(B<E<R>XIB"]P[VZQ=N_H;RM(+OH
MP:;'TB"\]B"^^+W`M,^TV2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#,*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@
M<F5M;W9I;F<@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(B<E
M<R>XIB"]P[VZQ=N_H;RM(+OHP:;'TB"\]B"^^+W`M,^TV2XB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ-3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R
M("(G)7,GN*8@O<.]NL7;OZ$@P]^PH<?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L
M;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(L;$P,\@O\.XKK'B
MOZ$@N:[!IK"A(,#6O<"TS[39+B`E<R#&Q,#/P,P@OO>WSK7EM<?!]B"^RK[2
MO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X
M.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@
M<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G
M97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S
M*2XB"FUS9W-T<B`B(@HBQL3`SR"^][?.M>4@O\"W^2X@P,S&Q,#/P+H@OO>W
MSK7E(,?CO^NUR"##UK3K(,6IL>(H)60@34(INKBTV2#%J[#-(+"PO<"TS[39
M+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y,0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE
M;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I
M86QL>2!U<&QO861E9"XB"FUS9W-T<B`B(@HBOO>WSK7E(,;$P,^_H2"YKL&F
ML*$@P-:]P+3/M-DN(,#,QL3`S\"Z(+[WM\ZUY2##UK3KQ^._Z\6IL>*XIB##
MRK#ZQ]6TS[39+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z,S4*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(KC>O</!
M]B#`_+S;(+_`M_DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,SD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C0X"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(K6EP,S%N"#`
MT\;WQJX@O\"W^2(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS
M,0HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN
M9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(K6EP,S%N"#`T\;WQJX@
MO\"W^2(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#`*(RP@9G5Z>GD*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A
M=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D
M(&9I96QD+B(*;7-G<W1R("*_Y,.[M<@@N-Z]P\'V(,#0L>(@O\"W^2(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X
M"B,L(&9U>GIY"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@<&5R9F]R
M;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE
M87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`BO^3#N[7((+C>O</!
M]B#`T+'B(+_`M_DB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8T,`HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE<F4@=V%S
M(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S
M92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(K[WM\ZUY2#&Q,#/(,#3QO?&
MKB"_P+?Y(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HR,C(*(RP@9G5Z>GD*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O
M<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@
M86=A:6X@;&%T97(N(@IM<V=S='(@(K_DP[NUR""XWKW#P?8@P-"QXB"_P+?Y
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X
M"B,L(&9U>GIY"FUS9VED(")4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U
M<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R("*ZZK;SO^S`^K"A(,#,
M(+'BM,G`NR#!]K_XQ\_!]B"^RKW`M,^TV2XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C0X"B,L(&9U>GIY"FUS9VED(")4:&ES
M(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*
M;7-G<W1R("+`S""PJL"Z(+S]P-J_J;[?(,?5M,^TV2XB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C4R"B,L(&9U>GIY"FUS9VED
M(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE
M+B(*;7-G<W1R("+`S""PJL"Z(+S]P-J_J;[?(,?5M,^TV2XB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,30U"B,L(&9U>GIY"FUS9VED(")4:&ES
M(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS
M9W-T<B`BP,P@L*K`NB"\_<#:OZF^WR#'U;3/M-DN(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U"FUS9VED("(B
M"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O
M=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI
M(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S-`IM<V=I9"`B
M(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR
M;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@(@HB9V%T97=A>2P@
M=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"FUS9VED("(B"B)4
M:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H
M('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G871E
M=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G
M:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY("(*(F=A=&5W
M87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@
M96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O
M=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.CDW."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#4W"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.#8@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3$Q-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@R(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-38*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3,P-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,SDX"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$U-3<@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@S.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.34X
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,#4*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C`R.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#<X
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-#D@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C(R,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-#$P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-30*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C8U-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.#(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,S<@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S,P-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS.#$T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,C(*;7-G:60@(E1H
M:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$P-C4*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N
M;'D@8V]N=&%I;B!I;G1E9V5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C0Q.`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL
M>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`Y-`IM<V=I9"`B5&AI<R!F
M:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$R,PIM<V=I9"`B5&AI
M<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI
M<W0@;V8@:6YT96=E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.3@Y"B,L(&9U>GIY"FUS9VED(")4:&ES(&9I96QD(&UU<W0@
M8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@(L#,(+"JP+H@O/W`VK^IOM\@
MQ]6TS[39+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,S8*;7-G
M:60@(B(*(E1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I
M;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F
M)RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z-38Q
M"B,L(&9U>GIY"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P
M<F]C97-S960N(@IM<V=S='(@(L#,N<P@P=:\TK?/OZ$@M>ZWS[7'ONX@P-:]
MP+3/M-DN(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I
M97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE
M;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA
M="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E
M('9I<VET("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C4Y,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE
M<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H
M97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@
M8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R("+`S""\_<#:M,(@P]:\TL?1(#'`
MVKBN(,#,N_/`S+[NOM\@Q]6TS[39+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]G>FEP+G!H<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N
M)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3@Y"FUS
M9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(T
M"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@
M(L#,(+"JP+H@O/W`VK^IOM\@Q]6TS[39+B(*"B,Z('-E<G9I8V5S+VEM86=E
M<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@
M8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*;7-G
M:60@(E1H=6YD97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(S-`IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#(X('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B5&EM92(*;7-G<W1R("+!IKCQ
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X-@IM<V=I9"`B5&EM
M92!4<F%C:VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z
M,3<*(RP@9G5Z>GD*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(KW#L*,@
MO+/!I"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U,SD*(RP@9G5Z
M>GD*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@(KW#L*,@O+/!I"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@
M;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@
M(L&FN/$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@(L6XP,S&
MLBC%^,;!*3HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R("*YWK3"(+OGMO<B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C4T"FUS9VED
M("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@
M0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y("(*(G=H:6QE(&-L
M:6-K:6YG+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S$Q"B,L(&9U>GIY"FUS9VED(")4;V1A>2(*;7-G<W1R("*ZN[FN
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@(DA434P@O-*]
MNB"ZN+'B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P.0HC+"!F=7IZ>0IM<V=I9"`B5&]G;R(*
M;7-G<W1R("*YWK3"(+OGMO<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VME
M;&%U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS,3,*(RP@9G5Z>GD*;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(B`HL[O`
MSRDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$P"B,L(&9U>GIY"FUS9VED(")4;VYG82(*;7-G
M<W1R("*YWK3"(+OGMO<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S<*;7-G:60@(E1O<"(*;7-G<W1R("+`IR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*
M;7-G:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`BN_/`IR#'P;>YP-,H
M7W1O<"DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*(RP@9G5Z>GD*
M;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R("+(K[#FO+/!I"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<Y,`IM<V=I9"`B5')U
M92!O<B!F86QS92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$P"FUS9VED(")4=6YI<VEA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3$*;7-G:60@(E1U<FME>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$Y,@IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES=&%N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#
M86EC;W,@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED
M(")4=79A;'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP
M.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-CD*;7-G:60@(E4N5BX@
M:6YD97@Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS
M9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U
M<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW"B,L
M(&9U>GIY"FUS9VED(")54DPZ(@IM<V=S='(@(E523"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3(*(RP@9G5Z>GD*;7-G:60@(E5G86YD82(*;7-G<W1R("*TWK?"(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,@HC+"!F=7IZ>0IM<V=I9"`B56MR86EN92(*;7-G<W1R("*Y
MV,'9(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#$R"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM
M<V=S='(@(G9F<W)O;W0@M?"WNL7DN*ZXIB#`T,"[(+SV(+[XO<"TS[39+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B
M56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG
M;FEN9R!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HS.#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G
M<W1R(")61E,@QL3`SR`E<R\E<\#'(,;;N<R\Q\"[(+JOL.;'TB"\]B"^^+W`
MM,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS.#4@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE
M("5S+R5S+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E<\#'(,;;N<R\Q\"[(+JO
ML.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C<U-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B4U%,(+RMN?:_H2#!HKS3Q](@O/8@
MOOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S(*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F
M:6QE('-I>F4@;V8@7"(E<UPB+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[
M*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z-C@X(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3`Q
M-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z.#,T"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S
M:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`B5D93(,;$P,\@)7,O)7/`NRBX
MIBD@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<W%L+G!H<#HT,S4*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-1
M3"!S97)V97(N(@IM<V=S='(@(E-13""\K;GVOZ$@P:*\T\?2(+SV(+[XO<"T
MS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,Y"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T
M<B`B4U%,(+RMN?:_H2#!HKS3Q](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,C(U(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,3DV(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#$*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P.0HC+"!F=7IZ>0IM<V=I
M9"`B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(E9&4R#&Q,#/
M("5S+R5SP+LHN*8I(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C,V-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB
M"FUS9W-T<B`B=F9S<F]O=""U\+>ZQ>2XKKBF(,#0P+L@O/8@OOB]P+3/M-DN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S4T(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C(U-@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R
M96%T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")V9G-R;V]T(+7PM[K%Y+BN
MN*8@P-#`NR"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,3(T"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E871E
M(%9&4R!F:6QE+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#F
MQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HR.#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C
M<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(E9&4R#&Q,#/("5S
M+R5SP+LHN*8I(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR-C4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T
M;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@(E9&4R#&Q,#/("5S
M+R5SP+LHN*8I(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O=&%R+G!H<#HW-@HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(E5N
M86)L92!T;R!D96-O;7!R97-S(&1A=&$N(@IM<V=S='(@(LBOL.:\L\&DP+L@
MNJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z,C(T(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,CDX"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<
M(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S='(@(G9F<W)O
M;W0@M?"WNL7DN*ZXIB#`T,"[(+SV(+[XO<"TS[39+B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z-S@@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z
M("5S+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@
MOOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,Q
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,SDR"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HS,3$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C,S-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS
M9W-T<B`B=F9S<F]O=""U\+>ZQ>2XKKBF(,#0P+L@O/8@OOB]P+3/M-DN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T."!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4R"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM
M<V=S='(@(G9F<W)O;W0@M?"WNL7DN*ZXIB#`T,"[(+SV(+[XO<"TS[39+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S-R!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HS,S4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T,PHC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0T"B,L(&9U>GIY
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(G9F<W)O;W0@M?"WNL7DN*ZXIB#`T,"[(+SV(+[XO<"TS[39+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#$W(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z-#(Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("*U
M\+>ZQ>2XKB"PR[OVO\"W^3H@)7,B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C(P-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(E9&4R#&Q,#/
M("5S+R5SP+LHN*8I(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HS,#,@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HR.#@*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$V-R!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HQ.#<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C,X,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,SDQ"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE
M+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]
MP+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-#0*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5SP+LHN*8I
M(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C0P-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R(")61E,@
MQL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,#,*(RP@9G5Z>GD*;7-G:60@(E5N
M86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@
M(G9F<W)O;W0@M?"WNL7DN*ZXIB#`T,"[(+SV(+[XO<"TS[39+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C`S"FUS9VED(")5;F%B
M;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+G!H<#HT-3$@9G)A;65W;W)K
M+TYE=%])35-0+TE-4U`O075T:"YP:'`Z,3$X"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G
M<W1R("(E<R#!I,#'N*8@P-#`NR"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ
M-C8@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$W,0HC+"!F=7IZ
M>0IM<V=I9"`B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(E9&
M4R#&Q,#/("5S+R5SP+LHN*8I(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.CDS(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z,3`R"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-C0X
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.3@*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB
M"FUS9W-T<B`B5D93(,;$P,\@)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[XO<"T
MS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(W-R!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S,*(RP@9G5Z>GD*;7-G:60@(E5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R(")61E,@
MQL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z.#`@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HW,@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N
M(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5SP+LHN*8I(+JOL.;'TB"\]B"^^+W`
MM,^TV2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C0U"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D
M(&%R8VAI=F4N(@IM<V=S='(@(LBOL.:\L\&DP+L@NJ^PYL?2(+SV(+[XO<"T
MS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX,S4*(RP@9G5Z>GD*
M;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A
M:6QE9"DN(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5SP+LHN*8I(+JOL.;'TB"\
M]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#8V"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL
M95-I>F4H*2!F86EL960I+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF
M*2"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(
M86YD;&5R+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"B,L(&9U>GIY"FUS
M9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`B5D93(,;$P,\@
M)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C8V.0IM<V=I9"`B56YA8FQE('1O(')E860@
M=&AE('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R(")V9G-R;V]T(+7PM[K%
MY+BNN*8@P-#`NR"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C$Q,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@
M97AI<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HR.3,*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B=F9S<F]O=""U\+>ZQ>2XKKBF(,#0
MP+L@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HS,CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R
M96YA;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(E9&4R#&Q,#/("5S
M+R5SP+LHN*8I(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C(V-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C,T,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E
M;F%M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5S
MP+LHN*8I(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HV,3`@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C(R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE("5S+R5S+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF*2"Z
MK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HS,C,@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(Q,PHC.B!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#4R(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HR.#4*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C,P,0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92XB"FUS9W-T<B`B5D93(,;$P,\@)7,O)7/`NRBXIBD@NJ^P
MYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B56YA
M8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5S
MP+LHN*8I(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@
M=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R("+`S""_]K7E
MN:Z\K;BF(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C$T.2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$U
M,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B5D93(,;$P,\@)7,O)7/`NRBX
MIBD@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C$W.0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B5D93(,;$P,\@
M)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,3,X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ-#,*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL
M92!D871A+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@
MO/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@T,0HC
M+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T
M82!W:6QL(&)E(&5X8V5E9&5D+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[
M*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM
M<V=S='(@(KG8P=DB"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHV"FUS
M9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`BNJ^PYKOGQ]<@M<>UN;BNL>(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S
M"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("*XML'V
MN+<@N.VWR2##Z[S2(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,C(S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,Y,`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E
M<G9E<B!O;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,0HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S@*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@T"FUS9VED(")5;F5X<&5C=&5D(')E
M<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*(RP@9G5Z
M>GD*;7-G:60@(E5N9FEL960B"FUS9W-T<B`BP-#!]B"^RL"Z(+C>P,\B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B56YI8V]D92`H551&
M+3@I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"B,L(&9U>GIY"FUS9VED(")5
M;FET960@07)A8B!%;6ER871E<R(*;7-G<W1R("*YS+&Y(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<T"FUS9VED(")5;FET960@2VEN9V1O;2(*;7-G<W1R("*_M;&Y(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R("*YS+&Y
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,SD@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/
M=71L>6EN9R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HV.2!L:6(O0FQO8VLO;65T87(N<&AP.C<Q"FUS9VED
M(")5;FET<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,CD@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#,P
M"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W
M;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*
M;7-G:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U
M.0IM<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDQ"B,L(&9U>GIY"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A
M<W-W;W)D+B(*;7-G<W1R("*[Y[_KP-K`S+BGL/H@OL_(H[BF(,#4M\+'S[R\
MO^0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-3@*;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT
M(@IM<V=S='(@(L?VP.<@O^2\TK^A(+BUQ:D@P::PQ2(*"B,Z(&9R86UE=V]R
M:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,CDV"FUS9VED(")5;FYA;65D(@IM
M<V=S='(@(L#,N*<@OOC`O2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL96=E9"!S8W)I
M<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A
M;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E
M(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB<VAO
M=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L
M:7!B;V%R9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@IM<V=I9"`B56YS970@8V]L;W(B
M"FUS9W-T<B`BN_:Q\B#!IK#%(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HV.#8@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HY,C8*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,S(*
M;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$Y-R!T96UP;&%T97,O861M
M:6XO=7-E<B]L:7-T+FEN8SHS,PHC+"!F=7IZ>0IM<V=I9"`B57!D871E(@IM
M<V=S='(@(L#/P-HB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C(Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B
M"FUS9W-T<B`BP,_`VB(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z-S8*(RP@9G5Z>GD*;7-G:60@(E5P9&%T92!U<V5R(@IM<V=S='(@
M(KOGO^O`VB##W["A(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO
M<&5R;7,O961I="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR
M,S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@7"(E<UPB
M+B(*;7-G<W1R("*[Y[_KP-H@P]^PH2(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C@S"FUS9VED(")5<&=R861E('-C<FEP="!D96QE=&5D+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ.3D*;7-G:60@(E5P;&]A
M9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS
M9VED(")5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@
M=&AE('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@
M;&%T:6X@;&5T=&5R<R(*;7-G<W1R("*V\\:^ONX@M.NYKL#:(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ
M.`IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("*WSKBV(+3K
MN:[`VB"\_<#:(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA
M9V5R+G!H<#HT-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U
M<G)E;G0Z("5S(@IM<V=S='(@(L?VP.<@O;K%N,#/(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S
M92!34TPB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R
M-`IM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O
M<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]E9&ET+FEN8SHR,0HC+"!F=7IZ>0IM<V=I9"`B57-E<B(*;7-G
M<W1R("*[Y[_KP-JX[2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I
M<W1R>2YP:'`Z-S(S"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@
M;F]T(&%U=&AO<FES960@9F]R("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HR,#,*(RP@9G5Z>GD*;7-G:60@(E5S97(@061M:6YI<W1R871I
M;VXB"FUS9W-T<B`B2&]R9&4@N^>_Z\#:(+#\N*XB"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C(U,0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM
M<V=S='(@(KOGO^O`VB"\L<7#N^?'UR(*"B,Z('-I9VYU<"YP:'`Z-C(*(RP@
M9G5Z>GD*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(DAO<F1E
M(+OGO^O`VB"P_+BN(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I9"`B57-E<B!2
M96=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0V.0IM<V=I
M9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP
M.CDX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$U,"!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,PHC.B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C<R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G<W1R("*[Y[_KP-JX
M[2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HQ,C0*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A;')E
M861Y(&5X:7-T<RXB"FUS9W-T<B`BN-[`S\?4(%PB)7-<(K"A(,#,N<P@N^>_
MZ\'?P-2TS[39+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX
M-PHC+"!F=7IZ>0IM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(KOGO^O`VKCM
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`HC+"!F=7IZ>0IM
M<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R("*[Y[_KP-JX[2(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN('1H
M92!S>7-T96TZ(@IM<V=S='(@(KW#O;K%V\#'(+OGO^O`VCHB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$T"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C$V,R!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E
M<R!N;W0@97AI<W0N(@IM<V=S='(@(L7KP?8@N*Z]NK/*("5SP+LHN*8I(,.C
MP+L@O/8@OOB]P+3/M-DN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$Q.`HC+"!F=7IZ>0IM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`BO<?'X"(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@V-@IM<V=I9"`B5F%L:60@
M;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.`IM<V=I9"`B5F%L:61I
M='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU.3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C4U"FUS9VED(")686QU92!I;B!M:6YU=&5S
M(&9R;VT@;F]W+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HX-38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$W-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T
M:"!O9B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(T-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8V"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(S,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,CDR.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N
M<&AP.C4Y"FUS9VED(")686QU97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C$P.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,3@V"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0T"B,L(&9U>GIY"FUS9VED
M(")687)I86)L92(*;7-G<W1R("+!IKCQ(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I
M9"`B5F5N97IU96QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED(")697)I9FEC871I;VX@9F%I;&5D
M("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HW,#`*(RP@9G5Z>GD*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`BL+/`SB"X
MWL#/(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R-@HC+"!F=7IZ
M>0IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(K"SP,X@N-[`SR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#,*;7-G:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(KSVP?<@P:2W
MQ"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`BO/;!]R##I+_R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M,PHC+"!F=7IZ>0IM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(KSVP?<@P:2W
MQ"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P
M"FUS9VED(")697)Y($AI9V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@HC
M+"!F=7IZ>0IM<V=I9"`B5FEE="!.86TB"FUS9W-T<B`BQ\JUY<#,N*<B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5FEE=&YA;65S92`H
M5DE30TE)*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HY-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*
M;7-G<W1R("(E<R"ZN+'B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM
M<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,C$*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B)7,@
MNKBQXB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"
M<FET:7-H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I
M;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C`Y"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-C,*;7-G:60@(E9I<VEB:6QI
M='DZ("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D
M869O;F5I=&%L>5]S;71P+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@271A;'D@
M=FEA(%--5%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B
M5T%23B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'(2$A(%)%34]612!30U))
M4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G:60@(E=)3B!V:6$@
M2%144"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")786QL:7,@
M86YD($9U='5N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T
M:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C(W,B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z.#,*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`BL.:P
M[2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-3@*;7-G:60@(E=E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#(W"FUS9VED
M(")796%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DR"FUS9VED(")796%T:&5R+F-O;2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B
M5V5B(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M,S<*;7-G:60@(E=E8B!3:71E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*
M;7-G<W1R("*XQ<'6(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z
M,C@*;7-G:60@(E=E;&-O;64B"FUS9W-T<B`BR*^_M2(*"B,Z('1E;7!L871E
M<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHU-PHC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S
M='(@(LBOO[7'U;3/M-DA("5S(,#4M,^TV2XB"@HC.B!S97)V:6-E<R]P;W)T
M86PO;6]B:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`BR*^_
MM<?5M,^TV2P@)7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-0IM<V=I
M9"`B5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.38*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$U
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA
M<F$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E
M<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L
M:6UI=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`BL;BZT""YKL#:M,(@N:N^^<#4
MM,^Q[C\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I
M9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R("+`SK_K
M(+K.R*.TPB"YJ[[YP-2TS['N/R(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,#8Q"FUS9VED(")7:&5R96ES($%U<W1R86QI
M82!M87`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS
M9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$S,PIM<V=I9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@
M9F]R('1H92!2:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T"FUS
M9VED(")7:61T:"(*;7-G<W1R("*SRKKQ(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$R-0HC+"!F=7IZ>0IM<V=I9"`B5VED=&@@:6X@0U-3('5N
M:71S(@IM<V=S='(@(K/*NO$@M-S`IR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S
M(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI
M;BDZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS
M9W-T<B`BQZ7`QR"SRKKQ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G:60@(E=I9'1H('5N:70B"FUS9W-T<B`B
ML\JZ\2"TW,"G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G<W1R("*SRKKQ.B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,3,*;7-G:60@(E=I:VDB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,"!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-0HC+"!F=7IZ
M>0IM<V=I9"`B5VEN9"(*;7-G<W1R("+#H['B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*(RP@9G5Z>GD*;7-G:60@(E=I
M;F0@16%R;'DB"FUS9W-T<B`BPZ.QXB(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z.#`*;7-G:60@(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-38*(RP@9G5Z>GD*;7-G:60@(E=I
M;F0Z(@IM<V=S='(@(L.CL>(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C0R"B,L(&9U>GIY"FUS9VED(")7:6YD.B`B"FUS9W-T<B`BPZ.Q
MXB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-`HC+"!F=7IZ>0IM<V=I
M9"`B5VES9&]M(@IM<V=S='(@(L.CL>(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3DV"FUS9VED(")7:7-H;&ES="(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*(RP@9G5Z>GD*;7-G:60@(E=O<FLB
M"FUS9W-T<B`BML>TPB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$V-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(L'W
MP.4@P=:\TCHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(L'WP.4@P/S(
MK;GXR*,B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-CD@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G
M:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T
M960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HS,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@
M;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I
M;F<@82!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(T,PIM<V=I9"`B6"U2968B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV
M,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,@IM<V=I9"`B6#4P.78S($5X=&5N
M9&5D($ME>2!5<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S(%-U8FIE8W0@06QT
M97)N871I=F4@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y
M($ED96YT:69I97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV.#(*;7-G:60@(E@U,#EV,R!E>'1E;G-I;VYS(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")962(*
M;7-G<W1R(")962(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0U-0HC+"!F=7IZ>0IM<V=I9"`B65E962(*;7-G<W1R(")962(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3`X
M"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*
M;7-G<W1R("*XQ;/B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I9"`B
M665M96XB"FUS9W-T<B`BP-#`NB"XWL#/(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV,PIM<V=I9"`B665S(@IM<V=S='(@
M(K^Y(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT
M;6PZ-38*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R"FUS9VED(")9
M;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@
M<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`B5$585+CPM>7`U+3/
MM-DN(%L\/ET@N?;&L,"[(+2IN*.XZ2!765-)5UE'(+CPM>6WSB"UN;[&L*FT
MS[39+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HX,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M
M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$T,3$*;7-G:60@(EEO=2!A<F4@;F]T(&%U=&AE
M;G1I8V%T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])
M9&5N=&ET>2YP:'`Z,S`R"FUS9VED(")9;W4@8V%N(&YO="!H879E('1H92`G
M7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U-2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.3<U"B,L(&9U>GIY"FUS9VED(")9;W4@9&ED(&YO="!E
M;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S='(@(L#?N/BUR"#`
MS+C>P,\@P=:\TB(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(Y,`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M87`@
M86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R
M97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`BP-/&]\:NM<@@
MQL3`S\#'(+[NMK(@Q]>X\;6U(%1U<F)AP,<@Q]>X\;^A(+C"L-0@O+/!I,?/
MP?8@OLJ^TKW`M,^TV2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M.#@*;7-G:60@(EEO=2!H879E(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`B
MM\ZQU[[&O_0@Q\^_M+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C8Q"FUS9VED("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED
M(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N
M86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I
M>"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X
M.`HC+"!F=7IZ>0IM<V=I9"`B66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V
M86QU92XB"FUS9W-T<B`BP-^X^+7((,#,N-[`SR#!UKS2(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@;75S="!C
M;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0U-@IM
M<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS
M9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U
M(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`BN:[!IB"Z
MN+#MO*VXIB"ZN+.[L>+`_+^A(,#,N:[!IK^A(+3KQ]$@O+.X[<"[(,#4M\+'
MV+[?(,?5M,^TV2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E<B!T:&4@55),('=H
M97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`BP,P@N+7%J;"A(+"A
MN*[$H;3"(%523,"[(,#4M\+'V+[?(,?5M,^TV2XB"@HC.B!S97)V:6-E<R]P
M;W)T86PO<G!C<W5M+G!H<#HX,`HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@
M<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R("*XU<#Z
M(+OHP:;'TB"]Q+JPP-JXIB"\L<7#Q]B^WR#'U;3/M-DN(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3$Y"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y
M(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R("*[Z,&FQ](@N^>_
MZ\#:(,#,N*?`NR#`U+?"Q]B^WR#'U;3/M-DN(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3`P"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@
M<F5M;W9E+B(*;7-G<W1R("*[Z,&FQ](@N^>_Z\#:(,#,N*?`NR#`U+?"Q]B^
MWR#'U;3/M-DN(@H*(SH@861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHX"FUS9VED(")9;W4@;75S="!S<&5C:69Y
M('1H92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@(L/?L*''TB"[Y[_KP-H@
MP,RXI\"[(,#4M\+'V+[?(,?5M,^TV2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M-#8*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N
M86UE('1O('5P9&%T92XB"FUS9W-T<B`BP]^PH<?2(+OGO^O`VB#`S+BGP+L@
MP-2WPL?8OM\@Q]6TS[39+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]Z:7`N<&AP.C$S.`HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E
M8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R("*\]KW%P,[`
MS""^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O
M<GE-86YA9V5R+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@='EP
M92!A(&YE=R!C871E9V]R>2!N86UE+B(*;7-G<W1R("*[Z,&FQ](@N^>_Z\#:
M(,#,N*?`NR#`U+?"Q]B^WR#'U;3/M-DN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N
M965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<V"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE
M87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R("(E<R"\O+S'P,P@N+BWX;7'OOJ]
MP+3/M-DN(+39O<,@M\ZQU\#.Q\^\O+_D+B(*"B,Z('1E;7!L871E<R]P<F]B
M;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B
M"FUS9W-T<B`BP,RXWL#/(,'6O-(Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(Q,@IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R("*X
MWL#/(,'6O-(Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8T(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y"FUS9VED(")9;W5R($EN9F]R
M;6%T:6]N(@IM<V=S='(@(L&DNK@B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HY.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE
M="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@
M>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I='DL
M('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B66]U<B!.86UE(@IM
M<V=S='(@(L#,N*<Z(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N
M:6YC.C4*(RP@9G5Z>GD*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@
M8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U
M('=I<V@@=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O
M=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T
M:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*(K3GO<7`QR#`SL'UQ:RV\\#,OO#&
MKK"A(+OGO^O`VKBF(,/?L*''TB"\]B"^^+W`M,^TV2X@ML>TPB"TV;BE(,#,
MP*^WSB"[Y[_KP-H@(@HBP]^PH;'BM,G`NR"[Y[_KQ](@O/8@OOB]P+3/M-DN
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHU"FUS9VED
M("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P
M<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B"B)H87,@8F5E
M;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S='(@(B(*
M(K3GO<7`QR#`SL'UQ:RV\\#,OO#&KK"A(+OGO^O`VB"X\;?/NKBQXKBF(,'V
MO_C'S\'V(+[*O<"TS[39+B"VQ[3"(+39N*4@P,S`KR(*(K?.(+OGO^O`VB"X
M\;?/NKBQXKBF(+OGO^O'TB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HY.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U
M<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B
M96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO
M=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU,`IM<V=I9"`B66]U<B!B<F]W
M<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R("*Z
MZK;SO^S`^K"A(,#,(+'BM,G`NR#!]K_XQ\_!]B"^RKW`M,^TV2XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]P<FEN="YJ<SHT,@HC+"!F=7IZ>0IM<V=I
M9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN
M="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I
M;G0N(@IM<V=S='(@(B(*(KOGO^O'S[#M(+#HO<4@NNJV\[_LP/JTPB#`SKSB
M(+_)O,?`NR#!]K_XQ\_!]B"^RKW`M,^TV2X@P,Z\XL?/L>(@P*?'V+RMM,(@
MQ,$B"B+&KK?1+[_)O,?%L+_-(%"XIB"TJ;BCO+R_Y"XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C4W"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z
M;VYE.B(*;7-G<W1R("+']L#G(+W#L*.TZSHB"@HC.B!S97)V:6-E<R]P<F5F
M<RYP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET
M>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R("*QXKJ[(+W$NK#`VCHB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34X"FUS9VED(")9;W5R(&1E9F%U
M;'0@:61E;G1I='DZ(@IM<V=S='(@(K'BNKL@O<2ZL,#:.B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR,#$*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*
M;7-G<W1R("+`_,.\(,#,N*<Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP
M:'`Z,3`P,`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E
M9"XB"FUS9W-T<B`BO\F\Q\#,(,#ZP.6UQ[[ZO<"TS[39+B(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-30*;7-G:60@(EEO
M=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N
M(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`BP,P@O+R\QR"UO[[((+_)O,?`
MS"#`^L#EM<NTS[39+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,34V"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N
M(@IM<V=S='(@(K_)O,?`S"#`^L#EM<>^^KW`M,^TV2XB"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H
M87,@8F5E;B!R97-E="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E
M;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U
M<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.C<S,@IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP
M:7)E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C4X"B,L(&9U>GIY"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*
M;7-G<W1R("*XWL#/(,'6O-(Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-30@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I
M9"`B675G;W-L879I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$X"B,L(&9U>GIY"FUS9VED("):86ER92(*;7-G<W1R
M("+'RL7-(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-38@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H
M;&EG:'1Q=6]T97,N<&AP.C$W,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q
M=6]T94)L;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM
M<V=S='(@(EO`SK_K(+S[L>*QXETB"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H
M<#HX.`IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R(");O\"W^2"Z
MN+#MQ\^QXETB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K
M<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R(");
MP,Z_ZR"ZN+'B("TB"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R
M+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,L('!H<"UF;W)M870*;7-G:60@
M(EM3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM<V=S='(@(EO`SK_K
M(+JXL>(@+2`E<R#!V5TB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(");;&EN92`E<R!O9B`E<UTB"FUS
M9W-T<B`B6[;SP,X@)7,@+R`E<UTB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C$U-#$@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHQ,0IM<V=I
M9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E]!L/RXKB(*"B,Z(&QI8B]A
M<&DN<&AP.C$U-PIM<V=I9"`B7T-,22(*;7-G<W1R("(B"@HC.B!L:6(O87!I
M+G!H<#HQ-#$*(RP@9G5Z>GD*;7-G:60@(E]$871A5')E92(*;7-G<W1R("+`
MS\#:(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,Q"FUS9VED(")?1&5L971E(%)O=R(*;7-G<W1R(")?1,?@
M(,'VO_(B"@HC.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@(E]'<F]U<',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W
M-0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`BM;6_\KB[(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S"FUS9VED
M(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")?2;'7N+(@O-.\NBXN
M+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.30*(RP@
M9G5Z>GD*;7-G:60@(E],;V<@:6XB"FUS9W-T<B`BM\ZQU\#.(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I9"`B7TQO9R!O
M=70B"FUS9W-T<B`B7TRWSK'7OL:_]"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO9&EF
M>2!,:6YK+BXN(@IM<V=S='(@(E]MN+7%J2"\]L&D+BXN(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V-`IM<V=I9"`B7T]P=&EO;G,B
M"FUS9W-T<B`B7T^\L<7#N^?'UR(*"B,Z(&QI8B]A<&DN<&AP.C$S-PHC+"!F
M=7IZ>0IM<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@(L7DM]`B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C8*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R(")?<KBUQ:D@N^C!
MIBXN(@H*(SH@;&EB+V%P:2YP:'`Z,3(U"B,L(&9U>GIY"FUS9VED(")?4V5T
M=7`B"FUS9W-T<B`BN-Z]P\'V(+RQQ<,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L
M92!0<F]P97)T:65S+BXN(@IM<V=S='(@(E]TQZ4@O-.\NBXN+B(*"B,Z(&QI
M8B]A<&DN<&AP.C$R.0HC+"!F=7IZ>0IM<V=I9"`B7U5S97)S(@IM<V=S='(@
M(KOGO^O`VKCM(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C$*
M(RP@9G5Z>GD*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R("+!UKS2M\\B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S-`HC+"!F
M=7IZ>0IM<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`BP=:\TK?/
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3,*(RP@9G5Z>GD*
M;7-G:60@(F-A;&5N9&%R(@IM<V=S='(@(K3>M\(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U.`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R("+#Z[S2(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A
M;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O
M<&5N(&EN<'5T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C4Y,@IM<V=I9"`B8VQI8VL@:&5R92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R,@IM<V=I
M9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<X"B,L(&9U>GIY"FUS
M9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(KC>P,\@O*VY]B#!
MI+JXN^?'UR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,34T"FUS9VED(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(V
M"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$X,@HC+"!F=7IZ>0IM<V=I
M9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S='(@(L7KP?8@N*Z]NK/*("5SP+LH
MN*8I(,.CP+L@O/8@OOB]P+3/M-DN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-S$*;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4U"B,L(&9U
M>GIY"FUS9VED(")F:6QE(@IM<V=S='(@(L&FN/$B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$W-"!L:6(O0FQO8VLO;65T87(N<&AP.C,V,"!L:6(O0FQO
M8VLO;65T87(N<&AP.C,X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H
M92`E<R`H)7,I(&%T("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-3`*(RP@9G5Z>GD*;7-G:60@(F=U<W1I;F<B
M"FUS9W-T<B`B.+_Y(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(T.0IM<V=I9"`B:#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U.`IM<V=I9"`B:&@B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ,S@*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(R,PIM<V=I9"`B:6UM961I871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"B,L(&9U
M>GIY"FUS9VED(")I;FQI;F4B"FUS9W-T<B`BOOC`O2(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,38R"FUS9VED(")I;G!U="]O=71P
M=70@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO
M8VMS+FIS.C$S"FUS9VED(")L:6YE<UTB"FUS9W-T<B`BP=E=(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S
M"B,L('!H<"UF;W)M870*;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W
M:&EL92!M86MI;F<@25-/+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S8Y"FUS9VED(")M;2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(Y,2!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S:61E8F%R+G!H<#HR,S(*;7-G:60@(FYA;64B"FUS9W-T<B`BP,RXIR(*
M"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ,C$*(RP@9G5Z>GD*;7-G:60@
M(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R("*[Z,&FM<?!]B"^RL"Z(+C>P,\B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,3D*(RP@
M9G5Z>GD*;7-G:60@(FYO="!Y970@:6UP;&5M96YT960B"FUS9W-T<B`BN^C!
MIK7'P?8@OLK`NB"XWL#/(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,#4*(RP@9G5Z>GD*;7-G:60@(FYO=&5P860B"FUS9W-T<B`BP-#!]B"^
MRL"Z(+C>P,\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@X"FUS9VED(")P97)C96YT(@IM<V=S='(@(L;;O+[&
MKB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<T"B,L
M(&9U>GIY"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R("*PL\#.
M(+C>P,\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS9W-T<B`BQ\B\OR(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED(")R
M96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*(RP@9G5Z>GD*;7-G
M:60@(G)I<VEN9R(*;7-G<W1R("*PYK#M(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ-#(*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B
M;&4B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HY.0HC
M+"!F=7IZ>0IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R("*[Y[_K
MP-H@R*^PYB(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C,X-0IM<V=I9"`B<W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S(*(RP@9G5Z>GD*;7-G:60@(G-T96%D
M>2(*;7-G<W1R("+`T,'V(+[*P+H@N-[`SR(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,S`Y"FUS9VED(")S=VET8V@@;V9F(&IA=F%S8W)I<'0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR.0HC+"!F=7IZ>0IM<V=I9"`B=&%S
M:R!L:7-T(@IM<V=S='(@(KSVO<6PQ;K.(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S`U
M"B,L(&9U>GIY"FUS9VED(")T<GD@86=A:6XB"FUS9W-T<B`BN/"UYR"WSK'7
MP,XB"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")T>7!E('1H92!P87-S=V]R9"!T=VEC
M92!T;R!C;VYF:7)M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N
M<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"B,L(&9U>GIY"FUS9VED
M(")U;FEF:65D(@IM<V=S='(@(L#0P?8@OLK`NB"XWL#/(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]087)T+G!H<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G
M<W1R("+`S+BG(+[XP+TB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*(RP@9G5Z>GD*;7-G:60@(G5S97(@
M<V5L96-T(@IM<V=S='(@(K'4Q*(HM_PI(+RQQ<,@O\"W^2(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I9"`B=D-A
M<F0B"FUS9W-T<B`B=D-A<F0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C0Q"B,L(&9U>GIY"FUS9VED(")W.B(*;7-G<W1R
M("+`_+3>.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS
M9VED(")W96%T:&5R+F-O;2(*;7-G<W1R("(B"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<P``````````````````````
M````````````````````````````````````````````````````````````
M`````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P
M-3$U-#,S-S0S(#`Q-S$U,``@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S
M+VQD87``````````````````````````````````````````````````````
M````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W-#,@,#(P,#<P`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W-C<FEP=',O;&1A<"]H;W)D92YS8VAE;6$`````````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`S-#4P-B`Q,#4Q-30S,S<T,R`P
M,C(T-#(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````(R`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O;&1A<"]H;W)D92YS8VAE;6$L
M=B`Q+C(P+C$P+C4@,C`P-2\Q,"\Q."`Q,3HS-#HP,"!J86X@17AP("0*(PHC
M(%1H92!O9F9I8V%L(&AO<F1E($])1"!A<W-I9VYE9"!B>2!)04Y!(&ES(#$S
M,#0P+@HC"B,@5&AI<R!S8VAE;6$@9&5P96YD<R!O;CH*(PDM(&-O<F4N<V-H
M96UA"B,*(R`*(R!(;W)D92!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ
M+C$S,#0P+C(N,2XJ"B,@24U0(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT
M+C$N,3,P-#`N,RXQ+BH*(R!4=7)B82!A='1R:6)U=&4@8G)A;F-H(#$N,RXV
M+C$N-"XQ+C$S,#0P+C0N,2XJ"B,@2W)O;F]L:71H(&%T=')I8G5T92!B<F%N
M8V@@,2XS+C8N,2XT+C$N,3,P-#`N-2XQ+BH*(R!.86<@871T<FEB=71E(&)R
M86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XV+C$N*@HC($=O;&QE;2!A='1R:6)U
M=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C<N,2XJ"B,@0VAO<F$@871T
M<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XX+C$N*@HC($UN96UO
M(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N.2XQ+BH*(R!4
M<F]L;"!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C$P+C$N
M*@HC($ML=71Z(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N
M,3$N,2XJ"B,@2F]N86@@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ
M,S`T,"XQ,BXQ+BH*(R!(97)M97,@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ
M+C0N,2XQ,S`T,"XQ,RXQ+BH*(R!*=6YO(&%T=')I8G5T92!B<F%N8V@@,2XS
M+C8N,2XT+C$N,3,P-#`N,30N,2XJ"B,@5')E86X@871T<FEB=71E(&)R86YC
M:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ-2XQ+BH*(R!7:'5P<R!A='1R:6)U=&4@
M8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C$V+C$N*@HC($EN9V\@871T<FEB
M=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ-RXQ+BH*(R!!;G-E;"!A
M='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C$X+C$N*@HC($=E
M;FEE(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,3DN,2XJ
M"B,@4V-R>2!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C(P
M+C$N*@HC(%=I8VME9"!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S
M,#0P+C(Q+C$N*@HC($%G;W)A(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT
M+C$N,3,P-#`N,C(N,2XJ"B,@1V]O<',@871T<FEB=71E(&)R86YC:"`Q+C,N
M-BXQ+C0N,2XQ,S`T,"XR-"XQ+BH*(R!-97)K(&%T=')I8G5T92!B<F%N8V@@
M,2XS+C8N,2XT+C$N,3,P-#`N,C4N,2XJ"B,@36EM<"!A='1R:6)U=&4@8G)A
M;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C(V+C$N*@HC($UO='1L92!A='1R:6)U
M=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C(W+C$N*@HC($YI8R!A='1R
M:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C(X+C$N*@HC($]C8V%M
M(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,CDN,2XJ"B,@
M3V1I;B!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C,P+C$N
M*@HC(%)A:VEM(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N
M,S$N,2XJ"B,@4V5S:&$@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ
M,S`T,"XS,BXQ+BH*(R!3=V]O<V@@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ
M+C0N,2XQ,S`T,"XS,RXQ+BH*(R!4:&]R(&%T=')I8G5T92!B<F%N8V@@,2XS
M+C8N,2XT+C$N,3,P-#`N,S0N,2XJ"B,@56QA9F]R;2!A='1R:6)U=&4@8G)A
M;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C,U+C$N*@HC(%9O;&]S(&%T=')I8G5T
M92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,S8N,2XJ"B,@"B,@2&]R9&4@
M;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C(N,BXJ"B,@
M24U0(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS+C(N
M*@HC(%1U<F)A(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T
M,"XT+C(N*@HC($MR;VYO;&ET:"!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N
M,2XT+C$N,3,P-#`N-2XR+BH*(R!.04<@;V)J96-T8VQA<W,@8G)A;F-H(#$N
M,RXV+C$N-"XQ+C$S,#0P+C8N,BXJ"B,@1V]L;&5M(&]B:F5C=&-L87-S(&)R
M86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XW+C(N*@HC($-H;W)A(&]B:F5C=&-L
M87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XX+C(N*@HC($UN96UO(&]B
M:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XY+C(N*@HC(%1R
M;VQL(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ,"XR
M+BH*(R!+;'5T>B!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P
M-#`N,3$N,BXJ"B,@2F]N86@@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N
M-"XQ+C$S,#0P+C$R+C(N*@HC($AE<FUE<R!O8FIE8W1C;&%S<R!B<F%N8V@@
M,2XS+C8N,2XT+C$N,3,P-#`N,3,N,BXJ"B,@2G5N;R!O8FIE8W1C;&%S<R!B
M<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,30N,BXJ"B,@5')E86X@;V)J96-T
M8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C$U+C(N*@HC(%=H=7!S
M(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ-BXR+BH*
M(R!);F=O(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ
M-RXR+BH*(R!!;G-E;"!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N
M,3,P-#`N,3@N,BXJ"B,@1V5N:64@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV
M+C$N-"XQ+C$S,#0P+C$Y+C(N*@HC(%-C<GD@;V)J96-T8VQA<W,@8G)A;F-H
M(#$N,RXV+C$N-"XQ+C$S,#0P+C(P+C(N*@HC(%=I8VME9"!O8FIE8W1C;&%S
M<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,C$N,BXJ"B,@06=O<F$@;V)J
M96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C(R+C(N*@HC($=O
M;W!S(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR-"XR
M+BH*(R!-97)K(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T
M,"XR-2XR+BH*(R!-:6UP(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N
M,2XQ,S`T,"XR-BXR+BH*(R!-;W1T;&4@;V)J96-T8VQA<W,@8G)A;F-H(#$N
M,RXV+C$N-"XQ+C$S,#0P+C(W+C(N*@HC($YI8R!O8FIE8W1C;&%S<R!B<F%N
M8V@@,2XS+C8N,2XT+C$N,3,P-#`N,C@N,BXJ"B,@3V-C86T@;V)J96-T8VQA
M<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C(Y+C(N*@HC($]D:6X@;V)J
M96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C,P+C(N*@HC(%)A
M:VEM(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS,2XR
M+BH*(R!397-H82!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P
M-#`N,S(N,BXJ"B,@4W=O;W-H(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ
M+C0N,2XQ,S`T,"XS,RXR+BH*(R!4:&]R(&]B:F5C=&-L87-S(&)R86YC:"`Q
M+C,N-BXQ+C0N,2XQ,S`T,"XS-"XR+BH*(R!5;&%F;W)M(&]B:F5C=&-L87-S
M(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS-2XR+BH*(R!6;VQO<R!O8FIE
M8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,S8N,BXJ"@HC"B,@
M2&]R9&4@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR+C$N
M*@HC"F%T=')I8G5T971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR+C$N,0H)
M3D%-12`G:&]R9&50<F5F<R<*"41%4T,@)TAO<F1E(%!R969E<F5N8V5S)PH)
M15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT
M+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($E-4"!A='1R:6)U
M=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C,N,2XJ"B,*871T<FEB=71E
M='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C,N,2XQ"@E.04U%("=I;7!0<F5F
M<R<*"41%4T,@)TE-4"!0<F5F97)E;F-E<R<*"45154%,2519(&-A<V5)9VYO
M<F5)035-871C:`H)4UE.5$%8(#$N,RXV+C$N-"XQ+C$T-C8N,3$U+C$R,2XQ
M+C(V>S$P,C1]("D*"B,*(R!4=7)B82!A='1R:6)U=&4@8G)A;F-H(#$N,RXV
M+C$N-"XQ+C$S,#0P+C0N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N
M-"XQ+C$S,#0P+C0N,2XQ"@E.04U%("=T=7)B85!R969S)PH)1$530R`G5'5R
M8F$@4')E9F5R96YC97,G"@E%455!3$E462!C87-E26=N;W)E24$U36%T8V@*
M"5-93E1!6"`Q+C,N-BXQ+C0N,2XQ-#8V+C$Q-2XQ,C$N,2XR-GLQ,#(T?2`I
M"@IA='1R:6)U=&5T>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N-"XQ+C(*"4Y!
M344@)W1U<F)A5'EP92<*"41%4T,@)U1U<F)A($]B:F5C="!4>7!E.B!#;VYT
M86-T+TQI<W0G"@E%455!3$E462!C87-E26=N;W)E24$U36%T8V@*"5-50E-4
M4B!C87-E26=N;W)E24$U4W5B<W1R:6YG<TUA=&-H"@E364Y405@@,2XS+C8N
M,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[.'T@*0H*871T<FEB=71E='EP92`H
M(#$N,RXV+C$N-"XQ+C$S,#0P+C0N,2XS"@E.04U%("=T=7)B84UE;6)E<G,G
M"@E$15-#("=%;F-O9&5D(&UE;6)E<G,@;V8@82!4=7)B82!L:7-T)PH)4U50
M(&YA;64@*0H*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C0N
M,2XT"@E.04U%("=T=7)B85!'4%!U8FQI8TME>2<*"41%4T,@)U!'4"]'4$<@
M4'5B;&EC($ME>2<*("`@("`@("!%455!3$E462!C87-E26=N;W)E24$U36%T
M8V@*"5-93E1!6"`Q+C,N-BXQ+C0N,2XQ-#8V+C$Q-2XQ,C$N,2XR-GLT,#`P
M?2`I"@HC"B,@2W)O;F]L:71H(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT
M+C$N,3,P-#`N-2XQ+BH*(PIA='1R:6)U=&5T>7!E("@@,2XS+C8N,2XT+C$N
M,3,P-#`N-2XQ+C$*"4Y!344@)VMR;VYO;&ET:%!R969S)PH)1$530R`G2W)O
M;F]L:71H(%!R969E<F5N8V5S)PH)15%504Q)5%D@8V%S94EG;F]R94E!-4UA
M=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R
M-'T@*0H*(PHC($YA9R!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S
M,#0P+C8N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P
M+C8N,2XQ"@E.04U%("=N86=0<F5F<R<*"41%4T,@)TYA9R!0<F5F97)E;F-E
M<R<*"45154%,2519(&-A<V5)9VYO<F5)035-871C:`H)4UE.5$%8(#$N,RXV
M+C$N-"XQ+C$T-C8N,3$U+C$R,2XQ+C(V>S$P,C1]("D*"B,*(R!';VQL96T@
M871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XW+C$N*@HC"F%T
M=')I8G5T971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XW+C$N,0H)3D%-12`G
M9V]L;&5M4')E9G,G"@E$15-#("=';VQL96T@4')E9F5R96YC97,G"@E%455!
M3$E462!C87-E26=N;W)E24$U36%T8V@*"5-93E1!6"`Q+C,N-BXQ+C0N,2XQ
M-#8V+C$Q-2XQ,C$N,2XR-GLQ,#(T?2`I"@HC"B,@0VAO<F$@871T<FEB=71E
M(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XX+C$N*@HC"F%T=')I8G5T971Y
M<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XX+C$N,0H)3D%-12`G8VAO<F%0<F5F
M<R<*"41%4T,@)T-H;W)A(%!R969E<F5N8V5S)PH)15%504Q)5%D@8V%S94EG
M;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q
M+C$N,C9[,3`R-'T@*0H*(PHC($UN96UO(&%T=')I8G5T92!B<F%N8V@@,2XS
M+C8N,2XT+C$N,3,P-#`N.2XQ+BH*(PIA='1R:6)U=&5T>7!E("@@,2XS+C8N
M,2XT+C$N,3,P-#`N.2XQ+C$*"4Y!344@)VUN96UO4')E9G,G"@E$15-#("=-
M;F5M;R!0<F5F97)E;F-E<R<*"45154%,2519(&-A<V5)9VYO<F5)035-871C
M:`H)4UE.5$%8(#$N,RXV+C$N-"XQ+C$T-C8N,3$U+C$R,2XQ+C(V>S$P,C1]
M("D*"B,*(R!4<F]L;"!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S
M,#0P+C$P+C$N*@HC"F%T=')I8G5T971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T
M,"XQ,"XQ+C$*"4Y!344@)W1R;VQL4')E9G,G"@E$15-#("=4<F]L;"!0<F5F
M97)E;F-E<R<*"45154%,2519(&-A<V5)9VYO<F5)035-871C:`H)4UE.5$%8
M(#$N,RXV+C$N-"XQ+C$T-C8N,3$U+C$R,2XQ+C(V>S$P,C1]("D*"B,*(R!+
M;'5T>B!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C$Q+C$N
M*@HC"F%T=')I8G5T971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ,2XQ+C$*
M"4Y!344@)VML=71Z4')E9G,G"@E$15-#("=+;'5T>B!0<F5F97)E;F-E<R<*
M"45154%,2519(&-A<V5)9VYO<F5)035-871C:`H)4UE.5$%8(#$N,RXV+C$N
M-"XQ+C$T-C8N,3$U+C$R,2XQ+C(V>S$P,C1]("D*"B,*(R!*;VYA:"!A='1R
M:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C$R+C$N*@HC"F%T=')I
M8G5T971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ,BXQ+C$*"4Y!344@)VIO
M;F%H4')E9G,G"@E$15-#("=*;VYA:"!0<F5F97)E;F-E<R<*"45154%,2519
M(&-A<V5)9VYO<F5)035-871C:`H)4UE.5$%8(#$N,RXV+C$N-"XQ+C$T-C8N
M,3$U+C$R,2XQ+C(V>S$P,C1]("D*"B,*(R!(97)M97,@871T<FEB=71E(&)R
M86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ,RXQ+BH*(PIA='1R:6)U=&5T>7!E
M("@@,2XS+C8N,2XT+C$N,3,P-#`N,3,N,2XQ"@E.04U%("=H97)M97-0<F5F
M<R<*"41%4T,@)TAE<FUE<R!0<F5F97)E;F-E<R<*"45154%,2519(&-A<V5)
M9VYO<F5)035-871C:`H)4UE.5$%8(#$N,RXV+C$N-"XQ+C$T-C8N,3$U+C$R
M,2XQ+C(V>S$P,C1]("D*"B,*(R!*=6YO(&%T=')I8G5T92!B<F%N8V@@,2XS
M+C8N,2XT+C$N,3,P-#`N,30N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV
M+C$N-"XQ+C$S,#0P+C$T+C$N,0H)3D%-12`G:G5N;U!R969S)PH)1$530R`G
M2G5N;R!0<F5F97)E;F-E<R<*"45154%,2519(&-A<V5)9VYO<F5)035-871C
M:`H)4UE.5$%8(#$N,RXV+C$N-"XQ+C$T-C8N,3$U+C$R,2XQ+C(V>S$P,C1]
M("D*"B,*(R!4<F5A;B!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S
M,#0P+C$U+C$N*@HC"F%T=')I8G5T971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T
M,"XQ-2XQ+C$*"4Y!344@)W1R96%N4')E9G,G"@E$15-#("=4<F5A;B!0<F5F
M97)E;F-E<R<*"45154%,2519(&-A<V5)9VYO<F5)035-871C:`H)4UE.5$%8
M(#$N,RXV+C$N-"XQ+C$T-C8N,3$U+C$R,2XQ+C(V>S$P,C1]("D*"B,*(R!7
M:'5P<R!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C$V+C$N
M*@HC"F%T=')I8G5T971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ-BXQ+C$*
M"4Y!344@)W=H=7!S4')E9G,G"@E$15-#("=7:'5P<R!0<F5F97)E;F-E<R<*
M"45154%,2519(&-A<V5)9VYO<F5)035-871C:`H)4UE.5$%8(#$N,RXV+C$N
M-"XQ+C$T-C8N,3$U+C$R,2XQ+C(V>S$P,C1]("D*"B,*(R!);F=O(&%T=')I
M8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,3<N,2XJ"B,*871T<FEB
M=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C$W+C$N,0H@("`@("`@3D%-
M12`G:6YG;U!R969S)PH@("`@("`@1$530R`G26YG;R!0<F5F97)E;F-E<R<*
M("`@("`@($5154%,2519(&-A<V5)9VYO<F5)035-871C:`H@("`@("`@4UE.
M5$%8(#$N,RXV+C$N-"XQ+C$T-C8N,3$U+C$R,2XQ+C(V>S$P,C1]("D*"B,*
M(R!!;G-E;"!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C$X
M+C$N*@HC"F%T=')I8G5T971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ."XQ
M+C$*("`@("`@($Y!344@)V%N<V5L4')E9G,G"B`@("`@("!$15-#("=!;G-E
M;"!0<F5F97)E;F-E<R<*("`@("`@($5154%,2519(&-A<V5)9VYO<F5)035-
M871C:`H@("`@("`@4UE.5$%8(#$N,RXV+C$N-"XQ+C$T-C8N,3$U+C$R,2XQ
M+C(V>S$P,C1]("D*"B,*(R!'96YI92!A='1R:6)U=&4@8G)A;F-H(#$N,RXV
M+C$N-"XQ+C$S,#0P+C$Y+C$N*@HC"F%T=')I8G5T971Y<&4@*"`Q+C,N-BXQ
M+C0N,2XQ,S`T,"XQ.2XQ+C$*"4Y!344@)V=E;FEE4')E9G,G"@E$15-#("='
M96YI92!0<F5F97)E;F-E<R<*"45154%,2519(&-A<V5)9VYO<F5)035-871C
M:`H)4UE.5$%8(#$N,RXV+C$N-"XQ+C$T-C8N,3$U+C$R,2XQ+C(V>S$P,C1]
M("D*"B,*(R!38W)Y(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P
M-#`N,C`N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P
M+C(P+C$N,0H)3D%-12`G<V-R>5!R969S)PH)1$530R`G4V-R>2!0<F5F97)E
M;F-E<R<*"45154%,2519(&-A<V5)9VYO<F5)035-871C:`H)4UE.5$%8(#$N
M,RXV+C$N-"XQ+C$T-C8N,3$U+C$R,2XQ+C(V>S$P,C1]("D*"B,*(R!7:6-K
M960@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR,2XQ+BH*
M(PIA='1R:6)U=&5T>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N,C$N,2XQ"@E.
M04U%("=W:6-K9610<F5F<R<*"41%4T,@)U=I8VME9"!0<F5F97)E;F-E<R<*
M"45154%,2519(&-A<V5)9VYO<F5)035-871C:`H)4UE.5$%8(#$N,RXV+C$N
M-"XQ+C$T-C8N,3$U+C$R,2XQ+C(V>S$P,C1]("D*"B,*(R!!9V]R82!A='1R
M:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C(R+C$N*@HC"F%T=')I
M8G5T971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR,BXQ+C$*("`@("`@("!.
M04U%("=A9V]R85!R969S)PH@("`@("`@($1%4T,@)T%G;W)A(%!R969E<F5N
M8V5S)PH@("`@("`@($5154%,2519(&-A<V5)9VYO<F5)035-871C:`H)4UE.
M5$%8(#$N,RXV+C$N-"XQ+C$T-C8N,3$U+C$R,2XQ+C(V>S$P,C1]("D*"B,*
M(R!';V]P<R!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C(T
M+C$N*@HC"F%T=')I8G5T971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR-"XQ
M+C$*("`@("`@("!.04U%("=G;V]P<U!R969S)PH@("`@("`@($1%4T,@)T=O
M;W!S(%!R969E<F5N8V5S)PH@("`@("`@($5154%,2519(&-A<V5)9VYO<F5)
M035-871C:`H)4UE.5$%8(#$N,RXV+C$N-"XQ+C$T-C8N,3$U+C$R,2XQ+C(V
M>S$P,C1]("D*"B,*(R!-97)K(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT
M+C$N,3,P-#`N,C4N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ
M+C$S,#0P+C(U+C$N,0H@("`@("`@($Y!344@)VUE<FM0<F5F<R<*("`@("`@
M("!$15-#("=-97)K(%!R969E<F5N8V5S)PH@("`@("`@($5154%,2519(&-A
M<V5)9VYO<F5)035-871C:`H)4UE.5$%8(#$N,RXV+C$N-"XQ+C$T-C8N,3$U
M+C$R,2XQ+C(V>S$P,C1]("D*"B,*(R!-:6UP(&%T=')I8G5T92!B<F%N8V@@
M,2XS+C8N,2XT+C$N,3,P-#`N,C8N,2XJ"B,*871T<FEB=71E='EP92`H(#$N
M,RXV+C$N-"XQ+C$S,#0P+C(V+C$N,0H@("`@("`@($Y!344@)VUI;7!0<F5F
M<R<*("`@("`@("!$15-#("=-24U0(%!R969E<F5N8V5S)PH@("`@("`@($51
M54%,2519(&-A<V5)9VYO<F5)035-871C:`H)4UE.5$%8(#$N,RXV+C$N-"XQ
M+C$T-C8N,3$U+C$R,2XQ+C(V>S$P,C1]("D*"B,*(R!-;W1T;&4@871T<FEB
M=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR-RXQ+BH*(PIA='1R:6)U
M=&5T>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N,C<N,2XQ"B`@("`@("`@3D%-
M12`G;6]T=&QE4')E9G,G"B`@("`@("`@1$530R`G36]T=&QE(%!R969E<F5N
M8V5S)PH@("`@("`@($5154%,2519(&-A<V5)9VYO<F5)035-871C:`H)4UE.
M5$%8(#$N,RXV+C$N-"XQ+C$T-C8N,3$U+C$R,2XQ+C(V>S$P,C1]("D*"B,*
M(R!.:6,@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR."XQ
M+BH*(PIA='1R:6)U=&5T>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N,C@N,2XQ
M"B`@("`@("`@3D%-12`G;FEC4')E9G,G"B`@("`@("`@1$530R`G3DE#(%!R
M969E<F5N8V5S)PH@("`@("`@($5154%,2519(&-A<V5)9VYO<F5)035-871C
M:`H)4UE.5$%8(#$N,RXV+C$N-"XQ+C$T-C8N,3$U+C$R,2XQ+C(V>S$P,C1]
M("D*"B,*(R!/8V-A;2!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S
M,#0P+C(Y+C$N*@HC"F%T=')I8G5T971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T
M,"XR.2XQ+C$*("`@("`@("!.04U%("=O8V-A;5!R969S)PH@("`@("`@($1%
M4T,@)T]C8V%M(%!R969E<F5N8V5S)PH@("`@("`@($5154%,2519(&-A<V5)
M9VYO<F5)035-871C:`H)4UE.5$%8(#$N,RXV+C$N-"XQ+C$T-C8N,3$U+C$R
M,2XQ+C(V>S$P,C1]("D*"B,*(R!/9&EN(&%T=')I8G5T92!B<F%N8V@@,2XS
M+C8N,2XT+C$N,3,P-#`N,S`N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV
M+C$N-"XQ+C$S,#0P+C,P+C$N,0H@("`@("`@($Y!344@)V]D:6Y0<F5F<R<*
M("`@("`@("!$15-#("=/9&EN(%!R969E<F5N8V5S)PH@("`@("`@($5154%,
M2519(&-A<V5)9VYO<F5)035-871C:`H)4UE.5$%8(#$N,RXV+C$N-"XQ+C$T
M-C8N,3$U+C$R,2XQ+C(V>S$P,C1]("D*"B,*(R!286MI;2!A='1R:6)U=&4@
M8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C,Q+C$N*@HC"F%T=')I8G5T971Y
M<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS,2XQ+C$*("`@("`@("!.04U%("=R
M86MI;5!R969S)PH@("`@("`@($1%4T,@)U)A:VEM(%!R969E<F5N8V5S)PH@
M("`@("`@($5154%,2519(&-A<V5)9VYO<F5)035-871C:`H)4UE.5$%8(#$N
M,RXV+C$N-"XQ+C$T-C8N,3$U+C$R,2XQ+C(V>S$P,C1]("D*"B,*(R!397-H
M82!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C,R+C$N*@HC
M"F%T=')I8G5T971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS,BXQ+C$*("`@
M("`@("!.04U%("=S97-H85!R969S)PH@("`@("`@($1%4T,@)U-E<VAA(%!R
M969E<F5N8V5S)PH@("`@("`@($5154%,2519(&-A<V5)9VYO<F5)035-871C
M:`H)4UE.5$%8(#$N,RXV+C$N-"XQ+C$T-C8N,3$U+C$R,2XQ+C(V>S$P,C1]
M("D*"B,*(R!3=V]O<V@@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ
M,S`T,"XS,RXQ+BH*(PIA='1R:6)U=&5T>7!E("@@,2XS+C8N,2XT+C$N,3,P
M-#`N,S,N,2XQ"B`@("`@("`@3D%-12`G<W=O;W-H4')E9G,G"B`@("`@("`@
M1$530R`G4W=O;W-H(%!R969E<F5N8V5S)PH@("`@("`@($5154%,2519(&-A
M<V5)9VYO<F5)035-871C:`H)4UE.5$%8(#$N,RXV+C$N-"XQ+C$T-C8N,3$U
M+C$R,2XQ+C(V>S$P,C1]("D*"B,*(R!4:&]R(&%T=')I8G5T92!B<F%N8V@@
M,2XS+C8N,2XT+C$N,3,P-#`N,S0N,2XJ"B,*871T<FEB=71E='EP92`H(#$N
M,RXV+C$N-"XQ+C$S,#0P+C,T+C$N,0H@("`@("`@($Y!344@)W1H;W)0<F5F
M<R<*("`@("`@("!$15-#("=4:&]R(%!R969E<F5N8V5S)PH@("`@("`@($51
M54%,2519(&-A<V5)9VYO<F5)035-871C:`H)4UE.5$%8(#$N,RXV+C$N-"XQ
M+C$T-C8N,3$U+C$R,2XQ+C(V>S$P,C1]("D*"B,*(R!5;&%F;W)M(&%T=')I
M8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,S4N,2XJ"B,*871T<FEB
M=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C,U+C$N,0H@("`@("`@($Y!
M344@)W5L869O<FU0<F5F<R<*("`@("`@("!$15-#("=5;&%F;W)M(%!R969E
M<F5N8V5S)PH@("`@("`@($5154%,2519(&-A<V5)9VYO<F5)035-871C:`H)
M4UE.5$%8(#$N,RXV+C$N-"XQ+C$T-C8N,3$U+C$R,2XQ+C(V>S$P,C1]("D*
M"B,*(R!6;VQO<R!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P
M+C,V+C$N*@HC"F%T=')I8G5T971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS
M-BXQ+C$*("`@("`@("!.04U%("=V;VQO<U!R969S)PH@("`@("`@($1%4T,@
M)U9O;&]S(%!R969E<F5N8V5S)PH@("`@("`@($5154%,2519(&-A<V5)9VYO
M<F5)035-871C:`H)4UE.5$%8(#$N,RXV+C$N-"XQ+C$T-C8N,3$U+C$R,2XQ
M+C(V>S$P,C1]("D*"B,*(R!(;W)D92!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS
M+C8N,2XT+C$N,3,P-#`N,BXR+BH*(PIO8FIE8W1C;&%S<R`H(#$N,RXV+C$N
M-"XQ+C$S,#0P+C(N,BXQ"B`@("!.04U%("=H;W)D95!E<G-O;B<*("`@($1%
M4T,@)TAO<F1E(%!R969E<F5N8V5S)PH@("`@4U50('1O<`H@("`@055824Q)
M05)9"B`@("!-05D@*"!M86EL("0@:&]R9&50<F5F<R`D(&EM<%!R969S("0@
M='5R8F%0<F5F<R`D"B`@("`@("`@9V]L;&5M4')E9G,@)"!K<F]N;VQI=&A0
M<F5F<R`D(&UN96UO4')E9G,@)`H@("`@("`@('1R;VQL4')E9G,@)"!N86=0
M<F5F<R`D(&ML=71Z4')E9G,@)`H@("`@("`@(&IO;F%H4')E9G,@)"!H97)M
M97-0<F5F<R`D(&IU;F]0<F5F<R`D"B`@("`@("`@=')E86Y0<F5F<R`D('=H
M=7!S4')E9G,@)"!I;F=O4')E9G,@)`H@("`@("`@(&=E;FEE4')E9G,@)"!S
M8W)Y4')E9G,@)"!A;G-E;%!R969S("0*("`@("`@("!W:6-K9610<F5F<R`D
M(&-H;W)A4')E9G,@)"!A9V]R85!R969S("0*("`@("`@("!G;V]P<U!R969S
M("0@;65R:U!R969S("0@=F]L;W-0<F5F<R`D"B`@("`@("`@;6EM<%!R969S
M("0@;6]T=&QE4')E9G,@)"!N:6-0<F5F<R`D"B`@("`@("`@;V-C86U0<F5F
M<R`D(&]D:6Y0<F5F<R`D(')A:VEM4')E9G,@)`H@("`@("`@('-E<VAA4')E
M9G,@)"!S=V]O<VA0<F5F<R`D('1H;W)0<F5F<R`D"B`@("`@("`@=6QA9F]R
M;5!R969S"B`@("`I("D*"F]B:F5C=&-L87-S("@@,2XS+C8N,2XT+C$N,3,P
M-#`N,BXR+C(*("`@($Y!344@)VAO<F1E1W)O=7`G"B`@("!$15-#("=(;W)D
M92!'<F]U<"<*("`@(%-54"!T;W`*("`@($%56$E,24%260H@("`@34%9("@@
M;6%I;"`I("D*"B,*(R!)35`@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N
M-"XQ+C$S,#0P+C,N,BXJ"B,*"B,@5'5R8F$@;V)J96-T8VQA<W,@8G)A;F-H
M(#$N,RXV+C$N-"XQ+C$S,#0P+C0N,BXJ"F]B:F5C=&-L87-S("@@,2XS+C8N
M,2XT+C$N,3,P-#`N-"XR+C$*("!.04U%("=T=7)B84-O;G1A8W0G"B`@1$53
M0R`G5'5R8F$@0V]N=&%C="<*("!355`@=&]P"B`@055824Q)05)9"B`@34%9
M("@@='5R8F%4>7!E("0@='5R8F%-96UB97)S("D*("D*"B,*(R!+<F]N;VQI
M=&@@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C4N,BXJ
M"B,*"B,*(R!.86<@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S
M,#0P+C8N,BXJ"B,*"B,*(R!';VQL96T@;V)J96-T8VQA<W,@8G)A;F-H(#$N
M,RXV+C$N-"XQ+C$S,#0P+C<N,BXJ"B,*"B,*(R!#:&]R82!O8FIE8W1C;&%S
M<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N."XR+BH*(PH*(PHC($UN96UO
M(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XY+C(N*@HC
M"@HC"B,@5')O;&P@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S
M,#0P+C$P+C(N*@HC"@HC"B,@2VQU='H@;V)J96-T8VQA<W,@8G)A;F-H(#$N
M,RXV+C$N-"XQ+C$S,#0P+C$Q+C(N*@HC"@HC"B,@2F]N86@@;V)J96-T8VQA
M<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C$R+C(N*@HC"@HC"B,@2&5R
M;65S(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ,RXR
M+BH*(PH*(PHC($IU;F\@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ
M+C$S,#0P+C$T+C(N*@HC"@HC"B,@5')E86X@;V)J96-T8VQA<W,@8G)A;F-H
M(#$N,RXV+C$N-"XQ+C$S,#0P+C$U+C(N*@HC"@HC"B,@5VAU<',@;V)J96-T
M8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C$V+C(N*@HC"@HC"B,@
M26YG;R!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,3<N
M,BXJ"B,*"B,*(R!!;G-E;"!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT
M+C$N,3,P-#`N,3@N,BXJ"B,*"B,*(R!'96YI92!O8FIE8W1C;&%S<R!B<F%N
M8V@@,2XS+C8N,2XT+C$N,3,P-#`N,3DN,BXJ"B,*"B,*(R!38W)Y(&]B:F5C
M=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR,"XR+BH*(PH*(PHC
M(%=I8VME9"!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N
M,C$N,BXJ"B,*"B,*(R!!9V]R82!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N
M,2XT+C$N,3,P-#`N,C(N,BXJ"B,*"B,*(R!';V]P<R!O8FIE8W1C;&%S<R!B
M<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,C0N,BXJ"B,*"B,*(R!-97)K(&]B
M:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR-2XR+BH*(PH*
M(PHC($UI;7`@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P
M+C(V+C(N*@HC"@HC"B,@36]T=&QE(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N
M-BXQ+C0N,2XQ,S`T,"XR-RXR+BH*(PH*(PHC($YI8R!O8FIE8W1C;&%S<R!B
M<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,C@N,BXJ"B,*"B,*(R!/8V-A;2!O
M8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,CDN,BXJ"B,*
M"B,*(R!/9&EN(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T
M,"XS,"XR+BH*(PH*(PHC(%)A:VEM(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N
M-BXQ+C0N,2XQ,S`T,"XS,2XR+BH*(PH*(PHC(%-E<VAA(&]B:F5C=&-L87-S
M(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS,BXR+BH*(PH*(PHC(%-W;V]S
M:"!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,S,N,BXJ
M"B,*"B,*(R!4:&]R(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ
M,S`T,"XS-"XR+BH*(PH*(PHC(%5L869O<FT@;V)J96-T8VQA<W,@8G)A;F-H
M(#$N,RXV+C$N-"XQ+C$S,#0P+C,U+C(N*@HC"@HC"B,@5F]L;W,@;V)J96-T
M8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C,V+C(N*@HC"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O=7!G<F%D97,`````
M````````````````````````````````````````````````````````````
M```````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P
M,"`Q,#4Q-30S,S<T,R`P,C`W-C(`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R
M:7!T<R]U<&=R861E<R]M;W9E7VAI<W1O<GE?;W5T7V]F7V1A=&%T<F5E+G!H
M<````````````````````````````````````#`P,#<U-2``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`V-#0P(#$P-3$U-#,S-S0S(#`R-S4S-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````C(2]U<W(O8FEN
M+W!H<"`M<0H\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]S8W)I<'1S+W5P
M9W)A9&5S+VUO=F5?:&ES=&]R>5]O=71?;V9?9&%T871R964N<&AP+'8@,2XS
M+C(N,2`R,#`U+S$P+S$X(#$Q.C,T.C`Q(&IA;B!%>'`@)`H@*@H@*B!4:&ES
M(&ES(&$@<V-R:7!T('1O(&UI9W)A=&4@2&ES=&]R>2!I;F9O<FUA=&EO;B!O
M=70@;V8@=&AE(&1A=&%T<F5E"B`J('1A8FQE<R!A;F0@:6YT;R!I=',@;W=N
M(&1A=&%B87-E('1A8FQE+@H@*B\*"B\O($9I;F0@=&AE(&)A<V4@9FEL92!P
M871H(&]F($AO<F1E+@I`9&5F:6YE*"=!551(7TA!3D1,15(G+"!T<G5E*3L*
M0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N
M+B\N+B<I.PH*+R\@1&\@0TQ)(&-H96-K<R!A;F0@96YV:7)O;FUE;G0@<V5T
M=7`@9FER<W0N"G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8V]R
M92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T-,22YP:'`G.PH*+R\@36%K
M92!S=7)E(&YO(&]N92!R=6YS('1H:7,@9G)O;2!T:&4@=V5B+@II9B`H(4AO
M<F1E7T-,23HZ<G5N;FEN9T9R;VU#3$DH*2D@>PH@("`@97AI="@B375S="!B
M92!R=6X@9G)O;2!T:&4@8V]M;6%N9"!L:6YE7&XB*3L*?0H*+R\@3&]A9"!T
M:&4@0TQ)(&5N=FER;VYM96YT("T@;6%K92!S=7)E('1H97)E)W,@;F\@=&EM
M92!L:6UI="P@:6YI=`HO+R!S;VUE('9A<FEA8FQE<RP@971C+@I(;W)D95]#
M3$DZ.FEN:70H*3L*)&-L:2`]($AO<F1E7T-,23HZ<VEN9VQE=&]N*"D["@HD
M8VQI+3YW<FET96QN*"1C;&DM/GEE;&QO=R@B0F5G:6YN:6YG(&UI9W)A=&EO
M;BX@5&AI<R!M87D@=&%K92!A('9E<GD@;&]N9R!T:6UE('1O(&-O;7!L971E
M+B(I*3L*)&-L:2T^=W)I=&5L;B@I.PH*<F5Q=6ER95]O;F-E($A/4D1%7T)!
M4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O1&%T
M851R964N<&AP)SL*"F-L87-S($1A=&%4<F5E3V)J96-T7TAI<W1O<GD@97AT
M96YD<R!$871A5')E94]B:F5C="!["@H@("`@9G5N8W1I;VX@7V9R;VU!='1R
M:6)U=&5S*"1A='1R:6)U=&5S*0H@("`@>PH@("`@("`@("\J($EN:71I86QI
M>F4@9&%T82!A<G)A>2X@*B\*("`@("`@("`D=&AI<RT^9&%T82`](&%R<F%Y
M*"D["@H@("`@("`@(&9O<F5A8V@@*"1A='1R:6)U=&5S(&%S("1A='1R*2![
M"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/F1A=&%;)&%T=');)VYA
M;64G75TI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^9&%T85LD871T<ELG
M;F%M92==72`](&%R<F%Y*"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)'1H:7,M/F1A=&%;)&%T=');)VYA;64G75U;)&%T=');)VME>2==72`]("1A
M='1R6R=V86QU92==.PH@("`@("`@('T*("`@('T*"GT*"B1D871A=')E92`]
M("9$871A5')E93HZ9F%C=&]R>2@G<W%L)RP@87)R87E?;65R9V4H2&]R9&4Z
M.F=E=$1R:79E<D-O;F9I9R@G9&%T871R964G+"`G<W%L)RDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)V=R;W5P)R`]/B`G:&]R9&4N:&ES=&]R>2<I*2D["B1D8B`]("8D9&%T
M871R964M/E]D8CL*"B1I<W%L(#T@)TE.4T525"!)3E1/(&AO<F1E7VAI<W1O
M<FEE<R`H:&ES=&]R>5]I9"P@;V)J96-T7W5I9"P@:&ES=&]R>5]A8W1I;VXL
M(&AI<W1O<GE?9&5S8RP@:&ES=&]R>5]W:&\L(&AI<W1O<GE?=',L(&AI<W1O
M<GE?97AT<F$I)R`N"B`@("`@("`@)R!604Q515,@*#\L(#\L(#\L(#\L(#\L
M(#\L(#\I)SL*"B1A;&P@/2`D9&%T871R964M/F=E="A$051!5%)%15]&3U)-
M051?1DQ!5"P@1$%40512145?4D]/5"P@=')U92D["G5N<V5T*"1A;&Q;1$%4
M0512145?4D]/5%TI.PHD:61S(#T@87)R87E?:V5Y<R@D86QL*3L*"F9O<F5A
M8V@@*"1I9',@87,@)&ED*2!["B`@("`D;V(@/2`D9&%T871R964M/F=E=$]B
M:F5C=$)Y260H)&ED+"`G1&%T851R965/8FIE8W1?2&ES=&]R>2<I.PH@("`@
M9F]R96%C:"`H)&]B+3YG971$871A*"D@87,@)')O=RD@>PH@("`@("`@("1V
M86QU97,@/2!A<G)A>2@D9&(M/FYE>'1)9"@G:&]R9&5?:&ES=&]R:65S)RDL
M("`@("`@("`@("`@("`@("`@+R\@:&ES=&]R>5]I9`H@("`@("`@("`@("`@
M("`@("`@("`@("`D;V(M/F=E=$YA;64H*2P@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@;V)J96-T7W5I9`H@("`@("`@("`@("`@("`@
M("`@("`@("!I<W-E="@D<F]W6R=A8W1I;VXG72D@/R`D<F]W6R=A8W1I;VXG
M72`Z(&YU;&PL("`@+R\@:&ES=&]R>5]A8W1I;VX*("`@("`@("`@("`@("`@
M("`@("`@("`@:7-S970H)')O=ULG9&5S8R==*2`_("1R;W=;)V1E<V,G72`Z
M(&YU;&PL("`@("`@("\O(&AI<W1O<GE?9&5S8PH@("`@("`@("`@("`@("`@
M("`@("`@("!I<W-E="@D<F]W6R=W:&\G72D@/R`D<F]W6R=W:&\G72`Z(&YU
M;&PL("`@("`@("`@+R\@:&ES=&]R>5]W:&\*("`@("`@("`@("`@("`@("`@
M("`@("`@:7-S970H)')O=ULG=',G72D@/R`D<F]W6R=T<R==(#H@;G5L;"P@
M("`@("`@("`@("\O(&AI<W1O<GE?=',*("`@("`@("`@("`@("`@("`@("`@
M("`@*3L*"B`@("`@("`@=6YS970H)')O=ULG86-T:6]N)UTI.PH@("`@("`@
M('5N<V5T*"1R;W=;)V1E<V,G72D["B`@("`@("`@=6YS970H)')O=ULG=VAO
M)UTI.PH@("`@("`@('5N<V5T*"1R;W=;)W1S)UTI.PH@("`@("`@(&EF("AC
M;W5N="@D<F]W*2D@>PH@("`@("`@("`@("`D=F%L=65S6UT@/2!S97)I86QI
M>F4H)')O=RD[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M:&ES=&]R>5]E>'1R80H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1V
M86QU97-;72`](&YU;&P[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!H:7-T;W)Y7V5X=')A"B`@("`@("`@?0H*("`@
M("`@("!C:&5C:R@D9&(M/G%U97)Y*"1I<W%L+"`D=F%L=65S*2D["B`@("!]
M"@H@("`@8VAE8VLH)&1B+3YQ=65R>2@G1$5,151%($923TT@:&]R9&5?9&%T
M871R965?871T<FEB=71E<R!72$5212!D871A=')E95]I9"`](#\G+"!A<G)A
M>2@D:60I*2D["B`@("!C:&5C:R@D9&(M/G%U97)Y*"=$14Q%5$4@1E)/32!H
M;W)D95]D871A=')E92!72$5212!D871A=')E95]I9"`](#\G+"!A<G)A>2@D
M:60I*2D["GT*"B1C;&DM/G=R:71E;&XH)&-L:2T^9W)E96XH(D1O;F4N($UI
M9W)A=&5D("(@+B!C;W5N="@D:61S*2`N("(@;V)J96-T<RXB*2D["@IF=6YC
M=&EO;B!C:&5C:R@D<F5S=6QT*0I["B`@("!I9B`H:7-?82@D<F5S=6QT+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@=F%R7V1U;7`H)')E<W5L="D["B`@
M("`@("`@97AI=#L*("`@('T*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C
M<FEP=',O=7!G<F%D97,O,C`P-BTP-BTR.5]H;W)D95]P<F5F<U]I;F1E>&5S
M+G-Q;``````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#4U,2`Q,#4Q-30S,S<T,R`P,C8W,C0`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+2T@5&AI<R!S
M8W)I<'0@861D<R!A9&1I=&EO;F%L(&EN9&5X97,@=&\@=&AE(&AO<F1E7W!R
M969S('1A8FQE('1H870@<VAO=6QD"BTM(&EM<')O=F4@;&]A9&EN9R!O9B!P
M<F5F97)E;F-E<R!F<F]M('1H92!P<F5F97)E;F-E('1A8FQE+@HM+0HM+2`D
M2&]R9&4Z(&AO<F1E+W-C<FEP=',O=7!G<F%D97,O,C`P-BTP-BTR.5]H;W)D
M95]P<F5F<U]I;F1E>&5S+G-Q;"QV(#$N,2XR+C$@,C`P-B\P-B\R.2`Q-CHR
M.3HP,R!J86X@17AP("0*"D-214%412!)3D1%6"!P<F5F7W5I9%]I9'@@3TX@
M:&]R9&5?<')E9G,@*'!R969?=6ED*3L*0U)%051%($E.1$58('!R969?<V-O
M<&5?:61X($].(&AO<F1E7W!R969S("AP<F5F7W-C;W!E*3L*"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W5P9W)A
M9&5S+S(N,E]T;U\S+C`N<&=S<6PN<W%L````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#0W,3`@,3`U,34T,S,W-#,@,#(T,C<T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"TM(%EO=2!C86X@<VEM<&QY(&5X
M96-U=&4@=&AI<R!F:6QE(&EN('EO=7(@9&%T86)A<V4N"BTM"BTM(%)U;B!A
M<SH*+2T*+2T@)"!P<W%L(#QD8B!N86UE/B`M9B`R+C)?=&]?,RXP+G!O<W1G
M<F5S<6PN<W%L"@I"14=)3CL*04Q415(@5$%"3$4@:&]R9&5?<')E9G,@041$
M($-/3%5-3B!P<F5F7W5I9%]N97<@5D%20TA!4B@R,#`I.PI54$1!5$4@:&]R
M9&5?<')E9G,@4T54('!R969?=6ED7VYE=R`]('!R969?=6ED.PI!3%1%4B!4
M04),12!H;W)D95]P<F5F<R!$4D]0('!R969?=6ED.PI!3%1%4B!404),12!H
M;W)D95]P<F5F<R!214Y!344@<')E9E]U:61?;F5W(%1/('!R969?=6ED.PI!
M3%1%4B!404),12!H;W)D95]P<F5F<R!!3%1%4B!#3TQ534X@<')E9E]U:60@
M4T54($Y/5"!.54Q,.PI#3TU-250["D1%3$5412!&4D]-(&AO<F1E7W!R969S
M(%=(15)%('!R969?;F%M92`]("=L87-T7VQO9VEN)R!!3D0@<')E9E]S8V]P
M92`]("=I;7`G.PH*0U)%051%(%1!0DQ%(&AO<F1E7V1A=&%T<F5E("@*("`@
M("`@(&1A=&%T<F5E7VED($E.5"!.3U0@3E5,3"P*("`@("`@(&=R;W5P7W5I
M9"!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("`@("!U<V5R7W5I9"!605)#
M2$%2*#(U-2D@3D]4($Y53$PL"B`@("`@("!D871A=')E95]N86UE(%9!4D-(
M05(H,C4U*2!.3U0@3E5,3"P*("`@("`@(&1A=&%T<F5E7W!A<F5N=',@5D%2
M0TA!4B@R-34I($Y/5"!.54Q,+`H@("`@("`@9&%T871R965?;W)D97(@24Y4
M+`H@("`@("`@9&%T871R965?9&%T82!415A4+`H@("`@("`@9&%T871R965?
M<V5R:6%L:7IE9"!334%,3$E.5"!$149!54Q4(#`@3D]4($Y53$PL"B`@("`@
M("!D871A=')E95]U<&1A=&5D(%1)34535$%-4"P*"B`@("`@("!04DE-05)9
M($M%62`H9&%T871R965?:60I"BD["@I#4D5!5$4@24Y$15@@9&%T871R965?
M9&%T871R965?;F%M95]I9'@@3TX@:&]R9&5?9&%T871R964@*&1A=&%T<F5E
M7VYA;64I.PI#4D5!5$4@24Y$15@@9&%T871R965?9W)O=7!?:61X($].(&AO
M<F1E7V1A=&%T<F5E("AG<F]U<%]U:60I.PI#4D5!5$4@24Y$15@@9&%T871R
M965?=7-E<E]I9'@@3TX@:&]R9&5?9&%T871R964@*'5S97)?=6ED*3L*0U)%
M051%($E.1$58(&1A=&%T<F5E7W-E<FEA;&EZ961?:61X($].(&AO<F1E7V1A
M=&%T<F5E("AD871A=')E95]S97)I86QI>F5D*3L*"D-214%412!404),12!H
M;W)D95]D871A=')E95]A='1R:6)U=&5S("@*("`@(&1A=&%T<F5E7VED($E.
M5"!.3U0@3E5,3"P*("`@(&%T=')I8G5T95]N86UE(%9!4D-(05(H,C4U*2!.
M3U0@3E5,3"P*("`@(&%T=')I8G5T95]K97D@5D%20TA!4B@R-34I($1%1D%5
M3%0@)R<@3D]4($Y53$PL"B`@("!A='1R:6)U=&5?=F%L=64@5$585`HI.PH*
M0U)%051%($E.1$58(&1A=&%T<F5E7V%T=')I8G5T95]I9'@@3TX@:&]R9&5?
M9&%T871R965?871T<FEB=71E<R`H9&%T871R965?:60I.PI#4D5!5$4@24Y$
M15@@9&%T871R965?871T<FEB=71E7VYA;65?:61X($].(&AO<F1E7V1A=&%T
M<F5E7V%T=')I8G5T97,@*&%T=')I8G5T95]N86UE*3L*0U)%051%($E.1$58
M(&1A=&%T<F5E7V%T=')I8G5T95]K97E?:61X($].(&AO<F1E7V1A=&%T<F5E
M7V%T=')I8G5T97,@*&%T=')I8G5T95]K97DI.PH*1U)!3E0@4T5,14-4+"!)
M3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7V1A=&%T<F5E(%1/(&AO
M<F1E.PI'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@
M:&]R9&5?9&%T871R965?871T<FEB=71E<R!43R!H;W)D93L*"D-214%412!4
M04),12!H;W)D95]T;VME;G,@*`H@("`@=&]K96Y?861D<F5S<R`@("!605)#
M2$%2*#@I($Y/5"!.54Q,+`H@("`@=&]K96Y?:60@("`@("`@("!605)#2$%2
M*#,R*2!.3U0@3E5,3"P*("`@('1O:V5N7W1I;65S=&%M<"`@0DE'24Y4($Y/
M5"!.54Q,+`H*("`@(%!224U!4ED@2T59("AT;VME;E]A9&1R97-S+"!T;VME
M;E]I9"D**3L*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$54
M12!/3B!H;W)D95]T;VME;G,@5$\@:&]R9&4["@I#4D5!5$4@5$%"3$4@:&]R
M9&5?=F9S("@*("`@('9F<U]I9"`@("`@("`@0DE'24Y4($Y/5"!.54Q,+`H@
M("`@=F9S7W1Y<&4@("`@("!334%,3$E.5"!.3U0@3E5,3"P*("`@('9F<U]P
M871H("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=F9S7VYA;64@
M("`@("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?;6]D:69I960@
M($))1TE.5"!.3U0@3E5,3"P*("`@('9F<U]O=VYE<B`@("`@5D%20TA!4B@R
M-34I($Y/5"!.54Q,+`H@("`@=F9S7V1A=&$@("`@("!415A4+`H*("`@(%!2
M24U!4ED@2T59("`@*'9F<U]I9"D**3L*"D-214%412!)3D1%6"!V9G-?<&%T
M:%]I9'@@3TX@:&]R9&5?=F9S("AV9G-?<&%T:"D["D-214%412!)3D1%6"!V
M9G-?;F%M95]I9'@@3TX@:&]R9&5?=F9S("AV9G-?;F%M92D["@I'4D%.5"!3
M14Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?=F9S(%1/
M(&AO<F1E.PH*````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S
M8W)I<'1S+W5P9W)A9&5S+S(N,E]T;U\S+C`N;7ES<6PN<W%L````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#0V-S<@,3`U,34T,S,W-#,@,#(T,S(W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"TM("1(;W)D
M93H@:&]R9&4O<V-R:7!T<R]U<&=R861E<R\R+C)?=&]?,RXP+FUY<W%L+G-Q
M;"QV(#$N,BXX+C(@,C`P-2\Q,"\Q."`Q,3HS-#HP,2!J86X@17AP("0*+2T*
M+2T@66]U(&-A;B!S:6UP;'D@97AE8W5T92!T:&ES(&9I;&4@:6X@>6]U<B!D
M871A8F%S92X*+2T*+2T@4G5N(&%S.@HM+0HM+2`D(&UY<W%L("TM=7-E<CUR
M;V]T("TM<&%S<W=O<F0]/$UY4U%,+7)O;W0M<&%S<W=O<F0^(#QD8B!N86UE
M/B`\(#(N,E]T;U\S+C`N;7ES<6PN<W%L"@I54T4@:&]R9&4["@I!3%1%4B!4
M04),12!H;W)D95]P<F5F<R!#2$%.1T4@0T],54U.('!R969?=6ED('!R969?
M=6ED(%9!4D-(05(H,C`P*2!.3U0@3E5,3#L*1$5,151%($923TT@:&]R9&5?
M<')E9G,@5TA%4D4@<')E9E]N86UE(#T@)VQA<W1?;&]G:6XG($%.1"!P<F5F
M7W-C;W!E(#T@)VEM<"<["@I#4D5!5$4@5$%"3$4@:&]R9&5?9&%T871R964@
M*`H@("`@("`@9&%T871R965?:60@24Y4($Y/5"!.54Q,+`H@("`@("`@9W)O
M=7!?=6ED(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@("`@('5S97)?=6ED
M(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@("`@(&1A=&%T<F5E7VYA;64@
M5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@("`@9&%T871R965?<&%R96YT
M<R!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("`@("!D871A=')E95]O<F1E
M<B!)3E0L"B`@("`@("!D871A=')E95]D871A(%1%6%0L"B`@("`@("!D871A
M=')E95]S97)I86QI>F5D(%--04Q,24Y4($1%1D%53%0@,"!.3U0@3E5,3"P*
M("`@("`@(&1A=&%T<F5E7W5P9&%T960@5$E-15-404U0+`H*("`@("`@(%!2
M24U!4ED@2T59("AD871A=')E95]I9"D**3L*"D-214%412!)3D1%6"!D871A
M=')E95]D871A=')E95]N86UE7VED>"!/3B!H;W)D95]D871A=')E92`H9&%T
M871R965?;F%M92D["D-214%412!)3D1%6"!D871A=')E95]G<F]U<%]I9'@@
M3TX@:&]R9&5?9&%T871R964@*&=R;W5P7W5I9"D["D-214%412!)3D1%6"!D
M871A=')E95]U<V5R7VED>"!/3B!H;W)D95]D871A=')E92`H=7-E<E]U:60I
M.PI#4D5!5$4@24Y$15@@9&%T871R965?<V5R:6%L:7IE9%]I9'@@3TX@:&]R
M9&5?9&%T871R964@*&1A=&%T<F5E7W-E<FEA;&EZ960I.PH*0U)%051%(%1!
M0DQ%(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*`H@("`@9&%T871R965?
M:60@24Y4($Y/5"!.54Q,+`H@("`@871T<FEB=71E7VYA;64@5D%20TA!4B@R
M-34I($Y/5"!.54Q,+`H@("`@871T<FEB=71E7VME>2!605)#2$%2*#(U-2D@
M1$5&055,5"`G)R!.3U0@3E5,3"P*("`@(&%T=')I8G5T95]V86QU92!415A4
M"BD["@I#4D5!5$4@24Y$15@@9&%T871R965?871T<FEB=71E7VED>"!/3B!H
M;W)D95]D871A=')E95]A='1R:6)U=&5S("AD871A=')E95]I9"D["D-214%4
M12!)3D1%6"!D871A=')E95]A='1R:6)U=&5?;F%M95]I9'@@3TX@:&]R9&5?
M9&%T871R965?871T<FEB=71E<R`H871T<FEB=71E7VYA;64I.PI#4D5!5$4@
M24Y$15@@9&%T871R965?871T<FEB=71E7VME>5]I9'@@3TX@:&]R9&5?9&%T
M871R965?871T<FEB=71E<R`H871T<FEB=71E7VME>2D["@I'4D%.5"!314Q%
M0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?9&%T871R964@
M5$\@:&]R9&5`;&]C86QH;W-T.PI'4D%.5"!314Q%0U0L($E.4T525"P@55!$
M051%+"!$14Q%5$4@3TX@:&]R9&5?9&%T871R965?871T<FEB=71E<R!43R!H
M;W)D94!L;V-A;&AO<W0["@I#4D5!5$4@5$%"3$4@:&]R9&5?=&]K96YS("@*
M("`@('1O:V5N7V%D9')E<W,@("`@5D%20TA!4B@X*2!.3U0@3E5,3"P*("`@
M('1O:V5N7VED("`@("`@("`@5D%20TA!4B@S,BD@3D]4($Y53$PL"B`@("!T
M;VME;E]T:6UE<W1A;7`@($))1TE.5"!.3U0@3E5,3"P*"B`@("!04DE-05)9
M($M%62`H=&]K96Y?861D<F5S<RP@=&]K96Y?:60I"BD["@I'4D%.5"!314Q%
M0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?=&]K96YS(%1/
M(&AO<F1E0&QO8V%L:&]S=#L*"D-214%412!404),12!H;W)D95]V9G,@*`H@
M("`@=F9S7VED("`@("`@("!"24=)3E0@3D]4($Y53$PL"B`@("!V9G-?='EP
M92`@("`@(%--04Q,24Y4($Y/5"!.54Q,+`H@("`@=F9S7W!A=&@@("`@("!6
M05)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?;F%M92`@("`@(%9!4D-(
M05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]M;V1I9FEE9"`@0DE'24Y4($Y/
M5"!.54Q,+`H@("`@=F9S7V]W;F5R("`@("!605)#2$%2*#(U-2D@3D]4($Y5
M3$PL"B`@("!V9G-?9&%T82`@("`@($Q/3D="3$]"+`H*("`@(%!224U!4ED@
M2T59("`@*'9F<U]I9"D**3L*"D-214%412!)3D1%6"!V9G-?<&%T:%]I9'@@
M3TX@:&]R9&5?=F9S("AV9G-?<&%T:"D["D-214%412!)3D1%6"!V9G-?;F%M
M95]I9'@@3TX@:&]R9&5?=F9S("AV9G-?;F%M92D["@I'4D%.5"!314Q%0U0L
M($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?=F9S(%1/(&AO<F1E
M0&QO8V%L:&]S=#L*````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]S8W)I<'1S+W5P9W)A9&5S+S(N,E]T;U\S+C`N;V-I."YS
M<6P`````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#0T-S,@,3`U,34T,S,W-#,@
M,#(T,#$V`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"TM("1(;W)D93H@:&]R9&4O<V-R:7!T<R]U<&=R861E<R\R+C)?=&]?
M,RXP+F]C:3@N<W%L+'8@,2XQ+C(N,2`R,#`V+S`T+S`V(#(R.C4S.C0P(&IA
M;B!%>'`@)`H*04Q415(@5$%"3$4@:&]R9&5?<')E9G,@34]$2499('!R969?
M=6ED(%9!4D-(05(R*#(U-2D["D%,5$52(%1!0DQ%(&AO<F1E7W!R969S($U/
M1$E&62!P<F5F7W-C;W!E(%9!4D-(05(R*#$V*3L*04Q415(@5$%"3$4@:&]R
M9&5?<')E9G,@34]$2499('!R969?;F%M92!605)#2$%2,B@S,BD["E501$%4
M12!H;W)D95]P<F5F<R!3150@<')E9E]U:60@/2!25%))32AP<F5F7W5I9"D[
M"E501$%412!H;W)D95]P<F5F<R!3150@<')E9E]S8V]P92`](%)44DE-*'!R
M969?<V-O<&4I.PI54$1!5$4@:&]R9&5?<')E9G,@4T54('!R969?;F%M92`]
M(%)44DE-*'!R969?;F%M92D["@I$14Q%5$4@1E)/32!H;W)D95]P<F5F<R!7
M2$5212!P<F5F7VYA;64@/2`G;&%S=%]L;V=I;B<@04Y$('!R969?<V-O<&4@
M/2`G:6UP)SL*"D-214%412!404),12!H;W)D95]D871A=')E92`H"B`@("!D
M871A=')E95]I9"`@("`@("`@("!.54U"15(H,38I($Y/5"!.54Q,+`H@("`@
M9W)O=7!?=6ED("`@("`@("`@("`@5D%20TA!4C(H,C4U*2!.3U0@3E5,3"P*
M("`@('5S97)?=6ED("`@("`@("`@("`@(%9!4D-(05(R*#(U-2DL"B`@("!D
M871A=')E95]N86UE("`@("`@("!605)#2$%2,B@R-34I($Y/5"!.54Q,+`H@
M("`@9&%T871R965?<&%R96YT<R`@("`@5D%20TA!4C(H,C4U*2P*("`@(&1A
M=&%T<F5E7V]R9&5R("`@("`@($Y534)%4B@Q-BDL"B`@("!D871A=')E95]D
M871A("`@("`@("!#3$]"+`H@("`@9&%T871R965?<V5R:6%L:7IE9"`@3E5-
M0D52*#@I($1%1D%53%0@,"!.3U0@3E5,3"P*("`@(&1A=&%T<F5E7W5P9&%T
M960@("`@($1!5$4L"@H@("`@4%))34%262!+15D@*&1A=&%T<F5E7VED*0HI
M.PH*0U)%051%($E.1$58(&1A=&%T<F5E7V1A=&%T<F5E7VYA;65?:61X($].
M(&AO<F1E7V1A=&%T<F5E("AD871A=')E95]N86UE*3L*0U)%051%($E.1$58
M(&1A=&%T<F5E7V=R;W5P7VED>"!/3B!H;W)D95]D871A=')E92`H9W)O=7!?
M=6ED*3L*0U)%051%($E.1$58(&1A=&%T<F5E7W5S97)?:61X($].(&AO<F1E
M7V1A=&%T<F5E("AU<V5R7W5I9"D["D-214%412!)3D1%6"!D871A=')E95]O
M<F1E<E]I9'@@3TX@:&]R9&5?9&%T871R964@*&1A=&%T<F5E7V]R9&5R*3L*
M0U)%051%($E.1$58(&1A=&%T<F5E7W-E<FEA;&EZ961?:61X($].(&AO<F1E
M7V1A=&%T<F5E("AD871A=')E95]S97)I86QI>F5D*3L*"D-214%412!404),
M12!H;W)D95]D871A=')E95]A='1R:6)U=&5S("@*("`@(&1A=&%T<F5E7VED
M("`@("`@3E5-0D52*#$V*2!.3U0@3E5,3"P*("`@(&%T=')I8G5T95]N86UE
M("`@5D%20TA!4C(H,C4U*2!.3U0@3E5,3"P*("`@(&%T=')I8G5T95]K97D@
M("`@5D%20TA!4C(H,C4U*2P*("`@(&%T=')I8G5T95]V86QU92`@5D%20TA!
M4C(H-#`P,"D**3L*"D-214%412!)3D1%6"!D871A=')E95]A='1R:6)U=&5?
M:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*&1A=&%T<F5E7VED
M*3L*0U)%051%($E.1$58(&1A=&%T<F5E7V%T=')I8G5T95]N86UE7VED>"!/
M3B!H;W)D95]D871A=')E95]A='1R:6)U=&5S("AA='1R:6)U=&5?;F%M92D[
M"D-214%412!)3D1%6"!D871A=')E95]A='1R:6)U=&5?:V5Y7VED>"!/3B!H
M;W)D95]D871A=')E95]A='1R:6)U=&5S("AA='1R:6)U=&5?:V5Y*3L*"D-2
M14%412!404),12!H;W)D95]T;VME;G,@*`H@("`@=&]K96Y?861D<F5S<R`@
M("!605)#2$%2,B@Q,#`I($Y/5"!.54Q,+`H@("`@=&]K96Y?:60@("`@("`@
M("!605)#2$%2,B@S,BD@3D]4($Y53$PL"B`@("!T;VME;E]T:6UE<W1A;7`@
M($Y534)%4B@Q-BD@3D]4($Y53$PL"@H@("`@4%))34%262!+15D@*'1O:V5N
M7V%D9')E<W,L('1O:V5N7VED*0HI.PH*0U)%051%(%1!0DQ%(&AO<F1E7W9F
M<R`H"B`@("!V9G-?:60@("`@("`@($Y534)%4B@Q-BD@3D]4($Y53$PL"B`@
M("!V9G-?='EP92`@("`@($Y534)%4B@X*2!.3U0@3E5,3"P*("`@('9F<U]P
M871H("`@("`@5D%20TA!4C(H,C4U*2P*("`@('9F<U]N86UE("`@("`@5D%2
M0TA!4C(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]M;V1I9FEE9"`@3E5-0D52
M*#$V*2!.3U0@3E5,3"P*("`@('9F<U]O=VYE<B`@("`@5D%20TA!4C(H,C4U
M*2P*("`@('9F<U]D871A("`@("`@0DQ/0BP*"B`@("!04DE-05)9($M%62`@
M("AV9G-?:60I"BD["@I#4D5!5$4@24Y$15@@=F9S7W!A=&A?:61X($].(&AO
M<F1E7W9F<R`H=F9S7W!A=&@I.PI#4D5!5$4@24Y$15@@=F9S7VYA;65?:61X
M($].(&AO<F1E7W9F<R`H=F9S7VYA;64I.PH*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W5P9W)A9&5S+S,N,%]T
M;U\S+C$N;7ES<6PN<W%L````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$W,C0@
M,3`U,34T,S,W-#,@,#(T,S$U`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"TM("1(;W)D93H@:&]R9&4O<V-R:7!T<R]U<&=R
M861E<R\S+C!?=&]?,RXQ+FUY<W%L+G-Q;"QV(#$N,2XR+C$@,C`P-B\P,2\P
M-B`Q,#HT,3HQ,R!J86X@17AP("0*+2T*+2T@66]U(&-A;B!S:6UP;'D@97AE
M8W5T92!T:&ES(&9I;&4@:6X@>6]U<B!D871A8F%S92X*+2T*+2T@4G5N(&%S
M.@HM+0HM+2`D(&UY<W%L("TM=7-E<CUR;V]T("TM<&%S<W=O<F0]/$UY4U%,
M+7)O;W0M<&%S<W=O<F0^(#QD8B!N86UE/B`\(#,N,%]T;U\S+C$N;7ES<6PN
M<W%L"@I!3%1%4B!404),12!H;W)D95]U<V5R<R!!1$0@0T],54U.('5S97)?
M<V]F=%]E>'!I<F%T:6]N7V1A=&4@24Y4.PI!3%1%4B!404),12!H;W)D95]U
M<V5R<R!!1$0@0T],54U.('5S97)?:&%R9%]E>'!I<F%T:6]N7V1A=&4@24Y4
M.PH*0U)%051%(%1!0DQ%(&AO<F1E7VAI<W1O<FEE<R`H"B`@("!H:7-T;W)Y
M7VED("`@("`@($))1TE.5"!.3U0@3E5,3"P*("`@(&]B:F5C=%]U:60@("`@
M("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@:&ES=&]R>5]A8W1I;VX@
M("!605)#2$%2*#,R*2!.3U0@3E5,3"P*("`@(&AI<W1O<GE?=',@("`@("`@
M0DE'24Y4($Y/5"!.54Q,+`H@("`@:&ES=&]R>5]D97-C("`@("!415A4+`H@
M("`@:&ES=&]R>5]W:&\@("`@("!605)#2$%2*#(U-2DL"B`@("!H:7-T;W)Y
M7V5X=')A("`@(%1%6%0L"BTM"B`@("!04DE-05)9($M%62`H:&ES=&]R>5]I
M9"D**3L*"D-214%412!)3D1%6"!H:7-T;W)Y7V%C=&EO;E]I9'@@3TX@:&]R
M9&5?:&ES=&]R:65S("AH:7-T;W)Y7V%C=&EO;BD["D-214%412!)3D1%6"!H
M:7-T;W)Y7W1S7VED>"!/3B!H;W)D95]H:7-T;W)I97,@*&AI<W1O<GE?=',I
M.PI#4D5!5$4@24Y$15@@:&ES=&]R>5]U:61?:61X($].(&AO<F1E7VAI<W1O
M<FEE<R`H;V)J96-T7W5I9"D["@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$
M051%+"!$14Q%5$4@3TX@:&]R9&5?:&ES=&]R:65S(%1/(&AO<F1E0&QO8V%L
M:&]S=#L*````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W5P9W)A9&5S
M+S,N,%]T;U\S+C$N;V-I."YS<6P`````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#$S-30@,3`U,34T,S,W-#,@,#(T,#$Q`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"TM("1(;W)D93H@:&]R9&4O<V-R:7!T
M<R]U<&=R861E<R\S+C!?=&]?,RXQ+F]C:3@N<W%L+'8@,2XQ+C(N,2`R,#`V
M+S`T+S`V(#(R.C4S.C4T(&IA;B!%>'`@)`H*04Q415(@5$%"3$4@:&]R9&5?
M=7-E<G,@041$('5S97)?<V]F=%]E>'!I<F%T:6]N7V1A=&4@3E5-0D52*#$V
M*3L*04Q415(@5$%"3$4@:&]R9&5?=7-E<G,@041$('5S97)?:&%R9%]E>'!I
M<F%T:6]N7V1A=&4@3E5-0D52*#$V*3L*"D-214%412!404),12!H;W)D95]H
M:7-T;W)I97,@*`H@("`@:&ES=&]R>5]I9"`@("`@("!.54U"15(H,38I($Y/
M5"!.54Q,+`H@("`@;V)J96-T7W5I9"`@("`@("!605)#2$%2,B@R-34I($Y/
M5"!.54Q,+`H@("`@:&ES=&]R>5]A8W1I;VX@("!605)#2$%2,B@S,BD@3D]4
M($Y53$PL"B`@("!H:7-T;W)Y7W1S("`@("`@($Y534)%4B@Q-BD@3D]4($Y5
M3$PL"B`@("!H:7-T;W)Y7V1E<V,@("`@($-,3T(L"B`@("!H:7-T;W)Y7W=H
M;R`@("`@(%9!4D-(05(R*#(U-2DL"B`@("!H:7-T;W)Y7V5X=')A("`@($-,
M3T(L"@H@("`@4%))34%262!+15D@*&AI<W1O<GE?:60I"BD["@I#4D5!5$4@
M24Y$15@@:&ES=&]R>5]A8W1I;VY?:61X($].(&AO<F1E7VAI<W1O<FEE<R`H
M:&ES=&]R>5]A8W1I;VXI.PI#4D5!5$4@24Y$15@@:&ES=&]R>5]T<U]I9'@@
M3TX@:&]R9&5?:&ES=&]R:65S("AH:7-T;W)Y7W1S*3L*0U)%051%($E.1$58
M(&AI<W1O<GE?=6ED7VED>"!/3B!H;W)D95]H:7-T;W)I97,@*&]B:F5C=%]U
M:60I.PH`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W5P
M9W)A9&5S+S(P,#4M,#DM,C)?:&]R9&5?<')E9G-?=F%R8VAA<C(N;V-I."YS
M<6P`````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#$Q-S,@,3`U,34T,S,W-#,@,#(W-C,R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"TM(%5S92!T:&ES('-C<FEP
M="!T;R!C;VYV97)T($-(05(@8V]L=6UN<R!I;B!H;W)D95]P<F5F<R!T;R!6
M05)#2$%2,B!A;F0@=')I;0HM+2!T:&4@<W!A8V4@<&%D9&EN9RX@(%1H:7,@
M:7,@;VYL>2!N96-E<W-A<GD@:68@:&]R9&5?<')E9G,@=V%S(&-R96%T960@
M=7-I;F<*+2T@<V-R:7!T<R]S<6PO8W)E871E+F]C:3@N<W%L"BTM"BTM("1(
M;W)D93H@:&]R9&4O<V-R:7!T<R]U<&=R861E<R\R,#`U+3`Y+3(R7VAO<F1E
M7W!R969S7W9A<F-H87(R+F]C:3@N<W%L+'8@,2XQ+C(N,2`R,#`U+S$P+S$X
M(#$Q.C,T.C`Q(&IA;B!%>'`@)`HM+0I!3%1%4B!404),12!H;W)D95]P<F5F
M<R!-3T1)1ED@<')E9E]U:60@5D%20TA!4C(H,C4U*3L*04Q415(@5$%"3$4@
M:&]R9&5?<')E9G,@34]$2499('!R969?<V-O<&4@5D%20TA!4C(H,38I.PI!
M3%1%4B!404),12!H;W)D95]P<F5F<R!-3T1)1ED@<')E9E]N86UE(%9!4D-(
M05(R*#,R*3L*55!$051%(&AO<F1E7W!R969S(%-%5"!P<F5F7W5I9"`](%)4
M4DE-*'!R969?=6ED*3L*55!$051%(&AO<F1E7W!R969S(%-%5"!P<F5F7W-C
M;W!E(#T@4E1224TH<')E9E]S8V]P92D["E501$%412!H;W)D95]P<F5F<R!3
M150@<')E9E]N86UE(#T@4E1224TH<')E9E]N86UE*3L*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I
M<'1S+W5P9W)A9&5S+S,N,%]T;U\S+C$N<W%L````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#$S,S8@,3`U,34T,S,W-#,@,#(S,34P`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"TM("1(;W)D93H@
M:&]R9&4O<V-R:7!T<R]U<&=R861E<R\S+C!?=&]?,RXQ+G-Q;"QV(#$N,2XR
M+C$@,C`P-B\P,R\R.2`R,3HR-SHU,B!J86X@17AP("0*"D%,5$52(%1!0DQ%
M(&AO<F1E7W5S97)S($%$1"!#3TQ534X@=7-E<E]S;V9T7V5X<&ER871I;VY?
M9&%T92!)3E0["D%,5$52(%1!0DQ%(&AO<F1E7W5S97)S($%$1"!#3TQ534X@
M=7-E<E]H87)D7V5X<&ER871I;VY?9&%T92!)3E0["@I#4D5!5$4@5$%"3$4@
M:&]R9&5?:&ES=&]R:65S("@*("`@(&AI<W1O<GE?:60@("`@("`@0DE'24Y4
M($Y/5"!.54Q,+`H@("`@;V)J96-T7W5I9"`@("`@("!605)#2$%2*#(U-2D@
M3D]4($Y53$PL"B`@("!H:7-T;W)Y7V%C=&EO;B`@(%9!4D-(05(H,S(I($Y/
M5"!.54Q,+`H@("`@:&ES=&]R>5]T<R`@("`@("!"24=)3E0@3D]4($Y53$PL
M"B`@("!H:7-T;W)Y7V1E<V,@("`@(%1%6%0L"B`@("!H:7-T;W)Y7W=H;R`@
M("`@(%9!4D-(05(H,C4U*2P*("`@(&AI<W1O<GE?97AT<F$@("`@5$585"P*
M+2T*("`@(%!224U!4ED@2T59("AH:7-T;W)Y7VED*0HI.PH*0U)%051%($E.
M1$58(&AI<W1O<GE?86-T:6]N7VED>"!/3B!H;W)D95]H:7-T;W)I97,@*&AI
M<W1O<GE?86-T:6]N*3L*0U)%051%($E.1$58(&AI<W1O<GE?='-?:61X($].
M(&AO<F1E7VAI<W1O<FEE<R`H:&ES=&]R>5]T<RD["D-214%412!)3D1%6"!H
M:7-T;W)Y7W5I9%]I9'@@3TX@:&]R9&5?:&ES=&]R:65S("AO8FIE8W1?=6ED
M*3L*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]S8W)I<'1S+W-Q;```````````````````````````````````````````
M````````````````````````````````````````````,#`P-S4U(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W-#,@,#$W-S0W`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O<W%L+V-R96%T92YO8VDX+G-Q
M;```````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,S$P-2`Q,#4Q
M-30S,S<T,R`P,C(V-3,`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````<V5T(&1O8R!O9F8["G-E="!S<6QB;&%N:VQI;F5S(&]N
M.PH*+RHJ"B`J($]R86-L92!486)L92!#<F5A=&EO;B!38W)I<'1S+@H@*B`*
M("H@)$AO<F1E.B!H;W)D92]S8W)I<'1S+W-Q;"]C<F5A=&4N;V-I."YS<6PL
M=B`Q+C0N."XQ,"`R,#`V+S`V+S(Y(#$V.C(Y.C`S(&IA;B!%>'`@)`H@*B`*
M("H@0&%U=&AO<B!-:6=U96P@5V%R9"`\;7=A<F1`86QU87(N8V]M+F%R/@H@
M*B`*("H@5&AI<R!S<6P@8W)E871E<R!T:&4@2&]R9&4@4U%,('1A8FQE<R!I
M;B!A;B!/<F%C;&4@."YX(&1A=&%B87-E+B!3:&]U;&0*("H@=V]R:R!W:71H
M($]R86-L92`Y+G@@*&%N9"!/<F%C;&4W('5S:6YG('9A<F-H87(R*2X*("H@
M"B`J($YO=&5S.@H@*B`*("H@("H@3V)V:6]U<VQY('EO=2!M=7-T(&AA=F4@
M3W)A8VQE(&EN<W1A;&QE9"!O;B!T:&ES(&UA8VAI;F4@04Y$('EO=2!M=7-T
M"B`J("`@(&AA=F4@8V]M<&EL960@4$A0('=I=&@@3W)A8VQE("AY;W4@:6YC
M;'5D960@+2UW:71H+6]C:3@M:6YS=&%N=`H@*B`@("`M+7=I=&@M;V-I."!O
M<B!I;B!T:&4@8G5I;&0@87)G=6UE;G1S(&9O<B!02%`L(&]R('5N8V]M;65N
M=&5D('1H92!O8VDX"B`J("`@(&5X=&5N<VEO;B!I;B!P:'`N:6YI*2X*("H@
M"B`J("`J($EF('EO=2!D;VXG="!U<V4@=&AE($EN<W1A;G0@0VQI96YT+"!M
M86ME('-U<F4@=&AA="!T:&4@=7-E<B!T:&%T('-T87)T<PH@*B`@("!U<"!!
M<&%C:&4@*'5S=6%L;'D@;F]B;V1Y(&]R('=W=RUD871A*2!H87,@=&AE(&9O
M;&QO=VEN9R!E;G9I<F]N;65N=`H@*B`@("!V87)I86)L97,@9&5F:6YE9#H*
M("H@"B`J("`@(&5X<&]R="!/4D%#3$5?2$]-13TO:&]M92]O<F%C;&4O3W)A
M2&]M93$*("H@("`@97AP;W)T($]205].3%,]+VAO;64O;W)A8VQE+T]R84AO
M;64Q+V]C;VUM;VXO;FQS+V%D;6EN+V1A=&$*("H@("`@97AP;W)T($]205].
M3%,S,STO:&]M92]O<F%C;&4O3W)A2&]M93$O;V-O;6UO;B]N;',O861M:6XO
M9&%T80H@*B`@("!E>'!O<G0@3$1?3$E"4D%265]0051(/21/4D%#3$5?2$]-
M12]L:6(Z)$Q$7TQ)0E)!4EE?4$%42`H@*B`*("H@("`@64]5($U54U0@0U53
M5$]-25I%(%1(15-%(%9!3%5%4R!43R!"12!!4%!23U!224%412!43R!93U52
M($E.4U1!3$Q!5$E/3@H@*B`*("H@("`@66]U(&-A;B!I;F-L=61E('1H97-E
M('9A<FEA8FQE<R!I;B!T:&4@=7-E<B=S(&QO8V%L("YP<F]F:6QE(&]R(&EN
M"B`J("`@("]E=&,O<')O9FEL92P@971C+@H@*B`*("H@("H@3F\@9W)A;G1S
M(&%R92!N96-E<W-A<GD@<VEN8V4@=V4@8V]N;F5C="!A<R!T:&4@;W=N97(@
M;V8@=&AE('1A8FQE<RX@268*("H@("`@>6]U('=I<V@@>6]U(&-A;B!A9&%P
M="!T:&4@8W)E871I;VX@;V8@=&%B;&5S('1O(&EN8VQU9&4@=&%B;&5S<&%C
M92!A;F0*("H@("`@<W1O<F%G92!I;F9O<FUA=&EO;BX@4VEN8V4@=V4@:6YC
M;'5D92!N;VYE(&ET('=I;&P@=7-E('1H92!D969A=6QT"B`J("`@('1A8FQE
M<W!A8V4@=F%L=65S(&9O<B!T:&4@=7-E<B!C<F5A=&EN9R!T:&5S92!T86)L
M97,N(%-A;64@=VET:"!T:&4*("H@("`@:6YD97AE<R`H:6X@=&AE;W)Y('1H
M97-E('-H;W5L9"!U<V4@82!D:69F97)E;G0@=&%B;&5S<&%C92DN"B`J(`H@
M*B`@*B!4:&5R92!I<R!N;R!N965D('1O('-H=70@9&]W;B!A;F0@<W1A<G0@
M=7`@=&AE(&1A=&%B87-E(0H@*B\*"G)E;2!C;VYN(&AO<F1E+R9H;W)D95]P
M87-S=V]R9$!D871A8F%S90H*+RHJ"B`J(%1H:7,@:7,@=&AE($AO<F1E('5S
M97)S('1A8FQE+"!N965D960@;VYL>2!I9B!Y;W4@87)E('5S:6YG(%-13`H@
M*B!A=71H96YT:6-A=&EO;BX@($YO=&4@=&AA="!P87-S;W=R9',@:6X@=&AI
M<R!T86)L92!N965D('1O(&)E(&UD-2UE;F-O9&5D+@H@*B\*"D-214%412!4
M04),12!H;W)D95]U<V5R<R`H"B`@("!U<V5R7W5I9"`@("`@("`@("`@("`@
M("`@("`@5D%20TA!4C(H,C4U*2!.3U0@3E5,3"P*("`@('5S97)?<&%S<R`@
M("`@("`@("`@("`@("`@("!605)#2$%2,B@R-34I($Y/5"!.54Q,+`H@("`@
M=7-E<E]S;V9T7V5X<&ER871I;VY?9&%T92`@($Y534)%4B@Q-BDL"B`@("!U
M<V5R7VAA<F1?97AP:7)A=&EO;E]D871E("`@3E5-0D52*#$V*2P*"B`@("!0
M4DE-05)9($M%62`H=7-E<E]U:60I"BD["@H*+RHJ"B`J(%1H:7,@:7,@=&AE
M($AO<F1E('!R969E<F5N8V5S('1A8FQE+"!H;VQD:6YG(&%L;"!O9B!T:&4@
M=7-E<BUS<&5C:69I8PH@*B!O<'1I;VYS(&9O<B!E=F5R>2!(;W)D92!U<V5R
M+@H@*B`*("H@<')E9E]U:60@("!I<R!T:&4@=7-E<FYA;64N"B`J('!R969?
M<V-O<&4@:7,@=&AE(&%P<&QI8V%T:6]N('1H92!P<F5F(&)E;&]N9W,@=&\N
M"B`J('!R969?;F%M92`@:7,@=&AE(&YA;64@;V8@=&AE('9A<FEA8FQE('1O
M('-A=F4N"B`J('!R969?=F%L=64@:7,@=&AE('9A;'5E('-A=F5D("AC86X@
M8F4@=F5R>2!L;VYG*2X*("H@"B`J(%=E('5S92!A($-,3T(@8V]L=6UN('-O
M('1H870@;&]N9V5R(&-O;'5M;B!V86QU97,@87)E('-U<'!O<G1E9"X*("H@
M"B`J($EF('-T:6QL('5S:6YG($]R86-L92`W('1H:7,@<VAO=6QD('=O<FL@
M8G5T('EO=2!H879E('1O('5S90H@*B!605)#2$%2,B@R,#`P*2!W:&EC:"!I
M<R!T:&4@;&EM:70@:6UP;W-E9"!B>2!S86ED('9E<G-I;VXN"B`J+PH*0U)%
M051%(%1!0DQ%(&AO<F1E7W!R969S("@*("`@('!R969?=6ED("`@(%9!4D-(
M05(R*#(U-2D@3D]4($Y53$PL"B`@("!P<F5F7W-C;W!E("!605)#2$%2,B@Q
M-BD@3D]4($Y53$PL"B`@("!P<F5F7VYA;64@("!605)#2$%2,B@S,BD@3D]4
M($Y53$PL"BTM("!3964@86)O=F4@;F]T97,@;VX@0TQ/0G,N"B`@("!P<F5F
M7W9A;'5E("!#3$]"+`H*("`@(%!224U!4ED@2T59("AP<F5F7W5I9"P@<')E
M9E]S8V]P92P@<')E9E]N86UE*0HI.PH*0U)%051%($E.1$58('!R969?=6ED
M7VED>"!/3B!H;W)D95]P<F5F<R`H<')E9E]U:60I.PI#4D5!5$4@24Y$15@@
M<')E9E]S8V]P95]I9'@@3TX@:&]R9&5?<')E9G,@*'!R969?<V-O<&4I.PH*
M"B\J*@H@*B!4:&4@1&%T851R964@=&%B;&5S(&%R92!U<V5D(&9O<B!H;VQD
M:6YG(&AI97)A<F-H:6-A;"!D871A('-U8V@@87,@1W)O=7!S+`H@*B!097)M
M:7-S:6]N<RP@86YD(&1A=&$@9F]R('-O;64@2&]R9&4@87!P;&EC871I;VYS
M+@H@*B\*"D-214%412!404),12!H;W)D95]D871A=')E92`H"B`@("!D871A
M=')E95]I9"`@("`@("`@("!.54U"15(H,38I($Y/5"!.54Q,+`H@("`@9W)O
M=7!?=6ED("`@("`@("`@("`@5D%20TA!4C(H,C4U*2!.3U0@3E5,3"P*("`@
M('5S97)?=6ED("`@("`@("`@("`@(%9!4D-(05(R*#(U-2DL"B`@("!D871A
M=')E95]N86UE("`@("`@("!605)#2$%2,B@R-34I($Y/5"!.54Q,+`H@("`@
M9&%T871R965?<&%R96YT<R`@("`@5D%20TA!4C(H,C4U*2P*("`@(&1A=&%T
M<F5E7V]R9&5R("`@("`@($Y534)%4B@Q-BDL"B`@("!D871A=')E95]D871A
M("`@("`@("!#3$]"+`H@("`@9&%T871R965?<V5R:6%L:7IE9"`@3E5-0D52
M*#@I($1%1D%53%0@,"!.3U0@3E5,3"P*"B`@("!04DE-05)9($M%62`H9&%T
M871R965?:60I"BD["@I#4D5!5$4@24Y$15@@9&%T871R965?9&%T871R965?
M;F%M95]I9'@@3TX@:&]R9&5?9&%T871R964@*&1A=&%T<F5E7VYA;64I.PI#
M4D5!5$4@24Y$15@@9&%T871R965?9W)O=7!?:61X($].(&AO<F1E7V1A=&%T
M<F5E("AG<F]U<%]U:60I.PI#4D5!5$4@24Y$15@@9&%T871R965?=7-E<E]I
M9'@@3TX@:&]R9&5?9&%T871R964@*'5S97)?=6ED*3L*0U)%051%($E.1$58
M(&1A=&%T<F5E7V]R9&5R7VED>"!/3B!H;W)D95]D871A=')E92`H9&%T871R
M965?;W)D97(I.PI#4D5!5$4@24Y$15@@9&%T871R965?<V5R:6%L:7IE9%]I
M9'@@3TX@:&]R9&5?9&%T871R964@*&1A=&%T<F5E7W-E<FEA;&EZ960I.PH*
M0U)%051%(%1!0DQ%(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*`H@("`@
M9&%T871R965?:60@("`@("!.54U"15(H,38I($Y/5"!.54Q,+`H@("`@871T
M<FEB=71E7VYA;64@("!605)#2$%2,B@R-34I($Y/5"!.54Q,+`H@("`@871T
M<FEB=71E7VME>2`@("!605)#2$%2,B@R-34I+`H@("`@871T<FEB=71E7W9A
M;'5E("!605)#2$%2,B@T,#`P*0HI.PH*0U)%051%($E.1$58(&1A=&%T<F5E
M7V%T=')I8G5T95]I9'@@3TX@:&]R9&5?9&%T871R965?871T<FEB=71E<R`H
M9&%T871R965?:60I.PI#4D5!5$4@24Y$15@@9&%T871R965?871T<FEB=71E
M7VYA;65?:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*&%T=')I
M8G5T95]N86UE*3L*0U)%051%($E.1$58(&1A=&%T<F5E7V%T=')I8G5T95]K
M97E?:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*&%T=')I8G5T
M95]K97DI.PH*"D-214%412!404),12!H;W)D95]T;VME;G,@*`H@("`@=&]K
M96Y?861D<F5S<R`@("!605)#2$%2,B@Q,#`I($Y/5"!.54Q,+`H@("`@=&]K
M96Y?:60@("`@("`@("!605)#2$%2,B@S,BD@3D]4($Y53$PL"B`@("!T;VME
M;E]T:6UE<W1A;7`@($Y534)%4B@Q-BD@3D]4($Y53$PL"@H@("`@4%))34%2
M62!+15D@*'1O:V5N7V%D9')E<W,L('1O:V5N7VED*0HI.PH*"D-214%412!4
M04),12!H;W)D95]V9G,@*`H@("`@=F9S7VED("`@("`@("!.54U"15(H,38I
M($Y/5"!.54Q,+`H@("`@=F9S7W1Y<&4@("`@("!.54U"15(H."D@3D]4($Y5
M3$PL"B`@("!V9G-?<&%T:"`@("`@(%9!4D-(05(R*#(U-2DL"B`@("!V9G-?
M;F%M92`@("`@(%9!4D-(05(R*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?;6]D
M:69I960@($Y534)%4B@Q-BD@3D]4($Y53$PL"B`@("!V9G-?;W=N97(@("`@
M(%9!4D-(05(R*#(U-2DL"B`@("!V9G-?9&%T82`@("`@($),3T(L"@H@("`@
M4%))34%262!+15D@("`H=F9S7VED*0HI.PH*0U)%051%($E.1$58('9F<U]P
M871H7VED>"!/3B!H;W)D95]V9G,@*'9F<U]P871H*3L*0U)%051%($E.1$58
M('9F<U]N86UE7VED>"!/3B!H;W)D95]V9G,@*'9F<U]N86UE*3L*"@I#4D5!
M5$4@5$%"3$4@:&]R9&5?:&ES=&]R:65S("@*("`@(&AI<W1O<GE?:60@("`@
M("`@3E5-0D52*#$V*2!.3U0@3E5,3"P*("`@(&]B:F5C=%]U:60@("`@("`@
M5D%20TA!4C(H,C4U*2!.3U0@3E5,3"P*("`@(&AI<W1O<GE?86-T:6]N("`@
M5D%20TA!4C(H,S(I($Y/5"!.54Q,+`H@("`@:&ES=&]R>5]T<R`@("`@("!.
M54U"15(H,38I($Y/5"!.54Q,+`H@("`@:&ES=&]R>5]D97-C("`@("!#3$]"
M+`H@("`@:&ES=&]R>5]W:&\@("`@("!605)#2$%2,B@R-34I+`H@("`@:&ES
M=&]R>5]E>'1R82`@("!#3$]"+`H*("`@(%!224U!4ED@2T59("AH:7-T;W)Y
M7VED*0HI.PH*0U)%051%($E.1$58(&AI<W1O<GE?86-T:6]N7VED>"!/3B!H
M;W)D95]H:7-T;W)I97,@*&AI<W1O<GE?86-T:6]N*3L*0U)%051%($E.1$58
M(&AI<W1O<GE?='-?:61X($].(&AO<F1E7VAI<W1O<FEE<R`H:&ES=&]R>5]T
M<RD["D-214%412!)3D1%6"!H:7-T;W)Y7W5I9%]I9'@@3TX@:&]R9&5?:&ES
M=&]R:65S("AO8FIE8W1?=6ED*3L*"@I#4D5!5$4@5$%"3$4@:&]R9&5?<V5S
M<VEO;FAA;F1L97(@*`H@("`@<V5S<VEO;E]I9"`@("`@("`@("`@("!605)#
M2$%2,B@S,BD@3D]4($Y53$PL"B`@("!S97-S:6]N7VQA<W1M;V1I9FEE9"`@
M($E.5"!.3U0@3E5,3"P*("`@('-E<W-I;VY?9&%T82`@("`@("`@("`@0DQ/
M0BP*"B`@("!04DE-05)9($M%62`H<V5S<VEO;E]I9"D**3L*"@IE>&ET"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO8W)E871E+FUY<W%L+G-Q;```
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$R,S`W(#$P-3$U-#,S
M-S0S(#`R,S$V,0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O<W%L+V-R96%T92YM
M>7-Q;"YS<6PL=B`Q+C0N-BXY(#(P,#8O,#<O,#4@,34Z-3,Z,3`@:F%N($5X
M<"`D"BTM"BTM($EF('EO=2!A<F4@:6YS=&%L;&EN9R!(;W)D92!F;W(@=&AE
M(&9I<G-T('1I;64L('EO=2!C86X@<VEM<&QY"BTM(&1I<F5C="!T:&ES(&9I
M;&4@=&\@;7ES<6P@87,@4U1$24XZ"BTM"BTM("0@;7ES<6P@+2UU<V5R/7)O
M;W0@+2UP87-S=V]R9#T\37E344PM<F]O="UP87-S=V]R9#X@/"!C<F5A=&4N
M;7ES<6PN<W%L"BTM"BTM($EF('EO=2!A<F4@=7!G<F%D:6YG(&9R;VT@82!P
M<F5V:6]U<R!V97)S:6]N+"!Y;W4@=VEL;"!N965D('1O(&-O;6UE;G0*+2T@
M;W5T('1H92!T:&4@=7-E<B!C<F5A=&EO;B!S=&5P<R!B96QO=RP@87,@=V5L
M;"!A<R!T:&4@<V-H96UA<R!F;W(@86YY"BTM('1A8FQE<R!T:&%T(&%L<F5A
M9'D@97AI<W0N"BTM"BTM($EF('EO=2!C:&]O<V4@=&\@9W)A;G0@<&5R;6ES
M<VEO;G,@;6%N=6%L;'DL(&YO=&4@=&AA="!W:71H($UY4U%,+"!014%2($1"
M"BTM(&5M=6QA=&5S('-E<75E;F-E<R!B>2!A=71O;6%T:6-A;&QY(&-R96%T
M:6YG(&5X=')A('1A8FQE<R!E;F1I;F<@:6X@7W-E<2P*+2T@<V\@=&AE($UY
M4U%,(")H;W)D92(@=7-E<B!M=7-T(&AA=F4@0U)%051%('!R:79I;&5G92!O
M;B!T:&4@(FAO<F1E(@HM+2!D871A8F%S92X*+2T*+2T@268@>6]U(&%R92!U
M<&=R861I;F<@9G)O;2!(;W)D92`Q+G@L('1H92!(;W)D92!T86)L97,@>6]U
M(&AA=F4@9G)O;0HM+2!T:&%T('9E<G-I;VX@87)E(&YO(&QO;F=E<B!U<V5D
M.R!Y;W4@;6%Y('=I<V@@=&\@96ET:&5R(&1E;&5T92!T:&]S90HM+2!T86)L
M97,@;W(@<VEM<&QY(')E8W)E871E('1H92!D871A8F%S92!A;F5W+@H*55-%
M(&UY<W%L.PH*4D503$%#12!)3E1/('5S97(@*&AO<W0L('5S97(L('!A<W-W
M;W)D*0H@("`@5D%,5453("@*("`@("`@("`G;&]C86QH;W-T)RP*("`@("`@
M("`G:&]R9&4G+`H)4$%34U=/4D0H)T!714)-04E,7U!!4U-73U)$0"<I"BD[
M"@I215!,04-%($E.5$\@9&(@*&AO<W0L(&1B+"!U<V5R+"!S96QE8W1?<')I
M=BP@:6YS97)T7W!R:78L('5P9&%T95]P<FEV+`H@("`@("`@("`@("`@("`@
M(&1E;&5T95]P<FEV+"!C<F5A=&5?<')I=BP@9')O<%]P<FEV+"!I;F1E>%]P
M<FEV*0H@("`@5D%,5453("@*("`@("`@("`G;&]C86QH;W-T)RP*("`@("`@
M("`G:&]R9&4G+`H@("`@("`@("=H;W)D92<L"B`@("`@("`@)UDG+"`G62<L
M("=9)RP@)UDG+`H@("`@("`@("=9)RP@)UDG+"`G62<**3L*"BTM($UA:V4@
M<W5R92!T:&%T('!R:79I;&EG97,@87)E(')E;&]A9&5D+@I&3%532"!04DE6
M24Q%1T53.PH*+2T@37E344P@,RXR,RYX(&%P<&5A<G,@=&\@:&%V92`B0U)%
M051%($1!5$%"05-%($E&($Y/5"!%6$E35%,B(&%N9`HM+2`B0U)%051%(%1!
M0DQ%($E&($Y/5"!%6$E35%,B('=H:6-H('=O=6QD(&)E(&$@;FEC92!W87D@
M=&\@:&%N9&QE"BTM(')E:6YS=&%L;',@9W)A8V5F=6QL>2`H<V]M961A>2DN
M("!&;W(@;F]W+"!D<F]P('1H92!D871A8F%S90HM+2!M86YU86QL>2!T;R!A
M=F]I9"!#4D5!5$4@97)R;W)S+@I#4D5!5$4@1$%404)!4T4@:&]R9&4["@I5
M4T4@:&]R9&4["@I#4D5!5$4@5$%"3$4@:&]R9&5?=7-E<G,@*`H@("`@=7-E
M<E]U:60@("`@("`@("`@("`@("`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,
M3"P*("`@('5S97)?<&%S<R`@("`@("`@("`@("`@("`@("!605)#2$%2*#(U
M-2D@3D]4($Y53$PL"B`@("!U<V5R7W-O9G1?97AP:7)A=&EO;E]D871E("`@
M24Y4+`H@("`@=7-E<E]H87)D7V5X<&ER871I;VY?9&%T92`@($E.5"P*"B`@
M("!04DE-05)9($M%62`H=7-E<E]U:60I"BD["@I'4D%.5"!314Q%0U0L($E.
M4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?=7-E<G,@5$\@:&]R9&5`
M;&]C86QH;W-T.PH*0U)%051%(%1!0DQ%(&AO<F1E7W!R969S("@*("`@('!R
M969?=6ED("`@("`@("!605)#2$%2*#(P,"D@3D]4($Y53$PL"B`@("!P<F5F
M7W-C;W!E("`@("`@5D%20TA!4B@Q-BD@3D]4($Y53$P@1$5&055,5"`G)RP*
M("`@('!R969?;F%M92`@("`@("!605)#2$%2*#,R*2!.3U0@3E5,3"P*("`@
M('!R969?=F%L=64@("`@("!,3TY'5$585"!.54Q,+`H*("`@(%!224U!4ED@
M2T59("AP<F5F7W5I9"P@<')E9E]S8V]P92P@<')E9E]N86UE*0HI.PH*0U)%
M051%($E.1$58('!R969?=6ED7VED>"!/3B!H;W)D95]P<F5F<R`H<')E9E]U
M:60I.PI#4D5!5$4@24Y$15@@<')E9E]S8V]P95]I9'@@3TX@:&]R9&5?<')E
M9G,@*'!R969?<V-O<&4I.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%4
M12P@1$5,151%($].(&AO<F1E7W!R969S(%1/(&AO<F1E0&QO8V%L:&]S=#L*
M"D-214%412!404),12!H;W)D95]D871A=')E92`H"B`@("`@("!D871A=')E
M95]I9"!)3E0@3D]4($Y53$PL"B`@("`@("!G<F]U<%]U:60@5D%20TA!4B@R
M-34I($Y/5"!.54Q,+`H@("`@("`@=7-E<E]U:60@5D%20TA!4B@R-34I($Y/
M5"!.54Q,+`H@("`@("`@9&%T871R965?;F%M92!605)#2$%2*#(U-2D@3D]4
M($Y53$PL"B`@("`@("!D871A=')E95]P87)E;G1S(%9!4D-(05(H,C4U*2!.
M3U0@3E5,3"P*("`@("`@(&1A=&%T<F5E7V]R9&5R($E.5"P*("`@("`@(&1A
M=&%T<F5E7V1A=&$@5$585"P*("`@("`@(&1A=&%T<F5E7W-E<FEA;&EZ960@
M4TU!3$Q)3E0@1$5&055,5"`P($Y/5"!.54Q,+`H*("`@("`@(%!224U!4ED@
M2T59("AD871A=')E95]I9"D**3L*"D-214%412!)3D1%6"!D871A=')E95]D
M871A=')E95]N86UE7VED>"!/3B!H;W)D95]D871A=')E92`H9&%T871R965?
M;F%M92D["D-214%412!)3D1%6"!D871A=')E95]G<F]U<%]I9'@@3TX@:&]R
M9&5?9&%T871R964@*&=R;W5P7W5I9"D["D-214%412!)3D1%6"!D871A=')E
M95]U<V5R7VED>"!/3B!H;W)D95]D871A=')E92`H=7-E<E]U:60I.PI#4D5!
M5$4@24Y$15@@9&%T871R965?<V5R:6%L:7IE9%]I9'@@3TX@:&]R9&5?9&%T
M871R964@*&1A=&%T<F5E7W-E<FEA;&EZ960I.PH*0U)%051%(%1!0DQ%(&AO
M<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*`H@("`@9&%T871R965?:60@24Y4
M($Y/5"!.54Q,+`H@("`@871T<FEB=71E7VYA;64@5D%20TA!4B@R-34I($Y/
M5"!.54Q,+`H@("`@871T<FEB=71E7VME>2!605)#2$%2*#(U-2D@1$5&055,
M5"`G)R!.3U0@3E5,3"P*("`@(&%T=')I8G5T95]V86QU92!415A4"BD["@I#
M4D5!5$4@24Y$15@@9&%T871R965?871T<FEB=71E7VED>"!/3B!H;W)D95]D
M871A=')E95]A='1R:6)U=&5S("AD871A=')E95]I9"D["D-214%412!)3D1%
M6"!D871A=')E95]A='1R:6)U=&5?;F%M95]I9'@@3TX@:&]R9&5?9&%T871R
M965?871T<FEB=71E<R`H871T<FEB=71E7VYA;64I.PI#4D5!5$4@24Y$15@@
M9&%T871R965?871T<FEB=71E7VME>5]I9'@@3TX@:&]R9&5?9&%T871R965?
M871T<FEB=71E<R`H871T<FEB=71E7VME>2D["@I'4D%.5"!314Q%0U0L($E.
M4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?9&%T871R964@5$\@:&]R
M9&5`;&]C86QH;W-T.PI'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$
M14Q%5$4@3TX@:&]R9&5?9&%T871R965?871T<FEB=71E<R!43R!H;W)D94!L
M;V-A;&AO<W0["@I#4D5!5$4@5$%"3$4@:&]R9&5?=&]K96YS("@*("`@('1O
M:V5N7V%D9')E<W,@("`@5D%20TA!4B@Q,#`I($Y/5"!.54Q,+`H@("`@=&]K
M96Y?:60@("`@("`@("!605)#2$%2*#,R*2!.3U0@3E5,3"P*("`@('1O:V5N
M7W1I;65S=&%M<"`@0DE'24Y4($Y/5"!.54Q,+`H*("`@(%!224U!4ED@2T59
M("AT;VME;E]A9&1R97-S+"!T;VME;E]I9"D**3L*"D=204Y4(%-%3$5#5"P@
M24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]T;VME;G,@5$\@:&]R
M9&5`;&]C86QH;W-T.PH*0U)%051%(%1!0DQ%(&AO<F1E7W9F<R`H"B`@("!V
M9G-?:60@("`@("`@($))1TE.5"!.3U0@3E5,3"P*("`@('9F<U]T>7!E("`@
M("`@4TU!3$Q)3E0@3D]4($Y53$PL"B`@("!V9G-?<&%T:"`@("`@(%9!4D-(
M05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]N86UE("`@("`@5D%20TA!4B@R
M-34I($Y/5"!.54Q,+`H@("`@=F9S7VUO9&EF:65D("!"24=)3E0@3D]4($Y5
M3$PL"B`@("!V9G-?;W=N97(@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*
M("`@('9F<U]D871A("`@("`@3$].1T),3T(L"@H@("`@4%))34%262!+15D@
M*'9F<U]I9"D**3L*"D-214%412!)3D1%6"!V9G-?<&%T:%]I9'@@3TX@:&]R
M9&5?=F9S("AV9G-?<&%T:"D["D-214%412!)3D1%6"!V9G-?;F%M95]I9'@@
M3TX@:&]R9&5?=F9S("AV9G-?;F%M92D["@I'4D%.5"!314Q%0U0L($E.4T52
M5"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?=F9S(%1/(&AO<F1E0&QO8V%L
M:&]S=#L*"D-214%412!404),12!H;W)D95]H:7-T;W)I97,@*`H@("`@:&ES
M=&]R>5]I9"`@("`@("!"24=)3E0@3D]4($Y53$PL"B`@("!O8FIE8W1?=6ED
M("`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@(&AI<W1O<GE?86-T
M:6]N("`@5D%20TA!4B@S,BD@3D]4($Y53$PL"B`@("!H:7-T;W)Y7W1S("`@
M("`@($))1TE.5"!.3U0@3E5,3"P*("`@(&AI<W1O<GE?9&5S8R`@("`@5$58
M5"P*("`@(&AI<W1O<GE?=VAO("`@("`@5D%20TA!4B@R-34I+`H@("`@:&ES
M=&]R>5]E>'1R82`@("!415A4+`H*("`@(%!224U!4ED@2T59("AH:7-T;W)Y
M7VED*0HI.PH*0U)%051%($E.1$58(&AI<W1O<GE?86-T:6]N7VED>"!/3B!H
M;W)D95]H:7-T;W)I97,@*&AI<W1O<GE?86-T:6]N*3L*0U)%051%($E.1$58
M(&AI<W1O<GE?='-?:61X($].(&AO<F1E7VAI<W1O<FEE<R`H:&ES=&]R>5]T
M<RD["D-214%412!)3D1%6"!H:7-T;W)Y7W5I9%]I9'@@3TX@:&]R9&5?:&ES
M=&]R:65S("AO8FIE8W1?=6ED*3L*"D=204Y4(%-%3$5#5"P@24Y315)4+"!5
M4$1!5$4L($1%3$5412!/3B!H;W)D95]H:7-T;W)I97,@5$\@:&]R9&5`;&]C
M86QH;W-T.PH*0U)%051%(%1!0DQ%(&AO<F1E7W-E<W-I;VYH86YD;&5R("@*
M("`@('-E<W-I;VY?:60@("`@("`@("`@("`@5D%20TA!4B@S,BD@3D]4($Y5
M3$PL"B`@("!S97-S:6]N7VQA<W1M;V1I9FEE9"`@($E.5"!.3U0@3E5,3"P*
M("`@('-E<W-I;VY?9&%T82`@("`@("`@("`@3$].1T),3T(L"@H@("`@4%))
M34%262!+15D@*'-E<W-I;VY?:60I"BD@14Y'24Y%(#T@26YN;T1".PH*1U)!
M3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7W-E
M<W-I;VYH86YD;&5R(%1/(&AO<F1E0&QO8V%L:&]S=#L*"D9,55-((%!2259)
M3$5'15,["@HM+2!$;VYE(0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T
M<R]S<6PO:&]R9&5?<V5S<VEO;FAA;F1L97(N<W%L````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P-C4P(#$P-3$U-#,S-S0S(#`R-#<U,@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````M+2`D2&]R9&4Z(&AO
M<F1E+W-C<FEP=',O<W%L+VAO<F1E7W-E<W-I;VYH86YD;&5R+G-Q;"QV(#$N
M,2`R,#`T+S`Y+S$X(#$W.C(P.C4Y(&-H=6-K($5X<"`D"@I#4D5!5$4@5$%"
M3$4@:&]R9&5?<V5S<VEO;FAA;F1L97(@*`H@("`@<V5S<VEO;E]I9"`@("`@
M("`@("`@("!605)#2$%2*#,R*2!.3U0@3E5,3"P*("`@('-E<W-I;VY?;&%S
M=&UO9&EF:65D("`@24Y4($Y/5"!.54Q,+`H@("`@<V5S<VEO;E]D871A("`@
M("`@("`@("!,3TY'0DQ/0BP*+2T@3W(L(&]N('-O;64@1$)-4R!S>7-T96US
M.@HM+2`@<V5S<VEO;E]D871A("`@("`@("`@("!)34%'12P*"B`@("!04DE-
M05)9($M%62`H<V5S<VEO;E]I9"D**3L*"D=204Y4(%-%3$5#5"P@24Y315)4
M+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]S97-S:6]N:&%N9&QE<B!43R!H
M;W)D93L*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O<W%L+V-R96%T
M92YM<V1E+G-Q;```````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M-C0Q,"`Q,#4Q-30S,S<T,R`P,C(W-#(`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+2T@)$AO<F1E.B!H;W)D92]S8W)I<'1S
M+W-Q;"]C<F5A=&4N;7-D92YS<6PL=B`Q+C$N,BXU(#(P,#8O,#8O,CD@,38Z
M,CDZ,#(@:F%N($5X<"`D"@I54T4@;6%S=&5R"D=/"@I#4D5!5$4@1$%404)!
M4T4@:&]R9&4*1T\*"D5814,@<W!?861D;&]G:6X@)VAO<F1E)RP@)VAO<F1E
M7VUG<B<L("=H;W)D92<*1T\*"E5312!H;W)D90I'3PH*15A%0R!S<%]G<F%N
M=&1B86-C97-S("=H;W)D92<*1T\*"D-214%412!404),12!H;W)D95]U<V5R
M<R`H"B`@("!U<V5R7W5I9"!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!U
M<V5R7W!A<W,@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H*("`@(%!224U!4ED@
M2T59("AU<V5R7W5I9"D**0I'3PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%50
M1$%412P@1$5,151%($].(&AO<F1E7W5S97)S(%1/(&AO<F1E"D=/"@I#4D5!
M5$4@5$%"3$4@:&]R9&5?<')E9G,@*`H@("`@<')E9E]U:60@5D%20TA!4B@R
M,#`I($Y/5"!.54Q,+`H@("`@<')E9E]S8V]P92!605)#2$%2*#$V*2!.3U0@
M3E5,3"!$149!54Q4("<G+`H@("`@<')E9E]N86UE(%9!4D-(05(H,S(I($Y/
M5"!.54Q,+`H@("`@<')E9E]V86QU92!415A4($Y53$PL"@H@("`@4%))34%2
M62!+15D@*'!R969?=6ED+"!P<F5F7W-C;W!E+"!P<F5F7VYA;64I"BD*1T\*
M"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D
M95]P<F5F<R!43R!H;W)D90I'3PH*0U)%051%($E.1$58('!R969?=6ED7VED
M>"!/3B!H;W)D95]P<F5F<R`H<')E9E]U:60I"D-214%412!)3D1%6"!P<F5F
M7W-C;W!E7VED>"!/3B!H;W)D95]P<F5F<R`H<')E9E]S8V]P92D*1T\*"D-2
M14%412!404),12!H;W)D95]D871A=')E92`H"B`@("!D871A=')E95]I9"!)
M3E0@3D]4($Y53$PL"B`@("!G<F]U<%]U:60@5D%20TA!4B@R-34I($Y/5"!.
M54Q,+`H@("`@=7-E<E]U:60@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@
M9&%T871R965?;F%M92!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!D871A
M=')E95]P87)E;G1S(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@(&1A=&%T
M<F5E7V]R9&5R($E.5"P*("`@(&1A=&%T<F5E7V1A=&$@5$585"P*("`@(&1A
M=&%T<F5E7W-E<FEA;&EZ960@4TU!3$Q)3E0@1$5&055,5"`P($Y/5"!.54Q,
M+`H*("`@(%!224U!4ED@2T59("AD871A=')E95]I9"D**0I'3PH*1U)!3E0@
M4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7V1A=&%T
M<F5E(%1/(&AO<F1E"D=/"@I#4D5!5$4@24Y$15@@9&%T871R965?9&%T871R
M965?;F%M95]I9'@@3TX@:&]R9&5?9&%T871R964@*&1A=&%T<F5E7VYA;64I
M"D-214%412!)3D1%6"!D871A=')E95]G<F]U<%]I9'@@3TX@:&]R9&5?9&%T
M871R964@*&=R;W5P7W5I9"D*0U)%051%($E.1$58(&1A=&%T<F5E7W5S97)?
M:61X($].(&AO<F1E7V1A=&%T<F5E("AU<V5R7W5I9"D*0U)%051%($E.1$58
M(&1A=&%T<F5E7W-E<FEA;&EZ961?:61X($].(&AO<F1E7V1A=&%T<F5E("AD
M871A=')E95]S97)I86QI>F5D*0I'3PH*0U)%051%(%1!0DQ%(&AO<F1E7V1A
M=&%T<F5E7V%T=')I8G5T97,@*`H@("`@9&%T871R965?:60@24Y4($Y/5"!.
M54Q,+`H@("`@871T<FEB=71E7VYA;64@5D%20TA!4B@R-34I($Y/5"!.54Q,
M+`H@("`@871T<FEB=71E7VME>2!605)#2$%2*#(U-2D@1$5&055,5"`G)R!.
M3U0@3E5,3"P*("`@(&%T=')I8G5T95]V86QU92!415A4"BD*1T\*"D=204Y4
M(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]D871A
M=')E92!43R!H;W)D90I'3PH*0U)%051%($E.1$58(&1A=&%T<F5E7V%T=')I
M8G5T95]I9'@@3TX@:&]R9&5?9&%T871R965?871T<FEB=71E<R`H9&%T871R
M965?:60I"D-214%412!)3D1%6"!D871A=')E95]A='1R:6)U=&5?;F%M95]I
M9'@@3TX@:&]R9&5?9&%T871R965?871T<FEB=71E<R`H871T<FEB=71E7VYA
M;64I"D-214%412!)3D1%6"!D871A=')E95]A='1R:6)U=&5?:V5Y7VED>"!/
M3B!H;W)D95]D871A=')E95]A='1R:6)U=&5S("AA='1R:6)U=&5?:V5Y*0I'
M3PH*0U)%051%(%1!0DQ%(&AO<F1E7W1O:V5N<R`H"B`@("!T;VME;E]A9&1R
M97-S(%9!4D-(05(H,3`P*2!.3U0@3E5,3"P*("`@('1O:V5N7VED(%9!4D-(
M05(H,S(I($Y/5"!.54Q,+`H@("`@=&]K96Y?=&EM97-T86UP($))1TE.5"!.
M3U0@3E5,3"P*"B`@("!04DE-05)9($M%62`H=&]K96Y?861D<F5S<RP@=&]K
M96Y?:60I"BD*1T\*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%
M3$5412!/3B!H;W)D95]T;VME;G,@5$\@:&]R9&4*1T\*"D-214%412!404),
M12!H;W)D95]V9G,@*`H@("`@=F9S7VED($))1TE.5"!.3U0@3E5,3"P*("`@
M('9F<U]T>7!E(%--04Q,24Y4($Y/5"!.54Q,+`H@("`@=F9S7W!A=&@@5D%2
M0TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=F9S7VYA;64@5D%20TA!4B@R-34I
M($Y/5"!.54Q,+`H@("`@=F9S7VUO9&EF:65D($))1TE.5"!.3U0@3E5,3"P*
M("`@('9F<U]O=VYE<B!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?
M9&%T82!415A4+`H*("`@(%!224U!4ED@2T59("`@*'9F<U]I9"D**0I'3PH*
M1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E
M7W9F<R!43R!H;W)D90I'3PH*0U)%051%($E.1$58('9F<U]P871H7VED>"!/
M3B!H;W)D95]V9G,@*'9F<U]P871H*0I#4D5!5$4@24Y$15@@=F9S7VYA;65?
M:61X($].(&AO<F1E7W9F<R`H=F9S7VYA;64I"D=/"@I#4D5!5$4@5$%"3$4@
M:&]R9&5?:&ES=&]R:65S("@*("`@(&AI<W1O<GE?:60@("`@("`@0DE'24Y4
M($Y/5"!.54Q,+`H@("`@;V)J96-T7W5I9"`@("`@("!605)#2$%2*#(U-2D@
M3D]4($Y53$PL"B`@("!H:7-T;W)Y7V%C=&EO;B`@(%9!4D-(05(H,S(I($Y/
M5"!.54Q,+`H@("`@:&ES=&]R>5]T<R`@("`@("!"24=)3E0@3D]4($Y53$PL
M"B`@("!H:7-T;W)Y7V1E<V,@("`@(%1%6%0L"B`@("!H:7-T;W)Y7W=H;R`@
M("`@(%9!4D-(05(H,C4U*2P*("`@(&AI<W1O<GE?97AT<F$@("`@5$585"P*
M"B`@("!04DE-05)9($M%62`H:&ES=&]R>5]I9"D**0I'3PH*1U)!3E0@4T5,
M14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7VAI<W1O<FEE
M<R!43R!H;W)D90I'3PH*0U)%051%($E.1$58(&AI<W1O<GE?86-T:6]N7VED
M>"!/3B!H;W)D95]H:7-T;W)I97,@*&AI<W1O<GE?86-T:6]N*0I#4D5!5$4@
M24Y$15@@:&ES=&]R>5]T<U]I9'@@3TX@:&]R9&5?:&ES=&]R:65S("AH:7-T
M;W)Y7W1S*0I#4D5!5$4@24Y$15@@:&ES=&]R>5]U:61?:61X($].(&AO<F1E
M7VAI<W1O<FEE<R`H;V)J96-T7W5I9"D*1T\*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]214%$
M344`````````````````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,3(U-3,@,3`U,34T,S,W-#,@,#(P-S$T`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]"B!(;W)D92!$871A8F%S92!);G-T86QL871I;VX@1W5I
M9&4*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"CI,87-T
M('5P9&%T93H@("`D1&%T93H@,C`P-2\Q,"\Q."`Q,3HS-#HP,"`D"CI2979I
M<VEO;CH@("`@("`D4F5V:7-I;VXZ(#$N,BXQ,"XS("0*.D-O;G1A8W0Z("`@
M("`@(&AO<F1E0&QI<W1S+FAO<F1E+F]R9PH*"E!U<G!O<V4@;V8@=&AI<R!F
M:6QE"GY^?GY^?GY^?GY^?GY^?GY^?GY^"@I4:&ES(&9I;&4@=VEL;"!H;W!E
M9G5L;'D@96%S92!T:&4@:6YS=&%L;&%T:6]N(&%N9"!C;VYF:6=U<F%T:6]N
M(&]F('EO=7(*9&%T86)A<V4@9F]R('5S92!W:71H($AO<F1E+B`@5&AE('-C
M;W!E(&]F('1H92!D;V-U;65N="!D96%L<R!P<FEM87)I;'D@=VET:`IU<VEN
M9R!Y;W5R(&1A=&%B87-E('=I=&@@2&]R9&4@86YD('-H;W5L9"!N;W0@8F4@
M8V]N<VED97)E9"!A(')E<V]U<F-E(&9O<@IG96YE<F%L(&1A=&%B87-E('1A
M<VMS+@H*"E)E<75I<F5M96YT<R!F;W(@2&]R9&4*?GY^?GY^?GY^?GY^?GY^
M?GY^?GY^?@H*2&]R9&4@8W5R<F5N=&QY('-U<'!O<G1S(&%T(&QE87-T(#<@
M9&%T86)A<V5S.@H*("`@("T@37E344P@("`@("`@("!H='1P.B\O=W=W+FUY
M<W%L+F-O;2\*("`@("T@4&]S=&=R95-13"`@("!H='1P.B\O=W=W+G!O<W1G
M<F5S<6PN;W)G+PH@("`@+2!/<F%C;&4@("`@("`@(&AT='`Z+R]W=W<N;W)A
M8VQE+F-O;2\*("`@("T@4WEB87-E("`@("`@("!H='1P.B\O=W=W+G-Y8F%S
M92YC;VTO"B`@("`M(%-13&ET92`@("`@("`@:'1T<#HO+W=W=RYS<6QI=&4N
M;W)G+PH@("`@+2!-4R!344P@("`@("`@(&AT='`Z+R]W=W<N;6EC<F]S;V9T
M+F-O;2]S<6PO"B`@("`M($U31$4@("`@("`@("`@:'1T<#HO+W=W=RYM:6-R
M;W-O9G0N8V]M+W-Q;"]M<V1E+PH*37E344P@86YD(%!O<W1G<F5344P@87)E
M(')E9W5L87)L>2!U<V5D(&)Y('1H92!D979E;&]P;65N="!T96%M+"!A;F0@
M=VEL;"!W;W)K"G=I=&@@;F\@<')O8FQE;7,N("!/<F%C;&4@86YD(%-13&ET
M92!S=7!P;W)T(&AA<R!B965N(&UU8V@@:6UP<F]V960@<F5C96YT;'D*86YD
M('=O<FMS(&9I;F4@=&]O+B`@4WEB87-E('=E<F4@<F5P;W)T960@=V]R:VEN
M9R!I;B!T:&4@<')E=FEO=7,@=F5R<VEO;B!O9@I(;W)D92])35`@8GD@<V]M
M92!O9B!O=7(@=7-E<G,L(&%N9"!A<F4@87-S=6UE9"!T;R!S=&EL;"!W;W)K
M+BXN(&)U="!T:&%T"FAA<VXG="!B965N('9E<FEF:65D(')E8V5N=&QY+@H*
M"D)E9F]R92!9;W4@0F5G:6X*?GY^?GY^?GY^?GY^?GY^?@H*66]U('=I;&P@
M;F5E9"!T;R!H879E('EO=7(@9&%T86)A<V4@<')E8V]N9FEG=7)E9"!A;F0@
M=V]R:VEN9R!O;B!Y;W5R('-Y<W1E;0IB969O<F4@>6]U(&5V96X@9V5T('1O
M('1H:7,@<W1A9V4N("!&;W(@:&5L<"!W:71H('1H:7,L('!L96%S92!C;VYS
M=6QT('EO=7(*9&%T86)A<V4@<W!E8VEF:6,@:&5L<"!F:6QE<RX*"D)E9F]R
M92!U<VEN9R!A;GD@;V8@=&AE('-C<FEP=',@;&ES=&5D(&)E;&]W+"!P;&5A
M<V4@;&]O:R!O=F5R('1H96T@=&\@96YS=7)E"G1H870@86YY('-Y<W1E;2US
M<&5C:69I8R!S971T:6YG<R`H;W(@<&5R<V]N86P@8VAO:6-E<RD@87)E('-E
M="!T;R!Y;W5R"F1E<VER960@<V5T=&EN9W,@*&5G+B!@8'5S97)N86UE8&`L
M(&5T8RXI+@H**BI03$5!4T4@3D]412HJ('1H870@=&AE(&1A=&%B87-E(&-O
M;F9I9W5R871I;VX@<W1E<',@;&ES=&5D(&)E;&]W("HJ35535"HJ"FUA=&-H
M('=H870@:7,@8V]N9FEG=7)E9"!W:71H:6X@2&]R9&4N"@I3<&5C:69I8V%L
M;'DL(&EF('EO=2!C:&%N9V4@=&AE(&1A=&%B87-E(&YA;64L('5S97(L(&]R
M('!A<W-W;W)D('=H:6QE"F-O;F9I9W5R:6YG('1H92!D871A8F%S92`H8F5L
M;W<I+"!Y;W4@=VEL;"!N965D('1O(&UA:V4@=&AE('-A;64@8VAA;F=E<R!T
M;PIY;W5R($AO<F1E(&-O;F9I9W5R871I;VX@9FEL97,@87,@=V5L;"X*"@I-
M>5-13`I^?GY^?@H*5&AE(&UY<W%L7V-R96%T92YS<6P@<V-R:7!T('=I;&P@
M8W)E871E(&$@9&%T86)A<V4@8V%L;&5D(&!@:&]R9&5@8"P@86YD(&$*=7-E
M<B!C86QL960@8&!H;W)D96!@("AW:71H('!A<W-W;W)D(&!@:&]R9&5@8"D@
M=&AA="!H87,@9G5L;"!R:6=H=',@=&\@=&AE"F1A=&%B87-E+B`@*DYO=&4@
M=&AA="!W:71H($UY4U%,+"!014%2($1"(&5M=6QA=&5S('-E<75E;F-E<R!B
M>2!A=71O;6%T:6-A;&QY"F-R96%T:6YG(&5X=')A('1A8FQE<R!E;F1I;F<@
M:6X@7W-E<2P@<V\@=&AE($UY4U%,(&!@:&]R9&5@8"!U<V5R(&UU<W0@:&%V
M90I@8$-214%416!@('!R:79I;&5G92!O;B!T:&4@8&!H;W)D96!@(&1A=&%B
M87-E+@H*5&AI<R!S8W)I<'0@;F5E9',@=&\@8F4@<G5N(&%S('1H92!->5-1
M3"!R;V]T('5S97(@*'=H:6-H(&ES("I.3U0J('1H92!S86UE(&%S"G1H92!5
M3DE8+TQI;G5X(')O;W0@=7-E<BDZ.@H*("`D(&UY<W%L("TM=7-E<CUR;V]T
M("TM<&%S<W=O<F0]/$UY4U%,+7)O;W0M<&%S<W=D/B`\(&-R96%T92YM>7-Q
M;"YS<6P*"D%F=&5R(')U;FYI;F<@=&AI<R!S8W)I<'0L(&ET)W,@82!G;V]D
M(&ED96$@=&\@<F5S=&%R="!Y;W5R($UY4U%,('-E<G9E<CHZ"@H@("0@;7ES
M<6QA9&UI;B`M+75S97(]<F]O="`M+7!A<W-W;W)D/3Q->5-13"UR;V]T+7!A
M<W-W9#X@<F5L;V%D"@I4;R!C:&5C:R!T:&%T('1H:7,@:7,@=V]R:VEN9RP@
M=&AE(&9O;&QO=VEN9R!C;VUM86YD('-H;W5L9"!C;VYN96-T('=I=&AO=70*
M97)R;W)S.CH*"B`@)"!M>7-Q;"`M+75S97(]:&]R9&4@+2UP87-S=V]R9#UH
M;W)D92!H;W)D90H*5'EP92!@8'%U:71@8"!T;R!Q=6ET($UY4U%,+@H*"E!O
M<W1G<F5344P*?GY^?GY^?GY^?@H*("`C('-U("T@<&]S=&=R97,@("AO<B!W
M:&%T979E<B!Y;W5R(&1A=&%B87-E(')U;G,@87,N+BX@=7-U86QL>2!P;W-T
M9W)E<RD*("`D('!S<6P@+60@=&5M<&QA=&4Q("UF(&-R96%T92YP9W-Q;"YS
M<6P*"E1H:7,@<V-R:7!T('=I;&P@8W)E871E(&$@8&!H;W)D96!@(&1A=&%B
M87-E(&%N9"!A(&!@:&]R9&5@8"!U<V5R+B`@66]U('-H;W5L9`IS970@82!P
M87-S=V]R9"!F;W(@=&AI<R!U<V5R('=I=&@@=&AI<R!C;VUM86YD("AI9B!Y
M;W4@9&ED;B=T('5N8V]M;65N="!T:&4*;VYE(&EN('!G<W%L7V-R96%T92YS
M<6PI.CH*"B`@)"!P<W%L("UQ8R`B04Q415(@55-%4B!H;W)D92!7251((%!!
M4U-73U)$("=P87-S)SLB('1E;7!L871E,2!P;W-T9W)E<PH*5&AE;B!C<F5A
M=&4@=&AE('1A8FQE<R!W:71H:6X@=&AE(&!@:&]R9&5@8"!D871A8F%S93HZ
M"@H@("0@<'-Q;"`M9"!H;W)D92`M9B!H;W)D95]U<V5R<RYS<6P*("`D('!S
M<6P@+60@:&]R9&4@+68@:&]R9&5?<')E9G,N<W%L"B`@)"!P<W%L("UD(&AO
M<F1E("UF(&AO<F1E7V1A=&%T<F5E+G-Q;`H*5&AE<V4@<V-R:7!T<R!W:6QL
M(&%L<V\@9W)A;G0@=&AE(&!@:&]R9&5@8"!U<V5R('1H92!N96-E<W-A<GD@
M<')I=FEL96=E<R!T;PIE86-H(&]F('1H92!T86)L97,N"@H*3W)A8VQE"GY^
M?GY^?@H*4G5N(&!@<W%L<&QU<V!@+B`@3&]G:6XL('1H96X@6W=E(&YE960@
M:6YS=')U8W1I;VYS(&9O<B!C<F5A=&EN9R!T:&4@9&%T86)A<V4*86YD('5S
M97(@:&5R95TN"@I4:&%T('-H;W5L9"!B92!I="X@(%)E<W1A<G0@3W)A8VQE
M(&IU<W0@=&\@8F4@<W5R92P@86YD('1R>2!I="X@(%1H96X@8W)E871E"G1H
M92!T86)L97,@=VET:&EN('1H92!@8&AO<F1E8&`@9&%T86)A<V4Z.@H*6T%L
M<V\@;F5E9"!T:&]S92!I;G-T<G5C=&EO;G,@:&5R92Y="@H*4WEB87-E"GY^
M?GY^?@H*5&\@8W)E871E('1H92!D871A8F%S92P@9G)O;2!@8&ES<6Q@8"!R
M=6XZ.@H*("!C<F5A=&4@9&%T86)A<V4@:&]R9&4*"DYE>'0L('EO=2!S:&]U
M;&0@*')E8V]M;65N9&5D*2!C<F5A=&4@82!L;V=I;B!T;R!U<V4@=VET:"!T
M:&ES(&1A=&%B87-E+B`@5&AE"F!@:7-Q;&!@(&-O;6UA;F0@9F]R('1H:7,@
M:7,Z.@H*("!S<%]A9&1L;V=I;B`\=7-E<FYA;64^(#QP87-S=V]R9#X*"DYE
M>'0@>6]U(&YE960@=&\@8VAA;F=E('1H92!O=VYE<G-H:7`@;V8@=&AE(&1A
M=&%B87-E('1O('1H:7,@;F5W('5S97(N("!4:&4*8&!I<W%L8&`@8V]M;6%N
M9"!F;W(@=&AI<R!I<SHZ"@H@('-P7V-H86YG961B;W=N97(@/'5S97)N86UE
M/@H*069T97(@=&AA="P@>6]U(&IU<W0@;F5E9"!T;R!S970@=7`@>6]U<B!T
M86)L97,@=VET:&EN('1H92!D871A8F%S92X@(%1O(&1O"G1H870L(&IU<W0@
M<G5N('1H:7,@8V]M;6%N9"!F<F]M('1H92!C;VUM86YD(&QI;F4Z.@H*("!I
M<W%L("UI(&AO<F1E7W5S97)S+G-Q;"`M53QU<V5R;F%M93X@+5`\<&%S<W=O
M<F0^"B`@:7-Q;"`M:2!H;W)D95]P<F5F<RYS<6P@+54\=7-E<FYA;64^("U0
M/'!A<W-W;W)D/@H*"DU31$4@,C`P,"`H86YD('!O<W-I8FQY($U3(%-13"!3
M97)V97(I"GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^
M"@I4;R!C<F5A=&4@=7-E<B!A;F0@9&%T86)A<V4L('5S92!T:&4@;W-Q;"!C
M;VUM86YD.CH*"B`@0SI</F]S<6P@+54@<V$@+5`@861M:6Y?<&%S<W=O<F0@
M+5,@;&]C86QH;W-T("UI(&-R96%T92YM<V1E+G-Q;`H*0F4@<W5R92!T;R!C
M:&%N9V4@=&AE('!A<W-W;W)D(&9O<B!T:&4@:&]R9&4@=7-E<B!I;B!T:&4@
M<V-R:7!T(&9I;&4N("!4;PIS<&5C:69Y(&$@<&%R=&EC=6QA<B!I;G-T86YC
M92!O9B!T:&4@4U%,('-E<G9E<B!U<V4@=&AE"CQS97)V97)N86UE/B\\:6YS
M=&%N8V4^(&9O<B!T:&4@+5,@9FQA9RX@($EF('EO=2!A<F5N)W0@=7-I;F<@
M;6EX960@4U%,"F%U=&AE;G1I8V%T:6]N+"!T:&5N('EO=2=L;"!N965D('1O
M(&UO9&EF>2!T:&4@<V-R:7!T('1O(&%S<V]C:6%T92!T:&4@:&]R9&4*=7-E
M<B!W:71H(&$@=VEN9&]W<R!U<V5R(&%C8V]U;G0@86YD(')U;B!T:&4@<V-R
M:7!T(&EN('1H92!F;VQL;W=I;F<@;6%N;F5R(&%S"G1H92!!9&UI;FES=')A
M=&]R.CH*"B`@0SI</F]S<6P@+44@+5,@;&]C86QH;W-T("UI(&-R96%T92YM
M<V1E+G-Q;`H*268@>6]U)W)E(&AA=FEN9R!P<F]B;&5M<R!R=6YN:6YG('1H
M:7,@<V-R:7!T(&]N(&$@4U%,('-E<G9E<B!O;B!T:&4@;F5T=V]R:RP*8F4@
M<W5R92!T:&4@<V5R=F5R(&ES('-E="!U<"!T;R!A;&QO=R!N971W;W)K(&%C
M8V5S<RX*"@I!9&1I=&EO;F%L($YO=&5S"GY^?GY^?GY^?GY^?GY^?GX*"E1H
M:7,@:7,@8GD@9F%R(&YO="!A(&-O;7!L971E($A/5U1/+B`@5&AI<R!I<R!J
M=7-T(&$@8V]M<&EL960@;&ES="!O9B!W:&%T"G!E;W!L92!H879E(&-O;G1R
M:6)U=&5D('-O(&9A<BX@($EF('EO=2!H879E('1I<',L(&ED96%S+"!S=6=G
M97-T:6]N<R!O<@IA;GET:&EN9R!E;'-E('1H870@>6]U('1H:6YK(&-O=6QD
M(&AE;'`@;W1H97)S(&EN('-E='1I;F<@=7`@=&AE:7(@9&%T86)A<V4*9F]R
M('5S92!W:71H($AO<F1E+"!P;&5A<V4@;&5T('5S(&MN;W<N"@H\9&5V0&QI
M<W1S+FAO<F1E+F]R9SX*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]S8W)I<'1S+W-Q;"]S8W)I<'0N:6YI=&EA;%]H;W)D95]U<V5R
M+G-Q;```````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`U,S,@,3`U,34T,S,W-#,@,#(U
M-S(S`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"TM("1(;W)D93H@:&]R9&4O<V-R:7!T<R]S<6PO<V-R:7!T+FEN:71I86Q?
M:&]R9&5?=7-E<BYS<6PL=B`Q+C$@,C`P-"\P.2\Q."`Q-SHR,#HU.2!C:'5C
M:R!%>'`@)`HM+0HM+2!4:&ES('-C<FEP="!W:6QL(&-R96%T92!A;B!I;FET
M:6%L('5S97(@:6X@82!H;W)D95]U<V5R<R!T86)L92X@5&AE"BTM('!A<W-W
M;W)D(&)E:6YG('5S960@:7,@)V%D;6EN)RP@=VAI8V@@>6]U('-H;W5L9"!C
M:&%N9V4*+2T@24U-141)051%3%DN"@I)3E-%4E0@24Y43R!H;W)D95]U<V5R
M<R`H=7-E<E]U:60L('5S97)?<&%S<RD@5D%,5453("@G861M:6XG+"`G,C$R
M,S)F,CDW834W835A-S0S.#DT83!E-&$X,#%F8S,G*3L*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R
M:7!T<R]S<6PO:&]R9&5?:&ES=&]R:65S+FUS<W%L+G-Q;```````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`Q,C8R(#$P-3$U-#,S-S0S(#`R-3$P,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````M+2`D2&]R9&4Z
M(&AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7VAI<W1O<FEE<RYM<W-Q;"YS<6PL
M=B`Q+C$N,BXQ(#(P,#8O,#$O,3@@,3DZ-3@Z-#(@8F5N($5X<"`D"@I#4D5!
M5$4@5$%"3$4@:&]R9&5?:&ES=&]R:65S("@*("`@(&AI<W1O<GE?:60@("`@
M("`@0DE'24Y4($Y/5"!.54Q,+`H@("`@;V)J96-T7W5I9"`@("`@("!605)#
M2$%2*#(U-2D@3D]4($Y53$PL"B`@("!H:7-T;W)Y7V%C=&EO;B`@(%9!4D-(
M05(H,S(I($Y/5"!.54Q,+`H@("`@:&ES=&]R>5]T<R`@("`@("!"24=)3E0@
M3D]4($Y53$PL"B`@("!H:7-T;W)Y7V1E<V,@("`@(%9!4D-(05(H34%8*2P*
M("`@(&AI<W1O<GE?=VAO("`@("`@5D%20TA!4B@R-34I+`H@("`@:&ES=&]R
M>5]E>'1R82`@("!605)#2$%2*$U!6"DL"BTM"B`@("!04DE-05)9($M%62`H
M:&ES=&]R>5]I9"D**3L*"D-214%412!)3D1%6"!H:7-T;W)Y7V%C=&EO;E]I
M9'@@3TX@:&]R9&5?:&ES=&]R:65S("AH:7-T;W)Y7V%C=&EO;BD["D-214%4
M12!)3D1%6"!H:7-T;W)Y7W1S7VED>"!/3B!H;W)D95]H:7-T;W)I97,@*&AI
M<W1O<GE?=',I.PI#4D5!5$4@24Y$15@@:&ES=&]R>5]U:61?:61X($].(&AO
M<F1E7VAI<W1O<FEE<R`H;V)J96-T7W5I9"D["@I'4D%.5"!314Q%0U0L($E.
M4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?:&ES=&]R:65S(%1/(&AO
M<F1E.PH`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<V-R:7!T<R]S<6PO8W)E871E+G-Q;```````````````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`W-#8W(#$P-3$U-#,S-S0S(#`R,C`S,``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````M+2`D
M2&]R9&4Z(&AO<F1E+W-C<FEP=',O<W%L+V-R96%T92YS<6PL=B`Q+C$N,BXS
M(#(P,#8O,#4O,C(@,C$Z,C<Z,S,@:F%N($5X<"`D"@I#4D5!5$4@5$%"3$4@
M:&]R9&5?=7-E<G,@*`H@("`@=7-E<E]U:60@("`@("`@("`@("`@("`@("`@
M(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('5S97)?<&%S<R`@("`@("`@
M("`@("`@("`@("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!U<V5R7W-O
M9G1?97AP:7)A=&EO;E]D871E("`@24Y414=%4BP*("`@('5S97)?:&%R9%]E
M>'!I<F%T:6]N7V1A=&4@("!)3E1%1T52+`HM+0H@("`@4%))34%262!+15D@
M*'5S97)?=6ED*0HI.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@
M1$5,151%($].(&AO<F1E7W5S97)S(%1/(&AO<F1E.PH*"D-214%412!404),
M12!H;W)D95]P<F5F<R`H"B`@("!P<F5F7W5I9"`@("`@("`@5D%20TA!4B@R
M-34I($Y/5"!.54Q,+`H@("`@<')E9E]S8V]P92`@("`@(%9!4D-(05(H,38I
M($1%1D%53%0@)R<@3D]4($Y53$PL"B`@("!P<F5F7VYA;64@("`@("`@5D%2
M0TA!4B@S,BD@3D]4($Y53$PL"B`@("!P<F5F7W9A;'5E("`@("`@5$585"P*
M+2T*("`@(%!224U!4ED@2T59("AP<F5F7W5I9"P@<')E9E]S8V]P92P@<')E
M9E]N86UE*0HI.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,
M151%($].(&AO<F1E7W!R969S(%1/(&AO<F1E.PH*"D-214%412!404),12!H
M;W)D95]D871A=')E92`H"B`@("!D871A=')E95]I9"!)3E0@3D]4($Y53$PL
M"B`@("!G<F]U<%]U:60@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=7-E
M<E]U:60@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@9&%T871R965?;F%M
M92!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!D871A=')E95]P87)E;G1S
M(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@(&1A=&%T<F5E7V]R9&5R($E.
M5"P*"BTM(%1H97)E(&ES(&YO('!O<G1A8FQE('=A>2!T;R!D;R!T:&ES(&%P
M<&%R96YT;'DN($EF('EO=7(@9&(@9&]E<VXG=`HM+2!A;&QO=R!415A4(&-O
M;'5M;G,L('1H96X@;6%Y8F4@:70@86QL;W=S(&QA<F=E(%9!4D-(05(@8V]L
M=6UN<RP@<V\*+2T@=')Y('1H92!S96-O;F0@;&EN92X*+2T*("`@(&1A=&%T
M<F5E7V1A=&$@5$585"P*+2T@(&1A=&%T<F5E7V1A=&$@5D%20TA!4B@T,#DV
M*2P*"B`@("!D871A=')E95]S97)I86QI>F5D(%--04Q,24Y4($1%1D%53%0@
M,"!.3U0@3E5,3"P*"B`@("!04DE-05)9($M%62`H9&%T871R965?:60I"BD[
M"@I#4D5!5$4@24Y$15@@9&%T871R965?9&%T871R965?;F%M95]I9'@@3TX@
M:&]R9&5?9&%T871R964@*&1A=&%T<F5E7VYA;64I.PI#4D5!5$4@24Y$15@@
M9&%T871R965?9W)O=7!?:61X($].(&AO<F1E7V1A=&%T<F5E("AG<F]U<%]U
M:60I.PI#4D5!5$4@24Y$15@@9&%T871R965?=7-E<E]I9'@@3TX@:&]R9&5?
M9&%T871R964@*'5S97)?=6ED*3L*0U)%051%($E.1$58(&1A=&%T<F5E7V]R
M9&5R7VED>"!/3B!H;W)D95]D871A=')E92`H9&%T871R965?;W)D97(I.PI#
M4D5!5$4@24Y$15@@9&%T871R965?<V5R:6%L:7IE9%]I9'@@3TX@:&]R9&5?
M9&%T871R964@*&1A=&%T<F5E7W-E<FEA;&EZ960I.PH*0U)%051%(%1!0DQ%
M(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*`H@("`@9&%T871R965?:60@
M24Y4($Y/5"!.54Q,+`H@("`@871T<FEB=71E7VYA;64@5D%20TA!4B@R-34I
M($Y/5"!.54Q,+`H@("`@871T<FEB=71E7VME>2!605)#2$%2*#(U-2DL"B`@
M("!A='1R:6)U=&5?=F%L=64@5$585`HI.PH*0U)%051%($E.1$58(&1A=&%T
M<F5E7V%T=')I8G5T95]I9'@@3TX@:&]R9&5?9&%T871R965?871T<FEB=71E
M<R`H9&%T871R965?:60I.PI#4D5!5$4@24Y$15@@9&%T871R965?871T<FEB
M=71E7VYA;65?:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*&%T
M=')I8G5T95]N86UE*3L*0U)%051%($E.1$58(&1A=&%T<F5E7V%T=')I8G5T
M95]K97E?:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*&%T=')I
M8G5T95]K97DI.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,
M151%($].(&AO<F1E7V1A=&%T<F5E(%1/(&AO<F1E.PI'4D%.5"!314Q%0U0L
M($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?9&%T871R965?871T
M<FEB=71E<R!43R!H;W)D93L*"@I#4D5!5$4@5$%"3$4@:&]R9&5?=&]K96YS
M("@*("`@('1O:V5N7V%D9')E<W,@("`@5D%20TA!4B@Q,#`I($Y/5"!.54Q,
M+`H@("`@=&]K96Y?:60@("`@("`@("!605)#2$%2*#,R*2!.3U0@3E5,3"P*
M("`@('1O:V5N7W1I;65S=&%M<"`@0DE'24Y4($Y/5"!.54Q,+`HM+0H@("`@
M4%))34%262!+15D@*'1O:V5N7V%D9')E<W,L('1O:V5N7VED*0HI.PH*1U)!
M3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7W1O
M:V5N<R!43R!H;W)D93L*"@I#4D5!5$4@5$%"3$4@:&]R9&5?=F9S("@*("`@
M('9F<U]I9"`@("`@("`@0DE'24Y4($Y/5"!.54Q,+`H@("`@=F9S7W1Y<&4@
M("`@("!334%,3$E.5"!.3U0@3E5,3"P*("`@('9F<U]P871H("`@("`@5D%2
M0TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=F9S7VYA;64@("`@("!605)#2$%2
M*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?;6]D:69I960@($))1TE.5"!.3U0@
M3E5,3"P*("`@('9F<U]O=VYE<B`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,
M+`H@("`@=F9S7V1A=&$@("`@("!,3TY'0DQ/0BP*+2T@3W(L(&]N('-O;64@
M1$)-4R!S>7-T96US.@HM+2`@=F9S7V1A=&$@("`@("!)34%'12P*("`@(%!2
M24U!4ED@2T59("`@*'9F<U]I9"D**3L*"D-214%412!)3D1%6"!V9G-?<&%T
M:%]I9'@@3TX@:&]R9&5?=F9S("AV9G-?<&%T:"D["D-214%412!)3D1%6"!V
M9G-?;F%M95]I9'@@3TX@:&]R9&5?=F9S("AV9G-?;F%M92D["@I'4D%.5"!3
M14Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?=F9S(%1/
M(&AO<F1E.PH*"D-214%412!404),12!H;W)D95]H:7-T;W)I97,@*`H@("`@
M:&ES=&]R>5]I9"`@("`@("!"24=)3E0@3D]4($Y53$PL"B`@("!O8FIE8W1?
M=6ED("`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@(&AI<W1O<GE?
M86-T:6]N("`@5D%20TA!4B@S,BD@3D]4($Y53$PL"B`@("!H:7-T;W)Y7W1S
M("`@("`@($))1TE.5"!.3U0@3E5,3"P*("`@(&AI<W1O<GE?9&5S8R`@("`@
M5$585"P*("`@(&AI<W1O<GE?=VAO("`@("`@5D%20TA!4B@R-34I+`H@("`@
M:&ES=&]R>5]E>'1R82`@("!415A4+`HM+0H@("`@4%))34%262!+15D@*&AI
M<W1O<GE?:60I"BD["@I#4D5!5$4@24Y$15@@:&ES=&]R>5]A8W1I;VY?:61X
M($].(&AO<F1E7VAI<W1O<FEE<R`H:&ES=&]R>5]A8W1I;VXI.PI#4D5!5$4@
M24Y$15@@:&ES=&]R>5]T<U]I9'@@3TX@:&]R9&5?:&ES=&]R:65S("AH:7-T
M;W)Y7W1S*3L*0U)%051%($E.1$58(&AI<W1O<GE?=6ED7VED>"!/3B!H;W)D
M95]H:7-T;W)I97,@*&]B:F5C=%]U:60I.PH*1U)!3E0@4T5,14-4+"!)3E-%
M4E0L(%501$%412P@1$5,151%($].(&AO<F1E7VAI<W1O<FEE<R!43R!H;W)D
M93L*"@I#4D5!5$4@5$%"3$4@:&]R9&5?<V5S<VEO;FAA;F1L97(@*`H@("`@
M<V5S<VEO;E]I9"`@("`@("`@("`@("!605)#2$%2*#,R*2!.3U0@3E5,3"P*
M("`@('-E<W-I;VY?;&%S=&UO9&EF:65D("`@24Y4($Y/5"!.54Q,+`H@("`@
M<V5S<VEO;E]D871A("`@("`@("`@("!,3TY'0DQ/0BP*+2T@3W(L(&]N('-O
M;64@1$)-4R!S>7-T96US.@HM+2`@<V5S<VEO;E]D871A("`@("`@("`@("!)
M34%'12P*"B`@("!04DE-05)9($M%62`H<V5S<VEO;E]I9"D**3L*"D=204Y4
M(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]S97-S
M:6]N:&%N9&QE<B!43R!H;W)D93L*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO8W)E871E+GAM;```
M````````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$W,S4U(#$P
M-3$U-#,S-S0S(#`R,C`R-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/WAM;"!V97)S:6]N/2(Q+C`B(&5N8V]D:6YG/2))
M4T\M.#@U.2TQ(B`_/@H\9&%T86)A<V4^"@H@/&YA;64^/'9A<FEA8FQE/FYA
M;64\+W9A<FEA8FQE/CPO;F%M93X*(#QC<F5A=&4^/'9A<FEA8FQE/F-R96%T
M93PO=F%R:6%B;&4^/"]C<F5A=&4^"@H@/'1A8FQE/@H*("`\;F%M93YH;W)D
M95]D871A=')E93PO;F%M93X*"B`@/&1E8VQA<F%T:6]N/@H*("`@/&9I96QD
M/@H@("`@/&YA;64^9&%T871R965?:60\+VYA;64^"B`@("`\='EP93YI;G1E
M9V5R/"]T>7!E/@H@("`@/&YO=&YU;&P^=')U93PO;F]T;G5L;#X*("`@/"]F
M:65L9#X*"B`@(#QF:65L9#X*("`@(#QN86UE/F=R;W5P7W5I9#PO;F%M93X*
M("`@(#QT>7!E/G1E>'0\+W1Y<&4^"B`@("`\;&5N9W1H/C(U-3PO;&5N9W1H
M/@H@("`@/&YO=&YU;&P^=')U93PO;F]T;G5L;#X*("`@/"]F:65L9#X*"B`@
M(#QF:65L9#X*("`@(#QN86UE/G5S97)?=6ED/"]N86UE/@H@("`@/'1Y<&4^
M=&5X=#PO='EP93X*("`@(#QL96YG=&@^,C4U/"]L96YG=&@^"B`@("`\;F]T
M;G5L;#YT<G5E/"]N;W1N=6QL/@H@("`\+V9I96QD/@H*("`@/&9I96QD/@H@
M("`@/&YA;64^9&%T871R965?;F%M93PO;F%M93X*("`@(#QT>7!E/G1E>'0\
M+W1Y<&4^"B`@("`\;&5N9W1H/C(U-3PO;&5N9W1H/@H@("`@/&YO=&YU;&P^
M=')U93PO;F]T;G5L;#X*("`@/"]F:65L9#X*"B`@(#QF:65L9#X*("`@(#QN
M86UE/F1A=&%T<F5E7W!A<F5N=',\+VYA;64^"B`@("`\='EP93YT97AT/"]T
M>7!E/@H@("`@/&QE;F=T:#XR-34\+VQE;F=T:#X*("`@(#QN;W1N=6QL/G1R
M=64\+VYO=&YU;&P^"B`@(#PO9FEE;&0^"@H@("`\9FEE;&0^"B`@("`\;F%M
M93YD871A=')E95]O<F1E<CPO;F%M93X*("`@(#QT>7!E/FEN=&5G97(\+W1Y
M<&4^"B`@(#PO9FEE;&0^"@H@("`\9FEE;&0^"B`@("`\;F%M93YD871A=')E
M95]D871A/"]N86UE/@H@("`@/'1Y<&4^8VQO8CPO='EP93X*("`@/"]F:65L
M9#X*"B`@(#QF:65L9#X*("`@(#QN86UE/F1A=&%T<F5E7W-E<FEA;&EZ960\
M+VYA;64^"B`@("`\='EP93YI;G1E9V5R/"]T>7!E/@H@("`@/&QE;F=T:#XR
M/"]L96YG=&@^"B`@("`\;F]T;G5L;#YT<G5E/"]N;W1N=6QL/@H@("`\+V9I
M96QD/@H*("`@/&EN9&5X/@H@("`@/&YA;64^9&%T871R965?9&%T871R965?
M;F%M93PO;F%M93X*("`@(#QF:65L9#X*("`@("`\;F%M93YD871A=')E95]N
M86UE/"]N86UE/@H@("`@/"]F:65L9#X*("`@/"]I;F1E>#X*"B`@(#QI;F1E
M>#X*("`@(#QN86UE/F1A=&%T<F5E7V=R;W5P/"]N86UE/@H@("`@/&9I96QD
M/@H@("`@(#QN86UE/F=R;W5P7W5I9#PO;F%M93X*("`@(#PO9FEE;&0^"B`@
M(#PO:6YD97@^"@H@("`\:6YD97@^"B`@("`\;F%M93YD871A=')E95]U<V5R
M/"]N86UE/@H@("`@/&9I96QD/@H@("`@(#QN86UE/G5S97)?=6ED/"]N86UE
M/@H@("`@/"]F:65L9#X*("`@/"]I;F1E>#X*"B`@(#QI;F1E>#X*("`@(#QN
M86UE/F1A=&%T<F5E7W-E<FEA;&EZ960\+VYA;64^"B`@("`\9FEE;&0^"B`@
M("`@/&YA;64^9&%T871R965?<V5R:6%L:7IE9#PO;F%M93X*("`@(#PO9FEE
M;&0^"B`@(#PO:6YD97@^"@H@("`\:6YD97@^"B`@("`\;F%M93YP<FEM87)Y
M/"]N86UE/@H@("`@/'!R:6UA<GD^=')U93PO<')I;6%R>3X*("`@(#QF:65L
M9#X*("`@("`\;F%M93YD871A=')E95]I9#PO;F%M93X*("`@(#PO9FEE;&0^
M"B`@(#PO:6YD97@^"@H@(#PO9&5C;&%R871I;VX^"@H@/"]T86)L93X*"B`\
M=&%B;&4^"@H@(#QN86UE/FAO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,\+VYA
M;64^"@H@(#QD96-L87)A=&EO;CX*"B`@(#QF:65L9#X*("`@(#QN86UE/F1A
M=&%T<F5E7VED/"]N86UE/@H@("`@/'1Y<&4^:6YT96=E<CPO='EP93X*("`@
M(#QN;W1N=6QL/G1R=64\+VYO=&YU;&P^"B`@(#PO9FEE;&0^"@H@("`\9FEE
M;&0^"B`@("`\;F%M93YA='1R:6)U=&5?;F%M93PO;F%M93X*("`@(#QT>7!E
M/G1E>'0\+W1Y<&4^"B`@("`\;&5N9W1H/C(U-3PO;&5N9W1H/@H@("`@/&YO
M=&YU;&P^=')U93PO;F]T;G5L;#X*("`@/"]F:65L9#X*"B`@(#QF:65L9#X*
M("`@(#QN86UE/F%T=')I8G5T95]K97D\+VYA;64^"B`@("`\='EP93YT97AT
M/"]T>7!E/@H@("`@/&QE;F=T:#XR-34\+VQE;F=T:#X*("`@(#QN;W1N=6QL
M/G1R=64\+VYO=&YU;&P^"B`@(#PO9FEE;&0^"@H@("`\9FEE;&0^"B`@("`\
M;F%M93YA='1R:6)U=&5?=F%L=64\+VYA;64^"B`@("`\='EP93YC;&]B/"]T
M>7!E/@H@("`\+V9I96QD/@H*("`@/&EN9&5X/@H@("`@/&YA;64^9&%T871R
M965?871T<FEB=71E/"]N86UE/@H@("`@/&9I96QD/@H@("`@(#QN86UE/F1A
M=&%T<F5E7VED/"]N86UE/@H@("`@/"]F:65L9#X*("`@/"]I;F1E>#X*"B`@
M(#QI;F1E>#X*("`@(#QN86UE/F1A=&%T<F5E7V%T=')I8G5T95]N86UE/"]N
M86UE/@H@("`@/&9I96QD/@H@("`@(#QN86UE/F%T=')I8G5T95]N86UE/"]N
M86UE/@H@("`@/"]F:65L9#X*("`@/"]I;F1E>#X*"B`@(#QI;F1E>#X*("`@
M(#QN86UE/F1A=&%T<F5E7V%T=')I8G5T95]K97D\+VYA;64^"B`@("`\9FEE
M;&0^"B`@("`@/&YA;64^871T<FEB=71E7VME>3PO;F%M93X*("`@(#PO9FEE
M;&0^"B`@(#PO:6YD97@^"@H@(#PO9&5C;&%R871I;VX^"@H@/"]T86)L93X*
M"B`\=&%B;&4^"@H@(#QN86UE/FAO<F1E7VAI<W1O<FEE<SPO;F%M93X*"B`@
M/&1E8VQA<F%T:6]N/@H*("`@/&9I96QD/@H@("`@/&YA;64^:&ES=&]R>5]I
M9#PO;F%M93X*("`@(#QT>7!E/FEN=&5G97(\+W1Y<&4^"B`@("`\;F]T;G5L
M;#YT<G5E/"]N;W1N=6QL/@H@("`\+V9I96QD/@H*("`@/&9I96QD/@H@("`@
M/&YA;64^;V)J96-T7W5I9#PO;F%M93X*("`@(#QT>7!E/G1E>'0\+W1Y<&4^
M"B`@("`\;&5N9W1H/C(U-3PO;&5N9W1H/@H@("`@/&YO=&YU;&P^=')U93PO
M;F]T;G5L;#X*("`@/"]F:65L9#X*"B`@(#QF:65L9#X*("`@(#QN86UE/FAI
M<W1O<GE?86-T:6]N/"]N86UE/@H@("`@/'1Y<&4^=&5X=#PO='EP93X*("`@
M(#QL96YG=&@^,S(\+VQE;F=T:#X*("`@(#QN;W1N=6QL/G1R=64\+VYO=&YU
M;&P^"B`@(#PO9FEE;&0^"@H@("`\9FEE;&0^"B`@("`\;F%M93YH:7-T;W)Y
M7W1S/"]N86UE/@H@("`@/'1Y<&4^:6YT96=E<CPO='EP93X*("`@(#QN;W1N
M=6QL/G1R=64\+VYO=&YU;&P^"B`@(#PO9FEE;&0^"@H@("`\9FEE;&0^"B`@
M("`\;F%M93YH:7-T;W)Y7V1E<V,\+VYA;64^"B`@("`\='EP93YC;&]B/"]T
M>7!E/@H@("`\+V9I96QD/@H*("`@/&9I96QD/@H@("`@/&YA;64^:&ES=&]R
M>5]W:&\\+VYA;64^"B`@("`\='EP93YT97AT/"]T>7!E/@H@("`@/&QE;F=T
M:#XR-34\+VQE;F=T:#X*("`@/"]F:65L9#X*"B`@(#QF:65L9#X*("`@(#QN
M86UE/FAI<W1O<GE?97AT<F$\+VYA;64^"B`@("`\='EP93YC;&]B/"]T>7!E
M/@H@("`\+V9I96QD/@H*("`@/&EN9&5X/@H@("`@/&YA;64^:&ES=&]R>5]A
M8W1I;VX\+VYA;64^"B`@("`\9FEE;&0^"B`@("`@/&YA;64^:&ES=&]R>5]A
M8W1I;VX\+VYA;64^"B`@("`\+V9I96QD/@H@("`\+VEN9&5X/@H*("`@/&EN
M9&5X/@H@("`@/&YA;64^:&ES=&]R>5]T<SPO;F%M93X*("`@(#QF:65L9#X*
M("`@("`\;F%M93YH:7-T;W)Y7W1S/"]N86UE/@H@("`@/"]F:65L9#X*("`@
M/"]I;F1E>#X*"B`@(#QI;F1E>#X*("`@(#QN86UE/FAI<W1O<GE?=6ED/"]N
M86UE/@H@("`@/&9I96QD/@H@("`@(#QN86UE/F]B:F5C=%]U:60\+VYA;64^
M"B`@("`\+V9I96QD/@H@("`\+VEN9&5X/@H*("`@/&EN9&5X/@H@("`@/&YA
M;64^<')I;6%R>3PO;F%M93X*("`@(#QP<FEM87)Y/G1R=64\+W!R:6UA<GD^
M"B`@("`\9FEE;&0^"B`@("`@/&YA;64^:&ES=&]R>5]I9#PO;F%M93X*("`@
M(#PO9FEE;&0^"B`@(#PO:6YD97@^"@H@(#PO9&5C;&%R871I;VX^"@H@/"]T
M86)L93X*"B`\=&%B;&4^"@H@(#QN86UE/FAO<F1E7W!R969S/"]N86UE/@H*
M("`\9&5C;&%R871I;VX^"@H@("`\9FEE;&0^"B`@("`\;F%M93YP<F5F7W5I
M9#PO;F%M93X*("`@(#QT>7!E/G1E>'0\+W1Y<&4^"B`@("`\;&5N9W1H/C(P
M,#PO;&5N9W1H/@H@("`@/&YO=&YU;&P^=')U93PO;F]T;G5L;#X*("`@/"]F
M:65L9#X*"B`@(#QF:65L9#X*("`@(#QN86UE/G!R969?<V-O<&4\+VYA;64^
M"B`@("`\='EP93YT97AT/"]T>7!E/@H@("`@/&QE;F=T:#XQ-CPO;&5N9W1H
M/@H@("`@/&YO=&YU;&P^=')U93PO;F]T;G5L;#X*("`@/"]F:65L9#X*"B`@
M(#QF:65L9#X*("`@(#QN86UE/G!R969?;F%M93PO;F%M93X*("`@(#QT>7!E
M/G1E>'0\+W1Y<&4^"B`@("`\;&5N9W1H/C,R/"]L96YG=&@^"B`@("`\;F]T
M;G5L;#YT<G5E/"]N;W1N=6QL/@H@("`\+V9I96QD/@H*("`@/&9I96QD/@H@
M("`@/&YA;64^<')E9E]V86QU93PO;F%M93X*("`@(#QT>7!E/F-L;V(\+W1Y
M<&4^"B`@(#PO9FEE;&0^"@H@("`\:6YD97@^"B`@("`\;F%M93YP<FEM87)Y
M/"]N86UE/@H@("`@/'!R:6UA<GD^=')U93PO<')I;6%R>3X*("`@(#QF:65L
M9#X*("`@("`\;F%M93YP<F5F7W5I9#PO;F%M93X*("`@(#PO9FEE;&0^"B`@
M("`\9FEE;&0^"B`@("`@/&YA;64^<')E9E]S8V]P93PO;F%M93X*("`@(#PO
M9FEE;&0^"B`@("`\9FEE;&0^"B`@("`@/&YA;64^<')E9E]N86UE/"]N86UE
M/@H@("`@/"]F:65L9#X*("`@/"]I;F1E>#X*"B`@(#QI;F1E>#X*("`@(#QN
M86UE/G!R969?=6ED/"]N86UE/@H@("`@/&9I96QD/@H@("`@(#QN86UE/G!R
M969?=6ED/"]N86UE/@H@("`@/"]F:65L9#X*("`@/"]I;F1E>#X*"B`@(#QI
M;F1E>#X*("`@(#QN86UE/G!R969?<V-O<&4\+VYA;64^"B`@("`\9FEE;&0^
M"B`@("`@/&YA;64^<')E9E]S8V]P93PO;F%M93X*("`@(#PO9FEE;&0^"B`@
M(#PO:6YD97@^"@H@(#PO9&5C;&%R871I;VX^"@H@/"]T86)L93X*"B`\=&%B
M;&4^"@H@(#QN86UE/FAO<F1E7W-E<W-I;VYH86YD;&5R/"]N86UE/@H*("`\
M9&5C;&%R871I;VX^"@H@("`\9FEE;&0^"B`@("`\;F%M93YS97-S:6]N7VED
M/"]N86UE/@H@("`@/'1Y<&4^=&5X=#PO='EP93X*("`@(#QL96YG=&@^,S(\
M+VQE;F=T:#X*("`@(#QN;W1N=6QL/G1R=64\+VYO=&YU;&P^"B`@(#PO9FEE
M;&0^"@H@("`\9FEE;&0^"B`@("`\;F%M93YS97-S:6]N7VQA<W1M;V1I9FEE
M9#PO;F%M93X*("`@(#QT>7!E/FEN=&5G97(\+W1Y<&4^"B`@("`\;F]T;G5L
M;#YT<G5E/"]N;W1N=6QL/@H@("`\+V9I96QD/@H*("`@/&9I96QD/@H@("`@
M/&YA;64^<V5S<VEO;E]D871A/"]N86UE/@H@("`@/'1Y<&4^8FQO8CPO='EP
M93X*("`@/"]F:65L9#X*"B`@(#QI;F1E>#X*("`@(#QN86UE/G!R:6UA<GD\
M+VYA;64^"B`@("`\<')I;6%R>3YT<G5E/"]P<FEM87)Y/@H@("`@/&9I96QD
M/@H@("`@(#QN86UE/G-E<W-I;VY?:60\+VYA;64^"B`@("`\+V9I96QD/@H@
M("`\+VEN9&5X/@H*("`\+V1E8VQA<F%T:6]N/@H*(#PO=&%B;&4^"@H@/'1A
M8FQE/@H*("`\;F%M93YH;W)D95]T;VME;G,\+VYA;64^"@H@(#QD96-L87)A
M=&EO;CX*"B`@(#QF:65L9#X*("`@(#QN86UE/G1O:V5N7V%D9')E<W,\+VYA
M;64^"B`@("`\='EP93YT97AT/"]T>7!E/@H@("`@/&QE;F=T:#XQ,#`\+VQE
M;F=T:#X*("`@(#QN;W1N=6QL/G1R=64\+VYO=&YU;&P^"B`@(#PO9FEE;&0^
M"@H@("`\9FEE;&0^"B`@("`\;F%M93YT;VME;E]I9#PO;F%M93X*("`@(#QT
M>7!E/G1E>'0\+W1Y<&4^"B`@("`\;&5N9W1H/C,R/"]L96YG=&@^"B`@("`\
M;F]T;G5L;#YT<G5E/"]N;W1N=6QL/@H@("`\+V9I96QD/@H*("`@/&9I96QD
M/@H@("`@/&YA;64^=&]K96Y?=&EM97-T86UP/"]N86UE/@H@("`@/'1Y<&4^
M:6YT96=E<CPO='EP93X*("`@(#QN;W1N=6QL/G1R=64\+VYO=&YU;&P^"B`@
M(#PO9FEE;&0^"@H@("`\:6YD97@^"B`@("`\;F%M93YP<FEM87)Y/"]N86UE
M/@H@("`@/'!R:6UA<GD^=')U93PO<')I;6%R>3X*("`@(#QF:65L9#X*("`@
M("`\;F%M93YT;VME;E]A9&1R97-S/"]N86UE/@H@("`@/"]F:65L9#X*("`@
M(#QF:65L9#X*("`@("`\;F%M93YT;VME;E]I9#PO;F%M93X*("`@(#PO9FEE
M;&0^"B`@(#PO:6YD97@^"@H@(#PO9&5C;&%R871I;VX^"@H@/"]T86)L93X*
M"B`\=&%B;&4^"@H@(#QN86UE/FAO<F1E7W5S97)S/"]N86UE/@H*("`\9&5C
M;&%R871I;VX^"@H@("`\9FEE;&0^"B`@("`\;F%M93YU<V5R7W5I9#PO;F%M
M93X*("`@(#QT>7!E/G1E>'0\+W1Y<&4^"B`@("`\;&5N9W1H/C(U-3PO;&5N
M9W1H/@H@("`@/&YO=&YU;&P^=')U93PO;F]T;G5L;#X*("`@/"]F:65L9#X*
M"B`@(#QF:65L9#X*("`@(#QN86UE/G5S97)?<&%S<SPO;F%M93X*("`@(#QT
M>7!E/G1E>'0\+W1Y<&4^"B`@("`\;&5N9W1H/C(U-3PO;&5N9W1H/@H@("`@
M/&YO=&YU;&P^=')U93PO;F]T;G5L;#X*("`@/"]F:65L9#X*"B`@(#QF:65L
M9#X*("`@(#QN86UE/G5S97)?<V]F=%]E>'!I<F%T:6]N7V1A=&4\+VYA;64^
M"B`@("`\='EP93YI;G1E9V5R/"]T>7!E/@H@("`\+V9I96QD/@H*("`@/&9I
M96QD/@H@("`@/&YA;64^=7-E<E]H87)D7V5X<&ER871I;VY?9&%T93PO;F%M
M93X*("`@(#QT>7!E/FEN=&5G97(\+W1Y<&4^"B`@(#PO9FEE;&0^"@H@("`\
M:6YD97@^"B`@("`\;F%M93YP<FEM87)Y/"]N86UE/@H@("`@/'!R:6UA<GD^
M=')U93PO<')I;6%R>3X*("`@(#QF:65L9#X*("`@("`\;F%M93YU<V5R7W5I
M9#PO;F%M93X*("`@(#PO9FEE;&0^"B`@(#PO:6YD97@^"@H@(#PO9&5C;&%R
M871I;VX^"@H@/"]T86)L93X*"B`\=&%B;&4^"@H@(#QN86UE/FAO<F1E7W9F
M<SPO;F%M93X*"B`@/&1E8VQA<F%T:6]N/@H*("`@/&9I96QD/@H@("`@/&YA
M;64^=F9S7VED/"]N86UE/@H@("`@/'1Y<&4^:6YT96=E<CPO='EP93X*("`@
M(#QN;W1N=6QL/G1R=64\+VYO=&YU;&P^"B`@(#PO9FEE;&0^"@H@("`\9FEE
M;&0^"B`@("`\;F%M93YV9G-?='EP93PO;F%M93X*("`@(#QT>7!E/FEN=&5G
M97(\+W1Y<&4^"B`@("`\;&5N9W1H/C$\+VQE;F=T:#X*("`@(#QN;W1N=6QL
M/G1R=64\+VYO=&YU;&P^"B`@(#PO9FEE;&0^"@H@("`\9FEE;&0^"B`@("`\
M;F%M93YV9G-?<&%T:#PO;F%M93X*("`@(#QT>7!E/G1E>'0\+W1Y<&4^"B`@
M("`\;&5N9W1H/C(U-3PO;&5N9W1H/@H@("`@/&YO=&YU;&P^=')U93PO;F]T
M;G5L;#X*("`@/"]F:65L9#X*"B`@(#QF:65L9#X*("`@(#QN86UE/G9F<U]N
M86UE/"]N86UE/@H@("`@/'1Y<&4^=&5X=#PO='EP93X*("`@(#QL96YG=&@^
M,C4U/"]L96YG=&@^"B`@("`\;F]T;G5L;#YT<G5E/"]N;W1N=6QL/@H@("`\
M+V9I96QD/@H*("`@/&9I96QD/@H@("`@/&YA;64^=F9S7VUO9&EF:65D/"]N
M86UE/@H@("`@/'1Y<&4^:6YT96=E<CPO='EP93X*("`@(#QN;W1N=6QL/G1R
M=64\+VYO=&YU;&P^"B`@(#PO9FEE;&0^"@H@("`\9FEE;&0^"B`@("`\;F%M
M93YV9G-?;W=N97(\+VYA;64^"B`@("`\='EP93YT97AT/"]T>7!E/@H@("`@
M/&QE;F=T:#XR-34\+VQE;F=T:#X*("`@(#QN;W1N=6QL/G1R=64\+VYO=&YU
M;&P^"B`@(#PO9FEE;&0^"@H@("`\9FEE;&0^"B`@("`\;F%M93YV9G-?9&%T
M83PO;F%M93X*("`@(#QT>7!E/F)L;V(\+W1Y<&4^"B`@(#PO9FEE;&0^"@H@
M("`\:6YD97@^"B`@("`\;F%M93YP<FEM87)Y/"]N86UE/@H@("`@/'!R:6UA
M<GD^=')U93PO<')I;6%R>3X*("`@(#QF:65L9#X*("`@("`\;F%M93YV9G-?
M:60\+VYA;64^"B`@("`\+V9I96QD/@H@("`\+VEN9&5X/@H*("`@/&EN9&5X
M/@H@("`@/&YA;64^=F9S7W!A=&@\+VYA;64^"B`@("`\9FEE;&0^"B`@("`@
M/&YA;64^=F9S7W!A=&@\+VYA;64^"B`@("`\+V9I96QD/@H@("`\+VEN9&5X
M/@H*("`@/&EN9&5X/@H@("`@/&YA;64^=F9S7VYA;64\+VYA;64^"B`@("`\
M9FEE;&0^"B`@("`@/&YA;64^=F9S7VYA;64\+VYA;64^"B`@("`\+V9I96QD
M/@H@("`\+VEN9&5X/@H*("`\+V1E8VQA<F%T:6]N/@H*(#PO=&%B;&4^"@H\
M+V1A=&%B87-E/@H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP
M=',O<W%L+VAO<F1E7W-E<W-I;VYH86YD;&5R+G!G<W%L+G-Q;```````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,#4U,2`Q,#4Q-30S,S<T,R`P,C8P-S<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+2T@)$AO<F1E.B!H
M;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]S97-S:6]N:&%N9&QE<BYP9W-Q;"YS
M<6PL=B`Q+C$@,C`P-"\P.2\Q."`Q-SHR,#HU.2!C:'5C:R!%>'`@)`H*0U)%
M051%(%1!0DQ%(&AO<F1E7W-E<W-I;VYH86YD;&5R("@*("`@('-E<W-I;VY?
M:60@("`@("`@("`@("`@5D%20TA!4B@S,BD@3D]4($Y53$PL"B`@("!S97-S
M:6]N7VQA<W1M;V1I9FEE9"`@($E.5"!.3U0@3E5,3"P*("`@('-E<W-I;VY?
M9&%T82`@("`@("`@("`@5$585"P*("`@(%!224U!4ED@2T59("AS97-S:6]N
M7VED*0HI.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%
M($].(&AO<F1E7W-E<W-I;VYH86YD;&5R(%1/(&AO<F1E.P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D
M95]D871A=')E92YS<6P`````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#,P,S0@,3`U,34T,S,W-#,@,#(S-3(Q`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"TM("1(;W)D93H@:&]R9&4O<V-R:7!T
M<R]S<6PO:&]R9&5?9&%T871R964N<W%L+'8@,2XQ+C$P+C$@,C`P-B\P-2\R
M,B`R,3HR-SHS,R!J86X@17AP("0*"D-214%412!404),12!H;W)D95]D871A
M=')E92`H"B`@("!D871A=')E95]I9"!)3E0@3D]4($Y53$PL"B`@("!G<F]U
M<%]U:60@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=7-E<E]U:60@5D%2
M0TA!4B@R-34I($Y/5"!.54Q,+`H@("`@9&%T871R965?;F%M92!605)#2$%2
M*#(U-2D@3D]4($Y53$PL"B`@("!D871A=')E95]P87)E;G1S(%9!4D-(05(H
M,C4U*2!.3U0@3E5,3"P*("`@(&1A=&%T<F5E7V]R9&5R($E.5"P*"BTM(%1H
M97)E(&ES(&YO('!O<G1A8FQE('=A>2!T;R!D;R!T:&ES(&%P<&%R96YT;'DN
M($EF('EO=7(@9&(@9&]E<VXG=`HM+2!A;&QO=R!415A4(&-O;'5M;G,L('1H
M96X@;6%Y8F4@:70@86QL;W=S(&QA<F=E(%9!4D-(05(@8V]L=6UN<RP@<V\*
M+2T@=')Y('1H92!S96-O;F0@;&EN92X*+2T*("`@(&1A=&%T<F5E7V1A=&$@
M5$585"P*+2T@(&1A=&%T<F5E7V1A=&$@5D%20TA!4B@T,#DV*2P*"B`@("!D
M871A=')E95]S97)I86QI>F5D(%--04Q,24Y4($1%1D%53%0@,"!.3U0@3E5,
M3"P*"B`@("!04DE-05)9($M%62`H9&%T871R965?:60I"BD["@I#4D5!5$4@
M24Y$15@@9&%T871R965?9&%T871R965?;F%M95]I9'@@3TX@:&]R9&5?9&%T
M871R964@*&1A=&%T<F5E7VYA;64I.PI#4D5!5$4@24Y$15@@9&%T871R965?
M9W)O=7!?:61X($].(&AO<F1E7V1A=&%T<F5E("AG<F]U<%]U:60I.PI#4D5!
M5$4@24Y$15@@9&%T871R965?=7-E<E]I9'@@3TX@:&]R9&5?9&%T871R964@
M*'5S97)?=6ED*3L*0U)%051%($E.1$58(&1A=&%T<F5E7V]R9&5R7VED>"!/
M3B!H;W)D95]D871A=')E92`H9&%T871R965?;W)D97(I.PI#4D5!5$4@24Y$
M15@@9&%T871R965?<V5R:6%L:7IE9%]I9'@@3TX@:&]R9&5?9&%T871R964@
M*&1A=&%T<F5E7W-E<FEA;&EZ960I.PH*"D-214%412!404),12!H;W)D95]D
M871A=')E95]A='1R:6)U=&5S("@*("`@(&1A=&%T<F5E7VED($E.5"!.3U0@
M3E5,3"P*("`@(&%T=')I8G5T95]N86UE(%9!4D-(05(H,C4U*2!.3U0@3E5,
M3"P*("`@(&%T=')I8G5T95]K97D@5D%20TA!4B@R-34I+`H@("`@871T<FEB
M=71E7W9A;'5E(%1%6%0**3L*"D-214%412!)3D1%6"!D871A=')E95]A='1R
M:6)U=&5?:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*&1A=&%T
M<F5E7VED*3L*0U)%051%($E.1$58(&1A=&%T<F5E7V%T=')I8G5T95]N86UE
M7VED>"!/3B!H;W)D95]D871A=')E95]A='1R:6)U=&5S("AA='1R:6)U=&5?
M;F%M92D["D-214%412!)3D1%6"!D871A=')E95]A='1R:6)U=&5?:V5Y7VED
M>"!/3B!H;W)D95]D871A=')E95]A='1R:6)U=&5S("AA='1R:6)U=&5?:V5Y
M*3L*"@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@
M:&]R9&5?9&%T871R964@5$\@:&]R9&4["D=204Y4(%-%3$5#5"P@24Y315)4
M+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]D871A=')E95]A='1R:6)U=&5S
M(%1/(&AO<F1E.PH`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?<V5S
M<VEO;FAA;F1L97(N;7ES<6PN<W%L````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P-C$S
M(#$P-3$U-#,S-S0S(#`R-C$Q-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O<W%L
M+VAO<F1E7W-E<W-I;VYH86YD;&5R+FUY<W%L+G-Q;"QV(#$N,2XR+C$@,C`P
M-B\P,R\R,B`Q.#HS,#HR,R!J86X@17AP("0*"D-214%412!404),12!H;W)D
M95]S97-S:6]N:&%N9&QE<B`H"B`@("!S97-S:6]N7VED("`@("`@("`@("`@
M(%9!4D-(05(H,S(I($Y/5"!.54Q,+`H@("`@<V5S<VEO;E]L87-T;6]D:69I
M960@("!)3E0@3D]4($Y53$PL"B`@("!S97-S:6]N7V1A=&$@("`@("`@("`@
M($Q/3D="3$]"+`H*("`@(%!224U!4ED@2T59("AS97-S:6]N7VED*0HI($5.
M1TE.12`]($EN;F]$0CL*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L
M($1%3$5412!/3B!H;W)D95]S97-S:6]N:&%N9&QE<B!43R!H;W)D94!L;V-A
M;&AO<W0["@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7V1A=&%T<F5E+FUS<W%L
M+G-Q;``````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C4T-R`Q,#4Q-30S,S<T
M,R`P,C0V-C<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+2T@)$AO<F1E.B!H;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]D871A
M=')E92YM<W-Q;"YS<6PL=B`Q+C$N,BXR(#(P,#8O,#4O,C(@,C$Z,C<Z,S,@
M:F%N($5X<"`D"@I#4D5!5$4@5$%"3$4@:&]R9&5?9&%T871R964@*`H@("`@
M9&%T871R965?:60@24Y4($Y/5"!.54Q,+`H@("`@9W)O=7!?=6ED(%9!4D-(
M05(H,C4U*2!.3U0@3E5,3"P*("`@('5S97)?=6ED(%9!4D-(05(H,C4U*2!.
M3U0@3E5,3"P*("`@(&1A=&%T<F5E7VYA;64@5D%20TA!4B@R-34I($Y/5"!.
M54Q,+`H@("`@9&%T871R965?<&%R96YT<R!605)#2$%2*#(U-2D@3D]4($Y5
M3$PL"B`@("!D871A=')E95]O<F1E<B!)3E0L"B`@("!D871A=')E95]D871A
M(%9!4D-(05(H34%8*2P*("`@(&1A=&%T<F5E7W-E<FEA;&EZ960@4TU!3$Q)
M3E0@1$5&055,5"`P($Y/5"!.54Q,+`H*("`@(%!224U!4ED@2T59("AD871A
M=')E95]I9"D**3L*"D-214%412!)3D1%6"!D871A=')E95]D871A=')E95]N
M86UE7VED>"!/3B!H;W)D95]D871A=')E92`H9&%T871R965?;F%M92D["D-2
M14%412!)3D1%6"!D871A=')E95]G<F]U<%]I9'@@3TX@:&]R9&5?9&%T871R
M964@*&=R;W5P7W5I9"D["D-214%412!)3D1%6"!D871A=')E95]U<V5R7VED
M>"!/3B!H;W)D95]D871A=')E92`H=7-E<E]U:60I.PI#4D5!5$4@24Y$15@@
M9&%T871R965?;W)D97)?:61X($].(&AO<F1E7V1A=&%T<F5E("AD871A=')E
M95]O<F1E<BD["D-214%412!)3D1%6"!D871A=')E95]S97)I86QI>F5D7VED
M>"!/3B!H;W)D95]D871A=')E92`H9&%T871R965?<V5R:6%L:7IE9"D["@H*
M0U)%051%(%1!0DQ%(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*`H@("`@
M9&%T871R965?:60@24Y4($Y/5"!.54Q,+`H@("`@871T<FEB=71E7VYA;64@
M5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@871T<FEB=71E7VME>2!605)#
M2$%2*#(U-2DL"B`@("!A='1R:6)U=&5?=F%L=64@5D%20TA!4BA-05@I"BD[
M"@I#4D5!5$4@24Y$15@@9&%T871R965?871T<FEB=71E7VED>"!/3B!H;W)D
M95]D871A=')E95]A='1R:6)U=&5S("AD871A=')E95]I9"D["D-214%412!)
M3D1%6"!D871A=')E95]A='1R:6)U=&5?;F%M95]I9'@@3TX@:&]R9&5?9&%T
M871R965?871T<FEB=71E<R`H871T<FEB=71E7VYA;64I.PI#4D5!5$4@24Y$
M15@@9&%T871R965?871T<FEB=71E7VME>5]I9'@@3TX@:&]R9&5?9&%T871R
M965?871T<FEB=71E<R`H871T<FEB=71E7VME>2D["@H*1U)!3E0@4T5,14-4
M+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7V1A=&%T<F5E(%1/
M(&AO<F1E.PI'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@
M3TX@:&]R9&5?9&%T871R965?871T<FEB=71E<R!43R!H;W)D93L*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]S
M<6PO:&]R9&5?;75V9G,N<W%L````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`Q,3(U(#$P-3$U-#,S-S0S(#`R,S`V-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````M+2`D2&]R9&4Z(&AO<F1E
M+W-C<FEP=',O<W%L+VAO<F1E7VUU=F9S+G-Q;"QV(#$N,2`R,#`T+S`Y+S$X
M(#$W.C(P.C4Y(&-H=6-K($5X<"`D"@I#4D5!5$4@5$%"3$4@:&]R9&5?;75V
M9G,@*`H@("`@=F9S7VED("`@("`@("!"24=)3E0@3D]4($Y53$PL"B`@("!V
M9G-?='EP92`@("`@(%--04Q,24Y4($Y/5"!.54Q,+`H@("`@=F9S7W!A=&@@
M("`@("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?;F%M92`@("`@
M(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]M;V1I9FEE9"`@0DE'
M24Y4($Y/5"!.54Q,+`H@("`@=F9S7V]W;F5R("`@("!605)#2$%2*#(U-2D@
M3D]4($Y53$PL"B`@("!V9G-?<&5R;7,@("`@(%--04Q,24Y4($Y/5"!.54Q,
M+`H@("`@=F9S7V1A=&$@("`@("!,3TY'0DQ/0BP*+2T@3W(L(&]N('-O;64@
M1$)-4R!S>7-T96US.@HM+2`@=F9S7V1A=&$@("`@("!)34%'12P*("`@(%!2
M24U!4ED@2T59("`@*'9F<U]I9"D**3L*"D-214%412!)3D1%6"!V9G-?<&%T
M:%]I9'@@3TX@:&]R9&5?;75V9G,@*'9F<U]P871H*3L*0U)%051%($E.1$58
M('9F<U]N86UE7VED>"!/3B!H;W)D95]M=79F<R`H=F9S7VYA;64I.PH`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R
M:7!T<R]S<6PO:&]R9&5?=F9S+G!G<W%L+G-Q;```````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`Q,#8R(#$P-3$U-#,S-S0S(#`R,S8U,@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````M+2`D2&]R9&4Z
M(&AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7W9F<RYP9W-Q;"YS<6PL=B`Q+C$@
M,C`P-"\P.2\Q."`Q-SHR,#HU.2!C:'5C:R!%>'`@)`H*0U)%051%(%1!0DQ%
M(&AO<F1E7W9F<R`H"B`@("!V9G-?:60@("`@("`@($))1TE.5"!.3U0@3E5,
M3"P*("`@('9F<U]T>7!E("`@("`@4TU!3$Q)3E0@3D]4($Y53$PL"B`@("!V
M9G-?<&%T:"`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]N
M86UE("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=F9S7VUO9&EF
M:65D("!"24=)3E0@3D]4($Y53$PL"B`@("!V9G-?;W=N97(@("`@(%9!4D-(
M05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]D871A("`@("`@5$585"P*"B`@
M("!04DE-05)9($M%62`@("AV9G-?:60I"BD["@I#4D5!5$4@24Y$15@@=F9S
M7W!A=&A?:61X($].(&AO<F1E7W9F<R`H=F9S7W!A=&@I.PI#4D5!5$4@24Y$
M15@@=F9S7VYA;65?:61X($].(&AO<F1E7W9F<R`H=F9S7VYA;64I.PH*1U)!
M3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7W9F
M<R!43R!H;W)D93L*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<V-R:7!T<R]S<6PO:&]R9&5?;&]G+G-Q;```````````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`P-C(W(#$P-3$U-#,S-S0S(#`R,C4Q-@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````M+2`D
M2&]R9&4Z(&AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7VQO9RYS<6PL=B`Q+C$@
M,C`P-"\P.2\Q."`Q-SHR,#HU.2!C:'5C:R!%>'`@)`H*0U)%051%(%1!0DQ%
M(&AO<F1E7VQO9R`H"B`@("!I9"`@("`@("`@("!)3E0@3D]4($Y53$PL"B`@
M("!L;V=T:6UE("`@("!424U%4U1!35`@3D]4($Y53$PL"B`@("!I9&5N="`@
M("`@("!#2$%2*#$V*2!.3U0@3E5,3"P*("`@('!R:6]R:71Y("`@($E.5"!.
M3U0@3E5,3"P*("`@("TM($9O<B!$0G,@=&AA="!D;VXG="!S=7!P;W)T('1H
M92!415A4(&9I96QD('1Y<&4Z"B`@("`M+2!M97-S86=E("!605)#2$%2*#(P
M-#@I+`H@("`@;65S<V%G92`@("`@5$585"P*("`@(%!224U!4ED@2T59("AI
M9"D**3L*"D=204Y4($E.4T525"!/3B!H;W)D95]L;V<@5$\@:&]R9&4["@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O
M<W%L+U)%041-12Y/0TDX````````````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`R,S0S-B`Q,#4Q-30S,S<T,R`P,C$T,3<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````1DE24U0@3T8@04Q,.@I4
M:&ES(&ES(&YO="!M>2!F:7)S="!D;V-U;65N=&%T:6]N(2!B=70@;7D@9FER
M<W0@:6X@96YG;&ES:"X*1F5E;"!F<F5E('1O(&-O;G1A8W0@;64@870@=&]R
M<W1E;D!F;&%M;6EG97(N;W)G(&EF('EO=2!H879E(`IA;GD@<W5G9V5S=&EO
M;G,@;W(@<')O8FQE;7,@<F5L871E9"!T;R!T:&ES(&1O8W,*"D%L;"!I('=I
M;&P@=W)I=&4@86)O=70@3W)A8VQE('=I=&@@2&]R9&4@:7,@8F%S960@;VX@
M3W)A8VQE(#X](#AI"G1H;W5G:"!I="!S:&]U;&0@=V]R:R!W:71H(#EI('1O
M;RX@"@I)('1H:6YK("AI)VT@<W5R92D@)U5P('1O(&1A=&4G(&%V86EL86)L
M92!D:7-T<FEB=71I;VYS"F%R92!C87!A8FQE('1O(')U;B!/<F%C;&4N($D@
M:&%V92!T97-T960@:70@;VX*4VQA8VMW87)E(#<N,2\X+C`@*#@N,2XV*2!A
M;F0@:&%V92!R=6YN:6YG(&ET(&]N($=E;G1O;R`Q+C(@*#@N,2XW+C0I"G=I
M=&AO=70@86YY(%!R;V)L96US+B!3;VUE(&1I<W1R:6)U=&EO;G,@87)E(&-E
M<G1I9FEE9"!L:6ME(%-U4T4@;W(@"E)E9$AA="X@3VX@1&5B:6%N(&ET('-H
M;W5L9"!A;'-O(')U;BX*"D9U<G1H97)M;W)E(&DG;&P@87-S=6UE+"!T:&%T
M(&YO(")N;W)M86PB('5S97(@:7,@9V]I;F<@=&\@:6YS=&%L;`IO<B!I<R!I
M;B!N965D('1O(&EN<W1A;&P@86X@3W)A8VQE($1"("AO9B!C;W5R<V4@=&AE
M<F4@87)E('-O;64@9G)E86MS(#LI"G-O(&MN;W=L961G92!A8F]U="!S971T
M:6YG('5P(&%N9"!M86EN=&%I;B!A;B!/<F%C;&4*1$(@:7,@:6YD:7-P96YS
M86)L92$@36%Y8F4@=&AI<R!I<R!T:&4@<F5A<V]N('=H>2!N;R!!9&UI;@IH
M87,@979E<B!P;W-T960@86YY(&1O8W,@86)O=70@9V5T=&EN9R!(;W)D92!W
M;W)K('=I=&@@3W)A8VQE"@I.3U1%.B!A;&P@9&]C<R!A<F4@879A:6QA8FQE
M(&9R;VT@=W=W+F]R86-L92YC;VT@9F]R(&9R964@*$%&04E+*0H*3F]W(&QE
M="=S(&)E9VEN.@H*0V%S92`Q*2`*22=L;"!A<W-U;64@=&AA="!Y;W4@9&\@
M;F]T(&AA=F4@86X@:6YS=&%N8V4@<G5N;FEN9R!A;F0@=&AE<F5F;W)E"F%R
M92!A8F]U="!T;R!I;G-T86QL(&$@9G)E<V@@:6YS=&%N8V4@(FAO<F1E(B`N
M"@HM+0EC:&5C:R!A;F0@:68@;F5E9&5D(&-H86YG92!S:&%R960@;65M;W)Y
M('!A<F%M971E<G,*+2T)8W)E871E(&%T(&QE87-T('1H92!D8F$@9W)O=7`*
M+2T)8W)E871E('EO=7(@;W)A8VQE('5S97(L(&YA;64@:70@87,@>6]U(&QI
M:V4*"6UA:V4@<W5R92!Y;W5R(&]R82UU<V5R(&ES(&EN('1H92!G<F]U<"!D
M8F$*+2T)<W4@+2`\>6]U<B!F<F5S:"!O<F%C;&4@=7-E<CX*+2T@"7-E="!U
M<"!A;&P@=&AE(&%P<')O<')I871E(&5N=FER;VYM96YT('9A<FEA8FQE<R!F
M;W(@;W)A8VQE"@ET86ME(&$@8VQO<V4@;&]O:R!A="!T:&4@:6YS=&%L;"!H
M;W=T;R!P<F]V:61E9"!B>2!O<F%C;&4*+2T);6]U;G0@=&AE($-$("AI9B!I
M="!I<R!Y;W5R('-O=7)C92!M961I82D*+2T)<G5N('1H92!S8W)I<'0@<G5N
M26YS=&%L;&5R("T@8F5T=&5R('1O(&AA=F4@6#$Q(&EN<W1A;&QE9"`[*0H)
M071T96YT:6]N.B!)9B!Y;W4@87)E(&%B;W5T('1O(&EN<W1A;&P@3W)A8VQE
M(#EI"@ED;R!.3U0@<G5N('1H92!I;G-T86QL97(@9G)O;2!D:7)E8W1L>2!F
M<F]M('EO=7(@0T0A"@EL:6ME(&-D("]C9')O;2!A;F0@=&AE;B!S=&%R="!I
M="!B>2!T>7!I;F<@+B]R=6Y);G-T86QL97(*"7EO=2!W;VXG="!B92!A8FQE
M('1O('5N;6]U;G0@=&AE($-$(&QA=&5R(&]N(&)U="!Y;W4@:&%V92!T;PH)
M8F5C875S92`Y:2!I<R!A(#-#1"U3970*+2T)9F]L;&]W('1H92!I;G-T<G5C
M=&EO;G,@9VEV96X@8GD@=&AE(&EN<W1A;&QA=&EO;B!P<F]G<F%M;0H)870@
M=&AE('!O:6YT('=H97)E('EO=2!A<F4@87-K960@9F]R(&%N(&EN<W1A;&QA
M=&EO;B!M971H;V0*"6-H;V]S92`B=7-E<BUD969I;F5D(BX@5&AI<R!I<W0@
M97-P96-I86QL>2!615)9($E-4$]25$5.5"!I9B!Y;W4*"6%R92!A8F]U="!T
M;R!I;G-T86QL(#AI('-I;F-E('EO=2!H879E('1O('!A=&-H('1H92!I;G-T
M86QL871I;VX*"4)%1D]212!Y;W4@8W)E871E('EO=7(@9&%T86)A<V4A($EF
M('EO=2!N;W0@8VAO;W-E(")U<V5R+61E9FEN960B"@ET:&4@<')O9W)A;2`B
M9&)A<W-I<W0B('=I;&P@875T;VUA=&EC86QL>2!S=&%R="!A="!T:&4@96YD
M(&]F"@ET:&4@:6YS=&%L;&%T:6]N('!R;V-E<W,@86YD('=I;&P@:&%N9R!A
M;F0O;W(@9F%I;"X*+2T)870@=&AE(&5N9"!O9B!Y;W5R(&EN<W1A;&QA=&EO
M;B!Y;W4@:&%V92!T;R!C;VYF:6=U<F4@>6]U<B!L:7-T96YE<BYO<F$L"@ET
M;G-N86UE<RYO<F$@86YD('EO=7(@<W%L;F5T+F]R82!4:&ES(&ES(&%L;"!D
M;VYE(&)Y('1H90H):6YS=&%L;&%T:6]N('!R;V=R86UM+B`*+2T)3F]W.B!I
M9B!Y;W4@=7-E(#@N,2XW(&=E="!T:&4@<&%T8V@@9VQI8F,M,BXQ+C,M<W1U
M8G,N=&%R+F=Z(&9R;VT@3W)A8VQE+B`*"4ET)W,@870@=&AE('-A;64@<&%G
M92!L:6ME('1H92!D8BUS;W5R8V4N($EN<W1A;&P@87,@9&5S8W)I8F5D(&EN
M(%)%041-12YS='5B"@DH:70G<R!I;B!T:&4@<&%C:V%G92!S;R!F:7)S="!U
M;G1A<B!I="!S;VUE=VAE<F4@96QS92!O<B!U<V4@)VUC)R`I"BTM"4YO=R!C
M<F5A=&4@>6]U<B!D871A8F%S92X@4G5N(")D8F%S<VES="(*"4ET)W,@;F]W
M(&]N('EO=2!T;R!D96-I9&4@:&]W(&)I9R!T:&4@:6YI=&EA;"!T86)L97-P
M86-E<R!A<F4L(&AO=R!M86YY"@EC;VYT<F]L(&9I;&5S('EO=2!L:6ME+"!O
M9B!C;W5R<V4@:&]W(&ET)W,@;F%M92!W:6QL(&)E(&%N9"!W:&%T"@EO<'1I
M;VX@>6]U('!L86X@=&\@=7-E(&QI:V4@26YT97)-961I82X@270G<R!9;W5R
M($1E8VES:6]N("$*"2A"5%<Z('1H92!D969A=6QT<R!W:6QL('=O<FL@86YD
M(&%R92!V97)Y('1I;64@8V]N<W5M:6YG(#LI"@E!="!T:&4@96YD(&QE="!T
M:&4@9&)A<VES="!P<F]G<F%M('-A=F4@=&AE(&-O;F9I9W5R871I;VXN(%EO
M=2!C86X@8VAO;W-E"@EL;V-A=&EO;B!A;F0@;F%M92X@3F]W('EO=2!C86X@
M8VQO<V4@9&)A<W-I<W0N"BTM"6-H86YG92!T;R!T:&4@;&]C871I;VX@=VAE
M<F4@>6]U('-T;W)E9"!T:&4@<V-R:7!T<R!A;F0@=&%K92!A('-H;W)T(&QO
M;VL*"6%T(&QE87-T(&EN=&\@;W)A8VQE<G5N+G-H(&%N9"!O<F%C;&5R=6XQ
M+G-H+B!)9B!A;&P@:7,@3TL@8W)E871E('1H92!D871A8F%S93H*"7)U;B`N
M+V]R86-L97)U;BYS:"X@"@E3:70@8F%C:R!T86ME(&$@8W5P(&]F(&-O9F9E
M92!A;F0@:&]P92!A;&P@=VEL;"!B92!G;V]D(#LI"@H)268@>6]U(&-H;V]S
M960@=&AE($EN=&5R365D:6$@;W!T:6]N('1H92!C<F5A=&EO;B!P<F]C97-S
M('=I;&P@=&%K90H)86)O=70@,B!A;F0@82!H86QF(&AO=7(@*&]N(&UY(#4P
M,$U(>BU0,R`Z+2DN(%=I=&AO=70@2F%V82!I="!W:6QL('1A:V4*"6%B;W5T
M(#$@:&]U<BX@*'1H:7,@8F]T:"!I<W0@<VAO<G0@+2`Y:2!T86ME<R!A<R!M
M:6XN('1W:6-E('1H870@=&EM92`A*0H)"@E.3U1%.B!C:&]O<VEN9R!);G1E
M<DUE9&EA('=I;&P@9VEV92!Y;W4@96YH86YC960@<&]S<VEB:6QI=&EE<R!F
M;W(@<W1O<FEN9PH)86YD(&UA;FEP=6QA=&EN9R!M961I82!F:6QE<RX@3&]O
M:R!A="!H='1P.B\O:6YT97)M961I82YA<RUD871A<V5R=FEC92YD92\*"69O
M<B!A;B!E>&%M<&QE+BXN"@D*"4%.3U1(15(@3D]413H@:68@>6]U(&EN<W1A
M;&QE9"`X+C$N-R!A;F0@869T97)W87)D<R!A<'!L:65D(&%N('5P('1O(&1A
M=&4*"7!A=&-H<V5T("AL:6ME(#@N,2XW+C0I('EO=2!-55-4(')E<&%T8V@@
M>6]U<B!I;G-T86QL871I;VX@=VET:"!T:&4@"@EG;&EB8RUS='5B<R!P871C
M:"!O<B!Y;W5R($1"('=O;B=T(')U;@H)"@E04D]"3$5-4R`_.B!,;V]K(&%T
M('=W=RYO<F%F87$N8V]M(&9O<B!Y;W5R(&%N<W=E<@H*06QL('=E;G0@9FEN
M93\@1V]O9"P@;&5T<R!G;R!A:&5A9"!A;F0@8W)E871E(&$@;F5W('1A8FQE
M<W!A8V4@8V%L;&5D(&AO<F1E"@HM+0E4:&4@9&%T86)A<V4@<VAO=6QD(')U
M;B!A9G1E<B!I="!W87,@<W5C8V5S9G5L;'D@8W)E871E9"X@3&]G:6X@87,@
M=7-E<B!S>7-T96T*"6]R('-Y<R`H;&EK92!Y;W4@<')E9F5R*2X@5&AE('!A
M<W-W;W)D<R!W:&5R92!W<FET=&5N('1O('EO=2!O;B!35$1/550N"@E0;&5A
M<V4@8VAA;F=E('1H96TA($D@:VYO=R!D871A8F%S97,@<G5N;FEN9R!F;W(@
M>65A<G,@<W1O<FEN9R!I;7!O<G1A;G0@9&%T80H)86YD('-T:6QL(&AA=F4@
M=&AE(&1E9F%U;'0@<&%S<W=O<F0@(2$*"2AM86YA9V5R(&9O<B!S>7-T96T@
M86YD(&-H86YG95]O;E]I;G-T86QL(&9O<B!S>7,I"@HM+0ES<6QP;'5S('-Y
M<R]C:&%N9V5?;VY?:6YS=&%L;$`\>6]U<B!3240^"@EI9B!Y;W4@<')O<&5R
M;'D@<V5T('1H92!/4D%#3$5?4TE$(&5N=FER;VYM96YT('9A<FEA8FQE('EO
M=2!C86X@;VUM:70@=&AE"@ET<F%I;&EN9R!`/'EO=7(@<VED/B!W:&5N('EO
M=2!A<F4@;&]G9V5D(&]N('1O('1H92!M86-H:6YE('=H:6-H(&ES(')U;FYI
M;F<@=&AE($1"+@H*+2T)8W)E871E('1H92!T86)L97-P86-E(&9O<B!H;W)D
M90H)<W%L/B!#4D5!5$4@5$%"3$534$%#12!(3U)$10H@("`@("`@("`@("`@
M($Q/1T=)3D<*("`@("`@("`@("`@("!$051!1DE,12`G/%E/55(@4$%42"!(
M15)%/B](3U)$12YD8F8G(%-)6D4@/$%3(%E/52!,24M%/DT["@H)5&AI<R!I
M<R!I;F1E960@=F5R>2!S:6UP;&4@8G5T(&ET('=O<FMS(&%N9"!N;W1H:6YG
M(&AA<R!T;R!B92!I;B!U<'!E<F-A<V4*"6QE='1E<G,N($%F=&5R(&$@9F5W
M('-E8V]N9',@;W(@;6EN=71E<R`M(&1E<&5N9',@;VX@:&]W(&UA;GD@;65G
M86)Y=&5S"@EY;W4@9V%V92!T;R!T:&%T('1A8FQE<W!A8V4@+2!A(&YE=R!D
M871A9FEL92!H87,@8F5E;B!C<F5A=&5D+@H*+2T)5V4@8V%N(&YO=R!C<F5A
M=&4@82!U<V5R('=I=&@@9&5F875L="!T86)L97-P86-E($A/4D1%+"!L971S
M(&YA;64@:&EM(&AO<F1E.@H*"4-214%412!54T52($A/4D1%(%!23T9)3$4@
M1$5&055,5"!)1$5.5$E&245$($)9(#QY;W5R('!A<W-W;W)D(&AE<F4^(`H@
M("`@("`@(%1!0DQ%4U!!0T4@2$]21$4@5$5-4$]205)9(%1!0DQ%4U!!0T4@
M5$5-4"!154]402!53DQ)34E4140@3TX@5$5-4`H)455/5$$@54Y,24U)5$5$
M($].($A/4D1%($%#0T]53E0@54Y,3T-+.PH)1U)!3E0@0T].3D5#5"!43R!(
M3U)$13L*"BTM"6-O;6UI="!Y;W5R('=O<FLZ(#X@8V]M;6ET.PH)86YD(&QO
M9R!O=70*+2T);&]G:6X@87,@=7-E<B!H;W)D93H@<W%L<&QU<R!H;W)D92\\
M<&%S<W=O<F0^0#QY;W5R('-I9#X@86YD(&-R96%T92!T:&4@=&%B;&5S"@DA
M/'!A=&@@=&\@:&]R9&4^+W-C<FEP=',O9&(O;W)A8VQE7V-R96%T92YS<6P@
M86YD(&-O;6UI="!Y;W5R(&%K=&EO;CH@/B!C;VUM:70["@ET:&4@=&%B;&5S
M('=I;&P@8F4@8W)E871E9"!I;B!T:&4@9&5F875L="!T86)L97-P86-E(&9O
M<B!Y;W5R(&AO<F1E('5S97(*"0I/2R!N;W<@>6]U(&-A;B!C;VYF:6=U<F4@
M2&]R9&4@=&\@=7-E('EO=7(@:6YS=&%N8V4@8G5T(&%F=&5R(&$@<F5B;V]T
M($]R86-L90IW:6QL(&YO="!S=&%R="!A=71O;6%T:6-L>2X@5&AA="!I<R!W
M:&%T('=E(&%R92!G;VEN9R!T;R!C;VYF:6=U<F4@;F]W+@H*+2T);&]G;W5T
M(&]F(&]R86-L92P@;&]G:6X@87,@=7-E<B!S>7,@;W(@/'EO=7(@;W)A8VQE
M('5S97(^(`H)86YD('-H=71D;W=N('EO=7(@:6YS=&%N8V4Z("AH;W!E('EO
M=7(@;W)A8VQE('5S97(@:7,@:6X@=&AE(&=R;W5P(&1B82`M"@EI9B!N;W0@
M:&4@8V%N)W0@<VAU="!D;W=N('EO=7(@:6YS=&%N8V4I"@D^(&-O;FYE8W0@
M:6YT97)N86P*"3X@<VAU=&1O=VX@:6UM961I871E"@EA;F0@;&]G;W5T+BXN
M"@D*+2T)=&5S="!T:&4@<V-R:7!T(")D8G-T87)T(B!I;B`D3U)!0TQ%7TA/
M344O8FEN($EF('1H92!$0B!D;V5S(&YO="!S=&%R=`H)>6]U(&AA=F4@=&\@
M961I="!I="!O<B!C<F5A=&4@82!L:6YK(&9R;VT@)$]204-,15](3TU%+V1B
M<R]I;FET/'-I9"UN86UE/BYO<F$*"71O("1/4D%#3$5?2$]-12]A9&UI;B\\
M<VED(&YA;64^+W!F:6QE+VEN:70\<VED+6YA;64^+F]R80H)*"!D8G-T87)T
M('=I;&P@;&]O:R!F;W(@>6]U<B!S:60M9FEL97,@:6X@<W5B9&ER(")D8G,B
M(&)U="!T:&5S92!A<F4@<W1O<F5D"@EU;F1E<B`D3U)!0TQ%7TA/344O861M
M:6XO/'-I9"!N86UE/B]P9FEL92\@+2!T:&ES(&UA>6)E(&ES(&$@8G5G(&]R
M(&$*"69E871U<F4@:6X@=&AE(&]R86-L92!I;G-T86QL97(@*0H)=&5S="`B
M9&)S=&%R="(@86=A:6X@+2!N;W<@:70@<VAO=6QD('=O<FLL(&D@:&]P90H*
M+2T)961I="!T:&4@9FEL92`O971C+V]R871A8@H)0VAA;F=E('1H92!L:6YE
M"@D\<VED+6YA;64^.CQY;W5R($]R86-L92!(;VUE("T@1G5L;"!Q=6%L:69I
M960@<&%T:#XZ3B`@('1O"@D\<VED+6YA;64^.CQY;W5R($]R86-L92!(;VUE
M("T@1G5L;"!Q=6%L:69I960@<&%T:#XZ60H*+2T);F]W(&-H86YG92!O<B!C
M<F5A=&4@82!S=&%R='5P('-C<FEP="!W:&EC:"!I<R!E>&5C=71E9"!A="!B
M;V]T('1I;64N($ET('-H;W5L9"!C;VYT86EN"@ES;VUE=&AI;F<@;&EK92!T
M:&ES.@H)"@ES=2`M(#QY;W5R(&]R86-L92!U<V5R/B`M8R`B/&AO=7(@<&%T
M:"!H97)E/B]B:6XO;'-N<F-T;"!S=&%R="(*"7-U("T@/'EO=7(@;W)A8VQE
M('5S97(^("UC("(\>6]U<B!P871H(&AE<F4^+V)I;B]D8G-T87)T(@H*"6%N
M9"!O9B!C;W5R<V4@>6]U<B!I;G-T86YC92!S:&]U;&0@8F4@<W1O<'!E9"!A
M(')E9W5L87(@=V%Y+B!0;&%C92!T:&ES"@EI;B!T:&4@87!P<F]P<FEA=&4@
M<V-R:7!T('=H:6-H(&ES(&5X96-U=&5D(&%T('-H=71D;W=N('1I;64*"@ES
M=2`M(#QY;W5R(&]R86-L92!U<V5R/B`M8R`B/&AO=7(@<&%T:"!H97)E/B]B
M:6XO;'-N<F-T;"!S=&]P(@H)<W4@+2`\>6]U<B!O<F%C;&4@=7-E<CX@+6,@
M(CQY;W5R('!A=&@@:&5R93XO8FEN+V1B<VAU="(*"BTM"71E<W0@:70*"D5N
M9"!O9B!#87-E(#$I"@H*0V%S92`R*0H*4')O8FQE;3H@66]U(&AA=F4@86X@
M86QL<F5A9'D@<G5N;FEN9R!O<F%C;&4@9&%T86)A<V4@86YD('=O=6QD(&QI
M:V4*=&\@861D(&$@;F5W(&EN<W1A;F-E+B!3;VQU=&EO;B!I<R!Q=6EE="!E
M87-Y+@I&;W(@;F]W+"!T:&4@;F5W(&1A=&%B87-E)R!N86UE('=I;&P@8F4@
M+2T^(&AO<F1E"@I"969O<F4@:2!S=&%R="!I)VQL(&UA:V4@<V]M92!A<W-U
M;7!T:6]N<SH**%!,14%312!#2$%.1T4@5$A%(%!!5$A.04U%4R!!4R!.14-%
M4U-!4ED@*0H*,2X))$]204-,15](3TU%/2]H;VUE+V]R86-L90HR+@DD3U)!
M0TQ%7T)!4T4@/2`D3U)!0TQ%7TA/344*,RX)66]U<B!E>&ES=&EN9R!$871A
M8F%S92!I<R!I;G-T86QL960@=6YD97(@)$]204-,15](3TU%+V]R861A=&$O
M/'EO=7(@:6YS=&%N8V4@;F%M93X*-"X)66]U<B!E>&ES=&EN9R!4<F%C92]$
M=6UP+W!F:6QE+V)D=6UP+BXN("T@9&ER96-T;W)I97,@87)E(&EN<W1A;&QE
M9"!U;F1E<@H)("1/4D%#3$5?2$]-12]A9&UI;B\\>6]U<B!I;G-T86YC92!N
M86UE/B\*"@E4:&5R969O<F4@>6]U<B!N97<@:&]R9&4@9&%T86)A<V4@9FEL
M97,@=VEL;"!G;R!I;G1O(&%N;W1H97(@9&ER96-T;W)Y.@H))$]204-,15](
M3TU%+V]R861A=&$O:&]R9&4O"@H)5&AE(%1R86-E+T1U;7`O<&9I;&4O8F1U
M;7`N+BX@+2!D:7)S(&=O('1O.@H))$]204-,15](3TU%+V%D;6EN+VAO<F1E
M+PH*"51H92!I;FET:&]R9&4N;W)A(&9I;&4@:6X@)$]204-,15](3TU%+V1B
M<R!S:&]U;&0@8F4@82!L:6YK('1O.@H))$]204-,15](3TU%+V%D;6EN+VAO
M<F1E+W!F:6QE+VEN:70N;W)A"@I,971S(&)E9VEN.@H*+2T)8W)E871E('1H
M92!D:7)E8W1O<FEE<R!F;W(@>6]U<B!N97<@9&(@*&%S('EO=7(@3U)!0TQ%
M('5S97(I.@H)(SX@;6MD:7(@+7`@)$]204-,15](3TU%+V]R861A=&$O:&]R
M9&4O87)C:&EV90H)(SX@;6MD:7(@+7`@)$]204-,15](3TU%+V%D;6EN+VAO
M<F1E+V%D:&]C(%P*"0D@("`@)$]204-,15](3TU%+V%D;6EN+VAO<F1E+V)D
M=6UP(%P*"0D@("`@)$]204-,15](3TU%+V%D;6EN+VAO<F1E+V-D=6UP(%P*
M"0D@("`@)$]204-,15](3TU%+V%D;6EN+VAO<F1E+V-R96%T92!<"@D)("`@
M("1/4D%#3$5?2$]-12]A9&UI;B]H;W)D92]E>'`@7`H)"2`@("`D3U)!0TQ%
M7TA/344O861M:6XO:&]R9&4O<&9I;&4@7`H)"2`@("`D3U)!0TQ%7TA/344O
M861M:6XO:&]R9&4O=61U;7`*"BTM"6-O<'D@>6]U<B!E>&ES=&EN9R!I;FET
M+F]R82!F:6QE(&9R;VT@)$]204-,15](3TU%+V%D;6EN+SQE>&ES=&EN9R!I
M;G-T86YC93XO<&9I;&4O"@ET;R`D3U)!0TQ%7TA/344O861M:6XO:&]R9&4O
M<&9I;&4O(&%N9"!M86ME('1H92!A<'!R;W!R:6%T92!C:&%N9V5S(&EN(&ET
M"@E#2$%.1T4@050@3$5!4U0@5$A%(%!!5$A.04U%4R`A(2$*"BTM"6UA:V4@
M=&AE(&QI;FL@9G)O;2`D3U)!0TQ%7TA/344O9&)S+VEN:71H;W)D92YO<F$@
M=&\*"21/4D%#3$5?2$]-12]A9&UI;B]H;W)D92]P9FEL92]I;FET+F]R80H*
M"2,^(&QN("US("1/4D%#3$5?2$]-12]A9&UI;B]H;W)D92]P9FEL92]I;FET
M+F]R82`D3U)!0TQ%7TA/344O9&)S+VEN:71H;W)D92YO<F$*"BTM"7-E="!/
M4D%#3$5?4TE$('1O(&AO<F1E"@DC/B!/4D%#3$5?4TE$/6AO<F1E"@HM+0EL
M;V=I;B!A;F0@<W1A<G1U<"!T:&4@:6YS=&%N8V4*"2,^('-Q;'!L=7,@+VYO
M;&]G"@ES<6P^('-T87)T=7`@<&9I;&4]+VAO;64O;W)A8VQE+V%D;6EN+VAO
M<F1E+W!F:6QE+VEN:70N;W)A(&YO;6]U;G0*"BTM"6-R96%T92!T:&4@9&%T
M86)A<V4@9G)O;2!C<F5A=&5?:&]R9&5?9&(N<W%L("T@>6]U('-H;W5L9"!O
M9B!C;W5R<V4@:&%V92!S879E9"!I="!S;VUW:&5R92`[*0H)<W%L/B`A+W!A
M=&@O=&\O8W)E871E7VAO<F1E7V1B+G-Q;`H*"6%S('1E;7!L871E(&D@=&]O
M:R!T:&4@<V-R:7!T(&9R;VT*"6AT='`Z+R]W=W<N861P+6=M8F@N8V@O;W)A
M+V%D;6EN+V-R96%T:6YG9&)M86YU86QL>2YH=&UL(W-A;7!L96-R96%T961A
M=&%B87-E"@EA;F0@;6%D92!S;VUE(&UI;F]R(&-H86YG97,N"@HM+0EC<F5A
M=&4@=&AE(&1A=&$@9&EC=&EO;F%R>2P@971C+@H)<W%L/B`A+VAO;64O;W)A
M8VQE+W)D8FUS+V%D;6EN+V-A=&%L;V<N<W%L"@ES<6P^("$O:&]M92]O<F%C
M;&4O<F1B;7,O861M:6XO8V%T<')O8RYS<6P*"7-Q;#X@(2]H;VUE+V]R86-L
M92]R9&)M<R]A9&UI;B]C871H<RYS<6P*"7-Q;#X@8V]M;6ET.PH)<W%L/B!E
M>&ET"@HM+0EN;W<@861D(&$@;F5W(&QI;F4@=&\@+V5T8R]O<F%T86(*"@EO
M;&0@*"!O;FQY(#$@:6YS=&%N8V4@*3H*"3QY;W5R(&EN<W1A;&QE9"!I;G-T
M86YC92!N86UE/CHO:&]M92]O<F%C;&4Z60H*"6YE=R`H('=I=&@@=&AE(&YE
M=R!O;F4@*3H*"3QY;W5R(&EN<W1A;&QE9"!I;G-T86YC92!N86UE/CHO:&]M
M92]O<F%C;&4Z60H):&]R9&4Z+VAO;64O;W)A8VQE.ED*"BTM"6%D9"!T:&4@
M;F5W(&EN<W1A;F-E('1O('EO=7(@=&YS;F%M97,N;W)A"@EU<V4@=&AE(&IA
M=F$@9W5I(&YE=#AA<W-I<W0@;W(@8V]P>2!A;F0@<&%S=&4@=&AE('-T871E
M;65N=',@8GD@>6]U<G-E;&8@86YD"@EM86ME('1H92!C:&%N9V5S(&%S(&YE
M961E9`H*+2T)869T97(@86QL+"!T:&4@<V-R:7!T<R!D8G-T87)T('5N9"!D
M8G-H=70@=VEL;"!T:&5N(&%U=&]M871I8VQY('-T87)T(&%N9"!S:'5T9&]W
M;B!A;&P*"6EN<W1A;F-E<R!A="!O;F-E"@I#<F5A=&EN9R!T:&4@5&%B;&5S
M<&%C92!A;F0@<F5Q=6ER960@=7-E<B!I<R!T:&4@<V%M92!A<R`@9&5S8W)I
M8F5D(&%B;W9E"@H*22!H;W!E('1H870@=&AE<F4@87)E(&YO="!S;R!M86YY
M('-P96QL:6YG(&UI<W1A:V5S("@@;7D@;F%T:79E(&QA;F=U86=E(&ES(&=E
M<FUA;B`I(`IA;F0@=&AA="!T:&ES('=I;&P@8F4@:&5L<&9U;&P@9F]R('-O
M;65O;F4*"D5N9"!O9B!#87-E(#(I"@HD2&]R9&4Z(&AO<F1E+W-C<FEP=',O
M<W%L+U)%041-12Y/0TDX+'8@,2XR(#(P,#0O,#DO,C4@,3DZ-38Z,3(@8VAU
M8VL@17AP("0*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O<W%L
M+VAO<F1E7W5S97)S+G-Q;```````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#8R,B`Q,#4Q-30S,S<T,R`P,C,P-S$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+2T@)$AO<F1E.B!H;W)D92]S
M8W)I<'1S+W-Q;"]H;W)D95]U<V5R<RYS<6PL=B`Q+C(N,3`N,B`R,#`U+S$P
M+S$X(#$Q.C,T.C`P(&IA;B!%>'`@)`H*0U)%051%(%1!0DQ%(&AO<F1E7W5S
M97)S("@*("`@('5S97)?=6ED("`@("`@("`@("`@("`@("`@("!605)#2$%2
M*#(U-2D@3D]4($Y53$PL"B`@("!U<V5R7W!A<W,@("`@("`@("`@("`@("`@
M("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=7-E<E]S;V9T7V5X<&ER
M871I;VY?9&%T92`@($E.5$5'15(L"B`@("!U<V5R7VAA<F1?97AP:7)A=&EO
M;E]D871E("`@24Y414=%4BP*+2T*("`@(%!224U!4ED@2T59("AU<V5R7W5I
M9"D**3L*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/
M3B!H;W)D95]U<V5R<R!43R!H;W)D93L*````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]H:7-T
M;W)I97,N<W%L````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$R,S0@
M,3`U,34T,S,W-#,@,#(S-S0Q`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"TM("1(;W)D93H@:&]R9&4O<V-R:7!T<R]S<6PO
M:&]R9&5?:&ES=&]R:65S+G-Q;"QV(#$N,2XR+C$@,C`P-2\Q,"\Q."`Q,3HS
M-#HP,"!J86X@17AP("0*"D-214%412!404),12!H;W)D95]H:7-T;W)I97,@
M*`H@("`@:&ES=&]R>5]I9"`@("`@("!"24=)3E0@3D]4($Y53$PL"B`@("!O
M8FIE8W1?=6ED("`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@(&AI
M<W1O<GE?86-T:6]N("`@5D%20TA!4B@S,BD@3D]4($Y53$PL"B`@("!H:7-T
M;W)Y7W1S("`@("`@($))1TE.5"!.3U0@3E5,3"P*("`@(&AI<W1O<GE?9&5S
M8R`@("`@5$585"P*("`@(&AI<W1O<GE?=VAO("`@("`@5D%20TA!4B@R-34I
M+`H@("`@:&ES=&]R>5]E>'1R82`@("!415A4+`HM+0H@("`@4%))34%262!+
M15D@*&AI<W1O<GE?:60I"BD["@I#4D5!5$4@24Y$15@@:&ES=&]R>5]A8W1I
M;VY?:61X($].(&AO<F1E7VAI<W1O<FEE<R`H:&ES=&]R>5]A8W1I;VXI.PI#
M4D5!5$4@24Y$15@@:&ES=&]R>5]T<U]I9'@@3TX@:&]R9&5?:&ES=&]R:65S
M("AH:7-T;W)Y7W1S*3L*0U)%051%($E.1$58(&AI<W1O<GE?=6ED7VED>"!/
M3B!H;W)D95]H:7-T;W)I97,@*&]B:F5C=%]U:60I.PH*1U)!3E0@4T5,14-4
M+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7VAI<W1O<FEE<R!4
M3R!H;W)D93L*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D
M95]S97-S:6]N:&%N9&QE<BYO8VDX+G-Q;```````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#`U-C`@,3`U,34T,S,W-#,@,#(U-C$S`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"TM("1(;W)D93H@:&]R9&4O<V-R:7!T
M<R]S<6PO:&]R9&5?<V5S<VEO;FAA;F1L97(N;V-I."YS<6PL=B`Q+C(N,3`N
M,2`R,#`U+S$P+S$X(#$Q.C,T.C`P(&IA;B!%>'`@)`H*0U)%051%(%1!0DQ%
M(&AO<F1E7W-E<W-I;VYH86YD;&5R("@*("`@('-E<W-I;VY?:60@("`@("`@
M("`@("`@5D%20TA!4C(H,S(I($Y/5"!.54Q,+`H@("`@<V5S<VEO;E]L87-T
M;6]D:69I960@("!)3E0@3D]4($Y53$PL"B`@("!S97-S:6]N7V1A=&$@("`@
M("`@("`@($),3T(L"BTM"B`@("!04DE-05)9($M%62`H<V5S<VEO;E]I9"D*
M*3L*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H
M;W)D95]S97-S:6]N:&%N9&QE<B!43R!H;W)D93L*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?=F9S+F]C:3@N
M<W%L````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,#4U(#$P-3$U
M-#,S-S0S(#`R,S,W,``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O<W%L+VAO<F1E
M7W9F<RYO8VDX+G-Q;"QV(#$N,R`R,#`T+S`Y+S(Q(#`S.C,T.C`V(&-H=6-K
M($5X<"`D"@I#4D5!5$4@5$%"3$4@:&]R9&5?=F9S("@*("`@('9F<U]I9"`@
M("`@("`@3E5-0D52*#$V*2!.3U0@3E5,3"P*("`@('9F<U]T>7!E("`@("`@
M3E5-0D52*#@I($Y/5"!.54Q,+`H@("`@=F9S7W!A=&@@("`@("!605)#2$%2
M,B@R-34I+`H@("`@=F9S7VYA;64@("`@("!605)#2$%2,B@R-34I($Y/5"!.
M54Q,+`H@("`@=F9S7VUO9&EF:65D("!.54U"15(H,38I($Y/5"!.54Q,+`H@
M("`@=F9S7V]W;F5R("`@("!605)#2$%2,B@R-34I+`H@("`@=F9S7V1A=&$@
M("`@("!"3$]"+`HM+0H@("`@4%))34%262!+15D@("`H=F9S7VED*0HI.PH*
M0U)%051%($E.1$58('9F<U]P871H7VED>"!/3B!H;W)D95]V9G,@*'9F<U]P
M871H*3L*0U)%051%($E.1$58('9F<U]N86UE7VED>"!/3B!H;W)D95]V9G,@
M*'9F<U]N86UE*3L*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%
M3$5412!/3B!H;W)D95]V9G,@5$\@:&]R9&4["@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?<')E
M9G,N;7-S<6PN<W%L````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,#$Q
M(#$P-3$U-#,S-S0S(#`R-#$W-@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O<W%L
M+VAO<F1E7W!R969S+FUS<W%L+G-Q;"QV(#$N,2XR+C(@,C`P-B\P-B\R.2`Q
M-CHR.3HP,R!J86X@17AP("0*"D-214%412!404),12!H;W)D95]P<F5F<R`H
M"B`@("!P<F5F7W5I9"`@("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@
M("`@<')E9E]S8V]P92`@("`@(%9!4D-(05(H,38I($Y/5"!.54Q,($1%1D%5
M3%0@)R<L"B`@("!P<F5F7VYA;64@("`@("`@5D%20TA!4B@S,BD@3D]4($Y5
M3$PL"B`@("!P<F5F7W9A;'5E("`@("`@5D%20TA!4BA-05@I+`HM+0H@("`@
M4%))34%262!+15D@*'!R969?=6ED+"!P<F5F7W-C;W!E+"!P<F5F7VYA;64I
M"BD["@I#4D5!5$4@24Y$15@@<')E9E]U:61?:61X($].(&AO<F1E7W!R969S
M("AP<F5F7W5I9"D["D-214%412!)3D1%6"!P<F5F7W-C;W!E7VED>"!/3B!H
M;W)D95]P<F5F<R`H<')E9E]S8V]P92D["@I'4D%.5"!314Q%0U0L($E.4T52
M5"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?<')E9G,@5$\@:&]R9&4["@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R
M9&5?=&]K96YS+G-Q;```````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P-30Q(#$P-3$U-#,S-S0S(#`R,S(S,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP
M=',O<W%L+VAO<F1E7W1O:V5N<RYS<6PL=B`Q+C(N,3`N,B`R,#`U+S$P+S$X
M(#$Q.C,T.C`P(&IA;B!%>'`@)`H*0U)%051%(%1!0DQ%(&AO<F1E7W1O:V5N
M<R`H"B`@("!T;VME;E]A9&1R97-S("`@(%9!4D-(05(H,3`P*2!.3U0@3E5,
M3"P*("`@('1O:V5N7VED("`@("`@("`@5D%20TA!4B@S,BD@3D]4($Y53$PL
M"B`@("!T;VME;E]T:6UE<W1A;7`@($))1TE.5"!.3U0@3E5,3"P*+2T*("`@
M(%!224U!4ED@2T59("AT;VME;E]A9&1R97-S+"!T;VME;E]I9"D**3L*"D=2
M04Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]T
M;VME;G,@5$\@:&]R9&4["@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7W-E<W-I;VYH
M86YD;&5R+FUS<W%L+G-Q;```````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#4V-R`Q,#4Q
M-30S,S<T,R`P,C8Q,3<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+2T@)$AO<F1E.B!H;W)D92]S8W)I<'1S+W-Q;"]H;W)D
M95]S97-S:6]N:&%N9&QE<BYM<W-Q;"YS<6PL=B`Q+C$N,BXQ(#(P,#8O,#$O
M,3@@,3DZ-3DZ,3`@8F5N($5X<"`D"@I#4D5!5$4@5$%"3$4@:&]R9&5?<V5S
M<VEO;FAA;F1L97(@*`H@("`@<V5S<VEO;E]I9"`@("`@("`@("`@("!605)#
M2$%2*#,R*2!.3U0@3E5,3"P*("`@('-E<W-I;VY?;&%S=&UO9&EF:65D("`@
M24Y4($Y/5"!.54Q,+`H@("`@<V5S<VEO;E]D871A("`@("`@("`@("!605)"
M24Y!4EDH34%8*2P*"B`@("!04DE-05)9($M%62`H<V5S<VEO;E]I9"D**3L*
M"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D
M95]S97-S:6]N:&%N9&QE<B!43R!H;W)D93L*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]L;V<N;7-S<6PN<W%L````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`V-3<@,3`U,34T,S,W-#,@,#(S
M-C4W`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"TM("1(;W)D93H@:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?;&]G+FUS<W%L
M+G-Q;"QV(#$N,2XR+C$@,C`P-B\P,2\Q."`Q.3HU.#HT."!B96X@17AP("0*
M"D-214%412!404),12!H;W)D95]L;V<@*`H@("`@:60@("`@("`@("`@24Y4
M($Y/5"!.54Q,+`H@("`@;&]G=&EM92`@("`@5$E-15-404U0($Y/5"!.54Q,
M+`H@("`@:61E;G0@("`@("`@0TA!4B@Q-BD@3D]4($Y53$PL"B`@("!P<FEO
M<FET>2`@("!)3E0@3D]4($Y53$PL"B`@("`M+2!&;W(@1$)S('1H870@9&]N
M)W0@<W5P<&]R="!T:&4@5D%20TA!4BA-05@I(&9I96QD('1Y<&4Z"B`@("`M
M+2!M97-S86=E("!605)#2$%2*#(P-#@I+`H@("`@;65S<V%G92`@("`@5D%2
M0TA!4BA-05@I+`H@("`@4%))34%262!+15D@*&ED*0HI.PH*1U)!3E0@24Y3
M15)4($].(&AO<F1E7VQO9R!43R!H;W)D93L*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R
M:7!T<R]S<6PO:&]R9&5?<V5S<VEO;FAA;F1L97(N<V%P9&(N<W%L````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P-#0V(#$P-3$U-#,S-S0S(#`R-C`T-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````M+2`D2&]R9&4Z
M(&AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7W-E<W-I;VYH86YD;&5R+G-A<&1B
M+G-Q;"QV(#$N,2`R,#`T+S`Y+S$X(#$W.C(P.C4Y(&-H=6-K($5X<"`D"@I#
M4D5!5$4@5$%"3$4@:&]R9&5?<V5S<VEO;FAA;F1L97(@*`H@("`@<V5S<VEO
M;E]I9"`@("`@("`@("`@("!605)#2$%2*#,R*2!.3U0@3E5,3"P*("`@('-E
M<W-I;VY?;&%S=&UO9&EF:65D("`@24Y4($Y/5"!.54Q,+`H@("`@<V5S<VEO
M;E]D871A("`@("`@("`@("!,3TY'($)95$4L"B`@("!04DE-05)9($M%62`H
M<V5S<VEO;E]I9"D**0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O<W%L+VAO
M<F1E7VUU=F9S+FUS<W%L+G-Q;```````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,3`U-2`Q,#4Q-30S,S<T,R`P,C0R,C<`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+2T@)$AO<F1E.B!H;W)D92]S8W)I
M<'1S+W-Q;"]H;W)D95]M=79F<RYM<W-Q;"YS<6PL=B`Q+C$N,BXQ(#(P,#8O
M,#$O,3@@,3DZ-3@Z-30@8F5N($5X<"`D"@I#4D5!5$4@5$%"3$4@:&]R9&5?
M;75V9G,@*`H@("`@=F9S7VED("`@("`@("!"24=)3E0@3D]4($Y53$PL"B`@
M("!V9G-?='EP92`@("`@(%--04Q,24Y4($Y/5"!.54Q,+`H@("`@=F9S7W!A
M=&@@("`@("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?;F%M92`@
M("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]M;V1I9FEE9"`@
M0DE'24Y4($Y/5"!.54Q,+`H@("`@=F9S7V]W;F5R("`@("!605)#2$%2*#(U
M-2D@3D]4($Y53$PL"B`@("!V9G-?<&5R;7,@("`@(%--04Q,24Y4($Y/5"!.
M54Q,+`H@("`@=F9S7V1A=&$@("`@("!605)"24Y!4EDH34%8*2P*("`@(%!2
M24U!4ED@2T59("`@*'9F<U]I9"D**3L*"D-214%412!)3D1%6"!V9G-?<&%T
M:%]I9'@@3TX@:&]R9&5?;75V9G,@*'9F<U]P871H*3L*0U)%051%($E.1$58
M('9F<U]N86UE7VED>"!/3B!H;W)D95]M=79F<R`H=F9S7VYA;64I.PH`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O
M<W%L+V-R96%T92YS>6)A<V4N<W%L````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`Q,#$U-R`Q,#4Q-30S,S<T,R`P,C,S,#,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+2T@)$AO<F1E.B!H;W)D
M92]S8W)I<'1S+W-Q;"]C<F5A=&4N<WEB87-E+G-Q;"QV(#$N,2XQ,"XU(#(P
M,#8O,#8O,CD@,38Z,CDZ,#,@:F%N($5X<"`D"BTM"BTM(&AO<F1E('1A8FQE
M<R!D969I;FET:6]N<R`Z('-Q;"!S8W)I<'0*+2T@,#$O,C(O,C`P,R`M($8N
M($AE;&QY(#QF<F%N8V]I<RYH96QL>4!W86YA9&]O+F9R/@HM+2!C;VUM86YD
M(&QI;F4@<WEN=&%X(#H@(&ES<6P@+6EH;W)D95]S>6)A<V4N<W%L"BTM('=A
M<FYI;F<@.B!U<V4@;G9A<F-H87(@;VYL>2!I9B!Y;W4@;F5E9"!U;FEC;V1E
M(&5N8V]D:6YG(&9O<B!S;VUE('-T<FEN9W,*"G5S92!H;W)D90IG;PH*"D12
M3U`@5$%"3$4@:&]R9&5?9&%T871R964*9V\*"D123U`@5$%"3$4@:&]R9&5?
M<')E9G,*9V\*"D123U`@5$%"3$4@:&]R9&5?=7-E<G,*9V\*"D123U`@5$%"
M3$4@:&]R9&5?<V5S<VEO;FAA;F1L97(*9V\*"BTM($123U`@5$%"3$4@:&]R
M9&5?9&%T871R965?<V5Q"BTM(&=O"@HM+2!$4D]0(%1!0DQ%(&AO<F1E7W1O
M:V5N<PHM+2!G;PH*+2T@1%)/4"!404),12!H;W)D95]V9G,*+2T@9V\*"BTM
M($123U`@5$%"3$4@:&]R9&5?;75V9G,*+2T@9V\*"@I#4D5!5$4@5$%"3$4@
M:&]R9&5?=7-E<G,@*`H@('5S97)?=6ED('9A<F-H87(H,C4V*2!.3U0@3E5,
M3"P*("!U<V5R7W!A<W,@=F%R8VAA<B@R-38I($Y/5"!.54Q,+`H@('5S97)?
M<V]F=%]E>'!I<F%T:6]N7V1A=&4@;G5M97)I8R@Q,"PP*2P*("!U<V5R7VAA
M<F1?97AP:7)A=&EO;E]D871E(&YU;65R:6,H,3`L,"DL"B`@4%))34%262!+
M15D@("AU<V5R7W5I9"D**0IG;PH*0U)%051%(%1!0DQ%(&AO<F1E7V1A=&%T
M<F5E("@*("!D871A=')E95]I9"!N=6UE<FEC*#$Q+#`I($E$14Y42519($Y/
M5"!.54Q,+`H@(&=R;W5P7W5I9"!V87)C:&%R*#(U-BD@3D]4($Y53$PL"B`@
M=7-E<E]U:60@=F%R8VAA<B@R-38I($Y/5"!.54Q,+`H@(&1A=&%T<F5E7VYA
M;64@=F%R8VAA<B@R-38I($Y/5"!.54Q,+`H@(&1A=&%T<F5E7W!A<F5N=',@
M=F%R8VAA<B@R-38I($Y53$PL"B`@9&%T871R965?9&%T82!T97AT($Y53$PL
M"B`@9&%T871R965?<V5R:6%L:7IE9"!S;6%L;&EN="!$149!54Q4(#`@3D]4
M($Y53$PL"B`@4%))34%262!+15D@("AD871A=')E95]I9"DL"B`@1D]214E'
M3B!+15D@*'5S97)?=6ED*0H@("`@4D5&15)%3D-%4R!H;W)D95]U<V5R<RAU
M<V5R7W5I9"D*("D*9V\*"D-214%412!404),12!H;W)D95]P<F5F<R`H"B`@
M<')E9E]U:60@=F%R8VAA<B@R-38I($Y/5"!.54Q,+`H@('!R969?<V-O<&4@
M=F%R8VAA<B@Q-BD@3D]4($Y53$PL"B`@<')E9E]N86UE('9A<F-H87(H,S(I
M($Y/5"!.54Q,+`H@('!R969?=F%L=64@=&5X="!.54Q,+`H@(%!224U!4ED@
M2T59("`H<')E9E]U:60L<')E9E]S8V]P92QP<F5F7VYA;64I"BD*9V\*"D-2
M14%412!404),12!H;W)D95]S97-S:6]N:&%N9&QE<B`H"B`@<V5S<VEO;E]I
M9"!V87)C:&%R*#,R*2!.3U0@3E5,3"P*("!S97-S:6]N7VQA<W1M;V1I9FEE
M9"!N=6UE<FEC*#$Q+#`I($Y/5"!.54Q,+`H@('-E<W-I;VY?9&%T82!I;6%G
M92!.54Q,+`H@(%!224U!4ED@2T59("`H<V5S<VEO;E]I9"D**0IG;PH*"BTM
M($-214%412!404),12!H;W)D95]D871A=')E95]S97$@*`HM+2`@(&ED(&YU
M;65R:6,H,3`L,"D@241%3E1)5%D@3D]4($Y53$PL"BTM("`@4%))34%262!+
M15D@("AI9"D*+2T@*0HM+2!G;PH*+2T@0U)%051%(%1!0DQ%(&AO<F1E7W1O
M:V5N<R`H"BTM("`@=&]K96Y?861D<F5S<R!V87)C:&%R*#$P,"D@3D]4($Y5
M3$PL"BTM("`@=&]K96Y?:60@=F%R8VAA<B@S,BD@3D]4($Y53$PL"BTM("`@
M=&]K96Y?=&EM97-T86UP(&YU;65R:6,H,C`L,"D@3D]4($Y53$PL"BTM("`@
M4%))34%262!+15D@("AT;VME;E]A9&1R97-S+'1O:V5N7VED*0HM+2`I"BTM
M(&=O"@HM+2!#4D5!5$4@5$%"3$4@:&]R9&5?=F9S("@*+2T@("!V9G-?:60@
M;G5M97)I8R@R,"PP*2!.3U0@3E5,3"P*+2T@("!V9G-?='EP92!N=6UE<FEC
M*#@L,"D@3D]4($Y53$PL"BTM("`@=F9S7W!A=&@@=F%R8VAA<B@R-38I($Y/
M5"!.54Q,+`HM+2`@('9F<U]N86UE(&YV87)C:&%R*#(U-BD@3D]4($Y53$PL
M"BTM("`@=F9S7VUO9&EF:65D(&YU;65R:6,H,C`L,"D@3D]4($Y53$PL"BTM
M("`@=F9S7V]W;F5R('9A<F-H87(H,C4V*2!.3U0@3E5,3"P*+2T@("!V9G-?
M9&%T82!I;6%G92!.54Q,+`HM+2`@(%!224U!4ED@2T59("`H=F9S7VED*0HM
M+2`I"BTM(&=O"@HM+2!#4D5!5$4@5$%"3$4@:&]R9&5?;75V9G,@*`HM+2`@
M('9F<U]I9"`@;G5M97)I8R@R,"PP*2!.3U0@3E5,3"P*+2T@("!V9G-?='EP
M92`@("`@(&YU;65R:6,H."PP*2!.3U0@3E5,3"P*+2T@("!V9G-?<&%T:"`@
M("`@('9A<F-H87(H,C4V*2!.3U0@3E5,3"P*+2T@("!V9G-?;F%M92`@("`@
M('9A<F-H87(H,C4V*2!.3U0@3E5,3"P*+2T@("!V9G-?;6]D:69I960@(&YU
M;65R:6,H."PP*2!.3U0@3E5,3"P*+2T@("!V9G-?;W=N97(@("`@('9A<F-H
M87(H,C4V*2!.3U0@3E5,3"P*+2T@("!V9G-?<&5R;7,@("`@('-M86QL:6YT
M($Y/5"!.54Q,+`HM+2`@('9F<U]D871A("`@("`@:6UA9V4@3E5,3"P*+2T@
M("!04DE-05)9($M%62`@("AV9G-?:60I"BTM("`@*0HM+2!G;PH*"D-214%4
M12!)3D1%6"!P<F5F7W5I9%]I9'@@3TX@:&]R9&5?<')E9G,@*'!R969?=6ED
M*0IG;PH*0U)%051%($E.1$58('!R969?<V-O<&5?:61X($].(&AO<F1E7W!R
M969S("AP<F5F7W-C;W!E*0IG;PH*0U)%051%($E.1$58(&1A=&%T<F5E7V1A
M=&%T<F5E7VYA;65?:61X($].(&AO<F1E7V1A=&%T<F5E("AD871A=')E95]N
M86UE*0IG;PH*0U)%051%($E.1$58(&1A=&%T<F5E7V=R;W5P7VED>"!/3B!H
M;W)D95]D871A=')E92`H9W)O=7!?=6ED*0IG;PH*0U)%051%($E.1$58(&1A
M=&%T<F5E7W5S97)?:61X($].(&AO<F1E7V1A=&%T<F5E("AU<V5R7W5I9"D*
M9V\*"D-214%412!)3D1%6"!D871A=')E95]S97)I86QI>F5D7VED>"!/3B!H
M;W)D95]D871A=')E92`H9&%T871R965?<V5R:6%L:7IE9"D*9V\*"BTM($-2
M14%412!)3D1%6"!V9G-?<&%T:%]I9'@@3TX@:&]R9&5?=F9S("AV9G-?<&%T
M:"D*+2T@9V\*"BTM($-214%412!)3D1%6"!V9G-?;F%M95]I9'@@3TX@:&]R
M9&5?=F9S("AV9G-?;F%M92D*+2T@9V\*"BTM($-214%412!)3D1%6"!V9G-?
M<&%T:%]I9'@@3TX@:&]R9&5?;75V9G,@*'9F<U]P871H*0HM+2!G;PH*+2T@
M0U)%051%($E.1$58('9F<U]N86UE7VED>"!/3B!H;W)D95]M=79F<R`H=F9S
M7VYA;64I"BTM(&=O"@H*9W)A;G0@<V5L96-T+"!I;G-E<G0L(&1E;&5T92P@
M=7!D871E(&]N(&5D:71O<B!T;R!H;W)D90IG;PIG<F%N="!S96QE8W0L(&EN
M<V5R="P@9&5L971E+"!U<&1A=&4@;VX@:&]S="!T;R!H;W)D90IG;PIG<F%N
M="!S96QE8W0L(&EN<V5R="P@9&5L971E+"!U<&1A=&4@;VX@9&)A<V4@=&\@
M:&]R9&4*9V\*9W)A;G0@<V5L96-T+"!I;G-E<G0L(&1E;&5T92P@=7!D871E
M(&]N('-I=&4@=&\@:&]R9&4*9V\*9W)A;G0@<V5L96-T+"!I;G-E<G0L(&1E
M;&5T92P@=7!D871E(&]N(&-O;FYE8W1I;VX@=&\@:&]R9&4*9V\*9W)A;G0@
M<V5L96-T+"!I;G-E<G0L(&1E;&5T92P@=7!D871E(&]N(&AO<F1E7V1A=&%T
M<F5E('1O(&AO<F1E"F=O"F=R86YT('-E;&5C="P@:6YS97)T+"!D96QE=&4L
M('5P9&%T92!O;B!H;W)D95]P<F5F<R!T;R!H;W)D90IG;PIG<F%N="!S96QE
M8W0L(&EN<V5R="P@9&5L971E+"!U<&1A=&4@;VX@:&]R9&5?<V5S<VEO;FAA
M;F1L97(@=&\@:&]R9&4*9V\*"BTM(&=R86YT('-E;&5C="P@:6YS97)T+"!D
M96QE=&4L('5P9&%T92!O;B!H;W)D95]D871A=')E95]S97$@=&\@:&]R9&4*
M+2T@9V\*+2T@9W)A;G0@<V5L96-T+"!I;G-E<G0L(&1E;&5T92P@=7!D871E
M(&]N(&AO<F1E7W1O:V5N<R!T;R!H;W)D90HM+2!G;PHM+2!G<F%N="!S96QE
M8W0L(&EN<V5R="P@9&5L971E+"!U<&1A=&4@;VX@:&]R9&5?=F9S('1O(&AO
M<F1E"BTM(&=O"BTM(&=R86YT('-E;&5C="P@:6YS97)T+"!D96QE=&4L('5P
M9&%T92!O;B!H;W)D95]M=79F<R!T;R!H;W)D90HM+2!G;PH*"@HM+2!A9&0@
M>6]U(&%D;6EN7W5S97)?=6ED(&%N9"!A9&UI;E]U<V5R7W!A<W,*"BTM(&EN
M<V5R="!I;G1O(&AO<F1E7W5S97)S('9A;'5E<R`H)WEO=7)?861M:6Y?=7-E
M<E]U:60G+"`G>6]U<E]A9&UI;E]U<V5R7W!A<W-?;60U7V5N8W)Y<'1E9"<I
M"BTM(&=O"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?
M=F9S+G-Q;```````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q
M,34P(#$P-3$U-#,S-S0S(#`R,C4R,P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O
M<W%L+VAO<F1E7W9F<RYS<6PL=B`Q+C$N,3`N,B`R,#`U+S$P+S$X(#$Q.C,T
M.C`P(&IA;B!%>'`@)`H*0U)%051%(%1!0DQ%(&AO<F1E7W9F<R`H"B`@("!V
M9G-?:60@("`@("`@($))1TE.5"!.3U0@3E5,3"P*("`@('9F<U]T>7!E("`@
M("`@4TU!3$Q)3E0@3D]4($Y53$PL"B`@("!V9G-?<&%T:"`@("`@(%9!4D-(
M05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]N86UE("`@("`@5D%20TA!4B@R
M-34I($Y/5"!.54Q,+`H@("`@=F9S7VUO9&EF:65D("!"24=)3E0@3D]4($Y5
M3$PL"B`@("!V9G-?;W=N97(@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*
M("`@('9F<U]D871A("`@("`@3$].1T),3T(L"BTM($]R+"!O;B!S;VUE($1"
M35,@<WES=&5M<SH*+2T@('9F<U]D871A("`@("`@24U!1T4L"B`@("!04DE-
M05)9($M%62`@("AV9G-?:60I"BD["@I#4D5!5$4@24Y$15@@=F9S7W!A=&A?
M:61X($].(&AO<F1E7W9F<R`H=F9S7W!A=&@I.PI#4D5!5$4@24Y$15@@=F9S
M7VYA;65?:61X($].(&AO<F1E7W9F<R`H=F9S7VYA;64I.PH*1U)!3E0@4T5,
M14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7W9F<R!43R!H
M;W)D93L*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO
M:&]R9&5?=F9S+FUS<W%L+G-Q;```````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`Q,#<U(#$P-3$U-#,S-S0S(#`R,S8V-P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````M+2`D2&]R9&4Z(&AO<F1E+W-C
M<FEP=',O<W%L+VAO<F1E7W9F<RYM<W-Q;"YS<6PL=B`Q+C$N,BXQ(#(P,#8O
M,#$O,3@@,3DZ-3DZ,38@8F5N($5X<"`D"@I#4D5!5$4@5$%"3$4@:&]R9&5?
M=F9S("@*("`@('9F<U]I9"`@("`@("`@0DE'24Y4($Y/5"!.54Q,+`H@("`@
M=F9S7W1Y<&4@("`@("!334%,3$E.5"!.3U0@3E5,3"P*("`@('9F<U]P871H
M("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=F9S7VYA;64@("`@
M("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?;6]D:69I960@($))
M1TE.5"!.3U0@3E5,3"P*("`@('9F<U]O=VYE<B`@("`@5D%20TA!4B@R-34I
M($Y/5"!.54Q,+`H@("`@=F9S7V1A=&$@("`@("!605)"24Y!4EDH34%8*2P*
M("`@(%!224U!4ED@2T59("`@*'9F<U]I9"D**3L*"D-214%412!)3D1%6"!V
M9G-?<&%T:%]I9'@@3TX@:&]R9&5?=F9S("AV9G-?<&%T:"D["D-214%412!)
M3D1%6"!V9G-?;F%M95]I9'@@3TX@:&]R9&5?=F9S("AV9G-?;F%M92D["@I'
M4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?
M=F9S(%1/(&AO<F1E.PH`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T
M<R]S<6PO:&]R9&5?<')E9G,N<W%L````````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P-S<T(#$P-3$U-#,S-S0S(#`R,S`U-P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````M+2`D2&]R9&4Z(&AO
M<F1E+W-C<FEP=',O<W%L+VAO<F1E7W!R969S+G-Q;"QV(#$N,BXQ,"XQ(#(P
M,#8O,#8O,CD@,38Z,CDZ,#,@:F%N($5X<"`D"@I#4D5!5$4@5$%"3$4@:&]R
M9&5?<')E9G,@*`H@("`@<')E9E]U:60@("`@("`@(%9!4D-(05(H,C4U*2!.
M3U0@3E5,3"P*("`@('!R969?<V-O<&4@("`@("!605)#2$%2*#$V*2!.3U0@
M3E5,3"!$149!54Q4("<G+`H@("`@<')E9E]N86UE("`@("`@(%9!4D-(05(H
M,S(I($Y/5"!.54Q,+`H@("`@<')E9E]V86QU92`@("`@(%1%6%0L"BTM"B`@
M("!04DE-05)9($M%62`H<')E9E]U:60L('!R969?<V-O<&4L('!R969?;F%M
M92D**3L*"D-214%412!)3D1%6"!P<F5F7W5I9%]I9'@@3TX@:&]R9&5?<')E
M9G,@*'!R969?=6ED*3L*0U)%051%($E.1$58('!R969?<V-O<&5?:61X($].
M(&AO<F1E7W!R969S("AP<F5F7W-C;W!E*3L*"D=204Y4(%-%3$5#5"P@24Y3
M15)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]P<F5F<R!43R!H;W)D93L*
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O<W%L+VAO<F1E
M7V1A=&%T<F5E+FUY<W%L+G-Q;```````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,C4R-"`Q,#4Q-30S,S<T,R`P,C0V-S``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+2T@)$AO<F1E.B!H;W)D92]S8W)I<'1S
M+W-Q;"]H;W)D95]D871A=')E92YM>7-Q;"YS<6PL=B`Q+C$N,3`N,2`R,#`V
M+S`U+S(R(#(Q.C(W.C,S(&IA;B!%>'`@)`H*0U)%051%(%1!0DQ%(&AO<F1E
M7V1A=&%T<F5E("@*("`@("`@(&1A=&%T<F5E7VED($E.5"!.3U0@3E5,3"P*
M("`@("`@(&=R;W5P7W5I9"!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("`@
M("!U<V5R7W5I9"!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("`@("!D871A
M=')E95]N86UE(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@("`@(&1A=&%T
M<F5E7W!A<F5N=',@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@("`@9&%T
M871R965?;W)D97(@24Y4+`H@("`@("`@9&%T871R965?9&%T82!415A4+`H@
M("`@("`@9&%T871R965?<V5R:6%L:7IE9"!334%,3$E.5"!$149!54Q4(#`@
M3D]4($Y53$PL"B`@("`@("!04DE-05)9($M%62`H9&%T871R965?:60I"BD[
M"@I#4D5!5$4@24Y$15@@9&%T871R965?9&%T871R965?;F%M95]I9'@@3TX@
M:&]R9&5?9&%T871R964@*&1A=&%T<F5E7VYA;64I.PI#4D5!5$4@24Y$15@@
M9&%T871R965?9W)O=7!?:61X($].(&AO<F1E7V1A=&%T<F5E("AG<F]U<%]U
M:60I.PI#4D5!5$4@24Y$15@@9&%T871R965?=7-E<E]I9'@@3TX@:&]R9&5?
M9&%T871R964@*'5S97)?=6ED*3L*0U)%051%($E.1$58(&1A=&%T<F5E7W-E
M<FEA;&EZ961?:61X($].(&AO<F1E7V1A=&%T<F5E("AD871A=')E95]S97)I
M86QI>F5D*3L*"D-214%412!404),12!H;W)D95]D871A=')E95]A='1R:6)U
M=&5S("@*("`@(&1A=&%T<F5E7VED($E.5"!.3U0@3E5,3"P*("`@(&%T=')I
M8G5T95]N86UE(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@(&%T=')I8G5T
M95]K97D@5D%20TA!4B@R-34I($1%1D%53%0@)R<@3D]4($Y53$PL"B`@("!A
M='1R:6)U=&5?=F%L=64@5$585`HI.PH*0U)%051%($E.1$58(&1A=&%T<F5E
M7V%T=')I8G5T95]I9'@@3TX@:&]R9&5?9&%T871R965?871T<FEB=71E<R`H
M9&%T871R965?:60I.PI#4D5!5$4@24Y$15@@9&%T871R965?871T<FEB=71E
M7VYA;65?:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*&%T=')I
M8G5T95]N86UE*3L*0U)%051%($E.1$58(&1A=&%T<F5E7V%T=')I8G5T95]K
M97E?:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*&%T=')I8G5T
M95]K97DI.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%
M($].(&AO<F1E7V1A=&%T<F5E(%1/(&AO<F1E0&QO8V%L:&]S=#L*1U)!3E0@
M4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7V1A=&%T
M<F5E7V%T=')I8G5T97,@5$\@:&]R9&5`;&]C86QH;W-T.PH`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<V-R:7!T<R]S<6PO8W)E871E+G!G<W%L+G-Q;```````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`W-3`U(#$P-3$U-#,S-S0S(#`R,S$T
M-@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````M
M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O<W%L+V-R96%T92YP9W-Q;"YS<6PL
M=B`Q+C$N,3`N-2`R,#`V+S`X+S`T(#(P.C0Y.C0S(&IA;B!%>'`@)`HM+0HM
M+2!5;F-O;6UE;G0@=&AE($%,5$52(&QI;F4@8F5L;W<L(&%N9"!C:&%N9V4@
M=&AE('!A<W-W;W)D+B`@5&AE;B!R=6X@87,Z"BTM"BTM("0@<'-Q;"`M9"!T
M96UP;&%T93$@+68@8W)E871E+G!G<W%L+G-Q;`H*0U)%051%($1!5$%"05-%
M(&AO<F1E.PH*7&,@:&]R9&4["@I#4D5!5$4@55-%4B!H;W)D93L*"BTM($%,
M5$52(%5315(@:&]R9&4@5TE42"!005-35T]21"`G<&%S<R<["@H*0U)%051%
M(%1!0DQ%(&AO<F1E7W5S97)S("@*("`@('5S97)?=6ED("`@("`@("`@("`@
M("`@("`@("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!U<V5R7W!A<W,@
M("`@("`@("`@("`@("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@
M=7-E<E]S;V9T7V5X<&ER871I;VY?9&%T92`@($E.5$5'15(L"B`@("!U<V5R
M7VAA<F1?97AP:7)A=&EO;E]D871E("`@24Y414=%4BP*+2T*("`@(%!224U!
M4ED@2T59("AU<V5R7W5I9"D**3L*"D=204Y4(%-%3$5#5"P@24Y315)4+"!5
M4$1!5$4L($1%3$5412!/3B!H;W)D95]U<V5R<R!43R!H;W)D93L*"@I#4D5!
M5$4@5$%"3$4@:&]R9&5?<')E9G,@*`H@("`@<')E9E]U:60@("`@("`@(%9!
M4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('!R969?<V-O<&4@("`@("!605)#
M2$%2*#$V*2!$149!54Q4("<G($Y/5"!.54Q,+`H@("`@<')E9E]N86UE("`@
M("`@(%9!4D-(05(H,S(I($Y/5"!.54Q,+`H@("`@<')E9E]V86QU92`@("`@
M(%1%6%0L"BTM"B`@("!04DE-05)9($M%62`H<')E9E]U:60L('!R969?<V-O
M<&4L('!R969?;F%M92D**3L*"D-214%412!)3D1%6"!P<F5F7W5I9%]I9'@@
M3TX@:&]R9&5?<')E9G,@*'!R969?=6ED*3L*0U)%051%($E.1$58('!R969?
M<V-O<&5?:61X($].(&AO<F1E7W!R969S("AP<F5F7W-C;W!E*3L*"D=204Y4
M(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]P<F5F
M<R!43R!H;W)D93L*"@I#4D5!5$4@5$%"3$4@:&]R9&5?9&%T871R964@*`H@
M("`@9&%T871R965?:60@24Y4($Y/5"!.54Q,+`H@("`@9W)O=7!?=6ED(%9!
M4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('5S97)?=6ED(%9!4D-(05(H,C4U
M*2!.3U0@3E5,3"P*("`@(&1A=&%T<F5E7VYA;64@5D%20TA!4B@R-34I($Y/
M5"!.54Q,+`H@("`@9&%T871R965?<&%R96YT<R!605)#2$%2*#(U-2D@3D]4
M($Y53$PL"B`@("!D871A=')E95]O<F1E<B!)3E0L"B`@("!D871A=')E95]D
M871A(%1%6%0L"B`@("!D871A=')E95]S97)I86QI>F5D(%--04Q,24Y4($1%
M1D%53%0@,"!.3U0@3E5,3"P*"B`@("!04DE-05)9($M%62`H9&%T871R965?
M:60I"BD["@I#4D5!5$4@24Y$15@@9&%T871R965?9&%T871R965?;F%M95]I
M9'@@3TX@:&]R9&5?9&%T871R964@*&1A=&%T<F5E7VYA;64I.PI#4D5!5$4@
M24Y$15@@9&%T871R965?9W)O=7!?:61X($].(&AO<F1E7V1A=&%T<F5E("AG
M<F]U<%]U:60I.PI#4D5!5$4@24Y$15@@9&%T871R965?=7-E<E]I9'@@3TX@
M:&]R9&5?9&%T871R964@*'5S97)?=6ED*3L*0U)%051%($E.1$58(&1A=&%T
M<F5E7V]R9&5R7VED>"!/3B!H;W)D95]D871A=')E92`H9&%T871R965?;W)D
M97(I.PI#4D5!5$4@24Y$15@@9&%T871R965?<V5R:6%L:7IE9%]I9'@@3TX@
M:&]R9&5?9&%T871R964@*&1A=&%T<F5E7W-E<FEA;&EZ960I.PH*"D-214%4
M12!404),12!H;W)D95]D871A=')E95]A='1R:6)U=&5S("@*("`@(&1A=&%T
M<F5E7VED($E.5"!.3U0@3E5,3"P*("`@(&%T=')I8G5T95]N86UE(%9!4D-(
M05(H,C4U*2!.3U0@3E5,3"P*("`@(&%T=')I8G5T95]K97D@5D%20TA!4B@R
M-34I+`H@("`@871T<FEB=71E7W9A;'5E(%1%6%0**3L*"D-214%412!)3D1%
M6"!D871A=')E95]A='1R:6)U=&5?:61X($].(&AO<F1E7V1A=&%T<F5E7V%T
M=')I8G5T97,@*&1A=&%T<F5E7VED*3L*0U)%051%($E.1$58(&1A=&%T<F5E
M7V%T=')I8G5T95]N86UE7VED>"!/3B!H;W)D95]D871A=')E95]A='1R:6)U
M=&5S("AA='1R:6)U=&5?;F%M92D["D-214%412!)3D1%6"!D871A=')E95]A
M='1R:6)U=&5?:V5Y7VED>"!/3B!H;W)D95]D871A=')E95]A='1R:6)U=&5S
M("AA='1R:6)U=&5?:V5Y*3L*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!
M5$4L($1%3$5412!/3B!H;W)D95]D871A=')E92!43R!H;W)D93L*1U)!3E0@
M4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7V1A=&%T
M<F5E7V%T=')I8G5T97,@5$\@:&]R9&4["@H*0U)%051%(%1!0DQ%(&AO<F1E
M7W1O:V5N<R`H"B`@("!T;VME;E]A9&1R97-S("`@(%9!4D-(05(H,3`P*2!.
M3U0@3E5,3"P*("`@('1O:V5N7VED("`@("`@("`@5D%20TA!4B@S,BD@3D]4
M($Y53$PL"B`@("!T;VME;E]T:6UE<W1A;7`@($))1TE.5"!.3U0@3E5,3"P*
M+2T*("`@(%!224U!4ED@2T59("AT;VME;E]A9&1R97-S+"!T;VME;E]I9"D*
M*3L*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H
M;W)D95]T;VME;G,@5$\@:&]R9&4["@H*0U)%051%(%1!0DQ%(&AO<F1E7W9F
M<R`H"B`@("!V9G-?:60@("`@("`@($))1TE.5"!.3U0@3E5,3"P*("`@('9F
M<U]T>7!E("`@("`@4TU!3$Q)3E0@3D]4($Y53$PL"B`@("!V9G-?<&%T:"`@
M("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]N86UE("`@("`@
M5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=F9S7VUO9&EF:65D("!"24=)
M3E0@3D]4($Y53$PL"B`@("!V9G-?;W=N97(@("`@(%9!4D-(05(H,C4U*2!.
M3U0@3E5,3"P*("`@('9F<U]D871A("`@("`@5$585"P*"B`@("!04DE-05)9
M($M%62`@("AV9G-?:60I"BD["@I#4D5!5$4@24Y$15@@=F9S7W!A=&A?:61X
M($].(&AO<F1E7W9F<R`H=F9S7W!A=&@I.PI#4D5!5$4@24Y$15@@=F9S7VYA
M;65?:61X($].(&AO<F1E7W9F<R`H=F9S7VYA;64I.PH*1U)!3E0@4T5,14-4
M+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7W9F<R!43R!H;W)D
M93L*"@I#4D5!5$4@5$%"3$4@:&]R9&5?<V5S<VEO;FAA;F1L97(@*`H@("`@
M<V5S<VEO;E]I9"`@("`@("`@("`@("!605)#2$%2*#,R*2!.3U0@3E5,3"P*
M("`@('-E<W-I;VY?;&%S=&UO9&EF:65D("`@24Y4($Y/5"!.54Q,+`H@("`@
M<V5S<VEO;E]D871A("`@("`@("`@("!415A4+`H@("`@4%))34%262!+15D@
M*'-E<W-I;VY?:60I"BD["@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%
M+"!$14Q%5$4@3TX@:&]R9&5?<V5S<VEO;FAA;F1L97(@5$\@:&]R9&4["@H*
M0U)%051%(%1!0DQ%(&AO<F1E7VAI<W1O<FEE<R`H"B`@("!H:7-T;W)Y7VED
M("`@("`@($))1TE.5"!.3U0@3E5,3"P*("`@(&]B:F5C=%]U:60@("`@("`@
M5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@:&ES=&]R>5]A8W1I;VX@("!6
M05)#2$%2*#,R*2!.3U0@3E5,3"P*("`@(&AI<W1O<GE?=',@("`@("`@0DE'
M24Y4($Y/5"!.54Q,+`H@("`@:&ES=&]R>5]D97-C("`@("!415A4+`H@("`@
M:&ES=&]R>5]W:&\@("`@("!605)#2$%2*#(U-2DL"B`@("!H:7-T;W)Y7V5X
M=')A("`@(%1%6%0L"BTM"B`@("!04DE-05)9($M%62`H:&ES=&]R>5]I9"D*
M*3L*"D-214%412!)3D1%6"!H:7-T;W)Y7V%C=&EO;E]I9'@@3TX@:&]R9&5?
M:&ES=&]R:65S("AH:7-T;W)Y7V%C=&EO;BD["D-214%412!)3D1%6"!H:7-T
M;W)Y7W1S7VED>"!/3B!H;W)D95]H:7-T;W)I97,@*&AI<W1O<GE?=',I.PI#
M4D5!5$4@24Y$15@@:&ES=&]R>5]U:61?:61X($].(&AO<F1E7VAI<W1O<FEE
M<R`H;V)J96-T7W5I9"D["@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%
M+"!$14Q%5$4@3TX@:&]R9&5?:&ES=&]R:65S(%1/(&AO<F1E.PH`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]C<F]N9```````````
M````````````````````````````````````````````````````````````
M`````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q-C$Q
M(#$P-3$U-#,S-S0S(#`R,#(V,0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````C(2]U<W(O;&]C86PO<'-A+V%D;6EN+V)I;B]P
M:'`*/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O<V-R:7!T<R]C<F]N9"QV
M(#$N-"XQ,"XU(#(P,#8O,#8O,38@,#@Z,C0Z,CD@:F%N($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`S+3(P,#8@0VAA<FQE<R!*+B!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"G)E<75I<F5?;VYC
M92`G2&]R9&4O0TQ)+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O4V-H961U
M;&5R+G!H<"<["@HO+R!-86ME('-U<F4@;F\@;VYE(')U;G,@=&AI<R!F<F]M
M('1H92!W96(N"FEF("@A2&]R9&5?0TQ).CIR=6YN:6YG1G)O;4-,22@I*2![
M"B`@("!E>&ET*")-=7-T(&)E(')U;B!F<F]M('1H92!C;VUM86YD(&QI;F5<
M;B(I.PI]"@HO+R!,;V%D('1H92!#3$D@96YV:7)O;FUE;G0@+2!M86ME('-U
M<F4@=&AE<F4G<R!N;R!T:6UE(&QI;6ET+"!I;FET"B\O('-O;64@=F%R:6%B
M;&5S+"!E=&,N"DAO<F1E7T-,23HZ:6YI="@I.PH*+R\@1V5T(&%N(&EN<W1A
M;F-E(&]F('1H92!C<F]N('-C:&5D=6QE<BX*)&1A96UO;B`]("9(;W)D95]3
M8VAE9'5L97(Z.G-I;F=L971O;B@G8W)O;B<I.PH*+R\@3F]W(&%D9"!S;VUE
M(&-R;VX@:F]B<R!T;R!D;RP@;W(@861D('!A<G-I;F<@=&\@<F5A9"!A(&-O
M;F9I9R!F:6QE+@HO+R`D9&%E;6]N+3YA9&1487-K*"=L<R<L("<P+#4L,3`L
M,34L,C`L,S`L-#`@*B`J("H@*B<I.PH*+R\@4W1A<G0@=&AE(&1A96UO;B!G
M;VEN9RX*)&1A96UO;BT^<G5N*"D["@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]T:&5M97-?
M8VAE8VLN<&AP````````````````````````````````````````````````
M`````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#$T-38V(#$P-3$U-#,S-S0S(#`R,C0P,0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````C(2]U<W(O;&]C86PO<'-A+V%D;6EN
M+V)I;B]P:'`*/#]P:'`*+RHJ"B`J(%1H:7,@<V-R:7!T(&1O97,@<V]M92!C
M:&5C:VEN9R!O9B!T:&5M97,L('1O(&UA:V4@<W5R92!I;6%G97,@87)E"B`J
M('-Y;F-H<F]N:7-E9"!A8W)O<W,@=&AE;65S+@H@*@H@*B`D2&]R9&4Z(&AO
M<F1E+W-C<FEP=',O=&AE;65S7V-H96-K+G!H<"QV(#$N,RXQ,"XU(#(P,#8O
M,#0O,3@@,38Z,C8Z,#4@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S
M+3(P,#8@5&AE($AO<F1E(%!R;VIE8W0@*&AT='`Z+R]W=W<N:&]R9&4N;W)G
M+RD*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-87)K;R!$:G5K:6,@
M/&UA<FMO0&]B;&\N8V]M/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("HO"@I`
M9&5F:6YE*"=!551(7TA!3D1,15(G+"!T<G5E*3L*0&1E9FEN92@G2$]21$5?
M0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B<I.PH*+RH@0TQ)(&-H
M96-K<R!A;F0@96YV:7)O;FUE;G0@<V5T=7`@9FER<W0N("HO"G)E<75I<F5?
M;VYC92!(3U)$15]"05-%("X@)R]L:6(O8V]R92YP:'`G.PIR97%U:7)E7V]N
M8V4@)TAO<F1E+T-,22YP:'`G.PH*+RH@36%K92!S=7)E(&YO(&]N92!R=6YS
M('1H:7,@9G)O;2!T:&4@=V5B+B`J+PII9B`H(4AO<F1E7T-,23HZ<G5N;FEN
M9T9R;VU#3$DH*2D@>PH@("`@97AI="@B375S="!B92!R=6X@9G)O;2!T:&4@
M8V]M;6%N9"!L:6YE7&XB*3L*?0H*+RH@1V5T(&%N>2!O<'1I;VYS+B`J+PHD
M<VEM<&QE(#T@9F%L<V4["B1I9VYO<F4@/2!A<G)A>2@I.PII9B`H:7-S970H
M)&%R9W8I*2!["B`@("`O*B!'970@<FED(&]F('1H92!F:7)S="!A<F<@=VAI
M8V@@:7,@=&AE('-C<FEP="!N86UE+B`J+PH@("`@87)R87E?<VAI9G0H)&%R
M9W8I.PH@("`@=VAI;&4@*"1A<F<@/2!A<G)A>5]S:&EF="@D87)G=BDI('L*
M("`@("`@("!I9B`H)&%R9R`]/2`G+2UH96QP)RD@>PH@("`@("`@("`@("!P
M<FEN=%]U<V%G92@I.PH@("`@("`@('T@96QS96EF("@D87)G(#T]("<M<R<I
M('L*("`@("`@("`@("`@)'-I;7!L92`]('1R=64["B`@("`@("`@?2!E;'-E
M:68@*'-T<G!O<R@D87)G+"`G+6DG*2`]/3T@,"D@>PH@("`@("`@("`@("!L
M:7-T*"PD:6=N;W)E6UTI(#T@97AP;&]D92@G/2<L("1A<F<I.PH@("`@("`@
M("`@("`O+R1I9VYO<F5;72`]("1I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@('!R:6YT7W5S86=E*")5;G)E8V]G;FES960@;W!T:6]N("1A<F<B
M*3L*("`@("`@("!]"B`@("!]"GT*"B\J(%-E="!U<"!#3$DN("HO"B1C;&D@
M/2`F;F5W($AO<F1E7T-,22@I.PH*+RH@0VAE8VL@:68@870@;&5A<W0@=&AE
M(')E9VES=')Y(&ES(&%V86EA8FQE+B`J+PII9B`H(4!F:6QE7V5X:7-T<RA(
M3U)$15]"05-%("X@)R]C;VYF:6<O<F5G:7-T<GDN<&AP)RDI('L*("`@("1C
M;&DM/G=R:71E;&XH)&-L:2T^<F5D*"=.;R!(;W)D92!R96=I<W1R>2!F:6QE
M+B<I*3L*("`@(&5X:70["GT*"B\O)&-L:2T^=W)I=&5L;B@D8VQI+3YG<F5E
M;B@G4F5A9&EN9RXN+B<I*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G
M+VQI8B]B87-E+G!H<"<["@HO*B!'970@=&AE(&%P<',@86YD('-T87)T(&1O
M:6YG(&-H96-K<RX@*B\*)&%P<',@/2`D<F5G:7-T<GDM/FQI<W1!<'!S*&%R
M<F%Y*"=H:61D96XG+"`G;F]T;V]L8F%R)RP@)V%C=&EV92<L("=A9&UI;B<I
M*3L*"B\J($=E="!A(&QI<W0@;V8@=&AE;65S+B`J+PHD=&AE;65S(#T@87)R
M87DH*3L*)'1H96UE<U]D:7(@/2`D<F5G:7-T<GDM/F=E="@G=&AE;65S9G,G
M+"`G:&]R9&4G*3L*:68@*"1H86YD;&4@/2!O<&5N9&ER*"1T:&5M97-?9&ER
M*2D@>PH@("`@=VAI;&4@*"1F:6QE(#T@<F5A9&1I<B@D:&%N9&QE*2D@>PH@
M("`@("`@(&EF("@D9FEL92`]/2`G+B<@?'P@)&9I;&4@/3T@)RXN)R!\?"`D
M9FEL92`]/2`G0U93)R!\?`H@("`@("`@("`@("`D9FEL92`]/2`G+G-V;B<@
M?'P*("`@("`@("`@("`@(4!F:6QE7V5X:7-T<R@B)'1H96UE<U]D:7(O)&9I
M;&4O:6YF;RYP:'`B*2!\?`H@("`@("`@("`@("`A0&9I;&5?97AI<W1S*"(D
M=&AE;65S7V1I<B\D9FEL92]G<F%P:&EC<R(I*2!["B`@("`@("`@("`@(&-O
M;G1I;G5E.PH@("`@("`@('T*"B`@("`@("`@+RH@1&]N)W0@8F]T:&5R(&-H
M96-K:6YG('5N;&5S<R!T:&4@=&AE;64@97AP;&EC:71L>2!S=&%T97,@=&AA
M=`H@("`@("`@("`J(&EC;VYS('=I;&P@8F4@<F5P;&%C960@9F]R('1H:7,@
M87!P;&EC871I;VXN("HO"B`@("`@("`@:6YC;'5D92`B)'1H96UE<U]D:7(O
M)&9I;&4O:6YF;RYP:'`B.PH@("`@("`@(&EF("@A:7-S970H)'1H96UE7VEC
M;VYS*2D@>PH@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("!]"@H@("`@
M("`@("\J(%-T;W)E('1H92!A<'!S(&%N9"!T:&5I<B!T:&5M92!D:7)E8W1O
M<FEE<RX@*B\*("`@("`@("!F;W)E86-H("@D=&AE;65?:6-O;G,@87,@)&%P
M<"D@>PH@("`@("`@("`@("`D87!P7W1H96UE<U]D:7(@/2`D<F5G:7-T<GDM
M/F=E="@G=&AE;65S9G,G+"`D87!P*3L*("`@("`@("`@("`@)'1H96UE<ULD
M87!P75LD9FEL95T@/2`B)&%P<%]T:&5M97-?9&ER+R1F:6QE+V=R87!H:6-S
M(CL*("`@("`@("!]"@H@("`@("`@("\J(%5N<V5T('1H:7,L('1O(&UA:V4@
M<W5R92!I="!I<R!C:&5C:V5D('1H92!N97AT('1I;64@87)O=6YD+B`J+PH@
M("`@("`@('5N<V5T*"1T:&5M95]I8V]N<RD["B`@("!]"GT*"F9O<F5A8V@@
M*"1A<'!S(&%S("1A<'`I('L*("`@("\J(%-E="!U<"!S;VUE(&1I<G,N("HO
M"B`@("`D=&AE;65S7V1I<B`]("1R96=I<W1R>2T^9V5T*"=T:&5M97-F<R<L
M("1A<'`I.PH@("`@)&AO<F1E7W1H96UE7V1I<B`]("1T:&5M97-?9&ER("X@
M)R]H;W)D92<["B`@("`D:&]R9&5?:6-O;E]D:7(@/2`D:&]R9&5?=&AE;65?
M9&ER("X@)R]G<F%P:&EC<R<["@H@("`@+RH@4V%N:71Y(&-H96-K(&9O<B!T
M:&4@9&ER96-T;W)I97,N("HO"B`@("!I9B`H(4!F:6QE7V5X:7-T<R@D:&]R
M9&5?=&AE;65?9&ER*2!\?"`A0&9I;&5?97AI<W1S*"1H;W)D95]I8V]N7V1I
M<BDI('L*("`@("`@("!C;VYT:6YU93L*("`@('T*"B`@("`O*B!'970@82!L
M:7-T(&]F(&%L;"!H;W)D92!I;6%G97,@<F5C=7)S:79E;'DN("HO"B`@("`D
M:&]R9&5?:6-O;E]L:7-T(#T@87)R87DH*3L*("`@(')E861$:7)296-U<G-I
M=F5L>2@D:&]R9&5?:6-O;E]D:7(L("1H;W)D95]I8V]N7V1I<BP@)&AO<F1E
M7VEC;VY?;&ES="D["@H@("`@+RH@3&]O<"!T:')O=6=H('1H96UE<R!T:&%T
M(')E<&QA8V4@:6-O;G,@86YD(&-H96-K(&9O<B!D:69F97)E;F-E<RX@*B\*
M("`@(&9O<F5A8V@@*"1T:&5M97-;)&%P<%T@87,@)'1H96UE(#T^("1T:&5M
M95]I8V]N7V1I<BD@>PH@("`@("`@("1T:&5M95]I8V]N7VQI<W0@/2!A<G)A
M>2@I.PH@("`@("`@(')E861$:7)296-U<G-I=F5L>2@D=&AE;65?:6-O;E]D
M:7(L("1T:&5M95]I8V]N7V1I<BP@)'1H96UE7VEC;VY?;&ES="D["@H@("`@
M("`@("\J($-H96-K(&9O<B!I8V]N<R!T:&%T(&%R92!I;B!T:&4@2&]R9&4@
M8F%S92!T:&5M92!A;F0@;F]T(&EN('1H90H@("`@("`@("`J(&-U<W1O;2!T
M:&5M92X@*B\*("`@("`@("`D9&EF9B`](&%R<F%Y7V1I9F8H)&AO<F1E7VEC
M;VY?;&ES="P@)'1H96UE7VEC;VY?;&ES="D["B`@("`@("`@+RH@1&]N)W0@
M8F]T:&5R(')E<&]R=&EN9R!A;GET:&EN9R!F;W(@=&AE;65S('1H870@:&%V
M92!A;&P@=&AE(&AO<F1E"B`@("`@("`@("H@8F%S92!I8V]N<RX@*B\*("`@
M("`@("!I9B`H96UP='DH)&1I9F8I*2!["B`@("`@("`@("`@(&-O;G1I;G5E
M.PH@("`@("`@('T*"B`@("`@("`@)&-L:2T^=W)I=&5L;B@D8VQI+3YR960H
M<W!R:6YT9B@G6R5S72`B)7,B('1H96UE(&UI<W-I;F<@=&AE<V4@:6-O;G,Z
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S=')T;W5P<&5R
M*"1A<'`I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&5M
M92DI*3L*("`@("`@("!F;W)E86-H("@D9&EF9B!A<R`D:6-O;BD@>PH@("`@
M("`@("`@("`D8VQI+3YW<FET96QN*"1I8V]N*3L*("`@("`@("!]"@H@("`@
M("`@("\J($-H96-K(&EF(&]N;'D@9&]I;F<@82!(;W)D92!B87-E('1H96UE
M('1O(&-U<W1O;2!T:&5M92!C:&5C:RX@4VMI<`H@("`@("`@("`J('1H92!R
M979E<G-E(&-H96-K:6YG(&EF('1R=64N("HO"B`@("`@("`@:68@*"1S:6UP
M;&4I('L*("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@?0H*("`@("`@
M("`O*B!#:&5C:R!F;W(@:6-O;G,@=&AA="!A<F4@:6X@=&AE($AO<F1E(&)A
M<V4@=&AE;64@86YD(&YO="!I;B!T:&4*("`@("`@("`@*B!C=7-T;VT@=&AE
M;64N("HO"B`@("`@("`@)&1I9F8@/2!A<G)A>5]D:69F*"1T:&5M95]I8V]N
M7VQI<W0L("1H;W)D95]I8V]N7VQI<W0I.PH@("`@("`@("\J($1O;B=T(&)O
M=&AE<B!R97!O<G1I;F<@86YY=&AI;F<@9F]R('1H96UE<R!T:&%T(&1O;B=T
M(&AA=F4@86YY(&EC;VYS"B`@("`@("`@("H@;6]R92!T:&%N('1H92!B87-E
M('1H96UE+B`J+PH@("`@("`@(&EF("AE;7!T>2@D9&EF9BDI('L*("`@("`@
M("`@("`@8V]N=&EN=64["B`@("`@("`@?0H*("`@("`@("`D8VQI+3YW<FET
M96QN*"1C;&DM/F)L=64H<W!R:6YT9B@G6R5S72`B)7,B('1H96UE(&AA<R!T
M:&5S92!E>'1R82!I8V]N<SHG+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('-T<G1O=7!P97(H)&%P<"DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H96UE*2DI.PH@("`@("`@(&9O<F5A8V@@*"1D:69F
M(&%S("1I8V]N*2!["B`@("`@("`@("`@("1C;&DM/G=R:71E;&XH)&EC;VXI
M.PH@("`@("`@('T*("`@('T*?0H*)&-L:2T^=W)I=&5L;B@D8VQI+3YG<F5E
M;B@G1&]N92XG*2D["F5X:70["@HO*BH*("H@3&]O<',@=&AR;W5G:"!T:&4@
M9&ER96-T;W)Y(')E8W5R<VEV96QY(&%N9"!S=&]R97,@=&AE(&9O=6YD(&=R
M87!H:6-S(&EN=&\*("H@86X@87)R87DN"B`J+PIF=6YC=&EO;B!R96%D1&ER
M4F5C=7)S:79E;'DH)'!A=&@L("1B87-E<&%T:"P@)B1L:7-T*0I["B`@("!G
M;&]B86P@)&EG;F]R93L*"B`@("!I9B`H)&AA;F1L92`](&]P96YD:7(H)'!A
M=&@I*2!["B`@("`@("`@=VAI;&4@*"1F:6QE(#T@<F5A9&1I<B@D:&%N9&QE
M*2D@>PH@("`@("`@("`@("!I9B`H)&9I;&4@/3T@)RXG('Q\("1F:6QE(#T]
M("<N+B<@?'P@)&9I;&4@/3T@)T-64R<*("`@("`@("`@("`@("`@('Q\("1F
M:6QE(#T]("<N<W9N)RD@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES7V1I<B@B)'!A=&@O)&9I
M;&4B*2D@>PH@("`@("`@("`@("`@("`@<F5A9$1I<E)E8W5R<VEV96QY*"(D
M<&%T:"\D9FEL92(L("1B87-E<&%T:"P@)&QI<W0I.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&EG;F]R92!A<R`D
M<&%T=&5R;BD@>PH@("`@("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H
M*"1P871T97)N+"`D9FEL92DI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M8V]N=&EN=64@,CL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`D;&ES=%M=(#T@<W5B<W1R*"1P871H
M+"!S=')L96XH)&)A<V5P871H*2D@+B`B+R1F:6QE(CL*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!C;&]S961I<B@D:&%N9&QE*3L*("`@('T*
M"GT*"F9U;F-T:6]N('!R:6YT7W5S86=E*"1M97-S86=E(#T@)R<I('L*"B`@
M("!I9B`H(65M<'1Y*"1M97-S86=E*2D@>PH@("`@("`@('!R:6YT(")T:&5M
M97-?8VAE8VLN<&AP.B`D;65S<V%G95QN7&XB.PH@("`@?0H*("`@('!R:6YT
M(#P\/%5304=%"E5S86=E.B!T:&5M97-?8VAE8VLN<&AP(%M/4%1)3TY="@I0
M;W-S:6)L92!O<'1I;VYS.@H@("US("`@("`@("`@("`@1&\@;VYL>2!A('-I
M;7!L92!C:&5C:R!F;W(@86YY($AO<F1E(&)A<V4@=&AE;64@9W)A<&AI8W,@
M=&AA=`H@("`@("`@("`@("`@("`@87)E(&UI<W-I;F<@9G)O;2!T:&4@;W1H
M97(@=&AE;65S+"!A;F0@;F\@8VAE8VL@;V8@=&AE"B`@("`@("`@("`@("`@
M("!O<'!O<VET92X*("`M:3U0051415).("`@($EN<V5R="!A;GD@=F%L:60@
M<F5G97@@<&%T=&5R;B!T;R!I9VYO<F4@9FEL97,@9G)O;2!B96EN9PH@("`@
M("`@("`@("`@("`@8VAE8VME9"X@66]U(&-A;B!E;G1E<B!M=6QT:7!L92`M
M:2!O<'1I;VYS('1O(&EN8VQU9&4@;75L=&EP;&4*("`@("`@("`@("`@("`@
M('!A='1E<FYS+B!&;W(@97AA;7!L93H@+6D](B]X8V8D+R!T;R!I9VYO<F4@
M86YY(&]R:6=I;F%L"B`@("`@("`@("`@("`@("!'24U0(&9I;&5S+@H*55-!
M1T4["B`@("!E>&ET.PI]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C
M<FEP=',O8V]U;G1?<V5S<VEO;G,N<&AP````````````````````````````
M```````````````````````````````````````P,#`W-34@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P-#$U,B`Q,#4Q-30S,S<T,R`P,C,P,C,`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````(R$O=7-R+V)I
M;B]P:'`*/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O<V-R:7!T<R]C;W5N
M=%]S97-S:6]N<RYP:'`L=B`Q+C4N,BXS(#(P,#8O,#0O,3@@,38Z,C0Z-3@@
M:F%N($5X<"`D"B`J"B`J(%1H:7,@<V-R:7!T(&-O=6YT<R!T:&4@;G5M8F5R
M(&]F(&%C=&EV92!A=71H96YT:6-A=&5D('5S97(@<V5S<VEO;G,N"B`J"B`J
M($-O;6UA;F0@;&EN92!O<'1I;VYS.@H@*B`@("<M;"<@("!,:7-T('1H92!U
M<V5R;F%M92!O9B!A8W1I=F4@875T:&5N=&EC871E9"!U<V5R<PH@*B`@("<M
M;&PG("!,:7-T('1H92!U<V5R;F%M92!A;F0@;&]G:6X@=&EM92!O9B!A8W1I
M=F4@875T:&5N=&EC871E9"!U<V5R<PH@*B\*"B\O($YO(&%U=&@N"D!D969I
M;F4H)T%55$A?2$%.1$Q%4B<L('1R=64I.PH*+R\@1FEN9"!T:&4@8F%S92!F
M:6QE('!A=&@@;V8@2&]R9&4N"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N
M86UE*%]?1DE,15]?*2`N("<O+BXG*3L*"B\O($1O($-,22!C:&5C:W,@86YD
M(&5N=FER;VYM96YT('-E='5P(&9I<G-T+@IR97%U:7)E7V]N8V4@2$]21$5?
M0D%312`N("<O;&EB+V-O<F4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]#
M3$DN<&AP)SL*"B\O($UA:V4@<W5R92!N;R!O;F4@<G5N<R!T:&ES(&9R;VT@
M=&AE('=E8BX*:68@*"%(;W)D95]#3$DZ.G)U;FYI;F=&<F]M0TQ)*"DI('L*
M("`@(&5X:70H(DUU<W0@8F4@<G5N(&9R;VT@=&AE(&-O;6UA;F0@;&EN95QN
M(BD["GT*"B\O($QO860@=&AE($-,22!E;G9I<F]N;65N="`M(&UA:V4@<W5R
M92!T:&5R92=S(&YO('1I;64@;&EM:70L(&EN:70*+R\@<V]M92!V87)I86)L
M97,L(&5T8RX*2&]R9&5?0TQ).CII;FET*"D["B1C;&D@/2`F;F5W($AO<F1E
M7T-,22@I.PH*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E
M+G!H<"<["@HO*B!-86ME('-U<F4@=&AE<F4G<R!N;R!C;VUP<F5S<VEO;BX@
M*B\*0&]B7V5N9%]C;&5A;B@I.PH*)'1Y<&4@/2`A96UP='DH)&-O;F9;)W-E
M<W-I;VYH86YD;&5R)UU;)W1Y<&4G72D@/PH@("`@)&-O;F9;)W-E<W-I;VYH
M86YD;&5R)UU;)W1Y<&4G72`Z("=B=6EL=&EN)SL*"FEF("@D='EP92`]/2`G
M97AT97)N86PG*2!["B`@("!(;W)D93HZ9F%T86PH4$5!4CHZ<F%I<V5%<G)O
M<B@G4V5S<VEO;B!C;W5N=&EN9R!I<R!N;W0@<W5P<&]R=&5D(&EN('1H92!<
M)V5X=&5R;F%L7"<@4V5S<VEO;DAA;F1L97(@870@=&AI<R!T:6UE+B<I+"!?
M7T9)3$5?7RP@7U],24Y%7U\L(&9A;'-E*3L*?2!E;'-E('L*("`@(')E<75I
M<F5?;VYC92`G2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP)SL*("`@("1?<V5S
M<VEO;E]H86YD;&5R(#T@)E-E<W-I;VY(86YD;&5R.CIS:6YG;&5T;VXH)&-O
M;F9;)W-E<W-I;VYH86YD;&5R)UU;)W1Y<&4G72D["B`@("!I9B`H:7-?82@D
M7W-E<W-I;VY?:&%N9&QE<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@($AO
M<F1E.CIF871A;"A014%2.CIR86ES945R<F]R*'-P<FEN=&8H(DAO<F1E(&ES
M('5N86)L92!T;R!L;V%D('-E<W-I;VX@:&%N9&QE<B!O9B!T>7!E(%PB)7-<
M(BXB+"`D='EP92DI+"!?7T9)3$5?7RP@7U],24Y%7U\L(&9A;'-E*3L*("`@
M('T*"B`@("!I9B`H)&%R9V,@/"`R('Q\("@D87)G=ELQ72`A/2`G+6PG("8F
M("1A<F=V6S%=("$]("<M;&PG*2D@>PH@("`@("`@("1C;W5N="`]("1?<V5S
M<VEO;E]H86YD;&5R+3YC;W5N=$%U=&AE;G1I8V%T9615<V5R<R@I.PH@("`@
M("`@(&EF("AI<U]A*"1C;W5N="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!(;W)D93HZ9F%T86PH)&-O=6YT+"!?7T9)3$5?7RP@7U],24Y%7U\L
M(&9A;'-E*3L*("`@("`@("!]"@H@("`@("`@("1C;&DM/G=R:71E;&XH)&-O
M=6YT*3L*("`@('T@96QS92!["B`@("`@("`@)'5S97)S(#T@)%]S97-S:6]N
M7VAA;F1L97(M/FQI<W1!=71H96YT:6-A=&5D57-E<G,H)&%R9W9;,5T@/3T@
M)RUL;"<I.PH@("`@("`@(&EF("AI<U]A*"1U<V5R<RP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH)'5S97)S+"!?7T9)3$5?
M7RP@7U],24Y%7U\L(&9A;'-E*3L*("`@("`@("!]"@H@("`@("`@(&9O<F5A
M8V@@*"1U<V5R<R!A<R`D=7-E<BD@>PH@("`@("`@("`@("`D8VQI+3YW<FET
M96QN*"1U<V5R*3L*("`@("`@("!]"B`@("!]"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W-C<FEP=',O+FAT86-C97-S````````````````````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`Q-B`Q,#4Q-30S,S<T,R`P
M,C$P,C(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````1&5N>2!F<F]M(&%L;`H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S
M8W)I<'1S+VAT='!?;&]G:6Y?<F5F97(N<&AP````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#$W,30@,3`U,34T,S,W-#,@,#(S,C<U`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O:'1T<%]L;V=I;E]R969E<BYP
M:'`L=B`Q+C,N,3(N,R`R,#`V+S`Q+S`Q(#(Q.C(Y.C`Y(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H87)L97,@2BX@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@2F]N
M(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*<F5Q
M=6ER95]O;F-E("<N+B]L:6(O8F%S92YP:'`G.PH*)&%U=&@@/2`F075T:#HZ
M<VEN9VQE=&]N*"1C;VYF6R=A=71H)UU;)V1R:79E<B==*3L*"B\O($-H96-K
M(&9O<B!(5%10(&%U=&@N"FEF("AE;7!T>2@D7U-%4E9%4ELG4$A07T%55$A?
M55-%4B==*2!\?`H@("`@96UP='DH)%]315)615);)U!(4%]!551(7U!7)UTI
M('Q\"B`@("`A)&%U=&@M/F%U=&AE;G1I8V%T92@D7U-%4E9%4ELG4$A07T%5
M5$A?55-%4B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W!A
M<W-W;W)D)R`]/B`D7U-%4E9%4ELG4$A07T%55$A?4%<G72DI*2!["@H@("`@
M:&5A9&5R*"=75U<M075T:&5N=&EC871E.B!"87-I8R!R96%L;3TB)R`N("1A
M=71H+3YG971087)A;2@G<F5A;&TG*2`N("<B)RD["B`@("!H96%D97(H)TA4
M5%`O,2XP(#0P,2!5;F%U=&AO<FEZ960G*3L*("`@(&5X:70H)T9O<F)I9&1E
M;B<I.PI]"@II9B`H)'5R;"`](%5T:6PZ.F=E=$9O<FU$871A*"=U<FPG*2D@
M>PH@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N("1U<FPI.PI](&5L<V4@>PH@
M("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N($AO<F1E.CIA<'!L:6-A=&EO;E5R
M;"@G;&]G:6XN<&AP)RDI.PI]"@``````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]S8W)I<'1S+VUI9W)A=&5?=7-E<E]C871E9V]R:65S+G!H<```````
M````````````````````````````````````````````````,#`P-S4U(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,3`U-C4@,3`U,34T,S,W-#,@,#(T-C0U
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````",A
M+W5S<B]L;V-A;"]P<V$O861M:6XO8FEN+W!H<"`M<0H\/W!H<`HO*BH*("H@
M)$AO<F1E.B!H;W)D92]S8W)I<'1S+VUI9W)A=&5?=7-E<E]C871E9V]R:65S
M+G!H<"QV(#$N-2XQ,"XQ(#(P,#4O,3`O,3@@,3$Z,S0Z,#`@:F%N($5X<"`D
M"B`J"B`J($$@<V-R:7!T('1O('5P9&%T92!U<V5R<R!P<F5F97)E;F-E<R!T
M;R!C;VUB:6YE('1H96ER(&-A=&5G;W)I97,*("H@86YD(&-A=&5G;W)Y(&-O
M;&]R<R!F<F]M($=E;FEE+"!+<F]N;VQI=&@L($UN96UO+"!A;F0@3F%G(&EN
M=&\@=&AE"B`J(&YE=R!(;W)D92UW:61E('!R969E<F5N8V5S+B!%>'!E8W1S
M('1O(&)E(&=I=F5N(&$@;&ES="!O9B!U<V5R<R!O;@H@*B!35$1)3BP@;VYE
M('5S97)N86UE('!E<B!L:6YE+"!T;R!C;VYV97)T+B!5<V5R;F%M97,@;F5E
M9"!T;R!M871C:`H@*B!T:&4@=F%L=65S('-T;W)E9"!I;B!T:&4@<')E9F5R
M96YC97,@8F%C:V5N9"X*("HO"@HO+R!&:6YD('1H92!B87-E(&9I;&4@<&%T
M:"!O9B!(;W)D92X*0&1E9FEN92@G05542%](04Y$3$52)RP@=')U92D["D!D
M969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXG
M*3L*"B\O($1O($-,22!C:&5C:W,@86YD(&5N=FER;VYM96YT('-E='5P(&9I
M<G-T+@IR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V-O<F4N<&AP
M)SL*<F5Q=6ER95]O;F-E("=(;W)D92]#3$DN<&AP)SL*"B\O($UA:V4@<W5R
M92!N;R!O;F4@<G5N<R!T:&ES(&9R;VT@=&AE('=E8BX*:68@*"%(;W)D95]#
M3$DZ.G)U;FYI;F=&<F]M0TQ)*"DI('L*("`@(&5X:70H(DUU<W0@8F4@<G5N
M(&9R;VT@=&AE(&-O;6UA;F0@;&EN95QN(BD["GT*"B\O($QO860@=&AE($-,
M22!E;G9I<F]N;65N="`M(&UA:V4@<W5R92!T:&5R92=S(&YO('1I;64@;&EM
M:70L(&EN:70*+R\@<V]M92!V87)I86)L97,L(&5T8RX*2&]R9&5?0TQ).CII
M;FET*"D["@IR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A<V4N
M<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]0<F5F<R]#871E9V]R>4UA;F%G
M97(N<&AP)SL*)&-L:2`]("9(;W)D95]#3$DZ.G-I;F=L971O;B@I.PHD875T
M:"`]("9!=71H.CIS:6YG;&5T;VXH)&-O;F9;)V%U=&@G75LG9')I=F5R)UTI
M.PHD8TUA;F%G97(@/2`F;F5W(%!R969S7T-A=&5G;W)Y36%N86=E<B@I.PHD
M87!P<R`]("1R96=I<W1R>2T^;&ES=$%P<',H87)R87DH)VAI9&1E;B<L("=N
M;W1O;VQB87(G+"`G86-T:79E)RP@)V%D;6EN)RDI.PH*+R\@4F5A9"!I;B!T
M:&4@;&ES="!O9B!U<V5R;F%M97,@;VX@4U1$24XN"B1U<V5R<R`](&%R<F%Y
M*"D["G=H:6QE("@A9F5O9BA35$1)3BDI('L*("`@("1L:6YE(#T@9F=E=',H
M4U1$24XI.PH@("`@)&QI;F4@/2!T<FEM*"1L:6YE*3L*("`@(&EF("@A96UP
M='DH)&QI;F4I*2!["B`@("`@("`@)'5S97)S6UT@/2`D;&EN93L*("`@('T*
M?0H*+R\@3&]O<"!T:')O=6=H('5S97)S(&%N9"!C;VYV97)T('!R969S(&9O
M<B!'96YI92P@36YE;6\L($YA9RP@86YD"B\O($MR;VYO;&ET:"X*9F]R96%C
M:"`H)'5S97)S(&%S("1U<V5R*2!["B`@("!E8VAO("=-:6=R871I;F<@<')E
M9G,@9F]R("<@+B`D8VQI+3YB;VQD*"1U<V5R*3L*"B`@("`O+R!3970@)'5S
M97(@87,@=&AE(&-U<G)E;G0@=7-E<BX*("`@("1A=71H+3YS971!=71H*"1U
M<V5R+"!A<G)A>2@I+"`G)RD["@H@("`@+R\@1F5T8V@@8W5R<F5N="!C871E
M9V]R:65S(&%N9"!C;VQO<G,N"B`@("`D8V]L;W)S(#T@)&--86YA9V5R+3YC
M;VQO<G,H*3L*"B`@("`O+R!'96YI92X*("`@(&EF("AI;E]A<G)A>2@G9V5N
M:64G+"`D87!P<RDI('L*("`@("`@("!E8VAO("<@+B!G96YI92<["B`@("`@
M("`@)')E<W5L="`]("1R96=I<W1R>2T^<'5S:$%P<"@G9V5N:64G+"!F86QS
M92D["B`@("`@("`@:68@*"%I<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@)&=?8V%T96=O<FEE<R`](&QI<W1#871E9V]R:65S
M*"=W:7-H7V-A=&5G;W)I97,G*3L*("`@("`@("`@("`@9F]R96%C:"`H)&=?
M8V%T96=O<FEE<R!A<R`D8V%T96=O<GDI('L*("`@("`@("`@("`@("`@("1C
M36%N86=E<BT^861D*"1C871E9V]R>2D["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("!]"@H@("`@+R\@36YE;6\N"B`@("!I9B`H:6Y?87)R87DH)VUN
M96UO)RP@)&%P<',I*2!["B`@("`@("`@96-H;R`G("X@;6YE;6\G.PH@("`@
M("`@("1R97-U;'0@/2`D<F5G:7-T<GDM/G!U<VA!<'`H)VUN96UO)RP@9F%L
M<V4I.PH@("`@("`@(&EF("@A:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("1M7V-A=&5G;W)I97,@/2!L:7-T0V%T96=O<FEE
M<R@G;65M;U]C871E9V]R:65S)RD["B`@("`@("`@("`@("1M7V-O;&]R<R`]
M(&QI<W1#;VQO<G,H)VUE;6]?8V]L;W)S)RD["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1M7V-A=&5G;W)I97,@87,@)&ME>2`]/B`D8V%T96=O<GDI('L*("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D;5]C;VQO<G-;)&ME>5TI*2!["B`@
M("`@("`@("`@("`@("`@("`@)&-O;&]R<ULD8V%T96=O<GE=(#T@)&U?8V]L
M;W)S6R1K97E=.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M)&--86YA9V5R+3YA9&0H)&-A=&5G;W)Y*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@('T*"B`@("`O+R!.86<N"B`@("!I9B`H:6Y?87)R87DH)VYA
M9R<L("1A<'!S*2D@>PH@("`@("`@(&5C:&\@)R`N(&YA9R<["B`@("`@("`@
M)')E<W5L="`]("1R96=I<W1R>2T^<'5S:$%P<"@G;F%G)RP@9F%L<V4I.PH@
M("`@("`@(&EF("@A:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("1N7V-A=&5G;W)I97,@/2!L:7-T0V%T96=O<FEE<R@G=&%S
M:U]C871E9V]R:65S)RD["B`@("`@("`@("`@(&9O<F5A8V@@*"1N7V-A=&5G
M;W)I97,@87,@)&-A=&5G;W)Y*2!["B`@("`@("`@("`@("`@("`D8TUA;F%G
M97(M/F%D9"@D8V%T96=O<GDI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@?0H*("`@("\O($MR;VYO;&ET:"X*("`@(&EF("AI;E]A<G)A>2@G:W)O
M;F]L:71H)RP@)&%P<',I*2!["B`@("`@("`@96-H;R`G("X@:W)O;F]L:71H
M)SL*("`@("`@("`D<F5S=6QT(#T@)')E9VES=')Y+3YP=7-H07!P*"=K<F]N
M;VQI=&@G+"!F86QS92D["B`@("`@("`@:68@*"%I<U]A*"1R97-U;'0L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@)&M?8V%T96=O<FEE<R`](&QI
M<W1#871E9V]R:65S*"=E=F5N=%]C871E9V]R:65S)RD["B`@("`@("`@("`@
M(&EF("AC;W5N="@D:U]C871E9V]R:65S*2D@=F%R7V1U;7`H)&M?8V%T96=O
M<FEE<RD["B`@("`@("`@("`@("1K7V-O;&]R<R`](&QI<W1#;VQO<G,H)V5V
M96YT7V-O;&]R<R<I.PH@("`@("`@("`@("!F;W)E86-H("@D:U]C871E9V]R
M:65S(&%S("1K97D@/3X@)&-A=&5G;W)Y*2!["B`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)&M?8V]L;W)S6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1C;VQO<G-;)&-A=&5G;W)Y72`]("1K7V-O;&]R<ULD:V5Y73L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1C36%N86=E<BT^861D
M*"1C871E9V]R>2D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@
M("`@)&--86YA9V5R+3YS971#;VQO<G,H)&-O;&]R<RD["B`@("`D<')E9G,M
M/G-T;W)E*"D["B`@("`D8VQI+3YW<FET96QN*"D["GT*"B1C;&DM/G=R:71E
M;&XH*3L*)&-L:2T^=W)I=&5L;B@D8VQI+3YG<F5E;B@G1$].12<I*3L*97AI
M=#L*"F9U;F-T:6]N(&QI<W1#871E9V]R:65S*"1P<F5F;F%M92D*>PH@("`@
M9VQO8F%L("1P<F5F<SL*"B`@("`D<W1R:6YG(#T@)'!R969S+3YG971686QU
M92@D<')E9FYA;64I.PH@("`@:68@*&5M<'1Y*"1S=')I;F<I*2!["B`@("`@
M("`@<F5T=7)N(&%R<F%Y*"D["B`@("!]"@H@("`@)&-A=',@/2!E>'!L;V1E
M*"=\)RP@)'-T<FEN9RD["B`@("!F;W)E86-H("@D8V%T<R!A<R`D8V%T*2![
M"B`@("`@("`@;&ES="@D:V5Y+"`D=F%L*2`](&5X<&QO9&4H)SHG+"`D8V%T
M*3L*("`@("`@("`D8V%T96=O<FEE<ULD:V5Y72`]("1V86P["B`@("!]"@H@
M("`@<F5T=7)N("1C871E9V]R:65S.PI]"@IF=6YC=&EO;B!L:7-T0V]L;W)S
M*"1P<F5F;F%M92D*>PH@("`@9VQO8F%L("1P<F5F<SL*"B`@("`D<W1R:6YG
M(#T@)'!R969S+3YG971686QU92@D<')E9FYA;64I.PH@("`@:68@*&5M<'1Y
M*"1S=')I;F<I*2!["B`@("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@("!]"B`@
M("`D8V]L<R`](&5X<&QO9&4H)WPG+"`D<W1R:6YG*3L*("`@("1C;VQO<G,@
M/2!A<G)A>2@I.PH@("`@9F]R96%C:"`H)&-O;',@87,@)&-O;"D@>PH@("`@
M("`@(&QI<W0H)&ME>2P@)'9A;"D@/2!E>'!L;V1E*"<Z)RP@)&-O;"D["B`@
M("`@("`@)&-O;&]R<ULD:V5Y72`]("1V86P["B`@("!]"@H@("`@<F5T=7)N
M("1C;VQO<G,["GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP
M=',O<F5M;W9E7W!R969S+G!H<```````````````````````````````````
M```````````````````````````````````P,#`W-34@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P-#8R,B`Q,#4Q-30S,S<T,R`P,C(T-#,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````(R$O=7-R+VQO8V%L
M+W!S82]A9&UI;B]B:6XO<&AP"CP_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E
M+W-C<FEP=',O<F5M;W9E7W!R969S+G!H<"QV(#$N,RXQ,"XW(#(P,#8O,#0O
M,3@@,38Z,C4Z,S$@:F%N($5X<"`D"B`J"B`J(%1H:7,@<V-R:7!T(')E;6]V
M97,@82!P<F5F(&9R;VT@=7-E<G,G('-E='1I;F=S+B!(96QP<R!W:&5N(&$@
M<V5T=&EN9R!I<PH@*B!T;R!B92!M;W9E9"!F<F]M(&QO8VME9"`](&9A;'-E
M+"!T;R!L;V-K960@/2!T<G5E(&%N9"!T:&5R92!H879E(&%L<F5A9'D*("H@
M8F5E;B!P<F5F<R!S970@8GD@=&AE('5S97)S+@H@*B\*"B\J*@H@*BH@4V5T
M('1H:7,@=&\@=')U92!I9B!Y;W4@=V%N="!$0B!M;V1I9FEC871I;VYS(&1O
M;F4N"B`J*B\*)&QI=F4@/2!F86QS93L*"B\O($YO(&%U=&@N"D!D969I;F4H
M)T%55$A?2$%.1$Q%4B<L('1R=64I.PH*+R\@1FEN9"!T:&4@8F%S92!F:6QE
M('!A=&@@;V8@2&]R9&4N"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE
M*%]?1DE,15]?*2`N("<O+BXG*3L*"B\O($1O($-,22!C:&5C:W,@86YD(&5N
M=FER;VYM96YT('-E='5P(&9I<G-T+@IR97%U:7)E7V]N8V4@2$]21$5?0D%3
M12`N("<O;&EB+V-O<F4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]#3$DN
M<&AP)SL*"B\O($UA:V4@<W5R92!N;R!O;F4@<G5N<R!T:&ES(&9R;VT@=&AE
M('=E8BX*:68@*"%(;W)D95]#3$DZ.G)U;FYI;F=&<F]M0TQ)*"DI('L*("`@
M(&5X:70H(DUU<W0@8F4@<G5N(&9R;VT@=&AE(&-O;6UA;F0@;&EN95QN(BD[
M"GT*"B\O($QO860@=&AE($-,22!E;G9I<F]N;65N="`M(&UA:V4@<W5R92!T
M:&5R92=S(&YO('1I;64@;&EM:70L(&EN:70*+R\@<V]M92!V87)I86)L97,L
M(&5T8RX*2&]R9&5?0TQ).CII;FET*"D["B1C;&D@/2`F;F5W($AO<F1E7T-,
M22@I.PH*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H
M<"<["G)E<75I<F5?;VYC92`G2&]R9&4O1&%T851R964N<&AP)SL*<F5Q=6ER
M95]O;F-E("=(;W)D92]'<F]U<"YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E
M+U-H87)E+G!H<"<["@HO*B!-86ME('-U<F4@=&AE<F4G<R!N;R!C;VUP<F5S
M<VEO;BX@*B\*;V)?96YD7V-L96%N*"D["@H*)'-C;W!E(#T@)&-L:2T^<')O
M;7!T*%\H(D5N=&5R('9A;'5E(&9O<B!P<F5F7W-C;W!E.B(I*3L*)&YA;64@
M/2`D8VQI+3YP<F]M<'0H7R@B16YT97(@=F%L=64@9F]R('!R969?;F%M93HB
M*2D["@HO*B!/<&5N('1H92!D871A8F%S92X@*B\*)&1B(#T@)D1".CIC;VYN
M96-T*"1C;VYF6R=S<6PG72D["FEF("AI<U]A*"1D8BP@)U!%05)?17)R;W(G
M*2D@>PH@("!V87)?9'5M<"@D9&(I.R!E>&ET.PI]"@HO+R!3970@1$(@<&]R
M=&%B:6QI='D@;W!T:6]N<RX*<W=I=&-H("@D9&(M/G!H<'1Y<&4I('L*8V%S
M92`G;7-S<6PG.@H@("`@)&1B+3YS971/<'1I;VXH)W!O<G1A8FEL:71Y)RP@
M1$)?4$]25$%"24Q)5%E?3$]715)#05-%('P@1$)?4$]25$%"24Q)5%E?15)2
M3U)3('P@1$)?4$]25$%"24Q)5%E?4E1224TI.PH@("`@8G)E86L["F1E9F%U
M;'0Z"B`@("`D9&(M/G-E=$]P=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]03U)4
M04))3$E465],3U=%4D-!4T4@?"!$0E]03U)404))3$E465]%4E)/4E,I.PI]
M"@II9B`H)&QI=F4I('L*("`@("1S<6P@/2`G1$5,151%($923TT@:&]R9&5?
M<')E9G,@5TA%4D4@<')E9E]S8V]P92`](#\@04Y$('!R969?;F%M92`](#\G
M.PH@("`@)'9A;'5E<R`](&%R<F%Y*"1S8V]P92P@)&YA;64I.PH@("`@)')E
M<W5L="`]("1D8BT^9V5T06QL*"1S<6PL("1V86QU97,I.PH@("`@:68@*&ES
M7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@('9A<E]D=6UP
M*"1R97-U;'0I.PH@("`@?2!E;'-E:68@*&5M<'1Y*"1R97-U;'0I*2!["B`@
M("`@("`@)&-L:2T^=W)I=&5L;BAS<')I;G1F*%\H(DYO('!R969E<F5N8V4@
M7"(E<UPB(&9O=6YD(&EN('-C;W!E(%PB)7-<(BXB*2P@)&YA;64L("1S8V]P
M92DI.PH@("`@?2!E;'-E('L*("`@("`@("`D8VQI+3YW<FET96QN*'-P<FEN
M=&8H7R@B4')E9F5R96YC97,@7"(E<UPB(&1E;&5T960@:6X@<V-O<&4@7"(E
M<UPB+B(I+"`D;F%M92P@)'-C;W!E*2D["B`@("!]"GT@96QS92!["B`@("`D
M<W%L(#T@)U-%3$5#5"`J($923TT@:&]R9&5?<')E9G,@5TA%4D4@<')E9E]S
M8V]P92`](#\@04Y$('!R969?;F%M92`](#\G.PH@("`@)'9A;'5E<R`](&%R
M<F%Y*"1S8V]P92P@)&YA;64I.PH@("`@)')E<W5L="`]("1D8BT^9V5T06QL
M*"1S<6PL("1V86QU97,I.PH@("`@:68@*&5M<'1Y*"1R97-U;'0I*2!["B`@
M("`@("`@)&-L:2T^=W)I=&5L;BAS<')I;G1F*%\H(DYO('!R969E<F5N8V4@
M7"(E<UPB(&9O=6YD(&EN('-C;W!E(%PB)7-<(BXB*2P@)&YA;64L("1S8V]P
M92DI.PH@("`@?2!E;'-E('L*("`@("`@("!V87)?9'5M<"@D<F5S=6QT*3L*
M("`@('T*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W-C<FEP=',O<V5T=7`N<&AP````````````````````````````
M```````````````````````````````````````````````````P,#`W-34@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-#4T-"`Q,#4Q-30S,S<T,R`P,C$Q
M,3(`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M(R$O=7-R+VQO8V%L+W!S82]A9&UI;B]B:6XO<&AP"CP_<&AP"B\J*@H@*B!4
M:&4@;6%I;B!(;W)D92!S971U<"!S8W)I<'0@=VAI8V@@86QL;W=S(&9O<B!A
M('-T97`@8GD@<W1E<"!S971U<`H@*B!O<B!R96-O;F9I9W5R871I;VX@;V8@
M82!(;W)D92!I;G-T86QL871I;VXN"B`J"B`J("1(;W)D93H@:&]R9&4O<V-R
M:7!T<R]S971U<"YP:'`L=B`Q+C(U+C$P+C$P(#(P,#8O,#4O,3@@,34Z-#<Z
M,S(@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-87)K
M;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*B!#;W!Y<FEG:'0@,C`P,RTR
M,#`V($-H87)L97,@2BX@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36%R:V\@1&IU:VEC(#QM87)K
M;T!O8FQO+F-O;3X*("H@0&%U=&AO<B`@0VAA<FQE<R!*+B!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J+PH*
M0&1E9FEN92@G05542%](04Y$3$52)RP@=')U92D["D!D969I;F4H)TA/4D1%
M7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXG*3L*<F5Q=6ER95]O
M;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]C;W)E+G!H<"<["G)E<75I<F5?;VYC
M92`G2&]R9&4O0TQ)+G!H<"<["@HD8VQI(#T@;F5W($AO<F1E7T-,22@I.PH*
M+RH@0VAE8VL@9F]R(&-O;F9I9R!F:6QE<RX@*B\*)&9I;&5S(#T@87)R87DH
M)V-O;F8N<&AP)RP*("`@("`@("`@("`@("`@)VUI;65?9')I=F5R<RYP:'`G
M+`H@("`@("`@("`@("`@("`G;FQS+G!H<"<L"B`@("`@("`@("`@("`@("=P
M<F5F<RYP:'`G+`H@("`@("`@("`@("`@("`G<F5G:7-T<GDN<&AP)RD["F9O
M<F5A8V@@*"1F:6QE<R!A<R`D9FEL96YA;64I('L*("`@("1F:6QE(#T@2$]2
M1$5?0D%312`N("<O8V]N9FEG+R<@+B`D9FEL96YA;64["B`@("!I9B`H9FEL
M95]E>&ES=',H)&9I;&4I*2!["B`@("`@("`@8VQI7VQO9RAS<')I;G1F*%\H
M(D9I;&4@7"(E<UPB(&ES(&%V86EL86)L92XB*2P@)&9I;&5N86UE*2P@)VUE
M<W-A9V4G*3L*("`@("`@("!C;VYT:6YU93L*("`@('T*"B`@("!C;&E?;&]G
M*'-P<FEN=&8H7R@B1FEL92!<(B5S7"(@:7,@;6ES<VEN9RXB*2P@)&9I;&5N
M86UE*2P@)W=A<FYI;F<G*3L*"B`@("`D9&ES=&9I;&4@/2`D9FEL92`N("<N
M9&ES="<["B`@("!I9B`H9FEL95]E>&ES=',H)&1I<W1F:6QE*2D@>PH@("`@
M("`@("1C<F5A=&5?8V]N9FEG(#T@)&-L:2T^<')O;7!T*'-P<FEN=&8H7R@B
M0W)E871E(%PB)7-<(B!F<F]M(&1E9F%U;'1S(&YO=S\B*2P@)&9I;&5N86UE
M*2P@87)R87DH)WDG(#T^(%\H(EEE<R(I+"`G;B<@/3X@7R@B3F\B*2DI.PH@
M("`@("`@(&EF("@D8W)E871E7V-O;F9I9R`]/2`G>2<I('L*("`@("`@("`@
M("`@:68@*"%C;W!Y*"1D:7-T9FEL92P@)&9I;&4I*2!["B`@("`@("`@("`@
M("`@("`D8VQI+3YF871A;"AS<')I;G1F*%\H(D-O<'EI;F<@7"(E,21S+F1I
M<W1<(B!T;R!<(B4Q)'-<(B!F86EL960N($-H96-K('EO=7(@:6YS=&%L;&%T
M:6]N+B(I+"`D9FEL96YA;64I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!C;&E?;&]G*'-P<FEN=&8H7R@B1FEL92`E<R!C<F5A=&5D+B(I+"`D9FEL
M96YA;64I+"`G<W5C8V5S<R<I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1C;&DM/F9A=&%L*'-P<FEN=&8H7R@B66]U(&YE960@=&AE(%PB)7-<
M(B!F:6QE('1O(&-O;G1I;G5E('-E='5P(&%N9"!T;R!U<V4@2&]R9&4N(BDL
M("1F:6QE;F%M92DI.PH@("`@("`@('T*("`@('T@96QS92!["B`@("`@("`@
M)&-L:2T^9F%T86PH<W!R:6YT9BA?*")#86YN;W0@9FEN9"!<(B5S7"(L(&-H
M96-K('EO=7(@:6YS=&%L;&%T:6]N+B(I+"`D9&ES=&9I;&4I*3L*("`@('T*
M?0H*8VQI7VQO9RA?*"));FET:6%L('-E='5P(&-O;7!L971E9"X@3F]W(&-O
M;G1I;G5E('1H92!S971U<"!W:71H('EO=7(@8G)O=W-E<BP@9V\@=&\Z(&AT
M='`Z+R\\66]U<B!(;W)D92!I;G-T86QL(%523#XO861M:6XO(BDL("=S=6-C
M97-S)RD["F5X:70["@HO*BH*("H@5W)A<"!T:&4@;65S<V%G97,@=VET:"!A
M;B!I;F1E;G0L(&YE871E<B!S8W)E96X@9&ES<&QA>2X*("HO"F9U;F-T:6]N
M(&-L:5]L;V<H)&UE<W-A9V4L("1T>7!E(#T@)VUE<W-A9V4G*0I["B`@("`D
M;65S<V%G92`]('=O<F1W<F%P*"1M97-S86=E+"`V.2P@(EQN("`@("`@("`@
M("`B*3L*("`@("1'3$]"04Q36R=C;&DG72T^;65S<V%G92@D;65S<V%G92P@
M)V-L:2XG("X@)'1Y<&4I.PI]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O=&5M<"UC;&5A;G5P+F-R;VX`
M````````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S`P,R`Q,#4Q
M-30S,S<T,R`P,C(U,#``(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````(R$O8FEN+W-H"@HC(%1H:7,@:7,@86X@97AA;7!L92!C
M<F]N(&IO8B!S:&5L;"!S8W)I<'0@=VAI8V@@=VEL;"!C;&5A;B!U<"!A;GD*
M(R!T96UP;W)A<GD@9FEL97,@=VAI8V@@;6%Y(&=E="!S=')A;F1E9"!B>2!(
M;W)D92!U<V5R<R!I;B!T:&4*(R!W96)S97)V97(G<R!T96UP;W)A<GD@9&ER
M96-T;W)Y+@HC"B,@66]U(&UA>2!H879E('1O(&-H86YG92`O=&UP('1O(&%N
M;W1H97(@;&]C871I;VX@9&5P96YD:6YG(&]N('EO=7(*(R!C;VYF:6=U<F%T
M:6]N+B`@3W1H97(@;6]D:69I8V%T:6]N<R!M87D@86QS;R!B92!R97%U:7)E
M9"X*(PHC(%1H:7,@<V-R:7!T(&ES('!R;W9I9&5D(&%S+6ES(&%N9"!I<R!T
M;R!B92!U<V5D(&%T('EO=7(@;W=N(')I<VLN(`HC($AO<F1E(&%N9"!T:&4@
M875T:&]R<R!A8V-E<'0@;F\@<F5S<&]N<VEB:6QI='D@9F]R(&%N>2!D86UA
M9V5S(&]R"B,@;&]S97,@8V%U<V5D(&)Y('1H:7,@<V-R:7!T('=H971H97(@
M:6YD:7)E8W0L(&EN8VED96YT86PL(&]R"B,@8V]N<V5Q=65N=&EA;"P@('=H
M971H97(@;W(@;F]T('-U8V@@9&%M86=E<R!C;W5L9"!B92!F;W)S965N+@HC
M"B,@2&]W('1O('5S92!T:&ES('-C<FEP="!W:6QL(&1E<&5N9"!O;B!Y;W5R
M('-Y<W1E;2X@($9O<B!S;VUE('-Y<W1E;7,L"B,@:70@:7,@87,@<VEM<&QY
M(&%S('!U='1I;F<@=&AI<R!F:6QE(&EN('1H92`O971C+V-R;VXN9&%I;'D@
M9&ER96-T;W)Y+@HC($9O<B!O=&AE<G,L(&UO<F4@;W(@9&EF9F5R96YT('-E
M='5P('=I;&P@8F4@<F5Q=6ER960N("!3964@=&AE"B,@9&]C=6UE;G1A=&EO
M;B!F;W(@>6]U<B!S>7-T96US(&IO8B!S8VAE9'5L97(@9F]R(&UO<F4@:6YF
M;W)M871I;VXN"B,*"B,@5&AE(&QO8V%T:6]N(&]F(%!(4"=S('1E;7!O<F%R
M>2!D:7)E8W1O<GD*5$U07T1)4CTO=&UP"@H*(R!-4U=O<F0@871T86-H;65N
M=',@*&=E;F5R871E9"!B>2!T:&4@35-W;W)D('9I97=E<BD*9F]R($U35T]2
M1%]&24Q%(&EN(&!F:6YD("1435!?1$E2("UT>7!E(&8@+6YA;64@;7-W;W)D
M7"H@+6-T:6UE("LR(&`[(&1O"@ER;2`M9B`D35-73U)$7T9)3$4*9&]N90H*
M(R!)35`@871T86-H;65N=',*9F]R($E-4%]&24Q%(&EN(&!F:6YD("1435!?
M1$E2("UT>7!E(&8@+6YA;64@:6UP871T7"H@+6-T:6UE("LR(&`[(&1O"@ER
M;2`M9B`D24U07T9)3$4*9&]N90H*(R!+;'5T>B!T96UP;W)A<GD@9FEL97,*
M9F]R($M,551:7T9)3$4@:6X@8&9I;F0@)%1-4%]$25(@+71Y<&4@9B`M;F%M
M92!+;'5T>EPJ("UC=&EM92`K,B!@.R!D;PH)<FT@+68@)$M,551:7T9)3$4*
M9&]N90H*(R!3<&5L;"!C:&5C:VEN9R!T96UP;W)A<GD@9FEL97,*9F]R(%-0
M14Q,7T9)3$4@:6X@8&9I;F0@)%1-4%]$25(@+71Y<&4@9B`M;F%M92!S<&5L
M;%PJ("UC=&EM92`K,B!@.R!D;PH)<FT@+68@)%-014Q,7T9)3$4*9&]N90H*
M(R!61E,@=&5M<&]R87)Y(&9I;&5S"F9O<B!)35!?1DE,12!I;B!@9FEN9"`D
M5$U07T1)4B`M='EP92!F("UN86UE('9F<UPJ("UC=&EM92`K,B!@.R!D;PH)
M<FT@+68@)$E-4%]&24Q%"F1O;F4*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]S8W)I<'1S+W-E=%]P97)M<RYS:```````````````
M````````````````````````````````````````````````````````````
M,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,V,#$@,3`U,34T,S,W
M-#,@,#(Q-38W`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````",A+V)I;B]S:`HC"B,@<V5T7W!E<FUS+G-H("T@2F]N(%!A<FES
M92`\:F]N0&-S:"YR:70N961U/@HC"B,@)$AO<F1E.B!H;W)D92]S8W)I<'1S
M+W-E=%]P97)M<RYS:"QV(#$N-R`R,#`Q+S`T+S$U(#`Q.C4U.C,R(&-H=6-K
M($5X<"`D"@HC(")$86YG97)O=7,B(%!(4"!S8W)I<'1S"B,*1$%.1T523U53
M7T9)3$53/2)T97-T+G!H<"(*"B,@1&5F875L="!N;VXM=V5B('-E<G9E<B!U
M<V5R('=H;R!W:6QL(&]W;B!T:&4@=')E92X*(PI/5TY%4CUR;V]T"@HC($EN
M=')O9'5C=&]R>2!T97AT"B,*8V%T(#P\($5/1@H*5&AI<R!S8W)I<'0@=VEL
M;"!S970@=&AE('!E<FUI<W-I;VYS(&]N('EO=7(@2&]R9&4*=')E92!S;R!T
M:&%T('1H92!F:6QE<R!W:6QL(&)E(&%C8V5S<VEB;&4@8GD@=&AE('=E8@IS
M97)V97(N"@I9;W4@8V%N(&-A;F-E;"!T:&ES('-C<FEP="!A="!A;GD@=&EM
M92!U<VEN9R!#=')L+4,N"@I%3T8*"B,@5F5R:69Y('1H870@=V4G<F4@870@
M=&AE('1O<"!O9B!T:&4@2&]R9&4@=')E92X*(PIP=V0*96-H;PIE8VAO("UN
M("))<R!T:&ES(&1I<F5C=&]R>2!T:&4@=&]P(&]F('EO=7(@2&]R9&4@:6YS
M=&%L;&%T:6]N/R!;>2Q.72`B"G)E860@4D534$].4T4@"FEF(%L@(B1215-0
M3TY312(@(3T@(GDB("UA("(D4D534$].4T4B("$](")9(B!=.R!T:&5N"B`@
M("!E8VAO"B`@("!E8VAO("UN(")%;G1E<B!Y;W5R($AO<F1E(&1I<F5C=&]R
M>3H@(@H@("`@<F5A9"!$25(@(`H):68@6R`B>"1$25(B(#T@(G@B(%T[('1H
M96X*"0EE8VAO(")%>&ET:6YG+BXN(@H)"65X:70*"65L<V4*("`@(`EC9"`D
M1$E2"@EF:0IF:0IE8VAO"@HC($=E="!T:&4@=V5B('-E<G9E<B=S(&=R;W5P
M+@HC"F5C:&\@+6X@(E5N9&5R('=H870@9W)O=7`@9&]E<R!T:&4@=V5B('!R
M;V-E<W,@<G5N/R!;;F]B;V1Y72`B"G)E860@5T5"7T=23U50"FEF(%L@(G@D
M5T5"7T=23U50(B`](")X(B!=.R!T:&5N"B`@("!714)?1U)/55`](FYO8F]D
M>2(@"F9I"@HC($%S:R!B969O<F4@<')O8V5E9&EN9RX*(PIE8VAO"F5C:&\@
M+6X@(E!R;V-E960@=VET:"!C:&%N9VEN9R!O=VYE<G-H:7`@86YD('!E<FUI
M<W-I;VYS/R!;>2Q.72`B"G)E860@4D534$].4T4@"FEF(%L@(B1215-03TY3
M12(@(3T@)WDG("UA("(D4D534$].4T4B("$]("=9)R!=.R!T:&5N"B`@("!E
M8VAO(")%>&ET:6YG+BXN(@H@("`@97AI=`IF:0H*(R!3970@=&AE('5S97(@
M86YD(&=R;W5P(&]W;F5R<VAI<"!R96-U<G-I=F5L>2X*(PIE8VAO"F5C:&\@
M+6X@(E-E='1I;F<@;W=N97)S:&EP(')E8W5R<VEV96QY+BXN("(*8VAO=VX@
M+5(@)$]73D52("X*8VAG<G`@+5(@)%=%0E]'4D]54"`N"F5C:&\@(F1O;F4N
M(@H*(R!3970@=&AE('!E<FUI<W-I;VYS(&]N(&9I;&5S("@P-C0P*2!A;F0@
M9&ER96-T;W)I97,@*#`W-3`I+@HC"F5C:&\@+6X@(E-E='1I;F<@<&5R;6ES
M<VEO;G,@<F5C=7)S:79E;'DN+BX@(@IF:6YD("X@+71Y<&4@9B`M97AE8R!C
M:&UO9"`P-C0P('M](%P["F9I;F0@+B`M='EP92!D("UE>&5C(&-H;6]D(#`W
M-3`@>WT@7#L*96-H;R`B9&]N92XB"@HC($1I<V%B;&4@86YY(")D86YG97)O
M=7,B(%!(4"!S8W)I<'1S(&EN('1H92!D:7-T<FEB=71I;VX@*#`P,#`I+@HC
M"F5C:&\@+6X@(D1I<V%B;&EN9R!P;W1E;G1I86QL>2!<(F1A;F=E<F]U<UPB
M(%!(4"!S8W)I<'1S+BXN("(*9F]R($9)3$4@:6X@)$1!3D=%4D]54U]&24Q%
M4SL@9&\*"6EF(%L@+68@)$9)3$4@73L@=&AE;@H)"6-H;6]D(#`P,#`@)$9)
M3$4*"69I"F1O;F4*96-H;R`B9&]N92XB"@HC(%-A>2!G;V]D+6)Y92X*(PIE
M8VAO"F5C:&\@(DEF('EO=2!R96-E:79E9"!A;GD@97)R;W)S+"!Y;W4@;6%Y
M(&YO="!H879E('-U9F9I8VEE;G0@86-C97-S(@IE8VAO(")T;R!C:&%N9V4@
M9FEL92!O=VYE<G-H:7`@86YD('!E<FUI<W-I;VYS+B(*96-H;PH`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<V-R:7!T<R]C<F5A=&4M<WEM;&EN:W,N<&AP````````````
M`````````````````````````````````````````````````````#`P,#<U
M-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$W,S8R(#$P-3$U-#,S-S0S(#`R
M,S`V-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```C(2]U<W(O;&]C86PO<'-A+V%D;6EN+V)I;B]P:'`*/#]P:'`*+RHJ"B`J
M(%1H:7,@<V-R:7!T(&-R96%T97,@<V]F=&QI;FMS('1O('1H92!L:6)R87)Y
M(&9I;&5S('EO=2!R971R:65V960@9G)O;0H@*B!T:&4@0U93(")F<F%M97=O
M<FLB(&UO9'5L92X*("H*("H@270@8W)E871E<R!T:&4@<V%M92!D:7)E8W1O
M<GD@<W1R=6-T=7)E('1H92!P86-K86=E<R!W;W5L9"!H879E(&EF('1H97D*
M("H@=V5R92!I;G-T86QL960@=VET:"`B<&5A<B!I;G-T86QL('!A8VMA9V4N
M>&UL(BX*("H@1F]R(&-R96%T:6YG('1H:7,@<W1R=6-T=7)E(&ET('5S97,@
M=&AE(&EN9F]R;6%T:6]N(&=I=F5N(&EN('1H90H@*B!P86-K86=E+GAM;"!F
M:6QE<R!I;G-I9&4@96%C:"!P86-K86=E(&1I<F5C=&]R>2X*("H*("H@)$AO
M<F1E.B!H;W)D92]S8W)I<'1S+V-R96%T92US>6UL:6YK<RYP:'`L=B`Q+C$T
M+C$P+C<@,C`P-B\P,2\P,2`R,3HR.3HP.2!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#(@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN
M9RYD93X*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!*86X@4V-H;F5I9&5R(#QJ
M86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B!7;VQF
M<F%M($MR:65S:6YG(#QW;VQF<F%M0&MR:65S:6YG+F1E/@H@*B!`875T:&]R
M($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!S:6YC92!(;W)D
M92`S+C`*("HO"@HO+R!&:6YD('1H92!B87-E(&9I;&4@<&%T:"!O9B!(;W)D
M92X*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@
M)R\N+B<I.PH*+R\@0V]N9FEG=7)A=&EO;BX*+R\@16YT97(@9&ER96-T;W)I
M97,@=VET:&]U="!T<F%I;&EN9R!S;&%S:&5S+@H*+R\@5&AE(&1I<F5C=&]R
M>2!W:71H('1H92!#5E,@8VAE8VMO=70N"B1S<F-$:7(@/2!(3U)$15]"05-%
M("X@)R]F<F%M97=O<FLG.PH*+R\@5&AE(&1I<F5C=&]R>2!W:&5R92!T:&4@
M<V]F=&QI;FMS(&%R92!C<F5A=&5D+@HO+R!4:&ES(&ES(&%L<V\@=&AE(&1I
M<F5C=&]R>2!W:&EC:"!Y;W4@<VAO=6QD('!U="!I;B!Y;W5R(&EN8VQU9&4@
M<&%T:`HO+R!A9G1E<B!C<F5A=&EN9R!T:&4@;&EN:W,N"B1D97-T1&ER(#T@
M2$]21$5?0D%312`N("<O;&EB<R<["@HD8V]P>2`](&9A;'-E.PH*:68@*&ES
M<V5T*"1A<F=V*2D@>PH@("`@+RH@1V5T(')I9"!O9B!T:&4@9FER<W0@87)G
M('=H:6-H(&ES('1H92!S8W)I<'0@;F%M92X@*B\*("`@(&%R<F%Y7W-H:69T
M*"1A<F=V*3L*("`@('=H:6QE("@D87)G(#T@87)R87E?<VAI9G0H)&%R9W8I
M*2!["B`@("`@("`@:68@*"1A<F<@/3T@)RTM:&5L<"<I('L*("`@("`@("`@
M("`@<')I;G1?=7-A9V4H*3L*("`@("`@("!](&5L<V5I9B`H)&%R9R`]/2`G
M+2UC;W!Y)RD@>PH@("`@("`@("`@("`D8V]P>2`]('1R=64["B`@("`@("`@
M?2!E;'-E:68@*'-T<G-T<B@D87)G+"`G+2US<F,G*2D@>PH@("`@("`@("`@
M("!L:7-T*"PD<W)C1&ER*2`](&5X<&QO9&4H)STG+"`D87)G*3L*("`@("`@
M("!](&5L<V5I9B`H<W1R<W1R*"1A<F<L("<M+61E<W0G*2D@>PH@("`@("`@
M("`@("!L:7-T*"PD9&5S=$1I<BD@/2!E>'!L;V1E*"<])RP@)&%R9RD["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<')I;G1?=7-A9V4H(E5N<F5C
M;V=N:7-E9"!O<'1I;VX@)&%R9R(I.PH@("`@("`@('T*("`@('T*?0H*+R\@
M1&\@0TQ)(&-H96-K<R!A;F0@96YV:7)O;FUE;G0@<V5T=7`@9FER<W0N"G)E
M<75I<F5?;VYC92`D<W)C1&ER("X@)R]#3$DO0TQ)+G!H<"<["@HO+R!-86ME
M('-U<F4@;F\@;VYE(')U;G,@=&AI<R!F<F]M('1H92!W96(N"FEF("@A2&]R
M9&5?0TQ).CIR=6YN:6YG1G)O;4-,22@I*2!["B`@("!E>&ET*")-=7-T(&)E
M(')U;B!F<F]M('1H92!C;VUM86YD(&QI;F5<;B(I.PI]"@HO+R!,;V%D('1H
M92!#3$D@96YV:7)O;FUE;G0@+2!M86ME('-U<F4@=&AE<F4G<R!N;R!T:6UE
M(&QI;6ET+"!I;FET"B\O('-O;64@=F%R:6%B;&5S+"!E=&,N"DAO<F1E7T-,
M23HZ:6YI="@I.PH*0&EN8VQU9&5?;VYC92`G5')E92]4<F5E+G!H<"<["FEF
M("@A8VQA<W-?97AI<W1S*"=4<F5E)RDI('L*("`@(&5X:70H(EEO=2!N965D
M('1H92!014%2("=4<F5E)R!P86-K86=E(&EN<W1A;&QE9%QN(BD["GT*"B1L
M:6YK97(@/2`F;F5W($QI;FME<B@D8V]P>2D["FEF("@D:&%N9&QE(#T@;W!E
M;F1I<B@D<W)C1&ER*2D@>PH@("`@=VAI;&4@*"1F:6QE(#T@<F5A9&1I<B@D
M:&%N9&QE*2D@>PH@("`@("`@(&EF("@D9FEL92`A/2`G+B<@)B8*("`@("`@
M("`@("`@)&9I;&4@(3T@)RXN)R`F)@H@("`@("`@("`@("`D9FEL92`A/2`G
M0U93)R`F)@H@("`@("`@("`@("!I<U]D:7(H(B1S<F-$:7(O)&9I;&4B*2D@
M>PH@("`@("`@("`@("`D;&EN:V5R+3YP<F]C97-S*"(D<W)C1&ER+R1F:6QE
M(BP@)&1E<W1$:7(I.PH@("`@("`@('T*("`@('T*("`@(&-L;W-E9&ER*"1H
M86YD;&4I.PH@?0H*96-H;R`B7&XB.PH*+R\@('!O<W-I8FQE('AM;"US=')U
M8W1S"B\O("`\9FEL96QI<W0^"B\O("`@("`@/&1I<B!N86UE/2(O(B!B87-E
M:6YS=&%L;&1I<CTB6$U,(CX*+R\@("`@("`@("`@/&9I;&4@<F]L93TB<&AP
M(CY087)S97(N<&AP/"]F:6QE/@HO+R`@("`@("`@("`\9FEL92!R;VQE/2)P
M:'`B(&YA;64](E)34RYP:'`B("\^"B\O("`@("`@/"]D:7(^"B\O("`\+V9I
M;&5L:7-T/@HO+PHO+R`@/&9I;&5L:7-T/@HO+R`@("`@(#QF:6QE(')O;&4]
M(G!H<"(@8F%S96EN<W1A;&QD:7(](B\B/D1"+G!H<#PO9FEL93X*+R\@("`@
M("`\9&ER(&YA;64](D1"(CX*+R\@("`@("`@("`@/&9I;&4@<F]L93TB<&AP
M(CYC;VUM;VXN<&AP/"]F:6QE/@HO+R`@("`@(#PO9&ER/@HO+R`@/"]F:6QE
M;&ES=#X*8VQA<W,@3&EN:V5R('L*"B`@("!V87(@)%]S<F-$:7(["@H@("`@
M=F%R("1?8F%S94EN<W1A;&Q$:7(["@H@("`@=F%R("1?9FEL97)O;&5S(#T@
M87)R87DH)W!H<"<I.PH*("`@('9A<B`D7W)O;&4["@H@("`@=F%R("1?8V]P
M>3L*"B`@("!F=6YC=&EO;B!,:6YK97(H)&-O<'D@/2!F86QS92D*("`@('L*
M("`@("`@("`D=&AI<RT^7V-O<'D@/2`D8V]P>3L*("`@('T*"B`@("!F=6YC
M=&EO;B!P<F]C97-S*"1S<F-$:7(L("1D97-T1&ER*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?<W)C1&ER(#T@)'-R8T1I<CL*("`@("`@("`D<&%C:V%G949I
M;&4@/2`D=&AI<RT^7W-R8T1I<B`N("<O<&%C:V%G92YX;6PG.PH@("`@("`@
M("1C;&D@/2`F2&]R9&5?0TQ).CIS:6YG;&5T;VXH*3L*"B`@("`@("`@:68@
M*"%I<U]F:6QE*"1P86-K86=E1FEL92DI('L*("`@("`@("`@("`@)&-L:2T^
M;65S<V%G92@G3F\@<&%C:V%G92YX;6P@:6X@)R`N("1T:&ES+3Y?<W)C1&ER
M+"`G8VQI+G=A<FYI;F<G*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@)'1R964@/2!4<F5E.CIS971U<$UE;6]R>2@G
M6$U,)RP@)'!A8VMA9V5&:6QE*3L*("`@("`@("`D=')E92T^<V5T=7`H*3L*
M"B`@("`@("`@+R\@<F5A9"!P86-K86=E(&YA;64*("`@("`@("`D<&%C:V%G
M94YA;64@/2!T<FEM*"1T<F5E+3YG971%;&5M96YT0V]N=&5N="@G+W!A8VMA
M9V4O;F%M92<L("=C9&%T82<I*3L*("`@("`@("`D8VQI+3YW<FET96QN*")0
M<F]C97-S:6YG('!A8VMA9V4@)'!A8VMA9V5.86UE+B(I.PH*("`@("`@("`O
M+R!L;V]K(&9O<B!F:6QE;&ES="!I;B`G+W!A8VMA9V4O<F5L96%S92]F:6QE
M;&ES="<*("`@("`@("`D9FEL96QI<W0@/2`D=')E92T^9V5T16QE;65N=$)Y
M4&%T:"@G+W!A8VMA9V4O<F5L96%S92]F:6QE;&ES="<I.PH*("`@("`@("!I
M9B`H)&9I;&5L:7-T*2!["B`@("`@("`@("`@("\O(&1O('1H:7,@8F5T=&5R
M+"!M86ME('1H92!T<F5E(&-L87-S('=O<FL@8V%S92!I;G-E;G-I=&EV90H@
M("`@("`@("`@("`D8F%S94EN<W1A;&Q$:7(@/2`D9FEL96QI<W1;)V-H:6QD
M)UU;)V%T=')I8G5T97,G75LG8F%S96EN<W1A;&QD:7(G73L*"B`@("`@("`@
M("`@("1T:&ES+3Y?8F%S94EN<W1A;&Q$:7(@/2`D9&5S=$1I<CL*("`@("`@
M("`@("`@:68@*"1B87-E26YS=&%L;$1I<B`A/2`G+R<I('L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?8F%S94EN<W1A;&Q$:7(@+CT@)R\G("X@)&)A<V5)
M;G-T86QL1&ER.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?
M8F%S94EN<W1A;&Q$:7(@/2!P<F5G7W)E<&QA8V4H)WPO*WPG+"`G+R<L("1T
M:&ES+3Y?8F%S94EN<W1A;&Q$:7(I.PH*("`@("`@("`@("`@:68@*"%I<U]D
M:7(H)'1H:7,M/E]B87-E26YS=&%L;$1I<BDI('L*("`@("`@("`@("`@("`@
M(')E<75I<F5?;VYC92`G4WES=&5M+G!H<"<["B`@("`@("`@("`@("`@("!3
M>7-T96TZ.FUK9&ER*"<M<"`G("X@)'1H:7,M/E]B87-E26YS=&%L;$1I<BD[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?:&%N9&QE1FEL
M96QI<W1486<H)&9I;&5L:7-T*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D8VQI+3YM97-S86=E*"=.;R!F:6QE;&ES="!T86<@9F]U;F0@:6YS
M:61E.B`G("X@)'!A8VMA9V5&:6QE+"`G8VQI+G=A<FYI;F<G*3L*("`@("`@
M("!]"B`@("!]"@H@("`@9G5N8W1I;VX@7VAA;F1L949I;&5L:7-T5&%G*"1E
M;&5M96YT+"`D8W5R1&ER(#T@)R<I"B`@("!["B`@("`@("`@9F]R96%C:"`H
M)&5L96UE;G1;)V-H:6QD<F5N)UT@87,@)&-H:6QD*2!["B`@("`@("`@("`@
M('-W:71C:"`H)&-H:6QD6R=N86UE)UTI('L*("`@("`@("`@("`@8V%S92`G
M9FEL92<Z"B`@("`@("`@("`@("`@("`D=&AI<RT^7VAA;F1L949I;&5486<H
M)&-H:6QD+"`D8W5R1&ER*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("!C87-E("=D:7(G.@H@("`@("`@("`@("`@("`@)'1H:7,M/E]H
M86YD;&5$:7)486<H)&-H:6QD+"`D8W5R1&ER*3L*("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@
M)&-L:2`]("9(;W)D95]#3$DZ.G-I;F=L971O;B@I.PH@("`@("`@("`@("`@
M("`@)&-L:2T^;65S<V%G92@G1V]T(&YO(&AA;F1L97(@9F]R('1A9SH@)R`N
M("1C:&EL9%LG;F%M92==+"`G8VQI+7=A<FYI;F<G*3L*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@('T*"B`@
M("!F=6YC=&EO;B!?:&%N9&QE1&ER5&%G*"1E;&5M96YT+"`D8W5R1&ER*0H@
M("`@>PH@("`@("`@(&EF("@D96QE;65N=%LG871T<FEB=71E<R==6R=N86UE
M)UT@(3T@)R\G*2!["B`@("`@("`@("`@(&EF("AS=6)S='(H)&-U<D1I<BP@
M+3$I("$]("<O)RD@>PH@("`@("`@("`@("`@("`@)&-U<D1I<B`]("1C=7)$
M:7(@+B`G+R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&-U<D1I<B`]
M("1C=7)$:7(@+B`D96QE;65N=%LG871T<FEB=71E<R==6R=N86UE)UT["B`@
M("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1E;&5M96YT6R=A='1R:6)U
M=&5S)UU;)W)O;&4G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]R;VQE(#T@
M)&5L96UE;G1;)V%T=')I8G5T97,G75LG<F]L92==.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"%I<U]D:7(H)'1H:7,M/E]B87-E26YS=&%L;$1I<B`N("1C
M=7)$:7(I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4WES=&5M+G!H
M<"<["B`@("`@("`@("`@(%-Y<W1E;3HZ;6MD:7(H)RUP("<@+B`D=&AI<RT^
M7V)A<V5);G-T86QL1&ER("X@)&-U<D1I<BD["B`@("`@("`@?0H*("`@("`@
M("`D=&AI<RT^7VAA;F1L949I;&5L:7-T5&%G*"1E;&5M96YT+"`D8W5R1&ER
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!?:&%N9&QE1FEL951A9R@D96QE;65N
M="P@)&1I<BD*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1E;&5M96YT6R=A
M='1R:6)U=&5S)UU;)W)O;&4G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]R
M;VQE(#T@)&5L96UE;G1;)V%T=')I8G5T97,G75LG<F]L92==.PH@("`@("`@
M('T*"B`@("`@("`@:68@*"%I;E]A<G)A>2@D=&AI<RT^7W)O;&4L("1T:&ES
M+3Y?9FEL97)O;&5S*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@
M?0H*("`@("`@("!I9B`H(65M<'1Y*"1E;&5M96YT6R=A='1R:6)U=&5S)UU;
M)VYA;64G72DI('L*("`@("`@("`@("`@)&9I;&5N86UE(#T@)&5L96UE;G1;
M)V%T=')I8G5T97,G75LG;F%M92==.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1F:6QE;F%M92`]("1E;&5M96YT6R=C9&%T82==.PH@("`@("`@
M('T*("`@("`@("`D9FEL96YA;64@/2!T<FEM*"1F:6QE;F%M92D["@H@("`@
M("`@(&EF("@D=&AI<RT^7V-O<'DI('L*("`@("`@("`@("`@)&-M9"`](")C
M<"![)'1H:7,M/E]S<F-$:7)])&1I<B\D9FEL96YA;64@>R1T:&ES+3Y?8F%S
M94EN<W1A;&Q$:7)])&1I<B\D9FEL96YA;64B.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1P87)E;G0@/2`D=&AI<RT^7V9I;F1#;VUM;VY087)E
M;G0H)'1H:7,M/E]S<F-$:7(@+B`D9&ER+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8F%S94EN<W1A
M;&Q$:7(@+B`D9&ER*3L*("`@("`@("`@("`@)&1I<G,@/2!S=6)S=')?8V]U
M;G0H<W5B<W1R*"1T:&ES+3Y?8F%S94EN<W1A;&Q$:7(@+B`D9&ER+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R;&5N*"1P
M87)E;G0I*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R\G
M*3L*("`@("`@("`@("`@)'-R8R`]('-T<E]R97!E870H)RXN+R<L("1D:7)S
M*2`N"B`@("`@("`@("`@("`@("!S=6)S='(H)'1H:7,M/E]S<F-$:7(@+B`D
M9&ER+"!S=')L96XH)'!A<F5N="D@*R`Q*3L*("`@("`@("`@("`@)&-M9"`]
M(")L;B`M<V8@)'-R8R\D9FEL96YA;64@>R1T:&ES+3Y?8F%S94EN<W1A;&Q$
M:7)])&1I<B\D9FEL96YA;64B.PH@("`@("`@('T*("`@("`@("!E>&5C*"1C
M;60I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]F:6YD0V]M;6]N4&%R96YT*"1A
M+"`D8BD*("`@('L*("`@("`@("!F;W(@*"1C;VUM;VX@/2`G)RP@)&QA<W1P
M;W,@/2`P+"`D<&]S(#T@<W1R<&]S*"1A+"`G+R<L(#$I.PH@("`@("`@("`@
M("`@)'!O<R`A/3T@9F%L<V4@)B8@<W1R<&]S*"1B+"!S=6)S='(H)&$L(#`L
M("1P;W,I*2`]/3T@,#L*("`@("`@("`@("`@("1P;W,@/2!S=')P;W,H)&$L
M("<O)RP@)'!O<R`K(#$I*2!["B`@("`@("`@("`@("1C;VUM;VX@+CT@<W5B
M<W1R*"1A+"`D;&%S='!O<RP@)'!O<R`M("1L87-T<&]S*3L*("`@("`@("`@
M("`@)&QA<W1P;W,@/2`D<&]S.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M)&-O;6UO;CL*("`@('T*"GT*"F9U;F-T:6]N('!R:6YT7W5S86=E*"1M97-S
M86=E(#T@)R<I('L*"B`@("!I9B`H(65M<'1Y*"1M97-S86=E*2D@>PH@("`@
M("`@('!R:6YT(")C<F5A=&4M<WEM;&EN:W,N<&AP.B`D;65S<V%G95QN7&XB
M.PH@("`@?0H*("`@('!R:6YT(#P\/%5304=%"E5S86=E.B!C<F5A=&4M<WEM
M;&EN:W,N<&AP(%M/4%1)3TY="@I0;W-S:6)L92!O<'1I;VYS.@H@("TM8V]P
M>2`@("`@("`@1&\@;F]T(&-R96%T92!S>6UB;VQI8R!L:6YK<RP@8G5T(&%C
M='5A;&QY(&-O<'D@=&AE(&QI8G)A<FEE<RX*("`M+7-R8SU$25(@("`@(%1H
M92!S;W5R8V4@9&ER96-T;W)Y(&9O<B!T:&4@9G)A;65W;W)K(&QI8G)A<FEE
M<RX*("`M+61E<W0]1$E2("`@(%1H92!D97-T:6YA=&EO;B!D:7)E8W1O<GD@
M9F]R('1H92!F<F%M97=O<FL@;&EB<F%R:65S+@H*55-!1T4["B`@("!E>&ET
M.PI]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O8V]O:VEE7VQO
M9VEN+G!H<```````````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,38Q-R`Q,#4Q-30S,S<T,R`P,C(T,#8`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R
M9&4O<V-R:7!T<R]C;V]K:65?;&]G:6XN<&AP+'8@,2XR+C(N,B`R,#`V+S`Q
M+S`Q(#(Q.C(Y.C`Y(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-2TR
M,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U(&1I9`H@*B!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*B\*"D!D969I;F4H)T%55$A?2$%.1$Q%4B<L('1R=64I.PI`9&5F:6YE
M*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD["G)E
M<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PH*)&%U
M=&@@/2`F075T:#HZ<VEN9VQE=&]N*"1C;VYF6R=A=71H)UU;)V1R:79E<B==
M*3L*"B\O($-H96-K(&9O<B!#3T]+244@875T:"X*:68@*&5M<'1Y*"1?0T]/
M2TE%6R=U<V5R)UTI('Q\(&5M<'1Y*"1?0T]/2TE%6R=P87-S=V]R9"==*2!\
M?`H@("`@(21A=71H+3YA=71H96YT:6-A=&4H)%]#3T]+245;)W5S97(G72P@
M87)R87DH)W!A<W-W;W)D)R`]/B`D7T-/3TM)15LG<&%S<W=O<F0G72DI*2![
M"B`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@2&]R9&4Z.F%P<&QI8V%T:6]N
M57)L*"=L;V=I;BYP:'`_;&]G;W5T7W)E87-O;CTG("X@05542%]214%33TY?
M0D%$3$]'24XL('1R=64I*3L*("`@(&5X:70["GT*"B1U<FP@/2!5=&EL.CIG
M971&;W)M1&%T82@G=7)L)RD["FEF("AE;7!T>2@D=7)L*2D@>PH@("`@)'5R
M;"`]($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G:6YD97@N<&AP)RP@=')U92D[
M"GT*:&5A9&5R*"=,;V-A=&EO;CH@)R`N("1U<FPI.PH`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O4T-2
M25!44P``````````````````````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P-#0R,R`Q,#4Q-30S,S<T,R`P,C`S,#0`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T*($AO<F1E(%5T:6QI='D@4V-R:7!T<PH]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/0H*26YT<F]D=6-T:6]N"GY^?GY^?GY^?GY^?@I4:&ES(&1I<F5C
M=&]R>2!C;VYT86EN<R!V87)I;W5S('5T:6QI='D@<V-R:7!T<R!F;W(@=&AE
M($AO<F1E(&1I<W1R:6)U=&EO;BX*5&AE>2!A<F4@:&5R92!F;W(@>6]U<B!C
M;VYV96YI96YC92X*"@I38W)I<'0@26YD97@*?GY^?GY^?GY^?GY^"F-O;7!A
M<F5?<F5V:7-I;VYS+G-H"B`@("!#;VUP87)E<R!D:69F97)E;G0@0U93(')E
M=FES:6]N<R!O9B!T:&4@<V%M92!F:6QE+@H*8V]O:VEE7VQO9VEN+G!H<`H@
M("`@06QL;W=S('1O(&QO9VEN('=I=&@@=7-E<B!C<F5D96YT:6%L<R!P<F]V
M:61E9"!B>2!C;V]K:65S+@H*8W)E871E+7-Y;6QI;FMS+G!H<`H@("`@0W)E
M871E<R!S>6UB;VQI8R!L:6YK<R!N96-E<W-A<GD@9F]R(&1E=F5L;W!E<G,@
M=&\@=V]R:R!D:7)E8W1L>2!O;B!T:&4*("`@(&9I;&5S(&EN('1H92!F<F%M
M97=O<FL@;6]D=6QE('=I=&AO=70@;F5E9&EN9R!T;R!I;G-T86QL('1H92!C
M:&%N9V5D"B`@("!P86-K86=E<RX*"F-R;VYD"B`@("!T8F0*"F=E=%]L;V=I
M;BYP:'`*("`@($%L;&]W<R!T;R!L;V=I;B!W:71H('5S97(@8W)E9&5N=&EA
M;',@<')O=FED960@8GD@1T54('!A<F%M971E<G,N"@IH:6=H;&EG:'0N<&AP
M"B`@("!(:6=H;&EG:'1S('-O=7)C92!F:6QE<R!O;B!T:&4@8V]N<V]L92X*
M"FAO<F1E+7)S>6YC+G-H"B`@("!097)F;W)M<R!A(&-H96-K;W5T(&]F('1H
M92!L871E<W0@2&]R9&4@8W9S('-O=7)C97,@=7-I;F<@<G-Y;F,N"@IH='1P
M7VQO9VEN7W)E9F5R+G!H<`H@("`@=&)D"@IM86ME+7-N87!S+G!H<`H@("`@
M=&)D"@IM86ME+7)E;&5A<V4N<&AP"B`@("!"=6EL9',@9&ES=')I8G5T:6]N
M('1A<F)A;&QS(&9O<B!(;W)D92!A;F0@2&]R9&4@;6]D=6QE<RX*"FUE<F=E
M+G!H<`H@("`@365R9V5S(&-O;6UI=',@9G)O;2!A(&-O;6UI="!M97-S86=E
M(&EN=&\@=&AE($-64R!T<F5E(&]F('1H92!C=7)R96YT"B`@("!D:7)E8W1O
M<GDN"@IM:6=R871E7V-A=&5G;W)I97,N<&AP"B`@("!-:6=R871E<R!O;&0@
M8V%T96=O<FEE<R!T;R!T:&4@;F5W(&AO<F1E7V-A=&5G;W)Y7V%T=')I8G5T
M97,@=&%B;&4N"@IM:6=R871E7VQI;FMS+G!H<`H@("`@36EG<F%T97,@;VQD
M($AO<F1E7TQI;FMS('1O('1H92!H;W)D95]C871E9V]R>5]A='1R:6)U=&5S
M('1A8FQE+@H*<&%C:V%G92YD=&0*("`@(%1H92!014%2('!A8VMA9V4@9&5S
M8W)I<'1I;VXN"@IR<&,M=&5S="YP:'`*("`@(%!R;W9I9&5S('1E<W1S(&9O
M<B!T:&4@4E!#(&-L:65N="!A9V%I;G-T('-E=F5R86P@*&EN8VQU9&EN9R!O
M=7(@;W=N*2!24$,*("`@('-E<G9E<G,N"@IS971?<&5R;7,N<V@*("`@(%-E
M=',@9FEL92!O=VYE<G-H:7`@86YD('!E<FUI<W-I;VYS(&]N('1H92!(;W)D
M92!T<F5E(&9O<B!H:6=H('-E8W5R:71Y+@H*<V5T=7`N<&AP"B`@("!4:&4@
M;6%I;B!(;W)D92!S971U<"!S8W)I<'0@=VAI8V@@86QL;W=S(&9O<B!A('-T
M97`@8GD@<W1E<"!S971U<"!O<@H@("`@<F5C;VYF:6=U<F%T:6]N(&]F(&$@
M2&]R9&4@:6YS=&%L;&%T:6]N+@H*=&5M<"UC;&5A;G5P+F-R;VX*("`@($%N
M(&5X86UP;&4@8W)O;B!J;V(@<VAE;&P@<V-R:7!T('=H:6-H('=I;&P@8VQE
M86X@=7`@86YY('1E;7!O<F%R>2!F:6QE<PH@("`@=VAI8V@@;6%Y(&=E="!S
M=')A;F1E9"!B>2!(;W)D92!U<V5R<R!I;B!T:&4@=V5B('-E<G9E<B=S('1E
M;7!O<F%R>0H@("`@9&ER96-T;W)Y+@H*=7!D871E7VAO<F1E+G-H"B`@("!&
M86-I;&ET871E<R!T:&4@=7!D871I;F<@86YD+V]R(&EN<W1A;&QA=&EO;B!O
M9B!H;W)D92!A;F0@:71S"B`@("!A<'!L:6-A=&EO;G,N"@IM:6UE7VUA<'!I
M;F<O"B`@("!4:&ES('-C<FEP="!C;VYV97)T<R!A;B!!<&%C:&4M<W1Y;&4@
M;6EM92YT>7!E<R!F:6QE(&EN=&\@80H@("`@;6EM92YM87!P:6YG+G!H<"!D
M<FEV97(@9FEL92!S=6ET86)L92!F;W(@=7-E('=I=&@@2&]R9&4N("!)="!I
M<R!U<V5F=6P*("`@(&9O<B!S>6YC:6YG($%P86-H92!U<&1A=&5S('1O('1H
M96ER($U)344@='EP97,@=VET:"!(;W)D92X*"@I$871A8F%S92!38W)I<'1S
M"GY^?GY^?GY^?GY^?GY^?GX*1&%T86)A<V4@=&%B;&4@<V-H96UA<R!A;F0@
M87-S;V-I871E9"!U=&EL:71Y('-C<FEP=',@87)E(&QO8V%T960@:6X@=&AE
M('-Q;"\*<W5B9&ER96-T;W)Y+@H*"DQ$05`@4V-H96UA<PI^?GY^?GY^?GY^
M?GX*3$1!4"!S8VAE;6%S(&%R92!L;V-A=&5D(&EN('1H92!L9&%P+R!S=6)D
M:7)E8W1O<GDN"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W-C<FEP=',O9V5T7VQO9VEN+G!H<```````````````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,3,W-2`Q,#4Q-30S,S<T,R`P,C$W,34`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J("1(;W)D93H@:&]R9&4O<V-R:7!T<R]G971?;&]G:6XN<&AP+'8@
M,2XS+C$P+C,@,C`P-B\P,2\P,2`R,3HR.3HP.2!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#(P,#0M,C`P-B!*;V5L(%9A;F1A;"`\:G9A;F1A;$!I;F9O
M=&5C:RYQ8RYC83X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G05542%](
M04Y$3$52)RP@=')U92D["D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE
M*%]?1DE,15]?*2`N("<O+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@
M+B`G+VQI8B]B87-E+G!H<"<["@HD875T:"`]("9!=71H.CIS:6YG;&5T;VXH
M)&-O;F9;)V%U=&@G75LG9')I=F5R)UTI.PH*+R\@0VAE8VL@9F]R($=%5"!A
M=71H+@II9B`H96UP='DH)%]'151;)W5S97(G72D@?'P@(21A=71H+3YA=71H
M96YT:6-A=&4H)%]'151;)W5S97(G72P@87)R87DH)W!A<W-W;W)D)R`]/B`D
M7T=%5%LG<&%S<R==*2DI('L*("`@(&AE861E<B@G3&]C871I;VXZ("<@+B!(
M;W)D93HZ87!P;&EC871I;VY5<FPH)VQO9VEN+G!H<#]L;V=O=71?<F5A<V]N
M/6QO9V]U="<I*3L*("`@(&5X:70["GT*"FAE861E<B@G3&]C871I;VXZ("<@
M+B!(;W)D93HZ87!P;&EC871I;VY5<FPH)VEN9&5X+G!H<"<I*3L*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W-E<G9I8V5S````````````````````````````````````````
M```````````````````````````````````````````````````P,#`W-34@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<T-"`P,3<S
M,#4`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R````````
M````````````````````````````````````````````````````````````
M`````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P
M(#$P-3$U-#,S-S0S(#`R,#4W,@`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V
M:6-E<R]E9&ET;W(O:'1M;&%R96$`````````````````````````````````
M````````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W-#0@,#(R,S<P`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]L86YG````
M```````````````````````````````````````````````````````````P
M,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<T
M,R`P,C,S,3``(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R
M+VAT;6QA<F5A+VQA;F<O96XN:G,`````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#$U-3(U(#$P-3$U-#,S-S0S(#`R-#,S-P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````O+R!),3A.(&-O;G-T86YT<PH*+R\@
M3$%.1SH@(F5N(BP@14Y#3T1)3D<Z(%541BTX('P@25-/+3@X-3DM,0HO+R!!
M=71H;W(Z($UI:&%I($)A>F]N+"!H='1P.B\O9'EN87)C:"YC;VTO;6ES:&]O
M"@HO+R!&3U(@5%)!3E-,051/4E,Z"B\O"B\O("`@,2X@4$Q%05-%(%!55"!9
M3U52($-/3E1!0U0@24Y&3R!)3B!42$4@04)/5D4@3$E.10HO+R`@("`@("AA
M="!L96%S="!A('9A;&ED(&5M86EL(&%D9')E<W,I"B\O"B\O("`@,BX@4$Q%
M05-%(%1262!43R!54T4@551&+3@@1D]2($5.0T]$24Y'.PHO+R`@("`@("AI
M9B!T:&ES(&ES(&YO="!P;W-S:6)L92P@<&QE87-E(&EN8VQU9&4@82!C;VUM
M96YT"B\O("`@("`@('1H870@<W1A=&5S('=H870@96YC;V1I;F<@:7,@;F5C
M97-S87)Y+BD*"DA434Q!<F5A+DDQ.$X@/2!["@H)+R\@=&AE(&9O;&QO=VEN
M9R!S:&]U;&0@8F4@=&AE(&9I;&5N86UE('=I=&AO=70@+FIS(&5X=&5N<VEO
M;@H)+R\@:70@=VEL;"!B92!U<V5D(&9O<B!A=71O;6%T:6-A;&QY(&QO860@
M<&QU9VEN(&QA;F=U86=E+@H);&%N9SH@(F5N(BP*"@ET;V]L=&EP<SH@>PH)
M"6)O;&0Z("`@("`@("`@("`B0F]L9"(L"@D):71A;&EC.B`@("`@("`@("))
M=&%L:6,B+`H)"75N9&5R;&EN93H@("`@("`B56YD97)L:6YE(BP*"0ES=')I
M:V5T:')O=6=H.B`@(E-T<FEK971H<F]U9V@B+`H)"7-U8G-C<FEP=#H@("`@
M("`B4W5B<V-R:7!T(BP*"0ES=7!E<G-C<FEP=#H@("`@(E-U<&5R<V-R:7!T
M(BP*"0EJ=7-T:69Y;&5F=#H@("`@(DIU<W1I9GD@3&5F="(L"@D):G5S=&EF
M>6-E;G1E<CH@(")*=7-T:69Y($-E;G1E<B(L"@D):G5S=&EF>7)I9VAT.B`@
M(")*=7-T:69Y(%)I9VAT(BP*"0EJ=7-T:69Y9G5L;#H@("`@(DIU<W1I9GD@
M1G5L;"(L"@D);W)D97)E9&QI<W0Z("`@(")/<F1E<F5D($QI<W0B+`H)"75N
M;W)D97)E9&QI<W0Z("`B0G5L;&5T960@3&ES="(L"@D);W5T9&5N=#H@("`@
M("`@(")$96-R96%S92!);F1E;G0B+`H)"6EN9&5N=#H@("`@("`@("`B26YC
M<F5A<V4@26YD96YT(BP*"0EF;W)E8V]L;W(Z("`@("`@(D9O;G0@0V]L;W(B
M+`H)"6AI;&ET96-O;&]R.B`@("`B0F%C:V=R;W5N9"!#;VQO<B(L"@D):&]R
M:7IO;G1A;')U;&4Z(")(;W)I>F]N=&%L(%)U;&4B+`H)"6-R96%T96QI;FLZ
M("`@("`B26YS97)T(%=E8B!,:6YK(BP*"0EI;G-E<G1I;6%G93H@("`@(DEN
M<V5R="]-;V1I9GD@26UA9V4B+`H)"6EN<V5R='1A8FQE.B`@("`B26YS97)T
M(%1A8FQE(BP*"0EH=&UL;6]D93H@("`@("`@(E1O9V=L92!(5$U,(%-O=7)C
M92(L"@D)<&]P=7!E9&ET;W(Z("`@(")%;FQA<F=E($5D:71O<B(L"@D)86)O
M=70Z("`@("`@("`@(")!8F]U="!T:&ES(&5D:71O<B(L"@D)<VAO=VAE;'`Z
M("`@("`@(")(96QP('5S:6YG(&5D:71O<B(L"@D)=&5X=&EN9&EC871O<CH@
M(")#=7)R96YT('-T>6QE(BP*"0EU;F1O.B`@("`@("`@("`@(E5N9&]E<R!Y
M;W5R(&QA<W0@86-T:6]N(BP*"0ER961O.B`@("`@("`@("`@(E)E9&]E<R!Y
M;W5R(&QA<W0@86-T:6]N(BP*"0EC=70Z("`@("`@("`@("`@(D-U="!S96QE
M8W1I;VXB+`H)"6-O<'DZ("`@("`@("`@("`B0V]P>2!S96QE8W1I;VXB+`H)
M"7!A<W1E.B`@("`@("`@("`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B+`H)"6QE
M9G1T;W)I9VAT.B`@("`B1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B+`H)"7)I
M9VAT=&]L969T.B`@("`B1&ER96-T:6]N(')I9VAT('1O(&QE9G0B+`H)"7)E
M;6]V969O<FUA=#H@("`B4F5M;W9E(&9O<FUA='1I;F<B+`H)"7!R:6YT.B`@
M("`@("`@("`B4')I;G0@9&]C=6UE;G0B+`H)"6MI;&QW;W)D.B`@("`@("`B
M0VQE87(@35-/9F9I8V4@=&%G<R(*"7TL"@H)8G5T=&]N<SH@>PH)"2)O:R(Z
M("`@("`@("`@("`B3TLB+`H)"2)C86YC96PB.B`@("`@("`B0V%N8V5L(@H)
M?2P*"@EM<V<Z('L*"0DB4&%T:"(Z("`@("`@("`@(E!A=&@B+`H)"2)415A4
M7TU/1$4B.B`@("`B66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\
M/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N(BP*"@D)(DE%
M+7-U8VMS+69U;&PM<V-R965N(B`Z"@D)+R\@=')A;G-L871E(&AE<F4*"0DB
M5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE
M;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@(B`K"@D)(F1U92!T;R!B<F]W
M<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@
M(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@(B`K"@D)(F1I<W!L87DL
M(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S
M97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@(B`K
M"@D)(FET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R
M86P@4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQN7&XB
M("L*"0DB66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@3TL@
M:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET
M;W(N(BP*"@D)(DUO>BU#;&EP8F]A<F0B(#H*"0DB56YP<FEV:6QE9V5D('-C
M<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I
M8V%L;'D@(B`K"@D)(F9O<B!S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@
M=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@(B`K"@D)
M(G=H:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C
M97-S('1H92!C;&EP8F]A<F0N(@H)?2P*"@ED:6%L;V=S.B!["@D)+R\@0V]M
M;6]N"@D)(D]+(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#H@(D]+(BP*"0DB0V%N8V5L(B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B0V%N8V5L(BP*"@D)
M(D%L:6=N;65N=#HB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#H@(D%L:6=N;65N=#HB+`H)"2).;W0@<V5T(B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(").;W0@<V5T(BP*
M"0DB3&5F="(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@.B`B3&5F="(L"@D)(E)I9VAT(B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(E)I9VAT(BP*"0DB5&5X
M='1O<"(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@.B`B5&5X='1O<"(L"@D)(D%B<VUI9&1L92(@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#H@(D%B<VUI9&1L92(L"@D)(D)A
M<V5L:6YE(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#H@(D)A<V5L:6YE(BP*"0DB06)S8F]T=&]M(B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B06)S8F]T=&]M(BP*"0DB
M0F]T=&]M(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@.B`B0F]T=&]M(BP*"0DB36ED9&QE(B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B36ED9&QE(BP*"0DB5&]P
M(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@.B`B5&]P(BP*"@D)(DQA>6]U="(@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#H@(DQA>6]U="(L"@D)(E-P86-I;F<B
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M(E-P86-I;F<B+`H)"2)(;W)I>F]N=&%L.B(@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Z(")(;W)I>F]N=&%L.B(L"@D)(DAO<FEZ
M;VYT86P@<&%D9&EN9R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#H@(DAO<FEZ;VYT86P@<&%D9&EN9R(L"@D)(E9E<G1I8V%L.B(@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(E9E<G1I8V%L
M.B(L"@D)(E9E<G1I8V%L('!A9&1I;F<B("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#H@(E9E<G1I8V%L('!A9&1I;F<B+`H)"2)";W)D97(@
M=&AI8VMN97-S.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z
M(")";W)D97(@=&AI8VMN97-S.B(L"@D)(DQE879E(&5M<'1Y(&9O<B!N;R!B
M;W)D97(B("`@("`@("`@("`@("`@("`@("`@("`@(#H@(DQE879E(&5M<'1Y
M(&9O<B!N;R!B;W)D97(B+`H*"0DO+R!);G-E<G0@3&EN:PH)"2));G-E<G0O
M36]D:69Y($QI;FLB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z
M("));G-E<G0O36]D:69Y($QI;FLB+`H)"2).;VYE("AU<V4@:6UP;&EC:70I
M(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(").;VYE("AU<V4@
M:6UP;&EC:70I(BP*"0DB3F5W('=I;F1O=R`H7V)L86YK*2(@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@.B`B3F5W('=I;F1O=R`H7V)L86YK*2(L
M"@D)(E-A;64@9G)A;64@*%]S96QF*2(@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#H@(E-A;64@9G)A;64@*%]S96QF*2(L"@D)(E1O<"!F<F%M
M92`H7W1O<"DB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M(E1O<"!F<F%M92`H7W1O<"DB+`H)"2)/=&AE<B(@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")/=&AE<B(L"@D)(E1A
M<F=E=#HB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#H@(E1A<F=E=#HB+`H)"2)4:71L92`H=&]O;'1I<"DZ(B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")4:71L92`H=&]O;'1I<"DZ
M(BP*"0DB55),.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@.B`B55),.B(L"@D)(EEO=2!M=7-T(&5N=&5R('1H92!5
M4DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(@(#H@(EEO=2!M=7-T(&5N
M=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(L"@D)+R\@
M26YS97)T(%1A8FQE"@D)(DEN<V5R="!486)L92(@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#H@(DEN<V5R="!486)L92(L"@D)(E)O
M=W,Z(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#H@(E)O=W,Z(BP*"0DB3G5M8F5R(&]F(')O=W,B("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@.B`B3G5M8F5R(&]F(')O=W,B+`H)
M"2)#;VQS.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`Z(")#;VQS.B(L"@D)(DYU;6)E<B!O9B!C;VQU;6YS(B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(DYU;6)E<B!O9B!C;VQU
M;6YS(BP*"0DB5VED=&@Z(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@.B`B5VED=&@Z(BP*"0DB5VED=&@@;V8@=&AE('1A
M8FQE(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B5VED=&@@
M;V8@=&AE('1A8FQE(BP*"0DB4&5R8V5N="(@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@.B`B4&5R8V5N="(L"@D)(E!I>&5L
M<R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#H@(E!I>&5L<R(L"@D)(D5M(B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#H@(D5M(BP*"0DB5VED=&@@=6YI="(@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B5VED
M=&@@=6YI="(L"@D)(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B("`@("`@
M("`@("`@("`@("`@("`@("`@(#H@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B
M;&4B+`H)"2)#96QL('-P86-I;F<Z(B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`Z(")#96QL('-P86-I;F<Z(BP*"0DB4W!A8V4@8F5T
M=V5E;B!A9&IA8V5N="!C96QL<R(@("`@("`@("`@("`@("`@("`@("`@.B`B
M4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(L"@D)(D-E;&P@<&%D9&EN
M9SHB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(D-E
M;&P@<&%D9&EN9SHB+`H)"2)3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O
M<F1E<B!I;B!C96QL(B`@("`@("`@("`Z(")3<&%C92!B971W965N(&-O;G1E
M;G0@86YD(&)O<F1E<B!I;B!C96QL(BP*"0DO+R!);G-E<G0@26UA9V4*"0DB
M26YS97)T($EM86=E(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@.B`B26YS97)T($EM86=E(BP*"0DB26UA9V4@55),.B(@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B26UA9V4@55),
M.B(L"@D)(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(@("`@("`@("`@("`@
M("`@("`@("`@("`@(#H@(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(L"@D)
M(E!R979I97<B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#H@(E!R979I97<B+`H)"2)0<F5V:65W('1H92!I;6%G92!I;B!A
M(&YE=R!W:6YD;W<B("`@("`@("`@("`@("`@("`Z(")0<F5V:65W('1H92!I
M;6%G92!I;B!A(&YE=R!W:6YD;W<B+`H)"2)!;'1E<FYA=&4@=&5X=#HB("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")!;'1E<FYA=&4@
M=&5X=#HB+`H)"2)&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM
M86=E<R(@("`@("`@("`@("`Z(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S
M=7!P;W)T(&EM86=E<R(L"@D)(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B
M("`@("`@("`@("`@("`@("`@("`@("`@(#H@(E!O<VET:6]N:6YG(&]F('1H
M:7,@:6UA9V4B+`H)"2));6%G92!0<F5V:65W.B(@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Z("));6%G92!0<F5V:65W.B(*"7T*?3L*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I
M;G,`````````````````````````````````````````````````````````
M`#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S
M-S0T(#`R-#`U,0`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET
M;W(O:'1M;&%R96$O<&QU9VEN<R]!;G-E;$EM86=E````````````````````
M````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`P,#`@,3`U,34T,S,W-#,@,#(V,#4U`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+T%N<V5L26UA
M9V4O;&%N9P`````````````````````````````````````P,#`W-34@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<T,R`P,C8W-S8`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A
M+W!L=6=I;G,O06YS96Q);6%G92]L86YG+V5N+FIS````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S,34Q(#$P
M-3$U-#,S-S0S(#`S,#`Q-0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````O+R!),3A.(&-O;G-T86YT<PH*+R\@3$%.1SH@(F5N
M(BP@14Y#3T1)3D<Z(%541BTX('P@25-/+3@X-3DM,0HO+R!!=71H;W(Z($UI
M:&%I($)A>F]N+"!H='1P.B\O9'EN87)C:"YC;VTO;6ES:&]O"@HO+R!&3U(@
M5%)!3E-,051/4E,Z"B\O"B\O("`@,2X@4$Q%05-%(%!55"!93U52($-/3E1!
M0U0@24Y&3R!)3B!42$4@04)/5D4@3$E.10HO+R`@("`@("AA="!L96%S="!A
M('9A;&ED(&5M86EL(&%D9')E<W,I"B\O"B\O("`@,BX@4$Q%05-%(%1262!4
M3R!54T4@551&+3@@1D]2($5.0T]$24Y'.PHO+R`@("`@("AI9B!T:&ES(&ES
M(&YO="!P;W-S:6)L92P@<&QE87-E(&EN8VQU9&4@82!C;VUM96YT"B\O("`@
M("`@('1H870@<W1A=&5S('=H870@96YC;V1I;F<@:7,@;F5C97-S87)Y+BD*
M"D%N<V5L26UA9V4N23$X3B`]('L*"2\O($ET96US('1H870@87!P96%R(&EN
M(&UE;G4N("!0;&5A<V4@;F]T92!T:&%T(&%N('5N9&5R<V-O<F4@*%\I"@DO
M+R!C:&%R86-T97(@:6X@=&AE('1R86YS;&%T:6]N("AR:6=H="!C;VQU;6XI
M('=I;&P@8V%U<V4@=&AE(&9O;&QO=VEN9PH)+R\@;&5T=&5R('1O(&)E8V]M
M92!U;F1E<FQI;F5D(&%N9"!B92!S:&]R=&-U="!F;W(@=&AA="!M96YU(&]P
M=&EO;BX*"@DB26YS97)T($EM86=E(B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@.B`B26YS97)T($EM86=E(BP*"2));6%G92!54DPZ
M(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("))
M;6%G92!54DPZ(BP*"2)%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B("`@("`@
M("`@("`@("`@("`@("`@("`@("`Z(")%;G1E<B!T:&4@:6UA9V4@55),(&AE
M<F4B+`H)(E!R979I97<B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#H@(E!R979I97<B+`H)(E!R979I97<@=&AE(&EM86=E
M(&EN(&$@;F5W('=I;F1O=R(@("`@("`@("`@("`@("`@(#H@(E!R979I97<@
M=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(L"@DB06QT97)N871E('1E>'0Z
M(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B06QT97)N
M871E('1E>'0Z(BP*"2)&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T
M(&EM86=E<R(@("`@("`@("`@("`Z(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG
M="!S=7!P;W)T(&EM86=E<R(L"@DB4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G
M92(@("`@("`@("`@("`@("`@("`@("`@("`@.B`B4&]S:71I;VYI;F<@;V8@
M=&AI<R!I;6%G92(L"@DB26UA9V4@4')E=FEE=SHB("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@.B`B26UA9V4@4')E=FEE=SHB+`H)(D=A
M;&QE<GDZ(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#H@(D=A;&QE<GDZ(BP*"2)'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O
M;2(@("`@("`@("`@("`@("`@("`@("`@("`Z(")'86QL97)Y('1O('1A:V4@
M:6UA9V4@9G)O;2(L"@DB26UA9V4@9G)O;2!G86QL97)Y.B(@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@.B`B26UA9V4@9G)O;2!G86QL97)Y.B(L
M"@DB26UA9V4@9G)O;2!G86QL97)Y(B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@.B`B26UA9V4@9G)O;2!G86QL97)Y(@I].PH`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G
M:6YS+T%N<V5L26UA9V4O86YS96PM:6UA9V4N:G,`````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-3$P,2`Q,#4Q-30S
M,S<T,R`P,S`V-3$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+R\@06YS96P@26UA9V4@4&QU9VEN(&9O<B!(5$U,07)E82TS
M+C`*+R\@4&QU9VEN('1H870@86QL;W=S('1H92!I;G-E<G1I;VX@;V8@:6UA
M9V5S(&9R;VT@=&AE"B\O($AO<F1E(&9R86UE=V]R:R!M;V1U;&4@06YS96P@
M:6YT;R!A('1E>'0*+R\*+R\@36]D=6QE(')E=7-E<R!(5$U,07)E82!C;V1E
M"B\O"B\O($EM<&QE;65N=&%T:6]N.B!2;V5L($=L;W5D96UA;G,@/')O96Q`
M9VQO=61E;6%N<RYI;F9O/@HO+PHO+R`H8RD@,C`P-"X*+R\@1&ES=')I8G5T
M960@=6YD97(@=&AE('-A;64@=&5R;7,@87,@2%1-3$%R96$@:71S96QF+@HO
M+R!4:&ES(&YO=&EC92!-55-4('-T87D@:6YT86-T(&9O<B!U<V4@*'-E92!L
M:6-E;G-E+G1X="DN"B\O"B\O("1)9#H@86YS96PM:6UA9V4N:G,L=B`Q+C$@
M,C`P-"\P.2\P."`Q-CHP-CHQ,R!L86YC97(@17AP("0*"@IF=6YC=&EO;B!!
M;G-E;$EM86=E*&5D:71O<BD*>PH)=&AI<RYE9&ET;W(@/2!E9&ET;W(["@EV
M87(@:3$X;B`]($%N<V5L26UA9V4N23$X3CL*?3L*"@I!;G-E;$EM86=E+E]P
M;'5G:6Y);F9O(#T@>PH);F%M92`@("`@("`@("`Z(")!;G-E;$EM86=E(BP*
M"79E<G-I;VX@("`@("`@.B`B,2XP(BP*"61E=F5L;W!E<B`@("`@.B`B4F]E
M;"!';&]U9&5M86YS(BP*"61E=F5L;W!E<E]U<FP@.B`B:'1T<#HO+W=W=RYG
M;&]U9&5M86YS+FEN9F\O(BP*("`@("`@("!S<&]N<V]R("`@("`@(#H@(DAO
M<F1E(%!R;VIE8W0B+`H@("`@("`@('-P;VYS;W)?=7)L("`@.B`B:'1T<#HO
M+W=W=RYH;W)D92YO<F<O(BP*"6QI8V5N<V4@("`@("`@.B`B:'1M;$%R96$B
M"GT["@H*+R\@0V%L;&5D('=H96X@=&AE('5S97(@8VQI8VMS(&]N("));G-E
M<G1);6%G92(@8G5T=&]N+B`@268@86X@:6UA9V4@:7,@86QR96%D>0HO+R!T
M:&5R92P@:70@=VEL;"!J=7-T(&UO9&EF>2!I="=S('!R;W!E<G1I97,N"B\O
M(%1H:7,@9G5N8W1I;VX@;W9E<G)I9&5S('1H92!N871I=F4@2%1-3$%R96$@
M9G5N8W1I;VX*2%1-3$%R96$N<')O=&]T>7!E+E]I;G-E<G1);6%G92`](&9U
M;F-T:6]N*&EM86=E*2!["@EV87(@961I=&]R(#T@=&AI<SL)+R\@9F]R(&YE
M<W1E9"!F=6YC=&EO;G,*"79A<B!O=71P87)A;2`](&YU;&P["@H):68@*'1Y
M<&5O9B!I;6%G92`]/2`B=6YD969I;F5D(BD@>PH)"6EM86=E(#T@=&AI<RYG
M971087)E;G1%;&5M96YT*"D["@D):68@*&EM86=E("8F("$O7FEM9R0O:2YT
M97-T*&EM86=E+G1A9TYA;64I*0H)"0EI;6%G92`](&YU;&P["@E]"@EI9B`H
M:6UA9V4I(&]U='!A<F%M(#T@>PH)"69?8F%S92`@(#H@961I=&]R+F-O;F9I
M9RYB87-E55),+`H)"69?=7)L("`@(#H@2%1-3$%R96$N:7-?:64@/R!E9&ET
M;W(N<W1R:7!"87-E55),*&EM86=E+G-R8RD@.B!I;6%G92YG971!='1R:6)U
M=&4H(G-R8R(I+`H)"69?86QT("`@(#H@:6UA9V4N86QT+`H)"69?8F]R9&5R
M(#H@:6UA9V4N8F]R9&5R+`H)"69?86QI9VX@(#H@:6UA9V4N86QI9VXL"@D)
M9E]V97)T("`@.B!I;6%G92YV<W!A8V4L"@D)9E]H;W)I>B`@.B!I;6%G92YH
M<W!A8V4*"7T["@H@("`@=F%R(&UA;F%G97(@/2!?961I=&]R7W5R;"`K("=P
M;'5G:6YS+T%N<V5L26UA9V4O:6YS97)T7VEM86=E+G!H<"<["@H)1&EA;&]G
M*&UA;F%G97(L(&9U;F-T:6]N*'!A<F%M*2!["B\O"71H:7,N7W!O<'5P1&EA
M;&]G*&UA;F%G97(L(&9U;F-T:6]N*'!A<F%M*2!["@D):68@*"%P87)A;2D@
M>PDO+R!U<V5R(&UU<W0@:&%V92!P<F5S<V5D($-A;F-E;`H)"0ER971U<FX@
M9F%L<V4["@D)?0H)"79A<B!I;6<@/2!I;6%G93L*"0EI9B`H(6EM9RD@>PH)
M"0EV87(@<V5L(#T@961I=&]R+E]G971396QE8W1I;VXH*3L*"0D)=F%R(')A
M;F=E(#T@961I=&]R+E]C<F5A=&5286YG92AS96PI.PH)"0EE9&ET;W(N7V1O
M8RYE>&5C0V]M;6%N9"@B:6YS97)T:6UA9V4B+"!F86QS92P@<&%R86TN9E]U
M<FPI.PH)"0EI9B`H2%1-3$%R96$N:7-?:64I('L*"0D)"6EM9R`](')A;F=E
M+G!A<F5N=$5L96UE;G0H*3L*"0D)"2\O('=O;F1E<B!I9B!T:&ES('=O<FMS
M+BXN"@D)"0EI9B`H:6UG+G1A9TYA;64N=&],;W=E<D-A<V4H*2`A/2`B:6UG
M(BD@>PH)"0D)"6EM9R`](&EM9RYP<F5V:6]U<U-I8FQI;F<["@D)"0E]"@D)
M"7T@96QS92!["@D)"0EI;6<@/2!R86YG92YS=&%R=$-O;G1A:6YE<BYP<F5V
M:6]U<U-I8FQI;F<["@D)"7T*"0E](&5L<V4@>PH)"0EI;6<N<W)C(#T@<&%R
M86TN9E]U<FP["@D)?0H*"0EF;W(@*'9A<B!F:65L9"!I;B!P87)A;2D@>PH)
M"0EV87(@=F%L=64@/2!P87)A;5MF:65L9%T["@D)"7-W:71C:"`H9FEE;&0I
M('L*"0D)("`@(&-A<V4@(F9?86QT(B`@("`Z(&EM9RYA;'0)(#T@=F%L=64[
M(&)R96%K.PH)"0D@("`@8V%S92`B9E]B;W)D97(B(#H@:6UG+F)O<F1E<B`]
M('!A<G-E26YT*'9A;'5E('Q\("(P(BD[(&)R96%K.PH)"0D@("`@8V%S92`B
M9E]A;&EG;B(@(#H@:6UG+F%L:6=N"2`]('9A;'5E.R!B<F5A:SL*"0D)("`@
M(&-A<V4@(F9?=F5R="(@("`Z(&EM9RYV<W!A8V4@/2!P87)S94EN="AV86QU
M92!\?"`B,"(I.R!B<F5A:SL*"0D)("`@(&-A<V4@(F9?:&]R:7HB("`Z(&EM
M9RYH<W!A8V4@/2!P87)S94EN="AV86QU92!\?"`B,"(I.R!B<F5A:SL*"0D)
M?0H)"7T*"7TL(&]U='!A<F%M*3L*?3L*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O06YS96Q);6%G92]I
M;G-E<G1?:6UA9V4N<&AP`````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#$V,S`U(#$P-3$U-#,S-S0S(#`S,3,R,``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`H*
M+RHJ"B`J("1(;W)D93H@:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A
M+W!L=6=I;G,O06YS96Q);6%G92]I;G-E<G1?:6UA9V4N<&AP+'8@,2XU+C8N
M-2`R,#`U+S$P+S$X(#$Q.C,T.C`R(&IA;B!%>'`@)`H@*B\*"B\O($-H96-K
M(&9O<B!A('!R:6]R(&1E9FEN:71I;VX@;V8@2$]21$5?0D%312`H<&5R:&%P
M<R!B>2!A;B!A=71O7W!R97!E;F1?9FEL90HO+R!D969I;FET:6]N(&9O<B!S
M:71E(&-U<W1O;6EZ871I;VXI+@II9B`H(61E9FEN960H)TA/4D1%7T)!4T4G
M*2D@>PH@("`@0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%
M7U\I("X@)R\N+B\N+B\N+B\N+B\N+B<I.PI]"@HO+R!,;V%D('1H92!(;W)D
M92!&<F%M97=O<FL@8V]R92P@86YD('-E="!U<"!I;F-L=7-I;VX@<&%T:',N
M"G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8V]R92YP:'`G.PH*
M+R\@4F5G:7-T<GD*)')E9VES=')Y(#T@)E)E9VES=')Y.CIS:6YG;&5T;VXH
M*3L*"B\J($1E=&5R;6EN92!H;W<@=V4@=V5R92!C86QL960[('=I=&@@82!5
M4DPL(&]R('=I=&@@82!G86QL97)Y(&ED("HO"B1G86QL97)Y;&ES="`]("1R
M96=I<W1R>2T^8V%L;"@G:6UA9V5S+VQI<W1'86QL97)I97,G+"!A<G)A>2AN
M=6QL*2D["B1G86QL97)Y7VED(#T@571I;#HZ9V5T1F]R;41A=&$H)V=A;&QE
M<GDG+"!K97DH)&=A;&QE<GEL:7-T*2D["B1I;6%G96QI<W0@/2`D<F5G:7-T
M<GDM/F-A;&PH)VEM86=E<R]L:7-T26UA9V5S)RP@87)R87DH;G5L;"P@)&=A
M;&QE<GE?:60L(%!%4DU37U-(3U<L("=S8W)E96XG+"!T<G5E*2D["B1F:7)S
M=%]I;6%G92`](&-O=6YT*"1I;6%G96QI<W0I(#\@)&EM86=E;&ES=%MK97DH
M)&EM86=E;&ES="E=6R=U<FPG72`Z("<G.PH*/SX*/&AT;6P^"@H\:&5A9#X*
M("`\=&ET;&4^26YS97)T($EM86=E/"]T:71L93X*"CQS8W)I<'0@='EP93TB
M=&5X="]J879A<V-R:7!T(B!S<F,](BXN+RXN+W!O<'5P<R]P;W!U<"YJ<R(^
M/"]S8W)I<'0^"@H\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"@IW
M:6YD;W<N<F5S:7IE5&\H-#`P+"`R,#`I.PH*9G5N8W1I;VX@26YI="@I('L*
M("!?7V1L9U]I;FET*"D["B`@=F%R('!A<F%M(#T@=VEN9&]W+F1I86QO9T%R
M9W5M96YT<SL*("!I9B`H<&%R86TI('L*("`@("`@9&]C=6UE;G0N9V5T16QE
M;65N=$)Y260H(F9?=7)L(BDN=F%L=64@/2!P87)A;5LB9E]U<FPB73L*("`@
M("`@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H(F9?86QT(BDN=F%L=64@/2!P
M87)A;5LB9E]A;'0B73L*("`@("`@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H
M(F9?8F]R9&5R(BDN=F%L=64@/2!P87)A;5LB9E]B;W)D97(B73L*("`@("`@
M9&]C=6UE;G0N9V5T16QE;65N=$)Y260H(F9?86QI9VXB*2YV86QU92`]('!A
M<F%M6R)F7V%L:6=N(ET["B`@("`@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED
M*")F7W9E<G0B*2YV86QU92`]('!A<F%M6R)F7W9E<G0B73L*("`@("`@9&]C
M=6UE;G0N9V5T16QE;65N=$)Y260H(F9?:&]R:7HB*2YV86QU92`]('!A<F%M
M6R)F7VAO<FEZ(ET["B`@("`@('=I;F1O=RYI<')E=FEE=RYL;V-A=&EO;BYR
M97!L86-E*'!A<F%M+F9?=7)L*3L*("!]"B`@9&]C=6UE;G0N9V5T16QE;65N
M=$)Y260H(F9?=7)L(BDN9F]C=7,H*3L*?3L*"F9U;F-T:6]N(&]N3TLH*2![
M"B`@=F%R(')E<75I<F5D(#T@>PH@("`@(F9?=7)L(CH@(EEO=2!M=7-T(&5N
M=&5R('1H92!54DPB"B`@?3L*("!F;W(@*'9A<B!I(&EN(')E<75I<F5D*2![
M"B`@("!V87(@96P@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"AI*3L*("`@
M(&EF("@A96PN=F%L=64I('L*("`@("`@86QE<G0H<F5Q=6ER961;:5TI.PH@
M("`@("!E;"YF;V-U<R@I.PH@("`@("!R971U<FX@9F%L<V4["B`@("!]"B`@
M?0H@("\O('!A<W,@9&%T82!B86-K('1O('1H92!C86QL:6YG('=I;F1O=PH@
M('9A<B!F:65L9',@/2!;(F9?=7)L(BP@(F9?86QT(BP@(F9?86QI9VXB+"`B
M9E]B;W)D97(B+`H@("`@("`@("`@("`@("`@(F9?:&]R:7HB+"`B9E]V97)T
M(ET["B`@=F%R('!A<F%M(#T@;F5W($]B:F5C="@I.PH@(&9O<B`H=F%R(&D@
M:6X@9FEE;&1S*2!["B`@("!V87(@:60@/2!F:65L9'-;:5T["B`@("!V87(@
M96P@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"AI9"D["B`@("!P87)A;5MI
M9%T@/2!E;"YV86QU93L*("!]"B`@7U]D;&=?8VQO<V4H<&%R86TI.PH@(')E
M='5R;B!F86QS93L*?3L*"F9U;F-T:6]N(&]N0V%N8V5L*"D@>PH@(%]?9&QG
M7V-L;W-E*&YU;&PI.PH@(')E='5R;B!F86QS93L*?3L*"F9U;F-T:6]N(&]N
M4')E=FEE=R@I('L*("!V87(@9E]U<FP@/2!D;V-U;65N="YG971%;&5M96YT
M0GE)9"@B9E]U<FPB*3L*("!V87(@=7)L(#T@9E]U<FPN=F%L=64["B`@:68@
M*"%U<FPI('L*("`@(&%L97)T*")9;W4@:&%V92!T;R!E;G1E<B!A;B!54DP@
M9FER<W0B*3L*("`@(&9?=7)L+F9O8W5S*"D["B`@("!R971U<FX@9F%L<V4[
M"B`@?0H@('=I;F1O=RYI<')E=FEE=RYL;V-A=&EO;BYR97!L86-E*"=S:&]W
M:6UA9V4N:'1M;#\G("L@=7)L*3L*("!R971U<FX@9F%L<V4["GT["@IF=6YC
M=&EO;B!C:&%N9V5'86QL97)Y*"D@>PH@('9A<B!R96QO861?=7)L(#T@9&]C
M=6UE;G0N;&]C871I;VXN:')E9CL*"B`@<F5L;V%D7W5R;"`@("`@/2!R96QO
M861?=7)L+G-U8G-T<FEN9R@P+')E;&]A9%]U<FPN;&%S=$EN9&5X3V8H)S\G
M*2D["B`@<F5L;V%D7W5R;"`@("`@/2!R96QO861?=7)L("L@)S]G86QL97)Y
M/2<@*R!D;V-U;65N="YF;W)M<ULP72YG86QL97)Y+G9A;'5E.PH*("!D;V-U
M;65N="YL;V-A=&EO;BYR97!L86-E*')E;&]A9%]U<FPI.PI]"CPO<V-R:7!T
M/@H*/'-T>6QE('1Y<&4](G1E>'0O8W-S(CX*:'1M;"P@8F]D>2!["B`@8F%C
M:V=R;W5N9#H@0G5T=&]N1F%C93L*("!C;VQO<CH@0G5T=&]N5&5X=#L*("!F
M;VYT.B`Q,7!X(%1A:&]M82Q697)D86YA+'-A;G,M<V5R:68["B`@;6%R9VEN
M.B`P<'@["B`@<&%D9&EN9SH@,'!X.PI]"F)O9'D@>R!P861D:6YG.B`U<'@[
M('T*=&%B;&4@>PH@(&9O;G0Z(#$Q<'@@5&%H;VUA+%9E<F1A;F$L<V%N<RUS
M97)I9CL*?0IF;W)M('`@>PH@(&UA<F=I;BUT;W`Z(#5P>#L*("!M87)G:6XM
M8F]T=&]M.B`U<'@["GT*+F9L('L@=VED=&@Z(#EE;3L@9FQO870Z(&QE9G0[
M('!A9&1I;F<Z(#)P>"`U<'@[('1E>'0M86QI9VXZ(')I9VAT.R!]"BYF<B![
M('=I9'1H.B`V96T[(&9L;V%T.B!L969T.R!P861D:6YG.B`R<'@@-7!X.R!T
M97AT+6%L:6=N.B!R:6=H=#L@?0IF:65L9'-E="![('!A9&1I;F<Z(#!P>"`Q
M,'!X(#5P>"`U<'@[('T*<V5L96-T+"!I;G!U="P@8G5T=&]N('L@9F]N=#H@
M,3%P>"!486AO;6$L5F5R9&%N82QS86YS+7-E<FEF.R!]"F)U='1O;B![('=I
M9'1H.B`W,'!X.R!]"BYS<&%C92![('!A9&1I;F<Z(#)P>#L@?0H*+G1I=&QE
M('L@8F%C:V=R;W5N9#H@(V1D9CL@8V]L;W(Z(",P,#`[(&9O;G0M=V5I9VAT
M.B!B;VQD.R!F;VYT+7-I>F4Z(#$R,"4[('!A9&1I;F<Z(#-P>"`Q,'!X.R!M
M87)G:6XM8F]T=&]M.B`Q,'!X.PIB;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@
M8FQA8VL[(&QE='1E<BUS<&%C:6YG.B`R<'@["GT*9F]R;2![('!A9&1I;F<Z
M(#!P>#L@;6%R9VEN.B`P<'@[('T*/"]S='EL93X*"CPO:&5A9#X*"CQB;V1Y
M(&]N;&]A9#TB26YI="@I(CX*"CQD:78@8VQA<W,](G1I=&QE(CY);G-E<G0@
M26UA9V4\+V1I=CX*/"$M+2T@;F5W('-T=69F("TM+3X*/&9O<FT@86-T:6]N
M/2(B(&UE=&AO9#TB9V5T(CX*/'1A8FQE(&)O<F1E<CTB,"(@=VED=&@](C$P
M,"4B('-T>6QE/2)P861D:6YG.B`P<'@[(&UA<F=I;CH@,'!X(CX*("`\=&)O
M9'D^"B`@/'1R/@H@("`@/'1D('-T>6QE/2)W:61T:#H@-V5M.R!T97AT+6%L
M:6=N.B!R:6=H="(^1V%L;&5R>3H\+W1D/@H@("`@/'1D/CQS96QE8W0@<VEZ
M93TB,2(@;F%M93TB9V%L;&5R>2(@:60](F9?9V%L;&5R>2(@=&ET;&4](D=A
M;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(B!O;D-H86YG93TB8VAA;F=E1V%L
M;&5R>2@I.R(^"CP_<&AP(&9O<F5A8V@@*"1G86QL97)Y;&ES="!A<R`D9V%L
M;&5R>2DZ(#\^"B`@("`@(#QO<'1I;VX@=F%L=64](CP_<&AP(&5C:&\@:'1M
M;'-P96-I86QC:&%R<R@D9V%L;&5R>2T^9V5T240H*2D@/SXB/#]P:'`@:68@
M*"1G86QL97)Y7VED(#T]("1G86QL97)Y+3YG971)9"@I*2!E8VAO("<@<V5L
M96-T960](G-E;&5C=&5D(B<@/SX^/#]P:'`@96-H;R!S=')?<F5P96%T*"<F
M;F)S<#LG+"`R("H@)&=A;&QE<GDM/F=E=$QE=F5L*"DI("X@:'1M;'-P96-I
M86QC:&%R<R@D9V%L;&5R>2T^9V5T*"=N86UE)RDI(#\^/"]O<'1I;VX^"CP_
M<&AP(&5N9&9O<F5A8V@[(#\^"B`@("`\+W-E;&5C=#X*("`@(#PO=&0^"B`@
M/"]T<CX*("`\='(^"B`@("`\=&0@<W1Y;&4](G=I9'1H.B`W96T[('1E>'0M
M86QI9VXZ(')I9VAT(CY);6%G92!F<F]M(&=A;&QE<GDZ/"]T9#X*("`@(#QT
M9#X\<V5L96-T('-I>F4](C$B(&YA;64](FEM9U]G86QL97)Y(B!I9#TB9E]I
M;6=?9V%L;&5R>2(@=&ET;&4](DEM86=E(&9R;VT@9V%L;&5R>2(@;VY#:&%N
M9V4](F1O8W5M96YT+F9O<FUS6S!=+G5R;"YV86QU92`](&1O8W5M96YT+F9O
M<FUS6S!=+FEM9U]G86QL97)Y+G9A;'5E(CX*/#]P:'`@9F]R96%C:"`H)&EM
M86=E;&ES="!A<R`D:60@/3X@)&EM86=E*3H@/SX*("`@("`@/&]P=&EO;B!V
M86QU93TB/#]P:'`@96-H;R`D:6UA9V5;)W5R;"==(#\^(CX\/W!H<"!E8VAO
M("1I;6%G95LG;F%M92==(#\^/"]O<'1I;VX^"CP_<&AP(&5N9&9O<F5A8V@[
M(#\^"B`@("`\+W-E;&5C=#X*("`@(#PO=&0^"B`@/"]T<CX*"B`@/'1R/@H@
M("`@/'1D('-T>6QE/2)W:61T:#H@-V5M.R!T97AT+6%L:6=N.B!R:6=H="(^
M26UA9V4@55),.CPO=&0^"B`@("`\=&0^/&EN<'5T('1Y<&4](G1E>'0B(&YA
M;64](G5R;"(@:60](F9?=7)L(B!S='EL93TB=VED=&@Z-S4E(@H@("`@("!T
M:71L93TB16YT97(@=&AE(&EM86=E(%523"!H97)E(B!V86QU93TB/#]P:'`@
M96-H;R`D9FER<W1?:6UA9V4@/SXB("\^"B`@("`@(#QB=71T;VX@;F%M93TB
M<')E=FEE=R(@;VYC;&EC:STB<F5T=7)N(&]N4')E=FEE=R@I.R(*("`@("`@
M=&ET;&4](E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(^4')E
M=FEE=SPO8G5T=&]N/@H@("`@/"]T9#X*("`\+W1R/@H@(#QT<CX*("`@(#QT
M9"!S='EL93TB=VED=&@Z(#=E;3L@=&5X="UA;&EG;CH@<FEG:'0B/D%L=&5R
M;F%T92!T97AT.CPO=&0^"B`@("`\=&0^/&EN<'5T('1Y<&4](G1E>'0B(&YA
M;64](F%L="(@:60](F9?86QT(B!S='EL93TB=VED=&@Z,3`P)2(*("`@("`@
M=&ET;&4](D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S
M(B`O/CPO=&0^"B`@/"]T<CX*"B`@/"]T8F]D>3X*/"]T86)L93X*"CQP("\^
M"@H\9FEE;&1S970@<W1Y;&4](F9L;V%T.B!L969T.R!M87)G:6XM;&5F=#H@
M-7!X.R(^"CQL96=E;F0^3&%Y;W5T/"]L96=E;F0^"@H\9&EV(&-L87-S/2)S
M<&%C92(^/"]D:78^"@H\9&EV(&-L87-S/2)F;"(^06QI9VYM96YT.CPO9&EV
M/@H\<V5L96-T('-I>F4](C$B(&YA;64](F%L:6=N(B!I9#TB9E]A;&EG;B(*
M("!T:71L93TB4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(^"B`@/&]P=&EO
M;B!V86QU93TB(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/DYO="!S
M970\+V]P=&EO;CX*("`\;W!T:6]N('9A;'5E/2)L969T(B`@("`@("`@("`@
M("`@("`@("`@("`@("`^3&5F=#PO;W!T:6]N/@H@(#QO<'1I;VX@=F%L=64]
M(G)I9VAT(B`@("`@("`@("`@("`@("`@("`@("`@(#Y2:6=H=#PO;W!T:6]N
M/@H@(#QO<'1I;VX@=F%L=64](G1E>'1T;W`B("`@("`@("`@("`@("`@("`@
M("`@(#Y497AT=&]P/"]O<'1I;VX^"B`@/&]P=&EO;B!V86QU93TB86)S;6ED
M9&QE(B`@("`@("`@("`@("`@("`@("`@/D%B<VUI9&1L93PO;W!T:6]N/@H@
M(#QO<'1I;VX@=F%L=64](F)A<V5L:6YE(B!S96QE8W1E9#TB,2(@("`@("`@
M(#Y"87-E;&EN93PO;W!T:6]N/@H@(#QO<'1I;VX@=F%L=64](F%B<V)O='1O
M;2(@("`@("`@("`@("`@("`@("`@(#Y!8G-B;W1T;VT\+V]P=&EO;CX*("`\
M;W!T:6]N('9A;'5E/2)B;W1T;VTB("`@("`@("`@("`@("`@("`@("`@("`^
M0F]T=&]M/"]O<'1I;VX^"B`@/&]P=&EO;B!V86QU93TB;6ED9&QE(B`@("`@
M("`@("`@("`@("`@("`@("`@/DUI9&1L93PO;W!T:6]N/@H@(#QO<'1I;VX@
M=F%L=64](G1O<"(@("`@("`@("`@("`@("`@("`@("`@("`@(#Y4;W`\+V]P
M=&EO;CX*/"]S96QE8W0^"@H\<"`O/@H*/&1I=B!C;&%S<STB9FPB/D)O<F1E
M<B!T:&EC:VYE<W,Z/"]D:78^"CQI;G!U="!T>7!E/2)T97AT(B!N86UE/2)B
M;W)D97(B(&ED/2)F7V)O<F1E<B(@<VEZ93TB-2(*=&ET;&4](DQE879E(&5M
M<'1Y(&9O<B!N;R!B;W)D97(B("\^"@H\9&EV(&-L87-S/2)S<&%C92(^/"]D
M:78^"@H\+V9I96QD<V5T/@H*/&9I96QD<V5T('-T>6QE/2)F;&]A=#IR:6=H
M=#L@;6%R9VEN+7)I9VAT.B`U<'@[(CX*/&QE9V5N9#Y3<&%C:6YG/"]L96=E
M;F0^"@H\9&EV(&-L87-S/2)S<&%C92(^/"]D:78^"@H\9&EV(&-L87-S/2)F
M<B(^2&]R:7IO;G1A;#H\+V1I=CX*/&EN<'5T('1Y<&4](G1E>'0B(&YA;64]
M(FAO<FEZ(B!I9#TB9E]H;W)I>B(@<VEZ93TB-2(*=&ET;&4](DAO<FEZ;VYT
M86P@<&%D9&EN9R(@+SX*"CQP("\^"@H\9&EV(&-L87-S/2)F<B(^5F5R=&EC
M86PZ/"]D:78^"CQI;G!U="!T>7!E/2)T97AT(B!N86UE/2)V97)T(B!I9#TB
M9E]V97)T(B!S:7IE/2(U(@IT:71L93TB5F5R=&EC86P@<&%D9&EN9R(@+SX*
M"CQD:78@8VQA<W,](G-P86-E(CX\+V1I=CX*"CPO9FEE;&1S970^"CQB<B!C
M;&5A<CTB86QL(B`O/@H\=&%B;&4@=VED=&@](C$P,"4B('-T>6QE/2)M87)G
M:6XM8F]T=&]M.B`P+C)E;2(^"B`\='(^"B`@/'1D('9A;&EG;CTB8F]T=&]M
M(CX*("`@($EM86=E(%!R979I97<Z/&)R("\^"B`@("`\:69R86UE(&YA;64]
M(FEP<F5V:65W(B!I9#TB:7!R979I97<B(&9R86UE8F]R9&5R/2(P(B!S='EL
M93TB8F]R9&5R(#H@,7!X('-O;&ED(&=R87D[(B!H96EG:'0](C(P,"(@=VED
M=&@](C,P,"(@<W)C/2(B/CPO:69R86UE/@H@(#PO=&0^"B`@/'1D('9A;&EG
M;CTB8F]T=&]M(B!S='EL93TB=&5X="UA;&EG;CH@<FEG:'0B/@H@("`@/&)U
M='1O;B!T>7!E/2)B=71T;VXB(&YA;64](F]K(B!O;F-L:6-K/2)R971U<FX@
M;VY/2R@I.R(^3TL\+V)U='1O;CX\8G(^"B`@("`\8G5T=&]N('1Y<&4](F)U
M='1O;B(@;F%M93TB8V%N8V5L(B!O;F-L:6-K/2)R971U<FX@;VY#86YC96PH
M*3LB/D-A;F-E;#PO8G5T=&]N/@H@(#PO=&0^"B`\+W1R/@H\+W1A8FQE/@H\
M+V9O<FT^"CPO8F]D>3X*/"]H=&UL/@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]!;G-E;$EM86=E
M+W-H;W=I;6%G92YH=&UL````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`R,#,@,3`U,34T,S,W-#,@,#,Q,#`P`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#QB;V1Y
M/@H\<V-R:7!T/@H@9&]C=6UE;G0N=W)I=&4H)SQI;6<@:'-P86-E/2(P(B!V
M<W!A8V4](C`B('-R8STB)R`K(&1O8W5M96YT+FQO8V%T:6]N+G-E87)C:"YS
M=6)S='(H,2D@*R`G(CXG*3L*/"]S8W)I<'0^"CPO8F]D>3X*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O
M961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O0V]N=&5X=$UE;G4`````````````
M`````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S0S(#`R-C,R,0`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]#;VYT
M97AT365N=2]L86YG````````````````````````````````````,#`P-S4U
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W-#,@,#(W
M,C0R`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL
M87)E82]P;'5G:6YS+T-O;G1E>'1-96YU+VQA;F<O96XN:G,`````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,3(W
M-2`Q,#4Q-30S,S<T,R`P,S`R-C<`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+R\@23$X3B!C;VYS=&%N=',*"B\O($Q!3D<Z
M(")E;B(L($5.0T]$24Y'.B!55$8M."!\($E33RTX.#4Y+3$*+R\@075T:&]R
M.B!-:6AA:2!"87IO;BP@:'1T<#HO+V1Y;F%R8V@N8V]M+VUI<VAO;PH*+R\@
M1D]2(%1204Y33$%43U)3.@HO+PHO+R`@(#$N(%!,14%312!0550@64]54B!#
M3TY404-4($E.1D\@24X@5$A%($%"3U9%($Q)3D4*+R\@("`@("`H870@;&5A
M<W0@82!V86QI9"!E;6%I;"!A9&1R97-S*0HO+PHO+R`@(#(N(%!,14%312!4
M4ED@5$\@55-%(%541BTX($9/4B!%3D-/1$E.1SL*+R\@("`@("`H:68@=&AI
M<R!I<R!N;W0@<&]S<VEB;&4L('!L96%S92!I;F-L=61E(&$@8V]M;65N=`HO
M+R`@("`@("!T:&%T('-T871E<R!W:&%T(&5N8V]D:6YG(&ES(&YE8V5S<V%R
M>2XI"@I#;VYT97AT365N=2Y),3A.(#T@>PH)+R\@271E;7,@=&AA="!A<'!E
M87(@:6X@;65N=2X@(%!L96%S92!N;W1E('1H870@86X@=6YD97)S8V]R92`H
M7RD*"2\O(&-H87)A8W1E<B!I;B!T:&4@=')A;G-L871I;VX@*')I9VAT(&-O
M;'5M;BD@=VEL;"!C875S92!T:&4@9F]L;&]W:6YG"@DO+R!L971T97(@=&\@
M8F5C;VUE('5N9&5R;&EN960@86YD(&)E('-H;W)T8W5T(&9O<B!T:&%T(&UE
M;G4@;W!T:6]N+@H*"2)#=70B("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@.B`B0W5T(BP*"2)#;W!Y(B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M.B`B0V]P>2(L"@DB4&%S=&4B("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#H@(E!A<W1E(BP*"2));6%G92!0<F]P
M97)T:65S(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M.B`B7TEM86=E(%!R;W!E<G1I97,N+BXB+`H)(DUO9&EF>2!,:6YK(B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")?36]D
M:69Y($QI;FLN+BXB+`H)(D-H96-K($QI;FLB("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")#:&5C7VL@3&EN:RXN+B(L
M"@DB4F5M;W9E($QI;FLB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#H@(E]296UO=F4@3&EN:RXN+B(L"@DB0V5L;"!0<F]P
M97)T:65S(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#H@(D-?96QL(%!R;W!E<G1I97,N+BXB+`H)(E)O=R!0<F]P97)T:65S(B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")2;U]W
M(%!R;W!E<G1I97,N+BXB+`H)(DEN<V5R="!2;W<@0F5F;W)E(B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("))7VYS97)T(%)O=R!"
M969O<F4B+`H)(DEN<V5R="!2;W<@069T97(B("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Z("));E]S97)T(%)O=R!!9G1E<B(L"@DB
M1&5L971E(%)O=R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#H@(E]$96QE=&4@4F]W(BP*"2)$96QE=&4@0V5L;"(@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B1&5L
M971E($-E;&PB+`H)(E1A8FQE(%!R;W!E<G1I97,B("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`Z(")?5&%B;&4@4')O<&5R=&EE<RXN
M+B(L"@DB26YS97)T($-O;'5M;B!"969O<F4B("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#H@(DEN<V5R="!?0V]L=6UN($)E9F]R92(L"@DB
M26YS97)T($-O;'5M;B!!9G1E<B(@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#H@(DEN<V5R="!#7V]L=6UN($%F=&5R(BP*"2)$96QE=&4@
M0V]L=6UN(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@.B`B1&5?;&5T92!#;VQU;6XB+`H)(DIU<W1I9GD@3&5F="(@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")*=7-T:69Y
M($QE9G0B+`H)(DIU<W1I9GD@0V5N=&5R(B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Z(")*=7-T:69Y($-E;G1E<B(L"@DB2G5S
M=&EF>2!2:6=H="(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#H@(DIU<W1I9GD@4FEG:'0B+`H)(DIU<W1I9GD@1G5L;"(@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")*=7-T
M:69Y($9U;&PB+`H)(DUA:V4@;&EN:R(@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`Z(")-86ME(&QI;E]K+BXN(BP*"2)2
M96UO=F4@=&AE(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@.B`B4F5M;W9E('1H92(L"@DB16QE;65N="(@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(D5L96UE
M;G0N+BXB+`H)(DEN<V5R="!P87)A9W)A<&@@8F5F;W)E(B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Z("));G-E<G0@<&%R86=R87!H(&)E9F]R
M92(L"@DB26YS97)T('!A<F%G<F%P:"!A9G1E<B(@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#H@(DEN<V5R="!P87)A9W)A<&@@869T97(B+`H*
M"2\O($]T:&5R(&QA8F5L<R`H=&]O;'1I<',@86YD(&%L97)T+V-O;F9I<FT@
M8F]X(&UE<W-A9V5S*0H*"2)0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT
M('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(B`@.B`B4&QE87-E(&-O;F9I<FT@
M=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(L"@DB4F5M
M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(@("`@("`@("`@("`@
M("`@("`@(#H@(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B
M+`H)(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I(B`@
M("`@("`@("`@("`@("`Z(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S
M92!R97!O<G0A*2(L"@DB4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L
M;V<B("`@("`@("`@("`@("`@("`@("`@(#H@(E-H;W<@=&AE(&EM86=E('!R
M;W!E<G1I97,@9&EA;&]G(BP*"2)-;V1I9GD@55),(B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B36]D:69Y(%523"(L
M"@DB0W5R<F5N="!54DP@:7,B("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#H@(D-U<G)E;G0@55),(&ES(BP*"2)/<&5N<R!T:&ES
M(&QI;FL@:6X@82!N97<@=VEN9&]W(B`@("`@("`@("`@("`@("`@("`@("`@
M.B`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(L"@DB4&QE87-E
M(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT
M+B(@(#H@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK
M('1H:7,@96QE;65N="XB+`H)(DQI;FL@<&]I;G1S('1O.B(@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("),:6YK('!O:6YT<R!T
M;SHB+`H)(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT(B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`Z(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N
M="(L"@DB4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9R(@
M("`@("`@("`@("`@("`@(#H@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R
M=&EE<R!D:6%L;V<B+`H)(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S
M(&1I86QO9R(@("`@("`@("`@("`@("`@("`Z(")3:&]W('1H92!486)L92!2
M;W<@4')O<&5R=&EE<R!D:6%L;V<B+`H)(DEN<V5R="!A(&YE=R!R;W<@8F5F
M;W)E('1H92!C=7)R96YT(&]N92(@("`@("`@("`@("`@("`Z("));G-E<G0@
M82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B+`H)(DEN<V5R="!A
M(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(B`@("`@("`@("`@("`@
M("`Z("));G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(L
M"@DB1&5L971E('1H92!C=7)R96YT(')O=R(@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#H@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B+`H)(E-H
M;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G(B`@("`@("`@("`@("`@
M("`@("`@("`Z(")3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9R(L
M"@DB26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE
M(B`@("`@("`@("`@(#H@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H
M92!C=7)R96YT(&]N92(L"@DB26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T
M:&4@8W5R<F5N="!O;F4B("`@("`@("`@("`@(#H@(DEN<V5R="!A(&YE=R!C
M;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(BP*"2)$96QE=&4@=&AE(&-U
M<G)E;G0@8V]L=6UN(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B
M1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(L"@DB0W)E871E(&$@;&EN:R(@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(D-R
M96%T92!A(&QI;FLB+`H)(DEN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE
M(&-U<G)E;G0@;F]D92(@("`@("`@("`@("`Z("));G-E<G0@82!P87)A9W)A
M<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B+`H)(DEN<V5R="!A('!A<F%G
M<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(B`@("`@("`@("`@("`Z("))
M;G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(*?3L*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET
M;W(O:'1M;&%R96$O<&QU9VEN<R]#;VYT97AT365N=2]M96YU+F-S<P``````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#(T-3<@,3`U,34T,S,W-#,@,#,P,#8V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"\J('-T>6QE<R!F;W(@=&AE($-O
M;G1E>'1-96YU("](5$U,07)E82`J+PHO*B!4:&4@0V]N=&5X=$UE;G4@<&QU
M9VEN(&ES("AC*2!D>6YA<F-H+F-O;2`R,#`S+B`J+PHO*B!$:7-T<FEB=71E
M9"!U;F1E<B!T:&4@<V%M92!T97)M<R!A<R!(5$U,07)E82!I='-E;&8@*B\*
M"F1I=BYH=&UL87)E82UC;VYT97AT+6UE;G4@>PH@('!O<VET:6]N.B!A8G-O
M;'5T93L*("!B;W)D97(Z(#%P>"!S;VQI9"`C86-A.#DY.PH@('!A9&1I;F<Z
M(#)P>#L*("!B86-K9W)O=6YD+6-O;&]R.B`C9F9F.PH@(&-O;&]R.B`C,#`P
M.PH@(&-U<G-O<CH@9&5F875L=#L*("!Z+6EN9&5X.B`Q,#`P.PI]"@ID:78N
M:'1M;&%R96$M8V]N=&5X="UM96YU('1A8FQE('L*("!F;VYT.B`Q,7!X('1A
M:&]M82QV97)D86YA+'-A;G,M<V5R:68["B`@8F]R9&5R+6-O;&QA<'-E.B!C
M;VQL87!S93L*?0H*9&EV+FAT;6QA<F5A+6-O;G1E>'0M;65N=2!T<BYI=&5M
M('1D+FEC;VX@:6UG('L*("!W:61T:#H@,3AP>#L*("!H96EG:'0Z(#$X<'@[
M"GT*"F1I=BYH=&UL87)E82UC;VYT97AT+6UE;G4@='(N:71E;2!T9"YI8V]N
M('L*("!P861D:6YG.B`P<'@@,W!X.PH@(&AE:6=H=#H@,3AP>#L*("!B86-K
M9W)O=6YD+6-O;&]R.B`C8V1F.PI]"@ID:78N:'1M;&%R96$M8V]N=&5X="UM
M96YU('1R+FET96T@=&0N;&%B96P@>PH@('!A9&1I;F<Z(#%P>"`Q,'!X(#%P
M>"`S<'@["GT*"F1I=BYH=&UL87)E82UC;VYT97AT+6UE;G4@='(N<V5P87)A
M=&]R('1D('L*("!P861D:6YG.B`R<'@@,'!X.PI]"@ID:78N:'1M;&%R96$M
M8V]N=&5X="UM96YU('1R+G-E<&%R871O<B!T9"!D:78@>PH@(&)O<F1E<BUT
M;W`Z(#%P>"!S;VQI9"`C86-A.#DY.PH@(&]V97)F;&]W.B!H:61D96X["B`@
M<&]S:71I;VXZ(')E;&%T:79E.PI]"@ID:78N:'1M;&%R96$M8V]N=&5X="UM
M96YU('1R+G-E<&%R871O<B!T9"YI8V]N('L*("!B86-K9W)O=6YD+6-O;&]R
M.B`C8V1F.PI]"@ID:78N:'1M;&%R96$M8V]N=&5X="UM96YU('1R+G-E<&%R
M871O<B!T9"YI8V]N(&1I=B!["B\J("!M87)G:6XM;&5F=#H@,W!X.R`J+PH@
M(&)O<F1E<BUC;VQO<CH@(V9F9CL*?0H*9&EV+FAT;6QA<F5A+6-O;G1E>'0M
M;65N=2!T<BYS97!A<F%T;W(@=&0N;&%B96P@9&EV('L*("!M87)G:6XM<FEG
M:'0Z(#-P>#L*?0H*9&EV+FAT;6QA<F5A+6-O;G1E>'0M;65N=2!T<BYI=&5M
M+FAO=F5R('L*("!B86-K9W)O=6YD+6-O;&]R.B`C,S$V86,U.PH@(&-O;&]R
M.B`C9F9F.PI]"@ID:78N:'1M;&%R96$M8V]N=&5X="UM96YU('1R+FET96TN
M:&]V97(@=&0N:6-O;B!["B`@8F%C:V=R;W5N9"UC;VQO<CH@(S8Q.6%F-3L*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+T-O
M;G1E>'1-96YU+V-O;G1E>'0M;65N=2YJ<P`````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`S,S4U-B`Q,#4Q-30S,S<T,R`P
M,S$T,#``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+R\@0V]N=&5X="!-96YU(%!L=6=I;B!F;W(@2%1-3$%R96$M,RXP"B\O
M(%-P;VYS;W)E9"!B>2!W=W<N86UE<FEC86YB:6)L92YO<F<*+R\@26UP;&5M
M96YT871I;VX@8GD@36EH86D@0F%Z;VXL(&AT='`Z+R]D>6YA<F-H+F-O;2]M
M:7-H;V\O"B\O"B\O("AC*2!D>6YA<F-H+F-O;2`R,#`S+3(P,#4N"B\O($1I
M<W1R:6)U=&5D('5N9&5R('1H92!S86UE('1E<FUS(&%S($A434Q!<F5A(&ET
M<V5L9BX*+R\@5&AI<R!N;W1I8V4@35535"!S=&%Y(&EN=&%C="!F;W(@=7-E
M("AS964@;&EC96YS92YT>'0I+@HO+PHO+R`D260Z(&-O;G1E>'0M;65N=2YJ
M<RQV(#$N-B`R,#`U+S`Q+S(P(#$W.C0Y.C`S(&UI<VAO;R!%>'`@)`H*2%1-
M3$%R96$N;&]A9%-T>6QE*")M96YU+F-S<R(L(")#;VYT97AT365N=2(I.PH*
M9G5N8W1I;VX@0V]N=&5X=$UE;G4H961I=&]R*2!["@ET:&ES+F5D:71O<B`]
M(&5D:71O<CL*?3L*"D-O;G1E>'1-96YU+E]P;'5G:6Y);F9O(#T@>PH);F%M
M92`@("`@("`@("`Z(")#;VYT97AT365N=2(L"@EV97)S:6]N("`@("`@(#H@
M(C$N,"(L"@ED979E;&]P97(@("`@(#H@(DUI:&%I($)A>F]N(BP*"61E=F5L
M;W!E<E]U<FP@.B`B:'1T<#HO+V1Y;F%R8V@N8V]M+VUI<VAO;R\B+`H)8U]O
M=VYE<B`@("`@("`Z(")D>6YA<F-H+F-O;2(L"@ES<&]N<V]R("`@("`@(#H@
M(D%M97)I8V%N($)I8FQE(%-O8VEE='DB+`H)<W!O;G-O<E]U<FP@("`Z(")H
M='1P.B\O=W=W+F%M97)I8V%N8FEB;&4N;W)G(BP*"6QI8V5N<V4@("`@("`@
M.B`B:'1M;$%R96$B"GT["@I#;VYT97AT365N=2YP<F]T;W1Y<&4N;VY'96YE
M<F%T92`](&9U;F-T:6]N*"D@>PH)=F%R('-E;&8@/2!T:&ES.PH)=F%R(&1O
M8R`]('1H:7,N961I=&]R9&]C(#T@=&AI<RYE9&ET;W(N7VEF<F%M92YC;VYT
M96YT5VEN9&]W+F1O8W5M96YT.PH)2%1-3$%R96$N7V%D9$5V96YT<RAD;V,L
M(%LB8V]N=&5X=&UE;G4B72P*"0D)("`@(&9U;F-T:6]N("AE=F5N="D@>PH)
M"0D)("`@(')E='5R;B!S96QF+G!O<'5P365N=2A(5$U,07)E82YI<U]I92`_
M('-E;&8N961I=&]R+E]I9G)A;64N8V]N=&5N=%=I;F1O=RYE=F5N="`Z(&5V
M96YT*3L*"0D)("`@('TI.PH)=&AI<RYC=7)R96YT365N=2`](&YU;&P["GT[
M"@I#;VYT97AT365N=2YP<F]T;W1Y<&4N9V5T0V]N=&5X=$UE;G4@/2!F=6YC
M=&EO;BAT87)G970I('L*"79A<B!S96QF(#T@=&AI<SL*"79A<B!E9&ET;W(@
M/2!T:&ES+F5D:71O<CL*"79A<B!C;VYF:6<@/2!E9&ET;W(N8V]N9FEG.PH)
M=F%R(&UE;G4@/2!;73L*"79A<B!T8F\@/2!T:&ES+F5D:71O<BYP;'5G:6YS
M+E1A8FQE3W!E<F%T:6]N<SL*"6EF("AT8F\I('1B;R`]('1B;RYI;G-T86YC
M93L*"79A<B!I,3AN(#T@0V]N=&5X=$UE;G4N23$X3CL*"@EV87(@<V5L96-T
M:6]N(#T@961I=&]R+FAA<U-E;&5C=&5D5&5X="@I.PH):68@*'-E;&5C=&EO
M;BD*"0EM96YU+G!U<V@H6R!I,3AN6R)#=70B72P@9G5N8W1I;VXH*2![(&5D
M:71O<BYE>&5C0V]M;6%N9"@B8W5T(BD[('TL(&YU;&PL(&-O;F9I9RYB=&Y,
M:7-T6R)C=70B75LQ72!=+`H)"0D@(%L@:3$X;ELB0V]P>2)=+"!F=6YC=&EO
M;B@I('L@961I=&]R+F5X96-#;VUM86YD*")C;W!Y(BD[('TL(&YU;&PL(&-O
M;F9I9RYB=&Y,:7-T6R)C;W!Y(EU;,5T@72D["@EM96YU+G!U<V@H6R!I,3AN
M6R)087-T92)=+"!F=6YC=&EO;B@I('L@961I=&]R+F5X96-#;VUM86YD*")P
M87-T92(I.R!]+"!N=6QL+"!C;VYF:6<N8G1N3&ES=%LB<&%S=&4B75LQ72!=
M*3L*"@EV87(@8W5R<F5N=%1A<F=E="`]('1A<F=E=#L*"79A<B!E;&UE;G5S
M(#T@6UT["@EV87(@=&UP.PH*"79A<B!L:6YK(#T@;G5L;#L*"79A<B!T86)L
M92`](&YU;&P["@EV87(@='(@/2!N=6QL.PH)=F%R('1D(#T@;G5L;#L*"79A
M<B!I;6<@/2!N=6QL.PH*"69U;F-T:6]N('1A8FQE3W!E<F%T:6]N*&]P8V]D
M92D@>PH)"71B;RYB=71T;VY0<F5S<RAE9&ET;W(L(&]P8V]D92D["@E].PH*
M"69U;F-T:6]N(&EN<V5R=%!A<F$H8W5R<F5N=%1A<F=E="P@869T97(I('L*
M"0EV87(@96P@/2!C=7)R96YT5&%R9V5T.PH)"79A<B!P87(@/2!E;"YP87)E
M;G1.;V1E.PH)"79A<B!P(#T@961I=&]R+E]D;V,N8W)E871E16QE;65N="@B
M<"(I.PH)"7`N87!P96YD0VAI;&0H961I=&]R+E]D;V,N8W)E871E16QE;65N
M="@B8G(B*2D["@D)<&%R+FEN<V5R=$)E9F]R92AP+"!A9G1E<B`_(&5L+FYE
M>'13:6)L:6YG(#H@96PI.PH)"79A<B!S96P@/2!E9&ET;W(N7V=E=%-E;&5C
M=&EO;B@I.PH)"79A<B!R86YG92`](&5D:71O<BY?8W)E871E4F%N9V4H<V5L
M*3L*"0EI9B`H(4A434Q!<F5A+FES7VEE*2!["@D)"7-E;"YR96UO=F5!;&Q2
M86YG97,H*3L*"0D)<F%N9V4N<V5L96-T3F]D94-O;G1E;G1S*'`I.PH)"0ER
M86YG92YC;VQL87!S92AT<G5E*3L*"0D)<V5L+F%D9%)A;F=E*')A;F=E*3L*
M"0E](&5L<V4@>PH)"0ER86YG92YM;W9E5&]%;&5M96YT5&5X="AP*3L*"0D)
M<F%N9V4N8V]L;&%P<V4H=')U92D["@D)"7)A;F=E+G-E;&5C="@I.PH)"7T*
M"7T["@H)9F]R("@[('1A<F=E=#L@=&%R9V5T(#T@=&%R9V5T+G!A<F5N=$YO
M9&4I('L*"0EV87(@=&%G(#T@=&%R9V5T+G1A9TYA;64["@D):68@*"%T86<I
M"@D)"6-O;G1I;G5E.PH)"71A9R`]('1A9RYT;TQO=V5R0V%S92@I.PH)"7-W
M:71C:"`H=&%G*2!["@D)("`@(&-A<V4@(FEM9R(Z"@D)"6EM9R`]('1A<F=E
M=#L*"0D)96QM96YU<RYP=7-H*&YU;&PL"@D)"0D@("`@(%L@:3$X;ELB26UA
M9V4@4')O<&5R=&EE<R)=+`H)"0D)("`@("`@(&9U;F-T:6]N*"D@>PH)"0D)
M"2`@("`@("!E9&ET;W(N7VEN<V5R=$EM86=E*&EM9RD["@D)"0D@("`@("`@
M?2P*"0D)"2`@("`@("!I,3AN6R)3:&]W('1H92!I;6%G92!P<F]P97)T:65S
M(&1I86QO9R)=+`H)"0D)("`@("`@(&-O;F9I9RYB=&Y,:7-T6R)I;G-E<G1I
M;6%G92)=6S%=(%T*"0D)"2D["@D)"6)R96%K.PH)"2`@("!C87-E(")A(CH*
M"0D);&EN:R`]('1A<F=E=#L*"0D)96QM96YU<RYP=7-H*&YU;&PL"@D)"0D@
M("`@(%L@:3$X;ELB36]D:69Y($QI;FLB72P*"0D)"2`@("`@("!F=6YC=&EO
M;B@I('L@961I=&]R+F5X96-#;VUM86YD*")C<F5A=&5L:6YK(BP@=')U92D[
M('TL"@D)"0D@("`@("`@:3$X;ELB0W5R<F5N="!54DP@:7,B72`K("<Z("<@
M*R!L:6YK+FAR968L"@D)"0D@("`@("`@8V]N9FEG+F)T;DQI<W1;(F-R96%T
M96QI;FLB75LQ72!=+`H*"0D)"2`@("`@6R!I,3AN6R)#:&5C:R!,:6YK(ETL
M"@D)"0D@("`@("`@9G5N8W1I;VXH*2![('=I;F1O=RYO<&5N*&QI;FLN:')E
M9BD[('TL"@D)"0D@("`@("`@:3$X;ELB3W!E;G,@=&AI<R!L:6YK(&EN(&$@
M;F5W('=I;F1O=R)=(%TL"@H)"0D)("`@("!;(&DQ.&Y;(E)E;6]V92!,:6YK
M(ETL"@D)"0D@("`@("`@9G5N8W1I;VXH*2!["@D)"0D)("`@("`@(&EF("AC
M;VYF:7)M*&DQ.&Y;(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@
M=6YL:6YK('1H:7,@96QE;65N="XB72`K(")<;B(@*PH)"0D)"0D)("`@:3$X
M;ELB3&EN:R!P;VEN=',@=&\Z(ET@*R`B("(@*R!L:6YK+FAR968I*2!["@D)
M"0D)"2`@("`@("!W:&EL92`H;&EN:RYF:7)S=$-H:6QD*0H)"0D)"0D)("`@
M("`@(&QI;FLN<&%R96YT3F]D92YI;G-E<G1"969O<F4H;&EN:RYF:7)S=$-H
M:6QD+"!L:6YK*3L*"0D)"0D)("`@("`@(&QI;FLN<&%R96YT3F]D92YR96UO
M=F5#:&EL9"AL:6YK*3L*"0D)"0D@("`@("`@?0H)"0D)("`@("`@('TL"@D)
M"0D@("`@("`@:3$X;ELB56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B72!=
M"@D)"0DI.PH)"0EB<F5A:SL*"0D@("`@8V%S92`B=&0B.@H)"0ET9"`]('1A
M<F=E=#L*"0D):68@*"%T8F\I(&)R96%K.PH)"0EE;&UE;G5S+G!U<V@H;G5L
M;"P*"0D)"2`@("`@6R!I,3AN6R)#96QL(%!R;W!E<G1I97,B72P*"0D)"2`@
M("`@("!F=6YC=&EO;B@I('L@=&%B;&5/<&5R871I;VXH(E1/+6-E;&PM<')O
M<"(I.R!]+`H)"0D)("`@("`@(&DQ.&Y;(E-H;W<@=&AE(%1A8FQE($-E;&P@
M4')O<&5R=&EE<R!D:6%L;V<B72P*"0D)"2`@("`@("!C;VYF:6<N8G1N3&ES
M=%LB5$\M8V5L;"UP<F]P(EU;,5T@72P*"0D)"2`@("`@6R!I,3AN6R)$96QE
M=&4@0V5L;")=+`H)"0D)("`@("`@(&9U;F-T:6]N*"D@>R!T86)L94]P97)A
M=&EO;B@B5$\M8V5L;"UD96QE=&4B*3L@?2P@;G5L;"P*"0D)"2`@("`@("!C
M;VYF:6<N8G1N3&ES=%LB5$\M8V5L;"UD96QE=&4B75LQ72!="@D)"0DI.PH)
M"0EB<F5A:SL*"0D@("`@8V%S92`B='(B.@H)"0ET<B`]('1A<F=E=#L*"0D)
M:68@*"%T8F\I(&)R96%K.PH)"0EE;&UE;G5S+G!U<V@H;G5L;"P*"0D)"2`@
M("`@6R!I,3AN6R)2;W<@4')O<&5R=&EE<R)=+`H)"0D)("`@("`@(&9U;F-T
M:6]N*"D@>R!T86)L94]P97)A=&EO;B@B5$\M<F]W+7!R;W`B*3L@?2P*"0D)
M"2`@("`@("!I,3AN6R)3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D
M:6%L;V<B72P*"0D)"2`@("`@("!C;VYF:6<N8G1N3&ES=%LB5$\M<F]W+7!R
M;W`B75LQ72!=+`H*"0D)"2`@("`@6R!I,3AN6R));G-E<G0@4F]W($)E9F]R
M92)=+`H)"0D)("`@("`@(&9U;F-T:6]N*"D@>R!T86)L94]P97)A=&EO;B@B
M5$\M<F]W+6EN<V5R="UA8F]V92(I.R!]+`H)"0D)("`@("`@(&DQ.&Y;(DEN
M<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92)=+`H)"0D)
M("`@("`@(&-O;F9I9RYB=&Y,:7-T6R)43RUR;W<M:6YS97)T+6%B;W9E(EU;
M,5T@72P*"@D)"0D@("`@(%L@:3$X;ELB26YS97)T(%)O=R!!9G1E<B)=+`H)
M"0D)("`@("`@(&9U;F-T:6]N*"D@>R!T86)L94]P97)A=&EO;B@B5$\M<F]W
M+6EN<V5R="UU;F1E<B(I.R!]+`H)"0D)("`@("`@(&DQ.&Y;(DEN<V5R="!A
M(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(ETL"@D)"0D@("`@("`@
M8V]N9FEG+F)T;DQI<W1;(E1/+7)O=RUI;G-E<G0M=6YD97(B75LQ72!=+`H*
M"0D)"2`@("`@6R!I,3AN6R)$96QE=&4@4F]W(ETL"@D)"0D@("`@("`@9G5N
M8W1I;VXH*2![('1A8FQE3W!E<F%T:6]N*")43RUR;W<M9&5L971E(BD[('TL
M"@D)"0D@("`@("`@:3$X;ELB1&5L971E('1H92!C=7)R96YT(')O=R)=+`H)
M"0D)("`@("`@(&-O;F9I9RYB=&Y,:7-T6R)43RUR;W<M9&5L971E(EU;,5T@
M70H)"0D)*3L*"0D)8G)E86L["@D)("`@(&-A<V4@(G1A8FQE(CH*"0D)=&%B
M;&4@/2!T87)G970["@D)"6EF("@A=&)O*2!B<F5A:SL*"0D)96QM96YU<RYP
M=7-H*&YU;&PL"@D)"0D@("`@(%L@:3$X;ELB5&%B;&4@4')O<&5R=&EE<R)=
M+`H)"0D)("`@("`@(&9U;F-T:6]N*"D@>R!T86)L94]P97)A=&EO;B@B5$\M
M=&%B;&4M<')O<"(I.R!]+`H)"0D)("`@("`@(&DQ.&Y;(E-H;W<@=&AE(%1A
M8FQE(%!R;W!E<G1I97,@9&EA;&]G(ETL"@D)"0D@("`@("`@8V]N9FEG+F)T
M;DQI<W1;(E1/+71A8FQE+7!R;W`B75LQ72!=+`H*"0D)"2`@("`@6R!I,3AN
M6R));G-E<G0@0V]L=6UN($)E9F]R92)=+`H)"0D)("`@("`@(&9U;F-T:6]N
M*"D@>R!T86)L94]P97)A=&EO;B@B5$\M8V]L+6EN<V5R="UB969O<F4B*3L@
M?2P*"0D)"2`@("`@("!I,3AN6R));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R
M92!T:&4@8W5R<F5N="!O;F4B72P*"0D)"2`@("`@("!C;VYF:6<N8G1N3&ES
M=%LB5$\M8V]L+6EN<V5R="UB969O<F4B75LQ72!=+`H*"0D)"2`@("`@6R!I
M,3AN6R));G-E<G0@0V]L=6UN($%F=&5R(ETL"@D)"0D@("`@("`@9G5N8W1I
M;VXH*2![('1A8FQE3W!E<F%T:6]N*")43RUC;VPM:6YS97)T+6%F=&5R(BD[
M('TL"@D)"0D@("`@("`@:3$X;ELB26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E
M<B!T:&4@8W5R<F5N="!O;F4B72P*"0D)"2`@("`@("!C;VYF:6<N8G1N3&ES
M=%LB5$\M8V]L+6EN<V5R="UA9G1E<B)=6S%=(%TL"@H)"0D)("`@("!;(&DQ
M.&Y;(D1E;&5T92!#;VQU;6XB72P*"0D)"2`@("`@("!F=6YC=&EO;B@I('L@
M=&%B;&5/<&5R871I;VXH(E1/+6-O;"UD96QE=&4B*3L@?2P*"0D)"2`@("`@
M("!I,3AN6R)$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(ETL"@D)"0D@("`@
M("`@8V]N9FEG+F)T;DQI<W1;(E1/+6-O;"UD96QE=&4B75LQ72!="@D)"0DI
M.PH)"0EB<F5A:SL*"0D@("`@8V%S92`B8F]D>2(Z"@D)"65L;65N=7,N<'5S
M:"AN=6QL+`H)"0D)("`@("!;(&DQ.&Y;(DIU<W1I9GD@3&5F=")=+`H)"0D)
M("`@("`@(&9U;F-T:6]N*"D@>R!E9&ET;W(N97AE8T-O;6UA;F0H(FIU<W1I
M9GEL969T(BD[('TL(&YU;&PL"@D)"0D@("`@("`@8V]N9FEG+F)T;DQI<W1;
M(FIU<W1I9GEL969T(EU;,5T@72P*"0D)"2`@("`@6R!I,3AN6R)*=7-T:69Y
M($-E;G1E<B)=+`H)"0D)("`@("`@(&9U;F-T:6]N*"D@>R!E9&ET;W(N97AE
M8T-O;6UA;F0H(FIU<W1I9GEC96YT97(B*3L@?2P@;G5L;"P*"0D)"2`@("`@
M("!C;VYF:6<N8G1N3&ES=%LB:G5S=&EF>6-E;G1E<B)=6S%=(%TL"@D)"0D@
M("`@(%L@:3$X;ELB2G5S=&EF>2!2:6=H=")=+`H)"0D)("`@("`@(&9U;F-T
M:6]N*"D@>R!E9&ET;W(N97AE8T-O;6UA;F0H(FIU<W1I9GER:6=H="(I.R!]
M+"!N=6QL+`H)"0D)("`@("`@(&-O;F9I9RYB=&Y,:7-T6R)J=7-T:69Y<FEG
M:'0B75LQ72!=+`H)"0D)("`@("!;(&DQ.&Y;(DIU<W1I9GD@1G5L;")=+`H)
M"0D)("`@("`@(&9U;F-T:6]N*"D@>R!E9&ET;W(N97AE8T-O;6UA;F0H(FIU
M<W1I9GEF=6QL(BD[('TL(&YU;&PL"@D)"0D@("`@("`@8V]N9FEG+F)T;DQI
M<W1;(FIU<W1I9GEF=6QL(EU;,5T@70H)"0D)*3L*"0D)8G)E86L["@D)?0H)
M?0H*"6EF("AS96QE8W1I;VX@)B8@(6QI;FLI"@D);65N=2YP=7-H*&YU;&PL
M(%L@:3$X;ELB36%K92!L:6YK(ETL"@D)"0D@(&9U;F-T:6]N*"D@>R!E9&ET
M;W(N97AE8T-O;6UA;F0H(F-R96%T96QI;FLB+"!T<G5E*3L@?2P*"0D)"2`@
M:3$X;ELB0W)E871E(&$@;&EN:R)=+`H)"0D)("!C;VYF:6<N8G1N3&ES=%LB
M8W)E871E;&EN:R)=6S%=(%TI.PH*"69O<B`H=F%R(&D@/2`P.R!I(#P@96QM
M96YU<RYL96YG=&@[("LK:2D*"0EM96YU+G!U<V@H96QM96YU<UMI72D["@H)
M:68@*"$O:'1M;'QB;V1Y+VDN=&5S="AC=7)R96YT5&%R9V5T+G1A9TYA;64I
M*2!["@D)=&%B;&4@/R`H=&UP(#T@=&%B;&4L('1A8FQE(#T@;G5L;"D@.B`H
M=&UP(#T@8W5R<F5N=%1A<F=E="D["@D);65N=2YP=7-H*&YU;&PL"@D)"2`@
M6R!I,3AN6R)296UO=F4@=&AE(ET@*R`B("9L=#LB("L@=&UP+G1A9TYA;64@
M*R`B)F=T.R`B("L@:3$X;ELB16QE;65N=")=+`H)"0D@("`@9G5N8W1I;VXH
M*2!["@D)"0D@("`@:68@*&-O;F9I<FTH:3$X;ELB4&QE87-E(&-O;F9I<FT@
M=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B)=("L@(B`B
M("L*"0D)"0D)=&UP+G1A9TYA;64I*2!["@D)"0D)("`@('9A<B!E;"`]('1M
M<#L*"0D)"0D@("`@=F%R('`@/2!E;"YP87)E;G1.;V1E.PH)"0D)"2`@("!P
M+G)E;6]V94-H:6QD*&5L*3L*"0D)"0D@("`@:68@*$A434Q!<F5A+FES7V=E
M8VMO*2!["@D)"0D)"2`@("!I9B`H<"YT86=.86UE+G1O3&]W97)#87-E*"D@
M/3T@(G1D(B`F)B`A<"YH87-#:&EL9$YO9&5S*"DI"@D)"0D)"0D@("`@<"YA
M<'!E;F1#:&EL9"AE9&ET;W(N7V1O8RYC<F5A=&5%;&5M96YT*")B<B(I*3L*
M"0D)"0D)("`@(&5D:71O<BYF;W)C95)E9')A=R@I.PH)"0D)"0D@("`@961I
M=&]R+F9O8W5S161I=&]R*"D["@D)"0D)"2`@("!E9&ET;W(N=7!D871E5&]O
M;&)A<B@I.PH)"0D)"0D@("`@:68@*'1A8FQE*2!["@D)"0D)"0D@("`@=F%R
M('-A=F5?8V]L;&%P<V4@/2!T86)L92YS='EL92YB;W)D97)#;VQL87!S93L*
M"0D)"0D)"2`@("!T86)L92YS='EL92YB;W)D97)#;VQL87!S92`](")C;VQL
M87!S92(["@D)"0D)"0D@("`@=&%B;&4N<W1Y;&4N8F]R9&5R0V]L;&%P<V4@
M/2`B<V5P87)A=&4B.PH)"0D)"0D)("`@('1A8FQE+G-T>6QE+F)O<F1E<D-O
M;&QA<'-E(#T@<V%V95]C;VQL87!S93L*"0D)"0D)("`@('T*"0D)"0D@("`@
M?0H)"0D)("`@('T*"0D)("`@('TL"@D)"2`@("!I,3AN6R)296UO=F4@=&AI
M<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(ET@72P*"0D)("!;(&DQ.&Y;(DEN
M<V5R="!P87)A9W)A<&@@8F5F;W)E(ETL"@D)"2`@("!F=6YC=&EO;B@I('L@
M:6YS97)T4&%R82AT;7`L(&9A;'-E*3L@?2P*"0D)("`@(&DQ.&Y;(DEN<V5R
M="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92)=(%TL"@D)
M"2`@6R!I,3AN6R));G-E<G0@<&%R86=R87!H(&%F=&5R(ETL"@D)"2`@("!F
M=6YC=&EO;B@I('L@:6YS97)T4&%R82AT;7`L('1R=64I.R!]+`H)"0D@("`@
M:3$X;ELB26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO
M9&4B72!="@D)"2D["@E]"@ER971U<FX@;65N=3L*?3L*"D-O;G1E>'1-96YU
M+G!R;W1O='EP92YP;W!U<$UE;G4@/2!F=6YC=&EO;BAE=BD@>PH)=F%R('-E
M;&8@/2!T:&ES.PH)=F%R(&DQ.&X@/2!#;VYT97AT365N=2Y),3A..PH):68@
M*'1H:7,N8W5R<F5N=$UE;G4I"@D)=&AI<RYC=7)R96YT365N=2YP87)E;G1.
M;V1E+G)E;6]V94-H:6QD*'1H:7,N8W5R<F5N=$UE;G4I.PH)9G5N8W1I;VX@
M9V5T4&]S*&5L*2!["@D)=F%R('(@/2![('@Z(&5L+F]F9G-E=$QE9G0L('DZ
M(&5L+F]F9G-E=%1O<"!].PH)"6EF("AE;"YO9F9S971087)E;G0I('L*"0D)
M=F%R('1M<"`](&=E=%!O<RAE;"YO9F9S971087)E;G0I.PH)"0ER+G@@*ST@
M=&UP+G@["@D)"7(N>2`K/2!T;7`N>3L*"0E]"@D)<F5T=7)N('(["@E].PH)
M9G5N8W1I;VX@9&]C=6UE;G1#;&EC:RAE=BD@>PH)"65V('Q\("AE=B`]('=I
M;F1O=RYE=F5N="D["@D):68@*"%S96QF+F-U<G)E;G1-96YU*2!["@D)"6%L
M97)T*&DQ.&Y;(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R
M="$I(ETI.PH)"0ER971U<FX@9F%L<V4["@D)?0H)"79A<B!E;"`]($A434Q!
M<F5A+FES7VEE(#\@978N<W)C16QE;65N="`Z(&5V+G1A<F=E=#L*"0EF;W(@
M*#L@96P@(3T@;G5L;"`F)B!E;"`A/2!S96QF+F-U<G)E;G1-96YU.R!E;"`]
M(&5L+G!A<F5N=$YO9&4I.PH)"6EF("AE;"`]/2!N=6QL*0H)"0ES96QF+F-L
M;W-E365N=2@I.PH)"2\O2%1-3$%R96$N7W-T;W!%=F5N="AE=BD["@D)+R]R
M971U<FX@9F%L<V4["@E].PH)=F%R(&ME>7,@/2!;73L*"69U;F-T:6]N(&ME
M>5!R97-S*&5V*2!["@D)978@?'P@*&5V(#T@=VEN9&]W+F5V96YT*3L*"0E(
M5$U,07)E82Y?<W1O<$5V96YT*&5V*3L*"0EI9B`H978N:V5Y0V]D92`]/2`R
M-RD@>PH)"0ES96QF+F-L;W-E365N=2@I.PH)"0ER971U<FX@9F%L<V4["@D)
M?0H)"79A<B!K97D@/2!3=')I;F<N9G)O;4-H87)#;V1E*$A434Q!<F5A+FES
M7VEE(#\@978N:V5Y0V]D92`Z(&5V+F-H87)#;V1E*2YT;TQO=V5R0V%S92@I
M.PH)"69O<B`H=F%R(&D@/2!K97ES+FQE;F=T:#L@+2UI(#X](#`[*2!["@D)
M"79A<B!K(#T@:V5Y<UMI73L*"0D):68@*&M;,%TN=&],;W=E<D-A<V4H*2`]
M/2!K97DI"@D)"0EK6S%=+E]?;7-H+F%C=&EV871E*"D["@D)?0H)?3L*"7-E
M;&8N8VQO<V5-96YU(#T@9G5N8W1I;VXH*2!["@D)<V5L9BYC=7)R96YT365N
M=2YP87)E;G1.;V1E+G)E;6]V94-H:6QD*'-E;&8N8W5R<F5N=$UE;G4I.PH)
M"7-E;&8N8W5R<F5N=$UE;G4@/2!N=6QL.PH)"4A434Q!<F5A+E]R96UO=F5%
M=F5N="AD;V-U;65N="P@(FUO=7-E9&]W;B(L(&1O8W5M96YT0VQI8VLI.PH)
M"4A434Q!<F5A+E]R96UO=F5%=F5N="AS96QF+F5D:71O<F1O8RP@(FUO=7-E
M9&]W;B(L(&1O8W5M96YT0VQI8VLI.PH)"6EF("AK97ES+FQE;F=T:"`^(#`I
M"@D)"4A434Q!<F5A+E]R96UO=F5%=F5N="AS96QF+F5D:71O<F1O8RP@(FME
M>7!R97-S(BP@:V5Y4')E<W,I.PH)"6EF("A(5$U,07)E82YI<U]I92D*"0D)
M<V5L9BYI95!O<'5P+FAI9&4H*3L*"7T["@EV87(@=&%R9V5T(#T@2%1-3$%R
M96$N:7-?:64@/R!E=BYS<F-%;&5M96YT(#H@978N=&%R9V5T.PH)=F%R(&EF
M<&]S(#T@9V5T4&]S*'-E;&8N961I=&]R+E]I9G)A;64I.PH)=F%R('@@/2!E
M=BYC;&EE;G18("L@:69P;W,N>#L*"79A<B!Y(#T@978N8VQI96YT62`K(&EF
M<&]S+GD["@H)=F%R(&1I=CL*"79A<B!D;V,["@EI9B`H(4A434Q!<F5A+FES
M7VEE*2!["@D)9&]C(#T@9&]C=6UE;G0["@E](&5L<V4@>PH)"2\O($E%('-T
M:6YK<PH)"79A<B!P;W!U<"`]('1H:7,N:650;W!U<"`]('=I;F1O=RYC<F5A
M=&50;W!U<"@I.PH)"61O8R`]('!O<'5P+F1O8W5M96YT.PH)"61O8RYO<&5N
M*"D["@D)9&]C+G=R:71E*"(\:'1M;#X\:&5A9#X\<W1Y;&4@='EP93TG=&5X
M="]C<W,G/D!I;7!O<G0@=7)L*"(@*R!?961I=&]R7W5R;"`K(")P;'5G:6YS
M+T-O;G1E>'1-96YU+VUE;G4N8W-S*3L@:'1M;"P@8F]D>2![('!A9&1I;F<Z
M(#!P>#L@;6%R9VEN.B`P<'@[(&]V97)F;&]W.B!H:61D96X[(&)O<F1E<CH@
M,'!X.R!]/"]S='EL93X\+VAE860^/&)O9'D@=6YS96QE8W1A8FQE/2=Y97,G
M/CPO8F]D>3X\+VAT;6P^(BD["@D)9&]C+F-L;W-E*"D["@E]"@ED:78@/2!D
M;V,N8W)E871E16QE;65N="@B9&EV(BD["@EI9B`H2%1-3$%R96$N:7-?:64I
M"@D)9&EV+G5N<V5L96-T86)L92`](")O;B(["@ED:78N;VYC;VYT97AT;65N
M=2`](&9U;F-T:6]N*"D@>R!R971U<FX@9F%L<V4[('T["@ED:78N8VQA<W-.
M86UE(#T@(FAT;6QA<F5A+6-O;G1E>'0M;65N=2(["@EI9B`H(4A434Q!<F5A
M+FES7VEE*0H)"61I=BYS='EL92YL969T(#T@9&EV+G-T>6QE+G1O<"`]("(P
M<'@B.PH)9&]C+F)O9'DN87!P96YD0VAI;&0H9&EV*3L*"@EV87(@=&%B;&4@
M/2!D;V,N8W)E871E16QE;65N="@B=&%B;&4B*3L*"61I=BYA<'!E;F1#:&EL
M9"AT86)L92D["@ET86)L92YC96QL4W!A8VEN9R`](#`["@ET86)L92YC96QL
M4&%D9&EN9R`](#`["@EV87(@<&%R96YT(#T@9&]C+F-R96%T945L96UE;G0H
M(G1B;V1Y(BD["@ET86)L92YA<'!E;F1#:&EL9"AP87)E;G0I.PH*"79A<B!O
M<'1I;VYS(#T@=&AI<RYG971#;VYT97AT365N=2AT87)G970I.PH)9F]R("AV
M87(@:2`](#`[(&D@/"!O<'1I;VYS+FQE;F=T:#L@*RMI*2!["@D)=F%R(&]P
M=&EO;B`](&]P=&EO;G-;:5T["@D)=F%R(&ET96T@/2!D;V,N8W)E871E16QE
M;65N="@B='(B*3L*"0EP87)E;G0N87!P96YD0VAI;&0H:71E;2D["@D):68@
M*$A434Q!<F5A+FES7VEE*0H)"0EI=&5M+G5N<V5L96-T86)L92`](")O;B([
M"@D)96QS92!I=&5M+F]N;6]U<V5D;W=N(#T@9G5N8W1I;VXH978I('L*"0D)
M2%1-3$%R96$N7W-T;W!%=F5N="AE=BD["@D)"7)E='5R;B!F86QS93L*"0E]
M.PH)"6EF("@A;W!T:6]N*2!["@D)"6ET96TN8VQA<W-.86UE(#T@(G-E<&%R
M871O<B(["@D)"79A<B!T9"`](&1O8RYC<F5A=&5%;&5M96YT*")T9"(I.PH)
M"0ET9"YC;&%S<TYA;64@/2`B:6-O;B(["@D)"79A<B!)15])4U]!7T950TM)
M3D=?4TA)5"`]("<^)SL*"0D):68@*$A434Q!<F5A+FES7VEE*2!["@D)"0ET
M9"YU;G-E;&5C=&%B;&4@/2`B;VXB.PH)"0D)245?25-?05]&54-+24Y'7U-(
M250@/2`B('5N<V5L96-T86)L93TG;VXG('-T>6QE/2=H96EG:'0],7!X)SXF
M;F)S<#LB.PH)"0E]"@D)"71D+FEN;F5R2%1-3"`]("(\9&EV(B`K($E%7TE3
M7T%?1E5#2TE.1U]32$E4("L@(CPO9&EV/B(["@D)"79A<B!T9#$@/2!T9"YC
M;&]N94YO9&4H=')U92D["@D)"71D,2YC;&%S<TYA;64@/2`B;&%B96PB.PH)
M"0EI=&5M+F%P<&5N9$-H:6QD*'1D*3L*"0D):71E;2YA<'!E;F1#:&EL9"AT
M9#$I.PH)"7T@96QS92!["@D)"79A<B!L86)E;"`](&]P=&EO;ELP73L*"0D)
M:71E;2YC;&%S<TYA;64@/2`B:71E;2(["@D)"6ET96TN7U]M<V@@/2!["@D)
M"0EI=&5M.B!I=&5M+`H)"0D);&%B96PZ(&QA8F5L+`H)"0D)86-T:6]N.B!O
M<'1I;VY;,5TL"@D)"0ET;V]L=&EP.B!O<'1I;VY;,ET@?'P@;G5L;"P*"0D)
M"6EC;VXZ(&]P=&EO;ELS72!\?"!N=6QL+`H)"0D)86-T:79A=&4Z(&9U;F-T
M:6]N*"D@>PH)"0D)"7-E;&8N8VQO<V5-96YU*"D["@D)"0D)<V5L9BYE9&ET
M;W(N9F]C=7-%9&ET;W(H*3L*"0D)"0ET:&ES+F%C=&EO;B@I.PH)"0D)?0H)
M"0E].PH)"0EL86)E;"`](&QA8F5L+G)E<&QA8V4H+U\H6V$M>D$M6C`M.5TI
M+RP@(CQU/B0Q/"]U/B(I.PH)"0EI9B`H;&%B96P@(3T@;W!T:6]N6S!=*0H)
M"0D):V5Y<RYP=7-H*%L@4F5G17AP+B0Q+"!I=&5M(%TI.PH)"0EL86)E;"`]
M(&QA8F5L+G)E<&QA8V4H+U]?+RP@(E\B*3L*"0D)=F%R('1D,2`](&1O8RYC
M<F5A=&5%;&5M96YT*")T9"(I.PH)"0EI9B`H2%1-3$%R96$N:7-?:64I"@D)
M"0ET9#$N=6YS96QE8W1A8FQE(#T@(F]N(CL*"0D):71E;2YA<'!E;F1#:&EL
M9"AT9#$I.PH)"0ET9#$N8VQA<W-.86UE(#T@(FEC;VXB.PH)"0EI9B`H:71E
M;2Y?7VUS:"YI8V]N*0H)"0D)=&0Q+FEN;F5R2%1-3"`]("(\:6UG(&%L:6=N
M/2=M:61D;&4G('-R8STG(B`K(&ET96TN7U]M<V@N:6-O;B`K("(G("\^(CL*
M"0D)=F%R('1D,B`](&1O8RYC<F5A=&5%;&5M96YT*")T9"(I.PH)"0EI9B`H
M2%1-3$%R96$N:7-?:64I"@D)"0ET9#(N=6YS96QE8W1A8FQE(#T@(F]N(CL*
M"0D):71E;2YA<'!E;F1#:&EL9"AT9#(I.PH)"0ET9#(N8VQA<W-.86UE(#T@
M(FQA8F5L(CL*"0D)=&0R+FEN;F5R2%1-3"`](&QA8F5L.PH)"0EI=&5M+F]N
M;6]U<V5O=F5R(#T@9G5N8W1I;VXH*2!["@D)"0ET:&ES+F-L87-S3F%M92`K
M/2`B(&AO=F5R(CL*"0D)"7-E;&8N961I=&]R+E]S=&%T=7-"87)4<F5E+FEN
M;F5R2%1-3"`]('1H:7,N7U]M<V@N=&]O;'1I<"!\?"`G)FYB<W`[)SL*"0D)
M?3L*"0D):71E;2YO;FUO=7-E;W5T(#T@9G5N8W1I;VXH*2![('1H:7,N8VQA
M<W-.86UE(#T@(FET96TB.R!].PH)"0EI=&5M+F]N8V]N=&5X=&UE;G4@/2!F
M=6YC=&EO;BAE=BD@>PH)"0D)=&AI<RY?7VUS:"YA8W1I=F%T92@I.PH)"0D)
M:68@*"%(5$U,07)E82YI<U]I92D*"0D)"0E(5$U,07)E82Y?<W1O<$5V96YT
M*&5V*3L*"0D)"7)E='5R;B!F86QS93L*"0D)?3L*"0D):71E;2YO;FUO=7-E
M=7`@/2!F=6YC=&EO;BAE=BD@>PH)"0D)=F%R('1I;653=&%M<"`]("AN97<@
M1&%T92@I*2YG9714:6UE*"D["@D)"0EI9B`H=&EM95-T86UP("T@<V5L9BYT
M:6UE4W1A;7`@/B`U,#`I"@D)"0D)=&AI<RY?7VUS:"YA8W1I=F%T92@I.PH)
M"0D):68@*"%(5$U,07)E82YI<U]I92D*"0D)"0E(5$U,07)E82Y?<W1O<$5V
M96YT*&5V*3L*"0D)"7)E='5R;B!F86QS93L*"0D)?3L*"0D)+R]I9B`H='EP
M96]F(&]P=&EO;ELR72`]/2`B<W1R:6YG(BD*"0D)+R]I=&5M+G1I=&QE(#T@
M;W!T:6]N6S)=.PH)"7T*"7T*"@EI9B`H(4A434Q!<F5A+FES7VEE*2!["@D)
M=F%R(&1X(#T@>"`K(&1I=BYO9F9S9717:61T:"`M('=I;F1O=RYI;FYE<E=I
M9'1H("L@-#L*"0EV87(@9'D@/2!Y("L@9&EV+F]F9G-E=$AE:6=H="`M('=I
M;F1O=RYI;FYE<DAE:6=H="`K(#0["@D):68@*&1X(#X@,"D@>"`M/2!D>#L*
M"0EI9B`H9'D@/B`P*2!Y("T](&1Y.PH)"61I=BYS='EL92YL969T(#T@>"`K
M(")P>"(["@D)9&EV+G-T>6QE+G1O<"`]('D@*R`B<'@B.PH)?2!E;'-E('L*
M"0DO+R!D971E<FUI;F4@=&AE('-I>F4@*&1I9"!)(&UE;G1I;VX@=&AA="!)
M12!S=&EN:W,_*0H)"79A<B!F;V]B87(@/2!D;V-U;65N="YC<F5A=&5%;&5M
M96YT*")D:78B*3L*"0EF;V]B87(N8VQA<W-.86UE(#T@(FAT;6QA<F5A+6-O
M;G1E>'0M;65N=2(["@D)9F]O8F%R+FEN;F5R2%1-3"`](&1I=BYI;FYE<DA4
M34P["@D)9&]C=6UE;G0N8F]D>2YA<'!E;F1#:&EL9"AF;V]B87(I.PH)"79A
M<B!W(#T@9F]O8F%R+F]F9G-E=%=I9'1H.PH)"79A<B!H(#T@9F]O8F%R+F]F
M9G-E=$AE:6=H=#L*"0ED;V-U;65N="YB;V1Y+G)E;6]V94-H:6QD*&9O;V)A
M<BD["@D)=&AI<RYI95!O<'5P+G-H;W<H978N<V-R965N6"P@978N<V-R965N
M62P@=RP@:"D["@E]"@H)=&AI<RYC=7)R96YT365N=2`](&1I=CL*"71H:7,N
M=&EM95-T86UP(#T@*&YE=R!$871E*"DI+F=E=%1I;64H*3L*"@E(5$U,07)E
M82Y?861D179E;G0H9&]C=6UE;G0L(")M;W5S961O=VXB+"!D;V-U;65N=$-L
M:6-K*3L*"4A434Q!<F5A+E]A9&1%=F5N="AT:&ES+F5D:71O<F1O8RP@(FUO
M=7-E9&]W;B(L(&1O8W5M96YT0VQI8VLI.PH):68@*&ME>7,N;&5N9W1H(#X@
M,"D*"0E(5$U,07)E82Y?861D179E;G0H=&AI<RYE9&ET;W)D;V,L(")K97EP
M<F5S<R(L(&ME>5!R97-S*3L*"@E(5$U,07)E82Y?<W1O<$5V96YT*&5V*3L*
M"7)E='5R;B!F86QS93L*?3L*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L
M94]P97)A=&EO;G,`````````````````````````````````````,#`P-S4U
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W-#0@,#(W
M,30T`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL
M87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]I;6<`````````````````
M```````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P
M,"`Q,#4Q-30S,S<T-"`P,C<W,C``(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R
M=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS
M+VEM9R]C96QL+61E;&5T92YG:68``````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P,30U(#$P-3$U-#,S-S0T(#`S,C8T-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!'248X.6$2`!(`
MH0``````_____P``____(?D$`0```P`L`````!(`$@```C:<CZG+`P_;`:$&
M(`VU.(D$A=$@?`L@!"E:EJ>J=NXDAH8Y65?FZ)U4XVTJO\9PEPGRELRFI```
M.P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O
M<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]I;6<O8V]L+7-P
M;&ET+F=I9@`````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,38Q-"`Q,#4Q-30S,S<T-"`P,S(S-S8`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````1TE&.#EA$@`2`.<``````(````"`
M`("`````@(``@`"`@,#`P,#<P*;*\$`@`&`@`(`@`*`@`,`@`.`@``!``"!`
M`$!``&!``(!``*!``,!``.!```!@`"!@`$!@`&!@`(!@`*!@`,!@`.!@``"`
M`""``$"``&"``("``*"``,"``."```"@`""@`$"@`&"@`("@`*"@`,"@`."@
M``#``"#``$#``&#``(#``*#``,#``.#```#@`"#@`$#@`&#@`(#@`*#@`,#@
M`.#@````0"``0$``0&``0(``0*``0,``0.``0``@0"`@0$`@0&`@0(`@0*`@
M0,`@0.`@0`!`0"!`0$!`0&!`0(!`0*!`0,!`0.!`0`!@0"!@0$!@0&!@0(!@
M0*!@0,!@0.!@0`"`0""`0$"`0&"`0("`0*"`0,"`0."`0`"@0""@0$"@0&"@
M0("@0*"@0,"@0."@0`#`0"#`0$#`0&#`0(#`0*#`0,#`0.#`0`#@0"#@0$#@
M0&#@0(#@0*#@0,#@0.#@0```@"``@$``@&``@(``@*``@,``@.``@``@@"`@
M@$`@@&`@@(`@@*`@@,`@@.`@@`!`@"!`@$!`@&!`@(!`@*!`@,!`@.!`@`!@
M@"!@@$!@@&!@@(!@@*!@@,!@@.!@@`"`@""`@$"`@&"`@("`@*"`@,"`@."`
M@`"@@""@@$"@@&"@@("@@*"@@,"@@."@@`#`@"#`@$#`@&#`@(#`@*#`@,#`
M@.#`@`#@@"#@@$#@@&#@@(#@@*#@@,#@@.#@@```P"``P$``P&``P(``P*``
MP,``P.``P``@P"`@P$`@P&`@P(`@P*`@P,`@P.`@P`!`P"!`P$!`P&!`P(!`
MP*!`P,!`P.!`P`!@P"!@P$!@P&!@P(!@P*!@P,!@P.!@P`"`P""`P$"`P&"`
MP("`P*"`P,"`P."`P`"@P""@P$"@P&"@P("@P*"@P,"@P."@P`#`P"#`P$#`
MP&#`P(#`P*#`P/_[\*"@I("`@/\```#_`/__````__\`_P#______R'Y!`$`
M`/T`+``````2`!(```AI`/L)'$BPH,&#"/L!6,BPH4,``@'\^R=QXL2*%B$J
MO&B18T>-#T,RC'C1WS]_!$RB5`F2HTD")__!--F2HLJ4)W'Z`\DPYDR9,6L"
MN$GTI%"?2&F2M)FSZ,ZE$E\FI1A19,B$6+-JW1H0`#L`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S
M+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]I;6<O
M8V5L;"UM97)G92YG:68````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,38P,"`Q,#4Q-30S,S<T-"`P,S(T-S<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````1TE&.#EA$@`2`.<`````
M`(````"``("`````@(``@`"`@,#`P,#<P*;*\$`@`&`@`(`@`*`@`,`@`.`@
M``!``"!``$!``&!``(!``*!``,!``.!```!@`"!@`$!@`&!@`(!@`*!@`,!@
M`.!@``"``""``$"``&"``("``*"``,"``."```"@`""@`$"@`&"@`("@`*"@
M`,"@`."@``#``"#``$#``&#``(#``*#``,#``.#```#@`"#@`$#@`&#@`(#@
M`*#@`,#@`.#@````0"``0$``0&``0(``0*``0,``0.``0``@0"`@0$`@0&`@
M0(`@0*`@0,`@0.`@0`!`0"!`0$!`0&!`0(!`0*!`0,!`0.!`0`!@0"!@0$!@
M0&!@0(!@0*!@0,!@0.!@0`"`0""`0$"`0&"`0("`0*"`0,"`0."`0`"@0""@
M0$"@0&"@0("@0*"@0,"@0."@0`#`0"#`0$#`0&#`0(#`0*#`0,#`0.#`0`#@
M0"#@0$#@0&#@0(#@0*#@0,#@0.#@0```@"``@$``@&``@(``@*``@,``@.``
M@``@@"`@@$`@@&`@@(`@@*`@@,`@@.`@@`!`@"!`@$!`@&!`@(!`@*!`@,!`
M@.!`@`!@@"!@@$!@@&!@@(!@@*!@@,!@@.!@@`"`@""`@$"`@&"`@("`@*"`
M@,"`@."`@`"@@""@@$"@@&"@@("@@*"@@,"@@."@@`#`@"#`@$#`@&#`@(#`
M@*#`@,#`@.#`@`#@@"#@@$#@@&#@@(#@@*#@@,#@@.#@@```P"``P$``P&``
MP(``P*``P,``P.``P``@P"`@P$`@P&`@P(`@P*`@P,`@P.`@P`!`P"!`P$!`
MP&!`P(!`P*!`P,!`P.!`P`!@P"!@P$!@P&!@P(!@P*!@P,!@P.!@P`"`P""`
MP$"`P&"`P("`P*"`P,"`P."`P`"@P""@P$"@P&"@P("@P*"@P,"@P."@P`#`
MP"#`P$#`P&#`P(#`P*#`P/_[\*"@I("`@/\```#_`/__````__\`_P#_____
M_R'Y!`$``/T`+``````2`!(```A=`/L)'$BPH,&#"/L!6,BPH4,``@'\^R=Q
MXL2*%B$JO&B18T>-#T,RC'C1WS^3*$^>!,DQI4N*)"F^=,F2HLJ9,!4RQ(FR
MID2>.2L"`.K/Y\VC)D&*#)FPJ=.G4`,"`#L`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E
M<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N
M<R]I;6<O<F]W+6EN<V5R="UA8F]V92YG:68````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#$V-"`Q,#4Q-30S,S<T-"`P,S,V-S(`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````1TE&.#EA$@`2
M`,(```#__P``A.&`@/___P```/___________R'Y!`$```<`+``````2`!(`
M``,Y>+K<_C`&16J5\Q`P.`P@2'0=1G&>1%G$RK;1(<PT'-%U+.."#;V7V&!(
M]#V(11UR:'0`F[JHE)$``#L`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET
M;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO;G,O:6UG+W)O=RUD
M96QE=&4N9VEF````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`Q-3`@,3`U,34T,S,W-#0@,#,R-3,Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````$=)1C@Y81(`$@"A``````#_____
M``#___\A^00!```#`"P`````$@`2```".9R/J<L##U\;H=H`YK6Y[=HQT2@-
M`B($Z:IBAG`:+;L"\/W.>@<?Y/A"?%R>3V@Q/"I^RHGS"7T6```[````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A
M+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS+VEM9R]C96QL+6EN<V5R="UB969O
M<F4N9VEF`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,38V(#$P
M-3$U-#,S-S0T(#`S-#$U,@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!'248X.6$2`!(`P@````"`X8"``/______````____
M________(?D$`0``!P`L`````!(`$@```SMXNMSNX,D#(KE8UDJ&\,14'<3W
MA2*)7<K*3FT@!RA,S#3<NCHY_(/:I`,42ES&!_&7="R#/61O2I4D```[````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A
M8FQE3W!E<F%T:6]N<R]I;6<O8V5L;"UI;G-E<G0M869T97(N9VEF```P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#$V-B`Q,#4Q-30S,S<T-"`P
M,S0P,3$`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````1TE&.#EA$@`2`,(`````@.&`@`#______P```/___________R'Y!`$`
M``<`+``````2`!(```,[>+K<_O"02>,B(P]B%=9<1U5B8`:A19QH)XTAX#*`
M#*=-76/"(.`Y6Z\7NBEL,(]FX_ID@`_C;$IE)```.P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S
M97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO
M;G,O:6UG+V-E;&PM<W!L:70N9VEF````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#$V,3,@,3`U,34T,S,W-#0@,#,R-3,W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````$=)1C@Y81(`
M$@#G``````"`````@`"`@````("``(``@(#`P,#`W,"FRO!`(`!@(`"`(`"@
M(`#`(`#@(```0``@0`!`0`!@0`"`0`"@0`#`0`#@0```8``@8`!`8`!@8`"`
M8`"@8`#`8`#@8```@``@@`!`@`!@@`"`@`"@@`#`@`#@@```H``@H`!`H`!@
MH`"`H`"@H`#`H`#@H```P``@P`!`P`!@P`"`P`"@P`#`P`#@P```X``@X`!`
MX`!@X`"`X`"@X`#`X`#@X````$`@`$!``$!@`$"``$"@`$#``$#@`$``($`@
M($!`($!@($"`($"@($#`($#@($``0$`@0$!`0$!@0$"`0$"@0$#`0$#@0$``
M8$`@8$!`8$!@8$"`8$"@8$#`8$#@8$``@$`@@$!`@$!@@$"`@$"@@$#`@$#@
M@$``H$`@H$!`H$!@H$"`H$"@H$#`H$#@H$``P$`@P$!`P$!@P$"`P$"@P$#`
MP$#@P$``X$`@X$!`X$!@X$"`X$"@X$#`X$#@X$```(`@`(!``(!@`("``("@
M`(#``(#@`(``((`@((!`((!@(("`(("@((#`((#@((``0(`@0(!`0(!@0("`
M0("@0(#`0(#@0(``8(`@8(!`8(!@8("`8("@8(#`8(#@8(``@(`@@(!`@(!@
M@("`@("@@(#`@(#@@(``H(`@H(!`H(!@H("`H("@H(#`H(#@H(``P(`@P(!`
MP(!@P("`P("@P(#`P(#@P(``X(`@X(!`X(!@X("`X("@X(#`X(#@X(```,`@
M`,!``,!@`,"``,"@`,#``,#@`,``(,`@(,!`(,!@(,"`(,"@(,#`(,#@(,``
M0,`@0,!`0,!@0,"`0,"@0,#`0,#@0,``8,`@8,!`8,!@8,"`8,"@8,#`8,#@
M8,``@,`@@,!`@,!@@,"`@,"@@,#`@,#@@,``H,`@H,!`H,!@H,"`H,"@H,#`
MH,#@H,``P,`@P,!`P,!@P,"`P,"@P,#_^_"@H*2`@(#_````_P#__P```/__
M`/\`______\A^00!``#]`"P`````$@`2```(:`#["1Q(L*#!@PC[`5C(L*%#
M``(!_/LG<>+$BA8A*KQHD6-'C0]#,HQXT=\_?P1,HE0)DJ-)`B?_P339DB*!
MFSAS$@#),.9,F3%K`E"9\F11?T)U*A5*M.E)H3ZCTHPH,F3"JUBS:@T(`#L`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P
M97)A=&EO;G,O:6UG+V-O;"UI;G-E<G0M869T97(N9VEF````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`Q-3<@,3`U,34T,S,W-#0@,#,S-C0W
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````$=)
M1C@Y81(`$@#"``#A@(```(``______\```#___________\A^00!```'`"P`
M````$@`2```#-'BZW/Y0D4$)N"3.>D&&1"B*47D$9A.LJ;*^K1LO:#Q^)B$,
M`EY..Y]FUVL!!T(0,3EK'A(`.P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC
M97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS+VEM
M9R]C;VPM:6YS97)T+6)E9F]R92YG:68``#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P,34V(#$P-3$U-#,S-S0T(#`S-#`P-P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!'248X.6$2`!(`P@``
M````X8"`____``"``/______________(?D$`0``!P`L`````!(`$@```S-X
MNMS^\(%`@;@@SGI%AD`HBLX0/4-Z,FF[LF]CQL?XK0`A$/=IZ3V-CA?[>8K#
M(&T92P``.P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H
M=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]I;6<O<F]W+7!R;W`N
M9VEF```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,#(R-2`Q,#4Q-30S,S<T-"`P,S(R-3(`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````1TE&.#EA$@`2`*('````@.&`@,#`P``S
MF<S,S/___P```/___R'Y!`$```<`+``````2`!(```-:>+K<[B;*`\`[1NAM
MZLO9IGD-*(2;)T5GBW:6,0P@[4:#.N/[2>^Q`J%`'!:)0H/"($0:FT4E9D5=
M$:2&@';+W5Z7W;#V.ZU6R<RGVHF%NM58@GQ.IV/-^$,"`#L`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU
M9VEN<R]486)L94]P97)A=&EO;G,O:6UG+V-O;"UD96QE=&4N9VEF````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`Q-#0@,3`U,34T
M,S,W-#0@,#,R-3`R`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````$=)1C@Y81(`$@"A``````#_____``#___\A^00!```#`"P`
M````$@`2```"-9R/J<L&`9\(+Z9*I\#@0AI,W`64@&:6C40UR!EVKA.V\P!O
M-Y[NAN`[`'V"8I%X#`Z#S%L!`#L`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/
M<&5R871I;VYS+VEM9R]C96QL+7!R;W`N9VEF`````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,C,S(#$P-3$U-#,S-S0T(#`S,C,V
M,0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!'
M248X.6$2`!(`H@<`X8"```"`P,#``#.9S,S,____````____(?D$`0``!P`L
M`````!(`$@```V!XNMSN)LH3PCM&Z&WJR]FF>0THA)LG16>+=I8Q#"#M1H,Z
MX_M)[[$"H4`<%HG"#D:(-#*+2@-A)258KU.%H6``>+='J);K!8"?2>UTA<4:
MQLYX\[V4A].8MOY*I_JI!PD`.P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I
M8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]I
M;6<O=&%B;&4M<')O<"YG:68````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,#(R,2`Q,#4Q-30S,S<T-"`P,S(U,C8`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````1TE&.#EA$@`2`*(&
M````@,#`P``SF?___\S,S````/___P```"'Y!`$```8`+``````2`!(```-6
M:+K<[B5*`\`S)>A=ZLO9IGD-&(2;)T5GBW96(0@@[4:".N/[2>^Q`6%`'!:)
MPH*B($0:FT4EAD"M6JU2YG/KS$*_V^QU7/5RC]$EV-E=DLG9E7QN2```.P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O
M:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO;G,O:6UG+W)O=RUS<&QI
M="YG:68`````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#$U-S<@,3`U,34T,S,W-#0@,#,R-#0P`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````$=)1C@Y81(`$@#G``````"`````@`"`
M@````("``(``@(#`P,#`W,"FRO!`(`!@(`"`(`"@(`#`(`#@(```0``@0`!`
M0`!@0`"`0`"@0`#`0`#@0```8``@8`!`8`!@8`"`8`"@8`#`8`#@8```@``@
M@`!`@`!@@`"`@`"@@`#`@`#@@```H``@H`!`H`!@H`"`H`"@H`#`H`#@H```
MP``@P`!`P`!@P`"`P`"@P`#`P`#@P```X``@X`!`X`!@X`"`X`"@X`#`X`#@
MX````$`@`$!``$!@`$"``$"@`$#``$#@`$``($`@($!`($!@($"`($"@($#`
M($#@($``0$`@0$!`0$!@0$"`0$"@0$#`0$#@0$``8$`@8$!`8$!@8$"`8$"@
M8$#`8$#@8$``@$`@@$!`@$!@@$"`@$"@@$#`@$#@@$``H$`@H$!`H$!@H$"`
MH$"@H$#`H$#@H$``P$`@P$!`P$!@P$"`P$"@P$#`P$#@P$``X$`@X$!`X$!@
MX$"`X$"@X$#`X$#@X$```(`@`(!``(!@`("``("@`(#``(#@`(``((`@((!`
M((!@(("`(("@((#`((#@((``0(`@0(!`0(!@0("`0("@0(#`0(#@0(``8(`@
M8(!`8(!@8("`8("@8(#`8(#@8(``@(`@@(!`@(!@@("`@("@@(#`@(#@@(``
MH(`@H(!`H(!@H("`H("@H(#`H(#@H(``P(`@P(!`P(!@P("`P("@P(#`P(#@
MP(``X(`@X(!`X(!@X("`X("@X(#`X(#@X(```,`@`,!``,!@`,"``,"@`,#`
M`,#@`,``(,`@(,!`(,!@(,"`(,"@(,#`(,#@(,``0,`@0,!`0,!@0,"`0,"@
M0,#`0,#@0,``8,`@8,!`8,!@8,"`8,"@8,#`8,#@8,``@,`@@,!`@,!@@,"`
M@,"@@,#`@,#@@,``H,`@H,!`H,!@H,"`H,"@H,#`H,#@H,``P,`@P,!`P,!@
MP,"`P,"@P,#_^_"@H*2`@(#_````_P#__P```/__`/\`______\A^00!``#]
M`"P`````$@`2```(7`#["1Q(L*#!@PC[`5C(L*%#``(!_)LX42+%?Q8A*KR(
MD6/&B`]#+HSH[U_)DR9-?MR(LF5'C!$)R)Q)D\!*B2Y1-B29,N?-FD!OYNQY
MLZ?1DC=%ADS(M*G3IP$!`#L`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E
M9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO;G,O:6UG+W)O
M=RUI;G-E<G0M=6YD97(N9VEF````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`Q-C,@,3`U,34T,S,W-#0@,#,S-S$R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````$=)1C@Y81(`$@#"````__\`
M`(3A@(#___\```#___________\A^00!```'`"P`````$@`2```#.'BZW/[P
MD$E)5"-K>_6^AY=Q446!0JJ2D+JBKL`^Y@1"@6)&02X!`R"NUR,$@SP?`2CD
MZ2JWZ"T!`#L`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA
M<F5A+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS+VQA;F<`````````````````
M`````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P
M(#$P-3$U-#,S-S0T(#`S,#`V-0`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V
M:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO;G,O
M;&%N9R]E;BYJ<P``````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,3`P-S8@,3`U,34T,S,W-#0@,#,Q,3$P`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"\O($DQ.$X@8V]N
M<W1A;G1S"@HO+R!,04Y'.B`B96XB+"!%3D-/1$E.1SH@551&+3@@?"!)4T\M
M.#@U.2TQ"B\O($%U=&AO<CH@36EH86D@0F%Z;VXL(&AT='`Z+R]D>6YA<F-H
M+F-O;2]M:7-H;V\*"B\O($9/4B!44D%.4TQ!5$]24SH*+R\*+R\@("`Q+B!0
M3$5!4T4@4%54(%E/55(@0T].5$%#5"!)3D9/($E.(%1(12!!0D]612!,24Y%
M"B\O("`@("`@*&%T(&QE87-T(&$@=F%L:60@96UA:6P@861D<F5S<RD*+R\*
M+R\@("`R+B!03$5!4T4@5%)9(%1/(%5312!55$8M."!&3U(@14Y#3T1)3D<[
M"B\O("`@("`@*&EF('1H:7,@:7,@;F]T('!O<W-I8FQE+"!P;&5A<V4@:6YC
M;'5D92!A(&-O;6UE;G0*+R\@("`@("`@=&AA="!S=&%T97,@=VAA="!E;F-O
M9&EN9R!I<R!N96-E<W-A<GDN*0H*5&%B;&5/<&5R871I;VYS+DDQ.$X@/2![
M"@DB06QI9VXB.@D)"0D)("`B06QI9VXB+`H)(D%L;"!F;W5R('-I9&5S(CH)
M"0D)("`B06QL(&9O=7(@<VED97,B+`H)(D)A8VMG<F]U;F0B.@D)"0D)("`B
M0F%C:V=R;W5N9"(L"@DB0F%S96QI;F4B.B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(")"87-E;&EN92(L"@DB0F]R9&5R(CH)"0D)
M"2`@(D)O<F1E<B(L"@DB0F]R9&5R<R(Z"0D)"0D@(")";W)D97)S(BP*"2)"
M;W1T;VTB.B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(D)O='1O;2(L"@DB0U-3(%-T>6QE(CH)"0D)"2`@(E-T>6QE(%M#4U-=
M(BP*"2)#87!T:6]N(CH)"0D)"2`@(D-A<'1I;VXB+`H)(D-E;&P@4')O<&5R
M=&EE<R(Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B0V5L;"!0
M<F]P97)T:65S(BP*"2)#96YT97(B.@D)"0D)("`B0V5N=&5R(BP*"2)#:&%R
M(CH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(D-H87(B+`H)(D-O;&QA<'-E9"!B;W)D97)S(CH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`B0V]L;&%P<V5D(&)O<F1E<G,B+`H)(D-O;&]R(CH)
M"0D)"2`@(D-O;&]R(BP*"2)$97-C<FEP=&EO;B(Z"0D)"0D@(")$97-C<FEP
M=&EO;B(L"@DB1D<@0V]L;W(B.@D)"0D)("`B1D<@0V]L;W(B+`H)(D9L;V%T
M(CH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B
M1FQO870B+`H)(D9R86UE<R(Z"0D)"0D@(")&<F%M97,B+`H)(DAE:6=H="(Z
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B2&5I
M9VAT(BP*"2)(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE
M<F=E/R(Z("`@("`@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@
M=&\@;65R9V4_(BP*"2)(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O
M(&UE<F=E/R(Z("`@("`@("`@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI
M:V4@=&\@;65R9V4_(BP*"2));6%G92!54DPB.@D)"0D)("`B26UA9V4@55),
M(BP*"2)*=7-T:69Y(CH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(DIU<W1I9GDB+`H)(DQA>6]U="(Z"0D)"0D@("),87EO=70B
M+`H)(DQE9G0B.@D)"0D)"2`@(DQE9G0B+`H)(DUA<F=I;B(Z("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B36%R9VEN(BP*"2)-
M:61D;&4B.B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(DUI9&1L92(L"@DB3F\@<G5L97,B.@D)"0D)("`B3F\@<G5L97,B+`H)
M(DYO('-I9&5S(CH)"0D)"2`@(DYO('-I9&5S(BP*"2).;VYE(CH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(DYO;F4B+`H)
M(E!A9&1I;F<B.@D)"0D)("`B4&%D9&EN9R(L"@DB4&QE87-E(&-L:6-K(&EN
M=&\@<V]M92!C96QL(CH@("`@("`@("`@("`@("`@("`@(")0;&5A<V4@8VQI
M8VL@:6YT;R!S;VUE(&-E;&PB+`H)(E)I9VAT(CH)"0D)"2`@(E)I9VAT(BP*
M"2)2;W<@4')O<&5R=&EE<R(Z("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(E)O=R!0<F]P97)T:65S(BP*"2)2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(CH@(E)U;&5S('=I;&P@87!P
M96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B+`H)(E)U;&5S('=I
M;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(CH)("`B4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB+`H)(E)U;&5S('=I;&P@
M87!P96%R(&)E='=E96X@<F]W<R!O;FQY(CH)"2`@(E)U;&5S('=I;&P@87!P
M96%R(&)E='=E96X@<F]W<R!O;FQY(BP*"2)2=6QE<R(Z"0D)"0D@(")2=6QE
M<R(L"@DB4W!A8VEN9R!A;F0@<&%D9&EN9R(Z("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(")3<&%C:6YG(&%N9"!P861D:6YG(BP*"2)3<&%C:6YG(CH)
M"0D)"2`@(E-P86-I;F<B+`H)(E-U;6UA<GDB.@D)"0D)("`B4W5M;6%R>2(L
M"@DB5$\M8V5L;"UD96QE=&4B.@D)"0D@(")$96QE=&4@8V5L;"(L"@DB5$\M
M8V5L;"UI;G-E<G0M869T97(B.@D)"0D@("));G-E<G0@8V5L;"!A9G1E<B(L
M"@DB5$\M8V5L;"UI;G-E<G0M8F5F;W)E(CH)"0D@("));G-E<G0@8V5L;"!B
M969O<F4B+`H)(E1/+6-E;&PM;65R9V4B.@D)"0D@(")-97)G92!C96QL<R(L
M"@DB5$\M8V5L;"UP<F]P(CH)"0D)"2`@(D-E;&P@<')O<&5R=&EE<R(L"@DB
M5$\M8V5L;"US<&QI="(Z"0D)"2`@(E-P;&ET(&-E;&PB+`H)(E1/+6-O;"UD
M96QE=&4B.@D)"0D@(")$96QE=&4@8V]L=6UN(BP*"2)43RUC;VPM:6YS97)T
M+6%F=&5R(CH)"0D)("`B26YS97)T(&-O;'5M;B!A9G1E<B(L"@DB5$\M8V]L
M+6EN<V5R="UB969O<F4B.@D)"0D@("));G-E<G0@8V]L=6UN(&)E9F]R92(L
M"@DB5$\M8V]L+7-P;&ET(CH)"0D)"2`@(E-P;&ET(&-O;'5M;B(L"@DB5$\M
M<F]W+61E;&5T92(Z"0D)"2`@(D1E;&5T92!R;W<B+`H)(E1/+7)O=RUI;G-E
M<G0M86)O=F4B.@D)"0D@("));G-E<G0@<F]W(&)E9F]R92(L"@DB5$\M<F]W
M+6EN<V5R="UU;F1E<B(Z"0D)"2`@(DEN<V5R="!R;W<@869T97(B+`H)(E1/
M+7)O=RUP<F]P(CH)"0D)"2`@(E)O=R!P<F]P97)T:65S(BP*"2)43RUR;W<M
M<W!L:70B.@D)"0D)("`B4W!L:70@<F]W(BP*"2)43RUT86)L92UP<F]P(CH)
M"0D)("`B5&%B;&4@<')O<&5R=&EE<R(L"@DB5&%B;&4@4')O<&5R=&EE<R(Z
M"0D)"2`@(E1A8FQE(%!R;W!E<G1I97,B+`H)(E1E>'0@86QI9VXB.B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B5&5X="!A;&EG;B(L
M"@DB5&AE(&)O='1O;2!S:61E(&]N;'DB.@D)"0D@(")4:&4@8F]T=&]M('-I
M9&4@;VYL>2(L"@DB5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB.@D)"2`@(E1H
M92!L969T+6AA;F0@<VED92!O;FQY(BP*"2)4:&4@<FEG:'0@86YD(&QE9G0@
M<VED97,@;VYL>2(Z"0D@(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL
M>2(L"@DB5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(CH)"0D@(")4:&4@<FEG
M:'0M:&%N9"!S:61E(&]N;'DB+`H)(E1H92!T;W`@86YD(&)O='1O;2!S:61E
M<R!O;FQY(CH)"2`@(E1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(BP*
M"2)4:&4@=&]P('-I9&4@;VYL>2(Z"0D)"2`@(E1H92!T;W`@<VED92!O;FQY
M(BP*"2)4;W`B.B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(E1O<"(L"0H)(E5N<V5T(&-O;&]R(CH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`B56YS970@8V]L;W(B+`H)(E9E<G1I
M8V%L(&%L:6=N(CH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B
M5F5R=&EC86P@86QI9VXB+`H)(E=I9'1H(CH)"0D)"2`@(E=I9'1H(BP*"2)N
M;W0M9&5L+6QA<W0M8V5L;"(Z"0D)"2`@(DA434Q!<F5A(&-O=V%R9&QY(')E
M9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+B(L"@DB;F]T
M+61E;"UL87-T+6-O;"(Z"0D)"2`@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S
M97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB+`H)(FYO
M="UD96PM;&%S="UR;W<B.@D)"0D@(")(5$U,07)E82!C;W=A<F1L>2!R969U
M<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(BP*"2)P97)C
M96YT(CH)"0D)"2`@(G!E<F-E;G0B+`H)(G!I>&5L<R(Z"0D)"0D@(")P:7AE
M;',B"GT["@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O
M<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]T86)L92UO<&5R
M871I;VYS+FIS```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#$P,#(R,"`Q,#4Q-30S,S<T-"`P,S,P,C0`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+R\@5&%B;&4@3W!E<F%T:6]N<R!0
M;'5G:6X@9F]R($A434Q!<F5A+3,N,`HO+R!);7!L96UE;G1A=&EO;B!B>2!-
M:6AA:2!"87IO;BX@(%-P;VYS;W)E9"!B>2!H='1P.B\O=W=W+GIA<&%T96,N
M8V]M"B\O"B\O($-O<'ER:6=H="`H8RD@9'EN87)C:"YC;VT@,C`P,RTR,#`U
M"B\O(%1H:7,@8V]P>7)I9VAT(&YO=&EC92!M=7-T('-T87D@:6YT86-T(&9O
M<B!U<V4N"B\O"B\O("1)9#H@=&%B;&4M;W!E<F%T:6]N<RYJ<RQV(#$N-R`R
M,#`U+S`Q+S(P(#$W.C0Y.C`R(&UI<VAO;R!%>'`@)`H*+R\@3V)J96-T('1H
M870@=VEL;"!E;F-A<'-U;&%T92!A;&P@=&AE('1A8FQE(&]P97)A=&EO;G,@
M<')O=FED960@8GD*+R\@2%1-3$%R96$M,RXP("AE>&-E<'0@(FEN<V5R="!T
M86)L92(@=VAI8V@@:7,@:6YC;'5D960@:6X@=&AE(&UA:6X@9FEL92D*9G5N
M8W1I;VX@5&%B;&5/<&5R871I;VYS*&5D:71O<BD@>PH)=&AI<RYE9&ET;W(@
M/2!E9&ET;W(["@H)=F%R(&-F9R`](&5D:71O<BYC;VYF:6<["@EV87(@='0@
M/2!486)L94]P97)A=&EO;G,N23$X3CL*"79A<B!B;"`](%1A8FQE3W!E<F%T
M:6]N<RYB=&Y,:7-T.PH)=F%R('-E;&8@/2!T:&ES.PH*"2\O(')E9VES=&5R
M('1H92!T;V]L8F%R(&)U='1O;G,@<')O=FED960@8GD@=&AI<R!P;'5G:6X*
M"79A<B!T;V]L8F%R(#T@6R)L:6YE8G)E86LB73L*"69O<B`H=F%R(&D@/2`P
M.R!I(#P@8FPN;&5N9W1H.R`K*VDI('L*"0EV87(@8G1N(#T@8FQ;:5T["@D)
M:68@*"%B=&XI('L*"0D)=&]O;&)A<BYP=7-H*")S97!A<F%T;W(B*3L*"0E]
M(&5L<V4@>PH)"0EV87(@:60@/2`B5$\M(B`K(&)T;ELP73L*"0D)8V9G+G)E
M9VES=&5R0G5T=&]N*&ED+"!T=%MI9%TL(&5D:71O<BYI;6=54DPH8G1N6S!=
M("L@(BYG:68B+"`B5&%B;&5/<&5R871I;VYS(BDL(&9A;'-E+`H)"0D)"2`@
M(&9U;F-T:6]N*&5D:71O<BP@:60I('L*"0D)"0D)("`@+R\@9&ES<&%T8V@@
M8G5T=&]N('!R97-S(&5V96YT"@D)"0D)"2`@('-E;&8N8G5T=&]N4')E<W,H
M961I=&]R+"!I9"D["@D)"0D)("`@?2P@8G1N6S%=*3L*"0D)=&]O;&)A<BYP
M=7-H*&ED*3L*"0E]"@E]"@H)+R\@861D(&$@;F5W(&QI;F4@:6X@=&AE('1O
M;VQB87(*"6-F9RYT;V]L8F%R+G!U<V@H=&]O;&)A<BD["GT["@I486)L94]P
M97)A=&EO;G,N7W!L=6=I;DEN9F\@/2!["@EN86UE("`@("`@("`@(#H@(E1A
M8FQE3W!E<F%T:6]N<R(L"@EV97)S:6]N("`@("`@(#H@(C$N,"(L"@ED979E
M;&]P97(@("`@(#H@(DUI:&%I($)A>F]N(BP*"61E=F5L;W!E<E]U<FP@.B`B
M:'1T<#HO+V1Y;F%R8V@N8V]M+VUI<VAO;R\B+`H)8U]O=VYE<B`@("`@("`Z
M(")-:6AA:2!"87IO;B(L"@ES<&]N<V]R("`@("`@(#H@(EIA<&%T96,@26YC
M+B(L"@ES<&]N<V]R7W5R;"`@(#H@(FAT='`Z+R]W=W<N8FQO:VDN8V]M(BP*
M"6QI8V5N<V4@("`@("`@.B`B:'1M;$%R96$B"GT["@HO*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ"B`J(%5424Q)5$E%4PH@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ+PH*+R\@<F5T<FEE=F5S('1H92!C;&]S97-T(&5L96UE;G0@:&%V
M:6YG('1H92!S<&5C:69I960@=&%G3F%M92!I;B!T:&4@;&ES="!O9@HO+R!A
M;F-E<W1O<G,@;V8@=&AE(&-U<G)E;G0@<V5L96-T:6]N+V-A<F5T+@I486)L
M94]P97)A=&EO;G,N<')O=&]T>7!E+F=E=$-L;W-E<W0@/2!F=6YC=&EO;BAT
M86=.86UE*2!["@EV87(@961I=&]R(#T@=&AI<RYE9&ET;W(["@EV87(@86YC
M97-T;W)S(#T@961I=&]R+F=E=$%L;$%N8V5S=&]R<R@I.PH)=F%R(')E="`]
M(&YU;&P["@ET86=.86UE(#T@*"(B("L@=&%G3F%M92DN=&],;W=E<D-A<V4H
M*3L*"69O<B`H=F%R(&D@/2`P.R!I(#P@86YC97-T;W)S+FQE;F=T:#L@*RMI
M*2!["@D)=F%R(&5L(#T@86YC97-T;W)S6VE=.PH)"6EF("AE;"YT86=.86UE
M+G1O3&]W97)#87-E*"D@/3T@=&%G3F%M92D@>PH)"0ER970@/2!E;#L*"0D)
M8G)E86L["@D)?0H)?0H)<F5T=7)N(')E=#L*?3L*"B\O('1H:7,@9G5N8W1I
M;VX@<F5Q=6ER97,@=&AE(&9I;&4@4&]P=7!$:78O4&]P=7!7:6X@=&\@8F4@
M;&]A9&5D(&9R;VT@8G)O=W-E<@I486)L94]P97)A=&EO;G,N<')O=&]T>7!E
M+F1I86QO9U1A8FQE4')O<&5R=&EE<R`](&9U;F-T:6]N*"D@>PH)=F%R(&DQ
M.&X@/2!486)L94]P97)A=&EO;G,N23$X3CL*"2\O(')E=')I979E(&5X:7-T
M:6YG('9A;'5E<PH)=F%R('1A8FQE(#T@=&AI<RYG971#;&]S97-T*")T86)L
M92(I.PH)+R\@=&AI<RYE9&ET;W(N<V5L96-T3F]D94-O;G1E;G1S*'1A8FQE
M*3L*"2\O('1H:7,N961I=&]R+G5P9&%T951O;VQB87(H*3L*"@EV87(@9&EA
M;&]G(#T@;F5W(%!O<'5P5VEN*'1H:7,N961I=&]R+"!I,3AN6R)486)L92!0
M<F]P97)T:65S(ETL(&9U;F-T:6]N*&1I86QO9RP@<&%R86US*2!["@D)5&%B
M;&5/<&5R871I;VYS+G!R;V-E<W-3='EL92AP87)A;7,L('1A8FQE*3L*"0EF
M;W(@*'9A<B!I(&EN('!A<F%M<RD@>PH)"0EV87(@=F%L(#T@<&%R86US6VE=
M.PH)"0ES=VET8V@@*&DI('L*"0D)("`@(&-A<V4@(F9?8V%P=&EO;B(Z"@D)
M"0EI9B`H+UQ3+RYT97-T*'9A;"DI('L*"0D)"0DO+R!C;VYT86EN<R!N;VX@
M=VAI=&4M<W!A8V4@8VAA<F%C=&5R<PH)"0D)"79A<B!C87!T:6]N(#T@=&%B
M;&4N9V5T16QE;65N='-">51A9TYA;64H(F-A<'1I;VXB*5LP73L*"0D)"0EI
M9B`H(6-A<'1I;VXI('L*"0D)"0D)8V%P=&EO;B`](&1I86QO9RYE9&ET;W(N
M7V1O8RYC<F5A=&5%;&5M96YT*")C87!T:6]N(BD["@D)"0D)"71A8FQE+FEN
M<V5R=$)E9F]R92AC87!T:6]N+"!T86)L92YF:7)S=$-H:6QD*3L*"0D)"0E]
M"@D)"0D)8V%P=&EO;BYI;FYE<DA434P@/2!V86P["@D)"0E](&5L<V4@>PH)
M"0D)"2\O('-E87)C:"!F;W(@8V%P=&EO;B!A;F0@9&5L971E(&ET(&EF(&9O
M=6YD"@D)"0D)=F%R(&-A<'1I;VX@/2!T86)L92YG971%;&5M96YT<T)Y5&%G
M3F%M92@B8V%P=&EO;B(I6S!=.PH)"0D)"6EF("AC87!T:6]N*2!["@D)"0D)
M"6-A<'1I;VXN<&%R96YT3F]D92YR96UO=F5#:&EL9"AC87!T:6]N*3L*"0D)
M"0E]"@D)"0E]"@D)"0EB<F5A:SL*"0D)("`@(&-A<V4@(F9?<W5M;6%R>2(Z
M"@D)"0ET86)L92YS=6UM87)Y(#T@=F%L.PH)"0D)8G)E86L["@D)"2`@("!C
M87-E(")F7W=I9'1H(CH*"0D)"71A8FQE+G-T>6QE+G=I9'1H(#T@*"(B("L@
M=F%L*2`K('!A<F%M<RYF7W5N:70["@D)"0EB<F5A:SL*"0D)("`@(&-A<V4@
M(F9?86QI9VXB.@H)"0D)=&%B;&4N86QI9VX@/2!V86P["@D)"0EB<F5A:SL*
M"0D)("`@(&-A<V4@(F9?<W!A8VEN9R(Z"@D)"0ET86)L92YC96QL4W!A8VEN
M9R`]('9A;#L*"0D)"6)R96%K.PH)"0D@("`@8V%S92`B9E]P861D:6YG(CH*
M"0D)"71A8FQE+F-E;&Q0861D:6YG(#T@=F%L.PH)"0D)8G)E86L["@D)"2`@
M("!C87-E(")F7V)O<F1E<G,B.@H)"0D)=&%B;&4N8F]R9&5R(#T@=F%L.PH)
M"0D)8G)E86L["@D)"2`@("!C87-E(")F7V9R86UE<R(Z"@D)"0ET86)L92YF
M<F%M92`]('9A;#L*"0D)"6)R96%K.PH)"0D@("`@8V%S92`B9E]R=6QE<R(Z
M"@D)"0ET86)L92YR=6QE<R`]('9A;#L*"0D)"6)R96%K.PH)"0E]"@D)?0H)
M"2\O('9A<FEO=7,@=V]R:V%R;W5N9',@=&\@<F5F<F5S:"!T:&4@=&%B;&4@
M9&ES<&QA>2`H1V5C:V\L"@D)+R\@=VAA="=S(&=O:6YG(&]N/R$@9&\@;F]T
M(&1I<V%P<&]I;G0@;64A*0H)"61I86QO9RYE9&ET;W(N9F]R8V52961R87<H
M*3L*"0ED:6%L;V<N961I=&]R+F9O8W5S161I=&]R*"D["@D)9&EA;&]G+F5D
M:71O<BYU<&1A=&54;V]L8F%R*"D["@D)=F%R('-A=F5?8V]L;&%P<V4@/2!T
M86)L92YS='EL92YB;W)D97)#;VQL87!S93L*"0ET86)L92YS='EL92YB;W)D
M97)#;VQL87!S92`](")C;VQL87!S92(["@D)=&%B;&4N<W1Y;&4N8F]R9&5R
M0V]L;&%P<V4@/2`B<V5P87)A=&4B.PH)"71A8FQE+G-T>6QE+F)O<F1E<D-O
M;&QA<'-E(#T@<V%V95]C;VQL87!S93L*"7TL"@H)+R\@=&AI<R!F=6YC=&EO
M;B!G971S(&-A;&QE9"!W:&5N('1H92!D:6%L;V<@;F5E9',@=&\@8F4@:6YI
M=&EA;&EZ960*"69U;F-T:6]N("AD:6%L;V<I('L*"@D)=F%R(&9?8V%P=&EO
M;B`]("(B.PH)"79A<B!C87!E;"`]('1A8FQE+F=E=$5L96UE;G1S0GE486=.
M86UE*")C87!T:6]N(BE;,%T["@D):68@*&-A<&5L*2!["@D)"69?8V%P=&EO
M;B`](&-A<&5L+FEN;F5R2%1-3#L*"0E]"@D)=F%R(&9?<W5M;6%R>2`]('1A
M8FQE+G-U;6UA<GD["@D)=F%R(&9?=VED=&@@/2!P87)S94EN="AT86)L92YS
M='EL92YW:61T:"D["@D):7-.84XH9E]W:61T:"D@)B8@*&9?=VED=&@@/2`B
M(BD["@D)=F%R(&9?=6YI="`]("\E+RYT97-T*'1A8FQE+G-T>6QE+G=I9'1H
M*2`_("=P97)C96YT)R`Z("=P:7AE;',G.PH)"79A<B!F7V%L:6=N(#T@=&%B
M;&4N86QI9VX["@D)=F%R(&9?<W!A8VEN9R`]('1A8FQE+F-E;&Q3<&%C:6YG
M.PH)"79A<B!F7W!A9&1I;F<@/2!T86)L92YC96QL4&%D9&EN9SL*"0EV87(@
M9E]B;W)D97)S(#T@=&%B;&4N8F]R9&5R.PH)"79A<B!F7V9R86UE<R`]('1A
M8FQE+F9R86UE.PH)"79A<B!F7W)U;&5S(#T@=&%B;&4N<G5L97,["@H)"69U
M;F-T:6]N('-E;&5C=&5D*'9A;"D@>PH)"0ER971U<FX@=F%L(#\@(B!S96QE
M8W1E9"(@.B`B(CL*"0E].PH*"0DO+R!D:6%L;V<@8V]N=&5N=',*"0ED:6%L
M;V<N8V]N=&5N="YS='EL92YW:61T:"`]("(T,#!P>"(["@D)9&EA;&]G+F-O
M;G1E;G0N:6YN97)(5$U,(#T@(B!<"CQD:78@8VQA<W,])W1I=&QE)UP*('-T
M>6QE/2=B86-K9W)O=6YD.B!U<FPH(B`K(&1I86QO9RYB87-E55),("L@9&EA
M;&]G+F5D:71O<BYI;6=54DPH(G1A8FQE+7!R;W`N9VEF(BP@(E1A8FQE3W!E
M<F%T:6]N<R(I("L@(BD@(V9F9B`Y."4@-3`E(&YO+7)E<&5A="<^(B`K(&DQ
M.&Y;(E1A8FQE(%!R;W!E<G1I97,B72`K(")<"CPO9&EV/B!<"CQT86)L92!S
M='EL93TG=VED=&@Z,3`P)2<^(%P*("`\='(^(%P*("`@(#QT9#X@7`H@("`@
M("`\9FEE;&1S970^/&QE9V5N9#XB("L@:3$X;ELB1&5S8W)I<'1I;VXB72`K
M("(\+VQE9V5N9#X@7`H@("`@("`@/'1A8FQE('-T>6QE/2=W:61T:#HQ,#`E
M)SX@7`H@("`@("`@(#QT<CX@7`H@("`@("`@("`@/'1D(&-L87-S/2=L86)E
M;"<^(B`K(&DQ.&Y;(D-A<'1I;VXB72`K("(Z/"]T9#X@7`H@("`@("`@("`@
M/'1D(&-L87-S/2=V86QU92<^/&EN<'5T('1Y<&4])W1E>'0G(&YA;64])V9?
M8V%P=&EO;B<@=F%L=64])R(@*R!F7V-A<'1I;VX@*R`B)R\^/"]T9#X@7`H@
M("`@("`@(#PO='(^/'1R/B!<"B`@("`@("`@("`\=&0@8VQA<W,])VQA8F5L
M)SXB("L@:3$X;ELB4W5M;6%R>2)=("L@(CH\+W1D/B!<"B`@("`@("`@("`\
M=&0@8VQA<W,])W9A;'5E)SX\:6YP=70@='EP93TG=&5X="<@;F%M93TG9E]S
M=6UM87)Y)R!V86QU93TG(B`K(&9?<W5M;6%R>2`K("(G+SX\+W1D/B!<"B`@
M("`@("`@/"]T<CX@7`H@("`@("`@/"]T86)L93X@7`H@("`@("`\+V9I96QD
M<V5T/B!<"B`@("`\+W1D/B!<"B`@/"]T<CX@7`H@(#QT<CX\=&0@:60])RTM
M2$$M;&%Y;W5T)SX\+W1D/CPO='(^(%P*("`\='(^(%P*("`@(#QT9#X@7`H@
M("`@("`\9FEE;&1S970^/&QE9V5N9#XB("L@:3$X;ELB4W!A8VEN9R!A;F0@
M<&%D9&EN9R)=("L@(CPO;&5G96YD/B!<"B`@("`@("`\=&%B;&4@<W1Y;&4]
M)W=I9'1H.C$P,"4G/B!<"B`@("`@("`@/'1R/B!<"B`@("`@("`@("`\=&0@
M8VQA<W,])VQA8F5L)SXB("L@:3$X;ELB4W!A8VEN9R)=("L@(CH\+W1D/B!<
M"B`@("`@("`@("`\=&0^/&EN<'5T('1Y<&4])W1E>'0G(&YA;64])V9?<W!A
M8VEN9R<@<VEZ93TG-2<@=F%L=64])R(@*R!F7W-P86-I;F<@*R`B)R`O/B`F
M;F)S<#LB("L@:3$X;ELB4&%D9&EN9R)=("L@(CI<"B`@("`@("`@("`@(#QI
M;G!U="!T>7!E/2=T97AT)R!N86UE/2=F7W!A9&1I;F<G('-I>F4])S4G('9A
M;'5E/2<B("L@9E]P861D:6YG("L@(B<@+SX@)FYB<W`[)FYB<W`[(B`K(&DQ
M.&Y;(G!I>&5L<R)=("L@(EP*("`@("`@("`@(#PO=&0^(%P*("`@("`@("`\
M+W1R/B!<"B`@("`@("`\+W1A8FQE/B!<"B`@("`@(#PO9FEE;&1S970^(%P*
M("`@(#PO=&0^(%P*("`\+W1R/B!<"B`@/'1R/B!<"B`@("`\=&0^(%P*("`@
M("`@/&9I96QD<V5T/CQL96=E;F0^1G)A;64@86YD(&)O<F1E<G,\+VQE9V5N
M9#X@7`H@("`@("`@(#QT86)L92!W:61T:#TG,3`P)2<^(%P*("`@("`@("`@
M(#QT<CX@7`H@("`@("`@("`@("`\=&0@8VQA<W,])VQA8F5L)SXB("L@:3$X
M;ELB0F]R9&5R<R)=("L@(CH\+W1D/B!<"B`@("`@("`@("`@(#QT9#X\:6YP
M=70@;F%M93TG9E]B;W)D97)S)R!T>7!E/2=T97AT)R!S:7IE/2<U)R!V86QU
M93TG(B`K(&9?8F]R9&5R<R`K("(G("\^("9N8G-P.R9N8G-P.R(@*R!I,3AN
M6R)P:7AE;',B72`K("(\+W1D/B!<"B`@("`@("`@("`\+W1R/B!<"B`@("`@
M("`@("`\='(^(%P*("`@("`@("`@("`@/'1D(&-L87-S/2=L86)E;"<^(B`K
M(&DQ.&Y;(D9R86UE<R)=("L@(CH\+W1D/B!<"B`@("`@("`@("`@(#QT9#X@
M7`H@("`@("`@("`@("`@(#QS96QE8W0@;F%M93TG9E]F<F%M97,G/B!<"B`@
M("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2=V;VED)R(@*R!S96QE8W1E
M9"AF7V9R86UE<R`]/2`B=F]I9"(I("L@(CXB("L@:3$X;ELB3F\@<VED97,B
M72`K("(\+V]P=&EO;CX@7`H@("`@("`@("`@("`@("`@/&]P=&EO;B!V86QU
M93TG86)O=F4G(B`K('-E;&5C=&5D*&9?9G)A;65S(#T](")A8F]V92(I("L@
M(CXB("L@:3$X;ELB5&AE('1O<"!S:61E(&]N;'DB72`K("(\+V]P=&EO;CX@
M7`H@("`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TG8F5L;W<G(B`K('-E
M;&5C=&5D*&9?9G)A;65S(#T](")B96QO=R(I("L@(CXB("L@:3$X;ELB5&AE
M(&)O='1O;2!S:61E(&]N;'DB72`K("(\+V]P=&EO;CX@7`H@("`@("`@("`@
M("`@("`@/&]P=&EO;B!V86QU93TG:'-I9&5S)R(@*R!S96QE8W1E9"AF7V9R
M86UE<R`]/2`B:'-I9&5S(BD@*R`B/B(@*R!I,3AN6R)4:&4@=&]P(&%N9"!B
M;W1T;VT@<VED97,@;VYL>2)=("L@(CPO;W!T:6]N/B!<"B`@("`@("`@("`@
M("`@("`\;W!T:6]N('9A;'5E/2=V<VED97,G(B`K('-E;&5C=&5D*&9?9G)A
M;65S(#T](")V<VED97,B*2`K("(^(B`K(&DQ.&Y;(E1H92!R:6=H="!A;F0@
M;&5F="!S:61E<R!O;FQY(ET@*R`B/"]O<'1I;VX^(%P*("`@("`@("`@("`@
M("`@(#QO<'1I;VX@=F%L=64])VQH<R<B("L@<V5L96-T960H9E]F<F%M97,@
M/3T@(FQH<R(I("L@(CXB("L@:3$X;ELB5&AE(&QE9G0M:&%N9"!S:61E(&]N
M;'DB72`K("(\+V]P=&EO;CX@7`H@("`@("`@("`@("`@("`@/&]P=&EO;B!V
M86QU93TG<FAS)R(@*R!S96QE8W1E9"AF7V9R86UE<R`]/2`B<FAS(BD@*R`B
M/B(@*R!I,3AN6R)4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB72`K("(\+V]P
M=&EO;CX@7`H@("`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TG8F]X)R(@
M*R!S96QE8W1E9"AF7V9R86UE<R`]/2`B8F]X(BD@*R`B/B(@*R!I,3AN6R)!
M;&P@9F]U<B!S:61E<R)=("L@(CPO;W!T:6]N/B!<"B`@("`@("`@("`@("`@
M/"]S96QE8W0^(%P*("`@("`@("`@("`@/"]T9#X@7`H@("`@("`@("`@/"]T
M<CX@7`H@("`@("`@("`@/'1R/B!<"B`@("`@("`@("`@(#QT9"!C;&%S<STG
M;&%B96PG/B(@*R!I,3AN6R)2=6QE<R)=("L@(CH\+W1D/B!<"B`@("`@("`@
M("`@(#QT9#X@7`H@("`@("`@("`@("`@(#QS96QE8W0@;F%M93TG9E]R=6QE
M<R<^(%P*("`@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64])VYO;F4G(B`K
M('-E;&5C=&5D*&9?<G5L97,@/3T@(FYO;F4B*2`K("(^(B`K(&DQ.&Y;(DYO
M(')U;&5S(ET@*R`B/"]O<'1I;VX^(%P*("`@("`@("`@("`@("`@(#QO<'1I
M;VX@=F%L=64])W)O=W,G(B`K('-E;&5C=&5D*&9?<G5L97,@/3T@(G)O=W,B
M*2`K("(^(B`K(&DQ.&Y;(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W
M<R!O;FQY(ET@*R`B/"]O<'1I;VX^(%P*("`@("`@("`@("`@("`@(#QO<'1I
M;VX@=F%L=64])V-O;',G(B`K('-E;&5C=&5D*&9?<G5L97,@/3T@(F-O;',B
M*2`K("(^(B`K(&DQ.&Y;(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L
M=6UN<R!O;FQY(ET@*R`B/"]O<'1I;VX^(%P*("`@("`@("`@("`@("`@(#QO
M<'1I;VX@=F%L=64])V%L;"<B("L@<V5L96-T960H9E]R=6QE<R`]/2`B86QL
M(BD@*R`B/B(@*R!I,3AN6R)2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L
M;"!R;W=S(&%N9"!C;VQU;6YS(ET@*R`B/"]O<'1I;VX^(%P*("`@("`@("`@
M("`@("`\+W-E;&5C=#X@7`H@("`@("`@("`@("`\+W1D/B!<"B`@("`@("`@
M("`\+W1R/B!<"B`@("`@("`@/"]T86)L93X@7`H@("`@("`\+V9I96QD<V5T
M/B!<"B`@("`\+W1D/B!<"B`@/"]T<CX@7`H@(#QT<CX@7`H@("`@/'1D(&ED
M/2<M+4A!+7-T>6QE)SX\+W1D/B!<"B`@/"]T<CX@7`H\+W1A8FQE/B!<"B([
M"@D)=F%R('-T7W!R;W`@/2!486)L94]P97)A=&EO;G,N8W)E871E4W1Y;&5&
M:65L9'-E="AD:6%L;V<N9&]C+"!D:6%L;V<N961I=&]R+"!T86)L92D["@D)
M=F%R('`@/2!D:6%L;V<N9&]C+F=E=$5L96UE;G1">4ED*"(M+4A!+7-T>6QE
M(BD["@D)<"YA<'!E;F1#:&EL9"AS=%]P<F]P*3L*"0EV87(@<W1?;&%Y;W5T
M(#T@5&%B;&5/<&5R871I;VYS+F-R96%T95-T>6QE3&%Y;W5T1FEE;&1S970H
M9&EA;&]G+F1O8RP@9&EA;&]G+F5D:71O<BP@=&%B;&4I.PH)"7`@/2!D:6%L
M;V<N9&]C+F=E=$5L96UE;G1">4ED*"(M+4A!+6QA>6]U="(I.PH)"7`N87!P
M96YD0VAI;&0H<W1?;&%Y;W5T*3L*"0ED:6%L;V<N;6]D86P@/2!T<G5E.PH)
M"61I86QO9RYA9&1"=71T;VYS*")O:R(L(")C86YC96PB*3L*"0ED:6%L;V<N
M<VAO=T%T16QE;65N="AD:6%L;V<N961I=&]R+E]I9G)A;64L(")C(BD["@E]
M*3L*?3L*"B\O('1H:7,@9G5N8W1I;VX@<F5Q=6ER97,@=&AE(&9I;&4@4&]P
M=7!$:78O4&]P=7!7:6X@=&\@8F4@;&]A9&5D(&9R;VT@8G)O=W-E<@I486)L
M94]P97)A=&EO;G,N<')O=&]T>7!E+F1I86QO9U)O=T-E;&Q0<F]P97)T:65S
M(#T@9G5N8W1I;VXH8V5L;"D@>PH)=F%R(&DQ.&X@/2!486)L94]P97)A=&EO
M;G,N23$X3CL*"2\O(')E=')I979E(&5X:7-T:6YG('9A;'5E<PH)=F%R(&5L
M96UE;G0@/2!T:&ES+F=E=$-L;W-E<W0H8V5L;"`_(")T9"(@.B`B='(B*3L*
M"79A<B!T86)L92`]('1H:7,N9V5T0VQO<V5S="@B=&%B;&4B*3L*"2\O('1H
M:7,N961I=&]R+G-E;&5C=$YO9&5#;VYT96YT<RAE;&5M96YT*3L*"2\O('1H
M:7,N961I=&]R+G5P9&%T951O;VQB87(H*3L*"@EV87(@9&EA;&]G(#T@;F5W
M(%!O<'5P5VEN*'1H:7,N961I=&]R+"!I,3AN6V-E;&P@/R`B0V5L;"!0<F]P
M97)T:65S(B`Z(")2;W<@4')O<&5R=&EE<R)=+"!F=6YC=&EO;BAD:6%L;V<L
M('!A<F%M<RD@>PH)"51A8FQE3W!E<F%T:6]N<RYP<F]C97-S4W1Y;&4H<&%R
M86US+"!E;&5M96YT*3L*"0EF;W(@*'9A<B!I(&EN('!A<F%M<RD@>PH)"0EV
M87(@=F%L(#T@<&%R86US6VE=.PH)"0ES=VET8V@@*&DI('L*"0D)("`@(&-A
M<V4@(F9?86QI9VXB.@H)"0D)96QE;65N="YA;&EG;B`]('9A;#L*"0D)"6)R
M96%K.PH)"0D@("`@8V%S92`B9E]C:&%R(CH*"0D)"65L96UE;G0N8V@@/2!V
M86P["@D)"0EB<F5A:SL*"0D)("`@(&-A<V4@(F9?=F%L:6=N(CH*"0D)"65L
M96UE;G0N=D%L:6=N(#T@=F%L.PH)"0D)8G)E86L["@D)"7T*"0E]"@D)+R\@
M=F%R:6]U<R!W;W)K87)O=6YD<R!T;R!R969R97-H('1H92!T86)L92!D:7-P
M;&%Y("A'96-K;RP*"0DO+R!W:&%T)W,@9V]I;F<@;VX_(2!D;R!N;W0@9&ES
M87!P;VEN="!M92$I"@D)9&EA;&]G+F5D:71O<BYF;W)C95)E9')A=R@I.PH)
M"61I86QO9RYE9&ET;W(N9F]C=7-%9&ET;W(H*3L*"0ED:6%L;V<N961I=&]R
M+G5P9&%T951O;VQB87(H*3L*"0EV87(@<V%V95]C;VQL87!S92`]('1A8FQE
M+G-T>6QE+F)O<F1E<D-O;&QA<'-E.PH)"71A8FQE+G-T>6QE+F)O<F1E<D-O
M;&QA<'-E(#T@(F-O;&QA<'-E(CL*"0ET86)L92YS='EL92YB;W)D97)#;VQL
M87!S92`](")S97!A<F%T92(["@D)=&%B;&4N<W1Y;&4N8F]R9&5R0V]L;&%P
M<V4@/2!S879E7V-O;&QA<'-E.PH)?2P*"@DO+R!T:&ES(&9U;F-T:6]N(&=E
M=',@8V%L;&5D('=H96X@=&AE(&1I86QO9R!N965D<R!T;R!B92!I;FET:6%L
M:7IE9`H)9G5N8W1I;VX@*&1I86QO9RD@>PH*"0EV87(@9E]A;&EG;B`](&5L
M96UE;G0N86QI9VX["@D)=F%R(&9?=F%L:6=N(#T@96QE;65N="YV06QI9VX[
M"@D)=F%R(&9?8VAA<B`](&5L96UE;G0N8V@["@H)"69U;F-T:6]N('-E;&5C
M=&5D*'9A;"D@>PH)"0ER971U<FX@=F%L(#\@(B!S96QE8W1E9"(@.B`B(CL*
M"0E].PH*"0DO+R!D:6%L;V<@8V]N=&5N=',*"0ED:6%L;V<N8V]N=&5N="YS
M='EL92YW:61T:"`]("(T,#!P>"(["@D)9&EA;&]G+F-O;G1E;G0N:6YN97)(
M5$U,(#T@(B!<"CQD:78@8VQA<W,])W1I=&QE)UP*('-T>6QE/2=B86-K9W)O
M=6YD.B!U<FPH(B`K(&1I86QO9RYB87-E55),("L@9&EA;&]G+F5D:71O<BYI
M;6=54DPH8V5L;"`_(")C96QL+7!R;W`N9VEF(B`Z(")R;W<M<')O<"YG:68B
M+"`B5&%B;&5/<&5R871I;VYS(BD@*R`B*2`C9F9F(#DX)2`U,"4@;F\M<F5P
M96%T)SXB("L@:3$X;EMC96QL(#\@(D-E;&P@4')O<&5R=&EE<R(@.B`B4F]W
M(%!R;W!E<G1I97,B72`K("(\+V1I=CX@7`H\=&%B;&4@<W1Y;&4])W=I9'1H
M.C$P,"4G/B!<"B`@/'1R/B!<"B`@("`\=&0@:60])RTM2$$M;&%Y;W5T)SX@
M7`H@("`@/"]T9#X@7`H@(#PO='(^(%P*("`\='(^(%P*("`@(#QT9"!I9#TG
M+2U(02US='EL92<^/"]T9#X@7`H@(#PO='(^(%P*/"]T86)L93X@7`HB.PH)
M"79A<B!S=%]P<F]P(#T@5&%B;&5/<&5R871I;VYS+F-R96%T95-T>6QE1FEE
M;&1S970H9&EA;&]G+F1O8RP@9&EA;&]G+F5D:71O<BP@96QE;65N="D["@D)
M=F%R('`@/2!D:6%L;V<N9&]C+F=E=$5L96UE;G1">4ED*"(M+4A!+7-T>6QE
M(BD["@D)<"YA<'!E;F1#:&EL9"AS=%]P<F]P*3L*"0EV87(@<W1?;&%Y;W5T
M(#T@5&%B;&5/<&5R871I;VYS+F-R96%T95-T>6QE3&%Y;W5T1FEE;&1S970H
M9&EA;&]G+F1O8RP@9&EA;&]G+F5D:71O<BP@96QE;65N="D["@D)<"`](&1I
M86QO9RYD;V,N9V5T16QE;65N=$)Y260H(BTM2$$M;&%Y;W5T(BD["@D)<"YA
M<'!E;F1#:&EL9"AS=%]L87EO=70I.PH)"61I86QO9RYM;V1A;"`]('1R=64[
M"@D)9&EA;&]G+F%D9$)U='1O;G,H(F]K(BP@(F-A;F-E;"(I.PH)"61I86QO
M9RYS:&]W071%;&5M96YT*&1I86QO9RYE9&ET;W(N7VEF<F%M92P@(F,B*3L*
M"7TI.PI].PH*+R\@=&AI<R!F=6YC=&EO;B!G971S(&-A;&QE9"!W:&5N('-O
M;64@8G5T=&]N(&9R;VT@=&AE(%1A8FQE3W!E<F%T:6]N<R!T;V]L8F%R"B\O
M('=A<R!P<F5S<V5D+@I486)L94]P97)A=&EO;G,N<')O=&]T>7!E+F)U='1O
M;E!R97-S(#T@9G5N8W1I;VXH961I=&]R+"!B=71T;VY?:60I('L*"71H:7,N
M961I=&]R(#T@961I=&]R.PH)=F%R(&UO>F)R(#T@2%1-3$%R96$N:7-?9V5C
M:V\@/R`B/&)R("\^(B`Z("(B.PH)=F%R(&DQ.&X@/2!486)L94]P97)A=&EO
M;G,N23$X3CL*"@DO+R!H96QP97(@9G5N8W1I;VX@=&AA="!C;&5A<G,@=&AE
M(&-O;G1E;G0@:6X@82!T86)L92!R;W<*"69U;F-T:6]N(&-L96%R4F]W*'1R
M*2!["@D)=F%R('1D<R`]('1R+F=E=$5L96UE;G1S0GE486=.86UE*")T9"(I
M.PH)"69O<B`H=F%R(&D@/2!T9',N;&5N9W1H.R`M+6D@/CT@,#LI('L*"0D)
M=F%R('1D(#T@=&1S6VE=.PH)"0ET9"YR;W=3<&%N(#T@,3L*"0D)=&0N:6YN
M97)(5$U,(#T@;6]Z8G(["@D)?0H)?3L*"@EF=6YC=&EO;B!S<&QI=%)O=RAT
M9"D@>PH)"79A<B!N(#T@<&%R<V5);G0H(B(@*R!T9"YR;W=3<&%N*3L*"0EV
M87(@;F,@/2!P87)S94EN="@B(B`K('1D+F-O;%-P86XI.PH)"71D+G)O=U-P
M86X@/2`Q.PH)"71R(#T@=&0N<&%R96YT3F]D93L*"0EV87(@:71R(#T@='(N
M<F]W26YD97@["@D)=F%R('1R<R`]('1R+G!A<F5N=$YO9&4N<F]W<SL*"0EV
M87(@:6YD97@@/2!T9"YC96QL26YD97@["@D)=VAI;&4@*"TM;B`^(#`I('L*
M"0D)='(@/2!T<G-;*RMI=')=.PH)"0EV87(@;W1D(#T@961I=&]R+E]D;V,N
M8W)E871E16QE;65N="@B=&0B*3L*"0D);W1D+F-O;%-P86X@/2!T9"YC;VQ3
M<&%N.PH)"0EO=&0N:6YN97)(5$U,(#T@;6]Z8G(["@D)"71R+FEN<V5R=$)E
M9F]R92AO=&0L('1R+F-E;&QS6VEN9&5X72D["@D)?0H)"65D:71O<BYF;W)C
M95)E9')A=R@I.PH)"65D:71O<BYU<&1A=&54;V]L8F%R*"D["@E].PH*"69U
M;F-T:6]N('-P;&ET0V]L*'1D*2!["@D)=F%R(&YC(#T@<&%R<V5);G0H(B(@
M*R!T9"YC;VQ3<&%N*3L*"0ET9"YC;VQ3<&%N(#T@,3L*"0ET<B`]('1D+G!A
M<F5N=$YO9&4["@D)=F%R(')E9B`]('1D+FYE>'13:6)L:6YG.PH)"7=H:6QE
M("@M+6YC(#X@,"D@>PH)"0EV87(@;W1D(#T@961I=&]R+E]D;V,N8W)E871E
M16QE;65N="@B=&0B*3L*"0D);W1D+G)O=U-P86X@/2!T9"YR;W=3<&%N.PH)
M"0EO=&0N:6YN97)(5$U,(#T@;6]Z8G(["@D)"71R+FEN<V5R=$)E9F]R92AO
M=&0L(')E9BD["@D)?0H)"65D:71O<BYF;W)C95)E9')A=R@I.PH)"65D:71O
M<BYU<&1A=&54;V]L8F%R*"D["@E].PH*"69U;F-T:6]N('-P;&ET0V5L;"AT
M9"D@>PH)"79A<B!N8R`]('!A<G-E26YT*"(B("L@=&0N8V]L4W!A;BD["@D)
M<W!L:71#;VPH=&0I.PH)"79A<B!I=&5M<R`]('1D+G!A<F5N=$YO9&4N8V5L
M;',["@D)=F%R(&EN9&5X(#T@=&0N8V5L;$EN9&5X.PH)"7=H:6QE("AN8RTM
M(#X@,"D@>PH)"0ES<&QI=%)O=RAI=&5M<UMI;F1E>"LK72D["@D)?0H)?3L*
M"@EF=6YC=&EO;B!S96QE8W1.97AT3F]D92AE;"D@>PH)"79A<B!N;V1E(#T@
M96PN;F5X=%-I8FQI;F<["@D)=VAI;&4@*&YO9&4@)B8@;F]D92YN;V1E5'EP
M92`A/2`Q*2!["@D)"6YO9&4@/2!N;V1E+FYE>'13:6)L:6YG.PH)"7T*"0EI
M9B`H(6YO9&4I('L*"0D);F]D92`](&5L+G!R979I;W5S4VEB;&EN9SL*"0D)
M=VAI;&4@*&YO9&4@)B8@;F]D92YN;V1E5'EP92`A/2`Q*2!["@D)"0EN;V1E
M(#T@;F]D92YP<F5V:6]U<U-I8FQI;F<["@D)"7T*"0E]"@D):68@*"%N;V1E
M*2!["@D)"6YO9&4@/2!E;"YP87)E;G1.;V1E.PH)"7T*"0EE9&ET;W(N<V5L
M96-T3F]D94-O;G1E;G1S*&YO9&4I.PH)?3L*"@ES=VET8V@@*&)U='1O;E]I
M9"D@>PH)"2\O(%)/5U,*"@D@("`@8V%S92`B5$\M<F]W+6EN<V5R="UA8F]V
M92(Z"@D@("`@8V%S92`B5$\M<F]W+6EN<V5R="UU;F1E<B(Z"@D)=F%R('1R
M(#T@=&AI<RYG971#;&]S97-T*")T<B(I.PH)"6EF("@A='(I('L*"0D)8G)E
M86L["@D)?0H)"79A<B!O='(@/2!T<BYC;&]N94YO9&4H=')U92D["@D)8VQE
M87)2;W<H;W1R*3L*"0ET<BYP87)E;G1.;V1E+FEN<V5R=$)E9F]R92AO='(L
M("]U;F1E<B\N=&5S="AB=71T;VY?:60I(#\@='(N;F5X=%-I8FQI;F<@.B!T
M<BD["@D)961I=&]R+F9O<F-E4F5D<F%W*"D["@D)961I=&]R+F9O8W5S161I
M=&]R*"D["@D)8G)E86L["@D@("`@8V%S92`B5$\M<F]W+61E;&5T92(Z"@D)
M=F%R('1R(#T@=&AI<RYG971#;&]S97-T*")T<B(I.PH)"6EF("@A='(I('L*
M"0D)8G)E86L["@D)?0H)"79A<B!P87(@/2!T<BYP87)E;G1.;V1E.PH)"6EF
M("AP87(N<F]W<RYL96YG=&@@/3T@,2D@>PH)"0EA;&5R="AI,3AN6R)N;W0M
M9&5L+6QA<W0M<F]W(ETI.PH)"0EB<F5A:SL*"0E]"@D)+R\@<V5T('1H92!C
M87)E="!F:7)S="!T;R!A('!O<VET:6]N('1H870@9&]E<VXG=`H)"2\O(&1I
M<V%P<&5A<BX*"0ES96QE8W1.97AT3F]D92AT<BD["@D)<&%R+G)E;6]V94-H
M:6QD*'1R*3L*"0EE9&ET;W(N9F]R8V52961R87<H*3L*"0EE9&ET;W(N9F]C
M=7-%9&ET;W(H*3L*"0EE9&ET;W(N=7!D871E5&]O;&)A<B@I.PH)"6)R96%K
M.PH)("`@(&-A<V4@(E1/+7)O=RUS<&QI="(Z"@D)=F%R('1D(#T@=&AI<RYG
M971#;&]S97-T*")T9"(I.PH)"6EF("@A=&0I('L*"0D)8G)E86L["@D)?0H)
M"7-P;&ET4F]W*'1D*3L*"0EB<F5A:SL*"@D)+R\@0T],54U.4PH*"2`@("!C
M87-E(")43RUC;VPM:6YS97)T+6)E9F]R92(Z"@D@("`@8V%S92`B5$\M8V]L
M+6EN<V5R="UA9G1E<B(Z"@D)=F%R('1D(#T@=&AI<RYG971#;&]S97-T*")T
M9"(I.PH)"6EF("@A=&0I('L*"0D)8G)E86L["@D)?0H)"79A<B!R;W=S(#T@
M=&0N<&%R96YT3F]D92YP87)E;G1.;V1E+G)O=W,["@D)=F%R(&EN9&5X(#T@
M=&0N8V5L;$EN9&5X.PH)"69O<B`H=F%R(&D@/2!R;W=S+FQE;F=T:#L@+2UI
M(#X](#`[*2!["@D)"79A<B!T<B`](')O=W-;:5T["@D)"79A<B!R968@/2!T
M<BYC96QL<UMI;F1E>"`K("@O869T97(O+G1E<W0H8G5T=&]N7VED*2`_(#$@
M.B`P*5T["@D)"79A<B!O=&0@/2!E9&ET;W(N7V1O8RYC<F5A=&5%;&5M96YT
M*")T9"(I.PH)"0EO=&0N:6YN97)(5$U,(#T@;6]Z8G(["@D)"71R+FEN<V5R
M=$)E9F]R92AO=&0L(')E9BD["@D)?0H)"65D:71O<BYF;V-U<T5D:71O<B@I
M.PH)"6)R96%K.PH)("`@(&-A<V4@(E1/+6-O;"US<&QI="(Z"@D)=F%R('1D
M(#T@=&AI<RYG971#;&]S97-T*")T9"(I.PH)"6EF("@A=&0I('L*"0D)8G)E
M86L["@D)?0H)"7-P;&ET0V]L*'1D*3L*"0EB<F5A:SL*"2`@("!C87-E(")4
M3RUC;VPM9&5L971E(CH*"0EV87(@=&0@/2!T:&ES+F=E=$-L;W-E<W0H(G1D
M(BD["@D):68@*"%T9"D@>PH)"0EB<F5A:SL*"0E]"@D)=F%R(&EN9&5X(#T@
M=&0N8V5L;$EN9&5X.PH)"6EF("AT9"YP87)E;G1.;V1E+F-E;&QS+FQE;F=T
M:"`]/2`Q*2!["@D)"6%L97)T*&DQ.&Y;(FYO="UD96PM;&%S="UC;VPB72D[
M"@D)"6)R96%K.PH)"7T*"0DO+R!S970@=&AE(&-A<F5T(&9I<G-T('1O(&$@
M<&]S:71I;VX@=&AA="!D;V5S;B=T(&1I<V%P<&5A<@H)"7-E;&5C=$YE>'1.
M;V1E*'1D*3L*"0EV87(@<F]W<R`]('1D+G!A<F5N=$YO9&4N<&%R96YT3F]D
M92YR;W=S.PH)"69O<B`H=F%R(&D@/2!R;W=S+FQE;F=T:#L@+2UI(#X](#`[
M*2!["@D)"79A<B!T<B`](')O=W-;:5T["@D)"71R+G)E;6]V94-H:6QD*'1R
M+F-E;&QS6VEN9&5X72D["@D)?0H)"65D:71O<BYF;W)C95)E9')A=R@I.PH)
M"65D:71O<BYF;V-U<T5D:71O<B@I.PH)"65D:71O<BYU<&1A=&54;V]L8F%R
M*"D["@D)8G)E86L["@H)"2\O($-%3$Q3"@H)("`@(&-A<V4@(E1/+6-E;&PM
M<W!L:70B.@H)"79A<B!T9"`]('1H:7,N9V5T0VQO<V5S="@B=&0B*3L*"0EI
M9B`H(71D*2!["@D)"6)R96%K.PH)"7T*"0ES<&QI=$-E;&PH=&0I.PH)"6)R
M96%K.PH)("`@(&-A<V4@(E1/+6-E;&PM:6YS97)T+6)E9F]R92(Z"@D@("`@
M8V%S92`B5$\M8V5L;"UI;G-E<G0M869T97(B.@H)"79A<B!T9"`]('1H:7,N
M9V5T0VQO<V5S="@B=&0B*3L*"0EI9B`H(71D*2!["@D)"6)R96%K.PH)"7T*
M"0EV87(@='(@/2!T9"YP87)E;G1.;V1E.PH)"79A<B!O=&0@/2!E9&ET;W(N
M7V1O8RYC<F5A=&5%;&5M96YT*")T9"(I.PH)"6]T9"YI;FYE<DA434P@/2!M
M;WIB<CL*"0ET<BYI;G-E<G1"969O<F4H;W1D+"`O869T97(O+G1E<W0H8G5T
M=&]N7VED*2`_('1D+FYE>'13:6)L:6YG(#H@=&0I.PH)"65D:71O<BYF;W)C
M95)E9')A=R@I.PH)"65D:71O<BYF;V-U<T5D:71O<B@I.PH)"6)R96%K.PH)
M("`@(&-A<V4@(E1/+6-E;&PM9&5L971E(CH*"0EV87(@=&0@/2!T:&ES+F=E
M=$-L;W-E<W0H(G1D(BD["@D):68@*"%T9"D@>PH)"0EB<F5A:SL*"0E]"@D)
M:68@*'1D+G!A<F5N=$YO9&4N8V5L;',N;&5N9W1H(#T](#$I('L*"0D)86QE
M<G0H:3$X;ELB;F]T+61E;"UL87-T+6-E;&PB72D["@D)"6)R96%K.PH)"7T*
M"0DO+R!S970@=&AE(&-A<F5T(&9I<G-T('1O(&$@<&]S:71I;VX@=&AA="!D
M;V5S;B=T(&1I<V%P<&5A<@H)"7-E;&5C=$YE>'1.;V1E*'1D*3L*"0ET9"YP
M87)E;G1.;V1E+G)E;6]V94-H:6QD*'1D*3L*"0EE9&ET;W(N9F]R8V52961R
M87<H*3L*"0EE9&ET;W(N=7!D871E5&]O;&)A<B@I.PH)"6)R96%K.PH)("`@
M(&-A<V4@(E1/+6-E;&PM;65R9V4B.@H)"2\O("$A($9)6$U%.B!-;WII;&QA
M('-P96-I9FEC("$A"@D)=F%R('-E;"`](&5D:71O<BY?9V5T4V5L96-T:6]N
M*"D["@D)=F%R(')A;F=E+"!I(#T@,#L*"0EV87(@<F]W<R`](%M=.PH)"79A
M<B!R;W<@/2!N=6QL.PH)"79A<B!C96QL<R`](&YU;&P["@D):68@*"%(5$U,
M07)E82YI<U]I92D@>PH)"0ET<GD@>PH)"0D)=VAI;&4@*')A;F=E(#T@<V5L
M+F=E=%)A;F=E070H:2LK*2D@>PH)"0D)"79A<B!T9"`](')A;F=E+G-T87)T
M0V]N=&%I;F5R+F-H:6QD3F]D97-;<F%N9V4N<W1A<G1/9F9S971=.PH)"0D)
M"6EF("AT9"YP87)E;G1.;V1E("$](')O=RD@>PH)"0D)"0ER;W<@/2!T9"YP
M87)E;G1.;V1E.PH)"0D)"0DH8V5L;',I("8F(')O=W,N<'5S:"AC96QL<RD[
M"@D)"0D)"6-E;&QS(#T@6UT["@D)"0D)?0H)"0D)"6-E;&QS+G!U<V@H=&0I
M.PH)"0D)?0H)"0E](&-A=&-H*&4I('LO*B!F:6YI<VAE9"!W86QK:6YG('1H
M<F]U9V@@<V5L96-T:6]N("HO?0H)"0ER;W=S+G!U<V@H8V5L;',I.PH)"7T@
M96QS92!["@D)"2\O($EN=&5R;F5T($5X<&QO<F5R(")B<F]W<V5R(@H)"0EV
M87(@=&0@/2!T:&ES+F=E=$-L;W-E<W0H(G1D(BD["@D)"6EF("@A=&0I('L*
M"0D)"6%L97)T*&DQ.&Y;(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;")=
M*3L*"0D)"6)R96%K.PH)"0E]"@D)"79A<B!T<B`]('1D+G!A<F5N=$5L96UE
M;G0["@D)"79A<B!N;U]C;VQS(#T@<')O;7!T*&DQ.&Y;(DAO=R!M86YY(&-O
M;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(ETL(#(I.PH)"0EI9B`H
M(6YO7V-O;',I('L*"0D)"2\O(&-A;F-E;&QE9`H)"0D)8G)E86L["@D)"7T*
M"0D)=F%R(&YO7W)O=W,@/2!P<F]M<'0H:3$X;ELB2&]W(&UA;GD@<F]W<R!W
M;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B72P@,BD["@D)"6EF("@A;F]?<F]W
M<RD@>PH)"0D)+R\@8V%N8V5L;&5D"@D)"0EB<F5A:SL*"0D)?0H)"0EV87(@
M8V5L;%]I;F1E>"`]('1D+F-E;&Q);F1E>#L*"0D)=VAI;&4@*&YO7W)O=W,M
M+2`^(#`I('L*"0D)"71D(#T@='(N8V5L;'-;8V5L;%]I;F1E>%T["@D)"0EC
M96QL<R`](%MT9%T["@D)"0EF;W(@*'9A<B!I(#T@,3L@:2`\(&YO7V-O;',[
M("LK:2D@>PH)"0D)"71D(#T@=&0N;F5X=%-I8FQI;F<["@D)"0D):68@*"%T
M9"D@>PH)"0D)"0EB<F5A:SL*"0D)"0E]"@D)"0D)8V5L;',N<'5S:"AT9"D[
M"@D)"0E]"@D)"0ER;W=S+G!U<V@H8V5L;',I.PH)"0D)='(@/2!T<BYN97AT
M4VEB;&EN9SL*"0D)"6EF("@A='(I('L*"0D)"0EB<F5A:SL*"0D)"7T*"0D)
M?0H)"7T*"0EV87(@2%1-3"`]("(B.PH)"69O<B`H:2`](#`[(&D@/"!R;W=S
M+FQE;F=T:#L@*RMI*2!["@D)"2\O(&D@)B8@*$A434P@*ST@(CQB<B`O/B(I
M.PH)"0EV87(@8V5L;',@/2!R;W=S6VE=.PH)"0EF;W(@*'9A<B!J(#T@,#L@
M:B`\(&-E;&QS+FQE;F=T:#L@*RMJ*2!["@D)"0DO+R!J("8F("A(5$U,("L]
M("(F;F)S<#LB*3L*"0D)"79A<B!C96QL(#T@8V5L;'-;:ET["@D)"0E(5$U,
M("L](&-E;&PN:6YN97)(5$U,.PH)"0D)*&D@?'P@:BD@)B8@*&-E;&PN<&%R
M96YT3F]D92YR96UO=F5#:&EL9"AC96QL*2D["@D)"7T*"0E]"@D)=F%R('1D
M(#T@<F]W<ULP75LP73L*"0ET9"YI;FYE<DA434P@/2!(5$U,.PH)"71D+G)O
M=U-P86X@/2!R;W=S+FQE;F=T:#L*"0ET9"YC;VQ3<&%N(#T@<F]W<ULP72YL
M96YG=&@["@D)961I=&]R+G-E;&5C=$YO9&5#;VYT96YT<RAT9"D["@D)961I
M=&]R+F9O<F-E4F5D<F%W*"D["@D)961I=&]R+F9O8W5S161I=&]R*"D["@D)
M8G)E86L["@H)"2\O(%!23U!%4E1)15,*"@D@("`@8V%S92`B5$\M=&%B;&4M
M<')O<"(Z"@D)=&AI<RYD:6%L;V=486)L95!R;W!E<G1I97,H*3L*"0EB<F5A
M:SL*"@D@("`@8V%S92`B5$\M<F]W+7!R;W`B.@H)"71H:7,N9&EA;&]G4F]W
M0V5L;%!R;W!E<G1I97,H9F%L<V4I.PH)"6)R96%K.PH*"2`@("!C87-E(")4
M3RUC96QL+7!R;W`B.@H)"71H:7,N9&EA;&]G4F]W0V5L;%!R;W!E<G1I97,H
M=')U92D["@D)8G)E86L["@H)("`@(&1E9F%U;'0Z"@D)86QE<G0H(D)U='1O
M;B!;(B`K(&)U='1O;E]I9"`K(")=(&YO="!Y970@:6UP;&5M96YT960B*3L*
M"7T*?3L*"B\O('1H92!L:7-T(&]F(&)U='1O;G,@861D960@8GD@=&AI<R!P
M;'5G:6X*5&%B;&5/<&5R871I;VYS+F)T;DQI<W0@/2!;"@DO+R!T86)L92!P
M<F]P97)T:65S(&)U='1O;@H)6R)T86)L92UP<F]P(BP@("`@("`@(G1A8FQE
M(ETL"@EN=6QL+`D)"2\O('-E<&%R871O<@H*"2\O(%)/5U,*"5LB<F]W+7!R
M;W`B+"`@("`@("`@(")T<B)=+`H)6R)R;W<M:6YS97)T+6%B;W9E(BP@(G1R
M(ETL"@E;(G)O=RUI;G-E<G0M=6YD97(B+"`B='(B72P*"5LB<F]W+61E;&5T
M92(L("`@("`@(")T<B)=+`H)6R)R;W<M<W!L:70B+"`@("`@("`@(G1D6W)O
M=U-P86XA/3%=(ETL"@EN=6QL+`H*"2\O($-/3%,*"5LB8V]L+6EN<V5R="UB
M969O<F4B+"`B=&0B72P*"5LB8V]L+6EN<V5R="UA9G1E<B(L("`B=&0B72P*
M"5LB8V]L+61E;&5T92(L("`@("`@("`B=&0B72P*"5LB8V]L+7-P;&ET(BP@
M("`@("`@("`B=&1;8V]L4W!A;B$],5TB72P*"6YU;&PL"@H)+R\@0T5,3%,*
M"5LB8V5L;"UP<F]P(BP@("`@("`@("`@(G1D(ETL"@E;(F-E;&PM:6YS97)T
M+6)E9F]R92(L(")T9")=+`H)6R)C96QL+6EN<V5R="UA9G1E<B(L("`B=&0B
M72P*"5LB8V5L;"UD96QE=&4B+"`@("`@("`@(G1D(ETL"@E;(F-E;&PM;65R
M9V4B+"`@("`@("`@(")T<B)=+`H)6R)C96QL+7-P;&ET(BP@("`@("`@("`B
M=&1;8V]L4W!A;B$],2QR;W=3<&%N(3TQ72)="@E=.PH*"@HO+R\O($=%3D52
M24,@0T]$12!;<W1Y;&4@;V8@86YY(&5L96UE;G0[('1H:7,@<VAO=6QD(&)E
M(&UO=F5D(&EN=&\@82!S97!A<F%T90HO+R\O(&9I;&4@87,@:70G;&P@8F4@
M=F5R>2!U<V5F=6Q="B\O+R\@0D5'24X@1T5.15))0R!#3T1%("TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M"@I486)L94]P97)A=&EO;G,N9V5T3&5N9W1H(#T@9G5N8W1I;VXH=F%L=64I
M('L*"79A<B!L96X@/2!P87)S94EN="AV86QU92D["@EI9B`H:7-.84XH;&5N
M*2D@>PH)"6QE;B`]("(B.PH)?0H)<F5T=7)N(&QE;CL*?3L*"B\O($%P<&QI
M97,@=&AE('-T>6QE(&9O=6YD(&EN(")P87)A;7,B('1O('1H92!G:79E;B!E
M;&5M96YT+@I486)L94]P97)A=&EO;G,N<')O8V5S<U-T>6QE(#T@9G5N8W1I
M;VXH<&%R86US+"!E;&5M96YT*2!["@EV87(@<W1Y;&4@/2!E;&5M96YT+G-T
M>6QE.PH)9F]R("AV87(@:2!I;B!P87)A;7,I('L*"0EV87(@=F%L(#T@<&%R
M86US6VE=.PH)"7-W:71C:"`H:2D@>PH)"2`@("!C87-E(")F7W-T7V)A8VMG
M<F]U;F1#;VQO<B(Z"@D)"7-T>6QE+F)A8VMG<F]U;F1#;VQO<B`]('9A;#L*
M"0D)8G)E86L["@D)("`@(&-A<V4@(F9?<W1?8V]L;W(B.@H)"0ES='EL92YC
M;VQO<B`]('9A;#L*"0D)8G)E86L["@D)("`@(&-A<V4@(F9?<W1?8F%C:V=R
M;W5N9$EM86=E(CH*"0D):68@*"]<4R\N=&5S="AV86PI*2!["@D)"0ES='EL
M92YB86-K9W)O=6YD26UA9V4@/2`B=7)L*"(@*R!V86P@*R`B*2(["@D)"7T@
M96QS92!["@D)"0ES='EL92YB86-K9W)O=6YD26UA9V4@/2`B;F]N92(["@D)
M"7T*"0D)8G)E86L["@D)("`@(&-A<V4@(F9?<W1?8F]R9&5R5VED=&@B.@H)
M"0ES='EL92YB;W)D97)7:61T:"`]('9A;#L*"0D)8G)E86L["@D)("`@(&-A
M<V4@(F9?<W1?8F]R9&5R4W1Y;&4B.@H)"0ES='EL92YB;W)D97)3='EL92`]
M('9A;#L*"0D)8G)E86L["@D)("`@(&-A<V4@(F9?<W1?8F]R9&5R0V]L;W(B
M.@H)"0ES='EL92YB;W)D97)#;VQO<B`]('9A;#L*"0D)8G)E86L["@D)("`@
M(&-A<V4@(F9?<W1?8F]R9&5R0V]L;&%P<V4B.@H)"0ES='EL92YB;W)D97)#
M;VQL87!S92`]('9A;"`_(")C;VQL87!S92(@.B`B(CL*"0D)8G)E86L["@D)
M("`@(&-A<V4@(F9?<W1?=VED=&@B.@H)"0EI9B`H+UQ3+RYT97-T*'9A;"DI
M('L*"0D)"7-T>6QE+G=I9'1H(#T@=F%L("L@<&%R86US6R)F7W-T7W=I9'1H
M56YI=")=.PH)"0E](&5L<V4@>PH)"0D)<W1Y;&4N=VED=&@@/2`B(CL*"0D)
M?0H)"0EB<F5A:SL*"0D@("`@8V%S92`B9E]S=%]H96EG:'0B.@H)"0EI9B`H
M+UQ3+RYT97-T*'9A;"DI('L*"0D)"7-T>6QE+FAE:6=H="`]('9A;"`K('!A
M<F%M<ULB9E]S=%]H96EG:'15;FET(ET["@D)"7T@96QS92!["@D)"0ES='EL
M92YH96EG:'0@/2`B(CL*"0D)?0H)"0EB<F5A:SL*"0D@("`@8V%S92`B9E]S
M=%]T97AT06QI9VXB.@H)"0EI9B`H=F%L(#T](")C:&%R(BD@>PH)"0D)=F%R
M(&-H(#T@<&%R86US6R)F7W-T7W1E>'1!;&EG;D-H87(B73L*"0D)"6EF("AC
M:"`]/2`G(B<I('L*"0D)"0EC:"`]("=<7"(G.PH)"0D)?0H)"0D)<W1Y;&4N
M=&5X=$%L:6=N(#T@)R(G("L@8V@@*R`G(B<["@D)"7T@96QS92!["@D)"0ES
M='EL92YT97AT06QI9VX@/2!V86P["@D)"7T*"0D)8G)E86L["@D)("`@(&-A
M<V4@(F9?<W1?=F5R=&EC86Q!;&EG;B(Z"@D)"7-T>6QE+G9E<G1I8V%L06QI
M9VX@/2!V86P["@D)"6)R96%K.PH)"2`@("!C87-E(")F7W-T7V9L;V%T(CH*
M"0D)<W1Y;&4N8W-S1FQO870@/2!V86P["@D)"6)R96%K.PHO+R`)"2`@("!C
M87-E(")F7W-T7VUA<F=I;B(Z"B\O(`D)"7-T>6QE+FUA<F=I;B`]('9A;"`K
M(")P>"(["B\O(`D)"6)R96%K.PHO+R`)"2`@("!C87-E(")F7W-T7W!A9&1I
M;F<B.@HO+R`)"0ES='EL92YP861D:6YG(#T@=F%L("L@(G!X(CL*+R\@"0D)
M8G)E86L["@D)?0H)?0I].PH*+R\@4F5T=7)N<R!A;B!(5$U,(&5L96UE;G0@
M9F]R(&$@=VED9V5T('1H870@86QL;W=S(&-O;&]R('-E;&5C=&EO;BX@(%1H
M870@:7,L"B\O(&$@8G5T=&]N('1H870@8V]N=&%I;G,@=&AE(&=I=F5N(&-O
M;&]R+"!I9B!A;GDL(&%N9"!W:&5N('!R97-S960@=VEL;"!P;W!U<`HO+R!T
M:&4@<V]O;F5R+6]R+6QA=&5R+71O+6)E+7)E=W)I='1E;B!S96QE8W1?8V]L
M;W(N:'1M;"!D:6%L;V<@86QL;W=I;F<@=7-E<@HO+R!T;R!S96QE8W0@<V]M
M92!C;VQO<BX@($EF(&$@8V]L;W(@:7,@<V5L96-T960L(&%N(&EN<'5T(&9I
M96QD('=I=&@@=&AE(&YA;64*+R\@(F9?<W1?(BMN86UE('=I;&P@8F4@=7!D
M871E9"!W:71H('1H92!C;VQO<B!V86QU92!I;B`C,3(S-#4V(&9O<FUA="X*
M5&%B;&5/<&5R871I;VYS+F-R96%T94-O;&]R0G5T=&]N(#T@9G5N8W1I;VXH
M9&]C+"!E9&ET;W(L(&-O;&]R+"!N86UE*2!["@EI9B`H(6-O;&]R*2!["@D)
M8V]L;W(@/2`B(CL*"7T@96QS92!I9B`H(2\C+RYT97-T*&-O;&]R*2D@>PH)
M"6-O;&]R(#T@2%1-3$%R96$N7V-O;&]R5&]29V(H8V]L;W(I.PH)?0H*"79A
M<B!D9B`](&1O8RYC<F5A=&5%;&5M96YT*")S<&%N(BD["B`)=F%R(&9I96QD
M(#T@9&]C+F-R96%T945L96UE;G0H(FEN<'5T(BD["@EF:65L9"YT>7!E(#T@
M(FAI9&1E;B(["@ED9BYA<'!E;F1#:&EL9"AF:65L9"D["B`)9FEE;&0N;F%M
M92`](")F7W-T7R(@*R!N86UE.PH)9FEE;&0N=F%L=64@/2!C;VQO<CL*"79A
M<B!B=71T;VX@/2!D;V,N8W)E871E16QE;65N="@B<W!A;B(I.PH)8G5T=&]N
M+F-L87-S3F%M92`](")B=71T;VY#;VQO<B(["@ED9BYA<'!E;F1#:&EL9"AB
M=71T;VXI.PH)=F%R('-P86X@/2!D;V,N8W)E871E16QE;65N="@B<W!A;B(I
M.PH)<W!A;BYC;&%S<TYA;64@/2`B8VAO;W-E<B(["@DO+R!S<&%N+FEN;F5R
M2%1-3"`]("(F;F)S<#LF;F)S<#LF;F)S<#LF;F)S<#LF;F)S<#LF;F)S<#LF
M;F)S<#LB.PH)<W!A;BYS='EL92YB86-K9W)O=6YD0V]L;W(@/2!C;VQO<CL*
M"6)U='1O;BYA<'!E;F1#:&EL9"AS<&%N*3L*"6)U='1O;BYO;FUO=7-E;W9E
M<B`](&9U;F-T:6]N*"D@>R!I9B`H(71H:7,N9&ES86)L960I('L@=&AI<RYC
M;&%S<TYA;64@*ST@(B!B=71T;VY#;VQO<BUH:6QI=&4B.R!]?3L*"6)U='1O
M;BYO;FUO=7-E;W5T(#T@9G5N8W1I;VXH*2![(&EF("@A=&AI<RYD:7-A8FQE
M9"D@>R!T:&ES+F-L87-S3F%M92`](")B=71T;VY#;VQO<B([('U].PH)<W!A
M;BYO;F-L:6-K(#T@9G5N8W1I;VXH*2!["@D):68@*'1H:7,N<&%R96YT3F]D
M92YD:7-A8FQE9"D@>PH)"0ER971U<FX@9F%L<V4["@D)?0H)"65D:71O<BY?
M<&]P=7!$:6%L;V<H(G-E;&5C=%]C;VQO<BYH=&UL(BP@9G5N8W1I;VXH8V]L
M;W(I('L*"0D):68@*&-O;&]R*2!["@D)"0ES<&%N+G-T>6QE+F)A8VMG<F]U
M;F1#;VQO<B`]("(C(B`K(&-O;&]R.PH)"0D)9FEE;&0N=F%L=64@/2`B(R(@
M*R!C;VQO<CL*"0D)?0H)"7TL(&-O;&]R*3L*"7T["@EV87(@<W!A;C(@/2!D
M;V,N8W)E871E16QE;65N="@B<W!A;B(I.PH)<W!A;C(N:6YN97)(5$U,(#T@
M(B8C>#`P9#<[(CL*"7-P86XR+F-L87-S3F%M92`](")N;V-O;&]R(CL*"7-P
M86XR+G1I=&QE(#T@5&%B;&5/<&5R871I;VYS+DDQ.$Y;(E5N<V5T(&-O;&]R
M(ET["@EB=71T;VXN87!P96YD0VAI;&0H<W!A;C(I.PH)<W!A;C(N;VYM;W5S
M96]V97(@/2!F=6YC=&EO;B@I('L@:68@*"%T:&ES+G!A<F5N=$YO9&4N9&ES
M86)L960I('L@=&AI<RYC;&%S<TYA;64@*ST@(B!N;V-O;&]R+6AI;&ET92([
M('U].PH)<W!A;C(N;VYM;W5S96]U="`](&9U;F-T:6]N*"D@>R!I9B`H(71H
M:7,N<&%R96YT3F]D92YD:7-A8FQE9"D@>R!T:&ES+F-L87-S3F%M92`](")N
M;V-O;&]R(CL@?7T["@ES<&%N,BYO;F-L:6-K(#T@9G5N8W1I;VXH*2!["@D)
M<W!A;BYS='EL92YB86-K9W)O=6YD0V]L;W(@/2`B(CL*"0EF:65L9"YV86QU
M92`]("(B.PH)?3L*"7)E='5R;B!D9CL*?3L*"E1A8FQE3W!E<F%T:6]N<RYC
M<F5A=&53='EL94QA>6]U=$9I96QD<V5T(#T@9G5N8W1I;VXH9&]C+"!E9&ET
M;W(L(&5L*2!["@EV87(@:3$X;B`](%1A8FQE3W!E<F%T:6]N<RY),3A..PH)
M=F%R(&9I96QD<V5T(#T@9&]C+F-R96%T945L96UE;G0H(F9I96QD<V5T(BD[
M"@EV87(@;&5G96YD(#T@9&]C+F-R96%T945L96UE;G0H(FQE9V5N9"(I.PH)
M9FEE;&1S970N87!P96YD0VAI;&0H;&5G96YD*3L*"6QE9V5N9"YI;FYE<DA4
M34P@/2!I,3AN6R),87EO=70B73L*"79A<B!T86)L92`](&1O8RYC<F5A=&5%
M;&5M96YT*")T86)L92(I.PH)9FEE;&1S970N87!P96YD0VAI;&0H=&%B;&4I
M.PH)=&%B;&4N<W1Y;&4N=VED=&@@/2`B,3`P)2(["@EV87(@=&)O9'D@/2!D
M;V,N8W)E871E16QE;65N="@B=&)O9'DB*3L*"71A8FQE+F%P<&5N9$-H:6QD
M*'1B;V1Y*3L*"@EV87(@=&%G;F%M92`](&5L+G1A9TYA;64N=&],;W=E<D-A
M<V4H*3L*"79A<B!T<BP@=&0L(&EN<'5T+"!S96QE8W0L(&]P=&EO;BP@;W!T
M:6]N<RP@:3L*"@EI9B`H=&%G;F%M92`A/2`B=&0B("8F('1A9VYA;64@(3T@
M(G1R(B`F)B!T86=N86UE("$](")T:"(I('L*"0ET<B`](&1O8RYC<F5A=&5%
M;&5M96YT*")T<B(I.PH)"71B;V1Y+F%P<&5N9$-H:6QD*'1R*3L*"0ET9"`]
M(&1O8RYC<F5A=&5%;&5M96YT*")T9"(I.PH)"71D+F-L87-S3F%M92`](")L
M86)E;"(["@D)='(N87!P96YD0VAI;&0H=&0I.PH)"71D+FEN;F5R2%1-3"`]
M(&DQ.&Y;(D9L;V%T(ET@*R`B.B(["@D)=&0@/2!D;V,N8W)E871E16QE;65N
M="@B=&0B*3L*"0ET<BYA<'!E;F1#:&EL9"AT9"D["@D)<V5L96-T(#T@9&]C
M+F-R96%T945L96UE;G0H(G-E;&5C="(I.PH)"71D+F%P<&5N9$-H:6QD*'-E
M;&5C="D["@D)<V5L96-T+FYA;64@/2`B9E]S=%]F;&]A="(["@D);W!T:6]N
M<R`](%LB3F]N92(L("),969T(BP@(E)I9VAT(ET["@D)9F]R("AV87(@:2`]
M(#`[(&D@/"!O<'1I;VYS+FQE;F=T:#L@*RMI*2!["@D)"79A<B!686P@/2!O
M<'1I;VYS6VE=.PH)"0EV87(@=F%L(#T@;W!T:6]N<UMI72YT;TQO=V5R0V%S
M92@I.PH)"0EO<'1I;VX@/2!D;V,N8W)E871E16QE;65N="@B;W!T:6]N(BD[
M"@D)"6]P=&EO;BYI;FYE<DA434P@/2!I,3AN6U9A;%T["@D)"6]P=&EO;BYV
M86QU92`]('9A;#L*"0D);W!T:6]N+G-E;&5C=&5D(#T@*"@B(B`K(&5L+G-T
M>6QE+F-S<T9L;V%T*2YT;TQO=V5R0V%S92@I(#T]('9A;"D["@D)"7-E;&5C
M="YA<'!E;F1#:&EL9"AO<'1I;VXI.PH)"7T*"7T*"@ET<B`](&1O8RYC<F5A
M=&5%;&5M96YT*")T<B(I.PH)=&)O9'DN87!P96YD0VAI;&0H='(I.PH)=&0@
M/2!D;V,N8W)E871E16QE;65N="@B=&0B*3L*"71D+F-L87-S3F%M92`](")L
M86)E;"(["@ET<BYA<'!E;F1#:&EL9"AT9"D["@ET9"YI;FYE<DA434P@/2!I
M,3AN6R)7:61T:")=("L@(CHB.PH)=&0@/2!D;V,N8W)E871E16QE;65N="@B
M=&0B*3L*"71R+F%P<&5N9$-H:6QD*'1D*3L*"6EN<'5T(#T@9&]C+F-R96%T
M945L96UE;G0H(FEN<'5T(BD["@EI;G!U="YT>7!E(#T@(G1E>'0B.PH):6YP
M=70N=F%L=64@/2!486)L94]P97)A=&EO;G,N9V5T3&5N9W1H*&5L+G-T>6QE
M+G=I9'1H*3L*"6EN<'5T+G-I>F4@/2`B-2(["@EI;G!U="YN86UE(#T@(F9?
M<W1?=VED=&@B.PH):6YP=70N<W1Y;&4N;6%R9VEN4FEG:'0@/2`B,"XU96TB
M.PH)=&0N87!P96YD0VAI;&0H:6YP=70I.PH)<V5L96-T(#T@9&]C+F-R96%T
M945L96UE;G0H(G-E;&5C="(I.PH)<V5L96-T+FYA;64@/2`B9E]S=%]W:61T
M:%5N:70B.PH);W!T:6]N(#T@9&]C+F-R96%T945L96UE;G0H(F]P=&EO;B(I
M.PH);W!T:6]N+FEN;F5R2%1-3"`](&DQ.&Y;(G!E<F-E;G0B73L*"6]P=&EO
M;BYV86QU92`]("(E(CL*"6]P=&EO;BYS96QE8W1E9"`]("\E+RYT97-T*&5L
M+G-T>6QE+G=I9'1H*3L*"7-E;&5C="YA<'!E;F1#:&EL9"AO<'1I;VXI.PH)
M;W!T:6]N(#T@9&]C+F-R96%T945L96UE;G0H(F]P=&EO;B(I.PH);W!T:6]N
M+FEN;F5R2%1-3"`](&DQ.&Y;(G!I>&5L<R)=.PH);W!T:6]N+G9A;'5E(#T@
M(G!X(CL*"6]P=&EO;BYS96QE8W1E9"`]("]P>"\N=&5S="AE;"YS='EL92YW
M:61T:"D["@ES96QE8W0N87!P96YD0VAI;&0H;W!T:6]N*3L*"71D+F%P<&5N
M9$-H:6QD*'-E;&5C="D["@H)<V5L96-T+G-T>6QE+FUA<F=I;E)I9VAT(#T@
M(C`N-65M(CL*"71D+F%P<&5N9$-H:6QD*&1O8RYC<F5A=&5497AT3F]D92AI
M,3AN6R)497AT(&%L:6=N(ET@*R`B.B(I*3L*"7-E;&5C="`](&1O8RYC<F5A
M=&5%;&5M96YT*")S96QE8W0B*3L*"7-E;&5C="YS='EL92YM87)G:6Y,969T
M(#T@<V5L96-T+G-T>6QE+FUA<F=I;E)I9VAT(#T@(C`N-65M(CL*"71D+F%P
M<&5N9$-H:6QD*'-E;&5C="D["@ES96QE8W0N;F%M92`](")F7W-T7W1E>'1!
M;&EG;B(["@EO<'1I;VYS(#T@6R),969T(BP@(D-E;G1E<B(L(")2:6=H="(L
M(")*=7-T:69Y(ET["@EI9B`H=&%G;F%M92`]/2`B=&0B*2!["@D);W!T:6]N
M<RYP=7-H*")#:&%R(BD["@E]"@EI;G!U="`](&1O8RYC<F5A=&5%;&5M96YT
M*")I;G!U="(I.PH):6YP=70N;F%M92`](")F7W-T7W1E>'1!;&EG;D-H87(B
M.PH):6YP=70N<VEZ92`]("(Q(CL*"6EN<'5T+G-T>6QE+F9O;G1&86UI;'D@
M/2`B;6]N;W-P86-E(CL*"71D+F%P<&5N9$-H:6QD*&EN<'5T*3L*"69O<B`H
M=F%R(&D@/2`P.R!I(#P@;W!T:6]N<RYL96YG=&@[("LK:2D@>PH)"79A<B!6
M86P@/2!O<'1I;VYS6VE=.PH)"79A<B!V86P@/2!686PN=&],;W=E<D-A<V4H
M*3L*"0EO<'1I;VX@/2!D;V,N8W)E871E16QE;65N="@B;W!T:6]N(BD["@D)
M;W!T:6]N+G9A;'5E(#T@=F%L.PH)"6]P=&EO;BYI;FYE<DA434P@/2!I,3AN
M6U9A;%T["@D);W!T:6]N+G-E;&5C=&5D(#T@*&5L+G-T>6QE+G1E>'1!;&EG
M;BYT;TQO=V5R0V%S92@I(#T]('9A;"D["@D)<V5L96-T+F%P<&5N9$-H:6QD
M*&]P=&EO;BD["@E]"@EF=6YC=&EO;B!S971#:&%R5FES:6)I;&ET>2AV86QU
M92D@>PH)"6EN<'5T+G-T>6QE+G9I<VEB:6QI='D@/2!V86QU92`_(")V:7-I
M8FQE(B`Z(")H:61D96XB.PH)"6EF("AV86QU92D@>PH)"0EI;G!U="YF;V-U
M<R@I.PH)"0EI;G!U="YS96QE8W0H*3L*"0E]"@E].PH)<V5L96-T+F]N8VAA
M;F=E(#T@9G5N8W1I;VXH*2![('-E=$-H87)6:7-I8FEL:71Y*'1H:7,N=F%L
M=64@/3T@(F-H87(B*3L@?3L*"7-E=$-H87)6:7-I8FEL:71Y*'-E;&5C="YV
M86QU92`]/2`B8VAA<B(I.PH*"71R(#T@9&]C+F-R96%T945L96UE;G0H(G1R
M(BD["@ET8F]D>2YA<'!E;F1#:&EL9"AT<BD["@ET9"`](&1O8RYC<F5A=&5%
M;&5M96YT*")T9"(I.PH)=&0N8VQA<W-.86UE(#T@(FQA8F5L(CL*"71R+F%P
M<&5N9$-H:6QD*'1D*3L*"71D+FEN;F5R2%1-3"`](&DQ.&Y;(DAE:6=H=")=
M("L@(CHB.PH)=&0@/2!D;V,N8W)E871E16QE;65N="@B=&0B*3L*"71R+F%P
M<&5N9$-H:6QD*'1D*3L*"6EN<'5T(#T@9&]C+F-R96%T945L96UE;G0H(FEN
M<'5T(BD["@EI;G!U="YT>7!E(#T@(G1E>'0B.PH):6YP=70N=F%L=64@/2!4
M86)L94]P97)A=&EO;G,N9V5T3&5N9W1H*&5L+G-T>6QE+FAE:6=H="D["@EI
M;G!U="YS:7IE(#T@(C4B.PH):6YP=70N;F%M92`](")F7W-T7VAE:6=H="([
M"@EI;G!U="YS='EL92YM87)G:6Y2:6=H="`]("(P+C5E;2(["@ET9"YA<'!E
M;F1#:&EL9"AI;G!U="D["@ES96QE8W0@/2!D;V,N8W)E871E16QE;65N="@B
M<V5L96-T(BD["@ES96QE8W0N;F%M92`](")F7W-T7VAE:6=H=%5N:70B.PH)
M;W!T:6]N(#T@9&]C+F-R96%T945L96UE;G0H(F]P=&EO;B(I.PH);W!T:6]N
M+FEN;F5R2%1-3"`](&DQ.&Y;(G!E<F-E;G0B73L*"6]P=&EO;BYV86QU92`]
M("(E(CL*"6]P=&EO;BYS96QE8W1E9"`]("\E+RYT97-T*&5L+G-T>6QE+FAE
M:6=H="D["@ES96QE8W0N87!P96YD0VAI;&0H;W!T:6]N*3L*"6]P=&EO;B`]
M(&1O8RYC<F5A=&5%;&5M96YT*")O<'1I;VXB*3L*"6]P=&EO;BYI;FYE<DA4
M34P@/2!I,3AN6R)P:7AE;',B73L*"6]P=&EO;BYV86QU92`](")P>"(["@EO
M<'1I;VXN<V5L96-T960@/2`O<'@O+G1E<W0H96PN<W1Y;&4N:&5I9VAT*3L*
M"7-E;&5C="YA<'!E;F1#:&EL9"AO<'1I;VXI.PH)=&0N87!P96YD0VAI;&0H
M<V5L96-T*3L*"@ES96QE8W0N<W1Y;&4N;6%R9VEN4FEG:'0@/2`B,"XU96TB
M.PH)=&0N87!P96YD0VAI;&0H9&]C+F-R96%T951E>'1.;V1E*&DQ.&Y;(E9E
M<G1I8V%L(&%L:6=N(ET@*R`B.B(I*3L*"7-E;&5C="`](&1O8RYC<F5A=&5%
M;&5M96YT*")S96QE8W0B*3L*"7-E;&5C="YN86UE(#T@(F9?<W1?=F5R=&EC
M86Q!;&EG;B(["@ES96QE8W0N<W1Y;&4N;6%R9VEN3&5F="`]("(P+C5E;2([
M"@ET9"YA<'!E;F1#:&EL9"AS96QE8W0I.PH);W!T:6]N<R`](%LB5&]P(BP@
M(DUI9&1L92(L(")";W1T;VTB+"`B0F%S96QI;F4B73L*"69O<B`H=F%R(&D@
M/2`P.R!I(#P@;W!T:6]N<RYL96YG=&@[("LK:2D@>PH)"79A<B!686P@/2!O
M<'1I;VYS6VE=.PH)"79A<B!V86P@/2!686PN=&],;W=E<D-A<V4H*3L*"0EO
M<'1I;VX@/2!D;V,N8W)E871E16QE;65N="@B;W!T:6]N(BD["@D);W!T:6]N
M+G9A;'5E(#T@=F%L.PH)"6]P=&EO;BYI;FYE<DA434P@/2!I,3AN6U9A;%T[
M"@D);W!T:6]N+G-E;&5C=&5D(#T@*&5L+G-T>6QE+G9E<G1I8V%L06QI9VXN
M=&],;W=E<D-A<V4H*2`]/2!V86PI.PH)"7-E;&5C="YA<'!E;F1#:&EL9"AO
M<'1I;VXI.PH)?0H*"7)E='5R;B!F:65L9'-E=#L*?3L*"B\O(%)E='5R;G,@
M86X@2%1-3"!E;&5M96YT(&-O;G1A:6YI;F<@=&AE('-T>6QE(&%T=')I8G5T
M97,@9F]R('1H92!G:79E;@HO+R!E;&5M96YT+B`@5&AI<R!C86X@8F4@96%S
M:6QY(&5M8F5D9&5D(&EN=&\@86YY(&1I86QO9SL@=&AE(&9U;F-T:6]N86QI
M='D@:7,*+R\@86QS;R!P<F]V:61E9"X*5&%B;&5/<&5R871I;VYS+F-R96%T
M95-T>6QE1FEE;&1S970@/2!F=6YC=&EO;BAD;V,L(&5D:71O<BP@96PI('L*
M"79A<B!I,3AN(#T@5&%B;&5/<&5R871I;VYS+DDQ.$X["@EV87(@9FEE;&1S
M970@/2!D;V,N8W)E871E16QE;65N="@B9FEE;&1S970B*3L*"79A<B!L96=E
M;F0@/2!D;V,N8W)E871E16QE;65N="@B;&5G96YD(BD["@EF:65L9'-E="YA
M<'!E;F1#:&EL9"AL96=E;F0I.PH);&5G96YD+FEN;F5R2%1-3"`](&DQ.&Y;
M(D-34R!3='EL92)=.PH)=F%R('1A8FQE(#T@9&]C+F-R96%T945L96UE;G0H
M(G1A8FQE(BD["@EF:65L9'-E="YA<'!E;F1#:&EL9"AT86)L92D["@ET86)L
M92YS='EL92YW:61T:"`]("(Q,#`E(CL*"79A<B!T8F]D>2`](&1O8RYC<F5A
M=&5%;&5M96YT*")T8F]D>2(I.PH)=&%B;&4N87!P96YD0VAI;&0H=&)O9'DI
M.PH*"79A<B!T<BP@=&0L(&EN<'5T+"!S96QE8W0L(&]P=&EO;BP@;W!T:6]N
M<RP@:3L*"@ET<B`](&1O8RYC<F5A=&5%;&5M96YT*")T<B(I.PH)=&)O9'DN
M87!P96YD0VAI;&0H='(I.PH)=&0@/2!D;V,N8W)E871E16QE;65N="@B=&0B
M*3L*"71R+F%P<&5N9$-H:6QD*'1D*3L*"71D+F-L87-S3F%M92`](")L86)E
M;"(["@ET9"YI;FYE<DA434P@/2!I,3AN6R)"86-K9W)O=6YD(ET@*R`B.B([
M"@ET9"`](&1O8RYC<F5A=&5%;&5M96YT*")T9"(I.PH)='(N87!P96YD0VAI
M;&0H=&0I.PH)=F%R(&1F(#T@5&%B;&5/<&5R871I;VYS+F-R96%T94-O;&]R
M0G5T=&]N*&1O8RP@961I=&]R+"!E;"YS='EL92YB86-K9W)O=6YD0V]L;W(L
M(")B86-K9W)O=6YD0V]L;W(B*3L*"61F+F9I<G-T0VAI;&0N;F5X=%-I8FQI
M;F<N<W1Y;&4N;6%R9VEN4FEG:'0@/2`B,"XU96TB.PH)=&0N87!P96YD0VAI
M;&0H9&8I.PH)=&0N87!P96YD0VAI;&0H9&]C+F-R96%T951E>'1.;V1E*&DQ
M.&Y;(DEM86=E(%523")=("L@(CH@(BDI.PH):6YP=70@/2!D;V,N8W)E871E
M16QE;65N="@B:6YP=70B*3L*"6EN<'5T+G1Y<&4@/2`B=&5X="(["@EI;G!U
M="YN86UE(#T@(F9?<W1?8F%C:V=R;W5N9$EM86=E(CL*"6EF("AE;"YS='EL
M92YB86-K9W)O=6YD26UA9V4N;6%T8V@H+W5R;%PH7',J*"XJ/RE<<RI<*2\I
M*2!["@D):6YP=70N=F%L=64@/2!296=%>'`N)#$["@E]"@DO+R!I;G!U="YS
M='EL92YW:61T:"`]("(Q,#`E(CL*"71D+F%P<&5N9$-H:6QD*&EN<'5T*3L*
M"@ET<B`](&1O8RYC<F5A=&5%;&5M96YT*")T<B(I.PH)=&)O9'DN87!P96YD
M0VAI;&0H='(I.PH)=&0@/2!D;V,N8W)E871E16QE;65N="@B=&0B*3L*"71R
M+F%P<&5N9$-H:6QD*'1D*3L*"71D+F-L87-S3F%M92`](")L86)E;"(["@ET
M9"YI;FYE<DA434P@/2!I,3AN6R)&1R!#;VQO<B)=("L@(CHB.PH)=&0@/2!D
M;V,N8W)E871E16QE;65N="@B=&0B*3L*"71R+F%P<&5N9$-H:6QD*'1D*3L*
M"71D+F%P<&5N9$-H:6QD*%1A8FQE3W!E<F%T:6]N<RYC<F5A=&5#;VQO<D)U
M='1O;BAD;V,L(&5D:71O<BP@96PN<W1Y;&4N8V]L;W(L(")C;VQO<B(I*3L*
M"@DO+R!F;W(@8F5T=&5R(&%L:6=N;65N="!W92!I;F-L=61E(&%N(&EN=FES
M:6)L92!F:65L9"X*"6EN<'5T(#T@9&]C+F-R96%T945L96UE;G0H(FEN<'5T
M(BD["@EI;G!U="YS='EL92YV:7-I8FEL:71Y(#T@(FAI9&1E;B(["@EI;G!U
M="YT>7!E(#T@(G1E>'0B.PH)=&0N87!P96YD0VAI;&0H:6YP=70I.PH*"71R
M(#T@9&]C+F-R96%T945L96UE;G0H(G1R(BD["@ET8F]D>2YA<'!E;F1#:&EL
M9"AT<BD["@ET9"`](&1O8RYC<F5A=&5%;&5M96YT*")T9"(I.PH)='(N87!P
M96YD0VAI;&0H=&0I.PH)=&0N8VQA<W-.86UE(#T@(FQA8F5L(CL*"71D+FEN
M;F5R2%1-3"`](&DQ.&Y;(D)O<F1E<B)=("L@(CHB.PH)=&0@/2!D;V,N8W)E
M871E16QE;65N="@B=&0B*3L*"71R+F%P<&5N9$-H:6QD*'1D*3L*"@EV87(@
M8V]L;W)"=71T;VX@/2!486)L94]P97)A=&EO;G,N8W)E871E0V]L;W)"=71T
M;VXH9&]C+"!E9&ET;W(L(&5L+G-T>6QE+F)O<F1E<D-O;&]R+"`B8F]R9&5R
M0V]L;W(B*3L*"79A<B!B=&X@/2!C;VQO<D)U='1O;BYF:7)S=$-H:6QD+FYE
M>'13:6)L:6YG.PH)=&0N87!P96YD0VAI;&0H8V]L;W)"=71T;VXI.PH)+R\@
M8F]R9&5R1FEE;&1S+G!U<V@H8G1N*3L*"6)T;BYS='EL92YM87)G:6Y2:6=H
M="`]("(P+C5E;2(["@H)<V5L96-T(#T@9&]C+F-R96%T945L96UE;G0H(G-E
M;&5C="(I.PH)=F%R(&)O<F1E<D9I96QD<R`](%M=.PH)=&0N87!P96YD0VAI
M;&0H<V5L96-T*3L*"7-E;&5C="YN86UE(#T@(F9?<W1?8F]R9&5R4W1Y;&4B
M.PH);W!T:6]N<R`](%LB;F]N92(L(")D;W1T960B+"`B9&%S:&5D(BP@(G-O
M;&ED(BP@(F1O=6)L92(L(")G<F]O=F4B+"`B<FED9V4B+"`B:6YS970B+"`B
M;W5T<V5T(ET["@EV87(@8W5R<F5N=$)O<F1E<E-T>6QE(#T@96PN<W1Y;&4N
M8F]R9&5R4W1Y;&4["@DO+R!'96-K;R!R97!O<G1S(")S;VQI9"!S;VQI9"!S
M;VQI9"!S;VQI9"(@9F]R(")B;W)D97(M<W1Y;&4Z('-O;&ED(BX*"2\O(%1H
M870@:7,L(")T;W`@<FEG:'0@8F]T=&]M(&QE9G0B("TM('=E(&]N;'D@8V]N
M<VED97(@=&AE(&9I<G-T"@DO+R!V86QU92X*"2AC=7)R96YT0F]R9&5R4W1Y
M;&4N;6%T8V@H+RA;7EQS72HI7',O*2D@)B8@*&-U<G)E;G1";W)D97)3='EL
M92`](%)E9T5X<"XD,2D["@EF;W(@*'9A<B!I(&EN(&]P=&EO;G,I('L*"0EV
M87(@=F%L(#T@;W!T:6]N<UMI73L*"0EO<'1I;VX@/2!D;V,N8W)E871E16QE
M;65N="@B;W!T:6]N(BD["@D);W!T:6]N+G9A;'5E(#T@=F%L.PH)"6]P=&EO
M;BYI;FYE<DA434P@/2!V86P["@D)*'9A;"`]/2!C=7)R96YT0F]R9&5R4W1Y
M;&4I("8F("AO<'1I;VXN<V5L96-T960@/2!T<G5E*3L*"0ES96QE8W0N87!P
M96YD0VAI;&0H;W!T:6]N*3L*"7T*"7-E;&5C="YS='EL92YM87)G:6Y2:6=H
M="`]("(P+C5E;2(["@EF=6YC=&EO;B!S971";W)D97)&:65L9'-3=&%T=7,H
M=F%L=64I('L*"0EF;W(@*'9A<B!I(#T@,#L@:2`\(&)O<F1E<D9I96QD<RYL
M96YG=&@[("LK:2D@>PH)"0EV87(@96P@/2!B;W)D97)&:65L9'-;:5T["@D)
M"65L+G-T>6QE+G9I<VEB:6QI='D@/2!V86QU92`_(")H:61D96XB(#H@(G9I
M<VEB;&4B.PH)"0EI9B`H(79A;'5E("8F("AE;"YT86=.86UE+G1O3&]W97)#
M87-E*"D@/3T@(FEN<'5T(BDI('L*"0D)"65L+F9O8W5S*"D["@D)"0EE;"YS
M96QE8W0H*3L*"0D)?0H)"7T*"7T["@ES96QE8W0N;VYC:&%N9V4@/2!F=6YC
M=&EO;B@I('L@<V5T0F]R9&5R1FEE;&1S4W1A='5S*'1H:7,N=F%L=64@/3T@
M(FYO;F4B*3L@?3L*"@EI;G!U="`](&1O8RYC<F5A=&5%;&5M96YT*")I;G!U
M="(I.PH)8F]R9&5R1FEE;&1S+G!U<V@H:6YP=70I.PH):6YP=70N='EP92`]
M(")T97AT(CL*"6EN<'5T+FYA;64@/2`B9E]S=%]B;W)D97)7:61T:"(["@EI
M;G!U="YV86QU92`](%1A8FQE3W!E<F%T:6]N<RYG971,96YG=&@H96PN<W1Y
M;&4N8F]R9&5R5VED=&@I.PH):6YP=70N<VEZ92`]("(U(CL*"71D+F%P<&5N
M9$-H:6QD*&EN<'5T*3L*"6EN<'5T+G-T>6QE+FUA<F=I;E)I9VAT(#T@(C`N
M-65M(CL*"79A<B!S<&%N(#T@9&]C+F-R96%T945L96UE;G0H(G-P86XB*3L*
M"7-P86XN:6YN97)(5$U,(#T@:3$X;ELB<&EX96QS(ET["@ET9"YA<'!E;F1#
M:&EL9"AS<&%N*3L*"6)O<F1E<D9I96QD<RYP=7-H*'-P86XI.PH*"7-E=$)O
M<F1E<D9I96QD<U-T871U<RAS96QE8W0N=F%L=64@/3T@(FYO;F4B*3L*"@EI
M9B`H96PN=&%G3F%M92YT;TQO=V5R0V%S92@I(#T](")T86)L92(I('L*"0DO
M+R!T:&4@8F]R9&5R+6-O;&QA<'-E('-T>6QE(&ES(&]N;'D@9F]R('1A8FQE
M<PH)"71R(#T@9&]C+F-R96%T945L96UE;G0H(G1R(BD["@D)=&)O9'DN87!P
M96YD0VAI;&0H='(I.PH)"71D(#T@9&]C+F-R96%T945L96UE;G0H(G1D(BD[
M"@D)=&0N8VQA<W-.86UE(#T@(FQA8F5L(CL*"0ET<BYA<'!E;F1#:&EL9"AT
M9"D["@D):6YP=70@/2!D;V,N8W)E871E16QE;65N="@B:6YP=70B*3L*"0EI
M;G!U="YT>7!E(#T@(F-H96-K8F]X(CL*"0EI;G!U="YN86UE(#T@(F9?<W1?
M8F]R9&5R0V]L;&%P<V4B.PH)"6EN<'5T+FED(#T@(F9?<W1?8F]R9&5R0V]L
M;&%P<V4B.PH)"79A<B!V86P@/2`H+V-O;&QA<'-E+VDN=&5S="AE;"YS='EL
M92YB;W)D97)#;VQL87!S92DI.PH)"6EN<'5T+F-H96-K960@/2!V86P@/R`Q
M(#H@,#L*"0ET9"YA<'!E;F1#:&EL9"AI;G!U="D["@H)"71D(#T@9&]C+F-R
M96%T945L96UE;G0H(G1D(BD["@D)='(N87!P96YD0VAI;&0H=&0I.PH)"79A
M<B!L86)E;"`](&1O8RYC<F5A=&5%;&5M96YT*")L86)E;"(I.PH)"6QA8F5L
M+FAT;6Q&;W(@/2`B9E]S=%]B;W)D97)#;VQL87!S92(["@D);&%B96PN:6YN
M97)(5$U,(#T@:3$X;ELB0V]L;&%P<V5D(&)O<F1E<G,B73L*"0ET9"YA<'!E
M;F1#:&EL9"AL86)E;"D["@E]"@HO+R`)='(@/2!D;V,N8W)E871E16QE;65N
M="@B='(B*3L*+R\@"71B;V1Y+F%P<&5N9$-H:6QD*'1R*3L*+R\@"71D(#T@
M9&]C+F-R96%T945L96UE;G0H(G1D(BD["B\O(`ET9"YC;&%S<TYA;64@/2`B
M;&%B96PB.PHO+R`)='(N87!P96YD0VAI;&0H=&0I.PHO+R`)=&0N:6YN97)(
M5$U,(#T@:3$X;ELB36%R9VEN(ET@*R`B.B(["B\O(`ET9"`](&1O8RYC<F5A
M=&5%;&5M96YT*")T9"(I.PHO+R`)='(N87!P96YD0VAI;&0H=&0I.PHO+R`)
M:6YP=70@/2!D;V,N8W)E871E16QE;65N="@B:6YP=70B*3L*+R\@"6EN<'5T
M+G1Y<&4@/2`B=&5X="(["B\O(`EI;G!U="YS:7IE(#T@(C4B.PHO+R`):6YP
M=70N;F%M92`](")F7W-T7VUA<F=I;B(["B\O(`ET9"YA<'!E;F1#:&EL9"AI
M;G!U="D["B\O(`EI;G!U="YS='EL92YM87)G:6Y2:6=H="`]("(P+C5E;2([
M"B\O(`ET9"YA<'!E;F1#:&EL9"AD;V,N8W)E871E5&5X=$YO9&4H:3$X;ELB
M4&%D9&EN9R)=("L@(CHB*2D["@HO+R`):6YP=70@/2!D;V,N8W)E871E16QE
M;65N="@B:6YP=70B*3L*+R\@"6EN<'5T+G1Y<&4@/2`B=&5X="(["B\O(`EI
M;G!U="YS:7IE(#T@(C4B.PHO+R`):6YP=70N;F%M92`](")F7W-T7W!A9&1I
M;F<B.PHO+R`)=&0N87!P96YD0VAI;&0H:6YP=70I.PHO+R`):6YP=70N<W1Y
M;&4N;6%R9VEN3&5F="`]("(P+C5E;2(["B\O(`EI;G!U="YS='EL92YM87)G
M:6Y2:6=H="`]("(P+C5E;2(["B\O(`ET9"YA<'!E;F1#:&EL9"AD;V,N8W)E
M871E5&5X=$YO9&4H:3$X;ELB<&EX96QS(ETI*3L*"@ER971U<FX@9FEE;&1S
M970["GT["@HO+R\O($5.1"!'14Y%4DE#($-/1$4@+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H
M=&UL87)E82]P;'5G:6YS+TQI<W14>7!E````````````````````````````
M```````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,#`P,"`Q,#4Q-30S,S<T-"`P,C4V,C8`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O3&ES=%1Y<&4O;&%N
M9P```````````````````````````````````````#`P,#<U-2``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S0T(#`R-C4T-P`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU
M9VEN<R],:7-T5'EP92]L86YG+V5N+FIS````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$T-3$@,3`U,34T
M,S,W-#0@,#(W-38W`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"\O($DQ.$X@8V]N<W1A;G1S"@HO+R!,04Y'.B`B96XB+"!%
M3D-/1$E.1SH@551&+3@@?"!)4T\M.#@U.2TQ"B\O($%U=&AO<CH@36EH86D@
M0F%Z;VXL(&AT='`Z+R]D>6YA<F-H+F-O;2]M:7-H;V\*"B\O($9/4B!44D%.
M4TQ!5$]24SH*+R\*+R\@("`Q+B!03$5!4T4@4%54(%E/55(@0T].5$%#5"!)
M3D9/($E.(%1(12!!0D]612!,24Y%"B\O("`@("`@*&%T(&QE87-T(&$@=F%L
M:60@96UA:6P@861D<F5S<RD*+R\*+R\@("`R+B!03$5!4T4@5%)9(%1/(%53
M12!55$8M."!&3U(@14Y#3T1)3D<["B\O("`@("`@*&EF('1H:7,@:7,@;F]T
M('!O<W-I8FQE+"!P;&5A<V4@:6YC;'5D92!A(&-O;6UE;G0*+R\@("`@("`@
M=&AA="!S=&%T97,@=VAA="!E;F-O9&EN9R!I<R!N96-E<W-A<GDN*0H*3&ES
M=%1Y<&4N23$X3B`]('L*"2)$96-I;6%L(B`@("`@("`@("`@("`@("`Z("`@
M(")$96-I;6%L(&YU;6)E<G,B+`H)(DQO=V5R(')O;6%N(B`@("`@("`@("`@
M(#H@("`@(DQO=V5R(')O;6%N(&YU;6)E<G,B+`H)(E5P<&5R(')O;6%N(B`@
M("`@("`@("`@(#H@("`@(E5P<&5R(')O;6%N(&YU;6)E<G,B+`H)(DQO=V5R
M(&QA=&EN(B`@("`@("`@("`@(#H@("`@(DQO=V5R(&QA=&EN(&QE='1E<G,B
M+`H)(E5P<&5R(&QA=&EN(B`@("`@("`@("`@(#H@("`@(E5P<&5R(&QA=&EN
M(&QE='1E<G,B+`H)(DQO=V5R(&=R965K(B`@("`@("`@("`@(#H@("`@(DQO
M=V5R(&=R965K(&QE='1E<G,B+`H)(DQI<W13='EL951O;VQT:7`B("`@("`@
M(#H@("`@(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI
M<W1S*2(*?3L*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R
M96$O<&QU9VEN<R],:7-T5'EP92]L:7-T+71Y<&4N:G,`````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#4Q-C,@
M,3`U,34T,S,W-#0@,#,P,C`R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"\O($QI<W14>7!E(%!L=6=I;B!F;W(@2%1-3$%R
M96$M,RXP"B\O(%-P;VYS;W)E9"!B>2!-161496-H(%5N:70@+2!1=65E;B=S
M(%5N:79E<G-I='D*+R\@26UP;&5M96YT871I;VX@8GD@36EH86D@0F%Z;VXL
M(&AT='`Z+R]D>6YA<F-H+F-O;2]M:7-H;V\O"B\O"B\O("AC*2!D>6YA<F-H
M+F-O;2`R,#`S+3(P,#4N"B\O($1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE
M('1E<FUS(&%S($A434Q!<F5A(&ET<V5L9BX*+R\@5&AI<R!N;W1I8V4@3553
M5"!S=&%Y(&EN=&%C="!F;W(@=7-E("AS964@;&EC96YS92YT>'0I+@HO+PHO
M+R`D260Z(&QI<W0M='EP92YJ<RQV(#$N,B`R,#`U+S`Q+S(P(#$W.C0Y.C`S
M(&UI<VAO;R!%>'`@)`H*9G5N8W1I;VX@3&ES=%1Y<&4H961I=&]R*2!["@ET
M:&ES+F5D:71O<B`](&5D:71O<CL*"79A<B!C9F<@/2!E9&ET;W(N8V]N9FEG
M.PH)=F%R('1O;VQB87(@/2!C9F<N=&]O;&)A<CL*"79A<B!S96QF(#T@=&AI
M<SL*"79A<B!I,3AN(#T@3&ES=%1Y<&4N23$X3CL*"79A<B!O<'1I;VYS(#T@
M>WT["@EO<'1I;VYS6VDQ.&Y;(D1E8VEM86PB75T@/2`B9&5C:6UA;"(["@EO
M<'1I;VYS6VDQ.&Y;(DQO=V5R(')O;6%N(EU=(#T@(FQO=V5R+7)O;6%N(CL*
M"6]P=&EO;G-;:3$X;ELB57!P97(@<F]M86XB75T@/2`B=7!P97(M<F]M86XB
M.PH);W!T:6]N<UMI,3AN6R),;W=E<B!L871I;B)=72`](")L;W=E<BUA;'!H
M82(["@EO<'1I;VYS6VDQ.&Y;(E5P<&5R(&QA=&EN(EU=(#T@(G5P<&5R+6%L
M<&AA(CL*"6EF("@A2%1-3$%R96$N:7-?:64I"@D)+R\@244@9&]E<VXG="!S
M=7!P;W)T('1H:7,@<')O<&5R='D[(&5V96X@=V]R<V4L(&ET(&-O;7!L86EN
M<PH)"2\O('=I=&@@82!G<F]S<R!E<G)O<B!M97-S86=E('=H96X@=V4@=')I
M960@=&\@<V5L96-T(&ET+`H)"2\O('1H97)E9F]R92!L970G<R!H:61E(&ET
M(&9R;VT@=&AE(&1A;6X@(F)R;W=S97(B+@H)"6]P=&EO;G-;:3$X;ELB3&]W
M97(@9W)E96LB75T@/2`B;&]W97(M9W)E96LB.PH)=F%R(&]B:B`]('L*"0EI
M9"`@("`@("`@("`@(#H@(DQI<W14>7!E(BP*"0ET;V]L=&EP("`@("`@(#H@
M:3$X;ELB3&ES=%-T>6QE5&]O;'1I<")=+`H)"6]P=&EO;G,@("`@("`@.B!O
M<'1I;VYS+`H)"6%C=&EO;B`@("`@("`@.B!F=6YC=&EO;BAE9&ET;W(I('L@
M<V5L9BYO;E-E;&5C="AE9&ET;W(L('1H:7,I.R!]+`H)"7)E9G)E<V@@("`@
M("`@.B!F=6YC=&EO;BAE9&ET;W(I('L@<V5L9BYU<&1A=&5686QU92AE9&ET
M;W(L('1H:7,I.R!]+`H)"6-O;G1E>'0@("`@("`@.B`B;VPB"@E].PH)8V9G
M+G)E9VES=&5R1')O<&1O=VXH;V)J*3L*"79A<B!A+"!I+"!J+"!F;W5N9"`]
M(&9A;'-E.PH)9F]R("AI(#T@,#L@(69O=6YD("8F(&D@/"!T;V]L8F%R+FQE
M;F=T:#L@*RMI*2!["@D)82`]('1O;VQB87);:5T["@D)9F]R("AJ(#T@,#L@
M:B`\(&$N;&5N9W1H.R`K*VHI('L*"0D):68@*&%;:ET@/3T@(G5N;W)D97)E
M9&QI<W0B*2!["@D)"0EF;W5N9"`]('1R=64["@D)"0EB<F5A:SL*"0D)?0H)
M"7T*"7T*"6EF("AF;W5N9"D*"0EA+G-P;&EC92AJ+"`P+"`B<W!A8V4B+"`B
M3&ES=%1Y<&4B+"`B<W!A8V4B*3L*?3L*"DQI<W14>7!E+E]P;'5G:6Y);F9O
M(#T@>PH);F%M92`@("`@("`@("`Z("),:7-T5'EP92(L"@EV97)S:6]N("`@
M("`@(#H@(C$N,"(L"@ED979E;&]P97(@("`@(#H@(DUI:&%I($)A>F]N(BP*
M"61E=F5L;W!E<E]U<FP@.B`B:'1T<#HO+V1Y;F%R8V@N8V]M+VUI<VAO;R\B
M+`H)8U]O=VYE<B`@("`@("`Z(")D>6YA<F-H+F-O;2(L"@ES<&]N<V]R("`@
M("`@(#H@(DU%9%1E8V@@56YI="`M(%%U965N)W,@56YI=F5R<VET>2(L"@ES
M<&]N<V]R7W5R;"`@(#H@(FAT='`Z+R]W=W<N<75E96YS=2YC82\B+`H);&EC
M96YS92`@("`@("`Z(")H=&UL07)E82(*?3L*"DQI<W14>7!E+G!R;W1O='EP
M92YO;E-E;&5C="`](&9U;F-T:6]N*&5D:71O<BP@8V]M8F\I('L*"79A<B!T
M8F]B:B`](&5D:71O<BY?=&]O;&)A<D]B:F5C='-;8V]M8F\N:61=+F5L96UE
M;G0["@EV87(@<&%R96YT(#T@961I=&]R+F=E=%!A<F5N=$5L96UE;G0H*3L*
M"7=H:6QE("@A+UYO;"0O:2YT97-T*'!A<F5N="YT86=.86UE*2D@>PH)"7!A
M<F5N="`]('!A<F5N="YP87)E;G1.;V1E.PH)?0H)<&%R96YT+G-T>6QE+FQI
M<W13='EL951Y<&4@/2!T8F]B:BYV86QU93L*?3L*"DQI<W14>7!E+G!R;W1O
M='EP92YU<&1A=&5686QU92`](&9U;F-T:6]N*&5D:71O<BP@8V]M8F\I('L*
M"79A<B!T8F]B:B`](&5D:71O<BY?=&]O;&)A<D]B:F5C='-;8V]M8F\N:61=
M+F5L96UE;G0["@EV87(@<&%R96YT(#T@961I=&]R+F=E=%!A<F5N=$5L96UE
M;G0H*3L*"7=H:6QE("AP87)E;G0@)B8@(2]>;VPD+VDN=&5S="AP87)E;G0N
M=&%G3F%M92DI('L*"0EP87)E;G0@/2!P87)E;G0N<&%R96YT3F]D93L*"7T*
M"6EF("@A<&%R96YT*2!["@D)=&)O8FHN<V5L96-T961);F1E>"`](#`["@D)
M<F5T=7)N.PH)?0H)=F%R('1Y<&4@/2!P87)E;G0N<W1Y;&4N;&ES=%-T>6QE
M5'EP93L*"6EF("@A='EP92D@>PH)"71B;V)J+G-E;&5C=&5D26YD97@@/2`P
M.PH)?2!E;'-E('L*"0EF;W(@*'9A<B!I(#T@=&)O8FHN9FER<W1#:&EL9#L@
M:3L@:2`](&DN;F5X=%-I8FQI;F<I('L*"0D):2YS96QE8W1E9"`]("AT>7!E
M+FEN9&5X3V8H:2YV86QU92D@(3T@+3$I.PH)"7T*"7T*?3L*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;W!U<',`````````
M```````````````````````````````````````````````````P,#`W-34@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<T-"`P,C,W
M,38`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA
M<F5A+W!O<'5P<R]F=6QL<V-R965N+FAT;6P`````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$R-S8P
M(#$P-3$U-#,S-S0T(#`R-S`S,P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\(41/0U194$4@:'1M;"!054),24,@(BTO+U<S
M0R\O1%1$(%A(5$U,(#$N,2\O14XB(")H='1P.B\O=W=W+G<S+F]R9R]44B]X
M:'1M;#$Q+T141"]X:'1M;#$Q+F1T9"(^"CQH=&UL/@H@(#QH96%D/@H@("`@
M/'1I=&QE/D9U;&QS8W)E96X@2%1-3$%R96$\+W1I=&QE/@H@("`@/'-C<FEP
M="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H@("`@("!?961I=&]R7W5R;"`]
M('=I;F1O=RYO<&5N97(N7V5D:71O<E]U<FP@?'P@)RXN+R<["B`@("`@(%]E
M9&ET;W)?;&%N9R`]('=I;F1O=RYO<&5N97(N7V5D:71O<E]L86YG.PH@("`@
M("!?961I=&]R7V-S<R`]('=I;F1O=RYO<&5N97(N7V5D:71O<E]C<W,["B`@
M("`@('9A<B!"05-%(#T@=VEN9&]W+F]P96YE<BYD;V-U;65N="YB87-E55))
M('Q\('=I;F1O=RYO<&5N97(N9&]C=6UE;G0N55),.PH@("`@("!V87(@:&5A
M9"`](&1O8W5M96YT+F=E=$5L96UE;G1S0GE486=.86UE*")H96%D(BE;,%T[
M"B`@("`@('9A<B!B87-E(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@B8F%S
M92(I.PH@("`@("!B87-E+FAR968@/2!"05-%.PH@("`@("!H96%D+F%P<&5N
M9$-H:6QD*&)A<V4I.PH@("`@/"]S8W)I<'0^"@H@("`@/'-C<FEP="!T>7!E
M/2)T97AT+VIA=F%S8W)I<'0B/@H@("`@("`@(&1O8W5M96YT+G=R:71E*"<\
M<V-R)R`K("=I<'0@='EP93TB=&5X="]J879A<V-R:7!T(B!S<F,](B<@*R!?
M961I=&]R7W5R;"`K("=H=&UL87)E82YJ<R(^/"]S8W(G("L@)VEP=#XG*3L*
M("`@(#PO<V-R:7!T/@H@("`@/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I
M<'0B/@H)+R\@;&]A9"!(5$U,07)E82!S8W)I<'1S('1H870@87)E('!R97-E
M;G0@:6X@=&AE(&]P96YE<B!F<F%M90H)=F%R('-C<FEP=',@/2!W:6YD;W<N
M;W!E;F5R+DA434Q!<F5A+E]S8W)I<'1S.PH)9F]R("AV87(@:2`](#,[(&D@
M/"!S8W)I<'1S+FQE;F=T:#L@*RMI*2!["B`@("`@("`@("`@+R]D;V-U;65N
M="YW<FET92@B/'-C<B(@*R`B:7!T('1Y<&4])W1E>'0O:F%V87-C<FEP="<@
M<W)C/2<B("L@<V-R:7!T<UMI72`K("(G/CPO<V-R(B`K(")I<'0^(BD["B`@
M("`@("`@("`@2%1-3$%R96$N;&]A9%-C<FEP="AS8W)I<'1S6VE=*3L*("`@
M("`@("!]"B`@("`\+W-C<FEP=#X*"B`@("`\(2TM(&)R;W=S97(@=&%K97,@
M82!C;V9F964@8G)E86L@:&5R92`M+3X*("`@(#QS8W)I<'0@='EP93TB=&5X
M="]J879A<V-R:7!T(CX*=F%R('!A<F5N=%]O8FIE8W0@(#T@;G5L;#L*=F%R
M(&5D:71O<@D@("`](&YU;&P["2\O('1O(&)E(&EN:71I86QI>F5D(&QA=&5R
M(%L@9G5N8W1I;VX@:6YI="@I(%T*"B\J("TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2T@*EP*("`@1G5N8W1I;VX@("`@.@H@("!$97-C<FEP=&EO;B`Z"EPJ
M("TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T@*B\*"F9U;F-T:6]N(%]#;&]S
M94]N17-C*&5V*2!["@EE=B!\?"`H978@/2!W:6YD;W<N979E;G0I('Q\("AE
M=B`](&5D:71O<BY?:69R86UE+F-O;G1E;G17:6YD;W<N979E;G0I.PH):68@
M*&5V+FME>4-O9&4@/3T@,C<I('L*"0DO+R!U<&1A=&5?<&%R96YT*"D["@D)
M=VEN9&]W+F-L;W-E*"D["@D)<F5T=7)N.PH)?0I]"@HO*B`M+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM("I<"B`@($9U;F-T:6]N("`@(#H@<F5S:7IE7V5D
M:71O<@H@("!$97-C<FEP=&EO;B`Z(')E<VEZ92!T:&4@961I=&]R('=H96X@
M=&AE('5S97(@<F5S:7IE<R!T:&4@<&]P=7`*7"H@+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2`J+PH*9G5N8W1I;VX@<F5S:7IE7V5D:71O<B@I('L@("\O
M(')E<VEZ92!E9&ET;W(@=&\@9FEX('=I;F1O=PH*("!V87(@;F5W2&5I9VAT
M.PH@(&EF("AD;V-U;65N="YA;&PI('L@+R\@244*("`@(&YE=TAE:6=H="`]
M(&1O8W5M96YT+F)O9'DN;V9F<V5T2&5I9VAT("T@961I=&]R+E]T;V]L8F%R
M+F]F9G-E=$AE:6=H=#L*("`@(&EF("AN97=(96EG:'0@/"`P*2![(&YE=TAE
M:6=H="`](#`[('T*("!](&5L<V4@>R`O+R!'96-K;PH@("`@;F5W2&5I9VAT
M(#T@=VEN9&]W+FEN;F5R2&5I9VAT("T@961I=&]R+E]T;V]L8F%R+F]F9G-E
M=$AE:6=H=#L*("!]"B`@:68@*&5D:71O<BYC;VYF:6<N<W1A='5S0F%R*2![
M"B`@("!N97=(96EG:'0@+3T@961I=&]R+E]S=&%T=7-"87(N;V9F<V5T2&5I
M9VAT.PH@('T*"B`@+R\@5$]$3SH@22=M(&YO="!S=7)E(&5X86-T;'D@=VAA
M="!T:&5S92!A<F4@861J=7-T:6YG(&9O<BP@8G5T(&EF"B`@+R\@>6]U(&1O
M;B=T(&%D:G5S="!T:&4@:&5I9VAT(&9O<B!)12!T:&5N(&1O8W5M96YT+F)O
M9'DN;V9F<V5T2&5I9VAT"B`@+R\@=VEL;"!G970@;&%R9V5R(&5V97)Y('1I
M;64@86YD('1H92`H<&]P=7`I(&5D:71O<B!W:6QL(&=E="!S='5C:PH@("\O
M(&EN(&$@=&EG:'0@;&]O<"!A;F0@=&AE(&)R;W=S97(@=V]N)W0@8F4@<F5S
M<&]N<VEV92X@($EN(&9U='5R92!W92=L;`H@("\O('=A;G0@=&\@9V5T('1H
M97-E(&UE87-U<F5M96YT<R!D>6YA;6EC86QL>2!I;B!C87-E(&5L96UE;G1S
M(&-H86YG92!S:7IE"B`@+R\@:6X@=&AE(&9U='5R92X*"B`@:68@*$A434Q!
M<F5A+FES7V=E8VMO*2![(&YE=TAE:6=H="`M/2`X.R!]"B`@96QS92`@("`@
M("`@("`@("`@("`@("![(&YE=TAE:6=H="`M/2`Q,#L@?0H*("`O+R!A9&IU
M<W0@96QE;65N="!H96EG:'0*("!V87(@;F5W2&5I9VAT5VET:%!X(#T@;F5W
M2&5I9VAT("L@(G!X(CL*("!E9&ET;W(N7W1E>'1!<F5A+G-T>6QE+FAE:6=H
M="`](&YE=TAE:6=H=%=I=&A0>#L*("!E9&ET;W(N7VEF<F%M92YS='EL92YH
M96EG:'0@("`](&YE=TAE:6=H=%=I=&A0>#L*?0H*+RH@+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2`J7`H@("!&=6YC=&EO;B`@("`Z(&EN:70*("`@1&5S
M8W)I<'1I;VX@.B!R=6X@=&AI<R!C;V1E(&]N('!A9V4@;&]A9`I<*B`M+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM("HO"@IF=6YC=&EO;B!I;FET*"D@>PH)
M<&%R96YT7V]B:F5C=`D@("`](&]P96YE<BY(5$U,07)E82Y?;V)J96-T.PH)
M=F%R(&-O;F9I9PD@("`]($A434Q!<F5A+F-L;VYE3V)J96-T*"!P87)E;G1?
M;V)J96-T+F-O;F9I9R`I.PH)8V]N9FEG+G=I9'1H"2`@(#T@(C$P,"4B.PH)
M8V]N9FEG+FAE:6=H=`D@("`](")A=71O(CL*"@DO+R!C:&%N9V4@;6%X:6UI
M>F4@8G5T=&]N('1O(&UI;FEM:7IE(&)U='1O;@H)8V]N9FEG+F)T;DQI<W1;
M(G!O<'5P961I=&]R(ET@/2!;("=-:6YI;6EZ92!%9&ET;W(G+"!?961I=&]R
M7W5R;"`K("=I;6%G97,O9G5L;'-C<F5E;E]M:6YI;6EZ92YG:68G+"!T<G5E
M+`H)"0D)"2`@9G5N8W1I;VXH*2![('=I;F1O=RYC;&]S92@I.R!](%T["@H)
M+R\@9V5N97)A=&4@961I=&]R(&%N9"!R97-I>F4@:70*"65D:71O<B`](&YE
M=R!(5$U,07)E82@B961I=&]R(BP@8V]N9FEG*3L*"@DO+R!R96=I<W1E<B!T
M:&4@<&QU9VEN<RP@:68@86YY"@EF;W(@*'9A<B!I(&EN('!A<F5N=%]O8FIE
M8W0N<&QU9VEN<RD@>PH)"79A<B!P;'5G:6X@/2!P87)E;G1?;V)J96-T+G!L
M=6=I;G-;:5T["@D)=')Y('L*"0D)979A;"AP;'5G:6XN;F%M92D["@D)"65D
M:71O<BYR96=I<W1E<E!L=6=I;C(H<&QU9VEN+FYA;64L('!L=6=I;BYA<F=S
M*3L*"0E](&-A=&-H*&4I('M].PH)?0H)+R\@86YD(')E<W1O<F4@=&AE(&]R
M:6=I;F%L('1O;VQB87(*("`@("`@("!C;VYF:6<N=&]O;&)A<B`]('!A<F5N
M=%]O8FIE8W0N8V]N9FEG+G1O;VQB87(["@EE9&ET;W(N9V5N97)A=&4H*3L*
M"65D:71O<BY?:69R86UE+G-T>6QE+G=I9'1H(#T@(C$P,"4B.PH)961I=&]R
M+E]T97AT07)E82YS='EL92YW:61T:"`]("(Q,#`E(CL*"7)E<VEZ95]E9&ET
M;W(H*3L*"@EE9&ET;W(N9&]C='EP92`]('!A<F5N=%]O8FIE8W0N9&]C='EP
M93L*"@DO+R!S970@8VAI;&0@=VEN9&]W(&-O;G1E;G1S(&%N9"!E=F5N="!H
M86YD;&5R<RP@869T97(@82!S;6%L;"!D96QA>0H)<V5T5&EM96]U="AF=6YC
M=&EO;B@I('L*"0D)("`@961I=&]R+G-E=$A434PH<&%R96YT7V]B:F5C="YG
M971);FYE<DA434PH*2D["@H)"0D@("`O+R!S=VET8V@@;6]D92!I9B!N965D
M960*"0D)("`@:68@*'!A<F5N=%]O8FIE8W0N7VUO9&4@/3T@(G1E>'1M;V1E
M(BD@>R!E9&ET;W(N<V5T36]D92@B=&5X=&UO9&4B*3L@?0H*"0D)("`@+R\@
M8V]N=&EN=6]U<VQY('5P9&%T92!P87)E;G0@961I=&]R('=I;F1O=PH)"0D@
M("!S971);G1E<G9A;"AU<&1A=&5?<&%R96YT+"`U,#`I.PH*"0D)("`@+R\@
M<V5T=7`@979E;G0@:&%N9&QE<G,*"0D)("`@9&]C=6UE;G0N8F]D>2YO;FME
M>7!R97-S(#T@7T-L;W-E3VY%<V,["@D)"2`@(&5D:71O<BY?9&]C+F)O9'DN
M;VYK97EP<F5S<R`](%]#;&]S94]N17-C.PH)"0D@("!E9&ET;W(N7W1E>'1!
M<F5A+F]N:V5Y<')E<W,@/2!?0VQO<V5/;D5S8SL*"0D)("`@=VEN9&]W+F]N
M<F5S:7IE(#T@<F5S:7IE7V5D:71O<CL*"0D@("!]+"`S,S,I.PD)"2`O+R!G
M:79E(&ET('-O;64@=&EM92!T;R!M965T('1H92!N97<@9G)A;64*?0H*+RH@
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2`J7`H@("!&=6YC=&EO;B`@("`Z
M('5P9&%T95]P87)E;G0*("`@1&5S8W)I<'1I;VX@.B!U<&1A=&4@<&%R96YT
M('=I;F1O=R!E9&ET;W(@9FEE;&0@=VET:"!C;VYT96YT<R!F<F]M(&-H:6QD
M('=I;F1O=PH@("!<*B`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM("HO"@IF
M=6YC=&EO;B!U<&1A=&5?<&%R96YT*"D@>PH*"2\O('5S92!T:&4@9F%S="!V
M97)S:6]N"@EP87)E;G1?;V)J96-T+G-E=$A434PH961I=&]R+F=E=$EN;F5R
M2%1-3"@I*3L*?0H*("`@(#PO<V-R:7!T/@H@("`@/'-T>6QE('1Y<&4](G1E
M>'0O8W-S(CX@:'1M;"P@8F]D>2![(&AE:6=H=#H@,3`P)3L@;6%R9VEN.B`P
M<'@[(&)O<F1E<CH@,'!X.R!B86-K9W)O=6YD+6-O;&]R.B!B=71T;VYF86-E
M.R!](#PO<W1Y;&4^"B`@/"]H96%D/@H@(#QB;V1Y('-C<F]L;#TB;F\B(&]N
M;&]A9#TB2%1-3$%R96$N;VYL;V%D(#T@:6YI=#L@2%1-3$%R96$N:6YI="@I
M.R(@;VYU;FQO860](G5P9&%T95]P87)E;G0H*2(^"B`@("`\9F]R;2!S='EL
M93TB;6%R9VEN.B`P<'@[(&)O<F1E<CH@,7!X('-O;&ED.R!B;W)D97(M8V]L
M;W(Z('1H<F5E9'-H861O=R!T:')E961H:6=H;&EG:'0@=&AR965D:&EG:&QI
M9VAT('1H<F5E9'-H861O=SLB/@H@("`@("`\=&5X=&%R96$@;F%M93TB961I
M=&]R(B!I9#TB961I=&]R(B!S='EL93TB=VED=&@Z,3`P)3L@:&5I9VAT.C,P
M,'!X(CXF;F)S<#L\+W1E>'1A<F5A/@H@("`@/"]F;W)M/@H@(#PO8F]D>3X*
M/"]H=&UL/@H`````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!O<'5P<R]P;W!U<"YJ<P``
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`V,C(U(#$P-3$U-#,S-S0T(#`R-34P,P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````O+R!H
M=&UL07)E82!V,RXP("T@0V]P>7)I9VAT("AC*2`R,#`R+"`R,#`S(&EN=&5R
M86-T:79E=&]O;',N8V]M+"!I;F,N"B\O(%1H:7,@8V]P>7)I9VAT(&YO=&EC
M92!-55-4('-T87D@:6YT86-T(&9O<B!U<V4@*'-E92!L:6-E;G-E+G1X="DN
M"B\O"B\O(%!O<G1I;VYS("AC*2!D>6YA<F-H+F-O;2P@,C`P,PHO+PHO+R!!
M(&9R964@5UE325=91R!E9&ET;W(@<F5P;&%C96UE;G0@9F]R(#QT97AT87)E
M83X@9FEE;&1S+@HO+R!&;W(@9G5L;"!S;W5R8V4@8V]D92!A;F0@9&]C<RP@
M=FES:70@:'1T<#HO+W=W=RYH=&UL87)E82YC;VTO"B\O"B\O(%9E<G-I;VX@
M,RXP(&1E=F5L;W!E9"!B>2!-:6AA:2!"87IO;BX*+R\@("!H='1P.B\O9'EN
M87)C:"YC;VTO;6ES:&]O"B\O"B\O("1)9#H@<&]P=7`N:G,L=B`Q+C$R(#(P
M,#4O,#$O,C0@,3@Z,CDZ-#@@:71O;VQS($5X<"`D"@IF=6YC=&EO;B!G971!
M8G-O;'5T95!O<RAE;"D@>PH)=F%R('(@/2![('@Z(&5L+F]F9G-E=$QE9G0L
M('DZ(&5L+F]F9G-E=%1O<"!].PH):68@*&5L+F]F9G-E=%!A<F5N="D@>PH)
M"79A<B!T;7`@/2!G971!8G-O;'5T95!O<RAE;"YO9F9S971087)E;G0I.PH)
M"7(N>"`K/2!T;7`N>#L*"0ER+GD@*ST@=&UP+GD["@E]"@ER971U<FX@<CL*
M?3L*"F9U;F-T:6]N(&-O;6)O4V5L96-T5F%L=64H8RP@=F%L*2!["@EV87(@
M;W!S(#T@8RYG971%;&5M96YT<T)Y5&%G3F%M92@B;W!T:6]N(BD["@EF;W(@
M*'9A<B!I(#T@;W!S+FQE;F=T:#L@+2UI(#X](#`[*2!["@D)=F%R(&]P(#T@
M;W!S6VE=.PH)"6]P+G-E;&5C=&5D(#T@*&]P+G9A;'5E(#T]('9A;"D["@E]
M"@EC+G9A;'5E(#T@=F%L.PI].PH*9G5N8W1I;VX@7U]D;&=?;VYC;&]S92@I
M('L*"6]P96YE<BY$:6%L;V<N7W)E='5R;BAN=6QL*3L*?3L*"F9U;F-T:6]N
M(%]?9&QG7VEN:70H8F]T=&]M*2!["@EV87(@8F]D>2`](&1O8W5M96YT+F)O
M9'D["@EV87(@8F]D>5]H96EG:'0@/2`P.PH):68@*'1Y<&5O9B!B;W1T;VT@
M/3T@(G5N9&5F:6YE9"(I('L*"0EV87(@9&EV(#T@9&]C=6UE;G0N8W)E871E
M16QE;65N="@B9&EV(BD["@D)8F]D>2YA<'!E;F1#:&EL9"AD:78I.PH)"79A
M<B!P;W,@/2!G971!8G-O;'5T95!O<RAD:78I.PH)"6)O9'E?:&5I9VAT(#T@
M<&]S+GD["@E](&5L<V4@>PH)"79A<B!P;W,@/2!G971!8G-O;'5T95!O<RAB
M;W1T;VTI.PH)"6)O9'E?:&5I9VAT(#T@<&]S+GD@*R!B;W1T;VTN;V9F<V5T
M2&5I9VAT.PH)?0H)=VEN9&]W+F1I86QO9T%R9W5M96YT<R`](&]P96YE<BY$
M:6%L;V<N7V%R9W5M96YT<SL*"6EF("@A9&]C=6UE;G0N86QL*2!["@D)=VEN
M9&]W+G-I>F54;T-O;G1E;G0H*3L*"0EW:6YD;W<N<VEZ951O0V]N=&5N="@I
M.PDO+R!F;W(@<F5A<V]N<R!B97EO;F0@=6YD97)S=&%N9&EN9RP*"0D)"0DO
M+R!O;FQY(&EF('=E(&-A;&P@:70@='=I8V4@=V4@9V5T('1H90H)"0D)"2\O
M(&-O<G)E8W0@<VEZ92X*"0EW:6YD;W<N861D179E;G1,:7-T96YE<B@B=6YL
M;V%D(BP@7U]D;&=?;VYC;&]S92P@=')U92D["@D)=VEN9&]W+FEN;F5R5VED
M=&@@/2!B;V1Y+F]F9G-E=%=I9'1H("L@-3L*"0EW:6YD;W<N:6YN97)(96EG
M:'0@/2!B;V1Y7VAE:6=H="`K(#(["@D)+R\@8V5N=&5R(&]N('!A<F5N=`H)
M"79A<B!X(#T@;W!E;F5R+G-C<F5E;E@@*R`H;W!E;F5R+F]U=&5R5VED=&@@
M+2!W:6YD;W<N;W5T97)7:61T:"D@+R`R.PH)"79A<B!Y(#T@;W!E;F5R+G-C
M<F5E;ED@*R`H;W!E;F5R+F]U=&5R2&5I9VAT("T@=VEN9&]W+F]U=&5R2&5I
M9VAT*2`O(#(["@D)=VEN9&]W+FUO=F54;RAX+"!Y*3L*"7T@96QS92!["@D)
M+R\@=VEN9&]W+F1I86QO9TAE:6=H="`](&)O9'DN;V9F<V5T2&5I9VAT("L@
M-3`@*R`B<'@B.PH)"2\O('=I;F1O=RYD:6%L;V=7:61T:"`](&)O9'DN;V9F
M<V5T5VED=&@@*R`B<'@B.PH)"7=I;F1O=RYR97-I>F54;RAB;V1Y+F]F9G-E
M=%=I9'1H+"!B;V1Y7VAE:6=H="D["@D)=F%R(&-H(#T@8F]D>2YC;&EE;G1(
M96EG:'0["@D)=F%R(&-W(#T@8F]D>2YC;&EE;G17:61T:#L*"0EW:6YD;W<N
M<F5S:7IE0GDH8F]D>2YO9F9S9717:61T:"`M(&-W+"!B;V1Y7VAE:6=H="`M
M(&-H*3L*"0EV87(@5R`](&)O9'DN;V9F<V5T5VED=&@["@D)=F%R($@@/2`R
M("H@8F]D>5]H96EG:'0@+2!C:#L*"0EV87(@>"`]("AS8W)E96XN879A:6Q7
M:61T:"`M(%<I("\@,CL*"0EV87(@>2`]("AS8W)E96XN879A:6Q(96EG:'0@
M+2!(*2`O(#(["@D)=VEN9&]W+FUO=F54;RAX+"!Y*3L*"7T*"61O8W5M96YT
M+F)O9'DN;VYK97EP<F5S<R`](%]?9&QG7V-L;W-E7V]N7V5S8SL*?3L*"F9U
M;F-T:6]N(%]?9&QG7W1R86YS;&%T92AI,3AN*2!["@EV87(@='EP97,@/2!;
M(FEN<'5T(BP@(G-E;&5C="(L(")L96=E;F0B+"`B<W!A;B(L(")O<'1I;VXB
M+"`B=&0B+"`B8G5T=&]N(BP@(F1I=B)=.PH)9F]R("AV87(@='EP92`](#`[
M('1Y<&4@/"!T>7!E<RYL96YG=&@[("LK='EP92D@>PH)"79A<B!S<&%N<R`]
M(&1O8W5M96YT+F=E=$5L96UE;G1S0GE486=.86UE*'1Y<&5S6W1Y<&5=*3L*
M"0EF;W(@*'9A<B!I(#T@<W!A;G,N;&5N9W1H.R`M+6D@/CT@,#LI('L*"0D)
M=F%R('-P86X@/2!S<&%N<UMI73L*"0D):68@*'-P86XN9FER<W1#:&EL9"`F
M)B!S<&%N+F9I<G-T0VAI;&0N9&%T82D@>PH)"0D)=F%R('1X="`](&DQ.&Y;
M<W!A;BYF:7)S=$-H:6QD+F1A=&%=.PH)"0D):68@*'1X="D*"0D)"0ES<&%N
M+F9I<G-T0VAI;&0N9&%T82`]('1X=#L*"0D)?0H@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H<W!A;BYT:71L92D@>PH)"0D)=F%R('1X="`](&DQ.&Y;
M<W!A;BYT:71L95T["@D)"0EI9B`H='AT*0H)"0D)"7-P86XN=&ET;&4@/2!T
M>'0["B`@("`@("`@("`@("`@("`@("`@("`@('T*"0E]"@E]"@EV87(@='AT
M(#T@:3$X;EMD;V-U;65N="YT:71L95T["@EI9B`H='AT*0H)"61O8W5M96YT
M+G1I=&QE(#T@='AT.PI].PH*+R\@8VQO<V5S('1H92!D:6%L;V<@86YD('!A
M<W-E<R!T:&4@<F5T=7)N(&EN9F\@=7!P97(N"F9U;F-T:6]N(%]?9&QG7V-L
M;W-E*'9A;"D@>PH);W!E;F5R+D1I86QO9RY?<F5T=7)N*'9A;"D["@EW:6YD
M;W<N8VQO<V4H*3L*?3L*"F9U;F-T:6]N(%]?9&QG7V-L;W-E7V]N7V5S8RAE
M=BD@>PH)978@?'P@*&5V(#T@=VEN9&]W+F5V96YT*3L*"6EF("AE=BYK97E#
M;V1E(#T](#(W*2!["@D)=VEN9&]W+F-L;W-E*"D["@D)<F5T=7)N(&9A;'-E
M.PH)?0H)<F5T=7)N('1R=64["GT["@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;W!U<',O86)O=70N:'1M
M;``````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`S,#$P-2`Q,#4Q-30S,S<T-"`P,C4W-S0`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/"$M
M+0H**&,I(&1Y;F%R8V@N8V]M+"`R,#`S+3(P,#4*075T:&]R.B!-:6AA:2!"
M87IO;BP@:'1T<#HO+V1Y;F%R8V@N8V]M+VUI<VAO;PI$:7-T<FEB=71E9"!A
M<R!P87)T(&]F($A434Q!<F5A(#,N,`H*(EEO=2!A<F4@;F]T(&5X<&5C=&5D
M('1O('5N9&5R<W1A;F0@=&AI<RXN+B`@22!D;VXG="!N96ET:&5R+B(*"B`@
M("`@("`@("`@("`@("`@("`@("`H9G)O;2!4:&4@3&EN=7@@2V5R;F5L(%-O
M=7)C92!#;V1E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B]A<F-H
M+W@X-E\V-"]I83,R+W!T<F%C92YC.CDP*0H*.RTI"@HM+3X*"CQH=&UL('-T
M>6QE/2)H96EG:'0Z(#$P,"4B/@H\:&5A9#X*/&UE=&$@:'1T<"UE<75I=CTB
M0V]N=&5N="U4>7!E(B!C;VYT96YT/2)T97AT+VAT;6P[(&-H87)S970]=71F
M+3@B("\^"CQT:71L93Y!8F]U="!(5$U,07)E83PO=&ET;&4^"CQS8W)I<'0@
M='EP93TB=&5X="]J879A<V-R:7!T(B!S<F,](G!O<'5P+FIS(CX\+W-C<FEP
M=#X*/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@IW:6YD;W<N<F5S
M:7IE5&\H-#4P+"`R-3`I.PIV87(@5$%"4R`](%M=.PIV87(@0U524D5.5%]4
M04(@/2`P.PIV87(@0T].5$5.5%](14E'2%1?1$E&1B`](#`["G9A<B!#3TY4
M14Y47U=)1%1(7T1)1D8@/2`P.PIF=6YC=&EO;B!S96QE8W1486(H:61X*2![
M"B`@=F%R(&-T(#T@5$%"4UM#55)214Y47U1!0ET["B`@8W0N8VQA<W-.86UE
M(#T@8W0N8VQA<W-.86UE+G)E<&QA8V4H+UQS*G1A8BUC=7)R96YT7',J+RP@
M)R`G*3L*("!C="`](%1!0E-;0U524D5.5%]404(@/2!I9'A=.PH@(&-T+F-L
M87-S3F%M92`K/2`G('1A8BUC=7)R96YT)SL*("!F;W(@*'9A<B!I(#T@5$%"
M4RYL96YG=&@[("TM:2`^/2`P.RD@>PH@("`@=F%R(&%R96$@/2!D;V-U;65N
M="YG971%;&5M96YT0GE)9"@B=&%B+6%R96$M(B`K(&DI.PH@("`@:68@*$-5
M4E)%3E1?5$%"(#T](&DI('L*("`@("`@87)E82YS='EL92YD:7-P;&%Y(#T@
M(F)L;V-K(CL*("`@('T@96QS92!["B`@("`@(&%R96$N<W1Y;&4N9&ES<&QA
M>2`](")N;VYE(CL*("`@('T*("!]"B`@9&]C=6UE;G0N8F]D>2YS='EL92YV
M:7-I8FEL:71Y(#T@(FAI9&1E;B(["B`@9&]C=6UE;G0N8F]D>2YS='EL92YV
M:7-I8FEL:71Y(#T@(G9I<VEB;&4B.PH@(&1O8W5M96YT+F-O;VMI92`](")(
M5$U,05)%02U!0D]55"U404(](B`K(&ED>#L*?0IV87(@961I=&]R(#T@;G5L
M;#L*9G5N8W1I;VX@:6YI=$1O8W5M96YT*"D@>PH@(&5D:71O<B`]('=I;F1O
M=RYD:6%L;V=!<F=U;65N=',["B`@2%1-3$%R96$@/2!W:6YD;W<N;W!E;F5R
M+DA434Q!<F5A.PH*("!V87(@<&QU9VEN<R`](&1O8W5M96YT+F=E=$5L96UE
M;G1">4ED*")P;'5G:6YS(BD["B`@=F%R(&H@/2`P.PH@('9A<B!H=&UL(#T@
M(CQT86)L92!W:61T:#TG.3DE)R!C96QL<&%D9&EN9STG,"<@<W1Y;&4])VUA
M<F=I;BUT;W`Z(#%E;3L@8V]L;&%P<V4M8F]R9&5R<SH@8V]L;&%P<V4[(&)O
M<F1E<CH@,7!X('-O;&ED(",X8C@[)SXB("L*"2`@(CQT:&5A9#X\='(^(B`K
M"@D@("(\=&0^3F%M93PO=&0^(B`K"@D@("(\=&0^1&5V96QO<&5R/"]T9#XB
M("L*"2`@(CQT9#Y3<&]N<V]R960@8GD\+W1D/B(@*PH)("`B/'1D/DQI8V5N
M<V4\<W5P/BH\+W-U<#X\+W1D/B(@*PH)("`B/"]T<CX\+W1H96%D/CQT8F]D
M>3XB.PH@(&9O<B`H=F%R(&D@:6X@961I=&]R+G!L=6=I;G,I('L*("`@('9A
M<B!I;F9O(#T@961I=&]R+G!L=6=I;G-;:5T["B`@("!H=&UL("L]("(\='(^
M/'1D/B(@*R!I;F9O+FYA;64@*R`B('8B("L@:6YF;RYV97)S:6]N("L@(CPO
M=&0^(B`K"B`@("`@("`@("`@("(\=&0^/&$@:')E9CTG(B`K(&EN9F\N9&5V
M96QO<&5R7W5R;"`K("(G('1A<F=E=#TG7V)L86YK)R!T:71L93TG5FES:70@
M9&5V96QO<&5R('=E8G-I=&4G/B(@*PH)("`@(&EN9F\N9&5V96QO<&5R("L@
M(CPO83X\+W1D/B(@*PH)("`@("(\=&0^/&$@:')E9CTG(B`K(&EN9F\N<W!O
M;G-O<E]U<FP@*R`B)R!T87)G970])U]B;&%N:R<@=&ET;&4])U9I<VET('-P
M;VYS;W(@=V5B<VET92<^(B`K"@D@("`@:6YF;RYS<&]N<V]R("L@(CPO83X\
M+W1D/B(@*PH)("`@("(\=&0^(B`K(&EN9F\N;&EC96YS92`K("(\+W1D/CPO
M='(^(CL*("`@("LK:CL*("!]"@H@(&EF("AJ*2!["B`@("`@("`@("!H=&UL
M("L]("(\+W1B;V1Y/CPO=&%B;&4^(B`K"@D)("`B/'`^/'-U<#XJ/"]S=7`^
M($QI8V5N<V4@7")H=&UL07)E85PB(&UE86YS('1H870@=&AE('!L=6=I;B!I
M<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!T97)M<R`B("L*"0D@(")A
M<R!(5$U,07)E82!I='-E;&8N("!3=6-H('!L=6=I;G,@87)E(&QI:V5L>2!T
M;R!B92!T:&]S92!I;F-L=61E9"!I;B!T:&4@;V9F:6-I86P@(B`K"@D)("`B
M2%1-3$%R96$@9&ES=')I8G5T:6]N/"]P/B(["@D@('!L=6=I;G,N:6YN97)(
M5$U,(#T@(CQP/E1H92!F;VQL;W=I;F<@<&QU9VEN<R!H879E(&)E96X@;&]A
M9&5D+CPO<#XB("L@:'1M;#L*("!](&5L<V4@>PH)("!P;'5G:6YS+FEN;F5R
M2%1-3"`]("(\<#Y.;R!P;'5G:6YS(&AA=F4@8F5E;B!L;V%D960\+W`^(CL*
M("!]"@H@('!L=6=I;G,N:6YN97)(5$U,("L]("(\<#Y5<V5R(&%G96YT(')E
M<&]R=',Z/&)R+SXB("L@;F%V:6=A=&]R+G5S97)!9V5N="`K("(\+W`^(CL*
M"B`@=F%R(&-O;G1E;G0@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"@B8V]N
M=&5N="(I.PH@(&EF("AW:6YD;W<N:6YN97)(96EG:'0I('L*("`@($-/3E1%
M3E1?2$5)1TA47T1)1D8@/2!W:6YD;W<N:6YN97)(96EG:'0@+2`R-3`["B`@
M("!#3TY414Y47U=)1%1(7T1)1D8@/2!W:6YD;W<N:6YN97)7:61T:"`M(&-O
M;G1E;G0N;V9F<V5T5VED=&@["B`@?2!E;'-E('L*("`@($-/3E1%3E1?2$5)
M1TA47T1)1D8@/2!D;V-U;65N="YB;V1Y+F]F9G-E=$AE:6=H="`M(#(U,#L*
M("`@($-/3E1%3E1?5TE$5$A?1$E&1B`](&1O8W5M96YT+F)O9'DN;V9F<V5T
M5VED=&@@+2`T,#`["B`@?0H@('=I;F1O=RYO;G)E<VEZ92@I.PH@('9A<B!B
M87(@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"@B=&%B8F%R(BD["B`@:B`]
M(#`["B`@9F]R("AV87(@:2`](&)A<BYF:7)S=$-H:6QD.R!I.R!I(#T@:2YN
M97AT4VEB;&EN9RD@>PH@("`@5$%"4RYP=7-H*&DI.PH@("`@:2Y?7VUS:%]T
M86(@/2!J.PH@("`@:2YO;FUO=7-E9&]W;B`](&9U;F-T:6]N*&5V*2![('-E
M;&5C=%1A8BAT:&ES+E]?;7-H7W1A8BD[($A434Q!<F5A+E]S=&]P179E;G0H
M978@?'P@=VEN9&]W+F5V96YT*3L@?3L*("`@('9A<B!A<F5A(#T@9&]C=6UE
M;G0N9V5T16QE;65N=$)Y260H(G1A8BUA<F5A+2(@*R!J*3L*("`@(&EF("@O
M=&%B+6-U<G)E;G0O+G1E<W0H:2YC;&%S<TYA;64I*2!["B`@("`@($-54E)%
M3E1?5$%"(#T@:CL*("`@("`@87)E82YS='EL92YD:7-P;&%Y(#T@(F)L;V-K
M(CL*("`@('T@96QS92!["B`@("`@(&%R96$N<W1Y;&4N9&ES<&QA>2`](")N
M;VYE(CL*("`@('T*("`@("LK:CL*("!]"B`@:68@*&1O8W5M96YT+F-O;VMI
M92YM871C:"@O2%1-3$%214$M04)/550M5$%"/2A;,"TY72LI+RDI"B`@("!S
M96QE8W1486(H4F5G17AP+B0Q*3L*?0IW:6YD;W<N;VYR97-I>F4@/2!F=6YC
M=&EO;B@I('L*("!V87(@8V]N=&5N="`](&1O8W5M96YT+F=E=$5L96UE;G1"
M>4ED*")C;VYT96YT(BD["B`@:68@*'=I;F1O=RYI;FYE<DAE:6=H="D@>PH@
M("`@8V]N=&5N="YS='EL92YH96EG:'0@/2`H=VEN9&]W+FEN;F5R2&5I9VAT
M("T@0T].5$5.5%](14E'2%1?1$E&1BD@*R`B<'@B.PH@("`@8V]N=&5N="YS
M='EL92YW:61T:"`]("AW:6YD;W<N:6YN97)7:61T:"`M($-/3E1%3E1?5TE$
M5$A?1$E&1BD@*R`B<'@B.PH@('T@96QS92!["B`@("!C;VYT96YT+G-T>6QE
M+FAE:6=H="`]("AD;V-U;65N="YB;V1Y+F]F9G-E=$AE:6=H="`M($-/3E1%
M3E1?2$5)1TA47T1)1D8I("L@(G!X(CL*("`@("\O8V]N=&5N="YS='EL92YW
M:61T:"`]("AD;V-U;65N="YB;V1Y+F]F9G-E=%=I9'1H("T@0T].5$5.5%]7
M24142%]$249&*2`K(")P>"(["B`@?0I]"CPO<V-R:7!T/@H\<W1Y;&4^"B`@
M:'1M;"QB;V1Y+'1E>'1A<F5A+'1A8FQE('L@9F]N="UF86UI;'DZ('1A:&]M
M82QV97)D86YA+&%R:6%L.R!F;VYT+7-I>F4Z(#$Q<'@["G!A9&1I;F<Z(#!P
M>#L@;6%R9VEN.B`P<'@[('T*("!T="![(&9O;G0M<VEZ93H@,3(P)3L@?0H@
M(&)O9'D@>R!P861D:6YG.B`P<'@[(&)A8VMG<F]U;F0Z("-C96$[(&-O;&]R
M.B`P,#`[('T*("!A.FQI;FLL(&$Z=FES:71E9"![(&-O;&]R.B`C,#!F.R!]
M"B`@83IH;W9E<B![(&-O;&]R.B`C9C`P.R!]"B`@83IA8W1I=F4@>R!C;VQO
M<CH@(V8X,#L@?0H@(&)U='1O;B![(&9O;G0Z(#$Q<'@@=&%H;VUA+'9E<F1A
M;F$L<V%N<RUS97)I9CL@8F%C:V=R;W5N9"UC;VQO<CH@(V-E83L*("`@("`@
M8F]R9&5R+7=I9'1H.B`Q<'@[('T*"B`@<"![(&UA<F=I;CH@,"XU96T@,'!X
M.R!]"@H@(&@Q('L@9F]N=#H@8F]L9"`Q,S`E(&=E;W)G:6$L(G1I;65S(&YE
M=R!R;VUA;B(L<V5R:68[(&UA<F=I;CH@,'!X.R!B;W)D97(M8F]T=&]M.B`Q
M<'@@<V]L:60@(S9A-CL@?0H@(&@R('L@9F]N=#H@8F]L9"`Q,3`E(&=E;W)G
M:6$L(G1I;65S(&YE=R!R;VUA;B(L<V5R:68[(&UA<F=I;CH@,"XW96T@,'!X
M.R!]"@H@('1H96%D('L*("`@(&9O;G0M=V5I9VAT.B!B;VQD.PH@("`@8F%C
M:V=R;W5N9"UC;VQO<CH@(V1F8CL*("!]"@H@("YL;V=O+"`N;&]G;RUH;W9E
M<B!["B`@("!W:&ET92US<&%C93H@;F]W<F%P.PH@("`@8F%C:V=R;W5N9"UC
M;VQO<CH@(SAF-#L@8V]L;W(Z(",P-#`[('!A9&1I;F<Z(#-P>#L@8F]R9&5R
M+6)O='1O;3H@,7!X('-O;&ED(",U-34["B`@("!H96EG:'0Z(#5E;3L*("!]
M"B`@+FQO9V\@+F)R86YD+"`N;&]G;RUH;W9E<B`N8G)A;F0@>PH@("`@;6%R
M9VEN+6QE9G0Z(#`N-65M.R!M87)G:6XM<FEG:'0Z(#`N-65M.R!P861D:6YG
M+6)O='1O;3H@,"XQ96T["B`@("!F;VYT+69A;6EL>3H@:6UP86-T+"=A<FEA
M;"!B;&%C:R<L87)I86PL<V%N<RUS97)I9CL@9F]N="US:7IE.B`R.'!X.PH@
M("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",U.34[('1E>'0M86QI9VXZ
M(&-E;G1E<CL*("`@(&-U<G-O<CH@<&]I;G1E<CL*("!]"B`@+FQO9V\M:&]V
M97(@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V9F9CL*("!]"B`@+FQO9V\M
M:&]V97(@+F)R86YD('L*("`@(&-O;&]R.B`C.#`P.PH@("`@8F]R9&5R+6-O
M;&]R.B`C,#1F.PH@('T*("`N;&]G;R`N;&5T=&5R+"`N;&]G;RUH;W9E<B`N
M;&5T=&5R('L@<&]S:71I;VXZ(')E;&%T:79E.R!F;VYT+69A;6EL>3H@;6]N
M;W-P86-E.R!]"B`@+FQO9V\@+FQE='1E<C$@>R!T;W`Z(#`N,65M.R!]"B`@
M+FQO9V\@+FQE='1E<C(@>R!T;W`Z(#`N,#5E;3L@?0H@("YL;V=O("YL971T
M97(S('L@=&]P.B`M,"XP-65M.R!]"B`@+FQO9V\@+FQE='1E<C0@>R!T;W`Z
M("TP+C%E;3L@?0H*("`N;&]G;RUH;W9E<B`N;&5T=&5R,2![('1O<#H@+3`N
M,65M.R!]"B`@+FQO9V\M:&]V97(@+FQE='1E<C(@>R!T;W`Z("TP+C`U96T[
M('T*("`N;&]G;RUH;W9E<B`N;&5T=&5R,R![('1O<#H@,"XP-65M.R!]"B`@
M+FQO9V\M:&]V97(@+FQE='1E<C0@>R!T;W`Z(#`N,65M.R!]"B`@+FQO9V\@
M+G9E<G-I;VXL("YL;V=O+6AO=F5R("YV97)S:6]N('L@9F]N="UF86UI;'DZ
M(&=E;W)G:6$L(G1I;65S(&YE=R!R;VUA;B(L<V5R:68[('T*("`N;&]G;R`N
M<F5L96%S92!["B`@("!F;VYT+7-I>F4Z(#DP)3L@;6%R9VEN+6)O='1O;3H@
M,65M.PH@("`@=&5X="UA;&EG;CH@8V5N=&5R.R!C;VQO<CH@(S0X-#L*("!]
M"B`@+FQO9V\@+G9I<VET('L@9&ES<&QA>3H@;F]N93L@?0H@("YL;V=O+6AO
M=F5R("YR96QE87-E('L@9&ES<&QA>3H@;F]N93L@?0H@("YL;V=O+6AO=F5R
M("YV:7-I="!["B`@("!F;VYT+7-I>F4Z(#DP)3L@;6%R9VEN+6)O='1O;3H@
M,65M.PH@("`@=&5X="UA;&EG;CH@8V5N=&5R.R!C;VQO<CH@(S0T.#L*("!]
M"B`@+F)U='1O;G,@>PH@("`@=&5X="UA;&EG;CH@<FEG:'0[('!A9&1I;F<Z
M(#-P>#L@8F%C:V=R;W5N9"UC;VQO<CH@(SAF-#L*("`@(&)O<F1E<BUT;W`Z
M(#%P>"!S;VQI9"`C-34U.PH@('T*("`C=&%B8F%R('L*("`@('!O<VET:6]N
M.B!R96QA=&EV93L*("`@(&QE9G0Z(#$P<'@["B`@?0H@("YT86(@>PH@("`@
M8V]L;W(Z(",T-30["B`@("!C=7)S;W(Z('!O:6YT97(["B`@("!M87)G:6XM
M;&5F=#H@+35P>#L*("`@(&9L;V%T.B!L969T.R!P;W-I=&EO;CH@<F5L871I
M=F4["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C-34U.PH@("`@=&]P.B`M,W!X
M.R!L969T.B`M,G!X.PH@("`@<&%D9&EN9SH@,G!X(#$P<'@@,W!X(#$P<'@[
M"B`@("!B;W)D97(M=&]P.B!N;VYE.R!B86-K9W)O=6YD+6-O;&]R.B`C.6(W
M.PH@("`@+6UO>BUB;W)D97(M<F%D:75S.B`P<'@@,'!X(#1P>"`T<'@["B`@
M("!Z+6EN9&5X.B`P.PH@('T*("`N=&%B+6-U<G)E;G0@>PH@("`@8V]L;W(Z
M(",P,#`["B`@("!T;W`Z("TT<'@["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C
M8V5A.PH@("`@<&%D9&EN9SH@,W!X(#$P<'@@-'!X(#$P<'@["B`@("!Z+6EN
M9&5X.B`Q,#L*("!]"B`@=&%B;&4N<W!O;G-O<G,@>R!B;W)D97(M=&]P.B`Q
M<'@@<V]L:60@(V%C83L@?0H@('1A8FQE+G-P;VYS;W)S('1D('L*("`@(&)O
M<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C86-A.R!V97)T:6-A;"UA;&EG;CH@
M=&]P.PH@('T*("!T86)L92YS<&]N<V]R<R!T<B!T9"![('!A9&1I;F<Z(#)P
M>"`P<'@[('T*("!T86)L92YS<&]N<V]R<R!T<B!T9"YS<&]N<V]R('L@=&5X
M="UA;&EG;CH@<FEG:'0[('!A9&1I;F<M<FEG:'0Z(#`N,V5M.R!W:&ET92US
M<&%C93H@;F]W<F%P.R!]"B`@;&DL(&]L+"!U;"![(&UA<F=I;BUT;W`Z(#!P
M>#L@;6%R9VEN+6)O='1O;3H@,'!X.R!]"CPO<W1Y;&4^/"]H96%D/@H\8F]D
M>2!O;FQO860](E]?9&QG7VEN:70H*3L@:6YI=$1O8W5M96YT*"D[(@H^/'1A
M8FQE(&-E;&QS<&%C:6YG/2(P(B!C96QL<&%D9&EN9STB,"(@<W1Y;&4](F)O
M<F1E<BUC;VQL87!S93H@8V]L;&%P<V4["B`@("`@('=I9'1H.B`Q,#`E.R!H
M96EG:'0Z(#$P,"4[(CX*"CQT<B!S='EL93TB:&5I9VAT.B`Q96TB/CQT9"!I
M9#TB=&1H96%D97(B/@H*/&1I=B!C;&%S<STB;&]G;R(^"CQD:78@8VQA<W,]
M(F)R86YD(@IO;FUO=7-E;W9E<CTB=&AI<RYP87)E;G1.;V1E+F-L87-S3F%M
M93TG;&]G;RUH;W9E<B<[(@IO;FUO=7-E;W5T/2)T:&ES+G!A<F5N=$YO9&4N
M8VQA<W-.86UE/2=L;V=O)SLB"F]N8VQI8VL](G=I;F1O=RYO<&5N*"=H='1P
M.B\O=W=W+FAT;6QA<F5A+F-O;2\G*3LB/@H\<W!A;B!C;&%S<STB;&5T=&5R
M(&QE='1E<C$B/B9L=#M(/"]S<&%N/CQS<&%N"F-L87-S/2)L971T97(@;&5T
M=&5R,B(^5#PO<W!A;CX\<W!A;@IC;&%S<STB;&5T=&5R(&QE='1E<C,B/DT\
M+W-P86X^/'-P86X*8VQA<W,](FQE='1E<B!L971T97(T(CY,/"]S<&%N/D%R
M96$@/'-P86X@8VQA<W,](FQE='1E<B(^+R9G=#L\+W-P86X^"CQS<&%N(&-L
M87-S/2)V97)S:6]N(CXS+C`@/'-P86X@<W1Y;&4](G!O<VET:6]N.B!R96QA
M=&EV93L@=&]P.B`M,"XV96T[(&9O;G0M<VEZ93H@-3`E.R!F;VYT+7=E:6=H
M=#H@;F]R;6%L(CY;(')E=BX@8F5T82L@73PO<W!A;CX\+W-P86X^/"]D:78^
M"CQD:78@8VQA<W,](G)E;&5A<V4B/D-O;7!I;&5D(&]N($UA>2`Q-RP@,C`P
M-2`P,3HP."!'350\+V1I=CX*/&1I=B!C;&%S<STB=FES:70B/D=O('1O(&AT
M='`Z+R]W=W<N:'1M;&%R96$N8V]M+R!;;&%T97-T(&UI;&5S=&]N92!R96QE
M87-E73PO9&EV/@H\+V1I=CX*"CPO=&0^/"]T<CX*/'1R/CQT9"!I9#TB=&1C
M;VYT96YT(B!S='EL93TB<&%D9&EN9SH@,"XU96T[(CX*"CQD:78@<W1Y;&4]
M(F]V97)F;&]W.B!A=71O.R!H96EG:'0Z(#(U,'!X.R(@:60](F-O;G1E;G0B
M/@H\9&EV(&ED/2)T86(M87)E87,B/@H*/&1I=B!I9#TB=&%B+6%R96$M,"(^
M"@H@(#QH,3Y(5$U,07)E83PO:#$^"@H@(#QP/D$@9G)E92!765-)5UE'(&5D
M:71O<B!R97!L86-E;65N="!F;W(@/'1T/B9L=#MT97AT87)E829G=#L\+W1T
M/B!F:65L9',N/&)R("\^"B`@1F]R($UO>FEL;&$@,2XS*R`H86YY('!L871F
M;W)M*2!O<B!);G1E<FYE="!%>'!L;W)E<B`U+C4K("A7:6YD;W=S*2X*("`\
M+W`^"@H@(#QP('-T>6QE/2)T97AT+6%L:6=N.B!C96YT97(B"B`@/L*I(#(P
M,#(M,C`P-"`\82!H<F5F/2)H='1P.B\O:6YT97)A8W1I=F5T;V]L<RYC;VTB
M('1A<F=E=#TB7V)L86YK(CYI;G1E<F%C=&EV971O;VQS+F-O;3PO83XL(&EN
M8RX\8G(@+SX*("#"J2`R,#`S+3(P,#4@/&$@:')E9CTB:'1T<#HO+V1Y;F%R
M8V@N8V]M(B!T87)G970](E]B;&%N:R(^9'EN87)C:"YC;VT\+V$^($Q,0RX\
M8G(@+SX*("!!;&P@4FEG:'1S(%)E<V5R=F5D+CPO<#X*"B`@/&@R/E!R;VIE
M8W0@<F5S;W5R8V5S/"]H,CX*"B`@/'5L/@H@(#QL:3X\82!H<F5F/2)H='1P
M.B\O<V]U<F-E9F]R9V4N;F5T+W!R;VIE8W1S+VET;V]L<RUH=&UL87)E82\B
M('1A<F=E=#TB7V)L86YK(@H@(#Y0<F]J96-T('!A9V4\+V$^("A`('-O=7)C
M969O<F=E+FYE="D\+VQI/@H@(#QL:3X\82!H<F5F/2)H='1P.B\O<V]U<F-E
M9F]R9V4N;F5T+V-V<R\_9W)O=7!?:60]-CDW-3`B('1A<F=E=#TB7V)L86YK
M(@H@(#Y!;F]N>6UO=7,@0U93(&%C8V5S<SPO83X@*$`@<V]U<F-E9F]R9V4N
M;F5T*3PO;&D^"B`@/&QI/CQA(&AR968](FAT='`Z+R]S;W5R8V5F;W)G92YN
M970O=')A8VME<B\_871I9#TU,C4V-38F9W)O=7!?:60]-CDW-3`F9G5N8SUB
M<F]W<V4B('1A<F=E=#TB7V)L86YK(@H@(#Y"=6<@<WES=&5M/"]A/B`H0"!S
M;W5R8V5F;W)G92YN970I/"]L:3X*("`\;&D^/&$@:')E9CTB:'1T<#HO+W=W
M=RYH=&UL87)E82YC;VTO9F]R=6TO(B!T87)G970](E]B;&%N:R(*("`^1F]R
M=6T\+V$^("A`(&EN=&5R86-T:79E=&]O;',N8V]M*3PO;&D^"B`@/&QI/CQA
M(&AR968](FAT='`Z+R]W=W<N:'1M;&%R96$N8V]M+R(@=&%R9V5T/2)?8FQA
M;FLB"B`@/DQA<W0@<'5B;&EC(')E;&5A<V4\+V$^/"]L:3X*("`\+W5L/@H*
M("`\<#X*("!&;W(@9&]W;FQO860@<V5C=&EO;B!P;&5A<V4@<V5E('1H92`\
M82!H<F5F/2)H='1P.B\O<V]U<F-E9F]R9V4N;F5T+W!R;VIE8W1S+VET;V]L
M<RUH=&UL87)E82\B('1A<F=E=#TB7V)L86YK(@H@(#YP<F]J96-T('!A9V4@
M0"!3;W5R8V5&;W)G93PO83XN"B`@/"]P/@H*/"]D:78^"@H\9&EV(&ED/2)T
M86(M87)E82TQ(CX*/&@Q/E1H86YK('EO=3PO:#$^"@H@(#QP/@H@(#QA(&AR
M968](FAT='`Z+R]D>6YA<F-H+F-O;2(@=&%R9V5T/2)?8FQA;FLB/F1Y;F%R
M8V@N8V]M/"]A/B!W;W5L9"!L:6ME('1O('1H86YK('1H92!F;VQL;W=I;F<*
M("!C;VUP86YI97,O<&5R<V]N<R!F;W(@=&AE:7(@/&5M/F1O;F%T:6]N<SPO
M96T^('1O('-U<'!O<G0@9&5V96QO<&UE;G0@;V8@2%1-3$%R96$@*&QI<W1E
M9"!A;'!H86)E=&EC86QL>2DZ"B`@/"]P/@H*("`\=6P^"B`@("`\;&D^/&$@
M:')E9CTB:'1T<#HO+W=W=RYC;VUP=71E<FQO=F4N8V\N=6LB('1A<F=E=#TB
M7V)L86YK(CY#;V1E($-O;7!U=&5R($QO=F4@3'1D+CPO83X@*%5+*3PO;&D^
M"B`@("`\;&D^/&$@:')E9CTB:'1T<#HO+W=W=RYN96]M961I82YR;R(@=&%R
M9V5T/2)?8FQA;FLB/DYE;VUE9&EA/"]A/B`H4F]M86YI82D\+VQI/@H@("`@
M/&QI/CQA(&AR968](FAT='`Z+R]W=W<N;W,S+FET(B!T87)G970](E]B;&%N
M:R(^3U,S/"]A/B`H271A;'DI/"]L:3X*("`@(#QL:3X\82!H<F5F/2)H='1P
M.B\O=W=W+G-O9G1W97)K+FYE="(@=&%R9V5T/2)?8FQA;FLB/E-O9G1797)K
M/"]A/B`H271A;'DI/"]L:3X*("`\+W5L/@H*("`\<#Y!;'-O(&UA;GD@=&AA
M;FMS('1O(&%L;"!P96]P;&4@870@26YT97)A8W1I=F54;V]L<RYC;VT*("`\
M82!H<F5F/2)H='1P.B\O=W=W+FAT;6QA<F5A+F-O;2]F;W)U;2\B/DA434Q!
M<F5A(&9O<G5M<SPO83X@9F]R"B`@8V]N=')I8G5T:6YG('1R86YS;&%T:6]N
M<RP@9F5E9&)A8VLL(&)U9R!R97!O<G1S(&%N9"!F:7AE<RX\+W`^"@H@(#QP
M/@H@($QA<W0@8G5T(&YO="!L96%S="P@=&AI<R!P<F]J96-T('=O=6QD;B=T
M(&AA=F4@97AI<W1E9"!W:71H;W5T"B`@/&$@:')E9CTB:'1T<#HO+VEN=&5R
M86-T:79E=&]O;',N8V]M(B!T87)G970](E]B;&%N:R(^26YT97)A8W1I=F54
M;V]L<RYC;VT\+V$^+@H@(#PO<#X*"CPO9&EV/@H*/&1I=B!I9#TB=&%B+6%R
M96$M,B(^"CQH,3YH=&UL07)E82!,:6-E;G-E("AB87-E9"!O;B!"4T0@;&EC
M96YS92D\+V@Q/@H*/'`@<W1Y;&4](G1E>'0M86QI9VXZ(&-E;G1E<B(^PJD@
M,C`P,BTR,#`T+"!I;G1E<F%C=&EV971O;VQS+F-O;2P@:6YC+CQB<B`O/@H@
M(,*I(#(P,#,M,C`P-"!D>6YA<F-H+F-O;2!,3$,\8G(@+SX*("!!;&P@<FEG
M:'1S(')E<V5R=F5D+CPO<#X*"CQP/@I2961I<W1R:6)U=&EO;B!A;F0@=7-E
M(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70*
M;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE
M(&9O;&QO=VEN9R!C;VYD:71I;VYS(&%R92!M970Z"CPO<#X*"CQO;#X*/&QI
M/@I2961I<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@
M=&AE(&%B;W9E(&-O<'ER:6=H="!N;W1I8V4L"G1H:7,@;&ES="!O9B!C;VYD
M:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N"CPO;&D^"@H\
M;&D^"E)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O
M9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT(&YO=&EC92P*=&AI<R!L:7-T(&]F
M(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T
M:&4@9&]C=6UE;G1A=&EO;@IA;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I
M9&5D('=I=&@@=&AE(&1I<W1R:6)U=&EO;BX*/"]L:3X*"CQL:3X*3F5I=&AE
M<B!T:&4@;F%M92!O9B!I;G1E<F%C=&EV971O;VQS+F-O;2P@:6YC+B!N;W(@
M=&AE(&YA;65S(&]F(&ET<PIC;VYT<FEB=71O<G,@;6%Y(&)E('5S960@=&\@
M96YD;W)S92!O<B!P<F]M;W1E('!R;V1U8W1S(&1E<FEV960@9G)O;2!T:&ES
M"G-O9G1W87)E('=I=&AO=70@<W!E8VEF:6,@<')I;W(@=W)I='1E;B!P97)M
M:7-S:6]N+@H\+VQI/@H\+V]L/@H*/'`^"E1(25,@4T]&5%=!4D4@25,@4%)/
M5DE$140@0ED@5$A%($-/4%E224=(5"!(3TQ$15)3($%.1"!#3TY44DE"551/
M4E,@(D%3($E3(@I!3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!705)204Y4
M2453+"!)3D-,541)3D<L($)55"!.3U0@3$E-251%1"!43RP@5$A%"DE-4$Q)
M140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,@
M1D]2($$@4$%25$E#54Q!4B!055)03U-%"D%212!$25-#3$%)345$+B!)3B!.
M3R!%5D5.5"!32$%,3"!42$4@0T]065))1TA4($]73D52($]2($-/3E1224)5
M5$]24R!"10I,24%"3$4@1D]2($%.62!$25)%0U0L($E.1$E214-4+"!)3D-)
M1$5.5$%,+"!34$5#24%,+"!%6$5-4$Q!4EDL($]2"D-/3E-%455%3E1)04P@
M1$%-04=%4R`H24Y#3%5$24Y'+"!"550@3D]4($Q)34E4140@5$\L(%!23T-5
M4D5-14Y4($]&"E-50E-425155$4@1T]/1%,@3U(@4T525DE#15,[($Q/4U,@
M3T8@55-%+"!$051!+"!/4B!04D]&2513.R!/4B!"55-)3D534PI)3E1%4E)5
M4%1)3TXI($A/5T5615(@0T%54T5$($%.1"!/3B!!3ED@5$A%3U)9($]&($Q)
M04))3$E462P@5TA%5$A%4B!)3@I#3TY44D%#5"P@4U1224-4($Q)04))3$E4
M62P@3U(@5$]25"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%
M*0I!4DE324Y'($E.($%.62!705D@3U54($]&(%1(12!54T4@3T8@5$A)4R!3
M3T945T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(10I03U-324))3$E462!/
M1B!354-(($1!34%'12X*/"]P/@H*/"]D:78^"@H\9&EV(&ED/2)T86(M87)E
M82TS(CX*/&@Q/E!L=6=I;G,\+V@Q/@H\9&EV(&ED/2)P;'5G:6YS(CX*/"]D
M:78^"CPO9&EV/@H*/"]D:78^/"]D:78^"@H*/"]T<CX\+W1D/@H\='(@<W1Y
M;&4](FAE:6=H=#H@,65M(CX\=&0@:60](G1D9F]O=&5R(CX*"@H\9&EV(&-L
M87-S/2)B=71T;VYS(CX*/&1I=B!I9#TB=&%B8F%R(@H^/&1I=B!C;&%S<STB
M=&%B('1A8BUC=7)R96YT(@H^06)O=70\+V1I=CX\9&EV(&-L87-S/2)T86(B
M"CY4:&%N:W,\+V1I=CX\9&EV(&-L87-S/2)T86(B"CY,:6-E;G-E/"]D:78^
M/&1I=B!C;&%S<STB=&%B(@H^4&QU9VEN<SPO9&EV/CPO9&EV/@H\8G5T=&]N
M('1Y<&4](F)U='1O;B(@;VYC;&EC:STB7U]D;&=?8VQO<V4H;G5L;"D[(CY)
M(&%G<F5E(&ET)W,@8V]O;#PO8G5T=&]N/@H\+V1I=CX*"CPO=&0^/"]T<CX\
M+W1A8FQE/@H*/"]B;V1Y/CPO:'1M;#X*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V
M:6-E<R]E9&ET;W(O:'1M;&%R96$O<&]P=7!S+W-E;&5C=%]C;VQO<BYH=&UL
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P-S`Q-#(@,3`U,34T,S,W-#0@,#(W,S0T`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#PA+2T@;F]T93H@
M=&AI<R!V97)S:6]N(&]F('1H92!C;VQO<B!P:6-K97(@:7,@;W!T:6UI>F5D
M(&9O<B!)12`U+C4K(&]N;'D@+2T^#0H-"CQH=&UL/CQH96%D/CQT:71L93Y3
M96QE8W0@0V]L;W(\+W1I=&QE/@T*#0H\<V-R:7!T('1Y<&4](G1E>'0O:F%V
M87-C<FEP="(@<W)C/2)P;W!U<"YJ<R(^/"]S8W)I<'0^#0H-"CQS8W)I<'0@
M='EP93TB=&5X="]J879A<V-R:7!T(CX-"@T*=VEN9&]W+G)E<VEZ951O*#(T
M,"P@,3@R*3L-"F9U;F-T:6]N(%]#;&]S94]N17-C*"D@>PT*("!I9B`H979E
M;G0N:V5Y0V]D92`]/2`R-RD@>R!W:6YD;W<N8VQO<V4H*3L@<F5T=7)N.R!]
M#0I]#0H-"F9U;F-T:6]N($EN:70H*2![("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(')U;B!O;B!P
M86=E(&QO860-"B`@7U]D;&=?:6YI="@I.R`@("`O+R`\(2TM('1H:7,@8V%N
M(&)E(&9O=6YD(&EN('!O<'5P+FIS("TM/@T*("!D;V-U;65N="YB;V1Y+F]N
M:V5Y<')E<W,@/2!?0VQO<V5/;D5S8SL-"@T*("!V87(@8V]L;W(@/2!W:6YD
M;W<N9&EA;&]G07)G=6UE;G1S.PT*("!C;VQO<B`](%9A;&ED871E0V]L;W(H
M8V]L;W(I('Q\("<P,#`P,#`G.PT*("!6:65W*&-O;&]R*3L@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+R\@<V5T(&1E9F%U;'0@8V]L;W(-"GT-"@T*9G5N8W1I;VX@5FEE=RAC
M;VQO<BD@>R`@("`@("`@("`@("`@("`@("\O('!R979I97<@8V]L;W(-"B`@
M9&]C=6UE;G0N9V5T16QE;65N=$)Y260H(D-O;&]R4')E=FEE=R(I+G-T>6QE
M+F)A8VMG<F]U;F1#;VQO<B`]("<C)R`K(&-O;&]R.PT*("!D;V-U;65N="YG
M971%;&5M96YT0GE)9"@B0V]L;W)(97@B*2YV86QU92`]("<C)R`K(&-O;&]R
M.PT*?0T*#0IF=6YC=&EO;B!3970H<W1R:6YG*2![("`@("`@("`@("`@("`@
M("`@("\O('-E;&5C="!C;VQO<@T*("!V87(@8V]L;W(@/2!686QI9&%T94-O
M;&]R*'-T<FEN9RD[#0H@(&EF("AC;VQO<B`]/2!N=6QL*2![(&%L97)T*"))
M;G9A;&ED(&-O;&]R(&-O9&4Z("(@*R!S=')I;F<I.R!]("`@("`@("`O+R!I
M;G9A;&ED(&-O;&]R#0H@(&5L<V4@>R`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!V
M86QI9"!C;VQO<@T*("`@(%9I97<H8V]L;W(I.R`@("`@("`@("`@("`@("`@
M("`@("`@("`@+R\@<VAO=R!S96QE8W1E9"!C;VQO<@T*("`@(%]?9&QG7V-L
M;W-E*&-O;&]R*3L-"B`@?0T*?0T*#0IF=6YC=&EO;B!686QI9&%T94-O;&]R
M*'-T<FEN9RD@>R`@("`@("`@("`@("`@("`O+R!R971U<FX@=F%L:60@8V]L
M;W(@8V]D90T*("!S=')I;F<@/2!S=')I;F<@?'P@)R<[#0H@('-T<FEN9R`]
M('-T<FEN9R`K("(B.PT*("!S=')I;F<@/2!S=')I;F<N=&]5<'!E<D-A<V4H
M*3L-"B`@=F%R(&-H87)S(#T@)S`Q,C,T-38W.#E!0D-$148G.PT*("!V87(@
M;W5T("`@/2`G)SL-"@T*("!F;W(@*'9A<B!I/3`[(&D\<W1R:6YG+FQE;F=T
M:#L@:2LK*2![("`@("`@("`@("`@("\O(')E;6]V92!I;G9A;&ED(&-O;&]R
M(&-H87)S#0H@("`@=F%R('-C:&%R(#T@<W1R:6YG+F-H87)!="AI*3L-"B`@
M("!I9B`H8VAA<G,N:6YD97A/9BAS8VAA<BD@(3T@+3$I('L@;W5T("L]('-C
M:&%R.R!]#0H@('T-"@T*("!I9B`H;W5T+FQE;F=T:"`A/2`V*2![(')E='5R
M;B!N=6QL.R!]("`@("`@("`@("`@+R\@8VAE8VL@;&5N9W1H#0H@(')E='5R
M;B!O=70[#0I]#0H-"CPO<V-R:7!T/@T*/"]H96%D/@T*/&)O9'D@<W1Y;&4]
M(F)A8VMG<F]U;F0Z0G5T=&]N1F%C93L@;6%R9VEN.C!P>#L@<&%D9&EN9SHP
M<'@B(&]N;&]A9#TB26YI="@I(CX-"@T*/&9O<FT@;65T:&]D/2)G970B('-T
M>6QE/2)M87)G:6XZ,'!X.R!P861D:6YG.C!P>"(@;VY3=6)M:70](E-E="AD
M;V-U;65N="YG971%;&5M96YT0GE)9"@G0V]L;W)(97@G*2YV86QU92D[(')E
M='5R;B!F86QS93LB/@T*/'1A8FQE(&)O<F1E<CTB,'!X(B!C96QL<W!A8VEN
M9STB,'!X(B!C96QL<&%D9&EN9STB-"(@=VED=&@](C$P,"4B/@T*(#QT<CX-
M"B`@/'1D('-T>6QE/2)B86-K9W)O=6YD.F)U='1O;F9A8V4B('9A;&EG;CUC
M96YT97(^/&1I=B!S='EL93TB8F%C:V=R;W5N9"UC;VQO<CH@(S`P,#`P,#L@
M<&%D9&EN9SH@,3L@:&5I9VAT.B`R,7!X.R!W:61T:#H@-3!P>"(^/&1I=B!I
M9#TB0V]L;W)0<F5V:65W(B!S='EL93TB:&5I9VAT.B`Q,#`E.R!W:61T:#H@
M,3`P)2(^/"]D:78^/"]D:78^/"]T9#X-"B`@/'1D('-T>6QE/2)B86-K9W)O
M=6YD.F)U='1O;F9A8V4B('9A;&EG;CUC96YT97(^/&EN<'5T('1Y<&4](G1E
M>'0B(&YA;64](D-O;&]R2&5X(@T*("`@(&ED/2)#;VQO<DAE>"(@=F%L=64]
M(B(@<VEZ93TQ-2!S='EL93TB9F]N="US:7IE.B`Q,G!X(CX\+W1D/@T*("`\
M=&0@<W1Y;&4](F)A8VMG<F]U;F0Z8G5T=&]N9F%C92(@=VED=&@],3`P)3X\
M+W1D/@T*(#PO='(^#0H\+W1A8FQE/@T*/"]F;W)M/@T*#0H\=&%B;&4@8F]R
M9&5R/2(P(B!C96QL<W!A8VEN9STB,7!X(B!C96QL<&%D9&EN9STB,'!X(B!W
M:61T:#TB,3`P)2(@8F=C;VQO<CTB(S`P,#`P,"(@<W1Y;&4](F-U<G-O<CH@
M:&%N9#LB/@T*/'1R/@T*/'1D(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E
M<CU6:65W*"<P,#`P,#`G*2!O;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT
M/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#`P
M,#`@;VY-;W5S94]V97(]5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P
M,#`P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@
M8F=C;VQO<CTC,#`P,#`P(&]N36]U<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N
M0VQI8VL]4V5T*"<P,#`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X
M(CX\+W1D/@T*/'1D(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W
M*"<P,#`P,#`G*2!O;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X
M(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#,S,#`@;VY-
M;W5S94]V97(]5FEE=R@G,#`S,S`P)RD@;VY#;&EC:SU3970H)S`P,S,P,"<I
M(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO
M<CTC,#`V-C`P(&]N36]U<V5/=F5R/59I97<H)S`P-C8P,"<I(&]N0VQI8VL]
M4V5T*"<P,#8V,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D
M/@T*/'1D(&)G8V]L;W(](S`P.3DP,"!O;DUO=7-E3W9E<CU6:65W*"<P,#DY
M,#`G*2!O;D-L:6-K/5-E="@G,#`Y.3`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T
M:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,$-#,#`@;VY-;W5S94]V
M97(]5FEE=R@G,#!#0S`P)RD@;VY#;&EC:SU3970H)S`P0T,P,"<I(&AE:6=H
M=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#!&
M1C`P(&]N36]U<V5/=F5R/59I97<H)S`P1D8P,"<I(&]N0VQI8VL]4V5T*"<P
M,$9&,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D
M(&)G8V]L;W(](S,S,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<S,S`P,#`G*2!O
M;D-L:6-K/5-E="@G,S,P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P
M>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,S,S,S,#`@;VY-;W5S94]V97(]5FEE
M=R@G,S,S,S`P)RD@;VY#;&EC:SU3970H)S,S,S,P,"<I(&AE:6=H=#TB,3!P
M>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S,V-C`P(&]N
M36]U<V5/=F5R/59I97<H)S,S-C8P,"<I(&]N0VQI8VL]4V5T*"<S,S8V,#`G
M*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L
M;W(](S,S.3DP,"!O;DUO=7-E3W9E<CU6:65W*"<S,SDY,#`G*2!O;D-L:6-K
M/5-E="@G,S,Y.3`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T
M9#X-"CQT9"!B9V-O;&]R/2,S,T-#,#`@;VY-;W5S94]V97(]5FEE=R@G,S-#
M0S`P)RD@;VY#;&EC:SU3970H)S,S0T,P,"<I(&AE:6=H=#TB,3!P>"(@=VED
M=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S-&1C`P(&]N36]U<V5/
M=F5R/59I97<H)S,S1D8P,"<I(&]N0VQI8VL]4V5T*"<S,T9&,#`G*2!H96EG
M:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V
M,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<V-C`P,#`G*2!O;D-L:6-K/5-E="@G
M-C8P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT
M9"!B9V-O;&]R/2,V-C,S,#`@;VY-;W5S94]V97(]5FEE=R@G-C8S,S`P)RD@
M;VY#;&EC:SU3970H)S8V,S,P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P
M<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC-C8V-C`P(&]N36]U<V5/=F5R/59I
M97<H)S8V-C8P,"<I(&]N0VQI8VL]4V5T*"<V-C8V,#`G*2!H96EG:'0](C$P
M<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V.3DP,"!O
M;DUO=7-E3W9E<CU6:65W*"<V-CDY,#`G*2!O;D-L:6-K/5-E="@G-C8Y.3`P
M)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O
M;&]R/2,V-D-#,#`@;VY-;W5S94]V97(]5FEE=R@G-C9#0S`P)RD@;VY#;&EC
M:SU3970H)S8V0T,P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO
M=&0^#0H\=&0@8F=C;VQO<CTC-C9&1C`P(&]N36]U<V5/=F5R/59I97<H)S8V
M1D8P,"<I(&]N0VQI8VL]4V5T*"<V-D9&,#`G*2!H96EG:'0](C$P<'@B('=I
M9'1H/2(Q,'!X(CX\+W1D/@T*/"]T<CX-"CQT<CX-"CQT9"!B9V-O;&]R/2,P
M,#`P,#`@;VY-;W5S94]V97(]5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H
M)S`P,#`P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\
M=&0@8F=C;VQO<CTC,S,S,S,S(&]N36]U<V5/=F5R/59I97<H)S,S,S,S,R<I
M(&]N0VQI8VL]4V5T*"<S,S,S,S,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q
M,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6
M:65W*"<P,#`P,#`G*2!O;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q
M,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#`P,S,@
M;VY-;W5S94]V97(]5FEE=R@G,#`P,#,S)RD@;VY#;&EC:SU3970H)S`P,#`S
M,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C
M;VQO<CTC,#`S,S,S(&]N36]U<V5/=F5R/59I97<H)S`P,S,S,R<I(&]N0VQI
M8VL]4V5T*"<P,#,S,S,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\
M+W1D/@T*/'1D(&)G8V]L;W(](S`P-C8S,R!O;DUO=7-E3W9E<CU6:65W*"<P
M,#8V,S,G*2!O;D-L:6-K/5-E="@G,#`V-C,S)RD@:&5I9VAT/2(Q,'!X(B!W
M:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#DY,S,@;VY-;W5S
M94]V97(]5FEE=R@G,#`Y.3,S)RD@;VY#;&EC:SU3970H)S`P.3DS,R<I(&AE
M:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC
M,#!#0S,S(&]N36]U<V5/=F5R/59I97<H)S`P0T,S,R<I(&]N0VQI8VL]4V5T
M*"<P,$-#,S,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*
M/'1D(&)G8V]L;W(](S`P1D8S,R!O;DUO=7-E3W9E<CU6:65W*"<P,$9&,S,G
M*2!O;D-L:6-K/5-E="@G,#!&1C,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB
M,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,S,S`P,S,@;VY-;W5S94]V97(]
M5FEE=R@G,S,P,#,S)RD@;VY#;&EC:SU3970H)S,S,#`S,R<I(&AE:6=H=#TB
M,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S,S,S,S
M(&]N36]U<V5/=F5R/59I97<H)S,S,S,S,R<I(&]N0VQI8VL]4V5T*"<S,S,S
M,S,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G
M8V]L;W(](S,S-C8S,R!O;DUO=7-E3W9E<CU6:65W*"<S,S8V,S,G*2!O;D-L
M:6-K/5-E="@G,S,V-C,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^
M/"]T9#X-"CQT9"!B9V-O;&]R/2,S,SDY,S,@;VY-;W5S94]V97(]5FEE=R@G
M,S,Y.3,S)RD@;VY#;&EC:SU3970H)S,S.3DS,R<I(&AE:6=H=#TB,3!P>"(@
M=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S-#0S,S(&]N36]U
M<V5/=F5R/59I97<H)S,S0T,S,R<I(&]N0VQI8VL]4V5T*"<S,T-#,S,G*2!H
M96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(]
M(S,S1D8S,R!O;DUO=7-E3W9E<CU6:65W*"<S,T9&,S,G*2!O;D-L:6-K/5-E
M="@G,S-&1C,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-
M"CQT9"!B9V-O;&]R/2,V-C`P,S,@;VY-;W5S94]V97(]5FEE=R@G-C8P,#,S
M)RD@;VY#;&EC:SU3970H)S8V,#`S,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@]
M(C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC-C8S,S,S(&]N36]U<V5/=F5R
M/59I97<H)S8V,S,S,R<I(&]N0VQI8VL]4V5T*"<V-C,S,S,G*2!H96EG:'0]
M(C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V-C8S
M,R!O;DUO=7-E3W9E<CU6:65W*"<V-C8V,S,G*2!O;D-L:6-K/5-E="@G-C8V
M-C,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B
M9V-O;&]R/2,V-CDY,S,@;VY-;W5S94]V97(]5FEE=R@G-C8Y.3,S)RD@;VY#
M;&EC:SU3970H)S8V.3DS,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B
M/CPO=&0^#0H\=&0@8F=C;VQO<CTC-C9#0S,S(&]N36]U<V5/=F5R/59I97<H
M)S8V0T,S,R<I(&]N0VQI8VL]4V5T*"<V-D-#,S,G*2!H96EG:'0](C$P<'@B
M('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V1D8S,R!O;DUO
M=7-E3W9E<CU6:65W*"<V-D9&,S,G*2!O;D-L:6-K/5-E="@G-C9&1C,S)RD@
M:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CPO='(^#0H\='(^
M#0H\=&0@8F=C;VQO<CTC,#`P,#`P(&]N36]U<V5/=F5R/59I97<H)S`P,#`P
M,"<I(&]N0VQI8VL]4V5T*"<P,#`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H
M/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V-C8V-B!O;DUO=7-E3W9E
M<CU6:65W*"<V-C8V-C8G*2!O;D-L:6-K/5-E="@G-C8V-C8V)RD@:&5I9VAT
M/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#`P
M,#`@;VY-;W5S94]V97(]5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P
M,#`P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@
M8F=C;VQO<CTC,#`P,#8V(&]N36]U<V5/=F5R/59I97<H)S`P,#`V-B<I(&]N
M0VQI8VL]4V5T*"<P,#`P-C8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X
M(CX\+W1D/@T*/'1D(&)G8V]L;W(](S`P,S,V-B!O;DUO=7-E3W9E<CU6:65W
M*"<P,#,S-C8G*2!O;D-L:6-K/5-E="@G,#`S,S8V)RD@:&5I9VAT/2(Q,'!X
M(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#8V-C8@;VY-
M;W5S94]V97(]5FEE=R@G,#`V-C8V)RD@;VY#;&EC:SU3970H)S`P-C8V-B<I
M(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO
M<CTC,#`Y.38V(&]N36]U<V5/=F5R/59I97<H)S`P.3DV-B<I(&]N0VQI8VL]
M4V5T*"<P,#DY-C8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D
M/@T*/'1D(&)G8V]L;W(](S`P0T,V-B!O;DUO=7-E3W9E<CU6:65W*"<P,$-#
M-C8G*2!O;D-L:6-K/5-E="@G,#!#0S8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T
M:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,$9&-C8@;VY-;W5S94]V
M97(]5FEE=R@G,#!&1C8V)RD@;VY#;&EC:SU3970H)S`P1D8V-B<I(&AE:6=H
M=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S,P
M,#8V(&]N36]U<V5/=F5R/59I97<H)S,S,#`V-B<I(&]N0VQI8VL]4V5T*"<S
M,S`P-C8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D
M(&)G8V]L;W(](S,S,S,V-B!O;DUO=7-E3W9E<CU6:65W*"<S,S,S-C8G*2!O
M;D-L:6-K/5-E="@G,S,S,S8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P
M>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,S,S8V-C8@;VY-;W5S94]V97(]5FEE
M=R@G,S,V-C8V)RD@;VY#;&EC:SU3970H)S,S-C8V-B<I(&AE:6=H=#TB,3!P
M>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S,Y.38V(&]N
M36]U<V5/=F5R/59I97<H)S,S.3DV-B<I(&]N0VQI8VL]4V5T*"<S,SDY-C8G
M*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L
M;W(](S,S0T,V-B!O;DUO=7-E3W9E<CU6:65W*"<S,T-#-C8G*2!O;D-L:6-K
M/5-E="@G,S-#0S8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T
M9#X-"CQT9"!B9V-O;&]R/2,S,T9&-C8@;VY-;W5S94]V97(]5FEE=R@G,S-&
M1C8V)RD@;VY#;&EC:SU3970H)S,S1D8V-B<I(&AE:6=H=#TB,3!P>"(@=VED
M=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC-C8P,#8V(&]N36]U<V5/
M=F5R/59I97<H)S8V,#`V-B<I(&]N0VQI8VL]4V5T*"<V-C`P-C8G*2!H96EG
M:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V
M,S,V-B!O;DUO=7-E3W9E<CU6:65W*"<V-C,S-C8G*2!O;D-L:6-K/5-E="@G
M-C8S,S8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT
M9"!B9V-O;&]R/2,V-C8V-C8@;VY-;W5S94]V97(]5FEE=R@G-C8V-C8V)RD@
M;VY#;&EC:SU3970H)S8V-C8V-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P
M<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC-C8Y.38V(&]N36]U<V5/=F5R/59I
M97<H)S8V.3DV-B<I(&]N0VQI8VL]4V5T*"<V-CDY-C8G*2!H96EG:'0](C$P
M<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V0T,V-B!O
M;DUO=7-E3W9E<CU6:65W*"<V-D-#-C8G*2!O;D-L:6-K/5-E="@G-C9#0S8V
M)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O
M;&]R/2,V-D9&-C8@;VY-;W5S94]V97(]5FEE=R@G-C9&1C8V)RD@;VY#;&EC
M:SU3970H)S8V1D8V-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO
M=&0^#0H\+W1R/@T*/'1R/@T*/'1D(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E
M3W9E<CU6:65W*"<P,#`P,#`G*2!O;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I
M9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y
M.3DY.3D@;VY-;W5S94]V97(]5FEE=R@G.3DY.3DY)RD@;VY#;&EC:SU3970H
M)SDY.3DY.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\
M=&0@8F=C;VQO<CTC,#`P,#`P(&]N36]U<V5/=F5R/59I97<H)S`P,#`P,"<I
M(&]N0VQI8VL]4V5T*"<P,#`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q
M,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S`P,#`Y.2!O;DUO=7-E3W9E<CU6
M:65W*"<P,#`P.3DG*2!O;D-L:6-K/5-E="@G,#`P,#DY)RD@:&5I9VAT/2(Q
M,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#,S.3D@
M;VY-;W5S94]V97(]5FEE=R@G,#`S,SDY)RD@;VY#;&EC:SU3970H)S`P,S,Y
M.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C
M;VQO<CTC,#`V-CDY(&]N36]U<V5/=F5R/59I97<H)S`P-C8Y.2<I(&]N0VQI
M8VL]4V5T*"<P,#8V.3DG*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\
M+W1D/@T*/'1D(&)G8V]L;W(](S`P.3DY.2!O;DUO=7-E3W9E<CU6:65W*"<P
M,#DY.3DG*2!O;D-L:6-K/5-E="@G,#`Y.3DY)RD@:&5I9VAT/2(Q,'!X(B!W
M:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,$-#.3D@;VY-;W5S
M94]V97(]5FEE=R@G,#!#0SDY)RD@;VY#;&EC:SU3970H)S`P0T,Y.2<I(&AE
M:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC
M,#!&1CDY(&]N36]U<V5/=F5R/59I97<H)S`P1D8Y.2<I(&]N0VQI8VL]4V5T
M*"<P,$9&.3DG*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*
M/'1D(&)G8V]L;W(](S,S,#`Y.2!O;DUO=7-E3W9E<CU6:65W*"<S,S`P.3DG
M*2!O;D-L:6-K/5-E="@G,S,P,#DY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB
M,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,S,S,S.3D@;VY-;W5S94]V97(]
M5FEE=R@G,S,S,SDY)RD@;VY#;&EC:SU3970H)S,S,S,Y.2<I(&AE:6=H=#TB
M,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S,V-CDY
M(&]N36]U<V5/=F5R/59I97<H)S,S-C8Y.2<I(&]N0VQI8VL]4V5T*"<S,S8V
M.3DG*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G
M8V]L;W(](S,S.3DY.2!O;DUO=7-E3W9E<CU6:65W*"<S,SDY.3DG*2!O;D-L
M:6-K/5-E="@G,S,Y.3DY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^
M/"]T9#X-"CQT9"!B9V-O;&]R/2,S,T-#.3D@;VY-;W5S94]V97(]5FEE=R@G
M,S-#0SDY)RD@;VY#;&EC:SU3970H)S,S0T,Y.2<I(&AE:6=H=#TB,3!P>"(@
M=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S-&1CDY(&]N36]U
M<V5/=F5R/59I97<H)S,S1D8Y.2<I(&]N0VQI8VL]4V5T*"<S,T9&.3DG*2!H
M96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(]
M(S8V,#`Y.2!O;DUO=7-E3W9E<CU6:65W*"<V-C`P.3DG*2!O;D-L:6-K/5-E
M="@G-C8P,#DY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-
M"CQT9"!B9V-O;&]R/2,V-C,S.3D@;VY-;W5S94]V97(]5FEE=R@G-C8S,SDY
M)RD@;VY#;&EC:SU3970H)S8V,S,Y.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@]
M(C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC-C8V-CDY(&]N36]U<V5/=F5R
M/59I97<H)S8V-C8Y.2<I(&]N0VQI8VL]4V5T*"<V-C8V.3DG*2!H96EG:'0]
M(C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V.3DY
M.2!O;DUO=7-E3W9E<CU6:65W*"<V-CDY.3DG*2!O;D-L:6-K/5-E="@G-C8Y
M.3DY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B
M9V-O;&]R/2,V-D-#.3D@;VY-;W5S94]V97(]5FEE=R@G-C9#0SDY)RD@;VY#
M;&EC:SU3970H)S8V0T,Y.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B
M/CPO=&0^#0H\=&0@8F=C;VQO<CTC-C9&1CDY(&]N36]U<V5/=F5R/59I97<H
M)S8V1D8Y.2<I(&]N0VQI8VL]4V5T*"<V-D9&.3DG*2!H96EG:'0](C$P<'@B
M('=I9'1H/2(Q,'!X(CX\+W1D/@T*/"]T<CX-"CQT<CX-"CQT9"!B9V-O;&]R
M/2,P,#`P,#`@;VY-;W5S94]V97(]5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3
M970H)S`P,#`P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^
M#0H\=&0@8F=C;VQO<CTC0T-#0T-#(&]N36]U<V5/=F5R/59I97<H)T-#0T-#
M0R<I(&]N0VQI8VL]4V5T*"=#0T-#0T,G*2!H96EG:'0](C$P<'@B('=I9'1H
M/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E
M<CU6:65W*"<P,#`P,#`G*2!O;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT
M/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#`P
M0T,@;VY-;W5S94]V97(]5FEE=R@G,#`P,$-#)RD@;VY#;&EC:SU3970H)S`P
M,#!#0R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@
M8F=C;VQO<CTC,#`S,T-#(&]N36]U<V5/=F5R/59I97<H)S`P,S-#0R<I(&]N
M0VQI8VL]4V5T*"<P,#,S0T,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X
M(CX\+W1D/@T*/'1D(&)G8V]L;W(](S`P-C9#0R!O;DUO=7-E3W9E<CU6:65W
M*"<P,#8V0T,G*2!O;D-L:6-K/5-E="@G,#`V-D-#)RD@:&5I9VAT/2(Q,'!X
M(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#DY0T,@;VY-
M;W5S94]V97(]5FEE=R@G,#`Y.4-#)RD@;VY#;&EC:SU3970H)S`P.3E#0R<I
M(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO
M<CTC,#!#0T-#(&]N36]U<V5/=F5R/59I97<H)S`P0T-#0R<I(&]N0VQI8VL]
M4V5T*"<P,$-#0T,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D
M/@T*/'1D(&)G8V]L;W(](S`P1D9#0R!O;DUO=7-E3W9E<CU6:65W*"<P,$9&
M0T,G*2!O;D-L:6-K/5-E="@G,#!&1D-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T
M:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,S,S`P0T,@;VY-;W5S94]V
M97(]5FEE=R@G,S,P,$-#)RD@;VY#;&EC:SU3970H)S,S,#!#0R<I(&AE:6=H
M=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S,S
M,T-#(&]N36]U<V5/=F5R/59I97<H)S,S,S-#0R<I(&]N0VQI8VL]4V5T*"<S
M,S,S0T,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D
M(&)G8V]L;W(](S,S-C9#0R!O;DUO=7-E3W9E<CU6:65W*"<S,S8V0T,G*2!O
M;D-L:6-K/5-E="@G,S,V-D-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P
M>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,S,SDY0T,@;VY-;W5S94]V97(]5FEE
M=R@G,S,Y.4-#)RD@;VY#;&EC:SU3970H)S,S.3E#0R<I(&AE:6=H=#TB,3!P
M>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S-#0T-#(&]N
M36]U<V5/=F5R/59I97<H)S,S0T-#0R<I(&]N0VQI8VL]4V5T*"<S,T-#0T,G
M*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L
M;W(](S,S1D9#0R!O;DUO=7-E3W9E<CU6:65W*"<S,T9&0T,G*2!O;D-L:6-K
M/5-E="@G,S-&1D-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T
M9#X-"CQT9"!B9V-O;&]R/2,V-C`P0T,@;VY-;W5S94]V97(]5FEE=R@G-C8P
M,$-#)RD@;VY#;&EC:SU3970H)S8V,#!#0R<I(&AE:6=H=#TB,3!P>"(@=VED
M=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC-C8S,T-#(&]N36]U<V5/
M=F5R/59I97<H)S8V,S-#0R<I(&]N0VQI8VL]4V5T*"<V-C,S0T,G*2!H96EG
M:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V
M-C9#0R!O;DUO=7-E3W9E<CU6:65W*"<V-C8V0T,G*2!O;D-L:6-K/5-E="@G
M-C8V-D-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT
M9"!B9V-O;&]R/2,V-CDY0T,@;VY-;W5S94]V97(]5FEE=R@G-C8Y.4-#)RD@
M;VY#;&EC:SU3970H)S8V.3E#0R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P
M<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC-C9#0T-#(&]N36]U<V5/=F5R/59I
M97<H)S8V0T-#0R<I(&]N0VQI8VL]4V5T*"<V-D-#0T,G*2!H96EG:'0](C$P
M<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V1D9#0R!O
M;DUO=7-E3W9E<CU6:65W*"<V-D9&0T,G*2!O;D-L:6-K/5-E="@G-C9&1D-#
M)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CPO='(^#0H\
M='(^#0H\=&0@8F=C;VQO<CTC,#`P,#`P(&]N36]U<V5/=F5R/59I97<H)S`P
M,#`P,"<I(&]N0VQI8VL]4V5T*"<P,#`P,#`G*2!H96EG:'0](C$P<'@B('=I
M9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&1D9&1B!O;DUO=7-E
M3W9E<CU6:65W*"=&1D9&1D8G*2!O;D-L:6-K/5-E="@G1D9&1D9&)RD@:&5I
M9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P
M,#`P,#`@;VY-;W5S94]V97(]5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H
M)S`P,#`P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\
M=&0@8F=C;VQO<CTC,#`P,$9&(&]N36]U<V5/=F5R/59I97<H)S`P,#!&1B<I
M(&]N0VQI8VL]4V5T*"<P,#`P1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q
M,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S`P,S-&1B!O;DUO=7-E3W9E<CU6
M:65W*"<P,#,S1D8G*2!O;D-L:6-K/5-E="@G,#`S,T9&)RD@:&5I9VAT/2(Q
M,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#8V1D8@
M;VY-;W5S94]V97(]5FEE=R@G,#`V-D9&)RD@;VY#;&EC:SU3970H)S`P-C9&
M1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C
M;VQO<CTC,#`Y.49&(&]N36]U<V5/=F5R/59I97<H)S`P.3E&1B<I(&]N0VQI
M8VL]4V5T*"<P,#DY1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\
M+W1D/@T*/'1D(&)G8V]L;W(](S`P0T-&1B!O;DUO=7-E3W9E<CU6:65W*"<P
M,$-#1D8G*2!O;D-L:6-K/5-E="@G,#!#0T9&)RD@:&5I9VAT/2(Q,'!X(B!W
M:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,$9&1D8@;VY-;W5S
M94]V97(]5FEE=R@G,#!&1D9&)RD@;VY#;&EC:SU3970H)S`P1D9&1B<I(&AE
M:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC
M,S,P,$9&(&]N36]U<V5/=F5R/59I97<H)S,S,#!&1B<I(&]N0VQI8VL]4V5T
M*"<S,S`P1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*
M/'1D(&)G8V]L;W(](S,S,S-&1B!O;DUO=7-E3W9E<CU6:65W*"<S,S,S1D8G
M*2!O;D-L:6-K/5-E="@G,S,S,T9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB
M,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,S,S8V1D8@;VY-;W5S94]V97(]
M5FEE=R@G,S,V-D9&)RD@;VY#;&EC:SU3970H)S,S-C9&1B<I(&AE:6=H=#TB
M,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S,Y.49&
M(&]N36]U<V5/=F5R/59I97<H)S,S.3E&1B<I(&]N0VQI8VL]4V5T*"<S,SDY
M1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G
M8V]L;W(](S,S0T-&1B!O;DUO=7-E3W9E<CU6:65W*"<S,T-#1D8G*2!O;D-L
M:6-K/5-E="@G,S-#0T9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^
M/"]T9#X-"CQT9"!B9V-O;&]R/2,S,T9&1D8@;VY-;W5S94]V97(]5FEE=R@G
M,S-&1D9&)RD@;VY#;&EC:SU3970H)S,S1D9&1B<I(&AE:6=H=#TB,3!P>"(@
M=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC-C8P,$9&(&]N36]U
M<V5/=F5R/59I97<H)S8V,#!&1B<I(&]N0VQI8VL]4V5T*"<V-C`P1D8G*2!H
M96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(]
M(S8V,S-&1B!O;DUO=7-E3W9E<CU6:65W*"<V-C,S1D8G*2!O;D-L:6-K/5-E
M="@G-C8S,T9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-
M"CQT9"!B9V-O;&]R/2,V-C8V1D8@;VY-;W5S94]V97(]5FEE=R@G-C8V-D9&
M)RD@;VY#;&EC:SU3970H)S8V-C9&1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@]
M(C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC-C8Y.49&(&]N36]U<V5/=F5R
M/59I97<H)S8V.3E&1B<I(&]N0VQI8VL]4V5T*"<V-CDY1D8G*2!H96EG:'0]
M(C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V0T-&
M1B!O;DUO=7-E3W9E<CU6:65W*"<V-D-#1D8G*2!O;D-L:6-K/5-E="@G-C9#
M0T9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B
M9V-O;&]R/2,V-D9&1D8@;VY-;W5S94]V97(]5FEE=R@G-C9&1D9&)RD@;VY#
M;&EC:SU3970H)S8V1D9&1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B
M/CPO=&0^#0H\+W1R/@T*/'1R/@T*/'1D(&)G8V]L;W(](S`P,#`P,"!O;DUO
M=7-E3W9E<CU6:65W*"<P,#`P,#`G*2!O;D-L:6-K/5-E="@G,#`P,#`P)RD@
M:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R
M/2-&1C`P,#`@;VY-;W5S94]V97(]5FEE=R@G1D8P,#`P)RD@;VY#;&EC:SU3
M970H)T9&,#`P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^
M#0H\=&0@8F=C;VQO<CTC,#`P,#`P(&]N36]U<V5/=F5R/59I97<H)S`P,#`P
M,"<I(&]N0VQI8VL]4V5T*"<P,#`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H
M/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](SDY,#`P,"!O;DUO=7-E3W9E
M<CU6:65W*"<Y.3`P,#`G*2!O;D-L:6-K/5-E="@G.3DP,#`P)RD@:&5I9VAT
M/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.3,S
M,#`@;VY-;W5S94]V97(]5FEE=R@G.3DS,S`P)RD@;VY#;&EC:SU3970H)SDY
M,S,P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@
M8F=C;VQO<CTC.3DV-C`P(&]N36]U<V5/=F5R/59I97<H)SDY-C8P,"<I(&]N
M0VQI8VL]4V5T*"<Y.38V,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X
M(CX\+W1D/@T*/'1D(&)G8V]L;W(](SDY.3DP,"!O;DUO=7-E3W9E<CU6:65W
M*"<Y.3DY,#`G*2!O;D-L:6-K/5-E="@G.3DY.3`P)RD@:&5I9VAT/2(Q,'!X
M(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.4-#,#`@;VY-
M;W5S94]V97(]5FEE=R@G.3E#0S`P)RD@;VY#;&EC:SU3970H)SDY0T,P,"<I
M(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO
M<CTC.3E&1C`P(&]N36]U<V5/=F5R/59I97<H)SDY1D8P,"<I(&]N0VQI8VL]
M4V5T*"<Y.49&,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D
M/@T*/'1D(&)G8V]L;W(](T-#,#`P,"!O;DUO=7-E3W9E<CU6:65W*"=#0S`P
M,#`G*2!O;D-L:6-K/5-E="@G0T,P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T
M:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-#0S,S,#`@;VY-;W5S94]V
M97(]5FEE=R@G0T,S,S`P)RD@;VY#;&EC:SU3970H)T-#,S,P,"<I(&AE:6=H
M=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T,V
M-C`P(&]N36]U<V5/=F5R/59I97<H)T-#-C8P,"<I(&]N0VQI8VL]4V5T*"=#
M0S8V,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D
M(&)G8V]L;W(](T-#.3DP,"!O;DUO=7-E3W9E<CU6:65W*"=#0SDY,#`G*2!O
M;D-L:6-K/5-E="@G0T,Y.3`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P
M>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-#0T-#,#`@;VY-;W5S94]V97(]5FEE
M=R@G0T-#0S`P)RD@;VY#;&EC:SU3970H)T-#0T,P,"<I(&AE:6=H=#TB,3!P
M>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T-&1C`P(&]N
M36]U<V5/=F5R/59I97<H)T-#1D8P,"<I(&]N0VQI8VL]4V5T*"=#0T9&,#`G
M*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L
M;W(](T9&,#`P,"!O;DUO=7-E3W9E<CU6:65W*"=&1C`P,#`G*2!O;D-L:6-K
M/5-E="@G1D8P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T
M9#X-"CQT9"!B9V-O;&]R/2-&1C,S,#`@;VY-;W5S94]V97(]5FEE=R@G1D8S
M,S`P)RD@;VY#;&EC:SU3970H)T9&,S,P,"<I(&AE:6=H=#TB,3!P>"(@=VED
M=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC1D8V-C`P(&]N36]U<V5/
M=F5R/59I97<H)T9&-C8P,"<I(&]N0VQI8VL]4V5T*"=&1C8V,#`G*2!H96EG
M:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&
M.3DP,"!O;DUO=7-E3W9E<CU6:65W*"=&1CDY,#`G*2!O;D-L:6-K/5-E="@G
M1D8Y.3`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT
M9"!B9V-O;&]R/2-&1D-#,#`@;VY-;W5S94]V97(]5FEE=R@G1D9#0S`P)RD@
M;VY#;&EC:SU3970H)T9&0T,P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P
M<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC1D9&1C`P(&]N36]U<V5/=F5R/59I
M97<H)T9&1D8P,"<I(&]N0VQI8VL]4V5T*"=&1D9&,#`G*2!H96EG:'0](C$P
M<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/"]T<CX-"CQT<CX-"CQT9"!B9V-O
M;&]R/2,P,#`P,#`@;VY-;W5S94]V97(]5FEE=R@G,#`P,#`P)RD@;VY#;&EC
M:SU3970H)S`P,#`P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO
M=&0^#0H\=&0@8F=C;VQO<CTC,#!&1C`P(&]N36]U<V5/=F5R/59I97<H)S`P
M1D8P,"<I(&]N0VQI8VL]4V5T*"<P,$9&,#`G*2!H96EG:'0](C$P<'@B('=I
M9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E
M3W9E<CU6:65W*"<P,#`P,#`G*2!O;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I
M9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y
M.3`P,S,@;VY-;W5S94]V97(]5FEE=R@G.3DP,#,S)RD@;VY#;&EC:SU3970H
M)SDY,#`S,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\
M=&0@8F=C;VQO<CTC.3DS,S,S(&]N36]U<V5/=F5R/59I97<H)SDY,S,S,R<I
M(&]N0VQI8VL]4V5T*"<Y.3,S,S,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q
M,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](SDY-C8S,R!O;DUO=7-E3W9E<CU6
M:65W*"<Y.38V,S,G*2!O;D-L:6-K/5-E="@G.3DV-C,S)RD@:&5I9VAT/2(Q
M,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.3DY,S,@
M;VY-;W5S94]V97(]5FEE=R@G.3DY.3,S)RD@;VY#;&EC:SU3970H)SDY.3DS
M,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C
M;VQO<CTC.3E#0S,S(&]N36]U<V5/=F5R/59I97<H)SDY0T,S,R<I(&]N0VQI
M8VL]4V5T*"<Y.4-#,S,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\
M+W1D/@T*/'1D(&)G8V]L;W(](SDY1D8S,R!O;DUO=7-E3W9E<CU6:65W*"<Y
M.49&,S,G*2!O;D-L:6-K/5-E="@G.3E&1C,S)RD@:&5I9VAT/2(Q,'!X(B!W
M:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-#0S`P,S,@;VY-;W5S
M94]V97(]5FEE=R@G0T,P,#,S)RD@;VY#;&EC:SU3970H)T-#,#`S,R<I(&AE
M:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC
M0T,S,S,S(&]N36]U<V5/=F5R/59I97<H)T-#,S,S,R<I(&]N0VQI8VL]4V5T
M*"=#0S,S,S,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*
M/'1D(&)G8V]L;W(](T-#-C8S,R!O;DUO=7-E3W9E<CU6:65W*"=#0S8V,S,G
M*2!O;D-L:6-K/5-E="@G0T,V-C,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB
M,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-#0SDY,S,@;VY-;W5S94]V97(]
M5FEE=R@G0T,Y.3,S)RD@;VY#;&EC:SU3970H)T-#.3DS,R<I(&AE:6=H=#TB
M,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T-#0S,S
M(&]N36]U<V5/=F5R/59I97<H)T-#0T,S,R<I(&]N0VQI8VL]4V5T*"=#0T-#
M,S,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G
M8V]L;W(](T-#1D8S,R!O;DUO=7-E3W9E<CU6:65W*"=#0T9&,S,G*2!O;D-L
M:6-K/5-E="@G0T-&1C,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^
M/"]T9#X-"CQT9"!B9V-O;&]R/2-&1C`P,S,@;VY-;W5S94]V97(]5FEE=R@G
M1D8P,#,S)RD@;VY#;&EC:SU3970H)T9&,#`S,R<I(&AE:6=H=#TB,3!P>"(@
M=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC1D8S,S,S(&]N36]U
M<V5/=F5R/59I97<H)T9&,S,S,R<I(&]N0VQI8VL]4V5T*"=&1C,S,S,G*2!H
M96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(]
M(T9&-C8S,R!O;DUO=7-E3W9E<CU6:65W*"=&1C8V,S,G*2!O;D-L:6-K/5-E
M="@G1D8V-C,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-
M"CQT9"!B9V-O;&]R/2-&1CDY,S,@;VY-;W5S94]V97(]5FEE=R@G1D8Y.3,S
M)RD@;VY#;&EC:SU3970H)T9&.3DS,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@]
M(C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC1D9#0S,S(&]N36]U<V5/=F5R
M/59I97<H)T9&0T,S,R<I(&]N0VQI8VL]4V5T*"=&1D-#,S,G*2!H96EG:'0]
M(C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&1D8S
M,R!O;DUO=7-E3W9E<CU6:65W*"=&1D9&,S,G*2!O;D-L:6-K/5-E="@G1D9&
M1C,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CPO='(^
M#0H\='(^#0H\=&0@8F=C;VQO<CTC,#`P,#`P(&]N36]U<V5/=F5R/59I97<H
M)S`P,#`P,"<I(&]N0VQI8VL]4V5T*"<P,#`P,#`G*2!H96EG:'0](C$P<'@B
M('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S`P,#!&1B!O;DUO
M=7-E3W9E<CU6:65W*"<P,#`P1D8G*2!O;D-L:6-K/5-E="@G,#`P,$9&)RD@
M:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R
M/2,P,#`P,#`@;VY-;W5S94]V97(]5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3
M970H)S`P,#`P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^
M#0H\=&0@8F=C;VQO<CTC.3DP,#8V(&]N36]U<V5/=F5R/59I97<H)SDY,#`V
M-B<I(&]N0VQI8VL]4V5T*"<Y.3`P-C8G*2!H96EG:'0](C$P<'@B('=I9'1H
M/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](SDY,S,V-B!O;DUO=7-E3W9E
M<CU6:65W*"<Y.3,S-C8G*2!O;D-L:6-K/5-E="@G.3DS,S8V)RD@:&5I9VAT
M/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.38V
M-C8@;VY-;W5S94]V97(]5FEE=R@G.3DV-C8V)RD@;VY#;&EC:SU3970H)SDY
M-C8V-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@
M8F=C;VQO<CTC.3DY.38V(&]N36]U<V5/=F5R/59I97<H)SDY.3DV-B<I(&]N
M0VQI8VL]4V5T*"<Y.3DY-C8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X
M(CX\+W1D/@T*/'1D(&)G8V]L;W(](SDY0T,V-B!O;DUO=7-E3W9E<CU6:65W
M*"<Y.4-#-C8G*2!O;D-L:6-K/5-E="@G.3E#0S8V)RD@:&5I9VAT/2(Q,'!X
M(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.49&-C8@;VY-
M;W5S94]V97(]5FEE=R@G.3E&1C8V)RD@;VY#;&EC:SU3970H)SDY1D8V-B<I
M(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO
M<CTC0T,P,#8V(&]N36]U<V5/=F5R/59I97<H)T-#,#`V-B<I(&]N0VQI8VL]
M4V5T*"=#0S`P-C8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D
M/@T*/'1D(&)G8V]L;W(](T-#,S,V-B!O;DUO=7-E3W9E<CU6:65W*"=#0S,S
M-C8G*2!O;D-L:6-K/5-E="@G0T,S,S8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T
M:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-#0S8V-C8@;VY-;W5S94]V
M97(]5FEE=R@G0T,V-C8V)RD@;VY#;&EC:SU3970H)T-#-C8V-B<I(&AE:6=H
M=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T,Y
M.38V(&]N36]U<V5/=F5R/59I97<H)T-#.3DV-B<I(&]N0VQI8VL]4V5T*"=#
M0SDY-C8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D
M(&)G8V]L;W(](T-#0T,V-B!O;DUO=7-E3W9E<CU6:65W*"=#0T-#-C8G*2!O
M;D-L:6-K/5-E="@G0T-#0S8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P
M>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-#0T9&-C8@;VY-;W5S94]V97(]5FEE
M=R@G0T-&1C8V)RD@;VY#;&EC:SU3970H)T-#1D8V-B<I(&AE:6=H=#TB,3!P
M>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC1D8P,#8V(&]N
M36]U<V5/=F5R/59I97<H)T9&,#`V-B<I(&]N0VQI8VL]4V5T*"=&1C`P-C8G
M*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L
M;W(](T9&,S,V-B!O;DUO=7-E3W9E<CU6:65W*"=&1C,S-C8G*2!O;D-L:6-K
M/5-E="@G1D8S,S8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T
M9#X-"CQT9"!B9V-O;&]R/2-&1C8V-C8@;VY-;W5S94]V97(]5FEE=R@G1D8V
M-C8V)RD@;VY#;&EC:SU3970H)T9&-C8V-B<I(&AE:6=H=#TB,3!P>"(@=VED
M=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC1D8Y.38V(&]N36]U<V5/
M=F5R/59I97<H)T9&.3DV-B<I(&]N0VQI8VL]4V5T*"=&1CDY-C8G*2!H96EG
M:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&
M0T,V-B!O;DUO=7-E3W9E<CU6:65W*"=&1D-#-C8G*2!O;D-L:6-K/5-E="@G
M1D9#0S8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT
M9"!B9V-O;&]R/2-&1D9&-C8@;VY-;W5S94]V97(]5FEE=R@G1D9&1C8V)RD@
M;VY#;&EC:SU3970H)T9&1D8V-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P
M<'@B/CPO=&0^#0H\+W1R/@T*/'1R/@T*/'1D(&)G8V]L;W(](S`P,#`P,"!O
M;DUO=7-E3W9E<CU6:65W*"<P,#`P,#`G*2!O;D-L:6-K/5-E="@G,#`P,#`P
M)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O
M;&]R/2-&1D9&,#`@;VY-;W5S94]V97(]5FEE=R@G1D9&1C`P)RD@;VY#;&EC
M:SU3970H)T9&1D8P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO
M=&0^#0H\=&0@8F=C;VQO<CTC,#`P,#`P(&]N36]U<V5/=F5R/59I97<H)S`P
M,#`P,"<I(&]N0VQI8VL]4V5T*"<P,#`P,#`G*2!H96EG:'0](C$P<'@B('=I
M9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](SDY,#`Y.2!O;DUO=7-E
M3W9E<CU6:65W*"<Y.3`P.3DG*2!O;D-L:6-K/5-E="@G.3DP,#DY)RD@:&5I
M9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y
M.3,S.3D@;VY-;W5S94]V97(]5FEE=R@G.3DS,SDY)RD@;VY#;&EC:SU3970H
M)SDY,S,Y.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\
M=&0@8F=C;VQO<CTC.3DV-CDY(&]N36]U<V5/=F5R/59I97<H)SDY-C8Y.2<I
M(&]N0VQI8VL]4V5T*"<Y.38V.3DG*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q
M,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](SDY.3DY.2!O;DUO=7-E3W9E<CU6
M:65W*"<Y.3DY.3DG*2!O;D-L:6-K/5-E="@G.3DY.3DY)RD@:&5I9VAT/2(Q
M,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.4-#.3D@
M;VY-;W5S94]V97(]5FEE=R@G.3E#0SDY)RD@;VY#;&EC:SU3970H)SDY0T,Y
M.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C
M;VQO<CTC.3E&1CDY(&]N36]U<V5/=F5R/59I97<H)SDY1D8Y.2<I(&]N0VQI
M8VL]4V5T*"<Y.49&.3DG*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\
M+W1D/@T*/'1D(&)G8V]L;W(](T-#,#`Y.2!O;DUO=7-E3W9E<CU6:65W*"=#
M0S`P.3DG*2!O;D-L:6-K/5-E="@G0T,P,#DY)RD@:&5I9VAT/2(Q,'!X(B!W
M:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-#0S,S.3D@;VY-;W5S
M94]V97(]5FEE=R@G0T,S,SDY)RD@;VY#;&EC:SU3970H)T-#,S,Y.2<I(&AE
M:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC
M0T,V-CDY(&]N36]U<V5/=F5R/59I97<H)T-#-C8Y.2<I(&]N0VQI8VL]4V5T
M*"=#0S8V.3DG*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*
M/'1D(&)G8V]L;W(](T-#.3DY.2!O;DUO=7-E3W9E<CU6:65W*"=#0SDY.3DG
M*2!O;D-L:6-K/5-E="@G0T,Y.3DY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB
M,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-#0T-#.3D@;VY-;W5S94]V97(]
M5FEE=R@G0T-#0SDY)RD@;VY#;&EC:SU3970H)T-#0T,Y.2<I(&AE:6=H=#TB
M,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T-&1CDY
M(&]N36]U<V5/=F5R/59I97<H)T-#1D8Y.2<I(&]N0VQI8VL]4V5T*"=#0T9&
M.3DG*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G
M8V]L;W(](T9&,#`Y.2!O;DUO=7-E3W9E<CU6:65W*"=&1C`P.3DG*2!O;D-L
M:6-K/5-E="@G1D8P,#DY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^
M/"]T9#X-"CQT9"!B9V-O;&]R/2-&1C,S.3D@;VY-;W5S94]V97(]5FEE=R@G
M1D8S,SDY)RD@;VY#;&EC:SU3970H)T9&,S,Y.2<I(&AE:6=H=#TB,3!P>"(@
M=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC1D8V-CDY(&]N36]U
M<V5/=F5R/59I97<H)T9&-C8Y.2<I(&]N0VQI8VL]4V5T*"=&1C8V.3DG*2!H
M96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(]
M(T9&.3DY.2!O;DUO=7-E3W9E<CU6:65W*"=&1CDY.3DG*2!O;D-L:6-K/5-E
M="@G1D8Y.3DY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-
M"CQT9"!B9V-O;&]R/2-&1D-#.3D@;VY-;W5S94]V97(]5FEE=R@G1D9#0SDY
M)RD@;VY#;&EC:SU3970H)T9&0T,Y.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@]
M(C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC1D9&1CDY(&]N36]U<V5/=F5R
M/59I97<H)T9&1D8Y.2<I(&]N0VQI8VL]4V5T*"=&1D9&.3DG*2!H96EG:'0]
M(C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/"]T<CX-"CQT<CX-"CQT9"!B
M9V-O;&]R/2,P,#`P,#`@;VY-;W5S94]V97(]5FEE=R@G,#`P,#`P)RD@;VY#
M;&EC:SU3970H)S`P,#`P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B
M/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#!&1D9&(&]N36]U<V5/=F5R/59I97<H
M)S`P1D9&1B<I(&]N0VQI8VL]4V5T*"<P,$9&1D8G*2!H96EG:'0](C$P<'@B
M('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S`P,#`P,"!O;DUO
M=7-E3W9E<CU6:65W*"<P,#`P,#`G*2!O;D-L:6-K/5-E="@G,#`P,#`P)RD@
M:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R
M/2,Y.3`P0T,@;VY-;W5S94]V97(]5FEE=R@G.3DP,$-#)RD@;VY#;&EC:SU3
M970H)SDY,#!#0R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^
M#0H\=&0@8F=C;VQO<CTC.3DS,T-#(&]N36]U<V5/=F5R/59I97<H)SDY,S-#
M0R<I(&]N0VQI8VL]4V5T*"<Y.3,S0T,G*2!H96EG:'0](C$P<'@B('=I9'1H
M/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](SDY-C9#0R!O;DUO=7-E3W9E
M<CU6:65W*"<Y.38V0T,G*2!O;D-L:6-K/5-E="@G.3DV-D-#)RD@:&5I9VAT
M/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.3DY
M0T,@;VY-;W5S94]V97(]5FEE=R@G.3DY.4-#)RD@;VY#;&EC:SU3970H)SDY
M.3E#0R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@
M8F=C;VQO<CTC.3E#0T-#(&]N36]U<V5/=F5R/59I97<H)SDY0T-#0R<I(&]N
M0VQI8VL]4V5T*"<Y.4-#0T,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X
M(CX\+W1D/@T*/'1D(&)G8V]L;W(](SDY1D9#0R!O;DUO=7-E3W9E<CU6:65W
M*"<Y.49&0T,G*2!O;D-L:6-K/5-E="@G.3E&1D-#)RD@:&5I9VAT/2(Q,'!X
M(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-#0S`P0T,@;VY-
M;W5S94]V97(]5FEE=R@G0T,P,$-#)RD@;VY#;&EC:SU3970H)T-#,#!#0R<I
M(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO
M<CTC0T,S,T-#(&]N36]U<V5/=F5R/59I97<H)T-#,S-#0R<I(&]N0VQI8VL]
M4V5T*"=#0S,S0T,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D
M/@T*/'1D(&)G8V]L;W(](T-#-C9#0R!O;DUO=7-E3W9E<CU6:65W*"=#0S8V
M0T,G*2!O;D-L:6-K/5-E="@G0T,V-D-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T
M:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-#0SDY0T,@;VY-;W5S94]V
M97(]5FEE=R@G0T,Y.4-#)RD@;VY#;&EC:SU3970H)T-#.3E#0R<I(&AE:6=H
M=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T-#
M0T-#(&]N36]U<V5/=F5R/59I97<H)T-#0T-#0R<I(&]N0VQI8VL]4V5T*"=#
M0T-#0T,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D
M(&)G8V]L;W(](T-#1D9#0R!O;DUO=7-E3W9E<CU6:65W*"=#0T9&0T,G*2!O
M;D-L:6-K/5-E="@G0T-&1D-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P
M>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-&1C`P0T,@;VY-;W5S94]V97(]5FEE
M=R@G1D8P,$-#)RD@;VY#;&EC:SU3970H)T9&,#!#0R<I(&AE:6=H=#TB,3!P
M>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC1D8S,T-#(&]N
M36]U<V5/=F5R/59I97<H)T9&,S-#0R<I(&]N0VQI8VL]4V5T*"=&1C,S0T,G
M*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L
M;W(](T9&-C9#0R!O;DUO=7-E3W9E<CU6:65W*"=&1C8V0T,G*2!O;D-L:6-K
M/5-E="@G1D8V-D-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T
M9#X-"CQT9"!B9V-O;&]R/2-&1CDY0T,@;VY-;W5S94]V97(]5FEE=R@G1D8Y
M.4-#)RD@;VY#;&EC:SU3970H)T9&.3E#0R<I(&AE:6=H=#TB,3!P>"(@=VED
M=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC1D9#0T-#(&]N36]U<V5/
M=F5R/59I97<H)T9&0T-#0R<I(&]N0VQI8VL]4V5T*"=&1D-#0T,G*2!H96EG
M:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&
M1D9#0R!O;DUO=7-E3W9E<CU6:65W*"=&1D9&0T,G*2!O;D-L:6-K/5-E="@G
M1D9&1D-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CPO
M='(^#0H\='(^#0H\=&0@8F=C;VQO<CTC,#`P,#`P(&]N36]U<V5/=F5R/59I
M97<H)S`P,#`P,"<I(&]N0VQI8VL]4V5T*"<P,#`P,#`G*2!H96EG:'0](C$P
M<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&,#!&1B!O
M;DUO=7-E3W9E<CU6:65W*"=&1C`P1D8G*2!O;D-L:6-K/5-E="@G1D8P,$9&
M)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O
M;&]R/2,P,#`P,#`@;VY-;W5S94]V97(]5FEE=R@G,#`P,#`P)RD@;VY#;&EC
M:SU3970H)S`P,#`P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO
M=&0^#0H\=&0@8F=C;VQO<CTC.3DP,$9&(&]N36]U<V5/=F5R/59I97<H)SDY
M,#!&1B<I(&]N0VQI8VL]4V5T*"<Y.3`P1D8G*2!H96EG:'0](C$P<'@B('=I
M9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](SDY,S-&1B!O;DUO=7-E
M3W9E<CU6:65W*"<Y.3,S1D8G*2!O;D-L:6-K/5-E="@G.3DS,T9&)RD@:&5I
M9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y
M.38V1D8@;VY-;W5S94]V97(]5FEE=R@G.3DV-D9&)RD@;VY#;&EC:SU3970H
M)SDY-C9&1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\
M=&0@8F=C;VQO<CTC.3DY.49&(&]N36]U<V5/=F5R/59I97<H)SDY.3E&1B<I
M(&]N0VQI8VL]4V5T*"<Y.3DY1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q
M,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](SDY0T-&1B!O;DUO=7-E3W9E<CU6
M:65W*"<Y.4-#1D8G*2!O;D-L:6-K/5-E="@G.3E#0T9&)RD@:&5I9VAT/2(Q
M,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.49&1D8@
M;VY-;W5S94]V97(]5FEE=R@G.3E&1D9&)RD@;VY#;&EC:SU3970H)SDY1D9&
M1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C
M;VQO<CTC0T,P,$9&(&]N36]U<V5/=F5R/59I97<H)T-#,#!&1B<I(&]N0VQI
M8VL]4V5T*"=#0S`P1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\
M+W1D/@T*/'1D(&)G8V]L;W(](T-#,S-&1B!O;DUO=7-E3W9E<CU6:65W*"=#
M0S,S1D8G*2!O;D-L:6-K/5-E="@G0T,S,T9&)RD@:&5I9VAT/2(Q,'!X(B!W
M:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-#0S8V1D8@;VY-;W5S
M94]V97(]5FEE=R@G0T,V-D9&)RD@;VY#;&EC:SU3970H)T-#-C9&1B<I(&AE
M:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC
M0T,Y.49&(&]N36]U<V5/=F5R/59I97<H)T-#.3E&1B<I(&]N0VQI8VL]4V5T
M*"=#0SDY1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*
M/'1D(&)G8V]L;W(](T-#0T-&1B!O;DUO=7-E3W9E<CU6:65W*"=#0T-#1D8G
M*2!O;D-L:6-K/5-E="@G0T-#0T9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB
M,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-#0T9&1D8@;VY-;W5S94]V97(]
M5FEE=R@G0T-&1D9&)RD@;VY#;&EC:SU3970H)T-#1D9&1B<I(&AE:6=H=#TB
M,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC1D8P,$9&
M(&]N36]U<V5/=F5R/59I97<H)T9&,#!&1B<I(&]N0VQI8VL]4V5T*"=&1C`P
M1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G
M8V]L;W(](T9&,S-&1B!O;DUO=7-E3W9E<CU6:65W*"=&1C,S1D8G*2!O;D-L
M:6-K/5-E="@G1D8S,T9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^
M/"]T9#X-"CQT9"!B9V-O;&]R/2-&1C8V1D8@;VY-;W5S94]V97(]5FEE=R@G
M1D8V-D9&)RD@;VY#;&EC:SU3970H)T9&-C9&1B<I(&AE:6=H=#TB,3!P>"(@
M=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC1D8Y.49&(&]N36]U
M<V5/=F5R/59I97<H)T9&.3E&1B<I(&]N0VQI8VL]4V5T*"=&1CDY1D8G*2!H
M96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(]
M(T9&0T-&1B!O;DUO=7-E3W9E<CU6:65W*"=&1D-#1D8G*2!O;D-L:6-K/5-E
M="@G1D9#0T9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-
M"CQT9"!B9V-O;&]R/2-&1D9&1D8@;VY-;W5S94]V97(]5FEE=R@G1D9&1D9&
M)RD@;VY#;&EC:SU3970H)T9&1D9&1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@]
M(C$P<'@B/CPO=&0^#0H\+W1R/@T*/"]T86)L93X-"@T*/"]B;V1Y/CPO:'1M
M;#X-"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S
M+V5D:71O<B]H=&UL87)E82]P;W!U<',O:6YS97)T7W1A8FQE+FAT;6P`````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`Q,34R-2`Q,#4Q-30S,S<T-"`P,C<S-#(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/&AT;6P^"@H\:&5A9#X*
M("`\=&ET;&4^26YS97)T(%1A8FQE/"]T:71L93X*"CQS8W)I<'0@='EP93TB
M=&5X="]J879A<V-R:7!T(B!S<F,](G!O<'5P+FIS(CX\+W-C<FEP=#X*"CQS
M8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*"G=I;F1O=RYR97-I>F54
M;R@T,#`L(#$P,"D["@IF=6YC=&EO;B!);FET*"D@>PH@(&DQ.&X@/2!W:6YD
M;W<N;W!E;F5R+DA434Q!<F5A+DDQ.$XN9&EA;&]G<SL@+R\@;&]A9"!T:&4@
M2%1-3$%R96$@<&QU9VEN(&%N9"!L86YG(&9I;&4*("!?7V1L9U]T<F%N<VQA
M=&4H:3$X;BD["B`@7U]D;&=?:6YI="@I.PH@(&1O8W5M96YT+F=E=$5L96UE
M;G1">4ED*")F7W)O=W,B*2YF;V-U<R@I.PI].PH*9G5N8W1I;VX@;VY/2R@I
M('L*("!V87(@<F5Q=6ER960@/2!["B`@("`B9E]R;W=S(CH@(EEO=2!M=7-T
M(&5N=&5R(&$@;G5M8F5R(&]F(')O=W,B+`H@("`@(F9?8V]L<R(Z(")9;W4@
M;75S="!E;G1E<B!A(&YU;6)E<B!O9B!C;VQU;6YS(@H@('T["B`@9F]R("AV
M87(@:2!I;B!R97%U:7)E9"D@>PH@("`@=F%R(&5L(#T@9&]C=6UE;G0N9V5T
M16QE;65N=$)Y260H:2D["B`@("!I9B`H(65L+G9A;'5E*2!["B`@("`@(&%L
M97)T*')E<75I<F5D6VE=*3L*("`@("`@96PN9F]C=7,H*3L*("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@?0H@('T*("!V87(@9FEE;&1S(#T@6R)F7W)O=W,B
M+"`B9E]C;VQS(BP@(F9?=VED=&@B+"`B9E]U;FET(BP@(F9?9FEX960B+`H@
M("`@("`@("`@("`@("`@(F9?86QI9VXB+"`B9E]B;W)D97(B+"`B9E]S<&%C
M:6YG(BP@(F9?<&%D9&EN9R)=.PH@('9A<B!P87)A;2`](&YE=R!/8FIE8W0H
M*3L*("!F;W(@*'9A<B!I(&EN(&9I96QD<RD@>PH@("`@=F%R(&ED(#T@9FEE
M;&1S6VE=.PH@("`@=F%R(&5L(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H
M:60I.PH@("`@<&%R86U;:61=(#T@*&5L+G1Y<&4@/3T@(F-H96-K8F]X(BD@
M/R!E;"YC:&5C:V5D(#H@96PN=F%L=64["B`@?0H@(%]?9&QG7V-L;W-E*'!A
M<F%M*3L*("!R971U<FX@9F%L<V4["GT["@IF=6YC=&EO;B!O;D-A;F-E;"@I
M('L*("!?7V1L9U]C;&]S92AN=6QL*3L*("!R971U<FX@9F%L<V4["GT["@H\
M+W-C<FEP=#X*"CQS='EL92!T>7!E/2)T97AT+V-S<R(^"FAT;6PL(&)O9'D@
M>PH@(&)A8VMG<F]U;F0Z($)U='1O;D9A8V4["B`@8V]L;W(Z($)U='1O;E1E
M>'0["B`@9F]N=#H@,3%P>"!486AO;6$L5F5R9&%N82QS86YS+7-E<FEF.PH@
M(&UA<F=I;CH@,'!X.PH@('!A9&1I;F<Z(#!P>#L*?0IB;V1Y('L@<&%D9&EN
M9SH@-7!X.R!]"G1A8FQE('L*("!F;VYT.B`Q,7!X(%1A:&]M82Q697)D86YA
M+'-A;G,M<V5R:68["GT*9F]R;2!P('L*("!M87)G:6XM=&]P.B`U<'@["B`@
M;6%R9VEN+6)O='1O;3H@-7!X.PI]"BYF;"![('=I9'1H.B`Y96T[(&9L;V%T
M.B!L969T.R!P861D:6YG.B`R<'@@-7!X.R!T97AT+6%L:6=N.B!R:6=H=#L@
M?0HN9G(@>R!W:61T:#H@-V5M.R!F;&]A=#H@;&5F=#L@<&%D9&EN9SH@,G!X
M(#5P>#L@=&5X="UA;&EG;CH@<FEG:'0[('T*9FEE;&1S970@>R!P861D:6YG
M.B`P<'@@,3!P>"`U<'@@-7!X.R!]"G-E;&5C="P@:6YP=70L(&)U='1O;B![
M(&9O;G0Z(#$Q<'@@5&%H;VUA+%9E<F1A;F$L<V%N<RUS97)I9CL@?0IB=71T
M;VX@>R!W:61T:#H@-S!P>#L@?0HN<W!A8V4@>R!P861D:6YG.B`R<'@[('T*
M"BYT:71L92![(&)A8VMG<F]U;F0Z("-D9&8[(&-O;&]R.B`C,#`P.R!F;VYT
M+7=E:6=H=#H@8F]L9#L@9F]N="US:7IE.B`Q,C`E.R!P861D:6YG.B`S<'@@
M,3!P>#L@;6%R9VEN+6)O='1O;3H@,3!P>#L*8F]R9&5R+6)O='1O;3H@,7!X
M('-O;&ED(&)L86-K.R!L971T97(M<W!A8VEN9SH@,G!X.PI]"F9O<FT@>R!P
M861D:6YG.B`P<'@[(&UA<F=I;CH@,'!X.R!]"CPO<W1Y;&4^"@H\+VAE860^
M"@H\8F]D>2!O;FQO860](DEN:70H*2(^"@H\9&EV(&-L87-S/2)T:71L92(^
M26YS97)T(%1A8FQE/"]D:78^"@H\9F]R;2!A8W1I;VX](B(@;65T:&]D/2)G
M970B/@H\=&%B;&4@8F]R9&5R/2(P(B!S='EL93TB<&%D9&EN9SH@,'!X.R!M
M87)G:6XZ(#!P>"(^"B`@/'1B;V1Y/@H*("`\='(^"B`@("`\=&0@<W1Y;&4]
M(G=I9'1H.B`T96T[('1E>'0M86QI9VXZ(')I9VAT(CY2;W=S.CPO=&0^"B`@
M("`\=&0^/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](G)O=W,B(&ED/2)F7W)O
M=W,B('-I>F4](C4B('1I=&QE/2).=6UB97(@;V8@<F]W<R(@=F%L=64](C(B
M("\^/"]T9#X*("`@(#QT9"!S='EL93TB=VED=&@Z(#1E;3L@=&5X="UA;&EG
M;CH@<FEG:'0B/E=I9'1H.CPO=&0^"B`@("`\=&0^/&EN<'5T('1Y<&4](G1E
M>'0B(&YA;64](G=I9'1H(B!I9#TB9E]W:61T:"(@<VEZ93TB-2(@=&ET;&4]
M(E=I9'1H(&]F('1H92!T86)L92(@=F%L=64](C$P,"(@+SX\+W1D/@H@("`@
M/'1D/CQS96QE8W0@<VEZ93TB,2(@;F%M93TB=6YI="(@:60](F9?=6YI="(@
M=&ET;&4](E=I9'1H('5N:70B/@H@("`@("`\;W!T:6]N('9A;'5E/2(E(B!S
M96QE8W1E9#TB,2(@(#Y097)C96YT/"]O<'1I;VX^"B`@("`@(#QO<'1I;VX@
M=F%L=64](G!X(B`@("`@("`@("`@("`@/E!I>&5L<SPO;W!T:6]N/@H@("`@
M("`\;W!T:6]N('9A;'5E/2)E;2(@("`@("`@("`@("`@(#Y%;3PO;W!T:6]N
M/@H@("`@/"]S96QE8W0^/"]T9#X*("`\+W1R/@H@(#QT<CX*("`@(#QT9"!S
M='EL93TB=VED=&@Z(#1E;3L@=&5X="UA;&EG;CH@<FEG:'0B/D-O;',Z/"]T
M9#X*("`@(#QT9#X\:6YP=70@='EP93TB=&5X="(@;F%M93TB8V]L<R(@:60]
M(F9?8V]L<R(@<VEZ93TB-2(@=&ET;&4](DYU;6)E<B!O9B!C;VQU;6YS(B!V
M86QU93TB-"(@+SX\+W1D/@H@("`@/'1D('-T>6QE/2)T97AT+6%L:6=N.B!R
M:6=H="(^/&EN<'5T('1Y<&4](F-H96-K8F]X(B!C:&5C:V5D/2)C:&5C:V5D
M(B!N86UE/2)F:7AE9"(@:60](F9?9FEX960B("\^/"]T9#X*("`@(#QT9"!C
M;VQS<&%N/2(R(CX\;&%B96P@9F]R/2)F7V9I>&5D(@H@("`@/D9I>&5D('=I
M9'1H(&-O;'5M;G,\+VQA8F5L/CPO=&0^"B`@/"]T<CX*("`\+W1B;V1Y/@H\
M+W1A8FQE/@H*/'`@+SX*"CQF:65L9'-E="!S='EL93TB9FQO870Z(&QE9G0[
M(&UA<F=I;BUL969T.B`U<'@[(CX*/&QE9V5N9#Y,87EO=70\+VQE9V5N9#X*
M"CQD:78@8VQA<W,](G-P86-E(CX\+V1I=CX*"CQD:78@8VQA<W,](F9L(CY!
M;&EG;FUE;G0Z/"]D:78^"CQS96QE8W0@<VEZ93TB,2(@;F%M93TB86QI9VXB
M(&ED/2)F7V%L:6=N(@H@('1I=&QE/2)0;W-I=&EO;FEN9R!O9B!T:&ES('1A
M8FQE(CX*("`\;W!T:6]N('9A;'5E/2(B('-E;&5C=&5D/2(Q(B`@("`@("`@
M("`@("`@("`^3F]T('-E=#PO;W!T:6]N/@H@(#QO<'1I;VX@=F%L=64](FQE
M9G0B("`@("`@("`@("`@("`@("`@("`@("`@(#Y,969T/"]O<'1I;VX^"B`@
M/&]P=&EO;B!V86QU93TB<FEG:'0B("`@("`@("`@("`@("`@("`@("`@("`@
M/E)I9VAT/"]O<'1I;VX^"B`@/&]P=&EO;B!V86QU93TB=&5X='1O<"(@("`@
M("`@("`@("`@("`@("`@("`@/E1E>'1T;W`\+V]P=&EO;CX*("`\;W!T:6]N
M('9A;'5E/2)A8G-M:61D;&4B("`@("`@("`@("`@("`@("`@("`^06)S;6ED
M9&QE/"]O<'1I;VX^"B`@/&]P=&EO;B!V86QU93TB8F%S96QI;F4B("`@("`@
M("`@("`@("`@("`@("`@/D)A<V5L:6YE/"]O<'1I;VX^"B`@/&]P=&EO;B!V
M86QU93TB86)S8F]T=&]M(B`@("`@("`@("`@("`@("`@("`@/D%B<V)O='1O
M;3PO;W!T:6]N/@H@(#QO<'1I;VX@=F%L=64](F)O='1O;2(@("`@("`@("`@
M("`@("`@("`@("`@(#Y";W1T;VT\+V]P=&EO;CX*("`\;W!T:6]N('9A;'5E
M/2)M:61D;&4B("`@("`@("`@("`@("`@("`@("`@("`^36ED9&QE/"]O<'1I
M;VX^"B`@/&]P=&EO;B!V86QU93TB=&]P(B`@("`@("`@("`@("`@("`@("`@
M("`@("`@/E1O<#PO;W!T:6]N/@H\+W-E;&5C=#X*"CQP("\^"@H\9&EV(&-L
M87-S/2)F;"(^0F]R9&5R('1H:6-K;F5S<SH\+V1I=CX*/&EN<'5T('1Y<&4]
M(G1E>'0B(&YA;64](F)O<F1E<B(@:60](F9?8F]R9&5R(B!S:7IE/2(U(B!V
M86QU93TB,2(*=&ET;&4](DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B("\^
M"CPA+2T*/'`@+SX*"CQD:78@8VQA<W,](F9L(CY#;VQL87!S92!B;W)D97)S
M.CPO9&EV/@H\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](F-O;&QA<'-E
M(B!I9#TB9E]C;VQL87!S92(@+SX*+2T^"CQD:78@8VQA<W,](G-P86-E(CX\
M+V1I=CX*"CPO9FEE;&1S970^"@H\9FEE;&1S970@<W1Y;&4](F9L;V%T.G)I
M9VAT.R!M87)G:6XM<FEG:'0Z(#5P>#LB/@H\;&5G96YD/E-P86-I;F<\+VQE
M9V5N9#X*"CQD:78@8VQA<W,](G-P86-E(CX\+V1I=CX*"CQD:78@8VQA<W,]
M(F9R(CY#96QL('-P86-I;F<Z/"]D:78^"CQI;G!U="!T>7!E/2)T97AT(B!N
M86UE/2)S<&%C:6YG(B!I9#TB9E]S<&%C:6YG(B!S:7IE/2(U(B!V86QU93TB
M,2(*=&ET;&4](E-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',B("\^"@H\
M<"`O/@H*/&1I=B!C;&%S<STB9G(B/D-E;&P@<&%D9&EN9SH\+V1I=CX*/&EN
M<'5T('1Y<&4](G1E>'0B(&YA;64](G!A9&1I;F<B(&ED/2)F7W!A9&1I;F<B
M('-I>F4](C4B('9A;'5E/2(Q(@IT:71L93TB4W!A8V4@8F5T=V5E;B!C;VYT
M96YT(&%N9"!B;W)D97(@:6X@8V5L;"(@+SX*"CQD:78@8VQA<W,](G-P86-E
M(CX\+V1I=CX*"CPO9FEE;&1S970^"@H\9&EV('-T>6QE/2)M87)G:6XM=&]P
M.B`X-7!X.R!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(SDY.3L@<&%D9&EN9SH@
M,G!X.R!T97AT+6%L:6=N.B!R:6=H=#LB/@H\8G5T=&]N('1Y<&4](F)U='1O
M;B(@;F%M93TB;VLB(&]N8VQI8VL](G)E='5R;B!O;D]+*"D[(CY/2SPO8G5T
M=&]N/@H\8G5T=&]N('1Y<&4](F)U='1O;B(@;F%M93TB8V%N8V5L(B!O;F-L
M:6-K/2)R971U<FX@;VY#86YC96PH*3LB/D-A;F-E;#PO8G5T=&]N/@H\+V1I
M=CX*"CPO9F]R;3X*"CPO8F]D>3X*/"]H=&UL/@H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S
M97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&]P=7!S+VQI;FLN:'1M;```````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,3`T,S8@,3`U,34T,S,W-#0@,#(U-C(T`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#QH=&UL/@H*
M/&AE860^"B`@/'1I=&QE/DEN<V5R="]-;V1I9GD@3&EN:SPO=&ET;&4^"B`@
M/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B('-R8STB<&]P=7`N:G,B
M/CPO<V-R:7!T/@H@(#QS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*
M("`@('=I;F1O=RYR97-I>F54;R@T,#`L(#(P,"D["@I),3A.(#T@=VEN9&]W
M+F]P96YE<BY(5$U,07)E82Y),3A.+F1I86QO9W,["@IF=6YC=&EO;B!I,3AN
M*'-T<BD@>PH@(')E='5R;B`H23$X3EMS=')=('Q\('-T<BD["GT["@IF=6YC
M=&EO;B!O;E1A<F=E=$-H86YG960H*2!["B`@=F%R(&8@/2!D;V-U;65N="YG
M971%;&5M96YT0GE)9"@B9E]O=&AE<E]T87)G970B*3L*("!I9B`H=&AI<RYV
M86QU92`]/2`B7V]T:&5R(BD@>PH@("`@9BYS='EL92YV:7-I8FEL:71Y(#T@
M(G9I<VEB;&4B.PH@("`@9BYS96QE8W0H*3L*("`@(&8N9F]C=7,H*3L*("!]
M(&5L<V4@9BYS='EL92YV:7-I8FEL:71Y(#T@(FAI9&1E;B(["GT["@IF=6YC
M=&EO;B!);FET*"D@>PH@(%]?9&QG7W1R86YS;&%T92A),3A.*3L*("!?7V1L
M9U]I;FET*"D["B`@=F%R('!A<F%M(#T@=VEN9&]W+F1I86QO9T%R9W5M96YT
M<SL*("!V87(@=&%R9V5T7W-E;&5C="`](&1O8W5M96YT+F=E=$5L96UE;G1"
M>4ED*")F7W1A<F=E="(I.PH@('9A<B!U<V5?=&%R9V5T(#T@=')U93L*("!I
M9B`H<&%R86TI('L*("`@(&EF("@@='EP96]F('!A<F%M6R)F7W5S971A<F=E
M=")=("$](")U;F1E9FEN960B("D@>PH@("`@("!U<V5?=&%R9V5T(#T@<&%R
M86U;(F9?=7-E=&%R9V5T(ET["B`@("!]"B`@("!I9B`H('1Y<&5O9B!P87)A
M;5LB9E]H<F5F(ET@(3T@(G5N9&5F:6YE9"(@*2!["B`@("`@(&1O8W5M96YT
M+F=E=$5L96UE;G1">4ED*")F7VAR968B*2YV86QU92`]('!A<F%M6R)F7VAR
M968B73L*("`@("`@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H(F9?=&ET;&4B
M*2YV86QU92`]('!A<F%M6R)F7W1I=&QE(ET["B`@("`@(&-O;6)O4V5L96-T
M5F%L=64H=&%R9V5T7W-E;&5C="P@<&%R86U;(F9?=&%R9V5T(ETI.PH@("`@
M("!I9B`H=&%R9V5T7W-E;&5C="YV86QU92`A/2!P87)A;2YF7W1A<F=E="D@
M>PH@("`@("`@('9A<B!O<'0@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*")O
M<'1I;VXB*3L*("`@("`@("!O<'0N=F%L=64@/2!P87)A;2YF7W1A<F=E=#L*
M("`@("`@("!O<'0N:6YN97)(5$U,(#T@;W!T+G9A;'5E.PH@("`@("`@('1A
M<F=E=%]S96QE8W0N87!P96YD0VAI;&0H;W!T*3L*("`@("`@("!O<'0N<V5L
M96-T960@/2!T<G5E.PH@("`@("!]"B`@("!]"B`@?0H@(&EF("@A('5S95]T
M87)G970I('L*("`@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*")F7W1A<F=E
M=%]L86)E;"(I+G-T>6QE+G9I<VEB:6QI='D@/2`B:&ED9&5N(CL*("`@(&1O
M8W5M96YT+F=E=$5L96UE;G1">4ED*")F7W1A<F=E="(I+G-T>6QE+G9I<VEB
M:6QI='D@/2`B:&ED9&5N(CL*("`@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED
M*")F7W1A<F=E=%]O=&AE<B(I+G-T>6QE+G9I<VEB:6QI='D@/2`B:&ED9&5N
M(CL*("!]"B`@=F%R(&]P="`](&1O8W5M96YT+F-R96%T945L96UE;G0H(F]P
M=&EO;B(I.PH@(&]P="YV86QU92`](")?;W1H97(B.PH@(&]P="YI;FYE<DA4
M34P@/2!I,3AN*")/=&AE<B(I.PH@('1A<F=E=%]S96QE8W0N87!P96YD0VAI
M;&0H;W!T*3L*("!T87)G971?<V5L96-T+F]N8VAA;F=E(#T@;VY487)G971#
M:&%N9V5D.PH@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*")F7VAR968B*2YF
M;V-U<R@I.PH@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*")F7VAR968B*2YS
M96QE8W0H*3L*?3L*"F9U;F-T:6]N(&]N3TLH*2!["B`@=F%R(')E<75I<F5D
M(#T@>PH@("`@+R\@9E]H<F5F('-H;W5L9&XG="!B92!R97%U:7)E9"!O<B!O
M=&AE<G=I<V4@<F5M;W9I;F<@=&AE(&QI;FL@8GD@96YT97)I;F<@86X@96UP
M='D-"B`@("`O+R!U<FP@:7-N)W0@<&]S<VEB;&4@86YY;6]R92X-"B`@("`O
M+R`B9E]H<F5F(CH@:3$X;B@B66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R
M92!T:&ES(&QI;FL@<&]I;G1S('1O(BD-"B`@?3L*("!F;W(@*'9A<B!I(&EN
M(')E<75I<F5D*2!["B`@("!V87(@96P@/2!D;V-U;65N="YG971%;&5M96YT
M0GE)9"AI*3L*("`@(&EF("@A96PN=F%L=64I('L*("`@("`@86QE<G0H<F5Q
M=6ER961;:5TI.PH@("`@("!E;"YF;V-U<R@I.PH@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"B`@?0H@("\O('!A<W,@9&%T82!B86-K('1O('1H92!C86QL
M:6YG('=I;F1O=PH@('9A<B!F:65L9',@/2!;(F9?:')E9B(L(")F7W1I=&QE
M(BP@(F9?=&%R9V5T(B!=.PH@('9A<B!P87)A;2`](&YE=R!/8FIE8W0H*3L*
M("!F;W(@*'9A<B!I(&EN(&9I96QD<RD@>PH@("`@=F%R(&ED(#T@9FEE;&1S
M6VE=.PH@("`@=F%R(&5L(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H:60I
M.PH@("`@<&%R86U;:61=(#T@96PN=F%L=64["B`@?0H@(&EF("AP87)A;2YF
M7W1A<F=E="`]/2`B7V]T:&5R(BD*("`@('!A<F%M+F9?=&%R9V5T(#T@9&]C
M=6UE;G0N9V5T16QE;65N=$)Y260H(F9?;W1H97)?=&%R9V5T(BDN=F%L=64[
M"B`@7U]D;&=?8VQO<V4H<&%R86TI.PH@(')E='5R;B!F86QS93L*?3L*"F9U
M;F-T:6]N(&]N0V%N8V5L*"D@>PH@(%]?9&QG7V-L;W-E*&YU;&PI.PH@(')E
M='5R;B!F86QS93L*?3L*"CPO<V-R:7!T/@H*/'-T>6QE('1Y<&4](G1E>'0O
M8W-S(CX*:'1M;"P@8F]D>2!["B`@8F%C:V=R;W5N9#H@0G5T=&]N1F%C93L*
M("!C;VQO<CH@0G5T=&]N5&5X=#L*("!F;VYT.B`Q,7!X(%1A:&]M82Q697)D
M86YA+'-A;G,M<V5R:68["B`@;6%R9VEN.B`P<'@["B`@<&%D9&EN9SH@,'!X
M.PI]"F)O9'D@>R!P861D:6YG.B`U<'@[('T*=&%B;&4@>PH@(&9O;G0Z(#$Q
M<'@@5&%H;VUA+%9E<F1A;F$L<V%N<RUS97)I9CL*?0IS96QE8W0L(&EN<'5T
M+"!B=71T;VX@>R!F;VYT.B`Q,7!X(%1A:&]M82Q697)D86YA+'-A;G,M<V5R
M:68[('T*8G5T=&]N('L@=VED=&@Z(#<P<'@[('T*=&%B;&4@+FQA8F5L('L@
M=&5X="UA;&EG;CH@<FEG:'0[('=I9'1H.B`X96T[('T*"BYT:71L92![(&)A
M8VMG<F]U;F0Z("-D9&8[(&-O;&]R.B`C,#`P.R!F;VYT+7=E:6=H=#H@8F]L
M9#L@9F]N="US:7IE.B`Q,C`E.R!P861D:6YG.B`S<'@@,3!P>#L@;6%R9VEN
M+6)O='1O;3H@,3!P>#L*8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(&)L86-K
M.R!L971T97(M<W!A8VEN9SH@,G!X.PI]"@HC8G5T=&]N<R!["B`@("`@(&UA
M<F=I;BUT;W`Z(#%E;3L@8F]R9&5R+71O<#H@,7!X('-O;&ED(",Y.3D["B`@
M("`@('!A9&1I;F<Z(#)P>#L@=&5X="UA;&EG;CH@<FEG:'0["GT*/"]S='EL
M93X*"CPO:&5A9#X*"CQB;V1Y(&]N;&]A9#TB26YI="@I(CX*/&1I=B!C;&%S
M<STB=&ET;&4B/DEN<V5R="]-;V1I9GD@3&EN:SPO9&EV/@H\9F]R;3X*/'1A
M8FQE(&)O<F1E<CTB,"(@<W1Y;&4](G=I9'1H.B`Q,#`E.R(^"B`@/'1R/@H@
M("`@/'1D(&-L87-S/2)L86)E;"(^55),.CPO=&0^"B`@("`\=&0^/&EN<'5T
M('1Y<&4](G1E>'0B(&ED/2)F7VAR968B('-T>6QE/2)W:61T:#H@,3`P)2(@
M+SX\+W1D/@H@(#PO='(^"B`@/'1R/@H@("`@/'1D(&-L87-S/2)L86)E;"(^
M5&ET;&4@*'1O;VQT:7`I.CPO=&0^"B`@("`\=&0^/&EN<'5T('1Y<&4](G1E
M>'0B(&ED/2)F7W1I=&QE(B!S='EL93TB=VED=&@Z(#$P,"4B("\^/"]T9#X*
M("`\+W1R/@H@(#QT<CX*("`@(#QT9"!C;&%S<STB;&%B96PB/CQS<&%N(&ED
M/2)F7W1A<F=E=%]L86)E;"(^5&%R9V5T.CPO<W!A;CX\+W1D/@H@("`@/'1D
M/CQS96QE8W0@:60](F9?=&%R9V5T(CX*("`@("`@/&]P=&EO;B!V86QU93TB
M(CY.;VYE("AU<V4@:6UP;&EC:70I/"]O<'1I;VX^"B`@("`@(#QO<'1I;VX@
M=F%L=64](E]B;&%N:R(^3F5W('=I;F1O=R`H7V)L86YK*3PO;W!T:6]N/@H@
M("`@("`\;W!T:6]N('9A;'5E/2)?<V5L9B(^4V%M92!F<F%M92`H7W-E;&8I
M/"]O<'1I;VX^"B`@("`@(#QO<'1I;VX@=F%L=64](E]T;W`B/E1O<"!F<F%M
M92`H7W1O<"D\+V]P=&EO;CX*("`@(#PO<V5L96-T/@H@("`@/&EN<'5T('1Y
M<&4](G1E>'0B(&YA;64](F9?;W1H97)?=&%R9V5T(B!I9#TB9E]O=&AE<E]T
M87)G970B('-I>F4](C$P(B!S='EL93TB=FES:6)I;&ET>3H@:&ED9&5N(B`O
M/@H@("`@/"]T9#X*("`\+W1R/@H\+W1A8FQE/@H*/&1I=B!I9#TB8G5T=&]N
M<R(^"B`@/&)U='1O;B!T>7!E/2)S=6)M:70B(&YA;64](F]K(B!O;F-L:6-K
M/2)R971U<FX@;VY/2R@I.R(^3TL\+V)U='1O;CX*("`\8G5T=&]N('1Y<&4]
M(F)U='1O;B(@;F%M93TB8V%N8V5L(B!O;F-L:6-K/2)R971U<FX@;VY#86YC
M96PH*3LB/D-A;F-E;#PO8G5T=&]N/@H\+V1I=CX*/"]F;W)M/@H\+V)O9'D^
M"CPO:'1M;#X*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D
M:71O<B]H=&UL87)E82]P;W!U<',O8FQA;FLN:'1M;```````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#`Q-R`Q,#4Q-30S,S<T-"`P,C4W-3``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/&AT;6P^#0H\+VAT;6P^````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R
M96$O<&]P=7!S+VEN<V5R=%]I;6%G92YH=&UL````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3(S-3`@
M,3`U,34T,S,W-#0@,#(W,S,R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#QH=&UL/@T*#0H\:&5A9#X-"B`@/'1I=&QE/DEN
M<V5R="!);6%G93PO=&ET;&4^#0H-"CQS8W)I<'0@='EP93TB=&5X="]J879A
M<V-R:7!T(B!S<F,](G!O<'5P+FIS(CX\+W-C<FEP=#X-"@T*/'-C<FEP="!T
M>7!E/2)T97AT+VIA=F%S8W)I<'0B/@T*#0IW:6YD;W<N<F5S:7IE5&\H-#`P
M+"`Q,#`I.PT*#0IF=6YC=&EO;B!);FET*"D@>PT*("!?7V1L9U]I;FET*"D[
M#0H@('9A<B!P87)A;2`]('=I;F1O=RYD:6%L;V=!<F=U;65N=',[#0H@(&EF
M("AP87)A;2D@>PT*("`@("`@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H(F9?
M=7)L(BDN=F%L=64@/2!P87)A;5LB9E]U<FPB73L-"B`@("`@(&1O8W5M96YT
M+F=E=$5L96UE;G1">4ED*")F7V%L="(I+G9A;'5E(#T@<&%R86U;(F9?86QT
M(ET[#0H@("`@("!D;V-U;65N="YG971%;&5M96YT0GE)9"@B9E]B;W)D97(B
M*2YV86QU92`]('!A<F%M6R)F7V)O<F1E<B)=.PT*("`@("`@9&]C=6UE;G0N
M9V5T16QE;65N=$)Y260H(F9?86QI9VXB*2YV86QU92`]('!A<F%M6R)F7V%L
M:6=N(ET[#0H@("`@("!D;V-U;65N="YG971%;&5M96YT0GE)9"@B9E]V97)T
M(BDN=F%L=64@/2!P87)A;5LB9E]V97)T(ET[#0H@("`@("!D;V-U;65N="YG
M971%;&5M96YT0GE)9"@B9E]H;W)I>B(I+G9A;'5E(#T@<&%R86U;(F9?:&]R
M:7HB73L-"B`@("`@('=I;F1O=RYI<')E=FEE=RYL;V-A=&EO;BYR97!L86-E
M*'!A<F%M+F9?=7)L*3L-"B`@?0T*("!D;V-U;65N="YG971%;&5M96YT0GE)
M9"@B9E]U<FPB*2YF;V-U<R@I.PT*?3L-"@T*9G5N8W1I;VX@;VY/2R@I('L-
M"B`@=F%R(')E<75I<F5D(#T@>PT*("`@(")F7W5R;"(Z(")9;W4@;75S="!E
M;G1E<B!T:&4@55),(@T*("!].PT*("!F;W(@*'9A<B!I(&EN(')E<75I<F5D
M*2![#0H@("`@=F%R(&5L(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H:2D[
M#0H@("`@:68@*"%E;"YV86QU92D@>PT*("`@("`@86QE<G0H<F5Q=6ER961;
M:5TI.PT*("`@("`@96PN9F]C=7,H*3L-"B`@("`@(')E='5R;B!F86QS93L-
M"B`@("!]#0H@('T-"B`@+R\@<&%S<R!D871A(&)A8VL@=&\@=&AE(&-A;&QI
M;F<@=VEN9&]W#0H@('9A<B!F:65L9',@/2!;(F9?=7)L(BP@(F9?86QT(BP@
M(F9?86QI9VXB+"`B9E]B;W)D97(B+`T*("`@("`@("`@("`@("`@(")F7VAO
M<FEZ(BP@(F9?=F5R=")=.PT*("!V87(@<&%R86T@/2!N97<@3V)J96-T*"D[
M#0H@(&9O<B`H=F%R(&D@:6X@9FEE;&1S*2![#0H@("`@=F%R(&ED(#T@9FEE
M;&1S6VE=.PT*("`@('9A<B!E;"`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED
M*&ED*3L-"B`@("!P87)A;5MI9%T@/2!E;"YV86QU93L-"B`@?0T*("!?7V1L
M9U]C;&]S92AP87)A;2D[#0H@(')E='5R;B!F86QS93L-"GT[#0H-"F9U;F-T
M:6]N(&]N0V%N8V5L*"D@>PT*("!?7V1L9U]C;&]S92AN=6QL*3L-"B`@<F5T
M=7)N(&9A;'-E.PT*?3L-"@T*9G5N8W1I;VX@;VY0<F5V:65W*"D@>PT*("!V
M87(@9E]U<FP@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"@B9E]U<FPB*3L-
M"B`@=F%R('5R;"`](&9?=7)L+G9A;'5E.PT*("!I9B`H(75R;"D@>PT*("`@
M(&%L97)T*")9;W4@:&%V92!T;R!E;G1E<B!A;B!54DP@9FER<W0B*3L-"B`@
M("!F7W5R;"YF;V-U<R@I.PT*("`@(')E='5R;B!F86QS93L-"B`@?0T*("!W
M:6YD;W<N:7!R979I97<N;&]C871I;VXN<F5P;&%C92AU<FPI.PT*("!R971U
M<FX@9F%L<V4[#0I].PT*/"]S8W)I<'0^#0H-"CQS='EL92!T>7!E/2)T97AT
M+V-S<R(^#0IH=&UL+"!B;V1Y('L-"B`@8F%C:V=R;W5N9#H@0G5T=&]N1F%C
M93L-"B`@8V]L;W(Z($)U='1O;E1E>'0[#0H@(&9O;G0Z(#$Q<'@@5&%H;VUA
M+%9E<F1A;F$L<V%N<RUS97)I9CL-"B`@;6%R9VEN.B`P<'@[#0H@('!A9&1I
M;F<Z(#!P>#L-"GT-"F)O9'D@>R!P861D:6YG.B`U<'@[('T-"G1A8FQE('L-
M"B`@9F]N=#H@,3%P>"!486AO;6$L5F5R9&%N82QS86YS+7-E<FEF.PT*?0T*
M9F]R;2!P('L-"B`@;6%R9VEN+71O<#H@-7!X.PT*("!M87)G:6XM8F]T=&]M
M.B`U<'@[#0I]#0HN9FP@>R!W:61T:#H@.65M.R!F;&]A=#H@;&5F=#L@<&%D
M9&EN9SH@,G!X(#5P>#L@=&5X="UA;&EG;CH@<FEG:'0[('T-"BYF<B![('=I
M9'1H.B`V96T[(&9L;V%T.B!L969T.R!P861D:6YG.B`R<'@@-7!X.R!T97AT
M+6%L:6=N.B!R:6=H=#L@?0T*9FEE;&1S970@>R!P861D:6YG.B`P<'@@,3!P
M>"`U<'@@-7!X.R!]#0IS96QE8W0L(&EN<'5T+"!B=71T;VX@>R!F;VYT.B`Q
M,7!X(%1A:&]M82Q697)D86YA+'-A;G,M<V5R:68[('T-"F)U='1O;B![('=I
M9'1H.B`W,'!X.R!]#0HN<W!A8V4@>R!P861D:6YG.B`R<'@[('T-"@T*+G1I
M=&QE('L@8F%C:V=R;W5N9#H@(V1D9CL@8V]L;W(Z(",P,#`[(&9O;G0M=V5I
M9VAT.B!B;VQD.R!F;VYT+7-I>F4Z(#$R,"4[('!A9&1I;F<Z(#-P>"`Q,'!X
M.R!M87)G:6XM8F]T=&]M.B`Q,'!X.PT*8F]R9&5R+6)O='1O;3H@,7!X('-O
M;&ED(&)L86-K.R!L971T97(M<W!A8VEN9SH@,G!X.PT*?0T*9F]R;2![('!A
M9&1I;F<Z(#!P>#L@;6%R9VEN.B`P<'@[('T-"CPO<W1Y;&4^#0H-"CPO:&5A
M9#X-"@T*/&)O9'D@;VYL;V%D/2));FET*"DB/@T*#0H\9&EV(&-L87-S/2)T
M:71L92(^26YS97)T($EM86=E/"]D:78^#0H\(2TM+2!N97<@<W1U9F8@+2TM
M/@T*/&9O<FT@86-T:6]N/2(B(&UE=&AO9#TB9V5T(CX-"CQT86)L92!B;W)D
M97(](C`B('=I9'1H/2(Q,#`E(B!S='EL93TB<&%D9&EN9SH@,'!X.R!M87)G
M:6XZ(#!P>"(^#0H@(#QT8F]D>3X-"@T*("`\='(^#0H@("`@/'1D('-T>6QE
M/2)W:61T:#H@-V5M.R!T97AT+6%L:6=N.B!R:6=H="(^26UA9V4@55),.CPO
M=&0^#0H@("`@/'1D/CQI;G!U="!T>7!E/2)T97AT(B!N86UE/2)U<FPB(&ED
M/2)F7W5R;"(@<W1Y;&4](G=I9'1H.C<U)2(-"B`@("`@('1I=&QE/2)%;G1E
M<B!T:&4@:6UA9V4@55),(&AE<F4B("\^#0H@("`@("`\8G5T=&]N(&YA;64]
M(G!R979I97<B(&]N8VQI8VL](G)E='5R;B!O;E!R979I97<H*3LB#0H@("`@
M("!T:71L93TB4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(CY0
M<F5V:65W/"]B=71T;VX^#0H@("`@/"]T9#X-"B`@/"]T<CX-"B`@/'1R/@T*
M("`@(#QT9"!S='EL93TB=VED=&@Z(#=E;3L@=&5X="UA;&EG;CH@<FEG:'0B
M/D%L=&5R;F%T92!T97AT.CPO=&0^#0H@("`@/'1D/CQI;G!U="!T>7!E/2)T
M97AT(B!N86UE/2)A;'0B(&ED/2)F7V%L="(@<W1Y;&4](G=I9'1H.C$P,"4B
M#0H@("`@("!T:71L93TB1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R
M="!I;6%G97,B("\^/"]T9#X-"B`@/"]T<CX-"@T*("`\+W1B;V1Y/@T*/"]T
M86)L93X-"@T*/'`@+SX-"@T*/&9I96QD<V5T('-T>6QE/2)F;&]A=#H@;&5F
M=#L@;6%R9VEN+6QE9G0Z(#5P>#LB/@T*/&QE9V5N9#Y,87EO=70\+VQE9V5N
M9#X-"@T*/&1I=B!C;&%S<STB<W!A8V4B/CPO9&EV/@T*#0H\9&EV(&-L87-S
M/2)F;"(^06QI9VYM96YT.CPO9&EV/@T*/'-E;&5C="!S:7IE/2(Q(B!N86UE
M/2)A;&EG;B(@:60](F9?86QI9VXB#0H@('1I=&QE/2)0;W-I=&EO;FEN9R!O
M9B!T:&ES(&EM86=E(CX-"B`@/&]P=&EO;B!V86QU93TB(B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/DYO="!S970\+V]P=&EO;CX-"B`@/&]P=&EO
M;B!V86QU93TB;&5F="(@("`@("`@("`@("`@("`@("`@("`@("`@/DQE9G0\
M+V]P=&EO;CX-"B`@/&]P=&EO;B!V86QU93TB<FEG:'0B("`@("`@("`@("`@
M("`@("`@("`@("`@/E)I9VAT/"]O<'1I;VX^#0H@(#QO<'1I;VX@=F%L=64]
M(G1E>'1T;W`B("`@("`@("`@("`@("`@("`@("`@(#Y497AT=&]P/"]O<'1I
M;VX^#0H@(#QO<'1I;VX@=F%L=64](F%B<VUI9&1L92(@("`@("`@("`@("`@
M("`@("`@(#Y!8G-M:61D;&4\+V]P=&EO;CX-"B`@/&]P=&EO;B!V86QU93TB
M8F%S96QI;F4B('-E;&5C=&5D/2(Q(B`@("`@("`@/D)A<V5L:6YE/"]O<'1I
M;VX^#0H@(#QO<'1I;VX@=F%L=64](F%B<V)O='1O;2(@("`@("`@("`@("`@
M("`@("`@(#Y!8G-B;W1T;VT\+V]P=&EO;CX-"B`@/&]P=&EO;B!V86QU93TB
M8F]T=&]M(B`@("`@("`@("`@("`@("`@("`@("`@/D)O='1O;3PO;W!T:6]N
M/@T*("`\;W!T:6]N('9A;'5E/2)M:61D;&4B("`@("`@("`@("`@("`@("`@
M("`@("`^36ED9&QE/"]O<'1I;VX^#0H@(#QO<'1I;VX@=F%L=64](G1O<"(@
M("`@("`@("`@("`@("`@("`@("`@("`@(#Y4;W`\+V]P=&EO;CX-"CPO<V5L
M96-T/@T*#0H\<"`O/@T*#0H\9&EV(&-L87-S/2)F;"(^0F]R9&5R('1H:6-K
M;F5S<SH\+V1I=CX-"CQI;G!U="!T>7!E/2)T97AT(B!N86UE/2)B;W)D97(B
M(&ED/2)F7V)O<F1E<B(@<VEZ93TB-2(-"G1I=&QE/2),96%V92!E;7!T>2!F
M;W(@;F\@8F]R9&5R(B`O/@T*#0H\9&EV(&-L87-S/2)S<&%C92(^/"]D:78^
M#0H-"CPO9FEE;&1S970^#0H-"CQF:65L9'-E="!S='EL93TB9FQO870Z<FEG
M:'0[(&UA<F=I;BUR:6=H=#H@-7!X.R(^#0H\;&5G96YD/E-P86-I;F<\+VQE
M9V5N9#X-"@T*/&1I=B!C;&%S<STB<W!A8V4B/CPO9&EV/@T*#0H\9&EV(&-L
M87-S/2)F<B(^2&]R:7IO;G1A;#H\+V1I=CX-"CQI;G!U="!T>7!E/2)T97AT
M(B!N86UE/2)H;W)I>B(@:60](F9?:&]R:7HB('-I>F4](C4B#0IT:71L93TB
M2&]R:7IO;G1A;"!P861D:6YG(B`O/@T*#0H\<"`O/@T*#0H\9&EV(&-L87-S
M/2)F<B(^5F5R=&EC86PZ/"]D:78^#0H\:6YP=70@='EP93TB=&5X="(@;F%M
M93TB=F5R="(@:60](F9?=F5R="(@<VEZ93TB-2(-"G1I=&QE/2)697)T:6-A
M;"!P861D:6YG(B`O/@T*#0H\9&EV(&-L87-S/2)S<&%C92(^/"]D:78^#0H-
M"CPO9FEE;&1S970^#0H\8G(@8VQE87(](F%L;"(@+SX-"CQT86)L92!W:61T
M:#TB,3`P)2(@<W1Y;&4](FUA<F=I;BUB;W1T;VTZ(#`N,F5M(CX-"B`\='(^
M#0H@(#QT9"!V86QI9VX](F)O='1O;2(^#0H@("`@26UA9V4@4')E=FEE=SH\
M8G(@+SX-"B`@("`\:69R86UE(&YA;64](FEP<F5V:65W(B!I9#TB:7!R979I
M97<B(&9R86UE8F]R9&5R/2(P(B!S='EL93TB8F]R9&5R(#H@,7!X('-O;&ED
M(&=R87D[(B!H96EG:'0](C(P,"(@=VED=&@](C,P,"(@<W)C/2(B/CPO:69R
M86UE/@T*("`\+W1D/@T*("`\=&0@=F%L:6=N/2)B;W1T;VTB('-T>6QE/2)T
M97AT+6%L:6=N.B!R:6=H="(^#0H@("`@/&)U='1O;B!T>7!E/2)B=71T;VXB
M(&YA;64](F]K(B!O;F-L:6-K/2)R971U<FX@;VY/2R@I.R(^3TL\+V)U='1O
M;CX\8G(^#0H@("`@/&)U='1O;B!T>7!E/2)B=71T;VXB(&YA;64](F-A;F-E
M;"(@;VYC;&EC:STB<F5T=7)N(&]N0V%N8V5L*"D[(CY#86YC96P\+V)U='1O
M;CX-"B`@/"]T9#X-"B`\+W1R/@T*/"]T86)L93X-"CPO9F]R;3X-"CPO8F]D
M>3X-"CPO:'1M;#X-"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S````````````````
M````````````````````````````````````````````,#`P-S4U(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W-#0@,#(S-C,U`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I
M;6%G97,O961?86QI9VY?;&5F="YG:68`````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#$P-2`Q,#4Q
M-30S,S<T-"`P,C<Q-3,`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````1TE&.#EA$@`2`(`!`````/___R'Y!`$```$`+``````2
M`!(```(<C(^IR^T!HISS/4JMAKAOUDG?%69C4@+GRK9(`0`[````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7VMI
M;&QW;W)D+F=I9@``````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`R,S(@,3`U,34T,S,W-#0@,#(V
M-C<W`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`$=)1C@Y81(`$@#"!@```````/__``!-34VJJJK_Z,W_______\A^00!"@`'
M`"P!````$``2```#7WBZW$PP2D>,O98,%4#_'I`9FXA=@36L`^@"16P40VAX
MQF<5,YYVMP)L-JO=7#F>T@?S\&`RH8AI$5P$M-3)`L!:I2^=M;>H8`I>LL)\
MO=+*L;@\!BC7:@!\'E!W^!4)`#L`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R
M=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]C=7-T;VTN9VEF````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P,3`S(#$P-3$U-#,S-S0T(#`R-C,U-P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!'248X.6$2`!(`
M@`$`````____(?D$`0```0`L`````!(`$@```AJ,CZG+[0_C`D`&2B6N<=O\
M<=9XB9U)INIJ%``[````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O
M<B]H=&UL87)E82]I;6%G97,O961?8FQA;FLN9VEF````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#`W,"`Q,#4Q-30S,S<T-"`P,C8Q,S<`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````1TE&.#EA$@`2`(```/___P```"'Y
M!`$`````+``````2`!(```(/A(^IR^T/HYRTVHNSWIP7`#L`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O
M:6UA9V5S+V5D7VEN9&5N=%]L97-S+F=I9@``````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`Q,C<@,3`U
M,34T,S,W-#0@,#(W,S8R`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````$=)1C@Y81(`$@"1`@```(0```#___\````A^00!```"
M`"P`````$@`2```"*)2/J1GKKX)LLTJ(!4"V'K`=W62`9E:&1K>H`HMBWGC%
MR]S8^KKW4`$`.P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]I
M;F1E;G1?;6]R92YG:68``````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,3(W(#$P-3$U-#,S-S0T(#`R
M-S,U-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!'248X.6$2`!(`D0(```"$````____````(?D$`0```@`L`````!(`$@``
M`BB4CZD9ZZ^";+-*B`5`MB*P&=UD@&9V@$>WA**%9MYXQ<O<V+JX]U`!`#L`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E
M<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?86QI9VY?:G5S=&EF
M>2YG:68````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#$P-2`Q,#4Q-30S,S<T-"`P,C<W,38`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````1TE&.#EA$@`2
M`(`!`````/___R'Y!`$```$`+``````2`!(```(<C(^IR^T!HISS/8JE=3GO
MUF$?$U+C4E;GRK9'`0`[````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET
M;W(O:'1M;&%R96$O:6UA9V5S+V5D7V9O<FUA=%]I=&%L:6,N9VEF````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`Q,34@,3`U,34T,S,W-#0@,#(W-C8U`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````$=)1C@Y81(`$@"1`P![>WN$A(0`
M``#___\A^00!```#`"P`````$@`2```"'IR/J<OM#XV8,XX9+*AV`LU%'BA8
ME_!!%&6V[@M'!0`[````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A
M+VEM86=E<R]E9%]C:&%R;6%P+F=I9@``````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,C$W(#$P
M-3$U-#,S-S0T(#`R-C0V-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!'248X.6$2`!(`H@<`@`"`P,#`@("`_P````#_````
M________(?D$`0``!P`L`````!(`$@```U1XNMS>(CX7@Y6SAL&OH,;%#8(5
M?(P0>J5E&.C1OJ8+"\52$D1`OP)`)"<S$6:1H)"X._9\$8`0IVA9CM#H4&?M
MW9(%(M?T#4]D)9CYS!6SW_`X/`$`.P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O9G5L
M;'-C<F5E;E]M:6YI;6EZ92YG:68````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#$T,2`Q,#4Q-30S,S<T-"`P
M,S`T-#(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````1TE&.#EA$@`2`(`!`````/___R'Y!`$```$`+``````2`!(```(XC(^I
M".V_`HASU=.D>8[E>FU8II781I83N::J='6,R+JB]N4<#9U):POQ."L%<"<T
M68S$7>29*```.P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S
M97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7W!A<W1E+F=I9@``
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`R,3,@,3`U,34T,S,W-#0@,#(V,38S`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````$=)1C@Y81(`
M$@"B!@"`@`"`@(```(#__P#___\```#___\````A^00!```&`"P`````$@`2
M```#4&BZW/[0E5FBH7,,7%D!`5!L8Q$&G6*B4IA>($<%[&*"^(F_GR[\0`%/
M%Q`0CL>?)P<P(@E&@8T8_4&!*J;SF511KT&H#;/E2A_!]-G";BL2`#L`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I
M=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]C=70N9VEF````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,3,S(#$P-3$U-#,S-S0T(#`R-38T,P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!'248X.6$2`!(`D0(```"`````
M____````(?D$`0```@`L`````!(`$@```BR4CZG+&_<:G-)$<65XN\Y<;6#H
M(4``E$8*M%7+KDTJQ/4LT_2BKSOC4@F'!0`[````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E
M82]I;6%G97,O961?<VAO=U]B;W)D97(N9VEF````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#$U,"`Q
M,#4Q-30S,S<T-"`P,C<S-C0`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````1TE&.#EA$@`2`)$"```SF0```/___P```"'Y!`$`
M``(`+``````2`!(```(YE(^IR^T/8YBTVF`"V+QW+&C>N($8&![HE*7M&YIG
M.I\LK>:9Z?:KC*O%>"M=K%6$W5C"VO("914``#L`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D
M7W)E9&\N9VEF````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`Q,C`@,3`U,34T,S,W-#0@
M,#(U-S<U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````$=)1C@Y81(`$@"1`@"`@(```(#___\````A^00!```"`"P`````$@`2
M```"(92/J<OM[T"8`4HT3TV;B^PME-)A8W*9)P=`[@O'\DR_!0`[````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]L:6YK+F=I9@``
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`P,30Q(#$P-3$U-#,S-S0T(#`R-C`P-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!'248X.6$2
M`!(`D0``____@("`````____(?D$!10``P`L`````!(`$@```C*<CZG+[0_C
M"*)68VLX%(!3>>`V"%^&"A@&J.9G4.5,I]DZJ9R&"&1^*V5^DJ+QB$PR"@`[
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D
M:71O<B]H=&UL87)E82]I;6%G97,O961?:&5L<"YG:68`````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#$P-B`Q,#4Q-30S,S<T-"`P,C8P,#``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````1TE&.#EA$@`2`(`!`````/__
M_R'Y!`$```$`+``````2`!(```(=C(^IR^T/`Y@@3G-?SE'6SD&A^'7F,6KE
MR;;N4@``.P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R
M96$O:6UA9V5S+V5D7V9O<FUA=%]B;VQD+F=I9@``````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`Q,3(@
M,3`U,34T,S,W-#0@,#(W,S,U`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````$=)1C@Y81(`$@"``0````#___\A^00!```!`"P`
M````$@`2```"(8R/J<OM_X"<,M8P7<:7[>U170@8X/*-2EJ2(@3'\DPS!0`[
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E
M9%]L969T7W1O7W)I9VAT+F=I9@```````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,3,Q(#$P-3$U-#,S-S0T
M(#`R-S8W-P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!'248X.6$2`!(`D0(`!`*$````____````(?D$`0```@`L`````!(`
M$@```BJ4CZG+[0]3F`R@&41>P!JL5=U';4HW:IF9H%?(><=:*704LL^-]_X/
M*0``.P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?=6YD;RYG:68`
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#$R,2`Q,#4Q-30S,S<T-"`P,C8P,3(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````1TE&.#EA
M$@`2`)$"`("`@```@/___P```"'Y!`$```(`+``````2`!(```(BE(^IR^T/
M8PLT@!4.15;M['D;)HX)R%6HT4G`*L7R3-=,`0`[````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E
M9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7V9O<FUA=%]S=6(N9VEF````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`Q,38@,3`U,34T,S,W-#0@,#(W,C$R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````$=)1C@Y81(`$@"1`@```(``
M``#___\````A^00!```"`"P`````$@`2```"'Y2/J<OM[T(P$@I9[9T:\Y=5
M`*`A9'EJJ3J6[@O'30$`.P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA
M<F5A+VEM86=E<R]I;G-E<G1?=&%B;&4N9VEF````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,3<Q
M(#$P-3$U-#,S-S0T(#`R-S`U-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!'248X.6$2`!(`H@``____S,S,`#.9````____
M````````````(?D$!10`!``L`````!(`$@```SY(NMS^D(Q)JQUJB,U[QY(G
M<N``!$"*JNE9GNT*JV5@WSC^RGR\QT!:)D>\_5A(5V;&Y-6*Q-)E.HE8K]AL
M`@`[````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O
M961?9F]R;6%T7W-U<"YG:68````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#$Q-2`Q,#4Q-30S,S<T
M-"`P,C<R,C<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````1TE&.#EA$@`2`)$"`(```````/___P```"'Y!`$```(`+``````2
M`!(```(>E(^IRVT`'(L2T?JPA2P$XV%>J)'B>(*?QK;N"[<%`#L`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7VEM86=E+F=I
M9@``````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`R,C0@,3`U,34T,S,W-#0@,#(V,3,S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````$=)1C@Y
M81(`$@"B!P``@`"```"`@`"`@(#__P``__\```#___\A^00!```'`"P`````
M$@`2```#67BZW/Y0F4&KI8:-(+CO8+8,@F&>:"`J6U8<+R$?I5:^^$$HJM:_
M`YBP-KH=@I1"L#?J!5E((JOT/!XI3%:@>B&MC@+`04P>MWR`M'HM!7_>G2]J
M/H_8[Y`$`#L`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O
M961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]H<BYG:68`````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P,3`V(#$P-3$U-#,S-S0T(#`R-30V,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!'248X.6$2`!(`D0(`,S,S
MF9F9____````(?D$`0```@`L`````!(`$@```A>4CZG+[0^CG+2!B[,^H?L/
M5N)(EN:I%``[````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL
M87)E82]I;6%G97,O961?<FEG:'1?=&]?;&5F="YG:68`````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#$S
M,"`Q,#4Q-30S,S<T-"`P,C<V-S8`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````1TE&.#EA$@`2`)$"``0"A````/___P```"'Y
M!`$```(`+``````2`!(```(IE(^IR^W_@@QP"HK`LM@`K7#'!X841I;A-7[-
MF:D)G+TL9-#XSO=^4@``.P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S
M+V5D7VAT;6PN9VEF````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`Q,3,@,3`U,34T,S,W
M-#0@,#(V,#$R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$=)1C@Y81(`$@"``0````#___\A^00!```!`"P`````$@`2```"
M(HR/J<OM#P$P\M5S5\93;?1]2=AY)7A2*<HZEPC%\DS71P$`.P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]S879E+F=I
M9@```````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`P,C$W(#$P-3$U-#,S-S0T(#`R-C`Q,0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!'248X
M.6$2`!(`H@4`W-S<@("`@(``____````____````````(?D$`0``!0`L````
M`!(`$@```U18NMS^4)%)*VU$D,'[(`41,-GF<50`+.6):BJKN1^\2K-;QKAF
M93:98$@LBFZAX6\2[$T"$]Q1**I*>4D?%)2<*K;+%+(`")C/:/-8`6B[W^V(
M/`$`.P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S
M+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?9F]R;6%T7W-T<FEK92YG:68`
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#$Q-B`Q,#4Q-30S,S<T-"`P,C<W,C(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````1TE&.#EA$@`2`(`!````
M`/___R'Y!`$```$`+``````2`!(```(EC(^IR^T*(@C3Q7-M-9M)_%!9(Y5F
M^#U;2B*CMW;+5(;VC>=,`0`[````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M
M;&%R96$O:6UA9V5S+V5D7V1E;&5T92YG:68`````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`Q
M,S(@,3`U,34T,S,W-#0@,#(V,S$Q`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````$=)1C@Y81(`$@"1``#___\```#___\````A
M^00%%``"`"P`````$@`2```"*Y2/J<OM%@)@<9Y84];8BKUTG]=@H",^GTF&
MV<E)EZRD5PO!8XBK5.\+'@H`.P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E
M<R]E9%]C;VQO<E]B9RYG:68`````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,C8U(#$P-3$U-#,S
M-S0T(#`R-C8T-``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!'248X.6$2`!(`LPL``(0``'L`A(2$>WM[_P#_`/___P``__\`
M``#_____````____````````````````(?D$`0``"P`L`````!(`$@``!&)P
MR4FKE4K=K?.VGO=-6J((VEB:RY"EU;HH@U`/.(XM28()AN"@0!Q@>B1@4$`L
M&'<2G&UZ$U`TM=-A*P@``D^2J[4]#+Z`,"DJF+H_`X1\0*BK*P(Y0E`GW"E2
M5#8CA(44$0`[````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?86)O=70N
M9VEF```````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#$R-R`Q,#4Q-30S,S<T-"`P,C8Q-C4`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````1TE&
M.#EA$@`2`(`!`````/___R'Y!`$```$`+``````2`!(```(NC(^)P.T/3%1T
M3IJL8EON>VA8YBT<&8"2FI9FUV:L^*+S[(9X/(9Y;X$(3SU*`0`[````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E
M<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7VQI<W1?8G5L;&5T+F=I9@``
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`Q,C`@,3`U,34T,S,W-#0@,#(W,S8V`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````$=)1C@Y81(`$@"1`@``
M`(0```#___\````A^00!```"`"P`````$@`2```"(92/J<L&W]0#)MA[T8R\
M^[1](49JT(>FX.F-9':$ZDQS!0`[````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT
M;6QA<F5A+VEM86=E<R]E9%]C;VQO<E]F9RYG:68`````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M,C4S(#$P-3$U-#,S-S0T(#`R-C8T-0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!'248X.6$2`!(`LPH``(0``'L`A(2$>WM[
M_P#_`/___P``__\```#_````____````````````````````(?D$`0``"@`L
M`````!(`$@``!%A0R4DK33AK*]/$'Z=X'3F*EXFFJP4.<!R[WF#<0Z$/M&+?
M`EV!5WD)!#`DDC+0"`Y000`0('(&T,.`"K!:!D>P4H`:(,X#@MI;$9P1`C6!
MS12#[ZV\7A$!`#L`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G
M97,O961?86QI9VY?<FEG:'0N9VEF````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#$P-"`Q,#4Q-30S
M,S<T-"`P,C<S,S4`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````1TE&.#EA$@`2`(`!`````/___R'Y!`$```$`+``````2`!(`
M``(;C(^IR^T!HISSV4/I;;F#;7D1N(@:R8GHRK8%`#L`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7V9O<FUA
M=%]U;F1E<FQI;F4N9VEF````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`Q,C4@,3`U,34T,S,W-#0@,#,P-#`V
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````$=)
M1C@Y81(`$@"1`@![>WL```#___\````A^00!```"`"P`````$@`2```")I2/
MJ<OM_X(,8M(F3W:[7OQU3"<NY#>&J!D``E"R$T0CUEWG.ET``#L`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC
M97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]F=6QL<V-R965N7VUA>&EM:7IE
M+F=I9@```````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P,30Q(#$P-3$U-#,S-S0T(#`S,#0T-``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!'248X.6$2`!(`@`$`
M````____(?D$`0```0`L`````!(`$@```CB,CZD&[=\46&>F"5VP<&?,5)?&
MB=6SA:J'@:FJ>:^5QG)YTO=J7W#TB=2$"%V(6)105KF@<;DL```[````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H
M=&UL87)E82]I;6%G97,O961?<FUF;W)M870N9VEF````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,#$V-B`Q,#4Q-30S,S<T-"`P,C8W,#4`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````1TE&.#EA$@`2`/(%`````!D``&9F9LS,
MS/___P```````````"'Y!`$```4`+``````2`!(```,[6+K<_C#*29<`&`@A
MP2#?,`"1!YX79(:$1CKKJ6TP^\TO$]];;GDB$>X!#(Y21*/0U[AD,)R*=$I=
M)```.P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA
M9V5S+V5D7V%L:6=N7V-E;G1E<BYG:68`````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`Q,#4@,3`U,34T
M,S,W-#0@,#(W-3`Q`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````$=)1C@Y81(`$@"``0````#___\A^00!```!`"P`````$@`2
M```"'(R/J<OM`:*<\UE(ZW6Y@\UY'\B(%%F*Z,JV1@$`.P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]C;W!Y
M+F=I9@```````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,34V(#$P-3$U-#,S-S0T(#`R-C`R
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!'
M248X.6$2`!(`D0,```"`````________(?D$`0```P`L`````!(`$@```C^<
MCZG+%@_;":**)P>U-,C>`>*H;!9@"6("/NBI(F:%/BKI7-";QGE:@U``$V&`
M!VP$(;X%\J0<28F9JO6**```.P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I
M8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?;&ES=%]N=6TN9VEF````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,#$R,B`Q,#4Q-30S,S<T-"`P,C8W,#``(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````1TE&.#EA$@`2`)$"
M````A````/___P```"'Y!`$```(`+``````2`!(```(CE(^IRPB]P#.A6ILF
M=')[V'T.=5V9:$@:BJJL5IJG&+*V6```.P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O
M:'1M;&%R96$O:6UA9V5S+V5D7W-P;&ET8V5L+F=I9@``````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#`R,3<@,3`U,34T,S,W-#0@,#(V-C<R`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````$=)1C@Y81<`%@"B!````(``______\`
M``#___\````````````A^00!```$`"P`````%P`6```#5$BZW/XPRDFKG2/K
MS<<;@@"&X4AZSFB69/EU</:5@1``]9VCC6H+@%^PQF.H`,BD$E!<;(10XDR4
MP]FL@:;BN%QJ":JJV/;UU8;`7SD&N[C?\'@E`0`[````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+V1I
M86QO9RYJ<P``````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`T-3<T(#$P-3$U
M-#,S-S0T(#`R-#(U-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````O+R!H=&UL07)E82!V,RXP("T@0V]P>7)I9VAT("AC*2`R
M,#`S+3(P,#4@9'EN87)C:"YC;VT*+R\@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@,C`P,BTR,#`S(&EN=&5R86-T:79E=&]O;',N8V]M+"!I;F,N
M"B\O(%1H:7,@8V]P>7)I9VAT(&YO=&EC92!-55-4('-T87D@:6YT86-T(&9O
M<B!U<V4@*'-E92!L:6-E;G-E+G1X="DN"B\O"B\O(%!O<G1I;VYS("AC*2!D
M>6YA<F-H+F-O;2P@,C`P,RTR,#`T"B\O"B\O($$@9G)E92!765-)5UE'(&5D
M:71O<B!R97!L86-E;65N="!F;W(@/'1E>'1A<F5A/B!F:65L9',N"B\O($9O
M<B!F=6QL('-O=7)C92!C;V1E(&%N9"!D;V-S+"!V:7-I="!H='1P.B\O=W=W
M+FEN=&5R86-T:79E=&]O;',N8V]M+PHO+PHO+R!697)S:6]N(#,N,"!D979E
M;&]P960@8GD@36EH86D@0F%Z;VXN"B\O("`@:'1T<#HO+V1Y;F%R8V@N8V]M
M+VUI<VAO;PHO+PHO+R`D260Z(&1I86QO9RYJ<RQV(#$N-R`R,#`U+S`Q+S(P
M(#$W.C0Y.C`T(&UI<VAO;R!%>'`@)`H*+R\@5&AO=6=H(")$:6%L;V<B(&QO
M;VMS(&QI:V4@86X@;V)J96-T+"!I="!I<VXG="!R96%L;'D@86X@;V)J96-T
M+B`@26YS=&5A9`HO+R!I="=S(&IU<W0@;F%M97-P86-E(&9O<B!P<F]T96-T
M:6YG(&=L;V)A;"!S>6UB;VQS+@H*9G5N8W1I;VX@1&EA;&]G*'5R;"P@86-T
M:6]N+"!I;FET*2!["@EI9B`H='EP96]F(&EN:70@/3T@(G5N9&5F:6YE9"(I
M('L*"0EI;FET(#T@=VEN9&]W.PDO+R!P87-S('1H:7,@=VEN9&]W(&]B:F5C
M="!B>2!D969A=6QT"@E]"@E$:6%L;V<N7V=E8VMO3W!E;DUO9&%L*'5R;"P@
M86-T:6]N+"!I;FET*3L*?3L*"D1I86QO9RY?<&%R96YT179E;G0@/2!F=6YC
M=&EO;BAE=BD@>PH)<V5T5&EM96]U="@@9G5N8W1I;VXH*2![(&EF("A$:6%L
M;V<N7VUO9&%L("8F("%$:6%L;V<N7VUO9&%L+F-L;W-E9"D@>R!$:6%L;V<N
M7VUO9&%L+F9O8W5S*"D@?2!]+"`U,"D["@EI9B`H1&EA;&]G+E]M;V1A;"`F
M)B`A1&EA;&]G+E]M;V1A;"YC;&]S960I('L*"0E(5$U,07)E82Y?<W1O<$5V
M96YT*&5V*3L*"7T*?3L*"@HO+R!S:&]U;&0@8F4@82!F=6YC=&EO;BP@=&AE
M(')E='5R;B!H86YD;&5R(&]F('1H92!C=7)R96YT;'D@;W!E;F5D(&1I86QO
M9RX*1&EA;&]G+E]R971U<FX@/2!N=6QL.PH*+R\@8V]N<W1A;G0L('1H92!C
M=7)R96YT;'D@;W!E;F5D(&1I86QO9PI$:6%L;V<N7VUO9&%L(#T@;G5L;#L*
M"B\O('1H92!D:6%L;V<@=VEL;"!R96%D(&ET)W,@87)G<R!F<F]M('1H:7,@
M=F%R:6%B;&4*1&EA;&]G+E]A<F=U;65N=',@/2!N=6QL.PH*1&EA;&]G+E]G
M96-K;T]P96Y-;V1A;"`](&9U;F-T:6]N*'5R;"P@86-T:6]N+"!I;FET*2![
M"@EV87(@9&QG(#T@=VEN9&]W+F]P96XH=7)L+"`B:&%D:6%L;V<B+`H)"0D@
M("`@("`B=&]O;&)A<CUN;RQM96YU8F%R/6YO+'!E<G-O;F%L8F%R/6YO+'=I
M9'1H/3$P+&AE:6=H=#TQ,"PB("L*"0D)("`@("`@(G-C<F]L;&)A<G,];F\L
M<F5S:7IA8FQE/7EE<RQM;V1A;#UY97,L9&5P96YD86)L93UY97,B*3L*"41I
M86QO9RY?;6]D86P@/2!D;&<["@E$:6%L;V<N7V%R9W5M96YT<R`](&EN:70[
M"@H)+R\@8V%P='5R92!S;VUE('=I;F1O=R=S(&5V96YT<PH)9G5N8W1I;VX@
M8V%P=VEN*'<I('L*"0E(5$U,07)E82Y?861D179E;G0H=RP@(F-L:6-K(BP@
M1&EA;&]G+E]P87)E;G1%=F5N="D["@D)2%1-3$%R96$N7V%D9$5V96YT*'<L
M(")M;W5S961O=VXB+"!$:6%L;V<N7W!A<F5N=$5V96YT*3L*"0E(5$U,07)E
M82Y?861D179E;G0H=RP@(F9O8W5S(BP@1&EA;&]G+E]P87)E;G1%=F5N="D[
M"@E].PH)+R\@<F5L96%S92!T:&4@8V%P='5R960@979E;G1S"@EF=6YC=&EO
M;B!R96QW:6XH=RD@>PH)"4A434Q!<F5A+E]R96UO=F5%=F5N="AW+"`B8VQI
M8VLB+"!$:6%L;V<N7W!A<F5N=$5V96YT*3L*"0E(5$U,07)E82Y?<F5M;W9E
M179E;G0H=RP@(FUO=7-E9&]W;B(L($1I86QO9RY?<&%R96YT179E;G0I.PH)
M"4A434Q!<F5A+E]R96UO=F5%=F5N="AW+"`B9F]C=7,B+"!$:6%L;V<N7W!A
M<F5N=$5V96YT*3L*"7T["@EC87!W:6XH=VEN9&]W*3L*"2\O(&-A<'1U<F4@
M;W1H97(@9G)A;65S"@EF;W(@*'9A<B!I(#T@,#L@:2`\('=I;F1O=RYF<F%M
M97,N;&5N9W1H.R!C87!W:6XH=VEN9&]W+F9R86UE<UMI*RM=*2D["@DO+R!M
M86ME('5P(&$@9G5N8W1I;VX@=&\@8F4@8V%L;&5D('=H96X@=&AE($1I86QO
M9R!E;F1S+@H)1&EA;&]G+E]R971U<FX@/2!F=6YC=&EO;B`H=F%L*2!["@D)
M:68@*'9A;"`F)B!A8W1I;VXI('L*"0D)86-T:6]N*'9A;"D["@D)?0H)"7)E
M;'=I;BAW:6YD;W<I.PH)"2\O(&-A<'1U<F4@;W1H97(@9G)A;65S"@D)9F]R
M("AV87(@:2`](#`[(&D@/"!W:6YD;W<N9G)A;65S+FQE;F=T:#L@<F5L=VEN
M*'=I;F1O=RYF<F%M97-;:2LK72DI.PH)"41I86QO9RY?;6]D86P@/2!N=6QL
M.PH)?3L*?3L*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R
M+VAT;6QA<F5A+W!O<'5P=VEN+FIS````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`W,S4S(#$P-3$U-#,S-S0T(#`R-#8W-@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````O+R`H8RD@9'EN87)C:"YC;VT@,C`P
M,RTR,#`U"B\O($1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE('1E<FUS(&%S
M($A434Q!<F5A(&ET<V5L9BX*"F9U;F-T:6]N(%!O<'5P5VEN*&5D:71O<BP@
M=&ET;&4L(&AA;F1L97(L(&EN:71&=6YC=&EO;BD@>PH)=&AI<RYE9&ET;W(@
M/2!E9&ET;W(["@ET:&ES+FAA;F1L97(@/2!H86YD;&5R.PH)=F%R(&1L9R`]
M('=I;F1O=RYO<&5N*"(B+"`B7U]H85]D:6%L;V<B+`H)"0D@("`@("`B=&]O
M;&)A<CUN;RQM96YU8F%R/6YO+'!E<G-O;F%L8F%R/6YO+'=I9'1H/38P,"QH
M96EG:'0]-C`P+&QE9G0],C`L=&]P/30P(B`K"@D)"2`@("`@(")S8W)O;&QB
M87)S/6YO+')E<VEZ86)L93UN;R(I.PH)=&AI<RYW:6YD;W<@/2!D;&<["@EV
M87(@9&]C(#T@9&QG+F1O8W5M96YT.PH)=&AI<RYD;V,@/2!D;V,["@EV87(@
M<V5L9B`]('1H:7,["@H)=F%R(&)A<V4@/2!D;V-U;65N="YB87-E55))('Q\
M(&1O8W5M96YT+E523#L*"6EF("AB87-E("8F(&)A<V4N;6%T8V@H+R@N*BE<
M+RA;7EPO72LI+RDI('L*"0EB87-E(#T@4F5G17AP+B0Q("L@(B\B.PH)?0H)
M:68@*'1Y<&5O9B!?961I=&]R7W5R;"`A/2`B=6YD969I;F5D(B`F)B`A+UY<
M+R\N=&5S="A?961I=&]R7W5R;"D@)B8@(2]H='1P.EPO7"\O+G1E<W0H7V5D
M:71O<E]U<FPI*2!["@D)+R\@7V5D:71O<E]U<FP@9&]E<VXG="!S=&%R="!W
M:71H("<O)R!W:&EC:"!M96%N<R!I="=S(')E;&%T:79E"@D)+R\@1DE8344Z
M('1H97)E)W,@82!P<F]B;&5M(&AE<F4L(&ET(&-O=6QD(&)E(&AT='`Z+R\@
M=VAI8V@*"0DO+R!D;V5S;B=T('-T87)T('=I=&@@<VQA<V@@8G5T(&ET)W,@
M;F]T(')E;&%T:79E(&5I=&AE<BX*"0EB87-E("L](%]E9&ET;W)?=7)L.PH)
M?2!E;'-E"@D)8F%S92`](%]E9&ET;W)?=7)L.PH):68@*"$O7"\D+RYT97-T
M*&)A<V4I*2!["@D)+R\@8F%S92!D;V5S(&YO="!E;F0@:6X@<VQA<V@L(&%D
M9"!I="!N;W<*"0EB87-E("L]("<O)SL*"7T*"71H:7,N8F%S95523"`](&)A
M<V4["@H)9&]C+F]P96XH*3L*"79A<B!H=&UL(#T@(CQH=&UL/CQH96%D/CQT
M:71L93XB("L@=&ET;&4@*R`B/"]T:71L93Y<;B(["@DO+R!H=&UL("L]("(\
M8F%S92!H<F5F/2<B("L@8F%S92`K(")H=&UL87)E82YJ<R<@+SY<;B(["@EH
M=&UL("L]("(\<W1Y;&4@='EP93TG=&5X="]C<W,G/D!I;7!O<G0@=7)L*"(@
M*R!B87-E("L@(FAT;6QA<F5A+F-S<RD[/"]S='EL93X\+VAE860^7&XB.PH)
M:'1M;"`K/2`B/&)O9'D@8VQA<W,])V1I86QO9R!P;W!U<'=I;B<@:60])RTM
M2$$M8F]D>2<^/"]B;V1Y/CPO:'1M;#XB.PH)9&]C+G=R:71E*&AT;6PI.PH)
M9&]C+F-L;W-E*"D["@H)+R\@<V]M971I;65S($D@2&%T92!-;WII;&QA+BXN
M(#LM*`H)9G5N8W1I;VX@:6YI=#(H*2!["@D)=F%R(&)O9'D@/2!D;V,N8F]D
M>3L*"0EI9B`H(6)O9'DI('L*"0D)<V5T5&EM96]U="AI;FET,BP@,C4I.PH)
M"0ER971U<FX@9F%L<V4["@D)?0H)"61L9RYT:71L92`]('1I=&QE.PH)"61O
M8RYD;V-U;65N=$5L96UE;G0N<W1Y;&4N<&%D9&EN9R`]("(P<'@B.PH)"61O
M8RYD;V-U;65N=$5L96UE;G0N<W1Y;&4N;6%R9VEN(#T@(C!P>"(["@D)=F%R
M(&-O;G1E;G0@/2!D;V,N8W)E871E16QE;65N="@B9&EV(BD["@D)8V]N=&5N
M="YC;&%S<TYA;64@/2`B8V]N=&5N="(["@D)<V5L9BYC;VYT96YT(#T@8V]N
M=&5N=#L*"0EB;V1Y+F%P<&5N9$-H:6QD*&-O;G1E;G0I.PH)"7-E;&8N96QE
M;65N="`](&)O9'D["@D):6YI=$9U;F-T:6]N*'-E;&8I.PH)"61L9RYF;V-U
M<R@I.PH)?3L*"6EN:70R*"D["GT["@I0;W!U<%=I;BYP<F]T;W1Y<&4N8V%L
M;$AA;F1L97(@/2!F=6YC=&EO;B@I('L*"79A<B!T86=S(#T@6R)I;G!U="(L
M(")T97AT87)E82(L(")S96QE8W0B73L*"79A<B!P87)A;7,@/2!N97<@3V)J
M96-T*"D["@EF;W(@*'9A<B!T:2`]('1A9W,N;&5N9W1H.R`M+71I(#X](#`[
M*2!["@D)=F%R('1A9R`]('1A9W-;=&E=.PH)"79A<B!E;',@/2!T:&ES+F-O
M;G1E;G0N9V5T16QE;65N='-">51A9TYA;64H=&%G*3L*"0EF;W(@*'9A<B!J
M(#T@,#L@:B`\(&5L<RYL96YG=&@[("LK:BD@>PH)"0EV87(@96P@/2!E;'-;
M:ET["@D)"79A<B!V86P@/2!E;"YV86QU93L*"0D):68@*&5L+G1A9TYA;64N
M=&],;W=E<D-A<V4H*2`]/2`B:6YP=70B*2!["@D)"0EI9B`H96PN='EP92`]
M/2`B8VAE8VMB;W@B*2!["@D)"0D)=F%L(#T@96PN8VAE8VME9#L*"0D)"7T*
M"0D)?0H)"0EP87)A;7-;96PN;F%M95T@/2!V86P["@D)?0H)?0H)=&AI<RYH
M86YD;&5R*'1H:7,L('!A<F%M<RD["@ER971U<FX@9F%L<V4["GT["@I0;W!U
M<%=I;BYP<F]T;W1Y<&4N8VQO<V4@/2!F=6YC=&EO;B@I('L*"71H:7,N=VEN
M9&]W+F-L;W-E*"D["GT["@I0;W!U<%=I;BYP<F]T;W1Y<&4N861D0G5T=&]N
M<R`](&9U;F-T:6]N*"D@>PH)=F%R('-E;&8@/2!T:&ES.PH)=F%R(&1I=B`]
M('1H:7,N9&]C+F-R96%T945L96UE;G0H(F1I=B(I.PH)=&AI<RYC;VYT96YT
M+F%P<&5N9$-H:6QD*&1I=BD["@ED:78N8VQA<W-.86UE(#T@(F)U='1O;G,B
M.PH)9F]R("AV87(@:2`](#`[(&D@/"!A<F=U;65N=',N;&5N9W1H.R`K*VDI
M('L*"0EV87(@8G1N(#T@87)G=6UE;G1S6VE=.PH)"79A<B!B=71T;VX@/2!T
M:&ES+F1O8RYC<F5A=&5%;&5M96YT*")B=71T;VXB*3L*"0ED:78N87!P96YD
M0VAI;&0H8G5T=&]N*3L*"0EB=71T;VXN:6YN97)(5$U,(#T@2%1-3$%R96$N
M23$X3BYB=71T;VYS6V)T;ET["@D)<W=I=&-H("AB=&XI('L*"0D@("`@8V%S
M92`B;VLB.@H)"0EB=71T;VXN;VYC;&EC:R`](&9U;F-T:6]N*"D@>PH)"0D)
M<V5L9BYC86QL2&%N9&QE<B@I.PH)"0D)<V5L9BYC;&]S92@I.PH)"0D)<F5T
M=7)N(&9A;'-E.PH)"0E].PH)"0EB<F5A:SL*"0D@("`@8V%S92`B8V%N8V5L
M(CH*"0D)8G5T=&]N+F]N8VQI8VL@/2!F=6YC=&EO;B@I('L*"0D)"7-E;&8N
M8VQO<V4H*3L*"0D)"7)E='5R;B!F86QS93L*"0D)?3L*"0D)8G)E86L["@D)
M?0H)?0I].PH*4&]P=7!7:6XN<')O=&]T>7!E+G-H;W=!=$5L96UE;G0@/2!F
M=6YC=&EO;B@I('L*"79A<B!S96QF(#T@=&AI<SL*"2\O($UO>FEL;&$@;F5E
M9',@<V]M92!T:6UE('1O(')E86QI>F4@=VAA="=S(&=O:6XG(&]N+BX*"7-E
M=%1I;65O=70H9G5N8W1I;VXH*2!["@D)=F%R('<@/2!S96QF+F-O;G1E;G0N
M;V9F<V5T5VED=&@@*R`T.PH)"79A<B!H(#T@<V5L9BYC;VYT96YT+F]F9G-E
M=$AE:6=H="`K(#0["@D)+R\@<VEZ92!T;R!C;VYT96YT("TM('1H870G<R!F
M=6-K:6XG(&)U9V=Y(&EN(&%L;"!F=6-K:6XG(&)R;W=S97)S(2$A"@D)+R\@
M<V\@=&AA="!W92!S970@82!L87)G97(@<VEZ92!F;W(@=&AE(&1I86QO9R!W
M:6YD;W<@86YD('1H96X@8V5N=&5R"@D)+R\@=&AE(&5L96UE;G0@:6YS:61E
M+BXN('!H=6-K(0H*"0DO+R!C96YT97(N+BX*"0EV87(@96P@/2!S96QF+F-O
M;G1E;G0["@D)=F%R(',@/2!E;"YS='EL93L*"0DO+R!S+G=I9'1H(#T@96PN
M;V9F<V5T5VED=&@@*R`B<'@B.PH)"2\O(',N:&5I9VAT(#T@96PN;V9F<V5T
M2&5I9VAT("L@(G!X(CL*"0ES+G!O<VET:6]N(#T@(F%B<V]L=71E(CL*"0ES
M+FQE9G0@/2`H=R`M(&5L+F]F9G-E=%=I9'1H*2`O(#(@*R`B<'@B.PH)"7,N
M=&]P(#T@*&@@+2!E;"YO9F9S971(96EG:'0I("\@,B`K(")P>"(["@D):68@
M*$A434Q!<F5A+FES7V=E8VMO*2!["@D)"7-E;&8N=VEN9&]W+FEN;F5R5VED
M=&@@/2!W.PH)"0ES96QF+G=I;F1O=RYI;FYE<DAE:6=H="`](&@["@D)?2!E
M;'-E('L*"0D)<V5L9BYW:6YD;W<N<F5S:7IE5&\H=R`K(#@L(&@@*R`S-2D[
M"@D)?0H)?2P@,C4I.PI].PH`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!O<'5P9&EV+FIS````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#(R-C<V(#$P-3$U-#,S-S0T(#`R-#8W,``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````O*BH@
M5&AI<R!F:6QE(&ES(&1E<FEV960@9G)O;2!0;W!U<$1I=BP@9&5V96QO<&5D
M(&)Y($UI:&%I($)A>F]N(&9O<@H@*B!386U787)E+FYE="X@($UO9&EF:6-A
M=&EO;G,@=V5R92!N965D960@=&\@;6%K92!I="!U<V%B;&4@:6X@2%1-3$%R
M96$N"B`J($A434Q!<F5A(&ES(&$@9G)E92!765-)5UE'(&]N;&EN92!(5$U,
M(&5D:71O<B!F<F]M($EN=&5R86-T:79E5&]O;',N8V]M+@H@*@H@*B!4:&ES
M(&9I;&4@9&]E<R!N;W0@9G5N8W1I;VX@<W1A;F1A;&]N92X@($ET(&ES(&1E
M<&5N9&5N="!O9B!G;&]B86P@9G5N8W1I;VYS"B`J(&1E9FEN960@:6X@2%1-
M3$%R96$M,RXP("AH=&UL87)E82YJ<RDN"B`J"B`J(%!L96%S92!S964@9FEL
M92!H=&UL87)E82YJ<R!F;W(@9G5R=&AE<B!D971A:6QS+@H@*BHO"@IV87(@
M:7-?:64@/2`H("AN879I9V%T;W(N=7-E<D%G96YT+G1O3&]W97)#87-E*"DN
M:6YD97A/9B@B;7-I92(I("$]("TQ*2`F)@H)("`@("`@*&YA=FEG871O<BYU
M<V5R06=E;G0N=&],;W=E<D-A<V4H*2YI;F1E>$]F*")O<&5R82(I(#T]("TQ
M*2`I.PIV87(@:7-?8V]M<&%T(#T@*&1O8W5M96YT+F-O;7!A=$UO9&4@/3T@
M(D)A8VM#;VUP870B*3L*"F9U;F-T:6]N(%!O<'5P1&EV*&5D:71O<BP@=&ET
M;&5497AT+"!H86YD;&5R+"!I;FET1G5N8W1I;VXI('L*"79A<B!S96QF(#T@
M=&AI<SL*"@ET:&ES+F5D:71O<B`](&5D:71O<CL*"71H:7,N9&]C(#T@961I
M=&]R+E]M9&]C.PH)=&AI<RYH86YD;&5R(#T@:&%N9&QE<CL*"@EV87(@96P@
M/2!T:&ES+F1O8RYC<F5A=&5%;&5M96YT*")D:78B*3L*"65L+F-L87-S3F%M
M92`](")C;VYT96YT(CL*"@EV87(@<&]P=7`@/2!T:&ES+F1O8RYC<F5A=&5%
M;&5M96YT*")D:78B*3L*"7!O<'5P+F-L87-S3F%M92`](")D:6%L;V<@<&]P
M=7!D:78B.PH)=&AI<RYE;&5M96YT(#T@<&]P=7`["@EV87(@<R`]('!O<'5P
M+G-T>6QE.PH)<RYP;W-I=&EO;B`](")A8G-O;'5T92(["@ES+FQE9G0@/2`B
M,'!X(CL*"7,N=&]P(#T@(C!P>"(["@H)=F%R('1I=&QE(#T@=&AI<RYD;V,N
M8W)E871E16QE;65N="@B9&EV(BD["@ET:71L92YC;&%S<TYA;64@/2`B=&ET
M;&4B.PH)=&AI<RYT:71L92`]('1I=&QE.PH)<&]P=7`N87!P96YD0VAI;&0H
M=&ET;&4I.PH*"4A434Q!<F5A+E]A9&1%=F5N="AT:71L92P@(FUO=7-E9&]W
M;B(L(&9U;F-T:6]N*&5V*2!["@D)<V5L9BY?9')A9U-T87)T*&ES7VEE(#\@
M=VEN9&]W+F5V96YT(#H@978I.PH)?2D["@H)=F%R(&)U='1O;B`]('1H:7,N
M9&]C+F-R96%T945L96UE;G0H(F1I=B(I.PH)8G5T=&]N+F-L87-S3F%M92`]
M(")B=71T;VXB.PH)=&ET;&4N87!P96YD0VAI;&0H8G5T=&]N*3L*"6)U='1O
M;BYI;FYE<DA434P@/2`B)B-X,#!D-SLB.PH)=&ET;&4N87!P96YD0VAI;&0H
M=&AI<RYD;V,N8W)E871E5&5X=$YO9&4H=&ET;&5497AT*2D["@ET:&ES+G1I
M=&QE5&5X="`]('1I=&QE5&5X=#L*"@EB=71T;VXN;VYM;W5S96]V97(@/2!F
M=6YC=&EO;B@I('L*"0ET:&ES+F-L87-S3F%M92`K/2`B(&)U='1O;BUH:6QI
M=&4B.PH)?3L*"6)U='1O;BYO;FUO=7-E;W5T(#T@9G5N8W1I;VXH*2!["@D)
M=&AI<RYC;&%S<TYA;64@/2!T:&ES+F-L87-S3F%M92YR97!L86-E*"]<<RIB
M=71T;VXM:&EL:71E7',J+V<L("(@(BD["@E].PH)8G5T=&]N+F]N8VQI8VL@
M/2!F=6YC=&EO;B@I('L*"0ET:&ES+F-L87-S3F%M92`]('1H:7,N8VQA<W-.
M86UE+G)E<&QA8V4H+UQS*F)U='1O;BUH:6QI=&5<<RHO9RP@(B`B*3L*"0ES
M96QF+F-L;W-E*"D["@E].PH*"7!O<'5P+F%P<&5N9$-H:6QD*&5L*3L*"71H
M:7,N8V]N=&5N="`](&5L.PH*"71H:7,N9&]C+F)O9'DN87!P96YD0VAI;&0H
M<&]P=7`I.PH*"71H:7,N9')A9V=I;F<@/2!F86QS93L*"71H:7,N;VY3:&]W
M(#T@;G5L;#L*"71H:7,N;VY#;&]S92`](&YU;&P["@ET:&ES+FUO9&%L(#T@
M9F%L<V4["@H):6YI=$9U;F-T:6]N*'1H:7,I.PI].PH*4&]P=7!$:78N8W5R
M<F5N=%!O<'5P(#T@;G5L;#L*"E!O<'5P1&EV+G!R;W1O='EP92YS:&]W071%
M;&5M96YT(#T@9G5N8W1I;VXH96PL(&UO9&4I('L*"71H:7,N9&5F875L=%-I
M>F4H*3L*"79A<B!P;W,L(&5W+"!E:#L*"79A<B!P;W!U<"`]('1H:7,N96QE
M;65N=#L*"7!O<'5P+G-T>6QE+F1I<W!L87D@/2`B8FQO8VLB.PH)=F%R('<@
M/2!P;W!U<"YO9F9S9717:61T:#L*"79A<B!H(#T@<&]P=7`N;V9F<V5T2&5I
M9VAT.PH)<&]P=7`N<W1Y;&4N9&ES<&QA>2`](")N;VYE(CL*"6EF("AE;"`A
M/2!W:6YD;W<I('L*"0EP;W,@/2!0;W!U<$1I=BYG971!8G-O;'5T95!O<RAE
M;"D["@D)97<@/2!E;"YO9F9S9717:61T:#L*"0EE:"`](&5L+F]F9G-E=$AE
M:6=H=#L*"7T@96QS92!["@D)<&]S(#T@>W@Z,"P@>3HP?3L*"0EV87(@<VEZ
M92`](%!O<'5P1&EV+F=E=%=I;F1O=U-I>F4H*3L*"0EE=R`]('-I>F4N>#L*
M"0EE:"`]('-I>F4N>3L*"7T*"79A<B!&6"`](&9A;'-E+"!&62`](&9A;'-E
M.PH):68@*&UO9&4N:6YD97A/9B@B;"(I("$]("TQ*2!["@D)<&]S+G@@+3T@
M=SL*"0E&6"`]('1R=64["@E]"@EI9B`H;6]D92YI;F1E>$]F*")R(BD@(3T@
M+3$I('L*"0EP;W,N>"`K/2!E=SL*"0E&6"`]('1R=64["@E]"@EI9B`H;6]D
M92YI;F1E>$]F*")T(BD@(3T@+3$I('L*"0EP;W,N>2`M/2!H.PH)"499(#T@
M=')U93L*"7T*"6EF("AM;V1E+FEN9&5X3V8H(F(B*2`A/2`M,2D@>PH)"7!O
M<RYY("L](&5H.PH)"499(#T@=')U93L*"7T*"6EF("AM;V1E+FEN9&5X3V8H
M(F,B*2`A/2`M,2D@>PH)"498('Q\("AP;W,N>"`K/2!-871H+G)O=6YD*"AE
M=R`M('<I("\@,BDI.PH)"499('Q\("AP;W,N>2`K/2!-871H+G)O=6YD*"AE
M:"`M(&@I("\@,BDI.PH)?0H)=&AI<RYS:&]W070H<&]S+G@L('!O<RYY*3L*
M?3L*"E!O<'5P1&EV+G!R;W1O='EP92YD969A=6QT4VEZ92`](&9U;F-T:6]N
M*"D@>PH)=F%R(',@/2!T:&ES+F5L96UE;G0N<W1Y;&4["@EV87(@8W,@/2!T
M:&ES+F5L96UE;G0N8W5R<F5N=%-T>6QE.PH)=F%R(&%D9%@@/2`H:7-?:64@
M)B8@:7-?8V]M<&%T*2`_("AP87)S94EN="AC<RYB;W)D97),969T5VED=&@I
M("L*"0D)"0D@("!P87)S94EN="AC<RYB;W)D97)2:6=H=%=I9'1H*2`K"@D)
M"0D)("`@<&%R<V5);G0H8W,N<&%D9&EN9TQE9G0I("L*"0D)"0D@("!P87)S
M94EN="AC<RYP861D:6YG4FEG:'0I*2`Z(#`["@EV87(@861D62`]("AI<U]I
M92`F)B!I<U]C;VUP870I(#\@*'!A<G-E26YT*&-S+F)O<F1E<E1O<%=I9'1H
M*2`K"@D)"0D)("`@<&%R<V5);G0H8W,N8F]R9&5R0F]T=&]M5VED=&@I("L*
M"0D)"0D@("!P87)S94EN="AC<RYP861D:6YG5&]P*2`K"@D)"0D)("`@<&%R
M<V5);G0H8W,N<&%D9&EN9T)O='1O;2DI(#H@,#L*"7,N9&ES<&QA>2`](")B
M;&]C:R(["@ES+G=I9'1H(#T@*'1H:7,N8V]N=&5N="YO9F9S9717:61T:"`K
M(&%D9%@I("L@(G!X(CL*"7,N:&5I9VAT(#T@*'1H:7,N8V]N=&5N="YO9F9S
M971(96EG:'0@*R!T:&ES+G1I=&QE+F]F9G-E=$AE:6=H="D@*R`B<'@B.PH)
M<RYD:7-P;&%Y(#T@(FYO;F4B.PI].PH*4&]P=7!$:78N<')O=&]T>7!E+G-H
M;W=!="`](&9U;F-T:6]N*'@L('DI('L*"71H:7,N9&5F875L=%-I>F4H*3L*
M"79A<B!S(#T@=&AI<RYE;&5M96YT+G-T>6QE.PH)<RYD:7-P;&%Y(#T@(F)L
M;V-K(CL*"7,N;&5F="`]('@@*R`B<'@B.PH)<RYT;W`@/2!Y("L@(G!X(CL*
M"71H:7,N:&ED95-H;W=#;W9E<F5D*"D["@H)4&]P=7!$:78N8W5R<F5N=%!O
M<'5P(#T@=&AI<SL*"4A434Q!<F5A+E]A9&1%=F5N=',H=&AI<RYD;V,N8F]D
M>2P@6R)M;W5S961O=VXB+"`B8VQI8VLB72P@4&]P=7!$:78N8VAE8VM0;W!U
M<"D["@E(5$U,07)E82Y?861D179E;G1S*'1H:7,N961I=&]R+E]D;V,N8F]D
M>2P@6R)M;W5S961O=VXB+"`B8VQI8VLB72P@4&]P=7!$:78N8VAE8VM0;W!U
M<"D["@EI9B`H:7-?:64@)B8@=&AI<RYM;V1A;"D@>PH)"71H:7,N9&]C+F)O
M9'DN<V5T0V%P='5R92AF86QS92D["@D)=&AI<RYD;V,N8F]D>2YO;FQO<V5C
M87!T=7)E(#T@9G5N8W1I;VXH*2!["@D)"2A0;W!U<$1I=BYC=7)R96YT4&]P
M=7`I("8F("AT:&ES+F1O8RYB;V1Y+G-E=$-A<'1U<F4H9F%L<V4I*3L*"0E]
M.PH)?0H)=VEN9&]W+F5V96YT("8F($A434Q!<F5A+E]S=&]P179E;G0H=VEN
M9&]W+F5V96YT*3L*"@EI9B`H='EP96]F('1H:7,N;VY3:&]W(#T](")F=6YC
M=&EO;B(I('L*"0ET:&ES+F]N4VAO=R@I.PH)?2!E;'-E(&EF("AT>7!E;V8@
M=&AI<RYO;E-H;W<@/3T@(G-T<FEN9R(I('L*"0EE=F%L*'1H:7,N;VY3:&]W
M*3L*"7T*"@EV87(@9FEE;&0@/2!T:&ES+F5L96UE;G0N9V5T16QE;65N='-"
M>51A9TYA;64H(FEN<'5T(BE;,%T["@EI9B`H(69I96QD*2!["@D)9FEE;&0@
M/2!T:&ES+F5L96UE;G0N9V5T16QE;65N='-">51A9TYA;64H(G-E;&5C="(I
M6S!=.PH)?0H):68@*"%F:65L9"D@>PH)"69I96QD(#T@=&AI<RYE;&5M96YT
M+F=E=$5L96UE;G1S0GE486=.86UE*")T97AT87)E82(I6S!=.PH)?0H):68@
M*&9I96QD*2!["@D)9FEE;&0N9F]C=7,H*3L*"7T*?3L*"E!O<'5P1&EV+G!R
M;W1O='EP92YC;&]S92`](&9U;F-T:6]N*"D@>PH)=&AI<RYE;&5M96YT+G-T
M>6QE+F1I<W!L87D@/2`B;F]N92(["@E0;W!U<$1I=BYC=7)R96YT4&]P=7`@
M/2!N=6QL.PH)=&AI<RYH:61E4VAO=T-O=F5R960H*3L*"4A434Q!<F5A+E]R
M96UO=F5%=F5N=',H=&AI<RYD;V,N8F]D>2P@6R)M;W5S961O=VXB+"`B8VQI
M8VLB72P@4&]P=7!$:78N8VAE8VM0;W!U<"D["@E(5$U,07)E82Y?<F5M;W9E
M179E;G1S*'1H:7,N961I=&]R+E]D;V,N8F]D>2P@6R)M;W5S961O=VXB+"`B
M8VQI8VLB72P@4&]P=7!$:78N8VAE8VM0;W!U<"D["@EI<U]I92`F)B!T:&ES
M+FUO9&%L("8F('1H:7,N9&]C+F)O9'DN<F5L96%S94-A<'1U<F4H*3L*"6EF
M("AT>7!E;V8@=&AI<RYO;D-L;W-E(#T](")F=6YC=&EO;B(I('L*"0ET:&ES
M+F]N0VQO<V4H*3L*"7T@96QS92!I9B`H='EP96]F('1H:7,N;VY#;&]S92`]
M/2`B<W1R:6YG(BD@>PH)"65V86PH=&AI<RYO;D-L;W-E*3L*"7T*"71H:7,N
M96QE;65N="YP87)E;G1.;V1E+G)E;6]V94-H:6QD*'1H:7,N96QE;65N="D[
M"GT["@I0;W!U<$1I=BYP<F]T;W1Y<&4N9V5T1F]R;2`](&9U;F-T:6]N*"D@
M>PH)=F%R(&9O<FUS(#T@=&AI<RYC;VYT96YT+F=E=$5L96UE;G1S0GE486=.
M86UE*")F;W)M(BD["@ER971U<FX@*&9O<FUS+FQE;F=T:"`^(#`I(#\@9F]R
M;7-;,%T@.B!N=6QL.PI].PH*4&]P=7!$:78N<')O=&]T>7!E+F-A;&Q(86YD
M;&5R(#T@9G5N8W1I;VXH*2!["@EV87(@=&%G<R`](%LB:6YP=70B+"`B=&5X
M=&%R96$B+"`B<V5L96-T(ET["@EV87(@<&%R86US(#T@;F5W($]B:F5C="@I
M.PH)9F]R("AV87(@=&D@/2!T86=S+FQE;F=T:#L@+2UT:2`^/2`P.RD@>PH)
M"79A<B!T86<@/2!T86=S6W1I73L*"0EV87(@96QS(#T@=&AI<RYC;VYT96YT
M+F=E=$5L96UE;G1S0GE486=.86UE*'1A9RD["@D)9F]R("AV87(@:B`](#`[
M(&H@/"!E;',N;&5N9W1H.R`K*VHI('L*"0D)=F%R(&5L(#T@96QS6VI=.PH)
M"0EP87)A;7-;96PN;F%M95T@/2!E;"YV86QU93L*"0E]"@E]"@ET:&ES+FAA
M;F1L97(H=&AI<RP@<&%R86US*3L*"7)E='5R;B!F86QS93L*?3L*"E!O<'5P
M1&EV+F=E=$%B<V]L=71E4&]S(#T@9G5N8W1I;VXH96PI('L*"79A<B!R(#T@
M>R!X.B!E;"YO9F9S971,969T+"!Y.B!E;"YO9F9S9714;W`@?3L*"6EF("AE
M;"YO9F9S971087)E;G0I('L*"0EV87(@=&UP(#T@4&]P=7!$:78N9V5T06)S
M;VQU=&50;W,H96PN;V9F<V5T4&%R96YT*3L*"0ER+G@@*ST@=&UP+G@["@D)
M<BYY("L]('1M<"YY.PH)?0H)<F5T=7)N('(["GT["@I0;W!U<$1I=BYG9717
M:6YD;W=3:7IE(#T@9G5N8W1I;VXH*2!["@EI9B`H=VEN9&]W+FEN;F5R2&5I
M9VAT*2!["@D)<F5T=7)N('L@>3H@=VEN9&]W+FEN;F5R2&5I9VAT+"!X.B!W
M:6YD;W<N:6YN97)7:61T:"!].PH)?0H):68@*'1H:7,N9&]C+F)O9'DN8VQI
M96YT2&5I9VAT*2!["@D)<F5T=7)N('L@>3H@=&AI<RYD;V,N8F]D>2YC;&EE
M;G1(96EG:'0L('@Z('1H:7,N9&]C+F)O9'DN8VQI96YT5VED=&@@?3L*"7T*
M"7)E='5R;B![('DZ('1H:7,N9&]C+F1O8W5M96YT16QE;65N="YC;&EE;G1(
M96EG:'0L('@Z('1H:7,N9&]C+F1O8W5M96YT16QE;65N="YC;&EE;G17:61T
M:"!].PI].PH*4&]P=7!$:78N<')O=&]T>7!E+FAI9&53:&]W0V]V97)E9"`]
M(&9U;F-T:6]N("@I('L*"79A<B!S96QF(#T@=&AI<SL*"69U;F-T:6]N(&ES
M0V]N=&%I;F5D*&5L*2!["@D)=VAI;&4@*&5L*2!["@D)"6EF("AE;"`]/2!S
M96QF+F5L96UE;G0I('L*"0D)"7)E='5R;B!T<G5E.PH)"0E]"@D)"65L(#T@
M96PN<&%R96YT3F]D93L*"0E]"@D)<F5T=7)N(&9A;'-E.PH)?3L*"79A<B!T
M86=S(#T@;F5W($%R<F%Y*")A<'!L970B+"`B<V5L96-T(BD["@EV87(@96P@
M/2!T:&ES+F5L96UE;G0["@H)=F%R('`@/2!0;W!U<$1I=BYG971!8G-O;'5T
M95!O<RAE;"D["@EV87(@15@Q(#T@<"YX.PH)=F%R($58,B`](&5L+F]F9G-E
M=%=I9'1H("L@15@Q.PH)=F%R($59,2`]('`N>3L*"79A<B!%63(@/2!E;"YO
M9F9S971(96EG:'0@*R!%63$["@H):68@*&5L+G-T>6QE+F1I<W!L87D@/3T@
M(FYO;F4B*2!["@D)15@Q(#T@15@R(#T@15DQ(#T@15DR(#T@,#L*"7T*"@EF
M;W(@*'9A<B!K(#T@=&%G<RYL96YG=&@[(&L@/B`P.R`I('L*"0EV87(@87(@
M/2!T:&ES+F1O8RYG971%;&5M96YT<T)Y5&%G3F%M92AT86=S6RTM:UTI.PH)
M"79A<B!C8R`](&YU;&P["@H)"69O<B`H=F%R(&D@/2!A<BYL96YG=&@[(&D@
M/B`P.RD@>PH)"0EC8R`](&%R6RTM:5T["@D)"6EF("AI<T-O;G1A:6YE9"AC
M8RDI('L*"0D)"6-C+G-T>6QE+G9I<VEB:6QI='D@/2`B=FES:6)L92(["@D)
M"0EC;VYT:6YU93L*"0D)?0H*"0D)<"`](%!O<'5P1&EV+F=E=$%B<V]L=71E
M4&]S*&-C*3L*"0D)=F%R($-8,2`]('`N>#L*"0D)=F%R($-8,B`](&-C+F]F
M9G-E=%=I9'1H("L@0U@Q.PH)"0EV87(@0UDQ(#T@<"YY.PH)"0EV87(@0UDR
M(#T@8V,N;V9F<V5T2&5I9VAT("L@0UDQ.PH*"0D):68@*"A#6#$@/B!%6#(I
M('Q\("A#6#(@/"!%6#$I('Q\("A#63$@/B!%63(I('Q\("A#63(@/"!%63$I
M*2!["@D)"0EC8RYS='EL92YV:7-I8FEL:71Y(#T@(G9I<VEB;&4B.PH)"0E]
M(&5L<V4@>PH)"0D)8V,N<W1Y;&4N=FES:6)I;&ET>2`](")H:61D96XB.PH)
M"0E]"@D)?0H)?0I].PH*4&]P=7!$:78N<')O=&]T>7!E+E]D<F%G4W1A<G0@
M/2!F=6YC=&EO;B`H978I('L*"6EF("AT:&ES+F1R86=G:6YG*2!["@D)<F5T
M=7)N(&9A;'-E.PH)?0H)=&AI<RYD<F%G9VEN9R`]('1R=64["@E0;W!U<$1I
M=BYC=7)R96YT4&]P=7`@/2!T:&ES.PH)=F%R('!O<U@@/2!E=BYC;&EE;G18
M.PH)=F%R('!O<UD@/2!E=BYC;&EE;G19.PH):68@*&ES7VEE*2!["@D)<&]S
M62`K/2!T:&ES+F1O8RYB;V1Y+G-C<F]L;%1O<#L*"0EP;W-8("L]('1H:7,N
M9&]C+F)O9'DN<V-R;VQL3&5F=#L*"7T@96QS92!["@D)<&]S62`K/2!W:6YD
M;W<N<V-R;VQL63L*"0EP;W-8("L]('=I;F1O=RYS8W)O;&Q8.PH)?0H)=F%R
M('-T(#T@=&AI<RYE;&5M96YT+G-T>6QE.PH)=&AI<RYX3V9F<R`]('!O<U@@
M+2!P87)S94EN="AS="YL969T*3L*"71H:7,N>4]F9G,@/2!P;W-9("T@<&%R
M<V5);G0H<W0N=&]P*3L*"4A434Q!<F5A+E]A9&1%=F5N="AT:&ES+F1O8RP@
M(FUO=7-E;6]V92(L(%!O<'5P1&EV+F1R86=)="D["@E(5$U,07)E82Y?861D
M179E;G0H=&AI<RYD;V,L(")M;W5S96]V97(B+"!(5$U,07)E82Y?<W1O<$5V
M96YT*3L*"4A434Q!<F5A+E]A9&1%=F5N="AT:&ES+F1O8RP@(FUO=7-E=7`B
M+"!0;W!U<$1I=BYD<F%G16YD*3L*"4A434Q!<F5A+E]S=&]P179E;G0H978I
M.PI].PH*4&]P=7!$:78N9')A9TET(#T@9G5N8W1I;VX@*&5V*2!["@EV87(@
M<&]P=7`@/2!0;W!U<$1I=BYC=7)R96YT4&]P=7`["@EI9B`H(2AP;W!U<"`F
M)B!P;W!U<"YD<F%G9VEN9RDI('L*"0ER971U<FX@9F%L<V4["@E]"@EI<U]I
M92`F)B`H978@/2!W:6YD;W<N979E;G0I.PH)=F%R('!O<U@@/2!E=BYC;&EE
M;G18.PH)=F%R('!O<UD@/2!E=BYC;&EE;G19.PH):68@*&ES7VEE*2!["@D)
M<&]S62`K/2!T:&ES+F1O8RYB;V1Y+G-C<F]L;%1O<#L*"0EP;W-8("L]('1H
M:7,N9&]C+F)O9'DN<V-R;VQL3&5F=#L*"7T@96QS92!["@D)<&]S62`K/2!W
M:6YD;W<N<V-R;VQL63L*"0EP;W-8("L]('=I;F1O=RYS8W)O;&Q8.PH)?0H)
M<&]P=7`N:&ED95-H;W=#;W9E<F5D*"D["@EV87(@<W0@/2!P;W!U<"YE;&5M
M96YT+G-T>6QE.PH)<W0N;&5F="`]("AP;W-8("T@<&]P=7`N>$]F9G,I("L@
M(G!X(CL*"7-T+G1O<"`]("AP;W-9("T@<&]P=7`N>4]F9G,I("L@(G!X(CL*
M"4A434Q!<F5A+E]S=&]P179E;G0H978I.PI].PH*4&]P=7!$:78N9')A9T5N
M9"`](&9U;F-T:6]N("@I('L*"79A<B!P;W!U<"`](%!O<'5P1&EV+F-U<G)E
M;G10;W!U<#L*"6EF("@A<&]P=7`I('L*"0ER971U<FX@9F%L<V4["@E]"@EP
M;W!U<"YD<F%G9VEN9R`](&9A;'-E.PH)2%1-3$%R96$N7W)E;6]V945V96YT
M*'!O<'5P+F1O8RP@(FUO=7-E=7`B+"!0;W!U<$1I=BYD<F%G16YD*3L*"4A4
M34Q!<F5A+E]R96UO=F5%=F5N="AP;W!U<"YD;V,L(")M;W5S96]V97(B+"!(
M5$U,07)E82Y?<W1O<$5V96YT*3L*"4A434Q!<F5A+E]R96UO=F5%=F5N="AP
M;W!U<"YD;V,L(")M;W5S96UO=F4B+"!0;W!U<$1I=BYD<F%G270I.PH)<&]P
M=7`N:&ED95-H;W=#;W9E<F5D*"D["GT["@I0;W!U<$1I=BYC:&5C:U!O<'5P
M(#T@9G5N8W1I;VX@*&5V*2!["@EI<U]I92`F)B`H978@/2!W:6YD;W<N979E
M;G0I.PH)=F%R(&5L(#T@:7-?:64@/R!E=BYS<F-%;&5M96YT(#H@978N=&%R
M9V5T.PH)=F%R(&-P(#T@4&]P=7!$:78N8W5R<F5N=%!O<'5P.PH)9F]R("@[
M("AE;"`A/2!N=6QL*2`F)B`H96P@(3T@8W`N96QE;65N="D[(&5L(#T@96PN
M<&%R96YT3F]D92D["@EI9B`H96P@/3T@;G5L;"D@>PH)"6-P+FUO9&%L('Q\
M(&5V+G1Y<&4@/3T@(FUO=7-E;W9E<B(@?'P@8W`N8VQO<V4H*3L*"0E(5$U,
M07)E82Y?<W1O<$5V96YT*&5V*3L*"7T*?3L*"E!O<'5P1&EV+G!R;W1O='EP
M92YA9&1"=71T;VYS(#T@9G5N8W1I;VXH*2!["@EV87(@<V5L9B`]('1H:7,[
M"@EV87(@9&EV(#T@=&AI<RYD;V,N8W)E871E16QE;65N="@B9&EV(BD["@ET
M:&ES+F-O;G1E;G0N87!P96YD0VAI;&0H9&EV*3L*"61I=BYC;&%S<TYA;64@
M/2`B8G5T=&]N<R(["@EF;W(@*'9A<B!I(#T@,#L@:2`\(&%R9W5M96YT<RYL
M96YG=&@[("LK:2D@>PH)"79A<B!B=&X@/2!A<F=U;65N='-;:5T["@D)=F%R
M(&)U='1O;B`]('1H:7,N9&]C+F-R96%T945L96UE;G0H(F)U='1O;B(I.PH)
M"61I=BYA<'!E;F1#:&EL9"AB=71T;VXI.PH)"6)U='1O;BYI;FYE<DA434P@
M/2!(5$U,07)E82Y),3A.+F)U='1O;G-;8G1N73L*"0ES=VET8V@@*&)T;BD@
M>PH)"2`@("!C87-E(")O:R(Z"@D)"6)U='1O;BYO;F-L:6-K(#T@9G5N8W1I
M;VXH*2!["@D)"0ES96QF+F-A;&Q(86YD;&5R*"D["@D)"0ES96QF+F-L;W-E
M*"D["@D)"7T["@D)"6)R96%K.PH)"2`@("!C87-E(")C86YC96PB.@H)"0EB
M=71T;VXN;VYC;&EC:R`](&9U;F-T:6]N*"D@>PH)"0D)<V5L9BYC;&]S92@I
M.PH)"0E].PH)"0EB<F5A:SL*"0E]"@E]"GT["@``````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H
M=&UL87)E82]H=&UL87)E82YJ<P``````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#(S
M-S(S,B`Q,#4Q-30S,S<T-"`P,C0V,3,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+R\@:'1M;$%R96$@=C,N,"`M($-O<'ER
M:6=H="`H8RD@,C`P,RTR,#`U(&1Y;F%R8V@N8V]M"B\O("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#(P,#(M,C`P,R!I;G1E<F%C=&EV971O;VQS
M+F-O;2P@:6YC+@HO+R!4:&ES(&-O<'ER:6=H="!N;W1I8V4@35535"!S=&%Y
M(&EN=&%C="!F;W(@=7-E("AS964@;&EC96YS92YT>'0I+@HO+PHO+R!!(&9R
M964@5UE325=91R!E9&ET;W(@<F5P;&%C96UE;G0@9F]R(#QT97AT87)E83X@
M9FEE;&1S+@HO+R!&;W(@9G5L;"!S;W5R8V4@8V]D92!A;F0@9&]C<RP@=FES
M:70@:'1T<#HO+W=W=RYI;G1E<F%C=&EV971O;VQS+F-O;2\*+R\*+R\@5F5R
M<VEO;B`S+C`@9&5V96QO<&5D(&)Y($UI:&%I($)A>F]N+@HO+R`@(&AT='`Z
M+R]D>6YA<F-H+F-O;2]M:7-H;V\O"B\O"B\O("1)9#H@:'1M;&%R96$N:G,L
M=B`Q+CDW(#(P,#4O,#$O,CD@,#`Z-#8Z-3$@:71O;VQS($5X<"`D"@II9B`H
M='EP96]F(%]E9&ET;W)?=7)L(#T](")S=')I;F<B*2!["@DO+R!,96%V92!E
M>&%C=&QY(&]N92!B86-K<VQA<V@@870@=&AE(&5N9"!O9B!?961I=&]R7W5R
M;`H)7V5D:71O<E]U<FP@/2!?961I=&]R7W5R;"YR97!L86-E*"]<>#)F*B0O
M+"`G+R<I.PI](&5L<V4@>PH)86QE<G0H(E=!4DY)3D<Z(%]E9&ET;W)?=7)L
M(&ES(&YO="!S970A("!9;W4@<VAO=6QD('-E="!T:&ES('9A<FEA8FQE('1O
M('1H92!E9&ET;W(@9FEL97,@<&%T:#L@:70@<VAO=6QD('!R969E<F%B;'D@
M8F4@86X@86)S;VQU=&4@<&%T:"P@;&EK92!I;B`G+VAT;6QA<F5A+R<L(&)U
M="!I="!C86X@8F4@<F5L871I=F4@:68@>6]U('!R969E<BX@($9U<G1H97(@
M=V4@=VEL;"!T<GD@=&\@;&]A9"!T:&4@961I=&]R(&9I;&5S(&-O<G)E8W1L
M>2!B=70@=V4G;&P@<')O8F%B;'D@9F%I;"XB*3L*"5]E9&ET;W)?=7)L(#T@
M)R<["GT*"B\O(&UA:V4@<W5R92!W92!H879E(&$@;&%N9W5A9V4*:68@*'1Y
M<&5O9B!?961I=&]R7VQA;F<@/3T@(G-T<FEN9R(I('L*"5]E9&ET;W)?;&%N
M9R`](%]E9&ET;W)?;&%N9RYT;TQO=V5R0V%S92@I.PI](&5L<V4@>PH)7V5D
M:71O<E]L86YG(#T@(F5N(CL*?0H*+R\@8G)O=W-E<B!I9&5N=&EF:6-A=&EO
M;@I(5$U,07)E82YA9W0@/2!N879I9V%T;W(N=7-E<D%G96YT+G1O3&]W97)#
M87-E*"D["DA434Q!<F5A+FES7VEE"2`@(#T@*"A(5$U,07)E82YA9W0N:6YD
M97A/9B@B;7-I92(I("$]("TQ*2`F)B`H2%1-3$%R96$N86=T+FEN9&5X3V8H
M(F]P97)A(BD@/3T@+3$I*3L*2%1-3$%R96$N:7-?;W!E<F$@(#T@*$A434Q!
M<F5A+F%G="YI;F1E>$]F*")O<&5R82(I("$]("TQ*3L*2%1-3$%R96$N:7-?
M;6%C"2`@(#T@*$A434Q!<F5A+F%G="YI;F1E>$]F*")M86,B*2`A/2`M,2D[
M"DA434Q!<F5A+FES7VUA8U]I92`]("A(5$U,07)E82YI<U]I92`F)B!(5$U,
M07)E82YI<U]M86,I.PI(5$U,07)E82YI<U]W:6Y?:64@/2`H2%1-3$%R96$N
M:7-?:64@)B8@(4A434Q!<F5A+FES7VUA8RD["DA434Q!<F5A+FES7V=E8VMO
M("`]("AN879I9V%T;W(N<')O9'5C="`]/2`B1V5C:V\B*3L*"B\O($-R96%T
M97,@82!N97<@2%1-3$%R96$@;V)J96-T+B`@5')I97,@=&\@<F5P;&%C92!T
M:&4@=&5X=&%R96$@=VET:"!T:&4@9VEV96X*+R\@240@=VET:"!I="X*9G5N
M8W1I;VX@2%1-3$%R96$H=&5X=&%R96$L(&-O;F9I9RD@>PH@("`@("`@(&EF
M("@A2%1-3$%R96$N7VEN:71?8V%L;&5D*2!["@D@86QE<G0H(D5R<F]R.B!9
M;W4@;75S="!C86QL960@2%1-3$%R96$N:6YI="@I(&9I<G-T+B`@3&EK92!T
M:&ES.EQN7&XB("L*"2`@("`@("`B2%1-3$%R96$N:6YI="@I.UQN(B`K"@D@
M("`@("`@(DA434Q!<F5A+F]N;&]A9"`](&9U;F-T:6]N*"D@>UQN(B`K"@D@
M("`@("`@(B`@=F%R(&5D:71O<B`](&YE=R!(5$U,07)E82@G961I=&]R)RD[
M7&XB("L*"2`@("`@("`B("!E9&ET;W(N9V5N97)A=&4H*3M<;B(@*PH)("`@
M("`@(")].UQN(BD["@D@(')E='5R;CL*"7T*"@EI9B`H2%1-3$%R96$N8VAE
M8VM3=7!P;W)T961"<F]W<V5R*"DI('L*"0EI9B`H='EP96]F(&-O;F9I9R`]
M/2`B=6YD969I;F5D(BD@>PH)"0ET:&ES+F-O;F9I9R`](&YE=R!(5$U,07)E
M82Y#;VYF:6<H*3L*"0E](&5L<V4@>PH)"0ET:&ES+F-O;F9I9R`](&-O;F9I
M9SL*"0E]"@D)=&AI<RY?:'1M;$%R96$@/2!N=6QL.PH)"71H:7,N7W1E>'1!
M<F5A(#T@=&5X=&%R96$["@D)=&AI<RY?961I=$UO9&4@/2`B=WES:7=Y9R([
M"@D)=&AI<RYP;'5G:6YS(#T@>WT["@D)=&AI<RY?=&EM97)4;V]L8F%R(#T@
M;G5L;#L*"0ET:&ES+E]T:6UE<E5N9&\@/2!N=6QL.PH)"71H:7,N7W5N9&]1
M=65U92`](&YE=R!!<G)A>2AT:&ES+F-O;F9I9RYU;F1O4W1E<',I.PH)"71H
M:7,N7W5N9&]0;W,@/2`M,3L*"0ET:&ES+E]C=7-T;VU5;F1O(#T@9F%L<V4[
M"@D)=&AI<RY?;61O8R`](&1O8W5M96YT.R`O+R!C86-H92!T:&4@9&]C=6UE
M;G0L('=E(&YE960@:70@:6X@<&QU9VEN<PH)"71H:7,N9&]C='EP92`]("<G
M.PH)?0I].PH*2%1-3$%R96$N;VYL;V%D(#T@9G5N8W1I;VXH*7M].PI(5$U,
M07)E82Y?<V-R:7!T<R`](%M=.PI(5$U,07)E82YL;V%D4V-R:7!T(#T@9G5N
M8W1I;VXH=7)L+"!P;'5G:6XI('L*"6EF("AP;'5G:6XI"@D)=7)L(#T@2%1-
M3$%R96$N9V5T4&QU9VEN1&ER*'!L=6=I;BD@*R`G+R<@*R!U<FP["@ET:&ES
M+E]S8W)I<'1S+G!U<V@H=7)L*3L*?3L*"DA434Q!<F5A+FEN:70@/2!F=6YC
M=&EO;B@I('L*"79A<B!H96%D(#T@9&]C=6UE;G0N9V5T16QE;65N='-">51A
M9TYA;64H(FAE860B*5LP73L*"79A<B!C=7)R96YT(#T@,#L*"79A<B!S879E
M=&ET;&4@/2!D;V-U;65N="YT:71L93L*"79A<B!E=G0@/2!(5$U,07)E82YI
M<U]I92`_(")O;G)E861Y<W1A=&5C:&%N9V4B(#H@(F]N;&]A9"(["@EF=6YC
M=&EO;B!L;V%D3F5X=%-C<FEP="@I('L*"0EI9B`H8W5R<F5N="`^(#`@)B8@
M2%1-3$%R96$N:7-?:64@)B8*"0D@("`@(2]L;V%D961\8V]M<&QE=&4O+G1E
M<W0H=VEN9&]W+F5V96YT+G-R8T5L96UE;G0N<F5A9'E3=&%T92DI"@D)"7)E
M='5R;CL*"0EI9B`H8W5R<F5N="`\($A434Q!<F5A+E]S8W)I<'1S+FQE;F=T
M:"D@>PH)"0EV87(@=7)L(#T@2%1-3$%R96$N7W-C<FEP='-;8W5R<F5N="LK
M73L*"0D)9&]C=6UE;G0N=&ET;&4@/2`B6TA434Q!<F5A.B!L;V%D:6YG('-C
M<FEP="`B("L@8W5R<F5N="`K("(O(B`K($A434Q!<F5A+E]S8W)I<'1S+FQE
M;F=T:"`K(")=(CL*"0D)=F%R('-C<FEP="`](&1O8W5M96YT+F-R96%T945L
M96UE;G0H(G-C<FEP="(I.PH)"0ES8W)I<'0N='EP92`](")T97AT+VIA=F%S
M8W)I<'0B.PH)"0ES8W)I<'0N<W)C(#T@=7)L.PH)"0ES8W)I<'1;979T72`]
M(&QO861.97AT4V-R:7!T.PH)"0EH96%D+F%P<&5N9$-H:6QD*'-C<FEP="D[
M"@D)?2!E;'-E('L*"0D)9&]C=6UE;G0N=&ET;&4@/2!S879E=&ET;&4["B`@
M("`@("`@("`@("`@("`@("`@("`@($A434Q!<F5A+E]I;FET7V-A;&QE9"`]
M(#$["@D)"4A434Q!<F5A+F]N;&]A9"@I.PH)"7T*"7T["@EL;V%D3F5X=%-C
M<FEP="@I.PH*?3L*"DA434Q!<F5A+FQO86138W)I<'0H7V5D:71O<E]U<FP@
M*R`B9&EA;&]G+FIS(BD["DA434Q!<F5A+FQO86138W)I<'0H7V5D:71O<E]U
M<FP@*R`B<&]P=7!W:6XN:G,B*3L*2%1-3$%R96$N;&]A9%-C<FEP="A?961I
M=&]R7W5R;"`K(")L86YG+R(@*R!?961I=&]R7VQA;F<@*R`B+FIS(BD["@HO
M+R!C86-H92!S;VUE(')E9V5X<',*2%1-3$%R96$N4D5?=&%G3F%M92`]("\H
M/%PO?#PI7',J*%M>(%QT7&X^72LI+VEG.PI(5$U,07)E82Y215]D;V-T>7!E
M(#T@+R@\(61O8W1Y<&4H*"Y\7&XI*C\I/BE<;C\O:3L*2%1-3$%R96$N4D5?
M:&5A9"`@("`]("\\:&5A9#XH*"Y\7&XI*C\I/%PO:&5A9#XO:3L*2%1-3$%R
M96$N4D5?8F]D>2`@("`]("\\8F]D>3XH*"Y\7&XI*C\I/%PO8F]D>3XO:3L*
M"DA434Q!<F5A+D-O;F9I9R`](&9U;F-T:6]N("@I('L*"71H:7,N=F5R<VEO
M;B`]("(S+C`B.PH*"71H:7,N=VED=&@@/2`B875T;R(["@ET:&ES+FAE:6=H
M="`](")A=71O(CL*"@DO+R!E;F%B;&4@8W)E871I;VX@;V8@82!S=&%T=7,@
M8F%R/PH)=&AI<RYS=&%T=7-"87(@/2!T<G5E.PH*"2\O(&EN=&5R8V5P="!>
M5B!A;F0@=7-E('1H92!(5$U,07)E82!P87-T92!C;VUM86YD"@DO+R!)9B!F
M86QS92P@=&AE;B!P87-S97,@7E8@=&AR;W5G:"!T;R!B<F]W<V5R(&5D:71O
M<B!W:61G970*"71H:7,N:'1M;&%R96%087-T92`](&9A;'-E.PH*"2\O(&UA
M>&EM=6T@<VEZ92!O9B!T:&4@=6YD;R!Q=65U90H)=&AI<RYU;F1O4W1E<',@
M/2`R,#L*"@DO+R!T:&4@=&EM92!I;G1E<G9A;"!A="!W:&EC:"!U;F1O('-A
M;7!L97,@87)E('1A:V5N"@ET:&ES+G5N9&]4:6UE;W5T(#T@-3`P.PDO+R`Q
M+S(@<V5C+@H*"2\O('1H92!N97AT('!A<F%M971E<B!S<&5C:69I97,@=VAE
M=&AE<B!T:&4@=&]O;&)A<B!S:&]U;&0@8F4@:6YC;'5D960*"2\O(&EN('1H
M92!S:7IE(&]R(&YO="X*"71H:7,N<VEZ94EN8VQU9&5S5&]O;&)A<B`]('1R
M=64["@H)+R\@:68@=')U92!T:&5N($A434Q!<F5A('=I;&P@<F5T<FEE=F4@
M=&AE(&9U;&P@2%1-3"P@<W1A<G1I;F<@=VET:"!T:&4*"2\O(#Q(5$U,/B!T
M86<N"@ET:&ES+F9U;&Q086=E(#T@9F%L<V4["@H)+R\@<W1Y;&4@:6YC;'5D
M960@:6X@=&AE(&EF<F%M92!D;V-U;65N=`H)=&AI<RYP86=E4W1Y;&4@/2`B
M(CL*"@DO+R!S970@=&\@=')U92!I9B!Y;W4@=V%N="!7;W)D(&-O9&4@=&\@
M8F4@8VQE86YE9"!U<&]N(%!A<W1E"@ET:&ES+FMI;&Q7;W)D3VY087-T92`]
M('1R=64["@H)+R\@96YA8FQE('1H92`G5&%R9V5T)R!F:65L9"!I;B!T:&4@
M36%K92!,:6YK(&1I86QO9PH)=&AI<RYM86ME3&EN:U-H;W=S5&%R9V5T(#T@
M=')U93L*"@DO+R!"87-E55),(&EN8VQU9&5D(&EN('1H92!I9G)A;64@9&]C
M=6UE;G0*"71H:7,N8F%S95523"`](&1O8W5M96YT+F)A<V554DD@?'P@9&]C
M=6UE;G0N55),.PH):68@*'1H:7,N8F%S95523"`F)B!T:&ES+F)A<V554DPN
M;6%T8V@H+R@N*BE<+RA;7EPO72LI+RDI"@D)=&AI<RYB87-E55),(#T@4F5G
M17AP+B0Q("L@(B\B.PH*"2\O(%523"US"@ET:&ES+FEM9U523"`](")I;6%G
M97,O(CL*"71H:7,N<&]P=7!54DP@/2`B<&]P=7!S+R(["@H)+R\@<F5M;W9E
M('1A9W,@*'1H97-E(&AA=F4@=&\@8F4@82!R96=E>'`L(&]R(&YU;&P@:68@
M=&AI<R!F=6YC=&EO;F%L:71Y(&ES(&YO="!D97-I<F5D*0H)=&AI<RYH=&UL
M4F5M;W9E5&%G<R`](&YU;&P["@H)+RHJ($-54U1/34E:24Y'(%1(12!43T],
M0D%2"@D@*B`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"@D@*@H)("H@270@
M:7,@<F5C;VUM96YD960@=&AA="!Y;W4@8W5S=&]M:7IE('1H92!T;V]L8F%R
M(&-O;G1E;G1S(&EN(&%N"@D@*B!E>'1E<FYA;"!F:6QE("AI+F4N('1H92!O
M;F4@8V%L;&EN9R!(5$U,07)E82D@86YD(&QE879E('1H:7,@;VYE"@D@*B!U
M;F-H86YG960N("!4:&%T)W,@8F5C875S92!W:&5N('=E("A);G1E<F%C=&EV
M951O;VQS+F-O;2D@<F5L96%S92!A"@D@*B!N97<@;V9F:6-I86P@=F5R<VEO
M;BP@:70G<R!L97-S(&QI:V5L>2!T:&%T('EO=2!W:6QL(&AA=F4@<')O8FQE
M;7,*"2`J('5P9W)A9&EN9R!(5$U,07)E82X*"2`J+PH)=&AI<RYT;V]L8F%R
M(#T@6PH)"5L@(F9O;G1N86UE(BP@(G-P86-E(BP*"0D@(")F;VYT<VEZ92(L
M(")S<&%C92(L"@D)("`B9F]R;6%T8FQO8VLB+"`B<W!A8V4B+`H)"2`@(F)O
M;&0B+"`B:71A;&EC(BP@(G5N9&5R;&EN92(L(")S=')I:V5T:')O=6=H(BP@
M(G-E<&%R871O<B(L"@D)("`B<W5B<V-R:7!T(BP@(G-U<&5R<V-R:7!T(BP@
M(G-E<&%R871O<B(L"@D)("`B8V]P>2(L(")C=70B+"`B<&%S=&4B+"`B<W!A
M8V4B+"`B=6YD;R(L(")R961O(BP@(G-P86-E(BP@(G)E;6]V969O<FUA="(L
M(")K:6QL=V]R9"(@72P*"@D)6R`B:G5S=&EF>6QE9G0B+"`B:G5S=&EF>6-E
M;G1E<B(L(")J=7-T:69Y<FEG:'0B+"`B:G5S=&EF>69U;&PB+"`B<V5P87)A
M=&]R(BP*"0D@(")L969T=&]R:6=H="(L(")R:6=H='1O;&5F="(L(")S97!A
M<F%T;W(B+`H)"2`@(F]R9&5R961L:7-T(BP@(G5N;W)D97)E9&QI<W0B+"`B
M;W5T9&5N="(L(")I;F1E;G0B+"`B<V5P87)A=&]R(BP*"0D@(")F;W)E8V]L
M;W(B+"`B:&EL:71E8V]L;W(B+"`B<V5P87)A=&]R(BP*"0D@(")I;G-E<G1H
M;W)I>F]N=&%L<G5L92(L(")C<F5A=&5L:6YK(BP@(FEN<V5R=&EM86=E(BP@
M(FEN<V5R='1A8FQE(BP@(FAT;6QM;V1E(BP@(G-E<&%R871O<B(L"@D)("`B
M<&]P=7!E9&ET;W(B+"`B<V5P87)A=&]R(BP@(G-H;W=H96QP(BP@(F%B;W5T
M(B!="@E=.PH*"71H:7,N9F]N=&YA;64@/2!["@D)(B9M9&%S:#L@9F]N="`F
M;61A<V@[(CH@("`@("`@("`G)RP*"0DB07)I86PB.@D@("`G87)I86PL:&5L
M=F5T:6-A+'-A;G,M<V5R:68G+`H)"2)#;W5R:65R($YE=R(Z"2`@("=C;W5R
M:65R(&YE=RQC;W5R:65R+&UO;F]S<&%C92<L"@D)(D=E;W)G:6$B.@D@("`G
M9V5O<F=I82QT:6UE<R!N97<@<F]M86XL=&EM97,L<V5R:68G+`H)"2)486AO
M;6$B.@D@("`G=&%H;VUA+&%R:6%L+&AE;'9E=&EC82QS86YS+7-E<FEF)RP*
M"0DB5&EM97,@3F5W(%)O;6%N(CH@)W1I;65S(&YE=R!R;VUA;BQT:6UE<RQS
M97)I9B<L"@D)(E9E<F1A;F$B.@D@("`G=F5R9&%N82QA<FEA;"QH96QV971I
M8V$L<V%N<RUS97)I9B<L"@D)(FEM<&%C="(Z"2`@("=I;7!A8W0G+`H)"2)7
M:6YG1&EN9W,B.@D@("`G=VEN9V1I;F=S)PH)?3L*"@ET:&ES+F9O;G1S:7IE
M(#T@>PH)"2(F;61A<V@[('-I>F4@)FUD87-H.R(@(#H@(B(L"@D)(C$@*#@@
M<'0I(B`Z("(Q(BP*"0DB,B`H,3`@<'0I(CH@(C(B+`H)"2(S("@Q,B!P="DB
M.B`B,R(L"@D)(C0@*#$T('!T*2(Z("(T(BP*"0DB-2`H,3@@<'0I(CH@(C4B
M+`H)"2(V("@R-"!P="DB.B`B-B(L"@D)(C<@*#,V('!T*2(Z("(W(@H)?3L*
M"@ET:&ES+F9O<FUA=&)L;V-K(#T@>PH)"2(F;61A<V@[(&9O<FUA="`F;61A
M<V@[(B`@.B`B(BP*"0DB2&5A9&EN9R`Q(CH@(F@Q(BP*"0DB2&5A9&EN9R`R
M(CH@(F@R(BP*"0DB2&5A9&EN9R`S(CH@(F@S(BP*"0DB2&5A9&EN9R`T(CH@
M(F@T(BP*"0DB2&5A9&EN9R`U(CH@(F@U(BP*"0DB2&5A9&EN9R`V(CH@(F@V
M(BP*"0DB3F]R;6%L(B`@(#H@(G`B+`H)"2)!9&1R97-S(B`@.B`B861D<F5S
M<R(L"@D)(D9O<FUA='1E9"(Z(")P<F4B"@E].PH*"71H:7,N8W5S=&]M4V5L
M96-T<R`]('M].PH*"69U;F-T:6]N(&-U=%]C;W!Y7W!A<W1E*&4L(&-M9"P@
M;V)J*2!["@D)92YE>&5C0V]M;6%N9"AC;60I.PH)?3L*"@ET:&ES+F1E8G5G
M(#T@=')U93L*"@DO+R!!1$1)3D<@0U535$]-($)55%1/3E,Z('!L96%S92!R
M96%D(&)E;&]W(0H)+R\@9F]R;6%T(&]F('1H92!B=&Y,:7-T(&5L96UE;G1S
M(&ES("))1#H@6R!4;V]L5&EP+"!)8V]N+"!%;F%B;&5D(&EN('1E>'0@;6]D
M93\L($%#5$E/3B!=(@H)+R\@("`@+2!)1#H@=6YI<75E($E$(&9O<B!T:&4@
M8G5T=&]N+B`@268@=&AE(&)U='1O;B!C86QL<R!D;V-U;65N="YE>&5C0V]M
M;6%N9`H)+R\)("`@(&ET)W,@=VES92!T;R!G:79E(&ET('1H92!S86UE(&YA
M;64@87,@=&AE(&-A;&QE9"!C;VUM86YD+@H)+R\@("`@+2!!0U1)3TXZ(&9U
M;F-T:6]N('1H870@9V5T<R!C86QL960@=VAE;B!T:&4@8G5T=&]N(&ES(&-L
M:6-K960N"@DO+R`@("`@("`@("`@("`@:70@:&%S('1H92!F;VQL;W=I;F<@
M<')O=&]T>7!E.@H)+R\@("`@("`@("`@("`@("`@(&9U;F-T:6]N*&5D:71O
M<BP@8G5T=&]N3F%M92D*"2\O("`@("`@("`@("`@("`M(&5D:71O<B!I<R!T
M:&4@2%1-3$%R96$@;V)J96-T('1H870@=')I9V=E<F5D('1H92!C86QL"@DO
M+R`@("`@("`@("`@("`@+2!B=71T;VY.86UE(&ES('1H92!)1"!O9B!T:&4@
M8VQI8VME9"!B=71T;VX*"2\O("`@("`@("`@("`@("!4:&5S92`R('!A<F%M
M971E<G,@;6%K97,@:70@<&]S<VEB;&4@9F]R('EO=2!T;R!U<V4@=&AE('-A
M;64*"2\O("`@("`@("`@("`@("!H86YD;&5R(&9O<B!M;W)E($A434Q!<F5A
M(&]B:F5C=',@;W(@9F]R(&UO<F4@9&EF9F5R96YT(&)U='1O;G,N"@DO+R`@
M("`M(%1O;VQ4:7`Z(&1E9F%U;'0@=&]O;'1I<"P@9F]R(&-A<V5S('=H96X@
M:70@:7,@;F]T(&1E9FEN960@:6X@=&AE("UL86YG+2!F:6QE("A(5$U,07)E
M82Y),3A.*0H)+R\@("`@+2!)8V]N.B!P871H('1O(&%N(&EC;VX@:6UA9V4@
M9FEL92!F;W(@=&AE(&)U='1O;B`H5$]$3SH@=7-E(&]N92!I;6%G92!F;W(@
M86QL(&)U='1O;G,A*0H)+R\@("`@+2!%;F%B;&5D(&EN('1E>'0@;6]D93H@
M:68@9F%L<V4@=&AE(&)U='1O;B!G971S(&1I<V%B;&5D(&9O<B!T97AT+6]N
M;'D@;6]D93L@;W1H97)W:7-E(&5N86)L960@86QL('1H92!T:6UE+@H)=&AI
M<RYB=&Y,:7-T(#T@>PH)"6)O;&0Z(%L@(D)O;&0B+"`B961?9F]R;6%T7V)O
M;&0N9VEF(BP@9F%L<V4L(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM86YD*")B
M;VQD(BD[?2!=+`H)"6ET86QI8SH@6R`B271A;&EC(BP@(F5D7V9O<FUA=%]I
M=&%L:6,N9VEF(BP@9F%L<V4L(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM86YD
M*")I=&%L:6,B*3M](%TL"@D)=6YD97)L:6YE.B!;(")5;F1E<FQI;F4B+"`B
M961?9F]R;6%T7W5N9&5R;&EN92YG:68B+"!F86QS92P@9G5N8W1I;VXH92D@
M>V4N97AE8T-O;6UA;F0H(G5N9&5R;&EN92(I.WT@72P*"0ES=')I:V5T:')O
M=6=H.B!;(")3=')I:V5T:')O=6=H(BP@(F5D7V9O<FUA=%]S=')I:V4N9VEF
M(BP@9F%L<V4L(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM86YD*")S=')I:V5T
M:')O=6=H(BD[?2!=+`H)"7-U8G-C<FEP=#H@6R`B4W5B<V-R:7!T(BP@(F5D
M7V9O<FUA=%]S=6(N9VEF(BP@9F%L<V4L(&9U;F-T:6]N*&4I('ME+F5X96-#
M;VUM86YD*")S=6)S8W)I<'0B*3M](%TL"@D)<W5P97)S8W)I<'0Z(%L@(E-U
M<&5R<V-R:7!T(BP@(F5D7V9O<FUA=%]S=7`N9VEF(BP@9F%L<V4L(&9U;F-T
M:6]N*&4I('ME+F5X96-#;VUM86YD*")S=7!E<G-C<FEP="(I.WT@72P*"0EJ
M=7-T:69Y;&5F=#H@6R`B2G5S=&EF>2!,969T(BP@(F5D7V%L:6=N7VQE9G0N
M9VEF(BP@9F%L<V4L(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM86YD*")J=7-T
M:69Y;&5F="(I.WT@72P*"0EJ=7-T:69Y8V5N=&5R.B!;(")*=7-T:69Y($-E
M;G1E<B(L(")E9%]A;&EG;E]C96YT97(N9VEF(BP@9F%L<V4L(&9U;F-T:6]N
M*&4I('ME+F5X96-#;VUM86YD*")J=7-T:69Y8V5N=&5R(BD[?2!=+`H)"6IU
M<W1I9GER:6=H=#H@6R`B2G5S=&EF>2!2:6=H="(L(")E9%]A;&EG;E]R:6=H
M="YG:68B+"!F86QS92P@9G5N8W1I;VXH92D@>V4N97AE8T-O;6UA;F0H(FIU
M<W1I9GER:6=H="(I.WT@72P*"0EJ=7-T:69Y9G5L;#H@6R`B2G5S=&EF>2!&
M=6QL(BP@(F5D7V%L:6=N7VIU<W1I9GDN9VEF(BP@9F%L<V4L(&9U;F-T:6]N
M*&4I('ME+F5X96-#;VUM86YD*")J=7-T:69Y9G5L;"(I.WT@72P*"0EO<F1E
M<F5D;&ES=#H@6R`B3W)D97)E9"!,:7-T(BP@(F5D7VQI<W1?;G5M+F=I9B(L
M(&9A;'-E+"!F=6YC=&EO;BAE*2![92YE>&5C0V]M;6%N9"@B:6YS97)T;W)D
M97)E9&QI<W0B*3M](%TL"@D)=6YO<F1E<F5D;&ES=#H@6R`B0G5L;&5T960@
M3&ES="(L(")E9%]L:7-T7V)U;&QE="YG:68B+"!F86QS92P@9G5N8W1I;VXH
M92D@>V4N97AE8T-O;6UA;F0H(FEN<V5R='5N;W)D97)E9&QI<W0B*3M](%TL
M"@D);W5T9&5N=#H@6R`B1&5C<F5A<V4@26YD96YT(BP@(F5D7VEN9&5N=%]L
M97-S+F=I9B(L(&9A;'-E+"!F=6YC=&EO;BAE*2![92YE>&5C0V]M;6%N9"@B
M;W5T9&5N="(I.WT@72P*"0EI;F1E;G0Z(%L@(DEN8W)E87-E($EN9&5N="(L
M(")E9%]I;F1E;G1?;6]R92YG:68B+"!F86QS92P@9G5N8W1I;VXH92D@>V4N
M97AE8T-O;6UA;F0H(FEN9&5N="(I.WT@72P*"0EF;W)E8V]L;W(Z(%L@(D9O
M;G0@0V]L;W(B+"`B961?8V]L;W)?9F<N9VEF(BP@9F%L<V4L(&9U;F-T:6]N
M*&4I('ME+F5X96-#;VUM86YD*")F;W)E8V]L;W(B*3M](%TL"@D):&EL:71E
M8V]L;W(Z(%L@(D)A8VMG<F]U;F0@0V]L;W(B+"`B961?8V]L;W)?8F<N9VEF
M(BP@9F%L<V4L(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM86YD*")H:6QI=&5C
M;VQO<B(I.WT@72P*"0EI;G-E<G1H;W)I>F]N=&%L<G5L93H@6R`B2&]R:7IO
M;G1A;"!2=6QE(BP@(F5D7VAR+F=I9B(L(&9A;'-E+"!F=6YC=&EO;BAE*2![
M92YE>&5C0V]M;6%N9"@B:6YS97)T:&]R:7IO;G1A;')U;&4B*3M](%TL"@D)
M8W)E871E;&EN:SH@6R`B26YS97)T(%=E8B!,:6YK(BP@(F5D7VQI;FLN9VEF
M(BP@9F%L<V4L(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM86YD*")C<F5A=&5L
M:6YK(BP@=')U92D[?2!=+`H)"6EN<V5R=&EM86=E.B!;("));G-E<G0O36]D
M:69Y($EM86=E(BP@(F5D7VEM86=E+F=I9B(L(&9A;'-E+"!F=6YC=&EO;BAE
M*2![92YE>&5C0V]M;6%N9"@B:6YS97)T:6UA9V4B*3M](%TL"@D):6YS97)T
M=&%B;&4Z(%L@(DEN<V5R="!486)L92(L(")I;G-E<G1?=&%B;&4N9VEF(BP@
M9F%L<V4L(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM86YD*")I;G-E<G1T86)L
M92(I.WT@72P*"0EH=&UL;6]D93H@6R`B5&]G9VQE($A434P@4V]U<F-E(BP@
M(F5D7VAT;6PN9VEF(BP@=')U92P@9G5N8W1I;VXH92D@>V4N97AE8T-O;6UA
M;F0H(FAT;6QM;V1E(BD[?2!=+`H)"7!O<'5P961I=&]R.B!;(")%;FQA<F=E
M($5D:71O<B(L(")F=6QL<V-R965N7VUA>&EM:7IE+F=I9B(L('1R=64L(&9U
M;F-T:6]N*&4I('ME+F5X96-#;VUM86YD*")P;W!U<&5D:71O<B(I.WT@72P*
M"0EA8F]U=#H@6R`B06)O=70@=&AI<R!E9&ET;W(B+"`B961?86)O=70N9VEF
M(BP@=')U92P@9G5N8W1I;VXH92D@>V4N97AE8T-O;6UA;F0H(F%B;W5T(BD[
M?2!=+`H)"7-H;W=H96QP.B!;(")(96QP('5S:6YG(&5D:71O<B(L(")E9%]H
M96QP+F=I9B(L('1R=64L(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM86YD*")S
M:&]W:&5L<"(I.WT@72P*"0EU;F1O.B!;(")5;F1O97,@>6]U<B!L87-T(&%C
M=&EO;B(L(")E9%]U;F1O+F=I9B(L(&9A;'-E+"!F=6YC=&EO;BAE*2![92YE
M>&5C0V]M;6%N9"@B=6YD;R(I.WT@72P*"0ER961O.B!;(")2961O97,@>6]U
M<B!L87-T(&%C=&EO;B(L(")E9%]R961O+F=I9B(L(&9A;'-E+"!F=6YC=&EO
M;BAE*2![92YE>&5C0V]M;6%N9"@B<F5D;R(I.WT@72P*"0EC=70Z(%L@(D-U
M="!S96QE8W1I;VXB+"`B961?8W5T+F=I9B(L(&9A;'-E+"!C=71?8V]P>5]P
M87-T92!=+`H)"6-O<'DZ(%L@(D-O<'D@<V5L96-T:6]N(BP@(F5D7V-O<'DN
M9VEF(BP@9F%L<V4L(&-U=%]C;W!Y7W!A<W1E(%TL"@D)<&%S=&4Z(%L@(E!A
M<W1E(&9R;VT@8VQI<&)O87)D(BP@(F5D7W!A<W1E+F=I9B(L(&9A;'-E+"!C
M=71?8V]P>5]P87-T92!=+`H)"6QE9G1T;W)I9VAT.B!;(")$:7)E8W1I;VX@
M;&5F="!T;R!R:6=H="(L(")E9%]L969T7W1O7W)I9VAT+F=I9B(L(&9A;'-E
M+"!F=6YC=&EO;BAE*2![92YE>&5C0V]M;6%N9"@B;&5F='1O<FEG:'0B*3M]
M(%TL"@D)<FEG:'1T;VQE9G0Z(%L@(D1I<F5C=&EO;B!R:6=H="!T;R!L969T
M(BP@(F5D7W)I9VAT7W1O7VQE9G0N9VEF(BP@9F%L<V4L(&9U;F-T:6]N*&4I
M('ME+F5X96-#;VUM86YD*")R:6=H='1O;&5F="(I.WT@72P*"0ER96UO=F5F
M;W)M870Z(%L@(E)E;6]V92!F;W)M871T:6YG(BP@(F5D7W)M9F]R;6%T+F=I
M9B(L(&9A;'-E+"!F=6YC=&EO;BAE*2![92YE>&5C0V]M;6%N9"@B<F5M;W9E
M9F]R;6%T(BD[?2!=+`H)"7!R:6YT.B!;(")0<FEN="!D;V-U;65N="(L(")E
M9%]P<FEN="YG:68B+"!F86QS92P@9G5N8W1I;VXH92D@>V4N7VEF<F%M92YC
M;VYT96YT5VEN9&]W+G!R:6YT*"D[?2!=+`H)"6MI;&QW;W)D.B!;(")#;&5A
M<B!-4T]F9FEC92!T86=S(BP@(F5D7VMI;&QW;W)D+F=I9B(L(&9A;'-E+"!F
M=6YC=&EO;BAE*2![92YE>&5C0V]M;6%N9"@B:VEL;'=O<F0B*3M](%T*"7T[
M"@DO*B!!1$1)3D<@0U535$]-($)55%1/3E,*"2`J("TM+2TM+2TM+2TM+2TM
M+2TM+2TM+0H)("H*"2`J($ET(&ES(')E8V]M;65N9&5D('1H870@>6]U(&%D
M9"!T:&4@8W5S=&]M(&)U='1O;G,@:6X@86X@97AT97)N86P*"2`J(&9I;&4@
M86YD(&QE879E('1H:7,@;VYE('5N8VAA;F=E9"X@(%1H870G<R!B96-A=7-E
M('=H96X@=V4*"2`J("A);G1E<F%C=&EV951O;VQS+F-O;2D@<F5L96%S92!A
M(&YE=R!O9F9I8VEA;"!V97)S:6]N+"!I="=S(&QE<W,*"2`J(&QI:V5L>2!T
M:&%T('EO=2!W:6QL(&AA=F4@<')O8FQE;7,@=7!G<F%D:6YG($A434Q!<F5A
M+@H)("H*"2`J($5X86UP;&4@;VX@:&]W('1O(&%D9"!A(&-U<W1O;2!B=71T
M;VX@=VAE;B!Y;W4@8V]N<W1R=6-T('1H92!(5$U,07)E83H*"2`J"@D@*B`@
M('9A<B!E9&ET;W(@/2!N97<@2%1-3$%R96$H(GEO=7)?=&5X=%]A<F5A7VED
M(BD["@D@*B`@('9A<B!C9F<@/2!E9&ET;W(N8V]N9FEG.R`O+R!T:&ES(&ES
M('1H92!D969A=6QT(&-O;F9I9W5R871I;VX*"2`J("`@8V9G+F)T;DQI<W1;
M(FUY+6AI;&ET92)=(#T*"2`J"5L@9G5N8W1I;VXH961I=&]R*2![(&5D:71O
M<BYS=7)R;W5N9$A434PH)SQS<&%N('-T>6QE/2)B86-K9W)O=6YD.GEE;&QO
M=R(^)RP@)SPO<W!A;CXG*3L@?2P@+R\@86-T:6]N"@D@*@D@(")(:6=H;&EG
M:'0@<V5L96-T:6]N(BP@+R\@=&]O;'1I<`H)("H)("`B;7E?:&EL:71E+F=I
M9B(L("\O(&EM86=E"@D@*@D@(&9A;'-E("\O(&1I<V%B;&5D(&EN('1E>'0@
M;6]D90H)("H)73L*"2`J("`@8V9G+G1O;VQB87(N<'5S:"A;(FQI;F5B<F5A
M:R(L(")M>2UH:6QI=&4B72D[("\O(&%D9"!T:&4@;F5W(&)U='1O;B!T;R!T
M:&4@=&]O;&)A<@H)("H*"2`J($%N(&%L=&5R;F%T92`H86QS;R!M;W)E(&-O
M;G9E;FEE;G0@86YD(')E8V]M;65N9&5D*2!W87D@=&\*"2`J(&%C8V]M<&QI
M<V@@=&AI<R!I<R!T;R!U<V4@=&AE(')E9VES=&5R0G5T=&]N(&9U;F-T:6]N
M(&)E;&]W+@H)("HO"@DO+R!I;FET:6%L:7IE('1O;VQT:7!S(&9R;VT@=&AE
M($DQ.$X@;6]D=6QE(&%N9"!G96YE<F%T92!C;W)R96-T(&EM86=E('!A=&@*
M"69O<B`H=F%R(&D@:6X@=&AI<RYB=&Y,:7-T*2!["@D)=F%R(&)T;B`]('1H
M:7,N8G1N3&ES=%MI73L*"0EB=&Y;,5T@/2!?961I=&]R7W5R;"`K('1H:7,N
M:6UG55),("L@8G1N6S%=.PH)"6EF("AT>7!E;V8@2%1-3$%R96$N23$X3BYT
M;V]L=&EP<UMI72`A/2`B=6YD969I;F5D(BD@>PH)"0EB=&Y;,%T@/2!(5$U,
M07)E82Y),3A.+G1O;VQT:7!S6VE=.PH)"7T*"7T*?3L*"B\J*B!(96QP97(@
M9G5N8W1I;VXZ(')E9VES=&5R(&$@;F5W(&)U='1O;B!W:71H('1H92!C;VYF
M:6=U<F%T:6]N+B`@270@8V%N(&)E"B`J(&-A;&QE9"!W:71H(&%L;"`U(&%R
M9W5M96YT<RP@;W(@=VET:"!O;FQY(&]N92`H9FER<W0@;VYE*2X@(%=H96X@
M8V%L;&5D('=I=&@*("H@;VYL>2!O;F4@87)G=6UE;G0@:70@;75S="!B92!A
M;B!O8FIE8W0@=VET:"!T:&4@9F]L;&]W:6YG('!R;W!E<G1I97,Z(&ED+`H@
M*B!T;V]L=&EP+"!I;6%G92P@=&5X=$UO9&4L(&%C=&EO;BX@($5X86UP;&5S
M.@H@*@H@*B`Q+B!C;VYF:6<N<F5G:7-T97)"=71T;VXH(FUY+6AI;&ET92(L
M(")(:6QI=&4@=&5X="(L(")M>2UH:6QI=&4N9VEF(BP@9F%L<V4L(&9U;F-T
M:6]N*&5D:71O<BD@>RXN+GTI.PH@*B`R+B!C;VYF:6<N<F5G:7-T97)"=71T
M;VXH>PH@*B`@("`@(&ED("`@("`@(#H@(FUY+6AI;&ET92(L("`@("`@+R\@
M=&AE($E$(&]F('EO=7(@8G5T=&]N"B`J("`@("`@=&]O;'1I<"`@.B`B2&EL
M:71E('1E>'0B+"`@("`O+R!T:&4@=&]O;'1I<`H@*B`@("`@(&EM86=E("`@
M(#H@(FUY+6AI;&ET92YG:68B+"`@+R\@:6UA9V4@=&\@8F4@9&ES<&QA>65D
M(&EN('1H92!T;V]L8F%R"B`J("`@("`@=&5X=$UO9&4@.B!F86QS92P@("`@
M("`@("`@("`O+R!D:7-A8FQE9"!I;B!T97AT(&UO9&4*("H@("`@("!A8W1I
M;VX@("`Z(&9U;F-T:6]N*&5D:71O<BD@>R`O+R!C86QL960@=VAE;B!T:&4@
M8G5T=&]N(&ES(&-L:6-K960*("H@("`@("`@("`@("`@("`@("`@961I=&]R
M+G-U<G)O=6YD2%1-3"@G/'-P86X@8VQA<W,](FAI;&ET92(^)RP@)SPO<W!A
M;CXG*3L*("H@("`@("`@("`@("`@("`@('TL"B`J("`@("`@8V]N=&5X="`@
M.B`B<"(@("`@("`@("`@("`@("`O+R!W:6QL(&)E(&1I<V%B;&5D(&EF(&]U
M='-I9&4@82`\<#X@96QE;65N=`H@*B`@("!]*3L*("HO"DA434Q!<F5A+D-O
M;F9I9RYP<F]T;W1Y<&4N<F5G:7-T97)"=71T;VX@/2!F=6YC=&EO;BAI9"P@
M=&]O;'1I<"P@:6UA9V4L('1E>'1-;V1E+"!A8W1I;VXL(&-O;G1E>'0I('L*
M"79A<B!T:&5?:60["@EI9B`H='EP96]F(&ED(#T](")S=')I;F<B*2!["@D)
M=&AE7VED(#T@:60["@E](&5L<V4@:68@*'1Y<&5O9B!I9"`]/2`B;V)J96-T
M(BD@>PH)"71H95]I9"`](&ED+FED.PH)?2!E;'-E('L*"0EA;&5R="@B15)2
M3U(@6TA434Q!<F5A+D-O;F9I9SHZ<F5G:7-T97)"=71T;VY=.EQN:6YV86QI
M9"!A<F=U;65N=',B*3L*"0ER971U<FX@9F%L<V4["@E]"@DO+R!C:&5C:R!F
M;W(@97AI<W1I;F<@:60*"6EF("AT>7!E;V8@=&AI<RYC=7-T;VU396QE8W1S
M6W1H95]I9%T@(3T@(G5N9&5F:6YE9"(I('L*"0DO+R!A;&5R="@B5T%23DE.
M1R!;2%1-3$%R96$N0V]N9FEG.CIR96=I<W1E<D1R;W!D;W=N73I<;D$@9')O
M<&1O=VX@=VET:"!T:&4@<V%M92!)1"!A;')E861Y(&5X:7-T<RXB*3L*"7T*
M"6EF("AT>7!E;V8@=&AI<RYB=&Y,:7-T6W1H95]I9%T@(3T@(G5N9&5F:6YE
M9"(I('L*"0DO+R!A;&5R="@B5T%23DE.1R!;2%1-3$%R96$N0V]N9FEG.CIR
M96=I<W1E<D1R;W!D;W=N73I<;D$@8G5T=&]N('=I=&@@=&AE('-A;64@240@
M86QR96%D>2!E>&ES=',N(BD["@E]"@ES=VET8V@@*'1Y<&5O9B!I9"D@>PH)
M("`@(&-A<V4@(G-T<FEN9R(Z('1H:7,N8G1N3&ES=%MI9%T@/2!;('1O;VQT
M:7`L(&EM86=E+"!T97AT36]D92P@86-T:6]N+"!C;VYT97AT(%T[(&)R96%K
M.PH)("`@(&-A<V4@(F]B:F5C="(Z('1H:7,N8G1N3&ES=%MI9"YI9%T@/2!;
M(&ED+G1O;VQT:7`L(&ED+FEM86=E+"!I9"YT97AT36]D92P@:60N86-T:6]N
M+"!I9"YC;VYT97AT(%T[(&)R96%K.PH)?0I].PH*+RHJ(%1H92!F;VQL;W=I
M;F<@:&5L<&5R(&9U;F-T:6]N(')E9VES=&5R<R!A(&1R;W!D;W=N(&)O>"!W
M:71H('1H92!E9&ET;W(*("H@8V]N9FEG=7)A=&EO;BX@(%EO=2!S=&EL;"!H
M879E('1O(&%D9"!I="!T;R!T:&4@=&]O;&)A<BP@<V%M92!A<R!W:71H('1H
M90H@*B!B=71T;VYS+B`@0V%L;"!I="!L:6ME('1H:7,Z"B`J"B`J($9)6$U%
M.B!A9&0@97AA;7!L90H@*B\*2%1-3$%R96$N0V]N9FEG+G!R;W1O='EP92YR
M96=I<W1E<D1R;W!D;W=N(#T@9G5N8W1I;VXH;V)J96-T*2!["@DO+R!C:&5C
M:R!F;W(@97AI<W1I;F<@:60*"6EF("AT>7!E;V8@=&AI<RYC=7-T;VU396QE
M8W1S6V]B:F5C="YI9%T@(3T@(G5N9&5F:6YE9"(I('L*"0DO+R!A;&5R="@B
M5T%23DE.1R!;2%1-3$%R96$N0V]N9FEG.CIR96=I<W1E<D1R;W!D;W=N73I<
M;D$@9')O<&1O=VX@=VET:"!T:&4@<V%M92!)1"!A;')E861Y(&5X:7-T<RXB
M*3L*"7T*"6EF("AT>7!E;V8@=&AI<RYB=&Y,:7-T6V]B:F5C="YI9%T@(3T@
M(G5N9&5F:6YE9"(I('L*"0DO+R!A;&5R="@B5T%23DE.1R!;2%1-3$%R96$N
M0V]N9FEG.CIR96=I<W1E<D1R;W!D;W=N73I<;D$@8G5T=&]N('=I=&@@=&AE
M('-A;64@240@86QR96%D>2!E>&ES=',N(BD["@E]"@ET:&ES+F-U<W1O;5-E
M;&5C='-;;V)J96-T+FED72`](&]B:F5C=#L*?3L*"B\J*B!#86QL('1H:7,@
M9G5N8W1I;VX@=&\@<F5M;W9E('-O;64@8G5T=&]N<R]D<F]P+61O=VX@8F]X
M97,@9G)O;2!T:&4@=&]O;&)A<BX*("H@4&%S<R!A<R!T:&4@;VYL>2!P87)A
M;65T97(@82!S=')I;F<@8V]N=&%I;FEN9R!B=71T;VXO9')O<"UD;W=N(&YA
M;65S"B`J(&1E;&EM:71E9"!B>2!S<&%C97,N("!.;W1E('1H870@=&AE('-T
M<FEN9R!S:&]U;&0@86QS;R!B96=I;B!W:71H(&$@<W!A8V4*("H@86YD(&5N
M9"!W:71H(&$@<W!A8V4N("!%>&%M<&QE.@H@*@H@*B`@(&-O;F9I9RYH:61E
M4V]M94)U='1O;G,H(B!F;VYT;F%M92!F;VYT<VEZ92!T97AT:6YD:6-A=&]R
M("(I.PH@*@H@*B!)="=S('5S969U;"!B96-A=7-E(&ET)W,@96%S:65R('1O
M(')E;6]V92!S='5F9B!F<F]M('1H92!D969A=6P@=&]O;&)A<B!T:&%N"B`J
M(&-R96%T92!A(&)R86YD(&YE=R!T;V]L8F%R(#LM*0H@*B\*2%1-3$%R96$N
M0V]N9FEG+G!R;W1O='EP92YH:61E4V]M94)U='1O;G,@/2!F=6YC=&EO;BAR
M96UO=F4I('L*"79A<B!T;V]L8F%R(#T@=&AI<RYT;V]L8F%R.PH)9F]R("AV
M87(@:2`]('1O;VQB87(N;&5N9W1H.R`M+6D@/CT@,#LI('L*"0EV87(@;&EN
M92`]('1O;VQB87);:5T["@D)9F]R("AV87(@:B`](&QI;F4N;&5N9W1H.R`M
M+6H@/CT@,#L@*2!["@D)"6EF("AR96UO=F4N:6YD97A/9B@B("(@*R!L:6YE
M6VI=("L@(B`B*2`^/2`P*2!["@D)"0EV87(@;&5N(#T@,3L*"0D)"6EF("@O
M<V5P87)A=&]R?'-P86-E+RYT97-T*&QI;F5;:B`K(#%=*2D@>PH)"0D)"6QE
M;B`](#(["@D)"0E]"@D)"0EL:6YE+G-P;&EC92AJ+"!L96XI.PH)"0E]"@D)
M?0H)?0I].PH*+RHJ($AE;'!E<B!F=6YC=&EO;CH@<F5P;&%C92!A;&P@5$58
M5$%214$M<R!I;B!T:&4@9&]C=6UE;G0@=VET:"!(5$U,07)E82US+B`J+PI(
M5$U,07)E82YR97!L86-E06QL(#T@9G5N8W1I;VXH8V]N9FEG*2!["@EV87(@
M=&%S(#T@9&]C=6UE;G0N9V5T16QE;65N='-">51A9TYA;64H(G1E>'1A<F5A
M(BD["@EF;W(@*'9A<B!I(#T@=&%S+FQE;F=T:#L@:2`^(#`[("AN97<@2%1-
M3$%R96$H=&%S6RTM:5TL(&-O;F9I9RDI+F=E;F5R871E*"DI.PI].PH*+RHJ
M($AE;'!E<B!F=6YC=&EO;CH@<F5P;&%C97,@=&AE(%1%6%1!4D5!('=I=&@@
M=&AE(&=I=F5N($E$('=I=&@@2%1-3$%R96$N("HO"DA434Q!<F5A+G)E<&QA
M8V4@/2!F=6YC=&EO;BAI9"P@8V]N9FEG*2!["@EV87(@=&$@/2!(5$U,07)E
M82YG971%;&5M96YT0GE)9"@B=&5X=&%R96$B+"!I9"D["@ER971U<FX@=&$@
M/R`H;F5W($A434Q!<F5A*'1A+"!C;VYF:6<I*2YG96YE<F%T92@I(#H@;G5L
M;#L*?3L*"B\O($-R96%T97,@=&AE('1O;VQB87(@86YD(&%P<&5N9',@:70@
M=&\@=&AE(%]H=&UL87)E80I(5$U,07)E82YP<F]T;W1Y<&4N7V-R96%T951O
M;VQB87(@/2!F=6YC=&EO;B`H*2!["@EV87(@961I=&]R(#T@=&AI<SL)+R\@
M=&\@86-C97-S('1H:7,@:6X@;F5S=&5D(&9U;F-T:6]N<PH*"79A<B!T;V]L
M8F%R(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@B9&EV(BD["@ET:&ES+E]T
M;V]L8F%R(#T@=&]O;&)A<CL*"71O;VQB87(N8VQA<W-.86UE(#T@(G1O;VQB
M87(B.PH)=&]O;&)A<BYU;G-E;&5C=&%B;&4@/2`B,2(["@EV87(@=&)?<F]W
M(#T@;G5L;#L*"79A<B!T8E]O8FIE8W1S(#T@;F5W($]B:F5C="@I.PH)=&AI
M<RY?=&]O;&)A<D]B:F5C=',@/2!T8E]O8FIE8W1S.PH*"2\O(&-R96%T97,@
M82!N97<@;&EN92!I;B!T:&4@=&]O;&)A<@H)9G5N8W1I;VX@;F5W3&EN92@I
M('L*"0EV87(@=&%B;&4@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*")T86)L
M92(I.PH)"71A8FQE+F)O<F1E<B`]("(P<'@B.PH)"71A8FQE+F-E;&Q3<&%C
M:6YG(#T@(C!P>"(["@D)=&%B;&4N8V5L;%!A9&1I;F<@/2`B,'!X(CL*"0ET
M;V]L8F%R+F%P<&5N9$-H:6QD*'1A8FQE*3L*"0DO+R!40D]$62!I<R!R97%U
M:7)E9"!F;W(@244L(&]T:&5R=VES92!Y;W4@9&]N)W0@<V5E(&%N>71H:6YG
M"@D)+R\@:6X@=&AE(%1!0DQ%+@H)"79A<B!T8E]B;V1Y(#T@9&]C=6UE;G0N
M8W)E871E16QE;65N="@B=&)O9'DB*3L*"0ET86)L92YA<'!E;F1#:&EL9"AT
M8E]B;V1Y*3L*"0ET8E]R;W<@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*")T
M<B(I.PH)"71B7V)O9'DN87!P96YD0VAI;&0H=&)?<F]W*3L*"7T[("\O($5.
M1"!O9B!F=6YC=&EO;CH@;F5W3&EN90H)+R\@:6YI="!F:7)S="!L:6YE"@EN
M97=,:6YE*"D["@H)+R\@=7!D871E<R!T:&4@<W1A=&4@;V8@82!T;V]L8F%R
M(&5L96UE;G0N("!4:&ES(&9U;F-T:6]N(&ES(&UE;6)E<B!O9@H)+R\@82!T
M;V]L8F%R(&5L96UE;G0@;V)J96-T("AU;FYA;65D(&]B:F5C=',@8W)E871E
M9"!B>2!C<F5A=&5"=71T;VX@;W(*"2\O(&-R96%T95-E;&5C="!F=6YC=&EO
M;G,@8F5L;W<I+@H)9G5N8W1I;VX@<V5T0G5T=&]N4W1A='5S*&ED+"!N97=V
M86PI('L*"0EV87(@;VQD=F%L(#T@=&AI<UMI9%T["@D)=F%R(&5L(#T@=&AI
M<RYE;&5M96YT.PH)"6EF("AO;&1V86P@(3T@;F5W=F%L*2!["@D)"7-W:71C
M:"`H:60I('L*"0D)("`@(&-A<V4@(F5N86)L960B.@H)"0D):68@*&YE=W9A
M;"D@>PH)"0D)"4A434Q!<F5A+E]R96UO=F5#;&%S<RAE;"P@(F)U='1O;D1I
M<V%B;&5D(BD["@D)"0D)96PN9&ES86)L960@/2!F86QS93L*"0D)"7T@96QS
M92!["@D)"0D)2%1-3$%R96$N7V%D9$-L87-S*&5L+"`B8G5T=&]N1&ES86)L
M960B*3L*"0D)"0EE;"YD:7-A8FQE9"`]('1R=64["@D)"0E]"@D)"0EB<F5A
M:SL*"0D)("`@(&-A<V4@(F%C=&EV92(Z"@D)"0EI9B`H;F5W=F%L*2!["@D)
M"0D)2%1-3$%R96$N7V%D9$-L87-S*&5L+"`B8G5T=&]N4')E<W-E9"(I.PH)
M"0D)?2!E;'-E('L*"0D)"0E(5$U,07)E82Y?<F5M;W9E0VQA<W,H96PL(")B
M=71T;VY0<F5S<V5D(BD["@D)"0E]"@D)"0EB<F5A:SL*"0D)?0H)"0ET:&ES
M6VED72`](&YE=W9A;#L*"0E]"@E].R`O+R!%3D0@;V8@9G5N8W1I;VXZ('-E
M=$)U='1O;E-T871U<PH*"2\O('1H:7,@9G5N8W1I;VX@=VEL;"!H86YD;&4@
M8W)E871I;VX@;V8@8V]M8F\@8F]X97,N("!296-E:79E<R!A<PH)+R\@<&%R
M86UE=&5R('1H92!N86UE(&]F(&$@8G5T=&]N(&%S(&1E9FEN960@:6X@=&AE
M('1O;VQ"87(@8V]N9FEG+@H)+R\@5&AI<R!F=6YC=&EO;B!I<R!C86QL960@
M9G)O;2!C<F5A=&5"=71T;VXL(&%B;W9E+"!I9B!T:&4@9VEV96X@(G1X="(*
M"2\O(&1O97-N)W0@;6%T8V@@82!B=71T;VXN"@EF=6YC=&EO;B!C<F5A=&53
M96QE8W0H='AT*2!["@D)=F%R(&]P=&EO;G,@/2!N=6QL.PH)"79A<B!E;"`]
M(&YU;&P["@D)=F%R(&-M9"`](&YU;&P["@D)=F%R(&-U<W1O;5-E;&5C=',@
M/2!E9&ET;W(N8V]N9FEG+F-U<W1O;5-E;&5C=',["@D)=F%R(&-O;G1E>'0@
M/2!N=6QL.PH)"79A<B!T;V]L=&EP(#T@(B(["@D)<W=I=&-H("AT>'0I('L*
M"0D@("`@8V%S92`B9F]N='-I>F4B.@H)"2`@("!C87-E(")F;VYT;F%M92(Z
M"@D)("`@(&-A<V4@(F9O<FUA=&)L;V-K(CH*"0D)+R\@=&AE(&9O;&QO=VEN
M9R!L:6YE(')E=')I979E<R!T:&4@8V]R<F5C=`H)"0DO+R!C;VYF:6=U<F%T
M:6]N(&]P=&EO;B!B96-A=7-E('1H92!V87)I86)L92!N86UE"@D)"2\O(&EN
M<VED92!T:&4@0V]N9FEG(&]B:F5C="!I<R!N86UE9"!T:&4@<V%M92!A<R!T
M:&4*"0D)+R\@8G5T=&]N+W-E;&5C="!I;B!T:&4@=&]O;&)A<BX@($9O<B!I
M;G-T86YC92P@:68@='AT"@D)"2\O(#T](")F;W)M871B;&]C:R(@=V4@<F5T
M<FEE=F4@8V]N9FEG+F9O<FUA=&)L;V-K("AO<@H)"0DO+R!A(&1I9F9E<F5N
M="!W87D@=&\@=W)I=&4@:70@:6X@2E,@:7,*"0D)+R\@8V]N9FEG6R)F;W)M
M871B;&]C:R)=+@H)"0EO<'1I;VYS(#T@961I=&]R+F-O;F9I9UMT>'1=.PH)
M"0EC;60@/2!T>'0["@D)"6)R96%K.PH)"2`@("!D969A=6QT.@H)"0DO+R!T
M<GD@=&\@9F5T8V@@:70@9G)O;2!T:&4@;&ES="!O9B!R96=I<W1E<F5D('-E
M;&5C=',*"0D)8VUD(#T@='AT.PH)"0EV87(@9')O<&1O=VX@/2!C=7-T;VU3
M96QE8W1S6V-M9%T["@D)"6EF("AT>7!E;V8@9')O<&1O=VX@(3T@(G5N9&5F
M:6YE9"(I('L*"0D)"6]P=&EO;G,@/2!D<F]P9&]W;BYO<'1I;VYS.PH)"0D)
M8V]N=&5X="`](&1R;W!D;W=N+F-O;G1E>'0["@D)"0EI9B`H='EP96]F(&1R
M;W!D;W=N+G1O;VQT:7`@(3T@(G5N9&5F:6YE9"(I('L*"0D)"0ET;V]L=&EP
M(#T@9')O<&1O=VXN=&]O;'1I<#L*"0D)"7T*"0D)?2!E;'-E('L*"0D)"6%L
M97)T*")%4E)/4B!;8W)E871E4V5L96-T73I<;D-A;B=T(&9I;F0@=&AE(')E
M<75E<W1E9"!D<F]P9&]W;B!D969I;FET:6]N(BD["@D)"7T*"0D)8G)E86L[
M"@D)?0H)"6EF("AO<'1I;VYS*2!["@D)"65L(#T@9&]C=6UE;G0N8W)E871E
M16QE;65N="@B<V5L96-T(BD["@D)"65L+G1I=&QE(#T@=&]O;'1I<#L*"0D)
M=F%R(&]B:B`]('L*"0D)"6YA;64).B!T>'0L("\O(&9I96QD(&YA;64*"0D)
M"65L96UE;G0@.B!E;"P)+R\@=&AE(%5)(&5L96UE;G0@*%-%3$5#5"D*"0D)
M"65N86)L960@.B!T<G5E+"`O+R!I<R!I="!E;F%B;&5D/PH)"0D)=&5X=`DZ
M(&9A;'-E+"`O+R!E;F%B;&5D(&EN('1E>'0@;6]D93\*"0D)"6-M9`DZ(&-M
M9"P@+R\@8V]M;6%N9"!)1`H)"0D)<W1A=&4).B!S971"=71T;VY3=&%T=7,L
M("\O(&9O<B!C:&%N9VEN9R!S=&%T90H)"0D)8V]N=&5X="`Z(&-O;G1E>'0*
M"0D)?3L*"0D)=&)?;V)J96-T<UMT>'1=(#T@;V)J.PH)"0EF;W(@*'9A<B!I
M(&EN(&]P=&EO;G,I('L*"0D)"79A<B!O<"`](&1O8W5M96YT+F-R96%T945L
M96UE;G0H(F]P=&EO;B(I.PH)"0D);W`N:6YN97)(5$U,(#T@:3L*"0D)"6]P
M+G9A;'5E(#T@;W!T:6]N<UMI73L*"0D)"65L+F%P<&5N9$-H:6QD*&]P*3L*
M"0D)?0H)"0E(5$U,07)E82Y?861D179E;G0H96PL(")C:&%N9V4B+"!F=6YC
M=&EO;B`H*2!["@D)"0EE9&ET;W(N7V-O;6)O4V5L96-T960H96PL('1X="D[
M"@D)"7TI.PH)"7T*"0ER971U<FX@96P["@E].R`O+R!%3D0@;V8@9G5N8W1I
M;VXZ(&-R96%T95-E;&5C=`H*"2\O(&%P<&5N9',@82!N97<@8G5T=&]N('1O
M('1O;VQB87(*"69U;F-T:6]N(&-R96%T94)U='1O;BAT>'0I('L*"0DO+R!T
M:&4@96QE;65N="!T:&%T('=I;&P@8F4@8W)E871E9`H)"79A<B!E;"`](&YU
M;&P["@D)=F%R(&)T;B`](&YU;&P["@D)<W=I=&-H("AT>'0I('L*"0D@("`@
M8V%S92`B<V5P87)A=&]R(CH*"0D)96P@/2!D;V-U;65N="YC<F5A=&5%;&5M
M96YT*")D:78B*3L*"0D)96PN8VQA<W-.86UE(#T@(G-E<&%R871O<B(["@D)
M"6)R96%K.PH)"2`@("!C87-E(")S<&%C92(Z"@D)"65L(#T@9&]C=6UE;G0N
M8W)E871E16QE;65N="@B9&EV(BD["@D)"65L+F-L87-S3F%M92`](")S<&%C
M92(["@D)"6)R96%K.PH)"2`@("!C87-E(")L:6YE8G)E86LB.@H)"0EN97=,
M:6YE*"D["@D)"7)E='5R;B!F86QS93L*"0D@("`@8V%S92`B=&5X=&EN9&EC
M871O<B(Z"@D)"65L(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@B9&EV(BD[
M"@D)"65L+F%P<&5N9$-H:6QD*&1O8W5M96YT+F-R96%T951E>'1.;V1E*")!
M(BDI.PH)"0EE;"YC;&%S<TYA;64@/2`B:6YD:6-A=&]R(CL*"0D)96PN=&ET
M;&4@/2!(5$U,07)E82Y),3A.+G1O;VQT:7!S+G1E>'1I;F1I8V%T;W(["@D)
M"79A<B!O8FH@/2!["@D)"0EN86UE"3H@='AT+"`O+R!T:&4@8G5T=&]N(&YA
M;64@*&DN92X@)V)O;&0G*0H)"0D)96QE;65N="`Z(&5L+"`O+R!T:&4@54D@
M96QE;65N="`H1$E6*0H)"0D)96YA8FQE9"`Z('1R=64L("\O(&ES(&ET(&5N
M86)L960_"@D)"0EA8W1I=F4).B!F86QS92P@+R\@:7,@:70@<')E<W-E9#\*
M"0D)"71E>'0).B!F86QS92P@+R\@96YA8FQE9"!I;B!T97AT(&UO9&4_"@D)
M"0EC;60).B`B=&5X=&EN9&EC871O<B(L("\O('1H92!C;VUM86YD($E$"@D)
M"0ES=&%T90DZ('-E=$)U='1O;E-T871U<R`O+R!F;W(@8VAA;F=I;F<@<W1A
M=&4*"0D)?3L*"0D)=&)?;V)J96-T<UMT>'1=(#T@;V)J.PH)"0EB<F5A:SL*
M"0D@("`@9&5F875L=#H*"0D)8G1N(#T@961I=&]R+F-O;F9I9RYB=&Y,:7-T
M6W1X=%T["@D)?0H)"6EF("@A96P@)B8@8G1N*2!["@D)"65L(#T@9&]C=6UE
M;G0N8W)E871E16QE;65N="@B9&EV(BD["@D)"65L+G1I=&QE(#T@8G1N6S!=
M.PH)"0EE;"YC;&%S<TYA;64@/2`B8G5T=&]N(CL*"0D)+R\@;&5T)W,@:G5S
M="!P<F5T96YD('=E(&AA=F4@82!B=71T;VX@;V)J96-T+"!A;F0*"0D)+R\@
M87-S:6=N(&%L;"!T:&4@;F5E9&5D(&EN9F]R;6%T:6]N('1O(&ET+@H)"0EV
M87(@;V)J(#T@>PH)"0D);F%M90DZ('1X="P@+R\@=&AE(&)U='1O;B!N86UE
M("AI+F4N("=B;VQD)RD*"0D)"65L96UE;G0@.B!E;"P@+R\@=&AE(%5)(&5L
M96UE;G0@*$1)5BD*"0D)"65N86)L960@.B!T<G5E+"`O+R!I<R!I="!E;F%B
M;&5D/PH)"0D)86-T:79E"3H@9F%L<V4L("\O(&ES(&ET('!R97-S960_"@D)
M"0ET97AT"3H@8G1N6S)=+"`O+R!E;F%B;&5D(&EN('1E>'0@;6]D93\*"0D)
M"6-M9`DZ(&)T;ELS72P@+R\@=&AE(&-O;6UA;F0@240*"0D)"7-T871E"3H@
M<V5T0G5T=&]N4W1A='5S+"`O+R!F;W(@8VAA;F=I;F<@<W1A=&4*"0D)"6-O
M;G1E>'0@.B!B=&Y;-%T@?'P@;G5L;"`O+R!E;F%B;&5D(&EN(&$@8V5R=&%I
M;B!C;VYT97AT/PH)"0E].PH)"0ET8E]O8FIE8W1S6W1X=%T@/2!O8FH["@D)
M"2\O(&AA;F1L97)S('1O(&5M=6QA=&4@;FEC92!F;&%T('1O;VQB87(@8G5T
M=&]N<PH)"0E(5$U,07)E82Y?861D179E;G0H96PL(")M;W5S96]V97(B+"!F
M=6YC=&EO;B`H*2!["@D)"0EI9B`H;V)J+F5N86)L960I('L*"0D)"0E(5$U,
M07)E82Y?861D0VQA<W,H96PL(")B=71T;VY(;W9E<B(I.PH)"0D)?0H)"0E]
M*3L*"0D)2%1-3$%R96$N7V%D9$5V96YT*&5L+"`B;6]U<V5O=70B+"!F=6YC
M=&EO;B`H*2!["@D)"0EI9B`H;V)J+F5N86)L960I('=I=&@@*$A434Q!<F5A
M*2!["@D)"0D)7W)E;6]V94-L87-S*&5L+"`B8G5T=&]N2&]V97(B*3L*"0D)
M"0E?<F5M;W9E0VQA<W,H96PL(")B=71T;VY!8W1I=F4B*3L*"0D)"0DH;V)J
M+F%C=&EV92D@)B8@7V%D9$-L87-S*&5L+"`B8G5T=&]N4')E<W-E9"(I.PH)
M"0D)?0H)"0E]*3L*"0D)2%1-3$%R96$N7V%D9$5V96YT*&5L+"`B;6]U<V5D
M;W=N(BP@9G5N8W1I;VX@*&5V*2!["@D)"0EI9B`H;V)J+F5N86)L960I('=I
M=&@@*$A434Q!<F5A*2!["@D)"0D)7V%D9$-L87-S*&5L+"`B8G5T=&]N06-T
M:79E(BD["@D)"0D)7W)E;6]V94-L87-S*&5L+"`B8G5T=&]N4')E<W-E9"(I
M.PH)"0D)"5]S=&]P179E;G0H:7-?:64@/R!W:6YD;W<N979E;G0@.B!E=BD[
M"@D)"0E]"@D)"7TI.PH)"0DO+R!W:&5N(&-L:6-K960L(&1O('1H92!F;VQL
M;W=I;F<Z"@D)"4A434Q!<F5A+E]A9&1%=F5N="AE;"P@(F-L:6-K(BP@9G5N
M8W1I;VX@*&5V*2!["@D)"0EI9B`H;V)J+F5N86)L960I('=I=&@@*$A434Q!
M<F5A*2!["@D)"0D)7W)E;6]V94-L87-S*&5L+"`B8G5T=&]N06-T:79E(BD[
M"@D)"0D)7W)E;6]V94-L87-S*&5L+"`B8G5T=&]N2&]V97(B*3L*"0D)"0EO
M8FHN8VUD*&5D:71O<BP@;V)J+FYA;64L(&]B:BD["@D)"0D)7W-T;W!%=F5N
M="AI<U]I92`_('=I;F1O=RYE=F5N="`Z(&5V*3L*"0D)"7T*"0D)?2D["@D)
M"79A<B!I;6<@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*")I;6<B*3L*"0D)
M:6UG+G-R8R`](&)T;ELQ73L*"0D):6UG+G-T>6QE+G=I9'1H(#T@(C$X<'@B
M.PH)"0EI;6<N<W1Y;&4N:&5I9VAT(#T@(C$X<'@B.PH)"0EE;"YA<'!E;F1#
M:&EL9"AI;6<I.PH)"7T@96QS92!I9B`H(65L*2!["@D)"65L(#T@8W)E871E
M4V5L96-T*'1X="D["@D)?0H)"6EF("AE;"D@>PH)"0EV87(@=&)?8V5L;"`]
M(&1O8W5M96YT+F-R96%T945L96UE;G0H(G1D(BD["@D)"71B7W)O=RYA<'!E
M;F1#:&EL9"AT8E]C96QL*3L*"0D)=&)?8V5L;"YA<'!E;F1#:&EL9"AE;"D[
M"@D)?2!E;'-E('L*"0D)86QE<G0H(D9)6$U%.B!5;FMN;W=N('1O;VQB87(@
M:71E;3H@(B`K('1X="D["@D)?0H)"7)E='5R;B!E;#L*"7T["@H)=F%R(&9I
M<G-T(#T@=')U93L*"69O<B`H=F%R(&D@/2`P.R!I(#P@=&AI<RYC;VYF:6<N
M=&]O;&)A<BYL96YG=&@[("LK:2D@>PH)"6EF("@A9FER<W0I('L*"0D)8W)E
M871E0G5T=&]N*")L:6YE8G)E86LB*3L*"0E](&5L<V4@>PH)"0EF:7)S="`]
M(&9A;'-E.PH)"7T*"0EV87(@9W)O=7`@/2!T:&ES+F-O;F9I9RYT;V]L8F%R
M6VE=.PH)"69O<B`H=F%R(&H@/2`P.R!J(#P@9W)O=7`N;&5N9W1H.R`K*VHI
M('L*"0D)=F%R(&-O9&4@/2!G<F]U<%MJ73L*"0D):68@*"]>*%M)5%TI7%LH
M+BH_*5Q=+RYT97-T*&-O9&4I*2!["@D)"0DO+R!S<&5C:6%L(&-A<V4L(&-R
M96%T92!T97AT(&QA8F5L"@D)"0EV87(@;#=E9"`](%)E9T5X<"XD,2`]/2`B
M22([("\O(&QO8V%L:7IE9#\*"0D)"79A<B!L86)E;"`](%)E9T5X<"XD,CL*
M"0D)"6EF("AL-V5D*2!["@D)"0D);&%B96P@/2!(5$U,07)E82Y),3A.+F-U
M<W1O;5ML86)E;%T["@D)"0E]"@D)"0EV87(@=&)?8V5L;"`](&1O8W5M96YT
M+F-R96%T945L96UE;G0H(G1D(BD["@D)"0ET8E]R;W<N87!P96YD0VAI;&0H
M=&)?8V5L;"D["@D)"0ET8E]C96QL+F-L87-S3F%M92`](")L86)E;"(["@D)
M"0ET8E]C96QL+FEN;F5R2%1-3"`](&QA8F5L.PH)"0E](&5L<V4@>PH)"0D)
M8W)E871E0G5T=&]N*&-O9&4I.PH)"0E]"@D)?0H)?0H*"71H:7,N7VAT;6Q!
M<F5A+F%P<&5N9$-H:6QD*'1O;VQB87(I.PI].PH*2%1-3$%R96$N<')O=&]T
M>7!E+E]C<F5A=&53=&%T=7-"87(@/2!F=6YC=&EO;B@I('L*"79A<B!S=&%T
M=7-B87(@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*")D:78B*3L*"7-T871U
M<V)A<BYC;&%S<TYA;64@/2`B<W1A='5S0F%R(CL*"71H:7,N7VAT;6Q!<F5A
M+F%P<&5N9$-H:6QD*'-T871U<V)A<BD["@ET:&ES+E]S=&%T=7-"87(@/2!S
M=&%T=7-B87(["@DO+R!S=&%T=7-B87(N87!P96YD0VAI;&0H9&]C=6UE;G0N
M8W)E871E5&5X=$YO9&4H2%1-3$%R96$N23$X3BYM<V=;(E!A=&@B72`K("(Z
M("(I*3L*"2\O(&-R96%T97,@82!H;VQD97(@9F]R('1H92!P871H('9I97<*
M"61I=B`](&1O8W5M96YT+F-R96%T945L96UE;G0H(G-P86XB*3L*"61I=BYC
M;&%S<TYA;64@/2`B<W1A='5S0F%R5')E92(["@ED:78N:6YN97)(5$U,(#T@
M2%1-3$%R96$N23$X3BYM<V=;(E!A=&@B72`K("(Z("(["@ET:&ES+E]S=&%T
M=7-"87)4<F5E(#T@9&EV.PH)=&AI<RY?<W1A='5S0F%R+F%P<&5N9$-H:6QD
M*&1I=BD["@EI9B`H(71H:7,N8V]N9FEG+G-T871U<T)A<BD@>PH)"2\O(&1I
M<V%B;&4@:70N+BX*"0ES=&%T=7-B87(N<W1Y;&4N9&ES<&QA>2`](")N;VYE
M(CL*"7T*?3L*"B\O($-R96%T97,@=&AE($A434Q!<F5A(&]B:F5C="!A;F0@
M<F5P;&%C97,@=&AE('1E>'1A<F5A('=I=&@@:70N"DA434Q!<F5A+G!R;W1O
M='EP92YG96YE<F%T92`](&9U;F-T:6]N("@I('L*"79A<B!E9&ET;W(@/2!T
M:&ES.PDO+R!W92=L;"!N965D(")T:&ES(B!I;B!S;VUE(&YE<W1E9"!F=6YC
M=&EO;G,*"2\O(&=E="!T:&4@=&5X=&%R96$*"79A<B!T97AT87)E82`]('1H
M:7,N7W1E>'1!<F5A.PH):68@*'1Y<&5O9B!T97AT87)E82`]/2`B<W1R:6YG
M(BD@>PH)"2\O(&ET)W,@;F]T(&5L96UE;G0@8G5T($E$"@D)=&AI<RY?=&5X
M=$%R96$@/2!T97AT87)E82`]($A434Q!<F5A+F=E=$5L96UE;G1">4ED*")T
M97AT87)E82(L('1E>'1A<F5A*3L*"7T*"71H:7,N7W1A7W-I>F4@/2!["@D)
M=SH@=&5X=&%R96$N;V9F<V5T5VED=&@L"@D):#H@=&5X=&%R96$N;V9F<V5T
M2&5I9VAT"@E].PH)=&5X=&%R96$N<W1Y;&4N9&ES<&QA>2`](")N;VYE(CL*
M"@DO+R!C<F5A=&4@=&AE(&5D:71O<B!F<F%M97=O<FL*"79A<B!H=&UL87)E
M82`](&1O8W5M96YT+F-R96%T945L96UE;G0H(F1I=B(I.PH):'1M;&%R96$N
M8VQA<W-.86UE(#T@(FAT;6QA<F5A(CL*"71H:7,N7VAT;6Q!<F5A(#T@:'1M
M;&%R96$["@H)+R\@:6YS97)T('1H92!E9&ET;W(@8F5F;W)E('1H92!T97AT
M87)E82X*"71E>'1A<F5A+G!A<F5N=$YO9&4N:6YS97)T0F5F;W)E*&AT;6QA
M<F5A+"!T97AT87)E82D["@H):68@*'1E>'1A<F5A+F9O<FTI('L*"0DO+R!W
M92!H879E(&$@9F]R;2P@;VX@<W5B;6ET(&=E="!T:&4@2%1-3$%R96$@8V]N
M=&5N="!A;F0*"0DO+R!U<&1A=&4@;W)I9VEN86P@=&5X=&%R96$N"@D)=F%R
M(&8@/2!T97AT87)E82YF;W)M.PH)"6EF("AT>7!E;V8@9BYO;G-U8FUI="`]
M/2`B9G5N8W1I;VXB*2!["@D)"79A<B!F=6YC<F5F(#T@9BYO;G-U8FUI=#L*
M"0D):68@*'1Y<&5O9B!F+E]?;7-H7W!R979/;E-U8FUI="`]/2`B=6YD969I
M;F5D(BD@>PH)"0D)9BY?7VUS:%]P<F5V3VY3=6)M:70@/2!;73L*"0D)?0H)
M"0EF+E]?;7-H7W!R979/;E-U8FUI="YP=7-H*&9U;F-R968I.PH)"7T*"0EF
M+F]N<W5B;6ET(#T@9G5N8W1I;VXH*2!["@D)"65D:71O<BY?=&5X=$%R96$N
M=F%L=64@/2!E9&ET;W(N9V5T2%1-3"@I.PH)"0EV87(@82`]('1H:7,N7U]M
M<VA?<')E=D]N4W5B;6ET.PH)"0DO+R!C86QL('!R979I;W5S('-U8FUI="!M
M971H;V1S(&EF('1H97D@=V5R92!T:&5R92X*"0D):68@*'1Y<&5O9B!A("$]
M(")U;F1E9FEN960B*2!["@D)"0EF;W(@*'9A<B!I(#T@82YL96YG=&@[("TM
M:2`^/2`P.RD@>PH)"0D)"6%;:5TH*3L*"0D)"7T*"0D)?0H)"7T["@D):68@
M*'1Y<&5O9B!F+F]N<F5S970@/3T@(F9U;F-T:6]N(BD@>PH)"0EV87(@9G5N
M8W)E9B`](&8N;VYR97-E=#L*"0D):68@*'1Y<&5O9B!F+E]?;7-H7W!R979/
M;E)E<V5T(#T](")U;F1E9FEN960B*2!["@D)"0EF+E]?;7-H7W!R979/;E)E
M<V5T(#T@6UT["@D)"7T*"0D)9BY?7VUS:%]P<F5V3VY297-E="YP=7-H*&9U
M;F-R968I.PH)"7T*"0EF+F]N<F5S970@/2!F=6YC=&EO;B@I('L*"0D)961I
M=&]R+G-E=$A434PH961I=&]R+E]T97AT07)E82YV86QU92D["@D)"65D:71O
M<BYU<&1A=&54;V]L8F%R*"D["@D)"79A<B!A(#T@=&AI<RY?7VUS:%]P<F5V
M3VY297-E=#L*"0D)+R\@8V%L;"!P<F5V:6]U<R!R97-E="!M971H;V1S(&EF
M('1H97D@=V5R92!T:&5R92X*"0D):68@*'1Y<&5O9B!A("$](")U;F1E9FEN
M960B*2!["@D)"0EF;W(@*'9A<B!I(#T@82YL96YG=&@[("TM:2`^/2`P.RD@
M>PH)"0D)"6%;:5TH*3L*"0D)"7T*"0D)?0H)"7T["@E]"@H)+R\@861D(&$@
M:&%N9&QE<B!F;W(@=&AE(")B86-K+V9O<G=A<F0B(&-A<V4@+2T@;VX@8F]D
M>2YU;FQO860@=V4@<V%V90H)+R\@=&AE($A434P@8V]N=&5N="!I;G1O('1H
M92!O<FEG:6YA;"!T97AT87)E82X*"71R>2!["@D)=VEN9&]W+F]N=6YL;V%D
M(#T@9G5N8W1I;VXH*2!["@D)"65D:71O<BY?=&5X=$%R96$N=F%L=64@/2!E
M9&ET;W(N9V5T2%1-3"@I.PH)"7T["@E](&-A=&-H*&4I('M].PH*"2\O(&-R
M96%T97,@)B!A<'!E;F1S('1H92!T;V]L8F%R"@ET:&ES+E]C<F5A=&54;V]L
M8F%R*"D["@H)+R\@8W)E871E('1H92!)1E)!344*"79A<B!I9G)A;64@/2!D
M;V-U;65N="YC<F5A=&5%;&5M96YT*")I9G)A;64B*3L*"@DO+R!W;W)K87)O
M=6YD(&9O<B!T:&4@2%144%,@<')O8FQE;0H)+R\@:69R86UE+G-E=$%T=')I
M8G5T92@B<W)C(BP@(FIA=F%S8W)I<'0Z=F]I9"@P*3LB*3L*"6EF<F%M92YS
M<F,@/2!?961I=&]R7W5R;"`K(")P;W!U<',O8FQA;FLN:'1M;"(["@H):'1M
M;&%R96$N87!P96YD0VAI;&0H:69R86UE*3L*"@ET:&ES+E]I9G)A;64@/2!I
M9G)A;64["@H)+R\@8W)E871E<R`F(&%P<&5N9',@=&AE('-T871U<R!B87(L
M(&EF('1H92!C87-E"@ET:&ES+E]C<F5A=&53=&%T=7-"87(H*3L*"@DO+R!R
M96UO=F4@=&AE(&1E9F%U;'0@8F]R9&5R(&%S(&ET(&ME97!S('5S(&9R;VT@
M8V]M<'5T:6YG(&-O<G)E8W1L>0H)+R\@=&AE('-I>F5S+B`@*'-O;65B;V1Y
M('1E;&P@;64@=VAY(&1O97-N)W0@=&AI<R!W;W)K(&EN($E%*0H*"6EF("@A
M2%1-3$%R96$N:7-?:64I('L*"0EI9G)A;64N<W1Y;&4N8F]R9&5R5VED=&@@
M/2`B,7!X(CL*"2\O(&EF<F%M92YF<F%M94)O<F1E<B`]("(Q(CL*"2\O(&EF
M<F%M92YM87)G:6Y(96EG:'0@/2`B,"(["@DO+R!I9G)A;64N;6%R9VEN5VED
M=&@@/2`B,"(["@E]"@H)+R\@<VEZ92!T:&4@249204U%(&%C8V]R9&EN9R!T
M;R!U<V5R)W,@<')E9G,@;W(@:6YI=&EA;"!T97AT87)E80H)=F%R(&AE:6=H
M="`]("AT:&ES+F-O;F9I9RYH96EG:'0@/3T@(F%U=&\B(#\@*'1H:7,N7W1A
M7W-I>F4N:"`K(")P>"(I(#H@=&AI<RYC;VYF:6<N:&5I9VAT*3L*"6AE:6=H
M="`]('!A<G-E26YT*&AE:6=H="D["@EV87(@=VED=&@@/2`H=&AI<RYC;VYF
M:6<N=VED=&@@/3T@(F%U=&\B(#\@*'1H:7,N7W1A7W-I>F4N=R`K(")P>"(I
M(#H@=&AI<RYC;VYF:6<N=VED=&@I.PH)=VED=&@@/2!P87)S94EN="AW:61T
M:"D["@H):68@*"%(5$U,07)E82YI<U]I92D@>PH)"6AE:6=H="`M/2`R.PH)
M"7=I9'1H("T](#(["@E]"@H):69R86UE+G-T>6QE+G=I9'1H(#T@=VED=&@@
M*R`B<'@B.PH):68@*'1H:7,N8V]N9FEG+G-I>F5);F-L=61E<U1O;VQB87(I
M('L*"0DO+R!S=6)S=')A8W0@=&]O;&)A<B!H96EG:'0*"0EH96EG:'0@+3T@
M=&AI<RY?=&]O;&)A<BYO9F9S971(96EG:'0["@D):&5I9VAT("T]('1H:7,N
M7W-T871U<T)A<BYO9F9S971(96EG:'0["@E]"@EI9B`H:&5I9VAT(#P@,"D@
M>PH)"6AE:6=H="`](#`["@E]"@EI9G)A;64N<W1Y;&4N:&5I9VAT(#T@:&5I
M9VAT("L@(G!X(CL*"@DO+R!T:&4@961I=&]R(&EN8VQU9&EN9R!T:&4@=&]O
M;&)A<B!N;W<@:&%V92!T:&4@<V%M92!S:7IE(&%S('1H90H)+R\@;W)I9VEN
M86P@=&5X=&%R96$N+B!W:&EC:"!M96%N<R!T:&%T('=E(&YE960@=&\@<F5D
M=6-E('1H870@82!B:70N"@ET97AT87)E82YS='EL92YW:61T:"`](&EF<F%M
M92YS='EL92YW:61T:#L*(`ET97AT87)E82YS='EL92YH96EG:'0@/2!I9G)A
M;64N<W1Y;&4N:&5I9VAT.PH*"2\O($E-4$]25$%.5#H@=V4@:&%V92!T;R!A
M;&QO=R!-;WII;&QA(&$@<VAO<G0@=&EM92!T;R!R96-O9VYI>F4@=&AE"@DO
M+R!N97<@9G)A;64N("!/=&AE<G=I<V4@=V4@9V5T(&$@<W1U<&ED(&5X8V5P
M=&EO;BX*"69U;F-T:6]N(&EN:71)9G)A;64H*2!["@D)=F%R(&1O8R`](&5D
M:71O<BY?:69R86UE+F-O;G1E;G17:6YD;W<N9&]C=6UE;G0["@D):68@*"%D
M;V,I('L*"0D)+R\@5')Y(&%G86EN+BX*"0D)+R\@1DE8344Z(&1O;B=T(&MN
M;W<@=VAA="!E;'-E('1O(&1O(&AE<F4N("!.;W)M86QL>0H)"0DO+R!W92=L
M;"!N979E<B!R96%C:"!T:&ES('!O:6YT+@H)"0EI9B`H2%1-3$%R96$N:7-?
M9V5C:V\I('L*"0D)"7-E=%1I;65O=70H:6YI=$EF<F%M92P@,3`P*3L*"0D)
M"7)E='5R;B!F86QS93L*"0D)?2!E;'-E('L*"0D)"6%L97)T*")%4E)/4CH@
M249204U%(&-A;B=T(&)E(&EN:71I86QI>F5D+B(I.PH)"0E]"@D)?0H)"6EF
M("A(5$U,07)E82YI<U]G96-K;RD@>PH)"0DO+R!E;F%B;&4@961I=&%B;&4@
M;6]D92!F;W(@36]Z:6QL80H)"0ED;V,N9&5S:6=N36]D92`](")O;B(["@D)
M?0H)"65D:71O<BY?9&]C(#T@9&]C.PH)"6EF("@A961I=&]R+F-O;F9I9RYF
M=6QL4&%G92D@>PH)"0ED;V,N;W!E;B@I.PH)"0EV87(@:'1M;"`]("(\:'1M
M;#Y<;B(["@D)"6AT;6P@*ST@(CQH96%D/EQN(CL*"0D):68@*&5D:71O<BYC
M;VYF:6<N8F%S95523"D*"0D)"6AT;6P@*ST@)SQB87-E(&AR968](B<@*R!E
M9&ET;W(N8V]N9FEG+F)A<V554DP@*R`G(B`O/B<["@D)"6AT;6P@*ST@(CQS
M='EL93XB("L@961I=&]R+F-O;F9I9RYP86=E4W1Y;&4@*PH)"0D)(B!H=&UL
M+&)O9'D@>R!B;W)D97(Z(#!P>#L@?3PO<W1Y;&4^7&XB.PH)"0EH=&UL("L]
M("(\+VAE860^7&XB.PH)"0EH=&UL("L]("(\8F]D>3Y<;B(["@D)"6AT;6P@
M*ST@961I=&]R+E]T97AT07)E82YV86QU93L*"0D):'1M;"`K/2`B/"]B;V1Y
M/EQN(CL*"0D):'1M;"`K/2`B/"]H=&UL/B(["@D)"61O8RYW<FET92AH=&UL
M*3L*"0D)9&]C+F-L;W-E*"D["@D)?2!E;'-E('L*"0D)=F%R(&AT;6P@/2!E
M9&ET;W(N7W1E>'1!<F5A+G9A;'5E.PH)"0EI9B`H:'1M;"YM871C:"A(5$U,
M07)E82Y215]D;V-T>7!E*2D@>PH)"0D)961I=&]R+G-E=$1O8W1Y<&4H4F5G
M17AP+B0Q*3L*"0D)"6AT;6P@/2!H=&UL+G)E<&QA8V4H2%1-3$%R96$N4D5?
M9&]C='EP92P@(B(I.PH)"0E]"@D)"61O8RYO<&5N*"D["@D)"61O8RYW<FET
M92AH=&UL*3L*"0D)9&]C+F-L;W-E*"D["@D)?0H*"0EI9B`H2%1-3$%R96$N
M:7-?:64I('L*"0D)+R\@96YA8FQE(&5D:71A8FQE(&UO9&4@9F]R($E%+@D@
M1F]R('-O;64@<F5A<V]N('1H:7,*"0D)+R\@9&]E<VXG="!W;W)K(&EF(&1O
M;F4@:6X@=&AE('-A;64@<&QA8V4@87,@9F]R($=E8VMO"@D)"2\O("AA8F]V
M92DN"@D)"61O8RYB;V1Y+F-O;G1E;G1%9&ET86)L92`]('1R=64["@D)?0H*
M"0EE9&ET;W(N9F]C=7-%9&ET;W(H*3L*"0DO+R!I;G1E<F-E<'0@<V]M92!E
M=F5N=',[(&9O<B!U<&1A=&EN9R!T:&4@=&]O;&)A<B`F(&ME>6)O87)D(&AA
M;F1L97)S"@D)2%1-3$%R96$N7V%D9$5V96YT<PH)"0DH9&]C+"!;(FME>61O
M=VXB+"`B:V5Y<')E<W,B+"`B;6]U<V5D;W=N(BP@(FUO=7-E=7`B+"`B9')A
M9R)=+`H)"0D@9G5N8W1I;VX@*&5V96YT*2!["@D)"0D@<F5T=7)N(&5D:71O
M<BY?961I=&]R179E;G0H2%1-3$%R96$N:7-?:64@/R!E9&ET;W(N7VEF<F%M
M92YC;VYT96YT5VEN9&]W+F5V96YT(#H@979E;G0I.PH)"0D@?2D["@H)"2\O
M(&-H96-K(&EF(&%N>2!P;'5G:6YS(&AA=F4@<F5G:7-T97)E9"!R969R97-H
M(&AA;F1L97)S"@D)9F]R("AV87(@:2!I;B!E9&ET;W(N<&QU9VEN<RD@>PH)
M"0EV87(@<&QU9VEN(#T@961I=&]R+G!L=6=I;G-;:5TN:6YS=&%N8V4["@D)
M"6EF("AT>7!E;V8@<&QU9VEN+F]N1V5N97)A=&4@/3T@(F9U;F-T:6]N(BD*
M"0D)"7!L=6=I;BYO;D=E;F5R871E*"D["@D)"6EF("AT>7!E;V8@<&QU9VEN
M+F]N1V5N97)A=&5/;F-E(#T](")F=6YC=&EO;B(I('L*"0D)"7!L=6=I;BYO
M;D=E;F5R871E3VYC92@I.PH)"0D)<&QU9VEN+F]N1V5N97)A=&5/;F-E(#T@
M;G5L;#L*"0D)?0H)"7T*"@D)<V5T5&EM96]U="AF=6YC=&EO;B@I('L*"0D)
M961I=&]R+G5P9&%T951O;VQB87(H*3L*"0E]+"`R-3`I.PH*"0EI9B`H='EP
M96]F(&5D:71O<BYO;D=E;F5R871E(#T](")F=6YC=&EO;B(I"@D)"65D:71O
M<BYO;D=E;F5R871E*"D["@E].PH)<V5T5&EM96]U="AI;FET269R86UE+"`Q
M,#`I.PH)<F5T=7)N('1H:7,["GT["@HO+R!3=VET8VAE<R!E9&ET;W(@;6]D
M93L@<&%R86UE=&5R(&-A;B!B92`B=&5X=&UO9&4B(&]R(")W>7-I=WEG(BX@
M($EF(&YO"B\O('!A<F%M971E<B!W87,@<&%S<V5D('1H:7,@9G5N8W1I;VX@
M=&]G9VQE<R!B971W965N(&UO9&5S+@I(5$U,07)E82YP<F]T;W1Y<&4N<V5T
M36]D92`](&9U;F-T:6]N*&UO9&4I('L*"6EF("AT>7!E;V8@;6]D92`]/2`B
M=6YD969I;F5D(BD@>PH)"6UO9&4@/2`H*'1H:7,N7V5D:71-;V1E(#T](")T
M97AT;6]D92(I(#\@(G=Y<VEW>6<B(#H@(G1E>'1M;V1E(BD["@E]"@ES=VET
M8V@@*&UO9&4I('L*"2`@("!C87-E(")T97AT;6]D92(Z"@D)=&AI<RY?=&5X
M=$%R96$N=F%L=64@/2!T:&ES+F=E=$A434PH*3L*"0ET:&ES+E]I9G)A;64N
M<W1Y;&4N9&ES<&QA>2`](")N;VYE(CL*"0ET:&ES+E]T97AT07)E82YS='EL
M92YD:7-P;&%Y(#T@(F)L;V-K(CL*"0EI9B`H=&AI<RYC;VYF:6<N<W1A='5S
M0F%R*2!["@D)"71H:7,N7W-T871U<T)A<BYI;FYE<DA434P@/2!(5$U,07)E
M82Y),3A.+FUS9ULB5$585%]-3T1%(ET["@D)?0H)"6)R96%K.PH)("`@(&-A
M<V4@(G=Y<VEW>6<B.@H)"6EF("A(5$U,07)E82YI<U]G96-K;RD@>PH)"0DO
M+R!D:7-A8FQE(&1E<VEG;B!M;V1E(&)E9F]R92!C:&%N9VEN9R!I;FYE<DA4
M34P*"0D)=')Y('L*"0D)"71H:7,N7V1O8RYD97-I9VY-;V1E(#T@(F]F9B([
M"@D)"7T@8V%T8V@H92D@>WT["@D)?0H)"6EF("@A=&AI<RYC;VYF:6<N9G5L
M;%!A9V4I"@D)"71H:7,N7V1O8RYB;V1Y+FEN;F5R2%1-3"`]('1H:7,N9V5T
M2%1-3"@I.PH)"65L<V4*"0D)=&AI<RYS971&=6QL2%1-3"AT:&ES+F=E=$A4
M34PH*2D["@D)=&AI<RY?:69R86UE+G-T>6QE+F1I<W!L87D@/2`B8FQO8VLB
M.PH)"71H:7,N7W1E>'1!<F5A+G-T>6QE+F1I<W!L87D@/2`B;F]N92(["@D)
M:68@*$A434Q!<F5A+FES7V=E8VMO*2!["@D)"2\O('=E(&YE960@=&\@<F5F
M<F5S:"!T:&%T(&EN9F\@9F]R($UO>BTQ+C-A"@D)"71R>2!["@D)"0ET:&ES
M+E]D;V,N9&5S:6=N36]D92`](")O;B(["@D)"7T@8V%T8V@H92D@>WT["@D)
M?0H)"6EF("AT:&ES+F-O;F9I9RYS=&%T=7-"87(I('L*"0D)=&AI<RY?<W1A
M='5S0F%R+FEN;F5R2%1-3"`]("<G.PH)"0DO+R!T:&ES+E]S=&%T=7-"87(N
M87!P96YD0VAI;&0H9&]C=6UE;G0N8W)E871E5&5X=$YO9&4H2%1-3$%R96$N
M23$X3BYM<V=;(E!A=&@B72`K("(Z("(I*3L*"0D)=&AI<RY?<W1A='5S0F%R
M+F%P<&5N9$-H:6QD*'1H:7,N7W-T871U<T)A<E1R964I.PH)"7T*"0EB<F5A
M:SL*"2`@("!D969A=6QT.@H)"6%L97)T*")-;V1E(#PB("L@;6]D92`K("(^
M(&YO="!D969I;F5D(2(I.PH)"7)E='5R;B!F86QS93L*"7T*"71H:7,N7V5D
M:71-;V1E(#T@;6]D93L*"71H:7,N9F]C=7-%9&ET;W(H*3L*"@EF;W(@*'9A
M<B!I(&EN('1H:7,N<&QU9VEN<RD@>PH)"79A<B!P;'5G:6X@/2!T:&ES+G!L
M=6=I;G-;:5TN:6YS=&%N8V4["@D):68@*'1Y<&5O9B!P;'5G:6XN;VY-;V1E
M(#T](")F=6YC=&EO;B(I('!L=6=I;BYO;DUO9&4H;6]D92D["@E]"GT["@I(
M5$U,07)E82YP<F]T;W1Y<&4N<V5T1G5L;$A434P@/2!F=6YC=&EO;BAH=&UL
M*2!["@EV87(@<V%V95]M=6QT:6QI;F4@/2!296=%>'`N;75L=&EL:6YE.PH)
M4F5G17AP+FUU;'1I;&EN92`]('1R=64["@EI9B`H:'1M;"YM871C:"A(5$U,
M07)E82Y215]D;V-T>7!E*2D@>PH)"71H:7,N<V5T1&]C='EP92A296=%>'`N
M)#$I.PH)"6AT;6P@/2!H=&UL+G)E<&QA8V4H2%1-3$%R96$N4D5?9&]C='EP
M92P@(B(I.PH)?0H)4F5G17AP+FUU;'1I;&EN92`]('-A=F5?;75L=&EL:6YE
M.PH):68@*"%(5$U,07)E82YI<U]I92D@>PH)"6EF("AH=&UL+FUA=&-H*$A4
M34Q!<F5A+E)%7VAE860I*0H)"0ET:&ES+E]D;V,N9V5T16QE;65N='-">51A
M9TYA;64H(FAE860B*5LP72YI;FYE<DA434P@/2!296=%>'`N)#$["@D):68@
M*&AT;6PN;6%T8V@H2%1-3$%R96$N4D5?8F]D>2DI"@D)"71H:7,N7V1O8RYG
M971%;&5M96YT<T)Y5&%G3F%M92@B8F]D>2(I6S!=+FEN;F5R2%1-3"`](%)E
M9T5X<"XD,3L*"7T@96QS92!["@D)=F%R(&AT;6Q?<F4@/2`O/&AT;6P^*"@N
M?%QN*2H_*3Q<+VAT;6P^+VD["@D):'1M;"`](&AT;6PN<F5P;&%C92AH=&UL
M7W)E+"`B)#$B*3L*"0ET:&ES+E]D;V,N;W!E;B@I.PH)"71H:7,N7V1O8RYW
M<FET92AH=&UL*3L*"0ET:&ES+E]D;V,N8VQO<V4H*3L*"0ET:&ES+E]D;V,N
M8F]D>2YC;VYT96YT161I=&%B;&4@/2!T<G5E.PH)"7)E='5R;B!T<G5E.PH)
M?0I].PH*+RHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*@H@*B`@0V%T96=O<GDZ(%!,54=)3E,*("HJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B\*
M"B\O($-R96%T92!T:&4@<W!E8VEF:65D('!L=6=I;B!A;F0@<F5G:7-T97(@
M:70@=VET:"!T:&ES($A434Q!<F5A"DA434Q!<F5A+G!R;W1O='EP92YR96=I
M<W1E<E!L=6=I;B`](&9U;F-T:6]N*"D@>PH)=F%R('!L=6=I;B`](&%R9W5M
M96YT<ULP73L*"79A<B!A<F=S(#T@6UT["@EF;W(@*'9A<B!I(#T@,3L@:2`\
M(&%R9W5M96YT<RYL96YG=&@[("LK:2D*"0EA<F=S+G!U<V@H87)G=6UE;G1S
M6VE=*3L*"71H:7,N<F5G:7-T97)0;'5G:6XR*'!L=6=I;BP@87)G<RD["GT[
M"@HO+R!T:&ES(&ES('1H92!V87)I86YT(&]F('1H92!F=6YC=&EO;B!A8F]V
M92!W:&5R92!T:&4@<&QU9VEN(&%R9W5M96YT<R!A<F4*+R\@86QR96%D>2!P
M86-K960@:6X@86X@87)R87DN("!%>'1E<FYA;&QY+"!I="!S:&]U;&0@8F4@
M;VYL>2!U<V5D(&EN('1H90HO+R!F=6QL+7-C<F5E;B!E9&ET;W(@8V]D92P@
M:6X@;W)D97(@=&\@:6YI=&EA;&EZ92!P;'5G:6YS('=I=&@@=&AE('-A;64*
M+R\@<&%R86UE=&5R<R!A<R!I;B!T:&4@;W!E;F5R('=I;F1O=RX*2%1-3$%R
M96$N<')O=&]T>7!E+G)E9VES=&5R4&QU9VEN,B`](&9U;F-T:6]N*'!L=6=I
M;BP@87)G<RD@>PH):68@*'1Y<&5O9B!P;'5G:6X@/3T@(G-T<FEN9R(I"@D)
M<&QU9VEN(#T@979A;"AP;'5G:6XI.PH):68@*'1Y<&5O9B!P;'5G:6X@/3T@
M(G5N9&5F:6YE9"(I('L*"0DO*B!&25A-13H@5&AI<R!S:&]U;&0@;F5V97(@
M:&%P<&5N+B!"=70@=VAY(&1O97,@:70@9&\_("HO"@D)<F5T=7)N(&9A;'-E
M.PH)?0H)=F%R(&]B:B`](&YE=R!P;'5G:6XH=&AI<RP@87)G<RD["@EI9B`H
M;V)J*2!["@D)=F%R(&-L;VYE(#T@>WT["@D)=F%R(&EN9F\@/2!P;'5G:6XN
M7W!L=6=I;DEN9F\["@D)9F]R("AV87(@:2!I;B!I;F9O*0H)"0EC;&]N95MI
M72`](&EN9F];:5T["@D)8VQO;F4N:6YS=&%N8V4@/2!O8FH["@D)8VQO;F4N
M87)G<R`](&%R9W,["@D)=&AI<RYP;'5G:6YS6W!L=6=I;BY?<&QU9VEN26YF
M;RYN86UE72`](&-L;VYE.PH)?2!E;'-E"@D)86QE<G0H(D-A;B=T(')E9VES
M=&5R('!L=6=I;B`B("L@<&QU9VEN+G1O4W1R:6YG*"D@*R`B+B(I.PI].PH*
M+R\@<W1A=&EC(&9U;F-T:6]N('1H870@;&]A9',@=&AE(')E<75I<F5D('!L
M=6=I;B!A;F0@;&%N9R!F:6QE+"!B87-E9"!O;B!T:&4*+R\@;&%N9W5A9V4@
M;&]A9&5D(&%L<F5A9'D@9F]R($A434Q!<F5A+B`@66]U(&)E='1E<B!M86ME
M('-U<F4@=&AA="!T:&4@<&QU9VEN"B\O(%]H87-?('1H870@;&%N9W5A9V4L
M(&]T:&5R=VES92!S:&ET(&UI9VAT(&AA<'!E;B`[+2D*2%1-3$%R96$N9V5T
M4&QU9VEN1&ER(#T@9G5N8W1I;VXH<&QU9VEN3F%M92D@>PH)<F5T=7)N(%]E
M9&ET;W)?=7)L("L@(G!L=6=I;G,O(B`K('!L=6=I;DYA;64["GT["@I(5$U,
M07)E82YL;V%D4&QU9VEN(#T@9G5N8W1I;VXH<&QU9VEN3F%M92D@>PH)=F%R
M(&1I<B`]('1H:7,N9V5T4&QU9VEN1&ER*'!L=6=I;DYA;64I.PH)=F%R('!L
M=6=I;B`]('!L=6=I;DYA;64N<F5P;&%C92@O*%MA+7I=*2A;02U:72DH6V$M
M>ETI+V<L"@D)"0D)9G5N8W1I;VX@*'-T<BP@;#$L(&PR+"!L,RD@>PH)"0D)
M"0ER971U<FX@;#$@*R`B+2(@*R!L,BYT;TQO=V5R0V%S92@I("L@;#,["@D)
M"0D)?2DN=&],;W=E<D-A<V4H*2`K("(N:G,B.PH)=F%R('!L=6=I;E]F:6QE
M(#T@9&ER("L@(B\B("L@<&QU9VEN.PH)=F%R('!L=6=I;E]L86YG(#T@9&ER
M("L@(B]L86YG+R(@*R!?961I=&]R7VQA;F<@*R`B+FIS(CL*"2\O9&]C=6UE
M;G0N=W)I=&4H(CQS8W)I<'0@='EP93TG=&5X="]J879A<V-R:7!T)R!S<F,]
M)R(@*R!P;'5G:6Y?9FEL92`K("(G/CPO<V-R:7!T/B(I.PH)+R]D;V-U;65N
M="YW<FET92@B/'-C<FEP="!T>7!E/2=T97AT+VIA=F%S8W)I<'0G('-R8STG
M(B`K('!L=6=I;E]L86YG("L@(B<^/"]S8W)I<'0^(BD["@ET:&ES+FQO8613
M8W)I<'0H<&QU9VEN7V9I;&4I.PH)=&AI<RYL;V%D4V-R:7!T*'!L=6=I;E]L
M86YG*3L*?3L*"DA434Q!<F5A+FQO8613='EL92`](&9U;F-T:6]N*'-T>6QE
M+"!P;'5G:6XI('L*"79A<B!U<FP@/2!?961I=&]R7W5R;"!\?"`G)SL*"6EF
M("AT>7!E;V8@<&QU9VEN("$](")U;F1E9FEN960B*2!["@D)=7)L("L](")P
M;'5G:6YS+R(@*R!P;'5G:6X@*R`B+R(["@E]"@EU<FP@*ST@<W1Y;&4["@EI
M9B`H+UY<+R\N=&5S="AS='EL92DI"@D)=7)L(#T@<W1Y;&4["@EV87(@:&5A
M9"`](&1O8W5M96YT+F=E=$5L96UE;G1S0GE486=.86UE*")H96%D(BE;,%T[
M"@EV87(@;&EN:R`](&1O8W5M96YT+F-R96%T945L96UE;G0H(FQI;FLB*3L*
M"6QI;FLN<F5L(#T@(G-T>6QE<VAE970B.PH);&EN:RYH<F5F(#T@=7)L.PH)
M:&5A9"YA<'!E;F1#:&EL9"AL:6YK*3L*"2\O9&]C=6UE;G0N=W)I=&4H(CQS
M='EL92!T>7!E/2=T97AT+V-S<R<^0&EM<&]R="!U<FPH(B`K('5R;"`K("(I
M.SPO<W1Y;&4^(BD["GT["DA434Q!<F5A+FQO8613='EL92AT>7!E;V8@7V5D
M:71O<E]C<W,@/3T@(G-T<FEN9R(@/R!?961I=&]R7V-S<R`Z(")H=&UL87)E
M82YC<W,B*3L*"B\J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BH*("H@($-A=&5G;W)Y.B!%1$E43U(@551)3$E4
M2453"B`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHO"@I(5$U,07)E82YP<F]T;W1Y<&4N9&5B=6=4<F5E(#T@
M9G5N8W1I;VXH*2!["@EV87(@=&$@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT
M*")T97AT87)E82(I.PH)=&$N<W1Y;&4N=VED=&@@/2`B,3`P)2(["@ET82YS
M='EL92YH96EG:'0@/2`B,C!E;2(["@ET82YV86QU92`]("(B.PH)9G5N8W1I
M;VX@9&5B=6<H:6YD96YT+"!S='(I('L*"0EF;W(@*#L@+2UI;F1E;G0@/CT@
M,#LI"@D)"71A+G9A;'5E("L]("(@(CL*"0ET82YV86QU92`K/2!S='(@*R`B
M7&XB.PH)?3L*"69U;F-T:6]N(%]D="AR;V]T+"!L979E;"D@>PH)"79A<B!T
M86<@/2!R;V]T+G1A9TYA;64N=&],;W=E<D-A<V4H*2P@:3L*"0EV87(@;G,@
M/2!(5$U,07)E82YI<U]I92`_(')O;W0N<V-O<&5.86UE(#H@<F]O="YP<F5F
M:7@["@D)9&5B=6<H;&5V96PL("(M("(@*R!T86<@*R`B(%LB("L@;G,@*R`B
M72(I.PH)"69O<B`H:2`](')O;W0N9FER<W1#:&EL9#L@:3L@:2`](&DN;F5X
M=%-I8FQI;F<I"@D)"6EF("AI+FYO9&54>7!E(#T](#$I"@D)"0E?9'0H:2P@
M;&5V96P@*R`R*3L*"7T["@E?9'0H=&AI<RY?9&]C+F)O9'DL(#`I.PH)9&]C
M=6UE;G0N8F]D>2YA<'!E;F1#:&EL9"AT82D["GT["@I(5$U,07)E82YG971)
M;FYE<E1E>'0@/2!F=6YC=&EO;BAE;"D@>PH)=F%R('1X="`]("<G+"!I.PH)
M9F]R("AI(#T@96PN9FER<W1#:&EL9#L@:3L@:2`](&DN;F5X=%-I8FQI;F<I
M('L*"0EI9B`H:2YN;V1E5'EP92`]/2`S*0H)"0ET>'0@*ST@:2YD871A.PH)
M"65L<V4@:68@*&DN;F]D951Y<&4@/3T@,2D*"0D)='AT("L]($A434Q!<F5A
M+F=E=$EN;F5R5&5X="AI*3L*"7T*"7)E='5R;B!T>'0["GT["@I(5$U,07)E
M82YP<F]T;W1Y<&4N7W=O<F1#;&5A;B`](&9U;F-T:6]N*"D@>PH)=F%R"@D)
M961I=&]R(#T@=&AI<RP*"0ES=&%T<R`]('L*"0D)96UP='E?=&%G<R`Z(#`L
M"@D)"6US;U]C;&%S<R`@.B`P+`H)"0EM<V]?<W1Y;&4@(#H@,"P*"0D);7-O
M7WAM;&5L("`Z(#`L"@D)"6]R:6=?;&5N("`@.B!T:&ES+E]D;V,N8F]D>2YI
M;FYE<DA434PN;&5N9W1H+`H)"0E4("`@("`@("`@(#H@*&YE=R!$871E*"DI
M+F=E=%1I;64H*0H)"7TL"@D)<W1A='-?='AT(#T@>PH)"0EE;7!T>5]T86=S
M(#H@(D5M<'1Y('1A9W,@<F5M;W9E9#H@(BP*"0D);7-O7V-L87-S("`Z(")-
M4T\@8VQA<W,@;F%M97,@<F5M;W9E9#H@(BP*"0D);7-O7W-T>6QE("`Z(")-
M4T\@:6YL:6YE('-T>6QE(')E;6]V960Z("(L"@D)"6US;U]X;6QE;"`@.B`B
M35-/(%A-3"!E;&5M96YT<R!S=')I<'!E9#H@(@H)"7T["@EF=6YC=&EO;B!S
M:&]W4W1A=',H*2!["@D)=F%R('1X="`](")(5$U,07)E82!W;W)D(&-L96%N
M97(@<W1A=',Z(%QN7&XB.PH)"69O<B`H=F%R(&D@:6X@<W1A=',I"@D)"6EF
M("AS=&%T<U]T>'1;:5TI"@D)"0ET>'0@*ST@<W1A='-?='AT6VE=("L@<W1A
M='-;:5T@*R`B7&XB.PH)"71X="`K/2`B7&Y);FET:6%L(&1O8W5M96YT(&QE
M;F=T:#H@(B`K('-T871S+F]R:6=?;&5N("L@(EQN(CL*"0ET>'0@*ST@(D9I
M;F%L(&1O8W5M96YT(&QE;F=T:#H@(B`K(&5D:71O<BY?9&]C+F)O9'DN:6YN
M97)(5$U,+FQE;F=T:"`K(")<;B(["@D)='AT("L](")#;&5A;BUU<"!T;V]K
M("(@*R`H*"AN97<@1&%T92@I*2YG9714:6UE*"D@+2!S=&%T<RY4*2`O(#$P
M,#`I("L@(B!S96-O;F1S(CL*"0EA;&5R="AT>'0I.PH)?3L*"69U;F-T:6]N
M(&-L96%R0VQA<W,H;F]D92D@>PH)"79A<B!N97=C(#T@;F]D92YC;&%S<TYA
M;64N<F5P;&%C92@O*%Y\7',I;7-O+BH_*%QS?"0I+VEG+"`G("<I.PH)"6EF
M("AN97=C("$](&YO9&4N8VQA<W-.86UE*2!["@D)"6YO9&4N8VQA<W-.86UE
M(#T@;F5W8SL*"0D):68@*"$O7%,O+G1E<W0H;F]D92YC;&%S<TYA;64I*2![
M"@D)"0EN;V1E+G)E;6]V94%T=')I8G5T92@B8VQA<W-.86UE(BD["@D)"0DK
M*W-T871S+FUS;U]C;&%S<SL*"0D)?0H)"7T*"7T["@EF=6YC=&EO;B!C;&5A
M<E-T>6QE*&YO9&4I('L*(`D)=F%R(&1E8VQA<F%T:6]N<R`](&YO9&4N<W1Y
M;&4N8W-S5&5X="YS<&QI="@O7',J.UQS*B\I.PH)"69O<B`H=F%R(&D@/2!D
M96-L87)A=&EO;G,N;&5N9W1H.R`M+6D@/CT@,#LI"@D)"6EF("@O7FUS;WQ>
M=&%B+7-T;W!S+VDN=&5S="AD96-L87)A=&EO;G-;:5TI('Q\"@D)"2`@("`O
M7FUA<F=I;EQS*CI<<RHP+BY<<RLP+BY<<RLP+BXO:2YT97-T*&1E8VQA<F%T
M:6]N<UMI72DI('L*"0D)"2LK<W1A=',N;7-O7W-T>6QE.PH)"0D)9&5C;&%R
M871I;VYS+G-P;&EC92AI+"`Q*3L*"0D)?0H)"6YO9&4N<W1Y;&4N8W-S5&5X
M="`](&1E8VQA<F%T:6]N<RYJ;VEN*"([("(I.PH)?3L*"69U;F-T:6]N('-T
M<FEP5&%G*&5L*2!["@D):68@*$A434Q!<F5A+FES7VEE*0H)"0EE;"YO=71E
M<DA434P@/2!(5$U,07)E82YH=&UL16YC;V1E*&5L+FEN;F5R5&5X="D["@D)
M96QS92!["@D)"79A<B!T>'0@/2!D;V-U;65N="YC<F5A=&5497AT3F]D92A(
M5$U,07)E82YG971);FYE<E1E>'0H96PI*3L*"0D)96PN<&%R96YT3F]D92YI
M;G-E<G1"969O<F4H='AT+"!E;"D["@D)"65L+G!A<F5N=$YO9&4N<F5M;W9E
M0VAI;&0H96PI.PH)"7T*"0DK*W-T871S+FUS;U]X;6QE;#L*"7T["@EF=6YC
M=&EO;B!C:&5C:T5M<'1Y*&5L*2!["@D):68@*"]>*&%\<W!A;GQB?'-T<F]N
M9WQI?&5M?&9O;G0I)"]I+G1E<W0H96PN=&%G3F%M92D@)B8*"0D@("`@(65L
M+F9I<G-T0VAI;&0I('L*"0D)96PN<&%R96YT3F]D92YR96UO=F5#:&EL9"AE
M;"D["@D)"2LK<W1A=',N96UP='E?=&%G<SL*"0E]"@E].PH)9G5N8W1I;VX@
M<&%R<V54<F5E*')O;W0I('L*"0EV87(@=&%G(#T@<F]O="YT86=.86UE+G1O
M3&]W97)#87-E*"DL(&DL(&YE>'0["@D):68@*"A(5$U,07)E82YI<U]I92`F
M)B!R;V]T+G-C;W!E3F%M92`A/2`G2%1-3"<I('Q\("@A2%1-3$%R96$N:7-?
M:64@)B8@+SHO+G1E<W0H=&%G*2DI('L*"0D)<W1R:7!486<H<F]O="D["@D)
M"7)E='5R;B!F86QS93L*"0E](&5L<V4@>PH)"0EC;&5A<D-L87-S*')O;W0I
M.PH)"0EC;&5A<E-T>6QE*')O;W0I.PH)"0EF;W(@*&D@/2!R;V]T+F9I<G-T
M0VAI;&0[(&D[(&D@/2!N97AT*2!["@D)"0EN97AT(#T@:2YN97AT4VEB;&EN
M9SL*"0D)"6EF("AI+FYO9&54>7!E(#T](#$@)B8@<&%R<V54<F5E*&DI*0H)
M"0D)"6-H96-K16UP='DH:2D["@D)"7T*"0E]"@D)<F5T=7)N('1R=64["@E]
M.PH)<&%R<V54<F5E*'1H:7,N7V1O8RYB;V1Y*3L*"2\O('-H;W=3=&%T<R@I
M.PH)+R\@=&AI<RYD96)U9U1R964H*3L*"2\O('1H:7,N<V5T2%1-3"AT:&ES
M+F=E=$A434PH*2D["@DO+R!T:&ES+G-E=$A434PH=&AI<RYG971);FYE<DA4
M34PH*2D["@DO+R!T:&ES+F9O<F-E4F5D<F%W*"D["@ET:&ES+G5P9&%T951O
M;VQB87(H*3L*?3L*"DA434Q!<F5A+G!R;W1O='EP92YF;W)C95)E9')A=R`]
M(&9U;F-T:6]N*"D@>PH)=&AI<RY?9&]C+F)O9'DN<W1Y;&4N=FES:6)I;&ET
M>2`](")H:61D96XB.PH)=&AI<RY?9&]C+F)O9'DN<W1Y;&4N=FES:6)I;&ET
M>2`](")V:7-I8FQE(CL*"2\O('1H:7,N7V1O8RYB;V1Y+FEN;F5R2%1-3"`]
M('1H:7,N9V5T26YN97)(5$U,*"D["GT["@HO+R!F;V-U<V5S('1H92!I9G)A
M;64@=VEN9&]W+B`@<F5T=7)N<R!A(')E9F5R96YC92!T;R!T:&4@961I=&]R
M(&1O8W5M96YT+@I(5$U,07)E82YP<F]T;W1Y<&4N9F]C=7-%9&ET;W(@/2!F
M=6YC=&EO;B@I('L*"7-W:71C:"`H=&AI<RY?961I=$UO9&4I('L*"2`@("`O
M+R!N;W1I8V4@=&AE('1R>2![("XN+B!](&-A=&-H(&)L;V-K('1O(&%V;VED
M('-O;64@<F%R92!E>&-E<'1I;VYS(&EN($9I<F5&;W@*"2`@("`O+R`H<&5R
M:&%P<R!A;'-O(&EN(&]T:&5R($=E8VMO(&)R;W=S97)S*2X@36%N=6%L(&9O
M8W5S(&)Y('5S97(@:7,@<F5Q=6ER960@:6X*("`@("`@("`O+R!C87-E(&]F
M(&%N(&5R<F]R+B!3;VUE8F]D>2!H87,@86X@:61E83\*"2`@("!C87-E(")W
M>7-I=WEG(B`Z('1R>2![('1H:7,N7VEF<F%M92YC;VYT96YT5VEN9&]W+F9O
M8W5S*"D@?2!C871C:"`H92D@>WT@8G)E86L["@D@("`@8V%S92`B=&5X=&UO
M9&4B.B!T<GD@>R!T:&ES+E]T97AT07)E82YF;V-U<R@I('T@8V%T8V@@*&4I
M('M](&)R96%K.PH)("`@(&1E9F%U;'0)("`@.B!A;&5R="@B15)23U(Z(&UO
M9&4@(B`K('1H:7,N7V5D:71-;V1E("L@(B!I<R!N;W0@9&5F:6YE9"(I.PH)
M?0H)<F5T=7)N('1H:7,N7V1O8SL*?3L*"B\O('1A:V5S(&$@<VYA<'-H;W0@
M;V8@=&AE(&-U<G)E;G0@=&5X="`H9F]R('5N9&\I"DA434Q!<F5A+G!R;W1O
M='EP92Y?=6YD;U1A:V53;F%P<VAO="`](&9U;F-T:6]N*"D@>PH)*RMT:&ES
M+E]U;F1O4&]S.PH):68@*'1H:7,N7W5N9&]0;W,@/CT@=&AI<RYC;VYF:6<N
M=6YD;U-T97!S*2!["@D)+R\@<F5M;W9E('1H92!F:7)S="!E;&5M96YT"@D)
M=&AI<RY?=6YD;U%U975E+G-H:69T*"D["@D)+2UT:&ES+E]U;F1O4&]S.PH)
M?0H)+R\@=7-E('1H92!F87-T960@;65T:&]D("AG971);FYE<DA434PI.PH)
M=F%R('1A:V4@/2!T<G5E.PH)=F%R('1X="`]('1H:7,N9V5T26YN97)(5$U,
M*"D["@EI9B`H=&AI<RY?=6YD;U!O<R`^(#`I"@D)=&%K92`]("AT:&ES+E]U
M;F1O475E=65;=&AI<RY?=6YD;U!O<R`M(#%=("$]('1X="D["@EI9B`H=&%K
M92D@>PH)"71H:7,N7W5N9&]1=65U95MT:&ES+E]U;F1O4&]S72`]('1X=#L*
M"7T@96QS92!["@D)=&AI<RY?=6YD;U!O<RTM.PH)?0I].PH*2%1-3$%R96$N
M<')O=&]T>7!E+G5N9&\@/2!F=6YC=&EO;B@I('L*"6EF("AT:&ES+E]U;F1O
M4&]S(#X@,"D@>PH)"79A<B!T>'0@/2!T:&ES+E]U;F1O475E=65;+2UT:&ES
M+E]U;F1O4&]S73L*"0EI9B`H='AT*2!T:&ES+G-E=$A434PH='AT*3L*"0EE
M;'-E("LK=&AI<RY?=6YD;U!O<SL*"7T*?3L*"DA434Q!<F5A+G!R;W1O='EP
M92YR961O(#T@9G5N8W1I;VXH*2!["@EI9B`H=&AI<RY?=6YD;U!O<R`\('1H
M:7,N7W5N9&]1=65U92YL96YG=&@@+2`Q*2!["@D)=F%R('1X="`]('1H:7,N
M7W5N9&]1=65U95LK*W1H:7,N7W5N9&]0;W-=.PH)"6EF("AT>'0I('1H:7,N
M<V5T2%1-3"AT>'0I.PH)"65L<V4@+2UT:&ES+E]U;F1O4&]S.PH)?0I].PH*
M+R\@=7!D871E<R!E;F%B;&5D+V1I<V%B;&4O86-T:79E('-T871E(&]F('1H
M92!T;V]L8F%R(&5L96UE;G1S"DA434Q!<F5A+G!R;W1O='EP92YU<&1A=&54
M;V]L8F%R(#T@9G5N8W1I;VXH;F]3=&%T=7,I('L*"79A<B!D;V,@/2!T:&ES
M+E]D;V,["@EV87(@=&5X="`]("AT:&ES+E]E9&ET36]D92`]/2`B=&5X=&UO
M9&4B*3L*"79A<B!A;F-E<W1O<G,@/2!N=6QL.PH):68@*"%T97AT*2!["@D)
M86YC97-T;W)S(#T@=&AI<RYG971!;&Q!;F-E<W1O<G,H*3L*"0EI9B`H=&AI
M<RYC;VYF:6<N<W1A='5S0F%R("8F("%N;U-T871U<RD@>PH)"0ET:&ES+E]S
M=&%T=7-"87)4<F5E+FEN;F5R2%1-3"`]($A434Q!<F5A+DDQ.$XN;7-G6R)0
M871H(ET@*R`B.B`B.R`O+R!C;&5A<@H)"0EF;W(@*'9A<B!I(#T@86YC97-T
M;W)S+FQE;F=T:#L@+2UI(#X](#`[*2!["@D)"0EV87(@96P@/2!A;F-E<W1O
M<G-;:5T["@D)"0EI9B`H(65L*2!["@D)"0D)+R\@:&5L;"!K;F]W<R!W:'D@
M=V4@9V5T(&AE<F4[('1H:7,*"0D)"0DO+R!C;W5L9"!B92!A(&-L87-S:6,@
M97AA;7!L92!O9B!W:'D*"0D)"0DO+R!I="=S(&=O;V0@=&\@8VAE8VL@9F]R
M(&-O;F1I=&EO;G,*"0D)"0DO+R!T:&%T(&%R92!I;7!O<W-I8FQE('1O(&AA
M<'!E;B`[+2D*"0D)"0EC;VYT:6YU93L*"0D)"7T*"0D)"79A<B!A(#T@9&]C
M=6UE;G0N8W)E871E16QE;65N="@B82(I.PH)"0D)82YH<F5F(#T@(B,B.PH)
M"0D)82YE;"`](&5L.PH)"0D)82YE9&ET;W(@/2!T:&ES.PH)"0D)82YO;F-L
M:6-K(#T@9G5N8W1I;VXH*2!["@D)"0D)=&AI<RYB;'5R*"D["@D)"0D)=&AI
M<RYE9&ET;W(N<V5L96-T3F]D94-O;G1E;G1S*'1H:7,N96PI.PH)"0D)"71H
M:7,N961I=&]R+G5P9&%T951O;VQB87(H=')U92D["@D)"0D)<F5T=7)N(&9A
M;'-E.PH)"0D)?3L*"0D)"6$N;VYC;VYT97AT;65N=2`](&9U;F-T:6]N*"D@
M>PH)"0D)"2\O(%1/1$\Z(&%D9"!C;VYT97AT(&UE;G4@:&5R90H)"0D)"71H
M:7,N8FQU<B@I.PH)"0D)"79A<B!I;F9O(#T@(DEN;&EN92!S='EL93I<;EQN
M(CL*"0D)"0EI;F9O("L]('1H:7,N96PN<W1Y;&4N8W-S5&5X="YS<&QI="@O
M.UQS*B\I+FIO:6XH(CM<;B(I.PH)"0D)"6%L97)T*&EN9F\I.PH)"0D)"7)E
M='5R;B!F86QS93L*"0D)"7T["@D)"0EV87(@='AT(#T@96PN=&%G3F%M92YT
M;TQO=V5R0V%S92@I.PH)"0D)82YT:71L92`](&5L+G-T>6QE+F-S<U1E>'0[
M"@D)"0EI9B`H96PN:60I('L*"0D)"0ET>'0@*ST@(B,B("L@96PN:60["@D)
M"0E]"@D)"0EI9B`H96PN8VQA<W-.86UE*2!["@D)"0D)='AT("L]("(N(B`K
M(&5L+F-L87-S3F%M93L*"0D)"7T*"0D)"6$N87!P96YD0VAI;&0H9&]C=6UE
M;G0N8W)E871E5&5X=$YO9&4H='AT*2D["@D)"0ET:&ES+E]S=&%T=7-"87)4
M<F5E+F%P<&5N9$-H:6QD*&$I.PH)"0D):68@*&D@(3T@,"D@>PH)"0D)"71H
M:7,N7W-T871U<T)A<E1R964N87!P96YD0VAI;&0H9&]C=6UE;G0N8W)E871E
M5&5X=$YO9&4H4W1R:6YG+F9R;VU#:&%R0V]D92@P>&)B*2DI.PH)"0D)?0H)
M"0E]"@D)?0H)?0H*"69O<B`H=F%R(&D@:6X@=&AI<RY?=&]O;&)A<D]B:F5C
M=',I('L*"0EV87(@8G1N(#T@=&AI<RY?=&]O;&)A<D]B:F5C='-;:5T["@D)
M=F%R(&-M9"`](&D["@D)=F%R(&EN0V]N=&5X="`]('1R=64["@D):68@*&)T
M;BYC;VYT97AT("8F("%T97AT*2!["@D)"6EN0V]N=&5X="`](&9A;'-E.PH)
M"0EV87(@8V]N=&5X="`](&)T;BYC;VYT97AT.PH)"0EV87(@871T<G,@/2!;
M73L*"0D):68@*"\H+BHI7%LH+BH_*5Q=+RYT97-T*&-O;G1E>'0I*2!["@D)
M"0EC;VYT97AT(#T@4F5G17AP+B0Q.PH)"0D)871T<G,@/2!296=%>'`N)#(N
M<W!L:70H(BPB*3L*"0D)?0H)"0EC;VYT97AT(#T@8V]N=&5X="YT;TQO=V5R
M0V%S92@I.PH)"0EV87(@;6%T8V@@/2`H8V]N=&5X="`]/2`B*B(I.PH)"0EF
M;W(@*'9A<B!K(#T@,#L@:R`\(&%N8V5S=&]R<RYL96YG=&@[("LK:RD@>PH)
M"0D):68@*"%A;F-E<W1O<G-;:UTI('L*"0D)"0DO+R!T:&4@:6UP;W-S:6)L
M92!R96%L;'D@:&%P<&5N<RX*"0D)"0EC;VYT:6YU93L*"0D)"7T*"0D)"6EF
M("AM871C:"!\?"`H86YC97-T;W)S6VM=+G1A9TYA;64N=&],;W=E<D-A<V4H
M*2`]/2!C;VYT97AT*2D@>PH)"0D)"6EN0V]N=&5X="`]('1R=64["@D)"0D)
M9F]R("AV87(@:V$@/2`P.R!K82`\(&%T=')S+FQE;F=T:#L@*RMK82D@>PH)
M"0D)"0EI9B`H(65V86PH(F%N8V5S=&]R<UMK72XB("L@871T<G-;:V%=*2D@
M>PH)"0D)"0D):6Y#;VYT97AT(#T@9F%L<V4["@D)"0D)"0EB<F5A:SL*"0D)
M"0D)?0H)"0D)"7T*"0D)"0EI9B`H:6Y#;VYT97AT*2!["@D)"0D)"6)R96%K
M.PH)"0D)"7T*"0D)"7T*"0D)?0H)"7T*"0EB=&XN<W1A=&4H(F5N86)L960B
M+"`H(71E>'0@?'P@8G1N+G1E>'0I("8F(&EN0V]N=&5X="D["@D):68@*'1Y
M<&5O9B!C;60@/3T@(F9U;F-T:6]N(BD@>PH)"0EC;VYT:6YU93L*"0E]"@D)
M+R\@;&]O:RUI="UU<"!I;B!T:&4@8W5S=&]M(&1R;W!D;W=N(&)O>&5S"@D)
M=F%R(&1R;W!D;W=N(#T@=&AI<RYC;VYF:6<N8W5S=&]M4V5L96-T<UMC;61=
M.PH)"6EF("@H(71E>'0@?'P@8G1N+G1E>'0I("8F("AT>7!E;V8@9')O<&1O
M=VX@(3T@(G5N9&5F:6YE9"(I*2!["@D)"61R;W!D;W=N+G)E9G)E<V@H=&AI
M<RD["@D)"6-O;G1I;G5E.PH)"7T*"0ES=VET8V@@*&-M9"D@>PH)"2`@("!C
M87-E(")F;VYT;F%M92(Z"@D)("`@(&-A<V4@(F9O;G1S:7IE(CH*"0D@("`@
M8V%S92`B9F]R;6%T8FQO8VLB.@H)"0EI9B`H(71E>'0I('1R>2!["@D)"0EV
M87(@=F%L=64@/2`H(B(@*R!D;V,N<75E<GE#;VUM86YD5F%L=64H8VUD*2DN
M=&],;W=E<D-A<V4H*3L*"0D)"6EF("@A=F%L=64I('L*"0D)"0EB=&XN96QE
M;65N="YS96QE8W1E9$EN9&5X(#T@,#L*"0D)"0EB<F5A:SL*"0D)"7T*"0D)
M"2\O($A!0TL@+2T@<F5T<FEE=F4@=&AE(&-O;F9I9R!O<'1I;VX@9F]R('1H
M:7,*"0D)"2\O(&-O;6)O(&)O>"X@(%=E(')E;'D@;VX@=&AE(&9A8W0@=&AA
M="!T:&4*"0D)"2\O('9A<FEA8FQE(&EN(&-O;F9I9R!H87,@=&AE('-A;64@
M;F%M92!A<PH)"0D)+R\@8G5T=&]N(&YA;64@:6X@=&AE('1O;VQB87(N"@D)
M"0EV87(@;W!T:6]N<R`]('1H:7,N8V]N9FEG6V-M9%T["@D)"0EV87(@:R`]
M(#`["@D)"0EF;W(@*'9A<B!J(&EN(&]P=&EO;G,I('L*"0D)"0DO+R!&25A-
M13H@=&AE(&9O;&QO=VEN9R!L:6YE(&ES('-C87)Y+@H)"0D)"6EF("@H:BYT
M;TQO=V5R0V%S92@I(#T]('9A;'5E*2!\?`H)"0D)"2`@("`H;W!T:6]N<UMJ
M72YS=6)S='(H,"P@=F%L=64N;&5N9W1H*2YT;TQO=V5R0V%S92@I(#T]('9A
M;'5E*2D@>PH)"0D)"0EB=&XN96QE;65N="YS96QE8W1E9$EN9&5X(#T@:SL*
M"0D)"0D)=&AR;W<@(F]K(CL*"0D)"0E]"@D)"0D)*RMK.PH)"0D)?0H)"0D)
M8G1N+F5L96UE;G0N<V5L96-T961);F1E>"`](#`["@D)"7T@8V%T8V@H92D@
M>WT["@D)"6)R96%K.PH)"2`@("!C87-E(")T97AT:6YD:6-A=&]R(CH*"0D)
M:68@*"%T97AT*2!["@D)"0ET<GD@>W=I=&@@*&)T;BYE;&5M96YT+G-T>6QE
M*2!["@D)"0D)8F%C:V=R;W5N9$-O;&]R(#T@2%1-3$%R96$N7VUA:V5#;VQO
M<B@*"0D)"0D)9&]C+G%U97)Y0V]M;6%N9%9A;'5E*$A434Q!<F5A+FES7VEE
M(#\@(F)A8VMC;VQO<B(@.B`B:&EL:71E8V]L;W(B*2D["@D)"0D):68@*"]T
M<F%N<W!A<F5N="]I+G1E<W0H8F%C:V=R;W5N9$-O;&]R*2D@>PH)"0D)"0DO
M+R!-;WII;&QA"@D)"0D)"6)A8VMG<F]U;F1#;VQO<B`]($A434Q!<F5A+E]M
M86ME0V]L;W(H9&]C+G%U97)Y0V]M;6%N9%9A;'5E*")B86-K8V]L;W(B*2D[
M"@D)"0D)?0H)"0D)"6-O;&]R(#T@2%1-3$%R96$N7VUA:V5#;VQO<BAD;V,N
M<75E<GE#;VUM86YD5F%L=64H(F9O<F5C;VQO<B(I*3L*"0D)"0EF;VYT1F%M
M:6QY(#T@9&]C+G%U97)Y0V]M;6%N9%9A;'5E*")F;VYT;F%M92(I.PH)"0D)
M"69O;G1796EG:'0@/2!D;V,N<75E<GE#;VUM86YD4W1A=&4H(F)O;&0B*2`_
M(")B;VQD(B`Z(")N;W)M86PB.PH)"0D)"69O;G13='EL92`](&1O8RYQ=65R
M>4-O;6UA;F13=&%T92@B:71A;&EC(BD@/R`B:71A;&EC(B`Z(")N;W)M86PB
M.PH)"0D)?7T@8V%T8V@@*&4I('L*"0D)"0DO+R!A;&5R="AE("L@(EQN7&XB
M("L@8VUD*3L*"0D)"7T*"0D)?0H)"0EB<F5A:SL*"0D@("`@8V%S92`B:'1M
M;&UO9&4B.B!B=&XN<W1A=&4H(F%C=&EV92(L('1E>'0I.R!B<F5A:SL*"0D@
M("`@8V%S92`B;&5F='1O<FEG:'0B.@H)"2`@("!C87-E(")R:6=H='1O;&5F
M="(Z"@D)"79A<B!E;"`]('1H:7,N9V5T4&%R96YT16QE;65N="@I.PH)"0EW
M:&EL92`H96P@)B8@(4A434Q!<F5A+FES0FQO8VM%;&5M96YT*&5L*2D*"0D)
M"65L(#T@96PN<&%R96YT3F]D93L*"0D):68@*&5L*0H)"0D)8G1N+G-T871E
M*")A8W1I=F4B+"`H96PN<W1Y;&4N9&ER96-T:6]N(#T]("@H8VUD(#T](")R
M:6=H='1O;&5F="(I(#\@(G)T;"(@.B`B;'1R(BDI*3L*"0D)8G)E86L["@D)
M("`@(&1E9F%U;'0Z"@D)"6-M9"`](&-M9"YR97!L86-E*"\H=6XI/V]R9&5R
M961L:7-T+VDL(")I;G-E<G0D,6]R9&5R961L:7-T(BD["@D)"71R>2!["@D)
M"0EB=&XN<W1A=&4H(F%C=&EV92(L("@A=&5X="`F)B!D;V,N<75E<GE#;VUM
M86YD4W1A=&4H8VUD*2DI.PH)"0E](&-A=&-H("AE*2![?0H)"7T*"7T*"2\O
M('1A:V4@=6YD;R!S;F%P<VAO=',*"6EF("AT:&ES+E]C=7-T;VU5;F1O("8F
M("%T:&ES+E]T:6UE<E5N9&\I('L*"0ET:&ES+E]U;F1O5&%K95-N87!S:&]T
M*"D["@D)=F%R(&5D:71O<B`]('1H:7,["@D)=&AI<RY?=&EM97)5;F1O(#T@
M<V5T5&EM96]U="AF=6YC=&EO;B@I('L*"0D)961I=&]R+E]T:6UE<E5N9&\@
M/2!N=6QL.PH)"7TL('1H:7,N8V]N9FEG+G5N9&]4:6UE;W5T*3L*"7T*"@DO
M+R!C:&5C:R!I9B!A;GD@<&QU9VEN<R!H879E(')E9VES=&5R960@<F5F<F5S
M:"!H86YD;&5R<PH)9F]R("AV87(@:2!I;B!T:&ES+G!L=6=I;G,I('L*"0EV
M87(@<&QU9VEN(#T@=&AI<RYP;'5G:6YS6VE=+FEN<W1A;F-E.PH)"6EF("AT
M>7!E;V8@<&QU9VEN+F]N57!D871E5&]O;&)A<B`]/2`B9G5N8W1I;VXB*0H)
M"0EP;'5G:6XN;VY5<&1A=&54;V]L8F%R*"D["@E]"GT["@HO*BH@4F5T=7)N
M<R!A(&YO9&4@869T97(@=VAI8V@@=V4@8V%N(&EN<V5R="!O=&AE<B!N;V1E
M<RP@:6X@=&AE(&-U<G)E;G0*("H@<V5L96-T:6]N+B`@5&AE('-E;&5C=&EO
M;B!I<R!R96UO=F5D+B`@270@<W!L:71S(&$@=&5X="!N;V1E+"!I9B!N965D
M960N"B`J+PI(5$U,07)E82YP<F]T;W1Y<&4N:6YS97)T3F]D94%T4V5L96-T
M:6]N(#T@9G5N8W1I;VXH=&]"94EN<V5R=&5D*2!["@EI9B`H(4A434Q!<F5A
M+FES7VEE*2!["@D)=F%R('-E;"`]('1H:7,N7V=E=%-E;&5C=&EO;B@I.PH)
M"79A<B!R86YG92`]('1H:7,N7V-R96%T95)A;F=E*'-E;"D["@D)+R\@<F5M
M;W9E('1H92!C=7)R96YT('-E;&5C=&EO;@H)"7-E;"YR96UO=F5!;&Q286YG
M97,H*3L*"0ER86YG92YD96QE=&5#;VYT96YT<R@I.PH)"79A<B!N;V1E(#T@
M<F%N9V4N<W1A<G1#;VYT86EN97(["@D)=F%R('!O<R`](')A;F=E+G-T87)T
M3V9F<V5T.PH)"7-W:71C:"`H;F]D92YN;V1E5'EP92D@>PH)"2`@("!C87-E
M(#,Z("\O($YO9&4N5$585%].3T1%"@D)"2\O('=E(&AA=F4@=&\@<W!L:70@
M:70@870@=&AE(&-A<F5T('!O<VET:6]N+@H)"0EI9B`H=&]"94EN<V5R=&5D
M+FYO9&54>7!E(#T](#,I('L*"0D)"2\O(&1O(&]P=&EM:7IE9"!I;G-E<G1I
M;VX*"0D)"6YO9&4N:6YS97)T1&%T82AP;W,L('1O0F5);G-E<G1E9"YD871A
M*3L*"0D)"7)A;F=E(#T@=&AI<RY?8W)E871E4F%N9V4H*3L*"0D)"7)A;F=E
M+G-E=$5N9"AN;V1E+"!P;W,@*R!T;T)E26YS97)T960N;&5N9W1H*3L*"0D)
M"7)A;F=E+G-E=%-T87)T*&YO9&4L('!O<R`K('1O0F5);G-E<G1E9"YL96YG
M=&@I.PH)"0D)<V5L+F%D9%)A;F=E*')A;F=E*3L*"0D)?2!E;'-E('L*"0D)
M"6YO9&4@/2!N;V1E+G-P;&ET5&5X="AP;W,I.PH)"0D)=F%R('-E;&YO9&4@
M/2!T;T)E26YS97)T960["@D)"0EI9B`H=&]"94EN<V5R=&5D+FYO9&54>7!E
M(#T](#$Q("\J($YO9&4N1$]#54U%3E1?1E)!1TU%3E1?3D]$12`J+RD@>PH)
M"0D)"7-E;&YO9&4@/2!S96QN;V1E+F9I<G-T0VAI;&0["@D)"0E]"@D)"0EN
M;V1E+G!A<F5N=$YO9&4N:6YS97)T0F5F;W)E*'1O0F5);G-E<G1E9"P@;F]D
M92D["@D)"0ET:&ES+G-E;&5C=$YO9&5#;VYT96YT<RAS96QN;V1E*3L*"0D)
M"71H:7,N=7!D871E5&]O;&)A<B@I.PH)"0E]"@D)"6)R96%K.PH)"2`@("!C
M87-E(#$Z("\O($YO9&4N14Q%345.5%].3T1%"@D)"79A<B!S96QN;V1E(#T@
M=&]"94EN<V5R=&5D.PH)"0EI9B`H=&]"94EN<V5R=&5D+FYO9&54>7!E(#T]
M(#$Q("\J($YO9&4N1$]#54U%3E1?1E)!1TU%3E1?3D]$12`J+RD@>PH)"0D)
M<V5L;F]D92`]('-E;&YO9&4N9FER<W1#:&EL9#L*"0D)?0H)"0EN;V1E+FEN
M<V5R=$)E9F]R92AT;T)E26YS97)T960L(&YO9&4N8VAI;&1.;V1E<UMP;W-=
M*3L*"0D)=&AI<RYS96QE8W1.;V1E0V]N=&5N=',H<V5L;F]D92D["@D)"71H
M:7,N=7!D871E5&]O;&)A<B@I.PH)"0EB<F5A:SL*"0E]"@E](&5L<V4@>PH)
M"7)E='5R;B!N=6QL.PDO+R!T:&ES(&9U;F-T:6]N(&YO="!Y970@=7-E9"!F
M;W(@244@/$9)6$U%/@H)?0I].PH*+R\@4F5T=7)N<R!T:&4@9&5E<&5S="!N
M;V1E('1H870@8V]N=&%I;G,@8F]T:"!E;F1P;VEN=',@;V8@=&AE('-E;&5C
M=&EO;BX*2%1-3$%R96$N<')O=&]T>7!E+F=E=%!A<F5N=$5L96UE;G0@/2!F
M=6YC=&EO;B@I('L*"79A<B!S96P@/2!T:&ES+E]G971396QE8W1I;VXH*3L*
M"79A<B!R86YG92`]('1H:7,N7V-R96%T95)A;F=E*'-E;"D["@EI9B`H2%1-
M3$%R96$N:7-?:64I('L*"0ES=VET8V@@*'-E;"YT>7!E*2!["@D)("`@(&-A
M<V4@(E1E>'0B.@H)"2`@("!C87-E(").;VYE(CH*"0D)+R\@270@<V5E;7,@
M=&AA="!E=F5N(&9O<B!S96QE8W1I;VX@;V8@='EP92`B3F]N92(L"@D)"2\O
M('1H97)E(%]I<U\@82!P87)E;G0@96QE;65N="!A;F0@:70G<R!V86QU92!I
M<R!N;W0*"0D)+R\@;VYL>2!C;W)R96-T+"!B=70@=F5R>2!I;7!O<G1A;G0@
M=&\@=7,N("!-4TE%(&ES"@D)"2\O(&-E<G1A:6YL>2!T:&4@8G5G9VEE<W0@
M8G)O=W-E<B!I;B!T:&4@=V]R;&0@86YD($D*"0D)+R\@=V]N9&5R+"!';V0L
M(&AO=R!C86X@16%R=&@@<W1A;F0@:70_"@D)"7)E='5R;B!R86YG92YP87)E
M;G1%;&5M96YT*"D["@D)("`@(&-A<V4@(D-O;G1R;VPB.@H)"0ER971U<FX@
M<F%N9V4N:71E;2@P*3L*"0D@("`@9&5F875L=#H*"0D)<F5T=7)N('1H:7,N
M7V1O8RYB;V1Y.PH)"7T*"7T@96QS92!T<GD@>PH)"79A<B!P(#T@<F%N9V4N
M8V]M;6]N06YC97-T;W)#;VYT86EN97(["@D):68@*"%R86YG92YC;VQL87!S
M960@)B8@<F%N9V4N<W1A<G1#;VYT86EN97(@/3T@<F%N9V4N96YD0V]N=&%I
M;F5R("8F"@D)("`@(')A;F=E+G-T87)T3V9F<V5T("T@<F%N9V4N96YD3V9F
M<V5T(#P](#$@)B8@<F%N9V4N<W1A<G1#;VYT86EN97(N:&%S0VAI;&1.;V1E
M<R@I*0H)"0EP(#T@<F%N9V4N<W1A<G1#;VYT86EN97(N8VAI;&1.;V1E<UMR
M86YG92YS=&%R=$]F9G-E=%T["@D)+RH*"0EA;&5R="AR86YG92YS=&%R=$-O
M;G1A:6YE<B`K("(Z(B`K(')A;F=E+G-T87)T3V9F<V5T("L@(EQN(B`K"@D)
M("`@("`@<F%N9V4N96YD0V]N=&%I;F5R("L@(CHB("L@<F%N9V4N96YD3V9F
M<V5T*3L*"0DJ+PH)"7=H:6QE("AP+FYO9&54>7!E(#T](#,I('L*"0D)<"`]
M('`N<&%R96YT3F]D93L*"0E]"@D)<F5T=7)N('`["@E](&-A=&-H("AE*2![
M"@D)<F5T=7)N(&YU;&P["@E]"GT["@HO+R!2971U<FYS(&%N(&%R<F%Y('=I
M=&@@86QL('1H92!A;F-E<W1O<B!N;V1E<R!O9B!T:&4@<V5L96-T:6]N+@I(
M5$U,07)E82YP<F]T;W1Y<&4N9V5T06QL06YC97-T;W)S(#T@9G5N8W1I;VXH
M*2!["@EV87(@<"`]('1H:7,N9V5T4&%R96YT16QE;65N="@I.PH)=F%R(&$@
M/2!;73L*"7=H:6QE("AP("8F("AP+FYO9&54>7!E(#T](#$I("8F("AP+G1A
M9TYA;64N=&],;W=E<D-A<V4H*2`A/2`G8F]D>2<I*2!["@D)82YP=7-H*'`I
M.PH)"7`@/2!P+G!A<F5N=$YO9&4["@E]"@EA+G!U<V@H=&AI<RY?9&]C+F)O
M9'DI.PH)<F5T=7)N(&$["GT["@HO+R!396QE8W1S('1H92!C;VYT96YT<R!I
M;G-I9&4@=&AE(&=I=F5N(&YO9&4*2%1-3$%R96$N<')O=&]T>7!E+G-E;&5C
M=$YO9&5#;VYT96YT<R`](&9U;F-T:6]N*&YO9&4L('!O<RD@>PH)=&AI<RYF
M;V-U<T5D:71O<B@I.PH)=&AI<RYF;W)C95)E9')A=R@I.PH)=F%R(')A;F=E
M.PH)=F%R(&-O;&QA<'-E9"`]("AT>7!E;V8@<&]S("$](")U;F1E9FEN960B
M*3L*"6EF("A(5$U,07)E82YI<U]I92D@>PH)"7)A;F=E(#T@=&AI<RY?9&]C
M+F)O9'DN8W)E871E5&5X=%)A;F=E*"D["@D)<F%N9V4N;6]V951O16QE;65N
M=%1E>'0H;F]D92D["@D)*&-O;&QA<'-E9"D@)B8@<F%N9V4N8V]L;&%P<V4H
M<&]S*3L*"0ER86YG92YS96QE8W0H*3L*"7T@96QS92!["@D)=F%R('-E;"`]
M('1H:7,N7V=E=%-E;&5C=&EO;B@I.PH)"7)A;F=E(#T@=&AI<RY?9&]C+F-R
M96%T95)A;F=E*"D["@D)<F%N9V4N<V5L96-T3F]D94-O;G1E;G1S*&YO9&4I
M.PH)"2AC;VQL87!S960I("8F(')A;F=E+F-O;&QA<'-E*'!O<RD["@D)<V5L
M+G)E;6]V94%L;%)A;F=E<R@I.PH)"7-E;"YA9&1286YG92AR86YG92D["@E]
M"GT["@HO*BH@0V%L;"!T:&ES(&9U;F-T:6]N('1O(&EN<V5R="!(5$U,(&-O
M9&4@870@=&AE(&-U<G)E;G0@<&]S:71I;VXN("!)="!D96QE=&5S"B`J('1H
M92!S96QE8W1I;VXL(&EF(&%N>2X*("HO"DA434Q!<F5A+G!R;W1O='EP92YI
M;G-E<G1(5$U,(#T@9G5N8W1I;VXH:'1M;"D@>PH)=F%R('-E;"`]('1H:7,N
M7V=E=%-E;&5C=&EO;B@I.PH)=F%R(')A;F=E(#T@=&AI<RY?8W)E871E4F%N
M9V4H<V5L*3L*"6EF("A(5$U,07)E82YI<U]I92D@>PH)"7)A;F=E+G!A<W1E
M2%1-3"AH=&UL*3L*"7T@96QS92!["@D)+R\@8V]N<W1R=6-T(&$@;F5W(&1O
M8W5M96YT(&9R86=M96YT('=I=&@@=&AE(&=I=F5N($A434P*"0EV87(@9G)A
M9VUE;G0@/2!T:&ES+E]D;V,N8W)E871E1&]C=6UE;G1&<F%G;65N="@I.PH)
M"79A<B!D:78@/2!T:&ES+E]D;V,N8W)E871E16QE;65N="@B9&EV(BD["@D)
M9&EV+FEN;F5R2%1-3"`](&AT;6P["@D)=VAI;&4@*&1I=BYF:7)S=$-H:6QD
M*2!["@D)"2\O('1H92!F;VQL;W=I;F<@8V%L;"!A;'-O(')E;6]V97,@=&AE
M(&YO9&4@9G)O;2!D:78*"0D)9G)A9VUE;G0N87!P96YD0VAI;&0H9&EV+F9I
M<G-T0VAI;&0I.PH)"7T*"0DO+R!T:&ES(&%L<V\@<F5M;W9E<R!T:&4@<V5L
M96-T:6]N"@D)=F%R(&YO9&4@/2!T:&ES+FEN<V5R=$YO9&5!=%-E;&5C=&EO
M;BAF<F%G;65N="D["@E]"GT["@HO*BH*("H@($-A;&P@=&AI<R!F=6YC=&EO
M;B!T;R!S=7)R;W5N9"!T:&4@97AI<W1I;F<@2%1-3"!C;V1E(&EN('1H92!S
M96QE8W1I;VX@=VET:`H@*B`@>6]U<B!T86=S+B`@1DE8344Z(&)U9V=Y(2`@
M5&AI<R!F=6YC=&EO;B!W:6QL(&)E(&1E<')E8V%T960@(G-O;VXB+@H@*B\*
M2%1-3$%R96$N<')O=&]T>7!E+G-U<G)O=6YD2%1-3"`](&9U;F-T:6]N*'-T
M87)T5&%G+"!E;F1486<I('L*"79A<B!H=&UL(#T@=&AI<RYG971396QE8W1E
M9$A434PH*3L*"2\O('1H92!F;VQL;W=I;F<@86QS;R!D96QE=&5S('1H92!S
M96QE8W1I;VX*"71H:7,N:6YS97)T2%1-3"AS=&%R=%1A9R`K(&AT;6P@*R!E
M;F1486<I.PI].PH*+R\O(%)E=')I979E('1H92!S96QE8W1E9"!B;&]C:PI(
M5$U,07)E82YP<F]T;W1Y<&4N9V5T4V5L96-T961(5$U,(#T@9G5N8W1I;VXH
M*2!["@EV87(@<V5L(#T@=&AI<RY?9V5T4V5L96-T:6]N*"D["@EV87(@<F%N
M9V4@/2!T:&ES+E]C<F5A=&5286YG92AS96PI.PH)=F%R(&5X:7-T:6YG(#T@
M;G5L;#L*"6EF("A(5$U,07)E82YI<U]I92D@>PH)"65X:7-T:6YG(#T@<F%N
M9V4N:'1M;%1E>'0["@E](&5L<V4@>PH)"65X:7-T:6YG(#T@2%1-3$%R96$N
M9V5T2%1-3"AR86YG92YC;&]N94-O;G1E;G1S*"DL(&9A;'-E+"!T:&ES*3L*
M"7T*"7)E='5R;B!E>&ES=&EN9SL*?3L*"B\O+R!2971U<FX@=')U92!I9B!W
M92!H879E('-O;64@<V5L96-T:6]N"DA434Q!<F5A+G!R;W1O='EP92YH87-3
M96QE8W1E9%1E>'0@/2!F=6YC=&EO;B@I('L*"2\O($9)6$U%.B!C;VUE(%]O
M;E\@;6ES:&]O+"!Y;W4@8V%N(&1O(&)E='1E<B!T:&%N('1H:7,@.RTI"@ER
M971U<FX@=&AI<RYG971396QE8W1E9$A434PH*2`A/2`G)SL*?3L*"DA434Q!
M<F5A+G!R;W1O='EP92Y?8W)E871E3&EN:R`](&9U;F-T:6]N*&QI;FLI('L*
M"79A<B!E9&ET;W(@/2!T:&ES.PH)=F%R(&]U='!A<F%M(#T@;G5L;#L*"6EF
M("AT>7!E;V8@;&EN:R`]/2`B=6YD969I;F5D(BD@>PH)"6QI;FL@/2!T:&ES
M+F=E=%!A<F5N=$5L96UE;G0H*3L*"0EI9B`H;&EN:RD@>PH)"0EI9B`H+UYI
M;6<D+VDN=&5S="AL:6YK+G1A9TYA;64I*0H)"0D);&EN:R`](&QI;FLN<&%R
M96YT3F]D93L*"0D):68@*"$O7F$D+VDN=&5S="AL:6YK+G1A9TYA;64I*0H)
M"0D);&EN:R`](&YU;&P["@D)?0H)?0H):68@*"%L:6YK*2!["@D)=F%R('-E
M;"`](&5D:71O<BY?9V5T4V5L96-T:6]N*"D["@D)=F%R(')A;F=E(#T@961I
M=&]R+E]C<F5A=&5286YG92AS96PI.PH)"79A<B!C;VUP87)E(#T@,#L*"0EI
M9B`H2%1-3$%R96$N:7-?:64I('L*"0D)8V]M<&%R92`](')A;F=E+F-O;7!A
M<F5%;F10;VEN=',H(E-T87)T5&]%;F0B+"!R86YG92D["@D)?2!E;'-E('L*
M"0D)8V]M<&%R92`](')A;F=E+F-O;7!A<F5";W5N9&%R>5!O:6YT<RAR86YG
M92Y35$%25%]43U]%3D0L(')A;F=E*3L*"0E]"@D):68@*&-O;7!A<F4@/3T@
M,"D@>PH)"0EA;&5R="@B66]U(&YE960@=&\@<V5L96-T('-O;64@=&5X="!B
M969O<F4@8W)E871I;F<@82!L:6YK(BD["@D)"7)E='5R;CL*"0E]"@D);W5T
M<&%R86T@/2!["@D)"69?:')E9B`Z("<G+`H)"0EF7W1I=&QE(#H@)R<L"@D)
M"69?=&%R9V5T(#H@)R<L"@D)"69?=7-E=&%R9V5T(#H@961I=&]R+F-O;F9I
M9RYM86ME3&EN:U-H;W=S5&%R9V5T"@D)?3L*"7T@96QS90H)"6]U='!A<F%M
M(#T@>PH)"0EF7VAR968@("`Z($A434Q!<F5A+FES7VEE(#\@961I=&]R+G-T
M<FEP0F%S95523"AL:6YK+FAR968I(#H@;&EN:RYG971!='1R:6)U=&4H(FAR
M968B*2P*"0D)9E]T:71L92`@.B!L:6YK+G1I=&QE+`H)"0EF7W1A<F=E="`Z
M(&QI;FLN=&%R9V5T+`H)"0EF7W5S971A<F=E="`Z(&5D:71O<BYC;VYF:6<N
M;6%K94QI;FM3:&]W<U1A<F=E=`H)"7T["@ET:&ES+E]P;W!U<$1I86QO9R@B
M;&EN:RYH=&UL(BP@9G5N8W1I;VXH<&%R86TI('L*"0EI9B`H(7!A<F%M*0H)
M"0ER971U<FX@9F%L<V4["@D)=F%R(&$@/2!L:6YK.PH)"6EF("@A82D@=')Y
M('L*"0D)961I=&]R+E]D;V,N97AE8T-O;6UA;F0H(F-R96%T96QI;FLB+"!F
M86QS92P@<&%R86TN9E]H<F5F*3L*"0D)82`](&5D:71O<BYG971087)E;G1%
M;&5M96YT*"D["@D)"79A<B!S96P@/2!E9&ET;W(N7V=E=%-E;&5C=&EO;B@I
M.PH)"0EV87(@<F%N9V4@/2!E9&ET;W(N7V-R96%T95)A;F=E*'-E;"D["@D)
M"6EF("@A2%1-3$%R96$N:7-?:64I('L*"0D)"6$@/2!R86YG92YS=&%R=$-O
M;G1A:6YE<CL*"0D)"6EF("@A+UYA)"]I+G1E<W0H82YT86=.86UE*2D@>PH)
M"0D)"6$@/2!A+FYE>'13:6)L:6YG.PH)"0D)"6EF("AA(#T](&YU;&PI"@D)
M"0D)"6$@/2!R86YG92YS=&%R=$-O;G1A:6YE<BYP87)E;G1.;V1E.PH)"0D)
M?0H)"0E]"@D)?2!C871C:"AE*2![?0H)"65L<V4@>PH)"0EV87(@:')E9B`]
M('!A<F%M+F9?:')E9BYT<FEM*"D["@D)"65D:71O<BYS96QE8W1.;V1E0V]N
M=&5N=',H82D["@D)"6EF("AH<F5F(#T]("(B*2!["@D)"0EE9&ET;W(N7V1O
M8RYE>&5C0V]M;6%N9"@B=6YL:6YK(BP@9F%L<V4L(&YU;&PI.PH)"0D)961I
M=&]R+G5P9&%T951O;VQB87(H*3L*"0D)"7)E='5R;B!F86QS93L*"0D)?0H)
M"0EE;'-E('L*"0D)"6$N:')E9B`](&AR968["@D)"7T*"0E]"@D):68@*"$H
M82`F)B`O7F$D+VDN=&5S="AA+G1A9TYA;64I*2D*"0D)<F5T=7)N(&9A;'-E
M.PH)"6$N=&%R9V5T(#T@<&%R86TN9E]T87)G970N=')I;2@I.PH)"6$N=&ET
M;&4@/2!P87)A;2YF7W1I=&QE+G1R:6TH*3L*"0EE9&ET;W(N<V5L96-T3F]D
M94-O;G1E;G1S*&$I.PH)"65D:71O<BYU<&1A=&54;V]L8F%R*"D["@E]+"!O
M=71P87)A;2D["GT["@HO+R!#86QL960@=VAE;B!T:&4@=7-E<B!C;&EC:W,@
M;VX@(DEN<V5R=$EM86=E(B!B=71T;VXN("!)9B!A;B!I;6%G92!I<R!A;')E
M861Y"B\O('1H97)E+"!I="!W:6QL(&IU<W0@;6]D:69Y(&ET)W,@<')O<&5R
M=&EE<RX*2%1-3$%R96$N<')O=&]T>7!E+E]I;G-E<G1);6%G92`](&9U;F-T
M:6]N*&EM86=E*2!["@EV87(@961I=&]R(#T@=&AI<SL)+R\@9F]R(&YE<W1E
M9"!F=6YC=&EO;G,*"79A<B!O=71P87)A;2`](&YU;&P["@EI9B`H='EP96]F
M(&EM86=E(#T](")U;F1E9FEN960B*2!["@D):6UA9V4@/2!T:&ES+F=E=%!A
M<F5N=$5L96UE;G0H*3L*"0EI9B`H:6UA9V4@)B8@(2]>:6UG)"]I+G1E<W0H
M:6UA9V4N=&%G3F%M92DI"@D)"6EM86=E(#T@;G5L;#L*"7T*"6EF("AI;6%G
M92D@;W5T<&%R86T@/2!["@D)9E]B87-E("`@.B!E9&ET;W(N8V]N9FEG+F)A
M<V554DPL"@D)9E]U<FP@("`@.B!(5$U,07)E82YI<U]I92`_(&5D:71O<BYS
M=')I<$)A<V554DPH:6UA9V4N<W)C*2`Z(&EM86=E+F=E=$%T=')I8G5T92@B
M<W)C(BDL"@D)9E]A;'0@("`@.B!I;6%G92YA;'0L"@D)9E]B;W)D97(@.B!I
M;6%G92YB;W)D97(L"@D)9E]A;&EG;B`@.B!I;6%G92YA;&EG;BP*"0EF7W9E
M<G0@("`Z(&EM86=E+G9S<&%C92P*"0EF7VAO<FEZ("`Z(&EM86=E+FAS<&%C
M90H)?3L*"71H:7,N7W!O<'5P1&EA;&]G*")I;G-E<G1?:6UA9V4N:'1M;"(L
M(&9U;F-T:6]N*'!A<F%M*2!["@D):68@*"%P87)A;2D@>PDO+R!U<V5R(&UU
M<W0@:&%V92!P<F5S<V5D($-A;F-E;`H)"0ER971U<FX@9F%L<V4["@D)?0H)
M"79A<B!I;6<@/2!I;6%G93L*"0EI9B`H(6EM9RD@>PH)"0EV87(@<V5L(#T@
M961I=&]R+E]G971396QE8W1I;VXH*3L*"0D)=F%R(')A;F=E(#T@961I=&]R
M+E]C<F5A=&5286YG92AS96PI.PH)"0EE9&ET;W(N7V1O8RYE>&5C0V]M;6%N
M9"@B:6YS97)T:6UA9V4B+"!F86QS92P@<&%R86TN9E]U<FPI.PH)"0EI9B`H
M2%1-3$%R96$N:7-?:64I('L*"0D)"6EM9R`](')A;F=E+G!A<F5N=$5L96UE
M;G0H*3L*"0D)"2\O('=O;F1E<B!I9B!T:&ES('=O<FMS+BXN"@D)"0EI9B`H
M:6UG+G1A9TYA;64N=&],;W=E<D-A<V4H*2`A/2`B:6UG(BD@>PH)"0D)"6EM
M9R`](&EM9RYP<F5V:6]U<U-I8FQI;F<["@D)"0E]"@D)"7T@96QS92!["@D)
M"0EI;6<@/2!R86YG92YS=&%R=$-O;G1A:6YE<BYP<F5V:6]U<U-I8FQI;F<[
M"@D)"7T*"0E](&5L<V4@>PH)"0EI;6<N<W)C(#T@<&%R86TN9E]U<FP["@D)
M?0H*"0EF;W(@*'9A<B!F:65L9"!I;B!P87)A;2D@>PH)"0EV87(@=F%L=64@
M/2!P87)A;5MF:65L9%T["@D)"7-W:71C:"`H9FEE;&0I('L*"0D)("`@(&-A
M<V4@(F9?86QT(B`@("`Z(&EM9RYA;'0)(#T@=F%L=64[(&)R96%K.PH)"0D@
M("`@8V%S92`B9E]B;W)D97(B(#H@:6UG+F)O<F1E<B`]('!A<G-E26YT*'9A
M;'5E('Q\("(P(BD[(&)R96%K.PH)"0D@("`@8V%S92`B9E]A;&EG;B(@(#H@
M:6UG+F%L:6=N"2`]('9A;'5E.R!B<F5A:SL*"0D)("`@(&-A<V4@(F9?=F5R
M="(@("`Z(&EM9RYV<W!A8V4@/2!P87)S94EN="AV86QU92!\?"`B,"(I.R!B
M<F5A:SL*"0D)("`@(&-A<V4@(F9?:&]R:7HB("`Z(&EM9RYH<W!A8V4@/2!P
M87)S94EN="AV86QU92!\?"`B,"(I.R!B<F5A:SL*"0D)?0H)"7T*"7TL(&]U
M='!A<F%M*3L*?3L*"B\O($-A;&QE9"!W:&5N('1H92!U<V5R(&-L:6-K<R!T
M:&4@26YS97)T(%1A8FQE(&)U='1O;@I(5$U,07)E82YP<F]T;W1Y<&4N7VEN
M<V5R=%1A8FQE(#T@9G5N8W1I;VXH*2!["@EV87(@<V5L(#T@=&AI<RY?9V5T
M4V5L96-T:6]N*"D["@EV87(@<F%N9V4@/2!T:&ES+E]C<F5A=&5286YG92AS
M96PI.PH)=F%R(&5D:71O<B`]('1H:7,["2\O(&9O<B!N97-T960@9G5N8W1I
M;VYS"@ET:&ES+E]P;W!U<$1I86QO9R@B:6YS97)T7W1A8FQE+FAT;6PB+"!F
M=6YC=&EO;BAP87)A;2D@>PH)"6EF("@A<&%R86TI('L)+R\@=7-E<B!M=7-T
M(&AA=F4@<')E<W-E9"!#86YC96P*"0D)<F5T=7)N(&9A;'-E.PH)"7T*"0EV
M87(@9&]C(#T@961I=&]R+E]D;V,["@D)+R\@8W)E871E('1H92!T86)L92!E
M;&5M96YT"@D)=F%R('1A8FQE(#T@9&]C+F-R96%T945L96UE;G0H(G1A8FQE
M(BD["@D)+R\@87-S:6=N('1H92!G:79E;B!A<F=U;65N=',*"@D)9F]R("AV
M87(@9FEE;&0@:6X@<&%R86TI('L*"0D)=F%R('9A;'5E(#T@<&%R86U;9FEE
M;&1=.PH)"0EI9B`H(79A;'5E*2!["@D)"0EC;VYT:6YU93L*"0D)?0H)"0ES
M=VET8V@@*&9I96QD*2!["@D)"2`@("!C87-E(")F7W=I9'1H(B`@(#H@=&%B
M;&4N<W1Y;&4N=VED=&@@/2!V86QU92`K('!A<F%M6R)F7W5N:70B73L@8G)E
M86L["@D)"2`@("!C87-E(")F7V%L:6=N(B`@(#H@=&%B;&4N86QI9VX)(#T@
M=F%L=64[(&)R96%K.PH)"0D@("`@8V%S92`B9E]B;W)D97(B("`Z('1A8FQE
M+F)O<F1E<@D@/2!P87)S94EN="AV86QU92D[(&)R96%K.PH)"0D@("`@8V%S
M92`B9E]S<&%C:6YG(B`Z('1A8FQE+F-E;&Q3<&%C:6YG(#T@<&%R<V5);G0H
M=F%L=64I.R!B<F5A:SL*"0D)("`@(&-A<V4@(F9?<&%D9&EN9R(@.B!T86)L
M92YC96QL4&%D9&EN9R`]('!A<G-E26YT*'9A;'5E*3L@8G)E86L["@D)"7T*
M"0E]"@D)=F%R(&-E;&QW:61T:"`](#`["@D):68@*'!A<F%M+F9?9FEX960I
M"@D)"6-E;&QW:61T:"`]($UA=&@N9FQO;W(H,3`P("\@<&%R<V5);G0H<&%R
M86TN9E]C;VQS*2D["@D)=F%R('1B;V1Y(#T@9&]C+F-R96%T945L96UE;G0H
M(G1B;V1Y(BD["@D)=&%B;&4N87!P96YD0VAI;&0H=&)O9'DI.PH)"69O<B`H
M=F%R(&D@/2`P.R!I(#P@<&%R86U;(F9?<F]W<R)=.R`K*VDI('L*"0D)=F%R
M('1R(#T@9&]C+F-R96%T945L96UE;G0H(G1R(BD["@D)"71B;V1Y+F%P<&5N
M9$-H:6QD*'1R*3L*"0D)9F]R("AV87(@:B`](#`[(&H@/"!P87)A;5LB9E]C
M;VQS(ET[("LK:BD@>PH)"0D)=F%R('1D(#T@9&]C+F-R96%T945L96UE;G0H
M(G1D(BD["@D)"0EI9B`H8V5L;'=I9'1H*0H)"0D)"71D+G-T>6QE+G=I9'1H
M(#T@8V5L;'=I9'1H("L@(B4B.PH)"0D)='(N87!P96YD0VAI;&0H=&0I.PH)
M"0D)+R\@36]Z:6QL82!L:6ME<R!T;R!S964@<V]M971H:6YG(&EN<VED92!T
M:&4@8V5L;"X*"0D)"2A(5$U,07)E82YI<U]G96-K;RD@)B8@=&0N87!P96YD
M0VAI;&0H9&]C+F-R96%T945L96UE;G0H(F)R(BDI.PH)"0E]"@D)?0H)"6EF
M("A(5$U,07)E82YI<U]I92D@>PH)"0ER86YG92YP87-T94A434PH=&%B;&4N
M;W5T97)(5$U,*3L*"0E](&5L<V4@>PH)"0DO+R!I;G-E<G0@=&AE('1A8FQE
M"@D)"65D:71O<BYI;G-E<G1.;V1E071396QE8W1I;VXH=&%B;&4I.PH)"7T*
M"0ER971U<FX@=')U93L*"7TL(&YU;&PI.PI].PH*+RHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*@H@*B`@0V%T
M96=O<GDZ($5614Y4($A!3D1,15)3"B`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHO"@HO+R!E;"!I<R!R969E
M<F5N8V4@=&\@=&AE(%-%3$5#5"!O8FIE8W0*+R\@='AT(&ES('1H92!N86UE
M(&]F('1H92!S96QE8W0@9FEE;&0L(&%S(&EN(&-O;F9I9RYT;V]L8F%R"DA4
M34Q!<F5A+G!R;W1O='EP92Y?8V]M8F]396QE8W1E9"`](&9U;F-T:6]N*&5L
M+"!T>'0I('L*"71H:7,N9F]C=7-%9&ET;W(H*3L*"79A<B!V86QU92`](&5L
M+F]P=&EO;G-;96PN<V5L96-T961);F1E>%TN=F%L=64["@ES=VET8V@@*'1X
M="D@>PH)("`@(&-A<V4@(F9O;G1N86UE(CH*"2`@("!C87-E(")F;VYT<VEZ
M92(Z('1H:7,N97AE8T-O;6UA;F0H='AT+"!F86QS92P@=F%L=64I.R!B<F5A
M:SL*"2`@("!C87-E(")F;W)M871B;&]C:R(Z"@D)*$A434Q!<F5A+FES7VEE
M*2`F)B`H=F%L=64@/2`B/"(@*R!V86QU92`K("(^(BD["@D)=&AI<RYE>&5C
M0V]M;6%N9"AT>'0L(&9A;'-E+"!V86QU92D["@D)8G)E86L["@D@("`@9&5F
M875L=#H*"0DO+R!T<GD@=&\@;&]O:R!I="!U<"!I;B!T:&4@<F5G:7-T97)E
M9"!D<F]P9&]W;G,*"0EV87(@9')O<&1O=VX@/2!T:&ES+F-O;F9I9RYC=7-T
M;VU396QE8W1S6W1X=%T["@D):68@*'1Y<&5O9B!D<F]P9&]W;B`A/2`B=6YD
M969I;F5D(BD@>PH)"0ED<F]P9&]W;BYA8W1I;VXH=&AI<RD["@D)?2!E;'-E
M('L*"0D)86QE<G0H(D9)6$U%.B!C;VUB;R!B;W@@(B`K('1X="`K("(@;F]T
M(&EM<&QE;65N=&5D(BD["@D)?0H)?0I].PH*+R\@=&AE(&5X96-#;VUM86YD
M(&9U;F-T:6]N("AI;G1E<F-E<'1S('-O;64@8V]M;6%N9',@86YD(')E<&QA
M8V5S('1H96T@=VET:`HO+R!O=7(@;W=N(&EM<&QE;65N=&%T:6]N*0I(5$U,
M07)E82YP<F]T;W1Y<&4N97AE8T-O;6UA;F0@/2!F=6YC=&EO;BAC;61)1"P@
M54DL('!A<F%M*2!["@EV87(@961I=&]R(#T@=&AI<SL)+R\@9F]R(&YE<W1E
M9"!F=6YC=&EO;G,*"71H:7,N9F]C=7-%9&ET;W(H*3L*"6-M9$E$(#T@8VUD
M240N=&],;W=E<D-A<V4H*3L*"6EF("A(5$U,07)E82YI<U]G96-K;RD@=')Y
M('L@=&AI<RY?9&]C+F5X96-#;VUM86YD*"=U<V5#4U,G+"!F86QS92P@=')U
M92D[('T@8V%T8V@@*&4I('M].PH)<W=I=&-H("AC;61)1"D@>PH)("`@(&-A
M<V4@(FAT;6QM;V1E(B`Z('1H:7,N<V5T36]D92@I.R!B<F5A:SL*"2`@("!C
M87-E(")H:6QI=&5C;VQO<B(Z"@D)*$A434Q!<F5A+FES7VEE*2`F)B`H8VUD
M240@/2`B8F%C:V-O;&]R(BD["@D@("`@8V%S92`B9F]R96-O;&]R(CH*"0ET
M:&ES+E]P;W!U<$1I86QO9R@B<V5L96-T7V-O;&]R+FAT;6PB+"!F=6YC=&EO
M;BAC;VQO<BD@>PH)"0EI9B`H8V]L;W(I('L@+R\@<V5L96-T:6]N(&YO="!C
M86YC96QE9`H)"0D)961I=&]R+E]D;V,N97AE8T-O;6UA;F0H8VUD240L(&9A
M;'-E+"`B(R(@*R!C;VQO<BD["@D)"7T*"0E]+"!(5$U,07)E82Y?8V]L;W)4
M;U)G8BAT:&ES+E]D;V,N<75E<GE#;VUM86YD5F%L=64H8VUD240I*2D["@D)
M8G)E86L["@D@("`@8V%S92`B8W)E871E;&EN:R(Z"@D)=&AI<RY?8W)E871E
M3&EN:R@I.PH)"6)R96%K.PH)("`@(&-A<V4@(G!O<'5P961I=&]R(CH*"0DO
M+R!T:&ES(&]B:F5C="!W:6QL(&)E('!A<W-E9"!T;R!T:&4@;F5W;'D@;W!E
M;F5D('=I;F1O=PH)"4A434Q!<F5A+E]O8FIE8W0@/2!T:&ES.PH)"6EF("A(
M5$U,07)E82YI<U]I92D@>PH)"0DO+VEF("AC;VYF:7)M*$A434Q!<F5A+DDQ
M.$XN;7-G6R))12US=6-K<RUF=6QL+7-C<F5E;B)=*2D*"0D)>PH)"0D)=VEN
M9&]W+F]P96XH=&AI<RYP;W!U<%523"@B9G5L;'-C<F5E;BYH=&UL(BDL(")H
M85]F=6QL<V-R965N(BP*"0D)"0D@("`@(G1O;VQB87(];F\L;&]C871I;VX]
M;F\L9&ER96-T;W)I97,];F\L<W1A='5S/6YO+&UE;G5B87(];F\L(B`K"@D)
M"0D)("`@(")S8W)O;&QB87)S/6YO+')E<VEZ86)L93UY97,L=VED=&@]-C0P
M+&AE:6=H=#TT.#`B*3L*"0D)?0H)"7T@96QS92!["@D)"7=I;F1O=RYO<&5N
M*'1H:7,N<&]P=7!54DPH(F9U;&QS8W)E96XN:'1M;"(I+"`B:&%?9G5L;'-C
M<F5E;B(L"@D)"0D@("`@(G1O;VQB87(];F\L;65N=6)A<CUN;RQP97)S;VYA
M;&)A<CUN;RQW:61T:#TV-#`L:&5I9VAT/30X,"PB("L*"0D)"2`@("`B<V-R
M;VQL8F%R<SUN;RQR97-I>F%B;&4]>65S(BD["@D)?0H)"6)R96%K.PH)("`@
M(&-A<V4@(G5N9&\B.@H)("`@(&-A<V4@(G)E9&\B.@H)"6EF("AT:&ES+E]C
M=7-T;VU5;F1O*0H)"0ET:&ES6V-M9$E$72@I.PH)"65L<V4*"0D)=&AI<RY?
M9&]C+F5X96-#;VUM86YD*&-M9$E$+"!522P@<&%R86TI.PH)"6)R96%K.PH)
M("`@(&-A<V4@(FEN<V5R='1A8FQE(CH@=&AI<RY?:6YS97)T5&%B;&4H*3L@
M8G)E86L["@D@("`@8V%S92`B:6YS97)T:6UA9V4B.B!T:&ES+E]I;G-E<G1)
M;6%G92@I.R!B<F5A:SL*"2`@("!C87-E(")A8F]U="(@("`@.B!T:&ES+E]P
M;W!U<$1I86QO9R@B86)O=70N:'1M;"(L(&YU;&PL('1H:7,I.R!B<F5A:SL*
M"2`@("!C87-E(")S:&]W:&5L<"(@.B!W:6YD;W<N;W!E;BA?961I=&]R7W5R
M;"`K(")R969E<F5N8V4N:'1M;"(L(")H85]H96QP(BD[(&)R96%K.PH*"2`@
M("!C87-E(")K:6QL=V]R9"(Z('1H:7,N7W=O<F1#;&5A;B@I.R!B<F5A:SL*
M"@D@("`@8V%S92`B8W5T(CH*"2`@("!C87-E(")C;W!Y(CH*"2`@("!C87-E
M(")P87-T92(Z"@D)=')Y('L*"0D)=&AI<RY?9&]C+F5X96-#;VUM86YD*&-M
M9$E$+"!522P@<&%R86TI.PH)"0EI9B`H=&AI<RYC;VYF:6<N:VEL;%=O<F1/
M;E!A<W1E*0H)"0D)=&AI<RY?=V]R9$-L96%N*"D["@D)?2!C871C:"`H92D@
M>PH)"0EI9B`H2%1-3$%R96$N:7-?9V5C:V\I('L*"0D)"6EF("AT>7!E;V8@
M2%1-3$%R96$N23$X3BYM<V=;(DUO>BU#;&EP8F]A<F0B72`]/2`B=6YD969I
M;F5D(BD@>PH)"0D)"4A434Q!<F5A+DDQ.$XN;7-G6R)-;WHM0VQI<&)O87)D
M(ET@/0H)"0D)"0DB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S
M<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@(B`K"@D)"0D)"2)F
M;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN
M:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G("(@*PH)"0D)"0DB=VAI8V@@<VAO
M=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L
M:7!B;V%R9"Y<;EQN(B`K"@D)"0D)"2);1DE8344Z('!L96%S92!T<F%N<VQA
M=&4@=&AI<R!M97-S86=E(&EN('EO=7(@;&%N9W5A9V4@9&5F:6YI=&EO;B!F
M:6QE+ETB.PH)"0D)?0H)"0D):68@*&-O;F9I<FTH2%1-3$%R96$N23$X3BYM
M<V=;(DUO>BU#;&EP8F]A<F0B72DI"@D)"0D)=VEN9&]W+F]P96XH(FAT='`Z
M+R]M;WII;&QA+F]R9R]E9&ET;W(O;6ED87-D96UO+W-E8W5R:71Y<')E9G,N
M:'1M;"(I.PH)"0E]"@D)?0H)"6)R96%K.PH)("`@(&-A<V4@(FQE9G1T;W)I
M9VAT(CH*"2`@("!C87-E(")R:6=H='1O;&5F="(Z"@D)=F%R(&1I<B`]("AC
M;61)1"`]/2`B<FEG:'1T;VQE9G0B*2`_(")R=&PB(#H@(FQT<B(["@D)=F%R
M(&5L(#T@=&AI<RYG971087)E;G1%;&5M96YT*"D["@D)=VAI;&4@*&5L("8F
M("%(5$U,07)E82YI<T)L;V-K16QE;65N="AE;"DI"@D)"65L(#T@96PN<&%R
M96YT3F]D93L*"0EI9B`H96PI('L*"0D):68@*&5L+G-T>6QE+F1I<F5C=&EO
M;B`]/2!D:7(I"@D)"0EE;"YS='EL92YD:7)E8W1I;VX@/2`B(CL*"0D)96QS
M90H)"0D)96PN<W1Y;&4N9&ER96-T:6]N(#T@9&ER.PH)"7T*"0EB<F5A:SL*
M"2`@("!D969A=6QT.B!T<GD@>R!T:&ES+E]D;V,N97AE8T-O;6UA;F0H8VUD
M240L(%5)+"!P87)A;2D[('T*"0EC871C:"AE*2![(&EF("AT:&ES+F-O;F9I
M9RYD96)U9RD@>R!A;&5R="AE("L@(EQN7&YB>2!E>&5C0V]M;6%N9"@B("L@
M8VUD240@*R`B*3LB*3L@?2!]"@E]"@ET:&ES+G5P9&%T951O;VQB87(H*3L*
M"7)E='5R;B!F86QS93L*?3L*"B\J*B!!(&=E;F5R:6,@979E;G0@:&%N9&QE
M<B!F;W(@=&AI;F=S('1H870@:&%P<&5N(&EN('1H92!)1E)!344G<R!D;V-U
M;65N="X*("H@5&AI<R!F=6YC=&EO;B!A;'-O(&AA;F1L97,@:V5Y(&)I;F1I
M;F=S+B`J+PI(5$U,07)E82YP<F]T;W1Y<&4N7V5D:71O<D5V96YT(#T@9G5N
M8W1I;VXH978I('L*"79A<B!E9&ET;W(@/2!T:&ES.PH)=F%R(&ME>45V96YT
M(#T@*$A434Q!<F5A+FES7VEE("8F(&5V+G1Y<&4@/3T@(FME>61O=VXB*2!\
M?"`H(4A434Q!<F5A+FES7VEE("8F(&5V+G1Y<&4@/3T@(FME>7!R97-S(BD[
M"@H):68@*&ME>45V96YT*0H)"69O<B`H=F%R(&D@:6X@961I=&]R+G!L=6=I
M;G,I('L*"0D)=F%R('!L=6=I;B`](&5D:71O<BYP;'5G:6YS6VE=+FEN<W1A
M;F-E.PH)"0EI9B`H='EP96]F('!L=6=I;BYO;DME>5!R97-S(#T](")F=6YC
M=&EO;B(I"@D)"0EI9B`H<&QU9VEN+F]N2V5Y4')E<W,H978I*0H)"0D)"7)E
M='5R;B!F86QS93L*"0E]"@EI9B`H:V5Y179E;G0@)B8@978N8W1R;$ME>2`F
M)B`A978N86QT2V5Y*2!["@D)=F%R('-E;"`](&YU;&P["@D)=F%R(')A;F=E
M(#T@;G5L;#L*"0EV87(@:V5Y(#T@4W1R:6YG+F9R;VU#:&%R0V]D92A(5$U,
M07)E82YI<U]I92`_(&5V+FME>4-O9&4@.B!E=BYC:&%R0V]D92DN=&],;W=E
M<D-A<V4H*3L*"0EV87(@8VUD(#T@;G5L;#L*"0EV87(@=F%L=64@/2!N=6QL
M.PH)"7-W:71C:"`H:V5Y*2!["@D)("`@(&-A<V4@)V$G.@H)"0EI9B`H(4A4
M34Q!<F5A+FES7VEE*2!["@D)"0DO+R!+15D@<V5L96-T(&%L;`H)"0D)<V5L
M(#T@=&AI<RY?9V5T4V5L96-T:6]N*"D["@D)"0ES96PN<F5M;W9E06QL4F%N
M9V5S*"D["@D)"0ER86YG92`]('1H:7,N7V-R96%T95)A;F=E*"D["@D)"0ER
M86YG92YS96QE8W1.;V1E0V]N=&5N=',H=&AI<RY?9&]C+F)O9'DI.PH)"0D)
M<V5L+F%D9%)A;F=E*')A;F=E*3L*"0D)"4A434Q!<F5A+E]S=&]P179E;G0H
M978I.PH)"0E]"@D)"6)R96%K.PH*"0D)+R\@<VEM<&QE(&ME>2!C;VUM86YD
M<R!F;VQL;W<*"@D)("`@(&-A<V4@)V(G.B!C;60@/2`B8F]L9"([(&)R96%K
M.PH)"2`@("!C87-E("=I)SH@8VUD(#T@(FET86QI8R([(&)R96%K.PH)"2`@
M("!C87-E("=U)SH@8VUD(#T@(G5N9&5R;&EN92([(&)R96%K.PH)"2`@("!C
M87-E("=S)SH@8VUD(#T@(G-T<FEK971H<F]U9V@B.R!B<F5A:SL*"0D@("`@
M8V%S92`G;"<Z(&-M9"`](")J=7-T:69Y;&5F="([(&)R96%K.PH)"2`@("!C
M87-E("=E)SH@8VUD(#T@(FIU<W1I9GEC96YT97(B.R!B<F5A:SL*"0D@("`@
M8V%S92`G<B<Z(&-M9"`](")J=7-T:69Y<FEG:'0B.R!B<F5A:SL*"0D@("`@
M8V%S92`G:B<Z(&-M9"`](")J=7-T:69Y9G5L;"([(&)R96%K.PH)"2`@("!C
M87-E("=Z)SH@8VUD(#T@(G5N9&\B.R!B<F5A:SL*"0D@("`@8V%S92`G>2<Z
M(&-M9"`](")R961O(CL@8G)E86L["@D)("`@(&-A<V4@)W8G.B!I9B`H2%1-
M3$%R96$N:7-?:64@?'P@961I=&]R+F-O;F9I9RYH=&UL87)E85!A<W1E*2![
M(&-M9"`](")P87-T92([('T@8G)E86L["@D)("`@(&-A<V4@)VXG.B!C;60@
M/2`B9F]R;6%T8FQO8VLB.R!V86QU92`]($A434Q!<F5A+FES7VEE(#\@(CQP
M/B(@.B`B<"([(&)R96%K.PH*"0D@("`@8V%S92`G,"<Z(&-M9"`](")K:6QL
M=V]R9"([(&)R96%K.PH*"0D)+R\@:&5A9&EN9W,*"0D@("`@8V%S92`G,2<Z
M"@D)("`@(&-A<V4@)S(G.@H)"2`@("!C87-E("<S)SH*"0D@("`@8V%S92`G
M-"<Z"@D)("`@(&-A<V4@)S4G.@H)"2`@("!C87-E("<V)SH*"0D)8VUD(#T@
M(F9O<FUA=&)L;V-K(CL*"0D)=F%L=64@/2`B:"(@*R!K97D["@D)"6EF("A(
M5$U,07)E82YI<U]I92D*"0D)"79A;'5E(#T@(CPB("L@=F%L=64@*R`B/B([
M"@D)"6)R96%K.PH)"7T*"0EI9B`H8VUD*2!["@D)"2\O(&5X96-U=&4@<VEM
M<&QE(&-O;6UA;F0*"0D)=&AI<RYE>&5C0V]M;6%N9"AC;60L(&9A;'-E+"!V
M86QU92D["@D)"4A434Q!<F5A+E]S=&]P179E;G0H978I.PH)"7T*"7T*"65L
M<V4@:68@*&ME>45V96YT*2!["@D)+R\@;W1H97(@:V5Y<R!H97)E"@D)<W=I
M=&-H("AE=BYK97E#;V1E*2!["@D)("`@(&-A<V4@,3,Z("\O($M%62!E;G1E
M<@H)"0EI9B`H2%1-3$%R96$N:7-?9V5C:V\@)B8@(65V+G-H:69T2V5Y*2![
M"@D)"0ET:&ES+F1O;5]C:&5C:TEN<V5R=%`H*3L*"0D)"4A434Q!<F5A+E]S
M=&]P179E;G0H978I.PH)"0E]"@D)"6)R96%K.PH)"2`@("!C87-E(#@Z("\O
M($M%62!B86-K<W!A8V4*"0D@("`@8V%S92`T-CH@+R\@2T59(&1E;&5T90H)
M"0EI9B`H2%1-3$%R96$N:7-?9V5C:V\@)B8@(65V+G-H:69T2V5Y*2!["@D)
M"0EI9B`H=&AI<RYD;VU?8VAE8VM"86-K<W!A8V4H*2D*"0D)"0E(5$U,07)E
M82Y?<W1O<$5V96YT*&5V*3L*"0D)?2!E;'-E(&EF("A(5$U,07)E82YI<U]I
M92D@>PH)"0D):68@*'1H:7,N:65?8VAE8VM"86-K<W!A8V4H*2D*"0D)"0E(
M5$U,07)E82Y?<W1O<$5V96YT*&5V*3L*"0D)?0H)"0EB<F5A:SL*"0E]"@E]
M"@H)+R\@=7!D871E('1H92!T;V]L8F%R('-T871E(&%F=&5R('-O;64@=&EM
M90H):68@*&5D:71O<BY?=&EM97)4;V]L8F%R*2!["@D)8VQE87)4:6UE;W5T
M*&5D:71O<BY?=&EM97)4;V]L8F%R*3L*"7T*"65D:71O<BY?=&EM97)4;V]L
M8F%R(#T@<V5T5&EM96]U="AF=6YC=&EO;B@I('L*"0EE9&ET;W(N=7!D871E
M5&]O;&)A<B@I.PH)"65D:71O<BY?=&EM97)4;V]L8F%R(#T@;G5L;#L*"7TL
M(#4P*3L*?3L*"DA434Q!<F5A+G!R;W1O='EP92YS8W)O;&Q4;T-A<F5T(#T@
M9G5N8W1I;VXH*2!["@EV87(*"0EE(#T@=&AI<RYG971087)E;G1%;&5M96YT
M*"DL"@D)=R`]('1H:7,N7VEF<F%M92YC;VYT96YT5VEN9&]W+`H)"6@@/2!W
M+FEN;F5R2&5I9VAT('Q\('<N:&5I9VAT+`H)"60@/2!T:&ES+E]D;V,L"@D)
M="`](&0N9&]C=6UE;G1%;&5M96YT+G-C<F]L;%1O<"!\?"!D+F)O9'DN<V-R
M;VQL5&]P.PH):68@*'1Y<&5O9B!H(#T](")U;F1E9FEN960B*0H)"7)E='5R
M;B!F86QS93L*"6EF("AE+F]F9G-E=%1O<"`^(&@@*R!T*0H)"7<N<V-R;VQL
M5&\H92YO9F9S971,969T+"!E+F]F9G-E=%1O<"`M(&@@*R!E+F]F9G-E=$AE
M:6=H="D["GT["@I(5$U,07)E82YP<F]T;W1Y<&4N8V]N=F5R=$YO9&4@/2!F
M=6YC=&EO;BAE;"P@;F5W5&%G3F%M92D@>PH)=F%R(&YE=V5L(#T@=&AI<RY?
M9&]C+F-R96%T945L96UE;G0H;F5W5&%G3F%M92DL('`@/2!E;"YP87)E;G1.
M;V1E.PH)=VAI;&4@*&5L+F9I<G-T0VAI;&0I"@D);F5W96PN87!P96YD0VAI
M;&0H96PN9FER<W1#:&EL9"D["@EP+FEN<V5R=$)E9F]R92AN97=E;"P@96PI
M.PH)<"YR96UO=F5#:&EL9"AE;"D["@ER971U<FX@;F5W96P["GT["@I(5$U,
M07)E82YP<F]T;W1Y<&4N:65?8VAE8VM"86-K<W!A8V4@/2!F=6YC=&EO;B@I
M('L*"79A<B!S96P@/2!T:&ES+E]G971396QE8W1I;VXH*3L*"79A<B!R86YG
M92`]('1H:7,N7V-R96%T95)A;F=E*'-E;"D["@EV87(@<C(@/2!R86YG92YD
M=7!L:6-A=&4H*3L*"7(R+FUO=F53=&%R="@B8VAA<F%C=&5R(BP@+3$I.PH)
M=F%R(&$@/2!R,BYP87)E;G1%;&5M96YT*"D["@EI9B`H82`A/2!R86YG92YP
M87)E;G1%;&5M96YT*"D@)B8*"2`@("`O7F$D+VDN=&5S="AA+G1A9TYA;64I
M*2!["@D)<C(N8V]L;&%P<V4H=')U92D["@D)<C(N;6]V945N9"@B8VAA<F%C
M=&5R(BP@,2D["@D)<C(N<&%S=&5(5$U,*"<G*3L*"0ER,BYS96QE8W0H*3L*
M"0ER971U<FX@=')U93L*"7T*?3L*"DA434Q!<F5A+G!R;W1O='EP92YD;VU?
M8VAE8VM"86-K<W!A8V4@/2!F=6YC=&EO;B@I('L*"79A<B!S96QF(#T@=&AI
M<SL*"7-E=%1I;65O=70H9G5N8W1I;VXH*2!["@D)=F%R('-E;"`]('-E;&8N
M7V=E=%-E;&5C=&EO;B@I.PH)"79A<B!R86YG92`]('-E;&8N7V-R96%T95)A
M;F=E*'-E;"D["@D)=F%R(%-#(#T@<F%N9V4N<W1A<G1#;VYT86EN97(["@D)
M=F%R(%-/(#T@<F%N9V4N<W1A<G1/9F9S970["@D)=F%R($5#(#T@<F%N9V4N
M96YD0V]N=&%I;F5R.PH)"79A<B!%3R`](')A;F=E+F5N9$]F9G-E=#L*"0EV
M87(@;F5W<B`](%-#+FYE>'13:6)L:6YG.PH)"6EF("A30RYN;V1E5'EP92`]
M/2`S*0H)"0E30R`](%-#+G!A<F5N=$YO9&4["@D):68@*"$O7%,O+G1E<W0H
M4T,N=&%G3F%M92DI('L*"0D)=F%R('`@/2!D;V-U;65N="YC<F5A=&5%;&5M
M96YT*")P(BD["@D)"7=H:6QE("A30RYF:7)S=$-H:6QD*0H)"0D)<"YA<'!E
M;F1#:&EL9"A30RYF:7)S=$-H:6QD*3L*"0D)4T,N<&%R96YT3F]D92YI;G-E
M<G1"969O<F4H<"P@4T,I.PH)"0E30RYP87)E;G1.;V1E+G)E;6]V94-H:6QD
M*%-#*3L*"0D)=F%R('(@/2!R86YG92YC;&]N95)A;F=E*"D["@D)"7(N<V5T
M4W1A<G1"969O<F4H;F5W<BD["@D)"7(N<V5T16YD069T97(H;F5W<BD["@D)
M"7(N97AT<F%C=$-O;G1E;G1S*"D["@D)"7-E;"YR96UO=F5!;&Q286YG97,H
M*3L*"0D)<V5L+F%D9%)A;F=E*'(I.PH)"7T*"7TL(#$P*3L*?3L*"DA434Q!
M<F5A+G!R;W1O='EP92YD;VU?8VAE8VM);G-E<G10(#T@9G5N8W1I;VXH*2![
M"@EV87(@:2P@4T,L(&QE9G0L(')I9VAT+"!R,BP*"0ES96P@("`]('1H:7,N
M7V=E=%-E;&5C=&EO;B@I+`H)"7(@("`@(#T@=&AI<RY?8W)E871E4F%N9V4H
M<V5L*2P*"0EP("`@("`]('1H:7,N9V5T06QL06YC97-T;W)S*"DL"@D)8FQO
M8VL@/2!N=6QL+`H)"61O8R`@(#T@=&AI<RY?9&]C+`H)"6)O9'D@(#T@9&]C
M+F)O9'D["@H)9F]R("AI(#T@,#L@:2`\('`N;&5N9W1H.R`K*VDI"@D):68@
M*$A434Q!<F5A+FES0FQO8VM%;&5M96YT*'!;:5TI("8F("$O8F]D>7QH=&UL
M+VDN=&5S="AP6VE=+G1A9TYA;64I*2!["@D)"6)L;V-K(#T@<%MI73L*"0D)
M8G)E86L["@D)?0H*"6EF("@A<BYC;VQL87!S960I"@D)<BYD96QE=&5#;VYT
M96YT<R@I.PH)<V5L+G)E;6]V94%L;%)A;F=E<R@I.PH)4T,@/2!R+G-T87)T
M0V]N=&%I;F5R.PH*"6EF("@A8FQO8VLI('L*"0EL969T(#T@4T,["@D)9F]R
M("AI(#T@4T,[(&D@)B8@:2`A/2!B;V1Y("8F("%(5$U,07)E82YI<T)L;V-K
M16QE;65N="AI*3L@:2`]($A434Q!<F5A+F=E=%!R979.;V1E*&DI*0H)"0EL
M969T(#T@:3L*"0ER:6=H="`](%-#.PH)"69O<B`H:2`](%-#.R!I("8F(&D@
M(3T@8F]D>2`F)B`A2%1-3$%R96$N:7-";&]C:T5L96UE;G0H:2D[(&D@/2!(
M5$U,07)E82YG971.97AT3F]D92AI*2D*"0D)<FEG:'0@/2!I.PH)"6EF("AL
M969T("$](&)O9'D@)B8@<FEG:'0@(3T@8F]D>2D@>PH)"0ER,B`]('(N8VQO
M;F5286YG92@I.PH)"0ER,BYS9713=&%R=$)E9F]R92AL969T*3L*"0D)<C(N
M<W5R<F]U;F1#;VYT96YT<RAB;&]C:R`](&1O8RYC<F5A=&5%;&5M96YT*")P
M(BDI.PH)"0EI9B`H(2]<4R\N=&5S="A(5$U,07)E82YG971);FYE<E1E>'0H
M8FQO8VLI*2D*"0D)"6)L;V-K+FEN;F5R2%1-3"`]("(\8G(@+SXB.PH)"0EB
M;&]C:RYN;W)M86QI>F4H*3L*"0D)<BYS971%;F1!9G1E<BAR:6=H="D["@D)
M"7(N<W5R<F]U;F1#;VYT96YT<RAB;&]C:R`](&1O8RYC<F5A=&5%;&5M96YT
M*")P(BDI.PH)"0EI9B`H(2]<4R\N=&5S="A(5$U,07)E82YG971);FYE<E1E
M>'0H8FQO8VLI*2D*"0D)"6)L;V-K+FEN;F5R2%1-3"`]("(\8G(@+SXB.PH)
M"0EB;&]C:RYN;W)M86QI>F4H*3L*"0E](&5L<V4@>PH)"0ER(#T@9&]C+F-R
M96%T95)A;F=E*"D["@D)"7(N<V5T4W1A<G0H8F]D>2P@,"D["@D)"7(N<V5T
M16YD*&)O9'DL(#`I.PH)"0ER+FEN<V5R=$YO9&4H8FQO8VL@/2!D;V,N8W)E
M871E16QE;65N="@B<"(I*3L*"0D)8FQO8VLN:6YN97)(5$U,(#T@(CQB<B`O
M/B(["@D)?0H)"7(N<V5L96-T3F]D94-O;G1E;G1S*&)L;V-K*3L*"7T@96QS
M92!["@D)<BYS971%;F1!9G1E<BAB;&]C:RD["@D)=F%R(&1F(#T@<BYE>'1R
M86-T0V]N=&5N=',H*2P@;&5F=%]E;7!T>2`](&9A;'-E.PH)"6EF("@A+UQ3
M+RYT97-T*&)L;V-K+FEN;F5R2%1-3"DI('L*"0D)8FQO8VLN:6YN97)(5$U,
M(#T@(CQB<B`O/B(["@D)"6QE9G1?96UP='D@/2!T<G5E.PH)"7T*"0EP(#T@
M9&8N9FER<W1#:&EL9#L*"0EI9B`H<"D@>PH)"0EI9B`H(2]<4R\N=&5S="A(
M5$U,07)E82YG971);FYE<E1E>'0H<"DI*2!["B`)"0D):68@*"]>:%LQ+39=
M)"]I+G1E<W0H<"YT86=.86UE*2D*(`D)"0D)<"`]('1H:7,N8V]N=F5R=$YO
M9&4H<"P@(G`B*3L*"0D)"7`N:6YN97)(5$U,(#T@(CQB<B`O/B(["@D)"7T*
M"0D):68@*"]>;&DD+VDN=&5S="AP+G1A9TYA;64I("8F(&QE9G1?96UP='D@
M)B8@(6)L;V-K+FYE>'13:6)L:6YG*2!["@D)"0EL969T(#T@8FQO8VLN<&%R
M96YT3F]D93L*"0D)"6QE9G0N<F5M;W9E0VAI;&0H8FQO8VLI.PH)"0D)<BYS
M971%;F1!9G1E<BAL969T*3L*"0D)"7(N8V]L;&%P<V4H9F%L<V4I.PH)"0D)
M<"`]('1H:7,N8V]N=F5R=$YO9&4H<"P@+UY;=6]=;"0O:2YT97-T*&QE9G0N
M<&%R96YT3F]D92YT86=.86UE*2`_(")L:2(@.B`B<"(I.PH)"0E]"@D)"7(N
M:6YS97)T3F]D92AD9BD["@D)"7(N<V5L96-T3F]D94-O;G1E;G1S*'`I.PH)
M"7T*"7T*"7(N8V]L;&%P<V4H=')U92D["@ES96PN861D4F%N9V4H<BD["@ET
M:&ES+F9O<F-E4F5D<F%W*"D["@ET:&ES+G-C<F]L;%1O0V%R970H*3L*?3L*
M"B\O(')E=')I979E('1H92!(5$U,"DA434Q!<F5A+G!R;W1O='EP92YG971(
M5$U,(#T@9G5N8W1I;VXH*2!["@ES=VET8V@@*'1H:7,N7V5D:71-;V1E*2![
M"@D@("`@8V%S92`B=WES:7=Y9R(@(#H*"0EI9B`H(71H:7,N8V]N9FEG+F9U
M;&Q086=E*2!["@D)"7)E='5R;B!(5$U,07)E82YG971(5$U,*'1H:7,N7V1O
M8RYB;V1Y+"!F86QS92P@=&AI<RD["@D)?2!E;'-E"@D)"7)E='5R;B!T:&ES
M+F1O8W1Y<&4@*R`B7&XB("L@2%1-3$%R96$N9V5T2%1-3"AT:&ES+E]D;V,N
M9&]C=6UE;G1%;&5M96YT+"!T<G5E+"!T:&ES*3L*"2`@("!C87-E(")T97AT
M;6]D92(@.B!R971U<FX@=&AI<RY?=&5X=$%R96$N=F%L=64["@D@("`@9&5F
M875L=`D@("`@.B!A;&5R="@B36]D92`\(B`K(&UO9&4@*R`B/B!N;W0@9&5F
M:6YE9"$B*3L*"7T*"7)E='5R;B!F86QS93L*?3L*"B\O(')E=')I979E('1H
M92!(5$U,("AF87-T97-T('9E<G-I;VXL(&)U="!U<V5S(&EN;F5R2%1-3"D*
M2%1-3$%R96$N<')O=&]T>7!E+F=E=$EN;F5R2%1-3"`](&9U;F-T:6]N*"D@
M>PH)<W=I=&-H("AT:&ES+E]E9&ET36]D92D@>PH)("`@(&-A<V4@(G=Y<VEW
M>6<B("`Z"@D):68@*"%T:&ES+F-O;F9I9RYF=6QL4&%G92D*"0D)<F5T=7)N
M('1H:7,N7V1O8RYB;V1Y+FEN;F5R2%1-3#L*"0EE;'-E"@D)"7)E='5R;B!T
M:&ES+F1O8W1Y<&4@*R`B7&XB("L@=&AI<RY?9&]C+F1O8W5M96YT16QE;65N
M="YI;FYE<DA434P["@D@("`@8V%S92`B=&5X=&UO9&4B(#H@<F5T=7)N('1H
M:7,N7W1E>'1!<F5A+G9A;'5E.PH)("`@(&1E9F%U;'0)("`@(#H@86QE<G0H
M(DUO9&4@/"(@*R!M;V1E("L@(CX@;F]T(&1E9FEN960A(BD["@E]"@ER971U
M<FX@9F%L<V4["GT["@HO+R!C;VUP;&5T96QY(&-H86YG92!T:&4@2%1-3"!I
M;G-I9&4*2%1-3$%R96$N<')O=&]T>7!E+G-E=$A434P@/2!F=6YC=&EO;BAH
M=&UL*2!["@ES=VET8V@@*'1H:7,N7V5D:71-;V1E*2!["@D@("`@8V%S92`B
M=WES:7=Y9R(@(#H*"0EI9B`H(71H:7,N8V]N9FEG+F9U;&Q086=E*0H)"0ET
M:&ES+E]D;V,N8F]D>2YI;FYE<DA434P@/2!H=&UL.PH)"65L<V4*"0D)+R\@
M=&AI<RY?9&]C+F1O8W5M96YT16QE;65N="YI;FYE<DA434P@/2!H=&UL.PH)
M"0ET:&ES+E]D;V,N8F]D>2YI;FYE<DA434P@/2!H=&UL.PH)"6)R96%K.PH)
M("`@(&-A<V4@(G1E>'1M;V1E(B`Z('1H:7,N7W1E>'1!<F5A+G9A;'5E(#T@
M:'1M;#L@8G)E86L["@D@("`@9&5F875L=`D@("`@.B!A;&5R="@B36]D92`\
M(B`K(&UO9&4@*R`B/B!N;W0@9&5F:6YE9"$B*3L*"7T*"7)E='5R;B!F86QS
M93L*?3L*"B\O('-E=',@=&AE(&=I=F5N(&1O8W1Y<&4@*'5S969U;"!W:&5N
M(&-O;F9I9RYF=6QL4&%G92!I<R!T<G5E*0I(5$U,07)E82YP<F]T;W1Y<&4N
M<V5T1&]C='EP92`](&9U;F-T:6]N*&1O8W1Y<&4I('L*"71H:7,N9&]C='EP
M92`](&1O8W1Y<&4["GT["@HO*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ"B`J("!#871E9V]R>3H@551)3$E4
M62!&54Y#5$E/3E,*("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B\*"B\O('9A<FEA8FQE('5S960@=&\@<&%S
M<R!T:&4@;V)J96-T('1O('1H92!P;W!U<"!E9&ET;W(@=VEN9&]W+@I(5$U,
M07)E82Y?;V)J96-T(#T@;G5L;#L*"B\O(&9U;F-T:6]N('1H870@<F5T=7)N
M<R!A(&-L;VYE(&]F('1H92!G:79E;B!O8FIE8W0*2%1-3$%R96$N8VQO;F5/
M8FIE8W0@/2!F=6YC=&EO;BAO8FHI('L*"6EF("@A;V)J*2!R971U<FX@;G5L
M;#L*"79A<B!N97=/8FH@/2!N97<@3V)J96-T.PH*"2\O(&-H96-K(&9O<B!A
M<G)A>2!O8FIE8W1S"@EI9B`H;V)J+F-O;G-T<G5C=&]R+G1O4W1R:6YG*"DN
M:6YD97A/9B@B9G5N8W1I;VX@07)R87DH(BD@/3T@,2D@>PH)"6YE=T]B:B`]
M(&]B:BYC;VYS=')U8W1O<B@I.PH)?0H*"2\O(&-H96-K(&9O<B!F=6YC=&EO
M;B!O8FIE8W1S("AA<R!U<W5A;"P@244@:7,@9G5C:V5D('5P*0H):68@*&]B
M:BYC;VYS=')U8W1O<BYT;U-T<FEN9R@I+FEN9&5X3V8H(F9U;F-T:6]N($9U
M;F-T:6]N*"(I(#T](#$I('L*"0EN97=/8FH@/2!O8FH[("\O(&IU<W0@8V]P
M>2!R969E<F5N8V4@=&\@:70*"7T@96QS92!F;W(@*'9A<B!N(&EN(&]B:BD@
M>PH)"79A<B!N;V1E(#T@;V)J6VY=.PH)"6EF("AT>7!E;V8@;F]D92`]/2`G
M;V)J96-T)RD@>R!N97=/8FI;;ET@/2!(5$U,07)E82YC;&]N94]B:F5C="AN
M;V1E*3L@?0H)"65L<V4@("`@("`@("`@("`@("`@("`@("`@("`@>R!N97=/
M8FI;;ET@/2!N;V1E.R!]"@E]"@H)<F5T=7)N(&YE=T]B:CL*?3L*"B\O($9)
M6$U%(2$A('1H:7,@<VAO=6QD(')E='5R;B!F86QS92!F;W(@244@/"`U+C4*
M2%1-3$%R96$N8VAE8VM3=7!P;W)T961"<F]W<V5R(#T@9G5N8W1I;VXH*2![
M"@EI9B`H2%1-3$%R96$N:7-?9V5C:V\I('L*"0EI9B`H;F%V:6=A=&]R+G!R
M;V1U8W13=6(@/"`R,#`R,3(P,2D@>PH)"0EA;&5R="@B66]U(&YE960@870@
M;&5A<W0@36]Z:6QL82TQ+C,@06QP:&$N7&XB("L*"0D)("`@("`@(E-O<G)Y
M+"!Y;W5R($=E8VMO(&ES(&YO="!S=7!P;W)T960N(BD["@D)"7)E='5R;B!F
M86QS93L*"0E]"@D):68@*&YA=FEG871O<BYP<F]D=6-T4W5B(#P@,C`P,S`R
M,3`I('L*"0D)86QE<G0H(DUO>FEL;&$@/"`Q+C,@0F5T82!I<R!N;W0@<W5P
M<&]R=&5D(5QN(B`K"@D)"2`@("`@(")))VQL('1R>2P@=&AO=6=H+"!B=70@
M:70@;6EG:'0@;F]T('=O<FLN(BD["@D)?0H)?0H)<F5T=7)N($A434Q!<F5A
M+FES7V=E8VMO('Q\($A434Q!<F5A+FES7VEE.PI].PH*+R\@<V5L96-T:6]N
M("8@<F%N9V5S"@HO+R!R971U<FYS('1H92!C=7)R96YT('-E;&5C=&EO;B!O
M8FIE8W0*2%1-3$%R96$N<')O=&]T>7!E+E]G971396QE8W1I;VX@/2!F=6YC
M=&EO;B@I('L*"6EF("A(5$U,07)E82YI<U]I92D@>PH)"7)E='5R;B!T:&ES
M+E]D;V,N<V5L96-T:6]N.PH)?2!E;'-E('L*"0ER971U<FX@=&AI<RY?:69R
M86UE+F-O;G1E;G17:6YD;W<N9V5T4V5L96-T:6]N*"D["@E]"GT["@HO+R!R
M971U<FYS(&$@<F%N9V4@9F]R('1H92!C=7)R96YT('-E;&5C=&EO;@I(5$U,
M07)E82YP<F]T;W1Y<&4N7V-R96%T95)A;F=E(#T@9G5N8W1I;VXH<V5L*2![
M"@EI9B`H2%1-3$%R96$N:7-?:64I('L*"0ER971U<FX@<V5L+F-R96%T95)A
M;F=E*"D["@E](&5L<V4@>PH)"71H:7,N9F]C=7-%9&ET;W(H*3L*"0EI9B`H
M='EP96]F('-E;"`A/2`B=6YD969I;F5D(BD@>PH)"0ET<GD@>PH)"0D)<F5T
M=7)N('-E;"YG971286YG94%T*#`I.PH)"0E](&-A=&-H*&4I('L*"0D)"7)E
M='5R;B!T:&ES+E]D;V,N8W)E871E4F%N9V4H*3L*"0D)?0H)"7T@96QS92![
M"@D)"7)E='5R;B!T:&ES+E]D;V,N8W)E871E4F%N9V4H*3L*"0E]"@E]"GT[
M"@HO+R!E=F5N="!H86YD;&EN9PH*2%1-3$%R96$N7V%D9$5V96YT(#T@9G5N
M8W1I;VXH96PL(&5V;F%M92P@9G5N8RD@>PH):68@*$A434Q!<F5A+FES7VEE
M*2!["@D)96PN871T86-H179E;G0H(F]N(B`K(&5V;F%M92P@9G5N8RD["@E]
M(&5L<V4@>PH)"65L+F%D9$5V96YT3&ES=&5N97(H979N86UE+"!F=6YC+"!T
M<G5E*3L*"7T*?3L*"DA434Q!<F5A+E]A9&1%=F5N=',@/2!F=6YC=&EO;BAE
M;"P@979S+"!F=6YC*2!["@EF;W(@*'9A<B!I(#T@979S+FQE;F=T:#L@+2UI
M(#X](#`[*2!["@D)2%1-3$%R96$N7V%D9$5V96YT*&5L+"!E=G-;:5TL(&9U
M;F,I.PH)?0I].PH*2%1-3$%R96$N7W)E;6]V945V96YT(#T@9G5N8W1I;VXH
M96PL(&5V;F%M92P@9G5N8RD@>PH):68@*$A434Q!<F5A+FES7VEE*2!["@D)
M96PN9&5T86-H179E;G0H(F]N(B`K(&5V;F%M92P@9G5N8RD["@E](&5L<V4@
M>PH)"65L+G)E;6]V945V96YT3&ES=&5N97(H979N86UE+"!F=6YC+"!T<G5E
M*3L*"7T*?3L*"DA434Q!<F5A+E]R96UO=F5%=F5N=',@/2!F=6YC=&EO;BAE
M;"P@979S+"!F=6YC*2!["@EF;W(@*'9A<B!I(#T@979S+FQE;F=T:#L@+2UI
M(#X](#`[*2!["@D)2%1-3$%R96$N7W)E;6]V945V96YT*&5L+"!E=G-;:5TL
M(&9U;F,I.PH)?0I].PH*2%1-3$%R96$N7W-T;W!%=F5N="`](&9U;F-T:6]N
M*&5V*2!["@EI9B`H2%1-3$%R96$N:7-?:64I('L*"0EE=BYC86YC96Q"=6)B
M;&4@/2!T<G5E.PH)"65V+G)E='5R;E9A;'5E(#T@9F%L<V4["@E](&5L<V4@
M>PH)"65V+G!R979E;G1$969A=6QT*"D["@D)978N<W1O<%!R;W!A9V%T:6]N
M*"D["@E]"GT["@I(5$U,07)E82Y?<F5M;W9E0VQA<W,@/2!F=6YC=&EO;BAE
M;"P@8VQA<W-.86UE*2!["@EI9B`H(2AE;"`F)B!E;"YC;&%S<TYA;64I*2![
M"@D)<F5T=7)N.PH)?0H)=F%R(&-L<R`](&5L+F-L87-S3F%M92YS<&QI="@B
M("(I.PH)=F%R(&%R(#T@;F5W($%R<F%Y*"D["@EF;W(@*'9A<B!I(#T@8VQS
M+FQE;F=T:#L@:2`^(#`[*2!["@D):68@*&-L<ULM+6E=("$](&-L87-S3F%M
M92D@>PH)"0EA<EMA<BYL96YG=&A=(#T@8VQS6VE=.PH)"7T*"7T*"65L+F-L
M87-S3F%M92`](&%R+FIO:6XH(B`B*3L*?3L*"DA434Q!<F5A+E]A9&1#;&%S
M<R`](&9U;F-T:6]N*&5L+"!C;&%S<TYA;64I('L*"2\O(')E;6]V92!T:&4@
M8VQA<W,@9FER<W0L(&EF(&%L<F5A9'D@=&AE<F4*"4A434Q!<F5A+E]R96UO
M=F5#;&%S<RAE;"P@8VQA<W-.86UE*3L*"65L+F-L87-S3F%M92`K/2`B("(@
M*R!C;&%S<TYA;64["GT["@I(5$U,07)E82Y?:&%S0VQA<W,@/2!F=6YC=&EO
M;BAE;"P@8VQA<W-.86UE*2!["@EI9B`H(2AE;"`F)B!E;"YC;&%S<TYA;64I
M*2!["@D)<F5T=7)N(&9A;'-E.PH)?0H)=F%R(&-L<R`](&5L+F-L87-S3F%M
M92YS<&QI="@B("(I.PH)9F]R("AV87(@:2`](&-L<RYL96YG=&@[(&D@/B`P
M.RD@>PH)"6EF("AC;'-;+2UI72`]/2!C;&%S<TYA;64I('L*"0D)<F5T=7)N
M('1R=64["@D)?0H)?0H)<F5T=7)N(&9A;'-E.PI].PH*2%1-3$%R96$N7V)L
M;V-K5&%G<R`]("(@8F]D>2!F;W)M('1E>'1A<F5A(&9I96QD<V5T('5L(&]L
M(&1L(&QI(&1I=B`B("L*(G`@:#$@:#(@:#,@:#0@:#4@:#8@<75O=&4@<')E
M('1A8FQE('1H96%D("(@*PHB=&)O9'D@=&9O;W0@='(@=&0@:69R86UE(&%D
M9')E<W,@(CL*2%1-3$%R96$N:7-";&]C:T5L96UE;G0@/2!F=6YC=&EO;BAE
M;"D@>PH)<F5T=7)N(&5L("8F(&5L+FYO9&54>7!E(#T](#$@)B8@*$A434Q!
M<F5A+E]B;&]C:U1A9W,N:6YD97A/9B@B("(@*R!E;"YT86=.86UE+G1O3&]W
M97)#87-E*"D@*R`B("(I("$]("TQ*3L*?3L*"DA434Q!<F5A+E]C;&]S:6YG
M5&%G<R`]("(@:&5A9"!S8W)I<'0@<W1Y;&4@9&EV('-P86X@='(@=&0@=&)O
M9'D@=&%B;&4@96T@<W1R;VYG(&(@:2!C;V1E(&-I=&4@9&9N(&%B8G(@86-R
M;VYY;2!F;VYT(&$@=&ET;&4@(CL*2%1-3$%R96$N;F5E9'-#;&]S:6YG5&%G
M(#T@9G5N8W1I;VXH96PI('L*"7)E='5R;B!E;"`F)B!E;"YN;V1E5'EP92`]
M/2`Q("8F("A(5$U,07)E82Y?8VQO<VEN9U1A9W,N:6YD97A/9B@B("(@*R!E
M;"YT86=.86UE+G1O3&]W97)#87-E*"D@*R`B("(I("$]("TQ*3L*?3L*"B\O
M('!E<F9O<FUS($A434P@96YC;V1I;F<@;V8@<V]M92!G:79E;B!S=')I;F<*
M2%1-3$%R96$N:'1M;$5N8V]D92`](&9U;F-T:6]N*'-T<BD@>PH)+R\@=V4@
M9&]N)W0@;F5E9"!R96=E>'`@9F]R('1H870L(&)U="XN('-O(&)E(&ET(&9O
M<B!N;W<N"@ES='(@/2!S='(N<F5P;&%C92@O)B]I9RP@(B9A;7`[(BD["@ES
M='(@/2!S='(N<F5P;&%C92@O/"]I9RP@(B9L=#LB*3L*"7-T<B`]('-T<BYR
M97!L86-E*"\^+VEG+"`B)F=T.R(I.PH)<W1R(#T@<W1R+G)E<&QA8V4H+UQX
M,C(O:6<L("(F<75O=#LB*3L*"2\O(%QX,C(@;65A;G,@)R(G("TM('=E('5S
M92!H97@@<F5P<F5Z96YT871I;VX@<V\@=&AA="!W92!D;VXG="!D:7-T=7)B
M"@DO+R!*4R!C;VUP<F5S<V]R<R`H=V5L;"P@870@;&5A<W0@;6EN92!F86EL
M<RXN(#LI"@ER971U<FX@<W1R.PI].PH*+R\@4F5T<FEE=F5S('1H92!(5$U,
M(&-O9&4@9G)O;2!T:&4@9VEV96X@;F]D92X)(%1H:7,@:7,@82!R97!L86-E
M;65N="!F;W(*+R\@9V5T=&EN9R!I;FYE<DA434PL('5S:6YG('-T86YD87)D
M($1/32!C86QL<RX*+R\@5W)A<'!E<B!C871C:"!A($UO>FEL;&$M17AC97!T
M:6]N('=I=&@@;F]N('=E;&P@9F]R;65D(&AT;6P@<V]U<F-E(&-O9&4*2%1-
M3$%R96$N9V5T2%1-3"`](&9U;F-T:6]N*')O;W0L(&]U='!U=%)O;W0L(&5D
M:71O<BE["B`@("!T<GE["B`@("`@("`@<F5T=7)N($A434Q!<F5A+F=E=$A4
M34Q7<F%P<&5R*')O;W0L;W5T<'5T4F]O="QE9&ET;W(I.PH@("`@?0H@("`@
M8V%T8V@H92E["B`@("`@("`@86QE<G0H)UEO=7(@1&]C=6UE;G0@:7,@;F]T
M('=E;&P@9F]R;65D+B!#:&5C:R!*879A4V-R:7!T(&-O;G-O;&4@9F]R(&1E
M=&%I;',N)RD["B`@("`@("`@<F5T=7)N(&5D:71O<BY?:69R86UE+F-O;G1E
M;G17:6YD;W<N9&]C=6UE;G0N8F]D>2YI;FYE<DA434P["B`@("!]"GT*"DA4
M34Q!<F5A+F=E=$A434Q7<F%P<&5R(#T@9G5N8W1I;VXH<F]O="P@;W5T<'5T
M4F]O="P@961I=&]R*2!["@EV87(@:'1M;"`]("(B.PH)<W=I=&-H("AR;V]T
M+FYO9&54>7!E*2!["@D@("`@8V%S92`Q.B`O+R!.;V1E+D5,14U%3E1?3D]$
M10H)("`@(&-A<V4@,3$Z("\O($YO9&4N1$]#54U%3E1?1E)!1TU%3E1?3D]$
M10H)"79A<B!C;&]S960["@D)=F%R(&D["@D)=F%R(')O;W1?=&%G(#T@*')O
M;W0N;F]D951Y<&4@/3T@,2D@/R!R;V]T+G1A9TYA;64N=&],;W=E<D-A<V4H
M*2`Z("<G.PH)"6EF("AR;V]T7W1A9R`]/2`G8G(G("8F("%R;V]T+FYE>'13
M:6)L:6YG*0H)"0EB<F5A:SL*"0EI9B`H;W5T<'5T4F]O="D*"0D);W5T<'5T
M4F]O="`]("$H961I=&]R+F-O;F9I9RYH=&UL4F5M;W9E5&%G<R`F)B!E9&ET
M;W(N8V]N9FEG+FAT;6Q296UO=F5486=S+G1E<W0H<F]O=%]T86<I*3L*"0EI
M9B`H2%1-3$%R96$N:7-?:64@)B8@<F]O=%]T86<@/3T@(FAE860B*2!["@D)
M"6EF("AO=71P=712;V]T*0H)"0D):'1M;"`K/2`B/&AE860^(CL*"0D)+R\@
M;&]W97)C87-I>F4*"0D)=F%R('-A=F5?;75L=&EL:6YE(#T@4F5G17AP+FUU
M;'1I;&EN93L*"0D)4F5G17AP+FUU;'1I;&EN92`]('1R=64["@D)"79A<B!T
M>'0@/2!R;V]T+FEN;F5R2%1-3"YR97!L86-E*$A434Q!<F5A+E)%7W1A9TYA
M;64L(&9U;F-T:6]N*'-T<BP@<#$L('`R*2!["@D)"0ER971U<FX@<#$@*R!P
M,BYT;TQO=V5R0V%S92@I.PH)"0E]*3L*"0D)4F5G17AP+FUU;'1I;&EN92`]
M('-A=F5?;75L=&EL:6YE.PH)"0EH=&UL("L]('1X=#L*"0D):68@*&]U='!U
M=%)O;W0I"@D)"0EH=&UL("L]("(\+VAE860^(CL*"0D)8G)E86L["@D)?2!E
M;'-E(&EF("AO=71P=712;V]T*2!["@D)"6-L;W-E9"`]("@A*')O;W0N:&%S
M0VAI;&1.;V1E<R@I('Q\($A434Q!<F5A+FYE961S0VQO<VEN9U1A9RAR;V]T
M*2DI.PH)"0EH=&UL(#T@(CPB("L@<F]O="YT86=.86UE+G1O3&]W97)#87-E
M*"D["@D)"79A<B!A='1R<R`](')O;W0N871T<FEB=71E<SL*"0D)9F]R("AI
M(#T@,#L@:2`\(&%T=')S+FQE;F=T:#L@*RMI*2!["@D)"0EV87(@82`](&%T
M=')S+FET96TH:2D["@D)"0EI9B`H(6$N<W!E8VEF:65D*2!["@D)"0D)8V]N
M=&EN=64["@D)"0E]"@D)"0EV87(@;F%M92`](&$N;F]D94YA;64N=&],;W=E
M<D-A<V4H*3L*"0D)"6EF("@O7VUO>E]E9&ET;W)?8F]G=7-?;F]D92\N=&5S
M="AN86UE*2D@>PH)"0D)"6AT;6P@/2`B(CL*"0D)"0EB<F5A:SL*"0D)"7T*
M"0D)"6EF("@O7VUO>GQC;VYT96YT961I=&%B;&5\7VUS:"\N=&5S="AN86UE
M*2D@>PH)"0D)"2\O(&%V;VED(&-E<G1A:6X@871T<FEB=71E<PH)"0D)"6-O
M;G1I;G5E.PH)"0D)?0H)"0D)=F%R('9A;'5E.PH)"0D):68@*&YA;64@(3T@
M(G-T>6QE(BD@>PH)"0D)"2\O($E%-2XU(')E<&]R=',@,C4@=VAE;B!C96QL
M4W!A8VEN9R!I<PH)"0D)"2\O(#$[(&]T:&5R('9A;'5E<R!M:6=H="!B92!D
M;V]M960@=&]O+@H)"0D)"2\O($9O<B!T:&ES(')E87-O;B!W92!E>'1R86-T
M('1H90H)"0D)"2\O('9A;'5E<R!D:7)E8W1L>2!F<F]M('1H92!R;V]T(&YO
M9&4N"@D)"0D)+R\@22=M('-T87)T:6YG('1O($A!5$4@2F%V85-C<FEP=`H)
M"0D)"2\O(&1E=F5L;W!M96YT+B`@0G)O=W-E<B!D:69F97)E;F-E<PH)"0D)
M"2\O('-U8VLN"@D)"0D)+R\*"0D)"0DO+R!5<VEN9R!'96-K;R!T:&4@=F%L
M=65S(&]F(&AR968@86YD('-R8R!A<F4@8V]N=F5R=&5D('1O(&%B<V]L=71E
M(&QI;FMS"@D)"0D)+R\@=6YL97-S('=E(&=E="!T:&5M('5S:6YG(&YO9&56
M86QU92@I"@D)"0D):68@*'1Y<&5O9B!R;V]T6V$N;F]D94YA;65=("$](")U
M;F1E9FEN960B("8F(&YA;64@(3T@(FAR968B("8F(&YA;64@(3T@(G-R8R(@
M)B8@(2]>;VXO+G1E<W0H;F%M92DI('L*"0D)"0D)=F%L=64@/2!R;V]T6V$N
M;F]D94YA;65=.PH)"0D)"7T@96QS92!["@D)"0D)"79A;'5E(#T@82YN;V1E
M5F%L=64["@D)"0D)"2\O($E%('-E96US(&YO="!W:6QL:6YG('1O(')E='5R
M;B!T:&4@;W)I9VEN86P@=F%L=65S("T@:70@8V]N=F5R=',@=&\@86)S;VQU
M=&4*"0D)"0D)+R\@;&EN:W,@=7-I;F<@82YN;V1E5F%L=64L(&$N=F%L=64L
M(&$N<W1R:6YG5F%L=64L(')O;W0N9V5T071T<FEB=71E*")H<F5F(BD*"0D)
M"0D)+R\@4V\@=V4@:&%V92!T;R!S=')I<"!T:&4@8F%S975R;"!M86YU86QL
M>2`Z+2\*"0D)"0D):68@*$A434Q!<F5A+FES7VEE("8F("AN86UE(#T](")H
M<F5F(B!\?"!N86UE(#T](")S<F,B*2D@>PH)"0D)"0D)=F%L=64@/2!E9&ET
M;W(N<W1R:7!"87-E55),*'9A;'5E*3L*"0D)"0D)?0H)"0D)"7T*"0D)"7T@
M96QS92![("\O($E%(&9A:6QS('1O('!U="!S='EL92!I;B!A='1R:6)U=&5S
M(&QI<W0*"0D)"0DO+R!&25A-13H@8W-S5&5X="!R97!O<G1E9"!B>2!)12!I
M<R!54%!%4D-!4T4*"0D)"0EV86QU92`](')O;W0N<W1Y;&4N8W-S5&5X=#L*
M"0D)"7T*"0D)"6EF("@O*%]M;WI\7B0I+RYT97-T*'9A;'5E*2D@>PH)"0D)
M"2\O($UO>FEL;&$@<F5P;W)T<R!S;VUE('-P96-I86P@=&%G<PH)"0D)"2\O
M(&AE<F4[('=E(&1O;B=T(&YE960@=&AE;2X*"0D)"0EC;VYT:6YU93L*"0D)
M"7T*"0D)"6AT;6P@*ST@(B`B("L@;F%M92`K("<](B<@*R!V86QU92`K("<B
M)SL*"0D)?0H)"0EI9B`H:'1M;"`A/2`B(BD@>PH)"0D):'1M;"`K/2!C;&]S
M960@/R`B("\^(B`Z("(^(CL*"0D)?0H)"7T*"0EF;W(@*&D@/2!R;V]T+F9I
M<G-T0VAI;&0[(&D[(&D@/2!I+FYE>'13:6)L:6YG*2!["@D)"6AT;6P@*ST@
M2%1-3$%R96$N9V5T2%1-3%=R87!P97(H:2P@=')U92P@961I=&]R*3L*"0E]
M"@D):68@*&]U='!U=%)O;W0@)B8@(6-L;W-E9"D@>PH)"0EH=&UL("L]("(\
M+R(@*R!R;V]T+G1A9TYA;64N=&],;W=E<D-A<V4H*2`K("(^(CL*"0E]"@D)
M8G)E86L["@D@("`@8V%S92`S.B`O+R!.;V1E+E1%6%1?3D]$10H)"2\O($EF
M(&$@=&5X="!N;V1E(&ES(&%L;VYE(&EN(&%N(&5L96UE;G0@86YD(&%L;"!S
M<&%C97,L(')E<&QA8V4@:70@=VET:"!A;B!N;VX@8G)E86MI;F<@;VYE"@D)
M+R\@5&AI<R!P87)T:6%L;'D@=6YD;V5S('1H92!D86UA9V4@9&]N92!B>2!M
M;WHL('=H:6-H('1R86YS;&%T97,@)R9N8G-P.R=S(&EN=&\@<W!A8V5S(&EN
M('1H92!D871A(&5L96UE;G0*"0DO*B!I9B`H("%R;V]T+G!R979I;W5S4VEB
M;&EN9R`F)B`A<F]O="YN97AT4VEB;&EN9R`F)B!R;V]T+F1A=&$N;6%T8V@H
M+UY<<RHD+VDI("D@:'1M;"`]("<F;F)S<#LG.PH)"2`@(&5L<V4@*B\*"0EH
M=&UL(#T@+UYS8W)I<'1\<W1Y;&4D+VDN=&5S="AR;V]T+G!A<F5N=$YO9&4N
M=&%G3F%M92D@/R!R;V]T+F1A=&$@.B!(5$U,07)E82YH=&UL16YC;V1E*')O
M;W0N9&%T82D["@D)8G)E86L["@D@("`@8V%S92`T.B`O+R!.;V1E+D-$051!
M7U-%0U1)3TY?3D]$10H)"2\O($9)6$U%.B!I="!S965M<R!W92!N979E<B!G
M970@:&5R92P@8G5T($D@8F5L:65V92!W92!S:&]U;&0N+@H)"2\O("`@("`@
M("!M87EB92!A(&)R;W=S97(@<')O8FQE;3\M+4-$051!('-E8W1I;VYS(&%R
M92!C;VYV97)T960@=&\@<&QA:6X@=&5X="!N;V1E<R!A;F0@;F]R;6%L:7IE
M9`H)"2\O($-$051!('-E8W1I;VYS('-H;W5L9"!G;R`B87,@:7,B('=I=&AO
M=70@9G5R=&AE<B!E;F-O9&EN9PH)"6AT;6P@/2`B/"%;0T1!5$%;(B`K(')O
M;W0N9&%T82`K(")=73XB.PH)"6)R96%K.PH)("`@(&-A<V4@.#H@+R\@3F]D
M92Y#3TU-14Y47TY/1$4*"0EH=&UL(#T@(CPA+2TB("L@<F]O="YD871A("L@
M(BTM/B(["@D)8G)E86L["0DO+R!S:VEP(&-O;6UE;G1S+"!F;W(@;F]W+@H)
M?0H)<F5T=7)N(&AT;6P["GT["@I(5$U,07)E82YG9710<F5V3F]D92`](&9U
M;F-T:6]N*&YO9&4I('L*"6EF("@A;F]D92D@("`@("`@("`@("`@("`@<F5T
M=7)N(&YU;&P["@EI9B`H;F]D92YP<F5V:6]U<U-I8FQI;F<I(')E='5R;B!N
M;V1E+G!R979I;W5S4VEB;&EN9SL*"6EF("AN;V1E+G!A<F5N=$YO9&4I("`@
M("`@<F5T=7)N(&YO9&4N<&%R96YT3F]D93L*"7)E='5R;B!N=6QL.PI].PH*
M2%1-3$%R96$N9V5T3F5X=$YO9&4@/2!F=6YC=&EO;BAN;V1E*2!["@EI9B`H
M(6YO9&4I("`@("`@("`@("`@<F5T=7)N(&YU;&P["@EI9B`H;F]D92YN97AT
M4VEB;&EN9RD@<F5T=7)N(&YO9&4N;F5X=%-I8FQI;F<["@EI9B`H;F]D92YP
M87)E;G1.;V1E*2`@<F5T=7)N(&YO9&4N<&%R96YT3F]D93L*"7)E='5R;B!N
M=6QL.PI].PH*2%1-3$%R96$N<')O=&]T>7!E+G-T<FEP0F%S95523"`](&9U
M;F-T:6]N*'-T<FEN9RD@>PH)=F%R(&)A<V5U<FP@/2!T:&ES+F-O;F9I9RYB
M87-E55),.PH*"2\O('-T<FEP('1O(&QA<W0@9&ER96-T;W)Y(&EN(&-A<V4@
M8F%S975R;"!P;VEN=',@=&\@82!F:6QE"@EB87-E=7)L(#T@8F%S975R;"YR
M97!L86-E*"];7EPO72LD+RP@)R<I.PH)=F%R(&)A<V5R92`](&YE=R!296=%
M>'`H8F%S975R;"D["@ES=')I;F<@/2!S=')I;F<N<F5P;&%C92AB87-E<F4L
M("(B*3L*"@DO+R!S=')I<"!H;W-T+7!A<G0@;V8@55),('=H:6-H(&ES(&%D
M9&5D(&)Y($U3244@=&\@;&EN:W,@<F5L871I=F4@=&\@<V5R=F5R(')O;W0*
M"6)A<V5U<FP@/2!B87-E=7)L+G)E<&QA8V4H+UXH:'1T<',_.EPO7"];7EPO
M72LI*"XJ*20O+"`G)#$G*3L*"6)A<V5R92`](&YE=R!296=%>'`H8F%S975R
M;"D["@ER971U<FX@<W1R:6YG+G)E<&QA8V4H8F%S97)E+"`B(BD["GT["@I3
M=')I;F<N<')O=&]T>7!E+G1R:6T@/2!F=6YC=&EO;B@I('L*"7)E='5R;B!T
M:&ES+G)E<&QA8V4H+UY<<RLO+"`G)RDN<F5P;&%C92@O7',K)"\L("<G*3L*
M?3L*"B\O(&-R96%T97,@82!R9V(M<W1Y;&4@8V]L;W(@9G)O;2!A(&YU;6)E
M<@I(5$U,07)E82Y?;6%K94-O;&]R(#T@9G5N8W1I;VXH=BD@>PH):68@*'1Y
M<&5O9B!V("$](")N=6UB97(B*2!["@D)+R\@86QR96%D>2!I;B!R9V(@*&AO
M<&5F=6QL>2D[($E%(&1O97-N)W0@9V5T(&AE<F4N"@D)<F5T=7)N('8["@E]
M"@DO+R!)12!S96YD<R!N=6UB97([(&-O;G9E<G0@=&\@<F=B+@H)=F%R('(@
M/2!V("8@,'A&1CL*"79A<B!G(#T@*'8@/CX@."D@)B`P>$9&.PH)=F%R(&(@
M/2`H=B`^/B`Q-BD@)B`P>$9&.PH)<F5T=7)N(")R9V(H(B`K('(@*R`B+"(@
M*R!G("L@(BPB("L@8B`K("(I(CL*?3L*"B\O(')E='5R;G,@:&5X861E8VEM
M86P@8V]L;W(@<F5P<F5S96YT871I;VX@9G)O;2!A(&YU;6)E<B!O<B!A(')G
M8BUS='EL92!C;VQO<BX*2%1-3$%R96$N7V-O;&]R5&]29V(@/2!F=6YC=&EO
M;BAV*2!["@EI9B`H(78I"@D)<F5T=7)N("<G.PH*"2\O(')E='5R;G,@=&AE
M(&AE>"!R97!R97-E;G1A=&EO;B!O9B!O;F4@8GET92`H,B!D:6=I=',I"@EF
M=6YC=&EO;B!H97@H9"D@>PH)"7)E='5R;B`H9"`\(#$V*2`_("@B,"(@*R!D
M+G1O4W1R:6YG*#$V*2D@.B!D+G1O4W1R:6YG*#$V*3L*"7T["@H):68@*'1Y
M<&5O9B!V(#T](")N=6UB97(B*2!["@D)+R\@=V4G<F4@=&%L:VEN9R!T;R!)
M12!H97)E"@D)=F%R('(@/2!V("8@,'A&1CL*"0EV87(@9R`]("AV(#X^(#@I
M("8@,'A&1CL*"0EV87(@8B`]("AV(#X^(#$V*2`F(#!X1D8["@D)<F5T=7)N
M("(C(B`K(&AE>"AR*2`K(&AE>"AG*2`K(&AE>"AB*3L*"7T*"@EI9B`H=BYS
M=6)S='(H,"P@,RD@/3T@(G)G8B(I('L*"0DO+R!I;B!R9V(H+BXN*2!F;W)M
M("TM($UO>FEL;&$*"0EV87(@<F4@/2`O<F=B7',J7"A<<RHH6S`M.5TK*5QS
M*BQ<<RHH6S`M.5TK*5QS*BQ<<RHH6S`M.5TK*5QS*EPI+SL*"0EI9B`H=BYM
M871C:"AR92DI('L*"0D)=F%R('(@/2!P87)S94EN="A296=%>'`N)#$I.PH)
M"0EV87(@9R`]('!A<G-E26YT*%)E9T5X<"XD,BD["@D)"79A<B!B(#T@<&%R
M<V5);G0H4F5G17AP+B0S*3L*"0D)<F5T=7)N("(C(B`K(&AE>"AR*2`K(&AE
M>"AG*2`K(&AE>"AB*3L*"0E]"@D)+R\@9&]E<VXG="!M871C:"!213\A("!M
M87EB92!U<V5S('!E<F-E;G1A9V5S(&]R(&9L;V%T(&YU;6)E<G,*"0DO+R`M
M+2!&25A-13H@;F]T('EE="!I;7!L96UE;G1E9"X*"0ER971U<FX@;G5L;#L*
M"7T*"@EI9B`H=BYS=6)S='(H,"P@,2D@/3T@(B,B*2!["@D)+R\@86QR96%D
M>2!H97@@<F=B("AH;W!E9G5L;'D@.D0@*0H)"7)E='5R;B!V.PH)?0H*"2\O
M(&EF(&5V97)Y=&AI;F<@96QS92!F86EL<R`[*0H)<F5T=7)N(&YU;&P["GT[
M"@HO+R!M;V1A;"!D:6%L;V=S(&9O<B!-;WII;&QA("AF;W(@244@=V4G<F4@
M=7-I;F<@=&AE('-H;W=-;V1A;$1I86QO9R@I(&-A;&PI+@H*+R\@<F5C96EV
M97,@86X@55),('1O('1H92!P;W!U<"!D:6%L;V<@86YD(&$@9G5N8W1I;VX@
M=&AA="!R96-E:79E<R!O;F4@=F%L=64["B\O('1H:7,@9G5N8W1I;VX@=VEL
M;"!G970@8V%L;&5D(&%F=&5R('1H92!D:6%L;V<@:7,@8VQO<V5D+"!W:71H
M('1H92!R971U<FX*+R\@=F%L=64@;V8@=&AE(&1I86QO9RX*2%1-3$%R96$N
M<')O=&]T>7!E+E]P;W!U<$1I86QO9R`](&9U;F-T:6]N*'5R;"P@86-T:6]N
M+"!I;FET*2!["@E$:6%L;V<H=&AI<RYP;W!U<%523"AU<FPI+"!A8W1I;VXL
M(&EN:70I.PI].PH*+R\@<&%T:',*"DA434Q!<F5A+G!R;W1O='EP92YI;6=5
M4DP@/2!F=6YC=&EO;BAF:6QE+"!P;'5G:6XI('L*"6EF("AT>7!E;V8@<&QU
M9VEN(#T](")U;F1E9FEN960B*0H)"7)E='5R;B!?961I=&]R7W5R;"`K(&9I
M;&4["@EE;'-E"@D)<F5T=7)N(%]E9&ET;W)?=7)L("L@(G!L=6=I;G,O(B`K
M('!L=6=I;B`K("(O:6UG+R(@*R!F:6QE.PI].PH*2%1-3$%R96$N<')O=&]T
M>7!E+G!O<'5P55),(#T@9G5N8W1I;VXH9FEL92D@>PH)=F%R('5R;"`]("(B
M.PH):68@*&9I;&4N;6%T8V@H+UYP;'5G:6XZ7"]<+R@N*C\I7"\H+BHI+RDI
M('L*"0EV87(@<&QU9VEN(#T@4F5G17AP+B0Q.PH)"79A<B!P;W!U<"`](%)E
M9T5X<"XD,CL*"0EI9B`H(2]<+FAT;6PD+RYT97-T*'!O<'5P*2D*"0D)<&]P
M=7`@*ST@(BYH=&UL(CL*"0EU<FP@/2!?961I=&]R7W5R;"`K(")P;'5G:6YS
M+R(@*R!P;'5G:6X@*R`B+W!O<'5P<R\B("L@<&]P=7`["@E](&5L<V4*"0EU
M<FP@/2!?961I=&]R7W5R;"`K('1H:7,N8V]N9FEG+G!O<'5P55),("L@9FEL
M93L*"7)E='5R;B!U<FP["GT["@HO*BH*("H@1DE8.B!);G1E<FYE="!%>'!L
M;W)E<B!R971U<FYS(&%N(&ET96T@:&%V:6YG('1H92!?;F%M95\@97%U86P@
M=&\@=&AE(&=I=F5N"B`J(&ED+"!E=F5N(&EF(&ET)W,@;F]T(&AA=FEN9R!A
M;GD@:60N("!4:&ES('=A>2!I="!C86X@<F5T=7)N(&$@9&EF9F5R96YT(&9O
M<FT*("H@9FEE;&0@979E;B!I9B!I="=S(&YO="!A('1E>'1A<F5A+B`@5&AI
M<R!W;W)K87)O=6YD<R!T:&4@<')O8FQE;2!B>0H@*B!S<&5C:69I8V%L;'D@
M;&]O:VEN9R!T;R!S96%R8V@@;VYL>2!E;&5M96YT<R!H879I;F<@82!C97)T
M86EN('1A9R!N86UE+@H@*B\*2%1-3$%R96$N9V5T16QE;65N=$)Y260@/2!F
M=6YC=&EO;BAT86<L(&ED*2!["@EV87(@96PL(&DL(&]B:G,@/2!D;V-U;65N
M="YG971%;&5M96YT<T)Y5&%G3F%M92AT86<I.PH)9F]R("AI(#T@;V)J<RYL
M96YG=&@[("TM:2`^/2`P("8F("AE;"`](&]B:G-;:5TI.RD*"0EI9B`H96PN
M:60@/3T@:60I"@D)"7)E='5R;B!E;#L*"7)E='5R;B!N=6QL.PI].PH*"@HO
M+R!%3T8*+R\@3&]C86P@=F%R:6%B;&5S.B`O+PHO+R!C+6)A<VEC+6]F9G-E
M=#HX("\O"B\O(&EN9&5N="UT86)S+6UO9&4Z="`O+PHO+R!%;F0Z("\O"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O
M:'1M;&%R96$N8W-S````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3`P-S(@,3`U
M,34T,S,W-#0@,#(T-S4V`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"YH=&UL87)E82![(&)A8VMG<F]U;F0Z("-F9F8[('T*
M"BYH=&UL87)E82`N=&]O;&)A<B!["B`@8W5R<V]R.B!D969A=6QT.PH@(&)A
M8VMG<F]U;F0Z($)U='1O;D9A8V4["B`@<&%D9&EN9SH@,W!X.PH@(&)O<F1E
M<CH@,7!X('-O;&ED.PH@(&)O<F1E<BUC;VQO<CH@0G5T=&]N2&EG:&QI9VAT
M($)U='1O;E-H861O=R!"=71T;VY3:&%D;W<@0G5T=&]N2&EG:&QI9VAT.PI]
M"BYH=&UL87)E82`N=&]O;&)A<B!T86)L92![(&9O;G0M9F%M:6QY.B!T86AO
M;6$L=F5R9&%N82QS86YS+7-E<FEF.R!F;VYT+7-I>F4Z(#$Q<'@[('T*+FAT
M;6QA<F5A("YT;V]L8F%R(&EM9R![(&)O<F1E<CH@;F]N93L@?0HN:'1M;&%R
M96$@+G1O;VQB87(@+FQA8F5L('L@<&%D9&EN9SH@,'!X(#-P>#L@?0H*+FAT
M;6QA<F5A("YT;V]L8F%R("YB=71T;VX@>PH@(&)A8VMG<F]U;F0Z($)U='1O
M;D9A8V4["B`@8V]L;W(Z($)U='1O;E1E>'0["B`@8F]R9&5R.B`Q<'@@<V]L
M:60@0G5T=&]N1F%C93L*("!P861D:6YG.B`Q<'@["B`@;6%R9VEN.B`P<'@[
M"B`@=VED=&@Z(#$X<'@["B`@:&5I9VAT.B`Q.'!X.PI]"BYH=&UL87)E82`N
M=&]O;&)A<B`N8G5T=&]N2&]V97(@>PH@(&)O<F1E<CH@,7!X('-O;&ED.PH@
M(&)O<F1E<BUC;VQO<CH@0G5T=&]N2&EG:&QI9VAT($)U='1O;E-H861O=R!"
M=71T;VY3:&%D;W<@0G5T=&]N2&EG:&QI9VAT.PI]"BYH=&UL87)E82`N=&]O
M;&)A<B`N8G5T=&]N06-T:79E+"`N:'1M;&%R96$@+G1O;VQB87(@+F)U='1O
M;E!R97-S960@>PH@('!A9&1I;F<Z(#)P>"`P<'@@,'!X(#)P>#L*("!B;W)D
M97(Z(#%P>"!S;VQI9#L*("!B;W)D97(M8V]L;W(Z($)U='1O;E-H861O=R!"
M=71T;VY(:6=H;&EG:'0@0G5T=&]N2&EG:&QI9VAT($)U='1O;E-H861O=SL*
M?0HN:'1M;&%R96$@+G1O;VQB87(@+F)U='1O;E!R97-S960@>PH@(&)A8VMG
M<F]U;F0Z($)U='1O;DAI9VAL:6=H=#L*?0HN:'1M;&%R96$@+G1O;VQB87(@
M+FEN9&EC871O<B!["B`@<&%D9&EN9SH@,'!X(#-P>#L*("!O=F5R9FQO=SH@
M:&ED9&5N.PH@('=I9'1H.B`R,'!X.PH@('1E>'0M86QI9VXZ(&-E;G1E<CL*
M("!C=7)S;W(Z(&1E9F%U;'0["B`@8F]R9&5R.B`Q<'@@<V]L:60@0G5T=&]N
M4VAA9&]W.PI]"@HN:'1M;&%R96$@+G1O;VQB87(@+F)U='1O;D1I<V%B;&5D
M(&EM9R!["B`@9FEL=&5R.B!G<F%Y*"D@86QP:&$H;W!A8VET>2`](#(U*3L*
M("`M;6]Z+6]P86-I='DZ(#`N,C4["GT*"BYH=&UL87)E82`N=&]O;&)A<B`N
M<V5P87)A=&]R('L*("!P;W-I=&EO;CH@<F5L871I=F4["B`@;6%R9VEN.B`S
M<'@["B`@8F]R9&5R+6QE9G0Z(#%P>"!S;VQI9"!"=71T;VY3:&%D;W<["B`@
M8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@0G5T=&]N2&EG:&QI9VAT.PH@('=I
M9'1H.B`P<'@["B`@:&5I9VAT.B`Q-G!X.PH@('!A9&1I;F<Z(#!P>#L*?0H*
M+FAT;6QA<F5A("YT;V]L8F%R("YS<&%C92![('=I9'1H.B`U<'@[('T*"BYH
M=&UL87)E82`N=&]O;&)A<B!S96QE8W0@>R!F;VYT.B`Q,7!X(%1A:&]M82Q6
M97)D86YA+'-A;G,M<V5R:68[('T*"BYH=&UL87)E82`N=&]O;&)A<B!S96QE
M8W0L"BYH=&UL87)E82`N=&]O;&)A<B!S96QE8W0Z:&]V97(L"BYH=&UL87)E
M82`N=&]O;&)A<B!S96QE8W0Z86-T:79E('L@8F%C:V=R;W5N9#H@1FEE;&1&
M86-E.R!C;VQO<CH@0G5T=&]N5&5X=#L@?0H*+FAT;6QA<F5A("YS=&%T=7-"
M87(@>PH@(&)O<F1E<CH@,7!X('-O;&ED.PH@(&)O<F1E<BUC;VQO<CH@0G5T
M=&]N4VAA9&]W($)U='1O;DAI9VAL:6=H="!"=71T;VY(:6=H;&EG:'0@0G5T
M=&]N4VAA9&]W.PH@('!A9&1I;F<Z(#)P>"`T<'@["B`@8F%C:V=R;W5N9"UC
M;VQO<CH@0G5T=&]N1F%C93L*("!C;VQO<CH@0G5T=&]N5&5X=#L*("!F;VYT
M.B`Q,7!X(%1A:&]M82Q697)D86YA+'-A;G,M<V5R:68["GT*"BYH=&UL87)E
M82`N<W1A='5S0F%R("YS=&%T=7-"87)4<F5E(&$@>PH@('!A9&1I;F<Z(#)P
M>"`U<'@["B`@8V]L;W(Z(",P,&8["GT*"BYH=&UL87)E82`N<W1A='5S0F%R
M("YS=&%T=7-"87)4<F5E(&$Z=FES:71E9"![(&-O;&]R.B`C,#!F.R!]"BYH
M=&UL87)E82`N<W1A='5S0F%R("YS=&%T=7-"87)4<F5E(&$Z:&]V97(@>PH@
M(&)A8VMG<F]U;F0M8V]L;W(Z($AI9VAL:6=H=#L*("!C;VQO<CH@2&EG:&QI
M9VAT5&5X=#L*("!P861D:6YG.B`Q<'@@-'!X.PH@(&)O<F1E<CH@,7!X('-O
M;&ED($AI9VAL:6=H=%1E>'0["GT*"@HO*B!(:61D96X@1$E6('!O<'5P(&1I
M86QO9W,@*%!O<'5P1&EV*2`J+PH*+F1I86QO9R!["B`@8V]L;W(Z($)U='1O
M;E1E>'0["B`@8F%C:V=R;W5N9#H@0G5T=&]N1F%C93L*?0H*+F1I86QO9R`N
M8V]N=&5N="![('!A9&1I;F<Z(#)P>#L@?0H*+F1I86QO9RP@+F1I86QO9R!B
M=71T;VXL("YD:6%L;V<@:6YP=70L("YD:6%L;V<@<V5L96-T+"`N9&EA;&]G
M('1E>'1A<F5A+"`N9&EA;&]G('1A8FQE('L*("!F;VYT.B`Q,7!X(%1A:&]M
M82Q697)D86YA+'-A;G,M<V5R:68["GT*"BYD:6%L;V<@=&%B;&4@>R!B;W)D
M97(M8V]L;&%P<V4Z(&-O;&QA<'-E.R!]"@HN9&EA;&]G("YT:71L92!["B`@
M8F%C:V=R;W5N9#H@(S`P.#L*("!C;VQO<CH@(V9F.#L*("!B;W)D97(M8F]T
M=&]M.B`Q<'@@<V]L:60@(S`P,#L*("!P861D:6YG.B`Q<'@@,'!X(#)P>"`U
M<'@["B`@9F]N="US:7IE.B`Q,G!X.PH@(&9O;G0M=V5I9VAT.B!B;VQD.PH@
M(&-U<G-O<CH@9&5F875L=#L*?0H*+F1I86QO9R`N=&ET;&4@+F)U='1O;B![
M"B`@9FQO870Z(')I9VAT.PH@(&)O<F1E<CH@,7!X('-O;&ED(",V-F$["B`@
M<&%D9&EN9SH@,'!X(#%P>"`P<'@@,G!X.PH@(&UA<F=I;BUR:6=H=#H@,7!X
M.PH@(&-O;&]R.B`C9F9F.PH@('1E>'0M86QI9VXZ(&-E;G1E<CL*?0H*+F1I
M86QO9R`N=&ET;&4@+F)U='1O;BUH:6QI=&4@>R!B;W)D97(M8V]L;W(Z(",X
M.&8[(&)A8VMG<F]U;F0Z(",T-&,[('T*"BYD:6%L;V<@8G5T=&]N('L*("!W
M:61T:#H@-65M.PH@('!A9&1I;F<Z(#!P>#L*?0H*+F1I86QO9R`N8G5T=&]N
M0V]L;W(@>PH@('!A9&1I;F<Z(#%P>#L*("!C=7)S;W(Z(&1E9F%U;'0["B`@
M8F]R9&5R.B`Q<'@@<V]L:60["B`@8F]R9&5R+6-O;&]R.B!"=71T;VY(:6=H
M;&EG:'0@0G5T=&]N4VAA9&]W($)U='1O;E-H861O=R!"=71T;VY(:6=H;&EG
M:'0["GT*"BYD:6%L;V<@+F)U='1O;D-O;&]R+6AI;&ET92!["B`@8F]R9&5R
M+6-O;&]R.B`C,#`P.PI]"@HN9&EA;&]G("YB=71T;VY#;VQO<B`N8VAO;W-E
M<BP@+F1I86QO9R`N8G5T=&]N0V]L;W(@+FYO8V]L;W(@>PH@(&AE:6=H=#H@
M,"XV96T["B`@8F]R9&5R.B`Q<'@@<V]L:60["B`@<&%D9&EN9SH@,'!X(#%E
M;3L*("!B;W)D97(M8V]L;W(Z($)U='1O;E-H861O=R!"=71T;VY(:6=H;&EG
M:'0@0G5T=&]N2&EG:&QI9VAT($)U='1O;E-H861O=SL*?0H*+F1I86QO9R`N
M8G5T=&]N0V]L;W(@+FYO8V]L;W(@>R!P861D:6YG.B`P<'@[('T*+F1I86QO
M9R`N8G5T=&]N0V]L;W(@+FYO8V]L;W(M:&EL:71E('L@8F%C:V=R;W5N9"UC
M;VQO<CH@(V9F9CL@8V]L;W(Z("-F,#`[('T*"BYD:6%L;V<@+FQA8F5L('L@
M=&5X="UA;&EG;CH@<FEG:'0[('=I9'1H.B`V96T[('T*+F1I86QO9R`N=F%L
M=64@:6YP=70@>R!W:61T:#H@,3`P)3L@?0HN9&EA;&]G("YB=71T;VYS('L@
M=&5X="UA;&EG;CH@<FEG:'0[('!A9&1I;F<Z(#)P>"`T<'@@,'!X(#1P>#L@
M?0H*+F1I86QO9R!L96=E;F0@>R!F;VYT+7=E:6=H=#H@8F]L9#L@?0HN9&EA
M;&]G(&9I96QD<V5T('1A8FQE('L@;6%R9VEN.B`R<'@@,'!X.R!]"@HN<&]P
M=7!D:78@>PH@(&)O<F1E<CH@,G!X('-O;&ED.PH@(&)O<F1E<BUC;VQO<CH@
M0G5T=&]N2&EG:&QI9VAT($)U='1O;E-H861O=R!"=71T;VY3:&%D;W<@0G5T
M=&]N2&EG:&QI9VAT.PI]"@HN<&]P=7!W:6X@>PH@('!A9&1I;F<Z(#!P>#L*
M("!M87)G:6XZ(#!P>#L*?0H*+G!O<'5P=VEN("YT:71L92!["B`@8F%C:V=R
M;W5N9#H@(V9F9CL*("!C;VQO<CH@(S`P,#L*("!F;VYT+7=E:6=H=#H@8F]L
M9#L*("!F;VYT+7-I>F4Z(#$R,"4["B`@<&%D9&EN9SH@,W!X(#$P<'@["B`@
M;6%R9VEN+6)O='1O;3H@,3!P>#L*("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L
M:60@8FQA8VL["B`@;&5T=&5R+7-P86-I;F<Z(#)P>#L*?0H*9F]R;2![(&UA
M<F=I;CH@,'!X.R!B;W)D97(Z(&YO;F4[('T*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W-E<G9I8V5S+W!O<G1A;```````````````````````````
M```````````````````````````````````````````````````````P,#`W
M-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<T-"`P
M,C`V,#8`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O<&]R=&%L+V5D
M:70N<&AP````````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S
M,3(W(#$P-3$U-#,S-S0T(#`R,C,R-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D
M92]S97)V:6-E<R]P;W)T86PO961I="YP:'`L=B`Q+C0T+C@N-2`R,#`V+S`S
M+S`X(#$X.C`P.C4V(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY
M+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O
M<'ER:6=H="`R,#`S+3(P,#8@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N
M:&%L;"YC;RYN>CX*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!*86X@4V-H;F5I
M9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE
M*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN+RXN)RD[
M"G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PIR
M97%U:7)E7V]N8V4@)TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP)SL*<F5Q
M=6ER95]O;F-E("=(;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`G.PIR
M97%U:7)E7V]N8V4@)TAO<F1E+TED96YT:71Y+G!H<"<["@II9B`H(4%U=&@Z
M.FES075T:&5N=&EC871E9"@I*2!["B`@("!(;W)D93HZ875T:&5N=&EC871I
M;VY&86EL=7)E4F5D:7)E8W0H*3L*?0H*+R\@1V5T(&9U;&P@;F%M92!F;W(@
M=&ET;&4N"B1I9&5N=&ET>2`]("9)9&5N=&ET>3HZ<VEN9VQE=&]N*"D["B1F
M=6QL;F%M92`]("1I9&5N=&ET>2T^9V5T5F%L=64H)V9U;&QN86UE)RD["FEF
M("AE;7!T>2@D9G5L;&YA;64I*2!["B`@("`D9G5L;&YA;64@/2!!=71H.CIG
M971!=71H*"D["GT*"B\O($EN<W1A;G1I871E('1H92!B;&]C:W,@;V)J96-T
M<RX*)&)L;V-K<R`]("9(;W)D95]";&]C:U]#;VQL96-T:6]N.CIS:6YG;&5T
M;VXH)W!O<G1A;"<I.PHD;&%Y;W5T(#T@)DAO<F1E7T)L;V-K7TQA>6]U=%]-
M86YA9V5R.CIS:6YG;&5T;VXH)W!O<G1A;"<L("1B;&]C:W,L("1P<F5F<RT^
M9V5T5F%L=64H)W!O<G1A;%]L87EO=70G*2D["@HO+R!(86YD;&4@<F5Q=65S
M=&5D(&%C=&EO;G,N"B1L87EO=70M/FAA;F1L92A5=&EL.CIG971&;W)M1&%T
M82@G86-T:6]N)RDL"B`@("`@("`@("`@("`@("`H:6YT*55T:6PZ.F=E=$9O
M<FU$871A*"=R;W<G*2P*("`@("`@("`@("`@("`@("AI;G0I571I;#HZ9V5T
M1F]R;41A=&$H)V-O;"<I*3L*:68@*"1L87EO=70M/G5P9&%T960H*2D@>PH@
M("`@)'!R969S+3YS971686QU92@G<&]R=&%L7VQA>6]U="<L("1L87EO=70M
M/G-E<FEA;&EZ92@I*3L*?0H*)'1I=&QE(#T@7R@B37D@4&]R=&%L($QA>6]U
M="(I.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+6AE861E
M<BYI;F,G.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O<&]R=&%L+VUE
M;G4N:6YC)SL*)&YO=&EF:6-A=&EO;BT^;F]T:69Y*&%R<F%Y*"=L:7-T96YE
M<G,G(#T^("=S=&%T=7,G*2D["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@
M)R]P;W)T86PO961I="YI;F,G.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N
M("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N
M<&AP````````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C4W,"`Q
M,#4Q-30S,S<T-"`P,C(V-3$`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O<V5R
M=FEC97,O<&]R=&%L+VUO8FEL92YP:'`L=B`R+C$U+C$P+C,@,C`P-B\P,2\P
M,2`R,3HR.3HQ-"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P
M-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%
M7U\I("X@)R\N+B\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O
M;&EB+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92])9&5N=&ET>2YP
M:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TUO8FEL92YP:'`G.PH*:68@*"%!
M=71H.CIG971!=71H*"DI('L*("`@(&AE861E<B@G3&]C871I;VXZ("<@+B!5
M=&EL.CIA9&1087)A;65T97(H2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=L;V=I
M;BYP:'`G+"!T<G5E*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W5R;"<L($AO<F1E.CIS96QF57)L*"DL(&9A;'-E
M*2D["B`@("!E>&ET.PI]"@HD:61E;G1I='D@/2`F261E;G1I='DZ.G-I;F=L
M971O;B@I.PHD9G5L;&YA;64@/2`D:61E;G1I='DM/F=E=%9A;'5E*"=F=6QL
M;F%M92<I.PII9B`H96UP='DH)&9U;&QN86UE*2D@>PH@("`@)&9U;&QN86UE
M(#T@075T:#HZ9V5T075T:"@I.PI]"@HD;2`]("9N97<@2&]R9&5?36]B:6QE
M*%\H(E=E;&-O;64B*2D["B1M+3YA9&0H;F5W($AO<F1E7TUO8FEL95]T97AT
M*'-P<FEN=&8H7R@B5V5L8V]M92P@)7,B*2P@)&9U;&QN86UE*2DI.PH*+R\@
M365S<WD@=V%Y(&]F(&QI;FMI;F<@=&\@86-T:79E(&%P<',@=&AA="!S=7!P
M;W)T(&UO8FEL90HO+R!D979I8V5S+B!3:&]U;&0@8F4@;6%D92!M;W)E(&5L
M96=A;G0@870@<V]M92!P;VEN="X*:68@*"%E;7!T>2@D<F5G:7-T<GDM/F%P
M<&QI8V%T:6]N<ULG;6EM<"==6R=S=&%T=7,G72D@)B8*("`@("1R96=I<W1R
M>2T^87!P;&EC871I;VYS6R=M:6UP)UU;)W-T871U<R==("$]("=I;F%C=&EV
M92<I('L*("`@("1M+3YA9&0H;F5W($AO<F1E7TUO8FEL95]L:6YK*"1R96=I
M<W1R>2T^9V5T*"=N86UE)RP@)VUI;7`G*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@($AO<F1E.CIU<FPH)')E9VES=')Y+3YG970H)W=E
M8G)O;W0G+"`G;6EM<"<I("X@)R\G*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1R96=I<W1R>2T^9V5T*"=N86UE)RP@)VUI;7`G*2DI
M.PI]"@HD;2T^9&ES<&QA>2@I.PH`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'``````````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`V,30R(#$P-3$U-#,S-S0T(#`R,C<Q,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@)$AO<F1E.B!H;W)D92]S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H
M<"QV(#(N,C8N-BXS(#(P,#8O,#$O,#$@,C$Z,CDZ,30@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`Q+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO
M<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H)TA/4D1%7T)!
M4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXO+BXG*3L*<F5Q=6ER95]O
M;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC
M92`G2&]R9&4O4E!#+G!H<"<["@II9B`H(4%U=&@Z.FES075T:&5N=&EC871E
M9"@I*2!["B`@("!(;W)D93HZ875T:&5N=&EC871I;VY&86EL=7)E4F5D:7)E
M8W0H*3L*?0H*)')P8U]S97)V97)S(#T@0'5N<V5R:6%L:7IE*"1P<F5F<RT^
M9V5T5F%L=64H)W)E;6]T95]S=6UM87)I97,G*2D["FEF("@A:7-?87)R87DH
M)')P8U]S97)V97)S*2D@>PH@("`@)')P8U]S97)V97)S(#T@87)R87DH*3L*
M?0H*)&%C=&EO;DE$(#T@571I;#HZ9V5T1F]R;41A=&$H)V%C=&EO;DE$)RD[
M"@HO+R!(86YD;&4@8VQI96YT<R!W:71H;W5T(&IA=F%S8W)I<'0N"FEF("AI
M<U]N=6QL*"1A8W1I;VY)1"DI('L*("`@(&EF("A5=&EL.CIG9710;W-T*"=E
M9&ET)RDI('L*("`@("`@("`D86-T:6]N240@/2`G961I="<["B`@("!](&5L
M<V5I9B`H571I;#HZ9V5T4&]S="@G<V%V92<I*2!["B`@("`@("`@)&%C=&EO
M;DE$(#T@)W-A=F4G.PH@("`@?2!E;'-E:68@*%5T:6PZ.F=E=%!O<W0H)V1E
M;&5T92<I*2!["B`@("`@("`@)&%C=&EO;DE$(#T@)V1E;&5T92<["B`@("!]
M"GT*"B\J(%)U;B!T:')O=6=H('1H92!A8W1I;VX@:&%N9&QE<G,@*B\*<W=I
M=&-H("@D86-T:6]N240I('L*8V%S92`G<V%V92<Z"B`@("!I9B`H*"1T;U]E
M9&ET(#T@571I;#HZ9V5T1F]R;41A=&$H)V5D:71?<V5R=F5R)RDI(#T](&YU
M;&PI('L*("`@("`@("`D=&]?961I="`](&-O=6YT*"1R<&-?<V5R=F5R<RD[
M"B`@("`@("`@)')P8U]S97)V97)S6UT@/2!A<G)A>2@I.PH@("`@?0H@("`@
M)')P8U]S97)V97)S6R1T;U]E9&ET75LG=7)L)UT@("`@/2!5=&EL.CIG971&
M;W)M1&%T82@G=7)L)RD["B`@("`D<G!C7W-E<G9E<G-;)'1O7V5D:71=6R=U
M<V5R)UT@("`](%5T:6PZ.F=E=$9O<FU$871A*"=U<V5R)RD["B`@("`D<G!C
M7W-E<G9E<G-;)'1O7V5D:71=6R=P87-S=V0G72`](%5T:6PZ.F=E=$9O<FU$
M871A*"=P87-S=V0G*3L*("`@("1P<F5F<RT^<V5T5F%L=64H)W)E;6]T95]S
M=6UM87)I97,G+"!S97)I86QI>F4H)')P8U]S97)V97)S*2D["B`@("`D<')E
M9G,M/G-T;W)E*"D["B`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H
M7R@B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(BDL("1R<&-?
M<V5R=F5R<ULD=&]?961I=%U;)W5R;"==*2P@)VAO<F1E+G-U8V-E<W,G*3L*
M("`@(&)R96%K.PH*8V%S92`G9&5L971E)SH*("`@("1T;U]D96QE=&4@/2!5
M=&EL.CIG971&;W)M1&%T82@G<V5R=F5R)RD["B`@("!I9B`H)'1O7V1E;&5T
M92`A/2`M,2D@>PH@("`@("`@("1D96QE=&5D7W-E<G9E<B`]("1R<&-?<V5R
M=F5R<ULD=&]?9&5L971E75LG=7)L)UT["B`@("`@("`@)'-E<G9E<E]L:7-T
M(#T@87)R87DH*3L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D
M<G!C7W-E<G9E<G,I.R`D:2LK*2!["B`@("`@("`@("`@(&EF("@D:2`]/2`D
M=&]?9&5L971E*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D<V5R=F5R7VQI<W1;72`]("1R<&-?<V5R
M=F5R<ULD:5T["B`@("`@("`@?0H@("`@("`@("1P<F5F<RT^<V5T5F%L=64H
M)W)E;6]T95]S=6UM87)I97,G+"!S97)I86QI>F4H)'-E<G9E<E]L:7-T*2D[
M"B`@("`@("`@)&-H;W-E;D-O;'5M;G,@/2!E>'!L;V1E*"<[)RP@)'!R969S
M+3YG971686QU92@G<VAO=U]S=6UM87)I97,G*2D["B`@("`@("`@:68@*"1C
M:&]S96Y#;VQU;6YS("$](&%R<F%Y*"<G*2D@>PH@("`@("`@("`@("`D;F5W
M0V]L=6UN<R`](&%R<F%Y*"D["B`@("`@("`@("`@(&9O<F5A8V@@*"1C:&]S
M96Y#;VQU;6YS(&%S("1C:&]S96Y#;VQU;6XI('L*("`@("`@("`@("`@("`@
M("1C:&]S96Y#;VQU;6X@/2!E>'!L;V1E*"<L)RP@)&-H;W-E;D-O;'5M;BD[
M"B`@("`@("`@("`@("`@("`D<F5M;W1E(#T@97AP;&]D92@G?"<L("1C:&]S
M96Y#;VQU;6Y;,%TI.PH@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1R96UO
M=&4I("$](#,@?'P@)')E;6]T95LR72`]/2`D9&5L971E9%]S97)V97(I('L*
M("`@("`@("`@("`@("`@("`@("`D;F5W0V]L=6UN<UM=(#T@:6UP;&]D92@G
M+"<L("1C:&]S96Y#;VQU;6XI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1P<F5F<RT^<V5T5F%L=64H)W-H;W=?<W5M
M;6%R:65S)RP@:6UP;&]D92@G.R<L("1N97=#;VQU;6YS*2D["B`@("`@("`@
M?0H@("`@("`@("1P<F5F<RT^<W1O<F4H*3L*("`@("`@("`D<G!C7W-E<G9E
M<G,@/2`D<V5R=F5R7VQI<W0["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S
M:"AS<')I;G1F*%\H(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N(&1E;&5T
M960N(BDL("1D96QE=&5D7W-E<G9E<BDL("=H;W)D92YS=6-C97-S)RD["B`@
M("!](&5L<V4@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B66]U
M(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+B(I+"`G:&]R
M9&4N=V%R;FEN9R<I.PH@("`@?0H@("`@8G)E86L["GT*"B\J(%-H;W<@=&AE
M(&AE861E<BX@*B\*<F5Q=6ER95]O;F-E("=(;W)D92]0<F5F<R]522YP:'`G
M.PIR97%U:7)E($A/4D1%7T)!4T4@+B`G+V-O;F9I9R]P<F5F<RYP:'`G.PHD
M87!P(#T@)VAO<F1E)SL*4')E9G-?54DZ.F=E;F5R871E2&5A9&5R*"=R96UO
M=&4G*3L*"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]R<&-S=6TO<G!C
M<W5M+FEN8R<["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM
M9F]O=&5R+FEN8R<["@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<```````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`R-3(S-"`Q,#4Q-30S,S<T-"`P,C,P,34`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J("1(;W)D93H@:&]R9&4O<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N
M<&AP+'8@,2XT+C(N,3,@,C`P-B\P,R\R,"`Q-3HP,#HP-B!J86X@17AP("0*
M("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:&%R;&5S($HN($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($IO
M;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`R,#`S+3(P
M,#8@36EC:&%E;"!087=L;W=S:WD@/&UJ<&%W;&]W<VMY0'EA:&]O+F-O;3X*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*B\*"B\J*@H@*B!$971E<FUI;F4@:68@=&AE(&-U
M<G)E;G0@=7-E<B!C86X@<V5E(&%N(&%P<&QI8V%T:6]N+@H@*@H@*B!`<&%R
M86T@<W1R:6YG("`D87!P("`@("`@("`@(%1H92!A<'!L:6-A=&EO;B!N86UE
M+@H@*B!`<&%R86T@87)R87D@("`D<&%R86US("`@("`@(%1H92!A<'!L:6-A
M=&EO;B=S('!A<F%M971E<G,N"B`J($!P87)A;2!A<G)A>2`@)B1H87-#:&EL
M9')E;B`@4F5F97)E;F-E('1O(&%N(&%R<F%Y('1O('-E="!C:&EL9')E;B!F
M;&%G<R!I;BX*("HO"F9U;F-T:6]N(&-A;E-E92@D87!P+"`D<&%R86US+"`F
M)&AA<T-H:6QD<F5N*0I["B`@("!G;&]B86P@)')E9VES=')Y.PH*("`@('-T
M871I8R`D8V%C:&4@/2!A<G)A>2@I.PH@("`@<W1A=&EC("1I<T%D;6EN.PH@
M("`@<W1A=&EC("1U<V5R.PH*("`@("\O($EF('=E(&AA=F4@82!C86-H960@
M=F%L=64@9F]R('1H:7,@87!P;&EC871I;VXL(')E='5R;B!I="!N;W<N"B`@
M("!I9B`H:7-S970H)&-A8VAE6R1A<'!=*2D@>PH@("`@("`@(')E='5R;B`D
M8V%C:&5;)&%P<%T["B`@("!]"@H@("`@+R\@26YI=&EA;&EZ92!V87)I86)L
M97,@=V4G;&P@:V5E<"!U<VEN9R!I;B!S=6-C97-S:79E(&-A;&QS(&]N"B`@
M("`O+R!T:&4@9FER<W0@8V%L;"X*("`@(&EF("AI<U]N=6QL*"1I<T%D;6EN
M*2D@>PH@("`@("`@("1I<T%D;6EN(#T@075T:#HZ:7-!9&UI;B@I.PH@("`@
M("`@("1U<V5R(#T@075T:#HZ9V5T075T:"@I.PH@("`@?0H*("`@("\O($-H
M96-K(&EF('1H92!C=7)R96YT('5S97(@:&%S('!E<FUI<W-O;B!T;R!S964@
M=&AI<R!A<'!L:6-A=&EO;BP@86YD(&EF"B`@("`O+R!T:&4@87!P;&EC871I
M;VX@:7,@86-T:79E+B!(96%D:6YG<R!A<F4@=FES:6)L92!T;R!E=F5R>6]N
M92`H8G5T(&=E=`H@("`@+R\@9FEL=&5R960@;W5T(&QA=&5R(&EF('1H97D@
M:&%V92!N;R!C:&EL9')E;BDN($%D;6EN:7-T<F%T;W)S(&%L=V%Y<R!S964*
M("`@("\O(&%L;"!A<'!L:6-A=&EO;G,@97AC97!T('1H;W-E(&UA<FME9"`G
M:6YA8W1I=F4G+B!!;GEO;F4@=VET:"!32$]7"B`@("`O+R!P97)M:7-S:6]N
M<R!C86X@<V5E(&%N(&%P<&QI8V%T:6]N+"!B=70@4D5!1"!I<R!N965D960@
M=&\@86-T=6%L;'D@=7-E"B`@("`O+R!T:&4@87!P;&EC871I;VXN(%EO=2!C
M86X@=7-E('1H:7,@9&ES=&EN8W1I;VX@=&\@<VAO=R!A<'!L:6-A=&EO;G,@
M=&\*("`@("\O(&=U97-T<R!T:&%T('1H97D@;F5E9"!T;R!L;V<@:6X@=&\@
M=7-E+B!)9B!Y;W4@9&]N)W0@=V%N="!T:&5M('1O('-E90H@("`@+R\@87!P
M<R!T:&5Y(&-A;B=T('5S92P@=&AE;B!D;VXG="!G:79E(&=U97-T<R!32$]7
M('!E<FUI<W-I;VYS('1O"B`@("`O+R!A;GET:&EN9RX*("`@(&EF("@O+R!$
M;VXG="!S:&]W(&%P<&QI8V%T:6]N<R!T:&%T(&%R96XG="!I;G-T86QL960L
M(&5V96X@:68@=&AE>2=R90H@("`@("`@("\O(&-O;F9I9W5R960N"B`@("`@
M("`@*&ES<V5T*"1P87)A;7-;)V9I;&5R;V]T)UTI("8F("%I<U]D:7(H)'!A
M<F%M<ULG9FEL97)O;W0G72DI('Q\"@H@("`@("`@("\O($1O;B=T('-H;W<@
M8FQO8VMS(&]F(&%P<&QI8V%T:6]N<R!T:&%T(&%R96XG="!I;G-T86QL960N
M"B`@("`@("`@*"1P87)A;7-;)W-T871U<R==(#T]("=B;&]C:R<@)B8*("`@
M("`@("`@(6ES7V1I<B@D<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G+"`D<&%R
M86US6R=A<'`G72DI*2!\?`H*("`@("`@("`O+R!&:6QT97(@;W5T(&5N=')I
M97,@=&AA="!A<F4@9&ES86)L960L(&AI9&1E;B!O<B!S:&]U;&1N)W0@<VAO
M=R!U<`H@("`@("`@("\O(&EN('1H92!M96YU+@H@("`@("`@("1P87)A;7-;
M)W-T871U<R==(#T]("=N;W1O;VQB87(G('Q\("1P87)A;7-;)W-T871U<R==
M(#T]("=H:61D96XG('Q\"B`@("`@("`@)'!A<F%M<ULG<W1A='5S)UT@/3T@
M)VEN86-T:79E)RD@>PH*("`@("`@("`D8V%C:&5;)&%P<%T@/2!F86QS93L*
M"B`@("!](&5L<V5I9B`H+R\@2&5A9&EN9W,@8V%N(&%L=V%Y<R!B92!S965N
M+@H@("`@("`@("`@("`@("@D<&%R86US6R=S=&%T=7,G72`]/2`G:&5A9&EN
M9R<I('Q\"@H@("`@("`@("`@("`@("\O($%D;6EN<R!S964@979E<GET:&EN
M9R!T:&%T(&UA:V5S(&ET('1O('1H:7,@<&]I;G0N"B`@("`@("`@("`@("`@
M*"1I<T%D;6EN('Q\"@H@("`@("`@("`@("`@("`O+R!5<V5R<R!W:&\@:&%V
M92!32$]7('!E<FUI<W-I;VYS('1O(&%C=&EV92!O<B!B;&]C:R!E;G1R:65S
M"B`@("`@("`@("`@("`@("\O('-E92!T:&5M+@H@("`@("`@("`@("`@("`H
M)')E9VES=')Y+3YH87-097)M:7-S:6]N*"1A<'`L(%!%4DU37U-(3U<I("8F
M"B`@("`@("`@("`@("`@("`H)'!A<F%M<ULG<W1A='5S)UT@/3T@)V%C=&EV
M92<@?'P*("`@("`@("`@("`@("`@("`D<&%R86US6R=S=&%T=7,G72`]/2`G
M8FQO8VLG*2DI*2!["@H@("`@("`@("1C86-H95LD87!P72`]('1R=64["@H@
M("`@("`@("\O($YO=&4@=&AA="!T:&4@<&%R96YT(&YO9&4L(&EF(&%N>2P@
M:&%S(&-H:6QD<F5N+@H@("`@("`@(&EF("AI<W-E="@D<&%R86US6R=M96YU
M7W!A<F5N="==*2D@>PH@("`@("`@("`@("`D:&%S0VAI;&1R96Y;)'!A<F%M
M<ULG;65N=5]P87)E;G0G75T@/2!T<G5E.PH@("`@("`@('T*("`@('T@96QS
M92!["B`@("`@("`@+R\@0V%T8V@@86YY=&AI;F<@=&AA="!F96QL('1H<F]U
M9V@L(&%N9"!D;VXG="!S:&]W(&ET+@H@("`@("`@("1C86-H95LD87!P72`]
M(&9A;'-E.PH@("`@?0H*("`@(')E='5R;B`D8V%C:&5;)&%P<%T["GT*"B\J
M*@H@*B!"=6EL9',@=&AE(&UE;G4@<W1R=6-T=7)E(&1E<&5N9&EN9R!O;B!A
M<'!L:6-A=&EO;B!P97)M:7-S:6]N<RX*("HO"F9U;F-T:6]N(&)U:6QD365N
M=2@I"GL*("`@(&=L;V)A;"`D8V]N9BP@)')E9VES=')Y.PH*("`@("1A<'!S
M(#T@87)R87DH*3L*("`@("1C:&EL9')E;B`](&%R<F%Y*"D["B`@("!F;W)E
M86-H("@D<F5G:7-T<GDM/F%P<&QI8V%T:6]N<R!A<R`D87!P(#T^("1P87)A
M;7,I('L*("`@("`@("!I9B`H8V%N4V5E*"1A<'`L("1P87)A;7,L("1C:&EL
M9')E;BDI('L*("`@("`@("`@("`@)&%P<'-;)&%P<%T@/2`D<&%R86US.PH@
M("`@("`@('T*("`@('T*"B`@("`D;65N=2`](&%R<F%Y*"D["B`@("!F;W)E
M86-H("@D87!P<R!A<R`D87!P(#T^("1P87)A;7,I('L*("`@("`@("`O+R!&
M:6QT97(@;W5T(&%L;"!H96%D:6YG<R!W:71H;W5T(&-H:6QD<F5N+@H@("`@
M("`@(&EF("@D<&%R86US6R=S=&%T=7,G72`]/2`G:&5A9&EN9R<@)B8@96UP
M='DH)&-H:6QD<F5N6R1A<'!=*2D@>PH@("`@("`@("`@("!C;VYT:6YU93L*
M("`@("`@("!]"@H@("`@("`@("1M96YU6R1A<'!=(#T@)'!A<F%M<SL*("`@
M('T*"B`@("`O+R!!9&0@=&AE(&%D;6EN:7-T<F%T:6]N(&UE;G4@:68@=&AE
M('5S97(@:7,@86X@861M:6XN"B`@("!I9B`H075T:#HZ:7-!9&UI;B@I*2![
M"B`@("`@("`@)&UE;G5;)V%D;6EN:7-T<F%T:6]N)UT@/2!A<G)A>2@G;F%M
M92<@/3X@7R@B061M:6YI<W1R871I;VXB*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=I8V]N)R`]/B`D<F5G:7-T<GDM/F=E
M=$EM86=E1&ER*"D@+B`G+V%D;6EN:7-T<F%T:6]N+G!N9R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<W1A='5S)R`]/B`G
M:&5A9&EN9R<I.PH*("`@("`@("!F;W)E86-H("@D<F5G:7-T<GDM/FQI<W1!
M<'!S*"D@87,@)&%P<"D@>PH@("`@("`@("`@("!I9B`H(21R96=I<W1R>2T^
M:&%S365T:&]D*"=A9&UI;E]L:7-T)RP@)&%P<"DI('L*("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D;&ES
M="`]("1R96=I<W1R>2T^8V%L;$)Y4&%C:V%G92@D87!P+"`G861M:6Y?;&ES
M="<I.PH@("`@("`@("`@("!I9B`H:7-?82@D;&ES="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1L:7-T(&%S("1M971H;V0@/3X@)'9A
M;',I('L*("`@("`@("`@("`@("`@(&EF("@D87!P("$]("=H;W)D92<I('L*
M("`@("`@("`@("`@("`@("`@("`D;F%M92`]("1R96=I<W1R>2T^9V5T*"=N
M86UE)RP@)&%P<"D["B`@("`@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D
M=F%L<ULG;F%M92==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;F%M
M92`N/2`G("<@+B`D=F%L<ULG;F%M92==.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@)&YA;64@/2!(;W)D93HZ<W1R:7!!8V-E<W-+97DH)'9A;'-;)VYA;64G
M72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D:6-O;B`]
M(&ES<V5T*"1V86QS6R=I8V]N)UTI(#\@)')E9VES=')Y+3YG971);6%G941I
M<B@D87!P*2`N("<O)R`N("1V86QS6R=I8V]N)UT@.B`D<F5G:7-T<GDM/F=E
M="@G:6-O;B<L("1A<'`I.PH*("`@("`@("`@("`@("`@("1M96YU6R=A9&UI
M;FES=')A=&EO;E\G("X@)&%P<"`N("=?)R`N("1M971H;V1=(#T@87)R87DH
M"B`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^("1N86UE+`H@("`@("`@
M("`@("`@("`@("`@("=I8V]N)R`]/B`D:6-O;BP*("`@("`@("`@("`@("`@
M("`@("`G<W1A='5S)R`]/B`G86-T:79E)RP*("`@("`@("`@("`@("`@("`@
M("`G;65N=5]P87)E;G0G(#T^("=A9&UI;FES=')A=&EO;B<L"B`@("`@("`@
M("`@("`@("`@("`@)W5R;"<@/3X@2&]R9&4Z.G5R;"@D<F5G:7-T<GDM/F%P
M<&QI8V%T:6]N5V5B4&%T:"@D=F%L<ULG;&EN:R==+"`D87!P*2DL"B`@("`@
M("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M('T*"B`@("!I9B`H2&]R9&4Z.G-H;W=397)V:6-E*"=O<'1I;VYS)RD@)B8*
M("`@("`@("`D8V]N9ELG<')E9G,G75LG9')I=F5R)UT@(3T@)R<@)B8@)&-O
M;F9;)W!R969S)UU;)V1R:79E<B==("$]("=N;VYE)RD@>PH@("`@("`@("1M
M96YU6R=O<'1I;VYS)UT@/2!A<G)A>2@G;F%M92<@/3X@7R@B3W!T:6]N<R(I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<W1A='5S)R`]
M/B`G86-T:79E)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)VEC;VXG(#T^("1R96=I<W1R>2T^9V5T26UA9V5$:7(H*2`N("<O<')E9G,N
M<&YG)RD["@H@("`@("`@("\J($=E="!A(&QI<W0@;V8@8V]N9FEG=7)A8FQE
M(&%P<&QI8V%T:6]N<RX@*B\*("`@("`@("`D<')E9G-?87!P<R`](&%R<F%Y
M*"D["B`@("`@("`@9F]R96%C:"`H)')E9VES=')Y+3YA<'!L:6-A=&EO;G,@
M87,@)&%P<&QI8V%T:6]N(#T^("1P87)A;7,I('L*("`@("`@("`@("`@:68@
M*"1P87)A;7-;)W-T871U<R==(#T]("=H96%D:6YG)R!\?`H@("`@("`@("`@
M("`@("`@)'!A<F%M<ULG<W1A='5S)UT@/3T@)V)L;V-K)R!\?`H@("`@("`@
M("`@("`@("`@(69I;&5?97AI<W1S*"1R96=I<W1R>2T^9V5T*"=F:6QE<F]O
M="<L("1A<'!L:6-A=&EO;BD@+B`G+V-O;F9I9R]P<F5F<RYP:'`G*2D@>PH@
M("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("\J($-H96-K(&EF('1H92!C=7)R96YT('5S97(@:&%S('!E<FUI
M<W-I;VX@=&\@<V5E('1H:7,*("`@("`@("`@("`@("H@87!P;&EC871I;VXL
M(&%N9"!I9B!T:&4@87!P;&EC871I;VX@:7,@86-T:79E+@H@("`@("`@("`@
M("`@*B!!9&UI;FES=')A=&]R<R!A;'=A>7,@<V5E(&%L;"!A<'!L:6-A=&EO
M;G,N("HO"B`@("`@("`@("`@(&EF("@H075T:#HZ:7-!9&UI;B@I("8F("1P
M87)A;7-;)W-T871U<R==("$]("=I;F%C=&EV92<I('Q\"B`@("`@("`@("`@
M("`@("`H)')E9VES=')Y+3YH87-097)M:7-S:6]N*"1A<'!L:6-A=&EO;BD@
M)B8*("`@("`@("`@("`@("`@("`H)'!A<F%M<ULG<W1A='5S)UT@/3T@)V%C
M=&EV92<I*2D@>PH@("`@("`@("`@("`@("`@)'!R969S7V%P<'-;)&%P<&QI
M8V%T:6]N72`](%\H)'!A<F%M<ULG;F%M92==*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D<')E9G-?87!P<ULG:&]R
M9&4G72DI('L*("`@("`@("`@("`@)&UE;G5;)V]P=&EO;G-?)R`N("=H;W)D
M92==(#T@87)R87DH)VYA;64G(#T^(%\H(D=L;V)A;"!/<'1I;VYS(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=S=&%T=7,G(#T^("=A8W1I=F4G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G;65N=5]P87)E;G0G(#T^("=O
M<'1I;VYS)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)VEC;VXG(#T^("1R96=I<W1R>2T^9V5T*"=I8V]N)RP@
M)VAO<F1E)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=U<FPG(#T^($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G
M<V5R=FEC97,O<')E9G,N<&AP/V%P<#UH;W)D92<I*3L*("`@("`@("`@("`@
M=6YS970H)'!R969S7V%P<'-;)VAO<F1E)UTI.PH@("`@("`@('T*"B`@("`@
M("`@87-O<G0H)'!R969S7V%P<',I.PH@("`@("`@(&9O<F5A8V@@*"1P<F5F
M<U]A<'!S(&%S("1A<'`@/3X@)&YA;64I('L*("`@("`@("`@("`@)&UE;G5;
M)V]P=&EO;G-?)R`N("1A<'!=(#T@87)R87DH)VYA;64G(#T^("1N86UE+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M<W1A='5S)R`]/B`G86-T:79E)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)VUE;G5?<&%R96YT)R`]/B`G;W!T:6]N
M<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=I8V]N)R`]/B`D<F5G:7-T<GDM/F=E="@G:6-O;B<L("1A<'`I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M=7)L)R`]/B!(;W)D93HZ87!P;&EC871I;VY5<FPH)W-E<G9I8V5S+W!R969S
M+G!H<#]A<'`])R`N("1A<'`I*3L*("`@("`@("!]"B`@("!]"@H@("`@:68@
M*$%U=&@Z.FES075T:&5N=&EC871E9"@I*2!["B`@("`@("`@)&UE;G5;)VQO
M9V]U="==(#T@87)R87DH)VYA;64G(#T^(%\H(DQO9R!O=70B*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G<W1A='5S)R`]/B`G86-T:79E
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:6-O;B<@/3X@
M)')E9VES=')Y+3YG971);6%G941I<B@I("X@)R]L;V=O=70N<&YG)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=7)L)R`]/B!(;W)D93HZ
M9V5T4V5R=FEC94QI;FLH)VQO9V]U="<L("=H;W)D92<L('1R=64I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T87)G970G(#T^("=?<&%R
M96YT)RD["B`@("!](&5L<V4@>PH@("`@("`@("1M96YU6R=L;V=I;B==(#T@
M87)R87DH)VYA;64G(#T^(%\H(DQO9R!I;B(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W-T871U<R<@/3X@)V%C=&EV92<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G:6-O;B<@/3X@)')E9VES=')Y+3YG
M971);6%G941I<B@I("X@)R]L;V=I;BYP;F<G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W5R;"<@/3X@2&]R9&4Z.F=E=%-E<G9I8V5,:6YK
M*"=L;V=I;B<L("=H;W)D92<L('1R=64L(&9A;'-E*2D["B`@("!]"@H@("`@
M<F5T=7)N("1M96YU.PI]"@I`9&5F:6YE*"=!551(7TA!3D1,15(G+"!T<G5E
M*3L*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@
M)R\N+B\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A
M<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]4<F5E+G!H<"<["G)E<75I
M<F5?;VYC92`G2&]R9&4O0FQO8VLN<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D
M92]";&]C:R]#;VQL96-T:6]N+G!H<"<["@II9B`H(4%U=&@Z.F=E=$%U=&@H
M*2`F)B`A)&-O;F9;)VUE;G4G75LG86QW87ES)UTI('L*("`@($AO<F1E.CIA
M=71H96YT:6-A=&EO;D9A:6QU<F52961I<F5C="@I.PI]"@HD:7-?;6]Z8F%R
M(#T@*&)O;VPI571I;#HZ9V5T1F]R;41A=&$H)VUO>F)A<B<I.PH*+R\@4V5T
M('5P('1H92!T<F5E+@HD=')E92`]("9(;W)D95]4<F5E.CIS:6YG;&5T;VXH
M)VAO<F1E7VUE;G4G+"`G:F%V87-C<FEP="<I.PHD=')E92T^<V5T3W!T:6]N
M*&%R<F%Y*"=T87)G970G(#T^("1I<U]M;WIB87(@/R`G7V-O;G1E;G0G(#H@
M)VAO<F1E7VUA:6XG*2D["@HD;65N=2`](&)U:6QD365N=2@I.PIF;W)E86-H
M("@D;65N=2!A<R`D87!P(#T^("1P87)A;7,I('L*("`@(&EF("@D<&%R86US
M6R=S=&%T=7,G72`]/2`G8FQO8VLG*2!["B`@("`@("`@)&)L;V-K(#T@)DAO
M<F1E7T)L;V-K7T-O;&QE8W1I;VXZ.F=E=$)L;V-K*"1P87)A;7-;)V%P<"==
M+"`D<&%R86US6R=B;&]C:VYA;64G72D["B`@("`@("`@:68@*&ES7V$H)&)L
M;V-K+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@($AO<F1E.CIF871A
M;"@D8FQO8VLL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@
M("`@("1B;&]C:RT^8G5I;&14<F5E*"1T<F5E+"`P+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@(&ES<V5T*"1P87)A;7-;)VUE;G5?<&%R96YT)UTI(#\@
M)'!A<F%M<ULG;65N=5]P87)E;G0G72`Z(&YU;&PI.PH@("`@?2!E;'-E('L*
M("`@("`@("`O+R!.965D('1O(')U;B!T:&4@;F%M92!T:')O=6=H(&=E='1E
M>'0@<VEN8V4@=&AE('5S97(G<PH@("`@("`@("\O(&QO8V%L92!M87D@;F]T
M(&AA=F4@8F5E;B!L;V%D960@=VAE;B!R96=I<W1R>2YP:'`@=V%S"B`@("`@
M("`@+R\@<&%R<V5D+@H@("`@("`@("1N86UE(#T@7R@D<&%R86US6R=N86UE
M)UTI.PH*("`@("`@("`O+R!(96%D:6YG<R!H879E(&YO('=E8G)O;W0[('1H
M97DG<F4@:G5S="!C;VYT86EN97)S(&9O<B!O=&AE<@H@("`@("`@("\O(&UE
M;G4@:71E;7,N"B`@("`@("`@:68@*&ES<V5T*"1P87)A;7-;)W5R;"==*2D@
M>PH@("`@("`@("`@("`D=7)L(#T@)'!A<F%M<ULG=7)L)UT["B`@("`@("`@
M?2!E;'-E:68@*"1P87)A;7-;)W-T871U<R==(#T]("=H96%D:6YG)R!\?"`A
M:7-S970H)'!A<F%M<ULG=V5B<F]O="==*2D@>PH@("`@("`@("`@("`D=7)L
M(#T@;G5L;#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=7)L(#T@
M2&]R9&4Z.G5R;"@D<&%R86US6R=W96)R;V]T)UT@+B`G+R<@+B`H:7-S970H
M)'!A<F%M<ULG:6YI=&EA;%]P86=E)UTI(#\@)'!A<F%M<ULG:6YI=&EA;%]P
M86=E)UT@.B`G)RDI.PH@("`@("`@('T*"B`@("`@("`@)&YO9&5?<&%R86US
M(#T@87)R87DH)W5R;"<@/3X@)'5R;"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G=&%R9V5T)R`]/B!I<W-E="@D<&%R86US6R=T87)G970G72D@
M/R`D<&%R86US6R=T87)G970G72`Z(&YU;&PL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)VEC;VXG(#T^(&ES<V5T*"1P87)A;7-;)VEC;VXG72D@
M/R`D<&%R86US6R=I8V]N)UT@.B`D<F5G:7-T<GDM/F=E="@G:6-O;B<L("1A
M<'`I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=I8V]N9&ER)R`]
M/B`G)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I.PH@("`@("`@
M("1T<F5E+3YA9&1.;V1E*"1A<'`L("%E;7!T>2@D<&%R86US6R=M96YU7W!A
M<F5N="==*2`_("1P87)A;7-;)VUE;G5?<&%R96YT)UT@.B!N=6QL+"`D;F%M
M92P@,"P@9F%L<V4L("1N;V1E7W!A<F%M<RD["B`@("!]"GT*"B\O($EF('=E
M)W)E('-E<G9I;F<@82!R97%U97-T('1O('1H92!*4R!U<&1A=&4@8VQI96YT
M+"!J=7-T(')E;F1E<B!T:&4*+R\@=7!D871E9"!N;V1E(&IA=F%S8W)I<'0N
M"FEF("A5=&EL.CIG971&;W)M1&%T82@G:'1T<&-L:65N="<I*2!["B`@("!H
M96%D97(H)T-O;G1E;G0M5'EP93H@=&5X="]J879A<V-R:7!T.R!C:&%R<V5T
M/2<@+B!.3%,Z.F=E=$-H87)S970H*2D["B`@("!(;W)D93HZ:6YL:6YE4V-R
M:7!T1FEL97,H*3L*("`@(&5C:&\@)'1R964M/G)E;F1E<DYO9&5$969I;FET
M:6]N<R@I.PH@("`@97AI=#L*?0H*)')T;"`](&ES<V5T*"1N;'-;)W)T;"==
M6R1L86YG=6%G95TI.PHD8F]D>4-L87-S(#T@)W-I9&5B87(G.PII9B`H)&)R
M;W=S97(M/FAA<U%U:7)K*"=S8W)O;&QB87)?:6Y?=V%Y)RDI('L*("`@("1B
M;V1Y0VQA<W,@+CT@)R!S8W)O;&QB87(M<75I<FLG.PI]"DAO<F1E.CIA9&13
M8W)I<'1&:6QE*"=H='1P8VQI96YT+FIS)RP@)VAO<F1E)RP@=')U92D["DAO
M<F1E.CIA9&138W)I<'1&:6QE*"=H:61E86)L92YJ<R<L("=H;W)D92<L('1R
M=64I.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+6AE861E
M<BYI;F,G.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O<&]R=&%L+W-I
M9&5B87(N:6YC)SL*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]P;W)T
M86PO:6YD97@N<&AP````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#,P,3`@,3`U,34T,S,W-#0@,#(R-#<W`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z
M(&AO<F1E+W-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`L=B`Q+C,Y+C$P+C<@
M,C`P-B\P,R\P."`Q.#HP,#HU-B!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P,RTR,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN
M8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H)TA/4D1%7T)!4T4G
M+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXO+BXG*3L*<F5Q=6ER95]O;F-E
M($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G
M2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`G.PIR97%U:7)E7V]N8V4@)TAO
M<F1E+T)L;V-K+TQA>6]U="]6:65W+G!H<"<["G)E<75I<F5?;VYC92`G2&]R
M9&4O261E;G1I='DN<&AP)SL*"FEF("@A075T:#HZ:7-!=71H96YT:6-A=&5D
M*"DI('L*("`@($AO<F1E.CIA=71H96YT:6-A=&EO;D9A:6QU<F52961I<F5C
M="@I.PI]"@HO+R!'970@9G5L;"!N86UE(&9O<B!T:71L90HD:61E;G1I='D@
M/2`F261E;G1I='DZ.G-I;F=L971O;B@I.PHD9G5L;&YA;64@/2`D:61E;G1I
M='DM/F=E=%9A;'5E*"=F=6QL;F%M92<I.PII9B`H96UP='DH)&9U;&QN86UE
M*2D@>PH@("`@)&9U;&QN86UE(#T@075T:#HZ9V5T075T:"@I.PI]"@HO+R!'
M970@<F5F<F5S:"!I;G1E<G9A;"X*:68@*"1P<F5F<RT^9V5T5F%L=64H)W-U
M;6UA<GE?<F5F<F5S:%]T:6UE)RDI('L*("`@("1R969R97-H7W1I;64@/2`D
M<')E9G,M/F=E=%9A;'5E*"=S=6UM87)Y7W)E9G)E<VA?=&EM92<I.PH@("`@
M)')E9G)E<VA?=7)L(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=S97)V:6-E
M<R]P;W)T86PO)RD["GT*"B\O($QO860@;&%Y;W5T(&9R;VT@<')E9F5R96YC
M97,N"B1L87EO=71?<')E9B`]("1P<F5F<RT^9V5T5F%L=64H)W!O<G1A;%]L
M87EO=70G*3L*:68@*"$D;&%Y;W5T7W!R968I('L*("`@("1L87EO=71?<')E
M9B`]($AO<F1E7T)L;V-K7T-O;&QE8W1I;VXZ.F=E=$9I>&5D0FQO8VMS*"D[
M"GT*)'9I97<@/2!N97<@2&]R9&5?0FQO8VM?3&%Y;W5T7U9I97<H)&QA>6]U
M=%]P<F5F*3L*)&QA>6]U=%]H=&UL(#T@)'9I97<M/G1O2'1M;"@I.PHD8W-S
M07!P<R`]("1V:65W+3YG971!<'!L:6-A=&EO;G,H*3L*)&QI;FM486=S(#T@
M)'9I97<M/F=E=$QI;FM486=S*"D["@HD=&ET;&4@/2!?*")->2!0;W)T86PB
M*3L*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUH96%D97(N
M:6YC)SL*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+W!O<G1A;"]M96YU
M+FEN8R<["B1N;W1I9FEC871I;VXM/FYO=&EF>2AA<G)A>2@G;&ES=&5N97)S
M)R`]/B`G<W1A='5S)RDI.PIE8VAO("1L87EO=71?:'1M;#L*<F5Q=6ER92!(
M3U)$15]414U03$%415,@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'``````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#(R
M-3`T(#$P-3$U-#,S-S0T(#`R,C<P-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D
M92]S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<"QV(#$N,RXR+C8@,C`P-B\P
M-2\R.2`Q-CHT,#HT.2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#4M
M,C`P-B!+87)S=&5N($9O=7)M;VYT(#QK87)S=&5N0&AO<F1E+F]R9SX*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J+PH*9G5N8W1I;VX@;&]A9$-A=&5G;W)I97,H)&1E=FEC
M92D*>PH@("`@9VQO8F%L("1D="P@)&-A=&5G;W)I97--87`L("1M:7-S:6YG
M4V5R=F5R0V%T96=O<FEE<SL*("`@("1M87`@/2`D9'0M/F=E=$]B:F5C="@D
M9&5V:6-E"B`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)SIC871E9V]R
M:65S)RD["B`@("!I9B`H:7-?82@D;6%P+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("1C871E9V]R:65S36%P
M(#T@)&UA<"T^9V5T*"=M87`G*3L*("`@("1M:7-S:6YG4V5R=F5R0V%T96=O
M<FEE<R`]("1M87`M/F=E="@G;6ES<VEN9U-E<G9E<D-A=&5G;W)I97,G*3L*
M"B`@("!R971U<FX@=')U93L*?0H*9G5N8W1I;VX@<W1O<F5#871E9V]R:65S
M*"1D979I8V4I"GL*("`@(&=L;V)A;"`D9'0L("1C871E9V]R:65S36%P+"`D
M;6ES<VEN9U-E<G9E<D-A=&5G;W)I97,["@H@("`@:68@*"%I<U]A<G)A>2@D
M8V%T96=O<FEE<TUA<"DI('L*("`@("`@("!R971U<FX[("\O(&YO=&AI;F<@
M=&\@9&\*("`@('T*"B`@("`D;6%P(#T@)FYE=R!$871A5')E94]B:F5C="@D
M9&5V:6-E("X@)SIC871E9V]R:65S)RD["B`@("`D;6%P+3YS970H)VUA<"<L
M("1C871E9V]R:65S36%P*3L*("`@("1M87`M/G-E="@G;6ES<VEN9U-E<G9E
M<D-A=&5G;W)I97,G+"`D;6ES<VEN9U-E<G9E<D-A=&5G;W)I97,I.PH*("`@
M("1R(#T@)&1T+3YA9&0H)&UA<"D["B`@("!I9B`H:7-?82@D<BP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("\O($]B:F5C="!A;')E861Y(&5X:7-T<SH@
M=7!D871E(&EN<W1E860N"B`@("`@("`@)'(@/2`D9'0M/G5P9&%T941A=&$H
M)&UA<"D["B`@("!]"GT*"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE
M*%]?1DE,15]?*2`N("<O+BXO+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!
M4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O4')E
M9G,O54DN<&AP)SL*"FEF("@A075T:#HZ:7-!=71H96YT:6-A=&5D*"DI('L*
M("`@($AO<F1E.CIA=71H96YT:6-A=&EO;D9A:6QU<F52961I<F5C="@I.PI]
M"@HD9')I=F5R(#T@)$=,3T)!3%-;)V-O;F8G75LG9&%T871R964G75LG9')I
M=F5R)UT["B1P87)A;7,@/2!(;W)D93HZ9V5T1')I=F5R0V]N9FEG*"=D871A
M=')E92<L("1D<FEV97(I.PHD<&%R86US(#T@87)R87E?;65R9V4H)'!A<F%M
M<RP@87)R87DH("=G<F]U<"<@/3X@)W-Y;F-M;"<@*2D["@HD9'0@/2`F1&%T
M851R964Z.G-I;F=L971O;B@D9')I=F5R+"`D<&%R86US*3L*"B\J(%5S97)N
M86UE(&ES('5S960@87,@<F]O="!F;W(@<WEN8VUL(&1A=&%T<F5E+B`@*$9O
M<B!H:7-T;W)I8PH@*B!R96%S;VYS+BD@*B\*)'5S97)N86UE(#T@075T:#HZ
M9V5T075T:"@I.PHD9W)O=7`@/2`G<WEN8VUL)SL@+R\@<')E9F5R96YC92!G
M<F]U<`H*)&%C=&EO;DE$(#T@571I;#HZ9V5T1F]R;41A=&$H)V%C=&EO;DE$
M)RD["G-W:71C:"`H)&%C=&EO;DE$*2!["F-A<V4@)V1E;&5T96%N8VAO<B<Z
M"B`@("`D9&5V:6-E:60@/2!5=&EL.CIG971&;W)M1&%T82@G9&5V:6-E:60G
M*3L*("`@("1D8B`](%5T:6PZ.F=E=$9O<FU$871A*"=D8B<I.PH@("`@)&ED
M(#T@)'5S97)N86UE("X@)SHG("X@)&1E=FEC96ED("X@)SIS=6UM87)Y.B<@
M+B`D9&(["B`@("`D:60@/2`D9'0M/G)E;6]V92@D:60L9F%L<V4I.PH@("`@
M:68@*&ES7V$H)&ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@)&YO=&EF
M:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(D5R<F]R(&1E;&5T:6YG('-Y;F,@
M86YC:&]R.B`E<R(I+"`D:60M/F=E=$UE<W-A9V4H*2DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G:&]R9&4N97)R;W(G*3L*("`@('T@96QS92![
M"B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*"(D:60@4WEN8R!A;F-H
M;W(@9F]R(&1E=FEC92`G)&1E=FEC96ED)R!D871A8F%S92`G)&1B)R!D96QE
M=&5D+B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAO<F1E+G-U
M8V-E<W,G*3L*("`@('T*("`@(&)R96%K.PH*8V%S92`G9&5L971E;&]G)SH*
M("`@("1I9"`]("1D="T^<F5M;W9E*"=P<F5V:6]U<U-Y;F-,;V<G+"!F86QS
M92D["B`@("!I9B`H:7-?82@D:60L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B17)R;W(@9&5L971I
M;F<@<WEN8R!L;V<Z("5S(BDL("1I9"T^9V5T365S<V%G92@I*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=H;W)D92YE<G)O<B<I.PH@("`@?2!E
M;'-E('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(E-Y;F,@;&]G
M(&1E;&5T960B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=H;W)D
M92YS=6-C97-S)RD["B`@("!]"B`@("!B<F5A:SL*"B!C87-E("=U<&1A=&5?
M8V%T96=O<FEE<R<Z"B`@("`D9&5V:6-E(#T@571I;#HZ9V5T1F]R;41A=&$H
M)V1E=FEC92<I.PH@("`@;&]A9$-A=&5G;W)I97,H)&1E=FEC92D["@H@("`@
M9F]R96%C:"`H)%]03U-4(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@
M:68@*'-U8G-T<B@D:V5Y+"`P+"`Y*2`]/2`G8V%T96=O<GDZ)RD@>PH@("`@
M("`@("`@("`D8V%T96=O<GD@/2!S=6)S='(H)&ME>2PY*3L*("`@("`@("`@
M("`@;&ES="@L)&-A=&5G;W)Y*2`](&5X<&QO9&4H)SHG+"`D:V5Y+#(I.PH@
M("`@("`@("`@("`D=F%L=64@/2!5=&EL.CIG971&;W)M1&%T82@D:V5Y*3L*
M("`@("`@("`@("`@)&-A=&5G;W)I97--87!;)&-A=&5G;W)Y72`]("1V86QU
M93L*("`@("`@("`@("`@=6YS970H)&UI<W-I;F=397)V97)#871E9V]R:65S
M6R1V86QU95TI.PH@("`@("`@('T*("`@('T*("`@('-T;W)E0V%T96=O<FEE
M<R@D9&5V:6-E*3L*("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B36%P<&EN
M9W,@<W1O<F5D+B(I*3L*"B`@("!B<F5A:SL*?0H*+RH@4VAO=R!T:&4@:&5A
M9&5R+B`J+PIR97%U:7)E7V]N8V4@)TAO<F1E+U!R969S+U5)+G!H<"<["G)E
M<75I<F4@2$]21$5?0D%312`N("<O8V]N9FEG+W!R969S+G!H<"<["B1A<'`@
M/2`G:&]R9&4G.PH*4')E9G-?54DZ.FAA;F1L949O<FTH)&=R;W5P+"`D<')E
M9G,I.PI0<F5F<U]523HZ9V5N97)A=&5(96%D97(H)&=R;W5P*3L*"B\O($!T
M;V1O.B!M;W9E('1H:7,@=&\@=&5M<&QA=&4*/SX*"CQF;W)M(&UE=&AO9#TB
M<&]S="(@;F%M93TB<')E9G,B(&%C=&EO;CTB/#]P:'`@96-H;R!(;W)D93HZ
M07!P;&EC871I;VY54DPH)R]S97)V:6-E<R]P<F5F<RYP:'`G*2`_/B(^"CQI
M;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%C=&EO;DE$(B!V86QU93TB=7!D
M871E7W!R969S(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)G<F]U
M<"(@=F%L=64](CP_<&AP(&5C:&\@)&=R;W5P(#\^(B`O/@H\:6YP=70@='EP
M93TB:&ED9&5N(B!N86UE/2)A<'`B('9A;'5E/2)H;W)D92(@+SX*4V]R<GDL
M(&YO(&-O;F9I9W5R86)L92!O<'1I;VYS('EE="X*4V5E(#QA(&AR968](FAT
M='`Z+R]W:6MI+FAO<F1E+F]R9R]3>6YC2&]W5&\B/E-Y;F,@2&]W5&\\+V$^
M(&9O<B!F=7)T:&5R(&EN9F]R;6%T:6]N+@H\/W!H<"`O*B`D:&5L<&QI;FL]
M)R<[("1P<F5F/2=S>6YC;6Q?8W)E871E7VQO9R<[(')E<75I<F4@)')E9VES
M=')Y+3YG970H)W1E;7!L871E<R<L("=H;W)D92<I("X@)R]P<F5F<R]C:&5C
M:V)O>"YI;F,G("HO(#\^"@H\<"!C;&%S<STB;F]W<F%P(CX*(#QI;G!U="!T
M>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB('9A;'5E/2)3879E($]P=&EO
M;G,B("\^"B`\:6YP=70@='EP93TB<F5S970B(&-L87-S/2)B=71T;VXB('9A
M;'5E/2)5;F1O($-H86YG97,B("\^"B`\:6YP=70@='EP93TB8G5T=&]N(B!C
M;&%S<STB8G5T=&]N(B!V86QU93TB4F5T=7)N('1O($]P=&EO;G,B(&]N8VQI
M8VL](F1O8W5M96YT+G!R969S+F%C=&EO;DE$+G9A;'5E/3`[(&1O8W5M96YT
M+G!R969S+F=R;W5P+G9A;'5E/2<G.R!D;V-U;65N="YP<F5F<RYS=6)M:70H
M*3LB("\^"CPO<#X*/"]F;W)M/@H\/W!H<`HD:60@/2`D9'0M/F=E=$ED*"1U
M<V5R;F%M92D["B1D979I8V5S(#T@)&1T+3YG971">4ED*$1!5$%44D5%7T9/
M4DU!5%]&3$%4+"`D:60L('1R=64L($1!5$%44D5%7U)/3U0L(#$I.PII9B`H
M:7-?87)R87DH)&1E=FEC97,I("8F(&-O=6YT*"1D979I8V5S*2`^(#$I('L*
M("`@(&%R<F%Y7W-H:69T*"1D979I8V5S*3L*"B\O($!T;V1O.B!M;W9E('1O
M('1E;7!L871E"C\^"CQD:78@8VQA<W,](FAE861E<B(^"B`\/W!H<"!E8VAO
M($AO<F1E.CIL:6YK*$AO<F1E.CIS96QF55),*"DL(%\H(E)E9G)E<V@B*2D@
M+B!(;W)D93HZ:6UG*"=R96QO860N<&YG)RP@7R@B4F5L;V%D(BDL("<G+"`D
M<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`_/CPO83X*(%1I;65S
M=&%M<',@;V8@<W5C8V5S<V9U;"!S>6YC('-E<W-I;VYS"CPO9&EV/@H\=&%B
M;&4@8VQA<W,](G-T<FEP960B(#X*(#QT<CX*("`\=&@^1&5V:6-E/"]T:#X\
M=&@^1&%T86)A<V4\+W1H/CQT:#Y397)V97(M5%,\+W1H/CQT:#Y#;&EE;G0M
M5%,\+W1H/@H@(#QT:#Y$96QE=&4\+W1H/@H@/"]T<CX*"CP_<&AP"B`@("!F
M;W)E86-H("@D9&5V:6-E<R!A<R`D9&5V:6-E*2!["B`@("`@("`@)'1M<"`]
M(&5X<&QO9&4H)SHG+"`D9&5V:6-E*3L*("`@("`@("`D9&5V:6-E7VYA;64@
M/2!A<G)A>5]P;W`H)'1M<"D["@H@("`@("`@("1I9"`]("1D="T^9V5T260H
M)&1E=FEC92`N("<Z<W5M;6%R>2<I.PH@("`@("`@(&EF("AI<U]A*"1I9"P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@
M("!]"B`@("`@("`@)'-U;6UA<FEE<R`]("1D="T^9V5T0GE)9"A$051!5%)%
M15]&3U)-051?5%)%12P@)&ED+"!F86QS92P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@($1!5$%44D5%7U)/3U0L(#(I.PH*("`@("`@("!I
M9B`H:7-?87)R87DH)'-U;6UA<FEE<ULD:61=*2D@>PH@("`@("`@("`@("`D
M;R`]("8@)&1T+3YG971/8FIE8W1S*&%R<F%Y7VME>7,H)'-U;6UA<FEE<ULD
M:61=*2D["@H@("`@("`@("`@("!F;W)E86-H("@D;R!A<R`D;V\I('L*("`@
M("`@("`@("`@("`@("1T(#T@97AP;&]D92@G.B<L("1O;RT^9V5T3F%M92@I
M*3L*("`@("`@("`@("`@("`@("1D8B`](&%R<F%Y7W!O<"@D="D["B`@("`@
M("`@("`@("`@("`D<V$@/2`D;V\M/F=E="@G4V5R=F5R06YC:&]R)RD["B`@
M("`@("`@("`@("`@("`D8V$@/2`D;V\M/F=E="@B0VQI96YT06YC:&]R(BD[
M"@H@("`@("`@("`@("`@("`@+R\@0'1O9&\Z(&UO=F4@=&\@=&5M<&QA=&4*
M("`@("`@("`@("`@("`@(&5C:&\@)SQT<CX\=&0^)R`N("1D979I8V5?;F%M
M92`N("<\+W1D/CQT9#XG("X@)&1B("X@)SPO=&0^/'1D/B<@+@H@("`@("`@
M("`@("`@("`@("`@('-T<F9T:6UE*"1P<F5F<RT^9V5T5F%L=64H)V1A=&5?
M9F]R;6%T)RD@+B`G("5(.B5-)RP@87)R87E?<&]P*"1S82DI("X*("`@("`@
M("`@("`@("`@("`@("`G/"]T9#X\=&0^)R`N(&%R<F%Y7W!O<"@D8V$I("X@
M)SPO=&0^/'1D/B<@+@H@("`@("`@("`@("`@("`@("`@("<\9F]R;2!M971H
M;V0](G!O<W0B/CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F1E=FEC96ED
M(B!V86QU93TB)R`N"B`@("`@("`@("`@("`@("`@("`@)&1E=FEC95]N86UE
M("X@)R(O/B<@+@H@("`@("`@("`@("`@("`@("`@("<\:6YP=70@='EP93TB
M:&ED9&5N(B!N86UE/2)A8W1I;VY)1"(@=F%L=64](F1E;&5T96%N8VAO<B(@
M+SXG("X*("`@("`@("`@("`@("`@("`@("`G/&EN<'5T('1Y<&4](FAI9&1E
M;B(@;F%M93TB9&(B('9A;'5E/2(G("X@)&1B("X@)R(@+SXG("X*("`@("`@
M("`@("`@("`@("`@("`G/&EN<'5T('1Y<&4](G-U8FUI="(@8VQA<W,](F)U
M='1O;B(@=F%L=64](D1E;&5T92(@+SX\+V9O<FT^)R`N"B`@("`@("`@("`@
M("`@("`@("`@)SPO=&0^/"]T<CXG.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@?0H@("`@96-H;R`G/"]T86)L93XG.PI]"@HO+R!#871E9V]R>2!H
M86YD;&EN9RX*<F5Q=6ER95]O;F-E("=(;W)D92]0<F5F<R]#871E9V]R>4UA
M;F%G97(N<&AP)SL*)&--86YA9V5R(#T@)FYE=R!0<F5F<U]#871E9V]R>4UA
M;F%G97(H*3L*"F9O<F5A8V@@*"1D979I8V5S(&%S("1D979I8V4I('L*("`@
M("1T;7`@/2!E>'!L;V1E*"<Z)RP@)&1E=FEC92D["B`@("`D9&5V:6-E7VYA
M;64@/2!A<G)A>5]P;W`H)'1M<"D["@H@("`@:68@*"%L;V%D0V%T96=O<FEE
M<R@D9&5V:6-E*2D@>PH@("`@("`@(&-O;G1I;G5E.PH@("`@?0HO+W9A<E]D
M=6UP*"1C;&EE;@H@("`@)&D@/2`P.PHO+R!`=&]D;SH@;6]V92!T;R!T96UP
M;&%T90H_/@H\9F]R;2!M971H;V0](G!O<W0B(&YA;64](G!R969S(B!A8W1I
M;VX](CP_<&AP(&5C:&\@2&]R9&4Z.G-E;&954DPH*2`_/B(^"CQI;G!U="!T
M>7!E/2)H:61D96XB(&YA;64](F%C=&EO;DE$(B!V86QU93TB=7!D871E7V-A
M=&5G;W)I97,B("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F1E=FEC
M92(@=F%L=64](CP_<&AP(&5C:&\@)&1E=FEC92`_/B(@+SX*"CQD:78@8VQA
M<W,](FAE861E<B(^"B`\/W!H<"!E8VAO($AO<F1E.CIL:6YK*$AO<F1E.CIS
M96QF55),*"DL(%\H(E)E9G)E<V@B*2D@+B!(;W)D93HZ:6UG*"=R96QO860N
M<&YG)RP@7R@B4F5L;V%D(BDL("<G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER
M*"=H;W)D92<I*2`_/CPO83X*($UA<'!I;F<@;V8@0V%T96=O<FEE<R!F;W(@
M1&5V:6-E(#P_<&AP(&5C:&\@)&1E=FEC95]N86UE(#\^"CPO9&EV/@H\=&%B
M;&4@8VQA<W,](G-T<FEP960B(#X*/'1R/CQT:#Y$979I8V4@0V%T96=O<GD\
M+W1H/CQT:#Y(;W)D92!#871E9V]R>3PO=&@^"CQT:#Y3=6UM87)Y(&]F(&QA
M<W0@96YC;W5N=&5R960@96YT<GD\+W1H/CPO='(^"CP_<&AP"B`@("!F;W)E
M86-H("@D8V%T96=O<FEE<TUA<"!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@
M("`@(&5C:&\@(CQT<B!C;&%S<SU<(FET96TB("X@*"LK)&D@)2`R*2`N(")<
M(CX\=&0^(@H@("`@("`@("X@)&ME>2X@)SPO=&0^/'1D/B<["B`@("`@("`@
M)'8@/2!I<U]A<G)A>2@D=F%L=64I(#\@)R<@.B`D=F%L=64["B`@("`@("`@
M96-H;R`D8TUA;F%G97(M/F=E=%-E;&5C="@G8V%T96=O<GDZ)R`N("1K97DL
M("1V*3L*("`@("`@("!E8VAO("<\+W1D/CQT9#XG.PH@("`@("`@(&EF("AI
M<U]A<G)A>2@D=F%L=64I*2!["B`@("`@("`@("`@(&5C:&\@)'9A;'5E6S!=
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&5C:&\@(B9N8G-P.R([
M"B`@("`@("`@?0H@("`@("`@(&5C:&\@)SPO=&0^/"]T<CXG.PH*("`@('T*
M("`@(&9O<F5A8V@@*"1M:7-S:6YG4V5R=F5R0V%T96=O<FEE<R!A<R`D:V5Y
M(#T^("1V86QU92D@>PH@("`@("`@(&5C:&\@)SQT<CX\=&0^/&5M/G1O(&)E
M(&1E9FEN960\+V5M/CPO=&0^/'1D/B<@+B`D:V5Y("X@)SPO=&0^/'1D/B<@
M+B`D=F%L=64@+B`G/"]T9#X\+W1R/B<["B`@("!]"@H@("`@96-H;R`B/"]T
M86)L93Y<;B(["B`@("!E8VAO("<\:6YP=70@='EP93TB<W5B;6ET(B!C;&%S
M<STB8G5T=&]N(B!V86QU93TB57!D871E($-A=&5G;W)I97,B("\^/"]F;W)M
M/B<["GT*"B\J($1I<W!L87D@;&]G(&]F('!R979I;W5S('-Y;F,N("HO"B1N
M86UE(#T@)W!R979I;W5S4WEN8TQO9R<["B1I;F9O(#T@)B1D="T^9V5T3V)J
M96-T*"1N86UE*3L*"FEF("@A:7-?82@D:6YF;RP@)U!%05)?17)R;W(G*2`F
M)B!I<U]A<G)A>2@D;&]G(#T@)&EN9F\M/F=E="@G;&]G)RDI*2!["B`@("`O
M+R!`=&]D;R!M;W9E('1O('1E;7!L871E"C\^"CQD:78@8VQA<W,](FAE861E
M<B(^"B`\/W!H<"!E8VAO(%\H(DQO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I
M;VXB*2`_/@H@/#]P:'`@96-H;R!(;W)D93HZ;&EN:RA(;W)D93HZ<V5L9E52
M3"@I+"!?*")2969R97-H(BDI("X@2&]R9&4Z.FEM9R@G<F5L;V%D+G!N9R<L
M(%\H(E)E9G)E<V@B*2D@/SX\+V$^"B`\9F]R;2!M971H;V0](G!O<W0B/@H@
M(#QI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%C=&EO;DE$(B!V86QU93TB
M9&5L971E;&]G(B`O/@H@(#QI;G!U="!T>7!E/2)S=6)M:70B(&-L87-S/2)B
M=71T;VXB('9A;'5E/2(\/W!H<"!E8VAO(%\H(D1E;&5T92!,;V<B*2`_/B(@
M+SX*(#PO9F]R;3X*/"]D:78^"@H\=&%B;&4@8VQA<W,](G-T<FEP960B('=I
M9'1H/2(Q,#`E(CX*(#QT<B!C;&%S<STB;F]W<F%P(CX*("`\=&@@=VED=&@]
M(C4E(CX\/W!H<"!E8VAO(%\H(E1I;64B*2`_/CPO=&@^/'1H/CP_<&AP(&5C
M:&\@7R@B3&5V96PB*2`_/CPO=&@^/'1H/CP_<&AP(&5C:&\@7R@B1FEL92(I
M(#\^/"]T:#X\=&@^/#]P:'`@96-H;R!?*")-97-S86=E(BD@/SX\+W1H/@H@
M/"]T<CX*/#]P:'`@9F]R96%C:"`H)&QO9R!A<R`D;&]G96YT<GDI.B`_/@H@
M/'1R/@H@(#QT9#X*("`@/#]P:'`@96-H;R!S=')F=&EM92@D<')E9G,M/F=E
M=%9A;'5E*"=D871E7V9O<FUA="<I("X@)R`E2#HE33HE4R<L("1L;V=E;G1R
M>5LG=',G72D@/SX*("`\+W1D/@H@(#QT9#X*("`@/#]P:'`@96-H;R!H=&UL
M<W!E8VEA;&-H87)S*"1L;V=E;G1R>5LG;&5V96PG72D@/SX*("`\+W1D/@H@
M(#QT9#X*("`\/W!H<`H@(&EF("AP<F5G7VUA=&-H*"<O7"]3>6YC34Q<+G!H
M<"0O)RP@)&QO9V5N=')Y6R=F:6QE)UTI*2!["B`@("`@("1F:6QE(#T@)V9R
M86UE=V]R:R]3>6YC34PO4WEN8TU,+G!H<"<["B`@?2!E;'-E('L*("`@("`@
M)&9I;&4@/2!P<F5G7W)E<&QA8V4H)R]>+BI<+U-Y;F--3%PO*"XJ*20O)RP@
M)V9R86UE=V]R:R]3>6YC34PO4WEN8TU,+R0Q)RP@)&QO9V5N=')Y6R=F:6QE
M)UTI.PH@('T*("!E8VAO($AO<F1E.CIL:6YK*"=H='1P.B\O8W9S+FAO<F1E
M+F]R9R]C;RYP:'`O)PH@("`@("`@("`@("`@("`@("`@+B`D9FEL92`@+B`G
M/W(]2$5!1",G("X@=')I;2@D;&]G96YT<GE;)VQI;F4G72DL("<G+"`G)RP@
M)V-V<R<I"B`@("`@("X@<')E9U]R97!L86-E*"<O7BXJ7"\H6UY<+UTJ*20O
M)RP@)R0Q)RP@)&QO9V5N=')Y6R=F:6QE)UTI"B`@("`@("X@)SHG("X@=')I
M;2@D;&]G96YT<GE;)VQI;F4G72D*("`_/@H@(#PO=&0^"B`@/'1D/@H@("`\
M/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&QO9V5N=')Y6R=M97-S86=E
M)UTI(#\^"B`@/"]T9#X*(#PO='(^"CP_<&AP(&5N9&9O<F5A8V@[(#\^"CPO
M=&%B;&4^"@H\/W!H<`I]"@IR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O
M8V]M;6]N+69O;W1E<BYI;F,G.PH`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W-E<G9I8V5S+W-H87)E<P``````````````````````````````
M```````````````````````````````````````````````````P,#`W-34@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<T-"`P,C`U
M-S(`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O<VAA<F5S+V5D:70N
M<&AP````````````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#(S,3`W
M(#$P-3$U-#,S-S0T(#`R,C,Q,@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]S
M97)V:6-E<R]S:&%R97,O961I="YP:'`L=B`Q+C(V+C$P+C@@,C`P-B\P-2\P
M,2`R,3HQ-CHT,2!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR
M,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J+PH*)&9I96QD<TQI<W1;)W-H;W<G72`](#`["B1F:65L9'-,
M:7-T6R=R96%D)UT@/2`Q.PHD9FEE;&1S3&ES=%LG961I="==(#T@,CL*)&9I
M96QD<TQI<W1;)V1E;&5T92==(#T@,SL*"D!D969I;F4H)TA/4D1%7T)!4T4G
M+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXO+BXG*3L*<F5Q=6ER95]O;F-E
M($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G
M2&]R9&4O365N=2YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+U-H87)E+G!H
M<"<["G)E<75I<F5?;VYC92`G2&]R9&4O1W)O=7`N<&AP)SL*"B1A<'`@/2!5
M=&EL.CIG971&;W)M1&%T82@G87!P)RD["B1S:&%R97,@/2`F2&]R9&5?4VAA
M<F4Z.G-I;F=L971O;B@D87!P*3L*)&=R;W5P<R`]("9'<F]U<#HZ<VEN9VQE
M=&]N*"D["B1A=71H(#T@)D%U=&@Z.G-I;F=L971O;B@D8V]N9ELG875T:"==
M6R=D<FEV97(G72D["@HD9F]R;2`](&YU;&P["B1R96QO860@/2!F86QS93L*
M)&%C=&EO;DE$(#T@571I;#HZ9V5T1F]R;41A=&$H)V%C=&EO;DE$)RP@)V5D
M:70G*3L*<W=I=&-H("@D86-T:6]N240I('L*8V%S92`G961I="<Z"B`@("`D
M<VAA<F4@/2`F)'-H87)E<RT^9V5T4VAA<F5">4ED*%5T:6PZ.F=E=$9O<FU$
M871A*"=C:60G*2D["B`@("!I9B`H(6ES7V$H)'-H87)E+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@)&9O<FT@/2`G961I="YI;F,G.PH@("`@("`@("1P
M97)M(#T@)B1S:&%R92T^9V5T4&5R;6ES<VEO;B@I.PH@("`@?2!E;'-E:68@
M*"@D8V%T96=O<GD@/2!5=&EL.CIG971&;W)M1&%T82@G<VAA<F4G*2D@(3T]
M(&YU;&PI('L*("`@("`@("`D<VAA<F4@/2`F)'-H87)E<RT^9V5T4VAA<F4H
M)&-A=&5G;W)Y*3L*("`@("`@("!I9B`H(6ES7V$H)'-H87)E+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("1F;W)M(#T@)V5D:70N:6YC)SL*("`@
M("`@("`@("`@)'!E<FT@/2`F)'-H87)E+3YG971097)M:7-S:6]N*"D["B`@
M("`@("`@?0H@("`@?0H@("`@:68@*&ES7V$H)'-H87)E+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D<VAA<F4L("=H
M;W)D92YE<G)O<B<I.PH@("`@?2!E;'-E:68@*&ES<V5T*"1S:&%R92D@)B8@
M075T:#HZ9V5T075T:"@I("$]("1S:&%R92T^9V5T*"=O=VYE<B<I*2!["B`@
M("`@("`@97AI="@G<&5R;6ES<VEO;B!D96YI960G*3L*("`@('T*("`@(&)R
M96%K.PH*8V%S92`G961I=&9O<FTG.@H@("`@)'-H87)E(#T@)B1S:&%R97,M
M/F=E=%-H87)E0GE)9"A5=&EL.CIG971&;W)M1&%T82@G8VED)RDI.PH@("`@
M:68@*&ES7V$H)'-H87)E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@)&YO
M=&EF:6-A=&EO;BT^<'5S:"A?*")!='1E;7!T('1O(&5D:70@82!N;VXM97AI
M<W1E;G0@<VAA<F4N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@?2!E;'-E('L*
M("`@("`@("!I9B`H075T:#HZ9V5T075T:"@I("$]("1S:&%R92T^9V5T*"=O
M=VYE<B<I*2!["B`@("`@("`@("`@(&5X:70H)W!E<FUI<W-I;VX@9&5N:65D
M)RD["B`@("`@("`@?0H@("`@("`@("1P97)M(#T@)B1S:&%R92T^9V5T4&5R
M;6ES<VEO;B@I.PH*("`@("`@("`O+R!0<F]C97-S(&]W;F5R(&%N9"!O=VYE
M<B!P97)M:7-S:6]N<RX*("`@("`@("`D;VQD7V]W;F5R(#T@)'-H87)E+3YG
M970H)V]W;F5R)RD["B`@("`@("`@)&YE=U]O=VYE<B`](%5T:6PZ.F=E=$9O
M<FU$871A*"=O=VYE<B<L("1O;&1?;W=N97(I.PH@("`@("`@(&EF("@D;VQD
M7V]W;F5R("$]/2`D;F5W7V]W;F5R("8F("%E;7!T>2@D;F5W7V]W;F5R*2D@
M>PH@("`@("`@("`@("!I9B`H)&]L9%]O=VYE<B`A/2!!=71H.CIG971!=71H
M*"D@)B8@(4%U=&@Z.FES061M:6XH*2D@>PH@("`@("`@("`@("`@("`@)&YO
M=&EF:6-A=&EO;BT^<'5S:"A?*")/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@
M861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P
M97)M:7-S:6]N<R!F;W(@82!S:&%R92(I+"`G:&]R9&4N97)R;W(G*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1S:&%R92T^<V5T
M*"=O=VYE<B<L("1N97=?;W=N97(I.PH@("`@("`@("`@("`@("`@)'-H87)E
M+3YS879E*"D["B`@("`@("`@("`@("`@("!I9B`H571I;#HZ9V5T1F]R;41A
M=&$H)V]W;F5R7W-H;W<G*2D@>PH@("`@("`@("`@("`@("`@("`@("1P97)M
M+3YA9&15<V5R4&5R;6ES<VEO;B@D;F5W7V]W;F5R+"!015)-4U]32$]7+"!F
M86QS92D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("1P97)M+3YR96UO=F55<V5R4&5R;6ES<VEO;B@D;F5W7V]W;F5R
M+"!015)-4U]32$]7+"!F86QS92D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!I9B`H571I;#HZ9V5T1F]R;41A=&$H)V]W;F5R7W)E860G
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1P97)M+3YA9&15<V5R4&5R;6ES
M<VEO;B@D;F5W7V]W;F5R+"!015)-4U]214%$+"!F86QS92D["B`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1P97)M+3YR
M96UO=F55<V5R4&5R;6ES<VEO;B@D;F5W7V]W;F5R+"!015)-4U]214%$+"!F
M86QS92D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H
M571I;#HZ9V5T1F]R;41A=&$H)V]W;F5R7V5D:70G*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1P97)M+3YA9&15<V5R4&5R;6ES<VEO;B@D;F5W7V]W;F5R
M+"!015)-4U]%1$E4+"!F86QS92D["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("1P97)M+3YR96UO=F55<V5R4&5R;6ES
M<VEO;B@D;F5W7V]W;F5R+"!015)-4U]%1$E4+"!F86QS92D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H571I;#HZ9V5T1F]R;41A
M=&$H)V]W;F5R7V1E;&5T92<I*2!["B`@("`@("`@("`@("`@("`@("`@)'!E
M<FTM/F%D9%5S97)097)M:7-S:6]N*"1N97=?;W=N97(L(%!%4DU37T1%3$54
M12P@9F%L<V4I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`D<&5R;2T^<F5M;W9E57-E<E!E<FUI<W-I;VXH)&YE=U]O
M=VYE<BP@4$5235-?1$5,151%+"!F86QS92D["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O(%!R;V-E<W,@
M9&5F875L="!P97)M:7-S:6]N<RX*("`@("`@("!I9B`H571I;#HZ9V5T1F]R
M;41A=&$H)V1E9F%U;'1?<VAO=R<I*2!["B`@("`@("`@("`@("1P97)M+3YA
M9&1$969A=6QT4&5R;6ES<VEO;BA015)-4U]32$]7+"!F86QS92D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'!E<FTM/G)E;6]V941E9F%U;'10
M97)M:7-S:6]N*%!%4DU37U-(3U<L(&9A;'-E*3L*("`@("`@("!]"B`@("`@
M("`@:68@*%5T:6PZ.F=E=$9O<FU$871A*"=D969A=6QT7W)E860G*2D@>PH@
M("`@("`@("`@("`D<&5R;2T^861D1&5F875L=%!E<FUI<W-I;VXH4$5235-?
M4D5!1"P@9F%L<V4I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P
M97)M+3YR96UO=F5$969A=6QT4&5R;6ES<VEO;BA015)-4U]214%$+"!F86QS
M92D["B`@("`@("`@?0H@("`@("`@(&EF("A5=&EL.CIG971&;W)M1&%T82@G
M9&5F875L=%]E9&ET)RDI('L*("`@("`@("`@("`@)'!E<FTM/F%D9$1E9F%U
M;'1097)M:7-S:6]N*%!%4DU37T5$250L(&9A;'-E*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D<&5R;2T^<F5M;W9E1&5F875L=%!E<FUI<W-I
M;VXH4$5235-?141)5"P@9F%L<V4I.PH@("`@("`@('T*("`@("`@("!I9B`H
M571I;#HZ9V5T1F]R;41A=&$H)V1E9F%U;'1?9&5L971E)RDI('L*("`@("`@
M("`@("`@)'!E<FTM/F%D9$1E9F%U;'1097)M:7-S:6]N*%!%4DU37T1%3$54
M12P@9F%L<V4I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P97)M
M+3YR96UO=F5$969A=6QT4&5R;6ES<VEO;BA015)-4U]$14Q%5$4L(&9A;'-E
M*3L*("`@("`@("!]"@H@("`@("`@("\O(%!R;V-E<W,@9W5E<W0@<&5R;6ES
M<VEO;G,N"B`@("`@("`@:68@*%5T:6PZ.F=E=$9O<FU$871A*"=G=65S=%]S
M:&]W)RDI('L*("`@("`@("`@("`@)'!E<FTM/F%D9$=U97-T4&5R;6ES<VEO
M;BA015)-4U]32$]7+"!F86QS92D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'!E<FTM/G)E;6]V94=U97-T4&5R;6ES<VEO;BA015)-4U]32$]7
M+"!F86QS92D["B`@("`@("`@?0H@("`@("`@(&EF("A5=&EL.CIG971&;W)M
M1&%T82@G9W5E<W1?<F5A9"<I*2!["B`@("`@("`@("`@("1P97)M+3YA9&1'
M=65S=%!E<FUI<W-I;VXH4$5235-?4D5!1"P@9F%L<V4I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1P97)M+3YR96UO=F5'=65S=%!E<FUI<W-I
M;VXH4$5235-?4D5!1"P@9F%L<V4I.PH@("`@("`@('T*("`@("`@("!I9B`H
M571I;#HZ9V5T1F]R;41A=&$H)V=U97-T7V5D:70G*2D@>PH@("`@("`@("`@
M("`D<&5R;2T^861D1W5E<W1097)M:7-S:6]N*%!%4DU37T5$250L(&9A;'-E
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<&5R;2T^<F5M;W9E
M1W5E<W1097)M:7-S:6]N*%!%4DU37T5$250L(&9A;'-E*3L*("`@("`@("!]
M"B`@("`@("`@:68@*%5T:6PZ.F=E=$9O<FU$871A*"=G=65S=%]D96QE=&4G
M*2D@>PH@("`@("`@("`@("`D<&5R;2T^861D1W5E<W1097)M:7-S:6]N*%!%
M4DU37T1%3$5412P@9F%L<V4I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1P97)M+3YR96UO=F5'=65S=%!E<FUI<W-I;VXH4$5235-?1$5,151%
M+"!F86QS92D["B`@("`@("`@?0H*("`@("`@("`O+R!0<F]C97-S(&-R96%T
M;W(@<&5R;6ES<VEO;G,N"B`@("`@("`@:68@*%5T:6PZ.F=E=$9O<FU$871A
M*"=C<F5A=&]R7W-H;W<G*2D@>PH@("`@("`@("`@("`D<&5R;2T^861D0W)E
M871O<E!E<FUI<W-I;VXH4$5235-?4TA/5RP@9F%L<V4I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1P97)M+3YR96UO=F5#<F5A=&]R4&5R;6ES
M<VEO;BA015)-4U]32$]7+"!F86QS92D["B`@("`@("`@?0H@("`@("`@(&EF
M("A5=&EL.CIG971&;W)M1&%T82@G8W)E871O<E]R96%D)RDI('L*("`@("`@
M("`@("`@)'!E<FTM/F%D9$-R96%T;W)097)M:7-S:6]N*%!%4DU37U)%040L
M(&9A;'-E*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<&5R;2T^
M<F5M;W9E0W)E871O<E!E<FUI<W-I;VXH4$5235-?4D5!1"P@9F%L<V4I.PH@
M("`@("`@('T*("`@("`@("!I9B`H571I;#HZ9V5T1F]R;41A=&$H)V-R96%T
M;W)?961I="<I*2!["B`@("`@("`@("`@("1P97)M+3YA9&1#<F5A=&]R4&5R
M;6ES<VEO;BA015)-4U]%1$E4+"!F86QS92D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'!E<FTM/G)E;6]V94-R96%T;W)097)M:7-S:6]N*%!%
M4DU37T5$250L(&9A;'-E*3L*("`@("`@("!]"B`@("`@("`@:68@*%5T:6PZ
M.F=E=$9O<FU$871A*"=C<F5A=&]R7V1E;&5T92<I*2!["B`@("`@("`@("`@
M("1P97)M+3YA9&1#<F5A=&]R4&5R;6ES<VEO;BA015)-4U]$14Q%5$4L(&9A
M;'-E*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<&5R;2T^<F5M
M;W9E0W)E871O<E!E<FUI<W-I;VXH4$5235-?1$5,151%+"!F86QS92D["B`@
M("`@("`@?0H*("`@("`@("`O+R!0<F]C97-S('5S97(@<&5R;6ES<VEO;G,N
M"B`@("`@("`@)'5?;F%M97,@/2!5=&EL.CIG971&;W)M1&%T82@G=5]N86UE
M<R<I.PH@("`@("`@("1U7W-H;W<@/2!5=&EL.CIG971&;W)M1&%T82@G=5]S
M:&]W)RD["B`@("`@("`@)'5?<F5A9"`](%5T:6PZ.F=E=$9O<FU$871A*"=U
M7W)E860G*3L*("`@("`@("`D=5]E9&ET(#T@571I;#HZ9V5T1F]R;41A=&$H
M)W5?961I="<I.PH@("`@("`@("1U7V1E;&5T92`](%5T:6PZ.F=E=$9O<FU$
M871A*"=U7V1E;&5T92<I.PH*("`@("`@("!F;W)E86-H("@D=5]N86UE<R!A
M<R`D:V5Y(#T^("1U<V5R*2!["B`@("`@("`@("`@("\O($EF('1H92!U<V5R
M(&ES(&5M<'1Y+"!O<B!W92=V92!A;')E861Y('-E="!P97)M:7-S:6]N<PH@
M("`@("`@("`@("`O+R!V:6$@=&AE(&]W;F5R7R!O<'1I;VYS+"!D;VXG="!D
M;R!A;GET:&EN9R!H97)E+@H@("`@("`@("`@("!I9B`H96UP='DH)'5S97(I
M('Q\("1U<V5R(#T]("1N97=?;W=N97(I('L*("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H(65M<'1Y
M*"1U7W-H;W=;)&ME>5TI*2!["B`@("`@("`@("`@("`@("`D<&5R;2T^861D
M57-E<E!E<FUI<W-I;VXH)'5S97(L(%!%4DU37U-(3U<L(&9A;'-E*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1P97)M+3YR96UO
M=F55<V5R4&5R;6ES<VEO;B@D=7-E<BP@4$5235-?4TA/5RP@9F%L<V4I.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A96UP='DH)'5?<F5A9%LD
M:V5Y72DI('L*("`@("`@("`@("`@("`@("1P97)M+3YA9&15<V5R4&5R;6ES
M<VEO;B@D=7-E<BP@4$5235-?4D5!1"P@9F%L<V4I.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)'!E<FTM/G)E;6]V955S97)097)M
M:7-S:6]N*"1U<V5R+"!015)-4U]214%$+"!F86QS92D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@:68@*"%E;7!T>2@D=5]E9&ET6R1K97E=*2D@>PH@
M("`@("`@("`@("`@("`@)'!E<FTM/F%D9%5S97)097)M:7-S:6]N*"1U<V5R
M+"!015)-4U]%1$E4+"!F86QS92D["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D<&5R;2T^<F5M;W9E57-E<E!E<FUI<W-I;VXH)'5S
M97(L(%!%4DU37T5$250L(&9A;'-E*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1U7V1E;&5T95LD:V5Y72DI('L*("`@("`@("`@
M("`@("`@("1P97)M+3YA9&15<V5R4&5R;6ES<VEO;B@D=7-E<BP@4$5235-?
M1$5,151%+"!F86QS92D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D<&5R;2T^<F5M;W9E57-E<E!E<FUI<W-I;VXH)'5S97(L(%!%
M4DU37T1%3$5412P@9F%L<V4I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("`O+R!0<F]C97-S(&=R;W5P('!E<FUI<W-I;VYS+@H@("`@("`@
M("1G7VYA;65S(#T@571I;#HZ9V5T1F]R;41A=&$H)V=?;F%M97,G*3L*("`@
M("`@("`D9U]S:&]W(#T@571I;#HZ9V5T1F]R;41A=&$H)V=?<VAO=R<I.PH@
M("`@("`@("1G7W)E860@/2!5=&EL.CIG971&;W)M1&%T82@G9U]R96%D)RD[
M"B`@("`@("`@)&=?961I="`](%5T:6PZ.F=E=$9O<FU$871A*"=G7V5D:70G
M*3L*("`@("`@("`D9U]D96QE=&4@/2!5=&EL.CIG971&;W)M1&%T82@G9U]D
M96QE=&4G*3L*"B`@("`@("`@9F]R96%C:"`H)&=?;F%M97,@87,@)&ME>2`]
M/B`D9W)O=7`I('L*("`@("`@("`@("`@:68@*&5M<'1Y*"1G<F]U<"DI('L*
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!I9B`H(65M<'1Y*"1G7W-H;W=;)&ME>5TI*2!["B`@("`@("`@
M("`@("`@("`D<&5R;2T^861D1W)O=7!097)M:7-S:6]N*"1G<F]U<"P@4$52
M35-?4TA/5RP@9F%L<V4I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)'!E<FTM/G)E;6]V94=R;W5P4&5R;6ES<VEO;B@D9W)O=7`L
M(%!%4DU37U-(3U<L(&9A;'-E*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1G7W)E861;)&ME>5TI*2!["B`@("`@("`@("`@("`@
M("`D<&5R;2T^861D1W)O=7!097)M:7-S:6]N*"1G<F]U<"P@4$5235-?4D5!
M1"P@9F%L<V4I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)'!E<FTM/G)E;6]V94=R;W5P4&5R;6ES<VEO;B@D9W)O=7`L(%!%4DU3
M7U)%040L(&9A;'-E*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1G7V5D:71;)&ME>5TI*2!["B`@("`@("`@("`@("`@("`D<&5R
M;2T^861D1W)O=7!097)M:7-S:6]N*"1G<F]U<"P@4$5235-?141)5"P@9F%L
M<V4I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'!E
M<FTM/G)E;6]V94=R;W5P4&5R;6ES<VEO;B@D9W)O=7`L(%!%4DU37T5$250L
M(&9A;'-E*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(65M<'1Y
M*"1G7V1E;&5T95LD:V5Y72DI('L*("`@("`@("`@("`@("`@("1P97)M+3YA
M9&1'<F]U<%!E<FUI<W-I;VXH)&=R;W5P+"!015)-4U]$14Q%5$4L(&9A;'-E
M*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1P97)M
M+3YR96UO=F5'<F]U<%!E<FUI<W-I;VXH)&=R;W5P+"!015)-4U]$14Q%5$4L
M(&9A;'-E*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)'-H
M87)E+3YS971097)M:7-S:6]N*"1P97)M+"!F86QS92D["B`@("`@("`@)'-H
M87)E+3YS879E*"D["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I
M;G1F*%\H(E5P9&%T960@7"(E<UPB+B(I+"`D<VAA<F4M/F=E="@G;F%M92<I
M*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@("`D9F]R;2`]("=E9&ET+FEN
M8R<["B`@("!]"B`@("!B<F5A:SL*?0H*:68@*&ES7V$H)'-H87)E+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`D=&ET;&4@/2!?*")%9&ET(%!E<FUI<W-I;VYS
M(BD["GT@96QS92!["B`@("`D=&ET;&4@/2!S<')I;G1F*%\H(D5D:70@4&5R
M;6ES<VEO;G,@9F]R("5S(BDL("1S:&%R92T^9V5T*"=N86UE)RDI.PI]"@II
M9B`H)&%U=&@M/FAA<T-A<&%B:6QI='DH)VQI<W0G*2D@>PH@("`@)'5S97),
M:7-T(#T@)&%U=&@M/FQI<W15<V5R<R@I.PH@("`@:68@*&ES7V$H)'5S97),
M:7-T+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A
M9V4H)'5S97),:7-T+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T52
M4BD["B`@("`@("`@)'5S97),:7-T(#T@87)R87DH*3L*("`@('T*("`@('-O
M<G0H)'5S97),:7-T*3L*?2!E;'-E('L*("`@("1U<V5R3&ES="`](&%R<F%Y
M*"D["GT*"B1G<F]U<$QI<W0@/2`D9W)O=7!S+3YG971'<F]U<$UE;6)E<G-H
M:7!S*$%U=&@Z.F=E=$%U=&@H*2P@=')U92D["FEF("AI<U]A*"1G<F]U<$QI
M<W0L("=014%27T5R<F]R)RDI('L*("`@($AO<F1E.CIL;V=-97-S86=E*"1G
M<F]U<$QI<W0L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?3D]424-%
M*3L*("`@("1G<F]U<$QI<W0@/2!A<G)A>2@I.PI]"F%S;W)T*"1G<F]U<$QI
M<W0I.PH*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUH96%D
M97(N:6YC)SL*)&YO=&EF:6-A=&EO;BT^;F]T:69Y*&%R<F%Y*"=L:7-T96YE
M<G,G(#T^("=S=&%T=7,G*2D["FEF("@A96UP='DH)&9O<FTI*2!["B`@("!R
M97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O<VAA<F5S+R<@+B`D9F]R;3L*
M?0H*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUF;V]T97(N
M:6YC)SL*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O9&]W;FQO860`````````
M````````````````````````````````````````````````````````````
M`````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P
M-3$U-#,S-S0T(#`R,3$Q-``@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E
M<R]D;W=N;&]A9"]I;F1E>"YP:'``````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#$S,C`@,3`U,34T,S,W-#0@,#(S,#`W`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B`D
M2&]R9&4Z(&AO<F1E+W-E<G9I8V5S+V1O=VYL;V%D+VEN9&5X+G!H<"QV(#$N
M.2XQ,"XS(#(P,#8O,#$O,#$@,C$Z,CDZ,3$@:F%N($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`R,#`R+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I
M9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN
M92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B\N+B<I
M.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V-O<F4N<&AP)SL*
M"B1R96=I<W1R>2`]("9296=I<W1R>3HZ<VEN9VQE=&]N*$A/4D1%7U-%4U-)
M3TY?4D5!1$].3%DI.PH*:68@*"$H)&UO9'5L92`](%5T:6PZ.F=E=$9O<FU$
M871A*"=M;V1U;&4G*2D@?'P*("`@("%F:6QE7V5X:7-T<R@D<F5G:7-T<GDM
M/F=E="@G9FEL97)O;W0G+"`D;6]D=6QE*2DI('L*("`@($AO<F1E.CIF871A
M;"@G1&\@;F]T(&-A;&P@=&AI<R!S8W)I<'0@9&ER96-T;'DN)RP@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*?0II;F-L=61E("1R96=I<W1R>2T^9V5T*"=F:6QE
M<F]O="<L("1M;V1U;&4I("X@)R]V:65W+G!H<"<["@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S
M97)V:6-E<R]O8G)O=W-E<@``````````````````````````````````````
M````````````````````````````````````````,#`P-S4U(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W-#0@,#(Q,30W`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<```
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-C`U-2`Q,#4Q-30S
M,S<T-"`P,C,P-30`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O<V5R=FEC97,O
M;V)R;W=S97(O:6YD97@N<&AP+'8@,2XV+C$P+C4@,C`P-B\P,2\P,2`R,3HR
M.3HQ-"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!#:&%R
M;&5S($HN($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("HO"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?
M7RD@+B`G+RXN+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L
M:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+U1E;7!L871E+G!H
M<"<["@HD<&%T:"`](%5T:6PZ.F=E=$9O<FU$871A*"=P871H)RD["@II9B`H
M96UP='DH)'!A=&@I*2!["B`@("`D;&ES="`](&%R<F%Y*"D["B`@("`D87!P
M<R`]("1R96=I<W1R>2T^;&ES=$%P<',H;G5L;"P@9F%L<V4L(%!%4DU37U)%
M040I.PH@("`@9F]R96%C:"`H)&%P<',@87,@)&%P<"D@>PH@("`@("`@(&EF
M("@D<F5G:7-T<GDM/FAA<TUE=&AO9"@G8G)O=W-E)RP@)&%P<"DI('L*("`@
M("`@("`@("`@)&QI<W1;)&%P<%T@/2!A<G)A>2@G;F%M92<@/3X@)')E9VES
M=')Y+3YG970H)VYA;64G+"`D87!P*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G:6-O;B<@/3X@)')E9VES=')Y+3YG970H)VEC;VXG+"`D
M87!P*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8G)O=W-E
M86)L92<@/3X@=')U92D["B`@("`@("`@?0H@("`@?0I](&5L<V4@>PH@("`@
M)'!I96-E<R`](&5X<&QO9&4H)R\G+"`D<&%T:"D["B`@("`D;&ES="`]("1R
M96=I<W1R>2T^8V%L;$)Y4&%C:V%G92@D<&EE8V5S6S!=+"`G8G)O=W-E)RP@
M87)R87DH)W!A=&@G(#T^("1P871H*2D["GT*"FEF("AI<U]A*"1L:7-T+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("!(;W)D93HZ9F%T86PH)&QI<W0L(%]?1DE,
M15]?+"!?7TQ)3D5?7RD["GT*:68@*"%C;W5N="@D;&ES="DI('L*("`@($AO
M<F1E.CIF871A;"A?*").;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RXB*2P@
M7U]&24Q%7U\L(%]?3$E.15]?*3L*?0H*)'1P;"`](#P\/%103`H\<V-R:7!T
M('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"F9U;F-T:6]N(&-H;V]S94]B:F5C
M="AO:60I"GL*("`@(&EF("@A=VEN9&]W+F]P96YE<B!\?"`A=VEN9&]W+F]P
M96YE<BYO8G)O=W-E<D-A;&QB86-K*2!["B`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@?0H*("`@('9A<B!R97-U;'0@/2!W:6YD;W<N;W!E;F5R+F]B<F]W
M<V5R0V%L;&)A8VLH=VEN9&]W+FYA;64L(&]I9"D["B`@("!I9B`H(7)E<W5L
M="D@>PH@("`@("`@('=I;F1O=RYC;&]S92@I.PH@("`@("`@(')E='5R;CL*
M("`@('T*"B`@("!A;&5R="AR97-U;'0I.PH@("`@<F5T=7)N(&9A;'-E.PI]
M"CPO<V-R:7!T/@H*/&1I=B!C;&%S<STB:&5A9&5R(CX*(#QS<&%N(&-L87-S
M/2)R:6=H=$9L;V%T(CX\=&%G.F-L;W-E("\^/"]S<&%N/@H@/&=E='1E>'0^
M3V)J96-T($)R;W=S97(\+V=E='1E>'0^"CPO9&EV/@H\9&EV(&-L87-S/2)H
M96%D97)B;W@B/@H@/'1A8FQE(&-L87-S/2)S=')I<&5D(B!C96QL<W!A8VEN
M9STB,"(@<W1Y;&4](G=I9'1H.C$P,"4B/@H@/&QO;W`Z<F]W<SX*("`\='(^
M"B`@(#QT9#X*("`@(#QT86<Z<F]W<RYI8V]N("\^"B`@("`\=&%G.G)O=W,N
M;F%M92`O/@H@("`\+W1D/@H@(#PO='(^"B`\+VQO;W`Z<F]W<SX*(#PO=&%B
M;&4^"CPO9&EV/@I44$P["@HD<F]W<R`](&%R<F%Y*"D["F9O<F5A8V@@*"1L
M:7-T(&%S("1P871H(#T^("1V86QU97,I('L*("`@("1R;W<@/2!A<G)A>2@I
M.PH*("`@("\O(%-E="!T:&4@:6-O;BX*("`@(&EF("@A96UP='DH)'9A;'5E
M<ULG:6-O;B==*2D@>PH@("`@("`@("1R;W=;)VEC;VXG72`]($AO<F1E.CII
M;6<H)'9A;'5E<ULG:6-O;B==+"`D=F%L=65S6R=N86UE)UTL("<G+"`G)RD[
M"B`@("!](&5L<V5I9B`H(65M<'1Y*"1V86QU97-;)V)R;W=S96%B;&4G72DI
M('L*("`@("`@("`D<F]W6R=I8V]N)UT@/2!(;W)D93HZ:6UG*"=T<F5E+V9O
M;&1E<BYP;F<G*3L*("`@('T@96QS92!["B`@("`@("`@)')O=ULG:6-O;B==
M(#T@2&]R9&4Z.FEM9R@G=')E92]L96%F+G!N9R<I.PH@("`@?0H*("`@("\O
M(%-E="!T:&4@;F%M92]L:6YK+@H@("`@:68@*"%E;7!T>2@D=F%L=65S6R=B
M<F]W<V5A8FQE)UTI*2!["B`@("`@("`@)'5R;"`]($AO<F1E.CIA<'!L:6-A
M=&EO;E5R;"@G<V5R=FEC97,O;V)R;W=S97(O)RD["B`@("`@("`@)'5R;"`]
M(%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`G<&%T:"<L("1P871H*3L*("`@
M("`@("`D<F]W6R=N86UE)UT@/2!(;W)D93HZ;&EN:R@D=7)L*2`N("1V86QU
M97-;)VYA;64G72`N("<\+V$^)SL*("`@('T@96QS92!["B`@("`@("`@)&IS
M(#T@(G)E='5R;B!C:&]O<V5/8FIE8W0H)R(@+B!A9&1S;&%S:&5S*"1P871H
M*2`N("(G*3LB.PH@("`@("`@("1R;W=;)VYA;64G72`]($AO<F1E.CIL:6YK
M*"<C)RP@<W!R:6YT9BA?*")#:&]O<V4@)7,B*2P@)'9A;'5E<ULG;F%M92==
M*2P@)R<L("<G+"`D:G,I("X@)'9A;'5E<ULG;F%M92==("X@)SPO83XG.PH@
M("`@?0H*("`@("1R;W=S6UT@/2`D<F]W.PI]"@HD=&5M<&QA=&4@/2`F;F5W
M($AO<F1E7U1E;7!L871E*"D["B1T96UP;&%T92T^<V5T3W!T:6]N*"=G971T
M97AT)RP@=')U92D["B1T96UP;&%T92T^<V5T*"=R;W=S)RP@)')O=W,I.PHD
M=&5M<&QA=&4M/G-E="@G8VQO<V4G+"`G/&$@:')E9CTB(R(@;VYC;&EC:STB
M=VEN9&]W+F-L;W-E*"D[(')E='5R;B!F86QS93LB/B<@+B!(;W)D93HZ:6UG
M*"=C;&]S92YP;F<G*2`N("<\+V$^)RD["@I(;W)D93HZ861D4V-R:7!T1FEL
M92@G<W1R:7!E+FIS)RP@)VAO<F1E)RP@=')U92D["G)E<75I<F4@2$]21$5?
M5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["F5C:&\@)'1E;7!L
M871E+3YP87)S92@D='!L*3L*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G
M+V-O;6UO;BUF;V]T97(N:6YC)SL*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]I;6%G97,`````````````````
M````````````````````````````````````````````````````````````
M````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T
M,S,W-#0@,#(P-34R`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+VEM
M86=E<R]C;VQO<G!I8VME<BYP:'``````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P-S0Q,R`Q,#4Q-30S,S<T-"`P,C,V-C,`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D
M93H@:&]R9&4O<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<"QV(#$N
M,3DN,3`N-"`R,#`V+S`Q+S`Q(#(Q.C(Y.C$T(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,BTR,#`V($UI8VAA96P@0V]C:')A;F4@/&UI:V5`9W)A
M9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=(
M3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN+RXN)RD["G)E
M<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PH*)'1I
M=&QE(#T@7R@B0V]L;W(@4&EC:V5R(BD["G)E<75I<F4@2$]21$5?5$5-4$Q!
M5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["@HD9F]R;2`](%5T:6PZ.F=E
M=$9O<FU$871A*"=F;W)M)RD["B1T87)G970@/2!5=&EL.CIG971&;W)M1&%T
M82@G=&%R9V5T)RD["@IE8VAO($AO<F1E.CII;6<H)V-O;&]R<V-A;&4N<&YG
M)RP@)R<L("=I9#TB8V]L;W)P:6-K97(B(&]N8VQI8VL](F-H86YG94-O;&]R
M*&=E=$-O;&]R*&5V96YT*2D[(')E='5R;B!F86QS93LB(&]N;6]U<V5M;W9E
M/2)D96UO0V]L;W(H9V5T0V]L;W(H979E;G0I*3L@<F5T=7)N(&9A;'-E.R(@
M<W1Y;&4](F-U<G-O<CIC<F]S<VAA:7([8F%C:V=R;W5N9"UC;VQO<CIW:&ET
M93MP861D:6YG.C%P>"(G*3L*/SX*"CQD:78@:60](F-O;&]R1&5M;R(@<W1Y
M;&4](F)A8VMG<F]U;F0M8V]L;W(Z=VAI=&4[=VED=&@Z,3`P<'@[:&5I9VAT
M.C(P<'@[<&%D9&EN9SHQ<'@B/CPO9&EV/@H\<V-R:7!T('1Y<&4](G1E>'0O
M:F%V87-C<FEP="(^"CPA+2T*9G5N8W1I;VX@8VAA;F=E0V]L;W(H8V]L;W(I
M"GL*("`@(&EF("AP87)E;G0N;W!E;F5R+F-L;W-E9"D@>PH@("`@("`@(&%L
M97)T*"(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B5&AE($]P=&EO;G,@=VEN
M9&]W(&AA<R!C;&]S960N($5X:71I;F<N(BDI(#\^(BD["B`@("`@("`@=&AI
M<RYC;&]S92@I.PH@("`@("`@(')E='5R;CL*("`@('T*"B`@("!I9B`H(7!A
M<F5N="YO<&5N97(N9&]C=6UE;G0N/#]P:'`@96-H;R`D9F]R;2`_/BD@>PH@
M("`@("`@(&%L97)T*"(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B5&AI<R!W
M:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=R(I
M*2`_/B(I.PH@("`@("`@('1H:7,N8VQO<V4H*3L*("`@("`@("!R971U<FX[
M"B`@("!]"@H@("`@<&%R96YT+F]P96YE<BYD;V-U;65N="X\/W!H<"!E8VAO
M("1F;W)M(#\^6R(\/W!H<"!E8VAO("1T87)G970@/SXB72YV86QU92`](&-O
M;&]R.PH@("`@<&%R96YT+F]P96YE<BYD;V-U;65N="X\/W!H<"!E8VAO("1F
M;W)M(#\^6R(\/W!H<"!E8VAO("1T87)G970@/SXB72YS='EL92YB86-K9W)O
M=6YD0V]L;W(@/2!C;VQO<CL*("`@('!A<F5N="YO<&5N97(N9&]C=6UE;G0N
M/#]P:'`@96-H;R`D9F]R;2`_/ELB/#]P:'`@96-H;R`D=&%R9V5T(#\^(ETN
M<W1Y;&4N8V]L;W(@/2!B<FEG:'1N97-S*&-O;&]R*2`\(#$R."`_("=W:&ET
M92<@.B`G8FQA8VLG.PH*("`@('1H:7,N8VQO<V4H*3L*?0H*9G5N8W1I;VX@
M9&5M;T-O;&]R*&-O;&]R*0I["B`@("!V87(@=&%R9V5T(#T@9&]C=6UE;G0N
M9V5T16QE;65N=$)Y260H)V-O;&]R1&5M;R<I.PH@("`@=&%R9V5T+G-T>6QE
M+F)A8VMG<F]U;F1#;VQO<B`](&-O;&]R.PH@("`@=&%R9V5T+G-T>6QE+F-O
M;&]R(#T@8G)I9VAT;F5S<RAC;VQO<BD@/"`Q,C@@/R`G=VAI=&4G(#H@)V)L
M86-K)SL*("`@('1A<F=E="YI;FYE<DA434P@/2!C;VQO<CL*?0H*9G5N8W1I
M;VX@9V5T0V]L;W(H979E;G0I"GL*("`@('9A<B!I;6<@/2!D;V-U;65N="YG
M971%;&5M96YT0GE)9"@G8V]L;W)P:6-K97(G*3L*"B`@("!V87(@>"`](&5V
M96YT+F-L:65N=%@@+2`Q,#L*("`@('9A<B!Y(#T@979E;G0N8VQI96YT62`M
M(#$P.PH*("`@('9A<B!R;6%X(#T@,#L*("`@('9A<B!G;6%X(#T@,#L*("`@
M('9A<B!B;6%X(#T@,#L*"B`@("!I9B`H>2`\/2`S,BD@>PH@("`@("`@(')M
M87@@/2`R-34["B`@("`@("`@9VUA>"`]("AY("\@,S(N,"D@*B`R-34["B`@
M("`@("`@8FUA>"`](#`["B`@("!](&5L<V4@:68@*'D@/#T@-C0I('L*("`@
M("`@("!Y(#T@>2`M(#,R.PH@("`@("`@(')M87@@/2`R-34@+2`H>2`O(#,R
M+C`I("H@,C4U.PH@("`@("`@(&=M87@@/2`R-34["B`@("`@("`@8FUA>"`]
M(#`["B`@("!](&5L<V4@:68@*'D@/#T@.38I('L*("`@("`@("!Y(#T@>2`M
M(#8T.PH@("`@("`@(')M87@@/2`P.PH@("`@("`@(&=M87@@/2`R-34["B`@
M("`@("`@8FUA>"`]("AY("\@,S(N,"D@*B`R-34["B`@("!](&5L<V4@:68@
M*'D@/#T@,3(X*2!["B`@("`@("`@>2`]('D@+2`Y-CL*("`@("`@("!R;6%X
M(#T@,#L*("`@("`@("!G;6%X(#T@,C4U("T@*'D@+R`S,BXP*2`J(#(U-3L*
M("`@("`@("!B;6%X(#T@,C4U.PH@("`@?2!E;'-E(&EF("AY(#P](#$V,"D@
M>PH@("`@("`@('D@/2!Y("T@,3(X.PH@("`@("`@(')M87@@/2`H>2`O(#,R
M+C`I("H@,C4U.PH@("`@("`@(&=M87@@/2`P.PH@("`@("`@(&)M87@@/2`R
M-34["B`@("!](&5L<V4@>PH@("`@("`@('D@/2!Y("T@,38P.PH@("`@("`@
M(')M87@@/2`R-34["B`@("`@("`@9VUA>"`](#`["B`@("`@("`@8FUA>"`]
M(#(U-2`M("AY("\@,S(N,"D@*B`R-34["B`@("!]"@H@("`@:68@*'@@/#T@
M-3`I('L*("`@("`@("!V87(@<B`]($UA=&@N86)S*$UA=&@N9FQO;W(H<FUA
M>"`J('@@+R`U,"XP*2D["B`@("`@("`@=F%R(&<@/2!-871H+F%B<RA-871H
M+F9L;V]R*&=M87@@*B!X("\@-3`N,"DI.PH@("`@("`@('9A<B!B(#T@36%T
M:"YA8G,H36%T:"YF;&]O<BAB;6%X("H@>"`O(#4P+C`I*3L*("`@('T@96QS
M92!["B`@("`@("`@>"`M/2`U,#L*("`@("`@("!V87(@<B`]($UA=&@N86)S
M*$UA=&@N9FQO;W(H<FUA>"`K("AX("\@-3`N,"D@*B`H,C4U("T@<FUA>"DI
M*3L*("`@("`@("!V87(@9R`]($UA=&@N86)S*$UA=&@N9FQO;W(H9VUA>"`K
M("AX("\@-3`N,"D@*B`H,C4U("T@9VUA>"DI*3L*("`@("`@("!V87(@8B`]
M($UA=&@N86)S*$UA=&@N9FQO;W(H8FUA>"`K("AX("\@-3`N,"D@*B`H,C4U
M("T@8FUA>"DI*3L*("`@('T*"B`@("!R971U<FX@;6%K94-O;&]R*'(L(&<L
M(&(I.PI]"@IF=6YC=&EO;B!M86ME0V]L;W(H<BP@9RP@8BD*>PH@("`@8V]L
M;W(@/2`G(R<["B`@("!C;VQO<B`K/2!H97@H36%T:"YF;&]O<BAR("\@,38I
M*3L*("`@(&-O;&]R("L](&AE>"AR("4@,38I.PH@("`@8V]L;W(@*ST@:&5X
M*$UA=&@N9FQO;W(H9R`O(#$V*2D["B`@("!C;VQO<B`K/2!H97@H9R`E(#$V
M*3L*("`@(&-O;&]R("L](&AE>"A-871H+F9L;V]R*&(@+R`Q-BDI.PH@("`@
M8V]L;W(@*ST@:&5X*&(@)2`Q-BD["B`@("!R971U<FX@8V]L;W(["GT*"F9U
M;F-T:6]N(&)R:6=H=&YE<W,H8V]L;W(I"GL*("`@('9A<B!R(#T@;F5W($YU
M;6)E<B@B,'@B("L@8V]L;W(N<W5B<W1R*#$L(#(I*3L*("`@('9A<B!G(#T@
M;F5W($YU;6)E<B@B,'@B("L@8V]L;W(N<W5B<W1R*#,L(#(I*3L*("`@('9A
M<B!B(#T@;F5W($YU;6)E<B@B,'@B("L@8V]L;W(N<W5B<W1R*#4L(#(I*3L*
M("`@(')E='5R;B`H*'(@*B`R.3DI("L@*&<@*B`U.#<I("L@*&(@*B`Q,30I
M*2`O(#$P,#`["GT*"F9U;F-T:6]N(&AE>"AD96,I"GL*("`@(')E='5R;B`H
M9&5C*2YT;U-T<FEN9R@Q-BD["GT*+R\M+3X*/"]S8W)I<'0^"CPO8F]D>3X*
M/"]H=&UL/@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W-E<G9I8V5S+VEM86=E<R]P:7AE;"YP:'``````````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C$W-2`Q,#4Q-30S,S<T-"`P,C(T
M-S``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O<V5R=FEC97,O:6UA9V5S+W!I
M>&5L+G!H<"QV(#$N,30N,3`N,R`R,#`V+S`Q+S`Q(#(Q.C(Y.C$T(&IA;B!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN
M92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B\N+B<I
M.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V-O<F4N<&AP)SL*
M"FAE861E<B@G0V]N=&5N="UT>7!E.B!I;6%G92]G:68G*3L*:&5A9&5R*"=%
M>'!I<F5S.B!7960L(#(Q($%U9R`Q.38Y(#$Q.C$Q.C$Q($=-5"<I.PIH96%D
M97(H)T-A8VAE+4-O;G1R;VPZ(&YO+6-A8VAE)RD["FAE861E<B@G0V%C:&4M
M0V]N=')O;#H@;75S="UR979A;&ED871E)RD["@HD<F=B(#T@<W1R7W)E<&QA
M8V4H)R,G+"`G)RP@571I;#HZ9V5T1F]R;41A=&$H)V,G*2D["@HD<B`](&AE
M>&1E8RAS=6)S='(H)')G8BP@,"P@,BDI.PHD9R`](&AE>&1E8RAS=6)S='(H
M)')G8BP@,BP@,BDI.PHD8B`](&AE>&1E8RAS=6)S='(H)')G8BP@-"P@,BDI
M.PH*:68@*"1R9V(I('L*("`@('!R:6YT9B@G)6,E8R5C)6,E8R5C)6,E8R5C
M)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E
M8R5C)6,E8R<L"B`@("`@("`@("`@-S$L-S,L-S`L-38L-3<L.3<L,2PP+#$L
M,"PQ,C@L,"PP+"1R+"1G+"1B+#`L,"PP+#0T+#`L,"PP+#`L,2PP+#$L,"PP
M+#(L,BPV."PQ+#`L-3DI.PI](&5L<V4@>PH@("`@<')I;G1F*"<E8R5C)6,E
M8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C
M)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E)RP*("`@("`@("`@
M("`W,2PW,RPW,"PU-BPU-RPY-RPQ+#`L,2PP+#$R."PR-34L,"PQ.3(L,3DR
M+#$Y,BPP+#`L,"PS,RPR-#DL-"PQ+#`L,"PP+#`L-#0L,"PP+#`L,"PQ+#`L
M,2PP+#`L,BPR+#8X+#$L,"PU.2D["GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O:6UA9V5S
M+W9I97<N<&AP````````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`W-38T(#$P-3$U-#,S-S0T(#`R,C,S,``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@1&ES<&QA>7,@
M86X@:6UA9V4@86YD(&%L;&]W<R!M;V1I9FEC871I;VYS(&EF(')E<75I<F5D
M+@H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UA<FMO($1J=6MI8R`\;6%R
M:V]`;V)L;RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B`D2&]R9&4Z(&AO<F1E
M+W-E<G9I8V5S+VEM86=E<R]V:65W+G!H<"QV(#$N,C`N,3`N-B`R,#`V+S`U
M+S(T(#`R.C(R.C`S('-E;'-K>2!%>'`@)`H@*@H@*B!`875T:&]R($UA<FMO
M($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J+PH*0&1E9FEN92@G2$]21$5?
M0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B\N+B<I.PIR97%U:7)E
M7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*"B\J($=E="!F
M:6QE(&EN9F\N(%1H92!F;VQL;W=I;F<@<&%R86UE=&5R<R!A<F4@879A:6QA
M8FQE.@H@*B`@)V8G("T@=&AE(&9I;&5N86UE+@H@*B`@)W,G("T@=&AE('-O
M=7)C92P@96ET:&5R('1H92`G=&UP)R!D:7)E8W1O<GD@;W(@5D93+@H@*B`@
M)V,G("T@=VAI8V@@87!P)W,@8V]N9FEG('1O('5S92!F;W(@5D93+"!D969A
M=6QT<R!T;R!(;W)D92X*("H@("=P)R`M('1H92!D:7)E8W1O<GD@;V8@=&AE
M(&9I;&4N"B`J("`G;B<@+2!T:&4@;F%M92!T;R!S970@=&\@=&AE(&9I;&5N
M86UE(&]R(&1E9F%U;'0@=&\@<V%M92!A<R!F:6QE;F%M92X*("H@("=A)R`M
M('!E<F9O<FT@<V]M92!A8W1I;VX@;VX@=&AE(&EM86=E+"!S=6-H(&%S('-C
M86QI;F<N("HO"B1F:6QE(#T@8F%S96YA;64H571I;#HZ9V5T1F]R;41A=&$H
M)V8G*2D["B1S;W5R8V4@/2!S=')T;VQO=V5R*%5T:6PZ.F=E=$9O<FU$871A
M*"=S)RP@)W1M<"<I*3L*)&%P<%]C;VYF(#T@<W1R=&]L;W=E<BA5=&EL.CIG
M971&;W)M1&%T82@G8R<L("=H;W)D92<I*3L*)&YA;64@/2!5=&EL.CIG971&
M;W)M1&%T82@G;B<L("1F:6QE*3L*)&%C=&EO;B`]('-T<G1O;&]W97(H571I
M;#HZ9V5T1F]R;41A=&$H)V$G*2D["@IS=VET8V@@*"1S;W5R8V4I('L*8V%S
M92`G=F9S)SH*("`@("\J($-H86YG92!A<'`@:68@;F5E9&5D('1O(&=E="!T
M:&4@<FEG:'0@5D93(&-O;F9I9RX@*B\*("`@("1C:&%N9V5D7V-O;F8@/2`D
M<F5G:7-T<GDM/G!U<VA!<'`H)&%P<%]C;VYF*3L*"B`@("`O*B!'971T:6YG
M(&$@9FEL92!F<F]M($AO<F1E)W,@5D93+B`J+PH@("`@<F5Q=6ER95]O;F-E
M("=61E,N<&AP)SL*("`@("1V9G,@/2`F5D93.CIS:6YG;&5T;VXH)&-O;F9;
M)W9F<R==6R=T>7!E)UTL($AO<F1E.CIG971$<FEV97)#;VYF:6<H)W9F<R<L
M("1C;VYF6R=V9G,G75LG='EP92==*2D["B`@("`D<&%T:"`](%5T:6PZ.F=E
M=$9O<FU$871A*"=P)RD["B`@("`D9FEL95]D871A(#T@)'9F<RT^<F5A9"@D
M<&%T:"P@)&9I;&4I.PH@("`@:68@*&ES7V$H)&9I;&5?9&%T82P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P<FEN=&8H
M)T5R<F]R(&1I<W!L87EI;F<@:6UA9V4@6R5S73H@)7,G+"`D<&%T:"`N("<O
M)R`N("1F:6QE+"`D9FEL95]D871A+3YG971-97-S86=E*"DI+"!?7T9)3$5?
M7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@97AI=#L*("`@
M('T*"B`@("`O*B!2971U<FX@=&AE(&]R:6=I;F%L(&%P<"!I9B!C:&%N9V5D
M('!R979I;W5S;'DN("HO"B`@("!I9B`H)&-H86YG961?8V]N9BD@>PH@("`@
M("`@("1R96=I<W1R>2T^<&]P07!P*"1A<'!?8V]N9BD["B`@("!]"B`@("!B
M<F5A:SL*"F-A<V4@)W1M<"<Z"B`@("`O*B!'971T:6YG(&$@9FEL92!F<F]M
M($AO<F1E)W,@=&5M<"!D:7(N("HO"B`@("`D=&UP9&ER(#T@2&]R9&4Z.F=E
M=%1E;7!$:7(H*3L*("`@(&EF("AE;7!T>2@D86-T:6]N*2!\?"`D86-T:6]N
M(#T]("=R97-I>F4G*2!["B`@("`@("`@+RH@57-E(&]R:6=I;F%L(&EF(&YO
M(&%C=&EO;B!O<B!I9B!R97-I>FEN9RX@*B\*("`@("`@("`D9FEL95]N86UE
M(#T@)'1M<&1I<B`N("<O)R`N("1F:6QE.PH@("`@?2!E;'-E('L*("`@("`@
M("`D9FEL95]N86UE(#T@)'1M<&1I<B`N("<O;6]D7R<@+B`D9FEL93L*("`@
M("`@("!I9B`H(69I;&5?97AI<W1S*"1F:6QE7VYA;64I*2!["B`@("`@("`@
M("`@(&-O<'DH)'1M<&1I<B`N("<O)R`N("1F:6QE+"`D9FEL95]N86UE*3L*
M("`@("`@("!]"B`@("!]"B`@("!I9B`H(69I;&5?97AI<W1S*"1F:6QE7VYA
M;64I*2!["B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R:6YT9B@G26UA
M9V4@;F]T(&9O=6YD(%LE<UTG+"`D9FEL95]N86UE*2P@7U]&24Q%7U\L(%]?
M3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@(&5X:70["B`@("!]"B`@
M("`D9FEL95]D871A(#T@9FEL95]G971?8V]N=&5N=',H)&9I;&5?;F%M92D[
M"B`@("!B<F5A:SL*?0H*+RH@3&]A9"!T:&4@:6UA9V4@;V)J96-T+B`J+PIR
M97%U:7)E7V]N8V4@)TAO<F1E+TEM86=E+G!H<"<["B1P87)A;7,@/2!A<G)A
M>2@G=&5M<"<@/3X@2&]R9&4Z.F=E=%1E;7!$:7(H*2D["FEF("@A96UP='DH
M)&-O;F9;)VEM86=E)UU;)V-O;G9E<G0G72DI('L*("`@("1I;6%G92`]("9(
M;W)D95]);6%G93HZ<VEN9VQE=&]N*"=I;2<L("1P87)A;7,I.PI](&5L<V4@
M>PH@("`@)&EM86=E(#T@)DAO<F1E7TEM86=E.CIS:6YG;&5T;VXH)V=D)RP@
M)'!A<F%M<RD["GT*)&EM86=E+3YL;V%D4W1R:6YG*"1F:6QE+"`D9FEL95]D
M871A*3L*"B\J($-H96-K(&EF(&YO(&5D:71I;F<@86-T:6]N(')E<75I<F5D
M(&%N9"!S96YD('1H92!I;6%G92!T;R!B<F]W<V5R+B`J+PII9B`H96UP='DH
M)&%C=&EO;BDI('L*("`@("1I;6%G92T^9&ES<&QA>2@I.PH@("`@97AI=#L*
M?0H*+RH@26UA9V4@961I=&EN9R!R97%U:7)E9"X@*B\*<W=I=&-H("@D86-T
M:6]N*2!["F-A<V4@)W)O=&%T92<Z"B`@("`D:6UA9V4M/G)O=&%T92A5=&EL
M.CIG971&;W)M1&%T82@G=B<I*3L*("`@(&)R96%K.PH*8V%S92`G9FQI<"<Z
M"B`@("`D:6UA9V4M/F9L:7`H*3L*("`@(&)R96%K.PH*8V%S92`G;6ER<F]R
M)SH*("`@("1I;6%G92T^;6ER<F]R*"D["B`@("!B<F5A:SL*"F-A<V4@)V=R
M87ES8V%L92<Z"B`@("`D:6UA9V4M/F=R87ES8V%L92@I.PH@("`@8G)E86L[
M"@IC87-E("=R97-I>F4G.@H@("`@;&ES="@D=VED=&@L("1H96EG:'0L("1R
M871I;RD@/2!E>'!L;V1E*"<N)RP@571I;#HZ9V5T1F]R;41A=&$H)W8G*2D[
M"@H@("`@+RH@268@;F\@=VED=&@@;W(@:&5I9VAT(&AA<R!B965N('!A<W-E
M9"P@9V5T('1H92!O<FEG:6YA;`H@("`@("H@;VYE<RX@*B\*("`@(&EF("AE
M;7!T>2@D=VED=&@I('Q\(&5M<'1Y*"1H96EG:'0I*2!["B`@("`@("`@)&]R
M:6<@/2`D:6UA9V4M/F=E=$1I;65N<VEO;G,H*3L*("`@('T*("`@(&EF("AE
M;7!T>2@D=VED=&@I*2!["B`@("`@("`@)'=I9'1H(#T@)&]R:6=;)W=I9'1H
M)UT["B`@("!]"B`@("!I9B`H96UP='DH)&AE:6=H="DI('L*("`@("`@("`D
M:&5I9VAT(#T@)&]R:6=;)VAE:6=H="==.PH@("`@?0H*("`@("1I;6%G92T^
M<F5S:7IE*"1W:61T:"P@)&AE:6=H="P@)')A=&EO*3L*"B`@("`O*B!3:6YC
M92!T:&4@;W)I9VEN86P@:7,@86QW87ES('5S960@9F]R(')E<VEZ:6YG(&UA
M:V4@<W5R92!T:&4*("`@("`J('=R:71E(&ES('1O("=M;V1?)RX@*B\*("`@
M("1F:6QE7VYA;64@/2`D=&UP9&ER("X@)R]M;V1?)R`N("1F:6QE.PH@("`@
M8G)E86L["GT*"B\J(%=R:71E(&]U="!A;GD@8VAA;F=E<R!T;R!T:&4@=&5M
M<&]R87)Y(&9I;&4N("HO"B1F<"`]($!F;W!E;B@D9FEL95]N86UE+"`G=V(G
M*3L*9G=R:71E*"1F<"P@)&EM86=E+3YR87<H*2D["F9C;&]S92@D9G`I.PH*
M)&EM86=E+3YD:7-P;&%Y*"D["@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<V5R=FEC97,O:&5L<```````````````````````````````````````
M`````````````````````````````````````````````#`P,#<U-2``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S0T(#`R,#(S-0`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]H96QP+VEN9&5X+G!H<```
M````````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#8U-#4@,3`U
M,34T,S,W-#0@,#(R,30V`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W-E<G9I
M8V5S+VAE;'`O:6YD97@N<&AP+'8@,BXX,"XQ,"XY(#(P,#8O,#<O,#8@,C(Z
M,C@Z,#(@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!*
M;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@I`
M9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN
M+RXN)RD["D!D969I;F4H)T%55$A?2$%.1$Q%4B<L('1R=64I.PH*<F5Q=6ER
M95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?
M;VYC92`G2&]R9&4O2&5L<"YP:'`G.PH*)'1I=&QE(#T@7R@B2&5L<"(I.PHD
M<VAO=R`](%-T<FEN9SHZ;&]W97(H571I;#HZ9V5T1F]R;41A=&$H)W-H;W<G
M+"`G:6YD97@G*2D["B1M;V1U;&4@/2!3=')I;F<Z.FQO=V5R*'!R96=?<F5P
M;&%C92@G+UQ7+R<L("<G+"!5=&EL.CIG971&;W)M1&%T82@G;6]D=6QE)RP@
M)VAO<F1E)RDI*3L*)'1O<&EC(#T@571I;#HZ9V5T1F]R;41A=&$H)W1O<&EC
M)RD["@II9B`H)&UO9'5L92`]/2`G861M:6XG*2!["B`@("`D9FEL97)O;W0@
M/2`D<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G*3L*("`@("1H96QP7V9I;&4@
M/2`D9FEL97)O;W0@+B`B+V%D;6EN+VQO8V%L92\D;&%N9W5A9V4O:&5L<"YX
M;6PB.PH@("`@)&AE;'!?9FEL95]F86QL8F%C:R`]("1F:6QE<F]O="`N("<O
M861M:6XO;&]C86QE+V5N7U53+VAE;'`N>&UL)SL*?2!E;'-E('L*("`@("1F
M:6QE<F]O="`]("1R96=I<W1R>2T^9V5T*"=F:6QE<F]O="<L("1M;V1U;&4I
M.PH@("`@)&AE;'!?9FEL92`]("1F:6QE<F]O="`N("(O;&]C86QE+R1L86YG
M=6%G92]H96QP+GAM;"(["B`@("`D:&5L<%]F:6QE7V9A;&QB86-K(#T@)&9I
M;&5R;V]T("X@)R]L;V-A;&4O96Y?55,O:&5L<"YX;6PG.PI]"@II9B`H)'-H
M;W<@/3T@)VEN9&5X)RD@>PH@("`@)&)A<V5?=7)L(#T@)')E9VES=')Y+3YG
M970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O<V5R=FEC97,O:&5L<"\G.PH@
M("`@)&UA:6Y?=7)L(#T@2&]R9&4Z.G5R;"@D8F%S95]U<FPI.PH@("`@)&UA
M:6Y?=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1M86EN7W5R;"P@87)R87DH
M)W-H;W<G(#T^("=E;G1R>2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G;6]D=6QE)R`]/B`D;6]D=6QE
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W1O<&EC)R`]/B`D=&]P:6,I*3L*("`@("1M96YU7W5R;"`]
M($AO<F1E.CIU<FPH)&)A<V5?=7)L*3L*("`@("1M96YU7W5R;"`](%5T:6PZ
M.F%D9%!A<F%M971E<B@D;65N=5]U<FPL(&%R<F%Y*"=M;V1U;&4G(#T^("1M
M;V1U;&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G<VAO=R<@/3X@)VUE;G4G*2D["B`@("!R97%U:7)E
M($A/4D1%7U1%35!,051%4R`N("<O:&5L<"]I;F1E>"YI;F,G.PH@("`@97AI
M=#L*?0H*)&)O9'E#;&%S<R`]("=H96QP)SL*<F5Q=6ER92!(3U)$15]414U0
M3$%415,@+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*:68@*"1S:&]W(#T]("=M
M96YU)RD@>PH@("`@+RH@4V5T('5P('5R;',N("HO"B`@("`D=7)L(#T@2&]R
M9&4Z.G5R;"@D<F5G:7-T<GDM/F=E="@G=V5B<F]O="<L("=H;W)D92<I("X@
M)R]S97)V:6-E<R]H96QP+R<I.PH@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M
M971E<B@D=7)L+"`G;6]D=6QE)RP@)&UO9'5L92D["B`@("`D=&]P:6-S7VQI
M;FL@/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@)W-H;W<G+"`G=&]P:6-S
M)RD["B`@("`D=&]P:6-S7VQI;FL@/2!(;W)D93HZ;&EN:R@D=&]P:6-S7VQI
M;FLL(&YU;&PL("=H96%D97(G+"`G:&5L<%]M86EN)RD@+B!?*"),:7-T($AE
M;'`@5&]P:6-S(BD@+B`G/"]A/B<["B`@("`D86)O=71?;&EN:R`](%5T:6PZ
M.F%D9%!A<F%M971E<B@D=7)L+"`G<VAO=R<L("=A8F]U="<I.PH@("`@)&%B
M;W5T7VQI;FL@/2!(;W)D93HZ;&EN:R@D86)O=71?;&EN:RP@;G5L;"P@)VAE
M861E<B<L("=H96QP7VUA:6XG*2`N(%\H(D%B;W5T+BXN(BD@+B`G/"]A/B<[
M"B`@("!R97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O:&5L<"]M96YU+FEN
M8R<["GT@96QS96EF("@D<VAO=R`]/2`G86)O=70G*2!["B`@("!R97%U:7)E
M("1F:6QE<F]O="`N("<O;&EB+W9E<G-I;VXN<&AP)SL*("`@("1M;V1?=F5R
M<VEO;E]C;VYS=&%N="`](%-T<FEN9SHZ=7!P97(H)&UO9'5L92D@+B`G7U9%
M4E-)3TXG.PH@("`@:68@*"%D969I;F5D*"1M;V1?=F5R<VEO;E]C;VYS=&%N
M="DI('L*("`@("`@("!E>&ET.PH@("`@?0H@("`@)'9E<G-I;VX@/2!3=')I
M;F<Z.G5C9FER<W0H)&UO9'5L92D@+B`G("<@+B!C;VYS=&%N="@D;6]D7W9E
M<G-I;VY?8V]N<W1A;G0I.PH@("`@)&-R961I=',@/2!5=&EL.CIB=69F97)/
M=71P=70H)VEN8VQU9&4G+"`D9FEL97)O;W0@+B`G+V1O8W,O0U)%1$E44R<I
M.PH@("`@)&-R961I=',@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1C<F5D
M:71S+"`G:7-O+3@X-3DM,2<L($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@(')E
M<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]H96QP+V%B;W5T+FEN8R<["GT@
M96QS92!["B`@("`D:&5L<"`]("9N97<@2&5L<"A(14Q07U-/55)#15]&24Q%
M+"!A<G)A>2@D:&5L<%]F:6QE+"`D:&5L<%]F:6QE7V9A;&QB86-K*2D["B`@
M("!I9B`H*"1S:&]W(#T]("=E;G1R>2<I("8F("%E;7!T>2@D=&]P:6,I*2![
M"B`@("`@("`@)&AE;'`M/FQO;VMU<"@D=&]P:6,I.PH@("`@("`@("1H96QP
M+3YD:7-P;&%Y*"D["B`@("!](&5L<V4@>PH@("`@("`@("1T;W!I8W,@/2`D
M:&5L<"T^=&]P:6-S*"D["B`@("`@("`@9F]R96%C:"`H)'1O<&EC<R!A<R`D
M:60@/3X@)'1I=&QE*2!["B`@("`@("`@("`@("1L:6YK(#T@2&]R9&4Z.G5R
M;"@D<F5G:7-T<GDM/F=E="@G=V5B<F]O="<L("=H;W)D92<I("X@)R]S97)V
M:6-E<R]H96QP+R<I.PH@("`@("`@("`@("`D;&EN:R`](%5T:6PZ.F%D9%!A
M<F%M971E<B@D;&EN:RP@87)R87DH)W-H;W<G(#T^("=E;G1R>2<L("=M;V1U
M;&4G(#T^("1M;V1U;&4L("=T;W!I8R<@/3X@)&ED*2D["B`@("`@("`@("`@
M(&5C:&\@2&]R9&4Z.FQI;FLH)&QI;FLI.PH@("`@("`@("`@("!E8VAO("1T
M:71L92`N("(\+V$^/&)R("\^7&XB.PH@("`@("`@('T*("`@('T*("`@("1H
M96QP+3YC;&5A;G5P*"D["GT*"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@
M)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M````````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`V-30W(#$P
M-3$U-#,S-S0T(#`R,C,W,P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]S97)V
M:6-E<R]M86EN=&5N86YC92YP:'`L=B`Q+C,Q+C(N,R`R,#`V+S`Q+S`Q(#(Q
M.C(Y.C$P(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,2TR,#`V($UI
M8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*
M("H@0V]P>7)I9VAT(#(P,#$M,C`P-B!#:&%R;&5S($HN($AA9V5N8G5C:"`\
M8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,C`P,2TR,#`V($IO;B!0
M87)I<V4@/&IO;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@I`9&5F
M:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD[
M"G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PIR
M97%U:7)E7V]N8V4@)TAO<F1E+TUA:6YT96YA;F-E+G!H<"<["G)E<75I<F5?
M;VYC92`G2&]R9&4O5&5M<&QA=&4N<&AP)SL*"B\J($UA:V4@<W5R92!T:&5R
M92!I<R!A('5S97(@;&]G9V5D(&EN+B`J+PII9B`H(4%U=&@Z.F=E=$%U=&@H
M*2D@>PH@("`@2&]R9&4Z.F%U=&AE;G1I8V%T:6]N1F%I;'5R95)E9&ER96-T
M*"D["GT*"B\J($EF(&YO("=M;V1U;&4G('!A<F%M971E<B!P87-S960@:6XL
M(&1I92!W:71H(&%N(&5R<F]R+B`J+PII9B`H(2@D;6]D=6QE(#T@8F%S96YA
M;64H571I;#HZ9V5T1F]R;41A=&$H)VUO9'5L92<I*2DI('L*("`@($AO<F1E
M.CIF871A;"A014%2.CIR86ES945R<F]R*%\H(D1O(&YO="!D:7)E8W1L>2!A
M8V-E<W,@;6%I;G1E;F%N8V4N<&AP(BDI+"!?7T9)3$5?7RP@7U],24Y%7U\I
M.PI]"B1A<'!?;F%M92`]("1R96=I<W1R>2T^9V5T*"=N86UE)RP@)&UO9'5L
M92D["@HO*B!,;V%D('1H92!M;V1U;&4@<W!E8VEF:6,@;6%I;G1E;F%N8V4@
M8VQA<W,@;F]W+B`J+PII9B`H(2@D;6%I;G0@/2`F36%I;G1E;F%N8V4Z.F9A
M8W1O<GDH)&UO9'5L92DI*2!["B`@("!(;W)D93HZ9F%T86PH4$5!4CHZ<F%I
M<V5%<G)O<BA?*")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO
M860@<W5C8V5S<V9U;&QY(BDI+"!?7T9)3$5?7RP@7U],24Y%7U\I.PI]"@HO
M*B!#<F5A=&4@=&AE($AO<F1E7U1E;7!L871E(&ET96TN("HO"B1T96UP;&%T
M92`]("9N97<@2&]R9&5?5&5M<&QA=&4H*3L*)'1E;7!L871E+3YS970H)VIA
M=F%S8W)I<'0G+"`D8G)O=W-E<BT^:&%S1F5A='5R92@G:F%V87-C<FEP="<I
M+"!T<G5E*3L*"B\J($AA=F4@=&AE(&UA:6YT96YA;F-E(&UO9'5L92!D;R!A
M;&P@;F5C97-S87)Y('!R;V-E<W-I;F<N("HO"FQI<W0H)&%C=&EO;BP@)'1A
M<VML:7-T*2`]("1M86EN="T^<G5N36%I;G1E;F%N8V5086=E*"D["@IS=VET
M8V@@*"1A8W1I;VXI('L*8V%S92!-04E.5$5.04Y#15]/5510551?0T].1DE2
M33H*("`@("\J($-O;F9I<FUA=&EO;BUS='EL92!O=71P=70N("HO"B`@("`D
M=&5M<&QA=&4M/G-E="@G8V]N9FER;2<L('1R=64L('1R=64I.PH@("`@)'1E
M;7!L871E+3YS970H)V%G<F5E)RP@9F%L<V4L('1R=64I.PH@("`@)'1E;7!L
M871E+3YS970H)VYO=&EC92<L(&9A;'-E+"!T<G5E*3L*"B`@("`D;F]T:69I
M8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B)7,@:7,@<F5A9'D@=&\@<&5R9F]R
M;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#
M:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O
M('!E<F9O<FT@870@=&AI<R!T:6UE+B(I+"`D87!P7VYA;64I+"`G:&]R9&4N
M;65S<V%G92<I.PH@("`@)'1E;7!L871E+3YS970H)VAE861E<B<L('-P<FEN
M=&8H7R@B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO
M;B(I+"`D87!P7VYA;64I*3L*("`@(&)R96%K.PH*8V%S92!-04E.5$5.04Y#
M15]/5510551?04=2144Z"B`@("`O*B!!9W)E96UE;G0M<W1Y;&4@;W5T<'5T
M+B`J+PH@("`@)'1E;7!L871E+3YS970H)V-O;F9I<FTG+"!F86QS92P@=')U
M92D["B`@("`D=&5M<&QA=&4M/G-E="@G86=R964G+"!T<G5E+"!T<G5E*3L*
M("`@("1T96UP;&%T92T^<V5T*"=N;W1I8V4G+"!F86QS92P@=')U92D["@H@
M("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")0;&5A<V4@<F5A9"!T:&4@9F]L
M;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O
M('5S92!T:&4@<WES=&5M+B(I+"`G:&]R9&4N;65S<V%G92<I.PH@("`@)'1E
M;7!L871E+3YS970H)VAE861E<B<L('-P<FEN=&8H7R@B)7,@5&5R;7,@;V8@
M06=R965M96YT(BDL("1A<'!?;F%M92DI.PH@("`@8G)E86L["@IC87-E($U!
M24Y414Y!3D-%7T]55%!55%].3U1)0T4Z"B`@("`O*B!.;W1I8V4M<W1Y;&4@
M;W5T<'5T+B`J+PH@("`@)'1E;7!L871E+3YS970H)V-O;F9I<FTG+"!F86QS
M92P@=')U92D["B`@("`D=&5M<&QA=&4M/G-E="@G86=R964G+"!F86QS92P@
M=')U92D["B`@("`D=&5M<&QA=&4M/G-E="@G;F]T:6-E)RP@=')U92P@=')U
M92D["@H@("`@)'1E;7!L871E+3YS970H)VAE861E<B<L('-P<FEN=&8H7R@B
M)7,@+2!.;W1I8V4B*2P@)&%P<%]N86UE*2D["B`@("!B<F5A:SL*?0H*+RH@
M36%K92!V87)I86)L92!A<G)A>2!N965D960@9F]R('1E;7!L871E<RX@*B\*
M)'1A<VMS(#T@87)R87DH*3L*9F]R96%C:"`H)'1A<VML:7-T(&%S("1P<F5F
M*2!["B`@("!L:7-T*"1D97-C<FEP+"`D8VAE8VME9"D@/2`D;6%I;G0M/FEN
M9F]-86EN=&5N86YC92@D<')E9BD["B`@("`D=&%S:W-;72`](&%R<F%Y*"=P
M<F5F)R`]/B`D<')E9BP@)V1E<V-R:7`G(#T^("1D97-C<FEP+"`G8VAE8VME
M9"<@/3X@)&-H96-K960@/R`G(&-H96-K960](F-H96-K960B)R`Z("<G*3L*
M?0H*)'1E;7!L871E+3YS971/<'1I;VXH)V=E='1E>'0G+"!T<G5E*3L*)'1E
M;7!L871E+3YS970H)W1A<VMS)RP@)'1A<VMS*3L*)'1E;7!L871E+3YS970H
M)VUA:6YT7W5R;"<L("1M86EN="T^9V5T36%I;G1E;F%N8V5&;W)M55),*"DI
M.PHD=&5M<&QA=&4M/G-E="@G;6%I;G1?<&]S=&1A=&$G+"`D;6%I;G0M/F=E
M=%!O<W1$871A*"DI.PHD=&5M<&QA=&4M/G-E="@G;F]T:69Y)RP@571I;#HZ
M8G5F9F5R3W5T<'5T*&%R<F%Y*"1N;W1I9FEC871I;VXL("=N;W1I9GDG*2P@
M87)R87DH)VQI<W1E;F5R<R<@/3X@)W-T871U<R<I*2D["@IR97%U:7)E($A/
M4D1%7U1%35!,051%4R`N("<O8V]M;6]N+6AE861E<BYI;F,G.PIE8VAO("1T
M96UP;&%T92T^9F5T8V@H2$]21$5?5$5-4$Q!5$53("X@)R]M86EN=&5N86YC
M92]M86EN=&5N86YC92YH=&UL)RD["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53
M("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+VQA;F=U86=E+G!H<```
M````````````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3,U-R`Q
M,#4Q-30S,S<T-"`P,C$V-C8`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J(%-C<FEP="!T;R!S970@=&AE
M(&YE=R!L86YG=6%G92X*("H*("H@)$AO<F1E.B!H;W)D92]S97)V:6-E<R]L
M86YG=6%G92YP:'`L=B`Q+C4N,3(N,R`R,#`V+S`Q+S`Q(#(Q.C(Y.C$P(&IA
M;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UA<FMO($1J=6MI
M8R`\;6%R:V]`;V)L;RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U(&1I9"!N;W0*("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H
M)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXG*3L*<F5Q
M=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["@HO*B!3
M970@=&AE(&QA;F=U86=E+B`J+PHD7U-%4U-)3TY;)VAO<F1E7VQA;F=U86=E
M)UT@/2!.3%,Z.G-E;&5C="@I.PHD<')E9G,M/G-E=%9A;'5E*"=L86YG=6%G
M92<L("1?4T534TE/3ELG:&]R9&5?;&%N9W5A9V4G72D["@HO*B!2961I<F5C
M="!T;R!T:&4@=7)L(&]R(&QO9VEN('!A9V4@:68@;F]N92!G:79E;BX@*B\*
M)'5R;"`](%5T:6PZ.F=E=$9O<FU$871A*"=U<FPG*3L*:68@*&5M<'1Y*"1U
M<FPI*2!["B`@("`D=7)L(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=I;F1E
M>"YP:'`G+"!T<G5E*3L*?0IH96%D97(H)TQO8V%T:6]N.B`G("X@)'5R;"D[
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<```````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M-S(U-B`Q,#4Q-30S,S<T-"`P,C,Q,3<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R
M9&4O<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP+'8@,2XQ+C(N,B`R,#`V
M+S`Q+S`Q(#(Q.C(Y.C$P(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P
M-2TR,#`V($-R;VYO<WES+"!,3$,@/&AT='`Z+R]W=W<N8W)O;F]S>7,N8V]M
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER
M;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"
M05-%("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T9O
M<FTN<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]&;W)M+U)E;F1E<F5R+G!H
M<"<["G)E<75I<F5?;VYC92`G2&]R9&4O5F%R:6%B;&5S+G!H<"<["@II9B`H
M(4%U=&@Z.FES075T:&5N=&EC871E9"@I*2!["B`@("!(;W)D93HZ875T:&5N
M=&EC871I;VY&86EL=7)E4F5D:7)E8W0H*3L*?0H*+R\@36%K92!S=7)E(&%U
M=&@@8F%C:V5N9"!A;&QO=W,@<&%S<W=O<F1S('1O(&)E(')E<V5T+@HD875T
M:"`]("9!=71H.CIS:6YG;&5T;VXH)&-O;F9;)V%U=&@G75LG9')I=F5R)UTI
M.PII9B`H(21A=71H+3YH87-#87!A8FEL:71Y*"=U<&1A=&4G*2D@>PH@("`@
M)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")#:&%N9VEN9R!Y;W5R('!A<W-W;W)D
M(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T
M:6]N+B`@0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(BDL("=H;W)D92YE
M<G)O<B<I.PH@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N($%U=&@Z.F=E=$QO
M9VEN4V-R965N*"<G+"!5=&EL.CIG971&;W)M1&%T82@G=7)L)RDI*3L*("`@
M(&5X:70["GT*"B1V87)S(#T@)E9A<FEA8FQE<SHZ9V5T1&5F875L=%9A<FEA
M8FQE<R@I.PH*)'1I=&QE(#T@7R@B0VAA;F=E(%EO=7(@4&%S<W=O<F0B*3L*
M)&9O<FT@/2`F2&]R9&5?1F]R;3HZ<VEN9VQE=&]N*"=(;W)D95-I9VYU<$9O
M<FTG+"`D=F%R<RP@)'1I=&QE*3L*)&9O<FTM/G-E=$)U='1O;G,H7R@B0V]N
M=&EN=64B*2D["@HD9F]R;2T^861D2&ED9&5N*"<G+"`G<F5T=7)N7W1O)RP@
M)W1E>'0G+"!F86QS92D["B1F;W)M+3YA9&1687)I86)L92A?*")/;&0@<&%S
M<W=O<F0B*2P@)V]L9%]P87-S=V]R9"<L("=P87-S=V]R9"<L('1R=64I.PHD
M9F]R;2T^861D5F%R:6%B;&4H7R@B3F5W('!A<W-W;W)D(BDL("=P87-S=V]R
M9%\Q)RP@)W!A<W-W;W)D)RP@=')U92D["B1F;W)M+3YA9&1687)I86)L92A?
M*")2971Y<&4@;F5W('!A<W-W;W)D(BDL("=P87-S=V]R9%\R)RP@)W!A<W-W
M;W)D)RP@=')U92D["@II9B`H)'9A<G,M/F5X:7-T<R@G9F]R;6YA;64G*2D@
M>PH@("`@)&9O<FTM/G9A;&ED871E*"1V87)S*3L*("`@(&EF("@D9F]R;2T^
M:7-686QI9"@I*2!["B`@("`@("`@)&9O<FTM/F=E=$EN9F\H)'9A<G,L("1I
M;F9O*3L*("`@("`@("!D;R!["B`@("`@("`@("`@(&EF("@D875T:"T^9V5T
M0W)E9&5N=&EA;"@G<&%S<W=O<F0G*2`A/2`D:6YF;ULG;VQD7W!A<W-W;W)D
M)UTI('L*("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B
M3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+B(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G:&]R9&4N97)R;W(G*3L*("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I
M9B`H)&EN9F];)W!A<W-W;W)D7S$G72`A/2`D:6YF;ULG<&%S<W=O<F1?,B==
M*2!["B`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(DYE
M=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N(BDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D
M:6YF;ULG;VQD7W!A<W-W;W)D)UT@/3T@)&EN9F];)W!A<W-W;W)D7S$G72D@
M>PH@("`@("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")/;&0@
M86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N(BDL("=H;W)D
M92YE<G)O<B<I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("\J($9)6$U%.B!.965D('1O(&-L96%N('5P('!A
M<W-W;W)D('!O;&EC>2!P871C:"!A;F0@8V]M;6ET(&)E9F]R90H@("`@("`@
M("`@("`@*B!E;F%B;&EN9R!T:&ES+BXN("U*348*"B`@("`@("`@("`@("1R
M97,@/2!!=71H.CIT97-T4&%S<W=O<F13=')E;F=T:"@D:6YF;ULG<&%S<W=O
M<F1?,2==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&-O;F9;)V%U=&@G75LG<&%S<W=O<F1?<&]L:6-Y)UTI.PH@
M("`@("`@("`@("!I9B`H:7-?82@D<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*"1R97,M/F=E=$UE
M<W-A9V4H*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`J+PH*("`@("`@("`@("`@
M)')E<R`]("1A=71H+3YU<&1A=&55<V5R*$%U=&@Z.F=E=$%U=&@H*2P@075T
M:#HZ9V5T075T:"@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@87)R87DH)W!A<W-W;W)D)R`]/B`D:6YF;ULG<&%S<W=O<F1?,2==
M*2D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97,L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT
M9BA?*")%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5S+3YG971-
M97-S86=E*"DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H
M(E!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+B(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=H;W)D92YS=6-C97-S)RD["B`@("`@
M("`@("`@(&EF("@A96UP='DH)&EN9F];)W)E='5R;E]T;R==*2D@>PH@("`@
M("`@("`@("`@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N("1I;F9O6R=R971U
M<FY?=&\G72D["B`@("`@("`@("`@("`@("!E>&ET.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T@=VAI;&4@*&9A;'-E*3L*
M("`@('T*?0H*)'9A<G,M/G)E;6]V92@G;VQD7W!A<W-W;W)D)RD["B1V87)S
M+3YR96UO=F4H)W!A<W-W;W)D7S$G*3L*)'9A<G,M/G)E;6]V92@G<&%S<W=O
M<F1?,B<I.PH*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUH
M96%D97(N:6YC)SL*)&YO=&EF:6-A=&EO;BT^;F]T:69Y*&%R<F%Y*"=L:7-T
M96YE<G,G(#T^("=S=&%T=7,G*2D["B1R96YD97)E<B`]("9N97<@2&]R9&5?
M1F]R;5]296YD97)E<B@I.PHD9F]R;2T^<F5N9&5R06-T:79E*"1R96YD97)E
M<BP@)'9A<G,L("=C:&%N9V5P87-S=V]R9"YP:'`G+"`G<&]S="<I.PIR97%U
M:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W-E<G9I8V5S+VIA=F%S8W)I<'0N<&AP````````````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,C0V,B`Q,#4Q-30S,S<T-"`P,C(R-#<`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J("1(;W)D93H@:&]R9&4O<V5R=FEC97,O:F%V87-C<FEP="YP:'`L
M=B`Q+C,W+C$P+C0@,C`P-B\P,2\P,2`R,3HR.3HQ,"!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#`M,C`P-B!#:&%R;&5S($HN($AA9V5N8G5C:"`\
M8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=(
M3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD["G)E<75I
M<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8V]R92YP:'`G.PH*)')E9VES
M=')Y(#T@)E)E9VES=')Y.CIS:6YG;&5T;VXH2$]21$5?4T534TE/3E]214%$
M3TY,62D["@HO+R!&:6=U<F4@;W5T(&EF('=E)W9E(&)E96X@:6YL:6YE9"P@
M;W(@8V%L;&5D(&1I<F5C=&QY+@HD<V5N9%]H96%D97)S(#T@<W1R<W1R*"1?
M4T525D526R=02%!?4T5,1B==+"`G:F%V87-C<FEP="YP:'`G*3L*"B1A<'`@
M/2!5=&EL.CIG971&;W)M1&%T82@G87!P)RP@571I;#HZ;F]N26YP=71687(H
M)V%P<"<I*3L*)&9I;&4@/2!5=&EL.CIG971&;W)M1&%T82@G9FEL92<L(%5T
M:6PZ.FYO;DEN<'5T5F%R*"=F:6QE)RDI.PII9B`H(65M<'1Y*"1A<'`I("8F
M("%E;7!T>2@D9FEL92D@)B8@<W1R<&]S*"1F:6QE+"`G+BXG*2`]/3T@9F%L
M<V4I('L*("`@("1S8W)I<'1?9FEL92`]("1R96=I<W1R>2T^9V5T*"=T96UP
M;&%T97,G+"`D87!P*2`N("<O:F%V87-C<FEP="\G("X@)&9I;&4["B`@("!I
M9B`H0&9I;&5?97AI<W1S*"1S8W)I<'1?9FEL92DI('L*("`@("`@("`D<F5G
M:7-T<GDM/G!U<VA!<'`H)&%P<"P@9F%L<V4I.PH@("`@("`@("1S8W)I<'0@
M/2!5=&EL.CIB=69F97)/=71P=70H)W)E<75I<F4G+"`D<V-R:7!T7V9I;&4I
M.PH*("`@("`@("!I9B`H)'-E;F1?:&5A9&5R<RD@>PH@("`@("`@("`@("`O
M*B!#;VUP<F5S<R!T:&4@2E,N(%=E(&YE960@=&AI<R!E>'!L:6-I="!C86QL
M('-I;F-E('=E"B`@("`@("`@("`@("`J(&1O;B=T(&EN8VQU9&4@8F%S92YP
M:'`@:6X@=&AI<R!F:6QE+B`J+PH@("`@("`@("`@("!(;W)D93HZ8V]M<')E
M<W-/=71P=70H*3L*"B`@("`@("`@("`@(&AE861E<B@G0V%C:&4M0V]N=')O
M;#H@;F\M8V%C:&4G*3L*("`@("`@("`@("`@:&5A9&5R*"=#;VYT96YT+51Y
M<&4Z('1E>'0O:F%V87-C<FEP="<I.PH@("`@("`@('T*"B`@("`@("`@96-H
M;R`D<V-R:7!T.PH@("`@?0I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O:V5Y8F]A<F0N<&AP
M````````````````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$S-30W
M(#$P-3$U-#,S-S0T(#`R,3<P-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*@H@*B`D2&]R9&4Z(&AO<F1E+W-E
M<G9I8V5S+VME>6)O87)D+G!H<"QV(#$N,3,N,3`N,R`R,#`V+S`Q+S`Q(#(Q
M.C(Y.C$P(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,2TR,#`V($-H
M=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I
M("X@)R\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A
M<V4N<&AP)SL*"B1T:71L92`](%\H(E-P96-I86P@0VAA<F%C=&5R($EN<'5T
M(BD["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R
M+FEN8R<["@H_/@H*/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H*
M=F%R('1A<F=E=#L*"F9U;F-T:6]N(&AA;F1L94QI<W1#:&%N9V4H=&AE3&ES
M="D@>PH@("`@=F%R(&YU;5-E;&5C=&5D(#T@=&AE3&ES="YS96QE8W1E9$EN
M9&5X.PH*("`@(&EF("AN=6U396QE8W1E9"`A/2`P*2!["B`@("`@("`@9&]C
M=6UE;G0N8VAA<F%C=&5R<RYT97AT8F]X+G9A;'5E("L]('1H94QI<W0N;W!T
M:6]N<UMN=6U396QE8W1E9%TN=F%L=64["B`@("`@("`@=&AE3&ES="YS96QE
M8W1E9$EN9&5X(#T@,#L*("`@('T*?0H\+W-C<FEP=#X*"CQF;W)M(&YA;64]
M(F-H87)A8W1E<G,B/@H\=&%B;&4@8V5L;'-P86-I;F<](C`B/@H@(#QT<CX*
M("`@(#QT9"!C;&%S<STB:71E;2!L969T06QI9VXB/@H@("`@("`\<#X\/W!H
M<"!E8VAO(%\H(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M
M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E
M('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+B(I(#\^/"]P/@H@("`@/"]T9#X*
M("`\+W1R/@H@(#QT<CX*("`@(#QT9"!C;&%S<STB;&5F=$%L:6=N(CX*("`@
M("`@/'1A8FQE(&-E;&QS<&%C:6YG/2(P(CX*("`@("`@("`\='(^"B`@("`@
M("`@("`\=&0@86QI9VX](F-E;G1E<B(^"B`@("`@("`@("`@(#QS96QE8W0@
M;F%M93TB82(@;VYC:&%N9V4](FAA;F1L94QI<W1#:&%N9V4H=&AI<RDB/@H@
M("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](F$B('-E;&5C=&5D/B!A(#PO
M;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,3DR.R(^
M("8C,3DR.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E
M/2(F(S(R-#LB/B`F(S(R-#L@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P
M=&EO;B!V86QU93TB)B,Q.3,[(CX@)B,Q.3,[(#PO;W!T:6]N/@H@("`@("`@
M("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C(U.R(^("8C,C(U.R`\+V]P=&EO
M;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S$Y-#LB/B`F(S$Y
M-#L@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R
M,C8[(CX@)B,R,C8[(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@
M=F%L=64](B8C,3DU.R(^("8C,3DU.R`\+V]P=&EO;CX*("`@("`@("`@("`@
M("`\;W!T:6]N('9A;'5E/2(F(S(R-SLB/B`F(S(R-SL@/"]O<'1I;VX^"B`@
M("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,Q.38[(CX@)B,Q.38[(#PO
M;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C(X.R(^
M("8C,C(X.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E
M/2(F(S$Y-SLB/B`F(S$Y-SL@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P
M=&EO;B!V86QU93TB)B,R,CD[(CX@)B,R,CD[(#PO;W!T:6]N/@H@("`@("`@
M("`@("`\+W-E;&5C=#X*("`@("`@("`@(#PO=&0^"B`@("`@("`@("`\=&0@
M86QI9VX](F-E;G1E<B(^"B`@("`@("`@("`@(#QS96QE8W0@;F%M93TB92(@
M;VYC:&%N9V4](FAA;F1L94QI<W1#:&%N9V4H=&AI<RDB/@H@("`@("`@("`@
M("`@(#QO<'1I;VX@=F%L=64](F4B('-E;&5C=&5D/B!E(#PO;W!T:6]N/@H@
M("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C`P.R(^("8C,C`P.R`\
M+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(S,CLB
M/B`F(S(S,CL@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU
M93TB)B,R,#$[(CX@)B,R,#$[(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO
M<'1I;VX@=F%L=64](B8C,C,S.R(^("8C,C,S.R`\+V]P=&EO;CX*("`@("`@
M("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(P,CLB/B`F(S(P,CL@/"]O<'1I
M;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R,S0[(CX@)B,R
M,S0[(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C
M,C`S.R(^("8C,C`S.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N
M('9A;'5E/2(F(S(S-3LB/B`F(S(S-3L@/"]O<'1I;VX^"B`@("`@("`@("`@
M(#PO<V5L96-T/@H@("`@("`@("`@/"]T9#X*("`@("`@("`@(#QT9"!A;&EG
M;CTB8V5N=&5R(CX*("`@("`@("`@("`@/'-E;&5C="!N86UE/2)I(B!O;F-H
M86YG93TB:&%N9&QE3&ES=$-H86YG92AT:&ES*2(^"B`@("`@("`@("`@("`@
M/&]P=&EO;B!V86QU93TB:2(@<V5L96-T960^(&D@/"]O<'1I;VX^"B`@("`@
M("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R,#0[(CX@)B,R,#0[(#PO;W!T
M:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C,V.R(^("8C
M,C,V.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F
M(S(P-3LB/B`F(S(P-3L@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO
M;B!V86QU93TB)B,R,S<[(CX@)B,R,S<[(#PO;W!T:6]N/@H@("`@("`@("`@
M("`@(#QO<'1I;VX@=F%L=64](B8C,C`V.R(^("8C,C`V.R`\+V]P=&EO;CX*
M("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(S.#LB/B`F(S(S.#L@
M/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R,#<[
M(CX@)B,R,#<[(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L
M=64](B8C,C,Y.R(^("8C,C`W.R`\+V]P=&EO;CX*("`@("`@("`@("`@/"]S
M96QE8W0^"B`@("`@("`@("`\+W1D/@H@("`@("`@("`@/'1D(&%L:6=N/2)C
M96YT97(B/@H@("`@("`@("`@("`\<V5L96-T(&YA;64](F\B(&]N8VAA;F=E
M/2)H86YD;&5,:7-T0VAA;F=E*'1H:7,I(CX*("`@("`@("`@("`@("`\;W!T
M:6]N('9A;'5E/2)O(B!S96QE8W1E9#X@;R`\+V]P=&EO;CX*("`@("`@("`@
M("`@("`\;W!T:6]N('9A;'5E/2(F(S(Q,#LB/B`F(S(Q,#L@/"]O<'1I;VX^
M"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R-#([(CX@)B,R-#([
M(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C$Q
M.R(^("8C,C$Q.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A
M;'5E/2(F(S(T,SLB/B`F(S(T,SL@/"]O<'1I;VX^"B`@("`@("`@("`@("`@
M/&]P=&EO;B!V86QU93TB)B,R,3([(CX@)B,R,3([(#PO;W!T:6]N/@H@("`@
M("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C0T.R(^("8C,C0T.R`\+V]P
M=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(Q,SLB/B`F
M(S(Q,SL@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB
M)B,R-#4[(CX@)B,R-#4[(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I
M;VX@=F%L=64](B8C,C$T.R(^("8C,C$T.R`\+V]P=&EO;CX*("`@("`@("`@
M("`@("`\;W!T:6]N('9A;'5E/2(F(S(T-CLB/B`F(S(T-CL@/"]O<'1I;VX^
M"B`@("`@("`@("`@(#PO<V5L96-T/@H@("`@("`@("`@/"]T9#X*("`@("`@
M("`@(#QT9"!A;&EG;CTB8V5N=&5R(CX*("`@("`@("`@("`@/'-E;&5C="!N
M86UE/2)U(B!O;F-H86YG93TB:&%N9&QE3&ES=$-H86YG92AT:&ES*2(^"B`@
M("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB=2(@<V5L96-T960^('4@/"]O
M<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R,3<[(CX@
M)B,R,3<[(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64]
M(B8C,C0Y.R(^("8C,C0Y.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T
M:6]N('9A;'5E/2(F(S(Q.#LB/B`F(S(Q.#L@/"]O<'1I;VX^"B`@("`@("`@
M("`@("`@/&]P=&EO;B!V86QU93TB)B,R-3`[(CX@)B,R-3`[(#PO;W!T:6]N
M/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C$Y.R(^("8C,C$Y
M.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(U
M,3LB/B`F(S(U,3L@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V
M86QU93TB)B,R,C`[(CX@)B,R,C`[(#PO;W!T:6]N/@H@("`@("`@("`@("`@
M(#QO<'1I;VX@=F%L=64](B8C,C4R.R(^("8C,C4R.R`\+V]P=&EO;CX*("`@
M("`@("`@("`@/"]S96QE8W0^"B`@("`@("`@("`\+W1D/@H@("`@("`@("`@
M/'1D(&%L:6=N/2)C96YT97(B/@H@("`@("`@("`@("`\<V5L96-T(&YA;64]
M(D]T:&5R(B!O;F-H86YG93TB:&%N9&QE3&ES=$-H86YG92AT:&ES*2(^"B`@
M("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB;6ES8R(@<V5L96-T960^(#P_
M<&AP(&5C:&\@7R@B3W1H97(B*3L@/SX\+V]P=&EO;CX*("`@("`@("`@("`@
M("`\;W!T:6]N('9A;'5E/2(F(S$V,CLB/B`F(S$V,CL@/"]O<'1I;VX^"B`@
M("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,Q-C,[(CX@)B,Q-C,[(#PO
M;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,38T.R(^
M("8C,38T.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E
M/2(F(S$V-3LB/B`F(S$V-3L@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P
M=&EO;B!V86QU93TB)B,Q.3@[(CX@)B,Q.3@[(#PO;W!T:6]N/@H@("`@("`@
M("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C,P.R(^("8C,C,P.R`\+V]P=&EO
M;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(R,SLB/B`F(S(R
M,SL@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,Q
M.3D[(CX@)B,Q.3D[(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@
M=F%L=64](B8C,C,Q.R(^("8C,C,Q.R`\+V]P=&EO;CX*("`@("`@("`@("`@
M("`\;W!T:6]N('9A;'5E/2(F(S(P.3LB/B`F(S(P.3L@/"]O<'1I;VX^"B`@
M("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R-#$[(CX@)B,R-#$[(#PO
M;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C4S.R(^
M("8C,C4S.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E
M/2(F(S(U-3LB/B`F(S(U-3L@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P
M=&EO;B!V86QU93TB)B,Q.3$[(CX@)B,Q.3$[(#PO;W!T:6]N/@H@("`@("`@
M("`@("`@(#QO<'1I;VX@=F%L=64](B8C,38Q.R(^("8C,38Q.R`\+V]P=&EO
M;CX*("`@("`@("`@("`@/"]S96QE8W0^"B`@("`@("`@("`\+W1D/@H@("`@
M("`@(#PO='(^"B`@("`@(#PO=&%B;&4^"B`@("`\+W1D/@H@(#PO='(^"B`@
M/'1R/@H@("`@/'1D(&-L87-S/2)F:7AE9"!L969T06QI9VXB/@H@("`@("`\
M=&5X=&%R96$@<F]W<STB-"(@8V]L<STB,C4B(&-L87-S/2)F:7AE9"(@;F%M
M93TB=&5X=&)O>"(^/"]T97AT87)E83X*("`@(#PO=&0^"B`@/"]T<CX*("`\
M='(^"B`@("`\=&0@86QI9VX](F-E;G1E<B(^"B`@("`@(#QI;G!U="!T>7!E
M/2)B=71T;VXB(&-L87-S/2)B=71T;VXB(&]N8VQI8VL](G=I;F1O=RYC;&]S
M92@I.R(@;F%M93TB8VQO<V4B('9A;'5E/2(\/W!H<"!E8VAO(%\H(D-L;W-E
M(%=I;F1O=R(I(#\^(B`O/@H@("`@/"]T9#X*("`\+W1R/@H\+W1A8FQE/@H\
M+V9O<FT^"CPO8F]D>3X*/"]H=&UL/@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]C86-H979I97<N<&AP````
M````````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$T-S8@,3`U
M,34T,S,W-#0@,#(R,#0S`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W-E<G9I
M8V5S+V-A8VAE=FEE=RYP:'`L=B`Q+CDN,3`N,R`R,#`V+S`Q+S`Q(#(Q.C(Y
M.C$P(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K
M($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO
M"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G
M+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP
M:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T-A8VAE+G!H<"<["@HD8VED(#T@
M571I;#HZ9V5T1F]R;41A=&$H)V-I9"<I.PII9B`H96UP='DH)&-I9"DI('L*
M("`@(&5X:70["GT*"B1C86-H92`]("9(;W)D95]#86-H93HZ<VEN9VQE=&]N
M*"1C;VYF6R=C86-H92==6R=D<FEV97(G72P@2&]R9&4Z.F=E=$1R:79E<D-O
M;F9I9R@G8V%C:&4G+"`D8V]N9ELG8V%C:&4G75LG9')I=F5R)UTI*3L*)&-D
M871A(#T@0'5N<V5R:6%L:7IE*"1C86-H92T^9V5T*"1C:60L("1C;VYF6R=C
M86-H92==6R=D969A=6QT7VQI9F5T:6UE)UTI*3L*:68@*"$D8V1A=&$I('L*
M("`@(&5X:70["GT*"B1B<F]W<V5R+3YD;W=N;&]A9$AE861E<G,H)V-A8VAE
M3V)J96-T)RP@)&-D871A6R=C='EP92==+"!T<G5E+"!S=')L96XH)&-D871A
M6R=D871A)UTI*3L*96-H;R`D8V1A=&%;)V1A=&$G73L*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<```````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3`P
M,C`@,3`U,34T,S,W-#0@,#(R-S<S`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E
M+W-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP+'8@,2XU+C$P+C<@,C`P-B\P
M-2\R-"`R,CHT-3HQ,R!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P
M-"TR,#`V($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*B\*"D!D969I;F4H)T%55$A?2$%.1$Q%4B<L('1R=64I.PI`9&5F
M:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD[
M"G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PIR
M97%U:7)E7V]N8V4@)TAO<F1E+T9O<FTN<&AP)SL*<F5Q=6ER95]O;F-E("=(
M;W)D92]3=')I;F<N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]687)I86)L
M97,N<&AP)SL*"B\O($UA:V4@<W5R92!A=71H(&)A8VME;F0@86QL;W=S('!A
M<W-W;W)D<R!T;R!B92!R97-E="X*)&%U=&@@/2`F075T:#HZ<VEN9VQE=&]N
M*"1C;VYF6R=A=71H)UU;)V1R:79E<B==*3L*:68@*"$D875T:"T^:&%S0V%P
M86)I;&ET>2@G<F5S971P87-S=V]R9"<I*2!["B`@("`D;F]T:69I8V%T:6]N
M+3YP=7-H*%\H(D-A;FYO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY
M+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB*2P@)VAO<F1E+F5R<F]R
M)RD["B`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@075T:#HZ9V5T3&]G:6Y3
M8W)E96XH)R<L(%5T:6PZ.F=E=$9O<FU$871A*"=U<FPG*2DI.PH@("`@97AI
M=#L*?0H*)'9A<G,@/2`F5F%R:6%B;&5S.CIG971$969A=6QT5F%R:6%B;&5S
M*"D["@HD=&ET;&4@/2!?*")297-E="!9;W5R(%!A<W-W;W)D(BD["B1F;W)M
M(#T@)DAO<F1E7T9O<FTZ.G-I;F=L971O;B@G2&]R9&53:6=N=7!&;W)M)RP@
M)'9A<G,L("1T:71L92D["B1F;W)M+3YS971"=71T;VYS*%\H(D-O;G1I;G5E
M(BDI.PH*+RH@4V5T('5P('1H92!F:65L9',@9F]R('1H92!U<V5R;F%M92!A
M;F0@86QT97)N871E(&5M86EL+B`J+PHD9F]R;2T^861D2&ED9&5N*"<G+"`G
M=7)L)RP@)W1E>'0G+"!F86QS92D["B1V(#T@)B1F;W)M+3YA9&1687)I86)L
M92A?*")5<V5R;F%M92(I+"`G=7-E<FYA;64G+"`G=&5X="<L('1R=64I.PHD
M=BT^<V5T3W!T:6]N*"=T<F%C:V-H86YG92<L('1R=64I.PHD9F]R;2T^861D
M5F%R:6%B;&4H7R@B06QT97)N871E(&5M86EL(&%D9')E<W,B*2P@)V5M86EL
M)RP@)V5M86EL)RP@=')U92D["B1C86Y?=F%L:61A=&4@/2!F86QS93L*"B\J
M($EF(&$@=7-E<FYA;64@:&%S(&)E96X@<W5P<&QI960@=')Y(&9E=&-H:6YG
M('1H92!P<F5F<R!S=&]R960@:6YF;RX@*B\*:68@*"1U<V5R;F%M92`]("1V
M87)S+3YG970H)W5S97)N86UE)RDI('L*("`@("1U<V5R;F%M92`]($%U=&@Z
M.F%D9$AO;VLH)'5S97)N86UE*3L*("`@("1P<F5F<R`]("90<F5F<SHZ<VEN
M9VQE=&]N*"1C;VYF6R=P<F5F<R==6R=D<FEV97(G72P@)VAO<F1E)RP@)'5S
M97)N86UE+"`G)RP@;G5L;"P@9F%L<V4I.PH@("`@)'!R969S+3YR971R:65V
M92@I.PH@("`@)&5M86EL(#T@)'!R969S+3YG971686QU92@G86QT97)N871E
M7V5M86EL)RD["B`@("`O*B!$;V5S('1H92!A;'1E<FYA=&4@96UA:6P@<W1O
M<F5D(&EN('!R969S(&UA=&-H('1H92!O;F4@<W5B;6ET=&5D/R`J+PH@("`@
M:68@*"1V87)S+3YG970H)V5M86EL)RD@/3T@)&5M86EL*2!["B`@("`@("`@
M)&-A;E]V86QI9&%T92`]('1R=64["B`@("`@("`@)&9O<FTM/G-E=$)U='1O
M;G,H7R@B4F5S970@4&%S<W=O<F0B*2D["B`@("`@("`@)'%U97-T:6]N(#T@
M)'!R969S+3YG971686QU92@G<V5C=7)I='E?<75E<W1I;VXG*3L*("`@("`@
M("`D9F]R;2T^861D5F%R:6%B;&4H)'%U97-T:6]N+"`G<75E<W1I;VXG+"`G
M9&5S8W)I<'1I;VXG+"!F86QS92D["B`@("`@("`@)&9O<FTM/F%D9%9A<FEA
M8FQE*%\H(D%N<W=E<B(I+"`G86YS=V5R)RP@)W1E>'0G+"!T<G5E*3L*("`@
M('T@96QS92!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*"));F-O
M<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I
M;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F
M=7)T:&5R(&AE;'`N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@?0I]"@HO*B!6
M86QI9&%T92!T:&4@9F]R;2X@*B\*:68@*"1C86Y?=F%L:61A=&4@)B8@)&9O
M<FTM/G9A;&ED871E*"1V87)S*2D@>PH@("`@)&9O<FTM/F=E=$EN9F\H)'9A
M<G,L("1I;F9O*3L*"B`@("`O*B!&971C:"!V86QU97,@9G)O;2!P<F5F<R!F
M;W(@<V5L96-T960@=7-E<BX@*B\*("`@("1A;G-W97(@/2`D<')E9G,M/F=E
M=%9A;'5E*"=S96-U<FET>5]A;G-W97(G*3L*"B`@("`O*B!#:&5C:R!T:&4@
M9VEV96X@=F%L=65S('=I=&AT('1H92!P<F5F<R!S=&]R960@;VYE<RX@*B\*
M("`@(&EF("@D96UA:6P@/3T@)&EN9F];)V5M86EL)UT@)B8@4W1R:6YG.CIL
M;W=E<B@D86YS=V5R*2`]/2!3=')I;F<Z.FQO=V5R*"1I;F9O6R=A;G-W97(G
M72DI('L*("`@("`@("`O*B!);F9O(&UA=&-H97,L('-O(')E<V5T('1H92!P
M87-S=V]R9"X@*B\*("`@("`@("`D<&%S<W=O<F0@/2`D875T:"T^<F5S9710
M87-S=V]R9"@D:6YF;ULG=7-E<FYA;64G72D["@H@("`@("`@(')E<75I<F5?
M;VYC92`G36%I;"YP:'`G.PH@("`@("`@("1M86EL97(@/2!-86EL.CIF86-T
M;W)Y*"1C;VYF6R=M86EL97(G75LG='EP92==+"`D8V]N9ELG;6%I;&5R)UU;
M)W!A<F%M<R==*3L*"B`@("`@("`@+RH@4V5T('5P('1H92!E;6%I;"!H96%D
M97)S(&%N9"!B;V1Y+B`J+PH@("`@("`@("1H96%D97)S6R=&<F]M)UT@/2`D
M96UA:6P["B`@("`@("`@)&AE861E<G-;)U1O)UT@/2`D96UA:6P["B`@("`@
M("`@)')E8VEP:65N='-;72`]("1H96%D97)S6R=4;R==.PH@("`@("`@("1H
M96%D97)S6R=3=6)J96-T)UT@/2!?*")9;W5R('!A<W-W;W)D(&AA<R!B965N
M(')E<V5T(BD["B`@("`@("`@)&)O9'D@/2!S<')I;G1F*%\H(EEO=7(@;F5W
M('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B*2P@)')E9VES=')Y+3YG970H)VYA
M;64G+"`G:&]R9&4G*2P@)'!A<W-W;W)D*3L*("`@("`@("`D;6%I;&5R+3YS
M96YD*"1R96-I<&EE;G1S+"`D:&5A9&5R<RP@)&)O9'DI.PH*("`@("`@("`D
M;F]T:69I8V%T:6]N+3YP=7-H*%\H(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@
M<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@
M;F5W('!A<W-W;W)D+B(I+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@("`@(&AE
M861E<B@G3&]C871I;VXZ("<@+B!!=71H.CIG971,;V=I;E-C<F5E;B@G)RP@
M)&EN9F];)W5R;"==*2D["B`@("`@("`@97AI=#L*("`@('T@96QS92!["B`@
M("`@("`@+RH@26YF;R!S=6)M:71T960@9&]E<R!N;W0@;6%T8V@@=VAA="!I
M<R!I;B!P<F5F<RP@<F5D:7)E8W0@=7-E<B!B86-K"B`@("`@("`@("H@=&\@
M;&]G:6XN("HO"B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")#;W5L
M9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S
M97(N(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS(&%R92!N;W0@8V]R<F5C
M="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF
M('EO=2!N965D(&9U<G1H97(@:&5L<"XB*2P@)VAO<F1E+F5R<F]R)RD["B`@
M("!]"GT*"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A
M9&5R+FEN8R<["B1N;W1I9FEC871I;VXM/FYO=&EF>2AA<G)A>2@G;&ES=&5N
M97)S)R`]/B`G<W1A='5S)RDI.PIR97%U:7)E7V]N8V4@)TAO<F1E+T9O<FTO
M4F5N9&5R97(N<&AP)SL*)')E;F1E<F5R(#T@)FYE=R!(;W)D95]&;W)M7U)E
M;F1E<F5R*"D["B1F;W)M+3YR96YD97)!8W1I=F4H)')E;F1E<F5R+"`D=F%R
M<RP@)W)E<V5T<&%S<W=O<F0N<&AP)RP@)W!O<W0G*3L*<F5Q=6ER92!(3U)$
M15]414U03$%415,@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+W!R969S+G!H<```````````````
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,#0U-"`Q,#4Q-30S
M,S<T-"`P,C$R,C``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O<V5R=FEC97,O
M<')E9G,N<&AP+'8@,2XQ.2XR+C$P(#(P,#8O,#(O,#<@,C,Z-3`Z,#`@:F%N
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAA<FQE<R!*+B!(
M86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#$Y.3DM
M,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("HO"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@
M+B`G+RXN)RD["G)E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O
M+BXO;&EB+V-O<F4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]0<F5F<R]5
M22YP:'`G.PH*)')E9VES=')Y(#T@)E)E9VES=')Y.CIS:6YG;&5T;VXH*3L*
M"B\J($9I9W5R92!O=70@=VAI8V@@87!P;&EC871I;VX@=V4G<F4@<V5T=&EN
M9R!P<F5F97)E;F-E<R!F;W(N("HO"B1A<'`@/2!5=&EL.CIG971&;W)M1&%T
M82@G87!P)RP@4')E9G-?54DZ.F=E=$1E9F%U;'1!<'`H*2D["B1A<'!B87-E
M(#T@)')E9VES=')Y+3YG970H)V9I;&5R;V]T)RP@)&%P<"D["@HO*B!3964@
M:68@=V4@:&%V92!A('!R969E<F5N8V5S(&=R;W5P('-E="X@*B\*)&=R;W5P
M(#T@571I;#HZ9V5T1F]R;41A=&$H)V=R;W5P)RD["@HO*B!,;V%D("1A<'`G
M<R!B87-E(&5N=FER;VYM96YT+"!B=70@9&]N)W0@<F5Q=65S="!T:&%T('1H
M92!A<'`@<&5R9F]R;0H@*B!A=71H96YT:6-A=&EO;B!B97EO;F0@2&]R9&4G
M<RX@*B\*)&%U=&AE;G1I8V%T:6]N(#T@)VYO;F4G.PIR97%U:7)E7V]N8V4@
M)&%P<&)A<V4@+B`G+VQI8B]B87-E+G!H<"<["@HO*B!3970@=&ET;&4N("HO
M"B1T:71L92`]('-P<FEN=&8H7R@B3W!T:6]N<R!F;W(@)7,B*2P@)')E9VES
M=')Y+3YG970H)VYA;64G*2D["@HO*B!3<&5C:6%L(&-A<V4@=VAE<F4@=V4@
M;F5E9"!T:&4@261E;G1I='D@;V)J96-T(&EN($AO<F1E)W,@<')E9G,N<&AP
M+B`J+PII9B`H)&=R;W5P(#T]("=I9&5N=&ET:65S)R`F)B`D87!P(#T]("=H
M;W)D92<I('L*("`@(')E<75I<F5?;VYC92`G2&]R9&4O261E;G1I='DN<&AP
M)SL*("`@("1I9&5N=&ET>2`]("9)9&5N=&ET>3HZ<VEN9VQE=&]N*"1A<'`@
M/3T@)VAO<F1E)R`_(&YU;&P@.B!A<G)A>2@D87!P+"`D87!P*2D["GT*"B\J
M($QO860@)&%P<"=S('!R969E<F5N8V5S+"!I9B!A;GDN("HO"B1P<F5F1W)O
M=7!S(#T@87)R87DH*3L*:68@*&9I;&5?97AI<W1S*"1A<'!B87-E("X@)R]C
M;VYF:6<O<')E9G,N<&AP)RDI('L*("`@(')E<75I<F4@)&%P<&)A<V4@+B`G
M+V-O;F9I9R]P<F5F<RYP:'`G.PI]"@HO*B!,;V%D(&-U<W1O;2!P<F5F97)E
M;F-E(&AA;F1L97)S(&9O<B`D87!P+"!I9B!P<F5S96YT+B`J+PII9B`H9FEL
M95]E>&ES=',H)&%P<&)A<V4@+B`G+VQI8B]P<F5F<RYP:'`G*2D@>PH@("`@
M<F5Q=6ER95]O;F-E("1A<'!B87-E("X@)R]L:6(O<')E9G,N<&AP)SL*?0H*
M+RH@268@=&AE<F4G<R!O;FQY(&]N92!P<F5F1W)O=7`L(&IU<W0@<VAO=R!I
M="X@*B\*:68@*&5M<'1Y*"1G<F]U<"D@)B8@8V]U;G0H)'!R969'<F]U<',I
M(#T](#$I('L*("`@("1G<F]U<"`](&%R<F%Y7VME>7,H)'!R969'<F]U<',I
M.PH@("`@)&=R;W5P(#T@87)R87E?<&]P*"1G<F]U<"D["GT*"FEF("@D9W)O
M=7`@/3T@)VED96YT:71I97,G*2!["B`@("!R97%U:7)E7V]N8V4@)TAO<F1E
M+TED96YT:71Y+G!H<"<["B`@("`D:61E;G1I='D@/2`F261E;G1I='DZ.G-I
M;F=L971O;B@D87!P(#T]("=H;W)D92<@/R!N=6QL(#H@87)R87DH)&%P<"P@
M)&%P<"DI.PH@("`@:68@*"1A<'`@(3T@)VAO<F1E)RD@>PH@("`@("`@(&EF
M("A5=&EL.CIN;VY);G!U=%9A<B@G<')E9D=R;W5P<R<I*2!["B`@("`@("`@
M("`@("1K965P4')E9D=R;W5P<R`]("1P<F5F1W)O=7!S.PH@("`@("`@("`@
M("!U;G-E="@D<')E9D=R;W5P<RD["B`@("`@("`@?0H@("`@("`@(')E<75I
M<F4@2$]21$5?0D%312`N("<O8V]N9FEG+W!R969S+G!H<"<["B`@("`@("`@
M)&AO<F1E7VUE;6)E<G,@/2`D<')E9D=R;W5P<ULG:61E;G1I=&EE<R==6R=M
M96UB97)S)UT["B`@("`@("`@:68@*%5T:6PZ.FYO;DEN<'5T5F%R*"=K965P
M4')E9D=R;W5P<R<I*2!["B`@("`@("`@("`@("1P<F5F1W)O=7!S(#T@)&ME
M97!0<F5F1W)O=7!S.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@('5N
M<V5T*"1P<F5F1W)O=7!S*3L*("`@("`@("!]"B`@("!]"@H@("`@:68@*&ES
M<V5T*"1H;W)D95]M96UB97)S*2D@>PH@("`@("`@("1P<F5F1W)O=7!S6R=I
M9&5N=&ET:65S)UU;)VUE;6)E<G,G72`](&%R<F%Y7VUE<F=E*"1H;W)D95]M
M96UB97)S+"`D<')E9D=R;W5P<ULG:61E;G1I=&EE<R==6R=M96UB97)S)UTI
M.PH@("`@?0H*("`@('-W:71C:"`H571I;#HZ9V5T1F]R;41A=&$H)V%C=&EO
M;DE$)RDI('L*("`@(&-A<V4@)W5P9&%T95]P<F5F<R<Z"B`@("`@("`@:68@
M*"1P<F5F<RT^:7-,;V-K960H)V1E9F%U;'1?:61E;G1I='DG*2D@>PH@("`@
M("`@("`@("`D9&5F875L="`]("1I9&5N=&ET>2T^9V5T1&5F875L="@I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1D969A=6QT(#T@571I;#HZ
M9V5T4&]S="@G9&5F875L=%]I9&5N=&ET>2<I.PH@("`@("`@("`@("`D:60@
M/2!5=&EL.CIG9710;W-T*"=I9&5N=&ET>2<I.PH@("`@("`@("`@("!I9B`H
M)&ED(#T]("TQ*2!["B`@("`@("`@("`@("`@("`D:60@/2`D:61E;G1I='DM
M/F%D9"@I.PH@("`@("`@("`@("!](&5L<V5I9B`H)&ED(#T]("TR*2!["B`@
M("`@("`@("`@("`@("`D<')E9D=R;W5P<ULG:61E;G1I=&EE<R==6R=M96UB
M97)S)UT@/2!A<G)A>2@G9&5F875L=%]I9&5N=&ET>2<I.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1I9&5N=&ET>2T^<V5T1&5F875L="@D:60I.PH@
M("`@("`@('T*("`@("`@("!I9B`H4')E9G-?54DZ.FAA;F1L949O<FTH)&=R
M;W5P+"`D:61E;G1I='DI*2!["B`@("`@("`@("`@("1R97-U;'0@/2`D:61E
M;G1I='DM/G9E<FEF>2@I.PH@("`@("`@("`@("`D:61E;G1I='DM/G-E=$1E
M9F%U;'0H)&1E9F%U;'0I.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D;F]T:69I8V%T
M:6]N+3YP=7-H*"1R97-U;'0L("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&ED96YT:71Y+3YS879E*"D[
M"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M:61E;G1I='DM/G-E=$1E9F%U;'0H)&1E9F%U;'0I.PH@("`@("`@("`@("`D
M:61E;G1I='DM/G-A=F4H*3L*("`@("`@("!]"B`@("`@("`@=6YS970H)'!R
M969'<F]U<',I.PH@("`@("`@(')E<75I<F4@)&%P<&)A<V4@+B`G+V-O;F9I
M9R]P<F5F<RYP:'`G.PH@("`@("`@(&)R96%K.PH*("`@(&-A<V4@)V1E;&5T
M95]I9&5N=&ET>2<Z"B`@("`@("`@)&ED(#T@*&EN="E5=&EL.CIG971&;W)M
M1&%T82@G:60G*3L*("`@("`@("`D9&5L971E9%]I9&5N=&ET>2`]("1I9&5N
M=&ET>2T^9&5L971E*"1I9"D["B`@("`@("`@=6YS970H)%]P<F5F<ULG9&5F
M875L=%]I9&5N=&ET>2==6R=E;G5M)UU;)&ED72D["B`@("`@("`@)&YO=&EF
M:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E1H92!I9&5N=&ET>2!<(B5S7"(@
M:&%S(&)E96X@9&5L971E9"XB*2P@)&1E;&5T961?:61E;G1I='E;,%U;)VED
M)UTI+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@("`@(&)R96%K.PH*("`@(&-A
M<V4@)V-H86YG95]D969A=6QT7VED96YT:71Y)SH*("`@("`@("`D9&5F875L
M=%]I9&5N=&ET>2`]("1I9&5N=&ET>2T^<V5T1&5F875L="A5=&EL.CIG971&
M;W)M1&%T82@G:60G*2D["B`@("`@("`@)&ED96YT:71Y+3YS879E*"D["B`@
M("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")9;W5R(&1E9F%U;'0@:61E
M;G1I='D@:&%S(&)E96X@8VAA;F=E9"XB*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=H;W)D92YS=6-C97-S)RD["B`@("`@("`@8G)E86L["B`@
M("!]"GT@96QS96EF("A0<F5F<U]523HZ:&%N9&QE1F]R;2@D9W)O=7`L("1P
M<F5F<RDI('L*("`@(')E<75I<F4@)&%P<&)A<V4@+B`G+V-O;F9I9R]P<F5F
M<RYP:'`G.PI]"@HO*B!3:&]W('1H92!522X@*B\*4')E9G-?54DZ.F=E;F5R
M871E54DH)&=R;W5P*3L*"G)E<75I<F4@)')E9VES=')Y+3YG970H)W1E;7!L
M871E<R<L("=H;W)D92<I("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<V5R=FEC97,O9V\N<&AP````````````````````````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`U-C4P(#$P-3$U-#,S-S0T(#`R,#4Q
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@02!S8W)I<'0@=&\@<F5D:7)E8W0@=&\@82!G:79E;B!5
M4DPL('5S960@9F]R(&5X86UP;&4@:6X@24U0('1O(&AI9&4@86YY"B`J(')E
M9F5R<F5R(&1A=&$@8F5I;F<@<&%S<V5D('1O('1H92!R96UO=&4@<V5R=F5R
M(&%N9"!P;W1E;G1I86QL>2!E>'!O<VEN9PH@*B!A;GD@<V5S<VEO;B!)1',N
M"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36%R:V\@1&IU:VEC(#QM87)K
M;T!O8FQO+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED
M"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J("1(;W)D93H@:&]R9&4O
M<V5R=FEC97,O9V\N<&AP+'8@,2XV+C(N,38@,C`P-B\P-B\R,B`P,CHT,SHR
M-"!C:'5C:R!%>'`@)`H@*@H@*B!`875T:&]R($UA<FMO($1J=6MI8R`\;6%R
M:V]`;V)L;RYC;VT^"B`J+PH*:68@*&5M<'1Y*"1?1T546R=U<FPG72DI('L*
M("`@(&5X:70["GT*"B1U<FP@/2!T<FEM*"1?1T546R=U<FPG72D["FEF("AP
M<F5G7VUA=&-H*"<O.UQS*G5R;%QS*CTO:2<L("1U<FPI*2!["B`@("`O*B!)
M12!W:6QL('!R;V-E<W,@=&AE(&QA<W0@.U523#T@<W1R:6YG+"!N;W0@=&AE
M(&9I<G-T+"!A;&QO=VEN9PH@("`@("H@<')O=&]C;VQS('1H870@<VAO=6QD
M;B=T(&)E(&QE="!T:')O=6=H+B`J+PH@("`@97AI=#L*?0H*:68@*&=E=%]M
M86=I8U]Q=6]T97-?9W!C*"DI('L*("`@("1P87)S961?=7)L(#T@0'!A<G-E
M7W5R;"AS=')I<'-L87-H97,H)'5R;"DI.PI](&5L<V4@>PH@("`@)'!A<G-E
M9%]U<FP@/2!`<&%R<V5?=7)L*"1U<FPI.PI]"@II9B`H96UP='DH)'!A<G-E
M9%]U<FPI('Q\(&5M<'1Y*"1P87)S961?=7)L6R=H;W-T)UTI*2!["B`@("!E
M>&ET.PI]"FEF("AE;7!T>2@D<&%R<V5D7W5R;%LG<&%T:"==*2D@>PH@("`@
M)'!A<G-E9%]U<FQ;)W!A=&@G72`](&9A;'-E.PI]"@HO+R!$;R!A(&QI='1L
M92!D=64@9&EL:6=E;F-E(&]N('1H92!T87)G970@55),+B!)9B!I="=S(&]N
M('1H92!S86UE('-E<G9E<@HO+R!T:&%T('=E)W)E(&%L<F5A9'D@;VXL(&1I
M<W!L87D@86X@:6YT97)M961I871E('!A9V4@87-K:6YG('!E;W!L92!I9@HO
M+R!T:&5Y)W)E('-U<F4@=&AE>2!W86YT('1O(&-L:6-K('1H<F]U9V@N"FEF
M("AS=6)S='(H<&AP7W-A<&E?;F%M92@I+"`P+"`S*2`]/2`G8V=I)RD@>PH@
M("`@+R\@5VAE;B!U<VEN9R!#1TD@4$A0+"!30U))4%1?3D%-12!M87D@8V]N
M=&%I;B!T:&4@<&%T:"!T;R!T:&4@4$A0(&)I;F%R>0H@("`@+R\@:6YS=&5A
M9"!O9B!T:&4@<V-R:7!T(&)E:6YG(')U;CL@=7-E(%!(4%]314Q&(&EN<W1E
M860N"B`@("`D;7EU<FP@/2`D7U-%4E9%4ELG4$A07U-%3$8G73L*?2!E;'-E
M('L*("`@("1M>75R;"`](&ES<V5T*"1?4T525D526R=30U))4%1?3D%-12==
M*2`_"B`@("`@("`@)%]315)615);)U-#4DE05%].04U%)UT@.@H@("`@("`@
M("1?4T525D526R=02%!?4T5,1B==.PI]"B\O(#$V(&ES('1H92!L96YG=&@@
M;V8@(B]S97)V:6-E<R]G;RYP:'`B+@HD=V5B<F]O="`]('-U8G-T<B@D;7EU
M<FPL(#`L("TQ-BD["@HO+R!"=6EL9"!A(&QI<W0@;V8@:&]S=',@8V]N<VED
M97)E9"!D86YG97)O=7,@*&QO8V%L(&AO<W1S+"!T:&4@=7-E<B=S"B\O(&AO
M<W0L(&5T8RDN"B1D86YG97)O=7-?:&]S=',@/2!A<G)A>2@G;&]C86QH;W-T
M)RP@)VQO8V%L:&]S="YL;V-A;&1O;6%I;B<L("<Q,C<N,"XP+C$G*3L*:68@
M*"%E;7!T>2@D7U-%4E9%4ELG4T525D527TY!344G72DI('L*("`@("1D86YG
M97)O=7-?:&]S='-;72`]("1?4T525D526R=315)615)?3D%-12==.PI]"FEF
M("@A96UP='DH)%]315)615);)TA45%!?2$]35"==*2D@>PH@("`@)&1A;F=E
M<F]U<U]H;W-T<UM=(#T@)%]315)615);)TA45%!?2$]35"==.PI]"@HO+R!,
M:7-T(&]F(&%L;&]W960@<V5R=FEC97,N"B1A;&QO=V5D7W5R:7,@/2!A<G)A
M>2@I.PH*+R\@0VAE8VL@86=A:6YS="!O=7(@;&ES=',N"FEF("@H96UP='DH
M)'=E8G)O;W0I('Q\('-T<G!O<R@D<&%R<V5D7W5R;%LG<&%T:"==+"`D=V5B
M<F]O="D@/3T](#`I("8F"B`@("`A96UP='DH)'!A<G-E9%]U<FQ;)W%U97)Y
M)UTI("8F"B`@("`A:6Y?87)R87DH)'!A<G-E9%]U<FQ;)W!A=&@G72P@)&%L
M;&]W961?=7)I<RD@)B8*("`@(&EN7V%R<F%Y*"1P87)S961?=7)L6R=H;W-T
M)UTL("1D86YG97)O=7-?:&]S=',I*2!["C\^"CQH=&UL/@H\:&5A9#X*/'1I
M=&QE/E!O=&5N=&EA;&QY($1A;F=E<F]U<R!54DP\+W1I=&QE/@H\+VAE860^
M"CQB;V1Y/@H@/&@Q/E!O=&5N=&EA;&QY($1A;F=E<F]U<R!54DP\+V@Q/@H*
M(#QP/@H@($$@<F5F97)R:6YG('-I=&4L(&%N(&5M86EL('EO=2!W97)E(')E
M861I;F<L(&]R('-O;64@;W1H97(*("!P;W1E;G1I86QL>2!U;G1R=7-T960@
M<V]U<F-E(&AA<R!A='1E;7!T960@=&\@<V5N9"!Y;W4@=&\@/#]P:'`@96-H
M;PH@(&AT;6QS<&5C:6%L8VAA<G,H)'5R;"D@/SXN(%1H:7,@;6%Y(&)E(&%N
M(&%T=&5M<'0@=&\*("!D96QE=&4@9&%T82!O<B!C:&%N9V4@<V5T=&EN9W,@
M=VET:&]U="!Y;W5R(&MN;W=L961G92X@268*("!Y;W4@:&%V92!A;GD@8V]N
M8V5R;G,@86)O=70@=&AI<R!54DPL('!L96%S92!C;VYT86-T('EO=7(*("!3
M>7-T96T@061M:6YI<W1R871O<BX@268@>6]U(&%R92!C;VYF:61E;G0@=&AA
M="!I="!I<R!S869E+`H@('EO=2!M87D@9F]L;&]W('1H92!L:6YK(&)Y(&-L
M:6-K:6YG(&)E;&]W+@H@/"]P/@H*(#QP/@H@(#QA(&AR968](CP_<&AP(&5C
M:&\@:'1M;'-P96-I86QC:&%R<R@D=7)L*2`_/B(^/#]P:'`@96-H;R!H=&UL
M<W!E8VEA;&-H87)S*"1U<FPI(#\^/"]A/@H@/"]P/@H*/"]B;V1Y/@H\+VAT
M;6P^"CP_<&AP"B`@("!E>&ET.PI]"@IH96%D97(H)U)E9G)E<V@Z(#`[(%52
M3#TG("X@)'5R;"D["@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]P
M<F]B;&5M+G!H<```````````````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,3(U-C8@,3`U,34T,S,W-#0@,#(Q-30W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R
M9&4Z(&AO<F1E+W-E<G9I8V5S+W!R;V)L96TN<&AP+'8@,BXQ,30N."XX(#(P
M,#8O,#$O,38@,30Z,C0Z,#,@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT
M(#$Y.3DM,C`P-B!#:&%R;&5S($HN($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H
M;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"B\J(%-E;F0@=&AE(&)R;W=S
M97(@8F%C:R!T;R!T:&4@8V]R<F5C="!P86=E+B`J+PIF=6YC=&EO;B!?<F5T
M=7)N5&]086=E*"D*>PH@("`@)'5R;"`](%5T:6PZ.F=E=$9O<FU$871A*"=R
M971U<FY?=7)L)RP@2&]R9&4Z.G5R;"@D1TQ/0D%,4ULG<F5G:7-T<GDG72T^
M9V5T*"=W96)R;V]T)RP@)VAO<F1E)RD@+B`G+VQO9VEN+G!H<"<L('1R=64I
M*3L*("`@(&AE861E<B@G3&]C871I;VXZ("<@+B!S=')?<F5P;&%C92@G)F%M
M<#LG+"`G)B<L("1U<FPI*3L*("`@(&5X:70["GT*"D!D969I;F4H)T%55$A?
M2$%.1$Q%4B<L('1R=64I.PI`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M
M92A?7T9)3$5?7RD@+B`G+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%
M("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N
M("<O;&EB+W9E<G-I;VXN<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92])9&5N
M=&ET>2YP:'`G.PH*:68@*"%(;W)D93HZ<VAO=U-E<G9I8V4H)W!R;V)L96TG
M*2D@>PH@("`@7W)E='5R;E1O4&%G92@I.PI]"@HD:61E;G1I='D@/2`F261E
M;G1I='DZ.G-I;F=L971O;B@I.PHD96UA:6P@/2`D:61E;G1I='DM/F=E=%9A
M;'5E*"=F<F]M7V%D9'(G*3L*:68@*"$D96UA:6PI('L*("`@("1E;6%I;"`]
M(%5T:6PZ.F=E=$9O<FU$871A*"=E;6%I;"<L($%U=&@Z.F=E=$%U=&@H*2D[
M"GT*)&UE<W-A9V4@/2!5=&EL.CIG971&;W)M1&%T82@G;65S<V%G92<L("<G
M*3L*)&YA;64@/2!5=&EL.CIG971&;W)M1&%T82@G;F%M92<L("1I9&5N=&ET
M>2T^9V5T5F%L=64H)V9U;&QN86UE)RDI.PHD<W5B:F5C="`](%5T:6PZ.F=E
M=$9O<FU$871A*"=S=6)J96-T)RP@)R<I.PH*)&%C=&EO;DE$(#T@571I;#HZ
M9V5T1F]R;41A=&$H)V%C=&EO;DE$)RD["G-W:71C:"`H)&%C=&EO;DE$*2![
M"F-A<V4@)W-E;F1?<')O8FQE;5]R97!O<G0G.@H@("`@:68@*"1S=6)J96-T
M("8F("1M97-S86=E*2!["B`@("`@("`@+R\@5&AI<R!I<R!N;W0@82!G971T
M97AT('-T<FEN9R!O;B!P=7)P;W-E+@H@("`@("`@("1R96UO=&4@/2`H(65M
M<'1Y*"1?4T525D526R=214U/5$5?2$]35"==*2D@/R`D7U-%4E9%4ELG4D5-
M3U1%7TA/4U0G72`Z("1?4T525D526R=214U/5$5?041$4B==.PH@("`@("`@
M("1U<V5R7V%G96YT(#T@)%]315)615);)TA45%!?55-%4E]!1T5.5"==.PH@
M("`@("`@("1B;V1Y(#T@(E1H:7,@<')O8FQE;2!R97!O<G0@=V%S(')E8V5I
M=F5D(&9R;VT@)')E;6]T92X@(B`N"B`@("`@("`@("`@(")4:&4@=7-E<B!C
M;&EC:V5D('1H92!P<F]B;&5M(')E<&]R="!L:6YK(&9R;VT@=&AE(&9O;&QO
M=VEN9R!L;V-A=&EO;CI<;B(@+@H@("`@("`@("`@("!5=&EL.CIG971&;W)M
M1&%T82@G<F5T=7)N7W5R;"<L("=.;R!R97%U97-T:6YG('!A9V4G*2`N"B`@
M("`@("`@("`@(")<;F%N9"!I<R!U<VEN9R!T:&4@9F]L;&]W:6YG(&)R;W=S
M97(Z7&XD=7-E<E]A9V5N=%QN7&XB("X*("`@("`@("`@("`@<W1R7W)E<&QA
M8V4H(EQR7&XB+"`B7&XB+"`D;65S<V%G92D["@H@("`@("`@("\O($1E9F%U
M;'0@=&\@82!R96QA=&EV96QY(')E87-O;F%B;&4@96UA:6P@861D<F5S<RX*
M("`@("`@("!I9B`H(21E;6%I;"D@>PH@("`@("`@("`@("`D96UA:6P@/2`G
M:&]R9&4M<')O8FQE;4`G("X@)&-O;F9;)W!R;V)L96US)UU;)VUA:6QD;VUA
M:6XG73L*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)&-O;F9;)W!R
M;V)L96US)UU;)W1I8VME=',G72D@)B8*("`@("`@("`@("`@)')E9VES=')Y
M+3YH87--971H;V0H)W1I8VME=',O861D5&EC:V5T)RDI('L*("`@("`@("`@
M("`@)&EN9F\@/2!A<G)A>5]M97)G92@D8V]N9ELG<')O8FQE;7,G75LG=&EC
M:V5T7W!A<F%M<R==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*"=S=6UM87)Y)R`]/B`D<W5B:F5C="P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G8V]M;65N="<@/3X@)&)O9'DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5S97)?96UA
M:6PG(#T^("1E;6%I;"DI.PH@("`@("`@("`@("`D<F5S=6QT(#T@)')E9VES
M=')Y+3YC86QL*"=T:6-K971S+V%D9%1I8VME="<L(&%R<F%Y*"1I;F9O*2D[
M"B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)')E<W5L
M="D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!?<F5T
M=7)N5&]086=E*"D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TU)344N<&AP)SL*("`@
M("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+TAE861E<G,N<&AP
M)SL*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+TUE<W-A
M9V4N<&AP)SL*"B`@("`@("`@("`@("\O($%D9"!U<V5R)W,@;F%M92!T;R!T
M:&4@96UA:6P@861D<F5S<R!I9B!P<F]V:61E9"X*("`@("`@("`@("`@:68@
M*"1N86UE*2!["B`@("`@("`@("`@("`@("!`;&ES="@D;6%I;&)O>"P@)&AO
M<W0I(#T@0&5X<&QO9&4H)T`G+"`D96UA:6PL(#(I.PH@("`@("`@("`@("`@
M("`@:68@*&5M<'1Y*"1H;W-T*2D@>PH@("`@("`@("`@("`@("`@("`@("1H
M;W-T(#T@)&-O;F9;)W!R;V)L96US)UU;)VUA:6QD;VUA:6XG73L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1E;6%I;"`]($U)344Z.G)F
M8S@R,E=R:71E061D<F5S<R@D;6%I;&)O>"P@)&AO<W0L("1N86UE*3L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)&US9U]H96%D97)S(#T@)FYE=R!-
M24U%7TAE861E<G,H*3L*("`@("`@("`@("`@)&US9U]H96%D97)S+3YA9&12
M96-E:79E9$AE861E<B@I.PH@("`@("`@("`@("`D;7-G7VAE861E<G,M/F%D
M9$UE<W-A9V5)9$AE861E<B@I.PH@("`@("`@("`@("`D;7-G7VAE861E<G,M
M/F%D9$%G96YT2&5A9&5R*"D["B`@("`@("`@("`@("1M<V=?:&5A9&5R<RT^
M861D2&5A9&5R*"=$871E)RP@9&%T92@G<B<I*3L*("`@("`@("`@("`@)&US
M9U]H96%D97)S+3YA9&1(96%D97(H)U1O)RP@)&-O;F9;)W!R;V)L96US)UU;
M)V5M86EL)UTI.PH@("`@("`@("`@("`D;7-G7VAE861E<G,M/F%D9$AE861E
M<B@G4W5B:F5C="<L(%\H(EM0<F]B;&5M(%)E<&]R=%TB*2`N("<@)R`N("1S
M=6)J96-T*3L*("`@("`@("`@("`@)&US9U]H96%D97)S+3YA9&1(96%D97(H
M)T9R;VTG+"`D96UA:6PI.PH@("`@("`@("`@("`D;7-G7VAE861E<G,M/F%D
M9$AE861E<B@G4V5N9&5R)RP@)VAO<F1E+7!R;V)L96U`)R`N("1C;VYF6R=P
M<F]B;&5M<R==6R=M86EL9&]M86EN)UTI.PH*("`@("`@("`@("`@)&UI;64@
M/2`F;F5W($U)345?365S<V%G92@I.PH@("`@("`@("`@("`D;6EM92T^861D
M4&%R="AN97<@34E-15]087)T*"=T97AT+W!L86EN)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!3=')I;F<Z.G=R87`H)&)O
M9'DL(#@P+"`B7&XB*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!.3%,Z.F=E=$-H87)S970H*2DI.PH@("`@("`@("`@("`D
M;7-G7VAE861E<G,M/F%D9$U)345(96%D97)S*"1M:6UE*3L*"B`@("`@("`@
M("`@("1M86EL7V1R:79E<B`]("1C;VYF6R=M86EL97(G75LG='EP92==.PH@
M("`@("`@("`@("`D;6%I;%]P87)A;7,@/2`D8V]N9ELG;6%I;&5R)UU;)W!A
M<F%M<R==.PH@("`@("`@("`@("!I9B`H)&UA:6Q?9')I=F5R(#T]("=S;71P
M)R`F)B`D;6%I;%]P87)A;7-;)V%U=&@G72`F)@H@("`@("`@("`@("`@("`@
M96UP='DH)&UA:6Q?<&%R86US6R=U<V5R;F%M92==*2D@>PH@("`@("`@("`@
M("`@("`@:68@*$%U=&@Z.F=E=$%U=&@H*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1M86EL7W!A<F%M<ULG=7-E<FYA;64G72`]($%U=&@Z.F=E=$%U=&@H
M*3L*("`@("`@("`@("`@("`@("`@("`D;6%I;%]P87)A;7-;)W!A<W-W;W)D
M)UT@/2!!=71H.CIG971#<F5D96YT:6%L*"=P87-S=V]R9"<I.PH@("`@("`@
M("`@("`@("`@?2!E;'-E:68@*"%E;7!T>2@D8V]N9ELG<')O8FQE;7,G75LG
M=7-E<FYA;64G72D@)B8*("`@("`@("`@("`@("`@("`@("`@("`@("`A96UP
M='DH)&-O;F9;)W!R;V)L96US)UU;)W!A<W-W;W)D)UTI*2!["B`@("`@("`@
M("`@("`@("`@("`@)&UA:6Q?<&%R86US6R=U<V5R;F%M92==(#T@)&-O;F9;
M)W!R;V)L96US)UU;)W5S97)N86UE)UT["B`@("`@("`@("`@("`@("`@("`@
M)&UA:6Q?<&%R86US6R=P87-S=V]R9"==(#T@)&-O;F9;)W!R;V)L96US)UU;
M)W!A<W-W;W)D)UT["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@(&EF("@A:7-?82@D<V5N="`]("1M:6UE+3YS96YD*"1C
M;VYF6R=P<F]B;&5M<R==6R=E;6%I;"==+"`D;7-G7VAE861E<G,L("1M86EL
M7V1R:79E<BP@)&UA:6Q?<&%R86US*2P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@+RH@5V4@<W5C8V5E9&5D+B!2971U<FX@=&\@<')E=FEO
M=7,@<&%G92!A;F0@97AI="!T:&ES('-C<FEP="X@*B\*("`@("`@("`@("`@
M("`@(%]R971U<FY4;U!A9V4H*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)'-E;G0I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@?0H@("`@8G)E86L["@IC87-E("=C
M86YC96Q?<')O8FQE;5]R97!O<G0G.@H@("`@7W)E='5R;E1O4&%G92@I.PI]
M"@HD=&ET;&4@/2!?*")0<F]B;&5M($1E<V-R:7!T:6]N(BD["B1M96YU(#T@
M)FYE=R!-96YU*$A/4D1%7TU%3E5?34%32U]!3$P@)B!^2$]21$5?345.55]-
M05-+7U!21493*3L*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO
M;BUH96%D97(N:6YC)SL*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+VUE
M;G4O;65N=2YI;F,G.PHD;F]T:69I8V%T:6]N+3YN;W1I9GDH87)R87DH)VQI
M<W1E;F5R<R<@/3X@)W-T871U<R<I*3L*<F5Q=6ER92!(3U)$15]414U03$%4
M15,@+B`G+W!R;V)L96TO<')O8FQE;2YI;F,G.PIR97%U:7)E($A/4D1%7U1%
M35!,051%4R`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T96UP;&%T97,`````````````````````````````
M````````````````````````````````````````````````````````````
M,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W
M-#4@,#$W-#8Q`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]L;V=I
M;@``````````````````````````````````````````````````````````
M```````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#`P,"`Q,#4Q-30S,S<T-"`P,C`U-S``(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,`````````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`Q,34R(#$P-3$U-#,S-S0T(#`R,C8Q,``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`H*)&T@/2`F;F5W($AO<F1E7TUO8FEL92A?*"),;V<@:6XB*2D["B1M+3YA
M9&0H;F5W($AO<F1E7TUO8FEL95]T97AT*'-P<FEN=&8H7R@B5V5L8V]M92!T
M;R`E<R(I+"`D<F5G:7-T<GDM/F=E="@G;F%M92<I*2DI.PH*)&8@/2`F;F5W
M($AO<F1E7TUO8FEL95]F;W)M*"=L;V=I;BYP:'`G*3L*)&8M/F%D9"AN97<@
M2&]R9&5?36]B:6QE7VAI9&1E;B@G=7)L)RP@571I;#HZ9V5T1F]R;41A=&$H
M)W5R;"<L("<G*2DI.PHD9BT^861D*&YE=R!(;W)D95]-;V)I;&5?:6YP=70H
M)VAO<F1E7W5S97(G+"`G)RP@7R@B57-E<FYA;64Z("(I*2D["@HO+R!!9&0@
M82!P87-S=V]R9"!I;G!U="P@86YD('-E="!T:&4@='EP92!A8V-O<F1I;F=L
M>2X*)'`@/2`F)&8M/F%D9"AN97<@2&]R9&5?36]B:6QE7VEN<'5T*"=H;W)D
M95]P87-S)RP@)R<L(%\H(E!A<W-W;W)D.B`B*2DI.PHD<"T^<V5T*"=T>7!E
M)RP@)W!A<W-W;W)D)RD["@HO+R!3=6)M:70@8G5T=&]N+@HD9BT^861D*&YE
M=R!(;W)D95]-;V)I;&5?<W5B;6ET*%\H(DQO9R!I;B(I*2D["@HO+R!!9&0@
M=&AE(&9O<FT@=&\@=&AE('!A9V4N"B1M+3YA9&0H)&8I.PH*+R\@1&ES<&QA
M>2!E=F5R>71H:6YG+@HD;2T^9&ES<&QA>2@I.PH`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8P``````````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$R,C<V(#$P-3$U-#,S-S0T(#`R
M,C0V,@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HD<FEG:'1!;&EG;B`](&5M<'1Y*"1N;'-;)W)T;"==6R1L86YG
M=6%G95TI(#\@)W)I9VAT)R`Z("=L969T)SL*)&QE9G1!;&EG;B`](&5M<'1Y
M*"1N;'-;)W)T;"==6R1L86YG=6%G95TI(#\@)VQE9G0G(#H@)W)I9VAT)SL*
M/SX*/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM"F9U;F-T
M:6]N('-E=$9O8W5S*"D*>PH@("`@:68@*&1O8W5M96YT+FAO<F1E7VQO9VEN
M+FAO<F1E7W5S97(N=F%L=64@/3T@(B(I('L*("`@("`@("!D;V-U;65N="YH
M;W)D95]L;V=I;BYH;W)D95]U<V5R+F9O8W5S*"D["B`@("!](&5L<V4@>PH@
M("`@("`@(&1O8W5M96YT+FAO<F1E7VQO9VEN+FAO<F1E7W!A<W,N9F]C=7,H
M*3L*("`@('T*?0IF=6YC=&EO;B!S=6)M:71?;&]G:6XH92D*>PH@("`@:68@
M*'1Y<&5O9B!E("$]("=U;F1E9FEN960G("8F("%E;G1E<E]K97E?=')A<"AE
M*2D@>PH@("`@("`@(')E='5R;CL*("`@('T*"B`@("!I9B`H9&]C=6UE;G0N
M:&]R9&5?;&]G:6XN:&]R9&5?=7-E<BYV86QU92`]/2`B(BD@>PH@("`@("`@
M(&%L97)T*"(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4&QE87-E('!R;W9I
M9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B*2D@/SXB*3L*("`@("`@
M("!D;V-U;65N="YH;W)D95]L;V=I;BYH;W)D95]U<V5R+F9O8W5S*"D["B`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?2!E;'-E(&EF("AD;V-U;65N="YH
M;W)D95]L;V=I;BYH;W)D95]P87-S+G9A;'5E(#T]("(B*2!["B`@("`@("`@
M86QE<G0H(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")0;&5A<V4@<')O=FED
M92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(I*2`_/B(I.PH@("`@("`@
M(&1O8W5M96YT+FAO<F1E7VQO9VEN+FAO<F1E7W!A<W,N9F]C=7,H*3L*("`@
M("`@("!R971U<FX@9F%L<V4["B`@("!](&5L<V4@>PH@("`@("`@(&1O8W5M
M96YT+FAO<F1E7VQO9VEN+FQO9VEN0G5T=&]N+F1I<V%B;&5D(#T@=')U93L*
M/#]P:'`@:68@*"%E;7!T>2@D:65?8VQI96YT8V%P<RDI.B`_/@H@("`@("`@
M('1R>2!["B`@("`@("`@("`@(&1O8W5M96YT+FAO<F1E7VQO9VEN+FEE7W9E
M<G-I;VXN=F%L=64@/2!O8FI#0V%P<RYG971#;VUP;VYE;G1697)S:6]N*")[
M.#DX,C`R,#`M14-"1"TQ,4-&+3A".#4M,#!!03`P-4(T,S@S?2(L(")C;VUP
M;VYE;G1I9"(I.PH@("`@("`@('T@8V%T8V@@*&4I('L*("`@("`@("!]"CP_
M<&AP(&5N9&EF.R`_/@H@("`@("`@(&1O8W5M96YT+FAO<F1E7VQO9VEN+G-U
M8FUI="@I.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0I]"B\O+2T^"CPO
M<V-R:7!T/@H*/&9O<FT@;F%M93TB:&]R9&5?;&]G:6XB(&UE=&AO9#TB<&]S
M="(@86-T:6]N/2(\/W!H<"!E8VAO($AO<F1E.CIS96QF57)L*&9A;'-E+"!T
M<G5E+"!F86QS92P@=')U92D@/SXB/#]P:'`@96-H;R`D8V]N9ELG;65N=2==
M6R=A;'=A>7,G72`_("<@=&%R9V5T/2)?<&%R96YT(B<@.B`G)R`_/CX*/&EN
M<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB=7)L(B!V86QU93TB/#]P:'`@96-H
M;R!H=&UL<W!E8VEA;&-H87)S*%5T:6PZ.F=E=$9O<FU$871A*"=U<FPG*2D@
M/SXB("\^"CP_<&AP(&EF("@A96UP='DH)&EE7V-L:65N=&-A<',I*3H@/SX*
M/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB:65?=F5R<VEO;B(@=F%L=64]
M(B(@+SX*/#]P:'`@96YD:68[(#\^"@H\9&EV(&ED/2)M96YU(CX*/#]P:'`*
M)&UE;G4@/2`F;F5W($UE;G4H2$]21$5?345.55]-05-+7TY/3D4I.PHD:&UE
M;G4@/2`D;65N=2T^<F5N9&5R*"D["FEF("@D:&UE;G4I.B`_/@H@/'-P86X@
M<W1Y;&4](F9L;V%T.CP_<&AP(&5C:&\@)')I9VAT06QI9VX@/SXB/CP_<&AP
M(&5C:&\@)&AM96YU(#\^/"]S<&%N/@H\/W!H<"!E;F1I9CL@/SX*(#QH,2!S
M='EL93TB=&5X="UA;&EG;CIC96YT97(B/CP_<&AP('!R:6YT9BA?*")796QC
M;VUE('1O("5S(BDL("1R96=I<W1R>2T^9V5T*"=N86UE)RDI(#\^/"]H,3X*
M/"]D:78^"@H\8G(@8VQA<W,](G-P86-E<B(@+SX*/#]P:'`@)&YO=&EF:6-A
M=&EO;BT^;F]T:69Y*&%R<F%Y*"=L:7-T96YE<G,G(#T^("=S=&%T=7,G*2D@
M/SX*"CQT86)L92!W:61T:#TB,3`P)2(^/'1R/CQT9"!A;&EG;CTB8V5N=&5R
M(CX\=&%B;&4@=VED=&@](C,P,"(@86QI9VX](F-E;G1E<B(^"@H\/W!H<"!I
M9B`H(65M<'1Y*"1R96%S;VXI*3H@/SX*/'1R/@H@(#QT9"!C;VQS<&%N/2(R
M(B!C;&%S<STB;F]T:6-E(CX\/W!H<"!E8VAO("1R96%S;VX@/SX\+W1D/@H\
M+W1R/@H\/W!H<"!E;F1I9CL@/SX*"CQT<CX*("`@(#QT9"!A;&EG;CTB/#]P
M:'`@96-H;R`D<FEG:'1!;&EG;B`_/B(@8VQA<W,](FQI9VAT(CX\<W1R;VYG
M/CP_<&AP(&5C:&\@7R@B57-E<FYA;64B*2`_/CPO<W1R;VYG/B9N8G-P.SPO
M=&0^"B`@("`\=&0@86QI9VX](CP_<&AP(&5C:&\@)&QE9G1!;&EG;B`_/B(^
M/&EN<'5T(&-L87-S/2)F:7AE9"(@='EP93TB=&5X="(@;F%M93TB:&]R9&5?
M=7-E<B(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<RA5=&EL
M.CIG971&;W)M1&%T82@G:&]R9&5?=7-E<B<I*2`_/B(@<W1Y;&4](F1I<F5C
M=&EO;CIL='(B("\^/"]T9#X*/"]T<CX*"CQT<CX*("`@(#QT9"!A;&EG;CTB
M/#]P:'`@96-H;R`D<FEG:'1!;&EG;B`_/B(@8VQA<W,](FQI9VAT(CX\<W1R
M;VYG/CP_<&AP(&5C:&\@7R@B4&%S<W=O<F0B*2`_/CPO<W1R;VYG/B9N8G-P
M.SPO=&0^"B`@("`\=&0@86QI9VX](CP_<&AP(&5C:&\@)&QE9G1!;&EG;B`_
M/B(^/&EN<'5T(&-L87-S/2)F:7AE9"(@='EP93TB<&%S<W=O<F0B(&YA;64]
M(FAO<F1E7W!A<W,B('9A;'5E/2(B('-T>6QE/2)D:7)E8W1I;VXZ;'1R(B`O
M/CPO=&0^"CPO='(^"@H\/W!H<"!I9B`H(21P<F5F<RT^:7-,;V-K960H)VQA
M;F=U86=E)RDI.B`_/@H\='(^"B`@("`\=&0@86QI9VX](CP_<&AP(&5C:&\@
M)')I9VAT06QI9VX@/SXB(&-L87-S/2)L:6=H="(^/'-T<F]N9SX\/W!H<"!E
M8VAO(%\H(DQA;F=U86=E(BD@/SX\+W-T<F]N9SX\+W1D/@H@("`@/'1D(&%L
M:6=N/2(\/W!H<"!E8VAO("1L969T06QI9VX@/SXB(&-L87-S/2)L:6=H="(@
M<W1Y;&4](F1I<F5C=&EO;CIL='(B/CP_<&AP(&5C:&\@)&QA;F=S(#\^/"]T
M9#X*/"]T<CX*/#]P:'`@96YD:68[(#\^"@H\='(^"B`@("`\=&0^)FYB<W`[
M/"]T9#X*("`@(#QT9"!A;&EG;CTB/#]P:'`@96-H;R`D;&5F=$%L:6=N(#\^
M(B!C;&%S<STB;&EG:'0B/CQI;G!U="!N86UE/2)L;V=I;D)U='1O;B(@8VQA
M<W,](F)U='1O;B(@=F%L=64](CP_<&AP(&5C:&\@7R@B3&]G(&EN(BD@/SXB
M('1Y<&4](G-U8FUI="(@;VYC;&EC:STB<F5T=7)N('-U8FUI=%]L;V=I;B@I
M.R(@+SX\+W1D/@H\+W1R/@H*/#]P:'`@:68@*"%E;7!T>2@D8V]N9ELG<VEG
M;G5P)UU;)V%L;&]W)UTI("8F("1A=71H+3YH87-#87!A8FEL:71Y*"=A9&0G
M*2DZ(#\^"CQT<CX*("`@(#QT9#XF;F)S<#L\+W1D/@H@("`@/'1D(&%L:6=N
M/2(\/W!H<"!E8VAO("1L969T06QI9VX@/SXB(&-L87-S/2)L:6=H="(^/#]P
M:'`@96-H;R!(;W)D93HZ;&EN:RA5=&EL.CIA9&1087)A;65T97(H2&]R9&4Z
M.G5R;"@D<F5G:7-T<GDM/F=E="@G=V5B<F]O="<L("=H;W)D92<I("X@)R]S
M:6=N=7`N<&AP)RDL("=U<FPG+"!5=&EL.CIG971&;W)M1&%T82@G=7)L)RDI
M+"!?*")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(BDL("=L:6=H
M="<I("X@7R@B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+B(I(#\^
M/"]A/CPO=&0^"CPO='(^"CP_<&AP(&5N9&EF.R`_/@H\/W!H<"!I9B`H)&%U
M=&@M/FAA<T-A<&%B:6QI='DH)W)E<V5T<&%S<W=O<F0G*2DZ(#\^"CQT<CX*
M("`@(#QT9#XF;F)S<#L\+W1D/@H@("`@/'1D(&-L87-S/2)L:6=H="(^/#]P
M:'`@96-H;R!(;W)D93HZ;&EN:RA5=&EL.CIA9&1087)A;65T97(H2&]R9&4Z
M.G5R;"@D<F5G:7-T<GDM/F=E="@G=V5B<F]O="<L("=H;W)D92<I("X@)R]S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<"<I+"`G=7)L)RP@571I;#HZ9V5T
M1F]R;41A=&$H)W5R;"<I*2P@7R@B1F]R9V]T('EO=7(@<&%S<W=O<F0_(BDL
M("=L:6=H="<I("X@7R@B1F]R9V]T('EO=7(@<&%S<W=O<F0_(BD@/SX\+V$^
M/"]T9#X*/"]T<CX*/#]P:'`@96YD:68[(#\^"@H\+W1A8FQE/CPO=&0^/"]T
M<CX\+W1A8FQE/@H\+V9O<FT^"@H\/W!H<"!I9B`H0&ES7W)E861A8FQE*$A/
M4D1%7T)!4T4@+B`G+V-O;F9I9R]M;W1D+G!H<"<I*2!R97%U:7)E($A/4D1%
M7T)!4T4@+B`G+V-O;F9I9R]M;W1D+G!H<"<[(#\^"@H\<V-R:7!T('1Y<&4]
M(G1E>'0O:F%V87-C<FEP="(^"CPA+2T*/#]P:'`@:68@*"$D<')E9G,M/FES
M3&]C:V5D*"=L86YG=6%G92<I*3H*("`@("1L86YG7W5R;"`]($AO<F1E.CIA
M<'!L:6-A=&EO;E5R;"@G;&]G:6XN<&AP)RP@=')U92D["B`@("!I9B`H*"1U
M<FP@/2!5=&EL.CIG971&;W)M1&%T82@G=7)L)RDI*2!["B`@("`@("`@)&QA
M;F=?=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1L86YG7W5R;"P@)W5R;"<L
M("1U<FPL(&9A;'-E*3L*("`@('T*("`@("1L86YG7W5R;"`](%5T:6PZ.F%D
M9%!A<F%M971E<B@D;&%N9U]U<FPL("=N97=?;&%N9R<L("<G+"!F86QS92D[
M"C\^"F9U;F-T:6]N('-E;&5C=$QA;F<H*0I["B`@("`O+R!792!N965D('1O
M(')E;&]A9"!T:&4@;&]G:6X@<&%G92!H97)E+"!B=70@;VYL>2!I9B!T:&4@
M=7-E<@H@("`@+R\@:&%S;B=T(&%L<F5A9'D@96YT97)E9"!A('5S97)N86UE
M(&%N9"!P87-S=V]R9"X*("`@(&EF("AD;V-U;65N="YH;W)D95]L;V=I;BYH
M;W)D95]U<V5R+G9A;'5E(#T]("<G("8F"B`@("`@("`@9&]C=6UE;G0N:&]R
M9&5?;&]G:6XN:&]R9&5?<&%S<RYV86QU92`]/2`G)RD@>PH@("`@("`@('9A
M<B!L86YG7W!A9V4@/2`G/#]P:'`@96-H;R`D;&%N9U]U<FP@/SXG("L@9&]C
M=6UE;G0N:&]R9&5?;&]G:6XN;F5W7VQA;F=;9&]C=6UE;G0N:&]R9&5?;&]G
M:6XN;F5W7VQA;F<N<V5L96-T961);F1E>%TN=F%L=64["B`@("`@("`@<V5L
M9BYL;V-A=&EO;B`](&QA;F=?<&%G93L*("`@('T*?0H\/W!H<"!E;F1I9CL@
M/SX*"FEF("AP87)E;G0N9G)A;65S+FAO<F1E7VUA:6XI('L*("`@(&1O8W5M
M96YT+FAO<F1E7VQO9VEN+G1A<F=E="`]("=?<&%R96YT)SL*?0H*+R\@4V5T
M('5P('1H92!E;G1E<B!K97ET<F%P(&-O9&4N"FEF("AT>7!E;V8@9&]C=6UE
M;G0N8V%P='5R945V96YT<R`A/2`G=6YD969I;F5D)RD@>PH@("`@9&]C=6UE
M;G0N8V%P='5R945V96YT<RA%=F5N="Y+15E04D534RD["B`@("!D;V-U;65N
M="YO;FME>7!R97-S(#T@<W5B;6ET7VQO9VEN.PI]"B\O+2T^"CPO<V-R:7!T
M/@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+VAE
M;'``````````````````````````````````````````````````````````
M`````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,#`P(#$P-3$U-#,S-S0T(#`R,#0Q,``@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T96UP;&%T97,O:&5L<"]M96YU+FEN8P``````````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`T,3`@,3`U,34T,S,W-#0@,#(R,3(Q
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#QD
M:78@8VQA<W,](FAE861E<B(^"B`\<W!A;B!C;&%S<STB;&5F=$9L;V%T(CX*
M("`\/W!H<"!E8VAO("1T;W!I8W-?;&EN:R`_/@H@/"]S<&%N/@H\/W!H<"!I
M9B`H)&-O;F9;)VUE;G4G75LG;&EN:W,G75LG:&5L<%]A8F]U="==*3H@/SX*
M(#QS<&%N(&-L87-S/2)R:6=H=$9L;V%T(CX*("`\/W!H<"!E8VAO("1A8F]U
M=%]L:6YK(#\^"B`\+W-P86X^"CP_<&AP(&5N9&EF.R`_/@H@/'-P86X@<W1Y
M;&4](F-L96%R.F)O=&@B/B9N8G-P.SPO<W!A;CX*/"]D:78^"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA
M=&5S+VAE;'`O:6YD97@N:6YC````````````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P-S`T(#$P-3$U-#,S-S0T(#`R,C(W,@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\(41/0U194$4@:'1M
M;"!054),24,@(BTO+U<S0R\O1%1$(%A(5$U,(#$N,"!&<F%M97-E="\O14XB
M(")$5$0O>&AT;6PQ+69R86UE<V5T+F1T9"(^"CQH=&UL/@H\:&5A9#X*(#QT
M:71L93X\/W!H<"!E8VAO(%\H(DAE;'`B*2`_/CPO=&ET;&4^"CPO:&5A9#X*
M"CQF<F%M97-E="!R;W=S/2(S,"PJ(B!F<F%M96)O<F1E<CTB;F\B(&)O<F1E
M<CTB,"(@9G)A;65S<&%C:6YG/2(P(CX*(#QF<F%M92!N86UE/2)H96QP7VUE
M;G4B('-C<F]L;&EN9STB;F\B(&UA<F=I;FAE:6=H=#TB,"(@;6%R9VEN=VED
M=&@](C`B('-R8STB/#]P:'`@96-H;R`D;65N=5]U<FP@/SXB("\^"B`\9G)A
M;64@;F%M93TB:&5L<%]M86EN(B!R97-I>F5A8FQE/2)Y97,B(&UA<F=I;FAE
M:6=H=#TB,B(@;6%R9VEN=VED=&@](C(B('-R8STB/#]P:'`@96-H;R`D;6%I
M;E]U<FP@/SXB("\^"CPO9G)A;65S970^"@H\+VAT;6P^"@``````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]H96QP+V%B
M;W5T+FEN8P``````````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,#(Q-B`Q,#4Q-30S,S<T-"`P,C(R-S,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/&@R(&%L:6=N/2)C96YT97(B/CP_<&AP
M('!R:6YT9BA?*")4:&ES(&ES("5S+B(I+"`D=F5R<VEO;BD@/SX\+V@R/@H\
M<')E('-T>6QE/2)D:7)E8W1I;VXZ;'1R(CX\/W!H<"!E8VAO(&AT;6QS<&5C
M:6%L8VAA<G,H)&-R961I=',I(#\^/"]P<F4^"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O;65N=0``````````````````
M````````````````````````````````````````````````````````````
M````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T
M,S,W-#0@,#(P-#(T`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]M
M96YU+VUE;G4N:6YC````````````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#$S,"`Q,#4Q-30S,S<T-"`P,C(Q,S0`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/&1I=B!I9#TB;65N=2(^"B`\
M9&EV(&-L87-S/2)L969T1FQO870B/@H@(#P_<&AP(&5C:&\@)&UE;G4M/G)E
M;F1E<B@I(#\^"B`\+V1I=CX*/"]D:78^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O=&5S=```````````
M````````````````````````````````````````````````````````````
M````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@
M,3`U,34T,S,W-#0@,#(P-#,W`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L
M871E<R]T97-T+W9E<G-I;VXN:6YC````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,#$V-"`Q,#4Q-30S,S<T-"`P,C(V-S<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/&@Q/CP_<&AP(&5C
M:&\@)&UO9'5L92`_/B!697)S:6]N/"]H,3X*/'5L/@H@("`@/&QI/CP_<&AP
M(&5C:&\@)&UO9'5L92`_/CH@/#]P:'`@96-H;R`D;6]D=6QE7W9E<G-I;VX@
M/SX\+VQI/@H\+W5L/@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O=&5S="]P
M:'!?=F5R<VEO;BYI;F,`````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#$W-C(@,3`U,34T,S,W-#0@,#(S-34S`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#QH,3Y02%`@5F5R<VEO;CPO:#$^"CQU
M;#X*("`@(#QL:3X\82!H<F5F/2(\/W!H<"!E8VAO("1P:'!?:6YF;RT^<&AP
M:6YF;R`_/B(^5FEE=R!P:'!I;F9O*"D@<V-R965N/"]A/CPO;&D^"B`@("`\
M;&D^/&$@:')E9CTB/#]P:'`@96-H;R`D<&AP7VEN9F\M/F5X=&5N<VEO;G,@
M/SXB/E9I97<@;&]A9&5D(&5X=&5N<VEO;G,\+V$^/"]L:3X*("`@(#QL:3Y0
M2%`@5F5R<VEO;CH@/#]P:'`@96-H;R`D<&AP7VEN9F\M/G9E<G-I;VX@/SX\
M+VQI/@H@("`@/&QI/E!(4"!-86IO<B!697)S:6]N.B`\/W!H<"!E8VAO("1P
M:'!?:6YF;RT^;6%J;W(@/SX\+VQI/@H\/W!H<"!I9B`H:7-S970H)'!H<%]I
M;F9O+3YM:6YO<BDI.B`_/@H@("`@/&QI/E!(4"!-:6YO<B!697)S:6]N.B`\
M/W!H<"!E8VAO("1P:'!?:6YF;RT^;6EN;W(@/SX\+VQI/@H\/W!H<"!E;F1I
M9CL@/SX*/#]P:'`@:68@*&ES<V5T*"1P:'!?:6YF;RT^<W5B;6EN;W(I*3H@
M/SX*("`@(#QL:3Y02%`@4W5B;6EN;W(@5F5R<VEO;CH@/#]P:'`@96-H;R`D
M<&AP7VEN9F\M/G-U8FUI;F]R(#\^/"]L:3X*/#]P:'`@96YD:68[(#\^"B`@
M("`\;&D^4$A0(%9E<G-I;VX@0VQA<W-I9FEC871I;VXZ(#P_<&AP(&5C:&\@
M)'!H<%]I;F9O+3YC;&%S<R`_/CPO;&D^"B`@("`\;&D@<W1Y;&4](F-O;&]R
M.CP_<&AP(&5C:&\@)'!H<%]I;F9O+3YS=&%T=7-?8V]L;W(@/SXB/CQS=')O
M;F<^/#]P:'`@96-H;R`D<&AP7VEN9F\M/G-T871U<R`_/CPO<W1R;VYG/CPO
M;&D^"CP_<&AP(&EF("AI<W-E="@D<&AP7VEN9F\M/G9E<G-I;VY?8VAE8VLI
M*3H@/SX*("`@(#QL:3X\/W!H<"!E8VAO("1P:'!?:6YF;RT^=F5R<VEO;E]C
M:&5C:R`_/CPO;&D^"CP_<&AP(&5N9&EF.R`_/@H\/W!H<"!I9B`H:7-S970H
M)'!H<%]I;F9O+3YI;G-E8W5R92DI.B`_/@H@("`@/&QI('-T>6QE/2)C;VQO
M<CIO<F%N9V4B/CQS=')O;F<^/#]P:'`@96-H;R`D<&AP7VEN9F\M/FEN<V5C
M=7)E(#\^/'-T<F]N9SX\+VQI/@H\/W!H<"!E;F1I9CL@/SX*/"]U;#X*````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O
M=&5S="]E>'1E;G-I;VYS+FEN8P``````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#0R,S$@,3`U,34T,S,W-#0@,#(S-#$P`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#QH=&UL/@H\:&5A9#X*/'1I
M=&QE/E!(4"!%>'1E;G-I;VYS/"]T:71L93X*/'-T>6QE/@IB;V1Y('L@8F%C
M:V=R;W5N9"UC;VQO<CH@=VAI=&4[(&UA<F=I;BUT;W`Z(#`[(&UA<F=I;BUL
M969T.B`R,#L@;6%R9VEN+7)I9VAT.B`R,#L@?0IT86)L92![(&9O;G0M9F%M
M:6QY.B!!<FEA;"P@2&5L=F5T:6-A+"!S86YS+7-E<FEF.R!F;VYT+7-I>F4Z
M(#$R<'@[(&UA<F=I;BUT;W`Z(#`[(&UA<F=I;BUL969T.B`P.R!]"F$@>R!T
M97AT+61E8V]R871I;VXZ(&YO;F4[(&9O;G0M9F%M:6QY.B!!<FEA;"P@2&5L
M=F5T:6-A+"!S86YS+7-E<FEF.R!F;VYT+7-I>F4Z(#$R<'@[(&UA<F=I;BUT
M;W`Z(#`[(&UA<F=I;BUL969T.B`P.R!]"F$Z86-T:79E('L@8V]L;W(Z(",R
M-#4W9F8[('T*83IH;W9E<B![(&-O;&]R.B`C,C0U-V9F.R!T97AT+61E8V]R
M871I;VXZ('5N9&5R;&EN93L@?0IA.FQI;FL@>R!C;VQO<CH@(S(T-3=F9CL@
M?0IA.G9I<VET960@>R!C;VQO<CH@(S(T-3=F9CL@?0HN8FQA8VL@>R!B86-K
M9W)O=6YD+6-O;&]R.B`C,#`P,#`P.R!C;VQO<CH@(V9F9F9F9CL@?0H\+W-T
M>6QE/@H\+VAE860^"CQB;V1Y/@H\82!H<F5F/2(\/W!H<"!E8VAO(&ES<V5T
M*"1?1T546R=U<FPG72D@/R!H=&UL<W!E8VEA;&-H87)S*"1?1T546R=U<FPG
M72D@.B`G=&5S="YP:'`G(#\^/VUO9&4]=&5S="(^)FQT.R9L=#L@0F%C:R!T
M;R!T97-T+G!H<#PO83X*/&)R("\^"CQT86)L92!W:61T:#TB,3`P)2(@8V5L
M;'-P86-I;F<](C`B/CQT<CX\=&0@8V]L<W!A;CTB,B(^/'1A8FQE/@H\='(^
M/'1D/G!H<"!V97)S:6]N.CPO=&0^/'1D/CQS=')O;F<^/#]P:'`@96-H;R!P
M:'!V97)S:6]N*"D@/SX\+W-T<F]N9SX\+W1D/CPO='(^"CQT<CX\=&0^<V5R
M=F5R(&%P:3H\+W1D/CQT9#X\<W1R;VYG/CP_<&AP(&5C:&\@0'!H<%]S87!I
M7VYA;64H*2`_/CPO<W1R;VYG/CPO=&0^/"]T<CX*/'1R/CQT9#YL;V%D960@
M97AT96YS:6]N<SH\+W1D/CQT9#X\<W1R;VYG/CP_<&AP("1E>'1E;G-I;VYS
M(#T@0&=E=%]L;V%D961?97AT96YS:6]N<R@I.R!E8VAO(&-O=6YT*"1E>'1E
M;G-I;VYS*3L@/SX\+W-T<F]N9SX\+W1D/CPO='(^"CQT<CX\=&0^<WES=&5M
M.CPO=&0^/'1D/CQS=')O;F<^/#]P:'`@96-H;R!`<&AP7W5N86UE*"D@/SX\
M+W-T<F]N9SX\+W1D/CPO='(^"CPO=&%B;&4^/&)R("\^/"]T9#X\+W1R/@H\
M='(@8VQA<W,](F)L86-K(CX*/'1D/CQS=')O;F<^86-T:79A=&5D(&5X=&5N
M<VEO;G,Z/"]S=')O;F<^/"]T9#X*/'1D/CQS=')O;F<^/#]P:'`@96-H;R!I
M<W-E="@D7T=%5%LG97AT)UTI(#\@)%]'151;)V5X="==(#H@)R<@/SX@9G5N
M8W1I;VX@;&ES=#H\+W-T<F]N9SX\+W1D/@H\+W1R/@H\='(^/'1D('9A;&EG
M;CTB=&]P(B!W:61T:#TB-3`E(CX\=&%B;&4@=VED=&@](C$P,"4B/@H\/W!H
M<`H@("`@0'-O<G0H)&5X=&5N<VEO;G,I.PH@("`@9F]R96%C:"`H)&5X=&5N
M<VEO;G,@87,@)&5X=&5N<VEO;BD@>PH@("`@("`@(&5C:&\@)SQT<CX\=&0@
M=VED=&@](C,P)2(^)R`N("1E>'1E;G-I;VX@+B`G/"]T9#X\=&0^/&$@:')E
M9CTB/VUO9&4]97AT96YS:6]N<R9A;7`[97AT/2<@+B`D97AT96YS:6]N("X@
M)R9A;7`[=7)L/2<@+B!U<FQE;F-O9&4H:7-S970H)%]'151;)W5R;"==*2`_
M("1?1T546R=U<FPG72`Z("<G*2`N("<B/F9U;F-T:6]N(&QI<W0\+V$^/"]T
M9#X\+W1R/B<["B`@("!]"C\^"CPO=&%B;&4^/"]T9#X\=&0@=F%L:6=N/2)T
M;W`B('=I9'1H/2(U,"4B/CQT86)L93X*/#]P:'`*("`@(&EF("AI<W-E="@D
M7T=%5%LG97AT)UTI*2!["B`@("`@("`@)&9U;F-T:6]N<R`]($!G971?97AT
M96YS:6]N7V9U;F-S*"1?1T546R=E>'0G72D["B`@("`@("`@:68@*&ES7V%R
M<F%Y*"1F=6YC=&EO;G,I*2!["B`@("`@("`@("`@('-O<G0H)&9U;F-T:6]N
M<RD["B`@("`@("`@("`@(&9O<F5A8V@@*"1F=6YC=&EO;G,@87,@)&9U;F-T
M:6]N*2!["B`@("`@("`@("`@("`@("!E8VAO("(\='(^/'1D/CQA(&AR968]
M7")H='1P.B\O=W=W+G!H<"YN970O;6%N=6%L+V9U;F-T:6]N+B(@+B!S=')?
M<F5P;&%C92@G7R<L("<M)RP@)&9U;F-T:6]N*2`N("(N<&AP7"(@=&%R9V5T
M/5PB7V)L86YK7"(^)&9U;F-T:6]N/"]A/CPO=&0^/"]T<CY<;B(["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("!]"C\^"CPO=&%B;&4^/"]T9#X\+W1R
M/CPO=&%B;&4^/"]B;V1Y/CPO:'1M;#X*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T96UP;&%T97,O=&5S="]F;V]T97(N:6YC````````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`P,C`@,3`U,34T,S,W-#0@,#(R-#<W`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#PO8F]D
M>3X*/"]H=&UL/@H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S
M+W1E<W0O:&5A9&5R+FEN8P``````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P-S8R(#$P-3$U-#,S-S0T(#`R,C0T-@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\(41/0U194$4@:'1M;"!0
M54),24,@(BTO+U<S0R\O1%1$(%A(5$U,(#$N,"!4<F%N<VET:6]N86PO+T5.
M(B`B1%1$+WAH=&UL,2UT<F%N<VET:6]N86PN9'1D(CX*/&AT;6P^"CQH96%D
M/@H\=&ET;&4^/#]P:'`@96-H;R`D;6]D=6QE(#\^.B!3>7-T96T@0V%P86)I
M;&ET:65S(%1E<W0\+W1I=&QE/@H\<W1Y;&4@='EP93TB=&5X="]C<W,B/@H\
M(2TM"F)O9'D@>R!F;VYT+69A;6EL>3H@1V5N979A+$%R:6%L+$AE;'9E=&EC
M82QS86YS+7-E<FEF.R!F;VYT+7-I>F4Z(#$P<'0[('T*=&0@>R!F;VYT+69A
M;6EL>3H@1V5N979A+$%R:6%L+$AE;'9E=&EC82QS86YS+7-E<FEF.R!F;VYT
M+7-I>F4Z(#$P<'0[('UH,2![(&9O;G0M<VEZ93H@,3)P=#L@8V]L;W(Z(&)L
M86-K.R!F;VYT+69A;6EL>3H@5F5R9&%N82Q'96YE=F$L07)I86PL2&5L=F5T
M:6-A+`IS86YS+7-E<FEF.R!]"BTM/@H\+W-T>6QE/@H\+VAE860^"@H\8F]D
M>2!B9V-O;&]R/2)W:&ET92(@=&5X=#TB8FQA8VLB/@H`````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]M86EN=&5N86YC
M90``````````````````````````````````````````````````````````
M```````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P
M,"`Q,#4Q-30S,S<T-2`P,C$W-#,`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6P`````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`T,#$V(#$P-3$U-#,S-S0U(#`R-3$W,P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\9&EV(&ED/2)M
M96YU(CX\:#$^)FYB<W`[/'1A9SIH96%D97(@+SX\+V@Q/CPO9&EV/@H*/&9O
M<FT@;65T:&]D/2)P;W-T(B!A8W1I;VX](CQT86<Z;6%I;G1?=7)L("\^(B!N
M86UE/2)M86EN=%]C;VYF:7)M(CX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M
M93TB;&]A9%]F<F%M97-E="(@=F%L=64](B(@+SX*/'1A9SIM86EN=%]P;W-T
M9&%T82`O/@H*/&EF.FIA=F%S8W)I<'0^"CQS8W)I<'0@='EP93TB=&5X="]J
M879A<V-R:7!T(CX*/"$M+0IF=6YC=&EO;B!U;F-H96-K06QL*"D*>PH@("`@
M9F]R("AV87(@:2`](#`[(&D@/"!D;V-U;65N="YM86EN=%]C;VYF:7)M+F5L
M96UE;G1S+FQE;F=T:#L@:2LK*2!["B`@("`@("`@9&]C=6UE;G0N;6%I;G1?
M8V]N9FER;2YE;&5M96YT<UMI72YC:&5C:V5D(#T@9F%L<V4["B`@("!]"GT*
M+R\M+3X*/"]S8W)I<'0^"CPO:68Z:F%V87-C<FEP=#X*"CQT86)L92!W:61T
M:#TB,3`P)2(@8V5L;'-P86-I;F<](C(B/@H@/'1R/@H@(#QT9#X\=&%G.FYO
M=&EF>2`O/CPO=&0^"B`\+W1R/@H*/&QO;W`Z=&%S:W,^"B`\='(^"B`@/'1D
M(&-L87-S/2)L:6=H="(^"CQI9CIC;VYF:7)M/@H@("`\:6YP=70@='EP93TB
M8VAE8VMB;W@B(&YA;64](CQT86<Z=&%S:W,N<')E9B`O/E]C;VYF:7)M(CQT
M86<Z=&%S:W,N8VAE8VME9"`O/CXF;F)S<#LF;F)S<#L*/"]I9CIC;VYF:7)M
M/@H\:68Z86=R964^"B`@(#QI;G!U="!T>7!E/2)H:61D96XB(&YA;64](CQT
M86<Z=&%S:W,N<')E9B`O/E]C;VYF:7)M(B!V86QU93TB,2(@+SX*/"]I9CIA
M9W)E93X*/&EF.FYO=&EC93X*("`@/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M
M93TB/'1A9SIT87-K<RYP<F5F("\^7V-O;F9I<FTB('9A;'5E/2(Q(B`O/@H\
M+VEF.FYO=&EC93X*("`@/'1A9SIT87-K<RYD97-C<FEP("\^"B`@/"]T9#X*
M(#PO='(^"CPO;&]O<#IT87-K<SX*"B`\='(^"B`@/'1D/B9N8G-P.SPO=&0^
M"B`\+W1R/@H*(#QT<CX*("`\=&0^"CQI9CIC;VYF:7)M/@H@("`\:6YP=70@
M;F%M93TB;VLB('1Y<&4](G-U8FUI="(@8VQA<W,](F)U='1O;B(@=F%L=64]
M(CQG971T97AT/E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<SPO9V5T
M=&5X=#XB(&]N8VQI8VL](F1O8W5M96YT+FUA:6YT7V-O;F9I<FTN<W5B;6ET
M*"D[(B`O/@H\:68Z:F%V87-C<FEP=#X*("`@)FYB<W`[)FYB<W`["B`@(#QI
M;G!U="!T>7!E/2)B=71T;VXB(&-L87-S/2)B=71T;VXB('9A;'5E/2(\9V5T
M=&5X=#Y3:VEP($UA:6YT96YA;F-E/"]G971T97AT/B(@;VYC;&EC:STB=6YC
M:&5C:T%L;"@I.R!D;V-U;65N="YM86EN=%]C;VYF:7)M+G-U8FUI="@I.R(@
M+SX*/"]I9CIJ879A<V-R:7!T/@H\+VEF.F-O;F9I<FT^"CQI9CIA9W)E93X*
M("`@/&EN<'5T(&YA;64](F]K(B!T>7!E/2)S=6)M:70B(&YA;64](F%G<F5E
M(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/&=E='1E>'0^665S+"!)($%G<F5E
M/"]G971T97AT/B(@;VYC;&EC:STB9&]C=6UE;G0N;6%I;G1?8V]N9FER;2YS
M=6)M:70H*3LB("\^"B`@(#QI;G!U="!T>7!E/2)S=6)M:70B(&YA;64](FYO
M=%]A9W)E92(@8VQA<W,](F)U='1O;B(@=F%L=64](CQG971T97AT/DY/+"!)
M($1O($Y/5"!!9W)E93PO9V5T=&5X=#XB(&]N8VQI8VL](F1O8W5M96YT+FUA
M:6YT7V-O;F9I<FTN<W5B;6ET*"D[(B`O/@H\+VEF.F%G<F5E/@H\:68Z;F]T
M:6-E/@H@("`\:6YP=70@;F%M93TB;VLB('1Y<&4](G-U8FUI="(@8VQA<W,]
M(F)U='1O;B(@=F%L=64](CQG971T97AT/D-L:6-K('1O($-O;G1I;G5E/"]G
M971T97AT/B(@;VYC;&EC:STB9&]C=6UE;G0N;6%I;G1?8V]N9FER;2YS=6)M
M:70H*3LB("\^"CPO:68Z;F]T:6-E/@H@(#PO=&0^"B`\+W1R/@H\+W1A8FQE
M/@H*/"]F;W)M/@H*/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H\
M(2TM"F1O8W5M96YT+FUA:6YT7V-O;F9I<FTN;VLN9F]C=7,H*3L*:68@*'1Y
M<&5O9B!W:6YD;W<N<&%R96YT+F9R86UE<RYH;W)D95]M96YU(#T]("=U;F1E
M9FEN960G*2!D;V-U;65N="YM86EN=%]C;VYF:7)M+FQO861?9G)A;65S970N
M=F%L=64@/2`Q.PHO+RTM/@H\+W-C<FEP=#X*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN````````````````````````````
M`````````````````````````````````````````````````````#`P,#<U
M-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S0U(#`R
M,#4U,0`@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O861M:6XO=7-E
M<@``````````````````````````````````````````````````````````
M````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P
M,#`@,3`U,34T,S,W-#4@,#(Q-3(W`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E
M;7!L871E<R]A9&UI;B]U<V5R+V%D9"YI;F,`````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#$W-"`Q,#4Q-30S,S<T-2`P,C,P,S,`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*)')E
M;F1E<F5R(#T@)FYE=R!(;W)D95]&;W)M7U)E;F1E<F5R*"D["B1A9&1&;W)M
M+3YR96YD97)!8W1I=F4H)')E;F1E<F5R+"`D=F%R<RP@2&]R9&4Z.G-E;&95
M<FPH*2P@)W!O<W0G*3L*/SX*/&)R("\^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8P``````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#(U-S4@,3`U,34T,S,W-#4@,#(S-S8V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#QH,2!C;&%S<STB:&5A9&5R(CX*
M(#P_<&AP(&5C:&\@7R@B4&5N9&EN9R!3:6=N=7!S.B(I(#\^"CPO:#$^"@H\
M/W!H<"`D86QL475E=65D(#T@)'-I9VYU<"T^9V5T475E=65D4VEG;G5P<R@I
M.R!I9B`H(6-O=6YT*"1A;&Q1=65U960I*3H@/SX*/&1I=B!C;&%S<STB=&5X
M="(^/&5M/CP_<&AP(&5C:&\@7R@B3F\@<&5N9&EN9R!S:6=N=7!S+B(I(#\^
M/"]E;3X\+V1I=CX*/#]P:'`@96QS93H@/SX*/'1A8FQE(&-L87-S/2)S=')I
M<&5D(B!W:61T:#TB,3`P)2(@8V5L;'-P86-I;F<](C`B/@H@/'1R(&-L87-S
M/2)I=&5M(CX*("`\=&@^)FYB<W`[/"]T:#X*("`\=&@^)FYB<W`[/"]T:#X*
M("`\=&@^/#]P:'`@96-H;R!?*")5<V5R;F%M92(I(#\^/"]T:#X*("`\=&@@
M=VED=&@](C$P,"4B/CP_<&AP(&5C:&\@7R@B1&%T92!296-E:79E9"(I(#\^
M/"]T:#X*(#PO='(^"CP_<&AP(&9O<F5A8V@@*"1A;&Q1=65U960@87,@)'-I
M9VYU<"DZ(&EF("@D<VEG;G5P+3YG971.86UE*"D@(3T@1$%40512145?4D]/
M5"DZ("1D871A(#T@)'-I9VYU<"T^9V5T1&%T82@I.R`_/@H@/'1R/@H@(#QT
M9#X*("`@/&9O<FT@;65T:&]D/2)P;W-T(B!A8W1I;VX](CP_<&AP(&5C:&\@
M2&]R9&4Z.G-E;&95<FPH*2`_/B(^"B`@("`\:6YP=70@='EP93TB:&ED9&5N
M(B!N86UE/2)U<V5R7VYA;64B('9A;'5E/2(\/W!H<"!E8VAO("1S:6=N=7`M
M/F=E=$YA;64H*2`_/B(@+SX*("`@(#QI;G!U="!T>7!E/2)H:61D96XB(&YA
M;64](F9O<FTB('9A;'5E/2)A<'!R;W9E7V8B("\^"B`@("`\:6YP=70@='EP
M93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/#]P:'`@96-H;R!?
M*")!<'!R;W9E(BD@/SXB("\^"B`@(#PO9F]R;3X*("`\+W1D/@H@(#QT9#X*
M("`@/&9O<FT@;65T:&]D/2)P;W-T(B!A8W1I;VX](CP_<&AP(&5C:&\@2&]R
M9&4Z.G-E;&95<FPH*2`_/B(^"B`@("`\:6YP=70@='EP93TB:&ED9&5N(B!N
M86UE/2)U<V5R7VYA;64B('9A;'5E/2(\/W!H<"!E8VAO("1S:6=N=7`M/F=E
M=$YA;64H*2`_/B(@+SX*("`@(#QI;G!U="!T>7!E/2)H:61D96XB(&YA;64]
M(F9O<FTB('9A;'5E/2)R96UO=F5Q=65U961?9B(@+SX*("`@(#QI;G!U="!T
M>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB('9A;'5E/2(\/W!H<"!E8VAO
M(%\H(E)E;6]V92(I(#\^(B`O/@H@("`\+V9O<FT^"B`@/"]T9#X*("`\=&0^
M/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1S:6=N=7`M/F=E=$YA;64H
M*2D@/SX\+W1D/@H@(#QT9#X\/W!H<"!E8VAO(&1A=&4H)UDM32UD($@Z:3IS
M)RP@)&1A=&%;)V1A=&5296-E:79E9"==*2`_/CPO=&0^"B`\+W1R/@H\/W!H
M<"!E;F1I9CL@/SX*/#]P:'`@96YD9F]R96%C:#L@/SX*/"]T86)L93X*/#]P
M:'`@96YD:68[(#\^"CQB<B!C;&%S<STB<W!A8V5R(B`O/@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8P``````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3`R,B`Q,#4Q-30S,S<T-2`P
M,C,S-C(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/&9O<FT@;F%M93TB8VQE87)U<V5R(B!M971H;V0](G!O<W0B/@H\:6YP
M=70@='EP93TB:&ED9&5N(B!N86UE/2)F;W)M(B!V86QU93TB8VQE87(B("\^
M"@H\:#$@8VQA<W,](FAE861E<B(^"B`\/W!H<"!P<FEN=&8H7R@B0VQE87(@
M;W5T('5S97(Z("5S(BDL("1F7W5S97)?;F%M92D@/SX*/"]H,3X*/'`@8VQA
M<W,](FET96TB/@H@/'-T<F]N9SX\/W!H<"!P<FEN=&8H7R@B4F5A;&QY(')E
M;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A
M;FYO="!B92!U;F1O;F4N(BDL("1F7W5S97)?;F%M92D@/SX\+W-T<F]N9SX*
M/"]P/@H\<"!C;&%S<STB8V]N=')O;"(^"B`\:6YP=70@='EP93TB<W5B;6ET
M(B!C;&%S<STB8G5T=&]N(B!N86UE/2)S=6)M:70B('9A;'5E/2(\/W!H<"!E
M8VAO(%\H(D-L96%R('5S97(B*2`_/B(@+SX*(#QI;G!U="!T>7!E/2)S=6)M
M:70B(&-L87-S/2)B=71T;VXB(&YA;64](G-U8FUI="(@=F%L=64](CP_<&AP
M(&5C:&\@7R@B0V%N8V5L(BD@/SXB("\^"CPO<#X*/"]F;W)M/@H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,`````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-#0T,"`Q,#4Q-30S
M,S<T-2`P,C,U-C4`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM
M"@IF=6YC=&EO;B!V86QI9&%T95]U<&1A=&4H*0I["B`@("!I9B`H9&]C=6UE
M;G0N=7!D871E=7-E<BYU<V5R7VYA;64N=F%L=64@/3T@(B(I('L*("`@("`@
M("!D;V-U;65N="YU<&1A=&5U<V5R+G5S97)?;F%M92YF;V-U<R@I.PH@("`@
M("`@(&%L97)T*"<\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B66]U(&UU<W0@
M<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(I*2`_/B<I.PH@("`@("`@
M(')E='5R;B!F86QS93L*("`@('T@96QS92!I9B`H9&]C=6UE;G0N=7!D871E
M=7-E<BYU<V5R7W!A<W-?,2`F)@H@("`@("`@("`@("`@("!D;V-U;65N="YU
M<&1A=&5U<V5R+G5S97)?<&%S<U\Q+G9A;'5E("$](&1O8W5M96YT+G5P9&%T
M975S97(N=7-E<E]P87-S7S(N=F%L=64I('L*("`@("`@("!D;V-U;65N="YU
M<&1A=&5U<V5R+G5S97)?<&%S<U\Q+G9A;'5E(#T@(B(["B`@("`@("`@9&]C
M=6UE;G0N=7!D871E=7-E<BYU<V5R7W!A<W-?,BYV86QU92`]("(B.PH@("`@
M("`@(&1O8W5M96YT+G5P9&%T975S97(N=7-E<E]P87-S7S$N9F]C=7,H*3L*
M("`@("`@("!A;&5R="@G/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E!A<W-W
M;W)D<R!M=7-T(&UA=&-H+B(I*2`_/B<I.PH@("`@("`@(')E='5R;B!F86QS
M93L*("`@('T*"B`@("!R971U<FX@=')U93L*?0H*+R\M+3X*/"]S8W)I<'0^
M"@H\9F]R;2!N86UE/2)U<&1A=&5U<V5R(B!M971H;V0](G!O<W0B/@H\:6YP
M=70@='EP93TB:&ED9&5N(B!N86UE/2)F;W)M(B!V86QU93TB=7!D871E(CX*
M/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB=7-E<E]N86UE(B!V86QU93TB
M/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1F7W5S97)?;F%M92D@/SXB
M("\^"CQH,2!C;&%S<STB:&5A9&5R(CX*(#P_<&AP('!R:6YT9BA?*")5<&1A
M=&4@)7,B*2P@)&9?=7-E<E]N86UE*2`_/@H\+V@Q/@H\=&%B;&4@8VQA<W,]
M(G-T<FEP960@;F]W<F%P(B!C96QL<W!A8VEN9STB,"(@=VED=&@](C$P,"4B
M/@H\/W!H<"!I9B`H)&%U=&@M/FAA<T-A<&%B:6QI='DH)W5P9&%T92<I*3H@
M/SX*(#QT<CX*("`\=&0@=VED=&@](C$E(B!C;&%S<STB;&EG:'0@<FEG:'1!
M;&EG;B(^"B`@(#P_<&AP(&5C:&\@7R@B3F5W(%5S97)N86UE("AO<'1I;VYA
M;"DB*2`_/@H@(#PO=&0^"B`@/'1D/@H@("`\:6YP=70@='EP93TB=&5X="(@
M;F%M93TB=7-E<E]N86UE,B(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I
M86QC:&%R<R@D9E]U<V5R7VYA;64I(#\^(B`O/@H@(#PO=&0^"B`\+W1R/@H@
M/'1R/@H@(#QT9"!C;&%S<STB<FEG:'1!;&EG;B(^"B`@(#P_<&AP(&5C:&\@
M7R@B4&%S<W=O<F0B*2`_/@H@(#PO=&0^"B`@/'1D/@H@("`\:6YP=70@='EP
M93TB<&%S<W=O<F0B(&YA;64](G5S97)?<&%S<U\Q(B`O/@H@(#PO=&0^"B`\
M+W1R/@H@/'1R/@H@(#QT9"!C;&%S<STB<FEG:'1!;&EG;B(^"B`@(#P_<&AP
M(&5C:&\@7R@B0V]N9FER;2!087-S=V]R9"(I(#\^"B`@/"]T9#X*("`\=&0^
M"B`@(#QI;G!U="!T>7!E/2)P87-S=V]R9"(@;F%M93TB=7-E<E]P87-S7S(B
M("\^"B`@/"]T9#X*(#PO='(^"CP_<&AP(&5N9&EF.R`_/@H@/'1R/@H@(#QT
M9"!C;&%S<STB<FEG:'1!;&EG;B(^"B`@(#P_<&AP(&5C:&\@7R@B1G5L;"!.
M86UE(BD@/SX*("`\+W1D/@H@(#QT9#X*("`@/&EN<'5T('1Y<&4](G1E>'0B
M(&YA;64](G5S97)?9G5L;&YA;64B('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS
M<&5C:6%L8VAA<G,H)&ED96YT:71Y+3YG971686QU92@G9G5L;&YA;64G*2D@
M/SXB("\^"B`@/"]T9#X*(#PO='(^"B`\='(^"B`@/'1D(&-L87-S/2)R:6=H
M=$%L:6=N(CX*("`@/#]P:'`@96-H;R!?*")%;6%I;"!!9&1R97-S(BD@/SX*
M("`\+W1D/@H@(#QT9#X*("`@/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](G5S
M97)?96UA:6PB("!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S
M*"1I9&5N=&ET>2T^9V5T5F%L=64H)V9R;VU?861D<B<I*2`_/B(@+SX*("`\
M+W1D/@H@/"]T<CX*(#QT<CX*("`\=&0@8VQA<W,](F-O;G1R;VP@;&5F=$%L
M:6=N(B!C;VQS<&%N/2(R(CX*("`@/&EN<'5T('1Y<&4](G-U8FUI="(@8VQA
M<W,](F)U='1O;B(@;F%M93TB<W5B;6ET(B!O;F-L:6-K/2)R971U<FX@=F%L
M:61A=&5?=7!D871E*"D[(B!V86QU93TB/#]P:'`@96-H;R!?*")5<&1A=&4@
M=7-E<B(I(#\^(B`O/@H@("`\:6YP=70@='EP93TB<F5S970B(&-L87-S/2)B
M=71T;VXB(&YA;64](G)E<V5T(B!V86QU93TB/#]P:'`@96-H;R!?*")297-E
M="(I(#\^(B`O/@H@(#PO=&0^"B`\+W1R/@H\+W1A8FQE/@H\+V9O<FT^"CQB
M<B`O/@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V97%U975E9"YI;F,`````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,3`P,2`Q,#4Q-30S,S<T-2`P,C0W-S<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/&9O<FT@;65T:&]D/2)P;W-T(B!A8W1I
M;VX](CP_<&AP(&5C:&\@2&]R9&4Z.G-E;&95<FPH*2`_/B(^"CP_<&AP(%5T
M:6PZ.G!F;W)M26YP=70H*2`_/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE
M/2)F;W)M(B!V86QU93TB<F5M;W9E<75E=65D(B`O/@H\:6YP=70@='EP93TB
M:&ED9&5N(B!N86UE/2)U<V5R7VYA;64B('9A;'5E/2(\/W!H<"!E8VAO("1F
M7W5S97)?;F%M92`_/B(@+SX*"CQH,2!C;&%S<STB:&5A9&5R(CX*(#P_<&AP
M(&5C:&\@7R@B4&5N9&EN9R!3:6=N=7!S.B(I(#\^"CPO:#$^"CQP(&-L87-S
M/2)I=&5M(CX*(#P_<&AP('!R:6YT9BA?*")!<F4@>6]U('-U<F4@>6]U('=A
M;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(I+"`D
M9E]U<V5R7VYA;64I(#\^"CPO<#X*/'`@8VQA<W,](F-O;G1R;VPB/@H@(#QI
M;G!U="!C;&%S<STB8G5T=&]N(B!T>7!E/2)S=6)M:70B('9A;'5E/2(\/W!H
M<"!E8VAO(%\H(E)E;6]V92(I(#\^(B`O/@H\+W`^"CPO9F]R;3X*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V92YI;F,`````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#<W-R`Q,#4Q-30S,S<T-2`P,C,V,3$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/&9O<FT@;F%M93TB<F5M;W9E
M=7-E<B(@;65T:&]D/2)P;W-T(CX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M
M93TB9F]R;2(@=F%L=64](G)E;6]V92(@+SX*"CQH,2!C;&%S<STB:&5A9&5R
M(CX*(#P_<&AP('!R:6YT9BA?*")296UO=F4@=7-E<CH@)7,B*2P@)&9?=7-E
M<E]N86UE*2`_/@H\+V@Q/@H\<"!C;&%S<STB:71E;2(^"B`\<W1R;VYG/CP_
M<&AP('!R:6YT9BA?*")296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO
M;B!C86YN;W0@8F4@=6YD;VYE+B(I+"`D9E]U<V5R7VYA;64I(#\^/"]S=')O
M;F<^"CPO<#X*/'`@8VQA<W,](F-O;G1R;VPB/@H@/&EN<'5T('1Y<&4](G-U
M8FUI="(@8VQA<W,](F)U='1O;B(@;F%M93TB<W5B;6ET(B!V86QU93TB/#]P
M:'`@96-H;R!?*")296UO=F4@=7-E<B(I(#\^(B`O/@H@/&EN<'5T('1Y<&4]
M(G-U8FUI="(@8VQA<W,](F)U='1O;B(@;F%M93TB<W5B;6ET(B!V86QU93TB
M/#]P:'`@96-H;R!?*")#86YC96PB*2`_/B(@+SX*/"]P/@H\+V9O<FT^"@!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O861M:6XO=7-E<B]N
M;V%D9"YI;F,`````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`T,C<@
M,3`U,34T,S,W-#4@,#(S,S<Q`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#QH,2!C;&%S<STB:&5A9&5R(CX*(#P_<&AP(&5C
M:&\@7R@B061D:6YG('5S97)S(&ES(&1I<V%B;&5D+B(I(#\^"CPO:#$^"CQP
M(&-L87-S/2)C;VYT<F]L(CX*(#P_<&AP(&5C:&\@7R@B66]U<B!A=71H96YT
M:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S
M+B!)9B!Y;W4@=VES:"!T;R!U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R
M(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@875T:&5N=&EC
M871I;VX@8F%C:V5N9"XB*2`_/@H\+W`^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8P``
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,S4R(#$P-3$U-#,S-S0U
M(#`R,S8Q,0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\:#$@8VQA<W,](FAE861E<B(^"B`\/W!H<"!E8VAO(%\H(DQI<W1I
M;F<@=7-E<G,@:7,@9&ES86)L960N(BD@/SX*/"]H,3X*/'`@8VQA<W,](F-O
M;G1R;VPB/@H@/#]P:'`@96-H;R!?*")9;W5R(&%U=&AE;G1I8V%T:6]N(&)A
M8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@
M9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S
M;VXN(BD@/SX*/"]P/@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,S,P,"`Q,#4Q-30S,S<T-2`P,C,R-3``(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/&@Q(&-L
M87-S/2)H96%D97(B/@H@/#]P:'`@96-H;R!?*")5<V5R<R!I;B!T:&4@<WES
M=&5M.B(I(#\^"B`\/W!H<"!I9B`H)&YU;6ET96TI.B`_/@H@(#QS;6%L;#Y;
M/#]P:'`@<')I;G1F*%\H(B5S('1O("5S(&]F("5S(BDL("1S=&%R="P@)&5N
M9"P@)&YU;6ET96TI(#\^73PO<VUA;&P^"B`\/W!H<"!E;F1I9CL@/SX*/"]H
M,3X*"CQD:78@8VQA<W,](FAE861E<F)O>"(^"@H\9&EV(&-L87-S/2)C;VYT
M<F]L(CX*(#QF;W)M(&UE=&AO9#TB<&]S="(@;F%M93TB<V5A<F-H(B!A8W1I
M;VX](CP_<&AP(&5C:&\@2&]R9&4Z.G-E;&95<FPH*2`_/B(^"B`\/W!H<"!E
M8VAO(%5T:6PZ.F9O<FU);G!U="@I(#\^"B`\:6YP=70@='EP93TB:&ED9&5N
M(B!N86UE/2)P86=E(B!V86QU93TB,"(^"B`\<W1R;VYG/CP_<&AP(&5C:&\@
M7R@B4V5A<F-H(BD@/SXZ/"]S=')O;F<^)FYB<W`["B`\:6YP=70@;F%M93TB
M<V5A<F-H7W!A='1E<FXB('1Y<&4](G1E>'0B('9A;'5E/2(B('-I>F4](C4P
M(B!M87AL96YG=&@](C$P,"(@+SX*(#QI;G!U="!T>7!E/2)S=6)M:70B(&-L
M87-S/2)B=71T;VXB('9A;'5E/2(\/W!H<"!E8VAO(%\H(E-E87)C:"(I(#\^
M(B`O/@H@/"]F;W)M/@H\+V1I=CX*"CQT86)L92!C;&%S<STB<W1R:7!E9"(@
M=VED=&@](C$P,"4B(&-E;&QS<&%C:6YG/2(P(CX*/#]P:'`*)')E;6]V92`]
M("1A=71H+3YH87-#87!A8FEL:71Y*"=R96UO=F4G*3L*)'1O=&%L(#T@,#L*
M9F]R96%C:"`H)'5S97)S(&%S("1U<V5R*3H*("`@(&EF("@D=&]T86PK*R`\
M("1M:6X@?'P@)'1O=&%L(#X@)&UA>"D@>PH@("`@("`@(&-O;G1I;G5E.PH@
M("`@?0H_/@H@/'1R/@H\/W!H<"!I9B`H)')E;6]V92DZ(#\^"B`@/'1D('=I
M9'1H/2(Q)2(^/#]P:'`@96-H;R!(;W)D93HZ;&EN:RA(;W)D93HZ87!P;&EC
M871I;VY5<FPH)V%D;6EN+W5S97(N<&AP/V9O<FT]<F5M;W9E7V8F=7-E<E]N
M86UE/2<@+B`D=7-E<BDL(%\H(D1E;&5T92(I*2`N($AO<F1E.CII;6<H)V1E
M;&5T92YP;F<G+"!?*")$96QE=&4B*2D@/SX\+V$^/"]T9#X*/#]P:'`@96YD
M:68[(#\^"B`@/'1D('=I9'1H/2(Q)2(^/#]P:'`@96-H;R!(;W)D93HZ;&EN
M:RA(;W)D93HZ87!P;&EC871I;VY5<FPH)V%D;6EN+W5S97(N<&AP/V9O<FT]
M=7!D871E7V8F=7-E<E]N86UE/2<@+B`D=7-E<BDL(%\H(E5P9&%T92(I*2`N
M("!(;W)D93HZ:6UG*"=E9&ET+G!N9R<L(%\H(E5P9&%T92(I*2`_/CPO83X\
M+W1D/@H@(#QT9"!W:61T:#TB,24B/CP_<&AP(&5C:&\@2&]R9&4Z.FQI;FLH
M2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=A9&UI;B]U<V5R+G!H<#]F;W)M/6-L
M96%R7V8F=7-E<E]N86UE/2<@+B`D=7-E<BDL(%\H(D-L96%R('5S97(@9&%T
M82(I*2`N("!(;W)D93HZ:6UG*"=R96QO860N<&YG)RP@7R@B0VQE87(@=7-E
M<B!D871A(BDI(#\^/"]A/CPO=&0^"B`@/'1D(&-L87-S/2)L969T06QI9VXB
M/CP_<&AP(&5C:&\@)'5S97(@/SX\+W1D/@H@/"]T<CX*/#]P:'`@96YD9F]R
M96%C:#L@/SX*/"]T86)L93X*/#]P:'`*:68@*"1N=6UI=&5M*2!["B`@("`D
M<&%G97(@/2`F;F5W($AO<F1E7U5)7U!A9V5R*"=P86=E)RP@)'9A<G,L(&%R
M<F%Y*"=N=6TG(#T^("1T;W1A;"P@)W5R;"<@/3X@)'9I97=U<FPL("=P86=E
M7V-O=6YT)R`]/B`Q,"P@)W!E<G!A9V4G(#T^("1P97)P86=E*2D["B`@("!E
M8VAO("1P86=E<BT^<F5N9&5R*"1P86=E+"`D=&]T86PL("1V:65W=7)L*3L*
M?0H_/@H\+V1I=CX*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP
M;&%T97,O861M:6XO<V5T=7``````````````````````````````````````
M````````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W-#4@,#(Q-S$Q`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`V,R`Q,#4Q-30S,S<T
M-2`P,C,W-C8`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/'1A9SIN;W1I9GD@+SX*"CQT86)L92!C;&%S<STB<W1R:7!E9"(@
M8V5L;'-P86-I;F<](C`B('=I9'1H/2(Q,#`E(CX*("`\='(^"B`@("`\=&0@
M8VQA<W,](FAE861E<B(^"B`@("`@(#QG971T97AT/D%P<&QI8V%T:6]N/"]G
M971T97AT/@H@("`@/"]T9#X*("`@(#QT9"!C;&%S<STB:&5A9&5R(CX*("`@
M("`@)FYB<W`["B`@("`\+W1D/@H@("`@/'1D(&-L87-S/2)H96%D97(B/@H@
M("`@("`\9V5T=&5X=#Y3=&%T=7,\+V=E='1E>'0^"B`@("`\+W1D/@H@(#PO
M='(^"B`@/&QO;W`Z87!P<SX*("`\='(^"B`@("`\=&0^"B`@("`@(#QT86<Z
M87!P<RYN86UE("\^"B`@("`@(#QT86<Z87!P<RYV97)S:6]N("\^"B`@("`\
M+W1D/@H@("`@/'1D(&%L:6=N/2)C96YT97(B/@H@("`@("`\=&%G.F%P<',N
M8V]N9B`O/@H@("`@/"]T9#X*("`@(#QT9#X*("`@("`@/'1A9SIA<'!S+G-T
M871U<R`O/@H@("`@/"]T9#X*("`\+W1R/@H@(#PO;&]O<#IA<'!S/@H\+W1A
M8FQE/@H\8G(@+SX*"CQT86)L92!I9#TB=7!D871E(B!C96QL<W!A8VEN9STB
M,"(@=VED=&@](C$P,"4B/@H@(#QT<B!V86QI9VX](G1O<"(^"B`@("`\=&0@
M=VED=&@](C4P)2(^"B`@("`@(#QI9CIA8W1I;VYS/@H@("`@("`\:#$@8VQA
M<W,](FAE861E<B(^"B`@("`@("`\9V5T=&5X=#Y3971U<"!U<&=R861E('-C
M<FEP=',@879A:6QA8FQE/"]G971T97AT/@H@("`@("`\+V@Q/@H@("`@("`\
M=&%B;&4@8VQA<W,](G-T<FEP960B(&-E;&QS<&%C:6YG/2(P(B!W:61T:#TB
M,3`P)2(^"B`@("`@("`\;&]O<#IA8W1I;VYS/@H@("`@("`@(#QT<CX*("`@
M("`@("`@/'1D/@H@("`@("`@("`@/'1A9SIA8W1I;VYS+FEC;VX@+SX@/'1A
M9SIA8W1I;VYS+FQI;FL@+SX*("`@("`@("`@/"]T9#X*("`@("`@("`\+W1R
M/@H@("`@("`@/"]L;V]P.F%C=&EO;G,^"B`@("`@(#PO=&%B;&4^"B`@("`@
M(#PO:68Z86-T:6]N<SX*("`@(#PO=&0^"B`@("`\=&0@=VED=&@](C4P)2(^
M"B`@("`@(#QI9CIF='!F;W)M/@H@("`@("`@(#QT86<Z9G1P9F]R;2`O/@H@
M("`@("`\+VEF.F9T<&9O<FT^"B`@("`\+W1D/@H@(#PO='(^"CPO=&%B;&4^
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S
M+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P,S,R(#$P-3$U-#,S-S0U(#`R-#$R,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\=&%G.FYO=&EF>2`O/@H*
M/'1A9SIF;W)M("\^"@H\:68Z<&AP/@H\8G(@+SX*/&@Q(&-L87-S/2)H96%D
M97(B/@H@/&=E='1E>'0^1V5N97)A=&5D($-O9&4\+V=E='1E>'0^"B`\<VUA
M;&P^6R`\=&%G.F1I9F9?<&]P=7`@+SX@73PO<VUA;&P^"CPO:#$^"CQT97AT
M87)E82!S='EL93TB=VED=&@Z,3`P)2(@<F]W<STB,C`B/CQT86<Z<&AP("\^
M/"]T97AT87)E83X*/"]I9CIP:'`^"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]A9&UI;B]S971U
M<"]D:69F+FAT;6P`````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#4Q
M-R`Q,#4Q-30S,S<T-2`P,C,U-S$`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/&EF.F1I9F9S/@H\;&]O<#ID:69F<SX*/&@Q
M(&-L87-S/2)H96%D97(B(&ED/2(\=&%G.F1I9F9S+F%P<"`O/B(^"B`\=&%G
M.F1I9F9S+F%P<"`O/B`\<VUA;&P^6R`\=&%G.F1I9F9S+G1O9V=L95]R96YD
M97)E<B`O/B!=/"]S;6%L;#X*/"]H,3X*/'!R92!C;&%S<STB=&5X="(^/'1A
M9SID:69F<RYD:69F("\^/"]P<F4^"CPO;&]O<#ID:69F<SX*/&5L<V4Z9&EF
M9G,^"CQP(&-L87-S/2)N;W1I8V4B/CQG971T97AT/DYO(&%V86EL86)L92!C
M;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N/"]G
M971T97AT/CPO<#X*/"]E;'-E.F1I9F9S/@H\+VEF.F1I9F9S/@H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T96UP;&%T97,O861M:6XO9W)O=7!S````````````
M````````````````````````````````````````````````````````````
M,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W
M-#4@,#(R,#<P`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]A9&UI
M;B]G<F]U<',O961I="YI;F,`````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,S8P-R`Q,#4Q-30S,S<T-2`P,C,U-S4`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/&9O<FT@;F%M93TB961I=%]G<F]U
M<"(@;65T:&]D/2)P;W-T(B!A8W1I;VX](F=R;W5P<RYP:'`B/@H\:6YP=70@
M='EP93TB:&ED9&5N(B!N86UE/2)A8W1I;VY)1"(@=F%L=64](F5D:71F;W)M
M(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)C:60B('9A;'5E/2(\
M/W!H<"!E8VAO("1G<F]U<"T^9V5T260H*2`_/B(@+SX*/#]P:'`@571I;#HZ
M<&9O<FU);G!U="@I(#\^"@H\:#$@8VQA<W,](FAE861E<B(^"B`\/W!H<"!E
M8VAO($AO<F1E.CII;6<H)W5S97(N<&YG)RD@+B`G("<@+B!H=&UL<W!E8VEA
M;&-H87)S*"1G<F]U<"T^9V5T4VAO<G1.86UE*"DI(#\^"CPO:#$^"@H\;&%B
M96P@9F]R/2)E;6%I;"(^/#]P:'`@96-H;R!?*")%;6%I;"!!9&1R97-S(BD@
M/SX\+VQA8F5L/@H\:6YP=70@='EP93TB=&5X="(@;F%M93TB96UA:6PB(&ED
M/2)E;6%I;"(@<VEZ93TB-3`B('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C
M:6%L8VAA<G,H)&=R;W5P+3YG970H)V5M86EL)RDI(#\^(B`O/@H\8G(@+SX*
M/&)R("\^"@H\:#$@8VQA<W,](FAE861E<B(^"B`\/W!H<"!E8VAO($AO<F1E
M.CII;6<H)V=R;W5P+G!N9R<I("X@)R`G("X@7R@B365M8F5R<R(I(#\^"CPO
M:#$^"@H\=&%B;&4@8VQA<W,](FQI;F5D4F]W(&YO=W)A<"(@8V5L;'-P86-I
M;F<](C`B('=I9'1H/2(Q,#`E(CX*(#QT<B!C;&%S<STB8V]N=')O;"(^"B`@
M/'1H('=I9'1H/2(Q,"4B(&-L87-S/2)L969T06QI9VXB/CP_<&AP(&5C:&\@
M7R@B57-E<B(I(#\^/"]T:#X*("`\=&@@=VED=&@](CDP)2(@8VQA<W,](FQE
M9G1!;&EG;B(^/#]P:'`@96-H;R!?*")296UO=F4B*2`_/CPO=&@^"B`\+W1R
M/@H\/W!H<"!F;W)E86-H("@D=7-E<G,@87,@)'5S97(I.B`_/@H@/'1R/@H@
M(#QT9#X\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'5S97(I(#\^/"]T
M9#X*("`\=&0^/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE/2)R96UO=F5;
M/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1U<V5R*2`_/ETB("\^/"]T
M9#X*(#PO='(^"CP_<&AP(&5N9&9O<F5A8V@[(#\^"CPO=&%B;&4^"CQB<B`O
M/@H*/#]P:'`@:68@*&-O=6YT*"1I;FAE<FET961?=7-E<G,I*3H@/SX*/&@Q
M(&-L87-S/2)H96%D97(B/@H@/#]P:'`@96-H;R!(;W)D93HZ:6UG*"=G<F]U
M<"YP;F<G*2`N("<@)R`N(%\H(DEN:&5R:71E9"!-96UB97)S(BD@/SX*/"]H
M,3X*/'5L/@H\/W!H<"!F;W)E86-H("@D:6YH97)I=&5D7W5S97)S(&%S("1U
M<V5R*3H@/SX*(#QL:3X\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'5S
M97(I(#\^/"]L:3X*/#]P:'`@96YD9F]R96%C:#L@/SX*/"]U;#X*/&)R("\^
M"CP_<&AP(&5N9&EF.R`_/@H*/&@Q(&-L87-S/2)H96%D97(B/@H@/#]P:'`@
M96-H;R!(;W)D93HZ:6UG*"=U<V5R+G!N9R<I("X@)R`G("X@7R@B061D($UE
M;6)E<G,B*2`_/@H\+V@Q/@H\/W!H<"!I9B`H)&%U=&@M/FAA<T-A<&%B:6QI
M='DH)VQI<W0G*2DZ(#\^"CQS96QE8W0@;F%M93TB;F5W7W5S97);72(@;75L
M=&EP;&4](FUU;'1I<&QE(CX*/#]P:'`@9F]R96%C:"`H)'5S97)?;&ES="!A
M<R`D=7-E<BD@>R!I9B`H(6EN7V%R<F%Y*"1U<V5R+"`D86QL7W5S97)S*2D@
M>R`_/@H@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H;R`D=7-E<B`_/B(^/#]P
M:'`@96-H;R`D=7-E<B`_/CPO;W!T:6]N/@H\/W!H<"!]('T@/SX*/"]S96QE
M8W0^"CP_<&AP(&5L<V4Z(#\^"CQI;G!U="!T>7!E/2)T97AT(B!N86UE/2)N
M97=?=7-E<B(@+SX*/#]P:'`@96YD:68[(#\^"CQI;G!U="!T>7!E/2)S=6)M
M:70B(&-L87-S/2)B=71T;VXB('9A;'5E/2(\/W!H<"!P<FEN=&8H:'1M;'-P
M96-I86QC:&%R<RA?*")3879E(%PB)7-<(B(I+"!%3E1?0T]-4$%4+"!.3%,Z
M.F=E=$-H87)S970H*2DL("1G<F]U<"T^9V5T4VAO<G1.86UE*"DI(#\^(B`O
M/@H\8G(@+SX*/&)R("\^"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O861M:6XO9W)O
M=7!S+V%D9&-H:6QD+FEN8P``````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`W
M,3,@,3`U,34T,S,W-#4@,#(T,S<W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#QF;W)M(&YA;64](F%D9%]C:&EL9"(@;65T
M:&]D/2)P;W-T(B!A8W1I;VX](F=R;W5P<RYP:'`B/@H\:6YP=70@='EP93TB
M:&ED9&5N(B!N86UE/2)A8W1I;VY)1"(@=F%L=64](F%D9&-H:6QD9F]R;2(@
M+SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB8VED(B!V86QU93TB/#]P
M:'`@96-H;R`D8VED(#\^(B`O/@H\/W!H<"!5=&EL.CIP9F]R;4EN<'5T*"D@
M/SX*"CQH,2!C;&%S<STB:&5A9&5R(CX*(#P_<&AP(&5C:&\@2&]R9&4Z.FEM
M9R@G9W)O=7`N<&YG)RD@/SXF;F)S<#L\/W!H<"!P<FEN=&8H7R@B061D(&$@
M8VAI;&0@9W)O=7`@=&\@7"(E<UPB(BDL("1G;F%M92D@/SX*/"]H,3X*"CQI
M;G!U="!T>7!E/2)T97AT(B!N86UE/2)C:&EL9"(@+SX*/&EN<'5T('1Y<&4]
M(G-U8FUI="(@8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP(&5C:&\@7R@B
M061D(BD@/SXB("\^"CPO9F]R;3X*/&)R("\^"@``````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N
M:6YC````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,3`W(#$P-3$U-#,S
M-S0U(#`R-#$P,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\9F]R;2!N86UE/2)D96QE=&4B(&UE=&AO9#TB<&]S="(@86-T
M:6]N/2)G<F]U<',N<&AP(CX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB
M86-T:6]N240B('9A;'5E/2)D96QE=&5F;W)M(B`O/@H\:6YP=70@='EP93TB
M:&ED9&5N(B!N86UE/2)C:60B('9A;'5E/2(\/W!H<"!E8VAO("1G<F]U<"T^
M9V5T260H*2`_/B(@+SX*/#]P:'`@571I;#HZ<&9O<FU);G!U="@I(#\^"@H\
M:#$@8VQA<W,](FAE861E<B(^"B`\/W!H<"!E8VAO($AO<F1E.CII;6<H)V=R
M;W5P+G!N9R<I(#\^)FYB<W`[/#]P:'`@<')I;G1F*%\H(D%R92!Y;W4@<W5R
M92!Y;W4@=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P
M<S\B*2P@)&=R;W5P+3YG9713:&]R=$YA;64H*2D@/SX*/"]H,3X*"CQI;G!U
M="!T>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB(&YA;64](F-O;F9I<FTB
M('9A;'5E/2(\/W!H<"!E8VAO(%\H(D1E;&5T92(I(#\^(B`O/@H\:6YP=70@
M='EP93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!N86UE/2)C;VYF:7)M(B!V
M86QU93TB/#]P:'`@96-H;R!?*")#86YC96PB*2`_/B(@+SX*/"]F;W)M/@H\
M8G(@+SX*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH
M96%D97(N:6YC````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q-S(S(#$P
M-3$U-#,S-S0U(#`R-#`T-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\9&EV(&ED/2)M96YU(CX*(#QS<&%N(&-L87-S/2)L
M969T1FQO870B/@H\/W!H<`HD;65N=2`]("9N97<@365N=2@I.PHD;65N=2T^
M861D*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G<V5R=FEC97,O<&]R=&%L+R<I
M+"!?*")(;U]M92(I+"`G:&]R9&4N<&YG)RD["F9O<F5A8V@@*"1R96=I<W1R
M>2T^;&ES=$%P<',H*2!A<R`D87!P*2!["B`@("!I9B`H)')E9VES=')Y+3YH
M87--971H;V0H)V%D;6EN7VQI<W0G+"`D87!P*2D@>PH@("`@("`@("1L:7-T
M(#T@)')E9VES=')Y+3YC86QL0GE086-K86=E*"1A<'`L("=A9&UI;E]L:7-T
M)RD["B`@("`@("`@:68@*&ES7V$H)&QI<W0L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@?0H*("`@("`@("!F;W)E
M86-H("@D;&ES="!A<R`D=F%L<RD@>PH@("`@("`@("`@("!I9B`H)&%P<"`A
M/2`G:&]R9&4G*2!["B`@("`@("`@("`@("`@("`D;F%M92`]("1R96=I<W1R
M>2T^9V5T*"=N86UE)RP@)&%P<"D["B`@("`@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1V86QS6R=N86UE)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)&YA
M;64@+CT@)R`G("X@)'9A;'-;)VYA;64G73L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1N86UE(#T@
M)'9A;'-;)VYA;64G73L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D:6UG
M(#T@:7-S970H)'9A;'-;)VEC;VXG72D@/R`D<F5G:7-T<GDM/F=E=$EM86=E
M1&ER*"1A<'`I("X@)R\G("X@)'9A;'-;)VEC;VXG72`Z("1R96=I<W1R>2T^
M9V5T*"=I8V]N)RP@)&%P<"D["B`@("`@("`@("`@("1M96YU+3YA9&0H2&]R
M9&4Z.G5R;"@D<F5G:7-T<GDM/F%P<&QI8V%T:6]N5V5B4&%T:"@D=F%L<ULG
M;&EN:R==+"`D87!P*2DL("1N86UE+"`D:6UG+"`G)RD["B`@("`@("`@?0H@
M("`@?0I]"F5C:&\@)&UE;G4M/G)E;F1E<B@I.PH_/@H@/"]S<&%N/@H\+V1I
M=CX*````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+VEN9&5X````
M````````````````````````````````````````````````````````````
M`````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M,#`P(#$P-3$U-#,S-S0U(#`R,#4W,``@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M96UP;&%T97,O:6YD97@O9G)A;65S7VEN9&5X+FEN8P``````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#(R-3,@,3`U,34T,S,W-#4@,#(T,#$P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP("1R
M=&P@/2!I<W-E="@D;FQS6R=R=&PG75LD;&%N9W5A9V5=*2`_/@H\(41/0U19
M4$4@:'1M;"!054),24,@(BTO+U<S0R\O1%1$(%A(5$U,(#$N,"!&<F%M97-E
M="\O14XB(")$5$0O>&AT;6PQ+69R86UE<V5T+F1T9"(^"CQH=&UL/@H\:&5A
M9#X*(#QL:6YK(')E;#TB4TA/4E1#550@24-/3B(@:')E9CTB/#]P:'`@96-H
M;R`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"D@/SXO9F%V:6-O;BYI8V\B("\^
M"B`\=&ET;&4^/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1R96=I<W1R
M>2T^9V5T*"=N86UE)RDI(#\^/"]T:71L93X*/"]H96%D/@H*/&9R86UE<V5T
M(&ED/2)H9B(@8V]L<STB/#]P:'`@96-H;R`H)')T;"`_("<J+"<@.B`G)RD@
M+B`H:7-S970H)'!R969S*2`_("1P<F5F<RT^9V5T5F%L=64H)W-I9&5B87)?
M=VED=&@G*2`Z(#$U,"D@+B`H)')T;"`_("<G(#H@)RPJ)RD@/SXB(&9R86UE
M<W!A8VEN9STB,"(@9G)A;65B;W)D97(](C`B/@H\/W!H<"!I9B`H)')T;"DZ
M(#\^"B`@/&9R86UE(&YA;64](FAO<F1E7VUA:6XB('-R8STB/#]P:'`@96-H
M;R!5=&EL.CIA9&1087)A;65T97(H:'1M;'-P96-I86QC:&%R<R@D;6%I;E]P
M86=E*2P@)V9R86UE<V5T7VQO861E9"<L(#$I(#\^(B!S8W)O;&QI;F<](CP_
M<&AP(&5C:&\@)'-C<F]L;&)A<B`_/B(@;F]R97-I>F4](FYO<F5S:7IE(B`O
M/@H@(#QF<F%M92!N86UE/2)H;W)D95]M96YU(B!S<F,](CP_<&AP(&5C:&\@
M2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=S97)V:6-E<R]P;W)T86PO<VED96)A
M<BYP:'`G*2`_/B(@<V-R;VQL:6YG/2)A=71O(B!N;W)E<VEZ93TB;F]R97-I
M>F4B("\^"CP_<&AP(&5L<V4Z(#\^"B`@/&9R86UE(&YA;64](FAO<F1E7VUE
M;G4B('-R8STB/#]P:'`@96-H;R!(;W)D93HZ87!P;&EC871I;VY5<FPH)W-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<"<I(#\^(B!S8W)O;&QI;F<](F%U
M=&\B(&YO<F5S:7IE/2)N;W)E<VEZ92(@+SX*("`\9G)A;64@;F%M93TB:&]R
M9&5?;6%I;B(@<W)C/2(\/W!H<"!E8VAO(%5T:6PZ.F%D9%!A<F%M971E<BAH
M=&UL<W!E8VEA;&-H87)S*"1M86EN7W!A9V4I+"`G9G)A;65S971?;&]A9&5D
M)RP@,2D@/SXB('-C<F]L;&EN9STB/#]P:'`@96-H;R`D<V-R;VQL8F%R(#\^
M(B!N;W)E<VEZ93TB;F]R97-I>F4B("\^"CP_<&AP(&5N9&EF.R`_/@H\+V9R
M86UE<V5T/@H*/"]H=&UL/@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]S:&%R97,`````````
M````````````````````````````````````````````````````````````
M```````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q
M,#4Q-30S,S<T-2`P,C`W-#8`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8P``````````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#(V-3(W(#$P-3$U-#,S-S0U(#`R,C0V,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\9F]R;2!N86UE/2)E
M9&ET(B!M971H;V0](G!O<W0B(&%C=&EO;CTB/#]P:'`@96-H;R!H=&UL<W!E
M8VEA;&-H87)S*"1?4T525D526R=02%!?4T5,1B==*2`_/B(^"CP_<&AP(%5T
M:6PZ.G!F;W)M26YP=70H*2`_/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE
M/2)A8W1I;VY)1"(@=F%L=64](F5D:71F;W)M(B`O/@H\:6YP=70@='EP93TB
M:&ED9&5N(B!N86UE/2)C:60B('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C
M:6%L8VAA<G,H)'-H87)E+3YG971)9"@I*2`_/B(@+SX*/#]P:'`@:68@*"%E
M;7!T>2@D87!P*2DZ(#\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%P
M<"(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D87!P*2`_
M/B(@+SX*/#]P:'`@96YD:68[(#\^"CQT86)L92!W:61T:#TB,3`P)2(@8V5L
M;'-P86-I;F<](C`B/@H\='(@=F%L:6=N/2)M:61D;&4B/@H@(#QT9"!W:61T
M:#TB,3`P)2(@8V]L<W!A;CTB-B(@8VQA<W,](FAE861E<B(^"B`@("`\<W!A
M;B!C;&%S<STB<FEG:'1&;&]A="(^"B`@("`@(#QA(&AR968](B,B(&]N8VQI
M8VL](FIA=F%S8W)I<'0Z=VEN9&]W+F-L;W-E*"D[(B!S='EL93TB8W5R<V]R
M.G!O:6YT97(B/CP_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G8VQO<V4N<&YG)RP@
M7R@B0VQO<V4@5VEN9&]W(BDL("<G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER
M*"=H;W)D92<I*2`_/CPO83X*("`@(#PO<W!A;CX*("`@(#P_<&AP(&5C:&\@
M2&]R9&4Z.FEM9R@G<&5R;7,N<&YG)RP@)R<L("<G+"`D<F5G:7-T<GDM/F=E
M=$EM86=E1&ER*"=H;W)D92<I*2`_/B9N8G-P.SP_<&AP('!R:6YT9BA?*")%
M9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(I+"!H=&UL<W!E8VEA;&-H87)S*"1S
M:&%R92T^9V5T*"=N86UE)RDI*2`_/@H@(#PO=&0^"CPO='(^"CQT<CX\=&0^
M)FYB<W`[/"]T9#X\+W1R/@H*/#]P:'`@)&]W;F5R(#T@)'-H87)E+3YG970H
M)V]W;F5R)RD[(#\^"CP_<&AP("1U<V5R<&5R;7,@/2`D<&5R;2T^9V5T57-E
M<E!E<FUI<W-I;VYS*"D[(#\^"@H\(2TM($]W;F5R<VAI<"`M+3X*/#]P:'`*
M:68@*&ES<V5T*"1U<V5R<&5R;7-;)&]W;F5R72DI('L*("`@("1O<&5R;2`]
M("1U<V5R<&5R;7-;)&]W;F5R73L*?2!E;'-E('L*("`@("1O<&5R;2`](%!%
M4DU37U-(3U<@?"!015)-4U]214%$('P@4$5235-?141)5"!\(%!%4DU37T1%
M3$5413L*?0H_/@H\='(@=F%L:6=N/2)M:61D;&4B/@H@(#QT9"!C;&%S<STB
M:&5A9&5R(&QE9G1!;&EG;B(@=VED=&@](C4U)2(^"B`@("`\/W!H<"!E8VAO
M($AO<F1E.CII;6<H)W!E<FUS+G!N9R<L("<G+"`G)RP@)')E9VES=')Y+3YG
M971);6%G941I<B@G:&]R9&4G*2D@+B`G)FYB<W`[)R`N(%\H(D]W;F5R(%!E
M<FUI<W-I;VYS(BD@/SX*("`\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R(B!A
M;&EG;CTB8V5N=&5R(B!W:61T:#TB,24B/CP_<&AP(&5C:&\@7R@B4VAO=R(I
M(#\^/"]T9#X*("`\=&0@8VQA<W,](FAE861E<B(@86QI9VX](F-E;G1E<B(@
M=VED=&@](C$E(CX\/W!H<"!E8VAO(%\H(E)E860B*2`_/CPO=&0^"B`@/'1D
M(&-L87-S/2)H96%D97(B(&%L:6=N/2)C96YT97(B('=I9'1H/2(Q)2(^/#]P
M:'`@96-H;R!?*")%9&ET(BD@/SX\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R
M(B!A;&EG;CTB8V5N=&5R(B!W:61T:#TB,24B/CP_<&AP(&5C:&\@7R@B1&5L
M971E(BD@/SX\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R(')I9VAT06QI9VXB
M('=I9'1H/2(T,"4B/B9N8G-P.SPO=&0^"CPO='(^"CQT<CX*/#]P:'`@:68@
M*"1A=71H+3YH87-#87!A8FEL:71Y*"=L:7-T)RDI.B`_/@H@(#QT9"!C;&%S
M<STB;&EG:'0B/@H@("`@/'-E;&5C="!N86UE/2)O=VYE<B(^"B`@("`@(#QO
M<'1I;VX@=F%L=64](B(^/#]P:'`@96-H;R!?*")396QE8W0@82!N97<@;W=N
M97(B*2`N("<Z)R`_/CPO;W!T:6]N/@H@("`@("`\;W!T:6]N('9A;'5E/2(\
M/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&]W;F5R*2`_/B(@<V5L96-T
M960](G-E;&5C=&5D(CX\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H075T
M:#HZ<F5M;W9E2&]O:R@D;W=N97(I*2`_/CPO;W!T:6]N/@H@("`@/#]P:'`@
M9F]R96%C:"`H)'5S97),:7-T(&%S("1U<V5R*2![(&EF("@D=7-E<B`A/2`D
M;W=N97(I('L@/SX*("`@("`@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H;R!H
M=&UL<W!E8VEA;&-H87)S*"1U<V5R*2`_/B(^/#]P:'`@96-H;R!H=&UL<W!E
M8VEA;&-H87)S*$%U=&@Z.G)E;6]V94AO;VLH)'5S97(I*2`_/CPO;W!T:6]N
M/@H@("`@/#]P:'`@?2!](#\^"B`@("`\+W-E;&5C=#X*("`\+W1D/@H\/W!H
M<"!E;'-E.B`_/@H@(#QT9"!C;&%S<STB;&EG:'0B/CQI;G!U="!T>7!E/2)T
M97AT(B!N86UE/2)O=VYE<B(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I
M86QC:&%R<R@D;W=N97(I(#\^(B`O/CPO=&0^"CP_<&AP(&5N9&EF.R`_/@H@
M(#QT9"!A;&EG;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA
M;64](F]W;F5R7W-H;W<B/#]P:'`@96-H;R`H)&]P97)M("8@4$5235-?4TA/
M5RD@/R`G(&-H96-K960](F-H96-K960B)R`Z("<G(#\^("\^/"]T9#X*("`\
M=&0@86QI9VX](F-E;G1E<B(^/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE
M/2)O=VYE<E]R96%D(CP_<&AP(&5C:&\@*"1O<&5R;2`F(%!%4DU37U)%040I
M(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@.B`G)R`_/B`O/CPO=&0^"B`@/'1D
M(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB
M;W=N97)?961I="(\/W!H<"!E8VAO("@D;W!E<FT@)B!015)-4U]%1$E4*2`_
M("<@8VAE8VME9#TB8VAE8VME9"(G(#H@)R<@/SX@+SX\+W1D/@H@(#QT9"!A
M;&EG;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](F]W
M;F5R7V1E;&5T92(\/W!H<"!E8VAO("@D;W!E<FT@)B!015)-4U]$14Q%5$4I
M(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@.B`G)R`_/B`O/CPO=&0^"CPO='(^
M"@H\(2TM(%-P86-E<B`M+3X*/'1R/CQT9#XF;F)S<#L\+W1D/CPO='(^"@H\
M(2TM($1E9F%U;'0@4&5R;6ES<VEO;G,@+2T^"CQT<B!V86QI9VX](FUI9&1L
M92(^"B`@/'1D(&-L87-S/2)H96%D97(@;&5F=$%L:6=N(CX*("`@(#P_<&AP
M(&5C:&\@2&]R9&4Z.FEM9R@G<&5R;7,N<&YG)RP@)R<L("<G+"`D<F5G:7-T
M<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`N("<F;F)S<#LG("X@7R@B06QL
M($%U=&AE;G1I8V%T960@57-E<G,B*2`_/@H@(#PO=&0^"B`@/'1D(&-L87-S
M/2)H96%D97(B(&%L:6=N/2)C96YT97(B/CP_<&AP(&5C:&\@7R@B4VAO=R(I
M(#\^/"]T9#X*("`\=&0@8VQA<W,](FAE861E<B(@86QI9VX](F-E;G1E<B(^
M/#]P:'`@96-H;R!?*")296%D(BD@/SX\+W1D/@H@(#QT9"!C;&%S<STB:&5A
M9&5R(B!A;&EG;CTB8V5N=&5R(CX\/W!H<"!E8VAO(%\H(D5D:70B*2`_/CPO
M=&0^"B`@/'1D(&-L87-S/2)H96%D97(B(&%L:6=N/2)C96YT97(B/CP_<&AP
M(&5C:&\@7R@B1&5L971E(BD@/SX\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R
M(')I9VAT06QI9VXB/B9N8G-P.SPO=&0^"CPO='(^"CP_<&AP("1D<&5R;2`]
M("1P97)M+3YG971$969A=6QT4&5R;6ES<VEO;G,H*3L@/SX*/'1R/@H@(#QT
M9"!C;&%S<STB;&EG:'0B/B9N8G-P.SPO=&0^"B`@/'1D(&%L:6=N/2)C96YT
M97(B/CQI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB9&5F875L=%]S:&]W
M(CP_<&AP(&5C:&\@*"1D<&5R;2`F(%!%4DU37U-(3U<I(#\@)R!C:&5C:V5D
M/2)C:&5C:V5D(B<@.B`G)R`_/B`O/CPO=&0^"B`@/'1D(&%L:6=N/2)C96YT
M97(B/CQI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB9&5F875L=%]R96%D
M(CP_<&AP(&5C:&\@*"1D<&5R;2`F(%!%4DU37U)%040I(#\@)R!C:&5C:V5D
M/2)C:&5C:V5D(B<@.B`G)R`_/B`O/CPO=&0^"B`@/'1D(&%L:6=N/2)C96YT
M97(B/CQI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB9&5F875L=%]E9&ET
M(CP_<&AP(&5C:&\@*"1D<&5R;2`F(%!%4DU37T5$250I(#\@)R!C:&5C:V5D
M/2)C:&5C:V5D(B<@.B`G)R`_/B`O/CPO=&0^"B`@/'1D(&%L:6=N/2)C96YT
M97(B/CQI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB9&5F875L=%]D96QE
M=&4B/#]P:'`@96-H;R`H)&1P97)M("8@4$5235-?1$5,151%*2`_("<@8VAE
M8VME9#TB8VAE8VME9"(G(#H@)R<@/SX@+SX\+W1D/@H\+W1R/@H*/"$M+2!3
M<&%C97(@+2T^"CQT<CX\=&0^)FYB<W`[/"]T9#X\+W1R/@H*/"$M+2!'=65S
M="!097)M:7-S:6]N<R`M+3X*/'1R('9A;&EG;CTB;6ED9&QE(CX*("`\=&0@
M8VQA<W,](FAE861E<B!L969T06QI9VXB/@H@("`@/#]P:'`@96-H;R!?*")'
M=65S="!097)M:7-S:6]N<R(I(#\^"B`@/"]T9#X*("`\=&0@8VQA<W,](FAE
M861E<B(@86QI9VX](F-E;G1E<B(^/#]P:'`@96-H;R!?*")3:&]W(BD@/SX\
M+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R(B!A;&EG;CTB8V5N=&5R(CX\/W!H
M<"!E8VAO(%\H(E)E860B*2`_/CPO=&0^"B`@/'1D(&-L87-S/2)H96%D97(B
M(&%L:6=N/2)C96YT97(B/CP_<&AP(&5C:&\@7R@B161I="(I(#\^/"]T9#X*
M("`\=&0@8VQA<W,](FAE861E<B(@86QI9VX](F-E;G1E<B(^/#]P:'`@96-H
M;R!?*")$96QE=&4B*2`_/CPO=&0^"B`@/'1D(&-L87-S/2)H96%D97(@<FEG
M:'1!;&EG;B(^)FYB<W`[/"]T9#X*/"]T<CX*/#]P:'`@)&=P97)M(#T@)'!E
M<FTM/F=E=$=U97-T4&5R;6ES<VEO;G,H*3L@/SX*/'1R/@H@(#QT9"!C;&%S
M<STB;&EG:'0B/B9N8G-P.SPO=&0^"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI
M;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB9W5E<W1?<VAO=R(\/W!H<"!E
M8VAO("@D9W!E<FT@)B!015)-4U]32$]7*2`_("<@8VAE8VME9#TB8VAE8VME
M9"(G(#H@)R<@/SX@+SX\+W1D/@H@(#QT9"!A;&EG;CTB8V5N=&5R(CX\:6YP
M=70@='EP93TB8VAE8VMB;W@B(&YA;64](F=U97-T7W)E860B/#]P:'`@96-H
M;R`H)&=P97)M("8@4$5235-?4D5!1"D@/R`G(&-H96-K960](F-H96-K960B
M)R`Z("<G(#\^("\^/"]T9#X*("`\=&0@86QI9VX](F-E;G1E<B(^/&EN<'5T
M('1Y<&4](F-H96-K8F]X(B!N86UE/2)G=65S=%]E9&ET(CP_<&AP(&5C:&\@
M*"1G<&5R;2`F(%!%4DU37T5$250I(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@
M.B`G)R`_/B`O/CPO=&0^"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T
M>7!E/2)C:&5C:V)O>"(@;F%M93TB9W5E<W1?9&5L971E(CP_<&AP(&5C:&\@
M*"1G<&5R;2`F(%!%4DU37T1%3$5412D@/R`G(&-H96-K960](F-H96-K960B
M)R`Z("<G(#\^("\^/"]T9#X*/"]T<CX*"CPA+2T@4W!A8V5R("TM/@H\='(^
M/'1D/B9N8G-P.SPO=&0^/"]T<CX*"CPA+2T@0W)E871O<B!097)M:7-S:6]N
M<R`M+3X*/'1R('9A;&EG;CTB;6ED9&QE(CX*("`\=&0@8VQA<W,](FAE861E
M<B!L969T06QI9VXB/@H@("`@/#]P:'`@96-H;R!(;W)D93HZ:6UG*"=U<V5R
M+G!N9R<L("<G+"`G)RP@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G
M*2D@+B`G)FYB<W`[)R`N(%\H(D]B:F5C="!#<F5A=&]R(BD@/SX*("`\+W1D
M/@H@(#QT9"!C;&%S<STB:&5A9&5R(B!A;&EG;CTB8V5N=&5R(CX\/W!H<"!E
M8VAO(%\H(E-H;W<B*2`_/CPO=&0^"B`@/'1D(&-L87-S/2)H96%D97(B(&%L
M:6=N/2)C96YT97(B/CP_<&AP(&5C:&\@7R@B4F5A9"(I(#\^/"]T9#X*("`\
M=&0@8VQA<W,](FAE861E<B(@86QI9VX](F-E;G1E<B(^/#]P:'`@96-H;R!?
M*")%9&ET(BD@/SX\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R(B!A;&EG;CTB
M8V5N=&5R(CX\/W!H<"!E8VAO(%\H(D1E;&5T92(I(#\^/"]T9#X*("`\=&0@
M8VQA<W,](FAE861E<B!R:6=H=$%L:6=N(CX\+W1D/@H\+W1R/@H\/W!H<"`D
M8W!E<FT@/2`D<&5R;2T^9V5T0W)E871O<E!E<FUI<W-I;VYS*"D[(#\^"CQT
M<CX*("`\=&0@8VQA<W,](FQI9VAT(CXF;F)S<#L\+W1D/@H@(#QT9"!A;&EG
M;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](F-R96%T
M;W)?<VAO=R(\/W!H<"!E8VAO("@D8W!E<FT@)B!015)-4U]32$]7*2`_("<@
M8VAE8VME9#TB8VAE8VME9"(G(#H@)R<@/SX@+SX\+W1D/@H@(#QT9"!A;&EG
M;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](F-R96%T
M;W)?<F5A9"(\/W!H<"!E8VAO("@D8W!E<FT@)B!015)-4U]214%$*2`_("<@
M8VAE8VME9#TB8VAE8VME9"(G(#H@)R<@/SX@+SX\+W1D/@H@(#QT9"!A;&EG
M;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](F-R96%T
M;W)?961I="(\/W!H<"!E8VAO("@D8W!E<FT@)B!015)-4U]%1$E4*2`_("<@
M8VAE8VME9#TB8VAE8VME9"(G(#H@)R<@/SX@+SX\+W1D/@H@(#QT9"!A;&EG
M;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](F-R96%T
M;W)?9&5L971E(CP_<&AP(&5C:&\@*"1C<&5R;2`F(%!%4DU37T1%3$5412D@
M/R`G(&-H96-K960](F-H96-K960B)R`Z("<G(#\^("\^/"]T9#X*/"]T<CX*
M"CPA+2T@4W!A8V5R("TM/@H\='(^/'1D/B9N8G-P.SPO=&0^/"]T<CX*"CPA
M+2T@57-E<B!097)M:7-S:6]N<R`M+3X*/'1R('9A;&EG;CTB;6ED9&QE(CX*
M("`\=&0@8VQA<W,](FAE861E<B!L969T06QI9VXB/@H@("`@/#]P:'`@96-H
M;R!(;W)D93HZ:6UG*"=U<V5R+G!N9R<L("<G+"`G)RP@)')E9VES=')Y+3YG
M971);6%G941I<B@G:&]R9&4G*2D@+B`G)FYB<W`[)R`N(%\H(DEN9&EV:61U
M86P@57-E<G,B*2`_/@H@(#PO=&0^"B`@/'1D(&-L87-S/2)H96%D97(B(&%L
M:6=N/2)C96YT97(B/CP_<&AP(&5C:&\@7R@B4VAO=R(I(#\^/"]T9#X*("`\
M=&0@8VQA<W,](FAE861E<B(@86QI9VX](F-E;G1E<B(^/#]P:'`@96-H;R!?
M*")296%D(BD@/SX\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R(B!A;&EG;CTB
M8V5N=&5R(CX\/W!H<"!E8VAO(%\H(D5D:70B*2`_/CPO=&0^"B`@/'1D(&-L
M87-S/2)H96%D97(B(&%L:6=N/2)C96YT97(B/CP_<&AP(&5C:&\@7R@B1&5L
M971E(BD@/SX\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R(')I9VAT06QI9VXB
M/CPO=&0^"CPO='(^"CP_<&AP(&9O<F5A8V@@*"1U<V5R<&5R;7,@87,@)'5S
M97(@/3X@)'5P97)M*2![(&EF("@D=7-E<B`A/2`D;W=N97(I('L@/SX*/'1R
M/@H@(#QT9"!C;&%S<STB;&EG:'0B/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC
M:&%R<RA!=71H.CIR96UO=F5(;V]K*"1U<V5R*2D@/SX\:6YP=70@='EP93TB
M:&ED9&5N(B!N86UE/2)U7VYA;65S6SP_<&AP(&5C:&\@:'1M;'-P96-I86QC
M:&%R<R@D=7-E<BD@/SY=(B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA
M;&-H87)S*"1U<V5R*2`_/B(@+SX\+W1D/@H@(#QT9"!A;&EG;CTB8V5N=&5R
M(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](G5?<VAO=UL\/W!H<"!E
M8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'5S97(I(#\^72(\/W!H<"!E8VAO("@D
M=7!E<FT@)B!015)-4U]32$]7*2`_("<@8VAE8VME9#TB8VAE8VME9"(G(#H@
M)R<@/SX@+SX\+W1D/@H@(#QT9"!A;&EG;CTB8V5N=&5R(CX\:6YP=70@='EP
M93TB8VAE8VMB;W@B(&YA;64](G5?<F5A9%L\/W!H<"!E8VAO(&AT;6QS<&5C
M:6%L8VAA<G,H)'5S97(I(#\^72(\/W!H<"!E8VAO("@D=7!E<FT@)B!015)-
M4U]214%$*2`_("<@8VAE8VME9#TB8VAE8VME9"(G(#H@)R<@/SX@+SX\+W1D
M/@H@(#QT9"!A;&EG;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B
M(&YA;64](G5?961I=%L\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'5S
M97(I(#\^72(\/W!H<"!E8VAO("@D=7!E<FT@)B!015)-4U]%1$E4*2`_("<@
M8VAE8VME9#TB8VAE8VME9"(G(#H@)R<@/SX@+SX\+W1D/@H@(#QT9"!A;&EG
M;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](G5?9&5L
M971E6SP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D=7-E<BD@/SY=(CP_
M<&AP(&5C:&\@*"1U<&5R;2`F(%!%4DU37T1%3$5412D@/R`G(&-H96-K960]
M(F-H96-K960B)R`Z("<G(#\^("\^/"]T9#X*/"]T<CX*/#]P:'`@?2!](#\^
M"CPA+2T@3F5W('5S97(@<F]W("TM/@H\='(^"CP_<&AP(&EF("@D875T:"T^
M:&%S0V%P86)I;&ET>2@G;&ES="<I*3H@/SX*("`\=&0@8VQA<W,](FQI9VAT
M(CX*("`@(#QS96QE8W0@;F%M93TB=5]N86UE<UM\?&YE=UTB/@H@("`@("`\
M;W!T:6]N('9A;'5E/2(B/CP_<&AP(&5C:&\@7R@B4V5L96-T(&$@=7-E<B!T
M;R!A9&0B*2`N("<Z)R`_/CPO;W!T:6]N/@H@("`@/#]P:'`@9F]R96%C:"`H
M)'5S97),:7-T(&%S("1U<V5R*2![(&EF("@A:7-S970H)'5S97)P97)M<ULD
M=7-E<ETI*2![(#\^"B`@("`@(#QO<'1I;VX@=F%L=64](CP_<&AP(&5C:&\@
M:'1M;'-P96-I86QC:&%R<R@D=7-E<BD@/SXB/CP_<&AP(&5C:&\@:'1M;'-P
M96-I86QC:&%R<RA!=71H.CIR96UO=F5(;V]K*"1U<V5R*2D@/SX\+V]P=&EO
M;CX*("`@(#P_<&AP('T@?2`_/@H@("`@/"]S96QE8W0^"B`@/"]T9#X*/#]P
M:'`@96QS93H@/SX*("`\=&0@8VQA<W,](FQI9VAT(CX\:6YP=70@='EP93TB
M=&5X="(@;F%M93TB=5]N86UE<UM\?&YE=UTB("\^/"]T9#X*/#]P:'`@96YD
M:68[(#\^"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)C:&5C
M:V)O>"(@;F%M93TB=5]S:&]W6WQ\;F5W72(@+SX\+W1D/@H@(#QT9"!A;&EG
M;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](G5?<F5A
M9%M\?&YE=UTB("\^/"]T9#X*("`\=&0@86QI9VX](F-E;G1E<B(^/&EN<'5T
M('1Y<&4](F-H96-K8F]X(B!N86UE/2)U7V5D:71;?'QN97==(B`O/CPO=&0^
M"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)C:&5C:V)O>"(@
M;F%M93TB=5]D96QE=&5;?'QN97==(B`O/CPO=&0^"CPO='(^"@H\(2TM(%-P
M86-E<B`M+3X*/'1R/CQT9#XF;F)S<#L\+W1D/CPO='(^"@H\(2TM($=R;W5P
M(%!E<FUI<W-I;VYS("TM/@H\='(@=F%L:6=N/2)M:61D;&4B/@H@(#QT9"!C
M;&%S<STB:&5A9&5R(&QE9G1!;&EG;B(^"B`@("`\/W!H<"!E8VAO($AO<F1E
M.CII;6<H)V=R;W5P+G!N9R<L("<G+"`G)RP@)')E9VES=')Y+3YG971);6%G
M941I<B@G:&]R9&4G*2D@+B`G)FYB<W`[)R`N(%\H(D=R;W5P<R(I(#\^"B`@
M/"]T9#X*("`\=&0@8VQA<W,](FAE861E<B(@86QI9VX](F-E;G1E<B(^/#]P
M:'`@96-H;R!?*")3:&]W(BD@/SX\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R
M(B!A;&EG;CTB8V5N=&5R(CX\/W!H<"!E8VAO(%\H(E)E860B*2`_/CPO=&0^
M"B`@/'1D(&-L87-S/2)H96%D97(B(&%L:6=N/2)C96YT97(B/CP_<&AP(&5C
M:&\@7R@B161I="(I(#\^/"]T9#X*("`\=&0@8VQA<W,](FAE861E<B(@86QI
M9VX](F-E;G1E<B(^/#]P:'`@96-H;R!?*")$96QE=&4B*2`_/CPO=&0^"B`@
M/'1D(&-L87-S/2)H96%D97(@<FEG:'1!;&EG;B(^)FYB<W`[/"]T9#X*/"]T
M<CX*/#]P:'`@)&=R;W5P<&5R;7,@/2`D<&5R;2T^9V5T1W)O=7!097)M:7-S
M:6]N<R@I.R!F;W)E86-H("@D9W)O=7!P97)M<R!A<R`D9W)O=7`@/3X@)&=P
M97)M*3H@:68@*"$D9W)O=7!S+3YE>&ES=',H)&=R;W5P<RT^9V5T1W)O=7!.
M86UE*"1G<F]U<"DI*2!C;VYT:6YU93L@/SX*/'1R/@H@(#QT9"!C;&%S<STB
M;&EG:'0B/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D9W)O=7!S+3YG
M971'<F]U<$YA;64H)&=R;W5P*2D@/SX\:6YP=70@='EP93TB:&ED9&5N(B!N
M86UE/2)G7VYA;65S6SP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D9W)O
M=7`I(#\^72(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D
M9W)O=7`I(#\^(B`O/CPO=&0^"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U
M="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB9U]S:&]W6SP_<&AP(&5C:&\@:'1M
M;'-P96-I86QC:&%R<R@D9W)O=7`I(#\^72(\/W!H<"!E8VAO("@D9W!E<FT@
M)B!015)-4U]32$]7*2`_("<@8VAE8VME9#TB8VAE8VME9"(G(#H@)R<@/SX@
M+SX\+W1D/@H@(#QT9"!A;&EG;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE
M8VMB;W@B(&YA;64](F=?<F5A9%L\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA
M<G,H)&=R;W5P*2`_/ETB/#]P:'`@96-H;R`H)&=P97)M("8@4$5235-?4D5!
M1"D@/R`G(&-H96-K960](F-H96-K960B)R`Z("<G(#\^("\^/"]T9#X*("`\
M=&0@86QI9VX](F-E;G1E<B(^/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE
M/2)G7V5D:71;/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1G<F]U<"D@
M/SY=(CP_<&AP(&5C:&\@*"1G<&5R;2`F(%!%4DU37T5$250I(#\@)R!C:&5C
M:V5D/2)C:&5C:V5D(B<@.B`G)R`_/B`O/CPO=&0^"B`@/'1D(&%L:6=N/2)C
M96YT97(B/CQI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB9U]D96QE=&5;
M/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1G<F]U<"D@/SY=(CP_<&AP
M(&5C:&\@*"1G<&5R;2`F(%!%4DU37T1%3$5412D@/R`G(&-H96-K960](F-H
M96-K960B)R`Z("<G(#\^("\^/"]T9#X*/"]T<CX*/#]P:'`@96YD9F]R96%C
M:#L@/SX*/"$M+2!.97<@9W)O=7`@<F]W("TM/@H\='(^"B`@/'1D(&-L87-S
M/2)L:6=H="(^"B`@("`\<V5L96-T(&YA;64](F=?;F%M97-;?'QN97==(CX*
M("`@("`@/&]P=&EO;B!V86QU93TB(CX\/W!H<"!E8VAO(%\H(E-E;&5C="!A
M(&=R;W5P('1O(&%D9"(I("X@)SHG(#\^/"]O<'1I;VX^"B`@("`\/W!H<"!F
M;W)E86-H("@D9W)O=7!,:7-T(&%S("1G:60@/3X@)&=R;W5P*2![(&EF("AE
M;7!T>2@D9W)O=7!P97)M<ULD9VED72DI('L@/SX*("`@("`@/&]P=&EO;B!V
M86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1G:60I(#\^(CX\
M/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&=R;W5P*2`_/CPO;W!T:6]N
M/@H@("`@/#]P:'`@?2!](#\^"B`@("`\+W-E;&5C=#X*("`\+W1D/@H@(#QT
M9"!A;&EG;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64]
M(F=?<VAO=UM\?&YE=UTB("\^/"]T9#X*("`\=&0@86QI9VX](F-E;G1E<B(^
M/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE/2)G7W)E861;?'QN97==(B`O
M/CPO=&0^"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)C:&5C
M:V)O>"(@;F%M93TB9U]E9&ET6WQ\;F5W72(@+SX\+W1D/@H@(#QT9"!A;&EG
M;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](F=?9&5L
M971E6WQ\;F5W72(@+SX\+W1D/@H\+W1R/@H*/'1R/@H@/'1D/B9N8G-P.SPO
M=&0^"CPO='(^"@H\='(^"B`\=&0@8V]L<W!A;CTB-R(^"B`@/&EN<'5T('1Y
M<&4](G-U8FUI="(@8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP('!R:6YT
M9BA?*")3879E("5S(BDL(&AT;6QS<&5C:6%L8VAA<G,H)'-H87)E+3YG970H
M)VYA;64G*2DI(#\^(B`O/@H\/W!H<"!I9B`H0&-O=6YT*"1C:&EL9')E;BDI
M.B`_/@H@(#QI;G!U="!T>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB(&]N
M8VQI8VL](F1O8W5M96YT+F5D:70N86-T:6]N240N=F%L=64@/2`G961I=&9O
M<FUI;FAE<FET)SLB('9A;'5E/2(\/W!H<"!E8VAO(%\H(D%P<&QY('1O($-H
M:6QD(%-H87)E<R(I(#\^(B`O/@H\/W!H<"!E;F1I9CL@/SX*(#PO=&0^"CPO
M='(^"@H\+W1A8FQE/@H\+V9O<FT^"CQB<B`O/@H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M
M<&QA=&5S+W!R969S````````````````````````````````````````````
M`````````````````````````````````````#`P,#<U-2``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S0U(#`R,#8P,``@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T96UP;&%T97,O<')E9G,O;75L=&EE;G5M+FEN8P``
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$P-#<@,3`U,34T,S,W
M-#4@,#(S,S<S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"1P<F5F+"`D7W!R969S
M6R1P<F5F75LG9&5S8R==*2`_/B9N8G-P.SP_<&AP(&5C:&\@)&AE;'!L:6YK
M(#\^/&)R("\^"CQS96QE8W0@:60](CP_<&AP(&5C:&\@)'!R968@/SXB(&UU
M;'1I<&QE/2)M=6QT:7!L92(@<VEZ93TB/#]P:'`@96-H;R!M:6XH-"P@8V]U
M;G0H)%]P<F5F<ULD<')E9EU;)V5N=6TG72DI(#\^(B!N86UE/2(\/W!H<"!E
M8VAO("1P<F5F(#\^6UTB/@H\/W!H<"`D<V5L96-T960@/2!`=6YS97)I86QI
M>F4H)'!R969S+3YG971686QU92@D<')E9BDI.R!F;W)E86-H("@D7W!R969S
M6R1P<F5F75LG96YU;2==(&%S("1K97D@/3X@)'9A;"DZ(#\^"CQO<'1I;VX\
M/W!H<"!E8VAO(&EN7V%R<F%Y*"1K97DL("1S96QE8W1E9"D@/R`G('-E;&5C
M=&5D/2)S96QE8W1E9"(@)R`Z("<G(#\^('9A;'5E/2(\/W!H<"!E8VAO(&AT
M;6QS<&5C:6%L8VAA<G,H)&ME>2D@/SXB/CP_<&AP(&5C:&\@:'1M;'-P96-I
M86QC:&%R<R@D=F%L*2`_/CPO;W!T:6]N/@H\/W!H<"!E;F1F;W)E86-H(#\^
M"CPO<V5L96-T/@H\8G(@+SX*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8P``````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3$V,3,@,3`U
M,34T,S,W-#4@,#(U,C(V`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#QS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*
M/"$M+0IF=6YC=&EO;B!R96UO=F4H8V%T96=O<GDI"GL*("`@(&1O8W5M96YT
M+G!R969S+F-!8W1I;VXN=F%L=64@/2`G<F5M;W9E)SL*("`@(&1O8W5M96YT
M+G!R969S+F-A=&5G;W)Y+G9A;'5E(#T@8V%T96=O<GD["B`@("!D;V-U;65N
M="YP<F5F<RYS=6)M:70H*3L*?0H*9G5N8W1I;VX@861D*"D*>PH@("`@=F%R
M(&-A=&5G;W)Y(#T@=VEN9&]W+G!R;VUP="@G/#]P:'`@96-H;R!A9&1S;&%S
M:&5S*%\H(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O
M<GDZ(BDI(#\^)RP@)R<I.PH@("`@:68@*&-A=&5G;W)Y("$](&YU;&P@)B8@
M8V%T96=O<GD@(3T@)R<I('L*("`@("`@("!D;V-U;65N="YP<F5F<RYC06-T
M:6]N+G9A;'5E(#T@)V%D9"<["B`@("`@("`@9&]C=6UE;G0N<')E9G,N8V%T
M96=O<GDN=F%L=64@/2!C871E9V]R>3L*("`@("`@("!D;V-U;65N="YP<F5F
M<RYS=6)M:70H*3L*("`@('T*?0HO+RTM/@H\+W-C<FEP=#X*/&EN<'5T(&YA
M;64](F-!8W1I;VXB('9A;'5E/2(B('1Y<&4](FAI9&1E;B(@+SX*/&EN<'5T
M(&YA;64](F-A=&5G;W)Y(B!V86QU93TB(B!T>7!E/2)H:61D96XB("\^"CQT
M86)L93X*(#QT<CX*("`\=&0@8V]L<W!A;CTB,B(^"B`@(#QI;G!U="!T>7!E
M/2)B=71T;VXB(&-L87-S/2)B=71T;VXB('9A;'5E/2(\/W!H<"!E8VAO(%\H
M(DYE=R!#871E9V]R>2(I(#\^(B!O;F-L:6-K/2)A9&0H*3LB("\^"B`@/"]T
M9#X*(#PO='(^"CP_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+U!R969S+T-A
M=&5G;W)Y36%N86=E<BYP:'`G.PHD8TUA;F%G97(@/2`F;F5W(%!R969S7T-A
M=&5G;W)Y36%N86=E<B@I.PHD8V%T96=O<FEE<R`]("1C36%N86=E<BT^9V5T
M*"D["B1C;VQO<G,@/2`D8TUA;F%G97(M/F-O;&]R<R@I.PHD9F=C;VQO<G,@
M/2`D8TUA;F%G97(M/F9G0V]L;W)S*"D["B1U<FP@/2!(;W)D93HZ=7)L*"1R
M96=I<W1R>2T^9V5T*"=W96)R;V]T)RP@)VAO<F1E)RD@+B`G+W-E<G9I8V5S
M+VEM86=E<R]C;VQO<G!I8VME<BYP:'`G*3L*)'5R;"`](%5T:6PZ.F%D9%!A
M<F%M971E<B@D=7)L+"`G9F]R;2<L("=P<F5F<R<I.PH*+R\@1&5F875L="!#
M;VQO<@HD8V]L;W(@/2!I<W-E="@D8V]L;W)S6R=?9&5F875L=%\G72D@/R`D
M8V]L;W)S6R=?9&5F875L=%\G72`Z("<C1D9&1D9&)SL*)&9G8V]L;W(@/2!I
M<W-E="@D9F=C;VQO<G-;)U]D969A=6QT7R==*2`_("1F9V-O;&]R<ULG7V1E
M9F%U;'1?)UT@.B`G(S`P,#`P,"<["B1C7W5R;"`](%5T:6PZ.F%D9%!A<F%M
M971E<B@D=7)L+"`G=&%R9V5T)RP@)V-O;&]R7R<@+B!B87-E-C1?96YC;V1E
M*"=?9&5F875L=%\G*2D["C\^"B`\='(^"B`@/'1D('-T>6QE/2)B86-K9W)O
M=6YD.CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D8V]L;W(I(#\^.R!C
M;VQO<CH\/W!H<"!E8VAO("1F9V-O;&]R(#\^(CX\<W1R;VYG/CP_<&AP(&5C
M:&\@7R@B1&5F875L="!#;VQO<B(I(#\^/"]S=')O;F<^/"]T9#X*("`\=&0^
M"B`@(#P_<&AP(&EF("@A)'!R969S+3YI<TQO8VME9"@G8V%T96=O<GE?8V]L
M;W)S)RDI.B`_/@H@("`@/&EN<'5T(&-L87-S/2)F:7AE9"(@<VEZ93TB-R(@
M<W1Y;&4](F)A8VMG<F]U;F0Z/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S
M*"1C;VQO<BD@/SX[(&-O;&]R.CP_<&AP(&5C:&\@)&9G8V]L;W(@/SXB(&YA
M;64](F-O;&]R7SP_<&AP(&5C:&\@8F%S938T7V5N8V]D92@G7V1E9F%U;'1?
M)RD@/SXB('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&-O
M;&]R*2`_/B(@+SX*("`@(#QA(&AR968](CP_<&AP(&5C:&\@)&-?=7)L(#\^
M(B!O;F-L:6-K/2)W:6YD;W<N;W!E;B@G/#]P:'`@96-H;R`D8U]U<FP@/SXG
M+"`G8V]L;W)P:6-K97(G+"`G=&]O;&)A<CUN;RQL;V-A=&EO;CUN;RQS=&%T
M=7,];F\L<V-R;VQL8F%R<SUN;RQR97-I>F%B;&4];F\L=VED=&@],3(P+&AE
M:6=H=#TR-3`L;&5F=#TQ,#`L=&]P/3$P,"<I.R!R971U<FX@9F%L<V4[(B!O
M;FUO=7-E;W5T/2)W:6YD;W<N<W1A='5S/2<G.R(@;VYM;W5S96]V97(](G=I
M;F1O=RYS=&%T=7,])SP_<&AP(&5C:&\@7R@B0V]L;W(@4&EC:V5R(BD@/SXG
M.R!R971U<FX@=')U93LB(&-L87-S/2)W:61G970B('1A<F=E=#TB8V]L;W)P
M:6-K97(B/@H@("`@/#]P:'`@96-H;R!(;W)D93HZ:6UG*"=C;VQO<G!I8VME
M<BYP;F<G+"!?*")#;VQO<B!0:6-K97(B*2P@)VAE:6=H=#TB,38B)RP@)')E
M9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G*2D@/SX\+V$^"B`@(#P_<&AP
M(&5N9&EF.R`_/@H@(#PO=&0^"B`\+W1R/@H\/W!H<`HO+R!5;F9I;&5D($-O
M;&]R"B1C;VQO<B`](&ES<V5T*"1C;VQO<G-;)U]U;F9I;&5D7R==*2`_("1C
M;VQO<G-;)U]U;F9I;&5D7R==(#H@)R-&1D9&1D8G.PHD9F=C;VQO<B`](&ES
M<V5T*"1F9V-O;&]R<ULG7W5N9FEL961?)UTI(#\@)&9G8V]L;W)S6R=?=6YF
M:6QE9%\G72`Z("<C,#`P,#`P)SL*)&-?=7)L(#T@571I;#HZ861D4&%R86UE
M=&5R*"1U<FPL("=T87)G970G+"`G8V]L;W)?)R`N(&)A<V4V-%]E;F-O9&4H
M)U]U;F9I;&5D7R<I*3L*/SX*(#QT<CX*("`\=&0@<W1Y;&4](F)A8VMG<F]U
M;F0Z/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1C;VQO<BD@/SX[(&-O
M;&]R.CP_<&AP(&5C:&\@)&9G8V]L;W(@/SXB/CQS=')O;F<^/#]P:'`@96-H
M;R!?*")5;F9I;&5D(BD@/SX\+W-T<F]N9SX\+W1D/@H@(#QT9#X*("`@/#]P
M:'`@:68@*"$D<')E9G,M/FES3&]C:V5D*"=C871E9V]R>5]C;VQO<G,G*2DZ
M(#\^"B`@("`\:6YP=70@8VQA<W,](F9I>&5D(B!S:7IE/2(W(B!S='EL93TB
M8F%C:V=R;W5N9#H\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&-O;&]R
M*2`_/CL@8V]L;W(Z/#]P:'`@96-H;R`D9F=C;VQO<B`_/B(@;F%M93TB8V]L
M;W)?/#]P:'`@96-H;R!B87-E-C1?96YC;V1E*"=?=6YF:6QE9%\G*2`_/B(@
M=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D8V]L;W(I(#\^
M(B`O/@H@("`@/&$@:')E9CTB/#]P:'`@96-H;R`D8U]U<FP@/SXB(&]N8VQI
M8VL](G=I;F1O=RYO<&5N*"<\/W!H<"!E8VAO("1C7W5R;"`_/B<L("=C;VQO
M<G!I8VME<B<L("=T;V]L8F%R/6YO+&QO8V%T:6]N/6YO+'-T871U<SUN;RQS
M8W)O;&QB87)S/6YO+')E<VEZ86)L93UN;RQW:61T:#TQ,C`L:&5I9VAT/3(U
M,"QL969T/3$P,"QT;W`],3`P)RD[(')E='5R;B!F86QS93LB(&]N;6]U<V5O
M=70](G=I;F1O=RYS=&%T=7,])R<[(B!O;FUO=7-E;W9E<CTB=VEN9&]W+G-T
M871U<STG/#]P:'`@96-H;R!?*")#;VQO<B!0:6-K97(B*2`_/B<[(')E='5R
M;B!T<G5E.R(@8VQA<W,](G=I9&=E="(@=&%R9V5T/2)C;VQO<G!I8VME<B(^
M"B`@("`\/W!H<"!E8VAO($AO<F1E.CII;6<H)V-O;&]R<&EC:V5R+G!N9R<L
M(%\H(D-O;&]R(%!I8VME<B(I+"`G:&5I9VAT/2(Q-B(G+"`D<F5G:7-T<GDM
M/F=E=$EM86=E1&ER*"=H;W)D92<I*2`_/CPO83X*("`@/#]P:'`@96YD:68[
M(#\^"B`@/"]T9#X*(#PO='(^"CP_<&AP"F9O<F5A8V@@*"1C871E9V]R:65S
M(&%S("1N86UE*3H*("`@("1C;VQO<B`](&ES<V5T*"1C;VQO<G-;)&YA;65=
M*2`_("1C;VQO<G-;)&YA;65=(#H@)R-&1D9&1D8G.PH@("`@)&9G8V]L;W(@
M/2!I<W-E="@D9F=C;VQO<G-;)&YA;65=*2`_("1F9V-O;&]R<ULD;F%M95T@
M.B`G(S`P,#`P,"<["B`@("`D8U]U<FP@/2!5=&EL.CIA9&1087)A;65T97(H
M)'5R;"P@)W1A<F=E="<L("=C;VQO<E\G("X@8F%S938T7V5N8V]D92@D;F%M
M92DI.PH_/@H@/'1R/@H@(#QT9"!S='EL93TB8F%C:V=R;W5N9#H\/W!H<"!E
M8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&-O;&]R*2`_/CL@8V]L;W(Z/#]P:'`@
M96-H;R`D9F=C;VQO<B`_/B(^/'-T<F]N9SX\/W!H<"!E8VAO("@D;F%M92`]
M/2`G7V1E9F%U;'1?)R`_(%\H(D1E9F%U;'0@0V]L;W(B*2`Z(&AT;6QS<&5C
M:6%L8VAA<G,H)&YA;64I*2`_/CPO<W1R;VYG/CPO=&0^"B`@/'1D/@H@("`\
M/W!H<"!I9B`H(21P<F5F<RT^:7-,;V-K960H)V-A=&5G;W)Y7V-O;&]R<R<I
M*3H@/SX*("`@(#QI;G!U="!C;&%S<STB9FEX960B('-I>F4](C<B('-T>6QE
M/2)B86-K9W)O=6YD.CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D8V]L
M;W(I(#\^.R!C;VQO<CH\/W!H<"!E8VAO("1F9V-O;&]R(#\^(B!N86UE/2)C
M;VQO<E\\/W!H<"!E8VAO(&)A<V4V-%]E;F-O9&4H)&YA;64I(#\^(B!V86QU
M93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1C;VQO<BD@/SXB("\^
M"B`@("`\82!H<F5F/2(\/W!H<"!E8VAO("1C7W5R;"`_/B(@;VYC;&EC:STB
M=VEN9&]W+F]P96XH)SP_<&AP(&5C:&\@)&-?=7)L(#\^)RP@)V-O;&]R<&EC
M:V5R)RP@)W1O;VQB87(];F\L;&]C871I;VX];F\L<W1A='5S/6YO+'-C<F]L
M;&)A<G,];F\L<F5S:7IA8FQE/6YO+'=I9'1H/3$R,"QH96EG:'0],C4P+&QE
M9G0],3`P+'1O<#TQ,#`G*3L@<F5T=7)N(&9A;'-E.R(@;VYM;W5S96]U=#TB
M=VEN9&]W+G-T871U<STG)SLB(&]N;6]U<V5O=F5R/2)W:6YD;W<N<W1A='5S
M/2<\/W!H<"!E8VAO(%\H(D-O;&]R(%!I8VME<B(I(#\^)SL@<F5T=7)N('1R
M=64[(B!C;&%S<STB=VED9V5T(B!T87)G970](F-O;&]R<&EC:V5R(CX*("`@
M(#P_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G8V]L;W)P:6-K97(N<&YG)RP@7R@B
M0V]L;W(@4&EC:V5R(BDL("=H96EG:'0](C$V(B<L("1R96=I<W1R>2T^9V5T
M26UA9V5$:7(H)VAO<F1E)RDI(#\^/"]A/@H@("`@/#]P:'`@96YD:68[(#\^
M"B`@("`\82!H<F5F/2(C(B!O;F-L:6-K/2)R96UO=F4H9&5C;V1E55))0V]M
M<&]N96YT*"<\/W!H<"!E8VAO(')A=W5R;&5N8V]D92A3=')I;F<Z.F-O;G9E
M<G1#:&%R<V5T*"1N86UE+"!.3%,Z.F=E=$-H87)S970H*2P@)U541BTX)RDI
M(#\^)RDI.R!R971U<FX@9F%L<V4[(CX\/W!H<"!E8VAO($AO<F1E.CII;6<H
M)V1E;&5T92YP;F<G*2`_/CPO83X*("`\+W1D/@H@/"]T<CX*/#]P:'`@96YD
M9F]R96%C:#L@/SX*/"]T86)L93X*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+W!R969S+W!A
M<W-W;W)D+FEN8P``````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M-#,P(#$P-3$U-#,S-S0U(#`R,S(Q,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<"!E8VAO($AO<F1E.CIL86)E;"@D
M<')E9BP@)%]P<F5F<ULD<')E9EU;)V1E<V,G72D@/SXF;F)S<#L\/W!H<"!E
M8VAO("1H96QP;&EN:R`_/CQB<B`O/@H\:6YP=70@='EP93TB<&%S<W=O<F0B
M(&ED/2(\/W!H<"!E8VAO("1P<F5F(#\^(B!N86UE/2(\/W!H<"!E8VAO("1P
M<F5F(#\^(B!S:7IE/2(S,"(@;6%X;&5N9W1H/2(V,"(@8VQA<W,](F9I>&5D
M(B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1P<F5F<RT^
M9V5T5F%L=64H)'!R968I*2`_/B(@+SX\8G(@+SX*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]P<F5F<R]E;F0N:6YC````````
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#<S,2`Q,#4Q-30S
M,S<T-2`P,C(Q,C$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/"]D:78^"@H\8G(@8VQA<W,](G-P86-E<B(@+SX*/&1I=B!C
M;&%S<STB;F]W<F%P(CX*(#QI;G!U="!T>7!E/2)S=6)M:70B(&-L87-S/2)B
M=71T;VXB('9A;'5E/2(\/W!H<"!E8VAO(%\H(E-A=F4@3W!T:6]N<R(I(#\^
M(B`O/B9N8G-P.PH@/&EN<'5T('1Y<&4](G)E<V5T(B!C;&%S<STB8G5T=&]N
M(B!V86QU93TB/#]P:'`@96-H;R!?*")5;F1O($-H86YG97,B*2`_/B(@+SXF
M;F)S<#L*(#P_<&AP(&EF("AC;W5N="@D<')E9D=R;W5P<RD@/B`Q*3H@/SX\
M:6YP=70@='EP93TB8G5T=&]N(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/#]P
M:'`@96-H;R!?*")2971U<FX@=&\@3W!T:6]N<R(I(#\^(B!O;F-L:6-K/2)D
M;V-U;65N="YP<F5F<RYA8W1I;VY)1"YV86QU93TP.R!D;V-U;65N="YP<F5F
M<RYG<F]U<"YV86QU93TG)SL@9&]C=6UE;G0N<')E9G,N<W5B;6ET*"D[(B`O
M/CP_<&AP(&5N9&EF.R`_/@H\+V1I=CX*/"]F;W)M/@H`````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T96UP;&%T97,O<')E9G,O;W9E<G9I97<N:6YC````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$U,38@,3`U,34T,S,W-#4@,#(S,C(S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#QD
M:78@8VQA<W,](G!R969S3W9E<G9I97<B/@H\/W!H<"!F;W)E86-H("@D8V]L
M=6UN<R!A<R`D:V5Y(#T^("1C;VQU;6XI.B`_/@H@/&1I=B!S='EL93TB=VED
M=&@Z/#]P:'`@96-H;R`D<W!A;B`M(#$@/SXE(CX*("`\9&EV/@H@("`\:#(^
M/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1K97DI(#\^/"]H,CX*"B`@
M(#QD;#X*("`@/#]P:'`@9F]R96%C:"`H)&-O;'5M;B!A<R`D9W)O=7`@/3X@
M)&=V86QS*3H@/SX*("`@(#P_<&AP(&EF("A0<F5F<U]523HZ9W)O=7!)<T5D
M:71A8FQE*"1G<F]U<"DI.B`_/@H@("`@(#P_<&AP(&EF("@A96UP='DH)&=V
M86QS6R=U<FPG72DI.B`_/@H@("`@("`\9'0^/#]P:'`@96-H;R!(;W)D93HZ
M=VED9V5T*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@D9W9A;'-;)W5R;"==+"`D
M87!P*2P@)&=V86QS6R=L86)E;"==+"`G)RP@)R<L("<G+"`D9W9A;'-;)VQA
M8F5L)UTI(#\^/"]D=#X*("`@("`\/W!H<"!E;'-E.B`_/@H@("`@("`\9'0^
M/#]P:'`@96-H;R!(;W)D93HZ=VED9V5T*%5T:6PZ.F%D9%!A<F%M971E<BA(
M;W)D93HZ<V5L9E5R;"@I+"!A<G)A>2@G9W)O=7`G(#T^("1G<F]U<"P@)V%P
M<"<@/3X@)$=,3T)!3%-;)V%P<"==*2DL("1G=F%L<ULG;&%B96PG72P@)R<L
M("<G+"`G)RP@)&=V86QS6R=L86)E;"==*2`_/CPO9'0^"B`@("`@/#]P:'`@
M96YD:68[(#\^"B`@("`@/&1D/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R
M<R@D9W9A;'-;)V1E<V,G72D@/SX\+V1D/@H@("`@/#]P:'`@96YD:68[(#\^
M"B`@(#P_<&AP(&5N9&9O<F5A8V@[(#\^"B`@(#PO9&P^"B`@/"]D:78^"B`\
M+V1I=CX*/#]P:'`@96YD9F]R96%C:#L@/SX*/"]D:78^"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T96UP;&%T97,O<')E9G,O<V5L96-T+FEN8P``````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$R,#`@,3`U,34T,S,W-#4@
M,#(R-C(R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"1P<F5F+"`D7W!R969S6R1P
M<F5F75LG9&5S8R==*2`_/B9N8G-P.SP_<&AP(&5C:&\@)&AE;'!L:6YK(#\^
M/&)R("\^"CQS96QE8W0@:60](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R
M<R@D<')E9BD@/SXB(&YA;64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R
M<R@D<')E9BD@/SXB/@H\/W!H<"`D97-C(#T@(65M<'1Y*"1?<')E9G-;)'!R
M969=6R=E<V-A<&5D)UTI.R`D8W5R=F%L(#T@)'!R969S+3YG971686QU92@D
M<')E9BD[("1S96QE8W1?=F%R(#T@571I;#HZ;F]N26YP=71687(H)'!R968@
M+B`G7V]P=&EO;G,G*3L@9F]R96%C:"`H)'-E;&5C=%]V87(@87,@)'-E;&5C
M=%]K97D@/3X@)'-E;&5C=%]V86PI.B`_/@H@/&]P=&EO;B!V86QU93TB/#]P
M:'`@96-H;R`D97-C(#\@)'-E;&5C=%]K97D@.B!H=&UL<W!E8VEA;&-H87)S
M*"1S96QE8W1?:V5Y*2`_/B(\/W!H<"!I9B`H)'-E;&5C=%]K97D@/3T@)&-U
M<G9A;"D@96-H;R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#\^/CP_<&AP(&5C
M:&\@)&5S8R`_("1S96QE8W1?=F%L(#H@:'1M;'-P96-I86QC:&%R<R@D<V5L
M96-T7W9A;"D@/SX\+V]P=&EO;CX*/#]P:'`@96YD9F]R96%C:#L@/SX*/"]S
M96QE8W0^"CQB<B`O/@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O<')E9G,O=&5X="YI;F,`````
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`T,3`@,3`U,34T
M,S,W-#4@,#(R,S,Q`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"1P<F5F+"`D7W!R
M969S6R1P<F5F75LG9&5S8R==*2`_/B9N8G-P.SP_<&AP(&5C:&\@)&AE;'!L
M:6YK(#\^/&)R("\^"CQI;G!U="!I9#TB/#]P:'`@96-H;R`D<')E9B`_/B(@
M;F%M93TB/#]P:'`@96-H;R`D<')E9B`_/B(@<VEZ93TB,S`B(&UA>&QE;F=T
M:#TB-C`B(&-L87-S/2)F:7AE9"(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P
M96-I86QC:&%R<R@D<')E9G,M/F=E=%9A;'5E*"1P<F5F*2D@/SXB("\^/&)R
M("\^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&5M<&QA=&5S+W!R969S+VYU;6)E<BYI;F,`````````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,S<V(#$P-3$U-#,S-S0U(#`R,C8U
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M:6YP=70@='EP93TB=&5X="(@:60](CP_<&AP(&5C:&\@)'!R968@/SXB(&YA
M;64](CP_<&AP(&5C:&\@)'!R968@/SXB('-I>F4](C,B(&UA>&QE;F=T:#TB
M,R(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D<')E9G,M
M/F=E=%9A;'5E*"1P<F5F*2D@/SXB("\^"CP_<&AP(&5C:&\@2&]R9&4Z.FQA
M8F5L*"1P<F5F+"`D7W!R969S6R1P<F5F75LG9&5S8R==*2`_/B9N8G-P.SP_
M<&AP(&5C:&\@)&AE;'!L:6YK(#\^/&)R("\^"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L
M871E<R]P<F5F<R]D96QE=&5I9&5N=&ET>2YI;F,`````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,3$S,R`Q,#4Q-30S,S<T-2`P,C0S-C0`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`@:68@*"$D
M<')E9G,M/FES3&]C:V5D*"=D969A=6QT7VED96YT:71Y)RDI.B`_/@H\<V-R
M:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"CPA+2T*9G5N8W1I;VX@9&5L
M971E261E;G1I='DH*0I["B`@("!V87(@:6YD97@@/2!D;V-U;65N="YP<F5F
M<RYI9&5N=&ET>2YS96QE8W1E9$EN9&5X.PH@("`@=F%R(&ED(#T@9&]C=6UE
M;G0N<')E9G,N:61E;G1I='DN;W!T:6]N<UMI;F1E>%TN=F%L=64["B`@("!I
M9B`H:60@/CT@,"D@>PH@("`@("`@(&1O8W5M96YT+FQO8V%T:6]N+FAR968@
M/2`B/#]P:'`@96-H;R!S=')?<F5P;&%C92@G)F%M<#LG+"`G)B<L(%5T:6PZ
M.F%D9%!A<F%M971E<BA(;W)D93HZ<V5L9E5R;"AT<G5E*2P@87)R87DH)V%C
M=&EO;DE$)R`]/B`G9&5L971E7VED96YT:71Y)RP@)VED)R`]/B`G)RDI*2`_
M/B(@*R!I9#L*("`@('T*?0HO+RTM/@H\+W-C<FEP=#X*/&)R("\^"CQI;G!U
M="!T>7!E/2)B=71T;VXB(&]N8VQI8VL](F1E;&5T94ED96YT:71Y*"DB(&-L
M87-S/2)B=71T;VXB('9A;'5E/2(\/W!H<"!E8VAO(%\H(D1E;&5T92!S96QE
M8W1E9"!I9&5N=&ET>2(I(#\^(B`O/CQB<B`O/CQB<B`O/@H\/W!H<"!E;F1I
M9CL@/SX*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1E;7!L871E<R]P<F5F<R]T97AT87)E82YI;F,`````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#0U-"`Q,#4Q-30S,S<T-2`P,C,Q-S(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`@
M96-H;R!(;W)D93HZ;&%B96PH)'!R968L("1?<')E9G-;)'!R969=6R=D97-C
M)UTI(#\^)FYB<W`[/#]P:'`@96-H;R`D:&5L<&QI;FL@/SX\8G(@+SX*/&1I
M=B!C;&%S<STB9FEX960B/@H\=&5X=&%R96$@=W)A<#TB:&%R9"(@:60](CP_
M<&AP(&5C:&\@)'!R968@/SXB(&YA;64](CP_<&AP(&5C:&\@)'!R968@/SXB
M(')O=W,](C8B(&-O;',](C@P(B!C;&%S<STB9FEX960B/CP_<&AP(&5C:&\@
M:'1M;'-P96-I86QC:&%R<R@D<')E9G,M/F=E=%9A;'5E*"1P<F5F*2D@/SX\
M+W1E>'1A<F5A/CQB<B`O/@H\+V1I=CX*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O
M<')E9G,O8VAE8VMB;W@N:6YC````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`S-S8@,3`U,34T,S,W-#4@,#(S,30V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#QI;G!U="!T>7!E/2)C:&5C
M:V)O>"(@8VQA<W,](F-H96-K8F]X(B!I9#TB/#]P:'`@96-H;R`D<')E9B`_
M/B(@;F%M93TB/#]P:'`@96-H;R`D<')E9B`_/B(\/W!H<"!E8VAO("1P<F5F
M<RT^9V5T5F%L=64H)'!R968I(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@.B`G
M)R`_/B`O/@H\/W!H<"!E8VAO($AO<F1E.CIL86)E;"@D<')E9BP@)%]P<F5F
M<ULD<')E9EU;)V1E<V,G72D@/SXF;F)S<#L\/W!H<"!E8VAO("1H96QP;&EN
M:R`_/@H\8G(@+SX*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+W!R969S+V5N=6TN
M:6YC````````````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,#0U
M(#$P-3$U-#,S-S0U(#`R,C,Q-@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<"!E8VAO($AO<F1E.CIL86)E;"@D<')E
M9BP@)%]P<F5F<ULD<')E9EU;)V1E<V,G72D@/SXF;F)S<#L\/W!H<"!E8VAO
M("1H96QP;&EN:R`_/CQB<B`O/@H\<V5L96-T(&ED/2(\/W!H<"!E8VAO(&AT
M;6QS<&5C:6%L8VAA<G,H)'!R968I(#\^(B!N86UE/2(\/W!H<"!E8VAO(&AT
M;6QS<&5C:6%L8VAA<G,H)'!R968I(#\^(CX*/#]P:'`@)&5S8R`]("%E;7!T
M>2@D7W!R969S6R1P<F5F75LG97-C87!E9"==*3L@)&-U<G9A;"`]("1P<F5F
M<RT^9V5T5F%L=64H)'!R968I.R!F;W)E86-H("@D7W!R969S6R1P<F5F75LG
M96YU;2==(&%S("1K97D@/3X@)'9A;"DZ(#\^"CQO<'1I;VX\/W!H<"!E8VAO
M("1C=7)V86P@/3T@)&ME>2`_("<@<V5L96-T960](G-E;&5C=&5D(B<@.B`G
M)R`_/B!V86QU93TB/#]P:'`@96-H;R`D97-C(#\@)&ME>2`Z(&AT;6QS<&5C
M:6%L8VAA<G,H)&ME>2D@/SXB/CP_<&AP(&5C:&\@)&5S8R`_("1V86P@.B!H
M=&UL<W!E8VEA;&-H87)S*"1V86PI(#\^/"]O<'1I;VX^"CP_<&AP(&5N9&9O
M<F5A8V@@/SX*/"]S96QE8W0^"CQB<B`O/@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+W!R969S
M+V)E9VEN+FEN8P``````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P-S<W(#$P-3$U-#,S-S0U(#`R,C0U,0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\9F]R;2!M971H;V0](G!O<W0B(&YA
M;64](G!R969S(B!A8W1I;VX](CP_<&AP(&5C:&\@2&]R9&4Z.G-E;&95<FPH
M*2`_/B(^"CP_<&AP(%5T:6PZ.G!F;W)M26YP=70H*2`_/@H\:6YP=70@='EP
M93TB:&ED9&5N(B!N86UE/2)A8W1I;VY)1"(@=F%L=64](G5P9&%T95]P<F5F
M<R(@+SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB9W)O=7`B('9A;'5E
M/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&=R;W5P*2`_/B(@+SX*
M/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB87!P(B!V86QU93TB/#]P:'`@
M96-H;R!H=&UL<W!E8VEA;&-H87)S*"1A<'`I(#\^(B`O/@H*/&1I=B!C;&%S
M<STB:&5A9&5R(CX*(#P_<&AP(%!R969S7U5).CIG96YE<F%T94YA=FEG871I
M;VY#96QL*"1G<F]U<"D@/SX*(#P_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R
M<R@D<')E9D=R;W5P<ULD9W)O=7!=6R=L86)E;"==*2`_/@H@/&)R(&-L87-S
M/2)C;&5A<B(@+SX*/"]D:78^"@H\9&EV(&-L87-S/2)I=&5M(CX*`'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]P<F5F<R]A<'`N:6YC````
M````````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C$S-2`Q,#4Q
M-30S,S<T-2`P,C(Q,S,`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/&9O<FT@;65T:&]D/2)G970B(&YA;64](F%P<'-W:71C
M:"(@86-T:6]N/2(\/W!H<"!E8VAO("1R96=I<W1R>2T^9V5T*"=W96)R;V]T
M)RP@)VAO<F1E)RD@+B`G+W-E<G9I8V5S+W!R969S+G!H<"<@/SXB/@H\/W!H
M<"!E8VAO(%5T:6PZ.F9O<FU);G!U="@I(#\^"CQD:78@8VQA<W,](FAE861E
M<B(^"B`\<W!A;B!C;&%S<STB<VUA;&QH96%D97(@<FEG:'1&;&]A="(^"B`@
M/#]P:'`@96-H;R!?*")%9&ET(&]P=&EO;G,@9F]R.B(I(#\^"B`@/'-E;&5C
M="!N86UE/2)A<'`B(&]N8VAA;F=E/2)D;V-U;65N="YA<'!S=VET8V@N<W5B
M;6ET*"D[(CX*("`@(#QO<'1I;VX@=F%L=64](B(^/#]P:'`@96-H;R!?*")#
M:&]O<V4@07!P;&EC871I;VXZ(BD@/SX\+V]P=&EO;CX*/#]P:'`@:68@*"%E
M;7!T>2@D87!P<ULG:&]R9&4G72DI.B`_/@H@("`@/&]P=&EO;B!V86QU93TB
M(CXM+2TM/"]O<'1I;VX^"B`@("`\;W!T:6]N('9A;'5E/2)H;W)D92(^/#]P
M:'`@96-H;R!?*")';&]B86P@3W!T:6]N<R(I(#\^/"]O<'1I;VX^"B`@("`\
M;W!T:6]N('9A;'5E/2(B/BTM+2T\+V]P=&EO;CX*/#]P:'`@96YD:68[(#\^
M"B`@(#P_<&AP(&9O<F5A8V@@*"1A<'!S(&%S("1K97D@/3X@)'9A;"DZ(&EF
M("@D:V5Y(#T]("=H;W)D92<I(&-O;G1I;G5E.R`_/@H@("`@/&]P=&EO;B!V
M86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1K97DI(#\^(CX\
M/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'9A;"D@/SX\+V]P=&EO;CX*
M("`@/#]P:'`@96YD9F]R96%C:#L@/SX*("`\+W-E;&5C=#X*("`\:6YP=70@
M8VQA<W,](F)U='1O;B(@='EP93TB<W5B;6ET(B!O;F-L:6-K/2)R971U<FX@
M9&]C=6UE;G0N87!P<W=I=&-H+F%P<"YS96QE8W1E9$EN9&5X("$](#`[(B!V
M86QU93TB/#]P:'`@96-H;R!?*")';R(I(#\^(B`O/@H@/"]S<&%N/@H@/#]P
M:'`@:68@*"1R96=I<W1R>2T^9V5T07!P*"D@/3T@)VAO<F1E)RD@96-H;R!?
M*")';&]B86P@3W!T:6]N<R(I.R!E;'-E('!R:6YT9BA?*")/<'1I;VYS(&9O
M<B`E<R(I+"`D<F5G:7-T<GDM/F=E="@G;F%M92<I*2`_/@H@/&)R(&-L87-S
M/2)C;&5A<B(@+SX*/"]D:78^"CPO9F]R;3X*/&)R(&-L87-S/2)S<&%C97(B
M("\^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M
M<&QA=&5S+W!R969S+VQI;FLN:6YC````````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P-3(S(#$P-3$U-#,S-S0U(#`R,C,P-P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\82!H<F5F/2(\
M/W!H<"!E8VAO("AI<W-E="@D7W!R969S6R1P<F5F75LG=7)L)UTI*2`_"DAO
M<F1E.CIA<'!L:6-A=&EO;E5R;"@D7W!R969S6R1P<F5F75LG=7)L)UTI(#H@
M)%]P<F5F<ULD<')E9EU;)WAU<FPG70H_/B(^/#]P:'`@:68@*&ES<V5T*"1?
M<')E9G-;)'!R969=6R=I;6<G72DI(&5C:&\*2&]R9&4Z.FEM9R@D7W!R969S
M6R1P<F5F75LG:6UG)UTL("1?<')E9G-;)'!R969=6R=D97-C)UTL("=H<W!A
M8V4](C,B)RD*/SX\<W1R;VYG/CP_<&AP(&5C:&\@)%]P<F5F<ULD<')E9EU;
M)V1E<V,G72`_/CPO<W1R;VYG/CPO83XF;F)S<#L\/W!H<"!E8VAO"B1H96QP
M;&EN:R`_/CQB<B`O/@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]P<F5F
M<R]I9&5N=&ET>7-E;&5C="YI;F,`````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P-3<S,B`Q,#4Q-30S,S<T-2`P,C0T,3(`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`@:68@*"1P<F5F<RT^:7-,
M;V-K960H)V1E9F%U;'1?:61E;G1I='DG*2DZ(#\^"CQI;G!U="!T>7!E/2)H
M:61D96XB(&YA;64](FED96YT:71Y(B!V86QU93TB/#]P:'`@96-H;R`H:6YT
M*21'3$]"04Q36R=I9&5N=&ET>2==+3YG971$969A=6QT*"D@/SXB("\^"CP_
M<&AP(&5L<V4Z(#\^"CQS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*
M/"$M+0H*=F%R(&ED96YT:71I97,@/2!N97<@07)R87DH*3L*/#]P:'`*9VQO
M8F%L("1I9&5N=&ET>3L*)&ED96YT:71I97,@/2`D:61E;G1I='DM/F=E=$%L
M;"@G:60G*3L*)&1E9F%U;'1?:61E;G1I='D@/2`D:61E;G1I='DM/F=E=$1E
M9F%U;'0H*3L*)&UE;6)E<G,@/2`D<')E9D=R;W5P<ULG:61E;G1I=&EE<R==
M6R=M96UB97)S)UT["F9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1I9&5N=&ET
M:65S*3L@*RLD:2DZ"C\^"FED96YT:71I97-;/#]P:'`@96-H;R`D:2`_/ET@
M/2!N97<@07)R87DH*3L*/#]P:'`*)&L@/2`P.PIF;W)E86-H("@D;65M8F5R
M<R!A<R`D;65M8F5R*3H*("`@(&EF("@D;65M8F5R(#T]("=D969A=6QT7VED
M96YT:71Y)R!\?`H@("`@("`@("%E;7!T>2@D7W!R969S6R1M96UB97)=6R=L
M;V-K960G72D@?'P*("`@("`@("`D7W!R969S6R1M96UB97)=6R=T>7!E)UT@
M/3T@)W-P96-I86PG('Q\"B`@("`@("`@)%]P<F5F<ULD;65M8F5R75LG='EP
M92==(#T]("=L:6YK)RD@>PH@("`@("`@(&-O;G1I;G5E.PH@("`@?0H_/@II
M9&5N=&ET:65S6SP_<&AP(&5C:&\@)&D@/SY=6SP_<&AP(&5C:&\@)&LK*R`_
M/ET@/2!N97<@07)R87DH(CP_<&AP(&5C:&\@)&UE;6)E<B`_/B(L("(\/W!H
M<"!E8VAO("1?<')E9G-;)&UE;6)E<EU;)W1Y<&4G72`_/B(L(#P_<&AP"B1V
M86P@/2`D:61E;G1I='DM/F=E=%9A;'5E*"1M96UB97(L("1I*3L*<W=I=&-H
M("@D7W!R969S6R1M96UB97)=6R=T>7!E)UTI('L*8V%S92`G8VAE8VMB;W@G
M.@H@("`@96-H;R`D=F%L(#\@)W1R=64G(#H@)V9A;'-E)SL*("`@(&)R96%K
M.PH*8V%S92`G;G5M8F5R)SH*("`@(&5C:&\@*&EN="DD=F%L.PH@("`@8G)E
M86L["@IC87-E("=T97AT87)E82<Z"B`@("!I9B`H:7-?87)R87DH)'9A;"DI
M('L*("`@("`@("`D=F%L(#T@:6UP;&]D92@B7&XB+"`D=F%L*3L*("`@('T*
M("`@("1V86P@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1V86PL($Y,4SHZ
M9V5T0VAA<G-E="@I+"`G551&+3@G*3L*("`@(&5C:&\@)V1E8V]D955224-O
M;7!O;F5N="@B)R`N(')A=W5R;&5N8V]D92@D=F%L*2`N("<B*2<["B`@("!B
M<F5A:SL*"F1E9F%U;'0Z"B`@("`D=F%L(#T@4W1R:6YG.CIC;VYV97)T0VAA
M<G-E="@D=F%L+"!.3%,Z.F=E=$-H87)S970H*2P@)U541BTX)RD["B`@("!E
M8VAO("=D96-O9&554DE#;VUP;VYE;G0H(B<@+B!R87=U<FQE;F-O9&4H)'9A
M;"D@+B`G(BDG.PI]"C\^*3L*/#]P:'`@96YD9F]R96%C:#L@96YD9F]R.R`_
M/@H*9G5N8W1I;VX@;F5W0VAO:6-E*"D*>PH@("`@=F%R(&9I96QD+"!V86P[
M"B`@("!V87(@:6YD97@@/2!D;V-U;65N="YP<F5F<RYI9&5N=&ET>2YS96QE
M8W1E9$EN9&5X.PH@("`@=F%R(&ED(#T@9&]C=6UE;G0N<')E9G,N:61E;G1I
M='DN;W!T:6]N<UMI;F1E>%TN=F%L=64["B`@("!I9B`H:60@/"`P*2!["B`@
M("`@("`@9&]C=6UE;G0N<')E9G,N<F5S970H*3L*("`@("`@("!D;V-U;65N
M="YP<F5F<RYI9&5N=&ET>2YS96QE8W1E9$EN9&5X(#T@:6YD97@["B`@("`@
M("`@<F5T=7)N.PH@("`@?0H@("`@9F]R("AV87(@:2`](#`[(&D@/"!I9&5N
M=&ET:65S6VED72YL96YG=&@[(&DK*RD@>PH@("`@("`@(&9I96QD(#T@9&]C
M=6UE;G0N<')E9G-;:61E;G1I=&EE<UMI9%U;:5U;,%U=.PH@("`@("`@('9A
M;"`](&ED96YT:71I97-;:61=6VE=6S)=.PH@("`@("`@('-W:71C:"`H:61E
M;G1I=&EE<UMI9%U;:5U;,5TI('L*("`@("`@("!C87-E(")E;G5M(CH*("`@
M("`@("`@("`@9F]R("AV87(@:B`](#`[(&H@/"!F:65L9"YO<'1I;VYS+FQE
M;F=T:#L@:BLK*2!["B`@("`@("`@("`@("`@("!I9B`H9FEE;&0N;W!T:6]N
M<UMJ72YV86QU92`]/2!V86PI('L*("`@("`@("`@("`@("`@("`@("!F:65L
M9"YS96QE8W1E9$EN9&5X(#T@:CL*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@8V%S92`B8VAE8VMB;W@B.@H@("`@("`@("`@
M("!F:65L9"YC:&5C:V5D(#T@=F%L.PH@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@8V%S92`B:6UP;&EC:70B.@H@("`@("`@("`@("!E=F%L*")N97=#
M:&]I8V5?(B`K(&ED96YT:71I97-;:61=6VE=6S!=("L@(BAV86PI(BD["B`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@
M("!F:65L9"YV86QU92`]('9A;#L*("`@("`@("!]"B`@("!]"GT*"B\O+2T^
M"CPO<V-R:7!T/@H\8G(@+SX*/#]P:'`@96-H;R!(;W)D93HZ;&%B96PH)VED
M96YT:71Y)RP@7R@B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C
M:&%N9V4Z(BDI(#\^/&)R("\^"CQS96QE8W0@;F%M93TB:61E;G1I='DB(&ED
M/2)I9&5N=&ET>2(@;VYC:&%N9V4](FIA=F%S8W)I<'0Z;F5W0VAO:6-E*"DB
M/@H@(#QO<'1I;VX@=F%L=64](BTR(B!S96QE8W1E9#TB<V5L96-T960B"CX\
M/W!H<"!E8VAO(%\H(DYO;F4B*2`_/CPO;W!T:6]N/@H@(#QO<'1I;VX@=F%L
M=64](BTQ(CX\/W!H<"!E8VAO(%\H(D-R96%T92!A(&YE=R!O;F4B*2`_/CPO
M;W!T:6]N/@H\/W!H<"!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D:61E;G1I
M=&EE<RD[("1I*RLI.B`_/@H@(#QO<'1I;VX@=F%L=64](CP_<&AP(&5C:&\@
M)&D@/SXB/#]P:'`@:68@*"1I(#T]("1D969A=6QT7VED96YT:71Y*2!E8VAO
M("<@<V5L96-T960](G-E;&5C=&5D(B<@/SX^/#]P:'`@96-H;R!H=&UL<W!E
M8VEA;&-H87)S*"1I9&5N=&ET:65S6R1I72D@/SX\+V]P=&EO;CX*/#]P:'`@
M96YD9F]R.R`_/@H\+W-E;&5C=#X\8G(@+SX*/#]P:'`@96YD:68[(#\^"@``
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+V1A=&$`````````````````````
M````````````````````````````````````````````````````````````
M`#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S
M-S0U(#`R,#,W,@`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,3(V-3`@,3`U,34T,S,W-#4@,#(R-#0Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#QS8W)I<'0@='EP93TB=&5X="]J
M879A<V-R:7!T(CX*/"$M+0IF=6YC=&EO;B!R97-E=$AI9&1E;B@I"GL*("`@
M('9A<B!F;W)M(#T@9&]C=6UE;G0N;6%P9F]R;3L*("`@('9A<B!T;7`@/2`G
M)SL*("`@(&9O<B`H:2`](#`[(&D@/"!F;W)M+G-E;&5C=$1A=&$N;&5N9W1H
M.R!I*RLI('L*("`@("`@("!T;7`@*ST@9F]R;2YS96QE8W1$871A6VE=+G9A
M;'5E.PH@("`@("`@(&EF("AI(#P@9F]R;2YS96QE8W1$871A+FQE;F=T:"`M
M(#$I"B`@("`@("`@("`@('1M<"`K/2`B7'0B.PH@("`@?0H@("`@9F]R;2YD
M871A2V5Y<RYV86QU92`]('1M<#L*("`@('1M<"`]("<G.PH@("`@9F]R("AI
M(#T@,#L@:2`\(&9O<FTN<V5L96-T07!P+FQE;F=T:#L@:2LK*2!["B`@("`@
M("`@=&UP("L](&9O<FTN<V5L96-T07!P6VE=+G9A;'5E.PH@("`@("`@(&EF
M("AI(#P@9F]R;2YS96QE8W1!<'`N;&5N9W1H("T@,2D*("`@("`@("`@("`@
M=&UP("L](")<="(["B`@("!]"B`@("!F;W)M+F%P<$ME>7,N=F%L=64@/2!T
M;7`["GT*"F9U;F-T:6]N(&%D9%!A:7(H*0I["B`@("!V87(@9F]R;2`](&1O
M8W5M96YT+FUA<&9O<FT["B`@("!I9B`H9F]R;2YS96QE8W0Q+G-E;&5C=&5D
M26YD97@@/CT@,"`F)B!F;W)M+G-E;&5C=#(N<V5L96-T961);F1E>"`^/2`P
M*2!["B`@("`@("`@9F]R;2YS96QE8W1$871A6V9O<FTN<V5L96-T1&%T82YL
M96YG=&A=(#T@;F5W($]P=&EO;BAF;W)M+G-E;&5C=#%;9F]R;2YS96QE8W0Q
M+G-E;&5C=&5D26YD97A=+G1E>'0L(&9O<FTN<V5L96-T,5MF;W)M+G-E;&5C
M=#$N<V5L96-T961);F1E>%TN=F%L=64I.PH@("`@("`@(&9O<FTN<V5L96-T
M07!P6V9O<FTN<V5L96-T07!P+FQE;F=T:%T@/2!N97<@3W!T:6]N*&9O<FTN
M<V5L96-T,EMF;W)M+G-E;&5C=#(N<V5L96-T961);F1E>%TN=&5X="P@9F]R
M;2YS96QE8W0R6V9O<FTN<V5L96-T,BYS96QE8W1E9$EN9&5X72YV86QU92D[
M"B`@("`@("`@9F]R;2YS96QE8W0Q6V9O<FTN<V5L96-T,2YS96QE8W1E9$EN
M9&5X72`](&YU;&P["B`@("`@("`@9F]R;2YS96QE8W0R6V9O<FTN<V5L96-T
M,BYS96QE8W1E9$EN9&5X72`](&YU;&P["B`@("!]"B`@("!R97-E=$AI9&1E
M;B@I.PI]"@IF=6YC=&EO;B!R96UO=F5086ER*"D*>PH@("`@=F%R(&9O<FT@
M/2!D;V-U;65N="YM87!F;W)M.PH@("`@:68@*&9O<FTN<V5L96-T1&%T82YS
M96QE8W1E9$EN9&5X(#X](#`@?'P@9F]R;2YS96QE8W1!<'`N<V5L96-T961)
M;F1E>"`^/2`P*2!["B`@("`@("`@9F]R;2YS96QE8W0Q6V9O<FTN<V5L96-T
M,2YL96YG=&A=(#T@;F5W($]P=&EO;BAF;W)M+G-E;&5C=$1A=&%;9F]R;2YS
M96QE8W1$871A+G-E;&5C=&5D26YD97A=+G1E>'0L(&9O<FTN<V5L96-T1&%T
M85MF;W)M+G-E;&5C=$1A=&$N<V5L96-T961);F1E>%TN=F%L=64I.PH@("`@
M("`@(&9O<FTN<V5L96-T,EMF;W)M+G-E;&5C=#(N;&5N9W1H72`](&YE=R!/
M<'1I;VXH9F]R;2YS96QE8W1!<'!;9F]R;2YS96QE8W1!<'`N<V5L96-T961)
M;F1E>%TN=&5X="P@9F]R;2YS96QE8W1!<'!;9F]R;2YS96QE8W1!<'`N<V5L
M96-T961);F1E>%TN=F%L=64I.PH@("`@("`@(&9O<FTN<V5L96-T1&%T85MF
M;W)M+G-E;&5C=$1A=&$N<V5L96-T961);F1E>%T@/2!N=6QL.PH@("`@("`@
M(&9O<FTN<V5L96-T07!P6V9O<FTN<V5L96-T07!P+G-E;&5C=&5D26YD97A=
M(#T@;G5L;#L*("`@('T*("`@(')E<V5T2&ED9&5N*"D["GT*+R\M+3X*/"]S
M8W)I<'0^"@H\9F]R;2!M971H;V0](G!O<W0B(&YA;64](FUA<&9O<FTB(&%C
M=&EO;CTB9&%T82YP:'`B/@H\/W!H<"!E8VAO(%5T:6PZ.F9O<FU);G!U="@I
M(#\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%C=&EO;DE$(B!V86QU
M93TB/#]P:'`@96-H;R`H:6YT*21N97AT7W-T97`@/SXB("\^"CQI;G!U="!T
M>7!E/2)H:61D96XB(&YA;64](FEM<&]R=%]F;W)M870B('9A;'5E/2(\/W!H
M<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H571I;#HZ9V5T1F]R;41A=&$H)VEM
M<&]R=%]F;W)M870G*2D@/SXB("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA
M;64](FEM<&]R=%]S=&5P(B!V86QU93TB/#]P:'`@96-H;R`H:6YT*21I;7!O
M<G1?<W1E<"`_/B(@+SX*/&@Q(&-L87-S/2)H96%D97(B/@H@/#]P:'`@<')I
M;G1F*%\H(DEM<&]R="P@4W1E<"`E9"(I+"`H:6YT*21I;7!O<G1?<W1E<"D@
M/SX*/"]H,3X*/'`@8VQA<W,](F-O;G1R;VPB/@H@/#]P:'`@96-H;R!?*")3
M96QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB*2`_/@H\+W`^"CQT86)L92!C
M96QL<W!A8VEN9STB,"(@=VED=&@](C$P,"4B/@H@/'1R/@H@(#QT9"!C;&%S
M<STB:71E;2(^"B`@/'1A8FQE/CQT<CX\=&0^"B`@("`\=&%B;&4@8V5L;'-P
M86-I;F<](C`B/CQT<CX*("`@("`@/'1D/@H@("`@("`@(#P_<&AP(&5C:&\@
M7R@B26UP;W)T960@9FEE;&1S.B(I(#\^/&)R("\^"B`@("`@("`@/'-E;&5C
M="!N86UE/2)S96QE8W0Q(B!S:7IE/2(Q,"(^"CP_<&AP(&9O<F5A8V@@*"1?
M4T534TE/3ELG:6UP;W)T7V1A=&$G75LG9&%T82==6S!=(&%S("1K97D@/3X@
M)'9A;'5E*3H*("`@("`@:68@*"%I<W-E="@D87!P7V9I96QD<ULD:V5Y72DI
M.B`_/@H@("`@("`@("`@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H;R!H=&UL
M<W!E8VEA;&-H87)S*"1K97DI(#\^(CX\/W!H<"!E8VAO("@D7U-%4U-)3TY;
M)VEM<&]R=%]D871A)UU;)VAE861E<B==*2`_(&AT;6QS<&5C:6%L8VAA<G,H
M)&ME>2D@.B!H=&UL<W!E8VEA;&-H87)S*"1V86QU92D@/SX\+V]P=&EO;CX*
M/#]P:'`@96YD:68["B`@("`@(&5N9&9O<F5A8V@[(#\^"B`@("`@("`@/"]S
M96QE8W0^"B`@("`@(#PO=&0^"B`@("`@(#QT9#X*("`@("`@("`\/W!H<"!E
M8VAO(%\H(D%V86EL86)L92!F:65L9',Z(BD@/SX\8G(@+SX*("`@("`@("`\
M<V5L96-T(&YA;64](G-E;&5C=#(B('-I>F4](C$P(CX*/#]P:'`@9F]R96%C
M:"`H)&%P<%]F:65L9',@87,@)&ME>2`]/B`D=F%L=64I.@H@("`@("!I9B`H
M(6ES<V5T*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG9&%T82==6S!=6R1K
M97E=*2DZ(#\^"B`@("`@(#P_<&AP(&EF("@H)&ME>2`]/2`G86QA<FU?=&EM
M92<I('Q\("@D:V5Y(#T]("=A;&%R;5]D871E)RDI.B`_/@H@("`@("`@("`@
M("`\/W!H<"!I9B`H(6ES<V5T*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG
M9&%T82==6S!=6R=A;&%R;2==*2DZ(#\^"B`@("`@("`@("`@(#QO<'1I;VX@
M=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2`_/B(^
M/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1V86QU92D@/SX\+V]P=&EO
M;CX*("`@("`@("`@("`@/#]P:'`@96YD:68[(#\^"B`@("`@(#P_<&AP(&5L
M<V5I9B`H)&ME>2`]/2`G86QA<FTG*3H@/SX*("`@("`@("`@("`@/#]P:'`@
M:68@*"$H:7-S970H)%]315-324].6R=I;7!O<G1?9&%T82==6R=D871A)UU;
M,%U;)V%L87)M7W1I;64G72D@)B8@:7-S970H)%]315-324].6R=I;7!O<G1?
M9&%T82==6R=D871A)UU;,%U;)V%L87)M7V1A=&4G72DI*3H@/SX*("`@("`@
M("`@("`@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H
M87)S*"1K97DI(#\^(CX\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'9A
M;'5E*2`_/CPO;W!T:6]N/@H@("`@("`@("`@("`\/W!H<"!E;F1I9CL@/SX*
M("`@("`@/#]P:'`@96QS93H@/SX*("`@("`@/&]P=&EO;B!V86QU93TB/#]P
M:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1K97DI(#\^(CX\/W!H<"!E8VAO
M(&AT;6QS<&5C:6%L8VAA<G,H)'9A;'5E*2`_/CPO;W!T:6]N/@H@("`@("`\
M/W!H<"!E;F1I9CL@/SX*/#]P:'`@96YD:68["B`@("`@(&5N9&9O<F5A8V@[
M(#\^"B`@("`@("`@/"]S96QE8W0^"B`@("`@(#PO=&0^"B`@("`\+W1R/CPO
M=&%B;&4^"B`@("`\:6YP=70@='EP93TB8G5T=&]N(B!V86QU93TB/#]P:'`@
M96-H;R!?*")!9&0@<&%I<B(I(#\^(B!C;&%S<STB8G5T=&]N(B!O;F-L:6-K
M/2)A9&1086ER*"DB("\^"B`@/"]T9#X\+W1R/CPO=&%B;&4^"B`@/"]T9`H\
M+W1R/@H\='(^"B`@/'1D/@H@("`@/'1A8FQE(&-E;&QS<&%C:6YG/2(P(B!W
M:61T:#TB,3`P)2(^"B`@("`\='(^/'1D(&-L87-S/2)I=&5M(CXF;F)S<#L\
M+W1D/CPO='(^"B`@("`\='(^/'1D(&-L87-S/2)S;6%L;&AE861E<B(^/#]P
M:'`@96-H;R!?*")-871C:&EN9R!F:65L9',B*2`_/CPO=&0^/"]T<CX*("`@
M(#PO=&%B;&4^"B`@/"]T9#X*/"]T<CX*/'1R/@H@(#QT9"!C;&%S<STB:71E
M;2(^"B`@/'1A8FQE/CQT<CX\=&0^"B`@("`\:6YP=70@='EP93TB:&ED9&5N
M(B!N86UE/2)D871A2V5Y<R(@+SX*("`@(#QI;G!U="!T>7!E/2)H:61D96XB
M(&YA;64](F%P<$ME>7,B("\^"B`@("`\:6YP=70@='EP93TB:&ED9&5N(B!N
M86UE/2)I;7!O<G1?9F]R;6%T(B!V86QU93TB8W-V(B`O/@H@("`@/'-E;&5C
M="!N86UE/2)S96QE8W1$871A(B!S:7IE/2(Q,"(@;VYC:&%N9V4](F1O8W5M
M96YT+FUA<&9O<FTN<V5L96-T07!P6W1H:7,N<V5L96-T961);F1E>%TN<V5L
M96-T960]=')U92(^"CP_<&AP"F9O<F5A8V@@*"1?4T534TE/3ELG:6UP;W)T
M7V1A=&$G75LG9&%T82==6S!=(&%S("1K97D@/3X@)'9A;'5E*3H*("`@(&EF
M("AI<W-E="@D87!P7V9I96QD<ULD:V5Y72DI.@H@("`@("`@("1M871C:&EN
M9UM=(#T@87)R87DH)&ME>2P@)&%P<%]F:65L9'-;)&ME>5TI.PH_/@H@("`@
M("`@("`@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H
M87)S*"1K97DI(#\^(CX\/W!H<"!E8VAO("@D7U-%4U-)3TY;)VEM<&]R=%]D
M871A)UU;)VAE861E<B==*2`_(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2D@.B!H
M=&UL<W!E8VEA;&-H87)S*"1V86QU92D@/SX\+V]P=&EO;CX*/#]P:'`@96YD
M:68[(#\^"CP_<&AP(&5N9&9O<F5A8V@[(#\^"B`@("`\+W-E;&5C=#X*("`@
M(#QS96QE8W0@;F%M93TB<V5L96-T07!P(B!S:7IE/2(Q,"(@;VYC:&%N9V4]
M(F1O8W5M96YT+FUA<&9O<FTN<V5L96-T1&%T85MT:&ES+G-E;&5C=&5D26YD
M97A=+G-E;&5C=&5D/71R=64B/@H\/W!H<"!F;W)E86-H("@D;6%T8VAI;F<@
M87,@)'!A:7(I.B`_/@H@("`@("`@("`@/&]P=&EO;B!V86QU93TB/#]P:'`@
M96-H;R!H=&UL<W!E8VEA;&-H87)S*"1P86ER6S!=*2`_/B(^/#]P:'`@96-H
M;R!H=&UL<W!E8VEA;&-H87)S*"1P86ER6S%=*2`_/CPO;W!T:6]N/@H\/W!H
M<"!E;F1F;W)E86-H.R`_/@H@("`@/"]S96QE8W0^/&)R("\^"B`@("`\:6YP
M=70@='EP93TB8G5T=&]N(B!V86QU93TB/#]P:'`@96-H;R!?*")296UO=F4@
M<&%I<B(I(#\^(B!C;&%S<STB8G5T=&]N(B!O;F-L:6-K/2)R96UO=F5086ER
M*"DB("\^/&)R("\^/&)R("\^"B`@("`\:6YP=70@='EP93TB<W5B;6ET(B!V
M86QU93TB/#]P:'`@96-H;R!?*").97AT(BD@/SXB(&-L87-S/2)B=71T;VXB
M("\^"B`@/"]T9#X\+W1R/CPO=&%B;&4^"B`@/"]T9#X*/"]T<CX*/"]T86)L
M93X*/"]F;W)M/@H\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"CPA
M+2T*<F5S971(:61D96XH*3L*+R\M+3X*/"]S8W)I<'0^"@``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8P``````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$V,#$@,3`U,34T,S,W-#4@
M,#(R-C,R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#QF;W)M(&UE=&AO9#TB<&]S="(@;F%M93TB:6UP;W)T7V9O<FTB(&%C
M=&EO;CTB9&%T82YP:'`B/@H\/W!H<"!5=&EL.CIP9F]R;4EN<'5T*"D@/SX*
M/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB86-T:6]N240B('9A;'5E/2(\
M/W!H<"!E8VAO("AI;G0I)&YE>'1?<W1E<"`_/B(@+SX*/&EN<'5T('1Y<&4]
M(FAI9&1E;B(@;F%M93TB:6UP;W)T7V9O<FUA="(@=F%L=64](CP_<&AP(&5C
M:&\@:'1M;'-P96-I86QC:&%R<RA5=&EL.CIG971&;W)M1&%T82@G:6UP;W)T
M7V9O<FUA="<I*2`_/B(@+SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB
M:6UP;W)T7W-T97`B('9A;'5E/2(\/W!H<"!E8VAO("AI;G0I)&EM<&]R=%]S
M=&5P(#\^(B`O/@H\:#$@8VQA<W,](FAE861E<B(^"B`\/W!H<"!P<FEN=&8H
M7R@B26UP;W)T+"!3=&5P("5D(BDL("AI;G0I)&EM<&]R=%]S=&5P*2`_/@H\
M+V@Q/@H\9&EV(&-L87-S/2)H96%D97)B;W@B/@H@/#]P:'`@96-H;R!?*")(
M97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(BD@/SX\8G(@+SX*
M(#QP<F4^/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1?4T534TE/3ELG
M:6UP;W)T7V1A=&$G75LG9FER<W1?;&EN97,G72D@/SX\+W!R93X\8G(@+SX*
M(#QL86)E;"!F;W(](FAE861E<B(^/#]P:'`@96-H;R!?*")$;V5S('1H92!F
M:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE
M8VL@=&AI<R!B;W@Z(BD@/SX\+VQA8F5L/@H@/&EN<'5T(&ED/2)H96%D97(B
M('1Y<&4](F-H96-K8F]X(B!N86UE/2)H96%D97(B('9A;'5E/2(Q(B`O/CQB
M<B`O/@H\+V1I=CX*/&EN<'5T('1Y<&4](G-U8FUI="(@=F%L=64](CP_<&AP
M(&5C:&\@7R@B3F5X="(I(#\^(B!C;&%S<STB8G5T=&]N(B`O/@H\+V9O<FT^
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O9&%T82]D871E;6%P+FEN8P``
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(W,#(@,3`U,34T
M,S,W-#4@,#(R-38P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#QF;W)M(&UE=&AO9#TB<&]S="(@;F%M93TB9&%T969O<FTB
M(&%C=&EO;CTB/#]P:'`@96-H;R!(;W)D93HZ87!P;&EC871I;VY5<FPH)V1A
M=&$N<&AP)RD@/SXB/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)A8W1I
M;VY)1"(@=F%L=64](CP_<&AP(&5C:&\@*&EN="DD;F5X=%]S=&5P(#\^(B`O
M/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)I;7!O<G1?9F]R;6%T(B!V
M86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*%5T:6PZ.F=E=$9O
M<FU$871A*"=I;7!O<G1?9F]R;6%T)RDI(#\^(B`O/@H\:6YP=70@='EP93TB
M:&ED9&5N(B!N86UE/2)I;7!O<G1?<W1E<"(@=F%L=64](CP_<&AP(&5C:&\@
M*&EN="DD:6UP;W)T7W-T97`@/SXB("\^"CP_<&AP(%5T:6PZ.G!F;W)M26YP
M=70H*2`_/@H\:#$@8VQA<W,](FAE861E<B(^"B`\/W!H<"!P<FEN=&8H7R@B
M26UP;W)T+"!3=&5P("5D(BDL("AI;G0I)&EM<&]R=%]S=&5P*2`_/@H\+V@Q
M/@H\=&%B;&4@8V5L;'-P86-I;F<](C`B('=I9'1H/2(Q,#`E(CX*/#]P:'`@
M9F]R96%C:"`H)%]315-324].6R=I;7!O<G1?9&%T82==6R=D871E<R==(&%S
M("1K97D@/3X@)&1A=&4I.B`_/@H\/W!H<"!I9B`H8V]U;G0H)&1A=&5;)W9A
M;'5E<R==*2DZ(#\^"CQT<CX*("`@(#QT9#X*("`@("`@("`\=&%B;&4@8V5L
M;'-P86-I;F<](C`B('=I9'1H/2(Q,#`E(CX*("`@("`@("`\='(^/'1D(&-L
M87-S/2)I=&5M(CXF;F)S<#L\+W1D/CPO='(^"B`@("`@("`@/'1R/CQT9"!C
M;&%S<STB<VUA;&QH96%D97(B/CP_<&AP('!R:6YT9BA?*"));7!O<G1E9"!F
M:65L9#H@)7,B*2P@:'1M;'-P96-I86QC:&%R<R@D87!P7V9I96QD<ULD7U-%
M4U-)3TY;)VEM<&]R=%]D871A)UU;)VUA<"==6R1K97E=72DI(#\^/"]T9#X\
M+W1R/@H@("`@("`@(#PO=&%B;&4^"B`@("`\+W1D/@H\+W1R/@H\='(^"B`@
M("`\=&0@8VQA<W,](FET96TB/@H@("`@/'1A8FQE/@H@("`@/'1R/@H@("`@
M("`@(#QT9#X\/W!H<"!E8VAO(%\H(D5X86UP;&4@=F%L=65S.B(I(#\^/"]T
M9#X*("`@("`@("`\=&0^"B`@("`@("`@("`@(#QS96QE8W0^"CP_<&AP(&9O
M<F5A8V@@*"1D871E6R=V86QU97,G72!A<R`D=F%L*3H@/SX*("`@("`@("`@
M("`@("`@(#QO<'1I;VX^/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1V
M86PI(#\^/"]O<'1I;VX^"CP_<&AP(&5N9&9O<F5A8V@[(#\^"B`@("`@("`@
M("`@(#PO<V5L96-T/@H@("`@("`@(#PO=&0^"B`@("`\+W1R/@H\/W!H<"!I
M;F-L=61E(&1I<FYA;64H7U]&24Q%7U\I("X@)R\G("X@8F%S96YA;64H)&1A
M=&5;)W1Y<&4G72D@+B`G+FEN8R<@/SX*("`@(#PO=&%B;&4^"B`@("`\+W1D
M/@H\+W1R/@H\/W!H<"!E;F1I9CL@/SX*/#]P:'`@96YD9F]R96%C:#L@/SX*
M/"]T86)L93X*"CQI;G!U="!T>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB
M('9A;'5E/2(\/W!H<"!E8VAO(%\H(DYE>'0B*2`_/B(@+SX*/"]F;W)M/@H`
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L
M871E<R]D871A+V1A=&4N:6YC````````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P-#`Q-R`Q,#4Q-30S,S<T-2`P,C(P-C,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*)&D@/2`P
M.PIW:&EL92`H)&D@/"!C;W5N="@D9&%T95LG=F%L=65S)UTI("8F(&5M<'1Y
M*"1D871E6R=V86QU97,G75LD:5TI*2!["B`@("`D:2LK.PI]"FEF("AS=')P
M;W,H)&1A=&5;)W9A;'5E<R==6R1I72P@)R\G*2`A/3T@9F%L<V4I('L*("`@
M("1D96P@/2`G+R<["GT@96QS96EF("AS=')P;W,H)&1A=&5;)W9A;'5E<R==
M6R1I72P@)RXG*2`A/3T@9F%L<V4I('L*("`@("1D96P@/2`G+B<["GT@96QS
M96EF("AS=')P;W,H)&1A=&5;)W9A;'5E<R==6R1I72P@)RTG*2`A/3T@9F%L
M<V4I('L*("`@("1D96P@/2`G+2<["GT@96QS92!["B`@("`D9&5L(#T@)R<[
M"GT*"B\O(%1R>2!T;R!G=65S<R!T:&4@9&%T92!F;W)M870@87,@;75C:"!A
M<R!P;W-S:6)L90HD9F]R;2`](&YU;&P["FEF("@A96UP='DH)&1E;"D@)B8@
M:7-S970H)&1A=&5;)W9A;'5E<R==*2`F)B!I<W-E="@D9&%T95LG=F%L=65S
M)UU;)&E=*2D@>PH@("`@)'!A<G1S(#T@97AP;&]D92@D9&5L+"`D9&%T95LG
M=F%L=65S)UU;)&E=*3L*("`@(&EF("AC;W5N="@D<&%R=',I(#X](#,I('L*
M("`@("`@("`D9F]R;2`]("=M9'DG.PH@("`@("`@(&EF("@H<W1R;&5N*"1P
M87)T<ULP72D@/3T@-"D@?'P@*"1P87)T<ULP72`^(#,Q*2D@>PH@("`@("`@
M("`@("`D9F]R;2`]("=Y;60G.PH@("`@("`@("`@("!I9B`H)'!A<G1S6S%=
M(#X@,3(I('L*("`@("`@("`@("`@("`@("1F;W)M(#T@)WED;2<["B`@("`@
M("`@("`@('T*("`@("`@("!](&5L<V5I9B`H)'!A<G1S6S!=(#X@,3(I('L*
M("`@("`@("`@("`@)&9O<FT@/2`G9&UY)SL*("`@("`@("!]"B`@("!]"GT*
M/SX*/'1R/@H@(#QT9#X\/W!H<"!E8VAO(%\H(E-E;&5C="!T:&4@9&%T92!D
M96QI;6ET97(Z(BD@/SX\+W1D/@H@(#QT9#X*("`@(#QS96QE8W0@;F%M93TB
M9&5L:6UI=&5R6SP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2`_
M/ETB/@H@("`@("`\;W!T:6]N('9A;'5E/2(O(CP_<&AP(&5C:&\@)&1E;"`]
M/2`G+R<@/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<@/SX^+SPO;W!T
M:6]N/@H@("`@("`\;W!T:6]N('9A;'5E/2(N(CP_<&AP(&5C:&\@)&1E;"`]
M/2`G+B<@/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<@/SX^+CPO;W!T
M:6]N/@H@("`@("`\;W!T:6]N('9A;'5E/2(M(CP_<&AP(&5C:&\@)&1E;"`]
M/2`G+2<@/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<@/SX^+3PO;W!T
M:6]N/@H@("`@/"]S96QE8W0^"B`@/"]T9#X*/"]T<CX*/'1R/@H@(#QT9#X\
M/W!H<"!E8VAO(%\H(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(BD@/SX\+W1D
M/@H@(#QT9#X*("`@(#QS96QE8W0@;F%M93TB9F]R;6%T6SP_<&AP(&5C:&\@
M:'1M;'-P96-I86QC:&%R<R@D:V5Y*2`_/ETB/@H@("`@("`\;W!T:6]N('9A
M;'5E/2)M9&%Y+VUO;G1H+WEE87(B/#]P:'`@96-H;R`D9F]R;2`]/2`G9&UY
M)R`_("<@<V5L96-T960](G-E;&5C=&5D(B<@.B`G)R`_/CX\/W!H<"!E8VAO
M(%\H(D1$(BD@+B`D9&5L("X@7R@B34TB*2`N("1D96P@+B!?*")962(I(#\^
M/"]O<'1I;VX^"B`@("`@(#QO<'1I;VX@=F%L=64](FUO;G1H+VUD87DO>65A
M<B(\/W!H<"!E8VAO("1F;W)M(#T]("=M9'DG(#\@)R!S96QE8W1E9#TB<V5L
M96-T960B)R`Z("<G(#\^/CP_<&AP(&5C:&\@7R@B34TB*2`N("1D96P@+B!?
M*")$1"(I("X@)&1E;"`N(%\H(EE9(BD@/SX\+V]P=&EO;CX*("`@("`@/&]P
M=&EO;B!V86QU93TB>65A<B]M;VYT:"]M9&%Y(CP_<&AP(&5C:&\@)&9O<FT@
M/3T@)WEM9"<@/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<@/SX^/#]P
M:'`@96-H;R!?*")962(I("X@)&1E;"`N(%\H(DU-(BD@+B`D9&5L("X@7R@B
M1$0B*2`_/CPO;W!T:6]N/@H@("`@("`\;W!T:6]N('9A;'5E/2)Y96%R+VUD
M87DO;6]N=&@B/#]P:'`@96-H;R`D9F]R;2`]/2`G>61M)R`_("<@<V5L96-T
M960](G-E;&5C=&5D(B<@.B`G)R`_/CX\/W!H<"!E8VAO(%\H(EE9(BD@+B`D
M9&5L("X@7R@B1$0B*2`N("1D96P@+B!?*")-32(I(#\^/"]O<'1I;VX^"B`@
M("`\+W-E;&5C=#X*("`\+W1D/@H\+W1R/@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1E;7!L871E<R]D871A+W1I;64N:6YC````````````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C$S-R`Q,#4Q-30S,S<T-2`P,C(Q
M,#4`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*)&D@/2`P.PIW:&EL92`H)&D@/#T@8V]U;G0H)&1A=&5;)W9A;'5E
M<R==*2`F)B!E;7!T>2@D9&%T95LG=F%L=65S)UU;)&E=*2D@>PH@("`@)&DK
M*SL*?0II9B`H<W1R<&]S*"1D871E6R=V86QU97,G75LD:5TL("<Z)RD@(3T]
M(&9A;'-E*2!["B`@("`D9&5L(#T@)SHG.PI](&5L<V5I9B`H<W1R<&]S*"1D
M871E6R=V86QU97,G75LD:5TL("<N)RD@(3T](&9A;'-E*2!["B`@("`D9&5L
M(#T@)RXG.PI](&5L<V4@>PH@("`@)&1E;"`]("<G.PI]"B1A;7!M(#T@*'-T
M<G!O<RA3=')I;F<Z.FQO=V5R*"1D871E6R=V86QU97,G75LP72DL("=A;2<I
M("$]/2!F86QS92!\?"!S=')P;W,H4W1R:6YG.CIL;W=E<B@D9&%T95LG=F%L
M=65S)UU;,%TI+"`G<&TG*2`A/3T@9F%L<V4I.PH_/@H\='(^"B`@/'1D/CP_
M<&AP(&5C:&\@7R@B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB*2`_/CPO
M=&0^"B`@/'1D/@H@("`@/'-E;&5C="!N86UE/2)D96QI;6ET97);/#]P:'`@
M96-H;R!H=&UL<W!E8VEA;&-H87)S*"1K97DI(#\^72(^"B`@("`@(#QO<'1I
M;VX@=F%L=64](CHB/#]P:'`@96-H;R`D9&5L(#T]("<Z)R`_("<@<V5L96-T
M960](G-E;&5C=&5D(B<@.B`G)R`_/CXZ/"]O<'1I;VX^"B`@("`@(#QO<'1I
M;VX@=F%L=64](BXB/#]P:'`@96-H;R`D9&5L(#T]("<N)R`_("<@<V5L96-T
M960](G-E;&5C=&5D(B<@.B`G)R`_/CXN/"]O<'1I;VX^"B`@("`\+W-E;&5C
M=#X*("`\+W1D/@H\+W1R/@H\='(^"B`@/'1D/CP_<&AP(&5C:&\@7R@B4V5L
M96-T('1H92!T:6UE(&9O<FUA=#HB*2`_/CPO=&0^"B`@/'1D/@H@("`@/'-E
M;&5C="!N86UE/2)F;W)M871;/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S
M*"1K97DI(#\^72(^"B`@("`@(#QO<'1I;VX@=F%L=64](C(T:'(B/#]P:'`@
M96-H;R`D86UP;2`_("<G(#H@)R!S96QE8W1E9#TB<V5L96-T960B)R`_/CX\
M/W!H<"!E8VAO(%\H(C(T(&AO=7)S(BD@/SX\+V]P=&EO;CX*("`@("`@/&]P
M=&EO;B!V86QU93TB86UP;2(\/W!H<"!E8VAO("1A;7!M(#\@)R!S96QE8W1E
M9#TB<V5L96-T960B)R`Z("<G(#\^/CP_<&AP(&5C:&\@7R@B04TO4$TB*2`_
M/CPO;W!T:6]N/@H@("`@/"]S96QE8W0^"B`@/"]T9#X*/"]T<CX*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,`````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`S,#0S(#$P-3$U-#,S-S0U(#`R,C8Q,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\9F]R;2!M971H;V0](G!O<W0B(&YA
M;64](FEM<&]R=%]F;W)M(B!A8W1I;VX](F1A=&$N<&AP(CX*/#]P:'`@96-H
M;R!5=&EL.CIF;W)M26YP=70H*2`_/@H\:6YP=70@='EP93TB:&ED9&5N(B!N
M86UE/2)A8W1I;VY)1"(@=F%L=64](CP_<&AP(&5C:&\@*&EN="DD;F5X=%]S
M=&5P(#\^(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)I;7!O<G1?
M9F]R;6%T(B!V86QU93TB8W-V(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N
M86UE/2)I;7!O<G1?<W1E<"(@=F%L=64](CP_<&AP(&5C:&\@*&EN="DD:6UP
M;W)T7W-T97`@/SXB("\^"CQH,2!C;&%S<STB:&5A9&5R(CX*(#P_<&AP('!R
M:6YT9BA?*"));7!O<G0L(%-T97`@)60B*2P@*&EN="DD:6UP;W)T7W-T97`I
M(#\^"CPO:#$^"CQD:78@8VQA<W,](FAE861E<F)O>"!T97AT(CX*("`@(#P_
M<&AP(&5C:&\@7R@B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE
M.B(I(#\^/&)R("\^"B`@("`\<')E/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC
M:&%R<R@D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)V9I<G-T7VQI;F5S)UTI
M(#\^/"]P<F4^/&)R("\^"B`@("`\;&%B96P@9F]R/2)H96%D97(B/CP_<&AP
M(&5C:&\@7R@B1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD
M(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.B(I(#\^/"]L86)E;#X*
M("`@(#QI;G!U="!I9#TB:&5A9&5R(B!T>7!E/2)C:&5C:V)O>"(@;F%M93TB
M:&5A9&5R(B!V86QU93TB,2(@8VAE8VME9#TB8VAE8VME9"(@+SX\8G(@+SX*
M("`@(#P_<&AP(&5C:&\@7R@B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A
M8W1E<C\B*2`_/@H@("`@/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](G-E<"(@
M<VEZ93TB,2(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D
M7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)W-E<"==*2`_/B(@+SX\8G(@+SX*
M("`@(#P_<&AP(&EF("AI<W-E="@D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;
M)W%U;W1E)UTI*3H@/SX*("`@(#P_<&AP(&5C:&\@7R@B5VAA="!I<R!T:&4@
M<75O=&4@8VAA<F%C=&5R/R(I(#\^"B`@("`\:6YP=70@='EP93TB=&5X="(@
M;F%M93TB<75O=&4B('-I>F4](C$B('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS
M<&5C:6%L8VAA<G,H)%]315-324].6R=I;7!O<G1?9&%T82==6R=Q=6]T92==
M*2`_/B(@+SX\8G(@+SX*("`@(#P_<&AP(&5N9&EF.R`_/@H@("`@/#]P:'`@
M:68@*&ES<V5T*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG9FEE;&1S)UTI
M*3H@/SX*("`@(#P_<&AP(&5C:&\@7R@B2&]W(&UA;GD@9FEE;&1S("AC;VQU
M;6YS*2!A<F4@=&AE<F4_(BD@/SX*("`@(#QI;G!U="!T>7!E/2)T97AT(B!N
M86UE/2)F:65L9',B('-I>F4](C(B('9A;'5E/2(\/W!H<"!E8VAO("AI;G0I
M)%]315-324].6R=I;7!O<G1?9&%T82==6R=F:65L9',G72`_/B(@+SX\8G(@
M+SX*("`@(#P_<&AP(&5N9&EF.R`_/@H\+V1I=CX*/&EN<'5T('1Y<&4](G-U
M8FUI="(@=F%L=64](CP_<&AP(&5C:&\@7R@B3F5X="(I(#\^(B!C;&%S<STB
M8G5T=&]N(B`O/@H\+V9O<FT^"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]D871A+V1A=&5T
M:6UE+FEN8P``````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,C$S
M-B`Q,#4Q-30S,S<T-2`P,C(W-#,`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*)&D@/2`P.PIW:&EL92`H)&D@/"!C
M;W5N="@D9&%T95LG=F%L=65S)UTI("8F(&5M<'1Y*"1D871E6R=V86QU97,G
M75LD:5TI*2!["B`@("`D:2LK.PI]"B1D87E?9&5L(#T@)'1I;65?9&5L(#T@
M)R<["FEF("AS=')P;W,H)&1A=&5;)W9A;'5E<R==6R1I72P@)R`G*2`A/3T@
M9F%L<V4I('L*("`@(&9O<B`H)&]R9&5R(#T@,#L@*&5M<'1Y*"1T:6UE7V1E
M;"D@?'P@96UP='DH)&1A>5]D96PI*2`F)B`D;W)D97(@/#T@,3L@)&]R9&5R
M*RLI('L*("`@("`@("!I9B`H)&]R9&5R*2!["B`@("`@("`@("`@(&QI<W0H
M)'1I;64L("1D87DI(#T@97AP;&]D92@G("<L("1D871E6R=V86QU97,G75LD
M:5TL(#(I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&QI<W0H)&1A
M>2P@)'1I;64I(#T@97AP;&]D92@G("<L("1D871E6R=V86QU97,G75LD:5TL
M(#(I.PH@("`@("`@('T*("`@("`@("!I9B`H<W1R<&]S*"1D87DL("<O)RD@
M(3T](&9A;'-E*2!["B`@("`@("`@("`@("1D87E?9&5L(#T@)R\G.PH@("`@
M("`@('T@96QS96EF("AS=')P;W,H)&1A>2P@)RXG*2`A/3T@9F%L<V4I('L*
M("`@("`@("`@("`@)&1A>5]D96P@/2`G+B<["B`@("`@("`@?2!E;'-E:68@
M*'-T<G!O<R@D9&%Y+"`G+2<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`D
M9&%Y7V1E;"`]("<M)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M9&%Y7V1E;"`]("<G.PH@("`@("`@('T*("`@("`@("!I9B`H<W1R<&]S*"1T
M:6UE+"`G.B<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`D=&EM95]D96P@
M/2`G.B<["B`@("`@("`@?2!E;'-E:68@*'-T<G!O<R@D=&EM92P@)RXG*2`A
M/3T@9F%L<V4I('L*("`@("`@("`@("`@)'1I;65?9&5L(#T@)RXG.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1T:6UE7V1E;"`]("<G.PH@("`@
M("`@('T*("`@('T*("`@("1O<F1E<BTM.PI]"@HO+R!4<GD@=&\@9W5E<W,@
M=&AE(&1A=&4@9F]R;6%T(&%S(&UU8V@@87,@<&]S<VEB;&4*)&9O<FT@/2!N
M=6QL.PII9B`H(65M<'1Y*"1D87E?9&5L*2`F)B!I<W-E="@D9&%T95LG=F%L
M=65S)UTI("8F(&ES<V5T*"1D871E6R=V86QU97,G75LD:5TI*2!["B`@("`D
M<&%R=',@/2!E>'!L;V1E*"1D87E?9&5L+"`D9&%T95LG=F%L=65S)UU;)&E=
M*3L*("`@(&EF("AC;W5N="@D<&%R=',I(#X](#,I('L*("`@("`@("`D9F]R
M;2`]("=M9'DG.PH@("`@("`@(&EF("@H<W1R;&5N*"1P87)T<ULP72D@/3T@
M-"D@?'P@*"1P87)T<ULP72`^(#,Q*2D@>PH@("`@("`@("`@("`D9F]R;2`]
M("=Y;60G.PH@("`@("`@("`@("!I9B`H)'!A<G1S6S%=(#X@,3(I('L*("`@
M("`@("`@("`@("`@("1F;W)M(#T@)WED;2<["B`@("`@("`@("`@('T*("`@
M("`@("!](&5L<V5I9B`H)'!A<G1S6S!=(#X@,3(I('L*("`@("`@("`@("`@
M)&9O<FT@/2`G9&UY)SL*("`@("`@("!]"B`@("!]"GT*)&%M<&T@/2`H<W1R
M<&]S*%-T<FEN9SHZ;&]W97(H)&1A=&5;)W9A;'5E<R==6S!=*2P@)V%M)RD@
M(3T](&9A;'-E('Q\('-T<G!O<RA3=')I;F<Z.FQO=V5R*"1D871E6R=V86QU
M97,G75LP72DL("=P;2<I("$]/2!F86QS92D["@II9B`H<W1R<&]S*"1D871E
M6R=V86QU97,G75LD:5TL("<@)RD@/3T](&9A;'-E*3H*/SX*/'1R/@H@(#QT
M9#X\/W!H<"!E8VAO($AO<F1E.CIL86)E;"@G;W)D97)?)R`N(&AT;6QS<&5C
M:6%L8VAA<G,H)&ME>2DL(%\H(E-E;&5C="!T:&4@9&%T92!A;F0@=&EM92!F
M;W)M870Z(BDI(#\^/"]T9#X*("`\=&0^"B`@("`\<V5L96-T(&ED/2)O<F1E
M<E\\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2D@/SXB(&YA;64]
M(F]R9&5R6SP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2`_/ETB
M/@H@("`@("`\;W!T:6]N('9A;'5E/2(M,2(@<V5L96-T960](G-E;&5C=&5D
M(CX\/W!H<"!E8VAO(%\H(E1I;65S=&%M<"!O<B!U;FMN;W=N(BD@/SX\+V]P
M=&EO;CX*("`@(#PO<V5L96-T/@H@(#PO=&0^"CPO='(^"CP_<&AP(&5L<V4Z
M(#\^"CQT<CX*("`\=&0^/#]P:'`@96-H;R!(;W)D93HZ;&%B96PH)V]R9&5R
M7R<@+B!H=&UL<W!E8VEA;&-H87)S*"1K97DI+"!?*")396QE8W0@=&AE(&1A
M>2!A;F0@=&EM92!O<F1E<CHB*2D@/SX\+W1D/@H@(#QT9#X*("`@(#QS96QE
M8W0@:60](F]R9&5R7SP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D:V5Y
M*2`_/B(@;F%M93TB;W)D97);/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S
M*"1K97DI(#\^72(^"B`@("`@(#QO<'1I;VX@=F%L=64](BTQ(CP_<&AP(&5C
M:&\@*"1O<F1E<B`F)B`H96UP='DH)&1A>5]D96PI('Q\(&5M<'1Y*"1T:6UE
M7V1E;"DI*2`_("<@<V5L96-T960](G-E;&5C=&5D(B<@.B`G)R`_/CX\/W!H
M<"!E8VAO(%\H(E1I;65S=&%M<"!O<B!U;FMN;W=N(BD@/SX\+V]P=&EO;CX*
M("`@("`@/&]P=&EO;B!V86QU93TB,"(\/W!H<"!E8VAO("@A)&]R9&5R*2`_
M("<@<V5L96-T960](G-E;&5C=&5D(B<@.B`G)R`_/CX\/W!H<"!P<FEN=&8H
M7R@B1&%T93H@)7,[('1I;64Z("5S(BDL("1D87DL("1T:6UE*2`_/CPO;W!T
M:6]N/@H@("`@("`\;W!T:6]N('9A;'5E/2(Q(CP_<&AP(&5C:&\@)&]R9&5R
M(#\@)R!S96QE8W1E9#TB<V5L96-T960B)R`Z("<G(#\^/CP_<&AP('!R:6YT
M9BA?*")$871E.B`E<SL@=&EM93H@)7,B*2P@)&1A>2P@)'1I;64I(#\^/"]O
M<'1I;VX^"B`@("`\+W-E;&5C=#X*("`\+W1D/@H\+W1R/@H\='(^"B`@/'1D
M/CP_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"=D87E?9&5L:6UI=&5R7R<@+B!H
M=&UL<W!E8VEA;&-H87)S*"1K97DI+"!?*")396QE8W0@=&AE(&1A=&4@9&5L
M:6UI=&5R.B(I*2`_/CPO=&0^"B`@/'1D/@H@("`@/'-E;&5C="!I9#TB9&%Y
M7V1E;&EM:71E<E\\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2D@
M/SXB(&YA;64](F1A>5]D96QI;6ET97);/#]P:'`@96-H;R!H=&UL<W!E8VEA
M;&-H87)S*"1K97DI(#\^72(^"B`@("`@(#QO<'1I;VX@=F%L=64](B\B/#]P
M:'`@96-H;R`D9&%Y7V1E;"`]/2`G+R<@/R`G('-E;&5C=&5D/2)S96QE8W1E
M9"(G(#H@)R<@/SX^+SPO;W!T:6]N/@H@("`@("`\;W!T:6]N('9A;'5E/2(N
M(CP_<&AP(&5C:&\@)&1A>5]D96P@/3T@)RXG(#\@)R!S96QE8W1E9#TB<V5L
M96-T960B)R`Z("<G(#\^/BX\+V]P=&EO;CX*("`@("`@/&]P=&EO;B!V86QU
M93TB+2(\/W!H<"!E8VAO("1D87E?9&5L(#T]("<M)R`_("<@<V5L96-T960]
M(G-E;&5C=&5D(B<@.B`G)R`_/CXM/"]O<'1I;VX^"B`@("`\+W-E;&5C=#X*
M("`\+W1D/@H\+W1R/@H\='(^"B`@/'1D/CP_<&AP(&5C:&\@2&]R9&4Z.FQA
M8F5L*"=D87E?9F]R;6%T7R<@+B!H=&UL<W!E8VEA;&-H87)S*"1K97DI+"!?
M*")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(I*2`_/CPO=&0^"B`@/'1D/@H@
M("`@/'-E;&5C="!I9#TB9&%Y7V9O<FUA=%\\/W!H<"!E8VAO(&AT;6QS<&5C
M:6%L8VAA<G,H)&ME>2D@/SXB(&YA;64](F1A>5]F;W)M871;/#]P:'`@96-H
M;R!H=&UL<W!E8VEA;&-H87)S*"1K97DI(#\^72(^"B`@("`@(#QO<'1I;VX@
M=F%L=64](FUD87DO;6]N=&@O>65A<B(\/W!H<"!E8VAO("1F;W)M(#T]("=D
M;7DG(#\@)R!S96QE8W1E9#TB<V5L96-T960B)R`Z("<G(#\^/CP_<&AP(&5C
M:&\@7R@B1$0B*2`N("1D87E?9&5L("X@7R@B34TB*2`N("1D87E?9&5L("X@
M7R@B65DB*2`_/CPO;W!T:6]N/@H@("`@("`\;W!T:6]N('9A;'5E/2)M;VYT
M:"]M9&%Y+WEE87(B/#]P:'`@96-H;R`D9F]R;2`]/2`G;61Y)R`_("<@<V5L
M96-T960](G-E;&5C=&5D(B<@.B`G)R`_/CX\/W!H<"!E8VAO(%\H(DU-(BD@
M+B`D9&%Y7V1E;"`N(%\H(D1$(BD@+B`D9&%Y7V1E;"`N(%\H(EE9(BD@/SX\
M+V]P=&EO;CX*("`@("`@/&]P=&EO;B!V86QU93TB>65A<B]M;VYT:"]M9&%Y
M(CP_<&AP(&5C:&\@)&9O<FT@/3T@)WEM9"<@/R`G('-E;&5C=&5D/2)S96QE
M8W1E9"(G(#H@)R<@/SX^/#]P:'`@96-H;R!?*")962(I("X@)&1A>5]D96P@
M+B!?*")-32(I("X@)&1A>5]D96P@+B!?*")$1"(I(#\^/"]O<'1I;VX^"B`@
M("`@(#QO<'1I;VX@=F%L=64](GEE87(O;61A>2]M;VYT:"(\/W!H<"!E8VAO
M("1F;W)M(#T]("=Y9&TG(#\@)R!S96QE8W1E9#TB<V5L96-T960B)R`Z("<G
M(#\^/CP_<&AP(&5C:&\@7R@B65DB*2`N("1D87E?9&5L("X@7R@B1$0B*2`N
M("1D87E?9&5L("X@7R@B34TB*2`_/CPO;W!T:6]N/@H@("`@/"]S96QE8W0^
M"B`@/"]T9#X*/"]T<CX*/'1R/@H@(#QT9#X\/W!H<"!E8VAO($AO<F1E.CIL
M86)E;"@G=&EM95]D96QI;6ET97)?)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&ME
M>2DL(%\H(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(BDI(#\^/"]T9#X*
M("`\=&0^"B`@("`\<V5L96-T(&ED/2)T:6UE7V1E;&EM:71E<E\\/W!H<"!E
M8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2D@/SXB(&YA;64](G1I;65?9&5L
M:6UI=&5R6SP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2`_/ETB
M/@H@("`@("`\;W!T:6]N('9A;'5E/2(Z(CP_<&AP(&5C:&\@)'1I;65?9&5L
M(#T]("<Z)R`_("<@<V5L96-T960](G-E;&5C=&5D(B<@.B`G)R`_/CXZ/"]O
M<'1I;VX^"B`@("`@(#QO<'1I;VX@=F%L=64](BXB/#]P:'`@96-H;R`D=&EM
M95]D96P@/3T@)RXG(#\@)R!S96QE8W1E9#TB<V5L96-T960B)R`Z("<G(#\^
M/BX\+V]P=&EO;CX*("`@(#PO<V5L96-T/@H@(#PO=&0^"CPO='(^"CQT<CX*
M("`\=&0^/#]P:'`@96-H;R!(;W)D93HZ;&%B96PH)W1I;65?9F]R;6%T7R<@
M+B!H=&UL<W!E8VEA;&-H87)S*"1K97DI+"!?*")396QE8W0@=&AE('1I;64@
M9F]R;6%T.B(I*2`_/CPO=&0^"B`@/'1D/@H@("`@/'-E;&5C="!I9#TB=&EM
M95]F;W)M871?/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1K97DI(#\^
M(B!N86UE/2)T:6UE7V9O<FUA=%L\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA
M<G,H)&ME>2D@/SY=(CX*("`@("`@/&]P=&EO;B!V86QU93TB,C1H<B(\/W!H
M<"!E8VAO("1A;7!M(#\@)R<@.B`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#\^
M/CP_<&AP(&5C:&\@7R@B,C0@:&]U<G,B*2`_/CPO;W!T:6]N/@H@("`@("`\
M;W!T:6]N('9A;'5E/2)A;7!M(CP_<&AP(&5C:&\@)&%M<&T@/R`G('-E;&5C
M=&5D/2)S96QE8W1E9"(G(#H@)R<@/SX^/#]P:'`@96-H;R!?*")!32]032(I
M(#\^/"]O<'1I;VX^"B`@("`\+W-E;&5C=#X*("`\+W1D/@H\+W1R/@H\/W!H
M<"!E;F1I9CL@/SX*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1E;7!L871E<R]C;VYT96YT<P``````````````````````````````
M```````````````````````````````````````````````P,#`W-34@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<T-2`P,C$S,38`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+V-O;G1E;G1S+V]P96Y?
M=FEE=U]W:6XN:G,`````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,30V(#$P
M-3$U-#,S-S0U(#`R-#8P-0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^
M"CPA+2T*"F9U;F-T:6]N('1R*&)A9'9A;"D*>PH@("`@<F5T=F%L(#T@)R<[
M"B`@("!V86QI9&-H87)S(#T@)V%B8V1E9F=H:6IK;&UN;W!Q<G-T=79W>'EZ
M,#$R,S0U-C<X.2<["@H@("`@8F%D=F%L+G1O3&]W97)#87-E*"D["B`@("!F
M;W(@*&D@/2`P.R!I(#P@8F%D=F%L+FQE;F=T:#L@:2LK*2!["B`@("`@("`@
M:68@*'9A;&ED8VAA<G,N:6YD97A/9BAB861V86PN8VAA<D%T*&DI*2`A/2`M
M,2D@>PH@("`@("`@("`@("!R971V86P@*ST@8F%D=F%L+F-H87)!="AI*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971V86P@*ST@)U\G.PH@
M("`@("`@('T*("`@('T*("`@(')E='5R;B!R971V86P["GT*"F9U;F-T:6]N
M('9I97<H=7)L+"!P87)T:60I"GL*("`@('!A<F%M(#T@(FUE;G5B87(]>65S
M+'1O;VQB87(];F\L;&]C871I;VX];F\L<W1A='5S/6YO+'-C<F]L;&)A<G,]
M>65S+')E<VEZ86)L93UY97,B.PH@("`@=VEN9&]W+F]P96XH=7)L+"`G/#]P
M:'`@96-H;R!B87-E7V-O;G9E<G0H;6EC<F]T:6UE*"DL(#$P+"`S-BD@/SXG
M("L@='(H<&%R=&ED*2P@<&%R86TI.PI]"@HO+R`M+3X*/"]S8W)I<'0^"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+VIA=F%S8W)I
M<'0`````````````````````````````````````````````````````````
M`````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M,#`P(#$P-3$U-#,S-S0U(#`R,38R-P`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,`````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#,W-S0@,3`U,34T,S,W-#4@,#(W,C0R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"\O($DQ.$X@
M8V]N<W1A;G1S"@HO+R!,04Y'.B`B96XB+"!%3D-/1$E.1SH@551&+3@@?"!)
M4T\M.#@U.2TQ"B\O($%U=&AO<CH@36EH86D@0F%Z;VXL(&AT='`Z+R]D>6YA
M<F-H+F-O;2]M:7-H;V\*"B\O($9/4B!44D%.4TQ!5$]24SH*+R\*+R\@("`Q
M+B!03$5!4T4@4%54(%E/55(@0T].5$%#5"!)3D9/($E.(%1(12!!0D]612!,
M24Y%"B\O("`@("`@*&%T(&QE87-T(&$@=F%L:60@96UA:6P@861D<F5S<RD*
M+R\*+R\@("`R+B!03$5!4T4@5%)9(%1/(%5312!55$8M."!&3U(@14Y#3T1)
M3D<["B\O("`@("`@*&EF('1H:7,@:7,@;F]T('!O<W-I8FQE+"!P;&5A<V4@
M:6YC;'5D92!A(&-O;6UE;G0*+R\@("`@("`@=&AA="!S=&%T97,@=VAA="!E
M;F-O9&EN9R!I<R!N96-E<W-A<GDN*0H*06YS96Q);6%G92Y),3A.(#T@>PH)
M+R\@271E;7,@=&AA="!A<'!E87(@:6X@;65N=2X@(%!L96%S92!N;W1E('1H
M870@86X@=6YD97)S8V]R92`H7RD*"2\O(&-H87)A8W1E<B!I;B!T:&4@=')A
M;G-L871I;VX@*')I9VAT(&-O;'5M;BD@=VEL;"!C875S92!T:&4@9F]L;&]W
M:6YG"@DO+R!L971T97(@=&\@8F5C;VUE('5N9&5R;&EN960@86YD(&)E('-H
M;W)T8W5T(&9O<B!T:&%T(&UE;G4@;W!T:6]N+@H*"2));G-E<G0@26UA9V4B
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B26YS97)T($EM86=E(BDI(#\^(BP*"2))
M;6%G92!54DPZ(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B26UA9V4@55),.B(I
M*2`_/B(L"@DB16YT97(@=&AE(&EM86=E(%523"!H97)E(B`@("`@("`@("`@
M("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D5N
M=&5R('1H92!I;6%G92!54DP@:&5R92(I*2`_/B(L"@DB4')E=FEE=R(@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P
M:'`@96-H;R!A9&1S;&%S:&5S*%\H(E!R979I97<B*2D@/SXB+`H)(E!R979I
M97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(@("`@("`@("`@("`@("`@
M(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")0<F5V:65W('1H92!I;6%G
M92!I;B!A(&YE=R!W:6YD;W<B*2D@/SXB+`H)(D%L=&5R;F%T92!T97AT.B(@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C
M:&\@861D<VQA<VAE<RA?*")!;'1E<FYA=&4@=&5X=#HB*2D@/SXB+`H)(D9O
M<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S(B`@("`@("`@
M("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")&;W(@8G)O=W-E<G,@
M=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(I*2`_/B(L"@DB4&]S:71I;VYI
M;F<@;V8@=&AI<R!I;6%G92(@("`@("`@("`@("`@("`@("`@("`@("`@.B`B
M/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E!O<VET:6]N:6YG(&]F('1H:7,@
M:6UA9V4B*2D@/SXB+`H)(DEM86=E(%!R979I97<Z(B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE
M<RA?*"));6%G92!0<F5V:65W.B(I*2`_/B(L"@DB1V%L;&5R>3HB("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@
M96-H;R!A9&1S;&%S:&5S*%\H(D=A;&QE<GDZ(BDI(#\^(BP*"2)'86QL97)Y
M('1O('1A:V4@:6UA9V4@9G)O;2(@("`@("`@("`@("`@("`@("`@("`@("`Z
M("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B1V%L;&5R>2!T;R!T86ME(&EM
M86=E(&9R;VTB*2D@/SXB+`H)(DEM86=E(&9R;VT@9V%L;&5R>3HB("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*"));6%G92!F<F]M(&=A;&QE<GDZ(BDI(#\^(BP*"2));6%G92!F
M<F]M(&=A;&QE<GDB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z
M("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B26UA9V4@9G)O;2!G86QL97)Y
M(BDI(#\^(@I].PH`````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<P``````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`R,#`R(#$P-3$U-#,S-S0U(#`R-C<W,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````O+R!),3A.(&-O;G-T
M86YT<PH*+R\@3$%.1SH@(F5N(BP@14Y#3T1)3D<Z(%541BTX('P@25-/+3@X
M-3DM,0HO+R!!=71H;W(Z($UI:&%I($)A>F]N+"!H='1P.B\O9'EN87)C:"YC
M;VTO;6ES:&]O"@HO+R!&3U(@5%)!3E-,051/4E,Z"B\O"B\O("`@,2X@4$Q%
M05-%(%!55"!93U52($-/3E1!0U0@24Y&3R!)3B!42$4@04)/5D4@3$E.10HO
M+R`@("`@("AA="!L96%S="!A('9A;&ED(&5M86EL(&%D9')E<W,I"B\O"B\O
M("`@,BX@4$Q%05-%(%1262!43R!54T4@551&+3@@1D]2($5.0T]$24Y'.PHO
M+R`@("`@("AI9B!T:&ES(&ES(&YO="!P;W-S:6)L92P@<&QE87-E(&EN8VQU
M9&4@82!C;VUM96YT"B\O("`@("`@('1H870@<W1A=&5S('=H870@96YC;V1I
M;F<@:7,@;F5C97-S87)Y+BD*"DQI<W14>7!E+DDQ.$X@/2!["@DB1&5C:6UA
M;"(@("`@("`@("`@("`@("`@.B`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S
M*%\H(D1E8VEM86P@;G5M8F5R<R(I*2`_/B(L"@DB3&]W97(@<F]M86XB("`@
M("`@("`@("`@.B`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DQO=V5R
M(')O;6%N(&YU;6)E<G,B*2D@/SXB+`H)(E5P<&5R(')O;6%N(B`@("`@("`@
M("`@(#H@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")5<'!E<B!R;VUA
M;B!N=6UB97)S(BDI(#\^(BP*"2),;W=E<B!L871I;B(@("`@("`@("`@("`Z
M("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B3&]W97(@;&%T:6X@;&5T
M=&5R<R(I*2`_/B(L"@DB57!P97(@;&%T:6XB("`@("`@("`@("`@.B`@("`B
M/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E5P<&5R(&QA=&EN(&QE='1E<G,B
M*2D@/SXB+`H)(DQO=V5R(&=R965K(B`@("`@("`@("`@(#H@("`@(CP_<&AP
M(&5C:&\@861D<VQA<VAE<RA?*"),;W=E<B!G<F5E:R!L971T97)S(BDI(#\^
M(BP*"2),:7-T4W1Y;&54;V]L=&EP(B`@("`@("`Z("`@("(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R
M9&5R960@;&ES=',I(BDI(#\^(@I].PH`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V=O
M;V=L95]W:6XN:G,`````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(R-#4@,3`U,34T
M,S,W-#4@,#(U-#(Q`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````&9U;F-T:6]N(&]P96Y?9V]O9VQE7W=I;BAA<F=S*0I["B`@
M("!V87(@=F%L+"!U<FP@/2`G)SL*"B`@("!F;W(@*'9A<B!I(#T@,#L@:2`\
M(&1O8W5M96YT+F=O;V=L92YA<F5A+FQE;F=T:#L@:2LK*2!["B`@("`@("`@
M:68@*&1O8W5M96YT+F=O;V=L92YA<F5A6VE=+F-H96-K960I('L*("`@("`@
M("`@("`@=F%L(#T@9&]C=6UE;G0N9V]O9VQE+F%R96%;:5TN=F%L=64["B`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@('T*"B`@("!S=VET8V@@
M*'9A;"D@>PH)8V%S92`G=V5B)SH*("`@(`EU<FP@/2`G:'1T<#HO+W=W=RYG
M;V]G;&4N8V]M+W-E87)C:#\G.PH)("`@(&)R96%K.PH*"6-A<V4@)VEM86=E
M<R<Z"@D@("`@=7)L(#T@)VAT='`Z+R]I;6%G97,N9V]O9VQE+F-O;2]I;6%G
M97,_)SL*("`@("`@("!B<F5A:SL*"@EC87-E("=G<F]U<',G.@H)("`@('5R
M;"`]("=H='1P.B\O9W)O=7!S+F=O;V=L92YC;VTO9W)O=7!S/R<["B`@("`@
M("`@8G)E86L["@H)8V%S92`G9&ER96-T;W)Y)SH*"2`@("!U<FP@/2`G:'1T
M<#HO+W=W=RYG;V]G;&4N8V]M+W-E87)C:#]C870]9W=D)3)&5&]P)B<["B`@
M("`@("`@8G)E86L["@H)8V%S92`G;F5W<R<Z"@D@("`@=7)L(#T@)VAT='`Z
M+R]N97=S+F=O;V=L92YC;VTO;F5W<S\G.PH@("`@("`@(&)R96%K.PH*"61E
M9F%U;'0Z"B`@("`)=7)L(#T@)VAT='`Z+R]W=W<N9V]O9VQE+F-O;2]S96%R
M8V@_)SL*("`@('T*("`@('5R;"`K/2`G<3TG.PH@("`@:68@*'1Y<&5O9B!E
M;F-O9&554DE#;VUP;VYE;G0@/3T@)W5N9&5F:6YE9"<I('L*("`@("`@("!U
M<FP@*ST@97-C87!E*&1O8W5M96YT+F=O;V=L92YQ+G9A;'5E*3L*("`@('T@
M96QS92!["B`@("`@("`@=7)L("L](&5N8V]D955224-O;7!O;F5N="AD;V-U
M;65N="YG;V]G;&4N<2YV86QU92D["B`@("!]"@H@("`@=F%R(&YA;64@/2`G
M1V]O9VQE)SL*("`@('9A<B!P87)A;2`]("=T;V]L8F%R/7EE<RQL;V-A=&EO
M;CUY97,L<W1A='5S/7EE<RQS8W)O;&QB87)S/7EE<RQR97-I>F%B;&4]>65S
M+'=I9'1H/3@P,"QH96EG:'0]-C`P+&QE9G0],"QT;W`],"<["@H@("`@979A
M;"@G;F%M92`]('=I;F1O=RYO<&5N*'5R;"P@;F%M92P@<&%R86TI)RD["B`@
M("!I9B`H(65V86PH)VYA;64N;W!E;F5R)RDI('L*("`@("`@("!E=F%L*"=N
M86UE+F]P96YE<B`]('-E;&8G*3L*("`@('T*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,`````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`Q-#0V,R`Q,#4Q-30S,S<T-2`P,C8R,C$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+R\@23$X3B!C;VYS
M=&%N=',*"B\O($Q!3D<Z(")E;B(L($5.0T]$24Y'.B!55$8M."!\($E33RTX
M.#4Y+3$*+R\@075T:&]R.B!-:6AA:2!"87IO;BP@:'1T<#HO+V1Y;F%R8V@N
M8V]M+VUI<VAO;PH*+R\@1D]2(%1204Y33$%43U)3.@HO+PHO+R`@(#$N(%!,
M14%312!0550@64]54B!#3TY404-4($E.1D\@24X@5$A%($%"3U9%($Q)3D4*
M+R\@("`@("`H870@;&5A<W0@82!V86QI9"!E;6%I;"!A9&1R97-S*0HO+PHO
M+R`@(#(N(%!,14%312!44ED@5$\@55-%(%541BTX($9/4B!%3D-/1$E.1SL*
M+R\@("`@("`H:68@=&AI<R!I<R!N;W0@<&]S<VEB;&4L('!L96%S92!I;F-L
M=61E(&$@8V]M;65N=`HO+R`@("`@("!T:&%T('-T871E<R!W:&%T(&5N8V]D
M:6YG(&ES(&YE8V5S<V%R>2XI"@I486)L94]P97)A=&EO;G,N23$X3B`]('L*
M"2)!;&EG;B(Z"0D)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B06QI
M9VXB*2D@/SXB+`H)(D%L;"!F;W5R('-I9&5S(CH)"0D)("`B/#]P:'`@96-H
M;R!A9&1S;&%S:&5S*%\H(D%L;"!F;W5R('-I9&5S(BDI(#\^(BP*"2)"86-K
M9W)O=6YD(CH)"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")"86-K
M9W)O=6YD(BDI(#\^(BP*"2)"87-E;&EN92(Z("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?
M*")"87-E;&EN92(I*2`_/B(L"@DB0F]R9&5R(CH)"0D)"2`@(CP_<&AP(&5C
M:&\@861D<VQA<VAE<RA?*")";W)D97(B*2D@/SXB+`H)(D)O<F1E<G,B.@D)
M"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D)O<F1E<G,B*2D@/SXB
M+`H)(D)O='1O;2(Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D)O='1O;2(I*2`_
M/B(L"@DB0U-3(%-T>6QE(CH)"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE
M<RA?*")3='EL92!;0U-372(I*2`_/B(L"@DB0V%P=&EO;B(Z"0D)"0D@("(\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B0V%P=&EO;B(I*2`_/B(L"@DB0V5L
M;"!0<F]P97)T:65S(CH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B0V5L;"!0<F]P97)T:65S(BDI
M(#\^(BP*"2)#96YT97(B.@D)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S
M*%\H(D-E;G1E<B(I*2`_/B(L"@DB0VAA<B(Z("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B0VAA<B(I*2`_/B(L"@DB0V]L;&%P<V5D(&)O<F1E<G,B.B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B0V]L;&%P<V5D(&)O<F1E<G,B*2D@/SXB+`H)(D-O;&]R(CH)"0D)
M"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")#;VQO<B(I*2`_/B(L"@DB
M1&5S8W)I<'1I;VXB.@D)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H
M(D1E<V-R:7!T:6]N(BDI(#\^(BP*"2)&1R!#;VQO<B(Z"0D)"0D@("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B1D<@0V]L;W(B*2D@/SXB+`H)(D9L;V%T
M(CH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B
M/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D9L;V%T(BDI(#\^(BP*"2)&<F%M
M97,B.@D)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D9R86UE<R(I
M*2`_/B(L"@DB2&5I9VAT(CH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B2&5I9VAT
M(BDI(#\^(BP*"2)(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O
M(&UE<F=E/R(Z("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")(;W<@
M;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(I*2`_/B(L
M"@DB2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B.B`@
M("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B2&]W(&UA;GD@<F]W
M<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B*2D@/SXB+`H)(DEM86=E(%52
M3"(Z"0D)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B26UA9V4@55),
M(BDI(#\^(BP*"2)*=7-T:69Y(CH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")*=7-T
M:69Y(BDI(#\^(BP*"2),87EO=70B.@D)"0D)("`B/#]P:'`@96-H;R!A9&1S
M;&%S:&5S*%\H(DQA>6]U="(I*2`_/B(L"@DB3&5F="(Z"0D)"0D)("`B/#]P
M:'`@96-H;R!A9&1S;&%S:&5S*%\H(DQE9G0B*2D@/SXB+`H)(DUA<F=I;B(Z
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B/#]P
M:'`@96-H;R!A9&1S;&%S:&5S*%\H(DUA<F=I;B(I*2`_/B(L"@DB36ED9&QE
M(CH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("(\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B36ED9&QE(BDI(#\^(BP*"2).;R!R
M=6QE<R(Z"0D)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B3F\@<G5L
M97,B*2D@/SXB+`H)(DYO('-I9&5S(CH)"0D)"2`@(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*").;R!S:61E<R(I*2`_/B(L"@DB3F]N92(Z("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B3F]N92(I*2`_/B(L"@DB4&%D9&EN9R(Z"0D)"0D@
M("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4&%D9&EN9R(I*2`_/B(L"@DB
M4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(CH@("`@("`@("`@("`@("`@
M("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4&QE87-E(&-L:6-K(&EN
M=&\@<V]M92!C96QL(BDI(#\^(BP*"2)2:6=H="(Z"0D)"0D@("(\/W!H<"!E
M8VAO(&%D9'-L87-H97,H7R@B4FEG:'0B*2D@/SXB+`H)(E)O=R!0<F]P97)T
M:65S(CH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B/#]P:'`@
M96-H;R!A9&1S;&%S:&5S*%\H(E)O=R!0<F]P97)T:65S(BDI(#\^(BP*"2)2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS
M(CH@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(BDI(#\^(BP*"2)2=6QE
M<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(Z"2`@(CP_<&AP
M(&5C:&\@861D<VQA<VAE<RA?*")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N
M(&-O;'5M;G,@;VYL>2(I*2`_/B(L"@DB4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!R;W=S(&]N;'DB.@D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H
M(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY(BDI(#\^(BP*
M"2)2=6QE<R(Z"0D)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4G5L
M97,B*2D@/SXB+`H)(E-P86-I;F<@86YD('!A9&1I;F<B.B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E-P
M86-I;F<@86YD('!A9&1I;F<B*2D@/SXB+`H)(E-P86-I;F<B.@D)"0D)("`B
M/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E-P86-I;F<B*2D@/SXB+`H)(E-U
M;6UA<GDB.@D)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E-U;6UA
M<GDB*2D@/SXB+`H)(E1/+6-E;&PM9&5L971E(CH)"0D)("`B/#]P:'`@96-H
M;R!A9&1S;&%S:&5S*%\H(D1E;&5T92!C96QL(BDI(#\^(BP*"2)43RUC96QL
M+6EN<V5R="UA9G1E<B(Z"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?
M*"));G-E<G0@8V5L;"!A9G1E<B(I*2`_/B(L"@DB5$\M8V5L;"UI;G-E<G0M
M8F5F;W)E(CH)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B26YS97)T
M(&-E;&P@8F5F;W)E(BDI(#\^(BP*"2)43RUC96QL+6UE<F=E(CH)"0D)("`B
M/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DUE<F=E(&-E;&QS(BDI(#\^(BP*
M"2)43RUC96QL+7!R;W`B.@D)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S
M*%\H(D-E;&P@<')O<&5R=&EE<R(I*2`_/B(L"@DB5$\M8V5L;"US<&QI="(Z
M"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")3<&QI="!C96QL(BDI
M(#\^(BP*"2)43RUC;VPM9&5L971E(CH)"0D)("`B/#]P:'`@96-H;R!A9&1S
M;&%S:&5S*%\H(D1E;&5T92!C;VQU;6XB*2D@/SXB+`H)(E1/+6-O;"UI;G-E
M<G0M869T97(B.@D)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B26YS
M97)T(&-O;'5M;B!A9G1E<B(I*2`_/B(L"@DB5$\M8V]L+6EN<V5R="UB969O
M<F4B.@D)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B26YS97)T(&-O
M;'5M;B!B969O<F4B*2D@/SXB+`H)(E1/+6-O;"US<&QI="(Z"0D)"0D@("(\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4W!L:70@8V]L=6UN(BDI(#\^(BP*
M"2)43RUR;W<M9&5L971E(CH)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S
M*%\H(D1E;&5T92!R;W<B*2D@/SXB+`H)(E1/+7)O=RUI;G-E<G0M86)O=F4B
M.@D)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B26YS97)T(')O=R!B
M969O<F4B*2D@/SXB+`H)(E1/+7)O=RUI;G-E<G0M=6YD97(B.@D)"0D@("(\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B26YS97)T(')O=R!A9G1E<B(I*2`_
M/B(L"@DB5$\M<F]W+7!R;W`B.@D)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S
M:&5S*%\H(E)O=R!P<F]P97)T:65S(BDI(#\^(BP*"2)43RUR;W<M<W!L:70B
M.@D)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E-P;&ET(')O=R(I
M*2`_/B(L"@DB5$\M=&%B;&4M<')O<"(Z"0D)"2`@(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*")486)L92!P<F]P97)T:65S(BDI(#\^(BP*"2)486)L92!0
M<F]P97)T:65S(CH)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E1A
M8FQE(%!R;W!E<G1I97,B*2D@/SXB+`H)(E1E>'0@86QI9VXB.B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B/#]P:'`@96-H;R!A9&1S
M;&%S:&5S*%\H(E1E>'0@86QI9VXB*2D@/SXB+`H)(E1H92!B;W1T;VT@<VED
M92!O;FQY(CH)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E1H92!B
M;W1T;VT@<VED92!O;FQY(BDI(#\^(BP*"2)4:&4@;&5F="UH86YD('-I9&4@
M;VYL>2(Z"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E1H92!L969T
M+6AA;F0@<VED92!O;FQY(BDI(#\^(BP*"2)4:&4@<FEG:'0@86YD(&QE9G0@
M<VED97,@;VYL>2(Z"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B5&AE
M(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'DB*2D@/SXB+`H)(E1H92!R:6=H
M="UH86YD('-I9&4@;VYL>2(Z"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S
M*%\H(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(I*2`_/B(L"@DB5&AE('1O
M<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB.@D)("`B/#]P:'`@96-H;R!A9&1S
M;&%S:&5S*%\H(E1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(BDI(#\^
M(BP*"2)4:&4@=&]P('-I9&4@;VYL>2(Z"0D)"2`@(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*")4:&4@=&]P('-I9&4@;VYL>2(I*2`_/B(L"@DB5&]P(CH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("(\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B5&]P(BDI(#\^(BP*"2)5;G-E="!C
M;VQO<B(Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(CP_
M<&AP(&5C:&\@861D<VQA<VAE<RA?*")5;G-E="!C;VQO<B(I*2`_/B(L"@DB
M5F5R=&EC86P@86QI9VXB.B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B5F5R=&EC86P@86QI9VXB
M*2D@/SXB+`H)(E=I9'1H(CH)"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE
M<RA?*")7:61T:"(I*2`_/B(L"@DB;F]T+61E;"UL87-T+6-E;&PB.@D)"0D@
M("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B2%1-3$%R96$@8V]W87)D;'D@
M<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N(BDI(#\^
M(BP*"2)N;W0M9&5L+6QA<W0M8V]L(CH)"0D)("`B/#]P:'`@96-H;R!A9&1S
M;&%S:&5S*%\H(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E
M('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB*2D@/SXB+`H)(FYO="UD96PM
M;&%S="UR;W<B.@D)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W
M(&EN('1A8FQE+B(I*2`_/B(L"@DB<&5R8V5N="(Z"0D)"0D@("(\/W!H<"!E
M8VAO(&%D9'-L87-H97,H7R@B<&5R8V5N="(I*2`_/B(L"@DB<&EX96QS(CH)
M"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")P:7AE;',B*2D@/SXB
M"GT["@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T96UP;&%T97,O:F%V87-C<FEP="]T<F5E+FIS````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-3`T-#0@,3`U,34T,S,W-#4@,#(S
M,C$R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"\J*@H@*B!(;W)D92!4<F5E($IA=F%S8W)I<'0@0VQA<W,*("H*("H@4')O
M=FED97,@=&AE(&IA=F%S8W)I<'0@8VQA<W,@=&\@8W)E871E(&1Y;F%M:6,@
M=')E97,N"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36%R:V\@1&IU:VEC
M(#QM87)K;T!O8FQO+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN($EF('EO
M=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@*@H@*B`D2&]R9&4Z(&AO
M<F1E+W1E;7!L871E<R]J879A<V-R:7!T+W1R964N:G,L=B`Q+C8R+C(N,3$@
M,C`P-B\P,2\P,2`R,3HR.3HQ-2!J86X@17AP("0*("H*("H@0&%U=&AO<B`@
M36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H@0'!A8VMA9V4@2&]R
M9&5?5')E90H@*B!`<VEN8V4@("!(;W)D92`S+C`*("HO"F9U;F-T:6]N($AO
M<F1E7U1R964H:6YS=&%N8V5.86UE*0I["B`@("`O*B!3970@=7`@=&AI<R!C
M;&%S<R!I;G-T86YC92!F;W(@9G5N8W1I;VX@8V%L;',@9G)O;2!T:&4@<&%G
M92X@*B\*("`@('1H:7,N7VEN<W1A;F-E3F%M92`](&EN<W1A;F-E3F%M93L*
M"B`@("`O*B!);6%G92!V87)I86)L97,N("HO"B`@("!T:&ES+FEM9T1I<B`@
M("`@("`@(#T@)SP_<&AP(&5C:&\@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E
M=$EM86=E1&ER*"=H;W)D92<I("X@)R]T<F5E)SL@/SXG.PH@("`@=&AI<RYI
M;6=";&%N:R`@("`@("`]("=B;&%N:RYP;F<G.PH@("`@=&AI<RYI;6=&;VQD
M97(@("`@("`]("=F;VQD97(N<&YG)SL*("`@('1H:7,N:6UG1F]L9&5R3W!E
M;B`@/2`G9F]L9&5R;W!E;BYP;F<G.PH*("`@("\J(%9A<FEA8FQE<R!T:&%T
M(&-H86YG92!B87-E9"!O;B!T97AT(&1I<F5C=&EO;BX@*B\*/#]P:'`@:68@
M*&5M<'1Y*"1'3$]"04Q36R=N;',G75LG<G1L)UU;)$=,3T)!3%-;)VQA;F=U
M86=E)UU=*2DZ(#\^"B`@("!T:&ES+F9L;V%T1&ER("`@("`@(#T@)V9L;V%T
M.FQE9G0[)SL*("`@('1H:7,N:6UG3&EN92`@("`@("`@/2`G;&EN92YP;F<G
M.PH@("`@=&AI<RYI;6=*;VEN("`@("`@("`]("=J;VEN+G!N9R<["B`@("!T
M:&ES+FEM9TIO:6Y";W1T;VT@(#T@)VIO:6YB;W1T;VTN<&YG)SL*("`@('1H
M:7,N:6UG4&QU<R`@("`@("`@/2`G<&QU<RYP;F<G.PH@("`@=&AI<RYI;6=0
M;'5S0F]T=&]M("`]("=P;'5S8F]T=&]M+G!N9R<["B`@("!T:&ES+FEM9U!L
M=7-/;FQY("`@(#T@)W!L=7-O;FQY+G!N9R<["B`@("!T:&ES+FEM9TUI;G5S
M("`@("`@(#T@)VUI;G5S+G!N9R<["B`@("!T:&ES+FEM9TUI;G5S0F]T=&]M
M(#T@)VUI;G5S8F]T=&]M+G!N9R<["B`@("!T:&ES+FEM9TUI;G5S3VYL>2`@
M(#T@)VUI;G5S;VYL>2YP;F<G.PH@("`@=&AI<RYI;6=.=6QL3VYL>2`@("`]
M("=N=6QL;VYL>2YP;F<G.PH@("`@=&AI<RYI;6=,96%F("`@("`@("`]("=L
M96%F+G!N9R<["CP_<&AP(&5L<V4Z(#\^"B`@("!T:&ES+F9L;V%T1&ER("`@
M("`@(#T@)V9L;V%T.G)I9VAT.R<["B`@("!T:&ES+FEM9TQI;F4@("`@("`@
M(#T@)W)E=BUL:6YE+G!N9R<["B`@("!T:&ES+FEM9TIO:6X@("`@("`@(#T@
M)W)E=BUJ;VEN+G!N9R<["B`@("!T:&ES+FEM9TIO:6Y";W1T;VT@(#T@)W)E
M=BUJ;VEN8F]T=&]M+G!N9R<["B`@("!T:&ES+FEM9U!L=7,@("`@("`@(#T@
M)W)E=BUP;'5S+G!N9R<["B`@("!T:&ES+FEM9U!L=7-";W1T;VT@(#T@)W)E
M=BUP;'5S8F]T=&]M+G!N9R<["B`@("!T:&ES+FEM9U!L=7-/;FQY("`@(#T@
M)W)E=BUP;'5S;VYL>2YP;F<G.PH@("`@=&AI<RYI;6=-:6YU<R`@("`@("`]
M("=R978M;6EN=7,N<&YG)SL*("`@('1H:7,N:6UG36EN=7-";W1T;VT@/2`G
M<F5V+6UI;G5S8F]T=&]M+G!N9R<["B`@("!T:&ES+FEM9TUI;G5S3VYL>2`@
M(#T@)W)E=BUM:6YU<V]N;'DN<&YG)SL*("`@('1H:7,N:6UG3G5L;$]N;'D@
M("`@/2`G<F5V+6YU;&QO;FQY+G!N9R<["B`@("!T:&ES+FEM9TQE868@("`@
M("`@(#T@)W)E=BUL96%F+G!N9R<["CP_<&AP(&5N9&EF.R`_/@H*("`@("\J
M(%1R964@8G5I;&1I;F<@=F%R:6%B;&5S+B`J+PH@("`@=&AI<RYR96YD97)3
M=&%T:6,@("`](&9A;'-E.PH@("`@=&AI<RYT87)G970@("`@("`@("`]("<G
M.PH@("`@=&AI<RYH96%D97(@("`@("`@("`](&YE=R!!<G)A>2@I.PH@("`@
M=&AI<RYR;V]T3F]D97,@("`@("`](&YE=R!!<G)A>2@I.PH@("`@=&AI<RYN
M;V1E<R`@("`@("`@("`](&YE=R!!<G)A>2@I.PH@("`@=&AI<RYN;V1E7W!O
M<R`@("`@("`](&YE=R!!<G)A>2@I.PH@("`@=&AI<RYD<F]P;&EN92`@("`@
M("`](&YE=R!!<G)A>2@I.PH@("`@=&AI<RYO=71P=70@("`@("`@("`]("<G
M.PI]"@I(;W)D95]4<F5E+G!R;W1O='EP92YS971);6=$:7(@/2!F=6YC=&EO
M;BAI;6=$:7(I"GL*("`@('1H:7,N:6UG1&ER(#T@:6UG1&ER.PI]"@I(;W)D
M95]4<F5E+G!R;W1O='EP92YR96YD97)4<F5E(#T@9G5N8W1I;VXH<F]O=$YO
M9&5S+"!R96YD97)3=&%T:6,I"GL*("`@('1H:7,N<F]O=$YO9&5S(#T@<F]O
M=$YO9&5S.PH@("`@=&AI<RYR96YD97)3=&%T:6,@/2!R96YD97)3=&%T:6,[
M"B`@("!T:&ES+FYO9&5S(#T@979A;"@G;E\G("L@=&AI<RY?:6YS=&%N8V5.
M86UE*3L*("`@('1H:7,N:&5A9&5R(#T@979A;"@G:%\G("L@=&AI<RY?:6YS
M=&%N8V5.86UE*3L*("`@('1H:7,N;W!T:6]N<R`](&5V86PH)V]?)R`K('1H
M:7,N7VEN<W1A;F-E3F%M92D["B`@("!T:&ES+G1A<F=E="`]("=T7R<@*R!T
M:&ES+E]I;G-T86YC94YA;64["B`@("!T:&ES+E]R96YD97)4<F5E*"D["GT*
M"DAO<F1E7U1R964N<')O=&]T>7!E+E]R96YD97)4<F5E(#T@9G5N8W1I;VXH
M*0I["B`@("!T:&ES+F]U='!U="`]("<G.PH@("`@:68@*"%T:&ES+F]P=&EO
M;G-;)VAI9&5(96%D97)S)UTI('L*("`@("`@("!T:&ES+F]U='!U="`]('1H
M:7,N7V)U:6QD2&5A9&5R*"D["B`@("!]"B`@("!F;W(@*'9A<B!I(#T@,#L@
M:2`\('1H:7,N<F]O=$YO9&5S+FQE;F=T:#L@:2LK*2!["B`@("`@("`@=&AI
M<RYB=6EL9%1R964H=&AI<RYR;V]T3F]D97-;:5TI.PH@("`@?0H@("`@9&]C
M=6UE;G0N9V5T16QE;65N=$)Y260H=&AI<RYT87)G970I+FEN;F5R2%1-3"`]
M('1H:7,N;W5T<'5T.PH@("`@=&AI<RY?8V]R<F5C=%=I9'1H1F]R4V-R;VQL
M8F%R*"D["B`@("`O+R!)9B!U<VEN9R!A;'1E<FYA=&EN9R!R;W<@<VAA9&EN
M9RP@=V]R:R!O=70@8V]R<F5C="!S:&%D92X*("`@(&EF("AT:&ES+F]P=&EO
M;G-;)V%L=&5R;F%T92==*2!["B`@("`@("`@=&AI<RYS=')I<&4H*3L*("`@
M('T*?0H*+RHJ"B`J(%)E='5R;G,@=&AE($A434P@8V]D92!F;W(@82!H96%D
M97(@<F]W+"!I9B!N96-E<W-A<GDN"B`J"B`J($!A8V-E<W,@<')I=F%T90H@
M*@H@*B!`<F5T=7)N('-T<FEN9R`@5&AE($A434P@8V]D92!O9B!T:&4@:&5A
M9&5R(')O=R!O<B!A;B!E;7!T>2!S=')I;F<N"B`J+PI(;W)D95]4<F5E+G!R
M;W1O='EP92Y?8G5I;&1(96%D97(@/2!F=6YC=&EO;B@I"GL*("`@(&EF("@A
M=&AI<RYH96%D97(N;&5N9W1H*2!["B`@("`@("`@<F5T=7)N("<G.PH@("`@
M?0H*("`@('9A<B!H=&UL(#T@)SQD:78^)SL*("`@(&9O<B`H=F%R(&D@/2`P
M.R!I(#P@=&AI<RYH96%D97(N;&5N9W1H.R!I*RLI('L*("`@("`@("!H=&UL
M("L]("<\9&EV)SL*("`@("`@("!I9B`H=&AI<RYH96%D97);:5U;)V-L87-S
M)UTI('L*("`@("`@("`@("`@:'1M;"`K/2`G(&-L87-S/2(G("L@=&AI<RYH
M96%D97);:5U;)V-L87-S)UT@*R`G(B<["B`@("`@("`@?0H*("`@("`@("!V
M87(@<W1Y;&4@/2!T:&ES+F9L;V%T1&ER.PH@("`@("`@(&EF("AT:&ES+FAE
M861E<EMI75LG=VED=&@G72D@>PH@("`@("`@("`@("!S='EL92`K/2`G=VED
M=&@Z)R`K('1H:7,N:&5A9&5R6VE=6R=W:61T:"==("L@)SLG.PH@("`@("`@
M('T*("`@("`@("!I9B`H=&AI<RYH96%D97);:5U;)V%L:6=N)UTI('L*("`@
M("`@("`@("`@<W1Y;&4@*ST@)W1E>'0M86QI9VXZ)R`K('1H:7,N:&5A9&5R
M6VE=6R=A;&EG;B==("L@)SLG.PH@("`@("`@('T*"B`@("`@("`@:'1M;"`K
M/2`G('-T>6QE/2(G("L@<W1Y;&4@*R`G(B<["B`@("`@("`@:'1M;"`K/2`G
M/B<["B`@("`@("`@:'1M;"`K/2!T:&ES+FAE861E<EMI75LG:'1M;"==(#\@
M=&AI<RYH96%D97);:5U;)VAT;6PG72`Z("<F;F)S<#LG.PH@("`@("`@(&AT
M;6P@*ST@)SPO9&EV/B<["B`@("!]"@H@("`@<F5T=7)N(&AT;6P@*R`G/"]D
M:78^)SL*?0H*+RHJ"B`J(%)E8W5R<VEV92!F=6YC=&EO;B!T;R!W86QK('1H
M<F]U9V@@=&AE('1R964@87)R87D@86YD(&)U:6QD"B`J('1H92!O=71P=70N
M"B`J+PI(;W)D95]4<F5E+G!R;W1O='EP92YB=6EL9%1R964@/2!F=6YC=&EO
M;BAN;V1E260I"GL*("`@('1H:7,N;W5T<'5T("L]('1H:7,N8G5I;&1,:6YE
M*&YO9&5)9"D["@H@("`@:68@*'1Y<&5O9BAT:&ES+FYO9&5S6VYO9&5)9%U;
M)V-H:6QD<F5N)UTI("$]("=U;F1E9FEN960G*2!["B`@("`@("`@=F%R(&YU
M;5-U8FYO9&5S(#T@=&AI<RYN;V1E<UMN;V1E261=6R=C:&EL9')E;B==+FQE
M;F=T:#L*("`@("`@("!I9B`H;G5M4W5B;F]D97,@/B`P*2!["B`@("`@("`@
M("`@(&EF("AT:&ES+FYO9&5S6VYO9&5)9%U;)V5X<&%N9&5D)UTI('L*("`@
M("`@("`@("`@("`@(')O=U-T>6QE(#T@)V1I<W!L87DZ8FQO8VL[)SL*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')O=U-T>6QE(#T@
M)V1I<W!L87DZ;F]N93LG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@('1H
M:7,N;W5T<'5T("L]("<\9&EV(&ED/2)N;V1E0VAI;&1R96Y?)R`K(&YO9&5)
M9"`K("<B('-T>6QE/2(G("L@<F]W4W1Y;&4@*R`G(CXG.PH*("`@("`@("`@
M("`@9F]R("AV87(@8R`](#`[(&,@/"!N=6U3=6)N;V1E<SL@8RLK*2!["B`@
M("`@("`@("`@("`@("!V87(@8VAI;&1.;V1E260@/2!T:&ES+FYO9&5S6VYO
M9&5)9%U;)V-H:6QD<F5N)UU;8UT["B`@("`@("`@("`@("`@("!T:&ES+FYO
M9&5?<&]S6V-H:6QD3F]D94ED72`](&YE=R!!<G)A>2@I.PH@("`@("`@("`@
M("`@("`@=&AI<RYN;V1E7W!O<UMC:&EL9$YO9&5)9%U;)W!O<R==(#T@8R`K
M(#$["B`@("`@("`@("`@("`@("!T:&ES+FYO9&5?<&]S6V-H:6QD3F]D94ED
M75LG8V]U;G0G72`](&YU;5-U8FYO9&5S.PH@("`@("`@("`@("`@("`@=&AI
M<RYB=6EL9%1R964H8VAI;&1.;V1E260I.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!T:&ES+F]U='!U="`K/2`G/"]D:78^)SL*("`@("`@("!]"B`@
M("!]"@H@("`@<F5T=7)N('1R=64["GT*"DAO<F1E7U1R964N<')O=&]T>7!E
M+F)U:6QD3&EN92`](&9U;F-T:6]N*&YO9&5)9"D*>PH@("`@=F%R('-T>6QE
M(#T@)R<["B`@("!V87(@<F]W0VQA<W,@/2`G=')E95)O=R<["B`@("!I9B`H
M=&AI<RYN;V1E<UMN;V1E261=6R=C;&%S<R==*2!["B`@("`@("`@<F]W0VQA
M<W,@*ST@)R`G("L@=&AI<RYN;V1E<UMN;V1E261=6R=C;&%S<R==.PH@("`@
M?0H*("`@('9A<B!L:6YE(#T@)SQD:78@8VQA<W,](B<@*R!R;W=#;&%S<R`K
M("<B/B<["@H@("`@+R\@268@=V4@:&%V92!H96%D97)S+"!T<F%C:R!W:&EC
M:"!L;V=I8V%L(")C;VQU;6XB('=E)W)E(&EN(&9O<@H@("`@+R\@86YY(&=I
M=F5N(&-E;&P@;V8@8V]N=&5N="X*("`@('9A<B!C;VQU;6X@/2`P.PH*("`@
M(&EF("AT>7!E;V8H=&AI<RYN;V1E<UMN;V1E261=6R=E>'1R82==*2`A/2`G
M=6YD969I;F5D)R`F)@H@("`@("`@('1Y<&5O9BAT:&ES+FYO9&5S6VYO9&5)
M9%U;)V5X=')A)UU;,%TI("$]("=U;F1E9FEN960G*2!["B`@("`@("`@=F%R
M(&5X=')A(#T@=&AI<RYN;V1E<UMN;V1E261=6R=E>'1R82==6S!=.PH@("`@
M("`@(&9O<B`H=F%R(&,@/2`P.R!C(#P@97AT<F$N;&5N9W1H.R!C*RLI('L*
M("`@("`@("`@("`@<W1Y;&4@/2!T:&ES+F9L;V%T1&ER.PH@("`@("`@("`@
M("!I9B`H=&AI<RYH96%D97);8V]L=6UN72`F)B!T:&ES+FAE861E<EMC;VQU
M;6Y=6R=W:61T:"==*2!["B`@("`@("`@("`@("`@("!S='EL92`K/2`G=VED
M=&@Z)R`K('1H:7,N:&5A9&5R6V-O;'5M;EU;)W=I9'1H)UT@*R`G.R<["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@;&EN92`K/2`G/&1I=B!S='EL93TB
M)R`K('-T>6QE("L@)R(^)R`K(&5X=')A6V-=("L@)SPO9&EV/B<["B`@("`@
M("`@("`@(&-O;'5M;BLK.PH@("`@("`@('T*("`@("`@("!F;W(@*'9A<B!D
M(#T@8SL@9"`\(&5X=')A0V]L<TQE9G0[(&0K*RD@>PH@("`@("`@("`@("!S
M='EL92`]('1H:7,N9FQO871$:7(["B`@("`@("`@("`@(&EF("AT:&ES+FAE
M861E<EMC;VQU;6Y=("8F('1H:7,N:&5A9&5R6V-O;'5M;EU;)W=I9'1H)UTI
M('L*("`@("`@("`@("`@("`@('-T>6QE("L]("=W:61T:#HG("L@=&AI<RYH
M96%D97);8V]L=6UN75LG=VED=&@G72`K("<[)SL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!L:6YE("L]("<\9&EV('-T>6QE/2(G("L@<W1Y;&4@*R`G
M(CXF;F)S<#L\+V1I=CXG.PH@("`@("`@("`@("!C;VQU;6XK*SL*("`@("`@
M("!]"B`@("!](&5L<V4@>PH@("`@("`@(&9O<B`H=F%R(&,@/2`P.R!C(#P@
M97AT<F%#;VQS3&5F=#L@8RLK*2!["B`@("`@("`@("`@('-T>6QE(#T@=&AI
M<RYF;&]A=$1I<CL*("`@("`@("`@("`@:68@*'1H:7,N:&5A9&5R6V-O;'5M
M;ET@)B8@=&AI<RYH96%D97);8V]L=6UN75LG=VED=&@G72D@>PH@("`@("`@
M("`@("`@("`@<W1Y;&4@*ST@)W=I9'1H.B<@*R!T:&ES+FAE861E<EMC;VQU
M;6Y=6R=W:61T:"==("L@)SLG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&QI;F4@*ST@)SQD:78@<W1Y;&4](B<@*R!S='EL92`K("<B/B9N8G-P.SPO
M9&EV/B<["B`@("`@("`@("`@(&-O;'5M;BLK.PH@("`@("`@('T*("`@('T*
M"B`@("!S='EL92`]('1H:7,N9FQO871$:7(["B`@("!I9B`H=&AI<RYH96%D
M97);8V]L=6UN72`F)B!T:&ES+FAE861E<EMC;VQU;6Y=6R=W:61T:"==*2![
M"B`@("`@("`@<W1Y;&4@*ST@)W=I9'1H.B<@*R!T:&ES+FAE861E<EMC;VQU
M;6Y=6R=W:61T:"==("L@)SLG.PH@("`@?0H@("`@;&EN92`K/2`G/&1I=B!S
M='EL93TB)R`K('-T>6QE("L@)R(^)SL*"B`@("!I9B`H=&AI<RYO<'1I;VYS
M6R=M=6QT:6QI;F4G72D@>PH@("`@("`@(&QI;F4@*ST@)SQT86)L92!C96QL
M<W!A8VEN9STB,"(^/'1R/CQT9#XG.PH@("`@?0H*("`@(&9O<B`H=F%R(&D@
M/2!T:&ES+G)E;F1E<E-T871I8R`_(#$@.B`P.R!I(#P@=&AI<RYN;V1E<UMN
M;V1E261=6R=I;F1E;G0G73L@:2LK*2!["B`@("`@("`@:68@*'1H:7,N9')O
M<&QI;F5;:5T@)B8@=&AI<RYO<'1I;VYS6R=L:6YE<R==*2!["B`@("`@("`@
M("`@(&QI;F4@*ST@)SQI;6<@<W)C/2(G("L@=&AI<RYI;6=$:7(@*R`G+R<@
M*R!T:&ES+FEM9TQI;F4@*R`G(B!A;'0](GPF;F)S<#LF;F)S<#LF;F)S<#LB
M(&AE:6=H=#TB,C`B('=I9'1H/2(R,"(@+SXG.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(&QI;F4@*ST@)SQI;6<@<W)C/2(G("L@=&AI<RYI;6=$
M:7(@*R`G+R<@*R!T:&ES+FEM9T)L86YK("L@)R(@86QT/2(F;F)S<#LF;F)S
M<#LF;F)S<#LB(&AE:6=H=#TB,C`B('=I9'1H/2(R,"(@+SXG.PH@("`@("`@
M('T*("`@('T*("`@(&QI;F4@*ST@=&AI<RY?<V5T3F]D951O9V=L92AN;V1E
M260I.PH@("`@:68@*'1H:7,N;W!T:6]N<ULG;75L=&EL:6YE)UTI('L*("`@
M("`@("!L:6YE("L]("<\+W1D/CQT9#XG.PH@("`@?0H@("`@;&EN92`K/2!T
M:&ES+E]S971,86)E;"AN;V1E260I.PH*("`@(&EF("AT:&ES+F]P=&EO;G-;
M)VUU;'1I;&EN92==*2!["B`@("`@("`@;&EN92`K/2`G/"]T9#X\+W1R/CPO
M=&%B;&4^)SL*("`@('T*"B`@("!L:6YE("L]("<\+V1I=CXG.PH@("`@8V]L
M=6UN*RL["@H@("`@:68@*'1Y<&5O9BAT:&ES+FYO9&5S6VYO9&5)9%U;)V5X
M=')A)UTI("$]("=U;F1E9FEN960G("8F"B`@("`@("`@='EP96]F*'1H:7,N
M;F]D97-;;F]D94ED75LG97AT<F$G75LQ72D@(3T@)W5N9&5F:6YE9"<I('L*
M("`@("`@("!V87(@97AT<F$@/2!T:&ES+FYO9&5S6VYO9&5)9%U;)V5X=')A
M)UU;,5T["B`@("`@("`@9F]R("AV87(@8R`](#`[(&,@/"!E>'1R82YL96YG
M=&@[(&,K*RD@>PH@("`@("`@("`@("!S='EL92`]('1H:7,N9FQO871$:7([
M"B`@("`@("`@("`@(&EF("AT:&ES+FAE861E<EMC;VQU;6Y=("8F('1H:7,N
M:&5A9&5R6V-O;'5M;EU;)W=I9'1H)UTI('L*("`@("`@("`@("`@("`@('-T
M>6QE("L]("=W:61T:#HG("L@=&AI<RYH96%D97);8V]L=6UN75LG=VED=&@G
M72`K("<[)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!L:6YE("L]("<\
M9&EV('-T>6QE/2(G("L@<W1Y;&4@*R`G(CXG("L@97AT<F%;8UT@*R`G/"]D
M:78^)SL*("`@("`@("`@("`@8V]L=6UN*RL["B`@("`@("`@?0H@("`@("`@
M(&9O<B`H=F%R(&0@/2!C.R!D(#P@97AT<F%#;VQS4FEG:'0[(&0K*RD@>PH@
M("`@("`@("`@("!S='EL92`]('1H:7,N9FQO871$:7(["B`@("`@("`@("`@
M(&EF("AT:&ES+FAE861E<EMC;VQU;6Y=("8F('1H:7,N:&5A9&5R6V-O;'5M
M;EU;)W=I9'1H)UTI('L*("`@("`@("`@("`@("`@('-T>6QE("L]("=W:61T
M:#HG("L@=&AI<RYH96%D97);8V]L=6UN75LG=VED=&@G72`K("<[)SL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!L:6YE("L]("<\9&EV('-T>6QE/2(G
M("L@<W1Y;&4@*R`G(CXF;F)S<#L\+V1I=CXG.PH@("`@("`@("`@("!C;VQU
M;6XK*SL*("`@("`@("!]"B`@("!](&5L<V4@>PH@("`@("`@(&9O<B`H=F%R
M(&,@/2`P.R!C(#P@97AT<F%#;VQS4FEG:'0[(&,K*RD@>PH@("`@("`@("`@
M("!S='EL92`]('1H:7,N9FQO871$:7(["B`@("`@("`@("`@(&EF("AT:&ES
M+FAE861E<EMC;VQU;6Y=("8F('1H:7,N:&5A9&5R6V-O;'5M;EU;)W=I9'1H
M)UTI('L*("`@("`@("`@("`@("`@('-T>6QE("L]("=W:61T:#HG("L@=&AI
M<RYH96%D97);8V]L=6UN75LG=VED=&@G72`K("<[)SL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!L:6YE("L]("<\9&EV('-T>6QE/2(G("L@<W1Y;&4@
M*R`G(CXF;F)S<#L\+V1I=CXG.PH@("`@("`@("`@("!C;VQU;6XK*SL*("`@
M("`@("!]"B`@("!]"B`@("!L:6YE("L]("<\+V1I=CXG.PH*("`@(')E='5R
M;B!L:6YE.PI]"@I(;W)D95]4<F5E+G!R;W1O='EP92Y?<V5T3&%B96P@/2!F
M=6YC=&EO;BAN;V1E260I"GL*("`@(&QA8F5L(#T@=&AI<RYN;V1E<UMN;V1E
M261=6R=L86)E;"==.PH*("`@(&EF("AT:&ES+FYO9&5S6VYO9&5)9%U;)W5R
M;"==*2!["B`@("`@("`@=F%R('5R;$-L87-S(#T@)R<["B`@("`@("`@:68@
M*'1H:7,N;F]D97-;;F]D94ED75LG=7)L8VQA<W,G72D@>PH@("`@("`@("`@
M("!U<FQ#;&%S<R`]("<@8VQA<W,](B<@*R!T:&ES+FYO9&5S6VYO9&5)9%U;
M)W5R;&-L87-S)UT@*R`G(B<["B`@("`@("`@?2!E;'-E(&EF("AT:&ES+F]P
M=&EO;G-;)W5R;&-L87-S)UTI('L*("`@("`@("`@("`@=7)L0VQA<W,@/2`G
M(&-L87-S/2(G("L@=&AI<RYO<'1I;VYS6R=U<FQC;&%S<R==("L@)R(G.PH@
M("`@("`@('T*"B`@("`@("`@=F%R('1A<F=E="`]("<G.PH@("`@("`@(&EF
M("AT:&ES+FYO9&5S6VYO9&5)9%U;)W1A<F=E="==*2!["B`@("`@("`@("`@
M('1A<F=E="`]("<@=&%R9V5T/2(G("L@=&AI<RYN;V1E<UMN;V1E261=6R=T
M87)G970G72`K("<B)SL*("`@("`@("!](&5L<V4@:68@*'1H:7,N;W!T:6]N
M<ULG=&%R9V5T)UTI('L*("`@("`@("`@("`@=&%R9V5T(#T@)R!T87)G970]
M(B<@*R!T:&ES+F]P=&EO;G-;)W1A<F=E="==("L@)R(G.PH@("`@("`@('T*
M"B`@("`@("`@=F%R(&]N8VQI8VL@/2`G)SL*("`@("`@("!I9B`H=&AI<RYN
M;V1E<UMN;V1E261=6R=O;F-L:6-K)UTI('L*("`@("`@("`@("`@;VYC;&EC
M:R`]("<@;VYC;&EC:STB)R`K('1H:7,N;F]D97-;;F]D94ED75LG;VYC;&EC
M:R==("L@)R(G.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("<\82<@*R!U
M<FQ#;&%S<R`K("<@:')E9CTB)R`K('1H:7,N;F]D97-;;F]D94ED75LG=7)L
M)UT@*R`G(B<@*R!T87)G970@*R!O;F-L:6-K("L@)SXG("L@=&AI<RY?<V5T
M3F]D94EC;VXH;F]D94ED*2`K(&QA8F5L("L@)SPO83XG.PH@("`@?2!E;'-E
M('L*("`@("`@("!R971U<FX@)SQS<&%N(&-L87-S/2)T;V=G;&4B(&]N8VQI
M8VL](B<@*R!T:&ES+E]I;G-T86YC94YA;64@*R`G+G1O9V=L92A<)R<@*R!N
M;V1E260@*R`G7"<I(CXG("L@=&AI<RY?<V5T3F]D94EC;VXH;F]D94ED*2`K
M(&QA8F5L("L@)SPO<W!A;CXG.PH@("`@?0I]"@I(;W)D95]4<F5E+G!R;W1O
M='EP92Y?<V5T3F]D951O9V=L92`](&9U;F-T:6]N*&YO9&5)9"D*>PH@("`@
M=F%R(&%T=')I8B`]("<G.PH@("`@:68@*'1H:7,N;F]D97-;;F]D94ED75LG
M:6YD96YT)UT@/3T@)S`G("8F"B`@("`@("`@='EP96]F*'1H:7,N;F]D97-;
M;F]D94ED75LG8VAI;&1R96XG72D@(3T@)W5N9&5F:6YE9"<I('L*("`@("`@
M("`O+R!4;W`@;&5V96P@=VET:"!C:&EL9')E;BX*("`@("`@("!T:&ES+F1R
M;W!L:6YE6S!=(#T@9F%L<V4["B`@("`@("`@:68@*'1H:7,N<F5N9&5R4W1A
M=&EC*2!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!A='1R:6(@/2`G('-T>6QE/2)C=7)S;W(Z<&]I;G1E
M<B(@;VYC;&EC:STB)R`K('1H:7,N7VEN<W1A;F-E3F%M92`K("<N=&]G9VQE
M*%PG)R`K(&YO9&5)9"`K("=<)RDB)SL*("`@("`@("!]"B`@("!](&5L<V4@
M:68@*'1H:7,N;F]D97-;;F]D94ED75LG:6YD96YT)UT@(3T@)S`G("8F"B`@
M("`@("`@("`@("`@('1Y<&5O9BAT:&ES+FYO9&5S6VYO9&5)9%U;)V-H:6QD
M<F5N)UTI(#T]("=U;F1E9FEN960G*2!["B`@("`@("`@+R\@3F]D92!N;R!C
M:&EL9')E;BX*("`@("`@("!I9B`H=&AI<RYN;V1E7W!O<UMN;V1E261=6R=P
M;W,G72`\('1H:7,N;F]D95]P;W-;;F]D94ED75LG8V]U;G0G72D@>PH@("`@
M("`@("`@("`O+R!.;W0@;&%S="!N;V1E+@H@("`@("`@("`@("!T:&ES+F1R
M;W!L:6YE6W1H:7,N;F]D97-;;F]D94ED75LG:6YD96YT)UU=(#T@=')U93L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!T:&ES+F1R;W!L:6YE6W1H
M:7,N;F]D97-;;F]D94ED75LG:6YD96YT)UU=(#T@9F%L<V4["B`@("`@("`@
M?0H@("`@?2!E;'-E(&EF("AT>7!E;V8H=&AI<RYN;V1E<UMN;V1E261=6R=C
M:&EL9')E;B==*2`A/2`G=6YD969I;F5D)RD@>PH@("`@("`@("\O($YO9&4@
M=VET:"!C:&EL9')E;BX*("`@("`@("!I9B`H=&AI<RYN;V1E7W!O<UMN;V1E
M261=6R=P;W,G72`\('1H:7,N;F]D95]P;W-;;F]D94ED75LG8V]U;G0G72D@
M>PH@("`@("`@("`@("`O+R!.;W0@;&%S="!N;V1E+@H@("`@("`@("`@("!T
M:&ES+F1R;W!L:6YE6W1H:7,N;F]D97-;;F]D94ED75LG:6YD96YT)UU=(#T@
M=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!,87-T(&YO
M9&4N"B`@("`@("`@("`@('1H:7,N9')O<&QI;F5;=&AI<RYN;V1E<UMN;V1E
M261=6R=I;F1E;G0G75T@/2!F86QS93L*("`@("`@("!]"B`@("`@("`@:68@
M*"%T:&ES+G)E;F1E<E-T871I8RD@>PH@("`@("`@("`@("!A='1R:6(@/2`G
M('-T>6QE/2)C=7)S;W(Z<&]I;G1E<B(@;VYC;&EC:STB)R`K('1H:7,N7VEN
M<W1A;F-E3F%M92`K("<N=&]G9VQE*%PG)R`K(&YO9&5)9"`K("=<)RDB)SL*
M("`@("`@("!]"B`@("!](&5L<V4@>PH@("`@("`@("\O(%1O<"!L979E;"!N
M;V1E('=I=&@@;F\@8VAI;&1R96XN"B`@("`@("`@:68@*'1H:7,N<F5N9&5R
M4W1A=&EC*2!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("!]"B`@
M("`@("`@=&AI<RYD<F]P;&EN95LP72`](&9A;'-E.PH@("`@?0H*("`@(&YO
M9&54;V=G;&4@/2!T:&ES+E]G971.;V1E5&]G9VQE*&YO9&5)9"D["B`@("!I
M;6<@/2`G/&EM9R!I9#TB;F]D951O9V=L95\G("L@;F]D94ED("L@)R(@<W)C
M/2(G("L@=&AI<RYI;6=$:7(@*R`G+R<@*R!N;V1E5&]G9VQE6S!=("L@)R(@
M)SL*("`@(&EF("AN;V1E5&]G9VQE6S%=*2!["B`@("`@("`@:6UG("L]("=A
M;'0](B<@*R!N;V1E5&]G9VQE6S%=("L@)R(@)SL*("`@('T*("`@(&EM9R`K
M/2!A='1R:6(@*R`G(&AE:6=H=#TB,C`B('=I9'1H/2(R,"(@+SXG.PH@("`@
M<F5T=7)N(&EM9SL*?0H*2&]R9&5?5')E92YP<F]T;W1Y<&4N7V=E=$YO9&54
M;V=G;&4@/2!F=6YC=&EO;BAN;V1E260I"GL*("`@('9A<B!N;V1E5&]G9VQE
M(#T@;F5W($%R<F%Y*"<G+"`G)RD["B`@("!I9B`H=&AI<RYN;V1E<UMN;V1E
M261=6R=I;F1E;G0G72`]/2`G,"<@)B8*("`@("`@("!T>7!E;V8H=&AI<RYN
M;V1E<UMN;V1E261=6R=C:&EL9')E;B==*2`A/2`G=6YD969I;F5D)RD@>PH@
M("`@("`@("\O(%1O<"!L979E;"!W:71H(&-H:6QD<F5N+@H@("`@("`@(&EF
M("AT:&ES+G)E;F1E<E-T871I8RD@>PH@("`@("`@("`@("!R971U<FX@;F]D
M951O9V=L93L*("`@("`@("!](&5L<V4@:68@*"%T:&ES+F]P=&EO;G-;)VQI
M;F5S)UTI('L*("`@("`@("`@("`@;F]D951O9V=L95LP72`]('1H:7,N:6UG
M0FQA;FL["B`@("`@("`@("`@(&YO9&54;V=G;&5;,5T@/2`G)FYB<W`[)FYB
M<W`[)FYB<W`[)PH@("`@("`@('T@96QS92!I9B`H=&AI<RYN;V1E<UMN;V1E
M261=6R=E>'!A;F1E9"==*2!["B`@("`@("`@("`@(&YO9&54;V=G;&5;,%T@
M/2!T:&ES+FEM9TUI;G5S3VYL>3L*("`@("`@("`@("`@;F]D951O9V=L95LQ
M72`]("<M)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!N;V1E5&]G
M9VQE6S!=(#T@=&AI<RYI;6=0;'5S3VYL>3L*("`@("`@("`@("`@;F]D951O
M9V=L95LQ72`]("<K)SL*("`@("`@("!]"B`@("!](&5L<V4@:68@*'1H:7,N
M;F]D97-;;F]D94ED75LG:6YD96YT)UT@(3T@)S`G("8F"B`@("`@("`@='EP
M96]F*'1H:7,N;F]D97-;;F]D94ED75LG8VAI;&1R96XG72D@/3T@)W5N9&5F
M:6YE9"<I('L*("`@("`@("`O+R!.;V1E(&YO(&-H:6QD<F5N+@H@("`@("`@
M(&EF("AT:&ES+FYO9&5?<&]S6VYO9&5)9%U;)W!O<R==(#P@=&AI<RYN;V1E
M7W!O<UMN;V1E261=6R=C;W5N="==*2!["B`@("`@("`@("`@("\O($YO="!L
M87-T(&YO9&4N"B`@("`@("`@("`@(&EF("AT:&ES+F]P=&EO;G-;)VQI;F5S
M)UTI('L*("`@("`@("`@("`@("`@(&YO9&54;V=G;&5;,%T@/2!T:&ES+FEM
M9TIO:6X["B`@("`@("`@("`@("`@("!N;V1E5&]G9VQE6S%=(#T@)WPM)SL*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&YO9&54;V=G
M;&5;,%T@/2!T:&ES+FEM9T)L86YK.PH@("`@("`@("`@("`@("`@;F]D951O
M9V=L95LQ72`]("<F;F)S<#LF;F)S<#LF;F)S<#LG.PH@("`@("`@("`@("!]
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@3&%S="!N;V1E+@H@
M("`@("`@("`@("!I9B`H=&AI<RYO<'1I;VYS6R=L:6YE<R==*2!["B`@("`@
M("`@("`@("`@("!N;V1E5&]G9VQE6S!=(#T@=&AI<RYI;6=*;VEN0F]T=&]M
M.PH@("`@("`@("`@("`@("`@;F]D951O9V=L95LQ72`]("=@+2<["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!N;V1E5&]G9VQE6S!=
M(#T@=&AI<RYI;6=";&%N:SL*("`@("`@("`@("`@("`@(&YO9&54;V=G;&5;
M,5T@/2`G)FYB<W`[)FYB<W`[)FYB<W`[)SL*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@('T@96QS92!I9B`H='EP96]F*'1H:7,N;F]D97-;;F]D94ED
M75LG8VAI;&1R96XG72D@(3T@)W5N9&5F:6YE9"<I('L*("`@("`@("`O+R!.
M;V1E('=I=&@@8VAI;&1R96XN"B`@("`@("`@:68@*'1H:7,N;F]D95]P;W-;
M;F]D94ED75LG<&]S)UT@/"!T:&ES+FYO9&5?<&]S6VYO9&5)9%U;)V-O=6YT
M)UTI('L*("`@("`@("`@("`@+R\@3F]T(&QA<W0@;F]D92X*("`@("`@("`@
M("`@:68@*"%T:&ES+F]P=&EO;G-;)VQI;F5S)UTI('L*("`@("`@("`@("`@
M("`@(&YO9&54;V=G;&5;,%T@/2!T:&ES+FEM9T)L86YK.PH@("`@("`@("`@
M("`@("`@;F]D951O9V=L95LQ72`]("<F;F)S<#LF;F)S<#LF;F)S<#LG.PH@
M("`@("`@("`@("!](&5L<V4@:68@*'1H:7,N<F5N9&5R4W1A=&EC*2!["B`@
M("`@("`@("`@("`@("!N;V1E5&]G9VQE6S!=(#T@=&AI<RYI;6=*;VEN.PH@
M("`@("`@("`@("`@("`@;F]D951O9V=L95LQ72`]("=\+2<["B`@("`@("`@
M("`@('T@96QS92!I9B`H=&AI<RYN;V1E<UMN;V1E261=6R=E>'!A;F1E9"==
M*2!["B`@("`@("`@("`@("`@("!N;V1E5&]G9VQE6S!=(#T@=&AI<RYI;6=-
M:6YU<SL*("`@("`@("`@("`@("`@(&YO9&54;V=G;&5;,5T@/2`G+2<["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!N;V1E5&]G9VQE
M6S!=(#T@=&AI<RYI;6=0;'5S.PH@("`@("`@("`@("`@("`@;F]D951O9V=L
M95LQ72`]("<K)SL*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("\O($QA<W0@;F]D92X*("`@("`@("`@("`@:68@*"%T:&ES
M+F]P=&EO;G-;)VQI;F5S)UTI('L*("`@("`@("`@("`@("`@(&YO9&54;V=G
M;&5;,%T@/2!T:&ES+FEM9T)L86YK.PH@("`@("`@("`@("`@("`@;F]D951O
M9V=L95LQ72`]("<F;F)S<#LG.PH@("`@("`@("`@("!](&5L<V4@:68@*'1H
M:7,N<F5N9&5R4W1A=&EC*2!["B`@("`@("`@("`@("`@("!N;V1E5&]G9VQE
M6S!=(#T@=&AI<RYI;6=*;VEN0F]T=&]M.PH@("`@("`@("`@("`@("`@;F]D
M951O9V=L95LQ72`]("=@+2<["B`@("`@("`@("`@('T@96QS92!I9B`H=&AI
M<RYN;V1E<UMN;V1E261=6R=E>'!A;F1E9"==*2!["B`@("`@("`@("`@("`@
M("!N;V1E5&]G9VQE6S!=(#T@=&AI<RYI;6=-:6YU<T)O='1O;3L*("`@("`@
M("`@("`@("`@(&YO9&54;V=G;&5;,5T@/2`G+2<["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("!N;V1E5&]G9VQE6S!=(#T@=&AI<RYI
M;6=0;'5S0F]T=&]M.PH@("`@("`@("`@("`@("`@;F]D951O9V=L95LQ72`]
M("<K)SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T@96QS92!["B`@
M("`@("`@+R\@5&]P(&QE=F5L(&YO9&4@=VET:"!N;R!C:&EL9')E;BX*("`@
M("`@("!I9B`H=&AI<RYR96YD97)3=&%T:6,I('L*("`@("`@("`@("`@<F5T
M=7)N(&YO9&54;V=G;&4["B`@("`@("`@?0H@("`@("`@(&EF("AT:&ES+F]P
M=&EO;G-;)VQI;F5S)UTI('L*("`@("`@("`@("`@;F]D951O9V=L95LP72`]
M('1H:7,N:6UG3G5L;$]N;'D["B`@("`@("`@("`@(&YO9&54;V=G;&5;,5T@
M/2`G)FYB<W`[)FYB<W`[)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!N;V1E5&]G9VQE6S!=(#T@=&AI<RYI;6=";&%N:SL*("`@("`@("`@("`@
M;F]D951O9V=L95LQ72`]("<F;F)S<#LF;F)S<#LF;F)S<#LG.PH@("`@("`@
M('T*("`@('T*"B`@("!R971U<FX@;F]D951O9V=L93L*?0H*2&]R9&5?5')E
M92YP<F]T;W1Y<&4N7W-E=$YO9&5)8V]N(#T@9G5N8W1I;VXH;F]D94ED*0I[
M"B`@("!V87(@:6UG1&ER(#T@*'1Y<&5O9BAT:&ES+FYO9&5S6VYO9&5)9%U;
M)VEC;VYD:7(G72D@(3T@)W5N9&5F:6YE9"<I(#\*("`@("`@("!T:&ES+FYO
M9&5S6VYO9&5)9%U;)VEC;VYD:7(G72`Z"B`@("`@("`@=&AI<RYI;6=$:7([
M"B`@("!I9B`H:6UG1&ER*2!["B`@("`@("`@:6UG1&ER("L]("<O)SL*("`@
M('T*"B`@("!I9B`H='EP96]F*'1H:7,N;F]D97-;;F]D94ED75LG:6-O;B==
M*2`A/2`G=6YD969I;F5D)RD@>PH@("`@("`@("\O($YO9&4@:&%S(&$@=7-E
M<B!D969I;F5D(&EC;VXN"B`@("`@("`@:68@*"%T:&ES+FYO9&5S6VYO9&5)
M9%U;)VEC;VXG72D@>PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@
M?0H@("`@("`@(&EF("AT>7!E;V8H=&AI<RYN;V1E<UMN;V1E261=6R=I8V]N
M;W!E;B==*2`A/2`G=6YD969I;F5D)R`F)B!T:&ES+FYO9&5S6VYO9&5)9%U;
M)V5X<&%N9&5D)UTI('L*("`@("`@("`@("`@:6UG(#T@=&AI<RYN;V1E<UMN
M;V1E261=6R=I8V]N;W!E;B==.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(&EM9R`]('1H:7,N;F]D97-;;F]D94ED75LG:6-O;B==.PH@("`@("`@
M('T*("`@('T@96QS92!["B`@("`@("`@+R\@57-E('-T86YD87)D(&EC;VX@
M<V5T+@H@("`@("`@(&EF("AT>7!E;V8H=&AI<RYN;V1E<UMN;V1E261=6R=C
M:&EL9')E;B==*2`A/2`G=6YD969I;F5D)RD@>PH@("`@("`@("`@("`O+R!.
M;V1E('=I=&@@8VAI;&1R96XN"B`@("`@("`@("`@(&EM9R`]("AT:&ES+FYO
M9&5S6VYO9&5)9%U;)V5X<&%N9&5D)UTI(#\@=&AI<RYI;6=&;VQD97)/<&5N
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#H@=&AI<RYI;6=&;VQD97(["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@+R\@3F]D92!N;R!C:&EL9')E;BX*("`@("`@("`@("`@:6UG
M(#T@=&AI<RYI;6=,96%F.PH@("`@("`@('T*("`@('T*"B`@("!V87(@:6UG
M='AT(#T@)SQI;6<@<W)C/2(G("L@:6UG1&ER("L@:6UG("L@)R(G.PH*("`@
M(&EF("AT>7!E;V8H=&AI<RYN;V1E<UMN;V1E261=6R=I8V]N86QT)UTI("$]
M("=U;F1E9FEN960G*2!["B`@("`@("`@:6UG='AT("L]("<@86QT/2(G("L@
M=&AI<RYN;V1E<UMN;V1E261=6R=I8V]N86QT)UT@*R`G(B<["B`@("!]"@H@
M("`@<F5T=7)N(&EM9W1X="`K("<@+SX@)SL*?0H*2&]R9&5?5')E92YP<F]T
M;W1Y<&4N=&]G9VQE(#T@9G5N8W1I;VXH;F]D94ED*0I["B`@("!T:&ES+FYO
M9&5S6VYO9&5)9%U;)V5X<&%N9&5D)UT@/2`A=&AI<RYN;V1E<UMN;V1E261=
M6R=E>'!A;F1E9"==.PH@("`@:68@*'1H:7,N;F]D97-;;F]D94ED75LG97AP
M86YD960G72D@>PH@("`@("`@(&EF("AN;V1E(#T@9&]C=6UE;G0N9V5T16QE
M;65N=$)Y260H)VYO9&5#:&EL9')E;E\G("L@;F]D94ED*2D@>PH@("`@("`@
M("`@("!N;V1E+G-T>6QE+F1I<W!L87D@/2`G8FQO8VLG.PH@("`@("`@('T*
M("`@('T@96QS92!["B`@("`@("`@:68@*&YO9&4@/2!D;V-U;65N="YG971%
M;&5M96YT0GE)9"@G;F]D94-H:6QD<F5N7R<@*R!N;V1E260I*2!["B`@("`@
M("`@("`@(&YO9&4N<W1Y;&4N9&ES<&QA>2`]("=N;VYE)SL*("`@("`@("!]
M"B`@("!]"@H@("`@+R\@268@=7-I;F<@86QT97)N871I;F<@<F]W('-H861I
M;F<L('=O<FL@;W5T(&-O<G)E8W0@<VAA9&4N"B`@("!I9B`H=&AI<RYO<'1I
M;VYS6R=A;'1E<FYA=&4G72D@>PH@("`@("`@('1H:7,N<W1R:7!E*"D["B`@
M("!]"@H@("`@;F]D951O9V=L92`]('1H:7,N7V=E=$YO9&54;V=G;&4H;F]D
M94ED*3L*("`@(&EF("AT;V=G;&4@/2!D;V-U;65N="YG971%;&5M96YT0GE)
M9"@G;F]D951O9V=L95\G("L@;F]D94ED*2D@>PH@("`@("`@('1O9V=L92YS
M<F,@/2!T:&ES+FEM9T1I<B`K("<O)R`K(&YO9&54;V=G;&5;,%T["B`@("`@
M("`@=&]G9VQE+F%L="`](&YO9&54;V=G;&5;,5T["B`@("!]"@H@("`@=&AI
M<RYS879E4W1A=&4H;F]D94ED+"!T:&ES+FYO9&5S6VYO9&5)9%U;)V5X<&%N
M9&5D)UTI"GT*"DAO<F1E7U1R964N<')O=&]T>7!E+G-T<FEP92`](&9U;F-T
M:6]N*"D*>PH@("`@+R\@5&AE(&5L96UE;G0@=&\@<W1A<G0@<W1R:7!I;F<N
M"B`@("!V87(@:60@/2!A<F=U;65N='-;,%T@/R!A<F=U;65N='-;,%T@.B!T
M:&ES+G1A<F=E=#L*"B`@("`O+R!4:&4@9FQA9R!W92=L;"!U<V4@=&\@:V5E
M<"!T<F%C:R!O9B!W:&5T:&5R('1H92!C=7)R96YT(')O=R!I<PH@("`@+R\@
M;V1D(&]R(&5V96XN"B`@("!V87(@979E;B`](&%R9W5M96YT<ULQ72`_(&%R
M9W5M96YT<ULQ72`Z(&9A;'-E.PH*("`@("\O($]B=&%I;B!A(')E9F5R96YC
M92!T;R!T:&4@=')E92!P87)E;G0@96QE;65N="X*("`@('9A<B!T<F5E(#T@
M9&]C=6UE;G0N9V5T16QE;65N=$)Y260H:60I.PH@("`@:68@*"%T<F5E*2![
M"B`@("`@("`@<F5T=7)N(&5V96X["B`@("!]"@H@("`@+R\@271E<F%T92!O
M=F5R(&5A8V@@8VAI;&0@9&EV+@H@("`@9F]R("AV87(@:2`](#`[(&D@/"!T
M<F5E+F-H:6QD3F]D97,N;&5N9W1H.R!I*RLI('L*("`@("`@("!I9B`H=')E
M92YC:&EL9$YO9&5S6VE=+FED+FEN9&5X3V8H)VYO9&5#:&EL9')E;B<I("$]
M("TQ*2!["B`@("`@("`@("`@(&EF("AT:&ES+FYO9&5S6W1R964N8VAI;&1.
M;V1E<UMI72YI9"YR97!L86-E*"=N;V1E0VAI;&1R96Y?)RP@)R<I75LG97AP
M86YD960G72D@>PH@("`@("`@("`@("`@("`@979E;B`]('1H:7,N<W1R:7!E
M*'1R964N8VAI;&1.;V1E<UMI72YI9"P@979E;BD["B`@("`@("`@("`@('T*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!T<F5E+F-H:6QD3F]D97-;
M:5TN8VQA<W-.86UE(#T@=')E92YC:&EL9$YO9&5S6VE=+F-L87-S3F%M92YR
M97!L86-E*"<@<F]W179E;B<L("<G*2YR97!L86-E*"<@<F]W3V1D)RP@)R<I
M.PH@("`@("`@("`@("!T<F5E+F-H:6QD3F]D97-;:5TN8VQA<W-.86UE("L]
M(&5V96X@/R`G(')O=T5V96XG(#H@)R!R;W=/9&0G.PH*("`@("`@("`@("`@
M+R\@1FQI<"!F<F]M(&]D9"!T;R!E=F5N+"!O<B!V:6-E+79E<G-A+@H@("`@
M("`@("`@("!E=F5N(#T@(65V96X["B`@("`@("`@?0H@("`@?0H*("`@(')E
M='5R;B!E=F5N.PI]"@I(;W)D95]4<F5E+G!R;W1O='EP92YS879E4W1A=&4@
M/2!F=6YC=&EO;BAN;V1E260L(&5X<&%N9&5D*0I["B`@("!V87(@;F5W0V]O
M:VEE(#T@)R<["B`@("!V87(@;VQD0V]O:VEE(#T@=&AI<RY?9V5T0V]O:VEE
M*'1H:7,N7VEN<W1A;F-E3F%M92`K("=?97AP86YD960G*3L*("`@(&EF("AE
M>'!A;F1E9"D@>PH@("`@("`@("\O($5X<&%N9"!R97%U97-T960@<V\@861D
M('1O(&-O;VMI92X*("`@("`@("!N97=#;V]K:64@/2`H;VQD0V]O:VEE*2`_
M(&]L9$-O;VMI92`K("<L)R`Z("<G.PH@("`@("`@(&YE=T-O;VMI92`](&YE
M=T-O;VMI92`K(&YO9&5)9#L*("`@('T@96QS92!["B`@("`@("`@+R\@0V]L
M;&%P<V4@<F5Q=65S=&5D('-O(')E;6]V92!F<F]M(&-O;VMI92X*("`@("`@
M("!V87(@;F]D97,@/2!O;&1#;V]K:64N<W!L:70H)RPG*3L*("`@("`@("!V
M87(@;F5W3F]D97,@/2!N97<@07)R87DH*3L*("`@("`@("!F;W(@*'9A<B!I
M(#T@,#L@:2`\(&YO9&5S+FQE;F=T:#L@:2LK*2!["B`@("`@("`@("`@(&EF
M("AN;V1E<UMI72`A/2!N;V1E260I('L*("`@("`@("`@("`@("`@(&YE=TYO
M9&5S6VYE=TYO9&5S+FQE;F=T:%T@/2!N;V1E<UMI73L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!N97=#;V]K:64@/2!N97=.;V1E<RYJ;VEN
M*"<L)RD["B`@("!]"B`@("!T:&ES+E]S971#;V]K:64H=&AI<RY?:6YS=&%N
M8V5.86UE("L@)U]E>'!A;F1E9"<L(&YE=T-O;VMI92D["GT*"DAO<F1E7U1R
M964N<')O=&]T>7!E+E]G971#;V]K:64@/2!F=6YC=&EO;BAN86UE*0I["B`@
M("!V87(@9&,@/2!D;V-U;65N="YC;V]K:64["B`@("!V87(@<')E9FEX(#T@
M;F%M92`K("<]97AP)SL*("`@('9A<B!B96=I;B`](&1C+FEN9&5X3V8H)SL@
M)R`K('!R969I>"D["B`@("!I9B`H8F5G:6X@/3T@+3$I('L*("`@("`@("!B
M96=I;B`](&1C+FEN9&5X3V8H<')E9FEX*3L*("`@("`@("!I9B`H8F5G:6X@
M(3T@,"D@>PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H@("`@
M?2!E;'-E('L*("`@("`@("!B96=I;B`K/2`R.PH@("`@?0H@("`@=F%R(&5N
M9"`](&1O8W5M96YT+F-O;VMI92YI;F1E>$]F*"<[)RP@8F5G:6XI.PH@("`@
M:68@*&5N9"`]/2`M,2D@>PH@("`@("`@(&5N9"`](&1C+FQE;F=T:#L*("`@
M('T*("`@(')E='5R;B!U;F5S8V%P92AD8RYS=6)S=')I;F<H8F5G:6X@*R!P
M<F5F:7@N;&5N9W1H+"!E;F0I*3L*?0H*2&]R9&5?5')E92YP<F]T;W1Y<&4N
M7W-E=$-O;VMI92`](&9U;F-T:6]N*&YA;64L('9A;'5E*0I["B`@("!V87(@
M8W5R0V]O:VEE(#T@;F%M92`K("<]97AP)R`K(&5S8V%P92AV86QU92D["B`@
M("!C=7)#;V]K:64@*ST@)SM$3TU!24X]/#]P:'`@96-H;R`D1TQ/0D%,4ULG
M8V]N9B==6R=C;V]K:64G75LG9&]M86EN)UT[(#\^.U!!5$@]/#]P:'`@96-H
M;R`D1TQ/0D%,4ULG8V]N9B==6R=C;V]K:64G75LG<&%T:"==.R`_/CLG.PH@
M("`@9&]C=6UE;G0N8V]O:VEE(#T@8W5R0V]O:VEE.PI]"@I(;W)D95]4<F5E
M+G!R;W1O='EP92Y?8V]R<F5C=%=I9'1H1F]R4V-R;VQL8F%R(#T@9G5N8W1I
M;VXH*0I["CP_<&AP(&EF("@D1TQ/0D%,4ULG8G)O=W-E<B==+3YH87-1=6ER
M:R@G<V-R;VQL8F%R7VEN7W=A>2<I*3H@/SX*("`@("\O($-O<G)E8W0@9F]R
M(&9R86UE('-C<F]L;&)A<B!I;B!)12!B>2!D971E<FUI;FEN9R!I9B!A('-C
M<F]L;&)A<B!I<R!P<F5S96YT+`H@("`@+R\@86YD(&EF(&YO="!R96%D:G5S
M=&EN9R!T:&4@;6%R9VEN4FEG:'0@<')O<&5R='D@=&\@,`H@("`@+R\@4V5E
M(&AT='`Z+R]W=W<N>',T86QL+FYL+WYP<&LO:G,O9&]C='EP97,N:'1M;"!F
M;W(@=VAY('1H:7,@=V]R:W,*("`@(&EF("AD;V-U;65N="YD;V-U;65N=$5L
M96UE;G0N8VQI96YT2&5I9VAT(#T](&1O8W5M96YT+F1O8W5M96YT16QE;65N
M="YO9F9S971(96EG:'0I('L*("`@("`@("`O+R!N;R!S8W)O;&QB87(@<')E
M<V5N="P@=&%K92!A=V%Y(&5X=')A(&UA<F=I;@H@("`@("`@(&1O8W5M96YT
M+F)O9'DN<W1Y;&4N;6%R9VEN4FEG:'0@/2`G,"<["B`@("!](&5L<V4@>PH@
M("`@("`@(&1O8W5M96YT+F)O9'DN<W1Y;&4N;6%R9VEN4FEG:'0@/2`G,35P
M>"<["B`@("!]"CP_<&AP(&5N9&EF.R`_/@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E82YJ<P``````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`Q-3,@,3`U,34T,S,W-#4@,#(T,#0P`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'9A<B!?
M961I=&]R7W5R;"`]("(\/W!H<"!E8VAO("1'3$]"04Q36R=R96=I<W1R>2==
M+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`_/B]S97)V:6-E<R]E9&ET;W(O
M:'1M;&%R96$O(CL*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O<')I;G0N:G,`````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`S-38R(#$P-3$U-#,S-S0U(#`R,S0P-@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\<V-R:7!T('1Y<&4](G1E
M>'0O:F%V87-C<FEP="(^"CPA+2T*"G9A<B!D82`]("AD;V-U;65N="YA;&PI
M(#\@,2`Z(#`["G9A<B!P<B`]("AW:6YD;W<N<')I;G0I(#\@,2`Z(#`["G9A
M<B!M86,@/2`H;F%V:6=A=&]R+G5S97)!9V5N="YI;F1E>$]F*")-86,B*2`A
M/2`M,2D["@II9B`H=VEN9&]W+F%D9$5V96YT3&ES=&5N97(I('L*("`@('=I
M;F1O=RYA9&1%=F5N=$QI<W1E;F5R*"=L;V%D)RP@<')I;G17:6XL(&9A;'-E
M*3L*?2!E;'-E(&EF("AW:6YD;W<N871T86-H179E;G0I('L*("`@('=I;F1O
M=RYA='1A8VA%=F5N="@G;VYL;V%D)RP@<')I;G17:6XI.PI](&5L<V4@:68@
M*'=I;F1O=RYO;FQO860@(3T@;G5L;"D@>PH@("`@=F%R(&]L9$]N3&]A9"`]
M('=I;F1O=RYO;FQO860["B`@("!W:6YD;W<N;VYL;V%D(#T@9G5N8W1I;VXH
M92D*("`@('L*("`@("`@("!O;&1/;DQO860H92D["B`@("`@("`@<')I;G17
M:6XH*3L*("`@('T["GT@96QS92!["B`@("!W:6YD;W<N;VYL;V%D(#T@<')I
M;G17:6X["GT*"F9U;F-T:6]N('!R:6YT5VEN*"D*>PH@("`@:68@*'!R*2![
M"B`@("`@("`@+R\@3E,T*RP@244U*PH@("`@("`@('=I;F1O=RYP<FEN="@I
M.PH@("`@?2!E;'-E(&EF("@A;6%C*2!["B`@("`@("`@+R\@244S(&%N9"!)
M130@;VX@4$,*("`@("`@("!60G!R:6YT5VEN*"D["B`@("!](&5L<V4@>PH@
M("`@("`@("\O(&5V97)Y=&AI;F<@96QS90H@("`@("`@(&AA;F1L95]E<G)O
M<B@I.PH@("`@?0I]"@IW:6YD;W<N;VYE<G)O<B`](&AA;F1L95]E<G)O<CL*
M=VEN9&]W+F]N869T97)P<FEN="`](&9U;F-T:6]N*"D@>W=I;F1O=RYC;&]S
M92@I?0H*9G5N8W1I;VX@:&%N9&QE7V5R<F]R*"D*>PH@("`@=VEN9&]W+F%L
M97)T*"<\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B66]U<B!B<F]W<V5R(&1O
M97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R
M;VPO0V]M;6%N9"`K(%`@=&\@<')I;G0N(BDI(#\^)RD["B`@("!R971U<FX@
M=')U93L*?0H*:68@*"%P<B`F)B`A;6%C*2!["B`@("!I9B`H9&$I('L*("`@
M("`@("`O+R!4:&ES(&UU<W0@8F4@244T(&]R(&=R96%T97(*("`@("`@("!W
M8G9E<G,@/2`B.#@U-D8Y-C$M,S0P02TQ,40P+4$Y-D(M,#!#,#1&1#<P-4$R
M(CL*("`@('T@96QS92!["B`@("`@("`@+R\@=&AI<R!M=7-T(&)E($E%,RYX
M"B`@("`@("`@=V)V97)S(#T@(D5!0C(R04,S+3,P0S$M,3%#1BU!-T5"+3`P
M,#!#,#5"044P0B(["B`@("!]"@H@("`@9&]C=6UE;G0N=W)I=&4H(CQ/0DI%
M0U0@240]7")70EPB(%=)1%1(/5PB,%PB($A%24=(5#U<(C!<(B!#3$%34TE$
M/5PB0TQ3240Z(BD["B`@("!D;V-U;65N="YW<FET92AW8G9E<G,@*R`B7"(^
M(#PO3T)*14-4/B(I.PI]"@HO+R`M+3X*/"]S8W)I<'0^"@H\<V-R:7!T('1Y
M<&4](G1E>'0O=F)S8W)I<'0B/@H\(2TM"@IS=6(@=VEN9&]W7V]N=6YL;V%D
M"B`@("!O;B!E<G)O<B!R97-U;64@;F5X=`H@("`@)R!*=7-T('1I9'D@=7`@
M=VAE;B!W92!L96%V92!T;R!B92!S=7)E('=E(&%R96XG=`H@("`@)R!K965P
M:6YG(&EN<W1A;F-E<R!O9B!T:&4@8G)O=W-E<B!C;VYT<F]L(&EN(&UE;6]R
M>0H@("`@<V5T(%="(#T@;F]T:&EN9PIE;F0@<W5B"@IS=6(@5D)P<FEN=%=I
M;@H@("`@3TQ%0TU$241?4%))3E0@/2`V"B`@("!O;B!E<G)O<B!R97-U;64@
M;F5X=`H*("`@("<@244T(&]B:F5C="!H87,@82!D:69F97)E;G0@8V]M;6%N
M9"!S=')U8W1U<F4*("`@(&EF(&1A('1H96X*("`@("`@("!C86QL(%="+D5X
M96-70BA/3$5#341)1%]04DE.5"P@,2D*("`@(&5L<V4*("`@("`@("!C86QL
M(%="+DE/;&5#;VUM86YD5&%R9V5T+D5X96,H3TQ%0TU$241?4%))3E0L(#$L
M("(B+"`B(BD*("`@(&5N9"!I9@IE;F0@<W5B"@HG("TM/@H\+W-C<FEP=#X*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?:'1M;%]H96QP97(N:G,`````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P-#$T-R`Q,#4Q-30S,S<T-2`P,C4U-S8`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+RHJ"B`J($AO<F1E($AT;6P@2&5L
M<&5R($IA=F%S8W)I<'0@0VQA<W,*("H*("H@4')O=FED97,@=&AE(&IA=F%S
M8W)I<'0@8VQA<W,@:6YS97)T(&AT;6P@=&%G<R!B>2!C;&EC:VEN9R!O;B!I
M8V]N<RX*("H*("H@5&AE(&AE;'!E<G,@879A:6QA8FQE.@H@*B`@("`@(&5M
M;W1I8V]N<R`M(&9O<B!I;G-E<G1I;F<@96UO=&EC;VYS('-T<FEN9W,*("H*
M("H@)$AO<F1E.B!H;W)D92]T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7VAT
M;6Q?:&5L<&5R+FIS+'8@,2XQ,BXR+C4@,C`P-B\P-2\Q,2`Q.3HT.3HQ-"!C
M:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UA<FMO($1J
M=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A'4$PI+B!)
M9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]G<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*B!`<&%C:V%G92!H
M;W)D90H@*B!`=&]D;R!A9&0@:&%N9&QI;F<@9F]R(&9O;G0@=&%G<RP@=&%B
M;&5S+"!E=&,N"B`J+PH*=F%R('1A<F=E=$5L96UE;G0["@IF=6YC=&EO;B!O
M<&5N2'1M;$AE;'!E<BAT>7!E+"!T87)G970I"GL*("`@('9A<B!L87D@/2!D
M;V-U;65N="YG971%;&5M96YT0GE)9"@G:'1M;&AE;'!E<E\G("L@=&%R9V5T
M*3L*("`@('1A<F=E=$5L96UE;G0@/2!D;V-U;65N="YG971%;&5M96YT0GE)
M9"AT87)G970I.PH*("`@(&EF("AL87DN<W1Y;&4N9&ES<&QA>2`]/2`G8FQO
M8VLG*2!["B`@("`@("`@;&%Y+G-T>6QE+F1I<W!L87D@/2`G;F]N92<["B`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@(&EF("AL87DN9FER<W1#
M:&EL9"D@>PH@("`@("`@(&QA>2YR96UO=F5#:&EL9"AL87DN9FER<W1#:&EL
M9"D["B`@("!]"@H@("`@=F%R('1A8FQE(#T@9&]C=6UE;G0N8W)E871E16QE
M;65N="@G5$%"3$4G*3L*("`@('9A<B!T8F]D>2`](&1O8W5M96YT+F-R96%T
M945L96UE;G0H)U1"3T19)RD["B`@("!T86)L92YA<'!E;F1#:&EL9"AT8F]D
M>2D["B`@("!T86)L92YC96QL4W!A8VEN9R`](#`["B`@("!T86)L92YB;W)D
M97(@/2`P.PH*("`@(&EF("AT>7!E(#T]("=E;6]T:6-O;G,G*2!["B`@("`@
M("`@<F]W(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G5%(G*3L*("`@("`@
M("!C96QL(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G5$0G*3L*("`@("`@
M("`\/W!H<"!R97%U:7)E7V]N8V4@)TAO<F1E+U1E>'0O1FEL=&5R+G!H<"<[
M("1F:6QT97(@/2!497AT7T9I;'1E<CHZ9F%C=&]R>2@G96UO=&EC;VYS)RD[
M("1I8V]N<R`](&%R<F%Y7V9L:7`H)&9I;'1E<BT^9V5T26-O;G,H*2D[(&9O
M<F5A8V@@*"1I8V]N<R!A<R`D:6-O;B`]/B`D<W1R:6YG*3H@/SX*("`@("`@
M("!L:6YK(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G02<I.PH@("`@("`@
M(&QI;FLN:')E9B`]("<C)SL*("`@("`@("!L:6YK+F]N8VQI8VL@/2!F=6YC
M=&EO;B@I('L*("`@("`@("`@("`@=&%R9V5T16QE;65N="YV86QU92`]('1A
M<F=E=$5L96UE;G0N=F%L=64@*R`G/#]P:'`@96-H;R`D<W1R:6YG(#\^)R`K
M("<@)SL*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@
M("`@("!C96QL+F%P<&5N9$-H:6QD*&QI;FLI.PH@("`@("`@(&EM9R`](&1O
M8W5M96YT+F-R96%T945L96UE;G0H)TE-1R<I"B`@("`@("`@:6UG+G-R8R`]
M("<\/W!H<"!E8VAO("1'3$]"04Q36R=R96=I<W1R>2==+3YG971);6%G941I
M<B@G:&]R9&4G*2`N("<O96UO=&EC;VYS+R<@+B`D:6-O;B`N("<N<&YG)R`_
M/B<["B`@("`@("`@:6UG+F%L:6=N(#T@)VUI9&1L92<["B`@("`@("`@:6UG
M+F)O<F1E<B`](#`["B`@("`@("`@;&EN:RYA<'!E;F1#:&EL9"AI;6<I.PH@
M("`@("`@(#P_<&AP(&5N9&9O<F5A8V@[(#\^"B`@("`@("`@<F]W+F%P<&5N
M9$-H:6QD*&-E;&PI.PH@("`@("`@('1B;V1Y+F%P<&5N9$-H:6QD*')O=RD[
M"B`@("`@("`@=&%B;&4N87!P96YD0VAI;&0H=&)O9'DI.PH@("`@?0H*("`@
M(&QA>2YA<'!E;F1#:&EL9"AT86)L92D["B`@("!L87DN<W1Y;&4N9&ES<&QA
M>2`]("=B;&]C:R<["GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,`````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`R,S(T-R`Q,#4Q-30S,S<T-2`P,C4P-#8`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=F%R(&-U<G)E
M;G1$871E+"!C=7)R96YT665A<BP@8W5R26UG260L(&-U<G)E;G1487)G970[
M"@IF=6YC=&EO;B!O<&5N0V%L96YD87(H:6UG260L('1A<F=E="P@8V%L;&)A
M8VLI"GL*("`@(&EF("AD;V-U;65N="YG971%;&5M96YT0GE)9"AT87)G970@
M*R`G6WEE87)=)RDN=F%L=64@)B8@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H
M=&%R9V5T("L@)UMM;VYT:%TG*2YV86QU92`F)B!D;V-U;65N="YG971%;&5M
M96YT0GE)9"AT87)G970@*R`G6V1A>5TG*2YV86QU92D@>PH@("`@("`@('9A
M<B!D(#T@;F5W($1A=&4H9&]C=6UE;G0N9V5T16QE;65N=$)Y260H=&%R9V5T
M("L@)UMY96%R72<I+G9A;'5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M9&]C=6UE;G0N9V5T16QE;65N=$)Y260H=&%R9V5T("L@)UMM;VYT:%TG*2YV
M86QU92`M(#$L"B`@("`@("`@("`@("`@("`@("`@("`@("!D;V-U;65N="YG
M971%;&5M96YT0GE)9"AT87)G970@*R`G6V1A>5TG*2YV86QU92D["B`@("!]
M(&5L<V4@>PH@("`@("`@('9A<B!D(#T@;F5W($1A=&4H*3L*("`@('T*"B`@
M("!O<&5N1V]T;RAD+F=E=%1I;64H*2P@:6UG260L('1A<F=E="P@8V%L;&)A
M8VLI.PI]"@IF=6YC=&EO;B!O<&5N1V]T;RAT:6UE<W1A;7`L(&EM9TED+"!T
M87)G970L(&-A;&QB86-K*0I["B`@("!V87(@<F]W+"!C96QL+"!I;6<L(&QI
M;FLL(&1A>7,["@H@("`@8W5R<F5N=%1A<F=E="`]('1A<F=E=#L*"B`@("!V
M87(@9"`](&YE=R!$871E*'1I;65S=&%M<"D["B`@("!C=7)R96YT1&%T92`]
M(&0["B`@("!M;VYT:"`](&0N9V5T36]N=&@H*3L*("`@(&-U<G)E;G1996%R
M(#T@9"YG971996%R*"D["B`@("!I9B`H8W5R<F5N=%EE87(@/"`Q.3`P*2![
M"B`@("`@("`@8W5R<F5N=%EE87(@*ST@,3DP,#L*("`@('T*("`@('9A<B!F
M:7)S=$]F36]N=&@@/2!N97<@1&%T92AC=7)R96YT665A<BP@;6]N=&@L(#$I
M.PH@("`@=F%R(&1I9F8@/2!F:7)S=$]F36]N=&@N9V5T1&%Y*"D@+2`Q.PH@
M("`@:68@*&1I9F8@/3T@+3$I('L*("`@("`@("!D:69F(#T@-CL*("`@('T*
M("`@('-W:71C:"`H;6]N=&@I('L*("`@(&-A<V4@,SH*("`@(&-A<V4@-3H*
M("`@(&-A<V4@.#H*("`@(&-A<V4@,3`Z"B`@("`@("`@9&%Y<R`](#,P.PH@
M("`@("`@(&)R96%K.PH*("`@(&-A<V4@,3H*("`@("`@("!I9B`H8W5R<F5N
M=%EE87(@)2`T(#T](#`@)B8@*&-U<G)E;G1996%R("4@,3`P("$](#`@?'P@
M8W5R<F5N=%EE87(@)2`T,#`@/3T@,"DI('L*("`@("`@("`@("`@9&%Y<R`]
M(#(Y.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&1A>7,@/2`R.#L*
M("`@("`@("!]"B`@("`@("`@8G)E86L["@H@("`@9&5F875L=#H*("`@("`@
M("!D87ES(#T@,S$["B`@("`@("`@8G)E86L["B`@("!]"@H@("`@=F%R('=D
M87ES(#T@6PH@("`@("`@("<\/W!H<"!E8VAO(%\H(DUO(BD@/SXG+`H@("`@
M("`@("<\/W!H<"!E8VAO(%\H(E1U(BD@/SXG+`H@("`@("`@("<\/W!H<"!E
M8VAO(%\H(E=E(BD@/SXG+`H@("`@("`@("<\/W!H<"!E8VAO(%\H(E1H(BD@
M/SXG+`H@("`@("`@("<\/W!H<"!E8VAO(%\H(D9R(BD@/SXG+`H@("`@("`@
M("<\/W!H<"!E8VAO(%\H(E-A(BD@/SXG+`H@("`@("`@("<\/W!H<"!E8VAO
M(%\H(E-U(BD@/SXG"B`@("!=.PH@("`@=F%R(&UO;G1H<R`](%L*("`@("`@
M("`G/#]P:'`@96-H;R!?*")*86YU87)Y(BD@/SXG+`H@("`@("`@("<\/W!H
M<"!E8VAO(%\H(D9E8G)U87)Y(BD@/SXG+`H@("`@("`@("<\/W!H<"!E8VAO
M(%\H(DUA<F-H(BD@/SXG+`H@("`@("`@("<\/W!H<"!E8VAO(%\H(D%P<FEL
M(BD@/SXG+`H@("`@("`@("<\/W!H<"!E8VAO(%\H(DUA>2(I(#\^)RP*("`@
M("`@("`G/#]P:'`@96-H;R!?*")*=6YE(BD@/SXG+`H@("`@("`@("<\/W!H
M<"!E8VAO(%\H(DIU;'DB*2`_/B<L"B`@("`@("`@)SP_<&AP(&5C:&\@7R@B
M075G=7-T(BD@/SXG+`H@("`@("`@("<\/W!H<"!E8VAO(%\H(E-E<'1E;6)E
M<B(I(#\^)RP*("`@("`@("`G/#]P:'`@96-H;R!?*")/8W1O8F5R(BD@/SXG
M+`H@("`@("`@("<\/W!H<"!E8VAO(%\H(DYO=F5M8F5R(BD@/SXG+`H@("`@
M("`@("<\/W!H<"!E8VAO(%\H(D1E8V5M8F5R(BD@/SXG"B`@("!=.PH*("`@
M('9A<B!L87EE<B`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=G;W1O)RD[
M"B`@("!I9B`H;&%Y97(N9FER<W1#:&EL9"D@>PH@("`@("`@(&QA>65R+G)E
M;6]V94-H:6QD*&QA>65R+F9I<G-T0VAI;&0I.PH@("`@?0H*("`@('9A<B!T
M86)L92`](&1O8W5M96YT+F-R96%T945L96UE;G0H)U1!0DQ%)RD["B`@("!V
M87(@=&)O9'D@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=40D]$62<I.PH@
M("`@=&%B;&4N87!P96YD0VAI;&0H=&)O9'DI.PH@("`@=&%B;&4N8VQA<W-.
M86UE(#T@)VET96TG.PH@("`@=&%B;&4N8V5L;%-P86-I;F<@/2`P.PH@("`@
M=&%B;&4N8V5L;%!A9&1I;F<@/2`R.PH@("`@=&%B;&4N8F]R9&5R(#T@,#L*
M("`@('1A8FQE+G-T>6QE+G=I9'1H(#T@)V%U=&\G.PH*("`@("\O(%1I=&QE
M(&)A<BX*("`@(')O=R`](&1O8W5M96YT+F-R96%T945L96UE;G0H)U12)RD[
M"B`@("!C96QL(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G5$0G*3L*("`@
M(&-E;&PN8V]L4W!A;B`](#<["B`@("!C96QL+F%L:6=N(#T@)W)I9VAT)SL*
M("`@(&-E;&PN8VQA<W-.86UE(#T@)VAE861E<B<["B`@("!L:6YK(#T@9&]C
M=6UE;G0N8W)E871E16QE;65N="@G02<I.PH@("`@;&EN:RYH<F5F(#T@)R,G
M.PH@("`@;&EN:RYO;F-L:6-K(#T@9G5N8W1I;VXH*0H@("`@>PH@("`@("`@
M('9A<B!L87EE<B`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=G;W1O)RD[
M"B`@("`@("`@;&%Y97(N<W1Y;&4N=FES:6)I;&ET>2`]("=H:61D96XG.PH@
M("`@("`@(&EF("AL87EE<BYF:7)S=$-H:6QD*2!["B`@("`@("`@("`@(&QA
M>65R+G)E;6]V94-H:6QD*&QA>65R+F9I<G-T0VAI;&0I.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"B`@("!I;6<@/2!D;V-U;65N
M="YC<F5A=&5%;&5M96YT*"=)34<G*0H@("`@:6UG+G-R8R`]("<\/W!H<"!E
M8VAO("1'3$]"04Q36R=R96=I<W1R>2==+3YG971);6%G941I<B@G:&]R9&4G
M*2`_/B]C;&]S92YP;F<G.PH@("`@:6UG+F)O<F1E<B`](#`["B`@("!L:6YK
M+F%P<&5N9$-H:6QD*&EM9RD["B`@("!C96QL+F%P<&5N9$-H:6QD*&QI;FLI
M.PH@("`@<F]W+F%P<&5N9$-H:6QD*&-E;&PI.PH@("`@=&)O9'DN87!P96YD
M0VAI;&0H<F]W*3L*"B`@("`O+R!996%R+@H@("`@<F]W(#T@9&]C=6UE;G0N
M8W)E871E16QE;65N="@G5%(G*3L*("`@(&-E;&P@/2!D;V-U;65N="YC<F5A
M=&5%;&5M96YT*"=41"<I.PH@("`@8V5L;"YA;&EG;B`]("=L969T)SL*("`@
M(&QI;FL@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=!)RD["B`@("!L:6YK
M+FAR968@/2`G(R<["B`@("!L:6YK+F]N8VQI8VL@/2!F=6YC=&EO;B@I"B`@
M("!["B`@("`@("`@;F5W1&%T92`](&YE=R!$871E*&-U<G)E;G1996%R("T@
M,2P@8W5R<F5N=$1A=&4N9V5T36]N=&@H*2P@,2D["B`@("`@("`@;W!E;D=O
M=&\H;F5W1&%T92YG9714:6UE*"DL(&EM9TED+"!C=7)R96YT5&%R9V5T+"!C
M86QL8F%C:RD["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H@("`@8V5L
M;"YA<'!E;F1#:&EL9"AL:6YK*3L*("`@(&EM9R`](&1O8W5M96YT+F-R96%T
M945L96UE;G0H)TE-1R<I"B`@("!I;6<N<W)C(#T@)SP_<&AP(&5C:&\@)$=,
M3T)!3%-;)W)E9VES=')Y)UTM/F=E=$EM86=E1&ER*"=H;W)D92<I(#\^+VYA
M=B]L969T+G!N9R<["B`@("!I;6<N86QI9VX@/2`G;6ED9&QE)SL*("`@(&EM
M9RYB;W)D97(@/2`P.PH@("`@;&EN:RYA<'!E;F1#:&EL9"AI;6<I.PH@("`@
M<F]W+F%P<&5N9$-H:6QD*&-E;&PI.PH*("`@(&-E;&P@/2!D;V-U;65N="YC
M<F5A=&5%;&5M96YT*"=41"<I.PH@("`@8V5L;"YC;VQ3<&%N(#T@-3L*("`@
M(&-E;&PN86QI9VX@/2`G8V5N=&5R)SL*("`@('9A<B!Y(#T@9&]C=6UE;G0N
M8W)E871E5&5X=$YO9&4H8W5R<F5N=%EE87(I.PH@("`@8V5L;"YA<'!E;F1#
M:&EL9"AY*3L*("`@(')O=RYA<'!E;F1#:&EL9"AC96QL*3L*"B`@("!C96QL
M(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G5$0G*3L*("`@(&-E;&PN86QI
M9VX@/2`G<FEG:'0G.PH@("`@;&EN:R`](&1O8W5M96YT+F-R96%T945L96UE
M;G0H)T$G*3L*("`@(&QI;FLN:')E9B`]("<C)SL*("`@(&QI;FLN;VYC;&EC
M:R`](&9U;F-T:6]N*"D*("`@('L*("`@("`@("!N97=$871E(#T@;F5W($1A
M=&4H8W5R<F5N=%EE87(@*R`Q+"!C=7)R96YT1&%T92YG971-;VYT:"@I+"`Q
M*3L*("`@("`@("!O<&5N1V]T;RAN97=$871E+F=E=%1I;64H*2P@:6UG260L
M(&-U<G)E;G1487)G970L(&-A;&QB86-K*3L*("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"B`@("!C96QL+F%P<&5N9$-H:6QD*&QI;FLI.PH@("`@:6UG
M(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G24U')RD*("`@(&EM9RYS<F,@
M/2`G/#]P:'`@96-H;R`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T26UA9V5$
M:7(H)VAO<F1E)RD@/SXO;F%V+W)I9VAT+G!N9R<["B`@("!I;6<N86QI9VX@
M/2`G;6ED9&QE)SL*("`@(&EM9RYB;W)D97(@/2`P.PH@("`@;&EN:RYA<'!E
M;F1#:&EL9"AI;6<I.PH@("`@<F]W+F%P<&5N9$-H:6QD*&-E;&PI.PH@("`@
M=&)O9'DN87!P96YD0VAI;&0H<F]W*3L*"B`@("`O+R!-;VYT:"!N86UE+@H@
M("`@<F]W(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G5%(G*3L*("`@(&-E
M;&P@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=41"<I.PH@("`@8V5L;"YA
M;&EG;B`]("=L969T)SL*("`@(&QI;FL@/2!D;V-U;65N="YC<F5A=&5%;&5M
M96YT*"=!)RD["B`@("!L:6YK+FAR968@/2`G(R<["B`@("!L:6YK+F]N8VQI
M8VL@/2!F=6YC=&EO;B@I"B`@("!["B`@("`@("`@=F%R(&YE=TUO;G1H(#T@
M8W5R<F5N=$1A=&4N9V5T36]N=&@H*2`M(#$["B`@("`@("`@=F%R(&YE=UEE
M87(@/2!C=7)R96YT665A<CL*("`@("`@("!I9B`H;F5W36]N=&@@/3T@+3$I
M('L*("`@("`@("`@("`@;F5W36]N=&@@/2`Q,3L*("`@("`@("`@("`@;F5W
M665A<B`M/2`Q.PH@("`@("`@('T*("`@("`@("!N97=$871E(#T@;F5W($1A
M=&4H;F5W665A<BP@;F5W36]N=&@L(#$I.PH@("`@("`@(&]P96Y';W1O*&YE
M=T1A=&4N9V5T5&EM92@I+"!I;6=)9"P@8W5R<F5N=%1A<F=E="P@8V%L;&)A
M8VLI.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*("`@(&-E;&PN87!P
M96YD0VAI;&0H;&EN:RD["B`@("!I;6<@/2!D;V-U;65N="YC<F5A=&5%;&5M
M96YT*"=)34<G*0H@("`@:6UG+G-R8R`]("<\/W!H<"!E8VAO("1'3$]"04Q3
M6R=R96=I<W1R>2==+3YG971);6%G941I<B@G:&]R9&4G*2`_/B]N878O;&5F
M="YP;F<G.PH@("`@:6UG+F%L:6=N(#T@)VUI9&1L92<["B`@("!I;6<N8F]R
M9&5R(#T@,#L*("`@(&QI;FLN87!P96YD0VAI;&0H:6UG*3L*("`@(')O=RYA
M<'!E;F1#:&EL9"AC96QL*3L*"B`@("!C96QL(#T@9&]C=6UE;G0N8W)E871E
M16QE;65N="@G5$0G*3L*("`@(&-E;&PN8V]L4W!A;B`](#4["B`@("!C96QL
M+F%L:6=N(#T@)V-E;G1E<B<["B`@("!V87(@;2`](&1O8W5M96YT+F-R96%T
M951E>'1.;V1E*&UO;G1H<UMM;VYT:%TI.PH@("`@8V5L;"YA<'!E;F1#:&EL
M9"AM*3L*("`@(')O=RYA<'!E;F1#:&EL9"AC96QL*3L*"B`@("!C96QL(#T@
M9&]C=6UE;G0N8W)E871E16QE;65N="@G5$0G*3L*("`@(&-E;&PN86QI9VX@
M/2`G<FEG:'0G.PH@("`@;&EN:R`](&1O8W5M96YT+F-R96%T945L96UE;G0H
M)T$G*3L*("`@(&QI;FLN:')E9B`]("<C)SL*("`@(&QI;FLN;VYC;&EC:R`]
M(&9U;F-T:6]N*"D*("`@('L*("`@("`@("!N97=$871E(#T@;F5W($1A=&4H
M8W5R<F5N=%EE87(L(&-U<G)E;G1$871E+F=E=$UO;G1H*"D@*R`Q+"`Q*3L*
M("`@("`@("!O<&5N1V]T;RAN97=$871E+F=E=%1I;64H*2P@:6UG260L(&-U
M<G)E;G1487)G970L(&-A;&QB86-K*3L*("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("!]"B`@("!C96QL+F%P<&5N9$-H:6QD*&QI;FLI.PH@("`@:6UG(#T@
M9&]C=6UE;G0N8W)E871E16QE;65N="@G24U')RD*("`@(&EM9RYS<F,@/2`G
M/#]P:'`@96-H;R`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T26UA9V5$:7(H
M)VAO<F1E)RD@/SXO;F%V+W)I9VAT+G!N9R<["B`@("!I;6<N86QI9VX@/2`G
M;6ED9&QE)SL*("`@(&EM9RYB;W)D97(@/2`P.PH@("`@;&EN:RYA<'!E;F1#
M:&EL9"AI;6<I.PH@("`@<F]W+F%P<&5N9$-H:6QD*&-E;&PI.PH@("`@=&)O
M9'DN87!P96YD0VAI;&0H<F]W*3L*"B`@("`O+R!7965K9&%Y<RX*("`@(')O
M=R`](&1O8W5M96YT+F-R96%T945L96UE;G0H)U12)RD["B`@("!F;W(@*'9A
M<B!I(#T@,#L@:2`\(#<[(&DK*RD@>PH@("`@("`@(&-E;&P@/2!D;V-U;65N
M="YC<F5A=&5%;&5M96YT*"=41"<I.PH@("`@("`@('=E96MD87D@/2!D;V-U
M;65N="YC<F5A=&5497AT3F]D92AW9&%Y<UMI72D["B`@("`@("`@8V5L;"YA
M<'!E;F1#:&EL9"AW965K9&%Y*3L*("`@("`@("!R;W<N87!P96YD0VAI;&0H
M8V5L;"D["B`@("!]"B`@("!T8F]D>2YA<'!E;F1#:&EL9"AR;W<I.PH*("`@
M("\O(%)O=W,N"B`@("!V87(@=V5E:RP@:71A;&EC.PH@("`@=F%R(&-O=6YT
M(#T@,3L*("`@('9A<B!T;V1A>2`](&YE=R!$871E*"D["B`@("!V87(@=&AI
M<UEE87(@/2!T;V1A>2YG971996%R*"D["B`@("!I9B`H=&AI<UEE87(@/"`Q
M.3`P*2!["B`@("`@("`@=&AI<UEE87(@*ST@,3DP,#L*("`@('T*"B`@("!V
M87(@;V1D(#T@=')U93L*("`@(&9O<B`H=F%R(&D@/2`Q.R!I(#P](&1A>7,[
M(&DK*RD@>PH@("`@("`@(&EF("AC;W5N="`]/2`Q*2!["B`@("`@("`@("`@
M(')O=R`](&1O8W5M96YT+F-R96%T945L96UE;G0H)U12)RD["B`@("`@("`@
M("`@(')O=RYA;&EG;B`]("=R:6=H="<["B`@("`@("`@("`@(&EF("AO9&0I
M('L*("`@("`@("`@("`@("`@(')O=RYC;&%S<TYA;64@/2`G:71E;3`G.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F]W+F-L87-S
M3F%M92`]("=I=&5M,2<["B`@("`@("`@("`@('T*("`@("`@("`@("`@;V1D
M(#T@(6]D9#L*("`@("`@("!]"B`@("`@("`@:68@*&D@/3T@,2D@>PH@("`@
M("`@("`@("!F;W(@*'9A<B!J(#T@,#L@:B`\(&1I9F8[(&HK*RD@>PH@("`@
M("`@("`@("`@("`@8V5L;"`](&1O8W5M96YT+F-R96%T945L96UE;G0H)U1$
M)RD["B`@("`@("`@("`@("`@("!R;W<N87!P96YD0VAI;&0H8V5L;"D["B`@
M("`@("`@("`@("`@("!C;W5N="LK.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@("`@(&-E;&P@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=41"<I
M.PH@("`@("`@(&EF("AT:&ES665A<B`]/2!C=7)R96YT665A<B`F)@H@("`@
M("`@("`@("!T;V1A>2YG971-;VYT:"@I(#T](&UO;G1H("8F"B`@("`@("`@
M("`@('1O9&%Y+F=E=$1A=&4H*2`]/2!I*2!["B`@("`@("`@("`@(&-E;&PN
M<W1Y;&4N8F]R9&5R(#T@)S%P>"!S;VQI9"!R960G.PH@("`@("`@('T*"B`@
M("`@("`@;&EN:R`](&1O8W5M96YT+F-R96%T945L96UE;G0H)T$G*3L*("`@
M("`@("!C96QL+F%P<&5N9$-H:6QD*&QI;FLI.PH*("`@("`@("!L:6YK+FAR
M968@/2!I.PH@("`@("`@(&QI;FLN;VYC;&EC:R`](&9U;F-T:6]N*"D*("`@
M("`@("!["B`@("`@("`@("`@('9A<B!D87D@/2!T:&ES+FAR968["B`@("`@
M("`@("`@('=H:6QE("AD87DN:6YD97A/9B@G+R<I("$]("TQ*2!["B`@("`@
M("`@("`@("`@("!D87D@/2!D87DN<W5B<W1R:6YG*&1A>2YI;F1E>$]F*"<O
M)RD@*R`Q*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@<V5T4V5L96-T
M5F%L=64H9&]C=6UE;G0N9V5T16QE;65N=$)Y260H8W5R<F5N=%1A<F=E="`K
M("=;>65A<ETG*2P@8W5R<F5N=%EE87(I.PH@("`@("`@("`@("!S971396QE
M8W1686QU92AD;V-U;65N="YG971%;&5M96YT0GE)9"AC=7)R96YT5&%R9V5T
M("L@)UMM;VYT:%TG*2P@8W5R<F5N=$1A=&4N9V5T36]N=&@H*2`K(#$I.PH@
M("`@("`@("`@("!S971396QE8W1686QU92AD;V-U;65N="YG971%;&5M96YT
M0GE)9"AC=7)R96YT5&%R9V5T("L@)UMD87E=)RDL(&1A>2D["@H@("`@("`@
M("`@("!V87(@;&%Y97(@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"@G9V]T
M;R<I.PH@("`@("`@("`@("!L87EE<BYS='EL92YV:7-I8FEL:71Y(#T@)VAI
M9&1E;B<["B`@("`@("`@("`@(&EF("AL87EE<BYF:7)S=$-H:6QD*2!["B`@
M("`@("`@("`@("`@("!L87EE<BYR96UO=F5#:&EL9"AL87EE<BYF:7)S=$-H
M:6QD*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*&-A;&QB86-K
M*2!["B`@("`@("`@("`@("`@("!E=F%L*&-A;&QB86-K*3L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@9&%Y(#T@9&]C=6UE;G0N8W)E871E5&5X=$YO9&4H:2D["B`@("`@
M("`@;&EN:RYA<'!E;F1#:&EL9"AD87DI.PH*("`@("`@("!R;W<N87!P96YD
M0VAI;&0H8V5L;"D["B`@("`@("`@:68@*&-O=6YT(#T](#<I('L*("`@("`@
M("`@("`@=&)O9'DN87!P96YD0VAI;&0H<F]W*3L*("`@("`@("`@("`@8V]U
M;G0@/2`P.PH@("`@("`@('T*("`@("`@("!C;W5N="LK.PH@("`@?0H@("`@
M:68@*&-O=6YT(#X@,2D@>PH@("`@("`@(&9O<B`H:2`](&-O=6YT.R!I(#P]
M(#<[(&DK*RD@>PH@("`@("`@("`@("!C96QL(#T@9&]C=6UE;G0N8W)E871E
M16QE;65N="@G5$0G*3L*("`@("`@("`@("`@<F]W+F%P<&5N9$-H:6QD*&-E
M;&PI.PH@("`@("`@('T*("`@("`@("!T8F]D>2YA<'!E;F1#:&EL9"AR;W<I
M.PH@("`@?0H*("`@(&EF("AC=7));6=)9"`A/2!I;6=)9"D@>PH@("`@("`@
M("\O(%=E)W)E('-H;W=I;F<@=&AI<R!P;W!U<"!F;W(@=&AE(&9I<G-T('1I
M;64L('-O('1R>2!T;PH@("`@("`@("\O('!O<VET:6]N(&ET(&YE>'0@=&\@
M=&AE(&EM86=E(&%N8VAO<BX*("`@("`@("!V87(@96P@/2!D;V-U;65N="YG
M971%;&5M96YT0GE)9"AI;6=)9"D["B`@("`@("`@=F%R('`@/2!G971!8G-O
M;'5T95!O<VET:6]N*&5L*3L*"B`@("`@("`@;&%Y97(N<W1Y;&4N;&5F="`]
M('`N>"`K("=P>"<["B`@("`@("`@;&%Y97(N<W1Y;&4N=&]P(#T@<"YY("L@
M)W!X)SL*("`@('T*"B`@("!C=7));6=)9"`](&EM9TED.PH@("`@;&%Y97(N
M87!P96YD0VAI;&0H=&%B;&4I.PH*("`@(&QA>65R+G-T>6QE+F1I<W!L87D@
M/2`G8FQO8VLG.PH@("`@;&%Y97(N<W1Y;&4N=FES:6)I;&ET>2`]("=V:7-I
M8FQE)SL*?0H*9G5N8W1I;VX@9V5T06)S;VQU=&50;W-I=&EO;BAE;"D*>PH@
M("`@=F%R('(@/2![>#H@96PN;V9F<V5T3&5F="P@>3H@96PN;V9F<V5T5&]P
M?3L*("`@(&EF("AE;"YO9F9S971087)E;G0I('L*("`@("`@("!V87(@=&UP
M(#T@9V5T06)S;VQU=&50;W-I=&EO;BAE;"YO9F9S971087)E;G0I.PH@("`@
M("`@('(N>"`K/2!T;7`N>#L*("`@("`@("!R+GD@*ST@=&UP+GD["B`@("!]
M"B`@("!R971U<FX@<CL*?0H*9G5N8W1I;VX@<V5T4V5L96-T5F%L=64H<V5L
M96-T+"!V86QU92D*>PH@("`@<V5L96-T+G9A;'5E(#T@=F%L=64["B`@("!I
M9B`H<V5L96-T+G9A;'5E("$]('9A;'5E*2!["B`@("`@("`@9F]R("AI(#T@
M,#L@:2`\('-E;&5C="YO<'1I;VYS+FQE;F=T:#L@:2LK*2!["B`@("`@("`@
M("`@(&EF("AS96QE8W0N;W!T:6]N<UMI72YV86QU92`]/2!V86QU92D@>PH@
M("`@("`@("`@("`@("`@<V5L96-T+G-E;&5C=&5D26YD97@@/2!I.PH@("`@
M("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("!]"@H@("`@<F5T=7)N(&9A;'-E.PI]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L
M871E<R]J879A<V-R:7!T+VME>6)I;F1I;F=S+FIS````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P-#<R,"`Q,#4Q-30S,S<T-2`P,C0U-34`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+RHJ"B`J($IA=F%S
M8W)I<'0@;&EB<F%R>2!T;R!H86YD;&4@82!S970@;V8@:V5Y8FEN9&EN9W,N
M"B`J"B`J(%1H92!U<V5R('-H;W5L9"!I;F-L=61E('1H:7,@<V-R:7!T+"!A
M;F0@=&AE;B!C86QL('-E=$ME>6)I;F1I;F<H:V5Y+`H@*B!C86QL8F%C:RD@
M9F]R(&5A8V@@:V5Y8FEN9&EN9R!T:&%T(&ES(&1E<VER960N(%1H:7,@<V-R
M:7!T('=I;&P@=&%K92!C87)E"B`J(&]F(&QI<W1E;FEN9R!F;W(@:V5Y<')E
M<W-E<R!A;F0@;6%P<&EN9R!T:&5M('1O('1H92!C86QL8F%C:R!F=6YC=&EO
M;G,L(&]R"B`J(&1O:6YG(&YO=&AI;F<@:68@;F\@8V%L;&)A8VL@:7,@<V5T
M+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+W1E;7!L871E<R]J879A<V-R:7!T+VME
M>6)I;F1I;F=S+FIS+'8@,2XU+C0N-B`R,#`V+S`S+S(T(#$V.C`U.C(T(&-H
M=6-K($5X<"`D"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9`H@
M*B!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`<&%C:V%G92!(;W)D90H@
M*B\*"B\J*@H@*B!!(&AA<V@@;V8@:V5Y8FEN9&EN9W,N"B`J"B`J($!V87(@
M7VME>4UA<`H@*B\*=F%R(%]K97E-87`@/2!N97<@07)R87DH*3L*"B\J*@H@
M*B!3970@=7`@=&AE(&ME>7!R97-S(&QI<W1E;F5R+@H@*B\*:68@*'1Y<&5O
M9B!D;V-U;65N="YC87!T=7)E179E;G1S("$]("=U;F1E9FEN960G*2!["B`@
M("!D;V-U;65N="YC87!T=7)E179E;G1S*$5V96YT+DM%65!215-3*3L*("`@
M(&1O8W5M96YT+F]N:V5Y<')E<W,@/2!K97E(86YD;&5R.PI](&5L<V4@>PH@
M("`@9&]C=6UE;G0N;VYK97ED;W=N(#T@:V5Y2&%N9&QE<CL*?0H*+RHJ"B`J
M(%-E=',@=7`@82!C86QL8F%C:R!F;W(@82!K97EC;V1E+@H@*@H@*B!`<&%R
M86T@:V5Y("`@("`@(%1H92!K97EC;V1E('1O('1R:6=G97(@;VXN"B`J($!P
M87)A;2!C86QL8F%C:R`@5&AE(&9U;F-T:6]N('1O(&-A;&P@=VAE;B`B:V5Y
M(B!I<R!P<F5S<V5D+B!3:&]U;&0@8F4@80H@*B`@("`@("`@("`@("`@("`@
M(&9U;F-T:6]N+B!)="!G971S('1H92!E=F5N="!A;F0@=&AE(&ME>6-O9&4@
M87,@<&%R86UE=&5R<RP*("H@("`@("`@("`@("`@("`@("!S;R!T:&%T('EO
M=2!C86X@=7-E(&]N92!F=6YC=&EO;B!T;R!H86YD;&4@;75L=&EP;&4@:V5Y
M<R!I9@H@*B`@("`@("`@("`@("`@("`@('EO=2!L:6ME+@H@*B\*9G5N8W1I
M;VX@<V5T2V5Y8FEN9&EN9RAK97DL(&-A;&QB86-K*0I["B`@("!I9B`H='EP
M96]F(%]K97E-87!;:V5Y72`]/2`G=6YD969I;F5D)RD@>PH@("`@("`@(%]K
M97E-87!;:V5Y72`](%M=.PH@("`@?0H*("`@(&EF("AT>7!E;V8@8V%L;&)A
M8VL@/3T@)V9U;F-T:6]N)RD@>PH@("`@("`@(%]K97E-87!;:V5Y72YP=7-H
M*&-A;&QB86-K*3L*("`@('T@96QS92!["B`@("`@("`@7VME>4UA<%MK97E=
M+G!U<V@H;F5W($9U;F-T:6]N*"=E)RP@)VME>2<L(&-A;&QB86-K("L@)RAE
M+"!K97DI.R<I*3L*("`@('T*?0H*+RHJ"B`J($EN=F]K960@8GD@=&AE($IA
M=F%38W)I<'0@979E;G0@;6]D96P@=VAE;B!A(&ME>2!I<R!P<F5S<V5D+B!'
M971S"B`J('1H92!K97EC;V1E("AA='1E;7!T<R!T;R!H86YD;&4@86QL(&)R
M;W=S97)S*2!A;F0@;&]O:W,@=&\@<V5E(&EF"B`J('=E(&AA=F4@82!H86YD
M;&5R(&1E9FEN960@9F]R('1H870@:V5Y+B!)9B!S;RP@8V%L;"!I="X*("H*
M("H@0'!A<F%M(&4@(%1H92!E=F5N="!T;R!H86YD;&4N(%-H;W5L9"!B92!A
M(&ME>7!R97-S+@H@*B\*9G5N8W1I;VX@:V5Y2&%N9&QE<BAE*0I["B`@("!V
M87(@92`](&4@?'P@=VEN9&]W+F5V96YT.PH*("`@(&EF("AE+FME>4-O9&4I
M('L*("`@("`@("!K97D@/2!E+FME>4-O9&4["B`@("!](&5L<V4@:68@*&4N
M=VAI8V@I('L*("`@("`@("!K97D@/2!E+G=H:6-H.PH@("`@?0H*("`@("\J
M($EF('1H97)E)W,@82!H86YD;&5R(&1E9FEN960@9F]R('1H92!K97D@=&AA
M="!W87,@<')E<W-E9"P@8V%L;`H@("`@("H@:70L('!A<W-I;F<@:6X@=&AE
M(&ME>6-O9&4@86YD('1H92!E=F5N="X@*B\*("`@(&EF("A?:V5Y36%P6VME
M>5TI('L*("`@("`@("!F;W(@*'9A<B!I(#T@,#L@:2`\(%]K97E-87!;:V5Y
M72YL96YG=&@[("LK:2D@>PH@("`@("`@("`@("!I9B`H7VME>4UA<%MK97E=
M6VE=*&4L(&ME>2DI('L*("`@("`@("`@("`@("`@(&4N<F5T=7)N5F%L=64@
M/2!F86QS93L*("`@("`@("`@("`@("`@(&EF("AT>7!E;V8@92YP<F5V96YT
M1&5F875L="`]/2`G9G5N8W1I;VXG*2!["B`@("`@("`@("`@("`@("`@("`@
M92YP<F5V96YT1&5F875L="@I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("!E+G)E='5R;E9A;'5E(#T@=')U93L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@?0I]"@``````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,34W-B`Q,#4Q-30S,S<T-2`P,C0U
M-3``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+RHJ"B`J("1(;W)D93H@:&]R9&4O=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O
M=&5";&]C:W,N:G,L=B`Q+C4@,C`P-"\P."\R-B`P,#HP-SHR.2!S;'5S87)Z
M($5X<"`D"B`J"B`J($!P86-K86=E($AO<F1E"B`J+PIF=6YC=&EO;B!T;V=G
M;&51=6]T94)L;V-K*&ED+"!L:6YE<RD*>PH@("`@=F%R(&)L;V-K(#T@;F5W
M($AO<F1E7TAI9&5A8FQE*"=Q8E\G("L@:60I.PH*("`@(&)L;V-K+G1O9V=L
M92@I.PH@("`@=&5X="`](&1O8W5M96YT+F-R96%T951E>'1.;V1E*&)L;V-K
M+G-H;W=N*"D@/PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("<\/W!H<"!E8VAO(%\H(EM(:61E(%%U;W1E9"!497AT72(I(#\^)R`Z"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)SP_<&AP(&5C:&\@
M7R@B6U-H;W<@475O=&5D(%1E>'0@+2(I(#\^("<@*R!L:6YE<R`K("<@/#]P
M:'`@96-H;R!?*")L:6YE<UTB*2`_/B<I.PH@("`@;&EN:R`](&1O8W5M96YT
M+F-R96%T945L96UE;G0H)T$G*3L*("`@(&QI;FLN:')E9B`]("<G.PH@("`@
M;&EN:RYC;&%S<TYA;64@/2`G=VED9V5T)SL*("`@(&QI;FLN<W1Y;&4N9F]N
M=%-I>F4@/2`G-S`E)SL*("`@(&QI;FLN;VYC;&EC:R`](&9U;F-T:6]N*"D@
M>PH@("`@("`@('1O9V=L95%U;W1E0FQO8VLH:60L(&QI;F5S*3L*("`@("`@
M("!R971U<FX@9F%L<V4["B`@("!]"B`@("!L:6YK+F%P<&5N9$-H:6QD*'1E
M>'0I.PH*("`@('9A<B!T;V=G;&4@/2!D;V-U;65N="YG971%;&5M96YT0GE)
M9"@G<71?)R`K(&ED*3L*("`@(&EF("AT;V=G;&4N9FER<W1#:&EL9"D@>PH@
M("`@("`@('1O9V=L92YR96UO=F5#:&EL9"AT;V=G;&4N9FER<W1#:&EL9"D[
M"B`@("!]"B`@("!T;V=G;&4N87!P96YD0VAI;&0H;&EN:RD["GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R,C4U,B`Q,#4Q-30S,S<T
M-2`P,C4P-3``(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````2%1-3$%R96$N23$X3B`]('L*"@DO+R!T:&4@9F]L;&]W:6YG('-H
M;W5L9"!B92!T:&4@9FEL96YA;64@=VET:&]U="`N:G,@97AT96YS:6]N"@DO
M+R!I="!W:6QL(&)E('5S960@9F]R(&%U=&]M871I8V%L;'D@;&]A9"!P;'5G
M:6X@;&%N9W5A9V4N"@EL86YG.B`B96XB+`H*"71O;VQT:7!S.B!["@D)8F]L
M9#H@("`@("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B0F]L9"(I
M*2`_/B(L"@D):71A;&EC.B`@("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B271A;&EC(BDI(#\^(BP*"0EU;F1E<FQI;F4Z("`@("`@(CP_<&AP
M(&5C:&\@861D<VQA<VAE<RA?*")5;F1E<FQI;F4B*2D@/SXB+`H)"7-T<FEK
M971H<F]U9V@Z("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E-T<FEK971H
M<F]U9V@B*2D@/SXB+`H)"7-U8G-C<FEP=#H@("`@("`B/#]P:'`@96-H;R!A
M9&1S;&%S:&5S*%\H(E-U8G-C<FEP="(I*2`_/B(L"@D)<W5P97)S8W)I<'0Z
M("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4W5P97)S8W)I<'0B*2D@
M/SXB+`H)"6IU<W1I9GEL969T.B`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S
M*%\H(DIU<W1I9GD@3&5F="(I*2`_/B(L"@D):G5S=&EF>6-E;G1E<CH@("(\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B2G5S=&EF>2!#96YT97(B*2D@/SXB
M+`H)"6IU<W1I9GER:6=H=#H@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H
M(DIU<W1I9GD@4FEG:'0B*2D@/SXB+`H)"6IU<W1I9GEF=6QL.B`@("`B/#]P
M:'`@96-H;R!A9&1S;&%S:&5S*%\H(DIU<W1I9GD@1G5L;"(I*2`_/B(L"@D)
M;W)D97)E9&QI<W0Z("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B3W)D
M97)E9"!,:7-T(BDI(#\^(BP*"0EU;F]R9&5R961L:7-T.B`@(CP_<&AP(&5C
M:&\@861D<VQA<VAE<RA?*")"=6QL971E9"!,:7-T(BDI(#\^(BP*"0EO=71D
M96YT.B`@("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")$96-R96%S
M92!);F1E;G0B*2D@/SXB+`H)"6EN9&5N=#H@("`@("`@("`B/#]P:'`@96-H
M;R!A9&1S;&%S:&5S*%\H(DEN8W)E87-E($EN9&5N="(I*2`_/B(L"@D)9F]R
M96-O;&]R.B`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B1F]N="!#
M;VQO<B(I*2`_/B(L"@D):&EL:71E8V]L;W(Z("`@("(\/W!H<"!E8VAO(&%D
M9'-L87-H97,H7R@B0F%C:V=R;W5N9"!#;VQO<B(I*2`_/B(L"@D):6YS97)T
M:&]R:7IO;G1A;')U;&4Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B2&]R
M:7IO;G1A;"!2=6QE(BDI(#\^(BP*"0EC<F5A=&5L:6YK.B`@("`@(CP_<&AP
M(&5C:&\@861D<VQA<VAE<RA?*"));G-E<G0@5V5B($QI;FLB*2D@/SXB+`H)
M"6EN<V5R=&EM86=E.B`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEN
M<V5R="]-;V1I9GD@26UA9V4B*2D@/SXB+`H)"6EN<V5R='1A8FQE.B`@("`B
M/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEN<V5R="!486)L92(I*2`_/B(L
M"@D):'1M;&UO9&4Z("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B
M5&]G9VQE($A434P@4V]U<F-E(BDI(#\^(BP*"0EP;W!U<&5D:71O<CH@("`@
M(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")%;FQA<F=E($5D:71O<B(I*2`_
M/B(L"@D)86)O=70Z("`@("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H
M7R@B06)O=70@=&AI<R!E9&ET;W(B*2D@/SXB+`H)"7-H;W=H96QP.B`@("`@
M("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DAE;'`@=7-I;F<@961I=&]R
M(BDI(#\^(BP*"0ET97AT:6YD:6-A=&]R.B`@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")#=7)R96YT('-T>6QE(BDI(#\^(BP*"0EU;F1O.B`@("`@("`@
M("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")5;F1O97,@>6]U<B!L87-T
M(&%C=&EO;B(I*2`_/B(L"@D)<F5D;SH@("`@("`@("`@("(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB*2D@/SXB
M+`H)"6-U=#H@("`@("`@("`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H
M(D-U="!S96QE8W1I;VXB*2D@/SXB+`H)"6-O<'DZ("`@("`@("`@("`B/#]P
M:'`@96-H;R!A9&1S;&%S:&5S*%\H(D-O<'D@<V5L96-T:6]N(BDI(#\^(BP*
M"0EP87-T93H@("`@("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")0
M87-T92!F<F]M(&-L:7!B;V%R9"(I*2`_/B(L"@D);&5F='1O<FEG:'0Z("`@
M("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B1&ER96-T:6]N(&QE9G0@=&\@
M<FEG:'0B*2D@/SXB+`H)"7)I9VAT=&]L969T.B`@("`B/#]P:'`@96-H;R!A
M9&1S;&%S:&5S*%\H(D1I<F5C=&EO;B!R:6=H="!T;R!L969T(BDI(#\^(BP*
M"0ER96UO=F5F;W)M870Z("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")2
M96UO=F4@9F]R;6%T=&EN9R(I*2`_/B(L"@D)<')I;G0Z("`@("`@("`@("(\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4')I;G0@9&]C=6UE;G0B*2D@/SXB
M+`H)"6MI;&QW;W)D.B`@("`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H
M(D-L96%R($U33V9F:6-E('1A9W,B*2D@/SXB"@E]+`H*"6)U='1O;G,Z('L*
M"0DB;VLB.B`@("`@("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")/
M2R(I*2`_/B(L"@D)(F-A;F-E;"(Z("`@("`@("(\/W!H<"!E8VAO(&%D9'-L
M87-H97,H7R@B0V%N8V5L(BDI(#\^(@H)?2P*"@EM<V<Z('L*"0DB4&%T:"(Z
M("`@("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")0871H(BDI(#\^
M(BP*"0DB5$585%]-3T1%(CH@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?
M*")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@
M=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB*2D@/SXB+`H*"0DB244M<W5C
M:W,M9G5L;"US8W)E96XB(#H*"0DO+R!T<F%N<VQA=&4@:&5R90H)"2(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@
M:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E
M<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T
M;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D
M:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O
M;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S
M(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R
M86P@4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<
M;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E('!R97-S($]+(&EF('EO
M=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(I
M*2`_/B(L"@H)"2)-;WHM0VQI<&)O87)D(B`Z"@D)(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*")5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S
M($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I='D@
M<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T
M(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S
M8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(BDI(#\^(@H)?2P*"@ED
M:6%L;V=S.B!["@D)+R\@0V]M;6]N"@D)(D]+(B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@
M861D<VQA<VAE<RA?*")/2R(I*2`_/B(L"@D)(D-A;F-E;"(@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C
M:&\@861D<VQA<VAE<RA?*")#86YC96PB*2D@/SXB+`H*"0DB06QI9VYM96YT
M.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B
M/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D%L:6=N;65N=#HB*2D@/SXB+`H)
M"2).;W0@<V5T(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B3F]T('-E="(I
M*2`_/B(L"@D)(DQE9G0B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"),
M969T(BDI(#\^(BP*"0DB4FEG:'0B("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S
M*%\H(E)I9VAT(BDI(#\^(BP*"0DB5&5X='1O<"(@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S
M;&%S:&5S*%\H(E1E>'1T;W`B*2D@/SXB+`H)"2)!8G-M:61D;&4B("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E
M8VAO(&%D9'-L87-H97,H7R@B06)S;6ED9&QE(BDI(#\^(BP*"0DB0F%S96QI
M;F4B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D)A<V5L:6YE(BDI(#\^(BP*
M"0DB06)S8F]T=&]M(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D%B<V)O='1O
M;2(I*2`_/B(L"@D)(D)O='1O;2(@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?
M*")";W1T;VTB*2D@/SXB+`H)"2)-:61D;&4B("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L
M87-H97,H7R@B36ED9&QE(BDI(#\^(BP*"0DB5&]P(B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H
M;R!A9&1S;&%S:&5S*%\H(E1O<"(I*2`_/B(L"@H)"2),87EO=70B("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B3&%Y;W5T(BDI(#\^(BP*"0DB4W!A8VEN
M9R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E-P86-I;F<B*2D@/SXB+`H)
M"2)(;W)I>F]N=&%L.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B2&]R:7IO;G1A
M;#HB*2D@/SXB+`H)"2)(;W)I>F]N=&%L('!A9&1I;F<B("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H
M7R@B2&]R:7IO;G1A;"!P861D:6YG(BDI(#\^(BP*"0DB5F5R=&EC86PZ(B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P
M:'`@96-H;R!A9&1S;&%S:&5S*%\H(E9E<G1I8V%L.B(I*2`_/B(L"@D)(E9E
M<G1I8V%L('!A9&1I;F<B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")697)T:6-A;"!P861D
M:6YG(BDI(#\^(BP*"0DB0F]R9&5R('1H:6-K;F5S<SHB("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S
M*%\H(D)O<F1E<B!T:&EC:VYE<W,Z(BDI(#\^(BP*"0DB3&5A=F4@96UP='D@
M9F]R(&YO(&)O<F1E<B(@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P
M:'`@96-H;R!A9&1S;&%S:&5S*%\H(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D
M97(B*2D@/SXB+`H*"0DO+R!);G-E<G0@3&EN:PH)"2));G-E<G0O36]D:69Y
M($QI;FLB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B26YS97)T+TUO9&EF>2!,:6YK(BDI(#\^
M(BP*"0DB3F]N92`H=7-E(&EM<&QI8VET*2(@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DYO;F4@
M*'5S92!I;7!L:6-I="DB*2D@/SXB+`H)"2).97<@=VEN9&]W("A?8FQA;FLI
M(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B3F5W('=I;F1O=R`H7V)L86YK*2(I*2`_/B(L"@D)
M(E-A;64@9G)A;64@*%]S96QF*2(@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")386UE(&9R86UE
M("A?<V5L9BDB*2D@/SXB+`H)"2)4;W`@9G)A;64@*%]T;W`I(B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L
M87-H97,H7R@B5&]P(&9R86UE("A?=&]P*2(I*2`_/B(L"@D)(D]T:&5R(B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")/=&AE<B(I*2`_/B(L"@D)(E1A
M<F=E=#HB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")487)G970Z(BDI(#\^
M(BP*"0DB5&ET;&4@*'1O;VQT:7`I.B(@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E1I=&QE
M("AT;V]L=&EP*3HB*2D@/SXB+`H)"2)54DPZ(B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D
M9'-L87-H97,H7R@B55),.B(I*2`_/B(L"@D)(EEO=2!M=7-T(&5N=&5R('1H
M92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(@(#H@(CP_<&AP(&5C
M:&\@861D<VQA<VAE<RA?*")9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E
M('1H:7,@;&EN:R!P;VEN=',@=&\B*2D@/SXB+`H)"2\O($EN<V5R="!486)L
M90H)"2));G-E<G0@5&%B;&4B("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B26YS97)T
M(%1A8FQE(BDI(#\^(BP*"0DB4F]W<SHB("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S
M:&5S*%\H(E)O=W,Z(BDI(#\^(BP*"0DB3G5M8F5R(&]F(')O=W,B("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A
M9&1S;&%S:&5S*%\H(DYU;6)E<B!O9B!R;W=S(BDI(#\^(BP*"0DB0V]L<SHB
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D-O;',Z(BDI(#\^(BP*"0DB
M3G5M8F5R(&]F(&-O;'5M;G,B("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DYU;6)E<B!O9B!C
M;VQU;6YS(BDI(#\^(BP*"0DB5VED=&@Z(B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S
M:&5S*%\H(E=I9'1H.B(I*2`_/B(L"@D)(E=I9'1H(&]F('1H92!T86)L92(@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@
M861D<VQA<VAE<RA?*")7:61T:"!O9B!T:&4@=&%B;&4B*2D@/SXB+`H)"2)0
M97)C96YT(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4&5R8V5N="(I*2`_
M/B(L"@D)(E!I>&5L<R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")0:7AE
M;',B*2D@/SXB+`H)"2)%;2(@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H
M7R@B16TB*2D@/SXB+`H)"2)7:61T:"!U;FET(B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B5VED=&@@=6YI="(I*2`_/B(L"@D)(E!O<VET:6]N:6YG(&]F('1H
M:7,@=&%B;&4B("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C
M:&\@861D<VQA<VAE<RA?*")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(BDI
M(#\^(BP*"0DB0V5L;"!S<&%C:6YG.B(@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D-E
M;&P@<W!A8VEN9SHB*2D@/SXB+`H)"2)3<&%C92!B971W965N(&%D:F%C96YT
M(&-E;&QS(B`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D
M9'-L87-H97,H7R@B4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(I*2`_
M/B(L"@D)(D-E;&P@<&%D9&EN9SHB("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")#96QL
M('!A9&1I;F<Z(BDI(#\^(BP*"0DB4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N
M9"!B;W)D97(@:6X@8V5L;"(@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S
M;&%S:&5S*%\H(E-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN
M(&-E;&PB*2D@/SXB+`H)"2\O($EN<V5R="!);6%G90H)"2));G-E<G0@26UA
M9V4B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B26YS97)T($EM86=E(BDI(#\^(BP*
M"0DB26UA9V4@55),.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEM86=E(%52
M3#HB*2D@/SXB+`H)"2)%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B("`@("`@
M("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H
M7R@B16YT97(@=&AE(&EM86=E(%523"!H97)E(BDI(#\^(BP*"0DB4')E=FEE
M=R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E!R979I97<B*2D@/SXB+`H)
M"2)0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B("`@("`@("`@
M("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4')E=FEE=R!T
M:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(BDI(#\^(BP*"0DB06QT97)N871E
M('1E>'0Z(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B
M/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D%L=&5R;F%T92!T97AT.B(I*2`_
M/B(L"@D)(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S
M(B`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")&;W(@
M8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(I*2`_/B(L"@D)
M(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B("`@("`@("`@("`@("`@("`@
M("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")0;W-I=&EO;FEN
M9R!O9B!T:&ES(&EM86=E(BDI(#\^(BP*"0DB26UA9V4@4')E=FEE=SHB("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H
M;R!A9&1S;&%S:&5S*%\H(DEM86=E(%!R979I97<Z(BDI(#\^(@H)?0I].PH`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,`````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,30R,34@,3`U,34T,S,W-#4@,#(V-C$Q`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"\O($DQ.$X@8V]N<W1A
M;G1S"@HO+R!,04Y'.B`B96XB+"!%3D-/1$E.1SH@551&+3@@?"!)4T\M.#@U
M.2TQ"B\O($%U=&AO<CH@36EH86D@0F%Z;VXL(&AT='`Z+R]D>6YA<F-H+F-O
M;2]M:7-H;V\*"B\O($9/4B!44D%.4TQ!5$]24SH*+R\*+R\@("`Q+B!03$5!
M4T4@4%54(%E/55(@0T].5$%#5"!)3D9/($E.(%1(12!!0D]612!,24Y%"B\O
M("`@("`@*&%T(&QE87-T(&$@=F%L:60@96UA:6P@861D<F5S<RD*+R\*+R\@
M("`R+B!03$5!4T4@5%)9(%1/(%5312!55$8M."!&3U(@14Y#3T1)3D<["B\O
M("`@("`@*&EF('1H:7,@:7,@;F]T('!O<W-I8FQE+"!P;&5A<V4@:6YC;'5D
M92!A(&-O;6UE;G0*+R\@("`@("`@=&AA="!S=&%T97,@=VAA="!E;F-O9&EN
M9R!I<R!N96-E<W-A<GDN*0H*0V]N=&5X=$UE;G4N23$X3B`]('L*"2\O($ET
M96US('1H870@87!P96%R(&EN(&UE;G4N("!0;&5A<V4@;F]T92!T:&%T(&%N
M('5N9&5R<V-O<F4@*%\I"@DO+R!C:&%R86-T97(@:6X@=&AE('1R86YS;&%T
M:6]N("AR:6=H="!C;VQU;6XI('=I;&P@8V%U<V4@=&AE(&9O;&QO=VEN9PH)
M+R\@;&5T=&5R('1O(&)E8V]M92!U;F1E<FQI;F5D(&%N9"!B92!S:&]R=&-U
M="!F;W(@=&AA="!M96YU(&]P=&EO;BX*"@DB0W5T(B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP
M(&5C:&\@861D<VQA<VAE<RA?*")#=70B*2D@/SXB+`H)(D-O<'DB("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z
M("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B0V]P>2(I*2`_/B(L"@DB4&%S
M=&4B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")087-T92(I*2`_
M/B(L"@DB26UA9V4@4')O<&5R=&EE<R(@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")?
M26UA9V4@4')O<&5R=&EE<RXN+B(I*2`_/B(L"@DB36]D:69Y($QI;FLB("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_
M<&AP(&5C:&\@861D<VQA<VAE<RA?*")?36]D:69Y($QI;FLN+BXB*2D@/SXB
M+`H)(D-H96-K($QI;FLB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B0VAE
M8U]K($QI;FLN+BXB*2D@/SXB+`H)(E)E;6]V92!,:6YK(B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B7U)E;6]V92!,:6YK+BXN(BDI(#\^(BP*"2)#96QL
M(%!R;W!E<G1I97,B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D-?96QL(%!R;W!E
M<G1I97,N+BXB*2D@/SXB+`H)(E)O=R!0<F]P97)T:65S(B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D
M9'-L87-H97,H7R@B4F]?=R!0<F]P97)T:65S+BXN(BDI(#\^(BP*"2));G-E
M<G0@4F]W($)E9F]R92(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DE?;G-E<G0@4F]W
M($)E9F]R92(I*2`_/B(L"@DB26YS97)T(%)O=R!!9G1E<B(@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*"));E]S97)T(%)O=R!!9G1E<B(I*2`_/B(L"@DB1&5L971E
M(%)O=R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")?1&5L971E(%)O=R(I
M*2`_/B(L"@DB1&5L971E($-E;&PB("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?
M*")$96QE=&4@0V5L;"(I*2`_/B(L"@DB5&%B;&4@4')O<&5R=&EE<R(@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C
M:&\@861D<VQA<VAE<RA?*")?5&%B;&4@4')O<&5R=&EE<RXN+B(I*2`_/B(L
M"@DB26YS97)T($-O;'5M;B!"969O<F4B("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"));G-E
M<G0@7T-O;'5M;B!"969O<F4B*2D@/SXB+`H)(DEN<V5R="!#;VQU;6X@069T
M97(B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B26YS97)T($-?;VQU;6X@069T97(B*2D@
M/SXB+`H)(D1E;&5T92!#;VQU;6XB("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B
M1&5?;&5T92!#;VQU;6XB*2D@/SXB+`H)(DIU<W1I9GD@3&5F="(@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E
M8VAO(&%D9'-L87-H97,H7R@B2G5S=&EF>2!,969T(BDI(#\^(BP*"2)*=7-T
M:69Y($-E;G1E<B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DIU<W1I9GD@0V5N
M=&5R(BDI(#\^(BP*"2)*=7-T:69Y(%)I9VAT(B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S
M:&5S*%\H(DIU<W1I9GD@4FEG:'0B*2D@/SXB+`H)(DIU<W1I9GD@1G5L;"(@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B2G5S=&EF>2!&=6QL(BDI(#\^(BP*
M"2)-86ME(&QI;FLB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DUA:V4@
M;&EN7VLN+BXB*2D@/SXB+`H)(E)E;6]V92!T:&4B("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D
M9'-L87-H97,H7R@B4F5M;W9E('1H92(I*2`_/B(L"@DB16QE;65N="(@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")%;&5M96YT+BXN(BDI(#\^(BP*
M"2));G-E<G0@<&%R86=R87!H(&)E9F]R92(@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEN<V5R
M="!P87)A9W)A<&@@8F5F;W)E(BDI(#\^(BP*"2));G-E<G0@<&%R86=R87!H
M(&%F=&5R(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P
M:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEN<V5R="!P87)A9W)A<&@@869T97(B
M*2D@/SXB+`H*"2\O($]T:&5R(&QA8F5L<R`H=&]O;'1I<',@86YD(&%L97)T
M+V-O;F9I<FT@8F]X(&UE<W-A9V5S*0H*"2)0;&5A<V4@8V]N9FER;2!T:&%T
M('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(B`@.B`B/#]P:'`@
M96-H;R!A9&1S;&%S:&5S*%\H(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A
M;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB*2D@/SXB+`H)(E)E;6]V92!T
M:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B("`@("`@("`@("`@("`@("`@
M("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4F5M;W9E('1H:7,@;F]D
M92!F<F]M('1H92!D;V-U;65N="(I*2`_/B(L"@DB2&]W(&1I9"!Y;W4@9V5T
M(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB("`@("`@("`@("`@("`@(#H@(CP_
M<&AP(&5C:&\@861D<VQA<VAE<RA?*")(;W<@9&ED('EO=2!G970@:&5R93\@
M*%!L96%S92!R97!O<G0A*2(I*2`_/B(L"@DB4VAO=R!T:&4@:6UA9V4@<')O
M<&5R=&EE<R!D:6%L;V<B("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP
M(&5C:&\@861D<VQA<VAE<RA?*")3:&]W('1H92!I;6%G92!P<F]P97)T:65S
M(&1I86QO9R(I*2`_/B(L"@DB36]D:69Y(%523"(@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*")-;V1I9GD@55),(BDI(#\^(BP*"2)#=7)R96YT(%523"!I
M<R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B
M/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D-U<G)E;G0@55),(&ES(BDI(#\^
M(BP*"2)/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W(B`@("`@("`@
M("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D]P
M96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B*2D@/SXB+`H)(E!L96%S
M92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N
M="XB("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4&QE87-E(&-O;F9I
M<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(I*2`_
M/B(L"@DB3&EN:R!P;VEN=',@=&\Z(B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"),
M:6YK('!O:6YT<R!T;SHB*2D@/SXB+`H)(E5N;&EN:R!T:&4@8W5R<F5N="!E
M;&5M96YT(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E
M8VAO(&%D9'-L87-H97,H7R@B56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B
M*2D@/SXB+`H)(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L
M;V<B("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H
M7R@B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9R(I*2`_
M/B(L"@DB4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(B`@
M("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")3
M:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B*2D@/SXB+`H)
M(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(@("`@
M("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B26YS97)T
M(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(BDI(#\^(BP*"2))
M;G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(@("`@("`@
M("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEN<V5R="!A
M(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(BDI(#\^(BP*"2)$96QE
M=&4@=&AE(&-U<G)E;G0@<F]W(B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D1E;&5T92!T:&4@
M8W5R<F5N="!R;W<B*2D@/SXB+`H)(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I
M97,@9&EA;&]G(B`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L
M;V<B*2D@/SXB+`H)(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C
M=7)R96YT(&]N92(@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@
M;VYE(BDI(#\^(BP*"2));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C
M=7)R96YT(&]N92(@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S
M:&5S*%\H(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@
M;VYE(BDI(#\^(BP*"2)$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S
M:&5S*%\H(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB*2D@/SXB+`H)(D-R
M96%T92!A(&QI;FLB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B0W)E871E(&$@
M;&EN:R(I*2`_/B(L"@DB26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@
M8W5R<F5N="!N;V1E(B`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*"));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT
M(&YO9&4B*2D@/SXB+`H)(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@
M8W5R<F5N="!N;V1E(B`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L
M87-H97,H7R@B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT
M(&YO9&4B*2D@/SXB"GT["@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&5M<&QA=&5S+W!O<G1A;```````````````````````````````
M`````````````````````````````````````````````````#`P,#<U-2``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S0U(#`R,#<V
M,@`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O<&]R=&%L+VUE;G4N
M:6YC````````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$P,S$@
M,3`U,34T,S,W-#4@,#(R-#<S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#QD:78@:60](FUE;G4B/@H@/&@Q(&-L87-S/2)L
M969T1FQO870B/CP_<&AP('!R:6YT9BA?*")796QC;VUE+"`E<R(I+"!H=&UL
M<W!E8VEA;&-H87)S*"1F=6QL;F%M92DI(#\^/"]H,3X*(#QD:78@8VQA<W,]
M(G)I9VAT1FQO870B/@H\/W!H<`HD;65N=2`]("9N97<@365N=2@I.PHD;65N
M=2T^861D*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G<V5R=FEC97,O<&]R=&%L
M+R<I+"!?*")(;U]M92(I+"`G:&]R9&4N<&YG)RD["FEF("@A)'!R969S+3YI
M<TQO8VME9"@G<&]R=&%L7VQA>6]U="<I*2!["B`@("`D;65N=2T^861D*$AO
M<F1E.CIA<'!L:6-A=&EO;E5R;"@G<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP
M)RDL(%\H(DQA7WEO=70B*2P@)VQA>6]U="YP;F<G*3L*?0II9B`H075T:#HZ
M:7-!9&UI;B@I*2!["B`@("`D;65N=2T^861D*$AO<F1E.CIA<'!L:6-A=&EO
M;E5R;"@G861M:6XO)RDL(%\H(E]!9&UI;FES=')A=&EO;B(I+"`G861M:6YI
M<W1R871I;VXN<&YG)RD["GT*96-H;R`D;65N=2T^<F5N9&5R*"D["C\^"B`\
M+V1I=CX*/"]D:78^"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O<&]R=&%L
M+V5D:70N:6YC````````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#,T,S(@,3`U,34T,S,W-#4@,#(R-#8S`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#QT86)L92!C;&%S<STB;F]P861D:6YG
M(B!C96QL<W!A8VEN9STB-B(@=VED=&@](C$P,"4B/@H\/W!H<`HD<F]W<R`]
M("1L87EO=70M/G)O=W,H*3L*;&ES="@D8W5R<F5N=%]R;W<L("1C=7)R96YT
M7V-O;"D@/2`D;&%Y;W5T+3YG971#=7)R96YT0FQO8VLH*3L*)&%L;&]W7V%D
M9"`]("@A96UP='DH)&-O;F9;)VAO;VMS)UU;)W!E<FUS9&5N:65D)UTI('Q\
M"B`@("`@("`@("`@("`@2&]R9&4Z.FAA<U!E<FUI<W-I;VXH)VUA>%]B;&]C
M:W,G*2`]/3T@=')U92!\?`H@("`@("`@("`@("`@($AO<F1E.CIH87-097)M
M:7-S:6]N*"=M87A?8FQO8VMS)RD@/B`D;&%Y;W5T+3YC;W5N="@I*3L*)&-O
M;'5M;G,@/2`P.PIF;W(@*"1R;W<@/2`P.R`D<F]W(#P@)')O=W,[("LK)')O
M=RDZ"C\^"B`@/'1R/@H\/W!H<`HD8V]L=6UN<R`]("1L87EO=70M/F-O;'5M
M;G,H)')O=RD["FEF("AI<U]A*"1C;VQU;6YS+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`D8V]L=6UN<R`](#`["GT*9F]R("@D8V]L(#T@,#L@)&-O;"`\("1C
M;VQU;6YS.R`K*R1C;VPI.@H@("`@)&ES161I=&EN9R`]("@D8W5R<F5N=%]R
M;W<@/3T]("1R;W<@)B8@)&-U<G)E;G1?8V]L(#T]/2`D8V]L*3L*("`@(&EF
M("@D;&%Y;W5T+3YI<T-O=F5R960H)')O=RP@)&-O;"DI.@H_/@H@("`@/"$M
M+2!C;W9E<F5D(&-E;&P@:&5R92`M+3X*/#]P:'`@96QS93H@/SX*("`@(#QT
M9"!C;&%S<STB/#]P:'`@96-H;R`D:7-%9&ET:6YG(#\@)V-U<G)E;G1";&]C
M:R<@.B`G:&5A9&5R8F]X)R`_/B(@=F%L:6=N/2)T;W`B('=I9'1H/2(\/W!H
M<"!E8VAO(&9L;V]R*#$P,"`O("@D8V]L=6UN<R`K(#$I*2`_/B4B(')O=W-P
M86X](CP_<&AP(&5C:&\@)&QA>6]U="T^9V5T2&5I9VAT*"1R;W<L("1C;VPI
M(#\^(B!C;VQS<&%N/2(\/W!H<"!E8VAO("1L87EO=70M/F=E=%=I9'1H*"1R
M;W<L("1C;VPI(#\^(CX*/#]P:'`*)&)L;V-K26YF;R`]("1L87EO=70M/F=E
M=$)L;V-K26YF;R@D<F]W+"`D8V]L*3L*:68@*"$D;&%Y;W5T+3YI<T5M<'1Y
M*"1R;W<L("1C;VPI("8F("%I<U]A*"1B;&]C:TEN9F\L("=014%27T5R<F]R
M)RDI('L*("`@(&EF("@D:7-%9&ET:6YG*2!["B`@("`@("`@)&5D:71?;&EN
M:R`]("<F;F)S<#LG.PH@("`@?2!E;'-E('L*("`@("`@("`D961I=%]L:6YK
M(#T@)SQS;6%L;#XG("X@2&]R9&4Z.FQI;FLH)&QA>6]U="T^9V5T06-T:6]N
M57)L*"=E9&ET)RP@)')O=RP@)&-O;"DI("X@7R@B961I="(I("X@)SPO83X\
M+W-M86QL/B<["B`@("!]"B`@("!R97%U:7)E(&1I<FYA;64H7U]&24Q%7U\I
M("X@)R]L87EO=70N:6YC)SL*?2!E;'-E('L*("`@(&EF("@D86QL;W=?861D
M*2!["B`@("`@("`@<F5Q=6ER92!D:7)N86UE*%]?1DE,15]?*2`N("<O861D
M+FEN8R<["B`@("!]"GT*/SX*("`@(#PO=&0^"CP_<&AP(&5N9&EF.R!E;F1F
M;W([(&EF("@D86QL;W=?861D*3H@/SX*("`@(#QT9"!V86QI9VX](G1O<"(@
M8VQA<W,](FAE861E<F)O>"(^"B`@("`@(#P_<&AP(')E<75I<F4@9&ER;F%M
M92A?7T9)3$5?7RD@+B`G+V%D9"YI;F,G.R`_/@H@("`@/"]T9#X*/#]P:'`@
M96YD:68[(#\^"B`@/"]T<CX*/#]P:'`@96YD9F]R.R!I9B`H)&%L;&]W7V%D
M9"DZ(#\^"B`@/'1R/@H\/W!H<`IF;W(@*"1C;VP@/2`P.R`D8V]L(#P]("1C
M;VQU;6YS.R`K*R1C;VPI.@H_/@H@("`@/'1D('9A;&EG;CTB=&]P(B!C;&%S
M<STB:&5A9&5R8F]X(CX*("`@("`@/#]P:'`@<F5Q=6ER92!D:7)N86UE*%]?
M1DE,15]?*2`N("<O861D+FEN8R<[(#\^"B`@("`\+W1D/@H\/W!H<"!E;F1F
M;W([(#\^"B`@/"]T<CX*/#]P:'`@96YD:68[(#\^"CPO=&%B;&4^"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+W!O<G1A;"]S:61E
M8F%R+FEN8P``````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$V,3(V
M(#$P-3$U-#,S-S0U(#`R,S$U,P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\9&EV(&ED/2)E>'!A;F1E9%-I9&5B87(B('-T
M>6QE/2)O=F5R9FQO=SIH:61D96XB/@H@/&1I=B!I9#TB;65N=2(@<W1Y;&4]
M(F]V97)F;&]W.FAI9&1E;B(^"B`@/#]P:'`@:68@*"%E;7!T>2@D8V]N9ELG
M;&]G;R==6R=I;6%G92==*2!\?"`A571I;#HZ9V5T1F]R;41A=&$H)VUO>F)A
M<B<I*3H@/SX*("`\<W!A;B!C;&%S<STB;&5F=$9L;V%T(CP_<&AP(&EF("AE
M;7!T>2@D8V]N9ELG;&]G;R==6R=I;6%G92==*2D@96-H;R`G(&ED/2)T:&5M
M96QO9V\B)R`_/CX*("`\/W!H<`H@(&EF("@A96UP='DH)&-O;F9;)VQO9V\G
M75LG:6UA9V4G72DI('L*("`@("`@:68@*"%E;7!T>2@D8V]N9ELG;&]G;R==
M6R=L:6YK)UTI*2!["B`@("`@("`@("!E8VAO($AO<F1E.CIL:6YK*"1C;VYF
M6R=L;V=O)UU;)VQI;FLG72P@;G5L;"P@;G5L;"P@)U]T;W`G*3L*("`@("`@
M?0H@("`@("!E8VAO($AO<F1E.CII;6<H)&-O;F9;)VQO9V\G75LG:6UA9V4G
M72P@)R<L("<G+"`G)RD["B`@("`@(&EF("@A96UP='DH)&-O;F9;)VQO9V\G
M75LG;&EN:R==*2D@>PH@("`@("`@("`@96-H;R`G/"]A/B<["B`@("`@('T*
M("!](&5L<V4@>PH@("`@("!E8VAO("<F;F)S<#LG.PH@('T*("`_/@H@(#PO
M<W!A;CX*("`\<W!A;B!C;&%S<STB;&5F=$9L;V%T(B!I9#TB;&]G;W!A9"(^
M)FYB<W`[/"]S<&%N/@H@(#QD:78@8VQA<W,](F-L96%R(CXF;F)S<#L\+V1I
M=CX*("`\/W!H<"!E;F1I9CL@/SX*(#PO9&EV/@H@/'-P86X@:60](F5X<&%N
M9$)U='1O;B(@8VQA<W,](G)I9VAT1FQO870B/CP_<&AP(&EF("@A)&ES7VUO
M>F)A<BD@96-H;R!(;W)D93HZ;&EN:R@G(R<L(%\H(D-O;&QA<'-E(%-I9&5B
M87(B*2P@)R<L("<G+"`G=&]G9VQE365N=49R86UE*"D[(')E='5R;B!F86QS
M93LG+"!?*")#;VQL87!S92!3:61E8F%R(BDI("X@2&]R9&4Z.FEM9R@G:&ED
M95]P86YE;"YP;F<G*2`N("<\+V$^)R`_/CPO<W!A;CX*(#QD:78@:60](G-I
M9&5B87)086YE;"(^"B`@/#]P:'`@)'1R964M/G)E;F1E<E1R964H*2`_/@H@
M/"]D:78^"@H\(2TM(&YE=W-F965D<R`M+3X*/'-C<FEP="!L86YG=6%G93TB
M:F%V87-C<FEP="(@='EP93TB=&5X="]J879A<V-R:7!T(CX*9&]C=6UE;G0N
M=W)I=&4H)SQS8W)I<'0@;&%N9W5A9V4](FIA=F%S8W)I<'0B('1Y<&4](G1E
M>'0O:F%V87-C<FEP="(@<W)C/2)H='1P.B\O)PH@("`@*R!L;V-A=&EO;BYH
M;W-T;F%M92`K("<Z.#@X,"]J879A<V-R:7!T+VYE=W-F965D<RYJ<RYP:'`B
M/CPO)R`K("=S8W)I<'0^7&XG*3L*/"]S8W)I<'0^"CQS8W)I<'0@;&%N9W5A
M9V4](FIA=F%S8W)I<'0B('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"F9U;F-T
M:6]N(&-R96%T94-O;VMI92AN86UE+'9A;'5E+&1A>7,I('L*("!I9B`H9&%Y
M<RD@>PH@("`@=F%R(&1A=&4@/2!N97<@1&%T92@I.PH@("`@9&%T92YS9714
M:6UE*&1A=&4N9V5T5&EM92@I*RAD87ES*C(T*C8P*C8P*C$P,#`I*3L*("`@
M('9A<B!E>'!I<F5S(#T@(CL@97AP:7)E<STB*V1A=&4N=&]'3513=')I;F<H
M*3L*("!]"B`@96QS92!V87(@97AP:7)E<R`]("(B.PH@(&1O8W5M96YT+F-O
M;VMI92`](&YA;64K(CTB*W9A;'5E*V5X<&ER97,K(CL@<&%T:#TO(CL*?0H*
M9G5N8W1I;VX@<F5A9$-O;VMI92AN86UE*2!["B`@=F%R(&YA;65%42`](&YA
M;64@*R`B/2(["B`@=F%R(&-A(#T@9&]C=6UE;G0N8V]O:VEE+G-P;&ET*"<[
M)RD["B`@9F]R*'9A<B!I/3`[:2`\(&-A+FQE;F=T:#MI*RLI('L*("`@('9A
M<B!C(#T@8V%;:5T["B`@("!W:&EL92`H8RYC:&%R070H,"D]/2<@)RD@8R`]
M(&,N<W5B<W1R:6YG*#$L8RYL96YG=&@I.PH@("`@:68@*&,N:6YD97A/9BAN
M86UE15$I(#T](#`I(')E='5R;B!C+G-U8G-T<FEN9RAN86UE15$N;&5N9W1H
M+&,N;&5N9W1H*3L*("!]"B`@<F5T=7)N(&YU;&P["GT*"F9U;F-T:6]N(&5R
M87-E0V]O:VEE*&YA;64I('L*("!C<F5A=&5#;V]K:64H;F%M92PB(BPM,2D[
M"GT*9G5N8W1I;VX@:&%S0VQA<W,H96QE;65N="P@8VQA<W-.86UE*0I["B`@
M("!V87(@8VQA<W-E<R`](&5L96UE;G0N8VQA<W-.86UE+G-P;&ET*"<@)RD[
M"B`@9F]R("AV87(@:2!I;B!C;&%S<V5S*2!["B`@("!I9B`H8VQA<W-E<UMI
M72`]/2!C;&%S<TYA;64I"B`@("`@(')E='5R;B!T<G5E.PH@('T*("!R971U
M<FX@9F%L<V4["GT*"F9U;F-T:6]N(&%D9$-L87-S*&5L96UE;G0L(&-L87-S
M3F%M92D*>PH@(&EF("@A:&%S0VQA<W,H96QE;65N="P@8VQA<W-.86UE*2D*
M("`@(&5L96UE;G0N8VQA<W-.86UE(#T@*&5L96UE;G0N8VQA<W-.86UE(#T]
M("<G(#\@8VQA<W-.86UE(#H@96QE;65N="YC;&%S<TYA;64@*R`G("<@*R!C
M;&%S<TYA;64I.PI]"@IF=6YC=&EO;B!R96UO=F5#;&%S<RAE;&5M96YT+"!C
M;&%S<TYA;64I"GL*("!V87(@;F5W5F%L=64@/2`G)SL*("`@('9A<B!C;&%S
M<V5S(#T@96QE;65N="YC;&%S<TYA;64N<W!L:70H)R`G*3L*("!F;W(@*'9A
M<B!I(&EN(&-L87-S97,I('L*("`@(&EF("AC;&%S<V5S6VE=("$](&-L87-S
M3F%M92D*("`@("`@;F5W5F%L=64@*ST@;F5W5F%L=64N;&5N9W1H(#\@)R`G
M("L@8VQA<W-E<UMI72`Z(&-L87-S97-;:5T["B`@?0H@(&5L96UE;G0N8VQA
M<W-.86UE(#T@;F5W5F%L=64["GT*"@IF=6YC=&EO;B!.1F-O;&QA<'-E3&ES
M="@I('L*("!V87(@3D9C;VYT96YT(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y
M260H)TY&8V]N=&5N="<I"B`@:68@*'=I;F1O=RY.1F]P96XI('L*("`@(&%D
M9$-L87-S("A.1F-O;G1E;G0L("=.1F-L;W-E)RD["B`@("!R96UO=F5#;&%S
M<R`H3D9C;VYT96YT+"`G3D9O<&5N)RD["B`@("!C<F5A=&5#;V]K:64H)W!L
M97-K7VYE=W-F965D7W9I<VEB;&4G+"`G9F%L<V4G+"`S,"D["B`@("!W:6YD
M;W<N3D9O<&5N(#T@9F%L<V4["B`@?2!E;'-E('L*("`@(&EF("@A=VEN9&]W
M+F%R=&EC;&4I"B`@("`@($Y&9V5T3&ES="@I.PH@("`@861D0VQA<W,@*$Y&
M8V]N=&5N="P@)TY&;W!E;B<I.PH@("`@<F5M;W9E0VQA<W,@*$Y&8V]N=&5N
M="P@)TY&8VQO<V4G*3L*("`@(&-R96%T94-O;VMI92@G<&QE<VM?;F5W<V9E
M961?=FES:6)L92<L("=T<G5E)RP@,S`I.PH@("`@=VEN9&]W+DY&;W!E;B`]
M('1R=64["B`@?0I]"FEF("AW:6YD;W<N3F5W<T9E961S*2!["B`@=VEN9&]W
M+DY&;W!E;B`]("AR96%D0V]O:VEE*"=P;&5S:U]N97=S9F5E9%]V:7-I8FQE
M)RD@/3T@)V9A;'-E)RD@/R!F86QS92`Z('1R=64["B`@9&]C=6UE;G0N=W)I
M=&4H)SQD:78@:60](DY&8V]N=&5N="(@8VQA<W,](G-I9&5B87)086YE;"`G
M("L@*$Y&;W!E;B`_("=.1F]P96XG(#H@)TY&8VQO<V4G*2`K)R(^)RD["B`@
M9&]C=6UE;G0N=W)I=&4H)SQT86)L92!C96QL<W!A8VEN9STB,"(@8V5L;'!A
M9&1I;F<](B(@=VED=&@](C$P,"4B(&)O<F1E<CTB,"(@8VQA<W,](G-I9&5B
M87)(96%D97(B/CQT8F]D>3XG*3L*("!D;V-U;65N="YW<FET92@G/'1R/B<I
M.PH@(&1O8W5M96YT+G=R:71E*"<\=&0@8VQA<W,](FAE861E<E1I=&QE(CX\
M/W!H<"!E8VAO(%\H)U1O<"!.97=S)RD[(#\^/"]T9#XG*3L*("!D;V-U;65N
M="YW<FET92@G/'1D(&-L87-S/2)H96%D97)"=71T;VYS(CX\82!H<F5F/2)J
M879A<V-R:7!T.DY&9V5T3&ES="@I.R(@8VQA<W,](F)T;BUR969R97-H(B!T
M:71L93TB/#]P:'`@96-H;R!?*"=2969R97-H)RD[(#\^(CX\<W!A;CX\/W!H
M<"!E8VAO(%\H)U)E9G)E<V@G*3L@/SX\+W-P86X^/"]A/CQA(&AR968](FIA
M=F%S8W)I<'0Z3D9C;VQL87!S94QI<W0H*3LB(&-L87-S/2)B=&XM;W!E;BUC
M;&]S92(@=&ET;&4](CP_<&AP(&5C:&\@7R@G3W!E;B]#;&]S92<I.R`_/B(^
M/'-P86X^/#]P:'`@96-H;R!?*"=/<&5N+T-L;W-E)RD[(#\^/"]S<&%N/CPO
M83X\+W1D/B<I.PH@(&1O8W5M96YT+G=R:71E*"<\+W1R/B<I.PH@(&1O8W5M
M96YT+G=R:71E*"<\+W1B;V1Y/CPO=&%B;&4^)RD["B`@9&]C=6UE;G0N=W)I
M=&4H)SQD:78@:60](FYE=W-&965D<R(^/"]D:78^)RD["B`@9&]C=6UE;G0N
M=W)I=&4H)SPO9&EV/B<I.PH@(&EF("AW:6YD;W<N3D9O<&5N("8F(')E861#
M;V]K:64H)VAO<F1E7W-I9&5B87)?97AP86YD960G*2`A/2`G9F%L<V4G*0H@
M("`@3D9G971,:7-T*"D["GT*/"]S8W)I<'0^"CPA+2T@+VYE=W-F965D<R`M
M+3X*/"]D:78^"@H\9&EV(&ED/2)H:61D96Y3:61E8F%R(CX*(#QD:78@:60]
M(FUE;G4B/@H@/"]D:78^"B`@/#]P:'`@96-H;R!(;W)D93HZ;&EN:R@G(R<L
M("<G+"`G)RP@)R<L("=T;V=G;&5-96YU1G)A;64H*3L@<F5T=7)N(&9A;'-E
M.R<I("X@2&]R9&4Z.FEM9R@G<VAO=U]P86YE;"YP;F<G*2`N("<\+V$^)R`_
M/@H\+V1I=CX*"CQS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*"G9A
M<B!R=&P@/2`\/W!H<"!E8VAO("1R=&P@/R`G=')U92<@.B`G9F%L<V4G(#\^
M.PIV87(@97AP86YD9613:61E8F%R(#T@;F5W($AO<F1E7TAI9&5A8FQE*"=E
M>'!A;F1E9%-I9&5B87(G*3L*=F%R(&AI9&1E;E-I9&5B87(@/2!N97<@2&]R
M9&5?2&ED96%B;&4H)VAI9&1E;E-I9&5B87(G*3L*:&ED9&5N4VED96)A<BYH
M:61E*"D["@IF=6YC=&EO;B!G971#;V]K:64H;F%M92P@9&5F;'0I"GL*("`@
M('9A<B!D8R`](&1O8W5M96YT+F-O;VMI93L*("`@('9A<B!P<F5F:7@@/2!N
M86UE("L@)STG.PH@("`@=F%R(&)E9VEN(#T@9&,N:6YD97A/9B@G.R`G("L@
M<')E9FEX*3L*("`@(&EF("AB96=I;B`]/2`M,2D@>PH@("`@("`@(&)E9VEN
M(#T@9&,N:6YD97A/9BAP<F5F:7@I.PH@("`@("`@(&EF("AB96=I;B`A/2`P
M*2!["B`@("`@("`@("`@(')E='5R;B!D969L=#L*("`@("`@("!]"B`@("!]
M(&5L<V4@>PH@("`@("`@(&)E9VEN("L](#(["B`@("!]"B`@("!V87(@96YD
M(#T@9&]C=6UE;G0N8V]O:VEE+FEN9&5X3V8H)SLG+"!B96=I;BD["B`@("!I
M9B`H96YD(#T]("TQ*2!["B`@("`@("`@96YD(#T@9&,N;&5N9W1H.PH@("`@
M?0H@("`@<F5T=7)N('5N97-C87!E*&1C+G-U8G-T<FEN9RAB96=I;B`K('!R
M969I>"YL96YG=&@L(&5N9"DI.PI]"@IF=6YC=&EO;B!T;V=G;&5-96YU1G)A
M;64H*0I["B`@("!I9B`H<&%R96YT("8F('!A<F5N="YD;V-U;65N="YG971%
M;&5M96YT0GE)9"@G:&8G*2D@>PH@("`@("`@(&EF("AE>'!A;F1E9%-I9&5B
M87(N<VAO=VXH*2D@>PH@("`@("`@("`@("!P87)E;G0N9&]C=6UE;G0N9V5T
M16QE;65N=$)Y260H)VAF)RDN8V]L<R`](')T;"`_("<J+#(P)R`Z("<R,"PJ
M)SL*("`@("`@("`@("`@97AP86YD9613:61E8F%R+FAI9&4H*3L*("`@("`@
M("`@("`@:&ED9&5N4VED96)A<BYS:&]W*"D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<&%R96YT+F1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=H
M9B<I+F-O;',@/2`H<G1L(#\@)RHL)R`Z("<G*2`K(#P_<&AP(&5C:&\@*&ES
M<V5T*"1P<F5F<RD@/R`D<')E9G,M/F=E=%9A;'5E*"=S:61E8F%R7W=I9'1H
M)RD@.B`Q-3`I(#\^("L@*')T;"`_("<G(#H@)RPJ)RD["B`@("`@("`@("`@
M(&EF("AW:6YD;W<N3D9O<&5N("8F("%W:6YD;W<N87)T:6-L92D*("`@("`@
M("`@("`@("!.1F=E=$QI<W0H*3L*("`@("`@("`@("`@:&ED9&5N4VED96)A
M<BYH:61E*"D["B`@("`@("`@("`@(&5X<&%N9&5D4VED96)A<BYS:&]W*"D[
M"B`@("`@("`@?0H*("`@("`@("`O+R!%>'!I<F4@:6X@;VYE('EE87(N"B`@
M("`@("`@=F%R(&5X<&ER97,@/2!N97<@1&%T92@I.PH@("`@("`@(&5X<&ER
M97,N<V5T5&EM92AE>'!I<F5S+F=E=%1I;64H*2`K(#,Q-3,V,#`P,#`P*3L*
M("`@("`@("!D;V-U;65N="YC;V]K:64@/2`G:&]R9&5?<VED96)A<E]E>'!A
M;F1E9#TG("L@97AP86YD9613:61E8F%R+G-H;W=N*"D@*R`G.T1/34%)3CT\
M/W!H<"!E8VAO("1'3$]"04Q36R=C;VYF)UU;)V-O;VMI92==6R=D;VUA:6XG
M72`_/CM0051(/3P_<&AP(&5C:&\@)$=,3T)!3%-;)V-O;F8G75LG8V]O:VEE
M)UU;)W!A=&@G72`_/CME>'!I<F5S/2<@*R!E>'!I<F5S+G1O1TU44W1R:6YG
M*"D["B`@("!]"GT*"FEF("AG971#;V]K:64H)VAO<F1E7W-I9&5B87)?97AP
M86YD960G+"!T<G5E*2YT;U-T<FEN9R@I("$](&5X<&%N9&5D4VED96)A<BYS
M:&]W;B@I+G1O4W1R:6YG*"DI('L*("`@('1O9V=L94UE;G5&<F%M92@I.PI]
M"@IV87(@365N=55P9&%T94AA;F1L97(@/2!["B`@("!O;DQO860Z(&9U;F-T
M:6]N*')E<W5L="D*("`@('L*("`@("`@("`O+R!2=6X@=&AE(&IA=F%S8W)I
M<'0@=V4@9V]T(&)A8VLN"B`@("`@("`@979A;"AR97-U;'0I.PH@("`@?0I]
M.PH*9G5N8W1I;VX@=7!D871E*"D*>PH@("`@=F%R(&-L:65N="`](&YE=R!(
M5%100VQI96YT*"D["B`@("!C;&EE;G0N:6YI="@B/#]P:'`@96-H;R!(;W)D
M93HZ87!P;&EC871I;VY5<FPH)W-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#]H='1P8VQI96YT/3$G+"!T<G5E*2`_/B(I.PH*("`@('1R>2!["B`@("`@
M("`@8VQI96YT+F%S>6YC1T54*$UE;G55<&1A=&5(86YD;&5R*3L*("`@('T@
M8V%T8V@@*&4I('L*("`@("`@("`O+R!$;VXG="!D;R!A;GET:&EN9R!O;B!E
M<G)O<G,[('!R;V)A8FQY(&$@=')A;G-I96YT(&9A:6QU<F4L"B`@("`@("`@
M+R\@86YD('=E)VQL('1R>2!A9V%I;B!A9G1E<B!T:&4@;F5X="!I;G1E<G9A
M;"X*("`@('T*("`@('=I;F1O=RYS9714:6UE;W5T*"=U<&1A=&4H*3LG+"`\
M/W!H<"!E8VAO("1P<F5F<RT^9V5T5F%L=64H)VUE;G5?<F5F<F5S:%]T:6UE
M)RD@/SX@*B`Q,#`P*3L*?0H*/#]P:'`@:68@*"1P<F5F<RT^9V5T5F%L=64H
M)VUE;G5?<F5F<F5S:%]T:6UE)RDI.B`_/@HO+R!5<&1A=&4@=&AE(&UE;G4@
M:68@<V5T(&EN('5S97(@<')E9G,N"CP_<&AP(&EF("@D1TQ/0D%,4ULG8G)O
M=W-E<B==+3YH87-&96%T=7)E*"=X;6QH='1P<F5Q)RDI.B`_/@IW:6YD;W<N
M<V5T5&EM96]U="@G=7!D871E*"D[)RP@/#]P:'`@96-H;R`D<')E9G,M/F=E
M=%9A;'5E*"=M96YU7W)E9G)E<VA?=&EM92<I(#\^("H@,3`P,"D["CP_<&AP
M(&5L<V4Z(#\^"G=I;F1O=RYS9714:6UE;W5T*"=W:6YD;W<N;&]C871I;VXN
M<F5L;V%D*'1R=64I.R<L(#P_<&AP(&5C:&\@)'!R969S+3YG971686QU92@G
M;65N=5]R969R97-H7W1I;64G*2`_/B`J(#$P,#`I.PH\/W!H<"!E;F1I9CL@
M96YD:68[(#\^"@H\+W-C<FEP=#X*"CP_<&AP(&EF("AI<W-E="@D1TQ/0D%,
M4ULG;F]T:69I8V%T:6]N)UTI*2`D1TQ/0D%,4ULG;F]T:69I8V%T:6]N)UTM
M/FYO=&EF>2AA<G)A>2@G;&ES=&5N97)S)R`]/B!A<G)A>2@G:F%V87-C<FEP
M="<I*2D@/SX*"CPO8F]D>3X*/"]H=&UL/@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O<&]R=&%L+V%D
M9"YI;F,`````````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$P
M-S,@,3`U,34T,S,W-#4@,#(R,C8U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP(&EF("@D;&%Y;W5T+3YI<T-H86YG
M960H)')O=RP@)&-O;"DI.B`_/@H\82!I9#TB8FQO8VLB/CPO83X*/#]P:'`@
M96YD:68[(#\^"@H\<"!C;&%S<STB:&5A9&5R(CX\/W!H<"!E8VAO(%\H(D%D
M9"!(97)E.B(I(#\^/"]P/@H*/&1I=B!S='EL93TB<&%D9&EN9SHR<'@B/@H@
M/&9O<FT@86-T:6]N/2(\/W!H<"!E8VAO($AO<F1E.CIS96QF57)L*"D@/SXC
M8FQO8VLB(&UE=&AO9#TB<&]S="(^"B`\/W!H<"!5=&EL.CIP9F]R;4EN<'5T
M*"D@/SX*(#QI;G!U="!T>7!E/2)H:61D96XB(&YA;64](G)O=R(@=F%L=64]
M(CP_<&AP(&5C:&\@)')O=R`_/B(@+SX*(#QI;G!U="!T>7!E/2)H:61D96XB
M(&YA;64](F-O;"(@=F%L=64](CP_<&AP(&5C:&\@)&-O;"`_/B(@+SX*(#QI
M;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%C=&EO;B(@=F%L=64](G-A=F4M
M<F5S=6UE(B`O/@H@/#]P:'`@96-H;R`D8FQO8VMS+3YG971";&]C:W-7:61G
M970H*2`_/@H@/&EN<'5T('1Y<&4](G-U8FUI="(@8VQA<W,](F)U='1O;B(@
M=F%L=64](CP_<&AP(&5C:&\@7R@B061D(BD@/SXB("\^"B`\+V9O<FT^"CPO
M9&EV/@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O<&]R
M=&%L+VQA>6]U="YI;F,`````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,3`Q,C$@,3`U,34T,S,W-#4@,#(S,#0T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP(&EF("@D;&%Y;W5T+3YI
M<T-H86YG960H)')O=RP@)&-O;"DI.B`_/@H\82!I9#TB8FQO8VLB/CPO83X*
M/#]P:'`@96YD:68[(#\^"@H\=&%B;&4@8V5L;'-P86-I;F<](C`B(&-L87-S
M/2)H96%D97(B('=I9'1H/2(Q,#`E(CX\='(^"B`@/'1D/@H@("`@/#]P:'`@
M96-H;R`D<F5G:7-T<GDM/F=E="@G;F%M92<L("1B;&]C:TEN9F];)V%P<"==
M*2`N("<Z("<@+B`D8FQO8VMS+3YG971.86UE*"1B;&]C:TEN9F];)V%P<"==
M+"`D8FQO8VM);F9O6R=B;&]C:R==*2`_/@H@(#PO=&0^"B`@/'1D(&-L87-S
M/2)R:6=H=$%L:6=N(CX*("`@("9N8G-P.SP_<&AP(&5C:&\@)&5D:71?;&EN
M:R`_/@H@("`@/#]P:'`@:68@*"1L87EO=70M/FES4F5M;W9A8FQE*"1R;W<L
M("1C;VPI*2!E8VAO($AO<F1E.CIL:6YK*"1L87EO=70M/F=E=$%C=&EO;E5R
M;"@G<F5M;W9E0FQO8VLG+"`D<F]W+"`D8V]L*2P@7R@B4F5M;W9E($)L;V-K
M(BDL("<G+"`G)RP@)R<L(%\H(E)E;6]V92!";&]C:R(I*2`N($AO<F1E.CII
M;6<H)V-L;W-E+G!N9R<L(%\H(E)E;6]V92!";&]C:R(I+"`G86QI9VX](FUI
M9&1L92(G*2`N("<\+V$^)R`_/@H@(#PO=&0^"CPO='(^/"]T86)L93X*"CQT
M86)L92!C96QL<W!A8VEN9STB,"(@8VQA<W,](FYO<&%D9&EN9R(@=VED=&@]
M(C$P,"4B/@H@(#QT<CX*("`@(#QT9"!C;VQS<&%N/2(S(B!A;&EG;CTB8V5N
M=&5R(CX*("`@("`@/#]P:'`@:68@*"1R;W<@/B`P*2!E8VAO("1L87EO=70M
M/F=E=$-O;G1R;VPH)V5X<&%N9"]U<"<L("1R;W<L("1C;VPI(#\^)FYB<W`[
M"B`@("`@(#P_<&AP(&EF("@D;&%Y;W5T+3YG971(96EG:'0H)')O=RP@)&-O
M;"D@/B`Q*2!E8VAO("1L87EO=70M/F=E=$-O;G1R;VPH)W-H<FEN:R]U<"<L
M("1R;W<L("1C;VPI(#\^"B`@("`\+W1D/@H@(#PO='(^"B`@/'1R/@H@("`@
M/'1D(&-L87-S/2)L969T06QI9VXB('=I9'1H/2(Q,2(^"B`@("`@(#P_<&AP
M(&EF("@D8V]L(#X@,"D@96-H;R`D;&%Y;W5T+3YG971#;VYT<F]L*"=E>'!A
M;F0O;&5F="<L("1R;W<L("1C;VPI(#\^"B`@("`@(#P_<&AP(&EF("@D;&%Y
M;W5T+3YG9717:61T:"@D<F]W+"`D8V]L*2`^(#$I(&5C:&\@)&QA>6]U="T^
M9V5T0V]N=')O;"@G<VAR:6YK+VQE9G0G+"`D<F]W+"`D8V]L*2`_/@H@("`@
M/"]T9#X*("`@(#QT9"!A;&EG;CTB8V5N=&5R(CX*("`@("`@/'1A8FQE/@H@
M("`@("`@(#QT<CX*("`@("`@("`@(#QT9"!W:61T:#TB,3$B/B9N8G-P.SPO
M=&0^"B`@("`@("`@("`\=&0@=VED=&@](C$Q(CX\/W!H<"!E8VAO("1R;W<@
M/B`P(#\@)&QA>6]U="T^9V5T0V]N=')O;"@G;6]V92]U<"<L("1R;W<L("1C
M;VPI(#H@)R9N8G-P.R<@/SX\+W1D/@H@("`@("`@("`@/'1D('=I9'1H/2(Q
M,2(^)FYB<W`[/"]T9#X*("`@("`@("`\+W1R/@H@("`@("`@(#QT<CX*("`@
M("`@("`@(#QT9#X\/W!H<"!E8VAO("1C;VP@/B`P(#\@)&QA>6]U="T^9V5T
M0V]N=')O;"@G;6]V92]L969T)RP@)')O=RP@)&-O;"D@.B`G)FYB<W`[)R`_
M/CPO=&0^"B`@("`@("`@("`\=&0^)FYB<W`[/"]T9#X*("`@("`@("`@(#QT
M9#X\/W!H<"!E8VAO("1L87EO=70M/F=E=$-O;G1R;VPH)VUO=F4O<FEG:'0G
M+"`D<F]W+"`D8V]L*2`_/CPO=&0^"B`@("`@("`@/"]T<CX*("`@("`@("`\
M='(^"B`@("`@("`@("`\=&0^)FYB<W`[/"]T9#X*("`@("`@("`@(#QT9#X\
M/W!H<"!E8VAO("1L87EO=70M/F=E=$-O;G1R;VPH)VUO=F4O9&]W;B<L("1R
M;W<L("1C;VPI(#\^/"]T9#X*("`@("`@("`@(#QT9#XF;F)S<#L\+W1D/@H@
M("`@("`@(#PO='(^"B`@("`@(#PO=&%B;&4^"B`@("`\+W1D/@H@("`@/'1D
M(&-L87-S/2)R:6=H=$%L:6=N(B!W:61T:#TB,3$B/@H@("`@("`\/W!H<"!I
M9B`H)&QA>6]U="T^9V5T5VED=&@H)')O=RP@)&-O;"D@/B`Q*2!E8VAO("1L
M87EO=70M/F=E=$-O;G1R;VPH)W-H<FEN:R]R:6=H="<L("1R;W<L("1C;VPI
M(#\^"B`@("`@(#P_<&AP(&5C:&\@)&QA>6]U="T^9V5T0V]N=')O;"@G97AP
M86YD+W)I9VAT)RP@)')O=RP@)&-O;"D@/SX*("`@(#PO=&0^"B`@/"]T<CX*
M("`\='(^"B`@("`\=&0@8V]L<W!A;CTB,R(@86QI9VX](F-E;G1E<B(^"B`@
M("`@("`@/#]P:'`@:68@*"1L87EO=70M/F=E=$AE:6=H="@D<F]W+"`D8V]L
M*2`^(#$I(&5C:&\@)&QA>6]U="T^9V5T0V]N=')O;"@G<VAR:6YK+V1O=VXG
M+"`D<F]W+"`D8V]L*2`_/@H@("`@("`@(#P_<&AP(&5C:&\@)&QA>6]U="T^
M9V5T0V]N=')O;"@G97AP86YD+V1O=VXG+"`D<F]W+"`D8V]L*2`_/@H@("`@
M/"]T9#X*("`\+W1R/@H\+W1A8FQE/@H*/#]P:'`@:68@*"1I<T5D:71I;F<I
M.B`_/@H\82!I9#TB8FQO8VLB/CPO83X*/'1A8FQE(&-L87-S/2)N;W!A9&1I
M;F<B(&-E;&QS<&%C:6YG/2(P(B!W:61T:#TB,3`P)2(^"B`@/'1R/@H@("`@
M/'1D/B9N8G-P.SPO=&0^"B`@/"]T<CX*("`\='(^"B`@("`\=&0@=F%L:6=N
M/2)M:61D;&4B(&-L87-S/2)L969T06QI9VXB('=I9'1H/2(Q,#`E(CX*("`@
M("`@/&9O<FT@86-T:6]N/2(\/W!H<"!E8VAO($AO<F1E.CIS96QF57)L*"D@
M/SXC8FQO8VLB(&UE=&AO9#TB<&]S="(@;F%M93TB8FQO8VMF;W)M(CX*("`@
M("`@("`\/W!H<"!5=&EL.CIP9F]R;4EN<'5T*"D@/SX*("`@("`@("`\:6YP
M=70@='EP93TB:&ED9&5N(B!N86UE/2)R;W<B('9A;'5E/2(\/W!H<"!E8VAO
M("1R;W<@/SXB("\^"B`@("`@("`@/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M
M93TB8V]L(B!V86QU93TB/#]P:'`@96-H;R`D8V]L(#\^(B`O/@H@("`@("`@
M(#QI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%C=&EO;B(@=F%L=64](G-A
M=F4B("\^"B`@("`@("`@/'1A8FQE(&-E;&QS<&%C:6YG/2(P(B!W:61T:#TB
M,3`P)2(^"B`@("`@("`@("`\='(^"B`@("`@("`@("`@(#QT9"!C;&%S<STB
M<VUA;&QH96%D97(B(&-O;'-P86X](C(B/CP_<&AP(&5C:&\@7R@B0FQO8VL@
M5'EP92(I(#\^/"]T9#X*("`@("`@("`@(#PO='(^"B`@("`@("`@("`\='(^
M"B`@("`@("`@("`@(#QT9"!C;VQS<&%N/2(R(CX*("`@("`@("`@("`@("`\
M/W!H<"!E8VAO("1B;&]C:W,M/F=E=$)L;V-K<U=I9&=E="@D8FQO8VM);F9O
M6R=A<'`G72P@)&)L;V-K26YF;ULG8FQO8VLG72P@=')U92D@/SX*("`@("`@
M("`@("`@/"]T9#X*("`@("`@("`@(#PO='(^"CP_<&AP"FEF("@D8FQO8VMS
M+3YI<T5D:71A8FQE*"1B;&]C:TEN9F];)V%P<"==+"`D8FQO8VM);F9O6R=B
M;&]C:R==*2DZ"B`@("`D8FQO8VL@/2`F)&QA>6]U="T^9V5T0FQO8VLH)')O
M=RP@)&-O;"D["B`@("`D9&5F875L=',@/2!A<G)A>2@I.PH@("`@9F]R96%C
M:"`H)&)L;V-K+3Y?<&%R86US(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@
M("1D969A=6QT<ULD:V5Y72`]("1V86P["B`@("!]"C\^"B`@("`@("`@("`\
M='(^"B`@("`@("`@("`@(#QT9"!C;VQS<&%N/2(R(B!C;&%S<STB<VUA;&QH
M96%D97(B/CP_<&AP(&5C:&\@7R@B0FQO8VL@4V5T=&EN9W,B*2`_/CPO=&0^
M"B`@("`@("`@("`\+W1R/@H\/W!H<"`D:2`](#`[(&9O<F5A8V@@*"1B;&]C
M:W,M/F=E=%!A<F%M<R@D8FQO8VM);F9O6R=A<'`G72P@)&)L;V-K26YF;ULG
M8FQO8VLG72D@87,@)&ED*3H@)&DK*SL@/SX*("`@("`@("`@(#QT<CX*("`@
M("`@("`@("`@/'1D(&-L87-S/2(\/W!H<"!E8VAO("@D:2`E(#(I(#\@)W1E
M>'0G(#H@)VET96TP)R`_/B!R:6=H=$%L:6=N(B!V86QI9VX](G1O<"(^/#]P
M:'`@96-H;R`D8FQO8VMS+3YG971087)A;4YA;64H)&)L;V-K26YF;ULG87!P
M)UTL("1B;&]C:TEN9F];)V)L;V-K)UTL("1I9"D@/SXZ)FYB<W`[/"]T9#X*
M("`@("`@("`@("`@/'1D(&-L87-S/2(\/W!H<"!E8VAO("@D:2`E(#(I(#\@
M)W1E>'0G(#H@)VET96TP)R`_/B(@=F%L:6=N/2)T;W`B/CP_<&AP(&5C:&\@
M)&)L;V-K<RT^9V5T3W!T:6]N<U=I9&=E="@D8FQO8VM);F9O6R=A<'`G72P@
M)&)L;V-K26YF;ULG8FQO8VLG72P@)&ED+"`D9&5F875L=',I(#\^/"]T9#X*
M("`@("`@("`@(#PO='(^"CP_<&AP(&5N9&9O<F5A8V@[(&5N9&EF.R`_/@H@
M("`@("`@(#PO=&%B;&4^"B`@("`@("`@/&EN<'5T('1Y<&4](G-U8FUI="(@
M8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP(&5C:&\@7R@B4V%V92(I(#\^
M(B`O/@H@("`@("`\+V9O<FT^"B`@("`\+W1D/@H@(#PO='(^"CPO=&%B;&4^
M"CP_<&AP(&5N9&EF.R`_/@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]P;W)T86PO8FQO8VLN
M:6YC````````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#,R-R`Q
M,#4Q-30S,S<T-2`P,C(V,S``(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/'1D(&-L87-S/2)H96%D97)B;W@B('9A;&EG;CTB
M=&]P(B!S='EL93TB=VED=&@Z/#]P:'`@96-H;R`D=VED=&@@/SXE(B!R;W=S
M<&%N/2(\/W!H<"!E8VAO("1R;W=S<&%N(#\^(B!C;VQS<&%N/2(\/W!H<"!E
M8VAO("1C;VQS<&%N(#\^(CX*(#QH,2!C;&%S<STB:&5A9&5R(CX\/W!H<"!E
M8VAO("1H96%D97(@/SX\+V@Q/@H@/#]P:'`@96-H;R`D8V]N=&5N="`_/@H\
M+W1D/@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T96UP;&%T97,O<G!C<W5M````````````````````````
M````````````````````````````````````````````````````````,#`P
M-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W-#4@
M,#(P-S<R`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8P``````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M-C4S,R`Q,#4Q-30S,S<T-2`P,C,P-C0`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S
M8W)I<'0B/@H\(2TM"@IV87(@8V%N8V5L4W5B;6ET(#T@9F%L<V4["@IV87(@
M9FEE;&1S(#T@;F5W($%R<F%Y*`H\/W!H<"!F;W(@*"1I(#T@,#L@)&D@/"!C
M;W5N="@D<G!C7W-E<G9E<G,I.R`D:2LK*3H@/SX*("`@(&YE=R!!<G)A>2@*
M("`@("`@("`B/#]P:'`@96-H;R!R87=U<FQE;F-O9&4H)')P8U]S97)V97)S
M6R1I75LG=7)L)UTI(#\^(BP*("`@("`@("`B/#]P:'`@96-H;R!R87=U<FQE
M;F-O9&4H)')P8U]S97)V97)S6R1I75LG=7-E<B==*2`_/B(*("`@("D\/W!H
M<"!I9B`H)&D@*R`Q(#P@8V]U;G0H)')P8U]S97)V97)S*2D@96-H;R`G+"<[
M(#\^"@H\/W!H<"!E;F1F;W([(#\^"BD["@IF=6YC=&EO;B!N97=#:&]I8V4H
M*0I["B`@("!V87(@86-T:6]N(#T@9&]C=6UE;G0N<')E9G,N<V5R=F5R+F]P
M=&EO;G-;9&]C=6UE;G0N<')E9G,N<V5R=F5R+G-E;&5C=&5D26YD97A=+G9A
M;'5E.PH*("`@(&EF("AA8W1I;VX@/3T@+3$I('L*("`@("`@("!D;V-U;65N
M="YP<F5F<RYS879E+G9A;'5E(#T@)SP_<&AP(&5C:&\@861D<VQA<VAE<RA?
M*")#<F5A=&4B*2D@/SXG.PH@("`@("`@(&1O8W5M96YT+G!R969S+G)E<V5T
M*"D["B`@("!](&5L<V4@>PH@("`@("`@(&1O8W5M96YT+G!R969S+G-A=F4N
M=F%L=64@/2`G/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D-H86YG92(I*2`_
M/B<["B`@("`@("`@=7!D871E1F]R;2AA8W1I;VXI.PH@("`@?0I]"@IF=6YC
M=&EO;B!U<&1A=&5&;W)M*'-E<G9E<BD*>PH@("`@9&]C=6UE;G0N<')E9G,N
M961I=%]S97)V97(N=F%L=64@/2!S97)V97(["B`@("!D;V-U;65N="YP<F5F
M<RYU<FPN=F%L=64@/2!D96-O9&554DE#;VUP;VYE;G0H9FEE;&1S6W-E<G9E
M<EU;,%TI.PH@("`@9&]C=6UE;G0N<')E9G,N=7-E<BYV86QU92`](&1E8V]D
M955224-O;7!O;F5N="AF:65L9'-;<V5R=F5R75LQ72D["GT*"F9U;F-T:6]N
M(&-L96%R1F]R;2@I"GL*("`@(&1O8W5M96YT+G!R969S+F5D:71?<V5R=F5R
M+G9A;'5E(#T@)R<["B`@("!D;V-U;65N="YP<F5F<RYU<FPN=F%L=64@/2`@
M9FEE;&1S6W-E<G9E<EU;,%T["B`@("!D;V-U;65N="YP<F5F<RYU<V5R+G9A
M;'5E(#T@9FEE;&1S6W-E<G9E<EU;,5T["B`@("!D;V-U;65N="YP<F5F<RYS
M97)V97(N<V5L96-T961);F1E>"`](#`["B`@("!C86YC96Q3=6)M:70@/2!T
M<G5E.PI]"@IF=6YC=&EO;B!C:&5C:U-U8FUI="@I"GL*("`@(&-A;F-E;"`]
M(&-A;F-E;%-U8FUI=#L*("`@(&-A;F-E;%-U8FUI="`](&9A;'-E.PH\/W!H
M<"!I9B`H)&)R;W=S97(M/F=E=$)R;W=S97(H*2`]/2`G;7-I92<@)B8@)&)R
M;W=S97(M/F=E=$UA:F]R*"D@/CT@-"DZ(#\^"B`@("!W:6YD;W<N979E;G0N
M<F5T=7)N5F%L=64@/2`A8V%N8V5L.PH\/W!H<"!E;F1I9CL@/SX*("`@(')E
M='5R;B`A8V%N8V5L.PI]"@HO+RTM/@H\+W-C<FEP=#X*"CP_<&AP(&5C:&\@
M7R@B66]U<B!R96UO=&4@<V5R=F5R<SHB*2`_/CQB<B`O/@H\<V5L96-T(&YA
M;64](G-E<G9E<B(@;VYC:&%N9V4](FIA=F%S8W)I<'0Z;F5W0VAO:6-E*"DB
M/@H@(#QO<'1I;VX@=F%L=64](BTQ(CX\/W!H<"!E8VAO(%\H(E-E;&5C="!A
M('-E<G9E<B(I(#\^/"]O<'1I;VX^"CP_<&AP(&9O<B`H)&D@/2`P.R`D:2`\
M(&-O=6YT*"1R<&-?<V5R=F5R<RD[("LK)&DI.B`_/@H@(#QO<'1I;VX@=F%L
M=64](CP_<&AP(&5C:&\@)&D@/SXB/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC
M:&%R<R@D<G!C7W-E<G9E<G-;)&E=6R=U<FPG72D@/SX\+V]P=&EO;CX*/#]P
M:'`@96YD9F]R.R`_/@H\+W-E;&5C=#X*/"]T9#X\+W1R/@H*/&YO<V-R:7!T
M/@H\+W1A8FQE/CPO=&0^/"]T<CX*/'1R/@H@(#QT9"!V86QI9VX](FUI9&1L
M92(^"B`@("`\8G(@+SX*("`@(#QI;G!U="!T>7!E/2)S=6)M:70B(&YA;64]
M(F5D:70B(&-L87-S/2)B=71T;VXB('9A;'5E/2(\/W!H<"!E8VAO(%\H(D5D
M:70B*2`_/B(@+SX*("`@(#QI;G!U="!T>7!E/2)S=6)M:70B(&YA;64](F1E
M;&5T92(@8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP(&5C:&\@7R@B1&5L
M971E(BD@/SXB("\^"B`@("`\8G(@+SXF;F)S<#L*("`\+W1D/@H\+W1R/@H*
M/'1R/CQT9"!C;&%S<STB:71E;2(^/'1A8FQE/@H\+VYO<V-R:7!T/@H*/'1R
M('9A;&EG;CTB=&]P(CX\=&0@8VQA<W,](FET96TB/@H*/&EN<'5T('1Y<&4]
M(FAI9&1E;B(@;F%M93TB961I=%]S97)V97(B('9A;'5E/2(B("\^"CP_<&AP
M(&5C:&\@7R@B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H
M;W)D92DZ(BD@/SX\8G(@+SX*/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](G5R
M;"(@<VEZ93TB,S`B(&UA>&QE;F=T:#TB-C`B("\^/&)R("\^"@H\/W!H<"!E
M8VAO(%\H(E5S97)N86UE.B(I(#\^/&)R("\^"CQI;G!U="!T>7!E/2)T97AT
M(B!N86UE/2)U<V5R(B!S:7IE/2(S,"(@;6%X;&5N9W1H/2(V,"(@+SX\8G(@
M+SX*"CP_<&AP(&5C:&\@7R@B4&%S<W=O<F0Z(BD@/SX\8G(@+SX*/&EN<'5T
M('1Y<&4](G!A<W-W;W)D(B!N86UE/2)P87-S=V0B('-I>F4](C,P(B!M87AL
M96YG=&@](C8P(B`O/CQB<B`O/@H*/"]T9#X\+W1R/CPO=&%B;&4^/"]T9#X\
M+W1R/CPO=&%B;&4^"@H\<#X*(#QI;G!U="!T>7!E/2)S=6)M:70B(&YA;64]
M(G-A=F4B(&-L87-S/2)B=71T;VXB(&]N8VQI8VL](F1O8W5M96YT+G!R969S
M+F%C=&EO;DE$+G9A;'5E/2=S879E)SL@<F5T=7)N('1R=64B('9A;'5E/2(\
M/W!H<"!E8VAO("1A8W1I;VY)1"`]/2`G961I="<@/R!?*")#:&%N9V4B*2`Z
M(%\H(D-R96%T92(I(#\^(B`O/B9N8G-P.PH\<V-R:7!T('1Y<&4](G1E>'0O
M:F%V87-C<FEP="(^"F1O8W5M96YT+G=R:71E*"<\:6YP=70@='EP93TB<W5B
M;6ET(B!N86UE/2)D96QE=&4B(&-L87-S/2)B=71T;VXB(&]N8VQI8VL](F1O
M8W5M96YT+G!R969S+F%C=&EO;DE$+G9A;'5E/5PG9&5L971E7"<B('9A;'5E
M/2(\/W!H<"!E8VAO(%\H(D1E;&5T92(I(#\^(B`O/B9N8G-P.R<I.PH\+W-C
M<FEP=#X*(#QI;G!U="!T>7!E/2)S=6)M:70B(&YA;64](FYE=R(@8VQA<W,]
M(F)U='1O;B(@;VYC;&EC:STB8VQE87)&;W)M*"D[9&]C=6UE;G0N<')E9G,N
M<V%V92YV86QU93TG/#]P:'`@96-H;R!?*")#<F5A=&4B*2`_/B<[(B!V86QU
M93TB/#]P:'`@96-H;R!?*")297-E="(I(#\^(B`O/B9N8G-P.PH@/&EN<'5T
M('1Y<&4](F)U='1O;B(@8VQA<W,](F)U='1O;B(@;VYC;&EC:STB8V%N8V5L
M4W5B;6ET/71R=64[9&]C=6UE;G0N;&]C871I;VXN:')E9CTG/#]P:'`@96-H
M;R!(;W)D93HZ87!P;&EC871I;VY5<FPH571I;#HZ861D4&%R86UE=&5R*"=S
M97)V:6-E<R]P<F5F<RYP:'`G+"`G87!P)RP@)VAO<F1E)RDL('1R=64I(#\^
M)R(@=F%L=64](CP_<&AP(&5C:&\@7R@B4F5T=7)N('1O($]P=&EO;G,B*2`_
M/B(@+SX*/"]P/@H*/"]F;W)M/@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O<')O8FQE
M;0``````````````````````````````````````````````````````````
M````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#`P,#`@,3`U,34T,S,W-#4@,#(Q,3(Q`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P-#0R,"`Q,#4Q-30S,S<T-2`P,C,S,S,`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/'-C<FEP
M="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM"B\O($-H96-K(&%L;"!O
M9B!T:&4@;6%I;B!F;W)M(&9I96QD<R!T;R!M86ME('-U<F4@=&AE>2!A<F4@
M9FEL;&5D(&EN"F9U;F-T:6]N('9A;&ED871E*"D*>PH@("`@:68@*&1O8W5M
M96YT+G!R;V)L96U?<F5P;W)T+G-U8FIE8W0N=F%L=64@/3T@)R<I('L*("`@
M("`@("!A;&5R="@G/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E!L96%S92!P
M<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB*2D@/SXG*3L*("`@
M("`@("!D;V-U;65N="YP<F]B;&5M7W)E<&]R="YS=6)J96-T+F9O8W5S*"D[
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?2!E;'-E(&EF("AD;V-U;65N
M="YP<F]B;&5M7W)E<&]R="YM97-S86=E+G9A;'5E(#T]("<G*2!["B`@("`@
M("`@86QE<G0H)SP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")9;W4@;75S="!D
M97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P
M<F]B;&5M(')E<&]R="XB*2D@/SXG*3L*("`@("`@("!D;V-U;65N="YP<F]B
M;&5M7W)E<&]R="YM97-S86=E+F9O8W5S*"D["B`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@?0H*("`@(&1O8W5M96YT+G!R;V)L96U?<F5P;W)T+F%C=&EO
M;DE$+G9A;'5E(#T@)W-E;F1?<')O8FQE;5]R97!O<G0G.PH@("`@<F5T=7)N
M('1R=64["GT*+R\M+3X*/"]S8W)I<'0^"@H\9F]R;2!M971H;V0](G!O<W0B
M(&YA;64](G!R;V)L96U?<F5P;W)T(B!A8W1I;VX](G!R;V)L96TN<&AP(CX*
M/#]P:'`@571I;#HZ<&9O<FU);G!U="@I(#\^"CQI;G!U="!T>7!E/2)H:61D
M96XB(&YA;64](F%C=&EO;DE$(B!V86QU93TB8V%N8V5L7W!R;V)L96U?<F5P
M;W)T(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)R971U<FY?=7)L
M(B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*%5T:6PZ.F=E
M=$9O<FU$871A*"=R971U<FY?=7)L)RDI(#\^(B`O/@H*/'1A8FQE(&-E;&QP
M861D:6YG/2(S(B!C96QL<W!A8VEN9STB,B(@=VED=&@](C$P,"4B/@H\='(@
M8VQA<W,](FAE861E<B(^"B`@("`\=&0@8V]L<W!A;CTB,B(@8VQA<W,](FAE
M861E<B(^/#]P:'`@96-H;R!?*")$97-C<FEB92!T:&4@4')O8FQE;2(I(#\^
M/"]T9#X*/"]T<CX*"CQT<CX*("`@(#QT9"!C;&%S<STB;&EG:'0@<FEG:'1!
M;&EG;B(^/#]P:'`@96-H;R!?*")9;W5R($YA;64B*2`_/CPO=&0^"B`@("`\
M=&0^/&EN<'5T('1Y<&4](G1E>'0B('1A8FEN9&5X/2(Q(B!N86UE/2)N86UE
M(B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1N86UE*2`_
M/B(@<VEZ93TB-S`B("\^/"]T9#X*/"]T<CX*"CQT<CX*("`@(#QT9"!C;&%S
M<STB;&EG:'0@<FEG:'1!;&EG;B(^/#]P:'`@96-H;R!?*")9;W5R($5M86EL
M($%D9')E<W,B*2`_/CPO=&0^"B`@("`\=&0^/&EN<'5T('1Y<&4](G1E>'0B
M('1A8FEN9&5X/2(R(B!N86UE/2)E;6%I;"(@=F%L=64](CP_<&AP(&5C:&\@
M:'1M;'-P96-I86QC:&%R<R@D96UA:6PI(#\^(B!S:7IE/2(W,"(@+SX\+W1D
M/@H\+W1R/@H*/'1R/@H@("`@/'1D(&-L87-S/2)L:6=H="!R:6=H=$%L:6=N
M(CX\/W!H<"!E8VAO(%\H(E-H;W)T(%-U;6UA<GDB*2`_/CPO=&0^"B`@("`\
M=&0^/&EN<'5T('1Y<&4](G1E>'0B('1A8FEN9&5X/2(S(B!N86UE/2)S=6)J
M96-T(B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1S=6)J
M96-T*2`_/B(@<VEZ93TB-S`B("\^/"]T9#X*/"]T<CX*"CQT<CX*("`@(#QT
M9"!C;VQS<&%N/2(R(B!C;&%S<STB<VUA;&QH96%D97(B/CP_<&AP(&5C:&\@
M7R@B1G5L;"!$97-C<FEP=&EO;B(I(#\^/"]T9#X*/"]T<CX*/'1R/@H@("`@
M/'1D/CPO=&0^"B`@("`\=&0^/'1E>'1A<F5A('1A8FEN9&5X/2(T(B!N86UE
M/2)M97-S86=E(B!R;W=S/2(R,"(@8V]L<STB.#`B('=R87`](FAA<F0B/CP_
M<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D;65S<V%G92D@/SX\+W1E>'1A
M<F5A/CPO=&0^"CPO='(^"@H\='(^"B`@/'1D/CPO=&0^"B`@/'1D(&-L87-S
M/2)L:6=H="(^"B`@("`\:6YP=70@8VQA<W,](F)U='1O;B(@='EP93TB<W5B
M;6ET(B!N86UE/2)F;W)M<W5B;6ET(B!O;F-L:6-K/2)R971U<FX@=F%L:61A
M=&4H*3LB('9A;'5E/2(\/W!H<"!E8VAO(%\H(E-E;F0@4')O8FQE;2!297!O
M<G0B*2`_/B(@+SX*("`@(#QI;G!U="!C;&%S<STB8G5T=&]N(B!T>7!E/2)S
M=6)M:70B(&YA;64](F9O<FUS=6)M:70B('9A;'5E/2(\/W!H<"!E8VAO(%\H
M(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(I(#\^(B`O/@H@(#PO=&0^"CPO='(^
M"@H\+W1A8FQE/@H\+V9O<FT^"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1E;7!L871E<R]C;VUM;VXM9F]O=&5R+FEN8P``````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3`S,R`Q,#4Q-30S,S<T
M-2`P,C,P,30`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/'-C<FEP="!L86YG=6%G93TB2F%V85-C<FEP=#$N-2(@='EP93TB
M=&5X="]J879A<V-R:7!T(CX*/"$M+0IV87(@7W-E=$AO<F1E5&ET;&4@/2`Q
M.PIT<GD@>PH@("`@:68@*&1O8W5M96YT+G1I=&QE("8F('!A<F5N="YF<F%M
M97,N:&]R9&5?;6%I;BD@<&%R96YT+F1O8W5M96YT+G1I=&QE(#T@9&]C=6UE
M;G0N=&ET;&4["GT@8V%T8V@@*&4I('L*?0HO+R`M+3X*/"]S8W)I<'0^"CQS
M8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*/"$M+0II9B`H='EP96]F
M*%]S971(;W)D951I=&QE*2`]/2`G=6YD969I;F5D)R`F)B!D;V-U;65N="YT
M:71L92`F)B!P87)E;G0N9G)A;65S+FAO<F1E7VUA:6XI('!A<F5N="YD;V-U
M;65N="YT:71L92`](&1O8W5M96YT+G1I=&QE.PHO+R`M+3X*/"]S8W)I<'0^
M"CP_<&AP(&EF("AI<W-E="@D1TQ/0D%,4ULG;F]T:69I8V%T:6]N)UTI*2`D
M1TQ/0D%,4ULG;F]T:69I8V%T:6]N)UTM/FYO=&EF>2AA<G)A>2@G;&ES=&5N
M97)S)R`]/B!A<G)A>2@G:F%V87-C<FEP="<I*2D[(#\^"CPO8F]D>3X*/"]H
M=&UL/@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]C;VUM;VXM:&5A9&5R+FEN
M8P``````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C<V-B`Q,#4Q
M-30S,S<T-2`P,C(W-C0`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*9VQO8F%L("1L86YG=6%G93L*:68@*&ES<V5T
M*"1L86YG=6%G92DI('L*("`@(&AE861E<B@G0V]N=&5N="UT>7!E.B!T97AT
M+VAT;6P[(&-H87)S970])R`N($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@(&AE
M861E<B@G5F%R>3H@06-C97!T+4QA;F=U86=E)RD["GT*/SX*/"%$3T-465!%
M(&AT;6P@4%5"3$E#("(M+R]7,T,O+T141"!82%1-3"`Q+C`@5')A;G-I=&EO
M;F%L+R]%3B(@(D141"]X:'1M;#$M=')A;G-I=&EO;F%L+F1T9"(^"CPA+2T@
M2&]R9&4Z($-O<'ER:6=H="`R,#`P+3(P,#8L(%1H92!(;W)D92!0<F]J96-T
M+B!(;W)D92!I<R!U;F1E<B!T:&4@3$=03"X@+2T^"CPA+2T@("`@("`@("`@
M("`@("`@("`@($AO<F1E(%!R;VIE8W0Z(&AT='`Z+R]H;W)D92YO<F<O("`@
M("`@("`@("`@("`@("`@("`@+2T^"CPA+2T@("`@1TY5($QI8G)A<GD@4'5B
M;&EC($QI8V5N<V4Z(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6P@("`@+2T^"CP_<&AP"F5C:&\@*"%E;7!T>2@D;&%N9W5A9V4I*2`_
M("<\:'1M;"!L86YG/2(G("X@<W1R='(H)&QA;F=U86=E+"`G7R<L("<M)RD@
M+B`G(B<@.B`G/&AT;6PG.PIE8VAO("@A96UP='DH)&EE7V-L:65N=&-A<',I
M*2`_("<@>&UL;G,Z244^)R`Z("<^)SL*/SX*/&AE860^"CP_<&AP"@HD<&%G
M95]T:71L92`]("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)VYA;64G*3L*
M:68@*"%E;7!T>2@D=&ET;&4I*2`D<&%G95]T:71L92`N/2`G(#HZ("<@+B`D
M=&ET;&4["FEF("@A96UP='DH)')E9G)E<VA?=&EM92D@)B8@(65M<'1Y*"1R
M969R97-H7W5R;"DI('L*("`@(&5C:&\@(CQM971A(&AT='`M97%U:78]7")R
M969R97-H7"(@8V]N=&5N=#U<(B1R969R97-H7W1I;64[=7)L/21R969R97-H
M7W5R;%PB("\^7&XB.PI]"@I(;W)D93HZ:6YC;'5D95-C<FEP=$9I;&5S*"D[
M"C\^"CQT:71L93X\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'!A9V5?
M=&ET;&4I(#\^/"]T:71L93X*/&QI;FL@:')E9CTB/#]P:'`@96-H;R`D1TQ/
M0D%,4ULG<F5G:7-T<GDG72T^9V5T26UA9V5$:7(H*2`_/B]F879I8V]N+FEC
M;R(@<F5L/2)32$]25$-55"!)0T].(B`O/@H\/W!H<"!E8VAO($AO<F1E.CIS
M='EL97-H965T3&EN:RA5=&EL.CIN;VY);G!U=%9A<B@G8W-S07!P<R<I*2`_
M/@H\/W!H<"!E8VAO(&EM<&QO9&4H(EQN(BP@571I;#HZ;F]N26YP=71687(H
M)VQI;FM486=S)RP@87)R87DH*2DI(#\^"CP_<&AP(&EF("@A96UP='DH)&EE
M7V-L:65N=&-A<',I*3H@/SX\<W1Y;&4^245<.F-L:65N=&-A<',@>V)E:&%V
M:6]R.G5R;"@C9&5F875L="-C;&EE;G1C87!S*7T\+W-T>6QE/CP_<&AP(&5N
M9&EF.R`_/@H\+VAE860^"@H\8F]D>3P_<&AP(&EF("A5=&EL.CIN;VY);G!U
M=%9A<B@G8F]D>4-L87-S)RDI(&5C:&\@)R!C;&%S<STB)R`N("1B;V1Y0VQA
M<W,@+B`G(B<[(#\^/@H\/W!H<"!I9B`H(65M<'1Y*"1I95]C;&EE;G1C87!S
M*2DZ(#\^/$E%.F-L:65N=&-A<',@240](F]B:D-#87!S(B`O/CP_<&AP(&5N
M9&EF.R`_/@H`````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M
M<&QA=&5S+RYH=&%C8V5S<P``````````````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P,#$V(#$P-3$U-#,S-S0U(#`R,3,S,P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!$96YY(&9R;VT@
M86QL"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<P``````````
M````````````````````````````````````````````````````````````
M```````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#`P,"`Q,#4Q-30S,S<U-"`P,38W-3``(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=E;FYE=FEL;&EE<G,`````````````````````````````
M`````````````````````````````````````````````#`P,#<U-2``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S0U(#`R,38Q-@`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9V5N;F5V:6QL:65R<R]I;F9O
M+G!H<```````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`W,30@,3`U
M,34T,S,W-#4@,#(S,S0S`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B!4:&ES('1H96UE(&%S(&)E96X@
M=W)I='1E;B!B>2!!:61E($9L;W)E;G0@/&9A:61E0&%L<&AA8V5N="YC;VT^
M(&%N9`H@*B!-Z6QA;FEE($=A<F5A=2`\;65L86YI92YG87)E875`=FEL;&4M
M9V5N;F5V:6QL:65R<RYF<CX*("H*("H@5&AE('1H96UE(&ED96$@=V%S('1O
M(&EN8V]R<&]R871E('-M;V]T:&QY(&EN('1H92!I;G1R86YE="X*("H@5&AI
M<R!T:&5M92!I<R!P=6)L:7-H960@=6YD97(@=&AE('-A;64@;&EC96YS92!A
M<R!T:&4@:&]R9&4@<&%C:V%G92X*("H*("H@5&AE(&YA;64@8V]M97,@9G)O
M;2!T:&4@8VET>2!O9B!'96YN979I;&QI97)S(&EN($9R86YC90H@*@H@*B`D
M2&]R9&4Z(&AO<F1E+W1H96UE<R]G96YN979I;&QI97)S+VEN9F\N<&AP+'8@
M,2XQ(#(P,#0O,3`O,3<@,3DZ,S,Z,S4@;61J=6MI8R!%>'`@)`H@*B\*"B1T
M:&5M95]N86UE(#T@7R@B5&5A;"(I.PH`````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=E;FYE=FEL;&EE<G,O<V-R965N+F-S<P``````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-C8U(#$P-3$U-#,S-S0U(#`R
M,S8W-P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```O*BH*("H@5&AI<R!T:&5M92!A<R!B965N('=R:71T96X@8GD@06ED92!&
M;&]R96YT(#QF86ED94!A;'!H86-E;G0N8V]M/B!A;F0*("H@3<.I;&%N:64@
M1V%R96%U(#QM96QA;FEE+F=A<F5A=4!V:6QL92UG96YN979I;&QI97)S+F9R
M/@H@*@H@*B!4:&4@=&AE;64@:61E82!W87,@=&\@:6YC;W)P;W)A=&4@<VUO
M;W1H;'D@:6X@=&AE(&EN=')A;F5T+@H@*B!4:&ES('1H96UE(&ES('!U8FQI
M<VAE9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!H;W)D92!P86-K
M86=E+@H@*@H@*B!4:&4@;F%M92!C;VUE<R!F<F]M('1H92!C:71Y(&]F($=E
M;FYE=FEL;&EE<G,@:6X@1G)A;F-E"B`J"B`J("1(;W)D93H@:&]R9&4O=&AE
M;65S+V=E;FYE=FEL;&EE<G,O<V-R965N+F-S<RQV(#$N-2XV+C,@,C`P-2\Q
M,"\Q."`Q,3HS-#HQ,R!J86X@17AP("0*("HO"@IB;V1Y('L*("`@(&)A8VMG
M<F]U;F0Z(",P,#8S-C,["B`@("!S8W)O;&QB87(M8F%S92UC;VQO<CH@(S8S
M8C5B-3L*("`@('-C<F]L;&)A<BUA<G)O=RUC;VQO<CH@(S8S8C5B-3L*?0IH
M=&UL('L*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C-C-B-6(U.PH@("`@
M<V-R;VQL8F%R+6%R<F]W+6-O;&]R.B`C-C-B-6(U.PI]"F$@>PH@("`@8V]L
M;W(Z(",Q,C)E8F$["GT*83IH;W9E<B!["B`@("!C;VQO<CH@(S$R,F5B83L*
M?0IA+G=I9&=E="!["B`@("!C;VQO<CH@(S`P,#L*?0IA+G=I9&=E=#IH;W9E
M<B!["B`@("!C;VQO<CH@(V9F9CL*?0HN:&5A9&5R+"`N<VUA;&QH96%D97(L
M(&$N<VUA;&QH96%D97(@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O
M=6YD.B`C-C-B-6(U.PI]"BYB=71T;VX@>PH@("`@8V]L;W(Z("-F9F8["B`@
M("!B86-K9W)O=6YD.B`C-#$X93AE.PH@("`@8F]R9&5R+6)O='1O;3H@=&AI
M;B!S;VQI9"`C-C`U.34Y.PH@("`@8F]R9&5R+7)I9VAT.B!T:&EN('-O;&ED
M(",V,#4Y-3D["B`@("!B;W)D97(M=&]P.B!T:&EN('-O;&ED("-C96-E8V4[
M"B`@("!B;W)D97(M;&5F=#H@=&AI;B!S;VQI9"`C9F9F.PI]"BYS96QE8W1E
M9"!["B`@("!B86-K9W)O=6YD.B`C-C-B-6(U.PI]"@HO*B!-96YU('-T>6QE
M<RX@*B\*(VUE;G4@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD
M.B`C-C-B-6(U.PI]"B-M96YU(&$@>PH@("`@8V]L;W(Z("-F9F8["GT*(VUE
M;G4@82YC=7)R96YT('L*("`@(&)A8VMG<F]U;F0Z(",T,3AE.&4["B`@("!C
M;VQO<CH@(V9F9CL*?0H*+RH@4VED96)A<B!S='EL97,N("HO"B-S:61E8F%R
M4&%N96P@>PH@("`@8F%C:V=R;W5N9#H@(S8S8C5B-3L*?0HC<VED96)A<E!A
M;F5L('-P86XL("-S:61E8F%R4&%N96P@82!["B`@("!C;VQO<CH@(V9F9CL*
M?0HC<VED96)A<E!A;F5L(&$Z:&]V97(@>PH@("`@8V]L;W(Z("-F9F8["GT*
M"B\J(%!R969E<F5N8V5S(&]V97)V:65W+B`J+PHN<')E9G-/=F5R=FEE=R!H
M,B!["B`@("!C;VQO<CH@(V9F9CL*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O87IU<@``
M````````````````````````````````````````````````````````````
M````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`P,#`@,3`U,34T,S,W-#4@,#$W-S,Q`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]A>G5R+VEN9F\N<&AP````````````````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#(U,"`Q,#4Q-30S,S<T-2`P,C$T-3$`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+V%Z=7(O:6YF;RYP:'`L
M=B`Q+C$@,C`P-"\Q,"\Q-R`Q.3HS,SHS,R!M9&IU:VEC($5X<"`D(#\^"B`J
M"B`J($!A=71H;W(@2F]O<W0@1&4@0V]C:R`\:F]O<W1`9&5C;V-K+F]R9SX*
M("HO"@HD=&AE;65?;F%M92`](%\H(D%Z=7(B*3L*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M87IU<B]S8W)E96XN8W-S````````````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#(T-S<@,3`U,34T,S,W-#4@,#(R,#$S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"\J*@H@*B!!=71H;W(Z
M($IO;W-T($1E($-O8VL@/&IO;W-T0&1E8V]C:RYO<F<^"B`J"B`J("1(;W)D
M93H@:&]R9&4O=&AE;65S+V%Z=7(O<V-R965N+F-S<RQV(#$N-2XV+C4@,C`P
M-2\Q,2\Q-2`P-CHT,3HP,B!S96QS:WD@17AP("0*("HO"@IB;V1Y('L*("`@
M(&)A8VMG<F]U;F0Z(",V-&$W8SD["GT*82!["B`@("!C;VQO<CH@(S,S.3L*
M?0IA+G=I9&=E=#IH;W9E<B!["B`@("!C;VQO<CH@(S8V-CL*("`@(&)A8VMG
M<F]U;F0M8V]L;W(Z("-F9F8["GT*+FAE861E<B!["B`@("!C;VQO<CH@(V9F
M9CL*("`@(&)A8VMG<F]U;F0Z(",P-CD["GT*+FAE861E<B!A('L*("`@(&-O
M;&]R.B`C9F9F.PI]"BYS;6%L;&AE861E<B!["B`@("!C;VQO<CH@(V9F9CL*
M("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",P-CD["GT*82YS;6%L;&AE861E<B![
M"B`@("!C;VQO<CH@(V9F9CL*?0HN8G5T=&]N('L*("`@(&)A8VMG<F]U;F0M
M8V]L;W(Z(",P-CD["B`@("!C;VQO<CH@(V9F9CL*("`@(&)O<F1E<BUB;W1T
M;VTZ(#%P>"!S;VQI9"`C,C(T.PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L
M:60@(S(R-#L*("`@(&)O<F1E<BUT;W`Z(#%P>"!S;VQI9"`C.3EC.PH@("`@
M8F]R9&5R+6QE9G0Z(#%P>"!S;VQI9"`C.3EC.PI]"@HO*B!-96YU('-T>6QE
M<RX@*B\*(VUE;G4@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD
M+6-O;&]R.B`C,#8Y.PI]"B-M96YU(&$@>PH@("`@8V]L;W(Z("-F9F8["GT*
M(VUE;G4@82YC=7)R96YT('L*("`@(&)A8VMG<F]U;F0Z(",V-&$W8SD["B`@
M("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(V5E93L*("`@(&)O<F1E<BUR
M:6=H=#H@,7!X('-O;&ED("-E964["B`@("!B;W)D97(M;&5F=#H@,7!X('-O
M;&ED(",P,#`["B`@("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(S`P,#L*("`@
M('!A9&1I;F<Z(#)P>#L*?0HC;65N=2!A.FAO=F5R('L*("`@(&)O<F1E<BUB
M;W1T;VTZ(#%P>"!S;VQI9"`C965E.PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@
M<V]L:60@(V5E93L*("`@(&)O<F1E<BUL969T.B`Q<'@@<V]L:60@(S`P,#L*
M("`@(&)O<F1E<BUT;W`Z(#%P>"!S;VQI9"`C,#`P.PH@("`@<&%D9&EN9SH@
M,G!X.PI]"@HO*B!3:61E8F%R('-T>6QE<RX@*B\*(W-I9&5B87)086YE;"![
M"B`@("!B;W)D97(M8V]L;W(Z('1R86YS<&%R96YT.PH@("`@8F%C:V=R;W5N
M9"UC;VQO<CH@(V)C9#9E,CL*?0H*+RH@5&%B('-T>6QE<RX@*B\*+G1A8G-E
M="!L:2YA8W1I=F5486(@82P@+G1A8G-E="!L:2YA8W1I=F5486(@83IH;W9E
M<B!["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(S`V.3L*("`@(&)A
M8VMG<F]U;F0M8V]L;W(Z(",P-CD["GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F5Y````````````````````````
M````````````````````````````````````````````````````````````
M```P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S
M,S<T-2`P,3<W,38`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R97DO
M:6YF;RYP:'``````````````````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,38V(#$P-3$U-#,S-S0U(#`R,30T-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@)$AO<F1E
M.B!H;W)D92]T:&5M97,O9W)E>2]I;F9O+G!H<"QV(#$N,2`R,#`T+S$P+S$W
M(#$Y.C,S.C,V(&UD:G5K:6,@17AP("0*("HO"@HD=&AE;65?;F%M92`](%\H
M(D=R97DB*3L*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F5Y+W-C<F5E;BYC<W,`
M````````````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S$R,"`Q
M,#4Q-30S,S<T-2`P,C$W-C(`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+V=R
M97DO<V-R965N+F-S<RQV(#$N-RXV+C$S(#(P,#4O,3`O,3@@,3$Z,S0Z,3@@
M:F%N($5X<"`D"B`J+PH*8F]D>2!["B`@("!B86-K9W)O=6YD.B`C-60U9#8P
M.PH@("`@<V-R;VQL8F%R+6)A<V4M8V]L;W(Z(",U9#5D-C`["B`@("!S8W)O
M;&QB87(M87)R;W<M8V]L;W(Z(",U9#5D-C`["GT*:'1M;"!["B`@("!S8W)O
M;&QB87(M8F%S92UC;VQO<CH@(S5D-60V,#L*("`@('-C<F]L;&)A<BUA<G)O
M=RUC;VQO<CH@(S5D-60V,#L*?0IA('L*("`@(&-O;&]R.B`C-3DU.34Y.PI]
M"BYW:61G970@>PH@("`@8V]L;W(Z(",S,S,["B`@("!F;VYT+7=E:6=H=#H@
M8F]L9#L*?0IA+G=I9&=E=#IH;W9E<B!["B`@("!C;VQO<CH@(S`P,#L*("`@
M(&)A8VMG<F]U;F0Z("-D9&0["B`@("!T97AT+61E8V]R871I;VXZ(&YO;F4[
M"GT*+FAE861E<B!["B`@("!C;VQO<CH@(V1D9#L*("`@(&)A8VMG<F]U;F0Z
M(",U-#4T-38["GT*+FAE861E<B!A('L*("`@(&-O;&]R.B`C9&1D.PI]"F$N
M;&EG:'0Z:&]V97(@>PH@("`@8V]L;W(Z("-F9F8["GT*+G-M86QL:&5A9&5R
M('L*("`@(&-O;&]R.B`C.68Y9F$P.PH@("`@8F%C:V=R;W5N9#H@(S4T-30U
M-CL*?0HN8G5T=&]N('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N
M9#H@(S4Q-3$V,SL*("`@(&)O<F1E<BUB;W1T;VTZ('1H:6X@<V]L:60@(S5D
M-60V,#L*("`@(&)O<F1E<BUR:6=H=#H@=&AI;B!S;VQI9"`C-60U9#8P.PH@
M("`@8F]R9&5R+71O<#H@=&AI;B!S;VQI9"`C-S<W-S@Y.PH@("`@8F]R9&5R
M+6QE9G0Z('1H:6X@<V]L:60@(S<W-S<X.3L*?0HN:71E;2!["B`@("!C;VQO
M<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0Z("-E964["GT*+G-E;&5C=&5D('L*
M("`@(&)A8VMG<F]U;F0Z("-D9&0["GT*"B\J($UE;G4@<W1Y;&5S+B`J+PHC
M;65N=2!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z(",U-#4T
M-38["GT*(VUE;G4@82!["B`@("!C;VQO<CH@(V9F9CL*?0HC;65N=2!A+F-U
M<G)E;G0@>PH@("`@8F%C:V=R;W5N9#H@(S8V-CL*?0H*+RH@4VED96)A<B!S
M='EL97,N("HO"B-S:61E8F%R4&%N96P@>PH@("`@8F%C:V=R;W5N9#H@(S8V
M-CL*?0HC<VED96)A<E!A;F5L('-P86XL("-S:61E8F%R4&%N96P@82!["B`@
M("!C;VQO<CH@(V9F9CL*?0HC<VED96)A<E!A;F5L(&$Z:&]V97(@>PH@("`@
M8V]L;W(Z('EE;&QO=SL*?0H*+RH@5&%B('-T>6QE<RX@*B\*+G1A8G-E="![
M"B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(S4T-30U-CL*?0HN=&%B
M<V5T(&QI(&$@>PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",U-#4T
M-38["B`@("!B86-K9W)O=6YD.B`C93EE.64Y.PI]"BYT86)S970@;&DN86-T
M:79E5&%B(&$@>PH@("`@8V]L;W(Z("-D9&0["B`@("!B86-K9W)O=6YD.B`C
M-30U-#4V.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",U-#4T-38[
M"GT*+G1A8G-E="!L:2YA8W1I=F5486(@83IH;W9E<B!["B`@("!C;VQO<CH@
M(V9F9CL*("`@(&)A8VMG<F]U;F0Z(",U-#4T-38["GT*"B\J(%!R969E<F5N
M8V5S(&]V97)V:65W+B`J+PHN<')E9G-/=F5R=FEE=R!H,B!["B`@("!C;VQO
M<CH@(V9F9CL*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O3F585&=R97D`````````````````
M````````````````````````````````````````````````````````````
M````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T
M,S,W-#4@,#(P-#4U`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R].95A4
M9W)E>2]I;F9O+G!H<```````````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#$W,B`Q,#4Q-30S,S<T-2`P,C(R,#``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D
M93H@:&]R9&4O=&AE;65S+TYE6%1G<F5Y+VEN9F\N<&AP+'8@,2XQ(#(P,#0O
M,3`O,3<@,3DZ,S,Z,S,@;61J=6MI8R!%>'`@)`H@*B\*"B1T:&5M95]N86UE
M(#T@7R@B3F585"(I.PH`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O3F585&=R97DO<V-R965N
M+F-S<P``````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(R,C(@
M,3`U,34T,S,W-#4@,#(R-3(S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R].
M95A49W)E>2]S8W)E96XN8W-S+'8@,2XV+C8N,R`R,#`U+S$P+S$X(#$Q.C,T
M.C$P(&IA;B!%>'`@)`H@*B\*"F)O9'D@>PH@("`@8F%C:V=R;W5N9#H@(S0T
M-#L*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C86-A.6%C.PH@("`@<V-R
M;VQL8F%R+6%R<F]W+6-O;&]R.B`C86-A.6%C.PI]"FAT;6P@>PH@("`@<V-R
M;VQL8F%R+6)A<V4M8V]L;W(Z("-A8V$Y86,["B`@("!S8W)O;&QB87(M87)R
M;W<M8V]L;W(Z("-A8V$Y86,["GT*82P@82YF:7AE9"!["B`@("!C;VQO<CH@
M(S,S.3L*?0IA+G=I9&=E="!["B`@("!C;VQO<CH@(S`P,#L*?0IA+G=I9&=E
M=#IH;W9E<B!["B`@("!C;VQO<CH@=VAI=&4["B`@("!B86-K9W)O=6YD.B`C
M8V-C.PI]"BYH96%D97(@>PH@("`@8V]L;W(Z(",Y9CEF83`["B`@("!B86-K
M9W)O=6YD.B`C,#`P.PI]"BYH96%D97(@82!["B`@("!C;VQO<CH@(SEF.69A
M,#L*?0HN<VUA;&QH96%D97(@>PH@("`@8V]L;W(Z(",Y9CEF83`["B`@("!B
M86-K9W)O=6YD.B`C,#`P.PI]"BYB=71T;VX@>PH@("`@8V]L;W(Z(",P,#`[
M"B`@("!B86-K9W)O=6YD+6-O;&]R.B`C86-A.6%C.PH@("`@8F]R9&5R+6)O
M='1O;3H@=&AI;B!S;VQI9"`C,C(R.PH@("`@8F]R9&5R+7)I9VAT.B!T:&EN
M('-O;&ED(",R,C(["B`@("!B;W)D97(M=&]P.B!T:&EN('-O;&ED("-D9&0[
M"B`@("!B;W)D97(M;&5F=#H@=&AI;B!S;VQI9"`C9&1D.PI]"BYS96QE8W1E
M9"!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C86-A.6%C.PI]"@HO*B!-96YU
M('-T>6QE<RX@*B\*(VUE;G4@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K
M9W)O=6YD+6-O;&]R.B`C86-A.6%C.PI]"B-M96YU(&@Q('L*("`@(&-O;&]R
M.B`C,#`P.PI]"B-M96YU(&$@>PH@("`@8V]L;W(Z("-F9F8["GT*(VUE;G4@
M82YC=7)R96YT('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",X-S@W.#<["B`@
M("!C;VQO<CH@(V1D9#L*?0H*+RH@4VED96)A<B!S='EL97,N("HO"B-S:61E
M8F%R4&%N96P@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(SDY.3L*("`@(&)O
M<F1E<BUR:6=H=#H@,7!X('-O;&ED(",R,C(["B`@("!B;W)D97(M8F]T=&]M
M.B`Q<'@@<V]L:60@(S(R,CL*?0HC97AP86YD0G5T=&]N('L*("`@(&UA<F=I
M;BUR:6=H=#H@,7!X.PI]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]C;W)N9FQO=V5R````````````````````````````````````
M```````````````````````````````````````````P,#`W-34@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<T-B`P,C$Q,S$`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V-O<FYF;&]W97(O9W)A<&AI8W,`
M````````````````````````````````````````````````````````````
M`````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U
M-#,S-S0V(#`R,C<S,0`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O8V]R
M;F9L;W=E<B]G<F%P:&EC<R]T86)?8F]T=&]M+F=I9@``````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`R,#$@,3`U,34T,S,W-#4@,#(U-C(Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````$=)1C@Y810``0"$(`#=X]7;
MX=/^_O[R].[FZ>#:X-+\_/SU]_+Y^??J[>3@Y-;EZ-[N\>KM\.GO\NOBY=KX
M^/;W]_7S]?#I[./Z^OC[^_OK[N=W9E7CYMODY]W]_?WL[^CAY-GQ\^[@X]CH
MZ^(L`````!0``0``!0;@)8YD688`.P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V-O<FYF;&]W97(O9W)A
M<&AI8W,O=&%B7W)I9VAT+F=I9@``````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q-S,P
M(#$P-3$U-#,S-S0V(#`R-30T,P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!'248X.6&0`98`A!``PLK-O<O6PM#:S-??T=SC
MWN;JWN;KYNWP[?+T\?;Y[_?Z\O;Y\_?X]?;X]??Y\_C[________________
M________________________________________________+`````"0`98`
M``7^("".9&F>:*JN;.N^<"S/=&W?>*[O;R`0#HA002P:C\BD<LEL.I_0J'1*
MK5JOV*QVR^U&'89!H"!,F,_HM'K-;KO?\+A\3J_;[_B\?L_O^_]S#H('`080
M#XB)BHN,C8Z/D)&2DY25EI>8F9J;G)V>GZ"AE8*#`0X+J*FJJZRMKJ^PL;*S
MM+6VM[BYNKN\O;Z_P,&UI((#!`S(R<K+S,W.S]#1TM/4U=;7V-G:V]S=WM_@
MX=7$8`+BY^CIZNOL[>[O\.CD"`$-]O?X^?K[_/W^_P`#"AQ(L*#!@P@3*ES(
ML*'#AP/).0@0KZ+%BQ@S:MS(D9E$BAU#BAQ)LJ3)=A_^3ZI<R;*ERXXI7\J<
M2;.FS6@Q;^K<R;/GQIP^@PH=2E0;T*)(DRH=>G2ITZ=063:-2K6J58M3KVK=
MRM5;UJY@PXK%.7&LV;-HDPD"F;:MVZMKW\J=ZS0NW;MX?=K-R[>OS+U^`PLF
M"7BPX<,7"R->S%B=XL:0(W-[++FR96F4+VO>C"PSY\^2/8,>O5@TZ=."3:->
MG5<UZ]=R7<.>C58V[=MA;>/>K54W[]]1?0,?KE0X\>-,RR)?#E<Y\^=0C4.?
M_M<Y]>O)V6+?WE,Z]^\AO8,?GU$\^?/QS*-?STX]^_?GW,.?[]4Z_?N)[>/?
M_TX^__]D:0?@@/+H1^"!]0G^B.""V_C'X(`./OA?A!+N1V&%]UV(X7P:;OA>
MAQZN!V*(YXU(XG@FGOA=BBINQV*+U[T(XW0RSOA<C38NAV..Q^W(XW`^_OA;
MD$+N1F21MQV)Y&Q*+OE:DTZN!F64ITU)Y6A67OE9EEINQF67EWT)9F5BCAE9
MF68VAF::I1G()GMKOFE8G'*FYF:=Y-&)9U]Z[MG:G7YRUV>@=`U*:&R`'DJ=
MH8JVQ6BCM24**7./3CI6I9;F)FFFQ&'**5>>?MK;IJ+R%FJI59V*:G"DKDJ;
MJJ[6U6JL3\Y*JY2VWEIEKKIBR6NO6_X*K)?"#AMFL<:2B6RR9R[+K)K./MNF
M@M)@XDIMM;M>BZVOVFX;;+?>$@MNN,>.2ZZRYI[;;+KJ0LMNN]/"RZV\H,%*
M[TKVWGM2OOJ6Q&^_(_T+<'C1#IR6P`;_5'#"9B',,$8./XS5PA*#%7'%\%R,
ML3L:;]S>1"$``#L`````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V-O<FYF;&]W
M97(O9W)A<&AI8W,O=&%B7VQE9G0N9VEF````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P,S`S(#$P-3$U-#,S-S0V(#`R-3(U,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!'248X.6$'`)8`XP,`NLG4[?+TV.'G
M____QM/<W.3I\_?XP]#:RM;=WN;K\O;WT-OBOLS7X^GM________+``````'
M`)8```1X<,A1")"!D12&8H4B#H=@G$9S**BQ+*V!F"U2Q#9^USN:\[H@<.CK
MG7Y%89)X-,J<R*92RGQ.K=4H=LFE=K?>,'BL+4//5W,:G65_U>VU/$Y_N\5P
M^UQ?Q]_)?WE^>X-]@(2'AH*)?(V%CHR/DI&4BY:!F(B7FG\1`#L`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]C;W)N9FQO=V5R+VEN9F\N<&AP
M````````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#(P,B`Q,#4Q
M-30S,S<T-B`P,C(V-#8`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S
M+V-O<FYF;&]W97(O:6YF;RYP:'`L=B`Q+C$@,C`P-"\Q,"\Q-R`Q.3HS,SHS
M-2!M9&IU:VEC($5X<"`D"B`J+PH*)'1H96UE7VYA;64@/2!?*")#;W)N9FQO
M=V5R(BD["@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O8V]R;F9L;W=E<B]S8W)E96XN8W-S````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#8U,C<@,3`U,34T,S,W-#8@,#(S
M,C$S`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]C;W)N9FQO=V5R+W-C<F5E
M;BYC<W,L=B`Q+C@N-BXT(#(P,#4O,3`O,3@@,3$Z,S0Z,3,@:F%N($5X<"`D
M"B`J+PH*8F]D>2!["B`@("!B86-K9W)O=6YD.B`C9F9F.PH@("`@9F]N="UF
M86UI;'DZ(%9E<F1A;F$L($=E;F5V82P@07)I86PL($AE;'9E=&EC82P@<V%N
M<RUS97)I9CL*?0IA('L*("`@(&-O;&]R.B`C,S,Y.PI]"F$N9FEX960@>PH@
M("`@8V]L;W(Z(",S,SD["GT*82YW:61G970@>PH@("`@8V]L;W(Z(",P,#`[
M"GT*:6YP=70@>PH@("`@9F]N="UF86UI;'DZ(%9E<F1A;F$L($=E;F5V82P@
M07)I86PL($AE;'9E=&EC82P@<V%N<RUS97)I9CL*("`@(&)A8VMG<F]U;F0Z
M("-F9F8["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C-C8V.PI]"G1E>'1A<F5A
M('L*("`@(&-O;&]R.B`C,S,S.PH@("`@8F%C:V=R;W5N9#H@(V9F9CL*("`@
M(&)O<F1E<CH@,7!X('-O;&ED(",V-C8["GT*<V5L96-T+&]P=&EO;B!["B`@
M("!C;VQO<CH@(S`P,#`S,SL*("`@(&)A8VMG<F]U;F0Z("-F8V9C9F,["GT*
M"B\J(%-I9&5B87(@<W1Y;&5S+B`J+PHC<VED96)A<E!A;F5L('L*("`@(&)O
M<F1E<BUR:6=H=#H@,7!X('-O;&ED(",P,#8["B`@("!B;W)D97(M8F]T=&]M
M.B`Q<'@@<V]L:60@(S`P-CL*("`@(&)A8VMG<F]U;F0Z("-F,V8W9C@["GT*
M(W-I9&5B87)086YE;"!A('L*("`@(&)O<F1E<CH@,7!X('-O;&ED("-F,V8W
M9C@["B`@("!P861D:6YG+6QE9G0Z(#%P>#L*("`@('!A9&1I;F<M8F]T=&]M
M.B`R<'@["GT*(W-I9&5B87)086YE;"!A.FAO=F5R('L*("`@(&)A8VMG<F]U
M;F0Z("-C8V,["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C,#`P.PH@("`@=&5X
M="UD96-O<F%T:6]N.B!N;VYE.PI]"B-E>'!A;F1"=71T;VX@>PH@("`@;6%R
M9VEN+7)I9VAT.B`Q<'@["GT*"B\J($UE;G4@<W1Y;&5S+B`J+PHC;65N=2![
M"B`@("!B86-K9W)O=6YD.B`C8V-C8V4U.PH@("`@8F]R9&5R+6)O='1O;3H@
M,G!X('-O;&ED(",P,#8["B`@("!C;VQO<CH@(S`P,#L*?0HC;65N=2!A('L*
M("`@(&-O;&]R.B`C,#`P.PH@("`@9F]N="UF86UI;'DZ(%9E<F1A;F$L2&5L
M=F5T:6-A+'-A;G,M<V5R:68["B`@("!F;VYT+7-I>F4Z(#$Q<'@["B`@("!F
M;VYT+7=E:6=H=#H@;F]R;6%L.PI]"B-M96YU(&$Z:&]V97(@>PH@("`@8V]L
M;W(Z("-F9F8["B`@("!B;W)D97(Z(&YO;F4["B`@("!P861D:6YG.B`S<'@[
M"GT*(VUE;G4@82YC=7)R96YT('L*("`@(&)A8VMG<F]U;F0Z("-F,V8W9C@[
M"B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(V1D9#L*("`@(&)O<F1E
M<BUR:6=H=#H@,7!X('-O;&ED("-D9&0["B`@("!B;W)D97(M;&5F=#H@,7!X
M('-O;&ED(",P,#`["B`@("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(S`P,#L*
M("`@('!A9&1I;F<Z(#)P>#L*?0HC;65N=2!A+F-U<G)E;G0Z:&]V97(@>PH@
M("`@8V]L;W(Z(",P,#`["B`@("!P861D:6YG.B`R<'@["GT*"BYH96%D97(@
M>PH@("`@8V]L;W(Z(",S,S,["B`@("!B86-K9W)O=6YD.B`C8V-C8V4U.PH@
M("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",S,SD["GT*82YH96%D97(Z
M:&]V97(@>PH@("`@8V]L;W(Z(",P,V,["B`@("!T97AT+61E8V]R871I;VXZ
M(&YO;F4["GT*82YH96%D97(@>PH@("`@8F]R9&5R+6)O='1O;3H@;F]N93L*
M("`@(&)A8VMG<F]U;F0M:6UA9V4Z(&YO;F4["B`@("!B86-K9W)O=6YD.B!T
M<F%N<W!A<F5N=#L*?0HN;&EG:'0@>PH@("`@8V]L;W(Z(",S,S,["GT*+G-M
M86QL:&5A9&5R('L*("`@(&)A8VMG<F]U;F0M:6UA9V4Z(&YO;F4["B`@("!B
M86-K9W)O=6YD.B!T<F%N<W!A<F5N=#L*("`@(&-O;&]R.B`C,S,S.PH@("`@
M9F]N="UF86UI;'DZ(%9E<F1A;F$L2&5L=F5T:6-A+'-A;G,M<V5R:68["B`@
M("!F;VYT+7-I>F4Z(#$Q<'@["GT*+G-M86QL:&5A9&5R(&$@>PH@("`@8V]L
M;W(Z(",S,SD["GT*82YS;6%L;&AE861E<CIH;W9E<B!["B`@("!C;VQO<CH@
M(S`S8SL*?0HN8V]N=')O;"!["B`@("!B86-K9W)O=6YD.B`C9&1D.PI]"BYI
M=&5M('L*("`@(&)A8VMG<F]U;F0Z("-E.64Y93D["GT*+RH@06QT97)N871I
M;F<@<W1Y;&5S+B!I=&5M,"P@:71E;3$@87)E(&1E<')E8V%T960N("HO"BYR
M;W=%=F5N+"`N:71E;3`@>PH@("`@8F%C:V=R;W5N9#H@(V5E93L*?0HN<F]W
M3V1D+"`N:71E;3$@>PH@("`@8F%C:V=R;W5N9#H@(V9F9CL*?0HN8G5T=&]N
M('L*("`@(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N9#H@(V-C8SL*("`@
M(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C,S,S.PH@("`@8F]R9&5R+7)I
M9VAT.B`Q<'@@<V]L:60@(S`P,#L*("`@(&)O<F1E<BUL969T.B`Q<'@@<V]L
M:60@(V,T8S1B.#L*("`@(&)O<F1E<BUT;W`Z(#%P>"!S;VQI9"`C8S1C-&(X
M.PH@("`@+6UO>BUB;W)D97(M<F%D:75S.B`U<'@["GT*+F)U='1O;CIH;W9E
M<B!["B`@("!B86-K9W)O=6YD.B`C8V1F.PI]"BYS96QE8W1E9"!["B`@("!B
M86-K9W)O=6YD.B`C8S9D,V9F.PI]"@HO*B!486(@<W1Y;&5S+B`J+PHN=&%B
M<V5T('L*("`@(&)A8VMG<F]U;F0Z("-F9F8@=7)L*")G<F%P:&EC<R]T86)?
M8F]T=&]M+F=I9B(I(')E<&5A="UX(&)O='1O;3L*("`@(&9O;G0M<VEZ93H@
M,3%P>#L*?0HN=&%B<V5T(&QI('L*("`@(&UA<F=I;CH@,#L*("`@(&)A8VMG
M<F]U;F0Z('5R;"@B9W)A<&AI8W,O=&%B7W)I9VAT+F=I9B(I(&YO+7)E<&5A
M="!R:6=H="!T;W`["GT*+G1A8G-E="!L:2!A+"`N=&%B<V5T(&QI(&$Z:&]V
M97(@>PH@("`@8F%C:V=R;W5N9#H@=7)L*")G<F%P:&EC<R]T86)?;&5F="YG
M:68B*2!N;RUR97!E870@;&5F="!T;W`["B`@("!M87)G:6XZ(#`["B`@("!P
M861D:6YG.B`S<'@@,35P>#L*("`@(&-O;&]R.B`C-S8U.PH@("`@8F]R9&5R
M.B!N;VYE.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",W-C4["GT*
M+G1A8G-E="!L:2!A.FAO=F5R('L*("`@(&-O;&]R.B`C,S,S.PH@("`@8F%C
M:V=R;W5N9#H@=7)L*")G<F%P:&EC<R]T86)?;&5F="YG:68B*2!N;RUR97!E
M870@;&5F="!T;W`["GT*+G1A8G-E="!L:2YA8W1I=F5486(@>PH@("`@8F%C
M:V=R;W5N9#H@=7)L*")G<F%P:&EC<R]T86)?<FEG:'0N9VEF(BD@;F\M<F5P
M96%T(')I9VAT('1O<#L*?0HN=&%B<V5T(&QI+F%C=&EV951A8B!A('L*("`@
M(&-O;&]R.B`C,S,S.PH@("`@8F%C:V=R;W5N9#H@=7)L*")G<F%P:&EC<R]T
M86)?;&5F="YG:68B*2!N;RUR97!E870@;&5F="!T;W`["B`@("!B;W)D97(M
M8F]T=&]M.B`Q<'@@<V]L:60@(V9F9CL*?0HN=&%B<V5T(&QI+F%C=&EV951A
M8B!A.FAO=F5R('L*("`@(&-O;&]R.B`C.3DY.PH@("`@8F%C:V=R;W5N9#H@
M=7)L*")G<F%P:&EC<R]T86)?;&5F="YG:68B*2!N;RUR97!E870@;&5F="!T
M;W`["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(V9F9CL*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V)R;W=N````````````````````````````````
M`````````````````````````````````````````````````````#`P,#<U
M-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S0V(#`R
M,#$P,``@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O8G)O=VXO:6YF;RYP
M:'``````````````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`Q
M-S`@,3`U,34T,S,W-#8@,#(Q-C(Q`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E
M+W1H96UE<R]B<F]W;B]I;F9O+G!H<"QV(#$N,2`R,#`T+S$P+S$W(#$Y.C,S
M.C,T(&UD:G5K:6,@17AP("0*("HO"@HD=&AE;65?;F%M92`](%\H(D)R;W=N
M(BD["@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V)R;W=N+W-C<F5E;BYC<W,`````````
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-3(T(#$P-3$U-#,S
M-S0V(#`R,C$U,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````O*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O8G)O=VXO<V-R
M965N+F-S<RQV(#$N-BXV+C(@,C`P-B\P,B\R,B`R,CHU-3HP-R!S;'5S87)Z
M($5X<"`D"B`J+PH*8F]D>2!["B`@("!B86-K9W)O=6YD.B`C-3`U,#4P.PH@
M("`@<V-R;VQL8F%R+6)A<V4M8V]L;W(Z(",U,#4P-3`["B`@("!S8W)O;&QB
M87(M87)R;W<M8V]L;W(Z("-C9F-F8F(["GT*:'1M;"!["B`@("!S8W)O;&QB
M87(M8F%S92UC;VQO<CH@(S4P-3`U,#L*("`@('-C<F]L;&)A<BUA<G)O=RUC
M;VQO<CH@(V-F8V9B8CL*?0IA('L*("`@(&-O;&]R.B`C-3`U,#4P.PI]"F$Z
M:&]V97(@>PH@("`@8V]L;W(Z(",U,#4P-3`["GT*82YW:61G970Z:&]V97(@
M>PH@("`@8V]L;W(Z(",U,#4P-3`["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C
M96)E8F0W.PI]"BYH96%D97(@>PH@("`@8V]L;W(Z(",U,#4P-3`["B`@("!B
M86-K9W)O=6YD.B`C8F)A.PI]"BYS;6%L;&AE861E<B!["B`@("!C;VQO<CH@
M(S4P-3`U,#L*("`@(&)A8VMG<F]U;F0Z("-B8F$["GT*+F-O;G1R;VP@>PH@
M("`@8F%C:V=R;W5N9#H@(V1E9&5B8CL*?0HN:71E;2!["B`@("!B86-K9W)O
M=6YD+6-O;&]R.B`C96)E8F0W.PI]"BYB=71T;VX@>PH@("`@8F%C:V=R;W5N
M9"UC;VQO<CH@(S4P-3`U,#L*("`@(&)O<F1E<BUB;W1T;VTZ('1H:6X@<V]L
M:60@(S(R-#L*("`@(&)O<F1E<BUR:6=H=#H@=&AI;B!S;VQI9"`C,C(T.PH@
M("`@8F]R9&5R+71O<#H@=&AI;B!S;VQI9"`C8V9C9F)B.PH@("`@8F]R9&5R
M+6QE9G0Z('1H:6X@<V]L:60@(V1E9&5B8CL*("`@(&-O;&]R.B`C9F9F.PI]
M"BYS96QE8W1E9"!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C8V1C9&-D.PI]
M"BYI=&5M,2!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C939E-F1E.PI]"@HO
M*B!-96YU('-T>6QE<RX@*B\*(VUE;G4@>PH@("`@8V]L;W(Z(",P,#`["B`@
M("!B86-K9W)O=6YD.B`C8F)A.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O
M;&ED(",P,#`["GT*(VUE;G4@82YC=7)R96YT('L*("`@(&)A8VMG<F]U;F0Z
M("-B9F)F86$["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(V5E93L*
M("`@(&)O<F1E<BUR:6=H=#H@,7!X('-O;&ED("-E964["B`@("!B;W)D97(M
M;&5F=#H@,7!X('-O;&ED(",P,#`["B`@("!B;W)D97(M=&]P.B`Q<'@@<V]L
M:60@(S`P,#L*("`@('!A9&1I;F<Z(#)P>#L*?0H*+RH@4VED96)A<B!S='EL
M97,N("HO"B-S:61E8F%R4&%N96P@>PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@
M<V]L:60@(S`P,#L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C,#`P
M.PH@("`@8F%C:V=R;W5N9#H@(V)B83L*?0HC97AP86YD0G5T=&]N('L*("`@
M(&UA<F=I;BUR:6=H=#H@,7!X.PI]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)E96X`````````````````````````````````````````````````````
M````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W-#8@,#(P,#4Q`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F5E;B]I;F9O+G!H<```````````````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#$W,"`Q,#4Q-30S,S<T-B`P
M,C$U-S(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+V=R965N+VEN
M9F\N<&AP+'8@,2XQ(#(P,#0O,3`O,3<@,3DZ,S,Z,S4@;61J=6MI8R!%>'`@
M)`H@*B\*"B1T:&5M95]N86UE(#T@7R@B1W)E96XB*3L*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)E96XO<V-R965N+F-S<P``````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#(T,C4@,3`U,34T,S,W-#8@,#(R,3(T`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"\J*@H@*B`D
M2&]R9&4Z(&AO<F1E+W1H96UE<R]G<F5E;B]S8W)E96XN8W-S+'8@,2XU+C8N
M-"`R,#`U+S$P+S$X(#$Q.C,T.C$W(&IA;B!%>'`@)`H@*B\*"F)O9'D@>PH@
M("`@8F%C:V=R;W5N9#H@(S$P-&4T8SL*("`@('-C<F]L;&)A<BUB87-E+6-O
M;&]R.B`C,3`T931C.PH@("`@<V-R;VQL8F%R+6%R<F]W+6-O;&]R.B`C,3,V
M.#8U.PI]"FAT;6P@>PH@("`@<V-R;VQL8F%R+6)A<V4M8V]L;W(Z(",Q,#1E
M-&,["B`@("!S8W)O;&QB87(M87)R;W<M8V]L;W(Z(",Q,S8X-C4["GT*82![
M"B`@("!C;VQO<CH@(S$S-C@V-3L*?0IA.FAO=F5R('L*("`@(&-O;&]R.B`C
M9F(Y,3`X.PI]"BYH96%D97(@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K
M9W)O=6YD.B`C,3,V.#8U.PI]"BYH96%D97(@82!["B`@("!C;VQO<CH@(V9F
M9CL*?0HN<VUA;&QH96%D97(@>PH@("`@8F%C:V=R;W5N9#H@(S$S-C@V-3L*
M?0HN8V]N=')O;"!["B`@("!B86-K9W)O=6YD.B`C9F9D,S8X.PI]"BYI=&5M
M('L*("`@(&)A8VMG<F]U;F0Z("-F-&0W.3,["GT*+F)U='1O;B!["B`@("!C
M;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-F8F$R,#@["B`@
M("!B;W)D97(M8F]T=&]M.B!T:&EN('-O;&ED("-F-V4P86$["B`@("!B;W)D
M97(M<FEG:'0Z('1H:6X@<V]L:60@(V8W93!A83L*("`@(&)O<F1E<BUT;W`Z
M('1H:6X@<V]L:60@(V9F9#,V.#L*("`@(&)O<F1E<BUL969T.B!T:&EN('-O
M;&ED("-F9F0S-C@["GT*+G-E;&5C=&5D('L*("`@(&)A8VMG<F]U;F0M8V]L
M;W(Z("-F-6,Q-#0["GT*"B\J($UE;G4@<W1Y;&5S+B`J+PHC;65N=2!["B`@
M("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z(",Q,S8X-C4["GT*(VUE
M;G4@82!["B`@("!C;VQO<CH@(V9F9CL*?0HC;65N=2!A+F-U<G)E;G0@>PH@
M("`@8F%C:V=R;W5N9#H@(S(X.#L*?0H*+RH@4VED96)A<B!S='EL97,N("HO
M"B-S:61E8F%R4&%N96P@>PH@("`@8F%C:V=R;W5N9#H@(S(X.#L*?0HC<VED
M96)A<E!A;F5L(&$@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B;W)D97(Z(#%P
M>"!S;VQI9"`C,C@X.PH@("`@<&%D9&EN9RUL969T.B`Q<'@["B`@("!P861D
M:6YG+6)O='1O;3H@,G!X.PI]"B-S:61E8F%R4&%N96P@83IH;W9E<B!["B`@
M("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-C8V,["B`@
M("!B;W)D97(Z(#%P>"!S;VQI9"`C,#`P.PH@("`@=&5X="UD96-O<F%T:6]N
M.B!N;VYE.PI]"@HO*B!0<F5F97)E;F-E<R!O=F5R=FEE=RX@*B\*+G!R969S
M3W9E<G9I97<@:#(@>PH@("`@8V]L;W(Z("-F9F8["GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]I9&5A<P``````````````
M````````````````````````````````````````````````````````````
M```````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q
M,#4Q-30S,S<T-B`P,C`P,S8`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+VED96%S+V=R87!H:6-S````````````````````````````````````````
M`````````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S0V(#`R,38S-@`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O:61E87,O9W)A<&AI8W,O8F%C:V=R;W5N9"YP
M;F<`````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`T-3$U-C8@,3`U,34T,S,W-#8@
M,#(T-38S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(```*\```!T`@&````0V2Y_P````9B2T=$
M`/\`_P#_H+VGDP````EP2%ES```N(P``+B,!>*4_=@````=T24U%!]4"&@L/
M"3E2B"T``"``241!5'C:[+UI8N/*KC280;E.[W])O8_>PK>`[]IB]`]Q`)!`
M#I1495<!]YU7MD5Q2.80B`0"^'__O__#DI:6EI:6EI:6EO:7VI)-D):6EI:6
MEI:6EH`W+2TM+2TM+2TM+0%O6EI:6EI:6EI:6@+>M+2TM+2TM+2TM`2\:6EI
M:6EI:6EI:0EXT]+2TM+2TM+2TA+PIJ6EI:6EI:6E)>!-2TM+2TM+2TM+2\";
MEI:6EI:6EI:6EH`W+2TM+2TM+2TM+0%O6EI:6EI:6EI:6@+>M+2TM+2TM+2T
MM`2\:6EI:6EI:6EI:0EXT]+2TM+2TM+2$O"FI:6EI:6EI:6E)>!-2TM+2TM+
M2TM+2\";EI:6EI:6EI:6EH`W+2TM+2TM+2TM+0%O6EI:6EI:6EI:6@+>M+2T
MM+2TM+2TM`2\:6EI:6EI:;_'D$V0EH`W+2TM+2TM[4^!3S3^AL;WT?BN-6:S
MIWU3^\@F2$M+2TM+^][`E<Z_+=`)\]T1H(I!T-P[OW=<<>XY^CTM+0%O6EI:
M6EK:#P*IHY^C`3P9`,W6N6<`+@>NW0.H%HRS`6+9^3TM+0%O6EI:6EK:#S`.
M?(X`&'H`EYWK(`"IK;^5B^!Y/Y>\-^^>1]O(8Z[3TA+PIJ6EI:6E_1#SF%R/
MJ66)F=D90#KZ-UQ\EMZY<.%\I=,>"8S37F&9M):6EI:6EO8$`+2`#<YGZ`#8
M5#=HMRT"8(R)\Z3]VY8,;UI:6EI:VB!PLFQC"UPEV'K_.V'0WG3>E[76NTQ+
MP'O=F*,_+2TM+>UG&@=!5]KO?2>MA#P.O+^2[R\![]O<X[2TM+2TM&]NHPSN
M")-H054NAZ^'%9%4&A+<IOUVP)N6EI:6EO9#K"6GU=/![8&SM/>"7_E[,O-I
M"7C3TM+2TM(Z`&JT($/:SP#"T6=,,/S76ZHTI*6EI:7]TV#(*YL[R^"F_?R^
M@')-JS@M`6]:6EI:6MJW![OL`)QD^_XNDW'7\K_6^\X^D(`W+2TM+2WMQP'=
M4OSJ9JWO,('/CP.T$6"5U>)0,HPA`6]:6EI:6MI?#(9L1:]6LE-KRSOM^SDU
M404X"7!M/V"^YP2\:6EI:6EI/QD`><"U52TM[>_O%Y@$R6D_UU*E(2TM+2WM
MKS8V@&\$BM/2HG[1DSQ+2\";EI:6EI;V+8!O+U%M!#"G_1M]9J9J6]KWM0QI
M2$M+2TO[)X%O]'>OPEJ"W7^K;[#1'](2\*:EI:6EI7U;LS&;"6+3O#XB^T>&
MO?P]EB$-:6EI:6G_A(UL2[^2U</$?6'BWD>N9;?BT3@?!N^+`\?RPO/_]#Z3
MEH`W+2TM+2TM`?8`2)T%4UY<::0X,0.0>X"]56IY)-;Y=\9#CSH2F826@#<M
M+2TM+2WMHO6*&7#R>`_,L@/>9@!?#R2B`URMMFT/H+^B;3VP*J\U<IT$N@EX
MT]+2TM+2TB[:*)`:#06(BF3T&-<(Q#(`SR-@>;0D<PL$OZ)MLPQP6@+>M+2T
MM+2T'P2,1UA)#H*^T6-F&.@KQR3X3/LNEBH-:6EI:6EI_Y#AR>_BS==(2WN'
M)<.;EI:6EI;V#QE_PW>3V4W[;I8,;UI:6EI:6EI:6@+>M+2TM+2TM+2TM`2\
M:6EI:6EI:6EI:0EXT]+2TOY5XP^_UXS*3$M+2\";EI:6EM:TS%M/2TM+2\";
MEI:6EI:`/2TM+2T!;UI:6EI:@EMK[ZCEE98VVO=>?3QS#+S!4H<W+2TM[>T+
M(AJ_?]=[_:[WZ;7G#M)'BN+^C6`+;VC7V<]'@!L:@`X#WQOYW/NL=;UG0"(N
M`E8.W#LOW`><,=Q[7DR,H=D^\KO'(YTV./^>@#<M+2WM[8"$+P`/?^)>>\#C
MN[3G*%A`9V&,%L\6N,(`R,(`^,/$_8\\[ZR3]>SG,]]YU[W,)%ORB?L;=3Q0
M?D_QY9&^VFM/.L#W"NB]<GT..C9E<%SXP#T!;UI:6MK+@-@(:'D&],XN:!P\
MYA7/^SL,V]490`D,M@P&CAH])@8[^A,$O-X(Z&(`ID;??7TLR0*@^[?][Z44
M]9GWMY%S]<X]<]ZQ:Z#3YQ_OD%MSH8P]_Y@S,PK.T0&N,^.#+QEC_GWWSH\G
MKSES3&],U&,S`6]:6EK:90!',_7J2;C/T\V"7KO@S`+:F$$9NY/]*`P_X:O:
MG!68;+-Y#``C7MAC(*Z#@5;`U'MN@>>1ENQ`?@>\1>#Q`)CBS$V@V0"B'GB$
M^%X/Y"(X7WC_9"G[W_>?6<Z_'>^0V_\]WJP\5>]9]W-@HG/MMZW/#6?((CX!
M4`II'@?5YP78KN<#]\<AKV5M>X[+\]>:!<`)>-/2TA+L/L5.,#@+&XP(71[I
ME6S(Z+$0D+W/#4%!=4Z#K!C`CO%P/4<B?J]PWT0ONGIF4[?7BR0`4"SE%+R>
M[\DJHM.`P^/WX"$5ZPI[S@8[+,Y=76?'EO*<XGM'7W287P`*`%I6F`Y@ENU-
MB32/O]$=-ASI;=2_\`*YZK:3_+UU4O&9]^SR67TG`4V0RLT).-[-B=)U;]M`
M->QWRKX;@_/OL/-(/3/2F2''`'0]3N1?$O"FI:6E/0EV_?-<WUX<@>`SQ]B[
M"?G9D1`^!>9/1LQRJM&BP^!3=F!N!4S8:V-4(*T$H-<NS_J^`M8QV(;F`0#*
MR20:8*)!(,K85C:=ZQ;WC8;/*`Y3`"EXU^$Q+(6@]2ET6\%<I['+KZ[C?8:@
M#S3?.54WJ>[MP(';=["#PX;+P]+>-?<&&(K3'XK33J:_<V)>"N]=M@F=CE!T
MV^)Q#GKM276P_FQ[)N4"PYDOT'=8J<9=W=?IS7S*(:OG"6X@.V7)TM+2?KQQ
M^]\5@,GC^U=`:2O>C=Z%W*-I_AL'LKVG9N.9Q4\,4"DUF*`+J1`]9G4JALX!
MBR^KY/Q=_<JA5II[N6RX#(-)8T#-LN%<]`]P@>(S>,U\M%8[1:C1.0RECDZ)
M7H-WF6Y_:9R_#%YCI#LSN(YL?QK`-C9,ZGM"H[NVM@]ZVPA7??.C#S7Z)AI=
M8T90860+!@[@Y^`[[#ZH;7N.39;"P4B&-RTM[:^PJQ&:V(#<:P(:YA>RB-EL
MI;08^FC[#<&2)^.,T0Y>:"U&Z+.0?9T$^HO^%2PZ=#R+97K[)X<#0M%86/<%
ME?'GDETC8J_GN`[U<;,J7/('&N#M?=8,R>[M$_2'0O@<;+T+C'<L>@YF`[FY
MY_"NAVO];[\?XN)Y&(]\C@XXT^^)>/BRT2[/^HF1?^QUJR.^VG>XW7[48\+%
M1PEXT]+2?IS56Z!PYM<STM#^[J_3_N?-&9YE7OYU&.S5!V(879C/ML6$Q0%=
M[-T4S\40(_2.CHAP6=T#T-&PH19<1X\YFBG./@AS%\U6DA("$`<'+'E23PZX
ML.^`<.X=^EU<=@J@G8$N\&P`W6'@5B8E9D=1/LJ\=BW>?-P4LK^((M%H`]1.
MEG+D!OO1E%,9N^6Q<^+T<3I]TW5D6L\>][L$O&EI:3\7[!YSI]9).,$H=3Q:
MQ9%:QI'-A+)SFF:`.>>T#F)0QC/NSH.Z="9WBT/8`RD,8OX:"Z]DK-`]VHD\
M8`6.W?;K,HVC(*'S/8X4-+`@52S6MOW8`DGL@+G6WG,O%@`=4#0"HEKG>E8N
MZQF@-_NW*^=^5W_C;VB?T?[."6?YU?=TY1WSA<_^P-`)>-/2TGXNV(VFNQ!W
M-H3AAT$OFW,Q1W;0:9C-7O)5!7;M0PYD_%=XZTD`PX:F0;A%W@)3K9?W3J`U
M0Y?V0,,K%OHKS_PJ,#@*--)B^UV.`;[A.\&W[B<)>-/2TKXMN+52/>UENL="
M=8`4[-G0.%OC.F3AD."^4?>I#CC!8YRC)8"7%.-LRB^4.%EJ&`P]4T%N!)S]
M22;Q%<?.G;$%[S%Q1U%1U<C=P.2]/O/]UG/WZM6]KKP)&D]T)9,L<N"BZ_VI
MOON[P&[OF6?;`Q.]KZT%DX`W+2WMVX/>\=78;+<[*R6\"94",,J_-W?67U,.
ME!2ZHJRE@F``\E#L:G@<:I6A=X'(/[@6CP*D=Q9W'@DL&`&^)0"$O6"%48YV
M!G+T7!5T0'@/V/>>I]5OO;;!T%MGLU1,'X"/5E/\">SX:&EK7AQ55\#_;/A"
M>Y<L`6]:6MK?@HZ+UH;L+\[G].TDOWBQ"<,`?'2A$]=!#,S'RD+TUB2K=_L[
M%]+7775<L=9G$*_<30MDC=[+U>MP$!R^TX&X`D?*B^][]CYBZ,/@6`[?`R?O
MO,4KES*NM\WR#M9[YNWPB=;YDZ#_T6()>-/2TKX)7IT+8>@"2#>"08CW8P1J
M8![L7F$Q&*-=CEY[?^Q>92;@^[SSZI$Q!/.?X8=>#<`RLO6'S3/?X)K/1'Z/
MI"ZF^2V8@#<M+>V/`UWOY^=`;V\EX9\.WXPO<#$B`.,-'H)>C['$I3OH;6U&
M*KW\,1O`:6G?%<Q';'"W]/1?#IRSTEI:6MH?![H_9RGYI@;,W26C;=WG(N5B
MF&PDX\J$?GY:6MJEV2JJ<N@5O8L^[]5`_$EC-AG>M+2T!+T!B/Q);.-8Z$.K
M%ML<W*]SW.-(U]E8S[1_`Y3A.UY\5CP@\O'^J@;K.[^O'+]C(HT)>-/2TA+H
M_F/6JY85+UU\XHHL(]NA_$W]R2VX]V-!X)"XVYZCV3AXCU[QHECDWU@:+Y.=
M?^V-E])6^Q*?$=<:I"H0Z,@I5,H-//S8*;R+!MI2CT/E*ZNVW__VBF'^KSA#
M(Y_--DD"WK2TM`2Z763Q_?&NMTRP`4!?E3'_6Q5TV5=9MD`.%YX-`W^+\%P%
MRCH7LZ!(JN2AU""47F.;"\LNN__L=6..9E/U_FU5^/4:!0U`R\'^Q\#3LNUD
M^@SIG&,4?'$,G'EMKOKEP,_=ZKEITRQP`MZTM+0$N6JVW%`'^3.VV=D&8I-8
MXEL_)H;[W/DJ[=^!]KDCN;$FMG-NCH/HUP.G+K`;??W\'GVP>=R,CA@=<#SK
MA3USSV_RG;V^6!5?G/*>TGKS7P+>M+2TM!"I_(3)G2]9_[_[*P'Z"W\%&`5(
M\K;OY=8X#55KZY"X8'C4FTBP\GN!]0^;:C@AL3W=!LBNL@_3!+QI:6EOFLQS
ME>\Q$+U8PK^-I7W&][C<G2RHD-68ZPHD-5@0Z>B$`X;Y)WO0=^C%W^5^_CV\
M'T4[>/T3I;R.*?YAKSH9WK2TM`2Z;UZ81G9@^>1Y_F;SDG_\UGG1JOB*"@'_
MSMN91$!19EO:JP!P=RYA_TVV0H</MX8OZC:_N9T2\*:EI278?</B\TI\Q-_Y
M$-\(D\1;OCTY@._6L._N:<^X9*US1](+5]`+O@G0G;G_?X>Y9J>5V.@Y4ZT4
M=:??T,P)>-/2TIX$N-@8N`2[/_;F37PK>KCHS0#79W0C`/4=0-0/>]'CZ7\_
MN)>/2.\QZ%D(]4QP%%'A\?,>20^G7?5QWQ-47]7A[AV#&;_#<[9[B8I3%TS`
MFY:6]A38W:;T?P#K\J?=+,8?RE4',']HZ8AZJ@BAW%*ICW&3S9YZ$S.*ME=Z
M`3K7M"OP%<^A_9V]#',LC!:A@5:P<J_U\'3+]L0KQKHM-U#*-X[UN/RU]W.K
M%_B\N7Z_\SWE^VN5C93!44[VC'K'!4O`FY:6EG:1/.!/NED/Z#9!EJ/BRS;[
M*H%O)`DFP>\U,?YH@Y7!9QQOD.YQK8W<D2#@*]X*._V.0V<Z`7(Q?XVO@084
M1*>]NLE4Y>1%>W_S(DO9$\5%"[ECX&%QX<WM-0<YT#;M$BWL]G[_#?RD((R9
M9W:?L1=Q8[Z<@#<M+6U^HOI'PA=^=-)8JQ+6$)CTP6STZB40MNSNZ#GFEL@K
M8JXC\&`4,HSW"F]['`.N5'0G-1N("BIZ<%R>>>3N>Z!KO$!'"\3.1+^S[L_R
M7_F0W#VJC3XD3.-L7^+H>Y_12L'`8'P-2)SY&P;G./RAZ6KZF8/I`(%/G(`W
M+2WMGP.[+?R'#K1Z&RB]N$(T@0=G%Y@K<9X^B'U=-YD-Y'L6+K3*@,U?`4Y$
M:!OLRD_9E:(ZKZDWRE_9;]%T+^H[9-/1"-HS*D/<TN=SNP5\-E?6`)8E[2R"
MBN))BW>\]R@-L*[*`8X"XUYH2_R3#?M@(Q2'@6-T.E2OF;9^SQKE]^$$O&EI
M:7\]P/66CY&"3;\%F\T&,7+L_L<K<$4;BW^"\V&9"0V(P."5:JQT(`$KB!"G
M,EV!V/9:8RT$#9YZWD_0(1DE"3E?810>P!H@$@XHM-<'YS*A%-J&/P@8O;,2
MQLZX6)J"`!Z9%'IAT\UGHC/V@PN3$\-P=WX:8UL]Y-D2O7[-HP?BQZ6*)N!-
M2TL+@2[P=V6_OQVZM\#N"*4\0BB*7=K]:WQ+BS"`!G_VS?32QDH#['+X)?H5
M;='<EO?H2-M\-CELLFZP!$1#50<L<NMX2@@ZU$A)X)DD([Z^]R!XWSC0O?B;
M*!O.@1X_XI.Z(X0O'@:M&"LT'(Q67V<@.":<&A[!]\5Q"W]"^MSC)B\`WBSJ
MG);V+X'>>NSG'/`T?FSARA[&Y&\"[V/HZPWG[0=;-)__,C9'\^EJ\,,S3I0"
M)3;92_;1>K3D8J#9>M3VJPIK\$\.L7&V/YJI.-@;^,0PQQ.C`*,''YT2DS%$
MLG1@$+!"<0$Z`!E1V_:#=O[4U/SQ_.24EI;V[]CW`+NCLOE_'.0V,%BKHE$H
M0E!:&?I1G.2?:BT.W%/_V^&W.'8"3L*8@[V*M-9JKW"^6:^$O(PTWUOB=%[?
M(T9U,YYQL?G^83WLN[[MVH+1[4F\M50WQCI?<=A@.Z;J8&M>\$+?5;`Z0QK2
MTM(&IL!QH/(G%M#OZHI+K4T&=]Z+H)5QA344:+VY5];%1;P(AL?9-S12*((!
M-+5!I9/(`X[7$(K=FUA)LGW+W\2Y"L$!7W]Y#(#4R,68C7S(_:39KJ$[]%C:
MX\1<O^]H2`9X3Q1D">*E<;F;MX42$_"FI:5=F3#9JBX@=7^^+^C]T\B:TT@L
M7G#:P."=@OO>`C.:F6,A$;H.@:Q<%;4[R6N>32M!:"0N=0)LCB[M(^)7+?=A
MIIN"_EMY)_O)%_=4OKF?C^BKX3O-11-/1W<_B$^U.&@&S!'2<V0MFF3*%L\\
MWF(CCE+O3`EXT]+2)I48)DIX_:;%[JT0?)"2XN54[C$HJ1>($0#:2+OOW9TE
M<%Q`SD/_M2>OU6JK<!'F[WBYK^^C(WF)'@A])5CDF\!GZ[F^C>>[8:XF$AT)
M")>"!CTO!.UVWC<.2A'ZU&5>S_@[]O?]P?9$0.CMJ%,UPU/V*.740^[.;>BZ
MA+TL@P2\:6DOF_I_UL8;]?\;6QDQV`H,(LKDS/];WLK)-KB@GM=6<%O!JE:]
MO]IW,`A01E)JVFSR:#PL;7LZ<#5:IGDEH'4R#K6W88L&OOE=KEMK?X3O&-=_
M"OS\Y@NS-T?-T.G/>#0VV@;Q?9+^2(TVUWY*Y;3(R8)4_HA$SJ4\6HA:>:EU
MY!$)>-/2?O;4?^UN-\FQIVK14TPG&(!B1YA7HYK7JR=W:$DI]N)`>>6MXPGG
MIQ="TF(Y9IVLR3A8%XM2G:XG:2^!,B.M6+YVQ(TH:OTSX'`V2RQR^E"NUN$8
MF(OV7?%M3G+D$#E:#8T32(P7&G+4I[TP+&G:E^)1)3O,B5GD.P!F-OQNE%J\
M)$S@+2-`V%/1/O>B$O"FI?UKT'R;@=J,9X_R,[,86P#0S+P!3M/)Z*]CS.F!
MM1<`EM?$UK+12-<@5(PG7ZQG9A@;1JL3G;;GZ][#MU(!_6YTW&C1/)98AVW@
M7*0N+>W]C%`YB]O?L<U)<.:FUH-P\N]/-.2[`XK9\&=Q382CY;]<<<7?Z02.
METAV.A,B:O_,0EAR^4]+^_?`;GL*>I:^B*?E\0F;K]E*)H__7@6XXC9[)9*,
ME@,V@>Y\E;47/?HLZ))_P_46N0J1W[F`TRHX?>OYH&X>TO]Y^KSJ9Q[_QHJY
M4<?P2ZSP^)_^C>(X!O\^V]_&S_/$OL*(Z`J=@6]^9^=4T3[2=^B^OA^&0E,.
M6;\TZH$H/DR&-RWM;P>Y,RL7T%CI>$4@\A+IXF91CZK%RQ,,"OSS>[XU]W>V
M5BYG&_2W/>2T0`7<'85Y%@N=?H6W,Z]:X&3;H\#\]YM"*0/#B%'?M\PK].]V
MV%=QIHTJ'P".D(03DGAO=#1RNE<$W'./]<"G`SI'0"\.$*6WP^NI!4&R&=6Y
MY-]TM3YV=K*"M\M&@'(OE@<#<Q_,.\?[RLU<GPEYM"QL/V'#\P(3\*:EI7G>
M_;M\?!W7P-%5_:I<0V>VYM0]/X\:*]FH#J;'C$;#=U$UF!*)&!,^>PIHOWB5
M9A#VHUG-\[E&`*S=[F>GK22&YVC?+RRDWIHGHF>RQ380]D()=,L4D^JG&W*V
M-ZBDI^<&)Q%KU,URM0Q*Q'"HM+1^#R@Z2AZJG5!%KKI5`ZEE`$=>B1OU)L8W
M1/<8219]/0CFU-!/P)N6]A<;1RFC2RCB!:#HV6.>>"QV%ID!B#D!CHH"*AY[
MLO\=Z%>9??4KFA7E\/.74)2>F4+T=%IX;INYV[Y.5_<2H)Y_CW/1CY3O-)24
MH'.M1C+DIG5*SKY1UN<90LL]UM7"$#@.&RJGET_7)L-9RADOF)->Z-*7IP`?
MFK".KDIV'/^ON??X?J<F"^JYR'8E8HAS>/\:*`!_`MZT/X9GTMX(<J]B5[*3
M;W]MLO$W,QN]9$(6[.J]C*UXF&FZ=D2(=^,.>6Q+X=*[\Q>1SL_H'-<5;X/Z
M2`[8?=7<X"5$V:S_WKL:^?M<B]4@SU494`T1ZC75U\1(`E6OWZ*4R0I<-+6\
M^BW"X`S/J)H$UQ@)98H]M9<XBQ@$N_&E/8=BILP"+HWC;G/@XD01G+07P/$.
M5GB_9@+>M+=Y56D_]6WP;5<_=A^?*-IVKEF<@=`#BS.ZP,5;XF3EVF:\XVB-
M51F'*W@92@;U"8S`-QQ;.38;`O62))_I70RR\6SLJ?[7N!";,"@)Y:``WG7X
MNA$`:'UJCD#'>CL=C&%!7\&BI0DW4AC8=\ILK*1[G&S3J&XVGN^TZ@D]AY*Z
M@K3GB%T1_Z-M"K.;TP>]G/3L+S+BYKM4H22H7\,KO.(.NN9O`K\)>-/2_A98
M^X?3PI^?G.*Z8NUY]`5QH.XTV]["K<HOC"9M3>V(RVSD20W="XOVRQR;M_;%
MYR#[>6\\PU,!(==W_<IP?[.,+#I5UMIT)2^U0Z,#VM`3V_^Z1?W8CW9HW0H:
M0'6TP25FQICV:^1_MGZ>]^[;6+8[*\&IT,:HOXU,P!RZ:2^ESE.X[5X4P?MN
MQ#E$P36O`+XI2Y:6]I>`W5?$*EZ!'IX<5DNM*HK9]&X?Q5??>1\'X#_!;TT2
MJVZAKY_+QKLI932.[@?LR^!*"6RKA[;]=RS&$&QK]-]8>@S5SSQZNQ7/*L=?
MI906@M'S9KD-=#I13SK.:]Z!>2#$6[/`V0&$P-CP>DF[7?'-HNBI*@:]_AE"
M8</IIB_L"`Q?#8X8;#R'KS'>Q5\A_I@,;UK:7P!VY;]__'X&R)D:H-<N/IMG
M?LD,WYQANQ7>85!Y*:^C4KVM>[,;CG*=B6JEPQS@#^]P*%I]HHZ]K9L!W??E
M@UTI$87C7"/QEL/O"9*']_[_,_K6O-Z'>K651RH2C-X:8_R"!MXI)2[F%@4;
M5>=C.%Q>);+2;Y.I^(=K8\0;,]X0QG2L,H?G1:W(@6::W&S?F>4R9AXQ`6]:
MV@\'NG\*U+[B_@%T8[K&>)EK&U^L%#P'4T<B3;&)8F8C.,2&.+[\'0R=4*R@
M`ET\2E/[X*45#5KGG\,LZ!L[2KCO:P[(M^-6J=12X6"6B3"2UB5[GB$&SULA
M1@=A>?[@J#;S!;#[#,9S_P;3YP,UBBGW@'--_D<FQMFRYE&!$UFJN/;'KDR3
MG5G,NW4]WA`"XVMM$G9;M-]O`MZTM`2[4][SRPD,LY,[5PL)UZF!0%^3%QZ(
M3Q!PG/SL/8NS$VS'5F8)RC!V:LD4,2I#'8'=`."%0--K231='LM@C2RZE_"#
M$?E':71IV;,AOT._#SIM@M(J[_MGG=]I$'[A=*.[Y]^I,G3SQEO'>ABXIUQ1
M1$@V9F:OOB((C7!:Q!N4\H2DFU5%-!*/2,";EI9`=W;!Z*S)\R<3T&,^IY\!
MB.WS"1S!SAV0^UWE]Q@A,GJ@9W0?FVV@VHS_*,TDGHAYXX@2?G2=W@IZ)&C1
M^9SNGX>JP!F,;=4?/-"I_M:Y"&>:HU&$ZCFWM]?P&!OT3X/K<<YV%$?/`*]6
MZ,6@0$'?<9K9+HH*9/;B=4S?.D'O(YD3WC2!F?<+QW%]L7_C/8^)K$C`FY:6
MUH]7+>4YB?B!.;'6*GV-YD)[_1#"]9/M]-3D_!9GJ.C0VPBK_BX/R7DAE0A`
M\<)'&LZ*L^A:F2FWLT;*`[)?VC!R-)RCJ^]G\+-'N`B?BQ-%>8&$W<Q&-%X&
M;$>NHH$3@F.>GSO0\-<P"-A:+8-WC;F>$XB^NXO"$J5:U-K@//49IUJ8S7?X
ML@Z3@#<M[8<`TC<QNR.RL*^\#ASYH#U1:7:J\ZI\66DGM+[-<23X;#VH82+D
M5>M<JY0O$;[QUA9C^V$LC:3/]%@+,8B]9%R@06T!X<O`<3L^H]FN-7JI;K/Q
M56-W'/BJ\3Y2/*$%LA@Y.Z,/YB3Z-7M?]/[Q1.^.TJ$:Y7,Q\>J\2LH38':&
MG>3L4'WU=-&N"W-.RJ*32EWM1\Z%G#X=,%R5>1ZE'FJWXF7:O.)9$_"FI?V+
M`/HW7B34MQ3;N^3,DA=!M?HH5G7FQ5EQ3>[KTGK=2VBZF$535:9E!^PVMG\Y
ML(@C;&$O$('5L?&FKQ=7VX`>1I^4''\."7I=Z/_"C*:G]BGH=PV6\4T)OSO,
M@-=1/;)WP#0,M"RTOX7G+O'.W9L9`0S$^/3"A7$4@E'DP!8"(4&K3$25)`3%
M=_>?T:R9@HG&CV1"SG<<;,1,O^<$O&EIWQF8OH'9?0O8O5SU=NR(:K%P04F]
M7(5@EWQO&[5RI2R;Q+D(2>DP>)]&U<B\&^LNI"Q-47@);QM!?N+;(QQ80W!M
M?W6,VF%T7(DSOR@0>P?_Y]U+=@``(`!)1$%4?,-8BR+58T0$`^(W=\,I2[R7
M&*C<PZC<F%%\<'VW&6+OJH-!C#F0$^=G[UY_TYS;*X*!TB_16[4%Y*[76650
M94%VAL.NK$.R73Z]4(%L>@`9I8P5J>ZSOJ-.31:>2$M+L/N2DUY)/HC978Z=
MBQ%@BJI32=7V:]S2S"3+;5W>MUFY/_.^>.P@#IJ!E/"0!G-PF.Z)`6:OM,'S
M#='CRC`(=C'05V1!AQ<-BL9UZNN>[#5?.BH9(WK;2;P72X?797%*5Y]E92F>
MJ0+1$NA2C#(X0XLEKACC%:`;51WTQ`$\_^C9#%NR'97QAX/XV7$IJ]G3OB_@
M8'X/++S]K0EF)]8E>9S.*T#167`P\S;*2!WV9B$*R$MM_P.2X4U+^]O![N^3
MMGK%.L`8RTXO7'`G_DB;Z16L+KT;EH4<Z#@)<KMP!\`EQC@:)(RFTKPP/*,#
M<'4TM=\C;(RJS=GF4"!M#3)[,D<M[-+O;#"@%Q<]`_91&ANR3Z($,H[0')QQ
ME8(-`P,W@*WT2]1M2=OF-`@8=7B-:7LX_;>*LQ882(8\J:1$#KZNT@"]W;PJ
M^,>VJ%=<G.K>D..GVAT"8*)S.7);>Q"WR\3:I!ZQ*E_-R<:;4%%F*<NR'(!W
MMP2\:6G?#.B^JD3P9=FPT:W`-R#I9MA"5VYW2`*B>%7+7K;*A)4<Z)1]@@`>
MDV"3)0!=+.4ZU]E<RVS(L]Z1I'Y,1XK+>PVJ&>;=(.'$G+_;5T"TG*`./:2>
MS4%R=K#T@LZM(*HLO!(4I\)QZ=VA@`Z?V,Z'[=Q^->J9.G(R7M/3!XZ<F)8S
M0E.&EN[]66FV.BGQT9D0@$^U=2[TGS$S14"TN5(R,&FRB!!FF57J*L-109&D
MEPTWZ?1HK96W#Q0*HB68='A]<JSR,%EJ>15/!)C./&,>N*K!"1_9)^!-2_M&
M8%?^^WLO7L+J3+\+[]))3!HD^=H(W04J+ZXR.I7:[[%KAMIJEI[S.<99F,OA
M8&M_NY[6=_#"/ZF/'>E(/3]GZ""70,4<H71\%_5EZ3!?IL\:G0J%[(]$/^IP
M1M(B1U30,$P)9.ME\N*D,*A:@<X?%(4K'A9.4/;A",0[%FS$]:BQ"`VD0_;?
MW`H=(!U=!ZTM`Z-*$PS<ME-?(F>I\7T3[$^(F%T'R*YDX>K%QWCL1R1R[0U`
M^##5Z$.#'A!'^[FB)6Q!`?QHW02\:6E_(WA^^8'C3.!U#@!.H8')9T!C9L0H
MBGXMV&UK(D0K6XMW.UOJ\DXJ'9(G!.1ME.C))W,(M;:73?^**!Y#C]('';A8
MD(^EKN!;+>^6890LH0,20IW?8FE&\;*4XV;89+ZZ8.[L.!FEZQLT:H@PG1<'
MZW%AP*MS).*FYK2ZC6'50EJM:?LD.CY#Z\-6%)/K:YB=0\&NKNOZB-MU+S&*
MT!N)IDZ_C%1#SF(^NJ^/;CIB5Z3PFB)ER=+2O@$X?1%ZO!CF^BVJ)_#BLUX[
M\]S6'(=N=$SU`1-/QD"NY\655YVM:-N;,-[V`YEP-K60C6=R0QF<Z`$VNC0<
MD-R-C+!1!R)>FMZ^M0`^9._-=WHOH&-LX8@&V[U^X`"],[`WKHG&\#BW+P=%
M8TQTK]B]9NU%!'K0ZG<OAE1NC3\Y6XP[`O6[YA5Y0UN\D+YOY^[`R5CGSN1R
M)*)!%/IE.<"NQ]W6Q8C8\&%;P3,M9XQ'HIQEXT>GE?VLR[+4[\=$-B3@34O[
M"\#N-/CI[7HV1._YDOOT%7*?17#GUB5=%HZ]%"5WX9[9.V\OLWS)RYD!L"/'
MZ:U'+:V%X9#$%D#".!YN/_=&H9(<;JDC!(#ZJ11Y"L&Z&0*Q3K"IGX04X-2]
M,0OF6",<&^CLACC1!_ED<RCS!;V-YHP,QT$=7QG'G:+IJO@[/@Y;2(:C%<YH
M;%60\UH2U36][VMG%;W)E-[$6M/^?,FT@%-2;/O+`^S&O5K_?;QD21R0PW`B
M0BD*>(]-:#@<WP500\AK5B3@34O[^4"7LP?_1CW)MJ<N=4O%8A>LT#-E?6?6
M!HA%4S-((YPYFT?R[?W(/`O*19J_*&FJ%KOB$U%4L`"EO9"Z"[Z;0JX9/<X@
M^H[#=0*!4M&55)1MK_FD!ATGAQE.<,1V&946FWVEPM=0@JJMPN56@'-TR]#Q
MEB&=*;KEGSV@[.>&2?!YQIN/Y8O510[L5CY+J-`6W&F)G?G.W?1UK'T`3=JG
ML(?J#+Z=V7VUH3%'C,U"&"<5Q'1A$[V/F'AS[=3A34O[P6#WE:BUJC9U(9SV
M);?"SKV]R]P@/#[;K&]I1*E)BQ$RY(6WY0/B$R8T]3$/$>(8+_G]#F]Z]WN6
MDOS7`;-#C0(A[A]K0<-<>P2TQL><,`&E5C3M(PSHP<4>V)5)9\4(0Q?725!,
MIV'`*]$'U7G0S*&E>'H6O3N!-E12VLD1L#S!M#R*9C[BH?,ZOY^#MN/@`K](
MY)C"\635O1]=>U.KKG1VX4^RH]X[^W"=Y?6[6S8N&A7+B[,';<<EPYN6]I/!
M\X4#1]@@=B:7_J582KAI&-%,[P?8S>M,HL6AF.E69`1:T"8&NL7!(1U4U']^
MRVZC!WB><"H$6/#/+R6WMAB_3H?@(*28\BA&>ZY7U]C9Q$49V&4H<[L3_E8S
M&EO(3MQL*]^HZF3S[<6H#S0U\.K*6E$J912X4,/6^HY87''K8E6M=A;ZT13;
M.:'+=LA-"A7<P/JQ`7NW(QF>QN'H.)[^.$!9UU5FARGH'X+>UO8"VN\<Y2U2
MPU6Y8\@^`^,B9VGAM+3?"$S_5*SNBRY$7/MR%`'7O=ZW]1S:CH%[O@9S4F-(
MCN,)D]LT%;@9@9!6-AHZ#DJ@(7V&KF@=60\@NK]=+!*"UPS<:MV?*YT]+JG_
M?+\7'2'<%1;)8NP7**D!/;5STB[)%3H[32#=<*KH.ET8:!/O>(:GT>'M=,8K
M3C`K"X>5TV$[^OZ1C$6MC*(>I5<ZK@0BMM';:]5<9A5[@%[OM')H;'68]AW9
M-X!G^SQU6`P:P#P!;UK:#P.[ET'K;P"$PZD-U?XN_W#[L#M)7VTG3XO>T^_G
M)`EVB1+L'<(V=GFLZ0PQC69:3&(/M1O4O!![4D;.BLER26>Y!XGP)#`=BJ$=
M_9R=PT:DAODDO!;OJ!=QJBNML:FL,73-:%#`1.4RD#*;?6P$_<ISPH*B'#L3
M+!U4Q3$KQK>4(6%>5V>O;GWYR`N@_"'8TYFQ>8)VA!7SP@'3DQ)_-?`550;=
M`A?;OQG#FY;V9K#[JLIIPC]_.5`=FO@Q=MC4??-5B'SDKG:!5/TPRZ*U&_>E
M`E/G5H1#-_'+3O:]4L*O>#\VZL_=%`T6*4"'..\QQ%;W<@>T"NSR:NTW#O0O
M$Q/L!1"S_=;8^.S5ZK:^LU?:$J:VDYB`W8-8%&+`L/U"B@!@;(IH52?C)&#%
M_,2I`]5'>HBO"W=]\D0#@YIWUW5,@T$G;SEZ9/)J@VJM;JG0(,>I?D14G:2.
MHS8HV>XP#4H3>G/D/#=TGNE1.$/&S]>=/1G>M+3?`'I?N4X.'3A=.I=-$`=7
M&W;VAH*_7J13FR&E@)&6VE)+4(3>8VMEX7R[32;Y<9#0:ME#>_)\9@;9UT,D
M,/U780EP3;9%"2703-ATM_$U95DY2N@C+'2'2/<S/C-H(1@H*UN&!H"!`W0'
M0714$8ZL07PS/!/=V<%M,P3.PI7L_2BDI=[A?W&D*,?GV)=.XFB#WBH6F%&5
M=?%FM\ICF+CU*/Q`*6-<D0>Q4Z8M!3WM)%GQ,SKICDS`FY;VW8$NKW[A*<D`
M4TVHH$F)77U*E/;B/']"G"&*$'G36P9*G8>%8UM6:[1.--_K"[<-/NK&K`(:
M-]UNCRE_?90+/4O9MA8ZCA(SPWV03YQ!%C)N-Z^GC;HC!O$M0`-D&<(:+J#C
M,2'=?$11;:U2UF#P/<Y?CX-CLUG4PR9_\1*.J<@_##I=Z'A[$?GMZ1KW8D?=
M.>BI05E>)5(^C/\9>@]&)$V6_SMTK,<]*IT<N3NC5E`28P5I>I^Q]F'(1FEF
MF2)X:`W3S1Q)P)N6]@V![F4F:8B(X-0).>+-M\X]4#WTE!2B*770)7M**1O3
M:<#?6'5;%'(]J`9>S5Y[->9M+)Y:>U0\)38&NRP%MU*6+3[P(4/T`+^DO[K\
M[B[+EN/3`DGTN"9['J.+VJPG^SQP\9C-WNDC8,VIX8Y*I6%4I]I_`ERZEVC^
M>9D#54I7:BRJ@=>[C['BV9,@#J_I5_/KSNG?2;LM-_5@R[(4KNO#(78!<J]/
MTNV+:JVH)OI>^1H_^)><?WX-TO5JDH`W+>V5B_@6UW@5]+XZL>P:V'W!C;$-
MO>.U`G'A":\RV-;>T7;F$+17$CV=5<E;%=&IAG1E.55;X?YS$RPHR\%B`QZS
M(_HC6>[K_8^`VUY>?3?\3U".W3*W84O#([_\.T;C1F0P<Y#EWL([?!$,9.$+
MYP^,C6>\L!-T+L.!/N+%P5]-./422R\!X.@&^+L'',NR+`5+O1X!*`LVB;)F
M<//8%A8CJ3>GTR`$N8&K9N3&#J$)C/1\$:-,9M):6MKK/>WK8!>SZPK;@.$=
M(69E@@N86E@QXKV;)S7).[,1!M.,K@5+J(I'!>V!:QVB\4<*2J<&N\Z:`91E
MN3F^P6MB'Z\H%[`,2+O)M&OXT>1Q<0'Y,^,2<+T!)#*X#@?)%ACK8$-;Y@`O
M]WA?^/*BF@<7\?)L%^/@UUG:+#HF;H43S?%^]N().PHP+`5[[.XQ1]AC$$]L
MLF.S-%Q+E***;Z#YEO0X\9A=DW3&UG@<[V0)>-/27KU>X#J`N+8=64(=Q78.
M!YRL7'_20D/KJ<[G%4H(>X*8444(V=@-2-`])ICI!F(,\>2B%.V(NT6FV+ZR
MSHON8PXVEN,]7`$3B&-9'J#W&;#+H79&M9QY(+1Y!12M]VI2V+VDJQY3S*W2
M&WN@E_I'VHI.\G8XK@PW]/Q\Q\3408I.4'!5?(X3U^";YM?!@UK5_C@T$_O-
M%"NPH'$<NLHMH\Y@.Y9=%YUX)+36L;R>PTM9`5%)1]B+,Z06Z+V$!M&`HUVH
M_NUV`'3:C['J388TI*4].QD_N]WG3%V\\@6,E)D]OS![NZTM17\'.*Z.[L-\
M73VG5H8,'IIGFO+T`H<2"O"'[YA^=G&[[=B<OR7;X6Y4>V*KI3SBCP=YBZ.V
MQ(*R$&5=:=I\S'GHR=U;%^B(-R5CG!TZ"G`:6_<+3@T4AXD5!1!"S>02AZV\
M=-=Z=!]>Z(XV!7"=SK8G+'D^I2P(`OLVH^!X+X.N%[(9/O#`H(JT7DU1!Z]I
MGH'7(PPP!4E`MPZ>3/$J;I\KC3DU#-P23"U**<OM=K*W4F6'>OQ09%':VIC$
MODY$HQY3L/Q\"%FA#D'X"OT4N$@V4;[LQGM/P)N6=AGH[C)#MAS9']C+@@]P
M&,;2#B#T`;::16Z7G4R<!!/8)<*VI"D+_0Y]2(DJX2!V&=Y+S2RL7,N"^0VK
MQ_W1"9G0LF=`E$`U#W9K9@2*"7*1MM6)$J=9R8>H_&`G0?=^@X0O&#=)*!TT
MTYVV>.,*/895F=BHS1<%>`]@*/M2`\_PI7'T&&ED#=+.[L^CCQ[9Y]15Z[SK
M4GEDNI``)5U+*-15C\R&EC(A"XL%&-N!:58CV&$(T7`Z@=*0J*BUAMW["L'P
M,UEE'!CS96IWIS3)!/.9<&(>84MG1X*9[_8YF.M:D1-NOX+5D^]$-[<"H1TE
M":\\M.Q_H7H)=+L^YG\T"`LFX$U+>Q;TOF*I?(HD=BMUH5HXW85,"#E6Q(EE
M3>FG(\B)<+77$HLVA,9,M]7("N@@0O';8GR]R`=B6-K1LI\"NJY8)ML+2*=\
MZX.E&6=Y]_MJ:?,7LC!H9UV/%-K7TZI??6!-/R+0MHA;H0[P=;C</XE2N$"7
MGY+MS@&@V@2X;+"=%#X,?<W;(HH%T%2JTV#4?YM:R8'^K;'':OIJNI3`MVAV
MN%D>V`#IN.D<Y0BGG6#.<;"[G23>HVH83$^@[C)#"#6Z$"Y,\';8(3ZMM3U)
M#8K!KV^"ZVJN%0=+T$Z"JK1T[%B@M]U6H5BV^TKC7'L2GMN/^)@C,Z0A+>TB
MR'U%];2I[??&+,?6%Q"#XB/KG9:3@5A,&,332L"\@=W.%CE:!1_0$_H]Q=/U
MLVQW3+RTJAV?^FZGV(*W4C<I2@LBKDOW'`!I!W/2L>B5;RT2:,(O_B!87YOG
MHK4_^_TW9+V@J<(H4H)BP08FWW'X_/%0K!9]GK=*:'`)(9;/8L1&=X?#@@P)
MW@\GPT-2,DBF\1Z]L:C`C(DXMJ*HE/=OP%#4ES;FD08$@OV=D`.L1>%%1JN5
M+8I4;<II5OD@OA%7=T9O:H[B%*Y*2)A-Q+I54);;LNVF>4FLIJC.!@#[Z@O.
MSUO>`!L%0;JEB"<:P_8+.(61EN6\JL7PY+XV)<.;EC8-=EN@[MU@:F1-5HLM
M1LYAZ5W!!.R@MY2(']):KXTVB\#HSOZN%H"9A1CEL7T?;@M>?">6S.2K7E)O
MP;,+(WH]A#7]?K2KCO]%K_=5#"X[ZXX$8`/5S3S?2X#E&@^T]D$[SD!C;+%H
MMJYRBBY4'&C>&458.!S`(*JNU2=%\&Z<P2Z/`<+C:)S-?OE=!B"U^$ZH;04.
M5$T`*JHVY!=;W<%!8YPH;RMQ/!N/1_C#T+K=>QRI]=]=EC*JA#&*.@WKNRQ+
M68YB-'$OW>-VGY4F'"5KT)H3;76385$;.?>5`J'![MW,(\QC*>NZ)N!-2_L]
M]DQIWGIQYLP76'O*/&>_QHSE)5&)+/?B5>MI3Y"AT#M0EE(4Z%5@R;)"$1Y<
M6;!<5QZX0K[$G.2`0Q(U#AR4=.S3HG(8QN-S'^>HD[%09^:9)1T&4#.(MZ0E
M`X,US>H+:R8V9BYY43M/.JLH"!?6UL*],^&/6$CK"^@H5)1!]OU2O(P8@1+X
MF@2\HW^(E^)6(#OB@QWVT#"ZK=X^M(-?@6I$TYSJI.^JAL;>X!]B*`U(5DIZ
M>@Z&5#")PE3*X':^2$3=WS]")[)LQ6=>2;NT;ZUZPXS7-/4EMVO4\]Y16MT)
M'V'A5FI]7P93EBPM;7!]L0SFA:D7ST\DW1*.9B*/6<\&2%6:/M0D#\V$MB>B
M<7"=<1@HVBU0K\TB9DPNO[CB4.R+A-@&OKP6F(P:-IK5_*[RMH_=9&B@RIIN
M6I;EG/0G[A/+XCRH58FU4DLZL00RPTH\$$01CYUQ\GN;D1E3(38VMO0$NZAO
M<_"Q3U!`E&9E0F^X2K![7!JA6Z&>J2V4-8`).Z#BB+UV9-N*"%]Q?,FMBB(5
MF5I5-:O"GN0UK)PAS"R%H:'#ZEP#P`H]J3\C>-4$>YS$@6@BY$-NB_48KW$>
M*K`[XD0_0AEN*CEXAA)I._\L+P/&&%K8&L>:<A78YK#&',!U3Y)^E%HOI23@
M34M[)W+E#&W8$(ZLBQM@Z@:>G;;V"75TI_"8@,5_TFFPWUW7`#3SG-A;(0M[
MZ>-YL,IZ\V^R()K#\[B:H*U[UUK'&NBJ'"T5+FDU=<>[UF,!\%<*%X0[9ZHT
M:@6K>RS7%:#M#24H90P-NG$RJP,=L94,>3AKC377W8V`T%1U\PEU8MR5,)M.
MSI>X?RN#)1W==DT-_399'1?5<-.);A;:R9_0$(ZKP;$=>-X]N?=,Y_G%_^KO
MRB+$7B=B&2R+4MIU_AB.'0O"V5:@K9['VE*!7=N^K,:EEP,@DT4?XQJ%?%%.
M!`>)<XH!X,@PHA0'W/M.SIE8>9X[0QK2TIH#]3E/>;A$Y<1E?$T!R;YQC`-N
MZ(E*9@="?R@L$P_-7)Q;OD+O,0+S<`2Y*"'?HB=\5X2<9MF[PF;TWP,#*N*J
M]GXM,67++S]>@,HCVKYWN]U&ZG!4MJYK6;F>SQ,^.CVNSY4.HQ,";%E*=H%I
M@RWK?SFNZ`I]DY#J"_O/3BB`0NE2N:(J=5K+!$1L7E1,M=5W.*/SW`OBQK7I
MIP*<KD1J*]O>ERU`&,X`$SSA2UCY0-9LIF_OC+(OX03EB+2OG;D6>M+1Q5&:
M@)CNPD#H=J!D.`:QILZ-0#B2N3$"*@_"$M^5$\="0@R/0,-YL$\-I338&':3
M4[+84O*!Q)]'YB?@34L;@)<NO3)P/$=6E`"[2LW$]E=&P"[#R6%D(@H?0[#-
MDKTE&<Y'\;U[(!0*E%7?E((199R>I9D=&WB\4C/M-M*$_\*JSSB\HER(MGCF
MV\=-Q>L-7X\LZWWM212HUC_[51&+,[O/W%)44Y#0)$H^P.5`#I\+J^#WD=:Y
M8!5'2IU<U4W<\H897:>7PM&SSN71!.;61F2M$`#1IC<^/$Z<4<"(U+3.D0!Q
M1>M*$_0=*C>>W02^5\_`\X7+A*@@B%R%#4S,BP=TAIZU$%`1)X#?"X6P8O&K
M%0/QN('-6!-T1`C=]PJ#49A;5!>;,"#X-8QOU!WA>7A"U>94H+@6T9V`-RTM
M!`>S'^":W`R*H_V(]GTYE:ETW%<`AM!F=KW;6SH,I<?`L0<<3RKX7/QI`8MS
M;M;SLWS.95"63/+5=A%H%,L<`[NS=:%G?*]2RDU449K=?[C?5W=KE)[#=="C
M9U(4M\X']%$8Z?<`>LQ?D+%],#Z=^$H%(EE:H=2UGG.D2*"2W.PMMC;]'[:2
M*@R(Q>^T-HQ&XKJ*K^00AQCV'ZM]3+H[Q[7/%26TE1K'>@5C*AJO$AR)=QK`
M6.H/#'2:)=8M/C:..8'&#AG\L>+-@36HKQ.'X7S2VQ64;M2"Y4R21#E"$"0C
M>Y;39EG75>CJ%E^T5NJQ!6'8(TF^5RMYEH9/JM9(1'>P)?>NLGC%X]\$O&EI
MU\B/J<';FD2/;>J1K4M7V)"=[>AY;.7--J'LF/>S!06(JHBAZ*I/[*[@;-SF
M@KBNJ0L.^*C2)E=&A*Q/K9?JW6B3V60IXU+!M9+`;:^B=*&3/I(X5JVRX2ES
MH/:2`![P-,Z<EAO25:L$BY.;1:7(N1UL=9FAO8^A[52Z(%>!7[@,';R=&P_/
MB1CKX<[K:`DKIP[6"8B),`N:))NHOD>_")T-GVE%^S1+,`^0ED<H3$,5;U:Q
MJ^=X>VULPW>:-6(NO-/(2;X:"K7W+V`II\J)F$Y9KQ`RE.EL?^/,J;$0O#7,
M/7Y3@7&2?-+%-)SB&I2OBL9!2(8W+:TQ6+W"\,-$WS`B]N923[^]Y>^_`I1?
M!<+]$\.GXU1+\U$\PIU?<50':\E@`<M0C"*]R=139P/J)=U=U2$F90XUV1CP
MK9>&9<%$A]/+^KJN@F"+X[%/K`\=UF!QON!H;0(<7;RY;4EN",S;%0#K=U\&
MW#F&GNK9T(C4(LC*-7+*'00<M</X]=Z/HWA2NP)T^E;1X,:=K[;?]YV38GVS
MFE>4$FM2K_A*<FZ\6QZ?CP%!H)%^'=LAWP5"+E>^-QTV8<L,TTM@+3!%%M!U
MOKIL,N?G9SC]&ELA'M*.10UH]\(+]_NJUY=2[P-*Y[(2V:N0*WW/RWA;A"^U
MQM*N`MX>/('#K8@+J+?-9'C3TGIST93B[=BYNR$%G<A,-A;;"5)W9!M4E01V
M@$(%).D(*P8R,RR-DL<!I(_9W47IT8Z^EY43T;;T@10[,2,!$1Q.]&PLJ_?[
M^I`ALF6?#3RTJ4%'L@J#Q[%4'"$2@7HL'YIYZ?(^Z!3.*&!-*AVB_^P.`PK@
M5B0X.:IO,8`#\?@\0Q'D=SNEAMUW$C9&QRE#H&D+[4`HC5<!`E48$&(TZH%G
M,AB#-OS$MH'\7`)2G5]`E[:S<!-!K,5)8=*J8<"#G@(*2AK9=-B]3'(=G&R>
M746?UT$(JYK9X$8SRXA;X<*4,`##J3%BV5T)8F7;[I*1ZWHOMEB0=1_8<DU@
M)K-M[D<W'AB5M`=%XEL8KALO.0VB0(Q_=QLD*ZVEI;V.\70+-=308(_I\N8*
MH*B):HYQ'5MXY[;,9LM0R0D.`UEO]>+K5%$U#)=>!"$D;.@4MVP"G8U&=YT.
ML@GB"MET4MAZ;@,8B`A@%%4<[<ZU+%P*$;D&"$@EZDQVLQC0N6$+$Z/X2(6I
M2KNIS^UKA&$57)UDK>:HL\50=.<A3;^,SJOZ'45$"7S'!0&=+4#<"./;*ZU\
M['`(0'DRN";.03Z[C//VJK(9%,&`Z3[#'%@5$M%XCRYH5KL)G@-#CHQ4_[[#
MAJ1/LS:UVNCJ/TCFDX%[<C:<?&_1/@JKT#0+-:%*3HMFEE4+Q3$V?ID\Q\5]
MO9ND7,U]UOW-V:&A48YI#B.94\)#4A)F(F%#L]/*[5T)@?`<MP2\:6DECCM[
M&4`6U5["80Z]@/<XRC"8`<YW)S75)5MZEF,5+)=,;++Z"'+=]6(T/2JOB^1]
MY`"@T4S]J;(I2>5`;+I;>%",]_'XC.M2>9G6K4??\9J4Y.'!1(XL"=`):!YC
M*T`4!.<38T.=I`F'M?=?+QKI@#@8V;%AQ<;[QC"[:E_TKI#2[\.1$\,J$4VS
MHR?+=VR9`W4P*\1GQ:&_FIB/O@*%!;J&J:-'ZA4=VFGCX.',,6PY/?U74$;\
M"[1&^[5RB=>)@GU.4X2&9I513QGFU<2[$1($KBL+;@BJMIW@=]W"&6P).)H7
M*;$G&[/O2,2.+&@BM7W[6Q_^>BF3SF1"=_2NE229?">IPYN6]KHBBVRQ#HTM
M;>F=-QF$'J@)0=\<3:Q9YL>,#,N"*IQYSN80H*FIO=MX$UKWL71%V8\:]A9(
M#D7;^:!)/:_0['23NL2JY>/Y@+EJOE8HZO=8.Y=%A'X@*`Y17V<7Q%CIT+G[
M/>[@1SQ@3-"C-`MI!66P.8PZ-<B2R2F//LE&E9#8`0":ZZNH"L>XGH"YS:.O
MVN1W9_<?T$X!29>%E.$94NGA*,`BRL@RV"JRGQWE@V7\-%F6H*PP&Z[G;%@J
M)XY5B7:='%8.N<4^:!Q[`L1](-K_D843J&0<CC`,>+Z+[>M.'X/4>>9YF:@Z
M[[JNN@RU<<0]U8O>^V^P),$(K#GO(6+C"&O:_M]6$5,6I$&58K&-7JZ'HHQL
MVP2\:0EV>V/O*H3TU[*)\Z$Q?7#JGF=:I%*M(;O*S:7<```@`$E$0535FHZM
M5GH,(@/Z0%_(C\]JUWS"@_:<3/TUV_Z>^#H<%#38R'092+B4"B;[TKJNY;;<
M5,QJ!R&>+/&R%-SO3@SB=FX&GSB/<(!NQ5B*?T&%BTU8;4B2>VNHE3=[^%1H
M@(XZ2886CP0(RP\1D"#&V7IE'[P=IX'N[!(`*#DR&GDSY4A!L;,NHQL<ZS%U
M*_G\?/F&.9D<N6ZMX^T=WRKV40<&]";_@<P(&LIQAZ4[^$24;$$W%(QF&EJ6
MI10L5I]+MUM0:GJV=EQW:G5UDF<=W0ZDWLD4^#D:%&$2M*RV.',"WK0$N[_A
MI/,YSQB<VI][QB-N[V!]H)(?V*-30L9L$-K3S["GL[ZPJOQULNI'7?6)EH:0
M_:)"872H.RM*J1N#`8!%)=INDDS8REV'^[[(A_ZF"W0:R''!(ZE&M:2(M]8%
MC<6.!3RA>[CO#`%@L2D_%6M5X;83#)Z:PR(5B&V!J?/]HEO5K'9X]BU0Q@_D
M+<_;`[G`(GA0E%H+QL\'@V#VMG;80VAD2`VM1)Y@BAM,+=XP'YZA4$^=I"-G
M,B9T58?N^O.3I^B@]HY4=0\6&^.B[P3.7(!ZL$#0M=1)72WP!P32=]MY5Y&?
M@`ZH[<W4`W5JAHNDL',B1",LB%ZS^W0/-1J?*%D2]J0EV)WT-G\+P-;+$1M3
M0G7X\/7$^<76&RG.QU*:@9R.WN/4<P9,AK\H8:!5Y]X9%LO>XJR=ZJ!]3Y)*
M<BCV*W4M>E3.!DV(7;U):9YXM:\/0]4N``C'H!U&K:39G#[`HV2TUQWLGFG=
M*UI@]XB;I?BVV#GPBH2P8(?'11<LT3`[S%E"()!$?YC18;#VJHCN<'&!"31@
ME<?*6&T)NV1L_0[HHX(-\"L8>M4;KX'=ML[PTV#7:S<54#RJ`8?NNU"EH$]A
MY]./=!O*G/M(\H7C4DAG9*^\0;_S"R>%CA-S.LQP^Z5U%H!-[A%P4GK[_\WX
M)NWO8>AWBO<AYQ@9VG.PW;!.=QV@)EL]&=ZT!+O=29W3W^VR2DU&#Q6X\H7\
MV02?O>NS6_=XM)ZI_97=B;'":8(Y7)9E\])'SH8IB%LG<L,$M_J!FXQ`K\T6
MJ?/"BA5>M<!%+L*XJLAN&3&))L4Q>]M6,<KJWILU@?4CP5^XSOST.O!5]CM6
M]74;+VQ(SHN^"+"G!B$RW646.J@KRT6QH3)D`+/S"P1H,0F3KBR8D)D:'9^<
MD7GQI6[C8Z(GC3++U'=[Z6>-5NSM9(S,]D'1$9:Z\A[IS<6=`D+',\N^[?QL
M@:YIY[":XL:<[W/(N2,GJM4=,H3G39'7`PN&]\UTR++):ZU50/PK0D%7">QW
M5KM5=GP!RCVH_)D,;UK:JX`R^]/X#%N"8U.VY3$;5DLP1'VP"X>I8/P$:-TZ
M:QZ/`2L&S3#B2$98RG);Q(>-6-=1\78G<UE.S(\0X,5EFJG$O,Z,:'<OF&,=
M2(,:3H$3%AL+1S_KA=24"\36/E!NRRUN2[C=RF$*S[Y9`892]"(L&2`O\Q$=
MP#3$W[&41I*DOQ%0A[!`LJL"R%:C`WH;N\,I]CV_UG?8.R^'P>W!&/;$+3`Q
M_MTQ?\X&=)E,FHMYO"(:B8FC<ZG3D>7O[+&/D2:QI[PB^Z+3OO!NR<@WR+DB
MK'.CP>YY2EMB_C++XTX/X:X`2C-FHNV6(9@`$/1XQ&P+^X^:#&]:@M97?0?C
M`Z]W'@`!.<'8I8;VC)L.^'&O+1[8",:S55S-B:7T@A%9+ZB/K?9SX5M7\0QH
M9!4?;OM`_%ZO!JHMI5MQ$8W2>%)SU4N*DE)`#AG;90*-T@,LR*U"&CQ5_3/#
M_\'R[NREUH5N!8WHQ=5;@Q#T(?9C`-$`OBA]1JWJ*&:AK37H=3LZ,1:/W*&:
M)9=J![9W>*/IE#A#S2Y6[YKA6*6W>V#P4M?9KEA#'HH.'K";9ZZ+BGW>G2P5
M2:K&_GX<G)F$/3VKH(_X`QMNA^O".?^22A7`!W!>V$ZEDF$!LMF505`:?9=G
MB(D0EM(HA<W2KAPW)LVV]9#.SHR\FWI98]>?8I3$YU3K7->UK.L:1N`EX$W[
M^T'N%>7J"Q"95Q$N`EU6EUPQU:2J$'^HN@_>C=%%@AJ\AHD#7C6W4.;)3.ST
M9U^2Y9%-Q3.^4"P`+MBT4FBEKGH&^&WI9@5Y6XT15+/@G>WZ?$0,9EW%@*84
MDO[>(0L'`1<Z2)HBV<G%7T&*>P7JT(^J9B!M/UQ8`OVQQL[X8_1,11.)<#+G
M68PLV)Y,=[#!I2RX'=NL^]\9#!B*1"+*A5EL-Z_W>[6P/\821'?>L_U5\>?B
M;QB/.+46^NPI/J)8R?!\!H?A@W]EUKY*I,4;3N-PG,].OXR4H*-"QE$'1.6H
MV'`(6V"ALYOCS=5B)P#*B2I-!]-3R$0I92U&#03MQ+_V#B.;066L^K_?5=BY
MHLX/0%UIHSR2].[KZK?IINR2@#?MKS?@.MOZ5AD>:*6`\;4$#<;W9+RD/NZI
M@>YMQ/G)6$/2-/1];I_]B-DFO<W:J@IEGE+%OB*^M:"D:"FEK'N->3B$2[%2
M53%H&E>K*#6K=E2+P[F(RH^W9+,=4%5ANE)8J5.7D^O)-AZ9XQ*X+R@+EL*5
M9W;_8@CZ97D(X'-U)'UM3*23_\X:VTOF"U@*C^P\9P%$$(,^&CA_/(CGW-6Q
M@T64=+TMM[+<ED<YZW#T!=2U%-._Z89[Q%VN1[O72:N2<T6C0]J1RTY'A>/+
M0;PM>]QK9D4:F&UCOFG&W[EM3]?Y*@'T]_(IJ`AG.'7M'"Q=/`8=SB+3:F_[
M?+K_AVRN..9VNPG-[.*7FF^$5ZMB0:@G2"]F'=4LCX*!A:L%AA$2.G:%>H!<
MM2.U.C=&:@E$X<CNE=X2\*;]W>SNMT/?!N0.L<_U0@.1]$(E<@J'*=ST:B$9
M)C8\]F`Y;"9E._NM,^##)NV)1U9+D+B'95ET\A<ZS>?@@;V:%F1RBJJ(A".>
M;KEA`V(R>YKNEG-QET\-=O=0#NP28W+;?,$1VVQWU2.PV^WO>Y]94!8NVS7*
MR38>R3`;NEU$IO@A$;8<S.9#Q![EOC&22NDC6/IH9<*VYUANMW);%O%<*/?[
MUZ:G6<JR/!;Y^\%^RFUSE$BJP!U>,"!E^_5V^RC+@A-X\@0<`,JRO2N,TM!.
M652JOZ/:!5BPE(]?'^7KZVM3XYC-")"0L#<@S%^@Y),;YYWA`?M!$5K]C153
M6<V7%8RBBE_%P-N!*";C[T)H$(;PC9JIE\Y\[14(V1VM8$RWWO0>@Q^&63,N
M\.")^<&9&-L]!\,.9B6]B*'%P`?,FXXUZ(O]JM+8HD*EG,<3\*8EV'TCL^QN
M3X^LE3-?J%QED9&%FJ'"YBVO9:WR*UR/?%!/T58FZ\Z$VW:?`JT!::5T9PTH
M!LH%>8/(ISB]D!-0:TW1(R91BIT_A"^-`!:"V&,^XHX/Z2-L)8,K,E;]O"\>
M+`B6]C$'"D"Y?=STMNSM5A?B`.O*=8B6(P<0311;X;J6LMS*(N*Q/SY^/=0Z
M]O;9@._*]0%\I;@\:ADY7\\`:IA`.`&WCQ-(+&51L``*R/>5DU4H@@LUZEC&
MG6U?EJ5\?'R4S\_/(XR!$R#S=(`=V1#89Q']U!7VD$Y,P'ON#A$P,CNX?S_9
MW-/IQ@;LUFV;&FS[TC20C%W%U[;L!R'[DN2?64VW1'L_C%X`OW2,-F<Q*)JG
MG'SIW\GT@9W>W/,M1NL93E=4<QXCK&#HQ)PC(KT=-0]=H^T!=NMYZ<Q!8*@[
M6)+A34N[#*;IYYS$X.`9V%ZG\'*(TFRSS'N,K>1UV<&KY,#BH6H^MAL0CI::
M!)9RR]DMW3P*=(-4X9U%59O'.,'N"39-O&N!TNID8;FO]XK=<YO&,#NM/B59
MDH).GZ(&(=VV,8C:RN>#(G&($"66SX"9E12@IX::W85UN^BZ/A).'DRN7.!O
MBHA]U(2XE64Y0RZ^[E]5$I"-_73'$\X8W8_;A\MHRDX3;Y-[SPO=!]PLO-J[
M`WB`WMOMP?16_<!M303.I'`JX:D+0)?G#JH=JG!UU.,<<-AHTE0WB:G=';`M
M"\JR?`AG\Q&7N2<C25]>>M@,'!V#RWWV4<:1&H8;)=+9KD.XHOGW!.JHG">/
M4Z4I='&HQ`#E=OLH84PLSWM<N;I.E;M=5$RQ-'2*M#B%+7OY*RK0QQ;#<$"J
M#;5@Q;.SW.^/`A,[&<)0CN4L69^`-^VO!*-3;NH,0\P.18A!S#K,R-5T)T<?
M;H#I*TMYQ'3:1V3G/D=T4\=I<,5@P&IMRI*W<C9&B>/(1G1%MS98;LNQ=5ZV
MK6L=XU9\NH"CY9W/)(LC7WU/;/*T-NEE>#LR2F24"J[O3R)&BU@@BFT(J+??
M6[0=#.?]6&`WVQ7N]P?@/1X'\&,(MQ`4+"CD6A8N93U*)CODCA"N=]GNVP-`
M>Y6R**)9?0`_HF'-07Y-@D>4CXUQOM_O3J`(BEM[T28]L3CL;*DH-2O9IY.E
M)"C=@G38FWM9`V,WF%:/_=O'3<2I/_KFQ[*4PD<[?'U]Z?`F4PP%48*=TW0>
M^WCV$[M7HYE$'6_N1;U&X3TZ0IA!\`]-*`!+*;?;4LIB$E:]).)5R!&R$1(C
MZ&%9\Z_^"@^Z^W2^;1STR%K*8)JNQP@-,P"5B\*RKO?CN+6L#]!+J_NMWT.J
M-*3]Y<AW!G@-'.^HQU3#?;;P%P8>@98.1#R11\#/K82Q9<L[H-=MQW"=9A?(
ML\&?52!<3M1>"5G4K,'8OGGT$=16>O,T*D[:E@)%>>1P^15`:'1W]TFZ"$DV
MFFNP29&>.J6DUR_@O#]'GF#PM>NTLW*4LF6#0*+3)Q2@%.]WW6)G%RS]PBV"
M]0:6LO)>;&$+A?G+N3$-)1VUE.5V<UEIA@H%?-,D5#M)'[\^'G)+]]4H4P1R
M6J:01;5;`];C%OIE505)J-/GR-BWHL%)$OA6&S\"U#T<S]L1+UU7GROE]O%(
M%OSZ^GJP>XHAIM;)/DEVW^%U?60*"373%R3ZA-SY$,5.$#@PPG'RB@DA2+:U
M.QO+[5;?EP,X#W;7EE*D/W=4CKDW9R">'`P'4=PE*US;RB&+Z!V@(LW*&5]?
M3!]<#WZW#C>1W2(!;]I?QNY>U"#CQ"'PV;MP<HW.CS8;2;L/UWNV'M@.DH?/
MK/\9Z:'B%:_RMZJZQ/8&HQ3;Z(O..T$0P^]MKO*=TXS[8HC6D:OC)#&8Z"5+
M$X".@=9[EPF]@N)MCJYWJWE)O]J?:`-L\8Y>C*7GSS7OKXIEE!7>K$YO#2:P
MQ<JVVYMO:]71">G7KU_E"_=R__HJ*Y4>AW#[SG`%I8ZQH1&KHB>!G25?(8&N
MU2;>&U;D)^BD,T^E2R>5%?JR6D=2(/QI<0?&'[]^E8^/1P@,6<K]ZVN+WV05
M!Z]!F&!D:=":"*5JD+75IHHEKXNL]6*<$SHJMI*9UA,`E)SA<KNYH2;UL,/#
M.1).'FF84L=MLLZ"W1$P1&\X0MP:(Z:[GDH*VW,+^;_>3/=(HJU'TJ'H8N7'
M4:2+GI76TOXVL/M&<KCRIN&KSK3TS)NS1;^R:PAF,<C,ECK^;6<GRPS@8,VR
MFDKQ<S<+'-);(Y"A1;!'4O"OZ1T(=7,9^C52?NT$P3S4,B1D1)6,-JX*\*Z!
M5<O#<]M6I'-,7<*4=3$F^F#WK""%"?AI`(5EVJ20AZCJ]^OCXS<V950U*BAG
M9]K[XW8KO_[[[R%)M>!@JFT<I:RXY>;+4K^3&I"=29AAD3.@V)((/NAA53;Y
M=!Q/YI+E5`-!4-C-<@E[*,K'QR,<1<_)"+2@;?@.=!@'G1T5,ZG!M"5DD]CN
MQRN3CG@2GO/K;5G*$>?`(O[5`VA=[U7\+LP<5'\6SUFJ(%R)*QE&]4$L^0%*
M)Q5*&JX$"7LL9SEAI<3@C"+IK'G+63*\:7\%T`4P-H],E"RE^:(670B874Y<
MBP$^#97TT65KKP+Z7;VA@$X<5+3H%4UQA-<(F#SQ^8*EJ=DX^C"_`[]$V^U>
MDGHH#R5EXBK7H7[MX'MYQY!9$7%^[H:!<U\RGM2M-2+",&08\.VV=,=QU<1B
M5V"/J[3A'3:L8KD]I+^`5_86N`H5ZJ&=O]'+6A>`0#H&"U#^^_7K$?IQOY=U
M`XG+!@8>R7O%+:)231><89WK/FR3N<*W!0HV3Z/NQ]1Q)F>M*XOG\RKFV>`N
ME$?L[_U^K_1JY=A2?1)PY<50_!"<(:]+C'?X9<'JJ9.!DH]Q6!8I7=BIQ'*_
MW[<?U^!>/3X9<8U$M;:.["YZY3T:3=K12-_GG05P'3=89%QL*15]X@2\:7\-
MZ)TFPD8Q,B.ZI#,Q/H-`FX@=ET!\[]!SF]$K?ZE!T!%G1Y;[.I.@5)<H/K1=
MRWRVH;?U]BHPZ(5'6_U*'G)2]>N2_<;S3PZ9G2V;?E3_[6*)D.GGWN/'X3(Z
M,'V$CI.F,ZR]K5T2A^3:;8M1;-4;L=6I:RD\L4J:ID#96,%?'VH!]:XQ/'X$
MT-Z+1CPT?'F$!!QJ(WN"G-5=YOB<MK-='[]^59\ORU*^[O>R;DEN]*8-VBUH
M"VAT_"^%=-N9WA97DK/WK4+RH<]7\0.=;2T&]46P+`7+4KBN!4!9US6.'3V>
M!>'XH9A?X;9__,Y&G/8Z2HV!NWM*\47K@;R5=5VW7(R::D#3":((<[$)HF/9
MUGY2FC\7J8II^QSH/OWV_+?EW%7`<KQ?BK`4*23#(AE>F0O!!+QI_PHB+O'^
M36LL<YCT&$*5\SM<)B-`Z,2.Q\@V0C2H`>\Q%X45W`0C7!I5O<)GWZOAB.(%
M@*-)BF-2;)%1-CF"'1]!LS&M.DC#I$YU0;)QI`W+WD,;B`$_AJ4?'H+J0:+G
M'.F7)XLK8?K.NBSE7K[<L`8;B\S"!OC8P:[>CF[I&]``/<FPVL2C'90^ML`_
M=!RXE^7><YO$=U9RBR%=3Z6/HH-BUW)N/W]]?9WW@5H*L%(,"-Z/UY[+[59^
M+4NY+X_$+K!=%EB%RLLB-:H?P6@*^[-*&&(DYEVY<04X_2"8<]AQRJP^]JGR
MPI9*E>.4U2/#$SOP8DBK`@L>2#:@5_IH5/.>YF);.Q%R:-[O7Z*PB=$#9RGQ
MGENQT1W%<J4E2+KSG5$9H<^&,V#[9_V<>PC/_H)NM^4`][(QZ60%4+#4^PM*
MP)OV]S&['MB9`;JH)Y,F\>H5>H^28X\!Z@!-%^R*[`A)9PV(=U=25P[@\G1I
M]U@QR=ZQD@*CD`A#-9FBPY3*-O9"4ES=V7WU!*NR9FS5=(?/OMJ*/+2G[3+H
M9DK'`$"56Y]$-?6?VYU6]JC#/0;;X@R&1(O)KB6N?$FNO1I97(&/U0*(^B4_
M,M#WZFX.HQXIUU(Z7S#%$531%93;Q\<A\U7WC<8@%XCFU*PNA??U8%-9;-$V
M69BD/O7]?B_KNI;_?OW:P+IEI=KZQ2AQC#^`+1&/Y>OK'JI\1.$(=?I!:P<%
MCM8QS0"K;QZ6Q=MTP<\XWL'*@>+.;K?;!O)%\II3B$0EF+E3!#L.K(U,UR#>
M52=@>[FAFINI8K"Q:8+WUJUUO6\.%YU0HU&:A9TECJ9_,'!"J'9@O,+5S@"K
M).H>$I6+:(L-!'_<RK*BW+?DO,(@6%HIR#Q^2L";]G<!W5%&M[,3S!:+ZRO:
MNYAD2"W+(%#`#%BQ3:75A:"KC*%-W]%SQQU4\:ARA`UTK5NU)P9@A!6'-%1,
MSF33UG%=]-.^'1!^+!*CCDVQ(16&3`\6*V\QHWA/,$Z29$8LRPM",%\\LH?W
M;'/N8%)5?2L-M7S?"0)[2UN@A$G];%Y?U3_[5X![-=TS=I609HV"TBANN\EW
M?7Y^*B"ULW^_1+QN[5Q&T+I^QX_B!W>Q=6S5J`33Q'.7@A0M+.(W__?YO_+K
MUW\*T`P)H*&?U?KQ\>NA8'"_%RW_%OE)3F\5_0R!X^1OAK4X>J=@+TNW3D\D
MA+/_?%MNY8Z[(6\I),L:.UY\OE#C.09J+=NF-)=QKF$:8J^LUEL+O[[NFIAX
MY5H;IB=VUL_JHWH>M#_N0/<L)G'&.2O@O"SE`P_0^TC28^P0RW&1T"GMKP.[
M(P`W8H`YZ`\/*&U3Z>)@Z-YY+)`E\-2-*+JH!-:DP5JH.Y+T+(_X6N+,HM8T
MJ7"].2MZ+"9UK[+3>DH86:U)*4U3-G".)^)6Z^I5ILRO2?/PM#.U/JU9T(-V
MMK@5+.6^WHVTW@Y^U\?VGFH^43ABQ-MPDV=P;/E!@5WJI#-Z&K=L1/88!IXZ
MEE/QVF3Y_/HJOSY^E2.\U>6"XCZV+,L#]*SW0]OS8[D=A0PLV#U<..7%Z$G@
MB(V\W\O7_6O;1FW%)!IYI;U]9'*BV6GY_/PL__WW7S]9SVS[V[`-&%"[5R8[
M@;>>-^S&E*<,(HN\$&,[!*H,&JF=#W-<M=6/OA9V.&UA9WD_*Z<-#.*9W;%X
M,OEN.<3FEI\_'CQ=Z,#55[)M*%O\:F>=^=I":JQ;&1:UZ&CHT(H_AIZ^LR40
MK`6$7ESK\L)[=<'EF'\1%+XIE+LM#)EFKZ43\*;].+#K)50-`])>YBW:('`4
M5$9@(!)TB#BG.JZOED7?&4Z4Y?@.G-BY)@`VDY-,`H"`;]%6JR6]$5"J*(WR
ME>21>7Z"!00Q`P*4K"SEMER37Z9@BX_%[[X!E^6('[,QH0<`X*/T*7<PQ`Y`
M$^O!4DY'8F<.+3-[3.=D^;K?R\?M-A;BT!@351E1\E&FMUB-RU.?>==?I2GN
M\&@[E+B\+D4;PR&E-_YM*Q.,:G-9*;@V'@VB$$@I'Q\?1Q+<"1B=C6LGN/(8
MG^M:/K\^16QN.:6S&O'14HK+ZH)+X+HG6.V@U_O<,NH6^.J*PA",W]?AR,A=
M!S@#H)(,VZYC$]_H>2TP]T:5]N7VAY!617E*.>-VNVTJ!:M>'XRD5>3<JSA7
MLZNDYK7&/2(HW>N+V+8+")V)P88&%V/O483C[FQ)LIIKX;P-_QFB!'`&&:/R
M4>F'S8GJB=$BM.]T[#L^87G[[8_KMNLR`@&0#&_:3[0AL-L"LJTY!QWP&]$;
MJ)E=!6I-/*&,CZ4!@W`81B7Z31^U<BM;*Q?]$"%TXI)!?\(@O+0#5F#D`-W%
MQE;J<KW[N>[[I+7-SGL\9QTCJK<+J:;Q4\3<?6]AEA;+NFX+_%*.\I1<6;C>
M"^]:%NADET_`<KQO4_DI!KO[A/V0V]G/L2_,2C-3E",N9%F7I=R($N[#LC<`
MSF>^KVL%#DB_>TN&4B:'];812`=MRRULV:?0VZ")2_WNS"H6E(_;K=RJS/8Y
M(/4H8_NI"RT<>J-UZ=D1AJDN^WM*2=WO]W*[W:JX[3JVG7XE,NML[\=M?=.=
M,ZLJ"CQ^/J\CP+>'$.UN!G9-U?,E'X>"32T53XV@*N$K'6'3CCOH/<.!BEL(
MPJXA;OEJ:E=&A7J[8-:\?:L:0J,BT.R5V.3S;@+PUO%?7Y]W`7:==J71"S85
MQ6LP7.;65=2A:&K#U$T:]MEEB'@FF7,8+KOK_5PWG(48P=\3\*;]*';W$M"-
M@LU&PAA&RG29N/L6)FXN/'(2C9+@(+;HC+@I):#D0-O,.AL>H\5:+FA?`)=M
M"WX]%-VIM@[EPJ,$Q?<DICT&<==M/6@8'LP9O.=J[6DU<AR/+&_#A:P;,"QF
M(EXKAX"Q>+J[K;F!;0$,2L65ZAOGRE*6(BH4];8P'!=EW1C`O<>H2[!FOQT@
M##@#R<FFDAJJ-C.]2%<%IYYLOT2@'9"/O]V6I=R6_]1*/"M3MV[LJ&2.6"V^
M$R)\5NHO>"N[>D.3>1MD/W=`3.Z)I0XS;(&?&']V3-KQZ8%WOS/2:.8*]M$`
M:.#AJ'3G?%DZF7190AL_:T.@/+E%?XJLO3^;U&DU@K4"!2L'@98<@=Q/D9/W
MEJP6H-'[%F;CC5D;57#\[D0I:*UBD0LQ2/I09MYMWVT4JG/;^1'*<',=N6H9
MWW;#[O=[<^Z3?4[.Z0EXT_Y&:%R:NKFE0_[TF-UHJT4(K+,!:GWY'8@D%X8,
M+401T=@QF$"O@\=$3<'6HKM/4%OB3)';X8'(.#<0N-S.JEA'-3(B]$YXEIF*
MDPF]=/]J$4`I7#6':&-O!QP).`NE)('=_DH673S9,,=#3`RZ(=6/.%?3BYP^
MIQ0';(`!3R=!/[^.$GRP>K)T=/WH4&#;3W3"=@\(2QXP8)%0$&W%F,%^OS]"
M&)0^KFC[*N8WEDH03-1Y/(NC:7S(FSU"&QXZO5#L=TMIPR^`\E!JD&$-5>A"
MRR\$:E`+J]PRC/A#%P:"E=U+/'O,[4R8@P3[TR3)!(\BGP^*Z2YQ&)Q3DKXN
M<+2M!0O.A#6;$$:6K\\OO9/4";D%HL_UFG1H@^^1O-31WPI`VB!J2:<'98B]
M^:HE@>F=0I<S-]]0$RS4[)$QO&E_#;,;21>%S"X;``83LYXNZ%V'S[.<<72-
M!1(B%HZ,>:1]VY8K]1Q3-+-05?%!Z:M.!,_O*1&<K(&>:8^XSXTMX[H*'L\R
M`M'[7@O+4K,-"NI[HK4#Z=[%7T!H6+X39`\4S..88JZ@@DM8?!D=2AIG)C<Y
MZ/"(TZSKPZ'H@1\&@T,N?-X@J^/3,>20GE6=C!!%$+?NTN?=P>I#/.Z,V=?7
M!NK$-972A>[KH<]H"B](_>E2=+SK`>@V'=7[_:L`*/_]^N]@M![LU^Y\]$'K
M#B*792F?GY_:X91A`1Z*EE3EOKTLG".W:,11O4P^&_OR!)LV\J]?OWS>`6CR
M$S`H;I^G;LMR,/3V7M3]C0#:",/32.^UI`'47.SW?36V2]EB]?WY^.OKKACY
MR*/P=U2\;FKFFDU%AJ;GZI(=M!V\WIUD[%Y67#K7LBP?E1)E<?N$=A/HS0?P
ME_P$O&E_!=AM@HS@"V&1@EX80Q`Z&26NJ"W%\'0XBQ`T'N8A8?70)^2ZGG&L
ME!XP%>.\+*@#R-!@.^TQ8C%9B]RF->](Q&-R\\+)&$11Q?L)H+[%T&*!VA*6
MBXQ<\/9*9>X:2X<NL$P+N14'.%DLJOA3ZB0E$>/8E'ORBF(X%:_4:U',"%E;
M$2$``"``241!5"ORXFA'0L_OC@8H6;_?(U[8&5M43/*VX+G8`"8V_=QUD#'*
M+,X6+RL4<+"0>VE9FLSY-IYM,*X#ZB%[@M?]OA97ULE)PCK^CH;';2<;6''O
M8N*](;;,6?[O__YWS`OW^[W\^O7K,8ZGR%64__[[KWQ^?C[`?'%"$VP?9BTH
M)9UUR;JJZ4,ZQ!:,!>^+(D%U)P5@XXH#H%S8T%V-OB<`^E6P:\>3ZJOG=*+U
M=263"4V$P)0+/(JZN-75'N=<U_N@,W_F/%@-=M@YN=CPE3.;0(=Y4<=2T[:Q
MW84S3HFGO,#'FG5;J+37;:C<'AZG0FV\-^CL].Q[9TM"JK2_Q4)1[$YMBO"/
M5K)LN(`%0YE>[[:J;64/2>^$X['@Z(%=)Z:<=[!Z,T<$".$]IV'O@JW-G9VN
MI7<\Z2=H=M4PJ>OQG(N#(W!X^F>-^8%.$<V-1[[.>K"[-*+%-,\_ZHRI%C#L
MMAM_#&>^WDO4%IWU;\.^75QE+O+0K'36H@UMV?CETVOQ`]1/=ISN5HE^EG9!
M`;]/M1^4K1V9@'F7?>SS\W-+?MGZKA0Z8KW+H=AM!B_:BV^FOQZ[IV"I).$^
M/S\OQ][_^O7K48I8LJ*HE2-./60=5@!'94+.1Q!5`3S-9ODORR/YE46H$!C6
M>#]NO=_+Y^=G^?S?_\K__O>_AV.R*:+0GQ[K]^[$ZS:_.PA];;2'';,TBH&T
M9:1-TI^\HU92HHU'KKQX:(!W)A6S[G\#LY:L`FC;1VE+5_)R$%LTVDGR^_RY
M=W2&1MF=R\<<[98[[[RS';@GPYOV;9G=D=BM*:^\]Z=>E0A79-',@.REM#CQ
MAYNK',YC2@4(A<']/ABRM=1Z0L5(1?10?Y]QAV1H2JUE2S8NX&B2T51-*WM8
M`_RPAE(@RDSJTKQ#SP@),%%85G7/-N(2&--1-JV@66\3RJ%Z`O3V<%&,#-4.
M0!@/BT"=0Y(N'!@30KR4#E.J%T`XX`TNR]IJN[-"6''0>TSY0MWT,#'WD!S[
M_*S"A[RD+"7TQ-,YJ.8I1ZY,CEF=O&IQI]I".,^]G'W@?O\JMX]K2_:OCX^R
M%)3_??ZO[CNT29"-+6X6'P#+47-4I0MB:46;?7Q\:&6([:J/=Z/?Z7J_'^\?
M1X$"%"R+EF2[W\,^%,DG:MFQ)<CZ"J84!M.-($SVMH`8-X3N%0CE9<ZWLF[.
M6;,XH`H'@D<!.7?K2)JI^9QFO)EJ/?#&JQFC47TD1UKO?'?:*>`Z\AS1V$<"
MWK1ORM8.R(_97<0K!`C&UTO_XDX\UPC>9L6=PO>`#<L<E]U\'+A:[Q>1\/O,
MNW#DJJQ#<L2FUG,04"<4L%=ZDX_);;GIL(9S;GTL=.M]G7PR)WX64)(+GO;I
M;/++(=Q?876G8,!>9M@)8-,R=:B24]RPN2@W:VTUAR,8I6(M$`0'"S!A0$O4
M_ZVS5(%=*9$5=<16#'@1>JDJM&B+6ED?A2Z4H!YCH3%Z:RI/(*CZ['81&_9S
M@@Y9^_MT9*IXU,K!0EFYEEM-$W;Z__GY[>-6/OAQA#<H1^E(N-5)BAKLP"TA
M#%.8H98-#`#<IJ.*97F$,@C6?5U7/V-_[U^;E-O>?_9,?VY:WA9$^T!5;K$W
MXO6#I*J6I'OEQT`G[!YA;*3*WWB0H\O9EB8&ZA&25$12F>ZS&G/ZD?EQ[3N&
M/$^IJAQ2S6F>@UB4HU]T7'BI2U27XJACF,GH;O3F;/PN1(*)E:-+AC?MVS*[
M(P!C1'UK)O]LFBFVL<`MQ]O&I+E"$E`5C2)&^63Z`J!XC'_J$DE/V+*@/-87
M/W-:Y6))3W[7U2VEK&6M[[M1J?*^+8:2ESFXD$VV;!5)<9?='2F11+J.UPSH
M924(8#4B94((E58QG))65.7F**KK^3+3;+#;+.WV9V$=AB?A"R`(8%8`PGVE
M`GC*[7/I-'U]?1W%%]RZK!W&36W1D]4B7(0,T^?7IR--)<$>5#QS2]+N`+@5
MP(.Y?1U0+1-*H5@RH:DM=*7)H@I@6)XLKN*E.\#'QZ\"H'Q^?JI^>/@8+CBM
MM;1+Q?[98^6$1*/;=<[S]_M:>+]OI;-Q,KM2[]GIKO).UDT)9F=V#X!.DR@K
M`;RLAB>TRR'FZM:TN=;UR-K3&NLY'*HPT/F^?MT^3)@0E9J'G#O4<ZVFPEJ<
M*=8@7Z)E)U`8H9B3),`U;+%78\,1>`GH<N'\452Z-,4P3LZ%=9WW[60)>--^
M'+,["F:CHW@%/4]BX=GCE%9MC\HN@4ZD*7MKO7R$"@9C#[\L*.N*N*2L(V1.
MLMQYKT,:]^IP"XX%KG)\2A%,CUA448[OT<AE37LLK*6,['U8UK?[3D.PRSBN
MVS+QK+]QZA>WM9[#7,O-^;BO=Y/%?+8#.^Y!3;R@H[A!K0OK),J=G\EJ3`%H
MEC&HY!`;)^WKZTLIG*AW[,4CM"3IZ&4,F/Y"GP.D]`X%NRK?<SGQ1-&AZ@@)
M[_-O@<(!RL&FGW'!=!,?SW>UEEBKL=U0@"Y1#%,"<M>277%7PV59.G)5@N6L
MI@=;6,(A%O8/J-A!'^AZ^N-H:)",DSNZ38ZNO2QZOV5[,8_*8HX,F6@'Z;@!
M$;"%XFP]$4"M3XB#@7=/2!.^4\F>^<A;)M,M$/D8T61*^1YJ:326.)%QUPW/
MI+6T;\7NC@`+SN+33:2@2N1Q$[1*G;QECO,3'<:QEO1X:9E;>P&>NT&'>H`#
M=NORP^>Q>^G8E9QT'^1F%XYZYW6-<[C,RQ$+29DX(4K(XB$ZOI>4E(?OD_<.
M>&VL(,JC0IF.J6P57$`3Q57+M@O.&IB*/>!55XBR]Z!BYDS@P^ET+)K-#&XA
MRJ^\W6YEV6*?E?\#K19`%Y'[4F+'6'"2;2*@ZXU[]K+G*^0BDZ6<ZE<JI(3E
M?K\_0F!0E+.DR4B=X&/G@[/@1CL>601O>G4(W2<\VZ&<L=JEN(4_2KF$]U4_
MP`(%,BDF'U+/<JK0B(Q#[4@1GWK-]CLL-K"<(DG?+WXA$F/%J"(?C*M,.+4)
M:105YUA,Q,RQJ,!MQVB^Y^8*5-<2H0.M_VR)<)I\$%A'CRQ6WD6U@]IUD,_N
MC6>>:V+=$Z]UJF*")BA8UD["W'+$8:.QZLL_P9U&(Y"_GS<!;]K/!,>3Q\&J
M=[4TZ`=<\X.5G`T?+5[,\(/IE(DC]23;KI$,!3#D/"'`[[JZ$E/QS_L6F4Y2
MD0#5Q\Q0R@NL^1_!2NA)3BZ4NW+"@P4\X]IV]F=7''A,=$O,6(<Z;^*Z0@\K
MU-6%J4G@+1*T^I00.].]W0NQG5[QM8^%?$_4L\R3MSA[D/OQ_FX";[#$40[M
M@<$*Y)60(6^@PRI3OXRY*OH<-E'.G.]^7Q]LHD=21DNLJ1)2@W*,3!5!O^R+
M*=+$%9.<N71W5O2+8/ALP`D0&3ZC%W;MM0.@G:&SGU`K.E25WJ3F`!7`+&*[
M6_ZN/&B/FMQ!I/`LR%..+W)MK+*.B:0="K$*Y0'%>#J*NPAG2`+]TE(C8KM_
M[_'07N0.'3)CMH\=_Z.O:0XQ_F^RRMX^?DU.@_8'Z+9;>[I)6;*T;\3NO@L:
MDP-)4B,+"6V1@IE[=K*1*/E3'(H$8IDI-J<8V+UA.Z?AG)S@+.ILE`1U9T>_
MUOS.IB[+(H1CXKKT31'Q!56E+M9"D65=U[)LE8<>S[X\,K9%(L0".%0&BJ_S
MY1&%4%6A)*LL<8_%4JI-)9LA)*XT^V&[`7S=5@>V'B$-0\Z?LRUQ!+I1.'^F
MB$4'T"%D-)_`7L>"OHXBQ^%YI"HJ4>B"?+DE2H?>XQ"M;^_!$[V&:K-:S00U
M4XRZZ,-SX5</;=]]>[PJFN`XAN<6.:HN`HC('2?DFH;%I2B"XFJ->_K0193'
M547U&&GP58F`.L'./$0%'C6;*D.T7$?OV+DZ8YKEL5XU/!2O6F%=6)Q'0M]J
M4L=H^J]!KA;-*LW@>E?.5]_D4'7'_@)ZJGQ(`G@!RJ]?O\)B(#*Y[WZ_BYV'
M*W>2(0UI/PCL\ND#'()E@BWA&#DT!WUYLA1`"[1`@=[Z7!M[=Y0EO7(W$F:C
MS0:5XDI3C5\UTIK4YSJE>!XR9(<4F5/]J<<4-H2&=>B$E3(:P!D,0&JK?\/2
M%XPO<I)5;!T6\:]U\AIU(S>+W['MXM5,G,/@1BV@JL"M,;B]"*KWPA)'40E2
MQ*W6X)=.!2N6=HPX6UF"KD,IXQS1O'=*EC+:6,>DXXYS3&G`%_-T4%K40JM:
M`%C(WQL:T9ZL\H#X1D5B6-FM8D`I6;/GGD,44J%6$E$J$M!*SXH\`*NX85AK
M%5H1/.%J&F3=PM)HYTB>71J1OVPD&(\P&]&M6CA2;RS`60-'<F[.,#8L6X6]
MCX_R\?'AR.0)B<_-$?W\_"QW46%N%`(H1X49TI#VMX#=`-!>(HY#P.%OY^V3
M79?IDD2@S9UJQMCJDYS2-)7DX8,!/=C7!JG<6!T1+-MALE^3\Q:LJ?C?#G"X
MGLQ1G:5KMG,W,+I7"Z/)_->+5Y1S[`2+4"]:454\BDDX:ENUS3K153UFWFX1
M[RQ'WY]!GU$MI@,%HO"C8%,MYAXS5SVW3JP\PCUX'=QZ`/)^7_56L"CJ0,IM
M:RI'C$57*U1;O+1COP5T[>-$GG:_O]SO:_G?_S[KL`H.#_3C4D=84B-1D3QU
M=Q4[1[@7H4*]PEE`W1\J#6_H+6O2"Y5H40Y0^!^#[8I&WY%;_B3K'9L(^)9-
M(6(G(/:_"597S;-&(]C^G2<M*]QU*%\6'E87A43.@B(\YV)/]FUD^#<B:X[K
MR<(114?++'L(TC:?HS//<%V-0DF?RD#P6:HTI/TER%F#R;JTXP2;"P<SM4I9
M.EX^1U3^#9"J-'=+T7(YQ927-:=>RUK*NFO4HLZ[J71>T0&'""N_*_;)++(T
M^X!JVUZ%*K"07RH^M[C7>H#CVQ9[NL?N2DU>=?]5S<M2/`V#(][N4`HH':JS
ME%I$DJ_HMO6Z;7=7]]+`7.NRMNY[E"VD$UT>H%D6%JB3X-AQ4"/G[@`'@*ND
MP`J,;.]X:_>MW(A$E#[[8V3-(D9J7>^5;J`GO%45*73:<B]A?;+3=%A$'D!8
MEG;M3SQM!GE_S*^OA\/SZ[]?NNJ9:62K#6(=X-O'1_FZWPOO/&&0$27?@7]=
MP;&X83AZV%'=BYUC#BT!KF=D99B$9QQJ4ZZ:37=C8,H_DO;8)610/3-=)2V5
M6.T%,(>^:%UYKCB.?2=*2[7;67:=2AF"WGT[B=6V/="3?2Z-,;\M&<LBJ0\C
M4RBV``ZG`FT":S0-)P%OVD_`L65PSG+9,UB$$.$\^A2GRVY2,G[G0#TR:P,5
M<[UT4%4KWPD2%C]]3$_Q_D*W<MWBZDXOVF[K'#&KQ=?/C."3O9C*F);*_I$J
MNZPS?Y0]+@6\-][KHXU6KN7&FV(2]X=YQ/@N6L^TTXM4(MZ"\E!..U4D:.=O
M^'_0)3S;#"A<JL2T/XL/GEBT7F]!L(]I!X3>=+Q_W<_0@1+%=?OWW0.[/:FR
MD\GS.H8I4&+0JP0#>ZSDF?2$N'^N=80Y;9QD4V<9C>9!U:=@=R2\,:S*2/NC
M3&,D*-![OZ_EMCN``:"5TDW1;L^OCX_RO_7S3,XSVK<\/!&K4QQ7)V<T<?!D
M(2`*`QP5Q^B!)JME7(^-8X9OZ%Z'%0@=L`=HN:R&+'%WS9)%6&!(DKTP#8Q7
MH]I&_/SH_XMR*NNV9U"L0^]N%*#0J=?3T@Y6@)(QV*2#_BWYM*[K(TG-RN]Y
M@'Z;GY=E.7:WPL5_8)E/P)OVY\#L9#Q.Z\`AF3*;@MI"=7(0!5G[U;,X985;
MDX@&2C1`'0%0\T^L&85R).AXS,(C4Q]::LA9-GN;2%19_J**U!'39T(-Z!/F
M;E2=DMYY%&38E1E(S=;=U_4QB7Y\E-L-#<:CS;#8]Q>!7<T/B^W>4)E=)REI
MO=/SBRNE`^2QT:?.93=.VXV/%&57@Q+8:M''R8!757W1\BNDVH1Q(HV:!R3@
M+'ZL+*L%'>W2U>)99#9[*+[7T/ZN2V;[CDF]W*->B*U6;J4=JAT@Z1#+W9:'
MX@I+N96JU*\*S3!%(.S87FZW\M__@_+U^54^MSCG_2*J+XJ=F]VGK-K%T36V
M]W7,!QO:JJN%G7U>%O<F-9QZZ',7,:Y8)VV)MEM9OV_;YC:&F-YDJ^I`V&1=
MG3`L$_DLV`94]>Y33XLLMRW4Y/&YC&6EZPR=?0BG\R;;+MR=,D5NBNF/GMAW
MTZT_G0XO1\4"\E4X;)ZS;\.]UE4X"LXB>%0\E.L&A3/$9'C3OC'8]1SL".RR
M?TB\+':2K\=SLSL@%Z4A_Z0_E-M/;@)OX)E3<]JZ+9TJ6*?>[4#$FU?'MFB0
M?VR-LJX$U'[=;$8(R'@S%<LEL[_QR#S?P;P'WD;RC77@H`5I#$I]^(X3`Y%^
M>5_Z'4.5T:!8I!1/1Y:RH+"C;6GO]9'T81TJ!.PB#W"G1/&AQYT%BU72SL'(
MHH=/!</C46LC_>A\\OO]?L3O-LO`TG]V71K8##ST6##92'7800LL0_0#N?M#
MKF7!<H#$^[J66P7Z5W%]5&POG4ZZ+$NY_?HX2RV+4KRU(@W<@@?47HD(I]6M
MOLIW`:U`8.^K5AOW`^>;^LYR1H1=+]@F4"J\9T,RS*[!`=[U>U?U1Q0Q()P3
M/B:#Y?;(OXA(DSVQ5CG]`VUGJTA"M\SY/>P[1S11/72;`9/AXX\*[H^GOZ]K
MN95;[1"8:^[A;#*,S;YW-7I0M%J/H>X3\*9]2[`[N*Z-`^-+-QK<*R?O&_ZT
M5(O!.*H``XC;%P9K@W[)JKFQDA']3;MP./%FZH9&*N?!QS?[Q+4\=')7*5U%
M!\:PE/6^%N`F%D0-9#0]*>.F(>2Q1*NJYX7#N8XY75Z5(7\\&%8.-=;RB^*:
MIK1Y32O+?5TKC4VU9-"6AJ5AZ9Q824_!(:J((+R/2N^3+,NVV%<UK#K5W+Q+
M?7Y^;<X1=7^7\=J5D[E?J@:[U$'J==^%!C^2_8<!1?I%Z@0YJ=:BQI<(:SB+
M4Q1G#]Z$J4!FUM/963H=RG5=U9@!+`M-%4/+$L^/9U:^IEX5Y*JV4,:3%>E%
M9-'I*L<NG:P":<F$1LA36!*^G9]1C6@ZU<$D?[#@40'/)')5H!4H]-A6!KLN
M[E0K0"VI-F!,@+1Z?E5>&,'.7"4-5W1(!62?1_S.CW`.BO+Q_OQ"]=9$,1J:
MNT&6%D[[CH!X\@..X@P^>?UBO$8?_C0I991(Z,N<C^/W.):'!S4A5O%>U*5[
M+6=U;)%MSTX&,2`6%TR'K;!">PN6L@#EOMZ56@8,N'A<;BTL-[$FV6<JYYZL
M89]1<%1.BN[3=2S$HJY!%:?[?*3TIC*9!?M(N[E*A[<]$@0IMJ.#>%7+^IB`
M1A8$K#]#)PL6M$KF$*:*7($")Q.T[G&_NXJ'*F2P?;981EHZ#K3Q[$=D_0&$
M?8]3'U]5O`+53&&3:278;NVN4,3(T]V#]R<;.BZ2(J%E(1UA*UF[U([ZC0_J
MH<(8*O>)M8,W51R<G@,N&'5WDT!(.D)RG+:4K@!+7G4_-4=YX2QF1Z>TDZ=1
M2OEU^U#%)N3864?FS6!8MALO.)]E3_=$-5LXPLUUUC.6=**ENH241W.3+WG&
M')]RA?W5^5C79$Z`:(P$O&G?AMD=6M8PRJ@9L'<!;,?ZJ7M]>+91+08!7L#T
M#C2#'T<YDEP!V'#*QJHIF`6A"WF%N:^@O;>H[C(Z0,&RE.6VE/O*;8NZ9M).
MO&ZI'N%<D"8B0X([GF"9$R"KT097"ZG0;(Q+MG,OU%$GIM3,,ZLPF9-;L[W(
M[EB>B8*LDFV*6*!&')IU%_ROUMPS>:FJMH:!L*#`7R19/O_WN>T&U$%#:R65
M9O0,CI`&R4@]DM]@*I')S>DJA("U#Q?MW%358^V#P4A1<4#V;D":;.\7C]AX
M$1_[_[/WKFMNX\BR:`8HE=USWO]1]VJ[1"+.#Q)`WD"R;,^>M:>E^3QVUT4B
M05PB(S,C>&;9A0FW-O8Q6YJA:XHGB1R9&\I^152GM,_.@DW#S/I>!6H,;.]2
M1R=T>S0&?0P@#5YMLQ_\90@$LCR68=FN-<63.GO@9)[%VTS7S2D@#JRNF8;S
MYC63Y6!RKMF2.R,?EI+E1\!:M>TXIF>@O:Y01])_]PUXWZ__%6#W<H]V$?WM
M)K5?!+OWJ&+,%1-^%=!WP,=3"1:<1?IA;T"@#DM'?TF-X8UQ*`52-T@5YTAT
M,_L<H4ADS<JR,[5=68`YEP*?RZ.S0V[/*I3_*O#"VL'9+&5F6=-KR?4L=9ZQ
MMO37.:DV)H]FPU.@/'N*#!.$II%P,',ME8C)0LN;.%4#TC0EJGO7!O0N(D-E
MXRP>Y'30^G6]7B]C.9T5_.P8IB%,J[;140^U[P"D@'K4C$\5/)"1^5I(%:J"
MEJO'NQ$:LK*KDYP"6I'Y<^R,^#:*'CBK=+]VMV"ZZF#T:V$J2&&`H6<!Q5][
MXAB.%/S1!`=V3'"7F^@/$`+CS&`@,Z-,H3<#TJ2+A8*[F<[S\3BTTR74O]MY
M4623F@/S;%28@,@VUXCI?.NCYYKO+D]3)VF790!:M]ZN.`$E]>>E_>B:E!73
MI1X:?!\#SG?:-^!]O_ZO@-VK%"]OH"/^.Z_Q$GK[^L;YA07=P6LN6:ZDTOF5
M\;H!5G-^Y2N)14A9BM1#%Y2J5NZ2U56;8]8VU=)HNT/6!-2IG#<=8S+?F-.V
M(M'.36?N1[[CF2=I?,/V)HB'F?N9_G]=8ZTXZ7K4X3Z6)<S#^>$-`W"]I)'6
M(X[7>\U&P\M]Z2)0+6GFG:B:K!Q[$8IAVJRZ1P)@W,19UU6V=5/*#&*K5\FC
M(@"!G6X9`L;*'!,8-#6GFHZ#K<;)P&[[V8*2LY`25;6TZ4.O,Q:1=5OE63Y2
M=BY4Q:9@MQ[CMIEKFW.Y-JC)-$1HI0R"T0D1PT>]?L-^@%S.+0.^@%V;7:;0
M9'PX4?NV[]V#&F5"HNNE>9)F-`V/"9O:)/7*LLCS^;3[L:^?=OJ4W.QLXRD-
M`O&>F4B=Z10IHO=Q.!>]VT?#7".[[1<Z4/-UU8USV+9Z2)$Q/AR)S9\03,Z<
M,6)OP/M^_<<97OXON+X4`%U<*<_8U[3T(@K]<N)-1M7P<<IZ9V0:)DRW40-@
MZ.;VG-A9^3,@LF[U=.,_#2':-7&B?)#:M2:UA,JR4KBG_6.4[UD6!IDO$4GZ
MPN=-6_Q*,)*RYWO-*.YY+!@+:EDW62:,Z`SHH\#WX)GYQ]OU[0KD<L(NIS>"
M^'?JD>TA"11X3+I]U!6L!NS2P%WZ6L_L6.0H\=CQ+YP\$H.UZC2$I00S%F2U
MT;1I[\X6AZ9&6%0HHU89F7_O.;G?&T*W6H]F1KHU`!.DP(PT)GMZ?IW]P^$G
M>NJ1WH.)O;PBOW0XTM:4Y?>:9T]3-E(V3T-YV3UC2H/1PX#^=;^7NK,.R'?]
MXT>?S\>NS"!C+YS5Q$,@&ZNLZSK)YKA,Q42+(CUO&D!G?FSD>QI#<UU_1JZL
M*]NG?&8B-A?O2BMD)$@BZ7^L&TRFH.BRE_?K_?H/`=WS0UK$9<M_"\C>87?O
MR(UIA\LLHKSS?J%#6J)`/1P`G1Y@$YP1FH*4Y6.NN'NCT]BS5371Q3HI#OMU
MP]C@&6?&;YQK<!LIS0;J4ZL&_'8S#DSG+;(3,HTO$)CF]ME3U@.S>4(%VFBT
M:*]FOJ[0*"C'V'S-?I!DPN:>&VU0?S"I1M_]K<I'ZJ&E?*8-/+MO`(?]:(TC
M2&OQ.[2GK0&T5S'(S1HPJ<NW01(52V\L=!53V^Z_L^[&N8MNG.;/MP@$E/['
MLLG#"9A0_U;<=ZV;57T0W[P:.]V-[$%8DDR<PM0%=7D'N32BY(V]E8H&[O:]
M2!0^FOJ!KI%U"X_&_,36XVOKZ]'TY[6$U9Q"1'(Z,U^6(J49AU!Z#77?I>`T
M?R$JXP4WWS`"LNZFJ=E=)%V1%J##U>.<-E`Z,)_X.IYB@+(L;A]T=!-%-2<S
M3:3ZY\_`-GEB:5_3;\#[?OU'P2YO`,T[];K\!8AUS_CWC*UC`"?ZY[(C<R:N
M#YF4JIUXW9^-,0P\0=+C<W[J7,%A:EJ4$_26V&3^"NA-M3@1_UZ696<R'1C*
MYL*=II_+9D=R<CK0IL4AP:WLC(SKUM0-B%2.`X"NR_X+\V)Y/-P93*-ZX7_?
M@UT-4D_=ER^DS$S#RC$(NV[N9DPB=(A2Z0T$QG<K1;8:F6HO8,`@I0<GT84`
M)K+,`Y-FP`%N%8M,*Q22N!`'PP.S`71;5=5<&,Q1'!.HUF,'P0H0PQE>;%N=
MTOM!``(Z<DAV3;U7-;`,U>"%;`+$5HOI?`',O^U[[@Q?=6&BC0!X[2R8!J,)
ML-?KL94YT#+.YF:*`J*`/![/8:(RVW35..VUUI%@V`&^#@A'8+./"10#[E.`
MXP/H1+U-S"JY<4_6O\)P9CA@#!R&$RD[DXP[5-WSC?/<7R=MG\(;\+Y?_[87
M<!]PSKYY!Q#/(,R5Y?>7]7M=!ZDME(=XR?=X7#)4`=]AFD\E;1R@Y`P@.A89
M*7)$>(\S(XI,,2#XOFMK3'=H]0W[HB$&OL@B.1B6Y=%EK>Q83@Y`<<^,U\%2
M'%_D2CD)>S1[;W)VQ#-A<E3G<N4ILYN]"B#/QU.N^.&>;@^BF]%^^@8/?C[7
MU7S9&]?DI))4#$NLQVIO;K%/")EP/O/Y91A_6I96_YRWV)TR]:D?"5V*UNU;
MKN)#X-JDD`<EQ+R\BF=[(X]Y=*QCMS(MHP[5T$BKR*`G"Q+3$9EF-7"4"TC"
M"L?@EJJ(.<O4Z&<4Q@<QJ&S79V9-<KT:O.DQ@6.-[8&@QB:QT"UE,6Z!PT%P
M_],:*MGV*)0Q5MX:6[Q)B"0E$1(9^;;QZ4`F)-,8SF(:I9*S`PK]Y]L^MS3Y
M-<Q^=NQAU036./%*U,\*-J`WX/==TO!^_8<9WBLDC-L_BE#7=>=CII`$,X:3
MMTH@>,I[S0^FRXNYA\7=OD?)RP*\[NB7HAG1';GFSV33'7,"$XR$R=\.M-*0
M)5)0CII648QV=LA#"<F"OP``(`!)1$%4<LVKG%'*_AVO5&E,8G0W:UW>/`!$
M<%G+M+8\D][DMO;ZS:^MN08JE\?C6KLZI_6GXV"A771ZRK1O#0/$6.8#)U\$
MD9"Q@`+D6G:.9A]`RM9F_Y-)-J.7D_C4M@O.`UELRD619/1A&M&,T5]W[5(V
MJ:*8Q4.R"3Q1;7$A8^W#A2.-[MN>)AF1'IB4WDS)D[UIN`@BS2(,]089@X2,
M$3U`S(3M\VVH/$TMP*BKI)D-J"`9X[_%!T`Z&$$6A6?#N#_K/3C'I:(-51:`
M+JO".YDG]>]Y-K/8-1^"Y^0@)$UI'^6Z!Z`Y8"Y+2245_/IL2BNSDXX7&U=P
M?[1W^WZ]7_]+P*Y8=H,W.-U,BP]?9)KN_2!/65C<XKDBL(&E'O*&BNM+,WE1
M6Y.7-<\Q1,Q(^;3S!S7#XC,%`X4.7>VR/3!,35F8""IUS)'6\UQH=L`.9#2_
M4\]P^V<.'TA`\E9L/P[T`#AA[`W`=X>!;NQ1]:H3-;5\_`%9EF7(TCGP-WOL
M\P`.@4%/'M=H<COI;]NVFC#I`^+0%.+@=&W`/YZPYNQ!KIMV^L_/4BTN/9\5
M-EF0H@%3"`7<SR6@8[*^*+N2B0<'F`742-CU5"@B!IX=N$Y^(@9R<`I;172C
M(C');%#M#4'K3=>%,YB+B`H08L0EG>V=\@@3L1H$*V$KB$8F83"24!O8LRS/
MQ3"RJ:*'NZ[]&8\2JJAX@[$?2E'7=3P/W<J6]<40:6/:7*XM7NQL9K2`KI5Q
M(*G_U5F6RJ;.X)HD)X\JCMID=N)=P_M^_8?`[F5-[N7AK>7V>;OQ[#[BODD3
MG^RQ,H<`"6"]`2YOC2CSL:3B29FK,/#N7>OZ3MX;R=E&/KNKD>I':(KQ;C]I
MLUXHJ>8%6SV1$?.@E[D/?4*"2/"P0+8VK-H!/3+!#`"=CW]6FC+J;VW:5G.I
MV2PR;F5)N!F"/2^+!9%K<AV]@<H7HL05;I/UK::9"KAZ-HRJZ6_4(DM<"SR-
M36T-,S.@Z/E;"3;%\7>BNJ^$V#=?)Z]UDY\_?_:FI^D>J'NW9%@4V^"/24"<
MXQQ.S`M-O7>(\V<U[VILM;(!'$T^D27KL_&J1@T^&)517S]39F2V^^+R0[QU
M<7?Z*XO@:%9K9CCI<W/1==6*.)XMQWGMN0?%O7G990[.]NH[YRHF#:4BNVWR
M'FB77CZ#+*%WV(+;C%">?9EG:..(MO=[RY*]7__W`?$%T,5MG,D_^MG)+F?<
M6J;N3W+NDZ:=O?)-):9[09NCG=VK9W%]NY!/F\>47_0%NC-V68\-'),8),<X
M`WU9K2$E+<%TS!`E.0-P<?'-'EF&HU'65#9U@*(R9<CDB!3EH>O)9*(3&8')
M1)9-J7G1/=L[Y37D+O6SZZXR!EQ>OFERH9EFM9<EFI%M5H;-WGT]S!26Y:&.
MX`NM8\EU5"-N0->`93(I@T1](I?G+`*GJUE<'2G@*WGAP!%-PQ>G:]PY?#5M
M9LIEI4[:S&<43,1H2QNG+TS\&S!9=W!S'K%9LWT/JBX7"6$"8`H&H?=&*E64
M9.\9YC-68BTT+:H(!:KA2T*0>),XX6!DAQ2C6C=,C"(2,F7;-K6M0$D+\R;!
M1%?J-NYQ%NA/(3Z3-$TWJ]$6]DWWO<BR/"(C'!HV*9^O5]>'G@G<.VEENS=>
M$'%OP/M^_>]A=GF'W3TWHIS9*?PV,(9T7_@LQ2R87SN,ZU"V@<2@?@"K>[J?
MGFD^4+/H=%JOO>,=S8O,%M+>;K.>]3)JTP#A*QIQKGDG/'8-P"J%);)TLSF`
MC`.`W&IZ[`<D<*V=:\Z#>!/:H8O*VK6S9_V@M'7`!9""<J<<V:S-UVN5K6[V
M&>FFD#LU$9@<I)ZIXKS.CM[P08;;4JV499%)<!"%]:$#!.4(T8#F_J41_)E2
MA`:Z3VHC@V&.SJZ#)B">-;.%<561W&4MM1MKN*"+`GD^'V<A@(ECF+CFF5*%
MULA%FM^%1(";O9>O66][F+D+W[!'IK_?@J#1`[K+SP7;6U?K/ZI@E*XX>_M7
M;\J$E%[J$&2R0ID![KE1(BJ2@10"QW:,G#(_>=5ZN$!J8X_D^GRYB=E/D!-%
M/$D1$?/IF*NON(CGR.`]'H\\<''S<UW74:K%$P.<</^*8$#BI*?N_UW2\'[]
MKZ%][\E6X21E,U80_O#E02`HQQ]?_S?['2A=R$RR\@17V/K-KQ1(Y."QY3(A
MON04IZC&U)JYFT-@I882!4\Z+'CQWX;5G@FBJZNI9-H4E6[57N:-2GL5>5TO
MD'A.^91NKH(40&5(H;H#J#K$K)L!^W^7(F7YVM;]>HW#A%>VR#J-.RN<TS\#
MIT_":,'<&[,29DF/D:E-OFY-476*D>D*C6:363$3X\]^KS-J@+&F%M7,9O2I
M]*IW&J]!]6-2C*U%/W3`V@#[X_$X#?/SQE7NJB9*H0&&=G,LG*@ZYQ.'L3M?
MR\`6)UD6_6'U`+MTJ'OH.3M5"56[:T:@/5M_C7Z@?X4>82(PH<ZCI91[*CBF
MMGT[V=O5WG!R#HT`$7_H/$PF9W)F[NSN<GI=Y*X'O:Y;WSRFACC,@+K3N3OI
M$W@#WO?K?P>[>_-GIIP((MB]+VDFUX<A_,&EHMAI(X22K6$&9G^=>4Z3J6D3
M!B<[35:W-][$V&F>7"^2[QN>85*.8<]VRE6!2M[/EQD\N+]]A_A-(Q2M]4G>
M,'LV^WXB"-5E0^'80*KR1!JI='L?M'JD7SBXFJI#.XWAUQ/R9TI6>X[X@E<G
MSB]B_07T'-2UR9WY4\P=5'$IG1>>5Y)F..#8&3"1J!Z@2T28%-M_*3RF9JEI
M2G8#2\C0-17NP-?D,.F6-`V:XH,GR;L?4\-N^_VR%-.\:)DZ*\(*3=VK>FB#
MVGV3D_F^"P9,(Z-Z_\8(A_>6O;&J^@9(I>5AW#5\603ZY\RT8)I#&)*2BA$$
M15W@O`D9[F=D#U1+,<\>L\U'L9=UJY(E%:<`>W)&:*9[>GSV-9HKU<2@<')=
MQQL\'P^_6LVUHX/Z*ED)`TX(*(E'K;GV['??@/?]^K]%X,ZI3-X%P[SUIK\#
M=&]%M><PR6R4,WM>WAB?&4[#R7OQPH)C&!O4KX4<Y@)@'(G\\]1@(-,S];]P
MI<3A^_]UNE4.N9LK@XXK2IF*C>GOE?ARS,8]EWR-S'P`JY-N9S+.*JKW^%HP
M:MD___X#A*E@AQ;49HP]Q98T&`<SSF:?N(9'&IO=DN@R<S+61A:IUO/9#`MJ
MYI)Y@TVD8TG);/6II\W9?U\D@W%V<XPR@ZIF!(&-O.YE[X?_H=@A.KB3K)G-
M/S-,`04G:V5(JB4!,K7#H2<P->O+F?-NB&*T2H3-*LSW\ZQJ/)6W@D57B)/$
M.`RVSWZJU'[V_)G48JW;YFI:,=TEF4I21J!(=_;&W4%E]G39S20#9FN>QP/:
MC8"*S,J\1RQ4I=9-37<G_:9MU6629E"R;6<E@&_`^W[]V]E=7F%$^9K>KLS.
MD5OO].NP-K*KN'X+K5F9'=\\![M9:CPK9^V,P<2^RW]&K3Q/"_G:80/2&)V.
M$BK`MXV0?H._,@#)/9>T&YEE4[[RF#'_FK+SI-)!K>3-F7TNM!\96FW!FT]M
M#0"\#_W]<),V64&O1TK7M`;'IL#VSV$<H+KC.QL+).Y3?@AP`#"Z9QU8_F2Q
M4%^4Y$UGAK%'SG,-B3"D60@O295_+3*M=CU;22I),A>>W:?P`/4Z*T!9MTT^
M7Y_J&=[<28])T-WW-$`WY>9,&&4)]]^?O=8H9M1)U_,`:O./SI+.!,>54'G%
MB$`&DPHD0YQY\[X',I&1$^<PEH7HQH70V;@'(+Q?\\?'ASP._>NHGC+:/DG[
M++9UDTJE6W)#[C$JE.S?K$[M@(CGBEE'>CU)9N3`5&N[,=L/U:AV9FBT'N56
MW5;;60LS$2GD/&JPR0EW;6_`^W[]%M#]9;#K&9J+'YM6*046[G>YW3-7IIT9
MK5?%;+J^RH&:K#,J2_F,O9,IXV.C>1@P$ERR9E3LA$V]>W3B2CD]N#7Y*-^R
M.EZTW^NG8L:7`;?$ST]9W@3[6S8((04_9UK]C&4*O+JVK"L#R)KJVF=I-[G[
MV!ZF3I$*H_7:95AA66HVS3VK4:<MP;9@MC*8C/$HO=S?>WD\!`>8Q]GIQI,#
M/S'\\('Y:,S*XIU$)[D[G2$!NSC=[<+G(-D.G*,=O>R9]JAV*X&DO#Y?\OGZ
ME&NOQJ@(4%0]>&C`-(&OU;NETT4&+%/9ULN8$55&C;]2?J;;TY+UZ<^8>@2?
M5"H2I]NQMA1VLF<V,((ML2)#4)C)_&6!\P#/[,$R;Q,M^[]?Z]YD"@/(G;R>
M'B/ZZZ3-NB5SSDL<&JOL"1NCZ\_%,<'M>X_'XU;6K=;:&VEU:5=Z`OFC,#&-
M2;&!VF/>*@WOU[\/$/^A]X&)R\]9U7N-;]?@.F.462W+I_%>ZS+7/$+IZ2-*
MR/PB9QMQ"[LS,&Z&,:%EX211$N"4C;K#S.\WOD?E$R"L>4)-*6J))L[I\]8D
M*)Y1<`=';TS"F<K`UTRD;?4&E!$47`.(VE?]6,`]CTDF.].`I5$A&(SE#ES+
MK7LQ[XN=R>/K-<H'#`IU,DY-D80S!AY6CY<CZ&B*%$B*J@-IJ%ZEE-%\19D9
MSTT?I5?DYAU=:YNTR*U[/:/H:_1I65R`H7_*3'<'8G.=7I5@GKGI.>G8=5WE
M^7Q*`2YT;&(&9EF6WAC5#29@F6";WF:(RJ@?+,X5/\S<09/G'6$5,RTT'_RY
M<JDTP,FFD*<_89G).#T'0J2YUT0^#;`:Y8KM_*H1T[JN\OK\[-D(;QH!2)A0
M6A;L;(N(RADP=M%:D6BV/VME%C_&CV61LBR7&J--)K%6JD#)2FU"Z4?ODH?3
MU9P2.'H/!MZ`]_WZ#7;W5Q;R5T$QLQ;_K^&7&W!Z++9IA5[2?!5J;)7O.&1L
M@-5KNT[M9O/1V=?_T/&->#F:Z?;[@3=FU1JQ'$#E2Z&`$BU7Z3BC2F'8K=Q2
MC#M=XQX%CM1V.:2WT)F4RBJMCRH$\FE]Y0S,Y]81O@:SC>M^X`QGNE*@`!-Z
M]S@.H-#\?#J3*.P`.!I8(%3IL#\;JL-\'_-2<#M8TSBJE"*/YU/JMF<H6*M4
MJ:*=L<R)`E5C*X@(73L/(F-*/4!#G+MEE#L\/SX,&.:9CIQ[S$VY0K;-2&$%
M@PZ(8]UAD"?=O=U9HW0VLG1HP!CD>)M6UP%(6FDI<V"K]]=!F)D^E-S,I=\B
MTOR#[J+7<LQ!I<+HF\%KZ(T+"CI8G"=2H,'6&".M[(PPEN,^/8`-!@6P6L=W
M6)%DFKOR&UWC3!,00`/P0XYL!OQX`G8_/U69BBO.O9):E,01[PH<ZG<8==:,
M->)),*<#ME**E,-8XVR8.^^O:^\5F-<ZW0`][Z&EJ(=$X.P>5=G0&_"^7[\%
M>K\,9/DK[&\"0Q&EH4Y#^S-:V'R"KKFC^6\R"W5SYJIK@))!;U-KA(J<L$QM
MP>M:*7?>^/:1F(8O"0C5:;$;S\-<&/)`Y#BP[6=91JK7&'<&81P('6MAC&4]
MRD=.YQEY-")=;:^:$H/$JFH&&DZSS%4]_QW?CO?<#VW+K`R`N<FZKCWMIONZ
M#;,4TJL:<(KY'1^DY(UTZD3`:'`JRR(%(MNZ2EVUCUE2?($QT?9QQF3=PUJ`
M4E($;#"K8XJV;1,<'=T);3O?7(ZY5$J1==LZB*I&NDNBHQ40U:(102R`6_M=
MMCG1K19(B#G#7@1!GJ)%MN]B:N;"%`X-D*:Q]^[^50Z-6V^6HLL@:/60>>+/
MQ<SP79S)BTQ87!O=&"`'FQV"UJ85^[6A!@(7"-F_<UU;9[#1F@1E!.J`9TUW
M'5BH.O&V9NNVB3RNX=8.=G\Z,F66KE=[&$2L%B_4GF-9T@$(F9]C@?FU&M/@
M&%\YX1EP<::0E$TUA_I2(]ZQ\9QL^UYKN%W_&_"^7W\,Z/YN.<'YQA?W5&_>
MT#<R\*;4D.9C<`ZP,]^><#C80Y(BI[5;=+ML:/S!X#BR@WD0132,"%5JO)"J
MR8FVX:*A^*MN+]QQ7[-=T?M;UU"/2*,&,&?46[E$UB7MZV=KW3\'!;D^&R2U
M8X-)HRIYL-&1=;P_CWL9P%X4FQU4!7J-897EL>QU:DU+$^K[ZD`O@&K2L,]6
ME!/7NFU*=_5<*JZ;79B2&4:P=U&+/5*TF1,()]/$ZY,E(2;'^*ZOERQE464L
M<D^;^WB/95D$KU6MA<9064M=C]%,.IQQ)]!LG5'BP(QM]C;#CF\R3"6NNC8G
ME*/T\HG,',:[$>H+,WD@1945@6Q'T%F%@508X)`*[&"BQJ%3[O9Y8M(LJ.NG
M283YO$OD13]+IAZ-7@TD9_]\,#.R'.Y3O-,C/4F?L,P8NL8`QAYULI>NZRJO
MURL/.!3U/G4:5`R05GSP(AZQ-Z2']_US2T&P]YV-K]<5]V8>L[!(UV^?E\&P
ME]I$V<_X;#7H]W^_F];>KS\+AN7/5!L@179RV;?&F^\<OS)OZHJ]"6VA%\DI
MK>/+M:;?@TECTG044\M`)8TU\3YT9VM5[W.4`=0A:\-,A/T+X<<EY#U.N5IW
MF9GJHG62NRO:B82,THM7OU-5@X@?LU'#&%FEN.-K0X_8$^6U;RW8'4!^OX]:
MZ^YQG^C'D91MW40$79ZGL[@]C;?/A&59=G6"*>,UGMOZ6CMXGBI;^(9&VBPD
MZZ'MF:@@9/^!B<ZHK03792[./$.BM)JN=80DV%B_!>)6X)_=.%RI`A.-YSF-
MW:R5LTT&PZUO!L]DYME[B%4R44RAUCK5B$#+SOG[\0H5AET35^<I>:UC:'D#
M@MZOR5C3_P[--V=I<]W0&&3*&+"987MU<.('U7X]5]35`:@I'9-H&)0%B5FX
M8N;AS%_]8J^<&O@<KZU6^?S\M"E^#S'=H/EL$+,4#9Q%LL@T2/%!8CZ#8)J.
M?5,QR5A6,HOAIM*8\:<3Y_/T'GB:A7RK-+Q??YC=O</&\)HXG)SZ<JG9>[\6
MU4K\\R8C[(E"*(DH`]1.V%TM=15!M=4R#:K"/EVD.EN]45.[UJUJZ:"OF3"8
M3SMQ2&L,S0")[&Q0K'VV<"4[+[QSFI4,<J"7W%G"=7726$Q"C;S\@VY\V!0Y
M:C42;KI#6G=P:[>G=CC56H]R!@GZG%T$OY2]H2SHW,*PTAIXK:\UB-'#%;?8
M(@4K?U%9C\.&ITJMNBN\`U_:SGJCLD(+SDP`H!GKR7Y2F:1N'*A@UH0I3:[-
M`DDK%:U*1J;17C2Y&%)1NCS"K7E&NW'R0G[&']X:<'.^-)&,HY=DZV78M'_$
M`^)$I0(9(-+E(8+>T`B.D"G&)<SG8YKNYI0)A&IB%7JH2S7O_5-#KUONTGDZ
MS(7]'>@QU"PJH[UR=MC@QCET=L*LGY\GI(]GR7/R'X&O<:4;ZNUB9M*3/%F!
M@]U9;`G\<!MDK4:''C."2BFJI(8ZWM")SC5.$COCL(KM?;T![_OU1\#N)1<X
M`;M*H2E5%/@JF\Q;'>Q>S`1?AL\-"$#R-%WU[*YGS'"..YFPDRGH%,MF31[<
MT'><?>C9*7MGQSX:S<)]I5WFGE73SU-K9ZH-$8DV*:U$3ZU4#(FO;V/BJSP8
MD^IT3`<3[0Z!WLB,2\:;LM>F;NLZ4ISM/K`+-:$T?5&C,7!\3F3CR;WF[?,U
MV""JH(U&:S.I4X8N%VG/R#I=6>R&7.[+_<VT(G4^?5KQ@-;&-1:J*N,?:EZ9
MK,:C=$?7IGN033,I:=SKL@P/O=F@L_8UEL^)K3)U@*R,*YBPNDSA=K(A3J9=
M47)NG/(%L(+_.I/!T8RZ_SW^O0]`4<UCXSZ8LNZ30A1$TB*`$R32%HAVZ[IY
MSX.O*6!R.0NMK6VE$;7:`JTLFP[6)QM<UI2\E"7L81WLKNMA,,$8S$N2K.(T
MUQ=,;;)]%JJ$9$8Z1>MYF+(YOS'I'H7M./LN%:$=B1`P!B=!HNIMF.4K.=E\
MWH#W_?HML'N/59V!'GWH>L'O\Z3[G#BYOAI,.(DKBCD0I,(YZ/?L+N*&K6N!
M#1B#XNN027!:6V/>>';A^EIG>X@\[@49'MZ4X[U**1W$P$<S@+EF3GPIC59D
MTL074MJ`(Z)'7I2P@,\*V1<[1D>C7-N\M>"[0([Z4G5?RA(W%Y0?B*F4(@0L
M"!+I,F-&X@V#8?'OHQGE5V>T[T'-!EAJK4,G53'S]F`3QW*Y0]QWD/-Z#81K
M56QHZC['>6";[06I(8>S\]5?1J8=IANEO#"_L^FRM<W9:"/46GI%N-D53(/1
M"9J%,F9(06TZ"@JX*B#J:UN-*8/9^S`!%["`/[T_!H6+%M!Y.W)Z=W>M"9T9
M>B2R8>*>-YWJ!].KU2@+P6:=E_OM**UX?CRG9\VZK@$`FCV$-,S^S+`'.BAW
M*-_8:YO2N1GIDM5OV+KT7/_VV,MX9A*AI:7O-85Z/H9ZTI[F"RRE_0:\[]=O
M@=W9\O`[PW7-:%Y5><7HRI<8WK2:\`1&VR4=H^>XL:2=\^3%48V0DLZQ>&0F
M[U8EM(-$OVGYJD7M9*PUTU5*D>6Q')W?0[6AE/:G]#H[7Y:AZQ5'`Q$<V(I>
MZ1Z(#"8ENL>%_=MR.+'1`3#2;L-TPJ?,OS*"MNYY9Z:31A`Y;W*I1\F%D;90
MDV>ZBB@!>*=KWK&Z6DQ?`_"S`3#[@G8Z<X'8E,WRL9AS=X7*P0?U`KJQ@*[U
MC/M"&`\.5KS-B=SG1ILP3)1/?&EUJ*6G5)-W8CB^XWL/AK,4[UH&X=D."@<R
M]2>&WH,,.OM[5N"?DN;_@Y:S6??1N,1+0=KG0W=J6"6;:H);^QQ-?@\PTHEG
MIX*>7PB$,`V9H._SX^/C",9FQB2^EAVQI.MD786GHP:"6?RGFW*1NWIF>Q69
M`6#[7&@R!E=$R9"+.SW;,=>']\#=AU1^MKQ5&MZO/P.*_\#O>RW9/_+&D]@O
M9\-@&$88P!X7,)+-JJW/K&+`1-[&)I@G`"4#MK_"J>\=K6`$AK_R?+7V+RXO
MF*[S6DF].6<"GK(*$N53W>'0[4>-H"@N!=#%SS^(*5?1,G56[.&0ZX(82U6C
M$XIH>ZF!9&]"HVX8<8`G<YZBR+95*4M[KIB$1X,A"C)OV,LWTG'4/^ML4ST3
M=;ZN+8MKM3V/E5^L=:Q>1]FZ:G^_7I_'^&&4>'#2@4YE#M$#1XA?]$QD8(SV
MIV3`P,]7&#`!6N#4`QI5!0LWWTU`.>D&:+)Q>[;&HB%<;16'ZX-Q/?,`SY5L
ML(>2</XW,($P"!-$MJ]1HAJ",;/6]MZP^PN\U*^J4T?FB'!<6VVR5+1G32]K
M"0/%>2.K%19,@[4F@U4>13X^/KI=-E*X*!,YPMDC0Y>I#&R\G"8!PO[,=)]`
MZD"HQ]!_YFR>S<Z7-EZ]_&QBEPPSGF*+J1G4)<.6GSW)-^!]O_[C8#=E9_GO
MN4Z<:@!E)L;GPL&['%89`N,..!D0D0G;]_1]5M/*%"0>#@?1S<IM7.;(;^Y$
M&K-<`-XSQ:39\;!MFVS;Y@`!Y*A8C;]!25*;`UA"=RB;MQSL%@P`&_K'D)-[
M1-R8*32I6B##\(G$$<3J>\+5C-8J4A#;QQ3@M6!7`I/DI^)H,*H3"[-Q."&L
MJ_.Y9@3]@:_YO#@@H_6&C?236.*=DI/P9__]>KU4[6-5*6V('#)6^V%)]_Y*
M88(#R.C.KC.0/66@7%F(KM6O+L@PS)HD6J<N\.BP78,^,TML,V;$<!!]PZ3*
M@:#L[YO(5?GJ<G'/U&9)VN\4!9B]@0;2P%`44]KS/\KQB\?FU8`SC`G.WD&G
M9;6`D<6#[MHW0-HR_4V_&2EXHIL/B2F#>BW+(M\^O@V9/3FQQ"E%L&U2%1`]
M(Q.H),\D!%%WN`^8<@!=/Y[MD6,?T:K=6?`J76+QS"!'1(RZS<QP,RN1PAFR
M3XDAJ\?]+FEXO\[/+UX5(EP??M=E".H4F*A6\TO7G"$;*(OB\R8UK3%Y&FU+
M;&!!*4JNS$,*&M!DDIK4D"OW,?>D$K]@L^@1G*Y?_;7GJUA-LF]@O7Z+M/5_
MYL^,-E;=OFZCT^RD!L"VJU?I/MZL2<[FB3B=42T;UV71O`ZH5C10.=E1<RLB
MPLBB*LFU\#Q5/;$%IJ[&;\+^`2=KS=0[BRES4(C<?F:_3@;`,X(H!^K\&*LR
M@2`M5LJ7%KB6<`K28H:-=J5(;CQIA:+3O22#+<Q:YH,+%1,KU[O[*E2ML563
M@=.\W1OV+L@$71&%W`R-KA\K2ZQ3$"W"J?;--J88DX!*^2!C1.DM?--GX;5W
MQ;H8DL'RVBC?T*D^A'F@ZJ][B59FP:O<)B54(PNP,[N]7&+F&W$\O.?S&94W
MDJ:O,T6T,[";.A^*N!KS6.J2?A"C_CT@1BL#5]E#RNXD5_.U8<@"M_9X$PG0
M.1GVY_F&=._7?3#P1;"K%ISN7_*+"NYG(%^4:SCABB/`Q>D]99M$6L[@-I!R
M-":54I)%>4>DAGF8JW_C1M[+UWYU)L!MH!"<^GKP:I1<RJBRVB[[=(-G9WT@
MJL'M=)QBN0)G<F\'X,XMD^:3MM48M\,LU.CJ("7I>&[/'DSJBI66L#\LFCN8
M\'H2ZBYHO3YP(FUB#V,]=E%OV.I7^KFO:BN1!%^Z^[PMYJQVO[&(B$PFO:;>
MC4AL*8NI#TZL84R0&T&GA."*QS72:\ZZYD</:+TN=%R+#`$I?(`]6=ZV:(JJ
M[.(XQ%&.&E&D&-^_$[L*0[]9I<[@%#3Z()3]3Z@YT4P@7/P>;8E]%:P&QL:>
MUV<&7"M@W).C1NUP6+--?5870]P\E`2,^QD5?P\NF`A!)^>[W%**?/OX9G2K
MY69FP9A.3-0=[HCO&)41;Y:G,P?(Y3-U9!CM[&VXV!J#,Y,,LREAJ&7`!,S7
M&$1?I]Z_WX#W_?HE=O=.O:F6/O**+C)3Q>+-&J1)$)KI?7+23WJY#>#\L_IG
M'AWV@+=>S1$E#H"DMQL/#.+/1M6'"#[GSZXK$VAWIR2E'.NZKB?`>+[>=6M`
M+M,$)I#'\]%KV^;#3G>@NG'4*A/'A33#"U^6VWBX```@`$E$053'-YMS,F%(
M+E7;G(7PX_'801>B;!/-`7[<_^.Q,QRUAKDY<XBRG=&9RY$]8&`$GYSVL3H,
M`@,4+$=C,#;$-VQ=W=DB,Z8H2="X::6*JV@4(LMCD:64;M\-2,+,CPF0-ZXE
M@0PM`,BR3M/=Q'16185DTR!D:F>M%)K>T8`<HK3G_W@^11<VCKT4XX_H?]O6
MW=H=$:TN<R7/@S!2!,4UFD;S#%,;H"<<8N>MJ>,&E`VT:]YC#!X@WJ6/(YM`
MF1HBT-&75'/">N_1Z%O#9*747DJM\SN4::*1QP#4I13CH!A!YL6&I,;-U^/K
MG[4MVSPM5QO+@R:^R>8A#>-;S/[OCZH1H"7/3;O0N%Z'KM5[@THR;+WZSAOP
MOE\WP"YO<KY)RN,&%TNCX&C5''G[?9+]X)?@NMT$>?.S=<.,L:E-F-Q6K[DL
MR^E@X9#.XDS+-I-#RG12E;6EG&3Z^941\M:A&L@X867#:!WW#8&LV^K`@4@I
MBSR>3UM)[:276A#P?#R[TH0&E;CQJ&U0QM[XY*6.#""&_7<[I+H,FTDK,S(O
MQRU]?/L0E"+KMHZN;)'TP`I24$ZRH"R+8W,SV:!SZ9^,M?:L"R8J^TRZHW3G
M=0@4G:M7EI*]HPK3/N/CXT,>RQ(G=>K.QMC-3T[5"3L;?F-#@^M8]TU2!KPD
MT**M&:N/JNQ[VUZ@,R4-\#Z>ZIE+D-R?=?.;ZTH`;0P"8^#N+63IF5'-..J?
MS9HAY0S8(70QDHDB!<4HNW1&.%4-H%16YP`8YS^9E17!*$E0:RGRD!K#"-K)
M<Z9FV[9A4F,6)4V3:M]/_#Q-GLTL2/'S[ZY+*:_.@YZYTJ4<2!MN&^"EV/F1
MR>_QA`1@8FW.]/?VK[V;UMZO_PR@_D,-:I[$2_I'9['KK0,,:>M8_NJ@\F*;
MH.Q6DDO9+67KD>[6]8+&:.!DPR1:HU1C'2"V:WEL!,//O03-SE]_AKHI`(/%
MA/0.<LI>\@$5V;]>KP$^%(M0:]W![,>'<DX;!V<#NX_'0VJMAA5LSF5`B1/"
M==A[8K([$RDV>5D6*:7(MFV[=JT^1`_@W=C%@L;:[M>DNYU\S3&`_?[)2_<Q
M^$-,W6PKH<F!%U-JF\[1:X#'6/MMTHZAF%4Y4OE[O0M:>U=XK,G58Y$*]JNO
M?7Q\R**L6742NKHL`70@`+$9CV21![;,_1`2/=(=F$9FUJ:Z,7DNZ`U:<=<P
MUE8B0GD^/R37(;W_JFJ^<M8(1:OD`2<OU]7AU+IK(!!E,+M,0-B,07;>T#F@
M(VUJ7W1#'&(0G`9WZGX'/6P_EE[?E:;G8'R'G6`015::?A8WWU[K*I^?/Q/=
M:289&IO#H6/5^S.<2@6=%X[Q;,ZI[$!OGF[C2+3M?O2'*,,?[VK9>CVN"+:V
M/R#IZ^@_C1BXY7Z;;UFR]^N4V?U"M$>1$ZOR`).\6,'7.=CK!0NSV_S^6%R]
MBSVP3USICO?=MLV`%ET+..1%>5T^@J1&(>QSS,^4WY@GI#V3FG0-T$#O_LW'
M\NP'5*U[K2]-HYY.\>UVO,NR]!0?HX>QK.NJ6.MA3?E8'A;LJK^S&DE+*-@Z
M7@H%!?(L3^/@U6V#MTWX>NW7^MSOL2S+;D4L\SKC#,B?92J,A)PJ&EP:NYR`
M2`DL#A/-RHPU3<8N7031M8_)F)_+8MGIRLH@#0+UQI"\MGSO#"_R?#[EY\^?
M84M2JG%&HDW/+>N4QOD>P-;4&*7#;&VCU_N&8V$5H'8/'EW2C,ZZU4OF%7D\
M%@%^;\_7=>^ZJ0S.9I?)SP3+YS1XH.DGH,]&90!;K":MSP!``6B01B6G`Q\O
M&>FFMP^"X*3D*BD%Y6"!;2G,Z%WC9,^ED?`R0BKJ1[=MZV"7PCP#X]9T]`<]
MX*"R1I89Z/7/]S*-%S,8DKC6:1G'P=XFVP=%?GY^[DW.NI&0.>ED%(>F2A2V
M\,3'Y9KH>`/>]^N76=5XLMQA=!*]W41J]4O7X,,YV,^;*R!^$4#+N;M.Q@#-
MKKEW]6]4M9"Z;NY\0#QX0YIZ=2E'!;0SN]Y??1GI)NP;?5%LAB[WJ#HE9PX_
M4=WA5=9:#[86JOED!`2[48/:R8Y:VN#8!1OY^[)!8%<-\^PB95>>^*R?0UZ*
MBBE78OGKP0`W:UN9'%SZD-,*%E<'CCXH^R$`["4QR0%A[0ETGH^'R0#C>>B8
M+#CV)>NDAI;*TP>/_<CI<M-@%*KLIIPT,K9J7,]U=5DJ,II=T,G@F08CY#:N
MR4'=JUK":6J=ZHR.[D!?5L'U6)<M2.R27(TY]6YSNBF(4&6.%$K]Y>K$7LYS
M*(9D63,7YT@BJ3VV7]=_X%EB)HRC@8R<M!DW@.O\GI'0Z'"@.@LH]1ROJAYW
MI@QA0SR$>6'V7`6,?869!<24S\]7<LX@JL`(7>817SC-XH:-29!QY[P=0)XA
MV[@L2ZK3V_::6FO?:Z&E`%U(ZTR=1ZUOF!P(\_2LI.T->-^O+[&[OU/G`W=<
MG?D*7+&:=RQU?W,PU+4HW4XY5_&=:NJ<\=WTQ@)704,&IC&)1.ZS]K\"=,/U
M*G:D[3Q:O2'O6[<,K'%\NIAK[5![/!X#*"7Y+$X/*)%:MU"G)[XV#Q*^IV^^
MB@@-<WW%CFO7*TQ95"O_M&O\XI`R$M>QGEB@F*/`,_*9TV^E3<%Z@I*,I1)F
M>$ZD"#,&3PYVCJ04P<&F+>>'^,2&N"KMW2O2JJ=)2<^3B6\>LZYZE%SJWT;<
M0Y-YU/,269'5\?RJVX.)J.R`(===2I%:*=M:I3R7N4WSS:S4K)PD/#L'S+6U
M]NQY5U>B,[/&]7"RE#(:@H^Y`K?Q!&<RKU+3&QIA,VR`R0YU>7,3@&>L*J:'
ME$["E#+JK^U:&_O#ME6I=8M9)^%TW6@C#Y^909;&.BEMN&-)#[49&':<B22?
MR&B\0\Q290>EE:2?6T+%@P(F>R!*@2.CN=H7WDUK[]>O,[L),W3K/2ZZHZZ<
MFTPMU)D"6-+Q?(>*IHZ"H=)OIVY=N;,\OS"HU[J_CFF+'HM*TW7>\E<.=8.O
M-`5F]\O$O"#49CN&"AE[*;GE)"?VE/YK2RE24-)M\LZFWDH0]*4A[8!0S8(<
M34\T[+4DS5*2I&\G\0D]@QBU<Y>R'))NDGK91WX,Z;.+!VL[-'U-JE88<*QF
MRQ3TCGJG-H+X+#,;X?:NW74.\S\>'>WZUY!U74?#4G]>-/-)LZ>IM)7J2#<'
M-D=36:RFU$8SL43!-ATY";!*H3.<:L\&B(#+N[6MZ^JLM[]H%ZYJXZ^"XUDJ
M//N=V?N%IK;)ELB>25%?ZQD@!LW:T[/$[W70BC&3O:=RE&XX18CY'M/3%;(L
MC].(BR;S=5`6$\NRK&SI3Y[E?HW$SXUL,A*V8]I3H`:Y%*CR'SDM:;1;+\46
M<SAWF```F+JVO@'O^_5O90&G"Y4GC)U<$C3BSIL+2:3$VNDFA8F[Y0_PJ@SG
M@,ZPCP$\^MY\&M%USIA!S^F=I,SQM0=W]XFXP]GVQ=,E!;.2"DYJSC@9'=V1
M;<33F1."N1D#,VG.N`&3$[#JY/DYB1!$:05[P4LMJI\$A#JMM[,HN/&@K/A0
M/]`@J=3;T)Y%6*^DES5C9X)Y4B?(DX:\.#R4;:M6U]/\$.;+NCWZDJS9U%4N
M2H5E\[F!$!WD-,%>K<@2E"U:0."8VC0\07XM9^.J&5I.K%EY`^AL6W5`!UF<
MUP-^_;.8E!7<*1')K*RO@)XV,Z$DR;2980*3L6-4`6+"$.M-(Y50=+7UC0$.
MY49)+U[FC/@K08LX=VSSS%2M\UG#X&E`*A)48WQIB0A&`Z4ZC[.@NC5TYE/$
M6AM79H^4JI88$S8FA[UOP/M^W4J#\62QW6$*0\VN/G1O<Z\G%Y7E+S!GN>Y`
M.)RAI%]%B8D.,>8(:R23H&HY:9&5EIV]R[(?;IQG..GZ#1%_.:H$))-%SE.@
MJ<1.4M<(@2Q+D5(6R\#0`D^>LN@Y0*+,-$@MZ$M.,4ECLJ.9(QMR&@8_8<R/
MCZRLLCP>Z;C/0\=A+#"\Z\5(C6G5@A3P,/';0FQ@F3)_C'66P5:T']JU2\2%
MJ09.8RV4O<SC^7SNI0TRL:\525WO]&%,B?:]NC8SLY-KX-88*M`"]1G3?28K
MI?]F4H]#Y6*6+=G@9A?V@3H-CND6S52"S`>EN&=4E$G1\<(N-\_\,)?#/`D>
M>$)RY)[BB,$WK6E"(R:\GBY3?D+7?GLE%>=&F6J()T'%I$XXNJ--"!,O7Y8&
M-XDM/?92AF4IMC$/,6@?_0N9QKAFNF\<O?2F%9P^0[Z-)]ZONPSO'9.)7Z1\
M4V;R)DZ<JH[!Z5A^Y7+\1FYODE-3C(BM,6=:<+J7#9P"SY@BV=2N\4]@L%IC
MU:R3_L0>-@.,MMM9B8F369/Z37+=@P3?"77(G97%-"DR\*UGO!<[6(H@+0&D
MRL@@J[F.H&673WM^?,BW;]\/364:Q0<?Z+%;I-J#M,VI92G67.`B9-/-3J0U
M7Z">#LH`I3(!1CZ^!$Y!B;T<!S8J16NGPG040K9M3>?Y68!+2M=$UN4HVEW.
MW">=$82HIK10`YZ,P'1^#&!H,C.,[FP>U$XS'4&I`*81WQ?3GQ6T>/!;*PV3
M/35?UTYEB-&UF0\)Z#K+WGE;WKOGDF4>:6J%F03BW7Z8MO,_!"%9[:LOYS"'
M!'HV<#<"R=138(**P>PSE!AI=1Y.]G+(A9@Z<_J&,^`[099S0QZJ7RV]IR"(
MX:KGL:V[UK!5>E%9J-MGF'O&VA:=LTWB;2W\?GV1\<P6UI7JT-UL.'_E/7CV
MOO@2,<O)"M,1_9EC[;U!L_L/3NT_;PSZ5^[/R4GQ8@""@V@T]E%X%\8-QY9=
MB/,ZY2G(C0TQ4$@D`3K"J#-T&A%%^J"@A(/,:K6*>,I%XPS=2&/++\:_UO4E
MZ^HZLC6VOBAJ:X?@NJX'@VD-3B[;/5I3ES@=@5::H)R^#'ZZ86'MP9ZMDTU8
M1M@:/%V>4LHN[>;+?72P=X:!]+-D1M`+K8VY4DCQ:?)66SLB`YA4[6"_+/#"
M1>.<D:K2S5.AK3]Q':-S!I.8B>)DM06U`@R`6[VDEYE-"`\2R@="=&VM-]R`
M8\&S64[?`IEEI'@:-&3@3&#+JJPUMY=?2X`D,H60\_U_618I*)'M#J#:EK)T
M]2+2V',CK)WQ@)&!2_@H3MN2^Y)`Y)N[W\_"V-M1>1[J.-.$*D1>KU5^?OX<
MML)!5U=<EA(S\GD*?)$07$891=XJ#6]F]S>4&>YX=$\M?6\PP]/?\V8"F.'*
M7Q>HY(TQ,GL+LD,&VM3T=GCAN[.#JH461[\UE(R=[0;9R$FSW[S6J@"=(8K?
MA=$_A6(ZPDZF!>PQ-GV?.L1,XP=7$R7?(D$H,$%;0B"SLHLX3HPD9I\SZ[HF
MH-9.(.L2E;QW!Z?[P5%KE8^/CPZT@&)L4ORA30X9H**[YAF/\08*[[HOY>`.
MTU[2<=39;,7C\1@')Z)IRLPA;EA6TVH6PZY/LZZ\B<:DZ4F7?("2-O(9X*38
M6,D84@>R0JVE2?\</T?(1.GU8/P?UH[WY+EE3'RMM)`@R>A,Y;K<<R)5YSS]
M,XR*&'T=PBH4>(,+/5Y&J<&98(3?\U^3W)T2"M,W=89AKC`'O;T/H3<X-_44
MO8[G*Z@>#9I0\U"SOCKS8((1G"2P(%9YPNPA,&-MUD?['2U9AL&*IN]U`/S'
MX^%TE6/ZI6Z;.LM@-'CM5$*&X)4F;US/R%1NDK-'^#:>>(/="ZAP5<)Y_0[7
M2';V/M-KN*HKX-=S%^8:7/&G/]2MD0/FM]PE0G7G:`08>2E6(N&FPV&]X?MA
M`&(3G':;2ND?1WZ>;!SC<XJ(;!;\"/?[-:0L',;+&R2R)ACF,-FQ)0R,OCO&
M`U#2-LN[OSMDK2K];`3+>3DG*3']25<;X-.!G`'QH&5A057=JFQ;/90:<(CP
M%S,_,BD]:VHR:RQB/`SU7';399>.LY.DN4T%MEC$=*)K0X"Z5<$3A[1<9*[@
M$QQ:%469,PS`%(,J+4,&!2!BPZA=-W`7X.45.WBE;\:D"60Z(QGQOCK`7;H=
ML9FL?<8N3_>X%=ICLG9&1H)6/LH986B6,-0Z06FS(LE@*!4"TH^EA&?5`QDD
M":T&;O6_E4YW%DQK,&8DM7RYB5+FF;&*//:*$$0`\GP\@DK![+Q=UU76;9/8
M#^!J;CT@U,UQT/7+2`PIK'1CYDTAFL%'4@[CFPM=`+4'WDF#MJL3?CR?\OGS
MIP6LL&<JX`\Z3)`%7/;!KD-G#&>R*6_`^P:[MS;'KY.T]RS4O"?1],?O=F/A
MU\2XF;*.+=K.<G'VZ-<1ZEQ$1AL6G]T44I8IH&/$NM;`%(:=V^I#7CZ,D]*5
M9KL;6+%9ILVS@LR?LW/0-3)Q.OW-@SDH*,-X(&07<N"KI;9:39\Y?'F=Q8"?
MGYABIE'50<U:3`AV)HV`RMAC!XC[N"^E#/<OE:Z%.GAZ*OP8<Y[..XK'!)JA
M8PC4G/E$FR_,@J8C$M54U7$]2W<;_(4>43?>Y0#_VAAC6)1*_CD--"=&!1VL
MML`!1WI8/Q-Q8P%U-*M2BK`XDSX&>F0_+D[=TR[R/]0`K@U,_/Z_KIN5W4*B
MF8IH>A`V&5KP%9A=S=`A4:V`=Y)#J`7.ZH7A$5JR\<\T>EWZ0!F4V.R`_Q%(
M5"AH`?/S^53F,_'SFZ7XZ_7J[G:I-*!F8=4Z`O)P.[@P!C;4#A`3JU,K/>CO
M&PFC#WD<]YL.OUO$RQ&<5WJSBGEP<=:-D81";M]$RDF]:WC_H:\[J@QGM;.\
MY!-PNT[TLM;WEQKC\%L_[>OLKMXVEYKA!:3%UPJ!9^A+I;&@:1'30'<25F#"
MEI^K.]FZK=F@.'9@MJ\-@7@QM8)4!=2D8_9D;[K9ZF:`G)$LLS#.SGT.S<U-
M">];^UU.IR-YDFTX#3#G!=/TXX\HY]?<L5BK:X)KS5FUNWSINL_V,S6Q%Q[*
M!;..=HMHK8XOPO_R_0(J;8M^F.((GO";'KE,#`[&F(U`<S3KC3&1B4,>)L&W
MJ9VF;I1U+%TVE_6[*U;T%+*J-P-V/=.G=Q:4M,\J/LGC&;]>+Z/2(%W#F"8+
MY%T*T^^IM0:W\KP[V/@NPGH649)WD[.BKUMM##-9A_07;HJ/+2.O>P6TCCF3
MK;H[0#9V]^.CJ[`8%TOU$#X_/^7S\W/H[_I=D?:LB<W(5(!63`#!21T6S3F#
M*%WC)/%L_YHE?#R0;^4;=UZ?KT]C;C)(##7_>8=:@!?LM&$BXCE'CH?W!KSO
MU]?PY66SFK9"Q&]?"W[AXO'%>VU-&[56X^Z5EA-P'A(P@PBS1HW?&1I@*O_`
MD"*#BZ!MY_ZIG.N)5G)/BT^>5M"\3%ARRV3IIJ_)SVL=7*W5>&B)>AG>(*WE
M=M7V.975:*H.MFMB?'%'Y#3,!!B$[(GZT#=R$0W6P^BBS5D>EIVUU@/0C@"A
M@UW34,84(`7Q>Z.U2_.,]#/DZ?_$%`[JAKGVH5O=_D04;X#D`#,<)AV92<+9
M3H;8#8"9CBFU$QU<XQZ_2BL8SLR7A.AR!A/B]4"]F8'DLEZOUWK4ET-L6IVI
MW;)IS*->KZI<*VDJBX'C^`Q]/WHSTNO!:--BX)G1:(8POI"HI.";*06YBH[/
MC'%"-.BOEU*,%%G0[ST"U,_/SZFASK@Y#E85W>^DEWKXSC_[3,26/#@3!H9*
MW!'H-:OV7`<:(8AJBBA76R!)^?'SIZSKZH*6(U/E,WUT?R9TB=;2I@;!I%/K
ML3TP[Y*&?R*@O9`@F];F\@H0_X+^U%W4RVN`WI?RS8]N5UM)*Q>C%J1)`</7
M[YZPO>"Y9?+E6%Y\P$Q&)FE<`C)(SMR4ZZ);2?](W;8IO`OSS#6/Y,#8/3\M
M9^0,&/3?[4`9\F*0G&^/K(F5/<MKBSF-"V@;F]+/S0<T%Z+_6F9#2YOIOD3=
M=6ZDCAB9OIP5C-6`'02ULSEMKCQ9MD``</HKL^;'JUTF"[-'XY2R'6TE"4'D
MD^%:"%6N<&'^8(Q7@QWM+!B,.'T`RGRS@P%#E.?'-Y%#YJ[5+MKZ>":I:!S@
M9I.?/W^([26@#89%-5"9FTT:'+W?BQK0?E_N=[V[FV]>.C,FR+-G,)_-LV1*
M%FVJDJF8U8,=9]W810ZF,['-;K_[\_/3!<TV$/02?:%GY*AM:*`7#0PG&UQ6
M)J&'S];W#RT^&YS;=64;&XLLCT=RIC$T<[Y>GWM@Y<4J>IT]4I$=IMRNNLV@
M4#'1?H8^5_!F>-^O+V#+VT#2=E/^CH<M>0UV(;&#]/:]3@1-.VLP\0"_9,>I
M(^OQ[VMAF\G[88*6+A\3`WMHFD(N',:R]VU_;]T:DXY)31JB%,.B-WK,GDG"
M'0;FO4OMX'"<&@P_,@*;SBR!'O1.)"F9U.KJND/*!=C%"?#!E#6\7ACJ78NU
M2T5/SS9)J&HRFO%>O7^=&(OJ6FE4$;0A!K.YK<=4O"`"H\138ZO#[SD#!LG3
MDKH\MJ?5+RQWT26VD"YQ"':<09>&#RL!P:##;V`PP98W&E!-7SHKXQM<CZ\\
MEH=\/#],.E[7>>J4.I2<F7!OEOK[[[\E-U!A`B5YU$5C$D1[L1<*^OV.=#-$
MR\)9H;H!]K.@L,V'EGFK>\D.H[S<:(RS&FJ8%`,#GC-L5?].DC(!<MJ5,%^[
M*O%>J]2Z'>NOQCI@,_\@F9"-32^I^2M.:8)VBC&5^*#=K<BX7T)LTZ"JO7XV
M50;)^R+::UU7>;U6$X#;3,"8&]8>]%AS+AME3O?;+DMV3WHSO&]V]PN_?*=V
MUX,2Y+(V<L-LXL:EX@20_1;PGW7^G@[.C'W@#8Y*`IMV'Q9?T8*\'D#>8]/;
MJS6K=0FQB8.4IVZ,[)>3@V*J.6</TT8!9Z"^44J!X8ZGVV#R#K"<,;%*Y6=\
M)S#B,WOG$PD,R=/`X91+FF/2.D(%;HH1[H<`E%IW18U2BM2ZI>H)9[HL(<TY
M6V@ZL]%8,3(Z`B=ITP9T8Y<[%4.+='6U@6F2:U;R*B\0!.,%%:6#"M&2==&0
M@DWBJ6H]9D2EMR`9QI-TP[CR=MW%S6,`\OW[]U`G;0**@TW5]?P0D<_U)7__
M^%LUA,$"*I&TQ7._3\98F_:7H<4ZJ,LLG!O:\:SHF.#PG.!E^B)XG8V#GW!P
M:W$0SG4?8T8Z<<C^V9Q'#\(H\GP^]H8L#2)MW==NI-)Z%(XULG^KFM(,7^BM
M@^P"41;6*E`S%M_J^@[&OJA]=0B$8$HVS#.&1]"#LJM13&SMVW776N7U>EG`
MK$@%\TS@^GD#`7*L"M^CR$1Q"!*:F_5<?@/>-]C]16#U.P#L)JY")AMT#1B_
M4CT,S#GAH+6)H8MI:SR9@"`G_IU6(>!@.RP0,`>!)+;,3I#1-V5=/@TT2]%R
M_KB<C("IFU6USIE\5^B,3ETK\ED!Y_ADG^=@VO(FNNLGWU+;!3B<?T;S!Y2*
M@&=B0)Y.-'N]%U(5'FF(U2"&Y&4K^BL+($LI0YXLTPPE9"G']3R>.]MDR%P&
M:E,+P9=)EB%.$X^:>)IQ,+7"Y,%0L_];,U8(`8#Z**/$OP/FY4'!)Z3T^N7(
M!+<YVE4#&-4(='F3:7XB#\`6V>&^7ZER'+C\_%2C]?A&$:3D`D7DV[=OLBAW
M0;]((!%%@'O3T(\?/\:OU:A;:TJ."$'!R)HDRBJ.<[,F/6+5+8"\9`@Z.#(X
M&N9WJ1HP$;)H8AATB-4)GD%BA/]V6LV]IS">5FV.-`U:L_.H_9XBLG5WL>,3
MPC)1IB\B08Y-Z*RNZ3(SM"4*K`>0!M5UT-3DVJTB[Q#L]>]JK![/0WI-EW7$
MHT)>GZ\@^];?C4[A@UDWS)$C@":!;(P%G`.*'CRJ=WP#WO?K"[3G-::Z:[+`
MF]__,B']"_3NK/@^=-NVFLE4DQ>N5`Z>Y_8JV`G0L_?@$LQ=DDHD+GAH-NE$
MYW@P+$6R/2_U1G`;<&OR,MJ:J@YOCN_V@ZNQ`]6#>Q,LV"I1)**<1MOT,%68
M%'=.V8RZ;3OSJ=V/#G"KK[T`0L_X0X*8/E2$QBS!H47F$ZH40%ZX%@(ER'+H
M?IYI?S:VLAU2C_K8N_,=RT(=0*D#B9-K"!WDN%@38;U1GZSR6!Y&.@W=JM40
MH&JNVP>LB;*"(BA%J(3]M9K"OHXXRD`4Z-*9@$Q'^I@,^U>#CJM:Q1A&VU.F
MWNF_3A5(C]];ED4^GA]YW3WFT?ZZKO+SQP\+/G3)@U=344UKF0E$R.+,-]8!
M/NL8;_^^0D[815?^Y-(27DHRL[G.SAH=3GN#AK!%0ZR4EJJQW==4FY=1R+P>
M"C"U-M19=WQG)/L8]H;,(=!*?MG]Q%CL8A@[M+*UFA@T9``3+A"GV'E;"N3Q
M>'1SBEEQWFM=9=W6E`3!T4@9IFMR^,VRP,S&I*U+(S$7!_(->-_L[GUV]P;8
M#1;T^'7V=0ZRLW3WOZ%9SA_2+I6^;?5@2F$B9].4(),=]<+=K+&_]`+PF".A
MF0J$5[99ED4P`4FXD"(3B-0M41M(6*RL8Q?8P=>R++L>)9W@/0;$()&"\@:&
M=(/;3-:*-Z:SU@=N8)R`'+4`.[A<EET*S#79`8FF<;,%-?)-^B#2M7H3FL*A
MY"QXF(%=)`V"K6'#!'$B!G#X>8O$S<H@JVE.U*:_HYYIK)_)ZK0SMMZSKU:*
M#ITI?SX>\O/0.K7?M2+UNI%M6D?M&XFH'',[$XC)?LM@9&`:N[PHE],_[5\N
MD&_?OSL+[_.YC2.`^/'CA]6OUB5`$FV8R6B88ILL[]6GZ<;8G2U.RIZN[J$@
M&&*T]Z*;#QK\95T90#DD^]"#Y$JK#>Q+0PM<@AS6B*/29D%\X%)9I6IVE<H8
MQ30BSL`NPEC99C^K7]PI?=F!+E2YAETI%WLE76,8=LOO=FY,^VQKE<_/EWH^
M68"$PY4O=_8+WC.(@7?>5*_MO>.TK.2[:>V?#7;Q)8#(&\PNDX4C_!))?/&A
M`S52\A[X/U+#*U%-H-8JV[;)MFZRKJM)ZP.6U?C2/:4R87/+WD9UW3L%-7T`
M`"``241!5)(M=!_#WQF@?AA7=XDSJ9VX>>]`;3D`:K%BYNU_+;AH;!LLL]E^
MIM64[1:K)=[K58"F`*T%@4T?<H"+I2P1%%TY'=-%?E!I5(C3K8TJI0;\BZW9
M+;V4X?YZ;V/?YFA!Z6.MLP2^+GCHI=[Q7_2'<GP>0ZYJZ/[6K0HKT[2Y3)A6
M4U7IXH;'\W$T6MD,B&$?$TO>J_TSTUC-9;QR0.$EJWS-:&@:.K[^[>-#GH]'
M7C\-R><D1-:Z"GO#EW:':P6?#,URHFR/ZY&YJ3V[I=Z\9Y[$Z!M+8I;7:H"G
MSU;-.^.XR%BNT.9B:;K.IK;7USRK]4<%D:F89=4<91I>84LOAG;P:+2J=1N-
M5MF>+N+TT;4<&U46`U:JP<\QW;RI%A-I517T0X".SFCWE_#C8AO]Z(,PB#P?
MS_G><OQ9MVV<#R+.K`8Y*/"$RQWG^!LLC?5CV\^+-\/[SX;"7V0YS[T/OF"&
M=OVS@0J^\F3S<__W=(`U^U7KKM4Z4BU98\]1CTL([_2-7=K[YN!B)KM&D9N[
MQ.ZPM"P'TQO,V;5;U.0^F!4<,&<,IYN:`H#%LE;0!<RJD4C?6Y<@HP)RAAF[
M5\\,9U4*XT,_F*1U6U.WIYE,G7&4HO:Z1*\%SQX71&%=8J+VC``H[RZCQV.1
MK3YVO=YM4\]2Q-01ZZ>JI'WNK?@(""T.@&'K!PBFF8I5ZFC"@Y4R\_N1;;[;
MV;QOW[\?B@02TN*S]+?_7DB_)P%%5@>;RQ@P`=W._E5ZOU$_JI\?3_GX]BUI
M-(R]C70+=ULW9Q*27#^.QL!*7U9NL92R9X:VJE7K-?8J4+3&K$_9%.6^=:54
M$G"-?H:T6;ZV^L#$VEPQK8/1QEYV88PIK,D[7/`%$>%AB1WKJ%69&DT/FV%U
MQUKCY#P8GUH"U:GJH%-*7ET)HO-AQJV88$,U8SZ7AY1B`W/?9DQ2UJ-1S30K
MN_(7U^MH]CWM,)<>9\@(H.0LI&;V1YW^F^']Q[*[5^F!K^)AW,;0O/MV4Z<&
M_"D,?WG;1B#KU);UAA=O=I.NKHIN\TH;D0+#=6,,='H<.S,Q&&I.K]_:U5IS
M""^59FK`-%L#*^4$Y7&O&=O^/9@CX'B?HAB@TO\N92\W*`7IH7A[YKKT7;-L
MA:Y#A`=T[59AF-(.TK7\6^A$D;S<!]:T`+$M/FU0NUB59CY]^_9-OG_[+BC[
M^`'J<]4S[UK':>WY'9:W2+<RE9B:]JSO:WT-)M!R5,(,#Z2II/'%95GD7__Z
M:W^6P`TVFBKEFCM,<69"($C,4N!2*W&Y,?W\T9KY>#ZZ*H,=KS@&3-(WM5;K
M$"<1?.@!UK)QHJ3G=#-89T6-0UTTAMG71YGNX6W>[7,0*8NN&S*_)-V'>3X"
M;EV54NS7M*I,K78>T.H;FY(6'Y1/,ZB(\9`O=YFDJG3ICUZGH_'2/5.G,7]U
M+NEZ[B')IYOS1#EC6NB]._?1SGGF&1E2HDLDU9PS3I/S`]J:X,3J09.U>S.\
M[]=7TN+DC7<Y(7[XE>LY<;[X,QYNUP`A2F;RA$5SF]M%T]'OU'DDK4X9!6>`
M7)<%@@:]-:3%8X,`,\S<RRJ@U122<HY1JDC+[BI&53?]:`FQ#K9Z`T8[)(MQ
M:-+E#!J$:K'XU&&K?;ZI5155+A`]Y$6BQ6I>5ZG9HTFB(GET].SS"4#[4AK&
MV:G*`3(J:>D6#TI-NM@W-L6<33_OJJ5I6.GJV!$P-*O(Y^=+OG\O*5O:I<DP
M#D8ZML=;9I2R@]YMW63=MKTD:=OV>]<ZTLQ6U[Q,!XY):@'@Z"OEJ#/7UT7G
MX*B8:_V\FZ'!]V]_J4`SS]Y"9"(UIQ0C:&MJ>9JMT@$*5;.J&(8W5)\H^;@1
M+%&5%<2=[-OW;\IJFGWM-B.2%G@.G>;:2\NJTP&_!'(>!#OYQ&"B(%:>,LL.
M5`V"DXE278,SPS[-(SNH*6!7@]^:L&!UG[-YK\TG=/:*024$H\;7HO3N2-CN
M<7DLW38YGRM[\^_KM;K`)RKS<#:1$^,?G:VCG%@NTZI#!I)<`?XWX/V'L[N_
MSY+F-KJ_])8\*YN8R1PE_;7X,ZCX+@Z=BVPA;[Y1@%$'M1I,[)JI]12TQ53Q
M@*@@'*#<2RZ:'FO[I?W]BX^%X[,-47:F-(O.=EC-Q<$9-39E$$1>Y6"`7=_5
M/IB>\55MY:HWVG!0F0-II%"7`]ANZ]J9Z99&U]=62NF.;G2!`]1X[JR:EAJ+
MP8)WBLM@%I#+9@2PZQ?,;,W[-'8=:@@-.)CFG>"`EP%;UVW(DPP'HM)&?W)%
MS^,J=:,L!1(V%FJGO;BQT!@9V,]]/)[R>#RD5I&M;L)*^?GCA[$T-@U0//'5
M%DG9:K%)@D,36*FK>+OJX,PV[NWCXV-G=H'SQTOK)I6UM.^/E^.YF_&BI!H)
MT,8B]NOL:@#'G.G!#`Z[V#ID_I"5>`WA059*69:^;W2YKT4%O0?$*TL9+*?J
MJ:C:6IO>;6$V7VUCX#XNRC71!1]-`<&OO[VIK<Q[!JH<96Z44.JCN'1='F+K
M:_=2B[1>A"[#H.84'#E,M?ZJ"Y)H%WI?0^WGEO*0K$]1_\?/SY?4C;G+YHB6
M`@F`Y.>ARF.R[FYM-]TUJVMV=7#W]P:\;W;W3[[#K%GJ"V_%&Y2S%91)*ASY
M)\?GIM5;DJYB$'^'82RVWD4>6<<&#+<&>I46"P.%S(2/C<>+H'0/=.UL)5FS
MC2D,U!E_Q0RZ0&773VV;#$0W/T`XRA$$>V,#E0H%V3?EWDPE5CYH$`7SNH!@
M%C)A:3O;4XK@T*VDZO)ES?%B`]R:22ZE=%W6W>*X=F"A1>)U\-/![I0VB1)K
M^LNVUO#7@N&]?G)O7B-SH$IZER-<LHIQ[N418BRWWP.7;:OR_+"]G`;(>F<[
M]WQ9[4D^F,C#J:P\A*"LCX?4SSHT3K5,&Q,1:L`ZAGNC!$8Y17K:7JRF+<S-
M[>?V8UGDV\>W$!!.PVM%TNN:\GH`)=83J]G</<3)[%`QL#80&>8>#'-%9&=J
M@X/<@>%*V;OUK8-?&Q^UPS<-6ZU:P[UM[;$L(LL>*&W;)C]__DR#Z8;@(B,M
M1C^0'%]'J@^(PXY>CC*J(JS1YK>-U;;M2@ZL8N74V-1!*,D4L4&),72YU+6P
M.K?)B::]6`A)FRV[@UTI(E*DUNR$V7>#K5)>GUL/8`26@!"?14J*3:)`'$R0
MA2G1!%?6S%.BZPUX_VO9W7\W"AXR2W\"06>%[/,IGK8)]2O:-Z/R6]<B2K2>
M">-EF"I.2@1=P2UQ,*I'.AG5GO>IS_OTG(.1>&J;L-DHFU'&P<8NQ\&TZT/6
MWH$M4F)C#7""ZF$:,$S])T;JSCNI+<NRLS2P=K363\`Z;\4&H7*H,R`\L*XF
MH(17.T!C,G9^:(_/VM9M``G]*&D9IZ$6<0!>H51H75<QQ9;6:R$',O2UGVKX
MM;A]R<#NS"T/\7NE%'D\G[*N:T_Q:U1->IU26TXTV+$$"$UTA)%XIIK@08Z`
MJ`QW)<#O:3#[#C*6V[!!R"M*,.K&!XJ=.MV,H.QBJV-B0VL"84J7PAKUS>.S
MEU+D^U__<K6O-T@%-[\KJVQ;#=W^L\R?Y>IM(1-Z^CO^/H4]9=S772M)P.[U
M%0UZ]OO>?Z1(U,11:\$P_'`-8?M]M@S24A[R[4'Y\?FIE$!RG`A/TQ^N>3PH
M<R@VNQDW:$>V9CO]7)YRN':'D6SJ(U*I5"KHRLMB+7IW>%-@KJM?$DFJH<T?
M6&89+B!*YFX`V$;K^@B*JXI'&7-_K]<JVZ8S0[0F+*&Z5HRCX"A[$2=2[*9\
MV,>H]H^XZ0`TL8+@#7C_RU]GN7W>D;B]`(;W&-[3M[R1C8U+$S+3>R![T_]O
M!`LVA9HRT8:QF2'A>`O;MHE46&M&EX.=EJ(P1MCYV'$<*NJ(WK:]CE'_3"F9
M<;L$UE1_>["L5<GLC)HVV_`S-LMU6^5C^1C`,:V/QL&,)#5Z@*!6J:4<I0@[
M*$"9B0<CG;,F=2U(K&[C&&]U4])``Z"T.L4JA\R94A(Y4P'PC+2UFY\P]0<>
M*R@]4Y#6BI^+)_37WNQ7Y/7ZW)5(:E6'12BR,`PHM*XGQKBB#$81!4YVRYL8
MM#*7HRY;1,K2).N8WK^8NE(+RON)[24"F?.8S^?'WBSW6H?-:ZRZ->OB;IE8
M+ZL1J_DKR-?J;IBQVP8O)?CU1;;X+-'$G>7FM@D.!G_E9LQ.T@I*:IOD@X$\
MP$(1:]ZA%0)BQJ=]CV(UF0<GUU4>C.-:)_3N&1BU@![L@+8\'H(#\"+C$]5>
MHFV8"\K8&]H-*XM>'.QEZT$`]D:N95E$J`,"[YYI`_]>'RW#[6X$9_HH*&/I
M5=KUYC9\ZVJGRC)HC8BLTWO\7#-6V%4A'H_G"'=K`IQ)6==U:'B'K(J>XG1X
MO%T?HD%3H$`B4A]UY,,4JJ@2&M_H"GDWK?T#V%U<G'X7#.VT%M9+4?TF)I=[
M];L:M#`Y[?>:P-\4'U%BZ;+*[9H,LC50[8`M7*MB,JL_H#RP]0PG<S%U$I*'
MPG8R,&GR";_O`-F9D0.]X:^2$/--"YK@V;:MN_7TD@?CTK8#K^J[H_6.7:L0
MD&79K8%1=``1ZZ8-?$EJ"C4;-`/[1F;,Q32L5:5?>1KDT=47Z@,0D]_WY.G.
MDKMZ]9G;5@*(?;WXLCQ$9)^OIF[<R6WY6O+BQIH'<*B(I3P-Z!6QS8T-))16
MQG,H1T0+V'@B-BG`G<7-53!FV9<VCLOW[R+\6]:5_?`]4%QPV^-QSP,PT0;^
M"DB4!G*A[;(/4-8"`5@WNK_^^MX;,$V0Z4"I;2K,=O.CIO5(\Y/UP&^P%;L4
M(WU5E.JCJW;MV"^KP\ZD$F'`ARM"ZXP^I=9-'ER.)!/FV0"_-]/.+]VICU(Z
M0-51AF^L[9]7E+8N%,L/YX;8RK90Y./C*<_GAY41[!=?1KNB,B71#:"6_1QE
M8Z9VN$<4TOTDF/C4(+'2[-K>'%I<;=H5.%,01&)#L*\/*$,?PGJ'0CF/1F,<
MCM(0N#IU:(9]OR#,TJPN\0(S1SFR7H!Z%KXS8LSY-^#][X>_IX`7OBSA#M:5
M^Q;"1M1^%KGC?DT@KSX?^`,C1BEMES`6F!/BEN,@PU$/:8"?HYBN^NDHAQ"_
MG-MWZE3S+^<`0OF"W)/_83;F[)M?33R&B1WP+LLC=`Y3Y9[6=;UDSXIB>%^O
MESR?SPYZI\V"DH'=:A!C*SEIM<YUJ[VQJ:CT[-`BM2+M]QC`*"[7:_IF"T!)
MLCT>CSSID4TNI/*OYCD^'H]1RUW02V-PI$\KQ4C)V8-D@)I2M'4T)"L'EV88
MH(,)+3UU,-A%8EUDP/!@>C^!F.7Y_/_^_;O\^/'W$6A9L$ZJXBU'HUHGQ!@`
MXF3Q0&E/2X%\__9=GL^'$\N/>]U0()&C],/'-[O.]N?GSYUYHQTC:,OSCN7L
M.QC5$?@&(-<\[*I`4,34$NN:4%,VH4ITEJ/,*:P.GO`T"J11ZW&A`7<(%>]!
MY$R_3Q_TS$%!R,``19;';N_<UZ!8DH'B:DO].`G24YBV9-7T3+2Y;G8TJ/LZ
M?@F4J*ON>C\[Z%4H79?AZ//@\7@<9YINIX,94]!:<4/;VT,9>*B`T)1$319H
MRPY19:)-5K2,,I7@<@A(R?S<WR4-_S20:ZJHY(Z,@:W%R8]L.6MHIHW([K#2
M,>5W0;*2LWSAKX]<M,N:OKUN4O/LY/21T'G/AK%E*@OG.]!;"0!9C432C"'Q
M7^VI\3OCPAT@6K,%KS;!*(ZN)@,IW8ZYU^`-Q-<[VH,RA=?-+*73&W7=Y"41
M]-X#_$5$:I<Z0X$\EL>0Y"F+E*T,6V&,C7M9EKTV>FG`>S5-@+'^6*Z#M$0^
M2$2#@V5TLX,G\U8#&&<N(=$&%[)+>*'N%9O2._&/WZ1NA.;AO/2QRWS5;:_%
MQ``Y4(>/WVL*,#K%13MIL2MGF.8\4Q,(>_V0:YM%S(J;#]9G*?+]^W?Y^>.'
M"#?1G&2K2"Q8#DU;Q5926YCB:`#*8FZ8N]4*'R(BW[Y]DV\?SVF@"0^>-+LG
M%E2LGZO\^/OOHSR%6>F_))+2(N)*30Z&L_02*]7VIZAF:!9?)-2+H@Q4!LU(
M=B:N2BD^W3[)<'"V[PYB8K0@T.P_(4,CWH3$DT!*->*X\&_?6U""24V(+KLY
MV%6I]FLF@Z8)%EOV(F%W+<G:I0H,)M>D:GV'AXN53"PN&&[/Y^.Y2"GF1`KY
M5,JNJ%(K.]/?M8E%[^=B2L!*@?%S@Y--M+<T5F*J]()\Z3,I*WL#WO\FF'OB
M'I0#NY'ZN`**3B7ODE<T[`1G*'K.EMZ#[S-@QE]G>GGRWYP8I"E,MFW;G0>E
M-!4SYAR]CDW;L`:&DB++8P=_];,:L-OU!QLPY&C.:</_4`!1KIY#/[/GU%5(
M\0:6$9W]*26#^1+E8!/V^?%X].MNAW$;]X_GASV`;\S6Q^-Q&B2T9CM6)_K>
M##8:D/M6Y,>/G[V..1N;-.8Q@AA9E_(8D:UN\J@/5[<,Y08%"Q0(![EB[AD\
MI-A`X0%ZR3TE7%5#23D.L[(L\G@\I91#/N^S.I,-Q4PEG]FT?_7?.%A[>YXA
MW]-F$I[MLP^*>F><17)5#WM\/Y:'+/_ZE[S6=7>@.THL=OOIO6;\Q\\?>_:A
M!7;*^E8'%VG`I=8.5/WWQ[</^?[MVR7W@`S#NR]NVR9__QA@-\/X64-=/#,<
M`$3R'"Z>26:LP-J8NT/GM<3R`FT%;/5[D3NX2716+`52ZP@L>AH=KG2HFT:X
M0PE*51U#7>;Y7'ISJ@%>?LD>[U=9C_DCXANWC.-;8S2K37%Z-\<"U3J:"[G8
ME*D']S[[H7].D2?H>]YB<CFFCEN3K;U\QWX>7:-N>Z<]P!ELNGE^\(0<[&[B
MHF0?R^J@R?['<>:]8>)_'^C]"N\[L_H]<S2Z4[=[UJ26JZO$^)$24ZAW^.C:
MTZI?P[F]THI6*<`#L5.2[BLF$N3I<Y$;M=@M]C<VJ^)M,5W:4426Q^-@TC"]
MG\Q>N#%PVV0"G3';5CX*4Q>QG,(9;U5K[9LQ#]4)''73G_(I'Q\?DWF89S5F
M8-?+B*%8;4[/#&GW(/N(/<.8E'*T'*'W=84%BJ52/C\_=\%^L369N>;IC2F)
M75Q>/Z=M7663*JA'G3=&L]RRE/[96ZV#R3E`G68$3^-H5Q[";9/'\W$$>NA=
MUEH'V`R7UXWFWERXK:L`D.?S>6,$M`L5Y/%\BO3?:]:E^S/]_OV[?'Z^!("\
M7I][D`4=N6N9*8;&OYZU..;,Q_=O\O'Q(42^%6:.Q*GJTK%6?WY^[LH,)W/?
MZP`SQ4I(Z53*]=R:J15H$"0'P*,@]._O^PY4()C0=TJB,4/8^E$TMI$NX(*B
MD>U>A_1$ZB54D,E>$4MKUO4U1$#@<S9><[L5N#,?[R,K$L%NENFQ/],_PUM/
MM]IEN'HH[';6,#7?*N-65"UV@90%LE6M9'?\7L'<F5!UQX7*@\3HQIP`NFX;
ML(H/L%.&L&/^!KS_1:^@0?JE7[X&=1>XX38C.Y,5FYGF>C&3Z;7P'OM\=MWM
MK-YK:`/\.#V[<0/LFO=!8D>*KXUH<TMCM)<1.71_UVU3AI1C`[^>3Y,#$46Y
M*LF07#-T;EX&8YXO)GJZP#0HX-$5+`=#7;6&[M$4]_I\R?/CJ9C/DVK*IO<S
M^9$6/#E1+JL1BO$LAEUS%GPRU@"K>P\2?V!OSNGR1(=^\^?G2SZ>S^/Z\H?%
MN^LY>?#+\[DWI0R/V!Y@\,#F=:N['?!Q!][&-BY7?0JSR[8U)GI9BE1"N.TL
M$-RX<%+>I,?MY^M3MG5OC%PNU@_MY>02MZI<"BCR\>W;_NR617[\^"';MKJF
M6Q5B>C.8?J"7GAZ70PLY3QW-ZEG=Q1[`[O/UVE59Z+-)SE3#2>,8P,V=BC7*
M$FZ\)`O?&%"<4LB`6\,BY9``>ZVK_/Q\R<?'\T1N%F$?`!%8E&YI+,>84J?\
M79!Y;/1`L9UW31^Y0`%A"&N5C76OXP_9)]KQH<BZ;?+C]3KDQ""CXHRN3UPQ
MN]T$B&G?J5:>,.YB')</8\`SKK,%XX"N3U>6%6H.@]RSAM1*]'ES^\[:+U+Y
MLAG=!O1Y$F\B6J=3/5OX#*%+!$(%3",8]O/<[B%OP/L/87?O<9M?!\=?!;OG
M/X.4Y;W]86IA?*6\(QO#ZK0CKS3^[S"\S`#=E,0]28&K7R`IZVN=7A1*$;3Z
M4W>?-#5EF%>!N$UKUY[=#Y7`LMGSR47IJIX3DT%T=6[,6'!`MEIE21`=N<N?
M82WR/$H5SD,53%E>:#>WUHC5QAT7[)EF+ID#?%(3-'2RZ\C!R+$>UM=KEV:;
M!BYWHU(.1R<WR9KBR5XB$-'TY^O5W<1V6;83=E]4K>2D-KW54^_.5;]FETB*
MU(VR8I-''<$*W#,)`0%G[E,RBI=5VKV4(M^^?9>__^=_NJ:T-D5H?YD&.,%N
M*O'MFRR/QS!(F*74=`I>XKK7L&!=-ZG;40=O7*T4J]G>LR9VTN.=#7B+Y@VC
M6XXZ>)%#VLM%@<-2V:J*]"&M>^W[XV#5.66GQ:G<,!;ZDH?1Q0'6="9@`KRT
M33*J`HK5SI/=5(8B6@WPI/[N]5JE;@QR;=&Q\-@5ZU"@:8RO5?))3L*J(P0)
M5M_],:CY`*U(XZW1L9MH+,NB2D(NSNZC>[(>@5+_]-I&GL.,**N32TPE*/8\
M:O)MU>RC$]F^0&]8`Z4WX/V'@-UKD'D?'O\R,WP!"&]]7W(FA&X1_@[@#5JW
MO&:-4S.9F>+;58VQ+5\:K*(W0.I:BXZ_Q;TG2^47GUT6YW%(>H-:FLPWFOBN
M;9^5,)WA,X%_-<9H_P.4UO"@/K9U/6I,E\NLR.D4PP!RWN5M.-8='$C7#6Z/
M#THOTI?'#"!`29K/]($.E[TXOK:NJSP_GL:X833685ATAMRU+3A$EZQ+@JQ:
M(U,INXM7/=+GE4G4(?E]V7W*SJ%=X425M?!^/P(ZJ-NMDNMGE?^S_A_Y]O$A
MS^>S`^[:%3Z0!DL&;WH=E*Z)?SBV+8O\ZZ]_R8\?/V3=UG$`N^AX#Q`7>7X\
MY7FH?YC:7[=TZ32_"*N!O/]H,0!A?:T[,*L#)'ARLQHDJT.ZF$EK.J[BY?VT
MZV/_G,.PA=7H_%:EE9K0E?T]MFT@X#/AD9E.-0X&EMK:NSK#(')ZY'59+=I,
M7U%-93C,-,H-&T]29'MM^W600RNVGU757$9-V.?2-6:S/(9N/%.@L._]=*`X
M/Z,U*0&,_>+Y6)Q#7IBF)I!H@=M6L\/X:'ZMV=Y+6])@B(=JYYV,3!PY=YV#
ML<B1D9WAF^']YX#A._B27W@?WJ=T=;'Y`#V3]Z9<.V$H,,B)9-$T^OXRV+W"
MW]'G.S.=^*)YW509XUZH0EM0EMP390=+30\7"?',+\0>8@V+)/IR:0FI8ALH
M#',&QX:X:U#`NSFVY5K![/),'Q_+;ZV=WGU?Z\ZF(I\7H-J(+>ED!/]%(H68
M920&X.!T36S;)D\^S2*V_3>(ZN_)>@E?HW(H,D!K'!P!'9A@\VS6)[IIK9FR
M5L'R,,%,`T99':B_[A\__I:Z;E*.#`"W3?[^^V_Y^?.G/)_/KDA2C\:[$'R)
M[Z"'^SJ,B+W(SH;]]==?.^A==]`K=<SU95GDX^.CJVN<98LZ0^[9]A:8FGFR
M@_=:J[Q>+_G\?(V@J*D5]-(;G`;`<`&<\EL8G?/].NR<!"?>)RZXHW%`Q-%#
MNW_6XZ,DSG[9/L?)=J>!%V5[O8X&4W'*,<=P5JV04*VC&;7*B`+UAQ&#\/J`
M?'U^RNNU6@%R2M!)U\",3G>V,]1=>-8*)#<0/=8#5!.<LRV?U=H9645VF_1E
M60Z[9)614>4=0S^<O52BUC;^>=EA$-MI?=1*]X3&D%Y2J)]*$*I.NB";=TS2
M]OEOP/M?R>Y&C^Y?A\3W?V[>_,9I?>$O(!#+MIQ<V1G+F]4%Z_I+?]GSNN/Y
M4?[5X0P;_:0.EKK#0^1$\8)[_6["JK1:6-/@Q3GHS63HO&N9EY,A+7_4I+R,
M`U>V"<N0J0J`[-!K;3J84/:T(7@Y`(&N5\9-Y;H,8V;SJ5<)%RCK7R84>7*P
M)>N7)TR4.0*XIS\_/S_EV\?'*"SQ];R]9`)&Q6$\.SO"PP2$W1'/CVE[%12I
M5*HD]42.1;,OW<1"*5X(9'VM\G@\C4R9]$,\KEUXYMC9@+?G56N5GS]_[M=<
M=AWC!]FUEK.,0RRI0+B'=O6E+/*O?_U_NT3;H7U;ED4>34+.,V6MKO.HE4V+
M-Y@[:NF`I-8J__,__R/;NJF]S-9P=K*LZ^/2BJW`";52A:O5\XO#1$,'(`9@
M!<]N*,"D>C.._6M_'L]@7L";:Y,FV.3AT&B-9`PC[8Q\FFXZCE*/EI6A"K:Z
M'*!2R8',,XR?GZ]#<M&Y9](^6R8!1V-L*NH(>/5/.I.<K">`7GJ.3$7%A-Z,
MYZ@UKK'LIU]O96")Z_$[$ES67)D8$,N>Q-;;5M>_8QH^?0;&E=E1U8"$!MYC
M?K\![W\=V'431<ZL)[YJ6Z#$'^_T6DV(1][HBKM;U9"5SMXI90BIHMZ@<Q>U
M)C_H>U4N?C,V`K!W*%.5"#0W*7'GB,C1[4R=O[)`F*SC[1'+#1K3VX!C?JTP
M!]Z>&J[F($3SH.^-.U&::%D>^V<Y9Z2NHG\`DEIKEZPRGO='VO[Y?/:-=`>S
M".-)BE36`'CO!EJZL1##:U2<_ZER=FKZP.B;/[,,1L8FBDN_)JSOK!1@6U?9
M#@DA/7]TRGXX$B'):,2N:#(!D^YO!E4.)+0QC"VT7AQ#>'Z@DE8;?E[N,W>R
M6Y9B3$L\&SPLJRF?GR]Y/!9Y/I][T$<-ZI)FQ[ZVK?N3OHC'`7)O[=?>Q<VQ
MY#D#KS6OJZRO=0>[70.5;IX-\7Z=4AZ@$B;[D&7_8\8*\^OV\UP51VM651L>
M[&M9@?(;*],$GMWM:_]>K=P_2P-_B\+&OJ7=\F+$O*_ZL@<LSX\/\<USPT%M
MO-9U35TB24[CW7QP0```(`!)1$%46&HFN<^MDAR:#$!?%"O?U5$F)7C=N8TV
MTX#9F>F;.KWZSV%A_?GS\]#A97`%9,+0,\D."&)`;LOD1#'+,JRAW;F9J@4I
M(N<->/\[8;"X(M`3L,N);>U]^NNRO20&M^D;\<YG8IK9<IOPM;6&9BP;*X"`
M93D=P3OL0P:0D?B\9B,Q0"Y.I%H@2]D/\IB>1BC:LB!@9T10BBQEZ;M4U4R,
M0%G_3)APW2!!)X?6?>>?1^-!->!K_,H!ZH]#\/5Z!3!5#EF@IKF[+,N1@MN-
M(;+T`EEOQ7#3-<*Q\<+74JNWT,+J66`R`IEX`#)AG^FR%'"ZP_KP;TH5C?UF
M0D,Q2S,J:^.T`U0[_:G/9[A!NN!(U7("5F4!D37N9@=)JH$I0(A?V[9M3^NK
ML>WC$CYK__[K]9)UK;*^-OG^UU^NI.1DN?]"=BHC)O*T?;3),\U3M<I:-UE?
M+_G\_!RI>SEJ5Q/@DJKW>%<N78W%3!HJ0G`=]$17/=6T1F7PT.O,<?1HC<"9
M];!=/LD$:I,?$[A5NS?9U/8PN-$VU^+VN:X1[(B3Y\?'OC^:/=G=.]$!+RF)
MVD;IJ?7IN:1+=R@V,^<I"-]4R-SBFKZ)BWH]*"=%Q<8>TM/=O8VFR7C4W9*0
MGS]_CB"3?M\2,P>0U/5K/>(][F&NH>[KW'5YC=@L'^"O`>^2AG\&Z`WPRAX^
M7Y0MFM657J6A>'E2P%@(7J'(VV4:KO[/I"+I-3[%B/>GM9A7J'MFX.&<<'0Z
MF1,2RXBNFSH#^WMDE9I[S.P=N9YF390$UM<J&RPSMJAT[WJH/+0Z1`,NC12<
MTQN54<O((]W800?:(40#Y-9M9PH>RW(<@NKG:^V6R[76':RK&C9]$.JT_"F+
MRPA>QZU5Q<&XTHD&A!/#C.SY!RY(U<\-S=#Y81@9WO&U==V.YCR.FD1SX&CW
M*)D`%B1@V)5:D,[B'F;]MH.E-53Y-"J\(D9OKCN`N\SK<\^"25VRX,U!?!V.
MY=GVSWN]7B("^?[7M]Q%ZWK[RH-PG:6PMF!BJ.[)FY#6#>RUO@XIM)JRQ+,4
M1C9W+#BU_8%Y%H[A^UYO>K_6FC.Q09V%A_)!M==QE'L`MM'5!(JZ)\LY3.Y?
M8\HFP.\1WA#ET)0>O0'[P#R61SH>)`R8VN?2.ECM`RRR[=`<R2S=Z*G-';J*
MA2HMZJNWJ4GHPU@'%JK!N@-"^!(<6]OJZ]:H"VYUS;HS<&$[>PSYH4MI$$@0
MZ[IIX7CBVRE9H\Y(]L&PP+5&HP[OU@G@#7C_GX6S-U49,&,HOZJL$$*R_-NS
M_?>Z^>N+P%NN[2@:R#*ID`RV:M6#R3O"C.:-3EV9U6+"UB?V0T3+U*CJIUD#
MD'.6&NF@4?A/W60DE%R=A\HN6"D/O#[W!K/C4-G'<I6"(ENM!NSZATU3LTG9
MMBK;N@5?U`'P#N."8X2W;>LLKG'OH@9>V%4"8%V$='D`,!&8.)G>/%EG7:/9
M@Q1B+BC@`36LK6?`P2=K2!+V9`](5JD_ML,-ZBG+8[%=YSPY<VS/M3I(:!@9
M.)#NKZ&#"=?N;NMMJ9AR]?W**(S/D]21RQ*UM+ZH6LSI7MD`1+.-.JBRU^M3
MGL]'KPU/`U8%9."R26$?="RUD2J`I`H41@T"(R.PKJO\_/ESV%M/TN7>>GS\
M&Y.O3^;7&?`E?75`R*R9\\74^KI1.E+BK,ZDH!$5(GW_,1F)PZ6MU23K:RG'
MGM7VPSVC9)WIIG0%7?5`K\O/K"9B-F!;-QMDTV:*H$N_Z,O%Q#2Y]6!-,_$Z
M<.YE`1Q&&NH4&+7F&EC;8`?JO!FZZICF4?Q^<`R1T5,03QCI=4QQ09^V/T?8
M,P'FQ(%JT.V@-YSL4=GD+4OV#^)Y?^=E!.!Y!;"3!GS>^8R3ZST!V1=1P=0=
MR'P6\@]B<@T:C/+4GTZ3&@XXI"D=#\(9-B<;OKCTFUAG.B0L/Y4I#]PV.#"_
M=LRJH5&M<@N&`"$RI[?[]&DI59]U,-;0]<]&58=J@X.#9Z(:<=!+#1H;,J[!
M:4V'-+H3QJ$XYOG_9^]=UQPYDEQ!,V=F27O>_U'W;*LR&8[]$>'N@)DYR2RI
MNZ69K/EZ5)<D&8R+.PP&`URB2/E[I/AC8-O=6("$`H1A.8`D`N/H)NRJ5Q_>
MFL!A/S^ZW8[;&;PP6-^$K7USEZ^"[CC.Z?^.!23G(-;UJN-^B.7:F.1'.63&
M<@M0]*BG]E'5:7]4WT^=N@`Z2,=!_]WEOAD3ZA\?'PIX1>ZQ&#1QK?#"<FWH
MD$.R("?1)3UU>$9&L?[Q\7%*%TB.U,E.,#)LH,I&B]B"A"@B@W&.YZ_7IR2Y
MPE$DW;MM7I/I3`%Z-F$SM7``WO2>UPLZ8$<_EC:VKZ2VV^4H<'M[(^O`<Q#N
M+`YZ2)KDT3X+(E)R(2#7J]MU/PA;OZE([_?[LH.;W<5.MW?NA79T>=;'NA2]
MNU')&C@BF`?%TGI2W6N>4C"]]*1<C44WK,A[6^%,7NUE_`>X,-+9#,\U4GZH
MZ*H`RK#<5O+`"*!!@/@;\/X/9'<?HM^O1-^&AV2G9L6&I?@U</VU]\`O_EO%
M%H,`6-W1JT(Z0K*21Q&FDZ(A^]T*N'IZ7L,00\)97O'+"7"60;?2TO++(S%?
M4U`LE;:,0K&`+,=`F/!6VRS*D`_?UVG@"8Y-06$%;;4FI><@"2VX'C6N6*TZ
M'M*8[<1SATI,!.P^)[@1QR')TF>KX0T3ZGF3NV`9,D"-Y]9P`M&1-C;B=5$F
M*50;XCG0-=A$WGC/Z&:;[@,'@:WAA6JD-W9HF2=655[=A`L8OC+8.@?,>-(>
M87`3.X8\#\?=[W?[_/P\!RL;)\*A"`WIY<RJ1?:\6!R50#B3\_IQ7%(%G_?J
M&+!+VOFKP\%`OY[S\Y+!C8!(P95K]1T`@Z5^@&7ML^/2K)IX,OLUF`JRB>K6
M[7Y<SA:^6O#C_EL=.NA$_AUVN!L^/JRUF[V]W::_LI-O<26WFXQHZ$!033*_
M[_O[V\42MZ#)#QKB*^61V^ZC2](I<&*N`42?\R!61RA'>;`T@$(A2FG?`H4E
M54Y#Y\<7S^8U+`<;]KU(@'JL:<=QV!\__PC^XF%V1B*;P["FA\%<7\$59EF_
MSV"^VV-_)(\=-%_S)-^`]W_3KU\%NW\BP>TK0;_R_+X0T?NKH!^A<MV"=LM4
M<&$2I-\7^ZFZ5*G&O?X5G09O4"+*Y$72XP[[`+PFC"B62[IA@L@NI`%$8:J]
M/K'PX,])[+1U'J3!-/A/B4GQ"WG=MINZN2LD83!YWMK:?.D[+5T:+J>(GGP\
MYT1TUUQWCB7E@1CH6A\YEKPACS9MB,M.\:B3Q5MZV&CB]OEYGR!I#;[Y_/UP
MKW#'#&/Z^?%S!DKD3?W<J._W>[AG79PV9K3TIAUJ%!XB]XIS_*XEUE;/X;K.
M;V]OD]6;AW6UR2VD"4;0$UG3GS]_FK=FS=H)P#AM;S!;_;!^=.O]F*^]M6:W
MMS=[N[WMPV?0YV>?%F:G=&=(AG22OX4!Q=`VPP+>%8#-K.&FQO&L;>4!16_4
MDG>W*CQ&B&VC+H[ILXDBK+WW;O_ZXU\KH*4`YK,K@G.PC#6ZXWI\?!R7RT>;
MYR2@]0EP2_]ESCH!S-O-?OOMQWD/7=]'QD599F6+B99Y$<_2H>&6XS[TO13D
M`0Z*6=9]$):5P*<KHQGWD8ZX%U^_PF"@N3YX0WLLTH)@17F@K^CA[-ZW0*F[
M%OQ,9ZBM`G5>U"V/B8!Z7J@>7K.T_GQ+&OZA[.X>N;[D=/`7(N9'X#`VU[?N
MP%^R+/L31#4>'>_COU>M_2,KIGH$:C&;&41Z`-^OA7DH>_I`C+%'\P72GMZK
M6XWW`T^.S:9KB?&*]EMK8ZP*!K;52HT]+_Z.%G$`LR4\#N],8&L7:P9[>[N9
MF5_:X?NTV)DM.!F,TU2H-2W=MVXDT34!P9]S6AP)\^-1U+D?V/2X-MADL._W
M(\51\^USNUTLL)M]?'R<A4$Q&H]^M2\Y!0^0@B1V9YRM@US-Y2ULHMFRC`NG
MC?$\?:<?/W[8'W_\(=<XM]H#FWD-?+(>]W[`_N__^W^OEOEE@=>:'??[.;S9
M1[*>@L7##O/[W6ZWF_W^^^\$3!:0/8[#/C\7>[XE%&`&[W-P*3UC'$CA-J4U
MRPYP21*FYW7AV+'T_MUB0F-\?CU5(GRKI:BX!UN&UQ2_6PJKD4[09(:5O60]
M.`QVV"&`>]DD(DO#+Q&J3/RC7X$AS6YOMS0;,20IJ^`<I^!(;/ENVF/)I'1^
M0>*@K[[^&`8<X1?+Z<3D81D=!Z?8\ZJ+F$F!I:QNK=G_\_OOE]SD^F[-US/O
MZSS?VFV=E^8K:GKN:4YKNDF2YOSN1-C,:]+J+<R?#&&LY$&DK6D.(GX#WG\L
M[/VK2=P_^[$/D:B.,NW?\RNL[I\#NT\,RZJ4M/G0>R[OMXX+E7%[]6]6#^G@
M\6F.*X*_$(&<BPH\9_9EXB5LOJ7&K`:]&B#EEXU2#<:B1S$\)L@1&$)F7OA$
M`9P,!#N.<SI\A#1\?!R$)1CI<R3PDA4L0+&FPGG9!C*X$)D"0H%C(=&,AL.<
M:,]:CUY83DVVW5-H%UO(`6;]_CFMZ3HSI)QT-]K-11`(<T<P]G^VT./?59"+
MQ3L]3\UJBA1;BM+]M+*['W>[7XX+*9F-_ANGMT!."G.MZMWN</'U/7^DB49X
M,JQV6H;UX[#>^P0.=OW]SX^?=K^32TD53Q9^M>;"^CNS?,S$&FC(1^<%UKQ3
MZ(!X(GKS<"64]11+N69B,2;OY\\#,[GX2#II6Y*I:FWQ:C#$D8K?I>%&&OSW
M":[$E7B(1R9[+U[1H;(#.?YTUJ8'^9\\=_1G=0ZM-,+T/#C-'?`\B>?[TG<-
M`=[+G.90_-1#__CQPZRMH508K*&M?8\*U?OQ:38<81R)U?=9I*NEIN;IZ;6L
MM@*O#/N":)@[#Z)/#Q9GWX#W?S%&QE_P)L\6M7\;X[P#A;[_#&Q9T#SDL6,M
MB[[J+WR1!T;M+[SE%JKC>41TUOHA;38:,L$O-!:`J06`^\/K4['$B(:S/4=E
MEE01$/BA<\%UA!F)(0M`9C_E*VR9-@+3%R#K".P9.1H(X';9AU.H1+RW/!16
MQA():G]4?JHH*B4$)HEGJ*I?O??3?//!_=;9':"X[I'9YA*P-D9<;=L!;(8&
M,]UWSQ[NZUU_^_&;?7Y\BCR@`Y5H7G[/A=V)[?H:P$ME*HB![W+O-#_9M?O]
MT_[O_W?8;[_]9JTU^^-??]C1CSE8:87^TP-X2RPG3\<7FO#F%LN.(/6ACI('
MB4**'G;J*@R@[07;ACE@%%?4Z`?MK%F-4I84MQM&+%N^[IQ*5B<W.G.-\YRN
MQ&UH83$>.RS`^O/G'Q0'O4)11F"&^1DCW'L_NT0-96W'#T7%:TP.1<)V5-OK
M<,*ZZZ2[17];-PE;'._)\;ORZ+J]O[^=L=MN]O'Y,;LYI[2CV=OM-K\O.JY`
MG[OY+8QP<VA2Z#PY6ZH9*-[%"`1GNL.-P;/E8BUVCYSUV%F"\PUX_TF8]64K
MLN3<\PH1^Q!6/85XF^"QAPCL10E#"0QW$@+L@2$J!!S27Q[B3>#!.7]%C_!%
ML)O:W$4)'!*@2IZYW.]A,9]==;C8K=GA6/;>PPAG/0[^)"56",60Z7)HM*F\
M.X-],G<W<46X_#`%L)HP8B@\BG7(3+TP=+/F27Y]7L?7'EZ1T]G`LMV7DWY9
MOW9EM>6!/4)Y$3KM%T[;9'1=V?EUH@*YI(WMQ-0X)5C%D;H,7%NXS=OU/R^8
MR;AYC@"05:C%>P@9H:U_!RR:(UF0:Q"\HJ&A<>\@F>R/CL5P3_C7O_Y%8-)G
M)Z#"\1K=X31T`V&LHC5WJ77&A@>@[["8M2K<9@6EK"$DB)<SWS]8I*\".@_7
MVRG],QA83-;5M+/A5L5M>R@N%ULJUF)7URM&'#LL^2US4,.0PXR0'`!V\V:?
M6![#O9\V@*<G.>SSLQ-X]03TA/T&67=YB(NG0L]CSOSX;4,0SN+ZGKRV**@<
M/]MA-H(G!V-\N_DE?UIN('Y544"W^]'M=FO6T>W^^3F7O$:3?H!O@O+.E,I9
M$)K5OM2[/\^42Q1[+&G_BZ)X7>.U)GP#WO]!O](0U`-F]TM.LMA_UI]A;('G
M$HS'K*5N$Y%!J)/.:((7-7?TJ+`H&=8YC%587>$+FN.2&:A`?/2ZC*#/D@87
M:5@N:(E?8(91>,IRFDUD]E*-`FSO&PYUC5/)9H4>3[1[=4T"NRR6?'E2`K$P
M0'G^%V!V<<``V70)6C-/X1'+Z](L:[>'1_("1-'D34"I:Z2G:!?Q*-#%1&(`
MUM49Z?MH$"JF63D71HBUI=.S1ZR;\1",QO&";>8N?>(8.%*+I>J.6D,UZOMZ
M^4EW"/L#%,$%.\YX&^F&&:-ZRA1"P6(,L+2M#%MV;6[]"E8@[NKHTSED1`9C
MNER$<U<$DR!TDTND"]/V+O29"A6%2(64<`:%M13M?E2^URC[:>M-5R1Y,(<@
MEP`ZEZ%EO4(%FI+3<>'RL*BX%=9J+HSNW$4<UNT0ZX%S&;A/I`])]5,94YP_
MG4[!5-CI%_<<NYBVE3QX-KYS-9@W`'#S0%RTLR/!K#\__^TJ*C\^?\X3VZ)T
M:SA+S*'5*%G!+`161R->;+:K"RAFRFE8>TZIEPC=`H_%'^8I_0:\_Y,8X$<H
M^%??!;_VP<_4I*^`W:]\(!XI?*$LVI8L%G"R<RHM/B$`OKD@`7_N4D@;U8*6
MS+?L]5?.[9R,+5.>=LB`TVRXE<HQLH^Q1/Q';4]9`9!(_SIW755H(<:>SC9:
M!#O$U-*BF"]XY9FJQ4:9&0]8?]#I*&4C\4\;EBZFHV&?O;JYP:4<6/<)#V+!
MQ=:'&=.85Q]9^?1](+%8)YB;P0*@D`@O?6$3?(HCW,N9WSX^/A<K1QLM@[N>
MGLE@>,_?Z=*QJ`Y8*TU((4("$_<4^^HC[0(4$3W`;HC`C@X-5??!$`&-"QBH
M!D_G4)]KP>AX,&\0_&K/D`A:(P;@2,.3".5U/N_34:9;,F`&=0X0BS@4V5Q0
M'W-/6=T\R(<4[SV?2M+,U_<C1+<_[/AR=P3B4F"&,L+"H#9>'E@`A/6`BQOW
M)\]\H=6N6G>(YXN&+CVL8BFNF.*.$?8@7IN7+>0^KC5VQ60[+G2].[#+WXVW
MS6_`^T\!LWB64_978%>43-F7/O.5%_GK[U$#-W\!4H?/>SC0Y8%%K/_5PX(-
MPV.LX6:;0*W7KP3B\-8#\/@*FPS**]]=!T1S[RQ]]$!",\.,P`#OOWN0.Q1#
M>QT(5]RI);H:=PQ0<SMC++C,7F1VJ52-Q/`HWN5-IYP1-CSLV&QG;]+PELSR
MT,GM_<5`;6&:LF8PMKXK:FUN6CU//.OD_)@>KX,S.J4XG6_9@D4;#Y;U+P#X
M(J+Y\@:5@3`;\=4+E$4I!Z+-EFOB%Z?*#2<.!N;2M:`A..L]N*A<P(@9O'E-
M>OG,8U/?,NN+!%2#!VF$F6-8$:1=)<;>2Q9<41-U]A>>%'-45U\N>'F\B8&$
MI[H>P7Q62BMW[;98T,O+.GRVU,ML!5818143"/*I0/I/S^&S8.SJ_1Q]M9PY
MZ]"@AVI40=:,X_E*7=Q0B.LU\SS]$&<MTL"@ZP4E&F,"5>"4.71BIRGL!/[<
M.<JM<&1B&[V21%#98?;$IE?2J:PHA6_`^S_Y5]$F^F6PNGL]O@"&_:_X4JC!
M\!-=!)Z>ID<3X?4(56+J\`O%07HJ(U.\MW`+U-06B$L%30OBL(7QHF;7URF,
M9EN?R&SB29&F;6`OS.VM\*T=8#)L/R@")W:?[Y6US0"3N5,@$IE"PL"*WFV*
M9MC(XO[B'BH9BV!P[R92#K"]I/$G7:%SX`;D(_W9PSJG\WWKT'&2ND@MZJH@
M2K97#RKOM7<WH8#:[6:X7R$@0R]M;5HYP:CPL4+3S\57L%KK':?':P#&[LTB
MKS?TIUE[VM)UDB<*MAT`C1'7R_*-@PF"36*PZ!`]O!Q?59@*YYF`27XN\K7G
M@(W:342?17`D[C@SV*=[+!VWK00\=CH@Y"3RG5CL,%L=.C[@`550!+*W*\XZ
M,SB+86YKA8`G+37B6C$&SL+U8'F&CG?`X@P%Z'P+$5&`W5&44D^RV./6\74S
M:Q1)/'+6FB^'&W::45]]#901K_@1N/'`$S^RNI9N.]_N=T:=@F_`^T]G?NVU
M]C6>LJ:O`;37P?(#K^!7!]4>B(3QXL>]ILB(S';U9FM@2MOVOL'RJ,T<_$\6
M`1O[,AWPLB+OL8XW]QQ#)1LW'B0$8[.X9":*SI'LZV%XC/*%)3K8V&C>:2H<
M)7A*P/MBCV+,\_*$C5_*TY!=#%H86DT&%2/QR\J4.1V,<0(:`Y2I0X6"FQDR
M(3&Y!-L$O%C-6%[;SV3-X?6S`ZL3TFAXBPN>W4TL?J.>&]OK._C%)*TV=X5[
MAU;<O4_PR->X'UT&OE98AHG6V<,3C<X^QYBQVBN5SR9X?[BH[!:V';,Y"Q\W
M="O+SGGO%BPM@Z3(G.M,P_)/UKIMZ%:QP/O0Y(M&`%/&<`Y>FOQ\.B8WM1*\
MGJ>-*UPHQPH/;O)SYAK1B7V7#@Q=#PVQ#<\]G;=X+!Y&+B&I:">#CTUN_=*J
M]F*?\<*W6IFI.(`LFO#X?6<QH6N^Q&;'^\/U_*3MJ%B_S'(\L[$[@X61$Q21
MY5M;NGT]#0HD\?)1@UB0@<B#J?.V5=!_`]Y_`JA]T9WAR^QL566_,+"%!T`3
M.X-)]LW[(D!_ZIMK5LX>N;VJ97TL:8C,J.C(*H]4E">F1+E1LU0!\9W$HO(P
M1LK+-+44F^2HI[0UU6O1(N++@W;G!((-"SF_8\DHN33Y4JI9T"&ZA%.8^-PC
MQ"#QXHR)SLA#B8G5(,?05J/)1/7\>]:Q\F9;I%65]VAH10.\F>EU%V])4$3K
M`V:5DZ9B-S/IMKMN#L)"0=E"%"$3NZC:&K!F`#U=#R[)0-[P^+ED=XKU?B.U
M+,I(F,7*]F_C&(;\@B)_XP!2\0A#T@*S#K>Z-IY`?QCA#\]V9.Q60165E9X!
M!MF@Y2'5.,3&]P9$*K+./7E1!U4H)P].L#78U<8>UW1?RN^A]V5I`>DEY9$*
M,KY&4C174A^.2-;C'"X@_'W1\;C3`I64K'^G3T3AS"#/5XS*#9HK+#D4;S><
MF%?)FE+7+@#)F-#W%).X;_:J-8P!JS6[D7E]UOKDS].&J`9<.3EX+"G2*D2^
M`>__,B;XS\#A\B=0,Z7;>-VO'+2;MHQV1XCZ>^+E#ZG9K+ACPXM(QN+'\6#R
MW^,\B&>%<-VFUTTNU=Z.;>L\D]6NIK6\8(T?24-RMG1<#XCU[3!5<<$6H`RQ
MTK3)PP-0D//MY486A\[&)K$83]U408AW[\!A(LI%/)^]Y_L/.3P#V)T[94/C
M0?3.%D=/I`SD2K&^']FR]<P"98\N*]KWGC<?7^$<[OY2X:ZN"3P<64?6XDG,
M]CE%_BG4'[H%Z0EK'YEU6FSQ8'6?K8@J&83<(]7@W01^K-,4"[)UWCMJSAPR
M[&:/00)6$,74UG([?EI4(:5QN2N3Z(4?L%/!SX$=ZK4+^5Y8U@D+H+D6E0AQ
MX^.>Z#CE)%9(4-,]M^D,N.T+MFEE"$IT'(`<0;@T745L8P6H$H52'E=XE$<)
M&SO2J)^U=BUX3H3)#KX'TS.N%^`IN58]MWE0+'+IHZL&\1,6(D08:W9^@)`B
M,IA67.;2@A31NN_R^OZ&@G]#9/HBLVMYC]J^U^M,9WPRW;9M^V?,;C%F[E\Y
M#[\@-O9?^&F-$M^\@_L7KI\GEH'7!4V5L@7`;"<+@,S(+A9$;P!4YPZZT,2A
MGMUYFZQCG"RFSTRQOKS(7I^U/I.%JVN3CVTJMNU*!E*(/TO`N6HW0Y\0A',=
M6>_">5;^B!X-<ZYK<QFULX]M9#R1)"X(;Z[,KGH`FYS7[694HC(%6#R4(_92
MQ?GEV\LWK8]'WL6[7^<`GLHQIFT:]L]>/`>=KG\_#NLA`,3=4R3'\!X5CUZW
MK/^,WQ'%9>OG_QC03@80"WB,J.IY'YBRPQ8BCR54P?(@65D5E`X9^D_C/LI`
M0,-WP.<)78^+Q.<S88ZN`X@YC"X?\QX-%G&XDLH0O(U7<Z&M\Q?/4[@/QU+`
M'1]TA+5%];/SN">\Y/9"8)*9-;1]0<;2H[UKH),]VA4@PC[,EK70W*$I+=!#
M\33!.W1=F`XIP/:9C7]?%7)SS2N(D!+1T_NN@!)^QA!6?ZS[<I.`F@;2/?9F
MUJN^&=Z_VR^WIQ772YSL+X#%F#CD[C-6$G@&F8NY]*\FKT6<@E_X0D4G3&!,
M:I6ZW6[-6&?4*6DFM?KBPUZ(H(1L94W=_+S;-"T?&>C5)@9BUQ*Y.?@A,AK?
M3\U%(_Y$16Z8>VQ&&70Y*5O;?`\Q$&ZG[F\`@\CFS(4P1*3.XB'<$X!'^!EN
M01>.)-L]A2_M:L>#U);`XXY%'.HI(!1/6IM[8+5R*V_'GJ*8;C9AE[PN1%TG
MV2<K3ZX5,1"#F2LO&%\/X0ZO/JRJZ50O4`37BO0<C./K4/UV!#9CNASL>XK5
MR=BL,@A)<#&K96D]73H6D:>L3H=XMEZ2DI40@F+]H'9Z6,1RR(=I4IR[L&C5
MXNR2Y,=,7DN@M09V:O<0H[:G?9FMX:4E9_%2"E3W]6)@SJ7$W@1BIB:<RFC7
MP#(SZ]</=D.>CPC/P)9]1$B<BYK4"TQ'0=RXKQI+6(SC>*G8Z)=/+GLGSW5I
M^?*>3#RO,%BI?Y&@HI"]&A_$:/=!DA?A(&&X+,XG6&HB[ICDC'17.)YO(8)+
MQP#?#._?FNC%G_12^`5'!'<OBT4U&'^$/Q]$S'[A&/TK&#YA,5\FY)O7Q32O
ML2&,W[?6+@L;-V]M_KG=;O-_VTT=E;9U#6U,+5S<2.UQ_&S\$$Z6^K(%1YQR
M968KM>VQ@&1,'ABO+<#.>-_;=:Y6!.HZM_(5H<`<,55C&MM#JO[U>^C/EE0W
MF,,A\)NU"JQ!E%<CDK)8("N`2&8'UQ`_EW7+```@`$E$050+,RI76$+)DN[7
M`V7,7FF%("2*9;:^(Q<!H/0F8>NM2I-"'>X@8,&-S?V5_8;=C_LY?$8#0<Z0
MDL6\!)"871]%(`N5VC5DZ#3@Y0CM^G!/"I,6FP?!*+HU+[R:4YH`M7N@$F'Q
M^<WZX77>KE/0LJ,%BJ98]M^%A*!8H2?VXCQP%R`68`CI/0I0D*[W/(;XS,05
M<ULT;>12<3V1WX\A4Y):`&OP5!QN3I4+^GDOM>N:-5NV=K44H%ZN\S"I)YK9
M);QE?<<J8IUZ5=-+N5&"G6]IB;:]/RJ&EYERWK>$B475)2MJ*L2DS4)_[;J7
MK!`]$%N/U(&*<RX/LF/,['MH[>]+]#[503X`@%&X_U7L#&;V%N/S:%AM'\CP
M*_3T(P;Y\?NE`"RKVK%>OG<_^K79HL32>$0\IXA0"P-ZZ]4GLWMN[,7J(VS:
MT,TB)5RMI",75X4X84P,[L8]X.'Y%?\Q3S^YL\8:@9"M7?&;0S?8CTF[\&1O
MC-7DXD'.83"2989E^>`B,X3L7A"MPAX4FWC2"1'I:P@;T%/KDOQ3<>1UO;,!
MNA(,4;-$`A(V5AK5!CV"$W;L;>\]>=$^6$H"NQ@7DW6WWC_O]N/]Q]3&MND"
MD$%-C`MN[G:D\@9%0\-MQH)4YW/C3HC+MS;Z(8O55:06C;68ZE0QY#&V8<WW
M-VCES)'WC3IASLM[:5[GMKI<,L2(/`PK7L!)7\P2"=2%!,7_\H(M*5RSR,G/
MDUARN8[P14F%#,C1\ZAAWEBN$L1\]K!D=AY,=)((L1L)GA!)\5'4W/:\1<FS
MWF?4-;LX@(:,ES8ZAWM'5A35EB@-#7+&D4QHWSQ?;$-GPL8OJ4C=-8RS#_HH
MYLGMO.)I/#%</8B_A];^IS&\">QZLF8Q*SH/)<,8'_["WRKAOB?ZA:]$C95Q
MQOYX(*RHZ.*YJ%]Q,EPG,-O[Q\)JQZ_S\PHPJ#PY7=MNQ\$L96[3,@!$J):3
MU/KZOR[-FW!-L1M(TTW`/+>$N7V5/8OW]ZP[Q?I>R^#9R8-*!>16\Q1!7$85
M[UP!QF96>?E2&SOYL$O5M!M>W`0TA"_A8H"D&R8D34K$%AIGO&E@:`&3'RLW
M*P??4'E!!>U0A\E`4CQO1K:CJMLTBQ,T?28W]>#UC-7:;NL@WUJSM_=WKA[.
M@!3G;3183EV@K+5FUDX^SOH:ZG&LMC#BHI=:'1ZV>+MD$.I9JNJ&85_6SN`,
M8:%Y6%"'<"HOK.457,F/H(.FZ7N8>M@&:ZB1/C=^R??P.DT,P(RACE[9X(0O
MD5^QE`-2!X!1%/2)9E]H8_<8`B_S>#O*(*!YS4D[NX8AFY718]?]T:&Z6.G@
M7'_5$=@-9_#MH8ZFHVLYAKK<MEW]AU?@A";%K4)"Y4!SB!<Y1,*#(P_$VH9G
M'"!6A;UCAI-TJR9Y=#_NIN2"Q]6[*,R9D>ZF,@94>YV7["`Y,B`1,Q/X?FMX
M_[Y@]Q6&-]TY0J+XTV9GM+_9,31%!/OS,`5[[.CP%..6TIVBRGO1H0&%<2^N
MQ;_A9'?+2K)J#V[^^TK^&Y@]"4;EN5WGA88TLF.7SCJ9Y6L0Q=`#UXI2DB\\
M&!IBXW,#I^%X$=.Y%C[N@KDC"0T6>%E_WZMROC"&WW4U6&=97DL/I+)GJ[='
MSX)M\+`,(VULZW8%U?8^#S_3+;/X@`X+50R\5Q9ZFOEDJ'J2V"P:*;X!LG%7
MT:W">%W'W%JSW__/_UE2A'I7"T%>/#EO=KO=K/=^#C_QYF?!X17!'LHA7=GH
MZ1I;^<+B>_%LJ/"XB*<-6M7HNQ>GWL5;>D;&7!(434Q`['ZXKG5B;S;>OW<:
M"M.!-D^!%&'2-`2PI'O*%^A=>UKE3%)-@'GIZHCX+$Y=L/KDGA9WGM;:R.@[
M,AD0/;QSXEW0.<]S:A(X,0%ZW#_'7$R(I=X]E9:4ONMZS\Y`<*:);C'+5ID1
M[QHHGN?-UP+,<B28I6Z:@OSH>&,AQ=$?KFYBX>R0=6!U'6I+P^@[O:'VSL+Z
M&U[^_7Y]">QNT:(]X.(>-<I>^T'?UFKV:S(*>Y:<5B>.?:V0J(_W?ASUE/\C
MG%Y4GR!S192](I-%61>(NN4K$<"Q3<52!1K&BI99_L(%]L0T;"N%`NRPWRW+
M"S`E(A-<@.(WJT$8&=;E;'OLY,R)??K2_>"6P)&\CVM*5/J,!YMR>0[=-T70
MIA&Q@WZ>F7'?,.#^%&R'+9[01+!E77\W`$_R_-RS6=C<4^C=/C\^[/W]W;RU
M<"]LHB+#<=UN-_OY\^<\AZ=<:!<@L[^]HQ/`3K+#$H0^XYQ'1')8@WWC_\HN
M',U+LF/*2[`@*U=M,MP%?\$/NRI:LO\KHN2(@+.;$X///L2;.ZIKEXS//=!/
M#2H/X1&3&^5'T\S-3=("G1$ER5.8J4X6:Q=S:928AZ()P-'GB*VC$=4>)N,4
MQ,?TR]#Q4ZI7BKK]O8MPO48;7[CSS)0.,`XO[V>CQ+F.!8I7##J640?6G*6R
M]K$;2%2K:<*D2EB<%'20SD5%,N1.UK!#LS28.'[W#7C_I@SO,VCR)Y0!&Z87
M3^AC;(!F5K9^"73LW\:>85_?,KG1]DB76\U#1WE&7PG&\+@Z,O/J^_-[6I*Y
M';T7.%Y3P80]HUE;SKWGEJTR54[3UYN[AAE3Z9;Z8B'HOTZZ-80I;PO>E+W#
M@(,&M#*P2"X.TG:[OG&:6G]4PX>S"<O3R,SJ`K8CM1_IQU)TI>W>!`]Z<?4_
MN;]09^!)P4IR)O[2OHT"7M]&6<V5IJ2V:9:+%<LA(^<T>5_R%F:?+GUZ-[.?
M/W_:_3CLMQ^_V=O;;1NQFSI-8QCE]F;-FW7KIOD/JGF-NM9'CA)X>+ZRCG98
M>$6&>3H=Q.OD2U7,/GU+GWV!R&Y!LT[/76M2G.50""V^^:NTYC*0]"KU(79Y
MJ<5QK3M-V5R/P25^GA=W"F+@(T_2!)*<%"G,XO1A^^NKSB8K6`=!9]K1K5F[
M9%A0*5%<=[@[A!!Y;.Q!3*QY\K$=EQ_%&G45<="9FCX#6\B]7):;[(13!=/(
M"N;!=<>TH("9>5?)34QRG''<F=S=7B]/2YNO8A$9*[@O@'SN3TA"):2V#;Y=
M&OY98/=U1/NL/2ML!C+80\6V/CTT?PEA;]]_^_7PA=A@FH`GAP%4#$NTF,*3
M<PS;^@./P9EJREFU3Z=SP>UV6U/CQ"VXG2W>M]N;I=@@!@JAU<J3_YP:UQKY
M*/N&+=PPUL8M9N@]HV"WV>WM)@,SI_58GP-Z@11)#-KX[_N/'_;V]B[ZK_(^
M\;VT1+Z=UT[52AQY2!URS7"O9..>N9HMZ"V&=C+0\N=D\+0,TFGFDC<JGNDU
M++C^3[VHO00FU:>D^\\>6V>/^T'6`++9ZH#=[W?[U[_^93\_/E9J60S#>.!I
M^O[C1^BL0(O>,(V^`[OLA?MH.8YN$P/41R]JR''L4KGH-9'Q:[:FV-L%)&8!
MP4^)%\Q]-87W',@OH.8D$[#2#[5?UV_D-.`"9U.%=.5[C,$_9G?U>NC[5\5J
ML`).6GU.0F./UTDP-I_'R"N,#/["S*U9+QJG'F])KSM^*-8I3NJ<]FWNFN1F
MU=#;*BZ<F%-8,Z!9-#1<]^5^W6>)#H-R<5NAZG8U$8,_.LP,S<S:E@1`8F9#
M*I]8:P;&EJ5LP?^=O?-CQUFM#M<Y_V9X_V?"YJ_I$S8@,@4'EL6_9[KEJX"]
M8*U0T;DOX&YM2?L6M_(#"T_PNJ8/"UVQ4VSAU!'V_G)EDAA"-[N]O5F[6J7]
MP68KK4H\*FJ(D45<P+V\;3QFNFX633>W=CL7DS7!KIRY>[:Z6OMYF+9O3?2,
M\DZ!3'*7+N)+<@"K[H'A/UO%>9JR-0_3ZQX\`S%E2^_/Z#GID\63S`[SLBA9
MUX*^4?!IW3W^Y[/B#PMNYXEZ*/!.T:2!28Y2$3ZF%FRX3M:JV\?/#S,S^_'C
MQSF(MCOWP6#[[>TFTIRU7Q?N)-6`96+!&K5RLWXQ1A:#M>A%O.OHT[`-EEN3
M(40/;+P._8SC4AYL,6&7MZM/PG<Y4ECP:I41HV+X;6B&?7S_;L8.`.1IS5I/
M9B3YFITCB&UJ0P>S/P>1^VK'NXTT,UT#*CUN"_>2^`F#UC$^O]1UZ/R^P76@
MB=Y96<=.K*?\F=;5J3WEBUN(D&_-IPT:'&2OR;Z[H8-Z71<G;;3H7F$R$)L:
M)>XRN^`((1=AX$W7)^.[F88\<YPOGW/1YYH.Y7GS[7Q`O$>=9&:LC>=881ZN
M=E^EQC?@_<>QNWB>/!UUXY6.U&SFHN\@<&6_A1VX]M?!Z/8#W?9R!3RW]<43
MK"\QGM.4W5(BPRMZYG@<;7KX^N7`H*UB5BEU&A2)W^#6;J?]T=$7RP5M3GF(
M8!2*VC<,G"1Y+7.:;ETUO@.@C$4"IE&LL<89&T`_MN52NK!C`2Q8R,^/S\QH
MFHLNO+RE@UW;LV?)(V5D>1".I\=GNC!9M+EQ:_62$+0F!8\,87ELW%;`N`EP
MDN"2@$!9;UV;;A3I;![:A<*(1%!$7)97YR:`5F%K%&`Z`>+(^$\0<150W4[0
M^_;V9F^W1E/6F?D>[S$TI6_O;_;!]U``M<F.JUJ;.&5+AMPV%EN77RNLS\$O
MOYP;UK.XBJ>A@17M]JH^S+R9MZ"(!%W/&1^,Y380@,$*>W#]#-/G-BZR[(33
M&FF$W1)P/L'E*:EHOMC21L-IZRPWOA$L*L\8:*]AP`6P.297[-$(3*DW]/A8
M7P/<?/W:>0!M0W2XDR47+[&>"W!0)+/'`6*Y65V`JP+?4U[K"-[:GC>T!83'
M-2BBK.DZQ&)<S#=@(B,!R=:<W`\2*S6E;K&CMHHU99L9?%?)K9>EICA_>"+>
MLC,A_53IZ*`!&-^`]Q\$=A/@PQZ`N=NC1JMDH#^EQ6:N>/WAK_*ZA=5?3BO;
MV2RX/J"/71BP[S5Y8,9B>PI>D8D6*`+JN<VU+!W'3FG=>U_CP0$DCJ&=HQ\$
MX%$PJV8\9@REAY)>-M]CPU^1J=%H2^<*#*`+*@=U'/<[!4,8M4+S0L7G4MUV
M8/W,:BVET:4?=+IU7#XO:P#-++$#->4N>T7`@9Z-D=8"O.EW[B6]FB.?@88G
MR1\B#I7$-C=Q'MVXG7"JF4QDBW80U'Y5!DG4&E>[N&HQ/AJDDL*)P%:W;I_W
M3[O=;M-7R(M%PB_[I'$B6KN9^:<,@K*ND\%GN3*!)\37-6WM!+#SO+=FUKM>
M]^N">`+82`V`D\WK5'`QH_]$6X5<;'?J1+#=9',OA[$<JRVLGSF^ZWCO\]]F
MYV4^.Y<5FQ,3V4^@WZ_TR-1?0V#UQOER_?Y\3OOL)'1U.R`0+PPS7]6V_)C;
MI=6-;&"45-1[FEN82I.8^,K"T%L8Y)L@V%/HB*P93@EMIBF(G@S9W';MCQ5(
MA.19[<A[&LL#9C"*%!K%21(K-7Y&JW71J?"A8VUT3<!N<1"9AQ.@GMT6M^2E
M[7&]'&SX]0[?@/=O\BM'--J3=OP#,)R\/LL/U.C#/<Y<-_4&;3B!`SP8/HM@
M>S215;^S^B"KW4K^F#LK,B_I/MM'Q+FT!->/(X&0J(G*S!"8E`CO9P0$W43]
M'P[1)ZO23[WC`UN"\0GO[^]VW`]B%9%`R_.$D'U5(ILH(A=D5RQS+%R\++H0
MIS!&*XV`E!,0KH!;=&V*PWW#"0)D2+\F_S/#%R"IG-LVVW[K/O608=\B>XK5
M9IW`AEBIU!:L?$-%1Z``,@Y8LOW<L$/RX,,I.D+H!L77IUU@I5$KG]ELN5?9
MGYOD%L+20:.A/6HQX_KG"@+0^P15LBM')KX-C2CLP/T*B.AZ;6,2"4Y4XJ)Y
M/X'>Z8%Z#9M1Y^,\QBD63:<006:#4.A%-XZK:9[`S`BK6-\=-L(C4<9F(^:Y
M:9#$A!DT)-J<'CL"V_UTS1@RK8XE:3B[4ET]:"]IA+N;M1&40U[B+0\X.LND
MV/\XQ/NN()W58?)@HM>N`;-QO:)BWZF@BL:UY_EH!35Q]AGX"?,!SCIR&B^%
M0L1[]3RG$*>#"=!"[*Y[L'ET#P.(NEEX4&]OAY(--#1J@95%`(M:Q.+RT:XZ
MQB[>X]+^*=:X>N(B2M8T(D3?PRGVF(D(MZH[57>XOP'O/X3A?2:?36;<J'T'
MX@#0^>!IEC@J*8#M_SUAG9>4&<@FZY%/1>3NLB?:-@$M>NIL(M*@J>_IW]U#
M'OR$KLJ:5!/R5A4@M*(,DV]FGYJ?R61XK;1YX($+$>MO*7;W_<`15E`"#S7,
M!<[=WM_>[>A'[4\;SS>MJ!XWX$T7P]D*UA<_8+0IFN=[6CORL$<#'-(*]J%G
M<[)IXX)&4\YV-[^W1K*9!3*J//G88O>`CI#@HJUI\$"E5:W?H='#+&):BH=U
M7Z"W8KI%R!P>NO%9+<Q`M]9F,E5Z%&?Z426YL!7AZEYJO5<!%=:RCCI7H[+^
MF]?&ERQB`/?F^1R8B13)P_J8,B),0QI<+-\""!?:WA,SATTMCQZ3)$<;WBV*
M"O;[#*UQ;0R7M0F"ICQC2B0\R"?6]YH6;1Z+HY.)'QT%1*UH.*?GV@-->>-6
M^@5^)?D,Q!BF<)EF*]K@ZEP@@BUN"[6E1[<L&8RH:@#JI:?%<III>>UGSUXP
MBNO]&DC+VT9/7:EUW3O/8WA<_R-3K,-<0)@Q<-KQ21,]7Q]8!S=FH+/(7CM]
M+=YUV8;/U"G("Z"!+3I:KC*2_'9]QC?@_8?)&3:J@KQ8;+=U34C*$X[U>NC!
M2Y#3I.S!,=GCYMS#?_"J#5M@2M^1E]S7@+@";MC?S,9D]ILTOH4T]:6I*?*/
M5*>`-?5<G2/9:"F9"-M'WQ](1*IJV$GO:ZDM&6OT6VMF0\Y0,):/;JPYL#(W
M`$\Y!^<BVB;+TU$Q^A[8^59W(+``BVX`@[#C`VW:Q0P,\/34GW8XY+<1TJ>B
MMJZ*ZN5_'QZCIRZ:SX1:PCGKM#E0`-K2=JO="+P:\I%BP45W&\%6]O_-0Y%R
MS*Z=!S<OF78&_F]O;^E<17G.VI3;U+R/PK23Z?\)8$$$G2?'8'Y>AI9898M>
MIQV&^WQ\+@JT*BZI4*YK;<Q]#:53O'(/:\UD#@44^'R/M.AXR^X=8\9@>@KG
M@4.6VXR_;ZV5>]=B<1NYQA1MYN+T5=]%B(M+5\WKNP?)%T*EL8!8%\IW%G_6
MPCJ,R=:F&-Z-A[633A24L+=>X]EEKV,RJ.VZ=\5)Q9ND;,+V&O11\,S!N1#.
M$X=*D5MR.65.UJ4%C.>/@F5\FA98"YHR(X+"N83W0^VNKN/(WKOK?''W$>%G
M[#M:^.\C9W@5]+X$+!_0P;'#_2S5+;60[;F.$B]^C\<_BU!!9E"_E5B4G#8V
MHH;=-<D64?.!]SW.QRO7SA\SM]BB17*5\$K!M1MBBD-*/+F>6:#<AJV_U=OM
M[5J\>V8X71<U/C8!3;Q8(MZ3"^;'\S>]*2N0%<YSIX6369)>%#/CA>W:(B7E
M)PV/,0@.$J*-Y5,9X6I!8$.L%JB%BL[V7QJ(<0X?.@5W(+3RP[T8==WDGK#T
M@Y;C8PL]\+A?V[#0LJ@S'\U[ZC$3N)ELZFA;FMNM-7M_?R>F<0W#`3D/SIO;
M<;\:[,3"]^L'NEBBY>SLR>Y>%^/>%WAV]Y3L)JQH[*:YS\2WUAJ%3&B!T@LM
MZ63$!T8M]/CC=6SGA$NB8>C"YAL(A!`S*C[)PL3YQ8XM%>4<)L3B=3L4@'#3
M`]3!<_G.\34:A3X_?T-K#Q`-2+^/P&&CH4B_EK:FLBYR)QC#@\DN:P(NI*&Q
MR>32,7:2+W6.!H<@R/FSWEQD!8>I4XG*XC2>FKMR_`R#!I8YUCK7:,%!9_0K
M_=G>5.Q6J%D1N'I!+W>-0/L7V]SR1M>H=996.C;^WP+V3>ZQL<U]`]Y_",/[
M#%UFC<VF=84:M4;0^TSJN?W7%Q#O*XPR]5++5\7AC/V1>8K'2E/RT6[L5<2>
MJ9(GKZDUN1!VJ#^,GK7`[C(SB-C\C@MYF1KEMIO=*L;ZEG:U-6NW9OTXYL1Y
M6C$WVO`XMULNJ%RM>PX;$"NR72T!;:'[`V).Y2I,@GMM+>(JM-DQMM'WM8JJ
M]=#,8\F$QPA:JUM\#M5)+S4'M"T96[$"?(CCOC2&Z+U@0&.:DZ4B@@L!?H+[
M)AC%R`?8W>WWWW^?+"+?#SOIR_B.PQJP7:RRVJ+Y!(<@_6%,[V(;HW0ON0GH
M7O(,O?N&%(#G#RAA808S,'B=H-QMZJ@K<F2JNBYSU#$X-L!RMW"9XN"K9^`"
M6P-NTU$"KJX*SM$"2V\_[;^,6^M(#"@*4"-G6L@7;7]7^R1HN&H-TZF-WAJN
MO-AK!*]M)W`;?HU@#B=G!D<M,V%/9<#HV%?_8VU%L;@<(*ZM`C($^;!L`)7\
MT(L`$(_1[=G.#KYD@APNXV%OX0?`I>C.W:]4%%);3(2$T7CFA6V4W6=TU<P;
M34PT]6\?WG\&V`US_)J_;L\8SL"%O(!D<_.AR".7YGY,-7L-JY=XL_@'O,#`
M/GI_61Y>3+]*Q_:B4B&[U4/9"`((<4+X3":[/WG8B_;AAG5.0!LU,8ZMCS+$
M-Y1/[.W6SK2XXS`+:75.FE]'&&@4,%G;_+K'-"(>^O"PB7O)VZM%*X$^CG25
M`@A:1T"WJSC0%JWXRL<JFI(R`(Y2`GX^"XVJSY-)&ZX;R2G66#VJVLA"NI+K
M?>A1PL!!"I8C9BT&4X2(W3XB8R_KHG;]3',%)EP(#,>/]_?WTYTAW`\J.2B\
M;KW9K=WFEHK>BZ&N\_QT7@[INS7^K'@MZ=I[+&*`8?!GT\#A_--Z\B\&NZ-;
MOX;`!JC$8+I#M\6*M;BYI>L8@ESS(NEN58Q-=%*006;7XV:)@T=P,S3@1"RW
MH'?7UOH2<O"LXCF(%EN*GHO;>7^N-4Z'FM@-XCP/-P]:9I+JR;WOZP&;X!S%
M=H$H+3`9<M4(7!>+073,Y\/F`%MV<VF6U[W<L,]WBKM^S^@FK!TV)\,$<KP8
M`%ZD='FPT+2LHS`CA*Q0*_I\ZI&<;?"H:!]/5+@8;AJ])]K=P`I^`][_\J]7
MY0ROL+M[UI);*^*0DI[BEZ.(92M]$7D6'\(1HT;9[*_0P?Y*`E-JXA#*BK&.
MT$E:]8FTIUH.);^TU!1.S,]-_?[Y:0>P'Z0J=,K\;S<:C+)D?+ZJ\-VQULPX
M,GWN+O6"P:S=;H;>3__=Q+XA%RU%C>%%A2\._"1W&,P,\264[9ZE'%UR*`>;
M85-/*O90U*YV9GZN(1CV-H48\_JTH0)O`+)8A\%$+24(-(UC1KYOQ8)IM;79
MHDQ?'T0]T/O0Z=D'U+9++)]\!2RTFQOGJ2B6"GI@TA1/P$"QJ>XN#AX\V/[^
M_GY&"Y?3UH_^[O3`?KLUN[4SMONXKX0H#/NR"SRT`331:3!2[;+&HX"'(2RG
M'*)=*-?=9<5Q`M)K7W8QXH^=I\&V=@)V')C`Q^&;J83):+O9K8`='*CB#G$;
MX?9PU;WP;8`'4D'_*,W.:$YB`&VO2)I54PE-[`_:\.-\M697X6/G(%H8NN5[
MBK6T(NLQ`M`$JICY;>3"L&SJ0C(.#4P.]GCZ=R<'DK6N-*=B1FS%*(XZ]N4&
M@^YT)*Y;8-TM@7:[4,Q<1S+%,Z%C'6D8U8DQ%O>G:D^_I!^QP$P%CT7=M@)E
M;VJ/^0UX_^8,[[:YO4W6LBRZ#9L9MY_]R7'X%D!^D2I^F!@!U9N%`;EGG_F2
M`L%+5VIE`D,1X9(4$P:J+9[>P@F!4"(/M;76YJ97;^"^*6QT0VFW6UJ@#+!H
M[I)`.7U>:VYO;\NLW_7_22MO?$Z[-;O=FGU^WG6".FP.J&RXBF*/C?'AM&P6
MVL"IU!L_=Z7[M,@@I.$QO6C.H+8X1Z<^N(KO=;4PH_9T],ELSGZY(YC`DOW6
M^,`6VGHH0BI.\.B6"3:WVS6=7-_S,&LM^"XO4#0\0UO3=N`TPX^%60H.0;SE
MR_AG_F;3_JR=0/G';[_9V]O;P_4Q=PK.M6+D-/B56C5]@0?:!<QOOG[/Z7%D
MD8>B*/`PS<^LOSAY-&J?MDL%"P4OMS8*!^0.`EF3`MWH<*<[L0RINHLDP5EJ
MPY>CF=AQK:2MZWYINNXX^:N./+0R^5#:YBR)6+*-',!0A!VY;SIV50PT5.;C
M&\#/!7,;9[^7+(D0!0.\=9/4.F:W+8%'#Z$.5*A?I(0/ZE\TU_6Z+.O\%=6V
MO@X,4Y?L[$.GFZT/H+R"BMPK'8!.5X@5I&]D`SORRHN6EZO\QW.[*`SCJ1QE
MW7K8)B7"<Z?N7`O:M-6S;PWOWY[[W</=ISD1*(>6MNH&X(5/?@XPL8MN?Q&5
M8O,%O=05>`(O.RVO%^Q&Y:E;.D1P`%)T9A)%![C/LXS=&8@2L\/3]KE-CNG%
MZ13K//1C[F9OM]NU,;K2S^S_B'W1,A::'S]^G,$1QV'WXUCF\@$,PF!O[<W>
MW]_'_,5IG\;$A7OF)Q\44HG;FNUA6U/F(0Q$AH>@<]0^%DK+L;P#&8Q7=.L7
MB&>OWZQ5YIR"%<.9"[K9C<:R(#/W9:-&4^/\VG:]<#$Y9FR#!P1W@NN+MC`]
M7@WK\>D32S\._7"6.R`77W3NQ_'U47JXML)3U\4@H%1`&;-@,/OQVX\+[.)A
M)V=$KB)\1A_@M#5#/X(V&?,^94"[V%44':/A,-'7'2J;M8N3107*?0R178-W
M8WAN13+K7=?%MW>-_3LWBWU%L<ITO(5`+:FG0RB-`+SH*((@55-:4%;@IBWG
M;KGP'S\S?)'=W)8T.R0_<L<!ZJ@R_MN:GU[!;4?MJOP%E/\^GI,V[.Z&QAN%
MU*Q=?L(.&=SEX2]0RW]8-L>5K5^^Q;,8+YEOB091W7#);W7SFT^_9)M%*\L_
M?&F\6TFARG5-G8&)5DUG00JO]133S@0,?R9G3[@G=X<I4/#PCL&'G-_?W;=`
MG+O8^&9X_\[L[@LR`7P5E,86&@V98.=G\$C.4)"T52K5D^-[V;8W\;'CIL<+
MZ5OQ3UZ\[Q,?9`)/I4_Q&-S"AGT.#V;O/0#L30"!M-/65/+)[J'P!H$``"``
M241!5%8L/MEMD;XPHKCA^3M^W6XW.XZNIN0D,?&Q:5TM_L_[?=D.-=_J@Q^1
M_NN]EW;-_;0AL[X\7+-4W,,FOIA*_A0I4CS;X&!SPA$=+1A@1"VQ:50SKO/!
M6EWVG!9K,3%QOP;$FA=?&`]\F76PS:_4K8H23==G:(`?-XU2/'*#=DXZND7/
MS1B.@42\@XHD7)K=(K'*8W&*<EU;UZ)?0Y1]_?2P8^*A(5.'FFD#)UWHJ#UT
M(N;S0&+ON`H8'@JR%3%\;=X1<+O4PQYD.E1`P^9P6_SL&-<<(WFW]PPX=*/+
ML%64K>3WWU,+\3EDYPPD/\FVY%?4&9CG>A(%5Q#&S4-+&X7D@M868?)Q#5:2
M_(`Z31!0:N5@FP0Q-==Y`K$&5#89S$B*G*LI%N!8\>8IH0[,'@?&%+)/D)?Q
M8$P+<LNX:^0L!QN=KA#A;/F\^-:(7_P59K(>[/$\21R^E0(7#+91-HNY@.?[
MXQOP_M?`KFT7B%<)8,?K!&H"5B\RNT\L)U/AB!+9[(_SY>-.J6%(?"W\U3?.
ML;#[,B%('*S^G@#L?O_,^C=D[]*C]ZN]QM5H-(JQR?*N36T]S/?[_91&;(9<
MQH9U>WL[!VH(8(]C//IA_:/;V]N;M=9.T,OL&&+N#6:+Z#CN)`-9+;B^JS9F
ML1`M,<B#ET`8/+`;D4*$EUZ\TK'WO5B9M996.!7(-2L&O-(0$'N7CL4:R'<6
MZUZI1:MR&226UP)(Y>0V`,&[6*-)JQM:&IE>@2`/;*7)AKG\B[MH@$M06L1<
M.]E%N9E]_/QIO__^>^D/+4F+P4D#H;#I'7;__%3PS45;<<TDJ,04*.Y<RJMD
MS':UK$^F^?+)%:;+9"A,O%6=/7'S5@!A_I>K0\W,6P@6L3+:6\%K3TE7",,4
MO/X.IXO8+XO2%WX-#X"))C=:?Z%FW/D]UC%U`8GS^0%II<=YH/0]!D?PP#"2
M[_'2VJJYU^S(H)`/!<-A\'H#Y%`0/!E2D6D\DW12ASYU1712`.Y6%"3KNXGA
M2)@VGEIW#_,:GHDP=P_^TW1T44I2/6$T-](E,MASB37/J9//<G;CA7U+&OZ;
MD#>TC+X"_^R9E/<E=K7`'B]2QB_RL@]<R_PKQ[X1$%6ABSO`G64/V/1_GS/%
M^?B)7=ED,\?)6$2W"$![,7$3IM\?U_10/WHZS6ZNH6:7%V5K;OTX)B@#N8A_
M?GY::[?@3YH5I!-`X?SLP9Y@P[SI8'](_M)Q>T8;BU&(WXT'/'=6:B'F&N"I
M88WTY%8U$%PFN@)1!8K0R>$J;(*N\<X&;[`5RX9IM2&!V$#-+A%IX)48>="$
M-+?..?K7=^?6?-.B+VS'QF<,5ILFTIG9E2``;W9,L'9^RX_/3WM[?[]D#5Z"
MRE;DZSK=EY^?G_;Q\5.`5@4F=-U88&@`<1WB@X`N3[K[];TM2B):$:1@P=*L
M$YBH+"5#E'-DIW>KJ01VM*KP%/I>$^\\!+%L(L;$*NL"O\,W>;@\2-D0W#DJ
MA\QH;&*&XM[T!=+3<A_3!S'#-&*,\8P=[[UHK5MVI@@>OG(/0HP%5Y2OF<J/
M@E]<&KS:[9'0O<'%%F+=ARVFHH;HW[/H"VO"SI?25![I"#'S<]B<0>Y8]\*S
MYIYB[GFM=-OXXT\GFO4BV5,X^"-%>2OS[-^`][_WZY?=&?X"F+T#I%N\YP&+
M?95`_;.@U[^&LY_3R?Z%X_;23[:2)^_RS#T`;;7ZJD]JBJ\-UG`;7*T/N[G=
M/S\?LNKC/0=C*V#*\M[;C^/R"T5!G++GH88V\[!?8J5=NPX>04U:D-VVHAWN
M?#B>WH/S>(F!X0V$SX<%YB/Z8:(*<S#5XJWW==(&7AGWDHY52P1XH^T\#&(<
M`;P8XM5^5;`E&E?Z_7`RB"$8;B[%@PR-0#A(T:^;J8<K+LLRUD&.8_CX^#C]
MG9L2`7M7`)OG[3@.^^.//Z28D_N\]TT78-V#(ZJV<A@0H&D5Z-70@$>+*+>P
M/5".PC:B3I?CP`E!`=@L9]BLXQZNIUL.I4!P&X"I$\<T*XG^TGFM39KZ!X3F
M9/\I`M=LI-A=T;&NG17W;``IC1[3F0F<;UCV^_QQK^^$C:0S7J`0,G`UGROT
MTI+R_$\7]A)$@3MR8$:T/E2'!\S(8@.2_:.Y38>2G?C``VBV$GS7>\YHN;!L
M(;:H9!`PK&&QS&>O9;"G=_0#YR`1TR*1NP_?@/>_Q>]^-5GMA8W[913XA1=H
MS",>88B7`2JV3.E+E<+7S'Y1L[W/?![$7]`7V'QTO`">_)UOVXH5T\Z=/B]<
M*X)S/MDKA4V:0+6;I[9TNA8D*HPRD?L`O"$6U<34O%A*L2\2%H'19PL8R*4#
MGJ25>-`)"OM&P,FC11I<V6&^[AP5ZLJT(2SL,IP&"-.9&%G'0Q"G1<(C2Q9M
MJ7)[DJV,=BEO_'N@L#2SZ/V]AL_4.'_]3`^QS7IWH`2[9F,(\@0SK7EHRR-)
M2R;8[=W^]<<?=O1^I=&A9(CED8EF*#3L$U_K5W3QC-8-H;-`9I0DIMNS=CUN
M[8CN`Q:D-".=K?>'/NQ\SEL*$UKZ<P[,6.WQ.NXUKB%K&[E^MM=QV;%HEX1@
MGJ-^&/H3_+5#:QNID"1G!1$Y$'#L2(!H:;T5D#U:TTMY=%PS32.V\[E=+:3X
M]\G^W(N9D,1^0];X$-!&X-!2M/98]_NPZCO[*EMRKD]R(A?EJ?,DP!MR/Z0]
ME3N@0CQ`],TZG@)=L8027AV^;\#[=V:![47+K2^]IS\>@"D:5S7A^03-_B()
M^XAX)8[$MG&'L?6[B0OW8,\6BP%X]`M<>M#'\H:X>->2%;Q`E^/![]W""AA;
M8APO2AVQ:NC.(L0A]+<V2->!$PO>QNE>>2W4P\)2S79QB3$-,:7,?)\_W^<7
M=$N9FJ86PZ$Z*$YE)U";I";7B_INMX8&1P@C*YN]T^:&=!_G6A6)A0(Q2U9=
MYP>;-I)%$.1U4ZY2%"`<V8OHR@<LX`M<EE41_KH,[U4`MV*BN9`#3LWN<1R2
M"H>B38H';9K*`DXW[\?IAQ'\5-*;\<R/M87A6.76$N\?,Y4,>)QT#Q$J<9AK
M_E[N/T@"H!2'83H_:K69\95BLZ,N-DP=*&,H1E+GE(SK<G_A`;M\OZSY!WU=
M%]O$)$P#2H97'21@(:VX'C8VCG[&@VY5]K7N)/F9YXBU^C0G$)#_Z2S!U\!J
M!XE'`XWS''4\'PBG<!P$/?D0BWAQ+=+<3RI.D8?_XEX?)F[74+"&@HS-\!OP
M_IU9X+^6VJ5A*'^X&7I@S6J0O-D`GMCSXB\]%YX>YPQ\B8<4YRY/'HO,I&1)
MP0)*LM$%()`'C7);+E7LH9<3G24`U*"=V:K=^0H61=*^#J`@4RVN#@"4PJ-#
M4W5KDAW;XN5R9),XE]C*G>PGQ+[.-2\,*R3W.9?69L@=MEV8?&(8$6,W"S8:
MCUL!:_!HA"'P!DV@",LZJ0)C42,]W0!2BI]KJQ]Q&*W3/<'%!@&#`)*LL?ZT
MS8O<8Y[2!6C'X,G04T87@>2<8"91LUM[.W<[CEYV?Q"*I9B8Q[K"ZAGE^\.O
MAXC![[#).J^ASS_'`E.TKF&H9H+@:.$&[,$Y4':/=EZN::BLNI<ZTB"F>&#S
M,^;!J]AJ;?E.BJ)%9UF7ZB,TA^F:66'?I<!Q2!],6-SX;$=FN'+4]`#$LJ)^
M,+&N&3T8KK]X(<P3BW:U1M^KY?->=#DL#'$9:LTY)Z%)0;7K;5[#Q&Q_MR-Z
M%IA%7)W7\FIZ047S[,4>R_>X.$"M]DQ/GY3CT\_U;-SSWX#WOP-D_R(YPU=Q
M;Y4#@31!('`WMT&?@.FO6*6]>NS:#C03CZ'@%:@L4ZST$08P*L]:%VNOIR.%
M5&7+K)DS@U>?+1$6I)66EE;GW'@Z3L?&!0.I_*YRW[?*$X\)-RYM,3E7P2\V
M,UP:2XIX>'$[\AB&XA2,%R;(Q2%B<5QSD7?5&?("FMK9EIG%ISK[G3U@#(Z(
M,<I.&Z7%UASI8!W35J`RV3=B\=&7R7V:$G\0WM`%6('6A)2OO%[?5EMX7`-4
M/0@L$0-[K19?(S]3%5!"9$L?L4\NK!-"0>3B.G`-*;8JN<D7&"[`1`K!T-DJ
M8729]=.BR94!+A[JUMIDTQ^OP*K+C5/MD?A81(4_I!-<&.(19@#QCQ;_U*1K
M'M<#A265%DEI3X'1.J`&V<.K?+?6EA*)#0I]O(>=9[6CV).&>X:9>`.XU^6(
M?`Z"/W8@3G:8X=&Z!%ON$I'MEZ.G>8)JGQ8=;H%ALI<PD1!AYJ1RP8`4-]@P
M9S;=?;PH;%:'J)BSD;<\S_,WX/VW__H%*O;5]QWF[5^0Y6Y!IWNJLK*:STJ+
M!^Q:AG\1J*^^=NR0>!#*221K`3ZY\@?B1*Z)Y^K3]CQK0SU;\5AD*]WS`)V`
M(<V,R7*"'&"0#1_6UN*9DTCHQZ7XN<YIR^P^JG'BHCV6VG%FB2EP]_(>C`OI
MVM]V&?+7QMN:`/05%1VLGX(7M0LP]QKT%K9#?CE*O'RO0ZV94K1R&`"*LLE4
ME(;8YCEMOMD<G<";DV<>DE9N,V`T"B^XW'<2QUUD22<I`JST4&7[*/.6[*V`
MTW^V]]-KMUW:VG9K9I_DQ:PC\U=[MT6>:VFT+_]9CAZ6[^O1US-WAQ(`@,H%
MLJYQV99Q&(T5S##,Q)-ZA=F8#&NM8=BHG\?EPZJLKP5-[;POO![4]<LO=P6Q
M4!0\ED<X%T`=4>)`.GBM1`L@ZFG`%L7Z4$F`U.]Y3?$+"XH<IL$V=QUQE2&G
MDY#[&?7_=0<&8SYM)32&D`875M=?)LM`G\'NW2Z#7Q=P#(-^3"`X[7T[<;5?
MR2'+92'#`CBV[2A)XBSLU,3Y1CW2YO?K1;A6W#_G/3,`]7?2VG^$S_UKW\K_
MW/MZT4)Z?.385\H%$Q"34G[Y4-U#A"_J7/<`&A?84>V48GH_/3-GVZ.O.%(H
MHZDB6-//B9?&(YX->E0/NM*D68P%./GL7I/M0#%`8I'4\Z+)&71H16OXU0O&
M+?D%!E*^L+3`YX2MV'G99/V:>V*(DX5:\`[ED]4N4#%B:N/%66$$NG$T\NKD
M5OL,4P@;L=//\J*[*P1JQLE'RJ@"NH(N]O0LL`XQIKC5GQ?;HB4#%HHD,=N,
MG87-0*&[E>W/9TQYU3Z>R.`ZIOO];I\?'W:_W^D\G($I[^_ON44+?8[.>@!S
M&"[=YN+MRM<ZLVY16UR>5X,4""GTA+M"DZEGEY`FSA*S,#&GWZ=#3ZPS)V8M
MIEH9Z'%[SVC@8M!M>R^3G(6'I3P5%B"@<Z7E(3LR>K)F0V`&O4H#3WN.AR3"
M<X`OMBK"O7`5U9Y;-8NT][`7)7E0/'<1P&,F'(^@DQ&Q/:V^+A<*!;XU_XP"
ME/(`WOHWTHQW[9S%J8%6;`,"]CM6#'I'*,*HXU94`,+OR_D.%FVQ\Q0ZKK&0
M\&)04.Z%Z]^_`>]_&OZ^Z##PD!<N;\2O))8]?BWB*OK"._N?."?N]3LL7S^E
M=-U-AILB4[J8GC!!/6--EY?C^8`W.ZR'!*Q=2RQCWDO2*-HT5^$L`9,:9"KS
M=H$B'\#<S;NOP(HZ(=EF[&II^>/+BY*TI[.X*.C&Z*\+GF)VLN0)KVUSJOT<
M:NJ]RT#1\+^<C&S\?)R1G`PFYG!4D=T^[@<!K^9BONP&ZX<9O$L;;[:X/=@"
M"=73I0AJOB:7&QV;O';3FA1_X%A+H0HBL"(=R:?FD@L(E.U&9.;:X@1_]OA5
M\_ZP=KG6-0RL![C(ZPCK*[O>E_3=CN/0P44[?:(_/S^O>%J2^)C;_;C;_;@+
M@SHCNZN`@KFU^V*FX1+\(MMF$*)/D<:MZ3WMG%RI[@K'E5"HO?!U_9"")"YF
M-R3"(WA2I4$[8'JL#K_C.DT(RK+W)3Z5V:?-$"J&Q99K:YSUEP"2A_!DB=$O
MT.OBNC#T['/XU%CO;:;3]P4SR8RVW,_19*MHS;NER=Z9[.:I:<!)\<$Y`<'K
M7>4J`U&R^PD_5Y,Y]B!W&?M2;+T@;7_SNZ98D!&9?*+>N9:Q#`.@*%])'3P_
M^S`DZ0[;00K,+,<BEN;9"H8VD6F^#"XU$<XE,*@NG0G\7E_F&_#^5X"N?YWZ
MK`WSONHR]AI(!=ODX"&0"IDK]0&13&D7#*KL7O2G#""'VGT=*^IS&G(WFUZ@
M:IQ%N>D;?53VY[0'MIH>!0820[JT;6[>CX*9\*`;[('!7""U7=Z=1RQV8&(>
M/S1MJ-AP`D9],ZSH=,P6`BIF^]6S[I47/V]MA00XL5B44M9:LUMKUU"$LKKQ
MF"<3W[L8U\^SV!:[:U<+%;:8,A]L>3-K!NN]$0"J]8ZL=9X1EWY]M]OYW=[\
MS8[[<6Y@XO_*]CSJA+"&I-K\R>2O"B2YQ;P615RI&SM`U#ZY&ES@:=A1@)_7
MZ\%XM!N!HSRPZ*(!K-9`=AI@V<CGY]WN]_O\F314.<`05#MIKLX-XK5*@*71
M8)^%"%,K-V$J,)P=!3PYF0C+&>12K5%+G1H]SL-2,JBTSO6N%0?3P)?H;5VQ
M?(!VSV)[2/)?+-H91OWL<B`8!6-'OT!/;4<695P@X`VH1W7TJA5FGGZ-O^^L
MC:>5V"_]Y[I?:L>2%`["P#-TV&<=;`SZ-$1D%;60+L.ZYRR%FS1OY]K%;D#1
M"8/N@.2:87N[3=;Z<^=#AI&]ZMB:#(].QKRM>Q535NFBW?60>#'#/EB^]63H
MFN4(NFVKM[L)485$'HTS]PUX_T._?",0?P1'O1@V^K.4JA?T*OO<H:I^'QJI
MVW/YP@-$/O893KQRQ_*PW'PD*%$*(<FL==/IU=)3LD]HNB:O42?*24*8K>;.
M=>XZ[R8DYNHAHC2VO`;;/-@=0)LQ0+?>W<A])[0*(_,2FSDF"U1R%TB2#!<F
MN!]]#OR`-A#6@G9T,9\?$_QC96O6#(V-_TG7V%9_`8#ATF8N1GH=\^UVNX[]
MD'\W5Z9J,"9+/WENBCYE+"H)X/OCO`8<G5JUQWTE-`%FMY-T[T=?[<A^2B*$
M(+8>VLU(K*J&(&3WC%'L86-0G*4#6<"TCJF;#@2&5C!9CL7"ND,W]KTM'\JB
MBPN?^?93@G2]]CC6/6G::N?C</)?8Z@S;*LXX0OBH6S)BBN7\`3JFB=F]:R9
MKG_S\6<KV\_5>C;?WT&*5M\OLY6/*Q8S*$7;5?A+H(3MV_[L61V98[F.+:;%
M>6+5H^]L=>SB(K%Q%-%B5_6FR0+,Z\UHR1BRAW,9%4^_^J8XM`OLBJL/[Q.!
MM#AE+2'@)A1FPV.9R05<G2F_Y!C)1@VV9WJC4Y"II_QZKM0=IB6;#I42M-BU
M#-T*:RX2GGR"G;I.MHD2=ST.+5&IZ#C_MAG7JY#ZM;,W]C?@_8_#WI>)W&S&
M_!4JV+>^DHJV(HM3;5I%NLN+>%:>P4>EW&76[0Q^:CG>:D^0T?3H(@X2IIN5
M=E&LFVO,E(`V?8J0M=$*+J(^IV$[(,=2#1"Z&&^[#K-,0_L8OG:R%K##&EH8
M5$H(W#@+/9TYSXQ;G)1VEF,0.#Z.+EICG\-$/N45,DC@;D<_)DLWI`9]NEDL
MMI1U;P/L\N:W9-8N0'FP8=Y\ZM\FV.U(*50=9K?!$(PH48\,DQ8\O/F/\W4+
M$HSSGCW#/)V9V6;F(`TFL\5!2J&;*))DO(<!.G$QBFR(Y4(OZ0A=+;EF["JY
M8*RYIY"VYYYZ.@B<4!50,%*BYK4:H79=^?#@$9\"5.*$MYNO8M.I".WSFRC_
M"1VTX8I;=)C=EAU3:,8MKU9HET-TD=18#D.**N%7^53SMH;33&.@K=!X"YOF
MA0L$5,HEIRH.%DW'A9:&EBJ6V#<%#G]NM4%$V4P,VY#B!02R0>.W'CLF7K)Z
MVB[7U6XPPQ&<&G1P43L&GACG\V6\9N5KF&1`QL.>ZB*R7A/7@L+6C7?8P23#
MRI]6YG^X+W2Y0"[Z]8!%JECMP:Q>'1N_9F?,=$A0_!6H2/9X0\E0K\O`MX6?
MKSR$ART@RW];^+EOP/L?E30\'@Q*D:\E<K1MKSTTLI/?H8R*5RU+>U0EOQ`G
M_(#@E>$;I/7HA0$Z3(%[##S8:8!WSL&CVH9\=Q3LP;6XQAD>6@RABOQK$U$M
M%VU%(?I0+;<L^&_BPI3=NS!,<U/="/5C*Y*E$=',/K.\RWHH@:<!=B]0,5AI
MA,2X?OFB#JG!<'PP1,"RBH;C`KW47U]R`I:/7*"SM3;##/P"F79HF]<\%'Z5
MSRH;T(/NKD)^8I>^C=E0]URB1H#`@,V+029N^U9A`BBC"6DP1'Q<,R!:[)W&
ME$8)Q&)_%H,RNQ1!>+SLA#ST=37ZULGZKQ?`5<,G($XJE1>VR!!F_1>\JM'U
M._*UX.>2/ZL'H(V\'FB[W>2^T<'`2!A0=R?)T%R&,C4(1<$N)SZJ'*,(HE`Q
MKC!=P@2>(I^IDYP`$M`]9+>FT[8"\V"`T+3[<!$"HZLN=GSF8@7)]PWWM\\.
M4K-XHJ--'$I])Y]SOO\Y!*4>0I2U`B;#?X,L:79UO+AHNQQ`.`Q'DO2&E(@E
M#*4TI6:V$0#ZB6?+\2X!QUP$L9;8A=%6/0<JP%D.I&(OKRC6?]8X2,+ED`-%
M]BUUO7Q%.A,Y@L(`_AOP_L?`[FO,[HZ,!52ON1=!A#6-[<6JU^()2'V"9K''
MWPF,\2*&3$#FBA79^`SV6*"^@(ZE!VP/I)%K`9EXADR%1IJTFJXO6]27QC@.
MR/3!$L,*+14!8.C4_<XX8VD.5V;ZVCF0TM+<LO<R2SU`8-BF0\%!`"*FKYWM
MW0;8;>AH'6;>!93`V\4R]K2@SL5OG!<KK'+BI+&/Q7Q)'1K)(LZIXB[G,@(.
M]O[5)TF]B9<]TV#I^V*O;Z=G:@/LF)(/EEVD=5@W`'-Q]=`P!M)BPS+(ALJ%
M],90<!1;H]&\8$6'9B8P#;J%SU;PU>?!L#0F@DDO!NG2[4W'T@NOY-/2S*7E
MZ@)^E7&;GL*NLJ`E6^*B*.(L".@P\Q!0$(B((OJ-0?W._L^MN'<6Y;6*[SB9
M3T""A%69_;\`V5K2U/ZK,/'3\\X^7FYIH(UE,*J?#K=-91.&Q=+-#@A0Q31.
MZ58=>A&+=Y;/Z;7TN#;&XK>1UM@6>&^4O.B3K7<]7-=[<#@2>)#WB#X7V1-I
M>2FO>80I^V!FI]#%`$(*3^)F=I+@:K,&DT%,0^XPR)H#VO.L2"5*_N`D.0E!
M2?&UL@]3(51Y9:_.V'K_;\#[=P#$+_S`Z\K?O^:S_2'[7'S.*QG(6]W5(P;Y
M\1&Z*[N4<NM+IO=:K$(JXV21TYY!PWLT:#:'94HCXDW>I)E88"F(V,A)`FBO
M;,E"K]F2<;=8^JRI==D`F^>A*-;##J8X!!Z4EVQ*/3`MQ[AUS@X$K+LU6VTQ
MT%3N^DZK%0D?C@EFQW'IE&?B55N:UTY,<N_G-#CJ$(K%G+HD\BV2$]D><BS&
M8YA#;,Y<@1J#3MDP8O<'PM!6!70Y@,/`>3/D9J%%N=+"0G2J+39_2O3:V-0K
MZRJ_G`+Z5>0TZJCD>_NQF7Z0IB"D2Y5@]P(\O'G30$YL[YNK51FSA.I1BF"]
M5VW6@7WU_0*TK*E<&=R-!1@_+^W2^QL70.:K'<0=B&$;%IET'B@J-'0^!%_9
MSG>"30:&G8:1U`7&9*#0@UL&KX<6(G+Y6JO,J85[&7-`N6*X*PLY]RH1,P[E
M:9=T.#8T][1_C<>A.T+19#+P)V$<LJ]?`W^S`"GL)"/DI:[C9,:][&=*IV%%
M^L)XDJ,*F!(;3-HON2.5'VPGMXDHPPNVA=/:D9[G]+P0`8$4GJE[+Z#GV[*#
M0_N&FW\-</S/`>,O:@'^U'=R>MR]?!_?MC!^`6G#-E6MWO@\.+583`49T^[H
M0;8C,R^(YY.&M_B_TTYK6/ZXB5&]?#W6IXWW:1Z&PTSUN<G"!6%/TM:7,\M@
M7CA06*%B*7W+M!D/5"$Y)'WP`L!D[V:Q#D/ATSHGOKF1L*8_LH?LVACY=`VP
MZ][L=KN=?[XLW88UU'$<EZX6=>`!*JF#.@_P,?C.YBAV5PJ)B`(9#T$H&F;@
M5J<NS0*%OL,\UNC+"V7M^#LC`MCA;#'9$TUFBQV!)?E`YL2GM$%9>;>LKRN?
M312)CQ([NH)5O/DU+(@@MX!.X@]]]OA.O2<`'0'N^+P<<[R\BQN[#W0H`TH^
MT.+G.AG^!:X:^6^O[Z\M8/33$4%-_UL1HG#)J)Q;ZKOU%MH)]SUA4:5P0<)(
M,NLPU\'"2[?<?5H3V=/\?:?S"+=:KTO1TLVG#$)G!Z)EH&_N1"RICX7K>MW'
MK,_F^_>4774E:#S/1GM(24I#?<+&NMZ/%O8L86+S\58[-DBF`8_S+VN7[Z;:
M>AKW/O_-U^?U:WWKH'-H=9PT/\]Q7TG%+[/Z$IYC">1+VQ3?26N_SKK^-T"X
M[V0,^&6$&Y.%8[NX\NC\M?-41%PF#\4%BE!0#.YL[P*-8;T6TQ;9WC`)FB:E
M40RDF5^66>UR8>@33'*PP6C5=SRPSW`:]&K-VAQD\B1/J=JZ(?QLSO?*!(1Y
MWL!,I0%`(%$"\^)\[FD8+^]UA0!X.XOHPF;$=B]@&4"$P:46-H7>.07/4HJ;
M@+G+=6$`W0[0<2#9PKWDO^QZKJN6'<1W.;#B%V#L%]C1UFM?P+@CS(JY#,<\
M7*^XJ.!)ZZH-'<X=TD70_J=,X3/[1[[`.9RBCHVM!F%XK8G#4WDF`=0N1SJ7
M3NRFRSENI/"!2$K82Y:M`:NH:8XI9O]DM^4?'N]M>'8(Z/*>'I(D6+.LYR6N
M`_+Y_-P@=HFX#>;9TLZ+CC@R>.4.\HC=]2&#0J1)D!*Y%A.-S3W@>DVHT%6+
M/BV(O37KIB$,\YB@LQM5K#4HLER=!%;"6B/G$+3!_K:E1;WNESX'9/N4CB1W
M"%BY^)12&"S8NQ;(-0G6@^690>_ANCT;AID[ID7:#`L)H4J:)JH6<O+$1:65
M.+M`AD.36L4ENBDU+X7U]9C\NI)HAS3._%O#^\^`TU]))ZXF*9^)`RJAOIO8
M(ZVA'3S6*0Q1S```(`!)1$%4\C[D;-QV-;0C:@)KL#MN[`E\[`PIF.#?;]?-
M?KUG&_Z;EZG]+BF='LS;K4G,[>UV*]MB9RMX)>-4U\UG(((MX^RAZPP-EKBA
M3H`??=&9823-X60?MIJ3[*L+-0:=P+AW6._0I%(0.]9!!N<Y=GJP5!!MX%JQ
M='9N324/=JY=WZU/4!'2UXKV_OC[WC%E&T?OUH\ND].\^-[>WDXPW`^YWO?[
M08.$Q,0[9]1G=(S>#<-FSNE[S9A8"E,)A4DG:`B/P"`G="6`X':UM0O;;K?D
MJ:``*81M\'JP\QYCT-!"R],5U`I@)$_G+O`F_&IN(<>#/#?=9*[&U/+*W!,K
M/CRBEV]KDP%)GQL[0GXYV9J1GZI(1&QX5R_]?!R&-;)8<SKPT6A-$:M%>B(#
MWXX^C]>O\Z6M\M7Z;H.Y$[LFM3@D\\'+38/BB&,H18CK[?-:$+#U52`)\(GW
MA`UGC%4X39$(IV<&BS`83>4W%XNV9&47-,H<3+)BI\>Y]!"Z`S(]/W][L-77
M#"#IITD6^/SXE,FAD^^7%UB6[?H*LF$]3UP,K6.VX*[ISGKE)7$22=9U!)V`
MZGD;C\^_5F#78]#^B95%_R/F'+)_\3Z/1-;$B*DL/8G=2.;430K";\#[[X:V
MP$-8^!*.Q:OOOR=UGWY.6,`\)*G`\*>#+BQ4AKLCQD.&&.6P5(TVQ^)_32)7
M80N%'^MQ=+,KU4E:WB=)*Y/IS=T.%&C`)_<SSR<&4"P8UOS%K\C=2XL*@^'H
M4MWS1'T<#UB5\EKD:G9[@=[!!'79R%=JT1P^\L!DNI'O)QU+4P<UJ=#=TF=T
M`EC=SZ&WR91<K;$QX-?1K:%-=J^S+[.[`<<)V'NW?O$][![`X/8P,_-CG8=V
M,]A]M=VNX9-A;09R'!CGJZ-K\(K3M1XT6[>41A4'@Q;NS(RBL=,&@H_G&%Y!
M'B3AU#J[9HLL&<ZS4-GH&M.V&Z26<0`,TGV@8JJ8&(<,WS@Y;I!GK>?FZ]CL
M.Q>?:=+3JT"S"[31H".Z')M:U#UHEY&=%0@D,>#KPZHN-F&0T^RRBUL5L3J>
MXZXMZ,"RCV6\TYLV^'@"SLZ!DUG5=;EZQ[+_<M6/2Y2#$Y-+,9U#QC'G&P")
MRQW>US/FMSB]?,UG,F!;/N5L!;8&*RTL,)<;3K(YH\)NBF#:Q;AW,[0X!Y4W
MI*(+-`H=G\=2@3H,K8JDA95A-QX&&:$VHVO(4NFC#@UBX#6@5]9U!BD^W+/+
MS^R0H.IX01EZ[K0]=;LHGATKXH`%Q:+>M_ES:2WUT`4:__P->/^VOW;52P:[
M:<'\$Z`Z#T:YMA6P`['Y[_*D^VX#L9G-NY=HK*&K,I1B*YS8_Q0'&YPA#_K`
M(^2NGT3M[62S8GLU24$LV7IU7$SC24FP?>CEZXH2](K_:J"!@%Q1KRGU2P`!
MDU8G.Q28Q2&_,Y0#3.CRT(F=+@B#N>Y8[(`,<+%8S0M?2%`1,$`V,W?=K-]`
M/Z-WP@#`SGH]^NYBVV71?#[H#&F8[RQXE@/%\'IMQ?3X8`9'R,1*\>KK/K7H
M]<R3WZ$M+3M_3/>.EG[:;@79^L041@\L(4S]>5?ZFT\K-W'(XN\NT^26?&"3
MW*$:"B*0Z48L\00#E^XQ6Q),OV5-G2(FB`H&::^2UW($JV:5IIF?&5>M<_+D
MNJ0*W:2+,H?*+F]6IY9XFD_?!`");=QUC6>W(J27N:-,9T.FY2^],_$<0=LZ
M&5TO4B@%0`8;P$Z//77=3S_ST;7)1;=VL+(#`/@>'MTR2K5#)[:7PQ)XZ'>"
MN*ZL*IHXT8A[R\P0M@)`3TZTD.-0F]WW&Z4XQ(2_8[)E=<L4V"E1F[$"BKU]
M/C-="VX/\:(2QQVL#.-08)25;>5*"&X8GN<!8#N2L`[9P`:0(`ZQXQOP_@?9
MW3\M;'@J&#@G*2EONKP9OD`%1^/K*M3`:E;$?2?+"$D[B`Q1!M+G0N[[PXXQ
MM&&$%(:58D.O6>ECL/N=%@T4S.^U\'6'W6AP8$WB2QR73.C/8`5*\G+VLZ%-
MFW/IXQ`$#)M(44B2'Z#Z7O@*@<"4#K`4@MA@MM#B3R76RAW+8U?8-$A26[3S
M0NQ!CQ@R*&LV/[N;-5_GJP^Y!6#>NQTV0MV&VT`(S/!EES39BA%,<-GO=-$5
M^A6W:10;:W+\(_%H;(R]K^,""=U`L<%3_D'O.5KK8"G!Z**+Z[N3DX4%.[)L
M3\9,[`3L"+(E7U(4JC7/L][S1`^L2BLLUCI^9GJTV\IQ%=%7<[6@7=86EJSP
MYYT.((T`>)!C>#$9_FC9`Z1[X;9TU3ZI34_L@KID#;WD"ATYT!-UL01>2YX0
MXX%G@EK']$0NL"NM45:GUE,H`>2>,6/3A"E!#;&O8XAQ^&Z?UE^]\&!="SG3
M)+ST+H";6_=\5R/XHC>1DE`!-"Y9R[9Z@%*G2Z)DY)_=^`&8Z]\98ZXL8L[:
M7(!ZNNX@3#O`@L474JPS*-&0`TV4:!C6?KYE2DT$B"$)C[RU.0Y:BG=Y[G56
M`[7?H5SKTCBH<IPH;..BE[YGVIN*\LRXHV!WHR>YV;>DX=_+T6[;8[8'I!'&
M;A/':M8R:=QX@P@;9:[`"G]#R^E<5@Q&?96MKI@'9E'J[[U6XHVD,+0S3-K.
M21D4<^,M3]G&XQP+H1AB^QFGN**"6RF5X$'`-E*[PEGJB->,%P.?OI&<PN2F
M$_HN&S@MT"D^)]Y5BY7M8$-]->C'I2T^S\')7IWMS&L+\79N4"0QGI*#(OD'
MLJEL%L5BX3TZSB2ZRS6#>/<S\6AL6D,6`LRB@P$4#]-%O>EP)3C;O"<P:793
MYK[W,J%M=0RLC.TV*SH:,<X3&H3!@U`C5<P\>\/JXY(C9"$@".E^B5K+J,5=
MS'BOUS3G:S889,LR#@3++:QI>+>JD.9V<%O7CN4>5%"4:VVT5'+;MV$O?>>I
M_]?PF3B`6;6SLZ'_`NJ<>G4F]+6@!P?YV%J2ALPA1QEJ\WK]'396K*.^XKTU
M!*23ERTE7]GJ)G22)RB`4S]S=D^_%L]5P`V5#[W>6R,I72ZD=WLJL\D2=RWW
MZD+RFER(F3;HETU=M3<*44%E&P?(3$_=UC8R@-#U"X.SLAZ"[B&V8.-PC>$$
M(>ROT$D4=L*D#/_.V?=AOM[+8Z:!O.9E##7;,,JUI><S2SG6D"B2'>,:FIOR
MP!"8$<F6Q!Y3<,N_#?!^9<[J?Q_#Z]*,>]E_]M$*&W]`&([XGFO^72960VOA
M$9#%,TV#A04/^W=)@REX(+?P_>=I"P>EOADD"Q@>G/O+0^/*U.KLZ&;=<X*5
MN<H0!!!#O=A#VQ<1<LM[^#4DU^PX(*WCH?-E)EJ#+5U`^/D>ARRH`\"/(1YF
M',;F-W5ZE^U,:V:MO=GM9A/P2I!DV##ZQ7"/5MDY\->E7=::2RNWD9<KH"VV
MZ77?K_>[78-N8?$=5G*#H;K<2J_K6##_L=B0PO-B%`FP+1LL3*].:=WU7K*D
M$5RQG,/C8!KJEN#\)O!0%B*DO:%\1IS(DZHUZ1L/:65E7EOW.+V-"=[F:R"*
MAYN23VS110!I!RVP9^C]`AZ7?$B"&9@-)7X[M&EQ:6OB\RR@#DK\GDQML^:W
M6;S/R."9/F:E.X`EJ9:7.\0`PJ!G;=K;A>>#K<B:AY9UA\59VY-)7:!RAAD,
M!X[F*G,*/M,PLW;SZ<_-UWQ>`[>\5K#=V'7=F,"H"B#*NA!6%P8!5RK#T35D
M=KP\M^15O^`4'QYMV9R(T1RW,!CR%'5?75UQ$'.QG%NFE)?3"*UC[N'G9\"$
M*Z7#<ICK;V>A2=]5.Q"!:N/"%1O_WADEG_4PL7".]>>X-SHPQ[I34$X(A$F:
MW:5/NKRYSW/S;P.\WV#W95N%AT#P^3FN8P1C*A&JA*JQ>#[P%=5C00"5CT#N
MKO59Z"8<IM-/N=V^,]M/,:#6:PL6Z(2IH5OOR\@\A!5;8?6]0$Z'P;MLE&`?
M3BN"@-P30!B,;I^^G<P":[L'89%BD=H)2FVU4:F5R0QK6Z/F2Z>YZ)4K!W[M
MY._O[]9:L_O];I^?GV1;1FN8F35KAA:8*[GFIPL"LR3G1MH)M,>;Y&0^VJU-
M`'.0).1V:];:;3IO]*/;86ZMK8UZL+EG^MG-[+(F8S![W.]36SBD+[KQC>\(
MB?_UBW83QEA:[T6$9F!)QGMULBP3VRAP/&F5C*9/FWM5]Z)X5CQL'%;$7JGB
MP$.;$\$^C@,KG*;JNR$111QSVR7@(?AI%GI)39ER.6\,K%3GB-1Z%0JZU'`U
M&LBR0FN(E4#%8,_:Z4<Z[CNTZ<20VO6F*GH$KV1TK#A=#QI'9MPM7C,/<,KG
M,V'$%`[@TEKPKNU=UVI7QFUYSD*ML\)],'!:[RI6@VF4ME'`A#=7/V!33?ET
M5`!T?B'Y?1>D0BJ@"E;?-7F,"ZF>G&DMN4VXZX"WW..^.BISH#D*<8.E.T3J
MPRQO5[E8,>"ILA3/X3=N4D3,1V_*JT"%':8[QRRX:*".;1$Z,ZR%!W!5\%LB
MVV+1*R52"K.I!O&&U(&OS[>DX=\G:'@!]F,K37B$C?&$855UYT.%0=%.C6_D
MRXMODZ#[F/W=@?/B!:Y&C0DT/V)V%[*[,MUS*#''\BX@UF=H`9OJPUA;J$X*
M9TL/B3WO%X"[4<@``\ZI4QS-]Z'C[#T,+#B99L`^/^\+K+/U$OS<4,+@5P0E
MH^U^O]JRZ<0-T'F[G=K8ZYP,64#23EZ;S3%TR7U5_6^WMTLOO&ZTX^@7$PMA
M?,=GB-W8=;[/1"FS][>WJ:D;>MAQ*=[?S\_Z^/@Y!P(]F+*;+P>`^_V>I`P?
MGY]+<WU])S8Z7]?E'!8:QWP<AQW]F,PU!$AV2BA;$_+1?,MA\]]2D=A!FFO7
MT!E.#2.&CQ/!>J6MO.YK3_ZE088@OLZZEO@U:.?M:EE>PD_`=9>]K($LN5`0
M<&JVB8W6<U4-OW)0@WD[V:3Y7J?&-`U$A?^_GL'%%G&ZF@6?<&>K,:@,;!Q+
MIT6AAX;4NA<RRZ=.)HB23%/=;V`8R2F!I6Q]6K$%:FP"V.4C'F4OJQWMT\&!
M9R$2^P_5&_-:AN1BH:UUZ6I($=*"?9;)&LJ%S"(RBJ*&BKJ4PAGTW57ZWPP>
M*MA&_O-9R'=R/5!K.:?G"^(R'FPY0T1WC(7S^<!2RA]9GM4$40A>N>088Z)9
M!#I0:8BXLX&_@0K8AR-%<UT_N%/)^Y?XM,>^<C3C32EW0Y"A75;IG@:K9O\&
MO/].=M>_"'1EY=@K`&3B`%MF=?\9:V@!!:NC71SD8;)7F&OLP+"'XZT6S4`O
M%?&\=4@`M$T5WC.U!:_7W.]W>WM[RXM8.BW1YJ9BX=D3=@&3X^CG!MSU*$;D
M;J\TI1Q:$!<PF`"?WB^)PN46P,<S]&F]]Y,Q;;>Y0##[V)P&ORY`]_/GSSFH
M`I%DG!*(S\_/!>2O\]F/P]S;9(?M8E&7G&%EWK?6+L_;NQW]D'L25[^RM</>
MW]_F,%F_P.#G_;"WMV[M=KLVY9Y:TY,-.6FFBR&.]Z:VDMW'^0JW^\66']=Y
M'-?U2&#W^LS3-XN`9RZ0-(DOVDSY]DX4(_G8RH]K#PUB6FB!)M>P![5W%W:N
M3V]I]KYES6`5HI*>+FCKM$>_5CEG$63H)+8PXG/@B(,I2,PU]-E&'JI4U`_+
MLS@XFC(A7%GB'F+&\^L6BSBD`L-R3\&7)B\.]P=W/P?@W,17FH$%6^ZM9+*@
M99V2VN/LH!!X'C(3F?<JD]%<[F7T<`\R2VTN>DZCHHPUJAZTU$;%IL>"3*0%
M,F4AVE<S#]'-Q!:Z;3NBMGF^A)28_K^KD]9L64!ZT:U9W4=/NF"AJ(VMN=H<
M.+1@&>EK,TD`/B>9J?ZU(MCF7E#ESGCLNI"OO$=ID.OGA$QE3RVF>/J]C`FM
MHL6C*1(0OMFPVOL.GO@W<;O^.#H1C['N%N<^DTH\AZ)C4:<&#7:`V9YJAO$0
M[*KUD3V&NIG[W0@$%>O#'A#=FXHYYZ??[_='%_,:I("8J1NJQ6*QE^//O?>I
MW^.VY5RD0I^M^EY&#!1_)QFLZ\A3W.'[#[]3_C`4`X#'<=C'QT?2MP*G?.+'
MC_?)\"[M[D139K98XMNM7:QI\97<[7X<=N]];NH"RLSL\_YY!G^P==4%:O[X
M^=-^^^VWQ6@)>%FLD\_VWXCYY!MN36US?&Z<_1I,U^?'A_7CMKX_M.5V7HM\
M/V*3L)3G1O'@_@\N'/D662"_>$A+!4/5CJDZ,9[+Z=@J13&X)W=B2`R;0+'W
MD#S6@QT3R$'@<DOIS"1%K][AW8H@R2ATU)0JZ*W%!IAJ#:F[P#9L<IJ:%[*C
MS89NT7(OR)FZZK)CP9RL))T*.(8<+`_`TN2Z&T4_N^I&95`MWYM`[!!5NEY]
MUGE(T0T%WJ)S,C2@KO9YGACR\QF\3>WL915(0[YS$-=Z27HD\`<C0&7)U6;N
M(\0:@^T78[*BMREYZSV`:AKC]6E3>%UQ:>=3"MYD\H.,:`YWF03<1"M+35Q<
M7V84OQU!;*,*.M/T5<PPEEBO0\XA=VMH&*TJ<+C(\+6F=:/DMSG81G-(HZ/A
M*W!E&&>,XN\;\/[;&-ZOO.`5U]C]#"Z^\D%E,M8V2*E8DSQ-G.\.@C7S>"39
MH-34Y$+A507XQ"+I4<`'7KQ>U^?>;K?)>/0KM>O1.<<U]=L[!*19@`MNKM9-
MJ(?L5$Z2(WUA""!9Y0S<XO?6MC?/_7ZWVZU9AYW,[>4\@,"JW6XW<W?[^/P@
M_>JZ@>;PQ`7T[X=+NAH;\WY\?)ZRDA)@7M^WXTI+.Q(`/X[#_OCC7\H,#[]2
M,5FW"6RJ:?TD-7-M9[);PM%QA5KTTBJK>G(CN$3Y;]DA(8+,J#D5`Z\@'4+7
M6%*781K/GIW3A[4"JP5JAR7OS51@8@,T(VAWEDVPOA$S,TD+HG.CZS)-[L)^
M]^M^KYPXV.^6]89K$$>+]BE/:+;84I;GI'A?IX&Y,00:&+@0A3I9YTXN$]IB
M*"Z%#HRQ&54@^(5E@[EH6##8^L'ZHZ<V_VCKR^1]8$)M.*-LUE1F'_MLG"`3
M.I==X3PO<;VE/<@O8',P\`/))V:2F%I?3:X7&KOMKG*(927FZ1X9P*RQ15KS
MDBF>]R0SQW3_]KDO4(SOT#23-F9V@^B>B]'EG/!8W3]Q.%.CR`EDADX1=\&D
M./!B7N8Z]I$>N=P07=+?*D>>>3(;64"FPD3=?IAHA!+K\NL;\/[;&%X\9C"_
MAH=?B@A^X<BV>H.7WS.T3"RT%"/@)&O+O2("CT&^F6W/)Q*+A1JQ[]C?A,[U
M('L_V^93T]JZW3_OQI/[$4`IL,.FZ+"B399_O;V]G?K;SWMZ/T[RJ2(S>>BD
M^4I]8YLAIX&6GS\_+\>%OCEO?@VV73ZW8'-O;G'K]#S;,0V6ID>]^.XZ7UK,
MSTM_6W526%=LX;Y,R5:Q<`HLE#"&H=4XVJ?WHR]-^/23AG;H*+!%ATX\^;$:
MY;[KE#<T(O;ZV69!:@"333R=6U<7E@$8C>0C8P@&DN#F:G''C%8H2K<%H&F(
M@VC,73VC$7N1ON*E)XX(A0$[)$0_XN74I*UL_A`/^M`>;`#7N0]%C+D(,]G?
MF`M<UEJ#&,OXN'=*J.H#"$9@$IZ1LHB@82)7`H_^>X%P7U6J#%QZ"`9Y!$PV
MS^[./[E5GNW7A>AD%3;`?#]`ATFN.49IPAAR@B"M'C8.9^#OV7D?VD^?F&H6
MW.*;VR]&EMP/'!0S`:SOLR)^3L_ON.-VS)8Z)SW>O`D8GF_;C.0Y:ICL,<G0
M-KIC8QLO%XO"4JI!Q<R2M4!BDCWX$_/C.F1>PRY0-?%NS<BE@PKFJ:M&%,S[
M:4;!V1VNS+L7.*+%K@R4;?X&O/]AAO>K8%7-JOQ/O=]\_O\B$%XA7Q0H$PD]
M:/7]["A*FR-[(:@Y&%37[5L%\U&K/`:3EA42@8<-GF4]FGGL4J^-]/9VL^;-
M/CX^U$-TT;NG35`1T:L?R8N@:=J8T\]<VL$.!EL+9!U3"QS-[Z^?=S,TGU&Z
M/70!E4D/[5AB-:(Q_!P_\*"_\@7H^W&D!"JPC,%L6J:9),S]_^Q]V98CR:TD
MX!%<LEJ:___.47=EDHQPS(-OAL6#9%6W[LR9['OZ2JK*)&-U-Q@,9D'KF;46
MS#)_=I*^7RT`U=B:%!.FT@>8HB+-%H9@1]68#`08PM9-H+5K-?LF$^]J.7I_
MK=46G(?43F4V%64OFM#$,&)Y$3SW33T/0$?6!BJ[T!-T7\B$6F>AU&P5<V%R
M,X[%ME:U:,93@%IL&M@RN*6=+]B-RH\A445W=;!KHY:3"O#(Z&R@GK%A*:"L
MST1H-^#%2IW:-6WLXMYD(&(5GD)9FCZ?^Y!L_Z[JS*)]:VMP!A,E*59E&ESI
M\VF:_/8<6^LP"[(DG,LPUG`RG"3040+#BL0:5/.,,$$'!U$#D6@]V-_T#*#*
MJ=?JNR&L6.%4M=B)D%V%Y15$\XFT'VW.VBE#R=R4Y8+N]`09C?W"X+$1:HY=
MA-/PXV9-T=8M**G]D5'^@&61M)R?Y!8@%@(`KGV\R0!4,HTM-I&!?>"5_`:,
MT=5*,5,+'?Y.6OOO@=U?]26.=;#OL\/,Z:F'[1-2-V"H</V?>?=.@&[4"C%8
MZ27Y1M`FMJW]^%?XF/&E(]E`<'YJ\$(O4"E5!P1@?5)*M*1EM"]S5M8J:*$D
M!WH,:_*O(R9%M[.E#*JXYT./$#N6%&48@W75S\.\A3EO^3.P>,,=S;3>$M-]
MV^I`TUC$<P6TUMQ>5?^!-FS6A7%V4/T'G^?""P4LGA'P3K\;!E=LG"PR,R(\
M[2;U]062GA)#,IN5(X1=*/8M2S/Y3G;S;\]:^^O,2@O=(WD!*+56?$9;)7R/
M\@"YS;^TN9QPZTCTUBZ[(@&I'[&\;B;G.^QD):!-UL->R,8.D79CPSB(!F;R
M16^H-0"Y@.YJS;M;[<]W&L.MEHG-RM7!=A[LD)R>8.PLG6J]@Z>KT82B.X'6
MF;,:8FK.'LVE)4/!AL61J.)7E,^M'O8*K"![@`0K;_D&MM0`'6D7!.;ANB$A
M=X+%D`T&(<J,Q8]HMP/TM^71=>!$:F"S#P&FX0S3PT+4.1FRAEG;]1&IU%`Q
M>B[FHSW=A$693HJWSF2WWB6"@7$C%<('674/P%M9M8@)"](!RDD1)6)K474J
MW[9D_TT@_+K8X/#WY%>^D]E9W,J+GX>Z)IDRH]'Q"\UC->2(9!W'^*Q*D#>N
MJ/QZ\1&=-P?@&FUKG+EVU:0U^["\[R2+T%H="$BRD8(,EDP"VR(FGM^OR37=
M\]X'R-`>2-@X_^`S8CQWQT"2`<8ALQ)<1V.^H5KHUO&)VD#AT,SHE!W2?I(D
M<8$36`]%IEW>`2/2J09>*-@NI(.-P+*KV!F1@_=/Z>4H_.^JQ4ZB`#+C1FVI
M>T9-XQB&L9^!THC>V&ULGF"1PH?%I2Z"Q+#\&L1C9V4X*XAR%5$%"I/3'[MB
M1>G)>:Z[)M\S[7('T>X`-I7.%7@038[#<0B`LDI-.UHF01)EXJ*QAR)2@$!=
M6HJEF`@M:0%VN]WUK/2;$@Q.BNK&B?8$)C_@UT`MPY!O3]NJ13ZQ2_3M1$$V
M1:!Y7(<,Q'1\]/6(NS#V[Q`0JOXDBXKFC3LGTJ.[&7OUX%7,">0:*OK=V!$J
M_U@:9(BWT%7=6F:=C8;%/RE/X1;R8I-8O2Y=@'5RSB^I=A1,5VZ0)^4*=HT]
M<_@^#06#U'N.B82D4^BQ6XGS#2):ST[Z]\34--^`][\`=/D)8)-?_>`70/0`
M9S"A_L;'1SK9YVC=+XRNLN.8`39=N>?-V8._FL2\JU_#EV)4T.(_P^!;81/X
MP8%S0Y]X+5Y'SERJ>X7*%.RH)+=@F,B2OSQE,(L.MC-.V4SD"YFVFK^6;?-*
M?2I7PB==7NA\%(NT1+GJ82W0]6S]/%2%:<A-F)N'[ICR=F;XS$_?S^@98&;_
M/`JK%J&:5K?<.,//,Y5^L3#$QOKVW&@I"FP0K+LCQKX/M7.Z(AW3].@YC2RC
MP(;B_&M!"L,@G]&;L;;64L5$V#'RCULT8(:A&6I8B\?$*X9YJ/?'1I\J(_LJ
M01"!C=]VK[2$"37,.+VN[-YZAR(-]LVY]V#O-JFXY`8L<.B5P(8IZE`@L=%.
M8P?[,ZY%[V!O[1I&RI-7F?@[+(XZ<U:L.G;#<@;@9`KV;-[A`I"3LG2T[ZH#
MBQ-M<X*!1:=;5;[&.,K)KBO@HK`I!I^J,R!>RL%]A@(J_F:-1V@K1\,YA"#H
MP8#\/MQ(8UA.K&<\H7\T$<DH($.[2_=4BM9.$TJ&V-DQZHW5#Y4EZ&)@!RZZ
MASR16VF@K-E;!?)5\3:>O_0-2?_9?Z9X[+>CZ.2%6`L=QRLB;W^OMB.)0R5B
M;:F$\H;6SF&:&X#VW`8^XEB??7=,Z4Y=(&1R53GX2$S%X?@@%%@5"(VP?W;(
M=`OMQIT`)]A-DTT=YM&4M',$"-A=BX7:0>6<U3@O#F'T%NB!K&=(!],8C`CO
M&V:IJTQF]9!P8F!_6I1RZI'"Y*Z</BDV<@;[6`X@9.@#==2ZK8H;Y&!H01H`
MB*FU/VTK6)06TQKFMTE^?%@@0:ZY'C#!OTQ46Z?"@Y'JFY_Z6=A80'?.B?7F
MG_1]$WONADT_&G@*RV6QLB0>+%RS4.KO!D/Z5Y0$QN;=J">7:D@%05H>=+0R
M>*RB7+1];DHC*8\3]PGYW"VA1#%XC6E%1C.+'@Y2!0,\CRZFVOG<A8%Y`R#U
MD(:LUQ^"0;H*N'L'2&DK>Q\`&/+671AK.KY+8O\/X]GM3L;:0<@-]^&`J@G`
MR`@L)_I@N[:R\8"-.D2]T,E^_Y2CCJAX25T_?YD3'%WB5->N87&I0X5Z%Y%T
MT8G6E1GL`6UQ9'W?W>YI?YZ\OR\G#J^M=B<:;3L]]T#5R>?@6@3=P:<8"N<A
M[*#-MX;W;V9SW]'''@PAO<(3OX5;A5X$NU"5824=:1MMM4L4#JRY!2AJ\:K@
M!0ZUQC+=%:,R`$<[Z>DBI1G:UZ\/1_TT```@`$E$051M#_"8X&-K/J\89M9>
MGK/R9:_I:.[9@BC+TWJBQ_WN.M[V8H6Z56O\?>A93#IYS4ST:Z!Z_"2G;ML4
MEX?*Z8(M\\XNP6ALLNS,ZR7JFW>6*'"3Z`F#0CDWID9OY)3),62I=PU%&_:K
M<7GS7H'FFDTK00UA`,,Y?DR"``0VK/S8%%EG":NQE^[6(4&2%NOT&<L@.:M"
MRPC9:&S+NDZ!`[3-LV:P&ZLU6%/P6C9MF3Y$UUA!6]`T72OS_(%E_8ZD9`(3
M2(>FL)$&H-=O\^7.JF,C:O`M#+8Q$@-;K*F(6U/J*<:T!B:P98_;ZF\&:"40
M(2-C2`K$ZFO8ND'9.+^P"2;0;7CX&7S/$W=MJUV@TDQ.$EP?#4SUI<57+3',
M)[`Y-G2,8`[&K[G'-MO]4+&8UO7(M-2B=+>Y8T;5T-M.42`[T;_/`>G$/AZ8
M/8G+IJM0#MVT&3K3H5NL7>(BXJY?N(=8R0\%D@<`MUJGW9LFW__\/X*FWV)E
ME5N8R`M\L.V-ZSC%$`JR@[=DG1>$,#)6?(RL21F;N/].P:XXKHU[5"?3\X]*
M*=&Z+B&8]?2D`<\R-)RLB3O"Z5?\1"00$_,APE9!$QQS^XG+\9?$L2!VNC)9
MZ[K2Y7Q6'^X-O^/G9+2`"^-\O]W5)CF[<KU]EI(:KAIL;P(V1TQ+7[.0<\9]
M/`3GTXD^/JYT/I_I>KVJ]AT#Z.0:)>T97=ONTQMAXB+#8&;7?5"T%"=B+@QV
M8@]0QW4=+!Z;XA"M=,I?ZO\N-<Z72?OV($/;!KJZVT5E:;$OJ(NNYEJ0X-H/
MR4C?B!JPK]_7AK8X[-:PV^B+Q1^[3DYC5-F`%#)V7MH621P;CJ`G&W_F9VRS
M2)#2*+JX4FL62BY,Z[S?V#ZN7SXD@<<P0WMW!#(+/`^1-MQ?7_UWL-:@UZH=
M^'*LM[AWMW<XDI&LL-E;>`RZ]0G_P346+7'0=7-KCI![+[%8XJ!8P>(_6M_I
MR7.)U\THR+167*S;C*@E"'V0]:%X=PW]/K%K\S/S(4%4_C,?8H1TU%%AG_06
M!4"0S-QHYIU$9MVM(#'?P2`MLK[.P;6>'1M/K1^#]Z,U=+Z1Y'\=CQ*]`,3<
MD)AY$?B%CQ5H5[W*#O=6A`U+")+%XF$U4Z]"&ZH$,F3WKWMI1$\O^10V#[BC
ME\[^;=@!R5)!XVHL3TC[_ZF/XQA_<5P-V$C-P@:F#E+']#E>>C-!K_8"AM9@
M88:6=1F5-&QFG)B6-,Y/G8JAA`W?.6TSHV]ENV+ML^W@GAN&:"U6*2$6#4"B
M?$%)&9J','@&,Y..&6W^C"G1NI[H<KG$`,;<1X;*']D.!'L*1*+K1DKFV;(-
M]7$O$"0VH%<`;"9,OQ`UM4S]YPA:\(P4)>.$'7>)@P)H?7H&+8I$74^]4?DJ
MKQU_`P^)D[-N0_F(+C2XL]D-2.-S(+`;,1841F.AKFNU?V++"I+6[O9AMZ!5
MBZUBM9[!A&XDD6ZL7<[B`*.6;R35%;/7VPY?C0`6)G0^B<)-D(44M6;P86L:
MB]02=R[^705PH`$>MHR-A1BSZ="QEU9%(22!>X5B>H-T,*\'U^EN5@/:]I<\
MZ_HX!ACOCZC4,5V<FV-6\<6B`+1F8"?:6=9N/UA083&EGX<H#9%5TB'JD]D.
MF]HAN@DP)F;U3#/HGTEYH9,K&'"?=<0;*X7?2X6HZ/\W!@,9[!+;_F>D;M;#
M_/N?W_AG5DS)$S+U*,9>0=MG+?Z#OWM=.4=AE*10H&T];/^+X0P!"+276/1_
M#_]5#3_#K(9.$T8_:&C@R*BZI(%M11IP.M&RI&KAUMBPN<W:$6_.7*W(4K*F
MA25!AJ@Z)G`!JXG;7J<8.)_1AE9D1<NV[1LM::%E7:&%1CTL@VL"$BE@PH%6
M2^;M5/(V25ROT6@QEN<G`:.K-A5H_>W[3D)"I].)TI*<IK1\AO&&A(4;A95H
M?=6.;:M!%1:(N`W7/D,,>EMIWY;*OYPH+3P6?BOY`/`Y@$12C(N(UB'C<%=K
MT9?I^E2UDC5"%)/9#(AKSVI[;J$2&9L!C]\EYG"UL3[5V#I6DA*FH$`9SQL=
MO#&]H(!BADQ!D<D6-.TZ`AO-QYT%(JNCC]DO9F\D+0:0.]!9BYX9VR$"[7UF
MO5[UHCH1#@`RL6;&^@DF58@>ZZ`%K-4,6(7?P_<3;0`Q-ATE([E%B*-/LO/2
M#1C3_E[J=;3'+P?QUBI(ACRX3K5HLG\N.2M933:>P,T76P(@U=Q`T&=[6.CY
MHCG\?A(7;QL_'N.=L1(+^VYR(&'@`\:W=^YZQ8*$B6B&MOM_9_.^^+4>KW$6
M<1[E4=&0)?@9L*_H$DLC3S@J3+R-HB'5#,F&?]XTS=\:WK^-X7T:@_#>Y\V`
MJ+SZ>W$+7`YXX9EC0+/44D=UY(X0,;UO'.^S/V?;ZI+9=Q]<4]@Q&PNPI*6R
MCM1U=@U4VDI?:"+>!8;B=%J[[G7;-TC-*2_@]BBI9JG&]<Z>*V;T6263U$7T
M>&S]^!/8`5&=?-[WO?RKV'2MW72EB@4_Y&6BV,9C/F;3D:UHWWF[W6A=UIXF
M-^Z'0#MZN%_T%KW1;S,\IU3!]-Z?65^("`PV*%-_](R?Z6'$I`S58THZY\D`
M%*Z.'$W;R2X.F#'5C-'\7HR$0ONM-G"3H)#AP%JJ:8$%M)'H;#$^NP"USF"K
MEOH8>.H`?G9]U8;=CDU;;R5*:B"/I5E!46=C!'Q]T25#HN<74\_,N7<PX";N
MC5^KLZ71H0W^/1GR@UR[1<IK'-O8&#@`SB+HCC'J(P[6?IU8EJL?MOYKZTUJ
M)M[[<\B.N&#0R?9K&_CV8M1P8^Z4^T7$\!WM/$:/W]:`:$G,DHLNV$33#E98
M3!N=P]T(6>E($XM#9U'J[5$!HIC^^LXHMY4.>O5[T^WI@F-,@0X9"YCAC3Y6
MV#%4%I`:UL$"M;3R+`BJ'9^X-8EQC3'O"MNV\,2(1\(]T+[GABG&;E/<%_ZV
M)?L?E3.\!(I-Z4ML\A-?^7QY`23#`NQ*;NU!&,LF',>E`;)QOWDV'#9-!-;[
M2'@PRG/4K'1::ZPWO,((;$0[^1`&DQT<7E/S?N4L]'ALG2&Q0TMM<=JVG7C?
MG;V8&BX5XVD,>>=ML=D>&Q'O.A%.M&0DPW```6#"=MSLV=`M=!?W</A2B+NG
M)06+B`J[GKVUE3A@G]6`2]\0NU]SL5WC^[U>;Y#E!&R4-M<`(,[H90S:0,."
M,,-P1KM^K#<TTRL'5P:J"6J10SH8UI./R(Q",,9[VP`+!8,=9H!.@/T5`,4I
MU8*#5.A&!SXPA).S3+L;'!A8]=9H2C4ZMP+]*A$H.*:"J%[<IN;L5<$XM%5A
M2"O!QDW,\\V2]/`6%FR#$1SG6$`HAZUG,EKB9'QUG7X9]-"-<6)&R40<%YLS
M.I:8G+L)#K"?%W4<1G=8QCK5[@^L%^/9S8YEQ.L6AE_@FH,`U124&K^PZC(-
MKU;N!07ZE.,U91.8P%J/XG$0W*-LF5+U[EGY$IO"3_?[>A(@R$A(6J(:/I>X
MEI:"*4/,-\I>4!JGHJ&%E"6:6H)[0:6]DW6P`ZMNP/!.'@5O5KILG!.">.KZ
MKOAD4]%2(7@7(@]W"B+DU=[YI'LM*LQ'DUO?@/>?E#D<@;I?29#@YS_V-$XT
M/,ZY?RKQKZ?$'0'"5PH`.;J@_.S$/*J>66"Z%CY:$06?RWSPE0`DF\,"D1EJ
M0P9`ACNR"V%0QRT4VM[VR7`R5D,4%"\UJG9R7YS!N"V(C&2$CA+@)+:2$],^
M9;*QH]J,P+4-Z^\F2"I"\+'ONY<Q..:&/><Q;@B`7Y/F%D7H,CM&`3=$Q@EN
M'KG3K!CRZC]*=BA:&[^7?4)<"U$S6F/0+(LWGL888B:,BHU,Y&%?[ZQ>"IDO
M'3K`IF#1Y],!-(">A+@_T<$`'+N)_J086E:@R;&2QOY+;`&'7KH,$>%0)*9Z
MKSR8]J$D2H\-#C@%&,P3'+M.6#VW<MA1Q.*'0P#`WH<\2."S_K"8<*"67_`G
M5A(CH^MLQ7MQ;,C&"C&0`,`KF\`#6-ERU?N;NG]P5O>H/]<M8MPF&C:@A]'D
M+10$)`Y:4M"<-<J[W)ZT/6<E#<'417M]]@QL;5_3V_LO\,R(+X",SK?=NXQ=
M.Y[=<W33&1K<'##?ND@A2U^-Z/0LQL:0E3G#6,]8D2I%KB5JO6O7EGD.EG``
M4SF.&$:\'4K&5,YZ#;X![]_#\;[^I_("&/X-.ED.T.\Q<!4?9=,^)X73!=,T
M+9Z@\%=`/C\#[OQZ*IWK9XC\QMU$$'E\?R(L+L$OLWLFV$$$D:@%Y`?!F+0M
M$8GXVF!FU65AG"D$^*U"3@Z9WKXA"(7M0R)2QO#A<R6DSA'!'PXC-98J6D7M
MI#_9T`03YF!/R5I(%</\/`8#K:T6.4<=#1!;LIFQ\+%3]^%SK":BK76;9E]F
M271Z6&>\9!F>J2Z+0&`4:`M'$)*5'B#@YQ&`PJ2"!/K`%[*3J8@<!I`!K2</
MZ8353J:4ND8SHH9:"]<.#,9+K8!D0^KQZ$CP)E=JWY<E.^LM$B$<L%?L9NW@
M-;!K&5J4_KAN6)=.F,>CA5]H@E^UR4><<P5P:AWAV!W!=M[:L6:M'[83_<V?
M>#%V:>W>MZ<]CZI,G2,68<)$+!RFP_5W%?I$HE/#1T$J,BG<I`-A#$W@3AR*
M[L"VHADI>,EJYGL/-!_<_,U5T(2$`Y?]6C"3,>+L[Q.";AW&(#X0!]?B/.X1
MD[X6R(!G(IWJR(.\P%YA5K:*WA.8`@>2"(*$:Y[9%S(41%T^9HJH;\#[/P2/
MG[DLR`1,R<'0@I.?O2-]D`F@9M\:F[/)P9'S5'UP"#+EX!Q5-/>K\<+3,`2.
M-<X2WZ_#HH$/&&6)R?HQV4NN#E=V9#R[OJSLENRB2`'8I0.F7U3^.\?,NHW<
M-:$),[:>B0\]AU7,+HL)V/#7RH)&`D"@&%YGH$]*SC#&><7I%9$U*7&I^.=Z
M(^:DP486Z0UX(G&+-QO0P)!.Q#WR61NILQT\,>RN8NN$`0RR_ARX9ZE+"E@#
M@.;="XQ/`7!)@51+S3$PR$.G2EUJD6AH4:RW*BMV4""R50_;N'9TSGV0;`0+
MD`)R^)DYYW`U$IRV%SW494%1`[U-OH#M=5>,A?5W"QE@9X'&$*K!X'J`#%QC
M0#-,\F-QKQ+SZG]F.R@5%C\@2.G/`ZXI^IXA"]Q;VH:12P#?4D\MD6!Y%F/M
M-1Z>_JY#F[[]-?K]II1BWW;RK7V[)G,$Z`V1H9V2_)X\W`OR-&")[:+*4#@N
MZ'!#FO4-.BIJG4L4:I%UIXF>Z@+8?H<0K0L''1-1H1]6NL+`MB;366OK^YJ6
MN@YDG<1F/I/,N=A.5S*5K+(LJ\_--^#]OXH3G@`EQ]0:QN!%Q'S([C)/6V3:
MDY&F&>]B0;?93ZR']3,MCN%6%``YDM#*2U0LA=?0>%?[Q8'>3,][=J.14;+`
MV[IXL'CTV6)+`PE!E/QU!/YG[@P3@PZ,8)N>MFJQRIP1MNPN.3([>'!,8("2
MC)C\3S_\-9@`4HQ=')",/H_=*Y6YLX?]HXUM(,HN.G-LW4<48]PD,RW=0L#U
M89S2B&(%#5V.F.5QP=K@E=HD`&B2P?@16\^<.FW6_`:R:C$*;*Z^0\#DC>RI
M@_'!/RJ@*ZC%]`;U=FBJ/',<%!9M'<L.]+6A,V2FN;>\N?O06J=KM$M+1C^J
MV6YCYHL2)#&ZX"8IP$AL6\@BJ%4#0T(F:FH\8XRL+@P>F^"`'@$;_)UM6V&P
M0;^/("V(UMDL0Q*@"0!V/LL,Q:92W`OI3D!_]E(H!QC7AM204P]X@""<2,X0
M%04X4/PTW:T-MK*7>S48N"P+72Y7.IU67<C[R40']B++-SZ@9V880FGO(U*U
M7L/'OM&2$MWO=R7=V[>-,K,9#J3`:W>L%=?+A4[G,WW=ONAQ?^A9E>9T5R;)
MB8($P&!J!\Y=SZ9\`][_)J"5=W[O(!Z,X99:C8U,",XCR%<7(+2=&0Q"F@)J
M)CN7#NU&CA$W4Q2.<$29QA?!AK%Q!.#EB3L%6A^03T6S60%/L>L+S*^U=SK\
M,)^#3+W?A!J1"8!-`4OQEA:;_0!)7(U-#,NQ716=OTH@JI&E%$AB@-G5\RYZ
MH,KJH]6&%I1FBD4$8"IVR*.W^;)CI)J>LRO%4%82L=Z2.V!%+TSEJ>ON@PQG
M!]..KWU[_:RQ?PVL.X5*JR,*$O@LV"<5%8M#5`S:=72,4!I7@=:ZLG)"_;"$
MS7J1/"W6D,41<W-\T\HZK2#@'KI::FWR]FRQ=8.`9UE*H41]J*[:ZB%CC,-?
MC16MWFNM*R`R9#%#3PQ%;0?P0DK2Q!QZ&Z?>(0#P)JQ4:XS/'>OC;6RM<FP`
M!,PI33R"M;Q`:63QG>K2%0GW(P5=6A>@@]FD@3V!OE=$Z;=MR`/:5XF52A`Y
M=C$"NG:1M'^>L-W>"[3AR^R&&!/3^53\PY5EG`F?4`$DYMI;9I2JXXF=ZTCU
M6K9!WQX$$4%&)N=UW]_<G&DGHL?C40`O`SMA0VI$,ZV6A<U4+#H?]T>5T^AW
MFZ6-+0]KNNZ]WK2_9N,6_%D`]M^`]__:?YA"#P27%2V_1B/[N?DH5X)RWHVN
MZ/#H_+2_3%B_$*3YFG_F'O#TVLVJ8CL!;%EG>?WN/`7!C=5[QS29(F#,GNXW
M+2['O`:LQ)%-UXS\5=4V6>I[8N0.K="XG<N>W67+,)"R3;=6;-%&-BL`XL0>
MU'M%&B#N[!MN)?V>`F?!>NY9@W[+]-ER`08DA<?S(I2=-$EW4&04`%E79;F#
M">[#0F-`9#@=R,38']^[/L*76'MR-H#!'"00!B!HH#P7.(#^G^K1Y;&Q8XL=
M!U:ZP[<%[(&30+=5@]9XUQ2*;K.B99V:*E?W`PH(!E#CSI%)4L66(UMB`!.U
MWFG0UUQG!NN/PV[(O,-P88LO5DR?D6HH9X_4[TU:4@\?DL!9IMN&11(WRYI'
MK!N#0XJ(CCR>%'QY+S(%,@`>V^?.LUX.I'B3]28@L%7'Q'4Z)VN,*.<*<BL8
M)ARNRTJ7ZX7.I[,;&U`R'#B>;%K[#&R_,-/C\2#)F4[G$TD6>CP>Q#5MDVRD
M,S+Y,-AJJU_;L3M?+F/(;]\U%FG'RTSLUIAX$^Q^W(92%B!.^O5@W<T[LD?L
M4>GUP[\![^\RN2)_WV?A?W-^IT=5\*^X*/#S8^FZLOSR\?-SW!Y<,VN`&GL'
M6N+NZ?='@Q,FOE8G%`5)(#*'Y4$*IM\`A%YPE#!_P=%H&P0Z&G<&>>:'?/",
MAF#7#,>%+A%/WH&PF<8'3(EK-9*R7HL>+MSX)&=_FM:6B8PIOIA^G4N18,T&
M&4>+X3J`WJ<:I8I(<-R8SE29.(:?;6J&#J@B[RF&6R3=<FI(+\;-;(N^2,2J
MDTI>$CO50Z2+"?*%=G\?&)*/P`LVUX$<M^%U"8)QHN#!K"O6L`A;2R$>/`<Z
M\4L7S>/R)5,`)4I,79;1&#H<KFE,9&Q-AI91(\(:#X%-8Z8]B]U3EGRX13N.
M#*X1MF7=K<((C10X*.Y(;?JDN@MZ?1>T4,3W:'*M.2HP`O8W(A_:,7%D(\?#
M\[D56VS#*\2SKVP*#0[6?`=:9\T5!%L3LJ#]9XJZ6<QN/VC7+'&B];32]7*E
M95G&$N>8]F%)F?>=]FVGQ_:H;&VJ@4-+T4DO"ST>#_KYUU]$1'1_W$FRT+YO
M)85R6;L_?`N)26G1KA&$MF4<KNEXWA\?'_3%3(_[W74&HZ[T;,"H7<-L"LIP
M;\VYVSKB,-V0E(ES8VF5YC?@_4VP.ZLBCXC'ESC=P%C_)7NP0,;PE!^-G+\G
MME*Q%ZZ04?^XBQ&H3_T,_AL@/AQ6IU]TOHBHZ`/M[G1]M/?JS>%!N\A$&6CN
M$">`W'HKOO3],*Q6@%/6L(9IZESP4N$3@=7`?U/%<\HX?^1QU,;;!M6L9M2U
M6+4YOY9L!$,@@="<P3F#E1Y78G:<]>.M6'GH4F?0T^JVNHSN"DY;TV`LQV"8
M`8B]8:C;E*JSP1H\J><O#Q"L-SKJX+2%TK"+&Q;E`QHM+^CAB@$8.1O/6F#N
M+3"?Z2L',2!@E\1*3M&>IS:(B."S?7<)H,%!P>0*`.M089_[+-I*BT`.,[HO
M`L\WZ@^U][-:GEMAQ+Y;HX(E>!1&H\5+W1[-I5[U@B.KR.BH0Z=F)W!(+@!Y
MN,B$>R=J4H$15N^3MP)WPU46R/LZ190^-'YV-/`5BGV2>X1Q,(CJC5X*&[DL
M*WU\?-!I7<.N*OYNSD+[_J!MV^A^OX]D.!I)>07X)EI/)[K=;C7!DRC?X=W/
MF1[Y041"]_N]@ETN@+<.JZ[KVB462UK&$&\K_LWZ+R*TKBNMRT(/"ARBX`(G
MD!UAATQH>*Y+L-$*Z[6<#P(X5#>"1167[?O^9L#[MSBV_C_SS[PU_TN(Z_#G
MWQIRF^_7-!42!.S6(;TY03,RL3?@P_.9"22.BHTGU\'X$\4QL',_\NCZ\^3T
MPXG9)S=`Y!@16CTBDV:)XMO`;W<=+'X=9MV!%C:"XE$K.V@QO6)-@BU.>QUG
M)+D:3'GKY0W.D3&BDOV]JE(#MD`%@&]"%M->F]Y#UC*`-O%>\*:VUB%(KTHN
M$"4;JS;+1EM)A50++@V:G:[6;O;1\`]I0_B<=W6C$+0(G#>:[F.:%OHCM[TR
MD\3O6&!,/QLR0A9RF/63"X)0^AOC=($/B`8Z>L"G/PN8B)CC-"X+OE71IX)B
M_!"1S(<7-!@+$NG&H"/U8HJM9MUJ<%D[3]@77TSBQ2QRUOV9`N;2Y1BB],GC
M_=!;B_3@D'GGB$G/P)J9#F9O1S@F?<=`X(0(MGZY7;L>$!]M0/1T/M/'QP<M
M2SK<T+=]I_O]3MOVZ-[B*@*Y#U66/V]ZVFRC>(.DO!(:4Q+W<."L'3\ST_E\
MIM-ZHF59:B`&=$SLX.NR4%J6'O@S/*I)N:(P1)2KI,$^M+>6A,R<%?MOHY.C
MK<3JG7'8`Z4E?S/@_?\'[+Y]65ZH!2*P]$I>P]%'O])-CPSZ0R'!+.D,?F`V
ME'4$&*,_X2=_^I*M+K[P$[>TQI2PL&_;']F,P9^P<0E@6S=`V[A'>+YT_)Y#
MM_/WGHFP*6+'#Q"S/EFQOQM9;83`US,V81RQ\[LTD@5G]1%,N@=>FT>:=PT$
MV'/JS,`&UF?!#E$Q]VI#V5(U76S_>QO7BX$9A;+(@C-J0IR:F;K6UW&U/NNY
M]%V76<:2^G54^E?K6M`IGOYW2K\XL4TYTBFB\;S>4/1`E>#&(Z)!2+,I0M]0
M$0#N/*RGR`0='/QC(VD=@%+,TDBWPF=>I8=5']\0K(+UT9C_DJZ!9>8J\P`7
M!R%]+TW'5_#XQ5@F'K!<^GZQZ[N)Q*$5$6FCHZE)O1L)XI!G0\&E.",3`C%`
M%=JMX9<JQPDR8P/F,440)^(#%Z)S*[:".[SW&AACL27*<YG4,TA=<J$'M"SQ
M@:$U:5GH<KG0Q_7:KT%/VB-MK_=X/.AVO]&V;8H-=S,+\`QDN'960VW7/>;Q
MG"(^W/?<__[S\Y/NZ4Z7RX6692%>5R7;0<;[=#H1,W<6>M]W8.B%;"!&DU6<
MSF?*>Z9U78K$8UWI\;CCI%]8R#+Y]+6(=>]%'XBVOR4-OX-CWYEP>B%P(M(`
M\%O.#G.<_32LP9A#\\&7'9F=S+[@:,AK%JMM72!H9IMU=$T/VOHV!4?><KB0
M^)AX"D<[Y_+V#!YAH?&,"1<-M%]@6OWPHXH7,Z$/`CI`#V*519@<WZ"^$-MK
MC78,J*2(^X3!A']D;#(S.`>;)O+>OUI(+]T+MY<6,@2:+=5'@^5V<LV)=&AW
MU::K9`@C\E<@>B[#P)Q@,`6;H3.EN2PF#CGK(15.)JKZE2Z2F<!GT[%H;)RZ
M;,KJ1`_@*'6DDE@DS)2-UQNXO!9XJV,44Y"1U\KV<`BG`27"L`GTY&W/J.#S
M;MPWT!:PAV0$BB!E9V=TU0UX.;_P0-+AP8$YYDEW!Z?_59'HNF2LUZ`NR:G3
M\GG(<O33C^MD#+Q32N:>2/]SL9TX8\6,\=#(DF/4+3JR:!<,NP_J8>.H;5Y\
MA[.R##N4-E;KK>O'!XD(W1\/RGFG=3TI^9;L.]UNMR)=,$.C^KD9]GJ*X030
M&[*?%-H+3_]NSSM]?GW2:5UI67Y02LM8FEE_[VE=:5U66M)"7U^?A:FU0\#`
MJB_+6@;U3D/WG^IU[)(-.S,QL6B+=.O8;4,]<?J&K?\PV#4OP,MV7&^H0WBR
MR\\EXK/?%PK,&CSHXJ-SE.G)/F.A+41X%>SJ+WQ^QNJGY$TZ/&Q:=4+*3`OK
M+U-VY?+"-;07YXDF5SQL]59B'+.\HT,KQ]IH/N#?8='U#'\4.*&GWB.];'O@
M.&!5B+2-TO36N9A;/22C-+GBATVHLKAJ6EI=;P8O7<U,.VLN8,T:..M)7XS1
MS3+LN/K-82>W\)Z[`U@*`!%W/_+0,>:`.?7V;E1S5:4/DV68@NX@A<?GMT?!
M2%Z[9KK_G_%-;I^M6_N3SH<Y2/LY1R#+%D.E;2RJBZ2?;3(#:>-Y'Y(5IF4I
M@T#H+4OF5Q1X`D#<_&_M,UDV\/F`6P,4UK$BPWT8SR0PH&HM'!64""X@)5(Z
MBK3Q'L?:1S<?2/[Q/</6>I^\1T<"4&):1P_E7F1D)^U9U==,#-,IYAC9;TIV
MP^C6'*SL$/&[VO>=S^?N:I!SII\_?]+7UPV>4Z)M>]#/GS_I=KN5W\U-=C"&
MU_KMD5S_#08U6:<0JFU(Q+R/XL"OBH26\AX_MHWV/??B)G:O+_]Q.I_H?#Z;
MSYOA%&#/.15IA"E\\`&UUW@\XSF6,0GI=8;D&_#^ZC_,;]!T;[.T\EY*V@NM
MZ]>^FY^V#?GIX!V8Z/%;EX">Q1C((3G*!)-!SU`YR!S$M17UNQ9[@QX>:63A
M$.CKGQ4,0O/%(@*WF!1DDX@],Q2`AH#AE@G8G474]G;?P4W7&X],>P1BL^%E
M7C)9JR(<3)%)4>2!O=G(51#"V./:D,<XEZ"ERA!4("VF$YI^*%T``"``241!
M5!Z+U/YN;.7X_3F+VJ14;*899YP6$@`D)%I3`A]5=0X-W&;<N<";.%L#?=:Z
M@`FCV,&[U:1*<PF`D(])D2?FI6A,9;>.RM*'SAI#BD,L[?\$PAO<FRBQ[A\7
M0G&`0B@W<$`<`HIH@!-UH,H>SLQI.;!LDP<I9O<:L\G=YS7YPKP^F"6BN;A^
M4)5[Z.,?O]\`=<X:9'L6,996V/..0&\O@!I+Q^.-26#-Q0PV=0"$W%";NT;F
MD<5%%[H6=HB.@YD,-J$+E\N%/CX^Z':[T9]__DF/^YU$,NW[7IC0;:/;UQ=]
M_OPL$@8"_UHFY;2&LK*(>.I%6T\X"]AI>*\BLL`%_]2?O3\*Z[QM^["M0T(`
M?GX]G8J?<+2SB="R+&"19IQ)TJ(&@[6G.#L6=[9V";P\W\$3_R3S>_`'S[2V
M$O06?U?#^P9E3;^)FST[*;]YG-ZG^CE+'$UQ'J`O-3G-4:W!$TC.QX5'H",1
MTGZC_(YKQY/"@!68UY&S8O\NNB^"?5D`;9,IO&<#FV@C%`,RF78S;"2D#Q*P
M;3N9%J#B@T.=;=7\T8M<6$2!#C9_WD,=JE5Z::ER36<CG6O?]7"Y)[TEY710
M[:NZ3,+,NT%`@O2!.H9!I&'I9,$QJT'U81<AD*(F+[ZC.!$]0)<X3V4\-ABQ
M5_I<1L_O;**>V4M3M/V;E[DDD[S5D^(P^M7$H$JP_K;[DL6Z<V`MR/X19PB.
M8"-#L5T&=9X!DVEUT,%ZJRVXM'BD5BKZ$X34Y'SYW@R^R0<:8`SKF#P</2JZ
MRX6R&Z12NE?H%K@`!M(>U"/2._7CR1,Z_9F&&>5$=KN8#=Y%>289ND"7\YFN
MURO=[G>ZW6Z4<^Z@5D3H=KM7SUQQ&EPE=5`LON@U.?0RU^$_B9F6E$K1T-C0
M*)FM2:V&"-O-`]SN-SJ?3G0ZG:;A)\NRT/5ZI7W?Z?&X=W9X24QI6>A\N52_
M9Z%MWVA)@]E=EJ7H[O/N-+E-[X_OLY(-D1\H1/:(^=N6[#?PX2NC5XHX?1TH
MOZ7Y?2Y7D"-PVA;E%W>XMY0<!D#*:_NG/_CIL!PP3F3LJ$CK]APY`Y_?[7^?
M73-TF;>M/0J=;O3$-CE9W/%]G$0&3Z^E.9>CYY%?N7G@P<MN7"1^#YZ%=Z@!
MBB.1N4G!LZR5>-/+P4J2]6!DT\H<X0(((3"BU(51P$84]==%8N-\D:@U8:WG
MN!]O5@EZI#8X:1MJ'^)C)67H+![']T:'N(@JM'U'@$=01'O'()W)1IAV_]\>
M<C$TQSSQ?AT>FD7CW'Q7N_96@<;LV,Q^N"D-9M@X`#1]KK.3:M<]%2>"#LRD
MLN\&]/:4ISYT)>H9:YI*&V+#W`HC!"\->),#7NWY&IM]DP9HH"IB+.^F0X9<
M!BA;0AD6)'B/0.MJ7\X&/I.)01?2%HC&==8,#VGG&6%<448\=:98XF:MP3B0
M@]A=06F$ZQY7.B=E8)),-VR$>^C0"7'X652;`=OG7.V[4DIT.I_I=K_3_?&@
MR_5*C_K?^S41(9R'[!(3P>=QK#^YNK(@@VS(],Z*,U=I34IT7E<ZG<ZT[QM]
M?GT-T`WK)A-3JGZ^6826)='Y?.Z#:.W8UO5$5'751][HZ^E,RYIISYFVO=B@
MG:]7.H%L(>=,7[<;7<X76IDI[SNEE.AZO=#/S\]0JI8LHVOW(6-M-[;MLD9]
M`][_$=J7PHU(7OSYZ4<?#G/YT;"6AD(O@O>WP*[\T]?0@UUYL3"QG^FLJ8`!
M"WM?-J(4&!ME'Z:8T]<K$CPS9W%#+PXA$L6:Y"G@%E(1-AI*!<X(?I/1@(*'
M35-X4&P\8`W@$C_PHENTI*?%;:3E4SD%![I2,^FK6NZPP.9V^)'K@W0@*@9P
MX\([P)JVZFKOI-2A#S%%$ZL6HGX2NNN6BDRU;5NPO3KH&*@T/\-<BN@"4;5,
M28,$8FC/HY.#"BX8-[SK=1FOCZAWKPSB<3@LB=T%'0>L[:_$G:=_+Q*S2AS#
MYZ#[\;H"B13K*<"<EXU^5.^]``'`.A+2N(./!DP2L;85$SUD:24YR%RVX36;
M&I>ZK_"P+,,4NQ%/7<"H9LMYNO9$H).$S'V'#@%AC+T>U&H2B65)VH<90BI"
MWW'SK#>[JYR%*!'HC0UC7*]SCZ]U_LBZ(,DR!@MS=?TXUYC@KZ^O$AE<0Q76
M=2T.#3G[5,-(7M2/*^MS`ZN_,E16PB26)=&V;05PG\Z44K4>2TRG]5)B?'_^
M5->O/9N7JC-^/!YTO5[I=#J1R!<1/?KW[CG38W]07AO+2X$&>A1Z:5F(.-&R
MKLK-H5BH%<;[M)XZ.YZ61"FML/;H+EVN705MQPC)F^CQ#"15!^+?:/0?_N<%
MYG2`77X353H'IR<_J9<C>1O%OB!G>$6#\0IP9PV"?!@`&V"HT](.-:1TC!9?
MC56(M-.VVX3:R=FT>63N(\%G1B-YFN&+KR,>HYZP#:6+\=D:4_E7'O-#G3N3
MFSPG4Y'7B:J#XDLTPQ:`[L9X6ILN'5)AHW9%L2V-;;82C6XCQHTQ$[W($NAX
M.U`UBN(L\\C2%A2OOA,8=Q&5DYH4:Q.ISP$43%Q(^I1T2FKBNPV7I=XZ-/<N
ML$JR(1<V4<L5(LP*R*J-7[4WJX5;DR>XMOO0"'L+*PT-<Q['J@'%`)NIWU\-
M8'4C0LSPEV=O]SUWT":1)RP^A/8^$UIEH9:V)E35`FD`7:T%'<QS4HRD&C9+
M^'=L?'Q)`;_A-B)N2AYE!VZ+$?W^%M:.'?&3P"VAG>J^9TII^#=C%X\G.]TH
M7J7+5])"$!]=#FB'3HQ,)%*1E$IUG.J:5L#FB?:<Z70^T_ETHL^OK]+JOUSH
MKY\_NX1A4)?0Q3"#?A+(@]H_I_5$U^N5UL:<<@'5)11B*>>V#WG`Y7(AR;D'
M5`@1+>M"E].9UJ7\_)H2I24IQY.<<QE@N]WIL6WT6![T[W__JZ3$1?L-['F)
MB<ZG4[4RS/3Y]47[MJOAU5R/Z70J;'2_-AF-_"%27'!(G!3032!QL7DJWX#W
M;Y(ST*NLVU-63NL`?D7.\*+MKXE<^AL!_J^>>P!(Y0DREH#"E`,CL1"02WS<
M,?/%X7'QY/./[-AT?:-UFS.G!IX3MD&'P)\8'_^"9F?-V?'!\^\&9T)K+N5^
MYR(_M3K!ZM<.`'00H2JF48^M6I%9&$!=8\6`%ARZ(>FLK/U=Z>PN*3WHL)5D
M<Z?KQV=QTI?V?H;/%098(.NF@+R7-B@0KQAUT]XUVD<&QCU;6Q,CUV##A*HN
M!P#J".Q&G0.E]U71PS(""12;WAC--FP$OKAI1`2/,(!$SH[8>DG#]>MM[WK,
MV;*5E>'+DIWG['#ED!Y>D@F=$5!F,];FV"N7(:C%=Q%0&R\&G+4D.\GDK-;R
MQ/-1=0:Z],2"V,%4,OD"NQ479/6F&+"A_.?9;5$-[(I0UX$*=GB,#&$4)3XF
MMP'5#/IM#CI6D9:XKS3U7%H\;UH2_?'Q021"V^-!']>/TJW)F4ZG4QE:V_<N
M5>O/!C5'"QES`&T(+T.Z(8EZM_.^T>?/GW0^%^"+4Y3WVXT2%]:7:RPW5XNT
M!@KW?2^68NLZ!M:6I1_3]7*FQ^W6BSZIXIY]WVG?-EJ712G]L$!F8KJ>ST7&
ML"R41>CV]47[8^L[-=<39R*2O-/]MM/V>%2?;@)'&\WFX'/+$3:#`=:QEGYK
M>/];JH7W2.`7!]UF`.X9V!72R3A_!UDMP2346[KE(P1J%U82Y].GV*^#[W9,
MCHE_?:XY-AI4;#$+2`,,]'Z>RL?&>]%?!HP3'GZ=8V-3<;$R9Z\EAL+CVFJ4
M^;*=VEQ*<&P;-L(XV%E0O9IF*`&SYLZM:QK]^>7*KG!_0U+GG_#B,7$<(=Q9
MW0%F!LC4PDX&4-PUS<8L7A=O;4,P#).)_(W>D6%,G^'99L4&*O-V:)D/YI:`
MY0XD6!0%CWB=M/6G[H*&E%3[NK>'NX98E.65:EUGJ<RD@,>N%-]AF$_`\\34
M+M24,X!O[1=,H70B6H>[5"`E!Q3U-<T0>9P,>`5C?Z<ACPM`/5CE!W>Y.33`
MO6@>MY*#N$5#C$@PR==8W@SQU7U0$.WFP$D!P7_.I$-'F%WOJK4CFG1@J=<J
M):Y.#!#);;I@J0%\,H$5E;WO(#6E,<`(,J("$H-!QO;],B0WW2^9F?9<M+;7
MZY76-='/GS>ZWTJ01`;[-?6>![FZXY'5@W_]&J8B[5G7$E5,1/2?__R'1(C6
M=:'M\2A_]^-'U^V>UI4X)3J?3\[1PSY3DIL\XUQ[`\W!HTI?FD=RL#OV?2HE
M6A/3OF?:'@]Z@(89WXJTE.")V^W>`S#:AR0D3ZI<+.'@I_&\IH#Q;\_%-^#]
MF]C=7P6*GK24IRRM>J@F&M#C[Y(P%DR>D,&OT<9Z\WZ%\>97/Y_UAFX!34NW
M>D&VZSQ^A5_Y3@J!N$2M=16J(&KR]J`,T2B:Q=T;9P/#'FA/_<K(VQP!DM/M
M;C=8Y:^[CWVD,/&HLQ42%P!Z8MO781PFJTV&V4S$G)(41,^,V4BT+$*>=T>`
M51N;D[UB""X-]&-(:+"M<4=_!P,TK+6@EG%3K+L!'3;BESD:2-33_!0<6VQM
MI->-$;B6S>]P*'O(P()..VK&&@ZO01L>4FMJB\DU`XIX/[N\A&*V4P*QK]*M
M1[&^C5G/.AB#@=FUW2G&())`'J"L!\U]SX&FL@-7N/]9O7^ZZ%%A"I9Q#Q@%
MVW(74USL%202,+7VN6+#"*-^N.NV>X>E,/P-[.8>!$(J@*$/>AHG`0)@.IX?
MWROT^XDH4)U-=T;VG>AVIW__^]^T+(GV++3M>]$05[";E8.0UIV5]R1U73.N
MN:UX7%*BZ_5*RYJZE&';MB(UV';*4KQSA826T[E*A1;*>:?'MI6X8"%:U@3/
M[(@N7J#KD253%J9VZW*UH$O,=+]O1)1H71-A@J*8"?-]S_3Y^4G;8Q]2CA'7
M1IP2;5NF^[:KK:P[HY`9&!8F278X3;K$291["(Y&?@/>]\'KBXR3ZSO+.[]P
M#%S=Q[WJL/#D@&;$X$'6`+WA51&W("CV0Y697``W$_Y%FEV<<F2>.2$4M*$#
M+:*S-&,M'A*A9\&HFK'W>N@H!4K9>K$U_$I#M\@!^T?6NNW%!PD\2/N@F(AC
M(*R,0&V,XJ\O!Z3[P=<_*4;9M52/"CG=RD<-[%AH.RN%C%MC%ZSL05U.#IZE
MH)`0WWT00U4,.QX&,VD_\(H.!?;Z6)LE[^J@M<D:WS'80;'V'^UZ/Z&4-..I
M'0*E^[PV9P-/@NIC#(>@/"<&`6UM`\SCQ@&(LVWO_JPD5GZOO?UO`IZ8*?2.
M;?]D,K9\&$<-`2*=?;?@415\0XH1-KXT?G#63%@(#L"M74UTW"X#LPY04+1&
M71,T$AZ[<IO(&,D]&7QKTI,&VN%EWW,;;JOGF7P03==F$]'NUE8]Y&A!I]@U
M)J/OK90"!8K<?FVS+GCX-`(]RI#5HH$NQ\4L1JRK@39X=U)*=/WQ01_7:SV.
M3#]_?M+M?N_#<,Q<"@QFNMWOM.>=+N=+U3^7]R#OF1[;@YB7+GEH7:U=,B5*
MI2C8BQ79Z72FO0;-")4"YO/V1??'G?[UKW_1NJS!B'4YZL>VT^W^,(7YB!PO
MS/U8U]KZF?'=[ZEI<9'MB092Q]*N^W?PQ'^!X7U!3.ON$;_P46Q[.'3\N[VU
M9=ORPJJMQR]^EBAV$JVF^*73=@S%$2@)0P*<,_=S1E=G:(8)3NPQ2GA%1`ZF
MW)A>^\-^&NS9&@MDW=`5'(M)3>H_PYZ^QPEM-DI=]O/M8?W&S"KHH@W/'+\C
M;#9L=ISA$;.K?M*YQ>O0$YZ\')ZEM_&40U/)YN&0/B2F#S0-:JSHTE#F0/'0
M%H5,,INCLZ!$`Z#^TRI(!8"#[1FP#LQ(/83@H.,@R#R!K,4Y&P2ZVY;B%DS/
MX^0Y*Q,0(9^:Z%W=<%);3%NX'#+Z[5(-5&#5(FYR@C$$._PZJZJS3)FWP2Y8
M;UIJ5M?HD@DC$>EI>:1D$SH2%D,W\,VSX2+HKSVBE.-HV#$$B6L^*U`?T?%L
M`FI$J+>75>I98G///+$2!F#@T"93;!F9AC-&!Y6)U7.2J:7\20%A>8P_M6<V
MM5?;,/DY#Q_@9*;ZO:<VPSI7[WW6EI=DV.,E);I>+CU<HC&F&'["4@@"KA:#
ME(58,G&6GJ!&-0DQ<:+3NM)I7>GC^D'__M<?]'&]ENNP[_3S/W_1UV<=`LO#
M=SK5*BUO.]WO&TG.M"XKK>E$2UKH?#[3ONWT^?FSR)AR@9IYVREO>U]G\KZ7
MYTW*WQ/F0>02LE)D"@68)Y;^+W.5;^7A_8U[3*&](46^#Z&"7W6]5H1#R@<^
MZN/8!IO&C9#)W[9D_RS#^Q;GZ:<`>-+^G^&I9P8):BF-1F>?L,I6EXL;LZ]8
M7],?"\=LWRO7U#/=K`=]HNO!$U;1@CJ)3`ZT$3=3,&`H=J*6S`"8*5I,A]0"
M<+%`/`!#-`&H^ASUV?(3<,H1*][9#@N`V7?G`L[>@73Q6>L<,#*'[R)95IM=
M)\-Y9W*P*=N$09P*QH0S&1-<&`1,;=(?%FPRPU5*8MRC8XW9/K"G?<"(V`JW
M:[O/OY?,%`0M4/=;M2\@!T6&8]Y0S]K;YKENK@"P(Q>&UD:W[/*DZS*<+RR(
MUD5K:]NW`3$R#L/-RY2(**6J#08%,MI+-2>&`K`R2>9QW-WKC49R$QN&#TO0
MJE\=3+MA@2G0R^;AB9M8^_SJ8D'<$!>R\SI-C(Q,@MW]&994;)W]AD85?J9U
M-^RY=\VZ:,NVIN=U`!Z'G(BG79=>?&1QF1ZXE#=GCQ;1/7R?=2'(ICO5_6II
M6);IZ&\&BSI-YK0_$RB,EZ5H:2_G2V%*]YWV;:?[[4:4BQ:5=*DZ++4(GOUV
M#7.FM#!]7*]T.9][P$;[OOO]1E^W+R))]7=D@-VF_:\%Q.-QK^EF0B0+[?M.
M>=^*1G==>U&Q;8\J>TB4I01'].^<#'8OR<]%4)T%*0X,VQC2DW%M^_O99#O[
M7C6[#.<!ZRS.DXA4"2,[*W8["U"N"WT/K?U=#*_\AIQ!0@!S#%Y5ZSL(J>#P
M:\<J$FE)Y[]W2*`:MI%?!OD]U(N,IZ<\<3:8758>("(ZUGGQH!$\2TB:3VZ:
MCD)2\@"V`%A@L9,8N)MBBBG.9=`#Z=%WZD_V+ITPY!7)!2#E9U80J`$:E^9&
M09J9U7R(JH^,VZX#;JXU:8'WP4LXM,'<0P78*Z:!90IB=LFD*YG?%-1&=#T;
M)IF9X:?2M%.#9'IH2GL#JV0A9<'FUZ?&1G()>1O`MWL>9\6(<O7])?A/*R<8
M!9C5JX+MFVDF('B0@\AAV^`:JY0>X&GL%3*>HTT*#A1VXE]I6ZO5&VLMY2@V
M3',;AKY:H:1<,?I%3$YR(3G7@`5V,J,1;E>']K(8;3%U9GJTN.HSHUPK_'.(
M:7ZMB!B@4-O@#6!+/2(X&1>247C%W1<;WXM=G]P!#++/XSKA@%O_WVP"8I(Y
M-XGM\)BCX^6PY6T',]FPTTJ'3!KX2B`-$2&Z7,Z%W87?^?GS+[K?'ST5$1=K
M'$QL#@U8*&0:+7]>4G\FA(BV;:?[8R>J!1^WWA)VH4`??W]L]-C_K``U4<Y%
MGO!Q/5<];/EW/9TI9Z''8X<(]?;6IQK4`OKSWEUD(SW4?6*!9,-3C1[>'H\1
M/%.UO"3#7J][49//QD(K.*@;W6Q#*=+';WY+&OXQ*O@Y4'R%\WU*<TK<OI^W
MXOG7!N]>]M:5EZ00;L,63<*):DT__\X!&%_[XE!1^P3E1JU91VV&R4?15#N`
M188C`J6&\#CD'-Q7@4$P8=/I<4R:R3Z7V="79HEZ<YGCL`%GC,`TGV2''D,V
M@4Y*WL+D,M^UA(2]%(71ZHSM+)+V[9T:@&`K-6#*#)+#*6H"8E<(.F_*;A-O
M.@0P0"=@M'TQ@]K+9SAX/QCB3;UB7P989/;>T>UY88:?-8QT94(9/%IUP,8H
MA(9P"L!.2NZA$%5@<A/'=A:Y])[+='CN3'K=>!O3BL-BG%04J8#6O/\YQVPV
M/C/2VM\`Z*B#GF3>8RU3B)C<?LUD6"QQ#TP@=4]PVES+=4!ZAAI42+-KQR(2
M]VH8OB>E,;B6P6F@`S_V8%:_E_$`J_WS(FO)?>]1[S2)9\`[\RY==N7`+@P"
M$D>.(5K_&O6NVK&T$(AVC_OQ";Y/#7S:?3TH^OKS1MT?6:]1K-8(7"?:>[!7
M6[O3Z41I24WAT('!]GC0_7XOQ\:L]P+5^>=>R.2]))_='QMER70^GZL#P^C:
M_/S\I*_[O;^'CVWOQX@2'NGK>*8-?L:*D03N54M1^^.//^B/'S_H^O&#B(H>
M./<=L!XOK$%HN=C72!$2[BM0O0Z1&$K?SV_`^YOL[BN@]XTO>/UCF7X]X(%Y
M"K#EMPY-U,;_[+*XM%4&.;&=I3*85;SSJZ:'GWRYTP`_Q;SL9*-*:\E!I0(#
M(6)N'NO^:\Q2'DB$IRX"HENU=CI?@UE1FKHC80L'HCTQISY_3P1&P,1KA%W4
MG4R<&2;R`U>4:=_4<?[LK-/$L*[6]HE95QYL]#*ME6HU\%:;7J2<@Y40!,W]
M'J7![E6VLE^YQ'7"GD<!)/I]:87)+`$+04I/>N*1BB3]OR?*DT(H-Z<VCH&?
MBF(%Q1Y5UJULFJ(<.QKXZHEQ31-N-,;.L@];!`;0]7O74NL`O)*1P!#XL*+=
M5NQ_F\9`6@<_N0/D=K\*4$N$EE(4@(!@8E<QQ\PXD"<`:D6QV2($H)OC8`_2
M4J8A\P!0#NX-..RCUHD94QHPP/Y[??>%'#C1/:G&>';2`)^)I&4?`U`/QE[T
M2N?6$X[F`2!QKB]]C-(5#YSQ7+;M05]?7T57V]C/'`,#$=_I92K)9__KW_^B
MR^E,J<%D$;K?;H4U-H6&CSO3U]-*R,[G2P^G$!+ZNA6)Q+9MX'N<#[%,2HG6
M99UBAA8JP43T\?&#KA\?Q26B7B,<',Q"+L!%*`J4$76OQ_,O8]#0D"SM_?Z6
M-+S%<G*8[_Q$J_""G.%U(#WSZWW9-4SUKE\[`I$YK\H'\0S/+,FFCA"&-(U]
MB0_\,*/CYSCTP#*F%#@:S*Z'8L;<R7/`[`X-J&4/RZ](V!J0%^Y??,/\!+:U
M].)(72RX(5$H*W#3V@?5A2U-O)Q&V_0<ZG=]#%&=H&:%,I'E8G0SP(W)#>P,
MAD3;B`7%@N@R,7IVE858/W92MF%B&&;RS8(@W8F?KC/]CRNPC>S(K/:7X?I@
M*,6(MR7S3!BMK3H?<0"%><(XTAC$LD7+:.2+8I91O,PM?2NUE*ZEZGHU<,W.
M!L^\1EU>P]JJSL3QE@A9"U*0B6\M:E;?+Q`SUMT(9D0*HV2$1S(9.%R4B?PH
M?-R#310X]<`.%6G-RK-7'R]YO1O/[0'M.1V'-_CU@EFSOU%\LK*IZD6E'A)%
MMQ0V:6YX+?&]0#<0]5B(7LNS")#R7NY1DL/N0X]-"=P@XBC>9KU6VOX+_?@8
M`1'89;S?'W2_WURD+AE20\6)8_N)<5!4VWLE3K3GG;YN7Y0>J5NWJ7O7NCTI
MT?5RI?/I-!X3YXTOY3.8:5F6KOL7D?*_4Z*ENE@TP0XNE1K;H'#")`%R<(QL
MWN,LWPSO/\;POL7`\EM>NK^!L0-1P2N,,$T,!OCW/GT"V"5B?P^(<]N"FK&Z
MH\UCIXC9(>IX/GQ,&36=F6(.1+2`GCF096@'`''\@SR]CJ*R%1F^5Z;/@4VR
MG#'>8@9APPW*I-F0F?Z/;K#=G/3GLIKU\BU;J]T1YS$K9E.(KZ6X1=&R!`1M
M>)5@95N0JF4HX[/LJ2L+(MT.#BWQVE0_M%<C1M\R-Y;#0CTP_M/8U0%0ARRA
M_%V<7.22;R7J&/'DG@"H9G;'GG-6@0].3@%K34_Y"HG><:RI^J*)F6A!0WQ2
M!>NP_8J+7-'V84I"D<+G.F+6U+FW\R;M5(%`53E!@/8V9NWT_<5WLGV7R#P@
M9O:9HWG&2JO=:[2)/&IV+30K1PY-BW&4R=T.2SM:V#V($_>BIQ5PK2`K?K*Y
MNV2(O3[FFJE"4XS_,12$?:B4],^<3B>Z=+D`>UM&W`V,7_3'CQ_T1[7ZBNB)
M\_52W4-\QZ++=P)B"N4L>\YTO]]IW_=^WDM:^O$][H\R;$=H"Z:_:ZD);8]M
MFSH6B10IQ;J>ZM!<^824%KI<KI32,F*J)=IUM;9.]PJ#XHK,WF1VZ6^&]S?`
M[CMN8\=_]9HG[HSD<9OFX:_(6^#Z+=;X67A%]#\F-FSRQB75'I]/SJE/@B.#
MY(%*?-XP*,(4`JN(;98@CZ8#;PDT_@=&M&(&Y515/T/Z`6#!?3OQ&%(CZYP0
M3-=C.YAI/@!G65T6^)Z)LS%NZ/+,:DZQ/F-*>UP>XQX!"Z:]O-AJ'6X,')-;
M%8@T'U:7DL2CI))L0TU,<I;92!CML<P]4![-MO-$OC7,44``PV>R%I=$F]JL
ML="8Q<$*#T"//K.N&1&X.6#`@8T9'BPQ*?LH@>)`)*GS;9NX32;#FE0@YK;Y
MOO:!O39()M'@D_8C]OORL(9RYZ=1K9<(!9[&D38VDB>U]O,SB4'8#9P`5D=B
MB#@7%91G2.3/._$IMM<&.P9J[6$Q`W7DO+YUS+(HDQ1EIT>C:.&#-6N\&P*?
M`>?/QC>[L;TX<[$+$2\D=>APN+38:79=E(\0F(5V\'-HH'U[;'2_/VJ1J#LL
M/24Q8#;LZ/)I/='Y?-:2H50&X`:[/PJLO=J3X25[U.2T(E?XH!\?'V,2O?ZS
M[SNMZU)<)JSG$3.=SR?:MHWV?7?=-P9K&%6HV2Z0?94@DE3Y823^9GC_N7_X
MD.$]@BE/R4I^'V.S8RGYD#7%RI8/6Z?R_'-F?_?*#S\!QC-6,[3UI+@-I]XA
M?NWP^J9@_XW8T]#`/WA&!(A`.6@2"+F$*%(NH?[Z--]*-&5B8U4T!92L=5,\
M>0[U@!D%+.NP=5*-$+9MW+G-E81%UJR@>/Y^>"T>/M="6@$H4[:*8#+>#$JK
M@J/_XGGT10``(`!)1$%4_H1%TYI=OR#@K^*`$9D!.3*N#A9PJ-\EB@N,*!6&
MI"<:3MD\<H1\!S3R*J-(=4`NL6^;\1`NXR`<#K^U[VPZ8$Q0LRQ[=PBHK54O
MTV&CHYVL!XF'DX3U'PXBH3,PO!*DXZF!,8Y!(^I/.SL)VF<^,,RU?XJ:Z9#Q
M=/N0UB$KB0;'R7[Q^RWNO`=X9V?!UM:Q!EY=09`XO*:,OM8YS]GM&IF;<_V7
M\%^F+$Q25;7ZS\NW['L9_OKY^1D^`^-:D+O_/>R$QOGC^U"8V9M[E[M>G0(G
M:WP7<TNH*P-QK;#+.5?0"=;\_7V/TR[;9^4L]/GY2??[8SBUU'NT[WL!UY7M
M;F>4X-CW?:>_?OXU],*60)-9VWFP^+KK)&J`&-?M;\#[*GSE`Y/C%QGA0V3W
M!M!Z@_A]&1G+2PAU!G;YUS48<O!E3T](#JN$J"VB3,1=[,($445W6WP(",=[
MI4XV,K_0$K-&RY\/=<X*I'(PV<<V.H*'UFRB=1B2$)G\B&<+E;E&%L<DLZD@
M.*I8[`LT&;09+*8^9M\R$%/42'@AU5QASDXBT8Y?US&BV7>RS@GBJR8QM*)K
MQQ)(%RAHQ;%FD-E<-E&CW6K*W/YYE&K5CJVWZNV]8&!:@G>_$"Y>S4H@3W#`
M."JF:`;VZJ8Z89K9ZIZ,[EYZ*(%^WQ.``_5]AGUW[]U$?^EBN]FWGU"N(`%(
MZ[(4&=(*)6'(NOATX""FBB$$`SHQR((*GAMU3V)D=6V!EX!996Z64^+_I>+Z
MD5O!#6"6J$SGCW0M"N0W&9Y;N(<(!(.DMA(N$>W=TN\]N6):]'\B>]V2#0=,
M&U9_P/JWZ[<L"YW65=]C9,<GV&!9%KI^?-#Y?`XWOBQ"VV.C/;CW4>1UV*ED
MHF5=Z'0Z]4")=JUOMR_:\PZ:9S'OH="RK*Y#UUCFQ^/1K]M>`RDNERM=KA<7
MFI2-O*P\$[8H%#NN`=(T<>]^U[JK=5<+O;XE#:]BLR?MU5F;_26\^692\<L,
MJD&-41RQ_,8U&:U+>?_S@EZC<!@,-L,M_O,.^["CS2%AP,=SJ8?3*04MQK!"
M/3CR(W>,PS\+V60.`7O7R7&LJ16AIS8<8A8.I3M3H%Y>ZP1`&][96L%&;[]?
M^Q%K9P61YV_#\(HTTI`GV$%_(P8AF$@\/%N98GD5`:RB$`2=+&KX`8!I+#QD
MXCTL09RQ-DVV>E]^<N_U9W>FK5L4(9I/BH;&8FE:3-G+8BW8E-V@M4$C-;.%
MSTSQ>)T@Y:D&-A>F$@:X2LC&")M1EH+5+ZJWK#4%'TH3O%Q@#&?UN.8L#MDW
M+6[$PHXVO+;10H96`P>04Y$.%1'?I@ELOXK[19[LC?8S^O>89T%0HE+/C8/.
M2RS):+[1I&41"7QX6:<.=JN$'A`B<.YB@KI'>(4>FBI_9R4D0_I0[EL"QXM(
MEC+LTS0P#Q,0F2GO0H_M,;QIC9=VM-8*M-$2,WU\_*!E2=T+M_W4MN]TW[:Q
M;[$9R4R)UG6E;B23P1NW_NB>]WYO'H\BNRC@G8S4D'UG9$ED:W@,YAAA/QQW
M38A4]+:;9ZA/_3?@_<<`\AO`]2VA[#'RDV?(4N3EKW93S"&(T?V$5]P99G_)
MD6!2GEPJ>4]C3"H&PI%V/KH9<\K83/KRS).70ML,GXX4W2,YO"G^K]B-LTHT
M.67`-0?V:4SS)$'5%F0SR2SQ71Y1&^RN25>)!6A5#W])?#E!SRKR2E3))#0C
M`&+>Q$$HSDV0\#]1`J+O:S"<JIP;0+O+@X*SLD\)6A\238#B/;=I5;`9VR$U
M3L/^1P-=V&PD+BHE!+8Z:]`Z?C#%*7U>0ZL!=]-9#@`W6ME+2CZPA`+=IZ4&
MC&U#=YMHH#;+N$88HQZY]\"?[7MVT@\;C"%'ZWH@+[(R@9%\QOZ=)1]BDR5*
MYF/G3I!-<9_%RK.P*..GFZ!V-!&E9T<]<&FWC\]))`XX*P!>JIQQ?"/1!^Y_
MU7O7/\\UD2\#DRP$S@<J\8Z)EP*F$US[I@$OCB9$]\>-_OSKSQ%CG%CM4WU=
M-"F.>]Z+_GR6S2+&,40&8!0;Q@'WCZ4>ZU*(BJ7&9?=G,V?Z_/RDO&?3S^3N
M1C$*0E%L-AN&&M>TT_E$$FQ<MOA**='E<J5U76G;-KK=;H/Q5;:-7#-CAKZW
M.?P($CBD8Y]QE?N6-/S/0^.7A\A^T7K7M7Q?8X:?`W?UN?SZL;^J4G@5]!]*
M@?GH>(:=T-'%E9#E-V#!M4_(R35F<KHC604?,*7L$!H%5L0,&E24%_BD,:')
MA+IBQYX]3<@;&L==]FX-^CR>-`&";U"<E6"J&L4`9.99^:QLM)Z\X1O)0_[`
MQKR`*?`M0,>-X\%'_90DPX!"/GT%83:$0K,L,H:V%,M8SR%TR0H\/M6D=.YM
MQ93&=6#6#A.=P:\LZG#YT-]C)^@;,$K)M-O-P]A\=7/.-?!`IXL53*1;\FP#
M9#KP,='&(#5HP'?(87B`LT"_VLX%71?(1CIC=B_YH3+KNI&[\X*6+$C7ZVMW
MD5S;TUFYR5B_FF%#EYDI*P<6#.,X>%:EN1<(A#M8FT-2+"H"J@*J2I2QH`L"
MSPS:APFUR+"B(Q<BP]WC&0'P.#9P+ZG7-K?(XG9J6:#8'^UX9<?7I`Z](!\N
M$2-@8<@\,LA<TKJ4%,#:]F\_N^\[_?GY%^U92"BI^YOA6+-(^9GFN@(6>MN>
MZ<^_?M+M]E!DS;[E^KGC?N1<FPQP[?8LM.]9A^W08*5/YXNR,<1G#D%R%JI!
M&E4BDQ9:UY72LHR_:^$3-$)<=!B29N&54Q/(\W*3`]4__V9X?P,^\N\"MM\A
M=0,6<-I,?H=M_J5_6/$XSSY3CK2Y[R#Z@U;IZVRX:):)G@#2B192R,M3(4!2
M.Q9;-KQ/_[*/9@V^B(_H>+8@23S/QG';<GJMVO&B2P#:$CF'@`!/0MQC5%`)
MO>[4H8";:-WP<&J(=-,!*R31\?#AL34&@<W/1[POFP(!HR]1SSN(?6.1QI,.
MC7@[)/PG9YT@UF4%"EWT7+W!\#50X&SCH!V/PR0\A"7"%+*XZ".K&/;&[F5=
MX<T&%XOL*?!@)M/.#=KXS56C,5IL_;.1%57V=!@C3,J?&&W0NL.#&4Q"8$H!
M^QKY>,^\WI,=2K*Z>G"9L)'C^C19:W5A^"S+/KZSQ4TK)G,<5?EK=IV$5N%E
MB0I_/]C:!QI=%T&\9(!+M"WTNY5O,M-"F3+-`NH3IQXCG8DH$?=AQ2[+8E]H
MZ.`<LHN.>M932I261/N^.3TX=DV8:J1TS3M?3DLMUD3IJ(F%[O<[;8\=W$78
M.+T`J<"H,1[O64I,R[*6X(<LQ$N;(<&.CE\SAT?X2&MD*KZZ+13DX^.#UJKO
M9>+BA;UGHN6`2.H+1B)FH7W;:=OV$>YBTN7T&`@[45;O9S37(?)*OV_`^PK0
M?*+?/<`83]K2\O+OJ,:>O(KIFK7(:"[;#Y@U@Y\QNV)_^YD=&-'S*-\G++%8
M5I.?2R4B/P;;_K7):9%V=Z1VL>/,H]\;4;]#`M"/ATWX!.HXIUIH'44[O8ZJ
M]R^QQ$5B<_7^$\!>-`#!3Y\UNZF*TU=:FQR3PQ!&%T\QN+EW(I,G!5AO`8T.
MV@Q)T!%`60B'DXB##/1A64:72S6>K!N$8E5C]+B)U."%V]!Z+JP&93J;67L-
MEY:J>1:,2T.[69G$1.X:.0.X@NC77Z==1=ZD[7L33*D;TU4?4M!E.@V>B.GN
ML(ED]JU[',Q!MP8.WQE?V'2MKBI<V!0P/-TOP@(YB.MMH%4(I`,2*\6[#RSY
M04'FU@-@^+M1Y`AI"RV[C['28#<0T=KV"=Z[P?:Z=T@P+IK<\Q=IF_LSD$6Y
M2Q3_W`0FROJ`G3.KU4MWZ0@XS?3/%O0O"_UD!3IEK2!,&.;`VO;L=KO1OA?@
M)G5A0_LP'6A2?(&79:$?/WZ`+``]HYE.IPM]7(G^_///T-E#N2EQ?5,$;9:8
M+N<+G4YKU<LR26:E<V-*QA9P/+_[GFG?I6AWJ6B,K]<KG=:U`'RPXFO2D(R=
MBJGUG729Q9(66O]UHGW?Z3__^=^],&$[(%2?P3[4U@N25(9HZS5+]?[VQR5]
M#ZV]2"3&NL;IP)'9T^8;.+\<)TP1J.8CS&QT5A/?5GX%B#[CN5_`[8(2QDC;
M8'5L'%<48BX=1W]'0=?K&:+B"<MH-R;V4H#PW"4:9?(@5"@RS:9`RLOS(@4-
MTO%:!O-4;J!!21U:1KD/$`A)>=$3\:%6X6"H:/:.25"4^60WZ2P!'_G=R7'Q
M>E3H]4P/:VM$.'1GHVT;@\23$`K1PYXR+.4:X\'*Y8!#GU_R@7,*^/2K`(,I
MT;$S>/(V_*TUG;;HXX/!4:\+TN"9>IO1VDD/K>P`[PH8&`9*`IL_!%K-*YG#
MB7Q<'[1'M*=5+35/RC?X".C.GC<+<"W;K*S3,`&O8U9DY(,!,7B',:&N6E0,
M\![Z>(-C@HHNUM^A+;-$>=WBD!@.T3&0%&*)'_1>AO`((5+Z3%7'XC,4=,X4
MZY>TCKT3"PP=#A(]WTR8W";A6I7K$29*%5LF2I5!'7*BPLAR*HPNLM.=;1:A
MQ[;1Z70N7YAUL,*V[05HKTO1^0J2-SR.6R7&L6*B']O>WXG&:N];IL_/K^*S
M&Q2Q#6QNN22F99)>B&416D^G,CS8W3>JDP,1W1\;+:<3K<L22LCLW<IY+S[6
M*9%P(LE[>8[SZ*@1K$L,UP\N@%G'6S>C/$??@/<7V=UGP1"_$N;PEJW84V`Z
M;$6BEN[A\3QAG"WGT'`D/SGIJ-.,?\:S[Y?CH`YY1HE'`#.8\;&S<DSDVD6S
M=ILJ@"#V<MJF/[K@,JD6(KW`@3D",S`L@5^QGPTT@-X^.P?O!0YV-+`BRKTC
M?KJM/CIB`\0]O\-&:=)9)#LDA@E$4W8I8'HMN]TO$8\"RNI-E3RF,V2DP`,W
M2SJAX6S`^LNU%$!5#>A"J;6F,$R%P%4H2+<C\:E;MDVNW"3PM].XIVSMX)XL
M5Y%[A1A&53E)>+LJ;,TS,`_]=4`3?NL,4"-<R6C,59I;;7\CL^O""EIP!\<Q
MW#:(P6EP`V]I#79C_PP5U*%B@TF!3"RNEL2*Y6Z'HECO!M!XJ=<T#:NR^IF1
MI1NA7`8BA\=PUF`J55@"HW4BN^&Y:"OH$=18X9#WM]5UIHY;3JG$,H_N@9@T
M3A\YK-:]>OT2R)H$GL<E+;0L*^V/1V5YI0^;<D*I>&4AJ8!)U)JVSVO'OFT/
M^OGS9^UT$`CE$@QN21@!WPKA[?&@T\<'+<NIG]^>=[H_'EU/;.=!6NA#6UNL
MUW56[\5XF=.RE`'"/1-5UGJV*&01RGFGO_[ZJTN/]M;IP**.A\,,UTF&'N.>
M2Q@."VN73M*-@6_`^[<CY#=_!%N/]&+"V#L)QTPDSRR:?O&S<9N(IK/#[2HP
M)`BE"=.+8=LYOTK;8PN?7*2JEJG81B+I25BWX<Q#1YA\=.;LND469.PJ6*@6
MC`YT)@/0C04;Z:G3K,I"EWS\;M=RBOJ]L="*LZ(9!<'Q,*'P@?,'L[.E<F"W
M@5&)V7IV!8T![PF[%B8%C64J?U#64\:S%14'P^)J-!V$?`X\H1R"?+SP:/<6
MT-6_LP*+E#2@('Q/F>KT-FEV+;"$\_886M+4)]^9%*B:/816QTRLBP8F:TDU
MOFN`79C0-HRZLBSJK6M3')$VD4.][F!413\SS?J+!_C:*X!J+U\'E%A@8<'E
M+#=$IY;9)4KF@1=8'(J1@)`,C:XBK%LZH"E`\=S;T%$*NBX"T^\AZTTMH<R3
M*XW=+&UQUC6I$!2SY%,*3>=B-C.!*TT[\BSE#>K#AME(VB`SLAUR-G9YZ",^
M=-VBUDMF&2/"TB(IDI(H-+G!`'OE.J<ET6D%_UW15/;U>B7)6859](U+K;?0
MW6&=W'@^G>A\.M.2^A'0NJQT.JWE/+*X#FQ7V39M<BH:ZF5)=#Z=RB'DK3];
MX\1V8LFTI/IFVH&&^OE;WBG79,2\[X5%WO<B?3+2A_;/TH0.QC*NM$/$CDIW
M[VCZ#IYX3<[P%JYE^DUOV_?^_#C<E@^HJX,OXC<3TYX<MV*[C&A,@B1$)M^R
MU<S4:T4%AV@/;I(2^I,;^IV?G<Q92,+D*7!#F)"E$CPX;D[)W&>MC=5RAI%+
M3M#R$K)NJY$IA;--"MA79,@E>/HZ2?26MZN?2L?!D)F%'!*2V+ENX1R80*0V
M97.>^'.<S)$'+7QF'^SA[CL7W6/[WXP!($PP[#6`-P5M\M:.):ZZM.;1R9JA
M3"F9E#'-B/5-D6%CX@&*F*F[*S!3:*'%TS?=#`9!XI:(]?/D4-8T\Q%EN(XV
M48I`XZ<E#CX$H9R;#AWH4^+&38'`10)(^F[_Y`:L1$;;W@S,.0E#.^8&DH@I
M21V>(J(D94-GZ)BE^KPE!G]6*+(2I^&)P@,(M.N3"N7;V3(6H:4"BO9Y2TJ4
MZN\O7&:-:GY87W$3V$[9=]86&<H&+@L9VVY=L!(."XKZG1[W(.6XVYDNS-U:
M#!-!6=IY=ZU,`9C5'J!=]Z3BAT"252W+$KB>Z*`8JM<;G'Z:["D/F<J^[^58
M<J8$[0<6_TZUP:]E84I)*+%0XG+?N+W_)'0^G\O['X#]?@R0#EFG".F\KO3'
MCP_ZXX\?=#HM:GE9$M.___4ONEXN%9C6YT2$.%/_WY)SO?[EVEQ.IQ(7+&78
MC*LV/\$UV;<"9OMS2</#G%.Y-I]__:2\[71:%DK,M-!@SOM_UON:VGWO!<;8
M/\KWM\*F"6'*OPF22+\9WO\RN_M,O/`N6.9I5[O/7T]STX5^S3=77A1?,&E&
M1;WDD^_@%W$Y/3EV-N)9S%M2@V.DJ^`([/G-F-5YS$X",4P<+6Q96IXS/2'S
M/+\P;-B.\1>1#S.[<XV2N1`V6U!BSTL"/V&MB8N?0-<&CMJ**-?HH-D7+3A(
M$9G^1T-#/9@$3CUQ<E*8;#2MO;4I[/*XM8DZ#H$-M,YJ@'#X@R+@HEP+1.P*
MH8,`NQ&\PLATS^/4K:\2I3;H32FC_B_KNP4:TNXW2FR85\W$CZC>Y-O_I`<B
M.S-K!WK\6+9AULH]TL;^`EQ=H(RJD^M6-R_Y6-[2F4NF@]`'S?(?^ED;&8G3
MU4OD>L**)24$6YWISGV]Q["/_I7H#VW>[SUG2IR*M9?3^?L"$<]?)Z*1\O6>
MKR.F@#?=FW$=P%&"D='FH0:J0#9#^$;7?;.X+D(&K^D6>#0\;@&TUW<!I1+,
M^GE0TJ"ZMBY+23*[WQ_P'N421RQZ6+*Q\ON^T^U^IV5=A[6AMCVA^_VN$O9L
M(P@3Y3KAR4SGRX5^?'R$G;^<2R+:_;%!1XIA'QGWM-FO"1&E)9%4J[4699US
M[H7]MFVT[56#R[[0(2'ZO-WHL=WI<KT0I43<I"8@R^GK:V*U)B36_UL3&<$>
M59^7;\#[#)J^VC.7%[KQIA7X--GA-UGAP8<:G\FG^5_O?J.\%9X1#=2K4(0)
M?,?!=B%C66*_(YC>]U"?#ZSEQ"WT:K"&]1`-FUW63RVSV\S<X`:<S^%CP:',
M>7IO[!`&?H^85K;:U*+V(9..N[4N!D9/:2^*&YES%@?\=!C(`BW;>(S\50=@
MR%HB0L/>B2T[1:P&[9C8;S2@D^32KP27A5%.Z#34X911?AXUN,EL7E"C),^6
M9<K$G(;S06=Y06T'S@AM<KPQV0)M&)$,;'G2@X.M#<IQB`$;6<9H>;=SA\$I
M&5*,#IC:O4ME(GQL9)E(DF(W45ZC+)C,>IK58)ST`34)(JP77NP+.XH&'H;[
M5MLIX,-KW[<4!I"0L_+3$;XQLYZS:.F'?9/,\%L_QQ9^4%/)ALS%%X&MR!(!
M4T4Y&-JN]\YU0N$=5E9I-`EE,=9SZ'[2WITQL6^S0R&HHIZO,+@B*)TN:PE%
MCQ$>K7`U<P`QSDVV(H[$\9K99DM&A,Y(K&PCNXY?2CSWPLNP*4O);6:<EA'*
M`=I[D4C>,V19*3%M^T:W^XW.YW.-@AYJB-OC3G_]]5<M^A+MDG6"6FN(I$0I
M+<3,=#J?Z'RYT&/;Z]I0"O0NHY+Q\Z48JD?(C:\M,<0_/[^H2:ESSEVW:Y,*
M&R./6UL&2T"B(:LR91H(>,MG?0/>OXO(/7`+B'_O.+[Q'?KWN>^M_`:'_!I3
M+:]@WDD:KO]K9'<D'$9B`7W7LPE"YZ7`+YS54&]BG2!,8:PO>AT(&PE%X&(1
MA1O'+?\7[MKAM8\?3'4<3^AT7/S$3-A;XWA#J2FFH+$MVC-13U>KEBBP-1UL
M<@!RV;#-#/_92KX&DB9LDP**;/QQ,=&J;A8<.!(0CP0GY1$$S`E:6C6S_+[Q
M&N:/88-FTDQB.R[/4K,J0A@V;6RW]Z%*&7+GMOF*<(T0Q2`+!BU<N0^=2<M'
M\@8&/2C<EPRM:$X0E)%-@AB;@38FKLX<NY&^8#7"^.Y.GVM60`&91>W0$0\P
MV1=669:9J7Z2^;&PP'H#D^>MM=_/!PO4`'SV_P0=,;>D+P,@*`#'0F5=Q4%=
M9FNIDT>(0.!<X*)SNV886+N@J,:NB8OSEK'.=$!49=.E`/04HHAF)YO$HVFY
M6<3L#.`%#+DN_;YDT0TR"?PLH;6WKB=:ED<):L".2`M",/[!A)K[?A!8<!*=
MSR?ZNB7:=W&;2#()>"D-&\33NM):)0-:#D.T<*+K^4(I);HU!ED&/B=@^%-B
M^N/C!RWK4MQH>*=U6?I]*6YGY5Y<SB=*_(-N]QO=[JEZ]&8B+FER/W_^I#T7
MN<.^[;2F9/8,CG7@9LX`UT9F'0M-Z.4KWY*&U[C,:*CE!=#["W]]"-=F;*8\
M_=PG'FEORQGB,_H;B.H7KQOH[(B,%(%UZ]EF;WOWX,&6R/S[>IPKD]=83B2-
M>#T4`+:6@OC]/'_N9FX/.+!C[X&$R>6O=09T>5!`I4Q(&?S?(GX#&(0L]Y8^
MD9<61.WQ^*&*78&'?!;MLRI0JALOFX73OML-H.&46;>[JKM=;X>:"7'%]\JP
M_U(;6Q44=&_LQNHE/=V6*+FD+P1_JDF$8`:!I0+.!O14%C=3+KI"'BU_?&\0
M+"5@>?.>:\MW#/)U%CD-;3':"6$N2N)4"Z!Q+"4&-=$FNW>/@.O`5:^<<*C1
M))RAK*(PUV,H2_G]&K]C"V:<:X!EF2WKC1[/RK$!V%V6T,E':[K'=^2^F5-W
M!VB_D;//*T]M:)')>=(FC%P6=EV''N"`##9E2@SZ70)I`+&+K+::971&Z/I<
M]F]R0LD!VVZ*#'D1OBI-]YM&<>#U(+J3J-9?Y;!"70,M`0;`83C%,'>@+QT0
MK\NJNH+C<XLXM\@!I,NELF3:]ITNG5+U#_^ZKO3CXX,^O[YHV[8P4KH5I=?+
ME4ZG$]UN-SJ=3K0L:[W^2:UUY].9UG6EQ^-1=+I`X+3WM)T/)RZ):'5-2,LR
MO'3K]V_;3MNVT;(L=#Y?*.=,?_[Y5XGZIN&'G7,&UE;(VA\GHP-7G5=EVR'D
MJ7\]B(U#R-^`]^^0,_Q-Q.E+>EKV2/<Y0&55UKUT7OS.>9GLDTF1\"N7"0=2
M@E,W`RNBOT<L$SB3+DR*"66/HQ-_B$DQ+WKUG@-HF<DK6.:;!L4)3V3M>XRW
MJ5N@@SQSF3!%FG7U4X4^X<QC48ZKB[=>)QW9R6`%9K$P$T8G"\H5C)71L&82
MUXKM!405@3>M&"Z:.D=/^J;0Y:\TAK_&=1Q1`-PH&Q[,\TA_\F[-J0VHL96,
M:.UQ,LX$=@WC5*4/K`&IB(X:%I!",$QTXW\O!01W@WTR[7BM!:S/81E)[]>7
M36!#.Y8E+93S7EOFH-N5,9!(4JR/NO\GLMVUQ=G#25L!5-O=_7[9V.$ZW-7W
M56='98:L#%/9/BN+,<0&9P>T.;/%,QN6SJ7SP7$XEI2U$X68@E$SQ*2812RK
MDPK_&+KH[@9"J?X,VGFQ8G'M0HO2!^R(X35$1XD43>WRD/"H@@[T/<Q#^E'"
M!U+<+C/BDP;`F;63B_IZYUR"P2[^:_IGD;>A(Z,U;L_WU^<721;ZN%YI/:?6
M3ASW)C%]?%R)4Z(___RS^/$&K)=(T=!^?'R0U*&R?=M+P9JDN#2DT3&2+/3Y
M^5G6Q5H@-L:YG>:^;R19:-\VVE.J01&I#*4E[N_JS\^?=+_=*2T+?5P_BK]O
M&^)31MG4_:\CH*/VGV[1I]?KQ,-'V8JKD)L2D`-]`]Z_F8I\/<;W*"KB1598
MG@-)I]T$#T\*K?./#V@V'(>+0&2VS@$\5AN[SK#0W\7D[+2>@GR><8+LFOIL
M4\%,.T]`$R2L:4S_769ZV3&>$I<)+OHI.';KD4J`DSEF74685-`B:[NP(WV>
MO%`4J(7>7+_PU*>>P>SOK=+!Z@`&JYL<>!=`+P`:R0,\I%EX`AKF<X*4*>,1
M"E'1#+HT3N02JA(O7C<*K&<[S03I;%U3F8<4@KN8L9/$Y>\3*[%=!RL0Q86@
MB,`[M.T_F6J+N'U/UJPP<RHMTL[$9N(ZL!)IKMMP&P[1M*>P,)(:Z(RA).[L
ML=+&DY;GXGE$DHX!!I.R;>KM=3/(*#J7U=LH&O69]3=V0UJDW52PJ]"83DQ1
M4Z\VDA@,UF#<BAKJ_J<)M*ZY2W:Q0`#-*DYS`)NK;+-@>1D2&-U*D$":T7R+
M-?G`"D"&PVMMNAY8YZB8T"$;%N>*.K<>6I$@'*1U*EQ6..M"IL^QZ3`''"1N
MGYLAIEV1(?67EG6ECX^/ZIWKT;"RNJO78<\[?7Y]DDBF?ZU_=#WLL#`LQW%:
M5SJ?+W1_W*O-6E;=C)066M:E#(YM&WU]?16PMRYTO5YI62[J,J2TT/7C@_9M
M(R&BKZ\O(A):UQ(:4>S(:L$.THCV'',6NMWOM.^9;O='>4;VG?[Z_*EB(ZT4
MIP6K*&M$^+O%/!>&?NF_YW?T0?P."9E\:WA_F?F=,L)OMO9U!J.:F(_&D.0M
M((J2_HG/F'#LV_I"-/(A2%>&^1.P:]$L:W"H%A,!BL+JI>2%"2]W$<4AZKY4
M2SP*I4`+LY8N/+O%]F7TMU[#V0<7```@`$E$050MNG$7GV'`"EKU,[:=+5,8
M#)50[%Z@#B)XL-@9OOO(9CL6.(8T*O\:''OSC&;PBL5)9AQDD>CI$Y^.)J)=
M'52<LK,]TRQQM[*B86&%XVM#.N&C=)>%>_LW(<-5-W@R+<BFG5,,1HJ&^@:`
M[4#!,+8=F#:C^X%$322N#.:<*-!M5FL@;F"M;':YVN5CUR0CPRS6XY6H>V4)
MN>2UYB3!U:&TZ4[1+[7C]YS+1'<;Q',M3S(3^0/X-_NGC-4/#+0DMKA$WS>"
MKD%ONYM`"]>5$!Y!%C",A$$>68#M%NT;>I0$F$6SI>W>Y^Z@(<J#O<7<$DA]
M6EM]`'(>X0X\`'0DZ<#NEPX**5KP&4/JAN44^\O*,QBE%0DZ#"@#XX!8:;,&
MW;VBZ:0[4STC-320[C[VK!U^E,V:4&A?>+E>Z?/SJ[[;6B:CSEMUWK@Z-<P%
M9_?[@U*U$\M[II\_?U(6H<OU0K>O&RTIT<?U@W(ND<7M.;[==B)B6@#$MF,^
MK:<RU%:M#Q^/.UTNEQJB,0!ODM'U>CP>M*2BX;U]W6G;-R7Q:?ZZRCV&Q\R"
MSDT4%4[5"@NV7M+&<8-(.V<X`D:T[.@;\/ZB]""2&C#]BH[5#U+-@&^(.&DF
M:QA,U!08LZ4H18%-9"@D8N?>%B5S\'M&SR9C6$<M."):'TG&^@HV"+Q^KCN&
M"5G]?\M4-Z6RU3FF;H.K1RX7N4_"*\<JI>'E8,/M;4DP?>\`1Z*0"9T;Q\X"
M24_G.Y\*<QV'4$24WG'.GY=V=7+1>2]64R3SFA#T?'V("X0";*:@VT+*DMSS
M-0;&J`DCJ1&6F%8VK+CJ-Z$^!'Q[<WT>!DC50Q=-"ZNTK8E[,I!VR1@.!4,G
M.8;VF@1!):XQ:&Z1"0>C^_8S#=18MLY.W0\-)W>/SDPCO`(!3`H"*S3S;V."
MBWD]ZG>[)5I[+E.5&`AJ-`&HU.'5)94X9V3TVXN?6CL^L?<!%PFE//C?$[+"
M!M38*%MT]$BMJP!2)4PU8\G.@YPKX.S`*"6U-.T0IM`/7RQC2@KHEQU@<4E[
M7#L/"=C7KLU,VNINN!10*+MJFF'/WB:_OIMG"]G?(P_P;GL%Q]$)"A[>O7;H
M$_UU!]/=6NGBG&YP.^A+)^M[KRSY1$@X$4N)Z97J<D"2:-]R25S;[WT=1RUS
ME_Y!JTY$:'MLM&]"ZYKTX&25.*SK2BNMM*XGHI/0NJRT[1LM*55)3CG>S\]/
MVK:-<M[[^W>_WRFE1-?+A=()];RI6O25D(OKI;#`12NLB93<AV!3!^#_A[UW
MW8XDN9&$#1Z125:U-/O^;[D[ZBXR+^'X?OC-`(<'R6J-]MMS*)T9=5>1F7%U
M!PQV:2X-ACH9(/;-.J^\FR6\(J7-K''MU9\T+&1DSN]>IG?$:A?%65Q^([S_
M=I3W[.?78C<Y29;]!/7@A&IP6FJL0#R*I;:C.7&T@P\4>L1!L'E5=G/0T*_5
M"H_\J"]R-]#@Z[]V)R,XD_%?UZFJI^^**UHEGN='-Z47^&I&/"Q(FBIX@2M\
MQ8U0Y^LSHQ2!"IU\8;M3@'*YO+B*)G\]2)%K8\EES!J-[-7C4Y%GKACO2/7I
M:!2^P:(P52>TK%8%7=@,0=ID(*)19&XS3V=Q4T\JDK[I&+].[B`%AIL*D8FK
M*2E!V/:I\T!A(S]9Z03B+L([*)`(S=V]=ATZ']7<U[*YY69"'XREU54)_!QP
M83PS(%(O_/VHGT>2S3NU%4IS$>;$4XXRI2QN`<+1>K-5FD(D@L2RL*W5T:0>
MF:)]<PMN*)&I-IC!3AZ.SB<E^HR"O)09`(C!ERDE38<=6;>F4[7/(8FVV(D%
MB%TG^-];\S3[[6H8F0U7Z"K4!MKT]+K62%(3DR2VUV3J"NT;"DM?:&XA2FEP
MZHQLVE1$IZ<)%$3!4=&%>5\H!`<NEZU.+C9<KU<\'H]^OS)YK2E-#WH1+<#;
M[1T0X(^??_3B>-_W?@#[?C'KW.6R8[_L_;-^_?J%?_WK7UW89JW-%8_G':\O
M+Z6ASHJTI7%=>O.1ZG?M=3VQ,S6IZ7!__ODG;K?[2`1T1:YYEQS:LU]V_/&/
M/\HRE?-XCB"=,J+3%+?N*A6(4#,.=AHB0I.;#N*[X/T/5<$?@:$Z!2-BP@WU
MWW6(.A?B,U*G'P0<K&UV?,B%3K\G'UXR+K18:#%=4T5<Y@>*J?G<)U?8T-1"
MH:<73MR&VT?WXM39"*QSQ(X9#7?,H\RZB&*;\%M>(^;1P^Q"82V%$(4TF")?
MC6V;W0A&826.U*YGU)-`:"7!AN.?K5$(:N<<EN2KW+NC)KX8`**X9\DIP@4F
MF`0R-G463YE(9?:.=-&ZWCE#U/)9N4'BZ7P[!RZ\"H*>9^ZCC,2U[&.!VQ6<
MW#"T%RR29!)JL=>T"J;S:IGW0Q"9S<K1Q^4F@IK?[VIW)%N_QE`;S)$:%S,?
M1IRJU:S?.G+0A,+S<TDT9D1F[CG/WKLU+&S5(*\J=H0N9GQDB\J&_L+8*HV*
M1*O?KSKG@_XC:A%3=2RD421S43D`C#;B%TD.0>V6O5-%;]@?_IH&-)B!6'/L
M-(6I,.K6>/,D=K2?-=YK;U-E"F^=*1$]'$8YH!O=6:)S]/O>TAJ44O2FCI2K
M">00HI[T20,$1_6[O5Q^0J#8]H37[15'/O#^]D;7LOI^TSMGUCI1O-]N4%7\
M_/&SASP,K]GV#'O6="D<[X_[[,9)Z]WQ//#V_HZ?/W\,$>66QOO=UL\F\*R3
MG?:\/RHO.*54PC5XKRFYT0BM_,2NNSD?E:\/9#W,1%();A?/Z>%0$.?#-'CC
MA<?$J9C?MF3_SKI6_T9!JKZ\DD\?Q,>V9+Y0F`M'#>D&GM\K7[=:D"#]X9,?
MH*:+IVA&X;&\3D6R*<Y@#`UF6L*$<G_B2HK$)!2G=!''.98&91NAZADU`!;5
M/2EV=2;9>GJ__70OM/@$#\?38"PO=HSDO!W<]`PX])C_D_4,_08F=1_]CU%M
MZQ`8<LZZI((@^V0OU=RYT4)CC8*DY8&PJ1)R:1&Q'B_+A9:WL.LH2.&K0C-E
M_57S^\:]K5"32N[?FS21@MPAPJB1IY*0,(YYBK%7D&]Q8Y2[,7\K"',N8U*)
M;+:TGZ-/+FNJ?H#0._4H+!5C=)T&,F0ME-CI@`GOQ?G!%A]:44UOS9:S3DWJ
MQ-UE(;TI.&T!W0MQ5P!::[BX&`2/\V$MP3ANEIL.;V\F;)>HB&QI3'$](:'J
M`R.L4))MH<49_G?NN9L1&?LS22X5S$:2-P<0GOQ$S6(+'/$N#RTUL/?RSB6B
M^QBK7T=Y.6*G%7X^%,B"+"24$^LOG&J4[;#K'@CWD15;&O[;/W\6MX+'_=[O
ME9!;C*&#Z:"M/!]/X`?P?#SQ_OZ&R^6"E]<7:*&Q=RK)^WMQ=TA;*GS>-B6`
M]=W.6J8BFC,>]SN>URLNEPL$P+T6V"6^>$/6HS8"A2,,`#]__D3.&7_]]1>>
MSZ?C/XN)=H_V9=XFI(I3__SK+_S\\5H1_=FKKG'U/?`B5.":TL7;(ZMU</@N
M>$\+KD^BM9[K^D4*Q'FYX4H[_;OT"CU%![WI]RJJ01=^P`%L_.5#LL(!!0N:
M36K+B7AOZ0X@,;HK;>G[9.,BBPQD%M"8#EQD+D_%L#4,HAU>;!%'(];3!DH]
M"BX(CE4!2)AXQJ2889D4YJ\-E)?B-A$@>MDE+YV^7P8YPS!K5R=>Y+`)=ONH
MFT<37I&A`K4;&4C5'HR1OH:^UN)@%N6@(+7L.M!3A;BQ4*)?\,*<?2YH+UJ2
M"(Z&4'MA3F[QN=I3UXI_;4.Q*V+2D->&;"D]C94\JIG4]=E.+Y((<A5`%0>)
M#)'-HJ$Y!X]=5;`+<V:5BM!DTKZRYNX*,0K3)C(:XI9$2FLQU`F8>V#&J34N
MEQ.8_#B^%0W6T[2>,[DP&%31C$W1]'N.!N$6"]6)^RR@$!,2:!8+L(%>B0@.
MME!S`$9#3MMSX5'XF6LL)EY8FBA,X*@6,-9P_-JVZR;$F;?>X'.ASWBDGTQH
MM&Y1<]!^AX5L$97%@T]EW4CQ/33S(R?,4]O8=XZPIWZY>W&[E42S+5E^[(_7
M%QS/ATD1M-^G4Z.6->.___7?I8@^#MP?#]P>=USW"_;]TM'ZV^U64%U8Y+.O
MA63+Q=9Y;V^_\/Z><+GL>*FN#\_G$[I93C>G4[Z_W^HY!/N/Z1IE6N>3S$!4
MX1=;R\/H.?;=J''B@+6B]'L$:WJ^"]Z3D?JG?7@_X8=[_NL2T.<#Q.]SA_'A
MWZW]?N-*E5.G3K][49A]O?X>8XBLJRJ?4KPT1K(G%P:GAE7##1ZV7:*3:5E\
MW&MF`2WLKF#1:*CLJ!ZJRV0'CI)<-6I36I%8]&"`/B?I3XQ<ARX-]DD28R*N
MAK_[4=B#4+J4T^$X`WH.K8A1!7%&^T,\0Y_7YK=5"&@H%*)QTA[&N+T4R#!"
M$T9XV7%`*U(K0<_!O$<3^=J.(]<-$&GRMFY<:.U"J/G1'$6_O4[:>6VI.PCP
M;_81/:6?;;+UH`F[V=F8Z6[T3C0'SKEG+FD[RJQQ+&Y[)AHJY;V?#T?Y4-4I
MMO;(V06Q:?R*\3K`*"1@D#AC0R9N8PV>;4XVFZWMXL9UK$W6W[>?HWM/#*U#
M8^#&T&+$QJ/W\V3TMKZ3(Z2$1\4*EUQLCD5;1&P;W2_>>7K8ITI[6)VGWAP*
MK'?R5'PN4DMU:LSB8LIXOJ>(R\S>L6+C=S&<"9Z/!ZZ;=5K8MJV/]`5S*EU#
MW8UO;U:H'OT0CN-`/@[<Y5$1Y$J!:6M3W;@2/>#=0<(YHZ"*XR#`\_G`\U$L
MS`#M$<+[I7"%'\\#^UYB@N_W!]CG5L%Z;[(\#06(]OV%:>(+^)!F1(E2U.:"
MZTSH&+T#WP7O;R"\^AL0ZWD!>)8FI<N?^`I10'EQ60[OY>0X8N1W*HSEB]?&
M?9"(\P!U2G)UPBDCI..QF;@V7R/F9ALI*B%P@\2K47H$Q1FNK[4M`GK>.^8X
M2X$ZX;@N:"">%AAY'B_LI=RX-'J^C$C.KT@R0$CV46442&%CY9@*L[*N\T5!
M#IK-(:)8V;9)'WM";+J7E$IRWAP5T[][WJ!'HO3$J+HHCU%QT$9E:+(+Z?&]
M=B-GE&>@:,5!(9NC*+ZWTGG1&K@+\+7JR&LMP@?_THZQ)0DV[#WYJ$U4NG<O
M%7Y'KL;UU9.W?,<Q/8,M:IA'X9+&^5D*"Z6\N?>:K:B2<<M0XL(F9#V&,`8V
MOIC?5]^\3DR;)I1QK@>S5^]<-,G"?YS11&&Z#"P5P09FC#";@E#+E);6$%^H
M$QE2$1L]&V%1[GBP[1!S5D,K,=[#39_HT`9U"*T_GG!_E7E-,#:0,APLFM@U
MN?=9@R`>V\/-5+$985;[C%!28F_"3.J;6%J$C-^YO=]PO5QQV4=YM6\[_OF/
M?^+M_1?N]\>,%H>UA_248=OH:Q%%5K>69*M!PQ-6^7C46GB_CW[^S[I^/(^C
MW\N+M.2X/+C/[#L.Q>OU%<]<0BY`36[6F*0Y_(7+\6[;5@K\8'S.@2NL>U&7
M*X#)ZQDF/>Z[X/TM1/;W7!J^]HGZ(<+[>^EE^AN_,Q?.T=@]UO"?&JP9ZN<8
M4<T^G-'(1"*^)XD,:(4;"SK62FO^#C,:<5==SUH7U6`NCYE\3TC160"P]]H0
M:JF5_3LQ[&B\$01?9T-Z@DMWH@72Z1R,9VOD6B!P:FO/J7"V3Y%A_RI&.*8R
MS^?1!Q&5]]6*)9V*D;&(MK5S/+TR>+U@3U^=$/R^$4_W?BZ>1\*:#*38%5^#
M2D$.&SK>6,W:[8-8>!/Y7JMJ<01H.R:YK.0CFW\W/KPR^,HR\X"04(SOG\\G
M\G%,0J;VS\V6J\6H)D*YBZ_GUC?;K%3<!,_`MA4OT,?CT85J`^E+=:Q_V'?0
M)<*,#5/L]&55K-&3XHM._F0)"DS;K*7^#$1(;D:>;!7;0Y$<<@VF!-43,!&L
MQMD`[IU+DW#0NAR@"@?+1"%WD92EDW@'&L]55B=4;CS;I:\LO<]F%*V@&&);
M"&<J]OTZ-A#ULO-XBH:ZZ]+#7MS:9!HCM4X6<`F3(@QT")['@;?W&XY+QG[9
M"KH+X/IRQ9$/'(?B0(8>V17?;=N:B[;6_"C=K!93W.YY,L##$$0V,""[^.R,
M8@UF08D!V]HA:6EVR_/\+$##MM$[O>/'CU>\W]YQ/(^^-A[!Y)79@,7WMQS;
M'W_\`[?['>]O;\7^D"I6J5F52DW,E`I:USDC.C7<QF^$]]\`!?\[?E]_^\/U
MMPO?%94#2T3U,Z7R*C!,/0JL-+H-1N:,%L]V8S)]EPTCD.4E]'9`@A'W>6ZB
M3(IKE3E"ESY?@Q&`?A29!SFYK]H%;X;OUR-PA[);U.7_POXKFQ#DZ&"=!0S$
M%A%C;PZ&]"06XT+/\`6]L##@#K<"7:&GU**>/N;$B()B>7.]OD!$\'@\JA]E
MGH2`&HZ`![(*$JAY=$_.GA1**>M_EF`*V&B:9$;769WP;(0"-$-@7T>T8B`'
M(2DESE=Z%&B[MN6ZY,[WZYN[--7Z\#^]7"[%D'[;NNW1?%T&@ES\=#>()&PI
MX7*]X'*]=B[F<1QX/)ZXW^\U3M@[E)2B_7IYZ2_7D;-!PY5,J":QI*<$>.3>
MK1$2(;2+P`2F:JAWN_?OSF(JU-?6G'M4<O1==FT,IC!\/`T-;PTLC=)!#AHM
MR2JE-&@L]:JDVO@D&=22D40FG<+C/7C#]Y6*IWF>K5/A,AQ68-!_MC'SZ6U*
M02`B)%C5F$;4&KH"K&1K8<BUGP3.%.B0/28/\OJROK__`O"*_?K'^"Q5O+R\
MXN7Z@MO]AG_]ZU_(AW;:1N.M&Y36-/3D0$*%<78TMFE9U?FY3U.TL;?'=^N'
M@$(L%-?KCO_ZYS^GM=@*?`-TW>_;D@`DW._W*8FM7P?G@9WI.4NPG&QSF]AI
MIUFA?5>L?[/&_9O\W8_BB,]*7_W-NOMS5(9Q<GX0#['(EO7#6P5;:$!]T&K?
MY=*O1-8P.@F3_,A>IQ"-P!<RVG0<OVZ-P,L2@56'QJW2Y-8/D>TX^"PZ[[8N
MT#T.=G&(K%;6Z/YXL9Q'0#O2:Y.B^E54RZL%%3@#J95PS#C2G:R`PHQE8<>_
MD=G'\#80A^J57[A444=4-&@4Z5J?C\0-F?(T08TU7A=X2C,_+W@)-",;S$3G
M)#!X+BEMVLF=5XX+G_'90<)7NP=]HW"%*"PZ4N@)UA_;O/$M92DE7*[7_ON>
M.\M(*BJ+.:6$;=MP?;EBWR^XW6_=TBBEA,OE@M<?K[A>+P7=>7\W3W[.)='I
M>GWB]>6UCMJ;T;T5K/A%3H/IBQ7'#4$<%XQ&/-4F(-V=(=GT-2XJ.4:51O*A
M#F!.F>E<80Z\@*>_$)JOP3&OHL?%C6Q25,ACQ$*KC@GQGAQRC3DT8GZG!FKI
MT_@:4M=Y^U/LMI@@S>2]QS,,Q]EZ^@XAHY`:>#3[I=-/K2G(2DNS`IJ*0+/O
M<YCCNG6F'I@UN'UT5NC1^,=I\(R3X.7EBN?C!??[@>-XCD*@Q^7J)+II'%_?
M(*007;+K"T\K&>45`BJFB6DOBC..Y[-,5R"X7"[X\?IJ*#5__OD7<LYX5E&>
MC6\?96YR.UZN[A67RQ6_?OU%A3^FM0I*^$9[5XQ=%<G30E.C[^")\['T%PI(
M^5V<5G4MC`K&`7\+9)9YK+\J#@-<=1K%>U3.S7=BJ%?0(PT;>F.^8=3",[>)
M/2[/SH\02#7%;NPY;([2C$3&=P[5N$58#%IWXG<;H>2Z>!Z6[0BEM8UF24SQ
M,V@7=#\$+MU#00Y-MA-7#9H$0N_4.C^R=ZU78:\XC3P.[K&;W/`H%;#"5!>=
M^<G&G:'<M&W;D+;-)%LI)7'YY[91T;IEF%)*G7,)*<5"XH=RH/KJW%28LTG"
M#D^OR,1)Y6LW^3:3VKIYES(BS4X``PFVDX)4.;AM?,U\83A#?AZMIY3P^OJ*
M?2M1HO?[O:NU+=HFPU&C;NRO/WY`5?'G7W_A5NV/VGW9]QU__/$']HH<'T?E
M`&)XRA:QS!W7ZPOVRP5'/I"?U:B^TT5F,5:TIBMQ\,6Y)S2DM3^GBX;)K(.1
M70T&TFA\JSE>UC2S$J:^1?]NFANG`O*"+HMHTABYHL#*$X\`,8[$?HW6HM66
M*VL;FP]U2-:,9,(SJ-C1/-D6CAY))EI5C[66.GRO62J&E]U<*M1:W)7":Q;+
M,H4J02C%L:W18HNFY'C,T'#C-4$)$-SO-T`5/W_^Q/5R,78YFVSX^>,/O%P/
MW&[O>'N_F>87_+QDM8XY/2*9&QMQ-%:FIKF]3W7V!)X:LR*\;0UWB0E6_/SQ
MVK^D7=/G<91`BT>Q*JO$FFG;X1)8V+4H9Z@>1>":2U:S];8?TRP[)=!^?FE1
MK1C>_C?"^^_YSP<N2^><WZ^Z0?QM[D*4$<3&Y>?XIBY*<X&-K8V0I[Z1=#/Y
M:,`G7\!7`R1'YL)5U*.H<8%IZ+Z.BBM^++=DILC27DSY@"/K,'%QPC,$B;B<
MUC52KSJ]_%)'DAVY(Z1(G7Q=5</1&+"R')(N+A)^J&B!],E5NMCH>=>QZ(0Z
M:LPH*%(J",3C\<#]?L=EW[O:>&KO>*Q=5^=N@J]M>(9I.L'7*'4D//7$-JWI
M3=(<"PBULF-8@#GN(KXY$Q=M3>BCP""M1\Y#P9]+E*[E25?$*DDULM<I3,/<
M1QFH3T%A?^"R[R51ZBAHCT>1&+%/(OWW1`3O[[<^MFR);7T<^^L-__CGAI02
M]FTOU^P8$*6BT%(>SWM)KGH^H(^'"VT1FU`8><^:4;4:9P_OC?OAFNP6?1^`
M8`NL6$DNP3OAQ9I^&L#/![L;<"`*OZM%T#EC$>T/>M2M>\>BU:4\[Z7(3<9V
M9M!%1$;``_=KF2:%/<*;+F'N:5CH#A'<]"@*'[2;KQ%7UR^XWI&@%??)KR])
MH(<:-%EJ+/KH_S,E.LKIOD\IQMWBLE!U,O[YSW_B<MF-D'+?=VS;ALOU@FW;
M\.O76^5H6^_?@7Q[K4-KVC(UZF[2(R[BO-&8H#U4PF-4YGZG8B.X[\5UXG*]
M=#ZQG]QQ8\W,CVD_DBD_D]Z':)<50S$!ZR&R6@YYUDY#\6E^WQS>_QL4B,_P
M(R8*0/QC7ZE_!80T8>:A+DHS^_N]*(@12I&X[!IN"`W%$DY"-<EK*^J!A,@Q
M,0>:"\/,OAB;MSF1\6J*L^@Y=>AP-F,F,5@6/_P!2C]14Y:>N%X/)9W+R3Z2
MC-;QN)\%$2GYZULV1E2!A2XV7PD$%2,>%R2]#6*1HTW?[1P*G^0V7R$)'"3:
MN>[[!2DEW&XW/.L8[K47%FY#[`OFL&+JMKXB4$T=*96%@8G(H#QX$=UPCM`^
M*DY;&DX6$B2VH5$\LD5X&<F#$]DL%/B==E0+O(340P$.S>/^F4"&<CQ;I1Q(
M2OCYQQ^%[UD_B_G0+*CJ!4+]L,OE4GFZ&8_'8XS7U;9-K8!.*?5BO-,!2##U
MZ]<O_*__5=3OCYKR9E!6L2A0+ZXYV8MH&R'X`-?U^J(39)5%W!??*/BB.Y\U
MDB=KC8GJEO'.V+A8+,)TQ`K-W!3'%]N3[9<ZWV/`%*)%N)2,2#!G-=[&S5=X
MV*MQ(,0X6`YBZ)21E":?XD9E:/[*N8[Y%8`F*W+C:^UU!#U1+]D0(P7'2RM[
M;LU3`T<5*6P&@7<K?SP>)1Q"7[#ONZ70U/OTX^=/B`A^O;\A'P7ES%G'\LY3
M"$,O<S4D[T5!Z(^ZQKVLOS4-K\4LT[/R\G+%R\M+0=CK!&K?MF&5]GP._%X&
M!WH)P?!TC*:+TZ0A,H_OSRN1J]G;EZE9X?WZIC3\1U#><X1WF$0//I*]T1KY
M,XA.0)B>D13(JHGSISG+'60YPM9CG0/8%<<,.LF$ID3C;*GI.,VCLR?M9&LU
M9$ST3=%0_K/MI2`K"%-+D)E5]%QTM.\.G25$D?-<9)J7=@[JL1LHD99UNO##
MQ,P(?(1"-'1.B8NL=OIF(8)D:"6";4LE8[T*CX[C*+Z-AL7/Y>2(HNTC3C:V
MKPC@D0]K$^1:*!&K@,^$3DY"BY/G$CUPP),^Q-$9AE4/(T!M]+CO!8$HGI(U
M._[QP/5ZQ?-YA)SET1`H-MGZ,UHV8!MMVCFO5325TD9QKL"6-FS[AB2"1W4R
M:`76OFU(6^&T-HLO0/!XWKO?;HG,?:(<_K@VJ1JS9QUQP`6@%P=:"30-WU[M
MB)%2PI5`C]S%:BD-5+.E3K5_/YY/O+V]8=_V[I=[U!'FNETN]_LX#D#1^7^M
M(,B,(-9CS,<!7"Y3F$4F_J0J\'C<<;GLB\94(;)AW](HL,AR;0X;&"@>H]3L
MF"",E#%EAP?,SNY.J<%!--6H'%U/N0F+Y)/]QOZS<P;Q3`69?:I](ZM86[!Q
MZ$,/,VC?PU'+P&1!)Y1F!K$3@>4QN370(^=S`S[6`/]^1^X1YOD366S@@?9D
MV3"QRX::(DQ$\/[VAN,X\%__]5^+,D#PX\=/O+R^XG:_XWZ_X?G(]1VB0K3]
M<P.>A,(_`FL_$5FBJR'R6C_GLE\@27!_/'"Y7'!YN5`04$?-H*IX>[_A=K\-
MX*-%T$4ICV9#;0UWAI!@<RZH=`IT*0.XF;;5-2;B1=_EG[\+WG\7BJN_B?!.
M2&7\,OC.[JM5-8^I.%G4A@@09]&UL9.M$F(_41'M24G&@)07YGH@9?/3D/K`
MQ5]'LV@Q8TNE+F+P?KY)L&_[0&UX$\,0:(CD*2C"UW;JP&&-('"V1&/AD]C-
MT)^L'_'#<?WXQU-*%47P,;<C3"!MY?_D(67\.XD8RK^GM'7EK0U?J/<[9214
MD8Z1U\JT42MT_)Q8"H@Q/,=P$H!#EB9^B"PF"&(+7:TPR&4KA>:MC<[KZ"VK
M8MMWI.V!HQ7"&!OUB/JM(ADD;-N.G&K3<)#Q/=\_3=C2WM$^@11QUK85L57]
M+BB0MH1K=3?HJ&7.A0>K5>+57`VPXSBRH=,T1#ZI]`)-=43$=C2NT52J5VNW
M=FK.#-[*C9XPP^&KZ*BJXNWMK?ADIH34)@#4V/81KO'(Y]$``"``241!5.,9
MW6ZWPA,^,MF.]<[-I-LI-2>^868SD<(3+!SD5*D<?#YM1`P(GL_''-;A(G-S
M;JB[5J1;*O!/):U#QH#2V+#(;/+B_<##E__,1\R:XB`H8H/$:O,S/7*X-4#4
M./M",.?<K>YX+?("/T9@?8/<O)ZS<L%E"]@TK95Y3-\XD*$),?DY92<(M;[?
M,OD(SWH8<Y\<VJON?.=PBW$^/=$NCZ)6^Y:FWAW>".HR2JK8_7ZK+@=7[/MN
M?&R3"#9)N.P[MB38_KC@KS__Q/OM?4P11)&DR&NAR1;D8K+6D19=TM+A0H@;
M+,"/U]=N`\A3BU:$IY3P_OZ.V^TVP!DWSA2*`?>Z/Z$YGA>">@J<MW'D)+8N
M1A2;\"ENY*R:OPO>+V"XKK;1?]]'ZV<+8YT7Q),0M/X2)QIWMS%@T!W;S<]9
M?!@@<Q2].1]]H6D(0,G%SB7,BDZN\&M*$:6$(CKY^NR%V3;6XS""A>10VZS.
M)*;Y\@%58&,%7P+!E@K:]G@^>\SA.=V`5<@1%<.0C:R+ARIFG,$IQ$]Z&''\
M$FE>J^7LZUBX<L+2AGTOH0*:GX%=VJS4/SK/C6R,R#!_J+/'5*"A@L.V3#M=
M1D1PV7?<'X_88#T/,I\N[,EBU^39+%XJ9Q2HANEM9(_ZW&7%Z\LK?AV_BG\L
MK,]CYYU)^??K]0I%08J+T`IUA!Z%821LJ?#;5!7O[Y5.0?&^Q4MV3"<>CR=R
M?N(XM!=@>Q7;E<)52H!#%?VH%O_:PKN=D]4R-2P-/6S69OV1[/&EF-`O6V"J
MI7^`Q%R5ZL#I<C:^>CQ3C5)BX!9&2OL%+)9ES\<3CT^8\C^>CUFM+AS%F^JU
MRE`\PTG<"!?`2'%+'*P@E"96;-EZY*L3>_FHV9SS-`6+7`WX?T>$KSO.[H3"
M/']B2_G&@$H)3!9O]CM-(=B+S=1%8/[G?`'IT6@1"XJ,<YC=`92+W?JNYDKN
M;=/&<;TM4JTM5GOA@=Q=%CI52Z<4T$Z\Z5QF2\,X<\MHUI3<EY_I.]KO/9\'
M_OS7G_79^Z,4O&"A;D4AMQVH?_?R^H*T28_)+ESV9_6R3M`,',<#:=MPK=J%
MQN>7@"K74/:V[XF4QO#EY06O+R\%+,C%@WG?=[R\7.F:EF?C<;]#4L(&]*;>
M^S-/]#<=`4RC:*6PE4#XSL_KB+*V=$A8<J(!\I0:?M0I[W?!^Z6J5'ZWEOWD
MS^FRR#:%8U"`A=\9)`$99('$(\":TVO&0`O*@F;%H4>W&RITA<-U^W6QW**-
M@X48&4UW:2-;,8\[%R4G%R0Y'SBXF*4.L*5TB0-I/=QB\M>9]M$+1,#SK_M"
MUN**24#GA7T&11*)QTUFA-\S@(Q-43Z>R.^Y+)35$JKXI<8-T7$<7>T.!0XG
M2VP-C`J-O&A#8E<%Q9R>M.T[\'B84?54+&2;9F1$#VS#Q(6(&Y/M>RD6&Y5C
M.L_G@<OUBI?K"][>WT?<:/.>30-)W/>]_WD1G>@0><$*?!JZJZIX?WO'\SCZ
MN;;XWQ*`D>JF]ZP.!^48>U%<(UEW>I^T6B:U1E&U.BP0I<<@*[#\5<WS_1C1
MOF0C2F*G?"*:&L],A@-S'5VP9,Z)#D_F/CEPH^BV$3_N#[S?WO$\LG7Z`-'4
M:2.5E(!*%^'KD#7C^7@@'ZG0)'+UBZ7IE<ROZA#2^BDU1IPNTWL:]Y%]JY4"
M$3(LSSHJ.-EK-6==%$J!PX#;"+2BY?[S^=[Y/:!9T76`H_)E6TA()HXW-\>`
MM6:+8GZ]X$VL_Z$5&UI%LT6DP>@O.A^XVS-6L*1,ZD;:83+1ZMF^IR1J4GH8
MCD/K)-[RN(?5G!F0E\92W7[AF!&F$":D5Z04BK=;<7&X7J\5O%%7^`&OM1!M
M[_-QY/(<2N,;)_SKO_\;:4OX^8\_\'P\\/Y^P^-^MU0G.LQ]V_&//_XHS77.
MN-WOV*JC2@,-4JI"V/INC.A@P>5ZQ?U^IW6L-C@IT:(PKK,?7T_K2IW,F%2V
M#SCNW8#(Q<?W1J].M5BT]LWA7:"B'Q>G^AM5[:)@_E3PQ+PXF$5%/W5BQ@)*
M[=!A"H!8FI)-"@E>'*1S"QG9F%)<`!(:Z>1QS>B%^F+7K#WV@(61R58TX#D2
MIX(XWN?S:1"KZ9RI0)WN?QWM#?3<FI\)"X%$@_OG>*0TSK&V8F**.X5O.GCE
M+3S:Y_/`]5IC62L://Q8![J1G?!()Q4$H]EYOE_$#^4B0JM:^W@^8[]6.H:V
M`7K1#W\WCVH[YYT.9-]W2"T$6:C3BO/'\<`%%^R7'>D^D*>.IJH=?1W'$[?;
M.Y[/)VUB6@,:Q'B-MB(PYV-8[3ET\O%\0#%03[X6N=V[)-WKLON,MF.LUVG?
M=PJ+"&S6O'L`+/VG%%9'D+H%&T,<('P>F33I:"J3UVM4<`E18OCOWBK',4]V
M=,11K)SC9@THE(K7&H'\//#()50A:^Y)7UV4B#AP`ME*C3KU0G,O;%-[#OL&
MG@=/L^H1U+U#4WB`ITP2Q8BG;EQ(9C-14/=G=GP>%<VVP4QS$2V)T%[TT;TM
MTL>JU6@0,.""XY*W^T&-I:4QZ<07&_<41HR42%.R\7.TT:B[>L.WHDLH+?!H
M[A&!\V*[!QM1*^Q(/9N"54#?!TNS&&N["Y_OEFECY;N]O^/Q?H.(X(\__L"/
MGS\Z^#2>[O$.)4G`5J9`67?<*XU@@^#UY07/QQ/O;V_84L(___@#[]N&^^/>
M&YN7&O9RO]^PUVE3>4XS_OCQ`[_>?N'Q>!0GEMKYY[I672Y70,IW_WI[P_OM
M?="4#+:FUC:,]FEA.IRC<:::MB9"GLLB;J(YJ`R^6#!_CF@M&M__7?#^#U,1
M".];%KU?C1W^"&?VO]'%*Y0F,Y5O:D<VJG8<;XRPF:`JEKW4S.*'"\")+<$Z
M37848S@WLE`@,,Q6:`8T9>JVQ6PI.J$=YQ=3"''BT7%1HI=-)#<A4/<-;"^R
MX&AH1(4!QKC7%=EN[&<0^"I2VK:MY+&[`I+O?*&:7+K(I'D3,^*0*VJ07;I0
M*]Y-"'E`;M%5MU7/X<@9Q_T^\WTI(&/?]QI1JXZ#9V\J-P]3TR'2J0`^_:O]
M_O/QP!M^8=MW$CFJ.5?1YOGZ@,BCHVX#?7.\OIIRUS[/A%\XCF9#F?VQ6VLK
MF,+#-I/E.+:ZH=]<`\''Y1TV+*J2NS.#N>;DQ<GWE[F-H]#)(P!!+5IKZ"]T
M'W/WRIR;'PYV\`VQ\?8%2C(5*/FKC>,S<9AKY#'`B7@ZV2/.+A=IC%Z[M5YR
MMW.DSW4=@`1)7R.1A%P)U.H#%K',`(@;*].?:_6:[N<<<C.I8*N"8^:F1D5J
M[@EV:18\F4*=W4N8"A!-IPRW(UQ?2VWB;`;9.24@C_5W07QJGAK.**#8>((F
M5@/0BMC6]+)N!(X_JI@%@H*!$C,'V2X1A0Z`9-^9UAB]O;WA<MFKI^T#+]<7
M;/OF-!#C7=JD%+"0V@1O/\MT[UD:QI?K!5L"?FI!AO-QX/KR4H6T5T`5^U:N
MN517FS]^O);/3JD[L4`!/3*>>B\ZB!\_<+N]5UXOQ2Y'DTTNUAN@H,UCUSH*
M"7DB#[()"=+4A6D2:..;1G'--.<_??OP+O@V7_+%U:]@NO(%=)>_PW[11T?G
MO[>+B3[X;2/H",(PU&VF1JWJ.%Z`2^@*[,1,02E&DT]?:%/'+)!H#;GA7H!N
MG2,)4GE06E$8MD9:VF;1<6O0P)0"ZX#(8<;Q3+!OD^?!.Y;*?<[PP@Y?!$EP
M0/O>A&8/@[JX.6Q-I!J6/9FX32;R5*J53M\H,(>&B&#?-MSKF$R<>?YG)AS9
MA2VTPG_?=MR.@T:H&@:6\*)F;D@M<A(5\)@BB:73`')6ZT&B\85N\:D34HDQ
M0FMH6!OA0S(A@\/2:+:7DJG!80NR4ICD(4BC<\FUV-EJL(9YM=KO4Y@$>_XJ
M1PZ[$K`5JKF+'QW"AZ$X[ZAF$&'*Z*"8-:#0&R;./FPXC(A]IAI"GW/"ME7!
MGN$$4V2V(383'Y1%:CZL@8=/C$:Z=V0UWU/FP28QQS,LMZD("\(*N!E7XJC)
MPKLZWG^D%Z/EN5'#J_1K7.00$>U_)EEN@=I[WBMW"/V^&.>3>:UK$\92'#G:
M"VU,0NY"F=PC6LRLTN<RZKU:HL9TC^@RM)FH>8]"P\RA:Y!AC2D$6PO%F+/=
M8G.#>1X'_O?_^=\EX&4K4Y[7U]=^?)?+I:.QJ&O/M@WZ@&[UF.C/`.!RO1A>
M*Z"X;M?V`/03N3_N/=HZYZ/8#BIPO5P+4%"3$5]?7DIAJC":XM8LJ(/W(@KA
M3-HL_TW"0FC'_Q7_OLRFK9.5I7!*WVC&O@O>+U,:%-&$_KP>9D=J^1(;(N+1
M_5:A[KS\5M0%]<-VB:_-,+/7P!%,N]!`(R8"1=PV;JM2.V:V9%?/,?6+[6LZ
MHJ2.:27H!/^&`G8DUA=YP?U0X?P#,6.;QH&U"6=*B5IPC@^-`3KS6#T]9$),
MZV>EE.`&0W;OH+%1/G+X[&S;7@S\'P\\GX>!S!OOM*EP]WW'OE\*[^SQL!9.
MO)A5VH9`'#)I$2NF&A0_1\LUY?I"36I00][R=&TN^]XWP6W;Z_>,%+&!?BY$
MFN2+6_P]QY_G6MB-R4@IAK,VY7E%%S-&(6:,.KBX!5+:"+$9X^3(:FD*\:(-
MOCT''=6JU!IOO]6:OAZ-G!MM(8=4&_/*BXWV/"V^`$MQ,.5!N6['4>A.ZCCQ
MHXA)R$(4)DZ=@E;OX%(TIN;T(`))7$@U,5W=1).X@)%8,-:XBB9UC18%QAVX
M".[O5AK^JQ`J=)VO*0/W'?T2.T7A)>_<NHSH%^PR,ZTQ<0RP1XU9H#5/#P;"
M;SG"@\/N&_<V56I:$1\(`:?!$']-F_V6P%!MV!N[N0;P>F0*ZF@?]0$<"((F
MV95%<$+U@GF?@7G-8N<('U31?NK(BHP,',#CD?%\'H53N^_(6^K%6Z[QXXW&
MX\6B37B][5NA<^0"QFR=8G+@?G\434LN]_11W4RNC?9PNY?))8#WZK2R[=MH
M/)R^+(LO84<=8)(N82/OQ31U;?HT4/78^UP"1G4$6(S7*A$%Z[O@_3T6PV=!
MWIF$H@[.U/4$J!<N9U&T#@E8H\LX+7;AOI>I#J7[G@>#:F92EJ.EBUU4=:8D
MS#U?V7R>'9H\:0[\!L]CC'H]GL>!#<-S=MLW;+HA=W>"8RC#@1//6*Z`J0CA
MB1V-H#FFEB%C7?&YO6<M(=56W)().9NYF&,1/=S?:8]S+:DY5^Q[-D*E,B;-
MW?NU7#.05_!LQ,X604+&ZZN-E0OOXIB@HS`+FSC>A%T!6<^G_>[UY8K]4MPI
MCN/`X_X8L<<ZT%F1W%&QCB[VR,[D)A;\4@F)*@A!;,^&ZD09*F/B#=?K%9?K
MI8B"<NZV7>/<V/0>AGK##58;:3=K+Q7+@VR1P6+P*CN!8<<)#>*P&V)IN+H8
MQOIM3"YRS,5Y$"O>$>J<#3=YT`:JSVM%@L5[G;)H2@0OKZ]X_OEGOP;BC6DG
M0=&P/9C6RF9/1]0&786O-]NRYJ@@:0AMC`Z"`Q4TF#R1@)"NB2\Z98H,ICAI
MG1L;_EXY";J01:IB.P;?R+`+S_R="`5S3'N(TN<G_UW$#=5<T(,:8)UXTA/B
M;,))8/0>?!X-J6U"R=Q&Y(DF`HW*,E%"1C,N_1D95.^#Y!A9K<PY4([@_G@"
M*%2X/_]ZP[9M>/WQBF=U:'@^GC5J>Z/T-<6??_[516`_?_S`\W'@.)X]WOOM
M[1UO[^]FGVJOQ_O]WJG6^7''_?DH\3<533]RV2NRVPI%,26:\3Q$LXYDOA;T
M!!0_;LU%<Y(+'4/%#"J-C(5U+4,#,N]O6H$XA0W"T6]*P_^M,AG+M!]OOL3J
M]8\07J%(QD\>PK(XGJD.'_R4?LQ$'GN1!G&;=#123/D%V5PG<30#\&8_[XNC
M(%;@F9^=3PMIB5."M.](.>$XGC@\$=\5T9X3Y*UBK8;.HUQ8&RTOKJ'GK0+`
M\_&8-S$GB]9>^.B$L3-54G/&O?J>3@(VOZC7<;7?H-K8K8_#_>%$Z74=F1,\
M'WELG#I0-'[>@L"@ZI<KQ5\W;15!/#J'NM3L8A2Z<V*2=,LB@^(G<3'*Q.4C
M3OMD3>=%>3(LHEZN5URKVKK$'M^*VT$S\6^7(+>-E1+,-'<DN+E0I.HAW1N%
MK7S/,Y-OIF`:,??QK;>+ZF$"U'CE.4A:I(ADWM_?UTTMK#=F0P*%IC%C%#JX
MJKF>)Q=?7+2@(5HBN%XN>-^V,G6@8\MDL6403J!;&DHP%6O'HDK-I"ZF?VVR
MY-##5N`E^CLU"**&J+TOUGR#.%!Z#XG09(:NFR]4>7S/U[8]]SP)"1'@%GJR
MT#J$E`;,(KTAALP&O?9I;[ZX]5'<[>GB..*01A7X&[-8VOK2KD,M6+RYFJ:*
M"7*J#=%@FE+$<EOJQ%"$O&6;`+@_'GU]%@%N]WO__.,X\/)\XGHMG-S;_8:?
M/W]"J__U]7+!?=MQN]UP'`>>1\;U>L'C>9!#QQQ,T1S%V<5C%0DOJ^FX1WQ%
MC?":FV&MPN]]WW$C"['^VPGD9S_F/4;(;1B0Q"6O?YGIC?DN>+]*#?@$2GI>
M6GZE3%:#<'[VF[Z*0LO7ZO30)W?^K#EFD%O:@8@&G)Z*HGEC><\E41F*7@DL
M8I10U:+@[X&(?0/8]JT63#MROIN"T)RK!AU")-)`LAQ(=HUPI?ZG'C/RR6P6
M9W9TJ38]SW8$;I,H_WL<!U*U*VL%M/$)IA_/R`8-8=K=$#155$ZMV`F!Q54[
M^,Z=,\$!;G(`[WGL4"0!+GNQT7E_?\/]\:PN">WYLQM*/K2[:HQP`3^%L0U+
M1ZP5ADO;QY$Z+,BRSOR^\APG7*]7Y./`^_L['H^G14"('YP[AHJA&,<("#B.
MPK%KX\=2_$K=K'2@]('(E'V3N7EISY:)C25?V8:LBRBP`:^OKW@>!XZJ%%?W
MLC1<.6UIHJ'T\2^)V]H]ZK[:&JS%)/#:.ITCXJ4.`Z:4A#C;6,8*ZS35D2F(
M!BQL<T49>X1ZGG0[WYQ]$<O>S[&%&/]S0XI+T>KH`6K78>^@$*&FPU)PT$LR
M68%Q8]H"7*+/.N,`KWQR(Q]B7TA9.M-L0]7N"Q^S%^1UF[C.TW4%:VVB3!SZ
M-"D8:V]'W\EBPU(.E=#>]JS58)D1#=F/X7*]5CV&;>;;FIJVA./Y1-:,E+8:
M:)-[0=U\PHN#PH[+?L'VCPWR*U6:U[!8+-.^"_9]@\BK^1Z_#C5[O[Y^U4G?
MD8\YS55(?Z"P8K0@8EM-1F$%<9[/X?/=.+>\[M(>S/;L&@!<D1B3'Z#O@A?K
MCOLSE>[G*`T3_'?J>2N8D<(O?9??=%/M)A7XK.E:%*'ICR*Z5LM3<UJC56"&
M@,87SF9)/<PWW0XQ,7)E[*)$G2!A"(J+@#Z!RR69$:TZ];3A+8'8H'YQK=>Z
M>:X.$=$0D('B:;V!_71-?9;QXCV>B7`:!F.T?V]6;&6QE&Y79ZX<%==,8/04
M`&;K],W#QW@:E*E&\%8/R$SJ=BX3E2RR_)/2N-NE8=EQ?]QQ?SRJ7VXVJW&?
MCK3GH**C3>AVL)]HLE['8Q.P9&R3B:'QZ^W1TYPSWM[>K(O$2$%PUCM2^'R@
M['@,A*E%):>T`?*L(\QR'02"0P\JUNWS]>/'#_SZ]6M"4M@_M8O4',6I\6P-
M&J68[AO:J+_%'Q-/MF]YOFF2,4)NA3XW7]+&R0+LETMQ`*E1T7P]^7</"B<H
M/K.#]\%HI9@&G="]AD:J%3_Y-+'CR`$-H#WK&D_R!-8&,"@>.0CA.+)!&<]H
M"HR<^L(Y4[/I[0*97^F_(W."'*S?<X0H>Z3:HL.6$SRM?R)&:.@WBCX-4''`
MQB)2N%-94K^?0RNGYCDVU\GS?G4>(WJGFN%OK68R."6!IH2?/W]V>[`VL6FB
M5)/ZYDD/]!PWGNY6/=?S,^-ZO?9_W_<=VW/KC=#E<L'UDDJ8Q9&Q[7L'GO)1
MIQNB>#XSMCH1W>HDY:^W7]VF+=+`FW.4>(^2.1.[.!8QBH`A_N8`%>%3[]:/
M=O)Z"@)^VY+]'2CX-ZK/3YKG:@QH?E"D>I[OT"V*%./[C&S<":)BR*ON977X
M9VX/;;3#RDWY'#JN`=IF?M9&$*V+?%+(V6NCIV,8CY9,BQN(N]13Y=#1G]ZQ
M`Q9M0^-`HB,.?I/3]=DL4!J'!--FGR2RQ!OG]6C4"(X'#:Z[]T]M"S`[::@4
M16\3D-R=Z3F?Z^5RA:(LZLT<O?%-(3-M`;#V1_PXI:T(,^XU2G@HH0?$;Q3>
M7*,:!X=,X^)Y)&YC1K-[7R+1IAVIM7C>XWG843TE:_FW6<QWV;'JX_'`<1P]
M2>]RO>!ZO>+^?^[&&24;1*L48-?K!;?;UH,K5!G-AFU\'/U\GNI(%="H<PNH
M1;I0"ER2$;JB.:0UB7_A)SYLJK'/6QW3'HNU1-"U:DZ$U='DAOK1.]`:'>\]
MS)[@`V',G1:E87&IR_C6?OUJP\=4`VY4(G%=1!.*_IG%>,S-]6$8/B0"09'<
MG!I,6$8MSLXH!6=(\'"4T%-A=N<UNSO,X1("YE6+$=DQU8_)!4GL.RXT9A^?
MH8:>H]Y51V8$TTXJ[9_P=XEFW-]O_?.V*DQ[Y@/;EK`A53^NU-_E?!RET=>A
M1Y%:,.Y[$2+_>G]'/I[8I(`!4,7S>/8$PDYC:$$WETL7=>4\]!PY9SQ;&NFV
ME?3*/-[SY,`?;A6[/=@)$C92/,=TUE!(HNDJ.9UXQX<.Q]$[STYXS87FN^#]
M'707^$(<<%`M=G_3S]N?G:&SU=[NM)24))!L,ZE#JH7+,C"2%_G@F$4^?3XZ
M+8(S9T#F<$33]G_D:+QM.U1SV1B]7R@XUI!\27F!/BWXT<,\NEI5CZX8YDV6
MBZ+#'+CC])V(#IE79@,[))P$G#5E2@5+4U=(T.$4-,\6GNR5.4;816V^I:V&
M`V@8BB``+I=])*(%"'>C,/CG=$X>%NS[AN?QZ-GNMLNW;0Z#Y2TFL[P7($YK
M_3TA+TA1>&.C<6Q-E`@[MH>-^NU!$:LV4KSHSQ<^<^-PN]WQ\^>/2LFIJ6(-
M-9-4TYB\(*EZ^=:(XUBU2KZORM9^LW):P6@^Q3Q3LR&)T-P6YTO6;5M+2)(T
MO'/]6J>#CYRJX\K[V]OL2E&/+VVI;^@%]<?8DAGU-<NPEK]K"5ZJ4#WL1DS_
M?Q3,\S1E%*2Y"];$\9C:^I(,9:$\=X=:/UQ/"8C05+X6*24;6E(_6\ERKCVC
M'%S!!:9OLF+?8AG.%X`M+&MQ'36]MDB4>7KCBF3/$>[>N=V9QKH"29\FS=[#
M7-2W29SRF.;,@00QC>W<O:2=M_.^5^!^?RLB7`'D@6Y!=$R-[ZFR'4#A]_YZ
M>^OG\00@%=3HMFB8GQF.??=TQ?:S]^JE#M/@Z!Q(Y?0M*CRU75\C#6D\&I0$
M,NUA(TAI:#6\C6E+L?LN>(..]+SHU2\!O4OG7%7_N'R2%_#E"KZ@#S4)*$E"
M3GDJ:JW30N3$0.,?LU'/+Y]\0/E@&G\B-;0N%QF=U=;T%0E1T=<XAT#:BH)_
M.!8,HZA-BNBIT!N.<$3HBU!_?$HI<UYL80H5MJK1@(ZA0;@(.WI,R+I'&PF1
MD,\\&CH6[YH2-5M2V#//7CPI=O1JQZ%!)*J6\>^V[SBJ>&*F=$3'H!,'1JJ'
M[_O[NUD`H\^3%/5-I;A)*!9C.GG^#N6^]7L6\YPQ"8A19"]`@FCEW%;F!XK)
MN];2.]=1:_<C/KEW!>6]0_&C)",!>']_)Q3.7X-:2!W/JO+>3!'$-!'O#`%G
MD39'X,Y-<$BF<9S=CI`Q1[V&>$RC]BKR276\JJK=+LFL*TDZ545$QIBT%>^B
M$TN(_V5+FT'&1Z&O(^J6T'..X/4C[=+DH%,Z^,7T8B4K3)/U:-X5<3R%RKY9
MUGE"(6[]3.0,@?8LF$0Q>V*?*49Q0G7P*/7XNSG=;Q6)+.(YO=1<+I+F^+W!
M(G:Y^1^WYS^)I56E)%9<RE[I[O.X46'^?%\_\GBFQYXKH:9EN@TR[F]"$$&/
MF"?=US"F"*EK_K@X75Q#YD$S35&,5[TL&P8KB)XCSI>%4"!&3T2]BCWDZZLO
MPR/_N^#]),*KBTI7?__;SM'@OWTRXXYG`*EN*DU1WY$CY@CI.7_"TAV&<MC0
M'&&C%76%2'?2O)V=]E%OPD!/H;Y&](-Z!/X`>#X/[)>R2:9$]D'U.U,=5Q[/
MH]L]34C7)RYS\"ZZ_$J84<V`O`1AW)R%T1:N%GK^_42[&&/J,?)7JS[KBR#3
M&H9=T_Q<&*YC31%+::/K**%#P^-1Z`>WVWOX7,!A\"9UK-[I)*F/69\5W5U9
MGPGEJOMFCA\J(]:K#=.X-6)F:R.-2::@#`7S6]7Q78]2E%6_WVW;"RH.Q?U6
M8T#=5']E_'_DC/O]CM?75QS/)VZWFXU;#HNF<OVOUQ?:Y*T9?M^TC=/`N)9'
M/G!KQWI";1HV9+78Z?9VQ0?;1P<7<Z(JJ,OLFTM[7BK<[Y%2B*DXZVEK]?W=
MTH9GMKQIIN<8I*\5!HV+S@57$RFEX0-K0C5L"CB*S1IL"$'W!YT1PN:HXKFD
M_CX:IX``/>W3!8^(.H2-+9[R0HNA+O1'U#8D<,\G4PG&M793M;!`MHX3OC@R
MSW"VT=Z=5F*-%Y8H>-1T\`&J`WT&+YHG`DXLJ;:89&[R\/'&K#]1BVZ:I:0F
M/TX^^3IX_@Q(9]`40TJ\?'O'A7;C/F4)-#!]+S;6BW!3V#48+GU]%D2&#68O
M4K>K!9H3=@@RZZ*A04SY*W1\8A)B_R,N#;\GM/K_%\+[.\>O)W^PL.#]6]=I
M%@4LDG6HEVLH%E>RBC/>Q`SI:@0&RGHK+!O:83/687EK1RX&W)V7*2<$!M5)
M1,+=Z./^P+95D1*/V;H';T:.T-TSVLHBG2N(&G'"&XM:+GG0QJS2!Q%8EP8)
MM@S+/K%DAQ&KB2F6U'-X=?)I59\2WS_C\7C@T=2V&EF`54H'4QD\,J-J*QR0
MXBFEV@``(`!)1$%4WRE@TG2>QX'GVUL7OC%?UA<$`J>*;YM-<T!0F.]+7!SK
MC%QXWN<P4Y#N20D:5ZMSFU<4&YZ&5CX?SV($CQH01ILB^_3Z_SSN=[R\O.#]
M_58$B.TKLDXY-ZV8>SR>V/=+Y\%.Z(MP/#&F:R\0_.M?_QJ4%O;45DI+\QZQ
M27#=+TBIG//M?H=JQK:E8@<(&R.NG6XB!F%/E?L]\=ZU%9F5;UJ+WIP/,X9N
MJ*QW.`"%WRAK(K(M"C58O(6\>3D&NZ/B6DL26BQM&EW0V#'OEH1W?>U:B%VC
M],C))HV`!E,(!H4FCXYU@=A)4%S[\_"(=O1,,STED=L&?%$H5NMABR_VL8[]
M>2?_8:\Q<4XT[+KCBT6MH1I#0X&9`SY&I&9OX4E0;\C#XRA[=58U'M-*AB>M
M&A\B8&=M"DM9\-&[EJ1`]ZR[(:F98DZ3$D;IQ0,(G(=FZ9%*P-*2$+((%%B!
MPH,QY9#N_T3!^_]*L;O:5/3DQ!1?")X@MX`/U82S5<-2X"71L1*\SXDV61TJ
M.XW)/^A2-"([R!0QJU.U%R%YWIQ_H"'3@J@3ZV(JHGV"#?_M\S@@5>4,H1&\
M0SY7SX+`BI\,2NTP3UT].QU9M7VI1NBN!I4V00CJT6/'J86VC5J#ZQ%OD!ZF
MUVYC-3\EIC<72MC*VB.3(Z0*9JHP#0NFISE"$4:AQ30+G6@A;`-E$M5XP^@.
M"/8=4XZ9!5S2FD5R3'%M/;6Z[9H5W92BN`GM/$^W-7@C$4T7HIC:/#R?>']_
MMP5'HKA36%3^R`=N]UL/KE"7\C9=[:D(.V:ZCGMTR;6ICXISSCVBE%&WXEI1
MOJNAP7Z=Z'Z^]>_>;T/L8\)N%,B50Y\P<WM4M3M8#&2.TA$Y/8P:SG%<&L))
MK4GJ01+ANM?H`[;H7?FF>^%50R73EIRU84PI`)Q(DZY':`=&-\V'7W`3Q9^=
MLYKQN'_?3;&1,U1&A.R*@F!\<H&P<!['/EHA=9NE.!1XO==:V\B(%]WNZTH/
MX5^`'@P3K+F=*M76B%+=C^AK/^05$N$*IJ:F[VFT2;;4P&@/XNAE21(ZZ42_
M/\(<B`^,&>+E9\U7"^*ND0=J\J*V%:*7B*NED@.1S#42:L"KT]`WI>%W$.I/
M6)*%_K/X).=W@NMBT9JLH6K3LZE;$%3711D?X"32,O\L,2ILI?"K@>=T%FP%
MYA?HLBA]X.4664N80(/ZDF5,KZ%'"":40^%;U>GG+=?8\HG$Q55"(BXD?;Q(
M7,PZ1(JHHY9CXY@2*ZUA&U/:2&=?A'NIE<0/>9B&-#=F=K0L@9V0A*,SZX:@
MDS+>_Z=90CD/@K#@][I)+S2T%)+%RTB("?_N0*_'<ZXXC`\MA*8P!)=DG:=/
M'+V94BI<5LTVXCFD=XQWX7%_8/^Q(XG@R>_9=$W)CFQI=1<O/3[RM"54]1C8
M)54GB%:HA<&VI>Y0H1P_[#_+(^O.)[@XUF@?VWHQDQ>@<2'+-`@VNH=K$%GE
M;\?K$C9EOL#MB&X=X?<F41V-(^+.*GHQ8Y//<I\J3&X5@5@-B,,$?*##=)TQ
MTPHDS<$8?3TT[VWJXCV/E+:0&':-:`M$XNO@QMK1!-<7>AW-[,=+(N$(#R(Z
M17].@O.<T]@:P".FP^[O=-LO?%P]4*/,20PF'FYAGVB89J-?0^+%VPW"%OQ0
M&P0R)HIS(F:_=^T8W%XP!2AY2D\'P(EB92@).NZOH*H>(C!,EC5&^YOO@O=W
M$&KY*L)KJXZ/"F5^J#\C8-,5_.S&V*>_IY^#Y",?`7/,&J#&AM^[+MFC(;_R
M:$>^>N-DJJ%TNC[J1DQ^!`T6[`=<XD#41AHUA0W(F&KS5?PGC\G<]PUUM*->
M2-R$?&@&(I@CFM5[=&A71%O[&!_1.8\A954;.C[&2/1#V)095;Y3!HK;_)4H
M.,+BGHB[%U3G)4Q#+:\N1/$I7I6RE5;U,#^(ILCOFQ"<-=CL:PH4)X*7EU>\
MO;]AU5KV2%O3[!8.]/U^-[2&>?PLRT+-HTN^.;$'81LF]JI(DIPME-@)%:%W
M)26Q'#>+[=3'F>O8>$'%80M'T6JJWV-Z6R%/O%UN/C1`(M7='UOH-I,'/7G'
MQ80H^&=2:#HPBNYDHI&9UM"F=PT];0$DW#F(V`(R:J+LLS,[1:CJQX@+B:+F
MILL)HAHG&#-7?2X8M7-C#7V/FH&&M`]ZR&@:4]`8)!EI;<TGW3>,?M<:;@7)
MV/ZQ!9PLIL<LU`+&)(9!%YW]_XR0K!"BK+BTKWTY5\BSZG7Z_4_&425A'E:,
M0*/!_4VP-<O$]^#CS(.RT7>(C_9KI9\7V["+RPWF4`P-UGP.O+`EKG443]\E
M[?]`07QR<S^J.X!S_N_9[TH`M2CT:W9K'WRE!/_DW=:F<91XA'"\O/S?=MC&
M$_&S)T^;G'C#`5.$.W-LB8M/^)&2($#]N`L?:&SG5V$VV0Y[XVC$1S^_&LFE
MNFE+$E/\JJXMVVPTL%W`)%B<_7A"/ES%9.D2H3XVQR#F]O=$UONJ1%7S'+GC
M&I_R197::=!8$9T],]W'#-%'=E^3"+&&0:_Y_U(2BA^M5SX-)(F?#05"M7[W
MWA3!]7+%MI%@J'=7".D]W?>R;BC/HW);V?C?%#[:1_O>D]B*\>)[9L1'T;UK
M&Y=ZZDQPW!AQIY.XU.$XS-//)&@<7.CQ+':KN%8L@*T*A9+&2$@7\$Z9`MMS
M-P(>JV]&9N<!:R^FL.XCS2>U%?Q^O\A9B0^L9GV+$$?K*ZS3LQ;^)VN?6`VQ
M'8R"J/N/+X(Q8M%>_F#[+$6FTGW07*SD--M(66Z\V_.3=;:=S&T"I(M4,*=;
M45+&*9S8D0(NIC5/Q8`$Y2()\C$:W/8U*:`R:@UET>K%E@$<+0J^UIJY-6T.
MNVH-'A\?VS`VBEG-RBCWMEY7IIYEU"3'?CRPSVBJ#A*5PYM3I6<D2\'P_'"[
M3O<#^K!F$8KW%E<'2$`7U,JO_T9X@Q?R0TK#)_YNDBY-*.,G:]I/I!)_-;AX
MQNX0'I]^\E/D:R"QV]SG/">+2:W/SH??S!&GL^HVO&CT@QK8_ZVN$\@3=X0<
MP/*(@FQBD0C=CAJ=F;,KD/4S2^I:/6E5>,'@DU)=/UWJ1O;B<,^L:DT?/NO)
M["@-4]"<VNMHN&"^N0LV4Z6(:TR);JXG:8@+I;4)66=Q^:70":TR\WS7L%C[
M'37-@XDY7O!/6KQG">^H01/WN[7FDIB[:]%H>O>R8M\V/-I&%$7'.L-\\SP:
M9)X+5>NR(6ZS4RZHV/>7A%O)>7@"P//Q[!QQ!&NU0I$/A::1<E6"7VAR(Q24
M(32>;DU.UHYV)1G<2LTSGSE"+_.BH&,ZQ))7:@2#EN[0T,TS<9IQ@R'+,0V\
M?_E^1]2"Z/R*OZ]V>T(E@9Y/TFIN.\PI/RM<6DPVC]^99M'XPL/Y(=.ZJ7T,
MGFLAW!(=VT0J7!'K,?*QF[ATBO9&G3)P)9H1AV9X+]N!2+K:(O$H5^JUY;A>
MF0$E7KB$N-1$/6B<5>6FW$_P7),Z!0]I*:K%W>!A*^C0;'7-<T6-I[W4K=M*
MGS/6TZ)SR&I=9&1<ID[Y:?<^BYU6^IJ@X=[?!6^$0/T;T%V!LV;6\P)5/HFN
M?OR=,VJWXO[*R3FMCD=/YUF?OVJ39U\8QB&0Q;A6S&;I/E<B5%"";V<(3^'V
M\?D:R,)LV(UX1@2BDCL#5M#K;`-SUB0$(V3FG_EK9?/HW0)-.CQU*Y-&OIN(
MQ0J,SJ^*W=#C.+X48=$[QN`2AE5,%S;B^'J!E8M'[L4B"]N:.T'_&9E&LU)V
M0V,.:BV&QLJ[8+X;NZO5./CE]14OUVNU=;OA1HEVY?>S&2>/XE>ZS1'HG([C
M*&EUJU`#D7#A&>ECT=_9:S05<Q[1Q-CDF/[0O9"E>"6W$7]?5UN`A,RKBU;A
MGZCU".7BFQ&G01>@(K^-AWM!*',2=-CCS()-$Y^<K<ALHA<@MBVS'L"?\ZJ5
ML(%Q-!`?VUYYJ!HTS9-O[4EQS`7Z<`UQ-"2R4>/1O'\6-9C@])A@>A?;CS1:
M`Z9D-$S/8,0M5K7BIQ3UH-V6,$_6:Y;;HS&M@=U,A#Y'7)KI9(=`#3=TVN\2
M16SZB:$L:IQ#AS?X8GL:!?&T)\SZC&&')KWP'0WP3'T27]@+*P?FA%._[V1N
ML"&&YL*V1=\^O)]`>'_794)/=G+][.]\$<;5B-*@^OGC#*)$]1.%]V<HHJ>?
M>>)Y:[G`H6Q_689[OJR&V6EQXV/1N_A'8S%#,P,0@SS(2>?/W;<&"]N*"C&I
MLS_HB(PXAXHZZ)G2.C[7\$DZ\V^6@`_F?'W'@J<>Y.Y(X]*^)K"@,1Q,K?.U
MX!M#5%04J7.N<_]=D>8TG;M"N(E-M/)$A5"][H$I&J;%C1$PV9@9M&;0(NZW
M8C^6J[6;Y]]:PWO;"`BDC!>SFN9/B:MJ"B_B\DV"23<UZ;Z@)ZN&!N^N1=[B
MV.Q^WW4QYJ2"E,531K?*J!F]K/UWO$54BPQGCV)&CMPYC7`,&Q[AWX+NV`<]
MW7?X7%LQ[E'?R&]Y%>Q@G@TC!!:*])Z+X,9[!OGZ-A>,E?68=XTPQ;&;TK3O
M9"LY;P-FK@-6X3*1\'`T!QM];OLLXWZA>NZ<Y'R-^65HX4D1SYNMYFP`AAJ4
MEQM3:8AEM/>PR`W\;@>B19$/@;1!L6)QM[>VM"*U>7]=I.1-9F?CNB5GP2=B
MDV+%>&33!#([.AJC\9VKKPO:8/E_WP7O!PCO[U(:PI_\()KW,Y_W55]C":)G
MSPI5D?-J5SXZ#L5ZA(1`.RF(D=</BBA?$*NSN-`S/SF9JWO?+/A&0#[1(!B'
M!'&V9E3\!H#%`C!C[T^=HI']QA9UW:M[,%`Z#<W4(WJ!F`3U:$PA1B`V?9#K
MY.?O'4\7<R/-@CHE'&G/B(]0Q>*3*9.?HQ@5L<#HLBB&FF=I76#2\]%&@6Z]
M/.W&[XLX</1N_2]KIJ:I1?V+XRC^U87_F:W/I<CB3JMMG'IBE%I$U*<TK=8&
MS+GWW$R>C:ZSXXR.C4I._%PR<D.FQ4;2AH4.V[O90>PZQ:R+O,1$\G9N.8SQ
MS#C6--#`K&J.:RX"!L5CM>^LA(KLZQS9F$6\W#/DMZV]0QPWQX9+%7+QXN8%
MHV>B-[\VM09"R4XPN6YZ*O+I'6J(<40CL>BIV-\%\8R#GS7H=!14$8!'7,1K
M,+7SB*_U$!8CR#*/;?-'E\&I5;Y$-`%@GO9TS!I3\GSR)=-ZQ#>AQ,04]NS5
MN;X8+@OSGFD*?KHG0\"MRT`UK\,11U,4XT8EYG^C"N4_$CSQ_W*Q>XI>GM>N
M"SLS/1TM_!9R_!D0N'K0?;I4EF6%.E$S]),5>>0OS!N2>?EU6:6=H)<K_\L9
M*39CU%5A[F2STSCE(^A;02X+`L_@\F/`V$A_C('\UXS1&"&TKM"W`J0%G8!'
M\VZ,:<=/8E8R842@`01Y4<V?H0P0$Y+@;9W\TF<VH98;;,:A"2QV-)])G8OQ
M=FP%0F1U)?$]5TIF2%+10%&H)M>L,$TB:FFL`7!+!(Q&TJ/`*.*EY,:QUM=W
M]H;C"%5_/U)8Y`Y*D;7ATZ"AG@N0CZ9;`QDCZA+9>8U0!O_53-U)LV,'H>M:
MN85</'+,L4\?,WQC"2998FWL>M/BN8[$2??KD@1N(MS,<5(7%UEYL6;,4P.Q
M%H]$LVE%P?!J)N21G0HR)74EF3C8GH+1IP4!C675:&3RAX_<('SBW1P]/"/*
MQ5U#`BY_$=M)0V2!R;&"=P<S3J?&*IEW$08T\/<VN7OE.?9-]->;#UKJC,][
M$V(W5Q-M2":[&HB-A>;WG>PQU>AE6+CLT>-8+&P]<>'\JW4&A^RB;BD19J_@
M%$M:J]52$OJSX!KO!#XWHE0X7_OO@O<#.L,R[.#3]ET!3/AE=/B#4O<3/F="
MX]??(6HX?9.U]_I`H+3^2O46#NO3#S\S'@U^)@[80[M3W@/S+F6V^?(%-M?D
M,9:^]H&5$)?3L&B7%I[`X16NP)&3HG/RA22YKAG_"Z:"T-(B[)C7^ZY^]$3G
MB2,,#(<'M=['"ZBQH]DI39B#(CNQ%4RJ7]ED$B"%KN#%.^H5D(QP9IL'/]3!
MR?R*+VJR4=;/X1U^;!V-B]OYRI&GGPU3%`-">SH)//`#R:Y\[ZBI]@E&+Z[=
MDRQ!01T^%][LGFDV;6*`V*[/1)).EGINW:IN#+';B82I8=V[]F0]B<;XS-&=
MCV6%,`>4'!KM>Q3>)YMQ<;C<LYSKA?^\5BCJ%!V\5=J+N(F:FJC81`47%Y),
M'PAI-WYRPVCEL*FH'K+M=EM;,B[R$G,XJ5_F/^]\5\@R1K/8<GFO9111(S7D
MQ1S!.I9$?&Q_;SOB";'P*+O6\.1#SC?]J/G)JL2'C81ULMJ>)AKB4H0LH$"(
MV+%L.<X\V>\5,9H\?D1&T4_H<3\SKDN(-_U=\/YFJ7G&;?S0GU>_4O)^8$`K
M7S^G*,%\VJ#XP16+]KA=ZO0Y5LQ?:(I+H0=T^MVO^4^HZOF/AW+7&<GI]EX2
M<Y<D.%$U];^XM"![U7W$96S?9`5&MJQ0>VW9;[,ET$1HJJS$9M)%5_8:<@&U
M>-[9L-R)QZ;B#3!F__.]('1.U"S,$65#@J"$8C&6BG!*/6=3K648`$6"29=K
M3UUJX[RA)&84U@N[#`V`(X:%T&#5[D,KJ]QX:E@B7U+FC$["/(.4%RNT9G_5
M+)28[X;@&5QQ$?F\X%3DD=NR4"&B5(QDY$FD,OI+/P)R(^ZLIT7G^)5R'SM7
MD`IGR\/$%-+"#4;WML44KF;XU4K?R[Z\9]9D1A08B+XZC[59I@6QPV:T386Y
MB;4-'&HBS]T(E>5"HEBXU12QM`VZ`Q57?*\FM#K27@AZL9S#6.,:N=N"6&`3
MQ?R"E*;)%<5^0R=1*D^PS+/8W@D9FHP>&8Q<FQ`-FII&GW**C"YZM!ZS'B`1
ML>NNFOE@(/B413,E;`"*X50AZF@'MI&WTZPZO8+70JBA/4I0G0IP3E/RTSR>
M)G5GG-F(70R*;C40(X2$8I0#/_UO']X/*`V_PR^03_UB3*Z6LR_2Y4=-L8-R
M>JRR_+ZS8?3D0^M?K`4KP@M6?5TJGDI@7AQJ(T^Q*$R+#\E_J!L-BF@-_&YE
MQ8M$B"+W\V1QC(("!@;_0%9S\L7Y&3J&\QSVQZJ^^().FSD7DI&;!6O"V1^W
M>R>K1Y5=[^T0X>Y%VP,X)'@>9B_<@=;JLOV+.+(BP%;Y?FE+%C5@_Q1.R`(+
M"-5:5_5S@!G=<89;,\_W?L*^@Q1J$B::#?NODGAJXBU"#!H<-^)*%E^)&B:=
ME>DZHY+3LZ_JW!@2_1X^GB9(O,)$R6Y#3$7'E-<BK<B>S'`W5\5R0/W(?/^K
MYVGS'VW6>WQ]LHNS;M<].1J`*2)QSG]E;G+.V3R'3,WH`1P!8L\_(ZX)[:X(
M*4W'XM>)3-'325()7*!`C*C@XF2U[K'K/GM$EVM8[++/JG:#VK&.M^/J/LK-
M&U9@G-UY/?01X-EM4`9XZ"BMTNY7KEF>K!0+S4CH'I<&4ZKWF)`W,2=W"@DN
M/5_8`K_>RY:1]E#4J7;O4[AS`T5SU[_/VES&Q[NG&$UZOZ:4[I[;,T6V?1GC
M&3->O32-9.&>GP)U(:F.9,%V?$KOG-+[VB/9[>!VFI=^([PGE(;/%+N?%[7I
MHFZ-9$J_4[$OD-55/O").9H`SD;FZP>CGT"L!Y*JQFM/(R0ZB/WDHL.&?"DP
M#3_40F`K!-_[IA`*HY33KAK?/X$L-@,7/>QX%#I5[1)8@'T<N3=;H,U)>[F+
M(ZQ5TT@7\VB?A)Q0.P40@U2M-O2)BJ*1=9H'9R44UOGH5(.<M7N8U7*<27!&
M/@V59E%'W[D^PR+%/2$-F@2$.6)MOTP494SV<'0O%`%P#IML)`Y-Y*+#^@';
M(M9W`EJC94,>G[<L;'Z6WK+-H)1B70WHG#3G'JKA?6H]-U7K:)FYYI+8S<*B
M6Z(V"$*YV3!^F\XK6&VSIHLPE.DS%_<(D]C4HK-8<-\C`5G[YV,5SQO\^Q"\
MSL]_XF*.W17:VI%@8X,9!>2BD:\'H[:NF)ZR:%@E[ZW)R%^U/<,1;U:SN@"6
M@/:Q<JB@.:!?YZ9]+.@,IS"$]CW.XG%N2F"]:"G-3%WC*55;P"N]*A>VS%NW
MZ+>9BM)>TJ/*_6[GGH?A%C3..]/"[3UP1:07O6KV8DZ=M&KM3N<A?CP$TWNM
M?EP:\/P5VKG*8F[L/#T76L,S0'::=G4'[?_?"._O@;B_1Y"8*$/Z<2&C`<7@
M*T>OML=R0^?E>0ZQPV>O@WSNFBTBM-1%+^CJ]R2&E.4$13*%A_.:#9':)//7
MD+K4GH::A8<%+[1Z#Y6I]^6=T&Q_W9W;@W[44'@\,1;EB:2!N+H%7P)TEU=Z
M@]*@&=';#2\:DR(8#Z^3V1=/DA&6Z7G`A0O+\"@.(W;9H/!\G:P2N(TCQ8RE
MR0]3)&@P%VEPP#06S0N_8K[&0@6H?.#US;VV.B^4S,V?&V6K<C<R:#5^%-^:
M@>GTY#Q1T/O7KJAA_=VJJ70E5=`AP,*\=GZ9QAC<(^J9"W*I,B5&XU3GQZC^
M'"-CG,AF.;JZG"1J4-BVY,0(\>6$/7]M>@B$.JJ,6HH(([L=>>5&+$`)5[Q0
M9:0PZ[1NL-L"<WG]U*(_%FE\3D^_<\_P\-9U7&L(..3,<-^G8\]C334I?S,$
MU9!U_XYI#3XQSVQ=F"WO?3PSJ:[GDL9L%RT]K2G2:D<XK!?%-%^9UK%^[WFO
MD(%N]\(PL4\UB>)$@'H]I=)--$+ZFSE:W5P3Q.T-,COG&(H4[^?9"D+5;\TC
MP[)X$F/&:(4;`>EI;SUDLKQ$4/(S;E:1[9B^$=Y/E'$:`)3ZY>(3F'FP,A5-
M_YX"W':`'Y_4^7><&1)(B.E^$K768$Z]XL<&FZ@XKE/48/!F8+C($IV%HUZ$
MD/EYN:^NR!!$F73KSUI['TOX'!H$NR\^ND[=$IFLFIH%3E-I8RI"U:!^'ED4
MP617Y#?)[@+@A$@IB2D,16R7GC5&MWP!95!IEUHFA"HF259<TM+U`K0AFTU,
MND^0[]D*.I4'W[(Y5@AY,D<3(6=0+YA%3B,Z>%QCF[BEQITA29I3Q7HZ$<:S
M43=B1N$3^Z`F1C63'5*9,`!V4K!(E1\_&G:C&^.D*3%P-7&3OF?WHLT%!3#*
M+35VJJ/<*4%4(40'B!#8Z%'S7%D-W#1F'^3QL\E'O_I1?F0Q&/G.^H+917Y[
M=3P+J-H];A[.7)"NZ"+>+<2+,4$4`+3K#FO=E6$CF^'$F$-.X;RT3;@0S+&R
M&&[$"N?`=@SUW9?^%*YU`',B&%/Y^!TQSAQ"R*Z.1CYU3FFA`"5Z4#>X]=LA
MVE(YI\675Z<J`N2Z`5W8DZGSRJ['8%!2L9E(PR*MQ[#-:UXXTACSF=:0EF-)
MPSD"[LN:E:7)LB%PJ7^NC"J?N+B&/CPY_,AH'IJX\KND77>S,=+H)MU?+DXU
MG@NO"FCYB(J!J?L_"V-8>=N*PP6_A(`WWE(JJ.'HQAV_TLXB'%H[$)8)M'(H
M2*H<J8;V`!+@U3HC;$NZA8;3>CFY#Y$YQ3+1KG7X*X1//K:HF'BL(MBV#?ME
M+SS5:&X@THL5;T3>D0<:P0NA!6'0AFLT3I]_*B129%6E7LULGV?#RG#7*T9U
M#:S2$5'F!O/(EA'>CIH2?:-E^/`,5SW76_@Y3R:GGC<G2:DBH6.\OJ7-<&G+
MM4\?+5+=,BI45OL"22U2U#GFBP2Z\;N!]95@&CO;6QT_P^U]%>T]P0D`+`LG
MA1DX5L643#=SW3&'4>@JVE?=F\_(N[KK47V0>R.8^^]:Y-K>7PU\5/F]C)+-
M9B]G"6D2WG;-N`0$U]4[/83THX#7&UZ[8"',FF?19<`U]JX8$:V!HZ$SN9G8
M8YU%CTJ1V>:Y"S0-J[U-J>!B@2`,K8V"&Y1&Z#(0^.(KII4OI5-2'9\Y`Q7E
MM=')9<-[Q7O7#?B)H9FTT=HE!$F++3A',[1-G\'(ZOPLL)-/;4(8<&&$W]"]
MG,^QVMJ!PUC;%4R!`X2Z>7'[?I'OX(F_A:9^Z,80C5=_!U7^`%N,$F!FX%1"
MZ@"6""05P!*#G/S36QV-""T4QW'`3_?-2T*\PC;FRDV,$92=182TF?QP$1W\
MG9/!/L!Q@QJ?C%%:QX"L(+9,.?4CGI`DE\BDL`@MT1_4(%UCV+6EA.OE`@!X
MZ!-9<MEX.?P!L;#$+%K33)FZ8QVH"1>I(%24&YO3C=!;3+$&Y43#USFV;H%G
MY;!%G^IR:^UM*_(TMT8##67N7L!5([0&$$JNHAE#(;6:N,^!JB5D'$#.2*G$
M^>I1><'(@*9^'`T560#Z,>;I/)/YOO6Y$L?:]H(T%><$HBQPL6;6DTS1H'4,
M/8KXT=1XVS,E>R3>+1,7!-`P_E?0T'*9^(Q\/LC:+;3@470,VRH8=P$A5#';
MQ:FB2^T6IR14>%GZBM+[LDI`XT:5D4KO;>M]=B6E[F_+E"ECX)_7J*SGS+8B
MU-N#A<<;^/Y&:+8_!VZVVCW*FLW/MZD/'U^[ICGG@0C7SSV./$]PP@8AB%2F
M=UJ)UQYQJ,6'80CQY97KQ8%`COO;H&284!7PW].R<O9.&^O:YK!`+Y$D@1YZ
M.I7HSAE$Z;#S/;O"J(JM$XP&0#\H:>:J)3<;3?=+(3!$#J?].$7-$"PS+=!0
M/IR5W2H+X-N']^N%I[_9>E((?S6"-_XYZ87=,NP`P7@A*!H^_BZ-I_<RE\Q1
M-]X](UL2U"?.O762DI)-=8FH$74!'X5I`A!$UD*F8LZ^X#(A].++XU#L8**X
MS#,@',LHF'*\S>1G\N8LPY:1#6^+086GX)-ZGY%9E:"XC@0Q;0H7&=@[[UJH
M01WX^(TW@\BR.N,"RU(/XD>WV6EY1PKA]!^'9@[[(SLN9PI&^><\1FQ=/$6(
MBYE)"OU=FCF])C'))9_IF/T)P8L"Q;[OI>#(=QR9[X$8]"E^\HBKZ;B;DZU0
MVW@:TA:@0A"?'.6;$,L&7&&#```@`$E$052U!#UF?#Q*(]]<XXH--:,]:UF-
M;W"246R*:2Q93(GI=[&P91JTDMGFJ_-^@5X8(YA:-$J809!J89ZAIJD?R+I]
MOWS]D0-JP!!T:1A/*_5<=$+-DW46H7L;H<(>!>SA)@VI]`(Z]QIXQ)G?-Y^&
MQNNNP(9[3,$2O;&R5"D3#!)1.#`[M=BB/)GUV^&^8/>7J(#F]4K\^7<+PTR^
MRV,-;&)12E"@9UCLM"%0:$_!%5UHZXKEK!]6*1)0`/TTI`C$LK.XLVL[BP]G
MRDL>SSO'_88Y.R3V#5`.D7AZJ#IE5O3C3SY<PD^=*)SHVY;L;R"\\D%>PH2C
MDB+^L]_7-C%KRK_^I>5('6SR-,^LYWSL3YQX\.<Y*_)Q(.>C6_2<TS$L%<)3
M&/P(7`'D(_>7;)58I<%-$AKE1/='W53<_KX8(=GJ0HG&)!7!!ZG25`!TY:E$
M"*W+G'!WV4VLIL4ZZK2M2E>M#Z2.S^6@#2M^"D0,).*8K)D0Q'2J;S10-ZWD
M"NAA590#)(WM<@;?4BV,T$9<O@G()/[1834T"E&OQ)^WT#%:!0DS6"4]QJLI
M)7)FH.=?,2'F8?&"422EE-QF;?\[J#\(18KSHZC6$FB*'EZ_SQI$%K,%$3\G
MQ5HJARBC/U=4E-7&-]N%3P/Q)!>)BXI^+A*$U@*RSNI-O6_F=!:<-]H#>SYS
MT6DXSL2OU-!Y(HIQQH1P3<#`$JS14?"[ZKS?[]:(D049\WQ;L=O^EY%C;R_E
MBZU^_VDM$>*4YZQ32-.$7N8\"62%>',QY0$&A1=J,+WH<(7^BL"LS>W/<J.Z
MY"'H%?!$HGD`,[4A-TN8WDSRGM@*TH8P3\]T$C/E]125:!_UUI2A2%$0.E1X
M2[/6J":1B5IIU\ID)RV8UY7^'F$XW$3"43Y6[[O,[YH$?M[R[=+P,<)[5F">
M,2]#)MJ'GJOV=Y4?YL\>K\YBL;GP]NCL1^CS>N,-"_W([%QMF$RJW?"V;6;#
MGKYYBE!2JP"5L^M/+[9$F]*Z^%P)Y6R=:U\MM7757!`'@OKNEM"5MN*HQT)C
M,3$(=L<_2-@A20RZ,&UT6"QF+%)0'B4%RGXX?NT)I0:+="L1&_-KKJ?CFG+\
MK(2*>-<5,>+B@S!Z,<T%G>6G:DP>=L6U&E]/+K9[H=MIH<6[4W/YL^/(%05-
M?>"H0='(?J<^E(35XS;&5N-N[F1\+2*G]G=FE-JOO4X%OBY"`%*:)PXA$BG%
MHC!7[\]#<U58)\Q>,[5H/#)R%6!9A-);9&7[W&\)0MQWE:'R'OZO,I3O(M"$
M$1QBZ`>>`F"?Z^RLOU8C08_*SS0>,47:JIC%HJB`*;)MXY@)1FL%?N3BX3UX
MV:?73!."9K=-Y]BC-7=>;IVCI(1M&\+2G'69"JA`Z!T,YZF>C]R+*)'`+6=U
M'5TS(-[IP/M6![#P\*ZM5+TLE;ZT`>W_H%`]((G\A<GM0)?W-Z)`Q'NU\<$U
M4(7.!67PN3S>&^X^=(ZJ=JI)7L,CI$:LCS"[*:@&$RIRH*`FO%W_K(&EJ'<W
M(D3[VZ7A=Q!>'Z+PI0_[F/'K*08KVZ'E[S@H49?%V#B>,%_A$XYI9H3W&?6>
MC&)GVU+`4Z079_*GC?Y)%HE"8D8HI@LT+[+[>?$.!,%L<L6NYMQSQU?L5(?H
M_@L52T'Q;:;ZKOA7G5>^YFDI?K1#1VO$:C*4K"I1P`7'-62CJO_4.U,X"N,(
MR(*(D6G+/T4H9O""%!^3[,?1-D1":8/*O>@%YD2SX0FMU61>;=I0;53&YE]I
M/-ZJ(TGH*WP<1_EY\+1B1H]]#&F_[X2F]&NIZPU<#;5G<$/YWU,76&$Y"M=L
MJ0X]#4\]XB4&=6N(W6399Y#S,4K-4S'<U@3'/R3/W8;B9K(_8D6]4GA3H9_4
M^Q?D:V`B;\FRL"S_D\W]8B1T3L<*'!T$8;RQ!E.N<%D-1LW\3!M+,)=J)F[B
M(R9^C-PXF`=,2+I_'SW_&#[HQL54FJ0XXV2AG;H!#9I0D9`/RN-_W\Q&J&_3
M240.&<R?]N$?T-F_WG#_R5\>ZIU.U%$GR.Y0!NTF=^ZQ3OGSK9E.B[0X[4!(
M-(^+:PTSNNC%_2#491/?:P$1QAO8Q2IK)O_O;+R"C1^W6#_W?A9J0TCL\Z9F
M9NW3#L>C/!(+OPM>K!T:/C:1^@VX6.53IEWB.I:^X"Q(WQJ-R/6\6(\]6BWZ
M]IGS'P(K?*BV:X*KR%-R0I;P.?&>1AVX!DBQ.'ZUQK"K+B!9'H^/HEPF%#3,
M*0[.K6?1YQR,EH6"(&8:"(AWV00A!M5T!4-;!#9"TU5=:EB>:_VR:;7%9Z"O
MW?T!F.R=N,!B1%94<=0BPT9PMI%8JAN>5F[<`:?7&]>-XWV#(E%5<%0OKF%+
M5IH!3B\SMDX"(!/*+56H5O_9HSF]Z&W\L(I$2DV"0BX[4DH)FR0\'\_R?6G=
M2/;SB+Q).<+4%T[B[FE0["+DS8GC@ZX9_]8>RC9'.8\X7G'%S!1*X=YOF2S)
M<)J@9DY!!F(H37B&.$:X>YJV6Q`Z$B@]VT0:#_:,X2?L.:1J?)53$)S03?XI
M!GC0/-0T5Y:G':-^9P(L,XV`#7S@FRK@6.MZW[)6"N0(*/&BUX@*,#E%!']G
MKGO`.QZ6?#(5LA*`&/UG=?!3VW+7T&5U3I3*T>BUD3<H]L(1`XZFXA,?BZ"3
MQ7$CV]9,((WPMR%'2A:.7G9.U[P^RXTQT*P$#2C+WO%T[!,T)!\999:);*=(
M99T\32;:GOCI'8(-QD]/9SW.:*`D`&0B/8$-\VG1[M\N#4&'_"6D]PM5L#AX
M?;PL\P>U8`!FMC,1/(K)#$M&.2\0IU*W/K6I?;=/-\G9)=0XQ`<CP0O#2]O7
M^SCR8=*02I$C'QYGY%XLP0T1A1O;M*^CY)43I:]WQ3>)<^+182?T\]H7`VCI
M`B6:$0.SS(6T#2&NJ8U#;0MW;RR<&7L7W>0BP1D1I:#[4N[-9;]`5?$\GDAU
ML=NW'6G;`%4\CP/'\72(E_W/EA(NEPN>QP%]/.HHB@H+8=%3]7;-1W6<&!M2
M0UU20XQ](=$W+$4^LN,PB[$G:[RR)&J#!5*Y+N70!/OE`M6,XSAZ3*N2V&>@
M*<3Q4S4HC$BJ*6V6#U5T;CJ$%8ZRH8G\4FDL*4KB$H=R2^WLLF9G4V%1<SBK
MJS&:;\\/)B&1Z0_5)::QO9:)HK:C77\N$^#@"J$(130.'!XMI/<GM\U98='M
M17(74Q"2*69+4YG8][<7K(.:9,0Z!HB<TP"9;\STF@G9#V@TMK&+.<NA0-%-
M=R+1GTFLPZ`5]";N?(!GZ1@.K68>>2M@)E08\W7PHJZ9;J-+JSG?:(FZ"9FX
MJ1D"MPP^YBH8AG%SL6M8WY\C7\O%_5)"3[MG>;M'X2:>.X(K2'TZEV2\%<.C
M86%9("S,M*Y(-K%,S#JG&FYU\SU0ASBE,>U9#9$E:L[!UI$Z[X.\#JAMCDVZ
MG7R[-/Q]U%8_!G7/1C!<(:Z92O8ADHB9@$5,K>]^@T)M*+R=X;NZL7I[T=4B
MG6)FJNN+PJCH$*N4#67;MD]?V[%P*;R8;RP\C`JXET$TO,;1QN+M./0C59]7
MW?*"D/5TNJ!3MVW/S]8%&:IB!"9\Z5)*V/>]+QQ''ES'7$>'V[;U\:3*4!^W
M>Y(JQYH-Z]LQ'\_G\`+>=SR?3SR?3QH_$V)7?TZ!_C.C.!G(,;LT2,URT&XQ
M5HZY_5]'/H.-OB'3PB/P6JQL:KV(?0QH7SSKAOQR?0&@>'M['UL"V6@U%7VE
MFM+(?#0`S^<#1SZ,!1,?>QNI<C'3W`X,`FGV.YTXT#T89"'\$O(N\W95=A.6
MB8?/EER>J^J_I_.7A1<KR_ME2)&;B*AKT@4:/0SJU178-G4LYR,4U"3BK"9)
M-8F+C]-RDK-K,AA)Y(UY.!AD4SRJ)7D3S6-.NA.'[#)*6U@4N;];4Z'!Z5?<
MF"F012>18X0*M^,X.C_:3@?ZN]-07\Q3J%5P1E]/H*?^OJ&?=.3XL$A<C`69
M%MF%FYXI%>L^ZG:L#21`K]]=WB<'%!'2Z/<#IGN,ZUZ>[&-!8Q$_Y5`EBI:$
M@2`*=4U.7&R#`5>F;A!72GB=XGUK$DB?,`&'-YRA%XH?(;F?&0OO2'YLD\"1
M]JASQ*3C<W\7O/^S->_T4'5_QS;&)424^RRM7G1V,\NAWVSWK)L#[8$%0C@C
MDG.VN-F7FI."?(S$?H22FX5&-+3%TL_XW'[P9\:K3^VUYD)=@Z`.OXA/F;B1
M"[.L+TA4F"$8Z\&-V&)CCE'8Y.K[VD=SE<ZP;5O?S!^/ARVPM*(P*6'?MDF0
MQ0U`2]W:M@V/QV-\%AW/ON]X?7TM2/#S:5&+D^O0EJY6]`ZUMSBG`WM9-6<<
M.4\+?(L$E92P[1N./.R'RL)/(VT!,HB#JT?OX(;"NKQS^W[!ON]U,E$1U*S]
MH>H3F7I?6(0#53R?#V/+53BXN2./G`3'_JDY\I25T<@-9?]'S6VL6I['^3!1
MPA$HQ$A47)^2P,V[%_AU(&@>U27)>42TH/XR-0(BZZE=X?;J$,V6V"UCP<2S
M#PD*P+%1>T2<4=9L@Q]Z<Z&#JA,481Q0H8@;%L/-=>NP+W;]),Z"_&JB?[EI
M2SX5I*XCAQ.JL1T74QU*BE<\,>5&X*#TP%;TMZF-1FES?7(GA@LN[GC]]RJ:
M.\>,A(M#+L71,S!1"A#$BQ)KMVL"+)+M$=R18H9IS6UKR'PNE)S6-`^^Z#44
MH>0*XS%N5&[TW2F)VD\2FB1ZWKT[U9YDU]T3U!7#_?CY,X?E*C?%PZB3OL]M
MN49CDM$G<H(Y@8_OQ'?!^S?_HY_]^VGD2YS(&'`TF\MJ8S-0OA%\#85D7RA6
M\&,T$O#*WN.`MG&RC]#\1`<@KM#NB>%&YJY3P,/G&@P)1R3*GHMB4[!L`,2\
M*`E1(\2AKX.*$C2OG^V&/-KO?>XZYU@GU:S4AJC01Q5@8W!"3([CP./Q,+9!
M[).95/&$#Z)@^H7V3>KY?.)VOU6Q%2%/]=G(.>-ZN11$R*1]N;0F\AP=GU7@
MW)P%*0$YIU#$TS;$'DX2V.Z(")("/UY?"^J,IQ4+*14I$&0]G,M`1051-N_'
MXXE]OV#;-\C#4D.Z@(SNS?")'K?5*,UUOO\2-3_!/T>HD1K1*0N+LD%$O:N&
MN`*3[T]*$D87SXCK.1U(N>B>J#YJ^.9A\88QJ?$OVVCN,!</$[]YQ)="`4TR
MH6:#ZAR_M&H\8V>DS%($F)>:^OLY<Y9/G#^F\[64LG@<CNZ!/(_ZVY2#J`J.
M-^UM"CG6.O/Q.ZJ&^C"+_Z^]*]MN(\F50!8IN___5^>T9(F5N`^Y10#((FW?
M?I//T4Q;%L5B+9E`()9$K$=HLYMV:F(5F=,T(MT#/Z='K!4:$I$+K4Y'[TM&
MEW!(LZBGU["MUO00AR(O\UC.CH=I!"X32#>4.T>30$O*L3[/!B?Q-)^/)IG=
M.NJ5>_Z93N9H&(CP&A:MR<S:-34*3@^*J"Z$W1`UU(PH?Z/@'C2FS,WGN^"]
M>,#L/W]72PNGV++)UM),P\@SLMMP#(-J3?QWCYIDG[_9JM186&)Z8E)\FD>5
M)>?_3"N<71H+(LY.E)6.4TQSH@@H[<.8"@HK@^Z0W1*\BA1_SBA7_FDSY)/.
M5!T*KJF'+_+*6)C3SM_GYR?$H$ITON@%R=@@K2.6=:05R=I`SY.+W;'8CY\]
M:^.XWN_W.8IGX@R/\<W%/H^1'"+&HU`7X,3.8W4^H]GHDB(RQ26\"?-LAU,"
ML4RMD3O.\R&U5CG*(<?1A6<!+5UI1%979'$I45!I4GM(B4N&@Q%=]@QFHVLO
MT@@(KPLGP'O&(V\T5H5I`R+D*)K*BETO/L-Q-#HQ<*G)Z'/X'2;1.]>%,"Y$
M518R-6@&CA-HFGWF%/C>GUMXOX7*+1/^D<K6G@5+BZ@TL<Q1$-+D0F^554HK
M%`+EI8;7S@1,*#30R6*W)]JF44H1>`&_5H^2._38DT$I<,'SGC%H16.A'&DY
M<:1MD)S'C@N,>F94FJVEJ+(CSA!ORHZCB^XSQHX"ZV559,--S39F+9J>#W/@
M#DY4BA2>`'7!F]=8$UKJNESZO6JAF&:!HZ-B>+&QT(`I+;2M6@2>@*IEFR:"
MP)#O4E>VW=^5#Z_9\[1@2U;2G!!@E^/K/(,P&KQ?'/536L8ZDHP'X[T=$RLM
M-_;03$YFO%LAY^[,1KB;!08WXX"R;M+`/.HVQ"(SD"-X@NK6=]@K<@7P])3.
M('F1K[Y*GQL\WI<5?(?99BM#'B:ZUHO+N>%:5-5:XBZ!YZ]6D[.>\NOSLS<Z
MG(2D8#-'D:6N(:&X4>?%:H;TB7:6;K<;O:8MO#T`X#S)##\+41B\8VX$?:$B
MRR3>G/N`+5/^6JN<]93CZ/0/6=R]X8Y!26[`VT2?7YO.K@K7=8G>,*(Y(%)F
MN6U=*(KV4:.HP-^CJ4+G-45WZ[)2:]<$SJUK8`WH&CH8((NSU3C:SB,X--MN
M=CI-_2D=SJVO>&_5-0XN6EJS<=;E"][C2$O?LXO`VE#P>G!ZI#D`825.M3/=
M++7B*IHA]K[XF19Q6;&LJ8]:0$O)A];RX`]L'*=+@;-4\\*X&<(A0O9FH:#/
M1@`1,@\>T![AG@V@&/BQ0D1Q77SYFD0Y6_CLUT$>E_O.H"Y(%+4%JVL(@)GO
M#<$Y69#+V@9`EV+@U6V8/8<\<)GKO3D.$0NF*SO'ZY."(`$"(\\Z"6M2+KHK
MK'/I?4#WBI)33;:3>LT%B>LO]FWIE)OO/W_(8[A\GO_F=^NFZ(6_;YW%S.2Y
MR1JOPFF(J8:MDH:,0CB7B<98-R%_PI2'OR(7.77EM2J=\]$CB$#/.GXLDY"@
MA%_5&[9#=3_^/6M,#$=(RN^I%TV6-]\/JN0$W?6I-%CQ6\(5G'9/@.P<I<CM
MN/7-H@)Z"QZ+L))[TWMS"5=K8>=$*>S&B<L>C:&[8&U'NXEC3RV%$_O*(6]O
M;UP<P5MQ(IH3Q1@OGHWO.UPH1$JY.PZA3*7Y0+RC#[&&R$P\EW[Q]D(?2Z@/
M*TG)&^]?%</"G7I(4&,!E3FBD.<$[U88!5NQB.SX30ZG,3X9+1<P^;"-\/'J
M*@"\-M4'5.1C9NG*]^56XA'%5O"4U>8:6NH)K2'9:#P[=A*%.C1=-@E@6)@N
M/_(X(<`"-Z3RN6/))B=8#/M&MH;$PBI6+7#L0]'DJ`B[ZU%<((R?@*!'JZ;@
ME;KUG2<CR(??41GF.>Z^O.)!$K?.\5/.C9I-!Q!-'LON(5Y;2,T2D+L`CTDE
M**+]2_28Z\V('J8]M^JB#I2XW?-:GE0.WNQ7-0!,F3N).&#'1\R+6^\TJ7?$
M06=TSV_6I6';AHVQ?-N2_2TJ?%VSVI/OI46RQAO1OTZ=T;69A8")G4X[K9+-
M([N+3!X^8ZH&9>3!JZ4=]K0Y*@WH[$M-=XAD]<<,@0#.9'R"YQM;'T9/#)H#
M2_L3N^AXGGHG^PF"<*:Y,*^_.4UD%]W8(DLA4K4<AQRW6[?6T8G&/LY'LMC+
MY')Z'V`3M)9AAXO,-FF:F&^&$".B4IV"O%-[&1%R*)`J9Q/^^/%C?JX:$#D^
MSR@6PZX(-S&K(E^?7W*_OZW$L#)<@=KK?_S\*2(J[_^^[X&+OK$.H=PJ:"0\
M:YHEU^VL$WE4,&&=@0ZF&P(^:!?<0M/$E5>57`.B3C86KM0(]#1!,7$\9"Z4
MAV]S]8IN)\0S,5*4J^,?(_)'IOB0DB=.D8[W-5^"M>Z6!*G#@@1]72U!/+,8
MX9U+028`"S2(37'MW^M9@1G0YDY1RJ@/"JEL[#6,-):+*>H51:*?>"7_:YF*
M_)#D"3!ILY`K,2P"IGM6>=R.J+3W1I[G;J;?L6@T-K+&B9VFL\@LZ?4!`:J#
M2**MG4ZN:^-61UW)>/MJ1J2A5LLJ\_EM<=A+DNB:\J\EHT;AM$;A&4,MATB1
M?:QYV%M=LZ_![<7`@6>Q_7GRPE.U;X3W"BUX/N%X&0[^+=M>B]CA[G>NB_J<
MT$"@74J]8-J!&8^!B"O$7CNAD],4_KDZM_8LYC[M,M;QP=*E3/=[=HH]FF;`
M(S8<D2:#9=T]K!>@O4]%LN0\J6[&3L8%&SKVHLW3C.-UH\WS/.5Q/N3KZTL^
M!T\V`0!5^:8(U#C7U9OLK:2X.)8YKC6H@A:UK\0-(4$.(X>[_?S'Q_OD_UKW
MS=T]&;`^AX5V69:U@NWSUR<C0QUM.LHA]_N]42W(%LR$Q:;[#.SM!.ZJNR:D
MRB%^P+5.^\Q11$X!*O9WC/C2/682.E)2_\-(?!:D%ND)ZM:C*:_UTQ;"R31D
MI0=%?RG./<MRI3L)ZX3LX<PX44]`\(7'DB&XDA3^-:'=("*[DL4BH)&B5@EB
M2@]N@N[N?@_^-\58=ZH`.BL\VS=K$F,LEE,LK!H%;&`#&-=V#7N"?P[G^@SH
M*^\K;/TVPV94W.1*+Z^5%G8_6*/W`H-`=`U93BZ#DF4OU`$[3O74)P<WF;7G
MSJ?5(/QFT#Y,0/A;J3DIE[7.)MPGH3;XF&`%#4S1>&V#:X^Q2&]0C]3DDF<N
MF*AID?<\]L-OA%=^7[!F\IPI:\^QO">5Z?/?_;L&86;/C\BRA;LO#D<Y1'K>
M]XFC+]F,N5\Z@_HR<K[[F)DGJ-EU61IC#&%!U)V%DV[1W2#.@_63_BU#U=QX
M#O+1UL(TJ\9EF*@J<KO=NT"MTAN.CU8=W_4$WUC<P#,;%^0I$HHF')>L;J/T
M&ZUF&[G&;9X$)C0!T%6@B:3BA+/6B::]O[_+SW_^(6&:SVD?EIDX>A.*XQSB
MK2(J)E^/+[G=;E+*(8_'4J\?MYM8;<$<TR=3F?OIN;E*,<B2FJQGZU%PQI/G
MGMN&DPGSD:9"J%<VKPB1KK*?BFB_#KR0M#A;J\;U!(X[.Q]8BO6M5Z?='C53
M&C<QRS@V/0EJ_EPSC)WC9+*U2KS5!BK=1MB+4XL%5"F'H^WH#";)/%%WJ8!^
MFA2*W001',67`/*8[@]/7`=8-*>3+H"!&PW9%0IM00]G24;4HV(I9<5$KQ'T
M<'S0:-M%EB<R(\8)S<?T,AL>N4S#F![6(%XM)=*&:HTB4"416G*^9$W7B$/N
MT&A\]!7O54RU4Z4IU/B\3"&`I$);WLM>PS)1;\C_+M"T^_LK.@\IX":<T.D[
M#D[/$V*^#0]XG`)2$E6?W*1T/F&]3[O/F=N,2+9J?I]/`;UJ2&?\1GB?%F=Y
M/6JO!DZ\7L?R9/)B-],]!O#DO1RQ(("("YGRNK71E4N_H8/3H$$,F4,#-?+L
M"=T1$X]5/JUXB>>S6M_U7F1.WRQ/L!,6Y4XS?`%?;7UQM&\H''IL])099'04
MC0L]9=4[!)UX2L:7J1R'E*,`N7_]+C-$-QP?U%9TY7P](2`5U.5^%*J!BCG>
M[SQ/,*K?735<>#7L[9E(`K_&L0R?VO&E@*:9B'S^^@R(V70;<-Z,2-,(_@Y@
M@?9X?,G;VPV>GR*W<N]I<R<)X.;YFZMRC>?"%@?4-E9^]N*:,2D,#KU#VY[0
M3#C^KA\CKJ;-7.*?;9.],&94\+[5#'&!OQ<8$9NY4#J%C5KE"?#=?KJ4>>Y'
M4;&S5%0LP#I"KMTR4<<8VIQ7:U]SBJYK6,#3.BMN,YNDW7]G:Q#]+%I285QX
M/U[\>2]$BWN?0YL!M#C/&A+9,H38-^M(]_3ZB$FY&L^7D5=:$QH&X*4ND6$W
MTU89CA:KH"L8?VSR$L?34R(R>H>JSO.:\<@S(3/8Q4R;2S\Q*=,L;,1:]V:\
MB!3M?^]/4J-S#%'M$%$ZX8%R25=<K'.V=DQ[/XW)C1/6,);GD`2CO[8X[0?)
M>FA_*QS<(:Q-G=9JBO@.%*TZOA10;24-P6JB^--\%[RRYS+M=IA7_!!4]95L
MA'U-^I]XHBD7JI:7TCZ2+UN8/8(W/030"LEV'T6WY_UYT:LY%'V)?*M[HIJ*
MFA;O_K`?MYO<[RUHH-EL'7-#H"]'W;`))?E(U?UG0:L:Y:IO+LA;9%Q[.IT]
M1_2]`,^PR1A1TB*)<'`3%ZQLX3;^C%"*2#08"U5QO#?F@!7P><[&Q&$$G<:O
M]GVSGNP,`IML&OTJ0D(P4F#W`(K'^>@A%/<F@+BUAN,Q*!3NO.$!^1C3*`",
ME`IQ&T6&W*UHX@UW,W&`B?2:R-/VSAI&:+2&\7JZUJE0L^:?5A3L>8%0]CO]
MWZOM0FJ8?I3?WRX^O'/]ASW3&/-[M-8`OB,1D+;75V4*SN\`*UG3X5T2=M&Z
M"ISB>F'-M%Y79J&.O\O3%T;(A!>+90@H'KM-IQA>TY`W:P$YC/>])1.)4(S"
MNFG><DTL(+:$BAK35<8Q98U&"$]R-WOJC-*+WNAHP6*Z*"!7<HX9Z\H,?^I%
ML:B)29U<=_^')GR):XX9JWO4)9=ZD"S3JV253JB;30)G>EL#>)3?GV^(`!?)
M*6'J"HEQCWQ3&JY0W&TQ^[P@_0,B@T_@_!.'L<MC4*Y.PV<RV]$.0)B4N4C0
MY/;/J2$*DTA[@<_@P8[U8"B9?OO7HT*^^L6ZUF:@VD>%T\#?>_V*XX/)M8CQ
MJM'2"S/Y*:@R(;[E48X^>D5EK??X7`MK5CB4H\BA*G(<#>4]O:<IASK5@"(:
M1U/C^(T672.$;0:A5"'4'.W(5N.UWO-VO\GGYU?8[.F8BM+HK%U?&/^J#U&`
M\P:"#AH%]F^<YRE63=[N;Z*J<K_?._)[4I``TP3@/8Q'L_A<A8W>C5%#`;-Y
M#E5]^`S3"'1.9R18&<Y([EFHK!&GX0X)!3**F3#Z5G&A;+!CY^FNA6C2)0R0
M9QS#HD`%SIGGX*8T$&L#3$+N9Q&#Q\P<VFI=E"@MN7)ZUA8%X:C&.-U!?Q"@
M1*'P%0)7,DYL5M!69P?FUXGJ$KLX$"`6I>@+[%/APF0@=8:(=)<0(^SFC$4E
M.`<-6L2PJ_-%\+RG!H7!!7(H0(&5G%:$7B]4/!JE^*'@$L-<U!UC]GE'`4JN
M)F;A.:2`#34Q*9W_/>@&)B8GN*(XA-UA-6M3KV4GZ5H``!(K241!5/'AU]K_
MK3"]!)L%#%_!\!_D6DM-R]II+0CB-;^.D,]W:/A`%`R+9/7>XL9`A%A\-LC*
M+0'65-#.KJ&ZPQCMN^#]BVK2_@"%M6>EJ6T!O7T1Z(KDR\)KC+K]:Q`\M1P3
MTL+1CI&CX`Y?7T2K]2*AS)T:3;ILBV4]V7J9(R^WS<SH`-L:TK/CP=O11$*R
MV')5!;5/,H[OB<_7UQX618PTSL0:`!O([7:;1?GPDUV+C,7%W*4J21_16>=)
M[2Q>%D-%89&WA("BD1,M"VVM9G(<18[CF*()I(D<QR'W7DAZE?V(+'U[^R'G
M6>7Q>`1S=Y4#!MKCYBO`T9WV%OTX-4P],+5,B1;3-M8B+7'NQ\\?<K_?1$N1
M]_?WM@$XA32.BY%[3<BQ+J<1?-T,[_!%E23^M-O%0/-FUFP69+.(4`D.).1$
M()[+N^RR@F]W49?XB`$K$FR0^/B<N&@CUC6QS@E6:JIF5+LQ<V]MEBL2UQ>9
MV,2AT;ZG6,_W@/O>H!`>SV0V`4N#)(05[^::(-\,3>_9\?QBW&\B7",+L1H+
MU1T*;$Z$QMQ=C5ZH;AK1G!O6C5J2L`\%I*ZX8_$V:VG'[HNA(10<Q314BXR8
M^V:=U`@.<`"NKRV5*8$,<PI2P14']E&-Q2R?LU&6N8:.IC33Z;W]+HM:AF&I
M1\BPN\_HN7(3IADJKOENU;`7VZIL#;R5&<2R?:#'KDZJEC0NL/.;QO")Y#[V
MT^IO2L.?_OE--.]EEH+^-\=U4?U"W>J4_<#K:;ZMQUI0+!&+^%'4TX^#QMP2
M$2GG08L(TC.^B'DTS-Q<QH2\&7V5A^EDO!GYT91-^R8JK/7ZLGBT0D687SOK
M!^37-?K!V_U-CJ.)21[G@U+VV`!=B2+@G0Y&<MY$5PN:?Z_QO!M"0DPUC\7%
M.-EHG,NS5JGG*:44>?OQ-A/92O]<@R90P3S=2,RQJJ1A.S8Y@^/S%0'.8X'/
MH&SIHVCJM^XS"PC6\#AF#Y^OQV.BXPW=?8@E/*3@:B%+'*2"B7Y0#,IR0R'D
M+!_*I.-$LQK\<WWS1^$.S8\>U-XZ5=L&"3,^6CBD8$GF%RXQ;04*"Y4DP,7%
MAC(BOA#G=@\(.[2X<!5+:!/8`'EQ#KIO"#@Q+(YS+YH-D3Q-EVUL!Y&WNALO
MS\++A(K6K"A5Y^RP0V=?^;Y?5SUJB_Q?7PAGUF?C]45Y$328\/@_9?)_H]67
M)07R1/X*-P*2W).+MJ7@)XR\ZJ1^<]2IY84.ZZOILA.;]`,53GI?,0^(*A<`
M,W0H/CR]R?R&U;_Z^[;W!A]>>LX]CQC!#@W3,W^_7@N4U%O%T[/KS84LH*^Z
M#77R+CQX?`6"HKQ6"9/S]F%1153+-\+[2NUI?U!79AO4,YI#^N\T6I2T2T1T
MYMKO%SQ1<92)8^ZB"7%]/8AG+Y+\@N211-T"V`9=E].9>M_?:''P_'KI4FE&
M=7<<A=(Q443;).-UP9L!36)SGR1T$;L\UHW/QEQH2W<36+[(I1QRN]UFL77V
M<;JZ2LO(>2&/KS[/4SY^_9*?/W_*[7:3Q^/1T0R3+-U5O0@IV7##1MB/Z>/C
M0W[T]]$?C9Y0:Q-BG&>5KZ]/.<\JQW',[^$F>]8J'[\^Y#AN#2UR&_DH'!N?
MK6TD7H0QCTU%;K=#OKX>LU!:_#VA@LO<R.[Q^)+S/.5VM//U>#QR$$KC&5=H
M&]38!@S=-\1PK-M1E6WCE(C'IL-!=#=`KN?@B;?S`HV`>80$)AQ6@RV3.$J3
MC_S6HN&Y(@_BV()L72.(3VQD!@&;9F%>-C0#AG'=KE'P$Z&BZ*E;4@_:=4]%
M"L`XAA+2P^IR6A`04%GW:;:\D/5K;.V"LJR9]2CE%DU3E1,0:<L^0T=GC^/@
MJ%F-:"4CS1R_O#N.ZA*P$-DK&47#%LKO"WF:E,&]@H)8?UYXC+[P>Q,,8ED_
M6X"G78F>U!LJ=T<;3$4&TK[$C@,530:]9G%JXYPFL""T39.$JS_2*;(&++OV
M63.0%;5KV-FG2,$2T-94-`$S!"*JS2'X'(2S_/;;)*ILCY?V=I'O@C>#P;/-
MY3?JKK!)/2^2;3_2E]?H"CZ8:E^LQ_@)&G7TZ6SK@H&P7VN:,*:PP,R1E40O
M/0N==^2'6';LQB<%ZXALX[4$`>.Q:^3<!JN6@;XI]QQF&7];Z;RZPZ7"-O=6
MS+_77E[[YKW6B+.>4C_KW/",PLL!?=W>)]:*Q7YRS_.4CX\/.;K-4O1CY42=
MK'ANU]Y;?*U1UEBP/M[?FP@0J27.M_8\'W*>J291'E\/>3Q.A_8L=(_>4ZI3
M/W!0QGE6&J$/KG3DXZU-=8R$W_]]EY___)3W]W])%**NRYL4$'\_FBU;-]78
M@!&RQ((D*G[`>YDH"YX68.)0)HT<QR3=2Y/)!W?TEEP+SU=@7@!MTM!\IT(K
M30/*ER>GP4-O:-*?QZ<J\H:I4-@$0$!JX'BXQG@[7@N^#N;^+2M8*7FJ<AC.
M+C%S?.\H14X[8>S-A2<GIEWO<UEP!:*R!E0!1GL76AJ"+7!J-:Z>)I9MKD#-
MCLN_!G4``0%W@K]1K,Y@!2QZ1;GIG,_LNB_7/MAR-+48/#$`&<'4,'@E&7.=
MU/.:.\>=[A4Q.#9TP'`)=?U>KQOA*!>JO";@,U^M@E^$!:]K+$P]5W_&M(^G
MCBR8A$`V]?=V*9,F,4$[!5_@L._X6!AN#H+F`>N0;]&:I-U26N2^B-1>H<(O
MO\YRD/>ZT,Y].^,OV3@'4("`23WS//)+)#H!4WTAGAA#1)XB)EUM/I%ZX_!!
MF+48<N"A\*N-A#9O]2B7302`2X7-^4:T#Q.=E,=<9ANV8K>#:\;E@%)V8<$4
M38PC48=;FX3W\TV6]C`*+`"O-D@L#E@8%<>P&17[K&=HX%2'R,"/$,.M.Q=[
MCR)Z+INHB9WF!':KVV_V:2B*<8U"7X"+%HI<-FNTAO-__^OH7RY<(>0#&JGU
M_)&Y:9HX9=3F)8E."26T<=MR%&B/W!A%+M.UMFQ<$]']C&\YD'B:&`AK";)C
M6W]/B`(DG#0PA+;H`@$BQ&J+X]M0RC+12(^DUEJ[SVT-]]I`.4.!K,E>@FO8
MQGO4%W73JS9#VSHB7+R(!ZD3`@X%_>$"R]ZG16Y&=1BH:T9IR3QYPSTP(G/[
MRE6(5UR9@N(H#0/]#4VH*`5D>$]CGC9J#&*A:>/P6K;I*M&>SQ(WJN0^5U"#
M&[[,F&Y!A?LL5.N<2'C``[4%(Z(<*1Y&$UN=X(>/(E^3'PY?P:0R_/P:-RYN
MT'SZ8:>75'1V))S;V-L>]P2KCI:ED3L/3;U*MC[:W(?'>HWIK3C)_BYX7RXA
M8:KP\NMXMW@6+VRO5M4OH(39R_%F?E8[5\D[QB"D">(JW53`;NRA*<Z[SM$L
M>AW72%$,$,=X6^P\N7::HMSK\5#15"B'XV^K=F&\K!-QR\;_DA0+EAT]^;0:
ME-DP\D-(FM"!+FQ+-C)UR,B6AZ*2HQ9.((7C3LY&3^Y3Z!*<;[X3>V4/!\<9
M9V.Y;*PK-*9T'\,)(-%K%45'@R]:S1=9.W&%D1F_21=CU-9@H`U6*$IQX0=3
M?NW-C8],78613K1I5\ADJP6G%&/`B(H/+\\LJ;Q[`2GH51*ZDVMIP_64R5*L
MP:MVX\>K<:W24N0`.L$<@?:Q1!!XE;*=Y&74!T0'55TG=S5!;(;-,^#!?Z!0
ME/;?61UJ/$6O&46J+M6]IK'P^[W$?$1R$,()_6Z?VD9B,!47<)/0WR`R'1NI
M&221+$_>)42NZ!O^&8`)7PW1TGD@DMK9GS^/HZ#(#2T0;8XY:W=$*+T#L1ZS
M;5+39Y,*2I7>+"!K;@F%"6+P(1$6&^GYOUV+9UU$C%,*=7"?D0@;RDIUL=W]
M+U7:]2R#8N0L74=S4<TUWLKH,?*5*M$Z.$I*"ZP3M!8M0L2W:$U^(WA"?^?'
M$J_19X6F[J'0Z]?IWY\$?:'@I^^K^V\6":%!MS\!XR:>YNJEQQ:K([0C<9U0
M%`E=/7:#(=J`XG@EDNZ3TZ#TN&=E:"P2+;%'$8U65:G0!8W[DW-'FZGZU++5
MM4\C[D1%G1:$3^YMCJ_%S/=X]JZX7]E4P:@+]ZFU%J8#>)%WQOWB:"?>[U;,
M(VSP^:P)2*QF:GH__NS'6^,SD!4,@JD_M"@G$Y3I(;HI8I)XTV43MKAR)NP+
M?;W.Z?9WMN\5>*J6K54HTJ@Y2&@%4U08GZL@:D(1&@I6D:[0-3^EK`:IC5=;
MTRY]7%NMRFE5ZA"9NJS3*=#4MM&K$V:V9ZKT:Y.$2@B'*2#5P+L=A#&\RK(_
MO'`H0(V!;9!8@Z`4?SZ].X./S@V?*0F\N(HWSNS3C)J>-8X/L;V)[[A=.$X@
MRNO/5T;=*0FJ7LF)1\6D=$'8,.K!W:*O#7)(E24<DRE:ZW_7(C,.HA>TM1>K
MM1V(5+'^/5Y#P[WO[/[2O1IB=4W08SW6"#;N:1B.6&^*YCH)'M.TSB'%0-&]
MR'E4=^<?Z^D0\QK10K1^IU4,NU((NHGW`MO&L0X@(/AFF4OJ=\$KVTWES^M+
MV_SE,H3@#XOKIP<%SY3??W138$?Z,/-C,&YVCB_Z1C:*UU)&`IA&L]W>C6DI
M7217*,V&KTDL/LIQR'$[<D/RC&;X.]?+=R?`+]IH6J&XE>`4D7L,*B6V\7V8
M*ZL]NAHB7T.*5O([S,<0:+)AX<HDD&##GRE-C',;BN=T7@DI-7&UF,**P!N.
M!:*G.,RF0+UI.3\4BZ/<!\EFO6B4D(`WO5VK.!'DXGG&<74>K8P_YPNH-!U/
MA!36.PJ%69P*#&4X(H(^0=#_#D*-Q9XJM_%82R(.XGNLAH)*76&#8]LJ*Z&+
M1IQP"!6_/XH)C6$&$9G>A%=`0ID_R=ZE@)P+.FKOQE$I/Q6YV6G`1.:'BRKY
M;=(73%S<9YC%(!3#NXD("?-$TI"7&*@@&]I%$YE5*,31ELPVT<IE$V4\"F0J
MZA.!JEZ@V(MCKRXTAKV*#:S=EWL`.OQHZHC!38'SQ*6)@057"8XI7A2'2A[I
MG#Z(*6XH8*N._C"+\73]7F*ZV>0F>QIDF\5SJQ=`HEY!A!8W,.0_$T=:TWMF
M%.Y&4VU(XOLN=_>4@+^'3/7/?J>K<?35=\K4^/KTL%[^[%Q\D"R:T,N1F$5J
M:!S%$-*I4V2B[#/$J&A_J^,XY#B.P$'<8(>7G]77^FG3$9`65HJN<Y)$2XK-
M,`:?]K.S,YI"C#3FT;B;'4CK^&\T`,^2?Q)++@V;,-XD+C@!4>85E)X6:\O8
M/3$A-W&HR^+((B];DV0%SPY&49P751&=Q:ZQS97&1L#)S(;74EIT;+CU];*0
MPG(;D7'D!!N,_-&:;01%%.W/DRXK)MM85^&&6S8QJ+9Y7=C<T(YL%F@I=R!%
M^,MEL`J.:Y6;*XD%#`H=,[#"USSK#E82A"D$@*#PU8NO&E(,26O*=(;6J$OB
M!!)I"1Z9]"<[*VI#XJ!`>AF>8RCXEKBRTECWNA"3M%#.$.&`GB;/OB^,EI"Y
M@QR23S1HN@'<V31\8^-B<25Z"W:)PF)E'6NU#&<-FS&^VC#=OH[7X:C;7'/(
M*I.I4Y,B@#CR;-96@ZQNS4(+O%)X:I!=BW3ZB#]3E"S17J-\L#7@BA]VR:"(
MK"ISI9_1)U,[1['P[(=F#M"7@D6_18]A$E+;=_!$OA#]O_YRN;"IPLXDP:[0
MT]^N4.!$C?:[80^7AYUOC)84VVCTO&Q*E%#0@&0.P57&992-4E16THZ9_5&[
M\CN!=E0JJD?V,C3=)88XH5I8\,%XWWN7^E'Z-%@GFG0NF`J+AGH.E"9HD9!"
M>"'ZA?PHO=%J.LK,_%KUZGH!ES8+76F2X,5K<^(=?&`TRP$GU2[\K!425(U;
M=")A`^E*.-M90(%'[*O5R:W-&A][2NR'0J"("_]H!9N9.0\6?":=D`V0L\QU
M8*T1"^W*#+"#G170%AJJ5W/>ID:C?`W3AY6&-B@&.H,>'!H*0IRBW'@LP:]M
MIWFA@>CG%PNNN;9MD</^_S4Z.(0F0S7E+'N/7DP'LR`6LM3LGSL631,7=V$8
MOGA.;29'82J%"I[@<@$HX:[HCB$4-8SV%3^_*VZ+0XDG%2@!M7QSHH,8*Q:$
M6A1(X3RQF6Y2)S^<*%C]?BNJU-@5*DJ[KZXRCWG6`\#;-A=C[]<]'YXQ_:N]
M6$Z<@Q0^ZZ.)PJ4;WK^X9RA`-MZ52&0Y/VCTNR^3TN4$Z"X.&),;]4)`2]2I
MDE""1.3_`+M*R6:N=@G=`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+VED96%S+V=R87!H:6-S+VUE;G5?=&]P+G!N9P``
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,C0U(#$P-3$U-#,S-S0V(#`R
M-#(U,@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12`````0```#("`P```."561D````,4$Q412]<
MESJ5S/_______RE&YND````!8DM'1`,1#$SR````"7!(67,```!(````2`!&
MR6L^````#TE$051XVF-@H#%P8'````%D`('-KE#;````%W1%6'1C;VUM96YT
M`&=L;W5D96UA;G,N:6YF;WR@-=``````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]I9&5A<R]G<F%P:&EC<R]L969T7VUE;G5?=&]P+G!N9P``````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,30Q-R`Q,#4Q-30S,S<T-B`P,C4R-C8`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```2L```!,"`8````U(I'B````!F)+1T0`_P#_`/^@O:>3````
M"7!(67,```L3```+$P$`FIP8````!W1)344'U0<8#QDY9O/B<0```!UT15AT
M0V]M;65N=`!#<F5A=&5D('=I=&@@5&AE($=)35#O9"5N```"<TE$051XVNW;
MO8H=91S'\=\\,^?D;*()[L8J&&R"C9!"(T2$@"20(I>0SLO04J_!&\A%"(JX
M:"7::1$21`QV.1M8ESTO\V:Q816#E8:=XO.!IQNF^!=?_C/,5-?O?SX&8.**
M$0!B!2!6@%@!B!6`6`%B!2!6`&(%B!6`6`&(%2!6`&(%B!6`6`&(%2!6`&(%
M(%:`6`&(%8!8`6(%(%:`6`&(%8!8`6(%(%8`8@6(%8!8`8@5(%8`8@4@5H!8
M`8@5(%8`8@4@5H!8`8@5@%@!8@4@5@!B!8@5@%@!8@4@5@#_67/AY@U3`&Q6
M`/^':O_Q<C0&P&8%(%:`6`&(%8!8`6(%(%8`_ZI)DEL_?VL2P$M3)WFMF>?M
M\Q?SP:M[N5XUN32;IY0Z52E_G51)5:6JJA?N4>T_7HX[K[2F";PT[3#DR7J=
MKP\.\M7!,K^N5KEU\7(^6ES*ZSL74II92JE3ZOIYK,H+P1(KX$Q\_.A1OCQ8
MYI,K;^7]L:3,9FF:>4K3G&Q9_PB66`%G9CT,N?OC#[E_^6KNC75FYQ:IY^=2
M-[.44E*5^C187K`#9V912KZY\5X>//TMW\^;;(Z/TFU6&;HVPS`DXYAQ',4*
MF(8OWGDWG_[^,,O#9]FNCM-M-QG[/N,XG%XC5L`D-JP[NWMY<'Z>[>HX[6:=
MOFLS_"U88@5,PF?7KF7_\&F.5D?IMNMT[29#WV4<Q`J8F#=W=O++E:OI-NOT
MVZU8`=-T>W<OW_VQ/-VL^JX5*V!Z/MS=S4_'A^G;-GV[3=]U&88^R?/?;0"F
MX(W%(L^Z;?J^G#P"]KW-"IB>62GIDXS#<'+&(<G)=U9_`L[0P6(2KC%4````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]I9&5A<R]G<F%P:&EC<R]L969T7VUE;G5?8F]T=&]M+G!N
M9P`````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`Q-3$R,B`Q,#4Q-30S,S<T-B`P,C4W-C8`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```2H```G$"`8```"]FRFZ````!F)+1T0`_P#_`/^@
MO:>3````"7!(67,```L3```+$P$`FIP8````!W1)344'U0<;$188J0_/=```
M`!UT15AT0V]M;65N=`!#<F5A=&5D('=I=&@@5&AE($=)35#O9"5N```9MDE$
M051XVNW<OXY491S'X>_[[\R9@0S9A,N@ML72WL2;X18L#2VWH#6$6E&O8`L)
M-!3NA$3"KB'9L3C#XL88"[/L%,^33#G-K_CD-^]YSY07;][L`W`$OOCIQSRY
MV&>^L\UZ>Y+Y[KV,>9UJ-,"Q$RI`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`
MJ`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*
M$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H
M`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0
M*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"
MA`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J
M`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$
M"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0*$R@@`H0(0*D"H`(0*0*@`H0(0*D"H
M`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0
M*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"
MA`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J
M`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$
M"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`
MH0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*
M0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A
M`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`
MJ`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"
M$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H
M`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0
M*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`
MA`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J
M`*$"A`I`J`"$"A`J`*$"A,H(`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"
M$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H
M`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0
M*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`
MA`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J
M`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$
M"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`
MH0(0*D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*
M0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A
M`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`
MJ`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"
M$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H
M`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0
M*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`
MA`H0*@"A`H3*"`"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`
MJ`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"
M$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H
M`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0
M*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`
MA`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J
M`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$
M"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`
MH0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*
M$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A
M`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`
MJ`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"
MA`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H
M`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0*$
MR@@`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A
M`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`
MJ`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"
MA`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H
M`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0
M*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`
MH0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J
M0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A
M`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`
MJ`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*
M$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H
M`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0
M*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"
MA`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"A,H(`*$"$"I`
MJ`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*
M$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H
M`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0
M*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"
MA`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J
M`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$
M"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*$"H`
MH0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*
M0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A
M`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`
MJ`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"
M$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H
M`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0
M*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`H3*"`"A`A`J0*@`A`I`J`"A
M`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`
MJ`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"
M$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H
M`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0
M*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`
MA`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J
M`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$
M"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`
MH0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*
M0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A
M`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`
MJ`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"
M$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H
M`(0*$"H`H0*$"D"H`(0*$"H`H0*$R@@`H0(0*D"H`(0*0*@`H0(0*D"H`(0*
M0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A
M`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`
MJ`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"
M$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H
M`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0
M*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`
MA`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J
M0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$
M"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`
MH0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*
M$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A
M`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`
MJ`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"
MA`I`J`"$"A`J`*$"A,H(`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`
MH0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*
M$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A
M`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`
MJ`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"
MA`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H
M`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0
M*D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`
MH0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J
M0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A
M`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`
MJ`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*
M$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H
M`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0
M*@"A`H3*"`"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A
M`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`
MJ`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*
M$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H
M`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0
M*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"
MA`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J
M`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$
M"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`
MH0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*
M0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A
M`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`
MJ`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"
M$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0*$R@@`
MH0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*
M0*@`A`H0*@"A`H0*X'9]N+Q,$RK@F+V^N,A)GY+]/BEE^20II0@5<!R>[W9Y
ML-E>!>I0J>SW>Z$"CL.SW5F^>?4J24FNM<I&!1R)E^?G2YAJ3:TMM;644K*/
M,RK@"#PZ/<W#[?U,O:?UGMIZ2FTIM:;$1@7<LHO+RSS=G>7KE[^EMI[:1_J8
MEF#5EM22;DS`;?KJUU_R^.W[3&.5/J:,:4X;J\-659U1`;>[27WY\XM\NWN7
M7DK:&&G3*GTUITU36A_+.55L5,`M>'1ZFJ>[LSQ^^SZCE+0Q9:S6F>9-^K1L
M5K7UJ_M40@7<J`^7EWE]<9'GNUV>[<[R\OP\#[?W\]WNCTQCE3;&$JGUG8QY
MD[%:I[;#-E66GWXE/WR_-TK@IK0D)WW*@\UVN2=5DE4?*;4MA^;3*M.\R9@W
MRT:U6J>-ZZ'J3RYT"KAI?R;O?D_F34JM::VGCK$<G$^KC-5Z^<DWS8?K"9\B
ME21]OK,U0^!&[;/<,$_)X3)G3QM3^EBE3=/A3&JD?HQ4RE6DDJ2OMR>F"'R>
M4.WWR[6#UM)Z/SS9ZX=/2TJYMDE=A6J^>\\4@9MU[=V]>O6:3&I-/=R5*J4>
M0E7^\?4^YK4A`I^G5X=W]TI*4LOAB5[YUT!=A:IV-Q2`SZ=^7*_^]G]3_Z67
MXG(Z</.;U/_Q%^`$=%RA@]&U`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]I9&5A
M<R]I;F9O+G!H<```````````````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#$W,2`Q,#4Q-30S,S<T-B`P,C$U-C``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D
M93H@:&]R9&4O=&AE;65S+VED96%S+VEN9F\N<&AP+'8@,2XQ+C(N,2`R,#`U
M+S$P+S$X(#$Q.C,T.C$X(&IA;B!%>'`@)`H@*B\*"B1T:&5M95]N86UE(#T@
M7R@B261E87,B*3L*"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O:61E87,O<V-R965N+F-S
M<P``````````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3$W,S(@
M,3`U,34T,S,W-#8@,#(R,3$R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"\J*@H@*B!)9&5A<R!T:&5M92!B>2!2;V5L($=L
M;W5D96UA;G,@/'(N9VQO=61E;6%N<T!I+71O+6DN;FP^"B`J($)A<V5D(&]N
M('1H92!)9&5A<R!T;R!);G1E<F-O;FYE8W0@0E8@=V5B<VET92`H:'1T<#HO
M+W=W=RYI+71O+6DN;FPI"B`J"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+VED
M96%S+W-C<F5E;BYC<W,L=B`Q+C,N,BXS(#(P,#8O,#,O,C0@,3DZ,S,Z-#<@
M8VAU8VL@17AP("0*("HO"@IB;V1Y('L*("`@(&9O;G0M9F%M:6QY.B!697)D
M86YA+"!'96YE=F$L($%R:6%L+"!(96QV971I8V$L('-A;G,M<V5R:68["B`@
M("!B86-K9W)O=6YD+6-O;&]R.B`C8S%D8V5D.PH@("`@8F%C:V=R;W5N9"UI
M;6%G93H@=7)L*&=R87!H:6-S+V)A8VMG<F]U;F0N<&YG*3L*("`@(&)A8VMG
M<F]U;F0M<&]S:71I;VXZ(&)O='1O;2!R:6=H=#L*("`@(&)A8VMG<F]U;F0M
M<F5P96%T.B!N;RUR97!E870["B`@("!B86-K9W)O=6YD+6%T=&%C:&UE;G0Z
M(&9I>&5D.PI]"@HN=&5X="!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C8V%E
M.&4X.PI]"@IA('L*("`@(&-O;&]R.B`C,F8U8SDW.PI]"@HN<V5L96-T960@
M>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V)A9#!E-SL*?0HN:&5A9&5R('L*
M("`@(&-O;&]R.B`C8F%D,&4W.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(S-A
M.35C8SL*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C,#`U,SDV.PH@
M("`@=VAI=&4M<W!A8V4Z(&YO=W)A<#L*?0HN:&5A9&5R(&$@>PH@("`@8V]L
M;W(Z("-B860P93<["GT*+FAE861E<B!A.FAO=F5R+"!A+FAE861E<CIH;W9E
M<B!["B`@("!C;VQO<CH@(S)F-6,Y-SL*("`@('1E>'0M9&5C;W)A=&EO;CH@
M;F]N93L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",S83DU8V,["GT*82YH96%D
M97(@>PH@("`@8F]R9&5R+6)O='1O;3H@,#L*("`@(&)A8VMG<F]U;F0M8V]L
M;W(Z('1R86YS<&%R96YT.PI]"@HN:&5A9&5R8F]X('L*("`@(&)O<F1E<BUL
M969T.B`Q<'@@<V]L:60@(S`P8C%B,#L*("`@(&)O<F1E<BUR:6=H=#H@,7!X
M('-O;&ED(",P,&(Q8C`["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@
M(S`P8C%B,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-C864X93@["GT*"BYL
M:6=H="!["B`@("!C;VQO<CH@(S,S,SL*?0HN<VUA;&QH96%D97(@>PH@("`@
M8F%C:V=R;W5N9"UC;VQO<CH@(S-A.35C8SL*("`@(&-O;&]R.B`C8F%D,&4W
M.PH@("`@9F]N="UF86UI;'DZ(%9E<F1A;F$L2&5L=F5T:6-A+'-A;G,M<V5R
M:68["B`@("!F;VYT+7-I>F4Z(#$Q<'@["GT*82YS;6%L;&AE861E<CIH;W9E
M<B!["B`@("!C;VQO<CH@(S)F-6,Y-SL*("`@(&)A8VMG<F]U;F0M8V]L;W(Z
M(",S83DU8V,["B`@("!T97AT+61E8V]R871I;VXZ(&YO;F4["GT*+G-M86QL
M('L*("`@(&-O;&]R.B`C,#`P.PI]"BYC;VYT<F]L('L*("`@(&)A8VMG<F]U
M;F0M8V]L;W(Z("-B860P93<["B`@("!B;W)D97(Z(&YO;F4["GT*"BYC;VYT
M<F]L(&$@>PH@("`@8V]L;W(Z(",P,#`["GT*+F-O;G1R;VP@83IH;W9E<B![
M"B`@("!T97AT+61E8V]R871I;VXZ('5N9&5R;&EN93L*("`@(&)A8VMG<F]U
M;F0M8V]L;W(Z('1R86YS<&%R96YT.PI]"@HO*B!&;W)M('-T>6QE<RX@*B\*
M:6YP=70L('-E;&5C="P@=&5X=&%R96$@>PH@("`@8V]L;W(Z(",P,#`["B`@
M("!B86-K9W)O=6YD+6-O;&]R.B`C9C-F,V8Y.PH@("`@8F]R9&5R.B`Q<'@@
M<V]L:60@(S`P-3,Y-CL*?0II;G!U=#IF;V-U<RP@=&5X=&%R96$Z9F]C=7,@
M>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V9F9CL*("`@(&)O<F1E<CH@,7!X
M('-O;&ED(",P,&(Q8C`["GT*+F)U='1O;BP@+F)U='1O;CIF;V-U<R!["B`@
M("!B86-K9W)O=6YD+6-O;&]R.B`C,V$Y-6-C.PH@("`@8V]L;W(Z("-F9F8[
M"B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(S`P-3,Y-CL*("`@(&)O
M<F1E<BUR:6=H=#H@,7!X('-O;&ED(",P,#`["B`@("!B;W)D97(M;&5F=#H@
M,7!X('-O;&ED(",P,&(Q8C`["B`@("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@
M(S`P8C%B,#L*("`@("UM;WHM8F]R9&5R+7)A9&EU<SH@-7!X.PI]"BYB=71T
M;VXZ:&]V97(@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(S)F-6,Y-SL*?0H*
M82YF:7AE9"!["B`@("!C;VQO<CH@(S,S.3L*?0H*+G-I9VYA='5R92P@+G-I
M9VYA='5R92!A('L*("`@(&-O;&]R.B`C.3DY.PI]"@HO*B!-96YU('-T>6QE
M<RX@*B\*(VUE;G4@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(S)F-6,Y-SL*
M("`@(&)O<F1E<BUB;W1T;VTZ(&YO;F4["B`@("!B86-K9W)O=6YD+7)E<&5A
M=#H@<F5P96%T+7@["B`@("!B86-K9W)O=6YD+6EM86=E.B!U<FPH9W)A<&AI
M8W,O;65N=5]T;W`N<&YG*3L*("`@(&)A8VMG<F]U;F0M<&]S:71I;VXZ(&)O
M='1O;3L*("`@('!A9&1I;F<Z(#!P>#L*("`@(&-O;&]R.B`C8F%D,&4W.PI]
M"B-M96YU(&$@>PH@("`@8V]L;W(Z("-B860P93<["GT*(VUE;G4@83IH;W9E
M<B!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C,V$Y-6-C.PI]"B-M96YU(&$N
M8W5R<F5N="!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C,V$Y-6-C.PH@("`@
M8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED("-A86,["B`@("!B;W)D97(M<FEG
M:'0Z(#%P>"!S;VQI9"`C86%C.PH@("`@8F]R9&5R+6QE9G0Z(#%P>"!S;VQI
M9"`C,#`P.PH@("`@8F]R9&5R+71O<#H@,7!X('-O;&ED(",P,#`["GT*"B\J
M(%-I9&5B87(@<W1Y;&5S+B`J+PHN<VED96)A<B!["B`@("!B86-K9W)O=6YD
M+6-O;&]R.B`C8S%D8V5D.PH@("`@8F%C:V=R;W5N9"UI;6%G93H@;F]N93L*
M("`@('!A9&1I;F<Z(#!P>#L*("`@(&UA<F=I;CH@,'!X.PI]"BYS:61E8F%R
M("-M96YU('L*("`@(&AE:6=H=#H@-S%P>#L*("`@(&)A8VMG<F]U;F0M:6UA
M9V4Z('5R;"AG<F%P:&EC<R]L969T7VUE;G5?=&]P+G!N9RD["B`@("!B86-K
M9W)O=6YD+7!O<VET:6]N.B!B;W1T;VT@<FEG:'0["B`@("!B86-K9W)O=6YD
M+7)E<&5A=#H@;F\M<F5P96%T.PH@("`@;6%R9VEN+6)O='1O;3H@,'!X.PI]
M"B-S:61E8F%R4&%N96P@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V-A93AE
M.#L*("`@(&)O<F1E<CH@;F]N93L*("`@(&)A8VMG<F]U;F0M:6UA9V4Z('5R
M;"AG<F%P:&EC<R]L969T7VUE;G5?8F]T=&]M+G!N9RD["B`@("!B86-K9W)O
M=6YD+7!O<VET:6]N.B!B;W1T;VT@<FEG:'0["B`@("!B86-K9W)O=6YD+7)E
M<&5A=#H@;F\M<F5P96%T.PH@("`@<&%D9&EN9RUB;W1T;VTZ(#(P<'@["B`@
M("!P861D:6YG+71O<#H@,'!X.PI]"B-S:61E8F%R4&%N96P@82!["B`@("!C
M;VQO<CH@(S)F-6,Y-SL*("`@(&)O<F1E<CH@;F]N93L*("`@('!A9&1I;F<Z
M(#!P>"`Q<'@@,G!X(#%P>#L*?0HC<VED96)A<E!A;F5L(&$Z:&]V97(@>PH@
M("`@8F%C:V=R;W5N9"UC;VQO<CH@(S-A.35C8SL*("`@(&-O;&]R.B`C8F%D
M,&4W.PH@("`@=&5X="UD96-O<F%T:6]N.B!N;VYE.PH@("`@8F]R9&5R.B!N
M;VYE.PI]"B-E>'!A;F1"=71T;VX@>PH@("`@;6%R9VEN+7)I9VAT.B`V<'@[
M"GT*"B\J(%1A8B!S='EL97,N("HO"BYT86)S970@>PH@("`@8F]R9&5R+6)O
M='1O;3H@,7!X('-O;&ED(",P,#4S.38["GT*+G1A8G-E="!L:2!A('L*("`@
M(&)O<F1E<CH@,7!X('-O;&ED(",P,#4S.38["B`@("!B;W)D97(M8F]T=&]M
M.B`Q<'@@<V]L:60@(S`P8C%B,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-C
M,61C960["GT*+G1A8G-E="!L:2!A.FAO=F5R('L*("`@(&-O;&]R.B`C8F%D
M,&4W.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(S-A.35C8SL*?0HN=&%B<V5T
M(&QI+F%C=&EV951A8B!A('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R
M;W5N9"UC;VQO<CH@(S)F-6,Y-SL*?0HN=&%B<V5T(&QI(&$N86-T:79E5&%B
M.FAO=F5R('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9"UC;VQO
M<CH@(S-A.35C8SL*?0H*+RH@06QT97)N871I;F<@<W1Y;&5S+B`J+PHN<F]W
M179E;BP@+FET96TP('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-C864X93@[
M"GT*+G)O=T]D9"P@+FET96TQ('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z('1R
M86YS<&%R96YT.PI]"@HN:71E;2!["B`@("!B86-K9W)O=6YD+6-O;&]R.B!T
M<F%N<W!A<F5N=#L*?0H*+RH@4')E9F5R96YC97,@;W9E<G9I97<N("HO"BYP
M<F5F<T]V97)V:65W(&@R('L*("`@(&9O;G0M<VEZ93H@,31P>#L*("`@(&9O
M;G0M=V5I9VAT.B!B;VQD.PI]"BYP<F5F<T]V97)V:65W(&1T(&$@>PH@("`@
M8F]R9&5R.B`Q<'@@<V]L:60@(S`P8C%B,#L*("`@(&)O<F1E<BUB;W1T;VTZ
M(#%P>"!S;VQI9"`C,#`U,SDV.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(S-A
M.35C8SL*("`@(&-O;&]R.B`C8F%D,&4W.PI]"@HN<')E9G-/=F5R=FEE=R!D
M9"!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C8V%E.&4X.PH@("`@8F]R9&5R
M+6QE9G0Z(#%P>"!S;VQI9"`C,#!B,6(P.PH@("`@8F]R9&5R+7)I9VAT.B`Q
M<'@@<V]L:60@(S`P8C%B,#L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI
M9"`C,#!B,6(P.PI]"@HN<')E9G-/=F5R=FEE=R!D="!A.FAO=F5R('L*("!C
M;VQO<CH@(S)F-6,Y-SL*?0H*+F)O>"!["B`@("`M;6]Z+6)O<F1E<BUR861I
M=7,Z(#$P<'@["B`@("!B;W)D97(Z(#%P>"!D87-H960@(S`P8C%B,#L*("`@
M(&)A8VMG<F]U;F0M8V]L;W(Z("-C864X93@["GT*"G1D+FQI;F5D4F]W+"!T
M<BYL:6YE9%)O=R!T9"P@=&%B;&4N;&EN9612;W<@=&0L('1A8FQE+FQI;F5D
M4F]W("YI=&5M+"!T86)L92YL:6YE9%)O=R!T:"!["B`@("!C;VQO<CH@(S`P
M,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-C864X93@["B`@("!B;W)D97(M
M8F]T=&]M.B`Q<'@@<V]L:60@(V,Q9&-E9#L*?0HN;&EN9612;W=396QE8W1E
M9$-O;"P@=&0N;&EN9612;W=396QE8W1E9$-O;"P@=&%B;&4N;&EN9612;W<@
M=&0N;&EN9612;W=396QE8W1E9$-O;"!["B`@("!C;VQO<CH@(S`P,#L*("`@
M(&)A8VMG<F]U;F0M8V]L;W(Z("-C,61C960["B`@("!B;W)D97(M8F]T=&]M
M.B`Q<'@@<V]L:60@(V-A93AE.#L*?0H*=&@@>PH@("`@8F%C:V=R;W5N9"UC
M;VQO<CH@=')A;G-P87)E;G0["GT*<W!A;B!S=')O;F<@>PH@("`@8V]L;W(Z
M(",R9C5C.3<["GT*"@``````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VMO;&%B````
M````````````````````````````````````````````````````````````
M`````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P,#`P(#$P-3$U-#,S-S0V(#`R,#`T,0`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O:V]L86(O9W)A<&AI8W,`````````````````````````````
M````````````````````````````````````````````,#`P-S4U(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W-#8@,#(Q-C0Q`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]K;VQA8B]G<F%P:&EC<R]K;VQA
M8BYP;F<`````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,S$W-R`Q,#4Q
M-30S,S<T-B`P,C,U,C<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```(P````H"`8````L31+&
M```61DE$051XVNV<>7A<U7G&?W>9J]E'THS6T;Y9MH2QP=AF-00,#@%CXA@,
M*8%2V@0,;8$"80DE)90D$"A-:!*:%-)0MZP.D(#!9C&;C5>\R;(E2[:UKZ-9
M-/N]MW\,'FDT(]L0DT*J[WG\//:]=\[YSCGO?;_W^\ZY%G1=U_DS,%75:&\?
M8M.F@^S<V<VV;1WT]?D9&`C0W^\G&E.QVXPHBH3+967:M'SJZPN9,Z>,L\^N
MQ>6R,F5'-^'+!IBNKA%"H2C5U7EHFL[O7MK!'UYMXJVW]M+9.?*9VI1ED05G
MU7+UU7/YQM)9*(H\A8PO.V!T7>?.^U[CB5]_B*;I++UT%K]\[.LLOO17K'UK
MWW'KIZK2R0^^?R%+OWXB@B!,(>3+"ICF_<-<^NU5*=>>?/A"]NSHX*:_?Y$2
MMY7*<@=Y^29L5@6;34$4P>>+XO-%Z>X9I?V`E[Z^(*IV]"%?=.$,GOCY9>1D
MFZ90\F4#3"`0H7,HP@T/;TZY_N!W3J3(%F=_6QMVFY(8D"`@RS(&@P%)DI+L
MI*HJT6B4@<%1MGT\P-OO=K%I2Q^1J#IIOW4U+E8]>PUEI3E32/DR`*:WS\]=
M]ZTF$(CPW[_Y)@_\KH?FOB@`Q7:)!RYS,SS81S0:Q6JU8C*9R,K*0A3%C.%$
MUW7B\3C!8!"_WT];>Q__N7(7K[QV@'`D,W"FU^7Q^Q>OQ>6T3*'EBPH87==9
M^=QV[OW!&CPC(<I+K:Q:>27ND@)V]*F$XS"[4,*L".BZ_IFUAJ[K!(-!MGW<
MQCT_6,>.W<,9GSOW[')6_OI*#`;#%&"^:(#Q^</<\8]O\,)+NS";#%Q]11T7
MGE>,+(N4E961EY?W^?3K"W#7/[W!LZN:,]Y_]($%7'GY:?_OA?`7"C"M[<-<
M<\.+M+8-TSC=R6TK&G#E&E`4A9*2$K*SLX^X8`.#(0X<\N'U1?",1+#;%)RY
M1NJJ<[#;E:/VKVD:=]SW!K]]9D?:O6DU=IY[\NODY^=/`68\1=]R]_OX_`F=
M$(VJ^$=C6*T*JJIQQKPB5EPW,ZV1AW^VE37O=,*$M8S'-$Q&B:<>/P^7\\C9
MQL:M75SW]R\S/!SBHO/+N'9Y)9($>7EYN-WNI(`=;[&8RIIW.GGY]0-T#8:P
MY1@IKW20XS22G6/$[XLR-!BBO=5#U!_ES%,*^:MO3L=FFQP\\;C&I=_Z'[;M
MZ)TP4_#$PZ=QP7FGI/D2C:J$PO&TMD1!.&)?1[)-6WM9NZZ3OOX@_D_6XUAL
M1GTNM]YX4O+?[Z_O9OVFGF/ZK:((..S&9&UJQK1<9IV0ARB.+6Q*A:JO/T1G
M0.7.^\]"4:3#\X1L$'GEQ1:LZB@>CX><G+&LX1=/[:8S#(^M7)P"F-%`C-MO
M>)T;_ZH:]%'"80&CT9C1T74?'N3ZVUYE-!CC+Y;5L.PB-Z(H4E%1D=+78?/Z
MHCS^Y&[6;NCCI#-*6;)B+DZ7Z:AZ9=/Z;I:N>(>K+J[@JF5UDQ;Q'OG!(BZX
M[+]0U53R_6AK/_/FC.!T.E.NW_*]#_'$5&2#F+RFQG4&._RL?O:B3P44?R#*
M37>]C^(TLW!1)6>ZC[T"W=L38.TSN_#Y?%BM5D11Y.>_:6+9W\S$8)`(A6*$
M@O%C:BL<4?GMFD-\]X<;N>O&V9Q]NCL=,!NV]C/MY!+\J@%"XVZ$X+T/>KEI
MB<+0T%!R$9]XNIFWF_U<?]M\>OUCCP='8_SHNVNY;K&=O)P@7J^7W-S<S&!9
M?XB_N7TUT9C.LHO+6':1&UF6J:FIP6*Q3`@9.D\^LX_?O'*0A<L:N&79+`1!
M0`7Z`T<E4RIFNKFIL9A53^]BWX^W</_M)V=\LK8JEPO/K^,/:_>G7._JC^#U
M>M,`T]X7XO['ST^YUK;/PUO__1'[]NVCNKHZ(T.F,Z;&M;>^Q[G+3Z!A5B+T
M?1J]T+R_C[)BC?;V=F;.3$2"@:!&?E6BK4];')@QKYS%5ZG\Z)YUN)Q&&NN=
MJ8#9N'V(@C-JZ?%/?#W!T^<EQU&$S68#X-E7VGEYFX]OKIB7`I9P,,83][_-
M=RZQ,J/6C,/AH+*R$E$4TQS:US;,W]V[%E6#!?/SN7QQ*;(L4U=7A\F4RAC]
M@R&NOV<CYMI"OG7O0D11.`:09`;.&9>>P&O/[.*I9YNYYK+ZC$\M7]+`ZG<.
MI%P;],0)!`(IF9G7%R5N-M'M3?W]>Q\-4%^31202R3CV3/;#Q[=3=FHUSJI\
M>GV?(8QM&>2Z<ZQ8+!8$0>!05P#%Y:!G0EN=;1Y&AH(IUXQF`Y737$CR1%\E
M+OGKN?SPI^_RRQ\O2`7,KO91\KYJ2W/6TQ^@HC#1D,UFX_E7#_+8*[TLO6$^
M?8&Q.!0)QWC^T7>YZ1(S#;4F'`X'5555&2=L>"3,]7>M)1R#$K>5ZY:7(8D"
MU=75:6#9T^KEFN]MX;3E)Y-?XF!@](\7;[,7-?#X(V^R\(Q<W,7I0G;>2<58
M[2;"X[1)7!>(Q^-HFI9DC`W;!LFO*:1[PISMV#'$XLLL6*W68\JL-FP;8.V^
M*$NOKTA;8!W0XMK8$LJ9`3C0ZZ<P+SO)S`G?"M((8.4O-W/Q*:EM]/OBO/@4
M++_C7`Q9J7MINME*?P`Z.CK&`!.+:72&Y10`'+:=&_LXO]&*+,N\O\7+`R_T
MLO#J^?2/CCT;#<=Y\U<?<.L2(PTUQB."1=-T[GUD/3U#(21%YMIOE&#*DB@M
M+<5J38W9>]M\7''/Q\R_Z@RP*I^153(SC:.^@E6K]_'MJW+2:BP&6:2N.I==
M^X:2UYRY1B8FE1]L'<!67I'&,&%O`(<U-RVL9K)@*,ZMCS0Q[^K3TA9WN,O+
MYA<V46*-(@BPH]?`Y7<N3!?K416[%$$42?:Y:><PYH9I*0",1>(X33&^NJ`@
MJ7,.6_%;PWRTH8_JV>Z4MB/!&(H$HZ.C8X#9OG<$,2\W(Q6V[QMB]EDF-C=%
M>.@/!YE[Q3SZQH%%BVML?V$3MRXQT%!CQ&ZW3PH6@!=6M[)N4S>2+#.[WDI#
MC16[W8[+Y4H5M_X85_WC=JHNF8]/5_#YCV^*J!3GT=1V@,'!08J*BM+NYV2;
MD>0Q)#ASTC.>+2VC%,^PIS!,9#1*D4-#$#@FP-SSV"YL<Z?CB1M@7#OA0(2V
M51MY^'H'=JO$D%?CYI52QC4:.N2EKCSAG]EL3JSI@3#N66:"XYX?:!]A>F46
M`#4U-2G:RK6KG>%V`?.$]MLV=G+^;'.JZ-VPPX.8[TK1(X>S"[L6H+W;Q/TO
M"=1>?$H*LVAQC4.O;^;.K^DT5ANQV6Q'!(O7'^%G*W<A?9*%+3['A2`(E)24
MI%'W[8_L0I_5B(^LXPX6@`@*$57`[_=G!(S);$CZ"5!5:D:6Y>380F&5UH`!
MP9_J]U#;".=6&1$$(2V\3K2W-O3S<IM$S7GY::&H]:5M_.0O;-BM$FZWF\X1
M%;E037L.H+/%PT4GFC"93,BR3"BLTAXR($V(&(?V>5@Z+_'<>+`$0W%^]8<>
M3.?,36D_Z@\1;-[/N7^7"'5)P'RTVT>HI#S-F:@G@%./<_?SD/N54^@/26,9
ME*KA>6\K]U^BTEB5A<UF.VI&\._/-1,(J4BR3'E1%I5N(SDY.6D3N[5IA-^U
M&\@_/8=P@,_%(H-19ILE8K%8QOLC_AB2G)@B08`9569,)E,2V+M:?01M.6GZ
M9:!]A!,696&Q6(XH>#V^*#<]WH[Y]#EIK.%KZ>3R61%*"JSDY>516%C(YN?W
M$,TNS<@PPST^IEVB)-EE5ZN/D#4[;3W[N_T\_6:85>N'L5H_'M.OG5&"-=.Q
MA&4(?S(_?1ZDG=MYZ%H[LB106%@X!IC-71K#V0((J9MPD;8AVONMV!><1%\`
M0$TJL>CF'3QP48S&*N68P#+BB_#*ND-(AD2W)T]/Z)5,U=-_>>80:E4-?2/J
MYU:UC!X:H?ZTK(R+&E<U.@9"25^KBA4<5BE%8ZW?.4+0FDWW\`0?/7[*"^6C
MAJ/;_W4OO26UR./G%="C,<K[VKCT&U841<'M3FB*S?M##!>;(,.<%(BC6$VF
M,?W2Y$T`QI/ZK'C23'9F<J9!``%\'A6UHQ>ZNEE<'^2:%58L)H&"@@(<#D<"
M,-T#80[L]Z#M?R>M'4G0D00![VOOI\M&36/0;SDFL`"\]D$744U(+D)=F1%%
M&7LKDO085GGU@P'\X?[/M<SM,`O,OMJ1L:!XL#M`,*HG?3UGCAV`[.SL,<&[
MPTO@@_T)^AEG)U>+&&3[$0'SRGO]_.>K/2"EC]$@ZMQRBPU)A/+R<B1)0E5U
MMNSVXMW\3L;VSCXU(=H/]_E1DX_`AZV?;6(T#5&`:)T)BUFBM,1-7EY>XN@(
MP*8]?G1!(E/R5U$LLO1TA8>>#Z=7D221'S\?8>XL&W5U1R],O;FI-TGQH@A%
M3@,.AR--N^P]&,0?(6TACK==>J81Q2!@M]O3[KV]I2_I:ZY=8E:-$;/9G`R=
MJJJS<6\@,9")+VN5DK)X$ZW?$^7ZA_:"G/DH:+5;IJE#8W^?P-8N/^!GQ!_'
M&]8GG9.&BL3Y'Z,QD<EMW#,*0KIO]:42Q@G:?="KTS6DD4P`)1$->.Z]&%45
M%KX_.R^Y1C*0&+@AL_,-E3)+3E/H#=CX[5I/.G4#U_QP/VL?-=-8[3ABO-[?
M$T+\I!]3EH!B$-+8!6`X$$>0/]]SM2Z[P!7G9"%)4@IK'`Y':S;U)WP58/'I
M%F1)(#\_/SEQ[3UA>D:TC'XV5B8V3#,=A]!UG9O^I87!@#[I&/?VPD,OQH`8
M,";@CC0GC94R9K,9413I'8[2WA]%D%-?8ED2^.D*,Q:C,,$G^(\U4?[CC?0]
MJ\>>[^6*<TQ,KRT=!YCFT4F=:2B7$$61?[UE.FW]37S8E*Y`O1&X[/LMO/5H
M(X7.S/M%>SO\")+$X3$8%`%1(..D*@;Q<P6,*,!=RQ5L)H&BHJ*T4/K.U@$&
MO#%D1::J4&)6E8+1:$S9WEC?Y,_HHR!`0YF8K+9.M)5O#O+R>N]Q'9_-!&5Y
MXIA^:0X@9)C7JF(!BS&1D8[?WM!UG7LK8SSY]L?I.@]X=VLOY6XG9K,9.1+3
M^/A@9%)ZG%&68`%3EL33WYO&63<WT3F8GE6T#^E<^<\M_/Z!Z9B-Z6T-C$23
M%'^8F:)Q,NJ>VA(3DB*C:I_#]CSPMU\3F5<G8K5:,PKNQBH'9\[.9VOS,)>?
M:400H*RL+`4`'^X9S3AGL@0_7P,F4Q!-:"422XWC[^_T33K7G]6FEPLI-9_-
M+9E]FUDI)*OU\H3[AP8FQT`X+N#Q>!*`V7TPS&A,1,A0;K:9H,RE)1TIRE58
M>7<MY]_5DC81`!M:XZSX63N_NKD:24IM;]@?3PK(Y+71Q%G;B5:8JW#FK&S6
M;3^^Q1=1A!O.AV^<*F`P&*BLK$R"H+O'QP,/KN'0(0]+ELSD>U?/8=VF%K*5
M`"Z7*[F'EASKOE!&EH@#K^TX_&Y&,T+V>+-G8[F>*G@G\:W.K1..R\1T!5]P
M;-Y;NR/<^&\=D_I5D*T3C2;&(F]L":;%NN2;7JQCD+04\79*G85'OU/&BI]W
M9OS-LQM"U#S7Q5V7IQ;B9%E,`TS;`,R-1#*V<]]5)9S7W'+<6,9FU+GC:SH+
MINL8#`9J:VM1%&5,5]R]ALW;NA/[0(]]1&%)+F?-*^;0H4.4E)2D%N;\<?;V
MQB?5?9_6C++.W1>K&"<Y`=KG$WAX]>1)14-I'$4Q(,LR<55GZX$H9%C3AU^'
MG[P.B'M2KL=BVA@]3K`R)]04Q).,)&]JC4PZ\!DE\8QJ_^IS<]C9$>$7KWLR
M[[J^Y*>Z:)#E"\:.4[JRLQ`-J0[MZH%`8)1,A]CFU5MX\"]+N..IGC\Z!IU:
MK7'S^1J%#AVSV4Q5515965ECM::H1E=4H7!&Q=B&9U>("TRFC.6"#7M#QY4E
M_G)!C+.GZUBMUHPI_JI-400Y<W%1$J"^.)[<Y-S=$68T+B(8TB/&9!4MP9`9
MC+*H<_.BQ![6X4Q2_J@M.KG@+8EA,!C2A*D@"#QX52%[NN.\NR>4G@D`*Y[T
M4%Z0Q:GUB8Y*\HQ($Q#<'X`MK7XJ*K2,Q;,;+W+ALDO<\F0/OM"G2[$%`6:6
MJ'QK?HPY%5JR0.AVN]/Z4@PBIRZHI[U_C.UFS2Q"EN6T6`^POB4\*2M_6JMT
M:BR;$\=@,%!=79VQOY8W>A%D;\;?E^1JV$WZF.!M/3Z^.2TZ_W!>F#D5&E:K
M=0PPMRUQXAWQ,N)-_\QT5HF*Q>+(J/856>`W-Q6S\NTNO-[,@]G6=)"9I558
M+!9JW6;L-H71<&J,>;U9Y[29P[@+71G;6'Y6#G.K=!Y]J8?5NV5Z?,(1LY_R
M7(WYE7$6UL>HRM,02+P=;K<[8PK?U!%$TW7N7%[)LQ]'&`KIS"F6^,H,X^0A
M1)%8=)(%O_^/V[,P*SI?/S&"08*2DI*,8`$P&T4NF&5"B*>?ZZ@O4!'&1P$!
M%LVVX@]\>OVG2#H.DTY#D<H953',RA@C'\:`H.NZ/C`P@-^?N8.<G)R,QR23
M-*>J'#AP("E>!4%(`9BB*)26EB((`C][K9=WF](W0AK=(G<NK<1@F/S-"(?#
M='1UTW301TN_B"<HXH\(&&4=LZ)39->H<JKD6'0$$ME7;FXN+I<K9?\G6<S4
M=5[=.L+*]X<P&P3NORR?0J?UF+\*\'@\M+>W'Q>6L=OM5%=7'_F`^\``'1T=
MXP2\F/+WQL;&Y+5@,$AS<_-GC^)"(C/.R<G!Y7*E]/4G_6J@8RC*=U=VDNE+
MU=-JS7Q[83Z*?.33:;%8#)_/Q^CH*)%(!%55T74=29)0%`73)_LID]5!`+H]
M,7[]UB!-72%L60(7SXA2;`Y@^D2SC-<W4S8!3'_JSTR>?M_#ZIV9V6Q:819_
M?4XNA=F?SP=CGE&5WW_LX^W=?J(JU+HT%E;XR1*C6"P6JJJJDIG3E'U!`!.-
MZSSX^T':!C*K?D466'2"E0L:+5B-XA_=GZ;K[.^/\=Z^(!^V!(FI8#9HG%,^
M2I4]@``4%!107%Q\S&=OIP#S)S9_6.,G;XS0X9G\DX<3W0HW?L61\DW,L5HX
MIG%P6&7KP0A;#H;Q!!-"6Q9T9CK]S,KS8Y0TC$8CY>7E:<="I^P+!AB`4%3C
MW]_SL+,W'1`Y9H'[ON;@E9=W\L\_6H,@"-QVZU?XYN6SV=X5)18'<Y:`)$`D
MKC,:T?&&=?I\*@>'XO3X5,:=F481-:8Y_)R8Z\-JB"-)$H6%A>3GYT^QRI<%
M,`#Q>)PU.P99>T!A-#Z64GYUNL+\0I4%ESY--);(OB1)8,TS5[+';^2E79%C
M:M]AB#+-YF.:W8=14A%%D?S\?/+S\Z<^K/^,]G_Z?W/)LLRBV07,+!Y@78N/
MO3X;0U$3.1:9@WU^<JM+4YX_T!<B.\^2ML4PWFQR%+<Q0(W%1UY6"('$CGA^
M?B$NEVO26L>4?0D`<SCG=Q?FL\P9H[>WE[:^/ARZD^IJ)S4G5C$:T3XIE@F<
M.,W).QT@RQ*2H"$+.@XY3*XA3*XA1)XAA,,0^821)!R.7)Q.)S:;;>J_'_MS
M"$F93%55`H$`=KN=3H_*VZU1!.#L&H5\B\KVW?N(J1JRD/ASV"1)2M9@'`['
M40]@3]F?"6".9",C(X1"H21`)$G"8#"0E96%P6"8`LB?P/X7,#6O=?K,HF$`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+VMO;&%B+V=R87!H:6-S+V)G+G!N9P``
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,C`W(#$P-3$U-#,S
M-S0V(#`R,S`Q-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12`````0````,(`@```-V_\M4````&
M8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP````'=$E-10?4
M"1$+'BA-;][6````%$E$051XVF.X<N$$$P,#`].]^P\`':`%#LYQM6H`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]K;VQA8B]G<F%P:&EC<R]K;VQA8FQO9V\N<&YG````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P-3<W,B`Q,#4Q-30S,S<T-B`P,C0T,3(`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```#<````H"`8```!:6V((````!F)+1T0```````#Y
M0[M_````"7!(67,```L3```+$P$`FIP8````!W1)344'U`L$#QX=`=)&Y```
M"X=)1$%4>-J]F7N0U-65QS^_9[^[IQ_3]$SWO'H>#&"`B20@2I"LJ$%C1!1!
M"R$F&U=7L]G=,FY88\A&U]HJUVRJ3&VM68MD8\BB%1$U0H2HY*&;$-X#\AR8
M&6:&>0_=/=/=O^[?[[=_##2TW0,.S'BJ^I][;]][OK]SSO><<Z]@FJ;)IR"Z
M;G#R9#\[=[9RX$`G>_:TT]T=I[<W04]/'"VCXW99456)0,#)U*E!&AM#S)E3
MR8TWUA,(.,=]IC#1X#HZAD@F-6IK2S$,D]<W[^?7;Q_BW7>/</KTT!7M*<LB
M"[]0S^K5G^?N9;-15?G3!6>:)M]9MX477_H`PS!9MG0V__6CN[ACZ7^S_=VC
M$_;QHC5^GO[^$I;=-0M!$#X=<(=/#+#TH4UY8^N?6\)'^]MY[%NO$0D[J:GR
M4!JTX7*JN%PJH@BQF$8LIM'9-<S)4V?I[AY!-RZOTNU+IO/B?R['6V*;7'")
M1)K3_6D>>>XO>>//_LTLREQ93K2TX':IHP<*`K(LHR@*DB3EK*[K.IJFT=LW
MS)Z]O;SWNPYV[NHFK>ECGMM0%V#3*VNHK/!./+@SW7'6KMM*(I'FES^[GV=>
M[^)PMP9`N5OBF>5A!OJZT30-I].)S6;#8K$@BF)1ES)-DVPVR\C("/%XG):3
MW?S/AF;>W'**5+HXR&D-I;SUVH,$_(Z)`6>:)AM>W<=33V]C<"A)586331ON
M(QR9POYNG506FD(2=E7`-,W+QL:ESAD9&6'/WA:>?'H'^P\.%%WW5S=6L>&E
M^U`4Y>K`Q>(IGOC>._QJ<S-VF\+JE0TLN:D<61:IK*RDM+1T4E))+)9@[;^\
MPRN;#A>=_^$S"[GOWOEY'W)<X(Z?'&#-(Z]QO&6`:Z;Y>?QO9Q#P*:BJ2B02
MH:2DY))6ZNU+<JHMQME8FL&A-&Z7BM]GI:'6B]NM7O9\PS!X8MT[_'SC_H*Y
MJ75N7EU_%\%@</S@_KR[@Z]_ZPT&!I+<?G,E#ZZH09*@M+24<#B<(X>+)9/1
MV?;^:=[XS2DZ^I*XO%:J:CQX_59*O%;B,8W^OB0GCP^BQ346?"[$U^Z?ALLU
M-M!LUF#I`__+GOUG/A9@\.)S\[GEIL_E=,F!,PP#412+;KCC@U8>?OQMAD<R
MK+RSFGMN#R.*(M75U7B]A4QU-J;QX_4'V?Y_W7SVA@IN6A+%'[!=-KYV?MC)
MYE\<9-67JUEU3\.8:X^U#'#+\E^@Z_EV6;.\FF]^XWK\?O\%<.>-5\RE=GS8
MQC<>WX*FZ2R[M9R57ZE`EF7JZNIP.!P?<QN3]1N/\K,W6UE\SPR:YI:/FTP,
MPV33R\V$!8T??/O:,=<]NO8W_'K[B7QBN;Z4M8]=2S0:':UL<E8MHL31E@'^
M[JGMZ`8LG!?DWCM&@34T-&"SY5NBIR_)PT_^&7M]B`>>6HPH"O0DKH0Z!&Y8
M^AFV;&SFIZ\<9LWRQJ*K5MPY@ZWOG\H;ZQO,DD@D<@PMCT75`T,I'EZ[G50&
M(F$G7U]1B20*U-;6%@#[Z/A9UGQW%_-77$LPXJ%W^.K9L>G6&?SX^=^R^`8?
MX?)@P?S<SY;C=-M(I;(7XM$4R&:S&(:!)$G(Q8`9ALE3SW](5W\2295Y\.X(
M-HM$144%3F=^=7ZD)<;*)_<R;]4-X%2OT%K%+>AIK&;3UJ,\M,I;D,,46:2A
MUD?ST?[<F-]GY6)^+%I>_VKK<7;L[$2299H:G<RH<^)VNPD$`OG$$<^PZGO[
MB'YE'C%3)1:?V-RFEI=RJ.44?7U]E)65%<Q[2^Q(\MD+X+SY+%L`[FP\S0L;
MFI'443J]8U$`01"(1"(%[OOMYYLQ9U]##,N$`P-(HY+6!>+Q>%%P-KN2TQ,@
M6F%'EN4<ZQ>`^\FKATDD=219IJK,0DW8BM?K+8BSW8>&>/VD0O!Z+ZD$DR+I
M/HTFNT0FDRDZ/Q3/(,GR.4*$Z5$[-ILM9X0\<$.Q-&_N:$-21H>OG38:7Q=G
M_?/R'QO;T*-U=`_ID]:]:VU#-,ZW%,V_6=V@O3>9TS5:KN)Q2GF<D`=NRQ\[
MT`PA]X>&2BNJJF*WV_,V'DGIO/W'7N*IGDF]FO#8!9I6>[!:K05SK9T)1C0S
MI^NB.6X`2DI*BH/[[<XS.3.+(I3Y%3P>3T&L'6D=(9X^YPN3*$L76%$5`;?;
M73#WWJ[NG*X^M\3L.BMVNST7/J9I7@`W&-,XT95$//<E;!8!51$*K`8PD,@B
MR/*D`@NX!58NLB!)4IXUSKODMIT]H[H*<,?U#F1)(!@,YADBI^&1]CB")"&?
M(Q]%%1`%"O(+@*J(DPI.%&#M"A673:"LK*R@*']_=R^]9S/(JDPT)#$[JF*U
M6O'Y?,530>^0EC,S0!;0LA2M]NLC-B151C<F'I@`?/,VD;D-(DZGLRB971/U
ML*`IR.[#`]R[P(H@0&5E97XO)P@7P`W$L[G@S(T-C]YM?%Q"/I4%LTO8L6]B
MDYLHPB,WP]W7"2B*0DU-34[ASJX8SSR[C;:V0>Z\<R;?73V''3N/4:(F"`0"
MN%RNPBO!7#FCB`7@6GKA\^ET4476K8IPT^%C$V8]E]7DB=M,%DXS412%^OIZ
M5%7-D<-C_[R-O^SI!&#_C_Y$*.+C"W/+:6MK(Q*)%+1/>98+^:V(2KX+-G=!
M(C%,$<]@;J.#9[\:X8F?=EVU'UY7:_#W-QN$/"9VNYUH-(K%8KF0S#6##DTE
M-+WZ0K'>D>06FXW:VMJBH9-GN8I2*Y*<OZ@G`;N.QZFN+M[(/GI[@(!;XA_6
M=Q%+CB\M"`+,C.@\,"_#G&HC5RR$P^&"LU1%Y+J%C9SLN>!%LV>6(<LR<A%B
M.^_*N4X\DS7XV@M'&4[E^YG7;O+]Y5,(AP)C*MIR>H`?;NYBZT&9KIAP21:L
M\AG,J\FRN#%#M-1``-QN-^%PN&C:.=0^@F&:!+T67MF;IC]I,J=<XDO3K8CB
M)[AQ/N^C+VPYP^\.Q0K9*2SRG64U*(HTYD:I5(KVCDX.M<8XUB,R."(23PM8
M91.[:E+F-HCZ=;P.$X%1%O;Y?`0"@;QZ,-=VF29O[QYBPQ_ZL2L"/U@>).1W
MCJNSS[L@:N_7^*<-IREVFSV_WLY#BX.HLGC)#3.9#+%8C.'A8=+I-+JN8YHF
MDB2AJBHVFPV'PX'#X1A3T<[!#"^]V\>ACB0NB\"7IVN4VQ/8SL78Q?$XKK>"
ME_\PR-8#Q2E^:LC"7R_R$2I1)B5Y#P[KO+4WQGL'XV@ZU`<,%E?'L8@:#H>#
M:#2:8]`K`J=E39Y]JX^6WN)MABH+W/H9)[=<X\!I%:\:D&&:G.C)\/NC(WQP
M;(2,#G;%8%'5,%%W`@&8,F4*Y>7E8][.C>LA))XR^/=WAF@?S([YQUEAE4>_
MZ+EL4!>-SXQ!ZX#.[M8TNUI3#(Z,DI@LF,STQYE=&L<J&5BM5JJJJ@JN-JX*
M'$!2,_C)[P<Y<*90>:]=8-UM'MY\XP#_^F_;$`2!Q__QB]Q_;Q/[.C0R6;!;
M!"0!TEF3X;3)V91)=TRGM3]+5TPG>Q$IJZ+!5$^<6;X83B6+)$F$0B&"P>"X
MK?6)WPJRV2S;]O>Q_93*</9"/OG2-)5Y(9V%2U]&RXR69Y(DL&WC?7P4M[*Y
M.?W)^C5%8ZHKQE1W#*ND(XHBP6"08#!8M&`?KURRM)=EF5N;IC"SO)<=QV(<
MB;GHUVQX'3*MW7%\M15YZT]U)RDI=124<7EEEJP1MB:H<\0HM201&.T\@L$0
M@4"@:%*>%'#GLWTX%.0>?X8S9\[0TMV-Q_136^NG;E:4X?2H?UE5@5E3_;S?
M#K(L(0D&LF#BD5/XE!0^)4FIDL2CI,]96L+C\>'W^W&Y7%?\S'7%;EE,=%TG
MD4C@=KLY/:CSWG$-`;BQ3B7HT-EW\"@9W4`61G_G19*D7([S>#PX'(ZKBJ=)
M`7<I&1H:(IE,YL!(DH2B*%@L%A1%F70P'Y?_![H7<,0^Z$-U`````$E%3D2N
M0F""````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VMO;&%B
M+VEN9F\N<&AP````````````````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,S,U(#$P-3$U-#,S-S0V(#`R,34V-0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@2V]L86(@
M=&AE;64@8GD@4W1U87)T($)I;F=E(#QS+F)I;F=E0&-O9&5F=7-I;VXN8V\N
M>F$^"B`J($1E<FEV960@9G)O;2!T:&4@)TQI9VAT($)L=64G('1H96UE+@H@
M*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]K;VQA8B]I;F9O+G!H<"QV(#$N
M,2`R,#`T+S$P+S$W(#$Y.C,S.C,V(&UD:G5K:6,@17AP("0*("HO"@HD=&AE
M;65?;F%M92`](%\H(DMO;&%B(BD["@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]K;VQA8B]S8W)E96XN8W-S
M````````````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S`P-2`Q
M,#4Q-30S,S<T-B`P,C(Q,#<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+RHJ"B`J($MO;&%B('1H96UE(&)Y(%-T=6%R="!"
M:6YG92`\<VMB:6YG94!G;6%I;"YC;VT^"B`J($1E<FEV960@9G)O;2!T:&4@
M)TQI9VAT($)L=64G('1H96UE+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE
M<R]K;VQA8B]S8W)E96XN8W-S+'8@,2XQ,"XV+C(@,C`P-B\P,R\Q,"`P,#HQ
M,CHU-"!J86X@17AP("0*("HO"@IB;V1Y('L*("`@(&)A8VMG<F]U;F0Z("-E
M-64U934["GT*82!["B`@("!C;VQO<CH@(S,S.3L*?0HN;&EG:'0@>PH@("`@
M8V]L;W(Z(",P,#`["GT*(W1H96UE;&]G;R!["B`@("!B86-K9W)O=6YD+6EM
M86=E.B!U<FPH)V=R87!H:6-S+VMO;&%B;&]G;RYP;F<G*3L*("`@(&)A8VMG
M<F]U;F0M<&]S:71I;VXZ(&-E;G1E<CL*("`@(&)A8VMG<F]U;F0M<F5P96%T
M.B!N;RUR97!E870["B`@("!H96EG:'0Z(#4P<'@["B`@("!W:61T:#H@,3`P
M<'@["GT*+FAE861E<B!["B`@("!B86-K9W)O=6YD.B`C9&1F.PH@("`@8F]R
M9&5R+6)O='1O;3H@+C%E;2!S;VQI9"`C,#!C.PI]"BYS;6%L;&AE861E<B![
M"B`@("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0Z("-D9&8["GT*+G-M
M86QL:&5A9&5R(&$L("YS;6%L;&AE861E<B!A.FAO=F5R+"!A+G-M86QL:&5A
M9&5R.FAO=F5R('L*("`@(&-O;&]R.B`C,#`P.PI]"BYB=71T;VX@>PH@("`@
M8F%C:V=R;W5N9#H@(S`P8SL*("`@(&-O;&]R.B`C9F9F.PH@("`@9F]N="UW
M96EG:'0Z(&)O;&0["B`@("`M;6]Z+6)O<F1E<BUR861I=7,Z(#5P>#L*?0H*
M+RH@365N=2!S='EL97,N("HO"B-M96YU('L*("`@(&)A8VMG<F]U;F0Z("-F
M9F8["B`@("!B;W)D97(M=&]P.B`U<'@@<V]L:60@(S`P8SL*("`@(&)O<F1E
M<BUB;W1T;VTZ(#-P>"!S;VQI9"`C.&)F.PH@("`@8V]L;W(Z(",P,#`["GT*
M(VUE;G4@82!["B`@("!C;VQO<CH@(S`P,#L*?0HC;65N=2!A.FAO=F5R('L*
M("`@(&)O<F1E<CH@;F]N93L*("`@('!A9&1I;F<Z(#-P>#L*("`@(&)A8VMG
M<F]U;F0Z("-C8V8["B`@("!C;VQO<CH@(S`P8SL*?0HC;65N=2!A+F-U<G)E
M;G0@>PH@("`@8F%C:V=R;W5N9#H@(V1D9CL*("`@(&)O<F1E<CH@;F]N93L*
M("`@('!A9&1I;F<Z(#-P>#L*?0H*+RH@4VED96)A<B!S='EL97,N("HO"B-S
M:61E8F%R4&%N96P@>PH@("`@8F%C:V=R;W5N9#H@=VAI=&4["B`@("!B;W)D
M97(M8F]T=&]M.B`N,F5M('-O;&ED(",X8F8["B`@("!B;W)D97(M<FEG:'0Z
M("XR96T@<V]L:60@(SAB9CL*?0HC<VED96)A<E!A;F5L(&$@>PH@("`@<&%D
M9&EN9RUL969T.B`Q<'@["B`@("!P861D:6YG+6)O='1O;3H@,G!X.PI]"B-S
M:61E8F%R4&%N96P@83IH;W9E<B!["B`@("!C;VQO<CH@(S`P,#L*("`@(&)A
M8VMG<F]U;F0Z("-C8V8["GT*(V5X<&%N9$)U='1O;B!["B`@("!M87)G:6XM
M<FEG:'0Z("XR96T["GT*"B\J(%1A8B!S='EL97,N("HO"BYT86)S970@;&DN
M86-T:79E5&%B(&$L("YT86)S970@;&DN86-T:79E5&%B(&$Z:&]V97(@>PH@
M("`@8V]L;W(Z(",P,#`["B`@("!B86-K9W)O=6YD.B`C9&1F.PH@("`@8F]R
M9&5R+6)O='1O;2UC;VQO<CH@(V1D9CL*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O;&%V86YD97(`````````````````
M````````````````````````````````````````````````````````````
M````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T
M,S,W-#8@,#(P-30U`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]L879A
M;F1E<B]I;F9O+G!H<```````````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#$W-B`Q,#4Q-30S,S<T-B`P,C(R-S0`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D
M93H@:&]R9&4O=&AE;65S+VQA=F%N9&5R+VEN9F\N<&AP+'8@,2XQ(#(P,#0O
M,3`O,3<@,3DZ,S,Z,S8@;61J=6MI8R!%>'`@)`H@*B\*"B1T:&5M95]N86UE
M(#T@7R@B3&%V96YD97(B*3L*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O;&%V86YD97(O<V-R965N
M+F-S<P``````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(Q-S`@
M,3`U,34T,S,W-#8@,#(R-C$U`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]L
M879A;F1E<B]S8W)E96XN8W-S+'8@,2XY+C0N,R`R,#`U+S$P+S$X(#$Q.C,T
M.C$Y(&IA;B!%>'`@)`H@*B\*"F)O9'D@>PH@("`@8F%C:V=R;W5N9#H@(V5E
M93L*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C9C1E-68W.PI]"FAT;6P@
M>PH@("`@<V-R;VQL8F%R+6)A<V4M8V]L;W(Z("-F-&4U9C<["GT*82!["B`@
M("!C;VQO<CH@(S<Q,&8Y-CL*?0IA+G=I9&=E="!["B`@("!C;VQO<CH@(S<T
M,F$X,CL*?0IA+G=I9&=E=#IH;W9E<B!["B`@("!C;VQO<CH@(V9F9CL*("`@
M(&)A8VMG<F]U;F0Z(",W-#)A.#(["GT*+FAE861E<B!["B`@("!B86-K9W)O
M=6YD.B`C93%C,F4W.PH@("`@9F]N="US:7IE.B`Q,G!X.PI]"F$N:&5A9&5R
M('L*("`@(&)A8VMG<F]U;F0M:6UA9V4Z(&YO;F4["B`@("!B86-K9W)O=6YD
M+6-O;&]R.B!T<F%N<W!A<F5N=#L*?0HN;&EG:'0@>PH@("`@8V]L;W(Z(",V
M931E-S(["GT*+G-M86QL:&5A9&5R('L*("`@(&-O;&]R.B`C965E.PH@("`@
M8F%C:V=R;W5N9#H@(V4Q8S)E-SL*?0HN8V]N=')O;"!["B`@("!B86-K9W)O
M=6YD+6-O;&]R.B`C96-C868R.PI]"BYI=&5M('L*("`@(&)A8VMG<F]U;F0M
M8V]L;W(Z("-F-F4W9C@["GT*+F)U='1O;B!["B`@("!C;VQO<CH@(V9F9CL*
M("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",Y83<X83`["B`@("!B;W)D97(Z(#%P
M>"!S;VQI9"`C,#`P.PH@("`@<&%D9&EN9SH@,"`R<'@["GT*+F)U='1O;CIH
M;W9E<B!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C-F0P86$P.PI]"BYS96QE
M8W1E9"!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C8S9A,6-D.PI]"G-E;&5C
M="!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C93!C,V4U.PH@("`@8V]L;W(Z
M(",P,#`["GT*"B\J($UE;G4@<W1Y;&5S+B`J+PHC;65N=2!["B`@("!C;VQO
M<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-F-&4U9C<["GT*(VUE
M;G4@82!["B`@("!C;VQO<CH@(S`P,#L*?0HC;65N=2!A+F-U<G)E;G0@>PH@
M("`@8F%C:V=R;W5N9#H@(V4Q8S)E-SL*?0HC;65N=2!H,2!["B`@("!C;VQO
M<CH@(S`P,#L*?0H*+RH@4VED96)A<B!S='EL97,N("HO"B-S:61E8F%R4&%N
M96P@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V5E93L*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<P``````````````````````````````````````
M```````````````````````````````````````````P,#`W-34@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<U,R`P,C`U-#<`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S````````
M````````````````````````````````````````````````````````````
M`````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U
M-#,S-S0W(#`R,38T-@`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O>G<N<&YG````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#(P-#0@,3`U,34T,S,W-#8@,#(S,#<R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```2````#`@#````6,P=C@```P!03%1%````____OAP@K!D>3"HKXL#"Q7!W
MRX*,NZZPN8B1I)27[,#.^_CY-S4VVM?:C(R-M[J\R<[/B8N+O\;#9&QE&T(5
M,5X9+G$%6YDU6I(X=ZM7B+EJ*FT`+F\%.7L0/GL828DA;*=&6(8[=*U0<I)!
M=IL#?:,-BJ\=:8,;FKXO<XXC?9DJAJ,PCJPUJ<M"H<!&L=)/KLY0Q,>[<Y<`
MX.A7JJ]CP\P`Q<X#Q<T)S=8-V.$=S=0?YNXO\OI"H:4LW^=!]_]/\OE0JZ]`
M]/I>O\-V[O!EV-<0Y.,AL*XAO+LH\O`UQ\8NTM$T_/M&Y>1"_OU0]O1.J*B0
M[^_NT,H%RL``Q+Y?[>BOQ+MIW--[V<B7M)]SY*Q.S7<!RW8!TWX*S7P-W8H8
MZIHK]ZD^_K--[:A)^[-1\KALUX@GTL_,SX`Y]*=MNIN%OBX*VST4YTTFN40F
MQ$PM]&`ZSU,SWU\^_6]*\6Y,_'11SR@'PP$`O0,#QP<'K`H*T104OQ@8(04%
MWB8FS2LKZSHZJBPLM#(QVSX^US\^P3HZ]4I*,A`0ZDQ,]%%1XTU-U$E)X%%1
M0B$AS'1S5#4U3S0T949&7D)";E!0:DY.,2\O'AT=1$)",3`P]?+R45!04$]/
M1T9&X>'A?W]_-S<W#0T-____````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````R^LZCP````%B2T=$`(@%'4@`
M```)<$A9<P```$@```!(`$;):SX```"]241!5!@99<^_#@%!$`;PG=FUY\_%
MD8A*[4$4*@JM0B-Z(0BO0*'P`IY`0TM-KQ(/H+CF)'+NUHXY.N;K?IE\DU'B
M;Y0H`;A/(FTI=C#,X%6)>;]:L,:\+"!'`M.PMFVEW-`2(@`@'90(=6]MX@F+
M1"W)""6,=^I4I_-95B/O6<NTVN?/Q_02'H2*L+]@&C2QLHDN*)6#%(UO3/6=
M;'=S`4B)9#E,C;)_HWLB7/2E4=$+^'CJ(T1)O>__O/0&1R-+SC&?'((`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]A;"YP;F<`````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`T-2`Q,#4Q-30S,S<T
M-B`P,C,P,C<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,
M5$4```#____5-3;'.CO_9V@'`0#,``#(``"?``!_``!V``!<```8``"Q`0&L
M`0'.`P/,`P-4`0%-`0&*`P/0!07.!07,!06[!05A`P/-"0F+!P>K"@K6#0W-
M#0V0"0FZ#0W8$!"+"@I$!06[$!#/$A*/#0U="0EF"@K2&!C/&!B4$1'A'1V0
M%!3D(2'4(!_7(2'1(""=&1FT'1VG&QN2&!C8)R>P(2'N+R^R(R.G(2&Y)B;=
M,"^\*"AQ&!CR-36_*BK$+2W!+"R[*RO'+BX>!P?*,#"R*BK-,C'A.#C5-C72
M-#3/,S/W/C[=.#AY'Q]&$A+Z0D+:.CJ[,C)8&!CG04#@/S[\1D;J0D+E0D+^
M2DKD0D*#)B;J1D;%.SO_34WN24GL2$C_3T_^3T^J-368+R_^4%#R3$S]45'\
M4%#V3D[N3$SI2DK[45'Y4%"M.#CQ4%#41D:P.CK21D;N45'K4%"\04'=34WV
M5U>"+R_L5U>H/C[Z7E[I65FI0D+]9&3'3T^&-35B)R?Z9&3X967_:FKX:FKM
M966H2$BW45%4)B8;#0UW.CJT7EY0*RLZ(2$N'1T8%!00$!`%!04#`P/___\`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````"$"W#R`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@``
M`+Y)1$%4"-=C8,`".#D-8ULK\S3%.404=.W"4D%"6D%M/:5^:MS"\D;F`8FY
M0"%%MYJF]D95(4%U6R>?N)QXH)!E`4M)A?]D5I<)T861Z6FA0"'FEG)?$R6>
M21/[&HI2,R.\@$+-U2$&<EP27?TIM?6Y,4RN0*&Z!%-9/E[IX-ZJLN+X0'='
MH%"^M8H`NY1.9W=V1U:HMX,54,A#0XQ-5%D_N2`C,\K+V<8,**0GR<8OHVT>
MGI0;X^EJ;V&,S3L`W_,NA,7$?:P`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+V)A+G!N9P``````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`R,#4P(#$P-3$U-#,S-S0V(#`R,S`Q,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````$@````P(`P```%C,'8X```,`4$Q410```/___P`72$]NL5!KJ#58GP$K
M=@DO=QLY;2)%AC9:FSI>GSM=F%%VMD)@E&F)PG&'KG.)KP`N=P`N=@`<2@$O
M=P,P>0,P>`4R>P4R>0<T?`DU>PTZ@0TX?0PQ;0HG51`]A!`\@1(\@!5`B!A"
MA!U)CA0P7B%-DA](B1](B!]%@R=/CB%`=2-#=B]:GB$_;R9'?1LR5BA)?C!6
ME"M-A#!2BRY/A2I'>#17D3)4BSA<FCA>FC99DD)KKC]BG4=OL$%FH4-FH3M9
MC$EMJDAMIT%BEE!WMU!VM4%@DE!VLTUQK%)WM$9FF5!TK4)=B%Z`N&2&O6B)
MOV:&NFJ+P%QUGGF6Q'^;R7N5P8&<R(ZJVI>OU9*IS8>:N*&UUKW+X5=[LUI[
MK7B!C[C%V*BUQR1$;5%H?FI^B(N5BY.3<+.RDJ*:88^&3]*V-)2"*\&M4;&@
M4LRE`=&J!Z&&%^2](=2R'[J;'N[(+]V\-_K50N#!/O[:2N[-2?[<4/G74/;7
M5Z",/**01*>62LNW7M*^9\"N7LNY9]&^:\R>`,R?`,V@`<RA!<VB"=:I#=BK
M$-NO%-ZR&-*I&.&U'>O`*_+(-?7+.N&]./C2/OS41O_83_+03/O84??54,Z@
M`]"B!=2F"NB\)O___P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````)KPGD`````!8DM'1`"(!1U(
M````"7!(67,```!(````2`!&R6L^````P4E$050(UV-@P`*8#!/Y,NNF3NAJ
MG]M;G&?O!A024?.+"\LJZ>Z8TS.QK,G=$R@D;YX0&^Z:6]`YKW_2M&9O9Z"0
MOD\@2XR`7%%AW_PI56U>=D`AI^!X*TX/P932XLG3:UH=+8!"0?X.&NQ:(=RI
MY14S:EML3(%"`2[:LJ)LBLF\:;-G5>=;F@"%?(V5Q(6DE+FB(]-G5C::&0"%
MK%4DA244U%DCHO@S<AJ,=(!"FM)"8C*J>K;,H4D\V?6Z'-B\`P"AZ#(U=0H\
MN@````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O86TN<&YG````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P,3(@,3`U,34T,S,W
M-#8@,#(S,#(R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!0
M3%1%````____P0$-P`$-R`H6PPT8A`H2TA@DSB<RWRLVJBHR[3Y)]4U7Y$E3
MXDA2\5%;X%EA]&1M#0'`#P/`$P?%'1+$(!3/,2;<*2&?.B_213KJ2#_654KT
M5DSH6U'S3D;,6E#H<&?V#0G!#0F_%A+'&!3")"#1,B[--C/?-#*X.SC#247L
M0T#05U3T4U#D4D_B6UCQ;6KS``#,`P/.!070!07,"0G-#0W6$!#8&!C2'1WA
M(2'D'R#5+R_N-37R,##*.#CA-C75-#320D+Z1D;\04'F0D+E.SK'1D;J3T__
M4%#^3D[V4%#Y5U?V7E[Z9F7W:FK_S'@#S'8'T'P(SG@)S'L)S7H/V(83UH$3
MP'02TH8;X8XCY)0DSX0CU(@EL'4CLG8G[IXUO'\J\J0XW),TQX@PX9P[TI$W
MRHDUL'DQTI$\_+%)Y:)$NX(XQHL__K93]K%0UIE*\Z]7\[)>Z*M<P',0Q7@6
MQ'P@IVL?OW\NU9$Z^JQ(ZJ)(ZJ1+_[15^;%5Z*E8S```?P``S@,#T`4%S`4%
MS0D)U@T-V!`0TA@8E!$1X1T=Y"$AU!\?G1D9[B\O\C4UX3@X^D)"NS(R_$9&
MYT%!QCL[_T]/_E!0^5!0]E=7^EY>]V5E_VIJ____````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````NV9DJ@````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX`
M``"C241!5!C3;8P[#L)`#$3]VTV02(,H0.(.'(++<`XN24<1":4`@?@($F)[
MV:WA5?;3S`#\@+"#:5W9NU=E*6P)H`[11S4E9B;&G(H2T3[FB9@(V1\"LXK2
M4&63?Z)4U'IBCT&-A#E&'/5(4'NO9B41`MEH(-!Z[Z66I]CSE=7FU;0K[*K%
M"YN;)=T+W)\G/4A(5\'SZ%:*>8F%PX+1[3+OEO"'+TU+3MB/$M.*`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]B8BYP;F<`````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,C`U,"`Q,#4Q-30S,S<T-B`P,C,P,3(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!(````,"`,```!8S!V.```#`%!,5$4```#___\H)5@N*V`.#$</#4<6
M%$Q"0&Q"0&M$0FQ85H5?78M;68%T<IX2$4L:&5(A(%4V-7([.G!/3GIH9Z!F
M99U03WE:685@7XMI:),``$X``$T``#$``#`#`U$#`U`%!5`)"5,-#5<*"CL2
M$EH8&%X1$4(A(6T?(&4?(&09&4L;&U`G)VHA(5<O+WDA(50F)ETH*&`U-7TP
M,'`J*F(M+68N+F@P,&LP,&HJ*ETT-'$X.'DT-'`S,VXR,FP^/H4X.'A"0H@Z
M.G8R,F9&1HL_/WQ!07\_/WM*2H]"0G]-39!&1H-)28A(2(9)28=04)-/3Y%,
M3(M04)%.3HU149)04)!149%04(Y&1GQ04(U75Y)>7IA968]D9)YE99UJ:J(B
M(UDK+&0Z.W'^\TI[<0!_=06]K@K;SA2:D29<5QA83P!_<P%R:`>.@@J#=PW?
MS3C=SC[,L@#)L`"!<P'`JP/#K`3)KP6^IP5];P->5`/'L`G#K0FNFPF]I@O&
MKQ2JF!'/N!CCS"%M8A#/N1^$=Q3/N"&*>Q9'0`WMU2_;R#6PH2KAS#CXX4+S
MW49B61QQ:"'^YT_AST;^Z%#WX5#SX%#<RDG+ND2+@"_GU5'NVU3JUUJ5BCI!
M/1U?62MX;2O___\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!,_^^%`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```,%)1$%4"-=C8,`"9&2UDGAG=3>4
M%58+J!NY^`.%9-6<XR2G-5<5E=0SZSD&A`*%E"UC8GGFY15GY_:QVWN%^0&%
M]"-$PCG:*E-R6KJ$/4("W8%"0O%1UDPU6:E-_?E<_L&>-D`AT6@W#;;2BO8Y
MTWNY@[P%+8!"L;XZ2JSE:9ES"Z9(^#C9)0*%(HU5Y%EJTS-F)\\4=[4U-0`*
M.:@J2/'5-79.G#1#S,K,4!<HI*DH+<??VM$S8?)43G.3!&ULW@$`25DQVL)U
M-DD`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V%N+G!N9P``
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#0V(#$P-3$U-#,S
M-S0V(#`R,S`S,@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`
M4$Q410```/___\7#QL+!P^'DZ:^TN8O+Z+##S'R%B0!^L@6"LPQ]K!V-O"&8
MS"V8Q2N2O"R1NBZ-MC.=QRV)L3BARS:9P$&GTT:LU$&<P5"]Z%"[YU"XXE*[
MY5Z_Y6#!YVC%ZENCPJK`R:J_R-;G[@*!LA&/P!*(MA:*MR"<RQ^0O"JASR:/
MMRR8PC&7OB=WEC&3N3"1MB^+KSVQW3>?QS27O3:5N4&IT3Z@QD*HSSN2M$:F
MRTZWWU*_Z$VQV$ZRV5*VW%.WW5C`YU>[X%>YWTRBPU>XW6;!Y&K'ZV[)['++
M['')Z[_2V:"PMJN[P;7&S-;H[\76W-/CZ=CFZ^GW_.'P]=KGZ^?T^-?CY^KV
M^J&LK\;'Q[*SL]35U-75U-C&P.?7TO;EX=U$),U!).-5./EO4^]P5^#-R<,<
M`,`C!<8G",4D"<`G"<<T&+0Z)N]>0O9?1M=80/1I3];!O>G9UO7EXJHI%:@H
M%>M.-;$[**]&.;]00\YB5M9V:\^YM_[^_OS\_/KZ^OGY^??W]_+R\N[N[N7E
MY>3DY.'AX=C8V-;6UM+2TM#0T,[.SLW-S<S,S,K*RL?'Q[^_O[R\O+N[N["P
ML*>GIYV=G924E']_?____P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````([J6^$````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^
M````OTE$050(UV-@P`)FS)@6Q5A2D).17=O1UEQ?!Q*:/KFI(3XI*SVSJ+VE
M@;$1*,01&1X1Q%Q15IK+%!@2'!8*%-)S\7`54N<6%N31,K)Q=+`""EFZ.XE(
M"'#J&O,Z>TE96Y@`A=QDS33UM?E5->SE/*7%10V`0O*V.FHJ7`I\8FR2,G;F
MIH9`(65O=B5%ULJJZAH6_P`_7Q^@4'M77U]W7&)Y?DI":]>$25.`0C&]?3V=
M:<EYA:G%L?T3HZ=B\PX`Z+LQ2^WUK:\`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O86\N<&YG````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#(P-#8@,3`U,34T,S,W-#8@,#(S,#,S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````2````#`@#````6,P=C@```P!03%1%````____OCH[_V=H/S4V(B,C
M*RPL'R`?!PL!$Q8*(B4!5E=-:&PK:&P8@H4^;&TFE99*$A(`?W\'6%@4BHHZ
MDI%"-#0A24DU5E9"9&1.%!00.CHU5U=12TM&4U-0,C(Q,#`O/S\^B80#?G<O
MS:\`7$P-%`\`U)T*S(D`[Z4UZ(<FVW`4S54!S$8!W&`AS$0#S4<)RB0`PQX%
MSB$-2D%`SA`#WB08NPH%T1`'S```?P``T`4%S`<%U@T-V!`0BPH*S!`0SQ(2
MTAH8E!$1QQ@8X1T=Y"$AU!\?G1D9ZRLKV"<G[B\OIR$AW2\O\C4U]3HZLBHJ
MX3@X^#X^US@XR30T^D)"NS(RX#\^_$9&YT%!_DI*\D9&QCL[_TU-VT)"[DE)
M[$A(_T]/_E!0\DQ,_5%1^U%1^5!0]%!0\5!0[$Y.U$9&]E=7[%=7^EY>Z5E9
M_61D]V5E_VIJ]FIJ%`D)*B`@.3`P3T9&6E!064]/(!T=9UY>;F5E9&1D45%1
M4%!03T]/3$Q,24E)2$A(1D9&0D)".CHZ.#@X-#0T,S,S,#`P+R\O+BXN+2TM
M*BHJ*"@H)R<G)B8F(2$A'1T=&QL;&!@8$A(2#0T-"0D)!04%`P,#____````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````)E2;MP````%B2T=$`(@%
M'4@````)<$A9<P```$@```!(`$;):SX```"_241!5`C78V#``JRL/&(*LP.=
M;"RM[=S\(I)`0LYA!;F1[@8:IK:NWJ&):4`A^X"\_`0O8UT==3//H-C4>*"0
M3Q9SAJ^COHJ%MI9_5$IR.%"(J2@GV,7(T-Q!3S,Z/3,N!"A476524JRFI%JI
M+%I17L92"A2J:>J?QL'%R<O#QUW;V"K/!A2J4Y@Z4U!(F%]$0*9!L:-G`E"H
M;<H,AAE28N*R<I(2[=U]$X%"[-,99DZ;U-527]<LW=G+.AF;=P#ZCC"^J];;
M+@````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B9"YP;F<`
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`T-2`Q,#4Q-30S
M,S<T-B`P,C,P,C``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#
M`%!,5$4```#___\?2B`B0B,K32PZ63L`+P``+0``'``#,`,#+P,%,@4%,04)
M-`D-.@T-.0T*)@H0/!`2/!(801@1+A$=21TA3"$?1Q\9-AD;.1LG3B<O6R\A
M0"$O62\A/B$F1B8H2"@U7C4J2BHN4"XM3BTX8#@P4C`J2"HX7S@S5C,T5S0^
M9SXX73A":T(V6#8R43(Z73I&;D9":$)*=$I"9D)&:T9);TE-=$U&:D8[63M(
M;$A/=D]);4E0=U!,<4Q.<TY1=U%0=5!&9D90=%!7>E=>@5Y>@%Y9>%EDA61E
MA65HB&AJBFHP5B\R5#$V634_8SX_8CY!94!FA65$9D%+;4@=0!@Q5BL-+P4)
M+`!,:4(=.Q!;<T]8;TP?-PUO;4Y<3"]`(0%K-Q^)4CIM+AAD'PEK&@.E9%&*
M.2>>,"&4%0?"4T:D)!C-6U#(6D_=6%&N!0"E$`G;.C7J2D;,``#'`0#&``#-
M`0',`0'*`P/(`P/,!07*!07,!P?4"@K0"@K0#0W.#0W3$!#/$A+;%!37%!39
M&!C;'1W?(2'H)B;E*ROI+R_R-37S.CKS/C[Z0D+^2DK_34W___\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````"VFC@=`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK
M/@```+Y)1$%4"-=C8,`".#@D6+U=-$+#V;@%Q10-;4%"(OJ>KL&)!?FIL:*R
MNM:.0"$!=7>/D/2&\K+:[#!M<P<;H)"<DY=C?%-%24U+1Y*Q@UT`4,C2VT4U
MN:JTNK&].\O6WD0+*!3D%LB44EQ9W];5E^MHH:<&%/*PDN)+**MK[>R=D&9F
MX,L"%'+V$>*,R&SNZ.G/B_'75)$'"ND(\[!S1V44%N7$&6DI*\@`A<1YV;GX
M1:4CHQU-_=24F"6Q>0<`ZITL9*6MO#P`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+V)E+G!N9P``````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`R,#0S(#$P-3$U-#,S-S0V(#`R,S`Q-P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$@````P(`P```%C,'8X```,`4$Q410```/___SLZ.VAG:!\@(#H[
M.Q\@'U%2269G7@P-`A`1!L;-`+.Y`\G0!;_%$[B^%>'H)L+'*NSR->_U.O;\
M1M+70\;,`,K,`,?-`<;,`<C.`\O.`\K,`\G,!;6Z!<O1!\?-"<[4"M'4"K2Y
M";F^"M#6#=+8$-;;%-G;%-C>&,_2&-OA'=_D(=+4'\K/'^7K*^GN+_/X/O7Z
M0OG^2OK_3_K^4/7Y4.7H6<W.#0P,`>/D(>[N+^'A.!04"A@8#2,C&3DY,')R
M:C`P+T%!0,C""LO&$=/.'-S8*N?B./#K1N+>2?;Q4.WI4O3O5<$T'L@_*M--
M.-U;1L%20.9G4]%?3>EN6MUI5^5O798M))XS*J`U+*<Y+ZD[,=M.0:P],ZX_
M-;%!-K1".+E&.[=$.KY)/KM'/<!*0.):3L5/1.=?4LM42-!73-1;4.AD6-E>
M4^AF6NMH7.!D6-UB5^=G7.5G7.1F6\TX+M9%.[=!.N!32;Y&/LM12.=?5=E<
M4^AD6^-C6F9E96IJ:F5E961D9%Y>7EE965=75U!04$A(2$9&1C@X.#(R,BHJ
M*B<G)R$A(1D9&1@8&!(2$A$1$0T-#0H*"@D)"04%!0,#`____P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````%^_-L`````!8DM'1`"(
M!1U(````"7!(67,```!(````2`!&R6L^````O$E$0508TVV,,0Y!011%Y[UY
M,Y-\*E$H?ZD@46@D5J"P#VI1"+^Q`"(2>Y&H-=:@D@B%!(F8^?-G/#4WN<W)
MN5>(GP!W,>Z^U.WIFDG]7#9+%&+E9_OC_64E`"1:"11KYR#ZDD4#@%I91J[(
MJ!-.#Z,!I`Z>T>@]E[&:HU&`&*QCE,G=)%RHI@@0\CPRDM1;'"J&Z"MY_QW2
MEJBE]?F$&$/!7R1D7PT2:ER!2?0^L#55PTT[A32%$-B*XD\^T,Y'(#<!S\X`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8F8N<&YG
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P,C4@,3`U,34T
M,S,W-#8@,#(S,#(P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@``
M`P!03%1%````_____6=H`%H``5P!`UP#`UL#!5X%!5T%!V`'"5\)#64-#6,-
M$&@0$F42%&L4&&H8'7,=(7<A'W`?&U@;)GDF)W8G(F(C(5\A+X,O)F<F*&DH
M-8@U*V\L*FLJ+7`M+G(N,'0P/I,^.HHZ,W@S.(,X-'HT0I-".H(Z1I9&0HI"
M2IE*39Q-1HY&29-)2)%(3YQ/3)5,4)Q03IA.49U14)I04)A09*ED#&<*,'PO
M,G<Q-GPU/X4^,H0K*VL@#E0`$5D#%EH).G`P0'@V3HU"3(9`48I&6YA/6Y90
M:)Y>;Z-E*GH8088O>:<-GL`=U)\0Q7\%T#\AMA8`S!L'R0T`N`P%OQ\8WCHU
MT#XXPSHTZDU&U$A"N3\[[5=0Y51.Y5U7\&]JQP``?0``?```R`$!QP$!R@,#
MR`,#RP4%R`4%R`D)S@H*T`T-R0T-B`H*TQ`0SA(2V104V!@8SA@8D!$1W!T=
MX"$ASQ\?FAD9YB8FTR<GY2LKIB$AZ2\OVR\O[34U\SHZKBHJW3@X\SX^]4)"
MN#(RX#\^^$9&XD%!_4I*PSL[^DU-ZTE)Z$A(^D]/\4Q,_%!0_%%1]U%1]E!0
MTT9&\%!0\E=7]5Y>Y5E9^&1D\V5E^VIJ____````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````F;T=[`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;)
M:SX```"N241!5!C3;<'-3<-`$`;0;W<G,W8L6S@1G5!.3CGFE*XHB0)0!!(0
M*T99]G\H`-X#_C`XFL?=G#]O/HA(W_5G"S./#V6]_P0FEHTX6`SC7OWJLR-F
M%HJPF/:G<O-Q65@VS#7!X$`:F]:FEITSM3T3KEJB:V8T^=N95A6$K_#F`YZ&
M];+M4MJ]@J#;D)1?>.J[.KU?*@C+1ZI$3E@TWDMIL+BF;(ED$)?FW$K!/WX!
M#,I2#B&%N.L`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]B9RYP;F<`````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,C`Q-R`Q,#4Q-30S,S<T-B`P,C,P,C(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____&Q\?)SLC$R</N
M\^W/T\[AY>"KKJKU^/0\@B#"Q\##R,'AYM\A;P`A:P`C<0,E;P4E;@4H<PDM
M>0TP>1`V>A@\AQU!B"%.ER]3F#5)A#!3D3A/C#9@ID);FD!<F$)@GD91A#MK
MKD]LK%!KJU!IIDYPJU=WLEY]M&6"N&I!A"`_;"E.AS1DID9DHT5CF4ASKU5X
MLEMFED_4V-+V^O3S]_'FZN3DZ.*%AX0O<PPQ=`\U>!,]?!U2DC%7D#ERJ59U
MJEF*O'`O9P%%?!A/@"=6BRM-=RQHFSY>BCIUIDUMFDB&L&0P:`$X;PHY;@U5
M@#%OG$EXIU'`"P#`#0/%$0?$'!+/'A3<,":P+B;2."^[-2WJ0SK&.S/61S[S
M4TKH54SS6E'H65#4.37,`@#+!`#,!P/0!P7,"`7+#0G4$0W8$Q#2&QC?(1WD
M(R'3(Q^F'1NP(B'M,R^Q)B.\*BCR-S6]+"K',"[),S#A.CC2-C3Y1D+\24;E
M1$+I24;^4D_^4E#V4$[X4U#^_O[\_/SZ^OKY^?GW]_?V]O;R\O+N[N[GY^?D
MY.3AX>'8V-C6UM;4U-32TM+0T-#.SL[-S<W,S,R[N[N=G9V4E)1_?W____\`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````'\"=E`````6)+1T0`
MB`4=2`````EP2%ES````2````$@`1LEK/@```*A)1$%4&--MP<L1`5$0!=#[
MNILW_JHH`K"UL/"-20R62@RRD@3+&0ICBM?=`N`<X$?`$;;U0TT$FDP_OA/`
M?6_,#%.WM-L#V&2QL:Y+J\WS3FVQ7"%@&GMN9D[%X$:A>ST)2GL\WTE)N!C>
M*>^`$*W*-06F(,_PT1R"B;]GCV8HB2CS*K[.@E&5K$_4%":WMC4@&-]38N$8
M)21551!*56*2.I->S-WQQQ>,9E`B"\<`9P````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V%R+G!N
M9P``````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#4P(#$P-3$U
M-#,S-S0V(#`R,S`S,0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X`
M``,`4$Q410```/___]74U<?&Q_[^_^WM[NOK[-?7V,W-SLO+S/O\_?;W^-C9
MVL#!PJ2FI_S^__O]_OK\_>_Q\N[P\2*BS!5E?R.CS"6DSB:FT":DS"BDS!EF
M?RJES2NFSBRHT"^MUBVES#&PV"^FS32NUC>QV#>LTB=YE#ZYX4&\Y#ZOU#VN
MTD.ZX4>^Y$.QU#B2L#.#G3>+IU#'[D">O%3,\C^7LU7)[DBHQUK,\E2_X4>A
MOU"TU$^RTDZMS&'5^D^MS$^LRF37_%G`X4J@NS=WBU6VU%2RT5W%YUW$Y6;6
M^FK9_%V_WFW;_VW;_FG4]E:KQVS6^6;*ZEJRSV"^VW+<_W+<_G'7^6[-ZV6\
MV'C:^G;6]F_+Z%F=LG[:]UZCN7_;^''"W&>MQ(?A_X/:]6^WSXOC_X'2[(/4
M[GS'WX[C_HWA^Y+C_8O9\HW9\8O2Z9GE_?'T]>3GZ$RQS4RPS%&QSMG<W-'4
MU,S/S]W?W_K[^]35U<S-S=C;VKB[K\/%O*RND]O=PL?(M[2U;Z>E%8!_'J6D
M+9^>4LS,RN?GYLS,RX6#!Z">5N/AV>GHY?CW]_[^_OS\_/KZ^OGY^?;V]O+R
M\NKJZN7EY>'AX=+2TLW-S<S,S,K*RO___P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#R2^P\````!8DM'1`"(!1U(````"7!(67,```!(````2`!&
MR6L^````P4E$050(UV-@P`*DI?7]$B,=M12DY%1TS#U#@$*B:DXQ$6Z:,F+B
M\NJ&MM[^0"'GZ-R\U/#BHD(KK["XE,PTH!!?*;]P25EM74UU0;Z`H%`Y4(B9
M<=*TZ6VMG<W=D_O[)DV=#A3JG=!>.:.CJZFE9P+CQ"E,LX!"7&SL')Q5#8WU
MW"P5K#PS>8%".?&!=C:N05%)&5G9Z<D)L4`A"U5)$0E%#6,''U]W:S,C/:"0
MKI*4K+*VJ4=P:("+O:6)`3;O``#2S3"/+PS#F0````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O8F@N<&YG````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#(P,C8@,3`U,34T,S,W-#8@,#(S,#(S`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____T#4VW3DZQ,/$
MB8B)I*2E^OO\\?/SY>?GXN3DRLS,Q\G)T]34T-'1N+FYFIN;QP``QP$`R`$!
MQP$!R`,#R`0$Q@0$RP4%R@4%R`4%Q@4%S`<'R`D)S@H*S@P,T`T-TQ`0R0\/
MUA04V1@8V!@8UA@8SA@8W!T=VQT=X"$AWR$AWR,CI!L;XB8FSR,CR"4EY2LK
MK"$AZ2\OKR,CMB8FZC(RQRLKN"@H[34U[#4UNRHJOBPLPRXNP"TMQS`P[SHZ
MR3(QQC`PT38USC0TRS,S\SX^RC0T]D)"]4)"U3HZTSL[^$9&]T9&W#\^VS\^
MW#\_X4)"^4I*YD9&^DU-Y49&ZDE)^T]/^D]/^U!0^E!0[DQ,\4Y.^%%1]U%1
M]5!0]%!0]E%1TTU-S$]/QTU-\G-SRFYNXGQ\QVUMQW5UT7U]QWQ\Z)R<S8J*
MV).3^\'!];V]QKFYQKJZW='1S\3$R<#`^.[N\^KJR<+"[>?GP[Z^^_KZ]?3T
M^OKZ]?7U[N[NZ.CHWM[>V-C8TM+2S<W-R,C(KJZND)"0?7U]?'Q\____````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````40XB6P````%B2T=$
M`(@%'4@````)<$A9<P```$@```!(`$;):SX```"O241!5!C3;<P[#L(P$`30
MW8V_^1"DU'24=!R`^R#10T$-IZ"EYBR<`8F:*#:.$QN'%J9\FAF`GR"<\;3M
MS&796JEUW517`@AQ1%H9RY34\U(`P3'V<?"M)<UU4PB;",\AHX<+2>I2C^]$
M88=]7`R2J[)2T9A$^XS0WZ-4JBZ$NX5I2!E#IYEJ"FVZ39^(*#A:RSP=]<Z/
M#E@B1/\4WZ,NV=3"0\9X/LNY??DP>/B3#][80W3NRIG1`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B:2YP
M;F<`````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`U,"`Q,#4Q
M-30S,S<T-B`P,C,P,C$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.
M```#`%!,5$4```#____2P,'W[.[NXN7,R\S3V-C8V]O)S,SCY.2RL[/2U=3+
MT,[!S,3P^?*IOJC+V,KF\^7=[-HP>"!*BSBOP:H\@"=DI%#0YLF:H9@[;RI.
MBSIFJ%!HJ5%GIU%FHU!\M&AQG6+@[]L\<R9"<C!KJU%MIE9XGFF2N(.,HH2Y
MU:YI=&4<1PE/C3-$>RU.AC=CGTEPIUESI%Z3Q'Z4PX!^HF^YV*L?30HX:"%&
M?"Q+@C!0B#12BC9;E3Y?F4)3A3MCG49CGDAII4QKITY?DD9SK%=VKUQYL5Y_
MM61_LV6$N6J,O71@=U6HP)U-A#%>F4"`HV[/TLCM[.7%P\#,Q\3CV=2K<5BU
M>V6X>63;II3#J)_"I9W8?W+-QL7"6D_>SLS0#P7A*!W.*R'C0SCJ4$;423_V
M7U?^:F'O<VKA<&K[@GK,:6/B>'+-=W+YFI71D(S3P<#^[^[,!P#,%`S6%0_N
M-R_A/CCG2$/D1T+013_V4D[*1D#Y5U#&5E+,=W._B(;QN+;]R\G>M++8M;3,
M!@76$`W8$Q#8%!#2&!C5.#7Z1D+_4D__:FJ=<W+,K*S+NKK;V=G\_/SZ^OKU
M]?7R\O+L[.SKZ^OHZ.C/S\_-S<W,S,S'Q\>[N[M_?W____\`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!UR$EH`````6)+1T0`B`4=2`````EP2%ES````2````$@`
M1LEK/@```,%)1$%4"-=C8,`"M.?VUO:DE76T%"6T531,5`(*Z?C,8<XK3\W-
M3BK)9)EDY@84,I?2$)S:'!L57=`T3<A$S@`H9.&BH.8[@R,LG'VZEJJLDRU0
MR-[+521@UBP>-LXIWC+.=M9`(4]W?V'%_KB0^)@@8W$'&RN@D(>CF#Y_<$1@
M:"2?A*&TGR502%[7E)<U?\+TR86-4P34]92!0D:BL_HJVY,SLM*K<IAF:ZH`
MA;AGUA6W)I9V==>D=%;7<TEB\PX`X,$RTAVKV;(`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+V%T+G!N9P``````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`R,#0V(#$P-3$U-#,S-S0V(#`R,S`T,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___\XD)<S$Q>+;
MW*2?H/KU]L;*RO?Z^O'T]-_BXMO>WM/6UM#3T\_2TL[1T<W0T,K-S<C+R\?*
MROO]_?K\_/7W]_3V]NGKZ^7GY^+DY.'CX]W?W]#2TL?)R<3&QO7V]NSP[\;)
MR,[)R//N[<@``,<``,8``'T``'P``,D#`\@#`\L%!<H%!<@%!<<%!<@)"=$-
M#=`-#=,0$,X8&,T8&)`1$=P='<<<'.`A(=\A(=(@'\@='<\?'YH9&:0;&\<C
M(\8E)<DG)ZPA(>HO+^DO+\PI*:\C(XD<'+@H*.TU->PU-;LJ*M@R,L,N+L<P
M,,HR,MXX.-TX.-8V-M$V-<XT-/9"0O5"0K@R,OA&1O=&1N)!0>%"0N5%1-,_
M/^9&1L,[._M/3_I/3^)'1_M04/I04/%.3O504+8_/ZX\//-65MA-3/)75\!'
M1N]96?5>7LM.3OID9.I?7^A>7MM:6?EH:/-E9?=H:/MJ:NYH:/AN;NYL;.5L
M;/AX>-;.SL?`P,:_O]C1T=G3T\K$Q,G#P\C"PL?!P?GS\_CR\N_IZ>[HZ.WG
MY]S6UM/.SLG$Q/KU]>KEY>CCX^7@X+ZZNO;R\M71T=#,S/___P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#?RIZD````!8DM'
M1`"(!1U(````"7!(67,```!(````2`!&R6L^````OTE$050(UV-@P`(T-.T2
M*G*"3/34=(PMO2)30$)F$67YT;8&:MI&YJ[A2>E`(8_,FMKB."<+&R;?V*S"
M\B*@$.NT_N[&YH9ZYCJ6SO:.KAZ@D+P(IXR`,+L@#Y<BARBG-#]02$%,BD]8
M3HB76T),5%Q25@DHQ#:QMZ6M5;EIDDK_E`E3^R8#A:JS`QP=W(*3\TJK*DL*
M<C.`0H&F^NJZQE;>4:EI,:%^GLY`(6L#52U#<Y>PQ/3X$'\?=WMLW@$`9]\N
M8A;YXB@`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8FHN
M<&YG````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P,#<@,3`U
M,34T,S,W-#8@,#(S,#(T`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=
MC@```P!03%1%````____.GD[`%\``%H``#D``#@``6$!`5H!`UP#`UL#!5X%
M!5T%!5@%!V4'"5\)#64-#6(-$&X0"D,*$F42$F`2&&H8$4L1'7@='W`?'V\@
M&509)W4G)W`G(5PA*F8J.(,X.((X,F\R085!.W@[2)!(4)A01H5&4)=05YU7
M5YE77J)>69A99*=D:*IH9:5E:JQJ:JMJ,'PO,'LO08E`9J9E18`#380-6X\?
M<*$X0WD`R\T`S=`'UMD4XN8F[_,ZW-\^^?U*[O%,^/Q1R,<`Q\<`R\D!R<D!
MR,@#R\L%R<@%1D8#R\H)SLX*T-`-T],0V-@8TM`8W-L=X.`AY>8KZ>DO[>TU
M\_,^]?5"^/A&^OI-ZNI)^OI/^_M0]_=1]?505E(485XA;FLO3$<*W\\A[-TU
MSL$T]^A&\>-.SKP%U,,0X=-"^NM0U!D-W2D=Z3LOQCHPT#\V]4Y"Y5!&^EI/
M]%I0W1@8YB8FI!L;YRLKK"$AKR,CMB8FN"@H\#4UNRHJOBPLPRXNP"TM\3HZ
MQS`PR3(QT38USC0TRS,S\SX^^D)"U3HZ^49&VS\^X4)"^4I*YD9&^DU-ZDE)
M_$]/^E!0[DQ,\4Y.^%%1]5!0]E%1____````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````R6I_@P````%B2T=$`(@%'4@````)<$A9<P```$@```!(
M`$;):SX```"@241!5!C3;<'-<<(P$`;0;_\D8T+`A\S0!#1-(RDF,[EEPB%&
MNY*E%`#O`4\(1A_?USB>O6I2$;TQ:,F7ZJ.&F#`+@W&8YAXQ0HR9F1L4^XGC
M_7?\T4K$/#H4:2[^4_1*06Q-ZJ=B6?=W7Q<E$Z;>#8H2]X?K>2>G:7*/"H8?
MBK>\T9Q2J]O6H(BO$EDI[VQX1.M@N!>S1&]9HVR]=[SP#PJ"2RRN:\6C````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]A=2YP;F<`````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,C`U,"`Q,#4Q-30S,S<T-B`P,C,P,S0`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____7453R;&WY
MF)G,2U"R+CE^(2BZ-#YW-#G*:7"U56.PDZA8.E"/9XN29X_.M,QS07>9>Y[/
MMMIR9(:PI<!>2(;"M-NAE;I84VR&>,%D7H931YB.AL)L9*9S;*J?F=(4"7\L
M)(YR;<"(A,FZN<81"X,T+Y-U<<=T<<.3D-0,"X84$HD5%(\?'I`A()8E))LO
M+I5'1JM"09]03[Q*2:E55,%55+Q75KQ'1I9/39]03YQB8+*?GLT!`H,&"(<&
M!H0'!X<("(4)"8<+#(<-#XX.#XL.#X@0$(<2$X\2$HX:&I@:&I4<'9,='9<A
M(IPG)Y\G)YXE)90E)9`?'W8L+*,P,*<O,*(Q,:<Q,:8E)7TF)W\U-:LJ*H<X
M.:TR,IPK*X4Z.J\P,(T_0+4T-90R,H\Q,HP_/[,W-YHV-I9"0K0\/:5$1+8^
M/Z$[.YE)2;M(2+E&1K0]/9Q!0:),3+Q-3;U/3[]/4+Y*2K!14L!,3;-24L!0
M4;I-3;)34[]55<%35+U-3;!14;=65L%65\!86,-65K]55;U45;A04*U24J]?
M7\)35*-H:,=G:,1M;<C*RLL,$(HB)HL\/II?8<,S1*OK=7+$3D[P9&/X9V>N
M3TZ42TKH>WN[:VOGC8S___\`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````"I8#PB`````6)+
M1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```,%)1$%4"-=C8,`">"6E
MIXL+V$[5=G#6ERW,KP<*<<Z>R\PRCXM;S=XK4-FDL@$HQ#YKSLQIK!QLBJY^
M8<FE6BI`(1$>X1FB0F*3W'PBL\KJ-&V`0GP:4DPRP?R"NN$*W=4671E`H;XI
M1DH>=A/5#>+Z6\T;C5.`0KVUQ9/=G=R\(W+*VJIR,Y.`0AWQ\A.L''U"T\M;
MFDSS4A.`0MEZ<JH]G@&))<TUG1*6L5%`H2`7'4-?_Y@"L_:*(NNTZ!!LW@$`
M^:$R&56"!HH`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V-A
M+G!N9P``````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#4P(#$P
M-3$U-#,S-S0V(#`R,S`Q,@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,
M'8X```,`4$Q410```/___]75U/;S\N3@W\J[N-*XL]/#P,X=!<HD#-`D#=<I
M$=(N&.$T'=U$+\0_+;(Z*LU$,?]D3_)@3/ME4=171M9G5LAB5,QR9LYT:/V1
M@LYX;.2/@^"8CL:*@?ZSJ?ZTJOZYK_>VK<V9DLR=EOS/R<RKIG\,`,P;!,P8
M!<H<!<T>"=8D#8L7"I0@$>(W(=,S(<LU);`P(>Y#+[(R(Z<N(;DV)KPY*,$\
M+,I!,.%).-)%--5(-O=2/^!0/OQ81N550NY;2>Q;2/EB4/%@4,M82?IP7O1O
M8/US9/AT9?][:L]E6,QQ9=J`=>Z9CM2(?OBEFLJ&?=*+@^&9D.ZEG/&LH_FT
MK/VXK__'P/S*Q/3-R/K3SLVQKLH2`'\*`,X4`]XF&-0O'Z<H&^LZ*_I/0L=(
M._Y?4.=62^=I7]2,A<T.`<P0!<\<$M@Q)_(^-<<W+L\\,_I,0MI#.KLZ,N=*
M0.I/1O]63?U:4?973O9@5^EA6?S/S/+.S-S,R\P)`)T=&?(Z-;\P*O]O:-+#
MP_[Z^MC5U?W\_.SKZ^?FYOO[^_KZ^OGY^?;V]O+R\N[N[NOKZ^KJZN7EY>'A
MX=[>WMC8V-;6UM'1T=#0T,S,S/___P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````&%!TD````!8DM'1`"(!1U(````"7!(67,```!(````
M2`!&R6L^````P4E$050(UV-@P`+BU.OE&'LFL:G,F#Y%IL$^#2BDKE>LU-7!
M[FJH-G627Z&0,U!(5Z`JO'U*C$96YN3^@#(11Z"0J6A3:*VW.">76$:40KFP
M'5`HU:LRN%DSEH-;/R]2L<+!&BCDZ5;BSZH5K\-KG*(:5FIC"13R<,J5GJ%L
MD)!L*]\94B1H`11RX<N1F#'--]U=JJU7MH#?#"ADQ9/M,[V5I::ZA7EB4+ZY
M$5`H4;M.<NJDONB([@E,@8TF2=B\`P#8ES&H&P[$Y0````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O87<N<&YG````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#(P,S8@,3`U,34T,S,W-#8@,#(S,#0R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____JD%#^H&#
MYXN/B5Q??E!6O9^IR:^]85UIN\36M<KB2%QND*:Y9*#):*3,:J/+;ZK3:Z3*
M?K??>;#5C<7K?:K*ELSPA;/4G-/XE<;GI=C[I=;YK-KZJ=;TL-KW9J''9J+'
M9J'&9Z''9Z+'::3*::3);*?-:Z7*:J3):J/&<:O1;JC+<:O0=['7=K#5<JG-
M=['5?+;;=JS/>*[1?K;:>:[/A+SAA;WAAK[AC<7HC\;IE<SOE\WPA;/1G-+U
MCK_?G=/THM?ZC[_=H]CYE,3BD<#=H]?X@:K$J-O\F\OIJMW^J=S\I]KYIMCX
MG\_MI-7TH]3RI]CWE;7*D<?FM./_0&E_8I"G@KC3D\;AL.7_0&U_@L7<;Z:U
MH,S8;J6S=JVZ=:FV@[C&DL;3AK7!HM3AC[O&A:^YK-SHH<[9J]GEM=_I<ZFT
M<JBS?;*]:8Z6?*6NA:ZW?:2LH<W6L>#JK=KC=:FSB;W'A;6^<IF@FLW7C;C`
MJ-GBD+=XILF2A[%JB[5NBK-ME;YXHLJ&?YQKBJATLMB6E+-]G;V&O^2EKL^6
MQ.>JO=^ED;1.DK1/EKE4F;E:H<1@K]%PCJA>JLAQF+-FOM^!HKUOL<U\RNF.
MR^J2P]^,PMZ.NS(RZ5E9^G%Q____````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````6`.&^`````%B
M2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"W241!5!C3;<$M3D-!
M%`;0[_[-S"-U70`)'H%"L`9`T1V0BFX&AV`'J!H\@B60H(`$655",WV\S-S;
M!<`YP!^$A3V6RY>3W<><\]'G:7XBS*;[9;I^WU4=2DHS63-ZHX<>M5DVTV(3
M%%?MUFY>]Y%2EF*]@?'-Y>+MURTG,9,Z@G#LY\_-B9F5R=TWA-5/ZN["Q,+1
M:;A3G(W-@YE4B'JX0_$5ZL0DPN0>'E!,O@T>A$?R4BE7_.,`LP-'N@(`IC,`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B
M;2YP;F<`````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`T,2`Q
M,#4Q-30S,S<T-B`P,C,P,C4`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8
MS!V.```#`%!,5$4```#____```'!!@G+"`G4$A/'*BO'+B_R6%KP7V#H86/N
M96CW:VS#5UCN='7KC8YY'!^W/D'-24VR,#>#,C:M1TW_UMCHPL3AIJUC-S^A
M:'*>:W9I3%2SB)6H@I"%5G')J<&$=82PH[7`KLM@0G-"'UQ8/7&4@:F'=:9M
M9WPR)6.1DK:LV<A-T#Z`Z&ATL4NZXJ"4HTW7UL7<V;[6R:G?RY_HWM"69S/;
MSL#>H7_RW='4<D[!1S7!/#'M;V7385[Z@7[IB(7,``#-`0',`0'-`@+.`P/,
M`P/0!07,!07'!@;1!P?-"0G4"@K6#0W6#@[.#0W'#0W8$!#6%1//$A+;%!3>
M&!C2&!CA'1WD(2'4(!_4(2'A)"3H)B:G&QOK*RO8)R>P(2'N+R^R(R.Y)B;=
M,"^\*"CR-36_*BK$+BW!+"SU.CK*,##N.SOA.#C5-C72-#3X/C[Z0D+0.SC@
M/S[\1D;Z1T?^2DKD0T+J1D;A1$3N24GL2$C_3T^4,"[^4%#V3D[Z4U'Y4%#E
M2TO>2$CQ4%#[6UKA65?]9&3[;F[R:VN[6%;G;VVR6%;I@X'___\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````"]])%.`````6)+1T0`B`4=2`````EP2%ES````2```
M`$@`1LEK/@```+I)1$%4"-=C8,`")&4T>14DE%2\G#R"(M-+ZX%"`G7=/`X]
M0FPN;OXQN66U34`AD=Z^3D=[46%7WQ9Q?K&V:J"0HJPRG[:<O"I+*)>9I15'
M"5!(2D.]74U+6I`ULLM8QZBY`"C$S5D5'<C$'!R19&=J85*<`Q3JJ$D(<''V
M#8LOM-8ST+?-`@JUIH:X.WF'QF:7-QKJFF>F`(7RPCVA+FJHL&%/2P0*1?DX
MN?E%)!75-E7FYV0DQV'S#@`THRYGB+?^I`````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+V)N+G!N9P``````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`R,#4P(#$P-3$U-#,S-S0V(#`R,S`R-@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___\Q;7>Z1
MDL$6&]S*RV9A8I*/D/SP^3LZ.W]^?]74U?SZ_=?5V/7T]NOK[!\@(,W.SL#(
M!>+K+^_X0BLL#?3[3_#X4,##`\7(!<?)&-36'>'C/\S./>7G1E]@(\O-3VEJ
M0L+"`,"_`+^_`,'!`[JZ`\/#!<'!!<'`"<G)#<S,$,G($L;'&-74'=C8(<G)
M'^+B+]S<+^;F-;R[,'EY'^SM/M?7.-;6.,S+-9:6*._O0O'Q1H^/*M750+Z^
M._/S3>/D2?3T3_/S4/#P4>[N4.SL4.OK5]?7461D)WMZ,O7U:MK:9)R<2.OK
M=M_?<_;VE_7TGVEI97Q\>#\_/D%!0%M;6KVY`$9%&_7TR]')$,&T$/GTKD=%
M-)Z23N_JV-#.Q[V*`%]:3+FWL9IK!]N=(>NU4-Z4->R81N+?W*NHIE=55)R:
MF<-]7J25CKQ#%3X0`=1*.JE?5U@)`<(S)M!@5;A=5)9336,/"G$>&(="/NR[
MN)]O;9IN;%X``,0'!Z\7%"T(""$)"9$K*^%*2I,X-]M<63D:&J9149-44^V;
MF\B-C..HI^+<W.SHZ)*0D./AX?GY^>KJZNGIZ<_/S\K*RK*RLJ*BHHN+BVIJ
M:EY>7C,S,RXN+BTM+2LK*R@H*"$A(?___P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````!`!C2\````!
M8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````P4E$050(UV-@P`*\
M3*WLO=TMI(14U+7UC6V<@4)<_<F1@?ZRT8D26GJ&UDZN0*$9TR;S\/,*YN8K
MV,F8.;@X`H78IF?VL4[I9JEGZHV/"?#S``IQS@S+;JVI+2OMJ>[BX)N0`!0*
MFA4JT%37V-Z9U\8\<1+W5*"0CZ^G:$%Q165S57E1,'M.%E#(S4A'+3REH:2P
MI2,I9/;<>4`A<UT-)<FHU/2,M#C%V#GS%P"%##255;6DA47$Q.4L36SE([!Y
M!P#HAC)Z\KO5_@````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M8F\N<&YG````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P,3<@
M,3`U,34T,S,W-#8@,#(S,#,R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````
M6,P=C@```P!03%1%````____`%P``%D``UX#!5T%!5P%"6$)#6<-$&<0&&D8
M'74='W$?(78A&UH;(F0C(5\A+X8O*FTJ*&@H-8@U+G$N,'4P.((X-'DT0I5"
M1I9&0HE"1I!&3YY/4)Q03I=.7G=>-GXU)&\`)G`#*W4',W@2.H452I`G/W4F
M38TO1WXM3H<S6I4^;+!+::5,;Z]1;*=07J`Z8')&86U$A(U'=7@NR<L!Q\H!
MR<L-T]4GO;\LU=@ZZ.I(]_I1^/IDR,<&S<T)TM(8U-4@RLHPR<HQX>$XTM(T
MU=0VY^=`_/Q&Y>5"Q\8[ZNI&__]/^/=-ZNM)_OY0]O9.^?E0]O97^OI><&\J
M^/=E__]JRL4&S\H2T\X:Z.0F]>XZ_O=*\NQ,\>M0U,]&Q+P`IZ$AW=4OX]HV
MX-D^_?91__AHH)(*D(02HI`-YM)#MJ=#E'4&J(\MF&<V?4`&S28!S",!U"<*
M^VE1SB@-BQP*WC,8ZT4KV#\GLCTJ^%<^_V5-[F!)[%](Z6U9_7EDS```?P``
MS@,#T`4%S`4%S0D)U@T-V!`0TA@8E!$1X1T=Y"$AU!\?G1D9[B\O\C4UX3@X
M^D)"NS(R_$9&YT%!QCL[_T]/_E!0^5!0]E=7^EY>]V5E_VIJ____````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=T8">0````%B2T=$`(@%'4@````)<$A9<P```$@`
M``!(`$;):SX```"H241!5!C3;<%+3@)1$`706Q]XH`P<N`(68)R[(=?A'DF8
MZ,08VT2"V'3WPZY;SP7H.<`?@B=L5H53C3!W=W]48+58YAP,-3,U@>-<!\DY
MV-3%I*[A^,Q2?6PW<A*1=2UP?&SZ[\B[[N5A?"OG2T!QS8%M:\\'*:XS"477
MG<9I]V.W?/WBD1,$]Y?(IBI7H2U;R[WCO0^J>^E=@DQ",3#$U!<&+I.1^,<O
M)N-9O0Q'V;<`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]A>BYP;F<`````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,C`R-B`Q,#4Q-30S,S<T-B`P,C,P-#0`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____Z]?8Q
M.;X]0[D;)K$C+;4F,K4;(GI#3M`[0Y]58-YC;N9>9]==9M9G<>1K<]5W@.@<
M,+P`)\P`&'\#*LX%+-`%+,P)+<T---80-]@8/-(1*I0=0N$A1^0?0=09,ITO
M5.XU6?(X6.%"9OHR3;M&:?Q!8.<Z5L=/<?]0<OY0</E7=?9>?/IE@?=JAO\`
M7@``7``#7@,%8@4%804)80D-9PT0;!`8;A@==1TA>"$?<1\;6ALA8B$B9",O
MAB\H;"@J;2HUB34N=2XP=3`XAC@T?31"E4)&F49"C4)&D$90H%!/GD].FTY0
MG%`V?C5.A3D]<"%@BC\H5``K5@12<S1PDU$X8!-$8R=2=S!+:RU?@C]MD$TO
M50=ND4ISE%'RW]C(;E+/KZ7,KZ;),07`,`;#/1;&/!?311W-2"+/2R?.5##>
M8CZZ4C3&5SC073S$63G29$/B:DGZ>5+B;$K$7D'@:TOE;T_D<E#R>5;D<U'L
M=53Q?%KR@%[SB6O\D''%<5CZCW'6?&+VE7KCK)S+LJO;32C-53G07#_T=53*
M9DSN>E_UA&?SB6WZE7K/+PW`.Q[*2B^;0"SD9TO89$O294SO=%CD<UG!7TOC
M=EW(:%+RBW3NO++!:5O"CHC___\`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````"9,VI"````
M`6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```*])1$%4&--MP4M.
MPE`4!N#_/'IML!V8$,*`&&5&7)JK<`LLP449!S!B@I,2[`-HSSG7!<CW`?\0
MYJC*![]<S4155;\8*(L4D[FQB+`0%-V0R`=Y;,D3DP0(VY*B>4JY)<G25_&N
M.,SBY+L07>U>?]//!,:R[B/6F[?GY6>]B'F&XFPWR]/^I>L_&AN/&8IO"<_7
MKN&*/(]%0'%JS42E3#<V=W<P!G<6+@H53Q&1<<<?KWI5!\(4R[,`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+V-F+G!N9P``````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#,T
M(#$P-3$U-#,S-S0V(#`R,S`R,0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P``
M`%C,'8X```,`4$Q410```/___\=+3<%45X4'(GX`'HLD/Y@X4__^_WQ[@.GH
M[^'@YP4%4@0$+0@(-!`062$A:"<G;C4U>CHZ?D9&B4Q,CE!0D%E9EU=7E%E9
MEFIJHVIJH9R<I]/3W>;F[-G9W]C8WNKJ[SL\;F9GGA(88D-*B-/4VL')T,3+
MT;K)P^#KYNSR[0EF$DR<4@%:`0%6`0U>#1AF&2=Q)RYV+RMK+#I].DV:33UY
M/4B-2$F.24.!0U&944Z/3E.34UVC75Z@7F2D9&JH:L+'PN?LY];;UL3(Q._S
M[^?KY]+6TKJ]N@IH!S)S,7*K<5:B40M=``Y>`RYI)E683%F:4!UH$CE^+S9R
M+3QZ,TB(/O+U\;_/$.#K3K*Z`+:^!;2[!;O"&)ZC(:FO*+2Z+K_$-,S2.-'7
M0LS*`,W+`\S*"=74#>#A'=33'UA8#:>E&[*Q([Z]*LK(,-34->GJ1F9F+$E)
M-&)B6^#@W]=L(>M]+_:-4/.*4(HZ%'TK"GPL"KUH2JM1-;!:/LP``,<!`,D!
M`<<!`<P%!<L%!<P'!\T)"=8-#=,0$-X8&-(8&.$='>@F)NLK*^TU-?4Z.O5"
M0OA&1OI/3\%/3MA=7<I75]MD8MW<W/[^_OW]_?7U]?+R\O'Q\>CHZ-34U,_/
MSZ>GI____P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````-::P3P````!8DM'1`"(!1U(````"7!(67,```!(
M````2`!&R6L^````M4E$0508TVW!P4T"81`&T&^^&=S%9"5K-)AH0S;!G5"%
M"3>/Q@(X>O-N"S9@`6:C'(3$`,O^,T,!^A[PAZ"95:^]_RS[ATJ%Y#<A-0]U
MDZ7D#55581A>I'+SPK#KS[P2"%8Q?Q[JW7HT&7L(/QX%]Y/UZ-@MMG;Q)+?B
M\F;0KV$3VC7::=N'.XC?_<Z#0LK8CX?68;ADEBRAC*F=9=Z]&]HA0[R0I3F/
MS(2ALA"*4'*:F9GXQPE8W5#VFGZ-T`````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8V<N<&YG````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#(P-#$@,3`U,34T,S,W-#8@,#(S,#(P`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____T#4V
M`'T``'P`!<@%"<<)#<D-"H@*$LH2&,X8&,T8$9`1']`@'\\?&9H9)],G(:0A
M,-@O*JXJ.-TX.-PX,K@R0>)`0>)!.L,[.\,[2.A(1M%&4.Y04.U05_)77O9>
M7O5>6>599/ED9/AD9O1E:/IH9?-E:OMJ:OIJ1<<`1L<!1\8#2<<%2\<)3LD-
M4LH25\T87-`?[/(U[_4ZV^$=V]T=W^0AXN@FXN0FY>LKY><KZ>XOZ>LO[>\U
M\_@^]?I"^/Q&Q\<`QL8`R,@!Q\<!R,@#QL8#R\L%RLH%Q\<%S,P'R,<)SLX*
MT-$-T-`-UM,0T]00T],0UM<4UM84V=H8V-@8W-L=W^`AX.`AS,<`R\8`S<@!
MS<@#S\H%T,P'T\X*U-`-Z:<O[*LU[ZXZ];1"][=&^;E*^KQ0\[`^^KI-^KM/
MHQL;K"$AKB,CM28FN"@HNBHJO2PLPRXNP"TMR3(QQC`PSC0TRS,ST#8U]41"
MU3HZ]TE&VS\^X4)"^4Q*^D]-Y49&ZDE)^D]/^E%/^E!0^E)0[DQ,\4Y.^%%1
M^%)1]U-1]%!0]%%0]E%1____````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````N.B81```
M``%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"Z241!5!@99<_+
M$L$P&(;AM*)IZ[P@6J8ZR##%QJVY!1?A_L3*C,-0R9^TB5C[EL^\FP^AOWFH
MX;7BGB@_FF5A=&FL3C[R0M*5H"HV30CW"X9\A$F[UA)8FI9.\M)1%&$E@-')
M^PSKO-(_ZH"`)9V^L-K/C%".6E+*Q3!]<K[/`CA:A)%1,!_11XAW-'ZK0^4J
M)?+Q\!Z<BU$$NK:UJ\0L&=Q"OAT'5JBJ-J[*)OUKDV\H(:"M,?;OC8,O+:Q/
MO#DC2"L`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]B<BYP;F<`````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`U
M,"`Q,#4Q-30S,S<T-B`P,C,P,S(`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,`
M``!8S!V.```#`%!,5$4```#___]8>*8!,&L!+VH+.'$F5(\F48@Z:9XT6()C
MC;Q=A;$*/7$A4819A[8$.6PA4H`B3WA%9H1>>9$/0VT00FP21W,32'8K57DL
M57DS6'A!;I11?J,=4WTE4G4L78-.>9ID@YLZ>3L`6@``4@``.0``.``#7`,%
M6P4)7PD-8`T*0PH09!`8:A@12Q$A>"$?<!\95!D;6!LB8B,A7R$F9B8O?2\A
M6"$H:2@UB#4J:RHK:RPP=#`N;RXM:RTJ8RHX@S@T=31"DD(R;C)&ET9)DDE/
MG$]0G5!0FE!0EU!1EU%7FU=DHV1JJ6IEH64P=R\V=S4_@CY:EUF*J(D*7P4C
M=!U5G4T=:1)2DD:-IXA#?C-\EG5SK%Y?D49%B!TS=@5TJ4RKP)EVJ$AQHCAY
MIT*RPYV=Q61ME3%6B@!LA3U[E$V3OCY]G3N2NB]PE@.-JC1UBS6VTU"DO3YW
MBBVIQ4&3I4K"V67,X6B]S7J!D3*7I4K"T'B@M@V>L3"VQ5BKOQ"FM$&8I1JT
MPR?6XT[6Y5&BK!RRNS'$S3K"R1C<XDB_Q4+"Q0#'R@7BYBOR]4+V^6K.S@W4
MU2#AX3C5U#;GYD#^_DK@X4+JZ4;N[DG^_4_]_5#V]4[M[DWV]E#Q\5#V]E?X
M]U[___\`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#0B\#P`````6)+1T0`B`4=2`````EP2%ES````
M2````$@`1LEK/@```,%)1$%4"-=C8,`"5-4,E7R]DSMZ,D)T]"U=W(%":GK.
M?C$E;97%K35Q9DYN'D`A;?N@M,Y2419FGJS>[#`O5Z"0>6SYO"Y)03D)`?:Z
MJ2T)@4"AG/[YDZHXI82$%9DB9\V>E@\4*ELP96(!JXB8O#1WZMSIDVN!0CY)
M31,:^<5E%62X*F:TIUL#A3S]P_.Z,WG9./@2YQ1%V9D"A1QT-53BZQNB@ZN;
M4QQM+4R`0@::RNI:H;E],PLC`FRLC(VP>0<`?>LR=J(&R@T`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V-H+G!N9P``````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`R,#,T(#$P-3$U-#,S-S0V(#`R,S`R,P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q41=74U<?&Q\'"
MPK*SL]35U.#@W]W=W,W-S,O&Q>/>W?KO[?#IZ,9Y<<O#PK$5![4;#;(:#:@9
M#+<>$+4>$+,>$;PA$[4?$JD>$;XC%<,F&+PG&;@F&;XJ':TI';@N(;HO(\<V
M*,@V*<`T)\X[+<`V*H4I(=)"-<]"-;@\,=E).[@_--9*/KE!-J0\,L],0+E$
M.JQ!-^-62<Y-0L%)/L=,0;I(/<M.0\!*/]%11K-&/-U93<U42-E93;U-0Z-#
M.NIB5=!73,A32=]>4M5;3[9-0]Q=4M=;4.1C5]M>4^MF6LM83N9D6=]B5\%5
M3,)73==A5L=94-]E6KQ53.1G7=YF6[I63.IN8^%K8=AI7]%E7.5R9^MX;<EF
M7<]J8>=Y;NM]<^-Z<.J#>NZ*@>R)@.V-A>NDG<N?F\6;E\:=F?7$P,>@G/G0
MS._CXK41!^5:4?CW]_____[^_OW]_?S\_/O[^_KZ^OGY^?7U]?+R\O'Q\>[N
M[NSL[.OKZ^CHZ.7EY>'AX=[>WMC8V-;6UM34U-+2TM'1T=#0T,[.SLW-S<S,
MS,K*RL3$Q+R\O+FYN;*RLK"PL*>GIY24E(N+BW]_?P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'XD+.\`
M```)<$A9<P```$@```!(`$;):SX```#"241!5`C78YB"`1BF3)ZLZA(?;B8O
M(B`FHZQ77`@2FF@7%V7AEY&N(ZJH:5-0!A2:U!<;[:84U-GA*ZEFZ%-2!12:
MT)P0:"(7RMX:HVYE'U+!"A1B+(@P2N/E:&ODY,[T]*]K`0KEESJJ9'6V-]57
ME69[>S%T`86*JC6DM4QY&FI2DQ(];-F9@$*5;++"?+D!M>7)>:[6EMV]0*'Z
M%G%^,8G('*X4)P=C@YY^H!!+AZ"0E(*V>UBPL[F^+O,$H!`&```QMU`EO%&Q
M3P````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O8G,N<&YG````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P
M-#8@,3`U,34T,S,W-#8@,#(S,#0P`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#
M````6,P=C@```P!03%1%````____.SH[:&=H``,/`P4-(4&P3G3V9&AV`##,
M`S/."3?-#3S6$$#8"2%J!1`T'4OA(4[D'TK4+USN*$J\-6#R+E''-%C20F[Z
M1G#\06GG0F?E3WC_4'C^4'CY,CYC`#3'`#/&`"B;`!53`SC.`AMC!3O0!3C+
M!3C(#4#1$$/3&$?.'4[;(5/@&3N=&SZD(D>O+U_J-67M*D^[,%?&.&/=-E[1
M0G#V1G7X.E_'1F_F3WO[4'WZ4'KU5W_R7HCZ262S:H_[98;C&$.L&4.M(4NS
M+EB^06G,4WK:88;B7'[498C@*5&O)T^D/62^67S(1V.@3FNJ6GBY:(K3:(?*
M'R(I/6.L1VRY/UN6;H_4'R`@*RT%IJ@*Y^E`U-9$\?-03D\:YNA2%A8`@X(%
MR<H(Q,0.U]80GI\-;FT-W-T;WMX=S<X;X^(A[>POX>(NVMLM[^\UR,@PN;HN
MT-`TTM(VQ,4T]_="[>Y!^OI&T=(\X^)"Y^=&_/Q/_/Q0]/-.]?90]O90Y>9,
M\O-4\?)7,#`O04%`#`L#`@$!,"\O9F5E:FIJ9&1D7EY>65E95U=74%!02$A(
M1D9&.#@X*BHJ)R<G(2$A&!@8$A(2$1$1#0T-"@H*"0D)!04%____````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````:MSZM0````%B2T=$`(@%'4@````)<$A9<P``
M`$@```!(`$;):SX```"_241!5!C39<\]+D11&`;@]_V^]QQ')E&8*31",84E
MZ*Q"I55JB<0"9@HV8"$2G4)$JU.(1"NB$''OG7M^+&">'3S`&D)[DTDJW5_I
M-]Q#U*.0SQ>S\M8/E28/,A"WP^KJ<*MV)$E:NQ/&>G$]O.8=1GW;_+V`L*6D
M^$2/2H%YN#$LK'L.I_,@1GE950BF=/1U\F':3-XJ"4&_T[/]@Y&]XEA;2Q!\
M^W*7#Y+T.<NM_H`XOI]Z\!!E)==6VLOZ!_^R)T%M(,Y_>@````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]C:2YP;F<`````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`R,B`Q,#4Q-30S,S<T-B`P,C,P,C$`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____F
M[>;O]>_<XMPHC2$VF2\VA3`ZBS1%I3Y$F#Y0KDI/I$E7L5!6K5`FAATB:1LR
MD"DH<2$J=",N>28O>R@^GS4Q?2HU@BTS@"PVA"Y`G#<XAS`[BS,\C30^CS9,
MJ4)"E#I'F3Y0K$9.J$9*G4)'DS].HD96L4U1IDE8LD]9LE!5J4Q:LE%6K$Y:
ML5%9KU!:L5)4HDQBMUI>KE=DM5PZB3'2V-'*T,G$RL/S^?+U^O3L\>O@Y=_-
MS<S,Q;_1RL38TLW/R<3GX=Q_-@#,5P',6@;,7`K/8A+,8Q;5:1G19QF421+4
M;"#7<BC<>3"Q9"KA@#G<?SOFAT'KCDGPE5'3@T?UFE?YH%[HEEG^J6KYIFC+
M5`#-5@/+5@/-7`W,7@[+7@^+00O/8A/4:B"=41K2;22F62+A?CB[;#/&=#O&
M=3OQDE#KDU/\HV3\I&7^IVCWH67WHV;^KG3,Q<#8T<S-QL'AVM7V\.S^_O[\
M_/SZ^OKY^?GX^/CU]?7R\O+N[N[KZ^OHZ.CDY.3AX>'>WM[;V]O8V-C6UM;4
MU-32TM+1T='0T-#.SL[-S<W,S,S___\`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````#M+@)\
M`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```*M)1$%4&--M
MRSL*PD`40-$W+S/F@RD40[01W((@N`!KM^5>;-R'8JD+,$136D@@F?=QM-5;
M'K@`/QG8P,*E;CAPL+^VHSRY($!BX^;D+(BBR6('"'/[Y+%8HZ19E+@ND!N4
M4AL\,)]3=/PA:Q\T6<*66'(T'8&%6(CJ=D;,)D@O@9B\GQ9!>-U+7U9AO/M"
M]1B$5(5N/A!1)<TJ"*`(LWQ)#2+3+C(O91'XTQOP4UL0N^LD70````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L
M86=S+V)T+G!N9P``````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R
M,#4P(#$P-3$U-#,S-S0V(#`R,S`S-``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````$@````P(
M`P```%C,'8X```,`4$Q410```/___[BSM=37V\3)R]'4U<W1TJBOL-G:VJ*C
MG[&MG;2LC;FQD\.^K<>D17U9`'Q8`,.+`<**`LF/!<>/"LJ2#<6/#8AC"LZ9
M&)!K$<^<'YIU&=VH)].A)\Z=)Z1^(=FG+^RX-:Z(*MZN.-VM.+B1,N*S0<.;
M.\.<.^BY2+N6/N[`4.V_4-"H1O+%5_'%5_7)7O7*7N6\6?G.9/C-9/3+9?K/
M://*9?O0:OO1:K:<7KRI>;>JB<R0!\F3%<20%LV7',&/&\Z8'\.2'\Z=++^3
M,>.R0-:H0.BX2,RC0\2B4KF83M/*MK:OH+NWKLJ6*^?.FKBKE/*O3,%=#9V&
M>L.KGZB=F/>"4,B\M[AL4;EE2>',Q=;&P=G*Q<<Y$-A((<!!'Z0Y&ZQ`(:]"
M([9&)KA(*+M**LI1+[Y-+,!.+<=1,,E3,>9J1LU?/MEE1?1U4.5T4L-C2-]^
M8>)_9.:);>V1>-B(<LJ`:]&&<.F8@N"4?>.7@M^7@]Z8A>>ACM*9B=B@D>2K
MFLB9B],T#<-,+L=.,-)5-<Q2,]=9.OQQ3^AI2?QR4.^!9/*%:.N%:^:?CN>G
ME\"/@ZR&?:F6D<$R$<]1-/IG1O)K3O9O4.Z*<Z.>G;68D]FYL^K8U][0T,'`
MP/___P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````&E?-AD````!8DM'1`"(!1U(````"7!(67,`
M``!(````2`!&R6L^````P4E$050(UV-@P`+X!:0U+/54)(2%G.5D%(/"@4("
MDJKFAFI2(HY6OO-]`DIG`(7$E8Q,-&5%!5V]_)CGS:TN``K)ZYKI*-C9B]GZ
M\\Z965F2!Q12M]!7<?#FXK8.98WMCVZ8"A0R-7!ST>*</)N)A6-";5%N%E#(
MV,/3AGU69'H36V-/5T=V!E!(VYTG+&32Q/KBOKJ8BO;,%*"0,E]@U)3"B*II
MW=/+REM2DX!"3L$)<<WQ-;V=^3EMK6G)B=B\`P`\Y3'DW(J8_@````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8VLN<&YG````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P-3`@,3`U,34T,S,W-#8@,#(S,#(T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____
MDCDZK7Z`8D%$FFIPFX.2SK?(E7V/4D!/JINIA6V&<5!WO:S!7%-?KJ.T:51_
MK*2XP+?29EN0E(J_95]_,R=U4$6'-BQX1CZ&3D:3C(:Z+29Y+B=Z,RQ_-2Y^
M.C.%.#)^/3:&/3:#0CR'24*22$*-2$*+.C5O3DB17UFE6%.0;VFT<&JS<VVW
M:F2G:&*C=&ZV=G"X=W&Y=6^V=6^U<VVQ=G"UA'Z[9V.3@GZM@GZL<F^3*2-X
M+BAZ+RE[,"I\,"I[,"M],BQ^,RV`,BQ\-"Y_-C""-C&!/3>'0#J+0CR.34>5
M44N95E"=6E2A0CYW7EBG8%NH5E&67%>>5$^04DZ.9%^K1T1Z6%.48UZG7EF=
M7UJ=7%B9:V:P:62K;FFR9&"A;VJQ;6BM<FVU:&.D:V:H;6BJ=G&X;FFK=W*X
M=G&V=W*U=&^P96&8?'B[>G:TA8&_9&&0C(C"@7ZT?'FH>'6B:F>.EY3&B(6R
M>7:>G)G)@7ZF85]\G9K(G)G$.#6`1T2,6%2>:VFE:F>??7J[@H"Y@7ZUB(:W
M<6^4>7>=I*+++2M^/#N&:FF36V&@S85[?UI5S:*<RWQSIG]ZW["JKEA1U7YW
MIV5?S7]XTX:`D%-/N6QGF$`^9BHJ____````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````6EW]
M_`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#!241!5`C7
M8V#``CCY:F<(\0KV.\G(J27&ZQH#A5@F3IDU=1(SJX13J'5)77$.4&C>[`G3
M)T^;RR366-H4KM?=#A02Y6*?R<\FT.#2$A*48E)@!13B$)&>(]S+S:/4')60
M999:!A2R:#405[3MD93J2#(RUX_L`@H5IFMZR-J[>_NUY6=GQFKW`85R@Y4=
M[=R\?`.K*Y)CPHK*@4+1*JZRSIX^6CJ&]95YEC8!0"%U>5D'!57_N`S3M)JJ
MS@@-;-X!`"R0,8U_VI,'`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]C;"YP;F<`````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,#0R,2`Q,#4Q-30S,S<T-B`P,C,P,C4`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!4````-
M"`,```!Q3-52````8%!,5$4``-H``/\Y.-XV-O][`(Q*1_]:6?_.``#I``#_
M``#G>7N$`(FE&(R$>?^]OL:UMO^]Q___C8O9VMG6V__O[^_O]_?W]^______
M__\```````````````````````````!8MVT8`````6)+1T0?!0T0O0````EP
M2%ES````2````$@`1LEK/@```$I)1$%4*,^URCD2@"`0!='^XB@ZKN!R_YN:
M4FCJ"[L:`&A2:4$VFRG<I0MU.8>J'JC;UKJ>R"1[OY)4U82W[N[37AH9/L3?
M:OS0/V&\#52*),M+`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8G<N<&YG
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P,S4@,3`U,34T
M,S,W-#8@,#(S,#0R`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@``
M`P!03%1%````____O.+U+YS,-)O+-)O*(&%^-Z34.)_.-YW,.)W+.Y[+0*;4
M1*_>0ZC70ZG71Z;1,G632*;13[+?4[;C3:G3.WZ</X6F18VO1Y"R8,'M3IB[
M:,SX9<3P4)N]5:/&6*7)8[G@7:S17J_3<<[Y59NZ;<7L=='[:[_E;+[C7J7&
M<,/H?-7^?=3]?=7]>]#X>]'X><[T?]#TB]3VD-O]<Z>_=*>_<Z:]>*S$=*>^
M>Z[%>:K`?*W#A+;.A[G/D\3;EL?=BK?+;(Z>D;S1HM+H?Z6VIM7JD[S.F<+5
MK]WRL=WRJ=/GI,W@LMWRL-OOIL_BEKK+J]/FN>#R+IS,+YW-,)W,-*+1.*'.
M)VV+0*S;/://4;KH5K[K3Z_81Y>Y5K3<8\GU3Z'$2)*R5JO/8[K?<M3^==7_
M;L?N<<OR=]7]=]/[=,OQ><?IAMG]A=7XB;#!03PY14`]:&-@>G5R,RTJ1#X[
M24-`2T5"4TU*6%)/5E!-6E118EQ9%@\,&1(/&Q01'A<4(QP9)A\<+28C,BLH
M-S`M2D5#%P\,1T$_5$Y,8%I88UU;8EQ:;VEG=G!N____````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````T*CMB`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;)
M:SX```"V241!5`C78V#``MC8Q+1,C!2%N%@Y^$1DU?5`0H*JQGD:HMPLG#S"
M4BHZ!D"AB*2<7+78<.80=MX8F;2L=*"04P!3H+.-F:F%K;V+IZ^W!U"HK;BH
MO+F^MKZIM:RZNZNS$"C4UUM1TM!>U]A26E734]E1`!0*\G&T-K>TLG-P\_+S
M=\]W!0IEQT>%!H=%1B>D9F:D)"?&`844!8`NX@>Z2-=04TE>6@(H!'>1OK:R
M@IRD.#;O```L>REZ0#K_.`````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]C;2YP;F<`````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,C`P-2`Q,#4Q-30S,S<T-B`P,C,P,C8`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___\Z;3L`2```1P``
M+0``+``#2P,#2@,%2@4)3`D-40T*-PH24Q(861@1/A$?8"`?7Q\91QDG9"<A
M4"$J62HX=#@X<S@R8C([:SM(@4A0B5!&=T97CE=>DUY9BEEDFF1DF61EF65H
MFVAJG6HP:R]!>D!FF&5XEVH4/0`5/@$9004<0PD@20U8>4AMC%XK4!A!8R_@
MY"'I[B_'RC#.T33S]S[;WS[Y_4KJ[4GZ_E#T^%"DI!NLK"&OKR.VMB:XN"CN
M[C6[NRJ^OBS#PR[`P"W&QS#)R3'.SC3+RS/0T#;U]4+5UCKY^4;<W#[AX4+Z
M^DWEY4;JZDGZ^D_\_%#N[DSQ\4[X^%'W]U'U]5#1P1#8R!WBTRO/PC7UYD;>
MT4+WZ4_TYE'MW3KKW4S*HP73A!#00@W;3!W'(@#,%@?*#0#+$`70&`W8(QCB
M+R;L/C7T3$+E3T;Y5TWQ5T[X6U'(``#'``"[`@#(`0''`0&]!`'+!P/*`P/(
M`P/)!06\!07`"0?("0G1"@K."@K,#0W($Q#9%!36%!3`%1+9&!C/&!C1'QWB
M(2'?(2'2'Q_B)B;E*RO**2?M+R_I+R_L-37O.CK@.#CS/C[V0D+W1D;Y2DK9
M0T'[3T_Z4%#U4%#J6%?___\`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````"5O-L[`````6)+1T0`
MB`4=2`````EP2%ES````2````$@`1LEK/@```)Y)1$%4&--MP=%M0C$,!=!K
MQW$>%+5B`R0D5F0I!F(%/BBMA%Y"[#@=H)P#_$/(M/LYG>OS6=?']6M7+@S:
MZ*%XJVTAHJUF,%1+S'5MK$0IYQ<82Q%+M3U^A93+<`CR\K)9OYV4G&?O8'SV
M3?>V9U9B,@L(NM\M4CD680H;`XS^T<=4T9R88X1#X#<WSIHE30_S`*.[":M*
MHH@9,?'&'RN!3RM6VIS+`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V-N+G!N
M9P``````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,C`U(#$P-3$U
M-#,S-S0V(#`R,S`S,``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X`
M``&`4$Q410```/___]4U-L<Z.[*7*I1Q$;N7,NFX6?:"5W\2`'\0`,TB"<P:
M`XL7"L\D$O]W:/=V9<P4!<X?#=0M'\P*`)T@&?UM9,P(`<P)`:<E(?%44-1+
M1O]O:LT!`,P``,P"`'\``,T!`<T"`<X#`\P#`]`%!<P%!=$'!\T)"<T-"=0*
M"M8-#<X.#=@0$,\2$ML4%-X8&-(8&.$='>0A(=0@']0D(.@F)J<;&^LK*]@G
M)[`A(>XO+[(C([DF)MTO+]TP+[PH*/(U-;\J*L0M+<$L+,<N+O4Z.LHP,,TR
M,>$X..$Y.-4V-=(T-,\S,_@^/OI"0MHZ.N=!0.`_/OQ&1N=!0>5"0OY*2NI&
M1L8[._]-3>Y)2>Q(2/]/3_Y04/),3/U14?9.3OM14?E04/%04/975_I>7OUD
M9/AE9?]J:O___P``````````````````````````````````````````````
M`````````````````````````````````````````(DS8M$````!8DM'1`"(
M!1U(````"7!(67,```!(````2`!&R6L^````GDE$050(UV-@P`(4.$4C9#B\
M#-7D5'6-'8-C@4)<K&P"J2'"FG+*VD;6_C%)0"%>%G:Q:$LA<44M`PN_R,0H
MH)"D-+^4'1^/K+J^F5M8?%P04(@Y(\734%`$8E!"J`]0*#TUT)1;'FI0.),[
M4"@MVE)'0@EJ4("'"U`HV5Y/10YFD*^S+5#($^XBH$&N#E9`(1,-F(O"O=V=
M;,RQ>0<`\/HCW.:+KT0`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+V)Y+G!N9P``````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#(V
M(#$P-3$U-#,S-S0V(#`R,S`T-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P``
M`%C,'8X```,`4$Q410```/___]0N,=4U-N$\/>=!0XDX.?J,C?":G`#,``/,
M`P7-!0W1#1#5$!W<'2'A(1NC&R&M(2*O(R_J+RBZ*#7O-2J[*B[%+C#&,#;1
M-330-$+V0D;Z1D+B0D;F1D_[3U#[4$[S3E#U4`7"``C%`PS'!QG1%"K>)BJR
M)C&]+3[K.C?',T+7/D[U2E#J3%7U40Z^!1#!"B.W$Z0E`:,E`:LM"J<P#;8[
M&,1-*Z-&+*U-,=)?/KE6.MML3<QF2=AO4;9&*LQS:+LO(L$V*LP``,<``,<!
M`,8``,@!`<<!`<X#`\@#`\8#`WT"`LL%!<H%!<@%!<<%!<P'!\T)"<@)"<X*
M"M8-#=`-#<D-#=,0$,H2$M84%'T,#-@8&,X8&,T8&.$='=P='7P0$.`A(=\A
M(=0@(,\?'^(F)M,G)^4K*YH='9`<'.XO+^DO+]@O+^TU->PU-<HP,.\Z.MTX
M.,XT-/,^/OI"0O5"0OA&1O=&1ML_/N)!0>%"0K@V-OE*2NI&1L,[._I-3?]/
M3^I)2>A(2/I/3_I04.Y,3/E04/%.3OA14?=14?104.U04,1%1?)75_%;6O5>
M7N5:6OAD9/-E9?II:?MJ:JY-3>9J:/9U=?5U=/M[>Z155=!O;____P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````*2E;I(````!8DM'1`"(!1U(````"7!(67,```!(
M````2`!&R6L^````KTE$0508TVW!S5G#,`P&X$^R']DR@4NA4S`2:W!A`<Y<
MF*&,T`FZ2,N!GT.=)@$22PS0OB]PAO`@>;W^W7_60:]*IS=/C*.N;N>O?AQ$
M<\G7`L;V_L[[[SJ$(CD7F1#Q2O;S44^MDZ*JRP1&M?G].,V:5%/VX0^,SA[K
MJ0\I95$>GQL(Z64SFC-38'8SWT706ZW.1"&PFYLC8F$_,+.D2$MKK8%A[D04
M)7!;S,UQP3]V0T[U_1"U30````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8V\N<&YG````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#(P,#0@,3`U,34T,S,W-#8@,#(S,#(W`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____H106
MI1D:HAD;KB0EJRLLNS0VD2\PG38XRD=)IST^ODE*L41%UEA:PU)3VF%CTEY@
M`2.%`2.$"BN+#2V)&#F7)T29*TNF*T2,,DN5/EVU.E2A36J_2&.R262S46V_
M9'W&!RA\"2I\#2Z!&#:%&CJ,+$N;*T)_-5&8/UZK,DJ(.%&11%Z@3VVW46RP
M5G*Y56^Q8V]^1E9H=H65=(&0@8^>@(V<BI:D.DM</$U>0%!A5&1U976&6VAU
M;WV+CYNG4F)QS:T`S*T#T;('S[(2V[T4Z,HFW<(O]=@ZX,<^_N-*\ME,_>-1
M\=A0U+]&S*L`?VL`S:T!S*P!SJT#T*\%S*P%S:T)U+,*UK8-SJ\-V+@0BW8*
MWKX8TK08E'\1X<$=Y,4AU+<?G8@9Z\PKV+PG[M`OIY(A\M,ULIPJX<8XTKDT
M^-H^^MU"NZ4R_-]&Y\Q!Y<M"Q[`[QK`[_^)-[M1)[-)(_^-/_N)0]MM.^^!1
M^=Y0]MQ7^N%>Z=)9_>1D_^=H]^!E_^=JQ`\`QA(#Q1<)SAP-V2L=S2T?HB4;
MK2XCYSXON34JQ#LPST(U\U!"Y%)&^%Q/\EQ0____````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````)/*2W0``
M``%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"=241!5!A798\Q
M$L(P#`0E68X)R80,#0V_X"6\AB_D=?D##7148;`5+*.DH,F5.W<[<P";(%SA
MV!_D-47Q515"/1!`UW3S%),P>^]W#@B:?:_I';_$S%5P`@S-XS1*UD*$1%1T
M01<Y_T48E]88`XEBJO%#J+DU=,])EQDY<L4$AOH85I%C$Y62GPBMJ)K8"*JE
M1(0A&T%>2;'>;?L'?OKY3"%5/U%U`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]B>BYP;F<`````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`U
M,"`Q,#4Q-30S,S<T-B`P,C,P-#(`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,`
M``!8S!V.```#`%!,5$4```#___^!)F&"*&.$+6:,,FR1075S-%V'17"13'F:
M4X"M9)-/%SV,-7"80'J:1'YK,5A]/6>J5X^W9YW&A;&"*6:15'Z\<*2Y<Z-Y
M'F*A3(NT:*"<48JP7)RX:*1[(6>&,G.LJZRKG_MD5LN`==R8C?4V*,P\+LP_
M,,XO)HM(/,]-/]5?4>M93=A'/J=C5>%01KEA5MQ83L1A5M)>4\QR9OAC6-5W
M:_YG7=I[;OYR9^YO9.9K8=]L8=]Z;?ET:.QP9>5T:>IB6<=Y;?)_=/]Y;O%X
M;>YW;.Q]<O:"=OV!=OMN9=1^<_&#>?:*?_J!>.F/A?V2B/^0A?>4BO^+A<]6
M3<);4LI02+)?5L][<?+&POH[--9%0-)$/[!,2+QF8.=;5])U;_9M:=1[=^2)
MA?>DH/X?''\T+]`R+LPV,LP].-A*1N$P+I1=6>Y34,=A7>%O:_I:6,Y34;MH
M9.5Y=O]X=?F"@/J/C].0DM6[O/:_P?:#AL*)CL>TN_QX@\US@,NBK?*3T9*3
MR9&LY:F;RYF8R96NV:O3_<_;_]>4S8R-S(.<S)3"^KG"\KNFYIF5S(J:QI%O
MFF;%];J[Y*V:NHO)S,>#CW.FLY%K;S595TAS9CFPHGBXK(N@E8"9=3JJAH;_
M__\`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#_;(+3`````6)+1T0`B`4=2`````EP2%ES````
M2````$@`1LEK/@```,%)1$%4"-=C8,`">'@$Q$0D9!3D)45Y^86$Q8%":3E%
M*67Q277UA='9N04EI4`AS7#_`/OREJ[.Q@H=4Q<O-Z"0GG>@JTK3E(G3IC>K
MFGM&V@*%G()]]6NZY\Z8-[^WTM+#P1@H%.1GK5W=KSASUM2>*CM'LS"@4("[
MKH9RZX39<R9W*%E9F(0"A7P,M=350MKZ)K5'.=M$&!D`A?)C,C/2LY(;:E,3
MBQ/RXF*!0FPL3,RL?%*R<M+<7)P<@NS8O`,`JFDR#,;OSH4`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V1E+G!N9P``````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`R,#,T(#$P-3$U-#,S-S0V(#`R,S`R,0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___]`U
M-L<Z.^=G:#H[.\:0`,>2!=.>$,V<&*R&(>RZ-=ZQ.,ZD-/?'1LB-`,F/`\J4
M!<B0"=&7#=RD'=^K(=*>'Z1\&^JS+Z^&([B0*+N0*L.:+M&D-?;!0N&U0N:W
M1OO(3_K+4/'$3L>:,/7$4,>$`,:%`\R*!\J,$M:5%.*C)K:%)MB@+\"/+>^S
M.LN8,]NG/OF_2NZW3/C!4>ZY4,@,`<<,`<X4"LD7#=DB&-,P)^4U*[XS+,DZ
M,?-'/M5".OI63>I12>A02/9:4?EK9,L``,<``*T!`,@#`ZT#`\\%!<P%!;('
M!\<)"=`-#=<0$`L!`;(2$KT4%-(8&-L='>,A(<\@(,HF)NDO+_$U-9,A(<8P
M,,(O+^$X.-(T-/5"0M@Z.OQ&1N)!0.1"0N5&1L<_/OY04/I/3_5.3O104.-*
M2ME,3/575^-14=E04+Y&1O5>7O1E9?YJ:A,*"A8-#1`*"B$8&#0K*R\G)T<^
M/C`J*E!(2%5-35E145!)26!966MD9&IJ:F5E95Y>7E=75U!04$]/3T9&1D)"
M0D%!03@X.#4U-3(R,B\O+R$A(1\?'QT='1D9&1@8&!$1$1`0$`T-#0D)"04%
M!0,#`____P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````+ZCH,8`
M```!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````M4E$0508TV7/
ML4T#01`%T#_S=P\P(!*@(PJ@"R,'!$@$2%`$<F`28OJ@#)"($"(Q3GQWOIW]
M2P%^'3Q@CP%XOGMD=YCGJSK5T(,#R_+D.:?YBZ+5!B3<_V0KV_B\_J`YS9#P
M?;%<K+>C\E<^FE$3'&^\^1NF(.D69=S!<:M^-Q6FS*YCO%88KC1*S=WIE-3>
M$S9CJ+E;HC<U"8:3JG8\G/8\MUB?:=,;+J,:+75,I1X,TN_^!__K3%8FB"AF
M+`````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O8W(N<&YG````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P
M-3`@,3`U,34T,S,W-#8@,#(S,#,S`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#
M````6,P=C@```P!03%1%````____`AI-!"I\"2^`.UN?2FRU/UJ50UV55W&I
M15>`77*?97JH@IC)"2]^%#J*'#^))4J8'#5I.%RH/%F3/5B05'6Z1V.>6GBW
M5&ZB36*+;8G$:(.Y5FJ4>9+&=HV\@IO.E:*[765UEZ2]F*2]H*S%K+C1<7F)
MN\??R-3KS]KQNL39T-GKHZ_%EI^PR];KS]KM<W54SL[*LK*O___\^_OX^/CU
M[N[KZ^OHWM[;U-31S<W*BXN)_?W[Z>GGS,S*EX]T[.OHHW]3I7U1V-31K&,[
MKW-<KU(^M$@[OC\UV;6R^M;3RC8NP#LSP3TVV$E!QTE"O44_MD,]N44_X%5.
MXEE2Y%I3Q4Y(Z&-<YV-<WV!9X&=AXFQFY7%KT&IDXGARXGESN&=BR)V:MI>5
MP:&?\<G'S*NIW;JX^M32[\S*[LS*MA40MA\9OB4>Q2LDQS4NN34OTD(\N3DU
MO3PWUD=`KCXYS4M%P$E$T51.SU--M$E$U5E3U%I4V5U7UUQ6Z&1>XV1>FD1`
MY69@RV%>Z79Q['ETZWETY7=R[']ZQFQH\(^+R9J8UZJHS*.AY+NYOB(?T**B
M_O[^_/S\]O;V\O+RY>7EY.3DX>'AV-C8TM+2T-#0S,S,Q\?'O+R\L+"P____
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````@L;W+0````%B2T=$`(@%'4@````)<$A9<P``
M`$@```!(`$;):SX```#!241!5!C39<]12@)1%`;@__SWSBA,TC#YDB*2"B6!
MFY`VXJ9<D$\]"NH(6AF"@3"FB8HY]UP7X+>##[@A(&(3NBS2@T3D/EX+&D%!
M[84G1PI%@J%%Y11Y:S9)[KU7%<+BK2B3YF='S<?K=]ND_MWB'(RK@_]5R^6C
MPDCJ4Q"EM);F.VWQ)6P_-U1`N*=)/4SL%Q?&N-F\"8O5HCON!CG3\O)'[W4#
M09^$5U7UI#4B/<'C[]T^_GL@LR3SB=L>;S^X`I[D3+>)Z+3W`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]C=2YP;F<`````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`U,"`Q,#4Q-30S,S<T-B`P,C,P,S8`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____Z
M9VCW;6Z_6USQ@H/RW=Z^'"B['2NR(CS+L;BH56UI%#=+`B^7:I=2`&$_$(\L
M"J-H7JP$`7AW=KJ`?\6+BM*GIO:<F^8``,8#`\L%!<H%!<<&!\D&!L0+"\D-
M#=$/$,P0$-,6%](8&,T='=L?(-<A(=\9&9TG)]X=':`O+^@D):PR,N4U->TK
M++@Z.^PP,,4X.-TV-=`R,L-"0O0X.,U$1?(Y.<U&1O<Z.\-,3/=&1N104/I/
M3_E(2>)'1^!14?=04/-24O%65OE34_%75_%J:OI24K]45,%75\!=7<EK:]1H
M:,EN;LM\?.*,C.]\?-2#@]R5E?2+B^&4E.Z<G/";F^ZFIO.IJ=*VMMZMK<ZC
MH\+5U?G.SO&JJL.OK\BYN=+'Q]_5U>S@X/;%Q=C@X/76UNH#"<R-CJO$Q>R8
MF;?1TO>^O^!E:\F@I?2?H<J:ILRIL\_4U,W.SLC-S<?,S,;___GX^/+KZ^7H
MZ.+>WMC^_OG]_?C[^_;U]?#N[NG@X-O;V];8V-/$Q,"YN;7R\N[1T<W/S\O]
M[>;'BX3H?G?/(AQ_``#$"0F)"@K*$1'2(""C(2'1+"S=,"^R*BKA.#C?.#CM
M4%#C4U/+5E;?8%_L:6CK=W;VV=GL[.S,S,S___\`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````##5`+[
M`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```,%)1$%4"-=C
M8,`">(4UK-S=C%1D)*65U/4L;8%"O3Q"^6%!OEX>GMX^_@'!H4"A_JG=G?.;
M2\I*BZLK*\KK&H!"DV8QS>$JBH]/2$Q*3DE+3P4*L<R;.YU=0%9>6=/`VL75
MP0(HQ,HV>V(?OY2"JK:IG9.-L2%0B'GFY`G<>7Z!(>'B$1)BHB)`H1E3>KH6
MM#=5U=?4MC5VM+0"A:9Q\!461$9EY<3&Y4;'9&<"A3@%,^04U73-'9WMS4ST
M=;2P>0<`8#8RK_S]W%@`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L
M86=S+V1K+G!N9P``````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R
M,#0R(#$P-3$U-#,S-S0V(#`R,S`R-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````$@````P(
M`P```%C,'8X```,`4$Q410```/___]$1$N@O,/]N;_UN;\>[O,K%Q/_Y^.?A
MX,T!`,P``'\``,T!`<P!`<X#`\P#`]`%!<P%!<T)"=0*"M8-#=@0$(L*"L\2
M$LX5%=X8&-X:&=(8&)01$>$='=L>'N0A(=0@'YT9&>@F)J<;&^LK*[`A(>XO
M+[(C([DF)MTP+[PH*/(U-;\J*L0M+<<N+O4Z.M@S,\HP,+(J*J<H*.LY.>$X
M.-4V-=(T-,\S,_@^/OI"0KLR,O5#0^`_/OQ&1L$V-N5"0OY*2LT]/.I&1L8[
M._]-3?A+2^Y)2?]/3_Y04/),3/U14?9.3N!'1]I%1?M14?E04/Y34_%04/)5
M5?%45/]:6OU:6NY55>Q45/M=7=1.3NE96?UD9/=E9<Q>7LY?7]1L;-MQ<=1P
M<.1\?.&`@.Z)B<R$A-"'A]:.CLR)B=VBHNRRLOK"PO_)R="_O]C)R>35U?+C
MX^'3T_SN[N78V-+&QO[Q\?;IZ?_S\\S"PM;.SN':VM7/S]3.SOKT]/GS\_CR
M\N[HZ.KDY-+-S<[*RLW*RO;V]N?GY^'AX=C8V-'1T<_/S\W-S<S,S/___P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````)?.P\H````!8DM'1`"(!1U(````"7!(67,`
M``!(````2`!&R6L^````NTE$050(UV-@P`)X>)1<\]I3982X!<44=.R]0$*R
M-G&Y'8G"W/RB<NK6GH%`(7'CF-B<K@0^7A$I52NW``^@D$DT2VAV3SP7DSRS
M;5!XB!]0B*VRHKBEKRJ_H+"HI+RBM`PHU%C/6=?6UUI=TU3/T=!<RPX48HTT
ME,SJ398V=0^+BO!W=@`*!6M)"*1W)RD;./EXVUGJ:0*%S(`NRNA*`;K(U]%"
M7UL-**0(=%%F9QK012[F1KH:*MB\`P`ODBO+(AL_)0````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8W8N<&YG````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P-#8@,3`U,34T,S,W-#8@,#(S,#0T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____
MQ;BZP[F[Y=G<]^ONV,W0U,G,ZM_BXM?:]>KMLJBKO;.VR+[!\NCK\>?JZ=_B
MP[:Z\N7I\>7IS<+&Q[F_P+.\S\++P+*\;VMN,"MF0SV)5D^H=&ZY:F6?=G6`
M.#*2.S62.S61)2%:/SB7/3:2/C>30#F5/SF30#F3/3>,1#Z90CR41#Z71T&;
M2T6@2D2>0CV(44ND3DB<-S-N4DR?5U&H0CU^7%6O5$Z@6E2L/SMW2D:(1D*`
M8EVS9V&W4TZ3:V6[;FB^6U:=44V,44V*8EVF=&[":62P>'+%:V:P6E:4?WG-
M?'?)>W;'<6RV=G&^8U^>@7O+?WG'>G7!@GW,@WW,>72^@7S*@WW*@7S(;FJK
MA8#'?7B[<&RG@7R]BX;,@WZ_D8S3CXO1D(O-E9#375M]14*:3TRE5E.C8E^S
M6%6@4$Z+65>6=''"@7W1:6:J<6ZV@X#/:6>CBH?2AH/,AH/+G)G98V)^961]
M85^@552+>':\>':[BHC3B(;,6EE^=W:<C8VDB8F7U\Z=T,62A(%QP[B,YMNO
MQ;R>O+"=RKVKVL_%Y%LUTE@SQT`?UTLNR5M%QS<<QC4<S3XDO5,_\V]6U61.
M^GQDZG1>Z'-=]GYG^(QX____````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````0$HC
M-0````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"_241!5`C7
M8V#``I25K0-38SR,-934#:P<_<)`0B;>*0G^ECI*:GHR]IZA44`A*=?$Y``S
M7455;2,[]Z#(<*"0;712O)RDH9:*OH63;T2(%U"HN+R^6;XZK2(C*Z^HKK2F
M`"C$S]?2*2C!U-W*(L0JS"G"#!2:,ZNO?_*D*1-ZI\V8/7/ZQ*E`(0'V]BXQ
M4?&>#BXN#C9>'FZ@4&%F>D-E=F-3?DE9;4%5;@Y0R%130=JE+2[6)UC6S=G!
MQAR;=P"-<#"X594-W0````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]E8RYP;F<`````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,C`T,R`Q,#4Q-30S,S<T-B`P,C,P,C``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!(````,
M"`,```!8S!V.```#`%!,5$4```#____Y4%&]``["!1.^!13$&"6E(2NQ*#.\
M+SG'-#_5.$350DUC76`@$L$X+;E<4.1<4=T0`[TQ)ZT\,,X^-,-)/]4'`,1E
M9.-L:=4!`<P)"<P-#<XB(M(G)]@K+,(R,LPS,\8Z.MHY.-%$0^))2>Y(2.Q)
M2.904/E@8/9D9/UH:/1KK+-FOKD^E8%`>6B9FYIB@VJ3FI0[3CI:;D]E<5U=
M9%A(3$6NP7^DM'BXPWYH<AQ26">(CR?,R@#.S03-RPK6U0W4TB"GIR'=W"_K
MZ3S@X#[GY4'^_DIU=2/R\DS]_5'Q\5#4U$;__FB)B$',Q@!_>P#0R07,Q@78
MTA"+APK2S1B4D!'AW!WDWB&=F1GNZ"_AW2R3D1[R[#6RKBJRKRKAW#CX\S[Z
M]$*]NC*[MS+\]T:3D"O&PCO_^4WNZ4GKYDC_^4_^^5#[]E'Y]%"GI3>5DC'V
M\5>GHS[Z]E[IY%G]^&3W\V7_^FJQKE3*QV?`NUO#OV.JIE?3SW#<UW75T7?@
MW(B,A".2CE*@E"UI94*HGH*3=%B`>W><?FW4AU[(52B3AX/G:U*EAH3P2D:"
M;6S,``#-`P/-"0G6#0W&&AG@'1W4(!^G&QNR(R/N,#"_*BK*,##5-C7J1D;U
M5%+___\`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````8\JE-`````6)+1T0`B`4=2`````EP2%ES
M````2````$@`1LEK/@```+Q)1$%4&!EEC[T.`5$0A>?._;$BV$0A(DJ54C3>
M0J>F\1:>010:3^(]5B-!1\-6R^[>N3-N[U0G7[[B'("_*%A`LY/6>1$"HK5)
M8V\`7*M+F6=6V$?K$`R8))7O2`_QE9-SZ"-ZESF7@VOFW3336BBBN1%?GDN2
MNC>SPN&D8,*^XB%3D/:]*\0W!`FUB"R6=B42?&#0X*LBJ(<;3ZK+,W;Z*FAY
M8;7[$"J]Y>A7"@X4%Z$ITO4Q`I;-WQV`'\RX8Z"M@%J$`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V-Y+G!N9P``````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#0V(#$P-3$U-#,S-S0V(#`R,S`T
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/__
M_^WK[?S[_/OZ^_CW^-[=WLW,S<G(R<K*RZRLK=S>X/K\_=#2T^CK[,_3U,?+
MS,_4U/?\_-/8V,G-S<_2TO'S\_K[^_GZ^OCY^?;W]^GJZM#1T>OS\:[$M;G`
MN[C/OH.GB;O!O*C)J:W#K<'5P?+V\LW0S?7V]?3U].WN[>+CXM76U<;'QM':
MT/?W]N'AX,G)R+&<A>SGX\C`N\-*!K](!K]*"L)\5-*7=\>:?];$NMC.R,%)
M",-)"<E4%]EV1<=P0<)M0=F"5]^;><2+;>BKC<BFE=O!L^3+OLM*$-&;@>[*
MN?/N[/7O[=W:V>WKZ_OZ^LC'Q\?&QOO[^_KZ^OGY^?CX^/7U]?3T]//S\_+R
M\O'Q\>[N[NWM[>KJZNCHZ.;FYN7EY>+BXN'AX>#@X-W=W=S<W-O;V]C8V-/3
MT]'1T=#0T,[.SLW-S<O+R\K*RLG)R<C(R,?'Q\;&QL/#P\#`P+Z^OKN[N[BX
MN+:VMJ^OKZZNKJ2DI)J:FI"0D(B(B'U]?7Q\?/___P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````%/-
M')H````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````OTE$050(
MUV-@P`(:F^I*0Z+3<HN*\[-2X\)#@$)-]951&LFB1<5%O-S2$:$10*&&FJ1P
M/F$3`1%!&T]?<?UXH%"MC'B`M;N3A96EBX^$9&PZ4*@T4,S?T<S<U,O!6"@T
M)B47*!09H<WO:F=K[^SFQQ.9E*,+%`I+R.)4,O+VT)-EEHK7,2P'"FEE%G#(
M*\HI**N%QF;DEU4!A=+RBDO8U554-5EB#')+*[F`0CE%084Y;$RLS)&)V<$5
MU;78O`,`PW<M'60!@$X`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M9FQA9W,O8WHN<&YG````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#(P-#<@,3`U,34T,S,W-#8@,#(S,#4Q`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````2````
M#`@#````6,P=C@```P!03%1%````____Q@`#V2@II0,9HPXJ<PA`;1%2:1)0
M-A!P-11UU]?8!0V665_"!1"5#!:3,#FN``A=#A=B$1IQ)C&C4%O&`!2@`16=
M"1N;#1^?"A9J$B6E&"NJ&"FA)SBJ(2V%,$"O*C:..$BX.$BV05"[.T>B2%C"
M1E2P5V;,2UBM7FS19'+5:'789G/2:GC8=(#94U=TK[7=#"">'S&F4&#'8FND
MY^GS>8>_L+3%QL?'X.#?S<W,\N?FS@,#T`4%S@<'SPT-U!`0VQ04WA@8VQT=
MWB$AHQL;XB8FYBLKJR$AZ"\OKB,CM28FMR@H[#4UNBHJO2PLPRXNP"TM[SHZ
MR#(QQ3`PZCLZSC0TRC,S\CX^T#8U]$)"U3HZ]D9&VS\^Q3DYX$)"^$I*T#\_
MY49&^4U-]$U-Z4E)^4]/^5!0\4Y.[4Q,^%%1]%!0]E%1Y$]/^5E9]%I:Y-G9
MY=O;_O3T_/+R]NSLV,_/TLG)_O[^_?W]_/S\^_O[^OKZ^?GY^/CX]O;V]?7U
M\O+R[N[NZ^OKZ.CHY^?GY.3DX>'AWM[>V]O;V-C8UM;6U-34TM+2T='1T-#0
MSL[.S<W-S,S,G9V=____````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````?!^P8@````%B2T=$`(@%'4@````)<$A9
M<P```$@```!(`$;):SX```#`241!5`C78V#``H0,)ELRUK?W3IK4W]766%4!
M%!(4-C6K:>V9.&E"=WM3#6,M4$A*D5??D'O"I(D]'<UUC-5-0"%Y=1U1`4T+
MZ[[.EH:*RD8KH)"JGH:R+(^1>5FA34EQ:5$Y4$A72\580HR/G3DL-;\@+RD>
M**2M)B<ISLGJ[!&9DIL6$Q(`%#)1D.9GLW=R#T[,SHJ+"/(!"BG)<+'8.;KZ
MQ69D)H0'^GH"A40XF&P=7+RBTW.2HT+]O=VP>0<`%N@P8AS$_&@`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]E92YP;F<`````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`T-B`Q,#4Q-30S,S<T-B`P,C,P
M,C4`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#_
M__\[.CLV-39K:VSBXN/'Q\A,3E,B)"@Q,S=`0D925%AI:V\"!0H)#!$G*B\[
M/D,0-6<:5J4;5Z@1-FD:4IT:4IP>6JH?6JD?6:8C7:HB6J,H8[(E6J`J9+(:
M/6TB27TP9J\P9JXW<+XZ<[\W;;0J4(1"=[T];:Y)@<U-A,TZ8)%.?\%;D=H%
M"`Q5A\M%;:->D]E7B,E,=:QFFN!GF=UFF-MCD]1=BL=<B<5FE=)LF==RH=YJ
MDL9YI-YVH-A]J.(4%QL6&1U-4%1255E'2DT?(""RL[/L[>SAXN'4U=0Z.CE!
M04#5U=3,S,MF967^_O[\_/SZ^OKY^?GV]O;R\O+N[N[L[.SJZNKEY>7DY.3B
MXN+AX>'8V-C6UM;5U=72TM+0T-#.SL[-S<W,S,S*RLK'Q\?`P,"_O[^]O;V\
MO+RXN+BUM;6PL+"KJZNGIZ=J:FI>7EY:6EI75U=65E9145%04%!/3T].3DY'
M1T=&1D9"0D(X.#@U-34T-#0S,S,P,#`O+R\B(B(A(2$='1T8&!@7%Q<4%!00
M$!`-#0T,#`P)"0D%!04#`P/___\`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````"3
M<A_J`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+])1$%4
M"-=C8,`"!`75C!VL=90DA23D5+0,38%"(@H&=C9&JE+"XC+*FKHF9D`A>6U;
M>TL-63%1:45U?7,K"Z`0ARL/-Z>C'B^?$[\`NXLS%U"(J:"XIK6'H:>CN;:J
MK**Z#BCD7^CCULW0V]G26%U>5L7<`!1B*6MHZ^IJ;ZJM+"DJK?:N!PIY^F5F
M9V>RQ;.&>T0GIN?D`85B$E)2$F.C0@,#0B(3TK)R@4)>R2E)<3%A08S!$;ZI
M&>[YV+P#`*OP+E6+7MT$`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V9L86=S+V5G+G!N9P``````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`R,#0U(#$P-3$U-#,S-S0V(#`R,S`R-@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$@``
M``P(`P```%C,'8X```,`4$Q410```/___\,8&L49&H<9&L:^O]7.SUE96S8V
M-\+"Q49'2?7V^&AI:L?*S.SP\O?Y^LG+S,/%QB(C(_?Z^O'T],[1T<W0T/O]
M_?K\_.'CX]W?WQ\@'\C)R,;&M38V-4U-3$='1EI:6<G(P=_;Q-/%A<JY<^WK
MXM/'FM.T5-[$<^#1GNOAP,O#J<O#OL:^N\<``'T``'P``,@#`\L%!<@%!<@)
M"=`-#=,0$,X8&)`1$=P='>`A(<\?'\LA(9H9&<8C(^DO+]4N+NTU-=TX./5"
M0K@R,OA&1M$[.^)!0<,[._I/3_M04/504*PY.?!34_)75_5>7O=A8>A<7.5;
M6_1E9/-E9?MJ:N-I:?9U=>+:VJ2>GM?0T,G"POCQ\>_HZ.WFYMO5U=#*ROKT
M].SFYL3#P_S\_/?W]_;V]O7U]?+R\N?GY^7EY>3DY./CX]+2TM'1T<[.SLK*
MRL3$Q,'!P;JZNFYN;FQL;&AH:%!04$]/3TY.3D9&1D)"0C\_/S@X.#4U-30T
M-#(R,C`P,"\O+RXN+BHJ*BDI*2@H*"4E)2,C(R$A(1T='1L;&Q@8&!`0$`T-
M#0D)"04%!0,#`____P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````.'#6W(````!8DM'1`"(!1U(````"7!(
M67,```!(````2`!&R6L^````ODE$0508TVW,/0X!01C&\?=K=K%V61$G4"J<
MA42<0:/3<0$5O4AT&H6$.RA4M"J)1NMK[(PQ/?_RR9,?P$\(38RC6-_N)A.1
M4-2&`'-A\:VUS9A9D2`0'*H59L?[8Q0E25P(0*`3(K[RRX;;M94#0F^E@0W,
MLYQS[JJ44>;J7RX@GI<,$K:(9>4M#.5!^N$P,R)*NGY*UFF]-KR<3Y=>LHU6
M>6^-2M*?6',WEDB$>4`PX_[T8[7]`"X(QP1_^@+WLCVD+2_5H`````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O9'HN<&YG````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P-#(@,3`U,34T,S,W-#8@,#(S
M,#0U`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````
M____[D=(^.;HU,K+U=35^?__^/S\P<+"LK.SLL_&V>GCP<G$]?OW#7D@!6H2
M(',C2IQ-`%T``%P``#D``UX#!6`%!5\%"6$)#6<-#60-$&P0"D0*$F<2&&P8
M$4P1'74=(7LA'W0?'W,@'W$?&549)W<G+X4O(5TA*F<J.(8X.(4X.(,X,G`R
M08Q!.GH[.WD[2)-(2))(4)E01H9&5Y]75YY77J1>69I99*ED9:=E:*MH:JUJ
M`F(!)74D*'@G,($O,'XO08M`9J=E#F$'%%T)(V@8&5D*)%\3488^X.#?U=74
MS<W,TM#,94,283X-:3`!9BT`92T#[^3>V+6GDC84KD<LM&UAYK:NJ8N&Q*^K
M_??VG1@&^>CFJ1`#QY60I!0*XK>TS```S`4%XEE8Y^7EWMS<SLW-_O[^_?W]
M_/S\^_O[^OKZ^?GY^/CX]O;V]?7U\O+R[N[NZ^OKZNKJY>7EY.3DX>'AVMK:
MV-C8UM;6TM+2T-#0S\_/S,S,RLK*Q\?'Q,3$O[^_O+R\N;FYL+"PIZ>G____
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MSJ@6M@````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"[241!
M5`C78V#``D1$5/5MS'0$>.IJ*LL*LS)`0O*Z5N9Z2AY1Z57E13F,N4`A&4T+
M2T-[_YAPEK3B/,;L(J"0AHFUL8-?G#N7;VI!1F:A%U#(P,94RRTYD#\R)9$]
M([^T&BCD;.ZD[)H4Q!?/%,&66\):#Q2R-%*3L@U(L.-F!AI4X<,!%#)VE!45
M<@D-"XD%&E3;V`(4TI83%Q:35O0,C@8:U-#<"A12D1`6E510%^3-+?&N;^)L
MP^8=`$]6*V>7%)I^`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]F;&%G<R]E<BYP;F<`````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,C`U,"`Q,#4Q-30S,S<T-B`P,C,P,S4`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!(`
M```,"`,```!8S!V.```#`%!,5$4```#___^6,32L4%3(=GNY<GJ76&)W36Z5
M=)2GBZF'<9!@;::#DLJ!DL9A=:9=>[4_6HQ/<*I&891(9)=,:)U.:Y]0;:)6
M<ZI8=:Q??K9ZG^%[H.!PD,I[G-E>A\U3<ZEEB<5JC<E6?;EKF>!SG=U/F2M7
MF3A=FSYKJTPH<P`J=P-BISYWL%<R=`4X?0U`@!AKIT)SL$UVL$]WKU$N<``R
M<P4]?A!)B!U-C"%:F"]?G#5OJD9NI$EWL%!VK5!ZKE%+@1@]<`J5MFJ/FTQ?
M8`UQ:R-]=C1^<CV[:@K">B/&@2NA>$7SMFZK=T"Z6P>Y70?QK6RY7Q+,>S7K
MH&*%/PF]8!G'@DO4?46N;T>X2`JY21&\4!MU/!_:?4_/;4"V/`JU/@S<>%#D
M@U[:@F#/<U:\1"+!33"V6$+KAFRS*`RG*`SF@VW50RKE6D+'3SJ@0S+O9U!N
M%0>[)0VP(@^T)Q#',1J^,1W%-R3#.R6Z-B3'/"G,02W)13+323763CO+4T/B
M8$[J:%3J:UCA=V>W&@:]'@IO%`BU(`ZS(A"Y)!*U)!&Z*1:\+!I['A+&,2&[
M,B&$)1F5-BK=4D'=6TK964OK:UO<:5K@;V+I>FYT$0BT(!'`(Q6Z)QKM7U/=
M9UOJ>&^N0SS`3DG___\`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````U>K_`````6)+1T0`B`4=2`````EP
M2%ES````2````$@`1LEK/@```,%)1$%4"-=C8,`"9A;&N#OIJ.F;FNB:65A9
MVP*%VB8LF-\<X>JHJ:5G;FE@9`<4ZLU/SDBLF9,5XN*@JFUH;`,4FA@6,"\H
MM*-]=E^:K[.]ACI0*-TG*2[5([.KK'K2W*DIWFY`H>S@<,\HOY*>JKJ&IL;)
M"]F`0C-BO0+]([O+:W,+IK-R\0D"A:;E12?$=Y;F3&'AY%50DA<!"M57SFII
M[6?FX)%64>07%Q4""E44%3.Q<\LI2\G*2$J("0M@\PX`&R8R\65"/?4`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V5S+G!N9P``````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#4P(#$P-3$U-#,S-S0V(#`R
M,S`S-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410``
M`/___WM=8(=I=ZJX*+3#*][H)N_U.M'9,\K/,_C^2LC*`,K,`\S.!];8%.+E
M)N;H*[6Y)LS.+<#$+>_R.MO@/MS>/OG[2NWR3/C]4?CZ4>WQ4-'31OG[9/G\
M:/3V9?K\;<?$`<?%`<K*!<W,"M#/#<G'#=/3$+Z^%-G9&-C6&-O<'=_?(>7C
M*^GI+Z2E(>SM-;Z^+,;',*ZL*LG),<[.-//T/O+P/M#0-O7U0M76.O?W1N'A
M0L/#._K[3>7E1OGX3>KH2>KJ2?KZ3_KZ4.[O3/'Q3O;W4?3T4/;U4>7D6=+2
M5N_O;(B&"O/P8^7=3>GB9I^7/*66#J*/%Z&%)8QL$<&J<[231;J,-;J,3L-_
M/,R:;\!7!L9;!]AQ(XY+&:I;(>F!-<%M+MM^.-Z%0O>74,13`M)A$(]-'K5A
M*,QQ-/6,1LE?&>^.3JI7*8UE4O>"7L4K`'L;`,<N`\8R"<\W#8\M$=I&'<Y&
M'^A8+_1I0K=/,N)D0?ET3_1T4/2&99561&PY+\@``,<``'T``'P``,H#`\L%
M!<@%!<@)"=(-#=,0$,X8&-P='>`A(=$@'YH9&:0;&^LO+Z\C(^TU-;LJ*L<P
M,-TX.-$V-?9"0OA&1N9&1L,[._M/3_Q04/504/)75_MJ:O___P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`("DJ@@````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````P4E$
M050(UV-@P`):6B?,6;A@>D]'<WMWWY19\X!"1675]04U%26%Q:7EE56U=4`A
M7V,O'V\A-44E%2U=<P=/1Z"0OHQ<6'X(#S<O'[^(N)2K&%#(5B$@JB%00UE=
MQ\#:Q<W&%"@D[Q>=Q\0<KJJM9^GL86]A!!22]8_,:(R/T!0PLW-WLC(Q!`I)
M<[`$A0:SLK%S24J(<@H+`H62<V+28M/C$K-3<U.RDC(3@$+]G4UM7;V39LZ=
M/WO&M*F3)V+S#@`?93+Q[FZ`R0````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O9FQA9W,O9FDN<&YG````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#(P-#4@,3`U,34T,S,W-#8@,#(S,#,Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````2
M````#`@#````6,P=C@```P!03%1%````____S<S.P<'&Q<7)\?'T[^_QQL;(
M^_O\\O+S[^_PW=W>VMK;S<W.PL+#M[>X!1%A$!MK(2QY-3^*.$*%-#U[1E"9
M0DN,.T)Z4%J?3E>:5V">:G*M>G^BDYBZFIZYJJ[+!Q5E'2MX'2MW-D%_04R-
M4%R>5V*@7FFF9G"I?H>Z9FV5A(JL;'"(L+74IZS)LK?5O<';!15C"QMF#1QK
M$!]M%"-L&2AM'"EO("]W'RUS("US)S1Y*#5Y+3R#+SZ(*CAY,#QW.TJ/0E"7
M.$1^/DJ(04Z+0D^,1E*13UR@4%N07VJA55^-<GVR>(.VAY&_HZG)EINS!!9C
M!!9B!QAE"1ME#!UG#!QE#R%L&RMQ5V2=35B$:'6L7FF8=8&V;7BI;WJKM;?`
MSM#9O\')W-[FY.;NO\#$PL/&^OO\LK.SU-74U=74_O[^_?W]_/S\^_O[^OKZ
M^?GY^/CX]O;V\O+R[N[NZ^OKZNKJZ>GIY>7EY.3DX>'AWM[>V-C8UM;6U-34
MTM+2T-#0SL[.S<W-S,S,RLK*Q\?'O[^_O+R\N[N[LK*RL+"PIZ>GG9V=E)24
MBXN+?W]_____````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````5;*NOP````%B2T=$`(@%'4@````)
M<$A9<P```$@```!(`$;):SX```"^241!5`C78V#``B9,Z$W74G=/;FEIK*TJ
MR<L!"?5ULOJJ.B2V--55EQ8P%@*%^KLJ<KUMS-.:ZVO*BACS2X%"NH&&^JYF
MX=JR.G(!>@8*\D`A"1EID<C08`%!(6$Q22EQ4:"0IH:J55A0B(F2O;.GFH>*
M(U#(/][+Q=@HPBTJ)LXO(=8G&BC$Q</$;*%HF<3)D<'&S<O'#Q2J;FAAMS:U
M2\G+*:YL:.OH!@IE-;>PV"H[I3(6EF>WMF?V8/,.`/"?+U[D(@)-`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]E="YP;F<`````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`S,B`Q,#4Q-30S,S<T-B`P
M,C,P,S<`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4`
M``#____A(23Y45;*25K47&U=:XR`FL`4>+@GB<4,=*@YF<L0=J97KM`CBZ]A
MMM)>K\,VAY-EN\@-<7T4<G`YBXIFL+!`BX9$CHF-R[AJK)59FWUMKX=9F7!V
MKX-AG&X`6Q`)8!9AG&EMIW8=="0M>"\Z>#L`6@``.```-P`#7`,%7@4%704-
M90T0:!`8:A@121$=<ATA=R$?;Q\94QDO@R\UB#4X@CA"DD(R;C)&ED9!B4%/
MG$]0G5!0FE!7G%=>HEYEI65JJVIDG&2(P8@N:"I3GDU7GU%>FUEIJ60/10HR
M@BM%DCY/DTA/E$ESJ6Q\LW64G"'&SR_<YCK)TC[D[TK;Y$SE[U';Y%#`R4;I
M\FCW_E;*S0SEYT'HZD;Z_$[X^E[,RP'-S`[2TAK4U2#7UBC!P"S,RS+)RC'A
MX3C2TC74U#;9V#KEY4/'QCON[$GKZDG^_E#V]D[Y^5#Z^5+V]E?[^F7W]V;_
M_VK,,`#=6"_@9#[R<TSQ=E#,,0///A*Y2";$4"W/5S.],QKF=F?,``#.`P/0
M!07,!07-"0G6#0W8$!#2&!CA'1W4(!^G&QNP(2'N+R^R(R.\*"B_*BK'+B[*
M,##A.#C5-C72-#3Z0D+E0D+J1D;_3T_V3D[Y4%#___\`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#GP_ZF`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+-)
M1$%4&--MP4U.`D$0!M"OJ@N;&=`1$A>@F+A!EU[)*W@%#L"!7)IX!O9N6!A)
M",+873\<0-\#_B`\8;R_L[ZW*DE$TKN`\N#65??1<DK,!,%#322;W9'SY)$*
M90AR1U[N/V_\NQGR*!R"16N'\M'QQ>0PGE(U,)KMMOY:>:X:RE_N8,3UT`>7
M1DMM9WJE#D&6+NK+ZHW+:Y]S!`3S'[5&U,GGYNH&P<F,$J^;Q&8>$?C'&9V6
M4*IQ1UZL`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V9L86=S+V9J+G!N9P``````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`R,#4P(#$P-3$U-#,S-S0V(#`R,S`R-@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M$@````P(`P```%C,'8X```,`4$Q410```/___YV+D:Z3GJ>.F=[%TI6*D&),
M6;BHLYM_DXII@K^PO*";H&=<:,NZS;^TQ8!ICM''WGYWGZFARW)PBYN:QVIK
MB%)6E5):F7%_L[3(U&63JJ_/WZO0X6F;L&J:KVR=L7>CMG&<K;#0W;#!R'BS
MR'"EN&N>L&V>L(>_TW*@L(6YS':DM9?-X8R\S7&7I7.8I9W.X'>;J)K(V)S*
MVJ?4Y*;3XX2FLZO7YWZ=J:G2XIB]RY6LM7"NPVJCMFR?L&R>KW&EMF^CLVZB
MLFZ@L7:JNW.EM7"@L(&SQ'NKNI''V'^OOG"9IX6UQ82TQ&6(E(JYR)#`T&Z3
MGY"_SGNCL(2NO)7$TWJ@K7B>JH:OO8&HM7ZEL9_/WH>MNJ32X9?!SHNQOJG6
MY)W&TZS8YJ#)UJ_9YZ?0W:;.V[7<Z;3'S6N@L'NSQ':HMWNIMWZLNH6SP(&M
MNFV1G("JMHRWPZ?8YY*]RJG8YJK8YFZCL:[,U)RLKM#>W;"TG\K-J\.I7[NX
ML>&E0.ZQ3;VZMMNJ:]C(M,Y[+^>>8JNFH\>LI.JDD^>*=NJ6A.*@D[M'--!?
M2_6`:^I_:L)M7N^*>=^$<Y1B6>:KH*E72NQ];>R$=-=X:;F&?_>WKK]'.($P
M)L:+B'5*2+1Z>,6DH____P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````.H\7=L````!8DM'1`"(!1U(````
M"7!(67,```!(````2`!&R6L^````P4E$050(UV-@P`+8><4F"O+Q2\H[JZEJ
MZI:D`H7F3YDU:?;4>0M\["R9VNNE3(%"<Z=U]4_HF].K;\O6VM#880@4$N%@
MG<'-+""ND%U5U];<%`P48A$6G2DDP<FEJ%U9V]F2&0H4DI&U-E>2EBOR\U+I
MGCZ9)P\HE)&2[YA5D>,1&%->W5,3&PX42B_6T;!W\]8S22Q37F@38@`4*LUU
M5W?R##`V2TZ+CXPV*@0*%6@YN+CZAL596"4E1$4$^6/S#@"A\#+Q#.\K6```
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O9V$N<&YG````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P,#8@,3`U,34T,S,W-#8@
M,#(S,#$W`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%
M````____(3QC*$1L-%)]4'&@`"=>!2QB!2QA$#=L&#QM(4=[-5F++DQT.%F&
M1FF:0F&,3FZ;!RU:"2]<'SE9)T)B+DIK-5)T576<#S1?$SEE(TAS)4AP-5F#
M.UE[2&N32VJ.576:0%E:+4A(+TE),TY./%144&IJ1EE95FQL3F)B8WM[5FIJ
M<8F)<XF)<8:&=XV-8G=V`$,`09=!7J]>`6L`!&T#"F\)#G8-$E41'H,=('X?
M,),O0Z)",WHR4*M/4:A09K%E!FX`.IHU/X8[;KIJ!$4`!$0`"W(%#'`%%GP0
M'GP8)XHA'6`9/9,X3*A&5JY07*Q7(WL!(WH!*X(*+8`-(%<*.8X81)$G2ITK
M0'LJ7:T^:K=-8ZI(9*M);;=1<:]9?;]DP,0`O\,#Q,@'Q,<2SM(4W-\FGZ$A
MTM4OZ>TZUMD^\_9*Z.M,\O91R\Y&Y^I0]?AHR<@`Q<4"P\,"R\H#S<P%R<D%
MRLD)R\L*T](-QL8.U=00UM89S\X8WMT=X>`ATM$@T=$HXN,LZ^LO[^XUN[PL
MR,@PT=`TW]XXQL8RTM$V\/`^]_="T],Z^OE&Y.-`XN)"Q<0[Y^9&_/Q/]_=.
M_/M0Y>5)\_).Y^=*]O50]/12\_-7]_=>]_=E]O5E_?QJ____````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````Q)2KM`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"?
M241!5!C39<_!4<-`$`3`F=F53J:$'[QY\N+A,!POX1"$H2@P%J>[VR4`=P8-
MW"'.G#>N8T2=I6WEF^-2)OOY7'I0$K\(QXO/[&U$RB1:PO%4E+5'2C0I`X[7
M8__XK<UGGQZ*Z@;A<5S_]F9NODS>]H20^_?>Z>;+4K)E@CBU$:DQN2S5(MZ)
M8X^@1+NM>3W<,HCG45DHU4-&S<S+_0?_:99/2P>OJLH`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]F;RYP;F<`````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,C`T,B`Q,#4Q-30S,S<T-B`P,C,P,S0`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!(````,"`,```!8S!V.```#`%!,5$4```#____%"`G""0K`$Q7!'"'**S"_
M+3*\+S79/4*X.S_#047E3U343%#745;K6V#F7&#H:6WH<'2T(RJ\+37)/477
M4%>\2U')45CC86C.6F"S3E3F:G#>9FW?;G3J?X6G,#NP-T&S2%*K.$2V04W`
M35C+6F7"7FCZ^?J?CZ"6AYJ4AIC2R=?*PM"[LL*&>I&BFJVLK*W=[OFCOLV_
MW.RIPM#)Y/3'XO&\U>2GO<JIO\N\T^#.YO2)F:+*X>ZQQ="[S]K5Z_?.X^^T
MQ<^(L<>4OM2QT."4K+B=ML.EOLNZU.*NQM/%W.C,X>S6Z_:/M\G8[??(Y?'!
MS,S$SLZ^Q\?O]_?&S,SW_?W\_?RQL:_\_/OU]?3Q\?#AX>#>WMW;V]K.SLW-
MS<S#P\*YN;B+BXK[^OC,R\G+RLC^_?S[^OGW]O7N[>SJZ>CIZ.?=W-O3TM'/
MSLW'``#+`0''!07,!P?3$!#,$A+<'1W4)R?C04'S5U?<V]O(Q\?'QL:YN+B;
MFIKZ^OKX^/CU]?7Q\?'M[>WIZ>GFYN;@X.#>WM[3T]/2TM+1T='0T-#.SL[-
MS<W+R\O(R,C'Q\?#P\.[N[NXN+BOKZ^DI*20D)!]?7U\?'S___\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````:WB!F`````6)+1T0`B`4=2```
M``EP2%ES````2````$@`1LEK/@```+M)1$%4&--MP4%*0F$4!M#ON_?'0/0%
MU<"!H`-1*DEP"\U;0//VX3+<A`MP#R).!)UH$#RJ03Z4"E[OWML"ZAS@#V+*
M?+UYF+4&MUZZ64P$\"#CIV38T3T$"8O/*V&0Y3[\X%9#PK:V[8A;_?6]4&W&
M"0F[%'EQ_W(BJ4HS)'Q'59K'D:I*MT#"3?;6?F:GQP\A[3+F"5WMYY7HV?F%
MB(@0@N&H407YE:VN.1J/EQ"(@"',XE'O"O()__@%?$5-+`"L)QH`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V=E+G!N9P``````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,C$Q(#$P-3$U-#,S-S0V
M(#`R,S`R,``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```&`4$Q4
M10```/___X@U-G%P<?_^_SH[.U]@8)66E?'M[&H``&<!`&L!`6D!`6P#`VL#
M`VX%!6T%!6L%!7`'!W()"6X)"7(*"F\,#'4-#7`-#7@0$'02$GL4%'04%'\8
M&'X8&'P8&'@8&((='88A(7T@'V0;&XHF)HXK*X$G)VH@(&LA(7TH*)(O+X(J
M*FTC(W(F)HDP+W0H*)8U-7\M+7<J*GPM+7XN+GLM+7DL+)HZ.H(R,8`P,(0S
M,Y`X.(@V-88T-)X^/J)"0HTZ.J5&1I(_/J1&1I9"0J=*2GXX.)M&1JE-39I&
M1JI/3YY)29Q(2*I04*),3*I14:5.3JE14:=04)M*2J-04+)D9+-G9[5N;L6^
MOMW7U\[)R<.^OOOV]D1#0\[,S+.QL5A75]W<W/'Q\=W=W=34U,O+RZ>GIVIJ
M:FAH:#4U-1D9&1,3$P("`O___P``````````````````````````````````
M`````````````````````````````````&V>V>$````!8DM'1`"(!1U(````
M"7!(67,```!(````2`!&R6L^````HDE$050(UV-@P`JR63,2W>4%./DEE0R=
M_(`"N3E9F6QQ&L*<O.**V@[>P4`A9O:TE+0$$QYN43DU>\\@'Z!0>BI+<E*\
M$9>0M*J%6X"_,U`H)I8C*CI22Q!L4*"K'5`H(CQ$1T9,`&*0%Y,54"C,5UV"
MAT=4%FR0HZ4Y4"A47XJ/$V:0M9D>4,A&`>(B%Y!!I@::0"%E$9B+/&RMC'55
ML'D&`-T?(*)IEJT2`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V9R+G!N
M9P``````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#$U(#$P-3$U
M-#,S-S0V(#`R,S`S-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X`
M``,`4$Q410```/___]`U-N[M\0``QP``Q@``?`,#R0,#Q@4%QPD)R`T-R0H*
MB!(2RA@8S1$1D!\@T!D9F2<GTR0DQ"4EPR$AI"DIQS`PV"LKQ#`PS2HJKC@X
MW3@XW#(RN#DYRD%!XCH[PSLZPTA(Z$9&T5!0[5=7\4Y.U5Y>]5E9Y61D^61D
M^&AG^F5E\V9E\VIJ^F5EY7EY\X2$^,?'R\/#Q\+"QM?7V\_/T\[.TM[>X<;&
MR>_O\-O;W/K]_L[3T\C-S<;+R^GN[OG]_?7Y^?/W]]_CX];:VN7FYM+2S]'1
MSLO+R,G)QNSLZN'AW]C8ULO+R=[>W=G9V-(8&-\A(=LD)*0;&ZPA(>DO+Z\C
M([4F)N4S,K@H*.PU-;LJ*KTL+,,N+L`M+<<P,,DR,<8P,,XT-,LS,_,^/O5"
M0N]!0=4Z.O=&1ML_/M`\/.%"0OE*2OI-3>5&1NI)2?I/3_=.3OI04.Y,3/%.
M3N!(2/A14?=14?104/E65NU34_986,>PL,VVMM6_O]_)R>G4U/+=W>_;V^/0
MT/?CX_;BXLC'Q_O[^_?W]_;V]NSL[.+BXM/3T]#0T,W-S<S,S,K*RLC(R,?'
MQ____P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````+*-43(````!8DM'1`"(!1U(````"7!(67,```!(````2`!&
MR6L^````IDE$0508TVW!P4T#,1`%T#_CC6-C*RC%<$-1"D"B!"KB2A6((B@!
MT0E9>==CSZ<`>`_X0Q!1[L]?3]?E_?(M^73WJD"NE0_;!HHN)44LB*4X_5A)
MB34=&Q0YA]["@"<YI3PZ%M326C#XI!3Q;8>B[GWMX/P8DF)_(Q3#?FR0GR4$
M;?N+06&K3?+P>'-A'VY0;&W,<""?;=K>;4)Q&Z;!2499IT_B'[_D,UD(NIC:
M?P````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O9VDN<&YG````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#(P-#0@,3`U,34T,S,W-#8@,#(S,#,Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____>1(3VC8WSW!Q
MCTY/__[_U=35Q\;'RLW-_O__U-75QL?'P<+"Y^?FX.#?S<W,R,3#\5$U^5Y"
M_%U&Y5E#\6=7JYZ=_U9/O9Z=S```>P``S@,#B0,#T`4%S`4%=@4%S0D)G0@(
MU@T-V!`0D0T-N!(2KQ,3TA@8X1T=KQ@8Y"$AU"`?N!L;IQL;P"$@L"$AF!T=
MSR@H[B\OLB,CM"4EO"@HORHJEB$AQRXNA1\?RC`PX3@XU38UTC0TP#,SL"\O
MY4)"ZD9&_E!0]DY.W$9&CBXM^5!0G#8VB#`OS%)1_&EI_&YNZ6QLS&AHM&%A
MT'1SL&5ECE)2\8V,N6]OW8:%Q'AXSX&!X(^/\:&@THN+M9>7KZ"@^/7U^_GY
M^/?WW=S<S\[._O[^_?W]_/S\^_O[^OKZ^?GY^/CX]_?W]O;V]?7U\O+R\?'Q
M[N[N[.SLZ^OKZNKJZ>GIY^?GY>7EY.3DX>'AVMK:V-C8UM;6U-34TM+2T-#0
MSL[.S,S,RLK*N[N[LK*RIZ>GG9V=E)24BXN+?W]_____````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````NSUN/`````%B2T=$
M`(@%'4@````)<$A9<P```$@```!(`$;):SX```"]241!5`C78V#``MK:FGD8
ML\JJZ^IJ*DIS4I)`0BT-F6G%5>(QM95E>6F,Z4"AUL:BY/SH("LW5LF"#,;4
M/*!04Q5;;D*@DKJI5E1V4G(./U"(`VA0HJ>T`I.%?UQ25DDU4"@^C8^;TT-6
MU=`A@"N]D+T>*)2<7U$KJ*NF;^_J&YM7+L`+%(H,9?'S,F(6%?/V"8X(#PL!
M"MEHR$O)J6@+B3B[.-I9FAD`A704I624-8V%)=R=;*W-3?2P>0<`DCXM&S75
M"2D`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]G;"YP
M;F<`````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`T,R`Q,#4Q
M-30S,S<T-B`P,C,P,S,`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.
M```#`%!,5$4```#____Y4%'54U36KJ_&Q\?@X-_IT=#-`0#,``#-`0',`0'.
M`P/,`P/,!`3,!071!P?0"0G-"0G,"0G.#0W4#P_/$A+;%!38%!32&!C,&!C2
M'!S4'Q_4(!_D(B*G&QO8)R>P(2&R(R.Y)B;=+R_=,"^\*"B_*BK$+2W!+"S'
M+B[*,##-,C'A.#C5-C72-#3/,S/:.CK6.CKR1$/@/S[G04'E0D+J1D;N24GL
M2$CR3$SV4%#Q4%#[5U?/2TOH5U?*34W]9&3J9&3Y;6W]<7'V<W/_>GG,86'Z
M>7C_@8'Z?G[X@(#]G)SACH[_I*3AF9G.C8WZL[/^N+?2EY?NL[/>J*C8HZ/G
MMK;,I*3.IJ;-IJ;VR<GANKKZT-#NR\O4M;7WUM;_XN+\Z>G,O[__]_?_^?GV
M\O+EX>'2SL[0SL['Q<7U]/3^_O[]_?W\_/S[^_OZ^OKY^?GX^/CU]?7R\O+N
M[N[KZ^OHZ.CDY.3AX>'>WM[;V]O8V-C6UM;4U-31T='0T-#.SL[-S<W,S,R[
MN[NRLK*GIZ>=G9V4E)2+BXM_?W____\`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!()UW\`````6)+1T0`B`4=2`````EP2%ES````2````$@`
M1LEK/@```+Q)1$%4"-=C8,`"NKK:65.C_8.3FQMJ*DKR<D!"'2T)'J8R0E(!
MM96E!8R%0*'.5G872P41;B[1T+(BQOQ2H%!;G9^-BA@OAX"X?79.;@D;4"@K
MQ5576IA/4$+.."DG+3T#*.3M%1X?%1')$A,7Z^;LQ.P`%'*T#&ML;JJK*BM*
MM+4PU-$$"MFHVC4WUU>7%^?X6)D8:"@#A70E^=TS02X*LC;3UU)3!`K)"G'R
M&/F&!'HRF>MIJRO)8_,.`-@T+C/;TY?(`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+V=P+G!N9P``````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`R,#,S(#$P-3$U-#,S-S0W(#`R,S`S-P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___]4U-L<Z._]G
M:'\[/,Q?8<YB8\UD9M9K;)1.3^%X>M1T=>Z)BOJ8FKMR<^>.C_^AH_F?H-)V
M>N2$B+!I;/*4F+QS=L=\?N&.D?RBIN64E_ZHK/JFJ/:CIO>HJ\QF:]!I<,QG
M;MAT>=*$B$F]5E+%7V#1;4N;5%2G7F[1>66];V>Y<(SPEXKKE4*Y3BES,$:]
M4D6Z44>[4U#%7$V]653!7V#2:T212U[&:7'@?7'??5VR9FW(=H'KBX+KC8CN
MDW_<B(KGDYGQHM35(,V]">'2.-*7&,Q_`>>B0/:S5\YU#?&;4-AR)\Q8!?^-
M:LPC`,T1`=T_+\\;$OIG7LP&`,T!`,P``,T!`<P!`<X$`\P#`]`%!=$'!]0*
M"M8-#<X-#=@0$(L*"L\2$ML4%-X8&.$='>0A(>@F)NLK*]@G)^XO+Z<A(;DF
M)MTP+_(U-<0M+<$L+/4Z.LHP,+(J*LTR,=(T-,\S,_@^/OI"0MHZ.N`_/OQ&
M1N5"0OY*2NI&1O]-3>Y)2>Q(2/]/3_Y04/),3/U14?9.3OM14?E04/%04-1&
M1NE96?UD9/AE9?___P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'V%5M\````!8DM'
M1`"(!1U(````"7!(67,```!(````2`!&R6L^````M$E$050(UV-@P`(,#"QT
MG)VTS(ST#4W,K>P<@$*L7/SRL@(\'&SLG-R\?()"0*&DDI[>IJR$R(BXU,R*
MAHY&H%!.-XM/4')T6&Q*1E%=6VLU4(C9W\O-W2\T)C$]OZ:EO;8,*-07XNGB
M&A`5GY9=V=Q9SU0,%.IM\O7V"(0:5%5:"!3JR@N.#H<95%Z0"Q22%%924%06
M$9.2D9-6D1`7!0I9FAJKJJE;V^OJ.=IJVVAJ8/,.`"N&,`\7S_I&`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O9W(N
M<&YG````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P-3`@,3`U
M,34T,S,W-#<@,#(S,#0P`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=
MC@```P!03%1%````____B(>:04"C2DFX.SJ26UJID9#5``!0"@J(#`R)#@Z(
M#@Z'$1&.%A:/&!B+&!B)&AJ0'1V9)"2:+R^G-S>I,#"4,3&5+2V).#BC-#22
M0D*W-C:6+BY\.SN>(R-=0$"H.SN;)B9>1D:J4E/"04&:2DJJ1$295%2[65G$
M6%C"4U.V6%B\7%S!7%RY5%2@:FK';6W'8&"J;&R\<7'#>'C.=W?*9F:I9V>G
M?W_+<'"S:VNI:FJG;V^M;FZK;FZJ;6VI?GZ_>7FV>'BT=G:O4U-[CH[1C8W/
M>GJRCX_.AH;!?7VTB(C#@("U:VN7G9W:='2AEI;/AX>ZFYO5F)C1D)#&D)#$
MAH:V?GZKI*3>GI[6IJ;=EI;'E97&K*SAJJK?I:77G)S*K*S<FYNXG9VZGIZZ
MGIZYIJ;"H*"[J*C#H*"ZLK+-M+3.P<'<K:W%K*S$P\/<DI*ESL[HG9VQT-#I
MIZ>[U=7NT='ITM+IL;'%U]?NQ<7:O;W%O[_&O+S#@H*'RLK1Q,3+MK:\DY.8
M\?'XZ>GPW]_FW-SCS\_5S<W3P\/)OK[$\_/Y\?'W[N[TYN;LX>'GVMK@P<'&
M\?'VY.3IU=7:L[.W\_/WQ<7(W]_AY.3E>'FQI*7<Z.GOY^CNS<[3JJNM____
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````(V_\-@````%B2T=$`(@%'4@````)<$A9<P```$@```!(
M`$;):SX```#!241!5`C78V#``CCDF]4-+&,][*UMG7Q"HN.`0DJNTX+=$_-2
MDU/2LW.+RLJ!0O4+9DV?$B3`P\TG+,JBI:L-%)+U[C%A=IG1W=4Y<5[OY/ZI
M0"%6]KD*_&(6YE:.GOZ14:&^0"&WI)E&JC+B<FIZAJ9FQFSZ0*&6MH;:NIK&
MCO;6WKX)\R<U`85T)`6Y.'F%1*15-#64%:4D@$)ALQUL[)R]`N?$)\2$1P3X
M`87RL](R,G,*2JHJJBM+BPN9L'D'`$^V,MW&MD?U`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]G="YP;F<`````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,C`U,"`Q,#4Q-30S,S<T-R`P,C,P-#(`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____4V-M\ON2"
MP^<54&T73FDG?*@F>*(H?*<H>:,M?:4O@*DB674Q?J<XA*I"E\(_D+@]B*TK
M8'HQ:H9!BK`U<8\Y<Y`\=Y9-E[P^>IA+D;5"?YY&A*-+C*U(AZ92E[I7H,1.
MCJY2E+5+B*97F[]@K-);H\=2DK)-BJA2D;!HMMU2CZY6E;5:FKI4D*Y>H<).
MA:!BI,5<FKEIK=!FJ,ECI,1NL]APM]IRN=QQM]MQN-MNL]5IJLMPM-9ML-%S
MN-MSM]ENK]!VMM9UM-.`PN-]O=U]N]J!O]Z`OMUVK\R`N]J&PN"(P^'N\O3T
M]O=7J=%3H<=%@9Y%?)91CZUGL=5<GKYOO>-KM=EGJ\QOL]1BG+AJJ,;-TM0_
MD*U+F+,SB:8TBJ<WC:H^E;-<I;YQMLV$Q]R-T.?EZ>K/UM;)T-#1U]??Y>7;
MX>'X_?W.T-#U]O;(S<NUN;>]QL&AKJ7M\>ZSQ;>2H96DL*9J@VQ^DW[$TL-L
MAF)]CG:@LYA;<4MQAF)M@%_!R;NTPJ>+FGQY@FQQ?5^"AT^NL'_9V=?%Q<3(
MQ%C&Q(23DG^OJZ#^_O[\_/SZ^OKY^?GR\O+N[N[DY.3AX>'4U-32TM+1T='.
MSL[-S<W,S,S___\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!F/S3'`````6)+
M1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```,%)1$%4"-=C8,`"6-E$
M=-(+ILV8,R=?4"!`.QPHQ"9LZ)V6,WWVG%FQDH&AEA9`(=Y@+\_4[*ZB\IE,
MZFI6CB9`(?%H'Z>4XIJ.]LHR\P@'>P.@D+ZOLVI\14M/=V,=LW64F3)0R,/=
M2#2NI*VOM[Z9Q<Y45PDHY&HKS9=8V-I05>OO%JD7(@\4LE'@YTK(ZFRJ+LUS
M"=-2D0$**0IQ<R1E3IT\H=\O1D,S2`(H),C#R9Z<.V4BXZ0,8SE9*3%LW@$`
MAWLQ)I`0>A<`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V=U
M+G!N9P``````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#4P(#$P
M-3$U-#,S-S0W(#`R,S`T,P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,
M'8X```,`4$Q410```/___X-X>I1]B%)(6G!>AUE*;E=.?4Y):&QECDE$9BTG
M7E=2BC@V7T-%@!`76!DD8R$L;10A8%1BH!,F9@`8704>8B<_@3Y2B#M.@0(>
M9`8@8`<@8`@A80DB8@LE9`PG9PPE8P\H91,L:PT>21,K:!<P;A@P:QPW=QXU
M<"([>24\=2Q#>C%)A2U#>B0V8C5-B2T_;C5*@3I2BRT_:C]7DC-&=C)%=#Q3
MBCE-?SA,?3=*>D1;E4=?F39(<S]3A3Y0?D9;CD18BD=<CU!FGT=<CDM?DU1K
MHE-IH$YCETUBE5%FFE9LHE-HG55JGU=LH55IG%QPH6%VJ&)VIV=\KEUOG6A\
MK&E\K&Q_KVE\JFZ!L`$4/P(4/@4D:`4C9!0O;1DU=!,F3QPV<"-`@"(\=ALN
M6C1+@4]LJTIDG3Q1?T5;CU%KI5)LI5)KHTQBEE9MHDE=BE1JGEEPI6N!LP`C
M:``B9@,E:@4F;`DJ;0TO<Q`Q=1T^@1\^?2%!A!LT9R([;"$Y:2]0D"8_<#54
ME"I#=BM%=S!*?C!*?31/@S91AT)AHD9DHC]:CT9BF5!NJTEEG%!LI82FHWBL
MGF.OE6*WEE?$E%^I@D"R9DB:8H2(8;BT89R+B&-96?___P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````&]23S4````!8DM'1`"(!1U(````"7!(67,```!(````
M2`!&R6L^````P4E$050(UV-@P`*BHU,SBXN,$V)+RZMJF[O[@$(QB7:1P5DI
M0OQQREH&MNX3@$(J)J%A7CHB+',$-'1M//S[@4+Z!1$!1O'<,Z:SB9NZ^'CW
M`(4<H@(E-,6XIDUAYLOP\77N``J%!SEJ*XER3)PTFR?7STVR'2@4DJ>G*BO%
M.WDJDW"^I[UU*U"H,$U=3D9!<.8LSAQO)ROS)J"019*BM+Q:,CMKMJ^KI9EA
M`U"HIJ*DK+*ZL2M]0F]G6TM]'3;O``#1S3&E'_9&3@````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O:&LN<&YG````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#(P-#8@,3`U,34T,S,W-#<@,#(S,#,W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____T<G%R[BR
MS9J.OR$`OB$`=Q0`P",#OR,#P20$PR8%PB4%P"4%P"@)QRP+R2T-R"T-PBP-
M@Q\*RS`0Q#$2QC88C"81U3P=U#P=UT$AR3P?R#T?R3X@GC$;E"X9S40GIS<A
MXDXOXE`OJ3HCGC8AL#XFTDLOLT`HY5,UM4(JOD<NNT8MN$0LJ4`JPTLQP$DP
MUU,XUE,XR4XTR$XTQ4PS[%P^RD\URT\V[V!"[F!"T%0ZLT@R\&1&W%M`UED^
M\6-'W%M!VUQ"OE$[O5$[]&E-WV!&Y&1)XF)(]&M/\VM/Z&9,Z&=,\VQ0ZVA.
MZVE.\FU1\6U1[FI0[FM0[FQ0YVI0RUU&['%7ZW!7\'=>X'!9\WQD[WUE[GUE
M]H)J]8)J]J64S(M]\-+,OR`!Q#`6T388S4$GWT<K\V1*ZF9.]6I3\&E1]FY4
MR5Y*R%]+ZW);]7]HUGAFYJ6:S;VZOQ@`PB4-RRD0Q2T8PC`<UDTXYV10RV!0
MR&!0YGML]XMZQW=KZI2&V[&K]LG#Y4DUPT0T[U1"SU-#\V)/\V-0VWYSUH%X
MXJ.<T9J3Y:RFW:BA_,W'R[BVOA8%P!H)URTAV<O*S+N[S,S,____````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=OV@6@````%B
M2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"_241!5`C78V#``MC9
MY5WB(XS*)[+QB$AIVOJ"A,1M8B,=I6OJN00DE"P]@X%"PGI1T1YII1.*^5/3
MS5P#W8%"JF$%585Y%<Q,C469&0$^]D`AY[CPRNJITUBZNI,2.OR=3(!",9%V
MLI-:<MLZ&UK;0]PL#(!"T1X*0LDI/7VU3779[M;ZND"A4'51SI+$*;WY_3G>
M]J8Z:D`A0S%>5NZRR<T.67Y.QMH:BD`A&3Y6#D%)92NO(#=S`RT5.6S>`0#N
MRBZ*(<TCQ@````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]G
M>2YP;F<`````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C,P-B`Q
M,#4Q-30S,S<T-R`P,C,P-3,`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8
MS!V.````!&=!34$``+&.?/M1DP```"!C2%)-``!Z)0``@(,``/G_``"`Z0``
M=3```.I@```ZF```%V^27\5&```#`%!,5$7U``'P``'=``&Y``0`A4``A#T`
M>3@!A3\!@#X%B$,+BT8&B4(8DDX`@C<`>S,`BC8`BC<`B38`AS4`A#8`@3,`
M@34`@#(!@S0!@C0!?C(8D$D`AC0`A#,`@S(`@S,`@C(`?3``?#``>"X#@#,#
M?S,$>3$%=S`6B$$?E4U$G&4"?"X">BPRDU4SGE,WH%8PFDPYH5)6K5=>M%Q7
MKE1CM%UUOUUQH6&%QF=UO%&$QEB)QEQOD5*BTVJLWTZCTD^WW%;*\$.]WT/'
MYC[(Y$K%V#+8[$G<[3OM^3_G\`'2V03N]B_Q^#?\_Q'__P#^_P+__P+__P/_
M_PC__PK/S@O__Q+__Q3__Q[]_A_\_2'__RRYK@6HG0B1@0F3?B>/<0>28!F#
M2P>0/`*3(0&;'P=@.#.F&0RV"@2A"P=O*B?_``#^``#\``#S``#C``#>``#(
M``#\`0'[`0'Z`0'Y`0&B!@0```#___\`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!FCL>B````=W123E/_____
M____________________________________________________________
M____________________________________________________________
M________________________________`*F?I&4````)<$A9<P``"Q,```L3
M`0":G!@```"M241!5!C38RC%``RE*6:&ZFQ*BI(J8*"L!A3*38UULC7B8963
M%@0"`66@4$%F?F)PF+N=L0:[B+20H`I0J#@SDZ$DSB,@Q-O>1(I%7@LH5)29
ME9G)E!SM[^L?ZN5HK@,38DR/\?/U#0QWL]&$:,QF3O#T#8IPM=+E%M8&"A5F
MYB5%^40Z6QAP\<I"C,])BW=QL-3C%)41`CJ"'^2(#&M3?0X^!3$),!!7!0IA
M``"[$3VDNWPD8@````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+VED+G!N9P``````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`R,#0U(#$P-3$U-#,S-S0W(#`R,S`S,``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___\'"PK*S
ML]35U.#@W]W=W-75U,W-S,K$P>7?W/WW]/CR[\K#P,C#P:,I`*4J`:0J`:4K
M`Z8P":LR"J8R#*XU#:@T#:DW$:<W$;9`&'HK$;I$';-"'+!$'Z]&([5+)\11
M*\A6+[]1+99%*M-C/M5G0LYC0*!.,L5B0;=:/<)B0M!I2=MP3<MI2-QR3]!K
M3-IS4=ES4;=A1L9J3-Y[6]9W6-I]7LQV6=A^8-Z"9-J#9>..<M/-R]+,ROCR
M\/?Q[^CBX*DF`*,F`&D7`*,H`ZTJ!:HJ!:@L!W4B"K8U$*DU$K(Y%+(Z&,-%
M(88Q&<!))M%7-;E/+\Y<.L17.-UH1L%;/JY4.]EK2MIP4-IQ4=%N4+!;0]MT
M5^6%:N"#:,O$PM[7U>SEXVT5`(\W(>-O4-3,RO;P[_[^_OW]_?S\_/O[^_KZ
M^OGY^?CX^/;V]O7U]?+R\O'Q\>[N[NSL[.OKZ^KJZNCHZ.7EY>3DY.'AX=[>
MWMO;V]K:VMC8V-;6UM34U-+2TM'1T=#0T,_/S\[.SLW-S<S,S,K*RL?'Q\3$
MQ+^_O[R\O+FYN;"PL*>GI____P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````^!WR\````!
M8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````ODE$0508TVV,(0["
M0!!%9W=G=UL:DB9(#D""IAJ-Y@@8P@40H)!4D&`0W(##8&@@J2"I11*:TMFA
M93T\^?+?!_A!P*R(`MM6-3E$5!@?$8I;M\?/LF2%QF`X!`DZC-NJJALA42NK
M+H#0?PS89XWVF9;788;P#O/GBUAI@QT4F/E5I,ZC.TZ-$Z<V$9Q[)9.QG;3D
MJ"X702<E?Q_NC01F=C0W>[M)O0I6RIL/$1B[UE)XM=70,),[:+NS<BG@#U^H
M5T<9U*<^O@````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M:64N<&YG````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P,3$@
M,3`U,34T,S,W-#<@,#(S,#(R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````
M6,P=C@```P!03%1%````____`'L``'<``$T``$P``WL#`WD#!7T%"7\)#7X-
M"E<*$H02&(@8$5\1'XT?'XH@&6D9)Y$G(7$A*HPJ*XLK+H\N*GPJ,8XQ.)XX
M-98U.)LX,H4R.HX[/I<^.XX[2*I(1IQ&4+%04*Y05[977KM>4Z536:]99+]D
M9+YD:,%H9;ME:L-J:K=J?<A]B-"(WN'>U-?4R<S)R,O(]/;TX^7CU=?5S<_-
MS,[,R<O),)<O0:1`9KUES<W,ZNGG]O3R\O#NWMS:UM32T,_.IU$;L%@ALELC
MN5\FO&$H\G\UOV,JQ&@MP68LQVHNRFPPS6XQTG$TSW`SU7,V^HI"V'<YVG@Z
MX'T^_(Y&Y8%"ZH5&_Y)-[HE)X8!%_Y-/_I50\HU,_911]H].^Y-1^9)0ZXU2
M]9A@U8=5_*-LY95C_ZAS\J!N^ZATY&HA[G8ORFDPTFXT^((^X'H^_HQ*[H9)
M_I%0^8Y0__W\_?OZ^OCWZ.7D_O[^_/S\^OKZ^?GY^/CX]?7U\O+R[N[NZ^OK
MZ.CHY.3DX>'AWM[>V]O;V-C8UM;6U-34TM+2T='1T-#0SL[.S<W-S,S,____
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````J@0FN`````%B2T=$`(@%'4@````)<$A9<P```$@`
M``!(`$;):SX```"B241!5!C3;<R]#<)0#`1@VWDO_R!!`T)B#\:`I1B$GHHA
MH*>@8@-:(''\;!R)#J[\[G0`/T$(,&GG<9='.,V6]VEQ"(!5,S6,`=1*K+TA
MR*M&#0.:6)D5L7,JZXQ[HF-*&Z0\#4YMPUV'L)5T)L*>G=;]XLFLXBO"CM7I
M,=PXF4M2\F(D7KE$%T%3D?'K?14A=H&+?E<OX2Q8DGUF:DD-_N0#UH!<%@>"
M"Y,`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]H<BYP;F<`````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,C`T-2`Q,#4Q-30S,S<T-R`P,C,P-#4`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___^\04.]
M75^L2$S!I*7-1$R1#R"A35^#-4FDH*%R.U=9&SU>%4'&IKQ5)TM&)5""8(Q2
M-EQZ<L!'0:L``(4%!8D%!8<'!X<)"8D/#XL0$)(3$Y(8&)$C(Y\E)9DA(7\?
M'W@H*(@T-:XG)X(N+I(N+HPX.*@T-)LU-98S,Y$[.Y]"0JP^/YA04,-24L1.
M3KI+2[)55<!)2H]86:E049=D9;`E)Z4O,9$Q,Y%$1KY.4<%76:%R=,%U>,5W
M>\S%QL?M\O+-T='Y_/SW^OKQ]/3.T='*S<W[_?WZ_/SAX^/=W]_$QL;Y^OKT
M]?7#Q,2\OKW3U-/1TM'(R<CDY.+2TM#\_/OW]_;V]O7GY^;2TM''Q\;;U];%
MP+_LV]C)>G;'IJ3D<V_GJ:?,``!_``!]``#-!07,!070#0W5$!"0$1',&1G=
M'1WA(2&;&1GI+R^)'!SO-37A.#C5-37U0D*X,C+Z1D;E143$.SOZ3T_\4%#U
M4%"M/#SV5U?Q5E;X7E[Y9&3K7U[I8&#S967\:FKU:&C-65GD;&SW>'C`7E[&
M9V?"9F;2<'#";&K1=G3'?G[1B8G;R<GX\_/W\O+NZ>GLY^?Y]?7LZ.CDX>'/
MS,S7U=7HZ.CFYN;___\`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!).IU[````
M`6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+Y)1$%4&--ESS%*
M0T$0!N!_=F9>?'E;I;$P8)E&(4<0Q(,$<A9!$&R#GD%(;>\!TM@)=I:)D<3L
MR\RL!\AW@P\X09A3.\QE5\R8153N!=!!=WS@)OH9)V:"(.>.(K6]2">#I`[!
M\Y/7D6^#'EL+DG<0;LZ\^;N8QK%;LIK:F^`<3L9&PQ6/$E%!POXN&EU_R,KJ
MX?9`#L'/HN2Z_;Y^U:OU2U,"A,F^#]+QY^0WF;G'%R,;6+E<[@2.BKHY_>`?
M>2-)_-:,:J8`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+VAT+G!N9P``````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#,W
M(#$P-3$U-#,S-S0W(#`R,S`U,``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P``
M`%C,'8X```,`4$Q410```/___]<8&>@J+O0^0OM.3[H)%,$K--=!2^Y/6.^%
MB\,@++PP.L8U0-I&4>E06^M>:.ME;[*KV*:@QHR`XR48OD4XT$`TPS\SNU-&
MZ4Y"U$8ZN5U0[5I.Y75J[V)7Y8:%R```QP``?0``?`$!RP$!R0,#R`4%RP4%
MR`D)QPH*S@T-T`T-R0H*B!`0TQ@8V!@8SA$1D!T=VR$AX!\?SQD9FB<GTRLK
MY2$AIR\OZ3`OVS4U[3HZ\RHJKC@XW3X^\T)"]3(RN$9&^#\_WT%!XDI*_3H[
MPTU-^DE)ZDA(Z$]/^DQ,\5!0^U%1_%!0]5%1]D9&TU!0\%=7\E-5YEY>]5E9
MY61D^&AG_65E\VIJ^R@KSIR=UGB*N%]G>WF2NI"PM8&9FFMV<E5>3K>PD<:^
MH6EB3^K2QL6CE\@``,<``,8``,L!`<D#`\8#`\H%!<<%!<P(",@)"=$-#<T-
M#=,0$,H2$LT8&-P='=\A(=`@'\PA(*0;&]<G)ZPA(>HO+Z\C([8F)M@P+[@H
M*.PU-;LJ*L$L+,,N+L`M+<PR,<<P,-TX.-$V-<XT-,LS,_9"0M@Z.O=&1ML_
M/N%"0N9&1NU)2>M(2/M/3_I04.Y,3/I14?%.3O504/A24NU04/QD9/R!?___
M_P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````+HT2H8````!8DM'1`"(!1U(````"7!(67,```!(
M````2`!&R6L^````N$E$0508TVW!WTD#01`'X-_,SNZ%7%3RIP*Q!D&P$1OQ
MQ5($&_`U-:0,7P0ED"`>)K>S<[MC`?I]P!^$:UHMUWH8LJ8NSKKYED&7BY4-
M9]4HDN*,P9@O-NTTY"F(Q-3%`D&_YO)]L[OGFO<I30;!^P>-_F84MAP#U0K"
MTG,P>N!07CVY^P_A9?P<\]5Q(KXK9EJ?!'[0TL[/1'3KM;E!<#R5&N6QO^A:
ML3)5,+Y,64+JDZC65AO^\0NCQ5:M[;7.A0````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O:'4N<&YG````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#(P,C$@,3`U,34T,S,W-#<@,#(S,#0R`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````_____O;W
MIJ"AU=35Q\;'U-75`&\``&P``W(#!7`%!6\%"70)#7H-$'H0&'L8'8@='X,?
M(8@A&V<;(G$C)X`G(6PA+Y@O*8`I+84M*'8H*GLJ-9DU+G\N,(0P-(@T.)(X
M0J=".9`Z-H@V1J=&0IA"1I]&3Z]/4*Q03J=.2I]*0H)"4)M07:Y=49517:-=
M;+IL:[1K<;UQ;K5N\_;SYNGFV=S9Q\K'^_W[^?OY]_GWZNSJZ.KHUMC6U-;4
MS]'/R<O)OL"^-HTU2HM)RLS)Y^?FM```LP``<0``<```M0,#N`4%M@4%M0D)
MO0T-P1`0O1@8N!<7MQ<7A!$1R1T=S2$AOA\?CAD9NB(B?A@8UR\OR2TMVS4U
MSC@XY$)"JS(RUC\_Q3HZYT9&TD%!MCL[ZD]/ZU!0HS@XY5!0Y%%1Y%=7[&!@
MYUY>VUE9W5M;Z6-CYF5E[FIJVFAH['1TS,+"T,?'S\;&R\+"W-/3VM'1].OK
MY][>_?7U_/3T\>GIW]C8\>KJT\W-^/?W_O[^_/S\^OKZ^?GY]O;V\O+R[N[N
MZNKJY>7EY.3DX>'AV-C8UM;6TM+2T-#0SL[.S<W-S,S,RLK*____````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````D2IJ@@``
M``%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"J241!5!C3;8Q+
M#L%0%$#OM]I23`PMQ`XLQ[0)$HE8A"58!-LQ("*--*]]]UV=<X8G)P?@!X0U
MS*HJ-$WL5+)1)F<!+/-)'X+UPJK$!`+SZ1@MD8JJ%B0^J,O^L-4"#86<D'UX
M:3QE+&"68G01W1#LCM>:(24WVS'7.E0KIJPIO'470F*\"72A_9@4.7/RY(O[
ML'^^HI&$,A>,77I$('A;1"95!EMZZ@S^\`755T6R5%X!P0````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]I;"YP;F<`````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`T
M-R`Q,#4Q-30S,S<T-R`P,C,P-#(`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,`
M``!8S!V.```#`%!,5$4```#______O_5U-7'QL>$AXO#Q\OT^/RVS-[(V.:S
MP,L#178*<;X/=+X2>L<2=;\4>,(46(LC@L@C?L$<47@QA,$K<J8UA<(UA<`\
MC\PV?;(ZA;Q'H>4Q<)Y%F-5`CL=!CL<Y>JI,G=E'D,9!A+58K_!3H-E=L_):
MK>I/ELI?LN]5G=->K>=>JN-=H]=KNO1JMNYEK.!WO_2*R/:!K,R"J<:2N-:K
MT_&;M<B=MLFLP]2KP=+(W_&LO<JRP<VTP<O&R\^JKK'U^OZRMKG8W-_1U=C(
MS,_J[O$'<K\4=[X?@LHBB-(@?+\F@L4H@,`OD-8LA\DTF.`M@L`QAL0[E-0S
M?+%'I^T\CLE$F]I!B\%3K_)-I.)4K.Q.G]DV;95(CL!AL^Y@JM]IM>QNNO%9
ME+YZO.RCN\RYTN3?\/SB[_C"R,SM\_?,S]'X^_W8YN_?YNK6V][4V=S@Y>CQ
M]_KDZNWBZ.N]P</I[O#4U=7!PL+GY^;@X-_-S<SX]_?=W-S^_O[]_?W\_/S[
M^_OZ^OKY^?GV]O;U]?7R\O+Q\?'N[N[L[.SJZNKEY>7AX>';V]O:VMK8V-C4
MU-32TM+.SL[-S<W,S,S*RLJGIZ?___\`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````"I%LTL`````6)+1T0`B`4=2`````EP2%ES````
M2````$@`1LEK/@```,!)1$%4"-=C8,`"1$3B4HQ3]11$@X(EE722C8!"W()2
M20D10OP\'GS>@6%1,4`A5L<B]E+7R1:6$PORLYV*2X!"TR<R==39F48JFW&V
MU3>T5P.%6!A;>R?92Z19J>4UUK?V3`(*U39754SA$K?FT,UD;.EFG@84:NB:
M,'FJK8FVH7E&4V=_3250J+S0@2TKIR_=IC[7W<6MS!DH).?KR2O@Y2^CJJX1
M*R\=*@84"O?S$0X(B=;2-TC4C%=1E,7F'0"+8#"C)P]RS0````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VEN+G!N9P``````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`R,#0P(#$P-3$U-#,S-S0W(#`R,S`S-0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___ZB.
ME)>%D-74U<?&Q_+P^<G)S*.DTZ>HNYB?RWZ(MY6>QX".OZ&MUG.%O'R+N9:B
MOM7>[[7`R>SQ\OK^_LK,S-35U<?,R_?[^NKN[>CLZ]38U\G-S/K]_+["P-;:
MV,K.S,G-RVZT8V*J4X7&=D62,$N7-U*9/U>026JK6&BC6'6R9(3#<XO,>D>2
M,EJD16"94(C+=3^0'SEU(5.=."1W`"E\!2EZ!3.'#32%$#F%&$*4'423(35Q
M&SYZ(T:$*D)^*%>D-4F(+E"0-%^A0F6J1F^V4&NP3BA\`"I^`R^`"52D+TZ.
M,%26-6:R0FBR1G&Z3W"V4.?GYLQ2`'\S`-!6!<Q5!=A@$-1>#\Y@$N1O(9U.
M&=AP*^MZ+^%\.+)B+/B*0?R/1L9S._^64/Z64.Z-3.R,2_N75/VC9W\R`,Y2
M`\E0!<Q3!\U6"=9<#8L_#=)B&)1$$>%J'=YI'-1F'^YZ+_*`-?J*0KMH,N>"
M0?^43_F24/:65_J;7NF47/>?9?^E:L^XJ]W'N^#,P/[HW/'=TM3#N>C0PZ>6
MC?7=T?WGW/+=TO_KXL*OK;&=G/CW]_[^_OS\_/KZ^OGY^?;V]NKJZN7EY>'A
MX=+2TLW-S<K*RO___P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#M"C<@`
M```!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````N4E$0508TVW!
M34X"01`&T*]^NGO`(`0B2#1X*L[@BK!Q"QY`5\:==_$NL"`1@D8A,#!371Y`
MWP/^((R1TJA>=E?&++<;>5-<%2F9]4\V4!4:$A3Q\^XC'ZQWO;U9BVB&8CB(
MR;SUX,_G?A6I!"'4KT*SRHWBW)7YGO'T\OY(WV7%YY^IT(1!&!F%8SB<<B%*
MD6VA2"&G0+V]MVMWCR44G6BY$.E>'LG<\PZ*W,GTQ6VABWW#=][$/WX!43A'
M5KIY-N``````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O:7$N<&YG````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P
M-#<@,3`U,34T,S,W-#<@,#(S,#0W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#
M````6,P=C@```P!03%1%````____B!L<\U97^7AYRL+#S\C)_?;W_/7V\>KK
MV]/5_/7W\.GK+RXO+2PM/SX_<7!Q8V)C5E56U=353T]0]_?X_/W^R<O,P\7&
M(B,CSM'1XN3DXN/C]OKY[O+PXNGEO,.^QM3)O-J_H[>EIKFHQMO(CK.1;Y]R
M8)5@:)5HE[J7H<:AAJ.&F[.;SN'.Q]C'K[NON,&XZ?#I'R`?N\"[Z_#KZNWJ
MQLG&OL&^X.+@U=;5TM/2R,G([/7K-C8UQ\?&V];5QP``?0``?```R`,#RP4%
MR`4%R`D)T`T-TQ`0SA@8D!$1W!T=R1T=QQP<X"$ASQ\?FAD9SR4ER2<GZ2\O
M[34UV3,SW3@X]4)"N#(R^$9&XD%!Y45$TS\_PSL[^D]/^E!0]5!0KCP\\E=7
M]5Y>^F1DZE]?Z%Y>\V5E]VAH^VIJY6QLQK^_U<[.RL3$I)^?[NCHW]G9T,S,
M^/CX]O;VZ.CHYN;FT='1QL;&O+R\=W=W<G)R<'!P86%A5%144%!03T]/3DY.
M34U-1D9&145%0D)".CHZ.#@X-34U-#0T,S,S,#`P+R\O+BXN*BHJ*"@H(2$A
M'1T=&QL;&!@8$!`0#0T-"0D)!04%`P,#____````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````2V2QF`````%B2T=$`(@%'4@````)<$A9<P``
M`$@```!(`$;):SX```#`241!5`C78V#``IR<`^.RDL.]W!Q=/?U#HQ*`0L[>
MD1DIT0'NCBX>/B$1\8E`(::D;);TV&`_WZ"P&.;4S#2@4'X1!P]77@XK6VXA
M)SMW@0-02$),3DU%7$%975%>5DE56@HH5%)LJ:EC8*BKH:]GJZTE;`,4$BTK
MK[`P,;>2,3,R+;6VKP0*5=>U\?)U\8L("E35U`HUM0"%VB=/9Y@^94)'<WUC
M:V=O_P2@D/$TAAE3)_:T-M0WVW7W24["YAT`_5<PGKVWC0L`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]I<BYP;F<`````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`T,2`Q,#4Q-30S,S<T-R`P,C,P-#(`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____Z
M45++='73>WS)LK3CX>+Z^/K\^_SBX>+/SL_>W=_$P\;[^_SR\O//S]#T]?;0
MT=+'S,SU^OKN\O+)S,SU]_?/T=''R<G&R,CT]?7R\_/EYN;BX^/-T=#Z_/OR
M]/-/F5),E4X`<P``<@``2```1P`#=`,%=P4%=@4)=@D-?0T0@1`8@1@16A$=
MBATACR$?A!\99!DOFB\UGS4XESA"J4(R?S)&K49!G4$ZBCM0LU!/L4]0KE!7
ML%=>M5Y5FU5EMV5JOFI6F%9FI6:.P([!QL'/T\_!P\$Z9CECJ&)RM7%>C5V"
MPH&%OH20S(^0RX^)P8B@TY[J[.C1T\_V]?3W]?30SLW'Q<3%K*K(JJCIQ\;'
MLK'(``#&`@+)`P/*!@;'!P?("0G1#0W3$Q/-&AK<'1W1(!_?(R.D&QNL(B+J
M+R^O(R.[*BJX*2GL-C;',###,"_1-C7=.CG.-C;V0D+W24GA0T/F1D;[3T_U
M4%#Q4%#;<G',;&S':6G&;6S0='36?'S*=77BB8FU<G+8BXK;CX[`?'S+A87M
MGY_XJ:COHJ+XJZOMI:7EI:77IJ7AO+SY]O;LZ>GJY^?(Q<6CH:'MZ^O;V=GZ
M^?GX]_?GYN;3TM+)R,C(Q\?V]O;5U=6]O;W___\`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````7Y-_H
M`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+I)1$%4&--M
MP3$R!%$0!N"_N_^9]\S.D%"EB@PG$"A5`M%&FTL=@RJI8)7`(=R"5.00<AEE
ML3O=V@'X/N`/P0&&6OWKVU<-2=H3(;4I,7J,-#.E@-BSY>"?W4ON=J(J`L5L
M,CMMM3DZ+H^UEND40%]W)MU68[S;+,/ZV@8(=MK+ZFS?GW-[U$5](^8B^G!R
M<YCWU^VB#YX+YAZ12:VILM2,*^+UW4/)4FXO/2(<Q$>XFEIK%S'^1";^\0ME
M4#_DB:.\1P````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L
M86=S+VES+G!N9P``````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R
M,#4P(#$P-3$U-#,S-S0W(#`R,S`T,P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````$@````P(
M`P```%C,'8X```,`4$Q410```/___]MX>:V>KZF9K)2"HI:%I*"5JM'$W<_#
MVI*"I)J)KZ.3N,2WU9Z/L[*EQ(Y_J,_*W**=M@X-BPX-B1T<DU54Q`$!A0$!
M@P,#5`8&AP0$500$5`<'APD)B0H*C`L+BPP,B0T-C`H*7A(2D!04F!,3D186
ME1@8EQP=DQ049R,CGB8FHR<GHB4EF"LKIA\?>"8FAB4E@"<G@C`PGS4UK2TM
MCSHZLSDYL#HZLBHJ@2XNC"TMB3,SF#X^M3,SDS4UECDYG3X^J#L[GT='NS\_
MIDA(NTI*ODQ,OTQ,ODU-OTE)M$='K4Q,MTM+LE%1P%%1OE!0N555PU96Q%96
MPU55P%-3O%E9N'M[N'=WI7]_KZ:FW9N;SJ:FVP<*B@P/C"0HI2(FF1T?<C(V
ML#L^JS<YCXJ+QI&3S9J;U(F*NZFJX&YRL'=[NC],I$52J5)?M6)NPDM3C7-_
MSX..W'^)T8:1VT!0J'%\P'%[N)>BY,PL(-`M(M8V*\X],]9%/.%42]M02>YE
M7.QJ8<I<5-5B6_IV;N=N:/I]=.IT;/^!>/E_=_^'?_J(@OB-A\HC'-1K:/F9
MEO*@GORMJ\<-#<TA(<HK*-%$0\524L=<6LQ?7N!X=NZ)B,][>>*,BL1Y>/N=
MG/*9F/___P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````!6&*_$````!8DM'1`"(!1U(````"7!(67,`
M``!(````2`!&R6L^````P4E$050(UV-@P`*D)9/8NWE31!6E%-1U+3V"@4(R
M6JF<[?R)(K)R:MJF;D&A0"%EJW".)CXE"7%Y#7T[KP!OH%!A1:5@@U!9;EY^
M05%Q:4DY4&C>I(E,4Z;/F-D_:_:$^0OFS@$*]?:T39L\M;:NOK&ULZNCI1DH
ME)6>P]S'DAV1EA$=&Y,9%0D4"C11X:H24-4Q=_?W=;4U,P0*.6G&LU9S)UAX
MAH3Y.-K;&`&%](3CV&IXDEW$0OV<':R-#;!Y!P`YJS*E!I'LBP````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O:70N<&YG````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P,C8@,3`U,34T,S,W-#<@,#(S,#0W
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____
MT#4VZ-76`'```&X``$8``W$#`W`#!7,%"70)#74-"E$*#W</$'<0$GH2$WL3
M%WL7&'X8$5D1&X$;'X,?'X(@&6(9)80E)X@G(6HA*G4J.)4X.),X,GXR.H8[
M.X<[2*)(4*E01I1&4*=05ZY75*=47K->6:A99+AD9+9D:+IH9;1E:KMJ:;AI
M=,!TPLK"P<G!OL:^O<6]TMK2R=')OL6^R]++VN':ZO#J,(\O/)0[09Q`9K5E
MS<W,ZMO:TAL;WB$AHQL;VR<GJR$AZ"\OKB,CM28FMR@H[#4UNBHJY38UO2PL
MPRXNP"TMR#(QQ3`PSC0TS30TRC,S\CX^]$)"U3HZ]T9&[T1$VS\^X$)"^$I*
MT#\^Y$9&^4U-Z4E)^4]/^5!0]U!0\4Y.[4Q,^%%1]%!0]E%1X$M+^5E8[555
M]EM;T+V]UL/#WLO+\N#@_^[N^NGI_>WM]N;F_O[^_/S\^OKZ^?GY^/CX]?7U
M\O+R[N[NZ^OKZ.CHY.3DX>'AWM[>V]O;V-C8UM;6U-34TM+2T='1T-#0SL[.
MS<W-S,S,____````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````[I1E
M+`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"O241!5!C3
M;<$Q4@)!$`70/ST[.\,6BX)E409&9"3>@LR;F1J;>@"/84B5)B3&A"K;S?QI
M#R#O`?\$]%B6ZV'7)WSM0UD,+QTPYM$]=6@ARGR6(.C+T";O@M=0KF99(5B4
M:+<F;^3SF#,-$3=SU>-JNZE\\(B3?@CN;:W*5DG)R5X;!$<[_-`K21?5QPJ!
MWOW2&\DJ;O0S!/9IC(FL"&TR(P0ZG:5SUJ?X_NUL#1?\`4BU6[IV](=_````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]J;2YP;F<`````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,C`T-R`Q,#4Q-30S,S<T-R`P,C,P-#0`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!(````,
M"`,```!8S!V.```#`%!,5$4```#___\[.CLV-39H9V@?("`K+"P-=@TZFSH$
M;0$$;`$.=PT2>1`GBR8VB35"ET%KN&H4>A!1ITXHB2%7K5`,<0,GB!TG@1].
MH$8-<``1=`42<P45=`DD?A@[F2]`G#5#E3A-J$)2JD99L$]:K5!AKE<=>0U&
MBCL;?`HSCR$B?0,RBQ1(C3!EM4HR@P`YB0>'Q%Y3G!UBHQATLRM7EP6%N$*"
MLQB$L2=A@1F<RC6/L@"1M0>2K"K)YE&ENP.VRQ3/XB_?[F6\R0"_S0K'T#3F
M\3YC9%"(B1O,S`!_?P!Q<``M+0#-S0%M;0&IIP/0SP7,S`7-S0G6U@U.3077
MV!#/SQ+AX1WHZ"9I:!&OKQ_KZRNRLR-V=AC5TR_'QR[Z^D*[NS)!01+\_$:H
MIR___TWL[$BZN3KR\DS!OS[KZE!R<BC$Q$]Y>36IJ5$:&@V1D$U963-K:T)F
M9E`H*"%"0CA34TDR,C$P,"\_/SY!04"ZM@"PK`/5T2'FXS[Q[F21D%E@7TH/
M#@!F965J:FID9&1>7EY75U=145%04%!/3T].3DY,3$Q)24E(2$A&1D9"0D(Z
M.CHX.#@T-#0P,#`M+2TJ*BHG)R<F)B8A(2$8&!@*"@H)"0G___\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````"B:&@;`````6)+1T0`B`4=2`````EP2%ES
M````2````$@`1LEK/@```,!)1$%4"-=C8,`"O#PMU`54%62E):5X-"V3,H%"
MC1$)C@;\XC*2HMR&#O'9;D"A65/KZU+-U;@X-<RB:O/;>X!",_I8BI)#[?3T
M[</3&MJ[*X!"3,UM$V<&5_F'U.3T=73U3P(*-;56LL[VK@X*BRWL[.ACG@P4
M:NF=EN?KXVQD[)J26SJAC`THU%&>Z.=AK<W+H6N;GE$P93I0J"0FP,E$4%A>
M243(U"4NJQ@H%!EHI<4N)J>HK"+!IV,3[8[-.P!7\3(&<G2+VP````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VIO+G!N9P``````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#0W(#$P-3$U-#,S-S0W(#`R,S`T
M-@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/__
M_\H;'/MK;,^3E,D!!L%"1L>UN>'=X/7R]?+O\N7BY>WK[='/T<3"Q+JXNO;U
M]N?FY]+1TNOK[-/9W+W%Q=SAX3H[.^_Q\>7GY^3FYM;8V._P\.+CX]C9V<O,
MS-+4TSE(0"E],#:&.@![``-Y`P6`!0U^#1"#$!V+'2&0(1MJ&R%R(2)T(R^;
M+RA\*#6@-2I^*BZ%+C"',#2.-$*J0D:N1D*?0D:C1D^R3U"S4$ZM3E"O4$:0
M1S]W/UF@64Z)3FBM:&BG:&ZP;B,J(QD:&>_P[\'"P3:0-4>`1EJ760YJ`"XR
M*T%%/EQ?66%D7F5H8A@;%"$D'5-63QD;%$-2"41*"&AH97DM!6I02Q8#`+,M
M'Z82`VHW,ED$`,YH9+YQ;\D``'\``,H%!<D)"<X-#8@*"L\2$L\8&,T8&(H3
M$<\@(-,G)Z,A(=LP+[$J*L@P,.$X.-TX.-0V-?%04.=,3.U04,)%1>E96=!2
M4OAD9/-W=^&$@_&5E<NBHO39V?GDY+NXN/S\_/KZ^O?W]_3T]./CX]'1T<C(
MR&IJ:EY>7E=75U!04$]/3T9&1D)"0D%!03@X.#4U-2\O+R$A(1\?'QT='1@8
M&!`0$`T-#0D)"04%!0,#`____P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#O5
MO/P````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````P$E$050(
MUV-@P`+BHES%.[LG3I_-,'O&E$E]/4"AI*S8\*X)4V<QS)DY;7)_+T@H+;\B
M/E+1)3`DR,<WV#_`#RB46\E<4IS0*.HN+R<I(2.E`!0J;Z@MRD@NJ).6=6MN
M:FUK!PI5U]=DIR0RL8@)MS0)"`IU`(6J2G-26=G813AX.+FX>?GX@4)E>>DQ
M84K*MO:.SDY>#IYV0*'"S`AO-0TM`S,K:W,3(WT=H%!TJ(JJNJ:>J:6-A8>Q
MH:XV-N\``.3<,7^ID\<+`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M9FQA9W,O:V4N<&YG````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#(P-#0@,3`U,34T,S,W-#<@,#(S,#,R`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````2````
M#`@#````6,P=C@```P!03%1%````____DQ87NB\PP#4VP3T^M#H[NDE*YWU^
MJ%U>QR\VR#D_TT]5O4Y2R%5:U5]CZ6]T]WA]\7=\O3$XYVUS^(:,`P(#/SX_
M>'Y^?8&!.CL[J-JV;:A]`'`;`W(="70B#7LG'X,W&V<M(G(U,)E(*GL],(1$
M-HU*4:UF(8@X1*982J!=,(Q!4:]D7[!N99IO;Y5VGLFF(8`P9YIP<:!YAK*-
M>)]_@:F(H,JG`&P0!6\5&'LG(6PL*'8S+G\Z-(A!.))%7:MIC[B5!7`20IA-
MEY>6FX%@J(]OFV90Q)1_44Y-HP``/@``HP4%M0D)-`,#EA$1O!@8O"`@MR8F
MH"(BS#4UNS$QM3`P6Q@8RS@XO30TOCDXYD9&UD)"T$%`ST)"PS\_U$9&ZD]/
MYU!08"$AWTY.XE!0S$A(X%=7O$I*NTI*4R$AV5I9Y5Y>NT]/Y&5EZVIJU&1D
MH$Q,U6AH[7=WVFUMUW)R62\O]82$ZH&!](B(S71TZ82$I%U=]YB8&Q@80#T]
M55)2:&5E<W%QEI65HJ*BE)24C(R,BHJ*B8F)=W=W:FIJ965E86%A7EY>4%!0
M3T]/1D9&0D)".SL[-34U,C(R+R\O(2$A'1T=&1D9&!@8$1$1!04%____````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````4*+?@`````%B2T=$`(@%'4@````)<$A9
M<P```$@```!(`$;):SX```"]241!5`C78V#`"F9*=3=-GC5'K'[V]"D3^T$B
MLZ?V]#4WID0T>,V8-FD"2$B\MZVU4[(V*Y-3HJNCQ;4=*%1475=3G!<0S1I2
M6%)155D&%&(KR(@,]/4)#LL.C4E.C8\""N7GQ@7Y>?LS)Y3')J4ELH0#A41%
M>+BYA)G2<]B%!`7X^7B!0A:F)L;Z,AZE')[2AD[F9@9`(0=K*TMG(QTW=SU'
M%WL[6QN@D**\K)R"IHJ6KH:VNIJJLA(VSP``<^DQ`&#?=8@`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]J<"YP;F<`````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3(S-2`Q,#4Q-30S,S<T-R`P,C,P
M-#4`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```!@%!,5$4```#_
M_____O_5U-7'QL?4U=7&Q\?!PL*RL[/4U=3GY^;@X-_=W=S5U=3-S<S`(0"_
M(0#!(P/#)07$*`?)+0W,,1#2.!C4/!W802'?2BOB3B_L7#[V[>N_'@/'*0K(
M*`S.,13#,1;*9%+I>V?TAW/VCGSWD8#8A7?!&@'`&`&_&`'$,AS;/";;/2;E
M2C7H43KN64+';6#UD8+'>F[-@'7(@7?@H);ZMJO5G)/WMZ[QO[C,IZ+;O[N_
M%0"_&@7.*!3R6TKS7DW)E8_3NK?RZNK8U-3X]_?^_O[]_?W\_/S[^_OZ^OKY
M^?GX^/CW]_?V]O;R\O+Q\?'N[N[L[.SKZ^OJZNKIZ>GGY^?EY>7DY.3AX>':
MVMK8V-C6UM;4U-32TM+0T-#/S\_.SL[-S<W,S,S*RLK'Q\?$Q,2_O[^\O+R[
MN[NYN;FRLK*PL+"GIZ>=G9V4E)2+BXM_?W____\`````````````````````
M``````````````````````````!5I!6J`````6)+1T0`B`4=2`````EP2%ES
M````2````$@`1LEK/@```+9)1$%4"-=C8,`"BHKRV1C]H^)34A)B(@,\W4%"
M!5E^WN'.IL;6L5%!WHP^0*'"G#"/8`M%+4UY]1!?1J\@H%!>'%.@C;8LO[""
MCI6[1P`W4(@%:)")G8"0J(2>D;M_1#Q0R,V;B]705E!$7,I`S2>4.14HY!$<
MD^2D(2<F*>UH&13-QPX4"N1)3$E1LM?5=U!UX4Y,SP8*@5WD:J:L8BX3$9^6
MF0L4XDQ.28*X*)0W-8,C#YMW`/";)^?DRXHD`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]K9RYP;F<`````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`T-B`Q,#4Q-30S,S<T
M-R`P,C,P,S8`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,
M5$4```#____ZUD+QR37+G`'*CP/2EPKSO3K,BP'+C@7/CP?-DPW9G13<H!CV
MOS[*B0#)A0#EI";+@0'4C0WBG2'KJB_)>P#-AQ+=E!WHHBO[MDK\N4W*>0/1
M@PKEFB;8@Q318Q#*6`717R?U@D;XB$_%.@#)/@?%00G63QCV@%'+1QCT=D;H
M7S7$+`/K83KR=5'!)P'91"'+01_43R_U<5#`(0"_(0!X%`!X%0#"(P._(P/#
M)07#)@7`)07!*`G*+0V$'PK,,!#$,1+&-AB,)A'5/!W802'*/1^5+AF?,1O-
M1">G-R&J.B/C32_B3B^?-R&P/B;22R^S0"CF4S6V0BJ^1RZ[1BVX1"S!23"I
M0"K#2S'75#C+3S7)3C3%3#/L7#[+3S;O8$+05#JS2#+Q9$;<6T#663[;7$*^
M43OT:4W@8$;?8$;D9$GB8DCT:T_U;%#H9TSK:4[R;5'O:U#Q;5'H:U#G:5#+
M74;M<%?L<5?P=U[@<%GT?63S?&3O?67N?67V@FK`'P"_'@#!(07**@W"*@W,
M+A#',AC).2#?1RO743C74CCO74+<6D'S94KD8DGB7TCU:$_H94SS:%#K9D[O
M:5#U?VCN9E#___\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!LQ)&+`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@``
M`+])1$%4"-=C8,`"+,P],AHJNMN;FZP=W8)3\D%"+LGU5;U&ZJJZ+:Y^B7G%
M0"&'R.K:"4K<+!RR&IWQF24Y0"'_\FEEQN*L`EP\<GI]105I0*&,ALHN+4XQ
M10419N7)A>FQ0*&ZJM0.=7X980E1)I7IV0D10*&:7*]6`R$V7DD^:?W^I*AP
MH%!IH)-5HYJ\(+N4YJ2TN+``H%"TLZV939NACK;)E/38T"!OH)"[G:FEO:MO
MS\2I63$1(3Z>V+P#`/Q:,%QV;[SM`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+VMH+G!N9P``````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`R,#,R(#$P-3$U-#,S-S0W(#`R,S`S,@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````$@````P(`P```%C,'8X```,`4$Q410```/___\,2%H0.$,`5%\07&](;
M'\XJ+=\Q-+`K+=(U-[LR-*HN,.U$1O525>1.4>).4/%76>A56.!=8/1I:\5P
M<>BIJO.SM,@.$\8W.\!O<=R.D,^&B>JAH_.SM1P4GBTDK$`XNU%*R%A0Q5M3
MS!$*ETQ&MQ43G#X]K`P+F0<(80P,F@\0G1$2G1D9I2,DIAD9=2@ILBHKJ2DI
MCCL[P3$QF#<XHD)#N4U.SCH[FTI*OEE:U5I;T6=HU&YNU``-J``(:0,0J@41
MK`42J0D5J@T9L1`=M1@DL1TIO2$MPA\KM!DAAALCCB(LF2\[S#5`T"HSI#`Z
MKSA#PS8_N$)-V492W#I#KD90S$]9WU!;X%!:VE=AVFISY-2\K_CDVLVLG>O3
MR?_JX=[!MLR9C,Z=D>&UJ]:LH^[!N/K2RLR"=-B5BONMHO*SJLU(.-%61LQF
M6]"`=\\O(>A&.,Q$.>1E6LTC&/]L8\X2#=(J(]@L)Z<E(<$P+,HU,,TW,=(Y
M--4Z-MH^.N=&0.!$/N5'0OY02L<_.^I+1NY.2>Q-2/)13/U64?933O%54-1+
M1OQ>6/9<5_IB7OUH9/]L:/AJ9?]N:LP#`]L4%,`4%,$8&-0@(-TR+_4^.N$[
M./Y24/E04-9.3O___P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#A1R#0````!8DM'1`"(!1U(
M````"7!(67,```!(````2`!&R6L^````LTE$0508TVW!,4[$0`P%T&][,A%$
MBE:LA$1/`2>@Y5Q;(%H.P!DX#344*#5+@<1&428>C\T!X#W@#\(]AB''NIA)
MDIS32\)7WN9H96%AD20$@ISU9&M]IL=O[DC\AW#8=SJ^7;_3S<?M,<?VP!CZ
MMIO*)#;I?$5J2!CM=-ZT<LSTN:OF2/!2)C7OW&4YJ@<(%Z7&9>V#:8NGP\E7
MPEUQ5R4B#N$Q_#5AKY63Y)RXF4<+_.,74Q=:)VJ->[8`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O:VDN<&YG````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P-#<@,3`U,34T,S,W
M-#<@,#(S,#0Q`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!0
M3%1%````____Q#H[^F=HOHN,RZ&BOI::U,;,IJ"JF)BHGJ3$JJ["5V&*G*._
M5&*28&^C@8V[?H6?BY&HMKS24%V'<7N<E*#%@(JI<GF0BI*MGZC$@8B>J;'+
M9'"48W"3<WV:?8:?AY"KG*;!GJ:^<':'D9BLC)*D/5"`56.(5%][AY2V>(*<
MFJ;%J++,?H67N\7=F)^P;WZ@>8>G:G6.<WZ89G"&DI^[DYVSC92CL[K)=8&9
MAH^ANL3905F%2F&+>XFCP,S=U]G%S-8AN\0%Q,L0P\HGW^8]Q,:2WM^/TM(-
MW=P=LJ8`NZ<`L)<#M8('N8@)KG4`[<A^P6\4N%T!VX(UPW]'MT0!M3@#OT\?
MP#\-N#(%PRD`PR(%[6A7QA4%P1D*RR88V$8XW$]!W#$F^6YJRFEF?0``?```
MQPX-B0H*T!00QQ02V!D8SA@8D!$1W!X=X"$ASR`@FAD9U2<GYBLKZ2\OI"$A
MV2\ORBTL[34U\#HZKBHJW3@XSS0T\SX^]4)"N#(R^$9&]T9&W#\^XT-"X4)"
M^4I*PSL[^DU-Y49&ZDE)Z$A(^D]/^U!0^E!0[DQ,\4Y.^%%1]U%1]5!0[5!0
MT$9&\5=7TDY.]5]>Y5E9]F)A^&1D\V5E^VIJ^GU[_HR*^)22____````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+<:<E`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX`
M``#`241!5`C78V#``M+2B]I38A,3XJ)CL@HJ&WM!0GD-<V8D1?C[^$;FE];W
M3`8*95;/G-U=G!$6')]34M<QJ0LH5#:5>4IY=GB`7U!R5=O$_F:@$-/<:36Y
M4=[.+DXA37T36FN!0@OFM116A+IZ>KD%SI_5.3T5*&3#S<;"*6KA[N&H[\#.
MRF$-%#(SM+-5%^'C%Q#3T3*RM](#"BDJ:`O*RXKSRN@JF0M)2V@"A51--'CD
M))6EN(0M#=2,356P>0<`RJXRMOA]M.\`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]L8BYP;F<`````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,C`T-R`Q,#4Q-30S,S<T-R`P,C,P,S,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!(````,"`,```!8S!V.```#`%!,5$4```#____,'R'-*"JP*"GR14;\
M5EC^6EO1PL/][_#;S<_4SL^+AH?.R<K__O_5U-7'QL?4U=7!PL+\__[.U=&_
MR</L\^ZXP;JRPK7+S,LK92/E[>22IX]VDW!ZH7&!HGE5>$Q$:3@K7!DW82'P
M\>\]61EB=#^KK*#GY^;@X-_-S<RWMJVB=52UA67<N:[0K*+$N+?,``!_``#.
M`P/0!07,!07-"0G,"PO6#0W8$!#0$!#,$!#2&!CA'1W8&QM_$A+D(2'4(!_.
M(""=&1G2(R*G&QOD+"S6*2GN+R^R(R/R-36_*BK*,#"4)"3A.#C5-C6\,##Z
M0D+4.3G'-S;\1D;A0D'2/3WJ1D;&.SO_3T_N2DK^4%#Y4%#E2TOV5U?Z7%R[
M1D;G6%C_:&C_:FKY:&CZ='3W>GK,N[O,O+S/P,#\Z^O=SL[/PL*YK:W@TM+R
MY.3QY.3>U]?_^/CX\?'KY.38TM*RK:W]]_?[]?7NZ.CLYN;IY.3X]_?=W-S^
M_O[]_?W\_/S[^_OZ^OKY^?GV]O;U]?7R\O+Q\?'N[N[L[.SJZNKHZ.CEY>7A
MX>':VMK8V-C4U-32TM+/S\_.SL[-S<W,S,S*RLJGIZ?___\`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````C^%JL`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```,!)1$%4"-=C8,`"C(R<(Y+C_&Q,
M#4TL';Q"HH%"]KX)::F)0<Q,3NY^4?%)*4`AGK+J\JI27G5M[L*2XJ**2J#0
M]`E\[;63Q!451+I;Z^K;-(%"`HPMO1,E9964Y54:ZEIZ)@*%:IHT!*?(2*FJ
MR4DS-G?Q3P,*U7?V3YXJ*J&C*R;<V-&G)004*LC.3,_@X-+7R^+,S\LQR`4*
MA;I8FUO9N;&RL<?%A@4'L`"%',T,C2UL/0(C8\+]?;P]7;%Y!P#=^B_WQ"+_
MY`````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VQC+G!N9P``
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#4P(#$P-3$U-#,S
M-S0W(#`R,S`R-@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`
M4$Q410```/___U-/47QWC&)=?%-17594:9*0ISDU>#LW=T,_?T`\>4Q(AF->
MGU=4B4],>F!<DEM8B')NJ&=DF&UJGVMHG&MHFF)?C6]LGV)?C'1QIG-PHV-@
MC'][LGY[L'UYKGIWJWUZK(.`LXZ+NVMIC9&.O921P).0OUQ:=G=UF#(O=B,A
M220B2C\\?CTZ>D`]>D9#@DI'B2XL54A%@T9#?TA%@4I(@S4S7%)/BT],A5=4
MDE%.AU%/B%11BT$_:SX\94Y,?UA5C$A&<U]=F%M8D$I(=49$;F-AG&EFHF-@
MF%Y<DE12@E!.?%=5A594@U]=CUQ:BF%?D75RK6=EF75RK&EGFWEVL&9DE5A6
M@&%?BX%^N'QYL'9TJ']]M(!]M'5SIH%^M75SI7]]LGY\L8!^LX*`L8*`L(B&
MMX!^JXZ,O(Z,N8V+N).1OV1C=C,Q<T)!@TY-=VMJHUU<C&QKF'Q[K%14?9"0
ML$E)4S`P,7AY@3<Y0C(T,P@)"`,#``D)!QX>&QL;&1L:$6-A6.2V(>BX)K61
M(/7'.NK"1O[44+ZA0>&P'9UY%*F$&.ZZ+[Z8*_K(0LNJ2A@5#4E&/IYV$/*[
M-?S(1O[.3_G*4,BF3BHF'1(/"H-_>TI*2A`0$`4%!?___P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````+I26U@````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^
M````P4E$050(UV-@P`)TM.TE<Y0\-57R](RM/,(2@$+:YA'9Z2(NK.4&7!;N
M(;')0"&C@@SE1%N9^@9Q0V<AV:08H)!;L:JB%P];;5TN;V%TBH(84"A2/578
ME*]BWMPY:4%Q\A+^0*&L=`EK78V:B3.KV:/DI`,%@4*9\8[ZEE6S>OHF5:I)
MA0=X`X5*!$PX2AN[6]HF-)6)%OGQ`X6"S3CSF28W3YG:,6-VJ*^/$U#(AEN+
MI;6KMW_:]/9.9@=7.VS>`0";H#&[TU@A0P````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O:W`N<&YG````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#(P-3`@,3`U,34T,S,W-#<@,#(S,#0R`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````2````#`@#````6,P=C@```P!03%1%````____QSH[KFMXNWF&L8:/
MR9FCL72!L'2!R8R9MX./UJ&MIGV&O(^9XJ^ZS9^IY;2_W:ZYFW)\QY:EV["^
MLX.3HG^+V*R[V[&_V;&_IG6'J'>)9TE4J'F*L("1O(V>RIVMWK3#>UQH!1.!
M`PQ0"1B%"AB#%2..'2J.)C2<'"9L("MU.4:L/$BC-D&325>Y2UBY/4B33%FO
M56/`5&&^5F.]6V:[;7?'!1>%"!F&#1^($2*.(3*<(S25)S-_-46K+SN).TB<
MR\[.Y>?FS)F4Z[>SBQ(,ZS<NN2TFSSLSX$8^_E-*_UA/\E1,\5A0^UQ4RVYI
MT'9PV()]_;&LS`D!S0X%R@T(U!8-VQD4WB0;Y"<ASB4?SR4@VBTG[C4OW30O
M\CLUQ#0M]4(ZRC4PLC`JS34QTCDTU3HV^DA"^$E!VCXZX$(^_$Q&Y4="ZDM&
M[DU)_U5/_E90\E!,_5E1]E-.[E-,ZT]+^U51^550Z6ED]HN(^Y:3QZ>F\MO:
MT0D'RPD)V!`0X1T=W"<CZ"HFZRPKSRDGIR,AP2\L]3XZ^$(^_DY*_U%-_551
MTTM(R$A(S$Y+TE11_65D^&5ERUA6T6QLX8*`Q9&0UZ"?R)N:QYN:RY^>U*BG
MSJ.C_-+1\?'QSL[.____````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````]>V)V0````%B2T=$`(@%
M'4@````)<$A9<P```$@```!(`$;):SX```#!241!5`C78V#``E14M`S-S70U
MU)15U35U#$R`0C)*8B(2PJ*R4M)R\@KBBI)`(;>4RF#7H.B0T/!(]TP?_U*@
M4%OOW'G3Y\\(JXMH[NCJ*<H&"C%5UTYMG5S3WQ"5D%-8DIL&%)I4Y3REOL]I
M0F-<1D%%7GHR4&ABV>R9LZ;-:6KI["[/STIM!PKYQ<<$N`3&-B=Y%_MZ>29Z
M`(78N#B8V5DXN?D$!/EY67F$@$*V5A:6UC;V^L:F1HYZ#G;:V+P#`&^[,E?S
MFOCL`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]K<BYP;F<`
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`T-2`Q,#4Q-30S
M,S<T-R`P,C,P-3``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#
M`%!,5$4```#____@3U:E$#&>46J8(4I>`T!J#5/5U-7'QL>$59I*1)8@'9N9
ME]<*"H\8&)HK*Z8O+[$^/K%'2+@[/:R0DMB&B+^'BKKQ\OKV]_WIZN_`QL;-
MTM+P]?73U]?Y_/S4U=7!PL*RL[.DI:74U=2OL*_%Q;_[^_G7U]5S<W+IZ>CG
MY^;@X-_-S<R3DY+_]O#\]?3HEI3.I:3-`0#*``#0!071!P?,#@[;%!3-0#_,
M2$C4CX[/JJKX]_?,R\O^_O[]_?W\_/SZ^OKY^?GV]O;T]/3R\O+Q\?'P\/#N
M[N[L[.SJZNKEY>7DY.3AX>'?W]_>WM[=W=W:VMK4U-32TM+1T='0T-#/S\_.
MSL[-S<W,S,S*RLK(R,B_O[^\O+R[N[NYN;FXN+BTM+2SL[.RLK*QL;&PL+"G
MIZ>EI:6DI*2@H*"=G9V;FYN9F9F5E964E)23DY.1D9&+BXN)B8F%A86$A(2"
M@H*`@(!_?W]\?'QZ>GIW=W=R<G)M;6UK:VMC8V-*2DI#0T,]/3W___\`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!T!4?"`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK
M/@```+Y)1$%4"-=C8,`"*BJRE=U=_$*BHL+"4[P=[4%"^1GY>6'!D5$18=7U
MX8S.0*&BU)SB0CDC*TOK`-7R8BU/H%!ZL&^NM(VYL9F%H6Q6C)L.4(B3T250
MAL7$E)F5R4#>U2<$*&3KI*T0R<W&SB/(I>_LS1$-%'+PBBY3$^?C%Q#B54^.
MU54$"KD'U39IAHJ)"(M*:E35)24`A?Q""AH:$WVE).P]2FOTXM*`0BJ1=I69
M_IY.C,[>\24I2NG8O`,`B.HJKH'2&',`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+VQK+G!N9P``````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`R,#0U(#$P-3$U-#,S-S0W(#`R,S`T,@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$@````P(`P```%C,'8X```,`4$Q410```/___P9#`!A6$2F"'Q5S
M"6ZW9!10"B5^&"MJ(3R.+S1U*D24.$6&.U6A2%RH4%&41FFS7G"U97:[:A=0
M`!=/`,SA-<34)O+X/O3Z0OO[3?__3^;F2?GY4,W)&.GD1NC9+]3".LBO%-F[
M*]BV'>[*5\F>(8!E&?#'4<&-"L*5,__2:LR(`,R)`="+!<V+"=*4&-VC+]JG
M0>RV2)=A`)EE!9YM$L"''=>;*ZI\)\^=/NBP2KR00/K!7LRC5\2>6=>O:-:)
M#=ZA.I=Q,KJ"+L-V$."=1K9C`+=E`;=G!;MI![MN$L1[)\:$.^.<3N>@4<%Z
M-*A7#>2//I94&^B54.:54,Q8`[-0!<Y?#=1L(.&`./&44,Q6`,Y8`[9/!_VD
M9/>@9;%%`>2$2N:&4*X]`+I*$.2!3<9F..)^4=9F.MUX4+=$&,A0)LY9+\Y:
M+ZDK`==J3J49`*8=!;`G$*PO&+(W'\Q,-=A=1J@:!;PT(:\=#;1$-K@H':$T
M*J4W+=!63*$)`)TO**HX,*LW,==949$F(<DZ-;(X-<-(0L%&0M144)H``*`#
M`YT#`YH#`Z`*":,*"IX-#:D4%+DD(9(C(Y@F)J`L+*@P,*\T--)$0M!"0KP_
M/M)&1L5&1LE)2=A/3]9/3\Q,3/___P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"7L:_8````!8DM'1`"(
M!1U(````"7!(67,```!(````2`!&R6L^````ODE$0508&67/L0X!010%T#=O
MAC5B$;(VF8@0B49$PP\H_)-_\A_4$E'91",*!&N%W7WSC-HM3^XM+L!?!`3<
M'$3IS+?L9442^Z6"BQ@W;TG5W"M7_1AZ,2@HJ)Q?IAT]UHDQ[\X$$+`@<LN4
MT.=3KF-&CI2TS)9B3[&*CYI^0_LC3#>IW"*.:J[U)&(KI#F_A<]88D<Z)\N(
M8MZ?+CHZ8S=T4,1,F%;JGUIE>0,)EL,@/S1Z2G>?H0E6N[\[`%]V\U/^2MW5
M<`````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;6$N<&YG
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$W-S0@,3`U,34T
M,S,W-#<@,#(S,#0Q`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````5````#0@#````<4S54@``
M`P!03%1%Y0`"X0`"V@`!W```YP``Z@``Q@``U!4`R`8`TP8`V@``Y04`T```
MW@,`Y0``Z0``Z```XP``_P@8^PX8[Q,5YQ`-Y`D#Y`@`Y@H`X1,`TAL`VRT*
MWRL*UQ4`XQ``Y`\!W1(#X`T"[@4!]0,"\P,$[0,"Y@``]P`$[``"V@4`T0P`
MTA(`TQ<`T1H`R!\`P2\`P#,`V#T-QQX`V!D`TQ$`V"4'SQ$`[0@"^`0#]P4$
M\@0$[`(#_PD-^@8&Z@X"Z"$*\3H:\4H@Y$H8TT0*V%(5RT4(XD\9Z4D7\4$8
M[3D4]$8A\3(6[08`^0$!]P$"\P$`ZP``_@``]@``\```Z0T`X2,`V#8%R$(#
MQ$,!S3T`OB0`Q"4`YD(-V34"W3$#Y"0`[QD`]@4`_@(!_`(#\``!^0$`_@8`
M_P<`\@<`V0T`S"``RS\!UE41SD``PBX`NB8`W4<,TS8`W2X`WQ``\PT`^@,`
M_P$!_@$#^```\@``[@``]04`^P4`\0(`Y`(`W!(`VS$`W$P/QDD&OTT&N$8`
MP$,!T3@`W"4`Y0P`_0``^`H`]@8`]P$`]`0`[A$`Y1T`U"@`R2X`TD,)W549
MW%0:OS``US<'V1\`[!(`]0@`_`,`_P(`_P("^P$"]```^P(`^P``[P<`X1X"
MVS,,U3X1USD,W!<`Y0\`ZA0`\"4'[C<5ZS02ZAP$Z`4`^`,`_0`"^0``_@4#
M_00"\@H`XAL&VRD+U"L*VB$#[0<`^0T"[B`+Z2$*Z1(`Z`$`^00!\0``]`0#
M^`8%^0<%]P@%]@T(]1`*\`T&ZP0`^`4!^@$`^`,"]PD&^`H'^`8$]P(!^P,#
M^0,$]`$#[@`"Y@(`Z@4"\@0"^`0$_@8'^@(#^04%]`0%\P,"]@("^P(&_`,'
M[0$#Z``"UP<`W`@`XP8`Y0(`ZP$`\`0$[@0#Z@(`YP,`Y04#XP0`X`$`X@``
M[P$!Y@`"X```````````````````````````````````````````````````
M````````````EAIF$P````EP2%ES````2````$@`1LEK/@```'E)1$%4*)%C
M9&`$@?__F1D1X!.C$",VH(Y5U`:K:""FT&LQQE2L:JM0N9]?J3"\9V3LPJIV
M%BN:P`E+QI.,&QF@O!\?),'TSC>O"QD/P!4]EP)38%67&?TV`ZF%"0D+&1F+
M^AD+^CQV,S(^A*K4N`DBE;->=?EN800`=+$?D-1RU?D````==$58=&-O;6UE
M;G0`0W)E871E9"!W:71H(%1H92!'24U0.80Y)0````!)14Y$KD)@@@````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M;6,N<&YG````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P-#0@
M,3`U,34T,S,W-#<@,#(S,#,R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````
M6,P=C@```P!03%1%````____QSP]_V=HU;.TP<+"LK.SU-74X.#?W=W<U=74
MS<W,S0$`S```?P``S0$!S`$!S@,#S`,#T`4%S`4%T0<'T`@(S0D)S`D)U`H*
MU@T-S@T-V!`0BPH*SQ(2VQ04V!04WA@8TA@8E!$1X1T=TAL;Y"$AU!\?Y"0D
MG1D9Z"8FZRLKV"<G[B\OIR$AW2\O\C4U\C@X]3HZLBHJX3@X^#X^^D)"X3L[
MTC<WNS(RX#\^_$9&YT%!_DI*_$E)QCL[_TU-Y45%[DE)[$A(_T]/_E!0\DQ,
M_5%1^U%1^5!0_E-3]E!0\5!0U$9&]E=7]EE9^EY>Z5E9_61D]V5E_VIJ_VQL
MSJ2DS**BS:2DUJRLX;BXU*^O[L?'RJJJ^M34Y\3$_]K:^=75ZLC(^MG9^-G9
M_O[^_?W]_/S\^_O[^OKZ^?GY^/CX]O;V]?7U\O+R\?'Q[N[N[.SLZ^OKZNKJ
MZ.CHY>7EY.3DX>'AWM[>V]O;VMK:V-C8UM;6U-34TM+2T='1T-#0S\_/SL[.
MS<W-S,S,RLK*Q\?'Q,3$O[^_O+R\N;FYL+"PIZ>G____````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````WB"'_P````%B2T=$`(@%'4@````)<$A9<P```$@`
M``!(`$;):SX```"]241!5!C3;<$Q3@)!%`;@?][.SIN9!<3$-4:NQ`5L20PG
MD`I+>QL-L;2BIO4"'L`SV$@(`0'G[6/'`\#W`2<,>AA<U_*]VB078JSB!P%U
M_TI7VUVR[-D%"\)%_R9OU[^)/+./-H%P>;N0Y>:@S@7VW/Z!\.6'/WM!K`)W
MNK9I83'*VCGF7!@B,N;][M."JLB4I9'T.O:1YR"$F2.H:B/W;L;3)Q#\0P'5
MHP@<3THR(#R7:%6E>2OYA>G1X(Q_VG5"2%9DG?D`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]K>2YP;F<`````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,C`T-B`Q,#4Q-30S,S<T-R`P,C,P-C``(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___^KDIN>
M@H[9P,M:14^UHZR3=H9]5&^YJ[7%K[]B6&)[8GZUJ[K(O-!?27:@FJ9Q8XAK
M7X"9C;0^,&B'?*B4B[!P:X`],6I327QC6HM".7!<5(AO:)=Z<Z(W+VM22H)7
M3XI=591&0&M43GQ84H!Q::%?68AR:Z)U;:1V;Z1]=JI\=:=Z=*,P*6<U+FHU
M+FDW,&PW,&LY,FXY,FT[-'`\-7$]-G$\-6Y!.G5#/'A$/7A#/'1'0'M'0'I+
M1'Y(0GA/28)028)33894389.2'T_.F1;5(]848I43H-<5HY@69)A6I)(0VU4
M3GY,1W)<5HEE7Y=02W=.271E7Y9J8YMO:*)74H!P::%<5X9N:)YD7H]X<:IN
M:)MU;Z5H8Y)X<J=L9I9[=:ES;9UP:YIY<Z5T;IY]=ZI\=J>+AK.(@Z^*A:\V
M,&XU+VPT+FHW,6U(0GYB799/2WEE8H!F9'D[-W,[-W)'0WB"?ZZ*B*="0'AS
M<HJ#@YA?9I:9H:"BKZ>YS;2@NI&NQ9N6GX;(HGRYFI#J@VWGBG?S@&NJ64N^
M:5OI@W+NB'>185CVMZSCJJ"W0S/`2SB`,27/7TW7<&&YA7UR2$7#B(2Q<7'_
M__\`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````#/`T+P````
M`6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+])1$%4"-=C8,`"
M6+E+NOBX>&OS#8RM70*UTH%"TWJG]O3U3Y\AD6OII!26G@$4FM39WM$V>>($
MD5)[]YK*I#2@D#@;2S<G$T^YF9VB6F.=9CQ0B%E8;(I@%3N'E7.A:$MK;"10
M**M"EE]:+T=2P3LBNZ%>*APHE)GL698G;U[@%14CT-0L5`04T@VP,=(WM?4(
M34B7JRY6\0<*13N8Z`-=%!*7GIHHXQ>L#!1RM=`WM'3TT=#625%7#?)UP^8=
M`$?I+^I,RB,H`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+VUD+G!N9P``````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#(S
M(#$P-3$U-#,S-S0W(#`R,S`S,``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P``
M`%C,'8X```,`4$Q410```/___]4U-@`7E#A+LU!BQ61UTP`06@,:E@,:E0TC
MF!\THR$R@$%6MCI+H#M,GEEKOV1WT65VSVA[TV9XS0`;D04?DPDBE`H;9A(K
MF1`GB!(JBQ(IB1@PG!$B;AHRDA\WH!PRBQDJ=R<^I3!&JBH\BCA.L#)$E#U1
MH4A=O$99JU!EPE=LQUYRS%1FM6I]TVEZQ72%S"@^DW5_4G5[,9J?"JFN#\;(
M"K.U"[W`$<O-&LK,,'U^/LS,`,[.`\S,!<W-"<+"#=+2&%I9"^3D(=34'[FZ
M&]/4)N[N+^'A./KZ0O__3_[^4/GY4'EX)]S<2-321NOL7JRH`::A`<O(-=/*
M-?;L3N_F4=#"!=;)#=O-&-#")NK?1JB9%'!H%.+40NO=3=+&2I6-265:`U)(
M"8%K`(-M!XAV)YR*.WIN069)`(!7(:8\!;%'$/Q81O]@3_MA4>$K'>LY*_5+
M.M5!->5.0O):3-@>$.0A(:<;&[`A(>XO+[(C([DF)KPH*/(U-;\J*L0M+<$L
M+,<N+LHP,,TR,=(T-,\S,_@^/OI"0MHZ.N`_/OQ&1N5"0OY*2NI&1O]-3>Y)
M2?]/3_Y04/),3/U14?9.3OM14?E04/___P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````&/D!B8````!8DM'1`"(!1U(````"7!(67,```!(
M````2`!&R6L^````K$E$0508TVW!74I#00P&T"]S)S=P]8(_6+%%6M#M^>@*
M7*!+*/5!$0KZ4%J3F20N0,\!_B`(5ON'S8]ZK-8DLSP5X)9K1H\@LF$:&067
M\GF(?;^^4:)96%%QN!K2SNX+G3N-[(:"@>]R^A:1V1J3-A1P[.0K[>TU)F)]
M#A1X7V0;MN\G)=+V$JA8ZC&#EH^DIX5Y[ZAHZD;T<='[E,W=46&67&<Z4ADS
M/!+_^`66P%0!2XDIKP````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O:WHN<&YG````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#(P-#8@,3`U,34T,S,W-#<@,#(S,#8Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____`(;,
M`(?,`8C,`HC+`XG.`XK.`XC,!8O0!8K,!XO1"8K-#9/6#8W.#8S-$)78&)O>
M&)32'9_A(:'D(:+D'Y?5'Y?4&WBG&G&=*ZGK)YS8(H.S(8"P+Z[N+Z_N)HBY
M*(J\-;'R-;+R*Y#"*HV_,:+:+9'$+I3',)?*,IG,.*?A.*GA-)W2,YO//KCX
M-I_5-J#40KSZ0KWZ.J3:1K_\0:_G/ZG?/ZK?0J[E.IC'1K+J1K/J3</_2;;N
M2;?N2+3L3\3_3+OR4</]3KSV4</[4,#Y4,'Y4+OQ5\'V7L;Z6KCG9,G]9<7W
M:LW_"8K(%9#,*Y[3-8ZX1*_C1+#A3L/Z4,7^6L'Q:\SZ&)'&#(R[+ZG75</L
M7,#G6[WA7\3I'Y"U*9B]3+[C8<CK'9:W5,'B%(ZN&)"N&8^L:<KC()&H2KG0
M-Z"S0++(%EQC.H*(5*"G=LO2@,_75;2[7,''@=39&EYA1:6I<\W.)VEH6;JV
M=<C%.YV5/J"8.IJ%4:Z/;;N10G=47JIVB,R5CLF6@K:*G=>E=K=Z:Y=C@[MW
MJMR;06DQK-N:M..C;JE3<:A1L-V5<Z=.AK9;?*E$O^!UJ,53E+$VS,`*V,L0
M____````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+0?X20``
M``%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"_241!5!C3;8M-
M#L%`&$"_Z<P8M.HGU<2.Q,Y>@L1)G,,QW,%"(A)+YY&F40LAA$[G5XTU;_GR
M'L`/");=U2#2:29DA=&P,]@1$'RBS?6B!"&XU@P>0,!G$O&36,39GK5](ISB
M0>.>S=&(1$4ON5D)'J!JF<[&`4:XU0]1D;O*L_92>NA<?RICBL(XA945FWK7
MR_(X.4JEW5BAI7JO[R@>1E>I[+<2K%2,;L-IX\6Y5M8I$APHP7[[1'ENK#;P
MAP]1=%5#]-^>WP````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]M9RYP;F<`````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`R
M,"`Q,#4Q-30S,S<T-R`P,C,P,S``(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,`
M``!8S!V.```#`%!,5$4```#______O_'QL?4U=7&Q\?5UM74U=0G?0HTA!1/
MGB]&ABQ.C34[C1A!CR%-G"M-C3%?JSY6F#I5D3ILMDUFJDE=F4)OM5$W;QM+
MEB8]=2$_>"-#?29$?BA'@BI9HC5*A2U>ICI1CC-FKT)IL$9AH4)LLTIFIT9Q
MM%!LK$QRM5%NKTYJI4],ARY/BS!5E#53D#1>G#YRMT]RM5`N;@,^>@U,B!U>
MF"]6AC!7AC-<C#9OIT)MGT9ZKT]YK%#GY^;=W=RY&P7!)A#.-R'<2C7#1C3H
M6D;25$+K8U#C8$Z[1C?%$0#!#P"_$`"T#P#`$0&_$0'`$P/)%07%%@7&%0?&
M&0K`&`G)'0W1(1#0(A31)QC,)QC4+!W=,2'=,R;>.BOB/B_K1#7J1SKL3#[N
M44+V54;;2C[T5TKZ7U#S6TWF5DGS74_I6$ST75'Q75#P7U'RB'_()Q_'2D+/
M7%3><FK`"@/!%0W;/SC__O[Z^?GX]_?LZ^O=W-S2T=']_?WZ^OKW]_?V]O;Q
M\?'L[.SIZ>GAX>'8V-C4U-32TM+/S\_.SL[-S<W,S,S+R\N[N[NRLK*GIZ>=
MG9V4E)2+BXM_?W____\`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````"6U9^"`````6)+1T0`B`4=2`````EP2%ES````
M2````$@`1LEK/@```*E)1$%4&--MP3%.0E$0!=`[,W?>)RJ6;@F(R]'$PF@(
M%0NP<"\&.DHJMV!/B,&\_/]FG@O0<X`_!&^(QX<Z?-4Z%"?M78&,9^$XC<5I
M5@H4/7Y2NX]*,W,V***^4GIO3AH9#0++->N1WR*B*ID?Q)/O#]O3)")4R4P0
MY.)>/INKFF7D!(*[E?8A;F;./CMGNRAL:0CS8G-I_3H2BHTA7^X:;R_M*L^9
M^,<OE]Q&E7\/<@``````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VQT+G!N9P``````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`Q,3`Q(#$P-3$U-#,S-S0W(#`R,S`T,P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````%0````T(`P```'%,U5(```&`4$Q41=W<`-_>`-[>
M`-W=`-K<`.'@`-O:`,C&`/KY"/OZ"?_^#O[]#___%OW[$NSH`?__"__]!/_[
M`O__"?_Z!O'H`-G_$-G_#MC_#]C_#=K_#=__$=S_#N'_$]W_$,[W!77_!77_
M`W3_!'3_`G/_!G3_#G#_#W7_%'+_$V3R""+O`"'N`"#O`!_M`!GI`!WM`!OK
M``_>``;\``?]``C\`!3_`!'\`!/_`!+^``?R`#/B"S/B"37D#37D"S;C"SC@
M!3;<`#K?!3??!BW4`)>0#)>0"Y6."I6."9..#)./$I&/%(Z.%(F*$H.$#;4N
M`+0M`+,M`+$O`*\P`*TP`*HM`*4I`.$-`>`,`.`-`.$.`-\+`-L)`/H%#/D&
M#/H%"O<#`_@$`_@$!/8#!?`!!.D!`.@!`.(``.`!`-\"`-H!`-,`````````
M````````````````````````````````````````````````````````````
M`````````````````````/Z!G=H````)<$A9<P```$@```!(`$;):SX````^
M241!5"B18V&``D8H!08L'*BB$&$6=@94`!%E8_P/AHP0F@DBRH5=E!C;8*+4
M-A<HS(#DWO\H)G"@BD),``!Z92;U]P7X00```!UT15AT8V]M;65N=`!#<F5A
M=&5D('=I=&@@5&AE($=)35`YA#DE`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VQU+G!N9P``````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#,U(#$P-3$U-#,S-S0W(#`R
M,S`U,P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410``
M`/___]`%!O(U-J>=GM74U<?&Q\C)S<;'R_;W^^7FZMC9W<C)S+V^P?CY_.GJ
M[>?HZ]76V=/4UT)KOT9PPT5NP$5NOT=PP4MRP%%YS%!YR51ZQE-WP51XP6"(
MV%^&U%E\QER!R4YLITIFGF2'T%^`Q5=VLU-PJG&8YG"6XF!_O5QZM6>'R6^1
MUF2#P'26W6N+RH&F\8"E[W:8VF%[L764TXBK\X2FZWV>WXJM](6FZVJ%O'*.
MQXFJ[H"<UI.S](^LZ9>U])&NZ,W/T\?)S?G[_O+T]]35U>?GYLP``'\``,P!
M`<X#`\P&!LT)"=8-#<T.#LP.#M@1$=06%I01$=(9&<X9&>$='8L2$M0?'^0B
M(MXD))T:&NXO+^LW-]@R,N$Y.?I"0KLR,K(S,OQ'1^=!0?A)2<8[._]/3_Y1
M4?E04/]86.Q24NY34_975_M<7/I>7O=E9?]J:NEB8OUM;<V^OM'#P\R^OMO-
MS<_"PNC:VMW0T/[Q\?7HZ.#4U/WQ\?+FYM3*RO_T]/'FYOCW]_[^_OS\_/KZ
M^OGY^?;V]O+R\N[N[NKJZN7EY>3DY.'AX=C8V-;6UM+2TM#0T,[.SLW-S<S,
MS,K*RO___P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`!F+;LP````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````MDE$
M0508TVW!,4H#41`&X/^?F;=9]V$0SY,J94#("00O8"V(EN(-/$/`7CL;BQ2Y
M22!(8G`W^]Z,!]#O`_X@%KC,N>R/O;\MV]5->A&@:SK_&8;"JZ371ABF^8+]
MJ:IHJVTRA^'U@9R<NU-$0^D@FO&Y44.M7DJ8I5O!X]/'N\(]:KU7O4L@IB)'
MSF(=L_AL9.2!F!^^^C#+.4FXQ[`Q;'<G9W*3PC)X*3!\5YJF[FQB8Y4@\8]?
M[+I)F?OV<V\`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O9FQA9W,O;'8N<&YG````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#(P,S4@,3`U,34T,S,W-#<@,#(S,#4T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````2
M````#`@#````6,P=C@```P!03%1%````____P:6NX,3-@Q`X4@HC@Q$YA1,[
MAQ4]BQA`AQ@_B!M!71,MDB!(EB9-91LUFRQ3GS!7HC-:F#17GC=;L4=L@#1.
MM4MPI49GFD%@N5%UIDIJO%5YJT]OLU5VL51TKU-SMEAYFDIFOEU_MEIZIE-P
MR'*0NIRFQ:BRTK6_PZRTZ]#9[M3=Y\_7\=KB@@PV@P\XA!`Y@Q`YAQ,\B!4^
MA14]CAQ%CAU%BAU$D2!(BR!&DR)*BR%'BB%&D"=,DBE.CRM/H3%9E"Y2;B,^
M=29"I3E??"Q)A"]-=BI%?RY+JCYEG3I=GCM>AS-1KD-IC395B353L$5KECQ<
MD3I9DSQ;I45GGT-DK$ELG$)BI4AIBSU9NU5YJTYOO5=[OUE]D$-?ME9XE$9B
MP%R`OEM^P%V`OUV`NUM]P%Z!O5U_NEM]MUM\H5!MO6.#Q6F*N&.!MV*`PFJ)
MM6.`Q&R+Q6Z-PW&.R763RWR8N9JEO9ZIT;C!UKW&YLW6N:2L^OGZ^?CY^/?X
M]_;W[NWNZ>CIYN7FX-_@U=35U-/4S<S-S,O,_O[^R\O+R<G)____````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````'D"]'P````%B2T=$`(@%'4@````)
M<$A9<P```$@```!(`$;):SX```"V241!5`C78V#``EA9G1-+<T+M3(TX+`7]
MHM-!0OQ1)04Q3EQ&[.8"7E(I&4`A'K'"8GEA;A9#3CY7\3AE.:"01[9:EH\5
MFX&)M9!H;*JB-%"H1D^WDDF]O$)#DUE;I[I*"RC44-?<UM'5WMK26-M9W]36
M#10JRP]SL+6Q%PE/RRW*4U6*!PJI>%L8Z!OS.@;*)"=$!OF[`X4DX"[*E)4,
M]G4#"CEQ&;*;`5V4E*$0$1+@Z8+-.P!<\BI;E+ZA]`````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]N82YP;F<`````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`U,"`Q,#4Q-30S,S<T-R`P
M,C,P,C8`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4`
M``#____,"`S1$!3A(230*S+>,CCR3%'_7V3Y='GN@(/^B(^I=X+"E)ZN?HJJ
MD:63>I"-AZ$P+X$[.GYF9:L``%X``%L!`3P%!60)"64-#682$F@8&'`?'W4G
M)WLX.(@X.(5!08]!08M(2)@[/'Q75Z%>7JI>7J=<79]D9*EJ:K`!!&-<79=P
M<:TK+5LK+4UU=Z`8'G5)3Y@.%V\5'W03%C%'3HIR>;1\?YT5&#!%38I26YA%
M3Y!I<:*#AYHH*S>)T91GNW$WG$%5M%]6K%]IQ')6LUT;9QLB<B,A;R$OE"\F
M=R8H>2@UGS8K?BPJ>RHN@BXM@"TPA3`PA#`TBS0SB3,VC39"IT(ZDCI&IT9"
MG$)*JDI"F$)-L$Y&H$9)I$E&GD9/KT]0L%!,ITQ.JDY1KU%0K%!1K%%0JE`R
MAS$VC34_ESX_E3ZHU::<PY>+HGJ>LXRVR*2?J(]]A6K/UKY782AY@TR5H3'&
MTV+!HI;;HYS1753OI9_QJZ70/C3>44G,3D?R:F'ACHC."@7;'1?,'QC2+B?N
M.C3/653;E)',``#-`0',!07,"`7-"0G4"@K6#0W8$!#D(2'4(!_H)B;K*ROU
M.CKX/C[Z0D+\1D;_3T_^4%#,6%C9:&C#C(O___\`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!?\49(`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```,%)
M1$%4"-=C8,`"Q$WU5;14Y64D1"6L>1MGS@8*69:66:@IRDJ*&1LTM<^8Q0D4
MLB^OL%.6D]*VXJN?.IVC-@\HI%=<I",D;2)8W3)E&G>)8PY02%A70\'0C*=N
MXB3VFERWF!"@D(BZDHU`0_,$%JY"UXR$L""@D*:1[;S6[GZV*H?8]/B(3#^@
MD#E_1V\7\]P"Y^C4Y.S00&^@4&=;3Q=KI8MO9%)*5$B`CR=0:'(?TYQ\)Z_P
MQ+2XK&!_#W=LW@$`SWTR!V<4&]P`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V9L86=S+VUN+G!N9P``````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`R,#(T(#$P-3$U-#,S-S0W(#`R,S`T,P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M$@````P(`P```%C,'8X```,`4$Q410```/___T^!J%"#J52'K5*$J5R/M96]
MVUJ+KF>:OFJ8N8"KR5",LU:1MV":P&VERGFQU86[WHW"Y(*RT8_#XXN\W#V2
MP3R1P$*6Q4&4PD>;R4J>S%">R5:HU5ZOW&*SWW"^Z7C%[S>4Q#J5QCJ6QCJ5
MQ#N5Q3N1OSR1OT&<S$&;RT*9QT"5PT*4P$NDTTNDTE>OW5*ET5>NW%&CS62Z
MYV2YYFN[YF>TW7'$\'O,]GO(\8#.]W[*\H+,],>))]NE2-.0.,>11NRQ9<V$
M+^2?4.VH7O"O9/*R:+U@`,=T(-F,0+U=`\!A#;]G$KU7!<-H&(I'$:9C*O.I
M:K%J,NF85]V26;UL.\A8']9N.,$\`[\Q`,`X";PL"+PL";\Q#;TS$'D4`'D5
M`,8T%<<W&L0]'Y<O&9XQ&Z<W(>1-+ZDZ([`^)K-`*.93-;5"*KY'+KM&+;A$
M+,-+,<!),,A.-,5,,\M/-N]@0M!4.O)D1M99/O1F2MM<0L!1._1I3=]@1N1D
M2?1K3_1L4.AG3.MI3O)M4?%M4>YK4-H_(<]")]E/-<)',,I,-.Y:/L].-M=7
M/N1=0\94/N5B2?5K4/!I4.UI4-=A2M]F3_!P6.1K5>QQ6NUY9/6$;W@0`(0:
M"O5V9/!W99\O(>I@4/___P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'!(_.L````!8DM'1`"(!1U(````
M"7!(67,```!(````2`!&R6L^````K4E$0508TVW!.V["4!`%T#N?!\1"((K(
M%$@I8GIZ%D)-SQ[8%:R'@B+BYR"DQ,^>&18`YP`O".M(Y==F<;3B9U4=AQ];
MQK*^?H=VDY'0_%`,$AA$'%W\MS<EJOJI@4+JGOQYOG.BWJFP#,5NPONAV>=-
M*$U_FPS%65+TC:\B)-'F`$/S0YQ2R4+L3>=0N!8>E"Y,'&;>0M&-PYAYJD1F
MV0R*4B-4]#0+;R,\\,83*.A-)ZW1/](`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;F,N<&YG````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P,C,@,3`U,34T,S,W-#<@
M,#(S,#,P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%
M````____TC4VSA09VR8KGB$EZ#H_UC]#\DI/YTQ1\E%6)@U_-1V)1S"96D*H
M:%&S8DVH:U6R'`Q7/S-X*AQO&QJ6'QY^``".!@:'!`15!`14"PN+#`R)%A:5
M$1)K&QMR)R>B.#BN.CJR.CN<3$R_.SN)5E;$7E[!;F[.`016!`F,#A.4'B.A
M,36P1$B^457#4%7&`',``W`#"7@)#7@-&($8'88='X<?&VH;(74A(G0C*'\H
M+Y0O*GXJ+H@N.)PX-)$T,(<P0JE"1JM&0J)"1J-&4+903[-/3K%.4+!0-I`U
M(H(%8+,U;99*=9U1<99016<F37`M5'@S884^;Y5,(3$07X<O>:8Z(#$%;94`
MAZ<AK;X2V-\FS-`%TM8-X^=`\O97S<T`QL8`2$@`S,P#R,@#M[<#/3T!-S<!
MN;D*5%0%SLX-O\`-9F8)WMX8T],@I*0;V-@G='082TL2W]XXA84GZ.A0>WLO
M_?UDM;5(__YHH*!>OKYTOKY[=75?I*2=85X`V]841T0'U;00W;\=]]->_=5J
MZ*HKR(0*Z)=(S(%)XB<AZS4O[S4UNRPLR#`PT30TQS(Q[SX^]T)"TSLZ^D9&
MXT)"QCL[YT9&^$Y-_$]/Z$I)_%!0]$Y.]E!0]%)1]V1D]F9E____````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````T>(F9P````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"L
M241!5!A7;8N[#@%!%$#GWGGLKDH0B43MH_R!1*&0^`PE'Z#W.[)ZHK)>L[-[
MY^&*DE.>G"/$#R!&H)5.[3/S$B4BEDIT7V8:H]Q2'QA,7/5@YL%;O:N_JD+Q
M6$6&;DOGFI9<S=7F6@ZB<S3),<^@:1<H.BD1-9(GHY'F22B15(](0R&-T=ZO
M`ZM]IHLQIN/%@DD,J\H.XR'H>RW1^A@B*Q=/9T2^T)OPJ?[P!J;O5/W4KD[F
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]L>2YP;F<`````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,3(P-"`Q,#4Q-30S,S<T-R`P,C,P-30`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!(````,"`,```!8S!V.```!@%!,5$4```#___\`<!H`<!L`1A`!<1L!<1P#
M<AT#<1T%=!\%<Q\'=B$)="(*>20*>"0->R<-=R8*41L0?BH2>BL4@2X8A3(8
M?C`162(=B#8AC#H?@S<98BHFD#\;9RTGB#XKE$0B<C4A;S,OF$@A:C,F=SDH
M>3LPCT8UG4TUG$TPCD8K?C\J>STN@D(M@$`J=3LZH5(ZH%(PA40PA$0TBTDS
MB4<^I%8XE4XVC4I"IUHZDDXR?D1&JEY!G%8_EU-"G%=*K6$ZATT[ATU-KV1&
MH%M-KF1)I%Y(HEU/L&5/L&9/KV90L&=,IV)1L&=.JF11KV=0K690K&50K&90
MJ650J&5&E%E7KFM>M')>LW)9J&MDN'AEM7AHNGMFM7AJNWTRAT5DN'?___\`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!'O^TL`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```)U)
M1$%4"-=C8,`"6%BD'6)#S<2XF#B%)#6LO4!"XE918392/,SL_!)*%A[^0"%!
MO8AX-SD!5C8^47E3%S]7H)!R2'2PIC`'*[>(C+Z]G[<M4,@1;I"ZM9>OG3%0
M*"8<;I![@+.Y(5`H$FP0+]`@)S]7RS@MH%"0FC`',]`@`WL?;UL3716@$,)%
M0(-T5!6!0C"#/`.=S8VT%62Q>0<`U?,:F,G.2XP`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]M;RYP;F<`````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,C`T-B`Q,#4Q-30S,S<T-R`P,C,P-3``(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___\?@4,KDE$UB51,
MEF@`<"<#<BH#<2D#<"L%="P%<RP%<2P)="X)<R\->S,->C0*42,0?C</=S,2
M>C<4>3@8?CP162H8?3T=B$(AC$<?@T(;9S8GB$DB<CXA;SPOF%0A:CLF=T(H
M>40PCU$UG%DK?D@J>T8N@DLM@$HJ=40PA4XPA$XTBU(SB5$XE5@XE5DXE%DV
MC51"IV8R?DU&JFE!FV%"G&%*K6TZAU8[AU9&H&5-KF])I&E(HFA/L'%(H6A0
ML'),IVQ.JFY1KW)0K7!0J6]0J&]&E&)7KG5>M'Q>LWQDN(%EM8%HNH5KO(=J
MNX8`1A@%="H&<RL-=3`=B$`?@D`BAD,98C(RF%0RAT\^I&$ZDEA!G&`_EUT_
MEEM#G&$_CUE8KW52HFU<M'E;K799J'1<IG1FM8%JMX1ROXQIKX!IJ'Z.RJ)&
MGF))H&10JFQQN8A\PI*/S:(XG54TD$^`OI$FB4"AU:\:?3*#K8T0=R85?"P6
M>RPTCD>FT*\6>2I'IEJ.M)69N)XUED.KQJ^^VL+0ZM,D@2XLAS6DO:88>1T?
M?B&\TKPYDS?H]^=HN5\QA1G,U<?4W<[-U,?S^.W___\`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````P&%6K`````6)+1T0`
MB`4=2`````EP2%ES````2````$@`1LEK/@```+])1$%4"-=C8,`"`@,C+`,\
M#21XV+B$I%1-'4%"XB:^7F9,M3V<`I(*QO:N0"%!K30?A[J.[HDU?<S1-BZV
M0"%%#S_WTLIJ%M;RED8+%Z<XH)!5@*=A9P-?UZ3DD@F.SN:Z0*$,[]@PT:JF
MULGU[5D%UD;:0"$?.]D0X>8IO6U3^XOR8Z+4@$)N*B(<P8DYV845N:GQ>II*
M0"%],6ZVH/#TLN+BS`1=#65YH)`T+QL[?VADBG]2GI&.NIP,-N\``'\[+I%T
M^A!C`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VUP+G!N
M9P``````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#0W(#$P-3$U
M-#,S-S0W(#`R,S`U,@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X`
M``,`4$Q410```/___[ZVO;2KM-?0V,;#RFA;A7]XE6EAC&UGAXV(H[FTSD$[
M?E-.AV5AB2@C>",@5D="E%10DFUHM592C7)NMX>#P9N8OQ<2=R(?=B@C@Q@6
M2RDF>BPI>R\K?#,O@S4RAC8S@CTZCCPXABHH7T(^BCTZ?S8S;C(P9TA%D#HX
M<511H5-0G593H4)`?5Q8JEA5I%!-E4=$@T9#@41"@$A%A$Q)B41!>DI(AE)/
MDDY+BU)/D5!-C511DUY;HV9CKU]<HVEEL6-@IV%>HE52C%U:F6]KM6QIL6=D
MJ7%MMW!MLW%NM%]=DWUZOGQYNG1RKGAVLWEWLX!]NX6"P8%^NVUKDHJ(N8V+
MNW1REYB6P*:DR2,A>28D?28D>2TK?3PZD#LZ=3T\>$U+BU=5G%A6G%!/CU=5
MF%Q:H$Q+A&%@J%U<GFAFJVMIKW%ON'%OM6YLKW%PM6%@FW-QM65DG(!^OH.!
MP2LL?#(R?DY.A69FIW%QL7AXNV]OJ&]OD+6UO<K*TL/#R;V]PFYPJ'=YL&UN
MH6)CA4%%B5I=ADE-<[BYPJBKN:FKLI&9JWN(EW..J8:<HE!I;L''R)>OI+[;
MOY6O?8"1:LK9M:FCBKJPD*65;KJE@,JWE*>;CO#HY+BKJKFYN?___P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````)4,9%X````!8DM'1`"(!1U(````"7!(67,```!(````2`!&
MR6L^````P$E$050(UV-@P`*DI35<@KUK^#K48A0$#1Q%04(J&4'57+-G3IW%
M&:]M[^D%%!(P]_?MF<+6VLXQHT7?+2\;**156%HP?8)$;:A4WR3AW)PLH)"(
M6)'K')Z*NL[BIFF![L[60*$0/X>V?J.XAGK=JLG-3K960*$2#\VR7O;R^8V9
MW!,KTVQ,@4+YAHJ2O/,BNKO$YX8GIUKH`852E&5CHWV8F5A9(M,MS4P2@$*J
M<OPR\DHZ85$!=D))QHGJV+P#`-00,>85K.RS`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O;F8N<&YG````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#(P-#8@,3`U,34T,S,W-#<@,#(S,#0P`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____E\V8J-FI`'4`
M`$D``78!`W<#`W8#!7@%!7<%"7H)#7\-#7L-"E0*$'X0$GX2%(44$X`3&(88
M&(08$5T1'8H='X@?'X<@(8LA&649&VL;)I`F)XPG*Y<K(G8C(7,A(6XA+Y@O
M)GLF*'TH-:$U*X(L*G\J+H<N+80M,(DP*G@J.J,Z,XTS.)HX.)DX-(\T,(0P
M-I$V-(HT/J,^0JQ".I8Z,H$R1J]&0J!".HL[/I(^.XL[1J1&3;--2JQ*2*=(
M2:A)3[1/4+503*Q,3J].2:-)4;114;-14+%04*]01IA&4*U04*Q06[E;6;59
M5[)77K=>6:M99+QD9+MD9;EE:+YH:K]J=[MW=:YU@L""?[=_A[V'B\*+B;Z)
MG=2=HM:BE,.4B+&(J-JHI-&DE+64EK:6GKZ>F+>8FKF:K,BLOMF^SNC.JKZJ
MU>W5T^K3UNW6P,_`Q,S$[O?N\_GS\?3QR\W+T]33((0?,),O,HLQ0:!`/YL^
M/Y8^3)Q+9KEEAK.%@:Y_@["!B[.)G[R>M\2VO\N^U-;3^OKZ^?GY]O;V\O+R
M[N[NZNKJZ.CHY^?GX>'AWM[>V-C8UM;6U-34T-#0S\_/SL[.S<W-S,S,____
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````^P_O&`````%B2T=$
M`(@%'4@````)<$A9<P```$@```!(`$;):SX```"_241!5`C78V#``EA9I:SR
MNB:TM<Z<&BFI:N$,$A(U#\WIG]+4.'URM)*IDR=0B$\[*"1[4EF%=?G$6!,[
M#T>@D*)WF&_6M%PVH<(^)GMWEQJ@D$UX@'[+S"1._KCN!"]72P.@4'U@M43:
MS&8>L:B.9%];(RV@4+"#+&_JC#IA.7]&9C>S*C6@D$^E`$=&D:",CE]Q2JVN
MIC)02$^$BR6S/28BOJ0TT5A#10$H),[-PIX^H2>_H+.WP5!=7AJ;=P!('C`C
M+D,Q"0````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]M<RYP
M;F<`````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`U,"`Q,#4Q
M-30S,S<T-R`P,C,P-#<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.
M```#`%!,5$4```#___^R:W"NE:=?2%N=?YC<Q=FXI[>2<I;.N-&!5XEF6VJW
MJ\)^9I?+ON&SJ\EL7J1`,9)82I^6B].;DM%T;Y$^,I101:)".:922:T_.81<
M4[U&0(M74*-84:1<5:EE7K9F7[9S:\1\=<XP*9<X,*$V+IDU+I@U+I<U+YHV
M+YDW,)DW,)@Z,IXY,ILY,ID[-)T]-I\\-9I$/*=!.J)`.J`_.)I$/*-$/:1'
M0*A#/)Y)0ZM.1K%(0J)/2:]43+143;)02JM.2*984;943JI<5KE(0XYA6KU,
M1Y1E7L-339]13)Y02IE53Z).299<5J]L9<UE7\%E7[YJ8\1>6:UR:\MV<,]U
M;\UX<M%R;<=P:L!N:+M]=M)S;<)_>-1]=M%Y<\Q]=]%]=\]Z=,A=69F)@]*+
MAM8T,)PX,YT[-I\\-YYJ9KU=6:6"?]*(AK5L:X!"/Z))1Z*%A,]O;HYI::MV
M=KZ#@\I=8[IC:;)X?\."B<R-E,^US-^6J[F9M</*Z?:\U^'`V^*VU-FGP[FG
MN:N/G9+#VL>.IGF2IF*-F%^0F&"5EHJRMV/KAW/HCGN275'19E3T@FW";E_P
MB7?KAG6Y@7?WLJ7CI)BK75'!4$*!-2W6=&>Y23YT14+#?W[___\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#AC&QN`````6)+1T0`B`4=2`````EP2%ES````2````$@`
M1LEK/@```,%)1$%4"-=C8,`"6+B+)_%Q\I=GJ.D:VWN&Q0&%YO9/G3QM^CPF
M,4U3QZ#(>&6@T*P9?1-[)\R<(ZA:45=;4Z0$%!)E9YO"P\Q;F"E1V=3:6*8(
M%&(5%IDM4,#!96Y35=_24"H/%$K-C18R4TD7EY2N;FMO+I$%"J7%NF2I:QE:
MNP;D]71TIG@#A9+]K734#2R=@R.2NKORO3R`0@JV^AIZ%@Z!X8D)V3F^?C)`
M(2<C#6T3._?0&.6H$#D?-RELW@$`N]XQ@UC)'K,`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+VUT+G!N9P``````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`Q-3<U(#$P-3$U-#,S-S0W(#`R,S`V,P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$@````P(`P```%C,'8X```,`4$Q416L``',``'-:6G-S<W-[
M>WL``'MC8WM[>XR,E)24E)24G*6<G*6EK:6MK:V,C*VMK;6]O;V]O;V]QL;&
MQL;.SLY[>\Z$A-:4E-;6WMZ$C-[6UM[>WM[O[^>$A.>,C.><G.?.SN?6UN?>
MWN?GY^?O[^?O]^?W]^?__^^4E.^<I?>$A/>,E/>4E/><G/>EK?\``/^$C/^,
ME/^4E/^<G/^EK?^MK?^UM?^]O?_.SO_6UO_>WO_GY__O[__W]____P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````##`KZX````)<$A9
M<P```$@```!(`$;):SX````C241!5!A78["#`WTH8+"S$Y-%%Y+C%A!&5R4J
MAZX*#@:5$```ZRUSV=11QP````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VYL+G!N9P``````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`R,#,Q(#$P-3$U-#,S-S0W(#`R,S`T,``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___XL.
M#]74U<?&Q\C)S<;'R_;W^^7FZMC9W<C)S+V^P?CY_.GJ[>?HZ]76V=/4UR%$
MF``SJ@(WJP4XK@4WJPL^K0Y#M1!#MAA'LR%2PR%1MQQ`D"-0L"51L"E5M21*
MFS%CSRA-HS5DTBM2IBY5K3);M39AOS1<N#):L3ACQ$1TW$9TWD)KR4=RSU!^
MXE!\X4YXV5%]W3]?I$USQ$=HKUF"VDYPN5I]R6Z4Y00ZK!Y2P#=AND9QS&B0
MY&B-VVN/VLW/T\?)S?G[_O+T]]35U>?GYN#(Q\P``'\``,X#`]`%!<P%!<P(
M",T)"=8-#=@0$-01$<X4%-(8&)01$>$='=X?'^0A(=0?'YT9&>XO+]@M+>LR
M,O(U->$X.+(O+OI"0KLR,OA$1/Q&1N=!0<8[._]/3_Y04/E04/]34^Y/3^Q.
M3OM75_975_I>7NE>7O=E9?]J:OUI:<VNKLRNKM&SL]N]O<^SL^C+R]W"PJ>3
MD_79V?[CX_WCX_+9V?'9V=2_O__HZ/CW]_[^_OS\_/KZ^OGY^?;V]O+R\N[N
M[NKJZN7EY>3DY.'AX=C8V-;6UM+2TM#0T,[.SLW-S<S,S,K*RO___P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````">+?9(`
M```!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````LDE$0508TVW!
MO7$",1`&T&]_3A)S-T!$`R0N@L`IW1"2V)&''N@$(B<$.'`C)`P>;O"=M%H7
M8-X#_B&L,>^Z<NN'(DT,0?<,M*FUQY@+:R,B!,:QG;(]1@\QQC0)#,4V4(V=
M.1,+$7V!H+8+HC"KI;AJLV&\?WP>!+6ZV9O(M@&A8^YIY6=?^2EPII[P>O_Y
M=4Z+(>4P>*W?BLNU&&LNDY'NV>P*QLWJBRQC$K89>6WQQ!^774H!L&0@80``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O;7@N<&YG````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P
M-#(@,3`U,34T,S,W-#<@,#(S,#4U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#
M````6,P=C@```P!03%1%````____U34V_):7^YN=X.KJYNCHQM;.P\K&$GHQ
M)XA$`',A`$<4`W`A!7,E"7<H"W0I#74J#74K"E(?#W@M%X$V&'XV$5DF&GXW
M'X<\'X([&6,N(X,_(6LV,(]+*G4_.)92.)-2.))2,GY(09Q;.XA12*)B4*II
M1I1=4*=H4*5I5ZYP7K-W6:AP9+E\9K=]:+J`9;1[:KN"<+^'`&X>`$@3`W,A
M.H=/9+9Z9K=\[O;P<H1VP<K#NL6\T=O3B9N,E*&6U][8Z_+LM+VUR-#)QL[&
M]_CW3V9+:7MD?H5[8&=<C)5^8F$^O[NP9%`?:EDQ85E'5E!$?75LV-7273`1
MKJ:APZRFLJFHC'MZY"$AIQL;L"$A[B\OLB,CN28FO"@H\C4UORHJQ"TMP2PL
MQRXNRC`PS3(QTC0TSS,S^#X^^D)"VCHZX#\^_$9&Y4)"_DI*ZD9&_TU-[DE)
M_T]/_E!0\DQ,_5%1]DY.^U%1^5!0V&9FX7!PZWQ\]8J*U7IZY8>'\I*2_Z"@
MV=C8_O[^_?W]_/S\^OKZ^?GY]O;V\O+R[N[NZNKJY.3DX>'AWM[>UM;6U-34
MTM+2T-#0SL[.S<W-S,S,____````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````W&*UXP````%B2T=$`(@%'4@````)<$A9<P``
M`$@```!(`$;):SX```"[241!5!C3;<&_+D1!%`?@W\R9/]?(YB:RHME:+4%%
M*11>2;94Z7@'SV'+;;8A6](0A4HBN6?FG#,>@.\#_G`XW8X+&:]#@'Z^YEF^
M"]CN#M4Z$4P=E13AD8>2&]'32KN;Y<@@S$OZX1>H_[@_EV2\]AA*F^J96>-^
M&QTW>,PKLXA(9;^,_&`@[/%[MWT>T_?!XTD]LDT`3UVH7SUKNKC\4A$$\!0/
MWW;*L5AH357AP:S>L>E-H&YJ'?_X!1BX7+.40TQ!`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]M>2YP;F<`````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`T-B`Q,#4Q-30S,S<T-R`P,C,P-C(`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____U
MEYG$14G#14G*35#.45;66U[#96G"9VO$3%+D?H/"<WC-7VC'>H#7J:YD6IDT
M)XL9#'XY+XH:$81M9KYU;<`4"W]97<TR.:!H<=T2'I03(905(94;)Y4K-IX%
M&)8[2:8`%IT##UT8*90A,Z4X2;97:<M%4IMN?=4)))0D.IA'6JMA<;AT@\4_
M3&R.FK,C+D-*5%5_BXL^1T.;J9EF;V"NNZ1K=EFTO(](3BA=8SF>I6VIKE.Q
MM4+L[$C.;FO,<&W6=W3,<6[1=G/,=G/AA(';@7[/>G?'>';HD(W;BHCDDH_=
MCXSNG9O^JZGYJ:?]KJS\KZWQJ:;^M;/*HZ+D8V',7U[.8F#,8F#R=7/09F3-
M9&/,96/J='/6:VG2:6C8<&[\A(+4<&[!963E>7C-;6SA>'?XA832<7#4='+V
MAH7:>';^BXJG7%OD?GW>?'O_D9#NB(?NB8>R9F6P963[DY'0>GB_;V[RCXV\
M;V[KC(K*>'?5@'[8@X'ZF)?AB8C2@'_NE)+\G9SXG)KJDI'ED([_H:"Y=73Y
MGIW^HZ+VGIW$?GWZHZ'UGIW_IZ7/AX;HF)C_JZG[IZ;RH:#@E93RI:3UJ:C@
MGIW^M;3]M[;RKJ[NOKW5K*SZR\OJP+__TM'YSLW___\`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````>3*D%
M`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+])1$%4&--M
MP<$N0U$0!N!_YDR/>WLI&^F"C70MI0N)V-@0L;/RDAZ@*XE=A?01NJT*HFC=
MSIQ[I@_`]P%_$'K=>DG95^^G@XWQU3W?,3HTC3N;[HT]C4Y6YPF"8,ZQ-6^\
MMU4Q4P;#(C=9$\67@_W=JKB&X*O8^_UPIKIZ+*JL!L%B8H&">7G)3#D/(7@K
M6=69;Y_+5E+=AN!&S7((X>B!+]Q2@N!P]I,X=MJ+,_JTT;%!\/IM)%&BN-7>
M5\4_UAY)4F5-5X9E`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L
M86=S+VYO+G!N9P``````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R
M,#0V(#$P-3$U-#,S-S0W(#`R,S`U,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````$@````P(
M`P```%C,'8X```,`4$Q410```/___]&QL^+"Q/#1T[NBI,:LKM.XNO?9W.?+
MSN7)S/37VO;<WP$D8HN6JJ:PP@<K:1`T<1(T;AU`?"=(?D%?DE=TI)6@L@4O
M:8B8KH>5J):ENJ"OPP`P:0HW;PX[<399@SY@B:R[SAE)?BI5A3]FD4ISGUF#
ML&:-MVZ2N6![F8*<N(:=MB=9C3IJG3A?B$Q[K$]XHUF%LUQ^GV*'J7&5MF2$
MH6B'I6^.JX*EQ'62K)&RT86COG2-I9>WU9*QSIBRR:?"VZK"V;/*WY>VT,V#
M??'&PLZ\N\T\.,Q85<Y;5\Q@6_63D,9X=?Z@G=2*B/>EHLP``'\``,T!`<X#
M`]`%!<P%!<T)"=0*"M8-#=@0$(L*"L\2$MX8&-(8&)01$>$='>0A(=0@'YT9
M&:<;&^LK*[`A(>XO+[(C([PH*/(U-;\J*L<N+KDL*_4Z.LHP,+(J*MTV-<PU
M,N$X.-4V-=(T-/@^/L0S,OI"0KLR,L\Y.?Q&1N5"0NI&1O]-3>!%1.Y)2?]/
M3_Y04/Y14/9.3OM14?E04-)(1?)34OU85_%75NE96>AI9O)P;M%C8?I]>MMR
M<.B"@*=@7^"+B?*;F?VCH?VEH_^JJ=[&QO___P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"ORS:D````!8DM'1`"(!1U(````"7!(67,`
M``!(````2`!&R6L^````OTE$050(UV-@P`*"@I)]G<7XV\,"0Z,2LZJ;0$+Q
ME0%.HN(>@2&1">D5C6U`H>B"[FD.(GQ%P1&QJ65UK0U`H4G^T]UTA*1<^R9,
M]/&;.F4R4,C6T45;44+!V,34TMK.WL8***2IH:8B+RNGK*MG8*1NJ*H/%.+A
M8G+7XI6<P<S"P<W)SL8*%.HJC/$V$Y#NR6ON[*BO*L\%"A7'A7F:"\KT5C>U
MU)3F9*8!A9+"`[TLA)7Z&]MJ2_*S,U*P>0<`[0DQ#'=<(&\`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;7HN<&YG````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P-3`@,3`U,34T,S,W-#<@,#(S,#4V
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____
M-C4V;G-R9VMH;7!MF)N8>KES>K5T+F4G(VX/)7`1)W`3*G(7+'08+WD;/H8K
M/H$L1XPT4)8]38P\69Q'59-$8:5/79I,::I7;:Y;;*M<<K%A:)]:<JUB>+)I
MC\6`+7,8-WXC/7\J38L[59!$695(8IY15HA(=J]F@[QSA[QXA[IXD<6"7F%=
M'44+:&IG>7MXD)*/B(J'J*JGI:>DH**?LKVH7'8^K;B99F=CN;N)N;L`O\,O
MN;H`IZ=R>GIV='1PA(2`E)20<7%NE962A(2!H*"=GY^<O+8%I:$CL:PJO+<P
MQL$US,DZV--%[^E/Y>!6M[-*PKY2\NUHS<E:W=EF^_=V[^QU^O=\O+0#Q+P-
MQKX0S\@=TLHAFY8;HYTAW=8OKJ@HX-@UN;,NQ+TTZN-"Z^1&UL]"V]5&[N=0
MYM].ZN-0O[I^O*H)O)D%OX<*E'5&V90]NHA(W)E/R'HM\*%HTI)F720$KTX7
MRUT?U9Q^NV=!QT@8>RX4VW9:OH9W['!0AA\*QC`2LD$JR308?A$`U$,OV$PX
MY615K%A-PQ<)D"LA<P<`;@L%4%!03T]/3DY.1D9&0D)"-34U-#0T,#`P+R\O
M(2$A'1T=$!`0#0T-!04%`P,#____````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````?C;O
M#`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#!241!5`C7
M8V#``BKT.36T-=64%7GXE(1$)66`0FUU%NSR$H*\7-S\`L+B4M)`H::6>GL.
M6545$3%U.2T%71V@4$]Q66<#,XL!JZ$QFZF)F1%0J-`ZMZBUCV'.K!E3)O5/
MG#P5*%1M;EG3W3MW]LSIDR?T3V*:!A0J+RFM[-*S<G1R]G!W=7-P`0HUMC<7
MV/KY!X:$1T:$A08'`84Z:O/M/&/BDM.SLC-24Y(2@$)5>391T;&):0$YF;X^
MWE[QV+P#`)OO,B=?.A;Z`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]N<"YP;F<`````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,3,U-R`Q,#4Q-30S,S<T-R`P,C,P-38`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!(````,
M"`,```!8S!V.```!@%!,5$4```#____'"@OJ.CS),S3'.COI3E+1)C'_Z^RR
M,#O=7FBD`1.@`!.R+D!?`!&M&#)T`C&H/6BQ3GJ90VJ52'55&T">5HM="TIK
M-6")0GMN*F=."4E:%56:7I?;VMM&!$E'#E1"#UB%8ZAE4'M)*W%]8:5?0I"*
M?;TS+W^ZN-]<6J-96)0_/W%;6XD]/4@C+'W1RLG82T33$`OA0#S-/SOLH9[/
MFYG=N+?-`0!_``#1!P?-"0G,#`G;%!24$1'A(![4(!_,(1_H)B;6)B/1)23.
M*B?N+R^+'QWL-37@-C:G*RG4-C7Z0D*[,C+9/3SY1D;A04#J1D;^3T_^4%#Y
M4%#Q7%FP1$/U7E[@6%;]963X967T967Q9V;Z:VOJ9F;1:VO7@X/HDI+7B(C3
MDY+,E)3,IJ;-K:W]V=G0P<',R,CQ\?'/S\_,S,S___\`````````````````
M``````````````````````````````````````````````````````#/C4ZG
M````;G123E/_________________________________________________
M____________________________________________________________
M____________________________________`*`%/#,````!8DM'1`"(!1U(
M````"7!(67,```!(````2`!&R6L^````CDE$050(UV-@P`(L^425-7,1`"1D
MYQO-):R"+.0>EIAN:LC"+:"@`1/R2N;(DC-SM+"R91=4@@BQQL9$\(K+2\M(
M28K)JFKI`H6BP@-<F'@4]9',BHQ+2DLQ,>)70PB%FF?GY!CX.3$+J<.$C.-3
M,S,2/#W\@]E$M"%"#M8VKL[V;CY!(8'>G!(Z>MB\`P!2@"U:U1X,5@````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]N<BYP;F<`````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,C`T,R`Q,#4Q-30S,S<T-R`P,C,P-3$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!(````,"`,```!8S!V.```#`%!,5$4```#___\()8X*)XX.+),9-)8;.)X>
M-HDA.8P7)UXM2:PE.7XV3J=`7+Q$7*X_5)T_4I12:K]7<,A+8*E6;<!>=,!@
M=;UM@M`-*800*X<1+8<1+883+H0,'%(4+X45+X46,(88,XL8,H@8,H8:-8X<
M.(X;-8@=-XP@.H\?.(HC/9(E0)8H0IHK1)@=+F8J0I`O29PK0XTT39\P1Y0P
M2)0V4*0H.G8Z5*DF-VX]5J<X3YHN0'TP0X!!6JLS1H8W2XXV28A0:\=&7Z]"
M6:,Z3H\X2XI,9;A*8[0^4Y<V2((]49%!5IE&7*-#5YM/9[9(7J9%69Q4:[D_
M48M7;[Q-8J=9<K]8;[Q09JQ;<\)4:K-6;+519JM'6I55:[!)6Y=>=<%:<;A;
M<;A9;K18;;)@=L%@=\%39Z=A=\%08Y]><[IA=[]@=KU28YMF>KUL@<-PA,AF
M>;9RAL=SAL1XB\IO?:6>IKO+S,R=G7*JJH*NKHIP;T)U=$=S<D9^?5%_?E6,
MBV&5E&^+BFB<FW>KJH2'AFBPKXF\NYJCDA^EE"&YJ3JOH#K(N$RKGD?5QE[#
MM5C)NU[<S6G:S76FE2:NG"NUIT[7R&G;SGO___\`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!`WON&`````6)+1T0`B`4=2```
M``EP2%ES````2````$@`1LEK/@```+Q)1$%4"-=C8,`"9&4M8HIS_?65992T
MC)S"TD%">D%%>>$F:C(*&@:V@2G90"%.SX+"9"M-.7EU74L_T:PDH!"WL+@(
M#RLS$PL;%Z^CD"`?4*BEK;*AKJ:JNK:^O**UN:D1*#1M8E_7I/:.R9W=O1.F
M]D_I`0KE1_)S2$JIZ)B[1<1'^7C8`X42TTIS)!2U3=U#4Q-"O%WL@$+.&64E
MTD`7!:=G1OMZ.5@#A8S9XPQ502X2BPT0<+4QP^8=`#.!+KI4-`;)`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W!A+G!N9P``````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#0V(#$P-3$U-#,S-S0W
M(#`R,S`S-0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q4
M10```/___\&YO=')S?W]_N7EYO+T^62`K>;K\[&\S<7.VYZDK;V_PO7W^@HT
M;Q1`>B5.@V2&LI^OQ=/;YL#&SN_R]N?J[@$O:0,S;`4U;@<W<`TX;P\\<1(_
M=!A"="%-A2=/@2E0@2]:D3!9B4)KG$AMG$YQFVF+LW&0M9ZRR]S@Y0`Q:@,S
M:P4U;0DX;@T]=1!`>`\\<!A%>!U,@A]+?2U5@S->D#AACT]XIU!WH[["QNWO
M\<K,SMW>W[[!P[[%R<'"PK*SLY.4E,W-S-K9V,B_OJ\+!;83#;@6$*X4#Z\5
M$:\9%+X>&,$C'<4G(<PQ*\<P*]`U+],Z-=I$/MU(0M5&0=],1KM"/^)23=1.
M2>-53^)64.!74=Y54.%74\U13>1@7-U=6=!_?;R!?\.=G.W/SM"[NJH"`*P%
M`[(,"KD4%+(8%L@I)KLN*]8].K@T-,5!/N!-2M=/3.%44=NFI<FIJ;JEI<N_
MO\J^OM#%Q>[BXNC=W=/)R?WR\OCM[?CO[^WFYOW\_,3#P_[^_OO[^_GY^?CX
M^/;V]NKJZN'AX=C8V-34U,_/S\[.SLS,S+R\O+FYN;*RLK"PL*>GIYV=G8N+
MBW]_?____P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````()>00X````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````
MOTE$050(UV-@P`*F39MBQ]+>6>F=[N;A%Q06#1)RXM849NTN]\QP]PT,B8H%
M"DV=R,DNU-5;X97IXQ\<$1,)%)K<S<$ETM-7GIV5DU=87%0`%.+AM;:UL;)G
MR@T(C4M(C`\'"FFHJYG*&<HH,E?5U=97U[@"A015%:3%Q?D$M-H86QI<G!V`
M0I;*LCK:4OQF8LV-J4FE31.`0N9&NMJ2!O(JHLWM)?G)_9.`0B9ZVA+ZQDH6
M;*T=:2EECI.Q>0<`9_<P=D51LKP`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O;VTN<&YG````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#(P,S4@,3`U,34T,S,W-#<@,#(S,#0V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```2````#`@#````6,P=C@```P!03%1%````____U34VZ#P]X4%"IU%2_XB)
M0:`C.GPC4:HR0H8J5JTW29`P4)DV9KM)7ZI$:[E0/GTE9:U(;[]2<+I2-G(=
M1H<K3I$R5)HW9K9$<;U1/H@308L73)`?5)@H27TH488O9J@\68\U99U`=;1,
M=*Y.>K=307<)Z^/BQC@QQ`@`Q`D!Q@T%R1(*SA4-U2`8XC,KNC(L[T4^TD`Z
M]U1-YE!)\UA1S```RP(!S@,#S`,#T`4%S`4%S0D)U@T-S@T-V!`0SQ(2TA@8
MS1D8X1T=S!L;TAP<Y"$AU"`?T1\?U"`@V"<GSR<G[B\OVRLKW3`O\C4URC`P
MX3@XTC0TW3DY?R$A^D)"YT%`_$9&Y4)"ZD9&[$A(_T]/_E!0]DY.^5!0]5!0
M\5!0[%!0QT-#?RPL]E=7X%)1_E]?^EY>_61D\F!@_65E?S,S^F5E^&5EG4%!
M_VIJ_W)RBT%!U&1DE$M+]X:&\82$QFYN_8^/NV]OLG!OZ:&AV,7%S,/#WM75
MU,O+]NWMSL;&S<7%__?W^/#PY]_?^_3T[N?G_O[^_/S\^OKZ^?GY\O+R[N[N
MY.3DX>'AV-C8UM;6U-34TM+2T-#0SL[.S<W-S,S,____````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````A&`$!`````%B2T=$`(@%'4@`
M```)<$A9<P```$@```!(`$;):SX```"V241!5!C39<^[34-!$`70NW=F%PLD
M.W="B`1]N`H(R"U$Z`:H@`")#G!.+62(%(G$?K_UV]T9"O#IX`!G`K:_Z\6\
M6JFB5;/F.R)?7UJ-(K#F;CN!8IF"#%.ML?G^WE\J`N+3Z_-W/EF*GP\7ZO5=
M\!AOW];=9(8[V#ST7\15/FZF0M&4E/7#H"A=/Y2>#"3=;GZ@R/U8CFV@"-W<
M1B@.76D\_*G$YN9F4(RED.0RS$SN1?/Y!_^B.%UT310E'@````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]N>BYP;F<`````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`T-R`Q,#4Q-30S,S<T
M-R`P,C,P-C4`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,
M5$4```#___^T;7"^=(C"C::<:8?;PM=>2%N;?)>GCJ2WIK:#5X:?<*.2=9;,
MM]"'7)=F6VI]99>UJ,*,<:IM4H]T6)_,O^%X7JAD2YMN6*>RJ<ER8J1F5Z%_
M<KF8B])U;Y$_,9-/0J%.0J!62J&$><R)?\Z9D-`],I5O9K0^-II12:U&0(MQ
M:,5\=<U[=,HP*I<U+I@U+I<U+YHV+YDX,9PW,)DW,)@Y,ILY,ID[-)T]-I\]
M-IP\-9H]-YU!.J)$/:1'0*A#/)Y)0ZM(0J)/2:Y43;).2*584;8_.H-43JI<
M5;A<5KEA6KUA6[Y,1Y-.299E7\)<5J]E7\%239M13)E43YUJ8\1<5ZQ:5*18
M4Z)D7K5R:\M>6:ES;<QC7K!T;LUU;\UV;\UX<L]N:<!P:K]M:+M\==%R;<-S
M;<)]=M%M9[=]=]%W<LAU;\-^>-%\=\]\=LUZ=,>+AM6)@]!P;HTU,9PX-*`X
M,YH\-Z0^.J9'0ZQ'0XYH9,=:5J=M:,AV<M%Y=-)Z==%U<LR"?](X-:-%0Z-3
M4:)O;M%98+?KB'/HCGOT@FW!;5_OB7CCHYCWLJ;09%2K75'JA'626U*Y@'>\
M2D&!-"W3<&:T0SUT1$+%@7[___\`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#SF;TU`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@``
M`,!)1$%4"-=C8,`"V`5*>L3XI#K*#4T4)0,2LX%",R=/Z>WOF\6D;E0ARAS?
M4``4FC:QJ[MSPM09"BU57CIIJKE`(7DNMDE"G"+691+B-?4J+!I`(0XYM>DR
MK;S<E?P\[=EZLC%`H>+F5&5-_5(E+=_83-V4\$B@4%&&IZV!L963=UUC?GI<
M1#!0J##0T<S`TL$]+"DO)ZLVU`\H%.5L86AN[QJ4D-TDS-KFKPT4<K,Q-+5S
M\8G.U$V6%@RI]L#F'0`3JS"=5MW:S0````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+W!E+G!N9P``````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`R,#4P(#$P-3$U-#,S-S0W(#`R,S`S-``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````$@````P(`P```%C,'8X```,`4$Q410```/___\L-#M(<']DR,]`U-L0Z
M._)B9/IG:/AU=OQN=/]U>LR<G]6MK\S)RMK6V,O)R^[M[OS]_OK[_,K+S'^'
MC<C-SM_DY.KN[M#4U-[AX?7W]]G;V\C*ROCY^6F9A<K0S7VPBUZ@:8[(EY/$
MF;?MO+SBOE"74*'9H=[?WG*0;JFZI:J\I-#8S8NJ>/?X]7>$5Y&4?>WM[*&0
M:***>*-J2^;DX[&3A\2?FL!/0*^3D<@``,8``'X``'T``,D#`\<#`\8#`\<$
M!,<%!<H'!\@)"<D-#=$/#XD*"LH2$LT8&)`1$>`A(=(@'\\@()H9&:0;&],G
M)ZPA(>DO+Z\C(Z0A(;8F)M@P+[@H*.XU-;LJ*KXL+,,N+L`M+<<P,*XJ*LDR
M,<8P,-XX.-TX.,XT-,LS,_,^/O5"0M4Z.K@R,OE&1M0[.^)!0-P_/ML_/N%"
M0OE*2L,[._I-3>5&1NI)2>A(2/I/3_Q04/I04.Y,3.A*2MQ&1O%.3OA14?=1
M4?504/104.Y04.U04-!&1O%75^544_5>7O5@7^596?ID9/AD9/5E9?-E9=%8
M5_QK:_MJ:N%E9.YO;\R@H-.HJ-RQL>*^OO/0T/GW]_'O[]#.SL_.SLG(R/O[
M^_;V]O___P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"3[0G@````!8DM'1`"(!1U(
M````"7!(67,```!(````2`!&R6L^````P4E$050(UV-@P`)L[?P+^Z9)S9HM
MRY?M$YE5#A2R\\[L:9\J*2`@,K,Z.+VL'BCD$=_15<4KIJ.MP-^:5E17`A0*
M;>9H8K%0E-=2T64OJ*W,!0JQ];<D,YLHB1KH:7!5U.2G`(6ZVW+\F,S532V-
M5;D;BED3@4*=I8%N3CS*AE9J^IPE&0G10*'&<$]'ATDRFD9"TR?FI<:&`862
MO)QM7":+"\H)SYB0$A,1!!3R=;6V=Y\B,7>.M%EO7%1(`#;O``!*L3&9(MX3
M#`````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<&8N<&YG````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P-3`@,3`U,34T,S,W
M-#<@,#(S,#,U`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!0
M3%1%````____QE97R%M=SVEJXZ.EZJRPMY67PWJ)EV>)=DE[AV>:DG>CBG^Y
M9%NAE(S)>72CHI[3I*2EOL#GA(S1GJ*[=8/*ML#K]/7XHJ_/]_G[V=O<SM'2
M[_3U]OW]QLS,Y>OKV-[>RL_/^O__^/W]\_CXT]C8R,S,P,3$KK*R]_O[ZN[N
MZ.SLY>GIR\_/MKFY[_+R[O'QB8N+S]'1^OO[^?KZ^/GYT-'1S]#0V^#?V-W<
M\?+QW-W<U=;5QL?&^/GWS<W)R\O)R<G(R\"VR+NTSX1@PFY*RKRWO&E.YJZ<
MOYZ3X,6\P5$RTW=AOY:,Q$$MOY")XY^:RH.!QX*`U(Z+PXZ,W:*@X:>E_+^\
M\[BVR```QP``?0``?```R0,#RP4%R`4%R`D)T0T-TQ`0SA@8VQT=X"$AT2`?
MFAD9I!L;ZB\OKR,C[34UNRHJQS`PW3@XT38U^$)"^$9&PSL[Y49&_4]/^U!0
M]5!0\E=7?#$Q^VIJR596T%M;D$1$W&EHZ7IZ]8J*XH&`N&AH^I.3]9*1]9N:
MQG]^\YZ>S8R+K'IYN(2#SI>6OI>7^_KZ^OGY]O7U]?3TQ,/#^OKZ]?7U\?'Q
M[N[N[>WMZNKJZ.CHY>7EXN+BX>'AW=W=T]/3T-#0SL[.R<G)OKZ^____````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````:0/[GP````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX`
M``#!241!5`C78V#``F)B,XJK*O)3$J+CD]-RBLJ`0I6U3>VMC2S,3-4U=?4-
MS2U`(2--714=-1>_`&=%!55E+6V@D)"YR31I=S<??U=O65.SJ39`H8F]UG-D
MO#S8>WP]I29-F3T?*#1A\BP+!P$N3AX.08G^F?/L@$)],^8N<!3EX^;E%[:?
M;NNT$"AD:*4DKVXL*28B+F=@J:>A#Q0*ZPAN"PH)9&6+B`SO#NWJ!`JE)T;%
M):5F%9:6EQ3DY69G8O,.`/7Z,O&OF_V7`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]P:"YP;F<`````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,C`S,R`Q,#4Q-30S,S<T-R`P,C,P-#``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!(````,"`,```!8S!V.```#`%!,5$4```#____-(R7-24K+JJVQ#2"^
M(#'-,D.Y-$&O,T"Y.$;:157-2%;@4F';4F$)!6H6$78G(H4Z-I4X-85+1Z-&
M0Y554:E23J,``&H!`6P!`6L!`6H#`VP#`VD%!6X%!6P'!W$)"6X*"G(-#74-
M#7$0$'@2$G04%'T8&'X8&'@='8(A(88?'WTF)HP9&5HK*XXG)X$O+Y(U-9<Z
M.IPX.)`^/IY"0J)&1J0_/Y-!099*2JDZ.X--3:E/3ZI)29Y,3*-(2)I04*I1
M4:M14:E04*=75ZE>7JYJ:K=E9:R8F,]45&,-#DA%1H,7&WF0DKQW>8G8VN.!
MB)[.SKGQ\=S=W='-S<?/S\NRLK!_?W[2TM'AWKG_^]+8SHK\^-WKX:'&OI+W
M[[_4SJ?3S:BFHY'GSU;ZX63_ZH#VXGO,M8G4OK+,``#.`P/0!071!P?4"@K6
M#0W8$!#,$1';%!3>&!CA'1WD(2'H)B:G&QOK*RNP(2'N+R^R(R.Y)B:\*"CR
M-36_*BK$+2W!+"S'+B[U.CK*,##-,C'5-C72-#3/,S/X/C[Z0D+:.CK@/S[\
M1D;E0D+^2DKJ1D;_34WN24G_3T_^4%#R3$S]45'V3D[[45'Y4%#,5E;+@'_Q
M\?'AX>'2TM*+BXO___\`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!0"]-D`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```+1)1$%4&--MP;%-`T$0!=`_LS.S
M)]M80D(B,P50!"'"?3BC!UJA!B)G2(Z1[!ZP1$AB?'M[.W,NP+P'7"&LZ?MF
M$;]_Y\&R99U]"I;]JL6IE$%432R!\=P)U;Y4-E4QJTBX4R;]*9[-U++7HZ!E
MG>RQ[7HB9HJ`@*;(I_MW)Q*FB`D"CSA_Q*OJ;9?K4-N;X&G++P]-TMS4JX\-
M`EJW/4OJ9DIE'-W!^-H<*(DN3(?B'H%_7``YI$E:`BV9'P````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W!K+G!N9P``
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#0V(#$P-3$U-#,S
M-S0W(#`R,S`T-P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`
M4$Q410```/_____^_\?&Q_+Q\]36UKK!OLW7TLS6T#QV33-N/L74R$!R2$1X
M3$^*5VB6;U9[6FJ!;(>CBA53&B5@*52(6$UV4(^>D'>A>::ZIPI)#"9E)R)2
M(RM=+$F`2H>BB`!"```^```[``%#`0$[`05(!05%!05"!04_!0=*!PE)"0E!
M"0M+"PU0#0U(#0Y*#@U%#1!3$!!2$!)0$A12%!1/%!96%AA8&1A5&!=/%QU=
M'1A-&!U<'2%B(1]<'R%A(1M(&R=B)R%0(2]N+R]M+R97)B]H+RA9*#5S-2I;
M*C5Q-2U=+3!C,"Y>+CAP.#1H-#!@,#9J-C%@,4*`0D)_0D%Z04:"1D%X04)X
M0D9[1D^*3TZ(3D^)3TE_24R#3%")4%&*45"(4$^%3U"%4$AW2%"$4$U_35&#
M45B-6%2'5%>+5U6(55Z+7FJ3:F6,96:(9FJ,:FB):&Z.;GJ8>I*PDHVIC8*;
M@J+`HJ&[H;#*L*_'K^?OY]OAV\3&Q-35U#)E,3!A+S9F-3]T/D=]1N?GYMW=
MW/CW]_W]_?KZ^O;V]O'Q\>SL[.GIZ>'AX=C8V-34U-+2TL_/S\W-S<S,S+N[
MN[*RLJ>GIYV=G924E(N+BW]_?____P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````+ZRK\(````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^
M````OTE$050(UV-@P`)FS9I>EIOE9Z&FH&ID[Q$6#Q*:,:4J)]Q.RU)'U\8E
M."H1*#1S:D]EBJ->D*"^>6AF=$(L4&A:/U-%@[&4N(B)M!!'1EP34(B9L;/4
M6IV+S<S>@T\B.\(?*-36T5*LK<C#RND6'),<&>@#%&KO[BM241:N91=-2Y?C
MK9<%"G6U3BQ4TC3-8ZDN+Y$7\'8%"O5.F)RO86CKQ<]=(RGFZ^X$%*J;-+G`
MP,HY)"FUN3'`4\8!FW<`00`Q0645BJL`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O<&PN<&YG````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#(P,C4@,3`U,34T,S,W-#<@,#(S,#0U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````2````#`@#````6,P=C@```P!03%1%````____Q\'"__[_QL?'X.#?
MS<W,S```S0$!S`$!S@,#S`,#T`4%S`4%T0<'S0D)U`H*U@T-S@T-V!`0SQ(2
MVQ04WA@8TA@8X1T=Y"$AU"`?S!X>SB`@Z"8FIQL;ZRLKV"<GS24EL"$A[B\O
MUBHJLB,CN28FW3`OO"@H\C4UORHJQ"TMP2PLQRXN]3HZRC`PS3(QX3@XU38U
MTC0TSS,S^#X^X3DY^D)"VCHZX#\^U#HZ_$9&Y4)"_DI*ZD9&_TU-[DE)[$A(
M_T]/_E!0\DQ,[DM+_5%1]DY.^U%1^5!0\5!0RD=&U4U-^EU=YUE8_61DZEU=
M_VEH^6AH^G1T^'M[V-'1T,G)S,7%\NOKY-W=TLS,__GY_OCX_/;V]O#PY=_?
MX=O;TLW-W=S<_O[^_?W]_/S\^_O[^OKZ^?GY^/CX]_?W]O;V]?7U\O+R\?'Q
M[N[N[.SLZ^OKZ>GIZ.CHY^?GY.3DX>'AWM[>V]O;V-C8UM;6U-34TM+2T='1
MT-#0S\_/SL[.S<W-S,S,N[N[LK*RIZ>GG9V=E)24BXN+?W]_____````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````1CF(J`````%B2T=$`(@%
M'4@````)<$A9<P```$@```!(`$;):SX```"N241!5!C3;<$[2@1!$`;@OVN[
MNF?&Q\(>S<Q85/`01B:&)@:B>#0SEP5!&<3IJ4>7!]#O`_Y(N(??^LU1*3"U
MUOI+!KI?^<B,;B[R?`U"^*>,S"G459XN*PB^/$QSH3MS4[FHCTB@\PV)(R('
M!R5ZS3AK^K&7-.RV0T[=`ADZO\U+#*(QC:TU`T'?O]=>N&Z':JNI(&/_M1IS
M/CXIJ8FX@7!HLF&>3FM9?LS=\(]?4O]>\FG40F\`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]Q82YP;F<`
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3(R,R`Q,#4Q-30S
M,S<T-R`P,C,P,S(`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```!
M@%!,5$4```#___]C!2IC"2QI#3%D#B]E$#%S&#QN&#IN&3IL'#MV($&!+DZ,
M-5>70F.006"+0U^'2V*(4&6*4FB36W&-66V28W6A=(6H>HRWD:#HV^!?`"=A
M`2E?`2=>`2=B`RIC!2QB!2QE!RYH"C%K#3-N$#=Q%#IJ%3=T&#YX'4)X'4-\
M(4=<&S:`)DM_)DJ$*U!C(3R)+U1F(SYK)D)M*$2--5EO*D9[,$YV+DMT+4IQ
M+$B1.EYX,$YZ,D]^-%)^-%-\,U&5/F&`-524/F&`-E280F:$.EB;1FF*/UV.
M0F&>2FR>2FV21F6@36^626FA3W&B4'*:3&RA47*?4'"<3FZ@47*_DJ2UGZBT
MH:FWIJVKD)S`J;.ZI:Z^K+39R=#KV^+__O_'QL?4U=7&Q\?4U=3GY^;=W=SX
M]_?]_?WZ^OKW]_?V]O;Q\?'L[.SIZ>GAX>'8V-C4U-32TM+/S\_.SL[-S<W,
MS,R[N[NRLK*GIZ>=G9V4E)2+BXM_?W____\```"D#SU-`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```*Q)1$%4&--MS+$-PC`0A>&S[\X)
MP05*A^AHL@C#L`0[,`H=$C/0,0`2$A*T((AC^VP<4<)??M)[`#\IV(#<8W]P
M<\]LFG:R(X`DU3YW1T]$9E8C:,C2IU4Z+=170B$9'B0Q9H-L&\Z^T&T[197S
M%;FVK-V[D%G[I]!2\SAS0RJD:-KF?$%N:Q-\&(D&U#KJSE8<O8]#(;0(@NIL
MC7:]"U+HA9`,H2I'05**\*</(Z=(6@/N(L,`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]P
M;2YP;F<`````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`U,"`Q
M,#4Q-30S,S<T-R`P,C,P-#0`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8
MS!V.```#`%!,5$4```#___^;>WR2?G_BT-+:N+V:BY`N.98Y0(I45FN\O<>-
ME=)J=;>"C,PR19XU2*,W29\W1Y%19<([28M<:[!;9Z(F.I4G.Y4J/I0I/(\M
M0),Y3ZU#5:9'6JQ&6*I49K1=;[AG><IL?LY?;JXZ0VIRA,MTA<AN?+=O?+,V
M1H0X2(4[27]/8:=!37M+5X!(5'E@:86*E;9:9'V2F*-L=(&8GJ6)CI.<GI]D
M;G&NO;V5FIK5V-C2U=74U=6$C8>XO+D\5$!/85)8<%F(FHEM<FUH;&C+S<M[
MC728FY5I;F%F;%J?HIA_@G6AI8^CII)B94]F:5.KKI2AHY!X>F*&B'./D7V`
M@F*=GW^&AVF-CG>RLH"NKI24DD&CH5V!@$N)AU&7EF:BH76XMX>HHSVOJ42!
M?3>0C$FWM&RWLVZPK6V[N('!L@*MGPBYK174QB/NWR_IVC7"MB[(OSOY[5#N
MX4[EV5#BUD^.AS/0QDR!>R_#NDCIWEG=TU6+A3:KI$;BV6'!N%.EGTFDGDZ)
MA4W!O'C/P"65BB#GUS6UJ2WWYSZLH3*OI#;%ND:2B33-PE,X+QFL?1B+?V3"
ME3BQ7`6I60JW;"&T40#&737<=E:[.1FN(Q"Q)Q&DC8JXI*/ET,^L(B#-N[N]
MMK;___\`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````0D'Z.`````6)+1T0`B`4=2`````EP2%ES````2```
M`$@`1LEK/@```,%)1$%4"-=C8,`"'%R<F+C5Y/DE)*4$9(4458%"CG;.K+P*
M!IZ:^C$FRKZ&2D"A_CD3W7GD]%+]!<-BU4V]-8!"S`OG6>KP!>34&C4U>+1D
MB`"%S&W=N&2TLG.#\PK\JDO,$H!"UC;VQN+:;7$I^371Q>FB$4`AE@5SV73%
M*M.J.NN3RB(;XX%",Z;/G,_IE5P4'A5H%>K3X0H4FC1A\BQVB];VTJR@Q+K"
M9F&@T-0ITV9S2(=49/;U='?UEJM@\PX`M](R\=CU\F0`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+W!R+G!N9P``````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`R,#4P(#$P-3$U-#,S-S0W(#`R,S`U,0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___[@4%<HU
M-K-E9I\6)[!W@H<,*D<1+<BVP%`H29I]EFI`=ET_?5,Z?38K>YZ9RBLF6E5/
ME7ESM'9QL'ETKX^*QI>3QDA#CT1`=8:!PW-PHWMXH>7D\D1`BUI7H(Z+PMC7
MZE12G$5%?EU>IAH=5$]2F9>;QJBOP_'W_>#@W\^LI\V!>\R3CLN3D-2<F<<'
M`'@$`<0-",LY-?%.2?-74^M44,595LY?7/.>F_2CH,V(AM>4DN2CH?&RL-2>
MG."IIZV$@^VXMKB/C<29E_C%P^&TLOO*R/+#P<JFI<^KJMFVM?+2T=[!P/O=
MW/#3TKX``,4#`\,&`\$'`\(%!;\%!<D-#<D0#<L0$,P8%,88&-0='=0A'=<A
M(=@H))<9&9X=&^(O+^(R+ZDF(^4U-;4L*N8\.,$S,,`P,-8X..]%0NY"0L@Z
M-_!&1KT[.^!)1M]&1MM(1?123_-/3_-04.Y04.Y24.M75\134<954_5J:MEL
M:LUH9^=]>_.-B^"$@OB6E?*5D[V)B,>2D?F\N^BPK_6[NL^BH>;#P_S<W/[^
M_OW]_?O[^_CX^/7U]?+R\N[N[NSL[.OKZ^CHZ-[>WMO;V]C8V-34U-'1T<_/
MS\[.SLW-S<S,S,3$Q+FYN?___P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````*#Q@[L````!
M8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````P4E$050(UV-@P`(X
M#./SJLHSHT(#0B)B4W)+@$*J7"Q6EO4UYA65%M6U=0V-0"%!977-B=-FS9D]
M?<JD7L:>"4`A26DI!4YM3T\O[PZ?3C]_7Z"0C*RX/!]KD%%D7)J)J5EA#E!(
M0%%4@I\],"PZ,;NXM(`Y`R@D)B(DQZUC;6-KU]+6:M_<!!025E+3F#-CZN2^
MKNY^K9ESYP&%5'C9=/7T'9Q<W3W<VEV<'8%"/$P&P>$Q25E%9?G&Z:G)"=B\
M`P"%I#'W!JEO/0````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M<'0N<&YG````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P,S4@
M,3`U,34T,S,W-#<@,#(S,#4V`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````
M6,P=C@```P!03%1%````____T#4VRF1EP%UHDJN;.GD[`%H``%<``#D``#@`
M`UP#!5T%"5\)#6D-"D,*&&H8$4L1'W`?&509(5PA*F8J.(,X,F\R.W@[2(](
M4)A01H1&7J1>7J!>69=99*=D:J]J9:5E:JEJ$V02,'PO9J9E"64%9ZED;JUH
M.G\G6Z!(>*U7-G4#:YY`57`"3V`1FZI3?H(F>WX-=G<G<7%!6%8=B(=7PZ$9
MM)H\DF@_SFT=UG4GQV,7Q5P0M$D$E3X'N4D'PTT2GDXIWU8KR#,-HCLDOU(\
MFV9:JJ">Q!0!R!L'O2(4X2HAQP``R0$!R`,#RP4%R`4%R@D)S@H*T`T-TQ`0
MUA04V!@8SQ@8W!T=X"$ATQ\?I!L;XB8FY2LKK"$A[2\OZB\OZ2\OKR,CMB8F
MN"@H[C4U[34U[#4UNRHJOBPLPRXNP"TMQS`P[SHZR3(QQC`PX#@XT38USC0T
MRS,S]#X^\SX^]T)"]4)"U3HZ^$9&]T9&W#\^VS\^X4)"^4I*YD9&^DU-Y49&
MZDE)^T]/^D]/^U!0^E!0[DQ,\4Y.^%%1]U%1]5!0]%!0]E%1JUQ;K61D____
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````TJ#?"P````%B2T=$`(@%'4@````)<$A9<P```$@`
M``!(`$;):SX```"V241!5!C3;8R]#<(P$$;/]MG.)42`B"A`L``CT+(."U#3
M,@X2#0NP"#^B0`(<8I\3DAI>^?1]#^`'`23H.1DOSQ4KK?-1;R-!6)QR??,L
M$9-A9@!!HS747+5&I0LR)4C0)J5^W[Y9F0%1K%J%5B4GLY)/S/*D<=TJ#[+:
M'0\BVD%JJFULE6<6^Z9Q5!"Y<NW;?,B\NBX=+E+R/L1.\9UY_IA-NI#[^-`>
M.09U,<60=/GR=1WA#U]X@D<:;\+G6@````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]P>2YP;F<`````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,C`S-R`Q,#4Q-30S,S<T-R`P,C,P-C4`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___^(&QS%
MM[FCGI^<DY:UE*#-M[^PBYFJFJ"_GZS+R<J_M;S!LKZ[K+WHY>LW-IE,2K!5
M5,1@7K\``(0%!8@%!88'!X<)"8D/#XL0$)(3$Y(8&)`A(9\C(Y\E)9<?'W@A
M(7TH*)$J*I(H*(@G)X(U-;`U-:XN+I8N+I$N+HPT-)LX.*4U-98\/:1&1[T[
M.Y](2+Q"0JM04,%.3KI+2[)55<!"0HY14:I*2IA14:)>7K%M;LML;,)R<LMO
M;\+W]_KU]?C/S]+$Q,?"PL7FYNCDY.;2TM3%Q<>ZNKS%QLGR\_7W^OKQ]/3O
M\O+)S,S[_?WZ_/SAX^/=W]_.T-##Q<5OJFQHGF)=HDU^G'?\_?ODY.+2TM#(
MR,;W]_;V]O7U]?3GY^;2TM'*RLG;UM7'``!\``#(`P/+!07(!07("0G0#0W3
M$!#.&!B0$1'<'1W@(2'/'Q_*(B&:&1G*(B+.)B7**"CI+R_M-378,C+=.#CU
M0D*X,C+X1D;B04'E1433/S_#.SOZ3T_Z4%#T4%"N/#SS5E;R5U?U7E[Z9&3J
M7U_H7E[S967W:&C[:FKE;&SX>'C6R\O8T='+Q<7Y\_/X\O+OZ>GNZ.CMY^?B
MW-SZ]?70S,SZ^OK___\`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````;OUV$````
M`6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+A)1$%4&--MP;%-
M`T$0!=#_9V?'9Z_N0+)LYV2$E.`&+-$$54!$0!,40`.(C,`Y.;EC2\87G'RW
M.TL!\![P!_&`MFLO?9]S4&VB/0G0S-,X#"5+"+,0"<'K9JE!XJ+MNNNK+AD4
MLJXNS7/0EZ8XY0N*^_=BG&PGCUN/.0H4R0MG;YEEW'U&X01B&S-I^VR\2Z.0
M'PH_?R^KW1SDUL]>JT-Q/-D/8UC-!_K%IP)!7ZBFBW0(="$K_O$+26H^)XWQ
MTWP`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+W-A+G!N9P``````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#0W
M(#$P-3$U-#,S-S0W(#`R,S`T,0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P``
M`%C,'8X```,`4$Q410```/___X.MA`!T``!S``!)``!(``%Q`0-V`P-T`P5X
M!05V!09X!@9V!@=U!PEX"0IX"@MW"PU_#0U]#0UZ#0]]#PI3"A""$!)]$A-[
M$Q1Z%!B&&!B!&!%;$1V+'1I]&AV)'1R$'"&0(1^''QMK&QED&22')26()2>+
M)RN4*R)U(R%R(2^;+R%M(2^:+R9Z)BZ2+BA[*#6@-2N!+"I^*BV#+2Z%+B^'
M+S"(,"IW*C"',#2.-#.+,SB8.#B7.#2--#:/-CZC/CZA/D*J0CJ4.C*`,D"B
M0$:N1D*>0D.?0SJ*.T"50#N*.T:B1DFG24BE2$:A1DVO34FF25"T4$^R3TVM
M34RJ3%"P4$^N3U&Q45"O4$ZJ3E&O44:71E"L4%2Q5$^D4$R>3$^C3U>Q5U>P
M5UVV75^W7UZV7E^T7UFH64Z33F2[9%^P7V"P8&6X96J^:FB[:%NC6U><5U27
M5&BW:'2_=&FL:7K">FNF:V:>9G2R=&^J;V^H;VB=:(7(A8;(AFZB;FVA;8C(
MB'"D<(&[@7:G=HC`B'FE>8&M@:#4H*S/K+/7LS"1+S*),3:/-4&>0#^:/C^8
M/ENW6F:X96VU;*;#I?___P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(P(`PX````!8DM'1`"(!1U(````"7!(67,```!(
M````2`!&R6L^````P$E$050(UV-@P`)8V52]\I/M9+B9N<25C-R#@4)LLJYY
M:9[JDH*\P@IZSB'A0"$QR\SRKHKBVH:BPI:,P$@_H)!N;,&4J:U9[4S55=UU
M,6$3@$(^^2F)'8V5S35E;9WUT1[60*')Z?UJ\H)2HG).$9/B?1TL@$+9_AHB
M[.P"TIJ.H3%!+KW&0*&X'@E./G/OA)S2IMR)-J;Z0"%;&6X6'D4#MYC4DB1[
M,T-MH)`R/S.'D)R.<TA40)^5B98*-N\``-F@+<N\X.43`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<V(N<&YG````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#(P-3`@,3`U,34T,S,W-#<@,#(S,#,T`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____)T./
M4EENP,GA`2>%$#22"B!6'T&5*D!Y4&VY<H2RAI&M`RR&`RN$"3"#$CB*&3%G
M*4N8.E>:.E6/2&BP)SA=2&:I3FFC5W2U1%N,<HS&8G>E4F*'?)/&BJ#0?9&]
MI;+.N,7B!"R`!BY]"S)_##%\#C2`$C>"&S^)*TR0'S)9.%F=)3MG1&6F2&:E
M6G>T8X"]9X7!:86_;8G!9'NHH;/9'C]Z/5N-3&:.-5%Q0%9D4V5?;GYH,'X-
M;K)018\A290F7Z8^9Z=)8*4Z9JQ"<K-/;*I,1HX=.FP;0'0A7J(U38,L4HHP
M5Y`T69(V9J%"<K-*:J5&=+1-=K5/=;51=[51<J].<Z]./X<00W8C6IXO1WPF
M27XH2X`J3X4M48<N5(PQ4XDP5HXS69(U6)`T:ZU"7I<Z;[!&8YT^8YP^:Z5&
M;JE)=[50<:Q,=[11=K)07Y\K@+E&@X]V2X4#C[]19YD4B;,OK,M*;7A)?)H%
MN,Y0FZ\8OLHU>'XWH*8`V=Q-D)`]L[-@L:X'JZ@[RL,=IIX@S+P`S;T!S+T%
MUL4-V,D0LJ44U,8?Z-@FZ-PZ^NU"W=`\QK,`S+D#S;H)T\$;Y-`AQ;4BZ]HK
M^.8^_.M&_NY0^NE/SK@%U+T*____````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````,-LK/P``
M``%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#!241!5`C78V#`
M`IC%!$7D6?0U557XV2R:9LT&"FGK2LF9*&BIJ_`)V$Z<,*<:*,3.J:@DSJ2A
MS&K5,F-F0ZDS4$C65-I`0H97K7)J7W]%J'LF4(C'3%)'F-NZK7M:;9%]>(`?
M4,C84(_#O&YN5VNYJUM!D+\O4,A(5,BFIV->3:%3<'Y.>J(/4(C+LG%R>W.9
MHTM@6%Y6<GP,4*AX>N>DJD@'[XS<B(#4A%@OH%#OE/H2.X_HM)""[)2DN"A/
M;-X!`,DQ,?590(Y``````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]R;RYP;F<`````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`P
M,R`Q,#4Q-30S,S<T-R`P,C,P-#8`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,`
M``!8S!V.```#`%!,5$4```#___\`)7\#)X$#)X`-,(4?0)`X5J(Z5))0;;1D
M?\-E@,``)WT`&$X%+'\)+H$*(UD2-H88/(H1*F$?0HX9,FHG29,A.G,P49DJ
M1'U!8*8[59!(:*Q0;[)7=KA>?+U9=+%D@<)HA,1F@;]JAL40,G40,704-7@7
M.'@</7\F18(X69\R388\69)&8IU4;Z5I@[9UC;[-L@#,L@#,M`#,M0#-LP',
ML@'.M@/.MP/,M`/,LP71MP?!J@?-LPG"JPG4O`K4O0K6O`W.MPW"JPW8OQ#&
MKP[;Q!3>Q1C-MQ?2NACAQQW%L!GDS2'DSB'4OQ_HSR;6P"3KTBONV"_NV2_.
MNBWRV37AS3CXXS[ZXD+\Y4;^ZDK_Z$_^ZE#=RT;YY5#MVUS0M07UW#K/K075
MLPW=O!CGQB;QT37ZVT+ISD;^X$WUV4[\X%',*Q#5-QW?12OI4SK+2S7Q7T;;
M6$+H8DSP:%'T9D^>)ANF+"&I+B.O,B:R,RCE0S6U-2JZ.2VW-RR].B["/C'`
M/##(033%/S/*0C;N44+/1SKP54;523[52S[:3T+?4D;S6TWC5DGS74_S7E#K
M6T[G64SR7U'P7U'N75#7+2'B.R_`.C#(/C3L23[R54KC4TGS6U#N6E#___\`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#->E7Z`````6)+1T0`B`4=2`````EP2%ES````
M2````$@`1LEK/@```)Q)1$%4&--MC+L.PC`,`&TG=4(%B`7Q#5WHK_'++$@,
M#*@5>=ND,]QX.AW`#P@'\,LTA^6=K^/TV/L;`?#%J,0U6D0<W0`$AE?5L";C
M$8T;4E?N3"HA%.9>L=2N[*=*BWG>.222M%6^5)5D[[VR6+*"!6E5&WEVM@]*
ME:YJ+8H._2F1OEK;7L?<!`US)-53;5OU[(8\F?X6;:+PAR\'9E(GF2`_TP``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W-D+G!N9P``````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`R,#0V(#$P-3$U-#,S-S0W(#`R,S`T,P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___]8^
M0,S#QCDV.=/1TR(C(_?Z^O'T]-_BXM/6UL[1T?K\_.'CX\[0T.+CX^SP[YJO
MGB9P*0!```,[`PEB"04J!0UI#0YC#@I'"A)M$AAM&!AL&!]V(!]G'PD="2=[
M)R%@(2EO*2IM*CB,.#B(.#M].TB52%"=4$:)1E";4%>B5UZG7F2L9&BO:&JP
M:H6CA20H)*&QH7%R<?#Q\,C)R#"#+T&/0%J;66:K96F28Q]&$2(J`#8V-4='
M1EI:6;RZM;2!9))!,FP'`,<``,@#`\L%!<@%!<@)"=`-#=,0$,X8&,,8&,49
M&=P='>`A(<\?'YT9&<LA(<8C(^DO+]4N+NTU-=TX./5"0OA&1N)!0<,[._I/
M3_M04/504/!34_)75_A>7O=A8>=;6^A<7/=E9?1E9/MJ:LO#P\:^ON+:VM7-
MS?CQ\>_HZ.WFYMO5U?S\_/?W]_;V]O+R\NOKZ^?GY^7EY=[>WM;6UM+2TM'1
MT<3$Q+JZNG%Q<6=G9V%A85!04$]/3TY.3D9&1D)"0C\_/SX^/C4U-30T-#`P
M,"\O+RXN+BHJ*B@H*"$A(1T='1L;&Q`0$`T-#04%!0,#`____P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'P6+18`
M```!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````OTE$050(UV-@
MP`)LG`.CTQ/"O=U=W+S\PR)C@4+"UDZIB5$!'BZNGGXA$3%Q0"%)90O'9*9@
M']^@T*CXI+04H)"BIIZ6E0-S9D9V5FY.3EX^4$A-7UM56DB0CXM3@)V'@Y<;
M*&2I8RXK*F%045Y26%!46FD*%-)55Q!7,F*MX#<I+"ZKJJX!"FF828D8LK0U
MUM<:U]DWV;4"A51DQ!@F3^QK;VYH:NGH[NT#"LG),TR9U-_5TMC0;-O9PS8!
MFW<`&`4P'>GCV$D`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O<V4N<&YG````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P
M-#8@,3`U,34T,S,W-#<@,#(S,#0T`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#
M````6,P=C@```P!03%1%````____`QN\$BR[)CJJ,$?*+4*T.E'C/U7.2F/K
M3&/A46GK4&;@9&5K,TF_`"*O`".O`2.Q`R2Q"BRV"B!X&#K`)D?,*TS.*D&=
M/E[<1F7B.E*S36OD3VSE4&O:9'SH97WC`!=K`26L!">N!2FP!2BO!BFM!RNT
M""NH"2RF"BRN#C&V$32Y$3*H%CF\&3JU$BE_&#>B'D#"(D3&($"X(#^O(#ZH
M&C&()TG)'#21(3J:(SV<,%+0(CF2*$.E-5?4*D2G+TJO.US8,4RR-5&Z.5?&
M-E.\0V/=/EW,,TNF1V?@0%S&0U_+3&OB26;51V304&_C3&G646_C47#C46_B
M3FS;36O84G'B46[>0ENT1V&^67+3:8/G%3695W'';875>(_<@86(J:RM;W-S
MGJ*BDI:6>'M[E)>7DY:6@X:&GJ&A=WER<7!0UK@-X<0=U+H@[M,ORK0PU;TV
M^N!"Y\Y`ZM)&_^5/^>!0^N)>^.)ES:T*O:YHSL"`QZ,/Q:$/R:00P9X2Q:(4
MRJ@5Q*0?S:PBQJ<CKI0DUK8NPJ<PL9@MS[(VS;([N:(]V+U)WL-/FH@[IY1%
M[M-DR+)4H)!(KIY7IIE?LJ1GRKMXN*IOH)1AQ[E\RKV"ULF2____````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````!W(D_0````%B2T=$`(@%'4@````)<$A9<P``
M`$@```!(`$;):SX```"_241!5`C78V#``A05S:43)DXR5552T3&V]PH&"1EX
M*L3W]>@**&L;V;@'1`"%1"2BY>.Z.C4$A47%)65"_(!"ME$Q<I&M;9KJ>A9.
MON%AWD"AF7-F3YO0V-`_>4KU])I9,Z8"A2HK2O*KZNIS\PJ*R\I+BPJ!0DD9
M:;PYM<W9B:E9*>F9:<E`(1Y69J;8I@XQ=DYN+@X^-A:@D*N^&K]A2[>'5%"H
MCXNCG150R$1+2<BLO3=0-L+?S=G!VA*;=P#B*S#XDKA3(0````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]S9RYP;F<`````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`T,B`Q,#4Q-30S,S<T-R`P,C,P-#(`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____!
MPL*RL[/4U=3@X-_=W=S5U=3-S<R_(0#!(@&_(@'!(P/#)07!)@7!*`G'*@K)
M+0W"*PW,,!#1.!C'-QC5/!W802'?2BOB3B_F4S775#CL7#[H6C[O8$+Q9$;6
M5S[T:4WD9$GT:T_U;5#O:U#Q;5'M;U;M<%=_=7/_\.W`'P"_(0/$)0?"*`K%
M+`_"+1#$+!+.,A3..!O(.1W).A_<0B;:1RO.1BV7,B&.,"#I5CJJ02[85#[+
M4SSS94KH94SS:E#R:U'=8DKU<EG59E/"74S?;5GXB77WD8!]3471CX3,N[CO
M?VWK@W/QB7GHAGBW:V#YE(;DC8#[LZE_7UJFB(34Q</5Q\7*O;OYZNC#>W+U
MGY3.O+K6Q,+XY>/AT,[FUM3NWMSZZNB+@'_-N[KJV]KWZ.?^_O[]_?W\_/S[
M^_OZ^OKY^?GX^/CV]O;U]?7R\O+Q\?'N[N[L[.SKZ^OJZNKHZ.CEY>7DY.3A
MX>'>WM[;V]O:VMK8V-C6UM;4U-32TM+1T='0T-#/S\_.SL[-S<W,S,S*RLK'
MQ\?$Q,2_O[^\O+RYN;FPL+"GIZ?___\`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````#HQ>]+
M`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+M)1$%4&--M
MRST.04$4AN$SY\R9X2:(0B(*";5";QWV(#:@H%)22*Y";S,V0:(1B83K-W'/
M#->H><LGWP?PDX+N(VD>MS=)G3::F-<$F:JF9=8'1_P5/"%T$.5^V7BE"8GH
M!1JNI8P?:2U#UF'VW@+".>^2)$-M>&]X1_6P:CP+47%?5HBM5;MY58&P$EEL
MB)-TWL]%2PG'?&P0O/=.>B:VXVF@W)""O$3`V!&C"C1A>'LO;L%V9G&@X$\?
MV$="-%6:57X`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L
M86=S+W-I+G!N9P``````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R
M,#,U(#$P-3$U-#,S-S0W(#`R,S`T-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````$@````P(
M`P```%C,'8X```,`4$Q410```/___XN*G:&AM%Q>=:6GO=+3W"HQ46MRDG-\
MF^KL\YRDO&5XIG>)L6-G;QX[<``F9@4K:@4K:0HN9Q`V=!4W;B%&@B%$>S58
MDS-5BS12@T9IH4%@DD)ADS)*<#M5@4%=B5!QITYMH55TID]LFE!MFT)5<VJ%
ML&1N?@HN9A(V;A]$>RY/@#)-=CA4?SY=B49GFEAWIEIXHZ6WT0`N:P,P;@DU
M<0TZ=QU)A"]:E#!3@399B4)KHSA8A#E9A$9JG$]VJU!UJ$-BC$IIE%Z`L&:&
MLFR*LFJ#IGN7OGF3MX";P(Z9J*^]S^KP]N?GYKH:"K<;#;X>#[L>$+@=$+@B
M%<<I&L`G&<(P(LPV*=,Z*\(W*Y@M)*,R**\Z+]I(.Z,U+.%,/KI"-J\],]-.
M0<5(/;I$.L1*/^Q=4.=:3M=62ME;4.]F6>=C5NQE6N=E6Z=#/MMD7J0=&*4?
M&JDD'JHM*+0P*\)!/)P[-[M(0]!43[%)1<!54=)D7]MJ9=%G8GQX>(B$A/[^
M_OS\_/O[^_KZ^OGY^?CX^/;V]O+R\N[N[NOKZ^3DY.'AX=[>WMC8V-;6UM34
MU-+2TM#0T,[.SLW-S<S,S']_?____P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````%Q-;ML````!8DM'1`"(!1U(````"7!(67,`
M``!(````2`!&R6L^````MDE$0508TVV-.PX!411`[^_-2!"-2J.0T%F#U@IL
M12,2B[`$*]"+A@5H;``AF$1\PKQ[K^DYY2G.`?@!83ILM!:C$`0TJGY\3'!\
M/Y?Y6AA,S>)8@`"UV[$>HQ=&1Q,!@9GA)LRCW^I9G?HK*UK-JUG"ADS$">:Z
M%VC[ME8V)$06M.A[AI!53K)+#K?T`N<KOD\"@T\T)T)^5=W]4=H([.ZYDDB:
M2J:Y1B^.+S5A"J6`41$IPA^^C(M7(J(.<XX`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<G4N<&YG````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P-#$@,3`U,34T,S,W-#<@,#(S,#4V
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____
MK`T8K!`:L10>LAXHR3(\HB\WP3I#K3<^UT5/MSU%QDE1XE5>V%=?XEQEV%IB
MO"`KV^+JO,7.?(*(HJBNZO+Z(&ZS+G2R,6VB.'6K5)K93X_)6)O7M;_(M+['
MQ]#8U-WEXNOS`%JD!5^H"5JA"5J@$&FQ$&:L$F*H%6&D&&NN&VNM(7B^+H'$
M,G_")V"0-'JT.(/`-GZX1I?918_00HK%.WFL0("W1HK"4)W<3IC54I_=4)'*
M5YW63(FZ:JSA::?=;J[CV>'HY^_VV-_EZ_+X`%ZG`V"I!5ZE"6.I"6&G#6FR
M#&*G'7>^'7*V'W.T+X?,-8G,,'>O-X&\0I?90I+208W(1I',3Z#?4)W:4YK3
M6*+=5YS37J7=9JG>M\')P\S3QL?'S```R```R0,#T`4%S`4%R`D)T0T-V!`0
MTA@8W!T=Y"$ATB`?I!L;L"$AZB\OKR,CO"@H\C4UNRHJQRXNQS`PX3@XTC0T
MT38U]D)"_$9&Y4)"YD9&_E!0^T]/]DY.]5!0_O[^_/S\^OKZ^?GY]_?W]O;V
M\O+R[N[NY^?GY.3DX>'AV-C8UM;6U-34TM+2T-#0SL[.S<W-S,S,N[N[G9V=
ME)24?W]_____````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````'NXE
M$P````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"Z241!5!C3
M;<%-2@(!&`;@]_O)"6(@(J$62003K3+R4E["G>"V;:N.T@&"!*$VP@01MG.3
M6N-\/QU`GP?807A$O#Q-#E3A%M[FB(',:BPB",^PD8!P2G?DO7S.=4FTNGU=
M"JXO<*ZSHKNZ_^UC<"1?BH+LK>F]D]15W?EH6RANLFFV7BF+5!3SJZGB<VXG
MEKH\ZRSXLOU>@'#\YY%<KE4X(R,:Q?#'3%2*0V$S=W]@;-Q96`L5]\A,[/$/
M(N162;8*93<`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]S:RYP;F<`````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,C`T-R`Q,#4Q-30S,S<T-R`P,C,P-3,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!(````,
M"`,```!8S!V.```#`%!,5$4```#____*`P2\#Q+.$A.W)B?A,#+"+2[-,S3P
M/#[Q3$W\45+P4%'53U#'34_*5%7,8F3$#13(='?,M+6P&B/VPL73OK_ETM/Y
MYN>;#QV<(S.U25B>*CR)*C^*26.I>I"/7GA[57=,,UM?4W911&UJ7(=X:Y-Z
M;I2(?:!O9(A>57IO98M-16A43&]`-V)%0FQ!2WL^4H&%AH@*,W(U6Y0T581&
M;*([5X%.<:-7>:MJB;7V^/ON\//AX^;4UMD!+FTP5(,X7Y,V6HM";:5!9YPN
M26Q&;)Y"9)1/>*U,<J-0=ZI0=:A<@*]>@K%BA+)FA[0A3XHG5(DO8IY.;YE<
M?JE4<99UE\#S]??FZ.K(S,^KK:[AY.7&Q\?W\O',8E_,``#.`P/0!07,!07-
M"0G6#0W,$!#2&!C8&QKA'1W4(!_0)"'-(2&G&QNP(2'N+R^R(R.\*"CR-37;
M,#"_*BK'+B[2-3+*,##A.#C5-C72-#3Z0D+=/CS\1D;>/S_E0D+\2DKJ1D;_
M3T_^4%#V3D[Y4%#K45#,24?,O[_^_O[\_/SZ^OKY^?GV]O;R\O+N[N[DY.3A
MX>'8V-C6UM;2TM+0T-#.SL[,S,R[N[N=G9V4E)1_?W____\`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````<N/9-`````6)+1T0`B`4=2`````EP2%ES
M````2````$@`1LEK/@```,!)1$%4"-=C8,`"9LV:$</8,V'RM&E3)O;W=G:`
MA&9.CY40%Q-NGSII0E\78S=0R"@J6K25ES^5+]+.UL8Z/`(HY!H:)E\M()0M
M%>CHZ>,7$@P4,K>R5"AMB\N2"3`Q\[9P-P4*^?NZ*#-+R@K*!3E[>+DY.0"%
M-#15E/3LC0T45=74M;5T=8!"/$4L3"+ZAM*<]=Q<M1SLK$"A\K2D^,1TML*:
MIN:ZRI*"7*!09G)\0DI&7E5C2T-%67%^#C;O``#AKC%:Q/-QQP````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W-L+G!N9P``````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#0P(#$P-3$U-#,S-S0W(#`R,S`T
M-0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/__
M_]74U<?&Q\G*S?O\_OGZ_.KK[=35U\K+S<G*S+Z_P<?)R_?Y^_/U]^;HZMG;
MW<_1TP!9G05=H05<G@UGJ1!GJAAIIQ]QK2%VMQM:B"=PIR%?CREQIRUUK"AH
MFC6'QBYQI#!UJ#B"NS1YKCF`MS9YK4:6TD*)OT^>V%"<UDZ7STJ0Q$)WGE".
MO$J`J%V@TE&(LEV6PFRLW6NGTW&OW0!<GP->H`EAH1UUM2)DDR^&Q"IMG39^
ML4*5T4:0Q5"<TVZIU.CJZ];8V=35U:*DH=K=V&Z@07^T3WZQ4(BW7HVY93AU
M`"-)`#MW`S]Y"42`#4J`%TI_%S5<$5.-'5&''U*''S]F&5*%(F2=+U^3+6NB
M-76L0F^B/V:5.EB!,F.,.UI^.("Q48.N68V[8(2O6XZ[8XRR:)K"=#MV`"5*
M`$![!3]Y!4J$$$Z$&%J2(3E:&&F:.'NP1H.U4(6S5Y7`:L7(POG[]^SNZL_1
MS<K,Q\G+QL7'POCZ]??Y].[PZ^'CWM;8T]36T>SMZ>?GYOCW]_[^_OS\_/KZ
M^OGY^?;V]O+R\N[N[NKJZN7EY>3DY.'AX=C8V-;6UM+2TM#0T,[.SLW-S<S,
MS,K*RO___P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````*=
M14D````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````N4E$0508
MTVW!/4X"410&T._^O!G0$:%`"Z.)80MN0-V-"9T5)0VA<#>N@\9H:0S$1J0P
MT6C>S/V>"]!S@#\$-]CUQR6"H:KOQW+GV%3-]BT&.50]V9/`,?FH3MLVFR:W
MI&<%CL<+-LR2O<="R2L(C,O*'!'LNN*>IHKY(M\;R!(Q,[M-`*JK7K_QT?!P
MD`[JZ[U]""YW/]^TNG;3PD(^.-:?0;&VK4VB"P8<7^>4YXG:]JCP]80O^,<O
M-&1-?9F=F=4`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M9FQA9W,O=&,N<&YG````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#(P-#4@,3`U,34T,S,W-#<@,#(S,#0R`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````2````
M#`@#````6,P=C@```P!03%1%````____O%)4UG9WUGM]L(&"ZJRMG%%4W7-W
MUGA\<"@MISU#PF)GKEUBVGV"GS,[QJ&DN)"5MH6-94!'9T5,I7F#RJVVDV)S
MC5=JFWF(C6-VPI^OS;'!85=AL*BW>W6&M[++BX>N-SEL4%2`$1U:+CIR,SUS
M<GVI5%IT`!-8#A]>:WBH!QU@(3=Z,D-\36&A7F^C"B)D#25E$BAE%"MN%BUK
M&"]P'35U(3=U+T:&*3QU+D%T+3]R-$=_,$-V-$=\-4A]/U*(1UR70E6,466@
M1UB'56F@04]Y4V6635R&7FV6`!I<`!M<`!I;`1Q=`1I<`QQ>`QU>!1]@!1]?
M!R%B""-D"21E"2)A"B1F#2=G$"IJ$BMH%"YN&3)R&#!L'39U(3IY'S=Q&RU:
M)C]])SUW*T2"(C5D(3-A+T>&+TB&)CEH*#MK,DF%-4V*,$9]*CUM*SYO.E*.
M,$-U/E:2.$Z$-DI]0EF50EJ51EZ91EZ82F&;1EN0/4]\2%V215F,25Z34&>?
M3V6>3V:>3F2:46>>4&6<4&:<36*64&699'>I5FZ;C(5AKZB&J9E5OJMFZ,EE
MX,1KBH-L[K]9S*YGQJ]^NJ=\ZKE>RIM=BEA8W*&@____````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````.<U3&P````%B2T=$`(@%'4@````)<$A9
M<P```$@```!(`$;):SX```"^241!5`C78V#``D1D-7@5I,6Z='R#HA)R*QN`
M0L(S6/G89@J):P5$FF>4-;4!A;C863B8F;CY52)B<YS<6NJ!0O(",IQR@E)J
M828.DR=,\7`$"HDJJO,H6TE*F.JZ3ILTU=,>**1M4*=DK!FJ:F'9WC^]K\8.
M*-19FV+D[V=HEEJLW]/;K5<`%.K(BP[T"8E)+JQR\9KH;I,%%"J)"_8&N:BB
MH=G9UCH['2B4&.X3&!F?6=[86EU:E)^6A,T[`)5%,/3,@X8$`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]S;RYP;F<`````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`S-B`Q,#4Q-30S,S<T-R`P,C,P
M-34`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#_
M___-TM<G;:LJ;JLM<*PN<*LO<:PQ=;(P<JTP<:PR=*\S=*XT=*TU=*TX=Z\Z
M>[4G47<]?K@]>K%#A+XN67]"?K1)B,%-C,5(@[@Z9Y$W8HA.B+Q6E,Q/B+Q+
M@K-`;YE#<IQ:F-!7E,H_:I))>:1@G]=>G--+>Z=?G--7C\%-?JI/@*QEHMA1
M@JY=E,97B[E3A+%HI=Q>E<99C;M8B[EHI-IKI]UOJ^)>DL!NJM]OJM]FG,QC
ME\59A[!:A[!UKN)NI-1MHM)KH,]VK^-WK^)SJMMQI]=WK^%VK-YVK=YVK-UF
ME+YTJ-=ZKMQGDKE[KMQYJ-*)NN:&M>"+N^=TFKR5P>F3N]^&I\6=O]Z8KL*M
MPM6SR-NYSN$G;:HK;ZL<1FLR<ZPS=*TY?;DW>+%(BL1#?K)/D,E(@[='@+)'
M=Z%6C\!2A;%(=9Q6B;94A[-1?J5FG,MRK>%QK.!FG,ISKN)JH,]UK^)VL.-F
MF,1WL.)VK^!WK^!TJ==[LN*`L^"`M."&N.1_H+R)J,.WT^O"R,WAX>'6UM;_
M__\`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!`
MK(S)`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+=)1$%4
M"-=C8,`"$A*D[4("C,42V;B%)#2MJT!"H@7!#3892?&<`N)*YA5>0"'!W,!&
M)QF>3'D.$5DSAQI'H)"*3Y"O5EI<4W.RLFZ1A[LM4,@^Q$]?S#^JE2DFO-C5
MK=``*!1<;R/)RQ+:WA9I5.Y=9I(#%&ITDN-G9XZ(CFVQJ':TS-<&"M5F"W.Q
MIE2FJX75N=OFZ60!A2`N2E6W*G4K,=5350`*9?"Q@5WDXNEL8JBA*(7-.P#,
MH"E;_`J4(P````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V9L86=S+W1G+G!N9P``````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`R,#(U(#$P-3$U-#,S-S0W(#`R,S`T-``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$@``
M``P(`P```%C,'8X```,`4$Q410```/___\P'"\\6&(L3%-(C)=@I*MTR,^=%
M1L<\/N%04O9;7/9?8/IS=.QP<?^$A@!M``!K``-O`P5X!05O!0EQ"0U_#0UX
M#1!Y$!A_&!V('1V%'1^!'R&((1MF&R)P(R^8+R^5+S6<-2IY*C68-3"%,#""
M,#:--D*G0D*D0D:F1D:@1D^P3T:=1D^M3U"M4%"L4%"J4!%]$".+(36+-#:+
M-4BJ1D.;0E&O4$^I3EYZ.C=5!&VH#'6N$(*Y()+(,JK<4JC84VJC`S92`FRE
M!J+5176F`WFJ"'>H"8.T$X.P&Y'`)'.6(WVA*J'/.(>K,)K#.X^U-Z[;29_'
M1+3>4Z[74*/+'96Z!:7'&;/7,)>R+Z"\-<+D0JO)/LOL4;[=3<KI59N\#+/4
M*L/B/K700L[L3L;A4,_L5:6W#L?,",;,"LS1#LK/&=C=->WQ5LS,",W-"=34
M$=O;&][>'^CH+>OK,KFY*\3$,O7U0/CX1,_/.>#@1/[^4/__4^[N3_+R4OW]
M5_O[5Y2+(Z6+",&>"+^=",*A$\VO+>+&3?39:<ZD%'\``'\#`\P'!\T.#G\*
M"M0B(J<A(90I*>=$0YTN+L9!0?I?7_]K:_AJ:M1R<O>7E[)Y>+N&A?&RLO_=
MW?WIZ>GIZ?___P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````C5U/@````!8DM'1`"(!1U(````"7!(
M67,```!(````2`!&R6L^````KDE$0508TVW!L4T#01`%T)G9?^OUB9",@`J0
M`U=`1C_878`(Z8("2&C`@8D)D)"0G%E.0,?>_$\!\)[9'VYW6GIL5N\]"X9%
M'5YAI33>YLUSC<F]=C?8]A%RMK5[!(!\@=V3FG(ZC-^C1XCFMJS)GM?[2S^>
MAS-WL`=F4D_E4-L7^DR#G21)5Q>E1(C4&^Q3HF(\`Z!9*8-]_)`>41!.DC+8
M;NHQH+:AS.V4L^P?OU+45/PPU8[I`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<W(N<&YG````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$V,C8@,3`U,34T,S,W-#<@,#(S
M,#8T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````)````#@@#````RDK&F@```P!03%1%``#_
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M<SZ5V@````)T4DY3_P#EMS!*`````6)+1T3_I0?RQ0````EP2%ES````2```
M`$@`1LEK/@```"%)1$%4&%=C9``"1C@!)B$L!`UB,B'8I`(DO0B3T6P#$P`%
MD``3=[\OO@````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O=&@N<&YG````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P,S<@,3`U,34T,S,W
M-#<@,#(S,#4P`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!0
M3%1%````____-2BG23R[34*M9EO&?W3>BH#AAWW<>'"Y@7J^IZ#CAH"VG9?0
MK:?BKZGB)1>D)!>C+1^J+!^D+2"E+B&G+B&E+B*E,".G,"2H,"2E,R:J.BVV
M.BVO.R^Q/S*U.R^K0#6N3#_$1CJT2S^^4$/#2#VR13RD/C:.6D[*7E+254J[
M75+,54NY8E;15DRT4DFM75+`64^V;&#;9%G+:V#79EO,;F+985?!;F/9<6;<
M95O%65"L:F#*=FO=<F?5<&72=FO<=FO895RY<VG2>6_6@'?<B'[B>'&Y?7:^
MB('(EY#6?'>LE8_,CHG!LZWMMK#MT,[RR<?GV=?YU]7VW-KXJ*;-I:/(<&^'
MRLGDH:#'H)_&L[+8P<#ELK'3RLGIE)2MSL[)S<W(S,S'?W]\^?GTX>'<UM;1
ME)21___[^OKV[N[JY^?CU-30N[NX]_?T?"03>R,3Q3D?R3TDQ3TDT4@OS$PU
MW5<_F#XMZVE2VV=2]GEBQV-0R&52P6)0^8%KR&=6T&Y<\(-OVWMJT'=FI%Y2
M^9.`KFA;Z8QZNG%DQGILT(-T]9N*Y96&^J24]*&2_O[^_/S\]O;V\O+RY>7E
MY.3DX>'AV-C8TM+2T-#0S,S,Q\?'O+R\L+"P____````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````0;=Q&0````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX`
M``"X241!5!C3;<Z]#@%1$(;AF=DY>W;CIZ$142BV5FBH7(P;<`MNPO4HE`J-
MJ"5$A)5(K,7.F>/T/.7[-1_`#X09VCB1EZ@B!3QG>+`KKX0%:NR-]P(A)7=Q
M]3=[J?!"6`MITV5W*DIG.4[KUA^`H+W2_/D1$QF;6JW*D-:39;$7PT>36M02
M(0)JVGOLU+0,X_NQ;>0$:><T?(U'@W/6V^[Z219^+8C`:^##J0AQRG`302;#
MA)7ZL,$?7QZP3<#":<+;`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]U82YP;F<`````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,C`R,B`Q,#4Q-30S,S<T-R`P,C,P,S0`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!(````,"`,```!8S!V.```#`%!,5$4```#___]`J\Q!J\Q"J\Q$K<Y&
ML-%&K]!%K,Q(K<U+L]1.MM9+K\Y0N-A2NMM-L,\T=HM8OMY4M-([?Y1<P>%@
MQ>1BR.A:M]1$B)UHS.M*D:=EP-QQT_)TUO55G+)ZVOANQN%>I;MQQ=]VS.>"
MX/Z!W_QGL,>&XO^&X?V`U_*(X_^(XOZ&WOERO=2(X/N"UO&*W/:0X?J'TNF6
MY?^5Y/V9Y_\I:W]#K<U#K,Q@O-AMT.Y]W?I^U.Y]TNR4X/='K<),L<9+KL-6
MNL]9MLEEQMMWU>EKNLMSQ]F&X?1[S-UKL<"-Y/:(W.Z.WNZ>Z/B\PQ>^Q1F]
MQ![&S2/1V#+&S33?YD2^Q$'(SD?L\E;:WU+=XUCQ]V+L\6+M\V_L\77,Q@#-
MR`',QP'.QP/,Q@/0R@7,Q@71RP?-QPG4S@K6SPW.R0W8TA#/R1+;U13>V1C2
MS1CAVQWDWB'4SQ_HXB:GHAOKYBO8TR>PJR'NZ"^RKB.YM2;=UR^\MRCR[#6_
MNBK$P"W!OBS'PR[U[SK*Q3#-R3'AW#C5T#72S33/RC/X\S[Z]$+:UCK@VS[\
M]T;EX$+^^$KJY4;_^DWNZDGLZ$C_^4_^^5#R[4S]^%'V\4[[]U'Y\U#Q[%#]
M^&3___\`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````"#RVVG`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```*M)1$%4&!EMR+$2P4`0`-#=W-WN
MD4D44J#7&I72__^`D@*%,0Q#)+G+;<[UO/(!_$#8P+&<],]7$Q19'M%.`^S+
MV?O=M@$U+_&!H.!33$,^.J_F-^;&T^2(L)A2N-5UU-8R:W0'#6L=?34,F&6H
M%(JDJF+H)0UF:0:)H&';GNHV6N+*6N=<@`SBI7$#&5,0B9?>I[K6+ABCQSEA
MUSN15/?.*V.X8--U05+]\07'0%!*KH@A=0````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W1N+G!N9P``
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#0V(#$P-3$U-#,S
M-S0W(#`R,S`U-@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`
M4$Q410```/___\S'R,`@`,`A`+\A`'@5`,(C`[\C`\,E!<,F!<$D!<`E!<$H
M"<HM#<(L#80?"LPO$,PP$,0Q$L<U&,8V&(PF$=4\'=A!(<H]'Y4O&9\Q&\U$
M)Z<W(:HZ(^-.+^).+Y\W(;`^)M)++[-`*.93-;9"*KY'+KM&+;A$+,%),*E`
M*L-+,==3.-=4.,M/-<E.-,5,,^Q</LM/-N]@0M!4.K-(,O%D1MQ;0-99/O-G
M2MM<0KY1.[Y2._1I3>!@1M]@1N1D2>)B2/1K3_5M4.AG3.MI3O)M4>]K4/%M
M4>AK4.=J4,M=1NUQ5^QQ5_!W7N!P6?1]9/-\9.]]9>Y]9?:":O'=V<$F",4D
M"<DK#<$J#<(M$-(X'<<X'<D[(-](*\Y#*^93-]=2..]>0MQ:0?%D2>)A2/5J
M3_)H3NAE3/-J4.MG3NYI4/-K4_5O5?5_:/JKGLNTL+\;`<$<`]@Z(<DV'])$
M+^E1.O-F4/!F4<=I6]9\;LMZ;L]_<LI\<..3AOFHG.*?EMZ<D^RPJ-2AFMRH
MH<V>E\VRKOKDX<A^==6,@\J&?<J+A//2SM&VL\NTL>;&P\RWM>O5T]31T?CX
M^-O;V____P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````##BI%`````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^
M````OTE$050(UV-@P`+8V*1L0WUU1;A9.84D5,U=0$)B9B'^*:71X<61X@HF
MSAY`(0'M@*"TA+K"]MJ8>",[3T>@D*)/OG=9#5-/W]3Z<BMW5TN@D$VH7U+L
MQ,ZVKL:PC"PW:P.@4+"_15Q4?W=+4W-'7HZ#L190*-!)AK^H:G+KI"D%E8ZF
M.II`(2]E80[FB.H)O0VYF9:&&DI`(3U1'E8NP9+$U(IL:P-U%5F@D"0O"SN?
MN'QRNH>]OI::G#0V[P``H_DMRGH$U]X`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O<WDN<&YG````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#$V-34@,3`U,34T,S,W-#<@,#(S,#<U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````6````#0@#````FGMN40```P!03%1%`````/\`0D)"A/^$C/^,I?^E
MK?^MO?^]QO_&SLYSSL[.SO_.UM;6UO_6W@``WM[>Y__G[P``[__O]P``]\;&
M]_?W]__W_P``_\[.____________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M________________________________________9A=)0`````EP2%ES````
M2````$@`1LEK/@```%-)1$%4&--C$,0"^)@8Q+$`8082A27`@!.%$F%@D`0"
M`5X6#C$0Q<PK!.)+0H0E61DY0!0;(SN8*PI5S2T$4BW$`810U3Q<//P\(,`/
MI[FX&&@)`'JD#IX"_6\,`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O=&\N<&YG````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#$R,S8@,3`U,34T,S,W-#<@,#(S,#4W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````2````#`@#````6,P=C@```8!03%1%````____Q\/$IZ2E
MX=[?QL?'Q@X`Q@\`QA``QA$`QQ$!QQ(!QA$!QA("QQ,#QA,#R14%QA4%RQ<'
MQQ@)S1D*S1H*T!P-T!T-SQT-QAL-TB`0R2$2U204V"<8V"@8S2<8S"88VRP=
MWC`ASRX?HR8;XC4FX34FY3HKJRPAZ#XOKBXCM3(FUSTOMS,H[$,U[$0UNC4J
MTSTPO3@LPSHNP#DM[T@Z[TDZR#XQQ3PPQ3TPSD$TS4$TRC\S\DP^\DT^W$8X
MT$(UT$(V]%%"U4<Z]U5&]E5&VTL^X$]"^%A*Y5-&Y%)&^5M-Z59)Z5=)^5Q/
M^5U/XE1(^5Y0\5M.[5A,[5E,^%]1]%U0]%Y0]E]1[%U0\6A=T6MC?DM']K^Z
MW<G'^N3BQ@T!QA`#R!<-R!H-R28:SRL?TS$GR#$FD",;K3,KW$,XB2THT$E`
MYU%(N$M#?30OY&-;^&QDXVQC]X=_](9^^I&+_)J3_^SKG%A5_M#.]<G'TK:U
M[-+1\>[N?W]_____4Q]*5`````%B2T=$`(@%'4@````)<$A9<P```$@```!(
M`$;):SX```"W241!5`C78V#``NKR*UC+H[+D!3D$I)3T7`*!0C$9>;'Q`:G"
M''SBBII._N%`H>S,@M(:PV0>+A%9=5OO"%^@$'-T66U<2B*GD(RJF4=HL!M0
MB*FRBJ5:D@UHD+Y+8)"[-5"HI+@H)YV73PQD4)B7HR50J#`W+2F!6U1.W<X[
MPL?9W`@H%*DCS0\T2,W4(S3$S<9$&RADKR#(#G*1*]`@*V-=#:"0,M!%$D"#
M_,(\'2P,M%2P>0<`HJ$E=SYYUW0`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O='`N<&YG````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P-#0@,3`U,34T,S,W-#<@,#(S,#4V
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____
MES<\BW^`>FIM1CU!HIZ@K*JK14!#U=35?'I^`#NE`3RF`3NE`SVG!4"I!3^F
M"4&G"D.M#4:O#42L$$JR&%&X&$ZN'56[(5J_'U2T*V+&+V;*-6O-.&K#/G/4
M0G?71GO938#<27C.3X'=4(/=4(#848+:16ZW7(/(*UBEEZG&E*7!F:K&I+70
MBIBNLL+=P='KS=STQ-+IS-STL\'6O;^^]OGWY>CF`'0``'(``W0#!7@%!78%
M"78)"&<("&8(#7T-$'X0&((8'8H=&'`8(8LA'X0?&VD;(G,C(6XA+YHO*'DH
M-9PU*GTJ+H(N,(8P.)@X-I$W-(HT0JE"-88U1JI&0IM"1J%&1I]'3[%/4*]0
M4*Y03JE./X(_6:Y93I5.5:!5:+IH:+1H;KUNU=C5^OSZ\_7SK:^MZNOJT]33
M)8$D-HXU1XM&6J-9V=O8R<K(TH]?NFL^CHR+0"`4DD0P>F%;B2T:MHN".C4T
MI%5(LWAMJ75K;SXW7UA7KE-.S65@T'-P>1033Q(26AT=VW%P8UI:0ST]E(V-
M5%!0<V]OCXN+M+*RL*^O_O[^_/S\^OKZ^?GY]O;V\O+R[N[NZNKJY>7EY.3D
MX>'AV-C8UM;6TM+2T-#0SL[.S,S,RLK*____````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````-3C6
MHP````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"]241!5!C3
M;<&_2H)A%`?@W_GS9J(6!)9#]R!T9:$.+8%#FT,1W4A+EQ"DDTN"+D%+0Z!\
MH/%][WG/Z0+J>8`_").3Z4W]LJ_KK$>JJAO&Z?ZZ\Q#69%$1$0*#/(RX,5(1
M82D@W+(E?S8B8A(G7BC:E1X>[\Z\N%FHI@5C>M]]*A0>I8Q$Q@K"+,*K+:>W
M82ROK/,Z%UQ^O*\_!U_U1>#\^"?UEHI=U9BL-+<3-SO[=C`.N7#BU%+*_1+%
M\8]?WGE2VL"6W5H`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]U9RYP;F<`````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,C`S-B`Q,#4Q-30S,S<T-R`P,C,P-#<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!(````,
M"`,```!8S!V.```#`%!,5$4```#____'G)Z]@(/)P,BMIZVVLK:XN[XL,"Q.
M4TU25U$[/SI*3DE)34AE:&0#"`$/$PTI+2<S-S&RLZY454YA8EJPL@!E9@"P
ML@.DI@.UMP>MKPVUMQ*ZO!1Y>A&OL1_6V#&DIB;'R2_$QB^OL2W;WCRYNS/)
MRSZ@H3+BY$K;W4SEYU':W5#6V%#:VU[:VV7,S`"CI``$!``"`@#-S`',S`'0
MT`7,S`74U`JEI@G.S@W8V!"+BPK>WAC2TACDY"&YNAWKZRO8V">PL"&\O"CR
M\C7'QRZRLBKAX3C2TC3X^#[\_$;EY4+__TWN[DGL[$C5UD+^_E#V]D[[^U'%
MQD';W$_IZ5G]_60)"044%!`<'!@E)2$<'!E*2D8[.S@X.#545%!:6E<]/3MM
M;6JLJ:.]G%_0G67$9B>C4B'6;B_N?CK;>3[XC$KLB4SWD%'LBU#/>D;#1P#$
M2@/$30G,4PW)4Q+471G781W-8!^A3!OA:R;E<B^L52.X7BK#9C#-;37R@D+B
M?T;WC$_QBU#YGFB^(@W#+AC433G&2#7N74?85D.\3#OI8T[Q9E'I:U?S?&KA
M1#7<;V0\(R%),S%/.3=;1$)@24=K4E!K4U%W85]]:&8H"PDH#0M<0D**='3_
M__\`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````"F+!C5`````6)+1T0`B`4=2`````EP2%ES
M````2````$@`1LEK/@```+=)1$%4&!EECST.`5$41N]][[Z',$:A4.@D$HE"
MHK4)"YL]6(+HM38@&HU")'X:(9@Q\^['U'/*4YSD$%5@FM+(LX9"]T,VHG9A
M2;/;]11MPN5\]+L.ME>F63/F])GF$"<-Z_.5T+C>O7U;#^6.W(V!DM!`T`,2
MBP2Q0$L5HY`&.VB$&JN"F-H0@+S.ER\VJ+U3IO$G*U2L=6(0H.$@U']GF7?B
MO>=O"(J_FN3*QHHS90@(Z\H.T0^YV%B9]]A__@````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W1R+G!N9P``````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#,R(#$P-3$U-#,S-S0W(#`R,S`U
M-0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/__
M_]`U-L,Z._J[O/'V]N+GYL@``,<``,<!`,8``'T``'P``,@!`<<!`<D#`\@#
M`\8$!,L%!<H%!<@%!<<%!<P'!\@)"<<)"<X*"M$-#=`-#<D-#8@*"M,0$-84
M%,H6%MD8&-@8&,X8&,T8&)`1$<89&=P='=L='>`A(=\A(=`@'\\?'YH9&:0;
M&^(F)L@E)>4K*\@G)ZPA(>HO+^DO+Z\C(Z0A(<PK*[8F)M@P+[@H*.TU->PU
M-;LJ*KXL+,,N+L`M+<<P,*XJ*N\Z.LDR,<8P,,HR,MTX.-$V-<XT-,LS,_,^
M/O9"0O5"0M4Z.K@R,OA&1O=&1MP_/ML_/N)!0>%"0OE*2N9&1L,[._I-3>5&
M1M-!0>I)2?M/3_I/3_M04/I04.Y,3/%.3OA14?=14?504/104/914>U04.A/
M3]!)2?)75_5>7N596?ED9,I14=!45/1E9<=24O-E9?MJ:L975_6`@/N'A_B)
MB>B#@\=P<,]Z>MV8F-B6EM.CH\F^ONWHZ/___P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````$4/
M0!T````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````LTE$050(
MUV-@P`*X>70C2W,\E$4XA.0T;0(3@$(\J@$EN:$ZXAP"TNJF?O%I0"%9Y[S*
MJA@9/EY))4.?J-18H)!Y-DMC78$@IYB\ODMX2E(P4(BY@K56153-74[+-B@Q
M.<P+*%14SE8CP6%4J`$T*#V:R0THE)]5WU!L(*D(-"@CUM_5'BB4::505FT!
M,2C$V]$2*.2A(LHE##/(P=H8**0MSLXOI6[B&Y<6X>ED9Z:'S3L`I_\H.2)U
MF$H`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M9FQA9W,O='0N<&YG````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#(P-3`@,3`U,34T,S,W-#<@,#(S,#4W`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````2````
M#`@#````6,P=C@```P!03%1%````____04%"`0(#*BPM<W=YBXV.$!,4L;2U
M3%-5$Q<8>W^`*B\P4%E;C)67>'U^=WU^55Q=/45&9F]P+S(RDIB835!0.CL[
M-#4UG9^?;6YN-C8UDY.2JZJI<6]NPB(`P"$`OR$`PB,#P2,#OR,#QB8%PR8%
MPB4%P"4%P2@)RBT-R2T-PBP-SC$0S#$0Q#$2T3<8QC88U3P=VT$ARST?S40G
MWTHKXTXOXDXOGS<AL#TFTDLOZ50UN$0LZ5<ZP4DPPTHQV%0XR4XT[%P^RT\V
M[V!"\V1&W%M`UED^\V=*VUQ"OU$[]&E-Y&1)XF)(]VU0]&M/Z&=,\VQ0ZVE.
M\FU1[VM0\6U1Z&M0\'=>]'UD\'UE]H)JOQ\!QR(&?18$Q"0'A!T*QRL1USTA
MR#D@O4(M[UQ"K44SWU]&RUM&^G!9ZVU7S6=4S695IU]3\HY]SX1WPWUP[IN-
MX9*%O'IO>4](_["BW)^4SI6+^+RQCFQF[+NRWK2LP1@`R"0*RS`8U#@?ZU$Y
MTDTZ\UU&W5I%\&50^G]LVWUOQ)&)[[VUWCLFJ3`AE9&1<W%Q965E7EY>45%1
M3DY.34U-2DI*2$A(0D)"/CX^,#`P*RLK)R<G'1T=&1D9$A(2#0T-!04%`P,#
M____````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````VQV$PP````%B2T=$`(@%'4@````)<$A9
M<P```$@```!(`$;):SX```#!241!5`C78V#``DIX9HE+R1;5J<NKZAK;N/D#
MA>(J!7O[F-BR:Y2UC2Q<`T*!0@EIU:*39[#+Y=0:F#G[A/D"A2PS6JN$9\]C
M9FWKM/,,"?0`"GE'9S6W"S',Y>K.:PH*]G(""D5%N"<G%G#.F2DB6=J2[F(/
M%(KT,]6)B2WGG3YU(D=AHX,M4"C<6E]%(;Z^3&!2OYA,?HH54,C14$-132^I
MH8)OPA0)[N(NH)")IH*2EI%Y:F8'O_0TEIY<;-X!`.>O,6,#0I$<`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]U:RYP;F<`````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`U,"`Q,#4Q-30S,S<T-R`P,C,P
M-#<`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#_
M__^\8F.Z8F2Y<G/LEICRNKNN*S"O+S.Q.C^X1TO69&CA;7'E<WC@<'79@X:M
M;&["DI3<J*K2IZG)J:KYV]SUV]RG*#"G+C:H/$.^14VO04BY1DZQ0TJP1DML
M*R_`3E7$4UK16V+47671767.6V.32D_7<7C==GW3<7;*?8'FG:'.HJ7FQ<?(
MN+F:#AB<$1R;$1N>$QV<$QV=%R&E&R6H'RFC(RR?(BNF)S&Q*S6U+SFH+#7`
M/$:S.4+$14[.3UC05%W`3U>G14S#4EK47&718VO6:G+!H*/NR<SCPL7$IZKJ
MRLV=2E:67&7$>H9R0$FPF)W-L[CKT]B=8W&H<'Z7@H?`J[#`I:RVGZ75N\+:
MP,?FS-/&L[CLV-Y^6'":@)&/;8:UH;%-3WNBH[12570=*7!&4(PI+DI78)ID
M:Y6IK+T%$UQH;Y"FK,BBJ<=18)5C;9"(D*XV1WU<;*%M=YF)D[0@-W8F/'IJ
M>ZYU@J80,'1.9IQ4;*%19Y9SA*EH=YB.G\33V>?I[/,-+G(.(TXK0W-UB[AQ
M?YR0DI9-9(RXO<9$6GZMN,J?J+?(TN*ML;::K;_1XO'!R]/D[_?GP\)Z4E+%
MC(RM@X/,I:7%H:'PSL[OT-#2P,#/OK[\Z>GTX^/___\`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````"/
MOZIN`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```,%)1$%4
M"-=C8,`"Y*=U=E1F%G%QY.949_FSS@<*900(+.@O*.5D+RQ/U&1K;@0*M?8D
M:4^=W"<AGA+*OV!2>PU0*"P\3E='9):%N;"0CUA,=!!0R%G#3<;26-_(S-K>
MT57521HHI.ZN8&-B:&!J9>N@K.(B*PD4"HZ*\/80G&DG-5O4TRLV,A`H5%LW
M48\Y)%M1J6G*'*V$KC:@4'WW=+GXBBINGOR2WGDL?JE`H;E,OLDM:65\O'GI
MQ0T39JAA\PX`D3DR\!,AFY\`````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V9L86=S+W1V+G!N9P``````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`R,#4P(#$P-3$U-#,S-S0W(#`R,S`V,0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$@``
M``P(`P```%C,'8X```,`4$Q410```/___[=^?\2)B[*9KZ&)HKFHO-K%WUU(
M8Y9]HHAJFKBIQL>UVV-9<7QCI;>LS\B]ZVYBM&]IFI2,X9*+W69BE$9%MCH[
MME]IRU^.N&:6O:;,ZZW.Z7.?NI>^UFR?O)K(XY*_V*'0['"DOWBKQI3(XIS/
MZ:;4[)#%W7:?L9K-Y*36[:G:\8^HM'2CMG6ALX_"UGNEMG6=K97!TZC9[:#.
MXJS<\:?7ZJ#.X:W=\6^HO&ZEN76NPW.LP'"GNW.IOG"EN7.IO7&FNG2JOGFO
MPW.GNGVSQWJOPWVRQ8"UR'FKOGROP82XRXN_TXO`TXJ_THB[SHB[S8_#UF>,
MFI+&V7"7IFZ5HY?*W)K-X(V[S)O-X*+4YI3!TJG9ZZ[=[ZO8Z:_=[J[;ZZC3
MXFZGNG"HNGBOP8&XRX"VR(*SQ(F]SH>XR)W1X[CB\'&JNHNVPZ?8YZ+0W:S<
MZH&HL8"EJ)"WN:_9W++<WZ'(RHNSM(JOJK#;S:K2Q;ODUZ;-P)"RIKSDTY:Y
MI[_FT,3EQ,7HPL3GO\/EO)NYD*G(G:+`EJ3"F<'@L*?#E,WJK]/OL.N%;.F.
M>)1D6>>MH+]0/=%E4/2";*M<3=YX9N^*>?BZK\-L7^R%=KJ'?\!,/8$S*7-*
M2O___P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````/P/<28````!8DM'1`"(!1U(````"7!(
M67,```!(````2`!&R6L^````P4E$050(UV-@P`(X>$5G"O#P2\BGV+OY:A7V
M`H7F39@]?<9$9B8]*_=`U?S&,J#0W*G]4_HFSYFD;^.C4=7<8PH4$F)CG\7-
MPB>FG&Z@UM*D9`P48A46F28HSLFEXA<5:Z9>7@(4DI&6TY65E,K+##>/BU?H
M;`,*Y11DV2;GIJ:%1"<D6K17&`*%DB*]'*R=/8.R=>J[%!N*C(!",=Y.UHX>
M_A$FEJ6U'96:84"A#%=K.Y>`<.V:UNKNNN+08&S>`0";T#'>70^=FP````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O=F$N<&YG````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P-#<@,3`U,34T,S,W-#<@,#(S
M,#0T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````
M____M)N=N*ZTTM'2JJFMP,#&T-#4XN+DS]+2LK.SJJNKX^7AA)9GN+ZKT-7&
MEZ!_MKRD?(=9BY=3GZEN>7UCLK>8QLJQQL?`QLN?VMZ\R\Z9T]6WR\RYS<W`
MV-C+_/SPT='(Z^OAX>'8TM+0[N[MU=74T,^1U,L?S+P`?W8`?W<`SKX#S;T)
MUL8-BX$*S+P0X=$=G9(9WL\GTL4E[M\OIYTAX=4XQ[P[QKL[^NY/\>90_?%D
M^.UES,N^S,N_]?3H__[SS+@`S+D`?W0`S;H!S+D!SKH#S+@#S+D#T+T%S+H%
MT;X'S;H)U,`*SKL-SKP-V,80S;P/S[T2S[X2V\<4T+\3S;T7TL$8E(@1UL4;
MY-$AU,,?U,0@V,<GW<POZ-@SLJ4JX=$XX=(XNZ\R\N)"Y]=`Y]=![-U(\>)0
MU,=&]N=7]NA7^NM>Z=M9_>YD__!H]^IE__%J__)JL:B"G9R;Z>CGTLO'H8^&
MLJJIL)B8[NOKR,7%_O[^_?W]_/S\^OKZ^?GY]O;V\O+RZNKJY>7EY.3DX.#@
MV-C8UM;6T-#0SL[.S,S,RLK*Q\?'Q,3$O[^_O+R\N;FYMK:VL+"PIZ>G____
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB8D6U@````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#`241!
M5`C78V#``K1=C"R+<Y)-['NZ.MJ:ZVN!0EJ1*86YZ3'A=MV=[64-C(U`(?W$
MO/R,.'\#.78)/@%^'E6@D%E6069\B$>0(INHD`BOL"Q0R*(H.RG"VRE,GH-3
ML$1,7`4H9)N;%NOK[!ZE+".M7L',.ADH9),1%^#FZF>L)"59SE19R@T4LHX/
M]G3V"4UPJ*VKKJKIGP04,H_P=O8*C$Y5J&UJ9>F;.`4HI*&KJ:-G:&KEV-BB
MUCN!:RHV[P``2'XOWL>-?B(`````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]F;&%G<R]T=RYP;F<`````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,3(Q,R`Q,#4Q-30S,S<T-R`P,C,P-C(`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!(`
M```,"`,```!8S!V.```!@%!,5$4```#____"`0/#`@3"!@C'"`G/$1/?'1[5
M-3;)0T;?:&JI!`FI!0NK"Q"V$!6T(B;?8&3JZ.FXK;<S$3@K##0Q%#J<CZ`\
M)$HF#3:LI[&-BI"0A)XT(DI30V=216*"=)0E$SXQ)S]>3W)N88!R:WQ&-UQ7
M2FL2!R4>##V!>)!!.%(4"R8;$2\L'DI`.4YM8H0R*4@/!R0E&$=94'`U*E5,
M0VN-AJ,;$D+U]?3,``#-`0',`0'.`P/,`P/0!07,!071!P?-"0G4"@K6#0W.
M#0W8$!#/$A+;%!3>&!C2&!CA'1WD(2'4(!_H)B:G&QOK*RO8)R>P(2'N+R^R
M(R.Y)B;=,"^\*"CR-36_*BK$+2W!+"S'+B[U.CK*,##-,C'A.#C5-C72-#3/
M,S/X/C[Z0D+:.CK@/S[\1D;E0D+^2DKJ1D;_34WN24GL2$C_3T_^4%#R3$S]
M45'V3D[[45'Y4%#Q4%#]9&3___\```````````````````````````````#=
M2G&G`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```*1)1$%4
M&%=MSKL-PC`4A>'KQ[T.(9%`R@Y,P"@P!<NP`6O10H-0H$GD9VSCH'1PRJ_X
M=0!^QF`GA38=W5Y[5-1LJC.'6O>=&7)*`E&U"H%#6.6K%"DS0MPJM"!!BF:(
M"B5';(FB+_1FTF<?`I/UFI@)A7IRE!+C;`[IRZ'0R=Q'DRM2<R@<IY+/#^T2
M+:$8?*'GZ";$;\@&%V.AE_7+(VNG6.C//HUM2*VM2%1F`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]T>BYP;F<`````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,C`T-2`Q,#4Q-30S,S<T-R`P,C,P-S$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!(````,"`,```!8S!V.```#`%!,5$4```#___^8B(^*?Y-W:H144(]>
M6Y!J9Z9N:Z9F9:IF9:<M+60S,VLU-6TY.7([.W0]/7<_/WE"0GU!07M$1(!'
M1X1&1H)*2HA)289;7*!45))D9:Q75Y9;6YIA8:-D9*525:9%1XA76:I14YM4
M5IY@8Z]@8ZY.3XT)3R%9DFPL:C]JG'DE8S=5C650AUX45B0I53,2/!LC8#`9
M1"(A3"I+@59#<4U/?EEGFW)QHGMNGGARHWUSHWT(,1`R7SM#>DX[:$1AE&MB
MD6MMGW<_=D8?(!\F71E:ADP[:2.,K753;!.+G$YS?"`:&AAM:@QS;P^GH%"'
M?B!W80>1>B(,"@-R6`4M)Q2MF%&)=T9V6`U50A"8>2IX82>FBT1D5"NXG%2#
M=5%8/0).-P55/Q"IA36SE$_&IV2LDEEA6DH\."]:5U`P(@DR)0U)/R\;$`"8
M>4FVG7P6$@VCBFRHDGD2#@I/3DT[.3@"```B(2%04%!/3T]&1D9"0D(^/CXZ
M.CHU-34O+R\K*RLF)B8A(2$='1T8&!@4%!02$A(0$!`-#0T*"@H)"0D'!P<%
M!04#`P,!`0'___\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````#[?*-R`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```+Y)1$%4"-=C8,`";&U-S&P<[8TT
MW/R3*^JK*T%"Q@Y6%J8Z^EY!.2T--5590"%#.R=G/2T/O\22UL;:TH1TH)"!
MN:6NBT]H7D];4UU&?#$;4,C,6M,],*F\MZ.Y/B*-65D1**1MX1V<S=#7V9(9
M6\"A(BX"%/(,B"GL[^_RC4ME4I-4%Q,$"H7GMO<Q](1%%[&KRDF)"O,!A<I:
M>QEZHU)8E*3E922$^'F`0J[=#"&1^:P*G%RRXB("O-S8O`,`XIHMEL0;DN<`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W9E+G!N9P``
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#$V(#$P-3$U-#,S
M-S0W(#`R,S`T-``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`
M4$Q410```/___\,Q0JP!%ZX%&;()';,4)[T6*LLG.Z,G-JXN/=DZ3K@T1,A`
M4.-,7M=-7N-29-E28A(:FALCG#(ZN3$WFD-+QDU4PDY5P5A?T@P5F0\8GA@B
MJ!\HJBTUJCA#O$90TS<^I#M$IS]'L$Y9T&EPU6AOTPT;IQ<EI1TKM!\LJR`N
MJBHXM#`]IS0_KS9#L452S$)-P493Q%!<UU!<T5=BTEYJUFITW69QU@@9H1,B
ME!8EE1HKI1LIF1PKFR$PJ"0SI#)$Q"X^L"DT@4%0PT%/P#I'JT54P$A5LE5C
MRV%OW%9CPUMIS%MGQ%->K':!TR,UJ&%QV<;($\S,`,[.`]#0!<S,!<W-"<'!
M"K^_"M;6#=C8$,+#%M+2&.'A'8."$>3D(=34']+3(>[N+_+R-<[.+]_@-.'A
M./KZ0OS\1N?G0>WM1O__3_[^4/GY4+2S._7U5>/D4/;V5^3D4?'R6?KZ7O__
M:O#O;&MG`&AF`-;298B!,%];,+JR83X]-$0R$\P``,X#`]`%!<P%!<T)"=8-
M#=@0$-(8&.$='>0A(=0@'Z<;&[`A(>XO+[(C([PH*/(U-;\J*L<N+LHP,.$X
M.-4V-=(T-/I"0OQ&1N5"0NI&1O]/3_Y04/9.3OE04%Y>7O___P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(@(LNP````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^
M````ITE$05085V6/RP[!4!1%]WG<5H(&$7,1?VCB._@^(R*(9U&M>^[!V-JS
M-=E9P!^$>69E'A_/VC@+&G3!<)^T_=4T1D%$A<#8VLKB^\TAM7X$*-9G2G5E
M)'P)+&X0D-]6^UB<7L5QXYOFME.,4N\Q&.XBV[C>%^8@3,OL3CEQQ=*]=M+]
M0.A?-3DSB;"G[RK"LHS&*GE+*5HTFS&>]GO37/@KW/T_!_@`G'Q82;+:Z>H`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O=F<N<&YG````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#(P-3`@,3`U,34T,S,W-#<@,#(S,#0T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````2````#`@#````6,P=C@```P!03%1%````____W*"BO51;G%%6U7-X
MUGR!BE=:R*:HIS0]W'-\R&AOKV)IUWR#Z*>LL(*&J#M'<"<OVW^(NHB0SJ^T
M94)*J'V'9$1,M9F@GVIXG6%RG&]^NIVPS;3%E7J-95IBLJ*QO++(+R-8D8JP
M6U9]0#QO>'>(+#!G/4-U)S)P.45]-$2$0E*43%R?;GJK`!-<'3)Z&2II+T2-
M*CMX/E&9.$B#46.D:WFK`QIB"B%M#21K%"IT&"US(3>`(35T+T2)0E62.TIY
M/$MY7F^G9':M`!E@`!I@`1IA`QUC!1]F!R%G"2)E"B)I"B-H$"EP$2EM&#!P
M'39Z(3I^(3I]&RU>)C^")SU[*T.%(3-E)CEL*#MN-4V/,$:"*SYT-4V.*CUP
M+4!V+D%W,$1Z.E*3-DJ!0EB:0EJ:2F&?1EN315F125Z82%V73V6B3F.>4&6@
M4&6=5&BC4EQW`!MB`!MA`1UB`QUB!2!G!1]D#2=K$"IO$BML%"YS'S=U(C5G
M+TB),$1Y-$F`.$Z(1EZ=1EZ</U2+3V:B4&>C4&>B4&:?&SEM9G*'*T=V3V:,
M8WJ@-EN!7(=^@XV(9HQM;Y1Q3(I*99]9;(AE:W-IIL^.A;9DC,!J@;Y5?+90
MK,V*K--^E+AE@8Q;____````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````3]Z],0````%B2T=$`(@%
M'4@````)<$A9<P```$@```!(`$;):SX```#!241!5`C78V#``L3E"WD4941Z
M?5T]_8*BF]N`0J+L_$)\3,*2ZA85!O:IK1U`(4$6-BY69@%.)<O.R5/ZS;*`
M0FH<LKP*$M(:_M;=L^=.TFT!"HDIFW.KV,E):=KVS9@S4:<!**3GG*EJJ%^F
M96S4,W/Z5--ZH)!+=IB5>XF/3;C)A'FSYCO%`H7R8ZI*B[RJ0Y/3"[JF.29$
M`H4:`\K=RBN#XYK:<QVT$Z,B@$(UWL4>%8%U:3EY&2E)\;4AV+P#`!8Q,I^#
M$I\L`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]U<RYP;F<`
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`S-2`Q,#4Q-30S
M,S<T-R`P,C,P-C(`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#
M`%!,5$4```#____!86/&9VC%:VW/<G3<@8/3@8*P;&WJD9/&?7[6C(WSH*'S
MHZ3#35*^6E[`8F6N863NBHW1>G[6@83HFIRZ25"[4E>]5%FV45C&76+!8&72
M;'&B5US@?(&Y:F[NDYCFCI/"<WFW:'"]@HC2IZY<4ZDG'H0Q*(I=5JIB79PF
M(F-+1I]W<L&+ALT=&E@V,I533YED8;=O;+Z`?<V!?LF)AM`4$U<:&%@@'VDR
M,'0V-7U*2:=&19!;6J=L:\%S<KU_?L\]/89Q<LAF9Z-Q>KBEK-^HK^!@:ZZ,
ME<O+:&+,:&/,;FC6@'OKFY;'@X'[L*W#,S/%-C;(.SK-/S_83D[)34S+45'F
M7U_575WR<'#/8F+B;6WW>WOR>GK8<'#O?W_-;V_F@(#;>GKXC(SMB8G6>WO+
M=G7XD)##<G'.>7GRD)#0?7WCBXOWFIGREY>[=77=C(R[=W?'@'_PFYO4BXK%
M@H+JG9SXIJ;,B8G%A83#@X/IG9WHG9W,BXOTIZ?$AX;,C8WUJJK6E97?G)SX
ML+#OJJK7FYKCI*3,E93'D9'&D9&@=77*E96L?W_QL[/EJJK0G)O$DI*XB8G3
MGI[-G)ORN;CXO;WHL;'UO;SBKZ[?K*SVP,#QO+SLN[OWR,?ZR\O___\`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````I`.5Q`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK
M/@```+9)1$%4&--ES[UQPD`0!M!O?^Y6AR0&AC$DSAVZ%U=``00$C"-7XU*<
MN@H/$9$9T$A@Z?9<`*^#!SP@O"8^-\-M=R<V$Z*MHB*IV_/IRXE)6`B*;N/W
MW[B>7F06K.+RJ5A,$E)_L1\65<T.12]UGTN[#"'60OX'Q;K(LTS?G4H:R'.!
M(GD1M[=@IN8W+P`^3!<L(::F?:IG^PJ$535Q8>9N3M=YOC1'Q?LP%HLI1LIC
MIM$/CQ_\`Z$#/+[_Q!!X`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+W9I+G!N9P``````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`R,#4P(#$P-3$U-#,S-S0W(#`R,S`T-@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$@````P(`P```%C,'8X```,`4$Q410```/___\=,3[YC9L947EXI
M/FXX5V@P57@^:<_.S^/CY.#@X<;&QQ0B<`$56P<=9P4?9=C@ZJ*ZU-+:XY;"
M[9NCJUBAXGBY\Z7.]:&^V+O:^(*4I+G.XKW'T&RGV':LVV64NVN;PX>]ZH^E
MM]/F]K/"S^3J[V65NW>MT;_,U<?*R\K1T\O,S+*SL[;2T6^`?Z7*M]/;U^+H
MY>7QZ;+"MJO4LB:2,TVF40"7`!:3%A^.(-35U(VOBW&H7ZC)G<;,Q)J[@HNT
M;*?`=+[,FN/ITJFNEI"H+)^N/;:]A^;OB>'FE.WQK9>>$Y^E+N;M1KS!/ZRR
M/?;XO,3&E\+$`(2&$=39-?#T4.OM3>KL3[W`0,/&3JNL1M?86NOM9.7H9'1U
M.N+C=>KM?-_@=^OLBM36A/+TG,?(@.?IE];7D?#QL>_PP;.T!>3E*]#1+_7U
M0.[O/O+Q3./D2-W=7L'!AGIZ9.'AP_7UVM;6R?'QZ<[.Q_'Q[9R<F=W=W/7R
M7*BG<WIY5+ZO*KVQ0;&H7>[MX^;5C=+1S;Z:1(N*B=2H@;%>&=)@3\I64_;V
M]O'Q\>'AX=C8V-;6UM34U-+2TM#0T,_/S\[.SLW-S<S,S,K*RL?'Q\3$Q+^_
MO[R\O+FYN;"PL*>GI____P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````,`,WT,````!8DM'1`"(
M!1U(````"7!(67,```!(````2`!&R6L^````P4E$050(UV-@P`+J2ZIY&'NX
M@XIU)O=S594%`H7B0Z+3,TLG1@97EF<DQ44D`H7:ZV)B"Z-$?7U</7+RPY.;
M@4+20BY%N0$"?/R\^GD%7FJ20"$%"5-;_VQ6=C:.IC`#$6%%H)"2E)V535HG
M4W=7B[&8G*PZ4$A%T-[2S+V!F:6C5D]>4TL9*-1;PVENX9;2V.;I[:0]9=9<
MH%#?I.DFC@[.H7X)XAJM,^?,`PI93YL^=8*A459JA8SJC-FZ\[%Y!P#[]C)(
M#S4BA`````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O=FXN<&YG
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P-#,@,3`U,34T
M,S,W-#<@,#(S,#4U`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@``
M`P!03%1%````____T#4VPSH[^F=HT-8-V=X8V^`=Y>LKRL<%T\\0Z=POR*T#
MUKD4^=Y*QJ<`W\`A[,@UQYP%S*$'\\(^QX,`SG(*R&,!XGPFQTH!]8)"]X=&
M[W<ZQS8`S4H8WU$A\7A.^G%0TS`0^&Q1S!L'QQ$`R!<)V#<O[T0ZRAH2UAD4
MXBPFQP``Q@``?0``?```R`$!QP$!R`,#Q@,#Q@<#RP4%R@4%R`4%QP4%R`D)
MQPH)S@H*T`T-R0T-B`H*TQ`0RA(2V!@8SA@8S1@8D!$1W!T=VQT=X"$AT"`?
MSQ\?SR`@FAD9HQL;TR<GY2LKK"$AZ2\OKB,CI"$AM28FV#`ON"@H[34U[#4U
MNBHJO2PLPRXNP"TMKBHJR3(QQC`PW3@XSC0TRS,S\SX^T#8U]4)"U3HZN#(R
M^$9&]T9&XD%`VS\^XD%!X4)"^4I*PSL[^DU-Y49&ZDE)Z$A(^D]/^E!/^E!0
M[DQ,\4Y.^%%1]U%1]%!0]E%1[5!0T$9&\E=7\5=7]5Y>Y5E9^61D^&1D]&5E
M\V5E^VIJ____````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````GDNYS@````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;)
M:SX```"\241!5`C78V#``O3TO?/:ZN*=S'5,[=W#TDN!0OHN::T-V9YJJD8V
MK@$IQ55`(;N8QN8B7UM)<6M'OZ3\RD*@4%`M2XVZIHFHL):V1FY%6190B+FM
M/EY.B)^32T!0NK0\)P$HU-*0Z64ER\/*SBU54E7`%`<4:@(:9&@@QL8ADE]=
MF!H;"12J"7$PUE'AE9#A4R[+2HP.!@K%.UOHFBG)AV<H*N0D1(7Z`X4\+'6,
M;-Q`+BI(CHL(],'F'0"61"UPFB5"X@````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]U>2YP;F<`````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,C`U,"`Q,#4Q-30S,S<T-R`P,C,P-C4`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____DZ//0T=2)F<"=
MK=2LO.*_S>^6G*O*TN7$R]QYCKR%E[^5J=2/H<EQ?YZ/GK^ZS/.BLM2WR.VY
MRN^<J<7"T?2@K<F>JL6GLLRWPMO%T>NLMLVYQ-S5X/FHL<74WO7!RM[`R=VK
MLL&UO,S;X_7>YOAVC;MWCKQ^E<)\DKY^E,!]DKR`E;^'G,B+H<V#E\&&F<&.
MHLN/HLF<L-F0HLAZBJFDN.*IONB$E+27J<RLO^>6I\JTR/"HN^"SQNVXR_&J
MN]^ZS/"RP^:]SO&;J,.IMM&BKL>VP]VKM]"FL,31W?:JM,C'TNG7XOBTO="P
MN<O0VN_/V.JAJ+;7W^^WO<G!Q<WGZ_/$Q\W4U]WN\??\_?_X^?N-HLJ9L-J"
ME+6+G;^GNMZSQ^VON<S'S]ZZP,N\P<K8W>;)S=34V-_N\OGL\/?"Q\^]PLK,
MT=G9WN;K\/C!Q,FOL[G*SM30U-KS]_WGZ_'FZO##R='`Q<SP]?SAYNWP]?NY
MO<+?X^C(RLST]OCGZ>O:W-[*S,[)R\WL[>[7V-C=UKKZ]-E_=5;_]=7&OZF+
M?59_=5BGFWB=DG+VZ,#KX<;AV+ZOBBZ2<R>XE#G\U'#2L%[YTGCOSX3VV)'B
MMUW'QL32TM)_?W____\`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````";G%I<`````6)+1T0`
MB`4=2`````EP2%ES````2````$@`1LEK/@```,%)1$%4"-=C8,`"YO7V=S,R
M24E*B(J[>4A[RP&%.J=,G=7!:<K"8\C'RB8BQ@X4ZID\>\;$MN;Z%N:FQH;H
MF%:@4-_T:3/;9;AU#(Q,K!V<G(6`0G.Z)DR:&^KJ[BGKJ^`7J)@,%,HN2*](
M3:O,R*S.*HVJ*RX$"KDDQFJI:VCJQUG8)ME9)<0#A<I*PG)S<_+RPZMJRB,C
M:HN`0EP!\EX^_DI!JFHA*2K*P1Q`(6-=+6T]7G-[06%'&P%+,WYLW@$`[V,Q
MJ:<_B3,`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W=S+G!N
M9P``````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#$W(#$P-3$U
M-#,S-S0W(#`R,S`V-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X`
M``,`4$Q410```/___]H='M`U-K<`#K@!#[@%$[P'%;T-'<40'M%!3N9>:N9E
M<;,`$;0#%+,)&;D@+QD%L0P!N0\%NQ,)NB(8P24;P4(ZNV%9YW)J\69=T@H`
MO0D!O'MZ\@``?0``?`,#S`T-S0H*B!\?TQP<FBDITR$AIS@XX2TMD$9&TU96
MZ$I*N&1D^$=(KFAJ_6EI]6EI\WU]^W-SY7=WXGQ]PQ(5SD%$VXB*\,L``,<`
M`,8``,T!`<L!`<P#`\@#`\8#`\L%!<H%!<<%!<P'!\@)"=,*"M(*"M`-#<T-
M#=,0$,H2$MD4%-84%-T8&-@8&,T8&-P='=L='>,A(>`A(=\A(=`@'Z,;&^(F
M)M<G)^4K*ZPA(>DO+ZXC([4F)M@P+[@H*.TU->PU-;HJ*KTL+,,N+L`M+>\Z
M.LDR,<8P,-TX.,XT-,LS,_,^/M`V-?5"0M4Z.OA&1O=&1ML_/N%"0OE*2OI-
M3>M(2.5&1NI)2?I/3_I04.Y,3/%.3OA14?=14?104/914>U04/UD9/___P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````&5Q:70````!8DM'1`"(!1U(````"7!(67,```!(````2`!&
MR6L^````J$E$0508TVW,.Q*",!2%X4LDW)N`#C26+L(UN0:78.T:K2@81Y!'
MR./&,)9ZVO/-#_"S#$Z9K$.GG_V9E-[7^B8@4^CYZ"-+1#HH"3GLI+0\,Z=+
M-2A7$)![7U9UU$*J/5&P2?4B"A]H%JC+(AJ3U#0,\VK?RYJ0='=.ZCH^7F/4
M5#6(QEQ<4K$=ED"H4\A9SUNK[8VC@KXAZT)2W;3D!>$6LLS!PY]]`&0]3JUV
MQG=Z`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O>64N<&YG````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#(P-#8@,3`U,34T,S,W-#<@,#(S,#4R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____U=35Q\;'(B,C
MU-75P<+"'R`??7Y]@H."-C8U;6ULY^?FS<W,W];3S\3!T\S*S,"]PB$`>10`
MQB4%PR4%SS`0P2T/RC88PS8:VT$AERX9TD(EZ5,USDTSWU0XV5,X]&1&JD<S
MP%$[[65*]VQ0[G!7Y6Q4XFM3\75<^()JX'=B](1N_?/Q_/+P\>?E_O7S\>CF
MOQT`>A0`>!(`P2`#P20)R2D-P"P/R#07C"01U3@=A243R3D?XDHO[UQ"LT8R
MW%A!]&A/[VA0]7)9\'1>[GIET,3"R[^]VL[,Y]O9W-'/].GGIIZ=^/?W_O[^
M_?W]_/S\^_O[^OKZ^?GY^/CX]O;V\O+R[N[N[.SLZ^OKZNKJY>7EY.3DX>'A
MWM[>VMK:V-C8UM;6U-34TM+2T-#0SL[.S<W-S,S,RLK*?W]_?'Q\;V]O86%A
M8&!@75U=6%A845%14%!03T]/3DY.34U-2$A(1D9&0D)"04%!/3T].SL[.#@X
M-34U-#0T,#`P+R\O+BXN*BHJ*"@H(2$A'1T=&QL;&!@8$!`0#0T-"0D)!04%
M`P,#____````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````XKSG-`````%B2T=$
M`(@%'4@````)<$A9<P```$@```!(`$;):SX```"_241!5`C78V#``HR%I96U
MU!0D1(5$Q*1D%56!0B96#FZNCK9F1J;FUG;V3LY`(1LE;1T-.4D+<4L9>147
M376@D*^`@;XWOX>@NZ>7CZZ>(1]0B)DQ+"XE(R,U,38\T#\L)@4HY!?,PYJ>
MD984%Q',&!+-E`D4"HA,3,M(3XZ/"F4,BDC@90,*9>665557EN;G<'!F<^<5
M%`*%:MJ[&;H[6FK+BTHJZAJ;6X!"[%T,/9VM#17%1>5<]4TL;=B\`P#\2BTJ
M)AY%]`````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]Z82YP
M;F<`````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`T-B`Q,#4Q
M-30S,S<T-R`P,C,P-#<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.
M```#`%!,5$4```#____*$Q3A8F/4:&K><'+K@8+XD9+_G)[NDY7[G9[-=WKV
MU-4[.CN^QOZWOO)"7O=0:?I@>/MTANZ4G<^\Q?TA-ZTH/[@N1L,T3<]"7.%/
M;/I.:/*!BKF+E,2BK-^SO?(;-:0B/J\J1KLP3<8V5-%&9>90;_7`QMO4V.=X
MC8+,V=*%FX^2IYJ8JI^NP;6QP[BBMJFINJ]WCGX[64`<.Q]-84\`)```(P``
M(```%P``$P`!(0$#)@,#)`,#'P,%*@4%)`4%(P4')0<)+`D*+0H-,PT0,!`2
M,!(1)Q$8-!@=/1TA/B$?.A\9+1DG02<O22\U434T3#0R2#(P13!&8D9"7$)(
M9$@V2S9"6D)0:E!.9TY&7$9/9T]09U!>=EYE?65D>62YO;D!'0`2+Q$=.AL<
M.Q@S3B]-:$E!5SH,*P%I=F&6IHV7IHZ#DGF+FX%\BG.-FX1R?VE[B'*YO[1P
M@5DO1@5`5A(]5``K.0"1H%"+F3AXA@V"BBJ=HQBSN2^ML@GDY6AO;@JUM2>+
MBB"NK3B[NE",C$9N;E=,3$`C(R&!@$C'``#(`P/+!07(!070#0W3$!#.&!C<
M'1W@(2'I+R_M-37U0D+X1D;Z3T_[4%#U4%#'J*AF965J:FID9&1>7E[___\`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#0T7XK`````6)+1T0`B`4=2`````EP2%ES````2````$@`
M1LEK/@```+])1$%4&!EES[$.`4$0@.&=N5E[YXA&2:A$1&AT$H\C:IUG4*"3
M>`>=2J=2RBE5"B$.W>5VQ=W8T_K+;S*3C!!_@>AS^1:=XUF2H.,@XI#$X"!;
M['8G\101;(*$U]./N'*LC4<9(%MR)<GGV>TLFT`IX"<`45S<$Z-WKI)V!JE9
MDY@C,&(N1R05I(QV$<.W>04>554"Q&@L78W>ZT+=VUZ4SU$^.Q^%)^,W_)7C
MJ#>3R2B(=;NT"<$K\*^_;RQ\`;8!2(2AMYZM`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+WEU+G!N9P``````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`R,#0R(#$P-3$U-#,S-S0W(#`R,S`V-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___]74U<?&Q]SB
M\J2LO[O#U[6\S=3<[\S3Y``G>@`83`0J?00J?`DN?@PRA`PD6!U"DBU1GT!C
MKD%@I$]PN$MJK4IIJU!PM5-SN&6"P)VFNZ*KP*VVRHB.G+K!T=7=[LS3XP`I
M>@`93`,J?`4M?P4M?0TTA0\T@A`XB!@]B!$J7QI`CR%(EA]"BQDS:"E+DB]4
MH35:IBM%?#A:GD)FL#)-A$9KLSI7CT]QN%!SN5=VMEY\NUIVL&6!O&J'P\G2
MY;.ZR-35U>?GYMC6U<"^O:0I`*4K`Z8P":XU#;E$';!$'XLW&Y9`(\A6+Z%'
M*JQ/,+56-=5G0LEG1MQR3]=Q4*M=1<S)R/KW]O;S\NWJZ>OHY^GFY:(D`*8I
M!:0I!;`T$*PY&+Q$(:I`(:I"(Y(Z(:]&*)Y"*,M6-:A)+KE2-+!-,;)0-+]6
M.-=G1L1?0L=C1=MO4-1K3J!4/K]F2]5T6+5D3,5Q6-^#9]:`9^"';=:#:M+.
MS<W)R,S(Q\O'QO[Z^=W9V-?3T_OX^/CW]_[^_OS\_/KZ^OGY^?;V]O+R\N[N
M[NKJZN7EY>3DY.'AX=C8V-;6UM+2TM#0T,[.SLW-S<S,S,K*RO___P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````$NESDH````!8DM'
M1`"(!1U(````"7!(67,```!(````2`!&R6L^````NTE$0508TVW!/6I"41`&
MT&]^[GN*X6&P$K00"SN7EL[**@CB?M+%WJP@8**(B(4:$#%&U-R9FP68<X`[
MA#8>RGF\GF,4U1!DPMB4\LP^;NLU\T:%%U"$4CZWQB7Q5Y-6K`Y&4;SEA_?O
MHEI\=G\JAS((XJ-,%&8>8U(-3XSGX>N+P#V9]45Z`83!M//+R</,.E/>U?9C
MQ:6^O2;1K"ZWEC>6W;'B>'(GB^Y"9O9XA&)A3DRJ3.XI><(__@#[2U)W%.T;
M9P````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O868N
M<&YG````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P-#<@,3`U
M,34T,S,W-#<@,#(S,#(T`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=
MC@```P!03%1%````____U=35Q\;'(B,C5%55U-75N+FY`%L``#D``#@`!6`%
M$&H0$4L1'70=$D@2(7DA&549+X0O-8HU.(DY.(0X0I1",F\R1IE&,FPR08I!
M.GH[29=)4)]03YU/4)M05Z-74YE34I=25YY76Z-;7J->9:9E:JUJ89YA;:UM
M'R`?GZ.?\_CSZ.WHUMO6TM?2]/CTZ.SHS-#,]OGV65I9T-'0$&@-&VP8.W\W
M$%X%'V80-'$?+VL9O<*Z.6H61W,936P20UX#2&`)0U<`.CHYY^?FQ,3#Y./2
MOK:2(2`=KYURMJB%?6U+6D,5?&4UPJ)AB7=2N:1[.SDU,C$OOKRX,"8433TA
M95$LDWA&K(Q2DWM0MYQLMIUOMZ%XU+N.Y<N;O*>"Q[*,[MFQ9UY.OJZ1Y-?`
MY=K%P)Q?NYIFNJ!V>6I1V;^4ZM*KX,FDRKB:R[ZK3DE"&Q80XMK03$E&4E%0
M^/?W_O[^^OKZ^?GY]O;V]/3TZNKJY>7EY.3DXN+BX>'ATM+2SL[.S<W-RLK*
MP\/#3T]/2$A(0D)"/#P\.#@X-C8V-#0T,#`P+R\O+BXN*BHJ*"@H(2$A'1T=
M&QL;&!@8#P\/#0T-#`P,"0D)!04%`P,#____````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````AY0^-0````%B2T=$`(@%'4@````)<$A9<P```$@```!(
M`$;):SX```#`241!5`C78V#``C@Y!:75E47-+3FX>02$)62!0ER\XFJJ4M9.
MSHYF?$)B<O)`(7Y)#4TE"SLK&P=[$1D%%46@D+:1L:&^MY=MH(>_NX&.KAY0
MB)FQLKXA,R$_KR@WIZRRI@$H5%KNRM84$YV8GAJ?5%'-U`P4JJIK;`E)B8S-
MB,M.JS5U8P<*F;A,FCH]U#?<)R"+M:VCJQ<HU#EE)L/,PC"_B*CD@NZ^"1.!
M0EHS&&9-\PQN;RTI#NKI9YF,S3L`D;(P.\)2F)<`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]M:6UE````````````````````````````````````
M```````````````````````````````````````P,#`W-34@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<T-R`P,C$U,#$`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O;7-E>&-E;"YP
M;F<`````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,S8P(#$P-3$U-#,S
M-S0W(#`R,S<R-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````$````!`$`P```.W=XE(````8
M4$Q4182$A/___P````"$`,;&Q@```````````%QP7RH````(=%).4_______
M__\`WH.]60````%B2T=$!Q9AB.L````)<$A9<P```$@```!(`$;):SX```!=
M241!5`C7)<HQ#H`P#$/1%".Q8I43=&%-CP#*@2HQY/HD[9^L)XL/B0X7'XPV
M%U6>RG(+4`"V)ETC>U[Y*K`SA@?9%`2EJ/;U`8+(E*">Y\&*,L=ECRW)<EB6
MH\U^%@@7SPTSPB@`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+V]O;U]W<FET97(N<&YG````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#,Q-"`Q,#4Q-30S,S<T-R`P,C0T-30`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!`````0!`,```#MW>)2````&%!,5$6`@(````#_
M___`P,```/____________]L?[^4````"'123E/_________`-Z#O5D````!
M8DM'1`<688CK````"7!(67,```!(````2`!&R6L^````.4E$050(UV,H9P`#
M<89R)B4@4(8R&)BA#"8PP\7%"2X"4>,"!,[H(D[*!-4X*:&H838&`2!#$`S$
M`9N!%.SLG&(#`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O;6EM92]V:61E;RYP;F<`````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`S-3,@,3`U,34T,S,W-#<@,#(S,S<U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````0````$`0#````[=WB4@````]03%1%````F9F9S,S,____````J7X.
MF`````%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3```+$P$`
MFIP8````!W1)344'U`P4$PPHV)`CCP```%5)1$%4>-I-S-$-@#`(A.$;H=4N
M`+(!"VA[^\_D:5KC__2%``"J*E![9MK"42;(B0R4A6HZRAIHW;M=+7"2;B,"
MV-R-FJ!YOP8%JJ&K[\\/VG9_P+<;9U,17Z#\KAP`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI
M;64O>&UL+G!N9P``````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M-#`S(#$P-3$U-#,S-S0W(#`R,S`V,P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````$````!`$
M`P```.W=XE(````P4$Q418"`@/___\#`P`````"`@`#__P``@`"`````_P``
M`````````````````````````"$-1KT````0=%).4___________________
M_P#@(UT9`````6)+1T0/&+H`V0````EP2%ES````2````$@`1LEK/@```%!)
M1$%4"-=C^,```OS_&3X(@H`"C*'(#V48&P,9BB(N@HK"#!]$$QU#$E.!##5!
M5_=$,660B$L%6$1042P-K`:L2Q#$<`$"1P(B4,9G8P@``%-=(`>HY5H(````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+V]O;U]I;7!R
M97-S+G!N9P``````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#,T-R`Q,#4Q-30S
M,S<T-R`P,C0V,S``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!`````0!`,```#MW>)2````
M&%!,5$6`@(````#____`P,"```"``(```/_____0+L$`````"'123E/_____
M____`-Z#O5D````!8DM'1`<688CK````"7!(67,```!(````2`!&R6L^````
M5$E$050(UV,H9P`#<89R)B4@4`8RF(U!`,A@%`0!D)004$H8S'!Q5H4PC(U2
MH2)FHF"&,%`3F`'2!&8H*0N##6124A"`,@P-C2`,864A%+L$(78!`$N=$Q%/
MP`IM`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]S;W5R8V4M<'ET:&]N+G!N9P``
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`V,#<@,3`U,34T,S,W-#<@,#(U,3$P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````0````$`@#````*"T/4P```&!03%1%(2$`0D(`
M````>WL`.3D`8V,`>WM[``#_6EH`A(0`0GL`8YP`(=X``/\``'L`(5H``+T`
M`#D`0KT`O0``.0``.;T`(9P`>P``________________________________
M>L(=BP```"!T4DY3_________________________________________P!<
M7!OM`````6)+1T0?!0T0O0````EP2%ES````2````$@`1LEK/@```)1)1$%4
M*%-5S\&2PC`,`U!%P>PJ<5L2H!SU_W_)H64&=-,[>"S8!@K\"6S62PU^P[7^
ME1^H_S7`D\`B26H1QQV4"*GGLDJT;6R]][R-7*5BVQB9.<8<<YY@WA];#F87
M#K@_<R7VKN,7O%XDR_+IA!]&2RE(DP1LWA8I0@%%%-B<J2/1&F%SGSG;/F<A
M:=CFN@WR'/,&,F,0&QN/=Y8`````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+VUI;64O;7-P;W=E<G!O:6YT+G!N9P``````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`Q,#,V(#$P-3$U-#,S-S0W(#`R-3`S-``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$````!`(`P```"@M#U,```#`4$Q418%_@,&_P/_^_W^!@`$!`/__
MXO__X____<#`OG=T5?_SL__QS__PS__PT8!``*5E)?_=O'H^')]C0=)2$=-3
M$GL\&WP]''T^'7P]'J%B0:%B0ZXN`*TM`*PL`*DJ"<Y/+@$``/____[^_L'!
MP<#`P(&!@8"`@`$!`0``````````````````````````````````````````
M`````````````````````````````````````````````````````,]_G^H`
M``!`=%).4___________________________________________________
M_________________________________P#">[%$`````6)+1T0_/F,P=0``
M``EP2%ES````2````$@`1LEK/@```*M)1$%4&--5CUL2PB`,16-]4-NTH"@5
M16HJ8G?!_G=EH(XS'G[@SN%.`BFEN``0^0$YH$)514Z@EX,U?/Q(%%-,(!LL
M*$\T,V#0:3_Z$6T(@<(,%K537GD<<D_(AL'M_L^PN-NQ<?X9=XWH3MFHQ=)Q
MLT8[-#0)$=[@%6+;=ETCZ[ITC-Z:X^%ZD;T0I8-'7_.%0H96CQ),-"WK3$L0
MN;\N1GB6+R]>83-_^0"[O1W7NDUYC0````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+VUI;64O;7-W;W)D+G!N9P``````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`P,S8P(#$P-3$U-#,S-S0W(#`R,S8P,``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$````!`$`P```.W=XE(````84$Q4182$A/___P``````
M_\;&Q@```````````/M!LW4````(=%).4_________\`WH.]60````%B2T=$
M!Q9AB.L````)<$A9<P```$@```!(`$;):SX```!=241!5`C7)8VQ#<`P"`1)
MFM28+(`I4MO*`K8\D#O6#T^N.DY"3[XIN)Q\<W`Z=<#'0QJW<*U_66.2J8EQ
M2&N]S!&B9B:0UN=;5A9188X2[UD,H&#B1OFWLBP`J<D'.+$7>R?BQUP`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]M:6UE+V)I;F%R>2YP;F<`````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#4U,R`Q,#4Q-30S,S<T-R`P,C,U-34`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!`````0"`,````H+0]3````8%!,5$4````P,#!"0D)86%AN;FYP<'"\GG.\
MHGN,B8:9F9F]J(>\K92^MJ^\M['`KY'"LYK#NJ?&P;;ES*?IU;C.SL[>WM[M
MW<?NX,GHXMGQY];JZNKT[>+W\NO]_?T```````!_+KH/````'W123E/_____
M__________________________________\`S1EV$`````%B2T=$`(@%'4@`
M```)<$A9<P```$@```!(`$;):SX```!Y241!5"A33<KA%H(@#(9AC6^FF">-
M#(FM^[_,9J<![^''>+;NHSE+Y^X'^]GB)E=`M#=$I0#I>\K4&Q!$1L*E@"C(
MOHS-!83YN-4+C7.:&V#F=#1`NJ=8@9@2X>4-&)E21*B0H7_@:I!3C"&$Q_"'
M;5O7^^S]8-#7OG6*$JF5@9WQ`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]H
M=&UL+G!N9P``````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(R-#<@
M,3`U,34T,S,W-#<@,#(S,C,W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````0````$`@#````
M*"T/4P````1G04U!``"QCGS[49,````@8TA230``>B4``("#``#Y_P``@.D`
M`'4P``#J8```.I@``!=ODE_%1@```P!03%1%````____ZNKK,T]M-5%O2&%\
M5FV&=(*1>H>5BI2?N,#)P,?/,4YL-5%N.U9R/EAS0EUX0UUX1%UW1U]X4&B`
M5VZ&7G2+9'F/G:JWCYBANL+*O<7-RM#6T-7:?(B3C):?QLW3V-S?WN'C[.WM
M2TM)_O[^_?W]^_O[\?'Q[N[N[>WM[.SLZ^OKZNKJZ.CHYN;FY>7EY.3DX^/C
MX.#@Q<7%Q,3$P\/#PL+"P<'!P,#`O[^_OKZ^O;V]O+R\N[N[N+BXMK:VM;6U
MM+2TL[.SLK*RL;&QJ*BHH*"@C(R,BHJ*A86%=G9V;&QL75U=5%144U-30$!`
M)R<G)B8F'1T=%Q<7%A86____````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````23'-[P```%=T4DY3____
M____________________________________________________________
M__________________________________________________\`OF,UXP``
M``EP2%ES```+$@``"Q(!TMU^_````*Y)1$%4*,]%T-46@D`4A>%9=HS=V"T6
MB*T#2MB(BLK[/XH(Q^5_^=WMC0P#_3*^(0,UK5KC!?I!)YARN;.S]AX!5&)4
MO>@I7:YW9$/&GPOC0O+<>`/@&L[C*J;I"4"Z[(N'L'?3F]K0HJ(!!VW6GP%T
MRPEG9"N*@P5`?P@M`<27I!TU29=7``]&416589YK`%E7;J?;3M\1`(9EV=&(
MXSC!ACDAA.<%LX,%__G6`1\*S2W3)#<H80````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]M:6UE+W9C87)D+G!N9P``````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#<R,2`Q,#4Q-30S,S<T-R`P,C,S-C4`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!`````0"`,````H+0]3````P%!,5$4""AX"1@)::G)F
MF@*6HJZVOL;)SM:$D9J:9C+.UM[.FF8:)C+:XNHJ,CK^SIHV0DZ^RM+BYNK^
M_LZ*EJ).6F*^QL[FZNI&3EK4V^,*$B;:WNJ3GJJ[PLO+TMOJZNK"RM136^]3
M6^]36^]36^]36^]36^]36^]36^]36^]36^]36^]36^]36^]36^]36^]36^]3
M6^]36^]36^]36^]36^]36^]36^]36^]36^]36^]36^]36^]36^]36^]36^]3
M6^_^&KX1````$7123E/_____________________`"6MF6(````!8DM'1#\^
M8S!U````"7!(67,```!(````2`!&R6L^````C4E$0508TUW/T1*"(!`%T`T4
ME<BD,DC8W?__RQ9T:/(^W(<S=V`6EE-@436O<+]=/P`+*&IYNX@@T)?DO#+B
MU/U@'Z4"(804F)RUCMJ"#=G'/!Z+)!N!V1[0]RLS4AS'C9[M#22MM:K@\VIP
MB@4N-!1@-ABWS7OY=@?L@)R7V@&[)!=0K6$HU\!_G<__`K6N#Y:X4DZB````
M`$E%3D2N0F""````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O;6EM92]O;V]?9')A=RYP;F<`````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`T,3,@,3`U,34T,S,W-#<@,#(T,#<U`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```0````$`0#````[=WB4@```#!03%1%@("`````____P,#``/____\```"`
M``#_@(```(``________________________P62WTP```!!T4DY3________
M____________`.`C71D````!8DM'1`\8N@#9````"7!(67,```!(````2`!&
MR6L^````6$E$050(UV/XSP`&\@S_F92`0!G$$#86-@0S3$)"@A5`#%,7%V4F
M?K!(D%H!1$0I/1$D(A*D5B8,5@P4`.LR4@T3AC(:E2&,B$G*J";#[&(V!@$@
M0Q`,Y`%#,B"PQ$6_KP````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O
M<G!M+G!N9P``````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q-#,W
M(#$P-3$U-#,S-S0W(#`R,S`W,0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````$````!`(`P``
M`"@M#U,```&`4$Q415A86-[>WKRWL9F9F?___^KJZFUM;?S\_'!P<,[.SC`P
M,(F)B6MK:T)"0DM,2U985EM=6V1D9&EI:4Y/3KZBH.*RL/;U]>+@WH^)A&YO
M;B$B(4M-2W-S<\S,S._O[]*_OL!H9<%13=S'PN?@V;ZVKU)34@<'!A\@']_?
MW_[^_OOX];Y&0KM`.\[(O[RNER8F)0("`O[^_?KX]/CT[(U*1HX7%+:$?0``
M``P,#$9'1L3$Q&1B7HB">,"UH[RKD'9Y=KZ[N(Z.BQL<&[:PJ!<7%[.JG!`0
M$,V^J;RHBG]^>KZVJKRPGKNLE;RFA0<'!U)24LG$OM[8SLB_L];+NM7(L]+#
MK-#`I<^[GKRC?_3MX?+HV/#DT.[>R.S:O^G6N.?1L.7,I[RA>,;!ML2]K,.X
MH\*SFL"OD;^JB+ZE?[V@=KR><___________________________________
M_________________________________________________S1O*TL```"`
M=%).4_______________________________________________________
M____________________________________________________________
M______________________________________________________\`.`5+
M9P````%B2T=$?TB_<>4````)<$A9<P```$@```!(`$;):SX```"L241!5"B1
M3<XM#L)`$`7@]]+"-E4$@0/7!$-P]`8$AZWF(IN>`(_"8JMJ,&@(%ZB#8%!@
M^"G;PFZ[I$_-^\3,4`*(4>=7:("ZL7"4M.!H8%$JV0"'S$O1``CE4FE8TN;:
MNU.N]'3NGP:&+@S(*!YF0&`@XYASLV-D^C-C2$Y3'"8*[J=%[AG.D'I\^/7:
MG0&@BY?W%GF;6WWVR%O''D[JQR(+FPH6L+"NP,<_7Z/A,A"\6WNR`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+VUI;64O;V]O7V-A;&,N<&YG````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P,S$V(#$P-3$U-#,S-S0W(#`R-#`T-``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$```
M`!`$`P```.W=XE(````84$Q418"`@````/___\#`P```@(``@```_____U;L
MI^$````(=%).4_________\`WH.]60````%B2T=$!Q9AB.L````)<$A9<P``
M`$@```!(`$;):SX````[241!5`C78RAG``-QAG(F)2!0!C&,00#$,&!F8#!&
M$U%2PBUB`A,)@8H8AD!%TD)0=<'L8H:)"(*!.`#8_!6)URW5I@````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+V5N8W)Y
M<'1I;VXN<&YG````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3,P-B`Q,#4Q
M-30S,S<T-R`P,C0T-C``(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3
M```!#E!,5$4````$`P(%!`,("`@)"0D+"P<3$0X:$PL6%A8<'!P@'1P>'AXO
M*2$K*RLM+2TN+BXX.#A-34V!6BMR<G*J;RND<39Z>GJL<2ZM<S*@=T2C>TN$
MA(2D?DZH@4RT?CZG@E*G@E.X@#ZJA%6KAUBLAUBZA$*KB%BZAD>\AT:\B$FZ
MB4NOC5ZMC62\BDRPC5^]C$ZED7:^C5";EY3&EEW'FV2HHY[*GVBJJJK+I''.
MI'#-IF[-IG;0IG3,IWO0J'3/JWRQL;'/K'O-K(/.K8/4K'G5KG[2LHG5LH38
MM8R\O+R^OK[6NI3`P,#!P,#"PL+:OIK@PI[APIS@Q*#?Q*/AQ*#BQ:'CQJ+2
MTM+;V]L```![0$@>`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9
M<P``"Q,```L3`0":G!@````'=$E-10?4#!02+`1^#@'Y````C'1%6'1#;VUM
M96YT`$UE;G4M<VEZ960@:6-O;@H]/3T]/3T]/3T]"@HH8RD@,C`P,R!*86MU
M8B`G:FEM;6%C)R!3=&5I;F5R+"`*:'1T<#HO+VII;6UA8RYM=7-I8VAA;&PN
M8WH*"F-R96%T960@=VET:"!T:&4@1TE-4"P*:'1T<#HO+W=W=RYG:6UP+F]R
M9V>*QT<```"9241!5'C:8V#`#B*!`(G++18>$>$IS`P7D/82X.04=)"&\?G\
M6$`4OSE,%Z\/F,7A"Q-@,^)B961DXC%EA]I@$!0<[._O[VTM!%$2&>IAIB(O
MKR"E*0X5"'/5<[>W=[30$($*A-B8*,G(R$BJPE0$6NJX.3DYVRI*0`4"7*RT
ME9759#7DH`)VQH:&6EKZNNJBD0B?00`V?P,``.(=%XJG_UT`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE
M+V]O;U]M871H+G!N9P``````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#(T
M-B`Q,#4Q-30S,S<T-R`P,C0P-S4`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!`````0"`0`
M``"U^C?J`````F)+1T0`@$<UH!(````)<$A9<P```$@```!(`$;):SX```!*
M241!5"C/M9!)#H`P#,3\=)Z6GYE#*:@P51$2\3'69$%D,X-"$U+5*-2-A[!,
M4`9B0FL<K3RB*\YWN)0O"8L=7ESQZR<K<@HX0W8:M8$Z+A9DN`````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]M86EL+G!N9P``
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(R-C(@,3`U,34T,S,W
M-#<@,#(S,C$R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P````1G
M04U!``"QCGS[49,````@8TA230``>B4``("#``#Y_P``@.D``'4P``#J8```
M.I@``!=ODE_%1@```P!03%1%DY./2TM)^_OXI:6C]_?U^OKYP,"_C8R&O+NW
M^?CTMK2NW-K4V]G3VMC2D9"-^_KW^OGVZ>?BXM_8D(V'W=K4VM?1^??S^/;R
M]_7Q\O#LDY*0W=G2W=K5Z>;AX]_9C8N(^OCU]_7RZ^GF]_7S[^WKEY22LK&Q
MH:"@_____O[^_?W]^_O[^OKZ\?'Q[>WMZ^OKZNKJZ.CHYN;FY>7EY.3DX^/C
MXN+BX.#@S\_/RLK*Q,3$P\/#P<'!OKZ^O;V]O+R\N[N[K:VMJ*BHHZ.CH*"@
MGY^?GIZ>G9V=G)R<FYN;FIJ:A86%=G9V:VMK75U=0$!`'AX>%A86`0$!````
M____````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````N+5Q&````%5T4DY3________________
M____________________________________________________________
M____________________________________`+"A!\\````)<$A9<P``"Q,`
M``L3`0":G!@```"[241!5"A31<[70L(P&$#A&F9M92_9(P(M5H&FLI<MM"*B
M)'G_9^$/4CB7W]61.+O$_22F:9H^FM\$P+;M6>_3%P##,#:'XR^C]`J.L_WX
M?C@QW!0"\/8.]<<,XP@5H.]<U_6\*0!^I`(&(G,A`/]0`.]K;Q*R%!`+"A@2
M8EG6&J`8R@!,EJLUY/Q%.Z\M@.LZ8P&4SCV7`#BGW;B$$)+E6M*'%U1(Y.N-
M2BWU#^TG556SBE*NAB_`Z3U^!NY>.TD6"DM$`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]M:6UE+V%U9&EO+G!N9P``````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#,W,B`Q,#4Q-30S,S<T-R`P,C,S-S$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!`````0!`,```#MW>)2````&%!,5$4```"]O0"$A(3__P#&QL;___\`
M``````".I5WQ````"'123E/_________`-Z#O5D````!8DM'1`"(!1U(````
M"7!(67,```!(````2`!&R6L^````9TE$0508&07!L0W#(!1%T0?"<AL%90%2
MO#8-$]A,@/X>X.:NGW,$K!,0\,Z`8/]N0%#;,!:[E_"#=ITE;/0976%0O68Y
M#*JCY\.M*7VGPJ"5>@F#6+6$C2"U\(-@O6YC`2D#`M8)_`')L27'Y^"<T0``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM
M92]C;VUP<F5S<V5D+G!N9P``````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(S
M,S0@,3`U,34T,S,W-#<@,#(T-#,T`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````0````$`@#
M````*"T/4P```P!03%1%``0```4```0'``0+``(.#!(@"@P9LTTV@"\<=CHO
M"```3U9@;8.86'^>?K#3<:W2B\SL4Y2J`#0]S2T)_Z6$_[.>_\"Q6A0,*P``
M&0``"P```003``@?``PK`!$N%6!SDMW@`"83TQH(OQ0#RS@NK2T@BA8`MT8D
MG"@`H3,`:Q,`D%@W5TD^]/__``H,J-')``X`QQL1_]#*_[ZY_]+&_^/#_\*'
M_\%J_[-2_]!V]*1='0``\_3F#2`>J+VXH24=_^#:_^7B_^#1__G/_^.:^K9'
M_\1%_[U(ZK]C#0H`\O_Z``<.M,/*"@``I#,C_]?(_^[D__':]NBW[MJ$^\M/
M_\8[]L!"[<]O``<`X/GV``<?M[[;%``(IQX`_^#!_^G0_^_,[,F/YKYF_\%%
M_[@S_;I%X;=E$0P`[OW_```SLK/L$@`>J2P`_]RP_KJ5],69],Z-^\UU_[Q%
M_]%2_]!CJ7TT!@$`W.[_`!)`M,'V"P`GAS8`__&]_^&S[M*@W,!_]-!Z_\9;
M\:\_OX4BT*]HS.[M`!<FH=+A``D,>4`5)```%0``#0``&@X`$0$`/1H`&P``
M"P(``!`$``T,'U57D\C"'4<Q``0,1%);7&YX:7Z/B:6[D[C3B++(BJ^W`!X4
M``<C``\R``@R``@S``@I`!,E``HF<I.R``D'%#M"`!8F1F^%``@C+4YO``4I
M1V2,+E)@``PB'E9O`!`K0W:1``XF+$M@``4;````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````F1/3'P```0!T4DY3____________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________`%/W!R4````!8DM'1/^E!_+%````"7!(67,```!(
M````2`!&R6L^````:4E$050HSV/\SP`"C!#P$\CZS\'(^(T;*L#XEH%1F!$%
MW&/A1Q5@0!,XS,#"AR+@PT!("WZ!VA:P`,30M2&,C!/!*AC!3I\!4Y4`%6!8
M".3\9V*,8H`)@,!RQ@@&A,!*J)X`%J@T!\Q:`"+`$[4PPS%Y`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+W1E>'0N<&YG````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#,Q-2`Q,#4Q-30S,S<T-R`P,C,R-3$`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!`````0!`,```#MW>)2````#U!,5$4```"$A(3&
MQL;___\````L9:@&`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9
M<P``"Q,```L3`0":G!@````'=$E-10?4#!03"PG;N*46````-TE$051XVF-@
M8'```08&!A9#(#`!,H2=00`H)&P,!$8H#!,7$V=T$1<R1&`,(240`#)87$"`
M`0#Y7!5JW)+KX0````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O;6EM92]S;W5R8V4M8RYP;F<`````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`S,C$@,3`U,34T,S,W-#<@,#(T,#`R`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````0````$`0#````[=WB4@```!A03%1%A(2$____````QL;&``"$````
M````````B^D4?0````AT4DY3_________P#>@[U9`````6)+1T0'%F&(ZP``
M``EP2%ES````2````$@`1LEK/@```#Y)1$%4"-=C*&<`@?)RAG)&04%!(788
M0P#&4%*',`2%P0P7%PA#Q%'$$9TAB$L*K@MA#I3!;`P"0(82&*@#`*,4%"C8
M:RJ3`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI
M;64O<V]U<F-E+6@N<&YG````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M,S$V(#$P-3$U-#,S-S0W(#`R-#`Q,P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````$````!`$
M`P```.W=XE(````84$Q4182$A/___P```,;&Q@``A````````````(OI%'T`
M```(=%).4_________\`WH.]60````%B2T=$!Q9AB.L````)<$A9<P```$@`
M``!(`$;):SX````[241!5`C78RAG`('R<H9R1D%!02%V&$,`QE!2!S)$'`4%
MA5$9+BXP$1%'HAE``P51&,S&(`!D*(&!.@"S1A1>9S9^?P````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+W-O=7)C92UJ
M879A+G!N9P``````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#4V-"`Q,#4Q-30S
M,S<T-R`P,C0U,3(`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````
M8%!,5$4A(2%"0D(```!"(2%24E+_>WO_.3E[(2&]6EK_``#>``"]O;V<.3F<
M``!:6EHQ,3'___^$A(2<>WNEA(2<G)QK:VO.SL[>WM[O[^^,C(RMK:U36^]3
M6^]36^]36^]36^^BICK[````('123E/_____________________________
M____________`%Q<&^T````!8DM'1!\%#1"]````"7!(67,```!(````2`!&
MR6L^````@4E$050H%07!24("`1`$L.H2%T2T70>]Y/^_-`E`!@A@&B!`V@(!
MTC9,!*1M!YV`-'=M3!N0T_W#8V.:(-.G^_-SQ\R$F5Q>SN?KZUM"I/N^']?K
MYWX%F23?NS\_NY<@:7O9W=T]BLPTQ^[N[E'$)'O[G?F^'4608\*<_@9!)M"!
M?\1K$5RW4&3[`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]I;6%G92YP;F<`````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`T,S0@,3`U,34T,S,W-#<@,#(S,S4Q
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````0````$`0#````[=WB4@```#!03%1%A(2$____
MQL;&_P``A```````A(0``/\``(0``````````````````````````````F$/
MRP```!!T4DY3____________________`.`C71D````!8DM'1`\8N@#9````
M"7!(67,```!(````2`!&R6L^````:4E$050(US7-P0F`,`P%T.H"FD@=P(,+
MM'M(U:`WI=`9NH);QR3B/SW^#\0Y#3.[!@"P^]%S-'C:!.,\%PR+:Y"H#%%N
MQJ.6L`CPJ/=^:7-.[:K`]!!:DZ`8,.</GNB;0'\(VDDC(,O%+\3^)0^Y3-I6
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+VUI;64O<V]U<F-E+6-P<"YP;F<`````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P,S,Q(#$P-3$U-#,S-S0W(#`R-#,T,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$````!`$`P```.W=XE(````84$Q4182$A/___\;&Q@``````A/__
M_________]PZ/BD````(=%).4_________\`WH.]60````%B2T=$!Q9AB.L`
M```)<$A9<P```$@```!(`$;):SX```!&241!5`C78RAG`('R<H9R1D%!02%V
M&$,`RA`V-H<P!(5`#!$701$PPT7$T<4)RH"*P-0@1&!JX+K@YL`83$H@`&08
M@X$Y`/#Z%8)31K%5`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M
M:6UE+VEC86QE;F1A<BYP;F<`````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,#<R,R`Q,#4Q-30S,S<T-R`P,C0R,3(`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!`````0
M"`,````H+0]3````P%!,5$4````6%A8K*RLO+R]#0T-5555H:&AU=75^?7A_
M?7B30CBG13Z`?WG434&"@7R#@7R%A'_GGCR*BHJ1D(F2D(J<FI2=FY6@GIBC
MH)JEI)VGIZ>LJ:.NK:6TL:JTL:NVMK;`P,#*RLK/S\_8U<W9UL[5U=7>V]7@
MW]?BX=OEX]_FY>#___^]O;T`````````````````````````````````````
M``````````````````````````````````````"V:2*O````+7123E/_____
M_____________________________________________________P"E[PO]
M`````6)+1T0_/F,P=0````EP2%ES````2````$@`1LEK/@```'-)1$%4&--C
MT$$##.0(,"`#D`"CE!`[&RLK"PL+,Q-8@$%;6U%;6T%;6UY;&2*@),,I(R,@
M`R1%H"K4Q;4T)965Q91E(`*J<GQR<KS<W-QR,!4:8FK*W(*"7"@JN+FXN&`J
ME.5X9&3X@(9*2S!@=1@AOP``Y(<>(C:/L<@`````245.1*Y"8((`````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]P9&8N<&YG
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(S,38@,3`U,34T
M,S,W-#<@,#(S,#0Q`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P``
M`P!03%1%````@````(``@(````"`@`"``("`P,#`P-S`ILKP!`0$"`@(#`P,
M$1$1%A86'!P<(B(B*2DI555534U-0D)".3DY_WR`_U!0U@"3S.S_[];&Y^?6
MK:F0,P``9@``F0``S````#,`,S,`9C,`F3,`S#,`_S,``&8`,V8`9F8`F68`
MS&8`_V8``)D`,YD`9ID`F9D`S)D`_YD``,P`,\P`9LP`F<P`S,P`_\P`9O\`
MF?\`S/\````S,P`S9@`SF0`SS``S_P`S`#,S,S,S9C,SF3,SS#,S_S,S`&8S
M,V8S9F8SF68SS&8S_V8S`)DS,YDS9IDSF9DSS)DS_YDS`,PS,\PS9LPSF<PS
MS,PS_\PS,_\S9O\SF?\SS/\S__\S``!F,P!F9@!FF0!FS`!F_P!F`#-F,S-F
M9C-FF3-FS#-F_S-F`&9F,V9F9F9FF69FS&9F`)EF,YEF9IEFF9EFS)EF_YEF
M`,QF,\QFF<QFS,QF_\QF`/]F,_]FF?]FS/]F_P#,S`#_`)F9F3.9F0"9S`"9
M``"9,S.99@"9S#.9_P"9`&:9,V:99C.9F6:9S&:9_S.9,YF99IF9F9F9S)F9
M_YF9`,R9,\R99LQFF<R9S,R9_\R9`/^9,_^99LR9F?^9S/^9__^9``#,,P"9
M9@#,F0#,S`#,`#.9,S/,9C/,F3/,S#/,_S/,`&;,,V;,9F:9F6;,S&;,_V:9
M`)G,,YG,9IG,F9G,S)G,_YG,`,S,,\S,9LS,F<S,S,S,_\S,`/_,,__,9O^9
MF?_,S/_,___,,P#,9@#_F0#_`#/,,S/_9C/_F3/_S#/__S/_`&;_,V;_9F;,
MF6;_S&;__V;,`)G_,YG_9IG_F9G_S)G__YG_`,S_,\S_9LS_F<S_S,S__\S_
M,___9O_,F?__S/___V9F9O]F__]F9F;__V;_9O__I0`A7U]?=W=WAH:&EI:6
MR\O+LK*RU]?7W=W=X^/CZNKJ\?'Q^/CX__OPH*"D@("`_P```/\`__\```#_
M_P#_`/______6").MP```0!T4DY3________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M________`%/W!R4````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^
M````6TE$050HD5V.RPU`(0@$N7FQ#OLOC&1#!;PEHL*;B^[P">+N\F`(8<E<
M4JM"L?BL`P5I@M2)%%PZXP=8%T-_`HHN=+=<,1`]P!$C`E15]NFYX(ZP9$V\
MG**>^P&ZF93#$VX9AP````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]M:6UE+W!H<"YP;F<`````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,C`S-2`Q,#4Q-30S,S<T-R`P,C,P-34`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!`````0"`,````H+0]3````!&=!34$``+&.?/M1DP```"!C2%)-
M``!Z)0``@(,``/G_``"`Z0``=3```.I@```ZF```%V^27\5&```#`%!,5$5[
M>WL```"]QL;___][A(1[A+TY0EJ$C+V4G,;O[_?>Y^^MM=;>WN_W]_]"0EJ,
ME,;&QMZUO=:]O=Z,E+W.UN><I<XY.3D8(2D8(2$Y0D*<G*7_____________
M______\@("`A(2$B(B(C(R,D)"0E)24F)B8G)R<H*"@I*2DJ*BHK*RLL+"PM
M+2TN+BXO+R\P,#`Q,3$R,C(S,S,T-#0U-34V-C8W-S<X.#@Y.3DZ.CH[.SL\
M/#P]/3T^/CX_/S]`0$!!04%"0D)#0T-$1$1%145&1D9'1T=(2$A)24E*2DI+
M2TM,3$Q-34U.3DY/3T]04%!145%24E)34U-45%1555565E975U=86%A965E:
M6EI;6UM<7%Q=75U>7EY?7U]@8&!A86%B8F)C8V-D9&1E965F9F9G9V=H:&AI
M:6EJ:FIK:VML;&QM;6UN;FYO;V]P<'!Q<7%R<G)S<W-T='1U=75V=G9W=W=X
M>'AY>7EZ>GI[>WM\?'Q]?7U^?GY_?W^`@("!@8&"@H*#@X.$A(2%A86&AH:'
MAX>(B(B)B8F*BHJ+BXN,C(R-C8V.CHZ/CX^0D)"1D9&2DI*3DY.4E)25E966
MEI:7EY>8F)B9F9F:FIJ;FYN<G)R=G9V>GIZ?GY^@H*"AH:&BHJ*CHZ.DI*2E
MI:6FIJ:GIZ>HJ*BIJ:FJJJJKJZNLK*RMK:VNKJZOKZ^PL+"QL;&RLK*SL[.T
MM+2UM;6VMK:WM[>XN+BYN;FZNKJ[N[N\O+R]O;V^OKZ_O[_`P,#!P<'"PL+#
MP\/$Q,3%Q<7&QL;'Q\?(R,C)R<G*RLK+R\O,S,S-S<W.SL[/S\_0T-#1T='2
MTM+3T]/4U-35U=76UM;7U]?8V-C9V=G:VMK;V]O<W-S=W=W>WM[?W]_@X.#A
MX>'BXN+CX^/DY.3EY>7FYN;GY^?HZ.CIZ>GJZNKKZ^OL[.SM[>WN[N[O[^_P
M\/#Q\?'R\O+S\_/T]/3U]?7V]O;W]_?X^/CY^?GZ^OK[^_O\_/S]_?W^_O[_
M__\'Q@QM````('123E/_________________________________________
M`%Q<&^T````)<$A9<P``"Q,```L3`0":G!@```!;241!5"C/G8])#H`@#`!+
M2%L%4=R]\?]?&I"R7)WC9-JT$"*J`I\`0806BL@#^E>A.J+`!$$I$'D8#36%
MG9C=7`OK%O1K4[`WN"W=CAV/DR[Y15'B?N1;N2!D7KFP"".%W##Q`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O<V-R:7!T
M+6IS+G!N9P``````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,S8P(#$P-3$U
M-#,S-S0W(#`R-#(P,P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$````!`$`P```.W=XE(`
M```84$Q4182$A````,;&QO__`/___X2$`/_______^,7U7D````(=%).4___
M______\`WH.]60````%B2T=$!Q9AB.L````)<$A9<P```$@```!(`$;):SX`
M``!=241!5`C78V"``$8&]O)R!B"A",0%)B:*8`9+:)"`.)!1X&*BR`1FN(8*
M"H*DP$K`:IA#@\11=3$PACJ!%3L)B!B!&"R&S,Y@J0(E1B6(8D&@,4`&DQ(8
M*#((0@$`@+<6DNH<%!<`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+V1E8BYP;F<`````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3`R,B`Q,#4Q-30S,S<T-R`P,C,P
M,3,`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````P%!,5$4````P
M,#!"0D)86%AL;&QP<'":``"N``"V``&Z*BJY*3*[6EG```#*.3G"7UK%967:
M>7B\GG.\HGN,B8:9F9F]J(>\K92[M*V\M['+DH7"DI+`KY'"LYK#N*/<JJ?@
ML*_DM+3&P;CES*?HU;?+RLG4SL;9T,/=W=WLW,3FWM3NX,GIXM?QY=3JZ>GS
M[>+V\>S\_/P`````````````````````````````````````````````````
M``````````"ES>*7````,G123E/_________________________________
M________________________________``U0F.\````!8DM'1`"(!1U(````
M"7!(67,```!(````2`!&R6L^````K4E$0508TT7.Z1*"(!B%8>U+(\5M7,MR
M2<<-$+S_FXLEI_<7/'-FP#ID<";/EH9954$&)S`A8XZ0HL$-,(JY<$:1V0I<
M[/D^\MK4N5XT8'=D;`X\QJI4`;J!"**VQ2,GI0)\0!#-K,,]HX5>'!`^N8C1
M1$GQ6W1>&^-RI9M9N"`:WR\GNBRY>04$)RN1]\$`NN]\IW09AH\!^=-FH]L@
M(3$`??AXO^HZ3TZP_WT!9%8<21%\580`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:P``````````````
M```````````````````````````````````````````````````````````P
M,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<U
M,2`P,C$V,S<`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V)L;V-K+VUO;VX`````````````````````````````````````````````
M`````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P,#`P(#$P-3$U-#,S-S0W(#`R,C8Q-``@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO;6]O;B]F=6QL;6]O;BYP;F<`````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#,V-S$@,3`U,34T,S,W-#<@,#(U,C0S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````P````,`@#````8-P)M0```P!03%1%`/\`,3$Q.3DY
M0D)"2DI*4E)26EI:8V-C:VMK<W-S>WM[A(2$C(R,E)24G)R<I:6EK:VMM;6U
MO;V]QL;&SL[.UM;6WM[>Y^?G[^_O]_?W____________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M________________________________________________`/\`WT_9W```
M`0!T4DY3____________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M________________________________________________`%/W!R4````!
M8DM'1/^E!_+%````"7!(67,```!(````2`!&R6L^```#1DE$051(Q\66S7+<
M1A"#`?1P5U*J7.4XLOW^3Q=+R25_-CG30`Y>V;*E.,DA%1YXX/`K<+K9P##X
M=Y?P7P/C^<=O8T(_/K/"IWNX76T`"3C.=W\'O-G["$",&(NGZ_'CMX"W^V%C
M$VB[MDY.Y)?(%\"K]QQ<IGD%+PY@C4!U_Q?`B_U&DWL+UFD$U%K%WLK;N^>J
M]&+=X#?8"I/IVKJ%2:^;ZN<47ARG[?@0``)92^=];H&_:VW`_9/&O3A8\[C@
MB=7+F6U,G9+\\#7P_0'U,@D(Z61P;Y+,'SN8>7S_Y2>]_@5@FC!#`(-1)D#&
MO!EQC%\?*QQ`(26+DL8H+E3B$(3GSM/8;Q]5Z?8#13$0&<01KK5"(6&ZIF^N
MUN^/%#Z`NJR"1+`O.354-<1UI'N=Y^UG!0/5"%A)(&0,SZZ*QMZ`X?=]_FY]
M4GAE8#H4$`:EH;3M$+T,`DSOTB>%PPQ`&BI4E%[)&,NG$9!0"/8Z/RB\F4$2
M2*"P#8#`.&U;:=000M+1?/_RHA#STF";*BX$NB)&!EV=]!CD9!\/`#[>AMRI
M/0L,%E5B!6IZNYI'^+D/1`B0H@@[*;*A`NRZ1G^(J5KT!:"L$%Y!@B+:/',2
M<HBK7H!5$SE=`)7-P`BAK`@8JDI,1AT/!V/XDT)J`DP<,(XH:[38$&SF;!^X
M'G$N97U'7:8`(0FR]XDTXW8%IT'WHC0>.IVB@X#00&>QUE20=)A&AN.L_K0'
M4'("(EXVH&H>Q8];0E-%=,"[!^`TX8#4M+$E1AJ#))ID+W([+7W\EP0`=QS;
M&&.<-B6#<"-;T6E#'520JMH^ST.M,2(%**7A`$'D;(2I104:=X]F^F5LZ9@^
MU12Z&G4E)L)1A!'X]//CF=XH((<S5XQ,@U*)7A(!!Y?2/SC?W6L#!NB,A:VK
MM@T&03H`T$-?.=^K)<QIGK/&F:LVH@.CD9#!Z?XK;U5ZNZXE[8G'*``R:`$-
M8+M_XJT_[!ANE"FR4"&=-!R"]=,S=G\[EYJ#L51`4+`G`&'\]&P^O-YG%88#
M2B8)=P)BW/]59+ULH`AG4!]-W`0?Q<F34'P[)RBC*"0!0=U].W;?+L<L"#2H
M=_\@IX$W09Z^^@W@_SV<_`DL:4#(;4YU3`````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V)L;V-K+VUO;VXO;&%S='%U87)T97(N<&YG````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`S-C4P(#$P-3$U-#,S-S0W(#`R-3<U-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````,````#`(`P```&#<";4```,`4$Q410````#_``@("!`0$!@8
M&"$A(2DI*3$Q,3DY.4)"0DI*2E)24EI:6F-C8VMK:W-S<WM[>X2$A(R,C)24
ME)R<G*6EI:VMK;6UM;V]O<;&QL[.SM;6UM[>WN?GY^_O[_?W]___________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M_________________________________________P#_`,Q,@W<```$`=%).
M4___________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M_________________________________________P!3]P<E`````6)+1T0`
MB`4=2`````EP2%ES````2````$@`1LEK/@```S5)1$%42,>UELMR%$<01<_-
MJNJ1@,#A\(L0C___+B3`>&4<'HUFIBJO%]42&I"PO:`7O>B.TY6/FS=;YO]=
MP?<&ZD,/WR1D$&\?>*>O<GBUVP]J!$9U<_5OP&_;,9(HT6P/+>?E\EO`Q?46
MHXA232UV;M`I<@+\_%<6&Z&EE1Y%])JA\NX1X/FV)38"+6?APC@V1BO9+A^H
MTNL_;]HP@&7Y&(L=L8_L3\IXH`]O/MV0`F,L>63NM[M!/U]2O/H:^'1-I(TL
MP-`/8_0^?"S-C(LO@5^VD#(@L,D:?804VN[!_?#B%'CY23(F#""D0ZF2$>5X
M2$O'GTZ`ZP$RZF(ETH%E(_*XUU+W+^\!+_X.0+@(A(U;41K(8&3?^6RYO@=L
ML301`?)(Y2@U:JF*?O#H_>SP\JX/K[ME@3S[*$D>1+7:?J2,=V/SM-\!-WU6
M<M9HUFE`6.H]0R8\;I:X"VGG.X4("?#HBCQF%"1"DG+7;X'7A_OBTGI,:2U*
MBQI8TB".NU_7D$9JYH!P&`PJBD:)7H8]:A5'C>-Z0D[!(4TEV<:9J2BJ)22W
M\S,L>3TAL6S-%#PU+W>WDG(Y9^R<BM+E]03'BAN,D)%"87N@S6*148R7%0B$
MD>?'#1)2!`Z!ATM:M2IR#:G,J;G-8UX98(5)EAS'PUE+;D,JM\&;.0LR=MH,
MIZQ68XQ!45V!RX)22&B&-/OH=*88IJ;3?=SEP$;(&+!7D7AF)+I'ND@]T=6M
MEI[<I%<+\;S+ZW@CC2XU]8C/6GI?IESNI"?/?F9:`XIQ*:5]GH>SF;2TUM5@
MP2!"270%J%Y]!IXV$^"Q#@/(MB-"ARB9:;E<W9NXM\^(#*R!/;6$%:'1HZSB
MT8D)?#PG$CLLD((HLR.$>T(ZXM0JGQ^[PK-&`DEX1"B2Z3[U\M3(+I]7CRB$
MA9'LV1.B%`/M_9=6^?NS@BW/G!%KV3Q2TO+^ZZ7XQP_MU@=FTL[,T<>P%.\>
MVJ(??]CD;-[T`8PI4:3ZX;&5]>-V.MGT@=IJ(-0N'U^*%]O=.AQ"45I3Q-6W
MU^Z+_7ZL?AEULWRY1!_8TW!Q<^R@6C<?_LMB7S?8VT=^'?3=_V;^`<.Y\NK8
MR,^2`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]B;&]C:R]M;V]N+VYE=VUO;VXN<&YG````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,S,V-R`Q,#4Q-30S,S<T-R`P,C4P-S0`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```#`````P"`,```!@W`FU```#`%!,5$4`````_P`("`@0$!`8&!@A(2$I
M*2DQ,3$Y.3E"0D)*2DI24E):6EIC8V-K:VMS<W-[>WN$A(2,C(R4E)2<G)RE
MI:6MK:VUM;6]O;W&QL;.SL[6UM;>WM[GY^?_________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M__________________________________\`_P`4.L2F```!`'123E/_____
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M__________________________________\`4_<')0````%B2T=$`(@%'4@`
M```)<$A9<P```$@```!(`$;):SX```*$241!5$C'Q9;;;MLP$$0#SIR1I3B.
MD_A2-<K_?V;[0-*6<VO[5,*`(8!'.[/<Y>KNUS^NN_\#+//I^'+X\?/O@-?G
M^P`@9WO^(W#:#I8DRW8I3,_+=\#\*%0`VS;883I^#;R@8%L&;.K*]O4+X*$,
M8,DJ<DRE3,;C9\"R=95?)*F]OX8;5K(NP-N##5(IDIMI61(FGLX?@)T<N5PB
M2%8IDAP2QOD=<)!LJ]3]136KDE2<`/>WP$^J`#?"MMHJ!H@?;X!]L2WYKJFQ
M5>-)DC'@'RO@;+N^M+W8-JAIPC(#VQ6PM>BBJET;]4>IF.#C!5@V,FXZKJ)4
M$UV3`.POP,%JFOJOZ3--8I'-=`'NU3<98R.I6%*-X.YJ;L""W)%6$%+C6XAZ
MZ$\-F"79PK9Z`8E@"-13E%TT->#<`H!LT_P:DB&V).I?&G"L,@&O?%:B-VLH
M$DL%#E2155-/J"&$#+%<0PP-.*%+,KTR'P(D"(B+NZ2YMIEJZAN0CB3!.-CC
M):U>U9!DU/HY;=D"L^L'MW'K,1E91IV@ND`R]JD#C[AT/>JZH%J`I!9:E@[,
M`VV?5'K1WMC&Q@_7\I[B>F3J]:WJNLO"9GBY`L^$4@^N=Z8).%V6R;AJH+<)
M8U1<6FE;-:?8"1AR6/?TB2A(=^IWF4ERD64\W5XSNQA**<4M24D2`L$8YWP+
M+",,E@N2`\DP7",X/+V_^<ZCG8C:$TF&%J,VX6[Y<!D?!\<87.57HAW&P_+)
M=7_:>#44TDP;D^O^F_DP3W:<X+:]F<A^^6ID[>&V3@&FTS=#<=ZUM->J(QF?
M7[\?N^?]&)(,PQ#&W?LA^NE@GY^VXV8SWC^=EK__='A;_MO'R6_H;*WF6HB=
MQ@````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O8FQO8VLO;6]O;B]F:7)S='%U87)T97(N<&YG````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#,V,3<@,3`U,34T,S,W-#<@,#(V,30S`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````P
M````,`@#````8-P)M0```P!03%1%`/\`"`@($!`0&!@8(2$A*2DI,3$Q.3DY
M0D)"2DI*4E)26EI:8V-C:VMK<W-S>WM[A(2$C(R,E)24G)R<I:6EK:VMM;6U
MO;V]QL;&SL[.UM;6WM[>Y^?G____________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________`/\`%Y409P```0!T4DY3____________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________`%/W!R4````!8DM'1/^E!_+%````"7!(
M67,```!(````2`!&R6L^```#'$E$051(Q\667V_=1!3$?W-V[1N20!$1;0K)
M]_]@38/45N(A!-W8NV=X6-_D-DT+/"`L6Y;6.SOG_UCFWUW!?PVH+RU>97.J
MQNT+W_2E#V_V2S=*B/GTP]\!KO?KVC*1!4F93DYOO@&XWJ_9K$QC$"8\G7W\
M*N!R[TEKSV8E1MN6^=7[EP$7RTEI7IK=)*4`+$OE_.-+@(NVXSX:5N\:3F`L
M%.7)K#@ZOT;/!D(!"4[;"+S<O_X"<+&HK,LCW++M!!P0Z]W;9X`W"]'71$C"
M2+(E(%.&]>[JLTS_^B?JO2M2D(@<NY'!F-C??<:P@.02#J12:ADA,D8VQKJ_
M/&+X9:^014IA*SL2MF0+AXTB_SABV*-0D,@H$J4!R2Z@M,'L7S\Q&$JF4;%-
M24QB4'@PI0(MCPQO.JR=.-1"*(ZBR\&?)\":V`:(6N=:@^QIL`46(,#KV\VD
MZP4,!*EPR1YA2<8:)0LRQON-(7UP)-,J84N*\2`P$L@\;`QF+-;LW>4AVX@*
M$)8AC(1%._@@+"R%%'3;"K`A,1$:^RQ?#8""0,K61,\2!6L2PPS%J`XAQ\80
ME33.WBVY9928(C2B8R.$)>2;S:0`@3.=V%U%18?6$B@\&K9L#.^V/-E8IDAM
ML;98;#[:2-/!:1=R'!*5[)V2ED9`G]*`3QZC%`6GP=GHN;J(W(;&ECYAQWP`
M[*(&$H6V]%K4$S\6$^0HC=C='``W4:=:ZC378D^0"5/8QS-%TNZI'TJKU1&&
M$IDFA25I<WT@RJ<GP&VQ([0L35./XF)WZU`$2@#.CH?`M$::Q6[N(;?'JALW
MEN=/QT/@_51K&.B>S1QUFLL6)(T^BO-GH_*R!>N:VKF7'6MX7=J6/.'P^>_/
M%"C<Z^E#"ZV.+!,IP@A20)Z>/Q^5M[/7%8AYGDB9T>)C_,7)#^^^&,:_G935
MF!)I$4-3;).P^_'F!16]G6N+2BE%"2$DC]?9JYNO2-;/-D7J+O*Z](Z1I_,/
M7]7IC]]-])XY>MP@Q?<_??BF[%ZW=*K@OBZMS/69B+ZDTW!E0V^>YG?_1-C_
M[Y^3OP#`P.^JJ^O84@````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L
M;V-K+W=E871H97)D;W1C;VT`````````````````````````````````````
M`````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M,#`P(#$P-3$U-#,S-S4P(#`R-#4P,P`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,P``````
M````````````````````````````````````````,#`P-S4U(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W-3`@,#(U,C8T`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R
M9&]T8V]M+S(S>#(S+S0W+G!N9P``````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C<T-B`Q,#4Q-30S
M,S<T-R`P,C8S,C(`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!<````7"`8```#@*M2@````
M!W1)344'U`$,#@@3=#2$30````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+
M$@``"Q(!TMU^_```!7-)1$%42,>%E=MS$W44Q[_9>YI[VJ9)FMZ@*:U0RE4'
M1\=A4-`9?7+@T?%O<$1?=7Q0GWS@G1&'!Q]\\(F1%J%@RZ`(CK2E+2TIS:6Y
MIVF3W2:[FUW/+DY!@?++[&RRF_V<<[[G?'_KP$N6T6ITTVD4IOH3_7*99FO[
MGH,^<'!TL)\#[#VZ-,>P4NK)_9W!9PGZM@/:24,O0]-DZ)JR?5^4W&`8B2@B
M\?UTEJ[2Y=,4H+(CG,`!0)\RM/PKBER$W#"AJDV8A@&'PP&&Y<#Q/%AH<#E%
M"N0!PX>)Z)RDQS^T`CA>`(Y2QN?5QMJI6KT*94N#:9K84K8(RM@!6)8%+PI0
M&TVJ2$/`)R+8W@5!ZK8"6!5\_`)X[2KT\O%2)4M@U09;15IGTS203:7`"X*=
M.<<+=C##:,'G\Z"WIP>L$+$D>L_QG*SWR?7"G71J42@4JBBL.^`6FU`TZ7&`
M9@&;"@-)9*!4U^`+^A&+A>#U>J'(-42C`83#?=3GB,H])_&O_K@S(S"<'RY?
M)T9[?.`X%H:5O760WI;FLBSC_NP<5K(Y9`M)'#O:AU:KA=1J#NWM'1"XEO`,
M_.:MNVCO'"``0U#.8E&6'!CZ4I,;J%:KF!@?AU*OH58O@V?JZ(ET0VUVV97E
MUS+HW]V/D*3C/_#Q*]?VS"\L]L:'AA$(!NQ9DF4%6UL-L)3]YL8FUM<K2*[<
MQ>N'8PAT'H%+5"&0_KPHV0S)Z42U4D$H5`/S-#R93!]G.?%0E0#%?(Z:9%"F
MZ]!US:Y"4U7D<WFT.7VD\VZ$0TZ$(E%P`D_WFK:I1$FR)\A:VW!JI"B*_$"U
M6K;'3%4UK"02V-RL(9%8P>^W;B*5SF`UF48AGT9B:0$-1;:A<JT&27+"[?5!
MH`JL<06)LBU+8B4=,0W]LZ7E1U12%P5K88-D&(S'21:%@NE(90CZ<)FJR4%I
MM".;R<!;K\/K]\-/3;3ZP]-X>GT!F`[7$SC/L]]-7I^&Q^=#J52!2L9H-E7\
M/3,+B32MU66";CPV-2-20,V6J<WELI^W>M+26S3W+/P!/P5Z*O-[<\O#O;T]
M=G,:#85<9T!OD;7;)/A]+F1S.>36TK;M)7<_FKH/>_:-VB:R#*61C):9?(%V
MN-T=E`-S?5OS='H5ZY19,I7!PH-E<IL7L>XNJD!'I2H30(3?3P:)1&@T)22S
M,C+TWV:#)HGE;+@U_Z'.(&UB'DN+;VQXI5SLGIU;E/*%HMU()SWL]GB0SA2Q
M1($*Q:)MI#:7F[(S$8[&P$OMN'1UUK[.,`XRD+6!,7!Y!IJFP_D%8:_9LDS=
MO/UI(;_67RX5208W6%'$U/0TBKDL#)BVGD&:>ZNQ-%)DF`;-?QVEPAJFIV[C
M^(DW:$_IAL\?)?'%;QFV[4O8\T(K5RCK#,N:5EWY?(8,U($J0;-K26IP@"R]
M@,2R03N>"_+F!E7E18OTU70#\RMUG."CM,<,-N#@SQ']ZV=>%I<GI^>O_'EW
MF*U6,';H`&8?/,3AO2-X4$K@G;%SN#PQ@O3Z?AP;C8-W>S&_F,"9=\<V.D*1
M:X%`CR:(KC/_WTJX?PUT^OY2*CS<'4;?X0-PD!GV&_BY*R0>B?5_'PL'5\%C
M!`>'XABBK6'#<."#6`R[XH.?.)W>\R]ZX3`$=MU;3+[_UZ.,OZ<C"#/8B=\F
M?D5[T/N64OHE5$GGL?K(@ZYH&?%=4:15X,;X%<NI9T5!N(`=%D-&>;/.L!_=
MN3%ISRNKT]/J!M2M\4!?_*(P,W,*Y<IKF+[.H;E50Y7FO4U@,#JZMT2OLM9.
M<(YE&'A,#7L&8HCO[K_D=(H!]>#6L8ZN'W'AAP".OGH2LE+'O@-U#(V,71QL
MZ4>4H;Y\1\`[@9>L?P`B'':5('Y_-@````!)14Y$KD)@@@``````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,2YP;F<`````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`R,S(R(#$P-3$U-#,S-S0W(#`R-C(Q-@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````%P```!<(!@```.`JU*`````'=$E-10?4`0P-.AKBWM;!````!F)+
M1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\```$7TE$051(B>V4
M7TS;513']^BS,3%9-/+DF_'%S&0QBVX22:93V1AA,`=,H-".OX7^`80RX%=@
MA?X1*!W%%OH/VM*-CI:Q`@76`O)/RK_2T)9%Q<%@L`$MCK"OUT8P,^/!Q`=-
M/,G-R3VY]W-/ON><>^S8__:OM2I1O8K!Y)HZK?=4_PC0.3P2WFL?#(KK9$&=
MP0R'<QA:_2U0`G&PH5%1ZO7ZW_O;4(?3>=W8WDZ55U2N%/(H?%LO@U*E0ZO>
M"+E2#8&H#FF9>>"55:ZDI-*I/KN=<C@<E)WX#K.9<KL7J&?/]MX^!.[O[Q\/
M!`*37J]WLIRBGI,%BL]'=@X3>2PVF+D$5E(":8,,+!8+M-0T,-(SH%`JP>86
M@,^O`(_'"]UI:]-C??UQQ"&<O!2VL;$)A\,)-IL-@4``:U<7N<1':6DIQ&(Q
M6'DLV'IZ4%%1@<RL[)"72"0H*BI&34T-FIM;D)6=0^1SS@:"P7<.X3L[@;"9
MF5ET6BPAH%ZO1T='!X1B"<F:A3:R+RLK@\UF@T[7BH*"0JC5FM"C&9G9)*8+
M[1.2Z5A>_J7F!9U5.GT$E^BK-YJ@UFBAT6A(EKV0RYM"4*%0"*%(!)5*A?[^
M_I`$,ME-2*52Q%Y)@)+(DY&5@YA$!NID3;M;6]MG#O2.4*BTCZIK&Z'6MI*,
MS:"(YK]#N/D%T!L,X'`X*"XN1GU]/4C1"+0!=SH[P>'FXUIZ.AKE<ESZ*A&1
M<<DHH:K@]?DB#N!O7><+EB0R!1J:6I"81,/%V"LX^\4%1,;$(_YK&K@$DD9G
M@'$M'7'Q5Q$5$X?PB+,X<?(48J_2$7$N$A^?BT)2!@?E52+X_/X_"SKO7I!R
M*H6@\TB'<(N1R"S"Z7/1"/_L(J(93'!)G/U-.?+X0J3G%N+SZ'B<_.1+?!#^
M*<Y?3D$4/1<)M`PP\XMAM5H7-C<WWSV$]\^XP^2N!7Q(ST:;@>C>U0.9L@5"
M>0MB;JJ0R>:"^DZ#\R(91))::(VW42)M@D!8"T9I-9*;6T&&36%L-\4_?+AR
MXH6"NE;63XL&1U$DKO591J>?YXKJX5[PP#SK16*#`M/N!4P]^`ECQ/N(KS99
MT'&W.S`V,;V<:[&C[O:=S=W=W0LOG<K[_I_GM?=Z,3(RUIS=[=A+JZK&HF\)
MEI$)#(R,8L#E09*R%=WWG3`X)G&I68^^H>%EY[C+JK79]Z9<KLLO!:^L;S+R
MAUP[B9Q"#(Q.@-ENA<YHA'5\&BE*/>[:^E#5/81X(L/$E.O7:DL_<A4M\"SZ
M<,/2ATJM/GCD7R*9\-2D&CI14D;Y`X&@B4RKZ?'&$T_YX`32;X@P-^=&X_`D
M#+UV+"TMG=G:WC8%@[L/3#U.)*C;T3<Y=33<M;I18QO_84VA4)PZB$VZ/.];
MYA9_-'=V.;>VMF@;3Y_2R-]#(VW[^A_M^]'(]/P3P]#W\/C\E4?"R<%7]_;V
MWOAK?'7UT7%2^=>.NK>VMOZFW[\41LZ]<B3\/VF_`85M(5O3ZNG5`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE
M<F1O=&-O;2\R,W@R,R\R+G!N9P``````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(S,C<@,3`U,34T
M,S,W-#<@,#(V,C(T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````7````%P@&````X"K4H```
M``=T24U%!]0!#`X!.`E*QD0````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``
M"Q(```L2`=+=?OP```1D241!5$B)[91=3)I7&,=[N>MER9)FR[S:W;*;I4N:
M9<WJS$PVM[2V.JVM'[6*WZT**FH51%Y$*@(3$)6"@BB@1*F@%K\+U?HUF5IA
M!;3;7+6BMBJX&OO?*YDN7>K%DEULR9Z;D_<YY_F=__M\G!,G_K=_K?$$4E5&
M+MW09;ZK^D>`MM$'(?V#(WZ11.9OU=^!U3:*%ET'.+>$_MIZ!<OE\GSTMZ%6
MFZVLK;V=8%=P5XH9!&HD=5"J--#JV]&@5(,G$",UBP9&.7<E.26-&!@8(&PV
M&S$T-$08C4;"X7`2+U[LO7\$W-_?/^GS^:9=+M<TFR!>LMD$"(*#[)Q<T/+R
MD4LE8<PR2&MEY'<>DBDI2,_(@D*A1#Z]"!45%6`RF60,`9U.#Z]W/?0(3MX4
MM+&Q":O5!AJ-!AZ/!W-W-S@<#E@L%H1"8<!OZ>L#AP1EW<@.[!WX2TI*P:^N
M1E-3$VYDY^">S3;G\_L_.(+O[/B"9F?GT-5E"@1IM5IT=G9"(/P..=0\:'4Z
ME)>7PV*QH*6U%85%Q5"KFR$2B0(7M;2TH+FY&?%):5A>_I7_2IY5&FTHO;0<
M>D,'U,T:\J"&5#D`N?PV"65#(!"B6B"`2J4"F5N4,AB0R>H@D4H1'7,EH#HK
MFXJHA'2(9?+=K:WMX,-\ARI4FJ?\&ED`?*#X0/W0\##HA470Z_4H**"CM)0!
ML42"3J,14FDM3"938#\S,POU]0V(CDW$^9@D,(E*N-SNT$/X>V6<6XO"6B6D
M#4U(N$9!Q*58G(N(0MC%*XA+I(!.+T1:6CHR,C(1$W<5%R*C$!+Z)4Z=/H-+
M5U,1&G8>GW\5CL3,?+!Y`K@]GC\+^G#!(2W@"I#&J$`VG8'XW)LX^W4D@L,B
M$)%.!9W)07XQ"S1.-3*I-_%-9!Q.?W$.GX2$(?QR,BZF41%/R4(.O11FL]FQ
MN;GYX1%\:'8AJ,'NP)F4ZV0_&Z#N[D.ML@G\^D9\6Z?&]?PB$+<U"!?602"J
M@::M`TSI;515BY'.XB.IL15"L4RAT[?%/7FR<NJ5@MI7O&<%(^,H$8G=IG'[
M2YI0`H?3">.<"PFU"M@7')A9^AD3Y.HFURJ#"<:>7M_$U.PRU30$<<>=S=W=
MW0NOG<I[GE\>:N[V8VQLHC&[U[J7RJW"C^Y%F,8F,3SV`,-V)ZXIM>@EYT!O
MG49THPZ#]T>7K9,SYF;+\-Z,W7[YM>`5[V9ZX7W[3CSYZ\/C4\AM-Z-%WX:>
MB3E02&"/I1^5O5;$2N68G+'_5D4JS56HX'SD1J5I$%R-UG_L6R*:<O)3]%U@
MEG,\/I_?0$ZK87WCF9,],H5,GA#S\PNH'YV&OG\0'H\G>&M[V^#W[RX9^FR(
M5[=C8'KF>+A]=8-OF?Q^32Z7?WKHF[8[/S;-/_K)V-5MV]K:HFP\?TXAWQX*
MV;9O_]&^GXW]L/"L;70<3L\B]U@X>?#-O;V]=_[J7UU]>I*L_%O'Q:VM>=]=
M>OPXR+N^_L:Q\/^D_0[N12%V*;V\U0````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S,N<&YG````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,C,P,"`Q,#4Q-30S,S<T-R`P,C8R,30`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!<````7"`8```#@*M2@````!W1)344'U`$,#@4KZ9A"G@````9B
M2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_```!$U)1$%42,?5
MU<MO&W40!_#O[F_7NYO8<>QDLZGMA,0I[B-!21&EJ*JJ1JK@4-0B(8&JJAS@
MB'J@A7^`&Q)23Y0#0G!#5(4#4LLC1`H54M-6:IRTM(T;.XD=O^UXWR][;4X<
M2N,6B0O\KB-]-)KYS0SP?WW4TX+)Y60D$`B=<)JM\^5J#2S'PK,M@*+@8UE0
MA('`^R`-2?`QY$:I7/IX(!S>DB2I]52\7"X?>IA:N]+JT+&^_B!Z!`$,0T!U
M@':G#9HFL!T;CN.B6"Q!E>MX;B2*O8G$^Z(H7@(`IAM^9VGIC=[@0"S`\V`)
M`<O0H`D!2P@TW8"BRKA]\P8LT\!V0T&KU4:KV<)$/'X.0'<\G4X?O7OOX8=M
M544X%`0H`DVW`'3`,@P:VPT42P6D5E/8MS>!Z+#8I@ES/3X^!H'GLG\Y.^)?
M?O4U+4H1)AJ-H;B51V1T%)JF0Q`X\!P'V[&ARAIBL5TX<_KM!4$0K@J"\.G?
M'7HG_-3)4Y\U&C((R\!I=Y`OE%&L5%$J5)!.9V"8)C9R6[`L"Y[G+>X$=\77
M-S;BN:T"&K("6=:065]'J,\/M^4BFR_A]NUEI%97X;HM$$*Z_K8GRF)9UH73
M[[S+BE($MNW`T$W8KHO55!HT1<%T;,B*"@H4:M5M>)[7%7\B\V\O?W\D%):(
M)`W#,$Q4JG54*W68A@F:HE#,EZ$TMD$1'VK;=5R]]F-4U[6^?X0OWEK"@"BB
M5JWCT:,,*)K"Z&@4/I8%H6D$_#WH``@&^T`1#LLK]\XN+%Q_\9GXW/R\+Y-9
M8U,/[L.T+;3;'O;MV8UFT\7&9@[KV1P(PT`<$L'Q//K[0\@6JUA:^>/BW/Q\
M;U?<LJQ>UVU>XGGVA&T[T%45AJ;A_H-5)),K*!6R,$T37MM#J]D$0R@,24,0
M>GKP\R]S,UN%TH+G>;MW;"C#,"(Z>*_14%"I5.#C./3V^J'(VR@6\N!X#IJF
M@6$9.+8%FB8`18-F&%`4C:7DRDO[]SQ_',#:$XO+\SRRN9F[,/?KPB>_-1KH
M;*XC%AR$.12&OU%'LYV#*-[$@Z0&8_@LH@R-<%\8-1^+H%Q;VS,^KL_.'E,C
MD<A;A)#R8YD30CQ=-]7I`S-@2D5,''X%Q78'D1X>6C4-,?0%8D-E?%Z6$)B8
MP.ST#+*&`=8R%W>/'#TS.3F5Z5ISVW:&,^NY#WZORX@-#L#T@*2JPU)J&.R[
M#%TQ<&<EA(DQ!V&T491-+"DZ+$-?V`E^#%^\E>17LOE$OEZ#R'-0W";X:AYJ
M[1L$A)_PP[67T:2/8WDM@H'^$*JV`;'E*+-'#M]_YH3V^_UH^7R8#0H8&QL]
M)ZMW7U?=ZZ]-[/\.\S=&</#0F_#X8<P<E*VI%R;/;Q;+('1O39*D*\_$1T9W
M;?E5;9RB.FBZ[J:A*;[I*>-8OC#+B8,G"_'XU*L.Q1B!:+R=2"2R__H&RG+C
MH_1:ZF*M5COPGSO0?P+1M/T3AC>"]`````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H
M97)D;W1C;VTO,C-X,C,O-"YP;F<`````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,C<R(#$P-3$U
M-#,S-S0W(#`R-C(R-0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````%P```!<(!@```.`JU*``
M```'=$E-10?4`0P.""8BAT!N````!F)+1T0`_P#_`/^@O:>3````"7!(67,`
M``L2```+$@'2W7[\```$1TE$051(Q]65RV\;51C%S[QL)['K^!6[MI.T3G"K
M)E531*F@J"*HHHNB%@FI4D'=P!)U00O_`#LDI*XH"X1@AXJ*A)!:'B%26A!)
M2TGLM$J"8^=A.X['[\>,QY[Q@\]&+$KC!HD-C'3ED4?W=\\]Y_ON!?ZO#_.D
MCX%@P&TR6<[4M/IE,9V&H-.AH2J=:3I!`,/QZ#4(<`XXP?/\K"@FW[=9K7&G
MTUE_(EP4Q>,KH?"->HOQ[NGO1X_!`('G.Q,:K18XCH.B5%%3:TAN;Z-4R&%X
MT(.#?O_;#H?C6IO!=X//+RR\:C3;O":"\@0B97\.CD59KB"?*^#>W5]0J<C(
MYXNHUYNH:PV,^'R7:'IW>"02.?G@X<J[S5()@_UF,`P+698[W]H+%/)Y;"<2
M"/T>PJ&#!^!U.9HLQ]_Q[1^F'>JC?W%VA'_ZV>>LW;F7]WB\$`GB]@Y"DF08
M:!<&O1[5:A7%8AE>[UZ\?N'\3$]/STT:'_Z=P^X$/W?VW$<%VJH@\%`;36QM
MBT@FTZ0VB7`D0E94$(UMH:HH:#0:<SN!N\+7-S9\L7@"N4()^4(1:^OK,)N-
M4.L:XELB[MT/DB7+%&:]$VRWYS%;%$6Y<N'BFX+#Y4:M6H,L50BB864U`I9A
M2&T5!5JTK2N3SK65=X4_IOS+ZU^_8+$[.9?3!8FJ(IW.(I7*0*%%6"K$1$+L
M!,IP`C*Y+&[>^M8C2>4]_P@^>_\WV.QVI#)YK*ZN@6%9#`UY.OZS]&XR]E%W
M,&03\3@=@HL/+\[,W'EZ5_C4]+1N+;(JA):7.J$UFPT</#`"35.QL1G'9C0&
M3N`PX+!2Y?3`:K$BMIW&0G#I*LWMZPHGK_M45;UF,`AGJFVORP4:92PMAQ`(
M+"*5B$)I+T@>:S65@F3@&!@`50J^_V%J(IY(SI#_HSL&2LWA0(MYJ]UMHIB"
MGFK::#)1>%DDJ=;U!CW*Y1(I%SJA<M2IY!FH>>B'P4(@^,RA`T^=(E3XL8.+
M5N4V-V-7IGZ\_<'M7`ZMZ!H\%CL4NPVF?!9:*P:[_2Z6`V7(KHOP\"RL9ALR
ME(6YD`G[]^^37IJ<++G=[O-4GN(CRNF/AB152A-')\`G$Q@]\1P2S18\O3I(
MJ778K)_`.R#BXY03)M\()H],($8V\55Y;M1S\HVQL?&UKG5./KM"JQOO_)S-
M8YS4RK4F`N2Y10,IO`ZI*&,^:<'(<`UU-+%=J&!>*>.P5IG9"?Q(H'._+A@6
MHW%_/)N!@_PMJBH,Z2V4,E_`U/,=OKGU+#3V%()A-VS]%J2J,AQ:K3AYXOFE
M73NTW]B+ND[`I+D7^_8-72J6'KQ24G\Z/7+H*TS/#N'8\=?0TKMP]%A1&3\\
M=CE,YXV>[<O0Q7!C5_C@H#=N+)7W,TP+FJIN2N6B[LB8].)68E+OL)]-^'SC
M+]-)(AN]HTV_WQ_]UW=@H9!_+Q(.7<UD,D?_<Q?T'VJ\^9(;T?Y@`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\U+G!N9P``
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#(S-S0@,3`U,34T,S,W-#<@,#(V,C,Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````7````%P@&````X"K4H`````=T24U%!]0!#`X(.:^/39L````&
M8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP```2)241!5$C'
MW95)3!MG%,=SBJJF!PX]]1!QZ[&W1,JA2D5516I516V:2+2!!`+%90D0S&*"
MC=EL@K$]-HOQ-C9>,(M9;%.,"9C5QI6-L4T**02Q"(Q!JD"$I2SZ]X-641#J
M$K6GC/3I&WWSYO?>_-\R%RZ\]9>8JKF<\C`WVN7Q7OY?@)N;F^^N12(I`JD\
MI9JJV^4+:]#CZ-]5TOJ4N=FY#_\3?'#852>1-Z)!K4-W[P"\_DDX1]RHI.2@
MZI4^4ZLYZHVADX%`E*A.<3V363!K(]#)8`AMUEYT_O@4FF8+.NT#B&?DX&9L
MTCZ;6Z;EEO$__M?P"?^DEEU>!7U+!_J'7+`Z!E$LD(%53L%LL<,Y.HZT/"X^
MOY.(3[[X!G?N)AS.O9B_^X_@X^/CJ.'1L?W22A&!>.`8=$%E[`!?JH;:V`Z/
MUP]Q@Q8)&040R_60*`Q(SF01Z;2;X?!:PJC+\_XYJ$[?]%X)3WBOL]ONJQ;7
MP&BVHM7J@-YL@U#6B*S'?)0*9>"2+WCPD(4:I1X^?Q#^0`BVOB'4*#2GN5'I
M3*MRA>K*&;@_$)0QV3SPJ`:8VFV0ZUK18NG%D.LG2%5&Q#%R(2).ZC3-,+99
M$)IZAMG960P0B4Q==O3TCZ"%[(P<#BJJA,]75E8_.@7O[NY6E%<*COD2):1*
M`\8\OE-#FV,(S9T]*.11*"*K;W`,P:F?$0A.P=X_#'V;#<SB*K#*A!@;]Y%W
MC;B=D`YF(1M>K_?&*7QA84$4GYP*2JZ#J:.;Z#J).MJ$TFH9?F!R45VK1NC9
M-*9GGI.(I]!-9*@0RQ&?FH\;M^XC.9L-=F4-DC(+B3T'N8^+,>'W_P%_N;U=
M04EKC[,+.*A5Z7!2V_FE0MRZEX;/OHK#]UF%,!`I:'TS5/J6TQS<3\_'IS>_
M0\R7L<C(Y8!95`$FNQR)C`PT*%3[:VMK,:\T7PZOR21F"QH[+'A2)4`>\9[!
M+$"10`PF58?4C"R4\*J0^HB%V/@DY!?S\2`U&XR,'.+4!$-3,SC%)5"JZ2VB
M=]R9A&I[G-$"VH!ZI8I$3R.7&'I]/K1/SB"!+X9*34.K-X+6ZH@-#?7(.+KL
M?1@<&D8)K0-56P^'HP_A<'CZ7"G.;+YT.2<"L!.#1)D6MTE$:HT6D@8%^-5B
M#+@]2!=0,+2VH://B<1*(6B=#HTD8BG="+?;C8F)B=SM[>VS=?YBX]>8`N_T
M>B*+@ZZG3J209')*RTGVM6!*ZB$0BE!"VOYKG@BC+C<D>C/X"C4,QB8\(CU!
M-;4>[N_O\W9V=JZ>BUHSLR1B](XB.X]U%/IEKF!Z<7EK?-QSF%;^!+'YA1!3
M$B23BN&J-(A$UG_K[7?"'PS"W-6%3)(338MY[R];WCZ_*JIOM^S06GW*J^$U
M-<-KLM@@)5I:K;83+6U[>WL=1T='5\@]+!8+%$1_!IL+?VAJX._FR;7#P\-O
M7S\[.#BXNK*RLKRXN(BEI24EV2_^:7MQ8V-#>=*=\_/S"(5"('/_^AN/7@+Z
M@#B))NO2Z^?KZ^N7MK:VH@DT.A*)G#Q_Y^WZ[_X.LS51]1?]Q7X`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T
M:&5R9&]T8V]M+S(S>#(S+S8N<&YG````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C,U,2`Q,#4Q
M-30S,S<T-R`P,C8R,C4`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!<````7"`8```#@*M2@
M````!W1)344'U`$,#@D/>2[I0P````9B2T=$`/\`_P#_H+VGDP````EP2%ES
M```+$@``"Q(!TMU^_```!'9)1$%42,?EE.M/FV48QO=-/VHRL\4O[@\P,7X9
M1HUS4P?&R=R8([(!8S#M!BNX#`H;XUBDE$$9A[9`@;U`2^F)0J&4MIQ**8=2
M6@ZEA:Z(*U`J)8`&.4AV^5#CDF6)NN@G?9([[_,^>?.[G_>^KOL^=.@_O<IY
M@M<8:>G'J,:F8W:[_:5_!3KG<EV@A!(:I[S27,ZK@K!9CE)N=8%M<O+C?P0V
MF$8BJRGQ1JU(#I5&#XO5AG[3*'BU0C#9G,6^?D.+U^M]Y87!'1I]0ED5]2O_
MH1C2-@VH9B4DRD[(R+Z[?Q!":2LBO[F%[#SVCE@BHS)SF'\_"8O#W:X5RJ#6
M]6%PV`RUOA\BN0K]1A-Z#284EM>`SLC&)9+@S/D(I&<QJ3\%>KTKAZMKJ*,$
MQLW*+WXB;]>AJ]>(ULX>U`@5).30]QG!K6E$+/TNR@1"M&FZR;,1J5D%3P:,
M)FY22L91M_O[P\_!=3U]#IZ`0@FW)E`*H4P%18<V`$E@,)%T-Q\YA5S$IV2C
MODD&N\.)Z1D'.KL-D+1JD)-?#$9F/E1J[?+6UM;QI^#1,4M4;F'99D5=$V0J
M#9H5[6A2=&#$8L5#L1+1-Y)QOTP`;>]`H.83TW82,VCOZD%))85NPV#@K]*8
MQ8B^=@.34_;9O;V]MP+PI-1,SL%'#ZH:8+;8T-*A0ZVH!<4\"K?O%:!>W$+.
MK8';CD],H5ZJ`I/#1VS2G4!B0:,,F:S2P/YT:!BJJJNQL+`0$H!W=FDY]_**
M0!P"I5J'_%(!$E)R$'Z5CNO)F=#V#$!';MU.+*DB=;Z=P4)8U'6<#(W`ES$W
MD9#*Q%>QB8A-8.#3<^'@\?F8GY__';ZQL?G&B,4VG<A^@#A2MY"SX7COU&<X
M?B($[UZ.Q<6OXW$^/!+GPB_CBVMT!%^A(>B#TWCG1#""HFEX/_\!3@9_CM"P
MBXB*OH(6I7+'[U_[*`#W[>Z][5G?N%FUO(9+ZAZPBHJ)KUM1)U?@$\,X(EE%
MX(FEJ)/(<'7(AM,E?"(@"WG<:J3P!;A068=O<[^#1*V!7J]O(\T5]510VMH>
MIV+)#_/$)`0-C9`,C2+-]S,TI,XJXNUR`?&U>P6YIC'TC(RBDJ(@M4[ADG,1
M4E4'\;X!\<['H,G;8;5:2Y^Q8;+S!TY,127J%2VP+J]@8LF+>+T1Z44<.'RK
MF/8LH6K(##K[/NQ.)Z;\ZS#/+R"AK@$UHB88EGW@MZK!8+%!!EO',W#BRS,6
MBX5;_W@%9P>M:!")#@3!M',6;-\F(DC[&X>&L;BXB-7M'01;9I%1+X3;[8:1
M)#XUN8!LHM<CMUOC]_M??:Z)]H&7G;_LL!7F\6WIX/#N'9<'M:TJV%9^W!?I
MNK<+)QPH(5YVNEQ0SS[:;NCMW\^8<:.Y2XLNQ]RN:7AT>W/SI[B_G"V7/>MO
MQHW9YWAB"5'=3S\X2YSWJF\I5!@:'E8?O&LWM^@Q-M>.4-D&E\OUX0M-1@(-
M(O%4]:6EI2.D+#2/QW/DCS.?SQ>UNKI*(]WX^@O!_]_K-ZO,02C,Z.%W````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O-RYP;F<`
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`R-#<R(#$P-3$U-#,S-S4P(#`R-C(R-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````%P```!<(!@```.`JU*`````'=$E-10?4`0P."2VL3JBG````
M!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\```$QTE$051(
MQ]V574R35QS&O=^6>#$7HXF2[&)9LF0FNW%+MB5N;+H)V\2,!84A:*A:76%V
MM"*@I:VE6-O2EO+VA7Z\_2YMWT);2J%\.2B"?/A1:;`4)<.I*%@U4P<;SUY9
MMLSIO#"[\B0G)SD7O_,__^<YSUFQXH4>(R.CJWXX(DCCE1]+NS(]O>Y_@<[/
MSV^/=/6R;$[W&85&!Y661*2KY[[)YF(M+"R\\=S@NW?OYIH=[I3)[D&3MQG=
M/;T(AL)P>OTHK3R.HP+QR.1DDKX0NTC?NW>/GIZ>IJ>F+M.SL[.O/1,<BT^P
M+0[/HE)'P=W2"H>G!04U6KRN]&&?6(G5VA:L-/?BS8(2K)=9(+#[\*XN`([9
M`Z_7F_9,.&5S/E"39OC;NM`?/8V>OB@X"A+I>C^VE)W$1Z80-K#+\0ZK%.E*
M"S(49FRA0B#<S9B8F'@2/C<W]RIEL:Y.)*?JJJ2*)0?=BO:>?OC#W3`Y?>!*
MU2BV!)`OJ@6;=.'K7?M0K2)1;?2@YG0"!^4$U'7UM:KZQG5S\_.O/`;OZQ^(
MDT8KI,IZN/UA4*X6-#.5$^8F'*ZJ02&'CSI/&-\+9="U=.*H1`:"LL)`61`8
MNX2<@KVH$,E06B%&;U\TS`B^=AE\[MSY/*%4?D>CM\/F"<(3:(>!Z>/@R%GX
M0IW@'!8A>S<;[D`(7-X1=/P813?3+JE2A:KC4G1%!U'"KX"KN0T%!WBH4:AQ
M??;FYF4XI[1"KB1,D&F-B`Z.(!CI@=[NA8YR@ELI02UA@+Q6#4)'0B@2PV:W
M@R1)L`YRL;^$#ZO-@>S<`A2756'GG@,02DY@,CGU)]P?ZI#S!1(HZHWPM4:8
M0_0XR!<BMZ@8.XI*X*(#<#1Y(9,K8++:EZOE\LJ0]4T>OLC.AU!<C4QFS2WB
M8`^[&$2#'M>N7]_\EZ?7#PV/QHX1#FS:4X[/M^4@ZUL6WD_/1$9.(3)X6GR6
MM1,<_C%LW2_`IQE9R,K)Q\:/,_%A>@:*&.#V76SL+&3=)\B&V[%8S,`P5_XM
MJ'MJ(8WK'L57^\J@J=/B[/D+S'5M:/1UX(.J9E3+58C$;^*32CM"H39T]`]#
MJM"@N[L;%RZ.,X*7PDO[&ACH2T]8,75_H99L.<7T6`R13(T:91W<'B\(3PB9
M>WDX-30*1U]LV983/]]&D>T<2+,#`P,#<-/-X!TNA\/I0C@<?MSGJ8=+:X_W
MW;Y\2-T$B]V)W3PQMF;G0:LWXX1W`*2!@LW?CN_DYF7K4?U)O'V`0*U6!ZY0
M#O%)#6B:3B42E\8F)Q-K'H/W_/2[?%/CY67Q3H_%P!:I0)"-X!LBV'C(@/*C
M51`Q(DOK#=`;C*BW^E!268WV4P/85A=%8273LDB$?NISUXP]E'\I,$(BK?GM
MQHT;_)F9F3O7;LX]V.^[LK1Y!PLFB@)A,*&A40^7RP6!4(A@:RL&IU/8P'/"
MY`[\.CX^_M93X:E42M[9V?E+,!AD_7._+1P>>U2I2JV&1%(-RFR&T61"N+T=
MR61RA,F1AT:C$4PB=OUG4"TM+;VWN+BXX]_[3'QN9R8K'H^?>52U6J.![*0<
M9HL5\?AX_JU;M_(8,(O)DC7/G>W,X:L&AX:&F]SN>"*1&+8[G&E7K\Z\_.+^
MO7\`<;IE0W%DWZ8`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A
M=&AE<F1O=&-O;2\R,W@R,R\X+G!N9P``````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(Q-C`@,3`U
M,34T,S,W-3`@,#(V,C$W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````7````%P@&````X"K4
MH`````=T24U%!]0!#`X*`UNU]JL````&8DM'1`#_`/\`_Z"]IY,````)<$A9
M<P``"Q(```L2`=+=?OP```/]241!5$C'[91=3)M5&,>7J/'*9$83O3*[,_%B
M6>)'=F-23=0MCAAOW!(U86YJ59(9.@,3-V"B3;"EE`7*^DU+^_9#U@]H*6N@
M@Z[TBPK=1@.RIH!(6?F0[T(I_'W>-[:)4=-=:N)S<][SY+R_\S__YSGGT*'_
MXU\9.SL[@E@L9DLFD[:%A04;&R,C([9X/&X;'Q^W93(9F]_OMTU,3+SUMX!\
M/O_*^OHZ;W%QD4<`7CJ=YD;ZD4>`_A>,M_!)8PO>T/?B&64O7JR7XJA(BW?:
M#'A/:<6;S1JH5"K^7\"Y7.[4ZNKJ4B*10"`0P.#@($*A$-AY*I5",!A$F2.$
MURJJ4&8/XN6S7^#5JN]PLD:(4WH/R@PW<490C7`X[-G>WJXL@O?W]Q_/9K/R
MF9D9>+U>Z/5Z:#0:='5U@8X*.BH&AX;0X(W@M*`&W_3X\6'Y6>@8,ZXI-:CM
M'<8%C17\"U_"X_%@;FYNBL0^4;#C!-F!R<E)#M[9V0FE4L6-#H<#T6@4GKX^
MF`(_X>.+E\#<"N-]@HO:Y/BJ^FLH'!Y4U-1!I]-A8&``T]/3V-W=E13AFYN;
M8)7[?#YT='2@J:D)$DDSZR'<;C<Z='K<]`_C//\S,'8GG.Y>J(QF?/IY!;0&
M!@U"(60R&9Q.)W?2(IQL>9K@-M;;_OY^3K%"H8!6JX75:N74L!NP\\I*`7X0
MB2!M:2%8.QH;&U%5506CT8CV]G9$(A%00X`$%^$G:"=05V!L;(RSQF0RP6`P
MP&PVP^5RH;N[&W*Y'$)2*)%(.*A`<!%JM1JU=75HHAQK"]L,Y#G(\R+\,$TT
M*RLK^]2W7%%:KRO1UB;C++)8+-QQ%52'YI9K8!@&M;5U:&UMA=UN1ZOL.NJO
M?LO]QXHCD?ND_/L_M2.I%Z^MK3'SZ86YLBLJ:/1&MA4]Y"%#Q6;Z0G'O5;D)
M`SZ?E\U-34TQL3OCGIH.#\X++N?)#H;L95C./][&I=7-U[N&XKG[R22VLSO'
M"GG'T*AE9.P>EI>7CQ=RB=G,,5\\"5\@G"UYS;.Y_%-7S,$;C+WW@)0TD&6/
M_F%=^P?2G@.MY09^6ULOPJ,_SR?$G2[8'<YW2[\AN3V^R'T7"IT)L[.SU47+
M<GN,RQ_[-1`8%E)]GBOD;:')M$!J@$@LYI6$_Y)9X2?NSR`<B;Y-_G.07/[@
MD8:>A*51_>,:%:N\N/;!\F.3,^F%T3MW#=2"ATO"C]<[^*<O-2,2C?H*N;W\
M0;DZD()4K<?&QD9=(7]O]H'FC-B!C\Z=$Y8$LV$.3O'M7C_FY^>+</+[^<S2
M,I]N,)^^7RKD4TOK&H=_%/[;MQ\.SCXX5,@C])`]6VHM>[/)IB-;6UM//A3\
M/Q6_`VVM+6<D3TRB`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+SDN<&YG
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,38R-B`Q,#4Q-30S,S<U,"`P,C8R,C8`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!<````7"`8```#@*M2@````!W1)344'U`$,#@H4V&9S;```
M``9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_````R-)1$%4
M2,?M54U,$U$0GG:W?[2II:WI'UAK0\I/-"2&F\&#&@]$CQHOQ&N/QAB-1T_&
M1&/DXL&#\>!!!(ER,$+1F!B1&()26RV68B&HE;;;=EL*VW:=>70;(`0]&R=Y
MW;?S9K[YYF=?`?[+/R4J95,NET_A>B0(`A2+1:;3:#2@U^N!XSBVF(-*!;(L
MP_KZ.JRMK4&E4F%G)I.)G@-&H_$Q[J>V@"-@=&%AH3T>CT,JE6*@-IL-/!X/
MVV^6:K4*HBA"+I=CB\@0$8?#`5U=76F[W7X>`XVJR1BC7UI=7?41$Y5*#3S/
M,X:2)`'J&6"M5F-L":A0*+``.IT.+!8+6[0G&\S>AF?'R(>G'TS3C6`ZBHYO
MC!4!$0BE72J5F",%(U`*7"?%[$A7+RWS)=L&N%JM?H`.9R@(&5(0`M!JM2P+
M/&^4AAS)AIX4E!8!DJW3Z619*/WAZV7,(*!$3;%:K<R96"CEH7T^GV_46V%&
MC:4]V1`A`B6=(@IX!QX8*;K!8&`.5&MB3*7`"=APK`-24"6P(D2,_$FGZ%E#
MT?$Y1DZ8S68!4Y,^?1?@VZ\5\/O]A4`@('B]7F%/LUV<6?P)V6)1;FUM%=QN
MM^!RN0JRU@BO(S'`=\GG\PE8EED$O[WCX(MBZ>+`:*CR<&A(3B02W8I^-AR[
M_';JO9Q,)D<47?QKTOOB0VSFZJT[<CJ=?K(=B]^NF)J.2%Z^"IT=W8/()EEO
M8O#^R-BUQ502_";#=<768C5?R$7"E7,GCTN8]<!V+/7F%TFJ].<X_L9P:(*;
MB\6F<78S]<;U>FQFK==B_H%E*BKVJ6SA['CXR^'YI<4JEG5B5^8(WG30;=-9
M3_<E`VUMDXH^')F'HH:#_4['W9Z>GEE%WVPR0%]WY^2!EI;QG4J\A?GPFQFX
M%WH)V6QV'AO[:F/T:B>65H2C@V,AB$:CC?'`^;[R[-U'ZUPVXRZ*XM!.X%N8
M&_3XT0@9<!UJ;^@X3CV6+X@W?4[3$:?#\3D8#-;OHG*)DR5Y+\_MP]Y8=KT5
M2?!NZ<1;L1=G=AEG^^F?KE3\L/KQ"F@B6^S/\O\_F;^2W[$YEK:%FEIM````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S
M+VYA+G!N9P`````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,C(P,"`Q,#4Q-30S,S<U,"`P,C8T-#$`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!<````7"`8```#@*M2@````!W1)344'U`$,#@HI
M@`X_?0````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_```
M!`U)1$%42,>M54E+HUD435%=FP*A&FQL>A5PI>#"A1APX4YZFUJYD<)::*`W
M(HJB/R"X$"6"43?.L_)IQ%EQUG*,\SQ/X)C$*6K4V^<\.E*TD;;!#SZ^X;UW
M[KWGG/N>3O?&:W-S\\O.SLZ?^_O[7W3O??7W]QL&!@9D<'#0\"Z`,S,S?QP?
M'_N+R&_CX^/&RLI*:6EI,?+[^OK:?WEY6>_Q>'[]3Z"+BPL_W*;+RTN]]]_4
MU)1]965E^.'A8?SL[$Q:6UME>WM;'A\?QT]/3X='1D8$8V;.Y;JKJRL3@OJ]
M`-_=W=4O+B[*Z.CHC\G)R4]/3T\Q`'*"!CDZ.I*]O3T9'AX6!!2`R/S\O'1W
M=POFF>UV^Z<?N.;FYH0X+\#7UM8^V&RVK^WM[2>@P`U`#P$;&AJDIJ9&ZNKJ
M)#<W5XJ*BF1H:$CJZ^N]@3RHSDW*`+[B=KM_?Y4>9*0A<^GKZU.@Q<7%"JBC
MHT/:VMK4[0W4T],CX)TZ")):<#J=H:]QKMW<W-@1V3DV-B86BT7*R\L5%?R>
MF)@0!N43#$AO;Z^4E95)55652@*<.['V^\;&AK\O6I9@-Y:FJ,C/SU<9$XQ"
M,@!!:4?24EU=K3@G3=!)T`=J;'5U=>D%^.WM[3=RS(PR,S,E+2U-(B,CA8Z(
MC8T53=,D.SM;2DI*I+"P4(*#@X4\0R<U1JHX=WU]_=O/=!C@9P.ZSPC.!.]2
M6EHJR<G)$A(2(@D)"1(5%:5`$Q,3%5A<7)Q$1$1(?'R\='9V2FUMK<S.S@K7
M(W,CA#805P=0539+I/H4C&*EIJ9*3$R,RCHP,%"RLK(D*2E):1`>'B[1T=$2
M%A8F34U-S_31MJ2TL;%1B*MSN5P.1'/`JRXOEWEY>0K<9#))3DZ.!`0$2$I*
MBJ2GIZOQH*`@-18:&BH9&1GJ'P'I,(CN@C4=Q'VF!VW,#A,V$L6T6JWJ21'-
M9K/Z9E7DF?9$,JI"@L.&`I?(W=T=FTKOR]^6KJXNQ6E!08$JCP*Q7.K`CEQ8
M6%!NFIZ>%C2:T%VDY!^?*ZLZ'`[+"W`X1<-VNG=R<J*RHH`L]=\^)RBK^1F8
M`;E5P(IV5*#Y;"3L=N'GY^>K5-Y;/BMA5K0H`=F5S<W-RGX4DSHQ&"C17FU[
M["4?`/H5$T\J*BK4(K:VEV?2Q&ZD>`S&_ZR0\R@D+&F#XS[Z!#\X.-"S;`+C
MW8:M5$-`)S-D!S(0@9@M&D6!HRN=]_?W&JJQ,3CF6>'OS[[:WP_<FO`T@1J5
M`:JP4V2ZB%JP%T@!]A`5$-]VSH,N']$C5F[-&-._Z22"2!I.(@L.!SW<8B0M
M2TM++MH-P2RHYIEG'!*?L87H4<DO__O(@Z`&\HV`CG<_H)&I86MK2PX/#_]Z
MZYJ_`83H3*%#H?J#`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L
M;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,3`N<&YG````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R
M,C<T(#$P-3$U-#,S-S4P(#`R-C(W-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````%P```!<(
M!@```.`JU*`````'=$E-10?4`0P--QW)%#TO````!F)+1T0`_P#_`/^@O:>3
M````"7!(67,```L2```+$@'2W7[\```$24E$051(Q^V374S:9Q3&>[WL8M=+
MEIDV:;*+KKW:DFW9VM4L+NU%FS:IIFJ5;?+7JE70JE695J=H503\`.5+$$%!
MP"\4/R<JBM*)HJ#&#]`.II7*9A6TSF?_WKAUK<VR[;)/\N9-SON>WSE/3LZ)
M$V_T7\3F5D7?H:<1>D-/]/\"=+I<[\PZYK3%+*Z6)ZK?5ZHTD"G5^\5E'*UQ
M:.3+?PVV.QPGF[1ML\4</AIU>LA;]6"K6J`B[]!\-D*2L_8EFC9_T\B$O\<T
M1E<.C_OGG2[_[N[N^Z\%Z[O[3\H4ZM$2;@WDZC9H.WH0PZK!AU5-N)J>BU.2
M3IRJ5.&#\`2<+96`PBS'QW4=D+5WP>5R!;T67L2JO%I05@5]SX\8,IDQ-OX0
M3%DC(L0JA#&*<*-"BO.AT0@._08W6;4@=`.(Y,IA'#;]NKW]]+V7@'Z__^VI
M:5M4G:PA2J'2[%?4UD&K[X6FW8`::2,R'G"0(U6`R,I!2GD-PBCQJ!!(P5-J
MH+`OXE9,/,HXE9*LG/PHK]?[T0MP@406Q!-*42V20]*@1EVC#DVZ3K09^E'&
MKT-<:A:$BD90XY.@;&D#3R`&I[(:U35"](V:023244D6H]W+0W-+Q_S>WO[9
M([A:UV$I8O-1)6Y`[Z`)]:I6=/89T3TP@N=Q:@(-`J$8M-1TC(Z9,3$^CIR\
M0F0P\J%NUN(!BPLIV5`DD8*"HA(XG<Z0(S@],\_!K95!UM2*AY/3$,I5**\6
M(2FK$,SR:C2J=5"I5&0!$0P&`SJ[ND")3<*U\&]AZ.G#[50&"%H6HN/HR&.6
M8'EY^4_X@''$<IN>"297B&JQ`G?S6`BG)N/R#0H2[_T`H52)S.P<L'EBI&7?
M1WAT#,Z'7,'G7U]#[!TZKD?$X!:1!$H<#75R96!S<_/B$?S1D]V@6LL3G`YC
M()VT&EL@P!4R@99=@$_3Z_%5:`P8;`G.)?`10:$BE\E"<%@,*-1X9)8)<89@
M@\C(G6C6:A4>CR?RA8%*9P)!J>TN7(YE8-;I@;C=B&G;#`R+.SB7J4.+OAN3
MJS[<%73!,3>'WJD5-!L&X'9[D-RR@C!F$Z:FIXE7K_K6OLE@MF%RRH:4KG5<
M2N/!N;J&H04WV/4:S+NW0&\8QZ!E!C,;`814C$/9VKVTL;4MNJ\8A*ZCJW-]
M??VME\!;_M\O$FV>C:COR_&38PD72H=01&[G_"^_@2HPPFRQ0FW?QAFZ',,3
M5H@LF_@L5825-3?4U@WPFON>'1P<1+RRZWK['NL+_CS2<@H/'ON>^D=F7?ZU
M1S\_JS1O(3A#1-JU(5&SB.^*Y;#9YU*GG1M^DW7NP.7=P26^%66J`?^QZZY9
MV&.5*@P[,IF,^(N;"$:/V\?ABUT[.SM:]\9C[:;7JR67X_3S]\/#PT3KJB]`
MY9&SL"_T'PLG+7T2"`1N_CU.3OTZ>2X<E^?S^2*7EI8(\L^[)][HG^H/D2P#
M*1P74*0`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R
M,R\Q,2YP;F<`````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(S-C(@,3`U,34T,S,W-3`@,#(V,C<U
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````7````%P@&````X"K4H`````=T24U%!]0!#`X,
M&QZ#R7L````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP`
M``1_241!5$C'[95;3)IG&,>[9#'+KMS%DEUMWNUF27>Q;#=+Y@[9FF7IVG5I
MK+%&L1YJ.V/KG%,)U7B86">"XCR!H"@B*B@"HE(0000%%44$/*$6-![P?(S]
M[Y4E)FW:IFEVM>Q-WGSYGC?/[WO>__M_WN_"A?_'ZPZ+U?H--3L_@9I;F.!9
M?!S]KT#7U]>+U1JMA%5>M50G%$/8(D6#6'K<U"*1G)R<?/5:T-W=W6"'T\4O
M*JU\4E4G@KRK!T;3$`:'K.A2ZU#(J@*=P3[6&0;MXQ/VT/6-C>!7AAM-P_S2
MZCI4\IO0)E-"W*X`M[$5(JD2\AXMU!H=_F!4X,<P"JA9N:BLX?)?30I2!:.<
M<\AODJ!;H\>0Q0K]@`G-4CG4?7J8+:,HJ>0C.2,/F7D,1-]-P[5PRA.=7E]^
M>GKZ]G.AJVMK5_D-S5'=C_HLC+\X:)0H(._M0YVX`XPJ`?*9U>"+VL&J%N!6
M4CKHS$KT#PY!K3.B5BA!=6T#1&TR7@Z=$;6]O?WI4_`Z8;.#S1&@C,@ADBK`
M(0F=/?_`TW**$7N/!GH9%ZE9#U'#$V#4-@ZGTX6^`3/:%&HTM'2`S:G';P\*
MP*[F,<[!JEY-?@&SXI1)JI(H>B!3/8*@I1,&LQ7\YG;<H]*17<C&@'F$0"<"
ML\]@#NB?36?B3S8'0R.VP`XB;Z>BA%USN+^__W4`GII!8S`J>"CGB8BF8Q#+
MNL"J$2"WN!))Z7EH)%6-$*#=,84)^R3$':K`6C21YTIX#%)H!:"7<G`KF8J8
M7]+`(K(2:2X%X/9)1WX:+>\T]R$+U?5BY!2Q$9N<CFN1B;A\(QXE%7PTMLI0
MQ1="(&['@\(R7(^^BR]_",.W5V[B)JGV[$.1<4F(N7,?'7(EB)TOG4OC]7H=
MO/H&)))M?G?Y9T1$Q2$L@D*>L;B=E`I*TJ\(2\E$."4>E+@[@?G3]0C<B(Q!
M5&(**!G9H-*R()6V8W5UU4F<<_$<3CKNZL+BXRCCZ+A%UBG'[-P<N!H#Y*I>
MV&RV\NFY^3VE6HMABP5ZZRC*B52#)C/&QR=@&;6A5]L'MWN:Y_/YHHZ/CY]V
MR\;63A"G?RB#*U$<KJRL&#:W=].YO?I]44L;R'M84X_.KS59SJKZGJ\UQA=R
M&K"PN#3AFE_(%?2;,>_Q*`\.#I[O<P)_1^^>[RJK;\3TS(Q&V6\*G7"XO+[E
M%=O1T=%%09?&+U-VPSXY^87).M;HGID%<42ZP3KV.U>IAL,Q)7EA9[H]2^_-
M>!:=7J\/VSL[<7+'C*>LK@G+R\NU*VMKM"GWS(G7YZM56L??+Y*J8""=NK.[
M^[EO996D+1WY?,L?O1">J=2%T`1MZ.I18]7O_Z3?X7:URI6'Y#I(*I:JA$SB
M>^O(2)98:PAN5JEA&1FUV!S.4('6B-9>S<%+[Q3#M"=$:QTC7><\J_8M<L"?
M[>WM19ZMF5RS0KUI^"R>1>)!1*8$8K4/79[%C\WV*4RZW"^'DX0W-S<W0[:V
MMD+(P;SQS-J[Y%#/XL'/Q(/\?G\(R?O@O_5[_!NA%%<GTG"]L`````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B
M;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S$R+G!N9P``````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,C0P,2`Q,#4Q-30S,S<U,"`P,C8R-S``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!<````7
M"`8```#@*M2@````!W1)344'U`$,#@P3$%A!20````9B2T=$`/\`_P#_H+VG
MDP````EP2%ES```+$@``"Q(!TMU^_```!(Y)1$%42(GME&E,TW<8QTWV9MFR
MS)=F2XSO?+$8=9LQ6S+C03(W-49@,Q.%68Z5J@/I4"A%H!U72VD+R%5HQ=)R
M%-I"6TI/H(>4XU]*H10VK0K#H>"`S`D)P^]^D,RE<TNV;*^6/>^^_^/SW,^6
M+?]Y$X@KME]B9NPPFLS;_Q7@O?O3KP0F@O1B@8A^O:;^J;"B!BJU]NF&=KK<
M._\1W-;GJJR4*M#0I$*/PP6O;Q16>R^*1%5@<?C4[=#=TK\--73;MAK-]H;\
MTLIG\M8.M'4:(6U20]79C7:="3W.6ZBH;<`GGS.>\<55*Y6U]1?_,KQ85'VP
M4%BU";7T.G'+,PBUWD3@1KAN#:"CRP+B&$EIV8@\FX1C46?65&WJ<W\*7%E9
M><DWZM]VXZ9\FT9G#!2+JZ$W]\%D=Z&UPXCJAA8T:;J(=B*G4(3DM&M0MNN)
M4S,V`JFNN[$T,?D-C5,DW/;CDR>OA<%=_0,[M'HC:F5R7*]KA%)MV(2V:(W@
M54B1D)(-5KX(F5\+P6070&^R8G+J6PQY1Z$S]T*J4"%?4`XVEP^3K4\8!C=9
M>ZKS>&4HKU=`9^J!5-F.+DLOW(->"&MNXAR=B89F#<F&//,,P3\V#LKGA[Q5
MBPJ)'(->/]0&,[Y(8R.+4SCU\-&CW<_AF3G<H)@TJ:Y1A1'_V&;*,M+$O!(R
M&21:`XET9-2/B>`DG/U#D#2V(:M`A)C$+Y'"XD*F5".-9/09[1+2LW)`4=31
MYW")K"&8<O4:)#=;T4+*D<N[CJ14-J+C+H#++X=[8!C=UEYTF6UH5'6`<24/
MQT_3<.1D#&(9Z:"3'IQ-3,69^`M@7F7!Y_/]!K\W_=UP2ID$$;&).'@R&@>B
M8[!SSS[LB3B!G;O>QJG+F=C_P2$<2TY%Q/%(O/M1)':_=Q![#W^,?<>BL.?0
M41R(2<"N=_:CIJ9V]?NYN2//X<&%Q;C,;B=.)##`KZD#JZ@$\60*HC@\T-A<
MG)<V(^X\#26*5IRF)2&N68?#D:=!^RH#R>DL,&J5^)1;`DYAZ3+9[-BPA@;G
MYA-9I"1E!%SMIF#M=8!KZT=J;@$,?6Y8R:RK2*V;[0YH/<-(5FB1GE^(4E)"
MN],%9J<=C+Q\^/W^8!AX?7W]3>MDB'(,45!Y`X@GTU$EO8'!0!`&LC39%C=J
MFU7@#8XC@9T#Q_`(W-0(1!8G:)7UD"F4&`Y.D64;F+ES)_16&/S!\A,AVT$A
MFR>`H,>#*T4"\/167.:703[HPUFQ!/PZ&5*5'>`(RY&GLT':KD56AQ4L424X
MVFX4RA3P>KV:M;6UU\/@9<-!(:.I$U62^I_O/IQ?Z1^?`-OD0C([%^*>?J3P
M1?"-!U8G0O=7C)1_/;ZYD]P6"0+WIE<=U.A:EF<,3!8;3J=+0.`OA\%;O0&A
M3*/[R6RVT#?T[1^6[4*]!5U6VRHQS?+RLF9I:>G5C7=R[T2_4*V#Q^.A%A<7
MMRI\DQEBFQMJC>;!_./''[YP5TC-WR<>8W[5Y,Z\L;"P0"?`V-]_2YR="H5"
M])F9F<U[3O[;.SL[NZ%?!/]O?V2_`"@"/7J9?!_U`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X
M,C,O,3,N<&YG`````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q-C0V(#$P-3$U-#,S-S4P(#`R-C,P
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````%P```!<(!@```.`JU*`````'=$E-10?4`0P.
M#`L#--D?````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\
M```#,TE$051(Q^V5NT\;613&4U%3TFV4)DVD[?8/2)IM5]HZHDR5)AU::24"
M38B#8@R*27:]7CLA!,S@!TD<;`.V\8P]X]?8'MOR8\:/\1M#LD&`%?3E>)!6
M*2)%*!0IN-+17,WC=^_WG7/N7+ER.7[($8O%[FWO[##!8)#9W]^W?C<P(V6O
MR4HMDTI)1Z5R^5.WVT6M5L>./X2M+?]1/I^?$D5QY-Q@556OI5)I-I,M0*XT
MH#8[6@SG1;F.%=L[+"V[8+&\F*,%?CT7/)O-9F1%0;?30:O30T*J82N0!LMG
MT6BVX?,G\=A@PY-GZWABM+8W-SUA699'OPFFEVX*T?B@T>JBU>ZB6.E`$.OP
MLSG4U1;*LHHU!XO-K3@BL0(81P"Z1P8$`H'HWM[>]:]"^_V^CA*VE$C$ZV6Y
M`JE00S*K("04\<83A]/-@XT6X'@3H>"@5%1TNCTHM1:$F(A7*ZOP>GU\)!)9
M.CP\O/WE;G^*\(*2+U91HH_X>`[;;`HEI0%.R,'XEPN.UQR2Z3+"@J190[O4
ME*3S%<I'&VJC"2Z:)Q5SM(CW^.#@X)8&3R02LVFI@+<D-5NH:I',E%!6FO#X
M13"N761R9?3[>P3MH:JVZ7D9;I^`5XR?WJ\@+A;!.%G,/)R#P6!`+I<[2S39
M,2N3%2FIA&:K`U&J(,AFL+[!PN8(HE)5T24+>KV>EH=`6,*_+[V8-]IALKC)
ML@BL+WV:NH<Z/186%D"E>@;_\.'];9[GWX?8,'S;NW"^WH;9ZJ2*>$YAU>X%
M@BQ8ED68C\+\G,&LWH*91V8\_7L%-H86<'FP;G?A_OVIH?=Y4OGS_[Z3A[_9
M[?;Q<#@23222X'D!N[LA<%P825$$Y034J5A=M>'!@QF8_C%C8N(/3$U-0Z?3
M#>;G%\:-1N/XD$%]\LM7JV8P&(P>'Q^/??SXWQC9,$:JQDY.3K1KM5J=65M;
M@]/IA-ELQG!.0"PN+AY=Q!GSY_+R,DPF$W6G18LAG..X[X=3#5_=V-B(>[T>
MZ/5ZK%!M3TY.DE6K=R_DA*2S9-3M=F-Z>AH,PQR0QPPING$A\-/3TY%&HW$G
M%`K=H4;Y_?*'=.[Q&>K9P4!7*NHW`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C
M;VTO,C-X,C,O,30N<&YG`````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,3$P(#$P-3$U-#,S-S4P
M(#`R-C(V-P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````%P```!<(!@```.`JU*`````'=$E-
M10?4`0P-."5FCIE^````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+
M$@'2W7[\```#U4E$051(Q]V524\;9QC'TW-;J8=&JGI(J'K@4JE?H<=\@!QZ
MH>+2BD,^!$I41:@+P0DD(!.,B1=B&S`E%!M[O#M>\3J>L3UXM\=K;5:#3/CG
M&0Y%58M4FI[R2B.-1L_[>_[/.C=NO->G7"[?=+O=0R:3::C9;-[Z7Z#[^_MW
MT^GT6+%8#":32?C]`223[+'9;!X[/3T=_L_@;O>/$9[/]5A.0+U>1Z?3`:E&
M.)*`2FV`T^D*=SKM7Z\-)MB]7"XWJ-9J:#1;R.9%L'P)._%=E,HBMIDPIF<-
M>/Q$?AX(1OJ)1.+>OX93*OHU422U;53$-D+Q,K;M<22Y'.J-%LQ,%,^5)FCU
M+OPRJ81<OC"@NHQ<">SU>I_Z?+[/1%&<B2>2YX5R'=*3$D3X(D4X?3QV"S6$
MH@*65UP(13+(%40$=W@HEY9!Q29$+T+GZ\/#PX__`B\62UPBP2+%\<CL%N&/
M9A%A\[![62PM,]"M>6#WI+"VX46(@*U6"ZUV&^5J$Y5J'3Y?`*9M.T4Q#X[C
M)O\$Y_/Y[R(Q=B\038/-E!",\G#[DZB*35*:Q;/Y5[#:=U"JB,@7*@1N$[@#
M/EN$R\>B6FM`)%N[F\5//\LP,3%Q"7<ZG9/I;!Z,*WX!$/(UQ+D"_.$,5C9>
M(QCF"%!'FY1*X`1?P*8E!*7&`L4+,[R!%#9-0>A6/!?P\?'Q2W@FDYF,Q>)(
M\3GD2U4$(@(VS6$H5!:HM!84Z9M8;Z#1:*!6;V';$</L\U=X]%@/C<Z.+68'
M*[^Y*2VO<?_^CS`8#)=P*L!M&I2XQ6(]5FN6,26;P?R""K(G<LAD3Z'3&_!"
MI8%>K^\;C>MGLW,+F'ZJP*,I.=D^(]M%ZOUE+"VICBT62SR5XF[_K6.VMK;&
M""`9@7H75BN#0""`@X,#S]'1D68P&-REU#R@KO!XO5YHM5JX7"ZDTQDX'`Z0
M2/G9V=F'_]B.-'7#L5@LK%`H+BY:K5:P+"M-Y[?]?O]+FM"%;K<[3:/_!;7M
MZ.KJ:H]V#F@=D*`E9+,"]O;VAJ[L=U*_2NH/7K[4->@=!$4T&NTRC*V]MK8F
M*3VG2+252D6IT6C>S,W-0:?301"$'CF.D.//KX13<4<HQ!_L=OL=NO20+FQ0
M@:!1J[&^OH[-S=]!@P):#QL>C^<AS_,VA\,)2M7JM78,Y?@#"OE[AF&D8EXH
M-!J-D-32]U')IMELW1*$W6](\5?7A7\BU6!F9@934U-0JS6@5$AIDGI^])UW
M.J5IF-(0E!PL+BY>.*%BXN3DY-WATJ%E=M-FLX6H,SBJQQU2/D11??3^_GO?
M`FQ49\\02%VJ`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\Q-2YP;F<`````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#$S-S8@,3`U,34T,S,W-3`@,#(V,S`U`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```7````%P@&````X"K4H`````=T24U%!]0!#`TX-7LYB1H````&8DM'1`#_
M`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP```*+241!5$C'[51+3YI1
M$/4GN.BBJZ;K[MITT473L.E/Z*:+_H2F:=*]24T^$V.-1'E'0<$`/A"#$0UQ
MH1(@/'P0BH`2P53"0P%)$%`YG9FT7=B739=ZDQO(O7?.G#ESYNOIN5NW;W6[
MW4>7EY>JDY,352*14$4B$=75U=7]_P5]2Z#*Q<7%Y^/C8VQN;F)C8P-.IQ/E
M<MD#0*$WRMG9F9),)A5*J-#9^Y^`Z/`>LZ''FG:[O56I5+9RN5R3P-%JM>#S
M^3`_/P^OUXO)R4DL+R^C5JN!$N/T]!1K:VO(Y_/\VZ+X#]?!DP0.8B'L`H$`
MYN;F4*U642J5!-SM=O_8`P,#V-W=13J=!DF%_?U]V.UVV&RV&N&\_B4XLPF%
M0A)HL5C@<#BPL[,#H]$(J]6*Z>EI`>&[8K&(P\-#A,-A23(U-86%A86ZQ^-Y
M<QW<Q>5'HU%HM5J,CX\+(#/B<ZZ$2Q\9&1%@O5Z/1J,AE<W.SDK,X.`@AH:&
M8BZ7Z]UU\%[2JH]T2S*03J>3H%@LMD45]9&N1F(DP.OKZU(-O1?)5E=700V5
MNXF)B8=_<LAC2M!.I5+"BOZ7MK>W`YE,)L[]J-?KLKDO=";54'7MHZ.C9V0`
M&R5[\%MPEH<2@/4G7XN.P\/#4DDVFQ6VK#4SY]Z,C8UA;V^O0^^?_]7;#,[`
MG4X'P6"0-11W<)*9F1E)R#Y?65F1IFLT&IA,)G:9ZR;@O;1;[%]N)EE+7#(Z
M.@J_WR_-+10*6%I:@L%@8(TY:;?9;'ZZT602^,=ODU?DP6%F9K/Y"^FI\,22
M#.[^_GXL+BXZU&HU-]WRS^-/+)^2?U44K*)F/?E^3LU[=7!P<!Z/QU_2W3E]
M:U[<?8%OP?H*48V9-"+GH$D`````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\Q-BYP;F<`
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#(S,3(@,3`U,34T,S,W-3`@,#(V,C<U`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````7````%P@&````X"K4H`````=T24U%!]0!#`TY"Z-#I?`````&
M8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP```17241!5$C'
MW97-3V)G%,9GT46;=M$F31>SJ6FF.]-T-;.=31L777311=.D&9?]!Z:956.[
ML4['L;83M2J*SB`@#!=$^1`1^10!4<#+11!!N'!!^12PT=$^/?<NIIDX:<VD
M29.2O(LW)_=WGO<Y'UR[]K_\M=OMZWM[Z:YBL3@6#H<YI\O%\3P?6EE9Z3H[
M.WOKE<''QZU;N1R?YW;3.*I4T.ET4#JLPNT-0*=;0"02D==J]2]>!=S-\X7D
M?I:'4*ZB4*J"%ZK@]GBD,@*TS"JF9QEH--J&(`@,)>Z^,CR3/6@*AQ6T2*UP
MV(`OF(+1$L!&B*-[#4NV$`:'U1@99S`P,$(O85IDW3\GJ#?J7^^P\6=YH0*>
M%,>2!;@#2=C=$4E]/)G'8]4J+/8P0I$T%BWK^/71.*Q6*W-Z>OHYG7<N0:O5
M&A/>VMI*)I.-;%Y`,)*"/[P+FRL"E<XIG15G%"JM$]:5(`Z/ZFBV.LCP1V`3
M&9A,UL:RS5Y1*I5LM5J]^QR<R^5NAL*Q8I3+8B\KP!N(P>8,83]7@B<0Q_"(
M%OHE']A='C$V@^;Q,5KM$QSP94F`<%C'4;4)AR>&'P<&,3HZ.O0<OKV]/11E
MTS"8U[&7*2!!A0OO[(,E"_0F'Q;,/J3V>;0[)Q)4$A",XZG!A6F%!=%X!I[U
M'3Q6VG'__C#Z^OI>A&>R.8)E42C7X`LDL&C=P(QB&7/S*]2"-1RWVNBTVRA7
M&C"3+2,3!CSX68D)N0D:,<D3"_1&-Q5X"&-C8W_!J95Z6#9^Y/;Z8339H-.;
M,3XYAP</QS'TBPPFBQWV51>"P1`<3B\4J@4\');CIT$9?IN8@UIKA,Y@AE*E
MP=34U%$BD>AYH:#-9O/33"9S0J^@XIBD$^>X/U*I5(<F$Q:+!;.SLUA:,D$F
MFP+#Z.'UKL/M]L#O]TMQF4P&E\O5\[+!>7-K:WN2&H8^<&-A80&;FYL"J>A=
M6UN#T6B$V6S&S,P,M%HM8M&H/YU.6SP>#[+9+%975^DXQ$1W+L$YCNMR.IVD
M;$D":#0:T/TN);AAM]O]8DR$ZO4&3$]/BY!>VB^SH5`(*I4::K5:$D!W[A*\
M5"I=IU'.!X)!3$[*6@S#E`T&P\=BC'K_;5(=%FTAA6FZ@Y;:=]5JY1M27M[=
MW8V(8++F6Y9EWWWI=`*X1<%D/!YWM-N=?H(,DTWW<OG<O?)A^<-ZO=Y/T(\*
MA0(*A2((#MJ:CD:C^0%]UT_GUM^.__GY>??%Q7DO[8H#K?8IYN?G0;:`"OT>
M)7_MXN)B0O1X8V-#JHO#X0#9\\F5%Q?M[-M4=3Q1S,'G\TE>DY?K!/\R%HO5
MEI>7(:I74%SL%K+T]RO#Z?FW(Y&HI$Q4+4(.#@[6Q1BUXE=BAXB%E\OE4IS6
MQ]7A]/37\_G\]RJ5BJ-%Q'F]7JY6J]T08V3!H\7%15BLUB(5\)E"H1BA&7G_
M7_GKH[Y_@ZP9(L]OVFRV'W0ZW6?_R7_PGR8YZU2LPLFE`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T
M:&5R9&]T8V]M+S(S>#(S+S$W+G!N9P``````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C(W-"`Q,#4Q
M-30S,S<U,"`P,C8S,#4`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!<````7"`8```#@*M2@
M````!W1)344'U`$,#3D>SIY!&P````9B2T=$`/\`_P#_H+VGDP````EP2%ES
M```+$@``"Q(!TMU^_```!$E)1$%42,?5U<MO5'44P/'O?<W<Z73::6>FTW;Z
ML`5:$`S%2%`QAD:C"PP8%QI"U$27AH6@_X`[$Q-6DK@PNB-17+!`$VIC08/8
M`"WET=+']#6OV\Y[YKYFYLZX<H&T8.)&?]N3?')RSN^<`__7)SPN.'U[NMOG
M:SMJ56NG-S8V4=PNG(H)"+@4!4&2:5(5PAUA9%G^7=-2GP7:VV/A<+CV6%S3
MM$-S\TL7J@UZ6EK]-'E4%$5&`.KU!J(D85L6IFV32B8IYK/T]T;8/33T42@4
M.@<@;X??FIIZL[DUT.-3511)0I%E9$E&ED3*ND$VF^?&Y#7*NDXN5Z!6JU.M
M.NP8'#P%;(\O+2V]?.?NW"?U8I%>OQ]!$"CI.@(@RS+Y;(Y$*L'<W#Q[=@_1
MTQFJBY)\=7"@'X_J7OO+V1+_^IMOQ5"X2^Z.])"*)XGT13!*.FZ/BNIV8UD6
MQ7R9GIXN3IYX9\+C\5SR>#Q?_-T1M\*/'SO^92Y70%9D*O4:\82&EM)()C06
MEZ+HIL':>@S+-'$<Y_I6\+;X\LK*X'HL02Y?HI`O$HTNX_/[J%0KQ&-);MR<
M8?[!'':EAB1)V_ZV1\IBFN:9$^]]H(0ZN[$M"[VL8U<J/%B((@HBMF63RQ=H
M`.G-+([C;(L_DOGY[R^^U!8(2YWA3LJZP48Z@Z9M8I0-!"">2)+/9A%$%^EL
MADL__A0IETLM_PB?G+Q!(!AD8S/#PD(401#H[^_%I<A(HDBSUPN`W]\"LHO;
M=^Z^.S%Q]=DGXF/CXZZ%A7EE8786PS2IU^OL&=Y%M5HANK+&RMHZDB(1Z@CA
M5IMH\P=83Z2Y.3-[=FQ\W+LM;IJFMU*IGO,VN8^:EHU>+**7BMR?G6-Z>H;-
M9`S#,'`<AVJUBBQ!1SB$VN1A[/+ED5@B->$XSLXM&RK+<H@&'^;R>;34!FY5
MQ>OU42@42,;7<*MN2N42DBQC6R:B*-$01$1%011%IJ9O/_?T\*Y7@<5'%I?C
M.-+JZOJ9L9^O?'XEFZ6QMDRD-8C5T4YS+D.EODY7UV_<NVE0"K]/1!9I;PV0
M5B1:\YG%X8&!\NCHD6)W=_?;DB1I#V4N29)3+AO%D0,C2*D$NPZ_0*+>(-+D
MHJS=)QC\BIX.C7/Q+GP[=G!D_WYBAHEL&==W1CI/[MV[+[IMS2W+[HPNKW_\
M:R9';[`=W8'I8@FCD*'=_P/E@L'43(#^OAKMU$GE36X52ICETL16\$/X]3^F
MU9G5^%`\DR:HJN2J-NIFC&+Z.WQ-OW#QTO/8PJO<BX8)M+6Q8>N$JG9A]/"+
M]Y\XH7Y?,S6WBU&_AX&G^DX5BH4W2O;DZP/#YQF_%N'@H;>HNSLY<+!@[MNW
M]_1B4L/=XDV'P^$+3\1[^[IBS<72@"`TJ%8JJWJIX!K9ESN2U%YQAX+'$H.#
MS[Q6$22]I7=G?6AH:.U?W\!\/O?ITN+\V70Z?>`_=Z#_!`Y._!JS\M!W````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,3@N<&YG
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`R,S4V(#$P-3$U-#,S-S4P(#`R-C,P-P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````%P```!<(!@```.`JU*`````'=$E-10?4`0P-.2[H1W&W````
M!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\```$>TE$051(
MQ^64ZT_:5QC'^VY[N25=VNS-^@<L6?9B-EG2M>E:;;;IM.MF.N^S%[5>VM5;
M7:N3>;]AU2(B5D%!BH@@@@BB@(@@(JB@6(IS0T44HVYQ7F;ZW9%E)DV3;69[
MM9WD).=W\LOG.<_S?;[/L6/_Z45K8+Z1GD,YQ6IK/V6WVU_Y5Z!/G<XK+`X_
M@5K',-70'X/#ZT0-C5%JG9R\\(_`6KTQBLGB;K1P!9#(^V&V6*'1CX+>S$%!
M&75!K=%V>3R>UXX,ELG[D^L8+;_26WCHZ):#]40$OK@7`G)6:8;1QA<A*B$=
M^85E.SR^@)5'*?C[04JIM.UFC@`RI1K#!A-Z^S7@=O9`H]-C4*M'12T3J=D4
M1-R\BX_#KN)!?@'K3X$>S_)Q>A/[I-Y@HGU;5/F\LT>!OD$=1+TJ,-L$:"*[
M7ZT#K:D-\:DYJ&5RT"U7H;:Q%??R2Y\/Z?2TVYD/3KI<WQ]_":X<4,\\8K)1
M36ORI\\52""4*@B$B^2L`MS^I@24BGHDI>>!W2Z`?686-OL,9"0KOE@.2G$E
MLO**()$IEK:VM@(.P:-CYNC\TIK-NB:N'\P3]J!=*(71;$4+3X28I$Q_*90D
MDW[U$":F;)BP3:.G;P#5#2RH2*E4&AUR"JH0<SV)!+7/[NWMO>.'W\G.H]:0
MGQXR6C%*@"*9$DU<(:KJ6;B;6PHVKPO&L7%,SS@P;K6AM4."0BH#\6DYB$[,
M\)?M?E$U8LGY4O!E,!H;,3\_?\D/[^U34',+*U''8*%+JD3)0R9N95(0_E4:
M$C/RH!@8\K^XIT]%VE*%=!+PL^ADG`^)Q.=Q*4C)_@Y7X],0GYR%D+`KJ*?3
M,3<W]SM\8V/S+>.8U99:0D4,I00?A8;C[,5@O'<V".]'QN.+Z[<0%AY%=B1"
MKZ4A*/8F`LY<Q.D/`A$0=0-GRNMQ+C`8(9?#$1T3BRZ1:,?G6_O0#_?N[KWK
M7M](82RM(4(ZB-+*2O!%8C1W"G%!/8:HXG+4\_AHY@L0I[<@L)I.!"Q!(:T1
MZ?1&A-*;<:>@&.W27BB5_=W$7-&'@B:L[5$?+?I@FI@$D]T&_L@H[GE_ALPT
M#K%61]J-]/7<,@I'S%`9C6A@L=!AF4*$8P$=$BG46BU2IN=Q@WC!8K'4O-"&
M&8X?J/%T)MC"+EB6EF%=]."6<@CW*ZLPXUV%S;T(AF$,:155L#L<F/*MPS0W
MC^3F5B)\.[1+7M#%4F25E($,-ND+<-*7GYC-9AK[QV5\JAL'B\,Y$`0VQRS*
MO)OXDMA?IS?`[79C=7L'06,.Y+(Y<+E<T)'`YR?GD5]>A6<NE]SG\[W^DHGV
M@5<=O^R4"4WF[8YAPVZ.TXW'8@FLRRO[7*5JNWQB!M7$H0ZG$[+99]NM`YK]
MW&D7GO0I()^>W=4;1[<W-W^Z]I>S)=*]_G:B>?II'9=/5/>E'MREN3RRKSLE
M&#$89`??BLVMU#BK<X<CZH;3Z3QWI,FXLK)RFH`/55]<7#RQL+"00$ISXH\[
MK]<;O;JZFD#<^.:1X/_O]1L@LD#Q#QA`\P````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A
M=&AE<F1O=&-O;2\R,W@R,R\Q.2YP;F<`````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P-S$@,3`U
M,34T,S,W-3`@,#(V,S`R`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````7````%P@&````X"K4
MH`````=T24U%!]0!#`TZ`X:U?@$````&8DM'1`#_`/\`_Z"]IY,````)<$A9
M<P``"Q(```L2`=+=?OP```/&241!5$B)[=!+;Y1E`,7Q_W-YW[E0.QV@4Z8M
MVE9;1<70`(F!&+9N1%T:/X,;5YH8%_HMW+@C2HQQH\0%8B/$60!N1&MI@>*4
M3J>=S.V=>6_/Q04;PP=P8?AMSNXDY\!3_RL"P%K[PL/M!S^LKZ\?M]9BK:5>
MKW\Y5:U>N'WKUM++K[R*`.[<N<.9LV=)TS%;6_=(XC''GUTDRU*BX0`I%=8Z
M:C,UEI=7+BIK[8IS[I(G.8ESNEP*]:.=;=UH-,Z>.+$\O;FYKG=V6GIAH:X;
MC1LZ'H_TT2.3>F)B0@<:_?/5JWIN?E:OK"SH4KF@V_MM_><?ZWIV;NZ2S+)L
M*8[C,\(GK*U=Y>;-VYP_MTJ_UZ';:5$J*IK-)J%."`.!R8?T>WM<_OHK#O;;
M6&M)X@231_QZXQ<*89FW+E[\;F9F9DO&XS'[[199TB4:'K#]8(M"D"&E)4UZ
M>!?3Z[1)DPAC8EJ/VLS5)WGCW$D:C0:')IZA/QB2)ST&_0,ZG0Z5RM0[Q6)Q
M0^I`?[1_<(#)1^!SXE&,=SG66KR+P><DHP'.#L$;_M[>X<<KUYFI57GW[?/<
MO?L[#^]M`@G.9K1:NSS:V6$41<@LRR_L[K;P=DRE4J1:+9*F7:*HCS$QI2(X
M85'"X%W*BR_-$!8ME[_YGMEC$U0J!:+A`$&.$(9!O\?FYB;-G2;:6DN2)/0'
M,:=7%\DRR]JUW^@<C&ANMSFU.L_[[[W.WEZ+OS::G#YUB#.K"RPO5=FXNT6K
MU>.YXU7VV[L,HPCOINCWNK3;;42KU?)KUWYBKW6?_;TFSCJ&_9ARJ4AU:@HG
M<CK=+E&44BZ4F#Y2Q9#3[?6P5A$4)YDHETG3`8-AS-'I.G/S\RPN/H\60N"%
M0(H"T[5%I+,<JWF,R7'68`U4)ZI,E2W>@[66("Q3KU4(`@U2H[5&JJ,@-4A%
M(2Q0*I?1A4*!(X</$PT&.)."![Q#YQG&&H0/P8-U#@`I)4J'**5`")36Z+!`
M4"BAE,9:@Y`2K15::WUONC:SE&89HRC"&(,U.2Y/<<;@G`7`.8=4"N\<0DJ\
M!Z4D0@BD5`@A45H3A`4F)R>IUV<1\7C\9IS$5T:C$8/!$&LMUF1DF2'/TL>E
M4F),AA`"YSU:::SS!$&`<XX@"`G"X/$JI:E4*M1J-82U]K`QYC7O_1?.N>-`
M"."]=\88Y[T72JG`>Y\YYT(@DU*&0@@`;ZU-I92AUAH>GVJ44EXI]8G@"=;:
MCX$RL`%<!Q:!#X#/@$__E0#WE5(?6FL_!\9`%_A6*=5^LO>I_\8_V6<+;00#
MOMH`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S(P+G!N
M9P`````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,38P,R`Q,#4Q-30S,S<U,"`P,C8R-S(`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!<````7"`8```#@*M2@````!W1)344'U`$,#3HM6F-SS@``
M``9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_````Q!)1$%4
M2(GM4TM/$U$4_F;FSJ.=ME,>\D@)+"0@ID1,U$2,(29L3%SX#XPN7+ECX\Z5
MB7L3X\Z%.S<NW+%PH02(1EX^4(&H4"@@06BG,YU.V_&<D3$-+EQK..G)[3WW
MW.]\Y[MG@"/[KTPZ',CE<MFW'SZV!D$`(00&^OHVDTE3GIB<;K/=,H:R)ZLG
M^OLF.'=R:GKXRT9>Z^YHKU^\,/SBK^`OIZ:?KBO)JY`DU#P75JGX-M64$AO0
M!_Q:'7'?\3*Z<GUU[5M5RAQ_Y$K"U%&K?E^8NW'KYK7'C5ARN5S6?=^_X[KN
M;+%8G'5*SJ7XL5:\>S./Q5?S^/IU;=`VS('U_#869V:AMK?K,^^6'BA6TT,D
M3//U^'/HNBJ02-W_M+0\2SC/2J521ZU6TX4LRW<=QQG;WMY&H5#`UF8>I[*#
MV&\UT6:UH63;R,05O%];06]"0W],P=S.3KK[>#=DNX1TW<'\^#CV]VSK4\H8
M\EQGJ*>G)U^OUR_+Q'Z,JH`VH;-.&4-'JV5A:26'S\MK2,I$3->1IEA<EJ`K
M,IH-%6:]0N1CN#(Z@A-4+*@'<.E=B"SHS6X+D@6[N[L4='\_@FL7D?NVBO/G
M3J-:]4C^`%8B#I*/SB54O`K*!-#1V8D?^S::FM.PJ+"J:4@F$P0,!A\1&@52
MJ50X&:05#&+M.+3&#.B:@%`"Y/.;&,SVA[+E-[<0B\<HMPA9ZL3(A;/05)4H
M!5"%`E;!HT$(5;!M.]C;VP-WP"T5"OMPRU[80U>F$YJFAV<UFA2^Z#@NS(1)
M124XK@>O4D&%O%BD#M(I<@LM+2VA"XE&CF>:72$MN3WZA9TPL.]7()/.LJR0
M@\X2!^\3$&.*22H$Q6-Z,U3J0%&4\(SMMRPT-:'NK"LS9#9L#-1HOT@H87X(
M0"08E/<<9R>^89[@RRR'36/ENDX(''7"A2*0J,.H&,<YQOEL$6O.B?)9EGNQ
MF#$JA'+&]Y-A<G2!@:+D:#W\OY%QU)%A&+P^"3]_`NNE"UT16'0YVC<6:31F
M%X$WVD&1A3\N'-F_;3\!5AZ>8459ULP`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S
M+S(Q+G!N9P`````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`U,"`Q,#4Q-30S,S<U,"`P,C8R-S``
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!<````7"`8```#@*M2@````!W1)344'U`$,#3L#
MGZY/0`````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_```
M`[5)1$%42(GME,MO5&4<AI_O.^?,G.G<+ZW#,%PZTX@"(@L:H581#/'"R@TN
M3(PKU_I_F.C6Q)4+%T8WAHL:"`6\026U)(A:;>BT]'KFUO;,S#GG.]]Q42'^
M#81G]2Y^>?/DMWCA"8\5XF&8GKYIN]O=XT)(_""\XP^VCHS6#_AV/#'?6)A[
M9M!W*5=J]PO%8F'F]HV,$`*BB&)I-X.^B]OK`I`O[.;$Q.22:9I_FP_+.^VU
M<CJEKVYMN>S=>^C+3K-YKNT\<'?O&9LJ9+RSY,#SMG\(_&1M3SFJ2"FP3(/U
MYBJ6$3*VSR(B8F5]F6;3^03X4#XL;S77,8V0M>7[M-OM<^DAN'GSIV3/[9Q-
MV![YM,9Q%B:E85:N3-WC\R\N8\=][M[]C<!K,S<WSZ>?G>?\A:LL+2Z]HX)@
MXI'Y"R=.G5E;OD,VEZ/=6J4XFL9Q.FQV'=H;#F$8HK2%N^UR8O(U'C3N\6`]
M9/K7?SA\^!!F/$:]]C3I3(E2J3BLM<Y(@$&__VZD^<C=#ABKCQ'I'HE$FFZW
MB[.^PMS\&G?_6,6,Q9F=OH&WM<'XL4-\]?5UXO80IFE3']U+K5;&[6TAA+@D
M#6/65$KENIW6FXN+"QFWK[AV_3:W?OZ%X>+[Q&1$*I5F8G(2;^"12-C\-?,-
ME4J>6]._L[*XQ$L3QT@DLER_-L-W5Z8X\.P1E%*G@8-2:WV\T]U\>W'^3P@C
M`F7P7+V*E#;9?(E,9IB+%R[S[<7+*&6BXT7VC!ZDU>IR\N47*>>3:!6R?[3.
MZ5=.,3X^3MQ.S``+PO>\UQN+C4L_3GU/>V.51J/!_I$$5JK$?&.9D9$RC;E9
MQJHE9&H7*TZ':K5*$/@(:=!QUDBF4PRE\JA($O@^)U]]8_7YHT??,H40Q&(Q
M4LDA@I9'K12C6L[C]7M8(S$LHT/M:)U**4=KTR4=2:2W@M("7VF&DV!;$=W.
M,LI,L*M:(Y?+;*H@Z)M::WJNRU;7H9"*DRN6L4P#,601%9((!!I0&C*I)*E4
M%H1`"$`(0@VA,*E$$F4E>6I?G6*A<-%.)&9-PS0W"X7B1JF\?WA[;1X/120,
M#"F)(DW@#U`J0&L-@$!AQPPL0R"%1`JPT"@,A/80"*24_]T"O5[OXZ:S\8&S
MNH0:N.@P@`@B'1#I$``=Z4=;(0484B`0",-`2A/#BF,ELY1V[6MFL[GW8O'X
M>0&@E!KS/:\:^!XJ#%&!1Z0U6D<[!CLSLO.*_R-V+*5A85DFIADC;ML]R[)N
M\83'CW\!%P2IAUAD^W0`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L
M;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,C(N<&YG````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q
M-S$Q(#$P-3$U-#,S-S4P(#`R-C(W-``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````%P```!<(
M!@```.`JU*`````'=$E-10?4`0P."S(3<,?0````!F)+1T0`_P#_`/^@O:>3
M````"7!(67,```L2```+$@'2W7[\```#5DE$051(B>U476\B911^AIEA@`&F
MD2HM!8;4;<)NNUU3&]U8$Z-=+]:]6XW7_H3]!2;^&&\T,<:8Z)4AUEYTX]Z8
MKH"Q*]5V*!T&J&6&^6+&\[Y83.,_V.Q)"`/O>YYSSO,\9X`7\5R%</5P<7&1
M,@SC;KO=QL[.#KK=+OO;US3M6;_?KZ?3Z;^'P^'`-,W:]O8V?-^')$D(PQ#F
MN3D'K-5J3G&I^/@:>-<P/OOYR9-/D\DD)I,)!($?V8N+BXW!8/#`L6U#DN5G
MV6SV[3B..?!X/`85Q7FOAU)I!4$80):DUNZ]>S=9LG0%_D>G\_'EY24'I2F@
MJBIRN9QZ<'#P8&-C'8>'AZ5RN5QB@(JBP+9M=#H=5*M5&*>G**VLX->G3R%*
MXGR*Q-4#2U(S*O;W]S`:C9!(",CG\T2/@7Q.8X4XX-'1$>^:-;&YN0G'L1%.
M0UB6A>ETBOOW/_@_N*[K&-MC?/CP(_B>2Q<C3D^E4N63L&YCNE=\N4!<"A!%
M$?5Z':F4`BVOX=:MFYR:5JMU'9Q$T=V)D^Z;/1P?=["^O@'7=7DW6UM;Z%M]
M#J8D97AC"TGZ)FYQ<G*"I"S#L2_1;#:QO]?`\E(Q'4VG^AP\BJ)'[5937WWU
M!GJ]<VC:`IBP?=.$3,F,LB`(.&TI=8&Z31$U,M,!:C8')97!<K&(.W=N4R%;
M)\$?_4<+J;^\O`1WXN*]W5TT&C]@0-V>$=^_M5LX.S/(;F<8#?MX_<VW"/07
ML"F[IW]A.!A`IDF45!JK-^K8^['![3EWBY!(H$)J__E[$]]\^1/6]!("WT&A
M5H!O':-64!"1:!G1P?=??8[5:HEHBO#:6@FA-X0['.&[K[]`$$5XY]WWYYQ+
ML\9C&MN#7EY"Y16-@`+$I#QS!%%&9R&)&?.UN+MUF_//SM@GC@6R8X4W*$@*
M*M7R=7!)%(UL;L&S%%69D)">SX`3"`,?KN=Q\*N0I00Y)PF)K"HF1%Z2%?;#
M&)$@$>=CWM"U#24AF@/+K(\L$T/RN<]!/28'94>\F/#O[9B2F;=G/V:T*DH*
M.3*"OKIFO518_(0,\>T<G!;@C<#W,ZQ3F]S!WATAK7/,ZD=3DE[DBR7,W$6K
M'F)6&=PY;,DRF32RV9PC2M)CO(CG+_X!V6V68W[EKMP`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,C,N<&YG````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`Q,30V(#$P-3$U-#,S-S4P(#`R-C(W-P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M%P```!<(!@```.`JU*`````'=$E-10?4`0P-.R@S$K8`````!F)+1T0`_P#_
M`/^@O:>3````"7!(67,```L2```+$@'2W7[\```!\TE$051(B>V2R8X2412&
M?ZH:"$,Q-D,Q26P32*#;C4%ZZ\K'T+=PY0OX%BY\`*.)"S&=2+H3-RX)"P(D
M8)@I"//H.2>I3O<;F,C9W)M;Y_[G^_];P*E.]4^4Q=QLM]OSZ71Z5JE4WO?[
M_6NKU8KC\8C-9@.[W8[=;@>;S8;U>@V+Q0*?SX=:K890*(1H-(IFLRE]FN9!
ML?CRD\/A^'!FBI/0S]5JE2V7RW"Y7)C/YR+8[79E7R@4T.ETD$PF<7=["ST6
MDSY-TU`JE;!<+D%PR.<O<75U><.:RD,;+,)D3)U*I4#3D<EDX/%X0(-%+!P.
MXYQH&XT&O%XOZO6ZG/O]?@&XN'CZA^Y]?"2^W^^Q6"RD,9%(R,J4%!=RN9Q0
M<8^B*,AFLXA$(N+,C$F/Z4BGTT2>_^5T.G\_$N=L)Y.)V-2C.@S#D"&#P0"J
MJMYG[W:[9>7!]#;BI-5J0554!OI"[M^:FLKA<"C2Q3O*[`F3,]%H/!+R7J\G
MEYEV.!S*$#[G2!B"'Y-=5*M5N4=`7XG>,,4M9/4Y#7@WF\U8X!E9?=%NMQ$(
M!"0FL@C^QJYX'Z.'9%(6)A<&9?YM/!Z_HCBV]#9OXO'X]WMQ/"@2SI"M:R:E
M@?+K<7&N?,;%;\#G_'>0DU$P&/Q,Q*^I?T-`/W"J4_UG]1=+BO$?LDGYZ@``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,C0N<&YG````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`Q,3(U(#$P-3$U-#,S-S4P(#`R-C(W-0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````%P```!<(!@```.`JU*`````'=$E-10?4`0P-.SE9HI;R````!F)+
M1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\```!XDE$051(B>U2
MR:I2<1S^/!X59W&>$PP4%._F(MYMJQZCWJ)5+]!;M.@!HJ!%1I`@M&DI+D0%
M#9P'G,=^WQ].W/L&07Z;__3CF\X!;KCAGX#)V!R/Q^!RN=0;C<;;T6CT8+%8
M<+U><3@<8+/9<#J=8+5:L=_O83*9X//YT&JU$`J%$(U&T>UVU;O'XT&E4OE@
MM]O?Z0:Y$/W8[7;Y6JT&E].)U7I-00R'0ZQE7RZ7,1@,D$PF4:_7$8O%X)0Y
MM]N-:K6*[78+,8=BL8A2J?2=G-KC&"2A,UU<I]-I.!P.Y'(YY4:$U3D<#B,8
M#"JG7J\7[79;B3`)#62SV=_B^OT3\O/YC,UFHP;ICFLJE5+N"X4"%HN%FM$T
M#?E\7HFP*J.F>#R.3"9#YS_%Q*\GY.R6!(S)R+/93(F,QV.8S68EPNY=+I=:
M*<PWBO1Z/34CACY)^M<&IW:Y7"I"7)?.GK$6#D^G4T7"OGFFL\ED`EW7U3TK
MH0G6PQ3-9A.12`3S^?RSN)\;Y":)>B<";U:K%0F>2]3[?K\/O]^O:F+/?&,J
M[AF?3DDL0O-.I_-%4KZ0.H[R;5XE$HFO?\GQ"$*<$_</[%4$U:]%L%?>$:R'
M]_P[I(II(!#X*(Y?ROQ!#'W##3?\9_@#/Y;Q'5QD*#,`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,C4N
M<&YG`````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`R,#,T(#$P-3$U-#,S-S4P(#`R-C(W-@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````%P```!<(!@```.`JU*`````'=$E-10?4`0P.``^H[%(*
M````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\```#J4E$
M051(B>V42TQ<913'?W/G<6?N#'.'\AB0>0%E>+1`A0DI11L18[6I:>+2J+%Q
M;U<NW+DP:J(QKDQ,%R8N=-.TB<986P,K(JF6BH.%0J'.T&&&&9B7PS"O.]=O
MB"[LRK7A).=^]WSG]3_G?#EP1$?T7\F0S6:#GZ[L7/IL)8=6-W!6SK-LL),N
M&3ENTGG_M)?WPBFFM!R>$[V\LY+'OK?'E:E.OMZN4-E-LV>QLIC74.LU+OOM
MJ<OG1CXY##X[._O"Y]6V[Z_%=8RKZSAW(N3/7T"+;F-QMS%V_QY;P_T8YA91
M9T99#B<P/]'"R%Z*=%<[F0=;5'K\'&1+2`X;WD2B/*,E/WC[U:<^E-+I-`5)
M0T\E&?C]*O[,&A6!0)F[+LX<=R(QXJ4\CP2ZI4(-]>=;C-R_P>HO/[&5WR-;
MJ5$P&S#=OHU]\2:;K<?D;/+@W40B,6UJP#\FOKY0$&/@+?3?[M+5I2*_^3I_
MENK4DAO8K./DG3)FJP799</6':1]=YY]Q43>(B'93.B".]4Z!G<3\5L)%A;V
M.0P>$HK26HSH=U>Q:$5>>O$"X;O+/'LVQ&J@AZ$V)_?JV_CL$K]*T#UTDF+!
MR4D+Y&2-+KN1)8-.4&UEQ&[B8:5"/I_'5"J5\)BAQRB<^MTT*:(2L\[F@R6&
MGQLEK5KI%X/]HUQBW*E1]O@8J130;!(>62)JE1E6S"@G`OB[5;9B<121T.EL
M02H6BV@[8DCI!%JUC$,V8XL_PE0K8]R.8*L6D>-1M/@&EJU57KOX-,?;FM%2
M,91,`DLFAKR]SO-G!FB1%1:N7<?M*M+;VXMI>GJ:2"3"Z6XS27L7X^/C1*-1
MII[TX%$,C'DEW,8J(7^-0',33=5==N.[^/4-V@T!:G(:MZ$-=RTI6IIATE=E
M]-0I)B8F,'5V=E(H%-!UG8.#`QIRXP5YO5Z:FYM1%.40Q=KZ.AZ/!TW3#N\;
M`)Q.)W5=M+,[@%?HYN?G#_W/3$[>%#9AR6*QS.5RN2N93`:SV?REU6J]4:U6
M<;O=!`*!S5`H1*U6HS\8Q.?S?:RJZIU8+$90R(.#@PP.]-/;T[.92J40<9B9
MF2GW]?7]*$#%3")X6:#XIE*IO"R&6[3;[5\)U&F;S?:*R^5Z0R0Y+RJZV-K:
MJ@K=#PZ'XZ'PB0DV"GVX\2I$U5\(GTOB[EQ'1\>W`N!'_]H#8@U,-%;!W_^N
M_?W]9T1"1T,6K1@2"<;^L15RN^`.'B-A'Q1L??S^B/XG]!?T!I)5K#?V3@``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO
M=V5A=&AE<F1O=&-O;2\R,W@R,R\R-BYP;F<`````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(R,3(@
M,3`U,34T,S,W-3`@,#(V,C<U`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````7````%P@&````
MX"K4H`````=T24U%!]0!#`X`(YHT/ND````&8DM'1`#_`/\`_Z"]IY,````)
M<$A9<P``"Q(```L2`=+=?OP```07241!5$B)[51)3UM7&.4G9%-U5:F[+KOH
MHIMTTS8*:M4NVTT74:4B*PEJVB9$)!$-)3$U"9@P!(*EX#"$A%!,@['Q%`=/
MV!@_XWG`\#P_C&/CX1G,I-,/JR6;JDK3+G.EIWOONT_GGN^<\[ZZNC?C=4>A
M6/K4X_$(HK&8@-9O_R^@.SL[)[+9K&QQT9KT>KTPF<P(AU<5_PDTG>;.^_S^
M'9/94C4:30B$UZ`WNZ#4VB&^,X!(9&WDM<&7'<R.R^-'FMO`YHL<@FM)S*IL
MT#YG()\WH*?WKE^I5'[PKX$/#P];-,^,AVP\#3:6@-GNQ=-Y"X8?/,;@/0GN
M2T?1TBK$V/C#F&W)[@P$0\Y$(GGJE<`3R>3'3Z9G]TQ+7DS/&G%#>!?7?^G"
M@Y$QS,TI(;HEQIEO&W"V\2)58H%";<"<4KUGLSO.[._OO_>WH*E4JE.A5$VH
MU+JD6K^(>3V#]HXA#`R-0*Y08ZM0P/;V-G);1<RI#&C\O@D-@G/H'Y1B<GH>
M4S(Y8K&8G2YXZQB4-B?B\<3PLL-Y&%I/P>UG:_J*.B68EOV._%8!Q3*/578#
M@4@*C"<*;C-/59G1UGX/WS4TXJNOO\'YQA](JG&$PN%WC\&)4;W+Y08Q1R;[
M`L%(G,JU0:,SH%`L@J]L(YDIDO81:!9<B*QS9'(1L_-+&!J68W1"@S9A'S[[
M_$LT7[D&EF7%Y%M]#7R=9>M=;C_%;1VS2@.Z>L?0+KH#A].#!)='/)V#+Y*!
MB<"MCA"27`Z6I3`>32U@Q1=#-)&%Q1XD";MQ\N1'$(ENP>/Q<J52Z9,ZGB^_
MOV`PA9JOME)I%W!3^"N<*VZ$UE)8<D7`>%GHC&Y(QS20R:W0&KR8D9OA"[*H
MD`<EOH(XD4BF.9C,5HP^G,*/%R_#OKR,&GLR2CSQ:!)Z@PU6)H1(=`-':7%Z
MU["9+]$ZA`')4V(<()`<."Z+,L^C4.(1)I\,5A^*I3+Y4X+FN1N7FMO0W=V#
MO[)]:<7EJOI"<1AL/M*:1XCEX`NG8+0%B?%BC6DN7T2E4JF!>NE;N=H.Z;@*
M]T=5<+A8J)XY,2DSX*>FZVAJNHQC8S<RF0`;C6.5F$03F\0V6)-!(E5B9LY2
MNW"+8LB7RTAMY*'4,>@;G(&X=PH3I+]2R]3D4NEL.'ON`F[<%+X$+Q0*7Y`1
M>[]-SZ!_0(*>OB%TW.Y!:UL'6GX68E@ZCH%!"<VC>/QD!IWB/G1U#](\1#]:
M)X6@$]T]_1!UW,:5J]>@U>I>@A\-RO-I+I.1K:RX9!3/\%$GM-OM8!@&#H?#
M<K3W!P+P^7RP6JWTCH%>KX="H8#-9DL[G4X9G<DHCK)JM2K[IQ[S(3V"O;VJ
MX.#@0$#K=_Z<:_O=W5TZVQ/P/"^@J@74GD^_4G]Y,_X`I>61PL;]JD4`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S(W
M+G!N9P`````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,C0S,"`Q,#4Q-30S,S<U,"`P,C8S,#``(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!<````7"`8```#@*M2@````!W1)344'U`$,#@$$)B6Z
MPP````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_```!*5)
M1$%42,?-E4ES&U44A;-@P39;6."_D"U;_@<K%E2*!1LHLH*"(D6%)'+B&(B)
MX\1&B2Q;EBQ9EFS-<FNP9+5F]:BI6_-D6Y)M6=/AM8J-$U*0"@NZZO7K\;OW
MGGM>O6O7_@\',+U-ADJ9WQ7T/J;C.3+,TW&?F0R/F?'P9#(>'F-"YNGHE,%T
M2,;H!OGV^EO"QW>FXQX&O0).ZA$T)"\J!0\J>0_JY/JD%D:_PV!RV2'LD96<
M/OBW6=]2LCMI1%&7?9"R7O`9.T3&@2SCA$SN*T4?"JP#Y9P/@[ZD!'#^,W@Z
M_DP!-V0*<LZ+HNA&GG<1L!U\THJ02XUTR`"6-H&)&)$\U(&C]>BU.9!JG6^L
M@&AX?3H\MBH92X('!=Z-@N!&B03)$7B8,H`.VN#=UV!W]3M$W&LDR`Z2)%CF
M4(O1196PQY^_26>SHG&1=T)(V2!F'$C0=B2B+L1H'UA>1##"P.'V0[WP#=QZ
M%3*D@G3$A(!M!1+G(>P+^6^SGX[/&:5Y><Y!?C`C<K@/011QVNVB?WZ.!)/'
MEND`-A<-T\XNG.9G2(7T2`1U"-J6X3?.8]!5]!_.O097[*:X0DA9<41MX2A"
MHU1KH5BJ(YK*P>JD$4N)J+<Z2+$"]!LKH/:?(^!:G_5B7_T]6J4$,+F8>]4A
M'XT&G4)!D21A1<"]@5W+/L(Q#B9K&#JC#WO.0V0X11H6>ZX8#&8?MLTNQ#-9
M.)PNF-1W(`M!I;%'K\)5E^<MDL$?H.P:V*U;<!^$L&EPX_<5`_9L%*+Q)#Q>
M"BNK>MR=7X5:ZP(KE"!5VPC'<]@VFL%F(IA.1LQKF?>[]4(X%$0RP^$@F,"&
MP0FGRX=(+(U2N8I6JX5JO8X0G<;]A\^QOK&-HB03F=J()`E\-PA?((S+RXNK
M\+.SLQO97*'<[9_AN-M'+)&!RQM`J5)!H]E"BI?A#[,(13F4JW42^``/%K6X
MIWH,C=8`(2?#L!N`><^'XY/3J_!NMZOBA`(J]3:HPPQ>:G=(5B74"5BJ-!%)
MR7!2212D,L1\"1J=%Q;[$='=CU^7-%A3ZW%(BTBR>?""\`J\U_U*J]T<?'WK
M6]S\XDNX/5ZP8@F,("$4R\'N31(830`\3);PS(Y*!95:`VD"?+3X&,M/U_##
MCS\C$`A<A8^&PT\"P6##N&.!APJ11A7@]B=(`(DXAL>3YQ;H=WPXBO((AAG4
MZDVT.QU2A0P^1RIL-)$DZ^#>_&^@:?HJO-?KJ:*Q&-$U#5\HA8)<03R=0UZJ
MPD7DT!D/9AFVVJU9#W+%"M&?AU;OA9N*@Q-E[#FBN/W3`AP.QU7X8#!0<1P/
M7BPBFR^#SY9FVF^9R%+7.I$OEM$DKF@2QTCEQLS[BTO;6/A%3[X)0+/E(<]"
MN'/W$2C*?Q4^F4P^[G0Z58X79E[>W#)B^9D&\PNKY(=%;.KT,)EV8#:;8',X
M21/7R+LUJ(@EEYZHB??7\6)=!_6+ETBETC=?6_[#X?!#GN?GVNWVTUJMSLBR
MS(C9/,-Q#%.MY$^KY3QJE1QD29RP3)I))%.,WQ]D6)9C&LUF_,'#A3F+Q3(7
MCT??>]MM[]._]L]WWT/_J^-/M*JOQ_Y/PTD`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K
M+W=E871H97)D;W1C;VTO,C-X,C,O,C@N<&YG````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S,3`S
M(#$P-3$U-#,S-S4P(#`R-C(W-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````%P```!<(!@``
M`.`JU*`````'=$E-10?4`0P.`10[DJJG````!F)+1T0`_P#_`/^@O:>3````
M"7!(67,```L2```+$@'2W7[\```%T$E$051(QZU5:TS35QS%N"S.)2Z9KV5N
M"\D^;)G;W$RV$74/W<PP6^)C$=!-'.JP$Z(((@R,@4T!P?(H4.0M\@;'H]`7
M2`NVE%<IM(66E@)]0$M+2WD)!8IGER;SPW")R[S)/_?+_W?NN>?\?O>XN3WC
MFK+K`@P&+0P&O8?;\UXV$]=>S\A&67G%_P<'',&V2;/2:IV@8<7L;E51ILNR
M?*$:D/=A9=3=X9BB62QFY?+R<O#?-4ZG<S/Y=JP!<SH7O`<&NBDC6BW%/F5?
M_]AIBE7UI*.!4X2E1T),B3]%2?S[Z!(FX;'C`8:56:BK+87#L1"[LCRQWF;5
M44PF4\OBXB)U#?CRXM@)G>HN6+5IT&J'&7`:U':Y%XII>Z$4>&.J81.*HUY%
M<<H>3$J_`2/S0_#8-X`5H]HQW<QH:<I`JZ@5>KW.?0VXPUZ[;MZ<&&CK^1K%
MJ0<AK/>'IO$3T`,W(<1G"WP/;<;W!]Z!K]=^7*/LQE7?;5#P/+&@\8:\;B<2
M$Z(G.CL[CHV-&=8]5>?'*W.417,.)MDO@1ZT#5'G7D?HD8VX=G([8L..@<LJ
MAU*E1DU-!4)^W@5^VFL8+'D129&[()<UJP'G9T\QSQEJM2A[AM1MAAES/M3,
M=Q%]9CM^\]^#VI(4\!NK()%TH5NF1F6-`'\R6I!X,Q0WSFQ%=O@6<(N^Q.)T
M*>9F1@US<S/5_P0_.6>IJE3R#J'ISEO(N?8&"F_N0F<''^+N;A06%2$M/0/Q
MU&30TG,A;).A?T"+G-N_H#1B*T39;X.1[8'2_`AR@U[E&O8K#IG[TE0)#`_W
MH3IJ$S@9/R`N/A[4Q$0P62ST]DK!9#<@.245N7FYZ!3+4'(O'9=.O(>K9W?C
M\KFOD$:]BB&-\O034/M$AT>O\**'6D0Y:M/$052X%^SK+^/FE>_`XC9!KM#`
M-&Z!V3(!(]FE?6K<3L[&Q:!PQ,33D9Y9!+Y``BGYCWXG!TG)R=,<#CM?H]%X
MN%G'>9`VGX:T9B>J8E[!^6,[$'AJ'QC5I3":Q@FH%7*5`>W=`^B0J#`Z-@YF
M0R>H*64(#8]%:%@4V`W-T(Z:(6SO059.'F)B_H!*I8*;>;3.0R'TW\^I3M"G
M)48BXTXV"NX58'S<#*O5YBKJE`Z#)Y!A1&^$8<R,FOHV5%0+R"Y"2EH!;MU*
M@%(]@@:^!+5,(3*S<B!L;8UT24,>HZ2XN%LH+"DC>N:C1Z;`X(@)`T-C$,M&
MT"Q2H$G0!YE2"PZO!U5UK=`,&UQR#0P:4%Y1A9BX.*31<Y&<5H(DVET(!$*L
MO@<?=(F[^I-IJ1"TMD'>UP^98@@B\0#D!(POE".OL(&TGP@M;0JP&[LP.&2`
MU69S2:8;'8=^U.BJ8W*:$7G]!AA,/AJ;>'"S3=H\.5P.,:4+32U2PDX'&3%-
MW*O&F,E"=.Q'07$#)%(U)JQ6F,T6%V.=P83VKGYP>1(";H)J4(]Z;A>"0\+(
M[>^ACQQ&)!GUY//Y4*B&(.Q0$A,M4&D,!'R0'"9#=9V(Z*EU=8O-Q7:"F*M$
M>54S,O,8*"QM0B._!Q55`K`?2'#<RQNTU/15$N5N"PN.@SV]4B>+S4:O7($^
MTE(/VQ6X3R8Q*X^)_$(V&?D1#&OUJT'A,K6.TXZ4]/M(I%42N83$2#'I&"'J
MF(WP\?%&;6WM*A%/EZ%+2XMGFWB-LY>#_''A5S]$1$0B+"P401<.X_C1+Q!Z
MZ0A"SG\.?Y^/$'S1#R&!AQ$4\".N7`E&0``%@0%G<>HG+_CYG0*=3H?1:-00
M+S]^,DRS,U/>C)I*2E9V#H7%8E%[)4)4%(0C+YL*A;P:XOIOD1KV)F@)`1`U
MTU&2%X:XV&APN5RP.6PJHZ8B0][7!YU.%TF`]_QK"I&;;%A9<42;3'JEV6QT
M)=&\D3I=3C^`-M'#Z?G9?G?KA(ZF5&F8)(W<2;AL(#4;22JY$^`7_G/L+<VV
MV[DUOX.,M?VY!_3\(TN`3CNXJF?`L];\!<KZK^3;VZJ8`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T
M:&5R9&]T8V]M+S(S>#(S+S(Y+G!N9P``````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C$W-R`Q,#4Q
M-30S,S<U,"`P,C8S,3(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!<````7"`8```#@*M2@
M````!W1)344'U`$,#@$F\T7[)P````9B2T=$`/\`_P#_H+VGDP````EP2%ES
M```+$@``"Q(!TMU^_```!`Q)1$%42,>]E3EOG540AI\YYWS+^7PW+Q<[=N0E
M!`LA(O(#J$.-9"@0)1)%*AHD$%6$H$A#BT2%$%7X`>$74`!ID$(LX<0VN7&\
M7=_-W_VV<R@<.R"6!*$PU2F.'LW,._,./,.0I_WHO?L$L$`JHC[\3W#GRDGQ
MY;(7^5I\`=ZO`@IPB*Q[#*+,AO>\K93I/C7<^^H=7+Z&'[_FRQ%%/L!YAT<A
M.+32:&-101TDNHE$-T29+YX(]]Y]@!M_C!NI(MUE..PSSDNJJL(YC]%"%,6(
M=]@DP=9F03<<RGXDHC[]6_A)QMGG+M]3P_Y#!J,4YQ79>`P>G',H)41Q1#'.
MR8N25B-B9FX9$\\Z5/RNB#ZKP/R^Q[A\S9<]M=.YR][!D*QPH#1*%*ZJ&`UZ
M!-H@.)0.J+QG;[_+87?(RJI2H6VO.5=^<ZJ!/`+7J[*X,>CO7;F_>9NM[1WR
MZJ3\YN0,M5J3(`A02J&U9M#OD8XSO`<H.=S98K)5X\+J)9X[M_*MUGI-*3,X
MS?S:X>'^E3NW?Z)W=$`0UYFV"=9:DL02A@83A$11C`YB8CO!\6A(419XYQ$1
M>GN_LO'+.FGNK\S-+5P#WCN%?ZG$O^E=/H]21%%,&`1$@>"*E*/>+E%LR>P$
M)JPARN"]QSM/Y2J,,50>!OT^9K=#;:(&C^:6JJK>J)R;4^I$7ZT4D4V(D@8Z
MB,G'&<-!'U>6I(-#BG&?/!]3E,6)%L,!]S?NX*N,E97GF9QJ/X:/1L?VP8.'
M:CA,$02E-2(0&$-@%+&-L38FF6B@M4(KB*,07$599&BE,%&"$D\2!X1A^(=I
M^6QI\=SKPVYG:7MKF[(H&*<M\FR,4@HG,8AB>^L>_>X^2;V)#F(J+[BJ9)P.
MB6/#POE9K+4.2,_@K=;DIBL'Z>K%!;+^+D<''4I=,"P'X#VXBN'1`0</.Y1E
M0:,Q391,D#2;--IMZC:DW3C/\O(B)@C73[WG;,Y1(5/M61;G&JA>A]CUF(@T
M^YU-C@=]C&BF@IS<9\Q-QS3:TYBX3F-VFO0XPU<9-JGCY3'R["7>OV7"QH^S
M2XO\_,-W/.AL8FMU\BRC?]2E66^R].++3$S.$-F8(LL);<QX-`1EF9MK8J(6
MB-DXR_=L]<7<0^*;C9F++%VZ1%Z5]'M'C-)C/.!%,&&$".QOWL57)8C@G*>1
M"/7)!5`)WLO5/\&5,EU4>`-==ZNOO,H+ER_C10A%(:((DPFJLB*V"?.K+]&<
MG47AJ=F0J?8\8IH.":Z+R,Z37;$:J/MW;[%^ZWOB(":P-6QS&JU`&TV<)#1G
MIJFWYA'3>K(K_I6?%^D!Q_TN69J>5*@U<6*):ZU'/4Y`F>LBYOU_=XF$K[RO
M+OSS)9*K(K(CHL;_ZPU]IO$;_6?FO68(6"<`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,S`N<&YG
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`R-S4P(#$P-3$U-#,S-S4P(#`R-C(W-P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````%P```!<(!@```.`JU*`````'=$E-10?4`0P.`A`7TCU]````
M!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\```%=4E$051(
MQZV5:TR39Q3'\18"\9JYQ'F9=3%+=/O@=#K,]-.R.;\0F6[+S#+GAV4LDFTQ
MF\D&T\4;$Y$*R$5;L("4`D(M+;1:[JT4*+106GJ%TBM]^_9"J=+2"_^]D(QD
M@R4N\TE.GN3)\_S.>4[^YYR$A!=<4W[K.9O-`KO-FI+PLM>46^07\!BHY;#_
M/QP(G_=Z75K2310@3M`"8QD!3LEIZ+0J->)VVFPX4.`F"6TL%CO_UYMX//X*
M9=N6P&+1F<]UH_+TB8GQ=/^4?]5<S)FM4Q1"+&(A\ER*YXI]8.?LA5QZ"W/A
M#ECT91`TU2(:C63'H\0JGW<BW46079%(]-82>"0\^8595X4F;BDL%G,38C9#
M0'T*-?2#,$A.8:IU$]B7-D)0GH*HZ1@$S'?1+KP&Q)V&D%_8U"F^`XE4"JO-
M25L"?^X3K0@Y+F=XY$?!*3R.`>%W,+<=1-&/&W#QR\VX\O4F_)"V";]\NQ_B
M_+VXGK$=:O&'>*9/@XK_-NAYUTFYO/\3N\.YXE_R'$J/$N4("!)Q]_QFY&>\
MAK9+R1BYL0:*@JV0,#Z&0E*+OAXQJEG9:&?NAXF=!'K6(8RH.@U`]+UEH-&?
MW2ZM<MS8:PL2E1AK?@N5/ZW'>.%J!*M7HN_N/JCZ6V#4JT$0;LI(C)FMX%17
M(B?S!!Z5?X305!V"TPY;,!CD_A-^VNNHKS=(TO"4N1,563O@8JQ&I&$E!ED'
M,"RK`TF2L#L)R(=,Z.D?I>!V]`[JD5_4B$)Z#FK*SH)3D0GUR+!VJ5K"&EK$
MSX%;>A3"W]=CKC8!'DXBNAJS,.DB0+@],)F=%%@'I<J$2<(#49L"#3PI'K<K
M<(]1@=J:,BH(=X"2XU<+4"_1EZ*4?I\R)OTFS6^Z!B7W"#1Y:R&AOXEFQ@FH
M57*,&JP8T5KPM%\/7DL?NF6C:.M2@=<L6_@!27I@MM@A$`C0W-Q,J4;&T6@T
M*0G>R5:,2,_"*-P+#S\)G-_6H>7&/LBZ^1@:&H9B9`R2WE&,3TPN1%C*%$"N
M-&!`J:/.'/#Y?+`Y"&BI`-QNDOJ='57L1^CO[T>"U\%-&96>3/'9!&KG2";$
MC`-X4G<=W3TJ*"GP_&6UUHQ1O07-3P;0(1D&52SP>#P4U(7!81/XHCYP^4\7
M'+1U#:.HI!RBQV(LYCP:-IR9<17"*#J$#EXVC`8=+#8GE8X)B#N58%6+\:1]
M$&[2"Y("SUN/7`\F2XB"XD;4<264`QFX`AGN5U2CJ[,#BVKQ.+A3@X\_0R?[
M"+K*#L/$.P-)XR4(V1=167H9=W*S4%E\`:T\.L0/KT(F9J*&14?)G5LH*2X%
MLR0;Q46W\;"!!RZ7!X5"D;NH\V"`4$[YQFPA?P4F>+O0=F4#)<=D3%<G(L!)
M`DF9FU+/-#<)/C:U5ZW%4,$&-.3N1D?]<1C5E5`JNFQZ@Y$O%+9LT6C4B7^3
MXUR,2(_9+V"B?CV8F3N@9.P&>7\C?.5K$'JP`N$'"9AFK8*;N0[.JFWP\1(A
M*5X+1EXJ0L],RU?H0O1STZ_'_`UZ8VL*J@I/8JC[`@(#A]&>OP6=.318V&^@
M-6\G5*6[8*]]%;R;E..!#^#OW8/ZV^]`*.21,S,SJ<O"X[&`UJ2^!Q[W+B4I
M8K$K5N8>A*;S4T2ZMT*<MPY5-_=C5OT^RJ[NP>@0"]&PUN`UYY,-;#JD4DD)
MU:Z3E^WG>IT\W>5RI,_.SB[IY[&Q5#S,VPY^PZ^8>\Y';\<?:!4+;/.IB,4B
MJ>,F1<F\/$/A$.V%)I&+L&M=KLF%210ABP/U]XZAM[<[@-@XC22M!3KC^&*3
MH@)*CD:C-*KT5__GL3<;[/.+>%=@-!G]+WU`AT/D.:O5!(?#>>Y%W_P)Y0-\
M^^+WN(L`````245.1*Y"8((```````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A
M=&AE<F1O=&-O;2\R,W@R,R\S,2YP;F<`````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(Q,C0@,3`U
M,34T,S,W-3`@,#(V,C<S`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````7````%P@&````X"K4
MH`````=T24U%!]0!#`X"(M\%;/T````&8DM'1`#_`/\`_Z"]IY,````)<$A9
M<P``"Q(```L2`=+=?OP```/A241!5$C'Q96];IQ%%(:?,S/?__YXXXUC3&1A
M"RV)(B+1<`N^`4I*NO1(($2%H(@H*6A1)!IN@&M``H0B)$P(QDGLV&M[X_UV
M]]OO9V8HO(F)`B0"(4X]>C3SSCG/@?^PY$4/>F\_!A*@$-'O_RNX=V4/U"U\
MN8FOP-L!H`"'R#82@X1W06X@ZJ&(GK\0W+OZ'=SL+=QTR]<CZGJ*<V[!]ABE
MT$&*!$N@NR#135'!N\^%>V_?P^8?T1RI:G9(/JLH:X]SX)S':"$,`Y1O2!-#
MG*U`<-&A.Q^(Z$_^$GYVX^GG;KZK)OF(?"YXKRF*`L'CK$4I(8XBRJJBJ6NZ
M+4U_Y25,NN[0K4]!??@X(GDJ8S?_DF:XE8]VR0M%W0`B*!&J^8SAW@/".$6J
M@B!K@P[PSK+<"UE;?PW"-9!H0U2PPR+$1:E;N-E650PYR3UU[0"'4F`"0SV?
M8[W#!(;AP3V.[M]!:8T)8_;W1N0G]\">`OZSQT1SGDFUZ>L39K.2LFPP2A!`
MB6#+@C"*>/GR.EHKN+S!?#H!U^`0K+7LW/F%J^T^)NMN_@F\QC4%=>,1[W"-
M0RF-K4I&>_<Q:4801BCQ!%%"$"=8YQ`Y>]G)<(]B,J*=G'>D.A\0.Z@:1U5[
M;&,QQA!&(>/C(W:V;[._\S--63(;YW@\WCOJLJ`J2[PRU$XSG4P!/U@,W)/,
M$[Q3U;SD]-$I"H^U%KS%-14F"%`BA'',?#K!5A7:!-1%#MX3!"$F3FFL!;Q:
M3/*36`I$N::NU/1X2!2GM'L]G*W)EGJ\<N4Z49)RM+_+X=UMUM9?Q98=E`Y(
MVQU$AT1QBM$:$`<43VY^Y@JUG201H1;RPWV*?$Q=-FBE:+4[Y,,#'F[_R"P_
MY>C!+N/A`4$0DW2Z**5(LI16IPO(]F/WG'^HA$1IARP+.;J?\^A@GU:WR_'>
M/:;Y*4H46FF2.*.]LDJW?PD=1@LA0)(FQ&D;5,RSW2+A71WUKURZO,KM;[[E
M\,$.2;M+5<W)1R/:G2[K@]=I75@F2A+JJB9,$N:3&4IK5B]U,7%_(;,_=,M9
MN;=1V=?M_@8;UP84C65\.F(ZG>$\B"A,%".B./[M5[QK`,$Y1Q9;6DMK9Q)#
M;CP#%Q6-4.E7!"ONRAMO,KA^#72`,1$H39!DN+HF2E-6!U?I7EP!$;($EOM]
M)%QQ2'0340^?;\7Z4.WOW.:G[W\@,BE!TB;I+:.U8+0G3B*6+K3)EM;.P+K[
M]U9\UN>3K6IV2#$>418S/!JM-7$:$K=ZF&@9S-*+^_SI322W\-4F?@[>#Q8#
M`F+&2+CWCS;1<W8HP'<B^@O^S_H=SPW2X^@[P>8`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S,R+G!N
M9P`````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,C0U-2`Q,#4Q-30S,S<U,"`P,C8S,#,`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!<````7"`8```#@*M2@````!W1)344'U`$,#@(U7-;I.@``
M``9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_```!+I)1$%4
M2,>M56UL4V44;MDD<PB&%3*<AA2<8&)BE!#60/B!)H+^(,`O-9&IB;B$&!,#
M9A"3+8@./_"C0R<@&\0A<[AU[<8&6^T^:+NRK5W7WO7C=MW:>_NYKNVZK=W:
M41_?VQ74M$1,=I,G;]N\]SFGSWG..3S>0SYNEUU$`.[D+??3V_F9B`#<N2R$
M?I]+$@IZQ$AZA4&OFE))=R/@[J6X[PL+47%PRFN.Q^,?W;N?3"8%!$]F$/F\
MKM6T15O&,K:R2"22`RR6#`\VL=3`UXA'>^"W58&6"<".5N#/A!+CUM^A5%0C
MD5BH2B02.210V:3?U4L^G\T@GYX."6FS$@/=GX!UZF5(>F@_<Q&ZYJ?AU^Z'
M^>9.3$IR0;5MP_3885CEVZ!7'@-W;W8V)-,JOX5II!4>MU.803XW-\OW>IA#
M^MLG`Y9;6V%3OP&GZE6</UZ`JG?7XM.W!*A\/1_B(P5HJ'P*?3^N!JO>"Y8J
MA^G62S#^<2`P/-1UB"C`SZHQ)T5PTD!3;<_#^/-*5+R]`3\<>0RJ4[D(7>(C
M?I6'2!T?NB]6HN7$&BC.;87]VN.8:!&`'FVAN?>S6\WMD#CL*C8:^@WFKI=Q
MXLT"U'^0A^@O?$!"XM[X!Z0\S%_E8^C,*LB_$F!$)L)\I!G1.8:=F0E+,L@G
M[$:Q1GX<=QHWXT+Y4L8IXE9")B?H(U"E(5\*$K_&A_%<(<R-S\'07H)NV7NP
M6C3F#/)$G!7.!CO@T.Q#U3MK4U*D,I:G"8<)#`1Z@GX"!2\5F/TI#SWB)S#:
MOAT^QQ5$IMVE]TF)?42:GFJ1477LH-=V!E3'+IPBQ>,T3DG0ER:VD6"._*53
MGP[8SB/_;@5,EXIA[]R9LFO`K:2X1B.6%O$\[G'<[CP-E70/3)+U<#:20A)7
M<,5+D:O2V8[G`9X-2P$,Z=\[.6EXN'.V$-/2'-!2`53-N]'=40'&08/',A91
M]XWC(A^CH+@&&6K:CM.'!2E7_"MS.B=KYK'Z%3#7%H-J?3'58#ZG@E+<."ER
M3EC_'A/Q>*0T[&L"+=^%B\?6I>R6H;D^?=XK*G%-\/*CL-9O`M._#['I+B07
M/9E-Q#(FL[+C*+32%R"OV8*;E068_P^WW&W@8ZJ^",9Z(88:-V&PNQR,TRS.
MTOY!221L9Q=FFDF+EZ#E]#IHB8_COV;QN62).%B["N:ZC?!J]H+K#YOE-NMB
MQR4/[%!FHIL>DQ5A[.H:])]_%H;J0K`U>2E7<$7F-.:DX#*FKQ3#??T1DLP.
MS,W8']RA9!+RQ^B10P9%:<#8L0..X0\1H0Y@L+805-TF6&J?@8:XPGBA&.,-
M6Z"[7`3?G==@4NS'1-=&Z-7BP,)\;']6\F!PBDS%'@ST?HY)/Y.>BA>@:UJ:
MBE[E'O@E*S'<L!4^W4$899OAM%3C[B)+ZP:NRS3RCZ$;:*T)AT+Y6=880^;Y
M<)G/ZRR+Q6+WY_E(_Y>(S_4@S'X/1]MZT.KWL1CKP^C@-U#W7&2Y>V,V*F?<
M;J@)3GD0BT:%#[6)N.($)EVI360:^NZ@MOT5,-:6"))^82#@%MO'C/>+1Y9$
M/H&0(/=_KSR]5B)2*ZK@<QO"R[Z@0R&_R,72\/N<1Q_VG;\`P!(8/OR?A"4`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E
M871H97)D;W1C;VTO,C-X,C,O,S,N<&YG````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,3(T(#$P
M-3$U-#,S-S4P(#`R-C(W-0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````%P```!<(!@```.`J
MU*`````'=$E-10?4`0P.`PEJHJ3\````!F)+1T0`_P#_`/^@O:>3````"7!(
M67,```L2```+$@'2W7[\```#X4E$051(Q\65R6Y=11"&O^KNTV?R'1S?Q.$J
M";*%;A(Q2&QX!;\`2Y;LLD<"(58(%A%+%FQ1I&QX`5Z"@(@0<@;L./$0SW<^
M?<[I9N'KF"A`(A"BUJ6O2W__]1?\AR6OVAA"_060`A,1_<F_@@=?S(.Z12B6
M"0Y"W0,4X!%911(0^Q#D!J*V1?3TE>#!EQ_BQ^_C1RNA/*(L1WA?$]`(-5II
M3)0C40MT"R2^*2KZZ*7P$.J/J8>?4^TI-]YA,':XTE-[\%ZA=2"V$2I4I*DA
MS2]`=-ZCFY^*Z"__$CZ;^!L_?:2&@WV&4X4/BLED@HC@ZQH1(4DL5>%P94DK
M5W0N=C'I%8^>^PK49Z<2R7,:^^EMJKV5P>$Z@XFB]"<M@E!-Q^QN/L8D.>(F
MV+R!:$/M/9UY2_?*5;!=D'A)5+3&[(-FI6[AQRMN\I2#0<!5`;Q'"=A(<,64
M.@2BR+"WL\'>X_N(UI@X86OSB,'!!M3'0/CZE&C.-''+H3QD/)Y2%!5&"2`H
M$<IIA;4QW4M74%H1+B]1C(<0/*'RU'7%VKT'7&]T,'EK^4_@);X:XRJ0$/!5
MC2A%77H.GCPFRC(B:R&`C3,BFQ#J^@1B+0=/-YD,#VFD9XY49PM2]USEJ<I`
M795H8X@32W]OE_7[/[.U=H^R*)B.!H3@@8`K)I2N((BF])K1<`2$WFSAGFF>
M$KQRTX+CHSY*P/L:O*>J'$9;E`AQDE",1GAW\G@Y'A!"((HBHB2CJFH@J-DF
M/Y-E@BA?E4Z-]W>)XH2Y<^>HJXIFJTUT[2WB)&=_:X.=!ZMT7W^#J&RB3$3:
M:(&.L$F.B2)`/#!Y-OE)5NC5-(TQ1C'8W68ZZ%,YA]*:N4:+X=X.V_=^83KJ
ML_MDG?[.-M8DY,TF6BG2/&6NT0!D]31[SCY4(N*L19X9]C8&'.YLT6BUV=]\
MQ+!_3*0-2D7$-J5UX36:G46,C4_=0)9E)%D#5,*+;A'[4,<+UQ8O7>3NG1_8
M?K).UFA2NBG]PP.:S3:7>V_3F%\@R5*<*XG3%#<:H;7F_&(3DW1F8?8'MYR4
M_P"5?]_H++%T]2I%53$\/F0T'N-]`-'8)$5IS?[Z;P1?$1!J#UGBF6MW3T(,
MN?$"7%1\B,J^(UKTU]Y]C]X[;Q)$8;5&&8/-,GSEL&G*Q=YU6N<702!/:A86
M.HB]X)'X)J*V7YZ*Y8[:6KO+KS_^1&QR;-8@;2^@M4)K3YHFM,_-D;>[)V#=
M^OM4?#'/ARMN_)1)_P@W&1'$H)0BR2S)W#PF7@#3?O4\?_X2R2V"6R9,(83>
M;$%`3!^QF__H$KWDA@+<$='?\G_6[YI"UM=0WO&(`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\S-"YP
M;F<`````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#(V-C,@,3`U,34T,S,W-3`@,#(V,S`V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````7````%P@&````X"K4H`````=T24U%!]0!#`X#&YD;U;0`
M```&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP```5`241!
M5$C'K95K;%-E&,>+0U$B1B,8C<@J1A(^^8$$I^$#QD0F.,018_SB)5&9(<2,
M,+Q`PKBX+0P%R@B@FVQ#7)@9W:6;@VVE6W?ING9K=[J>]9QMW;GT]/3>P]:M
M[5;^OF6"DO$!$T[RS_.>D_?\SG.>]WW_CTKU@)='',\B0CJJ'O9UH[4XBPCI
M^%"`/EG0AD.2!BE9'?3V.;KK-R/@Z7(@):GC\9@F%/32B41B[YWYJ53J6:(7
M%X%DK[2"'1W,$P4V3U&4#&#^=9M%*PSWGT`BU@G?:!%&FU9!HHMP*V'$Q&@=
M>F^<1#(9+TXFDQFAD)SG\XF=9/S3(G@X'%8S="?,AH,0.*J19,?X^')8ZUZ!
M;W`'G,UO0M`NPXCN-4393T!?WP!;USZDYTU-A1J'NH_#:6LF:\*I%\%)MDN\
M'C[79CP08%O7P]7[)?S6G3"=S01S80TBEYZ'\OMSX"M68[AB'9RU:R":/X3D
M.@*J/0?#AB\@"HQF;B[YQ"(X*<->4K]B#S_$6'5;05U]&T-UGV/L>CZDOD)(
MEI/PV<X@,'SV=F2-/V.DYRQLAB*,&?/!.O6(QV<Q/S]_^!XP680"61;C+MH$
M-]L"6W<)'"W?0#`6P#=T%&'F-!2Q`5'9""5H1R3@@H_K!DM=Q_!`$QA[,R3!
M`K_?`T6)QN?FY@Z1VB^[`S\I26X8VTMA;,F#N:D`HGX/E(%=B-L_QNS(1YAE
MOT+,78!IL033PB4$N28(=#/H(1WLEGI0ECI83'^"96R8F9D!^4#V77@\/@,/
MWP&JYS#LK4<@]!<C3!5"H7_`%+L?L<E\Q(1\3//[<),]AB!3!H_]`MB!:MA-
M5^`PE8%GVW!3B:1+`\+,5DW=#.^.A,2X+-HQ/G(15OTA,!T'(?4?A3)Z%%,3
MA8B)WV%&VH>X7'`[QKAO$66.P^OX!1,#O\'>6PW66@'W2"5\G@$$9%I+3O(F
ME>09A[&M!#VZG:!:=H"^1A:Q_0#XWF/PVTL0=I4BRA=!\11ARE>"*%>(\-A!
M1)V%\-I.@S.78:CM!+C.7:!TF]%=_Q:ZKAT"S[F@$G@F2]_\?9;,WW!PU'$,
M-I$]7),-4;<-LCX'DGD[V1U$]IP%#9'G@UOA[R'2;P-_=3.<-=M@;]F"2:H8
M/L'@2/,F)^E_;2(9CWP:E6LQVK8)U*G'D:HANU.G0LJ@PBT3D87<6TDTDV>=
M9'R-C.M5D,M7P%'U,CC3NXA%VY":\RP^1*(P2O>T[H:E<0-&JC(1K5H&7"60
M5@)I(T`C40\9=RR`T:!"XH\,<`1,7<Z$N?956`S[R>EV:A;!H]&P5HEPPDRT
M`:Z6C;!IGD*T\E'<ND)`)$,T_R/=0L:)RX_`??X9#):OA=BW!8J_%BZZ2Q`%
MM_:^+I@V*V'2P$S6K82[^DFP5:OA^?5I!,L?0_+2$B(5E(M+;Y>"NZ@F?[@.
M8MUC&&Y\`['I,2;]_GW!:6\9'W/D4H;/`HZ_-H(;W(.ID?=@J5@%IE*-L>IU
M&"A;">I\)B9JUF.X\@7X^G)`=^3"HW^);,<S@?CLS/;[PD.AX((K=I8@%/#<
MXXK>@??A[7P',LG21L"^P5PXF];"XRS%_)S(6$U7&DWM^V$U-YP+AT/+%\$%
M@5O!$#_W>;D\<GS_X^>E2$P;$.%.89+XN;OW:R1CW:#,&O1W50CI>>/C=(9[
MPG$N%)00B\74#]2)1'Y"&_"+FG3GH<UG/AAJR0;OTBKISA0(2!J&L=U=/&)4
MRXG41$O_=\NCK$U9)OV/D#VVR$-OT.&P/TOD&?AD;O>#OO,WY%B(G%I77]H`
M````245.1*Y"8((`````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W
M96%T:&5R9&]T8V]M+S(S>#(S+S,U+G!N9P``````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C(V-B`Q
M,#4Q-30S,S<U,"`P,C8S,#8`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!<````7"`8```#@
M*M2@````!W1)344'U`$,#@,RVZE-V`````9B2T=$`/\`_P#_H+VGDP````EP
M2%ES```+$@``"Q(!TMU^_```!$-)1$%42,?5E<MK7&48QI]SF5LFDTSFFLQ,
M8C)-)]6DM!%ML11Q(.BB8L1%(8@*NI0N;/4?<"<(79F%(+K32A$$0T$3&*K2
M6$TR21.3)I/)9>[W.6?.F3/W\9T1%S691G"C!\YB+M_O?;[G?;[W`_ZO#_.X
M'_VK?H?!T'>E5*U=3R53T&AXE"MUL*A#I5*!X7AT:56PV^Q0\?R]1"+^H<ED
M"MOM]MICX8E$XN+6=N!VM<FX>GN-T.FT+4![0:/9!,MQ*)=*4,IEQ&-QB/D,
MA@>=&/-XWK5:K;,M!M\)OK2\\JK!:'89M%KP!&J!^=;+L9#D(K+9''Z[?P^R
M+".;$U"K-5"MU.!VNZ_1\L[PW=W=YQ^L;[TOBB(&C48P#(,"05JJ6T5RN1QB
ML2@>;FWCJ3-C</9;&PS+WSWE'H9.JSG\BW,L_+//OV"M]@'>X70A$8O!X71"
M*DAM:[0:#4IDAY`OP.D:P,S,59].IYNC]^._<]CCX-.O3'^2R^7;-E3J#43(
MTU@R36H3".P&42R6<!B.H*0HJ-?KB\>!.\+W]O?=H7`,.4%$JTAP;Q^FGFY4
MJE6$HG'\NN3']M86):<&COK1Z3EBBZ(H-V;>?%MEM3MH^V7(4I$@55!RP+`L
MRN4*\GFQ';1T*MM2WA%^1/FMK[^YW&>V<W9[/R6AB&0Z@R194I05<-312&M'
MV0S`J9#.9O'=W!VG)!5Z_A%\\?X*S!8+4JD,=G:"[:0,#3FA5O$$9V'H[FK_
MSV@D'J_"@_7U-WR^NT^?")]?6%#O!+95.YN;*%*S&HTZSHR-HEJM8.\@C+W#
M,#AJLM5FH=.J0U^O"?N1%);7-F[26GU'.'FM)S]G]3K-%:7E=4&D^!6PN?D0
MJ_XU)*.'E))BNV"%?.?((UN_#7I]%W[X?OY\.!KWD?^CQS:48F>E)KV3R^?)
MXQ34:@WTW0:(@H!8Y)"4:E"0"FWE):7T9TK(,I9F#,LR6%Y9?>;)L=-3A`H<
M&5Q4E3LX"-V8G_=]Y*,3V-P/PM5GAF*UH#N70:41PH!C$1M+!13L;\%)>S;U
MFI%6\^C-9P)C(\.2U^L5'0['52J<>$0Y?5&7I*)X;G(2;#R*TY>>0[31@*N+
M%"?W8#%_"I<MCMGP``RG1N`]-XD0I8E7Y,71P8'7Q\<G@AT]ITSW!_="[_V8
MR6'08H),\?6+$F0A0PIO01**6%DUXXG!&DQH(I:GST(!BBSYC@,_`E_\Q:]=
M.XAX(IDTK#0)A4H9VE0(8OI+&+KNX-NYBR@S4]@(VF$V]B%5DF&IE07OY4N_
MGWA"C89NU#1J>(TZ#`\/7<L+PLM"^>>71CQ?8>$G)YZ]\!H:FGY,7A"4B;/C
MUP]HSG"L/DT7P^T3X8-#`^%NL3#",$V:RY4#61+4YR>D%V+)*8W5-AUUN\^^
M6&$XN6=HM.'Q>`[_]1V8S^<^V`ULWTRGTY/_N0OZ#][T^?;9)Z]P`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,S8N
M<&YG`````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`R-C0Q(#$P-3$U-#,S-S4P(#`R-C,P-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````%P```!<(!@```.`JU*`````'=$E-10?4`0P.!`TBCO8B
M````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\```%+DE$
M051(QZV5:TR35QC'W_=M"]Z8\S*S9%&+R\S<E\W%:+?YQ9AL?IE._;29C6R)
M&\O<IBY.=_."P2A30QI1!!Q##<R*%"@J.*"`I5!NI:7T\E(N[=LK+;U`:Z&E
M_'<J;"XI2USB24Y.SLDYO_.<_W.>YZ&HIVQVVZ"(="1&ZEDW17VVJ+DN&PWW
MLY\-W.VR27UC3C'B3N&8\Z%.6;D57D>++C&?G)P0^\9<ANGIZ.&_]\?CL16D
MOY0$<CEM::RQ.Y.S#F0&@T$>V;1%W7F'Z^\XCVBX&6[S61BKEX/K/X&9J`+#
MIG(HFZY@.AJN13R\VN=S9GI&K<VQV.2%)'@@X!<.&)O1T70<G*6W&G$'.VHI
MA*YB#3Q=[V/H[B:X*ODPW]V(@.%#&!O?1$_3=\!X'T(!IU+=F@.]1@:'W2),
M@H="(=KIL.Y1/_S9P]:NPT#K1_"IMD-U(14#.0*$BQA,%U-X5,!@+"\%[AM\
M.&NV(%"U&VS96_`6O`Y'W>D#1`%Z7HT34GA'-:Q1]AKL)0(,YRU$H(#&Y%D:
MSFP:CW(9N$[2B&;1"/]`PWL\#8&C`D1_I!#*3L=$2U$M,7)9\E>SCT@M0VU<
MV%<.9\O;,(L%"!73F*F@,'6>P:5]"S%TA`?I/AX&]C-HV<M@^`L:M7MY<.^G
MT?CY\VB17(3?Y[F;!!\9U(@[&@ZAJSP=C>?38+_$8.8.!=01*:XN@.Q+/MB?
M>"C[E(?VKP4HW)^*P5\8Y&4L@B5+@+P#+^#>K<]@,JH,2?#HI$4XX:N#M?4]
M2(\MA?LJ`\@(O('`_Z!1=8@']3D>;AWDH?L4@XI#?`R+:5S+Y,-VF4;IJ36P
ML44(!AP93_ZRVR9J;[H@TK8>WNT<.(>^>UN1F[$$DS=HH(;`%10B<@J_?Y\*
MDV0Q),3Z_F(&I<=X,)7P4'Z8.+:<0=FOJV'3GT8B'A(!1[ZTB'+8A]'\X`P4
M5=MAJ%@)<UD*+GZ\&)%_P<-M##K*4F%7+H6J-`4>.1\CLA2HBQ;`<IF!IC`-
MJGP^]!7+H:QX!_+:T[!:3*`X*RMZ4'-2Y+0TZFRZ$^B0O($S^]+@+)R3I9G"
MC(I"3$-C6L]#3$LCKB:OJ2>_J))&Z#H#P[578+BS$59RWFV1ZQ(\RXCQ29J8
MF@ID^%T5,#9M1=ZW*]%RG(<9*8'_.6L]R`70D-XS-T^L5U$8+5X"P_67P2EW
M(!RH1SSF2`XBJT5O4-1^@\[JS6BXO!ZWCRQ#J(1(4ST'DL]!Y7-SLAXK96"_
MN0;Z&^O0*4E'E_P(B>Y^\3SA[Y,&_4-<)%@)?<TF2+.6H_[$DEGM*ZE9B6KF
MQLI9,%?P''%N.MQM.S#NN0V3_B%GLPU+_S-";2--K%FZ"N;2-+3F;T#WQ17$
M:2GD%0RB-XESB<9>(D7"8EW).CAO"Z"5;4%HW,PFSL\+)IF09EGM'FW#)YZ^
M^YLQTGL0X[H/T%:T"GV_"6$D3E/DK((V?RU&;KT*;<F+<*O>A4&^"Y:&U>A5
MBCWAT,3.>>%C8UZAR="$MH8L>#VVQUG1;2U`CW0]7)T[,:K8AM%*`=22#?#T
M[().MA;#_6*2<CE6K9)4M]<?A;JC^HK?YULT3QFSDGRNSG2[K)F12"0IGP>X
M7%AD*V%29I)Y"_HZ<J&0YW.)?2S;SQLR:Z_XQAR(1!X)GZH2V;@AJ==C?UR)
M#%TYNWON;8/5)`TB[A9Z/`[QT*#F'^<1@Q;%8E-"<AG_?Y>\WFZIJ%U^!FZ'
MUO_,"[3?/RJR<P,@I>RKISWS%W+%"B6YDQ2G`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO
M=V5A=&AE<F1O=&-O;2\R,W@R,R\S-RYP;F<`````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(Q-S(@
M,3`U,34T,S,W-3`@,#(V,S`T`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````7````%P@&````
MX"K4H`````=T24U%!]0!#`X$*H>$0TD````&8DM'1`#_`/\`_Z"]IY,````)
M<$A9<P``"Q(```L2`=+=?OP```0'241!5$C'W95;3!-F%,=]6K;$11\6DBV9
MJ8DA<4$W,C)F:+!LL9@P6`&%,:&`XY9AN70J)<)@NM`6$'#HY*Y`D4M;V@JL
M@K3E8@%+2^\%6C08Z9@IDP(#9(3\]\D["&-/^Y+S=O([E_\YY]NW[W_[7KZ<
MWV]W/*$H^P8H@\,C%&7_X*;U/QJF#&FT%+/52EE<7*1L;&QX[`H\IC><T1K,
M=\WC=@P]UD*C-V%X=`PC6CVT1LNFZ4UF3-@=F)RT&VRV\939V=EWWP@F3C$/
M50/NOF$M=.8)3#Y]#L>T$U//G!B?FH;-,0VM:1RC!BLD73VHK;V#GEXEW`L+
M==N"29D'16))DUHS!KW5#J/-`8O]*8$^(_`9Z$PV=/6H\%TR"]',>,2?3P"/
MSX=&H\'JZFKKMG"%0DEK:FZ#^+X<(SHCK`0\:K1MFFG<@1[5(PC:I*BHK(12
MJ2+0T?7>WEZ.T^GDD,0.;`LO+"H.O5Y6#J&T"YW="I*I%3*Y"@.O6T1:T:T:
M0''9;71T=$ZLK*Q\LKZ^?GS'0C[6:%=9;`Z:A%)(.A^@L54&V6\*-(L[4%%W
M#V6_UB#Q^TRT"D7Z78]?47'):E(J&W4"(:KJFW&CX@X$0AGN-K?C9NT]L"[F
M@7$V%C=O5>P.[G`\$81%1(/-R0.?E)Y7<!U9N5Q<Y96CN+P:%Z\4("[Y!T1$
M)R,T+,+>-Z@^M&,XK[!4DOT3'^SLJR1`/CCY?/!*;Z/T5AVJZUO`R>/C[+DD
M,!/2$!.?@KQK7.Z.X9'?QDDB8Y)(=IF(CD]%=4,+?JFLQZ4<+G)_+D$^]P92
MV3FD-;F(BDU!7"++:319^M\(;F@4'#EU.F0TB!&YF=VY^`O@E54@D96%UP$S
MLO()O!0IZ=E(NY1+JN`A-BD=K(S+?[>TBJA;@LE(O2=H:AGR#PB$UW$??/H9
M%7[^=`30@^'M0P651D?X-TQ$,1,0Q(@B@D8CZ.L(!'X5CA/4+Y#.OBS9$DYF
M]0-2WO/4"VGX_(0?/O;VP4D:#0Q&*&@!7\+KF!<\/3UP].AAG*('PO]D`$)"
M&`@.#D%8^!FT2Z2OR'8RMPPP,S/CJU:K[6*Q&`V-C6AK$_Y5557-+>1?L7&O
M?82B@G?P8T[4*Y%())/+Y61#J\IELOLJXM>DT^FX:VMKOMOVG3AXN=UN&CE<
MM+FY/_T4B@?!'9*@%_J1_;#HWD:_(FF>^'@L+R_3EI:6WB*G]A"Q@[M>)I=K
M-M2H+X'#?``UE0ST]QS&\&#D_)X_"2(P0Z>IGILP?HB'7>]C3$=NC(:#,6WS
MWN$CZ@SNE.4(NJ2^Z);7.)>7ER0+"W_DN%PS]#W#7_S.XQJTF5`HVJU$:.__
M].\D8GE..29.NURN8_^6\0_]-+5/<^.9W0````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S,X
M+G!N9P`````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,C$W-R`Q,#4Q-30S,S<U,"`P,C8S,3(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!<````7"`8```#@*M2@````!W1)344'U`$,#@4"JRK:
M\@````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_```!`Q)
M1$%42,?=E6M,DU<8Q_VT;(F+?EA(MF2F9@N9<6YS<V$$(L7%RB(P2H!N`L6A
M6`R4FS!*!`'-6BIR&4BX@T+!4EI*$42ZMJS4`BLMI?0"M&!PT#$#D]L`&2'_
MG?$=A+%/>Y-_WO/A.;_SG.=V#ASXWWXO7LP?M#LF*,J>7HJFKY^B5&LH*B+U
MDSY*KTY/,5MLE*6E)<KFYJ;+GL"#QJ$@_9#YGGG$#JW.")UQ&'T#@^C7&Z$W
M6;9D)!JU.S`V9A^RVD:B9V9FWGPEF!B%RU4]"^H^/0SF48P]G8)CTHF)7YT8
M&9^$S3$)_?`(!H8L:.V0H[JZ%G*%"@N+BS4[@LDU#S=+I`U:W2",UC&8;'98
MQB8(]!G&GTW#,&Q#A[P;4=$Q"&-&XF(D"SE\/G0Z'=;6UIIVA"N5*JJ@401)
M6R?Z#298[4\Q8+)M:7C$`7GW$S0T25%67@Z5JIM`!S84"@7'Z71RB&.'=H3?
MSLVEYQ46H[FU`^U=RBU/VQZKT/-/B$@HY-T:\/-+T/:P?71U=?63C8V-CW:=
MR%]T^K6XI%0(1%)(VQ^CODD&V2,%A)*'**MM1%%I#:*NQJ-))#;NN?QR[^2O
ML6*34"-H1E6=$#^6U4+0+,.]!RVX6]V(N.1,T$.8N%M2NC<XJ6E!8$@X$CE9
MX!>4(HN;A^\SN+C)+\*=XDHD7^<BXLHU!(5&P8_.L/^LT1[9-9S+SY>F9?.1
MF):-),Y-<#+YR"DH0T%)-2KO/T!:9@X!L\"\S$;HQ:O(NL7E[1K.N!`A_28\
MBGB7@+!(-@$*451Q'RGI/&3<RD,6KQ"QUS+`3KX!1C@+$9=BG*9AJ_J5X+IZ
MP?MG??P'OO(+WMH8&AD+?F$Y6.Q4,)C1B$O))/`"1,=SR#J#W"H'W['BP$Y,
M_4O8)/;<%DQ*ZBU!@[#WM/<Y'#_Q&4ZY><+#BX8S-']\^KDG/*DT!#%"<8%Y
M"><#&`@(#L/YKT/@XQL(=X\S2$A,D6X+)[7ZCMEBF8IA)^$+=P]\?/(4O*C>
MH-,#0?7^DAQX'*ZN+CAV["C.TL[AM)<W?/WI\//S1U!0,%JDK2])=S*W/6!Z
M>MI-J]7:)1()ZNKK(1(U_UE14<&[S;]N^R'[`^1RW\"-]&]?BL5B66=G)^G0
MBF*9K*V;V#7H#0;>^OJZVXYQ)P8?+BPL4,G@HL[-_>&A4G7YM4M]GQO[#\)B
M>!UJY95Y8N.RLK)"75Y>?HV,VB-$A_?<3+.S,W23,1\.\R%4E0=`+3^*/@UC
M?M^/!$EP@$%7.3=J>A<_=;R-00.9,3H.^3?L']ZO3>"-6]]#1ZL[NCJKG"LK
MR]+%Q=_3Y^:F:/N&/_\MAS>DCX=2V6(EB3[YG[Z=)%FNXXY1G]G9V1/_EO$W
MN2.U0($`""L`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K
M+W=E871H97)D;W1C;VTO,C-X,C,O,SDN<&YG````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,S<T
M(#$P-3$U-#,S-S4P(#`R-C,Q,@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````%P```!<(!@``
M`.`JU*`````'=$E-10?4`0P.!11?_F^C````!F)+1T0`_P#_`/^@O:>3````
M"7!(67,```L2```+$@'2W7[\```$B4E$051(Q^V4:TR;913'2?QB-,9]))HL
M^\8'LXQIR**)"]M(MLAT&1")`P'+P,)0+AUR:;F5L4*YO+1`H>52"I0[+;24
MW@NT!<JE+6!I(3K8!!3%*<WF($'V]P$3M!J3&?UD/-_.\YSW=\Y[_N<Y?G[_
M>2OG"T]^PL@^I=;H3OXKP-75U1=<KB5Z664UG2^2/*%JA>B5*9X<^A;K1,`_
M@H^;S0*AN`-M77TPFB?@F%^`?M2"TNIZY+,Y]M6UM:J_#55IC2?4>I.DI%+P
MM*-W"#+%"%JZ9.A7:"!7:C!JF01/),'[<<E/J_AUNP)1<\HSP\MX#<$<J@%]
M0VKHQZRPVF8A&]:B3Z&&=6H:0R-ZE%0)D)B1A[#H1(1&W-CO&5!\^)?`W=W=
MYQR++G]QN]1?KAQ9XO)%4.G'C]K0,ZB&4-*#+ID*6I,%!9QJT!GYZ)2-D*1Z
ME/)$:&B6[+B75VCLTBK_1X\?O^0#)Q6=&B35B4B/ZYK:"&@8O:3RGL$1E->)
MD9#*!+.$A]P2"AG,.U!I#5A>^0*SC@4HM6-HD?:AI((/9G$YM,9QR@>N,XPV
M%'%K4-LL)<&C$'<.D,K'8)UVH%K8AACZ;4BZY;^>3<U@T;4$^_PB.OH4J&EL
MQPQ)(E/I\'$&"TPV9^6[[>TSQ_"<@F(/3]2&QHX^.!=<D/8/$Q$'45@N0,X=
M"BJ-@9POPNU9AF5JEL3U@W67AQL)J4C-*49KEQR,O+L(CTU&)K,`=KO]RC&\
M22SQI&;E0]36>]3C0FX=$M.9B(A+`9O\T:&H&L,85#H3#B?HUF=%N!I)PZ5K
M48A)RCS2(#HQ#1_$)X.1E8OY^?G?X/>_VIA+Y3<B)"8!P=<B<#X\"@&!00@,
M>1<!IU_'];0<G'O[`D+I:0BY&H:@=\)QYLU@G+T8BJ#0"`1>N(+ST3=Q^HUS
M$(I$>UM;6Y>.X9[M'V-S-1:\EYB""F$3<DHK0*/J$<[F@L9BXR-Q-^)H\:B0
M]B*2EHC8+B4NAD6"=CL;29FYH#>T(Y)=BN*R*N_ZQD:,CZ">K>T$)FE)36,+
M&B;L9+[-8)NFD5K(P;!Y$CHRW_VV.72;S!B:FD.2=!#I[!)4D8DR6:Q@*$Q(
M8G.(T"Z/#_C@X.!5_<I]NWG6@7Z'"_%$V/J65DR[/%!/SB!?/P%19P^X,R[<
M9!7`/.?$A-T)2F\!3=`,L;03<YX53-JFU^_=6WW-!_[-SB.*9;8CCUN)BE$;
MLDHK4:XR(KV<C_:9>43SF\!M:D4ZJ;:XFH\BI1$M_7*P%`;D\`1@#VK`:97"
MZ73*]_?W7_:!\^UN*KE+@?K&YI_7OMW>M;G<8&FM2&(5@F>:PJ=<"@M+[CWW
MZH-=M7WQ(+Y;@5JA")X'ZWOCCH5]INUS,)@L6*W62@)_W@?>ZUBBQ'+E3SJ=
MGG[H?_F#UT219SUB,.X1DWN]7OG.SLZ+AW?M3O<4-:"$S6:SD[,3'0Y/-L\X
M@0&9[&OR<"[_::^0GK]%,D;];L^\\OW#A_0=KS?FC[$DV76RY^ED(H[V.?GN
M[.;FYJ%_V>]_>Q;[!0\!/:T4[0NE`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\T
M,"YP;F<`````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#(S-3$@,3`U,34T,S,W-3`@,#(V,C<U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````7````%P@&````X"K4H`````=T24U%!]0!#`X&!1YC
M')(````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP```1V
M241!5$C'[91;3-IW%,=]7/;4+'M:MJ0/>URR+%O:+&MVL75MTZBS,=;82[05
M1[56NU:GM>*\(:#R1U$$5`3Q@H`@"%[X"P(B%`'%6K5BZV4V6^IM=?$6C'[W
MKP^F36O2-'M:=I+?R^_W.Y]S?M]SSB\DY'][5_.-CIUB%+'IN05,^I.9V81_
M!;JRLLJUV!U:ODCR5*Y0HU6E06.K.MC0U*9=6UL+?2?HQN;FD<FI:5EY5>V>
MN+$-AEXSG&XO[GN&T6L9`(L0HIA-!/L'G.-^_^CW5*`C;PUW>WRRZKI&B&0*
MM.N[H::6I$4#94<7NLE^D!8[2@@!PB\D((M1"(&X0?96X!=9\(7UVU*%%J1U
M$![?"!PN-U04V&QU8,@W#)Y0BK3L8MQC\I!P(PN1L5?W^LQ603`8?/^-T.65
ME2BY0A5/`7R\F@:T:(PPDG8T*O7@B>0HJ:B%K$V'RMHFT-+N@L438L#E09_-
M"6FK%C5B"13M.FEQ:64\)>NQ5^!-"O5D55T3!'5RZOG=J*<<#"8;FE5Z9!5P
MD70K!YPJ"3+SRU`K;8'_P4-,!0*P.X?0T6W9OU=-^6;FL2`0BH@#L,EL97(J
M1+O\NF9H#29T]EK1I#901?1!KM3A%P8+^:55<`X-8^3!V#[8ZKB/+M**?$XE
MR@42>(?]:&AIQ^7K&2@IYV\O+2V=W(?_RB@B"*$,-0T*#'G]5`%[\")0$5=(
M:5N$9K4>P_XQC$\^PL.)2:CTO2BD.B8A]2XB8FFXD\<!FU\/6GH.XI,S4,#B
MXO'T])E]>.#Q##./R=TM+.-#+%>A@,HR*3T;YZ\D(RHN$3RQ;#^`6-J*9HT!
MO[$K$9-P`Z'A<3CUTR5<_/DVXF]FXTI2&N+BZ>!5\C$[,W/F0)IGRZO"@K8.
MG+A&QX_G(A!^-1F?'?L&9Z/C$,GFXWCH:5R@I2+LSCV<^"$,D3$7\>7I"'S]
M71C.7[N)LX4<7$I,0BZ#@4&7>XHJZN<'\/KAJ:/%5@_.T>B0*C4HJV]$4W,K
M^,8^1(OEX'!YT/<[D$Y4H[9.`H%*A[(:(:JJQ$A5&)`BK(-&VR$UFRWQBXM+
MKW;+[W_][6PGS6AM4Z+(.H0D+A^34P&0_G%DL`F03C=*30.PN#TP><=`;^]!
M>U?O$X=[1,*0-D.MTSW?W-R,?JW'%U?73C*]$XL9!!].GQ\T=1?2<ABP>$;!
M[K'!8K-#1`6,$3:@Q]*/2M*!J!("UD$WE)XQ-/:8=RB-+[]Q@-2/YHD4LPN)
MUU,P/3L?%"M4T'<:P1\<02R+AZX>$KG==M`*F=!J.S(--@<J*&FZ!SR@:TS@
MM:FW#AUYW=0\D5%&0"@2S5)Z':?&6/GTCV=:5J_U^>VL7,S.S7N<+G?0:#1.
M!@*!+[:VMK3KZ^M:->G83J3DL[M<A\,W-C:)\8F)Y<Y.P[<O[WN]WA&;S>:D
MGOSI^L9&`O7O?/7R^>S<W)\FDL3"P@+G4/CN[MX'.SL['[]6B\6ECZCUX6%^
MR\O+G\S-S1^E[KP7\I^R?P#<:#&%9C&U^0````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]W96%T:&5R9&]T8V]M+S(S>#(S+S0Q+G!N9P``````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C,Q
M-"`Q,#4Q-30S,S<U,"`P,C8R-S4`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!<````7"`8`
M``#@*M2@````!W1)344'U`$,#@8:DVL19P````9B2T=$`/\`_P#_H+VGDP``
M``EP2%ES```+$@``"Q(!TMU^_```!%E)1$%42,?=E<M/8W44QV?A0J,+38R+
MV4C,N"/&U;"=C8:%"Q<NC(D9EOX#8V9ET`TCSH",$T">!2E]3I_T01^4ODM;
M6DKINZ4MO>WM^T$+!H;QZ[E=,#%,%(V)B4U^Z;V_<^_GG-_W/.Z-&__+7Z_7
MNYE.9P98MCP;"`1B-ILM5B@P?I/)-'!^?O[&/P9WCH^'C@I,(9[,H%9OX.3D
M!)5:`S:G%S*9"J%0B-=H-C_[V^!NMSO(%(O)3*Z`<K6.8KF!`EM'+,T@E6,A
ME9O!6Y5!+)&V69:5D^/!:\.SN7R'K3;0/3D%6VW#[4]!K?=BQQ^C^R8T1A\>
M38DP/:_`@_&?Z22*;K%8_&L'S5;GRX-([!D7*4,1AQ-%.+PI;-E#8&@OFBA@
M36B&WAS`;BB##;T'/SV9@UZ_*3\[._N4UEM7H(U&0QX(!(.)1+*=+Y3@"Z7@
MV4W`9-V'4&;M+Y,U!*%T&YLF'ZJU%HY[/>28&B+Q++0Z0]M@W*H+!(((L>Y=
M@H^.CF[[`P>E<"S?U]3A/8#1ZL=AODS744Q-2Z#0N!!),@A'#M$Y[J+;.T6>
MJ6(GD`!;::#6Z,#B"./!]Q.8F9F9O(13YB?WHQDH=6YD<B7$,PP"!X>()!C:
M\T"E<R%U6.SGH$=5DZ8`7+XHGJKL6.;KL1_-PN&)X!>!">/CCS$Z.OH"OK>W
M-YG)'1$LAQ)%X?;%L;&Y@Q6^`>MB,U5,$\?='JCN428YM$8O)5.)AY,"+/"T
M$"MMX*WIH=BP$WP"L[.S+^!42L/1:+1F=[JAUIH@4^HQM[".AQ-S^/'Q$K1Z
M,\P6&WP^/RQ6%_A")2:FEO'#HT7,SJ]#)%%#KM1A72#!TM)2+1Z/#_^Q:3J=
MC[/9[&DP&(16J^VO:"SV6RJ5.K':;%PU8'5U%1L:#187%R&7*^"D8.QV!SP>
M#]GU_7V[W3[\LL9YG>19X.#T`%0J%79W=UF*8F1[VPJU6MUWN+*R`JE4BG`X
M[$FGTWH.GLOEL+6U!8O%PCFZ>P5.L@Q8K=9+@$0B`<V2>^3@EMEL]G`V#JI0
M*+"\O(P=KW>$YLNJW^^'4"B"2"2B`#9`][$K\'*Y?+/$L@6OUXN%A<6N7"ZO
M*)7*#SE;,IE\4Z?3!3A9*+I,(IG@DOM-HU'_RN%P5!*)1(@[&4GS-07Y]DN[
M$\!0)!))T@,62O(80:=(IOLTP.Y7*M7W6ZW6&$$_H%8'M^KU&FAJ6EKMSGOT
MWABMH3]M_XN+B\'GSR]&6+:4ETJ?0BP6PV0R([BW]PXY?X7L\YS&7!*YO'`Z
MGYV=?W3MP<4PS!W2&VMK:W"Y7'VM?3Z?F^"?4R*;!H.A'SF?OPZ2!23IK]>&
M-YO-.]2U_<@HF03A<Q7AYFP:C>8+A\,)^@>/Q^O;:7Q<'TY'?[50*'PK%`IC
M-(AB3J<S1@YO<3:JD"<<>--@*%$"GY'CZ7:[_>Z_\NFCNG\M?'`PZ?7Y;AN-
MQN]D,MDG_\DW^'>LX.MGIJPOSP````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O
M-#(N<&YG`````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`R,S$R(#$P-3$U-#,S-S4P(#`R-C(W-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````%P```!<(!@```.`JU*`````'=$E-10?4`0P.!B_%
MV-5$````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\```$
M5TE$051(Q]V5R6\;=13'>^``@@-(B$,O1*C<(L2IN?8"RH$#!PX("9$C_T!1
M3RAPB1K:F)0J25N;.B&.G=C8\1+O2[P[MN,%[UOL>&R/G7@<.[:#DJ9\>>-#
M*Y0*`D)"8J2?-+]Y,Y_W?M^WS)4K_\MK,!A<+19+8RS;7(I$(AFGRY5AF%K8
M:K6.G9V=O?:/P;WCXXEJM<9D<B4<MML8#H=H'G!P>H)0*C6(Q^-BKM/YY&^#
M^_W^>*U>SY?*#%@",BR'>K.-?*F&0IF%0F7'XQ45-N2*;H-E58/A</S2\')E
MO\>VVA@,A@0_@B]<@-88Q$XX0_L.MBPAW)W?P,(#!6[/+M))-OOU>OVO'1P=
M'7V>3&6>,(TV1<LAD:O#$RS`[HZAQK:1SC%8E=E@LD6P&R]ARQC`#_<?PF@T
MJ4Y/3S^F]<8%*,=U5)%(-)K+Y;L5AD4H7H!_-PNK,P:9TDEKF^[CD"FV8;*&
M<7!XA./^$.5:&\EL!7J#N6NVV-M2J33%<=S-9^!JM7H]'$DT$ID*:=J@2),P
M.\,H[;-TG\;\@@*;6SZD\PP2Z3(HV>B39/NU%@*1'!HDW0'7@\.3P,SM.2PN
M+@J>P2GS@D1Z#YL&'XJ5!K(E!I'D'E(D@=H0@(:>Y_?JZ`]/"'I"[[#PAM)0
MJ%UX+#'B%W+H]B?QD]2*V=E[F)Z>?@Z/QF*"O4J58!4T6AWX0UGH3#L0KYDA
MD=NH!#LD09_``[3:71A(E@6A!G>^ET*XK(=<[2$G)FSJW`2?P]+2TG,XE=)D
M*IT^='O]T.HM4*H->"A<PQW!(PCNB:`WV6"SNQ`*A^%P^2"1:3`W+\9W=T5X
M\&@-ZW+MZ!NI5`Z1Z,?#;#8[^<>FZ?4^+)?+)]%H%'J]?K3HI=\*Q<*0.I.O
M!JRLK&!K:XL'0*7:A)>"<;L]"`0"9#?2<Q%<+M?DBQKGU5@L)N3A;K<;&HT&
MN[N[+#F8VM[>AE:K'3E<7EZ&0J%`(I$(%(M%(P^O5"JPV^UP.!R\HR\NP-/I
M])C3Z1Q%Q@/D<CD?Q4UR<,UFLP5X&P]5J]40B\78"0:G:+ZLA$DJF6P=Z^OK
M%(`.M,]<@#>;S:O4RDPP&(10*.JK5*H6@=[G;?E\_G6#P1#A9:%3E&A/W3OX
MFN/:7WH\GE8NEXOS)R-IOJ(@WWQA=P*82*52>7K!08-JAB#S)-.M*L/<:K5:
M[U+WSA#T/6IU\*O=/@1-34>WUWN'OINA-?&G[7]^?C[^].GY%,LV]A6*G[&Q
ML0$:L:!\O$7.7R+[(UYC/HE\7GB=3\_./KCTX*K5:C=(;ZRNKL+G\XVT#H5"
M?H)_2HGLF,UFT-2$1+(VJA:2]-=+PSN=S@WJVE%DE,P1A*+U\S:JF,\\'N\H
M\7QB>3N-C\O#Z>@O,PSSC4PFR]`@RGB]W@PYO,;;J$+NZW0Z&$VF!B7PB40B
M6>AVNV__*[\^JOM7$LFD(!@*7;=8+-\JE<J/_I-_\.\1`.M1RR!1C0````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO
M8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\T,RYP;F<`````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(S
M,30@,3`U,34T,S,W-3`@,#(V,C<W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````7````%P@&
M````X"K4H`````=T24U%!]0!#`X'!0=X+=,````&8DM'1`#_`/\`_Z"]IY,`
M```)<$A9<P``"Q(```L2`=+=?OP```19241!5$C'W57+3V-U%)Y_@(4+7;B:
MA0OCQLQ"^0-<."M7)JZ,\;'`Q,SH*#J2`8-`"V&8BXQ"`2D,E#XH[6WINZ5T
M@#YX%*&\+L,S4%J>27EV8'A\GO.+D7G$2*)QX4UNVIQ[[W?.^;[OG-^5*__+
M*YO-OKJTM'1U=755DT@DE(F)"263V8F'([&7_Q'PWMY>;C*92L[,S&-A<1';
MV]O8W-S$H]EY!'NBPR,C8WF'AX?O7PH,P"MTRV=G9W)O;Z_<U=4U:[%8X?8$
M$.CN@=<7I-^'D.U.Z/0RJN\WH:FI><=H-,IC8V.RR^62@\&@/#0T))^<G'SZ
M/`57-S8V$`Z'T=+2@K*R,K2WZU&F4J&BH@*UM76X>[<*G/#'DA*H5&H8C29Z
MIYW^J]#6ID-U=34J*RN1R62D%\!75E9@,!CH(R.!U<+E<N/>/4E\K-/IT-#0
M@%`H)&)55570Z_54?1,D21+QTM)2F$RFS:.CHW>>`2=.78%`0``3)3";S7"[
MW:BIN4\5_836UE9HM5IT=W>CHZ.#0+6BD.;F9JC5:I#8HENWQS<W-36=\R=P
M.IU^>W!H.&VU.6&SV1")1"#+,@8'!Z$NKX#19$)C8Z.HU._WDZ`]?U2M11,E
M+"TM@\?C@:9!"X<GBJ'XR`4M4U-34ORW!'ZI?P"K;$-?7Y^HLK^_'[>_OP.G
MTXGZ^GI1,7=GL5A$5R0\5.H*:#3TS&S%SW4&V!PQF,R6"_"9F1GIT>PL^L,#
MT+4;</.K;_'%C7Q\\MD-?%=0CCN%Q2@N+D%A41$*"XMPZYL"?$S//OSH<^3?
M5J.@L!RW\G^`SN@CC`0<#L<%.`EPG:K?BD2BQ)D?MJX`]$8'M4F</K!0-T[X
M`R'1R<#``.S.;C1J.U%9]2L]EV$PV1$,11!Z&":WQ;9H'JX_[?$OCX^/LUM;
M6X("\BMQ:D`B,8Y%&B#R,,R=G8+G3OKU>KU4A!>1:`P^?X!$;0'Y6\2I2.7Y
M`9+.S\]!$\<M";Y93+O=#D51A)CL$G911X=9%#`\/(Q4*B5\;K5:0:80G2TL
M+*3(Y]>>`:?)Q-S<G!@,]C.[@@=J9V<'T]/3PJ)\,Q@+.S\_+XKI(>>PP!QC
MEXV/CV-W=U=Z&CR'P-]\_/AQDL'JZNJXRG0T&LURTM/34^YD@>U),4Q.3H(I
MI/TC_,U%\5QPE\ED\BV*Y[RP7XB:7`)3DQ7;::@\M!'37'TL%L/Z^KJ6DY`V
MHB.V*VO#])`A3NA]-254'QP<O/17R^L]ND.49)1!N%5>`TP3NX06DA#8Z_6)
MZ61Q.1%1]/5E-F,>"\M4D#`"E(>&>6YM;</&QB;1$A/B^GP^+"\O"P/05GQ"
M5^[?@;]!X'D$_N0PFQ7NT&@TM%]J!#74/D@7$6?;L6OB\3CSS.#O7J;Z(DHP
M30D46L$*<:J,CH[2"911.$8)%*(H15/-^V2%3BBFZH-_[?@CT:[M[^]+).#K
M:VMK$OG]M?_\#/X=%^-$NJM;MP<`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S
M+S0T+G!N9P`````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,C<U,"`Q,#4Q-30S,S<U,"`P,C8S,#0`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!<````7"`8```#@*M2@````!W1)344'U`$,#@<7
M],%<FP````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_```
M!75)1$%42,>M56M,DV<8K:)!40S+_&%T,Q`3-]V/J=.-Z?RU+&0Q(=.QN2W+
M7,R2L;`M1C.3J5-'IFP!1"X"0KEU*U#`EEZP2+GUPJV4%FA+Z07:4EKX^O5"
M02Z]GGTT&<D&2USFFYSD^_&^)R?G.=]Y:+1G/'->:X;-9L&TS99,>]YGSBGT
M"GAE8+'J_C\YL'+9[9[5D4ZB`&$BT3>1X6,^^`0&O5J#\'1BP.\K(`A"Y_?[
M+__U)A()OTAAWSJR4&CI_+AN,-UB,:=[O=Z82,B1I5,60]1:C<"B#(NJ(ZC-
M?@6#LAQ$_%VPZBL@X+$0#`:RPD$BQN.VI!-.4AP,!G/7D0=6')^:QW\'E_T0
M5JN9AY#-,*?Y&'6Y;\(@3<.\,!ZUMQ/`JSB)X$0*!/1CZ!3>`<(.P[*WE2?I
M*$%?_P!L]MG$=>2+GM9-R_;,;UV#I\$J>A\*X3<P=YS`@TL)N/GY;F1^^0(N
MG4O`M:^/091_&'>_VP=U>PJ>ZL]BE/\:\N_=)A6*P7..&6+3O_B\G!XD*N$3
MQ.+AY=THO+(?HEMQ&,N)@2)_+WKH*5!*6)#WBL"LSH*(?A3&VNW(NW$"ZM%N
M`Q!\:P/2X`\D,:8R&_MM"TX&3"V'47,E'I.%6S'/W`QYV>M0#CR!4:_!+.$$
MY2TFS%.H8]8@Z\=4-%>E8'FN`0OS=MO"P@+GG^2?N>U-C0;IAY"6)Z'Z^LN8
M>;@%_L;-4%0?QTAO(UPN$O89)P:')]`[,$:1V]`_I$=A23.*[F>CKO(BZAFW
MH%&/Z-:G946;&)BKAT/V#H0_[T*$18.K+A82]D^8F24HM2X8)NV0R<>A&C5A
MAG"AM4,)-E^&MBX5RLH9:&RHA(LD?%0<OXB2NHF!9)7L^V13SU=GO::[4').
M0I.[$]*\@V@I_P":$3FT>BO4XQ;TR/7@/AZ`I$^##LDH]=V'28L=I,L%LW4:
M/!X?@I862&5]]5JM-IGFGFF'6G81QM9#</&WH_[&#@A^.X(^"1_#(\-04BJE
ME`V35@>>="I12A=@4&6`0J6/$GL\GM7X06>8@I-TPV2>!H/9#+E<#IK;SDD>
MZ_DHV6,3:!R:ZV@K.XXG#7<A[AV%2CT1O:S6F3%&J6]I4Z!+-D(-E:1FX(J2
M#@T;P1/V@\/OP9C!B@[Q"$K+F6AO;\.:Y\$5PX7EF7P8A<?1Q<V"T3`.J\V!
MT3%+5'$U4X2VSJ&HNE4;5M&KT(->+41!,1L-'"G8@CYJ!KVHKF&@N[L#:VEQ
MV3ESRM8TB)FGT%V9#!/W`J3L6Q#6W@2C-!-%.3?`*+Z*#FX>1$V_H$]$1UU-
M'DJ*<E%27`IZ21:*BO+0T,0%F\/%T)`R9RWG"SY"Y?-:;,M>!LS<)(@R$S!;
MN0/S];$@67%P1K$-\YSM\#"WP5>U$\/Y5!WD'H3DT1D8-0RHE&*;7F_D"X6/
M]VBUFMB_Q3$2)M)#]JNP-.X"G<KZ4-D!.*L2X*G<BE`M#?X_:)BKBH&S,AYV
MQCYXFW=`6AP/>NX9/%VP;/R'1M5'YO<'/&R]57P:Y;GG,2RYBCG%V^C,WX/V
M@@,P5B1!G)<(36D2IEF[P<T^`'+P/7CZ#Z'Q_A&TM`C(I:6EU`W)PR&?SJ2I
M0#.;#I(DHJTXKTT#\]X;T(K3$)#LA8C*/R/[*%:TIU!QYU6,#5<AN*(SN,WY
MY*/:/,ADTA*JKN,V['.]7IT^,^M*IQ9`M,_'E85K?1Z:2$53WDO@/[J&R!(?
M`UV_HEW$M:U:$0X'4B=-RA*2=&)Q<3'QF38104RO;:(`6>QK*GL7_7V=/H0F
M$SVNZ0*]<7*MI"A!<102*6SYSVO/OS#@%7(R830:O,]]0:\LDQE34R;8[8Z,
M9WWS)Z]V?1:A_-;1`````$E%3D2N0F""````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L
M;V-K+W=E871H97)D;W1C;VTO,C-X,C,O-#4N<&YG````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S
M,#(T(#$P-3$U-#,S-S4P(#`R-C,P,``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````%P```!<(
M!@```.`JU*`````'=$E-10?4`0P.!RJLJ1"*````!F)+1T0`_P#_`/^@O:>3
M````"7!(67,```L2```+$@'2W7[\```%H4E$051(B9656TR:9QS&>[';)ENR
MNUVL%[O:LF2[V9+=[&XQ6[:UW5)K#S:=UJ[:M=IJK;8J'BC60U$\@`HB*@HH
M?("`R$$!141$/%0HGK&Z5JM23]4J\NR%I6FL:YM]R9,WW_?E_3W_[_\^[_L=
M.?*>*[C_XA.BB+?HN_?-?Q<XA:@C&%C![M84-M<\86UO>+'_<A[!O:4E\IY)
M5/A_H-\$]S<]@=V5G8U5)Q;_MN&QKQMSLY:P'OMZL/"X%ZN+O=A9'\/^WDJ0
MS*DE.OI^>&"M8._%%):>],`WVQV6UV/`([<!8Z-:C'M,F)HTD7L]W"-M6%ZP
M(ACP@\"%[S0@+]."+V?W_4M]!&H)0T+PZ2DS@>E@UO/AM+>BOU>,8:<"+H<,
MHX,4_(O]KPQJWP:.#0;6]S?]PYB9-F-RO(N,EC`\--JM$A@T->BU-$%82T>G
ME@?/0]V_)OT2;/F'B,&&CW`^>Q/\$9$VL#V-I_-=X19,>#LQ00PFO`98S4TP
M&^M)>_3A>Z.6"T,[%Z-#ZC#<8JS#S+@.^[M/0M4SWX0?"P96\7)C&+X9<[@B
MAYU"ITX`H;`:<J4"4DH*OH`'G89'OD),JI5B:(""O4<$O;H*O5VUV-N:>`M\
M;QG/G]DQ/=F%+D,3RMF5X`J:H&S7HZ_?230`5;L!C"(6"HMRH:"X<)#>A]1M
M%$`A>8"-U1&$XTOVQR'XXGPW;%8I2E@EJ.(WHD6N@;!5`;Y0`I%,!4.7!0J5
M%M=2[^)45!0R,I)AU-7#9A%"0Y5A8R74]Y600<0A^,RX$9P*!D02*;K,5O0/
M.&'NL4%"P*&QRV)%&HV.Q+0<T`L?X$)</-*S:'#86DEK.&111PE\_2!\_?GR
ML95GD^@E"\?A\M$J5Z.-M*"A28(R#A>,XC(T-DN06UB"A.0[$,O:8'<XH=(:
M4,+F@<7*1X.@'&O+KE>1?`V?F)BB*CAL5-540=:F1;V8"L.%8BG2:0S$WTQ#
M:04'MS+SR',]QMP>/'SHAE*C@URE`[=>A*Q[Q5#*:A'8VQ01^(=A\,+\W-?<
M^J:%JCHAI$H-U%HC1%(ENJU]X<I#P(KJ.KB&AL-0NV,0^DX3!(U-R,R[#S4Q
M4ZH[</-N'DZ=.8>!0=?KM*PL+S/+*SG$O1E6FQU2N0I%S#)D,YBX3;M'S,@V
M]WC@=C^"<]"%*EX]4N[2<.:/2S@;FP!Z`3/\95>3TQ`=>QDVN^,U?'UM_6A9
M975'`;,<G-H&Y!>S$)>0A!-G+N!T]$6PJ_FH(VD)Q;)!),75I!0<CSJ/B!._
M(_+")<1?2T)4S!7$7$U&[)6$G>&1T90#.??.S-VBE=4@-OX:+MW)P4_'3^)*
M%@,__'(2L;=I^/&W2$03P-F+E_$S,3T5EX!?R1@5GXC(\]&(2:<A-9.&1K$L
M^]"YXAAQ>U+9=6AN:87&U`T.OP%%"CWBXN-`%]0A\MQI<#D,I*6G(J.D`I$)
MUR%LKB0J![N6AQL5/"C4VEW_ZNJG!\"D+5^:+-;Y8A8'?*D*#\HJH'>.XD9F
M+B0*"<FV%`:C'"55%7`-R%'-YR$]XP[*&R6@%$K(^ES(8A1"U6'\\U#58^Y'
M3)'13#)K1*E23U8]!U*%.IR6&GD[Z&PN&I7MN%Y8#G%+"U0J"A35@FP"#\6S
ME03`,>`<(JG[_`!X9WOM>Y-W>NVO+#K)-.7/+F9ML`0B)!640B"6(;NV&0R2
M''YS"W(*2U&FZD0FO0!M9/-DY!>#+54C,3L_E'GJ4-7CXQ,1E,F*]#P&9F=]
M;.(>PY=0@<2\@E!%%-6F@=,UB,U-?R79^K;[@A:4<ZJP_>)Y!TE%8Z6(0E)F
M;B`T[[_@'T].>JFI:>]3TOLO0L]T1M--IVL(4S.^;\D>B-C:](?^]!\L+3VA
MF7NL&!X>,H5./=_<_%?]`X.P]=FW#X')]0]P41`MQI).?`````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W
M96%T:&5R9&]T8V]M+S(S>#(S+S0V+G!N9P``````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C<V,B`Q
M,#4Q-30S,S<U,"`P,C8S,3$`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!<````7"`8```#@
M*M2@````!W1)344'U`$,#@<ZL1X`[@````9B2T=$`/\`_P#_H+VGDP````EP
M2%ES```+$@``"Q(!TMU^_```!7])1$%42,>-55M,FF<8;K*+)4N6)4MVLYON
M>C?+=K7L:DFSK!?+LETN67JWS&Q+UF:+3;.V-NE:7;5%K58\@Y:3U`):1104
MD/./G`7D+(*BR$$!L2@\>\&N2;N>ON3]3]_W/=_S/N_A/W7J%0.HOHW:X5G4
M'JM1+0#'NZ@=I1KWAM6_58LBH'*6'CX]]::#%G]#&P=0S1-V#$<E-XHY!L6L
MX>1.=GS@H;DP'9@&D0C1GB_>!/@T:I5[M<H&2OD5;&_JD8CKL;&^_-02<1TR
M*0WV=XVH%.VT/$$''&R12Y^]&KQ6*1^58]C+,(BOZQL6\"]BS:=JF,^C0#BH
M;MBJ:PZ1P!Q*63-MBS\YX"4>T,0E8EPM9HT-AJ&`&K[5>2S,2V#0BF#6BZ%5
M\;!BD<"Y,@4[(VV8QS;YY(!-$`;K1<`?4I"6BSD7HF$-5JP*+"])8+<Q."CE
M$0Q&,2630C;)Q@-A/QX(>F&S2.%VS,!NE<'GDN+H8*T>Y&.Z?/4\>!..L]A.
M+,)BF(39;$8H'$<FNX>]_0)VTADDDBG(I#)P1WHP,GB7O!'"2S)9#&(L*D:1
MV]91@+=)GO+99\&KA:;C<A`KYFDPC`7YO1-0KR^&9;T#2QHS8NM)F,P.='?U
MH(O5@4%V-]0J(7EX'S.2/D1\TY1!T7J:_O`<^%Y3/LU@63U'H"5D<WN(1#=A
ML?JA6K1@?2-%[+.0RI0033R"5F>'2"3%8/\@=&H^YJ8'H5%R43T,$_,*G@+G
M\OL?Y')99L4\@VAT@]BNDP5A,'FPI+9B5JZ&S1[`XI(!0M$T5KV1AER)9!IV
MAP<C`QW@CW5#+J/2*/OK67,"_KA2.>UT>CQNSQK\_B`\WC"4*@8N=P!&DPU<
MKI"83I,<;JA4RPB$*/\/RLB09^[5$#:W=NB@')Q.-T;Z6E$I45!KCT_`(]$(
MR^GRDYLV8A0@QB$8C`YBM0.]T0D>[R%6;"Z*08'D*C8"&PC%H=-;P>=+X0_$
M&H%?4!K`OMN&W92S7K'C#7"CT<#:2NW`YO`CM;U+BS>(I9=T-A)C.;VOHU`L
M-=CN%XJP,"Z(Q;,8'!C&Z"AIK=""+Y!1+%3@#/=B9YMDH7[3`-\OE,[9[*M[
M)`U,)@OFY$IP1L=QIYV%WKM]T.DL\'A68;/9&G&8G)Q&/WL(W9V=&!WAT_LL
M!#PA)`^G(1COP_Y^LI[LGSP-:#R^^;U.I^=8&09]]^[AKS]_P>\__X@_?CV'
MEDL7P&IO1=>==K3=N$G/-W#]RGE<OG@>MV^UDMT$N_LZ[G,ZD4P$7URA2VIS
MDU:KQ\/)!Q!P66B]=AXMS3_A2O//:/O[*JY>_`U#@\/H[""@X3;*$!8$E"&:
MI062B8I.+\?A84%!X.\^`VQS>-_3&1B)0J&D`F(PQAG!E(2#H9[+Z/RG&;?;
M6HCU-;![VL$=9<-!Y:ZA'B,6CL/G\V)2/($)(1^Q6+SY?ZP)_/2"4E?F<KA5
MD5`(@4""=#I9R^ZL5O1J$=B]+'1UD"2W6M!/$A@T0GB<<HAX;(R/<4CWJ7I<
M*KE\WO'2=CLK5TJFIN;2<KE"DLUF8X>'AUVUVC'#F&8T>NT<-I-.[*0"."@D
MD<EL4CN(![92Z2F#T8KT;J;IE;V<//C:Z_5^&XMO?:?1FG?K%;D6B"Q4CBH?
MU1M;J52\,"M748>,P&JU0Z^WM%)UOT7YWW10+G_\VC]1(KGUN<EDS8]Q^1@9
M&FZD7J%8E-;GHK$-J=7JP/S\(@1\'N6\=4"G6W[GM:#_#8?3_:5"09MY8UA8
MT%+YBQ".Q(WU.:52;93)9A")1#`\-`#QA!C^-7_G&X.3).\;3':16,@!ES.&
M1X_D"(;"9^IS+I?KC%P^3ZQ%X/,F$`H%42CLEU^$\R\$GT'$[ZC55@````!)
M14Y$KD)@@@``````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,"YP
M;F<``````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`R,C8Q(#$P-3$U-#,S-S4P(#`R-C(Q,0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````%P```!<(!@```.`JU*`````'=$E-10?4`0P--P7:>*5Y
M````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\```$/DE$
M051(Q]65RV\;513&/\^,[7'LQ$[<L1/;";$3[$*(FB!*!44(2Q4LBEHDI$H1
MH@M8HBYHX1]@AX34%66!$*P0H"(DI)9*C9#5+A)::)RF2HAK._'['8_M\6LF
M=C@>Q*(D;I#8P%A7,[XS]W?/_<YWSP7^KY?F<2]75E<=0X.6TRU%N5C(YZ'7
MZ=!6%&@T&N@X%AJ6PP"O@\UFAY9CEW+Y_$?684O2;K?O/A:>R^5.;(0B5SM[
M<`V9+3`8>`)PZH!.MPN69=%LM="6960S653%'3PQ[L!1K_<]01"N]!A</_B]
ME94WC&:K:X#GP;$,=%I.!7+4:E(=Y;*(.[\LH='H/5>PJW31:;<PY79?H.']
MX9%(Y.6U![]_T*U68;&8209&!:H#2`ZQ7$8FG<'#S1">/NJ#:U3H,BQWRS/M
MA6'`$/^+<R#\BR^_8@3[&.=PNI!+I^%T.2$1G.?UX/5ZM%IM5"HUZA_#PL*Y
M@,%@N$;MD[]SF(/@9\^<_;2W;);30NX"R4P>V6P!F4P.X4B4I&@AEDB@V6RB
MT^DL'P3N"]_:WO8DDAF(E8JJ;71K&V:S"3(Y)9G,XNYO05426=Y5\]#OVB<+
M17-IX?P[6L'N0)N67Y<:Y`@%FZ$(&(91^T2QJAJM6-CI1=X7OB_R[[[]X:7A
M$3MKMX]"JC>0+Y:0SQ?1H&<-_9*I#,H[)8#5H4CW:]=_<DI2;>@?P9?NWH-5
M$%`HE!!Z&`5#&V9BP@DM69%A-#"9C.IW%@OQ.#U6UQZ\'0C<>O90^.+BHBZZ
M%=:&-M;59.UU._#YGH2BR-B.)1&+QU4K"C8!>CV/8<LP$ND"@JOKEVFLL2^<
M8$995J[P>NYTSVI2K4JMAHV-302#]\F2<7()N8,F5"@'+*N!S6XC7P_@QLV;
M<\E,-D#Z3Q^84([C!$K2NV6Q@ER6Z@CM3*-Q$%5R3"85I_]ZVDBUWG=H-5M_
MNH0D8[1:-=$4P'-/^;RG"!7>5[AH5C862UQ:7`Q\'-@I0Q./PFD908/T-Y5+
MY/<$!&$9&T$)];'S<-*:1\Q6%'4<S&(I['-/2GZ_O^IP.,[1Q+E'(J>.CB0U
MJL?FY\%FTY@^^0+25*"<`SRD_!:L(Y_#9<OALYP=@QXW_'/SB-?KT+8;RU-.
MQUO/S,Q$^VK>:LFCT:WD^[=+9;B.6%$G^P:K$AJ5$D7X#:1*'??N#V-JLHT1
MS1XR8@,K]+XI28&#P(_`[_P:Y-<2*6^J5(1`^HI42OE\"K7BUQ@TW,"/UY^'
MPIS":M@!*[DDUZI#4-H5_\D7UP_=H4-&'J-:%OXA'I.3$Q?$RMKK-?GV:YZ9
M[_'S\@2.GW@3'7X,<\?+S9G9F8L1JC-ZQEBD@^'JH?#Q<5?25*VY-;1D199C
M]7I5=VQ6>B65\NN/6,^D/9[95V4-5S<YW5V?UQO_UV>@*)8_C(1#EXO%XOQ_
M[H#^`\IQ]@#>BF8\`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO
M=V5A=&AE<F1O=&-O;2\S,G@S,@``````````````````````````````````
M````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@
M,3`U,34T,S,W-3`@,#(U,C8T`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S0W+G!N9P``
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,C`V-B`Q,#4Q-30S,S<U,"`P,C8S,#<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```"`````@"`8```$$?4IB````!&=!34$``-;8U$]8,@```!ET15AT
M4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P```/(241!5%B%G9>[:U1!
M%(>W\4^Q$O,G^.@M+*R#V%A9:"="&FT4)(V51NQ$00C!0I2(`0N+B(J(@A!%
M7+"0M13!Q[C?;+[QW-FY-ZS%V;GS.*_?G,?L**4T@O[\_I$8\^3&S;7TX=,X
M;=RY,MN]>V\CG3EW/CU]?&NVL'+Q<CITY&CZ-ODZ6YB3`?^CS2?IY?9Z&O&!
MC.NK9V<RCAT_D?F7E@[^8Y$^[FRE=V\>)D?DEDU$;;]XG<4A"BIV(A;3H.63
MIQ-S)/SZ_FIVX.KJM;QY:OE`TERI8P.;TOR!G^,T_ORL&(GX<@`.C'S[?B>#
MB#I`@*G8P"8$J&SB13$2#@[A(@#A'NK*`5SCCG23`P4HN2*!0[D=T%O;>IXO
MX_Z#_=F&7APZ=SOU`!LF7S8+,8?:.%5X@96$QW@NB4#GLKUPX0)/0HYOG><J
MC2O&@I($4@@Q")DS$G\P8(T(=NY!J+D+"*`B[*"*`!@-A<Y-8RJ'.`PSHP*9
M*P@A,$8@BP67;J]G?S$9_[FRE0N',Z.QUKJQ_,,]ZSM:)I-]):P,SA9S;QRT
M\J/.DX4#R2!B?3"0V.2@R2?JSA$6A329C4`CDKN/T<@:0N8$P&#YB1'):&$9
M#&4.RTQL.#>8&*UIS<+'U:D91HAU7(B)9%$LD6C=B7D@8;8)%+7/"2!H8+`V
MR9RK[C0B$0*3`'=<P%22QP2"^(994KO,'1`Y3-)P$!<4(K6RL7.-(FR3B,U"
MHB:H7>:.`)L6Q#?$.G.L8XZ@9G,!`PZP"7BD-ADI`\"V$JF3SAR0`68(1O88
M>]/9:@0C8&;-TVN#`!1FSOQ7/1BJ$1G(W91OD?M#M60A`^H:4_>>6`&D5AT:
M?"$,*6XIC7')2*[&N6N6H)8A>RJ'R2)@MI&2?D,DB3GOW!JH(?9"4=&00>4(
MJVMC377=])EH+8$LQE8QC1@TH%8>2V2K9.9$W2U:HE1W`L@U46@JMR(B.!JB
M9WJO<LYC@,*%/M;O6,\YUVL`L%!Z?)YH!$I4&"LOZ]1!2E8LVRJJ`U.#FE?`
M0BRJ]D%'R;F&P@,"OM[J!A2[NH'8#$(;$M[YSH)<JYN5QGK.:_#QIO=>A^G;
M^ZRP)\4'7JW0QU[\;Z(!T:C8_#0&SWO_B>A!;$FQH\8UE?HM>58YOHE;+[)F
M)23`Z#ZB`.2T-CLUWWAIPW'/H&2.(7C+G=.$^GK`G`$<M(B8WQ@#_!IGF]0`
M]LP,7\A[*6P:`!,"]!I#1,*T4ZG?1KS*@1UC%NVNQ0`5V;M9RV5SJHP_"S[;
M,$[(X]FAGC]$?P&6;B*'+$K=)`````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H
M97)D;W1C;VTO,S)X,S(O,2YP;F<`````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-#8P(#$P-3$U
M-#,S-S4P(#`R-C(Q,P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````(````"`(!@```01]2F(`
M```$9T%-00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E
M861Y<<EE/```!,))1$%46,/ME^E+5&$4QOTWHD"(OD34AR`B*BC:$PM:*%.P
M16I,LVG1)AP&Q@PURTE-*J.<+-O%L"";3)TR3=,L,8FA14FC!44-$PHY^3O#
MO3FY8"1]B#Z\<^]]E^><]RS/.1,D(D&#A_G2U/1"S`F[W2Y6ZQY)34WUKUIV
M[A2+Q2+.C..!Y\TCV:?SQ&9W^C'.7RF2_/P+4E55+:%AVR1H>NA:F;LH1$[D
MY$B`V)&&_GS[]EUR<W-U)#F=LB%LDVJQ<M4:_ZZKU?72V]LKSJ)RB?=4R:MW
M[V7?N1N_(6)\-CRNK96Z^F=R]F*A#-EPIZ1$V.#Q>-2@45%1\KRQT:]D?W^_
M%!04".;'XEB,ZRY>NEQ>OWGCAYDQ:XZTM[=+\N$4*2XNUM,F0D=GMSQYW2KY
M)15J!W=QN>2<N23C=\T_`B`NHJWQ,B8`K.'S^31,L`(6P>$VFTWBXN+4=!B`
M`"`@TH^FRX</'W\BQ>P]*%ZO5WIZOJA#XN,3Q.UVZZ&NKBZU/\&-1?''UETV
M(<I,@)`U89*>=4H<*9D:N0M6K)>"Z[<D.2U#O<LZ@1P9G:#O[`'8!&CYW*%W
M#;];J<B$*"X*/Y8I;6T?9=VM>[J>=//VT%#)?NI3=8U)2\T+:6EIE8[N;L$V
MAHTB*AL4_.^Y\1\`L!YP:$S\-@`'R\K*-4<!P/>?/GV640$Z.SLE)C96PY<G
MD4BX%A86:B@SSSOSD9NWZ`@`P.]LA$<)6^*=^&<>QN#PU6O7=(T]L$4`0&)2
MFC(&DE`?`!*)Q$(C#I$#)-OL>0LUG$T`4I;4Y2!:P$<0&5?@`*!(G!@\6?>0
M!^2%"<#],1S)M-UJUPU\0TT`,T=R,<\[F4NZ!UPAYF6[$A_\1IZ3//!#J/N*
M((#DNN>I-),JP`LD"L9RE=9HY2`+N2_?N#+AQETU("XUV#0``.ELH+)09:(;
MWZI4(_N0RCS?P\9!1'*JN=#0Z%,+HQ6$8<Q#*E%VA_R#V?A?@;^J`+'^H/*1
M5ENRC%:BXF&U&!68NCBN"I`TD`B\`#_0_D$X/"$?J,T0GIF5I;QAU$\J.,P%
M1G-SLU8]GN0;?&)4MR%"6>"F9#)TR$'("""("@#8#:*"\>`4UJCZ*`$3,.]R
MN?S)/:`D:["B06SL^]K7-[P"M!;<$G-RD*?!QRC%#:%97,&3->9Q!\`(Y!WE
MH2$LA[(P"44`ZPRN+@'"Z2,Q+:P**$(Q&V``H!"W0BB"N+W13+'.[3F#(O1$
M1H/%.V>U$@V4-Y084E`8^!;A]$3X%NVY,?X,GC+5[(F8Q\P`HAQ/B@P*T'Q-
MF!2LM8,YFC#F&)RE]Z(T#*L``_-LNU\K_*M`,(?F[7>8@,PM.Y*M@"C"C5CG
MFS7`IRU9;0I%Z07.(XK#!;$@Y6;$+*!/BSB9IT'TTO=62PE_D3`Q1$^EF+\C
M5F^@96B@*33>'U34RN[3Y]0-?).J5!"*A='CC9J&KNHF%8Y_Z2@I4S,WAFL@
M4N-RO37J(B*8XF@H0];<+"H5FLHE>Q.T"K6VM.D?!X)U3#S`S0'`;)@(C4E)
M!IF1Z&U0TQ-T*,?W"L<AJ:NK4P$H10UE/Y;`<B%YE[6JC_DOPJ^M[Z^Q,=AW
MHPT4)GM&:N;^%Z/!XP></Z*3-A2$%0````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\R+G!N9P``
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#(T-#<@,3`U,34T,S,W-3`@,#(V,C(Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````@````(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9=$58
M=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```$N4E$0518P^V7V4N4
M813&_3>*H(LN*XJ"NDBH:%<J:*%,*=*(*<UL<:$F8]I,L6Q18Y)&DT01K="+
MS(6T3-.I+%&4H45)(Q-%"PL*.?D[P_OEY)*2=!%=O/-]W[L\[UF?<\9/1/R&
M#^NEJ;E9K(GC=KM$'3HDB8F)WE6;S28,Q\5+ON>M(ZG.+(FS.[P8-_/N2'9V
MMM34U,KZH##QF[MALRQ9$2A7TM/%Y]JQAOY\^_9=G$ZG#H?#(=N"=J@4`1LV
M>7?EU3Z3@8$!<=PID^BR&GGU[KT<<15,XHJIV?"DWBU/G[V0&[<*9<2&>R4E
MXG:[I;2T5`T:&AHJ+QL;O4(.#@ZJI3`_%L=B+I=+5JY>*Z_?O/'"S)F_4#H[
M.^7,V00I*BK2TQ9"3V^_N%^W2\Z]:K5#5M$#2<O(DZE3\X\`B(O]4=$R(0"L
MX?%X)#4U39V.17!X;%R<1$9&JNDP``%`0&#.#Q^Z?B)QT\/JQ_+ITV=U2'1T
MC)J70WU]?9*0D"`$-Q;%'[L/Q`I19@$$;@J2I*L9<N)<BD;NLH"MDE-0+&?/
M7U3OLDX@[]H7H^_L`=@":.ON45V#2QXI,B&*BX(O7)&.CB[94ERNZ[AJA`VN
M/O>H]\VDK:Y)VMK:I:>_7["-L5%(=8."_STW_@,`4;$G-28F#<#!RLHJS5$`
M\/W'C]TR+D!/;Z^$1T1H^/(D$I.3DZ6PL%!#F7G>F2>L&3X`^)V-A"]A2[RS
MB?G<W%P]G)^?KVOL@2U\`(Z?.J^,P4V(#P")1&(A$8?(`;X7^R_7<+8`2"12
MMZ*B0J6`CR`R5"`[`>7&Z3-GZ1[R@+RP`-`?PY%,>Z/LNH%O0!G,D5S,\QY^
MY)BFNX\*X:V=2GSP&WE.\K1ZWLKZK#SA`I*KK+3:2BH?+Y`H&"NEO$XK!UF(
MOGSCRIB"$C4@+C5LZ@/`[5B:RD*5V=_X5F\UV<>MS/,]:AR$G$FT%AH:/6IA
MI((PS#RDLL<>+_]@-OX7X*\*0*Q3^TA=&@!:B<I'M6(J,!PPI0*0-)`(O``_
MT/Y!.#PA'ZC-7)YR^;+RAJF?5'"8"XR6EA;%X4E"(JBI;B,N90%-R63HD'()
M&0$$40$`NT%4,!Z<PAI5'R%@`N999R]"L@:.(3;V??GZ=70!:"W0$BDYR!/I
MX6.8$`VA65S!$P9!6-P!,!?RSD70$)9#&)@$A;#.\.KB<SF-)J8%"%`NQ6R`
M`8!`:*6T-701VIMFBG6TYPQS]$2FP>*=LSO#]FEY0X@1!86!;Z%T.GQ\B_1H
MC#]IJ@RE,V\JEAD4&01@W[09,[5V,$<3-F^1O\YSEMX+G%$%8&">L(IZX5\%
M%W/(_VB\!<CA-4FI"HH@:,0ZW^QG??:JC?K-0(&ECB3%04&L1[D9,POHTT*N
M9:H;J$>4$H(.$T/T5`I_6X1JH&5HJ"DT[P\KZ^6@TZ5NX)M4I8)0+$R/-VX:
MIM0TZ>7XEXZ2,K5@>[`&(C7N>E6=%<$41R,,67/W=KG05*XZ'*-5J+VM0USW
MRS58)\0#:`X`9L-$2$Q*,LB,8U4-:GH"#.'X7A=_6O\`<1ZAJ*'LQQ)8+C`S
M5[O^"?]%^+7U_34VAOMNO('`9`\"_2]&OQL_`"A"HJ[\`,=1`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T
M:&5R9&]T8V]M+S,R>#,R+S,N<&YG````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C0U,R`Q,#4Q
M-30S,S<U,"`P,C8R,3<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```"`````@"`8```$$?4IB
M````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA9V52
M96%D>7')93P```2]241!5%C#U9=_2-1W&,<-]D?]-?97004C9@115/LCQOXP
M!@M9))$K(^N/K6[8;&@S5QQ9>=F5T9%>6JUY6^:*G5G9TD33H#2A'QJ2!HI%
M941'EQQ,D`KW[%Y/?,Z[[GM7=Z.-_GC\?+_?^WR>Y_UY/L_[_7Q,$9&4<-,_
MY>X*Z;DS(*.CHZ^^YOZX34H/')'0C*&A1_(\,&'\0Y2/@<%!.5%[9GQ&S>EZ
M*2IQO?KPXL5+:6QLD%U'O=$^NGKZY,[@?;D[]%CJZALC)WR>]J4X715RMJE5
M>(X(.C8V)E.GSY"Y"Q9*VA?I,GONISI&A2C8](U8PHYGH8>^OE[I[NV7OOZ[
M.EYL:XL,`6I^:+G4+J0JR@/)8`<D-A`(1$[(6F.3KY:MEIW.,IW`;B(F\(&M
MI<Z:H[8H/4-JZ^K&,7S?VB[8C<Y)8LO)"?T8@:'G^B<2=YO)FN5'#I2#';AW
M7QX^]FGN&EHN*[S,E=EBMSO$[_=;5Q03SC>WRJ7.:U+E/2NGSS?K>_;Z7/'Y
M?/&/\O>37K$7[Y7RPQX=2>M^]R]BTGRLNCJ^`U*\UI:G"QS[#BI<*IFSP2&V
M\+,TB>F@]M0%V5U^,+3_WT[.D;]'4B33X=33IQIB(CA172^%%8?DF7]8JJJ.
M*^W69"^6+;]N%@K1:O&[.\;_WP'<ZNR^K0I!$:$2))7:X+?P>HA:S%ES"J@;
M#JA$B%I0^)-6(D=,8<5T0!%!=Q9W7.M2!$3%`7(9=PO($YI(!&J?NF`Q1O0W
MYJ#R:)66,0L\-5[E`7RP;=RJT-_H@'I'/2E?%E4&"XH1>[V$+1W``YSD;W'H
M8KH"A#)D(@\Q'9`X)C&9Q3C[=D.!DHH15&B9T=,H!S!OVL<S5?32ERY7K4<(
M$42:`2,.^,W2`7W'5OFSBC+Z2R*?#GT@B]*F*T/I6I`JYA;<[AHYWM2LC8L&
M]J!_HF1ES1>WZR/Q/?&KZL9-8NZ?+3(R\I?6`(N0:&B=L7:)HKH2+..WX@+1
MVYI2I:O[IKP?=/[/`0P/!Y3MM&'D`<)26QAY[NBXJM]((1)"=<#1?P4`_8&;
M!$1:D!HTRAB20S"C7V@9<S#X#,?WNUP*DD))"``2Y-SCTMV9(#@&"($(R#N[
MQ@@&J7+S@BQTE$AIJ5/[(<4%#Q(&@(P98E'6!#.M'B,#1CO9+6V?->&7H*1K
M`"?(``V9(R`@.L,S`7GGF>Z/:*&$7`\!8.X>20,@]49_$#1TFD`$X1TC:&G9
MD=#M`=DE_4BOU3TF(0"D$N<8C@E($```!$!T'.Y#R+=18E28BQ29>/V\$P*`
M`TUG,#@.D71D3L\Y>"1\-W<FP#$R!S",_$[V`)@0`%*/Y!.<5%(#[,[L$.,;
MJ>;97-JH>H(S`@P#`#X88VF!)2K$FR-8=^P/2=]4J(#R?K#K>\9W.4HO@JW:
MMEJ%/W/%%/FZJ%@O@10@:VD.S(7_'H]'!<H*1$RU0W3@.4S@K#><:=!VA9/B
M'2OUUEE7^Z%>(O,W3E;^<[%L:6J7S=YS>IE(J@B167HB`4%M'-)L4;(B^SP-
MKKVRK$2;+AE`<,+G)LT"=@''PQWP;X]C>ZH&YL[-F1JM/]5\4;O].V]&4*KW
M]JVW%ICWIAW_`YR>F7ZG7R2B`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O-"YP;F<`
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`R-#,R(#$P-3$U-#,S-S4P(#`R-C(Q-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````(````"`(!@```01]2F(````$9T%-00``UMC43U@R````&71%
M6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/```!*Q)1$%46,/5EVU,
MC6$8Q[/YP"?SB<U\HLUFC+Z8^9#9R!BR1@ACRK*ST"IO"1U)C3,J>>T0":6.
M4&LGLE':&H55WB8;&<X<[6S:&I:+W]6>.L=YR<DP'Z[NYWG.?5_7_[[NZ_^_
M[D)$),3=]$].[A%Y^/BY='=W]WXU):5)]J'CTC>CH^.-?'8-Z?_@Y>-%^TLI
M+K7USR@NKY"T#$OOAR]?ODI55:7L/5GB[:/I49L\:7\E[1WOY')%I>>$&>&S
M9;\E7VS5-X1GCZ`]/3TR9NPXF1PV3<)G1<C$R6$Z>H5(2EPK/F$'LKZ'MK96
M:6I]*FW/VG6\45OK&0+4)+#F5IV0*B\/)(,=D%B7R^4Y(7IEG,R+7"Y[,@_K
M!';C,8$/6.B$26HS(Q9):5E9/P;3S3K![C4,E[CX^+X?/3`\:APO`;<Y6//Y
MD0,U#O;U6X?FKK+FML*+6AHCVU,SQ.ET^JXH)E3:;\JMAD8IO'A%RJ_;]7UU
M[$9Q.!R!C[+X?*FDIF=)SC&KCJ3U8.XI,=)<>/9L8`>DF$@L,!_(4[A4<L*F
MK>H0FS8]7/PZL%VVR[Z</-T_O#AS89)\ZPJ1*'.FGC[5X!<!\%..')6/SDXI
M*"A2VJV,F2-;3R<+A7BJ_,I?/,9_[P!N-32W:`%AJ`1%16WPFWL]>"WFK#D%
MR&E4(L])*5NT$CEB"LNO`XH(NA.YOK%)1Z+B`+D,N`7D"4TD`K5?4E:EBS&B
M#YB#_!,%6L8LL!:5*`_@0WQ"BD(?T`'UCGI2OK&F;9+_HZ`8L9]+V*<#>#!O
M\1I)W&;6Q3B#4`:9R(-?!R2.24QF,<[6;4A24C&""BTS]-3+`<Q#WV%DQ()(
M?4;C$4.:`2,.^,VG`_I.7/X)%67TM\)FEP\=0V5F^%AE*.R$5'ZWD)=;).>J
M[=JX:&"OG@V3Z.BIDFL9*8[W3E7=@$DT7:N1KJY/6@,L0J*A]<)5\Q75G1]E
M_$M<('IM=:@T-=^7_X/.?QU`9Z=+V4X;1AX@++6%D>?Z^KOZC11R\E0''/TM
M`.@/W"0@EP/D!8TR#,E!>C#4`RUC#@:?X?A!BT5!4BA!`4"",O=;='=&`!P#
MQ!!-WMDU1C!(12LSFS,D.SM3^R'%!0^"!H",02P4BK(FF-'J,4.M"<YN:?NL
M<;\$#;H&<((,T)`Y`CB&SO!,0`#P3/='M!`OKH<`,.X>@P9`Z@W]0=#0:0(1
MA'>,H%DYQU7HN-DANZ0?Z?5UCPD*`*G$.89C`A($```!$!V'AH%\(^,H,2J\
M/-:DF?CYO(,"@`.,X#A$TCD"SIDCX3N`>`8<(W,`PT@7(WO<>(("0.J1?(*3
M2FJ`/F/T&HQOI)IGX])&0((S`@P6```?C/ZTP"<JQ)LC6%=X2>8FIB@@'/*^
M<'V\THM@RW:N4.&/6C):HM+2]1)(`;*6YL!<^&^U6E6@?('PJW:(#CR'"=PZ
M-]BJM%WA)'WW4KUUEI6.T$ODYH11RG\NEC75=9)<<M7O97)``,@L/9&`H#8<
MTFQ1LK0=4S2X]LK#&=ITR0""XSYWT"Q@%W#<W0'_]IAWA6I@[MR<J:'UB!3C
M'V]&4*JUY<$O"\Q_TXZ_`V")F9-&?C0+`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A
M=&AE<F1O=&-O;2\S,G@S,B\U+G!N9P``````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(U,#0@,3`U
M,34T,S,W-3`@,#(V,C$V`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````@````(`@&```!!'U*
M8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E
M4F5A9'EQR64\```$UDE$0518P^V7V4]341#&^7M\TQ>C\<4EQIB@T<0EBAJQ
M+B#N&XH2<2&Y&!11#&610"F;N%#%I2X0!2TJB#4@E@+!1!]0#`_R0H)C?].<
MIA<*08V)41\.O??<.3/?F>6;(4Y$XJ*7_FE__5IV';6DI+0\O'NQN$*ZWKZ5
MI/T9X8V1D1%YV=HJ/I_/?CZBP]_1*8M7)HIN9%BYDIAR2,^C*V[:C)EB698,
M#P]+Y$CT0GJ<3E=YI=QK;)+\LAK)R'9*L*=7*F_<D14;4\)2[ML-DN8LDLW-
M?CER/%,V>+RRQ#JG9L:9B`E[R@(%A<4RH8!UWJD`<<+T.?/$)I#@2%+4:[?N
M5^3<`@>I0%]OKUX13_7W]\O#)SZ9&[]&!7%X6'W(<X.#@^+Q>`0</+.G&L[X
M>_5A16JZ.)PN(9AG7!7R<]?\F15SL^5%FZ1EYDIS2YNZI;BR3JJN7)4I*5BY
M9IT>K+WU0,[FN^1%FU]*:SSJPHKK=_5W='34?D<VK`M%FG`<9A66UZJPOZ-+
MC*LUFZPP,MQLR^FR&V$7'TP]K)%<G;Q+-CFV2':>4^8O6JHI/FO!4JFMJU<9
MENT*ZTJJQ.M[KH=OWO9*UOD+>@W>757U0C;DY5U2&5,-MBM$^Z&AH4%8YIWO
M)($)_N\/XY^C8.?>`_+APT?Y8050"TX+!`+RZDU7A*6FI(`$(=8D#NF<?>FR
MAI,:A=0F53`T-*3"9!I9F9E3()U=[Y0:J0=2FWR(J6!90I(2LOM:O=('UCGH
MV).N*(+!;D7%=Q09@HHX"VM8)M_YW9YZ2I^I1JJS_L$3K8UW@:"2ER$N5<`+
MFG$8EA&D"G$BO`0"$.('6D?R@6-V!>3VH<KK6B#`IJ233UM:1#B5(F+%+U\M
MC8^;)&'#QDAX(S[`.100AQ\_:U,+A+*Y^:G`_40&'R$S,#!@+Z83'?UJG>;@
M=KN5%'$2[W!!5HAJ47;J?J/0W\9%`4&T\I$JG.W8I@H6[MZG[./U>E4!UXJ9
M!]%:>>8`)&_V8)Z.SD[;WE]4SO\6`(J=UDZRTUX@?^J3_&0V"78'Y;<!H'K*
M:VYJ;5.B=7<?:8TS3L`T_&;EE6C%4;*D[2\#(*4I7[B`J0.2@50P"*&8Z8^;
M`PP`E#Z\P3?`P*%X[8<!4("P7*F[6D<#;LS"(`O28O$->L0@ALUT0-U!:`"F
MN5/8S"=X;4(`L`'M`V;DEAADQ(!J>8;<4<KM,08`>`O^)A>@'7B;7T"PCRYD
M\!#-`IJ&Y\:1(2P!>W(C%$-^*#(@C-M)0+X#!$`L<H)WAB?"`&5#Z>2"\9*A
M>18`"*D-`/%F="'F,"YQ-Y,O[L4S*"2N@$`I[LZYZ-1?`'([<L#(X26J@X4.
M]**?F8N*BID#!:$;P^9X!&*&Y5VN\.A+B!B)BVNOZ3Z<:X8UE.)^$JZZNEK/
MFO\QB#UC%:V%W)@P![Z.?I.>3U]4"<J9N?F?`]2T&8!@C(0"($"9S4W?`CR=
MQ,B6E5;HK0%#0YBT"C"\H^^SE@TW:`F\URY+)6@K"K5A)E#X@%!MSBF25=XF
MO3D50YYL2DM73R%/@P4\[I\2#^2W=\OZ])/*:F.%()G<JAH%HY-+Z(:$@SB:
MR=;T4K[A(3S!C!T]"O\2$V(((V,[^M@RQB"+RIA,]G\W-.L[>P[`+\`TV?\`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S8N<&YG
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,C0S-R`Q,#4Q-30S,S<U,"`P,C8R,C0`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```"`````@"`8```$$?4IB````!&=!34$``-;8U$]8,@```!ET
M15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P```2Q241!5%C#[9?;
M2Q-P%,=]ZZT_('JLAX@*@HBB'LJR&Q%4="$KI1ME%^AJ25<SRM*@66)()IFE
M@EUFK60@J!F+1B*YG):E:R[7NBO1*$Y]SOC-+5=9443U\'._G9US?M]S?N=\
MS\\X$8F+7/IG^;IM<O6:7<*"E"W[).]TL?"I@@7-7LDX<$"\7F^T?=CD>E6M
MS%RP+.1C_:;MLF7O$8F?E2A3ILT(J6%[T>7N.25R-38V2B^?6;F%8LDODIT'
M+;I:6UOEBKU:DE>M#VG9[789V?Y&P>_>MU\LWH!T=W>+Q^/I#3,F[#XK;$O=
M(5]4*"J[+"?/E"FX(2-&2Y1"A:U2JNL<FLQ;MYVJA($JO'SY2D,D=7A`B3T9
M)-RX`1U!(<S2TE*9].BYU-36RMKT#.GG^]"328?#(9F9F;++]4#CWY1Y1(+!
MH'Q_F#^R8@HWIF4(-<'%UCGKA1KS^7SR30<-=UURJOB"&O-YO."\5-7<E'G)
M&^2"K4K3A[.854S1D;;"TDMJ"`IRWN1N5N/T[#Q)F+TT[&1\?$(HS<93T^LN
M.?2P0XY9<K3@$SJZ=,\B_<B2DI-E8KE-<O/RQ6JU]F29U-<W-$BJ)R!<K-/I
MU/+DDY+$04%!@;2UM0GWRK5]-8F!0""L@`.S!_+ON<8_PT%.;KYVQ'<[H.]@
M$6=]@YC"@BCZY(#&I9#**RJU-VE:*A%F'#-U;DQ'45^`3!E3;::,#UM.RJJ-
M>W0/LIC$AR&L<*Z\0LHN75,GU#_P*6'NGW#X'91KMZ=KWX<=`-O`I>XY$4<8
ML4"#T8[]V7K0G"5KM*S##A``C],XF7C)`_!Q!$<A6[QZJ^Y940Y8<!2\"34-
M=+AU3](&NSMU+!`FC<0>?C/\H,8K'[]0`;'2A?0"Y$=#,4I('`?P.PTW;_[\
MZ&:"-2>T=*IG.NU&UULY6U.KG?C^DT+:`Z_N&1KD(K+9PB'`HI`'`]`@,,C8
MS_9U:<O'O,8OM3+P(^6&JO^R=OYW`%"#M!H%#3M`.WRGM9!1(;\$`+W,'(,8
M:$L(`:JB55E\O^&XK6"8A3S(&&5,H)\&P,$0#0<0<4M+BQ(M>\B'P8N,PQG,
MZ$,XAE-&C9T@,'N?`4!Q#-W"HM!DAQ8-01.I(2S8CL4>/<B,PP'J:G(K90#2
MO,1X3Z+'53&W8P(@&M"37NB3PWEW<JAQC$-T8$.8$AD9X4#V/(3X#F`R8G1@
M&'S"ICQ)"+#7^PWFQ("(.=P8\3(&/<8L(H-A.)3T4R/(*$:3#>J`!>\!!#NN
M!/#0.E1N'AE15P`J0(S9L%E3RAWRXC5KZ.3I,GG%&HV"W\PG3I$;??,Y/.N$
M+J/+*(#)>6>9JP@?WODN*.W^IYJ:M.(2-4`1N>N)7PWRJJH5'$ZN>#NEI-TG
M?K]?Y>,6)FIDZ"(G*SS@D!VUVG02?$[D40"2[C2I\Y24%)T&.`8,[VZBP!&3
M`2#\7G:O.4H?76P`,.5@EH+DB@B*VEB4FJ:ZGS^4>[4%\XO9QJ'&`$?T-7..
M:4NT/`Z8<?R.S>@[]]6&B8P,?;(TR!;Z[XV:^B$B2O2\D&$E5AWQD:..R0P8
M,A/Y@JU\U2W]W<^T)G@>_Q]&?SR`C]FXTZI22M+]`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E
M871H97)D;W1C;VTO,S)X,S(O-RYP;F<`````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-3<V(#$P
M-3$U-#,S-S4P(#`R-C(S,0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````(````"`(!@```01]
M2F(````$9T%-00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!);6%G
M95)E861Y<<EE/```!1!)1$%46,/MEDUH5%<4QP/2G3MQX<:-Q8**+;@0E6YJ
MJA`J2(M?C0L%8]H&;30)BE$3XI#&BDIF(E'':#Z:;],D3`?)H%%')8W):$?;
MT:(V:HU*_"J#4S1BCOY.N..\O&?2N!#!+L[,N^_=>^XY_W/^_WN31"0IT?1G
MR<H,F9R6)7-2%@^^S=A0(%ORM\FRU.6#+_K[^Z6TM%2N7OO+NC[NXVC["?G8
M'Q9]D9&5*\M6KY=Y"Q;)@D6IDH2C;2Z7]/7U27Q)HNW8N4ML/G?NK13,4U8C
M69ORI?EDAUS[][D0GD[HN?FWY.W:)QG%=6KC-Y^2@J(=SEL$@T'[%L.99<#^
MKYU0U>B3U6MR9'HXJD!^E.=^%0,?CP4[Y-.Y*1H].![VM0F8)D6C44UOX==I
MXJULT#0I`ZCQ33TT-?TLH=`Y(5U6_=K9J>71+?:<?Z(/<ZOO"1.SLK-EPO9+
MXIA%;^\M&3;--S''E[1`0[-/8ST2:)>-KMU26/2CA"_^(0,#`YJ/HX,'#Q\J
M$D!6TWQ$<4WY-EN*+_:JDQ9_0"IN/Q6/QV-UP$0FT*,L-(M!BO;R^_WB]7JU
M,0&JR+U?Z'Q+3Q^_^U3#;`L$M%"'SEQ7%N2<B,FFW,VZ.TY(@[$E@G^>#,BD
M>2O$W_&[5IL^90>X45U=K8MQ1F29.;GV;@28Q)?0!2-T\C4LB40B;ZF,[X8#
MFH52TORC<@"%J#-=2,T-#P$5$`W`C@Z@&YU(&T-8V)V\-B_.<,9(7J*PV#CP
M2^"D&B3??^.QK/K!+5,_F:F.D:STXC)[']"R+*!AC'R0/_*1L\4EJ]+2I;:M
M7;4.I6`._Q;-P<'ILR$-'5Z4'*B00^7E*A"T-@YI]<^2Y^LSN,0=X`W@,`B#
M)I77-&K/XY`(C;JC7;0SCBT83$SW*EEBL9B"A#R#]MCT&C&5"8<OR*RO5CIS
M@7[G`(`TT)3_EBN/M)SH'BR%&^!!2A8'4WYZIKO/R/1HWA^Z>S3?Q2ZOII&\
MM4[JZNM5+&&G+0)J3;ATW?U8OTR9_;FFP62CM+P?&G[<P=!VQ1DT)GQ2PQDX
M('FC(E-E596"^F[3^?T)@"*B43`$)G#@=75WJW+`44[UD;3KC0*@"7`.2:`E
M&Q($(C&FODM[GXX;5WA0QQAMS!BC$[]P-\D'I3X;!T8,@!:&PAU=OZE"(:A8
M9U=(]6'=Y:B>W!#N^]!ME3VX@J$;F9TW)+7*+VN"?^IX1!H`(4RN;6@2HZUD
MC=KQ;.Z+9(\X<9@C7FL+=ZMLH'2H("6A7/PSA\TYIRD=2I@82'QSA`JH$6ZD
ME0W)F@UY1I^06[ZQ*3"'(Y>5Z.A3<ZM/+W`7(I=4.?#%-VX2!,"_68L4,]<2
M`%D!M\F6#:DU%V"^@0A9$"#W/-0%M#!T#NU#.+B'$Q`(D3%(\,S&&*@PQK^M
M!#0<UQD:BZL.-25ZS@>>R9K,D'[&."+HB2G?Z9C,F,\\,R8(KDJ\0Y@)]K6'
M,K:]^YE,6[IQ<+.74(("T9(A1D<3'!W-,=(8.*-U)5-ZB'.7=1P=),1:&I82
M0>5AFY!SY\N2H$*)<;32T307#KDQ4@*>*0%(,:8,U'3:OCN*ACF*R9QCBF`I
MV[!7=,W\I0.@8P.R`RXX3B9<4X'>'(C0#X90<[A.Z<B4-2#Q3>LM/8U!S>E2
M:0O`'&%L[C01QV1%9YM&(SO3A*@BIS:;DRES\3?JF]U_,=`A,[,)03%V@OC_
MTW`D>P%929)WK,+1_@````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\X+G!N
M9P``````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#(S,38@,3`U,34T,S,W-3`@,#(V,C(R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````@````(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9
M=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```$8$E$0518P^V7
M74Q45Q#'?:^/OO:]IB8V^-"$1VN4M";5I!&,;10_JJ2L!JE8=:U-)#9K7+\`
M%]QL:H@;UETBV0K;0"6-)*(2B%"QK(A%!`F@H$1!0J33_H:<Y5[VHOB1&HT/
M9^\]Y\R=^<^<F?^<G2,B<ZQ#?_KZ^F2E^X!\$FV<7"TM+96*B@IQN5QV\<0G
MMH61D1$9&!B0CW<=%%WH[.R46"RFWW=U=<U"AZ-`?7V]'#UZ3.KJZN3[W6X)
MQL[+JO0,:6UMG9+$,,_Q\7%]`F;V)EY=`/L$<,'E`?EP]29]1J/120QL%A<7
M"P&]?O^1+$U+4T\(C@J,C8U);6VM"OC]?O%ZO5)>7BXU-37)7E1>B=M<M6'@
MN3SK1['.7X^;KZ2@J:E)<)*0D!8X"[QX/&Z'B!`''0@$)!0*"8??T=$AOIN#
MLL7KDX4IBS1L.26G=4[$>GM[IZ(T/#RL'Z&`4$8B$9TC2-9X/!X)A\.2FYNK
MB@CQT-"0/<QD#QF[+GN'0F3\>?TO6;OI6WT'T=GS%R0S,U,P:(["YO-\SR7-
M43/_Z=1O8CTS]I\9Q.SM>0F!B8D)6[#.M7;)'K=;_M]C?,L5F.2B4"DO3H?C
M,V5F4T#$20R$R3#2E8]-=4.3"[>ZY=,5&0G*LRD@@:!/LI"\Y_C.55;*YU^O
MET.-'=+0T*`H2.UE7Z7;4&AQDV4(0'[0!^EZPE<B&US;E$;(0%*:=_91@(L)
M!"B@B`SW4'4@R<_/U_J@%J`:")IWY'%;%1C_KS8W*PH4\$0!>8]2K.,2A,8^
M96ZK!28$;LF^H`:/&+2WM\N7WBJ-OIE_D1_10(^.CCI3UKW!!PEHC,)`T!;Q
MV]UW9ZZ%)^-/9=7&'%LQ$50KH^+*C`JZ^P=MF]\$&L3*KM/WDQ2D[#TK+2TM
M8H5K=0?_W]%J?`_@C0!H:VN3N>63%$6)?E00UOD'I_Z0SS*WZ'S>D3+E@;23
M$7TO*"A\=A::<J:A0FVFR4(R\`*41EEC'*.NYG[EQS4'?9)]\99V[ZW[/;JV
M<7.6KJWY)2K?U5[3/0B*ZX&U3=H(&>,HATLP".DP#``H$,(R5\_8G2'EVQ\.
M%PDM$R.%_H#06F%!M\>K,O"OH5"<@_"3[E<`H%WT]/0HTV'0W-:@3RB%.9'!
M$^;7XC>T3\.05=4UTG[K;[U)</TC`COR=BI@KB/H"`:#"APG'0%P-8$I81/0
M8HR/&-QUF+,.`-ZA;#Q%.4"88Y0YYVW6`8$C&.<=)Y,`F!R@+X`0(QBE*^%M
M45&1YH3U2'@'`'(8I]D@"V#VD3-`F!-^='/45HJ<,=/O/WPL\"M>T2:<9%IN
MW/Y/:=QQS_][L_8GI^O4K,KP0.B"^$K#B6ND=>!!ZN&+FO%.X`#/]V6A,_)2
M/,!Q'`]5ZYF3G-/W1YZ,.:XG>*+[GH*G=%\*0.K^7V5]WL]:$4G@GOZCWE."
M3M&A;RX^=LFQ^;Y0!,A6<_5YD<'Q\*WYN_B^&3UO_`N65!N='DX_#P````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W
M96%T:&5R9&]T8V]M+S,R>#,R+SDN<&YG````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C(R-"`Q
M,#4Q-30S,S<U,"`P,C8R,C$`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```"`````@"`8```$$
M?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA
M9V5296%D>7')93P```0F241!5%C#[9;+2]11%,?]8X(V+5JTBC91N$JH_H6(
M6D54E%"&6%;60C"2P=28&6M\OQ_#^$`'$9.4%-^:F)GHC$S:#.*,CJ?YG/C]
MYJU1$2$NSOSFWGONN>?Y/2=#1#)B27_*R\ME<7%1^.I&45&1U-;71S>2KL1M
MK*RLR,3$A`P,#,CV]K9D>+U>L=OMTMK:*APJ6SB\)UM;6Y)21LI'T*F@H$`Z
M.CJDJZM+.CL[I:*B0L;'QZ.<(R,C*A)&OKS]ZT_\.4--38TXG4Z9FYM3)U96
M5DI?7]]/'<+AL-36U@H.[>GI40L:&QO5"E,"II64E.A!75V=5%=72W]_?Y2A
MQ_U!%T5OFO3;ZG)+G`YG;F?KQJGK-R1V_7?,_#<"=G=W-8GJZQO,W)F>GI;Y
M^7F9G)B4X>%A&1H:4L]P1E(L+2W%QYID(QCX%[]W=W>K6Q&*6PF.P^$0B\4B
M+2TMR0*@0&!+3IP])[%[SDC@C/^?YI?DY/E,2>L#]_N/LKJZ:C)\V]B(8R9^
MFYN;Z048:J6CY>5E^4_#>`@$A$(A<;O=4EI:JDD#PLS,S&@F4N&SL[.:9*!C
M5565[L<)\'@\TMO;*S:;38`'X("+"!D='=4T!BO)SJ:F)OW/HZ8`D@.FXN)B
M!4`$&?`!<9'\YW6T:&MKDV`P&!40"`14;>"$?.<55&YN;M:ZX"*U@(D(@'=G
M9R<J`&G`K#U22&A15E:F101A$H*I0BJ5/2H7L$N*PMV6?K796'O6O\7E/N=4
M;=HPWG_RW#S<V]N3T[E/S368<>]1?OI:H.<\S,LS&8+!D&FG4>IY^?L(>%'M
M4FPVUB_?MJO3C/53>[L,#@ZF%X`CC:Z7BC@S0G?(BNE(@;^N`+E+;?M\/@%E
MJ!R#Z#AK:VNZO[Z^GD0,1IS#!\&W$>E,9*!1NOLJ`./"PH+"&1A`78`+_`>-
M`!&F(/`0J)N:FE)<`$?&QL:T@P-UW`?%C$Y//8%PH!B=+U89\W'P$8T!7\`9
M!`.8"@L+=;I""'L,4XP(0"2(AU#0#^2#Z/I,!*`@A/)\V7>Y7(I5S+`I/8"[
ML`QP9\3@448)O,":A[`.*['6(`/P48R[>`L$Y1Y&X$GVD$UHP;446!;66,&`
MBQ&,QEAMM5K5E2B!=5B-10CE/Y;SQ2-XAF;"_U@X1Q8RZ51&-TKR`$IPZ/?[
M-9GR+0[)O')-FPCQ9F*#L(2I[=GK2KEX)UN5(W3L\R5/</7C5S:]CW>,9(P%
MZ`/+\+L_(..1)$N%H=.3G\1B?1?7?Q)IX[M?[R<^>J`"H="./'CKE.-9E[3%
M)I[3JQ@$K]Z\I160>+[RU:/WCUW(VE?!M`KX?)OR^<MR7++$DMW1(9<M-LG)
MR4EY[O7Z]/YO(R&]D3FY,V8V3@S-AP@FD+"I'L^U-N@<34X<]8+_7H$?YDY@
MO0;>PY$`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O;F$N
M<&YG`````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`R-S`Q(#$P-3$U-#,S-S4P(#`R-C0T-P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````(````"`(!@```01]2F(````$9T%-00``UMC43U@R````
M&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/```!5-)1$%46,.]
ME\=*9%$0AGT"7\!'<.?"5W#IPI4K=R*X<"F(N!%11`0QH6+.F,6`.6#..4?,
M@CG'FOG*.>WMZ;:G1YT9../UWG,J_/777T</$?&P+OVOM[=7"@H*9'IZ6CQV
M=W=E:&A(VMO;I;R\_&U;2TN+Y.7ER<C(B/UYFXWP\'")CX\7?='6UB;>WM[B
M[^\OR<G);]LXW]#0(+8CUI66EB8W-S=B9W-V=E:RL[-E9F9&4E)2)#@X6&/<
MW-Q\VT7065E9,CX^KIN&AX>EMK96;F]O'<,DNLO+2WL7KI;M86)B0AX>'C@I
M3T]/]A::FIJ$0,$J-S=7#@X.Y/S\_#U-P(R*BE)`Y^;FI+&Q44A7-Q!]65F9
MA(2$2&5EI7AZ>DI149'T]/1(1D;&FY_\_'PM"2E.3D[JAI*2DG<7W=W=LK^_
M+S4U-0+V;'3(8F]O3URF^=$B+K=P6EU=U5+P?'1TI#%3*S*^NKH26/3Z^JK?
MR<'!P,O+BSP^/BJ.=75U6L^QL3$U"O7Z^OHD)R='$?OUS]X`AZD6\'EY><GR
M\K(6AN?T]'3Q\_-30Q@@(J<18``4*5I5595$1D;*QL:&!`4%*?RPFF+>W=TY
M)Q/T6UA8D,3$1!D<'%0<2(6?A86%ZF!I:4D^!/'T]%0_'AX>ZD$X55]?KQUB
M!:ZTM-1].M-);I7QL\OE1X#\E('CXV,M-&6CO+P;'1UU3>7JZFK=`-LZ.SNU
M(0$6,IV<G`A-RW?*N;*RXAS$M;4UF9J:4N(`'FH#^@@),@2YHJ.C'<M(_?',
MAK"P,`V=D*$Q$?",4?K:2B*;`5@(__$$"R%,:&BH&J3'\8K1XN)B[?74U%3'
M%"XN+K19?'Q\Q-?7]^<7#V7CUM:6RDQ@8*!45%0HP7!H,\`A<L4#WC&`>&,`
M5=_9V;$9!&CVT630'16R10#JR#^>`(Q#X!$1$:&2B7$`I1>,+MA2(%<4D`UT
M(V%2#0YB#"`'!@945$B#EG=61NU$I@<UQXA9\`+CS"2K=SL#H!L;&ZL=B%>$
M@[(AOWB'5%2$_)T:8!R99["@A9D"'1T=JHU$QS>,_7$Z&<E"!\_.SO1Y?7W]
M[V4=\*R3[-OU`+WD)O'/].1/BYE#U;\U``ID'1M6."GT]?6UPHK$P`S8`@K/
MS\_ZGF+3J]9V,W6UWGY<(H`CV$-30(+[^WM!)%$7J$E#(!XH#-2E=:$N789@
M,(4(AAL-3*2%00H[;I>`"440B"?:B")Q3^`JB1ZP0,7('?0V0=$OO%M<7)2X
MN#CM:+=*@%ISF$RVM[=5^I*2DG1(8Y"N!@5D@F\8-G*!A+*'P/K[^[4,F9F9
M*JDH)8LS]*1+!*@E-:4,"%ES<[,J)&K(\_S\O#ZC$'0!5P_N9P2-[/(-V4&*
MN>>P#_C1+P:'`P(,/481V0$9#<]/,R`P1`!<(7'&#0,GE(.R<&M&L@,"`G1Q
M4V<?]J@]"V0)G`5*"`P^\:W3"&:C@3CG(&**.A,`<)H`@-O,!NZV9`Q:0,T[
MII@)E+%`Z2`E).6&@W-*P/41G_AV*`$P47\VQ\3$*.NI*X%19^I()D!.??D)
M8K`=;ABNT"D,.Q#D/,/K]]9TX`";R`@M@#1$"]1,OZZN+FTO%D[,W95EG/*-
M;N#NQM2`&]C@>DZP<(CDW&I#RD&=(!+3!4TP?X@0%,9:6UMU`2]0,]KYG2LL
M"'`>+CD3M@\#H#YD`,&(EJY@H0MDF9"0H'"S*`G(X)P,08*)#2D9O"@?/("X
M:,J79@$(P&@4#N.H&GP`$9SSCAJS#RWY_3S!F&OFMPTCRD"G.-/X_S(-N67R
MQ\17;/P`;5E<"+T/RH0`````245.1*Y"8((`````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO
M=V5A=&AE<F1O=&-O;2\S,G@S,B]45T-L;V=O7S,R<'@N<&YG````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#0U,#4@
M,3`U,34T,S,W-3`@,#,P,C0W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````K````(`@&```!
M_)VQE0````1G04U!``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM
M86=E4F5A9'EQR64\```(UTE$0518PZU8"U"5QQ5>VQIBFS9IVD[KV$DF;3.V
MC<UTDDP::S-):XSX1$U`P8J*B4@%HL&(8B06H^;1J!-CC<K+!Y='>#^$RUL%
M14%\(1H0$44QB`]000+A]#N[>W_^>WEH27;FN_O_NV?/?_;L>>T58F&*$#,L
MXA?OY9`-(C!3".&7*L1T"XDW$XF;6)Y%/P_)TQ,S+/32EH/T_.8#]'%1C9[`
M,G)HXMUL3.`;=OSGQ6LVX"FIEEE5SX-)E8WTV-I"&OZ??7KPK30[OF+:KN>%
M\$]5F+)+BO;+D'PZUM!"55?OD`BRDL%ZR1[]+3]%W-;>11W41>OR:@R.55=;
M9=^]/[GY:,H]=YT:6MJII/XF;2N]0)L.UAF+C#V;,,CAW1ZLAR%X,.O"$2#,
M4L38G!S`1GA#C;?;Z0HP.;)<C?TK66G'MD%)O#1+PM9&;CH(Y6:2\$V1Q,8&
MF;CC&Z*A[^=3>-D%8\$3'^Z%?G?W)!;>2120<8::[W80:T9X)Y.UZAKA<'H2
M%U8WT<:B6BJ%VG:4U5/RJ09:N><,B=EQ)N(55C[6'B9C=]2^*5IU]KK\"_!(
MOWHVX!KU$G,:O_4P30LKE9@27DJ30DMIL@8_\YAMW@5(JOP*-I73!%6/[69L
M,PV;4M@_`C.[,><+*78[JU:WWZS+QQ%D==.HHS#T8&]S-L9_WTZY4.+HL,.4
M>?JJHG:-DHO33U^AQ(H&RH/V:YM:Z>F-Q=3"I^(9>Q^,W:-I__D;%%IZD81S
M.-V$1?751GRR7W$;'W$?C*?N4A2/?R#[%SXKD?V3:PKI%EQNTHXR^1Z05DG>
MJ954<ZV5A']:+XSYR+5S2\8O;R.Q*$WJ5LQ/A`VA7Y*AWGV288@8\T6_($G-
MN<(X)T8:C`>_DR$&!Z2;3&AYEK0,;7O_-YR69#B86V`FF\@)DR5L`I8"JX#?
MFXAK@0@@";BDQZ;H_J]Z[4<&'\.&?9+%PT'6?N-&7Y`A8GD6.TNPO7.`Z89]
MM>2RK<0P?`8[@PLP-5R!W\WSHS\]H!0[+Y&E?L((5A(>,4*'?16D&'ZI<D'%
M5[?I=^OWT<@MRC(XL1@T*Q"Q%Z>K"/AVNK"/VNZ:Z7*3%W&(]TTE,>ISR>PI
MV&I'%VA\DKIIX'5#0,=,>]JMC:G.%=)%@6<V%!%GMV'K"NBUW>5*4C:[0!59
MF?;!>S$-L)ZAGP7GD%=\!:6<:J1_A"GCO]W>2>6(B<(KCI[]3.FQ[MH=^MX*
M2+HB^QZ2^J70D?IFF>%:$6"&A>12^S==*@B]\%_)['&$[R_!D%L$`J\3I.V?
MJ>MN.Y_?7'R>]M5>HW$[CI+PB.;#H/&11ZCN9IN<OX$=.`7=BZD.<1XQQVE^
M0@6)<6'2A:V(9,7GKY.E_+*4KJ*AF5Y$%2'&AMW'02'?_20XERP55R3SX)QJ
M6J-S>%Y-D^PCRR_)?F5V-0DWR[T/2LR(E@MJK[=1%*2RM?B3ZB.IJ$6Z]-BJ
MW+-TY^M.&O1.A@-3F_%[QBJF')U>M["'D'@#\(PA\<\8_1RGQCE2<1KE"(;`
M/2[TB&0JHQ5@1"DN?AX(RKI.`VCLWK`:`=4I?D8D0NJ%IPPX!,)I[,)??]BM
MW;&O^1_I_L>Z=P(>%'K1-<`%"`!B@$0]WJ1[']W[`Z&:`3GTI;W7!:8PR#69
MF+QS9O0I=>IW@=:NKE[1YH!6A[ZMCW4V='(88*]].[T*R9B/XK<0+A)([KN(
ML6%6G-!!71WN=+:J>"ZH[<%CLV!IKX22&`/G<XZ`$P)NT>H97B_&AI,8'2HK
M`O%&0D\>$A@?N87"#E^4WS022H^*RU0-F'W,)JR,4>;P;0K18A'">$`Z\L,M
M2>N-B,%MZ.I\V8^/4,%S^Z$Z^BF"*N<3NX+*S`MSWP^TV@D[;$V!'08N+(/'
M40K_X:-"18LHP^W]_+.Z[#DH>Y>MAV081")3!7AOPF*>(Y196%M0Z;7.ZE58
M/KZ%*2J@</*;BR/S3E"!9E8LB4FX'RU.(\_8XS"!2*E-,2>.1GRP5](.7Y./
M<'E6UO'""SS<L7FW*,73/49N4&X$M=JW%_;EK>1N.2:?PX[4RS[N1`-9JQOE
M<W;557E'",D_)]\GXJZ3KITR$/<'R>.M=-F/02TBQS-.TR,K%?^6]DY%,R&2
M!NL+X,"%Y9U#`YV=\%IX;J)./*P];OXQ)U##)!C1]MBE9GH41ZO6JK0:8JV6
M_9\W%LE^U/K],A/:V@_8-/"=(>_F?$MA4;*(1>GTPV`K_6I5GK2[I_@NYQ))
MKWQ>0@N33M*"M#/T:W:@,:'D83DN!7&+.D9\*YZ^"_E^=BQ-#"^39N0<>HAF
M[SXNL^[?8-,/!653(&=5KWAR6I;Y'6C6(]K0@G/X$3K?W$9KX41%N)RL+3Q'
M3W^B-.8!<WD1SL1M]/92>?]<K$UA5LQ)JFR\1=L/*U/ZXYH"BCQZF;JZ=%7D
MG_H=V.PT.-!\>=>F":B'Q9_64\&%&U1^J45617-B3]))_/'`K:;I#DV(**6K
MK5_+]Z.7FVDVS*3^EJJ>$F!"(:A9FC#/I<?Z`W54=K$%Y=MF>8<9`BT/0-CH
M;F%=+2KD($1M**ZCJ3O+Z3D<'Q>;SP`S8T_0#`C,%R0W5&>O6X[2LYL.T*"E
M>^3<B`W%LC[G]RDX_L?6%M#:O37D@UO;HZ@WW\L[2\$%-:IVUU6>3=BAB*UF
M"/G?#Y<>IAL=5QV<N8P,YK)3A2[.-EX:<TW/\OT+^[EY#G1S>UEGHX-"'M!.
MN3I??E=5,+ZZ+%J0I*H9NW3&Y1&G6]8NZB\(((4>R/UKH'<V*20+QTKDVLWA
MQMD[F)"Q%,^+<8U:U`\"[X.F7T`Q`1GJ>\NR^I8)/]7`<&`'4`8\!%0"?D"G
M3HDS]7B'?E\-!)G*N+M`E7X?`[B:TJDG,$$_QVCZR:;Y?P,C3>];`&?]?!EH
M`8J!1IO4//$J,,(DP$H@6Y=I3^K[?2[P,9!I6C<4.*K?7]/SK^H/6(#G],:7
MZ=OS5JV<1N!+X$U@E/ZOX!`0"+@#BS7/$MUG_0]BNT/C?(RX+P````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\Q,"YP;F<`````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#(T,3(@,3`U,34T,S,W-3`@,#(V,C<P`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```@````(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W
M87)E`$%D;V)E($EM86=E4F5A9'EQR64\```$G$E$0518A>V76TB4013'?>JE
MYX)Z*'HIZ`)!@1B!]=`62%04E)%0=--*`K',H*MVQ\HRO&`47HK2*-,VNBC6
M6K9I&<1J(&U&6]MFDEBFEGGR=Y;9=MTMML@HZ&%VOF^^F7/._.?_/V<V0D0B
M_)OOP;(Q56Y55WM?LDX62W9VMK0\?^X=:&]O%]O=>U+_\%'@>I^-TLO79'A.
MF>C`P>/Y$I>0(GOV'9"M:8<D(BK:(D<S,Z7C0Z<$N/U>TY^NKBZY6E4C&3D%
M$ANW0DW97"]E=4*B=]:ANF[9877*U,(.J7GLE.2"VS)BK^,G7/R>":L3-\NF
M;6D*`"UZU^%O,12=.2>@,S]VI93:[7*OME9WX)O`%EE==_^^HCYGP1)%S^ET
M>LTG):=(;V^O3O!X/-+7UZ>]6@"#WCZ1I,KWLJ;\C4*\ZD*+_+YM_K(!&`.5
M;MONR(:D%`G;`'C>L==+<W.S',O.E?EKUTOB=;O,C%FHZ/`,MX(,P!`\6J]7
MJ0&@A7O@311@GY5W2BHKJZ3Q27,@S#30&QF]5#^,&CM1%XZ)G*T4G#1UNBQ9
MF:@]CJ;$QLOYDI)`MBW,*I/.GL]JA'/*+RK1]U%S-PI\IF<<)05AP"'[#[K=
M[I"@.1R.H/'!.\9_W`!)#/8I&_O/'AZ$;:"QJ4F/L+BT7(9<>*`ZI8<3J!RU
MNURN8"::5G"NS)<Y4YL\LCPM4V;,BI%I<Q;)EH?/!+[T]'P*-I"7?TJ]80#O
MZ4=R-?FQ%1C(M^T'CZD>>&YK:_O&1+P1MLF><!W*DN&A-#H@J_!,CV:(RF?`
M>&8A7M`#VX#O%145VN,91:()&L\!6XC,=:K5$8O3->31\?FJ1M[I`9%QWG%H
MZ.XS,&U+D8J'TF%$A'@(EW<2(HJ=L&QGL)A(C"RD.!!RSEVW(CTNKU43"SW<
M.&MKDH'"TQ\F4/A`%J^$3T^X?,<("X>NOQA:C>C=?S"4G)D3:OPO%=.?;/]N
M`&@76:'5@8E^4`*@UJ$@M'ZCVN:3*G6.`$@>R!6]0UO&3-HBQ5%0!FH@K``H
MM%1KDZ6XZ!``P40UO)7)ZS8+5TN>QUOZTY[U@=9-QGEFS-+@T0I/(?ZI`(@<
MB$VFPS$!\4X`IUM>J^%UZ?MEWY5:S3D)FW9KH,S975(FY?T2)7&!5%A'@$-@
M)@==LMY48SRS<V`G$#(F1E^UOE7(N;R^Z!<YG"#ED);@"'<8WOEN;!$@5T53
M%`*<&ZC)Y?1`AE.>,4`@&&#WS.&L<88CSIC&&C;!/!S#`\,=[)/*0<H<1T``
MY$*(Q$X,"I`+8RPD<DH;SD&$>31S)#C&N"F!H$00--;RW?3DWI!'8'=U:_:F
M=K`C2L')4JLRG@!S&CIE6&JU&J$\<#4F28,$1I^ZWF@=9CZYE\K`?'.9^R$'
MJ`#N=YU:2EE\XM$G_<_!#I`0WR$;SDCN9QT?)69'L>_B;H+C;P'V")#OWW,>
M$,"[KB]:S[A=8J"QM4<L>5[G[(QWD`%:X]P$AW.0PSE\X)WY?(>P824BBNJ\
MY`PI+"P,6F""PSFDP@$*@.'^5QQ_%'$^-WYKT/=?SH2#U?X'\!7:Q;Q?B!\$
M8P````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T
M8V]M+S,R>#,R+S$Q+G!N9P`````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C,W-"`Q,#4Q-30S,S<U
M,"`P,C8S,#``(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```"`````@"`8```$$?4IB````!&=!
M34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')
M93P```2.241!5%C#[9?;2]11$,?]=WKJ)>@AZ*5`HGHH2",JZ'XQ(\S*4C%*
MM+#([$)J2NJNIKLNN6N:U9JEB7>TU"Y;9N0-)%$S1$4F/[.<=1=UV<I>JH>S
MY_?[G3ESG^_,AHE(F/_2GXF)"2ET5(CO0_*5&]+5U24GD]*\9%-34WHZ.SL;
M>-]WQ?;@H>PX&.OED5=<)MD%-CEP(E'@%?;I2[^>]/;VSDL)MO0GYYY%;.5/
MY&IFOJ2D9\GK[G?BKFV0XZ<2YBDG)R=E='14.CL[)<5:JL^ABU@>`A3$YM:V
M-G%7/Y,``K1U/:Y19VS=>41Z>CZJ!4J0>"%5WGEZ]!#GE#BK9/WF[>K*\?%Q
M+QM,BJMIEIF9&3'FLOM$$):S2<GJH+/.:N%]^<S\)09C8V.2;[TOKBJWD!L8
M&C*#RQG9\J3FI>:@H[Q*NM^\E=Q"AWHI+C5#5JU9)PL8M+_JDCMYQ>KKC*P"
M>?^A1]*SK>K*UHY.]7M#2[LFYNV<0G76[J-GU),^3EDY]V1KRG65L&+E:ET\
M;XF*U=VLC9'[9%OD#KF6GBX!13$R]DVB8TZK>D-#0T+E7+!72$-CHWXC1=@)
MTZ(^X*"CHT-,8;)C,SL)P%Y:72>U=?7RY\/X%S#`X]1;4TN;@I%Q8D@,8N(O
M:DV2?206Z5QD=\K:#1'R=61$@C)`&AE'^C8VMXJSPIO*AV//*YZ11"8O`AB0
M-$A!8K[=)5=NYRH6LTA9+L,(;4AEM`0M?`SXD''7JD4$D]JF5JV#%_4M>I%:
M84%'G4`+[/@8((&+V(W4B+TQTM?7IT7$1:,^B_/(?<=ET[9=\PP&!@:T0$PA
ML2,A_-AI[W/XIOGB2DA56LI]@1/!=?Q!:1LPI"XN.9_*\/"P/D.S:!1`37-(
M_/V+"0W)A<)*]^)18`T.#HEA!#X3<X.N27,@PPZ0+)D'<>?B`TH7+%A0WMD6
M^0NK\=]4`+BA%],$J-M@<+,L"M!IP3=*LMA1IKE,SK,H53"`ALKLX72Y?)/#
M;RM`/5#W-%30"N'N9\^U8].`^<98R<C&=]`*2`0&#"P4%9?(+RE`(6*UZ?@(
M82\J>R0W<^_K0CCX"X"#=(`5"JA"<\ON>JI>8S;Q'YF65("X$E/@TFHK4TN9
M_<!HPQ3!S"D@)F?0@I!8^O&#1Q&4G9$$Q5#8=!9F2)K#_NA3"^<W$JK`7JX#
M$$)@!*[#@"D9:TV#P/TH@Q#PWN/Q*/9#@U+P0`B0C4$HP,Y=\H00D5<!"H"\
M7,#M)!2=AQW7D@=<I"]B.7T#:Z#!Y5C*,`8=88".Q1V$8K7AS9Z:=E4,/`:$
M@#BA")8!P/0-7,O875KJT$664P4D'31[#AT5B\7B/9OKP>R9F9FZN(OE4>>2
M]![>HC-,3T\''Z'I/\3?:,G@EUCR4.N>3FGFM%LVEZ\WLZ#!8_0NWC_W#VHO
M,YTFY"J@[:"Q&4,J:QLUQOZ93&_'0B91WLD78NU/PQDT/Z5`0E6=EHYI9:,3
MWW7,)6Y&H9O.Q_K-C+PZ5\S]0_.GP=WP\O_7%)("C`2X.1B:_0R-">/_;KC4
M^@%@0_/5+PU5E0````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,3(N<&YG````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`R-#8V(#$P-3$U-#,S-S4P(#`R-C,P,P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````(````"`(!@```01]2F(````$9T%-00``UMC43U@R````&71%6'13;V9T
M=V%R90!!9&]B92!);6%G95)E861Y<<EE/```!,A)1$%46,/ME\M+U%$4Q_T+
M@J!-BR"((%K4ID6T**A%)$&+PMX4TL,R8["FHE'+++/$J(0R[&69$IJ1HV4Z
M&CI:CJ:CY5@V&-7TH"(4"ER(G/J<X?Z:7S.&14%4B^O<.7/ON>?U_9YCG(C$
M12[]4UU3+Y?+;HACERLL/9!7(+GYA;)F\XZP(-?;*8.#@[*EJ]]^W])1[KXM
M9RZ6B`IFS)XG<Q8ND\4K-DK\TI42M]7AE`VE;O$VMXAU)7)Q($HG]I145$E-
M0XN<+[TN3Y_VZ_?M>P^&3YVL]JC19>45DMSHES59N>+S^>3CIT_19L8T>\P'
M3ITIE%$/$+RSQ>7J'G[;#N2?NR)$9_GZ9"&P#WH>R?6;GJ]QR#M=I#\BY*")
M7*??'U93W^B5U/HV>?WZE0IQ-?'(R;"&C)9N&1D9D:2D)'GV_(6FB%35UM;)
MC[OY,RNFL*6U77`,>WL"`<W?GLRC,B8%VU+W:M*KZYJ$\#4T^[0>-Z?NL_9#
M0T,2,Q&LIKL^#>>F'5ER[4:5QIQUZN)5K1Y7]@DQ8:=@+`6%;0]EVLQ96DDK
MT@[*I"E3-:++$A)TG]0;TD_.($>!90%IX-*VUE[)R<F1]/P"V=G8(2Z72]85
M5<@%CU=C`1(HW>[N;KL+*#`"_*..(^,2#`:M[X#A]Z?QSU$`SBFF'U9`OD$0
MD6_OZ%12>_ONW=@J,3%ECQ84"D`X5$E5@D]JX+L*`KV/]!*ES"?51_D:L*,H
M)O$95N`0]4\Y4[+)S@/ZB1OD'P4L++15(EI!&X=`GJE[7_M]Z>M[HHKA(L@9
M!;@):5L*,)V(\SJOXB\*<0.:1[9@R2J5LP>QX,+F0F+E'=GD2-5`;:R]IYPU
M<=)D69]_7F;/7Z0O+LG*TXR@#/JR*=B=EJ%@ZNCI5?^"K][(^P\?%%@0H@$9
M>T!F"R(7(4$0N?]6D_J]ZGBA(A*R/%KFUHMF'Y4%(`N3@D0@6WPW#&506A<(
M*B<,#P]+E3^@^R@%_&@$H5#(=H#?C"QR_Q?!^=\R@.*E_P,]$`)F`3N#`S(S
M^OQR`X`J^`7G]#HF)/#.*`'.^4XWAL*<Z=F*-*#\;<7]E`&&'WF`18>"I?$>
MN2$<(L&CG(?!(!\0#04PO8W9`,!(2(M+2M4;N)6'\!9/H4V4T_D9%]@[T@[K
M8SR.D8''065&C#+W21'Z(++(MFM['-[%"\(+,^J,\J4C\*A1#)WB(<S(G(*L
MW?]`']3]%QU\QV`>-&>($GHQ$G(T+<IF`(3(!2SF<2YBB/&2R\9+ID4>)27T
M/E+"61,-ZH!%7\`I6!@YQF.`F4YL!L!]&+#V9K/R/6MNRF[]'#=^@LQ<G*`4
MSQXYU&_V*.4WSB!GL9^^(-XZ8_:0\L#`0&P#8'98'3*F)1`JO(795Q\[+4ZG
M4RXTMHFCH$CW5#HY)?2';GNU%T'8U!!>LI`S5R-G(ARU"+N>O=1^A'5,BS0Y
M+I$_>A/5?ZFU2Q^A4.D.9H($@A@"%S`,&CEMRLC1,RH*[H?>JO<+X^,UQYE5
M#4)-4,DHHY]?K?'HF,J^TNW6WD>.V7.7T1;#TBL]FG<XP\AIJ)%=*\H`PI22
MF6W]=V%20B,E)804!7A#[XQ4DE'?JGV4M)G<?BLG@O^;T1]IP&?6V*JYJ@":
MD`````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O
M=&-O;2\S,G@S,B\Q,RYP;F<`````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(Q,3(@,3`U,34T,S,W
M-3`@,#(V,C<P`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G
M04U!``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQ
MR64\```#W$E$0518P^V774]3612&^9U<\0NXX$;31$),&!,_QBE:4#2HQ)$!
MM3K$0*RU4)0*E1ZE6&RK4%NE>(:V9)@0$A+R>IY%6B`%!4'C&"]VSNX^^ZS/
M=[UKM4%2P_95VRPO5U0[>)4MJ%0JB6?#GI_L.'#_*2F93&[*N/WW4[$&'\9U
M_H_.K:LM+2W:5<:>2G*%CYK)NGKWWM6'HJNN2U=W2EA9^5=K:VO:V-C0HW!8
MO;V]!U1Q^`M/8XXJY;)ZKM]3W85<+J?\!U>1V*QZ>L.V+WN7[4(T&A6AGT[E
MS;U\<4GG_`/J#SY1.IW>%+.^OB[7=86K75V7:B[N:J3C).3S^71T;AY*``Y.
M34WI0`)2LZ]5]O!'-(8?.7*FL\K,%77J3)].G[Y6`UJ=`%!8=$L:#,4$<@CC
MS?Z(HN,S%EZ21/R7EC;O^7PG##PU)"6<%TJEYQ4:3:KSR@-/^Z0*[Q?-FO%$
MQG)#$I\]SVIZ)JW&QD95*N4O!PF3AX:&%(E$U-;6)N)RX"R`<<=Q]/W3^#\7
M0-`@!RKIP$@<GYSU"K9D>4YEWNGBQ8#V)8`"AD;Y>&QRSNB08N\(!`U<U/)G
M!<3C<2.^3,[5A),W2(,\N!7X8AE@JA,`RN;S12L<8)MY4S#H0C./HXY900V\
MGEOP+%PR;MI!G!0+TM&"H/[[$YI)S:GDN5*MA5MW1C4X/&'%=;-O1$U-35L"
M[MX-6K#B3M9>4KH(@PUY4I6<H20<22AX[X%.GFROIVY2MKJZ:B:SYSDPX%5A
M3X]5WW:NVS>08K&8NKN[3<AV-MVW`#(#K5'&S<W-^BHHAT(A<^TGK<9?!GPW
M`ZAE*HNZ7_RX:*S#&?1%9=%Y]D+:H0Q86%BP&J#QLE!,IX:I>%+^G$-$T-[E
M*T%U=`3J.OA7&3`R.E93"L?"*\R*4.5P>-I8[[^598O$R)-7NO'G8QLGQIZE
MK8E?"/3IV+'C%KE]&4`(H0X\9LZJSLA.*J?)EV^-1ID<(#<6OS$$Q;"E31+>
M",(8@K$LF/:O_CO6GB!-Y&]/U=8D[%G)R('0H9$IXVX8EJ[R9KY@TR'-8O!A
MPK@>GN?,%%8V5S5-?$<3@;HAU(JW7B3G;5YB8(?*Z5X[#,!KA*&,GE"=6PDG
M%(Z'M#7>$W84$B$62HE0]0Y88%7_*7!6'=3`QZX&5%,`RF'N,V=_M\OT#?8\
M6>WMORG0V>6=^=7:VFI,SV^(FGQSSN(NBKA/4Z<?<Y?V`K"/C`?R^;S\?K_E
M%L-1PI[6@U+>?5,BHEWQWPOOB1Y-$["QQ_LO<<.1,1H*,82P$PF\WVNB_=4+
M?B@#/@&9=F,^Y^-DV0````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S$T+G!N9P``````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,C,S,R`Q,#4Q-30S,S<U,"`P,C8R-S8`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```"`````@"`8```$$?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F
M='=A<F4`061O8F4@26UA9V5296%D>7')93P```1M241!5%C#Y9?_3Y)Q$,?[
M(_U/_*'EW'+.+"N:YI=&.8M56C)=LIR1^#U$*4!0-%`1)044E,S-.=TN7F</
M0B"$K:W5#^=XGN<^=_>Y>]_[SFLB<BU?],_R\HKX_"$)!`+G;]]/!B252LGL
MI]"%JMELEMR1(AO1[92TW'MYKN'Q>&5D=%Y,;?U24U-SKF:U6J7@2+[8[78I
MLIG<2XOMO4MZ!Z9DRKDHZ71*=G?WY/KU&Q>:O;V]<G)R(I%(1,J&&8O%BEV4
MDX('YX</<JD"@8V,>B442>22D%/82:0DLA67%Z\GY,MV0C:WD\([53@Z.I*E
ME77I>O)6-F-QS7B/Q:'ER%DX.SN3C8V-G%F'PR$6BZ7XFL/#PU);6WOY-:EP
MV6M>14J^=+D6M%;[^VDY.-B79Y8WXEM8D(H&P!WIBL:2LAA.RKAS17\_>^'0
MM)&^KD=/A*04&)B<G!3KD%.]+89CX@]NZC,YQR@';>_<"LI@*"K]`[-R^XZI
M.(LVFTW`X_3T3#;\?3D\/%0E?@-B$$?+4+N25PB'P_JAN[M;/8,=#))]4(A!
MC/Q2%3#&80K>T_-4JJK";Y?Q[S!`TL@!?5Z5`;#@G`]*.HM"D$C=V]L[Y>O7
M3&4DQN-Q+1_=/3VWIN#!X,/.0>U7:*BL`;?;K="%%ES>384U#0XJ@3*1M;:V
MRO'Q<2&00![*L``'0JM;"EL@/3;ET2CVLI%]7M_.1KBG/6(`2@V`>:P;W(/'
MQ>"J7L<@=EB5*\&LS_LFI*&AX<(`/4"RYGVK^A%62V;;&1K"J/$.)T0T,#"D
M/5&0`XSP@49A)-"RIZ>G&@%7@,?H"8/+2B:1CFMJ:I)$(J%*),OH/)=K3G%!
MZ)!-20/P`@)XZNKJ!)(D643`;QP8QBLBD6L0-@>1JJ&,9W!!R/D$4E4SE?/\
M][3S_Q,`A:0S&'`&:["\T!$T`#M))>ZZ4@"93$;11&O2`)`";`/KA+/D0/OR
MS>=?5]IZW#,H]?7U1>/K2@'0?1@W.)(;,[&ANI$QO[+6M\.,OA^?6=()SI8$
ME[+CM'?V*8?^O)A=&@"MSVV9I_`&MV72>X,;XEY84QID=6730G@F$!R_LD[(
MUI<=#91)`(DA,"4E@G(9KY2JY&"GOE#HQ-R2C(Q_5.Z%(5E0P^M;.E)(N\WN
M4:Z&%7F7_K$`X91,()R#DJ%>2LAW2L1*<N]^N])440!P&*FFKG#Z0>9`!\+,
M[++8QWS*YXPE@B'M.#3XGC*!!4,'+"`$@?".C&'K[MT'2K@E2T!J2#^4S2"E
M?HPP-C(.-C??%I/))*P^/+>TM"C9\MS8V*1G6MO,*C<;;NEW]$D]W]"+1J.5
MR9AZX1@>A<$!$<^(L7^5$MH0?<Y!HUP(AV27*9"_5OX2F7=T=*AS,F&,&02@
MTB$`"D<$;!A'GW,(M6:B\(X`&)"_S82`E>#H=8(B"$87OPDD7Q?>@`_*$515
MSKD!.$#X;\387(T5^.=A^\=F`51,`&2!F@,T@BB5XG]G&/TI^0XX^83]9(&^
MO0````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D
M;W1C;VTO,S)X,S(O,34N<&YG````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q-S<W(#$P-3$U-#,S
M-S4P(#`R-C,Q,@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````(````"`(!@```01]2F(````$
M9T%-00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y
M<<EE/````Y%)1$%46,/MED=+95D4A>OO.7?DT(DC!15!S"@&<&!.F+-B#HB"
M63&+$7,6`^:`.:SBV_2S?65JNZ2:!H7+N_=X]CEKI[77#TD_GC]/+^OKZWI:
MB(B(4%U=G>[N[IRW.YE\O+"XN"BGA<O+2[UJ\NH1CX^/ZNGIT=K:FM+3TQ42
M$J+.SDX='Q__O?/AX4$E)24:&AK2X."@/#P\/G'%UVT`1T-#@UYL`'U?7Y]&
M1D:4F)BH[>UM;6QLR,G-B8D)6[BZNM+M[:U*2TN=O%!]?;TM%A86RMO;6^^"
MW-_?U]>Y^<</L+HC;$2BI:5%W=W=BHV-569FIHCSX>&AYN?GE9N;ZYSK^_M[
M-34UJ:"@X&ES<W.S%0>5DYV=K>OK:RN8Y.1D14='OUHL(B?D(BPL3'Y^?O8-
MFK:V-F5E9=G![\8`@_/S<[FYN<G5U=4,.,#%Q46-C8T?'_"?9^'[@%_2>7-S
MH^GIZ1>I>_,`C.AVJI*JR\_/5T='AZ:FINR;,B\J*M+N[JX=[M3P&*6DI*B\
MO-S8`2[M[>W5[.RL8F)BK#_2TM)T<7&AX.#@%_VNT]-3*]V$A`3C&VX<'Q^W
MFH=!J,:CHR,%!`0H*"A(-34U+WMA86%!965EVMG9D8/`Q\;&K#>`?')R8KU1
M45'Q)N/8!KH/_QT!I#?@=G=W=WT81'ST\?$QG^%WH`-[=755<7%Q.C@X>+>9
M#`&1QH@`$EQ(A7C$Q\?K7Q42,>"7]'TWT]<_WP#^/P!H,)H*2H-H8*OJZFHE
M)259F].]S,Z_N-,:DG?XH[^_WSKZV=_;G8P1%T$)T.+FYN:3/'#\'WF`5AH8
M&%!.3HYI)J1A>WN[O+R\-#DY:?P#?>SM[=GW\/"PJ3-/3T\G@G\5`%Z"'"I!
M:\W-S2D\/-R,1T='36[`R8&!@>KJZE)45)0-?:1(5565,2</PP$V75E9,?I%
MY,+I['TO!78YC`IJ?OW]_0T]QH[0$B5$/)SGZ^NKU-144]!$C#T\K:VMQL!$
M`FV$)OI4#<"\R\O+E@XN/#L[LW#.S,Q85%AS@,%CY@GI0+TQE`#$H'JNHC\U
ME!V'4T!X5EE9:8=&1D:JMK;6PKVUM64#"T#(2<(-X+R\/"TM+5FQ_N.A_EHZ
M`$+5XQ4Y+BXNMLM1BG0`Z0(DGE)X3$OJ)2,CPP"C8QW3Y+?:D,(DEW0&A4A$
M?MV#H$!`\!X:&NHD'KZ9\!O`6\]/I6AV$KK-J7$`````245.1*Y"8((`=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E
M871H97)D;W1C;VTO,S)X,S(O,38N<&YG````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-#<U(#$P
M-3$U-#,S-S4P(#`R-C,P-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````(````"`(!@```01]
M2F(````$9T%-00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!);6%G
M95)E861Y<<EE/```!,])1$%46,/5EVU/DF$4Q_V2?@K?^*[YQG(6F5IA&TV*
M4G*YT8--%[G(0?;`H@932`,*,RHBS2@#1*>>_!V]>/`&LJ=E;A<7W/=UG<?_
M^9]CBXBT5"_]6%KY*EM;6]+1T;'[U&:SR?CXA#B=SMT'V]N;4G/%(N-9]+7<
MNOU$3[4$@T$9&#@G]H%!2:52%:&A4$@L,F9CSR6>>"46F7?\S^3ZA']G/9#<
M:EZPLU#:D+X^^^XI]'@\'KUI=O3&X_%:$W&$_=/*2F,_ZOK%*A:+4BP6Q.5R
M2=T#^4)1QN\$Q7LO+$Z7MZ(BG4Y++)%6J[V^D!1V)(UXIB04?EF)@\/AD.[N
M$^(X/RA#0\/2TW-&?#Y?Y8!Q+9E,2GM[NV2S6?%ZO;61Q&]V$MG5U65U$S4F
M:.;P@>)PX#B9M;KZ37.UFB_*Z[?+\C`TIQZ?OW!-\*&A@'`X+(E$0B*Q!;TT
M?C<DEZY,*K#<5WU"(CXL?Y$W[Y<%-TQ:RV!(+KR3?+$D/G]8+_"[5"I):6U-
MIH,QL3MNR&F[1W.`X-Y>NQ6/,S,S,CT]K9:`7O.=-""('!4*M7"H$<"!_3YB
M^N;FIJZ]OY:YN;G&62!0)#D0")3+YM2I7@%2*``$3;/PVVD\'`+P-_<EIX""
MDS8V-N3``J+1J(!&:I"%$/+?V=FI*6PJ@*A#.V\RGR7P.*Y@0@`5/NF/R%F[
M6S*9C#4+(,Y<#D;B>ABT&7K(+JW(^OJZ"KYY<T+3"3[*`B*S">63Z/R":DVE
M/XJM;T1IA(M8P3M@#O<`=5PJ"Z#R7BY^T*I#$+B'P_&9RUSH.SNJ=<`[!,'/
M%0$[07.[W3(Z.JID`?+`.Z;"4U`P[,XEWM,Z+$$<&QO3XB$+IKPI(DQ%&,&C
M:DDQ"BT".,@RI,$^-36E.-BK">GO[U>A"*J71BTB$UV6*1QZ@>EKU958%TAP
MPCXM:@G/8-P?(I$@X2>!Y+=Q@<!5TW5#`5PFH.S&@K:V-K7B<);S/S$`3!%7
MPL)J1A=_Q`"`^SCX5/R/HI+[^DVA!@%0EY1A)+8H%R_=$-JOH:,_8@`XGD^D
M5!%S!?NK]"?Q!6:U85Z_]5`@$EAHYL5;K?>CW9>UWD_VN!1Y^W%_8`-@9+R!
MF6"HY&)6E3`&W@_N4AX$1/LG,M`>9(.!F:6<=G">#SHOEX<1F*VI`839M']8
M+!1YH?,A@C`"AD<)5`G?$GJB`;M1[2@@-:0`PSE/RO+Y@G(Q_'SD2(>2GL4`
M*A]O4,`HP22`)WB,]U`M[UAP,R2/8"@7''`&0QEFH5^,Y+OA<9X1)::_NO,;
M@N`RQF4&)!:&W)Y\JMZ2UV,GAI3O,0QCP0BX,.'F'(J/VX95&<]83-I@A6[4
MVMJJ`W1####"<(!2@]+I`1A'B(D*.Z4'/F!G6(OH07F`#A8'>-R%S>!6?G.V
M.O1-YTL&,RZS$RZ,,.2,8`9J>@SCD_G/@^A5MPE*%<48@&+3X.A930W`0Q9"
M02\>FEFT>J&<_L4[%&,8`*R>=^D@`),=.3]5AJ3"M!^B@D#"KM/'3HG6:R*D
M@=2Q\!:0_C83`C2L9S;`:Q:_3>OGPW1O9FGP@G)P1`KWQN)?-X`HH(PPDF>&
MEWKC(CG',-)&SE&.0?7(YZ]T0SPV\[R)TG_1CK\#!-Z<0#L99G,`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\Q-RYP
M;F<`````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#(T-#8@,3`U,34T,S,W-3`@,#(V,S`V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````@````(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9
M=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```$N$E$0518P]67
M[6O591C'%T38/Z!!U)L2`M$7]D*D%QM$L8S,&+5,"T)GZE@^S.7C0$]S;N@A
M=]S*AW.:V]+:8]-VF&<Z09V"#S.U+4Q:8(OJT&D<:#`RUK=]+KFW'<_#/!,-
M7UR[?[_?N>_K^M[7?7V_U[T,21GCS?Y4^"IUY?L;&AH:NOUUY=HM*O]DKT9G
M]/?_HK^CCXQ]B/-QO>^FOFAH&9MQJ/F(BK=[;W^X=>L?!8-M^GA_?;R/2U=Z
MQ?*^_M_4V-H6.^&%S)>TPUNIYK8.\1P3='AX6$\^_8QFS9ZCK!>S-6/6\S;&
MA2A<\[X2PDYEHP^]O3WJ[KFNWAM]-A[O[(P-`6H2V''BC$A5G`>2T=K>H=7K
M/8I&H[$3<A?G:=Z"=[2U=+?(/+N)F<`'MC;]N9EF6:^\KH:FIC$,*T?B8A?/
M/:Z\Y<M'?XS!</7"LTJYS<E:PH\<J#O8GW\-6^Z"H5,&+^>M1=JXN4212"1Q
M13'AF]`)G3QW7K6'F^SP>7]OZ8<*A\.ICY(%F[:5J>*S@(VD=9?O@%R:#];4
MI'9`BHG$`L_./0:72N9L<(C-F9NII`Y:&D/:7K'']O]CWT^J/CS3V)/C*;73
MIQJ2(CA4TZJBRD_U9V1`@4#`%BY>]++6?[Y.%.*!YJ\?X#'^_P[@UMG+UZR`
M,%2"HJ(V^&U\/<0MYJPY!<CI*I'GPJ*/K!(Y8@HKJ0.*"%83N>M\MXU$Q0%R
MF7(+R!.:2`1JO[XI:(LQHD^8@ZK]?BMC%OAKOS0>4-[+"C88]`D=4.^H)^6[
M9$61JORUMICG.TLXH0-X@!.$B\5T!0CER$0>DCI`)YG$9!;CC,B0BA%4:)G3
MTS@',`]]AY$XXADA1!!I!J;[(PZR7WLCL0/Z3E[5/A-E]+>U):0_^A]55N93
MQE#8":F2;L'GJU-M>\@:%PWLY@]3E)L[6SO+IBK\>\14-V42\X]V:'#P+ZL!
M%B'1?G^=YK_[JJ$Z/5+&=\4%HG>V3U?WY4MZ..C\P`$,#$2-[1`6>8"PU!9&
MGKNZSMHW4LC)4QUP])X`H#^!N@8+R.4`>4&CG"$Y2`^&>C@YPN`S'-_E]1I(
M"B4M`$A0Z0ZO[<X%P#%`G&CRSJXQ@D&J_%6%\GA*5%Y>:OV0XH(':0-`QB"6
M*=1(61/,M7K,J37!V2UMGS7C+T&3K@&<(`,T9(Z`@.@,SP3DG6>Z/Z*%$G(]
M!("[>TP:`*EW^H.@H=,$(@COF+MZN)L=HD?ZD=Y$]YBT`)#*LHJ]9F@Z`0D"
M`(("B(Y#PT"^G1*CP@N7YELF[CSOM`"0>IP0'(?L#IGCG#D2WMV="7#N&V`8
M64?V`)@6`%*/Y!.<5`*$W;D=8GPCU3R[2QM53W!&@&$`P`=C,BU(B`KQY@B6
M'/Q*V6N*#-"J@DWV/G_9!T8O@KV]9:&J]SVFG#>?4$[Q-KL$4H"LI3DP%_YS
MUT.@$H%(JG:(#CR'"=PZ5[0$K5WA9&OQ7/T[F*%C1Z?8)7)UP33C/Q=+F+&N
M_DC2R^2$`%`Q>B(!0>T<TFQ1,A><7NG;76)-EPP@.,BSFSMI%K`+.#[>`?_V
MN,#5-5/M3)W6-X:.VWC?FQ&4ZOGNV[L6F(>F'?\'^'N9K>-!INT`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W
M96%T:&5R9&]T8V]M+S,R>#,R+S$X+G!N9P``````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C0W,"`Q
M,#4Q-30S,S<U,"`P,C8S,#0`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```"`````@"`8```$$
M?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA
M9V5296%D>7')93P```3*241!5%C#[9;O;Y-5%,?WSG?^`<:7FI"8\((8#`%B
M-.#\$37!(!BW9$M$Q.IBLCC+(*+CEU108\4I$B<!F<L(J-L<SL8EK$YK:)B#
M=>TJT]%T=4T5T"W&1O-UGU/NLY95'!@-45_</D_/<\ZYWW/N.=]S*R15%"_[
M6?/D,^HZ&I(G\#W=I#?VM8FG"5:/I+5UVS:E4JE2>\_DX]ZP[EW]2,%'7?UZ
M-3R_4\ONKU;E7?<4U-+IM-Z/)69V*5Y#0T.:Y7-7\SX%W]JO33N"MD9'1]45
M.J;:M74%K5`HI`6IGPP\\(+IG*:FILK#+`M[S@KUC4WZ0X4#[1]J[X%#AF/>
M_(4J4>CL[M&Q_H@E\\OC48L``U,X=^Z\A4CJ\(`2[V20<"NN&\^+,`^VOJ=E
MW_Z@OG!83VS>JFLRO\UD,A*)*!`(Z-G8:8N_/K!3^7Q>EQ_FE:RR0O)%37"P
M_=$!46.93$9_ZN#DJ9AE`F.>N]]N56_?YUI94Z<CW;V6/IR5K6**CK2UM!XQ
MPZ<V;E=_Y+CBB1$SWOS2'BM*YV3)[96%-#M/\1\GM>.;<;T:?,TJZH[Q27MG
MD7YD-;6U6GSH([W^YEYU='3,9)G4#PP.RI_*B8.-1J-6GCPI21RTM+1H;&Q,
MG"O'=LDDYG(Y3P$'[AW(_\PQ7AT.R#0=<=D.Z+M7FM]1=&!0%!9UL:EIB^;D
M@,;%X'!GCU4B34LEPHR+[EQ9UE')'R!3QE2;*^,7@WNTMOXY>X??RA(?AK!"
MZ^%.M7]PU)Q0_P;_`A$2#M]!Z5O?9'WO.0`JB_BI>W;$$49?G1PND/NT4>.6
MEPW%`]7KK*P]!PCX0,.P,_&2!^#C"(Y"5KVNP=Y9)0Y8<)3?[S=JNOZ+A+V3
MM!L3$S86")-&XAU^<_Q@QH^FSYJ`6.E">@'RHZ$8)22.#?B^\?2X'ERUJK29
M8,W;DA/FF4[[;/)GO=L7MN[[=5H!(YJ*H4$NBIO-"P$6A3P8@`Z!0\;[BLRD
MM7QL.*Y+5F(VF_44@%_<XHZJ_V7M_-\!0`W2T!0TC4[;\9\>1D:%_"T`Z&?F
M&,1`6T((]#:MRN(_\P\PS$)F'Z.,'OC+`-@8DF$#(DXFDT:TO"/GLH.,S1G,
MZ$,XCE-N7G2KS=`Y`X#B,(",W?V"C5RDCK!@.Q;O1`V9L3E`8_&DW'&YFQCW
M2?QQ5,SML@"(ABA(+V=LQ#Y]WV-3YQB'1`@;PI3(R`@;PA!<A/@/8'PY'1@&
MO[`I5Q(H:];]#>;$`,1LCB%`&`A$B3&+],,P;$KZJ1%D%"-ZI)XZ8,%[`,$.
M.>!A8ZC<73)*C@!4@%CX6)T>]F^P,V1QZV7=M/QN+5_SN$6!W#V9%<B=KGO.
M#P2UH'F_I\OF,#GW+'<4WN83O^1U9II'`;'A8)L9H(@\]EW6#'9_\JF!PTE7
M>D)M9S*">Y$O>:C*(D,7.5GA`H>,[US\+B;R$@`U)^):VM`HG\]GTR![`0SW
M;B+!$9,!('QO'QXIT4<7&P!4OK#+0')$!$5MD%%T+[XHSVH+YA>SC4V=`8[H
M:^8<TY9HN1PPX_B.S2TGOC8;)C(R],G2#=UAW5=5985X1414E3IKHYP6*AZD
M7(4!0V:*;[`]YZ=T;>)[JPFNQ_\/HZL>P.\NHM-5BG+6T@````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,3DN
M<&YG`````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`R-3`R(#$P-3$U-#,S-S4P(#`R-C,P,0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````(````"`(!@```01]2F(````$9T%-00``UMC43U@R````
M&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/```!-1)1$%46,/M
ME_]KU548QS__1/XDA450OY40)$*($4$%]4-14/A#)*0ABI'E-!PYG7J].F^;
M;>H5MW&==^QNMF6N.]P7M^G=)FZYR6IKTX&CF\Z[.\H+&XRGS^M].=?K+`F4
M\(?]\-QSSG/.>3[G/.=YOY_G>F;FY8M^5KWRLBU_\04;'AXT;W9VUIY_[EG[
MZ/UWK;BP(+ML;F[.,IF,Q+O/1O_E'FV92:>MKZ_'O-;F_38Y=DJR;>N6N_MI
M^<!]-O[Q7(.7FZPM7F5//;G4GGEZF65F!BUTJ$3BS<_/VY'ORNQ868F5']QK
M9<$]=K3T@%6&*RQ27?D?/_%P"SA#(M$EQW'QYK/?V]MOO6$X9&AHR+RN\^U6
M41JPT>$.XS8_U!\VO,U-\)976AHRO!7<66"G:W>KOW+%2VHK3QPWKZ$AIFMR
M/:2\)*`K1R/5QIP.@DMQKVN=JSG?PU_S_S&02J6L_](YZ^YLLUCTA(V-].O1
M<1W!=>?/:XHE!%\S;F]O-QG@LL>/';4KEVJL_%"17#EZM=&6+'E".@PD.B,6
M+-YJ+6?+++1OEV6FS\L81N1!WB*X/Z#)@WMVZDV*MFVVPB_62^B#B,"N0LUK
MC;^^YF0D>X^1D5]E+1Z/6UUM5&]$*!*2/&:D*JP6?:RNSAI/-VCMQ,2$/2:O
ML&C`O(GKH\93[MA>H*>Y<*%#+4@'U:G;-ZP^5B/X@730__IKJ[.1"/32J=\4
M>80H8)Z^]8O51J/27^QLLE=7K[1S\7K[:O,&Z[W8K,T$H`PDDTE+W^J3`6B"
MT&5,5-)"`.@CE0%%(F&-P?'Q<6'>2R02-G.S-6O`CW$QLS_F:[1PD-C4GX/U
MG0'"&",>(=S;>41"W'^^[F,!ZO:-F,@+$-$_5;7=-GRVSJK#7TL/30E,Q#1<
MQ9$1@+1OQY8<D!R8T#LP`20,#`P,9($$G,,5AR7<&8YW/$\+UU>$@IH'9#@8
M<(EWX58Z0N-/9X0T4"?D^>0"$NF#4J2IJ5%([.[NOIN?7+)RLI!A%^H1]BR"
MZ='(X@'N&4Q.3BIK(`0[\4J<B[)\>D*/CC`$QXR)?\8D5^B*R@F08(LUQ#WQ
M[^PB(##'1OQ01:"X\]?OXC[2&=F9\:=K/Q0'_)$<TQABP8";AWS:6G]4']!1
M(=$']@C@='M9!Z]BCPOE#L`M(=GTU!5543`;*(8&J0]A,<H$YJD5H82AGULT
MYD!N+;I/UGR@$@VNP2-X`$YF'A[&`WPO5S[Q`Q^Q.'VS2^4$!Q`/3_?H`-R2
M<H-Y#@#9L8XQ!X!Z$4B/"["ON&BC/@B?0<'H8-&B;PKU;'Q3)2*N1T%YDDFU
MV'3RC(7+O]0'&/,$9)F.^+<:,Q<ZL$E]=!S.S:&'KEV??3P#5(^./$#:(T;P
MA*IY#D!@X59.QP=QHQ-'Y]R:EG\.W`PWDSO<'!YX[YTW-<<:BB\^AO#FZ&@9
MNT"%D$7$=$@)3$#["$_@ZN)<0>8G)_**RSE.&#-//E(J\?=B@UHZ5Y_Y:80L
MJ)K-']-7/B(&@`O/@%N88`'B\A2&]%_$-TQN4L[*^XC3N\/3=WOR#P"TG9#*
MJ0=R,'2I9VIJZAX!SRSDD`CP<1BG3S`MU.?/LQ<[KD7@#)[^@7\BF$1<_]_T
M"_OYN@?96<P%C\T!_@;<9P@@AQ/$[P````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO
M=V5A=&AE<F1O=&-O;2\S,G@S,B\R,"YP;F<`````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(R,3,@
M,3`U,34T,S,W-3`@,#(V,C<P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````@````(`@&```!
M!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM
M86=E4F5A9'EQR64\```$'4E$0518P^V7W4^45Q#&]__SJM&;WG"AB1<V36N,
M30P8:VT,K1A4("($95<T0C&42ENMUOB!("S[P>?"=A=?NBSLLJX04@@EP./^
M9CUO,39R86-,Y4UFS]><F3ES9IXS&Y`4V$[V\\N=N^KJ[E$D&E5@<W-3K:'K
MRN?S*A8+K[/[6]X^X7DSBD0B:FMK4Q2A.VYY@P$S!@8&-)TOFCE7VZ[)6WBN
MJN.GU-?77[9S>GI:\7A<DY.32B022J?3&A\?M_F=5?PW#+.SL\*!/3__*L;7
M;G;)9R@6BZJ]4*???G^@4]5UJC[;J(K]7^J'SFZMK:TIL+2T9%[B!'-S<\94
M6,CK2NB&<KF<`HN+BW:DB8D)34U-&<&<3";%YO=PS/<C@/O$)=<[.G6FO4=?
M5-:8%QKOAW7^Q[OZ_%BU&KIN:>^!(TJ5-N!2]I@`-HZ.CEK$U-75ZU)3J_Y(
M>Q8UM>>;K/WZFQIYS](Z=/A$:<^6W06>75Y>E@G`I0@9&1FQ!:*8N50J92X?
M&QNSM:&A(3U^W&MAR+P)P)1L-FOW,SP\;$SA<%B#@X-&]+'.$>F!$A28@`_C
M%G8%_#,@JZ%,)FNI%FSOM"MF#53;GNFO"5A?7[=0?K*RI8K/JDI)W6C]/7OW
M*[RATKTGK"42"75X?0$,B"J"Y/G?6^H/QRR<^1X^?&1MS=EZQ9.>0<OA(Y4V
M#^:9`#HN^O@N7FPU,.=[!5*6$R`+:'K[SCT_W(GBP,K*BFT`<F:\9P96A'4P
M&+(7`3@F%V+1N.;GLK8>B\4L-S8V-LJ0R&8F2"A@&:M()(=?"`"Z.2;)A$-]
M"_`!GG89"2/X[@"0/FL0ICOLSV0R90%D%!K1@F3\X;+09:7+1,9D+()]"W9S
MX=T%[!KP_S4`[&M.%GUJB'OV0L_/YW3Z4DC!/U=MGK:JY8:>#@P9.G5TWM2Y
MWG%=\?XRHE_?%-1;#0`."H6"I3N92D8#?90!*/ON^UK#$-:8SY7FO_JVUBJ!
M<XW->O%J#&P^2*34/[-@51C&,/_IP:-6#8`&P`G(Z)<6=(`3JC%PQD$KPODB
MT6';?/+T!0/TELLAFZ>2`UI!33YX,/3%8M%*DT_V53C,-EAFG8H"XJ"@L$$1
MKPEP##,&`(;@ES.`(BEXM?PT0923[!D=FS!\=X^&JSMO_=1M8^HA#.+#4-X$
MY+M*$Z@W.'=H#,*R`")S!5B*Y1!>81T`!?[M'T#),]P[?.%P&=XA#L*8"L[]
M]8`8<P4\&R`Y7C</8`4#O,`"BG"1LQ:4YTU!,&,\Y`HY^CQ.$/$!L<8>6L;4
M8AP(@I]]R":8S0!^"`JL1\'V)\4]*[3,H<@I=0H=/X2R?YN''Z-0[`I\%XA^
M.C#`&]ROJS*V$T'C"(_M1/"MKJZ^(0="OI\%NTCXT1OP$E8<O)S]V'FM````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S(Q
M+G!N9P`````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,C(R,2`Q,#4Q-30S,S<U,"`P,C8R-S``(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```"`````@"`8```$$?4IB````!&=!34$``-;8U$]8,@``
M`!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P```0C241!5%C#
M[9;?3U17$,?Y?_K8!WTQ3=K$!TVL]J7&UM0836H,Z@.-%1<1J8*5$G5Q#0CK
MP@)9T$5:*F2UBB2B;#5(BC^P!<7P0RU(L!$4(7[E,YMSX59,3.3!F'V8/7O/
MF9G[/7-GOC,9DC+FB_TD$BUB_;VQ+K4;CY1H?&Q4M[N3?G7/Q+=Q[5I2]_IZ
M]5MCC?"5<2`G2\'#A8K7114)E[V#CP45,'WP=[.F)[JT:<,Z6WNZ$W,N8\&`
MVB,!M89S3-HJ\]0:+=#E\XUZMU>\OT)'QU7U]_?KUX:H"4$D$)["7]<;]-6:
M5<K/SM3HR+_Z;-E2M9X[J9F9F53HN1JRXO,E>C(RJ$13RHMY:+UXWJ[HKGGQ
M9+Y=\VS%`2WB+=Y'%L]!K+9<.[=O5$-]B;Y9][6MDZ,MEE1[`KLLC,FVX[IW
M*Z:5*Y:;6!@Q)F%1VO3M:H6*\RR<TJB2[6=UXEBA0C]GJ7!?MGV'^[V=6OKI
M)_82ST%/SQU%@ON5MVVM&D/9.IBUWB19G:NCN]:;\,QY*"_3D.+PQ?/G*0=/
MQ\?MP\7+BU)2^I-.A?:*-$7J@[O55)IKPO=KK@U9W7Q@7R'M0!E4\O_7KAN=
M&AX>MNKFF7SA/T(2^1%,)\V`]*7J6>.Q_9J<F+"T?3)0YZ4SS]&JJCD'>(/L
M+OU1KY&AJT9X9-NK%]V6,+&:2JL-TIUS4IST]QS`R.0^.3[YWS]6#RBQ=R1G
MLW=6=C1?%YI/&P*8QAR0SQRPH@PGX1V#0X7Y]E8Z`X:<#PWTF3'Q,`?`A_HI
ME-K#.ZQH*)[ZHBW&8ZZP.'<KU_,0O)R:,LCGRO=XY#>?YR%!Q_>.\RDF7PR(
M/HW,52.5Z*J12J3$726V5!99T^#%Z5I8)`=I`!\?@/BIL#3=HI(CN:+=)9J"
M>CD65T5IB7$@7,@S.HY#*,2!GK!1WJ.^*COG&2ZYVW7"GCECK0X'/!Y9$``C
M`MRZ]?OO=*;A=&I$&&LS+F448]H"%,+L"%D!#!#%Q<76L+%G2J#[H\,TACUG
M@&+<`+@/`!MP+PJOIGJ-FRO*"FP@A8,9ZP(_9-H9=(IS:="`,E5`14QVT#&Z
M[H7.OCKRBUT&?<#Z(L`-;MV\::S*2^!O1D:8D]GFV=,AFW?@,&8;AF^$_YU_
MMFGMEU\89?,?&N?V\=*`32CH8(<]@(@J`ZVOI4&,A)?OS`#%A(]3^!\!%$YQ
MP/[NS2N-[@&(+F?H.%OTW/[\/:*+'NW0!X#PTQ^X+0P.<],>H/[VJGVI-C#;
M$OB/=$3WVN"&\)^]*S4%)I=K#YE@"_,[<9^(*+E6XOL$KO?:]YP-G?6AZ)Q#
MA#V`-1__\0TQ@+-]#$`+`<36M:(W`#@03!"4'@I,%H\?#IH\''R@X8$Y<<^L
M;Q-GBQ_\X1?_+O1I)DP#</(:[E7S(,*&!LX`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K
M+W=E871H97)D;W1C;VTO,S)X,S(O,C(N<&YG````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,C`V
M(#$P-3$U-#,S-S4P(#`R-C(W-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````(````"`(!@``
M`01]2F(````$9T%-00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!)
M;6%G95)E861Y<<EE/```!!A)1$%46,/ME^]/4V<4Q_FWC/^`B?J&.1),=-FB
MVS28&'4A@01,DY%T,DQG4ZVIM;0#@:X6.S:V&F#C-T@P0:SEAQA,E00C"7%.
M0W#?\3GUWO4*2TSDQ;+TQ>%Y[KVGWW.>\YSS/8<*216E8G^6EY<U,C*BB?&)
MXMNZNCH]??)$C0T-7G7W)YX7Z^OK`F-J:DIK:VM%P-K:6BTM+<EWOO$],'94
M:&UM57U]G;+9K)J:FM3;VZM`(*#%A86BUE"V6WW)L#*M`?T8#RK;&=9OF>^5
MG[VK]S/QX0KI=%JY7$[Y?-Z$8!!(5^'33XYH='34/.<#ISA[YDQ1X?6K5^*8
M)[_\0I%(1'^\>&%K,'BIJ+"QL:&!FU'UIZ[:,7MO7-'M9$2_]W1J%T_Q(;)[
M`.WM[4)J:FJ4R634W'Q!/I]/,S,SFIN?MS"&PV$+'^$D*3P`Z52792$**`+&
M"M#T]+3Z^_LUOP74_(U?>_?LT>R]>_\`;&YNJB>94.7!?;I\H=$DZ&_0^7,G
M3.I/?VYK,M*BFF-'=?3P(76TQ;T>S.=S!M)V+:3PQ:^W"8`.\-6`7^C_QVZA
M#*`*LH]*'MZB19X'!P?E9"AY`L-1S(YX`.!2`*ATLHT49H42R<3JZFH=/WY,
MB43"WD.S'@!2F'R'6]A757UL5CJ[NHP=`*(F`)F]/RN_W^\%@+SA'?(=]H28
M<!W`9M]7QJIX5UU5:0#H>@`"+7[[(=;'QL;TY\N7!H"K+2W?FD=4*15)G#@6
M<7$!"LN/#-6LO2T<]K]TA*S`H&V>*22GF"!#%P`.A\M1=`0"-*YO"[E$V'<S
MKN&>=M$+/`!0Z<10GU4BE?9N)9:6.)+J2`BV+=?"+@&4'?A_.4!U,1E"'%`<
M>Y@H]4/*.C&<"#_PS-0'4\%8<`@,=?UZ3-%HU.40Z(]&#2F!&8O%W+EG1P=0
MA`;ATP/[]]G*X#0W-V<D=>BC2@-E[,0A9Y"";^G^$)8S2_+L8$#RZ.#$RLK*
MOSL`"T*=DY.3*A0*9IPHT!T@?$Z%`1P-A4)V>HS!ICB(+M\QPC?>$QF>&6J)
M$`?8T0'H-?A=P`QA&%E<6+1PXCDKTS<G)I2E\T_MJ<_,`.$F@NC2$\#@JIB#
M8&'X\OFS5?WUYHVV.0`YWAD?<2=[[IL.A&"(\-,/6(D$)X?6R975U56[#D*.
ML[0&C!,Y(DJ.T`IQCO;@,/DV!V@+XP,_:>S7I"M#F;@&NZ.VCO8D3(9OQ>R=
M(\XW6H4C`^FXM0_F-4=N_WS+9C*G$W@<("Q/"X\M3`S@`-"#Z%/.GM[$A/BN
MT+?X_X1!'H=PL-1)Y[?=;1'#)]=V3$*<P#OZ&_=-K^<J'BXN;(4P;V&D(C@%
M>^Z=;PA[WM/S<V_E0>Z^Z9'0W#VXI?=?9L*R`\C?J/GYBQ"-VWH`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\R
M,RYP;F<`````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#$V,#<@,3`U,34T,S,W-3`@,#(V,S`Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G04U!``#6V-1/6#(`
M```9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```#&4E$0518
MP^U72TNR01CU9_0KPG6T<A'UA9O`91`$[2J2"*(BLJ`+&$'X2B5T(5,JK0PJ
MBHHHA:(+"A5A66`7L0B_*,5NY_,\T$4P</7EXET,,O/.G#GSS#/G.6H`:+XW
M3<:!NKHZU-?70Z_70Y/=DK2!G9T=E):68FMK"]DMR3CA^OH:965E:&MK@]/I
M%#JMK:U0%`79(>3"A(J*"K2TM,#C\>!/20DZ.SO1T]/S%1BKU8J#@P.4EY>#
MD9N<G,3,S`QRY13_%V!_?Q\G)R?8V-B0D$U,3&!D9$3ZQ\?'8+2.CHYDSMK:
M6GJ4F#$-#0U86%C`Z.@HFIN;83:;9?'T]#0J*RM14%``D\F$V-\87EY>O@"2
MR20N+BY`!D-#0]+FY^?1U=6%WMY>3$U-X>;F1E*1FUQ=72%'@Z@"Y`+`^/BX
M9.'R\C*\7B^"P2`6%Q?E<=ML-OC]?DEM/G@FWR?`Z^NKI.SL[*QD8U-3$XJ+
MBU%34R-@#H=#FC>EKQ1'1;$@'H]_`3P_/\L;F)N;DQV=J<DNETM$F:#M[29)
M;3+H[N[&\/!P>BH_/C[*@WEZ>L+>WIY0]/E\<+O=N+R\1%%1$0P&`\;&QN0]
MI,7@[>T-L5A,%O!\/#>?*B>2#0'XJ,[/SQ$(!"0V.7R-*L#O-)6`2B"M0UFD
M,(7#851558FVU-;6HJ^O3V20[HK5GIZ1W^BTJJNK8;?;H=/I,#`P(%+*-51'
MZC,+N=%HE'5T!HIBE2*?D0"%[?[^'NOKZT*`P+1V%#CZ94IK1T>'@%)2J9)T
M=O0Q'.OO[T=^?CY65E906%B(S<W-E!2WRYJEI:64XKK$V_P8`?J5W=U=`:"'
M.0V>RJE(A!OQQ-1X2C:=,OT/B:RNKN+P\%`*""-#!TTOQ"@T-C;"8K$@%`J)
M_<EX!>_O[T@D$HA$(L)Z<'!0))V@]*VL$W1F!&9!8>U@.$F$=8+?*?]:K58V
M8=3.SLXD,GEY>=C>WO[\MY!5$C(7[N[N\/#P(,1N;V^EAO**/L;96(>8,]%H
M5'[9Y_WR&C^P./:]G]NO0"6@$OB-]@\E2/A&Z>%#.@````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S
M,G@S,B\R-"YP;F<`````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$V,#(@,3`U,34T,S,W-3`@,#(V
M,C<U`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G04U!``#6
MV-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```#
M%$E$0518P^U72TNJ413U9_0OFD<C!R%!DP;-A"!H9F%$$*F$!CT@"20M"C*P
MM#+*A(RDHM`@T8S`'O2$'DI%2*2A/=9U;>@A&#BZ.7!PT'/\SOKV66?OM9<*
M`(J?0U%P0:O5HKV]'75U=5`4MR5O(10*H;:V%H%``,5M*?C`[>TMZNOKT=W=
MC9F9&0F'WZU6*XI#*(4'&AL;H=?KL;2T)*3T]O9B8&#@FQB;S89H-`JU6@TR
M-SL[BX6%!93**?XOP.[N+HZ/C[&YN2F434]/PVZWR_SP\!!DZ^#@`$='1UA?
M7\]GB1G3T=&!Y>5E3$Y.0J?387!P4#:[W6XT-36AJJH*1J,1R602KZ^OWP"9
M3`:7EY=@!&-C8S*\7B_Z^OI@-ILQ-S<'OL#E<LE+;FYN4*(DE@%*`<#A<$@6
MKJZN(A@,XN3D!#Z?3XI[?'P<^_O[DMHL>";?%\#;VQNVMK;@65R4;.SJZH)*
MI4)+2XN`.9U.&<&<OHH@#@\CG4Y_`V2S6:D!C\<C;W2YG)B?GQ?]6<R!FDQ&
M2>V]Z![Z^_LQ,3&1G\K/S\]2,*E4"I%(1$+<WMZ6T*^OKU%34X.&A@8Y'NLA
MCX/W]W>I+F[@^7ANEBH?9#0$8%%=7%P(!^2FA*^Q#/`WHQQ`.8"\"661PG1U
M=87FYF;1EM;65@P-#8D,4MW8[>D9^1N=ED:C@6-J"DJE$J.CHR*EW$-UI#ZS
MD;>UM<D^.@-ZRW@\CH(!4-@>'Q^QL;$A`4SE@`UZ@P@<_3*EM:>G1T#M.4FE
M2M+9T<=PS6*QH+*R$GZ_']75U:+Q)I-)]JSX5N#.232]S:\,T*^$PV$!X,;3
MTU.,C(Q(('P13TP6V#0,!H/X'VK[VMH:8K&8-!`RPU/2"Y&%SLY.#.<:R/GY
MN=B?@E?P\?&!EY<7)!()B9I44M()2M_*/D%G1F!*.WL'Z63O8)_@[[3P/#UE
MGX;X[.Q,F*FHJ,#.SL[7OX6BDI"Y\/#P@*>G)PGL_OY>>BBOZ'.=@WV(.7-W
M=R>?G/-^>8V?6%S[.2_M*B@'4`[@+\8_NCWX-B:--ID`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O
M=&-O;2\S,G@S,B\R-2YP;F<`````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(R,38@,3`U,34T,S,W
M-3`@,#(V,S`P`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G
M04U!``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQ
MR64\```$($E$0518P^V6?VC4=1C'OTXJA<@_HA()(S#4RB0A_^H'V()84.JL
MG/1[.3I04O/\IR.A#6P=$B<7,L]RM6:K;8&<.MLQC:WIX(:;ZU*466P8[.+2
MH7&XU7AWK^?X;'=NQ*"2D/OCP^?S>3[/]_UYOL_G>=[/XTGR<H<WI6#=MCH=
MO3ABPYO>)WF"I2O*M&K+=BU9&U)Y\/`T,*94N/OU@&9N:M2LL@WR=G;HS@5+
MY,4ORNM(9;6JJJI47U^OIJ8FI5(I!0(!#0X."OGTKOB/%;`61S#/>"EBALUH
M."L<%(E$Y'5>_E.;_7XQXZU=!]JTI^LG!2(M"H?#\J+1J/U:/!Z7S^=3(I&P
M@U@LINOT%]<'P#N2E/=>3+>4O*NB/:?$_ME0LXJ>J+8U,CSDSKS*8_(J]D\X
M8=OY*YK_Z,OFV^+0=V*_[OV=]A'[M2W=FKTRK!=;SFK#P%737=]_Q8+&`'@0
M'@A7$U6X&)<SB*I@,*C2TE*+MO;V=M/AK+^_/PN`$A^-C8V9$K+1T5%39IU,
M)I5.I^T]V?.6[/]'KU``^(<`Y"L9#F]9F&9XBZACO3S4:"'+^?R&GKQ0?ZNR
M-AL'!`["C?M;C#;N+:O(`D!\1W^VL%WQ9+%N_JS-`+AH;K!61??Y)P!6?]YM
MBN3`(UM#E@/$O*_W%]U3_*JMUWP5T^(2OY;YOY;_2-\$`'E0V=AK(0PO<1OF
ML=Y>4RNJ`^OPMQT&#%^QO^W^%[(`Q#7)X9*$I`$4WSC*AL,8@',1,M8&0-*X
MY""A."3[2##D`"%CSN5^$FS\&4EC9M*3`T`!8"9#L8[9G3E&+83ROP10,.#&
M,&!X>%B+OCRAV_?&QP?LE"M[L*93?0._&1>P?W-75$.7TWKZX!FC.QB-:IX>
M^<,*,/K5![JTM*$W#Z/N6$*3#"#%K>?+E'QZ0'@"LD%&5V5](><9;J5G9`UE
MSJP[+N_C+M.%1LV03#MQ:TVK&01]NN_0N>FC;[(Z&2:$-?(,>/CDKUKVPR6;
M%T?/V$4/]%VR\="YM!$Z((M\[YALSFN[M:![2'?L:-5=SU28MQ@8PCRWZ4<S
M8-[IWXW#H>7'OCAH>PR`*/,,J!L:4<6^N$I6E1MG/?]*N2)#5_74ED;SB%O3
M;[*&FJL[$\;MU`(HW,EY/N3PO_N.O@G]JIX+DPV`J@\=/Z7-'S2;`3`OC(OL
MN3="9D!SV_=6&S`,^<+'W[;>%GGW0$HGSB?M?;GTP]V?:,>GK78IYX=[!FS0
M]^)%GI0[Q@W@CQ%0$KB8,H`,%H?5:<38NU*!'I>SIQ)P1B`[73P*XV.L*S4,
M[J!>\<.3>C,.^<@U=P"RI[@!PAZ#6",'!)DK0YRY#A,=<%A3AC@'!^/1HR1-
MR0,`.M!<6>X'#$#='UPK_[N<OQ:GP(0%`QA_`:A8G@DRG3U,`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S(V+G!N9P``````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,C0T,R`Q,#4Q-30S,S<U,"`P,C8S,#,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```"`````@"`8```$$?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F
M='=A<F4`061O8F4@26UA9V5296%D>7')93P```2U241!5%B%W9?+3U-1$,;Y
M8]CR#VC<ZD;=Z$H3WW&!AL0$5VI\)+Z"`15\(+Y0RD/`1U$I"$30`$K1%*02
MJ$1>10K%`NUM@>#(;YIS%=M$HDB"B\.]O??<F6^^F?GFD"(B*3\O_>,H*9?'
MS]^*_>!^D4,ZNGQR,:\BONWTF2Q)3S\H&1F'%G]O?Q*<"(G](!0*23`4D4+'
M"^$^)1`(2&;F83ER])A>$VPDM<EZW=8EZS=LE,GIL&S<M%G.GL_Y@1.,OL_#
MXA^?$BL:TTW.ZA8-9NDN_G[#L/^+E#]Y)5D7<B1AP^#0D!+)IK**Q^)^YY6Y
MN;EX%"VMK5+_JD.FPQ%I?=^O432W]6K(NF%^?EZJ7KBEIV]8K<1B,1D)3,CL
M;$S6K%T7]Y.;FR<G3IX2TG3[;HE<SKNA5%^[GK\,//RQ`:_7*RS@+=D``9-3
M:*MK=&L\Q):=>U,\'H^XW>T)QN(5&`Q*UZ<1>=/NDRLWJH0B#DU.R:>!@'P>
M&A<JE.?4,/1NV;)5%AF`/?."?+@[^S0WC@>-XFKP2%%9@R*+1J,R./)5JIZY
MY-;M.^K(AF)9EGKS?!S0C_#X;7Y.(I&(&J5,R"/&;A:ZU$%:6EIR8N!B9F9&
M85(RYC<(Z*N52>,J-P!9%165TNOS"36R9`-LIGRY4D2D\EQ6_M(-5#YYKEV/
MAI4^;-0^H%AV[]DG-/ZO*4PP0/]2,-NV[U39I+BH0*H4*:$_J,($`ZZ:6E4,
ME&/O_@SM`Z2%RD1>""?[4K$J"&4/-[8!.@]H&,!#,#2MGC_T!K2D*6>:#&3T
M!NAH*JI3#83#TW(H\[@V4G5UM73WC=K-Q$C`"-=H+"[9+&80^DZ?*`R(>MG<
M*5T]?G'6M*AD\B%>(U94A1!DO*.U^P?'E&0Z4@T0$W'2,!CBI;=G0'];"U[H
M4%)*-S(PZ,:Z>O=BT70ZGZJ2FD6<J#RDH4KFGN%HAAN.D[8RFLW5+)`0%F13
MI:N@F59RK4X`M!ISBL7]/P5`MZ`D]#L:5U=7+P/^454<:I[VI21IEF4'0&\,
MCXZI(J&1@?%Q_8USA(?3&0L=H4>0@F4%4%+V2)UU=/=IM&@*"Y$F:IH3S44N
M43J4D&,$H/B.8]+/RO=;`$0)U6@N@H41A`UI0?!<M4T*!#VBH>VU0#\G!H8^
M2@$85/->J5-3=+7`H>DSQ\($`+Q@`^=H:#9THV=$RZ'(LB(JTSCD0(S.DP:T
MC?MPQ%(0Z-RQ4_GV.$/2`(3Z4DM)`4`3!U>*BPBS<PO5R(Y=!\3I=*IAA@M7
MY)Y9P7D6R2?_7\8FQ=W1K_."%+&'_Q#T^0*#L,`Q*#4U51F"95.T-A*B1V01
MWD!P2L$P`CJ[^W4,D`X4'X>5S]ZHLA,MCF$`=6<>H\.PQ!@!0*?/KZW*^0R6
M`$Z`,`*S-@!$NZFI29TSAW!HYA!'3QA@7N&<7%-H'-8Q2JOBU$1,:LQA$)!\
MQU0E73#$.]B@@!?E@ZD!*CU=+^2?Z/G03%6,G<TJ5@,`!13,,94!"AL4+([9
M1QWP+39(%VEF4:`P0-TE;0W&-F<%<RJ'&1:YHR80(PJ*9>[9QSOSGFM!08$N
M[GF//?.O`\!A?45U_X^D^+\'\!T0>'68IU\/T@````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D
M;W1C;VTO,S)X,S(O,C<N<&YG````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-S`U(#$P-3$U-#,S
M-S4P(#`R-C,P-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````(````"`(!@```01]2F(````$
M9T%-00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y
M<<EE/```!5=)1$%46,/5E]]3&U44Q_D#=:9_1!U?G.F#(T^*C#Y4BW:LG5)K
MS5A:P2G4(&E)"1"AT)#0AD)20]K$G0(!&D)2?F;L1)/C?DZ\FRR;4)E.G>G#
M83=W[SWG>WY]SZ5#1#J:1?^L9*=E=.@[V;+&ZZN+R:>2S69E?LFJ+V2?;4JQ
M5)+'Z17W>4?'QLI]2<5'1!?F@I?DEO^V3,XD[=\UZ4AG5^6GP=]T(1:+-9^O
MR6%A7K;79T7^WA>73CZ$QV[*_N&AH.%>\*K$I@:D831?E/6-34E9!=G9>2'`
M_++GLB02BPT3Y7)9]G:>2_F@(.GTLE2KU8:&XZ3QHUI6@.`!L`<D`4POCLKT
M+SV2C`XYFW2#M3PAUMJ61!]E!,!$:34Q9#;4Q'_3)]=N^#7`'YSIE'QI1P*C
M$_4-NWN[&KE\85NCU]<_*8/^B)3V#AH;$JFLJLY8.<EM%.2'OC'=Y&#`Y^UB
M4>.PGK,TN5XW6TK-Y?+Q<6I*Z/.UJ*0?AR2;FI1G3Z;T]Y-$2$KK4QZ%KD"S
MB7@^F+NK@E^S\[^+[^N/A+I"*850K>QZ7:`*,TM!Z>^_KA5#$.Z$HEI!1.]6
M8%:6TJL2"(QHLER)0@CKGR]?:OP)&$+11^-I57"QMU^N^OHT_*3%4TS=GWXB
M$Y-AB2<S>G`X..^D@_209,J4L@59/K_E3A,ERH:9V%,]&`H_U)QR<'1\0<Y^
M-:!/#L]$%MP*7D?>M((3%Y(MM8I4#C):-#0@3WZS_FH%=C'EK'M.)?ZQ'-;?
M"$763#<M*Y%BHA(YP#-P_7/M[H69`6UBI2)[7PL%-86*%>J?,H;U8`!*>>1*
MI](%RIKIHJ'`]@^K6($-*%\JCIQ31#\/#CM(4-8<#P<^D%%`D4S/I;1H*"SJ
MG^*"<B`.W/)0+PH8"30*4X"Z-_V`=:IP_V!?4:'L17'-K0"&X2.T3#-1OEBF
MD:`L%)S]HD<8-72E(3Q'`1^P#)]#?O#`PV1.&\<T%@'E.PAPQ:6`B-.)-`A1
M9_.E[W_5-J8;08$[*&;/Z=/ONQ5$(A'M<381=:S0C;B$.RBD0PDJP?4H(`8<
MA(GP$9]Q!6M,!-"<OS"DBHF+1X$1&`FK^,X8(]K0.(KB\4?"B/N_V_G-RPDV
MU^HM@-"0"!5MWA%MD>/YY^2$9BLV_$2_&L9`H!L&'VM0$$\N6,I?RAJO!G.L
M88RBU-`3DDF-JYC>AR"8AP"QDF.Z9EAG,QO\M^_;`VG+R!A%*6*,FPA@A&N;
M5JA=[MQO;IQ[3^Y>ZU+#`($:H4`FNEZK_A.CVT@QCA%N548)QN@UFI)60>AJ
M>HX>\]^)*=L-^,XI``!RCN@``&#M0'A&BLFU"24,"0/`T^:N`L5@%+:`NQ&^
MWPZ%%03W%T`S00R'`^3H-#D"H)YW#"/D%04_^GJ5/3`('>$QWF(,<.>_N:(L
MP\T1.N,)X\!`7)R9#=R7`-:J'EQHN'7!BQQ$`0P-$S,?8")8&%:",PU/\KZ0
MM!38A6\O.J3,_"`J```\Z>+FWA8`-(>!ORH5%0`,#H_KA,,(QA#6\1"EI`+:
MY#OO1((H\61T<)DC?7P#B)E/+0&`N+?WLISYL$O>>?>4"B$F[PPWR)Z(,*=0
MR%3`<R8%(X?0,PQ,9+C7,><@?H8APG\`]2BT`(#7S#6BP`T3M!CE8H!!$V[>
MF3:LLT8$"#F>F2AQGF(UJ2!J1`P0;0&0`O+,(;SBB1?JI0T&CPDOBE&*IR8U
M1(FT$`4S^G@W5V13F$0#&^V+T+XF8YA"I'(I*@3DY+2[^S/A'DZJD*Z/.W4?
MPA[V4K!T!GO-FI&CWK_&-#27WF9Y2\?Q/_?)_\X04%SD`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\R."YP;F<`````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#,Q,#8@,3`U,34T,S,W-3`@,#(V,S`R`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````@````(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O
M9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```%V$E$0518P[6776Q451#'
M]T$#4<,;)OAH8O#!$$-X,8;PH(D-QI`8-6`QA*A-,+1IL(8/@S0$*F**@50H
M$MA$9(%LC,`&VFI+M:75?@380JEU4P1EL5_KMEC0PL7Q_N8ZU[O=M5^$A[/G
MWG/GS)GYS\Q_SH9$),2X<6-(F/4EMN41:?SVN)2\-5="P[^?DXZ+%Z2CLT?J
M3I_VQ*N^.2NI5$J:6B]Y"\&A/SM6S-3]NG!P_4RYDAR0C\J/>%M0B`X6%BU:
M.$;'WW_(.P6OR<^)F&YW',?[\%?ZN,0K9LC6L@_EE9=?D)&1$4$ULPKT]0]*
MK*9%(M'OI*ZA0TWL'QB4MPL*LLUDT=SVS1YO^`\_-$4D?>%%D;O7].P,@5OG
MGY9#'S\EQ2\]I'BE3CR8*8`']0W?2S@<5F!!ZMTW\SRDSL6>D<7/S5/+\>1\
MYU4IV_:I7+YZ73>$(H<CTMO;IPNXB<L\`R]:0R=/56NL]NP[J1_JF[M4D#6T
M^EZ@!43_U\U<@PV5>S^32>&$\,[R#X2``LO6-4\J',OR9LOEQF>]_+@35RN(
MZ1@%CL(CM\IUXZK\^=+:_+4DD[]*4WM"]G]>K;"1`-UG\C08MV^/2H8%)&_[
M_@6RM_AA18=D`(3T4%IV[8[(TM=7RA='JQ1FE'ZRL^(_!0A]=>R8E):6^A!W
M)I***.]88/`CPV;6"@N+O-.)%="CB(V<\F6L69*_]:L5;"3(.W9%-3S(4@V$
MT'<!GXD\J(-#V>9E.B]>^)AL6ON\9@NIC*4;-FR4GIX>F3B=W8B@=%)AS#5P
M:=+UDFO4GRJ:A@(WQOC)G(C-D51_HSX'78$MLA2TU+PJ/W8G--MJPX]K]9*)
M%.KHF0=$K7$Q82;!LA3<O3.@@B!/95.T9"3"1.)Z[7S]/A94_1GHZQ(&-<#F
M6/2`AHGX4Z;D`.M:#VZZ6QIG6-#;,$=*EL^6Z)%*/RO)N)*2]Y3&(@>WJ57(
M5%=%LQ7<O%8DO^R>H>D)"9.!C/;X3YI`U`.U0)KSKGBAX%);H:)-V4*[MI$Z
MP'1R`2(GC=DX.#2LQ41)^XR#F2=JZK0*K9`04M[Z5Q%UP;-90S&I`F**KP"&
MN2UGN[5@.)&B:FB*JQ64-S+&GARF/0NT.0F_@^QII&B]#/]I'`SZ$_R@[8<?
M)6QW@[$//F.R*;<U%!G!&ZTI!L05-_@`+U*ZA\+Y2F$D$\D%P(1V7^5V#;.E
M<XX"<?SV16Y8VN+:E*N15AO,NBDK&'>X%<IU@DA,6\?D#7`T%8)]F<RGL8)K
MT$NP139(&5,PP-&BQJL@&\(4T,O[Z_*E.UZN!3W:^JC2#4&FFEC#J-CA)1IH
M=`7WM[6U^CP^(0(H(@%H!I``[S`-]PRH"4*@=.<],<L?K'/+8UV;IVL01J.'
MJQ<&3"$$CK9P^`^"03ET9@.O27>44B]4,/6"YWRG.8,.,TXHJXLSD0'>H<05
M1H?)&=02=40Y$!98C#Y,W3&H<`;T0(5#)=O7OZ'[N"E`Y-Q-Z!@8.!:)G-D-
M?&P"4A#@($@,TJ/8[=K!;8$#Z>5\QS"HAD)?LSI?D0-^GD$-KL]"X,^;5S2Q
ML!#OH69B32R!$R7<(#B,@QFP+<3`#/Q\@Z8@4+L',7A&QK@2P]:N*U96XCGC
M`LD@^Q&`@8$5SR!8(U7B;50/W!@!:['..YQIA$LKM([&=PS@NH0<Z]KY@R$@
M-L#(1XB6=_.6M@#4]!,4P/8,ZS4<'+R+F;$@8SF#<W#&ZN*-*LM%G#/\&Q"'
M`J>U"PYF,P>8I\QL!FH\8LT.M)S`:#H+<AAM,LAC-"T;)PDKO.#_V2&Y$+3X
M8I0U1/,:3\V8X,$&,6'#.`8AP`CV\<R,/FZE&,&^C!!`IT!%@MA`D+`PD\VL
MT>K(:MY)5+X#K64[-U?09#8]'&HSNH!^G':8.3",2JFMJE`#N=U1JK`C1(5B
M_L<-I[N\6Z$K1_(:;P3UY.H/T^^&[F%0+9X&_W[>IVZ8>]`=*=-[T?$/BGTA
M3''7"$8`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,CDN<&YG````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`R-C(P(#$P-3$U-#,S-S4P(#`R-C,P,P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M(````"`(!@```01]2F(````$9T%-00``UMC43U@R````&71%6'13;V9T=V%R
M90!!9&]B92!);6%G95)E861Y<<EE/```!2))1$%46,/-E\]/&U<0Q_,G]M9<
MJEYZJ=1#E`.G*H>J51,IR:$E31Q5<026B!-P9.)88&/2#3B.(0:#P1!C`@&+
M&BI^-8D(A.QT/[-^:R^V8U#5'X=AEWWOS<S[SLQWQN=$Y%RCZ)_M]5%YE@C*
MT9]S[M?I_`M96RE*>BSI?CC8GI#IH=LB1U7_>4_'RI(E"Y.#HA\20Q%Y.9^1
M<KDD!V]K1X*7SLM&*27>$4\<I7)4$?GPA_AT8MZRAF4N/Z;NH.Y%+BO)Q&#M
MY/&.Q+HO2NC[+R1R[6LI/+DKQ7Q2;/OXA)OVH<CQ&UWPF?B4U/_Y^,YUT)%F
M#8[77'YY(27EF;A,/^L7-<<&=D<'[LI,SI+%V;2L5]9D;KX@UDC$W;"WMRN@
M55DKZ08$]&]<Z:H#-9,(*/I<<>S>95DK6QJKN@^.@X%O/Y>'W1>DNFQ)>8I`
MV">AMA4#O4W+:[84V]/4&2=SP(&$C*FLICUH-BN3&GW[X%5[#PX/]N3I2$CZ
M0@&)/0HK$@0=V!87BS*>'M<$Z`O^+%/9A/^.8$VF<#`W8<E2:5:?8`W^)"0*
MP9\,`N*MS8H?I+<[)=4>#%R5@?"O,OSXOD3Z;NGFGE]^5'D<[54O7^;ZO:MX
M"O"".Q(.TA)Y</DK#0FQ*Z;#FB:OBT/-"=^4LD[";<P_E,S`=95RIM<-O!ZT
MSQ+&SO)/*SAS(KE@4N.F^%RI-B50:P6UJMU<27I92.5LK8_+WH;E*FH+HH/^
M\;N2+X41*&ZID-0J+^4C-24G%.#VZ^4I3:"!!SW*8:3OZNJRIC(I3"KS/1J^
M)?N[=27ZA[2$-DC33'I$TQIF*"].J@)3#Z3S;Z-Q37F^>0K0B`(6R7=JP8J'
M5`FU,#N;T\-X0FI33(>'[^L*LAE+7<<ZA^&GPF1*"P9O^-\HH59@73_C..C3
M4R@8/$$H'*R98N+NH\D^20T&W-">!)$(C`8O:>$,W>[28H+O(4*JCV@04N7<
MEL7D)$\V?E4/WOGA2ZU*F@35B&(JD7!BJ$UOL#7&]V]^HV6,@FSLIE*985JH
MK@.IVIK&E"[6)Q[=4#ZG[^J]6Z1SRP)1%]D,C2/:9UH7U7_/!_^J`PH-<#3"
M8X1OSIH;X4]ST-D(3<<*EY\@_?>[.0TJ`LT@O$,WK)%FWJ2C03\C(7J&E=NJ
MJA`#%(&AJH5I-Z<10UNLL8=OE.KJ?,QM)!Z9GC*)#"-C&/ZCN5+6""S$+`-K
M\:3DZ>2FAU+NO"/LAQXI?48#IL3&`FQR@$7(AXYNE&,08\R)$!:$!%D9GMVH
M_B[;.]LJO#-*L`>!%7EROK_G)QF.]2JQL;?ME`BM0I7FMM`KQG&*PPCK4&TN
M'=>1`[K%*03.-JS)$_J%84%"G7"0X7\SEO@<8%3D`)!S`"=PP$S(&*!!8!@'
M@-8T#:A;!W+G'<.@A>,(:$+AL'+:BLJ;?7]?]"'P\<.^*H&^.41\&SL5@G*>
MH,*3N',[',;YQAP!12Z#KOZ>[X3Y"QMM'="2<\J'K&<D@L7A4^8IR#B?"DKA
M:4C7:!NL-\YA[(7`$2J"Y*-BGC\)U_BXZHWO[<NP-EILE:+:BXP!YF^$GSK=
M79_I$P=PBL&/KH&3.$CK03!.:!A3ZLW@-+-=#0GJF/:$07H<PKL1&J;I.*#"
MKPE%"^-.`\4!R*E^<ULZ\D`3&3F.P(#%YW?4`8P"/S";F8F;\ZXCL//.C5U&
MK'9DP]/W`.7_'?%^5+:4JD?!I^T)?Z.3F<&W\P#\OV['?P%L)>\B8SNVV0``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O
M;2\S,G@S,B\S,"YP;F<`````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,P,C4@,3`U,34T,S,W-3`@
M,#(V,C<S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G04U!
M``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\
M```%ITE$0518A9V77VP4513&MX:0*`D1,3;AV1>TRIM/8F),C`G*BU%3HSY(
MU,08-6I,2$P?-%C2""J*M"5J43`AK*6VT;8VLA9UQ992Z%+;+K04;-G=L@NU
M=4GJN!SO[PQWF-E9Z&X?3N_.S+WG[W>^<QL1D0@R/S<GK/K04;=2D#=?7">1
M_&R_#`^?E+W[#TEB]*R[/7YXC[1LN5LE8G58T3_;G[U9S^N+;.<*:>WX7=*9
MC(Q/3IMM5^;EK=HULO6-FFMF/3$?7WGY.3ESJD,_%@H%]T/^8I<4]D4DF3PE
M?R;/R:792_+QSE;!>=UPI+M6QG>MDNB'CTCC>P_+]]^\*\V[/I"6EB_#;F("
M#0&W;R3>#Z+_=W2]2&%*%A86@AKFXFLU+7_OKI*>[_8(L0<VC+0LET)GE>1R
M.4T*$7B9&HX])%M>N$WZ!Y,:%MEBX]3T>6EHJ$>-(]W1QS7$3^LW:9BL=6]O
MU#*IB=Z]-?)?XAY)MZ^3A1]OE]S)C9ZC7A040_)=<MTP2TH^*HV-C:%#)150
M+YRFH+A#M4G',QNJ-7\:M3,DE[/[I.Z=S<65<#0@R7^D&:'PZ:]OTN*3$83L
M<)"L^8MQS0,#WA.M]\FQ]Y=I42:G,@KBW_K&)/9K0CJZ^C755AE`">;`:$4!
MR;J0S>KF_=\>5D4<XAW/%!%EGW_5K=@-),2YL%FH>F*;&\:5J"O\!JZST2H!
MNH0<2F(F->+%11W'3C1H,I]_XD[-#87G(%W2UG:P3#B;BMA8%RUC*?$WSI(4
MQ'YX=0D*3#4T1K-.M*V2W,PO^ML?"GD(*2"[``>TQ9JJY9_$@YIU&L6)+Q/U
MQN2$E58+>V`^LA$(0UP`ZNR.Y<HP5&"F=[U^+TZJ5T($S,.KU)[^A</\(-)^
M,"4-<0J2_KE:+7.X?=M=>B@SDY6>V*`J&DA,*@KKZS^30S]UAQ7,C+VF+N/!
MX)%.[Q"P906Z>',^E=&F&A@XZO;"2-]+@G5(J_GUU=H#'&:E#["*)V`"H;G@
M+LC-HR3;!_&N3[R#="!6V4PX-@3>(2BB:GIXZO0..="T2;MQ](N:``'RWC[#
M]TJ()H10.P,.PB"1_DZTW0@F8"=P4A*)E)!Z$PH(Q!.JP=JW^U:Y/%&K.%#:
M"RMPI+?7+4W!R;BM:^K-`3@=Y?;[Y'ALL>GD>!M2?]SKP18:J[@;SR1;`ZBK
M6,$-Q70H8?E1N10I<Z.;%GNAL;@#-D#"'R5H8*^?,BIPP-&F)BI_H2@L/$UQ
MX6IMZ+X[=/#!V723%MTX1='!JY_X.4_KE:IC2:^`'.V)0>@(Q0R(_N9;Y+'[
M5RO6P32_$9R``YA(O&=X<@:GT</XLKU?9@D<O4C06$QHC'#]XP9$4T$Z]`@=
M"O%8YF*FDCTXE<:#6PA"6=V7D>LXX$AV^H!Z#XMC@`E/9+:S<8;W&+57!G@'
MGAD:GE#^@>T@,W@'@3HH"Q.#TA1GHB2ZJ2<3H-@X$6.`:!'_]</>\'@'4W*_
MMI3,,[<LBZW`3,O/GU-@X2&HAH9('Y<DQA)D2,2)XW%5CC'$&H99[76%X<'D
MP1D,^2]6.$Z)<)R].,2W0/1$D/JK1U%-J@$@4=AHJ#4K"A$4$1T&46P-8HS(
M*0EG<9!S.&W/`$S*%G"`=F&R@5P0#YBF$^TZ-S#(`:*T2A'>V>@PCB/^S"`8
MY!UG<985_F!O`(1D0/O_*@ZX_X-D4`\6[%@!$ZQ6Z!9=K^ZA=%Q-`#&@IL0,
M`0"(LXNWH9E93!+P0!90!"@93=P\<8B6M,(S[_G./PH0E-Z%FEP.@-S*9D*N
M\+0-<T^]-?<E'(*(4,C5ADL7_XT0.6#%0;Y;9F3"<X9+>VKP46U%_XVV\EE@
M2L+_:JH$A\PS3$>43S_U@!P_=M`MFS'J[2O2P;PH-1^6/,4PEAYZ4L%4SBVZ
MS!)4)D15#*I*Y7_P:S!3.!(Z^0````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X
M,S(O,S$N<&YG`````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-C8Q(#$P-3$U-#,S-S4P(#`R-C,P
M,0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````(````"`(!@```01]2F(````$9T%-00``UMC4
M3U@R````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/```!4-)
M1$%46,/5E^U/6W44Q_<7&M\87VBR5[Y17RR:Q6A,9MRR:49B7(:"NLUIV1@.
M-MHQV]+"*-`AY:FP7N@##P.[)PAQ:G!S=&>_S_G=>VG+;0&-&E\<"K?W=\[W
M?'_G?,_AD(@<JC;]L;[:+Z/Q\[+].&V?%F;Z9.[6=^),W[0/GJPG93K:+O+'
M0NUYW\=R,27.9*_8!UM9&>P\);,C'2+/'MG7OOGH=2F7!L0_XMN3HG!"GJY)
MC4^^`,J*$U-S)GID#!25W]V3YD1?Z[O2>?*P=)]^0S'/9^,BSY_6P30G`,(7
MM2&:V,X?VX\MP*U<@`<#\F[QEBSE!Z64O2G9VST*T'^AO#@DI;FH+.5B,C_>
M+?FI7ME8O.:]4)')5(<2D^@X+NF>SV4B<5[B5T[L>+B3:%7V27'D:HNLE8;D
MS\U4%9,&(/1>.WM$'BRE-`2>Z](T#YYMB&QO2G":@5;Q/>W-DW?`4++UL%]6
MEX>%NEB<3\K]U3&Y5XS*\]\R31"8/#C(@;N%`2FOC&@!W!X(*2.CX1;)S\9D
M.-)N+Z,VQXH^A)V\*5P^*<+PN?>54KAWQKID)GU%)D=_4&?*1PT"XR`=_D+&
M(ZU2G([(H[5A<48OR[?'7I7(9V])XN(Q10>*XF3(3V7'@:D/<FS_X!4)'7]-
MC7O#V4^=GR@"RF0E%PDH^/J2)9UL2,:OGM3*R*?;[,7KP<I!KG%O^Z<='+B0
M+)F:*W>M#9C5XK*L[W96>]CMVOM+,;\*J0DJ\==RU#IJ2*)A'SFD`KW#6"[3
MJ\U,$>4GNG<YV<G5*"620!DC#T0=#)]1C>PZ\Z8X,S^JO*H25/6#GS>22T2*
MY>="4I;G^F1M(:&?%!&.T%?*FV"U#HQ'5!VX#TI6F"Z>.FSK/WE!#R([V(W0
M"4ML33.9QN`EF@;I)5?4A=_I`1#10*3!Z-CMP+!/Z:)70,9`$OOJJ/9$_[D/
M-0`:07O;=J[C@!O@1=K8.XC>TXD@@@/(I9V#F\D\!"8#@OSI2H;$XM1U&?[^
M8^4E/YO40`UF@Y4SKJRKY6UU@#:0/^D@-"B6)R2--=$@H771<EH9/?]E)6SS
MIE+WU4Q`I%@899C.F>"F^N_UX%\$4+&W!QUPR654&Y3QG=YP<PTZF*#AU-4G
M1)^>W5SMT];#F!Y\(C=\I\./"^>,7OI!!=$+S&%3EM0M`>@B%$:W,-.2A3MQ
M-4^VRLLCPA["V&)!8OKH(&DBIGLH<E8SQ3$2A]1AZ"6&3K"J(2YL1'0P4H`@
M(7L\HVN9H<H*/JL:,!B`&YP#9(TCLE0`9KM""LA2-RXZVZQ!ND:8OU$^%BQ`
M(!NP!`C$:SQZUBI``(B`D9+3CF>4L)O@C.`$))@&,@I)]CKTXU];K4*S76-Z
M<(Y/#`UGMELQ:+B>N?N;H1YZR9Q1A"/^9H4D$%FJ7#%EW&T#,)Z<LT4#"O-F
M`)-)5TYD'&'9/=*\PMM4E-/)-MV3IOHO:%#TD*(JS?3Z$XIIQ7<`08`17,07
M_20X0+Q=BA&@"YD"V&@$P*T!4[5H)SH*U3B$`52=Z480[AGSQ@8`,-Y5`)$V
MK9>']S):1P"@H'64NNM[8S%WZV!]X;).!6_1N]YZ1(UM\<OW7M9/YA>@V")A
M"9!SJ4MZ+5JD)GC1&;2+@'__^]GM0&F8H(^A^--W7M(9QS\"!/>,@0E37!6,
M,'E@B^!.YH9V">)DM2!8E)JKH"M&M"55#`B"#ETZK307,F$M5+J!WV$"%LA8
MVX[`=7?^UV:!-Q[I8_VGLFIM]"UG[YAW"+K/F?`W)IFW^%;;_W`<OP"\DOH[
MIW^PEP````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\S,BYP;F<`````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#(W-#0@,3`U,34T,S,W-3`@,#(V,S`T`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````@````
M(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D
M;V)E($EM86=E4F5A9'EQR64\```%=DE$0518P[6736Q4513'7RFMB%$AT4A"
MHPE^+%@10W0A"UVP46-"W.A6$DS<8-#$:.)*)`11XP*L`DT,V#9HFY;6:86V
MZ-`/.VF`VHKME"@MV(]1J;5U:EJGQ_<[]]W7^YP/!AH7M^V;N>_<<__G__^?
M4T]$/-;,S(SP6Q\D[LGLL1*1A&>^T8?Q#=*Z[P&SO:_S@#[\U;O:?.`N_?'\
MMKODX"L;3=!+S?=I,`)WGWS,;!NNN5VZJNYQCK5K:5IX(SG<JU]F,ID@R3^N
M"G&ES3/A8I[T?'RWS,W-F@VM];ND^IW-^@5G2:,G74<?ELG)\>PT.<)>.SL'
MR7,O5E?\"_ES.B&2N2KI=#H:X4)?N^:0/%`J-;O+Y=OCFZ,;!NK7B=1Y(2!2
MZX6;O([&%V7J9*FY0;+$+']SZM1J:3]]PH0YU_"4+)WP#`[^2E662T_=(\M(
M<K7,V`X9JMXJO[<^(>/)W;*PL!"%&E`*7C/?ZFAZ68K"B;J0JRS-RO3D1UIM
MRC_3L$K32[67B?S3KU5HJ7DNNQ+*@/E/E4AGWRXSL,6<Y4-W^-4*Z>]X.E*,
M,`!5XD2*H2\D`EA_ODUD(,#?#PI0.4$B*@&H)&S2%P:"E0A*4&L"+,WMSTVF
M^;E>W5C]UH.F;G7!JC6UH^#?M>WTMRYF!_CEVEAXKTO?GY(?S^^5V8DW-!-.
M-(4W+YZ)'2J>SDWU[Q97QES+%<XM!;@1B?(&^.;,)UKKB_7W2VHB+KB%>Q7<
M(BM`\Y>O&SOQV8;^T@/;%75TU]VPU:#OLS0>>TTF)Z[E!I$7L9N7GMTH5;O*
MU16O?+A*WGQA@TR=W288&@=E70&E_3KU@W+^R2WKM>Y*)DMCGPLPE.#0W;(P
MD@'.4+EGC2&0];>$PT(_()8\U5(FO>>.9`>`WZ2NS&L+*(P.DB6AF\+&P8;'
MC;O9`"`.2'B0VF^=HP._*VB0(`LP66SRU+_)>/KZ]64PH*OVA%IOV<.MF.(F
M@V3E6AGMWJXECESA\LB@F@GIA5[0%KP87_8#_*[G\XI()9PR+LK7Q[;H*8E]
M:TTF@1H!=NC(0\9^?9[D9")9H#BN@IVA>U`_7_6HEB\]LD.MS+6S2(#>GF:Q
MF;B!.AN?D;&1@V'I.`CP"FK!JA#:XA/\/3HZ<O.VCC9<UMU27RBT:)FLE<0H
M>B.XT7M<2X`ZD-B])9\#X8UNGC<!K();1=UP4?!IBCL\L%\+C/1^JK]#M3G4
MMU,_6Y@[KBQA9G&-GV28(7+5,6=6N`LWN]*^7H/1''":EO?O5</`GM`]TF7Q
MS(#RU7MW:D*HC80&+WRFK8XX)'`3)5A4P:!W/()>B<WQ6]W*$9G;^O@.)1_>
MLTD%B9I/']ID7-U!)&\"4!Z9`S62YV5NJLW:'AKSPCDIM(IX\!P+?-C?BQL@
M8HR<<8++@&;_Q4XIC(!O5,`'C$!+9P@-WA[J&AUV:Z>'A)-(D`27H"W-IO9&
M3#!,`&93'T2/:RC1_-;#HKXZK-N;NX=CT]BUM6R;A$6CT=@W=L:$!F%ILBB'
M;@W1(W;.8C*A7K`:8P5^>F($^H1S<PZV3<=-(&B#-"`\%02(26QWQ,XJ`1K&
MO6`N;(;5E"&<LV+_*8.[7!XX'<"BR53P]_QOA65(.53_U,IOWO``Z='H=.RT
M1'0;OEV-RVH`>@[G_Q7D2RR&!@CHCB0%G9`!,-U9JK6#2+`95E-3R`6\',3B
M;V3'H31-8-<)Q$<%->5K)#D3``'D@FRT$_G#%)XP/?F!#ERT.!VZ@CF)VY,@
MG[4?K9"QV!IM?[P#Y';FT&EO);T`UNI8[(^)6B+_`+@"2CB>?N8GRT'N^.S:
M<:[^L*)N2)-'5L5,T?]+.T92^?[_*W;]"_`*P#(%7L8*`````$E%3D2N0F""
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R
M>#,R+S,S+G!N9P`````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C8U,"`Q,#4Q-30S,S<U,"`P,C8S
M,#$`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```"`````@"`8```$$?4IB````!&=!34$``-;8
MU$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P```4Z
M241!5%C#U9?;;QM5$,;['\(3O"!X0T*\5""!D"I5*N56*B1*(]*B!@AN<.G5
MN35V'"<-CIO:2EP[V<1VG*N;7J.("!1:&G<XOSF[&Z^S=A(0(!XFN][=,_/-
MG&^^.3DB(D<:3?]LK"4DD^B2G:V,?5HI#$IQK%N<NS?M@Z=/1B0_=$[D]U)P
MO>]C>6%,YJ9B8A]L%R05_42*Z8LBSQ_;S[X[_HJL5U/B+_'M:558(<]J$O#)
M"Z"LS"74YK-793)N4-1_<U>:%0,=[TKTH]?E\JDW%7.I&!=Y\:P)IED!$%X$
M0[2QW1\[6Q;@MA/BP8!<K=Z2I?*H@KU[^ZH"]#]87[PEU9FX+#MQS8`J;2Q>
M]SZHR]3X12U,,G)",M>^E%RR2Q+1D[L>9I,=6OW8%V_)Q)73LFIJ_<?F>$,E
M#<!SQUZ5ZV>/RL.E<2E/&PS&<U.:YL'S#9&=30E/,]3JOJ?]Z^0M,"79?C0L
MM>6TP(O%^90\6)N4^PM#\N+77!L$)@\6LF"UDI)[*VFMZ>U41"LR$3NM^YON
M.V\W(YAC71]2[_G\@%XA8>^%#[2DU-Z9O"2%S"69FKBLSK0>`03&`=ZS?6>E
M,AV3QS53S4R/0%[*/_S]<44'BH6IB)_*K@/##W)D.[H_?$T-:E8-HCO13Q4!
M;%B9ZPLA?#-E#9I:(2+9*Q\K,\J93KOQNK!^F&W<W_YI!X<FDBVFYLI>:P,6
ME%RVZGN=!1>[7?M@*:XLI$%I5)BXM3YD';4LHJD^<@@#/0HC03/97MT^2*1=
MUN1D-U>CE$1D,?T*D49[SVCW_W3F;64H\JI*T-`/?MY(+E'A_[V*N2\,2*V4
MU"LDPA'Z"KT)%G1@/*+J3NZ&]@&+NC][0Q?F1[IT(;*#]4=.VL(&FLDT!A_1
M-.1-KJ@+]_0`B&@@4F!T['5@J@]UT:OEV4&UA]51B9]_3^5Z^,(QF1GO48V@
MO6T[-]6`'>!#VIB%-!-Z3R=6<M>DE(MI<55S0YO)/`0F$;\U]O7[+^N06#2M
M_?,/)[0KR\41#=1B-E@Y8\MH8]HZ>[-#\R>=<GY0%<L3DM:::)#0NF@YXH*>
M_[+2:_.&J0=J)B!"%D89IG,FO*G^>SWX%P'4[>Y1#FK)9C0:)>.=[G![#3J<
MH.'4U2=$GY[=7!O0UJ/A,>Z1&][I\&/#6:.;?EA!]`*SV-`2WA*`+D+74!M:
MLN(DU1`0#!GSSB'S17.:FHW90=)&3/=1Y()F2F`F-8$Q`F'H!$<UQ(7NI(.1
M`@0)Z>,90Y@9JE7!9T,#A@-P@[-`U<UDNC";4`GPKF2)(9L,<,#Q&^7SCA!(
M)P,<$(@7#:T*$`(B9*0XVO&,$H+@C*,=]P1#,5%(L@=`-O&-/O..']X1A'5<
M`8&&,]NM&+0\GKGG-U-ZRDO&[">.^,T1DB!DB5QA!$/[`>&DH_H>*><WYLT`
M)I,>.9%QA&7O2/.(MZDH\R.=<J>O4Z:'[<$*/43B$5;(16"F%2H-$`08P45\
M*;<",ER`G!"2$9#I_\H%L-$*@,L!PUJTDR,1I49/J0#!=;J9()`-\^:-9WR+
M`1Z^/+J?4T("`$+K*'6/[ZW%W.7!D]*/FIUWT+O1<52-TR*CABOS"U"47^>X
M`<G@8ULP)@A5T(.`O_\'.=N!TE2"/@;$J7=>"LPYSQB89,Q641$F#]5B]LWE
M^I6DB)/5@G!1:J^"KAC1EK`8``0=Z_E<R\R4AJ@$Y)Y*4`4RUK8C<-.>_[59
MX(U'^EC_J6PX-OKFV#WF&X(><";\C4GF'7P;[7\XCO\$@^GZCS7(H@T`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,S0N<&YG````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`R-S4P(#$P-3$U-#,S-S4P(#`R-C,P,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````(```
M`"`(!@```01]2F(````$9T%-00``UMC43U@R````&71%6'13;V9T=V%R90!!
M9&]B92!);6%G95)E861Y<<EE/```!7I)1$%46,.UETUL5%44Q\>%'RR,(3'J
M4A:Z<<'&CXW+BL:-LE&,B4N+N".8*"M%$PP!0PPV(`B1*-AH:4-)I[5F(@SM
M!)S),)2V3,L`G=+I%"QU,H_.I.GT>'_G];YYCYEIQQ(79S[>N^_><_[G?_[G
MO)"(A+!"H2!\NW^B&R47?D?XUCOC_=MD]N8.&3C9ZBZ_&-TK?^Q;+Y(,N1?\
MIA\\/WA\B[MI^LR+DA_Y3`KQK3+0^9*[+/WC8_+7X2>JQWJV5)31\#,RED[H
MS4JEXMZ8NG55LI$=4AI]5YSL)Y(?:Y?$^6.2G\ZY"WH[/Y;4@:=$>D)2B9I+
M[2&)_?1L=8'?.,*&7>N#-(@+BT5_E7]NQT4J69F?GP_ND$J>U<`!`!L(MPH1
MZ`)^<`$@2N,?BG/C2QE/G!3PU#`C7>_+2/>;,A7[5!&_/=*JOT$PTG_,/>=<
M5XN&IB&:4`EYL./Y*I*$MI3=+.._O"QSX5<5^X6%A2#4@+)BF(T,E)O""735
M5Y/0N9G]$CWZM$1_?D5R'0^K>]._/RJRF-(L])YX.X@C<(#EC4RG1+MWNHBD
M]\J]W&D%_^[=6<E=CTKJ8K?<'.F7F9D)";"X7"[+].1Y?1C6.&,[E36EJ8\\
M8\.)^!%ET=C0]^(XQ?OX:%*,R\#ML2KIFH6?>T,G-LJ2LZ<^F4K.!5V8V+/>
MW<AGE[]Y4O&`%0:,V@TF)R<\D@U?[I6KJ=T:!J=SHIMX]\%(7UOS=#YS:E=S
M::QG_L)9TP:KD:CA!AJCR<I0UX;E(IP5?RBVU@(;<)K*B6';E8['I3R\25%'
M'!`D1=^PE&]_701.YD2X<*W]+:^ZK<%.ZA9/:CP@A9P.PV#BG<0N*60.JON%
MN8Q^0V&H#&.AMB<9ELI_]GTAL=^VRYUS6Z5\Z3U/!#$V\V@\>$#BL6Z/,PH(
MZ8(XZ=[M>CJUX*\#_N>O?*</HT=XX7F`[@`2&G3MU`=>".B3U2BK4]S+1U[7
M[*!EA.(!"%T'OEY7U:YD;3%1#Q.#+9KB`(B9S*B*"5[8:O0JLJ=:B>@=:?43
MS)?&1>G[]CFYWO:(W/OAH4`E\C]U^`7E!3RIRT2\T(HK?JYRAL*R(0_2S,@*
M4N:7L\`&I,9ZPD9@PD87#'G@!RFT!P'>BK5@JQ")@V3VP?]<C;#3-H@UE?-J
M1LO$'F2/IA>"FU5R*PE0!Q+[H[25L5KD#1U`*H@JJ(:+@DZ37$J.!%,=R`X-
M;S2^3:\M%(\H2Z@2O_#C#'VO7A[K>H431,;FD!Y!H+LRGU%MF?WKE-O6^,_$
MP'V>T6HS=(9][,/P@`--(+"H(@'42!B'HX%,/PC-\-FO5)48T^C4B`KKK'$-
MV:,D,(0'^G.=%*)@?BT-.,`-($)P@1#EI@Q4X8Q$,F$ADU8JF;;LQ.5,M^D8
M@>&4=82H29W])K7\]G,DX``7$?!\]I!&>RF\6R44*66TL*:'+FNURBV_C>3:
M^ZP'*1"@"3`.@AI[H_V<Y<DQ<+.(AD#4F(6;PQ5RLR%-`2-::Y`.XW?QUCYO
M#8>!``Z0"G7&#/VHDE:..0,T`G*.D2,@A-6\'0P=?TTF3V]2HP]`KES\C16-
M=1C*C8[27^FS[,G>(-"0A,""Y[8"8+RG[+X68<WV&N^_KW78#L";">5*U.72
MWRN7(>G0^C=S"-`2$:55,^SU-+#E^UJ6YG"Z">7+7KSP0,#[1_6&"L5P1%3T
M,#;B#8Y-<::>#M!MN0_TC+"T,)ZG@7)XTTJH([RI?TI1O37#%$V4L1\H:7%.
MLD7S#+Q$CH,,8MPC=;RE\`R0$P@I]4^T:^H%L-8=&6?=F<(<`+F($K;K->,L
M0TZ]PRCQ>OWA@;HA*D=TS4S1_TL[IFP;O?\U:_\"FCY3/!F%<OP`````245.
M1*Y"8((```````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S
M,G@S,B\S-2YP;F<`````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(T-#4@,3`U,34T,S,W-3`@,#(V
M,S`U`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G04U!``#6
MV-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```$
MMTE$0518P]67;VC5913'%_3"WO2R`A."LEZ(OK`7$KU8$<5$&,+$65H0NII<
MLMF<QE@TYYQ;>M%MKI;MIFTI73?7''?,>W42;0[\,\O:0J,)MJ@NW=:@P5`9
MW_P<>;9[O;][]=ZP\,79\_R>^SSGG.><\_V>9SF2<N+%_M0W[-6%'W[4U-34
MS57?.Q6JV]VLF1UC8[_HZE_WS2XDZ;@X>D4'#W?.[F@[TJ7WMOMO+ER[=ET]
M/2%MVQ=,UG'NVQ%Q?'3L-[5WA1(W/)O[HG;XFW0D%!'S!*/3T].:.^]Q+5J\
M1,^_D*<%BYZV,<E$Z<;7Y>EV.IF9C(P,:VCXHD8NC=IXHJ\OT01>\T/D9+\(
M59(&@M%][+A*ME1I8F(B<4/AFB(M7?Z**FOVB,ASFX0-+'"U^4\M-,G-R]?A
MCHY9'WPG^H6<'7Q`1<7%,S\F^'#AS!-*>\ULQ7.1A+K$_OQKU&(7BGQE[A6L
M7*WR\BK%8C'OBF(#X3HY>$8MP2\M^1Q^K6B#HM%H^E1^?BBH\JVUJO\H8"-A
MW=7XB5R8]Q]H3:^`$&.)`]L^:#1WJ>3B#9M-(;+DF5RE5-#9'M;V^D:[_T^C
ME[7_T$)#3T%EM66?:DCIP<'/NE2V]T/]&1M7(!"P@VM6OZ0MGVX2A>AU^.ZE
M\?]7`+9.G?_."@B!)2@J:H/?XNLAZ3"Y)@NPFZM$YJ5EFZT223&%EE(!102J
ML3QP>LA&K*(`NDQ[!>@)3J1TD6!'CQU&L'[;&#3M:[$RYD"@+6@X``]4(J[?
M5@'U#GM2ONM\[ZJII=5&Y-82]E0`#E`"<7&8K@"@')B(0TH%\"2;V,QAE*U=
M7VJ@8L0KN,SQ:9("D/?H8T\:Z:$(KH<((42:`2,*\I8M]U9`WREJ^MA(F3QW
M=8;UQ]C]>BYWGB$4=`*JE%=H:&A3:V_8&A<-[,JE.2HL7*R=M0\I^GO,6#=M
M$'W=$4U._FW6.01%MS2W*?_59>;5UX.G[PS.6._KG:^A\^=T;\#Y/W=@?'S"
MT`Y@!P9.&6"94U_$V:T10C)/=8#1?^4`_`,VX2/>`-`+'.4$RH%Z$-C#T1$"
MGL'X+K_?G*10,G(`"JK9X;?;.0,HQA%'FGQS:P1C@*KD[3)5556KKJ[&^B'%
M!0XR=@`:.]H3-H9"$<9<JT<<6V.<V]+V.1/_",JZ!E`"#="020$&X1GF&.2;
M.=T?TH()>1[B@'M[9.T`H7?\`Z'!TQC""-\(!.>,\[*#=@D_U.OUCLG(`4)9
M6]]L@F(,8@0',(I#=!S>0]"W8V)8^.5U/HO$K?G.R`%"CQ*,HQ!*A^8LSS=2
MPCH.,<<Y1O;@#"._$ST<S,@!0@_E8YQ0X@BW<S=$6"/4S-VCC;:)<48<0]"#
M#AQ)Q06>7D'>I&#M@2^4M[',%`$KOO/?>-/@A;%5%3>>G($'5;#B$7L`(A0@
M9VD.[`7_O/4@*"\G4K(=I`/.00*OSO6=(6M7*-GZ_DI-3^;H6/<<>T26O/6P
MX9^'9:2W7YN"1^TQD541PF+T1`SBM5-(LX7)*BL6F'%Z9<.>:FNZ1`#"B=^;
M-0JX!1B/5\"_/<XP(2>GCNO;P\=MO.O-"$@-?__-'1/,/=.._P&!JYF8$LU@
M[`````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S,V+G!N9P``````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,C<S-B`Q,#4Q-30S,S<U,"`P,C8S,3$`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```"``
M```@"`8```$$?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`
M061O8F4@26UA9V5296%D>7')93P```5P241!5%C#M9=+:)Q5%,>_/&HV8DM!
M$<'B1JO0K8^%;K2XJ&)UX=J-8`0+@F`HW:BTV`A-$&E*2*6(QA0;HXT#J9EB
M.VD>C`TA;9G0)`3:)B83:C/&C)V!<7*\OW/G3NYDOAG'%!=GOOL][KGG\3__
M<R80D0!975T5KGHCT4!R7UC1-^FN.EF[OEWZ/]EE/Q\?_DQO,I?K[0-?]"?7
M&4CR<(-5.M7_H$@\D.O=33+ZW3/V,V[&3V[WCG6RGA)VS$S']64^G[,O4BMS
M,GJD4206R!_MC;K&QG0Z;3\8Z&N6TQ_O$8D$^I'T!C)Q\BE))A?+S>0(YW:Y
M#5+!+V1DZ(S\F?I5)#\OF4RF5,/$^'F9/;Y#"`#&+7RZ4W)#[1MNSOW0I`82
M';PXLK]1?CZQVWZ`!P1&/XB9\"4"R9X)A$V_1$_9<X;.[A/I-LNH%8X;^_Z)
MC2-P;?WF&S+3\[2LG'M>%F<_*!I:](*@5'6SDF!C37$B+VIK/BVIY.>:[6O?
M/"FI2(/DI_9:!V]'-`OG>O:79P($Y.]^*;.=3=9A$Y5W7WY`<LV!W#Y0)Q=?
MJ9.^5^OU_NB;>\I])$L`#@`K*`P(C[W5()G!0*6CN5[O`<OT^-L"U$IC8%(\
M\N-S]B.'*J.$O.@U:E%&I-?3K>%@RJ3C^N&IEL>M&[T%Z;:Y6SY=+\,#S<73
M2Q3\MG"KZ-?4U7Z92[3*VE*+6L*))-YMC`V>J!W.`S^UU9;&,/$+9TL*\'=+
M"M1'DY7)OEVRO#@DL(7O2F@0@:S2R=]7M)3^FGQ)HPX:2:]:DTKH-;FT$!Y$
MJ@H()XXV2O9PG:9/J]S(G8[']-G:1SNDS`4J#>[*SKZFF\E]MJ5>SA^Z3ZL?
M"`-GKI<-(F=F$N468%KOAXW%PH<ZH!"0B1*X!H5`.GZIJUP!)$#Q*/)B%O\7
MNAY2!:X&4-#V?I-E-Z<`WB%(E&V)`D/^=`7*>&%PF_+6VE>!!I98$?34RLI&
M,(!KZSN/;G"7*Z1$H;!,@5T[ME/F1_=JBDM<("B0R=399^7;`]NL%='"QJC=
MC&+X;JSG$?%9*O#!`=="*/BZN1II%I@/3D*1B!54'*X0/.J>1LA&L$&*H3*?
MSDH4Q,<BQ:;F%+$1URAMESH.(GA5:\%5(=B`)UC/WYK^[[2N1.L5SI;Z0C6A
M92+WHJ/F#XD;O<?/.@!&?"]9$\)_\[RB`5`%7OELB#)XFN224!),Z4$[5`EM
MAF?T-5"B.#4-4J6PGQDB+(^A5L$N>(9RE-$<:/[1]OMU0H)QM/\5Z(HUY$$-
M4-(W+KPH,O*ZW(@<TE[).]8UIT##9PH&"#.K<.#2<<M4\`%4!ZWQS*VYTK5=
M)T?</>^6#^XN26&H`4`>CPDU)4]!%KWM+5""H09(&8J$-E#.FBMDIL\,<?.L
MZ[V'B^NO._:I[BN3PU(]`H:HR"=A1($C>'<X_$04H%BHU:VY<A`I(FH\@]_=
M&LSX)%@T@+``$(J>D.,]U(O@D8;>&5`85Z#HSH,-&B76&.(`B?A8X9YOT4>3
M=?T1H)?0N1OQZ,*@&F+%`!W1_0C$-U&]+W&/O<T>C(=3X5-THML?L<M2`/A@
M+Y#K/,&(S1C02,0\8V*;6H?7`5PT\3J;^;TZ"(F`UK_)%35-\\((&EU)BXE4
MD,+!>,[A".6KN@P'`,#-HWI%AF(XNGNI07-+.NY<?$$5TJ)("X<0&80UTR?O
M:9K,0OI_S$0%G%1J)*$&$`'*!4;3`0HV,YR02K;I+$!I,G1AD/Z_,6''0/X&
M\([4P9;L(>0X`O#\B79+O0#4JA(S)FHYF0/`"E&Z.M%MGQEC&7+")F+`%]8?
M[JD;TN3QKI8I^G]IQWCES[E;D7\`)@^?(LELSQH`````245.1*Y"8((`````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO
M,S)X,S(O,S<N<&YG`````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,S(R(#$P-3$U-#,S-S4P(#`R
M-C,P,0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````(````"`(!@```01]2F(````$9T%-00``
MUMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/```
M!&1)1$%46,/=EW%HU&48QP?^(6'^(_WA/T8$*@2)H:W$5M@00ALTU/Y0*`8U
M$1(*NV3N9L[SJDW'<6C#YM(UMZ5M:5VL>4-J)A<U5\N=S<7<<#4:=6"PU6"P
M\6V?1]YYM^N\79L&_?'L?>_=^S[O\S[/\_T^SR]+4E:\V)_AX6%=[NY55=6Q
MFZNO%>U3976=IG8@?\;F)2XDZ.CI&U#E^[6W=KQ7TZ`W2ORW%L+AL!*..+EQ
MXP]%VCO4=C&BL;&QQ$O6/)&K@\$JG6T.BWF"AM'142VY?ZF6+G](^5NV*GO-
M4UJ=O3;9S+W>[1H?'U>2V;>3A!_GOV@3<NG[SN17M+9%]%VT1Q>_;I?7ZU57
M5S31ANJ3']D3=Q7YDVW8Y?%JR]:7[)G;"E[1DT\_DWC%BD<>4[PD;7!RO6>^
M4KZ"^$WWP8S\D)&?G-0WGE5'5[?Z?ADR(3_(,=;J&T,*!(+)P7;R<F&AFCYI
M5N>5JSIUIL4.F_LF/976`M()=[X=J-3^MRI47%IA\X(='N5M>C&]`K*(S<0B
M</2$*2O>?T@[7MUC&5U46J[JX[6IDZFLK$P\P>/Q&*8V;'Q6>1L7V)ST.'SD
M79N[]Z=T(L`DIJ%02+\/S%/&4;@2[=2LPCCK/)@3!9V7H\8.`!",D0M]?;V:
MF)BX/:2'AH;T9:3#,H\L'/CU-W7W]BO2T6692"10F%(!"<0!%'S[PX^6D2@D
MO#[?`8L,44JIX-.6\ZII:+2#S%'$&,^&*9\0B\4LA2$_*`2>.7J\045>G_DB
MK0+($`4E_D/:^?H^^0X>L9%4SLU=GU[![C??,="`!Q@=`5!@`DFK("__>=L(
MYE'"S5@!N`#5^@V;4S,29/?`@\OT\(J5QNMP/>B$`#G(__G-)?^H8'!PT%!(
MN!SZ0&+^<^L$2HD_3#0]&BDS,1RZ5\BYSXLS1V,PL-T.U]5LFE3P068*6EL*
MU?[5/9HII),61D9&1$+=-3C_YWQRUPR@WH-1&`(!Y-&?^JUN,2+QA=#U"M0X
M&`0L0U7_RH#:DW532A$N=Q?#=PAK,!`7@D:K2).@8738@%`S[I$`#[40Q0A<
M>?5:OY$K/.F\`'-!`5`A+Z9S0Z8S>$8>X#!M'WTG[L>-<"LM`\*%T"6M+!<C
MO!X#YB0'J`!P$5V">QVMQN&J$W8QZ_!V\-B'1KL0(+R%UV9M`&ZG'>$2^!TO
MT)HP]Q3[K9UT'H!UH7%8EQ&O45!G90!*>`W*48QK\0`A<(6&AA>C^,V(!S#:
MU0\J67P;-&,#R'J^!UPIX%6N4#DW8R"&[?67ZT!YP`SBTP;!0XSL0\^ITTV:
ML0'`!/<#'VH3WQ_4J>SL1ZVLYN3D3*TO7KQH2O@_ZXC;AS`G)T!$1B'`=;0?
M\#JUCMXWOMI<:%UHC2-5Y^.FFQ6',]2">!3-*16C\+,S*Z6_LA2L6*62/8_;
M_%SS-MU1*L9]I^L+Q)<.PN70:BQVW0HV#'='#?CYVFI]<^$^^4I?L'#\KZKA
MWS%WEK250P4S`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\S."YP;F<`````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#(S,3,@,3`U,34T,S,W-3`@,#(V,S`R`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````@
M````(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W87)E
M`$%D;V)E($EM86=E4F5A9'EQR64\```$74E$0518P\676VS+<13'EWCP@$@\
M>1$B02(A!$-B$23SL!`SP>).C+@\N!2SDM&YS-#479&-&<;<*INMA"$5E\E8
ML8F-C<5"$Y*-)4NV'#Y'_M6NNK9L/)S^?_W]?[]S/]]S_E$B$N5+^E-?7R_/
M7KX6N]W^<W=5<JH</)XMWA/05T\G_PT_'A55-7+TQ,E?)PYGGI5UF[;]VG`Z
MG>)WQ:#/G[^(ZU&)%-]S25-3D[^0T6,F2(;-+I?SBX2U'X?&QD;IU;N?]!LP
M4*9.2Y3HT6-EV(@Q@6IN-B^1YN9F"5"[+?+[<Z/8)3=N%<OC)Z6!5O#RB;M<
M[MU_)&:S6<K*W/XZ'#MU7DTTI:0%ZK#&9);I<Y:JF;,6KI"QXR?ZBQ@\=*3X
M4L`!@ZHK.DM0*XA?:Q^$Y8>(_&10=NYE*2E[(57OZY3(#W*,O3,7'&*UV@*#
M;=#BI"3)NY(OI<\KY-RE`KV,^Y:OVB@A-2"=<.>.O8<D=?MN2=F:H>M%R];)
MI(0YH1F011PF%M8C6<H,)D@GHUG;,W.")U-Z>KI@@LEDTIJ*C8V527%==$UZ
M[#]P4->&_4&=2&$24X?#(9]J.DG$47CN+FWS4L?G0;LP*'WF5G2@`*DQ<J&R
MJDI:6EK:+NFZNCJY[2K1S",+:SY\E)>OWXBKI$PSD4C`,"@#$H@+,'CP](5F
M)`P)K\62II$A2D$97+U^4[)RSNM%UC#B65A4%#H3/1Z/IC#@!X2`,^!JLMFB
MO@C)`#"$`;1R;:I8,@[HD_3V19&@#-9OWJE%PP4T(._)_X29BY1",I@8-U4+
MB)J'"806%!>,>!^4`6`'O@\:/$1QG75T=+2JSD7>4ZV3ITS[?1[4UM9J%1(N
MH_JHQ/@IXX0J)?X@4>MH!,W$(D=7@0H+4B*O1IMUB5X^G97P@\')R!@XKR?)
MP[O=)=R2#MAH:&@0$NJ?E?-_QY-_I@#]GAH%4D`)BMS]ZHWV+="#M=$(RRNK
MO;,"/0X$H9:!JC]2X%3V:14$4PCA"$$H>`>Q!P(A,''V/"T>BH:G41L`:L0S
M$L7#V`=C"&L-"\%)PPL@%Q``%&(QDQO4&L$C\@"7&?M0`/?C1K"5D0%"((#%
M*,L\@O#IB?-4@7;)`3H`6+3O:*8*0PBC!O_!::8'4--V[*P7=G$Y7OMK!;":
M<00A("E6)J>FZYHYDW$2A?``HTM<_$)%7>`<HJ'^E0*X'FM@#L1#N)@0&(UF
M]88T58K_*(8'4)K>$3]COG8RWS$H;`7(>KX'C%8`,Z-1&6YF#XOI?FF[K*HH
MGS80'N+).?B<R\V3L!6@3%"`R_0FOC_Z].VOO8EA+R8FQKO?LV</+_&>?0C%
M.0=QAYR@(B(*`:YC_`#7Z77,OK[=YHZSFPZ.=)V+>3\[#G?H!;Y5U*Y0#,-K
MEX:(?(L2VYYALFGC*%T7YL\*.^O_2`'<EYNS0/C2@1`.K'H\U=JPW[XM[U@%
MWE4.UQYMV3)7P_%?FE%'T7<8-9:--UR6,P````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M
M+S,R>#,R+S,Y+G!N9P`````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C0V,R`Q,#4Q-30S,S<U,"`P
M,C8S,3$`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```"`````@"`8```$$?4IB````!&=!34$`
M`-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P`
M``3%241!5%C#[9?+;\Q1%,?[%T@D-A82B4C$`@L+L2!!(AIB03R*H/$H;9-)
MQV`HHT8)XQ$FZM%0131-/:*CZ%/:::NC.C68%A-=>$3"I@E)%TUS]',F]V=^
MII4AB&!QS>GYG7ON>7[/D28B:8E'_ZFJKI=+%97BV+HSSO4>/2L^?[&LW.B,
M,WS!L/3V]LJF1R_M]RT=5P/5<N;"%5'&I&DS9?K<Q;)@^09)7[1<TC8[7+*N
M+"#!YA:QKB0>!))T8D_YM4JYV]`B)64WI*>G1^W,=1?&I?Q5=6*$LILZ9:77
M)Z%02#Y^^I1LYI!FIRS@+[XHPPI@7/&E"G4/OVT"W"0Z2]=FB^>@7QX_[9*;
MMVN_Q.'PJ5+]"!-!$[EPN#.NIJXQ*'F-87G]YHTR<37SX(FXAMVM$1D8&)"L
MK"P5($6DJJ:F5K[?S1\Y0S))PXG3%Z2],R)/HU'-GZ?`*RDIR''NT*17U3;)
MR?-ETM`<TGK<F.=1FHCU]?5)D@*J@X/0C3OW9(/3*]=NWM*81YYT2U%IN5;/
MCL)C0EX(,Y9:"LZ%'LN$R5.UDI;E[Y,QX\9K1!<O6:)T5O2U_B(#3=XL"T@#
MEW+:NL3G\\DN_VG-FSM_MZPNO2XE=4&-!9U`Z48B$;L+*#`,_*..$^,2B\6L
MOVF&7Y_&/T<!?4[Q?[<"9[Y7Z"`B3S4":N\_?$BM$C-SMVM!H8`.!RJI2@J'
M&OBF@FA7M]:]N6Q*F:*A.E$T)/!Q:!X0@3+E$M"1[=JKOP\[P@J&*.!@H:T2
MT;JUP*="6,#+U'VH_:$\?_Y"7P?D`6<4X":@;2G`="+.Z[R*ORC$#6`>WNR%
M&<J'IF/I"YL+F8'!#G3D::#6U]Q7S!H]9JRL\9^7:;/FZ8L+O4?4]+GIZ0I?
M-@4T#LW4,=B^",7>OM/4T5C.^@<**(9&UA9$+@*"=.2>.TWJ=\;Q8A4&+`]5
M!&QT4A9H69"43J1E+[=VB-OM5K2MC<84$Z!O=4:53E+0W]]O,8UOYO#-\!+I
MOZB=_RT#:#7F/ZU'NP5;0]JW]#$\L_K\=`-H5?J7/F?6L0PQYU@E`!#^;FEK
M5Q1RY!_0MJ5QOJZX'S+`X",/<)A0@"S>PS>`0R3`#^09OH`/'0T$8&#*!M",
M@-+E*V4"LK,F\!#>HHC5`.6L"AQHO.8Q'L?(Z+.8(B-&F?ND"'T`6>+8M3T.
M[N(%X27'NJ,,3@0>-8J!4SP$&=E9X!$1'B15T!P,1I>1(4KHQ4C`T8PHFP&`
M'!>PF,>YB"$,!;SD,H?PDU\>)27L/_"(G(D&=<!A+F`(<Q$^QF.`V4YL!H!W
M&+#J=K/B/6=&SC;]'3%RE$R9OU0A'AH^T&]HE/(-&?@<Z(ESTBT90P/*8.^0
M!H#LH#I5;$8"WK)KK3AR2EPNEY0TAL0QV'H`-M_(*>DKK`[J+`*PJ2&\Y,!G
MKX:/W+!%&'[U3N<1UK$M,N2X1/XP!&5,"AXI*BK2Z6`V2%H00\`"ED'#9TP9
M/GJ&[0(>QWNF)07G"=3KX*.24<8\+[];IZLI=&4@H+./RH;F+JLMAG%WB_>`
M8H;AL[4F3JTD`PA3;L%^ZW\7)B4,4E)"2%&`-R9_YG@:VG2.DI+$;[MJ6BU^
MRHO9_V'TN\]G856JW"H6P"\`````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O-#`N<&YG````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`R-#4W(#$P-3$U-#,S-S4P(#`R-C,P-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M(````"`(!@```01]2F(````$9T%-00``UMC43U@R````&71%6'13;V9T=V%R
M90!!9&]B92!);6%G95)E861Y<<EE/```!,%)1$%46,/ME]U+DW$4Q_T?NNRN
M("(BJ!N)7B!+*,2+R,JHL,+*DE+8S)*6I65)K3?+I#)Z<;G8$FU32RR8A>M%
M@V7+9F9@+X1!X$5="'7:YXS?4K=JAMU4%[\]>Y[?><[YGK?O^3U)(I(T?.G/
MI\^?Y6I=DT0?E!T]+<'N;K$6'XZ(G:ZL%+O=+@Z'8^3[T5=<]5Y9G6.)Z+AX
MK5[.U[@E.]\F^PX=DZ1ITV=(]N8MXO%XOUOYV=*?ZBL.<7E:Q%YU2<J.GY5`
ML$=\]QY)?F%Q1.I,H%=.MG7(]M`[\;;X]'^6_\D83(R/``#Q^6%'9]3%J`!H
M`4<PEJ[-E5=]?;+-NBL"DNCTO'BEFVS@[H*TE1I*[E5#QO+E,C#P0:/ON]LN
M3X-!Z7[^/**!&'SY\E6*_5VZ^EZ_$6N+7\;/S=]2,#@X*`ZG2SPW;PNU8=V]
M7Q)60+);?7YUM-[;HLZ:>BHJJY`9R2D2HR#0%50A+)XX5R,O>GOU2B@[`UT:
MSO8'G2I3>:%6E6?E[A201C6=.U\MR1F9,F_Q,IDP<9+F8NJLV9HXKLDI:7I-
MS\A2.5)#^T056-U-\O;=>YFY9H/FC!INO=,FJ06[U)4YV5MUWUG7$.L"+PRO
M'Q(.;"P,%[98+#(T-"1_/HU_@0)R3P_2G+0;^4Y8`67K;+BEW4T34URU[AM:
M'_$4C;BQ'S\E]SL"6KY8)__0:HYUKY175$O:RHW:SS$*R"U-@\5+;H\2(%S,
MHF3I#Y2"AE(&I:F1*&QJGR9""75/'\">(*!76,B9/L&E[Q,@;`'M-`M65VW(
ME?[^UUJ-O,@^\%EFGUZ)*H"2EI17R.2IT[07F`#<SYX[7WN`Z_2%Z=I,*:5'
M9%%JJA"O$4',/%&E`:0K<8$7\1/ZY+ZYN5FJ*FNUN6*""#'20`R'DM)2J7L6
MAAX(Z'TH%))-CT/:F4V!I^I6C`($L.!RN;5E@0]7&VLH):!+JAWQZX"I.;IM
M#3>:9R@>+?>7=.._"0"ZV5UR4&N4@A[-W>,.@&J"WVA)I@J-P6QCT:IP`&S#
MR**4QP+HIYOP`7T/1\")&*>AH#D(Q3R#XG@.GT#`\`1S=.*467I$^"T`QFOH
M#X8S3,<YEF<L_D,?$#A,!UD!`%D6ARVB5E!8%#-.XP(@KX32>(>G</-EEU<5
MXBF&.:<0&?:4G\,,B:=0+53S,GRE3@``.#-9F#(,!X[*,0`H*`QQ`$(I2L@U
M"E"$MV9`&.['"'R/8:C*T="HH-"!'#7!/0!PC&<<=4@/'#D"`(6#5P!!&!!<
M20//>9'<FIK`&V3XF@`@H-@C#<@Q<'B'P837@$$75\Y5.!BW!IP/@\KBS!8X
ME?&`$F8(N>0,ML+;JC-FCZU$[R%I]FTVF[8GAS?N\_(LLNV,0^7Y3X=`^AS%
MXM8`@XTS-I]#G-7XYECOZ]"<$:&!CX-2ZKRNGC)N``L`\D[''&AH4V/FG$=:
M,@\>EK+R\E\7(<KQ'/1X[>_IU\,^GFHMA/^SCW$Z!&-\$.$I`-C'./M,GJJ:
M)IV#U$5";<A0S=A1).:3Q)Q66'R>61_W:/%0[42*OB?D1,+(`HQ(7;G:J)%;
MO&Z]%FA"`%#ZHS"9(_3PW/V*.3E&)2+_?QI^`Y[POQ9US4T=`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O
M;2\S,G@S,B\T,2YP;F<`````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(U,#`@,3`U,34T,S,W-3`@
M,#(V,C<R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G04U!
M``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\
M```$TDE$0518P]67^T^2813'^2?]-_S5^8O-+JS4>6FC19F)FVY(L[2LAAH9
MP[Q!")I(B499Y+12>@&=Z]3GZ(,O<IE-6\7V^,#[/L^Y?L_W'!TBXK`O_;.Y
MO2,'!P?2V-AX^-3I=,KP\+"XW>[#!S]^'$C)E3(9\_%UN?]H6D\Y0J&0='5=
ME\ZNFY)*I8Z%3D\?G;#?7X@O2F+EK93)?/KLE0R.!,0W$I1O64NPT\KEI:7U
M^N$I]'B]7KUI=O0F$HE2$W&$?6M[N[H?%?UBY7(Y875W=TO%`UDK)\./IV1T
M;%[<W8^.5:33:8FOI,4J[.M+K._W3<A,^,UQ'%PNEURZ?$5<-]QR]VZO7+W:
M+GZ___B`<2V93$I]?;UD,AD9'1TMC21^LY/(YN;F<C=18X)F#I\J#J>.4S$<
MV:QDMKY)]KLEJ^G/$IQ94H]OW!H4?*@J(!P.:^XBBVORXN6B/'PZ*W?ZGBBP
M//U^30*"WVUL26AJ5DQ:BV!(KG[0&/L#$;W`[[U"0?+YO`1""]+INB=M[5[Q
M>,=4<&MK1SD>H]&H3$Y.JB6@UWPG#0@B1Y9EE<"A1``'3OJ(Z:2&=?1Q+"TM
M5<\"@2+)@4"@6#;7KK4(D$(!(*B9A3.G\=\0@+]?ON[H&GKP4/;W]^74`F*Q
MF.SL[FH-LF"0]LY^:6IJTA36%#`[-Z>T\^[CEU_@22B8$$"%0TT(VMC8*,]"
MH9#7E*%Y*I+0PZ#-T$-F<_N7&P45C$ND$WP4!4065I1/8LMKJI4B<K9XE$;V
M]O;4"MX!<[@'J.-240!FOUG_I%6'('`/A^,S!<2%UHX!Y2+>(0A^+@J@A#T>
MCPP,#"A9@#SPCJGP%(4#NW.)][2.LB`.#0UI\9`%4]X4$:8BC.!1M:08A64"
M.,@RI,$^/CZNO8GL\&EK:U.AID9.IE&+R$2790J'7F#ZFKT2*P()3D`+YAK!
M6,*SHY*NC42"A)\$DM_&!0)GI^NJ`KA,0-F-!30#K/@WR_FO&$!V@0)A8=6B
MBW,Q@"*G%]%>^$Z'@`"HRUVKH+WL]IU[0OLU='0N!N#IZY64*J+GL:^FMV3L
M>4P;IN]^4"`2N""Z_%[K_<*E'JUWR`3DG<3]J0V`C?$&DH&ADNL953(779/G
M4X>4Q[NU#YL2",:5]B`;#/RT^54[.,]OWNHI#B,P6TT#"#/LA5`H<":RK/,A
MH<<(&)[.CG?P+3,IT?!/S`G5C@*F`2("I7(>1YA3X&+XN:&A44FOS`!`A6(4
M,)N08SP)QU/J/53;YWVF7L+-D#R"H5QVSF`HPRSTBY%\-SS.,Z+$]%=Q?D,0
M7,:X#*A0;!^2R.M%9Z_R/89A+!@!%X1[(AC3<RCF',IX1AJ($%CQ^4:DKJY.
MQYVJ&(#O.`!]0^GT`(PCQ*"?G=(#'[`SK`5O0GF`#A8'>-R%S>!6?G/6'OJ:
M\R6#&9?9"9?]OPL$,U#38QB?S#NB9V\3=`448P"*38.C9]4T``]9"`.]>&AF
M4?M".?V+=YS%,'!CGW?I(`"3'3F_58:VB5*C@D#"3F<!V96:"&D@=2R\!9QG
M9D*`AO6P'%ZS^&U:/W],]P8[X`7E9L:NU$-_RP`$H(PPDF>&%SP]R?_D',-(
M&SE'.494(I\_T@U1=C2[.$R4_HMV_!,CT9Q;"_,5O`````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S0R+G!N9P``````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,C0W-R`Q,#4Q-30S,S<U,"`P,C8S,3``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`"`````@"`8```$$?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A
M<F4`061O8F4@26UA9V5296%D>7')93P```31241!5%C#U9=93Y-1$(;[)_D5
MW'"EX08E"B*@`@G$:I%%;2PH:@&70EH(%ME*2@O2HD5`$420K=26$$>?@5,^
MZ!*(&+')X;3?=\ZL[[PSV$3$9EWZ9V5M4_;V]J2XN'C_:7EYN;C=;K';[?L/
M?O[<DR-7,F2,A>?D:=>0GK+Y_7ZIK:V3FMK;$HO%#H4.#1V<L-Z?"$]*)/I!
M,F2^\HY)F]LG[>X!V=B*"W;N)%)2656W?PH]+I=+;YH=O9%(Y*B).,*^NK:6
MVX^L?K$2B82P'`Z'9#T0W]F1YR\&I;MG3.R.KD,5"PL+$HK.RTXRI2^1\J#M
MM0P'WA_&H;Z^7JY<+9/Z!KLT-35+1<5-\7@\AP>,:S,S,U)45"3+R\O2W=U]
M-)+XS4XB2TM+,]U$C0F:.7RB.)PX3F9M;V_+TK<-V8HG9.[35QD8GE*/&^ZT
M"3[D%!`(!#1WXY.STO\V+)VO1J2Q]:4"J_FA1\.'X/G%5?$/CHA):QH,T=AG
M14B/+Z`7^)U,_M"+"*QI>"(W:ES2ZO*JX*JJ6YEX#`:#TM_?KY:`7O.=-"",
M')%Q*QR.".#`<1^Q@-2P#CZVJ:FIW%D@4"39Y_.ER^;Z]4H!4B@`!'FS\,=I
M/!\"\'=]?5V+O^-9I^SN[LJ)!81"(=G<VI+@]"?%`D+(?TE)B:8PKX"1T5&E
MG?DO&^+S1]("J/#7W@FIJ7LHBXN+F5E()I.:,BX/CD<$'@-MAAZ65KY+*I52
MP;A$.L%'6L#X1%3Y)#0]JUIC"RM27GE?:82+6,$[8(X;0!V7T@*HO/=S2UIU
M"`+W<#B'N<R%JEM.<;9[]1V"X.>T`$JXI:5%G$ZGD@7(`^^8"D]1.+`[EWA/
MZ\@(8D='AQ8/63#E31%A*L(('E5+BE&8(8"#+$,:[+V]O=J;R`Z?ZNIJ%6IJ
MY'@:M8A,=%FF<.@%IJ]9*S$KD.`$M&"N$8PE/#LHZ?Q()$CX22#Y;5P@<%:Z
MSBF`RP24W5A06%BH5IS/<OXG!I!=H$!86/GHXDP,@%[H1=XW02UXH$:7H-0H
MPT!X5NXV/A;:KZ&C,S$`3]]%8ZH$I2B$*#Q]86V8[4\'!"+!*/B/>K]TI4EI
MZUJ%0Y%W'/<G-@!&QAM(!H9B1\EH\*/T#>Y3'L]H_]Z!L-(>9(.!T!\=G.>W
M[]Q+#R,P6UX#"#/M'Z&PV/#XM,Z'A!XCF+1:'O4H5<*WA+ZW+ZCL1K6C@-00
M$0SA_.I&7",(%\//%RX6*^EE&`"HL!H%C!*0/)Z@9.;CLE(M8P5>PLV\0[#!
M`6<PE&$6^L5(OG.6:/&,*#']99W?$`27,2XS(*'8.B3!XY?+FI3O393`2/PW
M-DRX.8?BJ]>:51G/6!@`5AZWNZ6@H$#'G9P8@.\X`'U#Z?0`C`,3A)=04WK@
M`W:&M>!-*`_0P>(`C[NP&=S*;\Y:0Y]WOF0PXS([X;+^=X%@!FIZ#..3>4?T
MK&V"JD$Q!J#8-#AZ5EX#\)"%,-"+AV86M2Z4T[]XQUD,`S?6>9<.`C#9D7.J
M,K1,E!H5!!)V.@OIR-9$2`.I8YE1]H^9$*!A/2R'URQ^F];/'].]P0Y*46YF
M[&P]]%0&(`!EA)$\,[S@Z7'^)^<81MK(.<HQ(AOY_)5NB+*#V<5FHO1?M.-?
M>Y:<.DLKK,,`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C
M;VTO,S)X,S(O-#,N<&YG`````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-C0Q(#$P-3$U-#,S-S4P
M(#`R-C,P,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````(````"`(!@```01]2F(````$9T%-
M00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE
M/```!3-)1$%46,/-U^U+UE<8!_#^N;%7#<?8F]9>%7L1Q%IL:U(4C944R#`W
MHU*G[L[25I8IFCBS.T-<)N(]MPR)11FMV0,1$O9P;9_C?NHO=9-8+.'X>SKG
M>OA>W^M[SKTF(M8L'NE?965EM+6UQ<Z=.^?>%@J%:&YNCGW[]LV]>/'B11CS
M2W(V'C]^')9LW[XC=N_>'6L&!@:BIZ<GCM05HE0JS4UK;&Q,LY;8&!T=C:FI
MJ5@2U]'6LW']^O6HJ*A(*X>&AJ*FIB9:3A7G9LW.SD9=75T\>_8L6'GX\&'T
M]O;&U:M7%TR)^]JU:VG2Q,1$Y%S\TYB_>?+D24Q/3\?`I<&E0=;6UJ;`NKJZ
M8MNV\MBS9T_"+4VX??MV"NC1HT<IB]]NW$B!;MJT:0&'0X<.Q^$CWZ51.'HL
MH7;RY,GY"2EW,+I65U<G"X.#@SDD0Q$[.CJB6"RF>%[.(L5@^#@\/+QZ'%:-
M$Y-0/G[\>(!%O)(QSK1WQF=?[$WU4YZ1D9%`DYP!L9\^?3HZ.SNCN[L[UGVP
M/B$!0N/$B1^BH:$ARLO+4ZX7BA<7#$!E9'0\@6_A6V^OC4\_+T]8;]BP8?[=
M>^]_&.O6;XRO*FJC]/-4'D7A5U55I0AT@!"!U=?7%_W]_8E(D,;N6[=N!6HL
M`?'Y\^=I$7H:&8>P[\Z=.RE%?[B];!505B2X#4@Y/WWZ-.[=NY=P$%5&@-=2
MQC?(`,``]_L?T_'3Y2NQ*@,`!!``,>]8ZZF_B'0V#GQS,+%0HP*RI:4EVMO;
M$[@Y`Q!6)NU&%C'.4%;5R!B*$SH^QP,/>,XR#R:C,4.\(I#W%%%ZV)E+87AX
M)"KV5Z8Z\[IUZ];D"><QT3.O'V_Y)#537W$TSO6>7XB`57FO?>?=Q/?-6[Y,
M_,^&=WI!#[A2U)PV4U+\UW&&<&&!]R)I:SL3W]8<3E>84+]<"BJ`^Q99@.OV
M!@;H`WS06;/-S,RD.3D#FH@RFB`TSS8:X.D)Z&<.8#0Y.9GD;0D/6EM;(]LL
M-)6AWB*@QZIE(>/+2AHC/EK`LP5R%IU4%H>^K`&A\R0-X6?"X?[FS9NIS)E.
MK*@'C-@$]()G*9`\&_=B.7]SVOE_"0#SP6&7&Q__)?[^>WT!H(Z#P86!L51D
MI+Y_?V'0K9X?KR3YR>CVR@'H%%L0QC0U-241<.I"`F)`FCRCIFNF0@0#=36*
M=D99[/-LK;G4R%[II+-B`*(GK`SK>0$PH!LYU>+><<JX0#DSW^"4KF97\[%8
MN<K*RF)L;&SE-N#8#D_5Z2@Y5&\.H2)[.SZ']?7U*6,-:B[],2\+E!Y[MA/X
M1H-):-O9P8PW^0"0ZM>)R3APL)"4CU%1<TJC].;&CS:G++V7H3F>!>X>S$ZZ
M@G9,,1]Z1-&V]'WS^>@Z-Q:-3858]A0*<G"5QB<3$H@EXMJ&COBZNC7V[B^D
M^RLCI30G$PR;Q,6A4M)Y<W;L.IBNUMH\.KHO17_Q<EJ#J'?OWHT5I8R`(B+"
M9+""W"+=($/[A?+('M2DS^G..W.IM7M00\IQ,"NI4JZHI9GT*0<F@Y%C@7`B
M6VUFK^4(P1A6<^AY9W.3!,U5/ARQWCPVE./!@P<K=X$@E`,*&<L9XB#[J00I
MP<C.%I2='K47Y^80?UP1,`Y9__(OH54)$6<&B&5N4X0,PUDP4.-00'C!H4SQ
MR?=74<*<<;7#!3#*/.MW-8:6$O@&;O6&'F[@BL!>68JSX[)Z,NB7%G6$@$P7
M!^E0`QWU]AWD^/!OLOR?[FQ.$]E9A18L5_,W;CO^$V>T;N9RL8SR`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\T-"YP;F<`````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#,P,S<@,3`U,34T,S,W-3`@,#(V,S`S`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```@````(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W
M87)E`$%D;V)E($EM86=E4F5A9'EQR64\```%L4E$0518PZV72VQ4913'QX9(
M9*%!$!+6;@Q57+!$$S?"`MGX(#6PL8DD+&RB!'&CB4ILP`<^L)4$:2$A(=12
M.@FT-+900D'&TL*TA;;T81]VINU8TCI-ZK4]?+]S_2[WSMRQ4\+B],[][O<X
MC___?[Y&1"2"S4Q/"T]]B7[\I&`?O+M>(NE[,>GL[)`3IQHE?F?`G=[27"DU
M!POEV/[U[H#?],_7.Y_0]3HP4;]"JJ-7)9%,2M_@J)FV,"-[BM9)Z?N%#X[U
MS'PLV?V&#/1&]>/"PKS[(?U7G3B5$>GI[96NGB&9FIJ2;P]7"\[KA&OU1=)7
MME*JOMDBY9^]*N=.?BI'RKZ4BHICV6YRA`T[VP?)$9>-_I_NET3F1V1N;BZX
MPW3+<YJ6\;(":3A;*<0>F'"[XG&9/_^8I%(I30H1X(M.Z+JT63XO?DIB[3WJ
M'-EBXA\C22DM+64;1^JK7M<0?_BB6,/D^<F^;5HF/:+]S$;Y-_Z\W/FY4.8N
MK)94QS;/42\*BB'I.LD99JBEJZ2\O%SRRA/UPFD*BCM4^]XO!;)CZUK-G^+#
MN26SDR?=><$-'`U(9@]I1BA\XD2!8G!B<E*+3W;V?;A7R)J_&`\\,.`E&3?V
M+].BL(`-KL2ZI>ERFT3K8IIJ4LPW@!+,@=F5#4@6I[+P5'6SUH-%C/%.$=GL
MZ/%Z+68@(<[$1T+5XU\]+0NG(P$#KN0$Z!)R5A+'$UU>7-2Q^^8!3>8[;SZK
MN:'P+(0E-35G\H2SJ8B-==$RAAG9SYLO8=9T[KV'V,!40V,TS_Z:E9(:OZR_
M_:&0AZP-R"ZJ`=I^/;Q._NYX1;/>>/Q%<:XN$_7&Y(3GGV/)D"2:CTP$P@@7
M@(+A*`P5&+ZX2;]G)M4K(0;FT57J#G_1,$"4''=!I'PP)<W2%*7KQ;5Z,HN1
M7I#'P@M--W6CUOB@H@\B-5^J#0%2=XD,'%JN'K1=.^\M`K9V,64E?DC5VOJ[
MRX7;UW<)IR-:/Y8\HX2!1#SA`=C'$Q9C<`3M0MP\2;(\:*G[WEL(`SF5R82#
M%VS&&,9&5$T7C]S]3JI^*E8VHFM^`63<OJ/W/`DAB\Z`@S!()(+B9R+O5IW`
M22@2`0[\)A00B#=4`X]B1U;(;'^1BQ.?G`4DC9CY/>\D7>J:>K,`30<?MG2#
M?4WB)UD(01RO?8W]]H(,CPSI;V1LR6P<Z*D.H&[)&_RO&8825F-CPZ*4?P0.
M.)HW?V>G6!0*2/CE@=_,72SR'`XX2FJB\A>*PB;B;VEQT6HE]/4U>@]`LV&3
M%MTX1='!JU_X60_UPNH8ZA60@YX<B!RQ,0T".+ZV:95B'4SS&\,)-(".Q#C-
MDS4T%_8!WI;[>9;`T8L$Q*)#<P@Z@3Y"+)YP!(8B/&@%1D\E>_9:P!J"4%7W
M922'`XY,CIY6[U%Q>QLE,LMLG&&<0]%9RH3NH#.W.ON5BZ@=2HCN8$@'9:%C
M4)K,3(2BFWK2`:RXV\.)F"AMQ/9PA,W>\!A#*>W]FN^\<\N"-3@=Z&GIF2$%
M%AZ":F2(]'%)HBTAAD3<T=ZBFW,89N\]**N]KM`\Z#PXPT%DR=Z%R(QUG+DX
MQ+=`]$0P-MR@J";5`)!T$@U/9)TG&V)L1'0<R,;V0`XC<DK"6AQD'4[;-=`W
MT$\L7>ALT`O$`Z;1>*WV#0ZDSD1I-\48XT!*8_NO/S,8!S+&6GM;Q`'F9FDP
MAB/@@/L_2*;56BQ0GDR#+3P!*T;IN)J014!-B6D"`-!_)<E-0].SZ"3@@2S`
M!D!):^+FB4/V,"C).^-\3]1ND%1TM:['"33`-I2\E)`K/+2A[^D_%N:^A$,(
MT96CJ_1J0^_DOQ$B!ZPXR'>KC'1XUG!I'VO;JE3TWVB7W@L,-?4_53;!(?..
MTA'EV]M?EO8;[E620[UY&7O0&\+ZP\-W0W,8_0$PY7.+?O3M^+^H,D&U5+L/
M3P0P?;L]SRH`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O-#4N<&YG````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`R,3(T(#$P-3$U-#,S-S4P(#`R-C,P,``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````(```
M`"`(!@```01]2F(````$9T%-00``UMC43U@R````&71%6'13;V9T=V%R90!!
M9&]B92!);6%G95)E861Y<<EE/````^9)1$%46(6EE[N/35$4A^\_@_]!0:V5
M2/0:2I4$$9U"J"0D$D9!,9EX%!0B)C(HS(1D"#(3SY!H%#.%4+#Y]O6=67N?
M?<^]R13[GG7V68_?6GL]]AVEE$9QY9^WKQ^D%\LW\\H;]^XOIC-GSZ7Y6W>W
M-JY>.IVNW%@HY3L=GSXN98X_OW^DT=<OG]/%RW-I]>6KE'Z]2Z,+3U;SU]U[
M]J9.A`4[HD#@"7?'P$<^`(-U\-"1]/CAM?1SX]E8&CC'3Y[*'[$%`^_[]A\8
M,P`"VWR`1@"ZP#!I=<3W;XL9QX?UE?P$UQ;#/\0@=QG((C+8!N2CI:?9@SOS
MY\>1@H'`$.##1T]D<,LKS[,7F6%S8S.MK:WGCX85]PHO^(";A)=SPT3'H/_8
MUW^T]-R,"]LL0HW[+#QUOQDG!1%JA01877C^*^ME`\(F)&$"-G"AHR*B5F2+
M"F`@",2:I#`YV#/$!DD4G0("I$7"SA,ASH1W%?$.;R^A$6#3,]JY8U=^H@2:
M?6AY,-8IX+#1S)%AR?1E#V9<PV]H,H9S+TX!:"B!-@%DLJBE8P[,5`\SUTN=
M#T39).)XX]D/*PBU14[8)7B^?W-[.!,55HA%$L4LK)44L"W[:-7,Y!2@8Q*5
M"()UF(B\)Z!U4SFBZ"E0D&SC25K3'5@(QW;24P!,DH=DXHD"GF0@BLE"$#85
M`,_6"S,6>9)8**(>[%OL%PJ`*V2MVMPL)%RQT%"2QX4*[.LL:(1)99CMD!:3
M)<U^X0(?Z\J#YLD[_EN)K"(/K#HLX@KTL>L+.5A8A[9+05MXG0+\P7<$\=7&
M0DDS2X`,C5M69J>`:-JV;?HP0[,/[5"T1Q0*@!WK'1>`Z#$1`VE[Q;;Z@;-A
MVMI6/YEDT$$5YTYKU3UH"-!4XS:VVHB=(EZL6GL4_A"00:_KYM@"06HZ..D%
M+!I&!,)['.^#`.IP1Z\$84UH+%X#8O.-`.!O@9@:=A60Z2RRW!YCGZ%,;%+Q
M&A&7D9H9`&>'H%TQ-CR>7C>]]K&\?MEVD(V#0`#MB5(!T#B&[+)V&0'8>35,
M%*#A\P[`GG/1V_5$`#00/=9`W>I5ZD73BY<SPV5$V!<T?/Z-Z!V!?5*E3C7'
MA(,*)?!X`S0/!.LP,R(U:(X&V68.P(APO"GR[DAA\:Y7<78[/>5S)$4P7@X=
MALTCB/]I&#T:==]A@2+YI-GW=JJLD\@A.]B("(WE9,@)L8IYISQ-*+SG3-ES
M8AE!@/GOA7WV!ELQQD'M>4.;U2@C.NYK1!Z/"X.1Q_TXP)L`HI>>3U2&!UYJ
MH.$GDWG"HRPRD_:G#J-)PP+A(0^0`71M!)G6?KW^`LWI.=L)O!M;`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S
M,G@S,B\T-BYP;F<`````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(Q-38@,3`U,34T,S,W-3`@,#(V
M,S`V`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G04U!``#6
MV-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```$
M`$E$0518A:67/6L5012&\SNMM?('V`J"8!<0JS16:6(14*L0%$RP4**-5V,A
M)H)74(E&8DAP'?>9N<_NV8][;X+%87=VSL=[/F=V):6TDJGZF7CFQ?[;[?I1
M)9[YP][K23K^=9(^'D[+A[6U]73SQK5T[^[J3+ZOX]W^I_1@?37].=E+*X\>
M/TF(;&V_S&)9X=^S#^G5B\WT^_0TZ*C-'A[L9M,\OT\+E(8!&$@?_3A.V$`M
M=AJ&.[=OI>M7KR1L8HLUR!J&K]^.,F[>-S8VD]\#AH*C^%,-&?`)@!*>M`RU
M%*#.SL^S&<`]W;K?>G'P_F'Z//V2@X%]O,@,@-S9>99=@X%H\\0#O&F\@`$7
MV<"$U&`HBRI_)`9@0*CC!2!A8F,RF<R+0YM;W,1U<B*Q+NZ/Q,E`PF12\9BL
M&Q;>(:+2C6,(-D*4":DC;$3#R$`H0!E*.KFF4@@C0KRC"+]1L/O\34X2^\0`
M`P2K44"IL8%5F!'D*;/?K&S664&L5ZL,)J#:-1!KXA+3-1I$H)MX+!M8JH4G
M"/G6[HVD$3]!`1J"QS<4\(YE8A'YQ^L@]H84<K]$01&<6T2S`3*WD&`B8!:3
M4\(UBJ*2C@*$L09CK$#7%E%6,G.I8QUAF'(OUFOK`T4$4"70L)1K6&R0!8L'
M1:3.VD`)")R;`P4(,"X@%*#,(<@[WQ!N%<PJD?Z&8B]8SC87Y*"G+CH*@(EU
MQRY*()@5=,K;:.48F;G`IG!E5)C*0P#_;6^0D=9.#&"&D2:*Q##T22#QGV`/
MT@@T?(,!`:(=(P]AP'@-"@G8,#N/L8*`5FUG^&RR026JV9%<8%99:6SUA<UD
MP$HUE@SY[4+=Z"PHYT!!I2MC2A;,@\4S@EZ0;/4^M7-D?)9<`D#5.:@<#_,H
MSJ#N'!H"N9#A,:/QLA#'37_M03@/R'SCLS!'@\ZX7%'U/A5%L7@I83^^*\.3
M/L"1/HBEGB.,0CH5@QZP5"?D@>S4\BB,$7$0HZ<+8L'E!$8$,`AY77!4.E.<
M=/W#.\Y@P7A"M,=*-33N;4VO-4@[>2O`.*WEVK:+MPF&(8"]UWBJ.,N]936&
M\=*IBF(,.GI1[/'$'@KYKA%3P]J+O2.]3)ZJ&?/(>K'J`&"0H@1&#/N.<;TV
MO#$M>AO/#&<F(/VF+'O^D@QJ((X]KX,<`WU2N>\:52:2UV;O:UZS%K8AJ&'$
MB&=P_XQ2H?\G\7YNKB'TL`\_>5]Z-3/O(O67@5E`[N(AB2'>,404XBU<XU#\
MLUAZ&DE6MI%HPU9FNT,'HX"SMWU2Q'2`UZ)XAE[Z+/#&*_6],&T`9:\%O5SW
M4H98"W2%D0'46+3\`;"._AN`=6%QM?4Q!!I;T'_"14<Q]`](U.L@@,@C)P``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S`N<&YG````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,C0T-2`Q,#4Q-30S,S<U,"`P,C8R,34`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```"``
M```@"`8```$$?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`
M061O8F4@26UA9V5296%D>7')93P```2W241!5%C#U9=?3--7%,<QV<-\6O;D
M$C-?)HF)P>S/@S$^L,6X:*9H0I0I^K`(4T<(."Q;B'\[1%EL`E7FG'2"##+^
M@Z&P=M6XR4A`1`W@IL-ERK+96$D328@://HYYD)K?RV692X\'.[]W=Y[SKGG
MGN_W'!)$)"%4]$^I\ZA<OGI=QL;&GJYF?;I+BDN^EHD=P\-_R?W@K,F%"!W7
MAX:DNJYI<D=U8XOL/N!XNO#@P4-QM[OEBV]J(W7T7AF07X?^E!O#_TA]2UOX
MAJ7)R^6@HTP:V[S"/,SH^/BXS)WWABQZ>[$D+ULA"Q>]HV.$B;P='XFEV[%D
M8C(P."A]_;_)X+4;.GK/_A1N`J\)(#\0J@@-!*/U!Y_D?F:78#`8OB%M4Z:L
M7+M1]A65")'G-F$;6.!JB0N25-Y;N4;J&AHF??C$=UZ0"UVS)7/;MHD?PWRX
MTC-?8EYSNF*YR(/RL+__<5-N_>W7V+5YSZE[J>O3I:#`+H%`P#JCV$"XSG;U
MR,F:9GU\#J=G9(G?[X_]E#7?U4G!_D-2>LRE(V$][#PA)LP5E96Q%1#BS9DY
M>L#^Y1%UETSF;5"(+%Z2+%$5--5[Y$#ID8G[GZQ)DD>C"9*ZKU!?GVR(Z@'N
MVXY^)7<#(U)>7J6PVY3^ON1_NU-(Q!.-S2_P&?]_!6"KJZ]?$PB!)4@N<H/?
M0O,AXC!OS2L`3@Z1B<SS;/F:B3PQO!15`4D$JK'<V7U11ZRB`+J,>07H"4XD
M=9':!K<>1K`^90S*CI=K&G/`556K.``/6[-MZOJ4"LAWV)/TS<CZ7,J>)!0C
M\FP*6RH`!RB!N#B,,@!EP$0<HBKP^7RZB<T<1MF6[7D**D:\@LO89ZD`Y,'O
M(!)%S"%"")%BP(B"5:O76"N@[F26'5=2AE!:FCQR9_@E>3?Y=44H50M01;V"
MTUDEISH\6KA(E)O77I:TM+?$Z7A5_+<#RKHQ@YAUVBNCH_?4.H>@:&"=LOD#
M]>KGKN[G@S/6S[0GRL6^7ID9<'[A#HR,!!7M`+:S\Q<%+'.$.)LU0@@ODQU@
M]%\Y`/^`3?B(Y@!Z@:.,0#E0#P)[P&7L0<`S&#_L<"@(2)2X'(""B@XZ]';&
M"(IQQ)`FW]P:P1B@RLVQB=U>*,7%15H/22[VQNT`--;J]BA#D=:`R91ZQ+`U
MQKDM99\SH4W0M',`)=``!9DGP"`\PQR#?#.G^D-:D!?M(0Z8WF/:#A!ZPS\0
M&CR-(8SPC9C6PW1VT"[AAWJM^IBX'""4-.F'2H^I8@QB!`<PBD-4'`H&]&V8
M&!:FD2(2S[YW7`Z@`,$X"J%T:$[?^<F3L&YZ)IQC9`_.,%+%B!X=3UP.$'HH
M'^.$DAS@=N:&"&N$FKEIVC"(<48<0W``'8S1N,#2*\B;)]A2\;VLV&%3AX`5
MWRD?;U5X8>S#71N4^%/7O:8-($("<I;BP%[P[W*YE*"LG(C*=I`..`<)=)W;
MF]Q:KE"R?^]Z[3H;ZE[1)C(W>X[BG\;2VW%>\FI;HS:34SH`P5`3,8C71B'%
M%B;;7?"F&M=:65*H19<(0#BA>Z>-`FX!QD,5\&^/?4^B&J;GYDT-U]=[?M1J
M_Y\7(R`UT'_IN0EFQI3CQV$FF;^1$VF0`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W-U;G)I<V4`````````
M`````````````````````````````````````````````````````#`P,#<U
M-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S4P(#`R
M,S,R-@`@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO
M8VLO<W5N<FES92]S=6YR:7-E+G!N9P``````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`U
M,S8@,3`U,34T,S,W-3`@,#(U-C`W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````<````#0@#
M````C5G^F````&!03%1%[+"=_8]U7%0D__GX\,,*_UDT_W-/__0H_,:W_>/:
M_^$6GY*`_SH6D'Y!_^[KOI!Y__\S____````````````````````````````
M````````````````````````````FTQKGP````EP2%ES````2````$@`1LEK
M/@```*1)1$%4&--]D%$2PR`(!4$$,5$,][]L,4D;.YWI^T*7513\3V"ID>\]
MI@7>M39S5">&Q50)2NK6U%D=6EV@,<<R^@6=C1HZT7.L<32K.`P;(=KTGX%,
MPAU[3Y$^7-C<JWZF18:4\[9MN:<=*=J;7!"D^IX"E3)Q`L?6@"Y8$<,+5(Z)
M<QH-[;P3U,BI]_".F1*PQ]-L0F%FQ/1FQZDJLM#7]_WD!6(/$3L-?YH$````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W-U;G)I<V4O
M<W5N<V5T+G!N9P``````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P-3,P(#$P-3$U-#,S
M-S4P(#`R-30S,@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````'@````\(`P```,1DCZX```!@
M4$Q41?[MZOE6&?]A1_]Z)/^#;O\\&VXX(/W-Q?ZTI]6TJ8MC2\4\#+JBF*F+
M?OR6@M*2@O^9,____P``````````````````````````````````````````
M``````````````HRJO\````)<$A9<P```$@```!(`$;):SX```">241!5!C3
ME9!9#L,@#$1MUPN0`O7]+UM#%C5M%2GS`98>,P.`7PINX$;KGN@O-@ED[I1.
MV'BN#F).YDG@A`$)IH>:QX3MJQLP#-&8._1IWN.W&*!P]5I4M=3L/-(@?5R-
M*>LB&%KT&>G`0CM.#%X5\3&$J#D:I!WAQIQUP%<H#I0N#%MWLE%4<+*5+W5S
MC@>)$+=RT.!8K!'=_/-?O0&,`!;R[ATVXP````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]L87)G95]L969T+G!N9P``````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,3<Q-R`Q,#4Q-30S,S<U,"`P,C0U,S4`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@````L````A"`,````X1:%$````!&=!34$``+&.?/M1
MDP```"!C2%)-``!Z)0``@(,``/G_``"`Z0``=3```.I@```ZF```%V^27\5&
M```#`%!,5$4```#_______\`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!(RK<'`````W123E/__P#7R@U!````"7!(67,```L3```+
M$P$`FIP8````*DE$050HSV-@0@`&O&PB2`;";`;";`8HP,-F(()-C#E$N8<H
M?Q%'X@]G`(=K`?G9`IC"`````$E%3D2N0F""````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]L969T+G!N9P``````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3<Q,2`Q,#4Q-30S,S<U,"`P
M,C,S-34`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@````L````+"`,```"><H<4````!&=!34$`
M`+&.?/M1DP```"!C2%)-``!Z)0``@(,``/G_``"`Z0``=3```.I@```ZF```
M%V^27\5&```#`%!,5$4```#_______\`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!(RK<'`````W123E/__P#7R@U!````"7!(67,`
M``L3```+$P$`FIP8````)$E$0508TV-@0@`&=)(!P69`L!F@`,AF0&(CBZ.H
M1S$'E80``"O4`*DU<H&^`````$E%3D2N0F""````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]D;W=N+G!N
M9P``````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3<P-B`Q,#4Q-30S
M,S<U,"`P,C,S-S8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@````L````+"`,```"><H<4````
M!&=!34$``+&.?/M1DP```"!C2%)-``!Z)0``@(,``/G_``"`Z0``=3```.I@
M```ZF```%V^27\5&```#`%!,5$4```#_______\`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!(RK<'`````W123E/__P#7R@U!````
M"7!(67,```L3```+$P$`FIP8````(4E$0508TV-@0@`&,,'`0#R;`09`XC`F
M6`V4B:D7A80``"O4`*F]6)+]`````$E%3D2N0F""````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]L
M87)G95]R:6=H="YP;F<`````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3<Q-R`Q
M,#4Q-30S,S<U,"`P,C0W,C``(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@````L````A"`,````X
M1:%$````!&=!34$``+&.?/M1DP```"!C2%)-``!Z)0``@(,``/G_``"`Z0``
M=3```.I@```ZF```%V^27\5&```#`%!,5$4```#_______\`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!(RK<'`````W123E/__P#7
MR@U!````"7!(67,```L3```+$P$`FIP8````*DE$050HSV-@0@`&O&RB2`9B
MV`QXV0Q00`R;@0@V/G.(<0_1_B*"Q!_.`(=K`?F=BXA]`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B
M;&]C:R]U<"YP;F<`````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,3<Q,2`Q,#4Q-30S,S<U,2`P,C,P-3``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@````L````+
M"`,```"><H<4````!&=!34$``+&.?/M1DP```"!C2%)-``!Z)0``@(,``/G_
M``"`Z0``=3```.I@```ZF```%V^27\5&```#`%!,5$4```#_______\`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!(RK<'`````W12
M3E/__P#7R@U!````"7!(67,```L3```+$P$`FIP8````)$E$05085V-@0@`&
M=)*!`4)!F&`.`Y0)XC#`F$`.NGJBV%```"O4`*FW0N%!`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]B;&]C:R]L87)G95]U<"YP;F<`````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,3<Q-R`Q,#4Q-30S,S<U,2`P,C0R,S``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`"$````+"`,```#&#10-````!&=!34$``+&.?/M1DP```"!C2%)-``!Z)0``
M@(,``/G_``"`Z0``=3```.I@```ZF```%V^27\5&```#`%!,5$4```#_____
M__\`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!(RK<'
M`````W123E/__P#7R@U!````"7!(67,```L3```+$P$`FIP8````*DE$050H
MSV-@(@08T/D,#/A4,,``=A4,J`!=!0,V@%#!@!N0Z`ZZJ<`*`'&M`?DLO@6`
M`````$E%3D2N0F""````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]B;&]C:R]L87)G95]D;W=N+G!N9P``````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,3<R-2`Q,#4Q-30S,S<U,2`P,C0U-3(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```"$````+"`,```#&#10-````!&=!34$``+&.?/M1DP```"!C2%)-
M``!Z)0``@(,``/G_``"`Z0``=3```.I@```ZF```%V^27\5&```#`%!,5$4`
M``#_______\`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!(RK<'`````W123E/__P#7R@U!````"7!(67,```L3```+$P$`FIP8````
M,$E$050HSV-D8B``&)%5_(,QF`9$Q3_<SF2"F_$/AS2*+?^P29/N4H@B)CPA
MAA4``.$H"2)>/2(I`````$E%3D2N0F""````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]R:6=H="YP;F<`````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,3<Q,"`Q,#4Q-30S,S<U,2`P,C,U-#``(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@````L````+"`,```"><H<4````!&=!34$``+&.?/M1DP``
M`"!C2%)-``!Z)0``@(,``/G_``"`Z0``=3```.I@```ZF```%V^27\5&```#
M`%!,5$4```#_______\`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!(RK<'`````W123E/__P#7R@U!````"7!(67,```L3```+$P$`
MFIP8````(TE$0508TV-@0@`&3)(!F<T`9C-``3*;`4T<63V&.4@D!```*]0`
MJ8QTR1(`````245.1*Y"8((`````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S````````````````````
M```````````````````````````````````````````````````P,#`W-34@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<U,2`P,C(R
M,#8`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A
M<G,O;&EN=7@N9VEF````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S-C0P
M(#$P-3$U-#,S-S4Q(#`R-#$Q-@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!'248X.6$\`$<`]P`````````S``!F``"9``#,
M``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS
M`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,
M`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S
M,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,
M,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S
M9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,
M9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`S
MF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,
MF6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\S
MF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,
MS#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PS
MS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,
M_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS
M_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,
M____^+\D````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````(?D$`0``V``L````
M`#P`1P``"/X`L0D<2+"@P8-05AQ<R+"A0X8)`4B<".#`PXL8&[*@R%&BPHP@
M,6[L.''%"HDA4S8D2=%*H),`5,HD&(#E1"M63`+X.%.ES9(P);+HF7+D3Y)$
M0QZUF11DS:5!)4)IBO&I3HHF<T;=2?5B32NL7K9D1=9*QZX/`ZQ@=>U:H)MD
MV;+:BM9A`+`NYTH,9"UGH+`<ZS8,$,C*`;`P_YY<RRJPX(4L<.XLM4*%"BNK
M)BJF^'CAW;DJ_HQ*-6K4'Q4DG+`JY;AS018!5@'*DZIV;56C\I!:]:2UZX$U
M_Y!JEHH9JF;(D:M2Y<3W;VP;\XPBCHI9<N2I5`%R_IO%BM&I4/Y5OYY*5&Z.
M0Y\+W(AGE/'DX47)']5\YV+UZP%4D9ZJV2CY?O@A7"E52.322?A!=P`II%`A
M&H`!DE(*-*NHL%-A``2`WT:!R`+(;'GD404@I9#5EEGVH:1>``&8PLHJI83X
M82FK0-/6-:P<P)&&W=W52BMDK2+D*FS=>,TL*%*4WF.P!5!DD"^R(HN1;>G%
M75<<&AE7D50>F>1$2Z*U$11<=FDFCB2%V=1&A)WI)HX6GH5E36N]>::5<B8%
MFT>!4&E-F55N"1A)/!)EU`I_M6*D-5UN^1<K*&ZE9E%/`?"7G50*NIB.G/5D
M%%B8FOFG6R4IV5,`!]349ZAN6GF5BOXJP;91G:RZ:99)44TJTE.KUGKF6SH%
M56A(`<P*J*]:!A55K+PBZZ8URIH:$INT=JDHLM&6-"V+.SWK;))1#7O1K):V
M^FVIG8KD$0#'WMBNG5]>R9!5U3;J[%LL9;0GKN\ZVQ:^2*E+4;_.6H/O5C%A
ME)`35)"@0K\$^VD--/4IR6)&@9"R'""7/>EO6\^$7+%$)+#@74:EC-:,*GFH
M4$6[-K*Z',L=J95'1M+!5X4*]2)K36DT=U3%<A=9(0IRUOG7'*+^6F,-::G@
M00)'*I!"&D/[Y2$:<<9<-PJ?4_IJS2JEI>(':A.ID(<JY2TD&C-)3V<=W,@5
M:&#$5,)8VOY_>#CAMQ.BC2;*0GXT`_?A25O77REQ`@`JJWK_5]H?@9?6#"JI
ME'*0*,4=;CCBU@5M8*T4FL>,>9(;8PSBJI!B$.>>@TYW=A6O<*V9,;<%32GM
MG5Z:**IW_?G5!?WQ>>*R]S>*A2184>LJ*_2^>O#,"._Y**X/]';LR6>7QQ.`
MW&[G7"2TMSIRJ]/]N>&C:2Z0'^Y5G_3QB-<V8:@&GZ0"_+(ST[GG_@'$0/@G
MO_EUCT&YNU.25&`ZQ*WO>/X9Q4``P;GTP<V"H(L@%4ID)B"))6T$G)MQJG.X
MO1$D9UW#8/^ZQAP5/.%19`E$("+"$2<0\'CBL8XQ4%>0/'"..('S0UH!TS<*
MJ4UM*1*QX2C2A\'29,\@?\!#'OP@']1=AW[FZ=L1EY*:!QVN:\SX#T:J0`4I
M5DYNV!%%B!K'$80YK#VEB5MN5$*%.N*ABI+S@Q9Y<A$I5M$\?Z`"4<CH!#Q$
M$0]]<T)*5.`@ROTA#X*DRM^<X$*9J(!A>*AC@IX3$```.P``````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V9R
M86YC+FIP9P``````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,C8W-"`Q,#4Q
M-30S,S<U,2`P,C0P-S(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````_]C_X``02D9)1@`!`0```0`!``#_VP!#``$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1"``R`#(#
M`2(``A$!`Q$!_\0`'P```04!`0$!`0$```````````$"`P0%!@<("0H+_\0`
MM1```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*Q
MP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA9
M6F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*S
MM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ
M_\0`'P$``P$!`0$!`0$!`0````````$"`P0%!@<("0H+_\0`M1$``@$"!`0#
M!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1
M"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI
M:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZ
MPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1
M`Q$`/P#ZR_X.8-(\7ZU^W#_P3/'PXD^&\_Q#T#X4?M;>(O"V@?%";5+70?%4
M]MJ'P8M]6\/6-YI$R7]GKUYX6E\1W>GWL-GK$5C'I]U=ZAI;Z?%<W-M^0?[,
M7[7'PX\6_M!?`SXU_MQ>!?&_[/G[/GP"\::]_P`(5XWT;2=4^-'[/WQ+_;"M
M=2T/P;81:O\`%?X<>#-5T:UT7X0Z=XDU+7?"UU:Z]=^';KQO)>ZG+X@O8O#9
MT[4_U*_:-_X(W>!?B5XTTCXQ?!C]I/\`:0^&OQA\`Z/K6G_"R?XL?$;6?VJ?
MAMX:?Q!X=U+P_P")8I_"7[1%S\1/$36/C*WOA'X@M$\;3V$,4<;6>F23V\+U
M^G/@OX"^!](_9[\0?LT?"FS\->!_!LWPP\9_#;1[/P[I2P>&O#E]KFFZII]_
MJ(\/:7<1VXGAUK5]0U6ZLIKN%DU*ZGD:X-Z4\W^4N-/$3A7.ZM/'X7"5\3/%
MX*.65*M2,\MSC)L+75>&8..)5+,,!5A6I8B$</#V..E3JK'U:<L+46%JUOZ/
MX<\-.)LGI8B.8UJ&%C@)K,,+3A*EC\!FF*C.D\/2=!5L%C*=2E4I*=:K*MA8
MI1PE.<<12G6C1_%3X&_LR:W_`,%X;/XB_MK?MY?M6_$G]E?_`()F:A\;+']G
M/]E;X$_#[Q-I_P`.I/C!>_\`";6_A#P5XL\=7/BBT\7>!TUW6_BCKGA;0M-N
M]6TGQEJ^J_$6V\1^#]#?PAH?AWPY>:SS?_!37_@W_P#@K_P2:^!VM?MQ?LY6
M&K_M>?!;X0:7<P?%?]E;]K[5-8\4Z-#K7Q"6Y^'/A_X\^%+[X,Z/\/-)U.]^
M'^M^)?"+^(?"?C3PLVG_`/"#V_BW7+'QOH?B.T\-7FA_6W["_P"VA^Q+^S]^
MRG\'?^":/_!9SX7WGP#\5?L,_%U->^`OQ,^)GA'XMR_`3X]:W\$?B!J>N^!?
MC/\`!WX@Z/X>L_M>IZ)=>(V6[\.:GYFAZMH%]!YZWMKK6M>$=$TO^"O?_!<O
MX`_MG_"?4?\`@FK_`,$W-#\;_MD?%K]JE]+\&^.-;^'7A.\T[PKHWP9F)UCX
MC+X-\3^+VTA7\?RZ5IS:?::[J/AC4_A[X,LT\1ZYXJU6"YT2UTV\_HC+<#PY
M@^'*&'RY86AP_'!7A6PN)]A1>'C1O5Q,L;AYT>2JZ<)3K8SVL*MU.=2JG=GX
M7CL7G&(SFM6QGMJF:RQ3YZ=>C[:HJLJJY*"PU:-7F@IRC&EAN2<;.,8P=TG]
MQ?\`!-__`()$?\$>O@/X9^+?_!/J]\%?"#]KO]JKX4^#/A;XH_;&\7?%3X<+
MK?B>YO/C#I=UXE\%OX=N=>T^\TKP1X/GT[2?M7A?PGX`U^XU'0M"ET>_\9:I
MJGB;Q#>:YK-K]D+0?A9_P2<_X*;?M/?L1^!C;_`S_@GC\1/V.++_`(*$^';K
MXI^.["T^&'P:^+_AWXN^$/@'\8[/PEX[\;SQ:EI'@SQ5H_B;X8ZCK&D>,?&.
MK6/AK6]%L_\`A'WTRQ\0/8+C>!O^"]O_``2U^'7[0WQ@G_:,^"WQ8_8;_;$;
MP#\-]#^,:_%#X2Z5XI\7>.-'T#P5=^-O`_AB7QW\!=<^*<7BZYTQ?$5YH/@6
MT\7_`-@>+]:EUC1=+M-$M9IFT;1_Y\?VZO&_P?\`V^/^"A7Q2^,7[6W[!G[4
M7B+QE\<?@XWP(_X)-_LQZGH'C'X7^+?BWJ/PCU^ZT^Y\7_&W3_#?Q`\,_$GP
M!J?BOXA^,=7\2:;<^*-)\->`_!WP/L?%6JZZOB77M)\,ZMK/7C<YP>!PV'KQ
MOF%;'2I_4<+EGL:^)S%RC3DY8.,Z].G7A1PT_K-:JZT80P=.IB'*,(V7-ALN
MKXJM5I-QPM/#1D\36QTITJ.%4>9)5W&G*=.56LO8TX1IRE*O.%*S<FS^Y_\`
MX>,?\$]_^C[OV-?_`!)_X)?_`#<45_GF:+_P9[_\%3-2T?2=1U'Q5^S#X>U"
M_P!-L;V^T#4OB7XBN]1T.\NK6*>ZT>_NM%\#:IH]S>Z9/(]E=7&DZGJ.F33P
M226%]=VK17$A7K\S[_\`E.?^?K^';7S^7T_\#BNWW;_+Y,_6KXG?`C]OS_@E
M[_P4,_8B_9(T?]N^X_:-_90_::;XA7'@[3/VD/`T.I_$70=`^$Z^'?$7Q%\$
M:C\3-%T2_P#$&K^,AX+N96^%FL7'BC3?"?VWS-%U/P=H%G'8SZA^E_P__9Y\
M;>#_`!E\?[KP?\88?A]I/QQ^,7@/XN:+=^%?`YU#Q;X7UNQLO!FD_%+2]:O_
M`!YXH\;^#M>L_BIH?@FP\)V\OAGP%X`_X0W2=2U'6+>+5?&\K>,#]_\`_!7S
M]CSXJ_M._`7P#\1_V:%F?]K?]D3XK:!^T!^S]I2^*/\`A$K#X@SZ?'-X=^*/
MP8UW5[B5=*MM&^+OPOU;Q)X5>75$2S?5'TJQU*_L?#]_KQF_.OX!?M$^"/VW
MOV=9?B!\'?%?BKX<ZAXETOQ#X4U0BQT*/XG?!+XC:<U]H6L:;JN@^(M.\0>'
MO^$H\%^(;6>6TBUK1];\+:\MG;WAM-8T&^V7'\L^,>1U<FS/"8_+,%@\#E&8
M4*>%QU:E@,'*C+&0QWUZ%?&TJ>%DJG.U"$95J=:MB(X7$4ZKJQKRC5_IGPCS
M7#Y[E&/RG,\;C,;G.#EB<3EE&MC\4JCP=;+OJ%3#82=;$J,(T[N<J<'2IT)8
MBA7HN$\/SX;ZX^.WQ1_9A\#>$;FV_::^(OP(\'>!]0O])TJ[MOCIXM\`>&_"
MFH:O*LVL:)I]U!X_OK?1+O4I3I-QJNDVTG^E3)HMU?V\7F6KSQ_BE\0?$O\`
MP1._:,^,$7Q%^'/[?-K^R!\7_AIX!U/X.S?$7]GW]H6W_9(L/$WPPN_%VM^(
MSX*T+5?&NA6/PJ\=^&XO&VI:EXV.L?#6TN;K5-2N-(UK4M;U+1T\/[_N/]FG
M_@G=^QW\!=2UGQ???#6V^+WQG\8:?!%\1?CU\?+V_P#B_P#$[Q]?Q3)=:CJF
MHZIXXO-8TGPY)K=VTE]JFD>`-&\'Z+<M8V$7]F7MQ!8)!]Y^+?A!\&/B7H-I
MH'CCX7?#?QWX;M="OO#.GZ5XI\(>'?$&E6'AR[M5T^XT'2XKK3YX[/2Y;.!+
M-[*S^SV?EJL0MXUB#5^/X/,,ER*NXX3&\454XU*<\;A:N!RVA+VE*,*Z665J
M>91Q=&H^>G%8C%X6;IQI5YTX5%["G];F&4YSC$H8_`9+2DG"K##5X8K&U4J<
M^:ERX^E/`QI3ARJ4GAZ%:$9NI0C5E']Y/QS]D;]EK]F#]F[P$;K]F7P_HDVG
M_$RST?Q1X@^+,7B>\^(WC;XT/=QW5]I?C'Q=\6-8U#7==^(2WT>M7^HZ-,VN
M7.AV%KK<T?A>STW1I!91^&_\%(?A?\2(_"OPI_;/_9VTRXU#]J']@CQI>_'7
MX8:9#J5Y;0^/?A\]C:P_M#?!J;1K71_$5OKDWQ=^%6F7GAO2]-AT^UUJ'Q*F
MC_V'XCT%I+J.]^[/AM\,OAW\&_!FC_#OX3^"?#'P]^'_`(=_M`:'X,\&:1;:
M)X8T:._U"[U*ZBTW1;..WM]/@N=2U&[N]MND<4;WC"V2)H_*7\POBD?B1_P5
MU\<W?[$W[+4/B#2?V,]-\8)HW[<_[;%M9:EI_@;Q%X,\+ZFT/CK]E7]G77+[
MP^=(^(_Q'\;7GDZ+XK\=^$_$%YHGPRT6TU2'Q#::HFNZ3INI^IP#A>(\^X]P
M./R*MC,5B<)F-/&XG-,?)\]'+8U%1JSS":JSBW6P4IX9X2G6FZRE.A1YJ:E*
M/C\68C)<IX3Q6%S:EAZ%'%8.IAZ.7X.*2J8V4(U8QPL7"/+[+%QA7]M4@G3N
MJU1^U:YOU^^&O_!7W]C3XH_#GP!\3-#F_:!LM$^(O@KPKXZT>SOOV5?VB=0O
MK32_%VA6'B#3[:\O_"OPW\2>%[VZ@M-0ABN+OPWXBU_0;F9'FT?6M5T][>^G
M*^UOAI^SK\%/A)\./A_\*?!'PV\(Z?X,^&7@GPI\/?"-A<>'](O;BR\,>"]"
ML/#>@6D]Y/9-/=S6VE:;:0RW,S&6=T:60EW)HK^\/9R_Y_UONH>7_3CU^_R/
MY2YU_P`^Z?WU?+_I[Y/[_(_F4\#_`/!?#]O7X.W=Y)^V-^PU\*OB9X,TS6VN
MM=\:_L<?$+Q3I7C#2_!$?A9[JZO_``]\$_B_#K,OC_4=,\2Z??173P?%?PI-
MJ&FW]G9^']`U>]TYKS6/RC_X*5?'+7?CW_P5=_9]\>?\$(T\":GXC^)?[.WA
M7XR?M*_%3X8V6M:7\-?B%K/Q/\0^,M6T\?M>Z=<QV_@:2^\)>#4L[HMXET.'
MXI:-XO\`%VH>$;B7_A8GA_P_H.@_T5^+?V*](U7P8/$<`A>Z:SAU-K*8&YV;
MYI@LL4307=O+NM+A;ZYO;EH91;YMWBL#%/<2_@#\./B!X6_X)2_\%$_BQX>N
M_@#\1?''P._;"^&'A;XR>*?$GPC^'VL^+]3^$'B7X1ZOXB\-^,-9'AWP]\WB
M?P5<2>--&\2_$2XLM.?Q#I-_XFT*\M],UY]7C_M#YOC%8V/#>:5,MRFAGV/A
MAI+#97BZ<:U#%<_)"LJE&<HK%*%%U<1'"M_[35ITJ5-JIR-^_P`*SP?]O9<L
M=F6*RC!O$)U\PP51T<3AW!.=%T:R7^S\]:-.E+$VFL/3G4K2C.,91/3OC5^T
MU_P6%_82^!Y^/O[3?@/]B/XM?";P%9:'K?Q1U;PGXE^)?@/QY<7/BGQ7#X9L
MOAQX?0Z5?Z%#XEMM9U;3-(L?$,7@_6-%^RI]JU6WD<O?3?0G[4G_``5G^+W[
M&_[._P#PT1XY_80^(-MX4UC6/#FD>%M1\5_M0_L>IX5\6>(?$\PDETO1M3^%
M/QG^-/CCQ%J<&BV.J:Y)8^&_AMKM]96FEMJ.N'PYH+:IJ<?P%_P6U_X*=?L;
M_M"?LK_`#X=_!#XZ^'/&VA^*OVK/#>H?&7P?)'XY\+7^G?#7X0Z=XHDUKP]\
M6OA#J.BZ-\2X=#O/'UUX-U31-'\3^!AH^N:EX2AO].$DFGVFI6/R_P#\$CO@
M!H/[0GP?_:%^&GQ9\%:5\8?V+7^*]KJ?[/\`9>.;+Q'%8:3XBU/1-9G\<S?#
M*WUJPTCQCX/L[2/7=,T^+Q9H$VE7"ZG)XGNM/>YF;Q;<3?D/!'AUD_%.21S7
MBWAF&6YD\RQ]-8'"T\?DD7AJ-2E"-/%X*->,J$EB(8FG^YIX=JBZ48I.*F_T
MWB_Q"SG*,QGE.0<0ULPRQ8+!OZUC)8#.*BKN$I2JX7'2P\IR;I.C*7/6K.59
M5G*;C)1C]R^$/VZO@-^V):^)=5_;[_X*1R)^SE>:QJNO6G[$_P"P%^RU^VC>
MZY\5="@US3+S3_@O\3?VNY/@?X1U'5-.8:9>^$-;TSX8W/@*7QU_PD=QXAU7
MQYX&T>$:#8_N9\$?^"XW_!,;X">"?AK\%])^!'[7_P"R#\#_``OX=N_#GPZF
M\;?L/?&SPW\-=+L/#-J;F30]*3P9X>\:>(-3U:ZEE>:[N+?1-4OM1UF]FU#7
MK]K_`%">\G_(/]GKQWX@_9!_:&\%_P#!/;XF:S)XG^&/C'P!KGBK]C?XHZLZ
M6WB*^T7P3+!_PDG[.WBM+:"YBU;Q+\//#SOKGASQK=_V?'J_A"&PT[4OMOB1
MHHIOV=\$^'+74W@\X6\C*Z;G8Q)&9/M+I%']MD6*VMXTDW&:ZDG4E58Q3&WB
M6:W_`'+*,DRG(<(L%D^78/+L.FI2IX2A&DISY8Q=2JXVG6K2A&,95JTIU)*,
M.:4E%'X_F&9YAFM=XG,L9B<96:LIXBJYN$;MJ$$_<ITXRDW&G3C"$;M12O<]
M#N?^#CG_`((NV-Q<66H_MM:)I.H6<TMK?Z7K'P7_`&D-'U?3;VWD:&ZT_5=)
MU/X.VFI:7J-G.DEO?:=J%K;7UE<QRVUW;PSQ21J5VUU^RUX?N+JYG;P]X)NV
MGN)IFNKNSD%U<F21G-Q<@V%P?M$Q;S)LSSGS&;,TOWV*]/5[-6Z>Z]M.M_/^
MK,X+KS_JWE_7R9]3>(P/^$1\2-@;AI=V`V!D!M-U`L`>H!*J2.A*@GH*_E5_
M;5U;5-._X*Z?\$O;/3]2U"PM->\+_MNZ3KEK9WES:VVM:7#\*K;7(=-U:""1
M(M1T^+6]%T?6([.\6:V35=)TW4%C%W86LT114T_M_P"*/_IJF/[%/_!_[=(^
MX_'O@CP7K6FZA8:SX0\+ZM8ZII-[:ZE9ZGH&DW]KJ-M->:?:RV]];W5I+#=P
M2VVHZA;217"21O!?7D+*8[J=7[GP[ING:9HND6VFZ?9:?;0:;:1P6]C:P6D$
M,;6UN&CBB@CCCC1A#$"J*JD11@CY%P44W_$C_@J?^E4QKX)?XH_E,_*O_@K.
M[Z5!_P`$]?$VENVF^)+#_@I3^SCH-CX@L&-GK=GH?BC2OB#:^)M&M-6MS'?V
M^E>(K:RL[?7=.AN$L]7@M+:+4(;B.")4_>7X91QMXL\.VS1HUM-KS6\UNRJ8
M);=M2F#021$&.2$A5!B92A`&5X%%%:=%ZO\`*))]Z^'YI9M!T2::626672--
MDEED=GDDD>SA9Y)'8EG=V)9W8EF8DDDDFBBBLET^7_N,S73Y?^XS_]D`````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]A=F%T87)S+V1E=FEL+F=I9@``````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,S(R-2`Q,#4Q-30S,S<U,2`P,C0P-C$`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````1TE&.#EA0`!`
M`/<`````````,P``9@``F0``S```_P`S```S,P`S9@`SF0`SS``S_P!F``!F
M,P!F9@!FF0!FS`!F_P"9``"9,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,
MS`#,_P#_``#_,P#_9@#_F0#_S`#__S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S
M,S,S9C,SF3,SS#,S_S-F`#-F,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9
MS#.9_S/,`#/,,S/,9C/,F3/,S#/,_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`
M,V8`9F8`F68`S&8`_V8S`&8S,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9FF69F
MS&9F_V:9`&:9,V:99F:9F6:9S&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_
M,V;_9F;_F6;_S&;__YD``)D`,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DS
MS)DS_YEF`)EF,YEF9IEFF9EFS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,
M,YG,9IG,F9G,S)G,_YG_`)G_,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`
MS,P`_\PS`,PS,\PS9LPSF<PSS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9
M,\R99LR9F<R9S,R9_\S,`,S,,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_
MS,S___\``/\`,_\`9O\`F?\`S/\`__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F
M,_]F9O]FF?]FS/]F__^9`/^9,_^99O^9F?^9S/^9___,`/_,,__,9O_,F?_,
MS/_,____`/__,___9O__F?__S/____B_)```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"'Y!`$``-@`+`````!``$````C^`+$)'$BPH$`K!A,J7,BPH4,6
M#@E"C$BQXL`5%B=:W-BP!,>/(`UZM!@@I$F!23:6/!DRI46,+$&VH6,1"I28
M'Y.TV;@3Y\8GD#9&\KD1"J0G!&TJ31CI)M&*D-@,;`.I:E4V(P="<ME0H\^J
MV*!$@D2K;-FJ;6!BBQIQ)5$VD)#`-4N75E6D:Z4Z5.LSB5RR=>L>!1JTJU><
M3T@`#DPW*A*P79\*),PX<%3(!;WR]4FULN?"!=VRD"%YK>?/!ED@%*AZX.&0
M0$]7UBN1X&J!;D\F65SY,EW:K#6V'IC;9.?/E,U"FF-;+0O-..=6GA.HU!S>
MM'H>5&L%.LLG;#S^7PIT[5J@Z\IIJX9IQ0KIX">A4,5N]I*>\N5+73++!BZ;
M).W!)$-WKMW6DE7*G74??N7I`5A5=K'1WD3MV68@2%:<AV!XR['"8'FLS''6
M61)6..%`5U1X$GG7L*+'=?Y9X>&'U\#EFUU/3+B"%<Y9<05+,X*H!W@D'&`%
MC2%>1595.[9W(C:J7?C1"BNP"&(@*QP`P)$?!G)5$OVU@5243C9)X$E:<MFB
M=6R04"6#K`1B(Q().6GGF2=E>44KUUAGU7^!5!?H=4MR5="`3CXGV1R7_&G5
M91"2J)"=I6&SFZ./9BIIG>Y5BDU_H/X):G^/;3K0I3F^AM-\C_:7:53^<VU%
MT&YEL?&$JC%!^"""C<7JE$#20;("$K_Z!)ZF])UU5T&^Q0479YFR@<1?O&6J
MW4!&V6@C),6&=)QR5DW[X+2V)@1F57+%*B5'1BE+XI*E0GI40?(]^EBXZW+T
MH+;[*KGO$S==&N&H_1D:TK#P/E%J>C8VIB2))=Q[U68RD:"M"?1%RMABW'YJ
M,:GY;A05PM(FVZO&5N%5\K(Q4?57PY[]A\T3K$+2QJ]I/0$P4:Q*UQN=#K7Q
M)%$Z_24;7@Q!D2.>DH5WVG(.)=$DKC'Y/%U#4`#HI*<+>\8<0RFUL'6EKG[V
MM4(EL*>B9+M9+5BW!#WA$J6E^<>K8`LI/1!UW9(M.2IV!F,[QZ^(AFQ2NW8Y
MJERW+"0!)AL]KDTT=KS:G-"CVI%9&JUW`W;MK$N>'275)L7:=5F?%S0?TF:R
M?6^H?@<-]4%C^P2%Q4JZ"NO9"^F\=Z(XU2MJJU:E[M#0++':DTZO6NZI0R<P
M1,<<HP9>6D```#L`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O879A=&%R<R]L:7-A+F=I9@``````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#(Q,#8@,3`U,34T,S,W-3$@,#(S-S`S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````$=)1C@Y82``(`#W````
M`````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`9@``9C,`9F8`
M9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`S)D`S,P`S/\`
M_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S,P`S,S,S,V8S
M,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DSF<PSF?\S
MS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F`#-F`&9F
M`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF9LQF9O]F
MF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F_S-F_V9F
M_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9,\R9,_^9
M9@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9S#.9S&:9
MS)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,`)G,`,S,`/_,
M,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,F3/,F6;,
MF9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,_\S,____
M``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___9@#_9C/_9F;_
M9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_S,S_S/__
M_P#__S/__V;__YG__\S____XOR0`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```A^00!``#8`"P`````(``@```(_@"Q"1Q(L*#!@P@3*ERH$``)@P\9-ARE
M@J`*BA(3`FB&$=O%9A4%D@"0<:"*9AQ5?.3X\&)$C0!B`EB)LB9*E:.:O41(
M(J?-GT!1[D1X,JA1H0Q['C6J8B3)A$67!ATUU*)/J3\[%HQ)$^C%E5]'K4`(
MX"I0)V)5KLA)0@6`%8'&'NQJ<]035M>NL7HB%B\K*X&J"J0+<@7>O'H-(V8E
MERA0BG\17S-L)2^KD'/-UE2\V+#?Q@8)H[1[F/',%4VA:J98-*V*M1Q'C7K*
MDT3;FQ2/JG0KD41*V2`UU]2JL&?%F:P)RQ8,4>15U@YM2R\Y."M5ZA`UI\8^
M4*9FYAD!)`0Z[9,X=YFL&*.>#5XB5\\KW@;F[EQV3+CXZ6.3R;\_;80!`0`[
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V5L;65R
M9G5D9"YG:68`````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C,P,R`Q,#4Q-30S
M,S<U,2`P,C0W,C$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````1TE&.#EA(``@`/<`````````,P``9@``F0``S```_P`S```S
M,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"99@"9F0"9
MS`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#__S,``#,`
M,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F9C-FF3-F
MS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,_S/_`#/_
M,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S9F8SF68S
MS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9_V;,`&;,
M,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`9ID`F9D`
MS)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF_YF9`)F9
M,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_9IG_F9G_
MS)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS_\QF`,QF
M,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,9LS,F<S,
MS,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`__\S`/\S
M,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^99O^9F?^9
MS/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__F?__S/____B_)```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"'Y!`$``-@`+``````@`"````C^
M`$E4&4BP8!4`V!(J7,APH4"#!DDTG-CP(<2"$B>2R%CQ(D2."3<.!*E0I$>,
M`%(^5'%0HT6/*EA6D>DD9LN*<EX:E#FSBI,JI)Z1>D(RI)R<$&T.E$EJU;.G
MI4BIP(FTH-*>0(4^U2J5(8FC5;$N'1B45-"G9H6"_`J6Q!.>!<^2`K0U3YZG
M*QR"/>K6:E:T6P.K+;DW)\^?9P4K7L61[5$59M_^54R9,6&P3[8ZI?SL[M8G
M02T;?9R8<^<5I=`^6;&*5&.P2$QK?K+*<YY50/->EN-$-EI6T&RSRN-:[]'8
MOO58LR:<N.[1<I"CS9,ZL')659XZL7*W*_3>:$FAE5I16@\K*ZR?U90[-:23
MZ.&)DW`BU^X*VTZHHVU,`KG9/"J\EUE@FVU%BEW/B%;26?(=15]@!T+H67$,
M0=9:'HX]>"!BTZ7F747D2;579H`<6)M=Q`G5'D78;%38@\^4<MMP9JU0E$;O
MC;B5C-1)A02+%6V$Q'&EF>7$1AL!61)!2$*&EHTY'JEDBW[-A&),+N8T)38`
M[#32D3&IP!9(`0$`.P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V%V871A<G,O9V%R9FEE;&0N9VEF````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`R,S`T(#$P-3$U-#,S-S4Q(#`R-#4S,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!'248X.6$@`"``]P``
M```````S``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F
M`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_
M`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F
M,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_
M,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F
M9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_
M9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F
M9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_
MF68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QF
MF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_
MS#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EF
MS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/__
M_P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F
M_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S_
M__\`__\S__]F__^9___,____^+\D````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````(?D$`0``V``L`````"``(```"/X`L0D<*!"`01($$Y(P"""APX$,`<Q!
MZ)!$GH@/'48D,5%A'A48,Q(T.''B)8K8+*HH:5#D2``D+JF(B9)$)Q(J3K9T
M*9"CBDZ=3DY$PC$FT)4H>=KL-)-$T8E.?][D23"F$Z!`G<RYBM7)2:H]3U["
M&M0H5K%)'\+,<W/%"J=N`;B%^Q;HPHP+EZY@Q<HMW[U]`<,\Z;0B6Z8X65V[
M]I<$X,6L0$K]6C6K'Q6HJO#MF^E3)L"LJJ!2X>?J78@P,5-!Q5J%:Q4K/JUX
MC9GUZIRGL0W&+&TTJMZL43D)_MMW;ZDUC_YV3=PUT]JM51RW.W!II^'1G0?;
M_IPY:ZZY#Z)FW1X,*/GSYK>#WUD0@(KS\..CWYZ[?2?Y^,__#$:Y\LVE3N3'
M52>#I57=0@;MAQ]B#!E($!('79+?=CH!@(1(3A$U5H`3:G506D[91)B"$U8X
M5H@IE4786.]-&,Q/*QKE%&%.F623B[A!-2-"3F&%(`DNEI>7CQ3=R!U,]P5Y
M4Y)"AN655T8&^>(E3U(&4TD+D:7EEF5AV5![$84IYI@A!00`.P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]R96DN
M:G!G````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3`V-S4@,3`U,34T
M,S,W-3$@,#(S-34W`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````/_8_^``$$I&248``0$```$``0``_]L`0P`!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!_]L`0P$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B
M``(1`0,1`?_$`!\```$%`0$!`0$!```````````!`@,$!08'"`D*"__$`+40
M``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$5
M4M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC
M9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2U
MMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$
M`!\!``,!`0$!`0$!`0$````````!`@,$!08'"`D*"__$`+41``(!`@0$`P0'
M!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6
M)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS
M='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#
MQ,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1
M`#\`^K/@9\3?&FK?`WP5\5WT_1M(UKPWJOQ-OO#-A9ZC<:3J=EI?B?P?XZ\!
M>$=:T.[CFOWUWXE&;Q3IFJRZ?+.;GQ#XCAB\W8WD+#Y;\6OB/<?"S]FB72Y-
M2N)O$WB_7=,^",&N^(7T^?7/%EAX5LX?#GBCQ@'L;.RMH[.PTS3-;\/^&M-M
M;:#3/#EO=7$WAZQTW5M2U'4KSE?!OQ)L_"/[-GA1].6U>7X<7/C/QZUFQ$'E
M^+]4UR;2OAE8C[/&T,+:/JVLP:R1]CFDBFTO3)T4QP3P7?R%X@TSQ=\=?@39
M/X/U)CH7[+O[-4?Q2\;ZG<&ZU?4/$%WXY\9W6DZG?:;>7EI8VTWB+3K>SUKQ
M8Y1+:+RX+MGC6%AY?[MB89=DF$P^<Q=&BL#@:&'E.,8Q:<E&-K_.VS];'XYE
M&$S+-,2XN%2?MJ];D;YGRTTDU'T73KIZGZ9?%'QRMM\>/V5O!.F2.VDWNHZC
MXR2)?L\.FS6-QX/B\&^$YKBW\L++!:6%[="VC4H$N"+B!HY@&KOOAY\6(/$?
MPP\<_%.&9KBPCUOXG:QIX<$J+?P%>ZE!80X!#&.^M;2S,RJP,TTTAA:!&2-/
MRP^)7Q!\3:1XU^!<WBC3]4'B3X!?#CP=X(\=:P8&M;:Y\0^`?%&H:LS6$9N)
MH@OB[X<:<WC736.IWLDFGV&H%89PT4<7TG^S%\1O!NJ?L;:C')J<%E8ZMXP\
M$^%=&S_Q]:D?C!XF\%6_A:SMU)*G4M?BU>>>[?RS#+#!=A;>,Y8?193Q%EN.
MPU&5#$PA*<X1E--72DXW=]=EJ_\`*QAF>4UL+4C&O)VE*,6W>\4W%?Y7^6^M
M_ONVUG6O!/P[^'K7).J:_;2_#70=5?5(4O1]NU'7M(\.ZN6M@(%N98&UR\DM
M891)&T-K$ES'=(LPF]`TWQIX:T+6K$:I:Z5K]OJ1\8?#SQC\/Y[/^T+3XH>!
M)9I)/B5\/-;U"Y:5[J]N-%OM0U70&N7DET+Q(MA>6SK96\FGS?/WQZ.M:QX_
M^$7AVPNH=&\$>`_BWX.^*'QD\9&[2'2K'PKX<@UU]$T"=\_-)XMU?3;W7WB4
MF2;P[X3U%[8VT^KZ;>V?F_P]^)DFJ>%/V?\`X@:_I>JZ3XUUWPY^UG\6M4\'
M2QP2:A9VWAV.]TZ^BNE\@K%?O`^GZ9F4-<?:)97B="H\O/-L5D&?87'Y##$4
ML=6C5<-9*4DW9)JS7VFM;;I/0YJ>"Q>65EBX3E7P\9*>R<8J+C*ZTZ6O]UT=
M_P",_P#@J[X&^%?C#Q9\,+#X@_`77;'X<>)==\!66M^)?`OB1/$>LVG@_5+K
MP];ZKX@33M?T[3TUO48=.2[U5;'3["S6_FN!:V5K`$@C*]/'PA^$/BT#Q7J/
MPQ\#7NH>)P/$-_>3^&-%NI[N\UK_`(F5U<S7+6#M<2SSW+RR3L[M*[M(68L2
M2OQE^'F)BW%5ZJ2;22D[))I67O=%>WR\SZ=<5TFD^:.MG]GKR_G?\?(_GHT#
MQ7XVTOPYX_\`AMX@L#9^(#XQUQ98(;KRKH^(?!&IV=QJ>GVRRS'[,;5%MM4M
M[64F8VH/^D"0B9?HK]D>7Q/X8\`>(]/E_94\%_&7_A?'B^^\&?"KQ1\5O$%]
MIWPL\,>$?!/A;QW\2M2;QK?^'[6XUG4-3O/#-Y?>#/#7@O1[F#5O$/C.]TBP
MTZ033K;30_M<^$-'\'?M#?$#6(M!,$WB0^'/BG!J%F&>/_A)-9TAM`U[4889
M3+"_V_4-(NAJELT<D<T)@3:A+,_Z;?\`!%CXD^#_`!E=>.OV9/$.JZ;(OA/Q
MUHOQ4\%^'=2EM;"[T_PSK$%Q:ZM::5$+12FKZ?KGA[1]8TN_M%AU73U\1V36
MM]%.8IHZ\4EF>2\"9;:$\0Y8BE/,)/F?MZ=24(TE5:^Q%M-6>EU<U\.,UK9M
M'+,?1KRC0E!3GR6^&?*IOX7O%O7S[GY=_LOV&@?MP:5>)I'@;PM^S3X[^-7P
M9U_Q-IWPE\*^+?&7CWP9J7QK_9W\4ZIH&BZMXEA^)4U]XD\#ZCX\^&^KZUI]
MEH5CK$5SIO@<O?O%>3PY?W/X4_!6;X4?%;XU?!G4]#;4?"G[/NG_``X^+R:"
MET3K#:UIOC;1;#X.RZ3/+IUII*II"^(O$%N\]W;I;H/!<$SW-I#9W33_`-1W
M[-'[!G[,_P"R%X<\7^$OA+X/UR^TOQYXLNO%6M7?C;5(/$^OK/>:1<Z#_96C
M^()-/LM5T_38-.O;J"W*7CZI)Y[)>ZI=08B'I&A_![X'ZWXR\4?$WPGI.CZE
MXKU*#1OA]XO\3:9?OK(N;OX=W>NZ8?"5W:K<*I?3]:U7Q%=7:W%S*RWS*RR0
MK&4;\)H<0\383"YG2PT_8*U*6%C3G_"C*4+JFG=[76MV_)ZGZEG.1Y%FDO=E
M4E=I;-7^&_:S;>FFFY_-9\6?BQX;^''C?X>?`WXY_$3]GKX8:UK/CK6?B5XJ
M\->.-)^,WCC5_B+>Z-8C0O!?P_N/`?@G2=-\>Q>#-#\)W\)BU/3=+U^PLO#5
ME<7,_B"\N)+N_N85'B_2?@SH'[1.M7?PU\4^'O&WQ9O+*#X@?!WXAZ+XN\#Z
M-\*?BL?BSI-[9MI]PD.K^'I_%?Q&\=^$X9K"34]9N-&M-"T)-<TVWGL;V6\^
MF_\`@HS_`,$;?B%\6OV@?@I\;?V,])\%?#[QKX,U+7K_`,;_`!/M_'MEX'^-
M$/B2[\36$.F^+M$U:3PMJ^HZMJFE:*T]E:Z'+J::7J%HJ:>\,3R_:EN?M-_\
M$T/@G^QK^Q[_`,%!?%?A#Q>=,T'XQ:3H,OPS^&&E:8?#7P_^'&NV5OX?\(>&
M-&\':2)8[2S\9^.-4MKKXB_$K4[+RSX@UAKS4+&UT2PE$"^GD&<YU@L71Q>%
MJXB.85,11GBN5WG52K0<D[W5G%6>FKYFGHD/.^&LER_`X2C0JT:]!X.I+%T(
M:UZ<E3;_`'TVW%I6N[:M=$>$_`C]HG4[7X'_``:MK@M-/;?"GX=P3S20":26
M:'PAH\<DKRDYE>1U9FD/+L2QY-%?E'\/?C?_`,(KX!\#^%S9^/+H^&_!_AK0
M3=6WAV66VN3H^BV6GFXMY`6$D$WV?S(G!(>-E;)SFBOZ;7$&.DE)X.5Y)-^[
MU=G^OY]F?SP\)E=W:5.U]+-VM>-K:[;?UO\`6W[<7A?7-;\'Z;XWTN::#6/"
MND:_IU_:)&MS<2Z-JT(N-)O;@HJE_P"SM9@$D;;XXH[6[O59/,DCFA\0_8V\
M:^*/!W[9/PR^)?A06T=K=66C:#KFFQG3=/U#QE-XKMQXE\,:+HVIW:FWM]5U
M7_A'-.\/V^F7:-+?".TM;6\LKF1KT?I-JMAI^O:?=:/J-E::E9ZO82Z+JMA.
MLLD>HZ9=$I/I\XCFBN/)F1W@_P!'GM[@1R,(IXY=DB_CYXT^#$W[.MYX@USQ
M#/K?BCPQXL\=V&@>%?$NB2S76LVGAK2]`TJZ\":C=:7:VY;3_$'AY-=\0P1W
M6F6MM=WDFGZ7'IT4-Y'-)><_B3*&;8>>3K$J67U*:;C)KV<?8I2I0<DM$I))
M:I_(^-\%>,8X3V&4NHW&DX4X4;[*\8\JZNZTWU_+^]I];N?%G@2-],DM;>^C
M@M()QJ]^^G6UM>SM#)>6&K7%I%=S6LT5@\WDPQ/'+>7"+]EG0%17A/[&'AKX
M4?#;X.6?PK\">/8/B->6_B_XF?$'Q#/JZ7VA>(M5UGXF?$;Q'XRUEKN'4;>R
MN=271=3\17FC:1?0&&(^';2P@EAO+U)=0N/S>_X)A?\`!1?2?B+XF\/_`+/W
MQT%E\//C[XL\+6>O^!CJ.M9\/?M"?"SPGJNJ>&_"'Q&^&FIVD3Z-KVNV]WI<
MVF^,/#*ZA9^+](O-&O=2%I+%?V-G#^]EQN6UN[J>.-+:2R<ZK=W<^FPW5CI]
MFK3[]3UN?3;;3+*QMU1KB.*37K.=$4M<1R$/7\J4,NJ1Q6,7UJ;J4JD$H3E:
MBJ<)1Y5'HTK7OK=)']A3ABJ>&=1T?8QQ3Y:/M5R.,966ETK;W5M5IKHC)U2[
MM+"'4WOM5TW1;'2K*34+_6M0,\&CZ5;V\1N91<3B=)ITC2,RW").))%C81,C
M%2/Y1O\`@IS^U!)^VG^T'X:_9HLVU:/]EGX+Z-<_$'XF>,-&U&:W_P"%Q^)K
MC3;F7Q1IWAFU26ZCM-(\':3;3^"=&NYK>YO;C7=3MXX+N>Y**/OK_@IU_P`%
M+_A/X<^%>H_"KX2ZO<>-=>\0Q:UJVL>-M)D>/X8^$/#OA>:WM=??3/$LMBB_
M$[Q+8VHU:<:?X,.J:%#>6T%OK.IV-M]HE/X*_LWZCJ'A*T\%X\(HNH>(/"VE
M^/\`Q&=9-WJEAH=]I^H:)K/@#PI?ZE]IB-V+'QS=Q_$WQ;963PV^M/I5IID?
MV.T%U;77ZYPSEV697%Y]FV,P34TYPC5E'WY*S44KI6;22^6EC\WXQS^EDF!K
MY;4UJ.C44HWUJ-PMRMM\S4MGK:S/V'\-_#+X/6OAW0+;_A`O#^A_9]%TJ#^Q
M4\->(=031_*L8(_[+6__`.$G3[<NG[?LBWFU?M(A$VT;\`K\U[C4=2N+B>>^
M\?>+;B]FFEEO+B+5KF".>ZD=GN)HX8!'#"DLK.Z10QI%&K!(T5`%!7T?_$5,
ML3THX%+2VVRY;=?+^M;?S4N)Y:?\)RZ='_<_+]/4^@9)IE2_999%9+6=D978
M,K""1@RD$%6#`,""""`>HKY"_P""H=S<:;^Q'^T5J>G3S6&I:9HWP\O]-U&R
ME>UOM/OH+XB"]L;N!H[BTNX0B"*Y@DCFC"KL<;1@HJN)O]PK_P")'PW@_P#\
MECAO^PW"_P#I^D?S3_M+^-O&?AS2/A#>^'O%WB?0;SP'\1-?O_`]WHNOZKI=
MSX,O[FS\/7UQ>^%)[&[@E\.W=Q>HMY/<Z0]G-+=*MQ([3`./ZKO%7QD^+WCS
M1?V!/`7CGXJ?$CQGX%\::K\(++QCX+\6>./$_B+PGXLL]3\2:'9ZE:>)?#FL
M:I>:/KMMJ%I=7-K>P:I9W45W;7$\$Z212R*Q17X+4_W?'?\`<Q_Z7(_T_P".
M/]VR3_L(PG_IRB;G_!8NVMK7XB?"?0;:W@M]#M/V;?%45IHT$4<.E6L<&KZR
MD$=OIT:K9PI"J(L21PJL:JH0`*`.7C_<:%X(@@_<P)\-]-V0Q?NXE_T&V^[&
MFU%Z#HHZ#T%%%>!Q9_R2F7?]?:/_`*<IG\H^,/\`R/9?XOUB8M%%%?!'Y(]_
MFOS@?__9````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V=R;W9E<BYJ<&<`````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-S$R-2`Q,#4Q-30S,S<U,2`P,C0S
M,#``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M_]C_X``02D9)1@`!`0```0`!``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_
MVP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`
M'P```04!`0$!`0$```````````$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%
M!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*
M%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U
M=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&
MQ\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!
M`0$!`0````````$"`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"
M`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF
M)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$
MA8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4
MU=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#^(34/#UU9
M7$D322J\EPZ6D,\3P?:'G>-4\AI`OG,\A$2K%N+,Z@`M4$UGJML!#/"\,K*B
MB,;E?#2[4VH0&+O)&40`99@R@9!%?MS_`,$H?^"=6I?\%)OVH9?AYK.K7?A;
MX-_#S3?^%A?&GQ)8RR-JC>'1/:6MEX8TRYMXY4C\0ZY=7:1JVY(UTJTUNY4;
MK0LGZ4_\%_OV0O"7[!GPX^!7AWX)_#GP_HGA7XAZCK_AZ'Q?_P`(II6N2Z!I
MW@^W@7P]X9AUJ_99+'5=?35+F\:_E<W]];V6HW]E'+:6%[)#\AG]?`9;F]#)
M\)4Y\6VO;SK3]G"C2=G3<91O=M+5.RO:W0^[P,YXFC+%8E.-"$8I1I)2G+2-
M])=KJUD_/2Q_)?#K6O:4)D5[OR9<"ZM[@2#S/**![9PV-C#<K'(W*%((ZUF:
MMJLFKW8N7C-LJK';Q6>]I8<2*$=S(I(5O+=E`8CEU[D9_>/]C+]CS4_VA?\`
M@G?^V-^TE\2]#TN/P[\`M+U^+P5\1]7LRL]_>VGAF_U+5="L;UHH8=170]33
M2=/@GMGF27^U(LMO,*O^+A\+:A,+:\E@L].BLT,B0$`0QRX2*.&WW`&ZFF6:
M&ZF`+&W0*'`#@GT\BAFN;3QV"IUX^SPU_P!][5RHRO:]YM*SC9*4=;=^VN-J
M971>&6#6,Q&*Q7(L+A/81=2=16]ISJ*O&%[<KW:3/9O!7P>^-GPT^$^B_M+>
M'K34=.T<^)X-+T;Q5IL$-[/X3\F.[?\`M>YEDC>'1[HBW:RL;NY9)'FO8[*S
M#7EY;*?[0O\`@V<_;>_:?^.`^/'P#^-/B#6_B/\`#KX3>!="\1>"_B'KVG_:
MM?\`".N7VIQV%U\/K_76AB&I6.N6<\>NZ+8MYE_:1Z3=K(`&K^;+_@G]^WU\
M;OV$;3Q-H,WPN\-_&CX+?$'3[I/%7PJ^-/AG4KOP5JT$Q@CO)M*U/RDMX(KB
M,%)%D-S:W.GS7\,%O+J$EDR?MU\(/^#B[X,?"+X<7W@_P-^P3X5^%,,,L5[9
M^&_@_P"*?#?ACP3J%Y<[EFGU5G\$O/+J$098GU.]@U%1:FUM+0>8EVR>1G?!
MN<XRE['"X7+\;SO_`'A8B<7";Y>9)03ORZK=7;U>FOHPQ<,+7HRQDL3E\.2,
M:^%Q6'<5"44KRI2DE&3ENN;3U/[.Y-;L3(Y;5;-&+L63_A()8MA+'*^45S%M
M/'EG[F-O:BOX7M0_X.1?BI)?WTEG^RMX'BLWO+E[6.X\5>)KF>.V:9V@2>Y@
M2TAN)DB*K)/#:VT4KAI([>%&$:E?*KPDXN=G:'3_`)?3_N^?]6]+=O\`K)D=
M_P#=\<]=U2P]G\.J][9V?],ZO_@V>_:W^#WP-^)/[1?P8^(>K>"_"&L?'&R\
M!^*/`7B#Q//%H"Z_<>!V\1Z=J/@VPUF^EMX8-2OTU^.]M+$2,U[%8EEB<^6U
M?UQ_M&>)_P!CGXB_"76M,_:9L?@]XW^'$,D6NWNE_%Y_#EUX.M[[3(A=IJYF
M\4*T5E<V_P`MG97NG!GG:2:W59(9;A:_RCO$FLQ:AJ=KJH6VM39VMM#IMLFQ
M&7R%5)Y?E5IK9Y&.X7$(250Q`<)(P:W=>.[K5K2ZL[R^U6;RK=;;3XM8U>[U
M*TCA.UYH(HY;F"V6!GC5QY[O)O1%",'8C],S_P`-J6=YS6S9YI5H1JJG'EC&
MGHJ>ZYFT[.^C\NC/ALOSVK0P,L/'#4N:4G>KSSYK:6]WX=DMUJ?T6_\`!87_
M`(*=_"+XB?#O3?V%OV%O"?@KPC^S%X:O[67QC>_##PZGAGPIXLUNWO9+O3_A
MSX=TS2DTU-<\/0WME:ZOJOB%-'F'BS7(-#&GZA+865_#-TW["O[$?@WX5>`=
M*\<?$KPCX3\4?&?Q+:P:Y/-XKT&RU^T^'%K=^1<0>'O#NF:M;7-E'KUM9'3F
MU_4YX5F%]>7-E$Z"UNTK^?O]D+1D\;_M,?"#0=34WNCMXL@O9[2>$A;BTT6T
MNM7EMI;9`UN$E:Q6&%BQ=BP1,AS7]@>DW;C[4N\0M&L"7$L&)8XG9`)HV"AE
MC0F.W9V;:%)B#8\Q<XX^E1X<PE+(\NJ.,:RYJV(C)^TG*HTY-M.SNUMLNA_7
M?T:N",#Q%1S/C+.\)2QLL%C*>6X%5*<'"BZ=#VLJL5;X^:T7I:S;?1'87GFQ
M6O\`9R:3HK:8D1EMM-?2M-N-,M"8VBE+:9L?2[HS+,QVPP1K#&702)DHWX[_
M`+;W[!OA#7_#VM_$SX3^%M'T3QK;64^LZKX,T"UFTGPYX[G5F$TIT^$26T6J
M(TJR0R6;\E9(%C)G&/UJU#5A"(TNQ))'&N5FMVV7`W(0&@<G9&^TL0TGR;`P
MSG%>2>+-?LK>PE:ZOX_L\,<I@1=K(RS!HA]O9B0\B/*I::,^2N"K$,R@^+A<
MWKY6W-5I1C2E&U)SDXRE[KE-MW=YO=+30_J'BOPRX=XQR;%95CLDP2=:G3]A
MB:-"%/$4IU()^TA4BDV[V]V5DK66A_&)<^+/#EI<3VMY-J-G>6TTMO=6C6EV
M&M;F%VCGMB&4,#!*K1$,`05Y`/%%?N5XE_97^#6L^(]?UA=%M%75M:U74E"Q
M1;0M]?3W0`^7H!+@>U%?5+C>5E^\W2^T^O+_`/)?U;7^(JOT<90JU(1Q6/Y8
M5)QC^\Z1E9?:[)=.OF[_`(:>+M#\0>%M3N--\2Z7JOA[48+J[E?2-;TZZTJ_
MLX998P?/M;B*$11F5D6#@;PP\O<,UB"]MU4Q2QD2`9P1AL#'(4C./F&>.ZC/
M.:_4G]J7]H_PEXLUZ>W^,OP=UB"X,T<$.I`Z0+Q7A!)DTW6+15(BC5R6MKO)
M(9)'PR)G\F/$>HZ6^L:K-X7:[AT6ZOY[FS@NY$DDBB!"(+EL%I+C:WR2Q?N2
M@D'4KCCX>XU6=X/VM?!NG5Y(S:I2G+#IRY6X\[U]UZ2MJFK-)H_$^*N$<?PC
MCL1EV,]VO1J.,*=9.%2<+^[-I*UY)-Z:/?:U_IK]DGQKI?@3]H_X3^);VX:S
MLH/%=I9WLUTC-9Q6NI)+8327(X+01K<%WP055-Y(17-?UO/XE\+PW,42W!NI
M]25GM=220Q"6WN2)8CIN&$,,/EVR,))R?EVX.'&?X:DUJ\5E99S&8Y(Y!)$?
M*D\R*5)(_+F&#&Z2(DH(8$B,K_%S^P7[/'[?:3>%[+PY\1[TVWBO1DM]/TS7
M[BY>&TU?3(HQ`D=Q("1;W$*N@&XKYB))(22M</$ZJ58T,9@Z<92C"%HJ3:;2
M7,K[W7EHN_;^H?HM>(^0</4\TX8XBQLL%3S'$QQF7>T<5">,5%4JM.7,[*GJ
MI7WONK:G[[:UX^\/6CHD4K32Q*9HT&Z**XNX\0+Y\LA"W,P2:3YH"8R-QZ@5
M\M_$WXAZ#;:/J=Y=WL\D\=PD@MK&17>W)+(3%(K,D9CE>-'>;$2;]C$.Z@_G
MSXP_;"TRU>9=*EBN88+B*-3#=7-]'<2S(\S3VTC`QR1KY95FC9MI8#H37PC\
M2_VI-4U"6Y:SEEAN9;F\(C\R0*YD.%CGC8_)&P/FJ2/OQ)@\XKXFEA<SQE64
M:U)1IU>5N7-+36-[7Z)]?S>A_4?%_C)P=PUEU2>'S;#8S%P47"G2J1E>I3@H
MJE[C;LM%=6>_0_0F;XYZA#-+%]JT<>5+)'BX4M<#8Y7$[`@&;C]Z1P7W$<45
M^'$_CC7[B>:X?6=3WSRR3/@RXW2NSMCCIECBBOHUD\K+1;+JO[G^7Y]C^0ZG
MCWB)U)R6`E:4Y25I5?M235OO5OEWT_8O]MJPL7^&NHNUE:,\"(87:VA+0EK"
M?)B8H3&3@9V$9P,]*_#/30#I]ID`Y=\\=>6ZT45X7AK_`,B3%_XZGYTSD^E5
M_P`EOA/^O6$_]N+DJJ)R`H`V=``/[OI4P=U:`JS*1(A!5B"#M;D8(HHK[M?[
ME'_$_P`XG\T4_P#D=9+_`-A%;_VTZ&&\O&=%-U<E0P(!GE(!VN,@%\#@D<=B
M:YZ9FDO29&9R;@9+DL3PW4L3117/1^%?]O?G$]G'_P"]3_["W^:.F6./`_=I
MT'\*^GTHHHJET^7_`+C/I([1](_E3/_9````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T
M87)S+W!U9F8N:G!G````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-S8R
M-B`Q,#4Q-30S,S<U,2`P,C,W-#(`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````_]C_X``02D9)1@`!`0```0`!``#_VP!#``$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1
M"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!`0$```````````$"`P0%!@<(
M"0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!
MD:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I3
M5%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6F
MIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T
M]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0````````$"`P0%!@<("0H+_\0`M1$`
M`@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S
M4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC
M9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.T
MM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`
M#`,!``(1`Q$`/P#Y"^#7A:]^+'B=[&V%SINA:<X;Q)KLR0QG3+3RS'##;$LL
M=]=WB136FFV<4$Y>4KYH2)+EE_4?7-%T;P]\/-"TY5^P65O8K:HKK@6]I;SV
MXM))&9T5S/)<-<2NHW--,\LA,KN6_!K]DKP%\?OC#^V++I_@?XH^,O`/PA^%
M47@_Q]X]M-/U?6)?".O:;8+9WUGX?U70;36['3=8OO&6IWNL>%+=M0AU%_#]
MC>:UXG>PN;+2[NQD_:3XD76H?$+QQIO@[3)FN)]6EE@L8//FBL[6&PLDO[Z4
MVD2K;3+9PV<L\?FO!%&((1"Z1-&:^LS7!+`9%0P&%IRJYIG]&G[.,+<]*C4Y
M7&3J+W8N5](N2:Y9.5EJ<V`K8NIGCQ>8RE@L)DLIR4*JG2]I6]C&:YZ511FX
MRA*-6G))TYPJTIPG*,M/RG_:EU[QEK?[3?A'P1\"/`[_`!+UW5/!KZW\0+6Q
M3R%TJWGGDL_#NHG5]0O[#1=+>>'1)8IVU>Y"7K?V=':_Z;)"P]YT7]F#XK2V
M,-SJMMH&FW(B+7%I<:N+B16E7*QE;*TNK;<CJQ8P2.%9=P.Z%2/T@\/_``HT
M3X;1+X=T"PL;KQ3K%T+CQ!XFATJ&VUCQ-JT7R64FHR22375U'864(TG1XKR\
MGBTC2XET[3!;65LD36=?DETXSVY"-]FF$:F..)B\22`3L&VD2R,&=I&9V!0,
MID*228^2Q?#>"R;"87"XVI.IBZ>'2FHRA&\H^_/6\G4:<M)1YER*#NCZG+>(
M\1F>)K8C"*/U:O74X.=FX4W&,*4HQ3]V,G!RY9)/GE.Z5['Y,^-OA5XQ\#(M
M[X@TYY+`O;11ZG:217EJMR[7CJ\H9!+;1"."9_M$MFY5C;X<F1(:\Q2**.+)
M:9YXS\PW,5$OD?NI6C9A.J^;YFTM'ED8/"JR"7'ZXW6GVVM6MW::A:0SQ3J;
M62UO$2[@-L(%0"2%PT<P>X8J6EC*[F6,S,O7\]?CC\+[CX=:O;ZG8213>'-;
MU"\%L$AA@BTFZD$DD>E-&+JX)C@LTNYK.=4B`6SDC\JW,&^OR[%XB%#%*$8R
MA"K*:IN3CI*.O+?X6^L6VMFFFVC]0PL)5L-)[5H1BZD-.5/EC)<O;56>K^*R
MZH\E%G&P#`W0#`,`H$B@'G"NJ%749P'!(8<@D'-%48]<41H$U*R90BA6,FTL
MNT88JL#*I(P=JLRC.`2,&BK56D[/EJ.]G_%IZ_!_>ZZ??Y%>R_Z=S^Z/E_>\
MOZUO];?L!7$/@3]CD_$2TG&I^-OC+XLUT:X+1H+'^R-*^&\B6>BV.I705KV:
M\EU/Q-XCN7W1""*S>P*[)"!+Z9_P3&^)/B']H'XD_M5?$KQ)H%@GAKX:^(]#
M\`_#1V5KM%CMKSQA8>+-6L];O8D,ESK#R:`\YL&B@2&QCM4,T<MO.WY7_LO?
MM7V'PX^"%S\&O$-EJUP=*\0:]K/A+5='M;-HKJQ\42F_UVUU)M2N[*XMY7N[
M>.>UVP3O#YT\:&VA@M@_[<?\$=_@G=_#7]C(WEW.L^H>//$_BS6;Z\*S(+E;
M'QCK]@'<2!$#E+&!&,$4:R3QRAB"6K^H<@HX;&/+:O/&O4PF6895(M-SHUE2
MC&:=V^63Q#G-I]).UFTC^=O$W/,3F'$O%.:-2IX7,,^QE+"W2C2JX%2AA\OC
M",8Q2IT\OI4*=H\JBH02BFFG]/:M_;4&O7^O6]HT*^5>16MY"DK0A[6P%O)`
M)ED5#<RVLY=M[,\;,,A!E%^%?V?]+^/&NVGB[5/CGX?N/`NHZAK]W=Z9H6H>
M.M#\46ZZ0VF>'_)N[-/#^KZU!I*2:E#K#0:")(9M.,DF862:"=_O[XJ2QV-M
M9NCN9--DN3;Q-Y8"+=R,EU,T84'=+&N\^:)-J[(TV!:^`OB-^U9\(?A%XH\`
M^#?B'>>+/#FH?$&36;FU\6W6E:5+\.],6ROM%@33-3UB37/[1LM4#:DUQ+:0
MZ'-81:;+9W:W2N;BW7PN+LMP]3'TZE;FE7I4HN#@VDHS<U)V6EGS<LE;50:>
MNI'!N.C0PKQ/NQ510P]Y7E%.A)NW*U;52M&3:=W?=W-/X^>/?%/P4^&_BWQG
MX0\"ZA\0=<TO1X_[+T/2]$N=9DN-4U'7M/TR.^FM[*(ZC<V&BV[W.L:M#!/:
MRG2K2Y<7E@-]VGGOB'5+CXO?LHZ1\2?%NDVVF>(+WX7:;\4KO3M/M+AHM,U>
M#PE)K=W'IL%W)>7UO%<>;.T-FSW5Y';R26HEN)8U\SV#2O'WP[\6:G<6W@WX
MK^`_%&L06MQJ[>'O#/BO2_$.L'1$G@E;5FM]$NKC[!;+<75M$YGDCN(9I&MY
M+>%I$:&]XMN3J/@3QII=R(6C@\'>(+7+KY,3-+H-Y#(DDB;)BH64,9&+3'>[
M,'8`G^;N*/\`9Z].FJ$J;H5%*G-W;JPE:7*[ZZN,=59JRMHVC^A.&52Q=:OC
MJ6+=:&(I1I*E"5Z5-Q46Y;VO=I6O+XF]&?B%#XZ\'M%$R^(;Q%:-&56",RJ5
M!"LQTUBQ`P"Q8DD9)/6BL&X^&5@;B<QZY?PQF:4I#$\;10IO;;%&QVEHXUPB
M,54E0"5!XHKSUB<M:3<L7=I-^]/=VOKSKSZ+T[^L\#F-]*E"U]/W?2\//R_!
MGR]H(N-`\6)IMW;&U<:G?6=S',F^X@F`D>;<L3JC>7(Y6)&>1&=W:)V&V63^
MPS_@G5XDTW5/V,_#.DVFY3X,E\>Z/J".CK''<W/C#Q5XBQ`OFS&4RV6MVLD1
M:*$"9T5U`1I:_!3_`(*1?#W0_AWX,T#XFZ+91P^/)O$NGZ%I?F`/:ZM'>1Q2
MW-OK*VZ0"4P65K=-'/%.DD<3SKA(W:W?[3_8KU^Z_9+MO$7A[]HCQ)I_@2R_
M:K\/>!_%/P@L-8N);&;1-8\$^&FO?'FC>,9-1M+.W\)7<)\<^'+;2&O9Y([R
M^4:;->1:J\=K<_V?P3D..I8O%6@IT,51G%3BVYQGAG"LJ;22O4C!UY--JT8N
M3NHV/X\XWQV&GE^'O4Y)T,92FXI12M4Y(N3MM[]2BV[:*HEV;^]_CYXEM[:X
MNP?."0[$FC5-T1;S&:UD0%UE=5$@1\E&4J3N<2`)^9?QA\%Z#\8O"3>'/$%C
M:7<&FZI!K>BW=[;?:H=-URRM]2M;.\:!\M)&UOK-[:7D"C=+IEU?0P26\]S'
M<Q?1/BR[\0>+$U$Z5=:?XBM=+-V^G7)UFR<7^F>:(T%O>SZK'975K!8I&(+B
M&98Y6B2*&64RQ)-\P7/C2Y@:2'5$CLF#SP2HZ/&[-;SF,1JKW#2!$<M"VQ`L
M;>0LC(@`7Q..\OQ*J*HZ-;V,J=2$;1<>;F5I1;337*VVGNTM.K/J?#W,HX&6
M&JX>K06+PN(P^+HN2IUHPJTY1K4INE5C*G47-"TZ=2+C).TD]G%^SS\%_A]\
M!K:]A\+:-I#^(-0N96U?Q)!IL=G=SHUE8VEQIUK.OFW]IH9N+".]33WO9LWL
MSW,TKR\CZH\6:NMC\-_&4S1,7GT+683*SK*IDO[06EM&C!\.3//O$8*JD*8W
M;P$;X]O_`(R>&?#<\%QK&M6EK;JD495%N'G21WE"(UK;Q2W13*.IF\K[,`'`
MD!*UP_[0/Q3\1?$KX(>(_$/P.?2_%5O\*+"X^)WQ!N3<M;:;IFC^%M`N]:AL
MM666^L+R=)(8+C4KO28);>_N;;2FDBD^UM8V]U_.?$63UZGL_91;UC",ZE5V
M4ZCC3IQG.2;@N9I/?=*VJM^_Y5GD,1BL5BZ\L/"K6G4Q>(]A3I4(2;?M*WL<
M/1C"G%VC)QA!16B2M8^?;O73#=7,*7<R)%<31HFZ3Y521E5>;9C\H`'))XY)
MZT5\9:9^TSX-U#3=.O\`6K=X]9O;&TN]6CL6NH[)-3N;>.:_2S1VG=+5;IY1
M;H\TS+$$5I9""Y*^>_U(SY:>TI:65E*ZTY5O[/7U\].E_4_UNR)ZK$3L[/71
MV?+NN;1ZO3II\_U;_P""N9)^%OA($DB/XF0",$Y"`>&_$1`0=%`(!`7'(!["
MO7O^#@R:6#2_V,KJ"62&Z.@_&W-S$[1SG_B8?`=>9D(D/RNZ\M]UF'1B"45_
MH'P?_#H?]AV:_P#J#6/XNXE_WNE_APG_`+B/YN=.\<>-=)B8:5XP\4Z8%+E1
MI_B#5K,*7U2;>5%M=QXW;FW8QNW-G.3FMKGQ-^)$L&MQR?$'QO)'Y\B['\5Z
M\Z;3I]R"NUK\C:1'&",8(C3/W%P45Y?'7^YQ_P"OU3_TE'N\-?[[#_KQ'_TI
MGE3^+?%5QHMM:W'B;Q!/:R2+<26TVLZC+!)<.C[YWA>Y:-YFR=TK*7;)RQS7
MZW?L-W%Q!_P3W_;ENH9YH;F\TOXNV-W<12O'/=65G\!K>>TL[F9&$D]K:S7E
MW-;6\K-%!+=7,D2*\\I8HK^:^(/X%/\`["L%_P"I-(_4LD_WN/\`V!8[_P!1
MY'Y%Z7;6[Z9ISO;PN[V-HSNT4;,S-;QEF9BI+,Q))))))))S1117MRW?J_S.
M`__9````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]A=F%T87)S+W1R:6XN:G!G````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`Q,#0U,B`Q,#4Q-30S,S<U,2`P,C,W-#4`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````_]C_X``02D9)
M1@`!`0```0`!``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!
M`0$```````````$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#
M``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H
M*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&
MAXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76
MU]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0``````
M``$"`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!
M40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y
M.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4
ME9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/D
MY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#^,2RTP:WJ5^UH"EI`ES?!
MV01JELLRK`D@C5H8FD\V-5080L"J,%'/O_P5L;7_`(2&U5=OGK,`/G.=R17(
M!^4\':2>!WY`Q7!?#>WL!9>(Y]0,L6C7XM=+:]>*.)P3;WMU&L08O$DYD^QR
M@?:`D4QM4D5T=9XN@^&NA>/=4\:^&-#^"OAOQE\1O'FLZS!HVE>#?#/A#6O&
M6MZUK-_.]AI6DZ'H&@V<^HZ[J>IRRRPVFG6(>YN+L)';B60!*PXSP;KY9#$1
MG3]OF-/%3J05E*E-U8J#<%\-"49.%*K=J7)*/2[W\-,1A\HS3#UJU*;PN!K4
M'.HW"551C44)JDJC@ZM:G*+G5I1DI+F3BG>R_KS_`&0+V\0Z+(+5$CCCMXI?
MDD,4S0PA)1:'S!(3"P5)_.)802PR1J'%PZ_O7\)]2E6*T,`CF:2.!)&79*'/
MDPF0JP"[A%N=<`!BBX(:0#=_)_\`L)?ML>%?%4D7A#7+7_A$_'FE*%?2IH_)
MAN=5^Q6]E=#3)+N_-W-.\]X62SE2*^:%YVF@BC*O-^POQ0_;5UG]EGPW_:$?
M@OQ#XEO+*W.HVZVVD11:'9LRWESIS^(-?O=2L]/T'31)IH75-0U%XS#"9KN"
MWOP3$W\7YQ2K8#.(TJ].IAZ[K0Y(*-IZR24J=[<T9):-6YHV=K'^H%1X'BOA
M>AC<LQ6%Q^#J81ISE)VAR4DYPK)7G2G3EI.FUS*U[-,_:/QK%#J&B7:W$,+-
M+!*@:2"&4QHPC5]@N(Y5!*\C?&Z$A"Z,JA:_@^_X+R_#.V\#?'+P7K&G:$]E
MIGBOP]K5_+-IZ016E_XAM-4AM[][2V6"T?SQ'<:<UV8V%K(EW#"EL]Y;:EJF
MJ?L[^S__`,%#?VE/VPM6\/3:Q^T!^S'\`_!<FLP:3JEUX5T37O%/B<ZGJ0F@
MTO153Q0=3\`WMWJVM6VDZ-;6EQJNFZ@8?$L4FE:;J6M?V5I5UY#_`,%J?@;K
M7BW]E_P7XYG>R\::K\./B5JMY)X@M=*FTZXU+POJ6FW-Q>ZL+1[F<6-Q/'I-
MMJ.IP:2MK:M/913VL<%I8V^FVWKY$JN2<=93C:V)HJEB9SH5E.4HU>6M0JI2
MJ1G!14U*TGK))Q:3T/R?/<AJYAX6\09/3A.>)Q."6)RZE2IUI4O:X?$TVJ6&
ME.G%5GRT91;@E*/-[T6GK_._X)_X)5?MS_$3P9X1^('A#X#>,M8\)^.O#&@>
M,?"^K6^D:H]OJGAWQ/I5IK>B:C`Z:>R-#?:;?6US$RLRLDJE6(()*_OU_9@M
MK/X<?LU?L\_#PZ;8RGP'\#?A+X,,EQX<U&>XD/A?P#X?T,O//%?V44TSFQW2
MRQ6=I'(Y9TM;=2(D*^CGXT9Q&I.-+#8)TXSE&FW33;@FE"[]CJW'EN[]7\O@
M:/T?\C5*DL2N)5B%3IJNHXC#J*K*,%544TFES\Z2:3LU=+I_G8_$SX2:C\,-
M4\>_#S6;@[M%\5>&;V"[*6BR:CH7B?1=1ET_60ME+/9HMQ:VVGW;6T!:6RFN
M7L;RWMKFUGMT^[_V0_V>M>LKC3?$^J-X5O/`=FUEJPO=:^'7PV\5VFH!1JES
M`NLZ3XWT/Q6NHP6VIO\`9X[:YLYH&0NKQ>04$??_`+7VF0W_`(0TN=M%L;E7
MEU+26UR6*T:_TM]0@WZ=IMO++ONT@N[WS;G$,26?VC3X3/<VMQ-9I<>*>&OV
ME=/\-_L]3^"+W4K>TUO3K6WT^:%II?M4S6NLN=C1+;2*#%&L>[:Q\SS&D&=C
M-7]L?2U\.\7X6<<T<FX=Q.,KY7-4)9?45*M1KX3!UZE3%8'#0KP<>;ZCAYK+
MX8RE."KRPE5\D*GM*5+^2OH%^(N0^+_`5;BSBZAEF"S:A1QD,PHXJIA<7@<R
MQV`AAZ6;2Q6#KNI"%+,\11GFWU2O3E'#K%X:FG4A[*I6YSX%ZW_PM[_@I)I'
MB/2%^VM\1_V@M=\0R>2UR#K4FOZU?ZAJFIR-J#I<0KK5VFHZG+9JUO\`8TN&
ML[&"VC2UA7^S;_@HG^R*WQV\")=^#+1K3Q!X/U73KRTU)8]%O(#H<-I)'#!J
MNF^((;FVO--FN[F!KY+,V>HR&*V"ZA96=N)HOX9OV%O$VH>%_P!J_P"`_B;3
M%9]3@^(FE16X1#YF-1E&GO*6".S^3#=7+;6C.5\WYHR[.O\`I#7OBR#PY-?2
MZJCW-A%I]Q!K;SR7$0M/-$;"[O"5N'2,QNLLMQ,"EM'+YDDJQD&OX6\172I9
MOE3Q$6E2P="3K/64/92KQO*5^:<^>4)-W;?LUIRIW_NGPJQ^:/+:F;993H3=
M;/.(7_9"IPIX7%0QBR6I.C[."5&'+AZT\/AU+EI\N(E!QEKR_EY^RG_P35LM
M,T+0Y/BAHFB:['X.\1:1XA\.217'B:74]!.FZYXMUZ&S\#ZKK?Q(\7#X9:1-
MK?B?6-4\4Z5\,K?P38?$2>_NXOB)8^+O,CN(/JG]JGX-^'?BW;>$/AA>V=M#
MX(\/:_:?$#QC=GR?LVE^$_AG:ZAKUW-<&_N;,-::CJ,&D^'+[=<3NMAKEU=R
M6%_';31I].Z!XXTC2-+U*VTVX6`O$ODK;W#SQL)#.[-N*SNZ,LSM$JRHL990
MAVJJK_-__P`%M?$/Q6\6>(/@!X#\.^)-?T7X;^*9?B1=?%2PTO76L-+UNR\/
MZA\.]7\*+XHT9;B$>(+>74[/48](TR]M+NTCU$W5ZX)M94.G`?#./\6O$'A/
MAG+ZN9YIF.9XB.'Q%:A2]O5PV#I.I.K+#1I*]*E0P2K5ZM>K)4*%*+G4J4X0
MDUAXA<74?![@OCOC_-\'DN0\/<-8+$8W*<NI4L/E5'%8W'+#X:G/$TJM.FL1
MB\7CJM#"4(I5J]?EH4*-*?+3I/G/'_\`P5"^/TWCOQK-X#\0^$;GP/+XM\22
M>#+G6?!%JFL7'A1]9O6\.SZLG]CQ;=2ET@V<E\OE1;;II1Y:8V@K\W#JU\"0
MK6!4'Y3)93/(1V,CB\4.Y'WF"J&;)VC.`5_O!AOHV^!6%PV'PR\,,CKK#T*-
M#VU:KCW6K*E3IT_:U7',(Q=6IRRG4<8Q3FVU%*R/^=W%_3!^D5BL5B<4O%/.
ML,L3B*U=8?#JC"AAU6J.HJ-"#RR3C1I*7LZ47*3C"$5=VN_9_BAX*C\=^`O$
M>A`*]_/:B;1E,EK$W]MVA-]IBK+=8CM4N[FU72Y;]GCCLDU'SII%CW!OPV\8
MZ+>6WB'5](U"SN;&9;D0:E%>Q&S?3+FQ*)JB7L-SY+07<=S'*DD4ZPS+<AD=
M&EW)7ZR_MA_%;4_A7\"O$<VA7%QI_B3QCJ6C^$="UG3KB2UU70)KS[3K%YJF
MG7<-Q;7=E+%I>E7EJMY:.)[6ZN;61&(!CE_(JRUW5KZSBU:YU?4M0\1ZA;S:
MAK%_J]_<7EY>S:RUQ<O=1W,\[WM],J7DPOB[S3+)%#,S,F77\9^GQF.08SB#
M(,HP4:KXHRW)88C,:T:D?JSPN+Q&+EEV%G2LZBQU",,3C(U$XP6'KTTTY2N_
MVW]FSA.),'PKQ)BLQG2_U2S7.)K)\/*E-XEXS#4\+ALVQ$:LFJ3P.,YL-@U3
M2Y_K.!JR4DI34OO'_@GC\$_A3X[_`&AO"UWJWQBO?`UGX=@U?Q+H@_M'P]H?
MB#4->T+3DO=-TO2FU:2>'4;V_P!1E\J#1;6QAOM5L[6_2TOK5HI[NT_N8^'W
MQN^%GB;P3#XD\4>,_"NI7FH^'4M/$NCWVJ:+*]A>?8[8:C9:CIEQ?3W%L\:V
MP-W#.9G9;S>T+)<6JQ_PW?LB_LJ:YXVUW3=>TR]\*7[WUA;7MCI::I)IOF;I
M5-O>VFHV0M;O2IK.XE^VI.)D2XN-+BB5+B86<D?]9O[)/[*FG_#/P[H^M^._
M`>AR>,;5-9MS<7D>@Z];6TMY/8F;4HM5\W5+C4-3OC9W#)?&>V_LZ"[N+"VM
MXA<7\U[_`(Q^(F*E7S)Q^NRK/#04*<90IR<)--5(WBE)Q3;NYQM>]GLG_P!"
M?AYPIPWA/#'#X_$XRIE.<8S$SKT<IP5&HZF)<II1:Q%=N%&%54<*W.DY24*,
M8I<Q]Q>'-.L)HWCL;J.[L9W$-I>2&)GD2*:6)A+*LC0%T9##YB2+`"A(VQX`
M_F\_X*0_%+1/B/\`M%:CI?A;4+K4-$^&OAZ+X=W!F93IDWBW2-?\1ZIXGOM-
M2.5O])MY=6L/"FJ33002?VAX5N80)+>&WDK^@#XP^&?&U]\!?C/X9^$E[<:%
MX[OOAKXTT7P5KNA7KZ5?^'O&'B'0=8M?#>IZ7?6<MI/I^J6^M7UK=V=]93I+
M97$27TDD?EAC_#Y\`/B/XL\;/XZTKQM>:SJWBC1-874KS4?$UY?W/B.^D\0:
MG?OXA?5I-1>:ZFO=/UI97N;F:47&=6BM;A7EMI)I/ZQ_9Q4.&8^+^.QV<5JO
M^L$.'\PPO#-*-H8>G6Q=*O5QM2O9\SJ5,KP.*I86":IOGKTY*4ITT?YT_M.\
MVXLK^"=#+,IY*V18GB/+,1Q54J/GQ4\%EE;"+`4*,HI4U_PL8G`8O'+24%3I
MN,5#G</>=[CLOYG_``HJP;1B201R2?\`6-_\117^X>O]/_@>O]/3_G\4Z6GP
M]/T\_O\`GW1X!_P4KDD7PK\+(5=UB?Q'K\KQ*S"-Y%L-.C61D!VLZQR2('(+
M!)'4':[`_GSX39AJOA<@D$O;J2"02K[4=2>X9&96'1E)4Y!(HHK_`#0^FQ_R
M?#//^P#AG_U0X0_U4^@G_P`F=X;_`.QGG_\`ZT.8G[R?\$E?FUB#=\V)D4;N
M<*EUI[(HST"D`J!PI&1@U_7QX?9O^$'\.'<V3!;9.3DY6Y8Y.><MR?4\]:**
M_P`G^-O^1UF7_7I_^ER/]QLC_P"2!X'_`.P:E^<C=\%`/\.=&+C>7BO&<M\Q
M9O[7N>6SG<?<Y-?P.:Q^X_X*)?M5QP?N4?XO_M(0ND7[M'AC^.+LD3*FT-&C
M1QLB$%59$(`*J045^_\`T%_^4A^'/^PC#?G7/X/^G=_RCSQ[_P!AN9_^F8'O
MB]!]!_*BBBO^@@_YWET^7_N,_]D`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V%V871A<G,O:VED+F=I9@``````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`R-S<W(#$P-3$U-#,S-S4Q(#`R,S4T,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!'248X.6$O`#``]P`````````S
M``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,
M`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S
M`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,
M,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS
M,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,
M9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS
M9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,
M9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68S
MF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,
MF<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,S
MS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,
MS)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S
M_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,
M_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S
M__]F__^9___,____^+\D````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````(?D$
M`0``V``L`````"\`,```"/X`L0D<2+"@08(`$AY<R+!AP80E(D*96$*APXL.
M`4S<R)$B`(P@'W8<N?%CR)`:H40$4`4/GBHE5)8\"3)EQ1)X`)30HS.E2IH7
M=7J$@J<B3Z$4@39$.I&E'P`O(6XLH91A3(Y.5_BIHO,J%)-5#?KD6$6/'I42
MFX8].)9CVI%@UPKL&K&NW;LKY0Y<(;,NR;=YY8XM<>"`UXD(6+!`X%:OSQ*+
M"U\M@:`P@@>,9RY-&!?A5!J!$K)HD7@%YP,LO'[40\KD"H2<XRJT>:"%:0`'
M:(`^*MJK0#W)JCPAE2S/P-A@9^M\4F4%"\X(6M!`@)R%X8@"GR1+!KSX<>38
M+/XF[$XJ<>$6>JH<J$Z*E&F!5;8#?PT[_,?9X;<3U^.<?.7U`(Q&G'L"K4"<
M?D_,Q9E]RN47W'80DJ*=>XJ-9M9VMR6D7WL,)M<@`,F0TAV$W$&87G=5$,?5
M0"$NN*!8LP$7'XDTTDA*?+?!IR"#,(*U`G<SUB@DCO;55R1LLLDXHI`1EF62
M;!;!*):,*3()816>)#C70YTIV&5X\=T89(UEK7@D1E$^M%.(551)8IE/IGG2
M"EHJ6`*6(J979G-Q?@D2<4\\89I67.E4EEE\&JD4`!.Z=X`?J*!2!0M0(&#I
M>CWZV="$0,84J:2ZZ0;!<VS)B9%V\JV`&J1^D*287MX$L;9=6LZ%:FL+7VFJ
ME';JC8;K1BW\"H5U*<+*8C*FL0"!;L'BJE@++.AAC35F&3O<"GQ"8>L#%:VP
M0BFKK"*M'L:&)^T30JWTQ"K4ELDNN>4^,>TJ@F++[K36T%O*M._!RA*^``><
MK[P\04'?6@"L(/"\X0(L'$PQ';RH2O?F*^X*%25<UBJEE!((QFJ5BM^6<S75
MTUW?0225P6C>E]QA9-7Y&$=/^-'RF=BL4)1=;=89'LQWHN(S0_>%AQ`>?B2M
M=)?88DPGJ[H>9W1G"=6,[D).H<+JU>4&5:^F`0$`.P!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]M87)G92YG:68`
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(Q-3<@,3`U,34T,S,W-3$@
M,#(T,#4T`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````$=)1C@Y82``(`#W`````````#,``&8``)D``,P``/\`,P``,S,`,V8`
M,YD`,\P`,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`
MS```S#,`S&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S
M`)DS`,PS`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\S
MF0`SF3,SF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S
M_YDS_\PS__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F
M9@!F9C-F9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9F
MS)EFS,QFS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9
M,P"9,S.9,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9
MF9F9F<R9F?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,
M``#,`#/,`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,
M9IG,9LS,9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,
M_P#,_S/,_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_
M,YG_,\S_,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__
MS`#_S#/_S&;_S)G_S,S_S/___P#__S/__V;__YG__\S____XOR0`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````A^00!``#8`"P`````(``@```(_@"Q"1P(
MH*#!@P@3`AC(4"")`1`C2IPX4<#"A@,?4MQ(,0#&A@$XBH0H@,1'AR-'6CR)
M36/*C1Y98@NY44```1!OVB1I\B0)G!0%K!BE`H"*449'W030\^3-B4F;$1TU
M%>E*F3,E!J#J9-0*HT.]&L0*@*(*J4]87;O&:H4*5FW_-/WHDN31%6K7LEVQ
MEI4*K#.!#@CPIZA>O7BML&(*F";$HV^MZ&T+E]5<GQ(%W,V[%^QEIT"CCDK+
M]LFH9E(_.QT`X#1JJ6Z'OB9*XJ],C49?HW;]6L71U+<AMA[E9/?OV:=I8WT:
MX'A1W]"9DE#]42>)WKRI4K]=4/=L%=L!35_WWLPV8);CO8<73X+WZ^GGZ4*J
M[;X9"3;K?9*`-!_R4<;Q833=?I"HP%]1^`7(D&Q$^:><@@.=1=YN^7UT5'VS
M50A2020PI=!%)P4$`#L`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]A=F%T87)S+W!I8V%R9"YJ<&<`````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P-S<Q-R`Q,#4Q-30S,S<U,2`P,C0R-#4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````_]C_X``02D9)1@`!`0```0`!
M``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!`0$`````````
M``$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&
M$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ
M0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66
MEYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3E
MYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0````````$"`P0%!@<(
M"0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(
M%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*
M4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.D
MI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T
M]?;W^/GZ_]H`#`,!``(1`Q$`/P#^F7Q_]OGL--UJ33KK3I]+UBT,ANXRJQV]
MM_'YL9<$/SGY?E]6ZUX3^VK^T#JWP=^&WANS^&.GZ+XI^.OQJ\1Q?#3X!>#+
M^:`&]\?W46JZY=^/?$<<<=Z#X&^&_@;PSXI\8>)=0NTL[>%;+0=$:>VU'Q7I
MQ@^K/BUXH\'>%?`_C'Q7X[UN32/`GA;P5K?B?Q/J4$5V+?1]-\/:-?Z_JE]J
M4]G:ZK]D%MINEWLS*4?/D@;@6K\BO%'Q'^*OC@^-_CKX\^%S^#]7\)?L[0>(
M/@W\-;9_'Q^(.C?##XH^,M>U>\\/^,-7>Q\FR\>_$+4_@S\.]1UU-,TV6Z\*
M76G>$](U][/3_$VL0VW^>>+QM/+\M>8U:=:O-J:A*%6:]]QM3;L^7D52W,DK
MN"E:2;37]EY+AGFV8PP_+"G2<HW3A&S2E'F5W:5VG;LF]5JD_I;]ECP?H/P;
M\(WG@VSU2?QSXR\:3ZAK/Q?^(WBB*5-6^-/CV>^NWU+Q)XI^U>1-?^&TUG5-
M8/AKP9IVI::GAF33;'P-_;NI:/<+/!AZ_P##W3/V7-9U/X]?"74M<TKX(SZG
M>:A\;OV>M(\-ZIXG\,:/IOBG4+B#Q=\4O@EI>FZGHOBCP=JOA?2;6_\`$_Q"
MT?P9J&J^'?%_AWP]XJU+1]&\/Q:/8R:W^5-E_P`%#/B+\$OB!X=TC]I7X,>$
M=*\"7.E_#<^-/$7P@\27FK:A\(]?^,_ACQO\3/"O@7QCI/CF#PX-,^(-CX1^
M'?BG6_$FB>'=4\3Z5HFN^&;2_G\1.WBVRMK7J?A?_P`%/OC1^UM^U=IOPP_9
MPNO!_P"S]\-V\/:YXN^'GBKXM_#WQ%XGO?C_`*AX?NM2U<Z'HVL?VIHOAKP5
MX?\`$4?@[5O%_AG2X+Z?6(M=\.7^H6ND>+YO#^FS>&?BLBR3Q7EF+Q^(4(9:
M[UN5UZ-:+C>ZY9P<^9.VB4[)-R:Y;M_0\497E6`G[++H4U5E&/-RRE%.Z2;:
M:G9J+;344[J*;2M;^A7P#XDT;Q7IUGK'@G7].\7>&O%^G:;XM\):_H^M:7K^
MB^*=#U&SLHTO]/O-+N[NX\2Z4_VT>';6;4K6?6'\#Z=J5C>:)I]W9KJ\^CJ%
MKJKQ2PZQ*@8PW4-NO!^S_9OXO/R/,W],;4V^K5^=/P9^(T7PL_;@^-GP.O\`
MPP]G\/OC5X^^%GQ&\-S:!XBBO=#\._'+QY\`/'7B7XC:<VD^(-:_X2#Q+8>+
M=`^#OB>^@M=-\,IH:1?V[K/]D:)*)[2+]4+ZPL;Z,PR>9<1?Z5QDH_\`I/\`
MMC)^3I_M=\5^G4YXJIR8N=237JDK)V:5DD]K<SNV[W:V7Q&&BJ&)E&I"-I<N
M\$I2M&.ZU2:=W:-DM7:^I@QC26CC9Y&W%$+?Z1%]XJ"W?US15-?`VD%5)CF)
M*@D_O1DX]/.X^E%>DLXH:>Y+I_R\G_=\_)_=]^5Z5]GO_/+^[_>\E]WK;G?B
MAX'TCXB_#;XD?#[Q58Q7?AWX@^`_&O@SQ)87;WEO;ZGIOC/1K[0;DW,.F7=N
M9!:Z;J=]#Y8=#<>=D26Y4&OY@O\`@FK^T!^TMXQU7]FSX=?M":?XHU+[7\"_
MC/J>@>--<AT/5M%\=?"J_P!1\`2>!_%<VLZ;?WUS<:EX#\>_#>TCUJ?681J&
MC:A^T'I7AWQSIA/B'2]2G_JSGFEBMQ)Y4L4?D^4P@")N_P!K]Y)-VZCGZGM^
M&?P'\'^*OAE\=_VU_`GB#P5J6B1:%\;_`!U\1?!&LW-S<:;H$OP>^.=[H_B7
M3='^%=[::[$8K+P_\0_A]J_A3XKZ#IEC;Z?IFN:]X3\6ZLOBU='\,>'=/^!S
MC.J&!X-XAI2P7UVK@$IT)72E2<K4ERW^-<]6,I1Y92:CSIPY'./UO"U%RQZG
M.JJ-3:]DG92BKJ*>Z3T:3=[):\J?A-SXBF\;_!OQC^Q!<?!_5[_]H_QO^U5\
M2]6\<?%#XJ_"V\71_A[X&\:?%C6;.;]H5/$/BG2[NTUWXE_\*.O]*^&GPR'A
M:_\`^$P%Q'8ZU:W=OHV@^)"_UO\`LO:%\=_AYK7AW]G70/%7PLLO@1^R7X_\
M4V'AJX\W6]?^.OC;P-\3?#7Q&'P,T?QA<S:7:Z-<6<_A#QI)J3^++<:?J_B[
M5O!VFZ)K$ZR:CXEO]6X7XA?M!>&OAC^TE\&?@M?ZY#H=EX@T:_?Q+>S:3IUE
MX,@\<^*M1GT/X!^"?%GB8:EH1\`R7NL^$?C-XI\#7%M>7OB77/$7@N+7M)DO
M-6UG4]0O;/Q(\?P:;^W/\&O$OPR\6WWB;PK::/X0^#/[77@[P9J^GVO@OPG%
M\5O&6K?#WX'R?$C7KF[59OB!I7Q$^*6F:EX,\&*=.\0Z7IOA/5?#MS+9QRVF
MI-XN6<2<5YS@<LP<*=3+<+BJ;JSBYM>UNWR.ZC>"O94XQ22C*,KJ$N9?1YWD
MV$PE1XEM8BLE=\LY36R<TH2G9)KFBKZ<TK23:LZ/A&TU+P5_P5'\*ZW>_$?P
M\EW\7_&GQIL9OA?J,O@S4H/"7PY\&_LN?"S3]$UB'61/XD\1>'_%_BC5K&2=
M[[2=9TUCH&E>+/"NG_9QXG\6ZOJG[OPW+9_=DQKV:6,)G_QXC_)SQFORD\1^
M$?"EE_P4<_9!^(#Z:;GQGXY_9N_:<\,:^;=-1L=%.O\`P>N/AT;+Q-=^';"P
M:4W.E:3XN^*7@F?4KC5K%=7N/$?A>8"`V\5A+^I5E%`EMM1Y;I^>6N/,(QUX
M*K].#^&*_1\!0Q5#)\`L57CB%6_B6C"+=K12;A&-G9)MQ>M[MN5S\WQMJN,_
M<Z.R;27?KKUO>^B?DM+=$M_)M7YH>@_A]J*S0L``'E-P`/\`6'M_P&BNKZK0
M_D_\FEY>?E^+[GG67]?+_)'*17D4Z9F@0Q_\\"K]O]O?[]?+Z?6OSK_;EU[4
MOA=XV_9?^/\`?WEPGP;T3Q)\0/@'\=;R&SL]2U?2?"_[1<_@.W^%?CA7$5M%
M:-X5^,/@OX?O-<36LT=E9ZAKT]W>.MQ.LGZ&CS?M.T!D3_IJD<8X]1YK=NV:
M\Y^)_P`,_"'QH^%GQ"^%'Q`T^;4O!_CGP3J/A7Q)I^F$'58(]7AE:PU33U(S
M-J4.IK>:MH]PAADTF[TZ`QO,VV1/@(5*.&HXG#8O#_6</C[+%4VM9J6CY9:N
M$UJXM62=G9JR/I:DI4:\<12;ITTU*\6]]K/5-WUT36KZ]?R?\/>$=%\=_M2?
MM;^#_'_ASPSXFT:\\`?LBZ7:^%8=.L-?T:]T+1O"/QXBCT73[&\6XCU*PT;Q
MSI>L7+PQ:[:0V46NO-JMAKP\*^%3I7K7C;X,_#CX8_"GPKX0^&?A2P\#6MW^
MU!^R+X@U73-(M$O]4GUZ7]MWX+:G<^(=3DOX]5NM<F:VL?$(UOQ+XIU#7GDU
M'1]'TGP=KNLQPF\UCYL\,?#GXG:!^T!\5?A'\1OB=K_A[XAZ7\$4\)^$?B8F
MI:-K7B'XF?!/PSKGAVV^#WQET#5_&>ER>$-*^*_@I?B)\1O!/[1K2'4DT#6_
M%WPYU'PTWC@>-=*MD]BU_P`$:I\,O!O[/7[-7P3^($^G^*/'?QI\,:'-XB\>
M>*/%_P`4/'NH^$=,\':YJ'Q9\9ZQ:S>)/#=_X5\0>#M:'A[XE?";7KV2;PAX
M+\06WPCT^Y\/>&O$OB&+2+KS\+EU6'$^3T%C,53P'[APPWLY3@X0I)*;J+FF
MX1DE",(N22YH25-0Y9?<XJIA)8#ZRJDI*<>;F3Y8IKEC[TI*ZO%-M2<KJ.FK
MC?Z#_9MO+?XX_M-?M#_M':;J!M_"7PV-Y^QC\#K^S;69K;6;OP[XA_X61^T[
MX[U(20"&YL/$_C^^\.>`M.NK(Q1W-]\-+V"/4)5B,,/Z&0F)T\Z=!'_TQM92
MG_CP5B?3[O>O'/@E\+/"OP#^&7@WX1?#NW72_!WA'PI8^%_#ESJ&H7-_/K&F
M:$=1U*Y\2ZOK2.'UGQ+XJN]>G\8ZO<26MO/+K.MW;R3W.U7/L-E;Q1=$V<_<
M:7?^1(7C\*_3\32IY94HX1WJX>E;V,+NZT6[5VV[W>KUO=MZGYUAZ<75G4>L
MG)V=VM&M-.FWWW:M>QJ_;[;^_P#R_P`:*S2]J22(!R2?O'_XBBNA:I/N9>PI
M?R+[Y?Y^7]79R]LJR`^8JR<#[X#>G][-1^(Y)+8^&9K:1[>9[;3P\T#M%*PC
M&H&,-)&5=MADD*9)V[WVXW-DHKX*KM'U7YQ/0Q7^YKU_1'XS_MHZGJ4/_!8;
M_@F?X=BU"^B\/ZQ\+/VJ[/5]"CN[A-&U6TD76=1>UU+3%D%E?6SZAIFG7SP7
M4$L37FGV5T5,]I`\?R=XI\7>*X?^"Z/_``3\T2+Q/XABT6?X,>/M,GTB/6M2
M32YM-_X6Y^U%IO\`9\NGK<BTDLO[.\-^';#[(\)@^Q:#HMKY?D:78QP%%?<X
M3_D=9+_V!_\`N6H=E3_DFH_XY?\`I<3^F:PCCC\3ZO:QHB6UM)I8M[9%58(`
M^D:=$PAA4".+='&D;;%7<B(ARJ@".Y)%U@$@<<`D#OVHHJLX_P!]7^+]#RL)
MM]W_`*2:+`9/`ZGL/6BBBG'9>B_(D__9````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V9E;6%L93$N:G!G````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,#<U,"`Q,#4Q-30S,S<U,2`P,C0S
M,#0`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M_]C_X``02D9)1@`!`@(`3@!.``#_P``1"`"^`)8#`1$``A$!`Q$!_]L`A``&
M!`4&!00&!@4&!P<&"`H1"PH)"0H5#Q`,$1D6&AH8%A@7&Q\H(1L=)1X7&"(O
M(R4I*BPM+!LA,30P*S0H*RPK`0<'!PH)"A0+"Q0K'!@<'"LK*RLK*RLK*RLK
M*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RO_Q`&B```!
M!0$!`0$!`0```````````0(#!`4&!P@)"@L0``(!`P,"!`,%!00$```!?0$"
M`P`$$042(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B<H()"A87&!D:)28G
M*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@X2%
MAH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35
MUM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^@$``P$!`0$!`0$!`0````````$"
M`P0%!@<("0H+$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R
M@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(
M24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JB
MHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR
M\_3U]O?X^?K_V@`,`P$``A$#$0`_`/JF@`H`*`"@`H`*`,7Q/XJT'PK:BX\1
M:O9:=&R.Z"XF"O*$`+;%^\Y&1PH)Y''(H`XNT^//PUNKJ&WB\3QK)*X13+:3
MQH"3@;F9`JCU)(`[F@#O]%UK2M=M7NM$U.RU*V1S&TMG.LJ*P`)4E21G!!Q[
MB@"_0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`'S'\:OVCX[3SM&^',V^]BF
MV3:NT:/$`N"1"#D/DY!8C&`=N[<&`!\I7=S/>74UU=S23W,SF2665RSR,3DL
MQ/)))R2:`(J`"@#UCX?_`![\:^$[H"[U"37M/=]TMMJ<C2/R5SLE/SJ<+@9)
M4;B=I-`'UE\+_B[X7^(%K;1V5['9ZVZ`RZ7</B56PQ(0D`2@!&.5S@8+!2<4
M`>B4`%`!0`4`%`!0`4`%`!0`4`%`!0!\Y?M0_&#4?"UTGA7PK<QPWT]L6O[I
M.9;8,1L6-@WR.5#$Y7(#H5(/(`/CZ@`H`*`"@`H`EM+F>SNH;JTFD@N87$D4
ML3E7C8'(92.001D$4`?5OP$_:"M9+"+0/B)?^3=Q;8[359LE9P2%"S-_"PS_
M`*P\$`EB",L`?3E`!0`4`%`!0`4`%`!0`4`%`$5W<P6=K-=7<T<%M"ADEEE<
M*D:@9+,3P``,DF@#\R_%6O7WB?Q'J.MZK)OO;Z9II,%BJYZ*NXDA5&%`R<``
M=J`,J@`H`0]*`$#`^QH`=0`4`%`'TY^S3\;8]/ALO!WBZ?;:+YGV35;JZ1([
M9%0%87W8POROM8L3EE4#&,`'UE0`4`%`!0`4`%`!0`4`%`'B7[5WCQ_"G@,:
M+:12?;O$*2VZS#;LBA7:)<Y!R65]H`'\1.05&0#X>H`*`"@`H`:5!H`!G/4X
MH`=0`A('6@`'(H`^TOV1/'?]O>#I?#.H3[M2T7'D;WRTEJQ^7&6).PY7@!54
MQ"@#WV@`H`*`"@`H`*`"@`H`^!/VBOB+:_$/QO'/I#7/]C:?#]FMO-8A93N)
M:4(?N;LJ.>2$4G!^4`'EE`!0`4`(3@4`(`3R?RH`-PS0`H(/2@!C_>H`<G2@
M#IOAWXPU'P-XML-<TN20-"X$\*/M%S#D%XFR",,!UP<'!'(%`'Z0:3J%KJVE
M6>I:?+YUE>0I/!)M*[T=0RG!`(R".",T`6J`"@`H`*`"@`H`^0_VC_CE_;/V
MKPGX+NO^)5S'?ZA$W_'UV,<9'_+/L6_CZ#Y<EP#YMH`*`"@!"<#-`#5R3DT`
M*QP*`(Z`%7[PH`5SSB@!8^AH`?0!^@'[,]S/=?`_PQ)=3232*DT8:1RQ"K/(
MJKD]@H``[``4`>G4`%`!0`4`%`'P]^T5\3?%FI>/-9T$W%[HVDV#RV0LH97C
M^TQG@R2]-XD7!`/RA2,9R68`\2H`*`"@`H`:_3\:`%`P,4`,8Y/TH`0<F@!Y
MPHXZT`,ZF@"0#`Q0`M`'VW^QSJ%U>_"6:"YEWQ6.IS06Z[0-B%8Y".!S\\CG
M)R><=`*`/<Z`"@`H`*`"@#YR_:8^"L_B.2Y\8>%(Y)M95%^W6()8W2JH4/&/
M[X4`;!]X#CYN'`/CZ@`H`*`"@!",B@`YH`BH`4'!H`.IH`>HP/>@!U`!0!]M
M_L<Z?=67PEFGN8MD5]J<T]NVX'>@6.,G@\?/&XP<'C/0B@#W.@`H`*`"@`H`
M*`/SJ^.>E3Z-\7_%MK=/&\DFH270,9)&V8^:HY`Y"R`'WSUZT`<-0`4`%`!0
M`4`-*B@!-GO0`X`"@!:`"@`H`_07]G'3[K3/@IX6@OHO*E>&2=5W`Y225Y$/
M![HZG'49P<&@#TF@`H`*`"@`H`*`/@3]J'_DNGB;_MV_])HJ`/+*`"@`H`*`
M"@`H`*`"@`H`*`.O^$_@R?Q[X\TS0XA(+:1_,O)4S^Z@7EVSM8*2/E4D8W,H
M/6@#]!=:UG0?!F@)<:K=V6D:3;((H@Q$:`*I(CC4=3M4X102<<"@#Q'Q+^U1
MX:LO,C\/Z-J6J2I,4WSLMM$Z#/SJWS-S@8#(IP><$8H`\[N_VJO&#74S6FC:
M!%;%R8HY8IG=5SP&82*&('4@#/H.E`'OW[/GC_5?B-X,O=7UNWLH+F'4'M56
MS1E0J(XV!(9F.<N>_I0!Z=0`4`%`'YR_&;Q/:^,?B=K^N:>N+*XF5(&R?WB1
MHL:OR`1N"!L$9&<=J`.+H`*`"@`H`*`"@`H`*`"@`H`]C\`?%FR^%>C:KIWA
M+2(]3U:[>,S:Q=SN(9=G9+?:K!!N<*2P8[MS`?ZM0#S'Q+XAU?Q/JLFI>(-1
MN=0O7R/,G?.T%BVU1T506.%4`#/`%`&50`4`?27[%&O6-EXC\1:)<R>7>ZE#
M#-;;BH5_*W[E&3DMB3<``>%8\8H`^O*`"@#YM_:C^,/]D0W_`(&T!<ZA<0^7
MJ=S(GRPQ2)GRT!ZLR,,MT4'CYCE`#Y#H`*`"@`H`*`"@`H`*`"@`H`*`"@`H
M`*`"@#J?A;XJ_P"$)^(&B^(&B\Z*SF_?(%W,8G4I)M&1\VQFQDXSC/%`'Z2T
M`%`'R'^TS\)_%>H_$#4_$^@Z7<ZKIMW#`\GV95:2)PHBV",,7?A%;(7`#?[)
M-`'@6N^'-;\/^1_;VC:EIGG[O*^VVKP^9C&=NX#.,C./44`95`!0`4`%`!0`
M4`%`!0!WWQFMO[(UW1O#C:?]@GT+1K6UN$\[S=\[J;B5L\@?O+AQ@$CCC@@`
M`X&@`H`U="\.:WX@\_\`L'1M2U/R-OF_8K5YO+SG&[:#C.#C/H:`-3_A7/C?
M_H3O$G_@KF_^)H`MZ7\*_'FIW\5I;>$=;263.UKFT>",8!/+R!5'3N1D\=30
M![1\)?V:M335;#6/'<MM;06TRS?V2@6=IMK'Y96Y0*2%.!OW*Q!VF@#ZRH`*
M`"@`H`X;QY\*/!WCB22XUW1X_P"T'1E%];,8I@2H4,2O#E0JXWA@,=,$@@'S
ME\8OV<_^$2\.:EXA\-:M<W]E9[7>QN(-TR1<!W\Q.&P?F/R*`N23\O(!\[T`
M%`!0`4`%`'L?[*7AK3O$?Q6C;5%D==*MCJ,"(^T&9)(PA;')`+[L<9(&<C((
M!Q?Q=\2IXO\`B5XAUN%HWMKBY*V[QHR!X4`CC;#<@E$4G..2>!TH`Y"@`H`Z
MGX9>-+[P!XQLM>T]/.\G*3VQD9%N(F&&0D?@1D$!E4X.,4`?HWI.H6NK:59Z
MEI\OG65Y"D\$FTKO1U#*<$`C((X(S0!:H`*`"@`H`*`"@`H`*`/S_P#VA/AX
MGP]\>26^G0R)H5\GVBP+,S[!T>/<0,E6[9)"LF22:`/,:`"@`H`*`/H+]BMH
M/^%D:RK1R&Y.DN4D$@"*OFQ;@5QDDDK@Y&,'@Y!`!\^T`%`!0`4`?7G[&OC?
M[=H5]X-O'_?Z=FZLN.L#-^\7A<?+(P.223YN!PM`'TE0`4`%`!0`4`%`!0`4
M`>+_`+67A?\`M[X5S:A!#OO=&F6Z4I;^9(8C\DB@CE5`82,>1B(9Z9`!\,T`
M%`!0`4`>Q_LGZ_!H?Q?M8;H1K'JMM)8B624((V)61>OWBS1A`.,EQ]"`<A\6
MO`E]X`\8W^F3P7/]F^<WV"[D1MMQ%@,,.54,RAU#;1@-D>E`&?<^!?%%KX27
MQ/=:'>PZ$SH@NI(]H.X`JVT_-L.0`^-I)`SGB@#FZ`"@#N?@9JL^C?%_PE=6
MJ1O))J$=J1("1MF/E,>".0LA(]\=>E`'Z*T`%`!0`4`%`!0`4`%`%#Q#I4&N
MZ!J>D7;R);7]M):RM$0'574J2I((S@\9!H`_,"@`H`*`"@"UI.H76DZK9ZEI
M\ODWMG,D\$FT-L=&#*<$$'!`X(Q0!^DO@;Q=I'C?PY;ZUH%QYUI+\KHW$D+C
M&Z-U_A89'L0002""0"7QGX:T[QAX8U#0=961K&]0*YB?:ZD$,K*?4,`1G(XY
M!&10!^<'BK0;[PQXCU'1-5CV7MC,T,F`P5L=&7<`2K##`X&00>]`&50!:TG4
M+K2=5L]2T^7R;VSF2>"3:&V.C!E.""#@@<$8H`_42@`H`*`"@`H`*`"@`H`*
M`/RQH`*`"@`H`*`.T^%/Q%U?X<>(UU+2F\ZTEPEY8NV([E!V/]UAD[6QD$GJ
M"P(!^@'A'Q3HOC#1EU7PWJ$=]8L[1F1`5*L.JLK`,IZ'!`X(/0@T`>;?M&?"
M5_B)HUOJ&BF-/$6FHPA5@JB[C//E,_4$$$J2=H+,#C=N`!\1Z_HVH^'M9N]*
MUJTDL]0M7V30R#E3U^A!!!!&00002#0!0H`_1#X)^/K'Q]X(L;J*]^T:O:PQ
MPZG&ZJDB3[?F8J.-KD,RD<$9'!!``.^H`*`"@`H`*`"@`H`*`/RQH`*`"@`H
M`*`);2VGO+J&UM(9)[F9Q'%%$A9Y&)P%4#DDDX`%`'KWP\^&WQBT*Z@\0>$M
M&O=-N71XPTTL$3LI."KPS,#C(R`R]E8=C0!]H^#[C7KK0+67Q7I]E8:LR*98
M;.X,R`[03G*C:=VX;07`P/G:@`UKPGX=UVZ2ZUO0-)U*Y1!&LMY9QRNJ@DA0
M6!.,DG'N:`/,==_9K^'NI>1]CMM2TGR]V[[%>%O-SC&[S@_3!QC'4YSQ@`BT
M7]G'P[H5T]UHGB?QCIMRZ&-I;/4(XG9202I*Q`XR`<>PH`])M/#NJ074,LOC
M/7[F.-PS0RPV(20`Y*MMMPV#T."#Z$4`=)0`4`%`!0`4`%`&!\0=0NM)\!>)
M=2T^7R;VSTRYG@DVAMCI$S*<$$'!`X(Q0!^:%`!0`4`;7A'PMK7C#65TKPWI
M\E]?,C2&-"%"J.K,S$*HZ#)(Y('4@4`?47PZ_9=TRQV77CN^_M2?G_0;)VC@
M'WA\TG#OP588V8((.X4`>\>&/"N@^%;4V_AW2++3HV1$<V\(5Y0@(7>WWG(R
M>6)/)YY-`&U0`4`%`!0`4`%`!0`4`%`!0`4`%`'@7[8WBK^R?A_:>'XXMTNN
MS?.[+E4BA9';!R,,7,>.",;NAQ0!\74`%`'OOP5_9]U?7]5AU+QS87.EZ#%\
M_P!EF_=SW9#$;"OWHUXY)`)!&WKN4`^O?#7A[2/#&E1Z;X?TZVT^R3!\N!,;
MB%"[F/5F(499B2<<DT`:E`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0!\2?M#Z/
MXS\8_%35;RS\+>)+C3;3;96;C2Y-I2/[Q5E4AE:0R,&R20PZ=``<_P"%_@'\
M0O$'V:3^Q?[,M)]W[_4I1#Y>,_>CYE&2,#Y.X/3F@#ZH\`_`KP7X1_LF[_L_
M^T=<L,/_`&A<._SR\_.(MVQ<$_+P2N`<EANH`]3H`*`"@`H`*`"@`H`*`"@`
MH`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@#__9````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V%V871A<G,O9F5M86QE,BYJ<&<`````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#(R,34U(#$P-3$U-#,S-S4Q(#`R-#,P-P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#_V/_@`!!*1DE&
M``$"`@!.`$X``/_``!$(`+X`E@,!$0`"$0$#$0'_VP"$``8$!08%!`8&!08'
M!P8("A$+"@D)"A4/$`P1&18:&A@6&!<;'R@A&QTE'A<8(B\C)2DJ+"TL&R$Q
M-#`K-"@K+"L!!P<'"@D*%`L+%"L<&!P<*RLK*RLK*RLK*RLK*RLK*RLK*RLK
M*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*__$`:(```$%`0$!`0$!````
M```````!`@,$!08'"`D*"Q```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&
M$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ
M0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66
MEYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3E
MYN?HZ>KQ\O/T]?;W^/GZ`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)"@L1
M``(!`@0$`P0'!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC
M,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:
M8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*S
MM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:
M``P#`0`"$0,1`#\`^J:`"@`H`*`"@`H`S-4\0Z+I-PL&JZOIUE.R[UCN;E(V
M*Y(SAB#C(//M2;2*4)2U2+]O/%<V\4]M*DL$JAXY(V#*ZD9!!'!!'>F2U;1D
ME`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0!XS\8OA+=>)M6FU[0)X!>
MO$HFM)<KYS*I`97)(#$!%"X`XR2*SG"^J.RAB5!<LCP66#7O!/B*%Y8KK2M6
MM6WQLRX/!*Y'9U.&&>589ZBLM4SMO&I'NCN_#7QR\3Z==LVL^1K%JW6-T6%U
MX/W61<#DC.0W3C'6J51]3&>$@U[NAZ?X.^-WA_6MT6M+_8ET952)9',L<@/?
M>%`7!Z[L`#!SUQ:J)[G-4PLX_#J>GV%[:ZC:1W6GW,%U:R9V302!T;!P<$<'
MD$?A6AS--.S)Z!!0`4`%`!0`4`%`!0`4`%`!0!YW\7/BUH/PTM85U$27FK7*
M,]O86Y&\@`X=R?N(6&W=R>N%;:<`'S;=_$_XW>+;6:]T:SU:/2;U"B?V1H[-
M$!C8WER[&<'(/(?(.<$8&`#@+;X9_$/7]997\+Z_)?7;O(\]];/$';EF9Y9<
M+D\\L>2>Y-`%O4OA+\2?#%U971\-:LER'\R"73L7#Q,A!#9A+%""003CIQT-
M`$W@SXT>,/#VHEM0U2ZU_2IR%O-.U28SI<1X(*AGW%,ACR."0-P8#%`)VU1[
M?\./$?PD^).HM#J/A^#0-=DV@6LEVT4,Q+;%6$HRJS?<RNU22QP&P34\D398
MBHE:YH>-_@+):VGVGP?=SWDB[0UG=L@=N3EED^5>./E('0G/05#I]CIIXN[M
M,\[\$^*M:^&WB*X+6+J[JL=U8W8>,E<A@<<8;&<,0<!CP<U";BSHJ4XU8[GU
M%\/O&FF^-M%%[IY\NXCPMS:LV7@<]CZJ<'#=_8@@;1DFCS*M)TW9G3U1F%`!
M0`4`%`!0`4`%`!0`4`?"G[6>E3Z?\9]0NIGC:/4K:"ZA"$DJH018;C@[HF/&
M>"/H`#[ATG4+75M*L]2T^7SK*\A2>"3:5WHZAE."`1D$<$9H`M4`%`&!XQ\&
M^'O&5@MIXFTFVU")/]6T@(DBR5)V.N&3.U<[2,@8.10!\A_&KX`:GX-\[5O"
MPN=5\-Q0^;.TC*9[7&`Q<`#>O.[<HX`;<`%W$`E^!7QZU'PI=66B>+;F2\\,
M*BP12%-TM@`3@@@;G09P5.2`!M^[M8`^MM8\.>&O&%C%<:A86&I0W$*&*[3!
M9H\[EV2K\VTYSP<$$]C2:3W+A4E#X6?.WBGP]KWP>\6P:MHD[R:;(Q6"X896
M13R89@,#.![9QN7!!"XM.#NCT(3C7CRRW/;OA7\0[/QQIA1PEMK5NH-S:@\$
M=/,3/)4G\5)P>Q.L97..M1=-^1W=48!0`4`%`!0`4`%`'@7Q6_:0TCPQ?MIG
MA.WMO$%WY)+WB7/^C0N1\@!4'S?5@"H'`W9SM`/._"GQ$^-_Q)UF23PI)':6
M+.$>2.QB6TML;`W[R568GY@Q4,S8)(&.*`/HW6/AUI'BGPYI>F^/5_X22[LL
MO]NE7[-(SG[Q'D[=JGCY0<85<[B,T`=5I.GVNDZ59Z;I\7DV5G"D$$>XML1%
M"J,DDG``Y)S0!G7'B[PW;7$L%SX@T>*>)BDD<E[&K(P."""<@@]J7,BU3F]4
MF1_\)IX6_P"AET3_`,#XO_BJ.9=Q^RGV9OTS,*`/#/B]^SUI'C._O-:T&Z_L
M?7)\O(A3=;7#X;EE'*,Q*Y<9'!.TL22`>0_!KXHZO\(_$<_@[QW!<QZ-',4D
MBD&Z33G/.],9W1MG<0N00=ZY)(<`^R$:SU7359&M[W3[N'(((DBFC8?B&4@_
M0@T`G;5'R_\`%3PK+\,?%NG:KX:OG@@N6>6T`),ENRXW(2>&7#@#.<@D,#U;
M"2Y7='IT:GMHM21[M\*_&\7CCPZ;MHTM]0MV$5U`K`@-C(=1G(5N<9[AADXR
M=8RNCBK4O9RMT.SJC$*`"@`H`*`/`OVO_&E]X>\'6.@Z>FS^W_-2>Y$C*T<4
M9C+(`,9W[P#DXV[A@[L@`X#]GWX"6OB/2K?Q-XWCN1I\V_[+IA!B^T(579,7
M5@P4Y;"X4G"MDJ<$`^M[2V@L[6&UM(8X+:%!'%%$@5(U`P%4#@``8`%`'EG[
M2_C76O`OP]M[_P`-SQVU]<ZA':F=XA(8U*.Y*ALKD^6!R#P3WP0`3:XVH>/?
MAG8V.I%M(O[ZWMYKQ5BR%?"NR%&^90&[;@1@9)Y!\NKC]7%+J>IA\)RM3;Z'
MC][\'M>B\]K:ZT^X1-QC7>RO(!T&"N`3]<>_>DL9![HZ^5G.ZAX!\46,*RSZ
M-<,I;:!`5F;/T0DXXZ]*U6(IO9BY6)X-\6ZWX$UF>;32(Y"#%<VERAV.1D8=
M<@@J<X/!'(Z$@[QE;5&52E&HK2/J+X5^-XO''ATW;1I;ZA;L(KJ!6!`;&0ZC
M.0K<XSW##)QD[QE='F5J7LY6Z'9U1B?/O[8G@R#5/!,'BJ$1QWVCNL<S'`,L
M$CA=N=I+%792`2``TG<T`7_V2/&G_"1?#]M"G2Y-[H&V)IY9-ZRQ2,YC`)Y&
MT*4V]`%7!YP`#M/CKH_]L?#75-D'G7%EMNXOGV[-A^=NH!Q&9.#^`SBHFKHW
MPTN6HCP7X%^)I?#WCRS@)=K/5&6TFC7)^9CB-L9`R&(Y.<*S8&364'9G=B:?
M-!OL?7-=!Y04`%`!0`4`?'/[:VH74GCW0M->7-E;Z9Y\4>T?*\DKJYSC)R(D
MX)QQQU.0#Z7^$&JV6M?"_P`+WNFI'';'3XHO*B#A(FC7RW1=Y+$*RLH))SC.
M3U(!M^)?$.D>&-*DU+Q!J-MI]DF1YD[XW$*6VJ.K,0IPJ@DXX!H`^/\`Q[X@
MF^.WQCT_1]+DD/A>Q=A#(L)C=8<*9I2<,06*@+N`'^K!`);.5>JJ4'(UHTW4
MFHGTY7SI[H4`%`',>-O!>F^+(4-T7@O8E(BN8@-P'.%8?Q+DYQP>N",FMJ5:
M5/;835SY[LKC5/!WBF"X$;VVIZ=.&,;D@$CJIVD95AP<'!4]<&O6A--*43&<
M5).+/LCP3XAB\5>%[#6H('MTNE),3D$HRL589'494X/&1C@=*ZD[JYX]2'))
MQ.'_`&H?^2%^)O\`MV_]*8J9!X#^Q;_R5+5/^P-+_P"CH:`/LK4;.#4=/N;*
M\C\RUN8FAE3)&Y&!!&1R.">E`TVG='Q-;F7PCXVB-RB7$^CZB#(D;D+(T4G(
M#$9`)7KC\*YMF>P_?AIU1]P5TGC!0`4`%`!0!\Q_ME>!;J]MK'QK8_/%8PBS
MOT:0#8AD_=.JXY^>1E;DGE,#`8T`<_\`L@?$6UTB_N?!FJM;6\&H3&YL[EV*
ML]P0B>4>WS!05Z<@CYBR@`'N?Q1^#?AKXD:K9ZEK4VI6U[;0^0)+*95\Q-Q8
M!@ZL."S8(`/S'.>,`&3X1^%?AWX;W-Q_88NKBYN4&^ZO'5Y0N?N*550%R,\#
M)/4G`QY.82?.H]+'J8&*Y7+K<Z>O..X*`"@`H`\8_:#MH5NM$N5C`N)$EC=\
MGYE4J5&,XX+M^?TQZ&"EHT1):W.Q_9:U'S=`US3/*Q]GNDN/,W?>\Q=N,8XQ
MY77/.[VY].F]#S<9'WDS;_:A_P"2%^)O^W;_`-*8JT.(\K_8<_YG7_MR_P#:
M]`'U/0!\G?M"Z/%I7Q'N)8-@34($NRB1A`C'*-TZDE"Q/'+'ZG"HK,]3"RYJ
M?H?3WA;4)=6\,:1J-RJ+/>6<4\BQ@A0S(&(&23C)]:V3NCS9KEDTNYITR0H`
M*`"@"AK^LZ=X>T:[U76KN.ST^U3?--(>%'3ZDDD``9))``)-`'YW_%B^\+ZC
MX\U.Z\#64EGHCO\`(K<([?Q/&F`8T)Y"'./]D$(H!>\/_%/X@^$(!9:?X@U&
MWA,,0C@NU$ZQQA<Q^6LH;8I5@1MP"-O4`4DT]AM-;GWAK:SK:V"W<D<MR$(E
MDBC*(S87)526*@GH"3CU/6O-S+[/S_0]#+_M?+]3(KRST0H`*`"@#S;X]_\`
M(GV?_7^G_HN2NO!_&_0F6P_]E3_F:/\`MV_]JUZ]+J>;C?LGI_Q=\-/XO^&O
MB'1(5D>YN+8M;I&ZH7F0B2-<MP`710<XX)Y'6M3A/'/V./#FM^'_`/A+_P"W
MM&U+3//^R>5]MM7A\S'G9V[@,XR,X]10!])4`?+W[34\4OQ!M4BE1WATZ-)%
M5@2C;Y&P?0X93CT(]:PJ;GI8->Y\SZ"^'O\`R(/AK_L&6W_HI:VCLCAJ_&_4
MWZ9F%`!0`4`?)O[;>O;]5\->'XI+E?)ADOIDSB)][;(SC/++Y<O4<!^#R:`+
M/[-7@"WTW0HO%6IVN=5O-QLS(#F"#H&"D##/R=W.4*X(W-GR,=7<I>S3T1ZF
M#HI1YWNSAOVL8)E\>:7<-%(()--5$D*G:S++(6`/0D!E)';</6NC+VO9M>9A
MCD^=/R/K^_O;;5]%TS5=/E$MC=1+-#)M*[T=0RG!`(R/7!J,QB^6,B\!)<S1
ME5Y1Z04`%`!0!YM\>_\`D3[/_K_3_P!%R5UX/XWZ$RV'_LJ?\S1_V[?^U:]>
MEU/-QOV3WZM3A"@`H`^,_B[J/]J?$KQ#<>5Y6RZ-OMW;L^4!'GH.NS..V<<]
M:YYN[/7H1M32/K7P=9SZ=X1T.RO(_+NK:Q@AE3(.UUC4$9'!Y!Z5NMCRZC3D
MVNYKTR`H`*`"@#Y#_;;TCR?%/AK6?/W?:[*2U\G9]SRGW;MV><^?C&.-O?/`
M![%\-O\`DG?A;_L%6O\`Z*6OG:_\27JSWJ/\./HCQ;]KW_F4_P#MZ_\`:-=^
M6_:^7ZG%F'V?G^A[Q\+-1AUOX(^$KNT61(X+**W82@`EH086(P3P60D>V.AX
MK;'Q;I7[,QP4DJMNZ/'?!?B#4?A7XFF\)^/+B2?2M0N'N-/UN5V*,S$;@Y8G
M:"QRW]UF).5;>.:K3CB(^TI[K='33G*A+DJ;/9GNM><=Q7U&^M-,LY+O4;J"
MTM(\;YIY!&BY(`RQX')`_&G&+D[)";25V9OA/Q1H_BW3I+_P_>?:[2.4PL_E
M.F'`!(PP!Z,/SJZE*5-VDB:=2-17BSD/CW_R)]G_`-?Z?^BY*WP?QOT'+8?^
MRI_S-'_;M_[5KUZ74\W&_9/?JU.$*`"@#S+7?@YX3O\`7;O7+^:_B668W-Q"
M+A5A)SN?)*[@"<DX88R<8XQG*,5JSIAB*EE"*/1=/O;?4;*&[LIEFMY5W(Z]
M"/Z'MCM50G&<5*+NF8U*<J<G":LT6*H@*`"@`H`\,_:[\(R:_P##F+5[*W\Z
M]T.8S,1O+"W<8EPHR#@B-B3T5&.1R"`<3^S#XQM+OPM_PC-W-!!?V,K?98V8
M*UQ&Y:0[06RS*=^<``+M]Z\C'T6I\ZV9ZF"JIQY'NBS^U?\`\D[T[_L*Q_\`
MHJ6EE_\`$?I_D/'?PUZGH?[.,1F_9\T!%SNVW)&!G.+F4X_2O1Q,'.E)(X,/
M-0J)LX#5_A[KWCKXAWDOCUXSX6TYV;2XK.14\T,4^5N"^-J8?)!W'Y#BO-CB
M(4J:]E\3W_K^O,]"5"=6H_:?"MCS'X<^`M<UC6O%R>"O$UWI6DV-P\%O=Q3.
M%OF5F\H%X\*1MY+#.-X(4[JZZU>$8Q]I&[?X'+1HRE*7)*R7XF!XET;5[GX?
M>&?&7B#7K_6+"ZNY(&LY[A_,A^9@?+=MX^80G)P,';PW;2$XJI*G&-G8B<).
MG&I)W5S[`T#0],\/:<EAHEC!96BX.R%,;C@#<QZLV`,L<DXY->+.<IN\G<]>
M$(P5HHX?X]_\B?9_]?Z?^BY*Z,'\;]`EL3_LJSRM;^)8&E<P(UNZQECM5F$@
M8@=`2%7)]AZ5Z]+J>;C5LSWJM3A"@`H`I:Y:27^BZA9PE5EN+>2)"QX!92!G
MVYK.K!SIRBNJ-:$U3JQF]DTSQSP=XGNO!-_=:7K%K+]FWEI(E4>9&^!R.<,"
M`.^,8(/KX>&Q,L+)TZBT/I,9@X8V"JTGK;Y-?U_D_+VC3[VWU&RAN[*99K>5
M=R.O0C^A[8[5[T)QG%2B[IGS-2G*G)PFK-%BJ("@`H`*`/E/XR?LWZC<:S?:
MUX`6R:VN'WG1Q^X,1.T'RV8[""2[8)0*.%!X%`'E?C+PK\5-8L+N]\5Z5K,]
MIX=B\J26Y0!40$@NO_/;[N6D7=P`6;&#6<*4(7Y5:Y<ZDIVYG>Q]$?L9W,\_
MPIO8YII)([?5I8X5=R1&OEQ-M4=AN9C@=V)[UH0>BW,8BN98U)*HY49]C7S=
M2*C-Q71GT%.3E%-]48'A/POH_A+3I+#P_9_9+224S,GFN^7(`)RQ)Z*/RIU*
MLJCO)BITXTU:*#PGX7T?PEITEAX?L_LEI)*9F3S7?+D`$Y8D]%'Y45*LJCO)
MA3IQIJT4;59EGGGQTMII_!4<D2;DM[M))3D#:I#+GWY91QZUU81I5/D3+8H_
MLLZA%'J^OZ<ROY]Q!%.K`#:%C8JP/.<YE7''8_CZ])GGXU:)GT36QYX4`%`!
M0!SOCGPU'XFT@0!UBNX6WP2LN0#CE2>NT]\>@/.,5RXO#*O"W5;';@<6\-4Y
MMT]SQSPAXCO/"VLJ)S<_8U=EN;3..>A.T]&!`]#QC(S7AX;$2P\];VZH^DQF
M$ABJ>EKVT?\`73_ASWC1=3M]8TNWO[(L8)URNY<$$'!!'J""*^BI58U8*<=F
M?)UJ,J,W3ENB[6AD%`!0`4`5=6T^UU;2KS3=0B\ZRO(7@GCW%=Z.I5AD$$9!
M/(.:`/D/]C[7)-!^(VL>%]2C^RRZE"5\J:)Q*+B`L?+/]W"-,3N'50,@\$`^
MH?$$12_+\E9%!''IQC]/UKQ<?!QJW[GKX*:=.W8S*XCK"@`H`H>(+.34=!U*
MR@9%EN;:2%"YPH+*0,X[<U4'RR3?<&>"?"#73X3^(UD^H.]K;RLUG>!U5=@;
M@;MV-H5PA)X("GZ'W825[G'B(<\&NI]A5T'DA0`4`%`!0!R7CSP?::_I\T]O
M"L>JHI>.5``92!PC'C(.``3T^F0>+%X2-:+:7O'HX#'SH349/W?R\U_6IY/X
M+\0S^$]<D:>&4P-^ZN8#E6&#UP?XE.>OJ1QG->-A<0\/4U6G5'T&-PL<72LG
MKNG_`%T9]!PR1S1)+"ZR1.H9'4Y#`]"#W%?2IIJZ/CVFG9[CJ8@H`*`"@#XS
M^)\J?";]IZW\1Q01O8W+KJ+0H6D?RY@T=P<,1\Y;SF49VC*]N``?7NMVXFL7
M8#+Q_,/IW_3^5<F-I\])OJCJPE3DJ)=&<M7AGL!0`4`%`'B_QM\)PVVS7].@
MV"63;>J@.-Q^[)@#`R<@G/)*\9)-=^$JM^XR)+J=E^SSX^^WVD7A34_^/JUB
M9K.=I,^;&#GRR"<[E!XQQM7H-O/J4Y=#S<51L^='MU:'$%`!0`4`%`'E7QC\
M.2NXUZV$7E(BQW*@!6SG"OG^+J%]1@=1T\;,\.W^]7S/?R?%I+V$M[Z?Y?J/
M^"^N*8KG1KF=0P;S;5&)R0<[P.V!@'`]6//.'E=?1TV_3]19UAM56BO)_I_7
MH>I5[!X(4`%`!0!\^_MF>&GU+P'INO0+(\FCW)64!U"+#-A2Q!Y)WK$!C^\<
MCN`#:_94\;_\)3\.4TJZ?.I:#LM7X^]`0?);A0!PI3&2?W>3]Z@#N=1MS;7D
MD>,+G*_3M7SV(I^SJ.)[M"I[2"D>:^._'TNA:H=.TVW@EGC56EDFW$+D$[=H
MQS@J<Y[XQ7;A,`JL.>;T/K<GX?CBZ/MZTFD[V2M]]]?-6L<M+\4===0%@T^,
M[@<K$V3@Y(Y8\'I^/&#S78LLHKJ_Z^1[,>%L&GJY/YK_`".T\*_$.PUN\2SN
M8&L;J1L1;G#(_3`W8&&//&.W7)Q7!B,OG2CS)W1X&8\.UL+3=6$N>*WTLU\M
M=/G\K:G6ZE86NIV$UE?PI/:S+M>-NA']#W!'(/-<$9.+NCYT^=_'W@[4_`>K
M64XF`M[EFFL+B&7YU"L",G`(<`H<@8R>#P<>W&_*I/JCFC.,VX]CTOX7_&N"
M#3XM,\:RSF2+Y8M1"&3<@!XE`^8MP!N`.<\XP6.T:G<Y*V%;=X'N>D:G9ZQI
MEOJ&F7"7-G<+OCE3H1_,$'((/(((/-:IW.*47%V9;H$%`!0!%=V\5W:36UPN
M^"9#'(N2,J1@C(]JF45).+V94)N$E*.Z9\WZK9W7AKQ)+`'Q<V4P:.3`YQAD
M;'(Y&#CGT-?+5(2H56NJ?_#'VM*I#$T5+I)?\.?1NG7<=_I]M>0AEBN(EE0,
M.0&`(S[\U]3":G%275'Q=2#IS<'NG8L51`4`%`%#7]&T[Q#HUWI6M6D=YI]T
MFR:&0<,.OU!!`((P00"""*`/@ZVEU[X#_%]FD@DE:S=U"2$Q)J-HQ(#?*2,,
M`&'W@KJ,@E2*`/MK0]:TKQUX8M=5T*ZAFBE5'P)%9H&*JQCDVD[7`897/!Q7
M/B:'M866YT8>M[*5WL>9^/?A]_;6H2WME.MO?D!94ER4D(P`<C.T@#L"#@=.
M2>/#8UT%[.:T3/OLFXA^JTE2J1O#HUNKZ_/7TMY['$V'@37;+5HY+O0XM2M(
MI,/%]K6-9EZ<,&##U!^F0>17H?VA0:^*WR9]#6S[!U:+5.LX2:T?*VT_2S3\
M_P`'U/0[_1[GQ)'8VMYI&GZ!H,,AN)=.LV5I)IN5!9E4`#;Z<X_#;RULQC%-
M4]7W/EJ.,IX%SJ4ZLJM5KE4Y7LH[Z)MMN_?3\;]K86YNKI(AG:3EB.P[UYE"
MDZLU$^>K5%3@Y'4W]E:ZC:26NH6T%U:R8WPSQAT;!R,@\'D`_A7T)X:;3NCY
MQ\<?`W6;74)KCPMY%]92RDI:[Q')`I+$+EVPRJ-HW;LDGIWK&5-]#T*>+BU:
M1YA_Q/\`PGJ'_,4T6]DB_P"FEO(T9/X$KE?ID>U1JCI]V:[GV+X!N=9O/!^E
MW'B:#R-7>+,Z%`AZG:2HZ,5VDCC!)&!T'1&]M3R:JBIM1V-^F9A0`4`>5?'#
M3_\`D&:DD7]Z"63=_P`"08S_`+_('U[5XV:T_AG;R_R_4]_)*OQ4V_/_`#_0
MZWX9WK7O@K3FDF666)6A;&,H%8A5('0[=OZ'O7;@)\U"-WM_7Y'GYG3Y,3*R
MLGK]_P#P3J*[#@"@`H`*`.+^*WPZTCXC^'&TW55\F[BR]G?(N9+9SW']Y3@;
MES@@#H0I`!\>^'-<\6?L^_$*^M+VQCE:1%2XMY)'\F[AW@K+$PP,X#!7(.W<
MX*YR*`/=M!_:)\#^(M,:3Q%]J\/:C$/N-$]RCY+<(\:Y/`!.Y5P6XS@FN;$X
M>-57ZHZ,/7E2?D4-8^/?@BP\G[+/?ZGOSN^R6I7R\8QGS2G7/;/0YQQGS8X&
MJ]]#T)8VDMM3S7Q#^T=K-W;"+0M&M--=D=7EFE-PP)'RLG"@$<GY@P/'''/7
M#+XI^\[G+/'R:]U6.Q_9B^+FO:]XZFT#Q5J45U'>VS/:$VJH_G)\Q4&-0,%/
M,)W?W!@@G![*=&%-6@K'+4JSJ.\F?5%:&84`%`!0`4`%`!0!YU\;;B)=`L+9
MFQ/)=>8JX/*JK`G/U9?SKR\UDO9J/6Y[620;JRET2_7_`(!+\%/^15NO^OUO
M_0$JLJ_@O_%^B)SK^.O\/ZL]`KTCQPH`*`"@`H`^??VU+:!OAOHUTT,9N8]6
M2-)2@WJK12EE!Z@$HI([[1Z"@#S7X&_!;P[\2OA[>:I=7NK6&K07,MH'CEC>
M$L$5E?RR@;`\P`KOYVGD9P`"S_PS1_U-G_E-_P#MM>9_:7]W\?\`@'H_V?\`
MWOP_X)Z#I7P4\%:=I5S:+I\EQ//;R0->W+B250W\2@C8KKQA@H(Q[G/++&59
M.]SHCA*25K'R]I]YKGPN^(@N(!''K.CW#+B2,M'(,%3PP!*.C'!X.&!!!P:]
MN$U.*DNIY$X.$G%GZ">`?$]KXR\':3X@L5V17T(=H\D^4X)5TR0,[7#+G`!Q
MD<&J)-^@`H`*`"@`H`JZGJ-GI=HUSJ%S%;P#^)VQDX)P!W.`>!S45*D::YI.
MR-*5*=67+!79\^>(-6O?%WB))3$HFF98+>%2`%!/RKDXR<GJ?7L.!\S6JSQ-
M6_?1'V&'H0PE&U]%JV>Z^$-)DT/PY9:=-*LLL*MO91@99BQ`]AG&>^.U?18:
MDZ5)0?0^4Q==5ZTJB5DS8K<Y@H`*`"@`H`\"_;2_Y);I?_89B_\`1,U`%K]C
MNPN;#X1SW-W&(X+W4IKB!RP.^,)'&6X/'S1N.<=,]"#2;25V-)MV1W=?,GT(
M4`>._'WX1W?BS36\3>&+..35K-2+JWC4^;>Q@#!7!^9T`Z8RP.`2553Z^7N3
MB[['EX]1YE;<\9^!_P`6M1^&NLE)!)>>';IP;RR!Y4]/-CSP'``XX#`8.,*R
M^@<)]N>`_&V@^.=&CU'P[?QSJ45IK<L!-;$Y&V1,Y4Y5AZ'&02.:`.DH`*`"
M@#FO%WC'3O#6(K@2S7KIOC@1<9!R`2QX`RN.Y]JY,3C(4-'J^QW83`5,3K'1
M7W/%-7U?6/%FI1_:/-NI_F$-O!'D(.I"J/;OR<`9/%>#4JU<1+75]CZ>C0HX
M6#Y=%U;/6/AYX)CT&);[4563577@=1;@]AZMZG\!QDGV<%@E17//XOR/G\QS
M%UWR0^'\_P"OZ\NXKT#R@H`*`"@`H`*`/E/]HOP]XU^(WQ9L-`TG0KU='L$6
M*WOI86%J6D57EE:79@``*I7+<Q\#<VV@#Z`TK1(_"/@/1]"LFC\NR@CMWDBB
M$0E(7YWVC."S98\GDG)-<6/DXTM.K.O!14JFO1%.O%/7"@#J](M7M+39(1O9
MMQ`[=./TKWL)1=*G:6YXN)JJI.ZV/#_C5^SU:^,=5FUWPK=6VEZO/\US;S(1
M!<N6&9"5R4;&XG"L&..`2S'I.<\!TOP9\6?AMXCBO=&T+6[74C"1YMC;B\C9
M&R"K;`Z'E<[6Y!"G'0T`?9GPK\3ZKXK\)0WWB#0;W0M6C<PW-M=0-$'8`'S(
MPWS;#GC/0@C)QD@'7T`>;_$/Q\VFRMINA2*;U&_?W&`PB(_A`/!;U].G7IY6
M-Q_(^2GOU9[>799[1>TK+3HN_G_7Y;^=:'HVK>+M4E$+M-,%W37-RY(48P-S
M<G)Q@#GIZ`X\NE1JXF>FOFSV:^(HX2"OHNB1[;X3\*:=X;@'V5/,O&0++<O]
MY^<\#^$9[#T&<XS7T&'PL*"]W?N?+XO&U,2_>VOHCH*Z3C"@`H`*`"@`H`*`
M"@`8!E*L`5(P0>])I-68TVG=%273;.1@6@4'&/ERO\JPEA:,G=Q-HXFK%64B
M2VM(+;/DQA2>IZG\ZNG1IT_A1%2M.I\3)ZU,PH`*`"@"*[N(K2TFN;AMD$*&
M21L$X4#).![5,I**<GLBH0<Y*,=VSYDU:\_M#5;V]V>7]IF>79G.W<Q.,]^M
M?)U)\\W+NS[FE3]G3C#LDCZ(\):+'H&@6M@H4RJNZ9U_CD/WCG`R.PSS@"OI
M\-15&FH'QN+Q#KU7/IT]/Z_$V*W.8*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"
M@`H`KZC:1W^GW-G,66*XB:)RIY`8$''OS4S@IQ<7U1=.;IS4UNG<X_3OAIH]
MAJ%M>0W.H-+;RK*@:1,$J01GY>G%<,,MI0DI)O1_UT/2J9O6J0<&E9JW7_,[
MBO0/*"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@#__9
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S
M+VUA;&4Q+FIP9P``````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-S(W,R`Q
M,#4Q-30S,S<U,2`P,C,W-S<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````_]C_X``02D9)1@`!`@$`R`#(``#_P``1"`"^`)8#
M`1$``A$!`Q$!_]L`A``&!`4&!00&!@4&!P<&"`H1"PH)"0H5#Q`,$1D6&AH8
M%A@7&Q\H(1L=)1X7&"(O(R4I*BPM+!LA,30P*S0H*RPK`0<'!PH)"A0+"Q0K
M'!@<'"LK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK
M*RLK*RLK*RO_Q`&B```!!0$!`0$!`0```````````0(#!`4&!P@)"@L0``(!
M`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$54M'P
M)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F
M9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>X
MN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^@$``P$!
M`0$!`0$!`0````````$"`P0%!@<("0H+$0`"`0($!`,$!P4$!``!`G<``0(#
M$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G
M*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%
MAH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35
MUM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/JF@`H`*`"@
M`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*
M`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`
MH`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`"0.IH`JW6
MH6MJI,\\:`>K4KC46]CG-4\?:'8`AKI78=EI.:1M'#S?0YR]^+^CQ8$*,[=Q
MG&*GVB-%A)=3'N_C1&)F6WM5*@?Q-S2]H:+!]V<KJ7QHU-I3Y$L<8'&U4S4^
MT9HL+!;F1=?%SQ%=D>7-<JJ]XHP,TN=EK#TUT(+OX@^*9[<!;F]=7'(W!3^E
M+F92HTUT,S_A+O$O]_4O_`EO\:+LKV<>Q6N]?UF\(-W!=3D=#+*6Q^=*XU%+
M9$']I7__`$#W_.@H/[2O_P#H'O\`G0!?A\7ZS;(J32ZC!".!LG;`_`&G=D<D
M7T.@T?QQJ\0#6FK7#`G.V1]V?SHYF2Z,'NCN?"_Q0O(KDIK6)HFZ,BX*U<:G
M<YZF$5O=/8-+U"WU*T2XM7#QL,@BM4[G#*+B[,MTR0H`CN)H[>%Y9F"1H,EB
M>!0-*YX;X]^)PDOVMM,O8H(4."Q<`M6,I]CT*.&25Y'F>J>+([YFBDU<M*3T
M5B2:B[.I02V1EV5K'J$;.;FY==W\8*TBBV-%M-X8J2WKF@"TEE;H21&N3UH`
M>MK`K;A$@/KB@"5451@*`/I0`M`!0`4`%`!0`C*K##`$4`9][I<4X4QDQ,IR
M"G%`#+2\DAN/LUZ`I)_=OV8?XT`>L?"GQ2=.OUT^[D_T>8X4GL:TA*VAR8FE
MS+F1[HI!`(Z&MCS0H`R/%.AQ^(=*-A-<2P1,P9S'U88/!]N?TI-71I3GR.]C
MS:?X#^'EC8VC`3$Y#2QAN:CV:.A8R75'$ZU\(?%%O/(^GW%H85.$"Q<GWJ'3
M9O'%0>YS&K>$/%ND1M)=RD1KU*6^:GE9JJL'LS/M[YH?W=QY\DF>28B*5C2Z
M$.L_O?+%K<9S@'90,M6-U+<.XDMWB"G@MWH`N4`%`!0`4`%`!0`4`%`%:_ME
MN;=D8<CD'T-`$>C7KRISE)H6P?J.]`CZ?^'FM?VWX9MIW(,Z#RY![BNB+NCR
M:\.2;1TU48A0`4`%`#9(HY%Q(BL/0C-`%"?1--F#>990'=U^04K(I3DNI@ZY
MX"T?4+=ECMUAEQ\K(,8I."9K#$3BSPWQ+H5UH.H/;72$+GY'QPPK!JQZ5.HI
MJZ,BD:!0`4`%`!0`4`%`!0`&@#%MW%OKTL.T_O5W`T`>S?`_4)(]:N;'),4T
M>_'H16E-ZG'C(^ZF>V5L><%`!0`V8D1.1U`-`&9X8NIKS24EN'WR%V&?H:2*
MDK,U:9(4`<E\2/#XUO0)?*3-S#\Z8')]JF:NC>A4Y)'SO+&\4C1R*5=3@@]J
MYSU4[C*!A0!8M[.YN"!!!(^?[JDT6)<DMRW/H6J01&26QG5!U)0T^5B52+ZF
M:00<$8-(L2@`H`*`,'40T?B&RD4C#@J10!Z5\+KG[-XPLB7**YVGWSVJH;F&
M(5Z;/HRN@\D*`"@""^E$-E/*W1$)/Y4#6YA_#VZ6]\+6US&"$D9F`/UI+8JH
MK2.CID!0`$9&#0!Y_P",_AY;:S(US9,(+D]>.&J)0N=5+$N&C.;L/A+<,0;V
M\51GD(*E4S66,71'3Z/\,](LN;@-<-G(W52@C&6*F]CL+/2[&RB"V]M%&H]%
MJK&#DWN<1K'C&]O[Z[T[PKI*:D;?Y997;:BMZ>])OL:1@DKR=CS7QCIU\KRW
ME[HTFGR#EQ'\Z-[Y'2LY1.RC56USE@#L5\$*PR#CK69U7$H&%`&)JW_(:T_Z
MF@#M_`__`"-.G?\`744X[F5;X&?3E=)XX4`%`%/6O^01>_\`7%_Y&AC6YS?P
MD_Y$+3?HW\S2CL75^)G84S,*`"@`H`I3ZI:07\-E+,JW,P)2//)H'9VN7:!$
M5VCR6LR1G#LA"GT-`(P_!&@?\(_I`@DV-<N[/+(H^\2:25BYRYF;ES;Q7,+Q
M3(KQN,$$=13(/&9M!CU#3M?TVUB4-I5P?(8]=I&2*S:NCMIU'&2;ZGF;*58J
M1@@X-8G>)0,Q-6_Y#6G_`%-`';^!_P#D:=._ZZBG'<RK?`SZ<KI/'"@`H`IZ
MU_R"+W_KB_\`(T,:W.;^$G_(A:;]&_F:4=BZOQ,["F9A0`4`5]1O(;"QFNKA
MPD42EF)-`TKNQR'@K3EU:Z;Q/?HQN9\BW5O^6<?;'UJ5W-)NWNH[>J,@H`*`
M([B9(('ED8*B`L2>PH`XSP#:+=#6=5&?)U*<LBD?PCC-2C6;M9=CQKQG8#3?
M$=Y;C[H<D?C6$E9GITI<T$S#I&IB:M_R&M/^IH`[?P/_`,C3IW_744X[F5;X
M&?3E=)XX4`%`%/6O^01>_P#7%_Y&AC6YS?PD_P"1"TWZ-_,TH[%U?B9V%,S"
M@`H`X7QY*-=U"T\,6LBEI6$MW@\K$#T_$U+UT-8>ZN8[6U@2VMHX(E"QQJ%4
M#L!5&1+0`4`!H`XKQ%JJZYJG_".:7)N?K>2+R(T]/J:EZZ&D5RKF9UMA:16-
MG%;6Z!(HU"J!5$-W/'?C1HHMK^'4HA\LWRO]:QJ+J=^$G=<IYC69VF)JW_(:
MT_ZF@#N?`JL_BK3@H)/FCI51W,JWP,^FJZ#QPH`*`*>L@MI-X%&286`'X&AC
M6YQWPMU6QM?!^GVES=10W*[@8W;:P.3V-3%Z&E6+YFSNXY4D4&-U8'N#FJ,A
MU`"/]T_2@#S;X6Z<D^N>(=;N)'EO9+IH`S'[J*>`*F/<VJO11/2JHQ"@`H`R
M_$MY/9://+:0O-<$;45!DY/&:3*BKLI>#/#\6A:;\P#WLY\RXE(Y9C0E8<Y<
MS.AID&5XDT2VUW39+2[7((^5NZGUI-71=.;@[H^<O$VB7&@ZK+:7"G`/R-CA
MAZUSR5F>M3FIQNCD-=REU8RJ/F$F,^@I&AZ-\*^?&=A]3_*KAN<^)_AL^BZW
M/*"@`H`"`1@]*`,#6O"&BZP,WEE&7[.ORD?B*32+C.2V.5M].3P9XQT:SL;B
MYEM=2WQM%+(6";1D$4MF6WSQ;?0])JC$1_N-]*`.%^%'_'MKG_80D_G4Q-:O
M3T.[JC(*`"@`-`!0`4`%`'(_$3PU#KFD22;/]*A4F-OZ5,HW1O0JN$O(^9/$
MEI/)"L4:DR)*,CTP>:YSU3T?X-VPG\70%B08HRP^H%73W.?%.U,^@JW/+"@`
MH`*`"@#@_B5_H^L>%+Z/_7)J`B&>FU@0:EFM/9KR.\'2J,A'^XWTH`XKX7VT
MUO;:QYT;)OOY&7(ZC/6IB:U7MZ';51D%`!0`4`%`!0`4`)(H="K#((P:`/!/
MB?X7DTK5'N[:(_9)3DD#H:PG&S/3P]7FC9[DGP5!_P"$N)QQY+4Z>X8OX#WB
MMCS`H`*`"@`H`YGQS:17%OIDDJY:&^B=#Z'./ZTF7![^ATPZ4R`H`1551\H`
M^E`"T`%`!0`4`%`!0`4`%`%>^LK>^MVANHEDC;J&%%AIM.Z,_1/#FF:+([V%
MLL;MU;O244BYU)3W9L4S,*`"@`H`*`,'QC_QY6?_`%]Q?^A"DRX;F\.@ID!0
M!#<74%NI:>9(P.[-B@+&5J'BG2+!`UQ>Q#(R`#DFE=%*#9F?\+"T#_GZ;_O@
MT<R*]E(TT\4Z.?*W7L2&094,<9HNB>21KPSQ3J&BD5P>ZG-,DDH`*`"@`H`*
M`"@`H`*`"@`H`*`,OQ)I"ZWIIM&FDA^=75XS@J0<BDU<J,N5W,`VOBW39`MI
M<VE];C`"S`JV/K2U*O!E74[?QOJ=[Y<$]EIME@99<N^>^*-1KD2[A'\.X;F3
MS=9U*\O7.,AGPOY4<H>UMLCHX/"^CPK$%L8B8QA2PSBG9$<[+G]D:=_SY0?]
M\"BPN9E/5/"^D:G&$NK*)@O0@8(HLAJ<EL+X?\/6FA>:+-I=LAR5=R0/I0E8
M)2<MS9IDA0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`
M4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`
M!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4
M`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!
M0`4`?__9````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]A=F%T87)S+VUA;&4R+FIP9P``````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P-S0W-B`Q,#4Q-30S,S<U,2`P,C0P,#4`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````_]C_X``02D9)1@`!
M`@(`3@!.``#_P``1"`"^`)8#`1$``A$!`Q$!_]L`A``&!`4&!00&!@4&!P<&
M"`H1"PH)"0H5#Q`,$1D6&AH8%A@7&Q\H(1L=)1X7&"(O(R4I*BPM+!LA,30P
M*S0H*RPK`0<'!PH)"A0+"Q0K'!@<'"LK*RLK*RLK*RLK*RLK*RLK*RLK*RLK
M*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RO_Q`&B```!!0$!`0$!`0``````
M`````0(#!`4&!P@)"@L0``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-1
M80<B<10R@9&A""-"L<$54M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$
M149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8
MF9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;G
MZ.GJ\?+S]/7V]_CY^@$``P$!`0$!`0$!`0````````$"`P0%!@<("0H+$0`"
M`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2
M\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D
M969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2U
MMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,
M`P$``A$#$0`_`/JF@`H`*`"@`H`*`(KNY@L[6:ZNYHX+:%#)++*X5(U`R68G
M@``9)-`'`:U\:OAUHUTEO=^*K*21D#@V:O=)C)'+1*R@\="<]..10`:+\:OA
MUK-T]O:>*K*.14+DWBO:IC('#2JJD\]`<]>.#0!W6EZC8ZM817NE7EM>V4N?
M+N+:59(WP2#AE)!P01]10!:H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`BN[F"SM
M9KJ[FC@MH4,DLLKA4C4#)9B>``!DDT`?-'Q&_:BL5L+JR\!V-S)>MOC34KQ%
M2./!`62./DOD;B-^W!VY4\K0!\Q>)?$.K^)]5DU+Q!J-SJ%Z^1YD[YV@L6VJ
M.BJ"QPJ@`9X`H`RJ`"@`H`].\(_'3Q_X:D4)KDFJ6P=G:WU7-P')7;RY/F`#
M`("L!D=.3D`^B/A7^T=H/B>2'3O%,<>@:F4)-Q)*!:2E5!/SL08R3N(5LC``
MWDD"@#WB@`H`*`"@`H`*`"@`H`*`"@`H`^'OVA/C5/X[NI-#\/220>%87Y."
MKW[`\.PZA`1E4/LS<X"`'B5`!0`4`,9L'`H`56S@=Z`'4`%`'K'P>^->O>!M
M9MTU2[O=6\.E$@ELIIBY@C7A3!N.$*C^'A6'!Q\K*`?<^@:SIWB'1K35=%NX
M[S3[I-\,T9X8=/J""""#@@@@@$4`7Z`"@`H`*`"@`H`*`"@#PS]L+7O[,^%:
M:9');>;JU['"\<A_>&),R,R#/9TC!."`'QU(-`'Q)0`4`%`"4`1L<F@!*`'!
MB*`'*P/UH`=0!ZQ^SW\4Y_A[XGCM=2NY!X5OGQ>Q;#)Y38PLR@'(((4-C.5!
MX8A<`'WC:7,%Y:PW5I-'/;3()(I8G#)(I&0RD<$$'((H`EH`*`"@`H`*`"@`
MH`^/OVV=5GF\9^'M(9(Q;6NGM=(P!WEI9"K`G.,8A7''<]>,`'SE0`4`(QP*
M`(\Y^M`"4`%`!0`\+QZ&@!5/8]:`'4`?5G['?Q#>:.?P-JDT86%&N-+)55)&
MXM+'G.6.6W@8)QYF3@```^HJ`"@`H`*`"@`H`*`/BG]LRY@G^*UE'#-'));Z
M3%',J."8V\R5MK#L=K*<'LP/>@#P>@!#P,T`1DDF@!Z#C.*`&,,&@`'7B@!Z
MJ!]:``MDX'6@!-IQ[T`+NX/K0!T7PU\3R>#O'FAZ\KRB.RNE:<1(KNT)^655
M#<9*%@.G7J.M`'Z74`%`!0`4`%`!0`4`?`G[4/\`R73Q-_V[?^DT5`'EE`!0
M`PISQ0`T$CO0``\\\T`29`&:`&\L?04`+PHH`!D^PH`4J"*`&[.>O%`'Z4?"
MC_DEO@[_`+`UG_Z)2@#J:`"@`H`*`"@#+\5:]8^&/#FHZWJLFRRL86FDP5#-
MCHJ[B`68X4#(R2!WH`_-KQ5KU]XG\1ZCK>JR;[V^F::3!8JN>BKN)(51A0,G
M``':@#*H`*`"@!"`>M`#&&#0`+C//6@!Q.!F@`5><GK0`Z@`H`*`/TE^%'_)
M+?!W_8&L_P#T2E`'4T`%`!0`4`%`'RQ^V=XTOH9M.\%VR>593PIJ%S,LC!IO
MG=5C*CC:"FXYSD[>FWD`^6*`"@`H`*`"@!#0`A4]C0`PY_&@`R?6@"13D9H`
M6@"6TMI[RZAM;2&2>YF<1Q11(6>1B<!5`Y)).`!0!^G^DZ?:Z3I5GINGQ>39
M6<*001[BVQ$4*HR22<`#DG-`%J@`H`*`"@"KJFHV.DV$M[JMY;65E%CS+BYE
M6.-,D`99B`,D@?4T`?FKXS\2ZCXP\3ZAKVLM&U]>N&<1)M10`%55'H%``SD\
M<DG)H`Q:`"@`H`*`"@`H`*`$H`-H]*`"@!:`/6/V9?!D_BSXH:?=$2)I^BNM
M_<2KD?,C`Q)G:1EG`.#C*J^#D4`?>U`!0`4`%`!0!E^*M!L?$_AS4=$U6/?9
M7T+0R8"EEST9=P(#*<,#@X(![4`?''B7]F3QQIGF2:0^FZU%YQ2-()_*E*<X
M=EDVJ.@R`[$$\9&30!XWK^C:CX>UF[TK6K22SU"U?9-#(.5/7Z$$$$$9!!!!
M(-`%"@`H`*`"@`H`*`"@`H`*`+6DZ?=:MJMGINGQ>=>WDR001[@N]W8*HR2`
M,DCDG%`'Z(?"'P+:_#WP19Z-!\UVV)[Z42%UDN&50Y7(&%^4`#`X49YR2`=I
M0`4`%`!0`4`%`!0!\Y?MF>#WU#PQIOBFTCC\S2G,%V0BAVAD("$L2"0K\!0#
M_K2>,'(!\?4`%`!0`4`%`!0`4`%`!0!]>?LD_#2QL](L_'US=?:KV]AEAMK=
MH%"VF)61F#$DEB$P"-N`S#G/`!])4`%`!0`4`%`!0`4`%`'-_$O1G\0_#WQ'
MI4-I'>7-UI\R6\,@7#3;"8_O<`API!.,$`Y&*`/S5H`*`"@`H`*`"@`H`*`"
M@#]&O@KI]KIGPE\(P6,7E1/ID,[+N)R\BB1SR>[NQQT&<#`H`[2@`H`*`"@`
MH`*`"@`H`Y;XJ>(/^$6^'/B+65N?LL]M92?9YO+W[9V&V+Y<$']XR#D8YYXS
M0!^;5`!0`4`%`!0`4`%`!0`4`?HK\#-5@UGX0>$KJU21(X]/CM2)``=T(\IC
MP3P6C)'MCITH`[F@`H`*`"@`H`*`"@`H`^=_VTH]7E\$:,MG9>=HT5Z9KVY5
M<M`X79%GGA6\R0$XQD*,@D`@'QS0`4`%`!0`4`%`!0`4`%`'UY^Q3KUB_A;7
M?#_F;=2AO?MVQBHWQ.B)E1G)VF/YN,#>G/-`'TE0`4`%`!0`4`%`!0`4`9?B
MCP_IGBG0KG1M>MOM6FW.WS8?,9-VU@P^92".5!X/:@#Y'^('[,7B32[HR^#9
MX]<L7?"PRND%Q$"6(W;B$8`!06!!)/W`!0!R'_#/WQ-_Z%G_`,G[;_XY0`?\
M,_?$W_H6?_)^V_\`CE`'(>+O`OBCP?(R^)-#O;&-76,3O'NA9BNX*LJY1CC/
M`)Z'T-`'-T`%`!0`4`%`&_X&\7:OX(\1V^M:!<>3=Q?*Z-S',AQNC=?XE.![
M@@$$$`@`_1#P-XNTCQOX<M]:T"X\ZTE^5T;B2%QC=&Z_PL,CV((()!!(!OT`
M%`!0`4`%`!0`4`%`!0`4`%`!0!X/\??@WX7O/`>KZUH&D66DZQIEL;A'M5\B
M*2./+.K1J-I)4M@X!R%!;:"*`/BF@`H`*`"@`H`U?#7B'5_#&JQZEX?U&YT^
M]3`\R!\;@&#;6'1E)495@0<<@T`?8WP:_:`TCQ983VWC&YTW0M9M\OODE\FV
MN$SP49V^5AD`J22>HR,A0#VZTN8+RUANK2:.>VF0212Q.&212,AE(X((.010
M!+0`4`%`!0`4`%`!0`4`%`!0!RWQ7_Y);XQ_[`UY_P"B7H`_-J@`H`*`"@`H
M`*`);2VGO+J&UM(9)[F9Q'%%$A9Y&)P%4#DDDX`%`'O'P>^#/Q*NO,N8M5U+
MP3IMQCS7\V2*>;;O`_<JRDX/]\KP^5W4`?8^EVLUE816]S?W.H2IG=<W*QB1
M\DGD1JJ\9QPHX'<\T`6J`"@`H`*`"@`H`*`"@`H`Y;XK_P#)+?&/_8&O/_1+
MT`?FU0`4`%`!0`4`7]`T;4?$.LVFE:+:27FH73[(88QRQZ_0``$DG``!)(`H
M`^X?@K\$-(^'GDZK>2?VCXF:'9)<-S%;DYW"$8!&00I8\D`XVABM`'KU`!0`
M4`%`!0`4`%`!0`4`%`!0!RWQ7_Y);XQ_[`UY_P"B7H`_-J@`H`*`"@#:\&>&
MM1\8>)]/T'1EC:^O7*H97VHH`+,S'T"@DXR>.`3@4`?H!\*?AUI'PX\.+INE
M+YUW+A[R^=<27+CN?[JC)VKG`!/4EB0#M*`"@`H`*`"@`H`*`"@`H`*`"@`H
M`Y;XK_\`)+?&/_8&O/\`T2]`'YM4`%`!0!+:6T]Y=0VMI#)/<S.(XHHD+/(Q
M.`J@<DDG``H`^W/V7OAD_@OPP^M:S;R1>(-60;X9XE5[2$$E4'5@6X9@2/X0
M5!0Y`/;:`"@`H`*`"@`H`*`"@`H`*`"@`H`*`.;^)EM/>?#?Q7:VD,D]S-I-
MU'%%$A9Y&,3`*H')))P`*`/S5H`*`-KPCX6UKQAK*Z5X;T^2^OF1I#&A"A5'
M5F9B%4=!DD<D#J0*`/M;X*_!#2/AYY.JWDG]H^)FAV27#<Q6Y.=PA&`1D$*6
M/)`.-H8K0!Z]0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`'YZ^./AQJMO\7]
M=\)^&-,DO9(KG?;P6FZ0102%6CWLWW0JR(&9C@'J>]`'IWPZ_9=U.^V77CN^
M_LN#G_0;)UDG/WA\TG*)R%88WY!(.TT`?5'AKP]I'AC2H]-\/Z=;:?9)@^7`
MF-Q"A=S'JS$*,LQ)..2:`-2@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`
MH`*`"@`H`*`"@`H`*`"@`H`__]D`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V1O9RYG:68`
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C$P-B`Q,#4Q-30S,S<U
M,2`P,C,U,C0`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````1TE&.#EA'0`>`/<`````````,P``9@``F0``S```_P`S```S,P`S
M9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"99@"9F0"9S`"9
M_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#__S,``#,`,S,`
M9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F9C-FF3-FS#-F
M_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,_S/_`#/_,S/_
M9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S9F8SF68SS&8S
M_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9_V;,`&;,,V;,
M9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`9ID`F9D`S)D`
M_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF_YF9`)F9,YF9
M9IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_9IG_F9G_S)G_
M_\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS_\QF`,QF,\QF
M9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,9LS,F<S,S,S,
M_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`__\S`/\S,_\S
M9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^99O^9F?^9S/^9
M___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__F?__S/____B_)```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"'Y!`$``-@`+``````=`!X```C^`+$)
M'$BPH,&#"%<H1,B0X0I6K%8TG$CPX9]`$BD:5+C""D96%S,F9&C%2D>+&!VF
M/!@HHL)`,$TF9"7SX`J8+2&NW,@*IDB"&(-"I/ESX,VC+(_F[%E4X,F=V#C>
MO#9T:,V*)G<"4`+Q(=6J3)MVU*I$TT>P.O5`(@&`A%L`#[5N5?(0;2"U;*R0
M0,*7A)6(!0$`*+%4IQ6\>ECI64%B16*H4;,.#522!"0VB=$R+:C4<-O+F343
MQ3JVI&`DF$5;+2I1ZEXDH55?=?A7]6J-':OBU#V;(=S:-"GG'HW;Y%^,)8UO
M+I[5"ES!OR&K;-XZ^4WIG$N^I/G<Y/;>!(DD@G6N?7Q3I\+-EZ\*'GU6G-JU
MXZ3<WBF`J-`%8]._(O]]@0$!`#L`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V%V871A<G,O<WEL=F5S=&5R+F=I9@``````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`R-38T(#$P-3$U-#,S-S4Q(#`R-3`R,P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!'248X.6$@`"``]P``````
M"```"`@`"`@($```$!`0&```&`@(&!`0&!@0&!@8(0``(0@((1`0(1@0(1@8
M(2$A*0``*1`0*1@8*2$A*2DI,1`0,1@8,2DI,3$Q.2DI.3$Q.3DY0@@(0A`0
M0A@80BDI0C$Q0D(Y0D)"2A`02BDI2CDY2D)"2DI"2DI*4A@84CDY4DI*4E)2
M6@``6A`06BDI6D)"6DI*6EI:8P``8RDI8SDY8UI:8V-C:P``:RDI:UI::VMC
M:VMK<VMK<W-K<W-S>W-S>WMS>WM[A```A`@(A'M[A(1[A(2$C```C(R,E```
ME!`0E!@8E)2,E)24G```G)R<I1`0I1@8I9R<I:6EK2DIK:VMM:VMM;6MM;6U
MO;6MO;VUO;V]QKVUQKV]QL:USKVUSL:]SL[&UL[&UM;.WLZ]WL[&WM;.WM[.
MWM[6Y][6Y^?6Y^?>[\[&[][6[^?6[^?>[^_>[^_G]^_G]_?G]_?O__?O___O
M___W________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M________________________________________________________95E8
M(?D$`0``_P`L`````"``(```"/X`_PD<2+#@/P,7#"I<N#`"PX<0'4*<2'`!
MC04N_GU@\('B0P,"`@`@L,#C1`(0```(0,/DPPL"5`(8`,(E0P(R50X@4-/F
MOQ4."(B4.8`H@1`4+3B8X.!!@@(Y"X@HJI,#`X@2MHQ)LT;+E1X)=*;X,H/J
M``XBKK[4,(8-G3E<>A0=D*(-&05%!52(,F("4Z86%%I@>X>-7)49RJS)D&*$
M`B5B;H0Q8T8-&S$:`AL$(::*`J(CR+!9$R5!@PM%IDRQXF8-FS%@$A:D,0%"
M`06X%4!(@49-$`]$B$!9,KQ)B`PS@*`P*('%D"N6UZP9@X3'C0\TD@R'4MS,
MF`Q8*OZL('C!R9HY=?#<P3.G"ILX96#0H+&D_A(B.MB0X8"#!7DG<=BAGGIW
MH-$"&6W0$08,*F1'A`HUG%'&@6#<((-`#"@1QWH<VM'&$6+TD,(82J"Q((1>
MG)'&$66045,,`DU0!1T#WI%''%JT44<<8@"1AAHEKB'&#SP`(888/0DD@1-M
M<'B'AU_,8<<=:@@Q@AA#C`''BFB,P84&$Q0T01DTVD@'%UK,L5X<1ZA1Q@\X
M\-"#CV2`J=`$9'0Q!X%UT"$@E4C$$0<0:L311AQC)&E0`TK,.*`=>=Q!I1)K
MU+'&$7&HE^A#!#R@A)1.LE&&$6K@P:8:3[H(D447/+&AAU-C:$#!#674H4:@
M=ZCJ$05/I!&K;"N$``:I>+"A@4LE*.#70#;$V(,<=XPAFTDE%-3L/PZ44=BQ
M/BTTP1IXJ!%FMPIIP$9A#Y!KD`5BJ+=&NA,%!``[````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]S;6EL97DN
M9VEF````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(Q,C`@,3`U,34T,S,W
M-3$@,#(T,C4Q`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$=)1C@Y82``(`#W`````````#,``&8``)D``,P``/\`,P``,S,`
M,V8`,YD`,\P`,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`
MF?\`S```S#,`S&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S
M`&8S`)DS`,PS`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS
M9O\SF0`SF3,SF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S
M_V8S_YDS_\PS__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF
M,_]F9@!F9C-F9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-F
MS&9FS)EFS,QFS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9
M`/^9,P"9,S.9,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9
MF6:9F9F9F<R9F?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9
M___,``#,`#/,`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,
M9F;,9IG,9LS,9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,
MS/_,_P#,_S/,_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_
M,V;_,YG_,\S_,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_
MF?__S`#_S#/_S&;_S)G_S,S_S/___P#__S/__V;__YG__\S____XOR0`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````A^00!``#8`"P`````(``@```(_@"Q
M"1Q(L*#!@P@3*ES($-N*%2H@KFBH\*$*/ZA029.&2B)%@@^I8-Q(DF3'B12K
MB"S)LF3'ABK]M)RYD0K*A"I7MO2CXF))%0!N&EQ!16=+H```R-R8-"A"HGZ6
MMFP*0(5&:4@!'(1JU"55`%0V^FDJ5"!4J4>IJMB(*NM0D6A9CJ5*DDK3@ESC
MNLP*P*3;@43ATA3;=&W=NX!%=IW)TV=)/W9!*M8[N"4JK8D%5]Z,V6S1J#-[
M;N98]JQ>H%<'JS"HXK/>L58'MWT+F;+=V)8C$@P4R$KKVHRKIF8+="!OWKXG
MTVQL-6-/I]B.]^[]>[%)*CVSVS0^W4KOY)HW+K_<W?U[:[B4358Y*-V[%=_G
MP[-M6]9@^_=`S]?&_O"CP./N6>21?P06:"!!`0$`.P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]A=F%T87)S+V1I;F\N9VEF````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,C$W,2`Q,#4Q-30S,S<U,2`P,C,W,#8`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````1TE&.#EA(``@`/<`````
M````,P``9@``F0``S```_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!F
MF0!FS`!F_P"9``"9,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_
M``#_,P#_9@#_F0#_S`#__S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,S
MF3,SS#,S_S-F`#-F,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,
M`#/,,S/,9C/,F3/,S#/,_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`
MF68`S&8`_V8S`&8S,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9
M`&:9,V:99F:9F6:9S&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_
MF6;_S&;__YD``)D`,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF
M`)EF,YEF9IEFF9EFS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,
MF9G,S)G,_YG_`)G_,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS
M`,PS,\PS9LPSF<PSS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9
MF<R9S,R9_\S,`,S,,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\`
M`/\`,_\`9O\`F?\`S/\`__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]F
MF?]FS/]F__^9`/^9,_^99O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,____
M`/__,___9O__F?__S/____B_)```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"'Y!`$``-@`+``````@`"````C^`+$)'$A0(`F!``X67,B0(8F'#QM*G`@Q
MXL2+!2M:Q,B11$(D'$-B(U%BHTB')4K0J?.$3HF3"TNLH$/GR9Z;=%;`)%BB
MSDTH=?1`V?,DD,Z=V%;L^;1G!92B1@,9W4F"SJ>K4'):,;IB*LP22T%]RBG3
M*(`5);\N9?ID15NG,Z&L4'$2+%,KI$@]R?I$SY,G>5<<Q6@7\+.\?TD]*U7J
MV6*]''LVS5LE;V/'F!U#QOBDS@I253YG'JWY"6&YB!63'JU'H<2J@/6J7HUY
M\\0D-0&MT$,[<RE2="G*U2-X]FI2>8"?[JM"]&A2E_,&IUB3.`#`ES7G:4RJ
M-4?<4/Q7(FD.?7$>0(?]B@3O5T7SOGD1N^Y(9T]X0,3;NG>/5"E1MRXA55!/
M5RW5E(`$(;%"'5==1<=\2)'@U$T%OH1@4H$((A=04*1TX0J"M"*(($;)=,5@
M#`4$`#L`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O8G)E="YJ
M<&<`````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$R,#`W(#$P-3$U-#,S
M-S4Q(#`R,S<R,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"
M$0$#$0'_Q``?```!!0$!`0$!`0```````````0(#!`4&!P@)"@O_Q`"U$``"
M`0,#`@0#!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1
M\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E
M9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:W
MN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?
M`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$
M!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0T
MX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U
M=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%
MQL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_
M`/[X*^(_^"E/CWPK\*O^"?O[9?Q1\8^!OAI\3=*^&O[-_P`6OB!8_#WXQ^$+
M7Q[\+O&?BWP9X.U3Q)X!\.^./!]ZCVVO:!JGCK3?#EK=V;M;L/,2>*^T^6)+
MZW^W*_FH_P"#FCXG?MA^$_V7O@Y\(OV:?&6B>&_AM^UCXW^(G[./[2FDZ'X"
MN?B'\>_$/PXU[X7:YX\U\?!_P_/-9Z+J>F67PH^'WQHM_'GAZ/4=,\=>+[C5
M?!7A?X?7]MJFJ7T@RKUJ>'HU:]:2A1HTY5:LWM"G!.4YRMJHPBG*36J2;2;T
M+I4YU:E.E37-4J3C"G%;RG)I0BKZ7E)I*^EVKV1_%7_P3SL/%V@_&/\`9)^*
MOQ;_`&D?V/?V:_@A^U'\3?'?[0/C+Q-X"USX:_!/XQZ1X4^"WQCU73O&7[.O
MB>W^$MO\,?%/PS^'?QR\>V/A^?P7\-+C4H_AM:>$_#&@>)/`%CIEGX-U3P?J
MGZ:?\%*O^"S7[/<'[8^F:=^S]^U1^W3X-'PQL=5\">,?B1^SKXI^&'BC]FQ/
M$GAO3?$NI>&]>\/?L^_$"23PI^T/]L\<^)H?#/Q-UKQ!XF\`:3-X6\$VJ^`[
M_P`:Z?>6>H3_`&5_P1K_`."-W[&_PU\$W7[3</Q-L?VT=#^-?@+Q5\,[:U\?
M_!_3_#GPM.CZ/\6XGUV:X^%/Q+TG6?$FF>+=)\1_#32]`O;;Q1,EUH&JZ1XB
M`MBNHQ0Z?^4?[6__``;F_MQ:9^U!\6K?]D_0/@]XQ_9V^/7B._ETWQ%JK?#C
MP5!\'/"OB+QOI7Q`/AFX\-:S9ZAX@\(P^!/$.A:;X8TWQ-\"+'4=<U_P+'_8
MXT_2M!\7^+_`</\`/5?B#PYXCX[Q\\TS*>`AE&68G"4/[1I4LLRW%8NK4:S*
M5:CF6#A7>88=QIT'A<:O9XJ5!6P]9^VA/]@CE'&>3<*8.C@\%'%/,,QHXF?U
M*M/'XNE0I4X/!*E5P.*G16"K7J5%B,*[THU6W6IQ]C-?V+?LR_$.]M_V3O`_
MQ0^,O[1OPI^-MOI_@O6_%?B/]IWPKIFD?#OX9^-?`^D:GKE]I7Q&U'2I=9U3
M1O"<J^!K'3+SQV;;56T2R\26GB"2RCL]*FMK6W_,GXP?`;]I[XT?\$G_`-I3
MPCX\NK?P7^TE_P`%>OVZO@EXK^!G@#Q1IE_X)U+P'X!\=>)OV8O#OP\^%7Q@
MTVRTRRM_"7B#P/\`LH?LW:I??%?1+V_U:6^.D:WX5DUOQ7XWUN'2-5^*_P#@
MH#_P3@_:&^$/['G[$_[&7PB_;-\7>./AUXW_`&E?V:/V:(O@O\8?#O@/2/@]
MJWB3Q)-XUUNZU;Q1XS^&_@"T^.&H?#6?Q]9Z;JEIX!UKQ1XMLM#T58K:T;5-
M0\.>%;K1OVU_X)WZM^V+^W;^W7XO^,G[8_PW^#OPU\%?\$P_$GQ%^"GPYT?X
M#?&6^^('@[QC^V'\4/`>FV'Q$\9WLEN\5Y?K\+/V</B(O@1?#GC.STL^&?$?
MQ>\0$Z7>^+K#4[+X=_GG"O!/]M<4Y%BLDS?)L=E%;BF7$N:.GAHX#,\)DW#&
M:T<=E-#"8"MA\.WA\TS=X;#YM2P.#C@LN^J82-'$SI58J.G'>=XMX7"Y7CL'
M7P57+LNPJ:GB'B56Q^+P:HU).K3K5X35&E3G+#5<56^M5(SQ$YP527*_Z0K:
MVMK*VM[.SMX+2TM((K:UM;:*."VMK:"-8H+>W@B5(H8(8D6.**-5CCC5410H
M`!4U%?V:?C`5^"/_``5:L?$OB[]O3_@E7X*6.]U3X>>'-$_;J^/OB;0TE6+2
M['QG\-O"7[/_`,,/AQX\OPM[93S77AH?M`>+?#6F0XU*T\SQ[<SW6D22P6FK
M:-^]U?BK^U)XLT?Q3_P4>L?!\^DWI\0?`+]D#P%XDT/6&U"*XT^;2OVJ_CA\
M1++Q5I4.E16EU>Z?>QWG['/@FXN;R":)M5AN+2*YT^Z&E:7<)\+XEXW^S^!.
M):^MYY>\)'E;34L?6I8).Z:MR^WYF[VM%WOL_LO#W"+&<:<.TI6Y:>80QDE*
M/.I+`0J8WV;A9N?M'AU3Y(IRES<L=6F?,_[%_P`/WT7XM?MV_$[3=0\2P^#/
MBA^TW:VW@7PO>:TUYX+T]/AG\$_A9\/OB=XK\-Z1!K6M:?8ZAXG^-6B?$ZU\
M330M'>:C-X;T^'48(YK%[5OO<^423O?)WG`A11G/R#"RX56&2V!B,X55<<C\
M+X?'O[;'_!,RXEG\7?#KPW^V1^P)+XG^-/Q"\7_$/]GOP+XBM_VP?A?XT^-W
MQ=\5?&CQ#XG\<_#/4O'VH>#?''PYTKQ7\0O$6GW;?#W2]/UKP_X4:#Q1KHTU
M/!]S:>-?V,^$?QA^%?Q[^'OA[XL?!?QUX8^)?PX\56]W<^'O&/A/5['5-&U$
M:;>SZ9>0K(D2RP7VFZA:W>FZOI-[#;:E::E:W-GJ%I;7EK/!'_$/$F`Q<:RS
M15J&899B%0PF$S/!R=2C..#PU/"X>EC8R2K8+,JF%P\,17PN,A2Q,G.=91G!
MN9_3.2XN@E/`2C7PV8TI5L1BL)BXPI5N;$XBI7KU<.YRG#$X&.(K5*5*MA9U
M*490]E>+2C'P7]K;]G7PC\=#\#_%/C3X[^/_`(%6W[/WQ?T7XW>"];\$ZA\'
M]*LO^%KZ%I][I'@K7=?NOBW\-?B!HEZ/#,&N:\-,\.O;Q^']0EU^9_$6E:S>
M:;H4NC_.?[`6F?#K]FS]IO\`9W_9P_X)_?M/?%?XP_#O7OC-\3=;_;F^&]CJ
M'A?]I+X?7^L7?P)^-NI>(?CI^T3\?K;X7^,?%/P,^..O?%CPU\)+'^PK3XK_
M``\T+Q[K]CX=\*3?#2RC\87?B2/S3_@M-^RYK_[<OPQ_9(_8L\'W_A_0/&W[
M27[8OA7P[I/C;Q)HOBK7(/`6E>$/@A\>_BAXN\:6>F^&I$N-0N;+PWX,O-)G
M@U$?V,VGZO?W=Y+I<=E_PD^C?!G[*WPX_:/_`&`?VJ?B!^R5\'_'6F_\$\_V
MV+OPSI7Q=^'O[*LWQ6UCX[_\$Q/VQO""1W_A'5/BSI7A/X@V5A\6O!WB3Q-=
M_#O6=(\1ZEHGC+PQ\2O"'@OP9I?B1+'7M/T'Q=I5K^K>'N)I<*9'EG&V=9OQ
M%A>'\/BL;0QE/)\KPU7+\'A:&)?[_/*T9SS/'9<ZN(QF(KPP.`QLLLHT*^-Q
M57`X:"K'Y7XA8O#8K,L?DN&RK*JV85,+@ZCS#%XC$/%J<J:<:6"IJU'#5(48
MTN1UJM*%9S?[NK4J.+_O3HK^*>]_X.^YO@[>W?PB_:+_`.">/Q+@_:#^%EU<
M?#CX[0>`_B+H5AX&A^,O@>5_#/Q/B\&6-]IOB^]LO"D?C;2]<3P[:7GBWQ1=
M6^D"SAN/$6MS(^IW)7]>TJ]"O2I5Z%>C6HUJ<*M&M2K4ZE.K2J14Z=2G.,G&
M<)PDI0G%N,HM--IIGX4X33<7"::=FG&2:::335M&FTF?VL5^87_!0;_@E5^S
M_P#MZ3^%/BC<_P#%FOVP/A$NA7GP!_:U\'Z0NH>./AWJ?A3Q/'XR\.:/XL\.
M'5-%T;XO_#"/Q`+UM6^&GC2Z-A)I^O\`BA?"^K>$-;UZZU]?S)_X+]?\%O/B
M'_P3UO?#G[,7[*FE>%;G]I[Q;\.;7XR^+_&GQ$T35]6\*_##X.:IXQE^'.C7
MOAC2;66PL?%?Q(\2^*XM2?3+?4M0;0/#6C>&=1NM;L;^[US0XHO\]+]H7X^?
M'/\`:X^)6I_&/]J3XK^*_CI\3-8"?:_$'C.6R73+!5T[2-,:T\+>#-'M--\&
M>#M,:VT33E&G>&M"TZ$F`/,9Y7DE?'%RP[ISH8BG"M3JP<949Q4XSA/FA)3C
M)<O*XW6[;NURI:O?#*M&I"M0J2I5*52,HU8MQE"<'&<91:=^9.S6R32=^W^A
M%^SE^T=XN7XW?M"?L9_'+6?`,?[6_P"R1KOAK2_B7'X!U`0>#_BMX'\8^%=`
M\:^`?C#X-\+ZEJ%SXBT;3-;\,>+?#\7C?PQ=OJB_#KQIJ3>'1XAU".[TF[N&
M?%G]EK6=,^/MO^WE^RU#/IG[1^C^"]5\.?$GX'+XKMO`7P<_;'\/0Z7=V=CX
M?^)VKV>B:S+X=^)6@I%H\G@3XL:CIM])ID^B>"_"OC"#4O!<&GS:3_$+_P`$
MI?CM:?LE_MN_"WXM7FE:CI7PH\1:A:_`3XR^)-"TM[FUT[3OC1#K"_#G2[G3
MX+JQ2]GO/B!X)L/%]S!IL6J^($\+_#WQ/J&GZ)JS::EM7^AY\-OB!X&U_P`9
M>.?A]H_B+3;KQ_\`#VW\-7_C7PP!<)K6CZ'XTLKR[\):I<6]Q;P`:/KLFD:S
M#I&LV$]WINI7^B>)=(9SJ?AR_AT_^,_$;(*G!/$E?$Y)AYT<IS7+IUOJ_)5J
M81X.O-83,<MQ/ORD\*ZTZ3CS5(3H+%X1T*M&O&A5C_5O".=X7C+A.E_;-:G4
MSS*<QH8.6)=6E3QE;$**Q&7X^GI2OBXX:G62<J=?VRP6+]I3JPG6C'Y6_:3_
M`&J+_P#9B\6_\$K?VD?C'I]C\(]'U/\`;`\#_#?X_>&M7\?:-'X4^&FF?M"?
MLO?'KP+KK>,_B3I^FW'A_4/#GP@\=Z[HFO7NN26VG^'O%%YX6L7;5O#EK.FJ
MV7O7_!Q7X!\!P_L`:O\`M1MX@\"^`?V@_P!CSQ_\.OC3^S5X_P#&.NV/AJ63
MQMI'CKPW-XC^&&G7UU<6LFMM\5?!%IX@\-IX-226'Q#J/]G)=P-8V]VP]A^+
MWPB^'GQW^&7C?X-?%KPM:>,OAI\1="O?#7B[PSJ%_J6FP:UH.JJ(IX$U#2;W
M2-:TZX#1PW%EK.B7^EZMI5W##J%A?6=Y;VUQ;_PZ_$W]OOQ[\*OAOJOCGQ!\
M>OB]\;_VL)?`WC/]CW_@F_\`M#^(M(TWPEXT^&/_``3^\&_%76[KQ5^U[XB;
M4O$&O7/B#XL_M-:9KEU\!/AC\0-,\/V?BZP\-?#+4O'C?$2XUW1[J#Q)^H>!
MN;X'.>%,YX;Q>6TZE#*\7[;$4ZU*.*P&(PV<5,15HX>5*M[6<E3JX6M"5/$*
MK&5/V<Y5IWG&G^3^*^5UL%GF7YM2Q"D\RPZI049*GB*=;+HX>G4J.S5.*E3Q
M%&<73<&I\\8T5RPE5_HZ\$_\'(O[%FG^#/"5A\8?BOH7P@^+=CX8T&S^*7PE
M\8?#/]H;6O%OPN^(UMI5I#XW^'7BG68_A[I2:MXC\$^)DU/PUK>III>FI?ZG
MIEU=+868E%O&5_GF_P!@Z0_SW6GV>H7+?-<W^H6EK=7][.W,UW>W4D)DN;NY
MD+37-Q(2\TSO(WS,:*^$J_1'\-YU:DZ?$GB'AZ<ZDY4\/1S?()4:$)2;A1I2
MQ'#->O*G2C:$'7K5JSC%.K5J3<IR^36?XQ))X3+9.RO)TL0I2=E=OEQ$8W>K
M?+%1O:R2T/ZO_P#@Z656_P""H'BDLJDI_P`$N/@RR$@$JQ_;=U9"RD\JQ1F7
M(P=K,O0D'^5>BBOZLQG\9_X8_D?/8;^$O67YGT#>2R:=_P`$[OC)XIT^1[#Q
M-H__``4`_93M-(\16;M:Z[I5KIW[.?[5.NZ?;:;J\!34+&WL=;O;S6+.&UN(
MH[75;NYU"!4NYY9G_O4T+5=4M/\`@M#XIT&UU*_MM#UW_@F5X=UK6]&M[RXA
MTK6-9\,_M??$73_#>K:KIT<BV>H:GX?L/%/B>QT2_NX9KK2;/Q'KUM82V\.K
MZ@EP45^%^-_\#*_^R;S[_P!3N&C]5\*O]YS'_L:97_Z;S0^[/VKM7U;P[^S!
M^T;XC\/ZGJ.A>(=#_9X^+&NZ+KNC7MSI>LZ/K>G>!==O=/UG2]4LI8+[3]5L
M+R&*[LM1M)X;NUN8HYX)HY45Q_GL?\%3;"QT3]JVY\,:-96FD>&O!OPQ^&_A
M3PAX>TRVAL-#\*>%K#2KG4+'PUX;TFU2*PT/0+._U;5;ZTT;2[>UTZWO-3U"
MYAMDFO;EY"BO%^CS_P`B_B__`*_9#_Z3FAV^+G^]<.?]>,S_`"P!^<M%%%?T
M(?DA_]D`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V%V871A<G,O=VEN;FEE+F=I9@``````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`R,#4R(#$P-3$U-#,S-S4Q(#`R-#(T-``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!'248X.6$@`"``]P``
M```````S``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F
M`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_
M`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F
M,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_
M,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F
M9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_
M9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F
M9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_
MF68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QF
MF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_
MS#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EF
MS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/__
M_P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F
M_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S_
M__\`__\S__]F__^9___,____^+\D````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````(?D$`0``V``L`````"``(```"/X`L0D<2+`@```%$RH<>!`A00"D2#E<
M2!%`LV?-$#9L*)'B0HL8GQV\2%)D0X\&0UX$H+)EQH,HL8$D.=-ER),554)L
M.?+FLXX>698L*=0E4)@&20TU6A3B1IP,ERX]2.KF09-(!=:4BI&J5(E99=K\
MRO4B4*U5RXZU.5&KVK<Z4\(EZK*MV[53E?),6'2NR+U\_=)\^A'O6`!NW-AE
MN-7PX(J*^SKN6A&2Y9YS%VMM:!E20[8ASQKL?-!-9\^'-RH$<-HS:])7S49$
M3'A@:]BMG[Y^?=GA[=.\?WLV#5R@\,ZF@^/.C?"X\^&W(69TS;DU\>>7:>I4
M[CGZ[Z)UN0A3/_A=;[.````[````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]E;&UO
M+FIP9P``````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#8Q-#$@,3`U,34T
M,S,W-3$@,#(S-S(U`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````/_8_^``$$I&248``0$```$``0``_]L`0P`!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!_]L`0P$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B
M``(1`0,1`?_$`!\```$%`0$!`0$!```````````!`@,$!08'"`D*"__$`+40
M``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$5
M4M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC
M9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2U
MMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$
M`!\!``,!`0$!`0$!`0$````````!`@,$!08'"`D*"__$`+41``(!`@0$`P0'
M!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6
M)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS
M='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#
MQ,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1
M`#\`^.?VB_\`@V9.B>#M?\1_`OXA7FO:]9V_VFVT/Q'_`*'_`&IS[=/_`*^>
M*_#?X&_M%_M<?\$L/CA=:7_Q57@FZTW4#;>(/"NJD_V+KUCGOIG35O;J>OM7
M^HSXSM]!\/Z9+JEO+>36FFZ/KFI:A#!<_;+VZ_LO3N1VK_+L_;F_;6^+/[</
MQB\4>,?&_P#9V@^'!K%];>!_`^E:/IUG9>&-$_M'_B6:</\`B3_VWJVKC_F9
M=<)/0]`<5^)\(9OC>(<++"YDH9GERC:TV[JUNF]TK\UU:U[:\M_V#/<!#!8I
MYIECEEF92DY)P;6LG>RM9ZOU=TK']%7B3]I_X4_\%7OV<M9_X4/\0M2_9P_;
M;\*^'[[6]'\-^'-8/AO1?BS?:7IW_$S\.\?]![_F6M=_Y&/PYXCS_P`RM7XP
M_L2>,/V[_B[\:XO@C\*[K4OB1?Z]<?VEX_\`#GQP_P")QX+T+0]+)TSQ-XB\
M<ZIJW_(J:1H/J3GI_P`(L?\`A*,5\#7'P%_:!^`W@+X1_M/^%+37M-\+^*I[
M_6O"_B/0[@C^RK[POXC.E]B.<Z9D=LXSP<5]!7G_``5$_:SU?PCXN\$>'IAI
MWB?XA`:;XA\8Z%X?-GXTNM#TP$Z9X<_M/2@#_9*ZOJ>IZR<@C.J'!/!;NPW#
M/#JP>/R_#91D>9Y?F3DE.3A&IE%N7FNTW*]];\S2:T:;L>GA^.^-<%7P..K\
M49]E^/RWELO^%;EE:UKIW4D[VV:U\[G[[?M3>/\`_@DU^Q<9=&\47VN_M!?&
MT:?9C6/!WPK\4:EX<^&7AC7/^8EI^F:H#_;0']K@Y')(P25^85^"_P"VE_P4
M0\)?M5:;X6L-+^#0\*ZSX#M_[-\+_$"X\4ZCXD\:77A7D_\`".>)M3U;_D+:
M1H./^*9_Z%WH.>O@]Y^R[XH\!>&O"7QC_:HL/&'AO0?B1?WQ\'Z']GQXU\9#
M3!_Q,]1_XF__`""=('_$MSK>O=<^QK^F;_@BO^RK_P`$BOVX;/QE\.I/@]X\
ML_C;\,?#]CXLUC0_B-XH_MBR\4:&=2_LO_A(O#6I^$_[`_M;^PO^)9_PDFB'
M0.NJXYSQGA<HX:X-PLLSP&"<U@(^]*+O":5KZN_,DW9WNF_DS;B?C_Q"X_G"
MAQ/GCS#!PE%T\HE=5(M<MI*]FGI?3S;UN?RO6'[7G[2>EV-EIEEXV\0066G6
MEO86D`U,*(;6SA2WMX@N?E$<4:(%[;<45_I;6_\`P2M_8/L[>"TB_9W\"S16
ML,5M'*?#HE,L<"+$DAEQ^]WJH;S/X\[N]%?,_P#$3N$7J\OA=ZO3J[7^UYO[
MO6W<LYX^22CG^81BDDE=:)<ME\DK?+R5_2+/X]^`_%-EI>LZ%XDTW6+7R/LM
MO/!J`_TH@'\?S_2OYU?VG_\`@CW^Q)XL^+^L_%KPGXI\=^%;7Q3X@OO$E_\`
M!WPY<>'3X7NK[5"=4U,:9J?_`"&O"FD>NAD'_J5LU\;>$_&_C+X?Z:8O!=_J
M4TNO7'V800?\NOT]?\YK]J?AOH=KIW@C08O$D7]I:S-;_:=0OM5M_P#CZOO[
M.S_9W7GG';(]3SC^<.,..\VX"RAK)L<UF&9IQ23:LFK/E[-)Z.RLU?<_T#K?
M1CX:P.9+&8C&K,L`I<RR:5]'=.^O9ZM>3.)E^''@.7X>:!\-;GPMII\">%?#
M_P#PC?A?PX8/MNBZ9H>E_P#,/TWGOZ]SU/45Y)I_[,'[/WAOQ%:^+='^''A6
M'7=-(N;?58-''^BGC\3W/TK[7N-/\.1I%+'I6F^5-_SPX_R!G'^37!^((]&M
MX;^6.ULX983_`,^_VSGZ]2/S/:OYGPG%^>O$RF\QSWFG)RE_PL/EE)M2E=7U
M3;=[WTOH?I%#PYR3&5HQKY;DBBDDO^$>-TERI*^EVE'=;VW9^7G_``5`_9]^
M+/[>.@_!"U^%&E:%J7Q5^"GA[Q7HEMX5GU#3?#E]\1?`_BC^RM4`\,C5B-$_
MM;0CI?.?^$?/B+PYJV>>`>L_X(A_L"_M`?L5?''Q[^U)^TQHL7PL.F_##7/!
M/P_\$7'B#P[>:SKU[XHU#2O[3\1:F-)U?7_[)TC0-)TP\YY\1$<#G/N7C_Q(
M=#F_X2+1XM,AUG0?^)WI\$%AS_Q*^?\`.>M?,'Q+_P""@OC?Q1X=^P>']*GF
MEO+?_2/]'^QFUS^/8_G^>?[#\/\`Q!S[-N"EDN+2E9*+FUS3Y>9-7;N]-;O>
MVG-;0_GCQ1^C8EQ9@LWX>P2BLQW25HWNKZ+1+HELNVQ^\5Y_P4)^'\%W=027
M]I+)#<3Q22M/N:1XY61Y&;'S%V4L6[DYHK^/^X\1>,[F>>YNV1;JXFDGN0J>
M<HN)7:28"7/[T"1F`D_C'S=Z*^F67</.S<==&_7W;]/+^K._RJ^C[G6G[Q]/
M_;;=?3[O/7Z'\`:I%<>.O#?A>WE\Z*SUBPN=0GYL_P#P69/_`%#/>OW,N?'^
MC3Z5%%)#-/%]GL?W%C<?8_?^I[U_.?X0\22QZ_H/BBW\X13ZO]IN)_\`E]^P
M_K_CGVK]6=0\:12:!:RV\LWV74_L-S<3SV_\N17\^^+N3XC&X_).7=->BVO=
M+[[?Y'^BV#R[#YT[JZ\[6>Z:N_6Q]#ZQXLTO[-:PZ7+>0R_\>UQ!/_H?'_0.
M[]!_];G%>&:Y\0Y8TEADOYIHH;?_`$>#[1[_`/(.[^OY9KQO7/'G[_\`=W4,
MT7_'SY]O_H?V3Z]?[6[>P->7ZI\0_LT/E277DQ0W%]<_O_KQD<'KZ"O@\MX:
MK75XW>E]->GE^730]NEE6%P"OB''1::JWGU_KKY=1\1_&%U<6%_+%+-YOV?_
M`$>#[0?MMU_/W'/_`-:OS)TN35([/S9+7SH8;C[3Y$%Q_P`>O\_3\>OM7T9X
M[^*>ER>';^6XNA-?P_Z-;007'_04_P`\\U\TZ?;Z7'?RR6VO^3+-_P`?%C/;
M_P">?S]>:_H3@3)Z^!P&-TLM+)Z:7B]$^]GT^\_/\]S/#X['X+ZLU[KZ.Z5K
M7T5[:_KU.C/B&W4E3&JE201D<$'!'7L>**G72K!%5'DL7=%"N_V`Q;F489O*
M_P"6>X@GR_X,[>U%?;^Q?6_WHY^9^7W+_+R7W'0Z>JPZ).L*B)4NO#&T1@1A
M<9QM"X`QVQBOK99YSX)\(.9I2Z>$3,CF1RRS?\]5;.5E_P"F@(;WHHK\UXTW
MI>L?S@?;\-?[O_VXO_;3Q36[Z]EW>;>74NRX&SS+B5]O3[NYSM_#%<9XPN[K
M^S#_`*3<<7/'[Z3CZ?-Q117AY3\</2'_`+:?-\0?\BA^M0^;?%<DCW_AI&D=
MDEA^T2HSL5EN,?Z^122'F_Z:L"_^U72:$23JSDDL7Y8\L>>YZG\3117[;@_X
M?_;O_MT3\PX<^./^)?G`CW,>K'\S1115'W1__]D`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O9W)E
M96YH96%D+F=I9@``````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`T-C(R(#$P-3$U
M-#,S-S4Q(#`R-#<P,@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!'248X.6%!`$T`]P`````````S``!F``"9``#,``#_`#,`
M`#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9
M`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``
M,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9
M,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`
M,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.9
M9C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`
M9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9
MF0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`
MF9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9
MF?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`
MS&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9
MS,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`
M_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9
M_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____^+\D
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````(?D$`0``V``L`````$$`30``
M"/X`L0D<2+"@P8/85@!8"`"APX<0(R)4R'#A"HD8,:ZX^)#ABD"MKEUC=<V*
MPHPH#U+DB'!A()(B6<$,U#"E32L5`5`TJ)"%R&N!6*Q@<67D"BLV,ZX\))-5
M()HU!P*P$E/&`P0L'CR0(8@5RZ007<JT(H/JM9U29R+@RDJ052NLHH(]R,*B
M("L/+NBU\"`0T(U2?\J`\',D@K4YYQ9DZ#?O!0@6]#X0:3(M90A-`V'+R7#@
M1HLV&8J,+"-'%P06+,1D"<!O200;5ZA0`<!`C"U;:"^,L;GB5X@4S2*2$5(P
M9I&<=2X,PSS,(D:,#!G2O4(ZHUC88QU2B-;A0BX_`_[)*%S2`B+D#`W`J`VC
MN?/GTL7DKF(HN_U8T@W%T/E0(<QKI[DFD@P7P,20#3PDZ!YSBSP'771;0'??
MA+$`XI%*`!36Q04RP,1*7C^Q0)L-8)2X8!B,./@@([#`0N&$AG"Q'W\$*43>
M!7R])$-D/UD1@WH\F.A>@RNNB)]T+]['16>>`?`?4`^D)N5X(E41!@PD"MD<
MD884R2(7LZG`19+9/;%0C0!065@@*R#P`"+%78-?D%INZ25T+HH!B'Y<K,#%
M*MC59Q\@NA&$TPI/BH0(4N3%P@B==3H'79<KNHC=(3K1%D.?*JP00WX4R87-
MH8F2]],AAH11(A@GHNBEB_[2'1(#))"L``A@33)ID$NFFLI*=%E&JB(C8N`)
MBRHJ[$<++4APEY)%O9(7"+'!LCHD=&'$L((8TGER"1LD`+`L)!XAI9%=T:ZD
MPJK6+MCI?TY9@1,))+#!!BVT0H+$F>?J1%Z\Z2$8:1A;:"N@M$[)AJ^]2)`0
M6G(<I3>P:-&:2A&XOTD4ZH4"A;JJ>^LM5+&I.`&`!!M(@!7;028!4*<!OI7:
M:UT)(>&)8@\9\/&5R25Z%WG\RH"S0SCMG!RZ(PGR+XU#.Z10NV$<S1`+\IJZ
M&6]->^>RJCPG9\@6-6W,$-99MP2`>[IQ)@9MN7*6<=F]N0=S3@:`+6JN>CQA
MYOYG=^.\7'-S5[2%(?P65+(>R21NIF]E+V0#X)QM(<94!RVD1RF))U-*N!69
MVS1.!C`7^!-ZY`W:8@"4KD+FB9-0BB>Z-OUWVI@GKD?AGCVA>>FLJX!Y[$,O
M=$,8NB'.NB=F%G1Y,GIPE[GQP`<?^GK&LZYXV``D7@I_&UF_.-P"G;V?)\FL
M1+[M%.E>RA,$`?!$[<F<_C98`&S!`P"EW+X0;=8OWSP+X:O($U:2D-,-;07M
M21U#5%`%]UDO<1P16T6D8D"<R89XBUN(W:JG/0INI&6@V1@`Y\*TLX5A8XS8
M@D)<Q[R3;*144#&9OOHF$7.53"JBJXAT"N@^CP`@!O[1D@$`[D4+W#E-5-B+
M2NBB5A%N(46$GI+92*H`B66%:WX%"57'&/*8,]4O#(';GR%P54"9C(P555P6
MLXQHD$-QSPH'0(!>#L"0+1"/,]+I5``!(2^9L<(*:AS7OK`8/D2Q:2%YR<L.
M=$#'"*60,RHPA*Q4(,7"W(MS1"07#9M$$C:AY@)NV@$HS_:@Y'PJ!F;IE8<N
M<8F*(`%?;-S5"D02B,A<X"H[V`$"0N>@M'$F3KT"B154`0B']:9AL90E*PAT
M@5SJX#!?#$.J4NC+A0!B9"*I3O+:%ST,(4`'S<SE#NBX1!480`7<(EQ.*AF3
M&!FQ9>?ZI@[$&809>(IX=/X$``-CM#%LEB06S@(+3A!P`*T$X:!!*(-"O9`#
M&<S`"S/87PP.L:0,1>L05HC%*DZB&(5$]`!<(`-"%:K01)`A$2:E2"17T:=2
MR80+];'0)C.B$P^)E*0E16DB^-80A4P458*RSW:2^2S7!,(D,L"I3DUJA:/R
MZSLODE4W4V*25LAD!0>0`0N\4`:4=M6D0F0<10`UH5`14B."8`A)N_#"LW1A
M48B(GEDEV+38J+6K73B`658@`T2,)992.RM-^6.1+B@T!ZX!0!=,@BBG,*UM
M4TV*0LRUD`3!0`:+E0D`\FD1>(+OB+E*$'4T2Z.2<>RSAN,FB>X7/J?>38NH
M[76("H+$VLUXUB$CC&WEVA,&'JB@D(_5+4H`P%OF!'"FPNU(<4_8&^0FMR7M
M:5#4FOO<T*A`4L3J5'"K&Y$?2G-2=A,L=YM$J15%=KRH*^^#NH->V1:I2^X4
M+W=W8RRA$K6]):O"=2:TBO..ER(QV.^$_`NW@```.P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V%V871A<G,O=&EG9V5R+F=I9@``````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`R,S$T(#$P-3$U-#,S-S4Q(#`R-#(S-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!'248X.6$@`"``]P`````````S``!F
M``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_
M`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F
M`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_
M,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF
M,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_
M9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF
M9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__
MF0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69F
MF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_
MF?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-F
MS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_
MS,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F
M_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;_
M_YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F
M__^9___,____^+\D````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````(?D$`0``
MV``L`````"``(```"/X`L0D<2%`@`!(%$RI<.)`$B3D(&4I<2"+0"H@3,Q(D
MH<(A@(\?(P[LZ'!BQT[!@G4B`1(`Q(A..G6ZM$)DPB<H4^I<&?)2IY.=5JQ8
MM<KFP!67=NI4R?+@SB=$K5D#D%`%@!4I5Y+(J1)DUB<65U@K6M#J4&O/5H3,
MR9-$RJ%#B:Y(R'*5U+&KU+H-]G!K2A6K#I94>-6N4*).@QWD>LGJQ!46I>;-
MF_.CRI@L,X:46A-MIY@?>7;Z.+&I6&M"T>(<O=7A2HD=#]J5O.J93M<K91K=
M"*DW)*A5\JK@FM7U[H:0>NWR/33X"A5+@P$]CHT$I%VT:/E6\4RJ[>@J7ZI3
M]$W^M/?H6I%(M$X>ZEW4SXYE=7()),.#O4F<O9L7[5^4(%&'S4&%O8<:`%(=
M\UE76XE'ET6SO?>1=RN@Y!J#"T&VGV032@5=,#$Q%1)%!8ZEUUT?%G?0)0)6
MY]"+;)RV2HI\+:98B]@@00(;,<Y6TU)^=7400QZIL.%PX*7$$@DL+@28@28F
MF=)B/&48H8G$18=D4PR=E5=B2X6XU&+KM90E4WLIB5)````[````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]B;WEA;F1M;W=E<BYG
M:68`````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,R,#(@,3`U,34T,S,W-3$@,#(U
M,C<W`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`$=)1C@Y83H`1@#W`````````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`
M,\P`,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```
MS#,`S&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS
M`,PS`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`S
MF3,SF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS
M_\PS__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F
M9C-F9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EF
MS,QFS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9
M,S.9,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9
MF<R9F?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,
M`#/,`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,
M9LS,9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,
M_S/,_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_
M,\S_,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_
MS#/_S&;_S)G_S,S_S/___P#__S/__V;__YG__\S____XOR0`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````A^00!``#8`"P`````.@!&```(_@"Q"1Q(L*#!
M@P@3*ES(L*'#AQ`C2IQ(L:+%BQ@A`@"P`MM&`!ZQ6;&2<>+'CU98!0JT8N7'
MD@^MH!P9B&,@F2<[PERXXF3.C596X@2Z$V%/GT!Q!@5ZLNA!I"A]6CG:U"E!
MJ$RQ5K4J4&I2JE)Q<AUX])K9LV997:MY\N;&L0,WL@J*MNZUCVY!.F6TJ.^B
M+0#4H@UJ!>W&O'IA\O7;%T;A0';7GAWZ=N=BOV<,%+ZV^>R*NFQ?[F3<N#/D
MP759`7B<."/IO@!.<^XLN6Y@5B)'DXX!`'5DPVH#%7T-N"[MR*=C#'^].JW,
M%71_7V,5HR^CDJ\7G8EM=N4*E=(Y_H?);C%[WQA5OJ\,;W:%^477)[[O"WCU
M5.E6JK^/'W'^^8TPV"2886?XQ]]#_KT6A@'<&9;@(A(]2%R#:\'P8(02DG;&
M9]WIYU]$EV6(V696;'$A1")F!X-95HR7($0AIMC7#859<8.$",K(V!8WC53B
MB0PUHJ-?/!KGXH<,#=E7&+0%9^*+"\6BY"(QL&(E9]U9"*5"2H;!&V\J<1B(
MEDARJ2./+2[B&'20!7+CE@C%*.$9@<1@XADQW#39D?,MI*.7^FW'D8,)'GB0
MB`$"8("+V\%`(UH&`!EGAC#$<$.`!@`2X(U;T$;F?GY*&`8`!=(78*E%GA5I
MF0G):1X`_F]BMNHB-*[D4JGF-1+D@S',ZM>B?BUXTI/F&8J0E/YMAVMCGZHY
M;)\.)>@H:3>02NU)?)*FJT/(F@>#K]H!D&VX&X%+6D1"9C?JLHL8$"MI'Q%+
M'KJO;9=M#,TR]A&[YTJ4KE\Q>+BDN.;5!P"K$'6[+FGNOI<HP=!.)*0!\M*:
M+V,/OSMO10(OLG#!Y6Z$L$(TL;2:7HO9.U^U!O`&<;$,U22<2$N-)!!?L/JW
MT8WECFS07"[%9C))`L%P,6.C6EOMRQL;=)C,,HW$D7TG\\NPR![O''%!A*W6
M$DO0G<P1;E98K6_.L"FZ=5PC68G;337Y.)5;K'"Q\D:XNCQN8E\(!66E4$O1
M_!)0@&@8`Q=;"'IPL!]E9RQ!/;(DM6I!V7I3W:2%`9;:'F]A<+81I3170;;>
MK.'#`)C8Z4<-^_5X2:Z>X7F!87B^!>APF2[BZW`UXJI?C6R;^_#$%V_\0`$!
M`#L`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O:F5R:2YJ<&<`````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`W-#4T(#$P-3$U-#,S-S4Q(#`R,S<S,@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````#_V/_@
M`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_;`$,!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_Q``?```!
M!0$!`0$!`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#!04$!```
M`7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6%Q@9
M&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY
M>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*
MTM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!`0$!`0$!
M`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<``0(#$00%
M(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ
M-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(
MB8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8
MV=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/RS^%WB*\MUT2TE
MENK0O<:#)(PC$D<,=O#;27,YF\EG\F#^S07@`&]IU)D4Q`2_TB_LZ_M0?"3P
M[X6TYO'?BK1+*.TAO$O+M]+U36%>RD&HZAI(FC'AS4;73%"E4-_*88X3:!#=
MQF[$)_'7X%_`N34O#=[XOGO$0Z;_`&K=PZ=!;P7=U-IT3SRI$EN+O[2?-&G?
M9?\`CT.P7AE.XP"&?ZO_`&4?B[^W)XK\7V_@/X1_"CP)XQ\'^(?$DWAZXTZ?
MP.WBVX\/V-G`ODMXBBM(-+N#9)92W"SOJWV31UFDMXKBX%S+9JWY7+#5\ZJO
M#X"%.=:$I*5.=:E0MR6O9UITXN^]DV?V+@Z<N%LF>,QT7*ECUB)Q3O/EHQLI
M5.6/,XVO?WDI:.U[G]3?P5\;^"/B!H>G7OP\\<^"_$VA75M8O>ZCIWB72Y99
M9$TN4B&/3;77+,VEV;NZM+.12&FB@>>8P-M:*OJ..ZNTT/4!=7.I/;"X^S6E
MAI_]I(([W17O].O;&&Z>^M;2^1R5N([(W6V^3?<B,_8"S?B+JOPFTOX+>*_%
M.O>)M"\->#?%W@*PM?&DOC;X/6VI>#-*OFU:VMEU'PWXA\*:+/-H]LMI=1Q:
M<;1M=U&2[N;FVU81PC2VM+K].OAY\0_^$G^$/A_XJ:=)-+)K]II>NBSL3;?;
M+AM0CGUP:7*;C0[B>[72$8Z9>SFXLO[6>[CU)S8&T%E<]>6YG/!U'ES=/FHS
M<:D?:0?[Q64HJ2;B[6W3<7T?1_C/&?!]3ZOA<\P^8*&$S"KAYT4H.4;8MITK
M]N;LTG'[48[GB/[7'[7^D_`KP3;R^"/#6C_$+XD>;X:71=#CU*#PY:1Q:JNJ
MW>IS^(OLWAF35[Z32!I"6T?AK3M1U=]>OKZU)%J;7[5!_+S_`,%"?VAOVHOC
M%X*\6_#WXS_$'23H7B"#2-5L/AY\,=*DMOAYI%E::9IFHM!J-WJ-I#K2^+M.
M$UI;WMG<&.&V%W?*4GD@25?TT_:DT6Z_::_;$\-:3#\#_%OC+6K;PY'IUO9>
M(O'-S\,/!$MM<:Y<V:ZAI#^'](\57-]?>']1AL+[^TH%T6[BA-TIOK>$2PWG
MY,?\%&4T?0_`G@GP-I/PR^)'PL^(7PWG\0>!O&2ZUXV37=#O[?PG"_AV35]`
MUR_TG3)?%NEZEK&J^?JFO:A.NIW5Q9:9:QVWE+-/']I@*F$JXM?6HP4N6+BX
MKGOHK6<4U?UN]%?8Y,=DU7(L&N2<*F,Y$ZTH2BDDU%I7YN5N[>B?G:[/Y_\`
M^T+JW_<#3FD$'[D2&X(+B/Y`Y'D]6V[OQHKI;7Q1IT-M;PW%KILMQ%!#'/*6
MD)DF2-5ED)6U=27<,Q*NRG/#,,$E?9JGAM/W<>GV5_=M^GWOY?$NOB;]=_YE
MY?\``_I:?U6?L2S$PZ#X5ET>=K&U2.U<7-QJ;V45VL6KR+-;)'IEW9FYEM-1
MB=8[6"ZN%BDE"QO#YTJ?N3H?[*GPLTFZM/$VD:5X9TW7-7O(AJ=W?3VMM;7%
MU<OI+-->K%J-G&?*@CFD:"[M;.]E`;_1DC$K)_/!^S+XIN=%\817-U:06R:E
MJNJ_V9/<*MP;E[:\M+*,(VDS66J02168"JZZJ4VP.KJ6F4Q_U-?"/Q>=6T.P
MU>XOM5TC3$A2[DET[5ET![B)+6WMKE7ET_3)=2OX(MIN&L]1N+I[AHD9K^)H
M5,OX/A)X1YO*..C4POL)3J.M3DVIN;3C%JG=OL[IK7T1_47B!B,QI\.Y54PN
M&C6A6PF(PDZ;J48\DIJ,8-*4T[MM--+=6;L?GG^W_P"-/#_@GPO_`,*?\.27
M+7OBN:6>_P!1\/W<\.D:B-)36FM]/LULK&[L;>*YCTZWN4MFMY[B:62)!J`6
M%DNOLS]C*_U'7/V;?"6FK8:_);Z7/X:T>**2TNEDECCM;*WU8/)%8"2-8X$D
MN;A7C*)+%#I[2![U+B/\MOVW?@_\5/%?Q]\7?%_4S)KO@.U@\/V/@#PSIB1W
MM[-?6\FAVTUP9-3BA$TXO=.U.[E58S--&9;,`)<27,7Z=?L4O?7GP]66X\.G
M2D0ZGJMK%JN@V%AJ%K?ZEJFC76IN=,1[E6@%_H=FT=T)(S!&[VH4B?S%QPCP
M5?-)U'@:K52I7E1E%W]I2H2CSU$];::N,K-]%L>9Q9E]+!>$N3TW7HRQT*F"
MQ%6$JU-5H.E;VT%!R4K4K))Q34TWR7/H'5_AOJ6GV>JW^E>(H/#]FZ:U)]LM
MH-$35=,T;4]2OP9M(F%G)K&BA]-OK^"YAEENHHKP6TI83M$L7\??_!9SXY/<
MZ[#X-\&Z#XAT#X<SPZ?X;\.>*]4BNHM0\9S>';HW?B/48Y5EM;F2SU/5!,^H
M'SY;6YN+BTN)$9[.%9/[8=:.H?V%OD345M3$T=VK70DT*.&ZBOGU"YECDN!;
M,MWJ4NG-%8"V@;3[>.ZD6\EC\R)O\_C_`(+"?M$V7[07[4_BVR\($?\`"L_@
MQ)>?#OP5]G:%+"[N[.6R/BF_MHX!L@35=7RUNNVYQ'ILC?:Y1,5C_3<DH8>K
MC83A3E2PT\/2J4E*[<N9+WFG>23:TYM;)Z'X"\UQ>.HUYRG*HI8BLH5):.4(
M\D8:2LTK*RT2UT25S\?)O"QGFEG6[TJ-9I9)5C;18I6C61RX1I&O`TC*"%+L
M`SD%B`3170_V9=GD--@\C_1T/';G[4N?K@9]!THK[;V=M$]/^&_X/]/3QN6M
M?9_^!1\O/R7W??\`T@_`O5H)!IVKV-DT-GI^IB[ME37+"Z_LZVU"YLC/.L0T
M.S>Z13=#Y1/%NP`0"0R?L+-\:;SX<_">7XK>(I;C5/!NDW+:;;Z9H6DM<ZOY
MANK:U$US#_:^GQ_V?=6<M[)-,ID-O.EM%Y$PG\Z'^23]E[]K;2K6"'P]XKOX
MM,$YM+?04GMII)[B9)M/M6@NB[V:0)&!).9C+/NDC2'R?WGG1_T2?!7Q[X8^
M)GA:.SO-4LM;T?5-(@LHO#HUQC'<2F1O-:33;31=5DL91):),EW,DD6,P,ZM
M,A/X1G^6UL+4G4H4YU).*4Y*,E9Z>[=VO9^;3U^7];</9UD7$6$PN!Q<'BEA
M&JLYJ,DN6\79)I)VMT3?WGM?PU_;P\+^*+ZTUB70/%^HI_:"7VFA='U"..Q-
MO<O<+;3-8:AJK6ZWS07MT;I[=HK;S!`8IVVL_P"A/P\_:]\)>(+"724O?$MU
M)>7ME<:6D4FKSR0BZ^U/J%K-#>Z-9PFQTT3%II$NC)(\<2^5&AD9/"?V:?V5
M=&T'2FU'1]>BT2'4[%@NGZ@+6YLWFT_[5>!EF"Z7=Q"Z+"Q5?LTHC\T3&.5@
M$7ZYL/"WA7X9Z'?>,?'&K:7I>B>!O#FO:Y<WMW'IUEIEO8WNHQ:?/>D'4+AK
MB.RMGVI++]GDFDU!$\B+:7?DRC!XZI4P=>GB?8T_88ZC.+A)M5:KBH+1._-W
M2:TN[&?'V?>&>(RYY?1P6(K9C0IQ@JC6(ITTXIJ,5&I&,;IIIR6DDVM8Z/Q_
M_@H7^T#I7[-G[&GQ8\9OJPBU_P`1Z9J?@;P39S1RVZZEXOUB.WT^3[+<_;)3
M%)IVEZE<ZHKI:/OEM?LX:%F^T1_YXVOR1MJ.I3W%RL5Y<W+?:UC:29I`2[6Z
MSM)*0TKS+?7%Q=8#SM<)&500[I?UC_X*S_\`!0P?MA?$V+P;X.OKQ/@C\-M0
MN'\)O'JFW3M;U^W:.TU;Q(+5+*)0UX%@2"$S7'DQQOMN9?,^3\?9H$N9([[[
M=`]I+:0V]QM4R7,UY')-(+DGS%V(T<KH5P^U@AWG<`/VGA[+JN'P6$EBIJI6
MAAJ=.4UT<?L/6^G?;4_EJO55ZD:5)48<\N2FI1MRWT;:=M5KUU[(D#N`!Y5L
MV`!N+29;W.'QSUXHJM_9Z?PPRE>QW@9'8XV\9'.**^@Y)=OQ7^9P7K_U./E_
MG^#['7^)88;;7O#9MHHK<@0,#!&L1#'7M+!8&,*=Q!()ZD$C/-?L'^R5J.H6
M^HS/;WUY`XO=`0/#<S1.$?\`M`NH9'4A6(!9<X8@9!P***^6SS_=*GJ__2D?
ML/AO_%K?]>'^3/["?V;%63P%H]Q(H>XCTRT>.=P&F1WO;!7=)6RZLRLP9@P+
M!F!)!.?R2_X+_:SK&D?L8:!'I.K:EI<>L?$G2;'5X].OKJR35;*3PWX@FDL]
M26VEB6^M9)HHI7M[D2PM+''(R%D4@HKY'*/]WA_U_J_^VGSW%O\`R-L9_P!P
M_P!#^-#4;>W32+>-((4C2=0J+$BHH:$LP50H50S<L``">3S6=#%$LL`6.-04
M&0J*`>4Z@#FBBOU+`_[M3]%_Z3$_.\3_`!?^W5^I*S,&8!F`#$``G`&>G6BB
MBNLS73Y?^XS_V0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O
M=&AO;6%S+F=I9@``````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,C0Q(#$P
M-3$U-#,S-S4Q(#`R-#(T-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!'248X.6$@`"``]P`````````S``!F``"9``#,``#_
M`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF
M`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__
M,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F
M,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_
M,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F
M9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_
M9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!F
MF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_
MF9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]F
MF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_
MS&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QF
MS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#_
M_S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF
M_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____
M^+\D````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````(?D$`0``V``L`````"``
M(```"/X`L0D<*)`5JT"!K%@!P!#`M88$(TH4V!#`B8N/'EU[>.TB@(D@+5X<
MF?'1'E8,5W@$&5&D-)4>"SQB@1+`"I4?60ZT>!/F"0`%+M!,B5/GSA,]1P(5
M6E.I48HC/>Y9.E3DSZ?8K/[<\^A"UZ$^<QJUV)`KI$?$5BAD&*%MVZ<`W+;E
MNN?:BHIQ(Q`@\)9E7KU\]]P$8+`PP[U[=>8MP+A`0U96"JM%B5AQV\:/U08R
M:`4A@,I^+S-F6+AP9\.)0T?`3)C50\ZO*1.PO'ITZX.<2W^>K9JUP4`K6-U$
M:'`W;=:$5P2Z]EOY;MXA1=O&[9IYPHJ6\3[>/+DFP[%MM7\S1$C^,&B0D-KN
M%8\W$.+4$],#)M`PD'B#[_VFW]NS]<W."%FQ@ESZ1<#=2Y#=9MIMA.D'B7`W
M)5A8@`(JM)!"(4$"B8#_6;C'AWMH*.*(#HX("0`BHFBB&X&X`4F)++J8XD,F
MVA?(BP[::*)XRJT`ETW`:?>0>%BQ9Z18V`0$`#L`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O879A=&%R<R]B;V)A9F5T="YG:68`````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#(R,#`@,3`U,34T,S,W-3$@,#(T-3,T`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````$=)1C@Y824`
M)0#W`````````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`9@``
M9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`S)D`
MS,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S,P`S
M,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DS
MF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F
M`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF
M9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F
M_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9
M,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9
MS#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,`)G,
M`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,
MF3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,
M_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___9@#_
M9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_
MS,S_S/___P#__S/__V;__YG__\S____XOR0`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````A^00!``#8`"P`````)0`E```(_@"Q"1Q($(#!%003*ES(<.#!
MAA`C%@0@L2)$@Q8S*L2HL2,VCMA6&!A)$J''A!Q7,)#`DB6#`R9/"L2XHJ5-
M"0=@RIP)P,#*FRUSZCQI$`#0FPQ`=BQZ]*92C45_-DU*D:A!)%BS:L7Z-&-1
M$D7#?GWH\2H2L&(-DLBJPBH,.6S8(`F+)*X<&`S:E@5@`Y">N&'CZ@%T0T),
MJ`"X!`KT-[">Q8&X'/8*`'(@-H$M!YIL<<4*RYB+LM',6>(**X&ZQ+@!*+3!
MT5QN*+92&N(*+ET:')#0&BT)-H19RJ[=L";+!A*XR)D+`(D<+C>),_1ITT9C
M`&STV+#)P$!'D21]7EIACL1*]_#2*QI(ZWWGPA5IT[OWZ-ED_9#W[PO,S]^^
M9XKVA22@@`C%9&!"AR$$@&?[$=C?0`SB=R"$'PU8H(4$4M@@00E^M.!^'\(7
MXH`DBAB@AO.EJ.**++H7$```.P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S
M+VUA;BYJ<&<`````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-S$U-"`Q
M,#4Q-30S,S<U,2`P,C,U-3$`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````_]C_X``02D9)1@`!`0```0`!``#_VP!#``$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1"``R
M`#(#`2(``A$!`Q$!_\0`'P```04!`0$!`0$```````````$"`P0%!@<("0H+
M_\0`M1```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$(
M(T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%56
M5UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBI
MJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W
M^/GZ_\0`'P$``P$!`0$!`0$!`0````````$"`P0%!@<("0H+_\0`M1$``@$"
M!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`5
M8G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F
M9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:W
MN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!
M``(1`Q$`/P#^-6[^VVUP9CY=O&CNCNKQJXBF@EB+N9"$:`L8PS](1O<D9!'Z
M^?LI_P#!,3X\_&OQK\$/AMX-^"VD_$?X@?'3P=8^/[:^^(NK^*?!'@'X>>$X
MWTKQ%)I]U-IUI')?>(X_`VH>']8UR_U![VS@'B'1+*VL?MFHK]K_`",O3#++
M);&1P+RS:%O,Q(&E_?>0D,`S(99IVCMI7`*QVEQ/<'"6LC+_`*CW_!%O]H3P
MM^U+\"_#'[5=_8Z'X&_LSX-_"C]F?PQ:ZF^D:):ZIXZ^$F@6.C?&KQ!X;AE2
MW2YT_7_&]QX;T2.]M7D)@TJVT^63?!&E`'Y"_#?X0_LK?\$POBAHOP!_:R_8
MR^$;ZS:RZA:^$_CGXU\"Z-\1?`GC#X<,+35M1UKP#JWBC1KF[7QEJ.LS7VC^
M-KWQ+;Z3J=MH5G;V-G86RZ9)<S_77PN_9J_X-U/VC;P3^&_V5_@I_P`)CX@U
M/5KB^T+3=7\4:7''>37LUW9O,-*\1F.RT[4UFN/[,O-&LX;.%Y/LBP(T>Y?T
M=_;W\+_LC?'CX8ZQ\%_VG_$7PL\/ZE<,OB7PCIWB[Q58>$_%VFLL[Q1/X;N!
M>1:K93ZY`+>SFU%-T5S)"+8QL\.3_-3XD_80^`?P+^'FK_&OX$?$O5;;5O"O
MB>T?PQXN\-^+]-UG0](T*#6(K/7].\5ZG9?VG_;CVMU/<:;>:I<20WND0LMS
M);PW6BV0G`/SJ_X+L?\`!&^W_P""?WB'1?V@?V=K75=<_8P^+VNQ:+IJW<MW
MJUU\$_'UQ#/>1?#WQ#J<DU[=ZMX)\5V]G>ZMX8\0ZA-!<-JUC_8JM(TT(G_G
M&CN)(B?/;Y^$+LWFN75`LA1XR0T!E5S"03F,@EB237^EC\7;GQ=\??\`@D)^
MW1\*OCSH^CSZMX3_`&=/B7XG>6S%M*=!O_AUIA\5>$->MXI((3'";^QTS5;>
M2R3S;"[BUS21<-;S(@_S:9[)+F)I_*=)62&21""QCWVL,L1\Q<HYDMWAGD*<
M122O;MB2!P`#)V2MR'@(/(R#G!YYSS150F0$@$8!(')[?3BB@#L+ZSMA#*4G
M,";&28L"TAC9'$Q>*/,MQ&C&V"Q,%CC:1W#[I"*_MP_8*_99^+7Q*_X)]_LW
M?M4_LT^`_`'PC\.>&/A+I5U\2/%/B3Q"OC7QBOB;X+^-?&S?$[QG\.T\;:?=
MZ=\*;%;71H?'GAAO!NE:K<:YXXEGCUN4::]OC^)2_F50[00Q9(_>3F&+"/&)
M)H(P[L)P"4D:X5%*(BQ,3R<?Z*'_``;!^-/$7[0G_!)#XB?L^^*-032M(\`>
M/_BE\)/"_BC3K][W7-.T+QEI3^+I9[S1+I;?[%>Z)JWBF]U+2I))PVM6\X1(
M_LVDRNP!Z9^UW\(?C;^T!XE_8,T/Q]XZTBXN?B7^SP^NZSJI\->&M&F\;?$N
M>:T\9:]X5%];Z*]E\/==U/P5?VNG>$_%-UH^MZ9=:QI<L$VC:9<O/<7/%>$?
MV!/#OP`^$?QSU_\`:F^*'P[USX>_$[X6>)?!OQ1B?PEIWAR^F\0:V-1T#P'=
M66I^"D7PSJ_BRPN]2\-:&FK6?AJ35/$^L&34&O9X?L=C9>H?%[Q#\6_A9^TO
M8>&=0\0>)?'WP,^#&B>"?AGH_@KQ!H,?@6\B?0_!MC'+XX\-:^=1U75]5@T^
MUAMIY->\V"V\7>);_6TT^)[1+9YOL3Q_\,/`?[2WQ,\!OXC276O`,'@30_%M
MEH>N,1I6D7)^U6&L'2K>)XX8?%MQ$5T_7M>NUEU/2H+;[!#:0RQW<L0!_+9_
MP3^_:-^+'C#]G[]MG]DWXL2^)O#'QJ\(_L4?M36NE?\`"9Z?<6'_``MWX7^&
M/A[XGT_0O$MB-0M=/?Q#8)9:-):Q^([.UDMKIK$R&4NK-7\@NF+));Z<BJQ6
M2PM[E/,8_.GV.W\X`G_6+',SC<"P"M&#@8%?UD?M1_MSZ7IO[0O[8_[>OBCX
M+KX?\+:7^S-K/_!//]A[0-0UV[D/Q`UCQ!XC\5_#;7/B)8/;:,=-&B>#_A_#
MXBUK6/#]Q+/<1K'X=TC!>2&6Y^:_^#=K_@FY\!/^"C>K?MP>$/V@?#]QJ?A7
MP%\`?`GA/P;XRT1HHM9^&7Q"\4Z]JMS9^.?#5S!%!!+XCTO1O"$,:6%[&ZW6
MCWM_92`3N#$`?S;RM&LDBEK)"KNI1KN%64AB"K*7!5E/!!`((P>:*B^)NJS>
M!/B3\0?!%E>7&O6?@WQQXL\*VFN0-HMK!K5MX>UZ_P!(@U:&UDE\RVBU&*S2
M\C@D^>%)A&WS*:*`-HSQ769PQ25[>2#>?NDEDE7$>/[B7$0DP<M.J9R<5_77
M_P`&I7QP^%]QXH_;'_8T^+OQ/N_`6E_%K1OAM\5/`VB+XMNO`MUXEN?`]U=Z
M7\08-%\4V4^FWMM/>V,.@?VIIEMJ<4VI:`+[[-&JK=35_(1*ZFY6-2"C%E&P
M#C:K2,N!G!5%>0^B!G/RJ:_<G_@A?_P3L^%/[??Q3_:,U7XQ?$CQU\*=#_9N
M\!>$?$WA?Q5X6U+POI%BOBOQMK>K^'[K3?$UQXN66TGTNX\/VEV?[.LAIQN9
M'2XU74XK6TL]@!_6GXOT;]AZ]T3XT?$'QS\9/V2/B=XY\.:_INC^%-0_9QO/
M&_PV\>_#](/$^H2:5+X[\;:I\6_%UUXSCTG3K*ULKW2KK3+6SEU"35[IK>-)
MW9O+O&7_``4=_9P^!G[,FA?!'X*_%70/B#\<-2\%:M8^8WC2R\3:?\,[3Q!<
MZE%<_$#QSXQ6?^QKFZT>"?5=5T?0%O1>S:K>0VKH\BQQC^1#]K*-?@)\9OB1
M\+/B%\>-.\5KX`\5W.A:%K?@C5HM8U3XDZ$\4$?@WQ;+-H<\NFQ:+>^#K?2[
MN<Q27FFI?WEY'87TJ,A'K7['WB/]G*;7-#EM8O#FIW.HB9XKG5]!;S+EK6YC
MU2ZM9-2U2"62S:TMX96$%P1;M-+*T:$R/0!?_:E^.OPA^(GB#X2?#JV\/:%\
M2M!_9RL/VG/VAOB?X5U.^UR?P!KNHQ>%4U3P1X&N[W0-4TR[FTVX6#0%URUT
M[4+2+6$OWM8-2CN'O8Y/ZF?^#<*W\8>&?V%_%7[37Q'\/^"]!\>_MH^+/$EM
M\*O"GPV\$^'/AYX2T'X4?`?P5K7AWP]:>%?"GA^QT\3:-9:GIWB2Z-Y=6UWJ
MM[<7-Q>ZEJ5_+*U[=?RI?M%_LB_&GQE^U'\:X?A;X&\0>)/#_P"VO\0_A!^S
M?\#/'V@^'9IO`$]Y\4=7\.WOQ`T:?QC9:;#X9T34O"VA>%#IFJ0-=^9%9:AJ
M0F"'3[M8/Z\/V*OB'\+OAY^UU:>&/#NM1CX!?LN_!C3/V+OV:-`TXV=K;^*9
M?"]EH>C^,?&]G;13#3[)O'GBZ.?4-:\8W6Z'[1=V-BUR\NOVL=R`?YF7C*33
M-4\7^*]3U;5#;:KJ/B37;_4[>\N(+6[@U"\U2ZN+V&ZMIF2:WN8KF21)X)42
M2&56C=592`5Z3^T9X$T;2?VA/CMI6CZWX6N-(TSXR_$_3]*G@O+6_@GTVR\;
MZY;6,T-_;326U[%):QQ/'=V\DD%RC":)VC=6)0!S6KDIX7UZ[0E+J*STEH[E
M25N(V?5&C=DF&)$+1JJ,58%D55.5`%?>_@F\N]"_X)J?M-#1+JXT<:Q\0_A!
M-JPTJ>73_P"U)K+P#JTME+J/V1H?MLEI+<3R6KW/FM;R33/$4:1RQ10!^<-N
MS-=^(4))2VAT]+9225MT9FD98%/$2L\DCLL84%W=B"68G[K_`&2;6VA\,>(+
MR&W@BNTU",I=10QQW"%Y](#E9T42J6'#$,"PX.:**`/[9_V9[BXT_P"$/[$T
M%A/-90)IW[:OC)8;25[:)?%_AW]CKQO)X?\`%:QPLB+XDT*2[NY-&UP`:IIC
MW5PUE=0--(6_*;X-3SMX(^&<!FE,.M_M/?"/P_K,)D<Q:OH-WX.\2:S=:)J<
M9.R_TBYU>XGU6XTVZ$ME-J4\U])"UU(\K%%`'\L'[4.C:1X?_:8_:)T'0=*T
MW1-"T3XZ?%O2-%T72+&UTW2=(TG3?'_B"RT[2]+TZRBAL]/T[3[.&&TLK*TA
MAMK6VAB@@BCBC1`444`?_]D`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]A=F%T87)S+VAU;7`N:G!G````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`Q,3(T,2`Q,#4Q-30S,S<U,2`P,C,W,S<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````_]C_X``02D9)1@`!
M`0```0`!``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!`0$`
M``````````$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#``01
M!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT
M-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)
MBI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9
MVN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0````````$"
M`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A
M<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$
M149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7
MF)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;G
MZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#\O_!?P_\`#WA3QHEIX+\`ZK8Z
M[K>O'3_'6NZO:6"7ESX<O'61IDB>_N='M]-M/#UQIL5A\VL3IY:R7N)VELH/
M=/%:7&B6-CX:M$N[Z.^\*>'O-L?#VB7OVW1+;7K>YO6F\.>("/#7A>VN]/T>
MZMO$&I7LEIK]J$NY=+-NE_;3R'TBV\/Z;X1L=`UW4?"=MH<FG:G<:;XINSJ^
MAW?AZ"ZN[M=0U**TT[[9=R6L4]^LFF3&"1'CU1+[S'+G:OD/Q/BUS5M6TVYT
M]`FL:3?Z"N@2I=ZCJ6F_V'!?[[#PO#J!FCT!,V%VJW<,)\Y+M7M))8A#);K_
M`"/7QV(S.LI8J=>6)HQYH2DY*,;<JLN6R=K[.Z];']IT,EH9=@G'#<BA)OFI
MQ5T_:0M*3O=ZJ4D];:^K/T2_X(Z_\$W/@)_P4!\:>)OB_P#'K0K_`,1_"SX`
M6_A?P1IWPDTW5Y-"\._$KQY*-4BMO%OCKQ;X=CL=3US3=`\-Z5X6\:S:%HNM
M6L/]K^.I[?4%E?PI<Z'XB\%_X+V?L*_LR_##]N3X(^&/@WX=T3X=>$/&WPE_
MX2/XA^$_ASJMMX:U#4H;'5YM#T^\LH9=+NO#5O?:U#8#45=]$U&;6KJ/4M6N
M[BZNM1><XW[&GQA_:2^&?P4_:`\)?!1/&7PV^%W[3-O=>$OB+XQEM)F^(GA'
MQ;=V,NCW'BOX+1Z=-HD(LK*UOO$/AZ?QG8:E?P>'GF>VFM#XB\,:-JFDM\2?
M#V75],^'/A;QUX^\;_$1/@=H[>'OACXC\?ZY9^*O%7AKPW+K/BK5[FSE\7ZW
M-JVN^)=*T:]U75-7TM;_`%+Q#!X8T2^L/#T'V'3]'L],LOM\%Q+A<OR7"X.A
M[*GF<\9#GK2BYSE%PJ^ZFVWJ^6UDNNFS7P-/@W&9IG]?%9@Y3RF>&>%ITH\L
M(6A3BZ<9)1BK0DJBBKN35GS:V/Q6^,G[`GBWX;?!O]E_XD0>,_`6H:1^T%!\
M;+C2/$.F1^(+KQ4T_P`,?B!;>#[S3]:^'EYI%OH]D]OJFHO9:,='UVZ?Q9I%
M@=4SI=]!J$<OSMX_^`>IQ?#7X=:Y\/\`P]XNO=4GEU.3Q[>Z/:ZIJ5K!!XHM
M;*Z\%7VBWWAW3HM+U+2VLME[<F338C#+>S122"59)'_;;XN_M(_"V_\`@G^S
M/\&=<^)WP9U(?`/XS_%;XG^&O''A[XJZ[XC@T3X=?&JTEN?&'PP;P.NB2>%0
M5\1VT7BJV\76/CZP7PIJ$EQHNI^&8=1@U;6K_P":?ASX;\(0:Y\*O"&C_&_P
MWH>B>+?%5M_PD_B/6YKW2+7PKX1^(4]I8Z#?7?AZT_L[5=:\-Z?"MOK-OK%C
M9RZ'8:=KEC'HC:SH<>GZK??1?ZUYUAU!UZ-'$QA&-15:E!R<7:-[2:;27,[:
MV\D[->-E_A_D&8SIX+^T982O/%8K#Q<JT:CITHN;ARI7=VX0DDTW%^[=VN?"
M4'@?]L>.&&/3/`GQ2.FI%&FGF'PS8K";%4"VAB64^:L1@$9C$O[P)@/\V:*_
M;:^^`_AJUOKRU'[<'[$R"VNKBW"'Q!\1E*"&9X]I4^$GVE=N"N]\8QN;J2H_
MUW=]<)@KWZTEO[OGZ?>_E^I0\`<O<8/_`%OQNL8_9EU4/^G?]7];>9>&)=&E
M\0:AJVJ^$-=TGQ)X6O+"P^)NJZGK5GJM@=9U>RMM9C,EGXHT^WTZ_P!?E?4(
M]0AT33;R^EFN9VE,]HC_`-G6W3Z@DMA>:AJFGZWXON7NO$WAJV'@?7=%\*:4
MT5YK<L1\,>*KO^SCHDFC)>ZE8W*WMI%)<O%:3VM\Q`FW2?-]WKFC?$+4_$_A
MGXTZW-XMNM(U>ZU[PKXM\^\@TWX?7]]?:A=WUGXF8./!?BB>]\27=O8V%SI-
ME9:MHD,HAN=19H<1=WJ'B71-(LO%>C^-V*VRZ%K&@106T.E:GKNKZOJVFZ)I
M3Z_=>(I[?5H]`;PO'HJ:=X:UT)-8V=JT\EQIUY=3+<1_"5,NG3BHRE/GNDXV
M]Q+1.SM>_2U[:=58*6-H5/W<,6VK7:YD]$XKKY]M==#Z?UNX\53:I:Z1J^VX
MU318=(D\/6FBQ^-?[/TV&WT^$7,$VLP:SIMO>:\FHRW0U'1]%DBTO671]3^R
M++=29_/?]HWXDZCXS_:`T']G*\^)NI_""YTOP?IJ:!JI\4?\(7\/=;^(GB[5
M_#EYJ6M?&;QCK7BK2-1\._"70_`L]T/$5MHGASQ5JTNLQW^DV^C:H%\RX]I/
MQ+A\;7,_A.V;5M/L-%\.275MXK\93I<Z=J^O:[;QVNC>%OA_I<-I<:QJ&B>'
M-&AD_M#5)+ZRUF[U&UEU&QU>RTV:WLH_R1_:I\'W=MXFM?B)I5[J6H>"=8BB
M\+WNI:E=SPS7HT&*&"PN7L1]JEU!?)LTO[2]O9;K48I[B2![T6,<&G6OM\(9
M/A*N?866+PU.LEK'GCS)3;II-:V3M)J^ZZ>]8^3X]S?%Y=PW5GE^+JJ<:T6E
M3DDX_NJBYDTK[/E[>]VL>O\`Q&\$?!KXK?%76]8^(O[=7[$?PRTZ;Q!X&\/-
M)^SS^S1^TOX4^"FG^$[]]9\(^,M7\/>'O`O[+7P[T2]DTG1-'\,>(O$OB>_@
MU*?XE:1XP@OK?Q/XA\:R:[HB>*>+_CW^TUXB\/>'?A_XR_:C^-/QB\"?">;3
M]-^$VBZ_\3OBAXI^&WAW2/!K6VF>&[SX>^"OBE9Z5=>%/#::3HVD0Z+X6OO!
MOAR*PTFTTZTU/PS;:C!=,_B4GBV-FC&FG3]'B+_:+*2RLU:>/S?WT+12$O)9
MI'-)+=?9D*6LMQ<2O=VTX6)(K=B-9UZ[L]!TM1?ZE?R3"U73%DFOI/-DB-Q-
M=)!!<SS2O<W9GD>SL+C=$7-Q(MQYK#^B_JV6*A7>-IPCAX)0TIQ;:Y(ODO:]
MGOZI:H_DNAG'$#S+"U<NJUZ>*BY5I5'4;=G)*4ES:)MR5[6TVLMOTP\/?\%H
MO&GA_0-#T'4_V9?V9_%6HZ)H^F:1J'B?Q%X$\?R>(/$=[IME!976O:[)I'Q4
MT?29-9U>>&34-3?2](TK3FO;B=K+3;&V,5K$5^7NJ_#I](U34M)U+5;TZCI=
M_>:=?F#3QY)O;*XDMKHP^:5E\HSQ2>7YBK)LQO`;(HKXIY3PY=VC&U]/W:V^
M[^K^EOU^/&_B.HQ_X5\1HH_\O5T4?[O2W_DOF?:<T_C"&'4]`O=9\/6?AS1Y
M;FZDCN=/N?#NCQW.HW&C:K->:-<2-_:.HSZHFEVS7"W]S>"UDO\`48D5+CRK
MB)D/QV\2>(/%=UJ6KG^P%UC45FM=0\J[N]&N&M(TT^TMHKRY_M=+O3[>WM8K
M6WM-2184CB1+LW=PDMY-^Y_[2G_!&+XJ^&M3U#2?V:OC3-\2HIK>ZU;P5\.O
MVC?"UKX+U7Q;X9BLK=['1OA7^TSX?E\7?L^^.O%IF:>WM/"/Q"B^"GCM[6W2
MU7P[J<UN^MZA^67PO\"3:GIWB?X>_$G2G^'WB3P!K+>$?$_P[\:6D?A?Q)H?
MB379Y[VQB\0V=MO:73M1EEGDT_Q#:W\FDK;7%@3$%#0GX')^(^$N(\+[3*,V
MRO-:%.,'5E&4:<\.IQ356=)R522BK1>EESJ]FTW^AXC`YMA\3+"T\)4P=2C4
M3G7JTYNG5@KQ=)2M9\TKVE&Z?LY)2?+(S=!NKG2=2TV[%]JLNLZG<ZMK.IQ:
M+J.CSQP1?V<;**XN+J+4IY-'GET]8VT^QALHK9;.:)4M%!`$$7B31[$V:R7.
MMZ8+2P&E:#;>+V\,ZOIFJ->`W;&?P*?"FC7NG3PI.=.M+W_A+'_M.S@M]58Q
MO>M&GHO@W]C7QIXFTW6/`/PU\6ZO9>.K"?4O$?PL\.V/BBUUWPUXT>.5M5\2
M?#&2YT[3=*B;QY#9:A#J.D^&`LMYX@LY5N[*\@%U%!!\]?%/7O%7@[4KV7XH
M_`*?2&\%:-_PC>JZAX'\?>/O#EG9>,K94L@/&&@^.$\1V6G^(+.*WEN[WP9I
M>EZ;>M&!MU:1V:[G][!9)B*4X9IE=2GBZ',X^VP\E#V3LIM\K?-[O+O9KMLC
MHQV19YCL#.I7P*E@N2SG"FZT*D]+1E3O>":4GS[*S75V\U\0^`/V=[N\U"#7
MM.^+_P`.=<N[6?5(M5TNT\-W^BZSJ*:E(=1M;+PG#IVJ7\6GR6KJ+.6/Q8YM
MW2268,H^R0]E\'-5_9)^%WQ`T;Q)\0?ACX]\:?"7PBOB>]\4^'O#?C:ULOB9
MXIU2]T'4--\-7^F?$#2+?2$\$^'+>[ET_4]=T6#2'NI(U*C4UN?,NY?TB^"_
M_!+;PS;?L[^'OVX/VV_'?B[P_P#`;1=.\1_$KQ+\&[+3=2T[Q!XQ\&?9K[2/
M@O%HNL'?K-KXG^+7C+Q7H,&BV:V5EH$N@V#SWETUS,+M?RL^'J6^O:SJFE:M
M:Z??V/A[P5#X&TVUTG3M,8SZGJK:;X3\/Z1YDFF,=6U(ZG?:9INIRWHU*28Q
M7*VE[*#%?OVPSZ.:T,1A\+F5;$8FAB%3Q.$IV32C%<TY2E&SY9.,6EK[T;)I
M)GSU#PUS#"SCCJV5991P[PLZE.I.JU47O4VH^RYERWB^:]_=ZI7LO[1/V7?^
M"#_["?QV_9G_`&=OC?'^R]XRV?&3X%?"/XJI_:WQ2-WJNSXA^`/#_BY?[3N[
MB?[1<ZAC5Q]MN)SYTUSYDDOSLU%?U'>$X/#O@?PKX9\%>'M-M?#^@>$/#^C>
M%]#T'2K*SMM+T31_#^G6VDZ9I&FV_P!F;[/8:;96D%E9P[F\JWACCW';DE7]
M6Q&EWBT]+KVE/1^Y=?!TL_N/F9+&*34<!A'%2?*U3KM.*<;--3UNDW=>5NA_
M/;_P3"\2^(_'^C>)-$\=Z_K?C71K_P`'07-]I'BW5;[Q)IE[<E;MS<7=AK,]
M[:W$Y<!S+-$\FX!MV0#7X:_M]VEK>:Q\'=>N[:WNM<UOP+\?M(UG6KB&.?5M
M7TGPQ^U5\4-#\-:7J>HRJUY?Z=X>T33[#1]#LKJ:6VTG2K&ST^PBM[2VAA0H
MK_-/P9_Y'C_[%\/_`$]1/[1X_P#^2AXI_P"P[`?^H,SX^^+VM:QX9\%WUYX;
MU;4_#UWHGA5?$6C76AW]UI-SI'B"S\3ZK:6FNZ9/82V\MAK%K:6UM:V^IVC1
M7L%O;P0Q3K'%&J\7\0OB)\0/B/X,^$&@_$/QUXQ\>:'K/P^\3:_K&C>,_$^M
M^*-*U77;JW\837.M:EIVN7U]9WVK7$Q,L^I74,MY-(2\DS,<T45_HOPY_NJ_
M[!I_E$^*R_\`Y%&/_P"O4O\`TY$_=C]KXFW_`.";_P`%[*W)@LY/@_\`\$V-
M*DM(3Y5L^F?VE^S_`"?V:\";8FL/,N[M_L;(;??=7#>7NFD+?S3?LLV%C_PU
ME\`-,^Q6G]FS?\%#/@!HTVG_`&:'[%+I$?QL\%Q1Z5+:;/(DTV.*..)+%XS:
MI'&B+$%10"BO@/#[_D><2?\`8=7_`/3E(X^-/^28RK_L74__`$E'^J9=*INK
MDE5),\Q)(&2?,;D\4445^NO?YK\X'\U+I\O_`'&?_]D`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]S;75R9G,N9VEF````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#(Q,#$@,3`U,34T,S,W-3$@,#(T,C8U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````$=)1C@Y
M82``(`#W`````````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`
M9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`
MS)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S
M,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68S
MF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F
M``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F
M9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F
M_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9
M,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9
MS`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,
M`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,
MF0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,
M_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___
M9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_
MS)G_S,S_S/___P#__S/__V;__YG__\S____XOR0`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````A^00!``#8`"P`````(``@```(_@"Q"1Q(4*`5``@3(K12
ML*%#;`M979M(<2(K``P?-D0HL:)'BA<S:L38\:-)BP!&ECS)\EK*C2UC4GPY
MT,I*F2Q7$`0@TXH5F31MRF1U$<`*EC1YQI3HT^<*A$<KZA2H%"=(HJR>0MW9
M4V%%HC0'`KCY\>"%LQ<`I$WHL.I)LVC/KD"+$691A!X1TE5[X>G9NCLOQH5Z
M#6[:B7A=_BVH-^Y:K7\K5E4;%N+?QH_YNI6<EC%:`HW5^CV,F*="A53C@G:L
MN;1IS(OY?G;<-_)IVF</RA[<>&[:%7-WL]:->S=4W+09ZL8,&WGQG00&0Q+N
MG.Y&Z=.=GP9\G2ZD[-5%'SXTO'8[:XUB$U:/*_ZA;/7(%Z)/37L[V_GTJU>>
M'Q``.P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T
M87)S+W)Y=2YG:68`````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S`W
M,"`Q,#4Q-30S,S<U,2`P,C,U-S,`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````1TE&.#EA(``@`/<`````````,P``9@``F0``
MS```_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9
M,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_
MS`#__S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F
M,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,
MS#/,_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S
M,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9
MS&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`
M,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EF
MS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_
M,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PS
MS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,
M,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`
MS/\`__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9
M,_^99O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__F?__
MS/___P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"P`````(``@```(
M_@`!!`@`H*#!@B0`D""Q8B&))RH0/EDH<&!!@@03DC"@T,#"%:2>&'"B`ED5
M$BI4;!PH0$!!EQ01`O"X0H63/*H8DJB2;.&3/`L#M`Q@@%6@%0@31E1((L^<
M9P_S.+'F9$6>4E59"F3%RDH@*RJ93E1!RLDSE:1(E`)*`L\39"566`QTU-JU
M:W1K+E3QY$E:%:6:Z@&@!RB@)ROD`K"2V`JKN]=*6;%R4B5$$B$1DQAU^0^)
MP8NM%%SQ&#+D)P%0_JRLT`G#)P`4T]68N`K7N]`".0D$Y8F>9'R?G&RHDB"`
M0*P6KK*6IZ"*QX!4!%J[*D^>)ZNJ."%U4C/!*]?X_CJ3@ZQA=8-JN5;18^B:
M$T"K'*K("'Y%84^J\E2Q!HAQP2K7/$.*7<\D1I$!`PT$7E/(D-*)$WK8=0TT
M#0&PREVL6`,;"0DFF%!]3S"7!REY6/.,'ERH4`*'>I`R2A6Q-=2A``2Q<$T5
M*D"3QS.K.&.--:5`P\<*@BP$B#5(0+''%0FV)$!"-B:WW#/'+'>7-5\Y\40G
MU6AH12G1R,42C0:T@A=A`8Z"S)776$/*'@(^`\V`;98@E),)80B`"GF,XLR`
M$E[Y3"?+02.A7$["A"$)-W4R*"EM0@;-**0<TZ9=K-B9Z$"S7+,*GYV,8HTS
MCD+F9C("_OB,-="TTD*B_@5!YD0G)%K3H(\_6H/?JFV2$A(KLV#A)%&X;>=@
M-0)VXHRAT#B#!!6>D`)(,J1(=U<K"#Q)`H;;/4/>,\B,LJJJI,C1+7,,0=8*
M"\1.N&4UM#ZCYC/5/#&'K\\\X]0S?5F1"&2)>'37*G+(&6HUI"!CC2I(_,$5
M5WI4X6U:5MPURRPSW15(%<@@:PFXXKJY`B#(!?+$B3ON9MI`K,CR3"GB/C.'
M$ZN$BPR]R>2:KQS.\%LQ9!P!`DTI5`HX"A(['N,)I2<])"`)-U<!GL4*!;+*
MJ@D?0PH>2.!1:8.K9GA-63]&;-I,@8QH(JO.2.7$N4""7=B/G:QP-F%4R`D9
M("M.F#N'37G((8=UYM([Z'.0S220X@<M;I!QCC_>>$```#L`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]A
M;F=R>6)O>2YG:68`````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,R,#4@,3`U
M,34T,S,W-3$@,#(T-C`V`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````$=)1C@Y84$`00#W`````````#,``&8``)D``,P``/\`
M,P``,S,`,V8`,YD`,\P`,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`
MF9D`F<P`F?\`S```S#,`S&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S
M```S`#,S`&8S`)DS`,PS`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S
M9IDS9LPS9O\SF0`SF3,SF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S
M_P`S_S,S_V8S_YDS_\PS__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F
M,YEF,\QF,_]F9@!F9C-F9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]F
MS`!FS#-FS&9FS)EFS,QFS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9
M`)F9`,R9`/^9,P"9,S.9,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9
MF0"9F3.9F6:9F9F9F<R9F?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9
M_YF9_\R9___,``#,`#/,`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,
M9@#,9C/,9F;,9IG,9LS,9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,
MS)G,S,S,S/_,_P#,_S/,_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__
M,P#_,S/_,V;_,YG_,\S_,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_
MF9G_F<S_F?__S`#_S#/_S&;_S)G_S,S_S/___P#__S/__V;__YG__\S____X
MOR0`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````A^00!``#8`"P`````00!!
M```(_@"Q"1Q(L*#!@P@%5EFX8L7"*@DC2IPHL4K#BPT97H1(L:-'@AHQ9K1B
M4>3'DQ(S5@$@<F/)%2P=KD!)4R#&ARU%,@3`$V/-CSJM6,FYD63/GA=_3GQ)
MM*'0ASB1\IPZ4RE"BTPOLARZ0NA3K5ICPJQJM>#(K"IS(JT2B&N@5:L<EC7;
MM&5/J%8"L5JUDN7;57GG#A2)M&[7O'JM[1U:)2\K5H$$*\PX5BQ,EHU7!;J,
M.9"USXI9@58L&5M)BRPMW[6BF;-#SZ`?CV9%$RM4;(9O-O:*&*[HT<"MH40;
MT[)#DDSUBOX=''BUY]6L13X)EBAKP!G_-M\^.OKGZ1]#_E)F:.5QV\?>N:L'
M#MYC5M9LV5H#G'B]?>"KAB?%MC<SY,;/W2?@=V5=!!=)JT`7W&/,Q;:*;)_!
MQ=Y<0VG&&G35/`98;P]:<\V'U\"5&&2!O#6:9&QUB"%<FJT"(BM"N:CA7O/I
M%6(5JWQ&FV`+Y:7@:'"!&`A6)1;9%H[?L1:A8*PQB&%Z,.:%W5B\C<664,M!
M-M=;3W:IHX4D.90C:"25"=M\?&V98)<8?ME6F$B2V5AC9\+%D56!L.DE<'N-
M"9IOBHU6Y%Q5L*+GG@XRI]EV0K7WDX^'_HC?FXXU%Z5D%ZZ((61^\@FAI7"5
MAB-T@#WW&&,/L@AJB0&25II"_BPN=&J,0^[&%H-[O=D6;)J].E"/1?9)ZH/]
MX57?7KGZBM!;Z+4:VZ[UA::9H\H.Q%>CQ#HWFX752E0B;PMQ"5V?;74[$;1%
M,M85B\B92Y%C)5[9V&&VW>EN0O`.>>107SUT;T0E:@857LCM-M2_!M$WI$KD
M]5AO0P@3M-F<>#WDE4B]E8AP7/P*Y11#<V+D%[&]WAMP6@Z!+!Y;(VKI+F`P
MWH8393?-R*V[USDZLTL&PCBMO<KZ9H5!(:6XUW[8E&DNL<D6]!*2##(4<8S1
MA>IT5ROP6B+2+P?L&[5E9ITK:BPAO"NVU.(V5D-3]61V7F@?Q'985$V]J]4&
M<=9V9=T18X/W07L'3E;?$06^]^"F04RX0%88CA1!&"]NFN`60;ZV4Y)O1A56
M*;]4'.+W5CFP<72#;BY73L&]=5,\`8VS6%;,9U%KEZ_M^KUZIUP9Y9(/YCA5
M<O6>=TL]"A]13L6_&A```#L`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O8F5R=#(N
M:G!G````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$P,S4P(#$P-3$U-#,S
M-S4Q(#`R-#`P-``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"
M$0$#$0'_Q``?```!!0$!`0$!`0```````````0(#!`4&!P@)"@O_Q`"U$``"
M`0,#`@0#!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1
M\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E
M9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:W
MN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?
M`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$
M!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0T
MX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U
M=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%
MQL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_
M`/X<O$UH+37-6MRQ98[G*$Q[&"L#(%V;FVX#$9W$$#/L*VBZ)?\`B37=)\/:
M/:W&H:GJ^I6>DZ?:01*T]W?7TT4%O;P(6VF25I`%W':"<-\N379>/T#>*+V[
M>V>!]2ABN8;7"%F,JB`1JVY8RP/S!G*)DA6*CYQ^CG_!(7X6Z'JO[2:_M!?$
MC2[FY^#_`.S)X-UGXQ>*[XZ?-<6]Y?:!9O#H,6FI=0"RU"ZAU=;&]FMI7(,*
M3H(YDA9V^NXIS^/"W#&;YS-Q4\+2]I3BK2KU*U17PL*-&-ZM656LZ<(J$)6;
M5[*]_!X(R*MQ/G&295!2D\;5HTI1C[SC3C",Z]62@Y.%.E1C4J2E*RLG;4_H
M%_9&_P"""7PFL/A1X$LOV@/$GB+6?'3:?/KOBV/P?J,&FZ99^(_$`M=0N]&@
MU*YLY%U"32=)AM+!A;1J'U"XU.Z01/>F"+W3XX_\&ZW[-'Q.\$:AX9^$OCCQ
MC\*O&]QIWD>']0\17<.L^&9-32X%W:RZS;01:;,+.ZNEA@OYHIFE@MGEFCCF
M91"WZF?LG_M+_"7]JOX=:;\2_@WXHCUVP6S`U70KF."/Q?X;NYUE6.WUGPQ%
M<74VF'4KF*,6ETMLEEJ,6+;3=3DNG6-?I7QO\3/`WPN\+3^*_B)XVT#P-H%M
M'=R3^(/%.O6&FZ4(H+A+-3:FXDCN+F>6\GL[$0:>MR(-1NH[2XN+<!IQ_DMF
MGB[XITN-Y8W$8O/*6/I9I]=JY#)OVE/#U*L7!U*49-1A.ZC/F5X1DW/E2=O]
M#LTX.X+>0+*,)@LD6#Q.4T<MCFL*:BHU*5/E52,Y1NJS]V3A%JIS6NFO=/\`
M-6\<?!CX=_LW^+]5^%'[05_XRT[XT_#6YUCPCXK\$6NBS2Z?I.LZ7?W$YEAU
M::>&&]T>Y:W1=/U1+*-=1@NHK^TMY[!)+B/Q5/%>B"TOK73YM/L$:*_-FFJ0
MI+=20RQ2"!!(@C$4L@*JA96"N0<$`U^_/_!R1\(=#E_:%^!'[1'A.U36+;]H
M_P"&-N^HZUIXFNM,\0Z[X/M-/CBU6*:W-NUY=/H6K^&-2F<VUDL4ES-:6D+6
M*W%M<_S.Z_9-%?7,5M;C'FVD)CDC*-!,I4-&Q_>LGFM\N&V8S\S+UK_5?P^X
MO_UWX,X7XJY(P_M&AB*=:$4URXC"25'%1E&U[TZETI?#):P;24C_`#2XSX7I
M9-Q+F^25*\XK!8I4J-1N[DI\M2"5M4I1;NFDK];NT>WA\72PPQ1>99GRHHX\
M^:HSL4+G&PXSC.,G'J:*\I:TD!(,.""01ES@@\C.><45]G==U]Z/F_[,H_\`
M034Z=)?W//T_K?T76=,SX@\&KXDM;K3K/5+O3+34ENK.YL[@:6=1CCU%EM[C
M)!CMFF(/F8)`^8=1_=G^S7^SO^S?\`?A'=^'_A+X7^R>$3X<\#GXHZP]W?W6
MH>+=,2.W3Q/JUR/,NUM_LFB:IJ]]9V&F0K-'=16K1W3S01M7\.OQB\1>*_$E
MAX7NO%FNS:W=6T,MHMW]E@L[@`VL%Z4>2(X>2<7!B#YCV%?,YW!1_41_P2%_
M;;T_5?A+X:\-?%?4[K2-2OIY-`T/Q+KJE='\2ZAI$\-JME;ZA=6Z64>J10;)
MKS2KN8M!;QF2-[W(C/\`,/TD<OSK%<.Y-G67UIQI8+&4Z.8X#ZPJ$<11I3C*
MC)^_&3E)Q27)&4XW37O)G]K_`$,\QX<I\2Y]@,PP-.6?8O+L5/A_.:]-SHY?
M4ES4W2G2G&T5[&<O>G:%DU*2CO\`4GQ)_P"">/BG0OC?\3?C%_P3WUBZ_86T
MWPQJG@32OA^=7^(%_K'PZ_:5T3Q!H>J7OB_QIH.GZ,VK3^&[CP]JUM9P:CX7
MN=$NM#OVU4M/:V,D$AN?6/V:O^"5%Q^T+^T3XFA_X*#_`!&_::_:*?X>_`O0
MOBMX9\87>EII_P"R9J_B#68/#$E[X,TOQP=>COM:U;P[?>(HM$U'P#IFBZ'H
M^O:UX0\5:W/J.=(71+^[\+_CIX)G\4>+K3PNEA80:9XL\1V\=LO]IB*SB:[6
M<RPQR^;!;6VLL(_.AMT>UN8E>,2(DQ*?JC\(_$]QJ?A1KU]9\2/I-S<*J>&;
M?7KRX\,V21I<F36[32;IXS%?ZH+VZAU.X,\MU=+*1)<LC212?R5G?B9C,EGF
MF*QG#="@L;E<<)AL1"A1>(^L3@Z:3S'%<F(GRRDM=&VE&+N]/ZCXF^CZ\EX7
MRS,\EXBGCL35SQ9MBLSHXKZ[E\H8BHIK!4\)&=2G1E'DG"":BY.<O:64*=_R
M&_X+J?LL_%CXN?L]?`KQ;^SQIFF2^(/V>]=\7ZA?^&84430_#<^$?#:0:SX9
MT<*QUI?"4.CK/=06XM;C991[+>[=%AD_BU^,OP_T/P#J%OX>@^)O@G7=2NO!
MEOXY?7]!UN:ZN;+5=5$LNK>"/$6GR6*W%QXDB@2>26U8V/\`9BX^:8_,?[:O
M^"NO[?>D?LV>'/#?@?POX;N_%?Q:\:^!_%FHZ%"VJV=OH>BZ;/!/IFNWVJRV
M\HNQ>6<2SQ:3IMAO:[:V6?S(R1#7\5.F_"-M3N/'<GC;P-\1KGQKI?B6[L/$
M_AN62R\+3:)XBOWM;C0[&VNKG1=2NI]6N+35+@WT%Q*HO;.%+9Y;8W9F@_J'
MZ+>99]1\/%2SC!U<+EV$K57EE2I9JHL9-5*[C%.4TN>3O)Q2ZW:/XO\`'GAG
M(:?&N6U,KQ%3$9Q/`SQ>?8".'K?[+B7/V>&4YNDJ4W*FU*T)S<+VJ)2NCX__
M`+2UT<+)"ZCA7W2_,.S?ZC^(<_C17ZR:=^P)X#O=/L;R>?QG;3W=G:W,UN?$
M]HQ@EG@262$LMB%8Q.Y0D``[<@`<45_2/]LX!.WUN.FG3^[Y??\`]O'Y/_JM
MC79K+9]'_"E_=_O+M^?9GQI\0[%+OPC?SL\1DT[4=+GMXG"G[2EW!:VD4/SR
MPK&L]M!)=,QD4*/W+,O^O'ZN_P#!*G]H;X>0_!GXR?`#XR^!4^)OPV36_#_B
MW4].>WCNM1T+2[F/5=.O_B)H%G;0OKD=SHL\6DRZW-IK/;BRU!FF:7[%B[_*
M[4Y;;4UU#PM?J4UB:S7^R$FBCMQJ][<6\K:$U@LWFP3?9I1]A4.6CE9O-<(`
MT-?K5_P0#^%W[.'Q=^./Q?\`!WQ(^+!^$WQSOO!%E8_!"XU7RK'P5XBN;[4=
M1;Q#IM]JL[Q3(((K/PV\N@-&8M3-Q<6T/EE#YGS/B9@,#F?">/H8BE4K3IXA
M3H5J-HRI58/FIUH)K65.2C+6,DVK-::]'@[Q)C>&.)<NS.C6IR45&&(A.+4*
ML9\D94:D>5N5.HO=:49*TI<U]$?JA\'_`/@G9\(_&Y/CGX<_M1ZQ;Z==7<4E
MOH^DZBG]NZ;8>42;:\GMY3)920)(/($P^W6C1*RK)*H6OJ7PE^RSIMCXX@L-
M9_:U^*WC"VM+J*'3/AAX%\=Z]>:E+!%M:.+6YW^Q>19%$:>^FGT\V:0F1)KA
M(]TP_2OP=_P1X\-ZYJ4'BWXB6>D>&=;TV^D%W+\/=;OM+C\10P/&+*_O+;2=
M1TK2]4LM5&'NE:WM[U(7>-+EI"L@^2_^"W/Q=^'G_!.?]A#Q'\-/V>=(T+PS
M\2?C.EQX-L/["D:PN].\%:G97J^/_&@U'284GNKZ/3''AW2;Z^O8KG^T-;L]
M35V:U-E<?P_A>'.(N*L[I9='-Y8[#8C$_5*L\?DU.&(E3YU3Q"AC%!^^H.?+
M.5"$>9)J2T/]",7X[<'9#P[C\5A\JK8>M+VDYY11JX5Y74Q4(0GAJM"+PB=.
M*K3YU!N$TE=VNI'\H'_!1#X^>`OVP_VS;OPGX-U>'P7X"^&%AJWPK^&/C0W<
M%QX<@\1>&C?:?INO76KPK?ZI>Z/XRO[6_C^USV-O+<)J%I?[88Y"4^P/$?PY
MU[Q5X1TOXB0>,?A[XDO=>\*W3?'#2_$7BG3;;QK??$'P]HWAB&_UKP]IBM%?
M>(QJ-[<O/INMQQ:;<):6QL(=.G=_.7^;6UU_5K;3/)TZXEL[S=<7<.HV(AL[
MN&]N(8HKF62XAM_M,[201?9;5C<H;&V?;"3.@G;ZVN?BK\28]/\`#.@OXNUR
M[BT'3-&MH;W5+J&_FL[B^MDUO19TUA+2UO8[J&RFCAW7C7L4DEG'<2QLA^S)
M_>&6\%Y!EG#.69)2>9X"GE=!8>FXUZ;CB7R*,:DU3FWH_>?-J[-6NU;_`#JQ
M7B5G+XNS/BG&*GC)YWC*BQ-*:YOJ=#FO24;WO%NT$H)^[[UE=L_=31=<\'IH
M^DHGA2`HFFV*H5L8G4JMK$%(=]65V!`!#.JLPY8`DBBOQNTK]JWXF66EZ;92
MZ9X0NI;.PL[62ZDTJZ\RYDM[>.)YY,:D!OF9#(V`!N8X`%%?,/@6-],TK-7T
M=YZK2S_#\/-GWJ\8[)?[-A]$O^7/;E_N]+?^2^9\Q>.26\#_``]O6):\ATZZ
M,-VQ)N8C#>>*3$8YSF6,Q&.,Q[7&PHFW&U<6/#EY=Z<WCC5-/NKBPU.SLM!O
M+34;*>6UOK6[BM-9EBNK:[@:.X@N8Y88I(YXI%E1XHW5@R*045]?Q)_R)\3_
M`-?/T1^4<'?[[A?^OU#_`-/(_;[P-^UE^U1X<^#]E;^'OVE_V@="M_[/N?W&
MC?&7XC:7#\D<>S]U8^)($^3`V_+\N!C&*_*[]KCQ9XJ\6?%/]IN^\5>)?$'B
M:]MO'/@6SMKSQ!K.HZS=6]I>6^KW%W:P7&HW-S+%;W5Q;6\]S!&ZQ3S00RRJ
MSQ(RE%?DOAY_R.J?_897_4_3^/O^1*O^PM?^EQ/C>S1/)3Y%YEMP?E'(+C(/
M'.>_K7UMH<$$OQ%\9VDD,4EJGA?P;*EL\:/;K*G@&#9(L+`QK(G\+A0R]B**
M*_><;_"I?X_U1_/D_AK_`/7R'YP/G:_EE6^O566156[N555=@JJ)G```.``.
M`!P!P****X#=[_-?G`__V0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]D:6=I;6]N+F=I9@``````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#0P,#`@,3`U,34T,S,W-3$@,#(T,S<T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````$=)
M1C@Y84$`00#W`````````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`
M,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`
MS&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS
M`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,S
MF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS
M__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F
M9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QF
MS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9
M,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9
MF?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,
M`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,
M9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,
M_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_
M,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_
MS&;_S)G_S,S_S/___P#__S/__V;__YG__\S____XOR0`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````A^00!``#8`"P`````00!!```(_@"Q"1Q(L*#!@P@3
M*ES(L"%!68'T6`EDS:'%BPD#!0*TL>)`:-`.81QY,2(@4H"L&`QD917)EPNM
M5/DSLXK!)U:NP-QYD(LU0%4`Z;EIQ<H>GD@%LK*V)>A!*"SV6`&4=*<UEE,/
M6EEQA<65HE5?@D68$XK1G"K#CDQ[L,J>*U]5YE2+;:+%0`CAZD0K<*A:*S(L
MLD(H52"4KW0)VFW8*F]:*X?I%E4)EZW"P0MQ)B[Z]>T5EPLQQZ2+5V#.R@Q+
M)6[(4:!>N*(1EEX]T'+MHE&N1#&J!YI"*+1K)Y3Z%DOE5K$+LEQ]FF%.J44#
M7;.67#C=*V\M2H0"+5H@5M>@_K%*3K$JYZ^5M]HVR%'6-5:"P%\+[Q';JE;U
M=[Y.OUZA^_FER!<>:*R(QY,,+)C%PH(8N>1>--2Q\MTLT;RG%"N@*62-+-'(
M0N%\@9@22((R1+%@@BNP8%-HULPW7X'1[!%(A4MAHP<B@4`CBWB-$:3C?RZ*
MV,J0"6[%@@PK/&$1D!6*QTHI@<P"XG@"SN<D-L_(U^)TR`F"""O(;;4"3/])
M62`KRD`IG8M2;NEB-.!%,XMX:@HRI"FM?#G;2U6"5*"(:[KYX3526GD-H*8D
M:@J80PY9'4G@M0@G-!15Z.)\EF*Z)42)*I,HF..U(DN&/$%S*30B2KEHA5+.
M4NBE_E+N44JBLS:*'X15;>@BJE&6`M@5%5J3J8NMA`=EFK."Z>*C5KD8Y42E
M?&7*I2Y>H9$57%"Z*'+S4>A;8M#,^1T+46)%(:O7X(C(1%9`]!TKELZ9GUH1
M6L-"%S(<((,5X18*S0I=""*##*Q<@>-X\\U+&RNS3(3O%01?(V>Z,0S,PD1X
MZH$P-`JO)C$B5W0!&"*8@GAO%P%;,6>`'=.FD8"%6F/%`2NL('$@7\6''"+!
M(<0P*P^R"8T5\4E,:*'C"=+S005>:FF+A[AI:;@T+FT0E56:$J!&LT@H,81=
M!\*SU06U6K(UR"$W'KI-PD?V0>)=VJ*=W4+XXG>FO'W0_B%56A/SI1I%M*?>
M`AVR:)6$$BOA*K)T13A!H4XGR"&"!")(Y8@L*HN$T2#VN%+6M-C*G/""">?.
MK"""2+2?8X/P>X<(/0OJ:5L^.-G6H"I+A!6R:G<K@<B"NM*/CQK(*JM@F&FA
M.P9R"""KI-1?S]&K8KTJ4\'J+"#6&Z**(501OLKUA:A"$[560J]**J]@8P@5
M>NM1116&_)&**MBD5.RK'7*Q2BI_".`6_A"^X,R/>]<S7Q[RH(HJJ"U4R.$>
M3?ZP/NO19'H[B9[ZU@=`+9""%%2H0A[R9*L(`N5Z]UL?4%:4%`FIXB2`2$4J
M8%&(%(YB@6,RR"KR@(P\C"*!X=A((0%;PY-`/"$EL@"*]PH!"/7E`0]^*4@I
M5-%#4GSOA5<$"B"X,#:81&L%5?#5"E10/@)6@0JJP$,>E+02;"S0>H7XPQ9J
M^,)5/.$)$MI)S59PB$"L`$DT`43-5)"'*CPAB@3980!3@3Q9'&(+310;*[:B
MD9?XD04K",3`:O8'+AQB!3%8@1[8B)`%4M`0R6/%$>=GA3PMZ'8-$9-*_KC'
M*ASB"2P()0L1LHH_Y&$57*C9%?9(2\#LD2?'%(@?YV>1)LZO9ELQ`#%S6#.8
MY)`@F-1C,@5RS=9Y\YO@I$M````[=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V%V871A<G,O;6EB+F=I9@``````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`R,#4V(#$P-3$U-#,S-S4Q(#`R,S4R-@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!'248X.6$@
M`"``]P`````````S``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8`
M`&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9
M`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`
M,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9
M,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``
M9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:9
M9F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`
M9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9
MF3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`
MF<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9
MS`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`
MS)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9
MS/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`
M_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9
M_\S,_\S___\`__\S__]F__^9___,____^+\D````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````(?D$`0``V``L`````"``(```"/X`L0D4"*"@P8,($PY<.#"A
M0Q(02>29F`<`0X8."R*)")&B1XL7"3K<&-&CR8(AL67D*-'DQY0K.;I\&?(A
MRYD405Y,R+(CSHHP$?;T.5,G1IX``A146O#D08P;,R*\EI&J3@`D(4K=^I1@
MGJ$&I$HDX;#AQ((LQ7XEB]!L10`]P_*<R-;@0@!GT<I\VY1HU[LY>[IL27/G
M6<$_<Z94N90E$J=P%2]F'.#FQX(&)"\^*)BM5KQ`)\--&A?`G-.G*X;>7'=H
MUL=?)Q/\##<M7-BK6=>M'1')P;.R]>ZNC5OS9MX\B0(7#8!JU.0^C=9L?HTJ
M[8<HCQ>L;GWX2>8'N0QG++S3H?B$F9=?#`@`.P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R
M<R]V86UP:7)E,BYJ<&<`````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#<R-C<@
M,3`U,34T,S,W-3$@,#(T-3,P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````/_8_^``$$I&248``0$```$``0``_]L`0P`!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!_]L`0P$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`
M,@`R`P$B``(1`0,1`?_$`!\```$%`0$!`0$!```````````!`@,$!08'"`D*
M"__$`+40``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A
M""-"L<$54M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U15
M5E=865IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>H
MJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V
M]_CY^O_$`!\!``,!`0$!`0$!`0$````````!`@,$!08'"`D*"__$`+41``(!
M`@0$`P0'!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P
M%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E
M9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6V
MM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#
M`0`"$0,1`#\`_K7^%.B>%_CG\8?"'[4'PQN5OOV?OC1^Q#I'A'P3=6&DG3+3
M3+?7O'LWBZ,1PK<"RT6YUGP_XET>5M"%G]IOM8T5+@-8"ROX)/R%\&^#?'G_
M``4#_P""/7[9?_!-3Q9X.CT_]J;]BW1-6_9T\,P7>FI:VWBG6O@]&-4_9S\>
M>'GU.6S:RN/B3H7A/2=%;5!.UI;7=[<ZI<Q_8[WR7Z'_`()-^)?VV/@%^RGI
MG@'X#?L9W_Q3_9@G\;7U_P#L\?%KXG_M#^&O`OB'7?!OCGXB:W+XF\<:M\*M
M4TW4/%'@+X=Z-8"VUK1_"EM/X@U\07-_>Z8^KV5VTS?O;I_C'X/^'?CSKOP[
MC\6:4WQY\?>`=%^(FO\`@BUN1_:2>`_"=S%X27QMJ-B;>6/3=,2_N8M)M;_Q
M!>R:AJ9M)[+1[=[?2[MD`,/]G0>$_A-\'_@5\![J[T[PYX@^'_P;^&7A!=`N
MK^.X%G>^'O!^@:1=:"FK-.]G?:[IMU9*]YI"W@U6ZL9;?6(X98Y!<'Z.U+48
M]*TVXU&>"[D2TMC/+;6L(N;Y44X=OL\+/YHB`)8P,RMAB@9<$?S^_P#!4KQ'
MXFT_0_B_XI_9=\7?$7X8_'7X6G2_%GBOQ]#X\-SI_@HW]YHUC!HOC7X"?$.#
M^R?%7P:^+^D:;9PZ/XU\(R:SH\OB19M!EFT+Q!'<6)^%_P#@C#_P<,W7QM^)
MUI^Q?^W;<^&O!'Q;O-0/A_X2?&&SCD\.>#?&>OV4&VY^&?BRVUBZED\,^*[F
M8*?"7GZC]GUU!#HT]XFM_8I-<`/W_P#VWO&7A?QE^Q_^T9=^&_$>GG7?A_\`
M#35_BYIT+9M]8L+[X+W%G\7+6X-CJ@L[BRAM=5\'V5CJ&HVLY73YI+:XBO+.
M]@@C'U1K&B>!/CA\.-+'B'0].\5>$O&&CZ1XELK6Z4S&5=2T6#4M,NM)U.+[
M'?:5J\<%W%<:5KEA-9:A:RHKV\MN2%%SXC_"WP#\6?#VH^%?B%X:LM>TK5],
MUC1;V*5I[6ZN-+\3:+=^'-8@COK:6WNX8;G3M:NK.2V%XZ8,3@//!;21_!__
M``3G\2_$[PAX>^)W[(WQ?\2V7B#QI^QYXI'@'0M;ALK1[_Q5^SSJKWTW[-_B
M76;J'67DN?$-G\.O#\>E^,+M[+S[_4XV61VU5;F=P#Z%@^"?[1MA!#8Z5^US
MXI32[**.TTU-=^&WPVUW6TL+9!#9KK.N7FB/>:SJJVZ1C4-5NW:YU&[$UY.S
M2S.25]8I$BHBF-,JJJ<I&3D``Y*HBDYZE54'LH'`*`/B/_@G1J6GW'[&_P`"
M/"MO80:#KWP?\"Z3\`O'WAL00PW7AKXD?`UYOAAXVT6_A@)%M+!XH\,ZA?:;
M;2&-KS2-4LO$9%Q;Z[:7$G*Z+#\-/@%^W3\4M4\5ZIJ.C^(OVTO#?PNN?!FO
M^*%M!X9U'Q7\%?#6I>%-2^$WA7Q0?)M]*U6'PJ^E?$*P\%ZA=?VAK-[J/C7Q
M!X6M[Z&VUR&+\"_V4_\`@II\7_V=/VY-)@_:K\.^"-"^#G[7Z>'/"WCOXK?#
M#4KR3X5:Q\:]-MM.\)_"_P"/VG:'-`LWA6Y\>:;86?PL^,UAH)FTW3=2M_AI
MXPU"VLFCU>Z\0_U#?M"?L_\`PG_:A^$?BKX+_%SP[#XA\%^++&WDD@AO+C3-
M7\-ZG93R7>@>,_!NN:1/:ZGX9\:>%=<2WUK0?$GAW4K'5M,U*U@N+/4`5B1P
M#S_]J']C?]F7]JS3M"O/VAOAUI'BB?P"NJ7'A_Q%=:UXB\+WFA0ZE;1MJNGW
MVL>&M<\-7-_X5NTAAN-7T76KZ;0K^>+SI+%9RK5_"!_P4U_X)1?!W]E[5OB9
M^V+\!OVR?V</%UG%XH&N>#_V6[FVL/$7B?5+/Q;=6&B7^E:%IWC+Q5XL'BFU
MLK">;7Y[G4]/U*XTN\E,L3PR00,G[L_`G]KC_@J7^P'^TK\9/V0?VG_A5X[_
M`&]_V;_@K\.[/X@?#O\`::\(Z=II_:0U/X.>*-3U+2?`=SXBT^&_L[?XHZEI
M>J:+=>&/B!/:Z6/&.DZR++6"+S1;^&=OU3^'<O[#W_!5?2_"7[0/@S6(?B-I
M?P_>[\+2Z/+X8\-:;J'A+7[B4:EJFD:_)X@\'7OC+2-9MQYNF73>'?$ECIMR
M+036QDCN!<D`_G6_8&\9?MA_!G_@GLW[07Q9_;V_:>U#Q'X,^*5A\+=&_9]\
MCP[\4-'L=2O(?"NI_!;POK/BGQY9V_C/1'^*][J]I:Z9XG.H:_X,;PMJ&GR1
M^5J$J78_JH_9#_9@U'X"Z)XC\7?$GXA:S\8OVB?B]/HOB/XX?$[7)K95U#6]
M(T^2TL?"O@C0K*WM]-\-_#KPO+>ZC9^%M'MK=+@6;1WVMW6J:[/<ZD_`?MB?
M!G]ACP]\#/'?C_\`:>\(>"_"GPR\'>$].AUKQK;W6H^&O%-E8Z!:V?ASPO::
M%K7AVXTOQ!J7BNRNDT'1_`5A#/>:S<>*FT>TTRTDE@LH[GNOV&/B/\2?B?\`
M`6T\4_$676KZ*3Q-KVE?#K6O&.DV^A?$7Q%\-M).F6FEW_Q+TS2]FBGQ_'JY
MUW0M7O?#]I8:+JT6DV.M6=NC:C/-,`?:`&`!MV8`&T8`7_9`4D#'3@D<<'%%
M`7:`O7:`N<`9QQT'`^@X]**`/P&_:WNOAO\`';P?KGA+]I/_`((N?M/>)O@C
MJ5G"D7C?P#HWP.UOXE:9"8Y[V/4;;X>?"GXL3?%?PTD`B:'4KFT;[?)!YUC+
MI\D5Q+9-U7_!(G]NWP%\4(O%?[%$_P`:$^+/C;X"Z?)??"/QUXAL-7\->/OB
MA^S[9:O%I.@6_P`1O!'B6QT3Q5X3^-7P8E>W^%_QET;4-&2:XU#3M"^(*7-_
M9^+Y!!^YQ10%0*%5"-J)\B*5<.NU5PHPP';D94Y4D'\WOVO_`/@GYX$^,/BC
M2?VG?@CH?A3X4_MV_"9)_$/P8^/=K82Z:VJ:Q9Z=<V;>!?C`NAM:R>-_A?XS
MTV>;P;XNM-7M=4UC2]&O;?5?#5WIFIZ5;7<0!T?C'4SH_P#P4F^#Z:O$FF:9
MXJ_8Y^._A[PIK=VES##XF\7:3\7/@QXCUWPS:W:Q16=QK.D^"]-U+Q%::;N?
M4$T>#6]5M+6_L;"[\G-\`>*?@G\'OCKX_P#@=^S'X-M_%_Q5^*_Q,U#XM?'D
M^'Y=*T[P1\,9+G2?#OA_5M9\2ZC;1P10SII^E:5;Z5X(T6*_O;GQ)=:G-J=]
M9W<EX\FE\*?&?P:_X*+?L^17/Q"\%W'ASQCX.\5WGA;XJ?#>[U6YT+XH_LX_
MM`^#(9-`\4:3:^)M`NM/UGPYXET*+4=6_P"$=\6:!>6#^*?A_KEK<64\^A>(
M=1M+G\#M*_9^_:V_8K^+/QVT;_@GKXS^&MQX%^%TVHVWQG_:#_:1^'>N^$M&
MTRU@\,W_`(P\3CQ;\:GU._\`"?C^[^'$UQH&C:1X:\&>%;@P^+KO4M>\;:"Z
M:1`LX!^P7_!0?Q!X`UOQ3X:\(S^(M-^(7Q6TS3=.\,_!3]GR[\-V?B+PG#^T
MI\<]33PG\'_C+XZ@O)-2TJ^U+X7^$=(^(7CCPOHVJV5V=$T#PIXY^(5E;?VE
MIOAZ<?IG\+_A_HWPI^'/@7X;>'Y;B?2/`GA/P[X4L+VYD9[W4H/#^CVND1ZE
MJ4QDD>ZU"_CM1=7MQ-)-)/<R-*\CL%8?D7_P3'_9/\;7.B?#/]LG]INTTI?B
MSXT^'UOXL\*>!Q/K>M:MX3U?XHZ!!+X\^+OQ9\9>*A#K_C;X[>./"CZ3X,U=
M]2TK0_"WPI\`:3:?#+X=:9IVFZAX@BU+]L!G`W#!QR/0]Q]YN_\`M-_O'K0`
M@`````````Z`#@`>P%%+10`V,DHA)))122>220,DGN352ZXM[IQP\4%[+$XX
M:.5;=462-NJ2!7=0ZD,%=@#AB"44`?DO\&T30O\`@M!^VAH>B(NCZ+X@_8\_
M90\:Z]H^E*-/TO6_&4GC7XQ>'9/%NKZ?:"&TU+Q-)X?T?2="?7KV&;56T;2]
M.TMKLV5E;01?2'[<=E9ZKX+^!6A:G:6VHZ)KW[8'[,NG:[HU_!%>:5K6GO\`
M%O2[Q[#5M.N$DM-1LWN[>"Z:UO(9H&N88IRAEC1E**`/M<LQ1,LQ_>J>23R-
M,>0'D]1(!(#V<!Q\P!J\%5`$151$&U54!555X5548`4``````#`XHHH`****
M`/_9````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O879A=&%R<R]A=2YJ<&<`````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#8R,S4@,3`U,34T,S,W-3$@,#(S-#`R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````/_8_^``$$I&248`
M`0$```$``0``_]L`0P`!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_]L`0P$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B``(1`0,1`?_$`!\```$%`0$!`0$!
M```````````!`@,$!08'"`D*"__$`+40``(!`P,"!`,%!00$```!?0$"`P`$
M$042(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B<H()"A87&!D:)28G*"DJ
M-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(
MB8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8
MV=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$`!\!``,!`0$!`0$!`0$````````!
M`@,$!08'"`D*"__$`+41``(!`@0$`P0'!00$``$"=P`!`@,1!`4A,08205$'
M87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#
M1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66
MEYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7F
MY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`_P`_^BOZ+S^P%^PG\5?AHND>
M'_#O[27[/OQLTO3;UVU_Q#HOB;7?"FHRVUC>W*GQI\'_`!+I*^.?#]SY]E-;
MSZQ\)_B!\9-%L(89=4U_1=`M!);V_P`[:9_P2'^(7A'P'XZ\>?&?1O%FC>&M
M.^(/PS\%_#WQUX?U+3;SX>_$#3?&OAWXRZYJ^L^'->31+LWMYIC?#71X8[.[
M73[O2/[8N8-?T7[8UO;P>;C\WP&69?C<QQ]?ZK1RZBL1C*5:G4CB:-%U51]I
M&CRWKTU.]JF'=6G*,92A.4;-_7Y-P-Q%Q!G64Y#DV&HYAC<\Q7U/+*E#$4OJ
MF(Q3H?6(T)8F;C##594^7]UBE0J4Y2C"M"G*Z7XLT5^_7[3G_!$GQAX%_:"\
M2>!_@+9?$;6O@EJ^B?#/QK\&_BK\5M7\%^&=-\;^$/B;X&\->*]/AL/$FL:9
M\/\`0_&_B+2K_6=2T+5M/\`Z=J%[!?Z+J%I%I,UQ;'SV?%3_`((.>.?@!\(K
M[XQ_M"_M%^$/@KX:!D;0[GQQX`\1>'+?Q%+#B>XT'P]H?C?5_`_Q@\7>*([$
MK<06O@?X-^*-"N7N=/67Q%917<LUGT/'8%K">SQN&Q%7&4</B*6%PM58O&1I
M8J,9495\+AU5KX=24U=U80BK3;?+";7#4X4X@HK%3KY97P^'P>(QF%JXW%RI
M8/`SQ&`<EBZ-#&8NI0P^)JTK*].A4J5&YTXQ@YU:<9?@117NOACX(WOBK4C9
MZ9J=U<6\MP]I831Z.YNKZ>1S#9K#91WTSO))*\)DMXY)'+,+6&1YG1J]5\<?
ML6?$;X>:U>>&/&0UGP=XJL!"]YX9\<^"]<\':[:)/&)8FO-*U9AJ%KYJ$/;F
M6U$<\961)-C!J^DH<.YQB8J5#!NIS*3C%5\-&I*,;7E"G*M&<XINSE",DFK-
MIGS3JP5[MV6[49-+;=I6UNK:ZWTN?&M%?2__``S)XF_Z&/0O^_>H?_(]%='^
MJ?$/_0KK_P#@=#_Y;Y_GV9/MZ7\Z^Z7^7G^?9G]1_AGX5V?C"QL]=^*OCS]M
MKX"^"=6TQM6\/6?QO\7Z`_Q%\6V(;S?[0\*_"K2[N[\4W6@1JMM+<^+O$=CX
M3\(VT<4]_<:Y#:6XD'3Z/HO[-OQ%^#?QTT7X+?M'?'OXB^._@MX5\.?%[4?`
M?C77M(\6>"M1\''XD>#_`(8WNJR:AX:GO?"-IXBT.V^(VB:C'!X3\2^.-+MM
M/74K6;7(+J-X9_Y^_%?QF^+'Q6BO+OXB_$+Q/XODUF\DU+6FU>^61O$6I.]O
M(=1\2S0Q6]QXGO[:XM@;.Z\0M?S:>ZN+%D#&XGZKX*?$CXR^`/$.O:1\$M0U
M^'Q'\6?"EW\)=;T'PWHZ:_J?C;PSXCUG0M7F\(1:0+#4;N]>_P!>\.^'[^UC
MTR!=3&HZ99/9S(ZE7^%S?P-RW.,BS:"E1PF/Q6`Q"RVC#%XUX"ABITD\/7Q6
M(K2J5ZL*4U&:C&E3IMW=2E./+"/]$<(?2+XEX8XEX?Q]2O4QN6X#-,!5S:K4
MR[*O[2Q>5TL53GF&$P=*E2H8;#5,7AO:T/:.K.M'F3I8FC+GG/\`JZ^"6K?\
M(Q^S[\"?$GC+_@KE\1?V;O$/Q)\-_$E?A9\'/$UEXHO/"2+\(_$$O@R7P5X4
M\:^(_BEX9^&'AC5;FSE\,_V!INMZMX/46GB.#3]/@DAFF9_YV_\`@I5\?_B]
M\7/B$OAGQ]\6?B/\4=3:TBT>QU7XD^!?">A7VC:+8W.H2:I:V^M:1XJ\4:DR
MBX14LUM+JZ\/:]I&J2ZEI>L7<%S'Y_S-^UOX^_:=LO#GPP^"/[0&F^+O#FF^
M!M*U;Q7\.O"_B[P;:^&+K2]'^,-AX2\:ZEJ=I>2Z19:SJ]MXHTY/"^J"+4;R
M_BTI62*R32[B;4K:?QKP>^O:AINC#7M9UG4X-$L/L>B66IZE?7EKH>F/.UQ#
MIVEV=U+Y>FV[SEKF2&UC$+,B#[I4#I\/?"7!9%+(JE7%5<1FV%P-&GFT\+FV
M:8O*:U:G%1=;!T\1B512DHTF_P#984XMU81I*$8N/F>+'CEF?'&8<483"X?"
M4>&L?FV*QF31QG#/"^7Y]@L#7KRJPP.+Q^6Y:L95Y(U9P<IYA7K2G&E6J8JK
M5]I*?V9\/_V1=:E_96U;]J/0OBM\!ETKP7XR?PKX@^#T_P`4['2/VB-'MFNO
M#5KI'C"S^'&IVUA=Z[X9U75O$B(FH>&M3U._M7L;RZO=/@M[6>2VL_'[]JO]
MH#]I?_A!;[]H3XJ>)?BQJ'PS\*1^"/!VN>,7L=0\1V/AF&8W::=J7B?['%KW
MB)A<F6[DU+Q/J6L:F]S/=W,EX\]W<O-\\VYCB@61L!G9AD@9)R0%#<84[,_,
MP4'))`Z>=>-O$\EE;K;6;!]0O'^S6D`!8-*SQH4!!`/EB0&7.`\ABA)"LZ+_
M`$9&G1RO#RQ&*EA\34HSJ5,!/ZI2IU\'0JTXTXX>%12DYR<6X<\?92J1J<DX
MM7;_`)\=1348TU*FYP@JZ524HU)1E?G<;+E7P\L'S)22:;.C?Q?8([(98<HS
M*?FB7E20?E>Y5AR.C*K#H0#D45X__P`*\:?]_-=7SRS?O972W:1'DD^=V624
MO*ZLS$J\CN[`AG9F))*\_P#M/.WJL+&W2]2%[>[:ZYM]KKS?=7%"G_,^GVO3
MR]?Q^?76)#6=J1G_`(]XARK*<JBJ>&`.,@[6QM9<,I*D$^A_#/XF>(/@S\0?
M!WQ6\*-I2>)?A_XBTKQ7H4FL^'O#/BFPBU71KR*]L9GT/QCH_B#PY>3PW$4<
MEDVI:/?);7BV]W#$+F"%U_,AM9UA\[]6U)LLSG=?739=\;W.93\S[5W-U;:,
MDX%1OJ>I2(T<FHWSHZLCH]W<,CHP*LK*TA#*P)#*0002",&OB9<74I471E@)
M34J3I24JT>62<.22E'V;]V2;3C=Z:7UN=BHR4E)2LTTTU>Z:=TT^Z:NGW/TZ
M_;;_`&X_B!^W=^T+=?&WXW3>#]!U2[B@TK3])\/6:Z?IFD>'+>_N[N"TA;4)
M[K5;I)[FZO+RX>[NI+--3OM2N[&QTZ*[FM!P.D^-O`T5O'&OBOPW$\@+%7UC
M3H0BHI\M,O.BH%C4%8V(8.Q0`,VROSUHKSLNXEJ98G'#X'#^SY8PC&4IIPA%
M644XV5DK_9ZW=RJU%UW.56I*4YR<YSTO*3U;?3?6RMZGZ3W'BWPZ(ED@UO2;
M@2)FW,.HV<L;*5W)(62Y91&Y8.=KG=O)C!&2/FJ]^*?AZ+Q7]OODO]4M+2)D
MM&TY;:0*SDD2,UQ=)'+,RO(SNK,$=XB3YD#0I\VT5OF'%^-QOL?9T*6']E45
M2W,ZL9-6Y4XRC%6BTVD^;=6LU=YT\+"G>\G*_6UOU>A]EK^T1X)"J/[)\3KA
M0-JV6DE5P`-JG^VE^4=!\J\`?*.E%?&E%1_KEG?\^&_\)X^7G_5_2Q]3H]I?
M^!,****^5.H****`"BBB@`HHHH`__]D`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V%V871A<G,O:VER:RYJ<&<`````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#$R,S8P(#$P-3$U-#,S-S4Q(#`R,S<S,0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#_V/_@`!!*1DE&
M``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_;`$,!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!`0$!
M`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#!04$!````7T!`@,`
M!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I
M*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'
MB(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7
MV-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!`0$!`0$!````````
M`0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1
M!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ
M0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25
MEI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3E
MYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/Z"O`_Q,\#_`!*\6>//#?@O
M5-*\01?#'Q;I?P]\8>+/#FJ:7J/ARU^*'VRXN?$WPNTF^N-9@_M_QSX0\/\`
M]B7GB_2/LFD6/AVY\7>'M-DU^]\16_BSP[X4_)?_`(*_76O7#_!VSA\07WAG
M0=3_`&9_VW-*U#Q-HUF^JQ:CXPU'4_V;?$OP%\$>&9[.2WN#XX\=_'7X>^%-
M#\.:/.KWNKZG:77@[1=4EOKVX72?O+]C[]GO1_V2_P!G;X6?";3[6[C\80^$
M=!OOC#JL$]_<ZEXG^-'B+2E\7_$/Q=X@UH7L3OJUU?:Q8>'(_$.O0:GXBL-"
M\->$O#Z:DFF^#_#EKI?Y[_MS?"7PC_P4`^..M?#WQYK?C'X9?#S]D#6K2VFU
M/P;J4$$/Q>\:_$OPKX/\1^-H/%6JW=K>0>&_"O@/P'=^$-$^&_B3^Q[VRUJ]
MUWQ=<Z=+X?L_#U[':?P#@JN3\.9K5Q6-Q4J>%P%!R:^J_6%6]JE1BITES*+4
MG%P=I)-WDI14HG]R8"CB<QK865&K3C&O5M:KRN%EH[7B^DE>S3=DKJ[;_/3]
ME?\`83^'W[1_@+XQ_%KQ5\69?#OQI^-/BR_U_P`4:#\$=?\`!-[;?#6]U7Q+
M=^,+_P"&OB73%N_%>@^$M*\1>(/"NB?%&?PUK,FE>(]$D\.Z1X:O&M_'FA7U
MS7T7XH_93^`OPA\:>&_"OC/]I#XW>,_$7Q(U;XB^*O`OP$\)+X%^&VHZCJ_Q
M`DM_$>NW[>(`?#>CZ5X;\0S+87FG>&_&7C/P]I?B1-+\//9P:_+I6D30]EIO
M[+'[-UQX#\'>!OV>O$;^%/!7Q*^-GA;Q#XPNO!7Q$\3>,[CQ?_PAGP]^+FOZ
M;HZWU_XRU'0E\3PM<W%UK5G:>*M+5=!LO^$[\17VI^.K75[KQ)[K\5/^"?\`
M^S'^T-\0?%WC#XF_#>YU_P"(GQ%NH-5B\:^&_&VJ:?XS\)0:/:RMIWB+X417
MM]X<L;ZPM3IJO8:UIMW?:8^BW=J#H&J7A@U0_G^8\;4ZO$]>ABL\S+#95CH3
MG0K1RA.I1A;EA!-RC*$(I-)1JKD3<H+FJ2D?K,LN6!P5*-"K@98NDN=44H)5
M&^722BFIK>334GHMFTGPW@CPY^S_`.`]-TG]E_QG^S+/I_PDO=8$-IH7QCT;
M79/B1X<^(VK^"YM#\':KXFT/Q'H?BGP]>:)XST7PI9>`?"WC[X:^*/'5OI'B
M6VTOP;I=EH&H>-=+\/>%O`/%/[+[^'_VK_%]CIY_:$_:";X4>#?A]XA^!5EH
M/QS^$$8^"OPVGUCQ/9^-?"!M?C%<:SK^J6^D/;Z;>>#?`_AZUU+PEXL^#^KS
M^'/$UYJ6M?#33M?@_1[X,K\8O@!\)?B;#\79=*^-FK?`GPYXL;X.?%^VU.ST
MWXG_`!0^#NG>'+_XA:3X.\5R7RZ)>/+HCV-IH-I9W/C+4_[9&J7GBO7$U?Q'
MX9&I:I\+6?P6L=#T7]EO]L"]U_XVZ)^U+\8_C1\$?C#JDNO:D'^$WQ.USQ)H
MD;:5IVC:O\/K[7-2TGX;^%?A-XF?X+>#=6\-W&L6>D:9JGAWX<^.O#AT?6O%
M;V?3D&9X>E4QD\-Q'CLWH5)>P4L2JTFJM27M54C[2I"48N*5-NSY;1A*'M)3
MG#YS%XK&58*.8T\-2K5I.%&C""BHV7-=1BK)RBFW;73F=TDGZ%XO_9\^`_CG
MQ;XH\;2#]N*XD\8>(M;\4R3OX&_9YLGF?Q!J5SJS2O9Z[\#+C6[1I&NR[6VL
MSS:K`6,6H2R7:3.Q7DGB;_@L-^T!\,O$GB#X;:I^Q!%XSU/X>ZWJO@?4?&/A
MKXF^-+SPYXLO_"=_<:#>>)?#]W'X%U".ZT37;BPDU32KA+^^2>PNK>5;RY5A
M,Y7VD:&-DE+GAJD]<9AD]5%[.NFNFC5^C/FO[/?9O[_TTZ]-/N/Z)%GL]0\9
M/>V^KV6OVFK:FE]!>6<EGJ*R:9K?V?5HIKF_5&BGGM].TT7.F:A;LFA:EX?D
MCU`0/%)&P_D[_:1^)/@#4O"7Q7^+OBG6/CEH7Q^\:_M>^)_AA-\3O%ME\&OB
MG^R;I^E?"CXW?$O0O!6HZ#H&O:'XUU'5]$^"GP'CGT+P*-,TBRU:/Q1JOB*'
M77U#3M$TJ'3OZ4?C-X:OS\!OCAX<^'DNG>&O$\WP2\9^&/`U_86]SI\&@F#P
M7<^'O#L/D:684\J#28[6RT>WTB*$:#IMOK$2+$+"V$7X.?`+Q1X?^,OP@_9'
M\"?#GX,?!+4M)^(O@BZ\-:7:?%K_`(1V\T#PM\6OAAX`\3:Y\6-;FL[33/BI
M:V7_``N.ZUBTU72/%&K1Z%XFU"[DO8;S3-,GU76M.FXL#G4J6"Q.8U<'3Q*Q
M3H49>TC"4GR*=:,6JEU+F<.92Y9Q@X*]N9*6F291@:_/3Q&(Q5-4J2GAY8:<
MX*G4;@I.3CJH\NFK7-KULSZJ^)O[._A3]G_XW?`?XY:9^VE^U9;67BKQ?#^S
M]\4?%]Z_@CXUZA-\+M7^'OQ<^,D\END7P%UO2+:PU/QAX/\`@AH%WK4&E:KX
M:AT37=0L)HY]/\/WU\_B_CMA\2_'7P=\+_"3XM^'?^"@D'CVY\:>)/')TKP%
M\+?V</B[\*/''P\L]$TSP=XOT+XJ>&/"VBVFC^)9?&/B32K+4K34=/MY;K1/
M`_B>VU+6-2M9M2>Y]*\+6?[/?PR\0V?A[XO?`#1OV*O&<TJ6?A;QWI(TSPM\
M.M5G%NNA2Z+X8^-W@0Z)XF\/>)O[/\0MH.IP^*;/1)]3TFYO?#EQ':V/B^\L
M=-Z.Q\>>$OV5_&VJ^)M(O_AMI_[)_P`7_$OP_P##6LMX1\0>#5T'X&>.M,FU
M;P3X:\0Z-X>\/WWACP[?VWQ(CGF\.20:1HO]F^'-<T_1/$OCWQ&=1UW4EU#S
M,5Q)C*]+F7#U/'3HTIT\+'ZG2E[31WA^[4U>,:D+1<[6BU*\G&#]&?#$%B85
M_P#6F47&2Y*<L54]K'2/NN\N>2WLHW;EHK-I+B_$'CW]J?0?VH?"7Q4U7X(?
MM=K\/=<BM;[5_@B/$'PL^('PYT;PEX>N?#%OXV\2:!8_#+XLZ+X?U7Q`MOXA
M\)76E6VM_#K7?$'B?4+>\?29ETG3K&TM.B_9W_:4TR__`&9_AY\,_@YX*6'Q
M>-3^,/QA@U?XFV&N^"?A!\+_`(9:G\8O%Z?#WXZ:YXKM[./QWHGA[Q6FN:KI
M?P]T[P[X9GUF]U&?Q/H5GXK^'_A""V\7:C^F.I6EQ;O>6IN6M)Y+N&:[NM-M
MY8;EX[2Z;5HKT7-BNI:1)JT-V+6SM]8GU.RU"%+&.W@N;>W7R*_%#XN_`3X)
M>%_A'HWPWV^+M2^$VC:I\3;?]JOXH>%IKZQL_#G@KX/^'-$^-GB;P7X]7PQ=
MVND:KXAU?P'IV@?"C]G;P7X_N/$/P^T3Q#X^N?$N@1:1>7-IM^4X1XLRWB#%
M+*\3D\\#CL+C%.IA:,9PA3I^]3YI4I2:4IWC!*+A=Q<8IRG8]W-,JJ8+*I8Z
MK7I8N-!.:KI>TJ;<RESVYG>VMN9\S3OIK]`ZC_P3LT7XD:A??$2W_:N^$^HV
M_CV\NO&D&H7G['-UKUW?0^*9WUR*\NM<6VB76KFZ2^6>?5EBC7497:\$:"8*
M"O>IO"?_``43M)I;2Y_X*)_L_?!ZYM99+>X^$F@?";P_K6A?"V>%C'+\.=$U
MB7X>3RZMI'@B16\,Z;J4LTTE_9Z9#=/+(TI<E?LJ65I)?4JVFFT^EO/R_%^5
MOR1\1R;;6*KV;NK.E:UX_P#3IZ:=WUWMK^E/AI;H:S;1R":[DCNK?0KZ."`7
ML5K<W%Q:)?3_`&86\]O91V]I+?:;>7#/+873:E]JNC<PVNOR7/\`/[\![_X<
M?"G]D3P(WQ=\1:%X<\$?!WQW\>OA;?:QKHM?[/\`"USX&^/WQ*MO[2\/K>P&
M5/&$NDZYX9T"SO='T.[%O906L>DR1VJ0`?FBW_!0S]N_X@'P[>:I^T3XA\/7
M?A>'^P]!D\"^#_!'A/31JU@)=5O-5UQ/#6E:A::Y<:AI?B33]-F\/ZSH+>&[
M4VVH6]AX<TV._P!1MIH/@5^T7XHO_&$'[.7QA_L#XL>%?VMOVG_`?B/5;O7)
M=.\&P>#M4^)GQ+T/3?B7XAC\%:+'\,[75M8\2ZE?>&84ELI]*\-:3XCM[R\L
M=$6QL->MKOQI\.4*6#K86E7G7]G.EB88>E4E&3A24I5(TDX:2<9<J=FVTU&,
M[I/^BL'X:<5\(QEFF88?"3R[DE2JRJ4H5(.*ORRE%Q?,E=N]M+N[6Y\D?$O_
M`(*9_MG_``S^+/Q[M_`?C_6OB%\";3X@>)]`D\%_M%>'4_:*^&VG:7'>:M;:
M!8ZS:_%=?&<DU_<6M[-!86^I-X>6-KR>!M'TGS9M/@F^#?QC^-W[>?QP^'_[
M,K_!G]C3X;W'Q4U)+GQAXA\*?L2_LS?"#7M#^'6A:4?&'Q&U;3?&.E^%)O&-
MIXIO/"_@K5M1@UO2O%/@>^OAX<U2PT&]OSK/AR./^GE?V3?@%KNJ>(?B?K_A
M#0-)U[7=!@>_US[1IVA:-)IFC6L*Z1K>N6GCB\F^'%EXKL=)-E<:MXVU+P_X
MA\):Q)8^)+BSGM=;32].U#XMT7]LW_@GM\,OCC\9=8\$VNO?$WQM:?"273+[
MXJ_V;K^OZS\0+Z?5B-(\$?";X;ZAHOA/0=/L+%M(\;3^(?B)'X?^#VCW<,6F
MP:CXCUKPAK<&JZS]5PSXL91FV6X_*<CX&GALPR[!QP];,*^"IQC6JRG&@I>W
M]G%N?/S3DW)N?,N=M-R/Q3BC@?#X/-?[6Q/$53"NIB'B(X7"PJ58.$N67)[*
M"<5"*:Y;+E<E*#=TU'](/V,=9E7]C/\`9\MO'OBS6I?^$>\+^-/#ND^+=9T[
M.MZMX/\``GQB\>Z3\/DN-$3PI:ZO9:[HOPT\.Z:ERSV%GH6LZ=X>UF.[UEM1
MA?Q5><A^PS\!/`?[0FF_';XX:G8^/O$/PG\?_'W7]"^%VB:AXV\4Q^#_`(Q^
M%?"T\&I:YXR\:_#OP'K.O^$/BKX6\=_$YY-"T?PWXQT+Q+H\O@;PKH,WB[P[
MHTM@D-I^-?B[Q[\<OB1X7U"PO/A)X?\`AU\%?#GPS\1_#[]G_P"`OBGQ+XTB
MU73OA#=>$_AC;^(=!U&;2H]*N/$'Q`^+/P8\<>$/'&@^-8_B6L'B/X1^&?'6
MD_#V\\+Z]J_B/Q=8==;_`/!27]O'5?`WA'PUX)\6_#G]F_P=X4@\66GA>Q\$
M>`/A5XT\5)HVH>(/&OB;PCX.DU74/"&I?#?P7X6\(?#:\TGPSH/B#PYH=OXB
MOQX4M+[4M<U/5M4U*_OOG<!P+E>78['<18VO1PV;9JXTYTH<M/V$$W63I1IS
M:YI*7)4<>;EE%1]I)-R?VV2\,<7\;8*CE?"SK8["SUQ4\3A)T:=.B[.G4YY0
M?,O:;1Z1^%1BHI?V!17>LSQ1S07.A7$$L:2PW#7ND7K3Q2*'CF:]DT74I+MI
M4(<W3ZC?O<%O-:]NF<SR%?R2V?\`P4J_;=^R6O\`9/[1NM7&E?9H/[,N%\`?
M#:)9]/\`*7[%,L>E?""'2XQ+;>4X3388K!`VVSC2W$:@KO\`[/7_`$,\7_X.
ME_=_Z>>:_INWM_\`$LW&O7#X._IKT_Z<^GX=M?R2\)00?8]03R8MAUAK@IY:
M;3/+<`23E<8,T@1`\F-[A5#,=HQZ'\/56X\.?'_4KA5GU'P[\)?VH]7\/W\P
M$M[H6J^#OA-_;'A'4]'NG#3Z9J'A75KFYU3PY>V4D%SH>HW$][IDMK<RR2L4
M5Z&`_P"1G_W"E_Z4C^L_$W_D@JG^-_\`IL^Q_P!K_P")/Q%U7]A3]D6'5/'W
MC74HOB3\4/V<+OXBQ7_BK7;R/Q]=ZE\,_'^O:C<^-4N+^1?%5Q?ZYX=\/ZS>
MS:Z+^2ZU;0]'U&=I+S3+*:#[7T/PUX<\)PSZIX6T#1/#6I7-G^W/IUQJ/A_2
MK'1KZ?3]$_X*=?L0Z7HMC-=Z=!;7$MGI&F:]KNG:7;/(T%A8:UJUI:)%;ZC>
M1S%%:<+_`,.G_P!A^)_])D?Q5'_>\1_UYPW_`*EH_GH^%7B'7_$OBPW?B/7-
M8\07>A:/\(9M$NM;U.]U6XT:;2_AGHGA;3)M*FOYYY-/ET[PQX:\.^'+"2T:
M%[/0=`T72+<QZ?I5C;P?2GQNEDB\,^(/+D>/?\)M4NGV.R;[J/XPZ'8I<MM(
MW7"64\]FDQS(MK-+;AA#(Z$HKEXL_P"1OA_6D?WGX&_\DW_W"A^43QPZ3I3$
MLVF:>S,268V5L223DDDQY))Y)/)-%%%<2Z?+_P!QGZI+=^K_`#/_V0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O
M<F5D8W)E871U<F4N9VEF````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S-#(U(#$P
M-3$U-#,S-S4Q(#`R-3(V-0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!'248X.6%!`$(`]P`````````S``!F``"9``#,``#_
M`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF
M`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__
M,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F
M,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_
M,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F
M9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_
M9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!F
MF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_
MF9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]F
MF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_
MS&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QF
MS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#_
M_S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF
M_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____
M^+\D````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````(?D$`0``V``L`````$$`
M0@``"/X`L0D<2+"@P8,($RI<R+"APX<*K4!AP6(%Q(L8$S[9N#&CQX^8+LWA
M".6CR8>=+HF<@^W)R9<+=Z6<,X>.2Y@X#>X*-A,*G9Q`!^[:I7(.E"<E@P*E
M0X?F'#U*L3%52G-/4"B7?@:E"16G%3J[,&D%ZG3A"BM6K@BZ,C!M($%[OEX:
M2C1JV80KH.0!E.P9E!4K].@I]>R9ITN8AE[R%!7;78-Y5W`L%6BC"LEYGJFD
MB]BJ4A8T$5JAN$*%BB>DGI0&_`00LDO!%#-N#,4H0HI/2)!0844U8,!ZD'4*
M%GO7[*B@;V*#PAS*%1:J293F^'O%'E*=#A,=&S3Y1LD5J?[_EO[=R1.G13<?
M'[B"!9VLGC,BY?B==>_Z'-&KO#1S,<&\M6UVB4E[.$7?1FCY1A]-`G8RG(.`
M$`3%'DW-X4ELW&'DU!R2<816;QWJ1U0PPB23#"DU=;6<)WHP.!<F!(XTDF0=
M*IC?'/NI)`PII7C224UT,-<4(.?-D=TE2;659$-'B:>"$RPP=UZ1.2JF4AX<
MF4>3350.*-"$S.T2GT-3JG::8"T6Z:)**8FD!T<``%#C@0*M`)9(*M$QYD+0
MD63%)Q32I":.^\V11VKWQ2GG91TF:2=1<R1FW$.CT6=%()\T>:.+I/#(VA.*
MQDDC"_\5NMDN&2XDT7F"[:'I@?ZH=2K8IZ$"<%NA.`ZE(D3?I77%%1+=!]AE
MI@4@'6"U`A``00%(5F51'OGF!5R!Q+6";BH<6YUOORFZK$#A$9IC:!E5Q$(7
M:P%;VF[7,CH=M\@J2Q!TN>XW5*H/`69%%X&,-NQJTPF6Y:<KV/K?$_;.-=1Z
M%TG6A;K5_?:$'IUZ8N2/JL%9T`ISP::P2@Q#U!Y@,@02R!5=Z&'%ACD6M9&!
MU06`L,)T+?Q19"0#VUN3&^(HZ,N+_<8HPHIQYJ5'4DH,Z]*"<OF$$Q'7RQFJ
M)S6W-'4+"CK2:9*Q=YZ`'>/;,'T1S_FR@?1MS&#1,+XT<MF?;MJS;01]36@G
M8N'T]O6VFZIY21Z/S7M431,"55'9?1>%'DN-X07W@2/]^#/CC3L>L=SY%5EY
M1(<K?=Y,&6^XN4)0))BU@0QN.7I$]ZGFA-9.Y>$)1ZLGA%85N)^M.TWF65$[
M9+_I@7L5F#NUY.]U`G9X[ID_[02+>R+_UT;3,^^4$T]2COR\'=7YA/7G$:_]
M]@)M1.K&<E=!?D'G'8\-C2NDOCY:>]3_7LC8M*[Z]E8<%M*=GL`?<R3BOLJA
M14@)R]/Z$"(EN;5,;-M[U>D$!,'?]>EJZ`D+_J1W-<CEJ8*CTY39($>H!1XD
M/!WTB0E/B$+Z,&>%"M$74EX(PQK:\",!`0`[````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W-O;FEC
M+F=I9@``````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C$V-B`Q,#4Q-30S
M,S<U,2`P,C0P-S0`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````1TE&.#EA'P`@`/<`````````,P``9@``F0``S```_P`S```S
M,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"99@"9F0"9
MS`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#__S,``#,`
M,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F9C-FF3-F
MS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,_S/_`#/_
M,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S9F8SF68S
MS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9_V;,`&;,
M,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`9ID`F9D`
MS)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF_YF9`)F9
M,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_9IG_F9G_
MS)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS_\QF`,QF
M,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,9LS,F<S,
MS,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`__\S`/\S
M,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^99O^9F?^9
MS/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__F?__S/___P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"P`````'P`@```(_@`!"!Q(L*#!
M@P0O`!!0L$`!`1`C"G#H$*)`9!B1";Q01F#$A1)#1GQH$0!&@64ZDA0IL0#!
ME24WJAPX4:1+`#MV"(194B$`ESI_VL1Y[5I0GAM_`M7)\^:.HD:%2DSJ]-K.
MED2A)MJYDFI6JS"!%@50=&O%GC\!)(+J<:%8JP*OF>T*0.'-M333DAT;=^Y'
M`"H9XAT(%RI<LG[1/E1[V+!APHD9UMW)V*ICQXBO_KU@5_#ESW*53JWK\R;?
M@H[G&E3H06A<DQDU[BU+,)CMI*T+QLX8-[1`V\%."C2P5_=NV0./RS9`_&!P
MY;L/&LAM\#ETWAJ1M_99^[IRV`,Y7',$`-S[=^'$.78D;_[XQ>7-4_ZV?IT@
M;P#3/;26/[]]QML`4,<9>//1AQ%PP!4DWD4%#H0@@`5)MN!)NR48(7G!3;:1
M0A1"AZ!'##VG(8?9^7>;12(BI.**!04$`#L`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V%V871A<G,O8G5N;GDN9VEF````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`R,38S(#$P-3$U-#,S-S4Q(#`R-#$Q,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!'248X.6$@`"``]P``
M```````S``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F
M`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_
M`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F
M,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_
M,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F
M9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_
M9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F
M9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_
MF68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QF
MF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_
MS#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EF
MS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/__
M_P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F
M_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S_
M__\`__\S__]F__^9___,____^+\D````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````(?D$`0``V``L`````"``(```"/X`L0D<2+"@P8,($Q8DP;"APH<"&:ZP
M$JAB("LD(")D2/&BE8\@,VHD2`*D29,KD&ALR/&DQ9<K1!Z4V+'BQY>L<NID
M57'%S)H[*^Z\1K0H4588%PK5>32GT:<Z`_DDJ2<0JVNL5JQ@9>WETJ`]%WI*
M=I6G5BL\I0(@L<*K5(8&`7PB._3H10`16<J,^ZF4M6O6G-J5.G(@B3U7L0KF
MF7:OQK9U<UI-&[,PMK:3=0I*G-9*3,<)V7I-/-AF98A(,`LV*ODE:(,DA#XU
M&CCHU(T42<\._-5L:-F[=_(4!$WR:VRQK09?+9SP3^50=1>-FO2@ZJ?09[>^
M71#`]:+99U%CO7C\.]'-XJ?W/)Z[*&_IZC-S'YB[J]#)TSEG9^6X8]JT%CG%
MRBI_,38=7O0I9V!ZX_TWW5Z0_9>9<*U=M%5.\P&@X88<=N@A`$B0L)9``0$`
M.P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]W;VUA
M;BYJ<&<`````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#<S-C<@,3`U,34T
M,S,W-3$@,#(T,3(U`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````/_8_^``$$I&248``0$```$``0``_]L`0P`!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!_]L`0P$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B
M``(1`0,1`?_$`!\```$%`0$!`0$!```````````!`@,$!08'"`D*"__$`+40
M``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$5
M4M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC
M9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2U
MMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$
M`!\!``,!`0$!`0$!`0$````````!`@,$!08'"`D*"__$`+41``(!`@0$`P0'
M!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6
M)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS
M='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#
MQ,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1
M`#\`_$O_`(*S_P#!6[XW_P#!3_XTIKDMQXE^'?P-\)'4-!^$7P9T+6;I?L6D
MZI(QN]:\;_V3>PZ;XG^(_BEHX=/\075I/=Z':PQVNGZ!YVDWEY<C[2^"W[-O
M[$?[%OPR^#&K?%[X7>&?VV?CU\3;;0/B7XRL=6M?$%M\*/@QX"@74?%WB?X4
M^'/#,,^@1>(?B!IT?A+QCHGCS7]?6'3I?$"1V&B:=9SP2W(_FMFNKRQDM;JQ
M2:TFMY8KNVNE:>+R+F!UEAF66&6WE1HI51PT5Q!(I7='-$V'7^DC_@E/^Q1\
M8/\`@LIXU\8F[^.5]\%?#WP)T.?Q?/XATZP@\<ZIJ7Q!\3:M#96NA>(M!U;4
M]*MI='URVL-7N-2U%]2NFUO3(=8O_*767$9`/N_X3?\`!8;PM\*+6P\#?LT?
MLX?L^_L^_#ZPN?"FL:W8?#_X:Z2OBC3/"O\`PC-WK'C:V76+JT-Y=>(O%.NC
M3[VU4ZS=_P!E1O!`ZA+A0]S1/^"L7C']HSP-?6_QO^&OP3^,,?B'Q.VJ:AX4
M^(GPX\$>,K+1/!,#6=W9:9J^K>(]/BE@N+A=+CN=2UF6^M[C6=6%Y"_DZ-9W
M=Q'^FG[+'_!"+]EG]G'X>MIGQMA7XY?&G4/^$WT;Q=J\6IZEHWPSC\,ZSJ%S
M96'AOP_X<GAU+4Q#I.AR07MO>RW<.IZ9J<8;29'\J&O3/VR?^"7GP=^)'P&\
M01?L[^!_!_PX_:"\)S6WC/P9K&E>&K;4-*\7:GX?T<^'4T?Q5H#2I;ZA8WOA
M\):6XXNTU"TAO'@::_7>`?C#_P`%&/\`@CU\`?VB_P!A?6?^"AG[#OPV\$?!
M[XH>`;'6?&?Q5_9U^$/B:?QK\.?%7A/PNPN/&,^@Z'-82GP=\1?!F@._B&\T
MWP_--9ZE'8KIUEB:2$/_`!Z6$EI<PP3P*C)-"DPDC<2J59"ZL-A8,K)\R[<[
MU'&><?W_`/\`P1J_:`\8V7QWM/@+\9[/PYIWA3Q=::MHOA^]\-ZI;ZK\/?$.
MJZ+:W>GW?@O5/"VI-]H\/WLVF//L62)[62"VNM'OB]T50?Q@_MX_LR>+?V1?
MVK_B9X!U_P`,_P#",^!?'FMZY\5?@=*K/<V>J_!?QAXP\3W?@>YL;Q5%K<3V
M@M)-"U5+1Y8],NA'8W!CF`B`!\B&ZL@2#/!D$@Y1L\>O%%9;P$NY\M^68\1L
M1R3T.T\>G)HH`P`VP_Z0P>!\*`SJZJ#W9)$FC9<=5>*5&'#1R*2A_J9_X()?
M\%"O"W_!.GX-_$KQ;!X!N_B7<?&#X^>'O!WQ5@C\)>-[?5O!GA70/#+1^`(]
M*^*-G::A\/KK7=2M;_Q1K,/@%C8:[K<EG+%9P>;&TL7\LS82!D#\(C$R*6\R
M,`??7RPT@91\RE%9@0"H)Q7]R7_!K-H7[/OC_P#8^_;3\+_$_P"'^A_$CQ7\
M+/C#I'QKN/"EYI2:QXAN/#L_PSDT?P_J&AZ)>KY9O;&_\+:_9Z7JEJLEVFJ0
MJULCW5QY3@'ZI_\`!1[]I7XG1?LY?!7XG_LBZGXC\2^#_C1/=^(?$'B?P#;6
M6C>.?^$`T>VN;E].@\2>+VMK/X42Q^)K34-(\;>(+UX;K1-1T*SMHVBO[R&"
M3Q+_`((T?'_]J+]IOQ!^T4GB.?QU8?#'PEX-\+W?P?\`%?Q;\6W7CJ72?B3X
MADUF'2-(M=?N/#.BZSXB&@:99I<>-K::]U"'1;N:T1$=I[99/U9^!7[0O[*O
MQ:>+X3_LW:9<:Y\,?A?\-M)OK'Q''X(UC2_"7AY_$M_>V[_#R]M?&VG6>I77
MC"Z8Q:]XHM7B\BXN;R/5=6$%ZUJD_P!7^'H[?26M['3[?3DL&DB-GIVDV%M:
MV<QWK!!)%I6GVL%NT[V[O+%-"TS;5:5-ZJ6`!_`'X5\?_'/X9?%WXZ:M\5--
MUKP'XRT?XZ^,=%UETAET%[#QWI.KZO;^,_'/P_GACCO)/!HUH7EQI<BQ?8[B
M+7;>U65BB*?IG_@L!\/;#]KC_@E=\._VLK9#K/Q2_9!^+/AG1M7U:RM;:=[+
MX&_'"UC\-:EHVH7>T7$^E>'?BKHECJ.DWC_N;2QUG4;B%QEF/!_\%FOV\?!?
M[1'_``4I/[/_`,(=)29?V<?"OB/X.>(M:C_LY=,\;_$^+Q58>,_&&@V9TTE9
M]/M8?M&F:=J5TTEY;^($>&\<-'*E?6G[(WP^UCX__L]?M6?LP^%+:]\5^!_V
MC_V//BM9Z%))<*L^B>(]'T:7Q=\/M3U"R?>1KT/BGP\NAW&G(BZA9B[NI%B6
M8$4`?Q)8N%^5A&&7A@9""&'!!&1@@Y!&.#156+7M/M8H[75;9;75+:-(-2M9
MY%BGMM0A41WD$T<I62.6&X62.1)%5T=65P&!%%`'/NUQ(I,2C"@E#&`6+#E=
MV,\$XY(QSVK^A?\`X-M_VB_%O[/W_!17P_8V^L#1/!OQX\"Z_P#LZZE?ZP9)
M?"5I\4_%^C?\)/\``H:T8[FRBG-[XU\-O91JM[;WKZ=K]^UF^YV:OY_828(6
M##S)3*]I#;,DJR7-\@"C3T2%6N'NWD*P_9[='NMSJL<9D9%/[4>/?@!KWPD^
M$'[/?P.M6B^%GQ)\-^%D^//BWXAZ+]H7Q9K'[0^OW^E^*?"&FRW.GR1-9W?A
MKP9>>#M`T3P]:W$4/AN^L]4U2!UU!YD`!_6E^QU\2/\`@H]_PTS'\.OC'XO\
M/^,O#&IZKXHD^)WA_P`7?L]>,_AU%X$F\.76JVLOB;P=X]3PIX:\.?9/$7VN
MYM?"FCW-SKFF:[)<6T=WJWD6\LR^V_\`!2C_`(*>>$_V-M)MO@M\*KVP^)7[
M:OQFM;C2?@Y\&M`NX;V\\%7FLK)IT?Q8^+&QY5\(>&/!QD&I6MG<QVW]K"RF
MM;-I)"0/PE\/?\%&?^"S_P"T3^SM\7?`3?&OX5Z'JG[./B'X5?#KQ9\7/#LU
MGX)^/'C_`,,_%V2QT_P#XTT)+6+4X;_5]2MX[C4?$&N:!'X7N[(0((;F?4)4
MD/YV_L7^!/A_H/QA\0Z=\5OB+XGT'Q'XEO[G4]8^(VD^)AX>\9^(O%9O"]S)
MK/BDZ-K7B:^FFO+6]F1&U>%9#/N6(!@:`/SK^$6B^(]%_:!\?R:CJC:SXO\`
M"_B[QO8^)O&&JW*C6-0^(?A_7XM6F\27Z73?:7@UW4?[4MQ(XQ>1ZS!:QL[1
M(M?T=_\`!-G]HSPW\'?VI=`\96>H:EHOP\U?XI6;W^FWMRM]IOA^W\?3V$T\
M($+A;'0]7U&/Q1J-I]J,=K;7$$.G(P>3RZ_+S_@HA^SSX'_8X_:Z@\3?!&RN
M]9_9]_:7\*>%O&GPD\7V/B.X\66]YXWL[?3--^-WA'Q)XNF$@MO$^@^.;/5_
M$7B6WO'CO&OY]*N!!%9,"WW?_P`$[OV,/C#^TUXTU*Q\!76B>#OAKX4MC8?'
M#XX>(GN-5^'FA^'%\C6_#>@>"K;3)$7QM\9?!NJ:;/<IX6M=0C\/:+#;6]_J
ME[:0:C(]`'SU^T]_P;;?M?>)/VE?VAO$7@2SB7P/KWQR^+6M>#5MM-O#;KX4
MU3Q]X@OO#H@\J`QF$:1/9B+RR4V;=A*XHK^N_3OCU^SCX0T^P\):E_P6%^+"
M:CX7LK7P[?I=_$_]D2UNDO=$@CTVZ6YM;WX1WUY;7"SVT@FM[N]O+F&0-'/=
M7$JO,Y0!_([_`,&OOP]\`_$']J;]K>X\>^!_!_C>X\#_``$UG4_!4_B_PSHO
MB6;P?J5OX=CNX-0\+RZS97K^'[Z"[C2ZAN]):TGCN$29)%D4,/>/CM:VUQ^V
M%\"([BW@G2]^+?QPN;Q)HHY4N[C3?"S'3KBY5U83S6!MX#92RAY+4P0F!H_*
M3:44`>7_`+.K,OQ-_P""FJ*S*EC9_LPVUBJDA;.WL/$4=S8V]JH(%O#97$44
M]I%"$CMIHTEA5'16'P#\=6:P^+7Q!>P8V3R>/_&_F/:$VSO_`&;JA73M[0["
MWV!69;+<3]E#,(/+!.2B@#^AKX:>%?"_B?\`9B_94\`>)?#>@^(?`FH?M/\`
M[+>FW_@K7-'T_5O"5[IVLZQXGN-8L+OPW?V]QHUS9:K<0PSZE:S63P7TT4<M
MU'*Z*P_:'_@M8[_"K]ACXX:)\+W;X;Z+I7P0\:7VEZ1X"8^#]+TV]1[:-+RP
MT_P\=.M+.Z2.66-+BWACF5))$#A78$HH`Z']DS]E3]E[5_V5OV9]6U;]F[X"
M:IJNJ?L_?!K4=2U/4?@]\/+W4-1U"]^'/ANYO+Z^O+GP[+<W=Y=W,LEQ=7-Q
M))///(\LKO([,2BB@#__V0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O879A=&%R<R]F<F5D9FQI;G-T;VYE+F=I9@``````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#(S-#`@,3`U,34T,S,W-3$@,#(U-C$U`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````$=)1C@Y82``(`#W````````
M`#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`9@``9C,`9F8`9ID`
M9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`S)D`S,P`S/\`_P``
M_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S,P`S,S,S,V8S,YDS
M,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DSF<PSF?\SS``S
MS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F`#-F`&9F`)EF
M`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF9LQF9O]FF0!F
MF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F_S-F_V9F_YEF
M_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9,\R9,_^99@"9
M9C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9S#.9S&:9S)F9
MS,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,`)G,`,S,`/_,,P#,
M,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,F3/,F6;,F9G,
MF<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,_\S,____``#_
M`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___9@#_9C/_9F;_9IG_
M9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_S,S_S/___P#_
M_S/__V;__YG__\S____XOR0`````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````A
M^00!``#8`"P`````(``@```(_@"Q"1PXD`02```((ERXD*##A]@.`D""C:'%
MB1`A7MQX,>-`CB`M>@Q)LJ'&D"M(D0*@@M0J4BH`Y$%(XB1'4L]RIER5<V7,
MD1,W\LSYC-2*E$<!U?18,2C#H3H#L5HA=053@081ZHFY@NBS52163!6[]&K%
M%:6,XB2Z:H65J6_+7B6QUNLS/49932VU@H1?LRV?V"V*]RBI)Z56O93[D`2@
M)W79)H;*EK%#`#OM&CTZ^*ME@BTY]S2L=C"ISUAQJNP)V651R(H5PV1*@O)A
ME:*-DE"AXBA%C[6]IM1=UV@>4FE5T(;:]G9*K[=[*L\8/&=;GF!;0H><4^G#
MA77;OA)=@7"G;,'/2C$&``'"@>=?N_:TZ!<^V,L0+%APC[;Y^(NN>>80$B4<
M`,$%%T`PG'Q%J<`&&PN)IIY#)'32R0H'7F#!`0<`4%Q?8>'670`)%63A)1@B
MF.![D2EF5UL)0%!BA9WP-L<*!JK(7V1V`6*@C%C5J-(3EUR8(8+\E3(8("O$
M&(")*O!TF(4!Y(BD@G65PN0`$#P)Y5!3JG!CAAP^P"*.`7#9(4$51DF46BI<
M4J4%*\KXHX$'7+)40```.P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W!A:6YT:6YG
M8FER9"YG:68````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C(S,R`Q,#4Q-30S,S<U
M,2`P,C4T,C8`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````1TE&.#EA)0`E`/<`````````,P``9@``F0``S```_P`S```S,P`S
M9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"99@"9F0"9S`"9
M_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#__S,``#,`,S,`
M9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F9C-FF3-FS#-F
M_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,_S/_`#/_,S/_
M9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S9F8SF68SS&8S
M_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9_V;,`&;,,V;,
M9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`9ID`F9D`S)D`
M_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF_YF9`)F9,YF9
M9IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_9IG_F9G_S)G_
M_\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS_\QF`,QF,\QF
M9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,9LS,F<S,S,S,
M_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`__\S`/\S,_\S
M9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^99O^9F?^9S/^9
M___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__F?__S/____B_)```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"'Y!`$``-@`+``````E`"4```C^`+$)
M'$BPH$``!A,J7'@0@,.'$!E*;`@@T(H5$#,ZE*@J(42,&D,R[&CP8TB1"_&0
M+'BRI40G*E<2!$`-@+.;.&W6G(C-"4P\+&DZL^G,F-&ASG9.Q/,S*+6<P*(:
MNZET(L*20F\"B`J,:-*-"S,ZA>H0Y]>K"L7.S#JTJ]>S#&D".'8,+#:'3[6^
MI6K7XU"ZU&HBQ&NVL-;`:$O^/495,-O".N?6C2O9;-W'..OR55N2KF7"AC4W
M!F#&#)[$`Q\ROGDY;V'121&7/HTZ-5VZH%^7Q8D8C^_3'F^W-NSLLMG>OVM3
MA+CZ\]Z:M6KY5AX\-(#3QP%$G\[S;O/,UR]Y9-S.O?M<W7@NJ+_PF_9<ZIVM
MMW=_&W[P[\4SUN_+L[)SU;CQUY]DPA5X67=AM21@0JPTR(I!#CH4H8,.3D3A
MA11*V"``&#;(4(<9LJ*AB"!ZR&")&X[((8HGHOC0A"RVB&%&*:[8H40EVLCA
MCC::B&"(%_9884$!`0`[````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V%V871A<G,O8F5R="YJ<&<`````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`W-S`R(#$P-3$U-#,S-S4Q(#`R,S<S,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````#_V/_@`!!*1DE&``$!```!
M``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_;`$,!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!`0$!`0``````
M`````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#!04$!````7T!`@,`!!$%$B$Q
M008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X
M.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4
ME9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+C
MY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!`0$!`0$!`````````0(#!`4&
M!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R
M@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(
M24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JB
MHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR
M\_3U]O?X^?K_V@`,`P$``A$#$0`_`/XFOV;?AK?_`!<^*W@?P%8Q&YN/$&NV
MD!4;YFBLY)HXI6:.T8W,31>0K^5(D;-#&CQK,QA5_P#0J^%7PS\,?#/P!X(\
M&Z996-E_PBGAJQLX)(XV\L/#`IN[Q!<PV^X_;9'NY6,$,L,TX:183<$2?R/?
M\$+?AEI7B[]H^\\3:U:+=P>#M(DU:V^UP,]C;SS.+3[83<F6TB=)8HHK:=(H
MI?MDD:1W7VJ"!5_I=_:I_;L^$W[)&G:3?_$"TU.6\\12W+V.E:9%#-?SI!:P
M/'<76V0);Y4K%)YKN8DC3EC#/%;_`,3_`$F,;F/$/%N3<$Y-AL3CZ^'HSQ\\
M!A/>J5L56A)P2IN=Y1HX>$ZDV[QA*I)P:O8_H#P_PCPV65<QJ5*5&-9RBZM:
M2IQA3A[C=2K-J,8S:Y(Q;M+E2O)R3?VGNLS*UQY`>:,OF=+4W$F83=0L%E@C
MFW.JQW"&)7::/S!#)&DLZ1/4DO(H#?"1K>W$48=<7KA)5^T3*QVB`+;RN\L:
M3R(AD\ZY1)9%1+>=OP.\7_\`!<[X0VQF_P"$:\%ZOJ\UI-(EM+?*EGY=UYSN
ML[I)(@CBD8"X6VE'FEX(GEB#PQ+#\S>,O^"U'Q:\;RR:;\+_`(41VMY=J-CZ
MF]SJSVKNRQ*4CMH+5%FE%RA6XE3Y)8IR=NXQVOXA@O!GQ(QR37#E3+Z3LYUL
MSQN%PE.BKJ5YQG7]JH)<TI/V3DW&UE))R^W>:9+2FHU,WPU:I?DC3PRJXJM*
M4907+"&'IU;S;:4=/9VYM6TC]<O^"B'P9\&_&']G/XA3Q1Z=I^O6FEOJMG>W
M<%O;M-=:5<R/:G9';_:;NZEB'E6;0*SJ\<*3NSQ2O!_$3XIA:TC:&8>7-'/>
M1G:[12*Q,2O.[.LP1H45HG*L3'&D<L"N$^S+^W2^&?\`@J#^W5X9?6]+\,^+
M'^&UU>SVCS(4T+0MVEVXN;FVNFN7B\T(9&F2.6W2::ZFMX8E?=9(/QR^+WAG
M5/!GB+7O"&LI<PZIX?U>]TO5`8VADBOK&4Q7(<'SI(YD8SLGEF7?+&R!)"XN
M(_ZX\%>%<TX)RF>29OFN!QN)KXM9A2P>7U)UHX*E/V>'K)U9)7YZL(QDH4U"
M/LY>S7-SRE^><9YAA<U4<3@H8ATL-#ZI*OBX*G*;3=2%)0YG44:?++D=:7-=
MR6RM'RR$2^5%A2@\M,)\D6P;1A?+,<ACVCC89'*8VEV(W$I8Q(\:/E3N16R&
MCP=R@Y&(YA@YXQ-*/263[Q*_9I3P_,[PIWN[_NZCUOKK]<C?7K9>BV/A(QJV
M5I5TK*UI12M;2W[AZ=M7ZL_KH_X)3_L)?$#]CVU\5^*OB;XB\&:I?>,M%TE[
M+2?#OV'4KW1[F6(3W%C>7R&:[%Y9I.(YY+E;!&/FVT#2LD<UG]Q_'K]FCX9_
MM#:=86'Q!T:'51IDS36,DL4;2VY97\Q$G+).D4C>6QC638'C0J$_UD?DGPG_
M`&G/A5XG?X?:?HOC/0M2\5>+]$;5+C0;*_%Q=B,10RO+/''<&.VGMO*N-T<]
MO:RO#.L9B5?,N*^U;;4$EC2550L=\<Z2E5$)!,$S'<60F*1L1E7;<P#1LQ4D
M?YC<<\6<89IQ=/B7.O;Y-GS?)1JX3#U\LE1A0E4PL98;WG4<+TZL75C*7M)^
MV;;NTOZ=RG(L)D6`I87+JL,=@I04?WGL\1"::]HX58SYH24^93BIZ.G*DK15
MDO,?@;_P30_8G^"_PM\4?&KQU\(M)\>WVA:)K7BN^M9M/_M,:;IWAV&XU62U
M\/Z4GV</?S0VZ.L,M[>!YEBA26#?-;0_.WAWP_\`LF?M1_"CQ+\=_P!G[X)3
M?`S6_#?BRY\$ZS8ZMI2:9#JD`M9KB2_L+9($\FX=;2*"[G@AAD5[N)]M[>6P
MBK[UT;XA^/\`P?;:E#X;O=/O]!NX)DN?#VNVDE]ISHZ3QWDMJ()X2LUX#MD!
M$SSK&!(RB;YOFOXA?$/5M2N9/!\6D^$_"WAFT>YU=-(\-06VEL);F6.WN)+J
M*RF>&-[6W=%FOK:UCNI)T`N-3MK:ZDTVW_8L?XO\.9CX:T<EJ/'XKB-Y4L+7
M==U:M668QM?,)8VM.-Z,JRIU_80G*+C>@Z,J7-)>%PYP3GRXX><X?%86EA88
MOZVW1E&DH8-M.I@OJ,*:@VXS=*%-Q]BN5SE*"Y4^TMM7^//@G6_V6[;X0^*/
M#?A+X">%?"*VWQ>\,SWUC;ZUJGB:[6X@D,L48D:];4I3&+&2UE/E74CRI<RW
M`L[I/XR/V_\`4VU']IGXS7DVGG2'/CS6BUK$'"Q,[RW0FF,43Q0NPD+[)H)9
M5+K$,NDID_K+M_&`BO+/3YKHM#:7D2FUN;BY$3W#,_R3:>THDN89%=F$KHMF
M[W%N;87$KH]I_)I^WTT1_:4^+,L,L\D4OBV\.^<QP%WFD+M,PM;:.*.YD#D1
MLOD!IAN@@A$SI#]_X'\?X[C+B"MAL9E^'P4<LR'"QC]7=5>WJ3Q>'H3JVDN6
M$*D8+W(\THMOD<W%R?C>)'!D>%<I595)U99CF->LZM:G%3Y.6I7IPE-R;J2I
MJIO)IMRO4=Y7/C)-H1`ZP;PJAM\@W[@`&WY\X[LYW9FE.<YD?[Q*:MQ%M7&Y
MAM&&58RI&.JD$@@]002,=#17]-2H4N9\U>2E=\R]E5T=]5\3V>F[]6?BBK:*
MRIVLK7=-NUNONK4^Y_\`@F5\/_BKXN_:?\#ZYX.@UA;;PC]KUJ_OEDN8(4L8
MK.6Y%N)&VK/#=F-8C;*S"83G;&R/.Z_U#:+^U7X2\/7ZZ!XSO8O"NK:?)'8R
MV>MSZ=81C=;/<331*\D1:680B))D^U+"Z26\SO+)(X^1/V7O`&L?LT?!OP#%
MX0MM'M_'&KRZ1K.OW/GPIJ<C7\L41T^YCE#R36[07;1R07=P(+97AN)6OU^S
M2)]V_'CPU\/FU5O!_P"T'\,]/U"QU33H]5@U73H(8[W3EU='EQ%J&V)H6L);
MH>?$XD:*%(Y9W6\G@,G\H>.N%P/%N:4N(GEF,J9+EU2KD%+$Y9"BL5:C4>)>
M-4:T84L32E*O-JDW'EC::J-2:G^^>&52GD^`GD>-5'%X[,(PS58.>)Y*]%U(
M0H^QHIIQ=2,*48U:=I2FY6BH/DD]:/\`:@^%,]G)(WB[P\8;@X$@U2TMY(YB
M$\T&-XPK26KRP2.S%_-A43M$D<RHOP%X\_:1\,ZGXYU630M7T;4#!M4&*02^
M8ZVUM<K<32SPXN(IC+;AK52'389))(I$VTWQ%_P3P_9Z\8^;<_"[XSV>C,LQ
MDET+Q#?-(H`:15,DOVJWGLQ;^3=%9[JV6/$D3".WM7FN+;YI\8_\$X/'7@NT
MUO6--^*_@.^L].M?MA,=]>)=BR>(70,J0!Y#Y<2A7D,4ZRR_:%2)+FW\H?E/
M#W#?AG"I5G6XIQL*M2$:,<+F665,&XSJ3IM0FZ;KQJ.]E:G*,;N_-*/-%?M>
M6YGA\EQM#$4<EJXUUW[.I@'4Q<,72;2A?DJY=AZ7-4;2A.E6EK*/,DVD_2YO
MB[XE\1ZW::1HUQ-+<736UE'!:^4+%XY9XXY!'%)OMQ+L=9@[@1,RB!42ZGG^
MT?B!^V;#)8_'[XE01ZH=4B/B2X66\!<!F54E%N\C1J[M`LSHJ&1A+/'*3'#(
MCW!_=+X%?!KQ)X,^%?Q2U_X:01>,?B5HG@_5=8D\2Z[.MOIGA.[LK25=0&F0
M7-JM[#)%;1.R-*1<K/+;"V07'DSI_/#9>'?$?Q0\0ZWK.N:HQNI+R]?4KZ\<
MW%S=W=Q=W$TY3<D+$&>7<90C(2)`S(3"B_T?X*</T?[8SG'Y1AX4\KPL*.5T
M*\Z$J5;,:\:M+%5L6X2A[6&$HR@J-"3G&52K.NZD&E`_,_I#<8X3,<+D61++
M8Y9B\)]8QF*H1J4IRPSQ,:=*&&J>Q;@ZU.%*\XS?M()VBHI-S\8&]@"0@)&2
M':`L,\X8AB"P[D$Y.3DT5]?Q_!?P+;QQVY@UF8P(L)F76@%E,2A/,4+9A0K[
M=P"@#!X`%%?TH\FS*_NRK*/V4H-)1Z))5K6MM;3L?RDJM*RO!MVU?,M7U?\`
M#/W'^)6HZA;>.;]K:^O+<V?BKPO#:&"ZGB-K";>Q<Q6YC=3!&7^8I%M4M\V,
M\U^VO[22)J7P@^#FKZBJW^JWGA6P%YJ=ZHNM0N@-!MIP+F]G$ES.!.JS#S96
MQ*!)]\`T45_,<_\`DW-+_KUEO_IJ!^U8K_DXU3U?_JNPQ^#/Q;N;C0_$\4>B
M7$VCQO8:<KII4LFGHZPZAI<,*LMHT(98H;NZBC!!"1W-PB@+-(&X)=9U@:@Y
M&JZD#:PS?92+ZZ!MO.>_DF\C$O[GS7=WE\O;YCLS-DL22BOR3-/]X?\`AG^5
M0_J/(?\`D6X__L#J?^JZ9^N?PGTO3(/^";'[26HP:=8PZ@_P;O;U[Z*TMX[Q
MKR:+,UVURD:SM<REF,DY<RR%F+.<FOXU/A)//)K;B2:5P=3F!#R.P(\FQFP0
MS'(\V667_KI)(_WG8DHK^I?!C_D4O_L+Q7_I5<_DCQJ_Y+;/O^PO_P!OI'U9
M1117[I+=^K_,_'C_V0``````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O:6-E<VMA=&5K:60N
M9VEF`````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S,#<T(#$P-3$U-#,S-S4Q(#`R
M-3(T,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!'248X.6$H`#P`]P`````````S``!F``"9``#,``#_`#,``#,S`#-F`#.9
M`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P`
M`,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9
M,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`
M,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9
M,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`
M9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR9
M9LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`
MF3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9
MF9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```
MS``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9
MS&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`
MS/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9
M_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`
M_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+``````H`#P```C^`!$)'$BPH,&#"`FR2L2P
MH<.'$"-*9,AJX<2+&"-6S,B1X\:.("5^#$FRX<B2)#<B\G)%ALLK7;P@0BD2
MT945`'+JU+E"QI66,KS09&5EI]&C.0-8F9GRZ(JG4)$"8"$T)"NC5G`"6&&%
M5:!`7I_J/-#%ZDZ7.5>PNL:*Z]J*6=->`=DV)XNB6]>RM0+VFE^X6N=Z%,1B
MA1<6.0/Y91MHA>+%;.NNN,+T(BM$@JX(PJDV<N/'C/O6W2IXXDC.:[\VMO(7
MK&._@<Y6AC@2,8"WC@-U#;V;K=:<I6E;3-0E)^MK6<'JK:C7]\X5LQV.1(3:
MMUO(D$?K%"1R>"(O.'?^:W5;,?OOG%VB4_2>Z$H``&!C;]7--SM2Z*T>GF1X
MTVWXBGTMAA=/:04BB"!6R)`>>XED]A1?#]:WF';S&9?59%E=X1UF3S7V8(?9
M#6@<9Q<J%E9!YVW587E_B9A68G@]UIA4/.G&E7(S&L555`42Y>)1-J9(HXHJ
MDJC55_<Y)N1.(BH'H%,7[A3D5E(I^1R/.B;G6%S/9>GA34/">*%8/%F1G&K*
MP?:@?#22Y^*.636''6-0\96C43*6.6.<<V(W&E=7.*7<F'?RV:=7.4ZVY!5\
MG7E4<H=")>EY$,ZGVI*09N=A5P".YR%7/R*5U7%_<?:5F6::&IZ'!$I5U''^
M1$'5'&`[\L157LREJ*A:%W9EIIRH"@D=1`IYE=:-)OY:JEBY_<8@1(+L!%=K
M?,5ZJY1%/?L0=3T&>,VGH>JD[4-=K-"%;G"]M>EOY^$T[K:)4`=GJBR4E9!`
MK+0R2Y_Y04LB3-QEU):^K11LL+[7S`*1%0<$3)=Z#;62L+\06Z:MQ`D?7#!1
M&A>\+W8'[Q>QOK.4;/(LK6A(\LD=GRSRR!HW]%1P`L\D$,)]0C9+73(07#!&
M5\GZL\<?]XL(EVI][!?*(D$GT$3[VM2N0QXOUJ])#D^DKQ4!!/!4O2MD/?*^
M5[?U;B+[;J;@"@>P3?-#$BN<2$7[HGQUU2C+^[4D%>EEQ/1&!??)=+P^"5*Q
M1'][%S--TEU#T;V01XY(6X8+%!```#L`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+VYE;RYJ<&<`````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P-S<R-B`Q,#4Q-30S,S<U,2`P,C,U-C0`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````_]C_
MX``02D9)1@`!`0```0`!``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`'P``
M`04!`0$!`0$```````````$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%!`0`
M``%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8
M&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X
M>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)
MRM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!
M`0````````$"`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"`Q$$
M!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I
M*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'
MB(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7
MV-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#^)6767,\;'RHE
MDDPTK,%5V!SM5BP!9B-H`))SCKQ6-XWU:34+%;:W*B*79!(Y+F+=YBE@SQ98
M%1\[`9PH)<%`PKS>76+QQL#@M"S21ASPQ_BQSR0,D;>X^E:"7$L@LX%W7$,R
M/<72,ZQ[2R.9(UD<X0LFX<G."<>E>="GB:*IU:>'IU:=%RG[Z7,Y1C'GY8R:
M;Y5R/JKRU:OK]`L8\9*<*BM4Q=2%'$SVYZ]2<5[LG92<KQ44M6]%KH_V7_X)
M+?LQ?MS^-M7\7^*/V6/#=WI%EXEL#X2O_BG=77ASPS'IEJ)A;ZK#HGB+7(+^
M>*&[AN7T/6M0TO2-:NM(T_5+F\33+JYB2UE_=>3_`((<?MT:W-X!T+Q+XQ^%
MM]X:75KR>XUSPIHR:?/X,^T))K]O-)/H]G/?>+=)\&:A8_V5\/K?6KI;KP99
MZYKIT35H]/UB\\-O]??\$X+[7M-_94^"GA?X8>&-3M-+M?!^BZAJ.E6^B30?
M8]8\4:=!K=Q?7^J06P-RMV@TUHFD?$@U+3W3(N[<R?J3IWQ"^*L.FP:/J&L:
M=!*59AIT%U;2W+)`J3LCQ32H,;#$7#D?+(I'+IG_`#N\0OI&\3QXLS>CE=#+
M<#A,'BYX5+&865:525.2O4A5<7&4'>,5RNRE&:MLE_<.3^!4*?"F2O+L1EJQ
MV)PE/%XRE7QM:AB:,:JNU5HT9ITX\D>;]Y!3:U;22O\`S'ZI^P=^V=^PC\;-
M/^-L'CS3/$W@+X=6VH0W_P`3+C1;WXGV[?#WQ%)+X?\`']OK'POUJ&P.O72^
M']:U>X_X1ZP%SKMY&F[0(I=96P5ORP_X+3?MV^&_VUK+]D]_#6KN^K_"OX<_
M$30O&NF2F.6\M_$.K_$B]TBT\0:IJ-KG0YM0\?\`@WX=^&/&;Z=H\CG3M'U7
MPU&6:%)GD_LQ^*OC;QCX?\.:_P"*?&-E,^@6-O?&=5TO35TC3[34+"YC-SKN
MI2M)9:98S6CS7#7-\T4+6L<LH?8K./\`.=_;#T[0M*_:.^,>B>$+2_MO#VE^
M-=6T+1(+PQ7$LUM8ZE/!=S2&$%8BL]JZV.T8?34=HR8T8C]<^C;QG7\1^)LQ
MK<0T\-_:&59?[7"XS#4%AL-["2E&-%<T(J=5SE4<DI-\K5DE=O\`-O'O@>AP
M-P=D]7*:^"F\TQJPV/HX/%3Q/-B>6FYSFI2=17BZ:VY;15M]/E!&38F60G:N
M3E>3@9/7N:*Z]-%LPJ@M("%`(!.`0.<>U%?UP\5--_O'H_\`GY#HX_\`R+_`
M_F2.3NT?W;V7V-/L>7K]S[Z<;"^]@[E4VY8EP0,*I)4C&26`V@<$EAT/-?0'
MPA^$GB?XAQ:G?Z5I^K2:+X8U?P2OB;4K4B:+2[3Q[XFL?".DF6W"DQW-S=Z@
M9-+2<I'<W%M(P#I!/M\#MBJ7^R1VAMYI'CDEVL/+MWS'<*-J2'<T3R1`;&PS
M@$#-?I%^Q+\2?AOI7@[X]?"3Q[H_@2+4_B)X$O?%'@/QIXB\1_V/-X9^(_@K
MP_J@\&6-O'K-Y9:/J]S*^KW,^DV,UU)(GB6&Q:TCDO;>"`<V?5\=0RG$8C+/
M>QF"EAJL*<KJ-2G7QV#HU>1I>^X4G4G.*4G&*4FK'I<%X+*L;Q/E=#.L5*A@
MG6KU>7FY5'$8?`8N>%G+I'_;IX)IR>O*UTNOV[^)&E?M/>#_`!!/X7\&V/BK
M0/`W@&UDT?X,_P#",?M.^(O@[:Z;!I8TG3SJEK%X363P]JFO^(K47_Q`O9?%
M%Z^E:AH<NK^$].L]2OK6#2KC[8^#'P^_;3'[/O[57BGQM\1HO%'C_P"%'A5]
M2\#^*++6$L8/%;-I;W-U8SZ';>#/"KVTFFZ/8QZU)>:MX:L+B?3[W1M)-S?:
MCH.HV[<Q^Q+^T9XF^*^C:;_PE,FIVVL:)H&CV;ZEIJ[]5U1[73K:PM[?6+"T
MM+NTGU2UN=/O?+TRSSJD\I^S0PR7,B1MZ[\:_P#@I3\$OV2]0^*WP:^+?PV^
M.$_B_7]#GT[5IM*\'>'K+P!<S^+KK0-1TV#P9XMD9+_QG?I\--2T[Q%K47B)
M8!I6L6-]HD)74I(K8_YT9MG7$^/SC$<'X+@7`XO$Y7*EB:U94,'6<XU*=*K-
MJ5>?M(Q=6HXS5*,8N4O?;DKQ_P!.\=@\CP67X3C'+\[Q6&I\5U)854::;=/!
MQKRI47427N*.&BM9VLE[NK2/R/\`B+\0_P#@H-H-_''XC^*/QD^)/Q%M_#(C
M\-:SX0^.K:?X9TVWO]&BU/Q+I=M\,])M/#NBZIH^@WEQI^C_`!4/BCPUXAMO
M$FM7&CV6C7>G;WO8_P`1_P!JWP3=>%OC7\0XDM[>TM[;5?#E_JFGVNFFUTZP
MUOQ1X<M-8O=*"Z7->:++>Z1J%WJ6DV&HVMX\GB+3K.]UB%)(3.\?]87[1WQ_
MTWPE\%O#^OZ?.^M2:QX7\+ZOX=L_$VFII&OZ]ITVESPZ)=^)+.UMEBT--?AN
M=-OO&*7TMO'I.M:C<07C1W.AM''_`#:?&;XC^']9^!?Q5\=^.38^*?BC\=/B
M1I\.D7FFZMII7P;I?P[U#38XM4U/1H)&O-.N);#[?X4T2"ZC@.JZ/?7&M6YN
M(+1Y*_I7P6X@S+,8XZ-3@_"Y+]2ME5=QP]##RG6IJ%6=2G2H^[R6K<R:M+FT
M4;7<?P7QWX8X;P.3TL)_;D\57H82&=4IRG%S;K2G35.*NG)WI:6VNVWI9_!Z
MS6X4`VT((`!!M9P00.005R"#US17`?;F//VH'/.=W7W^]17[O]1EWG_X"_+R
M\G_3T_B7^UH=,9B^GV)^7^?X^3(=3C6/4;V+&X1W%PB0[MK,6N`B*HX)/(8`
M#)"DU-!INM:?;Z=K1TK4(+*ZNFCTS5FM[@6$]U;'S)8[:\*?9IY(`A,R1RL\
M2JSNJA35S556+7M0E;(A^TW<,A*95XY3/!<1!BI5#(CM#YH(\EW$@8%01+/J
MUWJMOIEG<W*&/2=/DM+"!Y`+>WA-T&L[98]H#S1W)CN+FZ'S26R-YY=(RU>Y
M&$98>A*5G"4W3J):M+E@VG9W7:TE:UT]!8NG*AF>8>STE2K2=&?V9J,TDXNU
MI)M/WEU35]#]NOV(?VFM8TBWFM=-N=-T_P`6#2-'N[.]\26'B#4O"^DZH1::
MM9^(/$%EX:CDUDV41OIKNSEMT5)+J&%W8VZ3$?>'Q,_:1^._BC5+^?Q_KE]K
MFL:FZ:OIU]X4_8V/CSX?ZJZ6UWHEOJ?A_P`3GXNV'B&\%QHHL+*\C\6^'[?^
MS+*.74+&(7]G:D_C7??!GXD?`?PK^S?\5M(U"ZAC^(7PNTWXB>#O%-CI5P--
MU-=;U>Z;6?!KS2S6%AJVJ>']4BU'2+_2XKXWVGZ!>V%S-;JDMNLOUKIO_!73
M]I7P[X%N/"%KIW@$!)Y;.2\6UU:SO+2YE06@MVT;4;Z\T^\2%G$P"HR02*+F
M,+)"C+_-/%7A]B)Y_B\]X8R'(LSE+$.AC<9B<9[+'4'%J4J48PA5_<153GNX
MJ\W4C)*T6?VSX;^*F`P7#&"RGBS$9C1C#"JIAE1PE&K2<>2,(MSK.+4^:+34
M?=V:W:'?M=_M->.M9^%<.D?$CQ%X7UWQ0VI6&CZ':>$M`U#1X]!T?3W@NH;3
M5+#5KC5+JVGNC;+8"RTO46$5S<)$^Z+>K?A'K6H75]/J+SQ2J;FZ-VEM_I$<
M=DTLFXN('VA3-'E!N'*G<IX7'Z*:-I?Q8_:R^+/ANTO;:7QKXL\2Z\MGI6@0
M6XTRSEO(KA9-4O+J&*,&'0-*M?-NO$FMLBV7AW2(;S5]2N+6TLIIH_D_]I3X
M>I\'OC1\5?A39W^JZUI/@+QYX@\/^'=<UBW_`+/O]<\.0:I=OI_B26R>**1D
M\8VOV#Q+:[=ZP6MRHC9X79Z_5^`<IRG)*4L%2I8..8XO_A1QM'!UI5E&M45.
MC)N,[2A:5))Q24=+*^Q_.WB_Q)CN)LV_M+#UL;6RK#TE@,/4Q="-#W85:E54
MXNG>G**C6O>[E[SZ)-?.N\^@_7_&BIRL63EESWR5SGWHK].L^S_K_AU]Y^+>
MT79_U;_/\/6W1ZV3]OU$9.#?7N1DX/\`I;'^=9-J`;JU4@$-<P*P(R&5I4#*
M0>"&!((/!!(/!HHKBP_^Z1_[?_\`3:/9QO\`O_\`VY+_`-3*I_H07G@3P1KO
M_!(+XQ^'];\&^%=9T'P3^R]\%/$G@S1-5\/:1J&D>$?$5W\*1J=UK_AC3;NS
MFL]`UJYU*./4+C5=*AM+Z:^C2[DG:X59!_&%JR(=1^'<)53%JG@K0+_4XBH,
M>HWQMI$-[?IC;>793Y#<W`DF*_+OQQ117Y#P+_R,^,O^QEC_`/U'PY^SY]_R
M*LA_[%>&_P#3]0_IE_X([^&_#L?['G[3?C*/0-%C\83?'QO`LOBM-+L4\22^
M"8+?3-<@\'2:ZL`U1_"L.MV5GK$7AYKHZ1'JEI;:@EF+N"*9/Y[/^"P%O!;?
MMR_%V&VABMXEB^'6V*"-(HUW?"[PB[;4C55&69F.!RS$GDDT45P>'?\`R<?-
M?^Q8O_3]8X.,O^3?8+_L;O\`],8<_,@(F!\J]!_"/\****_>3\.73Y?^XS__
MV0```````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S
M+VUA=6PN9VEF````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`R-R`Q
M,#4Q-30S,S<U,2`P,C,W,3,`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````1TE&.#EA(``@`/<`````````,P``9@``F0``S```
M_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"9
M9@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#_
M_S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F
M9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,
M_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S
M9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9
M_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`
M9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF
M_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_
M9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS
M_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,
M9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`
M__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^9
M9O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__F?__S/__
M__B_)```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"'Y!`$``-@`+``````@
M`"````CT`+$)'$BPH,&#"!-B6P&@X0J%$`DR;$@1P,.("2=6I'@18T&-&SEZ
ME%AQA4F3)4<*+`F)1$M((%5.-`GI)0E:,&>.I%@3"21:0"'YA$31X\R;0H'2
M\DF+A,Z(#@'\9(9**2IF."TVC#@3@$MF3I0Z8=92JT6('!NZ_!FTK%D`:!V6
M)7$3*%VO,(MFY%B3+<ZV-35V-%A2[4^Z2$E$U7NPL%J<-9NF94QX<F272(F^
MA8MPXT3,-A=3)NGYI.F3(0</#,FZ=<7&KF-O-`A2MFN3*G,KG%T4KN_<OX-C
M$ZY2>._AR(NO1FX<^/+@6T?KGDZ]^O2````[````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V%V871A<G,O=V]L=F5R:6YE+FIP9P``````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#$Q-C4W(#$P-3$U-#,S-S4Q(#`R-3`Q,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````#_V/_@`!!*
M1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_;`$,!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!
M`0$!`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#!04$!````7T!
M`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F
M)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H.$
MA8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4
MU=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!`0$!`0$!````
M`````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&
M$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W
M.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2
MDY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KB
MX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/T\^-7C;5_$7QU^.WP.
MUC3;32KGQ)=^(?`W@/Q;JOV33K3PSXC7Q3X>\82W.MZQ+"1IW@+Q._PYT?6;
M[5(Y;R[TV_ACF:SMH=5U4C\;/VR]4\0_&NR^''P/ALM'U^Q\->)8/CGJFJV=
MZDNEP?"OP9X`\9Z;<7XO+83O=W>IW^I^&M&TV2WCFTO55\0"_MM0-FXD7]:O
MVJO!^N?"+3_A/\9?#\D'Q,^$_CF;6$LOAOJ%[;V_BRU@(^VW/AK0?%MY97^J
MSWUIIDDVD:9X;\5ZCJ6FV,*S>'[==!M+*PFL_P`:OC!^T%:>"-!^%GQ/^&NG
MVL.I3?$SP;\/+;2]>L=&N-+\2?LO>/\`P[\2+G5OAUXTN;PZG'X>U^U\1Z;X
M=\/VNNP75O?:!XD6WT"ZU860ELF_S?\``[P[7"7C1X3YSGV78/,LAPG&&%7#
MN<\.8^>+PT5CY8V&%GB*./PF6X["8JK5JTXX^%>@Z->5;&2P%3%_5\3B#]>S
MSC;+^+_"#Q$R+(Y8K`YC3X3Q%3,LOSK`1P]6GB(4J6'K8K#5\-5QE&OA)4:5
M.I3C1=26&E"DL6Z3J*G+L_@S\5OA!9'Q1XX\9:A9^'/`7P#_`&=?`FEZ[J]S
MO\V'QA/K/B_7M5TD:7:K<2R6TTOB[P_I^BQ6B37FH7MU<P1VR^3;FX]S_8?_
M`."E'Q"^%GQ(M9+CPQXYUG3?$GBKX>ZB_P`-_P#A&-2U'Q#<^'_$'A?XHF&]
MB'D6MN(=8N[70+W1+BTO-1TF\&G:R)]6LU2&YD_FA^*/CZWTG]IKQGX4F?64
M^"7BKXO_`/"=7OPHU6=X;W4+/PC;S1^`O#?B&.26&>\M8O\`A);?4=6TV_OI
M=%672Q`8[B/3Y$/[2?#[]KSQMX7LO&7QPU_5K9/VC/B2=!T?P7K.@Q2V-QI.
MB^$YM5M=#T^#2GMX6\0:9H&G:C;+#J>M64D,D\4VHO;NT7AQ-*_V4>9<59[Q
M'/AO+<CP%3A?!X7%8C/>(,PKNGRXNOC7++\FR?#1@Y8O&8QNIB<5B*CI4,MP
ME*D^3%XG$TL*_P"1,JP64Y%P3EN<YKGE3_6#'4J2R[)L#2C.?^R83#1QN:9K
M*:<J&7T[SPF$I4IRK9AC83@O9X3#SQE+^I./]IOP]\6/`?BOQ_H_A&]NK9X=
M0.B:2D^E:GJ.D_9+2Z47&LB&[1+!+R9"\2M&LI2&;!DPCU_-=^U+^T'JOA_X
MN:;XSBT/4["_\-:_H/B6R9T@-M'?:;K5O>P)*K3Q1,DTMF8_+";=D;1*^SYV
M^E/A'\8(_">AZ9X$\/7-SKFM>*H(+76KF0:5J$>FO<-);Q>?J=G;R1F[@^VR
M2/:Q7MW:^:LD4;M'&ZMZ9^U!^R4=;^`'C+Q))I,=UX@;POJ-_8:A);3J]AJ%
MG8W$T+198Q7P$H5T4>:K,P4!0HV_K609/ALFHXFE/GA/$RC3P4I5;QDX0:^&
M::5.,GR.7,W-^^MT?+9OF>+S.A%T6G4HI5*VG5)2<79+WY12:CJHZ0O9-GPQ
M>6EOXDN[KQ%IOQ*U?2=.U^YGUK3]*F\])=,LM5E:^M=/E2._EC22R@GCMG2.
M65%:,A)'4!B5^6]K\:/$NG6MMI\KZJDEA!#9R(LEOA7M8U@=1YL+2X5HR!YK
M-)@?.Q;))7N?VC66CKU%:R:]A%VMRW5^;6WO?U8Y5Q#@K+FHJ]E>U;$)7TO9
M)::K3MIVU_;#_@MU^V-XRUGX3_L]:[X=A\'Z3=?$#6O"'Q.T&7P1X3U&TFU"
M^UJT;7/#,&C:M%XA\1/X@2ZFET^)+[4;/PWKDTXQ<>&-+GN9--M_Q2T#XR_%
MKX1_M%^&="_;!\)36OPH^,FJ^$;/Q?X*\%:[%!I":YXCMH-/\#P>+]*:":SU
M&T\-Z[IEC?\`Q)T+2M1L[&[MUNY;J35;RQT#29\KPKX^L?B+X9\,_!GXJ>,/
M$7_"J]`\3WGBK08[%)]5USX;^-A;7TFG>*_"%L-0LL3/J4D=K?:)JDNI^$)[
M75;S6-0\,ZIJFFZ3>V?U#^T[\&/#GBVR'[:_CC0+N7X,>`_!ECF\L;&]T+P3
MXC_:#:V'A3P9\(M-U.[U:^M=1\06^I:'XX\:WUEX'U"+PAI7P]\-^%==T_2[
M;2O'.G$?YJ8!\-XKAN?!&986>4Y;GM+,LJSC#9/DN-S;,<5F^85JM;(,WP&9
MQJJKDSPE>G5K8;$^PKSP^;?5:3Q^"C7H5L5_7/&'`N;>%N?U<QA&6;RA+#YI
MPYGTL=_9V!>6X67L,PRW$8145'&YE)2HT<=A*>+IPHX*?UE4,;&<H8;]?/@-
M^PQ\%W\6?%'Q)\9_@3\,_B59^'M9U"RLM$\2^'[.;P_X'NK#4?$`@\/^%KVZ
M\.^:?!]O=Z@!;P"QTJ:SLK#2K%;.]C@2.W_"N[U"U_9)_:2UOX;_`+4'PJA^
M&6M6JZ=K6G:A!X9\)6GPQUG2)MDB:QX%O-)+6^K"YCE5!LALKJTN[66RU^32
M+U(HF_H>\"_M*Q:_\'M075_$>F>'/$?QH^&WP<_:&\`1QZ?)>:9XYT?QYI&@
M>-/%*:!?1*]K<7/A[4KZ_P!)U#28A<75IJ-A>Z'/]EU"UDM'^,+?7?&/[3WA
MV'5/VL_"/P1UOQHEUJ5CX*^&WPY;3O%.G^$_#!^SOJVG^)M<LE9]=\3PW%G`
M?$VM!1;)<((6E\R%I*_D/P+^DI])GP^QW%>1\?9KE.-X#R*KA>&.'85LMRR/
M&F!ABX3H9=G.2YC.C*6(R["4<#F%;,*'$>$QV(I48X.4<30PZPCQ_P#0V)^C
M;X?<<TLKXQH91C\)'$.IG^(P-&MF<\LSU1PN48G$X3%X>G+`QH.MF&9O"8>K
MEF,H\U6.*G1ISJ8/%U<-^D7_``3T_P""D_[&WA#Q-:V&GW_AN34/$NIZ)8'6
MICX7N=9%W<33Q6!2XN=42[M8X99F2"+1D3R`TC"T,@19/TS_`."@'Q+T*T^$
M'BWQYIH2^\$>*?#T,UW/HLD-S<V/BB.&[BAU;4AYZVT6FZO:VFG:='<03N\&
MM00.\+S:Y),?X]/CS^P7^SMH'@";Q5\+=`OSXXU74;/1O"^J?!G2O%_BGP=H
M'BGQ)JEGHO@_4/%GCG3[BZ^'_A6U/B"^M+8N=6O;I9!=*(X;R(+']^?\$_/C
MS\5/'?[/WQS_`&(OVQ/$^ICXI>'UU*+PV^J)866MZG\--1M;*.*ZM[>*RMTU
MA_"7B+3K^9;R*&6ZM+E=)N[F8-,9'_:>%/%S./#['X7CJ7&F<<=\-PS?#XWB
M7#<5KZSQ;1PN(K8:CB\3EV.PU7$4\SR^E3G##U%.IA?[+QT\!%TYX>>)CAM>
M/?!+*.,L!47#G!O^IV84L$\-A\#EO.LBA7I4ZCP<*N%Q-#"X[+:]6=*=:,I4
M<9A\QPE/&5:>-=>$8U_CV\T/X?ZA=W5^+*QE%[<3W8EEMH!)*+F5IA)($#('
M??N<(Q4,2%)&#17.W_[)'[5UA?7EA9^!M7U>TLKNXM+75M.O=/?3]4MK:9X8
M-1L7\P;[.]B1;FU;`W02H<#.**_U2H^-'A!7I4JU/Q/X(E3K4Z=6#EQ1ED).
M%2,)Q<H3Q<9P;C*[C*,91;LXII(_S^J>&'&,*DX5.#,_52$Y0FO['QCM.,DI
M*ZP[3M*ZNFT]-6FS\>;*PN-.O[?4;5=JL46>/&Z*YRGE,)`%W*\C%96(90O#
M$KG97[<_`KQ^/V\/V6_A-_P3T\2V<?F_"SXM^(_V@I=,E6WLM*^*V@>#_A1X
MG\,^$?!4<EBR:DFOZ)=ZGI4-[;-`R:WX6T9#_:;7ROI[?C%;0/\`O&W*D)\M
MXXRQ#/(&(&TLY\O<!D%2BXVH[E2%KZB_9N^'GQ(UWQE97W@!]>L-:LS%?Z?K
M>DQ7UM/IKQ7MJZ26=Y;(A@N8I3&Z7*2QF-TX8DHI_P`R.,,QCEN48O-O[6CD
MN+R_!XJ&&S=8AX7ZK&OAJE&<IUKI_NU5]K3G[TJ->G0KT_WM"GR_ZL9YD_#?
M$U3*LKS/!4L='!9O@\[P6#K4UC,,LRP-2G.*Q>%]I16+R[&QI^QS#!RE3CB,
M/4G%R4U&2^Y/V(M4^%MA\1?&WPP_:OET:Y^#'P?A^,.M>$_!GCNTU;4=+^'G
MB'0H;NXUJU\`V&D:?>:YX:U;Q;-JW@O67T+PI'H]KXH2RFDU$3MHT3)T_P"R
M+^QKXI\3^$O#C>##\2M!^#'BH'6O$7B+Q9/H6A^)/'^BWMF=9T.U\/\`A;P[
MKEQJNB^%Y#'=ZGJ\ECK+3:Q8ZKHLT<8@%OJE?1WQO_X)K?'SX]_#Z/XR>"K7
M3O$GQQN]-MI_B5I\]K=:5XH^*EGI.A+IGA>XT/[%%9>&+3Q9X<BDOK2ZFN;3
M3)_'VEZO=0>)M5U'5M.TV[;Q+]GCX$0_##X#?$_X8Z1XI^,7Q._9DUC3?"MV
M?@Y\4]2U+X;^//V4/$-BFNZI\2?`GQF_X0RY\*?$KQ)X5\?ZE/I]UX+\-Z,M
M[HNH:-X=\0V^H^#KWP_XG76=;_F=<?</^(_!V=YUP/QKA,PQ5/-<KRS/<EI2
M^M5L)4RV=?+\?4R[#XJOAL%2S>G5Q,<XR%9GB\KR[-<-#$Y@\?'.</AL'0^C
MPF:SP7&DJF7953QF*J0Q>'J3IXNG4P/#^+K2PU3`?6,/AJ$:ZPF90>)PN.Q]
M/"8[&?6X8.GA\HITUBZDOJ34?',?[5'B;X'>%OV=[W6]#_9;TKXR^']0N-:T
MV^\,:EX5^-^O?"'7=$\4>+-.^'^FMJ-[XL\,_"W0)=`\*^/--U[7M'\,ZSXL
MUV*;P]X9TQ?#]AXF?3;GQ;^!<T/[4OP$^+7@^+SM7T+XBZ-X/^)<L8"WUWX%
M^+%W=^%+DSPC<)+*PU&Y75?*,J,'M$D0RS.B'SWX1?&MM*\3^)?&6EPZ;IVM
MWUA8Z'X9%]8:7!K>G:/]DO6UU[*PTVWM-!L=1\1QI;-+:>'M+AL]`T^U^R:1
M=W-YK'BK5=<_0C]G'3/"PM?&'Q+\<:PDFH:7HLGBC4+^]ND&F+)X9U73-1T+
M3[=1+;VB2V5N^HW3I(-[+))/,[M&#'\S@7C:F=9?@,OP>"RS*\MPV;8+$9>F
MJ]#$TL\A3IX]XW,%A<#4SC&5<%*M"KF.)P^%;JQIT,'A,!@,)A,)0]O$RK<+
MPQ$,VQU;,L3F6&A6QDY-RK8W&QJ\^'C@</\`6<8\%A,M:P]E&OB'6S!8K'XJ
MOBZF*G7J^$0?%.ZT^&&PDA<R6,4=G(5=MI>V00L5Q'C:60D8XQC'%%?'NG0Q
M:UI]AK%WYJ76K65KJ5RBLZ*EQ?0)=3*J+&%15DE8!5`"@```#%%>96H\/4ZU
M6FH*T*LX+W8;1FDOM]DOQ[H[J/#O%TZ5*4J%I2ITY.\:FC<8-WT6S;[;/:RM
M_/D680OAF'[VT7@D?*\?SK_NMD[AT;)SG)K^E?\`X)_:1I47@_PY+'IFGQRM
MX?T;=(EE;)(V[^S`VYUB#'<&8').=S9ZG)17Z3],/_DT^-_Z^U/R/S?@?_DI
M,7_V"5?S9_4]^RW;6YM[@FWA)BM=!2(F*,F-&MKO*QY7Y%.U<JN`<#(X%>;_
M`!O\#^"_^$O_`&B8_P#A$/"_E^(?AD5U^/\`L#2=FN+IEWKK::NL+]DVZF-/
M:]O6L1>B<6AN[HV_EFXEWE%?QI]$7_DS&#_[++B'_P!2*A^,Y5_R<SC7_L&R
M/_U?9*?R$?#N**#X?_%74(8XX;^">.WAOHD6.\AM_LS_`+B*Y0":.'D_ND<)
MR?EKZE;4M13]F_XK,M_>JQ\%7^66ZG4G?8:_NR1("=VQ-V?O;5SG:,%%?UEC
M/CE_V&99_P"HN#/WS/O^3B9;_P!>*W_IRD?BSJVNZVNJZFJZSJJJNH7BJJZA
M=A547,H``$V``.`!P!P****_1J/\*E_U[A_Z2C]P>_S7YP/_V0``````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V%L:65N+FIP9P``````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,C(R-"`Q,#4Q-30S,S<U,2`P,C0P
M-C``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M_]C_X``02D9)1@`!`0```0`!``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_
MVP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`
M'P```04!`0$!`0$```````````$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%
M!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*
M%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U
M=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&
MQ\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!
M`0$!`0````````$"`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"
M`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF
M)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$
MA8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4
MU=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#^(;QQI<-G
MXYU[1M&C-VIUR[LK:.PLGCCCN9KD^9IEK9H"TBV=V\FG6YME\JY$*RVZ)%)$
MB_M5^RC\*-=FTN+1]'&KW%_?1K9:?:ZN=.LX;[1=*L(+O2]0$IT^RDD:*&YO
M+2VG@E6"\@*O-#<W*B['Y/\`QK^%/[0WP<^/ES\//&'AO4(?C2GA/P#\4[OP
MWX6M[SQ)J.F:'\2OA#X<^-^EP26MDFH2/%HWPV\5V%SXBLF^TVNAV5KJ=I>S
M2:?87$Q]Q_9N_P""CGQ)^"NN:1/XJT'3/B'H=KY-G-;/LTK5%TF3[6MQ';WL
M-M/&MY%%<PKIUPD$;6UM8K8GS;*^O8YO]=\D\7.`\LXAXDH0QF,P5?$XRI2R
M&IF&%@LGP]./M%0IXK&9?5Q,W9U8J=6&&J1FJT*E7$TZ$%3I_P`B>*_!7%W'
M?!/#M'AI9=G6'I9;@LPQV'684Z>/S55\+2J86OAGB*6%PDL/4JX>-1U)8K!5
M*M.5:6&A&O2HH_I?AUB\\":GIVD^(Y(K70);-([;4;;3X5NKN^T72M/T6<:G
M;VTM_<16=R;9=0M0ANM1B%SI5I/?K;6U_86O[8_L2_"]/&'A-7DT\(-0;5-3
MGN=(M9GOKVVT.YGM[&"]GO&NK6*\MY[;5[ZV%I;B)[2U?RK7^T'O+ROYTOVE
M_B_\+_C+^QO\"/VN/@?XKDTV'P]\<O!WPZ^./A*9[^+7O#?_``FMK_9PE?3K
MRWM-0NIM1@U*'7$\NR%@VDVEG=6?E2:WHVHV_P#49_P3Q\6:1\/?V#O'GQJN
M+G5E\1GP7XVN?",9U:5+P6\7@6\AM4N+Z::ZB34G\2ZI:O'=Z;IVGB34[Y[A
M[*>>Y>XF\SQ'Q$\KX9_M'(<=*MF>-QU')H4,%",:&95Z^/\`JN6UJGLISM3G
M&3QTJEZM&O\`5:.,PJ]E]7KS_B7,LI>9T<DIYM3K\)8C%X[,\DS_`!V/PT:5
M7)IY'-U,VQ*PN)Y7/,O[*=.AAJBK8K#YAC\TR^A3G1G.M[/ZO^$'B+X+_"?7
MAH?CGQOI[WVNP"_TJXM;$^9<I-8P/#;,8IW<K;Q%YTN/M]O:VT%_-=S2)IUP
MMQ<[OB?XB^%-;UK[=H$K2Z)+<_9Y]4FL[NPT_3K8V=Q>6LM]JEQ&]B]RY?3;
M#[-<W=K?0R7L%K/`MQ:O'+_-#\1_^"CG[*?_``3D\0:KXL_:[CU'XY?M2:]I
M-EXF\&_`;P=%IM[J?A7PWJ.FZ8WA";XC7%OJEKHW@&ZUS2+O3M4;3_$>JW7B
MN^\.6^I7O_"(0Z9K]AI-]\/?$;_@[._:0OM=T36=-_8-^$'P_P#AUK.F7%YI
M.EZOX@\6R:WXAMPR6UGJ>C>.;3PMX6TRZL+>XM'2]DM_"M^MS.US$;^V=G4_
M@.=Y=@:'%N.J1QV+SRLL)1I8_'*O"C@,)5Y)2TP6`P..Q%&<H^RA_M2P=.&(
MC&+4XU*E.G65^#/B!XB^'E.EDO#:Q<5FF)S"AF6+GE>1XGBG,*M&G3G4R[,<
MRQ&`AB\FR^FITL%+#X:M353"XF5:O7IQP]&7]K7V.U/*ZK9JIY59H=124*>0
M)5BL9XED`X=8YYHPV0DLB@.Q7X&?#O\`X+\?LV^,?A_X%\7>)?!FJ^&O$?BK
MP=X8\1Z_X<L_&GP_O+/0-;US1+'4]5T2UN[O6-$NKJVTJ^NI[&"XN=&TBXGB
M@66;3+"1FM8BO+6"Q;2<5BYQ:3C.%!2A).S4HR^KJ\9)W3LKIWTZ?B%?P7\3
M,/7K4)\`0YZ%6I1E;,J#7-3FX2LX\0RBU=;QE*/:36I_$+I7[;_[5_[.W[;G
M@_\`:M\-_$'48_CK\&=.\&?#_P`/^,9;?39;W7_AMX#^%NE?!#0_#WB2YM[)
M1JK:]\%M-L/!^NZ[.B^*)5FEUB#4M/\`$D%M?V?S]\<YO@O\2/BDFM_LK?#7
MX@>`]`\:QW^N7GP2U.2Y\8V_PL\5:IXL\43V_P`-/AEXOEUWQ)XT^)?@/PYX
M/7PG#I'C+QW;Z)XYU75GUZVU?1&ATZSUG6/J#]K'PIX@\&_$/1_CWX=M+:'P
M7X]GQIC+:3L_A[Q39V?V/Q)X-\7P7-I9WMGJEW<?VC/IC7H@N;K26DMM.>UN
MM`OK+1_U6_8$U>RBB3Q#H.A6.M0G2M?UO7+NUTZ.[\226VGZ5/=:.VC2:E!9
MWUMJ%['J^GZ-#I6F3SVMU;ZQ(]U$E_)<R:;^S9?X2\(^*&+K\;<.\98G#\-9
MO7EG>"P=3`X6&.PF68C&8BA3RWZT\7AH+%95B7BL#.G/`3I/%X+$4Z4IU.;$
M+_5WCOQ&Q_A+P_D>*K<*0QF.C@L/DU>G@\TJX++J.88?#152&+PO]GUX3PE.
M\*V"KTJD:]>-54Z4X85^VG\&_MH?M3?\%$OVB_B?\,OB9^VI\.]8^&EE\1_`
M/PN^&.BV$7PEO?@KX5^('A?X4ZCJ^E^&O%9T&&WTQ]5\5Z+<>)-8N;#Q;$86
ML3!8Z=H(L?#^A:5I%A_=[I.J_%+X`_\`!&K2_B_\!_AH?B9\78/@UJOQ!^!W
MP[TRVC\07OB+Q=%XML=/\+7.OZ>EC;#Q1'X"CU1?%WB3PW#>07&OZ3X;O]!A
M57U.*2U_DH_:Q/C?]JGQKX*?P[\.O$7BC1/`=MK=[=ZUIOAJ\\4W?PZ\`V-Q
MX?@'C'QM>P//9^'O#.@WUU+-'?F2TT[P_=>();674WMI)=27^N[]E+QC\1]7
M_9Z^#/P#G7PA;:Q9^"_%7@WX:>'KW7[6Q\3?%'P_\.;:VM_BSXC^$?AMM:@U
M'Q=HGA2?6](E\5>-=&:70M#UNZ:SG@N+_4(H+;W?$?@FGPKPCDG"U#B:4LMR
MWBG!8NO+-<5@,+C,/E5/+LWQ%>E@JD*%+#0A2Q684<5%5,-)4<+3Q%91?LZT
MH?QMQ]QY0XMRC@O-WP1E^)SZE+'*ED625<?/+9YA2XFR/!X7&YS.G7>:SP]3
MA?`8W#8NK/&4\2L;6R:I5J_5(X>C5_S>OV__`!3X/^*_[17C'X_>$?`?COX6
MW_Q[U+6?BE\4/AEXPT."WTKX?_&C7==U&/XK:+X$\5V%IH^E>,?`NL>-(-4\
M:>$VTWPQX>@\%Z!XLTOX<SQZS?>$;SQ%JOI_[3?[?/[5/_!1#X;_`+$G[+7B
MCP;X4U33/V1?AQ;?!'X!^$/@O\/=9M?%GB^*YTKPGH-O=>)M+L-0UZ3Q5XTO
M]-\'>';*(>'],T>Q\V.^N[70XM1UC5KJ]_TQOV7_`-A/X/\`@;6;;0?C'\/O
M!,FA77A2*2_TSQ=HMO?Z%J[VENMSK,%QI&OVFH:?8W.J^=.U[;:3=+9/"NI6
M=U<7,Z6-O<KX]\"?LV_L\^*=0\6?#GX1_"WX;Z-97NIZAK'C#1OA]I>E3Z#X
M.\/Z<]EJ5[<WVBV$>K6<L=E>1:1:1V<$FGO)>W"SVZB^NKF?\'JX7A'"Y[FN
M59+F>:9G1^H_VD\QKY5@(X.K"$<?3Q4Z&?5,UJUZ-;$X*IC(XG%4L-4JU56Q
M$Z^'E[987#_LF+^E%B<NR#),VGX?Y?GF:4\]S/AC(LOI<93H\0/&TL#A\;*5
M?ARCP[BL7ALOI4*N$PE)XNM7Q6(KT*$Z3Q%2I2QE;^8;X$?\&^_[2&M_`_X-
MZUXA^#>@Z5K^K_"KX>:IKFF:[XXUK2=<TW6-0\(Z/=ZG8:SI0;&F:K9WLT]O
MJ.GCBSO(YK8<1T5^L^L?\'(7@?PEJ^J>%?#WP_\`"&H:!X9U&^\/Z'?ZU)<P
M:S?:/HUS+IVF7FK06VDW=M#J=S96T$U_%;W5S!'=/*D5Q-&%D8KY+_B9C-L+
M_LV%R/A26&P_[C#NK'B6I5="C:G2=2I',8QJ5'3BG.<8QC.3<E&*:4?OZ7@U
MQ]F-*GF&-SK/,'C,?3AC<7A*.5\&*CA<3BHQKU\-2^L8]XA4Z%6<Z4/;MUE%
M+VK<TS^*']F;Q]\._C)\*_C%\$_C%XD\1:SXP^(MS9ZA\.-8N)=*O]"7Q5-?
M23:QXC\3Z_J3ZAK:^(KZ>1;.VUG3M-U6X=Y[NXUF:&6.UFE^7/`WC7QC^RM\
M5]6\,WEV]WX?34K6P\4:)>1W=M;26KI#)'J*VPAGN-.UG3;:<&9XX)Y-Z36$
MJWL:J]>$^'OB5XBTO3]$T"&\A&AZ1X@NO$^D0/8V=U/;Z[K5KHMA=W<VKW5J
M^OWUI?Z?%X=L_L%WJ#6-F%MK^RTZQN[[7$TS]"[_`,.>'/VMOAAX;U._N_#O
MA;XS65Q>^$M!UV^UK0K<>.)-!M+"\DT7QI9VD[:QH[NFM:=8^%O&6JZ59Z'?
M2W">'_MHMM(NO[)CZ._C?@.!U/A/BAJAEE3,'FG#/$CE6YN&<TJT94<;EV/6
M'_?8CAG/K4)8FE+V]'*,QI/,J&%C#,<YJU/Z/XRX.P'$F%QM'&8..88',L&L
M!G&624'#%48R4L/F%!2@Y0S++G=T:M&=*O.ER.,ZM?!8"DOTF_9Y_:K\0>$-
M*^,6B_#?5]1\+WOQC^#VI?"_QU+I]Q!I?B.VT#6KYI0VAZ[%%)J$<VCZA9QS
MFXM8TM7L=:%M*;>^OG6P_K._8/\`V(_AIJ_A/]CO]N"/7_'&J?%/]E;]DG3O
MV+]'TO5O$,B^"/#VK^&/#3>%_&OQ!\(Z:UQ;S:-XA^)UG=S7'B_7;66VFU:'
M5'6[2UD^V(G^=]X'A\9WGBKPEI[7.L>#_%G@K5]+\(^.?#=\EAJ&K7NLZ;>W
M-SI6O1V^N/)##>W]Q<6]M<-YFEZ=JUC;HK7Z7%@-4O\`^^?]D'P]^TY?_LP?
M#S4I?VG=#\-?#;Q3IGC'QI<>'_AU\'K2WNH-2U!["Z&GZ3XA\>^,_$4=_K<'
MA[3[BZGEA\/2KH'B*+4K*XO=0L]-MHU_L;QJPM+B')<GS/+,5E.52SG%1CC,
MXK8/$8W"9YE^+RO#TU0C##83'3>)AEL:V$HXJ<:&(I2P3HX3%RH.%/$_YH\<
MY?A_">MFN7U,VQ48YM@L1E^$R[#8RO@LSR?-*52LL)6Q&-IX#,,3/*?W=:O*
MGA%4AB\-C</E^)G"MF%C[B^-GQ`UKQN;CPW#=7::N;N^MTETJY:6[L;N6VU'
MP^D-G>N-2^T3ZGI\UE<26+6<\6EW!FL;F+4I[B\L[+^>K_@K'^V'I'[(GPXO
M?@'H^IR_$'XV>,I/"_BG]H35_'"W6I6YM[$6'C'PQ\)-/1=5M[)?#EOKNHG6
M?%5II-ZNH:EJSPV,.LHNDR6NG?1?_!33_@H]X"_8_P!`'A_X;/IUG\=[V""'
M4]-O+JWU&S^%\/V2Q?2Y5MI["&"Z\6ZO8R6UT'U2ZEDT*2\N+NZMCKBP3Z9_
M"O\`M$?&GX@_%KQF=:\9WWB"_P!8U&&UN+&;Q`VHBY.E7<4":-<VD&IQLZZ9
M-INR?P_.+5[,Z%!=:I:1W%A;Q::W\1^*/B3A\!DE3PXX3E/#X1R@N(\12A2I
MN=:A5A5AEE'$4IU76PM.K'VE>%*M/#5*L,/-U,37I.K']E^BWX&8ZOC<L\6.
M,<-B(T_JSQO#>$S&K3JYAF>8XJM"J^),9[.IB.3+\-&DED%.>*J_7?:_VFJ?
MU>E@,;F6-?\`Q,\9WE]>WD>MW=G'=W=Q<I:6QB2WM4GF>5;:W18E5(8%<11*
M%4+&B@``8HKYN>9"[DVMA*2S$ROJGA#?(22?,?[397]SN?[S?:+Z]GR3YMW<
M2;IG*_F@_P!!1SS3(+.5)9%D-EJ<QD5V5S,OA&RNUE+@AC(MU?7MRKD[A<7E
MU,#YEQ,S^S?#J::#5K+R)9(?+O=;AC\IVCV0VMSJ/V:)-A&V.W\B#R$&%B\F
M+RPOEIM**`/T+^-<DD/C[]B?7H7>'7?$VJW&G>)-:B9H]6\0:?I_C3PG#86.
MMZBA%YJMG8PN\5G;7\UQ!;1.T<*(K$'^YOPWXB\06O[/6D+;:[K%NNC?#VXU
M+1U@U.]A72M1MM"G>WO]-$<ZBQO;=T1X;JU\J>)D5HY%*@@HK_1#@[_DP_`/
M_7[B7_U6TS_.#Z5__)SN%_\`L"H?^K/#'\#_`.VQJNJ:A\3_`!3)J&I7]](_
MB"9'DO+RXN7=//U)MKO-([,NZ"!MI)&88CC,:8^`-9U74]<NM.N=:U*_UBXB
M7^Q(KC5+RXU">/1M#U[2?#^BZ1'+=R32)IFD:`S:'I=@K"UT_2&;3;2*&R)@
MHHK_`#QG\<O\4OS9_HQA?]VP_P#UXH_^FXGEG]L:M_T%-1_\#;G_`..T445)
MN?_9````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]A=F%T87)S+W-P965D>2YG:68`````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,C,T-"`Q,#4Q-30S,S<U,2`P,C0R-3``(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````1TE&.#EA(``@`/<`````````,P``
M9@``F0``S```_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F
M_P"9``"9,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_
M9@#_F0#_S`#__S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S
M_S-F`#-F,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,
M9C/,F3/,S#/,_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`
M_V8S`&8S,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:9
M9F:9F6:9S&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;_
M_YD``)D`,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF
M9IEFF9EFS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,
M_YG_`)G_,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS
M9LPSF<PSS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9
M_\S,`,S,,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`
M9O\`F?\`S/\`__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F
M__^9`/^9,_^99O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___
M9O__F?__S/____B_)```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"'Y!`$`
M`-@`+``````@`"````C^``$('$BPH,&")+`I5`B`E+.'I"(^G$BQ(D52"1<"
MH*BBHT.+(#DNQ+9Q(JE1*@"04/$Q9$6,&IV12KGR#T&6+BNJT#B3Q$&!.'-"
MS$@"XJB?`%0(G;B3Y,,5*GP>)-$R)\R2,H_^#"IT9\F9`TGDZ42VTYR52V7Z
M?/A$JXHY93OE63&'*T29>!\*I$AB!:L58\GZI;NB)2FH'544=K9WHM]K?P6S
M@DS8X<P\F#.OT&I2H%\5<CU'SA-5!6:I8DDW/CR0U=N4`EV3)7V:8&J!$>F>
M#3NGM>FX;WW.Z4VB=U+>J/-(%4AB95SES8O#MCGP;6:SS.<$CCL[SYS-0-_"
MSH9=\.QOX*0],FXXLVR>J=H[/K?;^'PG%8`*7R;-7>YBBJL!1M9*N6W'71Y/
M5*570Q!U=)I\_<VV&4C,X722:08>&%US])$`"20;1G=:<:AY2`LDM)S8UT<`
M8$-"BB=^"*)*'R(!"8TI0H($C#<JQ9B+*-+2'(HWOIBCB2?:"&)S*CG4(I`R
MVC@D+3;20N.0,XZDPE$+1??AD36"*..'/HVD4)EF8CEEBBIM:.:;;[:)A(<>
M@@CGG7AV.6=&>8X4$```.P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O8F%R8F%R:6%N+FIP
M9P```````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$Q,30W(#$P-3$U-#,S-S4Q(#`R
M-#<Q-``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_
MQ``?```!!0$!`0$!`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#
M!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*"
M"0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS
M='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$
MQ<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!
M`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<`
M`0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9
M&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"
M@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2
MT]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/N7Q?\`
MM&^)_A9#X?\``_Q*_L[P]JVD3ZKHVFK8ZY9ZK;7K:2;;3K^2TN)IK66\TB;[
M/"=.U!+:UN`AA%S8V;;C7R!^T-_P5P^&'P?\$7\DUW;:CXABTO4Y]/T[1[VW
MO-8O[N&W1IHKZ?39)18K=3W":5;QZI-LMI7DTVS-PEFENWT-\8OV=OAU^U'X
M)\9Z'XECUR#63>Z_JN@:WX8ECA\0:'-I[O!!KMIK-S`[Z=!8XM#=02S7+W\)
M>*YBOHOM$@_CH_;C_9C^.O[)_P`;/`OPM\4V&G>*I_&_BG3=>^$7BZUO="FT
M[XEZ=I>M?V3I5AK%KI]W%8:=<P^(=1L['6[758])BC\]+Z:STZ"62:3\7R7)
M<%G>+>%Q%>,E"GBI5\+&5*<JV'HI2GS^TER*$=(S2DJTE)J,97;/ZZ4LEPF5
MXK-<12Q=/%8!8=4Z$O=PM7$5ZL:-.?+!^VJ*HVVM)4XKW9<K:3V?VF?VL_C7
M^TIJ7Q4\>?$+7Y7\+_#<Z)IFA^!=/<OX.T_QIXY2X6ST:YTII!I/B&]\,:-I
MFO:CK']H6.K?VAKN@VLMS#9VMU/9Q_)5C\-]6\0?#?QI\1_&-[=Z*^@WVDP:
M?%KEO"+SQ5<:Q%-]NCLFFD%S;/!%':7M[>7+W&ERZ<TL^GF>2SEME^G?VE/"
MB:K\0/BI;:%X@\)7GP_G^,7AK6O$NK>']:L=-T;7/BY+\.K>;XA>$/`@UZ>2
M_.D6$VG^-=.^%&H^(=-@\'ZG'8:UH^E:K+JFJZ/H.I^<?M8:MX4USP5\,/"?
M@OQ#:^+7^'>EOH$.MV5GXC\):GK7AG?J,^F6OQ2^'?BI3>>'_B;X9G8:4^H:
M=KOB#PSK?AZ.RDM=7O2D#-^UY/#`9;4PV78-87`8%2E55.C3A0I8?#X:E1E2
MR]/D4H/'*JX3::J4I1<YR@^6_P`KCL!BJ=&KC*V7U<3BEA7*$:=*G3C&>*KS
MDJBC'DFZT*"I<M"A%RJ1O.%*4;M?`,\\+%D9;HC:%MT(62)`PD282;XU+13"
M1T4X0NC%YS(9)BW[M_\`!.']K/4_'MCJ/P,^)&K:GK?BC0;&3Q#X#\5ZU?\`
MVQM1\*62VL&H^"?$VH7$IN)KW1M173[KPGKMY-+/+I=QJ&AW]VGV/P_`?PFN
M-,N+=T6X0Q"4@(&0[C$`/,F*PAP8HG(C=PVXG+`;<9]B^&,OQ*^'%QI_QP\'
M7-MILWA6\FN=.:2]@EN[JRDD-AK9NO#TTK'6O"3VLTVC^)Q.K:;>Z;>:A82Q
MNN^>#[3+\Z_U?QF$S"EB*5*<JT*4EB)RE2QD):2PU;62E&3]]*JU33BGS;'Y
MU1RC,LUJ8S`TLNQV+6'P>(QN)5##5YSP&#P4:3Q&+Q,:<>>G2I^UAI6LIN?+
M!3::7]<$6JVZ11H)HD"1HH0Z?;L5"J`%+2'S"5QC+_.<9;YLT5^2&G?\%0?"
M$FGV$FI?"C7TU&2RM7OTT[Q-H+Z>EZT$;72V+ZGHEWJ3V:SF06SZA=7-\T`0
MW=Q-.9)&*_8?^(@99UJ.+TO'DQ>C?)=:4K:7:TT[=#Q5PIF&FM+I_P`O<#_=
M_P"GENGX+S/ZP?V</^"@/["?[/\`X$\1>*/CK^T-X`T[59O`L=OINAZ#XAM/
M%'B;5KS4+;6'O(+31M"74$@NI9WN5C?47FU2[O)5M(M*=K>6SM?Y,?\`@JG^
MV3\&?VX?C9X'O/A1;>*DO?"6N77@WX;W>IV=AX3\/Z?I7B37K:>\F\1:WK6M
M:AJ^IH^O3QZKI5V;+P+'8?VG?:EK+S2/INFZ%^0-QXT\1W*BWM]42WCDN1<P
M7OD6,M_&ZWYN!.M\+2ZU,.LA2..*VDLI;G+Q72-"A@@XV29I)UDCE:Y:66(Q
MRM`[N\\C*JR2&6Y6Y9Y&D8R.UXBRRR>9([3@/-_+O#G!>59!A5RU)8W,H2Q<
MX8^<(T5S8U6G[3E4)246HZ23@DKQC=GZ%F>=0Q>:5L0J6(>&K5L).KA*DU[%
M0PLE*G2H0<M(OWKN3BY3<92<K)K^K[X&_P#!.'_@GYIGP=\+_$K]HC]NW2_&
MW]JV"ZA/\+O@9H6@0V5GI/AV2RUO5M&^)5WJ>MZG\78=)N[+2IYKS6/#%CX"
M%KI8L?$7AKQU<:A.SV'P3\:O`7[&OPP^-7Q!\)_!V3XQ_';PWX&UHV>M_$G7
M]7^%?B#X9V4$NC:;K5G:^"O&VDZ!%_:MYI@GO5N/%'BW7]'T*QMM&N]2>/QU
MJ4L+W/Z!?\$T/A-^SE/X3^$G[9_CK]K+3O"7[1'C']G+]H,S_#SXBR:/I_BG
M6/B/8^$_B5\'Y/BUJ'QI\2:H/&&I?#Y6U70)M&T#7M,O+#7/BM'I_AOPM=:K
MX.\#ZX^BZ_[$WQ0_X)^:OK7AOX+6?[!G[*FM?%7PW^S_`*GJL?CC7[?Q5KNM
M>#?B#X*N_#EII?B[Q[X:\27FA>$OBUXRU^36#XQO=)\*27.MOIFD2Z+I_BW4
M3<"STC\;>-QF'QN8X>6'S7%SI2GB<?FTH.O@L/6YJE3%X['PR^36%I14*%'"
MTU2A!J7)*E*I;E_?L-F&.Q5.AG<L=G.<8"5&AEN"RJ&-H9-6P6'CA'6P&"R_
M`XW!X/!U:-*45A<5F%*,JT7S26,K3KRJR_F:^-?P@\4^!A%J>K^%/&/@_3?$
M&FZ1XQ\/Z/XW\.7/AWQ)/\//%>FV^K_#_P`820"QL4N;3Q1I<5Q>6FL:8D&E
M:O(%U;3[:V@OXK6.'2=6:T^',$D4-L-+@^'U[I=W*)$>ZAU>;Q/JHTNQTEMW
MGI)+<7]ZFKV4L4BK8/93S2,&MT7[%_:]\4?$'5/VE?B-HOQ=T"Z\-:I?Z-I=
M];:)_:P\1:)%8^,=/MO'6A>(/!>IQ1Z5:7G@OXBVNO6/B;2M3T_PYX4^W+J+
MS^)O"6D^-I?%5_K'YN^)K"_T!]3\,P7DUQHMU<V>K11LFU9'@!D1)8BH`FMQ
M</%)L6>:,IY8+N-J_L&'P\\QP^!RW%8G#U7AXX7-J6)I<TJ%;#UU42IP4E&3
ME1E3<6ZD(UI/62;L?GV.Q<<ACC^+<KPM>%+-\#F.19AA(Q;KX3,,)4P]:BL7
M'$RJ57EV9U*,J56G!U%3E&'.H0YFN6CCO%CC6,VK1JB!&*Z82R!0%;,T*S<K
M@_O5$G]\!LBB@2R``>=J!P`,K).%..,J&D5@OH&56QU`.117VS]@WMHW_,WI
M[O6WF_Z1^,J,TDDY6225JSMIRI?\O-MOO9JRWXGVBW6ZS!'<PDM%$`J&(Q<)
M`\KQ1%5)O9!(\D+3&$*[8=F-;2CRHR+A9F7[2UJ05BVKNCP3<2'"1H9&</'$
M&4[25&TCW/P3\$?BK\2+Z+3_`(??#'Q'XG>XN+:R2:PT=);7S=2>.'3[=[V\
M:!(YK^>:.V2);JW*.DDXB<G<_P"RGP*_X(=_'N\\/V.O?%O2KOX8^)?$$)OO
M#RZWH>C:C+8Q.YCDD33H_&6CR:?XBMM2Q9KK'B)Y+&VN)%"^&[]/(O%^?S3B
M7(\FI5YXS,,+"5"4H5J?M'4J0E%J$U*G152JI0D[2@H-IN]KNQ]92X;S+%8J
MG3Q-J%.IS0]I7PU?#<[Y823IPJ4J<ZM.<)J4*].,J%3F7+4:&_\`!%?XJ:-J
MUA^T=^QMJ4'POM?B%\<OASJ=C\%9?C3X'UOXD?#'Q)<WC:-J7Q=^#?C;PGH%
M]8ZQK^D:CX8\#>&/B7X(TG1M3TF6V\2^`KV:SEUB[N8?#FJ_2O[5_P"S+^R7
M\%/"6IIX`^*7[,O[+7C[55TC6?B'\.O"_P`>-*_:#^/'@#QG>VKW#^&?A3XK
ML?%N@&Q\,QW]EI]UK&KZO\#='\9V>J6,;)XU\.6]U-:O]<?LZ_\`!(#X0?LQ
M7OAKQUK7B74-?^)5AK.G^++75UO;.YU'PEXMTB6ZN_#.N^']4BATK3;JY\':
MK=VGB;3M(L_#:64^NZ?I:>(+S6=(M9;2Y^ZM)^*?B"[3QG:>%/\`@ES^S7\:
M?B?H_B"Z/Q>^*37?[,-Q>:]XKLM(L]4TGQO?6WQ6N[GXDZ#IVJ>%+C3M4TG2
M]&TC68])G6XL?#D6KP1F%/P+,>(<GS7B/,O[)Q6+PN`Q.*I9JG5IX>E4CF;I
M0IU,52A+!5:3H594J/LJ4I4W32GR48NM54OT/+%5X>PE#$XBE0Q4H0>$Q,*>
M*P^%2P+JPE3@G.G[:%2FN:"K8'V57EE"G6=1QC*7\JG[?VC:2_Q=^&D>C>?;
MJ?V7OV?);*ZU&YCNU?2KO6/'E_H&J:MJ>EVMI!(+KP99Z5?Q:BD.GZ;JZ7$,
MEE;:;:3Z;IT7YR?$OP]#?2I=Z(96LHIYWMY+V,F1[9)&N7$^;G9"[*\#FV+S
M3!A/#!<W2VL\L?WY^V3H_P"V)^T3^UAJWB3Q-^S=XR\-^-?V@!:Z]\/O#FCV
MIUC2_%'PR\!M-X/TA=!\2:?L\,7O@_PS>Z;?GQ1J"ZM8:"FO&U_M6VTRVL;#
M3Q^L/[*__!#R\\5I9:E\?]1N/&VMF%GN?!'@N6^T?X;>'&:Y?='K_C6S&G^(
M/B#>V9E74KU]`N/#'AA+X3P1/K\959?NJN<Y?P=A,HHU<5+'8VEA:4:6&P4G
MB<4W)RG*,XP52G3BY3DE'$RA&#O&'*HZ>G*KA<YR_-UF4)8+"5:CJ1J0]I0I
M6G4<H\WM?8U*M6FFDY)2J34KRE)/F/Y.39ZID[M*NW;)RZ-+L8YY9<,1M8\K
M@D8(P2**_OZA_P""+7[+UI#%:M\`='=K:-+=G_X5U)=[VA41EOM<^O\`GW6X
MJ3]HF_>S9\R3YV-%+_B+%'_HFLS6VCKX:_V='[WGKZOLK_$?V!DO3/ZOE_PF
MI]K:^TUVCZZ=SV#_`()S_#_P'!X`_;H\3P>"?",/B31/V@_C?:Z-XAB\-Z-'
MKFD6T7_".W$5OIFK)9"_L((I[^^GCAM;B*-)KV[D50]S,S_2_BT"?XP>"A,/
M.%Q%J5Q<"7]X)YY/C7XYB>>8/D2S/%;6\3R/N=H[>%"Q6*,*45^2>(7_`"/N
M+_\`LI\\_P#5C$]S"_Q\I_[%61?^JC#G>_&JSLSX"N+LVML;NWT.]D@N3!%]
MH@DDOK>&1X9MGF1N\*K$[(RLT2K&Q*`"OQP_8JU/4I?^"J>@Z?)J%])8:K\#
M)[G5+%[NX>TU*XL_VBOAI;VD]_;-(8;R:U@U[7(+>6X21X(=:U:*)E34;Q9B
MBO.7^]P_[!Z?_IR)[>0_\B7B#_KW6_\`3L3F?V`O^*F^)GB*[\1_\5!=Q>+/
MB7H,=SK?_$UN(]#T#6]7?0M&2:_^T2)I6BO>7;Z3IRL+/3FNKEK.&$SREOZC
M/@Y8V4?A&S$=G:H)[NX\X);PJ)MYO4?S0J`2;DCC5M^=RQHIR%4`HKULA_Y*
M+-?^OTOR9\WQ]_NF$_Z]T?\`TVCP#5-=UN+4]1CCUC58XX[^[2.--0NT1$2X
MD5415F"JJJ`JJH`4````4445URW?J_S/"CM'TC^5,__9````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+VUO;FME
M>2YJ<&<`````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R,#,Q-R`Q,#4Q-30S
M,S<U,2`P,C0R-S0`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````_]C_X``02D9)1@`!`@$`R`#(``#_P``1"`"^`)8#`1$``A$!
M`Q$!_]L`A``&!`4&!00&!@4&!P<&"`H1"PH)"0H5#Q`,$1D6&AH8%A@7&Q\H
M(1L=)1X7&"(O(R4I*BPM+!LA,30P*S0H*RPK`0<'!PH)"A0+"Q0K'!@<'"LK
M*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK
M*RO_Q`&B```!!0$!`0$!`0```````````0(#!`4&!P@)"@L0``(!`P,"!`,%
M!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B<H()
M"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T
M=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%
MQL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^@$``P$!`0$!`0$!
M`0````````$"`P0%!@<("0H+$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&
M$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W
M.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2
MDY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KB
MX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/JF@`H`*`"@`H`*`"@`
MH`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`
M"@`H`*`"@`H`*`"@`H`*`"@`)`&2<"@"A?ZO96,'FS3`IG'R?,:I1;.FC@ZM
M67+%%,>*-,(!\U_^^#3]G(Z/[+Q'8/\`A*-,_P">K_\`?!HY&']EXCL'_"4:
M9_SU?_O@T<C#^R\1V#_A*-,_YZO_`-\&CD8?V7B.Q-9:_I]W+Y<4I#?[2XJ9
M)QW,ZN7UZ2YI(THIHY21'(KD=<'.*5CDE"4=T/H)"@`H`*`"@`H`*`"@`H`:
M[JB%G(50,DGM0-)MV1S&H^,;6(,E@AN95."!TK54WU/8H9-4EK5?*CGY]:U.
M=I2TVV*7^#^Z/2KY8GJ0P6'@E9:HH*"HQN)'N:9TMW%H`*`"@`H`3GL2#[4`
M2VMS=63E[*8J['+9/6AI/<BI3IU5:HM#?MO&3B6)+BV(C'$CC^=0Z1YE3)59
MN$M>B.ETK5K35(F>SE#;3@CN*S<6MSR,1A*N'=JB+]2<P4`%`!0`4`%``2`,
MGI0!PGBS6FOY38V,A6W4_O9!_%["MH1MJSZ3+<$J*]M56O1&#&B1`")0OOW-
M:'IRDY?$QU(0E`!0`4`%`!0`4`+0`$Y&#R/2@06KR65ZEW8MY;K]Y!T:AZJS
M"HHU:;IU=4=UX;\01ZNKI(GDW"?\LV/)'J*QG#E/G,?E\L-9IWB^INU!YH4`
M%`!0`$X!)Z"@#A?$7B)[V22RTYBL*G$LO<^PK:,+:L^DP.6JDE5J[]$8*@*N
MU>E6>DW=W84`%``>.M#:6X`/F.%!)^E"=]M0VW)4M[AQE(&(JE&3Z$.I!;L<
M;6Z'_+`TW3FG87M:?\Q&T<J_>B85'O?RE*47LQF1TYS2NMBK"TP$H`6@`1I(
MYDF@<I,G(84":C*+C)73.^\,:P=6M&,BA)HSM8>OO6,X\K/FLPP?U:>FJ9LU
M!YX4`%`&-XKU#[!I,IC<+/(-J#UJX1NSORW#^VK*ZT6YY[;ILA&1B1N7]S6[
M/J9N\O(E12S;1UHC%RERK<ANRN+)&R'YAD>M5.$H.S$I)BP1F0GL/4]*TP\%
M+FYD*<E$Y#QI\1O#O@YC!=7"W.H8SY49SCZU+<*#5];G%7QL8.TF>8ZI^T1=
M2PO'INDHC9X<^E$\5&,OW:/,ECFT^5'+WGQ+^(.KN+JS>:"#^%8UX-<-?-(7
M4922:'3CC*T;QC<A'CCXDLRD7-UE>?NUA_:=):\Y?U?'?RFE:?'/Q78.4U"W
M21UX.]<5ZBS'GC>*1E+&U8Z.)Z!X8^.^C:M+!;ZO;?8Y7PI<?=S3]O!I*VK.
MNACX-I-V/68TBEC22VN(Y$D&Y<-DD4_8-NU-W/35:^C0P@AMI4Y]*Q=T[-&J
M::N2>6H(5ID#G^$MS6KHR32>[,_:J^PQT9&PPX['UK.47&7*S1--:!#<SV-Y
M!=6TA7:V)1V*TFDU9A*E"M3=.:]#U&UGCN;>.:)@R.,@BN=JQ\;4IRIR<9;H
MEI$`2`"3T%`'GGBR\_M#4UB&UK>(_*R^M;P5D?4Y;1]C2YNK,LDD^_:J.Q'E
M?QX^(,GA>Q@T/0YMNM7'S3N!DQ+VQ[FM:CC1C9/WNYY&-QCB^6.[V.1\&?$/
MQ?X7N++_`(3&WFET&X(#S2+R@/?-<E#-(RJ\O-=F$/K.'M.JG;\B/XH_%>^\
M1:I_87@=Y$T]\+YL8P\I_H*WQ>-4(N[LNXJV)G6DJ='5LA\.?"B.0-<>*;F6
MXN)1G;&Q)3ZFODZ^;S<E[):>9[>%X?AR-UW>1VND>#=&TA`MM8128_YZ`'->
M;4Q-6I/G<SV</@,/1I^SC$UD2*)`B6T<:#HH7`%8OWG=G="E&"Y8[#AY?41)
M^5*R[%\K[E2]TW3;^"6&YL;=O-&&<(-U:1J3C;E=K'//!TI-MJ]SEK;X7^%X
M)69EN')!PK-P#7;/-,1)6O8\F/#^'B[V.2U;PSXQ\,7#W^C:G<7$$!R@20DA
M?3%>MA,ZA&2C\+[]#R<3DV*I+GI2YO+J=MX4^.XN-!NK;6;4+K\,9%M(!\LK
M>A'8U]`\?%1O-:'#1QDF^22U[=V>9WEO\0=8O+C5G%\LCDN=KE0!["O,EFM)
M/G<Q_4<PJ3YE%IGJGP(^(]_KU\?"_B9PTT:$P3L,-D?PM7HTL3&<>6>M]F/#
M8JHJCA->\CV,@AF5QGL1ZT.+B[/<]J]]4;W@&[%O/-IS,S$_.O/"CTK.HKZG
MF9S1YXJNO0[BL3YT@OY8X;.9YF"H%.2::6IK1A*<TH[W/+B`LLFW[I/%=!]C
M>Z5QR,%8$]`:NG-0E=B:NCYQ^/\`ID^E?$Z'6[NW\_3[]5\ANP8#&/PZUS9E
MAY.+Y7:YX%O88E3DK_YF-X_\0:M;Z##H=Y=0WIN@&78.4'8?6OF\OP]*=3VL
M4THGK9MC*L(>PDDY2['4?#7P[9^$?#<NLZ\J0WKC>"_5$]/K7-CL6\354:>J
M6WF=V69:L%3]I4M>UV^WD)%XC\3^.KJ:U\#6/V33XQ^^O9N!^?:NBG@L/2?^
MTS]Y]#AKYO7K3Y<,M+[LCM_"7BZYC=M%\66E_=0-^\A1^5-8NKA(3Y:U)Q7<
MT^LX]MJ-9-#I_%?C+P\ZQ^(M`:[C48::$<-3AA<-B9?N:EO(F.;XC#PM7I_-
M%F+XFV+V[23Z7=0RKUBVU-3+:M.?(VCKI9_2G3YDF41\4[B]C=-)\-W3W'9M
MN0*V>4Q6]1',N(DG>4&T6K;XC2V85/%6AW-BQZ2[#@UC++[K]S-29U4<Z]Z]
M6+A%]3N;&[@O;&*\LI5GM)1D8.:\^46FXR1[L)QJ*\7Z,\N^,'@T/$WB'2(E
MC\O!GC0?^/5Z^68UJ7L:FJ>Q\SGN71Y?K%/XEOY^95T7QAK6N1Z;-'<K:V^F
M@?:\G`E4?_6J,1A:.'G)37-S;>1EA,QQ&)4%%VY?B?<;X,E?Q9\:XKS08#%$
M'WG:,`*.I/UKZ'*(/#QC&:O^AY>(Q4:N.=6FKK^M3ZDN6#3L1VXKTJVM1GMT
MTU'4;`[17UO(CF,!AN8>E9/8<XJ5.46KZ'J-O*DT*/&X=2.".]<S/CIQ<9--
M6,KQ@H;P_<@]./YU</B.W*W;$Q.!/6MCZ8.X'KQ0!S/B+7O#,^H7WA;Q'"ES
M<6D!N(@RY\LXXQZ5TJ.G))W/)Q3IU9)Q^+<^:?`]D=?^(1G<%X()2X'7@'BO
MG<WQ"ITFHJUR,GP\L5BN>;^$]/\`BIH]]XE.E6-EGR#,/."]EKPL%B*>&YIR
M[:'T>98.K7A&$7[M]35^+]\/!/PLL]*T-1:K/B,F,8)XYYKFRJF\3CG5GK;4
M\/'N%&G)1TZ(\W_9O\[_`(3*:16?;Y1#G/!^M>MQ%K15^YR9/%.4O0^CGF8E
MT<*Z9Z,,U\BM'>.C/IG2BT5!IVF3S[Y;"!G[G:*MUJK>LM69NA&*T1XUX\^)
M]SHGC!+#P]:6UO;P.!(0@R_M7TF"R5N@Y5V[M'E8K,O83]C"S[L]GO;.QU[3
M88M8M(YH[N`,P(^Z2.U?-TZD\/4O3>J9WRI*M1<7MV/%OA]#/X>^(6L^&=[/
M8)N>(,?NCM7TN,4:V'AB6K2>YEE%:I1JRPKUBM4>@75N+RRN;0C*RJ5(/<5Y
M:DUK'<^HJPA.-I[-'SOX=\.G5_'#>'!?"S@EG*,[-A0`:^UH.,H1G45W8_-9
MTN6O.E!VC<^M/"7@S2/`%@=.TB-9;MP#+>]2_P"->G&<:<?=W/7P>&ARJ:5E
M^)KC@5DE8]$;-_JF!Z&FAQ^(]$\*J%T:$+TQ7//<^6S%WKL;XN_Y`%S^'\Z<
M/B'EG^\Q.`/6MCZ<?#_K!['-;8=)U+,F>QXA<Q+;R?$OQ1,AN+L?N(7D'"`\
M<4ZO[J4IQ/#45^\K=5HCD?@);*+J\O=Q,I4C':OD,XJMR4#T>':2DY29WWC3
M7[GPOHPU2RB6617P5;IBO+PU%5JBI-VN?1YE7='#RFE>QM7UA8_$KX>V4EZV
MUIUWHR?\LGKGPN)GE6*FE&_1W/!E2AC:7JAWPW\#0^"-/NE60323_?G;C`]J
MG,<QEC)*VRZ&N%P5'#I*&KZFY'J^C/#<2QZM;NMMGS<..,5Q.C532<=]CH6*
MB[VZ')Z)\6?"VK:K+IN9+7?E$N)#A6]Q7H5<GQ5."J6O^AQ4L?3K3<%+;\3R
M;6?`6J1_$J**U#:E9S3B5;I1N3;G)R?:OH(9G"K@VY.TDK'E1RZ7UM12T;N?
M2S210(CS2+';P1C>YZ*`*^+C"=1\L%>1](VH09XKX5G&M_%;6M<L<OI2`Q+-
MCAC[5]/B%[+"0HS5I=CBRUSQ.+G57PI61Z#`"96QW!Q7EGU-3X3YTMK9[CQS
MJ:(K%Q(YRIY7GK7WF73C&,7)]#\XFO\`:I^K/I?X0:F=5\%RAY7F>U?87?K7
MH24O9-S7H>IA9NZ39UXZ"N<]`;-_JS30X;GHOAC_`)`\/TKGEN?*YA_'8SQ=
M_P`@"Y_#^=.'Q%99_O,3@#UK8^G!20P(..>::;3NA-:'(>(='N)=+\6PF")=
M%N(=\8`Y+XY-=$%[2]SS:M-PYK]4>'_`>[*:K?6+E1'M)!/7-?(9S3BK3ZFO
M#LY*4HI:'JVJ:?;ZMI\]A>INBE!&/2O#A*49*4=T?7UJ<:D'&6S6IEQ^(=%^
M%OA1;-YFNKHL3#;YRWX^@KJKT:N:UE-*R2U9\K.E0RQ.#DVGKYGF=_XX\:>/
M;QK/24EBA<X\N`8`'N:]..`P>"CSU-SS(8W%8BIR4=+_`)>IM^#_`(+:JUV9
M/$=TUK9-RZ1N<R?6N7&YY2MRT5=]^QT87*W%MU)7\EU.GU#X#Z/>QR?V5?20
MS@?NPQR":XZ/$%:#_>JZ-:F5X=.[31Y_::SXS^$>M_9[Q&EM-V"DHW1R#V/:
MO4E0P>:T[P=FNQY_M*^$?++6+9[5I/B'0?'GAJ;RKD1"5<3VV<,#W%>#.AB,
MNQ*G%:]&>Y"<,9'DINZ*6E:;9:/9FRTF#R;0'..['U-;UJU2M/VE5^\SZ#"X
M6&'IJ$%:PS7+U=-T*]O6<)Y,9()[FHITW4FH+=L,76]C2E/LCR+X1V,NK:OK
M6J3;A$D3,S8ZD]J^\PM"*BE+9'YU2E*=1U7LSZ`^%6GMIO@G,D8B:ZE+`=R/
M>NZK.]+E>Y[.$@T_Q.JZ<5S'>,F_U9IH<-ST7PQ_R!X?I7/+<^5S#^.QGB\,
M=`N=B,YXX`]Z</B*RRWUF-V<`>M;'TPE`R2%5F,EK,-T$Z%"O:M:+?/R]+&-
M:*<+]4?)^IVI\!?%IHI%,5HTW/IM)KR,UPWM:<HVVV/&R_$SPV,36B;L>I^.
M_$L/AG1?[07$CW(Q;KZG'6OE<-AY8B?*M.Y]IC,=3PU%SGTV\V>6?#WP9J7Q
M'\02:GJ[NFFHVZ:9OXO]E:]G&8REEU%4Z>Y\A3PU7'2>(KO1[>?IY'7?%*RU
MGP5+;7O@^`VNE1`!I(ER<_[7M7%EM2ABTXU]9/HSMS"E4ITHRPZM;>QZ!\-O
M&*^.?#DEVZF.\L@!<IV)QU'UKR<QP"PE=4XO26QME^-C5A>VNQY1\2/BEJ6I
MZK%I_AE)[5;=]I9!\TC`^GI7O83(5AKRQ6M_N.'&9A-U?8X>[U^\]BM[$>+/
M`4%CXMM@+F>,9)'S(>QS7SKK/"8ISH/1,]2KAE6C:2Z:H^<?%.@:S\-/$ZM&
M[F'.Z&8?=D7T-?84*E+,J%[>OD>!+VN6UU.D]/ZT/:?!6O)XJT".^C`6=/EE
MC'4&OG<1AY4*CA(^VP&.AB:2G'KOY,\V^-'BZ"\":)I[%EB;,[@\$^E>KE.$
ME?VTUZ'SN?YA?_9X/U_R/6O@+X4?0?!9N=4B4MJ`#JF/X3TK["E%4:?/+[C@
MP&&O&[ZGHR*J(L:#;$OW5]*QJ5'4ES/Y'LQBHJR%J"ALW^K--#AN>B^&/^0/
M#]*YY[GRN8?QV:<REX75<9*D#-2<D7:29Y?>6\MI>RPW./-)SQ72G=:'V-*I
M&I34H;$/?`Y/I0622(T`1Y6"..50GDU;HSY>==.AFJL)/E1XY^TEX3_M+1(_
M$%HK&>WXE4#^&MZR]M24UT/(S"@W'F['@\FI:EXNU'2=.N9"R1[88E'0#UKP
M(8>&&C.I'=ZLXJF*JXIPIS>BT/K?1]/CT;0K+2X$6-88P&"C&37P-:JZU5S;
MOJ?848Z)OHK%F1$F@>"X198'&&1AD$5$9.+YH[FMM;K<I:/I&FZ'!)!HMJEK
M#*=SJ@^\:NK5G6=ZCNS*E0C36BMJ$&BZ1!=/<PZ?;BY?EI-@R36L\=BJE-4I
MS;BM@5)*I[6WO=R\Q+=>W2N8U6AD>,/#EMXN\.W&EW0'G8W0RXY0UV8#'U<%
M4YJ;]U[HY,5A85HVGLSYK\.^(]1^'&L:M8F`22,#$0QP`>S5]=7P]/'TXU(N
MQ\_A\5/+JDJ;5_ZW.H^!_P`/G\8:W-KVO0G^QH7+MN_Y;29SCZ5[>%H))7V2
M,,-"5>LZDE>[/IH%`BQPC;"@PB#HHK2=3GEN?1QARH*10E(!LW^J/<]AZTT.
M.YZ+X7W?V/!O0H<=#7//<^5S"WMW9W-6I.(X3QI8O;ZC'=1[I#,<;?[M;TW?
M0^DRJNITG3>ECROQOX_DTB^&A^$K%M7\1/P4496+W-=5.2IQ;M=AB<1*W+#5
MG&F\O?`.L+XG^(>NK?:Q.A":1`^[R\^HZ#%11FX-U*FES@C:D_;5):OHBM?_
M`+1,-Y9W5K)H"/!.I4JQSP:R^LR5^4F>.C=<J.1^`FDPZMXUNKUH-MO`"\>1
MPASP*^=SG'SP]#DCO+<WRB,75E-QOV/HMV+.2>O2OB4K(^I2LA*8!0`4`%``
MK%'5AU!H8-75CP7]I/0HK76+'5H4PMRNV3`XR*^LX>KRE3E!]#YO.:<FHU7L
MM#K].^-_AG0_#VD:5I]@YBAA`F"+@;L<_6OKJ5:$H>^8T\71IZKM]QL:#\;_
M``IJDICU(26`SPQ'%:SJ4)6C%&]/,(-V3^\])@>*YLXKRPF2YLY1E'C.>*SJ
M4O9ZQU1Z%.M&IL%9FQ-8P376J6T5M'O96R_H!0VDB*TX4Z,I3=CU%!A%&`,#
MM7,?&O5BT"*&MV;7NG30HP20CY6(Z546TU8Z,+65*JI/8^/OB%\1M'\*W5_9
M^"HB=<E+17=^Z\J>^T^M=U>MR)0@SOQ6)C"\:>[_``.*\%^`]0\52R:OXAFF
M6%SN#2DEY3^/:OE\?FKB^2D[OJ^QW9;D<JC57$Z1?3JSI/&WA#0?#OABYN;"
M$_:2F-S\UP4<97KUH0D]+GJ8C*\+0H5*C5M-#;_9P0#PQ>,(SN:8Y?%8\0O]
MXO0XLGIQ6&Y^K9ZN2!7SQ[%B189&!9ML2#G=(<"B^MD9RJ1CYG/:MXT\,Z0&
M^U:M`9%.'13DBNNC@<15=E%F53$0IMJI)(L:9XH\-ZJ(_P"SM8@D9^@+8(/I
M6=3"5Z;M*#'0K^V3E"S2-B2-XB-X^4]&'0USIHVC*,M@10Z2IGYF0A?KCBGU
M3)JWY=#P'7[W4M1T#Q!X=\1.C:C8RF:WW=2GM7UE&E'VU/$4%HU9G@UIRI4:
ME'$.[>J*WPO\&:'KWA62\U%':Y$I7(/05KF&-JT:W+':QOE&64<30YI*[N;V
MI?"C1;M66PD:W8CY68]#7'#-,0I)O5'J5,@POLVK6?<YK0-?\1_!_P`1BTO2
M]QI,Q^:/.4=?5?0U]/EN9PJ*ZVZH^8G2JY?5Y:FL6?2NC:U8:YH]OJVDN)+>
MY'R)W#>E>E4HV7/3UB>UAZBJQT>G<]#\&:3-IMB[W6//F.XCNH]*XZDDWH>)
MFN+A7J)0V1T59GE!0`'I0!X)\9/@[X?EOV\8VZ"V>W;S;R!1\DWOCL:XL>YQ
MHOD/5R2G3GBXPFKW>ASMW?6=MI*ZA<2I#8!-R`'`^E?)P@Y-0BM3]!JU8T%)
MR>V[.'\?:M9>(?`MQ<6#AE3L*Z\*I4L5&,U9GG8Y1Q.!G.F[JQPOP\^)]_X.
MTJ73X[=)K61]_/4&O9QV4T\55523Z'QF#Q_L%9JZN>D3_'/3(=+22*Q,MZPY
M4]%->)#(*LJK4G:)ZE;-J7+>%[]CSC5_$GC3Q\1$C7#69D^6.$%57ZFO;I8;
M!X+:USS92Q6)CS):7.STSX%,;>.74[\F9URRKV-<4>(Z=.MK"\$=E/*%*-ZD
MM2AXK^"]WIUJ;K0[EIG49,>>?PIT\_I5:CYHVBWH7+)[0<J4K,/AO\2=5\/:
MG'H7BYI7T\G:&F'S1'Z]Q2QV4T:\'5P^YGA\;4H3Y,1OT9[/;^*?#LUP%@U*
M(D$$98<U\U/"5X*\HGM4\2JONIJYY9\?=$CM;@^)HY2C7:")-IX>OI>&L14E
M"=%.R1Y.9X>E"'M;^]L3?!2*1/!,FY<;I25]Q6.:R3KZ=CU^'DUATWW.HMM<
MTB[OGL8+M&NU."F>]<4Z%2$5.2T9Z]'&TZM1TX.[1F_$O28]8\(7,=P0KVH\
MR-L<Y%:X.LZ59274YLRPD,10E'YHZ#]D7PWJ$OA^ZO=521=.\W-JC@C)[D>U
M?;PQ$XTW!;,^%HXV5*E*E'=L^FATK`X0H`*`"@"&\M8+RV>WNHEEA<89&&0P
M]ZF45)69<)RA)2B[-'RG\9/@;X@?Q"C^%YI;CP[<ON>VW\VA[X'<>E<4Z=/"
MPYH0NSU(8FMF-50Q%3EC_7XE.R\&:1I?AW4-*L))9KB6,K()>H;'85\Y/&3G
M656:]Y=#[*EEWL\*\/'2,NIYG\*IM"M?$=UH?BVT$EO<,8DE(YB?.*][&X>M
M7I>VH3Y6E>W<^0P,E1KRP\HIN]CV_3_AEX0TJ5FCLOM6_D-)SQ7RKS?&2CRM
MGMPP5+F<E!)G465M9:?&(],LHK5!V"UPRG.;O)W.F%%1CRMZ$I)))+$DU-C7
M05'=#E3^=%A.*>YA>*O".@^++-K?5;402]5NHA\RFNK"XZMA9<T'?R.7$X;V
ML'%J_P"AYA+\`[G[26L]<46H.?,<8(%>W_K$GI[.YXW]D\MK3=SF/BEK[:BV
MF>#=-N?MEOIQ$?V@G/F/TKNP%#V2EBZBM=;$XVK&JXX2@KN^K?5GK'A739-$
M\/V=G,5>01\E?I7AU)^TG*?1L^TPV'C3HQI+HM?4\G^(/@6\\-N_B+2KO]P9
M=Y7=AXR3^HKW,%C8UU["NM;?>?+9EET\+4>(PK>FK\O^`?0'P2\/S^./#=CK
MOB>W:.W7Y8X","XQ_&?:HI9/:LW-^ZMBZW$M\-[.BO?:]Y]O0][M;>&UMT@M
MHDBA085$&`!]*]U*RL?*$M,`H`*`"@`H`*`.+\3>`M/U2XEO[5?(U`J=I7A2
MWO7EXO*Z=9N<=)'T&7Y_7P\51GK`^7/C1\&?$.BSV^NZ=$;QYY,2I:H2T;]C
MBM<#1JTZ7LZVIAF^-H8C$JMAER_Y]S<\)?$F/2[=-"^(=K<:3JMN@V2RQD!U
M[9KP,?D56,W.CJGTZG9A,VC4:YW9]>S/1=)OK36+'[;I=Q'/:_W\XKP*D94Y
M<DU9GMJHM//L6HD,QQ&T?_`FQ4MI=2IR4%>0YX'3.YHN/1P:+K<F-6,MALJ1
MV\)FO+BW@@`R7>0<"B,N?X=2766O*KV/%?B5\7;5(+S2/#I,H;*-<@\'UQ7T
MN!R.5XU*KMY'CXO-X*+5+67<XOX1^&XK[5O[7UDR):P'?&=I_>-7H9KCHTH^
MQCNS7(\GKUFL7):7T\_,]\TNRU#7;E%TNSD>WD.P7&/E2O"I4:E5\M-:=SZS
M$5Z&$@W6DDUTZL[G3?A+:WL$/_"4N+IHGSY2'Y''N*]W"95[-\U1ZGRN8<2\
MZE3P\;1DNIZA;6\5K!'!;QI%#&H5$08"@=`!7M-W/D4DM$2T#"@`H`*`"@`H
M`*`"@`H`Y[Q-X*\.>*)X9M?TBUO9H>$>1>0/3/I3C)Q=T*45)69S^K_"S1[S
M4K"YL6?3H+;@VUO\J/\`45Q8O`T<5?G6O<]#+\QK8)ODU5NI3\;?"/3_`!)I
MOV6#4+NP;.?,A/-<F!R3"X6?/:_J;8C.<35I.GW,GP_\#;/2H4CDUS4+G:.2
M[=:Z*^68:K4YN6R[$4,UQ%*E[.]_,Q]4_9PT_4[^26Z\0ZF;=SDP;OEKO]EA
MXV=.FD<53%8FH[.>C%L?V9/"5N^Z:>ZFQT!-95H2FK1=BL-5C2J*<H\UNC/5
M/#G@C0]"T6/3+>RBD@7J9%R36%+`TH1::NWNV=N*SC%5ZOM.;EMLELC?LK.W
ML8%@LX4AA'14&!73"G&FN6*LCSZM:I6ESU'=D]69A0`4`%`!0`4`%`!0`4`%
M`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`
M4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`
M!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`?_]D`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V5V:6PN:G!G````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-S(P-"`Q,#4Q-30S,S<U,2`P,C,W
M,S$`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M_]C_X``02D9)1@`!`0```0`!``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_
MVP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`
M'P```04!`0$!`0$```````````$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%
M!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*
M%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U
M=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&
MQ\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!
M`0$!`0````````$"`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"
M`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF
M)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$
MA8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4
MU=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#^QOQK\3;/
M1M3UA;2)KV^-W*4MK8*I,:2-%''///)&\0+H6S"CMDX(``KY%\=/\0?BQJ<5
MA?SM;>'X+ED.@Z0^P72!\(^JW$3^;+"Y12"ZYAW.8RS,6KS3XB_%#Q5K6JZI
M9^'/#MCI]AYTACUO5KN:YOK_`'R&22YC*"WEL^3*%1F=BH7H*]]_9X\0V]U:
MZ;875O&=9A6!-0D>1Y);[83YLLDC,74K\^R,G#$@D$9S_&_$/B)AN),\Q.2U
MJV(KY;5Q57#NE@ZDZ6&KQ5:=*F\54NZM:BIVJRP=**IXM12JRJ\\H/\`7L)D
M&)RG`4,P5&-*LXP]^:4J])S@GS024HTZCA+V:G43<;^ZURJWRG\=_B+\0?V<
M/#4/B#P1X>37=4\M=/O':TNKFP\,:;"?.6+2;>V"W+L&93<,LD:SO)))]]WK
M\YK?_@K=^T5I'B:RMI[SPEJNB76HK#>:!<Z=>_;/*!!DA:XD=;J*<H\"IA72
M-OD:-Y`J/_05^T%\/I_%'AW4(M(M[9M2NM-NTMXGCD"O/)$/LL8EBB),Q?RE
M$>?D!8]UQ_'C\=?A5\.OAWK7Q*T?Q?H/C[0?B(GB*YF\/>+=)U:.?28+_=]H
MU+1?$>E7=U'=VL897-O=*B(--F8LR,8I*\#-<#CN'L7:..S:K1E-<^(H4E4<
M\16<6\34HJO[\'RQA]4H0J5%2H03PLJ:ER>[ECP.:8=*6%P;JITZ;G6Q'L'"
M%E)3<^913IM*"E-<MYN4WRIG]//@OXQ^&?VIO@G-XCTV2"RU._T@6>MV*1NZ
MV=U,B[K24*L+1S6LL1'EE`6/R[QC)^./%?QX\2>`?`L_PIMIYX=5AUQK>WU.
MVD/G?V)"PF@1)/._=.)E0M(2WRK\R$'%?E!^P'^TCXB^$NL^(O"M_:ZCJ-IX
MML`8G#3W&DP2VS2VEO?W?D"4V_VA0DZW'W/,<AWD<&,_H7XF^(/P-\0>&9Y+
M_P`3Z+_PG\RS7BF^U$6J6L4:AHDE^9"_FDE45!N9]HP02*^2S?-,9A<;4HX3
M&SPN:O*\5A:^/C6@J6/P=>FG&$G%QJ5Z\KNE2]G!\U2C"M4^&I&'KY?EM&%!
M+$X9UL%]>IRH0F[3HS4*<E.I)<KE15.JFU?EJ*<7;16YJX^-?B&>>>:;6BTT
MLTLLK,EX6,LCL\A8J^TL6))(&"<D<45\X2^/M%265!=K($D=1)%J*^4X5B`\
M>4SY;8W)GG:117SB7$#2?M\W=[.[JUTW?E=[*HEK>^B2UVUU]%RHQDXK!X2R
M=E_LN%>B:2U]F^ZZO??M_1%!\'X=3MI+T10P_;(3,&$30*%D9\00Y&WCS0Y*
M9.XEAP<5\X>*M9U'X(^+K-UC4O([R0,DFUKC[+,#Q(?E*,THRA52R@C>!D5]
M90?$`_V/::?]H;$4=M'$;,9V-L0"-HINL@(^9U;:W`S7D'BSX<VGQ!UZSU#Q
M#OFTZT\QA`L_DR/"58/'*I=2$:148JK,#@$G(Q7O<283*L#A88O)98JCF<9^
MUC6J23A&;FU6O348\SO:=.LW*$4ZB:JKV<*?A97CJG-['-;5,$Z<82I03<Y<
MKM%1YK+=1LW9W2OH[GE<_P"T5\1/B#))H7@FVO(_$-[.8UO;RZC33[4P@EXW
ME\MVMWCDB7RV#,=K;<D'CYF\7_L)Z3\7?$.K^*?CUK5U<^+]5_<1?\(Y(D,=
MF)G"O>W,H18KB[:-%1'E#.%=\,HD85]HZKXX^'OP#18]+T2TN)97E:6PLPC7
MT[I(Y/D@^=(TA5F#X*J1SA>:^<?A_P#M7ZS\;O%_C<Z/8^&_!NB^#]0BMIX]
M;U>V@U^_DN#F-+'2YW\IWMU?<)0Y5I#$FW<2M<7]HXGZK@\9BL;F>/QDJC=+
M"PHU:6&IT_=E.O.-6KRMRNJM2JW>'+*<$W8[J5-_OE@<-0P.$G*%/VU62EB)
M2E9QI\\:<^2/N\S5I64?XEOB^>_B!^P-\(_@[^S_`/%_Q!X:U7Q*_BN+0=3^
MQ^*-:N9/ML:V\;36>CV5I:Y@(FD9HI)HXU:8-&IPBA1^0_[(_P"S5XF^-'Q1
M\/\`A:VT3Q-IK:'<7&M>//%%[J31^'8_#,%PL$4(LY;83C4881)]I@^ULINS
M"$5(RT9_HU_:1U+QS:_LYW_VF(RSZWK-OB86\<K7EA?75M%;110*P9FDE*RP
M@`$D@'()%>>?LA_"KQ/\-=/\9>._&U@VBR^)?#1M=,TR11;3QQ0))/+=:CN#
M,91C:H)'#[,8.![W#&*S#.\XKX*658NCEOL<&\=6E3EA'AYTZ46Z<G!J-6$E
M6C1HUYOGE",ZU)-\J>6/]GA,JHU'BZ;Q2Q57ZK153V\I4JF)A1E-0M_RZC0;
M=9VLFTG91.#F^"/P)TV:73H_#27D=A(]DEY(B^9=):L8%N9/E^_.L8E;_:<T
M4Z[>Z>ZN75$*O<3,I:4HQ#2,064(0I(.2H)"GC/%%?I7/P['W?JO#ZY?=MR1
MTM96UQ+VUZ]]>WSEL0]?K>(UL]95K_9\M]O73N?;6C7NC:REIJ5K<K-IT,D5
MPJI<%D8QJ%AC*MRH=B78$8(8#'R@5TGC+XDZ?X6TVZDNUC@M+&`2.T4K32%8
M2LTBF)%,K;\`,RD*5)!!!K\\?V=?B]+8>(+7PCXEO5N;._)_LMKDA;?S%+RK
M#&3.'D)DD*/D,(T1&(`-??5[X%LO%=M),EI:7<=W;^8EO,RW+-*S$E8KA8BT
M43("L<F3$RY0.6X/Y7A,5#B:C3Q.`HQ]O33^L4ZV'A-J4J=%N:P\VX^RJOV-
M3#T5.TYNU1.+DCV,5@991BWA\QE>G"5HNG*2C.',K1]JO>5M(3]UV=U:2U/&
M?#7Q.^%OB&];Q;X@NO#NBR337-K:W?B34(@K+#(T=R;:UOL>6[I'DGCAN.K8
M_/']O3P-\+O#FJ^!_BI\(5T>-/$FKWL'B6?PAJZ7^GWDD%M#>V>H7EO:R-;V
M<J74#JZ1-RT0<XD+5]"?M*WOQ/\`@>=`U2+X.:-KVE/=SB6\N=*MM>T:2QAR
MDT+1VL3O;R",K'(I"RPL7:0`FOA[0]-\,_'GQC':?#[P=XM^'VJ^*M=L9_%7
MA+27>]^'>IO.&,\PL+S-SHUSB25M1CM/(2=XS&W[Q'->-*>=5)TL!BL+7EC8
M8VE'ZO5HUX5\33J0C-PG2P3=256NJD882A'#2HU*G*ZN(E"G*M#W\)1P=%5<
M<L7&GA)X:?/*-2%2$91IW5U5A%\T;;N2<E=W5]/T5_9_B^*WQ@\%>&=6^(&K
M1S>!]$;2KW3K>>SFO)]6N]+ECGTY;>1DC2.WMG@$=V&:0H5(#$8-?6OQ0\2Q
M6WA&\2)$DGGBFLC&DS%C,%W2H+63=(%*DC@\\`9.#6OX5\,6_P`,?AUX?\*Z
M1L:+1M(M[2/S558S<0B,,QD"2,P-P[I\S*Y==K3R/R?`_BEK;ROI^G>8\;()
M9S;O+$R-<7)7;/(P;S@A$P="XV%03G:2:_>,-@,-PID-2-*E46,K+"RQL:^(
MJXSV^95(0HVE*M.JHSH7A3P].E*-.G3I4I<THTTG^?3KU,US"GSI*FN>-",8
MQ2HX6,E*%.*C&/Q2FY5)-WG4J2E:-[+PUKB0LQ\MUR2=OE70V\_=QCC'3':B
MK[1W(8@^43DY(GM\$YY(^?H3R**^"4<.K*5>A=63O.@G=<E[^\[.Z=]7UU/H
ME"EI[E?I_P"V_P!WST^79G#_`!.TK2]*\`_#/5M+TVPTW55U>R*ZG86=O9Z@
MI:*'<1>6\<=R"V3NQ)SDYS7Z>?!*1Y=/T&25WDD:SMMTDC%W;$7&68ECC)ZG
MN?6BBL,E_P"2AP/_`&+LN_\`4+#"S;_<7_V%XK_T_4/<O$EO;W>CZY%=00W,
M:)>[8[B))D7<)MVU)%95W8&[`&<#.<5^2/[,%G:1_&SXNO':VZ-;:T3;,D$2
MM;G[1=C,#*H,1QQF,KQQ117T]3_DY'"O_8=F7_J!5/*H?\DYFO\`U^P__IR!
M]T^,W?\`X1[S-S>8/L@#[CO`:YA+`-G<,DDGGDG)YKXV\=2R'7M0S(Y_=V:?
M?;[A3:5Z_=*@*5Z$<8Q117TG%?\`R+,/_P!A%#\XG'E7^]K_``K_`-.4SDB3
MD\GJ>Y]:***^=I_!#_##\J9];'9>B_(__]D`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T
M87)S+V)O>6%N9'!C+F=I9@``````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C,U
M,2`Q,#4Q-30S,S<U,2`P,C0U-30`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````1TE&.#EA0`!``-4A`/_>.?___P```%)24JVM
MK1@8&#DY.7-S<U)*$*V4*>?GY\;&QHR,C#DQ"!@8`,:M,7-C&.?&.8Q[(?_>
M4G-C,:V<:U)**5)2.8R$2CDQ(:V<4L:M0JV4.7M[>XQ[.:VE>XR$8P``````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"'Y
M!`$``"$`+`````!``$``0`;_P)!P2"P:C\BD<KD$.!^"J*`@-1BDT<,`RXTR
MOT6G.-'H*@)HQ>",;J<#!$%#3!=/P,1Z'<)P^]L*5`,$!P<$;50/>G1)BXYT
M4&YQ$(^.D6@+`H=N6T<3E6((FP.9!`-S>J)M%72J:`,%?P)X0Q=J;@8#?VB$
M!`D`$0D0&(,&``FZNY*T>4X($`D.!@RF:`=G`\S:S%13`X,$#`IJ`KFP40[9
MVV!C6(-=Y0P#?0OU"@0*#`?=L^N->J0.;=F%SXT"`YLP"9!0J0FH.IJ482I`
ML<`!!Q$624@68(`#"$H>+DH0D0$"D7I(+F@C@".O?DP^)6"PLHT!-E,*7`E8
MP`.D_P2*'B$PI\Y?`5,%&B!PH.\;Q:`(_$EM=NQD,`=E$&A%8*'`U*](!(7H
M)\6!!`15BH+]PB_*MV]7<L*KLM:(&"A2VL)C,-==72$0W;XK)[&-J4);&F34
M,U4/A"E8:K99@/`/3317@CK2]NAF@'J%)\?RX[%A3)%,0^_29[:.5FB_G"3Y
MA%*,!`%_MIA=_#`BFI:?QQH(4[M.@TT'3A9WTH#C`=Q^8`Y9GFY<%+Z\(6F9
M1Z$5QS@)7ZE%0AO`@S+@#*%I>F]`;``4T#1?5>?!6;>O_`$8))F`@<_A(7(!
M!2`PP$%*"!&@X((,$K`.!(2P$0`U`?S7D1@)-JCAAAKJY_^,,P+YQ\E?VY@G
MP`']39-0+B2VZ.)?PPTQG@$6O$B+7E7H1,`"6L3%A5<V&H'C%`901`@5%4DQ
M7HNRA>"C`5H8&4<YS_75DHMT.`#/D.=8&6-==-SFUI1SZ;1%%$,R"0PT4ER#
MA7^2%<:7''6`58>644#)ETMJY!+@9XD\<L<ZJ701)R9_$##:%I0\0F@="11P
MQI0$A;=20@=AY"AG>L3W"G2J$>*'`0Z8AH=0ATITSP'B&"2`<IM]49XC$8PF
MIP('Y%+(&6HX\%ZL(:$D@:W*A*/``A4AH)D8M0X0%T,.%=>`A7Y0%D4#$F2@
MU+)T'-<&+%?\LQQ)I+VZ'*@!"-#_`2=7`K:<&.@6T&AQ$E`;AX2O?#EK<:X(
MD%UM)WY+;1K2A?#N`Z080L6O]4'PS![$^M8&`T`2)U*]'9FBB0'SUF'*(*R$
M<H!AZ*)1L;B0GN7`**5\0T<P'ZQ,GQC3SN/?7*<>,_)D.V?<'C024*#@`0]8
M0`T#';LVRCH31#"(&X5@]DT?F,"Z004,!Y,`27UM,\$@5`>@0,D&#=+`UB__
M@DRHVR`00,\=X=@`158H5087"-QMI1?::'`--0I"60UEH1#UUN&()WZX/P]L
MC0H"`VQ'S0*F.!#D%Z'\H@K8U^1W>1,D74:.>M9T]+E#":#5$DVX4KE`(*>C
M#BL")-%!!E+LN&\3!``[````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O>&5N82YG:68`````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`R,3<T(#$P-3$U-#,S-S4Q(#`R,S<Q,P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!'248X
M.6$@`"``]P`````````S``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_
M`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF
M`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_
M,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF
M,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___
M9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F
M9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_
M9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-F
MF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_
MF<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!F
MS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_
MS)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]F
MS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/_
M_V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF
M_\R9_\S,_\S___\`__\S__]F__^9___,____^+\D````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````(?D$`0``V``L`````"``(```"/X`L0D<2%`@@(,(#Q9<
MR)!@PH<(&THTF'`%@!48$TYD^!"C1X\1-SJL^/&C0I$4+5XTF3$C`)38#JI4
M"5&C2)DUG1S4^?#F180D=N9QXH34T*`G)SY$>O"9TV>D>F[\N9,$49UYGN4!
M8!7IU)\ZNP8E^HPKUZT^#VX=.M3)4*UDT7X5FH?44U).GD*5JQ2H6U)V]]H%
MC/?E5XM6\]2U^]>IT:0-$2)VJQBPWKV0.:[D2D)QW3Q/0F<M;%BB3)6)%WMV
MK--B7Y<D.B^^O/7G:XLKNE;62]JUZ<VYKS:&RM/V[Y96*0LO3K5T0<D'4W]6
M#'UF9IPT*2]^C!W`$P!UG5KCC`Z`LF6HDD%^#T^Q.8GUYYW67HD8?LJ$[\O'
M=\H39/ZZ,=44VW?[:95>?0!$U1Q"5^EWV3/%940-->DE1)0??E"#U5-9&0B=
M$QGFA.&(%!8EF(>G`1!B0```.P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A
M=&%R<R]V86UP:7)E+FIP9P``````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3`R
M,#<@,3`U,34T,S,W-3$@,#(T-#,R`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````/_8_^``$$I&248``0$```$``0``_]L`0P`!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!_]L`0P$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_\``
M$0@`,@`R`P$B``(1`0,1`?_$`!\```$%`0$!`0$!```````````!`@,$!08'
M"`D*"__$`+40``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-180<B<10R
M@9&A""-"L<$54M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*
M4U155E=865IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2E
MIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S
M]/7V]_CY^O_$`!\!``,!`0$!`0$!`0$````````!`@,$!08'"`D*"__$`+41
M``(!`@0$`P0'!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC
M,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:
M8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*S
MM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:
M``P#`0`"$0,1`#\`^C?A5^Q1X:_;7_:2_9[?]H#P%?>,OAA^PC\&?A9\5OC+
MJOB731X6A^*?Q-UOPWI7ASX6?"/7!K"C4H9?$>I^&=0^*'Q!TWQ(AN+SPXN@
M:#;V$\?C&TM[W]@_VPO&GA#Q9\3_`-E[P/\`''QMX9\!^//BIXQ;PM^Q]8Z)
M<W7B'Q!X?^('BWP7K%UH?CC5/!^GZ5#I%G#97>AZ,_AVX\3:U>1:CJUQ/I.E
MZ%X/GDT^.3T_X0_`?5_&'PHUZ^T"&]T]OVCOVGOVH?C)\3GM(+^TBUK5]=^*
M.O>$/!MCJ&N?:(]0T[2-.^&GA6TTW4C:R"^;3;*6R\.S6>IZM`[?GW_P4Z\5
M_`O]E3QW^P_X"L-)L/&/Q#\0_MU?L>WGCCXMZ\]M::UX?N=(^)7A:W\/:%X=
MO=)B&G^#O"HT*/46L/!&B&UT71=`FB2:"-=)LEC`/S\M;?QA^T_\?-+^$/B*
MV^.'_!3?]KN[\.C4/B9X=\1>/?$/@W]CS]D?1;W4I[>+0OCK;:*?`/AIO%&F
M3VVOZG'\+]/N-$N[F"YL]/UFX\9:C<3F;V>P\0?M2_\`!.[QSX&^"_Q9^!7P
MM^#^F21:M\7/@N_PKEU'QI\%/&'Q)\!S)XMCT+1YI-,M_$7A_P`3/X1/CG3[
MV"]T>Q%S80VIU/538:%H=Y/^MW[.WQS_`&0?V+/VW?'7["-\=$^'7QQ_:S^)
M'Q-_:!T&]DMQ;Q^,?$6IZQ/:^%?`MWJEP%3^V[_X=>'=.\1>`89)FTG5;/2?
M$5@T<6O1PQ7'V?\`$_X-_"GQU\0-)^!?QS\'P>//AYXUU/Q!\3_@9-JG]H27
M7P[^(.D:)K%KX]\.Z9K.GS1W^E6PT/6;WQ'X9M;J<V)M=5\3^&8;?^R/#>EV
M@`/P'^#W[8'PQ7]H/]M;]M?X:_L?_$KXE_`GX#ZOJUCXV_:!U+5[^U>RU,ZO
M/K?Q!C\%:UK/G^+?%?B'18"FIZUI^@OIWPX\#_#T6_AW3[833$:_^U?PJ_:&
M^"'Q2^)'Q0T!O&/A#Q7^S[\8/A]XB\27.D^*&TR\\,0WVF:/#JGQ-NM0EUAA
MI\'@OXA_#/Q%H?BC4=-U)1I"S^&O%VLW%OI,,TUK<_:GPU^'?PE\%_#";X0>
M#O#V@MX&\+Z1>^#?$.BI9Z:]EK+MH\-MX@C\1M:VMOI^KZSK%G<K-XPG>*;[
M1J-Q<V]R\TL4JQ_RL_L%?\$P[GQ9X2\;^%?B?XHN-3_9@^*?QU^(?A7X&_"K
M3=<ET>3QKX"\)S^(_`D&O:EXSL=4T[QK+\)=)^%.DVMY)X?TFZBL?$?BJV\)
M:!?Q3Z4JP(`?6&C_`/!,+_@E!XVTC2O&?P\^/'QOTGP!XNTVQ\3^!M*\%^/M
M2/@[3/!^O6L6J^&=/\)F_P#"=W?'PS9:+=V5MH)O;JYN_P"RX[7[1<33;Y&*
M_H!\(^`?A9\/O"GACP%X3LO#7AWPKX(\/:+X0\,^'T:YC70O#_AK3;;1M&T=
M8YM96:-=,TZRMK)4E42*(`L@#`BB@#PS]A7QB?%/P+U_2;^6W.M_"CXX_M)_
M!OQ'+]F6W6WO_A[\;?'&FVT\T+EG"WV@Q:'JDK.1]LBO;>X?=O#G\??VH/V0
M?"7[5?QN\'>&_$>K:U;>*_%FN>)OB%IVOKY6H77@N/6=8MK'PSXFL-'O/,CN
M-9\+:5J5O>-J*B*ZM&6"UM9OMUUI[0?9?[.OB!/V??\`@HQ^U5^RQXDE,WPR
M_;6TO_AN+]FSQ'%=O+H&L>()]"\*_#O]ISX:6&K0.8&U>UO]$\(?$[3HH)OM
M5UX<\8ZAJUD!'9W!B^A_!GP=TJY_:^^(?C2:6673?"N@:'X4T.U\J/[1#>:`
MOA/QN+&>1@3-;1#Q);-;G)5HC"[XF,I`!_-5^WC_`,$R?VI_^"L>F?#+]L_X
M?>.+/X>_MB?"F2^MH?A+KNJ6O@S0]<\*:-X\\0>-/@IXD^&?B_0?LNI^']2T
M?0+:UN)[W6AJ_B;3?&?AW5-+U-9].6[+_8/PY^.'_!4OQ[X3_9A\'?MQ?`+Q
M#\-/B[\&]8\1ZKXW^('P)UBTU7Q1XDTG6?AKK7@/P1K.N:DFIZA\./`WQ"^(
M.M:KJEC9>#I?$.K1:_X@@T76YK/P;H^LZ#IUS]H^"O$47PL^.OP"\5V6BC5?
M#_@+Q9^U/\"/CQK+74LFH_#KP]X2^*.H6?PN\5W.GS2_8-/\"65EXW$FM:XJ
MV7]B#Q*)I)I+.[N%B]F^,WA#5].M?%_[37Q-^.WBCPY#:_&'P%=:7X1T#XMI
M;_"2T_9F\`^/+"]NO#6K^`K:ZO?#OC#Q)\0?!'_"5^-]=GL-.U;Q'XAGO]*\
M/"X31]!MK``'\]'Q<_X+B_MI_MC?&?X=?L=?\$KO@1\3O@?X)U+QAIWA'QM\
M3_C%\,)[SXVWNGVFO0CQ_>V/AB_74_!_@C3=.FDU;3?$FN:YJ.L^([[Q+<7T
MRR>';$S7.E?;W["/[4=O^V/_`,%,?&GACX%^$M4\)?L9?\$YO#_A_P#9V^&&
ME7]I!:WWBKXA^+M>\3:)\2?B'-;R&<6VE2W7AFXT;139W<SW.G::U^PLY-3N
M=/MO7?CK\9M<^+G[.7Q,TO\`9<\%?$G]DO0OC7\49/`VD^-$O;[P/\1O''BS
M7=!L=9^(OC3P/I4+VVK^!_A)X(\-:GX@\4^(O&\_]FWOB?QA>6<&AVT`OF:7
MH_\`@BM^S/X<^!GAOXWV?@^PD3P[>_%;X:V%K=0R3ZA=;_"_AOQ1XIUJZUS5
M=7D>_O-7N]2\2@:MJ-U<3SM?M+<)<!+I`P!Z'\7+SQ`/BM\3A#?7ZPCXA>-!
M$L<>K>6L0\2:D(U3;=!=@7`7:`N,8`&!17X]?&K]J#XZ>*/C)\6O$W@6#QE?
M^"/$7Q-\>:[X.OK/2M<>TO?"NK^*=5U#P]=VK0YA:VN-(N+.:!HB8S$ZE#M(
MHH`_1GX;_LS_`!R3]E/X8^-K;XAZMXHD^%WQ!\3_`!1^#6LIX?U/7?B7^QC\
M:?AQXC\1^"-4\.:18P+J/B;XH?LX>-X[+6/!/QG^$\D)^(-GX3US5CX9M?%.
MHW"6VD?J=^QQ^T'\.?VF+37/B!X4U+0-(^(_A[7=6\/?''X4)JL&J>(OAY\0
MWTKP997=J]U:;&U3PGJ=GHMKK7@WQ;)8O;>*?#FN:5-##X?UN#7M)M/%/^";
MG[0_Q8^*GP]\9>)/C5\)+SX>Z*VIS>)A\5+>32X/AUXT\5C6-6\-_$:[\+P0
M:G;ZUI8O?&.DZKJUU:3:4(+74-3UN)YW@D1:^_[KX+_![7?$-A\1!X&\+?\`
M"8V]A?0VWCCPY86^D^(YM/UE0;L#Q%X<CL]3OX9S-<362R7L\*27%Q/&%FEG
M)`/BOX7_``0^$_Q4^+'[3^A?$;PA%JI\#_M(:QXSLV.N:I9Q32_$7X9:-87L
M&KKI6KV]I>Z0UG9MJT>EZA:((]3.D7UQ&U[:0SU\BW_[/5KX;U'PL?@OK&M>
M$Y[[3=*AU33EUZW\1WWBC4_C!XN\2>&?`_P^E75I[V7PQ#?>`[%OB'\1/%:2
MGQ+I?AWPT]SX9ET_4[^]NKGNW\3>+?V:_P!LWXF:C_PG9?X2ZW\1?!Z^)O!T
M^MZ-XT^/GQ!U)?@W96?AWP]X2\(:A?1>)]?\%SW&IQZX]SX:M]5\67NL>!=7
MTMT-G`]O-[EIOQF\'Z_\;['XM7WAWQ3\,?@#\,O"WB#5-7U?Q1\._$&BMK_Q
MD\:Z)X4TVPU3Q=#%ICR^!9/AY\)K.32S/XXN-#N;"W\46MO:V=CI$=B]R`;_
M`(8^&U]_:GA;P98^&;E+"QM-1T3P5#J=N;:*V\#^'%?7?$'Q!\3+AWT[6?C#
MX^N_#\5KILF+A?"<L]C?>;)%>QUY5^T-J%A^S!\/O`/[$7[,E_</^TG^V1XN
MU7PWX*6*,7=Q\+?`O]EZ3:?'/]I'Q%%;`'3?"/PI\#VDVH^'H[UXFU[X@ZSX
M/\*Z<LR:AJBQ>MWW[8VF>*?#NJZK^QGX!\3?ME>-_'=S&OA_Q5X9B/@O]GZR
MLIH7&DWOBKXZ>)([7PC_`,('I%NUW?7LGP^3X@^+;V2ZU.[T#PMJ>HZI,U=/
M^RC^R)XA^%/C3X@?M+?M`>+--^,?[8OQGT[3-)^(OC[2=+O-&\$>`O`>D7AU
M'PK\!O@3H>I322>'/A3X,U*:YN[[5K_R_%'Q)\2K>_$3Q9;VVI:S::5I(!]6
M>!O@S\,/`7@GP?X%\.^"?#</A_P7X6\/^$]#BN-(TZ^N(M'\.:3::/ID<][<
MVK7%Y,EE9P++=3LTUPX::5B[L:*[SRM)/,EM;S2'_63&Q\TRO_%(9!`PD+ME
MBX)#D[LG.:*`/B7]AVQLI/`'QZT)[.U?1+#]J?\`:$T:QT9[>)M*LM'N/$=K
M+<:5::<4-I;Z;/+?7LDUC#"EK+)>73O$S7$I?D_V&]6U24_$;P[+J6H2>'_#
M'Q%\?:3X;T*2\N7T;P]I6G^/]2M+#3-#TQI#9:3I]E:@6UI96$%O;6UO^YAC
M2/Y:**`.@U+POX9\:_#+]I[4_&7AW0O%NI>'O%_Q\CT#4/$VD:?KU]H:>&K?
M2[GPXFCW>JV]W<:8F@7,$%QHJV4D`TJ>&*6Q$$D:,OS)\:+Z]\(_L>_M$:AX
M3O+KPQ?VO_!.G]H'Q?;7OAZXET6[M_%A;Q;.?%$%SIKVTT/B(SHDQUN-UU(R
MJLAN=ZA@44`??'[&FA:)X=_9*_9DT7P_H^E:'HVF?`#X/6^FZ3H^GVFF:9I]
MO+\.O#%S+!96%E#!:VD,EPS3R1011H\S-*RER6/TL$0$$(H(Z$*`1\NW@@<?
M+\O'\/'2BB@!^2.A/YT444`?_]D`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W-T86XN
M:G!G````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-S4T-B`Q,#4Q-30S
M,S<U,2`P,C,W-3``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````_]C_X``02D9)1@`!`0```0`!``#_VP!#``$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1"``R`#(#`2(`
M`A$!`Q$!_\0`'P```04!`0$!`0$```````````$"`P0%!@<("0H+_\0`M1``
M`@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152
MT?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D
M969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6V
MM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`
M'P$``P$!`0$!`0$!`0````````$"`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%
M!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D
M-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T
M=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$
MQ<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`
M/P#](?A?_P`$//$/AP0VVC^./`^G:Q+B77=9T'POXE\3>*]?NY(8UNM7\6^*
M]3&A:CKFJ7F"+[4-7UK_`$B5UDBAA$GE#Z.3_@A]XQE,DTGQSL5X4B(_#*VE
M;A<%<?\`"TH8%`Q@;=V5QO8MN8_T6Z/I$.EVD%K`BJBQ@3_+DW$P";YY6<LY
M8E2%4EE53@8``'QG^T[^U?XW_9^^./[)?PJ\*?LF?M$?M!Z+^TK\0=2\">+_
M`(I?!KPWJ.M_#[]F?3-,U;P+8#QQ\<=56VET;P[X:O;/QWJ&NV\^IWNCO<Z%
MX"\7R:9=:IKMIHVB7'XCA/!+AW$0A6S^OF6.QU5>TJ16.J>SH-64J:;<E)W=
M^:FJ$%9_N6[./Y/C_`CPDQ&,G5?#F8X^49.,\3G'%'$F,Q%?5-3BZ>:4*&&C
MWH4,/&#OKRVL?C]<_P#!&B\TRZ-K<_'Z>TN&C!^SR_!Z]A5@S8+Q36WQ7N+>
M>%2A431-)&2>6!V[J[?\$8_B!>VS'PA\8=#UA49P[:EX,U'08FD558[9X=>U
M6!LC@YD,P90&4(8R?Z+?B+86D_A^2ZGCDBEL);-[=[6-&N$:2ZBMS'&"\2&-
MTE(DC9Q&P1202JX^=_VP?VF],_8E^!EU\89/@?\`'[X_6&E^)O"OA[_A6'[,
M7PUA^*'Q2OQXCU>#2O[1M?"USXB\+VQT:PN+B.?4]5N-6@2RN)K.R"7DNIV]
MM+YM+P)R26:8B-6>(CE,(0G2Y*\IUY.3:=/FJ+=**;^SKI=MFF+\`O!&M@Z4
M:7!]6CCYS<)1IY_Q(H*$>6TT_P"UGK)OMHUKT3_GT\:_\$A?VO?#L<\V@V'@
M;QC%;JTJ+I_BZ'2[YW5V"JMMJMO"$*E4D:9;J(1@L\=W;M&+F/X%\?\`_!,#
M]M3X?:EKWQ.^&7P6N4UV2U7_`(2GP)8>)_A[JOA3XA796*T,Z)X2\4ZKJ7A7
MQ@L#SS6_B>ST)UU.X06/B>SU*TDDDC_NQ\.ZO'XG\,Z!XACTO6]%37]#TG68
M]'\1Z;+HOB32$U2QM[Y--U[1[EO.TC7-/$XM=3TZ=O.T^_AGMG/F0DUY?\3O
M"EXEG=^)/#%IIH\216-Q"BW\E]8Z=?W4[V=MIYU75=,BNKO2[2*8K%J&H6VG
M:E=6UC<7=_%9WZ6,FGWAFO@U@<IPM;%Y#C<=47(WB\NQ4J=6ABJ;23O%I1YJ
M*M6CS25I4XV=SR,L^CCX=1Q,J6%Q_$V2PQ*G3J0I9EA<?E^(51.*ACL#F&75
MXXB"32IOF5:%14ZE.O2JQ5:'\5>E_L__`+3.I:9IVHW/[+7[1VF7%_8VE[/I
MLOP?\4/+I\UU;QSRV,CP+>P-):/(T#M#>7<3-&3'<SH1*Y7]2_@;]HSX#>/?
M!/@_QSI?CW0])TSQGX6\/^+-.TKQ/=PZ-XETRP\1:3::Q::?XAT>_NY[[2M<
MLK>\CMM6TV\FFN[&_CN+6XEDFB=R5^//@^AS/_9ZBUV]CAFEK'3>[V7]-':_
MH9\"-MKBW-DF[I+*LJLD[.R_</;;=^KUO^DX8@+@Y'<=1^!Z^_Z]Z8X4N_[R
M3<P0`*V`HQVV\D,,GYMP4DE-I))\4T;Q_J%C:K;WMJE\D05(I5G6WEV*@55<
M?995)7:0&!W,""2,8-R^^(]Y,C)9Z?%:NX(::6?[25R,`B+[/$K8'4%U!]N2
M?ZII\>9`\/&NJE3VO(YU,+[WM(Z*\8MKDYD[*RDDU=WNC]ZJ<,YO3JRIJE'V
M;ERQK/E<;=++FYKM+K%O=;;=%X\UJ"UL[>PV6]S<7-Q#*UM*D,H:W@9I20LH
MD7>TB)Y;;#A5?!!Y'86DD.I06M]:W#B*4+*LD+1,)D&[]U.3&X,>6D&U2I#'
MS$97"LOS-<RW-U<274\QEGDRS2R')D8G/*!=L2G+'";L'`P>HWM!\37?AUBD
M:FXL)&'F6;R<K@<213%&96#L28\!)``"RGI\ME_B)"6;XFIC8SAEV(C&EAU&
M5Y82,9+]Y4BE=SDG[V][*VSO[F,X3G'+L,J%YXV#=2J^2RJ<RC[B;V<;.VJ6
MNK2U7T8N54*H4*@"A0,!0H``4#C`&/3'0<`5S'C&55\/:G',KO%<6LUI)&B*
M_F_:%\I4<O+"L:.[K&\GG1,%D*PMY[0XY=/B?HQ5<V>JEBI#K';6[(I"$D%D
MNCL5B-B$@,"5RJYKB?$OBVX\0A8H[62'30KK]EEF\N6Z651!,MVZ1RD0K"\S
M)!ATFD\M7:,#>OT>;<;9#3P-=8;%RQM2M2Y%3I<\9PY[+3FBEI>\G?:ZV/&P
M7#V9U<515?#U,-3C44IU).#5H>\MI/=JRZIZL_C3;_@GQ^WC\<6;XU?#?2_$
MO@7X=_&`GXH^`O!.N1>*=*UKP=X+^(!_X2SPMX5UC2ULP--U3P]H>KV.D:A8
M``6=W9S6XXCHK^P=G:1C(PVLY+LNXOAF.2-Y5"^"<;BBENI5<X!7XJ\SIMW^
MJU]7_.N\>_S_`!\S](6$G9?OZ?3_`)=)O3EZ\^NV_6R[LJ[Y%)4#*=0?E!)_
MGW/:ODO]K7]N_P#95_82\)^'?&_[5GQ:TWX6>'O&GB(>$_";W>A>,O$VH:YK
MZV4FH2VNF:3X"\+>+-86"UM(VFU2_O-*-A8QM;DW/G74%O)]$>#/&WACXA^&
MM&\8^"=>T?Q+X9\06:W^EZKI5['/#<6\B1R)B)C'=QRI'-']K@N[:TN;&9UM
M;NWBG.P?G!_P5/\`^"7/PN_X*:?"+2?#7BCQ!KW@#XO?"^S\<:K\`/B/I-ZS
M:3X<\6^,M,T&UU73O&_AZ31]13Q3X`\37W@_P8OBG3;)]-\006WAZ*7PEK:Z
MK<W^GUCE7]G8G%898[$/ZC4J*-6OA8.HXW5[I6G9)[MJ2:TM=Z/$8KVV"]OE
ME7#XJ=2*E1E2KQJQFO*,%&36UVI+IO=7\&G_`.#CK_@DK!=O:+\??%ER\33!
M_)^!_P`;<,L$SVTH1I_AY9J'292/F)5E!*A@01]J_LF_\%-OV'?VY=3UCP[^
MS7\>_#OC/QCH5I!?ZMX&U?2?%O@'QE;Z=*TZG4K'PY\1?#?A+4-?TNT2V:?6
M-6\,)XAT?0EGM_[9U33WN8;:/^9;]F?_`(-.-1DC\07W[8G[2]E97TDU[;^#
M_#O[*UCJ7B?3C'++:75KXB\3>//BSX-\,/#=W4;:@5\#:?X#D7[/]@OX?'MP
MMS):P>G_`/!.G_@W2_:1_9"_X*%?"W]H7XE?&WX*^,?@3\%]<\4^*/#4G@Z?
MXBQ_$WQSKE_X)\1^'O!)?PAJG@)?"OA1])U'6Q>^.I-*\?>*"=*TZZT/3;G5
M;BZOH-(^ZQ^3\`/#8GZEG.)AC*.'KU<.ZE*FWBZE%1:H4^6*4IIN\K7;BU:V
M[^?P^.XDI5J,ZV&2A-N,XRC-V:6KC'FVL]$[[-;']A$3K)#$2[-$R1NIW.."
M`4QR&`Z87@`<$8R*L@*HR,#<!R<'./KDCK^.>:JB59`6W(#M::7:XDC2.-3-
M</'-&&241Q+(\;J`DNU2&16W+\U?'7]JOX+_`+/`LQ\0/$TUSK^H6[SZ3X$\
M*VT6M^,=8A"PNQ@C>\L="TB%8KJUNYKGQ+K&D0_91(;%[^Z46K?FF(Q6&P="
M6*Q=:G0PU)1E5JUZD:,80<E&\IS3C&3O:*:;E-J*5V>YC,QP.`6'>-Q'LJN,
MG2HX7#TZ53$8G$8FO*-.AA\/AZ*E6Q-?$5IQHX?#X>%2O6J2A3I4ZDYJ)]/;
M;AOF6"X96Y5EMIF5E/(*LL9!4C!!!((Y!Q17X!ZE_P`%2_B:^HZ@]A\+/AS!
M8M>W364-^?%5W?0VC3R&WBO;N#6;*"ZNXX2B7%Q#9VD4TP>2.V@1A$A7P3\5
M>!$VO[<P^CMO!]4OY[=?ZUM^F1\*/%*<8R7A7XF)249)2X2JQDE)1=I1EC8R
M37-JI14DU9I-V/S*L/''C7X?ZEIFN>`_%_BCP3K=Q=6\$^L>$?$&K>&]5G@G
MD5)H9M0T:[LKN2*9$1)8WF9)%15=2%`']>7P?EEO_A=H]Y?227MW-I5@\UU=
MNUS<RO+',TKR3S%Y7:1B2[,Q+DDL2:**\KP?_P"2<J?]?:7_`*;9^9\<?\G]
M\0/^O>&_]3ZQW=A''*^V1$D4I)E757!Y3J&!%9GBDF&XA2$^4NU6VQ?NUW+R
MIPF!E3R#C(/(HHK]<I?[U@O\<_S@;U/]^K>M/_U+P!^2W_!63XA>/O`7PK^%
MMQX&\<>+_!EQKOBQ]-UN?PGXEUKP[-K&G77AOQ%]IL-5ET>]LWU"RN-J^?:W
M;303;5\R-L#'XE^&@+ZQTZ\O0+R[O+H&\NKH"XN;HRW(64W,\N^6<R*2LAE9
MMZ\-D445_/GC=_R+Z'_<3_TN9XOT9/\`E+"I_P!DIQ!_Z8D?5?\`9VGK\JV-
MF%'``MH0`!P``$P`!P`.`****_B\X,1_O%;_`*_5/_2XG__9````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]A=F%T87)S+W5S+FIP9P``````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`Q,34R,2`Q,#4Q-30S,S<U,2`P,C,T,38`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````_]C_X``02D9)1@`!`0```0`!
M``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!`0$`````````
M``$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&
M$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ
M0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66
MEYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3E
MYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0````````$"`P0%!@<(
M"0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(
M%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*
M4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.D
MI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T
M]?;W^/GZ_]H`#`,!``(1`Q$`/P#^/<#X+>,?"2ZA\-?V:/#&O^/+30O&?C#X
MN>%;6;XZZ;X:^$OASP5XST+6M#U;P3XDN_VC?$FH>*M!\0^'&F\)^/XO%>E_
MVOI^A7VJ0^$[S1_%TNA_$32<,:#\!]5\$>+[Q/@7\0?%-KX:L?AM=_\`"Y_A
M!XP\8_#[P/\`#SQ!X_TG3YO$/A;XT:-\1/!'[0\7B;3])UO3]7\.?#F]\*:[
M\'-1U+4;+Q=K%])\0;"[\-:+X5UKR]\,>,/AKIGPX^(>I_#OX9:%\`O"OQQM
M_A-\7_`GPE\3ZUJ_[4'CN;QOX?UF/X>^)?'<5WIZWVFV%MKL^H^%?$.IZ;96
MW@SP_>PV>J:0UYXDM6/->)M?\<:WX?UVP\>:MKOPZ\3ZKX.^!VF^#_A%X7^%
M@\&:#\9O"UI9Q2>#_$7B*Q\-IX9TO5&M]$EL/$F@>)M4T/Q+>^++C5;5]+NH
MK=;26'^PJ_A_P;B,-[%Y-EZH8BH\0\0Y5L'7P_U/,(U:>'HU\#4P]:HJV&DT
MY.I[#$T:4?K="KAUB[>5',,9!32]C&4XI)RP^&G*/^S\KJ0A7A.,.=24XIP<
M75ES4$JJA;IM0UO]G":/3_A?IGP.^"VD:>WQ/?3X/VKM9\4?M;:O]M^'^G:+
MH.EJNK^#].\::9I]YJ_G-)XR\87OA_X6:-?3ZSKPT[P]X5\)^&TTS3H=QOB_
MX/\`&'A[PUX)\9^$/@I\)/#'PW^'OQ,7P3\1/`?[*WP[U7Q+\;_%&D2:@GP^
MTCQAX@US0O[:O++;::1X4D\6ZO=:UKH^R7FM^.+[7O%NKZIKJXWCQ/%-KXL1
MO&7@BW\)_$=/C)I5Q<?L-3?#?XH>$=`CEU_P?X=GL/%FD^$EO8DLV\82)I]C
M/X;@N-.UJ[%WI4NDVE_X9O(["Q\K:\TSPM9Q'Q3INA?%@WOPQ\6:#IGA&]U7
MXEZ7)^S_`*UJ/BK5+>QNI(8Y]#V:MX<UR[OM8LM`O+[5_#%]J?B"6;7K'4C>
MV\^HX83A+A/*<0JM#(L-.DJCJT'C<MHXYU:?LXTISA4S'EQ5+GA4E5I5J,XT
MZD%"O'`X7VE-Q4LRQM-TU3Q;H4YSDY*BW0;<'#V%.M4PS]M%RG3C&E"=6<55
MYY3G[6K3K3_9K_@CG^SA^S)^TO\`M-7WAG_@I3!\$?@Q^SQ\5?V;]8^(6C>)
M=77X1?!5_'NK>!O'_A;P9X'?PY=:8/#GB7X>P>;I?BLZE<_!"3X5:O\`$>XT
M&YOOB/J?CC0[_P`0VWB#]@_B=_P;J?\`!+OXS^-[X_LJ?M3>'M9TRUM]36P\
M-?`KXS:=XATN*S%Y>7ND-XJE\>+\=_%;^+8X+AK/7-0T;4](\+_V!9^')+#P
MLFMIXAU;6_QY_P""'G["OP,_:W_;=3X0?&O]H:XL?AY8?L=ZY\:7\3_#/6K&
MQN_!NN_VYX&EO?AMJ[^/?#.I:?!J>@2^)-:.NZ?H]A<)/J,2W%A>2>=<*_\`
M7%K7_!`'_@EAHUGI4U_^W;\1M(;Q)K\/A#PW<:G\2?@2(-1\4W\MY:Z;IMO;
MGP-:RWLEU<65PUM'%/!'?00F2VNQ#+%<'^0?''!YSDW'5-9'D65PR6>28"M%
M87B2KPS5J59SQ=&HZ^#PN)_LQ8J"2I2KO!5*M10HRK.&)I15+^SO`[(O!//O
M#YT>->/N*<AX[AFV-HX?+L-X)8#Q1R;"Y5#V->A4J8J.7T,ZG[:O6QM:M@L-
MGV$6%E%1Y?>K1K?AB?\`@U]^%#$M:^._BY?VK$M;7UI\7_A6UI>P'F&[M6E^
M",,K6]Q&5F@:6&*0Q.I>-&)4%?HE>?\`!`/PSIEW=:;8?\%3_`]A8Z?<3V-E
M8P^&O&GDV5I:2M;VUI%_9?Q3BTSRK:&-(8_[.BBL=J#[)&EOY:@K\*<^,FVU
ME.<I-W2_XB!A'9=%=YY%NW=Q3>MTKM'[(^!/`--I>-?AI9.RY_HE^,3G9:+G
M=+"NDY:>\Z;=-N[@W%IO^"UM5L$\.:+9Z]XEUCQ/X&MYOBX/!_PTB\3:K_:G
MP\\2:EH>G0Z3XHU73;C2[;P[!'KVJIX7O-8G\/,9?$=GX1N[34/L3Z?96M=!
M<^*/"\/@SQOHNOZ,?C7XMU;P/\(SX&^*[^)OB-IMW\!(-$EL'\0^$!X>OH;3
M1/$%IY-[#\/2VH1W?A[2I+2SO_!]^S7JI7]4WQB_X-2_CY\*=1OY?@O^WW\-
M?B+XT\1:;KNG>++KQ#X"\3^!=#O=`\7:7J-GK5C=>(_#_BCXJW^J7FL?:##J
MMC>Z!:HEK>?VDE]/=QPP/X!H_P#P;+?M^Z!X9\8^#-'_`&G_`-G+3?"OCQ_#
MJ^+=$M-8^*JV/B2'PSK=UJ.BMJL)^&`+OHQE&J6$2NRMJ-Q<64DL<$27\_\`
MI:^/>$Y3ISP/$5">'A*BJ4^?$X-\E.3E1E+#XO#X?$U7'VLI351O#5</6KY=
M.4\%*HY?YFPPE>7M%4H1I.$ZU*46J7M*=6+J4Y4G"I5BU%5FH3K34ZE%05:$
MG*ERO\'4\9:;XDTRPN?&5SKFM?$-?C7\*[O5_P!O&+Q5\9O$5YX"\(3>#;:Q
ML/`$GAG5;723?:QX2'AZ;6-"U-$M_$?V;P;J^B>&5U'1;;2]2LO.)-0U7PU>
M^(8O"/C74?"VG>*/!?Q$\,>(_B/J5SXTM])^/6F0>)M3U6\@TB(^%Y-3LH?%
M=C:^&]';1=7`MGU:S:7Q+K>F?VK<6UO_`%O_``J_X-(_'_C3P!;^%M?_`."E
MGA3P,VI7MMXG\4_#I/A#XCU+P2OBOP_8+IMMK=I=7GQ9\.6FN365IXKU+2]`
MUW4_#6BZU)9W&OP0:?:VPNQ)[)=?\&8?Q#UG0M#TZ\_X*@>%M4\->'K+69_#
M=E<?`S6;W1=%TYK[[5X@FT:"3XWR65A9'4KC[1J\EFL4`O9_-NV$\NYMI>)/
M`$J$Z-;B6A'$J,:L.?"<1XIQE[2C&=)5)Y2YX>G.A0HP]MAIN[YXJ$Z52,D4
M<!C7RUZ&#Q?L_:.FZT&N6K6C!>TITJBDJ<>6"J/DA&HX3515'*2GR?@G_P`$
M>?V`9/VY_B3\98O"OB:T^$7_``JSP)\([J^?Q3I6I>*K_4Y/&>B:O#K&I:3%
M;7OA\0V>OZ[X>7Q!9VUT)[>TT75K2WMKNX-I!/=_U9_!;_@VJ^&OB6+^V?B5
M^V_&FDRQ7"1:'X:^'FA^%_%%G=17$D$+:D?$/CWQ+:1VUTL;W,)AMG+P+$%D
M+W$OV+\F-(_X-T/VV_AAXB\<Q#]J7X2>.(;1M!\&^'KW3-6^(.D7]YX5\`'4
M?#WAN(VS:(VCV=O;Z-+!-!8V^NWUK;`WGV?4-1FG^TWGU_\`#S_@@C\7_%5A
MIV@_%G]KGPMX?O3JEA86`TKPGXG\<^&(;=PEG#K&K:GXE\5^!)M*:U6>079A
MTB_CBM1-<+=`2-;)_"/C/E^!XB\1<ZS7+^!:O&$91RJC@\V?$D\NRVMA\-E.
M#BXT,+5J4\/2HTZL:]*K2ES3J8M5,3*4YXB2E_I=]&_Q;QW!WA%DO#E?Z8F5
M^!.1>US_`!6.X/P'@I2XRXEPF-QN>XJ#JULXPN!Q.?5<9B:/U/'8?$74,-ET
MEELG&.!<J7Z<_P#$,G^QC_T>#\5O^_\`\*?_`)645\OI_P`&OR2*KI_P4'^&
MKHZJZ.GPB#*Z,`596'QD(96!!5@2"""#BBOR7^P)IV?@W@DUHT^,J2=_=T=Z
M_P"??7K?^BUXP8>23C^TLXE::337T:,Q::?*TT_[*:::::?GZWO^._\`@@+^
MWSIFBZ_J][^W-X@\2)I%E=W@>[U;QV;&Y32+?4)K.XN)KCXC7FIVVG1F>Z;[
M1'HU[J%A;7UW/'I,LCW%N_P%J_\`P1O_`."D\[QS6'[57@2`!H(7MH?C9\>.
MD]Z3<79>3P!`NVWAG>8P@%S#;"WM@288A]M7/_!&;_@NO)*9)/VROM<CYW3'
M]L#X]NQV,T2;FN/#T<C;HXT=.#B)XU;9(KQ1^#7O_!.#_@L!/$J6?[?7V&42
M!FE_X:7_`&E[G=&%<&/RY?!`498JV\'(V;1PQK>GDF%=2E4CX>\:X>2OSMYY
M.K3:;3M.->I6FU&S2E"$9M.]D]3S,1XHY[1PN+PN)^F']%_/,.G2GA\/'PLP
M^6XF+I:6P];)\)DM&+KI4I5:=?%SI1E24(U%%*)S_P`./^"1O_!2B/4M%T_6
M/VQ/"?A6SUJ]TZ#7=3T/XQ_&@7NGP3N$+S6<GAGPWHFH2:8]Q,`]WXATC3Q%
MYDCWT$?F3O\`H'9_\&__`/P4,U&!WO?^"DGB?3F\XC[-J>O?%J>63;NE%R#I
MOQ"U.WV-+=7(7?.LXE:X=HE6422_`NB?\$X/^"QB@/J7[>%PI1&4I<_M2_M*
MN[F>RT:1-JVW@^YB(LYH[^SDEDD266X2:XC66&Z%Q+]&>'O^"/G_``7.U;2+
M+5=)_;=:VTW4X(;^R+?M>?M&69N;:ZABE@NQ;KX4#HL\+(4\](YBH4M&%V$N
MKD6$P\I->'?&F*2J-I+/L13I0;FURTXX6O!J*Y>:-HZJS<K:HP_BKQ%FZITY
M_3(^C#PW/V,:=2$?"K)\QQ5>%&G3M/$XO/LMS*.)FHU5AZDWCI_!9<TFY/S3
M]I/_`((7_P#!1#P)#ITVA?ME6WB_6=6N-2=KWQ/X_P#BEX0%]!HL-O"@TZ^T
MRY\?WVH2SK<VT4=MKEOX:AMXY+.0WCF&YMK;YB\,_P#!(/\`X*<+>W":I^T9
MX/M[1H93'+J?QP^+EPC21S6XMP@L?!VJ7$4TL4ERTD8C6W41+NN)7,2K]A_$
M/_@DE_P6U\,:-]I\8?MPH-+OW?2(;F?]K#]HK6;?[5?VMW(;62Q/A*>61)+>
MSFDF66W^R2H@AEE+.$/RC9_\$O?^"P4&M6EQ)^U^LDEE?V,-OJK_`+3GQZEM
MHK:R*VUM?H5T*WU58-/A@M9+*U2V2<6\20^1$8EMG4<BPU:C*_`?&>%A)INA
M_;,JCG*5KM5*M.M7BTXQ=W4II2;;Y8I-Q6\5\[RS,L+*'TL_HT9_B:--0IYI
M_P`0VH8"EA:=&T8TYX/+\5E655H^SJU*:C#!8J52A1I1A[2JY0I_H!H/_!"?
M_@HSK6AZ-K/_``W1X^7^UM)T[4]MGXJ\87-FOV^SANL6MS>_%W2;VXMAYN()
M[O2]-NI8MLEQI]G*SV\97S1_P[F_X*[?]'W?^;/_`+3?_P`P]%:K*<&DE_Q#
M7C1V2U?$>-N[6U=LR2N[=$EV2LK<4O$'B24I27TW_HR03DVH1\%N%G&";NHQ
M<^")SY8I))RG*5EK)O4_%N;]M/\`;'N5"7'[6?[3$Z!@X2;X\?%.50X!`8*_
MBI@&`9@&`R`Q&<$U6_X;&_:[_P"CJ/VC_P#P^'Q-_P#FHHHKS<%_N\?5_H?;
M\2_\C27_`%XH?^D'#6G[9?[7]OKNEV$'[5G[24%C'%J4,=E#\<_B?':1PVUY
MK,-M$ELGBA84BMX8((H(U0+%%#%'&%6-`/0(/VT?VQ;;=]F_:Q_:7M]^W?Y'
MQV^*46_;G;N\OQ4N[;N;;G.-QQC)HHKHS'_=H?\`7JC_`.GSQN#?^1WB/^QI
MB_\`U6TATW[:?[8]RH2X_:S_`&F)T#!PDWQX^*<JAP"`P5_%3`,`S`,!D!B,
MX)KPV_\`VQOVNK;7]6U"W_:H_:/@OYKFYMI;Z'XX?$V*\EMXYE2.WDN4\3K,
M\*);VZI$SF-5@A55`B0*4493_#I?]?8_^DS)\0?]XQ7_`&*Y?^EX,]I_X;&_
M:[_Z.H_:/_\`#X?$W_YJ****LS/_V0``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O879A=&%R<R]C;V-K>2YJ<&<`````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#<V-C$@,3`U,34T,S,W-3$@,#(T,3$Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````/_8_^``$$I&248`
M`0$```$``0``_]L`0P`!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_]L`0P$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B``(1`0,1`?_$`!\```$%`0$!`0$!
M```````````!`@,$!08'"`D*"__$`+40``(!`P,"!`,%!00$```!?0$"`P`$
M$042(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B<H()"A87&!D:)28G*"DJ
M-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(
MB8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8
MV=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$`!\!``,!`0$!`0$!`0$````````!
M`@,$!08'"`D*"__$`+41``(!`@0$`P0'!00$``$"=P`!`@,1!`4A,08205$'
M87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#
M1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66
MEYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7F
MY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`_@OHHHK^R#Y\_:[_`((&_M+V
M?P1_X*`>!O@]X]N)]3^`/[:^G7_[)'QH\!71U6^\.>,$^+D,OAKX;#4="T\2
MPSZBGQ#U'1?#$6OS0QSZ!X3\:>.(4U'3M,UG67F_=K]EC]A3QK=_MA?\$,?`
MNHVTUOXF_9)^$7[7WB[XT:C>R1WOB#2/`OP+_:F^)FC?#(ZB+.XET;^SO%'Q
M"\6Z5H'A^UT[5KIK&PU3Q!=PQWMGH217?D/_``0&_P"#:_QW^U+I'P=_X*!?
MM3_$#QG\"_@]:>*]!^)7P`^'G@BRL=-^,'Q0;P5X@@UCPS\2=5UGQ3I.KZ9\
M/_AGJ'B#1K2X\,+_`,(WK/BCXE^&UN/$F@W/@SPSJ'@OQGXJ_MVU+_@G9<:+
MXZUWXO\`PD_:C^-GA?XKZSX1\.^#KR?XF:3\,/C+\./$6B^$-=\8^(O#&C>,
MO#%[X*\(_$9?#NF:K\0/%MW)I?PI^,OP@O\`4I;^R74=;N+?1M+M[;_&_P"F
M_P#1^\4N./$KC/Q"^CIFG`V&S;B_PLS+A'C/+N)LUSC*H9SQ;3\/O%SPERW-
M\"\'P_FN5U\=0X$\8,RI2Q^/Q%"C5S'@[@S+ZTHY=2Q6,P?Z%PUF^!PV"PN%
MS:GBN7#9A3Q6%JT:5&KRX=8[`XZK1JQJUXSA#ZWE<&J:HOGHXW$58S;=-2_Q
M]_VCO"^J^)?BA^TC\:_"'A74;?X*C]IOQKX3T[Q(QL'TG3]8\<Z_\1?%_@KP
MG'=60M[/4=1F\(^$M=U"=M$MGT^PMM.MY+H6$>L:)'>_,]?UN?\`!:WX`P?L
MD?L??!?_`()U6/A?X?\`[*GPQ_9,NIOBIXU;7/'^F_$?XD_MS?M&>/?#7B3P
MQ\-_BI\&]!TJPTKQ[XH\)SZ99^-[OXK?%OXI>'?A7\//ATVLZK\&OA_::CJ?
MP5\*?##Q)_)'7]^?1=\1L]\0N!,VCQ#PKCN#<5P;Q3FO`^79#F3^M9GAN'^%
MXT,ER/%YYFV#K8W(<;Q!GV"P,>*L=@\@S7-L)DF"S_*LKQ..KXZAB*M3Y3.L
M)2PF*I^RKQQ$<10IXF=6'NP=6M>I5C3IR4:L:5*4O81E5A3E4E2G.,5%I(HH
MHK^E#R`KO/ASX"U?X@^)])T>RT7Q3J>COK?AZQ\3W_A31I]8OM"T?6M7M]-E
MU`JJ"RMKCRY+C^S3J=S9V=S>Q+!)<Q)YDB5?ASX(U3XF?$+P'\-]#EA@UKXA
M>-/"W@;1YKA))+>'5?%NNV&@:=+<)%B1H([S4(7F"$-Y2MAEZC_50_9L_9S^
M&_[*OP.\!_`SX0Z`-&\!_#O1[+1H9Q!']MUG6+B.6YU;Q-XDO8(HH[[Q1XMU
M./4==UB\=8S=WTUVUO%#:P1P0?YR?M`?I\Y7]"_*^"<JPG!4^/>,?$2.=5,)
ME\\_7#F"R3(LI^J8;%YOB<<LGSNI7Q>)QF84,)E6"C@X4ZDZ6-Q-?$*.#AA<
M9^N^%7A76\1JV9UJF:PRG+LI>%A5K?5OK=?$8G%^V=&A2I.OAX1A%47*M4G4
MO>=*%.G-SE*E^%GPW^&OQP\+_!;PA^QI^Q)\1/'_`(3^,?B;XO?MF:7\.Y'T
MOP'\/[/6_AWI7@GX<2?`#]AN7XB?M.:WJVE?&KP)X3\875[^T;\9/A3\??"/
MAK]H/1?@YH7[07PH^%OP_FB\':]HWCC^S3]C2VUKPM=?$GX7KK%EXC\.?#_2
M?A5!XHU#0]4\4:]X%\*?M*ZIX?UD?M$?"GX3:QXLG&H+\*?"4^F_#_Q;H/AF
M.SF@\#^)OB/XS\(+JMF='_X5W\./PZ_:+T/X"_##X;^!/!^I:=\//!\OQ6_:
M\^$5M\-M.\0#PM8Z-XE_:2^,?[0FF^,&O]1C\6I<:3JT?B+Q!JGB[Q1\3K*[
MM=576?ANOC_3KK1-:T6:[T&[_J/\/^'O#?@S0-,\-^%M#T3PIX7\/V$5AH^@
M>'],L-"T#1-,M$VPV6F:5IT%KIVFV%M&,16UK!#;PH,(BJ*_&OH;_21SGZ3W
MAOG?&V=<)PX8KY/QCF/#6'KX*C7H93GF#PN!R_'8?'82EB<1CJM'%T:>/AA,
MTP\<PS"E3Q='VM/&2CB'AL+U>)O!.$X#SW"93@\S>8PQ.54L=4IXB?M,9@JM
M7$UJ?))TE1H^PE["H\/)8:BZD)3=2BJL)8C$?C-_P7W_`."<_@O_`(*'_P#!
M//XNZ%>"32?BM\!O#WBO]HGX,^(=)TJSNM:U'QW\+OAQX_N=(^'E_>.8KP>$
M?'JZS?>']9MHYIHK.XOK+7X-/N]3T>Q4?X]*L'574Y5E#*<$9##(.#@C(/0@
M'UK_`'E?B+#]K^'OCZU;PZWBI9_!WBBV_P"$7,'VL>*5FT&\4Z$MK%>6<EPN
ML&0Z6;<WEA),TS1K<0*Z7%?X/.IZ5>:#J6I:%J#Z;)?Z)J%]H]]+HVL:+XBT
M>6\TNZEL;F72/$'AN_U3P]KVE2S0/)IVM:#J>HZ+JMFT%_I=]=V-Q!/)_HOX
M3XJHJV;X%SO2=+#XJ-/?DJ1G.C.>D_W?M8SA'WH/VWL?<FO833_*<=%6IRMK
M=QOW6]O.VO72^NZ*5%%%?M)YQ[7^S3\4-+^!_P"T?^SY\:M<TS4-:T3X/?'+
MX2?%36=&TEK==5U;2OAY\0/#WB_4=-TMKR>VLQJ=]9Z/-;6!O+B"T^URP_:I
MHH/,<?I[X-_;`^.O[=G_``5+A_:"D_:^\.?L*VMQJ'B"[\-?%3XD_$.STWP1
M\!O@5X.T^34K/P!IFB>)=3M]$^(6K:_I^DVL=_\`#*PTY=%^+GQ.UW5M7U3P
M_INDZQK%QI?XKU]7_L??$']ESP+\2]5M_P!L3X+^(OC-\$/&'A2\\-ZI'X#\
M07/AKXF?#O7EU;1M:T7XB>`+R#6?#UIJVK62Z3?>&-1\,:]K5EX?U30O%.IW
MUUY^I:/I$+?@GBQX:\"UL9G?C%FGA97\5N,LI\.<QX!H<.8;!Y/G./S/@K-L
MWI9EQ)DF49'Q'C,!D&.QN94^:I7H8W$PK9CA\''*L+)RQ=3#8OZ[AG.L;1JX
M+(Y9K#+<GKYUALTQ#K8C%X+"_7</2E2PU7&8O+Z5;&TJ$6U!U*=*I]7<G745
MRRDOZA?B1X[_`."1_P"WG^T)^S=/?_\`!27]KS]HG]ICX3_$CX90_!_0O&OP
MMT_P]\)O'^J1?%_PM>:OX2@\!^#OV8OAI\/?#UQXM\.:78V_BSQSIMMHVHR6
M6@:=JFL7/QBFTG2M%K_21D`QO,7FO%NDC4!-^_8Z_NC(R(DCH[QABZ##LK.J
M,QK_`#P/^"9'Q$_X(,Z1^U+^SO\`"+]E?4=(^%/BKXG?$WPAXL^(7Q>^/5UX
MUT#6+;1_@]KR?&?P9\%]#\>?%F^N/"VEZW\5OBAH/@+X::CX/\,R:5X=^)'@
MJW\0:7K6L^(/'</P\L?$W]^WP^^,WPF^+-YXILOA;\1_!OQ'?P3>6.F>+;KP
M+X@T[Q7I7A[6=0AN+J#P]JFMZ%/?:/:^)HK*"/4=0\-/?#7M)TO4=#U35-.L
M]/\`$.A7.H_S/X49_'B#A64\N\`LW^CIPMDV9XK(N%.!<]X4CP%F5?*L+"CB
M:V=+@?#5L3E_#668O-<7F6$RNA0K/$YG2P%;.L9"E_:%""^JX]Q$<3FV'JU<
MRX>S;,*F!HU<QQO#-?&8O+G5FY>QP\\;CL1B<1C,7AZ"IPK595:OLZ<J.&E6
MG4H3C3^*?^"O_P`8?"GP+_X)D_MK^/O&/Q(UCX4Z8/@#X\\(V?B_PO):0^-D
MU[X@:3+X'\/Z'\/[B]U/2(;'X@>*-6\06GAWP9K/VS/AWQ#J=AXC-M>1Z2]I
M-_BK1IY<<<><[$5,XQG:H7.,G&<9QDX]:_U2_P#@Z:^$W_!1[X^_L-+\)_V-
MOA5:?$;X#2ZSI'C7]JS3/!\TOB'X[>+-&\':[8^(?`GA?P+\.TTNXNM:\%>'
M_%NCZ9X[\>2^%+B]^(=]JND>"(-#TU?!NF_$9-2_RM@00""""`00<@@\@@C@
M@CD$=:_KCPJPN'CA<RQGMZ<\74K0H?5E63J4,/"*G[6=!-.*Q-1\JJ234EAE
M&#351/\`-L=)\T(V:BDW>VC;Z)^2Z>>O06BBBOULX`HHHH`0@$$$`@@@@C((
M/!!!X((X(/6O]Z_PWX;\.^#?#N@^$/"&@:+X4\)^%M&TSP[X8\+^&]*L="\.
M^'/#^BV4.FZ-H6@Z)I<%KIND:-I.G6UO8:9I>GVUO96%E;PVMK!%!%'&I17X
M=XM_\C'A[_L"S?\`]/Y6>E@/@J_XJ?Y3/X`_A[^UC^U//\)_"7BZ?]I;]H";
MQ9JO[;WACPCJ?B>7XR?$63Q#J/A0_%:RT0^&+_6G\1G4KSP\=%)T@Z+<7,FF
MG2R;`VWV0F*OY[?^#A?P[X?\,?\`!8/]KRR\-:%HWAZSU6W_`&<?&FJ6FAZ7
M9:3;:EXQ^(O[)?P'^('Q!\67\%A!;Q7GB;QUX\\3>)/&WC+7KA)-4\3^+O$.
MN>)-;NK[6=6O[VX**\WPP_Y*2I_V+,5_Z>PI>-_@K_''\I'XOT445_09Y1__
MV0``````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]B86)Y+F=I
M9@``````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(S-#<@,3`U,34T,S,W
M-3$@,#(S-C<W`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$=)1C@Y81T`*@#W`````````#,``&8``)D``,P``/\`,P``,S,`
M,V8`,YD`,\P`,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`
MF?\`S```S#,`S&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S
M`&8S`)DS`,PS`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS
M9O\SF0`SF3,SF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S
M_V8S_YDS_\PS__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF
M,_]F9@!F9C-F9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-F
MS&9FS)EFS,QFS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9
M`/^9,P"9,S.9,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9
MF6:9F9F9F<R9F?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9
M___,``#,`#/,`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,
M9F;,9IG,9LS,9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,
MS/_,_P#,_S/,_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_
M,V;_,YG_,\S_,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_
MF?__S`#_S#/_S&;_S)G_S,S_S/___P#__S/__V;__YG__\S____XOR0`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````A^00!``#8`"P`````'0`J```(_@"Q
M"1Q(4."*@@@3$CPX<`7#A@H5/L0&`,!"`!,C&G1HT")$C0XY-F0X,6-$C!^Q
ME329<`5*E1L7:BP8\J`5@R-GML0)LZ=.A`=)JF3YTR'&)RIJBBSJ4`^@4L]6
MK8I:BA0@/4^(CM0S]9G7KV"?E=)S4V(54F'3AAUK<@574FC5AB4%=96>DE:F
M8HTKURLI/7'O#JPRU2Z@KE[UZ($Z=W'4*@;C_DU;905?L(``^3U8Y6OFM%<O
M?YT<M:EGS7W5<O7Z!(">TZE5QW7YVNOGV&$_KW+8V6]MW%\!/R.E`MN3KF.!
MCZX-*"CJ9\*!CPT\T`ICTK'_2H8\<+7AU'\!Q5LEQ;UA%<7A24F%:_6J\%+G
ML])<`:@*U/"*G<)%;#=\68'HZ7$68G+]1=A5$UFQ&"DKJ/"$?J5$"-=5\EEG
MU7_8*/C74!4I9=1+5@""H4!/8.B0%5>DF&(75ZQ0XD\J57%>(*TD4N.-7>3W
M4Q69Z4%C(D`"V4H79XTUDV6/=1%DD(C($%=S&A%FFQ4V!CFD%:-IA4UO8EF!
MR)*M7/$;E!%9Y]5N5W@A"")L*NB5D3/E-9R'#AT'W4]6J*>'1(O!N&5Y?@8$
M`#L`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]A=F%T87)S+W=I>F%R9"YJ<&<`````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`Q,30W-"`Q,#4Q-30S,S<U,2`P,C0R-S8`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````_]C_X``02D9)1@`!`0``
M`0`!``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!`0$`````
M``````$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#``01!1(A
M,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W
M.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3
ME)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'B
MX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0````````$"`P0%
M!@<("0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B
M,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'
M2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:
MHJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ
M\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#^?>[M+6_M;FQOK:WO;*]MYK2\L[N&
M.YM;NUN8VAN+:YMYE>&>WGA=XIH94>.6-V1U96(/E?@M[OX/V7B+P=8?&._\
M>:7\3]2TSQUX\^#VB^$==TK5OAG%\$;+Q=X4\&?$7XK:O<:1X2^&^L:)IWPR
M\4^)]9\&W_PTO_B1+X:\%'XIZMX[MO@_=:7J^B^)O7*VO@[\-?@KX:\4>%_V
MEOBU\$_"'Q3/A_\`:L\!1:;X5\0_$#1;_1/B)X7^#,'@?XF?&GP7XR^$&JZ)
MK<E_8>(=,\2?!#PMK-YK]G<>"=1^'OCOQ/X?:UU?4_&5G=_#S^YOI,+B3!XW
MPCSS@V&)J\3X#C>6'R[#87`8+'?VD\7@9OZCCX8WV*EE2=%XO&4\#C\!FKAA
M^?`UY4XXS#ULN"'E\UGU#-,)'%8-Y4\364L36PLJ5*A6A"O4HUJ6'Q<*6*C1
MKSGA:N(PU?#_`%BG2HR@IUJ=6G]A?$;_`()Q_MH_"2_L])^(_P`$;[PIJMWX
M3TCQM)I6H^,_AP^IZ1X=\2^*)O!/@^;Q/I]IXQN;OPCJ7CSQA::EX8^'7A[Q
M3#H_B+XB:[HVOZ7X(TK7[S0-:BL/9O%7_!'_`/;:\*>"[;QE=>`M/O5E-Q!=
MZ+8:C<2W.F:C9Z2_B:[T[5?$+6"^`]"N+?PD(]>V>)O%VA37<K/X>TR"_P#$
MSV.DW_R_8?ML_&;Q-\1/#W@OPQX0CUSQWJ%_X&\9^)?#7AV-M9TGQKJ>E>*W
MMM%U70?"MQXTTCQG\,?"6D:7X+^`_P`";FP\&^-?#5U;_#CPK%KUIXP\5_$+
M3-!T6OZF/^"8TG[6/[67Q"\>?"GXT?&GX<:E\)?#6M_#']M;0=7^"ND?$C5/
M`6NW/C*'P/JOP&\%>"]1^,%EX7\8:C\-OAW=?#W3O%?AR+QCX>TWXP_#OQQ\
M/]'N?%NJMXMUV]&A?B>?_2>\:,BS_*LGS[(^#\DQ^#G5P7$64Y5@L\S>-//J
M-?$PK8.KCL7*E&MD*HX95<+G&`EA*N)I5J->K'#QQE*CA?5PO"_"^)R?.L30
MQV85L1A\1.IE.-Q53"X/#8O+J4\-!*>!I+%XJCF==8F$H86I5EAW)S4,4U@,
M4Z_\</B3PSXA\':W?^&O%>B:GX=U_2Y(XM0T?6+*?3]0M&F@BNK<S6MRD<JQ
MW-I/!=VLP4Q75I/!=6[RV\T4CX=?Z-_[77_!(#]EC]H7X,>)?"^LV?C#0/%V
MG^%WM/`/C_PA+XKUWQ#X4\1:1JNIWO@?44\!6_B:T\)>-;.VAUW5]"\5Z)KN
MF0C6;'Q!XFU_P]XB^&7BG7=;\92?Q@^#/V#/'7@SXN>,OAS\2M-CE\4?#OQC
M?^&]0%E'>MX>U#^S;R2+3]8T.YU33=.U#4M)\2VZV7B'PUJ9TRW_`+0\-W]A
MJ<=LJ7#Q5_1O!?TA,IXIR2;EE.(CQ?2JTL+#AS!SJ5(9C4J4DUF&&QE2C[/"
M9;SQJO$QKNOB<`HPHI8ZM7PGUKX:OE%2E4NJD5A]&ZTW%.%VTH.'-S3EM9Q2
M@VUS.%]/SJ3PWKDB)(FG3E7574DQJ2K`,"5:0,IP1E6`8="`>**_H^@_8X\*
MM!"UQ]F6<Q1F=5=PJS%%,BJ!;R@*'W``2R@`8\Q_O$KZ5YKXUR;E#(>"XP;;
MA&<LUE.,6TXQG)9C!.23M)J$+M-\D=$\U3RS2]3%7TO:=&U]+V_=O35]7Z[V
M_FEJGHGB>WTS6_'WAJV\.>#IM1\1^%/`K:EXJOK+6M7\:66C6GB/Q/>V^BZ0
M=5U"Z\&^$]-NM4TJ"[&O>&=!L/B'J2IKWAZ\\41^"]3UC0-<N5PWA_3SIWC#
MQ\SW&G/+KM[H7B`6MO=RRZA;V7_".Z;X;M+B_M)+>-+87M[X;U>.V,,\T,D5
M@'#F=[F&U]_Q"PN#QM7@'#X^BIX9>(N08I8B5.=:&"QF783-LRRJM*E#63Q.
M:X/`Y92J2:AA:^/I8R5UAW%ZY/7KT/[4EAW'GJ9-CJ$H/E4ZE"O[*EB52DX3
M<94\/*KB)\DJ4IT:-6DYNG4G2J;6H>)=2\`^)?A_\1M`M[Y?$/@_QCILUGJ^
MF13M>Z9INH[K76;>2XLIX;ZSL=8A6#3A?Q0ZA!H.M2:%XMNM/9?#:7UA]/\`
M['W_``4%\6_\$I/B!X=^(-MI.I>,?``M/!/P;^*?A>R>TU^-='T3QI\1M>T&
MWTS2=>\2W\,&O^!/!NG>(-/B@O;JS\/ZWXHM-,\375AK6C6/AC4[;Y-\>^'Y
MO$7AF_MK$$:U9QS:CH$R)`T\6K0VMQ"D4$L]Q9?93J=I<7FB7-U;ZAI=Y#8:
MG=FSU73+DQ7UOXQ\9_%7CNYT:ZN?$>DZ2]R+SP9XM\2S?VS>73I)H-[X=TG2
M;G0-7N+2QOX/%\^I#Q!;QWFD3RKH/AR:ZOK>PTB+7%T:Q_DCZ3G#6;X7C#&<
M5K"8BCD5;(,JJ/-:<*LL'+,\/B99?_9V(KQH>SHXVM%X.I1H2CBJE7"TY5Z5
M2E3I8KZK[W"E&&/K8++XU(JO6QCH2IR=*+E1K.FXQA*KB,.FZM6T*476H1EB
MOJT'[64XTI_TH:/_`,%3?VQ/^"@WB;X=?M<Q^"OCIX<\:?"_XB>-/VJ/V=_A
M5H_P^^*GCG]D?Q-X"^`'A2^\):9\(]`^']_-X/\`A]\8_$7AOQ]XMUK_`(7G
M^T?JFL:7\2O!WB+4+Z_^#?C#2O%D/[//[+6G?JO'\:_AW^U1XNUC]IOX=6]M
M'H_Q3L=$UZY+-!)JUMKNH:'IEQJFD:[!:^(?$VG:/X@\,(\/AK5M)TC4I;2S
MGL7MKB:YU6+5+R\_";]@.P_:&^!7[%OQM\2_#G]GKQEX`^"FL>%_$^O2?M!Z
MCX'\9>#=/U[P[I_PI^)6L:5JVD>,;C2HM`\76\>M:/IMGX`N_"&L"\U@?%5K
MC4-'\/\`AOQO\1/&WA3[T_X)I^(=)G_9SE^'MHUM%JWPF^(WQ&\,ZO80W]EJ
M36L'B#Q;JOC_`$/R+VUOI9]1TRTTGQ9!X=LM3U#2/#>I2W/AW4=-U;29];TG
M5=8U3X3Z*5/!4_%.M&CF&-Q3Q-+/\1B*./QF)Q#PN.GA,NQD,MPL,1*U##4L
M.X8VAA,+"&#IQBZM)2J>TG/T.+I8F.#PE*O@\/A'1P&#H4I4,)A\-+$T*6*Q
ME-XK$3PON8G&5:BE1Q-?$.6)2H4J-5\T/:5OT'HHHK_3<_.3_-_\(_M-?%3P
MI9W&G2WUGXFMDG:&"7Q?#J>J76G%+R(W1CU,7&CZC=1S2ZC(-GB+5[I[.WAT
M^TBFT^.`1ZC[7X2_:&U#4K?QU\3+SPM"U[X?\)_#?0;[1;+5)+:TU*[N_$6K
M(VJQS2Z==:G8VIE\32&TTY[+66B6#R[34;[[7<W4/R/XW\!W7@36((8KW3]?
M\.7WGW7A?QGHTMO=:/K^GVVM0VTK6^I64\EJNH:7+BUUBW:^T^[TV^E:V.H3
M:;)I5SJ&G9:7>V7P<U#68[LHFM?$;0O#=WIJ!R@GTG1-:O(4U.S@F1I(Y9+B
MVO%M9--N3+>Z1;W%P]\\Z06'^4F9\?\`B9D?U7A[,^),VI3R'.,GQN#PN:3H
M9E/"XW*L72S'*ZU"OC(XMU\-[M.>%=/$5\!B\%5HQC'$Y=4A"7Z[A\#EV(<\
M7AL%3D\3@\1"K+"*5"DZ&(2PV)C.-*$(1<57G*2G2I5%[&<8RHUXPY?OSX9_
MM,^!O']Q8:1?I-X3\2:A-!:VFGWTWV[2KZ\NWO\`[-8V&NQ6]O&+UH[.-/LV
ML66BRW=_=0V.BKJ^Z.>7LOC_`/!>77_A]H'C/2-.TC3]7NO$FHW&M7KZ0]SK
M.M^%=-CT'18M3M[[3);K4#%H%Q=ZWOTC^QIIM;CL#'+J-A<:9X5T[Q)^0Z(`
M!(S1HC;(F:X^T-(D)M&N+<2W`DMIA&]HSZ?-'%'!%=6RA]-MM0GC!A_H<_8<
M\):+\39?V<_A=XD>Z\.>#M)\//!XFT2[N-3LM+M7LO#%WXW^)\,-IIFM^%;C
MP1=^-;/P_`OC#Q@VK2^(M3U2335MK>Z\.>'/$_A]OKN*/&C/?$+@A<'<28?#
M5<?1S+"YB\\PF'E1Q.,P&%PN+IXG#5,%A\/+#4LQKSQ"I4\7@I8*A.G56'EE
MTX2K1Q'G83!U.&LRP^;9;6E3G[]-4_:1DJ<E5I5+I5).4Z$H))T\13Q$823?
MM9U(TYP^LOV(_P!HC2M+^&/PR^$VF^./B\/"OA"_TCP]XU^&WQB&NVXTRUU:
M]LX_$RI\/(H;7PWJT6FZ=>ZMX!TYT\/:I,NELT82]\11Z7KZ_IS_`,$IO#4%
M[XT_:*^`&N>,]1N-5T*70O%7AC49O"DF_P`0Q>&+71O!NO\`Q&O+_P#M:]2*
MR\?^&]0^&$^D:1-XCUZRUBTL(?&GA+5;6*Z\7:=J7YI_';X:+\#_`(V>(WTB
M:[?P?XP\::?9P3/%XDDT_2=:U"PT&_L=(;[1JU[%<N;+Q7J%A?RVC'2;.^O?
MA[,NA:)96UU)7T=IOQ8UK]EC]HGX$_M4>'[DVFE?$;PU>)XWTGPX4U[5]5TN
MPFL_`_Q'L8K"?QGIL=_KGB?0?%GA/2;B2\\2:IJ_C[XA06#^*M*\`SZ))<7'
MY-P?F&8<&XW#YMEV<8^CG.`Q&.Q.%Q=2=&H\-.I0KRI4*4L92JX;ZCB(4:.$
MJ8>M.A*I#%8S+H1KX/$QCB=L[QL,^Q3J/`X3`*=+#4\3A\#1E2P]=TJ4%+%U
M%24^:=7FEBJ\:52K.-:G&KB8K$TN8_HGU7]E'XW:7JFI:8-!\+WPTZ_O+$7L
M/Q.^%]A#>"TN)+<745CKWC'1]<LXKCR_-CM-9TC2]5MU<0ZCIUC>)-;1%?L+
MX*MO@/XZ\&^$O&W@SPOX]U_P?XQ\,Z#XJ\*:]#IWQ/L8=;\->(=*M-7T+5XK
M&_FTV^LX]2TN\M;Q+6]T[3[NW680W%E:S(\$97[,_I5^(,&X3ED//%\LKU<+
M!\RLG>#RN3@[[Q<I.-VN9VN>'2R#`3ITYNAQ(W.$)-T^&L?4IMRBFW3J0Q,H
MS@[WC.,I1E&SC)IIO_'[\(^']!7]HSXH>"UT32%\'3^$[2:?PF--LAX:FFL+
M3X97]C++H0A_LN22ROM5U2]M'>U+6]WJ5_<PE)KRX>3W6WTS3=$_X)5?MWZI
MHNGV.D:G<_\`!0#X7_#>YU'2[2WL+ZX^':Z3XE\4KX"GN[2.*XE\%KXG\%>#
M?$8\+22-H8U[PEX9U<6/]H:#I5Q:%%?G_CA_R1W`_P#V<BO_`.O1S$^LX>_W
MS.O^R5C_`.LFS\;;UFBEC2)FC06=DP2,E%#76F6@N6VJ0-UP.)SC,PXD+"O[
M5_V+?#V@6'@;X5:W8Z'H]EK2:EI$Z:O::996VJ+/KD7P@T[6IEOX8$NUEUC3
M[FYL=4D$H?4+.XGM;LS02R(Q17Q6$_C_`/<AF/\`ZCUCAQW^\X7_`+&V!_\`
M3N6B_MT:CJ%W\$_B+<W=]>75SIOB2/3M.N+BYGFGL-/U/XJ?M#Z3J5C92R.T
MEK9ZAI7A[0-,O;:!HX+O3]#T>SG22VTRRC@X#]MB^O=(_9!\(C2;RZTL6_QK
M^#R0#3KB6R$*2_LYP>+94B%L\7EK)XJO;SQ-(J;0_B"[N=98'4IY;ERBJJ_%
MC?\`L$PW_I^N>77_`(>6_P#8PQ7_`*@H_#&;POX9N)9;BX\.Z%///(\TTTVD
M:?++-+*Q>2661[=GDDD=F=W=BSL2S$DDT445\>]_FOS@?K^'_@4/^O5+_P!(
MI'__V0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O879A=&%R<R]A;'DN:G!G````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,3`P-#4@,3`U,34T,S,W-3$@,#(S-34T`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````/_8_^``$$I&
M248``0$```$``0``_]L`0P`!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_]L`0P$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B``(1`0,1`?_$`!\```$%`0$!
M`0$!```````````!`@,$!08'"`D*"__$`+40``(!`P,"!`,%!00$```!?0$"
M`P`$$042(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B<H()"A87&!D:)28G
M*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@X2%
MAH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35
MUM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$`!\!``,!`0$!`0$!`0$`````
M```!`@,$!08'"`D*"__$`+41``(!`@0$`P0'!00$``$"=P`!`@,1!`4A,082
M05$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X
M.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3
ME)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+C
MY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`_%KP/\1)M,AL?#WQGT+4
MI_"5L%%SXCTZVN[\6%C.RB&XDO(2[6UI&88Y8KAPUP#$=NW9S^A?PZU30M&M
MSJWP8^*O@[Q[IEP+.XFTS5M8MM-O[_#$>5K>C:JEJUQ<6\,KP:?K>G7/]JS!
M[E+O3=95;=;/Y1\`?!WP;\*=+74/C+^W[X.\"(K)+<:7KWA*&XBDMIDW2Q)8
MM<S37[OO@\Z&&'>3Y0;DICZY\/\`[1G_``3:L/"=KI6D^/?@Y\6_B9IEW&;K
MQ-HO@?5?!&I:C!$':!)++4;2-+FXD)9D>"XF#&++JF8L_P`0<8Y>\=&IBL@R
MK-\SPTJ\O:?V/E.88K)JU23UJ5J&8Y/1I4YSJMTW7PF9/EE=<K<73?\`I+DO
M%]'"?5<ISS,Z>!QKJ*BLKS;$Y)5S.G"F[PC4Q."S&M"K3C*,/9NM&-2E!4X-
M^Y8]V\1Z7\#?B!\,IY/$W@:[\,^/[=+N>PTIOM>A7#W\ET@.H:!K\*V>BWEC
M,T47VM)["TN;F,VBWT#`0FOSSU7]C^5_#^L_%/XD^./`OPFL[6WOIK>^T;Q'
MI$OBVYM(II#;'6;`ZEI7A^6-XT0>1#>6MY.IG"P7;*!%_5O^R5J'[/GQQ^"J
M:[X:T/09DL;>&VGMA90*;*2VACG#268F@5R9@$<!',PE;S`,_-_*7_P5,\%>
M+X/VUX_#'B']F/QO\6O@7H^A-I>A>$O#/B-/ACH'B74==2ZN&\5#6K.6[AU+
M6;.\G@^SB\LYVCCTQ+>1PKQ@+@7(<\6.PU!YWALDR_,Z6+K8O&8CZIB*N6K`
M8C#2Q&7T\-F6(P^$A7Q59S@X8FI4I*,*E>5#$/DH5/$S_P`0XTL+G&#P^0YA
MCLQR_'X>.&RZO3KXM8RMBVHT<5"6$PN,Q5*A2IRI5XU,+0J<].=.G*=*FZE6
MGT/P'_X*`_"'X.VUAX?OM?\`V<?B#IVFH+5O$&FZ;?>$]>6%)#`TFKP#3]1N
MIY$\U3>7:PR6B2^4T4\WF;E_72^\&>!_VL_A8NM+X=T72XK[3S-X>UO1Y9KF
M2\C\H26S/=WEG9W+PHSJ8YA!$)T=0V[RD"_A?_P3[_X(]?&#XR:C<+\:M+L/
M@=^SM-XGU+6]?:WATZ[^,7C32H6M;6W\!:OXS>&#4(_"L!TY9+K2M.6TTN^N
M+V:[O+:YF,+1_P!1]EX:\)>$;32/!GPTTJ#3O!'A6PL_#?AZVM-R0I8:9%':
M(DDGR+<2NT!,S*H4MC&>W-XCY)PCE6(P=?AC.L3C\RCB95\95C+!.@Y.//'V
M4L#"EA.?VCC*HL)"%*#YZ?*K21Y7!O%O&&9RK8CB/AZAP]B:5/"3PE*%3-)X
MCV+E.4Y8ZEF.(;C#$PE3A1I5,,G+#PJ3C&G#V4I_SF:I^PI?1:GJ,4FBPRR1
MW]W&\K:;`[2NEQ(K2,YB)8NP+%B26)R3DT5_2V?#NE2$R2Z#9M*Y+R,;>W8M
M(W+L6*9)+$DD\D\FBOEUQWQNDDL6K))*\%>RY4NF^WX;Z7_2?[<R!ZRR;+')
MV<GR-7;Y+OYMO[S_`#DK;X>W_B/1O&FB^*/AK\7?%7QGU;6-,O\`PEX[T0RZ
M_P"'7TV,2KJ.BZFE]$DYCF6YM7@OK>;S;`0.ZF,LA/MGA_\`9J\76NF>%;CQ
MU9Z7X6TW0]4U77]&\*Z5;3?VE:WNJQ:997(U?Q#<E]4N8FETFRN4M);A[>UF
MFNFA`:>0GZ*^#OC_`,4>%K*'4-#OIM:T35=/2:V@MG68V\%U#M1EADW//N&^
M(+`R^0L(1\JZ`>RR3:CXQMGGA=&GCC@%W;W#RV=XB$RO%$();<ED5ED(19"B
M$9PN0:_L/-.+LVPF*5%4,MP6"IMP>+^N5'55>,%14*6%?*J&B]G-)R51.516
MYG;^7>$_"3(,TP\<UKXO-,VS.JJ;A@9OV5%.I5CBXU:]6C!RS.H^955.<X<D
MN64H\T)1?[#?\$2_B7J.D>(O$'P]NM4F>TNK%M3"M<RD/+#.+>3R]\F^1581
M;V8<X2OZ#OB]\*M$\4Z)-J,FF6FI:WID$TEF$L[>8>2TAG>VR8F(65L,4!`9
MMS$$DU_*%_P34UYO`W[1>BZA>I>0V^IV>K:*VZ(R1*\D;2QAE7(D02IYFUU`
M60*X&>1_71X8O/'OB/P_I=SH5M#I$%S<6;SZEJ\`D>[M()(&G,<4H+$W,0D2
M-^RM(`<,:_#,^CEU?-\_P$J4JU/&5:.8TZ=&E[:U;'PC>K>$7&$(5TW-[O=.
MZN?H&<X?'9;#AK-L/66"Q"RZC@:D\16EAW*I@:M>@Z<OM3;PZA32U<N1)]&?
MFC?>)_%MYJ;^'K2WN-'LDWP7,3B2.8L&`=4`(VKE<D#`.X'!QFOKOX,_"A=9
ML(GOYY1%''&4=@5(*F9PN3U"LS,H'"L[D#+L3W/Q!^"6EZ[XJAU71-0M]+U]
MG+74$D@2QNG:260.L$:D`[-_GA0N1Y`?.Q-O2^"-0UKP=+:>%O$]D^F37#7$
MNEW$S)##JEHA`:ZM]S_:9(=SKM*@*H<8ZBOS?!9/B,%FT?[6H*6"@_94JL%S
MX;GD_=C*45RPDN973LU/W=[GJYEQ%0S#(Z,<AC'"X^K1C7Q>&E24*T(\E.=2
MI3NVY1J\GM%K9PE&5HI)*"3X<6\<CQ@L0CL@)4$D*Q4$G'?%%>Q%XF);*'<=
MV1-<X.><C+=#17U;RC+KO]S#?^:7>/GY?@K]3\]6>XU))UY75D]([Z7_`%_I
M,_S2O^"?/BK3-6\3CX.>,&GT[5M,NYM0TFWO)&B-]I)N!'>6UI-(05&FES<6
M=DA"&"Y'E(%7-?UF6GA#X>>$/@5XDUB/P;H&LWNGZ%-_9DUQH.F:G=2R_9]X
MNHB]K+<1>9%"A8Q%6#%V)RV:_C[U?P9+_P`)C!XY\!ZG<^'O%_AO4K#6-#U*
M"'?YP2./*70&T'3)U<V%[;,V(HQ;J(RB8']-'[#O[6?AWXL>!)_"'B]/['\:
MZ99MI7B/P[?JD02Z6TEC:XL'W+#<Z5?+NDM7PY*[XW`"@'[CQ^X(X@PU7`\4
MX7"XRME%*4GFF'I.HJ.%KQC&4L0U1O4E2G&TI2=^6M)QNH)GF_1Q\<N%>)LC
MI<&//<#2S_"5*.,RZA4Q5"AC<;A<5+#S>#I>VJ0C6Q6%?M8>RIR3G"GRQ3D[
M/YG_`&:/C-H'P]^*6E:SXD^&UJVDWNH77VW6M/AO9-4M9)FGEBFLM/F)C1K1
M)!'(T1B\M)(U.5(`_H=NOV]-5UO4?#/A;X4>!;77+!-*L+=];UW5(4ELS+:I
M#]GT[PSIBM>76HY<O&F\"*15+<S&OY,?VL=$^*_P=^*?_"9_#G7#=>'['Q*F
MK:IX.U"*TNO"NO:-,6^U:)J\<4;S65O>V?VF.VU"T426=RL3Y5_**_I9^Q__
M`,%6?V>_@1\,K_\`M#]ECQ%9_%6TU)M>\+ZK8:K::WIT3HT<[6BZM<D:Q-:0
M1M#'$M[+</.3(JHOV8@_/5.'LTQ^%PO$7#F(C2P.<82E'&ULOG5Q&)HQP\:U
M?ZM4P\XRK.;@HM5*48TXQ3<VHIR/WO-L5PYF&95\IS+(<[SK/,IES91@JE7`
M8#)<=0S*$53Q5/'5,714/J^*M#%4*T'6E4G.E2I8J+5&O_1JOQ-UGX5?`#XH
M_M&_$KP[?:+X4^%_A+6_'WBFYU2UMD\9ZKH^B&UMK[2?"?A8SZ1"_B.[:[4Z
M'#K6OV\.ISK]E:PU&27-K^4__!.K3?VH/VDGN/VXOVG_`!QK][XA^*FO:B/A
ME\+H[J]MO`?PW^&VDW!LUM/#/AES]BTI)+ET-O<D7&HWD44=]<7TXN(MORUX
ML_:@_:;_`."S7QM\&?!R7PC_`,*<_9F\-:I9^(/%?A;1]1DU._UR>!X;V;6O
M$.II#;BV$MS;6SZ5IK27&R7[3*%B>U0G^E+P=X$\.>!]/\.^"O#=BFF^&?!G
MAW2?"NC:?#'$EM96.FVT:BV18E2-Q),7N9G"A9))<G<R$U[&9X2CALK>28:I
M/$OVF'6,Q-;$4:M2,HUJ.)5%4:,JE.A.M6I.M6Y*DJE*-'#0K*G4KU::_.LQ
MPM7AG_A2S3#T<MX@SNGC5A,EAA\33AD^2U>6G.I*>,I4,3B,3BY1>'R^K/#X
M;#4\'0S.>%HU,/7R^M3]0AG'E18M(B/+3!:)"Q&T8+'NQ[GN<T5:$%P``-N`
M!CIT[=Z*QC@:=E^[GLNW]W_@_?\`=^8.I0;?N1W_`)I]X^?K]WEI_F<6BJJC
M:JKG&=H`SN))S@#.3USU[UUWA*^O=+\4:/>Z9>76G7GVRWA^UV-Q-:7/E2S(
M)(O/MWCE\N0`!TW[7``8$`445_>'%G_).9I_V!5?_24?XV\`_P#)P^%O^Q]E
M7_JPHGZ5>(O^)F(1J/\`Q,!-H)247O\`I8E0QQN4D$_F!U+HCE6R"R*Q&5!'
MQMX#L+$>.[^V%E:"WMYYI((!;0B&"0&<B2&+9LC<%F(9%5AN;GDY**_A[A[_
M`)$.;?\`895_]*1_TI<#_P#([R?_`*]K_P!*H']4/_!+O0]%T[P+=WNGZ1I=
MC>7=W8R7=W9Z?:6UU=2,-15I+B>"%)9G8*`SR.S$``G`%?JWH;N][<;W9_\`
M2T3YF+?(CRE$Y)^5"S%5Z*6;`&3117R.!_WO$?\`8=7_`/=4_'?&#_DM\Y_[
M`</_`.H^"/069@S`,P`8@`$X`STZT445](?BI__9````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]A=F%T87)S+V-H87)L:65?8G)O=VXN9VEF````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,C$P,2`Q,#4Q-30S,S<U,2`P,C4U-C0`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````1TE&.#EA(``@`/<`````````
M,P``9@``F0``S```_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!F
MS`!F_P"9``"9,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_
M,P#_9@#_F0#_S`#__S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,S
MS#,S_S-F`#-F,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,
M,S/,9C/,F3/,S#/,_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`
MS&8`_V8S`&8S,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9
M,V:99F:9F6:9S&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_
MS&;__YD``)D`,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF
M,YEF9IEFF9EFS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,
MS)G,_YG_`)G_,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS
M,\PS9LPSF<PSS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9
MS,R9_\S,`,S,,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`
M,_\`9O\`F?\`S/\`__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]F
MS/]F__^9`/^9,_^99O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,____`/__
M,___9O__F?__S/____B_)```````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"'Y
M!`$``-@`+``````@`"````C^`+$)'$B0(("#")TH7*@00$&#"",RG.@DH<.'
MV`!0W,A08\.+#SURI"CR(\:2(Q>BK(@QXT02,&/*7`FRH$R8*6EB),'QIL^8
M+!_^_/FLJ%&C)&IB`ZKP9E%2"H]*?082IQ.94$GEV;J5%*FI1T$VY>DUZU>P
M:*D.A"D0`%@G9Y\Y2:NVH%NC9^<>A9I6:4:C<S7BO<MW*D*[1>%2U?N,%&'&
M4TF1&'@P<=ZO<>72E=S6,>"\BI_2;3PYH^?1J)^5-GTW-5K.$%VG=1Q2-EJ_
M;6T;;MD:\,>(NUO^E:O0:^3>M(4/E^T8-^+4S=D@<1Y[]D$VTJ<KAWBP;',`
MV*4?8]>^W2["\./#DR_?%HG[Z>K12Z=N]_U[\$CDS\<6$``[````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O87!E+FIP9P``
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$P-C$P(#$P-3$U-#,S-S4Q
M(#`R,S4S,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#
M$0'_Q``?```!!0$!`0$!`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#
M`@0#!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S
M8G*""0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H
M:6IS='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZ
MPL/$Q<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#
M`0$!`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!
M`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q
M%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X
M>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(
MR<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`.(^
M)'[7GBOXL^/XOA%^S;X<T^^;Q=XIF\)>"M7A>&/Q-XTUR^N8;2PU:P?7#81>
M$=.O(H([V5+TV\NF6I76O%%]8:=!K%G'\S6=_P#'_P`3>*KO2]=TWQ/'KVCA
M[.]U#Q9966B2Z$;G38]0BAU!M:M3%`);"YT_73:7>FOK4^B0L='DL[>_NWN?
MA[X5>.;V3QMJWC73;NSU'7/!?AVT\<>#/"NE>,4O)1XN\/>*?#G_``B^L7]_
MHUK;ZIHNA*\MOJ<=_<?VAJLUUJ@MM'\1V%M'X:CU7]7/A;J7Q)U+X(V'Q+US
MPOXIUWXD>+O#WAS6H_#UE%K.MZL]CJ>C:1;V]WXBU2ZA^W:/?7=];RZ>FEPQ
MQZ[XFU:T\0:K%MU"XT\P_.TO9IM^RC>4H\LG"\JC44[MSBI7ER1DE%ZM7:5F
MSZN4ZU9WE6G[J;<8R2A"-TDE&%TE'FDFVG[NB;;0W3I+?3K==0\0>)O%5SJ5
MG%;"QTK2K.UA\/Z-=>)O%D%LL!U>ZTRYBO(X+>TTW1[)X=$BU>VNM8O-=NM<
MTIKS3K*S[?X??M1O\.I?#TO@/QQXR^%'B*2&*]T]]5U*]UK0QI+Z3*-(NM4M
M-4DGT;7+2XECMI]6T_4=3OH-4BLK.R<6FNV3H?#_``C%\<IM0O?$7B+PCXA\
M.:'X7TFRU&^DAT__`(1NX\0Z7:W6B>(K;2M.?5=+N]1\17[FZN[Z?PII^K:5
M#>:9<WMN+C04U34[C5O"=;\7^(/BA?,OBN&[%_8W<T6G)H?A:6YU`RO^YO=,
MDM8+VRB2..TTJ34K:?4#<7DR6UQ;M>6\,5O;G=.UN:ZU7PV;6L8IM1N[-R3T
MTY+.ZNDX<GHH7;UMS\T>:VKM*35FE%I7UYTURM*Z_K6_8[_X*6^'_BO<:3\*
MOC/%I>B>(]4ED\/>'O&UA#)I?AKQ/>6\,UE)X?O[-+W55TGQ.;B*"Q@-OJ*6
M>K:E>C3K>RTC48[&RU7]%+FWTX:A(EA<WJPSP`M-,BXO8442^5-*\2AFDD$E
MS:P$+,]PL9A3SHI+=OX._AUK.F/XR\-_#W4H`8K.\U'59=<?5[37/"__``@Q
M6\^WZIJNF7=U8VJ:;HMM?^)"=8N0VGV"ZGXDLXO`NJ>*-1N+:Z_;?]CC_@JC
MH?PQU'3?V>_BU\3/#WQN\")/I7@+P=\7O#G]O7'B3P%J4VE^'M!U&U\6OXG\
M/:.=:\/?VA?RZK%K>G76N1P6L.LVL?B/Q&--M;5\I152RIU7&2;3Y%&^T7))
M/FC)J+4G%)\R=UI'6'%KWDG33LI*^C;:]Y*45;5-;<NB6C:3_H(`0@%[:[WD
M`OBTMW&X_>PTD32,,YPTC,[=78L2246WB=-5MX-4LM<U&[L]2ABO[2ZT[4DG
MT^YMKQ%N(+BQFMY3;S6<T4B26TL!,,D#(\1V%:*Y/9MZ\M7772E?MU4VGUU3
M:>FNNCY9)_"UMT?]S_)_<?Y97[,_Q]C_`&?/VAM-\:VUEI>J^';^4>$?%SRS
M:G!%?:+?:]I6J76OQ7LFMZI?)-IVMZ1IFMJ]MJL!U:PTQK)KC3'U.>[M_P!4
M/VG]7_:,U_QW!X3^#^N7WA#0H4L+RPM=/O\`7?[6L-(AOGTYKF^%B]M:7.KZ
M?<6^GSK%J9L-'>:"?S7C$\QE_#?X6R6-Q\5_AS-XAO'BTR?XA>$)-<U"9_,D
MCL9?$FGMJ=Y+)*DY=TMVGG=Y(YMS`LZ29*M_6YX1_9B75M6NO'OQ2\-^"WT7
M5O!YM/#OPRU74KJ:UN=$BC.J^%M:UC2-0N([/1K`2^%H;G1_"36NFVO]E3W/
MB:+51IMM:0ZOW>S<E&$6^;E2N[:VM9S=G)Q;Z1B[M[<M[31ES1G?1<ZDDFTT
MFU=12T3:2UEM9M-RW_(K3?VF?VQ/@XNG:Y;^)=;\4WVF^$8F@T'63K&HVFJ:
M*M[=ZS:-JDEKHHD\0ZU_:-_K%WIEW+IOAJQGTV9;..38+W2;WJM*_:UM?B38
MW[_%+X5):^-]52^+>(GO]2LM;6QT[4QJ,K^(KV2WO/[4U#38VL3;>'O%=SK>
MF^'M!MK?2--T-8-`6:Q_1KXH?"SQ'JNAHGQ4^&%GX=U2QT*VL==^)>C:R=9O
M==\1VUUIT-JMAX>TOX:Z3+X16XU'Q!'<7#W&I6?A'1(;230=0MM<;<(?R,UG
M0A_:_B"T2QU&PMI))[0Z;=[8I+!9KMM.:T@26U2SAN+EKFYGFNOL5JW]IV]U
M?/!(;Y;;2,9.I!+EFZD5+53YFFE&Z2BV^G*^:$5JEYI:R]RRDN6\=+)*2?-"
M,N9-:/=<LI-+5+5&_P#M2>(=>UEO[8^$VMZG8:WX\OG\-7NH1^*-0M+O[+>W
M%U/K^OSJFEVL=AH$FGKIUM%I+3RR06=W8:AHK7-]X?U2TT./PL_B;X2>'/$]
MAJ^K7FF7FL>%WEUJ*-M&:]UIUL-0ATJUU_2UN+&&&=]2G6)Y]1M(M;T\ZK>7
MUEI\\TUKI<WQW\4_COXD\,^/)M-\-0:7<#P?IUG:-=^(8'N+A]4D$+7]S%:/
M>6%IJ)>2XL5DMKK29B9+![S[%%;PR,O::MX\U/Q!#>^(M8N+[33:6/B:6\FM
M[C2?$$FO3:?80G5M!M=1UD+;6.J:;9>')]5T)FLK^TN-/CUFQUCPWI^IP6<-
M[$VU4C)).ZG[*\KRE)TZ:<VWS>\K2E"*M?W%'5V<Q:DI-N2DG#G45:"CS2NE
M:UDV^5N^GO.5]&OKFR_:\^+&@6=IH6F?%CQ/:Z;HMM!I.GVUIJ>L+:V]CIT2
M6=I!;+9SO:+;PP0QQPK:N]L(U40,T6TDK\O[_P`=>*(+Z\ATP^#[K38;NXBT
M^ZO_`!#H;WUS8QS.EI<7C6^NZ;`UW-`(Y+AH-.L(6F9S%96J%8(RL+8EZIX?
M757<;ZVM?FM*^JW5]-5>QJJL$DN?%:*VCG;3M;2WIIV.R^&GP3\.:E(M_KKR
MZUI[Z?/=!97GL+)O/MK<V<$$NBW\YN=1CN)XY1)#K#V#VIDF\JXBA5YOZW/C
M=J7B/1)?AOXL\*^,-$\2>#HO@=\*+WPX^KZS8Z;'XICT?P/X973]`TZ^;2=0
M\%:DRW.C6NG6MGK?C/PO87-Q9ZO!<>((GT*UC7\=OA]_P2A_;#A;Q[XC\?VG
M@KX::W\-_!^M^(U\`>.]8\9:A-+J;Z9KNO(^F7GACP'XYTZ"_;PS)?Z1?K<:
MOX=OH=6TZ7PWINE:E>6,^F^'/TF^'>L>.CX*T']G#Q\MUJ>L_#RW\7Z3\.OB
M'X*N8_%>E^)?"$^FW'C%O#-Z]]J$6H37ND6EJFLZ/X,UO^R?%&C^%]=\/Z!K
M/P_,^O6,=:+VE2C.3KQC*Z:FY0:]Z\7#ENH+WK)QLG+6SO)-:4(JG5BO83<9
M17N\LHO3EDI<UG+5-M/51:3:]VS\>\2_%7Q=\0/$UAX<UJVN]`U3Q)/!%I&E
MV-YIWC:&ULYX9K+3[6Y\;:!?:QX.L-135T2]_L[5;C$=U/)NL+ZQNK#4X?AG
M]NOQ!X7^$?Q.MM1WO//;^`/"\NIVDEG_`&:9O$&H+_Q+M.33X[:9!J$WA33-
M!U:XDN+O2;^^O7.K:UH]A/%-*GWKX9^*"^%SH;^&_#WAQM3OM/NM;CUG64CB
M\+ZWX9TZ]:\U)[0IJ>M:EXZF>:ZDTF\L;K3-+LYIM+T^T'BO4K=[/4)?CGXN
M_L$S_'/XGOXSF\="'X>_%>&'7KWQQXKU6R?Q_P""SI5WJ_AZRUNY\%Z7HUFE
M]I]C>6VOOJFAZI+X7L'O9U\,+XFTB.X\.>(-)FE*HH1C.M"4?W5G3=YQ5^;5
M2G4D[12<4[R@N9.+T-,1",[^RISYW*3ES^["R45=6C"/O2DTY*T6G'EM=L_!
M2^U[6O$?B'5=>N[E3JVJ0ZO<7LR6S.C0R:7=1WD*0PP7+(K:>);99W4^2"+J
MZNX0DU[']*^&_$4=M\,[P6NK7T=_/'X<U&_6VFL@^G0V.J13ZIK3/:Z5820Q
MV>E6$5AH.C65_P"(M(CLO#5OI%]91W]M?>'++]7_`(?_`/!%GP@;_5O"OQ%_
M:,N](U:3PCJ>MPV$_@B;X=7T3P?$+P=X1'V>ZU^XUO2/%BV=WJ>C2W6@76N:
M/)(VMPZAH"SVMA=ZY/\`9?@;_@BU^ROI&NZ-H'Q7^)7[2%YHVAKXFM?B+;>`
M[CX:ZA-X-TZ3PQ=V=YH'BO4-"LO&+:#XFM[GPE:7VI:EXDL6\&:5H,FG6NG:
MPT]WH(\/[5)PFDH->ZTEHM8V=E'5-\UG"RO9[K5*7+3PE>-Y3@^K?O)N,ERM
MJ23ERM)J6J3DM%KM_+C_`,(W\2T^72+K5GTI?ETQ[7Q9;RVKZ>O%DUM(M]9+
M)`UL(C"XL[0/&586T`/E(5_7YJG_``1'_8=;4]1:VN_C#>6[7]XUO=W_`,1O
M"XO[J$W$ABN;T0?L57L`NYXRLMR(;R[B$S/Y=S.FV5RL/;RZJA?J_8SEK[O5
M3UWWZV3ZHW_LZM_+67E[1*VW3V>F^W3;M?\`93XJZ/I&G7OQ2U'3]+TZQU!8
M?"<BWUG8VUK>*^M:)I.I:PZW4$23A]6U'7M=O]38/F_O=:U:ZNC+/J-Y)-^9
M'QP\$^#-/\.:W\1[#PCX8LOB'%\4=%MHO'EIH&E6WC..V@^&?CN\@MT\40VB
M:XD$-W96=U%$M\(X[FTMIT42P1,A137QTO\`'+_VXZ7_``%_W+?^DTS\Z;:S
MM+WX5?MC2WEK;7<O@_\`:,:?PE)<P13R>%IM5OOB3/JDWAQY5=M$EU*:"":_
MDTPVKWDL,4EP9'C0K]"?"*QLE^.7[->CK9VJZ1XU^'?[*&H^,M+6WB&G>+=0
M\1>*/%FF>(+[Q-8A!;:]>:[IJKI^L7.JQ7<VIV(%I>O/;@1T45%'^%_V\O\`
MTY4%+^)3](_^D1/U1\$65G9^&+&TL[2VM;25_@AJ4MK;0106\NHZM\-=,\2Z
MI?R01(D3WNI>(KV\U_4+IE,]YK5W<ZK<R27T\L[Q?$'PYX>L+;Q]XBL=!T6S
M\0>&-?U-?#6NVFEV-OK'AY;Z[^"4]ZNAZG#`E[I*WDR)-="PGMQ<2HLDP=U!
M!17)/X)_]>I_^F\0>@]J7^.C^>$/FZ;Q%X@N9IKBXUW6;BXN)9)IYYM3O99I
MII7,DLTTLD[/)+([,\DCLSN[%F)))HHHKE>_S7YP.Z.R]%^1_]D`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]M96QO;BYJ<&<`````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,3$R,3,@,3`U,34T,S,W-3$@,#(T,#<W`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````/_8_^``
M$$I&248``0$```$``0``_]L`0P`!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_]L`0P$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B``(1`0,1`?_$`!\```$%
M`0$!`0$!```````````!`@,$!08'"`D*"__$`+40``(!`P,"!`,%!00$```!
M?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B<H()"A87&!D:
M)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ
M@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2
MT]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$`!\!``,!`0$!`0$!`0$`
M```````!`@,$!08'"`D*"__$`+41``(!`@0$`P0'!00$``$"=P`!`@,1!`4A
M,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU
M-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)
MBI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9
MVN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`^!OVM/VU/'W[3W[/
M_P"SKX]^-.NVESK^C?$_PA-\4/$.@KX57Q5J%@-:UC3/$>G^'_&FEV<.K2Z=
M!9+8Z?HMC#<I%<2BZDN81>7-WNH^*OA!^U'^WG\+_B#^S@VSQ)XL\(?%CX7^
M,/V=?%_QYUKP?\(K?PMX$N+6V\/Z@MIJOB76+$:K;W?A:[A\%:K8^%--O+O4
M]/\`AUH7]H6US-I=K%#]1_L7_LU?"/P[\*_!^H7?P(^*/[2-O-K>JW\7C#QE
MH?P<\#?LYP6&M:K#XRT73?@G\./V@?$*>/?%NC:3J.LW>F>&?BQJ&BW&M:RE
MG)K_`(.?2M,NDMS^BWCR6UT+P;9V?QG\`VOAOPOXGU6+PMX6\">(_B?XQ_:`
MO_&'B">>Z@MK"Q\.:3=>#=&LS9W%W?%M5^&%_J=Q87%Q=M*-&1[K4)/\V\3Q
M-DG"^;8?+\DH8/$9CDN=9AC\'C)T5.I@(/$1Q-HV;QE"#C0KX6OAJLHWP];E
MJ4W92C^9TLPP\ZE*E.HU452,I+FE9V5K]$][J7<_!_\`9)_X('_M#>,?$OQ"
M^'_CC]I_X=?`[Q7X/M]1U_7-,TKX6_&;QAXAO_#,'B6?1+GQ+X,OM8L?AE'J
MFG67BC[1IJ()D@U&XM'UF":_\/W=AJMU]E:+_P`$F?BOI/C_`,._LUW7QQ\,
M?M`^&_V?=5U8>-;FRTC5OA3X%\*6'B26>_\`#OAGXI_$.?Q#XBTS3O$7C35-
M2CO-5\`_"A?B[\48_#=_:WL6A>']#N+:.S_<3XE?$.7X8?L]>*Y#\4M=^'GB
MGX0>`AXZ\+R_$"*_^+GC'P7HAM+#POJ"1:.=+UW4;#X4^,[ZXO\`X:W4'C[6
MO$5IICV]IJ&FGQOKGA4RZ3P/P%\5>$_@+\*-6\*6VWXE>$=1^('C;QM>:[X8
MU;QWH_A_Q/K6J0Z3I=SJWB71-+MK#6=5AM=!GTK3OLWB-]0TI?"EMHNG>'?*
MO+S4)V\[.?&CB'.GB'B:^4X:&.Q<</0P4<%2A2K8S#QYOK$<1*FJV-@J59N5
M&5>\*CHS33A&_O3HY3C:U.C7JJG&K9KE=G*HGI=1TU?-S-ZM?(_E7_;1^$?[
M??@SXI_LY?#?]M;X#^"_AK\&O!OQY\,:?\/_`!K\(O@+\#=.^%=IX$TOQA+)
MJGAKPW^T%\(/!UOJ?BW1+33'MM0GT3XLI<ZK<Z_IU]?^,+6/Q3::LZ7/A?\`
M&WQ*_P"S=\;=3L/BYK?@#QI\9+WX[>._'GQ#M[2,*PN]<O=`_M&+^S18V^@Z
MIXH\*^$M+T:+4=.A%S-!<Z[XBB9KTV#-_7+\)OBKX(\0ZIK'@73/A/\`#_Q]
M!X5)T[XH>'?A4OP_CU/P_::C923:?:^+_@%\4)+/6/">EW>@:E`UQ:VC:MHK
M17DT]K%Y%ZBU^3'[<_\`P3S_`&7_`(EZ;;Q?LO6_@[]E+XKV_B;2[[1?@;\7
MO#OQ#^$WP`^*<-K?3ZW=^$/!6H^)]&UKX7>"?%'B6'3;2X\.W/AW5++P?XG\
M7R2Z8(M,OUE^S?5Y1XQ8+/*N5\,\0Y*\DK8?,\#4CF&$BY9?B<)&K'$5XU*6
M(YJU"A6J1PU22E]9HU)4X2G4LJ=O.SO*<%6A3IT)^YAYQ2::NY)/JDE*[6J>
MKM%>\XH[3PO_`,%?_AY8>&?#MC#^T[H/@^&RT+2+2+PE<_$C1["Y\+1VVGV\
M*>'+BQM_#P@LI]$5!IDMI`!#;26K0Q@(BT5_*3XN_:L^(WA'Q7XG\*>)/%]Y
MHOB'PQXAUKP]KVC>(/A*-2U[2=:T74KG3=4TS6]176YEO]7L+ZVGM=2O5EE%
MU>133B1Q)N)7[W'PUP$E&2IU&I)234(6::BTU:@U9KLWOOKI\]_J_5Z>T:TZ
MRV]S_@_CYG]%_A3]MKX6_%#X9>*?VFM7D_X9]^/'Q#U"_P#A3\+?BWJVF:M\
M:OV?_A@^BZOJ&@^%?"=QX(GT'66\'P^,M/TN\\5>)O&>G:!XE;5M?N(-,N[N
MW338=/LO6]+U^V_X)_\`P;\(_M(^-M$UKQA\2_COK^N:;!\9_B/\1-5^*.ER
M^"/`W@[4?%OAWQ5JOC70!;:U?^#_`(FOHVKZM%\#=$N/!GB&?5_$^A>"/'/B
MK3M'T.<^!/Q3^&.I3Z)\`_V3;'7%TBW@/QSO[W6;/4+>W72%L=%\5_'#Q3HE
MH(I4^S64.G>)[N/[#:!%CM]0LX+NW6.>-)!ZYXR_;-^-WPW\4?#^V\#V=K\2
M/#?B;Q1XDTOXH_!OXB1_\)+\$_B=>^+#X*D2W\9^%=;:[TZ?Q?8:KIE]J?A_
MQ'9V,EW:3V]K?B=;Y'EK\[_U*X8SG%PRNIA:.`P]?-,UQ..Q]"I)U*N6Y3#$
M83"X/$-6K_5Z<\-*M4C&5W.-/G4E*<7Y5+#^\J7Q5%5=7G;?-9)K23?,TG+O
M;35=_P![H?AUK&H_L9_%K0-,\5_&/X__`!!_:7^%/_"SO$EC%IFA^'O%&J^(
M/B?H-EIEEX-T'P;S<^%+#P/X(=M,MO"OB62^?2+<W]OIXCL;KRV]U_8%^"WQ
M/\??LO:'H_B-/C7XOU#0KOQ9X%76/&UQX!M4T?2-)*V>C>'K/4+RPM]8\265
MCH\UGHFHR^,-;U2\MK^UO?#6DFR\%Z?HNG6OP/HW[6WA70M5'Q'T7Q'>?"K0
M=/UNR\523)>W8MO"=MI6IQ6^M:=8^(4G0V]M=P1/H5A(@B=K&X-C,9%:4-YA
M_P`$^_VLO&/PP\4?&GP#^T/\<-<EM_'#V/QA^"OA75-;U:Z2ZN]2U&\_X2K3
MO!NJ6\XBN[K5/">L^%K/5DOGCD;6=*O=/821Z?$J_P`ZXGA/,\=PIQ\JV%JX
MNEEV>X3/<'C/80HTHT(RG0E0RMJDE1H1H+#RKI*G[3E3>RB>WE%2E.E6IUY-
MNG63C-/WHM1=DF[M*\MEV2ZW/U#\3?LS_##4=.U&W^)NDW,_AKX-_$:7X;_8
M?A!>36?Q_P#V1]=UJ32-=TG6_"?CS3M=\,ZUI_PMN]$\8>"O$_B#PK>^+/&7
MAKP''XLO;KPCIFD_#OPM<>&-.--_:.^$7PW\)_&S]F/]I#QS\/O&WB+X/^(M
M,\$^(-0\6M9^.?&'QW^#'B_1+3Q!\+_%WQ"$.AV6BZ?>:[IMWJ?@_P`8-I]@
M)].\2:5=7)EO7#:C=?FA^U3^VU\2_$'Q7^.G@+PW>ZG\-?`OB']C?3M;@NM.
MC%O)\2?$OA'6_B+HMWXFN(;66,6NO:=HNJ:;X(_MJ8-?RZ#X<TRQ6Y_LVWL[
M>/\`+'Q1\0M9N?VD/B[XZBU2:]M?%7[/GP1\0W^C2+I3W.IZYJVF:_/H[Q:G
M<12RK<F)99I)3*T[37=UESOP,H\#YSQ1E5?!XZM/!X.CEE#.<LQ&'E-X^GC)
MX_):=*E];@N:-&='%XA5:'-RQJTVJMY4[GIR]ARR=*I*4KN_,VVUM?6ZTM=2
M]W1NS=['[>0:G\*M,@ATWP?^U[\1_"_A+3XH[+PMX9_X5UI?B#_A'?#EH@@T
M30O[>OEDO=;_`+(TR.UT_P#M>\=[K4OL_P!LN':69R2OR)TGQW-?Z5IE]/=W
M]E->Z?97<UD+C1L6DMS;1S26HQ!C%N[F(8X^2BOHX<+<;1C"/^L^=/EC%?[S
MBW>RBMU4UOKKUNC#GG_-+_P)_P"9\^>*=-T/7?A%\&/#22:=J6C+XALM,\6Z
M?+>6=UI\_C**_P#&.F>+=9L-9BABU>UE3Q:U_JVEK;RB2T352D3H78M\]?'.
M77Y#8^(8K[4[6#P-K?A/5;?0]!TXW5_<Z_K_`(GN8-*N;4W\TU^-7TR+3;33
M;6Q:+[+>6=[-=OE]2N/,^S]>\.1V/@O2K?5-`TF./X;_`!GU:'4M&>&WO[B6
M5?B8EG:1VNKRZ9I\D_VFQ\0:7-<SK;(MY(1,TEV-EU+\X?M*Z8/"]M8^([>\
MU73/$_G75[86\%G'J!O[?PA%-XSN4U%)`8A8:(^FW5\^LR[M3BF,ME:,(844
M?T=0IQHYKE[5)SE5Q&<.G"/VGB)47-/E4M))3<GRRNVY6;M?R:"7-A797<;-
MVW]Y+7NO+L>W>)]!G\<VWB6PTZZO#:VNE7^JV/A>24#PIXGOWFT]-#TSQSH4
M20VNK:5IL]B+N;P]J5K<Z9INK+<Q6$"111$[7AS4?%6F?&G7?#_Q`\9Z5\2M
M+C^$]CXJL;JRTFTT:T\`^-].USPSKVJ>&_#EJT*:AHFCZ1I>MVMY<W*&.U\0
MOJ3:8/.M+"&"+;^%DL5WIMWXALYM.F7Q#I>E:K]IL(O,L)EOY!>IY,5S'G3;
M:1YS*L%Y&8H2YV(L>T5X#K_BK7YOVG_%\&MWPO+KQ'X1N/#69+IK^/3+'2-#
M\+:_H6C:9JVE-;:>\]Y)H^H7\%I8Q1-:33S0RJ]Y'<R/\+A)X['8?BG(IN/U
M2&79ABG1=TZ=2A6HM14;I6BN;3X;MNVUNC#Q2G6:27[WLND7_7R78[+Q3\0_
M%;_'IKCQCIFB2^$O&OPGU3X6>#1I.NVUQ?\`A_28M5U7Q!KT%VSQFQ\0:@UR
MET)[$Q+;1:1=:?I]YODMVQ\OV&K^-;.R\+:?(UA#KFO?!&WNM<G@N+J:TM=(
M^$=UI5IX/6**[D=[;6;FVO[RVUB.+;%'K,^LQVH6VF*MVWB(ZI-\7/A@MT+$
M:,FC_$2P^U3S7BW;V6H?V-%K=Q?12-)(VHFVD@LTGE9II8Y+K+E)W4^57;>(
M-8TG3M7T&TL]UK\*/'\&K3WT]W;7%DT/Q,?3([>SD;;((YS!]ML8D8(D-Q&8
MPH(S][PU@4\ORVA*E3_?932INT%"SPM;,,+&[BU=N5&-22:]^I%2EJ>]1HQJ
M**25[KHKM>[=7MMMZ(^E[?Q&X@A"WEN`(HP`;%<@!%P#\G845Z[_`&#X2@_<
M3W6E130_NIHC:3$QRQ_))&3Y7)1U*D]\45U?ZN5.\^G?^YY^?]61Z_U*/:/_
M`(#'R\OZMZ7]`^,LDG_""_&!_,??:ZQ\$;JU?<VZVNKKPMX$O+FY@;.89[B[
MM+2ZGFC*R2W%K;SR,TL,;+XY^U_%%%X#DNHHHX[EO$_AR%KB-%2<Q:GH26^I
M1&90)#'J%O=74%\A;;=PW,\4XD2:16**Z</_`+_@?^QGF7_I4C\ZPW^^4?Z^
MTCVWPBJVNF:VULJV[>7X<AS`!"?*4V,:Q9C"GRUC_=JGW0GR`;>*^&OB1&EU
M^U#XZCN42Y33_B)I\M@DZB9+&6#X2NT$MFL@86TD+,QB>$(T99BA!)R45\3D
M?_(^XP_[$V;_`/I$3U<+_$K?XU_Z0=AJ<$"^+_@BZPQ*]W8>.Y+IUC0-<NVB
M:%=,]PP`,SM<DW!:0L3.3*3YAW54/^D:%H*3_OTN/`7PC:=)OWBSMJ7Q@TVV
MU$S*^X2'4+8"WO2X8W4`$4_F1C;117V7"_Q9+_V#5O\`U98\]G#_`,2'^*/_
M`*3$_9`>$/"<P$TWA?P[++*!)++)HFFO))(XW/)([6Q9W=B6=V)9F)))))HH
MHK];73Y?^XSZ6.R]%^1__]D`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O=V]O9&EE+FIP9P``
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$P-3`P(#$P-3$U-#,S-S4Q(#`R
M-#(U,0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_
MQ``?```!!0$!`0$!`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#
M!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*"
M"0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS
M='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$
MQ<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!
M`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<`
M`0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9
M&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"
M@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2
MT]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/[?OVCO
MVB/!O[,OPXE^(?B_P]\1_&\]WJD7AOP=\./@]X$UOXE_%3XE>,KO3=5U?3O!
M?@'P9H437&K:_?Z;H>KWRO?76E:)I]AIM]J6MZSI>F6ES>1?DI\;OV_?"GQ`
MT*P_:Q^'?P8^-?@SXE_\$R_CGI%_^V9\`OC9\,9/"7Q]\#?LB?&OP-XH\,_%
M'QWH/A.QUW7-)\6^'$\-0:7\?O!NN>`O$GB`^-;7X#ZSX<T6>ZN9=4T&^_=^
M6VMYY+:6>WAFELYFN;.26*.22UN&M[BS:XMG=2T$S6EU=6K2Q%)#;W-Q`6,4
MTBM_-5\5OC!\.?VI?^"FOB+XF?LZ:IJ&K?#/]G/]GCQ9^SE\=/BEX;MK^S^&
MWQK^.>N?%?P[K_A[X>Z5KK6D6A_$^[_9?T?P1XXCUWQ#HL^K6?A'Q!\:?^$4
MT[6X+M/%VDO^+_2"\7<M\"O";B_Q0S3#X7,*?#>`A5R_)L5F,<J_MK.Z^(IT
M,FRJAC%A\75A5QN/J4:=14L'BYPP\:N(]E&E0KS/I^#>&ZW%O$679!0G*C+'
MU)QJ8E4W6CA,/3I3JXG%3I>THJHJ-"$Y0@ZU%3J^SASMR4)?7'[8_P"V7^S1
MK>H?\$ZOVB?AW^UK\";[X1>!OVWO"-]X_P#&6D_'#PY;^!1X%^+O[-'[1?PO
MTZ^\2>(=-\5Q>$[*Q_M?X@^'+NV7QI!/93M,EK82:9K-U8WB?7WPL_X*`?!3
M]HKXFQ^!?V5;77OVI_!.E-:I\0OVC?@?J?@#Q-^S1\/KR\M[:XA\.S?&"\\;
M:7X?^(/C:U@U+2M0UWP7\)/^$^USPQI-S/-XC@TO58;;1;_\F_$O[,O[.OC#
MX;:U\'/$?P-^%&I_"GQ'J\7B#7?AV_@/PU;^#]5U^"ZL[V+7;S0;/3K?3Y=:
M2[T^QG&K&`:AOM(";@B-0/I?X%>`OVA-(^&ES^S5^Q%\0_@/^R=X2\%Z"_B/
MP/)JW[/MY\5M*T>[DU+4!K7AG2_!.E?$WX6>&?#GA_6=9U72-?U+58$UG5[W
M4KKQ7=/:+J>KKJR?Q!]&W]I1DOCCXF9-X89QP'B>%\UXJS?.:619CAL?AZ^7
MQPF!RAYCEV&QWUBI*M7SC,)X+%8"JJ-&AA:<5A*E*M*525*A^I\;^".-X4R+
M$YYA\UCF.'P%#"RQ-#V4X5?:U:SI8O$P2BH4L+2BZ,HP<JM63E/GG:G'VG[9
M45\2?LE?&G]J[QGJWQ`^$W[7G[-@^%WQ,^%PL+@_&KX7:Q8:]^RQ\<M"U[4M
M8M?#VL?"2[U_Q#_PM;0/$ZV6C3WOCCX<>+_"]X/`2W.C+)X]\0MK]@B_;=?Z
MB0FIJZNFG:47;FA*R;C))M7LTTTW&46I1<H2C)_@KT"BBBK`_E,^(W[5'[37
M_!4KXS?M!>!?!?Q%\;?LQ?\`!-_X)_%/XA?L\N_PJU&#PG\>OVS_`!K\-O$-
MUX1^)6K7GQ8TJ_U#Q#\+_P!GVUUW1[S2=`M/AO/X4\;^/](U'5+/Q/KNEA+K
M0]+W?'G[+8T;X&?"SX0_LI>(5_9NB^!WC[X9^,OASIOA:75['P3>Z-X,\51:
MCXK^'GC_`$G2;VVU/Q=X,^(WAG4/%6F>*+2]U)KW4_$.KVOBO4KR^U2RD>Y^
M@?&?_!+[]MKX'_%'XJW/["'Q8_9DU/X"?&KXM^*OC5=_#G]JW3OBPOBCX)^.
M/BKXDU+Q=\74^'OBOX7)>CX@>"-=\6ZAJ/BSP[X.\86WAK5M"U'Q#J>F?\)Y
M/I-A8Q3\;?\`["__``6ZT?5+F\T;XY?\$PO'NG7=N%31]>^%W[4'PQCTBZ"R
M8FL;[2?'/Q1N[VWW+%YUMJ#&2?SG:&ZLA;+'=_XL_2C^C3].CQI\7\[XGPN*
MX6QWA_PKQ`\7X8\,XCB;+WD/]E4F\/A*V)X9QF&K8?&9SBL)6KPSZOQ!A[UO
MK&.P6%K/)GA<.OZ=X%XX\*.&^&<'@*U/,:&<YA@XTLZS&EERCCZ>(52G.3IX
M_"R52GAJ&(BJ^`5"4JRAAZ5>O3^M.*GU,OQ:^'D/Q;LO@3+XDA3XKZE\.=4^
M+5CX1:PU;S[GX>:+XFTCP=JOB2/5/L']AF&Q\2:_HVF3V!U,:L'U"WN%L&LR
MUPO5?LW>#_&7Q:^/.@?M4?L;?%+X3ZYXA^#'C[XB?L=_M=_#'XDZQX[T.S?X
M?Q0:9XMNX;+3-+\.:]=Z9\6O`'CY/"WBOP%<7FA>']#\=_#_`,0^)8(_'$WA
MWQ1X>U>R_(J]\(?MV_LP>(?VBO@U^T-X;\)_$W]O#Q)\/_!'[0?A?XJ_LV_$
MF:ZT+XT?LRZ-\<X=!U_X&_"JQ^+?@^74_@#XS\,Z'J'B_P`)^'89_AWJGP^L
M?%7CNP^)&I^*KW6VUG6V^TO!'_!2K]I_XM?M_P#[+W[/O[/V@_"7X7_#3Q1\
M:9'_`&E)O"/P-U*XT;QCH7A7P7XA;5_@+X._:*\5ZP-'^.OQ(^&_A[1I/%7Q
M*\6_"CX8^%/#7P]T?PNVB:I\0;'Q&]A\-_%?QWT-/HX\.>"GTE)R\4>(*^6\
M>\&UZ/"O#O"."Q&-S6IG/$F></X#%8KC3&/)LFGE^7^'M;!<0T,#P?+/,SI9
MAFF?X:I4Q."PV9X6&3X;T?$SCC'<4\$P61X*GB,FS-O,,=F%>C0P]/"X/"XN
MM[')^?$XYU)Y[">#5?'1P5&4?J\Y+!U)TJ=7$3_=K]IK]O?]C_\`8VU/PIHO
M[37QW\(?"/5O&^EZ[K7A?3]?AUV]NM3TKP[)90:G>F+0-(U=K&%KO4+33]+_
M`+1%HVO:I(^EZ$NI:C!<6L7A/[`W_!0K3?VL8_BAX?\`B;X?L?@9\4M`^)6M
MZC\-?A3XTU>RTGXA>-_V9/&MU:ZU^S[\7)O#ES,CQ:AXG\/:HOA;QIX?TF?5
MY?`_Q+\->(_!6N7*:U9!;C\X/VLOC58Z;^WQ^V)\1EM=9\?6?PA^#G[)'[+O
M@'PAX,C;7]8\4?'C7-3^+OQ5U'X.>%-+TJ&XN+CXE^,)/CG\$+2^L;R*5-(T
M[4_"VK:G<Z3HD>K75O\`1WPJ_P""2/Q-UOX]_!OX[?MG?M2:%\>_#OP=U#PS
M\7O!'[-?@[X#^%OA]\/OA]^TYX=NM.U30/'>A_%MM:U/XL^,?`WPZU."YO?!
M/@_Q-_9\FK>([7P_XQ\9WNJ2:'IOARR_TPR+QA\6>,O'_C7P_P"%/#SABIX5
M^%F:Y;P_QIX@9OQ3FF$QV;9KG_#>2\0PP7"668;(,5@J^:<*?79X?B#+\;BG
M2K_6L(HYEE$IT_KGX;B^&^'\MX2RW-\PSO&1X@SS#5,9EF1X;+Z-6GA\-A\=
MB\)[?,L3/&4ITZ.8PI4ZN#G2I.=)4JS='%*HEA_W$HHHK^ISX,*\R^,_AKXD
M>,OA3X_\*_"#XE#X._$[Q!X8U/2_!'Q2_P"$6T+QM)X$U^[A,=EXDM_"WBBV
MOO#6L7FG,6ELK?Q!IFLZ+'=^1<ZIH6NV4,^D7OIM%)JZ:=[--.S:>NFC333[
M---;II@?Q/\`P7_92_;._8U_;LTKXU?\%"]0^'^L:Q^UK\&+KX2_#WXL>$]9
M\-^([ZZ^,>E>.M5\<:A\+?B[XWM_"'@OQ9XG^(WBGX<^%-%\3>&->URTUGP/
M"NAWWPU\`Z]I,5AX:\&/[=_P4)^''AS2/A-\2/VC?#WQ(^(_P*^/'@GX6:UX
M2^&/QT^''Q@^(_PDO_AF^H'7=2&H:K??#?5;/5M2^'3>)-0TKQK\7?":Z?J^
MD>.=,^'OA>?QAIMQIG@NQU'1OZF/C=\!_@[^TE\.M9^$OQV^'7ACXH?#O7GM
M9]1\+^*K!;VS%]I\PN=-U;3KA&AO]&UW2KD+=:1KVC7=AK.DW2K<Z=?6TX$@
M_GI_X*,?L$_\$RO^"<W_``3C_:3UG_A3G@_4+KXO>*_"NBV?Q(_:4\7:]\;?
M%?AWX@^+KK2=`L_$GA[XG_'#Q#XI\3^!=2\.:#I6J>(]`N/#&NZ1>-XIT^QF
MAF-_):SV_P#FUXQ?09Q6;^.&5_2"X#\6\Z\.X9!EF6XO.\IRW*,5F&;8B7#C
MJXG%0RC-,'G>5U84\_P=&%#,*.)P^.JU\?7QF)Q$<PACJV'7[7P[XK_5^%,7
MP=FW#F$SUXV6/I83&8G%T:%'"QQU)1H>VP]7!UJ;67U[5J5=XBA&G1I45-QE
M0=6?XE_L/6_B7P+_`,%-O^">'Q(T'XQZ'\;_``KXC_:=_:L\/?$+P_IOP]\=
M^&/@/\,_$>N>&/A9X%M/&GABQ^)DD/Q&\:?&KQO?_M&VNI:E^U1\3]0U'XB^
M//%/B4^&KR[UO2/$*K-_:Y^U3XP_;"^&6J?#WXE?LW?#'PE^T%\//#D'BBV^
M-_[/XU?3_!7QF\7Z9?\`]BW&@>*O@EXY\4:MI_@"7Q;X073M9C7X?^-KCPWH
MOC:+6WL&\8Z'?KINIZ5_&'^Q#XIN?VH?VV_V-_#7@4V?C6_^)G@D?M=_'3_A
M&[F]^*FE>$OB%\4_VZ_@O\2[V;Q1XJTK1+SPM;:3X'_9_P#V2F\#^%M/\9Z3
MX,\+Z9=6W@RTM-&U_4[[2$O_`/0$K]\^B/C.+,9X7XW!\68+%83%9;Q3Q'A<
M/B\;0PV'QN9^TSC&XRMCL17RO+\FP68+VN(C0IYCAL)0JYE0H0QN.E4QN*Q-
M2?R'B#2P%/.J%3`U*<O;9;@'7HT_:?N:M+#4J$N>%>4ZM"5:5.=986:4<-"<
M*>'4L(L/*7YGO_P5"^'4#M#>?LM_M^6-Y"S175E<?LA_$=Y[.YC)2>UG>U6Y
MM6FMY0T4C6UQ/`SHQAFEC*NQ7Z845_57X_UY'PC=VVDDFVTE>ROT5VW9;*[;
M[MO4****!!7C'[0?PW^'?Q3^#_COPO\`$[P%X+^(_AD>&=?U,>'?'GA;0_%^
MA#4K+0M36SU`:1X@L=1T\7UH)YA;7?V?SX!-*(I$$CY**QQ'^[U_^O-7_P!(
MD..Z]5^9\M?\$P/A/\+/A_\`L6?LTZOX#^&GP_\`!.K:O\#/`>FZKJGA'P;X
M<\-ZCJ>G6%M/=6-AJ%[HVFV5S>V5E<WMY<6EK<RRP6T]W<RPQI)/*S_H9116
MP@HHHH`__]D`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O879A=&%R<R]W86-K;RYG:68`````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#(R,#4@,3`U,34T,S,W-3$@,#(T,#4W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````$=)1C@Y82``
M(`#W`````````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`9@``
M9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`S)D`
MS,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S,P`S
M,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DS
MF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F
M`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF
M9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F
M_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9
M,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9
MS#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,`)G,
M`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,
MF3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,
M_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___9@#_
M9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_
MS,S_S/___P#__S/__V;__YG__\S____XOR0`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````A^00!``#8`"P`````(``@```(_@"Q"01`D*#`@R0(DCB(K:!#
MA@T=%D0(J2(D$A@E/ARHT2`V$A9#7NSH42,2CR!%ADRH\2#!DR<+IE0IDN5$
MB`Y)L)E)LV9,G`Y["JU(`@E$C#L)#AVZD*)%I1>7JL3HE*A,J2,!Z+PHD"<D
MA4(Q9LS)]6--KQ<QKF!U[1JK%07?[JQ*D\3:MGCQO@W@MFE7IFSS"G[;ER%:
MBPD%*[ZV%N[1E58!+&[+R@JKMX'\4M2I,;#B%8'6!O!HF`W)NXKCRL1I4R/J
MO*H)LM+,6>+E%793R]9)@A4`IZTE4[YL)2]<K163=F5S,6G<MBNB>W:+F_G(
MY1@MFB9XE^U;SY;?8V;DZ#4X@+O<IU-N"F`J0X=K"[ZF[K(F1,.^)<(-4,+H
M0,2:W==;9P&8<()?6E%UGX#M570>*R6<<,)O"U;XWDR]K6#@A!1:6"%/O04@
MX0D%=NCA8Y$!L*$))IAXHF$D/100```[````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S
M+V-L;W=N+FIP9P``````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R,S0Q,B`Q
M,#4Q-30S,S<U,2`P,C0Q,3,`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````_]C_X``02D9)1@`!`@$`R`#(``#_P``1"`"^`)8#
M`1$``A$!`Q$!_]L`A``&!`4&!00&!@4&!P<&"`H1"PH)"0H5#Q`,$1D6&AH8
M%A@7&Q\H(1L=)1X7&"(O(R4I*BPM+!LA,30P*S0H*RPK`0<'!PH)"A0+"Q0K
M'!@<'"LK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK
M*RLK*RLK*RO_Q`&B```!!0$!`0$!`0```````````0(#!`4&!P@)"@L0``(!
M`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$54M'P
M)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F
M9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>X
MN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^@$``P$!
M`0$!`0$!`0````````$"`P0%!@<("0H+$0`"`0($!`,$!P4$!``!`G<``0(#
M$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G
M*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%
MAH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35
MUM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/JF@`H`*`"@
M`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*
M`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`
MH`*`"@!'=44L[!5`R23@"@:3;LCSKQ/\8?"^@Z@MFUP]Y(,B0VPW",CL37+4
MQE.#MN>]A.',9B(<]N7U,G_A??A?_GC??]^ZS^OTSJ_U2QG=!_POKPO_`,\;
M[_OW1]?IA_JEC.Z-;P_\8O"FKK<F2[-B8<<7(V[QZBKAC*4NMCEQ/#>-HM6C
MS7['5:+XLT+6HYGTW4[:98B%<AP,$]/Y5O"M"6S/-KY?B:#2J0:N:+:G8*,F
M\MP.G^L%5SQ[F"P]5[1?W'`?%+3-4\4+96_A[Q)=:&;:0R230?\`+7C@>]<%
M3,(QE:"OYF\,%)QYI')Z;8_$OP?$9M)UV'Q=$!))+8WXV2,<#&Q^N>.GUIT\
MPBW:2)J81Q5TSHOA1\9M(\<W$FEW<+Z3X@@4F6TG.`Q'WMI/7'H>:[TTU<Y;
M.]CTG^TK'_G\M_\`OX*7-'N:>PJ_RO[@_M*Q_P"?RW_[^"CFCW#V%7^5_<']
MI6/_`#^6_P#W\%'-'N'L*O\`*_N#^TK'_G\M_P#OX*.:/</85?Y7]P?VE8_\
M_EO_`-_!1S1[A["I_*_N)(+RVN'*07$4C@9*HX)`IJ2>Q,J4XJ\E8GID!0`4
M`>"?M-^(-3LQIVDVEP8;&Y1GF"'#.01@$^E>;CZDE:*V/MN$L'1J<U:2O)/0
M^>*\H^^L%`!0`E`$D<LL0/E2.F>H5B,T[M$RA%[JYVWP?T*[\3^.H);EYSH>
MC_O[ER24FF_ACS73!*-)REN]O0^(XDS&I'$1PF%=N5>\UU;Z>B/I-W,CL[=6
M.<>GM7*>*DDK(0$@@@D$<@CJ*!GB_P"T+X$%S9?\)OX=MWBUVR<&^CME_P!?
M'_SUP.X[UZ&%J\R]E)Z,X6Y86M&M#H[K_(\@BU"6YACN(;F4QRKNX<\'O7#)
M2A)P?0_6:4Z.)IQQ%-:35_GU'?:KC_GXF_[[-+F9I[*'8/M5Q_S\3?\`?9HY
MF'LH=@^U7'_/Q-_WV:.9A[*'8/M5Q_S\3?\`?9HYF'LH=C2\.>(]3\/ZQ!J6
MGW4BW$1Z,Q(<=U/M5TZLH2YDSFQ>`HXFDZ4UHS["^'/BV'QGX:AU2&%X')*2
MQM_"XZX/<5[M"JJL.8_*,TR^6!KNDW?L=16QYP4`?.'[4_\`R&=%_P"N+_S%
M>5F/Q(_0.#OX53U1X97FGVH4`%`!0`Z**>XEC@LTWW4K!(5]6/0_AU/L*J$5
M)V>W4Y<9B'AZ$JD?BMIZ]/NW]$?5/@'P[%X3\(6.CQ$%D'FSL&R'E;EF'XU=
M:ISRN?F%*#3<Y;LZ"LC82@!\;!7^895@4<?WE/44TVF14@IQ:/D+QEHL7A'Q
MYJOAN)D:WW_:K4JV=JM_`?>NK$1<X*M\F?1<)Y@DG@)]^:+_`#7^1GD$=17)
M<^T::W"@`H`*`"@#ZM_9L/\`Q;I?^OA_YU[6!_A?,_,.*_\`?O\`MU'JM=I\
MR%`'SA^U/_R&=%_ZY/\`S%>5F/Q(^_X._A5/5'A@YZ<_2O-/M5KL1R/,`WV6
MRNKUT(5A`A8*?0GU]JJ,8OXY*/J>3F&=8?!2=-ISFNBZ>K[^1#97HNKF:U>"
M2VO(3AH)>&JZM%TXJ:=XOJBLJSBCF,I4X+EFOLOJNY+IT6IZ[J[Z?X9M$O)(
M4+3R/PJ_C4U70PU)5<5+E3>G<\S,.(9T\1]7P45/E^)O:_9'H'P.\-WUY\0K
MJYUJTA*:-$!F*3B*=^@/O@-^=;QJ4OJZG1;M)]>R_0^9S#,*^/K)8A)<BV6U
MW^I[_P")=8MO#WAO5-:OVQ;V<)8<9W2$?*,?7%8TH.<E$XZ]3DCH<5\!/%VI
M^-/!-]?ZVR27EM>^6LBKMW(W0$>W:M\71C3DE$Y\+5E*5F>B,<*Q]!FN0]!;
MGGWB_P"(1\+_`!;T;PS?1VXT74($+W#G;)%(V<'=TV].,?C79##J=)R6YYKQ
M,U4,O]HKP2FM^&VU6TMU;5M-.XRQ*?,FB[@8Z\=*,+5Y9<CV9I5C>*J0T>_F
M>+3:'IMMH.G>(]#OKYM&FD,-^MPF]K9NQX[9XS7G1Q=:=>>$KQ7M$KQMI?\`
MK<]O+\RG@Y1K0DW3D[2OK;S^10NYXK:/S"QD5O\`5+'\QE]`HK>G"4W;;OY>
MI]WB\91PM+VTW=-:6U<O0NIH/BJ>P6_MM#9;7!9HY6_>D#K@5B\9@(S]E*K[
MWEL?-SXCQ4FIT:"4.J>_R,W3[V&^A:2,F-D)$D;]8\>M=-6C*D[/7MYGO9=F
M=#'TG5INUMT_L^OD)9ZC9WDC1V\X+J?NMP6^GK14H5::O):!@\VP6,FX4*EV
MNCTOZ=S[!_9\TZ[T[X>6XO(Q&9I&EC&<DJ3QFO7P46J6I^=\35H5,<U'HK/U
M/2ZZSYX*`/D[X]^)+CQG\1H/#G@ZQ6\O-.0I/<E@8\GDC/08Z5Y69U,/1A[7
M$2M%?>SZ/),VQ&"A*&'BG)OKLD8VC?#35[BRWZ[J%K9W3-@PPC+1IZ@]"37R
M6(S[#PG;#P<EW?5GUF'SC%UJ,O;JTG\+CI8](T73;/1-.BL=,A$-M'Z\LY[L
MQ[DU\YB<14Q%1U*KNW_5D>?A\-&E#E>KZONSGO'/P^T_Q<#=$O9:LJ;8[N(8
M#GMO]17H99G=;`>Y\4+ZI]/0Y<7@8S?/3=I=T0>']`L/ACX)U&XGF9K@QEKN
M[7^-OX50>F:TQ>-JYSC(1BM+^ZNW=LPP^'IX*BYS>MKEOX$I_P`(OX0O?$7C
M+4_L*^(+Q7B-RISP#M8_[V3_`-\U]O7IKW:5):11X=&H]9RU;95^+7Q;\&:U
MX!\0:%I=[<W%]/M6)A$0DA!'(/I6N'PM2$U)HSKUU/[BI^S?XL\*>'O!5WIN
MI^(8K;4;B;[3)'.NU(U7C:I[DT\92G.5TB<--0:E?H>ZW%U;0Z?)>SW$45DL
M7FM<.V$"$9#9]#D?G7G<K;LMST_:124CY7_:5U_1M:^(^E7NCZE!J%I%:Q"2
M2W;(7#9(^N*]G"P<:;3/&J/WKGMVG?&+P#K3?85UB6S(M54R7,153A>0/>N"
M>%J)\UCLIXA*/+N87A/PJ/#FFSV$-];:SX;OB9K%C'S)$_+!_7K7R7$<E]:C
M4BG&5M_3MZ=3VLJI\U"4)[7*GAKP)H_AW599XY(YR'+V-M<,"UMGV/7VKAQF
M<8C%TE%JVGO-=?ZZGJT91I8>.%3T3O?UZ+LCK69PY+%@_?->2DK:&R2MIL>6
M?$+P$-4\2Z;)H4$MN=29EU1H@!&B#'S^Q//UKZG*<Y]CAIK$-/D^"^]^WH>-
MB*5:G6<:#LJBM+S1?\2?##1I/!;:?HD#+J-BK2VMT3B29NI#GT-<^$X@Q*QG
MM:[]V6C71+R%6RQ0HKV>DEMWN>M_L\^/]*\0>"--TR6YAM]:LT,,UI)(-[;.
M"X'H:_281BHKEV/EZU:I5J.=5WD]SUT<BJ,CS;XR?%*V^'UK!;165Q>ZU?1L
M;&%$RC,#CYCV'-3*481<I.R0XQ<G9;GEWP_TJZTK0II-3MX(-7U&=[F\,(Y8
ML<@'TQGI7Y=GN/CC<6ZD'>*T7;Y'VF5X3V%)<RU.C`'I7CGIE#6]2.F6<<D<
M#7%Q-,EO!&.`9&.%W'LN>IKMR_`RQM=4D[:7;\EN<N,Q*H4^:URKI7PMUN[N
MQ>^+O%]V7E!::PTSY41CT"N>,"ON:>'P%&*C"DG;ON_,^:=3&5'?GM?^O4SM
M5^!=YJUL;;4?'M]<6H?<D4ENQ`],^IK>C+#4)<]*DDS*K#$U%RSE=>J/6=&T
MJ'3M`TW2IA%?)8P+`LEQ$'W;<X;!Z'FLY59.;DC6.&BX<LNYYS\=/!'AJ7X;
M:[JT&AVUMJEJRRQW%HFUF8GG<.FWVKJPM>;FHMG-B:$8;=AGP7\&>%-5^%&@
M7NJ>&]-O;N1I-\TJG<Q!/)-/%5YQFTF3AZ$:F_1'INHZ5I^J:9_9FI6<=SII
M"@VK$A"%^Z..P]*XHU)1ES+<[IT8RCR['S]^TSX3T'1M-\*+H.C6>EBZF=9I
M+=#[`9]?6O4P=:4[\SV1YM>DH2<5W/9/#_P\\*Z'I^DQIH.FW-[:V\;"]DBR
MSL1G<5/?ZUQ5,34;T9TT<-"<>9B^.O#FJ>(=/BLM&UJ#0X`/G9+8LW7(V8^Z
M/6N=T\/5:>(CS6>AO+V]/2AHCD=2^!FAW]F9%UK61XC(#?VK-+N5G'?8.0*Z
M:=>G"*IQ@E'L83H5FW4<KO\`KY'%>`O%NK6_BVZ\&>*HYIM0AD<073+AF`Y^
M<>A`R#7SN>Y+2I4OK>'TCU7^1Z>79C-U/95=?,]-R<$9.#U'K7R1]$&3G(/-
M`'GWQ,\$V5]I=UK.C6QLM>M09P]J"#<XY(8#OQVKZ+(\ZK8>M&E4E>F]->AX
MF8Y9"<'."U/I;X=ZG=:SX&T+4;\*+NYM(Y)0JD#<1SP>E?I35F?(IW.,^+E[
MHEKXDT)+ZYM8-6FCD2V\T88KQN&[L*^1XJIXF=./LTW!;V_#0][)*M*G*7/N
M]CG%9'&8Y(Y%_O1MN4_0U\"TUNK'U,)QFN:.PIH*)].U*QTO4+>?4[B.W@D<
M0K)(<+O;A03VYKU<EO\`6E97T>QQ9C)1H._<[>Y:.T662^FCM8(5+RS3-M1%
M'?/2OLHP<I<J/"E5C&'.8/@GQ"_BK1IM6&G2V%BURT5EYQ^>YB'_`"U([`]J
MNM25-VO=F5"M*;::T-ZL3I$E1)89895#Q2H4D1AD,IZ@^U-.VHI14MR#2=.L
M]+TV.RTV&"RT^#)5!B..//7VIRDY.\F2HQALM?(CEUC2(KN"UEUK3%N)RPB0
M7*G<5QN!/;&15^QJ6O8YXXVE)VB]A=2TS3=?L'M+R.QU6TBD$CQ(ZS"-QT)'
M8TESP=UH6JE*J_\`,N9R%]`H4>P'05F;J*BK(-I8%595<@["WW=W;/MFFK7U
M%-R46X[G$>#?'R:KX@F\,>(K(Z%XM@8@6KMF"Y`Z&)CSDCUKJJX>T>>&J..G
MBG>TSRGXWV4MI\;O#S:+$L>I7"HTR0.!(W/S;\?[(/X4JW)]0JJOLEU[]/Q)
M5_;Q=/N>GOC>V.F:_,%L?:J]A%^9@`1D]*>PWH9G@:34/&GQ"GL=.W6?A_17
M'VZ9DRUW)VC4D?*![<U]ODO#M*=!5\1JY:I+HOU/F,PS:K&JZ=/2Q]$@```=
M!7VBT/GCE?'W@#P]X\M+:#Q)8_:!;OOB=&*.OJ-PYP?2BX'S+-K(^$GC2^\&
MZ\SS>'_,\ZPN5!+P(W(!]1V-?+9_P]/%/ZS05I]NDO\`@GM9=F+H6A4VZ,C\
M6_%NWAMVA\%P/J5UY9>6YDB.V`>H'<UYF5\(XC$2;Q*:2Z+=^OD=V*S>ZM15
M_P`B]8Z[H'C[X:RR^)+U+40J#?&,X:&0?==1WSZ5Q5,)B\KS%+"QYKOW?-=4
M_0:KT\7A'[3=&;\,AXO^(YL?#OB"ZNI?`NGS">2>6+!N$7[D9;N#Z5]Q4E&E
M#F6DGT[,\",74E9:_J?2SL&8;5"(H"HBC`11T`KRF[NYZT(*$>5#:115UG48
MM&T2]U6XA:XBM5!\E3@NQZ?A2E+E7,;X7#2Q6(AAX.SEU['B>O\`BG6_$=LL
M&L72FUW>8L$(V@>BG'4"O,JXF4M+GZ#@\IP>"DY4(^]:UW^9Q5YX4T:[`\RU
M9&#%MR.0<GK6U/,\5#:5SDQ/#^!KJTH):]--S%U8:EX!N+?7?!M]=V>&"SKY
MA8$]L@]0?>O6R['/%2=*OJ^A\CQ#D<,#!5L.K1V:_4^H_AUXD3Q=X(TS6A<)
M/=2J4O65=H$XZC';BEB*?LYM'C86IS1L=$>1@]#Q6!U'$?%#X;VGCQK&Z.H2
MZ5K]@NVUO$'#CJJMW&#WKKH8ET]'JCAKX>_OP/#?`OV_PQ\6K[3O'T,IU^[7
MRX;ZX?(![,&/4,!@'WKBXCHSKX)3H/W8N[7?_AMR\LJ1IU_?UN>A_$7Q7_PA
M^C0W$4*7&I7,OEVULX)$@'WCQZ5\GDN52S/$>R5^5+5K?R1[^88[V$5RZMG$
MVOQ,\9:I'+%IOARVMKC<L:SN"/*8G`.#UK[*GX?OEE4DY.,=UW/.IXS&8B\*
M<-?,^GOA'X/G\&^%S;:A?&_U.[E:ZN[C&`TC=A["OH*4(TZ<:<%:*6A\Y4E*
M4W*6[.VJR0H`^:/C/''+\1+H30PS;85V^:@;'TK]#R.A3J8"+DKZL][!.]!7
M5_4XV%(X"QMX((2XPWEQ@;QZ'U%>O'#4HWLCK4K?"DO1'%W?A2W\1^,M/\,^
M&[>&VN;@F6ZD\_Y=HY.1[=<=:_/^)(X7"R2IQU6OW]#RL5"GSJG35N^I]7E]
M.\&>#$$LHM=%TN(+\S_*#['@DGTZU\'[]66G4V7)26NYYAJ?QYTQ;T_V'HVH
MZKIJ@;KN.)E`/<8([5M]64=)S2?:Y4)5:BYZ5.4DNJ3L=[X,\>>'O&<ERGA^
M^\^2W"EXW0H^".H5L$@'C/2LJM"=/XD%.M&>S-'QGICZQX2U"T@C:6[4>9`B
MMMY'7Z_2N:K'F@T>KE>*6%QL*LW:.S_KIZG@=O,D\(>-U8`[&*GHPZCZUX]2
M$H2<9*S/T6%6G47-3DFNZ=R2I+.,^(]R]U%::#96\UQ?W<BLB1J23SP!ZDU[
MF2T'SNNWHM#XKB['0]FL*E[SU/J7P!H*>&?!&BZ0MJEK/%"'NHE;=^^/4D^M
M;UZG/-L^3PL.6+9YOXZ^,%U;:_?^'/".GK<:G;%HY;BX.Q$.,'`/)(;/M6GL
MZ=*FJM9V3-Z-*MC*KHX=7:\[&)\.?B_?:/?0^'/B&'>2:4>5J;$853V?'!&>
MXK1TJ=>'M:#T[&5:%?!5?98A69W'QR\!6/C#PU+J9NC!J>FP&6VN@VY)(P-V
MWCL>Q&:C"UG3ERM:,QK4E-<\6>%>![JYU^-=8UJXEO;RT`M[8R_=A4#J!W;W
MK]#X1R;"4(2K4XV;D=&$G*LO:U'=K1>7_!.MN996C+F1VD3YD/<'L?>ONH1B
MG:VC.UR<M).Y]3_#_4'U/PAIES-=)<SF("21<?>[Y`Z&OR[-*"HXJ<(QLKZ'
MSF(AR5&DK'0UYYB%`'S5\901\1+O..85/!K](X??^P1]6>[@OX*]3B+F9;:V
MFN'4NL*%RH[XKU*]3V=-S[(ZFU%.3Z&W^R_82ZA)XC\5W3J[7$@MHT9<LG\6
M0WICBOQ;.L7+$57*74\O#-U*CF^I5^/L:ZC\6-)TRX=Y;(V"R/;ACMSZD5Y\
MZLJ.#E4@[.YW91AZ>*S!4ZJO'4ATW2KN>WE72=,GN8+=?WGV=<B,>]>!"C5K
MWDM;'Z>YX;#*-.<E"^R?4YHZ2VE7MOK7A4FVU*";S28F*F5?XD]LUWX;,9QE
M[/$/W;6]/,^=SCAR$J;GA8I3O?U\OF?1'PZ\9VOC70CJ5G$;.ZMY/*N;-G+/
M`P[L3ZUVUJ7(TUJGU/BJ51MNE4^);K]#E_'?PI76=4NM7\+ZFVC:K<X,\0&8
M93W8KV-'/3FE&M'F2^\WI5<1A6Y4)M7.4/P:\;`$KXOM">V8:7L\%_S[-O[6
MS+_G[^!U?ACX-:1I'B:PUV^U"\U74K?#!)CE6D'0@>@["K^L<L/9TXV7D<E6
M$ZU1U:TKONR3XZ?$>U\':1/IMM<NWBF^7]U'`_S6H/\`&Y'?T%7AL.YRYI;(
MPK5TER0^7]?U<\@\'Z`]C#"%@DNM9O6&]5.YY'/;/I[UY.+Q$\96Y(?"MC](
MR7+*67X;VE2RE:\F^AN?%CX?76FP6]IJI@DNY(O.M)H^,..J$?U[UO&-3+JR
MUT>YR5UA>(,+.5&+YH/2_P"#^?8]L^'5_>ZIX"T:?6]/^QW@@\B6V9,`JO`;
M'H175745.\7='PN&4K2A)6:?XGSKXM\/Q?#KXK?V?'?O)IFJQ_:$C`Y3<3M5
MA['O7V?"V8.-91D[)Z>5^AG0DJ5?EOHS<8$$@]17Z<CU&K'T#\!?^1#C_P"N
MS_SKX#B?_?GZ(\;,/XWR/1J^=.$*`/DGQ06/BO6BSNY^U-RYR?I7ZQ@K?5:=
ME]D^DI?PX^ASOB*4P^']1<123'R2NR/KR.OT%9YA/DP\W:^G0*KM2D[7T/9/
M@.8F^$'ASR?*R$D$GEXSG?\`Q>]?AN+_`(K.'!?"S#_:!\-75[I^F>)]&M!)
M=Z.Q.H21G$K6_;`[@<U5%*K3E1EU7XFD*SPF*A76B3Z=NI8^`GB6&'77MX[B
M!=,U1/,C:0X+2#H!_A7)E525&LZ-33H_T/K^):$,?@(8NC>3CV_E?<ZOXE_#
M%;J2;5_#4:QW39:>T7A93_>7T;^==>8Y8IKGIK7L>?D/%#II8;&.\>DNJ\GY
M'EGA#69O"6OSWD%LICN2$U&U88,@'\7^\*\2EB9TU[.3T7]6/J,=DF$QL'))
M*;U4E^3\CH+SXWZ9IVM7D&HZ%?KHJK_H%Y$N7G;NKCM[5[%*G3K1]R6O5=CX
M#&X3'8*HU6C\UJOD-'Q_\(9&[3-9"Y&3Y?0>M:?4Y=T<?MZW\K^XQ?$7Q=\1
MZU!<Z?X0T-](CF;$6KW+8D6+U`[,:SE5PM!7E+F:Z([J.49ABI*+ARI]7M_7
MD<=HGAA?MLEQ.)]:UF9_,>YD!=MU>;7QU?$OEA[L>R/LLOR'"X"/M*S3EW?Z
M'T+\//",/@JRN/$OBBXCANA"0$.-MNG7'NQ_^M7KX'"1PD'5JZ,^?SO.)9K4
MC@<%&\;_`/@3_P`D>(_&'Q=)J-Y>>(K-#"A=(X8ISG<@/4#L37!&4<;C.5K3
M\CW*RJY'E2A!IRB[OY]/,^B--G-UHNDW#`AI;*)\'MD=*TE'E?+V/BZ53VEY
MVM=W^\\-_:7;2_[<\'(@B_MWSR92/O\`D9^3/MUQ7T'#O-]:AVYCCJ_QXV[_
M`/#F3+_K'K]ECL>O+<]_^`C*?`J*&4L)GRN>1SWKX+BA/ZZWY(\3,/XOR/1Z
M^<.$1F"J68@*!DD]J$KZ(#Y)\3,K>*=99&5E-RV&4@@_0CK7ZS@TUAJ:?\I]
M)2_AQ]#+N(?M%M/!O*>:A3<.HR*NO3]I3<>Z+MS)Q[HT/V5]?AMI-:\)S'$X
ME-S`2#NDQPPQVP.:_%,VP[A4?D['D862C)Q9[_>6D&HV%W87N[[+>0M#+M;:
M<$>O:O)C+E=SMK0YXV1\H:=8W_@OQ5=>%=<5HWCE\W3V/S*XSD%6&,__`*Z>
M945.*Q-+YGO\+YG[.3P=5Z/;]5_PZ/I[X??$V#6)4T[6DCL[L(!'+N^24@<Y
M)^Z?;Z\UV8'-(5O<GH['%G?#$\-%UL.^:-]5U7;U_K0T/$/PTT76$OKJ#?'J
M%T"Z3ALJ&[''I6E?*Z-5.2W9S8'B;%X9PIRUA'2WD>3ZE\-_%-A-%%]A%Z67
M<9+=@RJ1V^;'->%5RG$0>BOZ'VE'B/+*\7)RY;/9K7\+E0>`O%)./[$GQ_P#
M_&LO[-Q7\K-?[;RO_GZOQ_R-/2_A=XFU*U,LL45D?,VF.Y?YL=V`&1712R:O
M+5I(YL1Q3E]"?*FY:=%IZ:V/7]#\/Z%X#TF:[9EBVH#/<RGEL#M_@*]^AA:.
M#AS?B?"XO,,;G%94UKKHE_7XGB7Q&\:3^++T[B8-'@.Z*!C@''\;^_MVKY['
MYA+$3Y8;=#]!R;**6547*3]]K5]O)>1Q/PVT)/B1X_CO+B#SO"VC',^^3:)7
M_A^4<G)_3O7HX:C]3H>]\<OP/B<[S+^T<0E2^".B\WW/IM5+,J1H`!\J(@P%
M'8`5ANS!)0B?+'Q?U>R\7_&2PCT1_,738EAGE92JED)W8[\=.<5]=PWA:DJ\
M$N]_D>?%>TQ"Y>YKN<N2.A-?K"6A[#=V>K_L\W%O%?ZQ;O*%NI=KK&2?F4=P
M.E?*\5PFX4YI:(\W,4VHOH>WU\2>2(ZAU*L`5(P0>]--IW0'R-X@$2>)-8CM
M@JPQW3*%48"^V*_6<*Y/#TW+=Q1]+3OR1OV*-;E&#K%C=Z??Q^)/#=PUGK=E
M^\W1_P#+8#J,=S_.OF,_R:GB:;JQ7O?G_P`$Y,3A^=.I#=?B>M_"CXQ67C6_
M?1]<MH=&\09_<IDB*Y]5Y^Z_MWK\NQ6!E1>QR4<4T[3_`.&.G^)G@>'QQIEM
M:R7)TW4[*3S+>[V9=#_=/M7+2J<EXR5T]T=4HNZJ4W9IW31X%J5[K'AS4+G3
M_%VCW$!M\"2]@C)A93P'R.QX_.N:KE-USX>5_)[GU&`XMLU#%QMYK8ZWPI\5
MKS3]/<:7KD+VSMPEV>8SZ`'H*F-7'8;W+/\`,[:M+)<R2K2:7H[?>=AH7QMU
M!(6@F2QU.Y+;E:.0*0/3`K>&:XBG']Y'YLXJG#66XFI_L]7ETVW-3_A=.HXS
M_8D./7S#3_MV79#7!6'>U9_<9NL_&36+B*(V45IIXC.Z5W8,&'ISTK.IG%:=
ME!6.BCPC@L.I2KR<E;TL>9>(?'][K5Q=*LFHZ[(7622&S0M%&>@YZ"I6%QF)
M]ZH^5/O_`)"J9QE>6VIX:-Y)=-[>;-_1OA1XC\5Z9(?%DS^'[??@6ELN]IE'
M4L?Y5T4:-#"RYH>\^[Z>A\]CLYQ680]G+W8]4GN>Q>$?"&F>#-&&FZ%9M!;2
M,'<LVZ25L=6[TJU:4WS39Y]%4XZ1>J,7XE^*%T32I].T]HYM=NDV)'NXMU/!
MD)'0@=/>O;R/A_%9I^^A[M)/XGU\E_F:.,JJ]W8\.T32(-)MA'&1+<'/F7)'
MS2DG/-?K6`R^G@Z:A%:]S6E1C2C9?>:-=YH=_P#`K_D?9/\`KU:O`XF_W%?X
MCCQ_\'YGT37YZ>(%`'F'Q2^'$>MA]7T-4@UA%S(@&%NAZ'_:]#7TV29Z\-:A
M7U@_P_X!WX3&.'N3V_(\%?=&[QSQO#*A*O'(,%2.HK[M6:O%W1[&^P"1000P
MR*=F/4SM3T?2M4F:>]A(NR!BYA;:Z$=&'O7EXO*,/B;N<=;&=2A3JN]1:]T=
MEX4^('BC1F6UUV[MM>TF,_+,1MNRO937R4^!8U9RM4:TT]?/R.>G@Y4Y/WM.
MG?YH]$M?B+X;U.**PN9EV7(Q);W$8*#OM8GZ5\_7X0S;#QE/E4E'JMWYHJ6'
MOJT17W@'X?\`BJY?59=%L[J5QM:2SDV(<?[([UXM26*PLO954XOLSFE@X\W^
M9S^M?`CP9J&H17>GR7^B;$VF*U;<&/\`>R>AJ5C9VM)7]2?JLX-.F[/NG833
MO@?HMA<0O!XCUEH4D#O`X!67'\)/8'BLZE6E4^*FKG90Q.84+*G4:5[]S;\9
M^%/A]8^&KJ^\2::+;28B-[+,0S-V5?4^U1AH<M1.FM3;,,RQF(I>RKU;K^MS
MSS3/C3:Z=ITFF?#KP9]D@W>5:7#*`C_[4A[GOUKWJ&2XO%RC)*Z?4\>E2<M(
M1;O]QDW?C?XG:KJ3W;:U:Z($"A+>,`HQ`P3WZU[F&X.JRB^?1HZ5@:TOBLAG
MAVXU?1;B^O8=?O+K4M04I>3RG*D'D[!V/O7TF$X6P%)1=>GSM:J_];'52PM.
MGJ]6*B[2Q+/([?>DD;<S?4U]+HE9*R71;'0V.H$(S*JEF(`'<TTK[`>N_`SP
MMJ$>H/XBNA]GM)(C'#$P^:0?WO85\CQ+F-%T_JL-9)W;[>1YN/KQ<?9K<]LK
MXL\H*`"@#"UKPEH>M74=QJ6GPS3H"`^,'GUQUKNPV98G#Q<*4VDS:G7J05HL
MH?\`"N_"W_0)A_,UT?VWCO\`GXR_K=;^8/\`A7?A;_H$P_F:/[;QW_/QA];K
M?S!_PKOPM_T"8?S-']N8[_GXP^MUOYA&^'7A9E*MI,)4]0<T+/,<M?:,/K=;
M^8Y'QO\`#>]TV6RU[X9F.QUFP78;"1O]'O8B>58=`WO7FX^M4QVN(?,UUZDO
M$U)-.3N:?A0>*=3,B:_X;BTAHX@V];Q9EE?N``/E'UKQ*F7S7PNYUT\='[2.
MA31[LN`P55)Y(;D5E]1K=C:6-I):'C?B#X;^+?B5X\@C\:VITKP=9AOLUO:7
M2L21T+<<ENY[5ZF'PZI+S/,J57-GKMO\./"MO:16L&D01P1($5%R!C_&O8HY
MIBJ45&$[)&D<76C%14M$+_PKKPM_T"8?S-;?VYCO^?C#ZW6[F7K7PG\/:C-`
M\"2V(C!#+`<!_KFNK#\1XNDFI>]?N:0QU6*UU*'_``IC0_\`G\O?^^A6_P#K
M3B?Y47_:-3L'_"F-#_Y_+W_OH4?ZTXG^5!_:-3L7-(^$?A^POA<3&:\4#B*<
MY4'UK&OQ+BZL.2-H^:(GCZDE9:'H4:+&BHBA448``X`KY]MMW9Q-W'4@"@`H
M`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"
M@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`
M*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@
M`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*
M`"@`H`*`"@`H`*`"@`H`*`/_V0``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V1U
M8VLN9VEF````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C$S-B`Q,#4Q
M-30S,S<U,2`P,C,W,#0`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````1TE&.#EA(``@`/<`````````,P``9@``F0``S```_P`S
M```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"99@"9
MF0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#__S,`
M`#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F9C-F
MF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,_S/_
M`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S9F8S
MF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9_V;,
M`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`9ID`
MF9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF_YF9
M`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_9IG_
MF9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS_\QF
M`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,9LS,
MF<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`__\S
M`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^99O^9
MF?^9S/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__F?__S/____B_
M)```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"'Y!`$``-@`+``````@`"``
M``C^`+$)'$BP(#8`"`TJ7%@0(0`K$`$PG-@0HL6(%"D^O&A18D:&&SE:\?A1
MX4.'*$>6-`E@A<L5@5BM2+BRX<L55E:P"C2SILV;,5V2K(FR:-&,1@,I7<IT
M*0NC!(U*G4KU(%6$>[)JW7/BZ=6O6+#N`9`5H=>O4\<^(LMV[8FK5M,"6`L@
M[%RV4P=2'7L-*\*^;Z7J!7#-RK5K._T>9KMX+("8A?M*)'RX<F6RC@?5Q?K6
MLF6'AV<Z7-%7*P!2`$YP)2RZY>*_G@^S.NV0E#'4"%$'BMTW;M&^MX/;'FZ,
ML&"0"(4K=^A3X&GEPX<2=;B<N<_GQ+/?EJ[1]M?M$XL\BIX9+'NPE@A;#TU_
M,^O,"U()8+XI^B!]EWM$$[A`H']__BWE=U]+]PE5%@`7))B@7P4V:.!614'8
M8$```#L`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V%V871A<G,O96EN<W1E:6XN:G!G````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#$Q,#8U(#$P-3$U-#,S-S4Q(#`R-#8Q,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#_V/_@`!!*1DE&
M``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_;`$,!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!`0$!
M`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#!04$!````7T!`@,`
M!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I
M*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'
MB(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7
MV-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!`0$!`0$!````````
M`0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1
M!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ
M0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25
MEI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3E
MYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/QM+`9X/'4D8`S[\Y[9_P`Y
M4$$`CH1D?0TJ_P"NC!!EVGYHDC9EY!(W.,`\'/&""<8R,TVYFCM87O+WR]/M
M/MDD+3W4]I;;(_-*IY%E+<BYN0?E"NA4%3OV``@<E>K%7MB%2:TVB]4XWW3Z
M/?[ANEB7%.C2==R2T2>C=M/=:;U]/F<)\1=+T?Q'X>EA\0WDMMX>TP-JNKVU
MO'J!L=3DT3_B;26NH1:5;WFI7>FXLR=0M[*SN;BYLUG@MXGE=5K]/_\`@F5_
MP4M\5_LEVS^*_`_QWT34_P!ESX>^.O#7AS]I#X3:SIFBWOB'P#\+_B3J.O?#
M7PW\5?#^DP:GX!\8:Q!X=^)K^&-&\2:-X%\6ZWKGA^?5K/5K3_A*="M[O[5\
MH?LG?&?P/\#/VG/@7^T'\6O#\_BC]E7P]XS\2>"/B[XNT_PE;^*O#W@?Q7XQ
M^'GC#1O"GB$V9\1>5=7?AOQA!>:MJW@2>SUC4K/1_!NO7DE]>B`6[>[?M?\`
M_!&/3-._;]^'OA3X6KJ$/[-?[9VA?&O4/AAXCL_[,3PSX8^(,OPZ^(?Q.^'O
M@"PO[#3?L-SX%UOQ`NDM\-='U?\`M7Q-X:\(13SZ_P")]>\3V,'B:#P)9E.I
M+]ZKI-)ZI:)QYGTZ)N^EW;?4^BP.25*F`A7=1TL6IISPW*FY1T=K2O+WK-:6
M?6ZW/V^^"/[0G@K]I#]I?]L;XO?LW^%/B=\,?C!#K%QX5_;E_8X\!^+O#OB2
M?]K7]D^9=6^'?@S]OSX07&F>#=-T^R^/?@"1EU_PWHG@_P`9>+=4^)V@>&8O
M"=A>:OIOQ5^%WQ&\97_V1_\`@G/_`,%(-8T+]G_]ES]H?Q5\.?B+^Q]^R+^U
M-\(?VI?V=?VA=9U?6?"W[07B[PGX`?6M:LOA?XN^&LEGK/B3P)K6HIXJM)O$
M>A>,(M-F^&\.EV'A"VN_%#74=S7S9_P0?_9'^-GASXY?`7]L?Q;XZ;P]IUC\
M"O$_[(/QS^$7B#2+G1O%MCXP^$5YX9\,^&-*T&^LWTU+3P-H-GX*\(75YJ.I
M1ZR;_4/A_K&G6%U;V3Z+IFE_I-\5?V[?^"AW@/\`X*M_`[]C#PKXX_88\5?#
MOXM-K_C&;PYHO@OXV7GC?X<?`[0O!OC#QK=^+?B=XGNO':^']6\9>*--\(ZE
MJ/A:Q\+VROJ<GARUT:TT&QTR^UOQ-I?K8#&X2OS4Z=6*FK1Y$[MNT=+MM[?R
MO9+7H>7F&78["3C.MAVX5$G&\6G%76NG3OOYZ'[RWOASQ/<WEW<KHG@:Y6XN
MKB=;B>S\6033K+*\@FF@33;A(990V^2);B=8W8HLTH4.Q77R^)=8$L@C^&WC
MJ=!(X2:";X;>1,@8A98?M/CFWN?*D&'C^T003["OFPQ2;D4KT[+S^]_YGEVE
MUI=NK_N7Z^;/\RK_`()X?L'?%C_@IUX[UW6=0UG7/AK^R/X9URZT?7?&.A/$
MOQ/\<:^EM</IWAKX?6M]$^B6VD0W<,0US6=5MI;B&&TU$P749,83^HWX"?\`
M!*']@C]F>RTS_A%O@UX2\<^,=+N?LTOQ`^+VE6?CKQ`XBA:SN+[4?[9DU7P[
M<:G?KYLE]<Z7IT-A)=SRS6$4,!A5?K']GKX$>"_V9/@[\-OA%\/-.T_2]`\%
M>$?#^CW]SI=A::8?$^I6VD0Q:KXBU?[%%`-4O]>OY;W4KK4+P3W-Z][)<7$L
MCSNS='\5?B?\,_@K\-O&GQ=^(>NVW@3X>^`-"N]:O=:ELTU"&RTG1%CNY+V#
M1BC)<M%XC%GX7TKPZD6S7[.Z73HX98)?*/XCFV8YEC<>J-&=2$8RY&HSDKVE
M;F>OO-]6WKMHK(_I+*.&,MR3!T\?B?92YJ4*LHRA%I-Q@[:II:Z:+;5WL?D_
M_P`%K=-\)>`_@'\,/VA_$NCZ/XA^''P:U#QWX*\7_#*336TWP_K/AKXX?#C7
M?V=M)UJ8F%[+06\$>,=:T/QCX;U2WMXCX5\0Z.VNZ3]DU"[U&>[_`)B/@;^U
M#X6_8M\,?LV>)/V:_P!HO7?B9JMQX\M?C'^UI^R3K'@B3P[\,?`%S\/_`!/%
MXJT:?X8?%?6[O7_#FDIJNF1OHM]'HVD:$FN27=OX5<2:=KUSIDG])7[5?Q7_
M`&R?CG^SA\2M>_:@_P""?GQ#^'__``3B\;Z!H&N^(O'_`(7^)_P[\:?M2^"/
MA=H/B[3?%FF?M&WOP5\/:.NN:#9_#SQ-;:?X_P#&7ASQ!)?:!;>'M.US4O$F
MA:GHZ:A;7GR;^S)_P1<^&/[0EG#X^\??M:^"_CI^SYX]\.:U9^%_"GP-\'^&
M_A+J'BO2M6M6MK/5_B?KWA*QTVT\8>-O`@:U\4R:;900WZZ_X>L;B4&.V=*^
MHPM>O@,'&IF%-3]I**?.U/W9*%KIWU2<NO>+<6M?@LRHT<[SV.9Y-C*5*<'"
M+P=&\(MPFG91BDN:6BTB]6G=F=\/O^"F/[2W_!0WXJ_#[2]!\?\`P>_8&_9A
MM_B/#XT\6Z]KOQX\':S\>3HNEZ_IWQ&T;2DTOQ/I5\/['O\`Q'X3T9)-&4Q:
M-/:7VIS7]I=6][J5O??IG_P6#TW3==_X)D?$;]J#X>>*1-#^SMXV^`OQ7^%W
MQ3\&7^FZSK6M_$2Q_:#\#^$=%\4^$];T6%-!\3MHQ^)?B76]"T#Q)8ZY9:?X
MG_LG0]"TZRTJYFM*^5OV#_\`@GW\#?@U\=HOV(OVQOV8_P!F[X]07EQ_PM?]
MF_\`:CN_@GX+UBY\?_!R'4AX6U#X=_%GQ)J'ABYU75/B!H^BWE\='O-:OKB]
MBUN'3&@D698I!^EW_!/KX.:_^U1XP^(G[3?Q>\0^"O#O[$_A7XG_`!8^%'[#
MO[&_PX?2K#]G#2O"7P;^(VN_#RW^.7Q+^&.GF#X:^,?&^E:[X)OOB#X,NO%7
MAZZDT&WU/3O%>EW5IJFA:/<1]>6X7"9ACH8O"35&>'FI<E)<BGR_S1CNK22U
M[+317PXCS''Y70AA\=156KB8KV+J>^J;DTGR<R]UW3O):ZWU;NOR[\:_\'-7
MQ=\">,O%O@CQY\`F\->.?!OB;7O"OC/PY<#XS6\^@>*_#VJW>D>(M$FM[+Q+
M#9P2Z5K%G>6$D-I#%;1/`R01I$J*"OY\O%?P+_;=^._BGQ+\<+:+7[NV^,NO
MZQ\5K>Z\0Z)X9U/7[F#XB:C<^+XKC7-2NC-<ZAK$T>L+)J=]<32SW=ZT\\LD
MDDC,2OK_`/:OYI??Z?Y+[OO_`#GZUB>D$MM.WPZ;>?\`6M_T-^'_`/P7W_;]
M\&Z)IWA;XF_LT_"CXGKHNCV&@Z?XH\)R^//#NKZC%I-I%86%WXHGN]3\0:!'
M(MK;V\4UQ86=NUUY8FG`O)9G/ZU?\$UOBM\8_P#@K<^O>/?VH?!?P7\#?LX_
M!3]H?X2Z;<_LY^$['Q1XRU?XY?$6TM/.\+0?%G7/%FMZYX9UGP'\/UB@^)2?
M"WPQX2\-IXD\7^&]/U+699IHFB/\U+`J$+`J)#A"PP'()!"$\,<@C`SR".U?
M2G[&W[3_`,8OV+_%?Q#F^'LWAS6_#_Q1\1>"_'6N>!/$G]IZ;)/KWPROX=;\
M+:EI7B;0H-4DMYIKW7[BX-G-IIG1=-O('W-'.8?(H91@,+.GBIQC*<8QE/3F
M:E[O,Y)WW=VU;>]K*Z7MU.*\_P`5AG@IXR<H-<D8).34;12A>*=K+1WN]$_,
M_P!'/3_B#X5U73_'-I)B"+P5XI@\,>(&1)>;S4;B"Q%PZVSQ7$DTQN1'.T4J
M7$L;/&LBLX(_`CXU?`?2_P#@EO\`'67XS?"B*R\$?L#?M$?%'5[7]H+PLUE:
M:7X._9A^.OC@Q-\)?B;\+(+2STV;PQ\-_BMX[31?AS\2M,M5DN?`WQ+\2^&4
M\&WV@Z7J&IZ?=?EQ\'/^"X?QJ^)GQR\9?L_:?^S?\-KZ[_:JLM<N?!^H^(/C
M?>:/I/B_QW:Z-?WVBP6'B.\^"^L1:%KVG:A;07]GX*\7:+J5CXJN;:/P[J$4
M-KJ<L\7U7^TM^V]\6/VCOV0/B?\`L2?M2?\`!+;]LKQIXV^(/A>Z\+:Y8?#3
M6_`_C+P8VI:-<VVN>"_$^C_&V.\3P\M[9:QHVE:GIFL6OPCTFQ\,W5E:QWRQ
MG?,NF/6`QF&^KUI<DXI\CT5I/X&EMOMYZ&'#E+/LNQ\,?@\$ZM!5J?MG=32B
MIPE---NS<=5I>^VBU_:$R+;R6NHZ?/:PW%AX>86<MEJ%O:?8Y+AEUW3-6TF[
MU-;FSM-+\2:W!80:3XLN8+C63XBO-.NY[FZ>,1-_*1^S[XZ\&_LO?"[]NW_@
MFY\*OV[+;QY^QMXE^&'CG7-+_:#T'POXBTSQK^S!XTU_6;C0-;\(>(=1AT;1
M/"WB?PM\2/!WAS6-)NM2T$V-EIOC"+5O%UOI$NK7,=_8?,%O_P`%!OVC_!'[
M)^J?\$Y/B'XU?PSXQ^$OA'48/VB/VK?#?B:VU3Q1\#/AU#XB?5-(^$NI0:'%
M+X*\0?%&S7Q59?!#7K_4/%N@2>&[[4K'PM<:,WB;P!J&E7F%^P1\*/$_QFA\
M$?$*V\.S?#?]DCP%X@U"?P/\'K^VNM;F^+_B[P_;W5[IWQ0\?WWDZ9_PD$<7
MB6.QU:>UT:PNHM+\2SZ#-/?%(-LT\&<'8R&(K8C$8QRPM:=Z7LU=Q5DK^ZN:
M.ENB\U967UO&/$&"SFA0C'"NGC<-#]Y*2:<7O=.6KLVTN5Z)]7=OPCX?:O\`
M\%.?!/@+P1X,\,?LK7?B7PUX1\(>&O#'A[Q':>"9+JU\0:'H&C66E:3K=M<R
MW[2W%OJMA:6]_#/*QDFCN%D<EF)HK]_+KX;:@UU<M)XJ\4-(9YBYLIX5LRYD
M8L;12S%;8MDP+N;$6P9.,T5^G_ZI8;_H.J_^`S\O+S?X=F?G7,OYE]_]=E]Q
M_.?/+)!%>O#(\+G3;LEHG:-B51PI+(020``"3D8XK$\'2/=Z&QNW>Z)AA)-P
MQG))1&))E+9)/))Y)YZT45^=2_B8S_KW_P"VHUP/^]K_`!/_`-M/*OVK;BXT
M?P+#K6D3S:5K&D>-I)=)U;397L=2TN78R>9IU]:M%=64FUF7?;2Q-M8C."17
M]W'[`/B7Q'K?[!?P5UO6?$&MZOK*>#Y@NKZGJM_?ZFH30+IT"W]W/+=J$=59
M0)1M90PP0#117S>8?[W0_P"OE'_TY3/U?A+_`)$V8_\`82OSI'\&=C=W>I_L
M%?M.:[J5U<:AK?B;]H7X+VOB/6;Z:2[U7Q!;7O\`PB&JWEOK>HSM)=ZK!=ZH
MB:E=0W\UQ'<7ZK>2J]PHD']:OP2TO3-*^$_P]L-+TZPTVQ@\-6;06=A9V]G:
MPM/9:=).T5O;QQPQF9U5Y2B`R.H9]Q`-%%?M?!?^ZOT_2)^<YW_R,ZWHOT/5
M=B?W5_[Y'^%%%%?8GA'_V0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V)A=&UA;BYG:68`````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,C$Q-"`Q,#4Q-30S,S<U,2`P,C0R,30`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````1TE&
M.#EA(``@`/<`````````,P``9@``F0``S```_P`S```S,P`S9@`SF0`SS``S
M_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"99@"9F0"9S`"9_P#,``#,,P#,
M9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#__S,``#,`,S,`9C,`F3,`S#,`
M_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F9C-FF3-FS#-F_S.9`#.9,S.9
M9C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,_S/_`#/_,S/_9C/_F3/_S#/_
M_V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S9F8SF68SS&8S_V9F`&9F,V9F
M9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9_V;,`&;,,V;,9F;,F6;,S&;,
M_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`9ID`F9D`S)D`_YDS`)DS,YDS
M9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF_YF9`)F9,YF99IF9F9F9S)F9
M_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_9IG_F9G_S)G__\P``,P`,\P`
M9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS_\QF`,QF,\QF9LQFF<QFS,QF
M_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,9LS,F<S,S,S,_\S_`,S_,\S_
M9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`__\S`/\S,_\S9O\SF?\SS/\S
M__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^99O^9F?^9S/^9___,`/_,,__,
M9O_,F?_,S/_,____`/__,___9O__F?__S/____B_)```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"'Y!`$``-@`+``````@`"````C^`+$)'$A08("#!1,:
M5*CP($*&`Q]"C.APHL$5%@TZ#&#QH)6,V`X"0$"R)(*"#C]V#&"R9<F0*3.R
M=.E2P$:5$$?:W!A`@`"3.SU.!!"4Y\&?)(OB;&C4*%*E.9LV_<ES*4JI4ZM"
MQ,HU)L.#@59T;7KR:X!`@0",Y5DVH<-`UP))74&7;=NK`:R@W8@6+:NT=K_F
ML:*6[[7#UUB1O4LPP+-G5HS"C2N5),6(CR&OW6A9(,F-F9]YM$)Z8Y4J@3V;
M=!RZ=>;3J#FW;<G:=6O8=LNNSI,YCV_?MT_G/KFZ=1[$O%]7(6&4)H+:CW__
M?@S;0'.7!VWWIB[\.NWDH8$JASXMUOOSS^"U<R_L_2!)`.EMGV:.];/[YP&J
M:!=NG2O[F?CE-UYY:P4$`#L`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V
M871A<G,O<V5X>2YG:68`````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R
M,38Q(#$P-3$U-#,S-S4Q(#`R,S<T-``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!'248X.6$E`"4`]P`````````S``!F``"9
M``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D`
M`)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9
M`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`
M,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9
M,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`
M9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF9
M9IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``
MF0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9
MF6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`
MF?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9
MS#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`
MS,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9
M_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`
M_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9
M___,____^+\D````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````(?D$`0``V``L
M`````"4`)0``"/X`L0D<2+"@P8,($RI<R+"APX<0(RH$H((@@(L2$:I0D2K5
M"A4?4S5+M7%%QH$<FTT;F6J4R&DK1YK,""#52I(;<[Y<"9+FR(VBC`DU)FJC
MS6DD)5(<Y20HLZ=0B3IYZ1$B1Y*BH&J%6K29UYD.57A588S9T*=GC0'PV@QL
MPZMDC>44.I>N2+<+5;A4D959J3VEGOX-;+9HU;`=`93U6R*NBA*$S7+$JU#O
M*,6"-])5$5GNX;>C+B\VNUBH5L^4)V)%N]4L6L.I$\*E.UKRT)2Q-8ZEV_=I
MT:%KFU5\F)(O,U%-A2+/VG6L596IDA?-&13YSL\,Q<+$*:J[=Z,PMT_G-J@=
MYD^*);&M./H38DVVS2X?A#L>X<7[`!+>/\F_O_^#^&&SGX`$YD>@4A8EF)^!
M!D84($8#,3C@20LJF*!2^PU888#_=>CAAR!Z&!```#L`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]L;W9E8FER9"YG:68`````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(R-S`@,3`U,34T,S,W-3$@,#(T-38S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````$=)
M1C@Y824`)0#W`````````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`
M,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`
MS&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS
M`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,S
MF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS
M__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F
M9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QF
MS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9
M,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9
MF?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,
M`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,
M9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,
M_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_
M,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_
MS&;_S)G_S,S_S/___P#__S/__V;__YG__\S____XOR0`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````A^00!``#8`"P`````)0`E```(_@"Q80-`L*#!@P(3
M)CQ(4*%``-<B2IQ(T>!":A@S4FOX<&)!CP0I7@,PD)JSDRA1DAPH$<"NEQ!'
MOMP5,^)*`"93ZB09$X"PF1!]`O7X,*=.E2Q=[A*6+%(DI;MJ[7IJLZ@S@BD!
M(`WZ,EFR6DY?UAI+=65)K5>-&=.*]5A(I<F$D1U+M^Q%E,:``4-[TBW7J'+I
M"K9;\N2>/0#T`MB#TJ],L8+K$L:Y<V]*QX^C1G8:].Y.OLXP/XX,EG#ASY=#
MMH1,ENK(HJ"/]E6].JI3UV9Q4HZ=NN;JVST?ZC;I5O9LEA6?!A=..33OQC=%
MULR-L7EQXVX7^FYYU_ISZ`X9EE(_J?68^>_.':H/G[/\>>/IUZ]O3KX@_/CR
M%=*_?S1[_H7'\"?;>?^%9YZ`E_E7H'8'\G>>60OJ!X!Y%%9((4<1JD>0A1SZ
ME6%^XB'TH7RLE&@B`":R@F*)(RJ48HHKEABCB2.^"..-,[*2H8TWGI@CBQ'R
MJ")!/A*9XHX\%E1DCA_:B.*3*_ZH8Y-.5GEDBT)F.65````[````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A
M=F%T87)S+V)O;RYJ<&<`````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q
M,#<T-"`Q,#4Q-30S,S<U,2`P,C,U-30`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````_]C_X``02D9)1@`!`0```0`!``#_VP!#
M``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_
MP``1"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!`0$```````````$"`P0%
M!@<("0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q
M%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(
M24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*C
MI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ
M\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0````````$"`P0%!@<("0H+_\0`
MM1$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!
M"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=8
M65IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJ
MLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ
M_]H`#`,!``(1`Q$`/P#\`S\;SI7Q@@\#^$)%\,>%++41)J][IUG+:W?B#0-'
MU*:WNK":YM;:RDM_#NN26DU[)I<=E.!`+=)%9O-CC_=']B7]MGXP_#>2]TO0
MOB-XMT30K;63KVEV5MK7B-8[32KT6QM-,%I:ZG_9=O97(GMT,"6US;)%!+`U
MBF`\WP-\<O\`@DC\>_V%/VQ?B%I_Q::T\4_`[QCKNJ6OP$^,=MJUAJ4/Q$L)
M?&*ZAX-T?Q'IFB73ZUX&\86UO:W]UJF@:Y8VVGSZGI>H+IFM:UH9LS<]UXGU
M32?A?X%\1;IUTZ^LXKQ]?UQVN(X_#ND66G7EW=ZC=K)')]K?2XM+^W0V\:23
M7YLA:QONGE63^2?&N&&Q>:Y7E.!J5)YO['+I1QN%JSC7H8J5:$WB(8BARUJ5
M:BFX2A3J[*G&G3J3DG+^Q_`2AE6)X?S/&9O1P5;+XU,7'V&,I0G05.G3A&M.
MLJJE2=.,5/GE*+N_=M:*D?T:^'O^"DW[3?C:XL/$6G_$W2].MM+TW3=,T^SO
MM`MHM(U:*]@GO[_5M5AMW%T-9M98A;0W]NBM+#-Y-Q;P1M)/6UX?_P""P'[4
MFA2ZE:W7AKX=>,+N[%CJ<4VH:;KT<>C0V;Z59ZC%#%IWBG2K:;2I;9)&2.6Y
MCGMM7FU">&2ZCG,,7\['[+'[1GP>^+/AJXU?0/%$_B2'2?M6A"2XTG7='6'6
MH_[%7=!974(GN5MTU"WE,[I)%/:SY0AX\I]/^'(9;OQ7J,NLW4T]AJ%M%'I:
MFWEMA)!+&/(4R1K!-;16KW<$VR7,LL)AN)79YFV_C^+XT\1N#<SQV#S'.<_C
MC<OHM5:682QRQ+J-Q4>>EB&X\T*<J4I1JTFI)W=Y7O\`:T_"3@3B_!PS+(L%
M@/[,Q&(4,%5RZA!T*M*$U[2U2BE.4.:-36,DDO=>JLOZL/@E_P`%:?@#XQTG
MPM;_`!535OA/XPU:VOAJD%WH^IZIX0L;NS$JK%#XATU+U4CE@L94C^U0KYEX
M#;PNSR1[_P!(/"'Q<^'WC[2-+UWP=XMT/7],UFQBU33IK.X=9IM,EBBF&I26
M-RD%_:V4<<T1N+BZMH4MF<17!BF!C'\*OQ+\63^%[NR2VN/,LK&2&:&S5A.;
M8+Y,CE)WFU*4?,S2AC=#8Y9\$EU/S3\7?C5KFHZ1>E_$U[%X;.FVEUJNGG[0
MUI<:C:68N+)C'(GDW-Q#ILMO86R1Q"SA\QKUX\0W(?\`2^$?I!<98FIE]',<
MDRS'83%0@WB8_6<-C9-PI14+T/:T95G=-Q^K2<I32]JE91_/^(/HW993P^*Q
M639[B:%6A%S^K8J%#$8=I25]4L'B*25.7-RRC-_NYO9I/_1.N/B=\/+.XGM+
MWQYX.LKRUFEMKNRO/$NB6]W:7,#M%/:W5O)>K)!<6\JO%/#(H>*5&1P&4BBO
M\G[4/VS=:TR_OM-MC#%;:?>7-C;Q_P!J:7#Y<%I,\$2>3_8Y\G9'&J^5D^7C
M9DXHK^@8<5<75(0FN%Z24XQFD\15NE)1:3M%JZ4K.S>MM=3\;?AM@T[/B?`W
MO9VI-KILW4NUV?FOG^F%E\7?'?QT%KXH^*WQ!U3Q3<VVG0V\5_K'BO6=40X5
M9A=YUS5-1NGN";E[J9WDC<PQD%"Q<'XK_:]\/_%;XK^`M<T'X2W6E_;-0U"S
MT[Q-)<W?V4:IX/TX74VI6D%Z8[JR_L[69A8V^HVU[&T=[ILE_:WL3VMPT,GV
MOK?P:U7PY\"-#\7:4D]O<ZKXFGT9()3F21?[&M-2MG:2S`$4FV2=%>9S&PLG
MB*[I%+?.5GX.\8>(9K;PWI=U>VFL7-XLTEHD\A2XM<I%?3).+^TB_=C+RVDR
MYD1?W?F.WEK_`"5D694\#G4<[I5L,WEV/C7H4L>EB*-)473KQJ5:<JL95()Q
MBTY2;<FFE>"M_:V;<.Y;F_#N.P.&4<#A,7@L7EE6>74XX>%"SC0K\M2C2G&G
M?GUC)6BE9VYKE7_@GE^SAXP,7B[5=:T;1-`\3>+/%GBWQ7/HGAAM(L_!6D7N
MJWL\"V/A#0O#&AZ5H.D:(=$^RQVEC;V#/IBP/'8O;Z1+%96WZ\^,/@-XB\+:
M=<W>MVKV]MK-N9++4;>.6/3M)C@NFMY+>*0V'EP7)PKW7V9[CSO/17\O`%=9
M^Q!H?AGX406EOK,+WTKZI973WEU$+K<TWA^QAO3:VS))/:P75Q'J&+7)?;Y7
MFET#F3]JOC)+\#?B=\-+3PN]U#X>U"9XKNRF^S2QO!/>:E:WLR6HM[0P+;^4
ML<$^1\C+(&/&:^!XYS'/.->(,ZXHGB</%RG&O"FU*FL1&A[&FJ="K.,U&*I4
M7+DJ-\TDK-N33\;(,=4X`P7#/#."R[,Z^386,\,\?&G4JQIQE.K7EC*E*DI-
M*5:LYJ=M(N]MC^!V;]HC5/#7[>GB+X<^,M?\:365KX<T[PYX>L]+U+0]'\%+
MXDU#1O#&JQ>*O']IK,.IZKX@AA\/:KXC2U3P_?>#?$VE>*]'\-WM[JVMZ5<^
M)-+U+V;]H9+^S\"7UQ:64QT2"TO)KM500B.QQ.;F6.0RVMA(\-C$MM+]I18$
MCCFCB+6T,0KZ8^+OPM\&^!OVC/&;^.?`GA_5/$6DWT=UX6\47?ARSNM:EMM0
MM+>25K;7/LV]=.CCDC@CM[EC"D4"6]ND;#)V_#FEZ5JEIK-GXBL-)O-.&H33
M"RU9+>;1Y8O)1G-U`2UK-'+$6@E@>&1W@:0.I#JU?I^8\79-;@O,<#D4</\`
MV+D&5X?&QH^P5/-ZM-R=7%8>6'CI5J3J2526)4JO-.$92E&E!+@R3A;B3#T^
M-\1B<X>,I<19[CLURW$3J59K!8?&1J.E2E&M&G"-.BWR>PHQC3?-*5DY2;_F
MZE\/:WJ<LFI6NE72VVH2/?6ZPZR8X5@NV,\*Q()W"1".11&@9@J8`8XR2OZ;
MKG]H?P?H-Q/H5CX"\`6EEHLTNDV=K;^!K=(+:UTZ1K.WMX4M?#$MJL,,4*1Q
MK;2RP*BJ(9'C"L2OUN/CEG:452\/,9.FDE3D^(\&G*"4>633P":<HZV:33DD
MTNGX-/PPKN<G4XPP"J.3=11R^;BIWCS)-8BS7,M&M&FK>?[JV/P<OO%'[/WP
MY\'ZNMB+>VMM/B2PCTR:"]M-0DTHQ7#F>\>-WTV"&66XT]=$BN;-%N'5+N6T
MBFE3N?V;?^":FDZ=J_\`PGWB&UBU)+J348M'EO+::]2!;Q[4VUW'!+J*I;S0
M>6SI/!:07N#L2\4`(GZ$^#/"UMX5\+VGA74M'UB^T6V^S;KC3Q#J>IQ7J1&&
M\T[[5:164-QH3Z?%N>VBLC-%-)-<7$K02(D?L^G_`!)\+^%_!-YIOAR[MO$>
MO:?IE]<Z7X2DF-KJ=Q'8VTRVFF6J,CS)?B^%E800B&57DD>-&+%%3\2X-X3P
M>.S;"XC-:\:5.EAH5))U8TU6Q-&$(^PG1=:-3%4I<LVE!5'-N*C"7O6Y>(O$
MC.\-EF9Y7DTZE+"YGF%>5>%-3G2]ABJTJDKUHIT,*_:*#E.?LY+W_:34531_
M/E\??V=-1_9O^*[Z;;ZQJT_ASX@ZYKVL3/HUK<SW6E>(M8\0QW8UR:+5+^:Y
MFL=-L+S5O-TZUU&WC9(7V+-(T$$UCP'H&N_&;Q5X1\#_``U\6KXVU#3[N>X\
M0@>%&M)=(MM7TK36TB$W>NR:=%/-]DN+J\\K3M1$$,6FR#5/M-U-I]C7U-^V
M1^T+\7_%?@'4;CPO^RE>+\21ILO_``BNI^-I]2N+2TM=3GMK=[J6TTK1+#4;
MBY@M)KN.6W@U&R^R:B]JLUS);W$AA^S/V(O$GPD\/IH<_P#PI3QI\/?&/B2U
ML=.OS+X;TS7_``Y;7^G6-Q%+?+XMT&QL9HK1XHMLK:UI5E/:^9;V0N+J.);N
M7[N7`N1YKF$LO>)G@,NQE2$Y-*MAI3A7UG2BJU*5ZE.O*#I\\8J,)6ES**M^
MIP\8,WR?PPPM7%9/3QF;TJ;R^GBZ6)R;%T)5J4'&&*KX>C.IF$J,</%7E2E&
M%6M37MHS5.FH_E__`,%7?V$/#GA:Y\"_$];A-2N(?#$6C^(1?6]NC075L=/M
M+*ZMM1@GN;E))H#+YD!LC9*D6Q)_,D1J_/-OV7M#^'_[*UW\4M9T2.35_$/C
MV*UT'PT=0FMM4_X12/P?<7UQXECTJSOWUO6+>XN$ATF.>RLC&UU+'!$GVEEC
M?^S/XO?#SX;_`!CTD:7XLMO#6KZ3Y]J)6U.+3+BS>*WC:1()7OHI;>&.60!"
M)$^=Q$L95@`?Q-_X*5^&C\4=&\`?#C]GG3[K^Q?!ES#X:UBU\#W\VGP:)"UO
MK.EW%QJMGX;T.1V\(V,%W!8ZV]YXCM]'@>[MHK[2H;BXTVYNOB.->#_]5<RQ
MDL-CE'AJA.BLGP:Q,ZM:;E3P\9U*5G)5849RK8NHY*[G."LXIQ/"X"\6,9GF
M599PQ7C-YG+'5:N;YUB)4Z>$_L_#RJUZ-*I*$(U*<ZU11PDI*<83H1C3DI-M
MR_EI3X(:9JB)J<NG1Q2ZBJWTD9U?483')=@7#H8KG48[B(HTA4QW$:3H1ME1
M9`R@K^E[P+_P3_L8_!/@Z/7(?"]QK4?A7P\FL7!5(S/JB:19KJ$QC6Z14,MV
M)G**B!=VT*H&`5Y:\0N(HI1IU,0J<4E!.6(NH+E44]=U%6\_FSU)YCPQ&<HR
M>72DI-.3JXB\FFDY/_:4M7KTO?S=OTJTR\N[+PC916=U<6D5SK-R]Q';3RP)
M.\K1K*\R1,BRM*L<:R,X8N$0,2%7'YR?M&>*O$_AZR^'>HZ!XCU[0]0NI=*D
MN;[1]8U#3+RX=I]0G9Y[JRN()YG:>""9FD=B988I"=\:%2BO;R__`'W)?\=+
M_P!*1^#S_P!VS;_!+_TNH?M5X`TW3O$'@+X?WNO6%EK=Y=^`HY;J[U>U@U*Y
MN98TTQDDN)[V.:6:1&GG9'D=F5II2"#(^?)OVKI9/!?PUT23P=(_A.234-)B
MDD\,NV@N\5UK-M%<QNVEFU9H[B/]W.C$K,GR2!EXHHK^AL\_Y%L?^P3#_P#I
MJB?F6"_A8;_L:8C_`-)K'A_A7Q'XAO[".&^U[6;V*?2].EFBN]4OKF.:7^TM
M;7S)4FG=9)-L,*[W!;;%$,XC0"'P[I6F6_Q"6^M].L(+V[\<RZ5=7D-G;Q75
MSI=])$;W3;BX2-9IK"\,LINK.1VM[@R2&:-][9**_G;BG^+EG_7Z7_MI^I<.
M?[MG?_8'+_U*/M\Z+HX)`TG3`!P`+"U``'```BP`!T%%%%>-4_B3_P`;_P#2
MH'AR^.7^+]8'_]D`````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O:&]M
M97(N9VEF````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,3,P(#$P-3$U
M-#,S-S4Q(#`R-#`V,@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!'248X.6$@`"``]P`````````S``!F``"9``#,``#_`#,`
M`#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9
M`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``
M,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9
M,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`
M,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.9
M9C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`
M9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9
MF0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`
MF9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9
MF?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`
MS&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9
MS,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`
M_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9
M_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____^+\D
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````(?D$`0``V``L`````"``(```
M"/X`L0D<2!"`00`$$RI<F/`@$B0D&$ID2`+`0Q(8,T[<2`()`!(J1C4;V6R4
MBH@;%W8,2;)E214I58YRXK+E*)0Q!ZJH61-F3H$D1/*TB3,FB:$N38+,N9/G
MJ!505ZA@=8W5"J-.K5"MNF(K*Y\3C];L>JTL5U9:BS)DZ7*%6;-=6;%2NW;D
M"J%DK93]JJ(O$J.C3+(<]41NU2=";\;\&'+FR*=][Y)4G-(B`+8V`TL]^3=E
M1(--)V\&1(J4'KH2@R9]HJ>T:].H93HNN:+U:]>Q5;*M??OUZ9]BFZG0,[PW
M[)^AAV,\>=(@QI_8@A=_G2=WV,DJ;EN?&+H9[]*_H38+E"KT)>GPXN-"3=Q7
MQ4?QT<U:E?QXZM6?4+?N)6^7:T[U^LEU66!35;4=-@<EZ)R"#!(4$```.P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O879A=&%R<R]B87)T+F=I9@``````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#(Q-C(@,3`U,34T,S,W-3$@,#(S-S`U`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````$=)1C@Y824`)0#W
M`````````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`9@``9C,`
M9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`S)D`S,P`
MS/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S,P`S,S,S
M,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DSF<PS
MF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F`#-F
M`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF9LQF
M9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F_S-F
M_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9,\R9
M,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9S#.9
MS&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,`)G,`,S,
M`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,F3/,
MF6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,_\S,
M____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___9@#_9C/_
M9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_S,S_
MS/___P#__S/__V;__YG__\S____XOR0`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````A^00!``#8`"P`````)0`E```(_@"Q"1Q(L*#!@P@3%B2!C2'#A@HC
M(@2@8E1%%20<2MPHD,2H9B";I1I%`@!$C@I)I`H9$B,VDR@3JF09TN+#AS$)
MJJ!)TZ;&G`T_\J0Y$B,2G!QG#AUJ$2;*G4N7DD0)P&/4I2IB`@"P\FI/I!))
M0/7*,BM*CZ.ZBDREEN?4I"I6R!TU2JY=H33-;ES!JF]?N7[[5L$+,A58F:RN
M6;EVC15?QI`=?TV:&/)CQ9%7M-4;MG+CRY`_JS5\-K!CSYE''TYI%W!HQI)K
MKI:9ENVH*JA9#09I,Z='MKQQ_UTAU"=0%<BAUIW+TDG:MQPK`F?9EK=SZ&$)
M>[TX&Z%2LLTJ4):,:15\,XM`&TIGR[[H6-+I&V:<GYPP_/@$T58/C]^@6*8N
M]3?0=Y,)V-!^O'&&7T5NR87%"MUM1,(5Q+57%Q98"()AA`IMY>&'('Y84$``
M`#L`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+VYI
M;FIA+FIP9P``````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C,Q,B`Q,#4Q
M-30S,S<U,2`P,C0P-C0`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````_]C_X``02D9)1@`!`0```0`!``#_VP!#``L("`H(!PL*
M"0H-#`L-$1P2$0\/$2(9&A0<*20K*B@D)R<M,D`W+3`],"<G.$PY/4-%2$E(
M*S9/54Y&5$!'2$7_VP!#`0P-#1$/$2$2$B%%+B<N145%145%145%145%145%
M145%145%145%145%145%145%145%145%145%145%145%147_P``1"``R`#(#
M`2(``A$!`Q$!_\0`'P```04!`0$!`0$```````````$"`P0%!@<("0H+_\0`
MM1```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*Q
MP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA9
M6F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*S
MM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ
M_\0`'P$``P$!`0$!`0$!`0````````$"`P0%!@<("0H+_\0`M1$``@$"!`0#
M!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1
M"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI
M:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZ
MPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1
M`Q$`/P#URLC6M6EM)(;.S57O;C.S=]U!W8^U:]<FK^;XBU&>3[T;+`F>R@9/
MZT`6H]&M<^;>;KV<_>DG.>?8=`*+NT"V#PV>+<]1Y8Q@U;WY7;W'05!)*'7.
M:`*_A"VM4AGD$6+Y&\N9VY)],>U=-7,:"V/$.H*@Q'Y2%AVW<_TKIZ`"BBB@
M`KC;MY;#Q'<P>4'^V,)(R6"CI@]>]=E7+>,+;<]E=-Y@CB8JS1G!0G&TY],B
M@#,N+K6KDM]DMA#&K;';?T_VB?3Z59M7D'FS/.TL)`$;D8S@<GZ$U(D`GA#7
M<]W,"/\`5S,"`?<#@T13F]DD*;3!'\N<<,>X'M0!H>%8&-E+?RC$EZ_F`?W4
M'"BM_-<=:2:EHUN\-E''<VY.8UE;:8L_S'M5D6^K3J9)=7='/\$2`*OMS0!U
M&:*YG^SKSOK=SG\**`.BN)X[:"2:5ML<:EF/L*Y-Y-0\01M)<3FRT]P=L"*"
M\B^K$^M:_BE\:,\?/[V1(_S-9AN3<ZB(8>(+?'F%>A..%H`SYM&DM8!%%=7<
MELRX*H063_$582Z:&VM+6VA62X:/*J@P@4=6/I6EYF?F;@DX^E-1@.<8P.*`
M%M;1D827,PEEZ#`PB>N!5J:6.!#([*@49))JO<&06TI1]C[25;_:JEIP.O7R
M)<(/LT$:RR+_`'W/0'V'6@"+_A(0>5MI&4]&'<>M%=B$4````#MBB@#'\3_\
M>-O_`-?47\ZQM+_X\ICW,[_^A444`32D\<]Z=;DE>O>BB@">YXLIR.HB8@^G
M%.\(@"VNR`,^?C\-HHHH`Z*BBB@#_]D`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V%V871A<G,O<W5P97)M86XN9VEF````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`R,#(V(#$P-3$U-#,S-S4Q(#`R-#8P-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!'248X.6$@`"``
M]P`````````S``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S
M`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,
M`,S_`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S
M,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,
M,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S
M9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,
M9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S
M9O]F9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,
MF3/_F68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PS
MF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,
MS`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DS
MS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,
MS/___P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S
M_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,
M_\S___\`__\S__]F__^9___,____^+\D````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````(?D$`0``V``L`````"``(```"/,`L0D<2+"@P8,($RI<R+"APX<0
M(TJ<B!"`Q8L8,V9<"(`6+4@@0XH<"8D-&P`).])BQHS31Y(P3:(TJ)*9L9<A
MV2#9*=+839,G"]:\*9(-)V,LC;D,Z=*HS($UI>$LB52:56DVI[)1^C3JTIQ5
MKUIEAI,-,VF<9`(PR8DLR:UGQ6*E!?1LVJ!KC4X=&5;NU;LSL>7=.]*C84MM
MK0(6:I(PS)"T."VF"=3DX[=/*[+E6KESSJ`*\R;VB[5E2=`<V;;T>#0II].!
M&>:%Y!AH[(:S,:.&*+JRI<P31;.<3%$P6^+%C=M.SG@W<X$6GTN?3CUA0```
M.P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]D
M:6QB97)T+F=I9@``````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P,#4@,3`U
M,34T,S,W-3$@,#(T,S<V`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````$=)1C@Y82``(`#W`````````#,``&8``)D``,P``/\`
M,P``,S,`,V8`,YD`,\P`,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`
MF9D`F<P`F?\`S```S#,`S&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S
M```S`#,S`&8S`)DS`,PS`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S
M9IDS9LPS9O\SF0`SF3,SF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S
M_P`S_S,S_V8S_YDS_\PS__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F
M,YEF,\QF,_]F9@!F9C-F9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]F
MS`!FS#-FS&9FS)EFS,QFS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9
M`)F9`,R9`/^9,P"9,S.9,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9
MF0"9F3.9F6:9F9F9F<R9F?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9
M_YF9_\R9___,``#,`#/,`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,
M9@#,9C/,9F;,9IG,9LS,9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,
MS)G,S,S,S/_,_P#,_S/,_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__
M,P#_,S/_,V;_,YG_,\S_,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_
MF9G_F<S_F?__S`#_S#/_S&;_S)G_S,S_S/___P#__S/__V;__YG__\S____X
MOR0`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````A^00!``#8`"P`````(``@
M```(X@"Q"1Q(4"```-@.(E28D&'!AP4!/#LXD:)"9,@00MS8\)G'CR`S:N2X
M42+(D"-)0C1YTF-&E1Q9MGP)<V7+CS1K1KSI,J5.@SR?Y?R9\)I,E$0-&C7Z
MD:)0GS4!+%5H4N)0G5*S-IWX-&E1K1XE6H4*TV++L4F=GG1ZM6Q0G&1)'KW9
MMJS:F7'=\JP;-2A?O73SJIP+MZ1@PCT-YT7L,"+5DDVI7C.Z\B"DN)(G:SY8
M&1+EAP`N:YZL\'-$S]<N@X8DVJC4S61?FQY8^N#HS2L]-Z8M^S;IV`I5TV[M
M&_?`@```.P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]A=F%T87)S+W)E:3(N:G!G````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`Q,3<Q,2`Q,#4Q-30S,S<U,2`P,C,V,S$`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````_]C_X``02D9)
M1@`!`0```0`!``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!
M`0$```````````$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#
M``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H
M*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&
MAXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76
MU]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0``````
M``$"`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!
M40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y
M.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4
ME9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/D
MY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#X(^('Q#TZ\_X*&_`/Q+I'
MB^[NO!EY\=?CM\#M/M[?65N?#5EHOP5_9X_9G\2:9/`MO=MI<%Y;^/?B7\5;
M:?R6"6EW>31);VNHW6J&X_=C]NKXH+IG['Q^,FB:@]E=S^%_AT(;NTN=DRX^
M,?@3P;J:6D]M<+(T\>A^,+1D2.Y+)$Z&3]PZ)+_'YX(T"\LOV>;KXD7'Q+\)
MVGQ`^"OCCP5^T1H6G7WB#2;FX6]^.&I:CX*^+L\NFQ7<]ZUEI*>'_A2NH![.
MX:ZF\4:5%I=G]IM[\5_1-\*_&'@/]N#]@SXB_#'P+>ZE/-H?AKQ1I=A:WT.J
MVTNGS:C<>(+GP(S7.KQV$+7=CXC^&^A^&+KR;RXMSJG@>\EO+D17]E?ZM^@<
M#\94<YPF8KE<,SHXW$XKZO5TG6IXA4DY4%4?+.,'3J*<8.3C[KDDI1;^"\0>
M`JW#V9Y(^6GB,'++L"I5*=2C5C3K4KO]\H2DZ<IT:E&HIU8QY^9I-SA.,?KW
M_@LAXG^)GAE?V?\`XG_#RQOM9T;P[HNI:AXN325U6XS;+:_"'XPVLEO'I3"&
M.271?A#XJL[-[B9`]]J12$E+BZFA^@?VW?#7AWXC:CXP^.27%OJ^F_$;_@FC
M^VI\-M&O8!%)8W?B7PC=>`/CKX6L;NZ5+CS+^_\`#&G^/&TE#=S2M:Q:I<V<
M"VT.HW2?/OCWX[?\+F_X)R_"SXW>'8K:['BCX:^%=1$MQ"DL%_)\-?'^C>#O
M'NA7,-[!&-/CU'0=,\5>'+N<H9+*U\17<]NMX]M;,_S?\/OCAJOQ#_X)Z^#/
M!'BKQ)IYUW]G+X]Z)X#\;ZJDUG;-K/PD^(/@/QO\&6U96W6T$J:_H7Q:\-6]
MQ9VES>:E%=6TZ*9)K.>:'DXK>'KY3F.%HRC*OA:-?$\NL)PPV+E.FJL7)1]R
M#@I-1;Y&DY16Y7#E.MA.)<JQSPU6M@XYUAJ2G&E*I"35+"8F=-J,9.$YTZEO
M>47*TDFY4Y*/RI\/?&/BSXU?L!?M"_LO>+M<\.6/B[]EJXTSXL?!31]=OTM=
M4\0^%/A3:1:M\'?&GV6]N)K_`%6#4/!NI^)OAQXINM)L+>WO=0TD:7:WD5O;
M3Q+R/[#WQP\8?#E=,7PYK'B+3-;T:STOQ%X8T'6K77=(MO"GA0_V?J5GIVI7
M^A7-L+J#X9>)]*;PSXOMF$?_``COP[\1>%/!UR;;4[^YA?S;6[/XI:'9>"_C
M5\,OV>/$7Q"OK/X2:G\&?C#K$^L>'/"]JWPSUE_M.K6MOI>KZ[:>--2O?#^L
MV'A?Q'X>U6Q\"-!?7-M>:/;:B/[;O[.;YF\%7/QJ\1>%Q#\/_`TNI:[X:U#6
M_C-X1UGP[\5O#,FA:EX9%G!8_$[P1KUUJ2Z'-=:9X[F\2ZSKNM:&DNNZCHNG
M>-!=Z//.?">FR:9^)Y)XCXCFX>XDKU:,IPPW]@<5X%UJ57FIX.<L/+%5:<:D
MXIXC"^SK6E^]A4H3YXQ;@G_2O$_A52AF7%G"N"PV*J8;,5_;W!F,6"Q-%RJX
MN4<1#"X:56A3E5=&O*>'4J:E3G&O2G&<J//./]HOAS_@ME\*-%\/:#H_C'P5
MKUSXNTG1M+TSQ5<65[\([FSG\26%C!:ZY-:7-WK_`-KN+:74XKIX)[K_`$B6
M)DDF_>LU%?QO0_M[_L]:;%%IWCF>]\->-M/C2R\8^')?A++XFE\/^*;51!X@
MT23Q';Z<8/$$FE:M'=V#ZW`3#JK0&_C.R=:*_<(9=PQ6C&M#B#*E"K&-2">8
M896C-0E%-.HFK)V::6TMNG\Z/#<3T).C/A_-5.B_93_X3L1\5-QA+>E?>/77
M>_6U;PK/\??B9XW^$7P#_9A^`'_"P/'4WA>]OO"USJ<>OVOA?4/#MKX7N7\:
M)>78T/03>P_V!/J.H7$&G37Z6%W'H.NEK273X+R+S7X-?$KXA?L5_M33^"->
M\##P1\0]6UG7O`OCCX8>"]?M?&&@ZGINE7MU9:YI7BK2-5N]/\5?#K5(=3T_
M2]:\!7.J>%[C4?%.F26.W4(M/N[9+G]=?V%_APWPJ_:B^&'PC\2:Y=Z_J/PN
M\:"Y\%_%"WL[W0-1U3PM/HOBOQ#H&I>'M7%Y#<VLDFC6%SX:U:ZT+6I%D.D7
M^G2S7T3V=K=?HI^T'_P2:\!?'+]M=?V[!\3['PKK<?BCPKXPUOP#HWPSWS:[
MXJ\+Z3HM@==7QLGQ!TF;2;G7;GP_INJ^(+>+PAJ0O6CN+>6XE6]N9J_D#+N+
M\KX+Q^+I8[!8W*<ZRW%8FI&K[3$5'B:LINU3FG[LJ<TM::A:/,DGK=?VYQ#P
M7CN.L+E>*6?T,[X9XAR_+)T</+!<CR^"H4J4,.J="$9NK1E%N<U4<M%SQ2:/
MR-^!'QN\`?LPR?$CX$^)?%:^)_V8?B)KVH^-_@KXBG>UCG\/CQAHMO>?%/P9
MXFN[AAH,/B*"7Q/HZ6%A8XM$U72;T6\#SO/-<K\([O6_"WB&^\3:;8V4W@SX
MO>";OP'XSU2&YM4TSX>?$%-?MI;'Q8+&*R>V/AKPUK$:>+AJ5U<0WUEX9?Q,
M;NSO%TK3+.7]$/`7[*7P`^,_[0_Q._8WNO#]CJ5CX@\&P^/?#/BN+1[:[U#X
M0>,/#BZ9#JELLL\"#Q#_`,)EH^O:`TBW1T^RW>"XYY?M%W<W*:;]V_"O]@+X
M7_">V\4>&(M-C\1V7B=X;Z[^V)]GTK3+YH[BQU>#1_#LEWJ%OI.G:K$MK+=Z
M7:ZBVGO*;G9;I]H=VWXG\9L5FV593FBP,X9A%8W!U8R@XX7-\HQD81GA<13:
MA*+PZ<I4)Q;=1M7<=#+A/P0RGAS/,^R/,LS57+*D<!C*=3#S?U_*\UP<ZE3"
M8^A1G=3CB(S<,50JRA*E"7+*[BC\\OAE_P`$V/VD_P!J#6QJOA76_A_X0^$N
MJ^&[B#6O%?Q/TNR\=>+/"&KZ_/;:A-%\,OAE.TW@BROD\&WVF:A8_%CQS'XH
M\8ZA=#9X:T+0O#VHQ:BW\GOBGX1_'_X<?M9^-?!/PGE^*.I>/OA5\3/B%X>U
M#5M>T<P:IJGQ)\(_&CQ'\.[>'0(?"L&@O;6?B62ST"RL]#U*2#4;[6]5O+&/
M3)-(FM@?]//X2_"N7X<^#--L_!B#PQIMM8V]M#!9WFHE3'%;B"VA\HW,2P01
M0A8XTC\Y+:"*&WAW11*$^&?$?_!.C]C?PK\1_&W[1.H?#.+7/B7XEU[Q)\4O
M$GB34_&WC[4=,?Q7>:E+XSU;Q%=Z/+XB.E$G6-*3Q$R7L#QC4!(&F\RX$I\W
M*^+\-E62TZ53))498B+E2C4P].=/$TL1S*4HPBI5'B*DYQC)-MR34KK4Z\?P
MAE6;<28S%X[.:V+P^&@UA9/$U:+PU?#^RDJ<YQJVH83#\CG35&<+<BC)NUE_
M&+\1_!?[8_A;XA^//#&O?LH^'/B%KGASQGXHT'6?'VF?"'XJ:GIWCC5M(UR^
MT_4?&&GZE9>-+*SU"R\37EO-K5I?6EG:6UW!>QW$%M!%(D2%?T3^-?CO=0^,
MO%L.AV>FOHL7B;7HM(=_$6IVCMI<>JW::>S6LFC/);,UH(2UN[,\))C9BRDD
MK:.'\1Y)2I>'=%TI).FW.2;IOE<&UT;B[VZ;==>CE\'UI6\<LTC66E6*K1M&
MJK>T2WT4DTM7HEKU7XF_"CXU_%;X%^,_!O@_1?B39/\`!71-8U_49O"GB_2-
M,U[P9\,O%5_IEGJ>E:K?WL=_H7B+2](\7OKNGVZ"'Q3::)H6MP^'M3U*SNM.
MU"UL:_KL^$7Q"TCXW_#31?%=C+#;3:UI=S!-':WL-Q>:5KT32Z9?+<8$:0S"
M2T9X[6XB622VGADB"$EW_BAMM,\5?$?PI?>*M$@T#Q%\9?A+I.H6'QT^%OAW
M2[P:+\4_"VJV]NWA^XTK2KFQ35]9U;1]#U&^U*T;7X[*'3[G4/%>C6-WJVF3
M0VZ_=W[''[?,W[+_`/PA&M^,+_5=7^"7Q)&K6?A?Q+XDUNUU76$UOP:EVWB7
M2O&4FEWTV@0:]I4?B+0;K3;E&L[O7_!]Y::M;6VIQ:+XBO\`2OT+Z17`%?B"
MM3XUX0J0Q6'J8>-;%X"#P].<HSC2J4\;A*K7M,0IPYZ=?#/3#RH1FES8EM_F
MOT<_$#`91@L7P/Q+SY?BJ>+KSRC-:\YRPRQ<*D:=?*,;*;Y<,_:>SE2Q,=5[
M24$[(^_O@/X-_;!_8<_;5^-_B[2O!&J_'?P;^T6/`\%UXWM;"72Y_ALWP^\.
M>+$M-->S@BU1;W2_$VJ>,KV"\EC;2YM*U%+%[MKRSN;>%?WE\(:YK&L:9;:A
MXF\-?\(WJ\KNEUI<EV+F>UMQ&9OM+NL%O\K2EADQ+@J!OVDK7S'%\3?`_P`?
M_!@UK2=5\5Z59ZFD$TA\)>)=4\#^(+232KUT2*RUWPMJ6FZO;>6UHQN7M[Z:
M">%F\B5[:<,_6?#KPCX7TN2]N;C5?BCKDA6'[%%XV^,OQ2\3Z?!)#<6MS;7/
M]CZSXKU"R6<W,$4KWL+)=NJ-`)4MY9XYOX]QN8SQ\\/0S'%SHUL#A*6!HT84
ME2IJ-&G&E%UXT^6G"NU3CSOE3<TV[MMO^N,5E>(H4<34P/#N&BZ]>>.Q^:_7
M/:5:M7'2]O4C2B]:M"$ZD_9-2<>1^ZE?7[5O_$&IZ=X<N+J"YDU!K6Q-S8Z5
M%+;PSZ@MGIYN;>PMFEBV1R7\Y^RQSR/)L=QLC)6OQF_;O^*'QCD^!&H>(O%&
MJZ!\"M.TA;N<>'HKJW^(']EZDNC7UI;^,O%6JV\-F]Y;VE]K%KI:>$M'9KC5
MM4CL;70+N77K[3["\_3_`%G7I;;1RL4BM/<RFV;#R,(5FADN+J\!=@3;H<O(
MZJ)-[Y,#N7E?\!_CU\=_!WQZ_;:M_@78?;_$^C_LUZ._Q`\>WCO8+\/_``_X
MP\.:GJMY;_\`"0SVMU<7.I^,?AS]F?QWH5C?VM[X=\->(](\$>)3INI^([&*
MZTO]"\+\MS3C#BW*LFPLY5XTZU+$UL55;JO"87"OVE2492NZ46TH:.*>BU/R
M+Q!EE_"?`^?9]FB4)0P]>E@L%1M36-QN+:HPISI)159)U74Y9*27*VE<P_`?
M[-G[9'B?P/X,\2Z9=?LNQZ;XA\*>'=<T^/XFV/C;P3\28['5M(L[^T3X@^#+
M>]>#PEXX2"XC7Q9X8@=X=!UX7^E1,R6BDE?F#\4?^"C7[2,?Q,^(L?@CQ3K1
M\&)XZ\7)X1-Q=R33GPPOB#4%T#SYI)YI)9O[*%IYDCS2N[[F:1R2Q*_T7CE.
M#C&,>;$MQ2C=.=G9)76NSNK>I_G8\PPTI.3P4+MW=\/&]VXO7W?-7^?9'PYI
MFJZII'_!6GP3J6DZE?Z7J,GC35[:34-.O+BRO9+>7X0:'%+`]U;213O#)'/-
M')$TA1TFE1E*R.#[#X2TW3D^-O\`P5&^&R:?9)\.KGX:?%34;GP"MK`O@JXU
M#P]JWA_Q-H%]/X5$8T*6\T/Q)))X@T>YDL&GTS6W?5K)X+]FN"45^29-_P`D
MME?_`&*J'_I,3]CS_P#Y*_B+_LHL7_Z<1^@G_!O=K.L:G^SOKL6I:KJ6H166
MJ10V<5]?75W':1&X\3H8K9)Y9%@C*(BE(@BE552,*`/ZBK+FWM2>23:`D\DC
M+\$GJ/8\445_#OB%_P`E#Q9_V,\+_P"ES/\`1G@+_DWW"'_8`_\`TQ2/%_VS
M]0O]&_91_:6UG1[Z\TK6+'X'_$%K+5=-N9K'4K-AX>OG#6M]:O%=6[!U5P89
M4(95;.0"/Y8?V!42/X._MTW$:+'.WC_Q!:M.BA9FMI?AS\(7EMS(H#F"5YYG
MDA+>6[32LRDR.245^S_10_Y*+$_]@M;_`-+/Y<^E=_R2^'_[",M_*H<]X4TW
M3I_"_AN::PLIIIM`T>6666U@DDEDDTZV>2221XRSN[$L[L2S,2Q)))HHHK^X
M9;OU?YG\:P^"/^&/Y(__V0``````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]G<F5M;&EN+FIP9P``````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,3`V,S0@,3`U,34T,S,W-3$@,#(T-#,P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````/_8
M_^``$$I&248``0$```$``0``_]L`0P`!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_]L`
M0P$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B``(1`0,1`?_$`!\`
M``$%`0$!`0$!```````````!`@,$!08'"`D*"__$`+40``(!`P,"!`,%!00$
M```!?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B<H()"A87
M&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W
M>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(
MR<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$`!\!``,!`0$!`0$!
M`0$````````!`@,$!08'"`D*"__$`+41``(!`@0$`P0'!00$``$"=P`!`@,1
M!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7&!D:)B<H
M*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H*#A(6&
MAXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76
MU]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`_G<^)G[*>K>"
M?"NI>)=&UA=?BTF]OKF]M1;-!=P>&D56M+YB9?(DN;',TFN,HBMH[%$O+=8Q
M:W:7'R8UI<PN5GM9H<37-JYGAGC6.XM57[7&X"AQ-9++'+<189X0T9FC*N%;
MKK;XB>++-'2TUG5;8->ZC>IY6N^(E6-]3M6M;F(P_P!L&WN8W3RC+)>PW5U>
MK;06NI7%[8*]H_NWPZ^"/BOQRVF7TFC3V?AC4/$^AZM+XOTV_P!%LXX['3K6
M\MO$%C8Z)+=217[QZF\,&AZK;::^B6:VNJS:79W&G:A%I]?U1BJ&'XKSK"X3
M@SAK,,NJ5\.W6RQXC$9S2IRIU(47C5C*-"=?"X9U,1A:5:6)P_U:A*7MZF(H
MT95'2_7\=D7#'BUQ7E^"\'>!>(.'Z\L/2CF.0>TQ7$F"A&G.G!YHL?3HNIEV
M'E.I'"8B>9NE@(UYX6O5QV%AB*\</V_P^_9YT?XC^"EUW^PI?`^I/&$L+E]5
MD\0Z%XHCW><;IM/G5=4T6S$]M;+!<:1XEN9I;:YO8C>7*EHE^6_B%\-O$'PU
MU4Z-XA6);Q-OSQ9%K>12&0P7^D32;&U+2YUC=#<B*"ZLKR*:SU2PL)39F\_2
MJU\::9X0T:/2?A]X7D&BVXDDN_&GC[4KOP7X6:]E6$27^H>(?$-G-K/B*_9O
M,^V?9;":0+82VD=Q#';(EOYW\9+*'XB?"O4O$^J-X1?6]$UBTTWPOJ?AQM3U
M!M7&J266GW'AQEUC2+&6*YO+J_#VTD2ZA;6ES;VNI[[*6SN)H/T?B#@OAJOP
MU0EE.-I2XORC**F8YK6P=.<,DSS"Y?1]KCY86JL%@,!5AAX5HK!YEEM%_671
MAA,?6QV,E[6/].>)O@+X=YAX?_\`&+3P]#Q'X4X=>:YGF&7898+(.(Z&68.>
M(S2$98;+<LR3$RC0P]6&"S+*<+1IU,93I8?-*]7&XV56?YLD$!2<?,,C#*3C
M<5^8`DJ<J?E8!MN&QM92>E\+Z6+_`%&*XFNS8V6G2)?7]S')/;W<%C;L&GN-
M.G2&2+^T4G:SL]-A9O-GU?4=+A2"6*2=X>XT_P"%FO:WKNC>%M#AU/Q!)-IB
MZY.+!"-/_P!.N1;"6UO6673[#3YHH+..;Q'?R"PG\B5K$:E)!86-_P!#\9-(
M_P"%=SV?@"TFMY9K&SLW\0W5K:1R:=?ZM=V,UZ=.MS>![FSL_#NG:S8/IENQ
MN9[R[U6Y\3WT\&N7'F-^-0P&->"JYG5P=6GEM'$T\&\56IRAA\3CZOM*E'+:
M,IP:K8B>&H5\3BH4XR^IX6E4E7<*DZ,*G\9X?@+.\HR_,^*\_P`JKT.'N'\;
M@<!.K57-A<WS_%T_K&%R'"8B/[G%_NZ5?$9K4P]5TL)@,/62KRQ=?+Z.,Z2V
M_:7UK1K>#2++P-\-([+2H8M-M(YO#5SJDJ6MBBVMNDNIV_BFWM]1D6*)%>_@
MMX(;M@;B*&))%12OERBO>I\;<64X0IPSO$0A3C&$(4\/@H0A&"C&,806%:C"
M*BE&*;Y5I<]J'CWXK4H0IT^*\73ITXQA3A"E0IPA""480A3ITX4X1C&*480C
M&$4E&,8Q22559F"J"S,0JJH)9F)P``.22>`!R3P*^X?@!\,M1TNQUOQY\0=`
M@F\.:_\`#_7K3P+=?\+-U+X6Z[X:\<WVDPW/@CXGZ,^E:5JVDZZ-%N].A.K>
M'/&=K9V/C'0[[5_],T^[FTOQ;8_)G@*+P]<>+-%@\4K<MH4E[;F_%E:7-]>M
M#!-'=-!:6MMO:6>^6!M/`DM[N)8[MV,*.J7-O]`'XN^'_&_QZ^'>I?$DZV_P
MC\/>*=)34?"W@LR)J5GX7CO574M/\./I]Y!'J'B:^TV..U2_BN+:PFU-ULK6
MX.@V]M=S?.UX\/4LBSK'9[0SK,JU##5/[+R?AK,Z^4YU7K8>G]=K8VGF."J4
M\=@U0]E1HY?3P]7#SS/,:L</*O3PU#%-Y>'O^HN297C>*N+\7FV,S&.987*N
M&^&^'LVAE6/G77LJV8Y]FN-5*M4P66Y9AJ]-9?3C&-7-<RJ>RI5*6'P6.K4_
MNOPO%\(M:^#9T[7M"NOBE\9--^+_`(=\;:;^T%J/Q7L+WP9X!^#ECX-GC\4_
M#J;P%I%VWAJZ\4W?C&VNY[GQ'/H,R:AX<U&VD;Q+I$_A6WT^_P#)91JWCQM?
MOO&WB"YT/07F@O?AG>7-O#HVAZC;7$VHZ!INI7.GR_:=0T[4)-2\2^%-8LY]
M1N4O;OPCXC\&:M9V\$6MK?R?6GP)^,'_``2F^''C+X:Z_P#'S2?CE\2-*TO6
M=)\7^,?!'B.QM-=^'OC;0I/V4+K2-1ME\%>']5BT'6?$$G[36@1:AHUIX@N+
M;P^FD^,-(M9/%LGACP)J=_XJ^!/CO^VAKW[2B>%O",_@#PEX1\'?#[X46O@S
M08K!;R^\1:X?A[\(_AQX'TOQ1XUU6ZG^P:QKFH>'O@1\-X[^SL=(TO0X;G0X
M)+2P783)\1P9XR9MFO'>+X?X;\+?$BCP5GF8XWC/CWB?Q3XCS)8+,LTSS+<R
MR7AWA?A#!U<TQN)IY1D-7(,JS#'9=A9U<-D57,:4\/SO'5Z=7][H>/&18+-,
MMR_),!F5;+<USK,\QXBP^=Y]F&-J\19KB\A63Y-A:\,/7KXC!Y'E^,E@L9@X
MX[,\XQ4ZU)S6(H8>C[.I],_"M(+VZ\=>(=.$2Z!>^)(/#GA=(2)K<Z#X&TJS
M\,B:SO!Q<V$^M6FMR6FTRQHN^1+F?SV*_*O[8?@06NJZ;XXM8UCMM:C6POW,
MLH3^W]-LW:.1_M%W!8V[:KX=LDM\Q1W%Y=S>&=.L[:W5YYY9/NWPZ=,31M*@
MTNRL=)M1I6GW4&CZ>EO!;Z;:WD1D@AAMK>*".*W#+/'$R6\,<C0R[$!1U7R;
MXT7_`(=\3>!_'?A*UO;34_$6D>'KGQ,VFVL3:A)8/X?D;4XA?-#9W]I8S7;Z
M=/8Q66I",ZBLLUBT,L$\RG^_.-.&LOQGAM6RRMB\''&T8U\ZRNNO8X2EB,_<
M\7FE6A@:%7V:IQQ\\1CL###P2JTL)BIP24H-K^S?%W@#*^)_`[-.&L?C\`\T
M>&QG$F3XMKV5*MQ73J8[/ZM#*,-7G[>E3QE3$9EEN$P=)3KX3+L4Z$:4E1=-
M_D'15B[BB@N[J""8W,$-Q-%#<-"]NT\4<C)',;>7,D!E11(89"7B+;'^9317
M\9Q:E%25[22:NG%V:NKQDE*+[J233T:3/\7&FFTU9IM-/=-:-/T*]==X)T==
M8UR-'NELH[&"?5'N6F,(A73HS=LX\BX@U":15B;[+9Z5NU+4[_[)I-E+8W&H
M1:C:;L?PB\?W/A=/%UEX:U6^T3-]YU[;6P=(%TZ:"TOO,MC*-4B;3KXWUKJ4
MMSIEM86W]FW<\%]=V\4\EOQ5AJ>K:#<Q3V4UQ8744VGZE;/M:*:"ZM6CO])U
M.U+`/!=6Y=+FQO82DGD3R(LCVEW/'-M7PU>@L*\5A:]&GBZ>'Q5..)HXC#?6
M\OJSA*5;#N2HU*E&O0<O8UZ,XPFY1E3K1NIKZ*GE&*R+&Y%B^*LASC#91F,<
M)F5&&(PV*RUYOE%5TZL<3EV(KTJ:Q.%KT9PJ4Z^&GRUJ-2+HXBE[6G7C^QOA
MS01X?^'O@?PQ=?#?]F_QOHWA/Q2/&_VOXM_`W2[7QW<:;<?#2U\"2^#O%OCS
MP-XA\-ZMJ_AW3EL;+Q6-.U5[Z:#QI:#5I-8GLXI-.N>/^.GBC3/VGE^!W@^R
M^'?[._AC4?@WX63X:7VN?LR?"*]\`>'[GPK,MO)JFK_$_P`4OXLU[3/%_C61
M+:^N--L;&XTFZL]:\4^(-2ETEA=S32?F+>^//$OB.]M3XH\0:MJ]MYJ^<FL:
MKJNJ6>[S[J:WFN;6]EU(?8[.2[R]C86\`EM8/+MUAOG-[7Z*>'?B5\,/C.-,
M^&=I;:KH<7V5-5U30+)+:ST/4([#[6+[PFFIZ->(+BU%RJZG,;:"WL]6TVV_
M=RE;B>"/ZOAWPZ\#>(N*Z.9Y?P1A>'<_RZHZF1?7>*>(I2S;,\^GC,!F4<OP
MJQW]@916Q4<?B*6/J3P&:U98;,8SR_+GB\-AY83^V/#JOX!>)>=8S`Y%P7D_
M".:4:F5X?*,JXCXAS2OB^+\96JU%'#Y4I8JIEN0SIRPF&CB,5+"9_B*,,;-Y
M7E;QU.AB(>E_$?P]:>-_#DT^AZ?H7B74+5VB*^1H.HSW=L+>=I-(@O-1:."`
MR7$]I<R0'5-)26-&CFO$@GEBG\;@\,>*_"7@[QSKNMZ79>'["Q\#>,8+C2K.
M;P_X9T:\GDTO46LY=.\+^"A<Z5)<SW)C@CU#Q-K&KZA'!=16^GV5I=M=RW7M
MT/P^LO"VO6&N?#_3]*\.0W5Q!9^+="L+5K/2=9TDXCAO+?3;6YM-*L-9T>1F
MN8M0ALOM%W:27EI<?:6>WC'RM^T;^T#;SV^N_#31M(NP$U,V6K:M<70BM=0M
M]&U"-+W3H(+8?:)+&YU6SO--U"1;VUF:+3[JR,12_>2W_H7CFCDN54LPXFXC
M^M99GCHXG+\#@,MQBKY7Q)B'@:CP511J8*&(3A&?LL7*K+"2P,Z5=0JU:-:G
MB,9_2OBSF/#G!V4YQQ_QQ6K\/<3X?+\=E&18'+,4LPR3B3-7@J^*RB>%4\HI
MX^JU6=*&.CCHX2AEV)H5Y?O</4H8['?"%];RVE]>6DZ".>UNKBWFC5D94E@F
M>*1`T2I&P5U*AHT5"!E%5<`%5:*_DF*:C%2:<DDFTG%-I:M1;DTF]4G*32TN
M]S_'&4G*4I/1RDY-+:[=S]L_AC96>G^!]#L["TMK&TA_M/RK6S@BMK>+S-8U
M"63RX(42)-\KO(^U1ND=G;+,2?RA^,]O!:?$?QG9VL,5M:67BSQ!:65K;QI#
M;6EJMS'<+;6L$:K%;VZSW%Q,(8E2,2SS2!=\KLQ17[OXP_\`)+>%7_8KJ_\`
MJFR@_P!"_I6_\F1\#?\`L599_P"LSDYY57TO^R>J_P#"WM(;`W"TU=0V!N"M
MHFJ%@#U`8JI('!*J3T%%%?D_"G_)6\(_]E9PQ_ZO<O/Y,\!O^3S>&7_999)_
MZF4S]6:_#;QK++)XM\2I))(Z0>(==BA5W9EAB.L7TQCB5B1'&9II92B`*999
M)"-[L245^]?2'_W?A'_L,S?_`-1<(?VI]/?_`)$?AQ_V-.(__47*#F****_F
M<_S1/__9````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]A=F%T87)S+V=O<&AE<BYG:68`````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,C,T-"`Q,#4Q-30S,S<U,2`P,C0R-#,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````1TE&.#EA(``@`/<`
M````````,P``9@``F0``S```_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F
M9@!FF0!FS`!F_P"9``"9,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,
M_P#_``#_,P#_9@#_F0#_S`#__S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S
M9C,SF3,SS#,S_S-F`#-F,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9
M_S/,`#/,,S/,9C/,F3/,S#/,_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`
M9F8`F68`S&8`_V8S`&8S,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F
M_V:9`&:9,V:99F:9F6:9S&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_
M9F;_F6;_S&;__YD``)D`,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS
M_YEF`)EF,YEF9IEFF9EFS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,
M9IG,F9G,S)G,_YG_`)G_,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`
M_\PS`,PS,\PS9LPSF<PSS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R9
M9LR9F<R9S,R9_\S,`,S,,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S_
M__\``/\`,_\`9O\`F?\`S/\`__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F
M9O]FF?]FS/]F__^9`/^9,_^99O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,
M____`/__,___9O__F?__S/____B_)```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"'Y!`$``-@`+``````@`"````C^`+$)'$BP(```2$@47,BPH4`D!Y$X
MG-B0!(F#%BEJQ$9"11X]@$#J4:%PX\*.>O(X40%HA1-`(4F:'$A"3\H2`*J0
MJ@*`Q,N0)2EBS)-GQ0H``9Q4N0A`A4=2>H(Z/(AT12!6@:P$`&"5%2LK'O-0
M97B1!-&+@:Q=L_85P-5KU]I2!7#R+"!215G!A6;%RHJOT-8&ZID2(T&S5520
MPOL7;MQ`?P/'M6)VL8HJ40]77FQ5+=:C:06OR+,8+\O,#UF6+GK5JA6N5R&3
M+DW*HQZZ`FO2WND4@%^J3IWLAGH9]V;:*IPXF7O0B<KA>(.2&/Z<U'*JPJW/
MI@VHY/'5M%7".J<]?K?WN^&A#[=8?K%WZNIWMU_</3?Z^-")4O>^'7_X_JM)
M!U]^\Y56'TVSM717?X#D81&``19D5DNL/+&@<BM=E-U^9%7Q5X5Z+$9:2M7M
MYJ!#:,5EH8@8[M9@1A/!%M<*]^VFQU$':5257I"%2-N-*[QV%$4DK!``"U8M
M599%L'FU`@L!3$0""U!268(3HSCA4Q5:6N$DE2Q(=1B850:05):CY)$E"0$\
M2::8')%9)90&F(FEFDX<2:6>80X4$```.P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O:W)Y
M=&]N+FIP9P``````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$P,3,V(#$P-3$U
M-#,S-S4Q(#`R-#,Q-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!
M(@`"$0$#$0'_Q``?```!!0$!`0$!`0```````````0(#!`4&!P@)"@O_Q`"U
M$``"`0,#`@0#!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!
M%5+1\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:
M8V1E9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.T
MM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_
MQ``?`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$
M!P4$!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*
M%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ
M<W1U=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"
MP\3%QL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#
M$0`_`/X1;AHDO5,ZL\*S,TBJ^PE`[%BKX*[E'S!,AI"`BD%@1^]G_!+K_@D/
M\>_^"E.BWWB;PGKOA_X8?`7PEK8\.^./C-XELI]7:3Q)#86FH+X1\'^#+6ZC
MU#5=7E@GC>6ZNYA;Z>\IO)DEM+62TD_"SP^MO+KNG?;()KP27+16UG;#?-->
MSAX+8&-"'"R74MK$F0%DE8(N\AEK_6-_X)?_`+)VA?L4_L4_!'X(6NG06OB:
M#1%\>?$_4(K5(7UGXC^.H8]8UB74<@F:\T.P&BZ7!*-H@4D0K&SRE_Z0XMXN
MK\+9'CJF!Q%-8[,*LJ&'HM^\E1IT9SJR5TU&2FHP:YGS0D[)73^<RK)*.>9C
M@<+B\/*IA,)'ZS6J.*=+WFX>S4K-\\7!-KW5:2U=M/GC]E7_`((@_L#?LM:5
MI]J_@'5?CUXOMA;75]XM^,\L>L6\^IQ;6DEL_!-FUGX7TRR23=):1:EH]V^]
M8L-]H6.1/T8USX'_``7O-&F\/Q?!SX:?V)+$?,T5?AGH$.EGRU#1JD5OID-F
MBHZ(R`1A-R*0N[!KV'6-52%)'-VP(B=C(Y$TC/&I>%6:7S'=3*$`5B5!(P*_
M/;]HSXL>.UUZ_LM*\5:II&FP0V]O%IEC-'"KR&W,LS,\<:S_`#!2^/,(7&$"
MC@?S/G7B!G,:DZ^:X[&8RLU&RC6DJ<(2C&:IQ]Y>[%MO9/5O2Q^W</<(X2=>
MG@,LP.74()<WMI4N:=Y/NZ;L[):7U>SZGR7^UE_P37^&OCKP5KU_\(_&$W[,
M?C"WT^\-CJMHUK??#V"\F/E_:-8\%373VHT]XGEAGEM+6..P$HU"YAN;>UE@
MD_@U_P""E?[)6O\`P#^,VK7RQ^%[ZTO=.T2^U:Y\'ZJ-=\-75Y<6L=M>^(]-
MO,0SKIFKZE!)+<),K+ITU]Y4;Q011+%_;#XUUO4;^W4:Y?WFLQ7SO'/;ZC>7
M%S&(V)\X3":0AT*%LJX9>>!D5_.__P`%+=(TF?QU\!?%]S;Z;>Z0;_Q?X,\3
MZ#?M(MAK'A2Q-KK]]I-Z89(Y#;R6T=XMH`ZB-Y(X%86I:&NC@[C&KQ%FM'(:
MF'3IX_F5.=2<IR53E2;G=MQBTHVLGK=I'H\><'U<HX?K9L\4ZE3+ZE-RC1A&
M,>2;C%1BDE?EE=MNWNM/5Z'X/^'_`-L?]J_PQH.B>&_#GQG^(FE>'O#VD:;H
M>A:797LBV>FZ-I-E#8:786BK:,HMK.QMX+>`!F`BC0`D<T5Z=J_P+^$<FK:G
M)IOQ,\0Z?ITFHWKV%A!]GD@L;)KF5K6SAD)8O%;0&.&-RQ+(@8DYS17Z3+PR
MQ/,_W/5ZWGW7]S^K+R/RF/$6,M&V*@E:-DZDKVM'_+^KZ?//PKU&WT3XE_#?
M6K^!Y[32OB!X-U6^@4(WGV.E>)-,O+BS<G<J)>$1AY9AY,/E*?WDC+$_^JK\
M%OVS=0^*'B^Y^''C_P"%/B/X,_$+3=)U34M/@\07D<OA7Q_I7ARV\-IXSUWX
M>ZM]IDGU_1_"3ZAHL>HR-IJW"27<ZK.8K=0G^6-\.?A-\3/''@OXK_$_PEX5
MO]4\%_`KP_X:\7?$?Q6EM.=)\+Z?XH\?>%OAMX8M+J_V?8!J.O\`C3QCH$>G
MV)F%^\.F7U_;Q"WLKJ5?]4CX76GPA^,/@KPY^T'%IMOJ?C6'X+:1X/TS4)[&
MUO-3\/R^(O"?A>W\4IHMU/'//:6FMZI96ESK"6BI%<?9R\R[=^?&\99X9QRC
M&4,5%XB&(S##2BIJ5)>SPF&J1C*UU&IS5973UVNE9'T?AYR1>9X;&X>I*@Z.
M#K1E"DY3:Q%>=/FA>RY/W3N[VT?Q-V.5U7_@I#^Q==ZQ<>'W_:#\!:7K&GZE
M;:9>Z;XB_MGP]%+<R2OC['=ZE;$7"DVLJ*\9$4C85<%EKYK^*WQ*\.^)_$>K
M>)/"VK:?XKTJ^F,EG?Z3J<%U8L3`\44D<HACC$81^=XPRYQER"+WQ>_X)7_L
MN?&#3=25?#FCZ9XS\4Z5X7TVZN]5U>;3M5L;;P]?P:[!<^#YW2Y-M=37=L\>
MHW,,`N;K3I[RSGG:"0JOF<W[*7P=_92TJ/PGI?Q(\6>+;Z2R>;7_`(?036>L
MV&F0PQ-)!>7?B'4KIM0L?/F2*-8;6-49F6*.*$N)%_FK-)8S$X53K2@YRC&3
MG&3<;*,59MJ]TEKIY7/Z$R*CE=+,7+`JIR2A%1A4IN-2Z2BW_(E)QTM/JMMC
MQ/4?[6\3K=6MM'NE*3_:Y$_=64"!7=2U^X$,9+*%/E$/(3Y2$.ZU^'/_``57
M^'%SI'AK2M1L?$^G:I)\*?&WA[_A/[.UM;F#^R[?XB6-M8Z6D5S?%[>9Y;AH
MDN@00UKY^!S7[3:E\2X_&6H:%H4<-IX6\(Z9K5HBZ'IJ7#3WUO#=QO.=2N\2
MW=V?+C:0>;+*L3JKH(R@9?PM_P""IOQ&:WB\7_#_`%N^CM-=_:)^+&E^-9]+
MO+F.2+0_AM\(;9]$\/1+$;575_$>JW5O-&?,2X5`\R2$1*![?A/+$U.,,J6$
M3K5H8BFGRQDX12E%R;=E9:VZW7E<\SQ-JK"\*9U#'3ITJ.(H+V,)23JRG%Z2
M4;N-GHE:5[]-K_E;'K_A&"-(4\-Z-*D*+$LOV\#S%C4(KX$@`W@!L`8&>.**
MXB+7K"TBBM!X8TQA;1I;AA;1ON$*B,'>X+/D+G<Q+-G+$DDT5_I`L3B;)/"J
M^E]*>_NWZ^;^_P"[^&^>;LTZMM+:>EOT_#MKYU\(/VH_BM\*_@U^TO\`LZ>'
M]2CC^&O[5GAWP-H'Q)T"8(H74?AG\3_"OQ1\(Z_;*8S)%>Z=J_A&32I`6CV:
M?K5ZV5E,'F?VO_L/?&B;]I/]BOX">&/!EKXYT+7KKX?Q:;XFU[P9X_T3PMXA
MA\1^"KW^Q]<T:QTK6=;M[B^L_$2:;%?R7EG''?VUM<O%:3PVI:%OXOOCW\([
MC3M8^('CCPYIT&G6?P]\;/X5\=:5]JB:XTO59M6O=(T34].M)#YUSIFLBSB6
MZE,1@M[UH(P[233)']X?\$WO^"@/@K]GVUC^&WQY6RN_AM<:A>ZGX?\`$%UX
M:MO%-]X<U#4);:6_TR]C6%=5MK.^N=/LME[:WD4FD,[7]LT<<4Z2_P`I<;Y%
M4S/P_P`9/!4JF(QN$SG^W8U)M^UJ9;B\+@L/*-"[;G)SPU65FU!K:;V7[]X?
MYW1R[B*K3S/%1PU">`GESBH4YTEBZ->K.E[1R:MR2J-.R<DDO=Z+^MI/#7BO
MP3<Z?"WBCXO2^)`D-E#X=^(=SK=W-HZQ2K);RZ?J=_>ZI#?^9*B&21;ID:$N
MI+1,4;RSXI_$K[%YT[O=+J.N:=:W6MI?+`)8[F*.XM9XA.$$UQ"]^MO?)#,[
MQ1&$>3&BY4^5:9_P4#^#USX/FO?A3\3_``=>VFL+-#+#KGC[6/'%KI%I)`PB
M70[35I+B\TV_#E%M[.XNIUAN"B(`1BOD+4_B/8^-K^.\MSXVUS2+;Y;Z\?3)
M+34+B"(R27*V"S[;,!8'G:U>6-(Y7V">=%S+'_)=5XNE)T7]<;I2<)T*D+.[
M:DE;F?V)1COOS>I_5.7JE62KP]C4HO#QDJ])4XQ:48\SYKIWNG+;9KT.M\0Z
M]J_B73M1&D:UJ>APQ02V[:QIDCVEVMY,?*C:SG@\MXF,CHC^2R*T32+(&0NI
M_FV_:9U?QUX?\56.I_%G5KSQ)I_Q(M=:\1^`=4U;7Y->\1:)X'\/>._$_@S2
M;>:WFFFDMS>3>'+B^ACN#YEU'=K=3F<V\3Q_IU^V9^W'X;^&'AJ'X7?`PVGB
M;QAK,<ZPO'C4XO"$=PNRY?5;BT5_[2\4Q6WVG[3I,/GZ?IB;]06Y=K0(WXK_
M``L^(N_Q7=^%?&_AZP\=:;XW?PWX>U.;6;<ZEXAT'0M)UE[VYMO!][<^9=:+
M'-+/>R:@UK<6LLUI)=2R,]RJ2K^[^#5#'Y;CY9@Z-+#2Q#]AA858-OVUH2]K
M)V;47S*-XMOW79=OYT\8\URW,J<,NP^(J5XX>?ML7[.I>"C=ITDW+F]I%PY^
M5I1LTF]6UOP?$#X;&"$G4+X$Q1Y$MKB0'8,B0*H4/G[^!C=G'%%<GJWA[]G/
M3]5U.PL_$?CN^M++4+VTM;TZ?"AO+:VN988+HHBJJ&XB192J@*I?````HK^E
MGC>)KN];+-]?]HQ"[7_YA_7[_N_$8XG*THI9?C'HDG[!:Z1L_BZZ/[O*_P!N
M_MF(EOJ'[8H@18!+\2XUE$*B/S5@\7^"YH%DV!=ZPS32S1!LB.6621`'=B?R
M?OF9;)RK,"[0[R"07S!D[B.6R22<YR22>M%%?)XS_D0T_P#LE<L_]/8PZZ__
M`"-<=_V-\;_Z>B>N?!+7-:L?%OAZWLM7U2S@76;!U@M=0N[>%7:Z&YQ'%,B!
MCW8+D]S7[6_&?X@>/(]+\+V$?C;Q='8ZAJGAK3[^R3Q)K*VE]87NK:=:7MC>
M6RWHAN;.[M99;:ZMID>&XMY9(94>-V4E%?S7F/\`R,*W_7Z/_I%,_I7AK_DG
MX_\`7N7_`*;B?'?Q/TS3=,\'?';5=-T^QT_5-'U/2=-TG4K&T@M+_2].FUK2
M8IK#3KRWCCN+&RECEECDM;:2*!TDD1HRKL#^>.CN\6G^*=1B=H]0@\/Z=+#?
M1L4O(99O$&G132172D3QR2Q.\4KHX:2-V1R58@E%?JW"'^\99_V$/_TBF?S]
MG_\`'S+_`!_^WH](TR&%]-T]WBB9WL;1F9HU9F9H(RS,Q!)8DDDDDDDD\T44
M5^VO?YK\X'YR]_FOS@?_V0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS````````````````
M````````````````````````````````````````````````````,#`P-S4U
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W-3(@,#(R
M-30V`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T
M:6-O;G,O86YG96QW:6YK+G!N9P``````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#<V
M,"`Q,#4Q-30S,S<U,2`P,C4S,30`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@````\````5"`,`
M``"N142%````P%!,5$4```#____]_P#Z^OKU]?7KZ^OJZNKAX>'4U-30T-#,
MS,S'Q\?"PL+!P<&^OKZZNKJXN+BPL+"LK*RCHZ.;FYN4E)20D)"-C8V+BXN'
MAX=_?W]K:VM04%`D)"0@("`;&QL4%!03$Q,("`C___\`````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!AX;?U````)'123E/_________
M_____________________________________P!8+`T-`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```)E)1$%4&--ECVT3@B`0A'=*.NPD
MP]Z(T-/X__\QT";'V$\\L[-["V*453$BRFZ51"3\V>E9^$5^JX5%AFQ^68*S
MK75!%NZ]X2SC^_F^/W&MM:ZY\;D_F-&_IB,!;$+:X_@RO9\'!=3L!&)9DZJJ
M2I%F*QC:F?<SMT/AISPZ4DJ11<ZG_BO.1-3AGOO3_>:!K-MR_W]?L7_SOP^^
M\1HLN>=^#@````!)14Y$KD)@@@````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+W=I;FMT
M;VYG=65O=70N<&YG````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`W-S`@,3`U,34T,S,W
M-3$@,#(V,C8P`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````/````#P@#````#`AE>````,!0
M3%1%````____S@!2M0!(_0-G_`-G(0002`\H+A0B$`L./",S$@T1#PP/%189
M/<RU,*".!A,1"R`="A$0C^+5/]6[/M&W)H!P.KJD.;BB)GEK'V)7-ZR7-:20
M2MK`)&I=+H!Q+'5I5MW%3LBR!Q(0"!02:^#,:]_+/H%V(T4_?^72-Z^8-JR5
M"!@5`P@'"A02'24C&QL;____````````````````````````````````````
M````````````````````MQ_B8````#)T4DY3________________________
M_________________________________________P`-4)CO`````6)+1T0`
MB`4=2`````EP2%ES````2````$@`1LEK/@```)-)1$%4"-=EC\D2`B$,1%/N
M*XZ*1@4%1E$8%S+__W.R>+$FI[RDNM.!-A51(,H=)')*2JD<%28M,)70E)CT
M$QGGG&$3!]`Z4>TOU]H`H'`MD,)5]7[<+0!#14`2N;'>>VLX2H)0>%LX=/91
MS]:WSV*Z>65]]$=^7@Z&\UWVC_<;9+->?WPH]W.^XV1T^N7KY/_[[PM#FAXK
MF]5UF`````!)14Y$KD)@@@``````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]D979I;"YP;F<`````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`Q-#$P(#$P-3$U-#,S-S4Q(#`R-#0S,0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````#P```!4(`P```*Y%1(4```&`4$Q410```/___\8@
M(\4@(IH9&Y48&I08&GH4%7`2%,,@(KD?(/8N,(T='I`>'_<\/4L<'?EK;6,0
M$A@$`_(A(>T@(.4?'\@;&]\?'\P<''P1$>@C(=P?'PX"`L\?'\T?'\@>'A0#
M`]8A(<L?'S0("-,B(<(?'\`?'V@2$1\%!;4?'ZX>'H,>'F,='5(8&/=45"<;
M&R`;&_S\_/O[^_KZ^KV]O;6UM:*BHG5U=1L;&Q@8&!<7%Q`0$`\/#PD)"0@(
M"`8&!@4%!0("`O___P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````_GK%````!#=%).4_______________________
M____________________________________________________________
M_____P!!8@3O`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@``
M`-))1$%4&--MD.M2PC`0A<\B(@VVJ4@!P;OQ`M%6J<J*(J7O_U!LM\B,,YS)
MC_W.F<UN@O*_L(>3;9W4?'6VY?-[Y?%?#Q+EBQW?*E]Z,&?,&$R5)_XY-,8\
M#*9>^=4'3G1SX+EB]HV[;N\TN7YJB('2!JX/1,#0!;8$AV[4`5*@,W(A@\TC
MHC2.XS3"BV%DYIM0*R],)CF(Y,P6-%M*SN'JDWZ)\@5]%-)?VM9Z_E7E[\61
MU?G--7)Z^RE.=+X8ATNY;=6N]Q/#5OL?6][]E[Y/JPT\?C/3IE3VXP````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]R87-P8F5R<GDN
M<&YG`````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P-S<S(#$P-3$U-#,S-S4Q(#`R
M-3,U,@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````#P````\(`P````P(97@```#`4$Q410``
M`/___\X`4K4`2/\!9R0!#U0$)CX%'U<(+1L$#Q8%#0(``20'%A4&#@\#"I8@
M9>,QF=\PEHX?7]HPDL$K@<0MA&D81\8NAH$>5Z(F;I4C92D*'",)&'PF6'XH
M6A4'#^M@L14)$.J(P"`'%KHL@;<L?ZXK>.@]HX@G8>I*J)DP;N9>KD@@..]V
MOB8<(@L#"!D'$@\$"QL;&____P``````````````````````````````````
M`````````````*4.'/P````T=%).4_______________________________
M_____________________________________P!+5R)E`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```)1)1$%4"-=EC]D6@C`,1.<H;KBA
M5>.&%J6U:*D:_O_?M*TO'O*4FYS)3-#X8G;,H8,G:[36QG)DSM5A3[NKRMDS
MYR6MQO/9DLKO`(U5!-R?IS=(V09L2`#R(0%!AL&:LDK6=2VKC#3#1;Y$=JV]
MUQ_/19I.7T'O[V>W29*,%N%^\!?#3K>_COX^'VT'O<TO7RO_WW\?!-<?PWTS
M@O(`````245.1*Y"8((``````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O8FQU<V@N<&YG````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#<V-2`Q,#4Q-30S,S<U,2`P,C0T-3<`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@````\````/"`,````,"&5X````P%!,5$4```#____Z^@#N[@#6
MU@#(R`#$Q`"XN`"GIP"?GP";FP"8F`"*B@!\?``\/``0$``$!`#5U0W,S`S'
MQPS__Q___SG__U4+"P02$@?_^#O9S@?AMAC_TRGFH!_GGR/]ES/_E3CP<B/_
M<2'_=#WV8C7^7#+_/RO_0RW\-23_)!G_,"G_!`3_&1C___\`````````````
M``````````````````````````````````````````````````````````#S
M^%F,````+G123E/_____________________________________________
M______________\`@H]S50````%B2T=$`(@%'4@````)<$A9<P```$@```!(
M`$;):SX```"4241!5`C794])$L(P#-,T;L*2IH;&@;+O>___/6)Z`G2RK+$D
MHU,PU\R?"<J"=\[YP#WGRI+"5JR<JY),412&RKQ`%RP!,4:`;.C`G@P@(H`A
MSV"WW*XDS9+LSFO'J-WI=6W3/,GC>7-UUC>78YM2DL-]GW7V"S0QW\<I]#[[
M#S#)_@U&ZJ_Y8RB&??YOO[_^7_^]`5ZL$@CU1(0+`````$E%3D2N0F""````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O96UO=&EC;VYS+V5M8F%R<F%S<V5D+G!N9P``````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#$P,S<@,3`U,34T,S,W-3$@,#(U-C(S`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````/
M````#P@#````#`AE>````,!03%1%````_____A@9]AXC^2PO[BTT[S4][3A!
MW$=8U$Q>TEAOODAILDMLM&:-K62.AF*6@F"6`0$"`P,%96BJ=7S#67'#`0($
M`@,%$Q06/&N_#`\4,'7:*V:[+FS&(4V-'41\'D:`&SYR)DE\6(/%'"`F,7OC
M`@4)'$1X+&FZ+&>W'$)U*V*N/8;H)U"(2HWJ4H3*8)KK(#%(=JKO#`\3!@H/
M``$"`0(#!PD*``$!'1X>_P0$&QL;$Q,3$!`0"PL+____%J]MB@```$!T4DY3
M____________________________________________________________
M________________________`,)[L40````!8DM'1`"(!1U(````"7!(67,`
M``!(````2`!&R6L^````K$E$050(UVV/QQ+",`Q$=^B]$T(1-0:"8^.$CH#\
M_U]APXD9=-+3SJXDI*Z8`^9/!T>QDE*JF+_\:'L+(IIZYZ=C'FQF)R'$>KZ[
MLN4X!"*M=02$<0I6!&ACC`9(,5AV&SV3)(FIEUJ2$<ARIKBZ/"_[W#TO`ZLW
M"Y7#+;F-JMF:U5D-^Q&L']'8^6T^"=A\"'+Y*2^WU/&%WZ'MTNVW@W!R?!TG
MH<5_]__\]P;#!28-=RQ]$0````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O96UO=&EC;VYS+W!U;FMM;VAA=VLN<&YG````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#$T-S<@,3`U,34T,S,W-3$@,#(U-3(W`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````/````%0@#````KD5$A0```8!03%1%````____A$1="`(%`P$"!0,$
M$0\0KSEX%P4/#`,(&`40XS&9AAU:XC*8VC"231$T"0(&-0PDQBZ&3A(U+PL@
M(@@7,@PB&0813!,T(PD87!Q!?"98=B14=2137QU#2Q<U=R55="]7ZV"QSE2;
M=3!84"$\ZHC`)@@:WS"700XLNBR!MRQ_G29MKBMX11$P<!U/Z#VC;1U-B"=A
M=B)4<B%1?2=:ZDJHYTFFU4.9.1(I*0T>'`L5Q%"42"`X+Q8E/Q\R[W:^Z'.Y
MW6VPW&VO12(W)APB$00,!0($`0`!!@4&`-,.`*@+`*@,`*8+`*4,`*`+`)T+
M`)L+`)H+`)D+`)@+`)<+`)8*`)0+%C`8&B(:1X,X.#HN`@$!D69F&!<7Y^3D
MTL_/GIZ>&QL;%145$!`0"`@(____````````````````````````````````
M````````````````````````````````````````````````````````````
M````````YW/!PP```&=T4DY3____________________________________
M____________________________________________________________
M________________________________________`!06NG@````!8DM'1`"(
M!1U(````"7!(67,```!(````2`!&R6L^````Y4E$050H4U7.5S?$8!2%X1-&
M#8.C&[V;^)0/44.4F#BZC-X/]O__"2XB:\6^>==SMPGIY"XMI3F3:\G[5*[R
MEDM)Y";G<TDD^>>J5'.^D(?'^\P:R&V-L<^:6DN>/#4P>R4%"%\#97YM==TB
MET>^0:C4=K4M^KZ_/-<35T"ZTDO9FE:5U/`,Q7L'1X6XF8U29'AV:W)_^G!J
MTV43D1IV-\;#,)Q8Z^@T2FJYN+2^,[;]4N_T624$'K?TG[S1.WWL!B#H4'?A
MY],AAXX'%03H\'QC'5'[PJAF_ZTQQ@9__P&H1JH`@%^/:E3KHF2_2`````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+V9R=7-T<F%T960N<&YG````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`U-C$@,3`U,34T,S,W-3$@,#(U-3$W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````/````#P@#````#`AE>````&!03%1%````____^OH`[NX`
MUM8`TM(`R,@`Q,0`N+@`BHH`?'P`;FX`:6D`/#P`*RL`%A8`$!``!`0``P,`
M__\/MK86__\?NKH7__\Y__]5"PL$$A('____````````````````Q/=7<```
M`!QT4DY3____________________________________`!>RXM<````!8DM'
M1`"(!1U(````"7!(67,```!(````2`!&R6L^````@DE$050(UV6/RQ;",`A$
MYR38/&PTM%*B^?__M#1VH;+BPID90+=BKLQ'!Z.28HRI\&#.@:Q"9F/.$WGG
MG*=I'Z"70("(`!1*!R?R@*H"GA*#(SG1]FPJCB*C#GX-KN>^-=WNEWUO^E5V
M_;;,IC=_MXH\ENOA?^;?YD_^[WU_]W_]]P8('0T69"N/:0````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V5M;W1I8V]N<R]C;VYF=7-E9"YP;F<`````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P-34W(#$P-3$U-#,S-S4Q(#`R-3$T-P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M#P```!4(`P```*Y%1(4```!@4$Q410```/___P04!`<A!S'C,3#:,2[&+RRN
M*S&V,`('`B9\)DOJ2F#K8(CJB1PF'"ZZ+"ZW+#"Q+B^N+B>1)BB()R%(('?O
M=AL;&____P```````````````````````````-*'6^X````9=%).4_______
M_________________________P`!-`JW`````6)+1T0`B`4=2`````EP2%ES
M````2````$@`1LEK/@```(-)1$%4&--M3P$.`B$,:Q2&`G*H0/?_EWH<,1?$
M+EG2=>LVJ$+U3#CB3-"Y`4O_C/\ZF<BOKJS%.5<J!Z?/TI$].Z??Q!ICK&Q[
M`5JS`"$$0')5L(@%8HR`E4+0B0FQM1:#$4>DP1^#IT7O\[<[=CR/^>Y_>>_^
MK^OAO^S_O6^Y?_KO`XS)$YXM>'U4`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O
M;G,O:&EP<&EE=&]N9W5E+G!N9P``````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3`Q-2`Q
M,#4Q-30S,S<U,2`P,C8P,C<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@````\````/"`,````,
M"&5X````P%!,5$4```#___]5#!LE`PW.`%*U`$C_`F7_`V4!`0`/"P(]*0`#
M`@"+70'XI`+SH0+MG@+5CP+2C0+/BP*W>@)V3@%Q3`&(6@)Z4@(G&@'ZL!]1
M.0K^LR#CH!V09A*&7Q%>0@P7$04?%P?]NSSVRFZ(6`'&@@+"?@*680(Z)@(5
M#@']JQ$<$P(7$`-X7"C^Q%9T62?TO%,F&0,@%P@7#@,"`0`F$@D7"@<<"@=:
M&Q0_$!`"`@+___\````````````````B2EGD````/'123E/_____________
M____________________________________________________________
M_____P"[B.NG`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@``
M`)Y)1$%4"-=EC^<.PC`,A"UV@1!#(&6/0D-8894"SON_%TD+0HC[Y>]LZ<Y@
MO8@"HFP"3UH*(:2FG"E4Z*5"\DQAC)PQQC%V!MC&JE.O#<>SI(OKC06"KY(^
M`0EDT\OQ=%A,&`J"P/$@,DL3C1P'V7X4&9.SNY?(S_MYFEYW'"6!U0K9]E:I
MWENH]"?_42H7VGE^UJ_Y+/;>_?[Z__SW`GG9'VQGEQ9?`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E
M;6]T:6-O;G,O9&%Z960N<&YG````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,3`T,"`Q,#4Q-30S,S<U,2`P,C0T,30`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@````\````/
M"`,````,"&5X````P%!,5$4```#____&("/#("*Y'R"O'1YB$A.:'1Y%#0Z0
M'A^^+B]]'A_W/#WQ.SSN.COC-SA+'!U2(R3Y:VW(5EB90D,7!`7R(2&;%15"
M"@GI(""N&!B2%!1F#@Y("@KH(R'.'QUH$`]."PM'"@I,"PM/#0S'(!_"'QZV
M'1R-%Q:#%12!%133(B'`'QZQ'1RD&AIK$1%`"@IJ$1%)#@Z#'AY*$A*.(R,8
M!@8$`0%-&AKW5%3!0D)&&!CR@'\G&QL;&QO_____?0T!````0'123E/_____
M____________________________________________________________
M__________________\`PGNQ1`````%B2T=$`(@%'4@````)<$A9<P```$@`
M``!(`$;):SX```"M241!5`C794_7$L(P#/.1,%)""0'"*'M#RBPK+77__Z](
M*"\<>K*LLR1#YH"8(GXF<$PP2BD3F'.,R/FHCV<2H>,8%380J``V!;N`3!#]
M`(][\-!$9(!,C]KWV,3W]D@S!*2A\HV4TOA*4X2T>.IP(U_2\%Y(4ZLOAC73
M;+0,'VRMCFS=+=^29U(OS9?VWOKO9I5J[7J9KIR_R]^/E>I/#GF^ZZ<=OOW^
M^O_\]P9,9B+:P)!^>@````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]E;6]T:6-O;G,O<V%D+G!N9P``````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#<U-2`Q,#4Q-30S,S<U,2`P,C0Q,3``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M``\````/"`,````,"&5X````P%!,5$4```#___\#!@LG8K8F7JXE6ZHP==H7
M-V4.(3TN;,8)%"4"!`<F27R(K^H<("8F8+$'$B$Q>^,"!0DL:;HA3HL@3(<L
M9[<@2X4&#ADA38@K8JXN9K$]AN@P:;8N9*XF5)$G4(A*C>I@FNL@,4AVJN\$
M"Q0;&QO___\`````````````````````````````````````````````````
M``````````````````````````````````````````````#\]0M!````*'12
M3E/___________________________________________________\`OJHN
M&`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"2241!5`C7
M98_)$L(P#$,U+`%#*81"@+!E0_W_/\1)3PPZ^=ECR<981?9DJU`I!^]]R)R8
MW6TE(NM+Q\KL3L>EM78Q.VL#8W;7_2/&^)AO7![!(`9(*0%&`D$O%BBE`%8\
MT2O'5'8E1>6^S97+Q&S[SRU4][:O_O)YJ__K(-5?\P<QFF]D:/G:<%+EIOO^
M[O_Y[PNIZ1;,XG5O9P````!)14Y$KD)@@@````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC
M;VYS+V9R;W=N+G!N9P``````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`U-#`@
M,3`U,34T,S,W-3$@,#(T-#8T`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````/````#P@#````
M#`AE>````&!03%1%````____`P8''",E.**[+&AVCM+C/;O7.[/."1L?-)*E
M:<OA-9ZP-9JM!A$3.)NM-I2E-Y:G+7N)+76!5<G?(D!%?M;F&QL;____````
M````````````````````````@#;V=````!ET4DY3____________________
M____________``$T"K<````!8DM'1`"(!1U(````"7!(67,```!(````2`!&
MR6L^````=$E$050(UV6/2Q+#(`Q#-<$4`J%-RT?<_Z3%L&K1RL\>RS*ZBC3D
MK*!4<P@A5RZF3:)*ELJTEWCGG)=K--!K$J"4`DBJ'<SB@1@CX"43#.)*;*W%
MXB009O%CL=GFNO\Z,/2>^^K__`S_^YS^V_W_?%O^G_^^!PL,\>]8%>0`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]C;V]L9W)I
M;BYP;F<``````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,S,U(#$P-3$U-#,S-S4Q
M(#`R-3$U,``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````#P````\(`P````P(97@```&`4$Q4
M10```/___P`!`0$#`P(%!0($!`$"`AUB5SW,M1]G7"9F7`@5$X_BU3_5NSJZ
MI#FVH3BSGC>PFS*@C3*?C#"9AS>LES6DD"Z`<2=I7BQU:5;=Q36)>B%53!4V
M,&O@S&G<R!HV,1$C(`P8%@8,"R-%/Q(C('_ETCUN93>OF#&<APH:%WWASF.R
MHQTE(P$#`@L-"P,"`1,0#@H&!1$+"B`+"O\``/H``/4``"```!<```$``#@#
M`B4$!`8"`AL;&Q<7%Q,3$____P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````&N3VOL```!"=%).4___________
M____________________________________________________________
M________________`$06$``````!8DM'1`"(!1U(````"7!(67,```!(````
M2`!&R6L^````J$E$050(UV6/V1*",`Q%,XJXMJ+05G#7BKC@7MRC_/]/V8H^
M.-ZGG$DR.8'4!#%&?%=@2`K.N9"8,?J,FC`?#3\J,UHBA)1HU'IJ'N5S8%4[
M<QO`FJ2`PBU:8`\*L"I3@8"<DNYXN9@.VX1RA%AST`]K82_0')O^!K)<'-U'
M00_GHTI4<MJ:_52R^OJFE+KN'";U/?2CQEU/[YN1%OKXN9[W]?OS__GO!0U0
M(2=H)?\W`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]P
M=6YK+G!N9P``````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,#$Q(#$P-3$U
M-#,S-S4Q(#`R-#,P,``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````#P````\(`P````P(97@`
M``#`4$Q410```/___P@"!0,!`@P#"!@%$.,QF=HPDDT1-)0B9)`A8<8NAILD
M:8TA7R\+(#(,(AD&$5P<07PF6$L7->M@L74P6%`A/.J(P"8(&M\PET$.++HL
M@;<L?ZXK>'`=3\(SB+HQ@K4P?VT=38@G878B5'(A4>I*J-5#F3D2*2D-'D@@
M.#\?,N]VONASN=UML-QMKT4B-R8<(@4"!`$``1L;&Q45%1`0$/___P``````
M`````````````````````````)";=+\````X=%).4___________________
M______________________________________________________\`.UP1
MR@````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```">241!5`C7
M98_)#L(P#$0MEA0P:PEK8J`$`H2RM#7T__^,I(@#ZIS\--)X!LH@YHRYNB"0
M,T1D''^98XU!.N;`KXG"2`@1H9J^/>>-86=CK=VO1T5>`A_&\%/KR,"$2RBN
M]V>S:",Q9(2KR^RV>,S/`BD+OCC)-$VE%<%G@Y!8*:7=`1J&TND^;'U^`CWM
M_#^.U:!*[RI?J-ZOUO]OWP>R"1U"S&HD^@````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I
M8V]N<R]G<FEN+G!N9P``````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P-S0U
M(#$P-3$U-#,S-S4Q(#`R-#(W-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````#P````\(`P``
M``P(97@```#`4$Q410```/___RL!`A@!`R4##`<!`Q8##`0``@(``1L$$:(P
MVH\LOXPKNY0NQI$MPG\GJ7HFHW\HJLJ(ZJ<QXX@LNH<LMX$KKF8GB%\F?+1*
MZKQ@ZSH@2,5V[R(<)O\``!@``!(```@```$``!L;&____P``````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````$W^BA0````E=%).4___________
M_____________________________________P`_ST)/`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```(U)1$%4"-=EC\D.PC`,1$>L)<50
M2+,G97'^_QN)&W%`S,G/(]MC5!%S85XK""5GK76).[,W)#*>A=G/I+36BN;6
M0$V&@!`"0"95L",%Q!@!18[!EG2(.><8-%E&Z7SO7,0_HNL]-K_-[YXOP<=)
MYMO^R[!=EF4SC+)?[I_WS3[<^OTUWW6:OOG^\O_\]P&SPA2-RV[AZP````!)
M14Y$KD)@@@```````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O;6%D+G!N
M9P`````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3`R-R`Q,#4Q-30S,S<U
M,2`P,C0P-S,`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@````\````/"`,````,"&5X````8%!,
M5$4"`@+^_OZC!P3^2#[?"0*P&A7:*B.^"`/O$P>F#PWM*!_*(!GN'A;\.2_^
M:V>P!P-.!@)6-B[^6E$:&AK:&Q/^?GK"$PW^+"#\#@72#P>S$@W+)R*['QK^
M'1'-"00```#)TS)6````('123E/_________________________________
M________`%Q<&^T````!8DM'1!\%#1"]````"7!(67,```!(````2`!&R6L^
M````E4E$050(US6/BQ*$(`A%&;,TC?#1IE:V__^72[I=AAD.S,`%OBSH:N63
M\SP>+.@,8KSL>=J='FCH_8+:>VYPS-=DDJ\^Z\+$8SLAH$^0-L5;Q6%-C6$-
ML2XWM+G!8?VLF'3GTR`.(:3Z\I2C<RY*26P*Z"HQUYIE5-#OJ[(M6LN[W><&
M'7LIM^K^GG<$$0GX^W\?;-4/<*8-U.%AR98```"#=$58=&-O;6UE;G0`5&AI
M<R!A;FEM871E9"!'248@9FEL92!W87,@8V]N<W1R=6-T960@=7-I;F<@56QE
M860@1TE&($%N:6UA=&]R+"!V:7-I="!U<R!A="!H='1P.B\O=W=W+G5L96%D
M+F-O;2!T;R!F:6YD(&]U="!M;W)E+@%54U-00TU4/0`Z&`````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O
M9&5V:6QT;VYG=64N<&YG````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3`V,"`Q,#4Q
M-30S,S<U,2`P,C4V-30`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@````\````5"`,```"N142%
M````P%!,5$4```#____&("/%("+#("*Y'R#V+C"0'A_W/#U+'!WY:VT6!08E
M!@L7!0@<`P@7!`A9!1D_!!15`QTD`0W.`%*U`$C_`67_`688!`/R(2'M("#E
M'Q_(&QO?'Q_,'!Q\$1'H(R'<'Q\.`@+/'Q_-'Q_('AYP$A$4`P/6(2'+'Q^)
M%A4T"`C3(B'1(B'"'Q_`'Q\?!06U'Q^N'AX;!04E!P>#'AYC'1WW5%06"`CR
M@'\G&QL@&QL;&QO___\````````,K$#G````/G123E/_________________
M____________________________________________________________
M____`+K[<38````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````
MOTE$0508TVW0V7+",`P%T#O4SEJ@K&U(@91]$5TH)C15_O^WB&7*#$/UI"./
M+-DH;P/_.+WDJ?-\?/'D7?SVUX-4/+UZ+9X9,!?,&.[%7^;H:ZT_AGLC_C6*
MJE@]&+9F4]N^#))T^5FK"BA#1:]``(Q(A278I\P#<L#+R&>PIB3(HRC*@X0T
MHW#^<2[NSFW_(3[5F_&W]-O[$^_QN=\8R/UV/F5/W5Y[Y^97!46;5F>AW'Y5
M(;3[^R%?_TO>)]D9A0`RVC\53WH`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T
M:6-O;G,O<'5N:W1O;F=U92YP;F<`````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3,T
M,R`Q,#4Q-30S,S<U,2`P,C4U,S(`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@````\````/"`,`
M```,"&5X```!@%!,5$4```#____.`%*U`$C_`6<D`0]4!"8^!1]7""T;!`\6
M!0T(`@4#`0(D!Q85!@X,`P@8!1#C,9G?,);:,))-$33$+81I&$?&+H:!'E<O
M"R`R#"(9!A$C"1A<'$%\)EA+%S45!P_K8+%U,%A0(3P5"1#JB,`F"!K?,)=!
M#BRZ+(&W+'^N*WAP'4_H/:-M'4V()V%V(E1R(5'J2JC50YDY$BDI#1Y((#@_
M'S+O=K[H<[G=;;#<;:]%(C<F'"(9!Q(%`@0!``$;&QL5%140$!#___\`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````"&Q'9&````
M17123E/_____________________________________________________
M_____________________________________P"R[K$X`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```*M)1$%4"-=EC\D6P4`01>L04XRM
M4<80<]((0<0029'__R;=Q,+Q5G7/6[Q;$*L0!43O"Q1YCA#"\>C#9-BH8AND
M^#&PD#/&.%K#I^2PV&FL7-?=++M1&`-M>_!-=4=``N<0G2ZW4E1#01`(7!S'
MY]EU<F`H`M6SO>G[ONDRU9.#O#^:ZGKESM$AB#T;V;JL:84ZVI[<(T/NYU/I
M;-.20HE?.Y=I)7Y__C__O0!$_":ONESU=@````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]E;6]T:6-O;G,O8V]O;'1O;F=U92YP;F<`````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,3,T,"`Q,#4Q-30S,S<U,2`P,C4U,#8`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@````\`
M```/"`,````,"&5X```!@%!,5$4```#____.`%*U`$C]`V?\`V<A!!!(#R@N
M%"(0"PX\(S,2#1$/#`\5%AD``0$!`P,"!04"!`0!`@(=8E<]S+4?9UP+(!TF
M9EP(%1,*$1"/XM4_U;L^T;<ZNJ0YN*(RGXPF>6L?8E<WK)<UI)!*VL`N@'$G
M:5XL=6E6W<4UB7HA54P5-C`(%!)KX,QIW,@:-C$1(R`,&!8&#`LC13\2(R!_
MY=(];F4WKY@QG(<(&!4*&A<*%!)]X<YCLJ,=)2,!`P(;&QL7%Q<3$Q/___\`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````#!
MT4KI````1'123E/_____________________________________________
M____________________________________________`''2CQ(````!8DM'
M1`"(!1U(````"7!(67,```!(````2`!&R6L^````J4E$050(UV6/UQ*"0`Q%
M,_8NXEK76%A7L&!#Q(I1_O^?W`5>'.]3SB29G$"D0Q02Q15H\J000GJ4,-D6
MZE@V:7[W+L@XYPR#Q4?QH=D`H[^ZF0#&*0*2D[8!YJX%KPY*`A+(U\?GX[Q?
M<A0$H6)GZP]]UU$<QGW']?V$U;Q$UMW<:^7!E>G]R+.0S^NY?'6$EJ?ND1T@
MJV2RQ7&@A%*_::DP2_W^_'_^^P(]FR;-%K+&4@````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]E;6]T:6-O;G,O8FEG9W)I;BYP;F<`````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,3`Q-2`Q,#4Q-30S,S<U,2`P,C0W-3``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@````\````/"`,````,"&5X````P%!,5$4```#___\!`P0!!`4<(R4XHKL<
M4%TL:'8"!P@KA9DG>8L]N]<F=8<C;'P[L\XTDJ4$"0H?0DIIR^$I>XDF<'TU
MFJTH=8,A8&P?6V4;3U@I=H0?661(Q=PM?(HO?XXM=8%5R=\B0$4L<WX``0$!
M!`0!`@+\_/S[^_OZ^OJ]O;VUM;6BHJ)U=74;&QL8&!@7%Q<0$!`/#P\)"0D(
M"`@&!@8%!04"`@+___\```````````````````````````````"68K'A````
M.'123E/_____________________________________________________
M____________________`#M<$<H````!8DM'1`"(!1U(````"7!(67,```!(
M````2`!&R6L^````HDE$050(UU6/R1:",`Q%$P5QI(K6$2U%%!PBBI3^_Y_9
MEL/"M\K-^`+:BL@C<A%8DH(Q)B2U3`'WK7A`EBE8]?JSR2C+MB8!6O+A^'A)
MYJ?IF4L-)/PP3J(H2N+0%P3$!M!IP0@\]D8$Q+S$0C'/U,%Q46)>F3J)^H%?
MQW=EYK5<-\^7[;^IC73WEPT4>/VHG;MO$OO*+*\/K;_.?]KY__OO!SZH&PWA
M^34Q`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O:'5R="YP;F<`````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#<V,B`Q,#4Q-30S,S<U,2`P,C0S,C$`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@````\````/"`,````,"&5X````P%!,5$4```#___\&`@</!!0=
M"">3*\=^):JB,-J#)["4+L8Y$DP2!A@#`01^-*,@"2QQ(9H8!R&G,>-W(Z(6
M!QZ(++J$*[6'++>!*ZZ$+K$7"!^(,+:"+JYL)I$^%E-F)XA?)GRT2NJ5/<*2
M/+Z-.KBS2NF\8.LK%C8C$BPZ($C%=N\(!0HB'"8."A$;&QO___\`````````
M```````````````````````````````````````````````````````````.
M^NX_````+W123E/_____________________________________________
M________________`%JE./<````!8DM'1`"(!1U(````"7!(67,```!(````
M2`!&R6L^````D$E$050(UV6/R1("(0Q$4VX8=W0$5V!4%,3P_Y\G8<J#VJ>\
MI#J=0&81):):`5,P6FL3J&.R"EG*$C/99C(>#!>CS;8T(`>%R^G5769K5"$#
M&13[]N'O\[-`0T`:Y<W'9_1.HB9(A9V/KXY3G1>.GSG[#STHVE4_[^^?G'/'
M5=W/^2BDE`*;FO][W]_]7_^]`9]#&LU`3YN-`````$E%3D2N0F""````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O96UO=&EC;VYS+V%N9V5L+G!N9P``````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`U-S8@,3`U,34T,S,W-3$@,#(T-#,P`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````/
M````%0@#````KD5$A0```&!03%1%````_____?\`^OKZ]?7UZ^OKX>'AU-34
MT-#0Q\?'PL+"P<'!NKJZN+BXL+"PK*RLFYN;E)24D)"0C8V-BXN+?W]_4%!0
M)"0D("`@&QL;____````````````````````ABT[#````!MT4DY3________
M__________________________\`)S0+-0````%B2T=$`(@%'4@````)<$A9
M<P```$@```!(`$;):SX```"0241!5!C398]M$X,@#(-SFQ0J#O<":/G_/W2M
M>O,<^<1SN:0!K<FIUM#D=DH:%'^V/CN_RU^UL\AJYL%2<YI2KK+S4B*;8EFV
M^V7DX+T//!;KKY$!(@(X5MV3.0#..2!P%DAB3VX8!D>>DV"=-KYO/*V=KWG,
MI'E*L+SV/_'0_AEOZ[?['YA>^_W_?=W^R_^^EH`4!>W\QSL`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N
M<R]C;V]L+G!N9P``````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,#`R(#$P
M-3$U-#,S-S4Q(#`R-#(U-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````#P````\(`P````P(
M97@```#`4$Q410```/___P`!`0$#`P(%!0($!`$"`AUB5SW,M1]G7"9F7`@5
M$X_BU3_5NSJZI"V1@"N+>BJ'=RF$=#*?C#>LES6DD#NNFCZVH#JJEBZ`<2=I
M7BQU:5;=Q36)>B%53!4V,&O@S&G<R!HV,1$C(`P8%@8,"R-%/Q(C('_ETCUN
M93>OF#&<APH:%WWASF.RHQTE(P$#`AL;&Q<7%Q,3$____P``````````````
M`````````````````````````````-(5=7\````U=%).4_______________
M______________________________________________________\`?+70
M"@````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```":241!5`C7
M98_9$L(@#$7O:*UU`3?08J/BAEB7&NW_?YO0/CG>IYQ),CE!'<-<,3<5(CFC
MM3:.6^9"R1A5<.3W\"8S(40FR_4G\*G;03+:WE,@N=1@L^@G2`\]O`;2,%A+
ML3L_']?C1DC-J`+3WH^]I<!5TR?K?<MAWDCD9*VE)>)^[=0$*R+*,5,NW..B
MG"-F6@:A?[\__Y__ON,?&Z55=I!0`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M
M;W1I8V]N<R]M<G0N<&YG````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q
M-3$Q(#$P-3$U-#,S-S4Q(#`R-#$S,@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````#P```!4(
M`P```*Y%1(4```&`4$Q410```/_____\``$!`/_D`/WC`/SA`/G>`//8`-B^
M`-:\`-.Y`,:N`,6M`+^I`+*<`*N8`*>1`)^+`)2!`(EW`&]A`&E<`&)5`$0[
M``@'`&Y?`&A:`%E-`$`W`#PT`#0M`!01`!@4`!L6`!H5`!L5`!@3`",;``\-
M"$(N`0\+`B49`*]T`?BD`NV>`N"4`M6/`KI]`K=Z`K=[`K9Z`K5Y`JYT`FI&
M`:9O`HA:`GI2`GE1`EP^`K%X!;-Z!_ZS(/V[/`4$`@8%`XY<`8E:`857`>>8
M`L:"`L)^`JIN`H)6`CHF`B\?`OVK$5@Z!MB6&AT5!AD3"/[$5@T(`'Y.`9-7
M`8)/`5XZ!0L(!&,["0(!`$\G!388`)@K``P#`!86%@@("`("`O___P``````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````+QBN2D`
M``!B=%).4___________________________________________________
M____________________________________________________________
M__________________\`$%:2J@````%B2T=$`(@%'4@````)<$A9<P```$@`
M``!(`$;):SX```#T241!5!C319#G4L0P#(1W0B]'-7!4`Z$%$LQ1$TI,/8,Y
M2N@E@/S^+X'CS,WM#ZV^&6EV)!@G^/#+QE6_8+_%"UB>!YI,>FUQZ?/F]K1D
M.KK>7IG<W3H_I((IN5S_>=F\`BX2,H!6SQMW7_<?;_O?KP`(B``II7,J.`2R
M+'-."&H(4YF=93(-40M`CM_;'AW;^5A$C=3NIXU(Q`2CE;"+5J%0VN77Q6^>
MYZNB7N3S7DK4R</3W[%*J)N#C_:1CG<.]F)-G8,<9F)@>(8H(.*\?[:XIUKI
M&>=6'96I\MZY(<8\QD:JS7^P,<_K8M.M_QC6SLOF'\J91_S_\?+8`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V5M;W1I8V]N<R]S;6EL92YP;F<`````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P-34S(#$P-3$U-#,S-S4Q(#`R-#0T-@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M#P````\(`P````P(97@```!@4$Q410```/____KZ`.[N`-;6`,C(`,3$`+BX
M`*>G`)^?`)N;`)B8`(J*`'Q\`#P\`!`0``0$`-75#<S,#,?'#/__'___.?__
M50L+!!(2!____P```````````````````````++>=HD````:=%).4_______
M__________________________\`%"(`V@````%B2T=$`(@%'4@````)<$A9
M<P```$@```!(`$;):SX```!^241!5`C798_;$@(A#$,ST`4O7*);4/[_1Z4R
M^^":IYYVDK88)K*2WPI&)<484^%BYB"FD&G,O(EWSGG99@.C!`%4%9!0!IC$
M`ZTUP$LB&,5IZZ_>U$DDZN+WXGK,^S&??NPZ_?J$^6?^!8^9O^-F^;;_#M-U
M[3_?]W?_SW\?L)@,1^D,.:$`````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O
M;G,O<VAO=70N<&YG````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#<W-R`Q
M,#4Q-30S,S<U,2`P,C0U,#<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@````\````/"`,````,
M"&5X````P%!,5$4```#_____<@KH9PO*6`NX4`K670RN30K+6@RG2@K_=10_
M'04F$0.>2A"/1A(6"P/7:1_39Q\:#03_AS3ZA#/Q@#';="W_EDS_K7(H'QG:
M70Q0+1;_HF45!@$7!P(.`P`:!@$;"`0/`P$(`@$(`0`H`@`H`P'_``#Z``#U
M```Z`0`@```7```Z`@$;&QO___\`````````````````````````````````
M``````````````````````````````#%N-KI````,'123E/_____________
M_________________________________________________P!BI=!X````
M`6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```)Q)1$%4"-=5C^D2
M@C`,A'<:K:5:/!`1BO=1O,+[OYU-F7'&_,J7G4TVZ*68:^;40<@[8XSS/##G
MFJ1TSL*<-Z2LM8J:.$#O-4U7ZZ*<STC['NQ(+8$*6"AR##9D"Z`%"DN&40M7
M[;:MA.NDEQ<`ITW2Q;^_AQ`^Y^27_>]'Z$+W2OOE_NX6]>=AN!\'HVOT'\=#
MOI1_DF6__'__?0%`*A;SZR3)B@````!)14Y$KD)@@@!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+V%N;F]Y960N
M<&YG````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$P,C,@,3`U,34T,S,W-3$@
M,#(T-S8S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````/````#P@#````#`AE>````&!03%1%
M`P,#:I*^,D)6'B@TLLKB2&2`*3E)AJK24E)2$!`0YN[V4G*2.CHZ=Y_.RMKJ
M+CI*F+C:_O[^2DI*0EEU7'RC.DYF)C)"HK[><IK*"@H*%A86TN+N1EY^0CY"
MNL[F````,$23$````"!T4DY3____________________________________
M_____P!<7!OM`````6)+1T0?!0T0O0````EP2%ES````2````$@`1LEK/@``
M`)%)1$%4&!DUC@L.`B$,1`OR$9&52%D7<>'^MW2*L4D;WI3,E*842?U>0LTY
MMU^6@FZZEE*JAB+<JHW,'#_500!;5BDEQ;;N8.#A<\[^8*OA05&)N9&!#T2<
MB+:^$24N;G$>_=9'!C^(`MA@;X2QGT'YEQGF>G_'*GD!_N?S7/["$/[Y;=T[
M0Y#[;`,NAH(<H3F_6FH-]\0BBLX```"#=$58=&-O;6UE;G0`5&AI<R!A;FEM
M871E9"!'248@9FEL92!W87,@8V]N<W1R=6-T960@=7-I;F<@56QE860@1TE&
M($%N:6UA=&]R+"!V:7-I="!U<R!A="!H='1P.B\O=W=W+G5L96%D+F-O;2!T
M;R!F:6YD(&]U="!M;W)E+@%54U-00TU4/0`Z&`````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+W=I
M;FMT;VYG=64N<&YG````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`W-S`@,3`U,34T
M,S,W-3$@,#(U-3,P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````/````#P@#````#`AE>```
M`,!03%1%````____3Q`>(P0.S@!2M0!(_@-F_@1F!@@#9(@=I^,QI-\PH-HP
M?:LFD,0M36D8DL8N7X$>&B,)7WPF$!4'O.M@;(<WN^I@R.J(C;HLBK8KBK<L
M@ZXK#Q0%L>@]5G$>$QD':8@GM>I*I-1#$14).T@@R.]V#Q,&(R8<$1(''A<-
M%`T)&`X)%`P)324<.!85&QL;____````````````````````````````````
M````````````````````````.44B/````#)T4DY3____________________
M_____________________________________________P`-4)CO`````6)+
M1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```)-)1$%4"-=EC\D2`B$,
M1%/N(FH444<8'5!&W,/__YPL7JS)*2^I[G0@I"+R1+F#1,YHK8VCPB04IE*"
M$I,X(&>,<:SB`()3]?1T/5L`5"X`&9S7D^U.`G`T!*216=FVK;0,-8$OO"_L
M._NHY^O-Y?&Z-5D?_9$=[Z/Q<Y;]X_T*^7LP["W*_9QO]>DO?_DZ^?_^^P(E
M_QPY#,>$^P````!)14Y$KD)@@@``````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]A;F=R>2YP;F<`````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,S4V(#$P-3$U-#,S-S4Q(#`R-#0U
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````#P````\(`P````P(97@```&`4$Q410```/__
M_\8@(\,@(KD?($(+#+<B))`>'XT>'Z(G*(4@(?Q$14L<'?EK;0(``/\$!/\8
M&!`"`I\6%I<7%>@C(<X?'2(%!?LG)ZT<&],B(9\:&805%2P'!_\J*B,&!M8F
M)?PP,!`#`^\O+[(E)/TW-]\Q,>4T,X,>'HTA(8(>'G4;&^4W-O8\//D_/PP#
M`_I`0/)24O=45"P/#_=551<("(0P,/*`?V1`0"<;&WA86/3T].;FYN7EY=K:
MVB`@(!\?'QL;&Q86%A45%1$1$0H*"@@("`,#`P$!`?___P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````--"B'@```!)=%).4___________________
M____________________________________________________________
M_________________P`,")]5`````6)+1T0`B`4=2`````EP2%ES````2```
M`$@`1LEK/@```+))1$%4&!D%P05"Q#``1<'?32!(BBX2W(-#T6++Q]_]3\2,
M`+![&P`!SBG&F+(!@6O86"NKRZ$:A.N@+,TLS"^6034BAR)-7D[MJH2,G,I0
MZJX[:5B2Y7AX==&U;=M-'QQ%JX_G<SNW[4/;;<ZNQ%Z.9_=/-Y+N'H_WHN6T
M_?ZL1LWGRZ@DBQP^7K\:-9]OHY`1KF,_OY+^OK>J$;B.GZR7LC]Q:A#@G&*,
M*1L0`'9O`_`/]38C`9-Z>10`````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]W:6YK+G!N
M9P```````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P-S,V(#$P-3$U-#,S-S4R
M(#`R-#,Q,0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````#P````\(`P````P(97@```#`4$Q4
M10```/___PX1"@8(`V2(':?C,:#:,'VK)FV4(FJ0(9+&+G*;)&B-(5]\)KSK
M8&R'-[OJ8(VZ+(JV*XJW+(.N*P\4!93",XZZ,8JU,%9Q'FF()[7J2J340SM(
M(,CO=@\3!B,F'`D*!1L;&____P``````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````)59<T(````D=%).4___________________________
M____________________`%@L#0T````!8DM'1`"(!1U(````"7!(67,```!(
M````2`!&R6L^````ATE$050(UV6/P1+"(`Q$=U10HZ`5JI5(Q?#__RB1Z4'=
M4UXRFTU052)%Y%-!*:<88\K265P@57"B+.Y"UAAC:6@-U!S&S?WY8(!"KI!$
MVW%].GO`4A)(),-^?LV>#45!Z;SJ7);YO,R;'Q-[[_D&];?]!UR9><)>][?\
MX0C5KN?_WO=W_]=_;TJN$]`$(*HP`````$E%3D2N0F""````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O=F%M<&ER92YP;F<`````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#<U,2`Q,#4Q-30S,S<U,B`P,C4P,#$`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@````\````/"`,````,"&5X````P%!,5$4```#___\(#!$]
M=[<Z<:TY;ZHX;:<V::(L580L58,:,TXZ<:PY;ZDN6(@I3WH.&RE(@L(W78E0
MB,44(C$,%!U`:)-,=Z9.>:EHF,UFE<EBD,)=B;@N0UL:)C-XH]*,L=F6M]S#
MU>D1(3()#Q0#`P,"`@+___\`````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#65SW;````)W123E/_________________________________________
M_________P"#5I?9`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK
M/@```(])1$%4"-=EC\D2`B$,1!LSB*!.$#?<P$'E_S]1(N7!LD]Y227=014Q
M%^9/!2%GC3'6<6<>-8GTR,(\#N1#")Z&UD!UFK:/4SS/=J1=!5OR!R`!1T^6
MP89"!#(0`QE&$4[YGI-PZ?.4<V>6?7PE^^W^^JENEZMZ+>1^\U]N5!NJ??=O
MC?G4XDVKGN\O_\]_;W/L#_9)#'A(`````$E%3D2N0F""````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O96UO=&EC;VYS+VAA;F=O=F5R+G!N9P``````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`W-3`@,3`U,34T,S,W-3(@,#(U,30V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```/````#P@#````#`AE>````,!03%1%````____SEP(_W(*QUD(62@$Z&<+
MUET,RUH,+!0#ME0._W44X&<2K4\.,18$GDH0$0@"CT826RT-_WTE(A$%&@T$
M!@,!SVXJLEXD_X<T_H8TTW`KR&HI,!P._Y9,.R,2_ZUR*!\9VET,U%H,(P\"
M4"T6_Z)E!`(!&QL;____````````````````````````````````````````
M````````````````````````````````````````````````]^6GA@```"IT
M4DY3______________________________________________________\`
M,JCP7`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"+241!
M5`C798_9%L(P"$0Y1DD4-<:ZX1+;:B+Y_Q^TI"\N\\2%,PQ`48ET(K4"I>2=
M<S[)R!(LJFP090G];#)?KJ?/Q]"`DBRN]E<^OA9H4P'Q:':76[R?M@:]@#BD
M<\PY1R9T`MW`'',[<E?G_#%7_P94A^K7_=0P<T-UO^:C(2*#?<W_O>_O_J__
MWEUA%=OW!+@\`````$E%3D2N0F""````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I
M8V]N<R]B:6=F<F]W;BYP;F<`````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P-S<U
M(#$P-3$U-#,S-S4R(#`R-3$V,0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````#P````\(`P``
M``P(97@```#`4$Q410```/___X0[!?]R"EDH!!</"70S!>AG"^)D"]YC"V@N
M!;I1"M9=#,A7"\M:#-]F$?]U%,9;$+E5#YY*$(E#$8]&$HQ%$ETN#?]])2X8
M"=]V+=1P*_^'-"P7"68\'D<J%3HB$?^63&0['L9^3B@?&=I=#&PN!F8K!D(@
M"E`M%AT2"_^B9>Z77J-H008$`QL;&____P``````````````````````````
M`````````````````````````````````+]%;\P````Q=%).4___________
M_____________________________________________________P`?FDXA
M`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```)E)1$%4"-=M
MCUL3`3$,A3-;-BY5I99:<2F[J$7Z_W^=AB?#><IWSIQ)`DG$W#"_)Q"*SACC
M(G^8*XTB7;$P5VT)8`'*-AN0HL8,E"W4,0$[5)Y"".05.@8V:"ET71?(HF%H
M,M>'V[._KS,WDD_7Q\?]M-M.)<_]XKJ1_JJ0?HJ3T=P3D9_UQE'V+R]#9:U5
M@_."_]SW<__7?R_>.1F3VGCX(@````!)14Y$KD)@@@```'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O=VEN:V=R
M:6XN<&YG```````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#<W-2`Q,#4Q-30S,S<U
M,B`P,C4Q-S0`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@````\````/"`,````,"&5X````P%!,
M5$4```#___\&"`-DB!VGXS&@VC!]JR:-ORR*NRN2QBZ/PBU]J2=XHR9]JBA?
M?":\ZV!LAS>[ZF#(ZHB-NBR*MBN*MRR#KBL/%`56<1YIB">UZDJDU$,[2"#(
M[W8/$P8C)AP1#0,:$00$`@`6#`,,!@$'`P$E#`,G!0$Y`P'_``#Z``#U```@
M```7```!```;&QO___\`````````````````````````````````````````
M``````````````````!,Q,)8````,7123E/_________________________
M______________________________________\`'YI.(0````%B2T=$`(@%
M'4@````)<$A9<P```$@```!(`$;):SX```"9241!5`C798_9$H(P#$4SVHI1
M!!5;;"T6=XM+^/^OLZ'C@^-]RLEZ`SV+R!,-$3`YH[4VCA)3H9"E"F*F8H-2
M""&QB@GHG:K'V_W.`J!R/9#!23U:KDH`B8:`-`I;-DU36H&:P"=>)_9</T+2
M.XOU.']]/4(7NN>!Y^/^67L+(=S/&>^/]ZOI)7:?%NG^X&^>YU]_?_Y__OL`
M>#D9#GOPL78`````245.1*Y"8((```!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+VAI<'!I96=R:6XN<&YG````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#$P,38@,3`U,34T,S,W-3(@,#(U-#8W`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````/````#P@#````#`AE>````,!03%1%````____`0$`
M#PL"/2D``P(`^*0"[9X"U8\"T8P"SXL"S8H"R8<"MWH"MWL"MGH"KW8"=DX!
MB%H">E(")QH!^K`?43D*_K,@XZ`=D&82AE\17D(,'Q<'_;L\]LINB%@!QH("
MPGX"EF$".B8"%0X!>%PH_L16=%DG]+Q3(!<(`@$`%@H`(`P`&@D`#P4`"`(`
M*0D`!0$`*`,`.@(`_P``^@``]0``(```%P```0```@("____````````````
M````N0'1^````#QT4DY3________________________________________
M______________________________________\`NXCKIP````%B2T=$`(@%
M'4@````)<$A9<P```$@```!(`$;):SX```"?241!5`C798_K$L$P$(5WE'2I
MN*3NE$8HZD[JLGG_]Y*TC#'.K_WVG)D]"\:)R"/*)W"D!.=<*"J80HE.,B3'
M%,;H,\9\C.T"3&56*Y=Z@W':QOG"`,%7:8>`.++19K5>3H8,.8%GN1LETR3J
M6_:<?W['GX'U2>#I<=.9SNX[%`1&R>KVHK6^'@*IBOOUHTWO&\7]O%^SU?KT
M^^O_\]\+/GT=0,,<6&0`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+W1O;F=U96]U="YP
M;F<`````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`W-#,@,3`U,34T,S,W-3(@,#(U
M,S<P`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````/````#P@#````#`AE>````,!03%1%````
M____1Q`>(00.S@!2M0!(_0-F_`1F,>,Q,-\P,-HQ+<0N&&D9+L8O'H$?+*XK
M"2,)!QD')GPF2^I*!Q4'8.M@"14)B.J)'"8<+KHL+K<L/^@]*(@G(4@@=^]V
M"1('%!<-#PT)$0X)#PP).24<+185&QL;____````````````````````````
M````````````````````````````````````````````````````````````
M````````````-?/`H````"AT4DY3________________________________
M____________________`+ZJ+A@````!8DM'1`"(!1U(````"7!(67,```!(
M````2`!&R6L^````B$E$050(UV6/R1("(0Q$NUPC&E$091!PW,+__Z$"7JS)
M*2^I[G10:HEXD=:A4HI:ZYBDLYC`M8*1RF(&5D2D>/@.4%)@P%H+<$@%$ED!
MSCE`<12(9K(NY^PLL1;XSI?.?K*O^L/I?'_>CDU?_>DZKM:/3?/O]U^+Y6S;
M[[=\^_=\]\LWR?_WWP<CHA7F9Y1_'0````!)14Y$KD)@@@``````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V5M;W1I8V]N<R]C;&]W;BYP;F<`````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`Q-3$W(#$P-3$U-#,S-S4R(#`R-#0V,0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````#P```!4(`P```*Y%1(4```&`4$Q410```/___P``60$!R`$!
MOP$!N0$!KP$!DP$!A0("Y@("M@("H`("60,#6P<'I0T-X@8&6!,3UA45TA\?
MO!P<5A@<&,'"P1C-`!C"`AR6##>(+'&);KK"N<#'OWR!>X:.A"8I)<T``,T"
M`LT#`\X%!<X&!LX'!\X*"M`/#\\2$M`4%-$='=,Q,=,S,]0V-M5`0-=-3=A5
M5=EB8MIF9MML;-N9F=RHJ-VTM,JEI>'AX=34U,[.SLK*RLG)R<?'Q\7%Q<+"
MPL'!P;V]O;R\O+JZNK.SL["PL*>GIY^?GYJ:FHV-C8N+BX:&AG]_?WEY>6YN
M;FQL;&AH:&1D9%!04$Y.3B0D)"`@(!X>'AL;&Q(2$@P,#`D)"0@("`8&!@4%
M!0,#`____P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````+]7T`````!A=%).4_______________________________
M____________________________________________________________
M_____________________________________P"N@&\Q`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```/M)1$%4&--%D&=3`C$0AG?L>MB5
M0*AVQ=Y-U$@43S2<+7"NE?S_7^'FCM'G0^9])LG.[H)+F![.I`&2<W8P"#+_
M/C,0$.,]G^SK,3J5^,306'^0,$?.N;4CJ5K+.7#&F&UCC&U+B0,PEN.5L!%6
M>(XQ(,\7BB6E5*E8R'N'<G;^4DIY4<V6R1S7;]`50GS`][-U@$:=?YT=;.Z=
M=*^50<!02W%46UG>%5*%"'$#;L3V^L+BFI`_MS'=?S;%86UU:4M<O3?IO;F#
MUNG^QL[Q`_C_SNI'N*?Z+7C15-]A5'_U;<!3/4(_7R?2RJ.C3KH/M(;Z-Q;_
M]H4T'R;I%V2R178EYN\U`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]I;F1I9F9E<F5N="YP;F<`
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`P,S<P(#$P-3$U-#,S-S4R(#`R-38S,``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````#P````\(!````)'?7<$````"8DM'1```JHTC,@``
M``EP2%ES````2````$@`1LEK/@```)Q)1$%4*)&%4;$-PS`,"]"M+WCQ#WZD
MFX_P%&3JGL5KMA[@!SKU.Y94Y1@9"H.`08NB),L+EHZ`@`B=(W9*"1G%D,E[
MBHL/K'B>6'G_);BX,;BC&G;RS1,H)W.JS,L@I@I)<F`O.15L!C%5R/13+J25
MKH:WH9%7QHKD>)$_%SE.W;WW?>P"M]&[3UYQ^.2'>7WRZ;LG6YON_/^/?0$`
MDB(7U21+EP````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]E;6]T:6-O;G,O9&ES87!P;VEN=&5D+G!N9P``````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,3`Q,B`Q,#4Q-30S,S<U,B`P,C8P,3``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@````\````/"`,````,"&5X````8%!,5$4"`@*NA#+^Q%9N2@+.IEJ@;`CX
MI`+^LR!:4D(N(`+5CP)F5CJW>@(>$P+]JQ']NSS^_OZ>?D+&@@+MG@*(6@)Z
M4@(/"P(>'A[&CAYJ8E*N<@)J4B+VRFXZ)@+"?@(````_>]P9````('123E/_
M________________________________________`%Q<&^T````!8DM'1!\%
M#1"]````"7!(67,```!(````2`!&R6L^````B$E$050(UV6/BP[",`A%[Z8#
MAWW$M5NUVN[__W)]&!.5A(0#X7+!7@/8@%[53%XIY1,Z8\U2(Z\5"B[BB,C)
M4AK84Q8RS&Q(<BI*7IQA:RT;)QY`E'BWXSA:)HF%E9R>E_.KL6ISXFL(CR%@
MF]#WAW"S/*58]G_U_^XW?[/6>N[^WO[CQ__7?P?#6PYTUYW,F````(-T15AT
M8V]M;65N=`!4:&ES(&%N:6UA=&5D($=)1B!F:6QE('=A<R!C;VYS=')U8W1E
M9"!U<VEN9R!5;&5A9"!'248@06YI;6%T;W(L('9I<VET('5S(&%T(&AT='`Z
M+R]W=W<N=6QE860N8V]M('1O(&9I;F0@;W5T(&UO<F4N`5534U!#350]`#H8
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O=V]R<FEE9"YP;F<`````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#<T-"`Q,#4Q-30S,S<U,B`P,C4P,3,`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@````\````/"`,````,"&5X````P%!,5$4```#___\'#!(]=[<Z
M<:TY;ZHV::(L58,?/%T:,TXI3WH?/%P.&RE(@L)0B,4P4G<,%!U(<9Y%;)=&
M;IEHF,UDD\90=9YXH])>?Z2,L=F6M]P!`@,1(3(Y6GT)#A,*#Q0#!0;___\`
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````2
MOK#+````(G123E/___________________________________________\`
M#=##<0````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"/241!
M5`C798_;$H,@#$0S30'!A=ZB2+5:__\G2[`OG>Y+<F8GR89V%;``K2,E[ZRU
MSN-@!--WW/4F0!GA'.B2+E0K*GO#,XTRTLS&[P3'<=VF/&UK9`>"Y33D4DH>
M$EO04EER>98LE9?F2_.E^3I_>U/5H\WK_M-+1.[7ME_O<TPI13[N:SY6??/]
MY?_Y[P/I\`Z3(#-VC@````!)14Y$KD)@@@``````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O96UO=&EC;VYS+V%S;&5E<"YP;F<`````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`S-C<@,3`U,34T,S,W-3(@,#(T-C$R`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````/
M````#P@$````D=]=P0````)B2T=$``"JC2,R````"7!(67,```!(````2`!&
MR6L^````FTE$050HD6/XSP"#TO^E_RO\!Y$(,;B4\?_P_]E@&`YDPY1`)0/^
M%_ZOA,-"(!^B`"I9#!1L^=\)ABU`=C%4`5#:&*RS$ZAX)A@R`]D@$XQ!TM)`
MNT`Z)P&EEX(A`Y`-,B$<J!\HG0W6._,_V_]-8`@R!:0_&R2M`)=>^I_C/R^*
MM`*R;E9LN@G8C>ER+F27$_0W@5`C&.:X8PP``H@AN==B1;T`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N
M<R]E;G)A9V5D+G!N9P``````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,#,T(#$P
M-3$U-#,S-S4R(#`R-#<S-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````#P````\(`P````P(
M97@```#`4$Q410```/___Z<!`OT"`[4"`_@&"00*$QQ'A#!UV@XB/P\D0@@3
M(RYLQAQ">18T7R13F29)?`\5'D!+6QP@)A`I3#%[XR-7H`\E1`D6*!<W9"QI
MNBQGMPP<,BMBK@L9+#V&Z"=0B"=/ATJ-ZCQSOSQROBI&:V":ZR`Q2"]'9W:J
M[U1?;ALG-@L0%@X5'48``$4``#(``#```"P``"0``!<``/3T].;FYB`@(!\?
M'QL;&Q45%0H*"@@("`,#`P$!`?___VB%`UL```!`=%).4_______________
M____________________________________________________________
M_________P#">[%$`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK
M/@```*E)1$%4"-=53UD;P3`0''<1E*JC$8V@4??-NOK__Y6D?6&?=G:^.1:)
M'2*/*-U@D99""*DIP^1R9H>[9#&Y8([O^PZ#.2#1'+U0*156P'4"DDV,IU$4
MS<9H2`()(']>QYM3\0!!\$0-I2V`?6$W$I[A6U5@%;=Q[`\-3Y(YH3)Z%3K,
MZ(T_Z[[>^#P'S/J;_.!^0>YQO05IOCDLEG64._.LG^T_^>W_]]\7V]L@<_N$
M(ZL`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M
M;W1I8V]N<R]L;W9E+G!N9P``````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q
M,#,W(#$P-3$U-#,S-S4R(#`R-#,P,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````#P```!4(
M`P```*Y%1(4```#`4$Q410```/___S'C,3#:,2*4(R&0(B[&+R2;)2&-(2RN
M*S*Z,3&U,"9\)DOJ2F#K8(CJB1PF'"ZZ+"ZW+#7",RB()R%(('?O=OT``/H`
M`/8``/4``/0``/(``/$``.P``-T``-L``-<``-,``-(``,D``+T``+P``+L`
M`+8``+(``)\``)4``(X``(,``'H``'(``"\``!L;&____P``````````````
M`````````````````````````````````````%$$')0````S=%).4_______
M____________________________________________________________
M`'&>O8X````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````N4E$
M050HD67.VTX#,1`#4"L+0T-WPC9-EGNY%<JE97;\_Q_'0UJ!Z..1+=D@2;H/
M[B1)D/1:8HRE>K/W641$<N\DZ/U"NA!")XO>"=8L@*H"DBOA13H@I01T4AP>
M)6@:QS%ID.@8FB^:AZ/<BV"N*24]AQ0':S[#4E7G.,VU[<\``"=M__^_H_\D
MW6UGM$_;F_9R^6';VU<[^.'J_O'Y;CWM37N[N5Y]38<^:9O5T\1?\_M]XE_3
M2/('F?$E`AZ#D8``````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V5M;W1I8V]N<R]T:7)E9"YP;F<`````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,S8T(#$P-3$U-#,S-S4R(#`R-#0T-0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M#P````\(!````)'?7<$````"8DM'1```JHTC,@````EP2%ES````2````$@`
M1LEK/@```)A)1$%4*)&%D3$.A"`014TV;K%7H.$.7&0[#D%EK.QM;.T\`!>P
M\G9__\R"A,),?F(^O/F,#`.&*@<'#_FVO1L%1"15I*\E!7XQ8;DU<?TO*'#F
MYHI-M=+/I8`X:'+#CD.UT\L)0;!C+TE*EQ$9;W5R0F2>.&GV(#I5F5[R2;#O
M\-5A;Z9K[T^;!5ZMM_'GYKV-J9DS?WZQ'V'*(P[=4^K:`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O
M;G,O:&EP<&EE+G!N9P``````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#<V,2`Q
M,#4Q-30S,S<U,B`P,C0V,34`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@````\````/"`,````,
M"&5X````P%!,5$4```#___\!`0`/"P(]*0`#`@"?:P&;:`&79@'XI`+MG@+5
MCP+/BP*W>@)V3@&F<`*(6@)Z4@(G&@'ZL!]1.0K^LR#CH!V09A*&7Q%>0@P?
M%P?]NSSVRFZ(6`'&@@+"?@*680(Z)@(5#@'3CP[%A0W*B0YX7"C^Q%9T62?T
MO%,@%P@"`0`"`@+___\`````````````````````````````````````````
M``````````````````````````````",,^PM````+G123E/_____________
M______________________________________________\`@H]S50````%B
M2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"0241!5`C798_;%@$Q
M#$6SU*T3I47<RE09BDG___?T\F#A/&4G63DG$+.8!7.I()/72BGMN3(;AUG.
M<&8V+392R@;;U(`X.LV&@_5FW\_Q?(G`\%&_9&"%<O=Z/.^'K43%(!*O;#@&
M2XE%F9,-H7+:UP@=66OI!J@9HG<+N!)1!Q/GJ_^T7!]7_]]\?_F__GL#TS47
M.1.:C=<`````245.1*Y"8((```````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6]B:6QE````````````````
M````````````````````````````````````````````````````````,#`P
M-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W-3(@
M,#(R,#$U`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M
M;V)I;&4O9&ES<&QA>2YJ<&<`````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,C8Q-2`Q,#4Q-30S,S<U,B`P,C0R-#<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````_]C_X``02D9)1@`!`0$!+`$L``#_VP!#
M``8$!08%!`8&!08'!P8("A`*"@D)"A0.#PP0%Q08&!<4%A8:'24?&ALC'!86
M("P@(R8G*2HI&1\M,"TH,"4H*2C_VP!#`0<'!PH("A,*"A,H&A8:*"@H*"@H
M*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"C_
MP@`1"`!X`)8#`2(``A$!`Q$!_\0`&``!`0$!`0```````````````@$``P;_
MQ``7`0$!`0$````````````````!`@`%_]H`#`,!``(0`Q````'T>NXW4RR3
M9:IE50SI-C.AV&4$EP><9E.V,D6[.*YUSHEM9-6V,<R(H8'H!$LBAEAS*2K*
MRJ*HRRHFM0GH3`]`4!T,42C+SRTU;+0T54KIS=RD71=E4DHF!8BR6)049H[:
M7,/9/FKEL6IZ(6Y=.=9CM)I-$(PF:11VTU.G-(F%<NFNZ8*H5,<S)FG263"7
M2B*FV$OFMNE"H:Y.AT9'CL*2;6'&QL*.DBMIMI=AMVPEM9=LEVVVFVTFPP[#
M)L;;;/\`_\0`&!`!`0`#`````````````````6`P0%#_V@`(`0$``04"CSAF
M=@C3(?\`_\0`&A$``@,!`0```````````````3``$2`00/_:``@!`P$!/P&'
M5X*CVX"\PX'@I91__\0`&A$``P$!`0$```````````````$1($`0,/_:``@!
M`@$!/P$6WA$]@]PGR?)2YO'_`/_$`!00`0```````````````````(#_V@`(
M`0$`!C\"#O\`_\0`&Q`!`0$!`0$!`0```````````0`0$2`Q03#_V@`(`0$`
M`3\APN:;RYG)OV;F&ER,#>8XR3Y+[YY<]I),Q!&<C.;S.3,SC$1Z<\LS.,1$
M1<CSR9F9F<$1$1$:S/@S$1A$1&,S.,SA$81$,7<9F9F<(C"(B[G9F9F9F(^1
MA@8NZSC,S,1'@9W75F9F(A\]N^.ZSOV[%WUW>YV_<7"^?P-[=\?,_]H`#`,!
M``(``P```!##;WG94P#O\J%ANN(M6T#_`,)+=[UV)S4^H`>OFA%!BNC=RLL]
MN#!A&3E<$L7Q=:(@'QM0N\C_`(`0P0'`0/_$`!H1`0$!`0$!`0``````````
M``$`$1`A,5'_V@`(`0,!`3\07]E++;>PY]@1;,I9;8;8MLEELLL\!'D6S/DS
M,1PLZ),D(OL%DDR2)9!!!9;?3;4DEED$',DR>,LL@LCG_\0`&A$!`0$!`0$!
M`````````````0`1$"%!4?_:``@!`@$!/Q#/A""`LD)"3H((7BPLF"3A$$'#
M&9+(B.!"9GA$,6S,LML,,.VPS']2R\/'($0VRRRSPX,-LLLL\__$`!X0``,`
M`P$!`0$!```````````!$1`A,6%!42"A_]H`"`$!``$_$$J)4J0C7="5<-R"
M:I";F"H:F%#UY$'1-0X%H2@DZ0(ZN;)N&B$\(K<$H(00T8-P::."V;3TWT02
MDV]"5=%41A"(:I")]'6($'2_&*V1Z</,&OP@0B%1">83!!$L*&JDOS!%*,()
M1*JB<$J)3"$QL3!!$/10FH)AJ)\%0B%L59&3<'!H()D^O,-ACJ'1UD01$U1Z
M=P3!JB0>SZ]-6:L0Z3_1:>#8)AJ3^`@]#TT$'MC?</@U9A&0V#=&&P8XR/6'
M`Q]HPS&(%!?<(&&0B_3@8;!MP9!BC#7`Q12C$#=P;")1B+3B8)IB<GHTZ,Q1
M85%U1ANEP,QD,Y@S71_W`M"=G@HQ.9*RZ@W<*/8VX,SO1NG7A3X1@FT)PNJ4
M48J+Z-PHU*.%1N^!M-^#'PAQ"_'^B<$Z4J+J"=$X-.E&Z<4J0;JA=0^0OP4_
M_]D`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUO8FEL92]R:6=H="YJ<&<`````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S,#0P(#$P-3$U-#,S-S4R(#`R,S<Q
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````#_
MV/_@`!!*1DE&``$!`0$L`2P``/_;`$,`!@0%!@4$!@8%!@<'!@@*$`H*"0D*
M%`X/#!`7%!@8%Q06%AH=)1\:&R,<%A8@+"`C)B<I*BD9'RTP+2@P)2@I*/_;
M`$,!!P<'"@@*$PH*$R@:%AHH*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H
M*"@H*"@H*"@H*"@H*"@H*"@H*"@H*/_"`!$(`'@`.0,!(@`"$0$#$0'_Q``;
M``$!`0$!`0$!```````````%``8$!P,!`O_$`!D!`0$!`0$!````````````
M``,$``$%`O_:``P#`0`"$`,0```!T1*Y<CQ*Y%\7IW:4J:U6[C3%"HJ/TI0S
MTHO0&1&R2JW<<2N/%1_1B9GI0[UP-PEJMW'C,BQO]3$C?1BW;H;A+5;N0$9&
MD?ZEJ%WQ;]HA<UJMW'@NYV1T1VP[X_24N'N-*K=QV<T6=E9O.:?+72^K=''V
M']U6[B#J!.[-57-ZMTT:56[_`/_$`"80``$!!P0#``,```````````0S`0(#
M!2`R-``0$1(A)#$B04/_V@`(`0$``04"U^QDGE@V\BT/WC?8BTM;R)1%O&4C
MK2O$HBWC+D*RG$HB*#+E*2C$HB*#+E*2C$HB*#+E*2C#W;I^\58I24X=#Z@E
MY2DJP]VZ?O$T2K+,.B(W\A$2%I<SU*'[AO`D7("9ZM$2[CJ.U<?'W;IC.\0C
M7]0V\B[Q6\0P'>Q4?X[Y>&9U'W__Q``>$0`"`00#`0`````````````!$`0`
M$3$R`B`A0?_:``@!`P$!/P&8/+])F@04S1!3-4%,P@IF!TF?*+D^\[4<O__$
M`!P1``("`P$!``````````````$$$"`1,3("(O_:``@!`@$!/P%$_6*(]F#"
M71@PEN#"6Z([HALT3&/&:?_$`",0``$#!`("`P$```````````$``B`#$'%R
M@<$184%18E+_V@`(`0$`!C\"7*K#]]6IXB57&#9L2JVHL,Q*JZ"W,2GZ=VYB
MY/T[07,793].T%S%V54T00S%V56P$$,Q=E5SBS8NRJOMW5F1=E#V2;4\1<J8
M^FVIZQ#?Z/A%.PJ6L"5Y^&#S9ZIC\P__Q``D$``"``0'`0$!`0``````````
M`1$@(3$005%QD:&Q88'!X?_:``@!`0`!/R%JA"#H?EQ<H4.1A*I'FNK_``I.
MPXJ308^7ZO#>.\F=IK[,I4L;Y,SLG*462SO\DS.QC+6]_DC.PQE+6^2P[0J=
MHGN$7DR.QV!=?+W!+R)7<'D^EH6'T;D>#%J?$5(0/W?<KVM0C9TSF!4A`7*:
M#-&V5WD#J^R%A`T>2-!#%=U\F/EMD79H(C^)-FH$$SE_%_1X,5E:$=\DD__:
M``P#`0`"``,````0T_?\ZXW\N]7\Z-_\89_\9`?\-L?\>`=\_\0`'!$``@,!
M``,```````````````$0$3$A46&A_]H`"`$#`0$_$%)3X%D?9&(?A>Q&(;A"
MPQ"\B,0]J*K@LAJ2'#%D/2V0+(__Q``;$0`"`P$!`0`````````````!$``1
M,2%AH?_:``@!`@$!/Q"LI-GL.KXEI#V6D/<N:79HZM88=07#V'4(@;#"O__$
M`"<0`0`"``,)``,!`0````````$`$2$Q42!!87&!D:&QP1#1\.'Q_]H`"`$!
M``$_$"4:F6L>'T=+EKF][Q[N8H:W*`;JG938$<>D%(S6!OY/E"#4.&YBI?\`
MJ7[#+\U75*%HS/1&U:N.&YO94^#L)AQN*R,K/1%B,D=B^P]1,;<#P;!\0X.D
M#NCI_J*N?,7]&#8KT]Q]S%?*>LP0_D:-C`^8NR>9AY;T_&S?\T;'H?D5ZOT9
M=#<.[?A.ME7'])L/!U^2M.[Z,)4MKOG])CY\JYKXAE^<G1^0*_"\PIS/"WW,
M7/E9W(\PR_.(B%-*M.\4:4YC0'[8JYK]G0OD0R_-*O2*OH.S?[BL6W3O+>@1
M5>,NS!;O578<W2#0YCWJ6P\J312WW&-M8+"+DM[AV`5W`KV@O86K1+\#!49.
M'(&$Y<G@O[&9S?7L$UO0EX7:'%/HI6W3&6S</KD1R%)?&Q__V0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]M;V)I;&4O;&5F="YJ<&<`````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,S`S,"`Q,#4Q-30S,S<U,B`P,C,U,C0`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````_]C_X``0
M2D9)1@`!`0$!+`$L``#_VP!#``8$!08%!`8&!08'!P8("A`*"@D)"A0.#PP0
M%Q08&!<4%A8:'24?&ALC'!86("P@(R8G*2HI&1\M,"TH,"4H*2C_VP!#`0<'
M!PH("A,*"A,H&A8:*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H
M*"@H*"@H*"@H*"@H*"@H*"C_P@`1"`!X`#@#`2(``A$!`Q$!_\0`&P`!`0`#
M`0$!``````````````8"!`4#`0?_Q``8`0$!`0$!```````````````%`P`"
M`?_:``P#`0`"$`,0```!_5!MI0]I$4EECC[>;I`-FR#)?)C;&,I+#:T]SCWI
M`1BQ#1?&C;&-I+RWM'=X]Z;Z%8L`R7/R5),TEANZ>YSNL^!&+`,F2DS3RU)9
M;>KZ<[N/H1BO#)DO(V$726YC[>/.H'P&Q8AHR;AKR!I+N:/8X.U*`6+(-&3L
M$=SLH\ZYI0&Q_\0`(Q````8"`04!`0```````````P0%$#,T`B$!$1(B,40`
M(/_:``@!`0`!!0)C4'LP?V>XWDYZ#&T:VHA2.H0@6Q;X,CJ,)6WE=`D=2A)V
M_L!D=3A(V_K!D=3RT1M_6!*ZC*1M_6#*ZC.1N9W0974;!*X/H^!,ZC8*Z.G-
M'P)G4IPM'5+CH:!F=3E]'57CQ"D=5]BZ-G\>\B'EU_A9XZES>C.'D`%QV_@<
MNX/_Q``=$0`!!`,!`0`````````````!``(0,0,1,C,A_]H`"`$#`0$_`4]-
M^O`E]K%Z"76L?H)-K'V)-IG8EUIG8EUJG;EUHTL)VP;7_\0`'1$``00#`0$`
M`````````````0`"`Q`A,3(1,__:``@!`@$!/P%,3SXTFVZ4W!MNE+P;&E)P
M;&E)\S;=*3DVU'(-MJ9H#\+_Q``C$``"`00!!`,!`````````````0(#$"!Q
M<A%188$2,4&"_]H`"`$!``8_`K3$07:`L&(GH6'L16Q6[5]XK=J^\5:ORQ^/
MXK5^0L)KPK5]BPEQ5J^Q8/C:MZ(X?P(EYB1PCQ%LI2[IHCA3T+91GVD1WA1?
MEBV2Z??3J1E[P@U^30A:)0?W%]"+/__$`"40``(``P@#`0$````````````!
M$2%Q$"`Q88&AL?!!4<'1\?_:``@!`0`!/R&QX4H&!S'])TX%A/=QH9S1/5&I
M%1]`[7E$U0GRH<'$[G4R)EJ3]F")$H[G:R)]9UT1A48K=[\)M9U40\NHK6N1
M(BW8KNR1R+C92-S9PAWX(Y/%SK,QMQ)3/8;=X%;M8T-1*?:8;ID*WLJ-JA:9
M^F_^7%AG/R.)"3^82U[F/]LA,B7/&GJF/"YI,@;68@W`AZ3)"PN'M$,1ZC(G
M&9(VI,.\\_P4L@S_V@`,`P$``@`#````$/+3//-=,O`>O/&,0_*!,O+/,O).
MO_(H?__$`!X1``("`@(#```````````````!$!$@(3%A07&1_]H`"`$#`0$_
M$![="D)M*E"8$XU9V.-PWW+C4:^_`Y7=E0@NCP%Q@3W!_\0`'A$!``$$`@,`
M`````````````0`0$2$Q8:$@47'_V@`(`0(!`3\0FEY;SU$%NUNGX!O\X%,8
MS?B%,XT>&#4Z:35-+0`H[:B,B/_$`"80`0`"`0,#!`,!`0````````$`$2$0
M,4%188%QD;'!H='A(/#_V@`(`0$``3\0TRIW_(U&Y3H0FN[?Z1R>5,],'37%
MG9?FXTU^$RK8[R+]PW3P/LF&M(]GQ<J5R$.^=,\#]QV.\$O6I`?I85OH3VT(
M!M[:JB>88%<0Y1VQT,#%:D-S>PMB#D@:KL(-28S7,M$/ACOHS<>""F7GZ7#&
MJG95_P![Q>5U%"YR@8@WK>CA:&+Q8S_4/U&3*@<7K8,-T]E/N49UB^]!E>B?
M4PP[J>\;:U.[K;VCU%65+EN.R'Y)AW(#6MA.%H@VF"SWM'PS8=L?Q7^`G\!9
MBJJXJL*2<87V2YO2>[4YK4;.<G;.$2JZAR"X=UH/B4*=J/AN9OTRZX4"NRBY
M2R&#.4O!8]Q*J94--[7]$E&97RC>?__9````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O;6]B:6QE+W1O<"YJ<&<`````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,3`Q-C4@,3`U,34T,S,W-3(@,#(S-#`S`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````/_8_^``$$I&248`
M`0$!`2P!+```_]L`0P`&!`4&!00&!@4&!P<&"`H0"@H)"0H4#@\,$!<4&!@7
M%!86&ATE'QH;(QP6%B`L(",F)RDJ*1D?+3`M*#`E*"DH_]L`0P$'!P<*"`H3
M"@H3*!H6&B@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H
M*"@H*"@H*"@H*"@H_\(`$0@`=0$'`P$B``(1`0,1`?_$`!L``0`"`P$!````
M```````````$!0(#!@$'_\0`&0$!`0$!`0$```````````````(!`P0%_]H`
M#`,!``(0`Q````'ZH```````QTDA$V&]YZ```````````&%#N7U9SU?N6VFG
MT5-IHB;]PSULD;JO%O0])\[]FOJCYKU\U=C-```````0==-4Z8.B%<829VNI
MV>4&O-O(^F7E1\Y,,F;^;A,Z^MT6VS5;+.H;<]Q\WRB_IR%-BP````$'?`V8
MW,6='TC.9XJ--+J^CQTC6>EEY8X8&>&LQHSUZYFD[SG63=O/W]<Z^9LKR1]"
MX;9'3OF.46```-!"V:.?N**QPRZ<LH^^,5/<_+>ICKU'E*+GRG]+;"KP+/77
M8%E$C\T>]917E<\O<,MS3@LIN_O?G?T3GT#-``5%OS>S*XKJ.4Z\YK'3LR?-
M&D@\]VL'-I+>IKIOJ_.:D%Y[1XE]!II1A,F6FSYM\RJ<_<?69>XLJ#]'^>=?
M'3H1%@`.+[#A+C?6R=%\T.=,Y=*"+U^7E]/.RKC.=IH_1-<A&[ECAMO:F\O+
MO/"D\N\2H\MQ3Y6NCKQA8Y1_;Y=UM!\CI]"'/H`!&X8Z<\=1L66T^']AZ3>6
M1L^C=]]-SP#PPQ,8C-Q&;%K3Z_RYT$[\OIPY]0/_Q``K$``!!`$#`0@!!0``
M```````!``(#!!(%$1,@$!0A(B,P,T`5)#$R-%#_V@`(`0$``04"_P`\D!&6
M,+O$*$C#]HD`37H8D[4Y)">_R)T"+*86%%<-<IL$X7>-0KJ'6@H;D,WU"0T6
M+[6(BS93Y*=<F_9D7#/*A1:A4B"[K$C3B*-$("Y`C<R38(9E'?M5'5-0AL#Z
M$T[8P]\MI\LU>DI'6+CHJS&(`!%P"=.QJ-R(+OL:%N(H2M*!W1`<I:;7(6)H
M1W<.;0U-T:BE;*SW;$^*;&9C=O[J"L&]DCPP37O%E34+*9H+BAH5<(Z+73]"
MB4FD6(UG;K&O=#TUP<B`X/@?7D;QWFU;$E62K8;89[<\F*9%D=2N&=\$(C:I
MI1$VO!-J4E6C!5;TE$!RNZ:UZAF>Q\3Q(U6(#DQPNPUY75I8)6S1^S([!K&9
M+6+7$RM$(VHG%I:;EZ)K8H]UNLEDMUNB5NB5JU</CHR[]FZF!@EF:V:+3K/#
M*/$>P_U)K$H@AB#I9NRP[%FC/#+N:Y%R+-9+)9(O62R4\@$-'XNS]Q2/%-8;
M@_2Y^2+KE=A'66MS;O:,6]EAG)`\N:^M=$S.1<A7(N5<JY%FLUFK=AUJ2LT9
M=MD'";::'39N*QUW7*`^!=S7>BY7.0:<H[NQ;*'C-9K);K=2W(HDY\]L01`-
MB8(V]%+X'>2:J_D@ZKCO5+^.E5&T2DD#%&_,<[,6/R%BHR92Q3,7'#NT3K>Z
M%E>*_6%&,.44;`F5W/+6A@Z:_EN6QL_1WY0=5EV[]0=CIS?!BL;;,Y708'&N
M'8[%;%.KM>G:<UR_%K\84W3$VD&H1%JQ>N-RP<L3T?QGO!:&_P`W2\[,F/FU
M0^FFM+BV(+$?0(!3H@41L9SZ5X;C1G;6>FQ\+_EU+^PHV[,^G8'A-XPS^,.F
MG:SV_P#_Q``D$0`"``0&`P$!`````````````0(0$3$#$A0@(5$$,$$R0/_:
M``@!`P$!/P'^5NAF,QF,QF%$5]+B^(;+BA,IE,I83[$Z;VQ\22VM#5!,3INK
M]DA,J5*E9127*(779$^!VFG2=).+J<-R&^R.PS#P8H[6%X;^LT:[-(NS2+LT
MJ[-*NS1P]C\-=D?B-*L/(E1\BOLQ!W1A\0^KR?VS[/\`_\0`)!$``@$!"0$`
M`P````````````$1`@,$$!0@(3%!43`2,D#_V@`(`0(!`3\!_E2D_$@@@@=)
M'Q5/;$C@;)))P@=.M(2G!O4AH:G5&\?%8,:T4K<7.+6,X)8LJT4<B+6WHL^>
M1WY=(SS\,X_#./PSC\,X_#.U>"OK[11?$W%6Q,J4/C10+LM-ZOE=/T6C_\0`
M.1```0(#!`@$`P8'`````````0`"`Q$A$C%!4000("(R87&1$R,P4D"!H10S
M4V*QX31"0U!RDM'_V@`(`0$`!C\"_M]2JO;W7WC>ZH]O?XJM%?-2@0R>@6\1
M#'YBO.TQHZ+>TIY7\1$[K<TPCJO(TICOG);[2X=U*,R16X\=#\)-U`MU6G'P
MV>YRQCQ%*"P0V\E.)%<MXS5RN5RW'$=%Y<4D<U+3=&#OS-O4]"C2=['*Q'!E
MS5]EWP.94F=\E^-'4XCB&Y!5"H%4A55X[K#NKQW5"J&:J%-ALE>'I;?&A?4+
MQM"?:;EB%8BU"M,,QZTFWYHEQDP7E>!H0DW%RFZI5%52ABT50>&WG1>=I'^H
M57Q3\U*<3NMR+$'6JG!C!WT7GL,L_P!U+'(JBDX+Q=%,CEFB6BQ''$S5-M^(
M]2RWB*F[A"^SZ/1@O(UDDJFY!&*\MN]BXW[<B)A%T#==E@58B4>,2IXXZA%@
MFS$;<472LQF\34$'-]*:M.O*$""=]U_)<]1*;`:=T<1_5-9#$FBX>EXK1OM^
MH33GNG6-(@WCB&838L/A=52=PXJGHRP"<\W`)T:+>3K;_D/U42U>1+7?Z#R<
ME/-XE]=AVCNX'[S>JFK)O'H$KJF0&]2I:W-7C,HX'>Y%<\1Z0@0*C$IK658S
M',XG8#V<;#:";$;<X30G=<?0:WYHG)18F`,AL^+"%<1FIP"6O]F*E&!!S4VD
M'IM5=:.07X4'$E6((-DWNQ=^RELQ(1_INIT.IAY;9Y)[^2&9U"A)-P"N(E@4
MXB9LF5%.1'53%'9KS&B*WG?W5"^$>87EZ0Q_S7`T_)?<M[+><QG8+SM*+N3:
MKR8,S[G_`/$#%,\N2IM2PB,_1`HC([9.94O=1#4VTUQ$[VWA/`)G/=+KY*('
ML(;:'`G4=*>[:R5Q5Q56?17'LJ3[+^97'LN$JC"N$JXJXJX[$!WYI=]3AF-H
M]-6CLYZJ*M5</@*A;M%(J?M(**;SVG]$%`'+4/A`4_HFG-H3.NQ__\0`*1`!
M``(!`P,#!0$!`0$``````0`1(3%!46%Q@1"1L2`PH<'1\$!0X?_:``@!`0`!
M/R'_`,_1`[LT9^$$_FFKSL((Z(_]-Z8.L`;OZ1PY[D8VRZ/XB9>B%9JF=$/W
M%=`\)>S71<R_"F:&</W,(]';R8A9D/0?^1P@&[#4S=EU>Q+#JMKV(\&MK>E]
MH1>VE/Y%5I>PU\36V.N9@'T/B4+EGJ29P)LK)6J?!4./7S3"5`X600439</G
M_A="]'CO,MT-=D,4?*#+8EHU$%,C`,1-!G3>:D?./F8#W3.K7_>(Q1X##K0[
MG[@BP'1N'43XC]X=$:@O8]IBZ,>5&_-(D"CBG4[0L-/O55^KA-6-DWB-J6"-
M9NFY5RL`"A1%BS&MN#NPLHF`+#P&69X7W?Q,RI4O<_:RDO.P_4881V_R,&U[
M(MZULVYM*;C](N)]@^'>'J]-1U)4`DNE/79T)&$\_DZD&Y0ND=&`<0\'W&R.
MIP3+%9%8\576\Z0<`7"V%0*U=^QUB1:O.WL<L)4O4%%QZ*12XP0Y$FHF(-_G
MSQ+W+:/@>G64D(,!V8.S+`F6'Q*8<#K<G2/`X'W(@6';A^T;K78Y8NX2/0P9
M&R"U,M6$QI=&#EVC:;&C@U?[I!R%H":]8F(N/&9QIK!VC9]!'C%M04*_)0P^
MUGB.L*;0)-L?,1(;"CP\1K)M@?N(!5CD?LJLNU_95484!1VSL;$>"'$9%T5L
M`>%9?>%]X@W]!+*S?F)Y@;1ZX]<TD1S3V^R%I>"7,(.C+':ENVXB@<<S-]Z?
M;['.58[S`5UP_L=IE?&2@'F7+95&J8[P1I`#_%.L*HT2#<U]*YOZ'JCG=QOJ
MRRZQK:OF7!HXIA,"C_`,4=HL/11&`O4FT!B-=4GP?8IH[H5BL([S?@!&;>ET
M0Z$TIS!X8I&&5.';DCD98II*PWJN68)5EUU8.6J]#EA2!W5B"@#54>7]2@!@
M<H.#C\F"*%])J^NI7.)U$OY!^Y[EFZ*T>Y]=O#A+*=&Q6/(LN`A0T#*P%;:I
M"D9<D`NEV].9V!J-,Q9O`F-`;X>Q^XI;O\/<_D"8C82OYS#XU_B;0/..T_5H
M]X[F=[?CB(Z9NW^'[8N>FAT[`P2B#S+5A!]"*W<#RK^%E`2U^3W^O.6I*'D/
M<PT.GI=1#=:.N(;`""UW/S`P`4LK@-,9(:RVZ!OW9UN%^/8F.ECM-8[YM-./
MRBC0>RG*+PP!MEKF^N2`4;Q'_P";-W\4`_E*-2\>@PBG`E]@DK%X9_BF/JL/
M"98#EG>%T[$T#I*`//$'J5[2O3VI7&(2I7H$J54K'IM*E7Z$TP>Y,ID_$1@I
M(PCJ#X1EQYR2D]1]2KO([[\[(/\`4=8%3?U-)QZ;0^MF\8S:;0.==3!]?Q'?
M:_"F(\?GZ/_:``P#`0`"``,````0\\\\\\\T\T\\\\\\\\\\\TRHDT0`X\\\
M\\\\\0P<P000LL<T\\\\\L,\(LP-I(4(LT\\\\L4L0P$0D,@4X`\\\VX$(<\
M\X\$XD0<\\\T(`L(0P@($,($<\\\`B_\!``@`=B\@`\\_\0`&Q$``@$%````
M`````````````1$`$"$P4&#_V@`(`0,!`3\0Y(`````````"&H```5`$`P)@
M(`(L8A4A5__$`!L1``$$`P````````````````$`$2%`(#!@_]H`"`$"`0$_
M$+@`'@```````#W0`H)B6S&!`@AF343O8?_$`",0``$"!04``P``````````
M``$`$1`@(4!0,#%!46%QD:'_V@`(`0$``3\0R-$(D0I=A2``]!26.(1@0($`
M@````D$0*`!B`=$!0H*B!QH"E0"`@4)`0`%`0!!!`4`!%`("@V*``+&``,"(
MWFQ(*`!"0!`0"D*`A`!`!0```*$4```H``%`.0`/PB%@H:((@`1`1(`````$
M0```)`"$`(@*(```0``(`0`"``0`(2`4$0```$J&H`,]A;"`@`A`*`"```@`
M`4)``!0``$2%(0``````("B%!]H=S8TPA`-YD*",```A`%,0`$T@````!`#`
M!```"B0!2&`]&$D`Y$)@"0```0A"```````4@`0```S(`(6$$_0+````0`@`
M&!0(@"`@``````40`6,``")@,B```*K%=$`0```````"$````*$``````$!0
M``(0@`````1`(5%F`'NY`,"`````````$@``0`!1""0`!`"B``0"`2`(``$`
M`44`!0``!@"`XK`P$$,$`*``!(``))```2```2(A2"D```$"400(,4*(``H!
M`;APZA"`F`"`(`0```0!0``(```A4"%A!@BAOS*`@!1\D0@,F0$R:#)H`F0)
M`SHH^E"X;%`^[B*&.X2#_]D`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]M;V)I;&4O8F]T=&]M+FIP9P``````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`S-C(V-"`Q,#4Q-30S,S<U,B`P,C0Q,34`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````_]C_X``02D9)1@`!`0$!+`$L``#_
MVP!#``8$!08%!`8&!08'!P8("A`*"@D)"A0.#PP0%Q08&!<4%A8:'24?&ALC
M'!86("P@(R8G*2HI&1\M,"TH,"4H*2C_VP!#`0<'!PH("A,*"A,H&A8:*"@H
M*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H
M*"C_P@`1"`$Y`0<#`2(``A$!`Q$!_\0`&P```@(#`0````````````````4$
M!@$"`P?_Q``9`0$!`0$!`0```````````````0(#!`7_V@`,`P$``A`#$```
M`?5`"+Y9ZYY5K%FKKHWE6YK&_E[67*/KY/4XV3F:XRF*=91Y1T)"G>J;(YU4
M9E:X5:0WT3QNW/>S*'OT/'6F"AS)>@,=0```\R]-\\N>=F\_]#WFIP;O5KE?
MCIK<:8Z8$'7.9OACIPR.N^*B]^4@;[<^^L8SG-A)WN6>F%K6OS==L]1NDEM`
MQT```"CWBE7/GWI7F[W>+T<8#49#885RMPPBL<,285G3/?BUC&A&Y&Z,]<XZ
M+ARBY3?IQ2K!G>:[.KVL0_0/.?3\Z?`9V```%)NU0N:*K=+=XL2J7Z7-4SG'
MK]66=`L")%VO18G/OT3CP8;ICKIJU9UG2&:=E<-)JZ_=YJLUZ1'N-?6O)O8L
MZF`9V```%5M5;3SAJK<]>50]1K5;FO7X5:F3*2#;-ZJ;56X;C])'0C[]]S3I
MTWEI,^98&J[?T4/'6V4WA5=>;NPG0=%_M/CGL^-9`F@```KECKZ>:N$SKKS:
MJ&VDU3W+).Q,(TU:[=:JQE=9F[-0NTSL1U#WS1&+&/K<[0]).>BBQ=#6.:YB
MO./L7C?LF-`$T```"!^@3S)VD>=>;/7*F:98(\=HD!I7*M7#*++96EY>(53Z
MPNZO^BP)6ZRF>L;,DG"%W;E<R7)$]F\8]GQH`F@```0/T">8OD-@Z<YU?L"I
MKK://6<6ZE:.#A*K,^M^EDE2U&+<^8B[H&5G&UHU$6&'TYR8B0GNKJN8KDB>
MS>->RXT`30```(7R)/+[#7K#TYS<9T:CKI6Z0X]ARJM79=1%.B]$TE\>,0;%
MI(MK,QSL*=&4,88X]@6L5Z1/9/'?8L:`)H```$CM*GEEBKEEZ<Y:EK6VKA-I
M=CA3P<PE["J=9VQ%81Q.BP886L*TTTM$JK<A":=%E62%[%<D;V+Q[V'&@":`
M``!*Z3IY19:S9NG.9&EC50G6!.F\Q9R(DUNF6UQZJ[S)4A3H+6">TZJ*9#ZH
MT4#$6M\BZKF*Y./K_D7KN-`$T```"IJL3R&RUJQ].;*))5-3.#2S2TN5*K*/
M--^51X+J*+^TGN;FG0UY\YD02P0%1,8>+)2YDM3'K?D_K&-`$T```"YC"3QJ
MQ5RP=.;>L6;+2KHMXI9>4?EE%8K-M5PW1=(L2'7<2M43BMY=6?9-H"I9J9?\
MI"ZK&2M)'JOF'I^-`$T```$>1H>(.D[+IRL._/5KOSC])5N^[.S*EL%0FV&.
MBN(]DE??&560G_`B3^D.3IB',MYJ6J='?H]"ON-`$T````!XSF<GZ<[>J8\5
MP]J%IR=T">PKGUJ[6NVSF3FUSC:N`JS7&NIBQ((\MH6R%LB%Y7[!IP2MT;-\
MMZ!_SZ`"@````>=TOU#RC>+HQ06"EZ6W;2UF%:LLJ(%KB6[=JQUDLVM=Y1#L
M\5GJU!PRB(H+)JNG/KP2(B:\(]7EACH``````$?PKWSS.YK=NH%@WFW9CR)K
M&,Z@:E@8P;8(I(RJA%B-<FNN_(UB]%Z+[52O9,U@!G8``````$*:'@AZIY-K
MG8GE0:U8\*.E,M8>Q*(H2U<K=9/3GQED<(>+F1QVY)Q1]YDKV_8VQT``````
M````Q6;.)X8Q]:J=RHEQ^MG4S@#.#)K@VZ<,$K2/P,(;58BD^F=LYV`*````
M```````!C(&,@````!C(``8R`````````?_$`#$0``$$`0($!`4%``,!````
M``,``0($!1$2$!,4("$B,30&%3`R0B,D,T%#)35`8/_:``@!`0`!!0+A8&Q`
MY'P+4?=6MQY=P!.6[/X?^&4FBQR;GC#E5[K^7!CW&[LHWFQ;[JV0!S0L^Z,9
M2@FM39=6NK76+K%UK+K5UJZU=:NM76+K%UBZQ=6Z>P1T[O)Z`>:8ZNNL*W[C
MNRS>.%GK%U=!R9]L[,^HY\^IK6"F>O=>90W9D:O8(1#O2<4[4N='73L$*19C
M'$(K#JV^LL(WZ_=EH_J8HFPS)VU:U5>N_9:KD.[578U:N4*E1>4.E?<`!1L2
MA*0;("$08;!<0`D:5<$00FZ/)3\QL$VK=V4;]U%^78JEWBX6**_+1^W:ZVK3
MMT=4Z4C(0XBC)T>?A8GX0?S8!M*?=F?+:NQVDQ5A1DIV]2$I6RKY'YIXTXUR
M;#+DD=&)$$XB)*,NDBI=*R8+.Y#\I0GO;0Z:MD"*6+MLPJEVNAY2Q636(%&6
M>JM37]8:.E#N^(&\UGSAKSV2<YCRL5+>(L5\G&W&9R,F/-U&;NKMKI`5P=.Q
M9R)(6UB3\Z:.BB[%'1LEIFF><46Y-=222B62O9#;$-:YC1RGY#2UE^6,;2CW
M?$/\8';=R''<P)FZTD&=LCA=9#NEKRK$KG0P,O"WF32<D]JVK:MJVJX+G5*4
M^KHF#HY"0#$759!\;B@T8W=.7!]H1QU4?OJ-MJ]V?;]OX:F@]BFVX;X[(1L!
MW:JR`5B-C"#>;PRM)L4S\AQ.T69:+1:(8V=2AM52T:JN3D3JK1H"G7F*4"E:
M#9&SJJS.>P50^\?A#NSOM?RK2VO?!O:$I`+7NOME8<KQ&.$BRU'B'U#MEJT5
MM6B:*T=D\7:&%E^J83&74CBT90`2S:T9GG;)&+#$55FUL=^<]K^0$RLU(S=N
M97F%X'3S(-^;JJ\NFR&U;%M3148J,%EC,"OCGY%5[:A`A&L6A5D.L6T\(1'&
M2*J/N^_-^T_*OQG!IL6D^H[9!,T`G5ZK+;B[C$CM6C,I-&+QBC$B"%@CW[0Z
MQ"J9JE53>Y=0*@@<9(JI^[[\U[/\J_'5N#^*)6"11A9$GKF@:GDG@AG@2`Y#
MB]K)P"K5DUQ8^K:"*55R(8Q"9WU6K<7155]SWYKV?Y@X2<EFS\G"B8@HU(]B
MK(18%BM710#(GHQ9WISDAT@P46VKQ=>B):;?&A>.I89F8XK-!#DQ(/Z%5;W/
M?F?9_G63JL3I[\BC;)<[1B..<+E.565<T3B?P4K<=T8WIJ4,A!/<D-#+`L4T
M9W24.C#"Q;GS>=(D[Y&Z>A%XTW155]SWYGV?YUO1U=K<]@$;F%F\TTR[:\M!
M8I_W!?W%PS1JU@6G>K*\/=(PB/D!M2L6)NU;''&''53O*_NU4Y1#!FE>FG15
M4]UWYCV7YUO3A8`,[,*T!=9L1;)[+4ZW2CO;@6B[[2U)R-A-HHS:5Z;W#/".
MUAEJ*%JO%N=8FHT]9\'1O2G[OOR_LO\`2OZ*4FBTK@64+(IJ,G3N[\';5GH-
M&3-D(K=D'4JU@Z`$8(<-74B1BGN!9#+`C<#>E'WG?E_9?Z5_M0(QN7N>$=@]
M&H=CXXU=5[3$E]`DVA&(+!V'6I#:<ZNW)U(@58G-"C*A[WOR_LO]*WVJ4GJ7
MW!$LIV7@H7'>5^M&T&@?G",6(H#%;LM'$2FTL.[(M6Z!5K;%=WT8$H1@Q>:&
M<8*0HK+'V@K"Y($98_WW?EO8_P"E?[58#"P.7-IRUYPQQTBQ-@\5K(KO&>5O
MSYX*%WF5IWG8@[.YLWI$MK65.!>;5J;QP\RL7HP>K5DQ.!O3&^_[\I['_2M]
MO#^B8\,I<F]!3IVK"$*`1Y"O.4AD#9B,4FBU62G(=9HQGD3J5(@R?\BGID*@
M`%7CP=&],7[_`+\G[%_Y*_VHQHC6V[)IF,%".,O'^S5PF7R\;+H&=#H5H._&
M4FBS3E-Y1M10[3<Q.C>F*_[#OR/LG_DJ_:L>1OF!HC-=WLZNXT)DQBU2MXIX
M>9_!2.)EU(4TVDI1W<)3=YM4Y,WMZ*=J;QS,6)5I3<E5T?TP_CD.^_[.?\M;
MT5Z+U[-4\=\"/-@SW/(+'J8DKRA8*\7>C&#U`5"`G2K2:QBA*!R5[!I[!!@\
M*N-.Q`SE%.T5?,]DD(,.#H_IA/'(]]SQJE_DJ>BT:3&HD"XK4%#S*Q8:O##B
MDT>;R<UD#.8E:4XT'-+=7/+9G)[GL#<E6J?J`,SPB:X`+<RU>56L.J-.C^F`
M;7(=Y_$!OY*B;B08RM+%U7<>.JPDKM1K,6*6NH7*KI[E1E+(1DJM*;E5BD"Q
M)L4!"I5@I^,E8]/AQOW7>[>%KP+4=1]"D8<8#LE73V].I<4HNTFX?U((Y)JX
M&3>'%T\]9-5LR1`V(JO88O"2.OAJ/F^AE([+=1U#TNRVGOD/-\.\^GL1$6-H
M),;,1(E@IV(,[2-)/(\4UN#.SL[+=S'K6*@YEAN(,7+E<\N54E87PY'2M]#/
MQVW:SH3^%ZN]@%*T[(=AM#V/U9%YP,+)T1Y'M%$.J*J1^;:L0#$L!'&;7&V[
MA-E4VK8<//Z^1%:LQ#"C"5BPZFK'KA8[<?\`0^)A_J`?QKOX,K=.%E.]BJ\+
MM236KX],95>L$Y7IY4EACBKDB*,SM.+G>3Y8O4V#"8@*]EZLNLILT\EO<5"9
M)_TZ*ZGXDJPY=?Z'Q`+?1B^DJ<U'TX3"$B&,8N%D`[`XU;M5=;8@OF!74_F=
MIJ5$=3A.$9LU2LR;RMPDC26-'S\A]$PV**Q!Q'K$T<$]6[]5KPU9EJS]KJ;J
MQ-?#(/I_$U3:6#JJ;1#GJWT"2=UL=U&P/JFUTX.ZDZ+).SE+2`U:M]*R"%@%
MNO.K8&Z`;1#+JMRU6O9JK]4EFO4KN,#40L<DO'52DG=3EHCD7P]1^KF<>UT.
MCPF)U#<FE)ES%S%N6Y;EN42[4UIU.P\EO7BZ:#J?E1RK$4'NFC%HM]3197%0
MN,41:I`V&90M#=,6LZTJNN57=<@"Z<*Z<*Z<*Y`&7+K,M:L5*R"*+=@C'W+'
M8DEF0Q0%#ZY@C-$^`#)YX`S(6!GM^0+Y#)?(9+Y#-?(2+Y"1?(2KY"5?(3+Y
M%90\`JN+K5EI_P#%_P#_Q``E$0`"`0,$`00#`````````````0(0$2`#$A0Q
M,`0A(E$30$+_V@`(`0,!`3\!)':-'U+T_@Q>J@SD0/SZ9R('(@<B!R=/[.1I
MD_61M\1-OW8N\)"&KU]BR'8LJQ5QD>\)="HT;2S-IM+,VB5&1P?0A46+%6.#
MZ%34U-I!R_K&*BW\B<8)?1>D<'T*DHI^[HG5LN2E*58X/H7DC@^A4O6V%Z,C
M@^A>-D<'T*BK:JJR.#%2U=QNQ9'!B\D<52Y?*]8XK&Q;)=9WSO58L5+4N7Q6
M37C2S:+E\+TN+PN)M+%BQM-IM_7_`/_$`",1``$#`P,%`0````````````$`
M$2`#$#`"%#$$(2)`41/_V@`(`0(!`3\!6FU?I?T\@CTE0+;5%MZBV]1;?6MM
M4^+:U/BVM14^CU$^2`&GL$8:;"'>W>Y+6/$-/-P4]GLZ>!@.;'"]C`<W`D4+
MF`YQ-<P'.)[F`D\S`93`93`93`7?$?1/HF(LUW3R,1Q%I&0.,S!PDX73ITZ=
M.G3^O__$`$`0``$#`0,(!P8$!@$%``````$``@,1$B$Q!!`@(C)!46$3(S`S
M4G%R)$)B@9&A%#2"H@5`4Y+!\-%$8&.QLO_:``@!`0`&/P+,YKA49FJNZ055
M^!51A_)5<J_1,9O`OS!Q]T=C5NTV\*JU317T*V?NMC[K8^ZV/NMC[K8^ZV/N
MMC[K8^Z[O[K8^ZV/NMC[K8^ZV1]5N"JXU5IVPS.WTG3?R<B,QD;W;MKD=)T;
M2QE,+6].CNH&50JZ+'#>G-DH!N4QH-5M0JET5*5H,5(30.%X5AMAMV+T*XZ(
M:T7E!C=WWS!2<F`:<PYJF:A5IE\7_P`Z-.JL[CO"+[5UBP@.IIQWIHJ*VOLI
MZ6:/%`K)Z*E*5WJ,-+;8%"K-F.EU';TUM:T&A1HO5!>=[M"=W/3D'$#,,Y?D
M]`3BW<46X/&+3VP<31G'BK+!0:#G(GB[38>2JK)S=%D[>DEX<%UN4-;R:K73
MZW%:DX=YJ]C7>17=%!DM6N.Y6G$9/'Q=B?DM8SR^9HKXIF?K5<GGO\,B]H8Y
MA"JR&=P]"U<DE^86K'T86L_]RZF9S>1*I_$(M7QMP5J-U1G`3.9TXCR0=FCR
M:`T>_?X1Q73P2=(P[1_Y5Q+9?"L5CFMXN-S0OQ.5=9E;[P#[BJ\DE`O%0C:O
M.;HI[VE#))G5C/=/S8K%7HP1#I)77472RCJCM`'95<\/EIPGFC&_9=<A')<!
MCY)SY,940;PNDR.YWA71Y6PW;Z*K7C,XN[K)]W%%QTCXVWA,?[^#E>JR.`"L
M9(PMCWR%6MN;>\HVE)%_3=J^DJV?EFB'PC3C]2P3K/?-%!Y('`A"IUQB,U)F
M!RKDL]EW`KQ,'S4[G;3G7JINY:-]RO4L,43I+1J`%62QDS/B5K*)73R<\$.A
M+;(W#=G>:]736_X7+,WRTV>K-4+I(QYC@JM-/)7JR#9&\JT,4X<0I&\PL:C1
MN%4YSS>LI<-[DVVX@!4$=6C>B^,[6Y:Q5(]G>Y"-@H!F:.?8-]6A:CN=PXJX
M'R75.LOX*CQF(.R[3*%=IVLKEX6C>59CUI%;GU6<%98*#/'ZAV'ZM&CQ56H7
M7JQE,=MO$+J)!:\)Q6&NU".3:S:UR`WG-5R_\++W%5P;S6/32<&K^C$J@6W<
M3HQ^H=A^K1Q5RUA5<"NKE)'!UZD>[>:W(,E/U6RZG(55==QPV2J7-//'Z)P8
M'4/'>C9+6U.\57M,[Y.6Y=7&`K]*/U#L/U:'X>`V:;;N"`DRB0O/-5R?*#Y%
M4RJ.[Q!58:C/K,'R58Y7L6OE,I"V:GXEJ@#R&>Q"TROX-59'M@;]UK95)56K
M?2Q;ZH.&!SL]0[#]6A.T^\:J!U1:-:JI*UZ6>:Z?(]G>SB@]N:S$UTCOA6KD
MUGU%7P-/D5[1`]G-58:C,YK'6(&[<BLY-9)&/%.(.%K54=7>_P#X3[6"B!QI
MG9ZAV!\]`.CNE;ASY*DC`)1N(O3;K5,6G>F-Z($!U;-JY$.WG`;EE#&[.*BR
M:MEIO<>2]F>R%C!X5&^;5?2I0UA0\T6FA/!,F@N8XZS5(YOAJF--*4O4QM=)
MJ@6P*?)8"I5IU&M"M.!;DP_=H1^H=@?/1I(+Q@[>NK+9V\'7%==D<H\E8R3)
M7-KBXJE;3W;14>4MV=D\DQS9:!M]*51:YU74Q*I4;Q]43=9XIF3Q7\2K/NTH
MBUT9ER?<6K5BF\@Q=1DUCXI%;RI_3/X;AHQ^H=@[S&A>MI7."N*O.:AO'!6L
MFE=">&(5Q@D7=Y.WYKVG*KN$85F%M`<3O.:Y8J]RVPM1P.A'ZAV#O,:#VR]U
M'NXE=&R)G1MH#1N\K6A9\@K62/+F^!R+'ZD@Q:>QJ4'=U&=_O'Y*KHWR.^/>
MAU#:;]47+\1DVHYN(":_Q#/%ZAV#_EH.K<V2\%6F/<"7VC>@&WDJ\:II2_E5
M-E9=-2H<M;;;<5:<5::&PQ\7[U5V5N/I6KE,H56.;,.&!1:X6)!BTJJ&5910
MEQI$P_\`M-)D:Z^M68(7G_35;1_TU5GWG7`*./>!?GB]0[!^A8D^1X*D]\>Z
M0(=&04`1@N#&A3O&R5$R78:+5.:#8W-VJWX*YC64--7!-YDMHGUW.HHIF7/3
M[.-A9,8K)=%N=@G5Q>ZT:;LW1Q=;+P:NGRHVIO=;N;H0^H=A)HT-X5J(NA=\
M."ZO*8W>I>U90VQP:A'&*-39X;WLQ'%69"*CW7JC!<."-H;U61[0@ZA&3,W\
M<Q?D<EBN+'8+_IQS7M.4EPX,5(6!O/?HP^KL)=#B3N56Y-=S*Z_)Y&CCBM1V
MAUL8)XKJY)V>3EK91E!^:K8MGB\U7+/>NK8YYY!5_#GZA='(TQR<':$/J["7
MRT)WOQ;JCDF-`OVWFN:U'U<GB:A%E>_9?QS5JKUMM6VU7%8YA'$+4AW*L])'
MX@;E&UMD-=PW(T(#A=\U:.VW`J-QQ(SQ>?82^G0Z=O=ON=R*+QB[>I+(=[U?
MJL'607;T^.5IY53HW7EER:R,6I'[(3!E1,LK_=!H$)&PM:.:[IGT5828G<E^
M'RK]+N*<XX!1367.MFLMG&B>?<M$,KP6`3KJU-35#)8+W''DFL;@T4SQ]A+Z
M=`AXJT[E:R369_3.Y67UB=P<M1[37@4;;VEVX!/F==;P0+O#<HB8^EA`.J#2
M].CDVKZ#DK(M`$_X1,FT;E#3:JGL]XMHA`YY:YMQ;6B`%&M'-:TE3P"I"WHH
M?$52.\G:<=^@/(]A(/ATJ2L:\<U<'M\BJV2\_$<PH;,C<"K.50N]35WI;YA=
M]7Y*F2Q/>[BNGRS;W,S6GMH[Q!7R3$*K8@3Q=?I./!O8%%#-:<FWLAM;-K$J
MU$^*7R*LY3&8CQ."NO&AK11G]*[F/^U74'D-"RP%SN2P:SS*-AT<E-P1%++Q
MB#H3.Y#L9!\6?)P[9M)@CD!+CJ-`O329`64PI@58DLFNXKI(:N@WMX)KF8'-
M3$\`M7)WJ_)WJCZL/Q!79G$FS$W$C?Y(0PEM:8UQ1<7OH=P<MK=3#'S4);BZ
MXZ$CN+NQ?SOST9WC;VJC[GMN-=RN1Z2.2V>[(W*D@H2V\*:/<TW)F3,-*WN/
M)1L@`:7NLVMZGB+BX1D4)5_+<KP'-/$)H::Y._=X4]PX)K86M=JWUQ5IT<0;
M8%:#_;\Q<Z@1RN2YHN97?H1\[^Q8_B-"W6Q-X@O:(B]GC8KYBWD6KH\EK(\H
MF3O'WGDA*=EXI567>8(W(T)<7&KG'>J'#'-%!%>ZJ=&=XHNARNK",'<54Y37
MR"LY%"]YXE"7+W6N$85-W#/11LX-[&UX#HW+7AC)]*ZJ-C/(9BR45"]FD;,S
MPNQ77?PXGR6I_#7?-4LLR>-5K;E/OYJ2-#AS5?P\?T5&@-'*[1B;SJ>R<PX.
M%$YAQ::=KBL>PDG/I'9C*6X.N=Y]I09OP]3TBOT@QNT<$R(;A?V;XG[+DZ)^
M(^_9V8'636JC;(ZTX8E=/8'2<5=I?B91Z!_GM:L[YNSSY(M<"'#=FN['!8Z5
MM_<-QYH`7`=M:9J3<>*L3,+3FO5ZVE=(N^7?!=^%WP7>A7O"Q"N5V8/GJR+[
ME!D8LM&`'\A9E8'#FJQ2.CY8K5G9\[EUDX!^$+\R?[5^9/\`:OS/[5^9_:OS
M/[5^9_:OS(_M7YAOT7YAOT7>QT76S_VA5:RT[B[_`+,__\0`*A```@(!`P,$
M`@,!`0$```````$1(3%!46$0<8&1H;'P,-$@P>'Q0%#_V@`(`0$``3\AZ(S,
M6!(&>`FPD?)?9)U2^(0Y">XTZSTGK)/\7UF9`QWBASJNYY+`F17M+O\`RBB*
M?)"+5#&?+_`M2X:P/$VPV&5.XA/JK[!*$-PB#`[?WV.?3\>F8A'<(3D&!Z2N
MXQS[")8&Y*VU7.KV&R9AD2;A.?JOY^<%[DBL0<IW2B]3L-3:_P"C1GKI<>$-
M>^+S!&+F#=OVD1A3;=AL%K_MB-7`SG[1:*N#1C>FSD:3%9T:7'5;61N;6YX6
MYA#LWNZ,*Y)F?SCUE]47IT60EB)341P,BF]VEG_!34IRG::QTCHVL[,+"/1M
MW)C)/4E;=/D-!'9MIY8C:Z1?864W&1?,4)2C1B>#8HR4@QV[V/?I!!=9EPEN
MR5LOF9&F9V/&D<P*E_/OS#:G%BW<OH[RLT3MBT;ZBV$TWY^T;C0X@BNC(\$F
MC$VC]R9$1N=NF17-TEO0@2-O]!#W\G+(4829$QV7@^K%+^=QPU7R>TR"PD4X
M197,T==ST+.1SB0K(Y\I++LP;IPM`^1-&*99%S.BM(N1=X924Y<IL%F?9>Y9
M6N2M,:AH:IA,IWQ&$=S4;;4\B.K,2D-D[MN\MA04?L2#.B8]:=Y#]_\`/YP;
MQEZ/_1:'A\,>F\"$"DM_5?T3_P#G/`BZ4K9C.W&5L9/),MZLL\\MTF\#]O0Q
M(6EQN.IF;W*<8'X409C1.J&-_P#C"6MT:9I$]88R.,,LI");LH^Y"FBX:GP4
MDB32)Y(MW^K_`)KY5>PVUIML]&9@)MN$M^R&HI-]%HA&"8K34RB4=%<7CL2C
M\'D7@3))(C::8G<ZW#:E_H]V6W(@@N`EV%M(+R^I/V"\R+YDO)L2J=1NU:,?
M?)"%RH8["(I$TZ:+PJYZ'Z'RQZ&6/&2O;^<C?NNBL9+ARWT(ZD-2R()I@R&?
MWU7D:-1XWZH8GS&Z"MXE+<K7+#9?ZZ/:(LN8:V*&S2T,.#$=&/SI-?IGV.:[
M(PAM!4ADL2C2=O0E(5+K4;%A20N(D+9/YI].S&@Y#+$LH/%[B<)EAX-#:.?=
M"G';W"^/D/3-V(EG*=[$,'*U>>@@NEB3F3!)SA$:(:F[20I7=D6T"0EV"L;6
M\#-=`Y[@<8;QW)/-2_X"\'NWN43.:D(_FL]K\,9Q15$6%Z,3>!ELBZ>7$U*%
MZ0G)>/4@UT+I.'I7G<&\:W\X,207FG":V$+IWBG+$IL[GE^Q53@@P,1,_P!G
M^##V?#&="Z,H@:/5'L(4RNOK41=N]EZ!E&GT%NAU"2*F]1'@F";K>)1T9QWH
MMQ_4ML@:O8P;FHH*_CHFS1_F._(NDUZ8&)3ZE_@^)\,R=!H/P/B":>1!:$T-
M$V-Q(DMZ27]BGTG`?Z9(P//X9+G/RX/JAHQ\-H1.6F3RWA8U@!$Y?H*:R-,0
MS3<X]"$1<PQN0<V2>F)BQOL:_@^)\,8O`Z0Z)02TRO&E,)$S:,9QX\Z$%?@,
M8HHB:V$4=XD$H5P>Z.?['DRYDD6.QB)9;922];-LDBQW8NEC16+PN\8I7TV2
M+2T2NEBS[3?\%_!_8_D)2,('4F!>4*>I%[O%40H"W;'E2MFD#$Z<M)#64RMA
MH2X)S&4(0SA/@$DI!9QV%*(Q^`Q9KZ?;[(1M^;+(C%K'L(2J$VUJVXC.5+*W
M87'<P,3ZS?\`![+_`&/YB5Z&L2\8O(:UPZ0F[57E@3,\IL5UCDIVIGI)M)!@
M+AP/:Z>]@Z-B6TD;;TDA*9M8$4M2&Y>P<UK&,$5)P:;3(.HL2>K8@BJZ`(-6
MEZP]R>OC!38'6I_KD=X2,#$^XW_![6?WZ;<Y,B=LPI/)2'Y>-KPDH$\(Q0ML
M34I%EBDOR+D-<AR3R'V0ZIDU74AOG8W)6,,JYT$,3J<#<<-,]0TN4)J;?!-O
M=^!2G]%J\1GLE"2T$8]#[K?\6"]+`WA(H(OE64W;O]#6?P9$9&PEB$W+7(P"
M@]95T:3DA]0ON2/6:&7W&)0A3J@>O[A3,2Y<#*U^1@?86,TZ'TV_X%_AB>2]
M>8/<+J64AAS-8'[$UDK+Z,4$^F,$5#*91"DCH[4CZR^DF63$#$.KO9Q\CD&P
M;R+\B/+)P'X$)ZL&8,^RW_![KY=%NEE>#D[""G)+J)47,A3LI':9ODR4U0/Y
M:MV?<?6NA&"$D+[SP^^Q'CBR@R&<P3:9U`SH$*>U)*1`THVER%--AQ#DE2J!
ME\M\H$M6ZAF2?,==PS%E_K7^#XOR?VZ[2FLIRQ"*>)"O.PV>A'3S!)#*)SRE
M`RU/4<0*CK(\EG5XU#$=A'4Y):4*DF&&2-A"*?/&7#,B&!XX;6I(Y3DD-5^X
M1;"U^8K'@B6MUK9%5LI7%RA?T;';&9A/I:_@^+\C^9#I[&60F93P-F];?`6,
MJV#-<M;)&!/=[B9<+9"\J==3D2MC(,I'N6>!U16YB;9,:F2]@^W`ESF1RX+J
M)3V%OMSA>I8$9U/(S7HS%NU_![!?**>8\J20JMJ$EMBH%L2F7>PBA["R4/C7
MT/N>C>ZSTER&>W60:U+M3I;0:HI*J2JA+8B.Q('5:G>7/[!=!BV)G@H1TU&8
M7\,SY^I'F^W0/W+%MA87D4%:;'B9H(6X:-$4)K#)[V4X&22T"&T>4)SUNYBE
M]BO#*FC"4,=+Q4TY?`I3XLW!:UV&.CA71)->Q.H%7K>LE<,B=#47+,#()^!5
MD7R==.4]`!7!23EHAD=X9X>XZ=1(EHQ!8H998R2WMVX)[JC=Y+'/*+DM&0XE
MTW\#LG&]>@N0MO#@Z$B1OO@]$N!HTWJF^)"BA:?!%1HM,U+/[#:(.[GR'3D%
M["?A_@6#R,O<:@L6-2BD-L,9WW2\G9N+M-DXHL>&[*,CRPIJ7(DVR):\BC>M
M?W&<))(<B[J%^6FPB-1Z$1=E%@/BA2V.@L/]@-UV1;(^HI014+OHT>=:XQ>=
M+AT<S$QV9[?@3F&^#/W)PB0CR=L"+]<CEVF46H+R(>D)*,1H<9HQO(I<XGCM
M6BJWXIAS/6I$UE"]KN.SOQK#9Z+4H]210SWK9#XZLA/OGY_!,O<6-L^NF>A(
M8TF)_8$]T=-IJ"T.9UI9'D6VT@QK<ETTV,OG*&&]\5PJ>T>1$/0V0J$%4M/:
M9BMG63K';VHYRZ8#TSP`^^GX>,F^2U%@O+-EO!*NA!I5N39R[%ZDD;;/*;+#
M-++$IQC(';QP2S)'Q!=1>+/1O02FV<#JQREH9#;!/>RM(C[.XM,D0G$I[$D[
M8%1I,]PW;(:],1LCVFUZ+_?P^-/87HF08*F)^[V'D38@2^`_""X17,-B"U#6
M9$-\-`6U)S;$L>G!"5IW_81%%,R[6!(U-IEALGP(*YK\2<R':&%AM*">Y<CH
MMB!D>!)-C*48C<5"Y2?<,!J&F`][G[OPQ:*/T_Z0F=3A0V2-%6MW(LF<I+&N
MZ&W@V)2,V=!LV)#:;^A+EJUJ188G9R1;03!;1JE6F0Y>BT/$;Z,<GOR<=9!*
M0<<.#QG'3$V%G`\F$1))23"Z:!HAHY$OPUW,GAUT"A(>>B7J'D[V:#:6F\;]
M16[-@*O5=AGP#^L+,3>9$B?W"RK+,N!1%JS98['<XLL@_A)S(5<:"C4?88B3
M)XM>@5D?AS/D9-ZR(*X%SB4]-.C,CL3)4V2>K(N6-2T]1.1`:Z.1D$5LT#`Z
M_P"OXV+..#3_`$1LF)-B[1.>DGD;))%B1QHK)J$Q&#08J8F#`RZ.A"Z,*8C6
M6PFY`;5):O7\4"TY3'^B&[ZX;HA:L:BEB$R)61>*'(E<DDD2./=(3XDCJ:-Q
ME&8HZ78)"(6-24U&Z8(_'!&9*66P-L00VW)(%!):%O1#<2OIB-!C4T0\"J=!
MG:3-2.DLVG0F):=+;MA!,"$EHORX0/T2?'N&](>C[,@9,=1I-"TY>3;/D3-"
M\FUZG0-SU!_L`LA>3>1H$A4&MW%=Y<,5&4XT'_@:]IT&:5;((8V5P8;[$R(;
M?;_9]C^SG_?<^G_1P?KN/:^K]C_V'[/^M/\`HQRQW4O]#VY\/]K'WK&?_C-)
MY((_C'2.D$#4K_YG_]H`#`,!``(``P```!#SIG:\6X\Y\D/QAWSSRI3[;K@_
M#AHL)CCSSRHP30.-C$>?KI63SSS'A9PR5#F5"3*##SSSJ$B;W3`PS#O?#SSS
MSZB!AR%S#F&]VA3SSRK0A?U$D'KC?#CSSSR[23XSS"S"1_13SSSSX"1FA1`4
M1RAP!3SSSH@@5BA,-A`A33SSSQ:`C$G2-/BQ#!A3SSP"`0W;A@!@[AC#3SSQ
M4@S2X1!Q!9&0!3SSRRCRH!CD%PR]2"'SSSR#A=1S::AA,C@3SSSP#B2V"??0
MVQ3C3SSSQ,R`%ACR`W2"/SSSSQB-AT$%0#WWY3SSSSSPD(331WK*/?SSSSSS
MSSQSRQRPRSSSSSS_Q``@$0`#``(#`0$``P```````````1$0(2`P,6%Q0$&Q
M_]H`"`$#`0$_$!1I!H2H]#_#ZGV/J?<^I\I]A&-V4';?$36#^*U\RPJK-.@"
M7X7D?O%8E>E4@S$YPTT47$*,4R#3Y!BP2J<VQI:S$Q"1>(MX_P!#KP?((0:)
M&T5X(3!<B$D8DETA'B(K*R"T1X?2"K$$6*NL"(F(S>(1=0&1,41Y.<SQP-XH
MK&S?,\=2<S\RH_.*BK%16?'-.1"/HI,JL1D>*LJ>..KPBRLO$(407'^X7*EZ
M9[("CW"E*B2X(V+7.4J466645@DOXW__Q``?$0`"`@(#`0$!````````````
M$0$0(#`A,6%`49'_V@`(`0(!`3\0)5!-RDZ:(_IX'D>1XGM/6>(V<8("(E$'
M3#L3)*!17(RY%^J<D/0CG4`<4<63,ST*I83LXS<1H16+!C#"TAB&,=.BTATA
M"D0M!V'2@=,.F+-VP6*%F[6I'3'%,4YNV"I"I:QATA4QZRI2*:6LQ8H>L*<A
M:$J,=(**0JDM@L9:18*?D$!OYO_$`"H0`0`"`0,#`P0#`0$!``````$`$2$Q
M05%A<8&1H<$@L='P$##A\4!0_]H`"`$!``$_$/X22]OR9'UG1)N.C-XL=]"#
MXWV3PAJ]5'!@!D]9K9KM>?X**Z_PO%RT&I9&W\+EX3B+4WJ82XI5OOB5\DYW
M[$RJ,FYS+++!U$7[I6?,:(8"PM"_1^I"QW$G9"/1J5TUR0U"^KLKVX\1W-04
MR\WQ7$6%\F/1Q*9UM+^\^(1\1U6L?O:?\=^(FHKIC^(+1W^^(T:H[R!1@=_T
M3=Q_6T_1_B#?U^(4MJW][17\3\0?X3\0MOW\1I??!^(97[=NLX6A;2:KZGT;
M,+DM+K+`&[1"#!<.MT7]58J5@&?0G\5+W+-""BAF[\QB[16^:O+>$!!')3HZ
M2C24ZE]93R^L2MCTE)LQ&+\W8!*2+=5M;SI;'L&J!&]6@>DILNV;MXBG6%FW
M.-7'%0+QJ$`OET@8SVD&Z=[EL`+[%!Q7>"2$*:;>'B!3='I,]?64NB'O!7:H
ME\*YX;BX#G?:`YBPL\C!M*TE`[Q8.@'=1?M]:-)L]D?B**+-0FO5ED/#:46=
M$L1LSDC!,;<!WW[0QCWVE(@PP&N^J-JW.\=5$%U4%O2,WEEK5X@C)7!:M--=
MHGF(3L*SB-A%7"&_E&`*M-:WK4'$B"&`.#M!?"*-1`YE(:4,NAO.<Q#CE&Q[
M](VPB[A:!T.-(F8@:3%8S7-3<`EPNZ`OX^NY^V]P#\RL)3VQ^I13+'24"64M
M9A.L++"?3<F[VA[T(@LO<=G:7(SJE$=0?&\IM56]<P9LJ6O7HMR2PM)Q25%7
M4KJ)/F(-T#:X;UB]1Z+^-)DW7RML3#:8TJ4H-]S2,`;YTH!-*7%'V'5N%S#*
M&5\F[U@68OGB4+42M7%$5CY,%*QM[T'UY*I1VL1P`T^5FL-F%M<._09M8V%+
M!`YDL;:RO`M-^*C6"H%"H;98RG-BB4+K%+$@5;X0KF7<H=$I]HA*E%6Z:B8D
M[A)Z);[RY6ZED\LWZ2U+A;/8X]IN<:CP&98`"XG(UF(KYW`P9%71]ZGM#)]`
M0W[2I.*Z3\<=-)?-,:NZB"Z)A6CUE@C@F`'72%(U<]3!2V>QL^'UIMGF03V4
MWY5?P[^8H6+5<V<QD^1V;P0:PH3J+8ZS;N<%/3F5%XN&W2'A8<L(I7``+%+7
MM\1CK-B$-$M^D4*W4NNA+,CT*%UJ/9T.%NDU"TTK%1_BX7W8&U;OHKFQ$N@*
M;U8-P(TDG0B-V)JW",M-!/*;O2'5":C-'8#>.->CMY&H[YE'8A[S(+K>\6BU
M7K'Y^O"-O7#\0=`1+1/L2N3L;T(.<F9:LT%-;TC[;5%$F*(FR.L!CR]!7"X[
MW%MI;!=?PN5.QHN_W]H2%'L^]PDK_H!!\O$6M4.G:6;0\6%#?\`6L(/#B5Q9
MANBM8M!5`\V?;[D1'1LQR<XJ>PJWP,1G[1:#E=CL11`L+2_?]VV'V]4:CJ//
MF9SUKN[;LC%!DO1-3GM%D<MW-HWZX:\8^;\1112\+B!F0+05*YPL8!0%F$30
ME1%D=3KU(U?HQ*,[RNV,D//HE]"3B:5T!-\E1SCN_"ONPFJ<!W#Y17:%X7B6
M:$!WV"<(-E!2\D$<J@EB[&FM#T@V4-'SY@,QBM[OW?+#`0JD!Q4,$V=99.V$
MI&IT1#9;>G..8ZV0H:!Q&>9P39FA[5]97<'W@'&)>#OTX[0;.P]7"`&A:JX%
M_F'DKUR!W-I1G5/4=(#QQ1E1Z1RI=SK?327'SGS3[P05I<P[L4U)T)T99`=*
M*`R^O4#V/^RR(1:O(^R0M`;5I?,+V8W!-(I<JXZQ5CL!F7!"WN'#M%FLJV(R
M_P!D#/,=V7BLS;^K4"`%[>WUW/AH4V0C!U`UM3QQ$)<VL\=;0((.@/&\8D'-
MV'I6T8.!PWA.\',6MC'ZJHO2E8^-/#"QJS6S>*VJ)%8I'((\DQ0&DZ.Q-1J#
MTHH#T)4V"^L&)HA7M^8@8=FUZ&T6!2+6]4'V=@&O>''II-3K+3T,''U@NX@.
M#?)-:7-RV>NO6-A_\P?S#!=6Q=/C?S+,-$_:=9=*1K9NZGVA9&=BGC];?,9*
M09H&J>&7U6OL]F-90K9K26:&@<-?^Q+JJ>T:D$.6FFYR2AX>@%LMS*!WP=(!
M59_,>JM"F^44+(M&<#]Z1.RQATZG?WC:%6PKC_GB8F4'+I&NO23CZ\QT@7:&
MT-939TCHRA-2X%JB[_$%**=S'O*X)-VPGDC*Y#=OD8F.B`->7Y1QN%#5;T/V
M0/H$J'U/>H8<"O*N4OS$VFL6)Q$(/-@'LLSS4N%:$I'8JZ1`'>]?%QZC*QAJ
M1V\!%!QFL4\QD<=4[?:,HT>,D`Z5Y*B5#_&,<0D<?T`8*MVHZ*,LVE'.B[H[
M5S`P?W+<H&I4/+--&7(FT:#K$44PJZ>IJ1#1.PJ+V-Y,GII%7EU]M?-SU>H^
MU0>J-5+_`'4'6?>EY"A\C"I)OD/0CG,]Z]M)5Q`%,&GQ+MYRL"]`A=AXT#?]
MJ7FVUFEL-.WA$6?1[B&!#$N(./KS;V^P(M,!=!UB6SZLZNC?$'L/V:+.!VJ%
M$M-`:Z:L-$7*@&<W=-TUF%.#$;W"5&`P>XX>L.T&+,W9S>T<6;:_3U=#U@=D
MM1H>)TGW:_:%#1RCW86:LBO9-F6:G+Z0/CZ=5[NUNPY6\HVN\O>'3TE#>`B]
M,QI2C99#4I&O6`5XJ.G278+L2&0>D=UFMU@L^2CCZSFX;^`9;C6)=!?:%.#[
M`N768.G1RDHI=3J0:DP(/))=@$!9X$PQH^9BMV5:=HU(*!0`;F8P@HTNT<,Y
M&&6T#1W*F(,8'4R=H;:>4#`3O;-:)L]K?$ZP@)ZG#&*<N\63+&K2ZB^;C16(
MZ6M`+[QJT%*4B@3S40.130BE8##Z0A9T#8-@DBF`%!P;!]H-<UND%B;R<?6+
M9V]V_P`QS+!BN8G)'#`'/6+8<R_#^#9*<]**S^/>,`LRX0XR5?$=@DJ6VPM!
MZ17@FD6;'2'D@.4-W2`*>BDO,;^8LK4(%NE>TT]2XN@HF-<2Q(X$RV7B:11S
M1Y>#K$E^LX*J7X]"/;"<N83[8M2ST&#L$VW$O@;O6:`H*$4#@.(.<2F)!2>8
M+,_0?F<?6;Z21QY7"2YS*L$TWA[,)=HEH>MH]:BM\NC%^J""X=WE\8A`"&RJ
M>D,*P+OO#OS10=TO):VOHEW[RAJS<'[RM3'(N]\1$+==1Y8@X66]GGX"CI!P
M;:=)0VO8U??F,U"MC*55<E3WE<Y+5?G;Q"CQA;`BO(-1Y0Y=)EUR]GXG'UAV
M/N5',%"TXF;="XDU310;9K4[5%P=Z%8Q-;:O2"@79"[-(J.]7HCC)F"GQS%4
MP4CDZ1MNRE`!\9B:U5R-DN]")P%Q3)'O-6DQ5:]HN8`LZ^=NT)FZMKAY7+#]
M,UR51HNCPAQ;BA@F7\%RCK>A-A<T!V8;/XPL^9./KSZ21?NJ;!9J6,5QI\9U
M[X^5E(LY3>S35Q&L@`!=BSV(/"!4MD`)#K!<72,,6E%(<P?AKMXZ&_:5!::X
MG1P^Z0`,K;IZ5<'>$(8<WB#VC--@=;KVG`<HIVYB]V">A"8!H#73_OB!(^8"
M<`M;\Q3(6)DS5&W/M"=!:J!38-,%\5,TYU9+0K>(]M`ZM?'\,)"GLR<?6+Z"
M_2%JL883:LRL2DTQ;G6,;QM37I,QO+^'<O1-F`ZF`=:-S6TO9,!=4%5<=X56
M->)"*.**72\Z326-$%C-1*/_`'?52K6H;J`%58,O!F576,SI`9&B`Y5GF#/B
M`,Y+A93:S**MUWSO-!.":G:K!&QAA:U8FY^^4>M:0@+D3JWO`R*WS_*7$2<?
M6;Z`O9^8H)"W648QK*`:96U8FQ;JUW&7AI=Q@/6@V!]R#ABZ_M4`1F&?ESR'
MF,4!3:<NG7,REN2BE:.L$4642LMM`RR@>M*NM,XTBS05%1Z1)7RUKW='?O.@
M56%8JJJ6/IFO<9J9B<UW/:+G5GG2WXB2K*#/<6?2='I,N$H7TCA;D6^C<X^L
M7T6@]"'@:5>TP?5&L<`?>"&(8Z9V7B,.Z?SU$^7U1OR6282N"\QG=OO`1H#O
M[$&L^8-'K9%]@&E`2_9QH+/B$A5T6C['M%!:D#`;J"(]#I<LJ6[7C'VC0,U*
MJ._$?UK1#?ECWGFE"^\7:5%0]G>6ZU3K7$./X2RC@^DX^L6/2^B/Q,:L5J<3
M:\LJ!18:46M<]8S47=.E5="NFS!K,EKD:&-',70UT>+FL&':`8JT$Z:[,0O'
M(,#\#"#`C=,Q,.;0J('!)[L+!)YC_GO`!H$5DS*HX"=KJ#>QU2I>MB!5-'+0
MI5RDLN2DU18,9PTU](IG`FIJM*M![1[B>D+Z,T8@O,U^6((4-V3Z"_$X^OJ,
M3&BZ0\0WFVA4'$K4N,K/3K+&ELX.A\OF+/N"[H,L-&CI&SJHR>EKWE=C>^YE
ML%N[XJ-ODXY>3UCK*VZW]@;PKYM&X6VI[7+]!"*E:Y=>\IK"J&MFM8*Z\I&K
MJ6[-(1:=OHH29%L'-$=0[\:U&M-S[0W_`-$#`S<U@](DDZ@`45GT.D0SE0.6
M]UQB816"]2KM*+C%X'S,"[)6'=!^D-OJ)X6_!<P:&2:.\LU]DJN2>PX9J;<=
M=!;('3*Z:V]^7:7B4K(+Y9K,HF%`7.7:.X%0JIT1*>K%HSLZLU$6/@HMK42%
M0#.Y`WB0,6\T]?OGO#J<+5U6[Y13I&L',&OI,;[RO(N,$W0#Q?#TJ,?4*`==
M=8B2VCV?,L1T$)3H;PIT36RO+B9[PJJHZ@^P>^#[LV^JH]!H?6#4"1+<8,TD
M-M'O&QNAYTC=J-?5_P"D;+O@CU&:R>'Q`7.(,`*!P1`OZI@WL])HY&8J<-0X
ME-V%5^(C=!I30KI$!>`>!10T?G>%6]07;[):UZK=^*CYF[Y6V]HA[@?@C@/Z
M8KUQ[106PE64>FWB8Q<H%Q0_Z^4?F'UW;H4]2I;MVH^&HX!WBY+%8J=[XC[8
MJLA"UIIVCNK)<P%UAMT4.3LT@3MP:2TH*LD#S7R`D65-JY'H1`3)NC[KE'Z7
M%?)3*ZM*O7_LLM2@M2-92M?1@!$TR3BAKWC^G2CQQI>&]FIR(C)YZG\5C%1F
MI@L^5^$/Z-(;IWQD>T"]=(J7F;EG?1&Z>C`^7L#-!T(ZMJ"SFKERQ4=0*&QP
M.\0W=MKJ3I#+$M146I1JLLZK2]>#2&V"Z+D.<U`/+)&0ZT'/K+BX.Q>\25&F
M6$@OAGK[5-V-H8P-:HW;T2H;4$Y@:N!5"+.!D5Y=6"+RUX(JV..T5+I*P0VM
M$=@?NOZ;W06)[GYN4%<T]B4X(HZ!79>\$(!1&2K;G>9\ZK;NMWC>+;!#4*P8
M1=[A.\OMZ+B9J*9T.Q,)JMM:UP][E)@=BKURT6FHVU!,"V\UYG!0HBX[Z1'H
MZP)ZYE(&3P@\1UZ</G2)7X4%CJ.MH6-4,)=JJQ`I-JWT]H#,%%2P&.,&4E>,
MPI*EUEH-VINJ;G>A[$V_HK8U%ZO\"(0;<Q#7,,BVJ[WS#UO'>@[P-I4Q_0E4
M;;1$Q7$=VY&U55@%68[##RE[F="!@#U0$8O?.B%Q9\RFQ=6@%T&DK4B#T!''
M:;`;["5"JR,^A_LO;G5KY[RRN1K&W'8C=SI<*=!/]C!__1M[RM`9BP]6T0'_
M`*2@X.D52I5M-9+6JZW1`*,C.&L_TNXV-_HW3TC<&:@MBX-6K*+NLP.[0=MO
M2<P/R7>B=`B[Y!X9A*5-+EP,;#"\KF*0*XH4[OS*,$ZL;]F7%_W=?L106*HO
MU+8]&EJ*?9YN)F-HTYY7',Z%=HO5G0E,'H5$W:U5_NOF7-?=#!>("K)0I']B
MXE.O]('6@OJ:]S6"O7$!'\1J4@.&94N!19&@&;8EKAZ18LQ,6HUYAM9K57'U
M+BFJE:GPL+*ZGF8ZG;A`05>&<VDK%0["9YCV+[P,ES$A,QW,5&3<R_</ZM=9
MLHY*H*%]7IUBFE8EL%=8246\2MIB+:-&)<0NZXBE4PAHP!.$WBU%ANX-O,5N
M`9R:PZ/;<Z@YJ$`6\L-8G4PRS24EXFL(@"INJ="7!*@*MU?U4@&K59H[#J45
MVB&[`M#:Z$=5B7(/>'PM?$*N#%93F+J2+.M(%WE5PRS1Q!A7>K+T(72_3#28
M:UCZ:76^L:Q&)0+4EC2C:("7M$I6HO6;[I$R5KESM*\_UE-%UN&`4L!R)^S*
M0ZHI.'^RD"%*25I4RZ/#*5P#S"^F`*%8'%><3Q>9L/O-'R[+S3VT@JEL+PNR
M#:C:[Q0ID0W@=HP522Y2Y86])9!6M./SUXZP\X!E`:!_:AR-57>)F)17!P#7
MQ47(6%R'H,W)KG>#4SQ!Z$U[E;)E;U>YB[1=Q#:\K`?BH];(?4$Q<?)0#"$Z
M2L*CH+JY>?%"KM#H=96?4%'^OU_OJC5C4B5D5V=2=&ROMM'WET_;9K`S>M35
MW4FU])(7YD?]%'6/G#MAYPF,YGW@=G]SK/V#YF-?LN(N3;U^6?$*T_10O%![
M2F-<:=/_`!:('O*1*YMQ5;2OXHE0IO"5_2!UE)2&@[^91_\`+__9````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O86QE<G1S````````````````````````````````````````````
M````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`P,#`@,3`U,34T,S,W-3(@,#(R,#0P`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A;&5R=',O=V%R;FEN9RYP;F<`````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#0Q-B`Q,#4Q-30S,S<U,B`P,C0R
M-S,`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!`````0!`,```#MW>)2````,%!,5$41$1%W
M=W<F&@`\/#RF@!K_S#-`,PT````-#0US60WROR8S)@`O+R____________\1
MSM"E````$'123E/___________________\`X"-=&0````%B2T=$#QBZ`-D`
M```)<$A9<P```$@```!(`$;):SX```!;241!5!A7+<:Q"0,Q`$-1+2D4LH=(
M8W"543*+2X_CYN"GN'O5$W`F(&"-)\V=J]D@./8$P4H'")H&Q-4T&W&<>B*6
M7U\/1)TZZ*K?/V?KV*D]M>X,U;;MZ//X`^1#4M`M*IF'`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O86QE<G1S+VUE<W-A9V4N<&YG````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#$P,#$@,3`U,34T,S,W-3(@,#(T,C0Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````0````$`@#````*"T/4P```,!03%1%````#!,:%!LC%1LC'",K
M(SA-,D9<+TMG,$MG,T]L-$]L-5)P.59T1%AL/5IX0%MX2EIM0EY\1F*`2F:$
M2V:#3FJ(56V'4V^-5&^,5W.16W>597:)7WB28'B17WN98W^=9W^::(.A;(>E
M;H>A=X:6?8J8@9:M@)BSAYNNEJB]F*J]F:S`G*R]HK+#I;3&IK7(L+W.____
M________________________________________________________IG<K
M>P```$!T4DY3________________________________________________
M____________________________________`,)[L40````!8DM'1#\^8S!U
M````"7!(67,```!(````2`!&R6L^````CDE$0508TW6/5P[",!!$AQ*:3>B$
MA!)Z"75.D/O?BMV-*$)B/BR]MV-YC?PG*$[+1V";G4_[-EZB>C^L5^DBF50*
M@8<PF<314"G'5.=D'(T&-:C(K*_<[YBX"9,4[H4FKCHGE;V)B_9)Y9:)W4;N
MD\(N@#U[7`J3WC50+%:>S[3OZJ7WZMUQZ)L!_G_N.T^&#27#0)73^P````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O86QE<G1S+W-U8V-E<W,N<&YG````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#$W-30@,3`U,34T,S,W-3(@,#(T,S`T`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````0````$`@#````*"T/4P```P!03%1%!`($/%(D'"H4
M3'HL#!H$-#XD;'I<3%H\+"HL#`X$=))<%!847'I$?)IL!`H$/&8<+"HD/#X\
M5&9,7'H\-#(T'"(4A)IT)#(4%"(,3%Y$#`X,A)YL#`H,3&XT1$H\!`8$/%8D
M)"X45'XL%!X,/$8T?(IL3%9$+"XL?)9D'!H<9(9,A)IL#`H$1&HD+"XD1$)$
M7&I47'X\-#8T'"(<#!(,``#7`0#T``!W`%YM`(!I%0KW`'AWJ$O>Y`#G$@`2
M``````/Y`0";``#T``!WR)C@Y0!)$IK[``!W\``.B.S9^?WT=W]WB!KB'`+8
M]`#T=P!W_SC0_^=G_Q(5_P``-P"`D`!H]``5=P``Q)0`'N8`Y1(`=P```*H`
M`)L`%?0``'<``+,``)L``/0``'<`.+@`Q^D`%A(`````!"38`0#G!0(2`0``
MW(`8XF@`$A4:````?E[>`(#G``H2P'@```(G````````````_R0`_P``_P(`
M_P``_P!L__!;__WE_W]W`'1H`.;``!(6`````$9H``#````6`````#!H`.?`
M`!(6````:_```(C``/D6`'<`6/D``YL``/0``'<`!N`']DD`Y/L`=W<`#R,`
M'J,`Y?0`=W<``"L``:,``/0``'<`>.0`9.8``1(``````,@``"@`%>4``'<`
M%```Y0``$@````````!L``!;``#E``!WX'@V^&0`$A4`````\`#_B`'_^0#_
M=P#_B`0V'"D`].4`=W<`_P14_^?R_Q(2_P``-V0`D"\`].8`=W<`X``,&`#H
MY0`2=P```&C^`,!8%19+`````&_L`!#G`.42`'<`>/];9/]B%?].`/\```@@
M`>CH`!(2````9)AO+Q`0YN7E=W=W`&R^`&_H`$X2````JBC(AY;_"D[_>`!_
MN`"(!@'H%@`2````W`1HYN?`$A(6````7@!O@`$0"@#E>`!W`,!H`-S``$\6
M```````!`#```````%P``%4``$X``%,``$\``%)N`%3]`$5&`$0`?.0:0@``
M``%T4DY3`$#FV&8````!8DM'1/^E!_+%````"7!(67,```!(````2`!&R6L^
M````>$E$050H%07!"0[!0```P*'N-F594276F8K&[?]O,P,```#;90D`ZF%Q
MR!,`:5VL8DP`S!>'3U,",']W8[,%'CM>UVD=$[!LV[/+\1<:@.JV'DSN=02@
MO[EFXS`"H+I/LC(`0%5TO@$`[$\A!P"]V1,`$',`0`+P!W@!!])RT`=)````
M`$E%3D2N0F""``````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O86QE<G1S+V5R<F]R+G!N9P``````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`U,C(@,3`U,34T,S,W-3(@,#(S
M-S4U`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P```&!03%1%<7%Q
M@```MP``W0``:B8:I@``-P``_\R93#,:7AH-=S,F3```@&9,64`F<UE`A```
MOYESG1H-V:9SYK*`C&9`@%DS:BHJB!H-\K^,S)EFS```42HJ8BHJ________
M____'#'O^@```"!T4DY3________________________________________
M_P!<7!OM`````6)+1T0?!0T0O0````EP2%ES````2````$@`1LEK/@```%])
M1$%4&--MC\$*P"`,0PN!-A>][;S__\NEK8PI2Q',4TIBM^1+>;?T`*@#;R!/
M#[*)I9?-*6+YSA?`_\&(J6%N;A`E?1P;F&(;D'"`8T=<.$`EJZ1L==+NMN2K
MK7_Z/QD7"0*-=Z(C`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+VEM86=E````````````````````````````````````
M`````````````````````````````````````#`P,#<U-2``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S4R(#`R,38S,``@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:6UA9V4O87)R;W<M9&]W
M;BYG:68`````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`R,#<@,3`U,34T,S,W
M-3(@,#(T-#<T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$=)1C@Y81``$`"S``#BXN+,S,R\O+RNKJZCHZ-\?'Q75U=#0T,`
M``#___\````````````````````````A^00!!P`)`"P`````$``0```$-##)
M2:N].-?#N^<;$(PD@5@((:QK89S6$;!#`:.J4+_9H;HWC,RFD:1XQ<0AJ$$P
MF\FH-`(`.P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+VEM86=E+W)A=&EO+G!N9P``````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`P-#8U(#$P-3$U-#,S-S4R(#`R,S4T,``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````$````!`(`P```"@M#U,```!=4$Q410```'^8M(2<
MMX6=MXF@N8J@NHJANHZDO(ZDO8^EO9"FOI.HOY.HP)2IP)6JP9BLPIFMPYJN
MPYZQQI^QQK'`T;+!T;+!TK/"TK3#T[?%U+?%U;O(U[S)U]G@YP```)%)R0,`
M```!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<
M&`````=T24U%!]0,%!,).<]7]S@```!1241!5'C:8V!`!W)0@!"0%9&0E!%'
M$A!E9&)AYT82D&)FY>#A1Q*09N/D%1"28X!#,2X^06%D0U%M09)`=@H&B4LU
MQ!94;Z"ID$-7P8"B%PH!NP$()N]<I`L`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]I;6%G92]R;W1A=&4M,3@P+G!N9P``````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#4W,"`Q,#4Q-30S,S<U,B`P,C0R,C,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!`````0"`,````H+0]3````?E!,5$4````G)R<J*BHP,#`\049ZAY2#
MD9^(D9N.HK2/I+:6H["5K<67KL:HK;*:LLB=N-*KM;^?N=&?N=*?N=.@NM.@
MN].AN]*BN].BO-2CO-6DO=6JP=BQQ]O`SMK!TN+"TN/#T^/$U.3%U.3'UN7(
MU^7*V>7,V>;,V>?,VN<```"16CIV`````7123E,`0.;89@````%B2T=$`(@%
M'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-10?4#!03"@92'(G&````
M<TE$051XVHV.W1I"4!!%IR0JVGZ25.*@V.__@AP^CKIJW>WUS>P9D0&.B(%-
MW>3^9B44D*4'ZTO<X\M^V=(-Q^?-,S5;"DM<S80:1(5H%BQ`!EURXI+Q>G\>
MD3T)MM!DJ3N?I<[AV=F93N#W=:S3])G\3P].=0N3?*@2/0````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:6UA
M9V4O<F]T871E+3(W,"YP;F<`````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`T
M,S8@,3`U,34T,S,W-3(@,#(T,C(T`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````0````$`@#
M````*"T/4P```$A03%1%`````0$!0D)"34U-B):CG;C2I+S4I;W5J<'7K\7:
MP</(L\C:M,C<MLK<M\K>NLW?R,S2Q];ER-?DS=KDU^#IU>'LV>/M````"<<S
M9`````%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3```+$P$`
MFIP8````!W1)344'U`P4$PH5UJ+(&````$])1$%4>-J-CS<2P#`(!.5PSCGM
M_W]JS;@0N!+=+LP!(607%$#B<C@G*8GJ&AM9L<UM;P5'IQJ3P6K'XP+V*$Q_
MN1^Y2.3Y,_@[?QQ-_I,O9#D$+5,;`.``````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VEM86=E+V9L:7`N<&YG
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P-#(W(#$P-3$U-#,S
M-S4R(#`R,S,U,@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,````_
M4$Q413"FNBHJ*H>?M8B@MHZCMX^HOY*IOY:PR)VXTIZXTJ.\U,#2X<+3X\/3
MX\34Y,?6Y<G7Y<G8Y=+>ZM3@ZP```)73<,4````!=%).4P!`YMAF`````6)+
M1T0`B`4=2`````EP2%ES```+$@``"Q(!TMU^_`````=T24U%!]0,%!,)%?V/
MF]L```!1241!5'C:A8]+#H`P"$1;%9VJ]3OW/ZNL;,$TLB!Y+PR$$!I%SSL=
M0V@9M8E'FH$TOH;DADY[E<D8S%8G/I%XW2MD.<L,)WM6C5A6T_/GN5(/,.,$
M$=/,O<(`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]I;6%G92]M:7)R;W(N<&YG````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#0Q-"`Q,#4Q-30S,S<U,B`P,C,W,C8`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!`````0"`,````H+0]3````-E!,5$4````&!PDJ
M*BIUBIUVBY]ZC)IZCZ9\DJ:(H+:/J+^1J+Z=N-*ZQM/!TN+"TN/$U.3*V>4`
M``!O9!%'`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q(`
M``L2`=+=?OP````'=$E-10?4#!03"2\[@T)I````3TE$051XVJV-VPZ`(`Q#
M)Z(R*DK__V?E(M-GXTGVT).L%?F(HPC=DWE6`5H^P`*&*1DIYX3;<(>Q=!,`
MC5$!/WZ"MHYYLM:MKJQ\[;+?3UPUL@/FU:',(0````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O:6UA9V4O9W)A>7-C86QE+G!N9P``````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#(Q-S`@,3`U,34T,S,W-3(@,#(T,S8W`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````0````$`@#````*"T/4P````1G04U!``"QCGS[49,````@8TA230``
M>B4``("#``#Y_P``@.D``'4P``#J8```.I@``!=ODE_%1@```P!03%1%WM[>
MW=W=W-S<V]O;T='1Q,3$P\/#P,#`O;V]N;FYLK*RL+"PJZNKJJJJJ:FIIZ>G
MHZ.CHJ*BGY^?GIZ>G)R<FIJ:F9F9F)B8EI:6E965DY.3D)"0CX^/C(R,BXN+
MBHJ*B8F)B(B(AH:&>7EY>'AX<W-S<G)R<7%Q;V]O8&!@7U]?6EI:5U=75E96
M4E)245%12$A(1T='.#@X(B(B(2$A!04%!`0$`P,#````____````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M^2=@R0```#IT4DY3____________________________________________
M________________________________`#?`_PH````)<$A9<P``"Q,```L3
M`0":G!@```"<241!5"C/7<_I#H(P$`3@BJAX4$4.6ZD*>*#6`T^&]W\Q$902
MYL\F7S:[&9(U0LJ!/'6`</D2"B"FELT"*/`F0\L3-9C9^89?`;!@+IM'?P#U
M7BM?1.4CDL'4M?']C>=Q+U%`3R/M#DU#'NRN^$)?;^F&F;(!7\L";*-KC)Q'
MR,+XA.*H0ZF#9+N)#PE^;_/[N,CS#54YU8\TZW\`8@\M2[$>*6X`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]I;6%G92]C<F]P+G!N
M9P``````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#(W,"`Q,#4Q-30S
M,S<U,B`P,C,S-3<`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!`````0"`0```"U^C?J````
M`F)+1T0``*J-(S(````)<$A9<P```$@```!(`$;):SX```!<241!5"C/?=&Y
M%<`@#`31D;IS,Q1#,Q1#,7("/M"A],_;1#+);EBC([-@`*VYQ\'+X<*7+]&:
MW<+)1^#Y%T3\"6)^@HQ7,*QA&#@&W0Q"=PPZC()!UG+"Y-_<=P,Y[R_--530
MP@````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O:6UA9V4O<F]T871E+3DP+G!N9P``````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`T-C,@,3`U,34T,S,W-3(@,#(T,30T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````0````$`@#````*"T/4P```%=03%1%````*"@H
M*BHJ,3$QC9RJE*&MD:6XG+?1G[?.G;C2G[G2G[G3HKO3HKS4H[S5I+W5I[[4
MO</(L<?;P=+BPM/CP]/CQ-3DQ];ER-?ER=?ERMCEU.#K````^H$ND0````%T
M4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8````
M!W1)344'U`P4$PH7.*RI-````%5)1$%4>-J-CCD2@#`,`\V-N`(!S.7_OQ-"
M@TV5[;3CD4P4@;QHL6_'.25*,#!T96:$:YM<=$?A^UI,\8I1S`ZC4E,I7PO@
MY^]&$#"_A&Q;?_DQ%,L->1H%^^LOS((`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+VEM86=E+W)E9G)E<V@N9VEF````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P,S,Q(#$P-3$U-#,S-S4R(#`R-#`S,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!'248X.6$0`!``Q```
M````>)>Q2&9_(C`[U=75IKK+<Y.NU=[FCZB^N\O8,TA:F9F9Y.3DHK?)3V^*
MS,S,@Z"X2VJ$DJO`____````````````````````````````````````````
M````````(?D$`0<`$P`L`````!``$```!5;@)(K$:)XC4*(F`0"(RI+`D10-
MP,P`9#@.@8XG40`&@,=L`@@`F$K18IB*/%<IZH3Q.I5JSQ%W,7H\`8XPRWP`
M*-(S[@'H,,:;=2,6Y7+*EA,N@%XH(0`[````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]I
M;6%G92]A<G)O=RUU<"YG:68`````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,#(Q,B`Q,#4Q-30S,S<U,B`P,C0Q-#4`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````1TE&.#EA$``0`+,``.+BXM/3T[R\O*ZN
MKJ.CHYZ>GGM[>U=75TM+2P```/___P```````````````````"'Y!`$'``H`
M+``````0`!````0W4,E)J[TX:Y7V3(@G@6)R$-V6&$&HF8:`9O`@%/.UVH+0
MZH=8KY>C)`B!I!+@^B">T&A*1*U$```[````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:6UA9V4O<F5F<F5S
M:"YP;F<`````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`U,S0@,3`U,34T
M,S,W-3(@,#(T,#4U`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````0````$`@&````'_/_80``
M``9B2T=$`/\`_P#_H+VGDP```1%)1$%4>-IC8,`.M!@H!/_),40=JO%__XI]
M_XDUA!')R5>OWGO&\.SM)X;7[S\S_/G[CR'.TYR!@8%!G(&!X14N`UB@]-7F
M!3L8YFT]P7#GSAT&!@8&AI_?O\+4L!+EYTFK#_PW]HCZS\#`\%_)P!KF!7VB
M`ZUB^D:8)@8<FE.AXF+(@DPPQN7+EY'%M1D8&"ZB&3`;2K]$-X0!*H#L`ESI
MXO_5>\]PJH,9DHHFKH_L-?_\+A0#F)`4OH)&ZVPTS1>NWGO&P,#`\-_8(PIG
M.L`&I!D8&)Y<O?>,H6KB$KC@DYL7&,[N6`;7RX+'@-\,#`P,BW>>AFMD8&"`
M:=8F-GJUT*+X/S3)DP2T\,0.289@!0`O`&4!>+W4?P````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964`````````````````````````
M`````````````````````````````````````````````````#`P,#<U-2``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S4R(#`R,34P
M-0`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]R
M978M:F]I;BYP;F<`````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$P,30@
M,3`U,34T,S,W-3(@,#(T,#$W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````4````%`@#````
MNE?M/P````E03%1%````____````<\:#<0````-T4DY3_P``1.[P,P```:])
M1$%4>`$!I`%;_@`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!
M`0$!`0$!`0`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!
M`0$!`0`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!
M`0`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!
M`0$!`0$!`0$!`0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!``$`
M`0`!``$``0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!
M`0$!`0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!
M`0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0`!
M`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0`!`0$!
M`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`3U)`8*<4[F3`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M=')E92]P;'5S+G!N9P``````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#`S-C<@,3`U,34T,S,W-3(@,#(S,C8S`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````4````
M%`@#```!S5#=J0````1G04U!``"OR#<%BND````9=$58=%-O9G1W87)E`$%D
M;V)E($EM86=E4F5A9'EQR64\````"5!,5$60D)````#___^)`$\A`````W12
M3E/__P#7R@U!````94E$051XVF)@8F1B@&*``&)@8F(``B8F@``"(D8@FXF!
MD8$)(("`;"80&SL)$$!@DA'&9(!H!S,9&1G!&$44IA8@@"":\3.ANM`5,#(2
MKQ8*``(,B4FV(`.:"K@@(]&"V&@RG00`0)8"T.<*"_8`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O9F]L9&5R
M;W!E;BYP;F<`````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,S4U(#$P-3$U
M-#,S-S4R(#`R-#0S,P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,`
M``&`4$Q41?WSU/WVW/OHN7-8(Z**5,:50L2YH\2,/??MUL:\I[JEBN#!AX=O
M/=BL4_/OY^C4H?+4DOCAJ*F38<K`K9A\4IR"2>#3K]O3PJ64;\RM7OKDL*6-
M6,:60>ODU9F#5/OKO_C:>ZR69H%I,\[!IN#(A8UL-/7MV??KR]ZW;>[@OKJH
M@IF%6?3:HL61/X9M.MJM7_3FP.'4L-#%K>/"?]FO89ET,Z^:;/;<C?_Z[<*0
M.__RR?_VW/SEEOO>?OWJL/WPR_SLPGM4(J"&3_______________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M_________________________________________P1"A,4```"`=%).4___
M____________________________________________________________
M____________________________________________________________
M______________________________________________\`.`5+9P````%B
M2T=$?TB_<>4````)<$A9<P```$@```!(`$;):SX```!Z241!5!C38ZA'`PR8
M`LP@@"3`;,C(R"C&C"2@S@`$S'!U#,SV<&#`#!9P0`"(`!.3L8PE!#@"M3$P
M2^FP<EA`@!J?.`\#LZ`)MS44:,HR`[4(Z,I;00&_,DA`7\,.!E2808:RF]O`
M@"1(0)77%@84P-;6.R(`,S;?`@"T34;?=EBG0@````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O
M8FQA;FLN<&YG````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,C8R
M(#$P-3$U-#,S-S4R(#`R,S,V,0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````%````!0(`P``
M`<U0W:D````$9T%-00``K\@W!8KI````&71%6'13;V9T=V%R90!!9&]B92!)
M;6%G95)E861Y<<EE/`````903%1%____````5<+3?@````%T4DY3`$#FV&8`
M```E241!5'C:8F!``(``@B.``$)&``&$'P$$$)D(((#HBP`";/@A``&V``'T
MA:V%`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+W!L=7-B;W1T;VTN
M<&YG```````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#,V-"`Q,#4Q-30S,S<U
M,B`P,C0U,#4`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```!0````4"`,```'-4-VI````!&=!
M34$``*_(-P6*Z0```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')
M93P````)4$Q419"0D````/___XD`3R$````#=%).4___`-?*#4$```!B241!
M5'C:8F!B9&(`8R8F@``"8@8@8&("""`@8@2RF1@8&9@``@@DP<2$BP0((##)
M"&,R0+2#F8R,C&",(@H#``%$#!.J"UT!(R/Q:J$`(,"0F&0+,J"I@`LR$BV(
MC2;320!#B`+2HT1%BP````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O=')E92]R978M;6EN=7-O;FQY+G!N9P``````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#$P,C`@,3`U,34T,S,W-3(@,#(U,3$R`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````4````%`@#````NE?M/P````Q03%1%D)"0````____
M````L2^FA@````1T4DY3__\``-,.5(8```&O241!5'@!`:0!6_X``@("`@("
M`@("`@("`@("`@("`@(``@("`@("`@("`@("`@("`@("`@(``@("`@("`@("
M`@("`@("`@("`@(``@("`@("`@("`@("`@("`@("`@(``@("`@("`@("`@("
M`@("`@("`@(``@("`@("`@("`@("`@("`@("`@(``@("`@("`@``````````
M``("`@(``@("`@("`@`"`@("`@("``("`@(``@("`@("`@`"`@("`@("``("
M`@(``@("`@("`@`"`@("`@("``("`@(``@$"`0(!`@`"`0$!`0$"``("`@(`
M`@("`@("`@`"`@("`@("``("`@(``@("`@("`@`"`@("`@("``("`@(``@("
M`@("`@`"`@("`@("``("`@(``@("`@("`@````````````("`@(``@("`@("
M`@("`@("`@("`@("`@(``@("`@("`@("`@("`@("`@("`@(``@("`@("`@("
M`@("`@("`@("`@(``@("`@("`@("`@("`@("`@("`@(``@("`@("`@("`@("
M`@("`@("`@):.@+9<[_KM@````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]R978M:F]I;F)O='1O;2UD
M;W=N+G!N9P``````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$P,C0@,3`U,34T,S,W-3(@,#(V
M,C$R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````4````%`@#````NE?M/P````]03%1%````
M____````````````@FO25@````5T4DY3_P`````(#\$]```!KTE$051X`0&D
M`5O^``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!
M``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!
M`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!
M`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!
M`0$!`0$!`0$!`0$!``$``0`!``$``0`!``$!`0$!`0$!``$!`0$!`0$!`0$!
M`0$!`0$!`0$!``$!`0$!`0$!`0$!``$!`0$!`0$!``$!`0$!`0$!`0$!`0$!
M`0$!`0$!``$!`0$!`0$!`0$!``$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!
M`0$!``$!`0$!`0$!`0$!``$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!
M``$!`0$!`0$!`0$!``$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!
M`0$!`0$!`0$!``$!`0$!`0$!0L(!AKX,7;,`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]L96%F+G!N9P``
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`S,S`@,3`U,34T,S,W
M-3(@,#(S,3<U`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````0````$`0#````[=WB4@```!A0
M3%1%;FUUDY&<S\S8____````____````````P6/*8@````%T4DY3`$#FV&8`
M```!8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8````!W1)344'U`P4
M$RTP1V.N.@```#E)1$%4>-IC8&!@<'%Q<0!2#"R.2HI@AI.3L1&(P:(,9;BX
M0!F.2DH0AI.Q,24,H#D0NUQ<8+9#```]9Q)<"+6@@P````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+W1R964O:F]I;F)O='1O;2UD;W=N+G!N9P``
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`P,34W(#$P-3$U-#,S-S4R(#`R-30R-@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````%````!0!`P```+='CTX````&4$Q410```/___Z79
MG]T````"=%).4_\`Y;<P2@```!9)1$%4&%=C_,_PD9$D'/8;0C<48J,!'\`G
M-;KQEU\`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]T<F5E+W)E=BUP;'5S;VYL>2YP;F<`````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,3`R,"`Q,#4Q-30S,S<U,B`P,C0W-#(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!0````4"`,```"Z5^T_````#%!,5$60D)````#___\```"Q+Z:&````
M!'123E/__P``TPY4A@```:])1$%4>`$!I`%;_@`"`@("`@("`@("`@("`@("
M`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("`@("
M`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"
M`@("`@("`@("`@("`@("`@("`@`"`@("`@("`````````````@("`@`"`@("
M`@("``("`@("`@(``@("`@`"`@("`@("``("`@$"`@(``@("`@`"`@("`@("
M``("`@$"`@(``@("`@`"`0(!`@$"``(!`0$!`0(``@("`@`"`@("`@("``("
M`@$"`@(``@("`@`"`@("`@("``("`@$"`@(``@("`@`"`@("`@("``("`@("
M`@(``@("`@`"`@("`@("`````````````@("`@`"`@("`@("`@("`@("`@("
M`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("`@("
M`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("`@("`E<B
M`M6#^,CP`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]T<F5E+VYU;&QO;FQY+G!N9P``````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#,T-"`Q,#4Q-30S,S<U,B`P,C0Q-#<`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!0````4"`,```'-4-VI````!&=!34$``*_(-P6*Z0```!ET
M15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P````)4$Q410```)"0
MD/____+]'R4````#=%).4___`-?*#4$```!2241!5'C:8F!B8F*`8H```F(&
M1D8@"1!`(`Y(B!$(`0((QL9.`@00A(0Q&4$`R@12C`Q`@"(*`P`!1`P3JHN)
M<K4``8;$)%N0$<IAI*(@^4X"`'#!`OM%&R<2`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O=')E92]J;VEN8F]T=&]M+G!N9P``````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`S,#,@,3`U,34T,S,W-3(@,#(T-#4R`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````4
M````%`@#```!S5#=J0````1G04U!``"OR#<%BND````9=$58=%-O9G1W87)E
M`$%D;V)E($EM86=E4F5A9'EQR64\````!E!,5$4```#___^EV9_=`````G12
M3E/_`.6W,$H````U241!5'C:8F!D@$)&1H```F((`@@@.`("@`#"3P($$`,>
M)@0PP@$2$R"`Z,L$"#`DYC`1!``^<0&&@DF8,P````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O<F5V
M+6QI;F4N<&YG````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,#$T(#$P
M-3$U-#,S-S4R(#`R-#`P-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````%````!0(`P```+I7
M[3\````)4$Q410```/___P```'/&@W$````#=%).4_\``$3N\#,```&O241!
M5'@!`:0!6_X``0$!`0$!`0$!`0$``0$!`0$!`0$``0$!`0$!`0$!`0$!`0$!
M`0$!`0$``0$!`0$!`0$!`0$``0$!`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!
M`0$``0$!`0$!`0$!`0$``0$!`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$`
M`0$!`0$!`0$!`0$``0$!`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$``0$!
M`0$!`0$!`0$``0$!`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$``0$!`0$!
M`0$!`0$``0$!`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$``0$!`0$!`0$!
M`0$``0$!`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$``0$!`0$!`0$!`0$`
M`0$!`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$``0$!`0$!`0$!`0$``0$!
M`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$``0$!`0$!`0$!`0$``0$!`0$!
M`0$``0$!`0$!`0$!`0$!`0$!`0$!`0%!10&'U?'8@0````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R
M964O<F5V+6UI;G5S8F]T=&]M+G!N9P``````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q
M,#(P(#$P-3$U-#,S-S4R(#`R-30S-0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````%````!0(
M`P```+I7[3\````,4$Q419"0D````/___P```+$OIH8````$=%).4___``#3
M#E2&```!KTE$051X`0&D`5O^``("`@("`@("`@("`0("`@("`@("``("`@("
M`@("`@("`@("`@("`@("``("`@("`@("`@("`0("`@("`@("``("`@("`@("
M`@("`@("`@("`@("``("`@("`@("`@("`0("`@("`@("``("`@("`@("`@("
M`@("`@("`@("``("`@("`@(````````````"`@("``("`@("`@(``@("`@("
M`@`"`@("``("`@("`@(``@("`@("`@`"`@("``("`@("`@(``@("`@("`@`"
M`@("``(!`@$"`0(``@$!`0$!`@`"`@("``("`@("`@(``@("`@("`@`"`@("
M``("`@("`@(``@("`@("`@`"`@("``("`@("`@(``@("`@("`@`"`@("``("
M`@("`@(````````````"`@("``("`@("`@("`@("`@("`@("`@("``("`@("
M`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("
M`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("5?`"UF*5DUX`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+W1R964O<F5V+7!L=7,N<&YG````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`Q,#(P(#$P-3$U-#,S-S4R(#`R-#`T,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M%````!0(`P```+I7[3\````,4$Q419"0D````/___P```+$OIH8````$=%).
M4___``#3#E2&```!KTE$051X`0&D`5O^``("`@("`@("`@("`0("`@("`@("
M``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`0("`@("`@("``("
M`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`0("`@("`@("``("`@("
M`@("`@("`@("`@("`@("``("`@("`@(````````````"`@("``("`@("`@(`
M`@("`@("`@`"`@("``("`@("`@(``@("`0("`@`"`@("``("`@("`@(``@("
M`0("`@`"`@("``(!`@$"`0(``@$!`0$!`@`"`@("``("`@("`@(``@("`0("
M`@`"`@("``("`@("`@(``@("`0("`@`"`@("``("`@("`@(``@("`@("`@`"
M`@("``("`@("`@(````````````"`@("``("`@("`@("`@("`@("`@("`@("
M``("`@("`@("`@("`0("`@("`@("``("`@("`@("`@("`@("`@("`@("``("
M`@("`@("`@("`0("`@("`@("``("`@("`@("`@("`@("`@("`@("4G("T,D.
MHAT`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+W1R964O<F5V+7!L=7-B;W1T;VTN<&YG````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`Q,#(P(#$P-3$U-#,S-S4R(#`R-3(V-0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````%````!0(`P```+I7[3\````,4$Q419"0D````/___P```+$OIH8`
M```$=%).4___``#3#E2&```!KTE$051X`0&D`5O^``("`@("`@("`@("`0("
M`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`0("`@("
M`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`0("`@("`@("
M``("`@("`@("`@("`@("`@("`@("``("`@("`@(````````````"`@("``("
M`@("`@(``@("`@("`@`"`@("``("`@("`@(``@("`0("`@`"`@("``("`@("
M`@(``@("`0("`@`"`@("``(!`@$"`0(``@$!`0$!`@`"`@("``("`@("`@(`
M`@("`0("`@`"`@("``("`@("`@(``@("`0("`@`"`@("``("`@("`@(``@("
M`@("`@`"`@("``("`@("`@(````````````"`@("``("`@("`@("`@("`@("
M`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("
M`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("
M4M@"TM??/=X`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+W1R964O;6EN=7,N<&YG````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`P,S8Q(#$P-3$U-#,S-S4R(#`R,S0R-0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````%````!0(`P```<U0W:D````$9T%-00``K\@W!8KI````
M&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/`````E03%1%D)"0
M````____B0!/(0````-T4DY3__\`U\H-00```%])1$%4>-IB8&)D8F!B`F)&
M)H```M(,0,#$!!!`0,0($@)!@``"23(QX2(!`@A,,L*8#!#M8"8C(R,8HXC"
MU`($$$0S?B94%[H"1D;BU4(!0(`A,<D69$!300U!\IT$`$2S`M1_5K1<````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]T<F5E+VUI;G5S=&]P+G!N9P``````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#,U-B`Q,#4Q-30S,S<U,B`P,C0Q-30`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!0````4"`,```'-4-VI````!&=!34$``*_(-P6*Z0```!ET15AT4V]F='=A
M<F4`061O8F4@26UA9V5296%D>7')93P````)4$Q419"0D````/___XD`3R$`
M```#=%).4___`-?*#4$```!<241!5'C:8F!B8F(`8T8F@``"T@Q`P,0$$$`@
M`9`0"`($$(R-G00((`@)8S)`M(.9C(R,8(PBR@2T!00``@A5&W8F5!>Z`D9&
MXM5"`4"`(3')%F1`4T$-0?*=!`!)=P+74$-!I`````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]M
M:6YU<V]N;'DN<&YG````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`S-#8@
M,3`U,34T,S,W-3(@,#(T,S,R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````4````%`@#```!
MS5#=J0````1G04U!``"OR#<%BND````9=$58=%-O9G1W87)E`$%D;V)E($EM
M86=E4F5A9'EQR64\````"5!,5$60D)````#___^)`$\A`````W123E/__P#7
MR@U!````5$E$051XVF)@8F)B@&*```)B!B!@8@(((!`')`2"``$$8V,G`0((
M0L*8#!#M8"8C(R,8HXC"`$``$<.$ZD)7P,A(O%HH``@P)";9@@QH*J@A2+Z3
M`$QI`MEE7OS0`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O:F]I;BYP;F<`````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,S`U(#$P-3$U-#,S-S4R
M(#`R,S(R-P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````%````!0(`P```<U0W:D````$9T%-
M00``K\@W!8KI````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE
M/`````903%1%````____I=F?W0````)T4DY3_P#EMS!*````-TE$051XVF)@
M9(!#@`!B8&2$((``0D8``01$C&`&5A(@@!CP,"$`JP*``(*0]&("!!@2<Y@(
M`@`XE@&"^PI?*P````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]T<F5E+VUI;G5S8F]T=&]M+G!N9P``````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#,U-"`Q,#4Q-30S,S<U,B`P,C0V-30`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!0````4"`,```'-4-VI````!&=!34$``*_(-P6*Z0``
M`!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P````)4$Q419"0
MD````/___XD`3R$````#=%).4___`-?*#4$```!:241!5'C:8F!B9&)@8@)C
M@``"8@8@8&("""`@8@0)@2!``($D(-+82(```I.,,"8#1#N8R<C(",8HHC``
M$$#$,*&ZT!4P,A*O%@H``@R)2;8@`YH*:@B2[R0`1Z4"UKSZI,<`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O=')E92]R978M;&5A9BYP;F<`````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`S,C<@,3`U,34T,S,W-3(@,#(S-S<U`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```0````$`0#````[=WB4@```!A03%1%;FUUDY&<S\S8____````____````
M````P6/*8@````%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3
M```+$P$`FIP8````!W1)344'U`P4$RX`2I?-50```#A)1$%4>-IC8&!Q<7%A
M``$6(241!S!#V5A%!<8P<H`RP*J`#"4E$0C#V%B%?(:0$M0<%Q>8_6```*'Y
M#,L$!T:]`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O
M<F5V+6IO:6YB;W1T;VTN<&YG````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,#$T
M(#$P-3$U-#,S-S4R(#`R-3(T-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````%````!0(`P``
M`+I7[3\````)4$Q410```/___P```'/&@W$````#=%).4_\``$3N\#,```&O
M241!5'@!`:0!6_X``0$!`0$!`0$!`0$``0$!`0$!`0$``0$!`0$!`0$!`0$!
M`0$!`0$!`0$``0$!`0$!`0$!`0$``0$!`0$!`0$``0$!`0$!`0$!`0$!`0$!
M`0$!`0$``0$!`0$!`0$!`0$``0$!`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!
M`0$``0$!`0$!`0$!`0$``0$!`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$`
M`0$!`0$!`0$!`0$``0$!`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$``0`!
M``$``0`!``$``0$!`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$``0$!`0$!
M`0$!`0$!`0$!`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$``0$!`0$!`0$!
M`0$!`0$!`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$``0$!`0$!`0$!`0$!
M`0$!`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$``0$!`0$!`0$!`0$!`0$!
M`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$^O0&&0*1ND0````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+W1R964O9F]L9&5R+G!N9P``````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`Q,C<P(#$P-3$U-#,S-S4R(#`R,S4T-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$```
M`!`(`P```"@M#U,```&`4$Q41?WSU/WVW***5/KDL+^$.\*-.G9;)+^(.O?K
MR^SFVJR69L:4/N7<R_?=G_3FP/OHN?SVYJ^:;//0@_#DQMW">;ZQF.7.E.'4
ML/SLPOG;>LF[H-"^F[^%.\"*._;NWN/#@JZ??Z6-6)^'4-?)K/;9EN#3K\^M
M5<.0/-_3O8QK-'=5(NWGW<BRB*F38<&+.[JH@M>X8?G;>_76C-#%K?CAJ.K9
MK/O=?7-8(__[\<.1._SCD/[WY/SIJO[OP?_UTWM4(OWPRZ"&3____P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````%*X
M3_X```!#=%).4_______________________________________________
M_________________________________________P!!8@3O`````6)+1T1_
M2+]QY0````EP2%ES````2````$@`1LEK/@```())1$%4&--ES]<:P4`00.'=
MZ#U!=$%$%YWH:[S_0YDA@R\YE__=$<]`(@QI`'#_8%F54@Z,'_22`@-*VQ+`
MXUM>>T.MDSGYJ;B)4!CI1S]KYB%$8A>NE"+8+>[</DN0:]^XRIC`25RY<I]@
MTSISJR:"78S6#Y_6PSE"`R:*FWK=\.T+K[DUCU88@X$`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+W1R964O<F5V+6YU;&QO;FQY+G!N9P``````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`Q,#(P(#$P-3$U-#,S-S4R(#`R-#<S,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````%````!0(`P```+I7[3\````,4$Q410```)"0D/___P```,^1W=0````$
M=%).4___``#3#E2&```!KTE$051X`0&D`5O^``("`@("`@("`@("`@("`@("
M`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("
M``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("``("
M`@("`@("`@("`@("`@("`@("``("`@("`@(!`0$!`0$!`0$"`@("``("`@("
M`@(!`@("`@("`@$"`@("``("`@("`@(!`@("`@("`@$"`@("``("`@("`@(!
M`@("`@("`@$"`@("``(``@`"``(!`@("`@("`@$"`@("``("`@("`@(!`@("
M`@("`@$"`@("``("`@("`@(!`@("`@("`@$"`@("``("`@("`@(!`@("`@("
M`@$"`@("``("`@("`@(!`0$!`0$!`0$"`@("``("`@("`@("`@("`@("`@("
M`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("
M``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("=&X"
M^Y064:@`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+W1R964O<F5V+6UI;G5S+G!N9P``````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`Q,#(P(#$P-3$U-#,S-S4R(#`R-#(Q,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````%````!0(`P```+I7[3\````,4$Q419"0D````/___P```+$O
MIH8````$=%).4___``#3#E2&```!KTE$051X`0&D`5O^``("`@("`@("`@("
M`0("`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`0("
M`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`0("`@("
M`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@(````````````"`@("
M``("`@("`@(``@("`@("`@`"`@("``("`@("`@(``@("`@("`@`"`@("``("
M`@("`@(``@("`@("`@`"`@("``(!`@$"`0(``@$!`0$!`@`"`@("``("`@("
M`@(``@("`@("`@`"`@("``("`@("`@(``@("`@("`@`"`@("``("`@("`@(`
M`@("`@("`@`"`@("``("`@("`@(````````````"`@("``("`@("`@("`@("
M`@("`@("`@("``("`@("`@("`@("`0("`@("`@("``("`@("`@("`@("`@("
M`@("`@("``("`@("`@("`@("`0("`@("`@("``("`@("`@("`@("`@("`@("
M`@("58H"U/'-.:T`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+W1R964O<&QU<V]N;'DN<&YG````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`P,S8R(#$P-3$U-#,S-S4R(#`R-#$V,``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````%````!0(`P```<U0W:D````$9T%-00``K\@W!8KI
M````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/`````E03%1%
MD)"0````____B0!/(0````-T4DY3__\`U\H-00```&!)1$%4>-IB8&)B8F!B
M!&(F)H```F(&(&!B`@@@$`<DS,#(P`000#`V=A(@@"`DC,D`T0YF,C(R@C&*
M*`P`!!`Q3*@N=`6,C,2KA0*``$-BDBW(@*8"+LA(M"`VFDPG`0!(3`+5@:.2
M``````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]T<F5E+W)E=BUP;'5S=&]P+G!N9P``````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,3`R,"`Q,#4Q-30S,S<U,B`P,C0U-C,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!0````4"`,```"Z5^T_````#%!,5$60D)````#___\```"Q+Z:&````
M!'123E/__P``TPY4A@```:])1$%4>`$!I`%;_@`"`@("`@("`@("`@("`@("
M`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("`@("
M`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"
M`@("`@("`@("`@("`@("`@("`@`"`@("`@("`````````````@("`@`"`@("
M`@("``("`@("`@(``@("`@`"`@("`@("``("`@$"`@(``@("`@`"`@("`@("
M``("`@$"`@(``@("`@`"`0(!`@$"``(!`0$!`0(``@("`@`"`@("`@("``("
M`@$"`@(``@("`@`"`@("`@("``("`@$"`@(``@("`@`"`@("`@("``("`@("
M`@(``@("`@`"`@("`@("`````````````@("`@`"`@("`@("`@("`@("`@("
M`@("`@`"`@("`@("`@("`@$"`@("`@("`@`"`@("`@("`@("`@("`@("`@("
M`@`"`@("`@("`@("`@$"`@("`@("`@`"`@("`@("`@("`@("`@("`@("`E:\
M`M,!FKD#`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]T<F5E+W)E=BUM:6YU<W1O<"YP;F<`````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,3`R,"`Q,#4Q-30S,S<U,B`P,C0W,S,`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!0````4"`,```"Z5^T_````#%!,5$60D)````#___\```"Q
M+Z:&````!'123E/__P``TPY4A@```:])1$%4>`$!I`%;_@`"`@("`@("`@("
M`@("`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("
M`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("
M`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`````````````@("
M`@`"`@("`@("``("`@("`@(``@("`@`"`@("`@("``("`@("`@(``@("`@`"
M`@("`@("``("`@("`@(``@("`@`"`0(!`@$"``(!`0$!`0(``@("`@`"`@("
M`@("``("`@("`@(``@("`@`"`@("`@("``("`@("`@(``@("`@`"`@("`@("
M``("`@("`@(``@("`@`"`@("`@("`````````````@("`@`"`@("`@("`@("
M`@("`@("`@("`@`"`@("`@("`@("`@$"`@("`@("`@`"`@("`@("`@("`@("
M`@("`@("`@`"`@("`@("`@("`@$"`@("`@("`@`"`@("`@("`@("`@("`@("
M`@("`EG4`M<!_K*L`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+VQI;F4N<&YG````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#,P,2`Q,#4Q-30S,S<U,B`P,C,R,3,`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!0````4"`,```'-4-VI````!&=!34$``*_(-P6*
MZ0```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P````&4$Q4
M10```/___Z79G]T````"=%).4_\`Y;<P2@```#-)1$%4>-IB8&2`0X``8F!D
MA""``$)&``$$1(Q@!E82((`8R&,"!!"$I!<3(,"0F,-$$``_4P&'P_V4C0``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O=')E92]P;'5S=&]P+G!N9P``````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`S-C4@,3`U,34T,S,W-3(@,#(T,#`T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````4````%`@#```!S5#=J0````1G04U!``"OR#<%BND````9=$58=%-O
M9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\````"5!,5$60D)````#___^)
M`$\A`````W123E/__P#7R@U!````8TE$051XVF)@8F)B8&($8X``8@`R@8")
M"2"`@`@LS,#(P`000#`V=A(@@"`DC,D`T0YF,C(R@C&**!/0%A``""!4;=B9
M4%WH"A@9B5<+!0`!AL0D6Y`!305<D)%H06PTF4X"`$5:`M,U"7%F`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VYA
M=@``````````````````````````````````````````````````````````
M`````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M,#`P(#$P-3$U-#,S-S4R(#`R,3,S,@`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O;F%V+V)O='1O;2YP;F<`````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`T-S<@,3`U,34T,S,W-3(@,#(S-#,S`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````0````$`@#````*"T/4P```%103%1%````"`T1*D-;,U)N
M-UEX/V6(16^6272<3'FC4("M6XBR7XNT9Y&XD;#,E;+.E[/.FK7/F[;0G+?1
MGKC1H+K3I+W5K\7:LL?;M<G<MLK=OM#A````%+0D>`````%T4DY3`$#FV&8`
M```!8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8````!W1)344'U`P4
M$2X,0*55$````&1)1$%4>-IMC5D.@"`,1.M2]P4*+LC][VG1B"7ZOCHODPX`
MXV\@XG<]UI44JS582K&12H7["*U?$?X[12R>(=^9Q1(BYK'3$I'(P<Q69H"L
MGY+,G2;-;,0IN<3!&S3P+!;^IW$"Q/H)S<'Z7PP`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+VYA=B]D;W=N+6=R97DN<&YG````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P-#4P(#$P-3$U-#,S-S4R(#`R-#`S,0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M$````!`(`P```"@M#U,```!(4$Q410```%-34W=W=X6%A8V-C924E)>7EYJ:
MFI^?GZ6EI:>GI\/#P\3$Q,;&QL?'Q\C(R,G)R<O+R\W-S=/3T]75U=;6UM?7
MUTM+2[5P#O4````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+
M$P``"Q,!`)J<&`````=T24U%!]0,%!$Q`?-.)S,```!9241!5'C:8V`@"HA#
M`)*`*#\W&RNR@+"@``LSLH"(`!^J@!B&`#\_0@!DOA@?R`R81>*<`D)`0UE8
MF.!J.`0$!)#X(!%>060^`P,C%P\*'ZB&71S=.S@]"@`/C05M$J,=MP````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]N878O;&%S
M="UG<F5Y+G!N9P``````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#4P,R`Q
M,#4Q-30S,S<U,B`P,C0P,C0`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H
M+0]3````45!,5$4```134U-W=W>!@8&%A86-C8V4E)27EY>:FIJ?GY^EI:6G
MIZ>LK*S#P\/$Q,3&QL;'Q\?(R,C)R<G+R\O-S<W3T]/5U=76UM;7U]?;V]M+
M2TMSECH$`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,`
M``L3`0":G!@````'=$E-10?4#!01,BWJNQ@3````:TE$051XVGV/VPZ#(!!$
MT8HM7F%H%>?_/U1@H0^F]B1D=T[V85#J-RR#K$(6'E\QY(U@NDK`L(K]LX40
MWC!-$<X#SGJL(T7,L-8!\,N+G*)XZD(;@XZO[Q(YBQ!RSJ+T:*6'OC9]\.XO
M?S@!A6H)@?X`Z3X`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;F%V+VQE9G0M9W)E>2YP;F<`
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`T-#(@,3`U,34T,S,W-3(@
M,#(T,#$U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P```$503%1%
M````:6EI=G9V=W=W>GIZ@8&!C8V-EY>7F9F9K*RLQ\?'R,C(R<G)RLK*R\O+
MS,S,S<W-SL[.T-#0T='1T]/3W]_?2TM+!6U78`````%T4DY3`$#FV&8````!
M8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8````!W1)344'U`P4$3,0
MJ\AE0P```%9)1$%4>-J%CTD2@#`(!..^!$1-PO^?*E$X&$OMVW11##CW`I>Y
M$)RXR,07EK<]Q!!I8LVP$GJ/\W"**N$"`"B,.M'T2F<[Q-29UKK$W%JR^;OT
M^<L'!QWK!4V>PL-)`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+VYA=B]D;W=N+G!N9P``````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`P-#4T(#$P-3$U-#,S-S4R(#`R,S`W,0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$````!`(`P```"@M#U,```!+4$Q4104`"@@-$2I#6S=9
M>#]EB$5OEDETG$QYHU"`K5N(LE^+M)&PS)6RSI>SSIJUSYNVT)RWT9ZXT:"Z
MTZ2]U:_%VK+'V[7)W+;*W0```(9?Z@<````!=%).4P!`YMAF`````6)+1T0`
MB`4=2`````EP2%ES```+$P``"Q,!`)J<&`````=T24U%!]0,%!$P$QGL9SH`
M``!:241!5'C:8V`@"DA``)*`&#\W&RNR@(B0(`LSLH"H`!^J@#B&`#\_0@!D
MOCB?`%``9I$$IZ"PD``+"PL37`V'@(``$A\DPBN$S&=@8.3B0>$#U;!+H'L'
MIT<!*N<%G#41(%\`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]N878O9FER<W0M9W)E>2YP;F<`````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#0V-2`Q,#4Q-30S,S<U,B`P,C0R,3<`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!`````0"`,````H+0]3````2%!,5$4```!I:6EV=G9W=W=Z>GJ!@8&-C8V7
MEY>9F9FLK*S'Q\?(R,C)R<G*RLK+R\O,S,S-S<W.SL[0T-#1T='3T]/;V]O?
MW]]+2TM"F7`E`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``
M"Q,```L3`0":G!@````'=$E-10?4#!01,@RFT@A-````9DE$051XVH6/V0[`
M(`@$[:$]Q-J3_?\_K8J:U)=.0@+#`XM2+0!R4\2#O"B"4@?^"K"'(`)\G-=]
MW7X1`:;=.VO=.H5A0<=N(R(7F(,PH0:3T2*2Z2-C%M'4*T9R##6';I.VO_SR
M`NZ."&10MEC>`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;F%V+W)I
M9VAT+6=R97DN<&YG````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`T-#<@
M,3`U,34T,S,W-3(@,#(T,C`U`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````0````$`@#````
M*"T/4P```$A03%1%````4U-3=W=WA86%C8V-E)24EY>7FIJ:GY^?I:6EIZ>G
MP\/#Q,3$QL;&Q\?'R,C(R<G)R\O+S<W-T]/3U=75UM;6U]?72TM+M7`.]0``
M``%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8
M````!W1)344'U`P4$3,J;<2\\0```%A)1$%4>-J-CED.@"`,1.N.6QE<VOO?
MU(B`"6KB^YO72:9$7^A#Y$9[O6\>F&AT7S<166"*(*P#+#O,P]71$<P6@)LZ
M;[2M`V5H--5)RG$EY;B5Y9=/Z2\'+RT%;2>JT]4`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VYA=B]R:6=H="YP;F<`````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P-#4S(#$P-3$U-#,S-S4R
M(#`R,S(S-@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,```!+4$Q4
M104`"@@-$2I#6S=9>#]EB$5OEDETG$QYHU"`K5N(LE^+M)&PS)6RSI>SSIJU
MSYNVT)RWT9ZXT:"ZTZ2]U:_%VK+'V[7)W+;*W0```(9?Z@<````!=%).4P!`
MYMAF`````6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<&`````=T24U%
M!]0,%!$S&DL=C%T```!9241!5'C:C8Y9#H`@#$1QQXT.N+3W/ZD1`1/4Q/<W
MKY-,E?I"'B(WTLM]\U@=C>SKQLP+=!$$.8",PSQ<'1FM,03`39TWTM:!,C2:
MZB3EN))RW,KRRZ?J+P=*]P6<F9:-H@````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]N878O;&5F="YP;F<`````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#0U-"`Q,#4Q-30S,S<U,B`P,C,P-30`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!`````0"`,````H+0]3````3E!,5$4````<+3TI0EHJ
M0ULM1V`T4V\_98A)=9Y+>*)HDKF:M<^;MM"<M]&>N-&?N=*@NM.CO-2DO=6F
MOM6JP=>KPMBNQ-FOQ=K$U./%U>0````HJ"[J`````7123E,`0.;89@````%B
M2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-10?4#!01,C9@
MWM'_````5TE$051XVF-@P`$DT?EH`I+BDFA\`4D(@/&%A$7$1$0%."6A?!Y!
M`3YN;CXN=K``HP0?/R\O#Q\0<$!5,+-!`2O,#*`($PBPP.P"BJ#8`A(AY%),
MO^`!`&W]!=8#5?25`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O;F%V+V)O='1O;2UG<F5Y+G!N9P``````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`T-S,@,3`U,34T,S,W-3(@,#(T,S<S`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```0````$`@#````*"T/4P```%%03%1%```%4U-3=W=W@8&!A86%C8V-E)24
MEY>7FIJ:GY^?I:6EIZ>GK*RLP\/#Q,3$QL;&Q\?'R,C(R<G)R\O+S<W-T]/3
MU=75UM;6U]?7V]O;2TM+.&]-50````%T4DY3`$#FV&8````!8DM'1`"(!1U(
M````"7!(67,```L3```+$P$`FIP8````!W1)344'U`P4$2\X>`J0Y````&-)
M1$%4>-IMC5<.@#`,0\,(>[0IH^3^!R4%45*!O^PGRP80\2V(XMV.=:7!Z@A+
M#38R*?`?8.T+PKXW8>,YXHX6&47,8Z<E(I4#F9W.`%D_)5DZ39J%**MU@4,^
M:)!;+/BG<0*@:PF!S%;@'0````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VYA=B]T
M;W`N<&YG````````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P-#<T
M(#$P-3$U-#,S-S4R(#`R,C<R-@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````$````!`(`P``
M`"@M#U,```!74$Q410```!PM/2E"6BI#6RU'8#-2;C13;S]EB$EUGDMXHF>1
MN&B2N9JUSYNVT)RWT9ZXT9^YTJ"ZTZ.\U*2]U::^U:K!UZO"V*[$V:_%VK[0
MX<34X\75Y````)8R$A8````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP
M2%ES```+$P``"Q,!`)J<&`````=T24U%!]0,%!$S,PFO%#$```!>241!5'C:
M7<])#H`P"$!1''&L6.?*_<\IIC%2_HX74E(`UH'$EY,ZE*H(=B.601K?G,Z!
M"DYF-Z,2#NLRX2\<_.8%/GFO[>0P5V?Y'$E`/;I;.,B`'PST35N7&M3/'OWL
M"AQL[V(>`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]N878O=7`N<&YG````````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#0U-"`Q,#4Q-30S,S<U
M,B`P,C(U-#8`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````3E!,
M5$4````<+3TI0EHJ0ULM1V`T4V\_98A)=9Y+>*)HDKF:M<^;MM"<M]&>N-&?
MN=*@NM.CO-2DO=6FOM6JP=>KPMBNQ-FOQ=K$U./%U>0````HJ"[J`````712
M3E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'
M=$E-10?4#!01-!&3CL,2````5TE$051XVF-@P`$8T?B2$I*H?'$^9DD4/@\_
M&Y*(I+B0("\;0D127$!8`"@`$Y$$`A$^'C8F$`.F1HR;#RB`9*@(NH`H'YJ`
M`!>:`"<[!RL+L@`$,!`'``[-!=9^K>YR`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O;F%V+W5P+6=R97DN<&YG````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`T-#$@,3`U,34T,S,W-3(@,#(S-3`V`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````0````$`@#````*"T/4P```$503%1%````:6EI=G9V
M=W=W>GIZ@8&!C8V-EY>7F9F9K*RLQ\?'R,C(R<G)RLK*R\O+S,S,S<W-SL[.
MT-#0T='1T]/3W]_?2TM+!6U78`````%T4DY3`$#FV&8````!8DM'1`"(!1U(
M````"7!(67,```L3```+$P$`FIP8````!W1)344'U`P4$30B+%ZB!````%5)
M1$%4>-J-S-D.@"`,1-&ZU8U:%9C__U0QAHA-2+Q/S$D#4:7&;$28+1T^VVU<
M".*Q.WX%44]-D`4I+X[;^Y%OPBH)BD^]A2`&=#$PC]/0E_!$_[H`QWP%3?LQ
M$R,`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+VYA=B]T;W`M9W)E>2YP;F<`````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P-#4S(#$P-3$U-#,S-S4R(#`R,S8V-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````$````!`(`P```"@M#U,```!(4$Q410```&EI:79V=G=W=WIZ>H&!@8V-
MC9>7EYF9F:RLK,?'Q\C(R,G)R<K*RLO+R\S,S,W-S<[.SM#0T-'1T=/3T]O;
MV]_?WTM+2T*9<"4````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES
M```+$P``"Q,!`)J<&`````=T24U%!]0,%!$T"8#B6T0```!<241!5'C:7<_K
M#H`@"$!ANDA9D)4F[_^FT5H+.?_XQF0"B`TTN4B+J(47_,9;!VU2Q<T\2#/3
MAD:D'COA+U+3F10^>:YE)NS-62DK*YA'LX?"#M+B($YS&"V8G]WX/@ADH<52
ML@````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]N878O
M;&%S="YP;F<`````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#4P
M-2`Q,#4Q-30S,S<U,B`P,C,P-C(`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!`````0"`,`
M```H+0]3````5%!,5$4````(#1$J0ULS4FXW67@_98A%;Y9)=)Q,>:-0@*U;
MB+)?B[1GD;B1L,R5LLZ7L\Z:M<^;MM"<M]&>N-&@NM.DO=6OQ=JRQ]NUR=RV
MRMV^T.$````4M"1X`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9
M<P``"Q,```L3`0":G!@````'=$E-10?4#!01,A2UOI`;````:DE$051XVGV/
MR0Z`(`Q$<<%]@8(+SO__IT#1@U%?0MIYZ6$0XAVD`5R"%QRWZ.(&0K@*F!:7
MV-?-.;=0FR6A+9%6EN8>+$:CE"8B.S7`X$4M$[D/TK^J#,3,@HDYBM0CYQ[R
MV;3`UU]^.`&QB0G-5`N:OP````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;F%V+V9I<G-T+G!N9P``
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`U,#8@,3`U,34T,S,W
M-3(@,#(S,C0W`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P```%=0
M3%1%````'"T]*4):*D-;+4=@,U)N-%-O/V6(276>2WBB9Y&X:)*YFK7/F[;0
MG+?1GKC1G[G2H+K3H[S4I+W5IK[5JL'7J\+8KL39K\7:OM#AQ-3CQ=7D````
MEC(2%@````%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3```+
M$P$`FIP8````!W1)344'U`P4$3$6<)VB]````&A)1$%4>-J%C\D.@"`,1-UQ
MA8J*BO/_WRE2))&++VG2OAXZS;(4`*%YQ8FP>(7T'>Q7P&HP+&#7S1QFUP,+
M6+EHFB8:6S?TR"^:E9+DZ)P0KDH1:%AX4SQ403PF7A&<HXPYZC1I^LLO-_%,
M"AQ[;Z;K`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V-A;&5N9&%R+G!N9P``````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`R,3`T(#$P-3$U-#,S-S4R(#`R,S$P,0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````$````!`(`P```"@M#U,````$9T%-00``L8Y\^U&3
M````(&-(4DT``'HE``"`@P``^?\``(#I``!U,```ZF```#J8```7;Y)?Q48`
M``,`4$Q410```/______^/__^\O*P*FHH)64C<"_MY.2C)N:E*JHH;>UKK:T
MK?WZ\)22C)B6D?SX[[Z[M+NXL=+.QLG%OM+.Q_^X1IF6D:M-0?=:3,-02/CX
M^/'Q\>SL[.#@X-34U,/#PZ&AH8B(B'EY>6-C8TY.3C<W-S(R,AD9&?___P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'U:V4<````J=%).4_______________________________
M________________________`#*H\%P````)<$A9<P``"Q,```L3`0":G!@`
M``!X241!5"C/C8_9#H)0#$0[,NY;%8O7NB#*=?G_'U0P/$!,=![FX>1DTLJS
M$_D#2"MO\#@7Q>5:EC'&V[T"`N`(G(`<6H,#N2#'54\^1I*L@:'J5%F#O=G6
M;.?NUF\V9KVY9UEH&1Y":(SNAJ;I@%R2H\U*OEWZZ[D7"'H6YK_\T?8`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=&%B
M7V)O='1O;2YG:68`````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P
M-#4@,3`U,34T,S,W-3(@,#(S-#0U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````$=)1C@W810``0"``0````#___\L`````!0`
M`0```@2$CYD%`#L`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W!R969S+G!N9P``````
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P-C$V(#$P-3$U-#,S
M-S4R(#`R,C0U-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,```"*
M4$Q410`%`!T='1\G+RDI*3`P,#$Q,38V-DE'1E!03U)24DU?<VQI9VMJ:7)P
M;69YCW""E72*HHJ'A'B-I'V,G'R1IWV1IW^9LXV9I82>N82>NJ2AG+&QL<C'
MQLK(P=+0S-+1T-/2S]74T\_6W=;5U=C8V-O:U][;UM_>W./BX>OKZ.SKZO?W
M]_GX^````-V7S1D````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES
M```+$P``"Q,!`)J<&`````=T24U%!]0,"!(=!SN5O]8```!]241!5'C:;8Y9
M$H(P$`6#X!;W!7%'HX"@??_K239!R_G(]%2]2C\A_@T_P,G#P4-I@#LNQDM3
M%WN?X9EK)'+YRZ/(]@1AXZ@G'1!\B^G3ONAQ'#5M9FJ-X+;P)59JN>G4NYI8
M;:+F6VFTU[%9*MY)&R8=ZC>>2CZ_.T>[P!LEU0YF]_NU'P````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]M87`N<&YG````````````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#8Q,2`Q,#4Q-30S,S<U,B`P,C(Q,#8`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!`````0"`,````H+0]3````8%!,5$5D9%O__,VH
MIHC:V+3#P:+-RZS_^KW\]*B<F'2OJXJVLI%X=F/[[H[9T(J0BV?VXWS/QYGS
MWG3WYYW_TS?VSTGZV%?DKAKDMCO(EA[4HRG=KC6K?1:^C1Q</R5/3T\```"*
MA^0P````('123E/_________________________________________`%Q<
M&^T````!8DM'1!\%#1"]````"7!(67,```!(````2`!&R6L^````EDE$050H
MSTW/V1*#(`P%T*NR"$6I%.N"#?__EV5S6AX8SDUF2!#+X7[C]85R3VLG3_X+
MGFO7"7?P.R@6PNZ\!LG##(#LQ7)0ZL-(1&8)+*+V,Q#(&!\8?+8#U`1KEU?`
M)H60C![&3,GO#_3IA%0T&U.L$?7AY)B"ZORMWFU/<W,93%V++5;WZ"KXM;DM
MIT)R_[=M2IKC%QG?$\>,AA/?`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O;W)G86YI>FEN9RYP;F<`````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#$Q-C<@,3`U,34T,S,W-3(@,#(S-3`W`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````0````$`@#````*"T/4P```2Q03%1%````"0D)#`L*#@X.$Q(1$Q,3
M%Q<7&!@8&QL;'AX>(B(B1$1$55557U]?=&M,;6UM;FYN=75U=G9V@G=5>7EY
M?W]_@X%XAH1[B89^B(B(C8V-E)*+DY.3EI2,H95PFYN;G)R<HY^7KJ!TL*)X
MMJ=UJJB?J*BHNJETJZFAJZNKK*RLL:VDOJ]]M+"HM+*JM[>WW+QTP,#`Q,"X
MQ,&YR<6]QL;&R\>_ZLA[R\O+W<V8TL_(U-',U-+,U=+,V-;0UM;6V-?1W-S<
M\]Z:]-^=]>*DX>'A]N.G]^2LY.3DYN;BYN;FZ>GFZ>GIZNGGZ^KIZ^KJ[>SH
M[^[M\?'N\O'N\?'Q\O+R]//R]/3R]/3S]/3T]?3S]?7U]_?T]_?W^/CX_/S\
M_?W]_O[^____````4VW#%0````%T4DY3`$#FV&8````!8DM'1`"(!1U(````
M"7!(67,```L3```+$P$`FIP8````!W1)344'U`P4$38P[=&QS@```,1)1$%4
M>-I-C]=6PE`41`-!JC2E*DA'Z44@2I$2>A'I'0SS___`O0$6S.->^YPUPS#7
M`,Q]@&GJ#@$'0=A5@V<$5@YD9__"\5A^(>3ALZ))6Y#:'[I?U$"NLV#_,E8T
M$H#[$0SRZZ5JTHNQ0-!$#65INU.KGCY`$S(2XV>QF@\''KC:,(@_7@N_HW'1
MBC>.')DIL47B`:=,%^6@O?0`I'CV-HGAT$,$8=^[_[O.P7XICTV+YVL$7+>@
MS]$D%;=I$K&%*)P`OVTSN5"G3W$`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O;&]G:6XN<&YG````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`W-C(@,3`U,34T,S,W-3(@,#(R-#4P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````0````$`@#````*"T/4P```,!03%1%(2$AZM3+X\6ZV[2D
M[M[7^O?U\N7ATJR9````C9Y\S=G"WN;7VN+1FZV)MY."<'UCM,:BK,"88VY7
MJXIZY.G=97%8Q)^-P]&U@(]P3%1"6&-.YNO@U-W)RM>^D*%_7VI34UQ)Z>WD
M86U6J+R5?(MN3%1#ML*J7FE3____________________________________
M____________________________________________________________
M%^1TEP```$!T4DY3____________________________________________
M________________________________________`,)[L40````!8DM'1#\^
M8S!U````"7!(67,```!(````2`!&R6L^````?TE$050HSVV/21+",`P$)Q&@
MP0&#3-CW_1GZ_Z\X.%29%'V:ZE,/O`>*"90"J&H!"C$8CFKM!#.5J"*+<6@F
M4XI(S,(YFUNBB"X`=R?;8,M$T14<3K9A;9OMCC$"#NX/1[/3F1=V';R:V8U.
M?DO9W!]/ENE\)?Y^X;LGG'_?9C[CZR@-,)>5\P````!)14Y$KD)@@@``````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+VQH86YD+G!N9P``````````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P-#$T(#$P-3$U-#,S-S4R(#`R,C0R,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M(0````X$`P```%,P:+\````84$Q41?___\#`P+^_OX"`@```_P``@```````
M`%KM>%,````"=%).4_\`Y;<P2@````%B2T=$!F%FN'T````)<$A9<P```$@`
M``!(`$;):SX```!_241!5"A37<]!"L4@#`30X`ETX[JDD`L4/('>0/?6PMS_
M"(U-V__I;"*/@1@*GWBR"<V_`$3D]E<BN*N0Z`M007?B9&@)R#E[BN36P4.6
MV3)AT:Z53`+V$$EFB9/)M:P[,*^IE'++A(.W5&N])6*18P-::X_0A!!_\EQA
M/_S$GR`J).UK)L>&`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]S<6PN<&YG
M````````````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`Q,B`Q
M,#4Q-30S,S<U,B`P,C(Q,C4`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H
M+0]3````!&=!34$``+&.?/M1DP```"!C2%)-``!Z)0``@(,``/G_``"`Z0``
M=3```.I@```ZF```%V^27\5&```#`%!,5$7\Z3O[YSO\ZSWYWSGVTC9E63!/
M015L7S1;4"U<3RMA5"[RMDWOM$WWM43WM47TLD37KG0```#___\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!Z0_`;````$W123E/_____
M__________________\`LGW<"`````EP2%ES```+$P``"Q,!`)J<&````%5)
M1$%4*,]UCUL*P#`(!.W[W73V_H?M1R0QA8K@.NB*ID]84=`"NH,(Z*\]`NQ>
MX@I#6@FFC.=&N0+BF<#O&(@9E-,!$<B'*ZC=#W!)ZR&R$\1O<WD!]@P1!>:%
MC&L`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V-O;F9I9RYP;F<`````````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`Q-S8Q(#$P-3$U-#,S-S4R(#`R,C8P-0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$````!`(`P```"@M#U,````$9T%-00``L8Y\^U&3````
M(&-(4DT``'HE``"`@P``^?\``(#I``!U,```ZF```#J8```7;Y)?Q48```,`
M4$Q410```/___^_O[]_?W\/#P[Z^OAL;&____P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$K7RQH````(=%).4_________\`WH.]60````EP2%ES```+$@``
M"Q(!TMU^_````$=)1$%4*,]MCP$*P#`(`Z_.KO__\2QM0=,%%#R"1H:(U5EU
M`&T"(X-0`19RTHYVY@V".*,"4R".5QQT\[R41\[^!)/HUW-9'[M>!2=L#7GT
M`````$E%3D2N0F""````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+W!E<FUS+G!N9P``````````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#,S(#$P-3$U-#,S-S4R(#`R,C0U
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,````$9T%-00``L8Y\
M^U&3````(&-(4DT``'HE``"`@P``^?\``(#I``!U,```ZF```#J8```7;Y)?
MQ48```,`4$Q418M]2F]D.UY5,N[6@/+R\NWM[=_?W]K:VL[.SLC(R,+"PK^_
MO[2TM*NKJY.3DVMK:U%144A(2$!`0"$A(0<'!P$!`0``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````/B:<RL````8=%).4___________________________
M____`,T3+NH````)<$A9<P``"Q,```L3`0":G!@```!A241!5"C/E<[!$H(P
M#$71:'V(MDH1O>___]0%#-;NN,LSF23AKC!K.W!.Z90ULT.*2&BHVV0`5YY:
MRQ"P7"25;<)A;E/)Y;?#C(_/^T5S=KIKF!LP597F,1OAHY![H(._O@.D$]3#
MJ2;/`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M87HN<&YG````````````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#`R-C<@,3`U,34T,S,W-3(@,#(Q-S4R`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````)````
M"0(#````G?_N@P````E03%1%N@`69F9F````C+7,0@````%T4DY3`$#FV&8`
M```!8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8````!W1)344'U`P4
M$389KV,IH@```"=)1$%4>-IC8`"!!@8&Q@D,#$P+&!C8EC`P<*U@8)!:R<"@
MM0HL"P!.9P2G^K[9)P````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W5N;&]C:V5D+G!N
M9P``````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,C$U(#$P-3$U
M-#,S-S4R(#`R,S$S-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,`
M``#G4$Q410````0#`@4$`P@("`L+!QH3"Q86%A<7%R\I(2XN+DU-38%:*W)R
M<JIO*Z1Q-JQQ+JUS,J!W1*-[2X2$A*1^3JB!3+1^/J>"4J>"4[B`/JJ$5:N'
M6*R'6+J$0JN(6+J&1[R'1KR(2;J)2Z^-7JV-9+R*3+"-7[V,3J61=KZ-4,:6
M7<>;9*BCGLJ?:*JJJLND<<ZD<,VF;LVF=M"F=,RG>]"H=,^K?+&QL<^L>\VL
M@\ZM@]2L>=6N?M*RB=6RA-BUC+R\O-:ZE,'`P-J^FN#"GN'"G.#$H-_$H^'$
MH.+%H>/&HMO;VP```(1/:.H````!=%).4P!`YMAF`````6)+1T0`B`4=2```
M``EP2%ES```+$P``"Q,!`)J<&`````=T24U%!]0,%!(N(IXUYH8```",=$58
M=$-O;6UE;G0`365N=2US:7IE9"!I8V]N"CT]/3T]/3T]/3T*"BAC*2`R,#`S
M($IA:W5B("=J:6UM86,G(%-T96EN97(L(`IH='1P.B\O:FEM;6%C+FUU<VEC
M:&%L;"YC>@H*8W)E871E9"!W:71H('1H92!'24U0+`IH='1P.B\O=W=W+F=I
M;7`N;W)G9XK'1P```(=)1$%4>-IC8,`!?'Q\T`2\'7B84038N<R%T71QZJ'I
M8G/R01C(PLC(Q*'#"N5KN+F[.SL[.QIQ0Y3X>-KKRHB+2P@I\D,%O&S4[,S,
M+/05>*$"'L;:4B(B(H*R,!6N!BJVEI96)I("4`$7:T-E:6DY404QJ("IEJ:F
MDI*ZJCR?#]P=4(#-VP#J$!=,:G,FXP````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VAI9&5?
M<&%N96PN<&YG````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P-S0U
M(#$P-3$U-#,S-S4R(#`R,S0S,0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````$````!`(`P``
M`"@M#U,```#`4$Q410```%)24E-34U5555965E=75UA86%E965I:6EM;6UQ<
M7%U=77ARD'ETD7ITD7IUDX!]=(A_HZRIO<7!TLK&UL_/S]#0T-+2TM/3T]34
MU-75U=;6UM?7U]C8V-G9V=K:VMO;V]S<W-W=W=[>WN#@X.'AX>+BXN/CX^3D
MY.7EY>;FYN?GY^CHZ.GIZ>KJZNOKZ^SL[.WM[>[N[N_O[_#O\_#P\/'Q\?+R
M\O/S\_3S]O3T]/;V]O?V^/?W]____P```&14^ZX````!=%).4P!`YMAF````
M`6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<&`````=T24U%!]0,"!(<
M+(XR=]<```">241!5'C:1<[;%H%`%(#A2`>5E$&A(D4*%5$4[?=_*]-DS?R7
MWUK[P'$D@\;]8?:/P437-5V;4F@72\NV[%4/`$8[&.(V#@'X`,#:<3W7VW8`
M;X00\#P_VOD!!GB@.09_'X1!>.C`[`)!$"4Q.I$1`L<H3N+DW"\U\5))EL?R
M-65G+VF69_F-/:8HJGHO2@;%LZS*JF90O>JF;KX4:#]@!Q8;\NX>>@````!)
M14Y$KD)@@@```````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]D96QE=&4M<VUA;&PN<&YG
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,38T,R`Q,#4Q-30S,S<U
M,B`P,C,W,#<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@````@````("`,```#ST4ZY```#`%!,
M5$69``"99F;,``#,,S/_``#_9@#_F3/,S,P`````````````````````````
M````````````_____T4&````````S/@2`#/*UG=\6MEWH@_8=Y0/V'<8;X\`
M&&N/``$````!`````0```*#X$@"<^1(`$/L2`##5V'?X^!(````4`%`Z^7<D
M````2`T4````%`#H`14`T/@2``````#H^A(`0'WZ=R`X]7?_____4#KY=_=\
M]7?UB/5W````````0``XAD@`$0````0````#````&&N/`&C;80!`^1(`ZT#4
M=VC;80#L____`````!AKCP`8:X\`()KU=RF:]7<88!@`)``"`%`\%0`L^A(`
M,/H2``````!S.OEW(&`8`'Z*]7?8!Q0`P8[U=SQ@&``H8!@``````,&.]7<%
M````*`````````!B7A@``````````0```!0`_/@2`'@!%`#D^1(`0'WZ=S@<
M]7?_____P8[U=V:1]G>!D?9WX#7\=W21]G>`8!@`8&`8`#Q@&```X/U_S/D2
M``0````H^A(`0'WZ=]@5]7?_____=)'V=Y2:]G<'````.````"A@&```````
ML%48`+@X`0```!0`=/D2``````!T^A(`0'WZ=S@<]7?_____P8[U=RZ/YW<`
M`!0``````#J/YW>@O-1W``!```$````07A@``.#]?P``0`````````````@!
M```H8!@`1/H2``````"P_Q(`AKOI=P"-Z'?_____.H_G=UQ70P`H8!@`H+S4
M=P``0``@````,#I"EG#+PP$P.D*6<,O#`8"GD>1Q%\,!`````(D````D````
M(`$``&1E;&5T92YG:68````````8^Q(`Z`$5````%``$^1(`!/L2`#3[$@!`
M??IW*!SU=______UB/5WTYCG=P``%``(`!0`Y)CG=Z"\U'<`````````````
M````````1-I$`!@"%0#<VQ8`'`(5`&R&2`#_____Z`$5`)[:1``8`A4`<]!$
M`.@!%0#)B\*S````"'123E/_________`-Z#O5D````!8DM'1/^E!_+%````
M"7!(67,```!(````2`!&R6L^````*$E$0508TV-@AP(&=D9&$,W$P,[.P@#B
M,X!Y8":"P0258F:!ZH(`%@`PR0%<TY`9Z0````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]P<F]B;&5M+G!N
M9P``````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#,P-2`Q,#4Q
M-30S,S<U,B`P,C(W-S$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!`````0!`,```#MW>)2
M````&%!,5$7\T\L```#?@63>=57RH(W?@63?@63?@61D#[54`````7123E,`
M0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-
M10?4"P43)0=M@FW7````)DE$051XVF-@8&!@%&"``"%%",VHI"1`-`.N"PL#
M;C(<8-B%IA@`!"L#(`1$O=8`````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8V]L;W)S8V%L92YP;F<`````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,T,C(@,3`U,34T,S,W-3(@,#(S
M-#8R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(```!D````P`@"````?0U1^P````1G04U!``"Q
MCPO\804````'=$E-10?2"`\')!^"GK;%````"7!(67,```L2```+$@'2W7[\
M````+'1%6'1#<F5A=&EO;B!4:6UE`%1H=2`Q-2!!=6<@,C`P,B`Q.3HS-#HU
M-2`K,3(P,+JD+W0```9I241!5'C:[9WAB1Q'%(2%L.$$$NS]TP\G('`"`D<@
M<`("1R`<@5`&PA$(9R!G((<@9R"'<`LR2&"#A<3T_'FW=56O>[I[=FNH7[NS
M<[/3W[U74S/;<_]>6:Z*'A<]*7I:]*SH>=&+HI=%KXO>%+TM>E?TONA#T4W1
M_U$/KQ;]\'C1CT\6_?1TT<_/%OWR?-&O+Q:]>KGHM]>+?G^SZ(^WB_Y\M^BO
M]XO^_K#HYN:KOBWW[WFA%^Y@?4?HBM!#0@=%CXK`!A\4@1W[ONC4MQ,.EI>3
M!VM:CM9/`:#6OPZ`8KY@_M_0R]T':S;$KHN8#3([)B)FLG)D3<+1=1#3\G*E
M*C;!!M;!RTB?]>BTMNN/-<7+9$WILR(^E3X+`,7LV)U^W3YK;I^U-J;F/DOJ
MCZ!1VF?MP6>MX\8,^W8^JYU?=\TZCSRKTF>!#3)YEGW6?#X+C!LS[&MAJN1(
MRD6=9TWLLU83G+/RS2/3G)6WS]IYGB6=$@*?U9<CUZR>/@N<KS/G8CU]EO.L
M"\BS@)K[K"V+E\D:FV<QI:IY9.KKAOOLAD/*F23[K)V3=7KYW$C'H%9;GNA@
MF:P,-9^*XBLK+.L=I/&5J".A/O29K$9D@>,-.`)E**[,X!-9^Q2TOE7)$4;,
M9-61%8\NPQ&@)B*V7<T"]$FLW8J8R=K,.H`1D/ICK&),S:JL4.O'R0KEFK49
M69$(\!;#$5/%F)H5*Y3$&D#,W7!TS<KU1T"$Y+.`<9=Z7T3,-6L#LJ1V!M:1
MT,C5+&D=:>>Q_S)90_.LRI&,C#1!PWG6W'E6KM<`:FX(26TQUYV=9TV39TF(
M@<;$)`H,1SG$P/<R67WS+#!*@!KI3)"I6:!C2H@YS]I5GL5$E``Z4+-`!IMK
M>3XW'-T-<P$IR!ABYBG5+'!Q2/)]SK,FSK-:W=`@^:R(&+@,WO`V"),U]$3Z
M<VLQB(%7&.CN?,5DC23KJI$.Q*\OI%?B3:Z)5TS6-F1UH.9P^L<[`!\)%B!W
MP[YD@0,O`;6"\"`(X`.@BUM>UV$F"(C?BV+-9-62Q1QX,&Z1FE8U*P+%X`.H
M65=VS1KML\#@5%8QJ6;%M];MQ.*5:XNW%"^3U;X;5@(%JD_.9T5J)*!`J4)5
MS&1M6+,DH,#*@".I4>:`2EIYDY4D*\=(7`<PPG`4UY'^>NT)H,G:4YXEH9%S
M^6"=)F":K.YYEM1]&#2N"8&,(=>O7;/ZDL4X70DHAC6F9C'G!A)0SK/VD&<!
MH`[*!1M@N"2.&*!<LZ8Y-ZQLE$R:+HG)^YUG[2'/DGS-0;D\P_@L)N_/72YT
M-QR=P4NE*K["W*.0JUF5<C><+W60Z!LBYUG3D?4?(>8FOG\('8.83S%_G?D6
M)FM+LBHY6F_'!"!\+#JF-(@UD]6J9G4H51)BHXN7R<J1Q1QOYG<+D1JFY>4F
MT.K&FLF:TF<Q_1%`]_&T[+/.SF=)Q0M4L4J?U9<UD]739U4BUMQG,?MCGS6?
MS]JNY37W62NS35@S61/X+#"2E3[+>=9EYUFK&"*.J=_AYUB+R-MG[3S/`CY;
M0HPY)6#VY]\B^ZP]^"RIY>4FT&).$IUG75*>U=-G`9<7]SD6+_NL/?BL'$>,
MS_)U0_NLIHA)O4\J7O99@[KA$-88Z)A&R>19=WIZD[4Q6:>7\Y\]RV2U)\NS
M9YFLIF1Y]BR3U90LSY[EFM7=9UWT[%DFJWTW].Q9)FOCFG71LV>9K"19GCW+
M/FMO>=:9S)YELKKF61<T>Y;):D:69\\R63/E66<[>Y;)ZG%N6-DH=SE[ELGJ
MD6==XNQ9)JM'!G^)LV>9K,$1S=G.GF6R1AVL[1[8VFK+)FL^LJ0!!$\X/1)/
M4Y5^O-.5/I/5C"QPO*4'-A]//WJ7P0<\XCP^Z[R2(X28R:HE"SP<'G`$J)&>
M"5U9LP!]$FNW(&:R-K0.8`2D_ABK&%.S*BO4^G&J0KEF;4A6)`*\Q7#$5#&F
M9L4*);$&$',W'%VS<OT1$"'Y+&#<I=X7$7/-VH`LJ9V!=20T<C5+6D?:>>2_
M3-;@/*MR)",C3=!PGC5WGI7K-8`::3(:IBWFNK/SK&GR+`DQT)B.RDPA@*,<
M8N![F:R^>188)4"-=";(U"S0,27$G&?M*L]B(DH`':A9((/-M3R?&X[NAKF`
M%&0,,?.4:A:X."3Y/N=9$^=9K6YHD'Q61`Q<!F]V&X3)$I8O9>3!DR?EH08`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+VUY86-C;W5N="YP;F<`````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`R,S0R(#$P-3$U-#,S-S4R(#`R,S,S-@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````$````!`(`P```"@M#U,````$9T%-00``L8Y\^U&3
M````(&-(4DT``'HE``"`@P``^?\``(#I``!U,```ZF```#J8```7;Y)?Q48`
M``,`4$Q412(B(PH,$,7&R`P0%N;HZR4H+`P0%2@L,3=&5A@>)6]_D7R*F9:A
MK:"KM[O&TD5A?DUJAU)NBTYH@UUYE0H-$&:"GD58:VB$H%5L@SU-7EEPB&V)
MI5ANA'..J@D+#6!RA7Z5K!TB)V1O>HV9I8F0E]7;X>?J[?+S]$YF?6>#GEQT
MBV^+ID569G61K%!C=7R5K8F=L(J>L)JLO:>XQV]ZA!D=()&9GY"8GLG3VPD-
M#Q(4%1,5%@T1$A$1$!@8%TM(1!,*`!L/`4$D!38?!9M8#\MU&<QV&LAT&M%Z
M'=!Z'=%['L5U',)S'--]'\5T'<%S'0X'``H%``@$`#4<`A4+`284`C(;`V4V
M!T<F!5LQ!S4=!#0<!)-/#2P8!*5<$'Q%#"D7!*Q@$8I,#GE##+5D$R85!!T0
M`[YJ%;9F%*E?$RT9!8-)#\IR&,QU&<UV&LQU&A@.!"X8`T(C!30;!#$:!"\9
M!#H?!5DV%44O&DPZ*1H2#"0>&BDF)LS,S$1$1"4E)1T='08&!@```/___P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````*^/>BL```"$=%).4_______________________________
M____________________________________________________________
M____________________________________________________________
M________________________`)?2-KX````)<$A9<P``"Q(```L2`=+=?OP`
M``"\241!5"C/8V@&@280`+.:&4"$;9.]?2!4!"30T&A?5P]48@L3L'.H#`E(
M2W5NA`DX.GG[^?NXQP?!!&(C/;Q\/?.2LV`")9FY;OFN.1FE,($RE_3LT,*D
ME"*XM1$Q88EQ$>'!,`&;FO+BJ.B$"DXYB`"KF8%)=4$5@Y*.I"5(@)U75E=/
MI99)F4M"1DRDF<'*7%]:6XM;7<U80558@X.1P9I'5%-<2I[%PDB53U50B(W!
MU%``"?`S,RBB`0!I=53+W.V4MP````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O<VAA
M9&]W+F=I9@``````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#8W
M-#4@,3`U,34T,S,W-3(@,#(R-C$U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````$=)1C@Y82`#(`/$``#____GY^?S\_/6UM;"
MPL+[^_NRLK+U]?7;V]O\_/SQ\?'@X.#1T='Z^OKV]O;JZNK8V-CM[>W%Q<7H
MZ.C)R<G]_?WX^/CO[^_^_OZUM;6[N[O$Q,3Y^?D````````````A^00`````
M`"P`````(`,@`P`%_R`@CF1IGFBJKFSKOG`LSW1MWWBN[WSO_\"@<$@L&H\O
MQ8&3P""?T*AT2JU:K]BL=LOM#@.70Z/B+9O/Z+1ZS6Z[WV5$0&$AP^_XO'[/
M[_O_=PP+$0X)@(>(B8J+C(V.910(#P>&CY:7F)F:FYQX$A`3`@6=I*6FIZBI
MJB<$`P&BJ[&RL[2UMENMKZ.WO+V^O\#!([FPPL;'R,G*?\2[R\_0T=+32,W4
MU]C9VMLFUMS?X.'BMM[CYN?HZ8OEZNWN[_!E[/'T]?;W/_/X^_S]_B7Z_@D<
M2!!=P((($RJ,=G"APX<0R;DJ%K&BQ8NG&F+<R+&C'XT>0XH<>08DR9,H4_]"
M,:FRI<N7.5C"G$FS)@J9-G/J=(ESI\^?'GL"'4KTH="B2)/^.ZJTJ=-X3)]*
MG3HN*M6K6*]9S<JU*[*M7L.*O05VK-FSJ,JB7<L6D]JV<.,B>BNWKET\=._J
MW8LF+]^_@+'X#4RX<+6)S@PK7BP/,>/'D+,,CDRY,HO)EC-K%H%YL^?(G3^+
M5AQZM&G`I4^KOIMZM6NXK5_+/AM[MFVOM6_KOII[MV^GO7\++QI\N'&?Q8\K
MKYE\N7.>CI]+;]M\NO60U:]KQYA]NW>(W;^+3QA^O'F!Y<^KWY=^O7MZ[=_+
M;Q=_OGUS]>_K_Y9_OW]L_?TG($/1#6@@=P4>J"#_>`DNZ"!Y#3XH(7H13F@A
M>Q5>J"%\&6[H(7T=?B@B?B&.:")_)9ZH(H`IKN@B@;J\*.,V`<YHXQXUWJ@C
M'#GNZ.,:/?XHI!E!#FDD+BT>J60I12[II!1-/BGE$5%.::4055ZI90]9;NDE
M#EU^*>8,88YII@MEGJEF"FFNZ28);;[Y9IQRKDEGG6?>B>>8>N[Y99]^;@EH
MH%<.2NB4AA[Z9***+LEHHT<^"NF0DD[Z8Z66[HAIIC=NRNF,GG[Z8JBBKDAJ
MJ2>>BNJ(JJ[Z8:NN;@AKK!?.2NN$MM[Z8*ZZ+LAKKP?^"NR`P@[[7['&[H=L
MLO<MR^Q\SC[[7K32KD=M_[7G78OM>-IN^UVWWFX';KC7C4ON=.:>^URZZB['
M;KO'O0OO</+.^UN]]NZ&;[ZW[<OO;/[^^UK``J]&<,&G'8SP:`HO_%G##F\&
M<<2934QQ919?#%J2&L_)<<=V?@QRGB*/S&?))O^)<LJ"KLQRH2Z_C&C,,B]*
M<\V.WHQSI#KO3&G//E\*=-":#DUTIT8?#6K22H_*=-.F/@UUJE)/S6K55K^*
M==:R;LUUK5Y_C6O88N]*=MF^GHUVL&JO36S;;A\+=]S*SDUWLW;?#6W>>D_+
M=]_6_@UXMH(/SFWAAG^+>.+B+LYXN8X_CF[DDJ]+>>7N7HYYO)IO3F_GGM\+
M>O_H^HY.>K^FGPYPZJH/S'KK!K\.>\*RS\YP[;8_C'ON$N_.>\6^_XYQ\,)O
M'&/Q8!^/_-C*+V]V\\ZG#7WT;$]/_=O67R]W]MK7S7WW>'\/_M[BC^]W^>8'
MCG[ZA*_/_N'NOZ]X_/(W3G_]D-^/_^3Z[V]Y__[+'``#R+D!$O!S!CR@Z!*H
MP-(QL(&H>R`$5R?!";JN@A:,'08S2+L-<O!V'OR@[D(HPMZ1L(3`.R$*AZ?"
M%1J/(BYT3L9BB(\9TM`>-KPAAUJH0\/DL(?O^"$00<3#(:*&>$8D#A*3.!0A
M,I%$17PB:Y8HQ9TXL8K@N"(6N:'%+6JCBUYD413#R!;_,))Q&F8\(XQ@J$80
MLK&-(WPC'$THQSFFL(YV9"$>\_C"Q/#QCG[\HQX#*<@^%E(S:3SD+Q*IR%XP
MLI%DH2(D-_+(2=*BDI:4!28SN8I-<C(5GOQD1B0I2J.0LI0+"24J.Z'*56ZB
ME:[,!"QC>8E9TO(1MKQE(W*IRW6<LI?^X"4PY_++86)HC,:<B3"3^9%B,K,>
MRWPFCIPI37A$LYIXH28VB;C';6+EFMYT`SC#R89QDE,-YCQG7[2I3G&DLYV-
M028\.?+.>7*AGO;4`C[S*1AV\C,;^_QG%0(JT"D0M*!1."A"GZ#0A5+)GPZ%
M1D,C2H2)4A1+$+UH,BRJT7QD_[2CQN`H2'D@TI'JH*0F!=-'4^H+E+*T!BY]
M*9E6*E.)R+.F]X@I3E^@TYVVH*<^70%0@\HFFA)5%4,]:C>,JM11WK2IZD@J
M5#G#U*FRLJI6?256LRK+K7*UEE[]*B[#*M9=DK6LOGPJ6KEXUK424ZUN!6A;
MX\J,N=*U#U*=:EZANM>F]E6I?SUJ8(DZV*`6UJ>'W6EB<;K8FC96IH]]:619
M.MF45M:DEQUI9D&ZV8YV5J.?O6AH*3K:B);6H:==:&H1NMJ"ME:@K_UG;/DY
MVWS6UIZWG6=NX;G;=O96G;\]9W#).=QP%M>;Q]UF<K&YW&HV5YK/?69TF3G=
M9%;7F/_7'69V@;G=7G97E]^]97AI.=Y8EM>5YUUE>E&YWE*V5Y3O_61\.3G?
M3-;7DO>=9'XAN=]&]E>1_SUD@`LY8$$6^(\'YF."\[A@.S9XC@^&8X3;.&$U
M5OB,%R9CAL.X82]V>(L?QF*(JSAB*9;XB2=F8HJ3N&(CMGB(+P9BC'LX8QW6
M^(8WIF&.8[AC%_9XA3]&89!+.&01%OF#1^9@DC.X9`LV>8)/AF"4&SAE!5;Y
M@%<F8)8#N&7_=7E_7\9?F.LW9OF5^7UG9E^:T[=F\[5Y?&\&7YR[-V?MU?EZ
M=Z9>GJ.W9^?U>7E_1EZ@BS=HX17Z=X?F7:)SMVC;-7IVCX;_7:1;-VG55?IT
MER9=ID.W:<]U>G.?QERH*S=JR97Z<:=F7*H3MVK#M7IPKP9<K/LV:[W5^FZW
MIENNX[9KM_5Z;;]&6[#+-FRQ%?MKQ^9:LK.V;*LU>VK/AEJTFS9MI57[:-<F
M6K:#MFV?=7MGW\99N&LV;IF5^V7G9EFZ4[9ND[5[9.\&6;P[-F^-U?MB]Z98
MOB.V;X?U>V'_1EC`"S9P@17\7P?G5\+SM7![-7Q>#X=7Q-LU<755_%P7)U?&
MP[5Q;W5\6Q_'5LBK-7)IE?Q9)V=6RI.U<F.U?%@O!U;,>S5S7=7\5C>G5<YC
MM7-7]7Q5/T=5T$LU=%$5_5-'YU32_S.U=$LU?5)/AU34&S5U157]4%<G5-8#
MM74_=7U/7\=3V.LT=CF5W6-PO2L:[:IV/9S=36\/6=K;+E&VT_T.<5=3WDDV
M][LK8^]F`OS)^N[WK]B]\&T0O)@4KS+"(UX8C/=2Y%OF^,<#8_):PCS,*F_Y
MEAZ^\^OD/.@C*?K1UT+S5D+]S$IO^EFH7DJOMQGK6Q^+V#O)]CF;/>V1^OG=
M(TGWOG=J-X,?U=X3_PJX5U+R>0;\XU^U^<[7*O2CW]7I4Q^LUK_^6+.O?;-R
MO_MI'3[XV?K]\;]5_.:7:_G37]?ULQ^OQG__$)9O)/K_S/WR=WO\\P\$^PO)
M_T*#?_R'=__[-X!<4H`&N`,`Z",+6#0"F(")AX`0J%(/.('H)($6"%,8F($S
M58$<2"0;^($PT(`Z0H)(XX$BV`4F:",KN#0HF(*_AWXPZ'DO.(/]5(,V:`4M
M*",[Z#0XF(-4T(,N(H11\X-`""4A>(2LD(1*"!!,V(3#\(10"`!$J")52#5&
M.(5&<(4FPH57DX5:6%%2"(5>*")EJ#5@&(88E89JV']CV(1GZ"%QV#5LV(8^
M,(<:@H?)(X-V:`IZ:"%_R#Q\V(>D$(@28HC/,XB$R`F(Z""-*#V*N(B:\(@*
M0HG5$XF2Z!9OJ(26:""=B#V8F(F6\(D"0HK;$XJBZ`BFZ!^KZ#W_J)B*C-"*
M^B&+X?.*L*@(M&@?N4@^MGB+YT=(OEB(FWB$NR@?Q7@^O1B,[9>,R@A_==B,
M/#6,0'B,[D&-ZL.,T*A_SYB-ER&-.6B-Z@&.[8.-W$B`VUB.176.Z+B$ZKB.
M3MB.[AB%\!B/5.B--BB.YH&/\$..]'B!\QB/^B@>`3D__-B/H5>0!@F"_^B.
M`^D=#6D_")F07O"0VD&1^1.1$GE/]CB#%FD='<D_&)F1^K21,/B1TF&2_Q.2
M(GF#*KF2.DB2*8B2,@23(BB3`M22+AF$-/F!GQ`*P)B3?!`)DY``"\``&Z`!
M&6``2KF43-F43OF44!F54CF55%F55GF5_UB9E5JYE5S9E5[YE6`9EF(YEF19
MEF9YEFB9EFJYEFS9EF[YED^9`1JP`8)`"`D0``C``!0@`030EW[YEX`9F((Y
MF(19F(9YF(B9F(JYF(S9F([YF)`9F9(YF919F99YF9B9F9JYF9S9F9[YF:`9
MFJ(IF!)``0P@!W10`1<0``N``!`P`+`9F[(YF[19F[9YF[B9F[JYF[S9F[[Y
MF\`9G,(YG,19G,9YG,B9G,JYG,S9G,[YG-`9G=(YG=19G;4)`0BP`&`@!A5P
M``H0`0\P`0$PGN19GN9YGNB9GNJYGNS9GN[YGO`9G_(YG_19G_9YG_B9G_JY
MG_S9G_[YGP`:H&(".J`$6J`&>J`(BIX3\``1H`1,@`$-8`$.<``"4*$6>J$8
MFJ$:NJ$<VJ$>^J$@&J(B.J(D6J(F>J(HFJ(JNJ(LVJ(N^J(P&J,R.J,T6J,V
M>J,XFJ,ZRJ$'X``6T`!-```A```[````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W-H
M861O=RYP;F<`````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`V
M-3$S(#$P-3$U-#,S-S4R(#`R,C8R-0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12```#/````T4(
M!````!32,6P````K=$58=$-R96%T:6]N(%1I;64`5&AU(#4@1F5B(#(P,#0@
M,3$Z,C$Z,C(@+3`V,#!R:CQF````!W1)344'U`(%$14?KSQU;0````EP2%ES
M```+$@``"Q(!TMU^_`````1G04U!``"QCPO\804```RC241!5'C:[=I1:MM`
M%$#1Y]B$0@AT_SL-3NR.9$,W$-U`>\Z@0?:7_BYOF/,`P-'.<UKK^0H`1_LU
M+VO-BL]=>``XWN^Y[.&YS7H!@*.]S^=\S!:>N_``<+RWN:[]NNW"`\#Q7F<K
MSG[%X.6GOP6`_\!VM>!YKTUX`#C>Z>]U:N$!("4\`*2$!X"4\`"0$AX`4L(#
M0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"D
MA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX
M`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`
ME/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)
M#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``
MD!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`I
MX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>
M`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@
M)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"
M`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`
MI(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*
M>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'
M@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!(
M"0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P
M`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`
M*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2
M'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!
M("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2
MP@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\
M`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`
M2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$
M!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`
M2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4
M\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/
M`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0
M$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA
M`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`
M4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E
M/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#
M0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"D
MA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX
M`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`
ME/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)
M#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``
MD!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`I
MX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>
M`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@
M)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"
M`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`
MI(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*
M>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'
M@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!(
M"0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P
M`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`
M*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2
M'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!
M("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2
MP@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\
M`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`
M2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$
M!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`
M2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4
M\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/
M`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0
M$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA
M`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`
M4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E
M/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#
M0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"D
MA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX
M`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`
ME/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)
M#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``
MD!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`I
MX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>
M`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`#C>?5^[RYSG
M==[F?3VO*T.GG_XV`/XY][FM]4S/97_YFL^YS@@/``?8PG-=I?G:FG-9?]S6
MCX_9(G02'@"^W3;B;*7Y7,79)YZO?=JYSGGMP@/`=]N.V!YG:VOFV4*S';"=
MU^.B`0!'N>V#SGUNCPGG<<1FV@'@*/=Y'+G-'_G%/JSX4"VM`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]C
M;VQO<G!I8VME<BYP;F<`````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,3,W-2`Q,#4Q-30S,S<U,B`P,C,V-34`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!`````0
M"`,````H+0]3```!@%!,5$4```"?.%,U$QQ?H(<@-2TRE981,C(+$@^6CG,J
M)QX2!@F[LYLP+2,&$1'':$E"(QBTUK@\1SU":VQFJJM\T=,I1D:KS[`S0#6W
MKY1%03,B+2H.%Q=+74L-#`FPIXFBEW:3BFPM*B$7%1$6#`BZL))Z<ENPI(%X
M<%B(?V2=DG/NUH!/1RL\."R^M)7"N9R\LI*WK(JTJ(2>E'0F)!PT,":$>V&_
MM9>]LY29CW`A'QAH6TU:4T&XK8O!N)N^M99P:%(5$P\:&`XC'AH:&!.HGG^D
MF7A333UK9$ZRIH3`MYJ6BVTN*B(=&Q6*@6=^=ES_____________________
M____________________________________________________________
M____________________________________________________________
M______________________________________________________]Y6C?C
M````@'123E/_________________________________________________
M____________________________________________________________
M____________________________________________________________
M`#@%2V<````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````BDE$
M050H%07!P4D#40!`P7F[/[M!<PR*!+0.JPMIQ1[LP4H$O>I!5U!G.@,`!A<`
MG`V7*(J8`)J!"="8@(EJWSS/U<K@0$N;0\4`EM;/M9^%`2QE>;]]>VH0QU_S
M7?=_#WT-3I2J=#6`?=O?VF9I`$MKVJP-XJ;ZQK''X0R\7+^>/G:9`':[/>/9
M/VM1%5#STJ5%`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]R96QO860N<&YG````````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#4S,R`Q,#4Q-30S,S<U,B`P,C(V,#(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!`````0"`,````H+0]3````8%!,5$7____\_/WR^?WO\OCCZ_71X?16INYR
MQG("F@.BVJ[/Z/[#U?>RLOX2GA+J]OZBUL[$X?JZWO:NU_TIIS>BTOY>NH(`
M``#___________________________________\`WAE^`````7123E,`0.;8
M9@````%B2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-10?4
M#!8.)20KEPCG````=$E$051XVF7/T1("(0A`T4VD92E16?/_/S4L'+?IOG%0
M9]RVO_K*X6:%`!%=/C`,^[U?(`#ZI0$[T4'\>$ZPV6+D">F0;%`<((C$<8*K
M`X"(E%+JA+$F&]4A&J1<DJHNL$YM#LR4]_.EVMH7$+G:BPOZSW_?+.`)B2O$
M=FP`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:&]R9&4M
M<&]W97(Q+G!N9P``````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#4W-#8@
M,3`U,34T,S,W-3(@,#(S-C8S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(```!4````'P@"````
M]I9].0````EP2%ES```N(P``+B,!>*4_=@``"YA)1$%4>-KE66M44U<6/O>5
MQ\WC$A(>255>"LACEA2*H6BFCE81Y:$H5!$(*A4[%BR5KK%HM3'26@14RJ`0
MG=7'N#IUA&I%C1U!EU21ZEA'L%AMA4$0%"08("&O.S^.<XDA/F:Y9M:T[I4?
M-_M\9Y_SG;W//OO<"\!S+`@`@*;IYY$Y@J!/!.W9L\?;V]O%Q44JE1J-QE\3
M_R>3KSVQGRWJ?OMC%Y/9M&;-&H?6AH:&BHJ*_S=6Y>7ES/-CIO=D\H81G==D
M3!8P/&W."UJMUK[IL\\^6[`P+C]_W<R9,WMZ>IYQQE>N7+ERY0H37(V-C5`)
M`(#&KUV[9C0:C48C5+:UM75T=+2UM<&F@8$!V/'BQ8LG3IQ@S!X_?OSBQ8N,
MJ8&!`=@%`(`_<4XFLY'$`0`@;A5]ZLC]DI*2O+P\`(!*I2K9L>W55")LFEB]
M_.R&#1NJJJJ>A?R&#1MD,EE[>WMU=75&1@9%4:6EI1X>'J&AH8</'RXH*%"K
MU7OW[EVU:A5%411%`0`Z.CKBX^/;V]MOW+BAT^D^^."#;=NVD20Y/#S,F-7I
M=-#Y)$F&AH:VM+2$AX=[>WL[\7QN;FY#0X.]QF(UXP0``*!D;]`4J4JEFCIU
M:DQ,3.G.#Q>N8<6DLS@\P.5P%B]>_.SA6E%1(10*O__^^Z&AH<K*RJ&AH8R,
MC)J:&AZ/IU*I)D^>7%=79S*9*(IBL]D`@.3DY,S,S$N7+E$4Y>GIV=_?K]/I
M*BLK29)D;+JXN&@TFIZ>GJRL+*U6V]'1D9:6YB3L$Y)?WKNO,B$A(20D1*U6
M&XW&M6O77KO2+99B``":MJ:_;XQ;(<"$MWYL.ZM\CQT=1P``CNX%$HG[[-FS
MGYU\:FHJ`$`NE\MDLD6+%LEDLO#P<)(D\_/SV6QV>GIZ;&PLB\6Z<^=.='0T
MTTLNEW=U=1$$H5`HQ&)Q2DJ*O>?U>GU*2DIP<'!H:"@`(#@XV,E1MUOS4<&&
M@K?*A)C5M7:?^8>+]PD6AA"#\Y:S(^>PL$?L#\L(4;!P./OUWZO5ZF=DGI"0
M<.C0H?]>%FQL;"PM+=VV;1N,^8>..JFG'\G'6R^8W/T&,K<.;ZWF+UB#Y.XD
MH^:-,K>8'2U>KN/8+(A3YCP>C\5BD23IL(\>):M7KW[&?`E'Y//Y,+>-G8]*
MI8+,'1->PORDNW>[UA>\S1.BD;/9!&F,F`T`P```QD'BJ`9<_X=QQ&`EA;1_
M.)CY&HLG1```WJ%6FK:N7;MVQXX=#H.-C(Q8K5:KU3HX./@TLX^)B7D6\B:3
M"8YHL]E,)M-8``Q[>WDHFE=FOME^Z_J>BMU\%R0HD@65MW]PW9[;Y2J2*!2O
M3IPX\:>??CI[YG33B:[7MY(3`G#QN.&DU9*JG57U]?5L-IO+Y8I$HKESYZY:
MM0I!$!A=!$'\#\YV#,/@B"B*/F47)^7M_$7A-]J:WRZG4!18!]W?67`K,C+2
M_N0$`,3.B[W47/<'#9_O@B((5K<?O=-A,8T`DY'N;C=;C<+V]G:"("P6"X[C
MS<W-7EY>0T-#8K'X4?,P&HU/!,"3',=Q!UA?7Q^/QQL9&9%()!:+A2"(<^?.
MA8>'VP/8;#:?SW<H;YWD,1MZ?_PD#$4!@F"?;T5$(I$#<P#`T=JC@<$33G[9
MG_`ZEZ:M,Y981T?JXJK3^IF_-$W'Q<7U]?59K5:*HJ*BHK[XX@M[4[MV[:JJ
MJNKJZK)8+!1%39TZ]<"!`_:`LK(RC49SZ]8MB\4"`&"SV6?.G`D("```+%FR
MY.S9LP,#`QB&2222L9>49<N6-30TZ'0Z%$6E4FEJ:NJ[[[[[$(*VDY*2$JD7
M-W.C0-/D]NF%0$]/SQ4K5M#.Y(TWW@AXD:QL=-,T/?B5U;FEYKE/\*,\/#QH
MFL9QYR>$GY]?=W<W-+)TZ=*QF\+'QZ>SLQ,"E$JE`P##L):6%KU>/W'B1*?V
M"8)H:6DQ&`QP@1[:Y#B>F)@(+8^2-YO-65E9$P.D,B_N_.6"'=^(-4UNGS>%
M2222XN)BI^1W[][MY4]6-$@T36YE)SUB7O.4N`O'CQ^_;-FRWM[>L>3AAH02
M$1%!TW1149$]QAXP9<H4FJ9W[=KE`$`0A,/AZ/5ZN5SNM",DK]/I%`J%4P"*
MHALW;H3D'Y@."/6T(4.1,414+"D0H?^.?P..XZVMK4X7^.K5JQP>P'`$`/#W
M$]RS1^_EYN:J5*JQ2(%`$!<7)Y5*:VIJ?O[Y9P#`Y<N7Z^OK*RLK823S>+SY
M\^>/'S_^T*%#UZ]?!P`T-S>?/'ERSYX]$$"29&QL+*Q/A$+AZ=.G8;D.`/#U
M]5VP8,'MV[>__OIKO5X/J5975S<U-3%QE)R<W-/34U-3,S`P8+/9/OGDD]%Y
MTC3M,0$O/.C*!##\[?M.^O(KP;Z^ODX]'Q3J':OD0V3TJR]$1D8Z`*#3$`3)
MR\MCE"*1"`Z:E)0$ZW,$0;*SLQF`JZLK!,3'QT,P@B!965GVEM/3TR&&HBBS
MV0R5^?GY,,]S.)SDY&1FW2]<N``Q.3DY#`!Z_H&375VI3]663[?0?]E.?_5'
MNO&8"0!@HRUI!4AO;V]<7)R#,Y.2DOKZ;\],80,`:!II_]'`X_&<7QM1-"$A
M@?G+<+MW[Q[T*HJBS%P!`.[N[DR*9@`+%RYT2._P02*1,/M"J51";@B",#>\
MX>'AZ=.G"X5"DB2KJJH@9VAV-.RS,]\[<N2(_J[^OM%H,IF^K;V!L^B(F6R"
MZLG=+MNY[E1`0,"L6;."@H):6UM/UFE[=?_,4G,I,1R,7IS#K=IT?O/FS9LW
M;W9Z2MDGU[$`L]G\^`/9X26*PR9GBIRQ`*O5:C`8')#,2?F`?$Y.3DY.SNC=
M;EUFM6:_]V1<(L.\IO2I#@@/[QXX]K?]7]5:>4+@]R*R<BF?DHS6$L'338MS
MJ.W%VWU\?#(R,O[3^L0^GSLEYB!.5Y#%8C'/5JN5B3L$01@\@B`BD6C+EBV/
MN\_OW/ZGKPY_>?.J12+#``!\D7GI>D#;"+,9)XC1"\']NZRVUI'`EP"+@T0G
M6O3W!'EY;[FZNH[=)DX+,@S#```VFZV^OG[&C!E0W]__H$;@<KF/ZLML,2:\
M`0!:K=9FLT'"`H&`0187%[-8+)O-9K/9.!Q.4E(2A\-YW)N<CW:N0W%+2!3K
MH6!#`8O]@#EM0[^KY:O3!_]<:%6GC53OLMWMM$7&8`:CX=JU:T_C;:%0Z.;F
M!MU87EY>6%AX_/CQJ*@H^-(&P[#ITZ<S#G20^/AXN'!]?7T1$1&UM;5%146%
MA860O$@D2DM+@[E@<'"PLK+2Q\=GSIPY<^?.34E)89@[*7*@1,V2Q:21FB8W
M39/[.Z6_F13B,G.1..M]R<>G)#"]I^4&\7@\I5+9V]N[?OWZP,!`-T^*+^0J
M%`J';(]AF%:K992^OKYPT.3DY$V;-C%!CJ*H_9'NY^?7V]L+G8]A6$U-C<,,
M_?W][8/(OIY?N7(E3=-!04'V`((@"((("PMC+#@G_^WY$]Z![*U_==WWG71Y
M7AB/QYLV;5I86)C83;`@^\'9]DJL7TA(B'TOK5:K5"H-!@.C@<Y!4?38L6.,
MTL?'!PXZ;]X\FJ85"L7832Z12,Z<.=/=W0VW,8JB!P\>=)CD^?/G/3P\QKZ-
MELOE$'#ITB5/3T\'@+^__Q/(O_F6DA)C'U9[)BX-Y_%XN;FY4%]<7"SS9I?5
M231-;B__SM=^%9T*E\O%<9S+Y9X^?9I1!@8&XCB.XWA24A+49&=GRV0R#H=#
M$`1%47*YO*6EA:;IUM96@4"`XSB'P[%?/D9NWKP9'1TM$HD(@N!P.#*9S*$2
M[^SL5"@4$``'A87CX\AW=G;.F"7G"TB*HDI*2NR;?/S%J>_P-4UN+TWS9=;X
M%RK.L[U,)JO[YEQ14=&D29,2$Q/MFWX;'7OJ\(%0.='5K@^8Y/UK^'#Q]*ME
M,!BD4BE%4>/&C2LJ*OJE>_ZY_E;W/'^D!?\"I^_A#YORDM(`````245.1*Y"
M8((``````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]H;W)D92UP;W=E<C(N<&YG````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-#(U-2`Q,#4Q-30S,S<U,B`P,C,V
M-38`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```%0````?"`(```#VEGTY````"7!(67,``"XC
M```N(P%XI3]V```(7TE$051XVNU8>TQ4V1G_[F.&X<+,=89!D`H,(AC'MQ!D
M-AF-9%L%Y:$80$&7UIK`FMA*:DJZTABMV$@0974;<<QJ#$F3)N)C3305$1\M
M)3-A!5$>72%=C<,R#.`,\[ISS_2/@[?CG0'%I!L:^N7^<>^YO^\[]W>^Q_W.
M`9C#0@"`S^>;B\P)@IS+GB<!8,6*%7.7?%]?W[5KU^8H>8_'4UM;.T?)`T!G
M9^?@X."'JSUX\*"WMW>JMV%A85*IE&&81X\>_0@<NKJZ\(SAX>%=75TS(Q^F
MD+QY\Z:RLO(#=>KJZK*RLG0ZW>'#AX,"W&XWQW%NM]MNM_\(Y#T>#Y[1Y7)Y
M/)Z9*7]:,`\`U&JUS6;SO4\J*BID,MGDRI%D2DK*P,"`"$/3-`!0%'7W[EW?
M?U\Z.CKPC!*)Q&@T?J#6)/FC?U;2-`D`I:6ETRMLV;*%HB@`B$\.2]F@P.I*
MI;*VMC:0/$W3/3T]3J?38K%,8_-#`&:SV6PV!\(L%HO3Z1P;&YN*O,5BF<JC
MD^0-[9&K/E$`P,*%"Z?Y")U.A_%+4^3US6I#>^0O?J]DPB4`()/)#`9#H.>3
MDI)4*A7+LG%Q<86%A2*#9\Z<6;Y\N4JE4B@4L;&Q.W;L$`'JZ^M7KER)`0J%
M(C(RLJ>G![\J*BJ*BXMC65:E4B4G)V.7^),O+BZ.CX]G65:I5&JUVN/'CT])
M_N`9%0[CDR=/!M*VV6Q:K1:#=9O9/SU2&]HC\96S5P$`H:&AK:VM(O*!DIB8
M:#:;,6;7KET2B40$2$A(>/7J%0:4EI:*`!1%=7=WVVRVQ8L7![4OD4BZN[N=
M3N>2)4M$KVB:SLO+"TZ^X>^1"Q>%`8!6JQ4Q[^GIB8^/Q_W@CL]5`FU#>V1#
M6V1L4B@`K%Z].C#L_1M)X3XU-=7G\]74U/AC_`'85'U]O0A`$(1,)K/9;.GI
MZ4$5,?FQL;'UZ]<'!9`D6555Y4]^<@*2@I^62+X^"L^?/U<H%"S+QL3$;-BP
M8<V:-0</'AP:&J)I<L_OV$^V4OZ3]7_+?]_O)$FRL+`PJ"OD<GEV=O:"!0N:
MFII>O'@!`$^>/&EI:6EH:/!ZO?BGN'7KUMC8V.O7K_?W]P/`TZ=/FYN;SY\_
MCP$,PV1E92U;M@P`%`I%:VNKR63"QA<M6K1MV[;7KU_?O'G39K-AJE>O7FUO
M;Q?BJ*"@8&AHJ*FI:7Q\'"%T^?+EHT>/OO.)V(U?/53_)"%4Y#&<2R&A]*]/
M*_U]CB_=IGD`$!T=';3:$P1145$A#"J52FPV/S^?95D,*"LK$P`JE0H#<G)R
M,)@@B'W[]OE;WK-G#\:P+,MQ'!X\=.@029*X]!04%`CK;C0:,>;`@0,"((CG
M`4`:0OS6$#8V'#KZ@^]E/_0947^7PV'G%$KIK^K"X[64R*OC%O3MPPD`R,C(
M"-Y"D&1N;J[PJ%*I1D='`<!JM6*ODB0I?"L`S)\_WVJU`L#(R(@`V+Y]N[_-
MD9$1?*-6JX6\*"TMK:NK0P@1!#$^/HX''0Z'7J\7%#%;;/8_A<#_@9$3C)R*
M603+TF'3;G#8),__P<<L)A=H@FS^C']%3@?'LNRI4Z>FZB!<+I=H>I%P'#=]
M#^)O(3#)A28G$,#SO-/I%"$C(B*F)"\21DZD?!H<@!`\O.'!.\*HJ*B/;L[\
MZWE08B()NH)2J52XYWE>B#N"(`0\01!*I?+8L6,?2GX:^><3_N5W$S1-EY65
MS527HBA<2A!"+2TM&S=NQ.,X*?"/<YI=PV32O0UO`+ASYPY""!.6R^4"LK:V
M5BJ5(H000C*9+#\_7^A-W]G8S%0>74<`$!L;6UQ</%-=W*Y@-YX[=ZZZNOKV
M[=LZG6YH:`@OC5ZO%QPHDIR<'+QP(R,CJ:FIMV[=JJFIJ:ZNQN252N7NW;MQ
M+;#;[0T-#0D)"9LV;<K,S"PL+!0Q_TCR8\/(U&('@+2TM(]0IVFZI*0$![G5
M:JVJJLK.SFYK:\,AJM%H]N_?/]7)6G%Q<6)B(EXXD\F4FYM;65EIL5CPV\V;
M-^?EY24G)V.`T6C,R,C0:#0:C2;HIY(`,/R*[S-YG_[-VVOR#GW/>SWO.=(C
M*0B3TP#P^/%C44'RSTR?SX<=(DK7B8F)(T>.Z/5ZS!\A)!1AM5I]Z=(EK]>+
M/2^R@.7*E2M"E>%Y'@,(@DA/3[]PX0(`-#8V1D='"P".XSB.FYB8".(&`/@B
M?Q0AW]LZ0<CG2;1IC#Z/3%I#!:U!"A59]D>FIHQ[^?)E5E;6O7OW`BL0QW$2
MB81A&&$P)"0$!R0.O];6UO+R\ALW;EBM5I[G&899NG3IQ8L7M5IM;V]O2$@(
M0HBF:7\+6-+2TMK:VDI*2IX]>V:WVRF*4JE4F9F9!H-!Z!%-)M/.G3N[NKKL
M=CM>]$`[DZ>W%$7)9#*:IA%"#H=#R+?%R\,+*R0)RX,7Q3M7O'_Y<E0JE9X^
M?;J\O/Q_\?26P-5RU:I5,IG,Z_5V=G8V-C;>OW]_<'"0YWF*)O,_5_RL1!*H
MS'OA^&>.?_5/Q,3$[-V[EV&8J*@HC4:C5JOE<GEH:"C+LH$U9M:1#UI=ZNOK
M3YPX83:;`6#KS^?EE0?A_^0!]^5OQMXY"2=)DB1IFJ9I6O)6(B(BFIN;10W&
MK":/9=VZ=7B?\-D72GTN'>C\KX^XONODO5[>[4(>-X^0SX?$!DF2/'OV[&Q+
MC?>3!X"U:]=V='3(&,GAR_+H>"I(M\<#S_L0#[P7W"YPVI#;"6ZGS^T`A]W7
M])7+^H,K-S=WMIV.$P3Q_@ZOI:4E*2EI>'CXFPOHEW^@@O[Y2(IXVQ&#,O(=
M3)^1>/B-:V!@8/8>74\C+,L6%14!@.F^;?@5/],)8I=,-C/P?YE5\F]R:[N-
MPK3LW0````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]S:&]W7W!A;F5L
M+G!N9P``````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#8R-"`Q,#4Q
M-30S,S<U,B`P,C,T-S0`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!`````0"`(```"0D6@V
M```!6TE$051XVI52/4L#011\;W<C,1A0J_2"53A(;2'8V02"8(PA_\*#0)"8
M"P'A()R!](K7*%J<C9V-Y6&XP#4)]P=2!(5(M-JU>/'NC!^85\W.SKQ9AL63
MXR-89`0`9+.[_U3[_KT@].3Z^(M(2L482JD8YTM)$`"PM[^SL;F.B(PQ1+R]
MOJ@;IN=Y(:.40D1$O+DZGR5PSC5-`X!NMTM,L]DD$1T-PR`L`"!DWZ;ORZED
MJ5@@`ZV/)\P,)`6`GCM\G4Q7TJF#PSO;ML-=K5:+GA<92)U(B'XO>'F>K*ZE
M@R"@K8PQ*26E18:>.WQ\Z!,F4*O52$%/,DWSBR$^U4;%<9Q<+O>]I<BPM:T!
MP&G]LMJHE(J%?#Y?+I?C?;3;[<B@E!J-1IE,IMJHV+8=##Q2_-62$&(\'A-[
M-O``0-=UND)$R[+F6^*<X^<0T^ET0H82?C80.\?$:\5%O_<'C@F!#2I@[6$`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:&]R9&4M<&]W97(S+G!N9P``````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#8T-#4@,3`U,34T,S,W-3(@,#(S
M-C8R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(```!4````'P@"````]I9].0````EP2%ES```N
M(P``+B,!>*4_=@``#-=)1$%4>-KE66MT5%66WN?<<Q_UKCQ("`FD"'F8%"%T
M0F`M&`3L7BVX6@)M-_0,KA[^Z%)Q=*UA'!#'Z:6NH7M$H<'(0X4&!18S(#["
M`!F@-8(/D$XF2`)YF!<D(:^J5-6MNK?N<WZ<4)0Q0$7I7WU^9-4]V>><^^U]
M]M[?WA?@;W@@`'C\\<<=;NN<GQ6YDFT_?L=P4`KZ(^&0+(6CAFX``,L1JUVP
MNRWN%#MAF40VZ>_V7SAS)2JK&./2TM+''GOLWB-'B-!?H>%([6?-Y8ONL[LL
M/VPO73/Z>_P][8.^@9`D1E5%&W628.7L+DMZ5G+&E&3GW;2<EIE46)I=_V6K
M81B7+U\^?_[\G#ES[CE^!@`6+ERH*(H4CH9#<GJF.T'CQ(_>SJ&Z<RUMC;V^
M_F!44JG!*6:$$/VMJ7HD)/=W^WL[AR+AJ"O9QG+D#GNZ4NR2J`9]85W7^_KZ
MRLO+.8Z[A\A?>NDE!``U-37OO_^^+,L`D)V?/G->WICX$4((88PP?31-TS!U
M65(:+W9T-M_0-8/*\#R?E)24G)SL<KDL%HNNZZ(H#@\/#PT-!8-!7=?I<H?;
MZBV?FCDU]0[O%QJ6OCY]58HH&..*BHJ%"Q?>VVN/*(P//OC@S)DSJJH"0%YQ
MUO0Y.1BC4:(,9CG"$X9%")FFJ1EJ<#CX=<V5WJY!TS010G:[/2\O;_GRY6EI
M:6.>5U-3\]EGG_7U]=&#",MX9WERO)FCSKKEDYCM;1_NN-J/`#D<#H?#(<NR
MIFD\SPN"(`@"R[(<QPF"P'$<(81E64*(W6[/R<D9!W@`.'#@P.>??TXM,WUV
M3L',R?&B&#,":W58DRR<#6-L&$8P&#AWYF);2Y>B*(20_/S\U:M7.YW.NY[Z
MR2>?G#Y]>G!PD#Y.GSVU8.:4,1P2$X&S"HS]1GM(4PQ557T^7W=WM\_G4U65
MOC-U*X9A$$(88_J7Y_DE2Y;<?__]B08\`%BU:E4@$&AH:-`T[4IM!\N3G,*,
M6^`1)@QKX6P_G[\L$`C:[;8WWMRJ2`8AA!"R8,&"BHJ*!._;HD6+RLK*MF_?
MWM7591A&4]TUJUV8G)OV?1<C#(<1^^03:X*!H,OE^OT??F^U6@.!@*;=BJ:F
M:=)'J@X`"(?#ER]?OBMX`/A.R'GJJ:=>>>65Z]>OZYKAZPO$@P<`A#"#27_?
M@"1)4D221$40!+?;O7CQXMFS9X_+WYQ.Y_KUZ[=MV];6UF::9E/=]=3T)+O+
M8IHT<&"$$&$(80ACDL&!04F2=%V;FC\I)4N8[$N6H[*NZIJJ:XJN:IJJ:$I4
MU51=BD0#0R(`^'R^1%YC=+RE6L089>=/'),6L"R1)""$"(*0DI*R8,&"DI*2
M'Q9RGGSRR8,'#W9W=P/`C39Q^IP4W=`1`,8,Q@QA6)ZU8IV,G,BR-H>%=R4[
M4G@P`6&,``&`;NBJIFJJHJIJ*!@^=^*;J*2(HCAN\%]]]=7P\#``N%/MR6EC
M>:]YZUJFI*04%A9Z/)X[)7]=5U55$(0Q_\NR[/+ER\^>/1L.ATW3`%EPNCF$
M,&%8@EG#,'E.X!@!8WPS"C"$M1*&93`AF-5U'2&,L*EJ2E259"7"6SB[TZ+(
MJBS+#0T-7J]W'.";FYL510&`U`PW0_"8"\R;%Z2RLK*EI462)(_'LVS9LB>>
M>&*4'G?MVE575R=)4G9V=D5%Q9HU:^(%SI\__]9;;]76UHJBB!!RN5R;MVYR
MV5(QPO][XL_'CU5_V]IF$03O]")%42D5)0PG"!P@.%/]Z;&/3[8V?\OQ7&E9
MR2]75$S+]Q`F($J0DN[V]0<U36MK:QL?^/[^?L,P`,"99+WM"A,`0);EPX</
MTXFFIJ;JZNI3IT[MW[_?8K$`P.[=N]>N71L(!&(Z/77J5'5U]:%#AZQ6*P"\
M]]Y[SSSS#+UE=`B"P!$+8W(OK/_=_GT'8_,7SE^,_>8YGB/"OZW_W9YW]L4F
M__)U[7\=/+)QT\L/_F*1;FA.IQUCK.MZ(F[_'?-2G@,`-H?E-M?8N'7U1U+@
MR`Y'CQ[=L&$#->FSSSX;0QX3J*JJ>NZYYP"@MK9VS9HU,>0T7SB=3JO%LJ/R
MG1CRV,+8L%BL>][>%T,>$P@&0__R[/.7_M+D[Y&&^\,88],T_7[_.,!_^NFG
M](58CA&LW&T(O'XSH<"T:=/V[-E3557UR"./T)D]>_;T]O9NV[8M'`X#@,?C
MV;U[][%CQU:N7$D%WGWWW9Z>GAT[=H1"(0"8,F7*SIT[3YX\>>3(D2U;MO3W
M#^S:^1:5_/M5*S\X=GCO_G?N*RP8T1'+=G?W;*_<21]_\P\K_J?ZHT.']Y?,
MG$'-MJMR=V!0CDHZ3?@\SR<4\`X=.M38V.CW^V\2+W([AZ<<EIIKRY8M#S_\
M,``\]-!#)24EERY="@:#QX\?KZ^O!P"&85Y[[36JER5+EK2TM%#W_O###R]>
MO$CMMFG3IA4K5E!WNW#A0EU=G=_G!X"?E,[<],?_4'4%(YR<FORKI2L51>4X
MMK[NF]Z>&P!0Y"W<^)^O6*U61=;6K5OWC[]=K:IJ?7T](<1JM69E965G9R>:
MYVMJ:JBK`P!O8;.F3>!X=DQI31MAYAS'E965Q>9S<W,O7;H$`'U]?=3L/,_'
MUV%%146UM;4`T-O;2\W.\WR,'1!"1%$<&AJBCX5%!8HF1Z(B@YF\@AQ!$!1%
MQ0@'`@'*9#H[NA;,^YFAZZ8)""'*2D51]'@\,V;,F#1I4B)F'P%O&`9"8+4+
MF3D3IMZ7<8>JUC1N.3S-"_'L8'09%\?#8O5,O$!L!X30:-*F:ZH6-3#!^E@M
M@W"8JCA^S)@Q8[R,@P#`A$GNC"DIDSRI-J=P%SX<5X'$Z.1H!=V<)^16*F$8
MY@ZK-$W3=3UV^S#&#&8(PV+,8$2HL@S3E,+1&$&@&]+=,,9>K[>RLG*\+(L`
MP+S%Q;=S\M'%!F%BMAH3!B&$9CM%49J:FK*RLNA\9V?G2"7K<'Q_(:U5Z$(`
MZ&COY%D+I?==;=V2+-,\QW,CMO%X/'OW[K7;[2S+&H9!",G-S8WI-_&!`2!!
MY`!`R*UB/G:3XX?;[2XN+J;&7+MV[;ESY[JZNM:M6_?%%U\`@,5BF3=O'@VK
M\:.SLU-1E-S<7(O5`@!??G%^Z^O;0P&YH_7ZAG_]=R6J`$!^05Y969G#X0"`
MMK:VHT>/IJ>G>SR>G)R<_/S\'X!\=)Z_.WB6H0Z+$(KW^7C+/_WTTS0#U]?7
M/_#``T5%1:^^^BK5U-*E2\O+R[\/OKV]/1*).)V.Y;]<1F/0IC]LGC=KX8,_
M_<7GY[ZD,K_^]:\<#@>M'75=?_WUUW-R<B9.G#AQXL11Y/*O!1YC3".3JJJQ
MX!P?SP*!P/SY\U]XX05J"E558Y%IUJQ96[=N-0R#:BWFY*(H=G1TA$(A,1+Z
MYW7_M'#12(H219':'&.\X<5UA46%@X.#JU>OGC]_/A6(1"+!8#`8#"98P]V]
MJKO#,$U#-[34U%2_?]AFLPT,#$0B$4I7;3:;S6:+!;F77W[9Z_7NVK6KH:%!
MEN7,S,S%BQ>_^.*+24E)P\/#;K=;EF6KU4J%/_KH(U$4.8Z35-'B8';\Z8\'
M]O[W\:J3[>V=`L^7S"Q>M?HW9>4_J?_Z:B@@9F1D'#]^?./&C5555=>N7:.6
MH+[P`UO7U1</)&#SD4X.QUAN=/I]`P&_WY^6EK9TZ=(?TTCS^7R;-V\>&AIB
M&.;O'BSQY$ZV\':."(0A"&$`TS`,55>ZNVY</'M9DN2"@H)''WWT'K>N$S&[
MHD5#$3]A1`6'OVUK%4/AUM96M]N=")>Z7<&[;]\^G\]GFF9*NC,YPRY%156+
M,@R+$8ZUV'1#:[[2VM?73[L@]["'20"@]9OKE-(2EB$LPQ#,$(87V'B&;YJF
M;JBRJF,-LW807'"MRZ_K^L<??SR*S"4^WG[[[=;65L,P.)Y,G^,!9&J&JAL:
MTJ(Q(F2:9M`?;F^]'HU&&8:Y]^#KO_P68X0PPAAC!F.,,(.L-F'V3PM'X3=-
MW0`=`*9Z)_;W^@9[`Z(H'CER1-?UN7/GCNO@-]YXX\J5*X9AF*9Y7VFV*\4^
M<@288!K?N9\,"!96#$1T73]QXD1F9F9>7MX]^VA15E9FFF`:IJ$;NJ9KJJY&
MM8@HVQS"V/T<`$*8I`G.@1Y_5%*CT>C5JU=[>GJ\7F\\J[O=:&QL?//--]O;
MVVFT+Y@YN:!D2LS48S1\.)(TP3'0,QR555F6FYN;2TM+8XSHQWZTV+%CAZ(H
MJJIJFJ8H2C0:'1H:,@S#F62=MV2&U7[;(B'HC_S?N9:!WF$:/UPN5W%Q\=RY
M<\=LFP>#P8:&AK-GSW9W=]/&`4*HJ"P[?^:4,?OVHT-C?_"KTXV2&`6`C(R,
MYY]_/L'JY0X![V_Y(RW\/X]%/&2Z+[JO`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VAE;'!?:6YD97@N<&YG````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,3$Q(#$P-3$U-#,S-S4R(#`R
M,S0T-0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,````$9T%-00``
MV.OU'!2J```#`%!,5$7___\```#FYN@N+S165UEP<7.>I:^[O<`B)RY%2$Q8
M6U]B96E!1DQ%24YE:6Y$8'Y"7'A(9()-:8=/:XE2;HQ3;XU3;8I8=))@>YAE
M?YMF@)QKA:%=;X."F+%%4%R-H+9C;WR:JKQ88&F>J[FDL;^ON\DQ3FLS4&XR
M3VPR3FLZ5W4\6'0_6G5%87U*8GI)8'A:=I,6'20-$15=>)1.97Q39WQ.7W%9
M;(`]2E=><80Z1$YN?Y!TA99ZBIN;K;\=("-A:G.KNLE;8FE"1TQ&2U"JLKI+
M3E&/E)E;7F%G:FVNL++P\?+N[_#GZ.G+S,TT46TU4FX]671-8'%^CY\O/4DS
M.T(N-3M.5ETB+#0^3%="1TMB9FG=X>1)3$[DY^E=<7OK[>Y@<WOO\/!L>7)Q
M?G>"B'2@H8'NUH!.3DX\/#PE)24.#@[___\`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````NN'=(`````7123E,`0.;89@````%B2T=$`(@%
M'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-10?5"AP&'0%2OO>"````
MLDE$050HD6-@P`8X&&$`*I"M:"RF&ZBM(V`&$6%TE!1.3T]/U=2/A"C(LC-(
M2U172P\P"P>K8%21$N%/24]/UK.(904)9,J+"\6GJZGYFX:Q@%0PJDJ+"FII
MJ*F9A'B"=63(2@CS`Q6H!85&@16P!=O:6%O*R)C+<4&,5&+F=7/CY'%VX>.&
M"#A$>_DR)?DD^+E#7&7/R&BEH!P3Y\WN`7,X`\@3$4ZN<#X8&#$R&C)@!0!,
M.1M(*A[`O0````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O:&]R9&4N<&YG````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#$Q-3(@,3`U,34T,S,W-3(@,#(R-#,S`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````0
M````$`@&````'_/_80````9B2T=$`/\`_P#_H+VGDP````EP2%ES```N(P``
M+B,!>*4_=@````=T24U%!]0,%0\W.KH;@(X```'W241!5!C3I9--:!-!&(:?
MW6[^2%?1@Q4:ZD'S(\%#`D(LFD2PO?A[\%`"-E9:VHK@32@2;X+:0Q$)B#>A
MH(>`+806H6!+<C`4%&V%6*@0M?%0%2N&9)/-CH=`0V13D+ZWF6_FX>-[9B1`
ML(LH`"<B;D:';A,*A?[KLL_G0P88O/N+9ZDGIH>*Q2*:IK6%R``'7#*V@^\H
M%`HMQ5PN1V+R$C<3?2PN+;8'5"O0>\[&H^3#[4(ZG69Z_CIC#^Q<&*\S-S?;
M?@8U3=#5T\$^?X8;$V>@TDWGH56N3#BQV&!Y02,^.+P#H-H0T1]SH-<T2K_7
M<>YQ8AB"K4THKO3@'_&W!]@<TO:&U2XARQ)Z36"U2ZSF-"*ARSMK7'I1X>N:
MC!#@<AL$3UMQ[I6IUP7[NV3>9EX3(V8*D`"13"8)A\,`9+-9GL].T3_R'=<1
M!<4"\T_+2,7S>#Q'4545554)!H,$`H$&()_/M[:E*%P;/\M`X@>.3HF:!AOK
M.N62H%H1E+8,-M_W,I-ZV=#X;W1=)SYPB^4%#8M-HD.!P\<L!")63EVT<[S/
MSI=O'YKOP"S1:)2-CPK":*R-NN#SFL[T_3_,W',S>O5.<XBFPY$DA&B:>94J
M\W/E)$/Q,;Q>;ZL%LV0R&;H]=3H4"]6*X-,;)X\GI\PM[.8[_P4+A:K^#!8T
MW`````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O<V5A<F-H+G!N9P``````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#(S-3<@,3`U,34T,S,W-3(@,#(R-C`W`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````0````$`@#````*"T/4P````1G04U!``"QCGS[49,````@8TA230``
M>B4``("#``#Y_P``@.D``'4P``#J8```.I@``!=ODE_%1@```P!03%1%]O;W
M^?K\]?;X.$-1Z>[T:8&<77**1%-D3V!S@)NX?):R@YZ[A:"]A)VYB**^A)RX
MB:*^0T]=;X.9A9VWC*2^C:2]AYNQEZW%A):JHK7*T]WHU^#JU][FY>OR05%B
M0E)C.4=5;XFD<XVH:H*;:X*:9GR377&&8'2):X&8AJ&]B*._<XJA:G^5872(
M04Y;<(:<:G^4BZ;!:7V2C:C#7G""E*S%E:S$E*O#BY^TF*W#EZF[CI^PG['$
MD:*SL</6J[S-ML?9K\#1M<;7N<C7N<3/S-?BN<++Y^WSX^;I]??Y/4M8<8><
MHK;)U-_IUMSAT]G>\O;YU=SAN;FYL;&QD)"0>GIZ=W=W=75U<W-S<'!P;V]O
M;FYN9F9F7EY>7%Q<6UM;6%A85U=75E964E)24%!03T]/24E)0T-#/CX^/3T]
M.CHZ,3$Q+R\O*RLK*2DI)B8F)24E(R,C&AH:%A86#0T-"@H*"0D)"`@(!P<'
M!@8&!04%!`0$`0$!````@("`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M0Q"UFP```']T4DY3____________________________________________
M____________________________________________________________
M____________________________________________________________
M____`/_A/`D````)<$A9<P``"Q,```L3`0":G!@```#.241!5"C/8Z@#@ZCT
M[-J:O.30NCH&,#^I5-#(6UO#JRP>(A!99F+MYB?CPZ56%@H6R-"S]6?P9)$V
MY61/`0OD&[@P!;!(V6F**.6"!6KU/1C=?1T,><SX:R`".H&R4@[&6MR2PK5@
M@2)U*U<G0RT^<T?%;+!`%K.*&"^W@+BSJ'P<2"`\MII#5<+"QMZ2K2H,))"0
M4UNJH"NDS"I7F0AT6&1M54516F9A36U!4@30Z3'Y02'%J75PP%`2'%U;6X<D
M4`[DQR,+Q-?6)B'QZP!.FEM.]'OPRP````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]G<F]U<"YP;F<`````
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C,R-2`Q,#4Q-30S
M,S<U,B`P,C(T-S$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````
M!&=!34$``+&.?/M1DP```"!C2%)-``!Z)0``@(,``/G_``"`Z0``=3```.I@
M```ZF```%V^27\5&```#`%!,5$4("`D4%!86%A@;&QP4%1<5%AC+TMS#Q\T.
M$QH.%!L1&"`0%AU$77E)9(%3;8EH?I:*GK2`D*(-$QD.%!I=>994;8=:<HM<
M=(Q3:'U:<(=K@9=9:GP?)2LC*"V"DZ3,U-S-T]E.9'EJAJ%*76]RCJF`EJML
M?(M=:WB)FZL.%1N)G*R!D9]R>7_<XN?=X>0E*"K(R\TU2DT1%Q0%"P=HIVDI
M?RDI?BHG=2@MA2TM@2TN@"XQAS$UBC8YDCE$C40X;CA/?D\G628P8B!/<D(9
M*Q`?*@T$!`(^/#9S<&>MJ9RII9@H)R3FX=#;UL?PZMF`?7:6:1J@<Q[4FC[1
MC2?6D"G:EB_=F#'2ESM*038:#@$2"@&J7PJL8`S$<!._;1.^;1.^;A.];!//
M>1S.>1QQ/PJ,3@TK&`1I.@J$2@VZ9A/-=AJ\;1M(1D0D%@D<$PLC&`Y33$8#
M`0`$`0!M:VMZ>7EG9V=:6EH%!04"`@(```#___\`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````S$L1V````>W123E/_____________
M____________________________________________________________
M____________________________________________________________
M_____________________________P"3PZCJ````"7!(67,```L2```+$@'2
MW7[\````N$E$050HSV.H@H'*2C#%`.-[^OAY5<(%&)D8?/W\_&`"S.5EI17^
M0>%P`;?BDL(B[[!0N$!D=D)\HGM(L)\'5"`J*3DK-B(P`&P(2"`M,S4CSM7)
MV<[*OA(LD!>3DA[MXFAB8V4)%F#1*<C-SS$T=K"U,`4)L*JIJ!NP"XHI&EF;
MF8,$]`64I/5TM?A%N2LKP8;*JHI(*+!IR(MS0?TB(\6GK"TGR<NC"?.<L#`G
M)Z<PAU`5JF]A```B$EE50;2K&@````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V-L;W-E+G!N9P``````````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P-#0S(#$P-3$U-#,S-S4R(#`R,C0T,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$````!`(`P```"@M#U,````S4$Q4104`!QP<'!T='3DY.5145%55
M57)R<HB(B(Z.CJ:FIJJJJKN[N\?'Q^/CX_[^_O___P```!":08T````!=%).
M4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<&`````=T
M24U%!]4$&A`("P<NQO<```!I241!5'C:78]9$H`@#$-95+!0F_N?UD)E&?.7
M-^D2YQPV.17*4D+W,M0)S#]&#)Q`%?$(/!(1GI7R2`B'=H'FB`BI/V0#+4([
MB&V$%[B`'!`FT`U9&#@G(-+'*M%MH,S'2_K*C&K=_^N_F],,42+]HT<`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]Z
M82YP;F<`````````````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,#(W,"`Q,#4Q-30S,S<U,B`P,C$W-#0`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@````D````)
M`@,```"=_^Z#````"5!,5$6Z`!9F9F8```",M<Q"`````7123E,`0.;89@``
M``%B2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-10?4#!01
M-@M<VECJ````*$E$051XVF-@``*M50P,4BL9&+A6,#"P+6%@8%K`P,`X`2C1
M`))E``!9YP2G>URP]`````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;&]C:V5D+G!N9P``
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$S,#8@,3`U,34T
M,S,W-3(@,#(R-3<T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P``
M`0Y03%1%````!`,"!00#"`@("0D)"PL'$Q$.&A,+%A86'!P<(!T<'AX>+RDA
M*RLK+2TM+BXN.#@X34U-@5HK<G)RJF\KI'$V>GIZK'$NK7,RH'=$HWM+A(2$
MI'Y.J(%,M'X^IX)2IX)3N(`^JH15JX=8K(=8NH1"JXA8NH9'O(=&O(A)NHE+
MKXU>K8UDO(I,L(U?O8Q.I9%VOHU0FY>4QI9=QYMDJ*.>RI]HJJJJRZ1QSJ1P
MS:9NS:9VT*9TS*=[T*ATSZM\L;&QSZQ[S:R#SJV#U*QYU:Y^TK*)U;*$V+6,
MO+R\OKZ^UKJ4P,#`P<#`PL+"VKZ:X,*>X<*<X,2@W\2CX<2@XL6AX\:BTM+2
MV]O;````>T!('@````%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,`
M``L3```+$P$`FIP8````!W1)344'U`P4$BP$?@X!^0```(QT15AT0V]M;65N
M=`!-96YU+7-I>F5D(&EC;VX*/3T]/3T]/3T]/0H**&,I(#(P,#,@2F%K=6(@
M)VII;6UA8R<@4W1E:6YE<BP@"FAT='`Z+R]J:6UM86,N;75S:6-H86QL+F-Z
M"@IC<F5A=&5D('=I=&@@=&AE($=)35`L"FAT='`Z+R]W=W<N9VEM<"YO<F=G
MBL='````F4E$051XVF-@P`XB@0")RRT6'A'A*<P,%Y#V$N#D%'20AO'Y_%A`
M%+\Y3!>O#YC%X0L38#/B8F5D9.(Q98?:8!`4'.SO[^]M+011$AGJ8:8B+Z\@
MI2D.%0ASU7.WMW>TT!"!"H38F"C)R,A(JL)4!%KJN#DY.=LJ2D`%`ERLM)65
MU60UY*`"=L:&AEI:^KKJHI$(GT$`-G\#``#B'1>*I_]=`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9&5L971E
M+G!N9P``````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$T-C8@
M,3`U,34T,S,W-3(@,#(R-C`T`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````0````$`@#````
M*"T/4P```8!03%1%````"`@($!`($!`0&!@0&!@8(2$8(2$A*2DA*2DI,3$I
M.3DI,3$Q.3DQ.3DY0D(Q0D(Y2DHY0D)"2D)"2DI"2DI*4E)"6E)*6EI28V-2
M8V-::V-::VM::V-C:VMC<VMC<W-C>W-C>WMC>WMK>WMS>WM[`/\`A(1SC(QS
MC(Q[C(R$E)2$G)R$G)R,G)R4I9R,I:6,I:64I:6<K:V4K:V<M;6<O;6<I:VE
MK:VEM;6MO;6EM;6UO<:]QKVEQL:EQL:MQL:]UM:]QL;&UM;.WM[&WM[.WM[6
MWM[>Y^?.[^?.Y^?6[^?6[^_>]^_6]^_>[^_G]_?G]_?O__?O____________
M____________________________________________________________
M____________________________________________________________
M________________________________________________A:+W/@```(!T
M4DY3________________________________________________________
M____________________________________________________________
M_____________________________________________________P`X!4MG
M`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```,-)1$%4&-,]
MS_T/@6`0!_!+Z"DBI!="9"/O(</FI:&%$/^0?UT]3[G;;M]]?KC;P3<JJEPM
ML(!C-`%ZS_?K*`$0H/>[3H7A>M/9#")@G;.WK?&\.K+M4,*^OP/_YNP7N\.J
MC:'_^(05^)>Q*D?PE?2)=_5.IEX7$%Z:R8N-5E.3>3J=P8`L,8]8BDH5N"R!
M^4:W]**6TWB&P-HU3Z8\+!D22F#@+A5+_$,W@?@*(PR4$(:B@K+)<X)I"!K'
MQL]AH@!(_`%4P#NN>&B9+0````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M=7-E<BYP;F<`````````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#(S-#(@,3`U,34T,S,W-3(@,#(R,S$R`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````0````
M$`@#````*"T/4P````1G04U!``"QCGS[49,````@8TA230``>B4``("#``#Y
M_P``@.D``'4P``#J8```.I@``!=ODE_%1@```P!03%1%(B(C"@P0Q<;(#!`6
MYNCK)2@L#!`5*"PQ-T96&!XE;W^1?(J9EJ&MH*NWN\;216%^36J'4FZ+3FB#
M77F5"@T09H*>15AK:(2@56R#/4U>67"(;8FE6&Z$<XZJ"0L-8'*%?I6L'2(G
M9&]ZC9FEB9"7U=OAY^KM\O/T3F9]9X.>7'2+;XNF159F=9&L4&-U?)6MB9VP
MBIZPFJR]I[C';WJ$&1T@D9F?D)B>R=/;"0T/$A05$Q46#1$2$1$0&!@72TA$
M$PH`&P\!020%-A\%FU@/RW49S'8:R'0:T7H=T'H=T7L>Q74<PG,<TWT?Q70=
MP7,=#@<`"@4`"`0`-1P"%0L!)A0",AL#938'1R8%6S$'-1T$-!P$DT\-+!@$
MI5P0?$4,*1<$K&`1BDP.>4,,M603)A4$'1`#OFH5MF84J5\3+1D%@TD/RG(8
MS'49S78:S'4:&`X$+A@#0B,%-!L$,1H$+QD$.A\%638512\:3#HI&A(,)!X:
M*28FS,S,1$1$)24E'1T=!@8&````____````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````KX]Z*P```(1T
M4DY3________________________________________________________
M____________________________________________________________
M__________________________________________________________\`
ME](VO@````EP2%ES```+$@``"Q(!TMU^_````+Q)1$%4*,]C:`:!)A``LYH9
M0(1MD[U](%0$)-#0:%]7#U1B"Q.P<Z@,"4A+=6Z$"3@Z>?OY^[C'!\$$8B,]
MO'P]\Y*S8`(EF;EN^:XY&:4P@3*7].S0PJ24(KBU$3%AB7$1X<$P`9N:\N*H
MZ(0*3CF(`*N9@4EU016#DHZD)4B`G5=65T^EEDF92T)&3*29P<I<7UI;BUM=
MS5A!55B#@Y'!FD=44UQ*GL7"2)5/55"(C<'44``)\#,S**(!`&EU5,O<[92W
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]I;F9O+G!N9P``````````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`U,R`Q,#4Q-30S,S<U,B`P,C(R
M-C8`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````!&=!34$``-CK
M]1P4J@```"!C2%)-``!MF```<XX``-3/``![#P``>/8``,OR```RC```(TU(
M$62R```#`%!,5$4```#____HY^C@W^#8U]B6E9;?W^#7U]CGZ.C7V-B5EI;7
MV-?8V-?0T,^6EI7HY^?0S\^6E97P\/#HZ.C@X.#8V-C7U]>PL+"@H*"6EI9^
M?GYM;6UL;&S___\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#+N72S````'G123E/_________________________
M_____________P#L&!Q>````"7!(67,```L2```+$@'2W7[\````:TE$050H
MSWV/R0Z`,`A$4:NMN[8NH.W__Z;@H:F:^,+IS4`"P(<LQ8JP*;<`0!YK$:,0
M$O%9\0S'&!L>T3\;(OX;KQO&Y<[D;G2"B(4&*FDF:H:B8E'K;=.=6I52:ZL!
MPC'MD?YD$=+70[@`#A@,U`L'DF<`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+VQA>6]U="YP;F<`````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P-#<R(#$P-3$U-#,S-S4R(#`R,C8U,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$```
M`!`(`P```"@M#U,```!.4$Q410```*">E[>UL+BVL>3`0>7!1,7$P.G+8NO0
M<NS1=>[7A]?6U.[8B]C7U=G8UMK9U]O:V-S;V=[=V_/CJO3EL?3EL^SLZ^WM
M[/+R\0```'&<)Q,````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES
M```+$@``"Q(!TMU^_`````=T24U%!]0,"!(=.F/]\\<```!E241!5'C:=<WA
M"H`@#$91TTK-FI6F[?U?-)7!L.C[M\O@".PG!([&&+OBG7+.9PTFQA@T)N<V
MD!2N$G*Y0?4?WK=@0YG&`\#O+2QU$\Y2*374\&')8Y8\9LECECQFR6.6O'_V
MO0?4/0\G9KL#,@````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]R:&%N9"YP;F<`
M````````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#0R-R`Q,#4Q
M-30S,S<U,R`P,C(T,S,`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```"$````.!`,```!3,&B_
M````&%!,5$7____`P,"_O[^`@(```/\``(````````!:[7A3`````G123E/_
M`.6W,$H````!8DM'1`9A9KA]````"7!(67,```!(````2`!&R6L^````BDE$
M050HD6W/00J#,!0$T$'!=3YHUN47_KHDD!.H)U#7B8&Y_Q&ZB$5:.IN!MQD&
M\A.'UIYD^9(,P%A$Q,&3%`\`736*.(SSO#(#/=4"6)J\`!A.K0IK$H">&$CJ
M1QXP4),(B\.T+&M43;EK\P[CMATQ:![.YR73OA^L@3#*+>)KI*9+/%G^O;CC
MWH=$)4M.+IH0`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;V9F:6-E+G!N9P``````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(S,3$@,3`U,34T,S,W-3,@,#(R
M-38T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P````1G04U!``"Q
MCGS[49,````@8TA230``>B4``("#``#Y_P``@.D``'4P``#J8```.I@``!=O
MDE_%1@```P!03%1%=W9WEI66DY*3DI&2@H&"@8"!?7U^>7EZ>'AY<W-TQ\?(
MP,#!J*BIH:&BBXN,BHJ+?G]_?7Y^?'U]<W1T:VQL86)BF9J:DY24C(V-@H.#
M?7Y]>7IY<7)Q<'%PR<K)EI>6E)64BXR+AXB'AH>&@(!_>WMZF9F8CHZ-@H*!
M@']_?7Q\?'M[>WIZGYZ>G9R<E924E).3DY*2DI&1BHF)B8B(B(>'AH6%V]O;
MV=G9S\_/SL[.R\O+RLK*R,C(Q\?'PL+"P<'!O+R\M+2TJ*BHH*"@GY^?G9V=
MFYN;F9F9F)B8EY>7EI:6D9&1D)"0CX^/CHZ.BXN+BHJ*AX>'AH:&A86%A(2$
M@X.#@8&!?GY^?7U]?'Q\>WM[>GIZ>7EY>'AX=W=W=G9V=75U<W-S<G)R<'!P
M;FYN:6EI:&AH9F9F965E8&!@````____````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````@0:T$@```&UT4DY3________________________
M____________________________________________________________
M____________________________________________________________
M`"VVU$L````)<$A9<P``"Q,```L3`0":G!@```"Z241!5"C/8\A!`PP0*AL(
M8`+9*""'(=O<$0BRP<C1T3F;(=O"*CW+"0RR@#1(@)O;P=Z.RU;.QMK*TA4H
MP"W+&:\C&!ZJ%*!NI"\,$DA.B-72E`PVEO`U\$H`"23&:0NPF)DH^C%Y>\2!
M!!A4I<)#@P+\F14\W:5!`NQ1*F'*@1*^XO)B;C$@@>@(C1`3/C]#1C4]%R&0
M0"1KJ"F_OP]0@RYO!%"`1S0S(TTD528I@4.'+24;TR_HW@<`(B%,7KJ^UYP`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]D871A=')E92YP;F<`````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#4V-B`Q,#4Q-30S,S<U,R`P,C,Q,S0`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!``
M```0"`8````?\_]A````!F)+1T0```````#Y0[M_```!*TE$050X3Z62.VK#
M0!1%M1KWJ;*(D&0#@30B8$AO`B%-6H.40H*@/Q'J5&4'*KP0]];__WO)&QC/
MV)(+HX%3B7/OG4&"(`BP$`'>Y1]XVDA7<?_RP0*>WR2X6W]>Q>VCR`+P]'U_
MD:[KH&U;:)J&4%45N*X[#?!]_T3\_O_V^[4^RG5=$[DL2[!M>SZ`0@.0<SG/
M<W`<9SY@;C(O%T4!699=7L#+O'CS\$K`]C1-0575^8`YL!7?`@.P/4D2D"2)
M!8SC.)F,(IV,K2AB,\I1%($LRRQ@&(;)9-I,Y=5F18CC&,(PA.UVRP)P_OE#
M\5?`9AJ`[8?#X30`97XFG8IM*&`C2CR*HK"`_7X/01#`;K<C>)X'IFD2#,,`
M7=<)FJ:!95E$%D7N5U[(LO,'BZ^28&3PF^D`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O961I="US;6%L
M;"YP;F<`````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`T-#`@,3`U
M,34T,S,W-3,@,#(S,S8U`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````)````"0@#````UT_V
M(@```&!03%1%YN;F^-DX3T$595P^7$\K\;5-]K1$UZYT_.D\2TM+2$A(145%
M0T-#0$!`.3DY-#0T,3$Q+BXN+2TM+"PL*2DI____````````````````````
M````````````````````_A/20@````%T4DY3`$#FV&8````!8DM'1`"(!1U(
M````"7!(67,```L3```+$P$`FIP8````!W1)344'U0<."!\L+4F_V@```#E)
M1$%4"-=C8``#3DY.*(.#E1_,X.)@8P:SN&$,'D8V9@$0@Y>1E440K(B/G5D8
MHHU)2`1F$H1F```[5`%246O)O0````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W)E<75I<F5D+G!N9P``````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,C,P(#$P-3$U-#,S-S4S(#`R
M,S$T-P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````"@````H!`P```+?\7?X````&4$Q41;4`
M`````.]@.PD````"=%).4_\`Y;<P2@````%B2T=$`?\"+=X````)<$A9<P``
M`$@```!(`$;):SX````=241!5`C78_A_@.$S&$UR8&AP8'AX`(3.@-'_`P#<
M_P[1P'"L+0````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]I;F9O7VEC;VXN<&YG````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,3`P,2`Q,#4Q-30S,S<U,R`P,C,R-C<`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!`````0"`,````H+0]3````P%!,5$4````,$QH4&R,5&R,<
M(RLC.$TR1EPO2V<P2V<S3VPT3VPU4G`Y5G1$6&P]6GA`6WA*6FU"7GQ&8H!*
M9H1+9H-.:HA5;8=3;XU4;XQ7<Y%;=Y5E=HE?>))@>)%?>YEC?YUG?YIH@Z%L
MAZ5NAZ%WAI9]BIB!EJV`F+.'FZZ6J+V8JKV9K,"<K+VBLL.EM,:FM<BPO<[_
M__________________________________________________________^F
M=RM[````0'123E/_____________________________________________
M______________________________________\`PGNQ1`````%B2T=$/SYC
M,'4````)<$A9<P```$@```!(`$;):SX```".241!5!C3=8]7#L(P$$2'$II-
MZ(2$$GH)=4Z0^]^*W8TH0F(^++VW8WF-_"<H3LM'8)N=3_LV7J)Z/ZQ7Z2*9
M5`J!AS"9Q-%0*<=4YV0<C08UJ,BLK]SOF+@)DQ3NA2:N.B>5O8F+]DGEEHG=
M1NZ3PBZ`/7M<"I/>-5`L5I[/M._JI??JW7'HFP'^?^X[3X8-)<-`E=/[````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]D;W=N;&]A9"YP;F<`````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#,W,R`Q,#4Q-30S,S<U,R`P,C,Q-#8`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!`````0!`,```#MW>)2````,%!,5$6```````#_
M``!_?W_`P,#___\`@```_P#________________________________6&,+;
M````"7123E/__________P!33W@2`````6)+1T0/&+H`V0````EP2%ES````
M2````$@`1LEK/@```$])1$%4"-=CZ.CH:&`$$@P@AB(N1@.#HB!$A$E)`D7*
MV-A8V-C8@J'9!0P,&4Q#02#8D,$$Q'<KAC)<G($,8Q``,<!J@`QC")!@:!0$
M@PX`X^<J.JA\;5$`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O;&]G;W5T+G!N9P``````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`W-#<@,3`U,34T,S,W-3,@,#(R-C4U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````0````$`@#````*"T/4P```,!03%1%````#A$,%QT5'24;("D:*C4F
M,3TL-$$O.4<S0E0]25Q"451/6UM:3V1(4VE,7&!9;&QJ>7EW8(%(B```F0``
MF3DIHA(,L!8*L1L0JC\LL4TVLU,^R#XKWT(>Y&)%YW5;C8V+F9F8J*BFN+BV
MP,"]R<G'T-#-U=72X.#>XN+@````````````````````````````````````
M````````````````````````````````````````````````````FL`]P@``
M`"MT4DY3____________________________________________________
M____`"/)I]`````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````
MB4E$0508TW7/T1*"(!"%X:-&F94FE*65@FA8[_^`[9)ITTS_!0S?!0MX_H3W
M.O6!A^M:/0'M!-;,4,.YGB!@X)H+[AX"AIJZ5;"M01AZ.%'G(_(MHH6'`Z4J
M[`V$8+@6A5(E>(I8CI?2V8\5,8&4$B4&`CT#,/1F@]4Z&1\6P6:(DUV:XM_G
MOGH!SJD54T>8+H``````245.1*Y"8((`````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L
M;V-K+G!N9P``````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R
M,38P(#$P-3$U-#,S-S4S(#`R,C0R-0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````$````!`(
M`P```"@M#U,````$9T%-00``L8Y\^U&3````(&-(4DT``'HE``"`@P``^?\`
M`(#I``!U,```ZF```#J8```7;Y)?Q48```,`4$Q411<?%A4<%!TE'%=O4Z.V
MH%UV6'&/:W".:FZ+:&V*9U]X6EYW66!Y6X6>@(*8?F2`7F-^75%G3&Z+9V%[
M6UAP4UIR56J&9%QT5VV#:(:>@:&SG0T1#&-^7&6`7E)H3&F%8FB$861^76%Z
M6FN'9&J&8VB#86>"8%MS56V)9FR(96F$8F>!8&F#8G**;'B.<GR/=X::@869
M@(VAB).FCIRLF)RKF!HA&%IQ4QPC&H"4>HF>@X>:@8V@AX^@B9^MFJ"NFYNI
ME0<)!A(6$````/___P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#=-=S8```!%=%).
M4___________________________________________________________
M________________________________`++NL3@````)<$A9<P``"Q,```L3
M`0":G!@```")241!5"C/8W!!`PS$"4B#@+.S,UR`T<[:QLA8`BH`E#`S$-!1
M51!Q!K$9G$T=G)D,^=6TQ$2=G:58G!F<[?5L^63X%;0T-81X);F!`B9*<N:*
MLEHJ&L*L/&P\0`%+06<+76TM90YQ9V=6H`JP059:\ISL7!!#058YZ:MS<W$S
M(]SA"`+(#B/-<P"BD#?/061(L`````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9&5V96PN<&YG````````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(Q,#8@,3`U,34T,S,W-3,@,#(R-#,R
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````0````$`@#````*"T/4P````1G04U!``"QCGS[
M49,````@8TA230``>B4``("#``#Y_P``@.D``'4P``#J8```.I@``!=ODE_%
M1@```P!03%1%%A8424E#&!@6YN;DLK*P[N[M75Q5B(>!D9"*L*^IMK6O0D$\
MB8B#=G1K;6MCD(Z&65A4G9R88%Y796-<EY6.GYV6*"<D@'UT0T(_DY&+JZFC
MU=312$9!-C0P(2`>C(N)W][<W=S:"@D([N[N````____````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````FU?PM0```"9T4DY3____________________________
M_____________________P"G>H&\````"7!(67,```L3```+$P$`FIP8````
M?DE$050HSVV/R0[",!!#`V4M#92$(2Q3UC?__XM<DBH"?+%DV;+M[`LN,U`)
M8#PQR`+O&2K*$K*P7XG([I"4$A'I0Y=\CH!*.!T'V2J8,V/>2G][39L4`\71
M#>[^B-EAQCJUS?4<Q]KV(BEYOR@MT*->F4"U=%,M_?WR[^V(#[*+'Z@DO2(`
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]W
M96)S:71E+G!N9P``````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,C0P-"`Q,#4Q-30S,S<U,R`P,C(W-S8`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!`````0
M"`,````H+0]3````!&=!34$``+&.?/M1DP```"!C2%)-``!Z)0``@(,``/G_
M``"`Z0``=3```.I@```ZF```%V^27\5&```#`%!,5$4```$'#10*'S4&$1P0
M*D08.%@6,U$:/5\-'B\8-E4&#10=/F`@0F0E1F88*CPO47(=)2T_14L[/D%I
M;&\C1&,H3&T<-4PI26@O57<-%R`R5G8S57,^8X8^77E,<)%);(M$8G].;XX>
M)R]]EZXS6'@M3&<^9(0^8X-*<)!8@:);>I5>?9=]G+4=(RB0JK^.I[Q`2U3&
MTMP##!,%"@Y-=95AB*=B@IM[G[M_H[^(JL1YEZ^!H;F$I+R!H+>`GK9]FK&-
MK<6`G+*)I[V+I[TY0TN9M,B;MLJ9LL:=M\J=MLF?M\JGO]&AN,JOQ-2KO\\N
M,C7(V.3'UN+-W.@'"@P1&!TI-C^!H[N7N-"4M<R7N,]]F*N2L,1=<'V-J+NA
MO=&;MLE#3U>LRMXT/4.MQ=:MQ=6JPM*IP=&\U>>DN<BOQ=6\TN'"U^:[T-XZ
M0$3`T=W+W.C&U^/%UN)*4%38Y>[9Y>W8Y.RON+ZVO\76X.=04U5IAIFKR-NR
MS^*BO,VEOLZ_V>FNQ=.[TN"^T^#'W.G$V.3(V^?&V./(V>3.W^K<Z?&[T=[2
MWN5^A8DW/4";J*_5Y.Q#14977F$&"0H```#___\`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!EF?-1````E712
M3E/_________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________`#9D&S@````)<$A9<P``"Q,```L3`0":G!@```#-
M241!5"C/8YB"!AA`A,O$R@E"@DIP@5SALI+._,!R_Q"(0&]/17]S=DMIL6'"
M))!`:%%W>U-]>E9A0%"&+DC`H"\OKKHFL;'`UR\E9C)0($G9SB$B/+*C+:<A
M/HH!*"#@[!1F;F'9VI59IZ<($I"4\TRV,=74L??V<N0':9&4=T]+M371D/%Q
MU>8$"1B+F7G4:JFI2\1&RS*#!*8PBKOI2ZM(B5I9,S&`'3:9JTJ!AU>$6Y5O
M\F2(TR<'<["QL[(8@?@0STV9#`8(WR(#`+X69SVIX6M*`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+W!R:6YT+G!N9P``````````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,3$V(#$P-3$U-#,S-S4S(#`R,C0V
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,```$=4$Q410```!L;
M&TU+1T]-25!-25%/2U%/3%)03%113E123F%>66%@7FMJ9VUM;&]N:W!O;'5U
M=7]^>W]^?(!^?(!_?(&`?HF'A8F(A8B(B(V-C8Z.CI"0D)*2DI.2D922D)23
MD):6EIN:F)Z=G)^>FYZ>GJ:FI*>GIZBHJ*NJIZNKJJRLJ:ZMJJ^NK+"NK+*P
MK;&QKK.QK[.RL+2TM+FXM;R[N[R\O+Z^O<"_O,+"PL7%Q<?&QL?'Q\O*R<_-
MS<[.SL_/S]'1T=/3T];4TMC7U-?7U]G8UMG9V-K9U]K:V=O;V=O;V]W;VMS<
MVMS<V]W<V][=W-[=W=_>W>+BXN7EY.GIZ>OKZ^SL[.[N[O3T\_?W]_CX^/KZ
M^OO[^____P```">S'D8````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP
M2%ES```+$0``"Q$!?V1?D0````=T24U%!]0,"!(I"!``4;````"J241!5'C:
M8V#`!N)@`,:/A8*P.)B`M*.CE(*UM0M<(#0$"$)#O>`"$E)2H0)&1@B!4`A`
M"$B'AJJHJZG90P3B3#3M3$'`DE<&)!)G$1,;'1L=$Q,=%6&F#!2)BXX,E@QW
M"/+P]W$VU&,$"E@Y>?L&!/JY>;J[BLJ#5-@J<7%PLK*S,#&SR8(%;,R-#?1U
M=+54-;1U%$$"<L)BXB(B0H)"_'P\W''(?@7[%P"D"#$IC\X.T@````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VAE;'`N<&YG````````````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,S$V(#$P-3$U-#,S-S4S
M(#`R,C(V-@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,````$9T%-
M00``L8Y\^U&3````(&-(4DT``'HE``"`@P``^?\``(#I``!U,```ZF```#J8
M```7;Y)?Q48```,`4$Q410```/___QT='#P\.WY]=[2SK=W<UO+QZ^'@VM33
MS]#/R\O*QLC'P_/R[O+Q[>SKY^3CW]C7TWY\=<"^MW5S;H:#?;&NJ//PZN?D
MWE%03F1C8=W;V(2!?;:SK]C5T?7R[NWJYNCEX>+?VV5A7%E54N?BWO+NZ^KF
MXW9S<=31S\K'Q;JWM?#MZ_3IXP@&!<F[M"XL*SLY.*:.A?#2Q_3CW61.1]R\
ML>C)O\I5->EL2NET5..!9N.,=)-=3NZ7?ZUX:.ZHE?"JE^&SIN.ZKMFYL*@T
M&=]))LQ(*>11+]]1,,Q++>AA0==C2,1B2]!K4]-N5NI[8<AU89M;3-:3@].3
M@NBBD?&IF-ZAD6154>;BX9$M%J@U&V\C$I0P&=1)*;I$*9`_+=9]:>V1?.BQ
MI0$```L*"D5"0A\>'@P,#/___P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````!AHG.P```!J=%).4___________________
M____________________________________________________________
M____________________________________________________________
M_P"\Y-SC````"7!(67,```N&```+A@%!!V6W````PDE$050HSV/(9&``(A#(
M`#$A6$..CUU"6RH5R`3+AQHK"BCR*]BX,F2"8;)CHCZK,(>YAUM,"E`-DV28
M3VQ$.H-D0H"WEZD!4$MD>+PAT*!,!M\D)V60&7Q<1H:9(&"HJR0*$A#7%&,`
M"S#P"HJ`!%2EN:$J=+3``MKJSD%@,T)<9)F!`JF2UE9V@4"'!ON[VZ9E@-P1
M[6GIH"9OXA<7%<4`<6F,A1D;)X\]B`\6T&.0E!%BT5`!<R&^@7@7ZM-,-```
M1O$WBEN3HO8`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O<VAE;&PN<&YG````````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`W,S0@,3`U,34T,S,W-3,@,#(R-#0W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```0````$`@#````*"T/4P```,!03%1%_/[\7++\3*[\E(ZD%(KL1':D%';<
M-&Z\/&JT-&J\+&JT/%ZD1%YL/%YT-%YT-%IT+%*$-$Y\1$ID3$I,/$I<)$J<
M'$J<'$J4/$9<'$J$#$:,'#YT)#I<)#94!#ID#"Y4%"I4#"I4!"I,#"9,#"94
M#"9$!")$````____````````````````````````````````````````````
M````````````````````````````````````````````````=G14E````"ET
M4DY3_____________________________________________________P!2
M]""'`````6)+1T0_/F,P=0````EP2%ES````2````$@`1LEK/@```(!)1$%4
M&--=CXL2@B`01:^6TL/LL9:EI-3Z^O\O#->PY,`RRYTSRX#!`U5^F]<U[P84
MN^T7I=3FT2)>.X(P6.T[1$?'(4V3$R/K_^$:]YX`LCW&P+QL`"+8JZ1B8+()
MDY$Y0Q0VOQFBB.&]<ED$UC@_M=9CR5DRWJ;A9M[<PO_^!UBQ&]4GU*L;````
M`$E%3D2N0F""````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5D:70N
M<&YG````````````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,S8U
M(#$P-3$U-#,S-S4S(#`R,C(V-@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````$````!`(`P``
M`"@M#U,```&`4$Q4149&1?SI//C9.$]!%65</EQ/*_&U3?:T1->N=/[^_OW]
M_?O[^_'Q\>[N[NSL[.KJZNCHZ.;FYN7EY>+BXLS,S,K*RL3$Q,'!P;V]O;N[
MNZ>GIX6%A8"`@'Y^?GU]?7Q\?'IZ>GEY>79V=G5U=7-S<W!P<&UM;6MK:V5E
M96-C8UY>7EE965A86%%144U-34M+2TI*2DE)24A(2$5%14-#0T!`0#T]/3P\
M/#DY.38V-C0T-#$Q,2\O+RXN+BTM+2PL+"LK*RHJ*BDI*24E)2,C(R$A(1T=
M'1D9&1<7%Q45%1(2$A$1$0\/#PP,#`L+"PD)"08&!O___P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````/:1IO\```!2
M=%).4_______________________________________________________
M_____________________________________________________P"M+0QQ
M`````6)+1T1_2+]QY0````EP2%ES````2````$@`1LEK/@```+!)1$%4&!D%
MP;TN!`$8`,#Y?JR]0J%Q)94(A41!$`_AM0E"(I$K%3J%4.QMG)B)6_<B,S+B
M!-K])XA%OQTAI:JJROKY6J$E(Y->OG]4';1B@G7\GKYL;;5D@2GGLZ=A4RW%
M!-/AX[`Y7[8(HVFT_SAL+O:T9"WFPX?^NVQ2RG$<HX:_JU71@C7'=]?]M)VT
M$MOS4#?/0M):S.;7"!2M"`@B:;43$(CO76TY1D9D9$8$_^[L*5BNR2V[````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+VME>6)O87)D+G!N9P``````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P-#`Q(#$P-3$U-#,S-S4S(#`R,S$R-P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$```
M`!`$`P```.W=XE(````>4$Q410``````__\``("`@*"@H/_`P-S<W,#_____
M_P```&NL?_4````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+
M$P``"Q,!`)J<&`````=T24U%!]0,%!,2*Y783>H```!<241!5'C:8V!@X)P)
M`@Q`AKJ$AE`EB"%4H:$NR0`6GUK1R3!1L*-):9*2)H0Q/0(J,J,(J@:D?48:
M&'@R3&L!`R##!00\@(P.#R#H@(FX@-1T``%0:@I$Q!)N#@#J;S%O=W-WZP``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F879I8V]N+FEC
M;P``````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C$W-B`Q,#4Q
M-30S,S<U,R`P,C(W-34`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````!``$`$!````$`(`!H!```%@```"@````0````(```
M``$`(````````````",N```C+@````````````````#_````_P```/\```#_
M````_P```/\```#_````_P```/\```#_````_P```/\```#_````_P```/\`
M``#_````_]C8V/_8V-C_V-C8_]C8V/_8V-C_H:&A_PY\8/\6UZ;_%<^@_QA-
M0/_8V-C_V-C8_]C8V/_8V-C_````_P```/_8V-C_V-C8_]C8V/_8V-C_V-C8
M_][>WO\15D7_%M.C_Q;3H_\-?V+_25)0_[&QL?_8V-C_V-C8_P```/\```#_
MV-C8_]C8V/_8V-C_V-C8_]C8V/_=W=W_$5=&_Q;3H_\5RYW_%<Z@_Q*RB?\+
M:5'_.D]*_YJ;FO\```#_````_]C8V/_8V-C_V-C8_]C8V/_8V-C_G9V=_PU^
M8?\6U:3_%<N=_Q;1HO\6V*?_%^"M_Q7'FO\<.S/_````_P```/_8V-C_V-C8
M_]C8V/_8V-C_W-S<_R=%/O\4PI;_%<Z?_Q7'FO\1I'__$)EV_P^1</\-@F7_
M1U10_P```/\```#_E965_]/3T__3T]/_EY>7_R9(/_\2K87_%M&A_Q;6I?\-
M=US_6EU=_X.#@_^0D)#_G9V=_\_/S_\```#_````_PZ#9?\074G_$%Q(_PZ!
M9/\4PI;_%M&A_Q70H/\1I7__1E%._]C8V/_8V-C_V-C8_]C8V/_8V-C_````
M_P```/\6U*3_%M2D_Q;4I/\6UJ7_%M"A_Q7+G?\6TZ/_#XYM_WY^?O_8V-C_
MV-C8_]C8V/_8V-C_V-C8_P```/\```#_%<N=_Q7+G?\6TZ/_%<Z?_Q3`E/\6
MSI__%<^@_Q7%F?\J1C__V-C8_]C8V/_8V-C_V-C8_]C8V/\```#_````_Q;1
MHO\5SI__#7E=_QQ11/\W243_"VA0_Q;1HO\6VJC_#'-9_ZVMK?_8V-C_V-C8
M_]C8V/_8V-C_````_P```/\7V*?_$K"(_TI.3/_8V-C_V-C8_XR,C/\+6$7_
M%M.C_Q.WCO])3T[_V-C8_]C8V/_8V-C_V-C8_P```/\```#_%^"M_PMD3O^Y
MN;G_V-C8_]C8V/_8V-C_H:&A_PY)._\63D#_F)F8_]C8V/_8V-C_V-C8_]C8
MV/\```#_````_Q7$E_\Z3$?_V-C8_]C8V/_8V-C_V-C8_]C8V/^^OK[_T='1
M_]C8V/_8V-C_V-C8_]C8V/_8V-C_````_P```/\E/SG_H*"@_]C8V/_8V-C_
MV-C8_]C8V/_8V-C_V-C8_]C8V/_8V-C_V-C8_]C8V/_8V-C_V-C8_P```/\`
M``#_````_P```/\```#_````_P```/\```#_````_P```/\```#_````_P``
M`/\```#_````_P```/\```#_````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V)L86YK+F=I9@``````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P,#4R(#$P-3$U-#,S-S4S(#`R,C0P,0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!'248X.6$!``$`
M@```````____(?D$`0```0`L``````$``0!``@%,`#L`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]D871A+G!N9P``````````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,3(P-R`Q,#4Q-30S,S<U,R`P,C(R-#4`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!``
M```0"`,````H+0]3```!+%!,5$4````!`0$"`P,#!`0#!`4%!04&!P@'!P<*
M"0@)"@H*"@H+"PL6%A08&!8A(!XH)R0A-D@V-#!#0C](1D$Z3%M)24-96%1)
M8'),8&U=7%5@7E=/9'598VUE8UQ4:7QM:V-R<G!V=&MK>()G>XN`?72(AX&)
MB(.,BXG'=&;'=&>,C(S'=6C(=FB0CH:0D)"3D8M_FJZWAWZ!FJZ7E8Z#GK*$
MH+7-AGK(BH"?G9:=G9V&I+F)IKRAH:'1CX2,J+W1D(2-J;[3D8:KJ:.PKZFH
ML;VVM:^VMK:ZN;:NO\W`P,#%Q<7(Q\*_R];-S<W'S]J_U>C*UM_5U-'6UM;7
MU]?+W>O/X.W?WMS;Y_'FYN3FYN;KZ^ON[N[Q\?'R\O+T]/3W^/KY^?G\_/S^
M_OX```!R:A(P`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``
M"Q(```L2`=+=?OP````'=$E-10?4#`@2)P7P,@"#````U$E$051XVF-@2$8!
M#`S)\2'FMF!@;^OH[Y_,D!SN8*BM"00:FCIF#G)`@5"'X"0H2#"5A@A`05",
MD3A"16)<%",CHSA<A1L7ER6K.[,(6"`Z*2F66TN!6]A"F$45).`1X.?#Z>UJ
M86&A:ZP"$G"P-C!29K.P$)-24U$$"=BY>#$R"EM("?$+6LB#!$R]O)+572W$
M^#AX(T!:K(R\?).9A"W4!'G4PV09DI5,C'PC!22XG%5<(P+U98&^DY&V\=1C
M=W6R4%%15)1D8(#Y7RQ96%$X610`L?4]@S"/>ML`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]A9&UI;FES=')A=&EO;BYP;F<`````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#4V,R`Q,#4Q-30S,S<U,R`P,C0S-C4`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!`````0"`,````H+0]3````8%!,5$4```"MK93.G#'_SF/&QL:$A(3O
M[^\Q,0"<8P!C8P#__YS__P"$``#_````G/\``/_.SC$Q``#.G````(136^]3
M6^]36^]36^]36^]36^]36^]36^]36^]36^]36^]36^^;E"$O````('123E/_
M________________________________________`%Q<&^T````!8DM'1`"(
M!1U(````"7!(67,```!(````2`!&R6L^````@$E$0508TTV.61;$(`@$VR7C
M@N.2'(#[WS*"/F?ZK^H!#9@9.RS!P6T.&/LOG(=U>V6Q@\$17AC6V&N+R1]G
M@ONU3&/F!&)"G(+AK>P@YDR($+[TAY032$N\12E?CD111&UJ"RAT0@):;9*0
MQSV0]&BMSX,\^DA:NX)^*Q_!6,PO;K@,*FHD/W,`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6%P
M7V5U+G!N9P``````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$T
M-#$@,3`U,34T,S,W-3,@,#(R-C`R`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````0````$`@#
M````*"T/4P```8!03%1%``#'`0''`@+'`@+(`P/'`P/(!07(!@;(!@;)"`C)
M"0G(#`S*#0W*#P_*$!#(%Q?`%A;,&!C-'!S#'1W.'Q_-(B+#)B:P)27$*BJQ
M)R?.)R?/*2G%+"S&,C*T+R_1,3'2-C:U-S>Q-S?&/#RQ/3VQ.CK4/#S).SO2
M0$"S04&W/C[51D:S0D+524FV2DJV34VG3$RU34VT4E*C556X4E+965FG65FJ
M6EJY75VG6%C:8F*Z7E[<9V>I9F:V9V>Y;&RI;6VN;FZL=76M>'BP>GJS?'RP
M=G;A=W?B?'S:@X._AX>QAX>RB(BVE97GH:'KJZOKL;'HMK;NP\/RU]?TX^/X
MX^/YY.3W\?'\\O+\_O[_________________________________________
M____________________________________________________________
M____________________________________________________9;\$I```
M`(!T4DY3____________________________________________________
M____________________________________________________________
M_________________________________________________________P`X
M!4MG`````6)+1T1_2+]QY0````EP2%ES````2````$@`1LEK/@```*Y)1$%4
M*!4%P8<B5@$`!M!SD;U"1F;+^&5+]G;-I+C&?9GOU9TC2;*_.#,Y_RM)(LGI
M2`$&MI-(#CNA:[I?RUHB)VW@PWWU6?-Z9!RT?AS\]SRF+XX*V'NJZ[I^;+5B
M%3;?_OS\\?#:X(OO\/\O5R\-C%J`ZE+OSA0,VX"J!/CFHD!5`FS)5U0EX%/D
MMH>J!-J/([GN-C<$.@X226YFFZ"8.$LB27*WN[ST^SQ)\@Y5KRN,!+X;S0``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O9V]O9VQE+G!N9P``````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#,R,C<@,3`U,34T,S,W-3,@,#(R-C$T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(```!+
M````(`@&````6GV%<P````=T24U%!],)&@@"(_2(4^,````&8DM'1`#_`/\`
M_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP```8D241!5&C>[5A_3%5E&'[@
M`BIXO7KE-WHQM$`#BL`?*(8"F3J];BH6D9+E*!V)Z1#69O)'J4E:3=209CJ7
M`;5L"!E)N[7<7%M:4XK^Z`^W3/NA;6U1FRN^ON>+<SOW<`Y.;FS,SKM]._>>
M\\'Y[O,][_,^[P?888<==MAA!QI$.&85CT)QBV-8KS,?(U&)^\-VHC*D'D="
MMN)G>)$Z]"\F./E-3R._HQWIK_O4R&KN1E[G>>2=KL?\IL5"B.$%5E=Q!`X@
M%M5X1@$U%8>&_J7S#Q4@J^DJ/!4'D;P\30-EVC1$8$KY4DQIN(*,+P22#_1B
M\N.YPXYA>_`$*M"+2=@ZQ$`U+49:L\#X94L'G.=><5$-%\;]/\&2+,+,CWKA
M+MQVT[EQ#\Y33!N&0<U28"7BL:%[RT+?FXBN8=8%!4)Y-B+;XK#J?!)J./;%
M8P7O6<U_82/BOGT7E=K8O@;>`3=BR?9HY+R7A:G3[\8(5XJZSJA?J>YI8)5#
MF('5Y$:1MBY^]C^(B%X4,$;&)ZNK:7CR4E!PH0=NKR\8H(J=R&UQX>M=8[!M
M_0@LX/43-WHOQ.'::EE/C?-/O(2M';OA(T`<1ZKQ\I63Z/FE'=?X73^WK$Q6
MNWEM.Y#>T(CDJA?5>KV7?U7ZRN\YAR>JW[T7SRJP)H27:'_K'0]G>PS:JB-Q
M<(L#*WGMBH+@6A7X&F!&X$R#.\,4'%OXQF"!*G#AOA-C(7@->"!W_VP$1&<(
MQ'3)7SU0'^S`'R@6`2Q:-`L9EX]#<(P,PVS>4T6&S$^N?%O_?Y'6\4^AX6>-
M)$:PA'!H0.G?\UH4-KTEGRX*17L_L/37?K'J^SKUXL&"Y?4ZOTS$F0T1.&?V
MF`SK<D!L",$/_)XP#1XR:*9'_BR3(,-NM$)4K<`E?X7F9D9&WALP,7OO-B2=
M%?J,"'D5M3(!_6`QW0@*,A^(U>8\DH,4`ECBP'=%H5A_:S^6],[D2V6%&T2T
MIV'=Q1C<6.C`4;/G14[<2=I7<=$)Q1YJT_G]$!F3L,QL/ME%L/:4ROFLN-Q,
MUS$_TP+D(_6,0'S%;P%@D5F>")7VYSPX4!<J!1\83^!.QN)P721:]"R_M:!_
MRNH6%'@*[H#B.NO@#%4YN5#YF2G"!3'5_)0V!.=0M\I#\2<7^>-I-#(%T^_`
MHU9=0T\G?B=8<5%(1]%7]0J4T7EU_70LJ=F<67U@74K"A_LDJQ>$HG1_)-9R
MXX*KA&Z,4493O=C".E!`Z=Y3=QY7SIX".WEG-Q]QMYAFI+75*YBF!$N*2SK!
M(K/6+K1VV=<[T+W9B[_FIB%!F5]7A]I,M58M>-]1(?2:)7U6`%A,MU:Y7U8I
M/[A@E6'^2\%,333IJ?2](;4BX7W_3M,>2-2$HCM+N4GXQN&;AYF&?>(>H$DF
M<>D=7"=8__I`6?$(3'+M3\H\JTY#MF#2\QE,::U>X"GD7%MUN-3+_ZJ_97E5
MK0Q!F-IZC=IBW;3*OI%.7Y<6#:-QBCM8$HX.X_3<%,022+^8SJYRDEE6J4@!
M/EJ)WL(L/*2_'P79^\4_N=+/;),L4-60IK2/660B*S$'M<I*)FX])F8E*JI+
M,54:04MA51"XR_KJ*2LB`>'@;NJGT\\80:2/(B`<!$>_<((X4(IB;FN-TM@)
M6SXW/N*)@TI#7;M#O:)N<3/)\%WW8`;OM[F0S;5*!`=IQ)G_<6M.8=1FR9Q&
MH:B>>[)1+7!.9R6RC^]66L4YQA20?TM06/6XB[0,9)SR.#P5,`294[L:5PD8
M[8)F4OG9<GV2E6HMS`#J&$]$>$JB-?ME^!@YN"K=WF>8CHW:>\EJ:F95GUP0
MO.=&X%,"%G1:,G7@FKE<49TG$!,WU<#SU&J*ZDUI*\L]'3S']E*=(%L$F46F
MJ1UW]Y_O\R%,I3Z!88'A6K@N6@;JK-P\-<>86CSC"KSI8(%AIQ%\51R&D9DI
MI8KNG6PVZ*C2,.HL,V#LG`K[I';VL74L)DXG[C)'4SIS:FP0K=KM$ZQ\DCFF
M=L9O*V1_:#.KS_]1R%E0K`X!I/<*]FCIM@C5TBB+\+Q0WHY=!%.3@U6:HB_[
M/IM5AM-9Q"QY13&,1S5T].QI[;###COL\,??5%.*7O`H7K4`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W-A
M=F4N<&YG````````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q
M,#4R(#$P-3$U-#,S-S4S(#`R,C(W,``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````$````!`(
M`P```"@M#U,```#Y4$Q410``!1$H-1$L.A,M/!@P0AHQ0"$V2"TY22Y#4R]&
M5C-)6CY/7$E@<D]D=5EC;51I?%AM@%IP@FYN;E]YB6MX@GIZ>H"&C("'CX:&
MAL=T9L=T9\=U:,AV:)"0D'V7K'Z9K7^:KK>'?H&:KH.>LH2@M<V&>LB*@)R=
MG8:DN8FFO*&AH=&/A(RHO9>EL-&0A(VIOM.1AIVIL)^IL*BQO:&VQ+*RLKFY
MN:Z_S;^_O\#`P,+"PL7%Q;_+ULW-S<?/VL[.SK_5Z,K6W]34U-;6UM?7U\O=
MZ\_@[=OG\>;FYNOKZ^[N[O'Q\?+R\O3T]/?X^OGY^?S\_/[^_@```&%J`:8`
M```!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<
M&`````=T24U%!]0,%!(K.6DGVR\```"J241!5'C:5<_5%H)`%(7AL0L#6Q1C
MQ`[L.J(HUMCP_@_C@*,N_\MO[9N-D/$70L9]7VU9=5L]5360<91+68&6$7(5
M.4SA(.]TUD,*OH&E73#W6SQOA'R!M@7:!\ZZ?B5F9P;3S6II-6(@-XJ85LAC
M!NTAP)KL:KXD`PG`Z==@XHAT+*AC4+P\P,S&]TV(E[%R<L=@,;;S`\Y\%PHV
MYZ*8CB8\@92+PO]_]`+JX#9W*JGT-0````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+W!R:6YT
M````````````````````````````````````````````````````````````
M`````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,#`P(#$P-3$U-#,S-S4S(#`R,#$P,P`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O<')I;G0O<V-R965N+F-S<P``````````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$S,S$@,3`U,34T,S,W-3,@,#(R,34Q
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"\J
M*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]P<FEN="]S8W)E96XN8W-S+'8@
M,2XQ+C$P+C0@,C`P-B\P,R\Q-"`R,CHT,SHU,"!J86X@17AP("0*("HO"@IB
M;V1Y('L*("`@(&)A8VMG<F]U;F0Z("-F9F8["B`@("!C;VQO<CH@(S`P,#L*
M?0IA('L*("`@(&-O;&]R.B`C,#`P.PI]"@HC;65N=2!["B`@("!D:7-P;&%Y
M.B!N;VYE.PI]"@HN:&5A9&5R8F]X('L*("`@(&)O<F1E<CH@;F]N93L*?0HN
M<V5L96-T960@>PH@("`@8F%C:V=R;W5N9#H@(V1D9#L*?0HN=VED9V5T('L*
M("`@(&-O;&]R.B`C,#`P.PI]"BYH96%D97(@>PH@("`@8V]L;W(Z(",P,#`[
M"B`@("!B86-K9W)O=6YD.B`C9F9F.PI]"BYS;6%L;&AE861E<B!["B`@("!C
M;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0Z("-F9F8["GT*+F-O;G1R;VP@
M>PH@("`@8F%C:V=R;W5N9#H@(V9F9CL*("`@(&)O<F1E<BUB;W1T;VTZ(#%P
M>"!S;VQI9"`C,#`P.PI]"BYI=&5M,"P@+FET96TQ('L*("`@(&)A8VMG<F]U
M;F0Z("-F9F8["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(V-C8SL*
M?0HN<VEG;F%T=7)E+"`N<VEG;F%T=7)E+69I>&5D('L*("`@(&-O;&]R.B`C
M,#`P.PI]"BYT;V=G;&5Q=6]T92!["B`@("!D:7-P;&%Y.B!N;VYE.PI]"BYQ
M=6]T960Q+"`N<75O=&5D,BP@+G%U;W1E9#,L("YQ=6]T960T+"`N<75O=&5D
M-2!["B`@("!C;VQO<CH@(S`P,#L*("`@(&)O<F1E<BUL969T+6-O;&]R.B`C
M,#`P.PI]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O:&DM8V]N=')A<W0`````````````````````
M````````````````````````````````````````````````````````,#`P
M-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W-3,@
M,#(Q,C`R`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]H:2UC;VYT<F%S
M="]I;F9O+G!H<```````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,#`T-R`Q,#4Q-30S,S<U,R`P,C(W,C8`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*"B1T:&5M95]N86UE(#T@7R@B
M2&DM0V]N=')A<W0B*3L*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O:&DM8V]N=')A<W0O<V-R965N+F-S
M<P``````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,R,34@,3`U,34T
M,S,W-3,@,#(S,C4S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````&)O9'D@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V9F9F9F
M9CL*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C-3`U,#4P.PH@("`@<V-R
M;VQL8F%R+6%R<F]W+6-O;&]R.B`C8V9C9F)B.PI]"FAT;6P@>PH@("`@<V-R
M;VQL8F%R+6)A<V4M8V]L;W(Z(",U,#4P-3`["B`@("!S8W)O;&QB87(M87)R
M;W<M8V]L;W(Z("-C9F-F8F(["GT*82!["B`@("!C;VQO<CH@(S`P,#`P,#L*
M?0IA.FAO=F5R('L*("`@(&-O;&]R.B`C,#`P,#`P.PI]"F$N=VED9V5T.FAO
M=F5R('L*("`@(&-O;&]R.B`C,#`P,#`P.PH@("`@8F%C:V=R;W5N9"UC;VQO
M<CH@(V9F9F9F9CL*?0HN:&5A9&5R('L*("`@(&-O;&]R.B`C,#`P,#`P.PH@
M("`@8F%C:V=R;W5N9"UC;VQO<CH@(V9F9F9F9CL*?0HN<VUA;&QH96%D97(@
M>PH@("`@8V]L;W(Z(",P,#`P,#`["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C
M9F9F9F9F.PI]"BYC;VYT<F]L('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-F
M9F9F9F8["GT*+FET96T@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V9F9F9F
M9CL*?0HN8G5T=&]N('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",P,#`P,#`[
M"B`@("!B;W)D97(M8F]T=&]M.B!T:&EN('-O;&ED(",R,C0["B`@("!B;W)D
M97(M<FEG:'0Z('1H:6X@<V]L:60@(S(R-#L*("`@(&)O<F1E<BUT;W`Z('1H
M:6X@<V]L:60@(V-F8V9B8CL*("`@(&)O<F1E<BUL969T.B!T:&EN('-O;&ED
M("-D961E8F(["GT*+G-E;&5C=&5D('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z
M("-E-F4V9&4["GT*+FET96TQ('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-E
M-F4V9&4["GT*"B\J($UE;G4@<W1Y;&5S+B`J+PHC;65N=2!["B`@("!C;VQO
M<CH@(S`P,#`P,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-F9F9F9F8["B`@
M("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(S`P,#L*?0HC;65N=2!A('L*
M("`@(&1I<W!L87DZ(&)L;V-K.PH@("`@=VAI=&4M<W!A8V4Z('!R93L*("`@
M(&9O;G0M9F%M:6QY.B!697)D86YA+$AE;'9E=&EC82QS86YS+7-E<FEF.PH@
M("`@9F]N="US:7IE.B`Q,7!X.PH@("`@=&5X="UD96-O<F%T:6]N.B!N;VYE
M.PH@("`@8V]L;W(Z(",P,#`P,#`["B`@("!P861D:6YG.B`S<'@["B`@("`M
M;6]Z+6)O<F1E<BUR861I=7,Z(#-P>#L*?0HC;65N=2!A.FAO=F5R('L*("`@
M(&-O;&]R.B`C,#`P,#`P.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED
M(",V-F$["B`@("!B;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C-C9A.PH@("`@
M8F]R9&5R+71O<#H@,7!X('-O;&ED(",R,C0["B`@("!B;W)D97(M;&5F=#H@
M,7!X('-O;&ED(",R,C0["B`@("!P861D:6YG.B`R<'@["GT*(VUE;G4@82YC
M=7)R96YT('L*("`@(&-O;&]R.B`C,#`P,#`P.PH@("`@8F%C:V=R;W5N9"UC
M;VQO<CH@(V%E865A93L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C
M965E.PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(V5E93L*("`@(&)O
M<F1E<BUL969T.B`Q<'@@<V]L:60@(S`P,#L*("`@(&)O<F1E<BUT;W`Z(#%P
M>"!S;VQI9"`C,#`P.PI]"@HO*B!3:61E8F%R('-T>6QE<RX@*B\*(W-I9&5B
M87)086YE;"!["B`@("!B;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C,#`P.PH@
M("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",P,#`["B`@("!B86-K9W)O
M=6YD+6-O;&]R.B`C9F9F9F9F.PI]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V)L=65W:&ET90``````````````````````
M`````````````````````````````````````````````````````````#`P
M,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S4S
M(#`R,#<S-P`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O8FQU97=H:71E
M+VEN9F\N<&AP````````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#`R,#4@,3`U,34T,S,W-3,@,#(R-#4W`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO
M<F1E+W1H96UE<R]B;'5E=VAI=&4O:6YF;RYP:'`L=B`Q+C$@,C`P-"\Q,"\Q
M-R`Q.3HS,SHS-"!M9&IU:VEC($5X<"`D"B`J+PH*)'1H96UE7VYA;64@/2!?
M*")";'5E(&%N9"!7:&ET92(I.PH`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V)L=65W:&ET92]S8W)E96XN8W-S
M````````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`U-3(W(#$P-3$U
M-#,S-S4S(#`R,S`R,``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````O*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O8FQU97=H
M:71E+W-C<F5E;BYC<W,L=B`Q+C$X+C8N.2`R,#`U+S$Q+S`R(#$Y.C,R.C,X
M(&IA;B!%>'`@)`H@*B\*"F)O9'D@>PH@("`@9F]N="UF86UI;'DZ(%9E<F1A
M;F$L($=E;F5V82P@07)I86PL($AE;'9E=&EC82P@<V%N<RUS97)I9CL*("`@
M(&)A8VMG<F]U;F0Z("-F9F8["GT*82!["B`@("!C;VQO<CH@(S,S.3L*?0HN
M:&5A9&5R8F]X('L*("`@(&)O<F1E<BUC;VQO<CH@(S8V83L*?0HN<V5L96-T
M960@>PH@("`@8F%C:V=R;W5N9#H@(T,V1#-&1CL*?0HN:&5A9&5R('L*("`@
M(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@(S8V83L*("`@(&)O<F1E
M<BUB;W1T;VTZ(#%P>"!S;VQI9"`C,#`P.PI]"BYH96%D97(@82!["B`@("!C
M;VQO<CH@(V9F9CL*?0HN:&5A9&5R(&$Z:&]V97(L(&$N:&5A9&5R.FAO=F5R
M('L*("`@(&-O;&]R.B!Y96QL;W<["B`@("!T97AT+61E8V]R871I;VXZ(&YO
M;F4["GT*82YH96%D97(@>PH@("`@8F]R9&5R+6)O='1O;3H@,#L*("`@(&)A
M8VMG<F]U;F0Z('1R86YS<&%R96YT.PI]"F$N9FEX960@>PH@("`@8V]L;W(Z
M(",S,SD["GT*+FQI9VAT('L*("`@(&-O;&]R.B`C,S,S.PI]"BYS;6%L;&AE
M861E<B!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z(",V-F$[
M"B`@("!F;VYT+69A;6EL>3H@5F5R9&%N82Q(96QV971I8V$L<V%N<RUS97)I
M9CL*?0IA+G-M86QL:&5A9&5R.FAO=F5R('L*("`@(&-O;&]R.B`C8V-E.PH@
M("`@=&5X="UD96-O<F%T:6]N.B!N;VYE.PI]"BYC;VYT<F]L('L*("`@(&)A
M8VMG<F]U;F0Z("-D9&0["GT*+G=I9&=E="!["B`@("!C;VQO<CH@(S(R-#L*
M?0H*+RH@1F]R;2!S='EL97,N("HO"FEN<'5T+"!S96QE8W0L('1E>'1A<F5A
M('L*("`@(&9O;G0M9F%M:6QY.B!'96YE=F$L($%R:6%L+"!(96QV971I8V$L
M('-A;G,M<V5R:68["B`@("!F;VYT+7-I>F4Z(#$R<'@["B`@("!C;VQO<CH@
M(S`P,#L*("`@(&)A8VMG<F]U;F0Z("-F,V8S9CD["B`@("!B;W)D97(Z(#%P
M>"!S;VQI9"`C-C8Y.PI]"FEN<'5T.F9O8W5S+"!T97AT87)E83IF;V-U<R![
M"B`@("!B86-K9W)O=6YD.B`C9F9F.PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@
M(SDY9CL*?0HN8G5T=&]N+"`N8G5T=&]N.F9O8W5S('L*("`@(&-O;&]R.B`C
M9F9F.PH@("`@8F%C:V=R;W5N9#H@(S,S.3L*("`@(&)O<F1E<BUB;W1T;VTZ
M(#%P>"!S;VQI9"`C,S,S.PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@
M(S`P,#L*("`@(&)O<F1E<BUL969T.B`Q<'@@<V]L:60@(T,T0S1".#L*("`@
M(&)O<F1E<BUT;W`Z(#%P>"!S;VQI9"`C0S1#-$(X.PH@("`@+6UO>BUB;W)D
M97(M<F%D:75S.B`U<'@["GT*+F)U='1O;CIH;W9E<B!["B`@("!B86-K9W)O
M=6YD.B`C-C9A.PI]"@HO*B!!;'1E<FYA=&EN9R!S='EL97,N(&ET96TP+"!I
M=&5M,2!A<F4@9&5P<F5C871E9"X@*B\*+G)O=T5V96XL("YI=&5M,"!["B`@
M("!B86-K9W)O=6YD.B`C965E.PI]"BYR;W=/9&0L("YI=&5M,2!["B`@("!B
M86-K9W)O=6YD.B`C9F9F.PI]"@HO*B!687)I;W5S('!O<'5P(&%N9"!S=&%T
M=7,@;&%Y97)S+B`J+PHN=&]O;'1I<"P@9&EV+FYI8V5T:71L92!["B`@("!C
M;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z(",V-F$["B`@("!B;W)D97(Z
M(#)P>"!D;W5B;&4@(V9F9CL*?0H*+RH@365N=2!S='EL97,N("HO"B-M96YU
M('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@(S8V83L*("`@
M(&)O<F1E<BUB;W1T;VTZ(#)P>"!S;VQI9"`C,#`P.PI]"B-M96YU(&$@>PH@
M("`@8V]L;W(Z("-F9F8["GT*(VUE;G4@82YC=7)R96YT('L*("`@(&)A8VMG
M<F]U;F0Z(",S,SD["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(V%A
M8SL*("`@(&)O<F1E<BUR:6=H=#H@,7!X('-O;&ED("-A86,["B`@("!B;W)D
M97(M;&5F=#H@,7!X('-O;&ED(",P,#`["B`@("!B;W)D97(M=&]P.B`Q<'@@
M<V]L:60@(S`P,#L*("`@('!A9&1I;F<Z(#)P>#L*?0H*+RH@4VED96)A<B!S
M='EL97,N("HO"F)O9'DN<VED96)A<B!["B`@("!B86-K9W)O=6YD.B`C9F9F
M.PI]"B-S:61E8F%R4&%N96P@>PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L
M:60@(S`P-CL*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C,#`V.PH@
M("`@8F%C:V=R;W5N9#H@(V4Y93EF9CL*?0HC<VED96)A<E!A;F5L('-P86XN
M=&]G9VQE+"`C<VED96)A<E!A;F5L(&$@>PH@("`@<&%D9&EN9RUL969T.B`Q
M<'@["B`@("!P861D:6YG+6)O='1O;3H@,G!X.PI]"B-S:61E8F%R4&%N96P@
M<W!A;BYT;V=G;&4@>PH@("`@8F]R9&5R.B`Q<'@@;F]N92!T<F%N<W!A<F5N
M=#L*?0HC<VED96)A<E!A;F5L(&$@>PH@("`@8V]L;W(Z(",P,#8["B`@("!B
M;W)D97(Z(#%P>"!S;VQI9"`C93EE.69F.PI]"B-S:61E8F%R4&%N96P@83IH
M;W9E<B!["B`@("!C;VQO<CH@(S`P-CL*("`@(&)A8VMG<F]U;F0Z("-C8V,[
M"B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C,#`P.PH@("`@=&5X="UD96-O<F%T
M:6]N.B!N;VYE.PI]"B-E>'!A;F1"=71T;VX@>PH@("`@;6%R9VEN+7)I9VAT
M.B`Q<'@["GT*"B\J(%1A8B!S='EL97,N("HO"BYT86)S970@>PH@("`@8F%C
M:V=R;W5N9#H@;F]N93L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C
M-C9A.PI]"BYT86)S970@;&D@82!["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C
M-C9A.PH@("`@8F]R9&5R+6)O='1O;2UC;VQO<CH@(V4Y93EE.3L*?0HN=&%B
M<V5T(&QI+F%C=&EV951A8B!A('L*("`@(&)A8VMG<F]U;F0Z(",V-F$["B`@
M("!C;VQO<CH@(V9F9CL*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C
M-C9A.PI]"BYT86)S970@;&DN86-T:79E5&%B(&$Z:&]V97(@>PH@("`@8F%C
M:V=R;W5N9#H@(S8V83L*("`@(&-O;&]R.B`C9F9F.PI]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O<VEM<&QE>```````````````````````````````````````
M````````````````````````````````````````````,#`P-S4U(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W-3,@,#(P-#,P`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]S:6UP;&5X+V=R87!H:6-S````
M````````````````````````````````````````````````````````````
M```````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q
M-30S,S<U,R`P,C(R,S``(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+W-I
M;7!L97@O9W)A<&AI8W,O8F%C:V=R;W5N9"YP;F<`````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P,30S(#$P-3$U-#,S-S4S(#`R-3$S,@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M`````@````0(`````(&$L>4````)<$A9<P```$@```!(`$;):SX````5241!
M5`C78WCVC.'I4X8W;QC>O0,`*VL'2XNJ#HT`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]S:6UP;&5X+VEN9F\N
M<&AP````````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#$W
M-2`Q,#4Q-30S,S<U,R`P,C(Q-38`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O
M=&AE;65S+W-I;7!L97@O:6YF;RYP:'`L=B`Q+C$@,C`P-"\Q,"\Q-R`Q.3HS
M,SHS-R!M9&IU:VEC($5X<"`D"B`J+PH*)'1H96UE7VYA;64@/2!?*")3:6UP
M;&5X(BD["@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O<VEM<&QE>"]S8W)E96XN8W-S````````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(Q-34@,3`U,34T,S,W
M-3,@,#(R-3`S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]S:6UP;&5X+W-C
M<F5E;BYC<W,L=B`Q+C@N-BXT(#(P,#4O,3`O,3@@,3$Z,S0Z,C$@:F%N($5X
M<"`D"B`J+PH*8F]D>2!["B`@("!B86-K9W)O=6YD.B`C965E('5R;"AG<F%P
M:&EC<R]B86-K9W)O=6YD+G!N9RD["B`@("!S8W)O;&QB87(M8F%S92UC;VQO
M<CH@(S<S.3!B.3L*?0IH=&UL('L*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R
M.B`C-S,Y,&(Y.PI]"F$@>PH@("`@8V]L;W(Z(",S8S=A93D["GT*83IH;W9E
M<B!["B`@("!C;VQO<CH@(S%B-3=C,CL*?0IA+G=I9&=E="!["B`@("!C;VQO
M<CH@(S`P,#L*?0HN:&5A9&5R('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C
M:V=R;W5N9#H@(S<S.3!B.3L*?0HN:&5A9&5R(&$@>PH@("`@8V]L;W(Z("-F
M9F8["GT*+FQI9VAT('L*("`@(&-O;&]R.B`C-&4U9#<R.PI]"BYS;6%L;&AE
M861E<B!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z(",W,SDP
M8CD["GT*+FET96T@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V5C969F-#L*
M?0HN8G5T=&]N('L*("`@(&-O;&]R.B`C,V,W864Y.PH@("`@8F%C:V=R;W5N
M9"UC;VQO<CH@(V1D9#L*("`@(&)O<F1E<CH@,7!X('-O;&ED(",P,#`["B`@
M("!P861D:6YG.B`P(#)P>#L*?0HN8G5T=&]N.FAO=F5R('L*("`@(&-O;&]R
M.B`C9F9F.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(SDY.3L*?0IS96QE8W0@
M>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(S<X031&,3L*("`@(&-O;&]R.B`C
M965E.PI]"@HO*B!-96YU('-T>6QE<RX@*B\*(VUE;G4@>PH@("`@8V]L;W(Z
M("-F9F8["B`@("!B86-K9W)O=6YD.B`C-S,Y,&(Y.PI]"B-M96YU(&$@>PH@
M("`@8V]L;W(Z("-F9F8["GT*(VUE;G4@82YC=7)R96YT('L*("`@(&)A8VMG
M<F]U;F0Z(",U.&$R9&,["GT*(VUE;G4@83IH;W9E<B!["B`@("!B86-K9W)O
M=6YD.B`C-3AA,F1C.PI]"@HO*B!3:61E8F%R('-T>6QE<RX@*B\*(W-I9&5B
M87)086YE;"!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C965E.PH@("`@8F]R
M9&5R+7)I9VAT.B`Q<'@@<V]L:60@(SDY.3L*("`@(&)O<F1E<BUB;W1T;VTZ
M(#%P>"!S;VQI9"`C.3DY.PI]"B-E>'!A;F1"=71T;VX@>PH@("`@;6%R9VEN
M+7)I9VAT.B`Q<'@["GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]C
M86UO=69L86=E````````````````````````````````````````````````
M```````````````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<U,R`P,C$P-3(`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V-A;6]U9FQA9V4O9W)A<&AI8W,`````````````
M`````````````````````````````````````````````````````#`P,#<U
M-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S4S(#`R
M,C8U,@`@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O8V%M;W5F;&%G92]G
M<F%P:&EC<R]M96YU+G!N9P``````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3`P
M-3`@,3`U,34T,S,W-3,@,#(T,S<W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(```,>````-`0#
M````]LOSP````!A03%1%'RX;$D0B*3TB9VQ`"BD2____________;XZ+^```
M``EP2%ES````2````$@`1LEK/@``#[9)1$%4>-JEG&V"LKP.AHNZ`#JZ@!%=
M``H+0.G^UW3H1Y([:7%\WM-?(Y8VR96/4NJX$*;41G\)P6_-.7><IF$8;E-I
MSZ&T>Z#VCA^WGM1ENV^[$&_OMZLG[A?6A\LM#A_":^MQ"?#U-#U\NBU]3&/E
MOKVC=M+]MPZ';:[SQ&W<.AU(QDWL/&)JI=>(8VS3S%F#K$^>10:@-HT'&9,,
ML?7LS-0@Y%)T33//-)LU([2KSY;C.1UU=Z1"GK')8TBCYWF&-'ON\/#"(P)I
M\B@7O%>622B)1[+VU&T?-W"[/++M_-0$<B-Q4LM?SZ%N;_:O8L,:QS9L&93G
M&GZC=3P`82D=`.G*].)".SRNY)W"@Q4B':)C^O.[R2-?$JT6DFB3X*?P\$6T
MTHJ?=[YA%,&1Q5HGL&:31TBR6AY9`_F@<-@)9U'__B$\)IYIL]IV5Y+MD'DT
M@00)-N*1M.*>=00.D"SRA:B%<VJ0Q,-O/%I@*W];69YMNM\N#X`6R+ZWPT,2
MBT3V`^0`16'"I!C:Q+9/.+8K;\R_KAT>4<WH[#\11\H]DIXX\!02S%BB5[^P
MQ[1P@%6(1V]XI(2E>+P_\*!PSSSR("?S??S&MWB\.`Q.$ME[/-8\+^OR@<=#
M2H?.53GI#,!C:8?'+9'<OMS"OM2"E4WOO9D<P]CP\!RV-8^KJJ71REOX3;[!
M8S-"L;U6(,FI$TA0/)RIUTFG9#Y]-3<R^8DLGB>[$H\!>*S9N$3CQ_B(!4(&
MBWK>.;:T,OL\;GFRI1@E1QF;WML`&2V/#H`PM%9XH%4V('?G'A6/WO"8=1R/
M)H-PPBH\C,T+CVN#Q\OD([#6]8?R*7VO4LU5+4I:1$CV1!!X*(/<=](5)[J:
M!U?:*D!.D"^01_$,6:P!#FVLPJ/_@T?0HKI//$[!MJ7X7H/'8LJUL18!D=AA
MU]"+Q+S,F-L\WHK'\R\>-R!)/,K2=273HYG_*X\KE$W@L>SQ<.];F\=H>2S`
MHY&3/O`8-8^UM2*DV:9//(9BO_4/'A;XG86G*[(<2@B6FL?H.&CV>;B:!Z1$
MZ*#L\1Y"Y.%;]<,=Q%,^\X#XN/]?/*8//&B5(L[U\R6/X0./8'G<90S@,2&/
MB2QU_I('=SD(C<\\>C5$;WDH)2(/G92^XW&MUU>K6I<$_S!.3]+'#K1*R3HE
M@YB$-;=PE.!N\[B#]'G<6VCQ.&L>_.1\UCSP`002UIF[G*+!J8//7J6]=`BQ
M?I2(T.'AGE.+QZWBP>EJTPDAP9\YP^SQ*#WSY"T>+HZ!23C+:@)D9GNI;#(#
MCU6IHKTI7CE/&&/$XTQPV!YVY51X9&B6QP0\,("&:GTE/'H8P=4\GIJ'#H^Q
MP6/!9=.TQX,>KP"'-O*05FR;(HYYN'RMLUVW`,F&?%@[*!ZBR1U%+2X[M7B<
M^8,8Y&$#)-U_G,7'F,<9NN",/T-K@;64L.@!1[[C..WP*#A8;.$1!J4C84M.
M??75`\A*-\</+]\&\DN#DU+E4A5+-TV##?%L\R`<P"-N$U8\W)D_J&R8L[SA
M(7]*MD$SM7@HJPRZ\C"M?1Z^/VE7D0T<3%;)@AP&SYSQJ_"8I!"*"#]-'D>:
MZS!`O3*%#5>9Q`.-+YJ`,$0CW8!F3XJ2R6>M\Y1W-8P-T#U)EEF6916/JP4"
M/!2G!3?G#`\5'"(!)+&7Y3'EC2WZ*.&1;SY!>%B_=XJ'Q&*\]-9`KCKO>A']
M-AL>J.]2[JG"X((\)KM8&,%+4MRV>5P"/$<"CXYY@)LN!^)A7/<#CTO%HWI`
M[(L%V0J42%[1!Y]%;_`L#(\H2X.'#L4FC\$LW$7P6UDLN7)!^V7N3U'`NCTT
M#]L,CT,4]8@N(PDGC:BS#_+P8O6I+-XN7_.XA)K':'9@^V)!Y%$R>XR5FX6I
M>800WI;'$2.1>83!`E&V$+EO5`S*LM8D!,EN,^3BAZ\UW>>19#VBRW1BZP8/
M#SQ(DCQ2(SPVR8\X]^$SC^FD;GX1CPEY)"#G9*-*K]-+X<``0:TUCD\\RHX?
MEY9LZ85?9^B<\/+JQ97B8:J&<23VVFPAIT)83+T6=V1_[3SRH.O,PX:'X8$[
M+YC[N>F;J7P8'A.GD-K/[(J"`^07E(8=^!T>5_AVJ\]/X.&R7R(/#)#S+H]=
M(`T>,1!1`K+T6AY9@'^#Q_HU#UG)7)LR[O&8O^0!ZZ)+S:.(,GIX99C7"Y:'
M++U.6RP<!^&1'II<69+YFL=4\S!YI,%CJ'@,MU&[!(WP4#/R,K)(<C(\+(Y<
M6?XKCRQ,W&YI\1@&74!&'1Y%Y`:/J)(*D&E^?\?C5AZ._RL/DPU:/&H)4FOS
M>+5Y3/L\W"Z/RY\\EL+C2#Q6QA'30H.'>FP(*D"`1]))\]B/CZ@"9]DI\UCV
M>9P_\F@'2"M?R>,KA;#B(4=L-`\T:BM?F>45;!7[9I%KA(>3!>_*UMST?FH>
MSQT>%"%8/^(@6#Z^Y7&;\I[;MSS8?_C[5H",+1X&QY%Y>-5ZJF2H]+K+8W&&
M!P?(U;>>/X!'W$WK6![@42:V/(:;,SL$%Q#CH)>[8`='9\3:/%)RHG)>;HJ.
MTC5YO&3S\;_R&!O)2E;\ZT.IF/.'Y;$<=W@LSO*@%=:5U-`"SB!V-*\#LY1H
MHHF?Q4#,X]?R\$H,4<UFBGBI&/S^_L3C5NZ(/#QK@5H[S8,>8"\-'G;;#@U4
MT6#++#6.FH?/];5^'JP-H)\Z]WBLQ5:2Y2D=</L9+(_!I*L8S:<*1Q6O*3R*
MP>^ZW)2)>7M+I.^\XB'@CUJ3-?,`DT`F:/.8#(RCLHQ2L6_PN/".$0UTTN$A
M$P4S7[IYC<:P/*B?N`'G`Z2!/)Y\1"C?@0*KUMET<9R(QPWVI9#'0<)C)%=J
M\5A06='D<6GPF.&EU`<>AF^0-XJR)!E0%"].ZX(!HD?$?3_6RB>/O,FLT3]7
MP\/KYQ\O^X0R8+09\>A)P5$I5AS[/-7M"7211Q=-N<AD62D6P4B'Y0GLKU+X
M"M^W>8S(PWAJ,5M2@;V-UD<E0%["(ZCDLB@><X!C%<`C)0B2LCP'W/9X!!T>
M@XP7>>0SC5E.ZVLR8(L'1MN3>'1E7EE<S9#"ZW*N'GW#3D,>RC_EUOWP6(K9
M=#]>()GF.%5#>"@>08W3B:??BYB@^]CD\5+AD3B.-FA=8Y\J7A@IU'=XW/2'
M+EOZ#>PQ1NMRKA9O?_"`<E_Q@`!!VRULMK/J=QIV@`@/+*-')2#.UX&C%]G>
MBD>'/-YW"1#F$1@OR-3RM?CWP__-XPS!\M`;]IS#*42-LZB=B,<>C\`6WE8/
M"8ZW/";+0^%PSNM^;Q%1,_F&ASAT-#?C*++-H+SA\2X;D"_D$>]Z((_\)@E4
M&T&(TJ'!XRD$SEA,9L!Q8Y_W*E]#NOH''OE(9TA>TC=YG#C_93>0J.E4/\5#
MR24\G*0KLUX+P!]YY`"1H9,E@748^%TI1-4][A\H'ILX/5H:>#P+L0\\.B_O
M.I+50,]MK*+"C_%$JN:8KKH_>22EUXG725;HP,]UH?`8Z,%$]3L-IK5XG(0'
MIL!]'O?TS5/QP-A[9V8E0O`NKWE<&\>3%0_\-93A4=YU/#D>P/5N$Z]3WB8Q
M%+&$1RP^7_,H"ARMT+$O\%CI/`QTS3S,WO2UQ0/^_,0#"D$2[4>TQ_,=%0_J
MM_%8U2J\<O\&C]L>#UY^%9>8S<LLX*'R=!&K%Q[#Y/=P+,#C+A7]J.2AR;AS
M//QS(#EJ;G_FJXV:62($J1^XX/V10A!7U)]YW+F""(\@>RJ'AK5=S:,%)-L\
MU:N^=13[%WD$C>-":11XW'9Y./+Y=_G)7JMM<UT@F/*U0Q%$T(U4JD,+A^)A
MEP@[/"X!'&4;0=*5V<<$'B$6P)SK[E"G2HQ\P:,!)%TNRX<&CU^G>*@S$X6'
M%QYQHJNF4%69$/(1L[7)8W3R>E;S&#"21I:)$^OU2QZ8KN`!!+-J7!D=BOYM
M'B5A]26V:`DLD_JA]0JWXE'_R@-=Z[B[V<O2OFRZ4@OI)_@.\"-9E3UV>'04
M=:#)H1)]A)"MPZ/)(]_(.VJKYG$Q.*@*_'J#PP_`@XI/X%.,--[9FOJQP\-$
M2-YT9AY/RZ,W/#!`+DR'>$@NU;TOV9>B+'@2O\6C?L.K?O7+/'B8=QT>D<<*
M6>+((\GCM5,\Y.=\*5E)5>Z\;_*X*QZS.57:^>J5.NVY61XF0-06:5_QN'K+
M`P)$X*A@&^0H/*!+/J?.D3=YP!O%U]'P`-'Q=-1''E/>-=5!M6675_:A4?-`
MPQWRJ)>LQ,/P&"`:(H\WA(PO2U6CE^?]DV&71Y[VRCRFBH<OBY0Z0/J*A]"\
MU\5&UCL?$Q;PR'$WRL.!!`@*]*;$*ID>>3SYKO+_#&+_4(0>E5`0';R7G^0@
M@T9;H\]1\9F+$/=XR=.C-::B!QGA:'Z:97O]?.3ARQXEJ,]6/E4\]+VZUM0\
MV@$"KTS2R%$1XB&^A(<'B4?.=I8'V`7#B9*L$FI2YZ$&^BEUT2]KT*'+$0]^
M7BL_=LG&0$N3A=,+>&TGTPMCO2H@GH#4&:L/ED>=[#[S8!>>"<ZMXI$:\V`-
MP3]>*=/_YB+161Y/T;@J-V"((@_*V?W0F_77F=*=U)4!?S<I/.YI#_S\D4<P
M/*3;XRL>I;S9`#E5/`;;$$=?\Z``F0E.>CWW;SPVY\@O')Q*"\Q#;E/5)JM\
M-CP0Q^;U5Z]X3(;'L,N#9J[2U39\_'W+/_#01BT.LB0Q=("<@N5AP\,\$C1X
MK(*C;!I]R6/D/A/Q..8O_HF'`!&]@(?_FL=9>+Q:/![^*Q[>\G#&J,+C,.@`
MZ4/%H\*!/.!!(!@@\O<SRO8%CT?/KK&IFE^0'C$O?,M#G\%08;SQH)]>*1ZP
MB0D\Z%1ABH\S>2=;NI??E1YGW!LLTN7_ZS*1LGZ/1Q8HGNT^X&/%UO&$I>1/
M'KUK\TA6D^25X^-B"E7%XZ&[."?Y2GB$'1YO)=H1`F0Q?O/#]5SQ8&M"_?"*
MARU<^`*E/U8G="./`,+CONA1=Q5S:AZNQ6,W7S&-K/`)@2@>4]XMJGCH0P,>
MCO+DX87'V.3Q*SDIO'Y0,]ZAG-._65&.D[M=Z%&E\+@T>=#5>W"E-_C/Z(!'
M;:<;'[`HW@=9Y=#V[RP<&[$G)U<\(I([G',N6HN"-%I00&:L)>75Y`Z/&PG=
MXN$,CQ5XQ"_%*C\0N"3YZ*HF*IPIZVPC2/:7/1E/NUK;1?I':^)`(RK?V+.=
M#`]H]`ORV5@DJ2P!XNRI,$C#*L/$K[(XV?T:0-::ASG"(3RX,C9YQ-SCA`?_
M8QTYP=15"O?[.-@UF4=T+8__]@MX_`@/E2QXZ#+AN>+Q._$OW6H>Q0O92=47
M^$OL-@]92>2YSJ1KH/_2T(@025?DX1?+XX=&*Y^IPPMY;$#H3=[_``)SUGS+
MK<_M`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]C86UO=69L86=E+VEN9F\N<&AP````
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#(P,B`Q,#4Q-30S
M,S<U,R`P,C(U-C<`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+V-A
M;6]U9FQA9V4O:6YF;RYP:'`L=B`Q+C$@,C`P-"\Q,"\Q-R`Q.3HS,SHS-2!M
M9&IU:VEC($5X<"`D"B`J+PH*)'1H96UE7VYA;64@/2!?*")#86UO=69L86=E
M(BD["@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O8V%M;W5F;&%G92]S8W)E96XN8W-S````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(R,#0@,3`U,34T,S,W-3,@,#(S,3(P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"\J
M*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]C86UO=69L86=E+W-C<F5E;BYC
M<W,L=B`Q+C<N-BXS(#(P,#4O,3`O,3@@,3$Z,S0Z,3,@:F%N($5X<"`D"B`J
M+PH*8F]D>2!["B`@("!B86-K9W)O=6YD.B`C,68R93%B.PH@("`@<V-R;VQL
M8F%R+6)A<V4M8V]L;W(Z(",U9#5D-C`["B`@("!S8W)O;&QB87(M87)R;W<M
M8V]L;W(Z(",U9#5D-C`["GT*:'1M;"!["B`@("!S8W)O;&QB87(M8F%S92UC
M;VQO<CH@(S5D-60V,#L*("`@('-C<F]L;&)A<BUA<G)O=RUC;VQO<CH@(S5D
M-60V,#L*?0IA('L*("`@(&-O;&]R.B`C,S,V.PI]"F$N=VED9V5T('L*("`@
M(&-O;&]R.B`C,&$R.3$R.PI]"F$N=VED9V5T.FAO=F5R('L*("`@(&)A8VMG
M<F]U;F0Z(",Y.38["GT*+FAE861E<B!["B`@("!C;VQO<CH@(V9F9CL*("`@
M(&)A8VMG<F]U;F0Z(",S-C,["GT*+FAE861E<B!A.FAO=F5R('L*("`@(&-O
M;&]R.B`C.3DV.PI]"BYH96%D97(@82!["B`@("!C;VQO<CH@(SDY-CL*?0IA
M+FAE861E<CIH;W9E<B!["B`@("!C;VQO<CH@(SDY-CL*?0HN<VUA;&QH96%D
M97(@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD.B`C,S8S.PI]
M"BYC;VYT<F]L('L*("`@(&)A8VMG<F]U;F0Z("-C8V$["GT*82YC;VYT<F]L
M('L*("`@(&-O;&]R.B`C,&8P.PI]"BYI=&5M('L*("`@(&)A8VMG<F]U;F0Z
M("-C8V$["GT*+F)U='1O;B!["B`@("!F;VYT+7=E:6=H=#H@8F]L9#L*?0HN
M<V5L96-T960@>PH@("`@8F%C:V=R;W5N9#H@(SDY-CL*?0H*+RH@365N=2!S
M='EL97,N("HO"B-M96YU('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R
M;W5N9#H@(S%F,F4Q8B!U<FPH(F=R87!H:6-S+VUE;G4N<&YG(BD["GT*(VUE
M;G4@82!["B`@("!C;VQO<CH@(V9F9CL*?0HC;65N=2!A+F-U<G)E;G0@>PH@
M("`@8F%C:V=R;W5N9#H@(S,V,SL*?0H*+RH@4VED96)A<B!S='EL97,N("HO
M"B-S:61E8F%R4&%N96P@>PH@("`@8F%C:V=R;W5N9#H@(S,V,SL*?0HC<VED
M96)A<E!A;F5L('-P86XL("-S:61E8F%R4&%N96P@82!["B`@("!C;VQO<CH@
M(V9F9CL*?0HC<VED96)A<E!A;F5L(&$Z:&]V97(@>PH@("`@8V]L;W(Z("-F
M9F8["GT*"B\J(%!R969E<F5N8V5S(&]V97)V:65W+B`J+PHN<')E9G-/=F5R
M=FEE=R!H,B!["B`@("!C;VQO<CH@(V9F9CL*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]L=6,`````````
M````````````````````````````````````````````````````````````
M```````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,#`P,"`Q,#4Q-30S,S<U,R`P,3<U,S(`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+VQU8R]G<F%P:&EC<P``````````````````````````````````
M`````````````````````````````````````````#`P,#<U-2``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S4S(#`R,3,S,@`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O;'5C+V=R87!H:6-S+W1A8E]B;W1T
M;VTN9VEF````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`R,#$@,3`U,34T
M,S,W-3,@,#(T,C(S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````$=)1C@Y810``0"$(`#=X]7;X=/^_O[R].[FZ>#:X-+\_/SU
M]_+Y^??J[>3@Y-;EZ-[N\>KM\.GO\NOBY=KX^/;W]_7S]?#I[./Z^OC[^_OK
M[N=W9E7CYMODY]W]_?WL[^CAY-GQ\^[@X]CHZ^(L`````!0``0``!0;@)8YD
M688`.P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+VQU8R]G<F%P:&EC<R]T86)?<FEG:'0N9VEF````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-C0V(#$P-3$U-#,S-S4S(#`R-#`U
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!'
M248X.6&0`98`Q```U="ZMZZ(TLRUV=3!XM[0Z>;;_?W\WMK)UM&[U]*]\_+L
MZ^C>[.K@]_;S\.[G[NSCY^38^OKXR<*FU,^XS<>MT,JRR\2IP+B7Y>+4W-C&
MV-._S\FPSLBNRL.G_/S[[^WE(?D$```````L`````)`!E@``!?]@((YD:9YH
MJJYLZ[YP+,]T;=]XKN^P)$"&H'!(+!J/R*1RR6PZG]"H=$JM6J_8K/;IB2@(
M@@L@&"F;S^BT>LUNN]_PN'Q.K]OO^+Q^S^_[XPT*#@L'$@@&#8F*BXR-CH^0
MD9*3E)66EYB9FIN<G9Z?H*&BE0H*#!`$`Q<8I:VNK["QLK.TM;:WN+FZN[R]
MOK_`P<+#Q,6Y#@\+&`<9'10.T-'2T]35UM?8V=K;W-W>W^#AXN/DY>;GZ.G;
M'\FHS&$/\?+S]/7V]_CY^OO\_?[_``,*'$BPH,&#"!,J[+>@P+(,`Q`$8$"Q
MHL6+&#-JW,BQH\>/($.*'$FRI,F3*%/_JES)LN7'!0L@/!R@(0#,FSASZMS)
MLZ?/GT"#"AU*M*C1HTB3*EW*M*G3IT,+N,N@(4&``EBS:MW*M:O7KV##BAU+
MMJS9LVC3JEW+MJW;MW#CDI5)`&("B1#RZMW+MZ_?OX`#"QY,N+#APX@3*U[,
MN+'CQY`C2RZ,@0"SNQ,"$-C,N;/GSZ!#BQY-NK3ITZA3JU[-NK7KU[!CRYY-
M&S4S#0`$"`APH+?OW\"#"Q].O+CQX\B3*U_.O+GSY]"C2Y].O;IUY!D@:IA0
MH<*&``/"BQ]/OKSY\^C3JU_/OKW[]_#CRY]/O[[]^_CSZV^O`0%W#A10$$`"
M!!9HX($()JC@_X(,-NC@@Q!&*.&$%%9HX8489JCAAAQV^"`"_@FP`046=!``
MB"BFJ.**++;HXHLPQBCCC#36:..-..:HXXX\]NCCCT#.",`$`E0`8`<F`J#D
MDDPVZ>234$8IY9145FGEE5AFJ>667';IY9=@ABGFF%5.0&0%)'8@00!DMNGF
MFW#&*>><=-9I)YEF%IGFFG?VZ>>?@`8JZ*"$,IDGFB7R6>BBC#;JZ*.0QGGH
MGFQ&:NFEF&:JJ:"3)EKIIJ"&*NJHI$+9J9J?EJKJJJRV"NBIBKHJZZRTUKHE
MK*G:JNNNO,J*:Z_`!BOLIK\.:^RQR`9:;++,-NOLF,L^*^VTU$H9;?^UV&;[
M[+7:=NMML-Q^*^ZXOIY)*;GHILMJN.JVZRZD[+XK[[S*FNLIO?CF^ZJ]J.KK
M[[]RQ@OPP`1C*7#!""?LY,$*-XPPPPY'_"_$$E=,+\469]PNQAIW/"[''H>L
M+<@BESPMR2:GS"S**K<\+,LNQ\PKS#+73"O--N>\+K^QZNSSRSSG^O/0N^),
M]-&7&HWTTHXJS?33A#H-]=1_2DWUU75:C?76<&K-]=?0!@WVV$V+3?;949N-
M]MI5J\WVVUF[#??<7<M-]]UAZWDOWGSGC6B_?0?^I=>"OTUXX6L?COC9BB\^
M=N..?PUYY%M/3OG5EE\^=>::/\UYYTM_#OK_T:*//G3IION,>NHYK\YZS:Z_
M'G/LLK=,>^TIWXY[R;KO'G+OOG<,?/`9#T]\Q<8?'W'RRC?,?/,)/P]]P=)/
M/W#UUD]L=_9D8\]]OMY_?_'VXG,=?OGOGH_^QN2O3[7Z[J,+?_P?MT\_T_/?
M[VW^^H]L?_]$XQ\`JR7``9[L?P;460$3Z*P%,G!E"'R@S!PHP6-1L()`TQO@
M,'BZ"'(P=Q[\(.]"*,+?D;"$PCLA"HNGPA4BKX4N7!X,8^B\&=(P>C:\(?5R
MJ,/K\;"'VM-@SX`HL@L2<55&/&*IDJC$43&QB:%Z(A2)]<,IIJ^*5F2?$(66
M18=)L8N6^B(8X87%(S'6;XMFE)@8T\BH-;*Q4&Y\XZ#B*,=ZH;&.#RLC'@D8
MM!```#L`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O;'5C+V=R87!H
M:6-S+W1A8E]L969T+F=I9@``````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#`U-C0@,3`U,34T,S,W-3,@,#(S-C8U`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````$=)1C@Y80D`E@#$``"WKHCO[>7@W,SL
MZN#Q[^GGY-C7TKS5T+K;UL3]_?WT\^WHY=OV]?+X]_3Q[^CKZ-[<V,;MZ^+9
MU<'P[N?N[./Z^??CW]#8T[_%OI_'P*/?V\N\M)#N[.3EXM3LZ>#3SK<A^00`
M`````"P`````"0"6```%\6`B/D:V`8`(88C7B`GT.7!5/1AM-PQS2#N&8IA9
M5'@*@F.R42"5'`J`)R0$*)%I3S&A##R`K37R>(2KY,4BG`P\"AT+8#@9%"P"
MS=S!>70T$!(`!!,1"Q:!%X,!`PL"$!<&BW8""`:25I26F(P%E9>3GINAGYR:
MH)FBJ)VEI*.IK;"OK+.GIJJWL;2KMJZ\N+ZYM<"RO[J]Q<+&P\?$N\K0P=+)
MT\_5R-;4VMG<V-[.W\WBS.3+YM';X>7HW>#NX^?7[^OR\.SJ\>GS^>WV]?3Z
M_`4$V(\@OGO[$`HLR._@OX8)'RHT&'$@Q(4.+4Z\%`(`.P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VQU8R]G<F%P:&EC<R]C=7)R96YT
M5&%B7W)I9VAT+F=I9@``````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-#$S(#$P-3$U
M-#,S-S4S(#`R-30P-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!'248X.6&0`98`Q```_____O[^_?W\]/+M^?GW\O'J=V95
M\O'K^OKX]_;R]O7Q^/?UV-+(KZ27D8-TY>'5Z.;:[^WF^?CVZNC>[>KB]?3O
MY^/8]O7P_?W]\?#I_/SZ\.[GZ^G?P+BN@'!?R\.V(?D$```````L`````)`!
ME@``!?^@(8YD:9YHJJYLZ[YP+,]T;=]XKN^OYS0/@'!(+!J/R*1RR6PZG]"H
M=$JM6J_8K';[#`@D%$;#T0EPS^BT>LUNN]]PKE=2B4#$G;A^S^_[_X"!1'-U
M'!`?#@R"BXR-CH^0:X01AA`-#9&9FIN<G7^3AA:(GJ2EIJ>H2:`0=QZIK["Q
MLI]?A1`6%@8!N[R]OK_`P<+#Q,7&Q\C)RLO,S<[/T-'2T]3%&!H2`Y00#P\&
M`N#AXN/DY>;GZ.GJZ^SM[N_P\?+S]/7V]_CYZAH$"=H3W+P1&$BPH,&#"!,J
M7,BPH<.'$"-*G$BQHL6+&#-JW,C1X8(+!2C<ZF8@@<F3*%/_JES)LJ7+ES!C
MRIQ)LZ;-FSASZMS)LZ?/GS`57#BPP5`W;P.2*EW*M*G3IU"C2IU*M:K5JUBS
M:MW*M:O7KV##BIUZ@"@%@$<-%%C+MJW;MW#CRIU+MZ[=NWCSZMW+MZ_?OX`#
M"QY,V&Z&"&<#>BO,N+'CQY`C2YY,N3+A#!L0A\)EH*SGSZ!#BQY-NK3ITZA3
MJU[-NK7KU[!CRYY-N[;MU`4.4Z@$P<#8W\"#"Q].O+CQX\A_']!-8;<!!="C
M2Y].O;KUZ]BS:]_.O;OW[^##BQ]/OKSY\^C3:[]PH<*`W)DC&%A`O[[]^_CS
MZ]_/O[___P`&*."`!!9HX($()JC@_X(,-OB?2>T-X)D!'55HX8489JCAAAQV
MZ&&%$BR0`'3L&8#`B2BFJ.**++;HXHLPQBCCC#36:..-..:HXXX\]NCCCT#2
M.)`$1$KPC3Y()JGDDDPVZ>234$:)I`94HJA+-5AFJ>667';IY9=@AHDE!F26
M:<`L:*:IYIIGG,GFFW#&*><0;LYIYYUXEE)GGGSVZ2<@>_XIZ*"$MEGHH8@F
M&D6@BC;J:**,/BKII'Q&2NFEF+)I:::<=IK*IIZ&*JHFH(YJZJF!E(KJJJR^
MH6JKL,:ZQ:NRUFKKHK?FJFL5M.[JZZZ]_BILK<$.:RRKQ1ZK[*C)+NLLI\T^
M*^VDT4YKK?^BU5ZK+:'9;NMMG]U^*ZZ=X8YK[IOEGJLNFNFNZ^XK[;XKKY[S
MUIMGO/;F"PF^^O:["+_^!NP'P`(7'`?!!B?,!L(*-VRHPQ"3&O'$^U)L,2,,
M7ZPQ$QEO[/$1'7\LLA`AC_QQR29OC'+*%Z_,,L4NOQQQS#([3'/-"M^,L\$Z
M[RQPSS[["W30^@Y-M+U&'SUOTDJ_RW33ZSX-];E23SUNU59_BW76VV[-];5>
M?SUMV&(_2W;9RYZ-]K%JKSULVV[_"G?<P-*]\]QVWXIWWL3R+?/>?L,*>.#(
M$I[RX(:?BGCBS#(N\N*.>PIYY-!2KK+E&D^..:6:;RYIYYX["GJ(Z-B2/K/I
M$(^.>J&JKSYHZZ[_"7OLX-+.L^T%SX[[G;KO/F?OOL<)?/#H$E^T\?D.CWR:
MRB\_2_/.QP)]]/!2[[3U[DZ/O2G:;T]*]]YW`G[XFXQ/?B;FGU^Q^MZFSWXC
M[K__K_S:QD\_H/=;:W_^?>S/_Q[^^]_!!.BL`!+0#08\X,(4R+80```[````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O;'5C+V=R87!H:6-S+V-U<G)E;G1486)?;&5F="YG:68`````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#`U,S<@,3`U,34T,S,W-3,@,#(U,C,P`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````$=)1C@Y80D`E@#$
M``#___]W9E7^_O[]_?SZ^OCY^??]_?W\_/KY^/;X]_7U]._V]?'T\NWR\>OV
M]?#W]O*[LZK=V=7IYN/U]/.!<6&8BW_AW=F8BWZZL:>3A7CAWMG'P+CR\>JN
MI)J3A7?&O[@A^00``````"P`````"0"6```%W"`@:EA%!8'X95`TB<#62;!H
M>70-8)`N7A$?@/+RI81'@&"Y##`-AH$T$!T<"(1"(2"](A*)1P!;0#P<"L:X
MG$`W&NNO@]'@C+.)15I]+3_T"@$'?5\+"UQ660A?5%%765M058,'3DN24R),
M3$DZG36?,*$BHP"EIT*FJ:A(JZZML$:OLK&>L[:UH+>ZN:*[OKVDO\+!JL6L
MM,FXRKS,P,[$T,;2R,O6S=?/V=';T]W5V.':XMSDWN;@X^KEZ^?MZ>SQ[O+P
M\_;U^,/W^OG'_/_^`E(#.%#@-X+=0@``.P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VQU8R]I;F9O
M+G!H<```````````````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P,38W(#$P-3$U-#,S-S4S(#`R,3(V,0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H
M;W)D92]T:&5M97,O;'5C+VEN9F\N<&AP+'8@,2XQ(#(P,#0O,3`O,3<@,3DZ
M,S,Z,S8@;61J=6MI8R!%>'`@)`H@*B\*"B1T:&5M95]N86UE(#T@7R@B3&]Y
M;VQA(BD["@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]L=6,O<V-R965N+F-S<P``````
M````````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-S8V,B`Q,#4Q
M-30S,S<U,R`P,C$V,34`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+VQU8R]S
M8W)E96XN8W-S+'8@,2XQ,"XV+C@@,C`P-2\Q,2\P,B`Q.3HS,CHT."!J86X@
M17AP("0*("HO"@IB;V1Y('L*("`@(&)A8VMG<F]U;F0Z("-F9F8["B`@("!F
M;VYT+69A;6EL>3H@5F5R9&%N82P@1V5N979A+"!!<FEA;"P@2&5L=F5T:6-A
M+"!S86YS+7-E<FEF.PH@("`@<V-R;VQL8F%R+6)A<V4M8V]L;W(Z("-C-&,T
M8C@["B`@("!S8W)O;&QB87(M:&EG:&QI9VAT+6-O;&]R.B`C939E-F1C.PH@
M("`@<V-R;VQL8F%R+6%R<F]W+6-O;&]R.B`C,#`P.PI]"FAT;6P@>PH@("`@
M<V-R;VQL8F%R+6)A<V4M8V]L;W(Z("-C-&,T8C@["B`@("!S8W)O;&QB87(M
M:&EG:&QI9VAT+6-O;&]R.B`C939E-F1C.PH@("`@<V-R;VQL8F%R+6%R<F]W
M+6-O;&]R.B`C,#`P.PI]"BYS96QE8W1E9"!["B`@("!B86-K9W)O=6YD.B`C
M8S9D,V9F.PI]"F$L(&$N9FEX960@>PH@("`@8V]L;W(Z(",S,SD["GT*82YW
M:61G970@>PH@("`@8V]L;W(Z(",P,#`["GT*+FAE861E<B!["B`@("!C;VQO
M<CH@(V8Y,#L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C9CDP.PI]
M"BYH96%D97)B;W@@>PH@("`@8F]R9&5R+6-O;&]R.B`C9CDP.PI]"BYH96%D
M97)B;W@@+FAE861E<B!["B`@("!M87)G:6XM;&5F=#H@+3%P>#L*("`@(&UA
M<F=I;BUR:6=H=#H@+3%P>#L*("`@(&)O<F1E<BUL969T.B!N;VYE.PH@("`@
M8F]R9&5R+7)I9VAT.B!N;VYE.PI]"F$N:&5A9&5R.FAO=F5R('L*("`@(&-O
M;&]R.B`C9F,P.PI]"F$N:&5A9&5R('L*("`@(&)O<F1E<BUB;W1T;VTZ(&YO
M;F4["B`@("!B86-K9W)O=6YD.B!T<F%N<W!A<F5N=#L*?0HN;&EG:'0@>PH@
M("`@8V]L;W(Z(",S,S,["GT*+G-M86QL:&5A9&5R('L*("`@(&-O;&]R.B`C
M,#`P.PH@("`@8F%C:V=R;W5N9#H@=')A;G-P87)E;G0["B`@("!F;VYT+69A
M;6EL>3H@5F5R9&%N82Q(96QV971I8V$L<V%N<RUS97)I9CL*("`@(&9O;G0M
M<VEZ93H@,3%P>#L*("`@(&9O;G0M=V5I9VAT.B!N;W)M86P["GT*82YS;6%L
M;&AE861E<BP@+G-M86QL:&5A9&5R(&$@>PH@("`@8V]L;W(Z("-F.3`["GT*
M82YS;6%L;&AE861E<CIH;W9E<BP@+G-M86QL:&5A9&5R(&$Z:&]V97(@>PH@
M("`@8V]L;W(Z("-F8S`["GT*+F-O;G1R;VP@>PH@("`@8F%C:V=R;W5N9#H@
M(V0X9#AC,3L*?0HN:71E;2!["B`@("!B86-K9W)O=6YD.B`C965E964V.PI]
M"@HO*B!&;W)M('-T>6QE<RX@*B\*:6YP=70@>PH@("`@9F]N="UF86UI;'DZ
M(%9E<F1A;F$L($=E;F5V82P@07)I86PL($AE;'9E=&EC82P@<V%N<RUS97)I
M9CL*("`@(&)A8VMG<F]U;F0Z("-F-V8W964["B`@("!B;W)D97(Z(#%P>"!S
M;VQI9"`C-C8V.PI]"G1E>'1A<F5A('L*("`@(&-O;&]R.B`C,S,S.PH@("`@
M8F%C:V=R;W5N9#H@(V8W9C=E93L*("`@(&)O<F1E<CH@,7!X('-O;&ED(",V
M-C8["GT*:6YP=70Z9F]C=7,L('1E>'1A<F5A.F9O8W5S('L*("`@(&)A8VMG
M<F]U;F0Z("-F9F8["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C9CDP.PI]"G-E
M;&5C="QO<'1I;VX@>PH@("`@8V]L;W(Z(",S,S,["B`@("!B86-K9W)O=6YD
M.B`C9C=F-V5E.PI]"BYB=71T;VX@>PH@("`@8V]L;W(Z(",S,S,["B`@("!B
M86-K9W)O=6YD.B`C9CEF.68X.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O
M;&ED(",P,#`["B`@("!B;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C,#`P.PH@
M("`@8F]R9&5R+6QE9G0Z(#%P>"!S;VQI9"`C8S1C-&(X.PH@("`@8F]R9&5R
M+71O<#H@,7!X('-O;&ED("-C-&,T8C@["B`@("`M;6]Z+6)O<F1E<BUR861I
M=7,Z(#5P>#L*?0HN8G5T=&]N.FAO=F5R('L*("`@(&-O;&]R.B`C9CDP.PI]
M"@HO*B!!;'1E<FYA=&EN9R!S='EL97,N(&ET96TP+"!I=&5M,2!A<F4@9&5P
M<F5C871E9"X@*B\*+G)O=T5V96XL("YI=&5M,"!["B`@("!B86-K9W)O=6YD
M.B`C965E.PI]"BYR;W=/9&0L("YI=&5M,2!["B`@("!B86-K9W)O=6YD.B`C
M9F9F.PI]"@HO*B!-96YU('-T>6QE<RX@*B\*(VUE;G4@>PH@("`@8V]L;W(Z
M("-F9F8["B`@("!B86-K9W)O=6YD.B`C939E-F1C.PH@("`@8F]R9&5R+6)O
M='1O;3H@,G!X('-O;&ED(",X,#@P-T$["GT*(VUE;G4@:#$@>PH@("`@8V]L
M;W(Z(",P,#`["GT*(VUE;G4@82!["B`@("!C;VQO<CH@(S`P,#L*("`@(&)O
M<F1E<CH@;F]N93L*?0HC;65N=2!A.FAO=F5R('L*("`@(&-O;&]R.B`C,#`P
M.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED("-F9F8["B`@("!B;W)D
M97(M<FEG:'0Z(#%P>"!S;VQI9"`C9F9F.PH@("`@8F]R9&5R+6QE9G0Z(#%P
M>"!S;VQI9"`C-S8U.PH@("`@8F]R9&5R+71O<#H@,7!X('-O;&ED(",W-C4[
M"B`@("!P861D:6YG.B`R<'@["GT*(VUE;G4@82YC=7)R96YT('L*("`@(&-O
M;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@(V,P8S!B.#L*("`@(&)O<F1E
M<BUB;W1T;VTZ(#%P>"!S;VQI9"`C9F9F.PH@("`@8F]R9&5R+7)I9VAT.B`Q
M<'@@<V]L:60@(V9F9CL*("`@(&)O<F1E<BUL969T.B`Q<'@@<V]L:60@(S<V
M-3L*("`@(&)O<F1E<BUT;W`Z(#%P>"!S;VQI9"`C-S8U.PH@("`@<&%D9&EN
M9SH@,G!X.PI]"@HO*B!3:61E8F%R('-T>6QE<RX@*B\*(W-I9&5B87)086YE
M;"!["B`@("!B;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C93EE.64Y.PH@("`@
M8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED("-E.64Y93D["B`@("!B86-K9W)O
M=6YD.B`C9C9F-F8V.PI]"B-S:61E8F%R4&%N96P@<W!A;BYT;V=G;&4L("-S
M:61E8F%R4&%N96P@82!["B`@("!P861D:6YG+6QE9G0Z(#%P>#L*("`@('!A
M9&1I;F<M8F]T=&]M.B`R<'@["GT*(W-I9&5B87)086YE;"!S<&%N+G1O9V=L
M92!["B`@("!B;W)D97(Z(#%P>"!N;VYE('1R86YS<&%R96YT.PI]"B-S:61E
M8F%R4&%N96P@82!["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C9C9F-F8V.PI]
M"B-S:61E8F%R4&%N96P@83IH;W9E<B!["B`@("!C;VQO<CH@(S`P,#L*("`@
M(&)A8VMG<F]U;F0Z("-E.64Y93D["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C
M,#`P.PH@("`@=&5X="UD96-O<F%T:6]N.B!N;VYE.PI]"B-E>'!A;F1"=71T
M;VX@>PH@("`@;6%R9VEN+7)I9VAT.B`Q<'@["GT*"B\J(%1A8B!S='EL97,N
M("HO"BYT86)S970@>PH@("`@8F%C:V=R;W5N9#H@(V9F9B!U<FPH(F=R87!H
M:6-S+W1A8E]B;W1T;VTN9VEF(BD@<F5P96%T+7@@8F]T=&]M.PH@("`@9F]N
M="US:7IE.B`Q,7!X.PI]"BYT86)S970@;&D@>PH@("`@;6%R9VEN.B`P.PH@
M("`@8F%C:V=R;W5N9#H@=7)L*")G<F%P:&EC<R]T86)?<FEG:'0N9VEF(BD@
M;F\M<F5P96%T(')I9VAT('1O<#L*?0HN=&%B<V5T(&QI(&$L("YT86)S970@
M;&D@83IH;W9E<B!["B`@("!B86-K9W)O=6YD.B!U<FPH(F=R87!H:6-S+W1A
M8E]L969T+F=I9B(I(&YO+7)E<&5A="!L969T('1O<#L*("`@(&UA<F=I;CH@
M,#L*("`@('!A9&1I;F<Z(#-P>"`Q-7!X.PH@("`@8V]L;W(Z(",W-C4["B`@
M("!B;W)D97(Z(&YO;F4["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@
M(S<V-3L*?0HN=&%B<V5T(&QI(&$Z:&]V97(@>PH@("`@8V]L;W(Z(",S,S,[
M"B`@("!B86-K9W)O=6YD.B!U<FPH(F=R87!H:6-S+W1A8E]L969T+F=I9B(I
M(&YO+7)E<&5A="!L969T('1O<#L*?0HN=&%B<V5T(&QI+F%C=&EV951A8B![
M"B`@("!B86-K9W)O=6YD.B!U<FPH(F=R87!H:6-S+V-U<G)E;G1486)?<FEG
M:'0N9VEF(BD@;F\M<F5P96%T(')I9VAT('1O<#L*?0HN=&%B<V5T(&QI+F%C
M=&EV951A8B!A('L*("`@(&-O;&]R.B`C,S,S.PH@("`@8F%C:V=R;W5N9#H@
M=7)L*")G<F%P:&EC<R]C=7)R96YT5&%B7VQE9G0N9VEF(BD@;F\M<F5P96%T
M(&QE9G0@=&]P.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED("-F9F8[
M"GT*+G1A8G-E="!L:2YA8W1I=F5486(@83IH;W9E<B!["B`@("!C;VQO<CH@
M(SDY.3L*("`@(&)A8VMG<F]U;F0Z('5R;"@B9W)A<&AI8W,O8W5R<F5N=%1A
M8E]L969T+F=I9B(I(&YO+7)E<&5A="!L969T('1O<#L*("`@(&)O<F1E<BUB
M;W1T;VTZ(#%P>"!S;VQI9"`C9F9F.PI]"@``````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]L
M=6-B;'5E````````````````````````````````````````````````````
M```````````````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<U,R`P,C`T,#(`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+VQU8V)L=64O:6YF;RYP:'``````````````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,C`P(#$P-3$U-#,S-S4S(#`R
M,C$Q-0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O;'5C8FQU92]I
M;F9O+G!H<"QV(#$N,2`R,#`T+S$P+S$W(#$Y.C,S.C,V(&UD:G5K:6,@17AP
M("0*("HO"@HD=&AE;65?;F%M92`](%\H(DQO>6]L82!";'5E(BD["@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]L=6-B;'5E+W-C<F5E;BYC<W,`````````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P-3,Q,R`Q,#4Q-30S,S<U,R`P,C(T-30`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+RHJ"B`J("1(
M;W)D93H@:&]R9&4O=&AE;65S+VQU8V)L=64O<V-R965N+F-S<RQV(#$N,3`N
M-BXT(#(P,#4O,3`O,3@@,3$Z,S0Z,C`@:F%N($5X<"`D"B`J+PH*8F]D>2![
M"B`@("!B86-K9W)O=6YD.B`C9F9F.PH@("`@9F]N="UF86UI;'DZ(%9E<F1A
M;F$L($=E;F5V82P@07)I86PL($AE;'9E=&EC82P@<V%N<RUS97)I9CL*("`@
M('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C0S1#-$(X.PH@("`@<V-R;VQL8F%R
M+6AI9VAL:6=H="UC;VQO<CH@(V4V939$0SL*("`@('-C<F]L;&)A<BUA<G)O
M=RUC;VQO<CH@(S`P,#L*?0IH=&UL('L*("`@('-C<F]L;&)A<BUB87-E+6-O
M;&]R.B`C0S1#-$(X.PH@("`@<V-R;VQL8F%R+6AI9VAL:6=H="UC;VQO<CH@
M(V4V939$0SL*("`@('-C<F]L;&)A<BUA<G)O=RUC;VQO<CH@(S`P,#L*?0IA
M('L*("`@(&-O;&]R.B`C,#-#.PI]"F$L(&$N9FEX960@>PH@("`@8V]L;W(Z
M(",S,SD["GT*82YW:61G970@>PH@("`@8V]L;W(Z(",P,#`["GT*:6YP=70@
M>PH@("`@9F]N="UF86UI;'DZ(%9E<F1A;F$L($=E;F5V82P@07)I86PL($AE
M;'9E=&EC82P@<V%N<RUS97)I9CL*("`@(&)A8VMG<F]U;F0Z("-F-V8W964[
M"B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C-C8V.PI]"G1E>'1A<F5A('L*("`@
M(&-O;&]R.B`C,S,S.PH@("`@8F%C:V=R;W5N9#H@(V8W9C=E93L*("`@(&)O
M<F1E<CH@,7!X('-O;&ED(",V-C8["GT*<V5L96-T+&]P=&EO;B!["B`@("!C
M;VQO<CH@(S,S,S,S,SL*("`@(&)A8VMG<F]U;F0Z("-F-V8W964["GT*+FAE
M861E<B!["B`@("!C;VQO<CH@(S`S8SL*("`@(&)O<F1E<BUB;W1T;VTZ(#%P
M>"!S;VQI9"`C,#-C.PI]"BYH96%D97)B;W@@>PH@("`@8F]R9&5R+6-O;&]R
M.B`C,#-C.PI]"BYH96%D97)B;W@@+FAE861E<B!["B`@("!M87)G:6XM;&5F
M=#H@+3%P>#L*("`@(&UA<F=I;BUR:6=H=#H@+3%P>#L*("`@(&)O<F1E<BUL
M969T.B!N;VYE.PH@("`@8F]R9&5R+7)I9VAT.B!N;VYE.PI]"F$N:&5A9&5R
M.FAO=F5R('L*("`@(&-O;&]R.B`C,#9F.PI]"F$N<VUA;&QH96%D97(Z:&]V
M97(@>PH@("`@8V]L;W(Z(",P-F8["GT*82YH96%D97(@>PH@("`@8F]R9&5R
M+6)O='1O;3H@;F]N93L*("`@(&)A8VMG<F]U;F0Z('1R86YS<&%R96YT.PI]
M"BYL:6=H="!["B`@("!C;VQO<CH@(S,S,SL*?0HN<VUA;&QH96%D97(@>PH@
M("`@8V]L;W(Z(",P,#`["B`@("!B86-K9W)O=6YD.B!T<F%N<W!A<F5N=#L*
M?0HN<VUA;&QH96%D97(@>PH@("`@8V]L;W(Z(",P,#`["B`@("!F;VYT+69A
M;6EL>3H@5F5R9&%N82Q(96QV971I8V$L<V%N<RUS97)I9CL*("`@(&9O;G0M
M<VEZ93H@,3%P>#L*("`@(&9O;G0M=V5I9VAT.B!N;W)M86P["GT*+F-O;G1R
M;VP@>PH@("`@8F%C:V=R;W5N9#H@(T0X1#A#,3L*?0HN:71E;2!["B`@("!B
M86-K9W)O=6YD.B`C965E964V.PI]"B\J($%L=&5R;F%T:6YG('-T>6QE<RX@
M:71E;3`L(&ET96TQ(&%R92!D97!R96-A=&5D+B`J+PHN<F]W179E;BP@+FET
M96TP('L*("`@(&)A8VMG<F]U;F0Z("-F.68Y9CD["GT*+G)O=T]D9"P@+FET
M96TQ('L*("`@(&)A8VMG<F]U;F0Z("-E.64Y93D["GT*+F)U='1O;B!["B`@
M("!C;VQO<CH@(S,S,SL*("`@(&)A8VMG<F]U;F0Z("-F.68Y9C@["B`@("!B
M;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(S`P,#L*("`@(&)O<F1E<BUR:6=H
M=#H@,7!X('-O;&ED(",P,#`["B`@("!B;W)D97(M;&5F=#H@,7!X('-O;&ED
M("-#-$,T0C@["B`@("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(T,T0S1".#L*
M("`@("UM;WHM8F]R9&5R+7)A9&EU<SH@-7!X.PI]"BYS96QE8W1E9"!["B`@
M("!B86-K9W)O=6YD.B`C0S9$,V9F.PI]"BYI;E!R;V=R97-S('L*("`@(&)A
M8VMG<F]U;F0Z(",P,#,S8V,["GT*"B\J($UE;G4@<W1Y;&5S+B`J+PHC;65N
M=2!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z("-E-F4V9&,[
M"B`@("!B;W)D97(M8F]T=&]M.B`R<'@@<V]L:60@(S@P.#`W03L*?0HC;65N
M=2!H,2!["B`@("!C;VQO<CH@(S`P,#L*?0HC;65N=2!A('L*("`@(&-O;&]R
M.B`C,#`P.PH@("`@8F]R9&5R.B!N;VYE.PI]"B-M96YU(&$N8W5R<F5N="![
M"B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z("-C,&,P8C@["B`@
M("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(V5E93L*("`@(&)O<F1E<BUR
M:6=H=#H@,7!X('-O;&ED("-E964["B`@("!B;W)D97(M;&5F=#H@,7!X('-O
M;&ED(",P,#`["B`@("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(S`P,#L*("`@
M('!A9&1I;F<Z(#)P>#L*("`@("UM;WHM8F]R9&5R+7)A9&EU<SH@-7!X.PI]
M"@HO*B!3:61E8F%R('-T>6QE<RX@*B\*8F]D>2YS:61E8F%R('L*("`@(&)A
M8VMG<F]U;F0Z("-F.68Y9C,["GT*(W-I9&5B87)086YE;"!["B`@("!B;W)D
M97(M<FEG:'0Z(#%P>"!S;VQI9"`C.#`X,#=A.PH@("`@8F]R9&5R+6)O='1O
M;3H@,7!X('-O;&ED(",X,#@P-V$["B`@("!B86-K9W)O=6YD.B`C939E-F1C
M.PI]"B-S:61E8F%R4&%N96P@82!["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C
M939E-F1C.PH@("`@<&%D9&EN9RUL969T.B`Q<'@["B`@("!P861D:6YG+6)O
M='1O;3H@,G!X.PI]"B-S:61E8F%R4&%N96P@83IH;W9E<B!["B`@("!B86-K
M9W)O=6YD.B`C939E-F1C.PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(S`S8SL*
M("`@('1E>'0M9&5C;W)A=&EO;CH@;F]N93L*("`@("UM;WHM8F]R9&5R+7)A
M9&EU<SH@,W!X.PI]"B-E>'!A;F1"=71T;VX@>PH@("`@;6%R9VEN+7)I9VAT
M.B`Q<'@["GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+W!O<W1N=6ME````
M````````````````````````````````````````````````````````````
M`````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M,#`P(#$P-3$U-#,S-S4S(#`R,#8Q-P`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O<&]S=&YU:V4O:6YF;RYP:'``````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`Q-S8@,3`U,34T,S,W-3,@,#(R,S0V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]P;W-T;G5K92]I;F9O+G!H<"QV
M(#$N,2`R,#`T+S$P+S$W(#$Y.C,S.C,W(&UD:G5K:6,@17AP("0*("HO"@HD
M=&AE;65?;F%M92`](%\H(E!O<W1N=6ME(BD["@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+W!O<W1N
M=6ME+W-C<F5E;BYC<W,`````````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`S-3$W(#$P-3$U-#,S-S4S(#`R,C8W-0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````O*BH*("H@)$AO<F1E.B!H;W)D
M92]T:&5M97,O<&]S=&YU:V4O<V-R965N+F-S<RQV(#$N."XV+C(@,C`P-2\Q
M,"\Q."`Q,3HS-#HR,"!J86X@17AP("0*("HO"@IB;V1Y('L*("`@(&)A8VMG
M<F]U;F0Z("-B,6(W.&(["B`@("!S8W)O;&QB87(M8F%S92UC;VQO<CH@(S8V
M-C8Y.3L*("`@('-C<F]L;&)A<BUA<G)O=RUC;VQO<CH@(V1D9&1F9CL*?0IH
M=&UL('L*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C-C8V-CDY.PH@("`@
M<V-R;VQL8F%R+6%R<F]W+6-O;&]R.B`C9&1F.PI]"F$@>PH@("`@8V]L;W(Z
M(",S,SD["B`@("!F;VYT+69A;6EL>3H@1V5N979A+$%R:6%L+$AE;'9E=&EC
M82QS86YS+7-E<FEF.PH@("`@9F]N="US:7IE.B`Q,G!X.PI]"F$Z:&]V97(@
M>PH@("`@8V]L;W(Z(&)L=64["GT*82YW:61G970@>PH@("`@8V]L;W(Z(",P
M,#`["B`@("!F;VYT+69A;6EL>3H@5F5R9&%N82Q(96QV971I8V$L<V%N<RUS
M97)I9CL*("`@(&9O;G0M<VEZ93H@,3%P>#L*?0IA+G=I9&=E=#IH;W9E<B![
M"B`@("!C;VQO<CH@8FQU93L*("`@(&)A8VMG<F]U;F0Z("-B,6(W.&(["GT*
M+FAE861E<B!["B`@("!B86-K9W)O=6YD.B`C8C%B-SAB.PH@("`@9F]N="US
M:7IE.B`Q-W!X.PI]"BYL:6=H="!["B`@("!C;VQO<CH@=VAI=&4["B`@("!F
M;VYT+69A;6EL>3H@1V5N979A+$%R:6%L+$AE;'9E=&EC82QS86YS+7-E<FEF
M.PH@("`@9F]N="US:7IE.B`Q,G!X.PI]"BYS;6%L;&AE861E<B!["B`@("!C
M;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0Z("-B,6(W.&(["GT*+F-O;G1R
M;VP@>PH@("`@8V]L;W(Z(&)L86-K.PH@("`@8F%C:V=R;W5N9#H@(V0Y9&-C
M,CL*?0HN:71E;2!["B`@("!C;VQO<CH@8FQA8VL["B`@("!B86-K9W)O=6YD
M.B`C93EE.64Y.PI]"BYB=71T;VX@>PH@("`@8V]L;W(Z('=H:71E.PH@("`@
M8F%C:V=R;W5N9"UC;VQO<CH@(S`P,#`P,#L*("`@(&)O<F1E<BUB;W1T;VTZ
M('1H:6X@<V]L:60@(T(Q0C<X0CL*("`@(&)O<F1E<BUR:6=H=#H@=&AI;B!S
M;VQI9"`C0C%"-SA".PH@("`@8F]R9&5R+71O<#H@=&AI;B!S;VQI9"`C.3DY
M.6-C.PH@("`@8F]R9&5R+6QE9G0Z('1H:6X@<V]L:60@(SDY.3EC8SL*("`@
M(&9O;G0M<VEZ93H@,3%P>#L*("`@(&9O;G0M9F%M:6QY.B!697)D86YA+$AE
M;'9E=&EC82QS86YS+7-E<FEF.PI]"BYS96QE8W1E9"!["B`@("!B86-K9W)O
M=6YD+6-O;&]R.B`C8F)C8F9F.PI]"BYT97AT('L*("`@(&-O;&]R.B!B;&%C
M:SL*("`@(&)A8VMG<F]U;F0M8V]L;W(Z('=H:71E.PI]"B\J($%L=&5R;F%T
M:6YG('-T>6QE<RX@:71E;3`L(&ET96TQ(&%R92!D97!R96-A=&5D+B`J+PHN
M<F]W179E;BP@+FET96TP('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-F.68Y
M9CD["GT*+G)O=T]D9"P@+FET96TQ('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z
M("-E.64Y93D["GT*+F9I>&5D('L*("`@(&9O;G0M<VEZ93H@,3-P>#L*("`@
M(&9O;G0M9F%M:6QY.B!M;VYO<W!A8V4L(&9I>&5D.PI]"G1D('L*("`@(&9O
M;G0M<VEZ93H@,3)P>#L*("`@(&9O;G0M9F%M:6QY.B!'96YE=F$L07)I86PL
M2&5L=F5T:6-A+'-A;G,M<V5R:68["GT*=&@@>PH@("`@9F]N="US:7IE.B`Q
M,G!X.PH@("`@9F]N="UF86UI;'DZ($=E;F5V82Q!<FEA;"Q(96QV971I8V$L
M<V%N<RUS97)I9CL*?0H*+RH@365N=2!S='EL97,N("HO"B-M96YU('L*("`@
M(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@(V(Q8C<X8CL*?0HC;65N
M=2!A('L*("`@(&-O;&]R.B`C9F9F.PI]"B-M96YU(&$N8W5R<F5N="!["B`@
M("!B86-K9W)O=6YD.B`C8F9B-SAB.PI]"@HO*B!3:61E8F%R('-T>6QE<RX@
M*B\*(W-I9&5B87)086YE;"!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C0C%"
M-SA".PI]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]B87)B:64`````
M````````````````````````````````````````````````````````````
M```````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,#`P,"`Q,#4Q-30S,S<U,R`P,C`Q-S,`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V)A<F)I92]I;F9O+G!H<```````````````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`P,3<U(#$P-3$U-#,S-S4S(#`R,3<R,0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O8F%R8FEE+VEN9F\N<&AP+'8@
M,2XQ(#(P,#0O,3`O,3<@,3DZ,S,Z,S,@;61J=6MI8R!%>'`@)"`_/@H@*B\*
M"B1T:&5M95]N86UE(#T@7R@B0F%R8FEE(BD["@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]B87)B
M:64O<V-R965N+F-S<P``````````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,3<W,2`Q,#4Q-30S,S<U,R`P,C(R-3$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+RHJ"B`J("1(;W)D93H@:&]R
M9&4O=&AE;65S+V)A<F)I92]S8W)E96XN8W-S+'8@,2XU+C8N,B`R,#`U+S$P
M+S$X(#$Q.C,T.C$Q(&IA;B!%>'`@)`H@*B\*"F)O9'D@>PH@("`@8F%C:V=R
M;W5N9#H@(V9E8C9C,CL*?0IA('L*("`@(&-O;&]R.B`C-#0X9CDY.PI]"@HN
M:&5A9&5R('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@(V9F
M.&5A-3L*?0HN<VUA;&QH96%D97(@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B
M86-K9W)O=6YD.B`C9F8X96$U.PI]"BYC;VYT<F]L('L*("`@(&)A8VMG<F]U
M;F0M8V]L;W(Z("-F8V,R9#`["GT*+F)U='1O;B!["B`@("!C;VQO<CH@(V9F
M9CL*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-F-#8Q-V8["B`@("!B;W)D97(M
M8F]T=&]M.B!T:&EN('-O;&ED("-F-#8Q-V8["B`@("!B;W)D97(M<FEG:'0Z
M('1H:6X@<V]L:60@(V8T-C$W9CL*("`@(&)O<F1E<BUT;W`Z('1H:6X@<V]L
M:60@(V9F.#EA,3L*("`@(&)O<F1E<BUL969T.B!T:&EN('-O;&ED("-F9C@Y
M83$["GT*+G1E>'0@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V9F935E8SL*
M?0H*+RH@365N=2!S='EL97,N("HO"B-M96YU('L*("`@(&-O;&]R.B`C9F9F
M.PH@("`@8F%C:V=R;W5N9#H@(V9F.3%A-SL*?0HC;65N=2!A+F-U<G)E;G0@
M>PH@("`@8F%C:V=R;W5N9#H@(V8T-C$W9CL*("`@(&)O<F1E<BUB;W1T;VTZ
M(#%P>"!S;VQI9"`C86%C.PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@
M(V%A8SL*("`@(&)O<F1E<BUL969T.B`Q<'@@<V]L:60@(S`P,#L*("`@(&)O
M<F1E<BUT;W`Z(#%P>"!S;VQI9"`C,#`P.PH@("`@<&%D9&EN9SH@,G!X.PI]
M"@HO*B!3:61E8F%R('-T>6QE<RX@*B\*(W-I9&5B87)086YE;"!["B`@("!B
M;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C9F5B-F,R.PH@("`@8F]R9&5R+6)O
M='1O;3H@,7!X('-O;&ED("-F96(V8S(["B`@("!B86-K9W)O=6YD+6-O;&]R
M.B`C9F8X96$U.PI]"B-E>'!A;F1"=71T;VX@>PH@("`@;6%R9VEN+7)I9VAT
M.B`Q<'@["GT*`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]M;WII;&QA````````````````````````````````````````````````
M```````````````````````````````````P,#`W-34@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<U,R`P,C`T,38`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+VUO>FEL;&$O9W)A<&AI8W,`````````````
M`````````````````````````````````````````````````````````#`P
M,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,S-S4S
M(#`R,C(Q-@`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O;6]Z:6QL82]G
M<F%P:&EC<R]M96YU+G!N9P``````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#`S,#<@,3`U,34T,S,W-3,@,#(S-S0W`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````!````
M,P@"````V<7U>`````=T24U%!]('$`H6`1<3G)P````)<$A9<P``"O````KP
M`4*L-)@````$9T%-00``L8\+_&$%````5DE$051XVE6,L0J`,!!#C_[_QSEV
M$'1S4!#$.6GOKD$[A"8ON=KYLCSW5<QL$N7)]/T-/C*1&40P0#W".\_LV\ZH
M?6Z^>X:H'O-_ZIS_L_:N=3]LJ5L#OTY=R0.?TKT`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VUO>FEL;&$O9W)A<&AI8W,O;65N
M=2UA8W1I=F4N<&YG````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,S(W(#$P-3$U
M-#,S-S4S(#`R-3(R,@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12`````0```#`(!@```-`S$($`
M```$<T))5`@("`A\"&2(````"7!(67,```KP```*\`%"K#28````(71%6'13
M;V9T=V%R90!-86-R;VUE9&EA($9I<F5W;W)K<R`T+C#J)B=U````3$E$051X
MG&V/L1&`,!##+.V_#0/0LQ04GWS(0>-"YUCY'.=UFR05P`AA,/6'=4_?;]U[
M5,\HTR%$:G0Q>]2OHUGMM:T^SF19WKYHCP=F'@0)V59GUP````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]M;WII;&QA+V=R87!H:6-S+VAE861E<BYP;F<`````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#0P,"`Q,#4Q-30S,S<U,R`P,C0R
M,C4`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@````<````9"`(```!R[*-O````+'1%6'1#<F5A
M=&EO;B!4:6UE`%1U92`Q-B!*=6P@,C`P,B`R,SHT-3HQ."`K,3(P,,6!&%$`
M```'=$E-10?2!Q`++@D/E<)B````"7!(67,```[#```.PP'';ZAD````!&=!
M34$``+&/"_QA!0```%=)1$%4>-ICG+)H+0,&8#QW_1ZF*,OSYQ\P19D8L`$6
M!E8&8M7B,($#N[DL6$49L*C&Y3*L)G"2X#*L)N!2B\UEI)A`N2C+N?/G,449
MO7RCL(@>NXPEY@$>T`USO=1@\`````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O;6]Z:6QL82]I;F9O+G!H<```````````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#`Q-S0@,3`U,34T,S,W-3,@,#(R,30S`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]M;WII;&QA+VEN9F\N<&AP+'8@,2XQ
M(#(P,#0O,3`O,3<@,3DZ,S,Z,S<@;61J=6MI8R!%>'`@)`H@*B\*"B1T:&5M
M95]N86UE(#T@7R@B36]Z:6QL82(I.PH`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VUO>FEL;&$O
M<V-R965N+F-S<P``````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`S,34V(#$P-3$U-#,S-S4S(#`R,C0W,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````O*BH*("H@)$AO<F1E.B!H;W)D92]T
M:&5M97,O;6]Z:6QL82]S8W)E96XN8W-S+'8@,2XW+C8N-2`R,#`U+S$P+S$X
M(#$Q.C,T.C(P(&IA;B!%>'`@)`H@*B\*"F)O9'D@>PH@("`@8F%C:V=R;W5N
M9#H@(V,W9#!D.3L*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C.31A,F(U
M.PI]"FAT;6P@>PH@("`@<V-R;VQL8F%R+6)A<V4M8V]L;W(Z(",Y-&$R8C4[
M"GT*82P@82YF:7AE9"!["B`@("!C;VQO<CH@(S,S.3L*?0IA+G=I9&=E="![
M"B`@("!C;VQO<CH@(S`P,#L*?0HN:&5A9&5R('L*("`@(&)A8VMG<F]U;F0Z
M("-C-V0P9#D@=7)L*")G<F%P:&EC<R]H96%D97(N<&YG(BD@<F5P96%T+7@[
M"B`@("!W:&ET92US<&%C93H@;F]W<F%P.PI]"F$N:&5A9&5R('L*("`@(&)A
M8VMG<F]U;F0M:6UA9V4Z(&YO;F4["B`@("!B86-K9W)O=6YD+6-O;&]R.B!T
M<F%N<W!A<F5N=#L*?0HN;&EG:'0@>PH@("`@8V]L;W(Z(",T135$-S(["GT*
M+G-M86QL:&5A9&5R('L*("`@(&-O;&]R.B!B;&%C:SL*("`@(&)A8VMG<F]U
M;F0M:6UA9V4Z(&YO;F4["B`@("!B86-K9W)O=6YD+6-O;&]R.B!T<F%N<W!A
M<F5N=#L*?0HN<VUA;&QH96%D97(@82!["B`@("!C;VQO<CH@8FQA8VL["GT*
M+F-O;G1R;VP@>PH@("`@8F%C:V=R;W5N9#H@(V%E8F%C83L*?0HN:71E;2![
M"B`@("!B86-K9W)O=6YD.B`C96-E9F8T.PI]"BYB=71T;VX@>PH@("`@8V]L
M;W(Z(&)L86-K.PH@("`@8F%C:V=R;W5N9#H@(V%D8C9C-CL*("`@(&)O<F1E
M<CH@,7!X('-O;&ED(",P,#`["B`@("`M;6]Z+6)O<F1E<BUR861I=7,Z(#5P
M>#L*?0HN<V5L96-T960@>PH@("`@8F%C:V=R;W5N9#H@(V,V9#-F9CL*?0H*
M+RH@365N=2!S='EL97,N("HO"B-M96YU('L*("`@(&)A8VMG<F]U;F0Z("-C
M-V0P9#D@=7)L*")G<F%P:&EC<R]M96YU+G!N9R(I(')E<&5A="UX.PI]"B-M
M96YU(&@Q('L*("`@(&-O;&]R.B!B;&%C:SL*?0HC;65N=2!A('L*("`@(&-O
M;&]R.B!B;&%C:SL*("`@(&)O<F1E<CH@;F]N93L*("`@("UM;WHM8F]R9&5R
M+7)A9&EU<SH@,#L*?0HC;65N=2!A.FAO=F5R('L*("`@(&)O<F1E<CH@,7!X
M('-O;&ED("-A96)A8V$["B`@("!P861D:6YG.B`R<'@["GT*(VUE;G4@82YC
M=7)R96YT('L*("`@(&)A8VMG<F]U;F0Z('5R;"@B9W)A<&AI8W,O;65N=2UA
M8W1I=F4N<&YG(BD@<F5P96%T+7@["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C
M865B86-A.PH@("`@<&%D9&EN9SH@,G!X.PI]"B-M96YU(&$N8W5R<F5N=#IH
M;W9E<B!["B`@("!P861D:6YG.B`R<'@["GT*"B\J(%-I9&5B87(@<W1Y;&5S
M+B`J+PHC<VED96)A<E!A;F5L('L*("`@(&)A8VMG<F]U;F0Z("-C-V0P9#D[
M"GT*"B\J(%1A8B!S='EL97,N("HO"BYT86)S970@>PH@("`@8F%C:V=R;W5N
M9#H@;F]N93L*?0HN=&%B<V5T(&QI(&$@>PH@("`@8F]R9&5R.B`Q<'@@<V]L
M:60@(V%B86)A8CL*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C93EE
M.64Y.PI]"BYT86)S970@;&D@83IH;W9E<B!["B`@("!C;VQO<CH@(S`P,#L*
M?0HN=&%B<V5T(&QI+F%C=&EV951A8B!A+"`N=&%B<V5T(&QI+F%C=&EV951A
M8B!A.FAO=F5R('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@
M(V%E8F%C83L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C865B86-A
M.PI]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]B;'5E;6]O;@``````
M````````````````````````````````````````````````````````````
M```````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P
M,"`Q,#4Q-30S,S<U,R`P,C`U-C<`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V)L=65M;V]N+VEN9F\N<&AP````````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P,3<W(#$P-3$U-#,S-S4S(#`R,C,Q-P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@)$AO<F1E.B!H;W)D92]T:&5M97,O8FQU96UO;VXO:6YF;RYP:'`L=B`Q
M+C$@,C`P-"\Q,"\Q-R`Q.3HS,SHS-"!M9&IU:VEC($5X<"`D"B`J+PH*)'1H
M96UE7VYA;64@/2!?*")";'5E($UO;VXB*3L*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]B;'5E;6]O
M;B]S8W)E96XN8W-S````````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P-C0Q,B`Q,#4Q-30S,S<U,R`P,C(V-#(`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+RHJ"B`J("1(;W)D93H@:&]R9&4O
M=&AE;65S+V)L=65M;V]N+W-C<F5E;BYC<W,L=B`Q+C$S+C8N,R`R,#`U+S$P
M+S$X(#$Q.C,T.C$Q(&IA;B!%>'`@)`H@*B\*"F)O9'D@>PH@("`@9F]N="UF
M86UI;'DZ($QU>&D@4V%N<RQ697)D86YA.PH@("`@8F%C:V=R;W5N9#H@(S`P
M,S@Y,SL*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C,#`S.#DS.PH@("`@
M<V-R;VQL8F%R+6%R<F]W+6-O;&]R.B`C,#$V.&1B.PI]"FAT;6P@>PH@("`@
M<V-R;VQL8F%R+6)A<V4M8V]L;W(Z(",P,#,X.3,["B`@("!S8W)O;&QB87(M
M87)R;W<M8V]L;W(Z(",P,38X9&(["GT*:6YP=70@>PH@("`@9F]N="UF86UI
M;'DZ($QU>&D@4V%N<RQ697)D86YA.PI]"G-E;&5C="!["B`@("!F;VYT+69A
M;6EL>3H@3'5X:2!386YS+%9E<F1A;F$["B`@("!F;VYT+7=E:6=H=#H@;F]R
M;6%L.PI]"G1D('L*("`@(&9O;G0M9F%M:6QY.B!,=7AI(%-A;G,L5F5R9&%N
M83L*?0IT:"!["B`@("!F;VYT+69A;6EL>3H@3'5X:2!386YS+%9E<F1A;F$[
M"GT*:6UG('L*("`@(&)O<F1E<CH@;F]N93L*?0IA('L*("`@(&9O;G0M9F%M
M:6QY.B!,=7AI(%-A;G,L5F5R9&%N83L*("`@(&-O;&]R.B`C,#`S0V9F.PI]
M"F$Z:&]V97(@>PH@("`@8V]L;W(Z(",P,#,X.3,["GT*82YW:61G970@>PH@
M("`@8V]L;W(Z(",P,#-#9F8["B`@("!F;VYT+7-I>F4Z(#`N.65M.PI]"F$N
M=VED9V5T.FAO=F5R('L*("`@(&-O;&]R.B`C,#`S.#DS.PH@("`@8F%C:V=R
M;W5N9#H@(S`Q-CAD8CL*?0HN:&5A9&5R('L*("`@(&-O;&]R.B`C,C<P,#0R
M.PH@("`@8F%C:V=R;W5N9#H@(S`Q-CAD8CL*("`@(&9O;G0M9F%M:6QY.B!,
M=7AI(%-A;G,L5F5R9&%N83L*("`@(&9O;G0M<VEZ93H@,39P>#L*?0HN:&5A
M9&5R(&$@>PH@("`@8V]L;W(Z(",R-S`P-#(["GT*=&0N:&5A9&5R('L*("`@
M('!A9&1I;F<M;&5F=#H@,W!X.PH@("`@<&%D9&EN9RUR:6=H=#H@,W!X.PI]
M"F$N:&5A9&5R('L*("`@(&-O;&]R.B`C,#!A.&9F.PI]"BYL:6=H="!["B`@
M("!C;VQO<CH@(V9F9CL*("`@(&9O;G0M9F%M:6QY.B!,=7AI(%-A;G,L5F5R
M9&%N83L*?0IA+FQI9VAT.FAO=F5R('L*("`@(&-O;&]R.B`C1D9#.#`P.PI]
M"BYS;6%L;&AE861E<B!["B`@("!C;VQO<CH@(S(W,#`T,CL*("`@(&)A8VMG
M<F]U;F0Z(",P,38X9&(["B`@("!F;VYT+69A;6EL>3H@3'5X:2!386YS+%9E
M<F1A;F$["B`@("!F;VYT+7-I>F4Z(#$T<'@["GT*82YS;6%L;&AE861E<B![
M"B`@("!C;VQO<CH@(S`P83AF9CL*?0HN<VUA;&P@>PH@("`@9F]N="UF86UI
M;'DZ($QU>&D@4V%N<RQ697)D86YA.PH@("`@9F]N="US:7IE.B`P+CAE;3L*
M?0HN8V]N=')O;"!["B`@("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0M
M8V]L;W(Z("-D,60Q9#$["GT*+FET96T@>PH@("`@8V]L;W(Z(",P,#`["B`@
M("!B86-K9W)O=6YD+6-O;&]R.B`C93EE.64Y.PI]"BYB=71T;VX@>PH@("`@
M8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C,F(W,V0U.PH@
M("`@8F]R9&5R+6)O='1O;3H@=&AI;B!S;VQI9"`C.3EC.PH@("`@8F]R9&5R
M+7)I9VAT.B!T:&EN('-O;&ED(",Y.6,["B`@("!B;W)D97(M=&]P.B!T:&EN
M('-O;&ED(",P,#`["B`@("!B;W)D97(M;&5F=#H@=&AI;B!S;VQI9"`C,#`P
M.PH@("`@9F]N="US:7IE.B`Q,G!X.PH@("`@9F]N="UF86UI;'DZ($QU>&D@
M4V%N<RQ697)D86YA.PH@("`@+6UO>BUB;W)D97(M<F%D:75S.B`U<'@["GT*
M+F)U='1O;CIH;W9E<B!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C,3$V-69F
M.PI]"BYS96QE8W1E9"!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C8F)C8F9F
M.PI]"BYF:7AE9"!["B`@("!F;VYT+7-I>F4Z(#$S<'@["B`@("!F;VYT+69A
M;6EL>3H@36]N86-O+$-O=7)I97(L;6]N;W-P86-E9"QF:7AE9#L*?0HN<V5L
M96-T960M;W9E<B!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C8V-E969F.PI]
M"BYT;V]L=&EP('L*("`@(&9O;G0M<VEZ93H@,3!P>#L*("`@(&)A8VMG<F]U
M;F0M8V]L;W(Z("-F9F,["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C,#`P.PH@
M("`@<&%D9&EN9SH@,G!X.PI]"BYA8V-E<W-+97D@>PH@("`@=&5X="UD96-O
M<F%T:6]N.B!U;F1E<FQI;F4["GT*82YH96%D97(Z:&]V97(@>PH@("`@8V]L
M;W(Z(#L*?0IA+F-U<G)E;G1486(Z:&]V97(@>PH@("`@8V]L;W(Z(#L*?0HN
M;F]T:6-E('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-F9F,["GT*+G-I9VYA
M='5R92!["B`@("!C;VQO<CH@(S8P-C`V,#L*?0HN<VEG;F%T=7)E+69I>&5D
M('L*("`@(&-O;&]R.B`C-C`V,#8P.PH@("`@9F]N="US:7IE.B`Q,'!X.PH@
M("`@9F]N="UF86UI;'DZ($UO;F%C;RQ#;W5R:65R+&UO;F]S<&%C960L9FEX
M960["GT*"B\J(%1A8FQE('-T>6QE<RX@*B\*+FQI;F5D4F]W('L*("`@(&-O
M;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V9F9CL*("`@(&)O
M<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C9&1D.PI]"BYL:6YE9%)O=U-E;&5C
M=&5D0V]L('L*("`@(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N9"UC;VQO
M<CH@(V8S9C-F,SL*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C9&1D
M.PI]"B\J($%L=&5R;F%T:6YG('-T>6QE<RX@:71E;3`L(&ET96TQ(&%R92!D
M97!R96-A=&5D+B`J+PHN<F]W179E;BP@+FET96TP('L*("`@(&)A8VMG<F]U
M;F0M8V]L;W(Z("-F,V8S9C,["GT*+G)O=T]D9"P@+FET96TQ('L*("`@(&)A
M8VMG<F]U;F0M8V]L;W(Z("-E.64Y93D["GT*"B\J($UE;G4@<W1Y;&5S+B`J
M+PHC;65N=2!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0M8V]L
M;W(Z(",P,38X9&(["B`@("!F;VYT+69A;6EL>3H@3'5X:2!386YS+%9E<F1A
M;F$["GT*(VUE;G4@82!["B`@("!C;VQO<CH@(V9F9CL*?0HC;65N=2!A+F-U
M<G)E;G0@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD.B`C,#$V
M.&)B.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",Y.6,["B`@("!B
M;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C.3EC.PH@("`@8F]R9&5R+71O<#H@
M,7!X('-O;&ED(",P,C,P-C0["B`@("!B;W)D97(M;&5F=#H@,7!X('-O;&ED
M(",P,C,P-C0["B`@("!P861D:6YG.B`R<'@["B`@("`M;6]Z+6)O<F1E<BUR
M861I=7,Z(#5P>#L*?0H*+RH@4VED96)A<B!S='EL97,N("HO"B-S:61E8F%R
M4&%N96P@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(S`Q-CAD8CL*?0HC<VED
M96)A<E!A;F5L('-P86XL("-S:61E8F%R4&%N96P@82!["B`@("!F;VYT+7=E
M:6=H=#H@8F]L9#L*("`@(&-O;&]R.B`C9F9F.PI]"B-S:61E8F%R4&%N96P@
M83IH;W9E<B!["B`@("!C;VQO<CH@(V9F8S@P,#L*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O;&EG:'1B
M;'5E````````````````````````````````````````````````````````
M````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`P,#`@,3`U,34T,S,W-3,@,#(P-S(V`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]L:6=H=&)L=64O9W)A<&AI8W,`````````````````````
M```````````````````````````````````````````````P,#`W-34@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<U,R`P,C(U,C8`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VQI9VAT8FQU92]G<F%P:&EC
M<R]M96YU+G!N9P``````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,38T(#$P
M-3$U-#,S-S4S(#`R-#(V,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````0P```!0!`P```.R/
M$G\````&4$Q416NEWG.M[\2S<UX````)<$A9<P```$@```!(`$;):SX````4
M241!5`C78V#``OY#P0,DUB!7!P`>T5AQKDZ&B0````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]L:6=H=&)L=64O:6YF;RYP:'``````````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#(P,2`Q,#4Q-30S,S<U,R`P
M,C(T-#(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+VQI9VAT8FQU
M92]I;F9O+G!H<"QV(#$N,2`R,#`T+S$P+S$W(#$Y.C,S.C,V(&UD:G5K:6,@
M17AP("0*("HO"@HD=&AE;65?;F%M92`](%\H(DQI9VAT($)L=64B*3L*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O;&EG:'1B;'5E+W-C<F5E;BYC<W,`````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#$Q-#`@,3`U,34T,S,W-3,@,#(R-S<R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"\J*@H@*B`D
M2&]R9&4Z(&AO<F1E+W1H96UE<R]L:6=H=&)L=64O<V-R965N+F-S<RQV(#$N
M."XV+C$@,C`P-2\Q,"\Q."`Q,3HS-#HQ.2!J86X@17AP("0*("HO"@IB;V1Y
M('L*("`@(&)A8VMG<F]U;F0Z("-B,&0P9C$["GT*82!["B`@("!C;VQO<CH@
M(S,S.3L*?0HN:&5A9&5R('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R
M;W5N9#H@(S9B835D93L*?0HN<VUA;&QH96%D97(@>PH@("`@8V]L;W(Z("-F
M9F8["B`@("!B86-K9W)O=6YD.B`C-F)A-61E.PI]"BYB=71T;VX@>PH@("`@
M8F%C:V=R;W5N9"UI;6%G93H@=7)L*&=R87!H:6-S+VUE;G4N<&YG*3L*?0H*
M+RH@365N=2!S='EL97,N("HO"B-M96YU('L*("`@(&-O;&]R.B`C9F9F.PH@
M("`@8F%C:V=R;W5N9"UC;VQO<CH@(S9B835D93L*("`@(&)A8VMG<F]U;F0M
M:6UA9V4Z('5R;"AG<F%P:&EC<R]M96YU+G!N9RD["GT*(VUE;G4@82YC=7)R
M96YT('L*("`@(&)A8VMG<F]U;F0Z("-B,&0P9C$["GT*"B\J(%-I9&5B87(@
M<W1Y;&5S+B`J+PHC<VED96)A<E!A;F5L('L*("`@(&)A8VMG<F]U;F0M8V]L
M;W(Z("-B,&0P9C$["GT*(W-I9&5B87)086YE;"!A.FAO=F5R('L*("`@(&-O
M;&]R.B!Y96QL;W<["GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O;6]B:6QE````````````````````````````````````
M````````````````````````````````````````````````,#`P-S4U(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W-30@,#(P,C$W
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]M;V)I;&4O<V-R965N+F-S
M<P``````````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3,V,R`Q
M,#4Q-30S,S<U-"`P,C(R-S(`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+VUO
M8FEL92]S8W)E96XN8W-S+'8@,2XQ+C$P+C$@,C`P-2\Q,"\Q."`Q,3HS-#HR
M,"!J86X@17AP("0*("HO"@IB;V1Y('L*("`@(&)A8VMG<F]U;F0Z("-F9F8[
M"B`@("!F;VYT+69A;6EL>3H@0V]U<FEE<CL*("`@(&9O;G0M<VEZ93H@,3!P
M>#L*?0IT9"!["B`@("!F;VYT+69A;6EL>3H@0V]U<FEE<CL*("`@(&9O;G0M
M<VEZ93H@,3!P>#L*?0ID:78N<VEM9&5V('L*("`@('=I9'1H.B`Q-3`["B`@
M("!H96EG:'0Z(#$R,#L*("`@(&]V97)F;&]W.B!A=71O.PI]"G1D+G1O<"![
M"B`@("!W:61T:#H@,C8S.PH@("`@:&5I9VAT.B`Q,3<["B`@("!B86-K9W)O
M=6YD+6EM86=E.B!U<FPH9W)A<&AI8W,O=&]P+FIP9RD["GT*=&0N;&5F="![
M"B`@("!W:61T:#H@-38["B`@("!H96EG:'0Z(#$R,#L*("`@(&)A8VMG<F]U
M;F0M:6UA9V4Z('5R;"AG<F%P:&EC<R]L969T+FIP9RD["GT*=&0N9&ES<&QA
M>2!["B`@("!W:61T:#H@,34P.PH@("`@:&5I9VAT.B`Q,C`["B`@("!B86-K
M9W)O=6YD+6EM86=E.B!U<FPH9W)A<&AI8W,O9&ES<&QA>2YJ<&<I.PI]"G1D
M+G)I9VAT('L*("`@('=I9'1H.B`U-SL*("`@(&AE:6=H=#H@,3(P.PH@("`@
M8F%C:V=R;W5N9"UI;6%G93H@=7)L*&=R87!H:6-S+W)I9VAT+FIP9RD["GT*
M=&0N8F]T=&]M('L*("`@('=I9'1H.B`R-C,["B`@("!H96EG:'0Z(#,Q,SL*
M("`@(&)A8VMG<F]U;F0M:6UA9V4Z('5R;"AG<F%P:&EC<R]B;W1T;VTN:G!G
M*3L*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]P=7)P;&4`````
M````````````````````````````````````````````````````````````
M```````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,#`P,"`Q,#4Q-30S,S<U-"`P,C`R-3<`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+W!U<G!L92]I;F9O+G!H<```````````````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`P,3<V(#$P-3$U-#,S-S4T(#`R,C`P-@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O<'5R<&QE+VEN9F\N<&AP+'8@
M,2XQ(#(P,#0O,3$O,C4@,#(Z,#0Z-30@8VAU8VL@17AP("0*("HO"@HD=&AE
M;65?;F%M92`](%\H(E!U<G!L92!(;W)D92(I.PH`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]P=7)P
M;&4O<V-R965N+F-S<P``````````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P-C`P,B`Q,#4Q-30S,S<U-"`P,C(S,C4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+RHJ"B`J("1(;W)D93H@:&]R
M9&4O=&AE;65S+W!U<G!L92]S8W)E96XN8W-S+'8@,2XQ+C0N-B`R,#`V+S`T
M+S(X(#(P.C0W.C(X(&IA;B!%>'`@)`H@*B\*"F)O9'D@>PH@("`@8F%C:V=R
M;W5N9#H@(S(R-#L*?0H*+FAE861E<F)O>"!["B`@("!B;W)D97(M8V]L;W(Z
M(",V-CD["B`@("!B86-K9W)O=6YD.B`C9F9F.PI]"BYH96%D97(@>PH@("`@
M8V]L;W(Z("-C8V4["B`@("!B86-K9W)O=6YD.B`C-#0V.PH@("`@8VQE87(Z
M(&)O=&@["GT*+FAE861E<B!A.FAO=F5R+"!A+FAE861E<CIH;W9E<B!["B`@
M("!C;VQO<CH@(V9F9CL*?0HN:&5A9&5R(&$@>PH@("`@8V]L;W(Z("-C8V4[
M"GT*82YH96%D97(Z:&]V97(@>PH@("`@8V]L;W(Z("-F9F8["GT*82!["B`@
M("!C;VQO<CH@(S,S.3L*?0IA.FAO=F5R('L*("`@(&-O;&]R.B!B;'5E.PI]
M"BYS96QE8W1E9"!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C8F)C8F9F.PI]
M"BYS96QE8W1E9"UO=F5R('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-C968[
M"GT*"BYW:61G970@>PH@("`@8V]L;W(Z(",R,C0["GT*82YW:61G970Z:&]V
M97(@>PH@("`@8V]L;W(Z(&)L=64["B`@("!B86-K9W)O=6YD.B`C8F)C8F9F
M.PI]"@HN;F]T:6-E('L*("`@(&9O;G0M=V5I9VAT.B!B;VQD.PH@("`@8F%C
M:V=R;W5N9"UC;VQO<CH@(V9F8SL*("`@(&)O<F1E<CH@,7!X('-O;&ED("-A
M86$["B`@("!P861D:6YG.B`Q<'@["B`@("!P861D:6YG+6QE9G0Z(#5P>#L*
M("`@("UM;WHM8F]R9&5R+7)A9&EU<SH@.'!X.PI]"@HN;&EG:'0@>PH@("`@
M8V]L;W(Z("-F9F8["B`@("!F;VYT+69A;6EL>3H@1V5N979A+$%R:6%L+$AE
M;'9E=&EC82QS86YS+7-E<FEF.PH@("`@9F]N="US:7IE.B`Q,G!X.PI]"BYS
M;6%L;&AE861E<B!["B`@("!C;VQO<CH@(V-C93L*("`@(&)A8VMG<F]U;F0M
M8V]L;W(Z(",T-#8["GT*+G-M86QL:&5A9&5R(&$Z:&]V97(L(&$N<VUA;&QH
M96%D97(Z:&]V97(@>PH@("`@8V]L;W(Z("-F9F8["GT*+G-M86QL:&5A9&5R
M(&$@>PH@("`@8V]L;W(Z("-C8V4["GT*+F-O;G1R;VP@>PH@("`@8V]L;W(Z
M(",P,#`["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C8V-C.PH@("`@8F]R9&5R
M+6)O='1O;3H@,7!X('-O;&ED(",Y.3D["GT*+FET96T@>PH@("`@8V]L;W(Z
M(",P,#`["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C965E.PI]"BYA8V-E<W-+
M97D@>PH@("`@=&5X="UD96-O<F%T:6]N.B!U;F1E<FQI;F4["GT*+G1E>'0@
M>PH@("`@8V]L;W(Z(",P,#`["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C9F9F
M.PI]"@HO*B!&;W)M('-T>6QE<RX@*B\*+F)U='1O;B!["B`@("!C;VQO<CH@
M(V9F9CL*("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",V-CD["B`@("!B;W)D97(M
M8F]T=&]M.B`Q<'@@<V]L:60@(S(R-#L*("`@(&)O<F1E<BUR:6=H=#H@,7!X
M('-O;&ED(",R,C0["B`@("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(SDY8SL*
M("`@(&)O<F1E<BUL969T.B`Q<'@@<V]L:60@(SDY8SL*("`@(&9O;G0M<VEZ
M93H@,3%P>#L*("`@(&9O;G0M9F%M:6QY.B!697)D86YA+$AE;'9E=&EC82QS
M86YS+7-E<FEF.PI]"F$Z:&]V97(N8G5T=&]N('L*("`@(&-O;&]R.B`C9F9F
M.PI]"@HO*B!-96YU('-T>6QE<RX@*B\*(VUE;G4@>PH@("`@8V]L;W(Z("-F
M9F8["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C-#0V.PI]"B-M96YU('5L('L*
M("`@('!A9&1I;F<Z(#5P>#L*?0HC;65N=2!L:2!["B`@("!L:7-T+7-T>6QE
M+71Y<&4Z(&YO;F4["B`@("!T97AT+6%L:6=N.B!C96YT97(["B`@("!M87)G
M:6XZ(#)P>#L*("`@(&9L;V%T.B!L969T.PI]"B-M96YU(&$@>PH@("`@8V]L
M;W(Z("-E968["GT*(VUE;G4@83IH;W9E<B!["B`@("!C;VQO<CH@>65L;&]W
M.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",V-F$["B`@("!B;W)D
M97(M<FEG:'0Z(#%P>"!S;VQI9"`C-C9A.PH@("`@8F]R9&5R+71O<#H@,7!X
M('-O;&ED(",R,C0["B`@("!B;W)D97(M;&5F=#H@,7!X('-O;&ED(",R,C0[
M"B`@("!P861D:6YG.B`R<'@["GT*(VUE;G4@82YC=7)R96YT('L*("`@(&)A
M8VMG<F]U;F0M8V]L;W(Z(",V-C@["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@
M<V]L:60@(SDY8SL*("`@(&)O<F1E<BUR:6=H=#H@,7!X('-O;&ED(",Y.6,[
M"B`@("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(S(R-#L*("`@(&)O<F1E<BUL
M969T.B`Q<'@@<V]L:60@(S(R-#L*("`@('!A9&1I;F<Z(#)P>#L*?0HC;65N
M=2!H,2!["B`@("!F;VYT+69A;6EL>3H@5F5R9&%N82Q(96QV971I8V$L<V%N
M<RUS97)I9CL*("`@(&9O;G0M=V5I9VAT.B!B;VQD.PH@("`@9F]N="US:7IE
M.B`Q.'!X.PH@("`@;&EN92UH96EG:'0Z(#4P<'@["B`@("!V97)T:6-A;"UA
M;&EG;CH@8F]T=&]M.PI]"@HO*B!3:61E8F%R('-T>6QE<RX@*B\*(W-I9&5B
M87)086YE;"!["B`@("`M;6]Z+6)O<F1E<BUR861I=7,M8F]T=&]M<FEG:'0Z
M(#$U<'@["B`@("!P861D:6YG+71O<#H@-7!X.PH@("`@<&%D9&EN9RUB;W1T
M;VTZ(#$P<'@["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C965E.PI]"B-S:61E
M8F%R4&%N96P@<W!A;B!["B`@("!P861D:6YG.B`R<'@["GT*(W-I9&5B87)0
M86YE;"!S<&%N+"`C<VED96)A<E!A;F5L(&$@>PH@("`@8V]L;W(Z(",P,#`[
M"B`@("!W:&ET92US<&%C93H@<')E.PH@("`@9F]N="UF86UI;'DZ(%9E<F1A
M;F$L2&5L=F5T:6-A+'-A;G,M<V5R:68["B`@("!F;VYT+7-I>F4Z(#$Q<'@[
M"B`@("!T97AT+61E8V]R871I;VXZ(&YO;F4["GT*(W-I9&5B87)086YE;"!A
M.FAO=F5R('L*("`@("UM;WHM8F]R9&5R+7)A9&EU<SH@,W!X.PH@("`@8V]L
M;W(Z(",P,#`["GT*"B\J(%1A8B!S='EL97,N("HO"BYT86)S970@;&D@83IH
M;W9E<B!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C9F9F.PI]"BYT86)S970@
M;&DN86-T:79E5&%B(&$L("YT86)S970@;&DN86-T:79E5&%B(&$Z:&]V97(@
M>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(S0T-CL*("`@(&)O<F1E<BUB;W1T
M;VTM8V]L;W(Z(",T-#8["GT*"B\J(%!R969E<F5N8V5S(&]V97)V:65W+B`J
M+PHN<')E9G-/=F5R=FEE=R!H,B!["B`@("!C;VQO<CH@(V9F9CL*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O8G5R
M;G1O<F%N9V4`````````````````````````````````````````````````
M````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`P,#`@,3`U,34T,S,W-30@,#(Q,C<V`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]B=7)N=&]R86YG92]I;F9O+G!H<```````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#0Q,"`Q,#4Q-30S,S<U-"`P,C,P
M,30`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J(%1H96UE(&)Y.B!%<FEC($IO;B!2;W-T971T97(@/&5R
M:6,N<F]S=&5T=&5R0'!H>7-I8W,N=71E>&%S+F5D=3X*("H@4&QE87-E(&-O
M;G1A8W0@=&AE('1H96UE)W,@875T:&]R(&9O<B!A;GD@;6ES<VEN9R!S='EL
M92X*("H*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O8G5R;G1O<F%N9V4O:6YF
M;RYP:'`L=B`Q+C$@,C`P-"\Q,"\Q-R`Q.3HS,SHS-2!M9&IU:VEC($5X<"`D
M"B`J+PH*)'1H96UE7VYA;64@/2!?*")"=7)N="!/<F%N9V4B*3L*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O8G5R;G1O<F%N9V4O<V-R965N+F-S<P``````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#,T,3<@,3`U,34T,S,W-30@,#(S,S4S`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"\J*@H@*B!4:&5M
M92!B>3H@17)I8R!*;VX@4F]S=&5T=&5R(#QE<FEC+G)O<W1E='1E<D!P:'ES
M:6-S+G5T97AA<RYE9'4^"B`J(%!L96%S92!C;VYT86-T('1H92!T:&5M92=S
M(&%U=&AO<B!F;W(@86YY(&UI<W-I;F<@<W1Y;&4N"B`J"B`J("1(;W)D93H@
M:&]R9&4O=&AE;65S+V)U<FYT;W)A;F=E+W-C<F5E;BYC<W,L=B`Q+C8N-BXS
M(#(P,#4O,3`O,3@@,3$Z,S0Z,3(@:F%N($5X<"`D"B`J+PH*8F]D>2!["B`@
M("!B86-K9W)O=6YD.B`C9C!B,#8P.PI]"F$@>PH@("`@8V]L;W(Z("-C-C`[
M"GT*83IH;W9E<B!["B`@("!C;VQO<CH@(V,V,#L*?0HN:&5A9&5R('L*("`@
M(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@(V,V,#L*?0HN:&5A9&5R
M(&$@>PH@("`@8V]L;W(Z("-F9F8["GT*"BYS;6%L;&AE861E<B!["B`@("!C
M;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z("-C-C`["GT*+F-O;G1R;VP@
M>PH@("`@8F%C:V=R;W5N9#H@(V8Y8V4X83L*("`@(&)O<F1E<BUB;W1T;VTZ
M(#%P>"!S;VQI9"`C8S8P.PI]"BYB=71T;VX@>PH@("`@8V]L;W(Z("-F9F8[
M"B`@("!B86-K9W)O=6YD.B`C8S8P.PH@("`@8F]R9&5R+6)O='1O;2UC;VQO
M<CH@(S,P,#L*("`@(&)O<F1E<BUR:6=H="UC;VQO<CH@(S,P,#L*("`@(&)O
M<F1E<BUT;W`M8V]L;W(Z("-F,&(P-C`["B`@("!B;W)D97(M;&5F="UC;VQO
M<CH@(V8P8C`V,#L*?0HN<V5L96-T960@>PH@("`@8F%C:V=R;W5N9#H@(V1F
M.68S9CL*?0IA+G-M86QL:&5A9&5R.FAO=F5R('L*("`@(&-O;&]R.B`C9F9F
M.PI]"@HO*B!-96YU('-T>6QE<RX@*B\*(VUE;G4@>PH@("`@8V]L;W(Z("-F
M9F8["B`@("!B86-K9W)O=6YD.B`C8S8P.PI]"B-M96YU(&$Z:&]V97(@>PH@
M("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED("-F,&(P-C`["B`@("!B;W)D
M97(M<FEG:'0Z(#%P>"!S;VQI9"`C9C!B,#8P.PH@("`@8F]R9&5R+71O<#H@
M,7!X('-O;&ED(",S,#`["B`@("!B;W)D97(M;&5F=#H@,7!X('-O;&ED(",S
M,#`["B`@("!P861D:6YG.B`R<'@["GT*(VUE;G4@82!["B`@("!C;VQO<CH@
M(V9F9CL*?0HC;65N=2!A+F-U<G)E;G0@>PH@("`@8V]L;W(Z("-F9F8["B`@
M("!B86-K9W)O=6YD.B`C9&8Y9C-F.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X
M('-O;&ED("-F,&(P-C`["B`@("!B;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C
M9C!B,#8P.PH@("`@8F]R9&5R+71O<#H@,7!X('-O;&ED(",S,#`["B`@("!B
M;W)D97(M;&5F=#H@,7!X('-O;&ED(",S,#`["B`@("!P861D:6YG.B`R<'@[
M"GT*"B\J(%-I9&5B87(@<W1Y;&5S+B`J+PIB;V1Y+G-I9&5B87(@>PH@("`@
M8F%C:V=R;W5N9#H@(V8P8C`V,#L*?0HC<VED96)A<E!A;F5L('L*("`@(&)O
M<F1E<BUR:6=H=#H@,7!X('-O;&ED("-F,&(P-C`["B`@("!B;W)D97(M8F]T
M=&]M.B`Q<'@@<V]L:60@(V8P8C`V,#L*("`@(&)A8VMG<F]U;F0Z("-F,&(P
M-C`["GT*(W-I9&5B87)086YE;"!A('L*("`@(&)O<F1E<CH@,7!X('-O;&ED
M("-F,&(P-C`["B`@("!P861D:6YG+6QE9G0Z(#%P>#L*("`@('!A9&1I;F<M
M8F]T=&]M.B`R<'@["GT*(W-I9&5B87)086YE;"!A.FAO=F5R('L*("`@(&-O
M;&]R.B`C.3`P.PH@("`@8F%C:V=R;W5N9#H@>65L;&]W.PH@("`@8F]R9&5R
M.B`Q<'@@<V]L:60@(S`P,#L*("`@('1E>'0M9&5C;W)A=&EO;CH@;F]N93L*
M?0H*+RH@5&%B('-T>6QE<RX@*B\*+G1A8G-E="!L:2YA8W1I=F5486(@82P@
M+G1A8G-E="!L:2YA8W1I=F5486(@83IH;W9E<B!["B`@("!B86-K9W)O=6YD
M.B`C8S8P.PH@("`@8F]R9&5R+6)O='1O;2UC;VQO<CH@(V,V,#L*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+W)T
M;"YC<W,`````````````````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`Q,S`P(#$P-3$U-#,S-S4T(#`R,#,S-``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````O*BH*("H@)$AO<F1E.B!H
M;W)D92]T:&5M97,O<G1L+F-S<RQV(#$N,BXR+C$@,C`P-2\Q,"\Q."`Q,3HS
M-#HQ,"!J86X@17AP("0*("HO"@IB;V1Y('L*("`@(&1I<F5C=&EO;CH@<G1L
M.PH@("`@9F]N="UF86UI;'DZ(%1A:&]M82Q+;V]D86LL2&]M82Q.87IL:2Q6
M97)D86YA+$=E;F5V82Q!<FEA;"Q(96QV971I8V$L<V%N<RUS97)I9CL*?0H*
M+FQE9G1!;&EG;B!["B`@("`@("`@=&5X="UA;&EG;CH@<FEG:'0["B`@("`@
M("`@9F]N="UF86UI;'DZ(%1A:&]M82Q+;V]D86LL2&]M82Q.87IL:2Q697)D
M86YA+$=E;F5V82Q!<FEA;"Q(96QV971I8V$L<V%N<RUS97)I9CL*?0HN<FEG
M:'1!;&EG;B!["B`@("`@("`@=&5X="UA;&EG;CH@;&5F=#L*("`@("`@("!F
M;VYT+69A;6EL>3H@5&%H;VUA+$MO;V1A:RQ(;VUA+$YA>FQI+%9E<F1A;F$L
M1V5N979A+$%R:6%L+$AE;'9E=&EC82QS86YS+7-E<FEF.PI]"@HN;&5F=$9L
M;V%T('L*("`@("`@("!F;&]A=#H@<FEG:'0["GT*+G)I9VAT1FQO870@>PH@
M("`@("`@(&9L;V%T.B!L969T.PI]"@HN:&5A9&5R('5L('L*("`@(&9L;V%T
M.B!L969T.PH@("`@=&5X="UA;&EG;CH@;&5F=#L*?0H*+RH@5&%B('-T>6QE
M<RX@*B\*+G1A8G-E="!["B`@("!F;&]A=#H@<FEG:'0["GT*+G1A8G-E="!L
M:2!["B`@("!F;&]A=#H@<FEG:'0["GT*+G1A8G-E="!I;6<@>PH@("`@9FQO
M870Z(')I9VAT.PI]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+VEE-6UA8RYC<W,`````````````````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P-3,T(#$P-3$U-#,S-S4T(#`R,#<P-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````O*BH*("H@)$AO
M<F1E.B!H;W)D92]T:&5M97,O:64U;6%C+F-S<RQV(#$N,BXT+C,@,C`P-2\Q
M,"\Q."`Q,3HS-#HQ,"!J86X@17AP("0*("H*("H@0U-3(&-O<G)E8W1I;VYS
M(&9O<B!)134O36%C+@H@*B\*"B-M96YU(&QI('L*("`@('=I9'1H.B`T,'!X
M.PI]"BYT86)S970@>PH@("`@=VAI=&4M<W!A8V4Z(&YO=W)A<#L*?0HN=&%B
M<V5T(&QI(&$@>PH@("`@9FQO870Z(&QE9G0["GT*(W-I9&5B87)086YE;"![
M"B`@("!P861D:6YG+6)O='1O;3H@,S!P>#L*?0HN:&5A9&5R('L*("`@(&-L
M96%R.B!N;VYE.PI]"BYH96%D97(@=6P@>PH@("`@=VED=&@Z(#$E.PH@("`@
M=VAI=&4M<W!A8V4Z(&YO=W)A<#L*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]M;WHQ-"YC
M<W,`````````````````````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#(V,"`Q,#4Q-30S,S<U-"`P,C`U,3$`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+RHJ"B`J("1(;W)D93H@:&]R9&4O
M=&AE;65S+VUO>C$T+F-S<RQV(#$N,2XR+C(@,C`P-2\Q,"\Q."`Q,3HS-#HQ
M,"!J86X@17AP("0*("H*("H@0U-3(&-O<G)E8W1I;VYS(&9O<B!-;WII;&QA
M(#P](#$N-"X*("HO"@HC;65N=2!["B`@("!O=F5R9FQO=SH@=FES:6)L93L*
M("`@(&AE:6=H=#H@-3!P>#L*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O;W!E<F$N8W-S````````````
M````````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`S,S8@,3`U
M,34T,S,W-30@,#(P-C4Q`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]O<&5R
M82YC<W,L=B`Q+C$N,BXT(#(P,#4O,3`O,3@@,3$Z,S0Z,3`@:F%N($5X<"`D
M"B`J"B`J($-34R!C;W)R96-T:6]N<R!F;W(@3W!E<F$N"B`J+PH*+G1R9652
M;W<@>PH@("`@;W9E<F9L;W<Z('9I<VEB;&4["B`@("!H96EG:'0Z(#(P<'@[
M"GT*"B-M96YU('L*("`@(&]V97)F;&]W.B!V:7-I8FQE.PH@("`@:&5I9VAT
M.B`U,'!X.PI]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+W-A9F%R:2YC<W,`````````````````````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P-#8U(#$P-3$U-#,S-S4T(#`R
M,3`Q,P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```O*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O<V%F87)I+F-S<RQV(#$N
M,2XR+C8@,C`P-2\Q,"\Q."`Q,3HS-#HQ,"!J86X@17AP("0*("H*("H@0U-3
M(&-O<G)E8W1I;VYS(&9O<B!3869A<FDN"B`J+PH*:6UG('L*("`@('9E<G1I
M8V%L+6%L:6=N.B!B87-E;&EN93L*?0H*+G1R9652;W<@>PH@("`@;W9E<F9L
M;W<Z('9I<VEB;&4["B`@("!H96EG:'0Z(#(P<'@["GT*"BYT<F5E4F]W(&EM
M9R!["B`@("!V97)T:6-A;"UA;&EG;CH@;6ED9&QE.PI]"@HC;65N=2!["B`@
M("!O=F5R9FQO=SH@=FES:6)L93L*("`@(&AE:6=H=#H@-3!P>#L*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]S8W)E96XN8W-S````````````````````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`R-S<T,2`Q,#4Q-30S,S<U-"`P,C$P,S,`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+RHJ"B`J("1(
M;W)D93H@:&]R9&4O=&AE;65S+W-C<F5E;BYC<W,L=B`Q+C<N-"XU-R`R,#`V
M+S`V+S$Q(#(Q.C,T.C(W(&-H=6-K($5X<"`D"B`J+PH*+RH@1VQO8F%L(&1E
M9F%U;'0@<W1Y;&5S+B`J+PHJ('L*("`@("\J(%IE<F\@;W5T(&%L;"!P861D
M:6YG(&%N9"!M87)G:6YS('1O('-T87)T('=I=&@@9F]R(&)E='1E<@H@("`@
M("H@8W)O<W,M8G)O=W-E<B!C;VYT<F]L+B`J+PH@("`@<&%D9&EN9SH@,#L*
M("`@(&UA<F=I;CH@,#L*?0H*8F]D>2!["B`@("!F;VYT+69A;6EL>3H@1V5N
M979A+$%R:6%L+$AE;'9E=&EC82QS86YS+7-E<FEF.PH@("`@9F]N="US:7IE
M.B`Q,G!X.PH@("`@8F%C:V=R;W5N9#H@(V9F9CL*("`@(&-O;&]R.B`C,#`P
M.PI]"@IB;V1Y+G-C<F]L;&)A<BUQ=6ER:R!["B`@("!M87)G:6XM<FEG:'0Z
M(#$U<'@["GT*"G`@>PH@("`@;6%R9VEN+6)O='1O;3H@,3!P>#L*?0H*:6UG
M+"`N:6UG+"`N:6UG.F%C=&EV92P@+FEM9SIH;W9E<BP@+FEM9SIV:7-I=&5D
M('L*("`@(&)O<F1E<CH@;F]N93L*("`@('9E<G1I8V%L+6%L:6=N.B!M:61D
M;&4["B`@("!B86-K9W)O=6YD.B!T<F%N<W!A<F5N=#L*?0H*:6YS('L*("`@
M(&)A8VMG<F]U;F0Z("-C9F,["GT*9&5L('L*("`@(&)A8VMG<F]U;F0Z("-F
M8V,["GT*"F)R+G-P86-E<B!["B`@("!F;VYT+7-I>F4Z(#AP>#L*?0H*+FQE
M9G1!;&EG;B!["B`@("!T97AT+6%L:6=N.B!L969T.PI]"BYR:6=H=$%L:6=N
M('L*("`@('1E>'0M86QI9VXZ(')I9VAT.PI]"BYL969T1FQO870@>PH@("`@
M9FQO870Z(&QE9G0["GT*+G)I9VAT1FQO870@>PH@("`@9FQO870Z(')I9VAT
M.PI]"@HN8F]X('L*("`@('!A9&1I;F<Z(#-P>#L*("`@(&)O<F1E<CH@,7!X
M(&1A<VAE9"`C.3DY.PH@("`@8F%C:V=R;W5N9#H@(V9F9CL*?0HN<V]L:61B
M;W@@>PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(S`P,#L*?0HN9W)E>6)O>"![
M"B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C,#`P.PH@("`@8F%C:V=R;W5N9#H@
M(V4Y93EE.3L*?0HN:&5A9&5R8F]X('L*("`@(&)O<F1E<BUL969T.B`Q<'@@
M<V]L:60@(S`P,#L*("`@(&)O<F1E<BUR:6=H=#H@,7!X('-O;&ED(",P,#`[
M"B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(S`P,#L*("`@(&)A8VMG
M<F]U;F0Z("-F9F8["GT*+G)O=6YD961";W@@>PH@("`@+6UO>BUB;W)D97(M
M<F%D:75S.B`Q-7!X.PI]"BYR;W5N9&5D5&]P('L*("`@("UM;WHM8F]R9&5R
M+7)A9&EU<RUT;W!R:6=H=#H@,35P>#L*("`@("UM;WHM8F]R9&5R+7)A9&EU
M<RUT;W!L969T.B`Q-7!X.PI]"BYR;W5N9&5D0F]T=&]M('L*("`@("UM;WHM
M8F]R9&5R+7)A9&EU<RUB;W1T;VUR:6=H=#H@,35P>#L*("`@("UM;WHM8F]R
M9&5R+7)A9&EU<RUB;W1T;VUL969T.B`Q-7!X.PI]"BYH96%D97(@>PH@("`@
M9F]N="UF86UI;'DZ(%9E<F1A;F$L2&5L=F5T:6-A+'-A;G,M<V5R:68["B`@
M("!F;VYT+7=E:6=H=#H@8F]L9#L*("`@(&9O;G0M<VEZ93H@,35P>#L*("`@
M('!A9&1I;F<Z(#-P>#L*?0HN:&5A9&5R(&$Z:&]V97(L(&$N:&5A9&5R.FAO
M=F5R('L*("`@(&-O;&]R.B`C,S,S.PI]"BYH96%D97(@:6UG('L*("`@('9E
M<G1I8V%L+6%L:6=N.B!B;W1T;VT["GT*+FAE861E<B!U;"!["B`@("!F;&]A
M=#H@<FEG:'0["B`@("!T97AT+6%L:6=N.B!R:6=H=#L*("`@(&9O;G0M<VEZ
M93H@,3)P>#L*?0HN:&5A9&5R(&QI('L*("`@(&QI<W0M<W1Y;&4Z(&YO;F4[
M"B`@("!D:7-P;&%Y.B!I;FQI;F4["GT*+FYO=W)A<"!["B`@("!W:&ET92US
M<&%C93H@;F]W<F%P.PI]"BYC;&5A<B!["B`@("!C;&5A<CH@8F]T:#L*("`@
M(&QI;F4M:&5I9VAT.B`P.PH@("`@:&5I9VAT.B`P.PI]"@IA('L*("`@(&-O
M;&]R.B!B;'5E.PH@("`@=&5X="UD96-O<F%T:6]N.B!N;VYE.PI]"F$Z:&]V
M97(@>PH@("`@=&5X="UD96-O<F%T:6]N.B!U;F1E<FQI;F4["GT*+G-E;&5C
M=&5D('L*("`@(&)A8VMG<F]U;F0Z("-B8F-B9F8["GT*+G-E;&5C=&5D+6]V
M97(@>PH@("`@8F%C:V=R;W5N9#H@(V-E9CL*?0H*+RH@5&%B;&4@<W1Y;&5S
M+B`J+PIT86)L92!["B`@("!B;W)D97(Z(&YO;F4["GT*=&0L('1H('L*("`@
M('!A9&1I;F<Z(#%P>#L*?0IT:"!["B`@("!C;VQO<CH@(S,S,SL*("`@(&9O
M;G0M9F%M:6QY.B!697)D86YA+$AE;'9E=&EC82QS86YS+7-E<FEF.PH@("`@
M9F]N="US:7IE.B`Q,7!X.PI]"G1D('L*("`@(&9O;G0M<VEZ93H@,3)P>#L*
M("`@(&9O;G0M9F%M:6QY.B!'96YE=F$L07)I86PL2&5L=F5T:6-A+'-A;G,M
M<V5R:68["GT*=6PN;&EN9612;W<@>PH@("`@;&ES="US='EL92UT>7!E.B!N
M;VYE.PI]"BYL:6YE9%)O=RP@='(N;&EN9612;W<@=&0L('1A8FQE+FQI;F5D
M4F]W('1D+"!U;"YL:6YE9%)O=R!L:2!["B`@("!C;VQO<CH@(S`P,#L*("`@
M(&)A8VMG<F]U;F0Z("-F9F8["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L
M:60@(V1D9#L*?0IT86)L92YL:6YE9%)O=RP@=6PN;&EN9612;W<@>PH@("`@
M8F]R9&5R+6)O='1O;3H@;F]N93L*?0HN;&EN9612;W=396QE8W1E9$-O;"P@
M=&0N;&EN9612;W=396QE8W1E9$-O;"P@=&%B;&4N;&EN9612;W<@=&0N;&EN
M9612;W=396QE8W1E9$-O;"!["B`@("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG
M<F]U;F0Z("-F,V8S9C,["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@
M(V1D9#L*?0HN<V5L96-T9612;W<L('1R+G-E;&5C=&5D4F]W('1D('L*("`@
M(&)A8VMG<F]U;F0Z("-F9F,["GT*+G-E;&5C=&5D4F]W.FAO=F5R+"!T<BYS
M96QE8W1E9%)O=R!T9#IH;W9E<BP@+G-E;&5C=&5D4F]W+6]V97(L('1R+G-E
M;&5C=&5D4F]W+6]V97(@=&0@>PH@("`@8F%C:V=R;W5N9#H@(V9F9#L*?0IT
M86)L92YN;W!A9&1I;F<@=&0L('1A8FQE+FYO<&%D9&EN9R!T:"!["B`@("!P
M861D:6YG.B`P.PI]"BYS;W)T=7`@>PH@("`@8F%C:V=R;W5N9#H@(V)B8V)F
M9B!U<FPH(F=R87!H:6-S+WIA+G!N9R(I(&-E;G1E<B!L969T(&YO+7)E<&5A
M=#L*("`@('!A9&1I;F<M;&5F=#H@,3!P>#L*?0HN<V]R=&1O=VX@>PH@("`@
M8F%C:V=R;W5N9#H@(V)B8V)F9B!U<FPH(F=R87!H:6-S+V%Z+G!N9R(I(&-E
M;G1E<B!L969T(&YO+7)E<&5A=#L*("`@('!A9&1I;F<M;&5F=#H@,3!P>#L*
M?0HO*B!!;'1E<FYA=&EN9R!S='EL97,N(&ET96TP+"!I=&5M,2!A<F4@9&5P
M<F5C871E9"X@*B\*+G-T<FEP960L("YR;W=%=F5N+"`N:71E;3`@>PH@("`@
M8F%C:V=R;W5N9#H@(V5E93L*?0HN<F]W3V1D+"`N:71E;3$@>PH@("`@8F%C
M:V=R;W5N9#H@(V1D9#L*?0H*+G=I9&=E="!["B`@("!F;VYT+69A;6EL>3H@
M5F5R9&%N82Q(96QV971I8V$L<V%N<RUS97)I9CL*("`@(&9O;G0M<VEZ93H@
M,3%P>#L*?0H*+FUI;653=&%T=7--97-S86=E('L*("`@('!A9&1I;F<Z(#%P
M>#L*("`@(&UA<F=I;BUB;W1T;VTZ(#1P>#L*("`@(&)O<F1E<CH@,7!X(&1A
M<VAE9"`C,#!C.PH@("`@8F%C:V=R;W5N9#H@(V5E9CL*("`@(&-O;&]R.B`C
M,#`V.PI]"BYM:6UE4W1A='5S5V%R;FEN9R!["B`@("!P861D:6YG.B`Q<'@[
M"B`@("!M87)G:6XM8F]T=&]M.B`T<'@["B`@("!B;W)D97(Z(#%P>"!D87-H
M960@(V8P,#L*("`@(&)A8VMG<F]U;F0Z("-F9F0P868["B`@("!C;VQO<CH@
M(V8P,#L*?0H*+FQI9VAT('L*("`@(&-O;&]R.B`C9F9F.PH@("`@9F]N="UF
M86UI;'DZ($=E;F5V82Q!<FEA;"Q(96QV971I8V$L<V%N<RUS97)I9CL*("`@
M(&9O;G0M<VEZ93H@,3)P>#L*?0HN<VUA;&QH96%D97(@>PH@("`@9F]N="UF
M86UI;'DZ($=E;F5V82Q!<FEA;"Q(96QV971I8V$L<V%N<RUS97)I9CL*("`@
M(&9O;G0M<VEZ93H@,3)P>#L*("`@(&9O;G0M=V5I9VAT.B!B;VQD.PI]"G-M
M86QL+"`N<VUA;&P@>PH@("`@9F]N="US:7IE.B`Q,'!X.PI]"BYC;VYT<F]L
M('L*("`@(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N9#H@(V-C8SL*("`@
M(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C.3DY.PI]"BYI=&5M('L*("`@
M(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N9#H@(V5E93L*?0HN86-C97-S
M2V5Y('L*("`@('1E>'0M9&5C;W)A=&EO;CH@=6YD97)L:6YE.PI]"BYT97AT
M('L*("`@(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N9#H@(V9F9CL*?0H*
M+RH@1F]R;2!S='EL97,N("HO"BYF;W)M('1A8FQE('L*("`@('=I9'1H.B`Q
M,#`E.PH@("`@<&%D9&EN9SH@,G!X.PH@("`@8F]R9&5R+6-O;&QA<'-E.B!C
M;VQL87!S93L*?0HN:'1M;&%R96$@+G-T871U<T)A<B`N<W1A='5S0F%R5')E
M92!A('L*("`@(&9O;G0Z(&EN:&5R:70["GT*+FAT;6QA<F5A('1A8FQE('L*
M("`@('=I9'1H.B!A=71O.PI]"BYF;W)M+65R<F]R('L*("`@(&-O;&]R.B`C
M9C`P.PI]"FEN<'5T+"!S96QE8W0@>PH@("`@9F]N="UF86UI;'DZ($=E;F5V
M82Q!<FEA;"Q(96QV971I8V$L<V%N<RUS97)I9CL*("`@(&9O;G0M<VEZ93H@
M,3)P>#L*("`@(&9O;G0M=V5I9VAT.B!N;W)M86P["GT*:6YP=70@>PH@("`@
M<&%D9&EN9SH@,7!X.PI]"F]P=&EO;B!["B`@("!P861D:6YG.B`P<'@@-7!X
M(#!P>"`S<'@["GT*+F-H96-K8F]X('L*("`@(&)O<F1E<CH@,#L*("`@(&AE
M:6=H=#H@,31P>#L*("`@('=I9'1H.B`Q-'!X.PH@("`@8F%C:V=R;W5N9#H@
M=')A;G-P87)E;G0["GT*+F)U='1O;B!["B`@("!F;VYT+7-I>F4Z(#$Q<'@[
M"B`@("!F;VYT+69A;6EL>3H@5F5R9&%N82Q(96QV971I8V$L<V%N<RUS97)I
M9CL*?0IA+F)U='1O;B!["B`@("!P861D:6YG.B`R<'@["B`@("!F;VYT+7=E
M:6=H=#H@;F]R;6%L.PH@("`@=&5X="UD96-O<F%T:6]N.B!N;VYE.PI]"@HN
M9FEX960@>PH@("`@9F]N="US:7IE.B`Q,W!X.PH@("`@9F]N="UF86UI;'DZ
M(&UO;F]S<&%C92QF:7AE9#L*?0H*+RH@4W1Y;&5S(&9O<B!E;6%I;"UL:6ME
M(&UE<W-A9V5S+B`J+PHN<VEG;F%T=7)E('L*("`@(&-O;&]R.B`C8V-C.PI]
M"BYS:6=N871U<F4M9FEX960@>PH@("`@8V]L;W(Z("-C8V,["B`@("!F;VYT
M+7-I>F4Z(#$S<'@["B`@("!F;VYT+69A;6EL>3H@;6]N;W-P86-E+&9I>&5D
M.PI]"BYC:71A=&EO;B!["B`@("!M87)G:6XZ(#%E;2`P.PH@("`@<&%D9&EN
M9RUL969T.B`Q96T["B`@("!B;W)D97(M;&5F="UW:61T:#H@,7!X.PH@("`@
M8F]R9&5R+6QE9G0M<W1Y;&4Z('-O;&ED.PI]"BYQ=6]T960Q('L*("`@(&-O
M;&]R.B`C-C`V.PH@("`@8F]R9&5R+6QE9G0M8V]L;W(Z(",V,#8["GT*+G%U
M;W1E9#(@>PH@("`@8V]L;W(Z(",P-S<["B`@("!B;W)D97(M;&5F="UC;VQO
M<CH@(S`W-SL*?0HN<75O=&5D,R!["B`@("!C;VQO<CH@(SDP,#L*("`@(&)O
M<F1E<BUL969T+6-O;&]R.B`C.3`P.PI]"BYQ=6]T960T('L*("`@(&-O;&]R
M.B`C,#`Y.PH@("`@8F]R9&5R+6QE9G0M8V]L;W(Z(",P,#D["GT*+G%U;W1E
M9#4@>PH@("`@8V]L;W(Z("-B-C`["B`@("!B;W)D97(M;&5F="UC;VQO<CH@
M(V(V,#L*?0H*+RH@5F%R:6]U<R!P;W!U<"!A;F0@<W1A='5S(&QA>65R<RX@
M*B\*+FYO=&EC92!["B`@("!F;VYT+7=E:6=H=#H@8F]L9#L*("`@(&-O;&]R
M.B`C,#`P.PH@("`@8F%C:V=R;W5N9#H@(V9F8SL*("`@(&)O<F1E<CH@,7!X
M('-O;&ED("-A86$["B`@("!P861D:6YG.B`Q<'@["B`@("!P861D:6YG+6QE
M9G0Z(#5P>#L*("`@(&UA<F=I;BUB;W1T;VTZ(#%P>#L*("`@("UM;WHM8F]R
M9&5R+7)A9&EU<SH@.'!X.PI]"BYT;V]L=&EP+"!D:78N;FEC971I=&QE('L*
M("`@(&9O;G0Z(#$Q<'@O,3)P>"!697)D86YA+$%R:6%L+'-E<FEF.PH@("`@
M8V]L;W(Z(",P,#`["B`@("!B86-K9W)O=6YD.B`C9F9C.PH@("`@8F]R9&5R
M.B`Q<'@@<V]L:60@(S`P,#L*("`@('!A9&1I;F<Z(#5P>#L*("`@("UM;WHM
M8F]R9&5R+7)A9&EU<SH@,W!X.PI]"F1I=BYN:6-E=&ET;&4@>PH@("`@<&]S
M:71I;VXZ(&%B<V]L=71E.PH@("`@;W9E<F9L;W<Z(&AI9&1E;CL*("`@(&]P
M86-I='DZ("XY,#L*?0ID:78N;FEC971I=&QE('!R92!["B`@("!F;VYT+69A
M;6EL>3H@(DQU8VED82!#;VYS;VQE(BQM;VYO<W!A8V4L9FEX960["GT*+FEN
M4')O9W)E<W,@>PH@("`@9F]N=#H@,3!P>"!'96YE=F$L07)I86PL2&5L=F5T
M:6-A+'-A;G,M<V5R:68["B`@("!P861D:6YG.B`R<'@["B`@("!C;VQO<CH@
M(V9F9CL*("`@(&)A8VMG<F]U;F0Z("-F,#`["GT*"B\J(%1R964@<W1Y;&5S
M+B`J+PHN=')E95)O=R!["B`@("!O=F5R9FQO=SH@:&ED9&5N.PH@("`@;6EN
M+6AE:6=H=#H@,C!P>#L*("`@(&-L96%R.B!B;W1H.PI]"@HO*B!-96YU('-T
M>6QE<RX@*B\*(VUE;G4@>PH@("`@;W9E<F9L;W<Z(&AI9&1E;CL*("`@(&UI
M;BUH96EG:'0Z(#4P<'@["B`@("!F;VYT+69A;6EL>3H@5F5R9&%N82Q(96QV
M971I8V$L<V%N<RUS97)I9CL*("`@(&UA<F=I;BUB;W1T;VTZ(#AP>#L*?0HC
M;65N=2!U;"!["B`@("!P861D:6YG.B`U<'@["GT*(VUE;G4@;&D@>PH@("`@
M;&ES="US='EL92UT>7!E.B!N;VYE.PH@("`@=&5X="UA;&EG;CH@8V5N=&5R
M.PH@("`@;6%R9VEN.B`R<'@["B`@("!F;&]A=#H@;&5F=#L*?0HC;65N=2!A
M('L*("`@(&1I<W!L87DZ(&)L;V-K.PH@("`@=VAI=&4M<W!A8V4Z('!R93L*
M("`@(&9O;G0M9F%M:6QY.B!697)D86YA+$AE;'9E=&EC82QS86YS+7-E<FEF
M.PH@("`@9F]N="US:7IE.B`Q,7!X.PH@("`@=&5X="UD96-O<F%T:6]N.B!N
M;VYE.PH@("`@<&%D9&EN9SH@,W!X.PH@("`@+6UO>BUB;W)D97(M<F%D:75S
M.B`S<'@["GT*(VUE;G4@:#$@>PH@("`@9F]N="UF86UI;'DZ(%9E<F1A;F$L
M2&5L=F5T:6-A+'-A;G,M<V5R:68["B`@("!F;VYT+7=E:6=H=#H@8F]L9#L*
M("`@(&9O;G0M<VEZ93H@,3AP>#L*("`@(&QI;F4M:&5I9VAT.B`T.'!X.PH@
M("`@=F5R=&EC86PM86QI9VXZ(&)O='1O;3L*?0HC;65N=2!I;G!U="P@(VUE
M;G4@<V5L96-T('L*("`@(&UA<F=I;BUT;W`Z(#$V<'@["GT*"B\J(%-I9&5B
M87(@<W1Y;&5S+B`J+PHN<VED96)A<B`C;65N=2!["B`@("!M87)G:6XZ(#`[
M"GT*(W-I9&5B87)086YE;"!["B`@("`M;6]Z+6)O<F1E<BUR861I=7,M8F]T
M=&]M<FEG:'0Z(#$U<'@["B`@("!P861D:6YG+71O<#H@-7!X.PH@("`@<&%D
M9&EN9RUB;W1T;VTZ(#$P<'@["B`@("!B86-K9W)O=6YD.B`C965E.PH@("`@
M=VAI=&4M<W!A8V4Z(&YO=W)A<#L*?0HC<VED96)A<E!A;F5L('-P86XL("-S
M:61E8F%R4&%N96P@82!["B`@("!C;VQO<CH@(S`P,#L*("`@('=H:71E+7-P
M86-E.B!P<F4["B`@("!F;VYT+69A;6EL>3H@5F5R9&%N82Q(96QV971I8V$L
M<V%N<RUS97)I9CL*("`@(&9O;G0M<VEZ93H@,3%P>#L*("`@('1E>'0M9&5C
M;W)A=&EO;CH@;F]N93L*?0HC<VED96)A<E!A;F5L('-P86XN=&]G9VQE('L*
M("`@(&-U<G-O<CH@<&]I;G1E<CL*?0HC<VED96)A<E!A;F5L(&$Z:&]V97(@
M>PH@("`@+6UO>BUB;W)D97(M<F%D:75S.B`S<'@["B`@("!C;VQO<CH@(S`P
M,#L*?0H*+RH@4&%G97(N("HO"BYP86=E<B!["B`@("!T97AT+6%L:6=N.B!C
M96YT97(["GT*"B\J(%1A8B!S='EL97,N("HO"BYT86)S970@>PH@("`@9FQO
M870Z(&QE9G0["B`@("!W:61T:#H@,3`P)3L*("`@(&9O;G0M=V5I9VAT.B!B
M;VQD.PH@("`@8F%C:V=R;W5N9#H@=7)L*")G<F%P:&EC<R]T86)?8F]T=&]M
M+F=I9B(I(')E<&5A="UX(&)O='1O;3L*?0HN=&%B<V5T('5L('L*("`@(&UA
M<F=I;BUT;W`Z(#1P>#L*("`@('!A9&1I;F<M;&5F=#H@,3!P>#L*("`@(&QI
M<W0M<W1Y;&4Z(&YO;F4["GT*+G1A8G-E="!L:2!["B`@("!F;&]A=#H@;&5F
M=#L*("`@(&UA<F=I;BUT;W`Z("TS<'@["B`@("!M87)G:6XM;&5F=#H@,G!X
M.PH@("`@=VAI=&4M<W!A8V4Z(&YO=W)A<#L*?0HN=&%B<V5T(&QI(&$@>PH@
M("`@8V]L;W(Z(",P,#`["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C93EE.64Y
M.PH@("`@<&%D9&EN9SH@,G!X(#`N-65M.PH@("`@9&ES<&QA>3H@8FQO8VL[
M"B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C,#`P.PH@("`@8F]R9&5R+6)O='1O
M;2UC;VQO<CH@(V4Y93EE.3L*("`@("UM;WHM8F]R9&5R+7)A9&EU<RUT;W!L
M969T.B`Q,'!X.PH@("`@+6UO>BUB;W)D97(M<F%D:75S+71O<')I9VAT.B`Q
M,'!X.PI]"BYT86)S970@;&D@83IH;W9E<B!["B`@("!T97AT+61E8V]R871I
M;VXZ(&YO;F4["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C9F9F.PI]"BYT86)S
M970@;&DN86-T:79E5&%B(&$@>PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O
M;&ED(",P,#`["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C,#`P.PH@("`@8V]L
M;W(Z("-F9F8["GT*+G1A8G-E="!L:2YA8W1I=F5486(@83IH;W9E<B!["GT*
M+G1A8G-E="!I;6<@>PH@("`@9&ES<&QA>3H@8FQO8VL["B`@("!F;&]A=#H@
M;&5F=#L*("`@('!A9&1I;F<M<FEG:'0Z(#)P>#L*?0H*+RH@4')E9F5R96YC
M97,@;W9E<G9I97<N("HO"BYP<F5F<T]V97)V:65W(&1I=B!["B`@("!F;&]A
M=#H@;&5F=#L*?0HN<')E9G-/=F5R=FEE=R!D:78@9&EV('L*("`@('!A9&1I
M;F<M;&5F=#H@,3!P>#L*("`@('=I9'1H.B`Y-24["GT*+G!R969S3W9E<G9I
M97<@:#(@>PH@("`@9F]N="US:7IE.B`Q.'!X.PH@("`@9F]N="UW96EG:'0Z
M(&)O;&0["GT*+G!R969S3W9E<G9I97<@9'0@82!["B`@("!D:7-P;&%Y.B!B
M;&]C:SL*("`@('!A9&1I;F<Z(#)P>#L*("`@(&9O;G0M=V5I9VAT.B!B;VQD
M.PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(S`P,#L*("`@(&)O<F1E<BUB;W1T
M;VTZ(#%P>"!S;VQI9"`C-#0V.PH@("`@8F%C:V=R;W5N9#H@(V4Y93EE.3L*
M?0HN<')E9G-/=F5R=FEE=R!D9"!["B`@("!P861D:6YG.B`R<'@["B`@("!M
M87)G:6XM8F]T=&]M.B`Q,'!X.PH@("`@8V]L;W(Z(",P,#`["B`@("!B86-K
M9W)O=6YD.B`C9F9F.PH@("`@8F]R9&5R+6QE9G0Z(#%P>"!S;VQI9"`C,#`P
M.PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(S`P,#L*("`@(&)O<F1E
M<BUB;W1T;VTZ(#%P>"!S;VQI9"`C,#`P.PI]"@HO*B!";&]C:R!S='EL97,N
M("HO"BYC=7)R96YT0FQO8VL@>PH@("`@8F]R9&5R.B`R<'@@<V]L:60@<F5D
M.PI]"@HO*B!(96QP('-T>6QE<RX@*B\*+FAE;'`@>PH@("`@8F%C:V=R;W5N
M9#H@(V9F9CL*("`@(&-O;&]R.B`C,#`P.PI]"BYH96QP(&@Q('L*("`@(&9O
M;G0M<VEZ93H@,35P>#L*("`@('!A9&1I;F<M=&]P.B`P+C5E;3L*("`@('!A
M9&1I;F<M8F]T=&]M.B`P+C5E;3L*?0HN:&5L<"!H,B!["B`@("!B;W)D97(M
M=&]P.B`Q<'@@<V]L:60@(S0T-CL*("`@('!A9&1I;F<M=&]P.B`Q96T["B`@
M("!P861D:6YG+6)O='1O;3H@,"XU96T["B`@("!F;VYT+7-I>F4Z(#$S<'@[
M"GT*+FAE;'`@<"!["B`@("!M87)G:6XM;&5F=#H@,65M.PH@("`@;6%R9VEN
M+7)I9VAT.B`Q96T["B`@("!M87)G:6XM8F]T=&]M.B`Q96T["GT*+FAE;'`@
M96T@>PH@("`@9&ES<&QA>3H@8FQO8VL["B`@("!P861D:6YG.B`U<'@["B`@
M("!M87)G:6XM;&5F=#H@,65M.PH@("`@;6%R9VEN+7)I9VAT.B`Q96T["B`@
M("!M87)G:6XM8F]T=&]M.B`Q96T["GT*+FAE;'`@96TN:&5L<%1I<"!["B`@
M("!C;VQO<CH@(S`Y,#L*("`@(&)A8VMG<F]U;F0Z("-E,&8P93`["GT*+FAE
M;'`@96TN:&5L<%=A<FX@>PH@("`@8V]L;W(Z(",Y,#`["B`@("!B86-K9W)O
M=6YD.B`C9C!E,&4P.PI]"@HO*B!3;W5R8V4@;6%R:W5P('-T>6QE<RX@*B\*
M=&%B;&4N;&EN94YU;6)E<F5D('L*("`@(&UA<F=I;CH@-7!X.PH@("`@8F]R
M9&5R.B`Q<'@@<V]L:60@(S`P,#L*?0HN;&EN94YU;6)E<F5D('1H('L*("`@
M(&)A8VMG<F]U;F0Z("-E.64Y93D["B`@("!B;W)D97(M<FEG:'0Z(#%P>"!S
M;VQI9"`C93!E,&4P.PH@("`@8F]R9&5R+6QE9G0Z(#%P>"!S;VQI9"`C9C-F
M,V8S.PH@("`@<&%D9&EN9RUL969T.B`Q,'!X.PH@("`@<&%D9&EN9RUR:6=H
M=#HQ,'!X.PH@("`@=&5X="UA;&EG;CH@<FEG:'0["GT*+FQI;F5.=6UB97)E
M9"!T:"!A('L*("`@(&9O;G0M9F%M:6QY.B!M;VYO<W!A8V4["B`@("!F;VYT
M+7-I>F4Z(#$R<'@["B`@("!L:6YE+6AE:6=H=#H@,39P>#L*?0HN;&EN94YU
M;6)E<F5D('1D('L*("`@('9E<G1I8V%L+6%L:6=N.B!T;W`["B`@("!W:61T
M:#H@,3`P)3L*("`@('=H:71E+7-P86-E.B!P<F4["B`@("!B86-K9W)O=6YD
M.B`C9F9F.PH@("`@<&%D9&EN9RUL969T.B`Q,'!X.PH@("`@9F]N="UF86UI
M;'DZ(&UO;F]S<&%C93L*("`@(&9O;G0M<VEZ93H@,3)P>#L*("`@('=H:71E
M+7-P86-E.B!P<F4["B`@("!L:6YE+6AE:6=H=#H@,39P>#L*?0HN<&%R96YT
M:&5S97,@>PH@("`@8V]L;W(Z(",R838["B`@("!F;VYT+7=E:6=H=#H@8F]L
M9#L*?0HN8V]M;65N="!["B`@("!C;VQO<CH@(V%A8SL*?0HN:'1A9R!["B`@
M("!C;VQO<CH@(S4V.3L*("`@(&)A8VMG<F]U;F0Z("-D-60V9&$["B`@("!F
M;VYT+7=E:6=H=#H@8F]L9#L*?0HN;65T86,@>PH@("`@8V]L;W(Z(",P9F8[
M"B`@("!B86-K9W)O=6YD.B`C9#5D-F1A.PI]"BYI9"!["B`@("!C;VQO<CH@
M(V4X,CL*("`@(&)A8VMG<F]U;F0Z("-E-&4T93`["GT*+F%T='(@>PH@("`@
M8V]L;W(Z(",V868["GT*+G9A;'5E('L*("`@(&-O;&]R.B`C9#0V.PI]"BYC
M;VQO<B!["B`@("!C;VQO<CH@(V8U-SL*?0HN96]L('L*("`@(&-O;&]R.B`C
M,C9E.PI]"BYU<FP@>PH@("`@8V]L;W(Z(",Y-C(["GT*+F9I;&4@>PH@("`@
M8V]L;W(Z(",T-#0["B`@("!B86-K9W)O=6YD.B`C9F4T.PI]"BYC;&%S<R![
M"B`@("!F;VYT+7-T>6QE.B!I=&%L:6,["GT*"B\J($1R;W`@<VAA9&]W<RX@
M*B\*+F1R;W!3:&%D;W<@>PH@("`@9FQO870Z(&QE9G0["B`@("!B86-K9W)O
M=6YD.B!U<FPH(F=R87!H:6-S+W-H861O=RYP;F<B*2!N;RUR97!E870@8F]T
M=&]M(')I9VAT("%I;7!O<G1A;G0["B`@("!B86-K9W)O=6YD.B!U<FPH(F=R
M87!H:6-S+W-H861O=RYG:68B*2!N;RUR97!E870@8F]T=&]M(')I9VAT.PH@
M("`@;6%R9VEN.B`Q,'!X(#`@,"`U<'@["GT*"BYD<F]P4VAA9&]W(&EM9R![
M"B`@("!D:7-P;&%Y.B!B;&]C:SL*("`@('!O<VET:6]N.B!R96QA=&EV93L*
M("`@(&)A8VMG<F]U;F0Z("-F9F8["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C
M-C8V.PH@("`@;6%R9VEN.B`M,W!X(#5P>"`U<'@@+3-P>#L*("`@('!A9&1I
M;F<Z(#)P>#L*?0H*+RH@;F5W<V9E961S("HO"@HN<VED96)A<E!A;F5L('L*
M("`@(&)O<F1E<BUR:6=H=#H@,7!X('-O;&ED(",P,#8["B`@("!B;W)D97(M
M8F]T=&]M.B`Q<'@@<V]L:60@(S`P-CL*("`@(&)A8VMG<F]U;F0Z("-E.64Y
M9F8["B`@("!F;VYT+69A;6EL>3H@5F5R9&%N82Q(96QV971I8V$L<V%N<RUS
M97)I9CL*("`@(&9O;G0M<VEZ93H@,3%P>#L*?0H*+G-I9&5B87)(96%D97(@
M>PH@(&)A8VMG<F]U;F0M8V]L;W(Z(",V93@Y9&0["GT*"BYH96%D97)4:71L
M92!["B`@8V]L;W(Z("-F9F8["B`@<&%D9&EN9SH@,W!X(#=P>#L*("!W:&ET
M92US<&%C93H@;F]W<F%P.PH@(&9O;G0M=V5I9VAT.B!B;VQD.PI]"BYH96%D
M97)"=71T;VYS('L*("!T97AT+6%L:6=N.B!R:6=H=#L*?0HN:&5A9&5R0G5T
M=&]N<R!A('L*("!O=F5R9FQO=SH@:&ED9&5N.PH@('=I9'1H.B`Q-G!X.PH@
M(&AE:6=H=#H@,39P>#L*("!D:7-P;&%Y.B`M;6]Z+6EN;&EN92UB;W@["B`@
M9&ES<&QA>3H@:6YL:6YE+6)L;V-K.PH@('9E<G1I8V%L+6%L:6=N.B!M:61D
M;&4["B`@8F%C:V=R;W5N9"UR97!E870Z(&YO+7)E<&5A=#L*("!M87)G:6XM
M<FEG:'0Z(#=P>#L*?0HN:&5A9&5R0G5T=&]N<R!A('-P86X@>PH@('!A9&1I
M;F<M;&5F=#H@,3`P<'@["B`@9&ES<&QA>3H@8FQO8VL["GT*+F)T;BUR969R
M97-H('L*("!B86-K9W)O=6YD+6EM86=E.B!U<FPH)R]T:&5M97,O9W)A<&AI
M8W,O:6UA9V4O<F5F<F5S:"YG:68G*3L*?0HN3D9C;&]S92`C;F5W<T9E961S
M('L*("!D:7-P;&%Y.B!N;VYE.PI]"BY.1F]P96X@+F)T;BUO<&5N+6-L;W-E
M('L*("!B86-K9W)O=6YD+6EM86=E.B!U<FPH)R]T:&5M97,O9W)A<&AI8W,O
M:6UA9V4O87)R;W<M9&]W;BYG:68G*3L*?0HN3D9C;&]S92`N8G1N+6]P96XM
M8VQO<V4@>PH@(&)A8VMG<F]U;F0M:6UA9V4Z('5R;"@G+W1H96UE<R]G<F%P
M:&EC<R]I;6%G92]A<G)O=RUU<"YG:68G*3L*?0HN3D9T:71L92!["F9O;G0M
M=V5I9VAT.B!B;VQD.PID:7-P;&%Y.B!B;&]C:SL*?0HN3D9I=&5M('L*9&ES
M<&QA>3H@8FQO8VL["FUA<F=I;BUB;W1T;VTZ(#5P>#L*?0HN3D9S;W5R8V4@
M>PIM87)G:6XM<FEG:'0Z(#5P>#L*?0HN3D9S=&%T=7,@>PIM87)G:6XM<FEG
M:'0Z(#5P>#L*9F]N="UW96EG:'0Z(&)O;&0["GT*+DY&=&EM92!["F-O;&]R
M.B`C,S,S.PI]"B-N97=S1F5E9',@>PIP861D:6YG.B`U<'@@-W!X(#5P>"`W
M<'@["GT*"@H`````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VEE-E]O<E]L97-S+F-S<P``````
M````````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,S0S(#$P-3$U
M-#,S-S4T(#`R,3<U,@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````O*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O:64V7V]R
M7VQE<W,N8W-S+'8@,2XQ+C(N,2`R,#`V+S`S+S(T(#`P.C0P.C,W(&-H=6-K
M($5X<"`D"B`J"B`J($-34R!C;W)R96-T:6]N<R!F;W(@244N"B`J+PH*+G1R
M9652;W<@>PH@("`@;W9E<F9L;W<Z('9I<VEB;&4["B`@("!H96EG:'0Z(#(P
M<'@["GT*"B-M96YU('L*("`@(&]V97)F;&]W.B!V:7-I8FQE.PH@("`@:&5I
M9VAT.B`U,'!X.PI]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W5T:6P`````````````````````````````````````````````
M```````````````````````````````````````````````````P,#`W-34@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S,S<U-"`P,38T
M-#``(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=71I;"]I8V]N7V)R;W=S97(N<&AP
M````````````````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`U-3(W
M(#$P-3$U-#,S-S4T(#`R,3<S-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]U
M=&EL+VEC;VY?8G)O=W-E<BYP:'`L=B`Q+C0N,BXT(#(P,#8O,#$O,#$@,C$Z
M,CDZ,3<@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@0VAU
M8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*B\*"D!D969I;F4H)T%55$A?2$%.1$Q%4B<L('1R=64I.PI`9&5F:6YE*"=(
M3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD["G)E<75I
M<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8V]R92YP:'`G.PH*)')E9VES
M=')Y(#T@)E)E9VES=')Y.CIS:6YG;&5T;VXH*3L*)&%P<',@/2`D<F5G:7-T
M<GDM/FQI<W1!<'!S*&%R<F%Y*"=N;W1O;VQB87(G+"`G86-T:79E)RP@)V%D
M;6EN)RP@)VEN86-T:79E)RP@)VAI9&1E;B<I+"!T<G5E*3L*:W-O<G0H)&%P
M<',I.PH*:68@*"@D87!P(#T@8F%S96YA;64H571I;#HZ9V5T1F]R;41A=&$H
M)V%P<"<I*2D@)B8@:7-S970H)&%P<'-;)&%P<%TI*2!["B`@("`O+R!0<F]V
M:61E(&$@;F]N+7=H:71E(&)A8VMG<F]U;F0@9F]R(&5Y96)A;&QI;F<@=')A
M;G-P87)E;F-Y+@H@("`@96-H;R`G/&AT;6P^/&)O9'D@8F=C;VQO<CTB(V%A
M86%A82(^)SL*"B`@("`D=&AE;65$:7(@/2`D<F5G:7-T<GDM/F=E="@G=&AE
M;65S9G,G+"`D87!P*3L*("`@(&EF("@A:7-?9&ER*"1T:&5M941I<BDI('L*
M("`@("`@("!E>&ET*'-P<FEN=&8H7R@B5&AE;65S(&1I<F5C=&]R>2!<(B5S
M7"(@;F]T(&9O=6YD+B(I+"`D=&AE;65$:7(I*3L*("`@('T*"B`@("`O+R!"
M87-E(&=R87!H:6-S(&9O<B!N;W<L(&9E96P@9G)E92!T;R!A9&0@=&AE;64@
M<W5P<&]R="X*("`@("1B87-E9&ER(#T@)&1I<B`]("1T:&5M941I<B`N($1)
M4D5#5$]265]315!!4D%43U(@+B`G9W)A<&AI8W,G.PH@("`@:68@*"%I<U]D
M:7(H)&1I<BDI('L*("`@("`@("!E>&ET*'-P<FEN=&8H7R@B0F%S92!G<F%P
M:&EC<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB*2P@)&1I<BDI.PH@
M("`@?0H*("`@(&EF("@H)'-U8F1I<B`](&)A<V5N86UE*%5T:6PZ.F=E=$9O
M<FU$871A*"=S=6)D:7(G*2DI*2!["B`@("`@("`@)&1I<B`N/2!$25)%0U1/
M4EE?4T5005)!5$]2("X@)'-U8F1I<CL*("`@("`@("!I9B`H(6ES7V1I<B@D
M9&ER*2D@>PH@("`@("`@("`@("!E>&ET*'-P<FEN=&8H7R@B4W5B9&ER96-T
M;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(BDL("1D:7(I*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+R\@0G)E861C<G5M8G,N"B`@("!E8VAO($AO<F1E.CIL:6YK
M*"=I8V]N7V)R;W=S97(N<&AP)RD@+B!?*")!<'!L:6-A=&EO;B!,:7-T(BD@
M+B`G/"]A/CQB<B`O/B<["B`@("!I9B`H(65M<'1Y*"1S=6)D:7(I*2!["B`@
M("`@("`@96-H;R!(;W)D93HZ;&EN:R@G:6-O;E]B<F]W<V5R+G!H<#]A<'`]
M)R`N("1A<'`I("X@)')E9VES=')Y+3YG970H)VYA;64G+"`D87!P*2`N("<\
M+V$^/&)R("\^)SL*("`@('T*("`@(&5C:&\@)SQB<B`O/B<["@H@("`@+R\@
M4VAO=R!I8V]N<R!F;W(@87!P+@H@("`@96-H;R`G/&@R/B<@+B!S<')I;G1F
M*%\H(DEC;VYS(&9O<B`E<R(I+"`D<F5G:7-T<GDM/F=E="@G;F%M92<L("1A
M<'`I*2`N("@A96UP='DH)'-U8F1I<BD@/R`G+R<@+B`D<W5B9&ER(#H@)R<I
M("X@)SPO:#(^)SL*"@H@("`@+R\@3&ES="!S=6)D:7)E8W1O<FEE<RX*("`@
M("1S=6)D:7)S(#T@9VQO8B@D9&ER("X@1$E214-43U)97U-%4$%2051/4B`N
M("<J)RP@1TQ/0E]/3DQ91$E2*3L*("`@(&EF("@D<W5B9&ER<R`F)B!C;W5N
M="@D<W5B9&ER<RDI('L*("`@("`@("!F;W)E86-H("@D<W5B9&ER<R!A<R`D
M<W5B9&ER*2!["B`@("`@("`@("`@(&EF("AB87-E;F%M92@D<W5B9&ER*2`]
M/2`G0U93)RD@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@96-H;R!(;W)D93HZ;&EN:RA5=&EL.CIA9&10
M87)A;65T97(H)VEC;VY?8G)O=W-E<BYP:'`G+"!A<G)A>2@G<W5B9&ER)R`]
M/B!B87-E;F%M92@D<W5B9&ER*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G87!P)R`]/B`D87!P*2DI("X@8F%S96YA;64H)'-U8F1I<BD@+B`G
M/"]A/CQB<B`O/B<["B`@("`@("`@?0H@("`@("`@(&5C:&\@)SQB<B`O/B<[
M"B`@("!]"@H@("`@)&EM86=E<R`](&=L;V(H)&1I<B`N($1)4D5#5$]265]3
M15!!4D%43U(@+B`G*BYP;F<G*3L*("`@(&EF("@D:6UA9V5S("8F(&-O=6YT
M*"1I;6%G97,I*2!["B`@("`@("`@9F]R96%C:"`H)&EM86=E<R!A<R`D<&YG
M*2!["B`@("`@("`@("`@(&5C:&\@2&]R9&4Z.FEM9RAS=')?<F5P;&%C92@D
M8F%S961I<B`N($1)4D5#5$]265]315!!4D%43U(L("<G+"`D<&YG*2P@)'!N
M9RP@87)R87DH)VAS<&%C92<@/3X@,3`L("=V<W!A8V4G(#T^(#$P*2P@)')E
M9VES=')Y+3YG971);6%G941I<B@D87!P*2D["B`@("`@("`@?0H@("`@?2!E
M;'-E('L*("`@("`@("!E8VAO(%\H(DYO(&EC;VYS(&9O=6YD+B(I.PH@("`@
M?0H*("`@(&5C:&\@)SPO8F]D>3X\+VAT;6P^)SL*?2!E;'-E('L*("`@("\O
M($QI<W0@87!P<RX*("`@(&9O<F5A8V@@*"1A<'!S(&%S("1A<'`I('L*("`@
M("`@("!E8VAO($AO<F1E.CIL:6YK*%5T:6PZ.F%D9%!A<F%M971E<B@G:6-O
M;E]B<F]W<V5R+G!H<"<L("=A<'`G+"`D87!P*2D@+B`D<F5G:7-T<GDM/F=E
M="@G;F%M92<L("1A<'`I("X@)SPO83X\8G(@+SXG.PH@("`@?0I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]U=&EL+V)A<F-O9&4N<&AP````````````````````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#4S-C$@,3`U,34T,S,W-30@,#(P
M-C,T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W5T:6PO8F%R8V]D92YP:'`L
M=B`Q+C$P+C$P+C,@,C`P-B\P,2\P,2`R,3HR.3HQ-R!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?
M0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B<I.PIR97%U:7)E7V]N
M8V4@2$]21$5?0D%312`N("<O;&EB+V-O<F4N<&AP)SL*<F5Q=6ER95]O;F-E
M("=(;W)D92]);6%G92YP:'`G.PH*+R\@1V5T('1E>'0L('5P<&5R8V%S92P@
M861D('-T87)T+W-T;W`@8VAA<F%C=&5R<RX*)'1E>'0@/2!5=&EL.CIG971&
M;W)M1&%T82@G8F%R8V]D92<L("=T97-T)RD["B1T97AT(#T@4W1R:6YG.CIU
M<'!E<B@D=&5X="P@=')U92D["B1T97AT(#T@(BHD=&5X="HB.PHD=&5X=&QE
M;B`]('-T<FQE;B@D=&5X="D["@HD:&5I9VAT(#T@571I;#HZ9V5T1F]R;41A
M=&$H)V@G+"`T,"D["B1T:&EN=VED=&@@/2!5=&EL.CIG971&;W)M1&%T82@G
M=R<L(#(I.PHD=&AI8VMW:61T:"`]("1T:&EN=VED=&@@*B`S.PHD=VED=&@@
M/2`D=&5X=&QE;B`J("@W("H@)'1H:6YW:61T:"`K(#,@*B`D=&AI8VMW:61T
M:"D@+2`D=&AI;G=I9'1H.PH*)&-O9&EN9VUA<"`](&%R<F%Y*"<P)R`]/B`G
M,#`P,3$P,3`P)RP@)S$G(#T^("<Q,#`Q,#`P,#$G+`H@("`@("`@("`@("`@
M("`@("`@)S(G(#T^("<P,#$Q,#`P,#$G+"`G,R<@/3X@)S$P,3$P,#`P,"<L
M("<T)R`]/B`G,#`P,3$P,#`Q)RP*("`@("`@("`@("`@("`@("`@("<U)R`]
M/B`G,3`P,3$P,#`P)RP@)S8G(#T^("<P,#$Q,3`P,#`G+"`G-R<@/3X@)S`P
M,#$P,#$P,2<L"B`@("`@("`@("`@("`@("`@("`G."<@/3X@)S$P,#$P,#$P
M,"<L("<Y)R`]/B`G,#`Q,3`P,3`P)RP@)T$G(#T^("<Q,#`P,#$P,#$G+`H@
M("`@("`@("`@("`@("`@("`@)T(G(#T^("<P,#$P,#$P,#$G+"`G0R<@/3X@
M)S$P,3`P,3`P,"<L("=$)R`]/B`G,#`P,#$Q,#`Q)RP*("`@("`@("`@("`@
M("`@("`@("=%)R`]/B`G,3`P,#$Q,#`P)RP@)T8G(#T^("<P,#$P,3$P,#`G
M+"`G1R<@/3X@)S`P,#`P,3$P,2<L"B`@("`@("`@("`@("`@("`@("`G2"<@
M/3X@)S$P,#`P,3$P,"<L("=))R`]/B`G,#`Q,#`Q,3`P)RP@)THG(#T^("<P
M,#`P,3$Q,#`G+`H@("`@("`@("`@("`@("`@("`@)TLG(#T^("<Q,#`P,#`P
M,3$G+"`G3"<@/3X@)S`P,3`P,#`Q,2<L("=-)R`]/B`G,3`Q,#`P,#$P)RP*
M("`@("`@("`@("`@("`@("`@("=.)R`]/B`G,#`P,#$P,#$Q)RP@)T\G(#T^
M("<Q,#`P,3`P,3`G+"`G4"<@/3X@)S`P,3`Q,#`Q,"<L"B`@("`@("`@("`@
M("`@("`@("`G42<@/3X@)S`P,#`P,#$Q,2<L("=2)R`]/B`G,3`P,#`P,3$P
M)RP@)U,G(#T^("<P,#$P,#`Q,3`G+`H@("`@("`@("`@("`@("`@("`@)U0G
M(#T^("<P,#`P,3`Q,3`G+"`G52<@/3X@)S$Q,#`P,#`P,2<L("=6)R`]/B`G
M,#$Q,#`P,#`Q)RP*("`@("`@("`@("`@("`@("`@("=7)R`]/B`G,3$Q,#`P
M,#`P)RP@)U@G(#T^("<P,3`P,3`P,#$G+"`G62<@/3X@)S$Q,#`Q,#`P,"<L
M"B`@("`@("`@("`@("`@("`@("`G6B<@/3X@)S`Q,3`Q,#`P,"<L("<@)R`]
M/B`G,#$Q,#`P,3`P)RP@)R0G(#T^("<P,3`Q,#$P,#`G+`H@("`@("`@("`@
M("`@("`@("`@)R4G(#T^("<P,#`Q,#$P,3`G+"`G*B<@/3X@)S`Q,#`Q,#$P
M,"<L("<K)R`]/B`G,#$P,#`Q,#$P)RP*("`@("`@("`@("`@("`@("`@("<M
M)R`]/B`G,#$P,#`P,3`Q)RP@)RXG(#T^("<Q,3`P,#`Q,#`G+"`G+R<@/3X@
M)S`Q,#$P,#`Q,"<I.PH*)&EM86=E(#T@)DAO<F1E7TEM86=E.CIF86-T;W)Y
M*%5T:6PZ.F=E=$9O<FU$871A*"=T>7!E)RP@)W!N9R<I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)W1E;7`G(#T^($AO<F1E.CIG
M971496UP1&ER*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G=VED=&@G(#T^("1W:61T:"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=H96EG:'0G(#T^("1H96EG:'0L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8F%C:V=R;W5N9"<@/3X@
M)W=H:71E)RDI.PH*)'AP;W,@/2`P.PIF;W(@*"1I9'@@/2`P.R`D:61X(#P@
M)'1E>'1L96X[("1I9'@K*RD@>PH@("`@)&-H87(@/2!S=6)S='(H)'1E>'0L
M("1I9'@L(#$I.PH@("`@+R\@36%K92!U;FMN;W=N(&-H87)S(&$@)RTG+@H@
M("`@:68@*"%I<W-E="@D8V]D:6YG;6%P6R1C:&%R72DI('L*("`@("`@("`D
M8VAA<B`]("<M)SL*("`@('T*("`@(&9O<B`H)&)A<B`](#`[("1B87(@/#T@
M.#L@)&)A<BLK*2!["B`@("`@("`@)&5L96UE;G1W:61T:"`]("1C;V1I;F=M
M87!;)&-H87)=>R1B87)](#\@)'1H:6-K=VED=&@@.B`D=&AI;G=I9'1H.PH@
M("`@("`@(&EF("@H)&)A<B`K(#$I("4@,BD@>PH@("`@("`@("`@("`D:6UA
M9V4M/G)E8W1A;F=L92@D>'!O<RP@,"P@)&5L96UE;G1W:61T:"`M(#$L("1H
M96EG:'0L("=B;&%C:R<L("=B;&%C:R<I.PH@("`@("`@('T*("`@("`@("`D
M>'!O<R`K/2`D96QE;65N='=I9'1H.PH@("`@?0H@("`@)'AP;W,@*ST@)'1H
M:6YW:61T:#L*?0H*:&5A9&5R*"=0<F%G;6$Z('!U8FQI8R<I.PHD:6UA9V4M
M/F1I<W!L87DH*3L*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W5T:6PO<F5G
M97A?=&5S="YP:'``````````````````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`Q,C,Q-B`Q,#4Q-30S,S<U-"`P,C$T,#0`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%-I
M;7!L92!S8W)I<'0@=&\@:&5L<"!W:71H(')E9V5X(&-O;G-T<G5C=&EO;B]D
M96)U9V=I;F<N(%!U="!I=`H@*B!S;VUE=VAE<F4@;VX@>6]U<B!W96)S97)V
M97(@86YD('!O:6YT('EO=7(@8G)O=W-E<B!T;R!I="X*("H*("H@0F%S960@
M;VXZ(&AT='`Z+R]M>69L=69F>61O9RYC;VTO<')O9W)A;6UI;F<O<&AP+W-C
M<FEP=',O<F5G97AP+G!H<`H@*@H@*B`D2&]R9&4Z(&AO<F1E+W5T:6PO<F5G
M97A?=&5S="YP:'`L=B`Q+C,N,3`N-"`R,#`U+S$P+S$X(#$Q.C,T.C(Q(&IA
M;B!%>'`@)`H@*B\*"G)E<75I<F4@)TAO<F1E+U5T:6PN<&AP)SL*)')E9V5X
M<"`](%5T:6PZ.F=E=$9O<FU$871A*"=R96=E>'`G*3L*)'-U8FIE8W0@/2!5
M=&EL.CIG971&;W)M1&%T82@G<W5B:F5C="<I.PHD<W5B;6ET(#T@571I;#HZ
M9V5T1F]R;41A=&$H)W-U8FUI="<I.PH*0'-E=%]T:6UE7VQI;6ET*#(I.PH*
M9G5N8W1I;VX@=6YH=&UL96YT:71I97,H)'-T<FEN9RD*>PH@("`@)'1R86YS
M7W1B;"`](&=E=%]H=&UL7W1R86YS;&%T:6]N7W1A8FQE*$A434Q?14Y4251)
M15,I.PH@("`@)'1R86YS7W1B;"`](&%R<F%Y7V9L:7`H)'1R86YS7W1B;"D[
M"B`@("!R971U<FX@<W1R='(H)'-T<FEN9RP@)'1R86YS7W1B;"D["GT*"FEF
M("@D<W5B;6ET(#T](")497-T(BD@>R`O+R!D;VEN9R!A(')E9R!E>'!R97-S
M:6]N('-E87)C:"`M+2!G970@=F%R:6%B;&5S"B`@("`D=6YE<V-A<&5D4F5G
M97AP(#T@=6YH=&UL96YT:71I97,H)')E9V5X<"D[("\O(&9O<B!S96%R8V@*
M("`@("1E<V-A<&5D4F5G97AP(#T@:'1M;&5N=&ET:65S*"1R96=E>'`I.R`O
M+R!F;W(@<VAO=VEN9R!O;B!P86=E(&%N9"!I;B!T97AT87)E80H@("`@)'1E
M>'0@/2`D<W5B:F5C=#L*("`@("1T97AT(#T@<W1R:7!S;&%S:&5S*"1T97AT
M*3L*("`@("1T97AT(#T@=6YH=&UL96YT:71I97,H)'1E>'0I.R`O+R!F;W(@
M<V5A<F-H"B`@("`D97-C87!E9%1E>'0@/2!H=&UL96YT:71I97,H)'1E>'0I
M.R\O(&9O<B!T97AT87)E80H*("`@("\O($1O('!R96=?<F5P;&%C92!O;B!S
M;W5R8V4L('-U8G-T:71U=&EN9R!M871C:&5D7W1E>'0@=VET:"!;8EUM871C
M:&5D7W1E>'1;+V)="B`@("`D:&EG:&QI9VAT961497AT(#T@<')E9U]R97!L
M86-E*"1U;F5S8V%P961296=E>'`L("=;8EU<7#!;+V)=)RP@)'1E>'0I.PH@
M("`@+R\@8V]N=F5R="!H=&UL96YT:71I97,*("`@("1H:6=H;&EG:'1E9%1E
M>'0@/2!H=&UL96YT:71I97,H)&AI9VAL:6=H=&5D5&5X="D["B`@("`O+R!R
M97!L86-E(%MB72!A;F0@6R]B72!W:71H(&AI9VAL:6=H="X*("`@("1H:6=H
M;&EG:'1E9%1E>'0@/2!S=')?<F5P;&%C92@G6V)=)RP@)SQS<&%N(&-L87-S
M/2)H:6=H;&EG:'0B/B<L("1H:6=H;&EG:'1E9%1E>'0I.PH@("`@)&AI9VAL
M:6=H=&5D5&5X="`]('-T<E]R97!L86-E*"=;+V)=)RP@)SPO<W!A;CXG+"`D
M:&EG:&QI9VAT961497AT*3L*?0H_/@H\:'1M;#X*/&AE860^"CQT:71L93Y4
M97-T(')E9W5L87(@97AP<F5S<VEO;G,\+W1I=&QE/@H\<W1Y;&4@='EP93TB
M=&5X="]C<W,B/@H\(2TM"F@Q('L*("`@(&9O;G0M<VEZ93H@;&%R9V4["GT*
M+F9I>&5D('L*("`@(&9O;G0M<VEZ93H@,3!P>#L*("`@(&9O;G0M9F%M:6QY
M.B!M;VYO<W!A8V4L9FEX960["B`@("!C;VQO<CH@(S`P,#`Y.3L*("`@(&)A
M8VMG<F]U;F0M8V]L;W(Z("-C8V-C8V,["GT*+FYO=&5S('L*("`@(&9O;G0M
M<VEZ93H@<VUA;&P["B`@("!C;VQO<CH@(S`P,#`Y.3L*("`@(&)A8VMG<F]U
M;F0M8V]L;W(Z("-C8V-C8V,["GT*+FAI9VAL:6=H="!["B`@("!C;VQO<CH@
M(S`P,#`V-CL*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-F9F9F,#`["GT*+F5M
M<'1Y('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-F9CDY,S,*?0HM+3X*/"]S
M='EL93X*/&UE=&$@:'1T<"UE<75I=CTB0V]N=&5N="U4>7!E(B!C;VYT96YT
M/2)T97AT+VAT;6P[(&-H87)S970]:7-O+3@X-3DM,2(^"CPO:&5A9#X*/&)O
M9'D@8F=C;VQO<CTB(T9&1D9&1B(^"CQH,3Y497-T(#QA(&AR968](FAT='`Z
M+R]W=W<N<&AP+FYE="]M86YU86PO96XO<F5F+G!C<F4N<&AP(CY02%`@4F5G
M=6QA<B!%>'!R97-S:6]N($9U;F-T:6]N<R`H4&5R;"U#;VUP871I8FQE*3PO
M83X\+V@Q/@H\9&EV(&-L87-S/2)F:7AE9"(^<')E9U]M871C:%]A;&PH)'!A
M='1E<FXL("1S=6)J96-T+"`D;6%T8VAE<RP@4%)%1U]3151?3U)$15(I/"]D
M:78^"CQF;W)M(&YA;64](F9O<FTQ(B!M971H;V0](G!O<W0B(&%C=&EO;CTB
M/#]P:'`@96-H;R`D7U-%4E9%4ELG4$A07U-%3$8G72`_/B(^"CQP/CQS=')O
M;F<^16YT97(@>6]U<B!R96=U;&%R(&5X<')E<W-I;VX@*"1P871T97)N*3H\
M+W-T<F]N9SX\8G(@+SX*/'1E>'1A<F5A(&YA;64](G)E9V5X<"(@8V]L<STB
M.#`B(')O=W,](C8B(&ED/2)R96=E>'`B/CP_<&AP(&EF*"1S=6)M:70I>V5C
M:&\@)&5S8V%P961296=E>'`[?3\^/"]T97AT87)E83X*/&)R("\^"CQS=')O
M;F<^16YT97(@=&5X="!T;R!S96%R8V@@86=A:6YS="!I;B!T:&4@=&5X=&%R
M96$@8F5L;W<@*"1S=6)J96-T*3H\+W-T<F]N9SX\8G(@+SX*/'1E>'1A<F5A
M(&YA;64](G-U8FIE8W0B(&-O;',](C@P(B!R;W=S/2(S(CX\/W!H<"!I9B@D
M<W5B:F5C="E[96-H;R`D97-C87!E9%1E>'0[?3\^/"]T97AT87)E83X*/&)R
M("\^"CQI;G!U="!T>7!E/2)S=6)M:70B(&YA;64](G-U8FUI="(@=F%L=64]
M(E1E<W0B/@H\:6YP=70@='EP93TB<F5S970B(&YA;64](E)E<V5T(B!V86QU
M93TB4F5S970B/@H\82!H<F5F/2<\/W!H<"!E8VAO("1?4T525D526R=02%!?
M4T5,1B==(#\^)SY(;VUE/"]A/CQB<B`O/@H\+W`^"CPO9F]R;3X*/&AR("\^
M"CP_<&AP"FEF("@D<W5B;6ET*2![("\O(&]N;'D@<VAO=W,@=7`@;VX@<F5S
M=6QT<R!P86=E"B`@("!I9B`H<')E9U]M871C:%]A;&PH)'5N97-C87!E9%)E
M9V5X<"P@)'1E>'0L("1R97-U;'1S+"!04D5'7U-%5%]/4D1%4BDI('L@+R\@
M9F]U;F0@;6%T8V@*("`@("`@("!E8VAO(")4:&4@<F5G97AP(#QS=')O;F<^
M("1E<V-A<&5D4F5G97AP(#PO<W1R;VYG/B!M871C:&5D(5QN/'`^(CL*("`@
M("`@("!E8VAO("(\:#$^2&5R92=S('=H870@=V%S(&UA=&-H960@<V5A<F-H
M:6YG('1H92!T97AT('EO=2!E;G1E<F5D.CPO:#$^7&XB.PH@("`@("`@("1Y
M(#T@,#L*("`@("`@("!E8VAO("<\9&EV(&-L87-S/2)F:7AE9"(^)SL*("`@
M("`@("!F;W)E86-H("@D<F5S=6QT<R!A<R`D;&]O<%]R97-U;'0I('L*("`@
M("`@("`@("`@)'@@/2`P.PH@("`@("`@("`@("!F;W)E86-H("@D;&]O<%]R
M97-U;'0@87,@)&QO;W!?<F5S=6QT,BD@>PH@("`@("`@("`@("`@("`@:68@
M*"1X("$](#`I('L*("`@("`@("`@("`@("`@("`@("`O*B!);F1E;G0@<W5B
M<&%T=&5R;G,N("HO"B`@("`@("`@("`@("`@("`@("`@96-H;R`B/&)L;V-K
M<75O=&4^(CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('!R
M:6YT9B@G)&UA=&-H97-;)7-=6R5S73HF;F)S<#LF;F)S<#LG+"`D>2P@)'@I
M.R\O('-H;W<@=F%R:6%B;&4@;F%M90H@("`@("`@("`@("`@("`@:68@*"$D
M;&]O<%]R97-U;'0R*2!["B`@("`@("`@("`@("`@("`@("`@96-H;R`G/'-P
M86X@8VQA<W,](F5M<'1Y(CY%;7!T>3PO<W!A;CXG.PH@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!E8VAO("<\<W!A;B!C
M;&%S<STB:&EG:&QI9VAT(CXG("X@:'1M;&5N=&ET:65S*"1L;V]P7W)E<W5L
M=#(I("X@)SPO<W!A;CXG.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@:68@*"1X("$](#`I('L*("`@("`@("`@("`@("`@("`@("!E8VAO
M("(\+V)L;V-K<75O=&4^(CL*("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@96-H;R`B/'`@+SXB.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)'@K*SL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D>2LK.PH@("`@("`@('T*("`@("`@("!E8VAO("<\+V1I=CXG
M.PH@("`@?2!E;'-E('L@+R\@;F\@;6%T8V@*("`@("`@("!E8VAO(")R96=E
M>'`@/'-T<F]N9SX@)&5S8V%P961296=E>'`@/"]S=')O;F<^(&1O97-N)W0@
M<F5T=7)N(&%N>2!R97-U;'1S7&X\<#XB.PH@("`@?0H@("`@/SX*("`@(#QH
M,3Y396%R8VAE9"!T97AT('=I=&@@;6%T8VAE<R`\<W!A;B!C;&%S<STG:&EG
M:&QI9VAT)SYH:6=H;&EG:'1E9#PO<W!A;CX\+V@Q/@H@("`@/#]P:'`@+R\@
M4VAO=R!S96%R8VAE9"!T97AT('=I=&@@;6%T8VAE<R!H:6=H;&EG:'1E9`H@
M("`@96-H;R`G/'!R93XG.PH@("`@96-H;R`D:&EG:&QI9VAT961497AT.PH@
M("`@96-H;R`G/"]P<F4^/&AR("\^)SL*?0H_/@H*/&1I=B!C;&%S<STB;F]T
M97,B/@H\:#$^17AA;7!L92!R96=U;&%R(&5X<')E<W-I;VYS.CPO:#$^"CQP
M/CQS=')O;F<^>R9L=#LA+2TH/SHN?%QS*2H_+2TF9W0[?3PO<W1R;VYG/B9N
M8G-P.R`M+29N8G-P.R!3:&]W<R!C;VUM96YT<R!I;B!H=&UL)FYB<W`[/"]P
M/@H\=6P^"CQL:3X\<W1R;VYG/GL\+W-T<F]N9SX@;W!E;B!D96QI;6ET97(\
M+VQI/@H\;&D^/'-T<F]N9SXF;'0[(2TM/"]S=')O;F<^('-E87)C:"!F;W(@
M;W!E;FEN9R!C;VUM96YT('1A9SPO;&D^"CQL:3X\<W1R;VYG/B@_.BY\7',I
M*CPO<W1R;VYG/B!A;GD@;G5M8F5R(&]F(&-H87)A8W1E<G,@;W(@=VAI=&4@
M<W!A8V4\+VQI/@H\;&D^/'-T<F]N9SX_/"]S=')O;F<^(&YO;BUG<F5E9'D\
M+VQI/@H\;&D^/'-T<F]N9SXM+29G=#L\+W-T<F]N9SX@<V5A<F-H(&9O<B!C
M;&]S:6YG(&-O;6UE;G0@=&%G/"]L:3X*/&QI/CQS=')O;F<^?3PO<W1R;VYG
M/B!C;&]S92!D96QI;6ET97(\+VQI/@H\+W5L/@H\<#X\<W1R;VYG/GLF;'0[
M<W1Y;&4@='EP92@_.BY\7',I*C\F;'0[+W-T>6QE)F=T.WT\+W-T<F]N9SX@
M+2T@4VAO=W,@('-T>6QE<SPO<#X*/'`^3F]T97,Z/"]P/@H\=6P^"CQL:3Y4
M:&4@<F5S=6QT<R!P86=E('-H;W=S('1H92!I;F1I=FED=6%L(&UA=&-H97,@
M86YD('-U8G!A='1E<FX@;6%T8VAE<RP@86YD('1H92!O<FEG:6YA;"!T97AT
M('=I=&@@=&AE(&UA=&-H97,@:&EG:&QI9VAT960N/"]L:3X*/&QI/DUI9VAT
M(&YO="!B92!A8FQE('1O('-E87)C:"!F;W(@:'1M;"!E;G1I=&EE<R!L:6ME
M("(F86UP.V%M<#LB(&)E8V%U<V4@;V8@=&AE(&-O;G9E<G1I;F<@9F]R(&1I
M<W!L87D@86YD('1E>'1A<F5A<R`H=&AE('-E87)C:"!P871T97)N("AR96=E
M>'`I(&%N9"!N;VXM=7)L('-U8FIE8W1S(&%R92!P<F]C97-S960@8GD@=6YH
M=&UL96YT:71I97,I/"]L:3X*/"]U;#X\+V1I=CX*/"]B;V1Y/@H\+VAT;6P^
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O971C````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S
M,S<U-"`P,30S-30`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]E=&,O<'-A+6AO<F1E````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,#`P(#$P-3$U-#,S-S4T(#`Q-C(S-@`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+V5T8R]P
M<V$M:&]R9&4O:&]R9&4`````````````````````````````````````````
M````````````````````````````````````````````````,#`P-S4U(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S,W-30@,#$W,S,W
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O971C+W!S82UH;W)D92]H;W)D92]C;VYF+G!H<```````
M````````````````````````````````````````````````````````````
M```````````P,#`T-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,#$R-B`Q
M,#4Q-30S,S<U-"`P,C$P-3(`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RH@0T].1DE'(%-405)4+B!$3R!.3U0@
M0TA!3D=%($%.651(24Y'($E.($]2($%&5$52(%1(25,@3$E.12X@*B\*+R\@
M)$AO<F1E.B!H;W)D92]C;VYF:6<O8V]N9BYX;6PL=B`Q+C<T+C(N-#$@,C`P
M-B\P."\P-"`Q-SHQ,SHR-2!J86X@17AP("0*+RHJ"BH@4&QE<VL@<')E9&5F
M:6YE9"!C;VYF:6=U<F%T:6]N(&9O<B!(;W)D93,**BHO"@HD8V]N9ELG9&5B
M=6=?;&5V96PG72`]($5?15)23U(["B1C;VYF6R=M87A?97AE8U]T:6UE)UT@
M/2`P.PHD8V]N9ELG=7-E7W-S;"==(#T@,CL*)&-O;F9;)W-E<G9E<B==6R=N
M86UE)UT@/2`D7U-%4E9%4ELG4T525D527TY!344G73L*)&-O;F9;)W-E<G9E
M<B==6R=P;W)T)UT@/2`D7U-%4E9%4ELG4T525D527U!/4E0G73L*)&-O;F9;
M)V-O;7!R97-S7W!A9V5S)UT@/2!T<G5E.PHD8V]N9ELG=6UA<VLG72`](#`W
M-SL*)&-O;F9;)W-E<W-I;VXG75LG;F%M92==(#T@)TAO<F1E,R<["B1C;VYF
M6R=S97-S:6]N)UU;)V-A8VAE7VQI;6ET97(G72`]("=N;V-A8VAE)SL*)&-O
M;F9;)W-E<W-I;VXG75LG=&EM96]U="==(#T@,#L*)&-O;F9;)V-O;VMI92==
M6R=D;VUA:6XG72`]("1?4T525D526R=315)615)?3D%-12==.PHD8V]N9ELG
M8V]O:VEE)UU;)W!A=&@G72`]("<O)SL*)&-O;F9;)W-Q;"==6R=P97)S:7-T
M96YT)UT@/2!F86QS93L*)&-O;F9;)W-Q;"==6R=H;W-T<W!E8R==(#T@)VQO
M8V%L:&]S="<["B1C;VYF6R=S<6PG75LG=7-E<FYA;64G72`]("=H;W)D92<[
M"B1C;VYF6R=S<6PG75LG<V]C:V5T)UT@/2`G+W9A<B]L:6(O;7ES<6PO;7ES
M<6PN<V]C:R<["B1C;VYF6R=S<6PG75LG<')O=&]C;VPG72`]("=U;FEX)SL*
M)&-O;F9;)W-Q;"==6R=D871A8F%S92==(#T@)VAO<F1E)SL*"B\O(&=E="!P
M87-S=V]R9"!F<F]M("]E=&,O<'-A+RYW96)M86EL+G-H861O=R`*:68@*"$H
M)&9D(#T@9F]P96XH(B]E=&,O<'-A+RYW96)M86EL+G-H861O=R(L(")R(BDI
M*2!["B`@96-H;R`B/'-C<FEP=#YA;&5R="@G56YA8FQE('1O(&=E="!W96)M
M86EL('!A<W-W;W)D(2<I/"]S8W)I<'0^(CL*("!E>&ET*"D["GT*9G-C86YF
M*"1F9"P@(B5S(BP@)&)U9F8I.PIF8VQO<V4H)&9D*3L*"B1C;VYF6R=S<6PG
M75LG<&%S<W=O<F0G72`]('!R96=?<F5P;&%C92@B+UQN+R(L("(B+"`D8G5F
M9BD["B1C;VYF6R=S<6PG75LG8VAA<G-E="==(#T@)W5T9C@G.PHD8V]N9ELG
M<W%L)UU;)W!H<'1Y<&4G72`]("=M>7-Q;"<["B1C;VYF6R=A=71H)UU;)V%D
M;6EN<R==(#T@87)R87DH*3L*)&-O;F9;)V%U=&@G75LG8VAE8VMI<"==(#T@
M=')U93L*)&-O;F9;)V%U=&@G75LG8VAE8VMB<F]W<V5R)UT@/2!T<G5E.PHD
M8V]N9ELG875T:"==6R=A;'1E<FYA=&5?;&]G:6XG72`](&9A;'-E.PHD8V]N
M9ELG875T:"==6R=R961I<F5C=%]O;E]L;V=O=70G72`](&9A;'-E.PH*)&-O
M;F9;)V%U=&@G75LG9')I=F5R)UT@/2`G8V]M<&]S:71E)SL*)&-O;F9;)V%U
M=&@G75LG<&%R86US)UU;)V1R:79E<G,G72`](&%R<F%Y*`H@("`@)VEM<"<@
M/3X@87)R87DH)V1R:79E<B<@/3X@)V%P<&QI8V%T:6]N)RP*("`@("`@("`@
M("`@("`@("`@("=P87)A;7,G(#T^(&%R<F%Y*"=A<'`G(#T^("=I;7`G*2DL
M"B`@("`G;6EM<"<@/3X@87)R87DH)V1R:79E<B<@/3X@)V%P<&QI8V%T:6]N
M)RP*("`@("`@("`@("`@("`@("`@("`G<&%R86US)R`]/B!A<G)A>2@G87!P
M)R`]/B`G;6EM<"<I*2D["@HD8V]N9ELG875T:"==6R=P87)A;7,G75LG;&]G
M:6YS8W)E96Y?<W=I=&-H)UT@/2`G7VAO<F1E7W-E;&5C=%]L;V=I;G-C<F5E
M;B<["@EI9B`H(69U;F-T:6]N7V5X:7-T<R@G7VAO<F1E7W-E;&5C=%]L;V=I
M;G-C<F5E;B<I*2!["@D)9G5N8W1I;VX@7VAO<F1E7W-E;&5C=%]L;V=I;G-C
M<F5E;B@I"@D)>PH)"0E`9&5F:6YE*$A/4D1%7T)!4T4L)R]U<W(O<VAA<F4O
M<'-A+6AO<F1E)RD["@D)"7)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L
M:6(O2&]R9&4O0G)O=W-E<BYP:'`G.PH)"0DD8G)O=W-E<B`](&YE=R!"<F]W
M<V5R*"D["@D)"6EF("@D8G)O=W-E<BT^:7--;V)I;&4H*2`F)B`D1TQ/0D%,
M4ULG<F5G:7-T<GDG72T^87!P;&EC871I;VYS6R=M:6UP)UTI>PH)"0D)<F5T
M=7)N("=M:6UP)SL*"0D)?0H)"0ER971U<FX@)VEM<"<[(`H)"7T*?0H*)&-O
M;F9;)W-I9VYU<"==6R=A;&QO=R==(#T@9F%L<V4["B1C;VYF6R=L;V<G75LG
M<')I;W)I='DG72`](%!%05)?3$]'7T524CL*)&-O;F9;)VQO9R==6R=I9&5N
M="==(#T@)TA/4D1%)SL*)&-O;F9;)VQO9R==6R=P87)A;7,G72`](&%R<F%Y
M*"D["B1C;VYF6R=L;V<G75LG;F%M92==(#T@)R]U<W(O;&]C86PO<'-A+W9A
M<B]L;V<O<'-A+6AO<F1E+FQO9R<["B1C;VYF6R=L;V<G75LG<&%R86US)UU;
M)V%P<&5N9"==(#T@=')U93L*)&-O;F9;)VQO9R==6R=T>7!E)UT@/2`G9FEL
M92<["B1C;VYF6R=L;V<G75LG96YA8FQE9"==(#T@=')U93L*)&-O;F9;)VQO
M9U]A8V-E<W-K97ES)UT@/2!F86QS93L*)&-O;F9;)W!R969S)UU;)W!A<F%M
M<R==6R=D<FEV97)C;VYF:6<G72`]("=H;W)D92<["B1C;VYF6R=P<F5F<R==
M6R=D<FEV97(G72`]("=S<6PG.PHD8V]N9ELG9&%T871R964G75LG<&%R86US
M)UU;)V1R:79E<F-O;F9I9R==(#T@)VAO<F1E)SL*)&-O;F9;)V1A=&%T<F5E
M)UU;)V1R:79E<B==(#T@)W-Q;"<["B1C;VYF6R=G<F]U<"==6R=D<FEV97(G
M72`]("=D871A=')E92<["B1C;VYF6R=C86-H92==6R=D969A=6QT7VQI9F5T
M:6UE)UT@/2`Q.#`P.PHD8V]N9ELG8V%C:&4G75LG<&%R86US)UU;)V1I<B==
M(#T@2&]R9&4Z.F=E=%1E;7!$:7(H*3L*)&-O;F9;)V-A8VAE)UU;)W!A<F%M
M<R==6R=G8R==(#T@.#8T,#`["B1C;VYF6R=C86-H92==6R=D<FEV97(G72`]
M("=F:6QE)SL*)&-O;F9;)VUA:6QE<B==6R=P87)A;7,G75LG:&]S="==(#T@
M)VQO8V%L:&]S="<["B1C;VYF6R=M86EL97(G75LG<&%R86US)UU;)V%U=&@G
M72`]("<P)SL*)&-O;F9;)VUA:6QE<B==6R=T>7!E)UT@/2`G<VUT<"<["B1C
M;VYF6R=V9G,G75LG<&%R86US)UU;)W9F<W)O;W0G72`]("<O=&UP)SL*)&-O
M;F9;)W9F<R==6R=T>7!E)UT@/2`G9FEL92<["B1C;VYF6R=S97-S:6]N:&%N
M9&QE<B==6R=T>7!E)UT@/2`G;F]N92<["B1C;VYF6R=M:6UE)UU;)VUA9VEC
M7V1B)UT@/2`G("]U<W(O<VAA<F4O;6ES8R]M86=I8R<["B1C;VYF6R=P<F]B
M;&5M<R==6R=E;6%I;"==(#T@)W=E8FUA<W1E<D!E>&%M<&QE+F-O;2<["B1C
M;VYF6R=P<F]B;&5M<R==6R=M86EL9&]M86EN)UT@/2`G97AA;7!L92YC;VTG
M.PHD8V]N9ELG<')O8FQE;7,G75LG=&EC:V5T<R==(#T@9F%L<V4["B1C;VYF
M6R=M96YU)UU;)V%P<',G72`](&%R<F%Y*"D["B1C;VYF6R=M96YU)UU;)V%L
M=V%Y<R==(#T@9F%L<V4["B1C;VYF6R=M96YU)UU;)VQI;FMS)UU;)VAE;'`G
M72`]("=A;&PG.PHD8V]N9ELG;65N=2==6R=L:6YK<R==6R=H96QP7V%B;W5T
M)UT@/2!T<G5E.PHD8V]N9ELG;65N=2==6R=L:6YK<R==6R=O<'1I;VYS)UT@
M/2`G875T:&5N=&EC871E9"<["B1C;VYF6R=M96YU)UU;)VQI;FMS)UU;)W!R
M;V)L96TG72`]("=N979E<B<["B1C;VYF6R=M96YU)UU;)VQI;FMS)UU;)VQO
M9VEN)UT@/2`G86QL)SL*)&-O;F9;)VUE;G4G75LG;&EN:W,G75LG;&]G;W5T
M)UT@/2`G875T:&5N=&EC871E9"<["B1C;VYF6R=H;V]K<R==6R=P97)M<V1E
M;FEE9"==(#T@9F%L<V4["B1C;VYF6R=H;V]K<R==6R=U<V5R;F%M92==(#T@
M9F%L<V4["B1C;VYF6R=H;V]K<R==6R=P<F5A=71H96YT:6-A=&4G72`](&9A
M;'-E.PHD8V]N9ELG:&]O:W,G75LG<&]S=&%U=&AE;G1I8V%T92==(#T@9F%L
M<V4["B1C;VYF6R=H;V]K<R==6R=A=71H;&1A<"==(#T@9F%L<V4["B1C;VYF
M6R=P;W)T86PG75LG9FEX961?8FQO8VMS)UT@/2!A<G)A>2@I.PHD8V]N9ELG
M86-C;W5N=',G75LG9')I=F5R)UT@/2`G;G5L;"<["B1C;VYF6R=I;7-P)UU;
M)V5N86)L960G72`](&9A;'-E.PHD8V]N9ELG:V]L86(G75LG96YA8FQE9"==
M(#T@9F%L<V4["B1C;VYF6R=T;VME;B==6R=P87)A;7,G75LG9')I=F5R8V]N
M9FEG)UT@/2`G:&]R9&4G.PHD8V]N9ELG=&]K96XG75LG9')I=F5R)UT@/2`G
M<W%L)SL*)&-O;F9;)V-S<R==6R=C86-H960G72`]('1R=64["B\J($-/3D9)
M1R!%3D0N($1/($Y/5"!#2$%.1T4@04Y95$A)3D<@24X@3U(@0D5&3U)%(%1(
M25,@3$E.12X@*B\*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]E=&,O<'-A+6AO<F1E+VAO<F1E+VUI;65?9')I=F5R<RYP:'``````````
M`````````````````````````````````````````````````````````#`P
M,#0T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#,V-3,W(#$P-3$U-#,S-S4T
M(#`R,C8S,``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]C;VYF:6<O;6EM95]D
M<FEV97)S+G!H<"YD:7-T+'8@,2XY-RXV+CD@,C`P-B\P-"\P-B`R,3HS,CHQ
M-"!J86X@17AP("0*("H*("H@1&5C:61E('=H:6-H(&]U='!U="!D<FEV97)S
M('EO=2!W86YT('1O(&%C=&EV871E(&9O<B!A;&P@2&]R9&4*("H@87!P;&EC
M871I;VYS+B!);F1I=FED=6%L($AO<F1E(&%P<&QI8V%T:6]N<R!C86X@;W9E
M<G)I9&4@=&AE<V4@<V5T=&EN9W,*("H@:6X@=&AE:7(@8V]N9FEG+VUI;65?
M9')I=F5R<RYP:'`@9FEL97,N"B`J"B`J(%1H92!A=F%I;&%B;&4@9')I=F5R
M<R!A<F4Z"B`J("TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"B`J(&-S<R`@
M("`@("`@("`@($-34R!3='EL97,*("H@9&5B("`@("`@("`@("`@1&5B:6%N
M('!A8VMA9V5S"B`J(&5N<FEC:&5D("`@("`@($5N<FEC:&5D('1E>'0@9F]R
M;6%T"B`J(&5N<V-R:7!T("`@("`@($=.52!E;G-C<FEP=`H@*B!H=&UL("`@
M("`@("`@("!(5$U,(&1A=&$*("H@:6UA9V5S("`@("`@("`@26UA9V4@9FEL
M97,*("H@;7-W;W)D("`@("`@("`@36EC<F]S;V9T(%=O<F0@9FEL97,@=FEA
M('=V2'1M;`H@*B!M<V5X8V5L("`@("`@("!-:6-R;W-O9G0@17AC96P@9FEL
M97,@=FEA('AL:'1M;`H@*B!M<W!O=V5R<&]I;G0@("!-:6-R;W-O9G0@4&]W
M97)P;VEN="!F:6QE<R!V:6$@<'!T:'1M;`H@*B!O;V\@("`@("`@("`@("!/
M<&5N3V9F:6-E+F]R9R]3=&%R3V9F:6-E($1O8W5M96YT<PH@*B!P9&8@("`@
M("`@("`@("!0;W)T86)L92!$;V-U;65N="!&;W)M870@*%!$1BD@9FEL97,*
M("H@<&AP("`@("`@("`@("`@5&AE(&EN=&5R;F%L(%!(4#0@<WEN=&%X(&AI
M9VAL:6=H=&EN9R!E;F=I;F4*("H@<&QA:6X@("`@("`@("`@4F5T=7)N('1E
M>'0L('=I=&@@;&EN:W,@;6%D92!C;&EC:V%B;&4@86YD(&]T:&5R($A434P*
M("H@("`@("`@("`@("`@("`@9FEL=&5R960@;W5T"B`J(')A<B`@("`@("`@
M("`@(%)!4B!A<F-H:79E<PH@*B!R97!O<G0@("`@("`@("!297!O<G0@;65S
M<V%G97,@*%)&0R`S-#4R*0H@*B!R9F,X,C(@("`@("`@("!$:6=E<W1E9"!M
M97-S86=E<R`H4D9#(#(P-#8@6S4N,BXQ72D*("H@<FEC:'1E>'0@("`@("`@
M4FEC:'1E>'0@=&5X="!F;W)M870@*%)&0R`Q,S0Q(%LW+C$N,UTI"B`J(')P
M;2`@("`@("`@("`@(%)032!P86-K86=E<PH@*B!S96-U<FET>2`@("`@("!3
M96-U<F4@;75L=&EP87)T<R`H4D9#(#$X-#<I"B`J('-I;7!L92`@("`@("`@
M($]U='!U="!T97AT('=I=&AO=70@;6]D:69I8V%T:6]N"B`J('-R8VAI9VAL
M:71E("`@(%-O=7)C92!(:6=H;&EG:'0*("H@=&=Z("`@("`@("`@("`@5&%R
M8F%L;',L(&EN8VQU9&EN9R!G>FEP<&5D(&]N97,*("H@=&YE9B`@("`@("`@
M("`@35,M5$Y%1B!A='1A8VAM96YT<PH@*B!V8V%R9"`@("`@("`@("!V0V%R
M9',*("H@=V5B8W!P("`@("`@("`@5V5B($,@4&QU<R!0;'5S"B`J('II<"`@
M("`@("`@("`@(%II<"!F:6QE<PH@*B\*)&UI;65?9')I=F5R<U]M87!;)VAO
M<F1E)UU;)W)E9VES=&5R960G72`](&%R<F%Y*`H@("`@)V-S<R<L("=E;G)I
M8VAE9"<L("=H=&UL)RP@)VEM86=E<R<L("=O;V\G+"`G<&1F)RP@)W!H<"<L
M("=P;&%I;B<L("=R87(G+`H@("`@)W)E<&]R="<L("=R9F,X,C(G+"`G<FEC
M:'1E>'0G+"`G<V5C=7)I='DG+"`G<VEM<&QE)RP@)W1G>B<L("=T;F5F)RP*
M("`@("=V8V%R9"<L("=Z:7`G+`H@("`@+R\@5&AE(&9O;&QO=VEN9R!M:6UE
M(&1R:79E<G,@<F5Q=6ER92!E>'1E<FYA;"!A<'!L:6-A=&EO;G,@=&\@8F4*
M("`@("\O(&EN<W1A;&QE9"X*("`@("\O("=D96(G+"`G96YS8W)I<'0G+"`G
M;7-W;W)D)RP@)VUS97AC96PG+"`G;7-P;W=E<G!O:6YT)RP@)W)P;2<L"B`@
M("`O+R`G<W)C:&EG:&QI=&4G+"`G=V5B8W!P)PHI.PH*"B\J*@H@*B!)9B!Y
M;W4@=V%N="!T;R!S<&5C:69I8V%L;'D@;W9E<G)I9&4@86YY($U)344@='EP
M92!T;R!B92!H86YD;&5D(&)Y"B`J(&$@<W!E8VEF:6,@9')I=F5R+"!T:&5N
M(&5N=&5R(&ET(&AE<F4N("!.;W)M86QL>2P@=&AI<R!I<R!S869E('1O"B`J
M(&QE879E+"!B=70@:70G<R!U<V5F=6P@=VAE;B!M=6QT:7!L92!D<FEV97)S
M(&AA;F1L92!T:&4@<V%M92!-24U%"B`J('1Y<&4L(&%N9"!Y;W4@=V%N="!T
M;R!S<&5C:69Y(&5X86-T;'D@=VAI8V@@;VYE('-H;W5L9"!H86YD;&4@:70N
M"B`J+PHD;6EM95]D<FEV97)S7VUA<%LG:&]R9&4G75LG;W9E<G)I9&5S)UT@
M/2!A<G)A>2@I.PH*"B\J*@H@*B!$<FEV97(@<W!E8VEF:6,@<V5T=&EN9W,N
M($AE<F4L('EO=2!H879E('1O(&-O;F9I9W5R92!E86-H(&1R:79E<@H@*B!W
M:&EC:"!Y;W4@8VAO<V4@=&\@86-T:79A=&4@86)O=F4N($1E9F%U;'0@<V5T
M=&EN9W,@:&%V92!B965N"B`J(&9I;&QE9"!I;B!F;W(@=&AE;2P@86YD(&EF
M('EO=2!H879E;B=T(&%C=&EV871E9"!I="P@=&AE;B!J=7-T"B`J(&QE879E
M(&ET(&%S(&ET(&ES("T@:70@=V]N)W0@9V5T(&QO861E9"X*("H*("H@5&AE
M("=H86YD;&5S)R!S971T:6YG(&)E;&]W('-H;W5L9&XG="!B92!C:&%N9V5D
M(&EN(&UO<W0*("H@8VER8W5M<W1A;F-E<RX@270@<F5G:7-T97)S(&$@<V5T
M(&]F($U)344@='EP92!T:&%T('1H92!D<FEV97(@8V%N"B`J(&AA;F1L92X@
M5&AE("=X+65X=&5N<VEO;B<@34E-12!T>7!E(&ES(&$@<W!E8VEA;"!O;F4@
M=&\@2&]R9&4@=&AA=`H@*B!M87!S(&$@9FEL92!E>'1E;G-I;VX@=&\@82!-
M24U%('1Y<&4N($ET)W,@=7-E9G5L('=H96X@>6]U(&MN;W<*("H@=&AA="!A
M;&P@9FEL97,@96YD:6YG(&EN("<N8R<@87)E($,@9FEL97,L(&9O<B!E>&%M
M<&QE+B!9;W4@8V%N('-E=`H@*B!T:&4@34E-12!S=6)T>7!E('1O("<J)R!T
M;R!M871C:"!A;&P@<&]S<VEB;&4@<W5B='EP97,*("H@*&DN92X@)VEM86=E
M+RHG*2X*("H*("H@5&AE("=I8V]N<R<@96YT<GD@:7,@9F]R('1H92!D<FEV
M97(@=&\@<F5G:7-T97(@=F%R:6]U<R!I8V]N<R!F;W(*("H@=&AE($U)344@
M='EP97,@:70@:&%N9&QE<RX@5&AE(&%R<F%Y(&-O;G-I<W1S(&]F(&$@)V1E
M9F%U;'0G(&EC;VX*("H@9F]R('1H870@9')I=F5R+"!A;F0@8V%N(&%L<V\@
M:6YC;'5D92!S<&5C:69I8R!-24U%+71Y<&5S('=H:6-H(&-A;@H@*B!H879E
M('1H96ER(&]W;B!I8V]N<RX@66]U(&-A;B!S970@=&AE($U)344@<W5B='EP
M92!T;R`G*B<@=&\@;6%T8V@*("H@86QL('!O<W-I8FQE('-U8G1Y<&5S("AI
M+F4N("=I;6%G92\J)RDN"B`J+PH*+RHJ"B`J($1E9F%U;'0@9')I=F5R('-E
M='1I;F=S"B`J+PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=D969A=6QT)UU;
M)VEC;VYS)UT@/2!A<G)A>2@*("`@("=D969A=6QT)R`@("`@("`@("`@("`@
M("`@("`@("`@/3X@)W1E>'0N<&YG)RP*("`@("=A=61I;R\J)R`@("`@("`@
M("`@("`@("`@("`@("`@/3X@)V%U9&EO+G!N9R<L"B`@("`G;65S<V%G92\J
M)R`@("`@("`@("`@("`@("`@("`@(#T^("=M86EL+G!N9R<L"B`@("`G=6YK
M;F]W;B\J)R`@("`@("`@("`@("`@("`@("`@(#T^("=B:6YA<GDN<&YG)RP*
M("`@("=V:61E;R\J)R`@("`@("`@("`@("`@("`@("`@("`@/3X@)W9I9&5O
M+G!N9R<L"B`@("`G87!P;&EC871I;VXO<&=P+7-I9VYA='5R92<@("`@(#T^
M("=E;F-R>7!T:6]N+G!N9R<L"B`@("`G87!P;&EC871I;VXO>"UP:V-S-RUS
M:6=N871U<F4G(#T^("=E;F-R>7!T:6]N+G!N9R<L"B`@("`G87!P;&EC871I
M;VXO;V-T970M<W1R96%M)R`@("`@(#T^("=B:6YA<GDN<&YG)RD["@H*+RHJ
M"B`J($1E9F%U;'0@=&5X="!D<FEV97(@<V5T=&EN9W,*("HO"B1M:6UE7V1R
M:79E<G-;)VAO<F1E)UU;)W-I;7!L92==6R=I;FQI;F4G72`]('1R=64["B1M
M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W-I;7!L92==6R=H86YD;&5S)UT@/2!A
M<G)A>2@*("`@("=T97AT+RHG*3L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG
M<VEM<&QE)UU;)VEC;VYS)UT@/2!A<G)A>2@*("`@("=D969A=6QT)R`]/B`G
M=&5X="YP;F<G*3L*"@HO*BH*("H@4&QA:6X@=&5X="!D<FEV97(@<V5T=&EN
M9W,*("HO"B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W!L86EN)UU;)VEN;&EN
M92==(#T@=')U93L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<&QA:6XG75LG
M:&%N9&QE<R==(#T@87)R87DH"B`@("`G=&5X="]P;&%I;B<I.PHD;6EM95]D
M<FEV97)S6R=H;W)D92==6R=P;&%I;B==6R=I8V]N<R==(#T@87)R87DH"B`@
M("`G9&5F875L="<@/3X@)W1E>'0N<&YG)RD["@H*+RHJ"B`J(%!(4"!D<FEV
M97(@<V5T=&EN9W,*("HO"B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W!H<"==
M6R=I;FQI;F4G72`]('1R=64["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W!H
M<"==6R=H86YD;&5S)UT@/2!A<G)A>2@*("`@("=A<'!L:6-A=&EO;B]X+7!H
M<"<L("=X+65X=&5N<VEO;B]P:'!S)RP*("`@("=X+65X=&5N<VEO;B]P:'`S
M<R<L("=A<'!L:6-A=&EO;B]X+6AT='!D+7!H<"<L"B`@("`G87!P;&EC871I
M;VXO>"UH='1P9"UP:'`S)RP@)V%P<&QI8V%T:6]N+W@M:'1T<&0M<&AP<R<I
M.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=P:'`G75LG:6-O;G,G72`](&%R
M<F%Y*`H@("`@)V1E9F%U;'0G(#T^("=P:'`N<&YG)RD["@H*+RHJ"B`J($-3
M4R!D<FEV97(@<V5T=&EN9W,*("HO"B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;
M)V-S<R==6R=I;FQI;F4G72`]('1R=64["B1M:6UE7V1R:79E<G-;)VAO<F1E
M)UU;)V-S<R==6R=H86YD;&5S)UT@/2!A<G)A>2@*("`@("=T97AT+V-S<R<L
M("=X+65X=&5N<VEO;B]C<W,G*3L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG
M8W-S)UU;)VEC;VYS)UT@/2!A<G)A>2@*("`@("=D969A=6QT)R`]/B`G:'1M
M;"YP;F<G*3L*"@HO*BH*("H@16YR:6-H960@=&5X="!D<FEV97(@<V5T=&EN
M9W,*("HO"B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)VAT;6PG75LG:6YL:6YE
M)UT@/2!F86QS93L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG:'1M;"==6R=H
M86YD;&5S)UT@/2!A<G)A>2@*("`@("=T97AT+VAT;6PG*3L*)&UI;65?9')I
M=F5R<ULG:&]R9&4G75LG:'1M;"==6R=I8V]N<R==(#T@87)R87DH"B`@("`G
M9&5F875L="<@/3X@)VAT;6PN<&YG)RD["@H*+RHJ"B`J($5N<FEC:&5D('1E
M>'0@9')I=F5R('-E='1I;F=S"B`J+PHD;6EM95]D<FEV97)S6R=H;W)D92==
M6R=E;G)I8VAE9"==6R=I;FQI;F4G72`]('1R=64["B1M:6UE7V1R:79E<G-;
M)VAO<F1E)UU;)V5N<FEC:&5D)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@
M)W1E>'0O96YR:6-H960G*3L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG96YR
M:6-H960G75LG:6-O;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G(#T^("=T
M97AT+G!N9R<I.PH*"B\J*@H@*B!2:6-H=&5X="!T97AT(&1R:79E<B!S971T
M:6YG<PH@*B\*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<FEC:'1E>'0G75LG
M:6YL:6YE)UT@/2!T<G5E.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=R:6-H
M=&5X="==6R=H86YD;&5S)UT@/2!A<G)A>2@*("`@("=T97AT+W)I8VAT97AT
M)RD["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W)I8VAT97AT)UU;)VEC;VYS
M)UT@/2!A<G)A>2@*("`@("=D969A=6QT)R`]/B`G=&5X="YP;F<G*3L*"@HO
M*BH*("H@5V5B($,@4&QU<R!0;'5S(&1R:79E<B!S971T:6YG<PH@*B!H='1P
M.B\O=V5B8W!P+G-O=7)C969O<F=E+FYE="\*("HO"B1M:6UE7V1R:79E<G-;
M)VAO<F1E)UU;)W=E8F-P<"==6R=L;V-A=&EO;B==(#T@)R]U<W(O8FEN+W=E
M8F-P<"<["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W=E8F-P<"==6R=I;FQI
M;F4G72`]('1R=64["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W=E8F-P<"==
M6R=H86YD;&5S)UT@/2!A<G)A>2@*("`@("=T97AT+WAM;"<L("=T97AT+W-G
M;6PG+"`G87!P;&EC871I;VXO>&UL)RP*("`@("=A<'!L:6-A=&EO;B]X+7-H
M)RP@)V%P<&QI8V%T:6]N+W@M:F%V87-C<FEP="<L("=A<'!L:6-A=&EO;B]X
M+71C;"<L"B`@("`G>"UE>'1E;G-I;VXO87-M)RP@)V%P<&QI8V%T:6]N+W@M
M87-P)RP@)W@M97AT96YS:6]N+V)A<R<L"B`@("`G>"UE>'1E;G-I;VXO8W,G
M+"`G=&5X="]X+6-S<F,G+"`G>"UE>'1E;G-I;VXO<F,G+`H@("`@)W1E>'0O
M>"UC*RMS<F,G+"`G=&5X="]X+6,K*W-R8R<L("=T97AT+W@M8RLK<W)C)RP*
M("`@("=T97AT+W@M8VAD<B<L("=X+65X=&5N<VEO;B]B870G+"`G=&5X="]X
M+69O<G1R86XG+`H@("`@)W@M97AT96YS:6]N+V8W-R<L("=X+65X=&5N<VEO
M;B]F.3`G+"`G>"UE>'1E;G-I;VXO9F]R)RP*("`@("=X+65X=&5N<VEO;B]F
M=&XG+"`G=&5X="]X+6IA=F$G+"`G87!P;&EC871I;VXO>"UJ879A<V-R:7!T
M)RP*("`@("=T97AT+W-G;6PG+"`G=&5X="]X;6PG+"`G=&5X="]X+7!A<V-A
M;"<L"B`@("`G87!P;&EC871I;VXO>"UC9VDG+"`G87!P;&EC871I;VXO>"UP
M97)L)RP@)V%P<&QI8V%T:6]N+W@M<'ET:&]N)RP*("`@("=T97AT+W@M<W%L
M)RP@)W1E>'0O>"UT8VPG+`H@("`@)V%P<&QI8V%T:6]N+W@M<VAE;&QS8W)I
M<'0G+"`G>"UE>'1E;G-I;VXO=FAD)RP@)W@M97AT96YS:6]N+W9H9&PG*3L*
M)&UI;65?9')I=F5R<ULG:&]R9&4G75LG=V5B8W!P)UU;)VEC;VYS)UT@/2!A
M<G)A>2@*("`@("=D969A=6QT)R`@("`@("`@("`@("`@("`@(#T^("=T97AT
M+G!N9R<L"B`@("`G=&5X="]X;6PG("`@("`@("`@("`@("`@("`]/B`G>&UL
M+G!N9R<L"B`@("`G=&5X="]X+6-S<F,G("`@("`@("`@("`@("`]/B`G<V]U
M<F-E+6,N<&YG)RP*("`@("=T97AT+W@M8VAD<B<@("`@("`@("`@("`@(#T^
M("=S;W5R8V4M:"YP;F<G+`H@("`@)W1E>'0O>"UJ879A)R`@("`@("`@("`@
M("`@/3X@)W-O=7)C92UJ879A+G!N9R<L"B`@("`G87!P;&EC871I;VXO>"UJ
M879A<V-R:7!T)R`]/B`G<V-R:7!T+6IS+G!N9R<I.PH*+RHJ"B`J(%-O=7)C
M92U(:6=H;&EG:'0@9')I=F5R('-E='1I;F=S"B`J(&AT='`Z+R]W=W<N9VYU
M+F]R9R]S;V9T=V%R92]S<F,M:&EG:&QI=&4O"B`J+PHD;6EM95]D<FEV97)S
M6R=H;W)D92==6R=S<F-H:6=H;&ET92==6R=L;V-A=&EO;B==(#T@)R]U<W(O
M8FEN+W-O=7)C92UH:6=H;&EG:'0G.PHD;6EM95]D<FEV97)S6R=H;W)D92==
M6R=S<F-H:6=H;&ET92==6R=I;FQI;F4G72`]('1R=64["B1M:6UE7V1R:79E
M<G-;)VAO<F1E)UU;)W-R8VAI9VAL:71E)UU;)VAA;F1L97,G72`](&%R<F%Y
M*`H@("`@)W1E>'0O>"UC<W)C)RP@)W1E>'0O>"UC*RMS<F,G+"`G=&5X="]X
M+6IA=F$G+`H@("`@)V%P<&QI8V%T:6]N+W@M<&5R;"<L("=A<'!L:6-A=&EO
M;B]X+7!Y=&AO;B<L("=T97AT+W@M8RLK<W)C)RP*("`@("=T97AT+V-P<"<I
M.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=S<F-H:6=H;&ET92==6R=I8V]N
M<R==(#T@87)R87DH"B`@("`G9&5F875L="<@("`@("`@("`@("`@("`@("`]
M/B`G=&5X="YP;F<G+`H@("`@)W1E>'0O>"UC<W)C)R`@("`@("`@("`@("`@
M/3X@)W-O=7)C92UC+G!N9R<L"B`@("`G=&5X="]X+6,K*W-R8R<@("`@("`@
M("`@("`]/B`G<V]U<F-E+6,N<&YG)RP*("`@("=T97AT+V-P<"<@("`@("`@
M("`@("`@("`@(#T^("=S;W5R8V4M8RYP;F<G+`H@("`@)W1E>'0O>"UJ879A
M)R`@("`@("`@("`@("`@/3X@)W-O=7)C92UJ879A+G!N9R<I.PH*+RHJ"B`J
M($=.52!%;G-C<FEP="!D<FEV97(@<V5T=&EN9W,*("HO"B1M:6UE7V1R:79E
M<G-;)VAO<F1E)UU;)V5N<V-R:7!T)UU;)VQO8V%T:6]N)UT@/2`G+W5S<B]B
M:6XO96YS8W)I<'0G.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=E;G-C<FEP
M="==6R=I;FQI;F4G72`]('1R=64["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;
M)V5N<V-R:7!T)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@)V%P<&QI8V%T
M:6]N+W@M8V=I)RP@)V%P<&QI8V%T:6]N+W@M<VAE;&QS8W)I<'0G+"`G87!P
M;&EC871I;VXO>"UJ879A<V-R:7!T)RP*("`@("=A<'!L:6-A=&EO;B]X+7!E
M<FPG+"`G87!P;&EC871I;VXO>&UL)RP@)W1E>'0O>&UL)RP*("`@("=T97AT
M+V1I9F8G+"`G=&5X="]X+61I9F8G+"`G=&5X="]X+7!A=&-H)RP@)W1E>'0O
M>"UC<W)C)RP*("`@("=X+65X=&5N<VEO;B]C<R<L("=T97AT+W@M:F%V82<L
M("=T97AT+W@M8VAD<B<L("=T97AT+W@M8RLK<W)C)RP*("`@("=T97AT+W@M
M8RLK:&1R)RP@)W@M97AT96YS:6]N+W9H9"<L("=X+65X=&5N<VEO;B]V:&1L
M)RP@)W1E>'0O>"US<6PG+`H@("`@)W@M97AT96YS:6]N+W9B)RP@)W@M97AT
M96YS:6]N+W9B82<L("=T97AT+W@M96UA8W,M;&ES<"<L("=T97AT+W@M=&5X
M)RD["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)V5N<V-R:7!T)UU;)VEC;VYS
M)UT@/2!A<G)A>2@*("`@("=D969A=6QT)R`@("`@("`@("`@("`@("`@(#T^
M("=T97AT+G!N9R<L"B`@("`G=&5X="]X;6PG("`@("`@("`@("`@("`@("`]
M/B`G>&UL+G!N9R<L"B`@("`G87!P;&EC871I;VXO>&UL)R`@("`@("`@("`]
M/B`G>&UL+G!N9R<L"B`@("`G=&5X="]X+6-S<F,G("`@("`@("`@("`@("`]
M/B`G<V]U<F-E+6,N<&YG)RP*("`@("=T97AT+W@M8VAD<B<@("`@("`@("`@
M("`@(#T^("=S;W5R8V4M:"YP;F<G+`H@("`@)W1E>'0O>"UJ879A)R`@("`@
M("`@("`@("`@/3X@)W-O=7)C92UJ879A+G!N9R<L"B`@("`G87!P;&EC871I
M;VXO>"UJ879A<V-R:7!T)R`]/B`G<V-R:7!T+6IS+G!N9R<I.PH*"B\J*@H@
M*B!487(@9')I=F5R('-E='1I;F=S"B`J(%1O(&%C8V5S<R!G>FEP<&5D(&9I
M;&5S+"!T:&4@>FQI8B!L:6)R87)Y(&UU<W0@:&%V92!B965N(&)U:6QT(&EN
M=&\@4$A0"B`J("AW:71H('1H92`M+7=I=&@M>FQI8B!O<'1I;VXI+@H@*B\*
M)&UI;65?9')I=F5R<ULG:&]R9&4G75LG=&=Z)UU;)VEN;&EN92==(#T@=')U
M93L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG=&=Z)UU;)VAA;F1L97,G72`]
M(&%R<F%Y*`H@("`@)V%P<&QI8V%T:6]N+W@M8V]M<')E<W-E9"UT87(G+`H@
M("`@)V%P<&QI8V%T:6]N+W@M=&%R)RP*("`@("=A<'!L:6-A=&EO;B]X+71G
M>B<L"B`@("`G87!P;&EC871I;VXO>"UG>FEP)RP*("`@("=A<'!L:6-A=&EO
M;B]X+6=T87(G+`H@("`@)V%P<&QI8V%T:6]N+V=Z:7`G+`H@("`@)V%P<&QI
M8V%T:6]N+W@M9WII<"UC;VUP<F5S<V5D)RD["B1M:6UE7V1R:79E<G-;)VAO
M<F1E)UU;)W1G>B==6R=I8V]N<R==(#T@87)R87DH"B`@("`G9&5F875L="<@
M/3X@)V-O;7!R97-S960N<&YG)RD["@H*+RHJ"B`J(%II<"!F:6QE(&1R:79E
M<B!S971T:6YG<PH@*B\*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG>FEP)UU;
M)VEN;&EN92==(#T@=')U93L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG>FEP
M)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@)V%P<&QI8V%T:6]N+WII<"<L
M"B`@("`G87!P;&EC871I;VXO>"UC;VUP<F5S<V5D)RP*("`@("=A<'!L:6-A
M=&EO;B]X+7II<"UC;VUP<F5S<V5D)RD["B1M:6UE7V1R:79E<G-;)VAO<F1E
M)UU;)WII<"==6R=I8V]N<R==(#T@87)R87DH"B`@("`G9&5F875L="<@/3X@
M)V-O;7!R97-S960N<&YG)RD["@H*+RHJ"B`J(%)!4B!A<F-H:79E(&1R:79E
M<B!S971T:6YG<PH@*B\*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<F%R)UU;
M)VEN;&EN92==(#T@=')U93L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<F%R
M)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@)V%P<&QI8V%T:6]N+W@M<F%R
M)RP*("`@("=A<'!L:6-A=&EO;B]X+7)A<BUC;VUP<F5S<V5D)RD["B1M:6UE
M7V1R:79E<G-;)VAO<F1E)UU;)W)A<B==6R=I8V]N<R==(#T@87)R87DH"B`@
M("`G9&5F875L="<@/3X@)V-O;7!R97-S960N<&YG)RD["@H*+RHJ"B`J($U3
M(%=O<F0@9')I=F5R('-E='1I;F=S"B`J(%1H:7,@9')I=F5R(')E<75I<F5S
M('=V5V%R92!T;R!B92!I;G-T86QL960N"B`J('=V5V%R92!H;VUE<&%G93H@
M:'1T<#HO+W=V=V%R92YS;W5R8V5F;W)G92YN970O"B`J"B`J(%1H92`G;&]C
M871I;VXG(&5N=')Y('-H;W5L9"!P;VEN="!T;R!T:&4@)W=V2'1M;"<@<')O
M9W)A;2P@3D]4('1H90H@*B`G=W9787)E)R!P<F]G<F%M+@H@*B\*)&UI;65?
M9')I=F5R<ULG:&]R9&4G75LG;7-W;W)D)UU;)VQO8V%T:6]N)UT@/2`G+W5S
M<B]B:6XO=W9(=&UL)SL*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG;7-W;W)D
M)UU;)VEN;&EN92==(#T@9F%L<V4["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;
M)VUS=V]R9"==6R=H86YD;&5S)UT@/2!A<G)A>2@*("`@("=A<'!L:6-A=&EO
M;B]V;F0N;7,M=V]R9"<L"B`@("`G87!P;&EC871I;VXO;7-W;W)D)RP**3L*
M)&UI;65?9')I=F5R<ULG:&]R9&4G75LG;7-W;W)D)UU;)VEC;VYS)UT@/2!A
M<G)A>2@*("`@("=D969A=6QT)R`]/B`G;7-W;W)D+G!N9R<L"BD["@H*+RHJ
M"B`J($U3($5X8V5L(&1R:79E<B!S971T:6YG<PH@*B!4:&ES(&1R:79E<B!R
M97%U:7)E<R!X;&AT;6P@=&\@8F4@:6YS=&%L;&5D+@H@*B!X;&AT;6P@:&]M
M97!A9V4Z(&AT='`Z+R]C:&EC86=O+G-O=7)C969O<F=E+FYE="]X;&AT;6PO
M"B`J+PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=M<V5X8V5L)UU;)VQO8V%T
M:6]N)UT@/2`G+W5S<B]L;V-A;"]B:6XO>&QH=&UL)SL*)&UI;65?9')I=F5R
M<ULG:&]R9&4G75LG;7-E>&-E;"==6R=I;FQI;F4G72`](&9A;'-E.PHD;6EM
M95]D<FEV97)S6R=H;W)D92==6R=M<V5X8V5L)UU;)VAA;F1L97,G72`](&%R
M<F%Y*`H@("`@)V%P<&QI8V%T:6]N+W9N9"YM<RUE>&-E;"<L"B`@("`G87!P
M;&EC871I;VXO;7-E>&-E;"<L"B`@("`G87!P;&EC871I;VXO>"UM<V5X8V5L
M)RD["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)VUS97AC96PG75LG:6-O;G,G
M72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G(#T^("=M<V5X8V5L+G!N9R<I.PH*
M"B\J*@H@*B!-4R!0;W=E<G!O:6YT(&1R:79E<B!S971T:6YG<PH@*B!4:&ES
M(&1R:79E<B!R97%U:7)E<R!P<'1H=&UL+"!I;F-L=61E9"!W:71H('AL:'1M
M;"P@=&\@8F4@:6YS=&%L;&5D+@H@*B!X;&AT;6P@:&]M97!A9V4Z(&AT='`Z
M+R]C:&EC86=O+G-O=7)C969O<F=E+FYE="]X;&AT;6PO"B`J+PHD;6EM95]D
M<FEV97)S6R=H;W)D92==6R=M<W!O=V5R<&]I;G0G75LG;&]C871I;VXG72`]
M("<O=7-R+VQO8V%L+V)I;B]P<'1H=&UL)SL*)&UI;65?9')I=F5R<ULG:&]R
M9&4G75LG;7-P;W=E<G!O:6YT)UU;)VEN;&EN92==(#T@9F%L<V4["B1M:6UE
M7V1R:79E<G-;)VAO<F1E)UU;)VUS<&]W97)P;VEN="==6R=H86YD;&5S)UT@
M/2!A<G)A>2@*("`@("=A<'!L:6-A=&EO;B]V;F0N;7,M<&]W97)P;VEN="<L
M"B`@("`G87!P;&EC871I;VXO;7-P;W=E<G!O:6YT)RD["B1M:6UE7V1R:79E
M<G-;)VAO<F1E)UU;)VUS<&]W97)P;VEN="==6R=I8V]N<R==(#T@87)R87DH
M"B`@("`G9&5F875L="<@/3X@)VUS<&]W97)P;VEN="YP;F<G*3L*"@HO*BH*
M("H@=D-A<F0@9')I=F5R('-E='1I;F=S"B`J+PHD;6EM95]D<FEV97)S6R=H
M;W)D92==6R=V8V%R9"==6R=H86YD;&5S)UT@/2!A<G)A>2@*("`@("=T97AT
M+W@M=F-A<F0G+`H@("`@)W1E>'0O>"UV8V%L96YD87(G*3L*)&UI;65?9')I
M=F5R<ULG:&]R9&4G75LG=F-A<F0G75LG:6-O;G,G72`](&%R<F%Y*`H@("`@
M)V1E9F%U;'0G(#T^("=V8V%R9"YP;F<G*3L*"@HO*BH*("H@4E!-(&1R:79E
M<B!S971T:6YG<PH@*B\*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<G!M)UU;
M)VQO8V%T:6]N)UT@/2`G+W5S<B]B:6XO<G!M)SL*)&UI;65?9')I=F5R<ULG
M:&]R9&4G75LG<G!M)UU;)VEN;&EN92==(#T@9F%L<V4["B1M:6UE7V1R:79E
M<G-;)VAO<F1E)UU;)W)P;2==6R=H86YD;&5S)UT@/2!A<G)A>2@*("`@("=A
M<'!L:6-A=&EO;B]X+7)P;2<I.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=R
M<&TG75LG:6-O;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G(#T^("=R<&TN
M<&YG)RD["@H*+RHJ"B`J($1E8FEA;B!P86-K86=E(&1R:79E<B!S971T:6YG
M<PH@*B\*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG9&5B)UU;)VQO8V%T:6]N
M)UT@/2`G+W5S<B]B:6XO9'!K9R<["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;
M)V1E8B==6R=I;FQI;F4G72`](&9A;'-E.PHD;6EM95]D<FEV97)S6R=H;W)D
M92==6R=D96(G75LG:&%N9&QE<R==(#T@87)R87DH"B`@("`G87!P;&EC871I
M;VXO>"UD96(G+`H@("`@)V%P<&QI8V%T:6]N+W@M9&5B:6%N+7!A8VMA9V4G
M*3L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG9&5B)UU;)VEC;VYS)UT@/2!A
M<G)A>2@*("`@("=D969A=6QT)R`]/B`G9&5B+G!N9R<I.PH*"B\J*@H@*B!3
M96-U<F4@;75L=&EP87)T<R`H4D9#(#$X-#<I"B`J+PHD;6EM95]D<FEV97)S
M6R=H;W)D92==6R=S96-U<FET>2==6R=I;FQI;F4G72`]('1R=64["B1M:6UE
M7V1R:79E<G-;)VAO<F1E)UU;)W-E8W5R:71Y)UU;)VAA;F1L97,G72`](&%R
M<F%Y*`H@("`@)VUU;'1I<&%R="]E;F-R>7!T960G+"`G;75L=&EP87)T+W-I
M9VYE9"<I.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=S96-U<FET>2==6R=I
M8V]N<R==(#T@87)R87DH"B`@("`G9&5F875L="<@/3X@)V5N8W)Y<'1I;VXN
M<&YG)RD["@H*+RHJ"B`J($EM86=E('-E='1I;F=S"B`J+PHD;6EM95]D<FEV
M97)S6R=H;W)D92==6R=I;6%G97,G75LG:6YL:6YE)UT@/2!F86QS93L*)&UI
M;65?9')I=F5R<ULG:&]R9&4G75LG:6UA9V5S)UU;)VAA;F1L97,G72`](&%R
M<F%Y*`H@("`@)VEM86=E+RHG*3L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG
M:6UA9V5S)UU;)VEC;VYS)UT@/2!A<G)A>2@*("`@("=D969A=6QT)R`]/B`G
M:6UA9V4N<&YG)RD["@H*+RHJ"B`J($U3+51.148@071T86-H;65N="`H87!P
M;&EC871I;VXO;7,M=&YE9BD@<V5T=&EN9W,*("HO"B1M:6UE7V1R:79E<G-;
M)VAO<F1E)UU;)W1N968G75LG:6YL:6YE)UT@/2!F86QS93L*)&UI;65?9')I
M=F5R<ULG:&]R9&4G75LG=&YE9B==6R=H86YD;&5S)UT@/2!A<G)A>2@*("`@
M("=A<'!L:6-A=&EO;B]M<RUT;F5F)RD["B1M:6UE7V1R:79E<G-;)VAO<F1E
M)UU;)W1N968G75LG:6-O;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G(#T^
M("=T97AT+G!N9R<I.PH*"B\J*@H@*B!$:6=E<W0@;65S<V%G92`H4D9#(#(P
M-#8@6S4N,BXQ72D@<V5T=&EN9W,*("HO"B1M:6UE7V1R:79E<G-;)VAO<F1E
M)UU;)W)F8S@R,B==6R=I;FQI;F4G72`](&9A;'-E.PHD;6EM95]D<FEV97)S
M6R=H;W)D92==6R=R9F,X,C(G75LG:&%N9&QE<R==(#T@87)R87DH"B`@("`G
M;65S<V%G92]R9F,X,C(G+`H@("`@)W@M97AT96YS:6]N+V5M;"<I.PHD;6EM
M95]D<FEV97)S6R=H;W)D92==6R=R9F,X,C(G75LG:6-O;G,G72`](&%R<F%Y
M*`H@("`@)V1E9F%U;'0G(#T^("=M86EL+G!N9R<I.PH*"B\J*@H@*B!297!O
M<G0@;65S<V%G97,@*%)&0R`S-#4R*0H@*B\*)&UI;65?9')I=F5R<ULG:&]R
M9&4G75LG<F5P;W)T)UU;)VEN;&EN92==(#T@=')U93L*)&UI;65?9')I=F5R
M<ULG:&]R9&4G75LG<F5P;W)T)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@
M)VUU;'1I<&%R="]R97!O<G0G*3L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG
M<F5P;W)T)UU;)VEC;VYS)UT@/2!A<G)A>2@*("`@("=D969A=6QT)R`]/B`G
M;6%I;"YP;F<G*3L*"@HO*BH*("H@3W!E;D]F9FEC92YO<F<O4W1A<D]F9FEC
M92!S971T:6YG<PH@*B\*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG;V]O)UU;
M)VEN;&EN92==(#T@9F%L<V4["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)V]O
M;R==6R=H86YD;&5S)UT@/2!A<G)A>2@*("`@("=A<'!L:6-A=&EO;B]V;F0N
M<W5N+GAM;"YC86QC)RP*("`@("=A<'!L:6-A=&EO;B]V;F0N<W5N+GAM;"YC
M86QC+G1E;7!L871E)RP*("`@("=A<'!L:6-A=&EO;B]V;F0N<W5N+GAM;"YD
M<F%W)RP*("`@("=A<'!L:6-A=&EO;B]V;F0N<W5N+GAM;"YD<F%W+G1E;7!L
M871E)RP*("`@("=A<'!L:6-A=&EO;B]V;F0N<W5N+GAM;"YI;7!R97-S)RP*
M("`@("=A<'!L:6-A=&EO;B]V;F0N<W5N+GAM;"YI;7!R97-S+G1E;7!L871E
M)RP*("`@("=A<'!L:6-A=&EO;B]V;F0N<W5N+GAM;"YM871H)RP*("`@("=A
M<'!L:6-A=&EO;B]V;F0N<W5N+GAM;"YW<FET97(G+`H@("`@)V%P<&QI8V%T
M:6]N+W9N9"YS=6XN>&UL+G=R:71E<BYG;&]B86PG+`H@("`@)V%P<&QI8V%T
M:6]N+W9N9"YS=6XN>&UL+G=R:71E<BYT96UP;&%T92<L"B`@("`G87!P;&EC
M871I;VXO=FYD+G-T87)D:79I<VEO;BYC86QC)RP*("`@("=A<'!L:6-A=&EO
M;B]V;F0N<W1A<F1I=FES:6]N+F1R87<G+`H@("`@)V%P<&QI8V%T:6]N+W9N
M9"YS=&%R9&EV:7-I;VXN:6UP<F5S<R<L"B`@("`G87!P;&EC871I;VXO=FYD
M+G-T87)D:79I<VEO;BYM871H)RP*("`@("=A<'!L:6-A=&EO;B]V;F0N<W1A
M<F1I=FES:6]N+G=R:71E<B<I.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=O
M;V\G75LG:6-O;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G(#T^("=O;V]?
M8V%L8RYP;F<G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL+F-A;&,G
M("`@("`@("`@("`@(#T^("=O;V]?8V%L8RYP;F<G+`H@("`@)V%P<&QI8V%T
M:6]N+W9N9"YS=&%R9&EV:7-I;VXN8V%L8R<@("`@("`@(#T^("=O;V]?8V%L
M8RYP;F<G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL+F-A;&,N=&5M
M<&QA=&4G("`@(#T^("=O;V]?8V%L8RYP;F<G+`H@("`@)V%P<&QI8V%T:6]N
M+W9N9"YS=6XN>&UL+F1R87<G("`@("`@("`@("`@(#T^("=O;V]?9')A=RYP
M;F<G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS=&%R9&EV:7-I;VXN9')A=R<@
M("`@("`@(#T^("=O;V]?9')A=RYP;F<G+`H@("`@)V%P<&QI8V%T:6]N+W9N
M9"YS=6XN>&UL+F1R87<N=&5M<&QA=&4G("`@(#T^("=O;V]?9')A=RYP;F<G
M+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL+FEM<')E<W,G("`@("`@
M("`@(#T^("=O;V]?:6UP<F5S<RYP;F<G+`H@("`@)V%P<&QI8V%T:6]N+W9N
M9"YS=&%R9&EV:7-I;VXN:6UP<F5S<R<@("`@(#T^("=O;V]?:6UP<F5S<RYP
M;F<G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL+FEM<')E<W,N=&5M
M<&QA=&4G(#T^("=O;V]?:6UP<F5S<RYP;F<G+`H@("`@)V%P<&QI8V%T:6]N
M+W9N9"YS=6XN>&UL+FUA=&@G("`@("`@("`@("`@(#T^("=O;V]?;6%T:"YP
M;F<G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS=&%R9&EV:7-I;VXN;6%T:"<@
M("`@("`@(#T^("=O;V]?;6%T:"YP;F<G+`H@("`@)V%P<&QI8V%T:6]N+W9N
M9"YS=6XN>&UL+G=R:71E<B<@("`@("`@("`@(#T^("=O;V]?=W)I=&5R+G!N
M9R<L"B`@("`G87!P;&EC871I;VXO=FYD+G-T87)D:79I<VEO;BYW<FET97(G
M("`@("`@/3X@)V]O;U]W<FET97(N<&YG)RP*("`@("=A<'!L:6-A=&EO;B]V
M;F0N<W5N+GAM;"YW<FET97(N9VQO8F%L)R`@("`]/B`G;V]O7W=R:71E<BYP
M;F<G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL+G=R:71E<BYT96UP
M;&%T92<@(#T^("=O;V]?=W)I=&5R+G!N9R<I.PH*"B\J*@H@*B!0;W)T86)L
M92!$;V-U;65N="!&;W)M870@*%!$1BD@9FEL97,*("H@64]5(%-(3U5,1"!.
M3U0@3D]234%,3%D@04Q415(@5$A)4R!3151424Y'+@H@*B\*)&UI;65?9')I
M=F5R<ULG:&]R9&4G75LG<&1F)UU;)VEN;&EN92==(#T@9F%L<V4["B1M:6UE
M7V1R:79E<G-;)VAO<F1E)UU;)W!D9B==6R=H86YD;&5S)UT@/2!A<G)A>2@*
M("`@("=A<'!L:6-A=&EO;B]P9&8G*3L*)&UI;65?9')I=F5R<ULG:&]R9&4G
M75LG<&1F)UU;)VEC;VYS)UT@/2!A<G)A>2@*("`@("=D969A=6QT)R`]/B`G
M<&1F+G!N9R<I.PH`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O971C+W!S82UH;W)D92]H;W)D92]M;W1D+G!H<```````````````
M````````````````````````````````````````````````````````````
M```P,#`T-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#0S,"`Q,#4Q-30S
M,S<U-"`P,C$P-C4`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/"$M+2!4:&ES(&9I;&4@8V]N=&%I;G,@86YY(")-97-S86=E
M($]F(%1H92!$87DB(%1Y<&4@:6YF;W)M871I;VX@+2T^"CPA+2T@270@=VEL
M;"!B92!I;F-L=61E9"!B96QO=R!T:&4@;&]G+6EN(&9O<FT@;VX@=&AE(&QO
M9VEN('!A9V4N("TM/@H*/&)R("\^"CQT86)L92!W:61T:#TB,3`P)2(^/'1R
M/CQT9"!A;&EG;CTB8V5N=&5R(CX\:6UG('-R8STB=&AE;65S+V=R87!H:6-S
M+VAO<F1E+7!O=V5R,2YP;F<B(&%L=#TB4&]W97)E9"!B>2!(;W)D92(@+SX\
M+W1D/CPO='(^/"]T86)L93X*"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+V5T8R]P
M<V$M:&]R9&4O:&]R9&4O;FQS+G!H<```````````````````````````````
M````````````````````````````````````````````````,#`P-#0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P-C`P,S0@,3`U,34T,S,W-30@,#(P-S(T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B!.3%,@*$YA=&EO;F%L($QA;F=U86=E(%-U<'!O<G0I(&-O
M;F9I9W5R871I;VX@9FEL92X*("H*("H@)$AO<F1E.B!H;W)D92]C;VYF:6<O
M;FQS+G!H<"YD:7-T+'8@,2XU.2XQ,"XW(#(P,#8O,#0O,3D@,C,Z,S8Z,C(@
M:F%N($5X<"`D"B`J+PH*+RHJ"B`J*B!$969A=6QT<PH@*BHO"@HO*B!4:&4@
M;&%N9W5A9V4@=&\@9F%L;"!B86-K(&]N(&EF('=E(&-A;FYO="!D971E<FUI
M;F4@;VYE(&%N>2!O=&AE<@H@("!W87D@*'5S97(@8VAO:6-E(&]R('!R969E
M<F5N8V5S*2X@268@96UP='DL('=E('=I;&P@=')Y('1O(&YE9V]T:6%T90H@
M("!W:71H('1H92!B<F]W<V5R('5S:6YG($A45%!?04-#15!47TQ!3D=504=%
M+B`J+PHD;FQS6R=D969A=6QT<R==6R=L86YG=6%G92==(#T@)R<["@H*+RHJ
M"B`J*B!,86YG=6%G90H@*BHO"@HD;FQS6R=L86YG=6%G97,G75LG87)?3TTG
M72`]("=!<F%B:6,@*$]M86XI("@F(W@P-C(W.R8C>#`V-#0[)B-X,#8S.3LF
M(W@P-C,Q.R8C>#`V,C@[)B-X,#8T83LF(W@P-C(Y.RDG.PHD;FQS6R=L86YG
M=6%G97,G75LG87)?4UDG72`]("=!<F%B:6,@*%-Y<FEA*2`H)B-X,#8R-SLF
M(W@P-C0T.R8C>#`V,SD[)B-X,#8S,3LF(W@P-C(X.R8C>#`V-&$[)B-X,#8R
M.3LI)SL*)&YL<ULG;&%N9W5A9V5S)UU;)VED7TE$)UT@/2`G0F%H87-A($EN
M9&]N97-I82<["B1N;'-;)VQA;F=U86=E<R==6R=B<U]"02==(#T@)T)O<V%N
M<VMI)SL*)&YL<ULG;&%N9W5A9V5S)UU;)V)G7T)')UT@/2`G0G5L9V%R:6%N
M("@F(W@P-#$Q.R8C>#`T-&$[)B-X,#0S8CLF(W@P-#,S.R8C>#`T,S`[)B-X
M,#0T,#LF(W@P-#0Q.R8C>#`T,V$[)B-X,#0S.#LI)SL*)&YL<ULG;&%N9W5A
M9V5S)UU;)V-A7T53)UT@/2`G0V%T86PF86=R879E.R<["B1N;'-;)VQA;F=U
M86=E<R==6R=Z:%]#3B==(#T@)T-H:6YE<V4@*%-I;7!L:69I960I("@F(W@W
M8C@P.R8C>#1F-3,[)B-X-&4R9#LF(W@V-3@W.RDG.PHD;FQS6R=L86YG=6%G
M97,G75LG>FA?5%<G72`]("=#:&EN97-E("A4<F%D:71I;VYA;"D@*"8C>#9B
M-C,[)B-X.6%D-#LF(W@T93)D.R8C>#8U.#<[*2<["B1N;'-;)VQA;F=U86=E
M<R==6R=C<U]#6B==(#T@)T-Z96-H("@F(W@P,3!C.V5S:WDI)SL*)&YL<ULG
M;&%N9W5A9V5S)UU;)V1A7T1+)UT@/2`G1&%N<VLG.PHD;FQS6R=L86YG=6%G
M97,G75LG9&5?1$4G72`]("=$975T<V-H)SL*)&YL<ULG;&%N9W5A9V5S)UU;
M)V5N7U53)UT@/2`G16YG;&ES:"`H06UE<FEC86XI)SL*)&YL<ULG;&%N9W5A
M9V5S)UU;)V5N7T=")UT@/2`G16YG;&ES:"`H0G)I=&ES:"DG.PHD;FQS6R=L
M86YG=6%G97,G75LG96Y?0T$G72`]("=%;F=L:7-H("A#86YA9&EA;BDG.PHD
M;FQS6R=L86YG=6%G97,G75LG97-?15,G72`]("=%<W!A)FYT:6QD93MO;"<[
M"B1N;'-;)VQA;F=U86=E<R==6R=E=%]%12==(#T@)T5E<W1I)SL*)&YL<ULG
M;&%N9W5A9V5S)UU;)V9R7T92)UT@/2`G1G)A;B9C8V5D:6P[86ES)SL*)&YL
M<ULG;&%N9W5A9V5S)UU;)V=L7T53)UT@/2`G1V%L96=O)SL*)&YL<ULG;&%N
M9W5A9V5S)UU;)V5L7T=2)UT@/2`G1W)E96L@*"8C>#`S.34[)B-X,#-B8CLF
M(W@P,V)B.R8C>#`S8C<[)B-X,#-B9#LF(W@P,V(Y.R8C>#`S8F$[)B-X,#-A
M8SLI)SL*)&YL<ULG;&%N9W5A9V5S)UU;)VAE7TE,)UT@/2`G2&5B<F5W("@F
M(W@P-44R.R8C>#`U1#$[)B-X,#5%.#LF(W@P-40Y.R8C>#`U14$[*2<["B1N
M;'-;)VQA;F=U86=E<R==6R=I<U])4R==(#T@)R9)86-U=&4[<VQE;G-K82<[
M"B1N;'-;)VQA;F=U86=E<R==6R=I=%])5"==(#T@)TET86QI86YO)SL*)&YL
M<ULG;&%N9W5A9V5S)UU;)VIA7TI0)UT@/2`G2F%P86YE<V4@*"8C>#8U934[
M)B-X-C<R8SLF(W@X83EE.RDG.PHD;FQS6R=L86YG=6%G97,G75LG:VU?2T@G
M72`]("=+:&UE<B`H)B-X,3<X,3LF(W@Q-V0R.R8C>#$W.3@[)B-X,3=C,CLF
M(W@Q-SEA.RDG.PHD;FQS6R=L86YG=6%G97,G75LG:V]?2U(G72`]("=+;W)E
M86X@*"8C>&0U-6,[)B-X860V9#LF(WAC-6(T.RDG.PHD;FQS6R=L86YG=6%G
M97,G75LG;'9?3%8G72`]("=,871V:64F(W@P,38Q.W4G.PHD;FQS6R=L86YG
M=6%G97,G75LG;'1?3%0G72`]("=,:65T=79I)B-X,#$W,SLG.PHD;FQS6R=L
M86YG=6%G97,G75LG;6M?34LG72`]("=-86-E9&]N:6%N("@F(W@P-#%C.R8C
M>#`T,S`[)B-X,#0S83LF(W@P-#,U.R8C>#`T,S0[)B-X,#0S93LF(W@P-#-D
M.R8C>#`T-#$[)B-X,#0S83LF(W@P-#,X.RDG.PHD;FQS6R=L86YG=6%G97,G
M75LG:'5?2%4G72`]("=-86=Y87(G.PHD;FQS6R=L86YG=6%G97,G75LG;FQ?
M3DPG72`]("=.961E<FQA;F1S)SL*)&YL<ULG;&%N9W5A9V5S)UU;)VYB7TY/
M)UT@/2`G3F]R<VL@8F]K;29A<FEN9SML)SL*)&YL<ULG;&%N9W5A9V5S)UU;
M)VYN7TY/)UT@/2`G3F]R<VL@;GEN;W)S:R<["B1N;'-;)VQA;F=U86=E<R==
M6R=F85])4B==(#T@)U!E<G-I86X@*"8C>#`V-#$[)B-X,#8R-SLF(W@P-C,Q
M.R8C>#`V,S,[)B-X,#8T.3LI)SL*)&YL<ULG;&%N9W5A9V5S)UU;)W!L7U!,
M)UT@/2`G4&]L<VMI)SL*)&YL<ULG;&%N9W5A9V5S)UU;)W!T7U!4)UT@/2`G
M4&]R='5G=29E8VER8SMS)SL*)&YL<ULG;&%N9W5A9V5S)UU;)W!T7T)2)UT@
M/2`G4&]R='5G=29E8VER8SMS($)R87-I;&5I<F\G.PHD;FQS6R=L86YG=6%G
M97,G75LG<F]?4D\G72`]("=2;VTF86-I<F,[;B9A=6UL.R<["B1N;'-;)VQA
M;F=U86=E<R==6R=R=5]252==(#T@)U)U<W-I86X@*"8C>#`T,C`[)B-X,#0T
M,SLF(W@P-#0Q.R8C>#`T-#$[)B-X,#0S83LF(W@P-#,X.R8C>#`T,SD[*2<[
M"B1N;'-;)VQA;F=U86=E<R==6R=S:U]32R==(#T@)U-L;W9A:R`H4VQO=F5N
M)B-X,#$P9#MI;F$I)SL*)&YL<ULG;&%N9W5A9V5S)UU;)W-L7U-))UT@/2`G
M4VQO=F5N:6%N("A3;&]V96XF(W@P,38Q.R8C>#`Q,&0[:6YA*2<["B1N;'-;
M)VQA;F=U86=E<R==6R=F:5]&22==(#T@)U-U;VUI)SL*)&YL<ULG;&%N9W5A
M9V5S)UU;)W-V7U-%)UT@/2`G4W9E;G-K82<["B1N;'-;)VQA;F=U86=E<R==
M6R=T:%]42"==(#T@)U1H86D@*"8C>#!E-#0[)B-X,&4Q-SLF(W@P93(R.RDG
M.PHD;FQS6R=L86YG=6%G97,G75LG=')?5%(G72`]("=4)G5U;6P[<FLF8V-E
M9&EL.V4G.PHD;FQS6R=L86YG=6%G97,G75LG=6M?54$G72`]("=5:W)A:6YI
M86X@*"8C>#`T,C,[)B-X,#0S83LF(W@P-#0P.R8C>#`T,S`[)B-X,#0U-SLF
M(W@P-#-D.R8C>#`T-#$[)B-X,#0T8SLF(W@P-#-A.R8C>#`T,S`[*2<["@H*
M+RHJ"B`J*B!!;&EA<V5S(&9O<B!L86YG=6%G97,@=VET:"!D:69F97)E;G0@
M8G)O=W-E<B!A;F0@9V5T=&5X="!C;V1E<PH@*BHO"@HD;FQS6R=A;&EA<V5S
M)UU;)V%R)UT@/2`G87)?4UDG.PHD;FQS6R=A;&EA<V5S)UU;)V)G)UT@/2`G
M8F=?0D<G.PHD;FQS6R=A;&EA<V5S)UU;)V)S)UT@/2`G8G-?0D$G.PHD;FQS
M6R=A;&EA<V5S)UU;)V-A)UT@/2`G8V%?15,G.PHD;FQS6R=A;&EA<V5S)UU;
M)V-S)UT@/2`G8W-?0UHG.PHD;FQS6R=A;&EA<V5S)UU;)V1A)UT@/2`G9&%?
M1$LG.PHD;FQS6R=A;&EA<V5S)UU;)V1E)UT@/2`G9&5?1$4G.PHD;FQS6R=A
M;&EA<V5S)UU;)V5L)UT@/2`G96Q?1U(G.PHD;FQS6R=A;&EA<V5S)UU;)V5N
M)UT@/2`G96Y?55,G.PHD;FQS6R=A;&EA<V5S)UU;)V5S)UT@/2`G97-?15,G
M.PHD;FQS6R=A;&EA<V5S)UU;)V5T)UT@/2`G971?144G.PHD;FQS6R=A;&EA
M<V5S)UU;)V9A)UT@/2`G9F%?25(G.PHD;FQS6R=A;&EA<V5S)UU;)V9I)UT@
M/2`G9FE?1DDG.PHD;FQS6R=A;&EA<V5S)UU;)V9R)UT@/2`G9G)?1E(G.PHD
M;FQS6R=A;&EA<V5S)UU;)V=L)UT@/2`G9VQ?15,G.PHD;FQS6R=A;&EA<V5S
M)UU;)VAE)UT@/2`G:&5?24PG.PHD;FQS6R=A;&EA<V5S)UU;)VAU)UT@/2`G
M:'5?2%4G.PHD;FQS6R=A;&EA<V5S)UU;)VED)UT@/2`G:61?240G.PHD;FQS
M6R=A;&EA<V5S)UU;)VES)UT@/2`G:7-?25,G.PHD;FQS6R=A;&EA<V5S)UU;
M)VET)UT@/2`G:71?250G.PHD;FQS6R=A;&EA<V5S)UU;)VIA)UT@/2`G:F%?
M2E`G.PHD;FQS6R=A;&EA<V5S)UU;)VMM)UT@/2`G:VU?2T@G.PHD;FQS6R=A
M;&EA<V5S)UU;)VMO)UT@/2`G:V]?2U(G.PHD;FQS6R=A;&EA<V5S)UU;)VQT
M)UT@/2`G;'1?3%0G.PHD;FQS6R=A;&EA<V5S)UU;)VQV)UT@/2`G;'9?3%8G
M.PHD;FQS6R=A;&EA<V5S)UU;)VUK)UT@/2`G;6M?34LG.PHD;FQS6R=A;&EA
M<V5S)UU;)VYL)UT@/2`G;FQ?3DPG.PHD;FQS6R=A;&EA<V5S)UU;)VYN)UT@
M/2`G;FY?3D\G.PHD;FQS6R=A;&EA<V5S)UU;)VYO)UT@/2`G;F)?3D\G.PHD
M;FQS6R=A;&EA<V5S)UU;)W!L)UT@/2`G<&Q?4$PG.PHD;FQS6R=A;&EA<V5S
M)UU;)W!T)UT@/2`G<'1?4%0G.PHD;FQS6R=A;&EA<V5S)UU;)W)O)UT@/2`G
M<F]?4D\G.PHD;FQS6R=A;&EA<V5S)UU;)W)U)UT@/2`G<G5?4E4G.PHD;FQS
M6R=A;&EA<V5S)UU;)W-K)UT@/2`G<VM?4TLG.PHD;FQS6R=A;&EA<V5S)UU;
M)W-L)UT@/2`G<VQ?4TDG.PHD;FQS6R=A;&EA<V5S)UU;)W-V)UT@/2`G<W9?
M4T4G.PHD;FQS6R=A;&EA<V5S)UU;)W1H)UT@/2`G=&A?5$@G.PHD;FQS6R=A
M;&EA<V5S)UU;)W1R)UT@/2`G=')?5%(G.PHD;FQS6R=A;&EA<V5S)UU;)W5K
M)UT@/2`G=6M?54$G.PH*"B\J*@H@*BH@0VAA<G-E=',*("HJ+PH*)&YL<ULG
M8VAA<G-E=',G75LG87)?3TTG72`]("=W:6YD;W=S+3$R-38G.PHD;FQS6R=C
M:&%R<V5T<R==6R=A<E]362==(#T@)W=I;F1O=W,M,3(U-B<["B1N;'-;)V-H
M87)S971S)UU;)V)G7T)')UT@/2`G=VEN9&]W<RTQ,C4Q)SL*)&YL<ULG8VAA
M<G-E=',G75LG8G-?0D$G72`]("=)4T\M.#@U.2TR)SL*)&YL<ULG8VAA<G-E
M=',G75LG8W-?0UHG72`]("=)4T\M.#@U.2TR)SL*)&YL<ULG8VAA<G-E=',G
M75LG96Q?1U(G72`]("=)4T\M.#@U.2TW)SL*)&YL<ULG8VAA<G-E=',G75LG
M9F%?25(G72`]("=55$8M."<["B1N;'-;)V-H87)S971S)UU;)VAE7TE,)UT@
M/2`G551&+3@G.PHD;FQS6R=C:&%R<V5T<R==6R=H=5](52==(#T@)TE33RTX
M.#4Y+3(G.PHD;FQS6R=C:&%R<V5T<R==6R=J85]*4"==(#T@)U-(24947TI)
M4R<["B1N;'-;)V-H87)S971S)UU;)VMM7TM()UT@/2`G551&+3@G.PHD;FQS
M6R=C:&%R<V5T<R==6R=K;U]+4B==(#T@)T550RU+4B<["B1N;'-;)V-H87)S
M971S)UU;)VQT7TQ4)UT@/2`G25-/+3@X-3DM,3,G.PHD;FQS6R=C:&%R<V5T
M<R==6R=L=E],5B==(#T@)W=I;F1O=W,M,3(U-R<["B1N;'-;)V-H87)S971S
M)UU;)VUK7TU+)UT@/2`G25-/+3@X-3DM-2<["B1N;'-;)V-H87)S971S)UU;
M)W!L7U!,)UT@/2`G25-/+3@X-3DM,B<["B1N;'-;)V-H87)S971S)UU;)W)U
M7U)5)UT@/2`G=VEN9&]W<RTQ,C4Q)SL*)&YL<ULG8VAA<G-E=',G75LG<G5?
M4E4N2T])."U2)UT@/2`G2T])."U2)SL*)&YL<ULG8VAA<G-E=',G75LG<VM?
M4TLG72`]("=)4T\M.#@U.2TR)SL*)&YL<ULG8VAA<G-E=',G75LG<VQ?4TDG
M72`]("=)4T\M.#@U.2TR)SL*)&YL<ULG8VAA<G-E=',G75LG=&A?5$@G72`]
M("=425,M-C(P)SL*)&YL<ULG8VAA<G-E=',G75LG=')?5%(G72`]("=)4T\M
M.#@U.2TY)SL*)&YL<ULG8VAA<G-E=',G75LG=6M?54$G72`]("=+3TDX+54G
M.PHD;FQS6R=C:&%R<V5T<R==6R=Z:%]#3B==(#T@)T=",C,Q,B<["B1N;'-;
M)V-H87)S971S)UU;)WIH7U17)UT@/2`G0DE'-2<["@H*+RHJ"B`J*B!-=6QT
M:6)Y=&4@8VAA<G-E=',*("HJ+PH*)&YL<ULG;75L=&EB>71E)UU;)T))1S4G
M72`]('1R=64["B1N;'-;)VUU;'1I8GET92==6R=%54,M2U(G72`]('1R=64[
M"B1N;'-;)VUU;'1I8GET92==6R='0C(S,3(G72`]('1R=64["B1N;'-;)VUU
M;'1I8GET92==6R=32$E&5%]*25,G72`]('1R=64["B1N;'-;)VUU;'1I8GET
M92==6R=55$8M."==(#T@=')U93L*"@HO*BH*("HJ(%)I9VAT+71O+6QE9G0@
M;&%N9W5A9V5S"B`J*B\*"B1N;'-;)W)T;"==6R=A<E]/32==(#T@=')U93L*
M)&YL<ULG<G1L)UU;)V%R7U-9)UT@/2!T<G5E.PHD;FQS6R=R=&PG75LG9F%?
M25(G72`]('1R=64["B1N;'-;)W)T;"==6R=H95])3"==(#T@=')U93L*"@HO
M*BH*("HJ(%!R969E<G)E9"!C:&%R<V5T<R!F;W(@96UA:6P@=')A9F9I8R!I
M9B!N;W0@=&AE(&QA;F=U86=E<R<@9&5F875L=`H@*BH@8VAA<G-E=',N"B`J
M*B\*"B1N;'-;)V5M86EL<R==6R=J85]*4"==(#T@)TE33RTR,#(R+4I0)SL*
M"@HO*BH*("HJ($%V86EL86)L92!C:&%R<V5T<R!F;W(@;W5T9V]I;F<@96UA
M:6P@=')A9F9I8RX*("HJ+PH*)&YL<ULG96YC;V1I;F=S)UU;)W=I;F1O=W,M
M,3(U-B==(#T@7R@B07)A8FEC("A7:6YD;W=S+3$R-38I(BD["B1N;'-;)V5N
M8V]D:6YG<R==6R=!4DU30TE)+3@G72`](%\H(D%R;65N:6%N("A!4DU30TE)
M+3@I(BD["B1N;'-;)V5N8V]D:6YG<R==6R=)4T\M.#@U.2TQ,R==(#T@7R@B
M0F%L=&EC("A)4T\M.#@U.2TQ,RDB*3L*)&YL<ULG96YC;V1I;F=S)UU;)TE3
M3RTX.#4Y+3$T)UT@/2!?*")#96QT:6,@*$E33RTX.#4Y+3$T*2(I.PHD;FQS
M6R=E;F-O9&EN9W,G75LG25-/+3@X-3DM,B==(#T@7R@B0V5N=')A;"!%=7)O
M<&5A;B`H25-/+3@X-3DM,BDB*3L*)&YL<ULG96YC;V1I;F=S)UU;)T=",C,Q
M,B==(#T@7R@B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(BD["B1N;'-;
M)V5N8V]D:6YG<R==6R="24<U)UT@/2!?*")#:&EN97-E(%1R861I=&EO;F%L
M("A":6<U*2(I.PHD;FQS6R=E;F-O9&EN9W,G75LG2T])."U2)UT@/2!?*")#
M>7)I;&QI8R`H2T])."U2*2(I.PHD;FQS6R=E;F-O9&EN9W,G75LG=VEN9&]W
M<RTQ,C4Q)UT@/2!?*")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(I.PHD;FQS
M6R=E;F-O9&EN9W,G75LG2T])."U5)UT@/2!?*")#>7)I;&QI8R]5:W)A:6YI
M86X@*$M/23@M52DB*3L*)&YL<ULG96YC;V1I;F=S)UU;)TE33RTX.#4Y+3<G
M72`](%\H(D=R965K("A)4T\M.#@U.2TW*2(I.PHD;FQS6R=E;F-O9&EN9W,G
M75LG25-/+3@X-3DM."U))UT@/2!?*")(96)R97<@*$E33RTX.#4Y+3@M22DB
M*3L*)&YL<ULG96YC;V1I;F=S)UU;)TE33RTR,#(R+4I0)UT@/2!?*")*87!A
M;F5S92`H25-/+3(P,C(M2E`I(BD["B1N;'-;)V5N8V]D:6YG<R==6R=%54,M
M2U(G72`](%\H(DMO<F5A;B`H155#+4M2*2(I.PHD;FQS6R=E;F-O9&EN9W,G
M75LG25-/+3@X-3DM,3`G72`](%\H(DYO<F1I8R`H25-/+3@X-3DM,3`I(BD[
M"B1N;'-;)V5N8V]D:6YG<R==6R=)4T\M.#@U.2TS)UT@/2!?*")3;W5T:"!%
M=7)O<&5A;B`H25-/+3@X-3DM,RDB*3L*)&YL<ULG96YC;V1I;F=S)UU;)U1)
M4RTV,C`G72`](%\H(E1H86D@*%1)4RTV,C`I(BD["B1N;'-;)V5N8V]D:6YG
M<R==6R=)4T\M.#@U.2TY)UT@/2!?*")4=7)K:7-H("A)4T\M.#@U.2TY*2(I
M.PHD;FQS6R=E;F-O9&EN9W,G75LG551&+3@G72`](%\H(E5N:6-O9&4@*%54
M1BTX*2(I.PHD;FQS6R=E;F-O9&EN9W,G75LG5DE30TE))UT@/2!?*")6:65T
M;F%M97-E("A625-#24DI(BD["B1N;'-;)V5N8V]D:6YG<R==6R=)4T\M.#@U
M.2TQ)UT@/2!?*")797-T97)N("A)4T\M.#@U.2TQ*2(I.PHD;FQS6R=E;F-O
M9&EN9W,G75LG25-/+3@X-3DM,34G72`](%\H(E=E<W1E<FX@*$E33RTX.#4Y
M+3$U*2(I.PIA<V]R="@D;FQS6R=E;F-O9&EN9W,G72D["@H*+RHJ"B`J*B!-
M=6QT:2UL86YG=6%G92!S<&5L;&EN9R!S=7!P;W)T"B`J*B\*"B1N;'-;)W-P
M96QL:6YG)UU;)V-S7T-:)UT@/2`G+50@;&%T:6XR("UD(&-Z96-H)SL*)&YL
M<ULG<W!E;&QI;F<G75LG9&%?1$LG72`]("<M9"!D86YS:R<["B1N;'-;)W-P
M96QL:6YG)UU;)V1E7T1%)UT@/2`G+50@;&%T:6XQ("UD(&1E=71S8V@G.PHD
M;FQS6R=S<&5L;&EN9R==6R=E;%]'4B==(#T@)RU4(&QA=&EN,2`M9"!E;&QI
M;FEK82<["B1N;'-;)W-P96QL:6YG)UU;)V5N7T-!)UT@/2`G+60@8V%N861I
M86XG.PHD;FQS6R=S<&5L;&EN9R==6R=E;E]'0B==(#T@)RUD(&)R:71I<V@G
M.PHD;FQS6R=S<&5L;&EN9R==6R=E;E]54R==(#T@)RUD(&%M97)I8V%N)SL*
M)&YL<ULG<W!E;&QI;F<G75LG97-?15,G72`]("<M9"!E<W!A;F]L)SL*)&YL
M<ULG<W!E;&QI;F<G75LG9G)?1E(G72`]("<M9"!F<F%N8V%I<R<["B1N;'-;
M)W-P96QL:6YG)UU;)VET7TE4)UT@/2`G+50@;&%T:6XQ("UD(&ET86QI86XG
M.PHD;FQS6R=S<&5L;&EN9R==6R=N;%].3"==(#T@)RUD(&YE9&5R;&%N9',G
M.PHD;FQS6R=S<&5L;&EN9R==6R=P;%]03"==(#T@)RUD('!O;&ES:"<["B1N
M;'-;)W-P96QL:6YG)UU;)W!T7T)2)UT@/2`G+60@8G(G.PHD;FQS6R=S<&5L
M;&EN9R==6R=P=%]05"==(#T@)RU4(&QA=&EN,2`M9"!P;W)T=6=U97-E)SL*
M)&YL<ULG<W!E;&QI;F<G75LG<G5?4E4G72`]("<M9"!R=7-S:6%N)SL*)&YL
M<ULG<W!E;&QI;F<G75LG<VQ?4TDG72`]("<M9"!S;&]V96YS:V\G.PHD;FQS
M6R=S<&5L;&EN9R==6R=S=E]312==(#T@)RUD('-V96YS:V$G.PH*)$=,3T)!
M3%-;)VYL<R==(#T@)B1N;',["@H*+RHJ"B`J*B!4:6UE>F]N97,*("HJ+PH*
M)'1Z6R=!9G)I8V$O06)I9&IA;B==(#T@)T%F<FEC82]!8FED:F%N)SL*)'1Z
M6R=!9G)I8V$O06-C<F$G72`]("=!9G)I8V$O06-C<F$G.PHD='I;)T%F<FEC
M82]!9&1I<U]!8F%B82==(#T@)T%F<FEC82]!9&1I<R!!8F%B82<["B1T>ELG
M069R:6-A+T%L9VEE<G,G72`]("=!9G)I8V$O06QG:65R<R<["B1T>ELG069R
M:6-A+T%S;65R82==(#T@)T%F<FEC82]!<VUE<F$G.PHD='I;)T%F<FEC82]"
M86UA:V\G72`]("=!9G)I8V$O0F%M86MO)SL*)'1Z6R=!9G)I8V$O0F%N9W5I
M)UT@/2`G069R:6-A+T)A;F=U:2<["B1T>ELG069R:6-A+T)A;FIU;"==(#T@
M)T%F<FEC82]"86YJ=6PG.PHD='I;)T%F<FEC82]":7-S874G72`]("=!9G)I
M8V$O0FES<V%U)SL*)'1Z6R=!9G)I8V$O0FQA;G1Y<F4G72`]("=!9G)I8V$O
M0FQA;G1Y<F4G.PHD='I;)T%F<FEC82]"<F%Z>F%V:6QL92==(#T@)T%F<FEC
M82]"<F%Z>F%V:6QL92<["B1T>ELG069R:6-A+T)U:G5M8G5R82==(#T@)T%F
M<FEC82]"=6IU;6)U<F$G.PHD='I;)T%F<FEC82]#86ER;R==(#T@)T%F<FEC
M82]#86ER;R<["B1T>ELG069R:6-A+T-A<V%B;&%N8V$G72`]("=!9G)I8V$O
M0V%S86)L86YC82<["B1T>ELG069R:6-A+T-E=71A)UT@/2`G069R:6-A+T-E
M=71A)SL*)'1Z6R=!9G)I8V$O0V]N86MR>2==(#T@)T%F<FEC82]#;VYA:W)Y
M)SL*)'1Z6R=!9G)I8V$O1&%K87(G72`]("=!9G)I8V$O1&%K87(G.PHD='I;
M)T%F<FEC82]$87)?97-?4V%L86%M)UT@/2`G069R:6-A+T1A<B!E<R!386QA
M86TG.PHD='I;)T%F<FEC82]$:FEB;W5T:2==(#T@)T%F<FEC82]$:FEB;W5T
M:2<["B1T>ELG069R:6-A+T1O=6%L82==(#T@)T%F<FEC82]$;W5A;&$G.PHD
M='I;)T%F<FEC82]%;%]!86EU;B==(#T@)T%F<FEC82]%;"!!86EU;B<["B1T
M>ELG069R:6-A+T9R965T;W=N)UT@/2`G069R:6-A+T9R965T;W=N)SL*)'1Z
M6R=!9G)I8V$O1V%B;W)O;F4G72`]("=!9G)I8V$O1V%B;W)O;F4G.PHD='I;
M)T%F<FEC82](87)A<F4G72`]("=!9G)I8V$O2&%R87)E)SL*)'1Z6R=!9G)I
M8V$O2F]H86YN97-B=7)G)UT@/2`G069R:6-A+TIO:&%N;F5S8G5R9R<["B1T
M>ELG069R:6-A+TMA;7!A;&$G72`]("=!9G)I8V$O2V%M<&%L82<["B1T>ELG
M069R:6-A+TMH87)T;W5M)UT@/2`G069R:6-A+TMH87)T;W5M)SL*)'1Z6R=!
M9G)I8V$O2VEG86QI)UT@/2`G069R:6-A+TMI9V%L:2<["B1T>ELG069R:6-A
M+TMI;G-H87-A)UT@/2`G069R:6-A+TMI;G-H87-A)SL*)'1Z6R=!9G)I8V$O
M3&%G;W,G72`]("=!9G)I8V$O3&%G;W,G.PHD='I;)T%F<FEC82],:6)R979I
M;&QE)UT@/2`G069R:6-A+TQI8G)E=FEL;&4G.PHD='I;)T%F<FEC82],;VUE
M)UT@/2`G069R:6-A+TQO;64G.PHD='I;)T%F<FEC82],=6%N9&$G72`]("=!
M9G)I8V$O3'5A;F1A)SL*)'1Z6R=!9G)I8V$O3'5B=6UB87-H:2==(#T@)T%F
M<FEC82],=6)U;6)A<VAI)SL*)'1Z6R=!9G)I8V$O3'5S86MA)UT@/2`G069R
M:6-A+TQU<V%K82<["B1T>ELG069R:6-A+TUA;&%B;R==(#T@)T%F<FEC82]-
M86QA8F\G.PHD='I;)T%F<FEC82]-87!U=&\G72`]("=!9G)I8V$O36%P=71O
M)SL*)'1Z6R=!9G)I8V$O36%S97)U)UT@/2`G069R:6-A+TUA<V5R=2<["B1T
M>ELG069R:6-A+TUB86)A;F4G72`]("=!9G)I8V$O36)A8F%N92<["B1T>ELG
M069R:6-A+TUO9V%D:7-H=2==(#T@)T%F<FEC82]-;V=A9&ES:'4G.PHD='I;
M)T%F<FEC82]-;VYR;W9I82==(#T@)T%F<FEC82]-;VYR;W9I82<["B1T>ELG
M069R:6-A+TYA:7)O8FDG72`]("=!9G)I8V$O3F%I<F]B:2<["B1T>ELG069R
M:6-A+TYD:F%M96YA)UT@/2`G069R:6-A+TYD:F%M96YA)SL*)'1Z6R=!9G)I
M8V$O3FEA;65Y)UT@/2`G069R:6-A+TYI86UE>2<["B1T>ELG069R:6-A+TYO
M=6%K8VAO='0G72`]("=!9G)I8V$O3F]U86MC:&]T="<["B1T>ELG069R:6-A
M+T]U86=A9&]U9V]U)UT@/2`G069R:6-A+T]U86=A9&]U9V]U)SL*)'1Z6R=!
M9G)I8V$O4&]R=&\M3F]V;R==(#T@)T%F<FEC82]0;W)T;RU.;W9O)SL*)'1Z
M6R=!9G)I8V$O4V%O7U1O;64G72`]("=!9G)I8V$O4V%O(%1O;64G.PHD='I;
M)T%F<FEC82]4:6UB=6MT=2==(#T@)T%F<FEC82]4:6UB=6MT=2<["B1T>ELG
M069R:6-A+U1R:7!O;&DG72`]("=!9G)I8V$O5')I<&]L:2<["B1T>ELG069R
M:6-A+U1U;FES)UT@/2`G069R:6-A+U1U;FES)SL*)'1Z6R=!9G)I8V$O5VEN
M9&AO96LG72`]("=!9G)I8V$O5VEN9&AO96LG.PHD='I;)T%M97)I8V$O061A
M:R==(#T@)T%M97)I8V$O061A:R<["B1T>ELG06UE<FEC82]!;F-H;W)A9V4G
M72`]("=!;65R:6-A+T%N8VAO<F%G92<["B1T>ELG06UE<FEC82]!;F=U:6QL
M82==(#T@)T%M97)I8V$O06YG=6EL;&$G.PHD='I;)T%M97)I8V$O06YT:6=U
M82==(#T@)T%M97)I8V$O06YT:6=U82<["B1T>ELG06UE<FEC82]!<F%G=6%I
M;F$G72`]("=!;65R:6-A+T%R86=U86EN82<["B1T>ELG06UE<FEC82]!<G5B
M82==(#T@)T%M97)I8V$O07)U8F$G.PHD='I;)T%M97)I8V$O07-U;F-I;VXG
M72`]("=!;65R:6-A+T%S=6YC:6]N)SL*)'1Z6R=!;65R:6-A+T)A<F)A9&]S
M)UT@/2`G06UE<FEC82]"87)B861O<R<["B1T>ELG06UE<FEC82]"96QE;2==
M(#T@)T%M97)I8V$O0F5L96TG.PHD='I;)T%M97)I8V$O0F5L:7IE)UT@/2`G
M06UE<FEC82]"96QI>F4G.PHD='I;)T%M97)I8V$O0F]A7U9I<W1A)UT@/2`G
M06UE<FEC82]";V$@5FES=&$G.PHD='I;)T%M97)I8V$O0F]G;W1A)UT@/2`G
M06UE<FEC82]";V=O=&$G.PHD='I;)T%M97)I8V$O0F]I<V4G72`]("=!;65R
M:6-A+T)O:7-E)SL*)'1Z6R=!;65R:6-A+T)U96YO<U]!:7)E<R==(#T@)T%M
M97)I8V$O0G5E;F]S($%I<F5S)SL*)'1Z6R=!;65R:6-A+T-A;6)R:61G95]"
M87DG72`]("=!;65R:6-A+T-A;6)R:61G92!"87DG.PHD='I;)T%M97)I8V$O
M0V%N8W5N)UT@/2`G06UE<FEC82]#86YC=6XG.PHD='I;)T%M97)I8V$O0V%R
M86-A<R==(#T@)T%M97)I8V$O0V%R86-A<R<["B1T>ELG06UE<FEC82]#871A
M;6%R8V$G72`]("=!;65R:6-A+T-A=&%M87)C82<["B1T>ELG06UE<FEC82]#
M87EE;FYE)UT@/2`G06UE<FEC82]#87EE;FYE)SL*)'1Z6R=!;65R:6-A+T-A
M>6UA;B==(#T@)T%M97)I8V$O0V%Y;6%N)SL*)'1Z6R=!;65R:6-A+T-H:6-A
M9V\G72`]("=!;65R:6-A+T-H:6-A9V\G.PHD='I;)T%M97)I8V$O0VAI:'5A
M:'5A)UT@/2`G06UE<FEC82]#:&EH=6%H=6$G.PHD='I;)T%M97)I8V$O0V]R
M9&]B82==(#T@)T%M97)I8V$O0V]R9&]B82<["B1T>ELG06UE<FEC82]#;W-T
M85]2:6-A)UT@/2`G06UE<FEC82]#;W-T82!2:6-A)SL*)'1Z6R=!;65R:6-A
M+T-U:6%B82==(#T@)T%M97)I8V$O0W5I86)A)SL*)'1Z6R=!;65R:6-A+T-U
M<F%C86\G72`]("=!;65R:6-A+T-U<F%C86\G.PHD='I;)T%M97)I8V$O1&%W
M<V]N)UT@/2`G06UE<FEC82]$87=S;VXG.PHD='I;)T%M97)I8V$O1&%W<V]N
M7T-R965K)UT@/2`G06UE<FEC82]$87=S;VX@0W)E96LG.PHD='I;)T%M97)I
M8V$O1&5N=F5R)UT@/2`G06UE<FEC82]$96YV97(G.PHD='I;)T%M97)I8V$O
M1&5T<F]I="==(#T@)T%M97)I8V$O1&5T<F]I="<["B1T>ELG06UE<FEC82]$
M;VUI;FEC82==(#T@)T%M97)I8V$O1&]M:6YI8V$G.PHD='I;)T%M97)I8V$O
M161M;VYT;VXG72`]("=!;65R:6-A+T5D;6]N=&]N)SL*)'1Z6R=!;65R:6-A
M+T5I<G5N97!E)UT@/2`G06UE<FEC82]%:7)U;F5P92<["B1T>ELG06UE<FEC
M82]%;%]386QV861O<B==(#T@)T%M97)I8V$O16P@4V%L=F%D;W(G.PHD='I;
M)T%M97)I8V$O1F]R=&%L97IA)UT@/2`G06UE<FEC82]&;W)T86QE>F$G.PHD
M='I;)T%M97)I8V$O1VQA8V5?0F%Y)UT@/2`G06UE<FEC82]';&%C92!"87DG
M.PHD='I;)T%M97)I8V$O1V]D=&AA8B==(#T@)T%M97)I8V$O1V]D=&AA8B<[
M"B1T>ELG06UE<FEC82]';V]S95]"87DG72`]("=!;65R:6-A+T=O;W-E($)A
M>2<["B1T>ELG06UE<FEC82]'<F%N9%]4=7)K)UT@/2`G06UE<FEC82]'<F%N
M9"!4=7)K)SL*)'1Z6R=!;65R:6-A+T=R96YA9&$G72`]("=!;65R:6-A+T=R
M96YA9&$G.PHD='I;)T%M97)I8V$O1W5A9&5L;W5P92==(#T@)T%M97)I8V$O
M1W5A9&5L;W5P92<["B1T>ELG06UE<FEC82]'=6%T96UA;&$G72`]("=!;65R
M:6-A+T=U871E;6%L82<["B1T>ELG06UE<FEC82]'=6%Y87%U:6PG72`]("=!
M;65R:6-A+T=U87EA<75I;"<["B1T>ELG06UE<FEC82]'=7EA;F$G72`]("=!
M;65R:6-A+T=U>6%N82<["B1T>ELG06UE<FEC82](86QI9F%X)UT@/2`G06UE
M<FEC82](86QI9F%X)SL*)'1Z6R=!;65R:6-A+TAA=F%N82==(#T@)T%M97)I
M8V$O2&%V86YA)SL*)'1Z6R=!;65R:6-A+TAE<FUO<VEL;&\G72`]("=!;65R
M:6-A+TAE<FUO<VEL;&\G.PHD='I;)T%M97)I8V$O26YD:6%N82]+;F]X)UT@
M/2`G06UE<FEC82]);F1I86YA+TMN;W@G.PHD='I;)T%M97)I8V$O26YD:6%N
M82]-87)E;F=O)UT@/2`G06UE<FEC82]);F1I86YA+TUA<F5N9V\G.PHD='I;
M)T%M97)I8V$O26YD:6%N82]6979A>2==(#T@)T%M97)I8V$O26YD:6%N82]6
M979A>2<["B1T>ELG06UE<FEC82]);F1I86YA<&]L:7,G72`]("=!;65R:6-A
M+TEN9&EA;F%P;VQI<R<["B1T>ELG06UE<FEC82]);G5V:6LG72`]("=!;65R
M:6-A+TEN=79I:R<["B1T>ELG06UE<FEC82])<6%L=6ET)UT@/2`G06UE<FEC
M82])<6%L=6ET)SL*)'1Z6R=!;65R:6-A+TIA;6%I8V$G72`]("=!;65R:6-A
M+TIA;6%I8V$G.PHD='I;)T%M97)I8V$O2G5J=7DG72`]("=!;65R:6-A+TIU
M:G5Y)SL*)'1Z6R=!;65R:6-A+TIU;F5A=2==(#T@)T%M97)I8V$O2G5N96%U
M)SL*)'1Z6R=!;65R:6-A+TME;G1U8VMY+TUO;G1I8V5L;&\G72`]("=!;65R
M:6-A+TME;G1U8VMY+TUO;G1I8V5L;&\G.PHD='I;)T%M97)I8V$O3&%?4&%Z
M)UT@/2`G06UE<FEC82],82!087HG.PHD='I;)T%M97)I8V$O3&EM82==(#T@
M)T%M97)I8V$O3&EM82<["B1T>ELG06UE<FEC82],;W-?06YG96QE<R==(#T@
M)T%M97)I8V$O3&]S($%N9V5L97,G.PHD='I;)T%M97)I8V$O3&]U:7-V:6QL
M92==(#T@)T%M97)I8V$O3&]U:7-V:6QL92<["B1T>ELG06UE<FEC82]-86-E
M:6\G72`]("=!;65R:6-A+TUA8V5I;R<["B1T>ELG06UE<FEC82]-86YA9W5A
M)UT@/2`G06UE<FEC82]-86YA9W5A)SL*)'1Z6R=!;65R:6-A+TUA;F%U<R==
M(#T@)T%M97)I8V$O36%N875S)SL*)'1Z6R=!;65R:6-A+TUA<G1I;FEQ=64G
M72`]("=!;65R:6-A+TUA<G1I;FEQ=64G.PHD='I;)T%M97)I8V$O36%Z871L
M86XG72`]("=!;65R:6-A+TUA>F%T;&%N)SL*)'1Z6R=!;65R:6-A+TUE;F1O
M>B==(#T@)T%M97)I8V$O365N9&]Z)SL*)'1Z6R=!;65R:6-A+TUE;F]M:6YE
M92==(#T@)T%M97)I8V$O365N;VUI;F5E)SL*)'1Z6R=!;65R:6-A+TUE<FED
M82==(#T@)T%M97)I8V$O365R:61A)SL*)'1Z6R=!;65R:6-A+TUE>&EC;U]#
M:71Y)UT@/2`G06UE<FEC82]-97AI8V\@0VET>2<["B1T>ELG06UE<FEC82]-
M:7%U96QO;B==(#T@)T%M97)I8V$O36EQ=65L;VXG.PHD='I;)T%M97)I8V$O
M36]N=&5R<F5Y)UT@/2`G06UE<FEC82]-;VYT97)R97DG.PHD='I;)T%M97)I
M8V$O36]N=&5V:61E;R==(#T@)T%M97)I8V$O36]N=&5V:61E;R<["B1T>ELG
M06UE<FEC82]-;VYT<F5A;"==(#T@)T%M97)I8V$O36]N=')E86PG.PHD='I;
M)T%M97)I8V$O36]N='-E<G)A="==(#T@)T%M97)I8V$O36]N='-E<G)A="<[
M"B1T>ELG06UE<FEC82].87-S874G72`]("=!;65R:6-A+TYA<W-A=2<["B1T
M>ELG06UE<FEC82].97=?66]R:R==(#T@)T%M97)I8V$O3F5W(%EO<FLG.PHD
M='I;)T%M97)I8V$O3FEP:6=O;B==(#T@)T%M97)I8V$O3FEP:6=O;B<["B1T
M>ELG06UE<FEC82].;VUE)UT@/2`G06UE<FEC82].;VUE)SL*)'1Z6R=!;65R
M:6-A+TYO<F]N:&$G72`]("=!;65R:6-A+TYO<F]N:&$G.PHD='I;)T%M97)I
M8V$O4&%N86UA)UT@/2`G06UE<FEC82]086YA;6$G.PHD='I;)T%M97)I8V$O
M4&%N9VYI<G1U;F<G72`]("=!;65R:6-A+U!A;F=N:7)T=6YG)SL*)'1Z6R=!
M;65R:6-A+U!A<F%M87)I8F\G72`]("=!;65R:6-A+U!A<F%M87)I8F\G.PHD
M='I;)T%M97)I8V$O4&AO96YI>"==(#T@)T%M97)I8V$O4&AO96YI>"<["B1T
M>ELG06UE<FEC82]0;W)T+6%U+5!R:6YC92==(#T@)T%M97)I8V$O4&]R="UA
M=2U0<FEN8V4G.PHD='I;)T%M97)I8V$O4&]R=&]?5F5L:&\G72`]("=!;65R
M:6-A+U!O<G1O(%9E;&AO)SL*)'1Z6R=!;65R:6-A+U!O<G1?;V9?4W!A:6XG
M72`]("=!;65R:6-A+U!O<G0@;V8@4W!A:6XG.PHD='I;)T%M97)I8V$O4'5E
M<G1O7U)I8V\G72`]("=!;65R:6-A+U!U97)T;R!2:6-O)SL*)'1Z6R=!;65R
M:6-A+U)A:6YY7U)I=F5R)UT@/2`G06UE<FEC82]286EN>2!2:79E<B<["B1T
M>ELG06UE<FEC82]286YK:6Y?26YL970G72`]("=!;65R:6-A+U)A;FMI;B!)
M;FQE="<["B1T>ELG06UE<FEC82]296-I9F4G72`]("=!;65R:6-A+U)E8VEF
M92<["B1T>ELG06UE<FEC82]296=I;F$G72`]("=!;65R:6-A+U)E9VEN82<[
M"B1T>ELG06UE<FEC82]2:6]?0G)A;F-O)UT@/2`G06UE<FEC82]2:6\@0G)A
M;F-O)SL*)'1Z6R=!;65R:6-A+U)O<V%R:6\G72`]("=!;65R:6-A+U)O<V%R
M:6\G.PHD='I;)T%M97)I8V$O4V%N=&EA9V\G72`]("=!;65R:6-A+U-A;G1I
M86=O)SL*)'1Z6R=!;65R:6-A+U-A;G1O7T1O;6EN9V\G72`]("=!;65R:6-A
M+U-A;G1O($1O;6EN9V\G.PHD='I;)T%M97)I8V$O4V%O7U!A=6QO)UT@/2`G
M06UE<FEC82]386\@4&%U;&\G.PHD='I;)T%M97)I8V$O4V-O<F5S8GES=6YD
M)UT@/2`G06UE<FEC82]38V]R97-B>7-U;F0G.PHD='I;)T%M97)I8V$O4VAI
M<')O8VLG72`]("=!;65R:6-A+U-H:7!R;V-K)SL*)'1Z6R=!;65R:6-A+U-T
M7TIO:&YS)UT@/2`G06UE<FEC82]3="!*;VAN<R<["B1T>ELG06UE<FEC82]3
M=%]+:71T<R==(#T@)T%M97)I8V$O4W0@2VET=',G.PHD='I;)T%M97)I8V$O
M4W1?3'5C:6$G72`]("=!;65R:6-A+U-T($QU8VEA)SL*)'1Z6R=!;65R:6-A
M+U-T7U1H;VUA<R==(#T@)T%M97)I8V$O4W0@5&AO;6%S)SL*)'1Z6R=!;65R
M:6-A+U-T7U9I;F-E;G0G72`]("=!;65R:6-A+U-T(%9I;F-E;G0G.PHD='I;
M)T%M97)I8V$O4W=I9G1?0W5R<F5N="==(#T@)T%M97)I8V$O4W=I9G0@0W5R
M<F5N="<["B1T>ELG06UE<FEC82]496=U8VEG86QP82==(#T@)T%M97)I8V$O
M5&5G=6-I9V%L<&$G.PHD='I;)T%M97)I8V$O5&AU;&4G72`]("=!;65R:6-A
M+U1H=6QE)SL*)'1Z6R=!;65R:6-A+U1H=6YD97)?0F%Y)UT@/2`G06UE<FEC
M82]4:'5N9&5R($)A>2<["B1T>ELG06UE<FEC82]4:6IU86YA)UT@/2`G06UE
M<FEC82]4:6IU86YA)SL*)'1Z6R=!;65R:6-A+U1O<G1O;&$G72`]("=!;65R
M:6-A+U1O<G1O;&$G.PHD='I;)T%M97)I8V$O5F%N8V]U=F5R)UT@/2`G06UE
M<FEC82]686YC;W5V97(G.PHD='I;)T%M97)I8V$O5VAI=&5H;W)S92==(#T@
M)T%M97)I8V$O5VAI=&5H;W)S92<["B1T>ELG06UE<FEC82]7:6YN:7!E9R==
M(#T@)T%M97)I8V$O5VEN;FEP96<G.PHD='I;)T%M97)I8V$O66%K=71A="==
M(#T@)T%M97)I8V$O66%K=71A="<["B1T>ELG06UE<FEC82]996QL;W=K;FEF
M92==(#T@)T%M97)I8V$O665L;&]W:VYI9F4G.PHD='I;)T%N=&%R8W1I8V$O
M0V%S97DG72`]("=!;G1A<F-T:6-A+T-A<V5Y)SL*)'1Z6R=!;G1A<F-T:6-A
M+T1A=FES)UT@/2`G06YT87)C=&EC82]$879I<R<["B1T>ELG06YT87)C=&EC
M82]$=6UO;G1$57)V:6QL92==(#T@)T%N=&%R8W1I8V$O1'5M;VYT1%5R=FEL
M;&4G.PHD='I;)T%N=&%R8W1I8V$O36%W<V]N)UT@/2`G06YT87)C=&EC82]-
M87=S;VXG.PHD='I;)T%N=&%R8W1I8V$O36--=7)D;R==(#T@)T%N=&%R8W1I
M8V$O36--=7)D;R<["B1T>ELG06YT87)C=&EC82]086QM97(G72`]("=!;G1A
M<F-T:6-A+U!A;&UE<B<["B1T>ELG06YT87)C=&EC82]3;W5T:%]0;VQE)UT@
M/2`G06YT87)C=&EC82]3;W5T:"!0;VQE)SL*)'1Z6R=!;G1A<F-T:6-A+U-Y
M;W=A)UT@/2`G06YT87)C=&EC82]3>6]W82<["B1T>ELG06YT87)C=&EC82]6
M;W-T;VLG72`]("=!;G1A<F-T:6-A+U9O<W1O:R<["B1T>ELG07)C=&EC+TQO
M;F=Y96%R8GEE;B==(#T@)T%R8W1I8R],;VYG>65A<F)Y96XG.PHD='I;)T%S
M:6$O061E;B==(#T@)T%S:6$O061E;B<["B1T>ELG07-I82]!;&UA='DG72`]
M("=!<VEA+T%L;6%T>2<["B1T>ELG07-I82]!;6UA;B==(#T@)T%S:6$O06UM
M86XG.PHD='I;)T%S:6$O06YA9'ER)UT@/2`G07-I82]!;F%D>7(G.PHD='I;
M)T%S:6$O07%T874G72`]("=!<VEA+T%Q=&%U)SL*)'1Z6R=!<VEA+T%Q=&]B
M92==(#T@)T%S:6$O07%T;V)E)SL*)'1Z6R=!<VEA+T%S:&=A8F%T)UT@/2`G
M07-I82]!<VAG86)A="<["B1T>ELG07-I82]"86=H9&%D)UT@/2`G07-I82]"
M86=H9&%D)SL*)'1Z6R=!<VEA+T)A:')A:6XG72`]("=!<VEA+T)A:')A:6XG
M.PHD='I;)T%S:6$O0F%K=2==(#T@)T%S:6$O0F%K=2<["B1T>ELG07-I82]"
M86YG:V]K)UT@/2`G07-I82]"86YG:V]K)SL*)'1Z6R=!<VEA+T)E:7)U="==
M(#T@)T%S:6$O0F5I<G5T)SL*)'1Z6R=!<VEA+T)I<VAK96LG72`]("=!<VEA
M+T)I<VAK96LG.PHD='I;)T%S:6$O0G)U;F5I)UT@/2`G07-I82]"<G5N96DG
M.PHD='I;)T%S:6$O0V%L8W5T=&$G72`]("=!<VEA+T-A;&-U='1A)SL*)'1Z
M6R=!<VEA+T-H=6YG:VEN9R==(#T@)T%S:6$O0VAU;F=K:6YG)SL*)'1Z6R=!
M<VEA+T-O;&]M8F\G72`]("=!<VEA+T-O;&]M8F\G.PHD='I;)T%S:6$O1&%M
M87-C=7,G72`]("=!<VEA+T1A;6%S8W5S)SL*)'1Z6R=!<VEA+T1H86MA)UT@
M/2`G07-I82]$:&%K82<["B1T>ELG07-I82]$:6QI)UT@/2`G07-I82]$:6QI
M)SL*)'1Z6R=!<VEA+T1U8F%I)UT@/2`G07-I82]$=6)A:2<["B1T>ELG07-I
M82]$=7-H86YB92==(#T@)T%S:6$O1'5S:&%N8F4G.PHD='I;)T%S:6$O1V%Z
M82==(#T@)T%S:6$O1V%Z82<["B1T>ELG07-I82](87)B:6XG72`]("=!<VEA
M+TAA<F)I;B<["B1T>ELG07-I82](;VYG7TMO;F<G72`]("=!<VEA+TAO;F<@
M2V]N9R<["B1T>ELG07-I82](;W9D)UT@/2`G07-I82](;W9D)SL*)'1Z6R=!
M<VEA+TER:W5T<VLG72`]("=!<VEA+TER:W5T<VLG.PHD='I;)T%S:6$O2F%K
M87)T82==(#T@)T%S:6$O2F%K87)T82<["B1T>ELG07-I82]*87EA<'5R82==
M(#T@)T%S:6$O2F%Y87!U<F$G.PHD='I;)T%S:6$O2F5R=7-A;&5M)UT@/2`G
M07-I82]*97)U<V%L96TG.PHD='I;)T%S:6$O2V%B=6PG72`]("=!<VEA+TMA
M8G5L)SL*)'1Z6R=!<VEA+TMA;6-H871K82==(#T@)T%S:6$O2V%M8VAA=&MA
M)SL*)'1Z6R=!<VEA+TMA<F%C:&DG72`]("=!<VEA+TMA<F%C:&DG.PHD='I;
M)T%S:6$O2V%S:&=A<B==(#T@)T%S:6$O2V%S:&=A<B<["B1T>ELG07-I82]+
M871M86YD=2==(#T@)T%S:6$O2V%T;6%N9'4G.PHD='I;)T%S:6$O2W)A<VYO
M>6%R<VLG72`]("=!<VEA+TMR87-N;WEA<G-K)SL*)'1Z6R=!<VEA+TMU86QA
M7TQU;7!U<B==(#T@)T%S:6$O2W5A;&$@3'5M<'5R)SL*)'1Z6R=!<VEA+TMU
M8VAI;F<G72`]("=!<VEA+TMU8VAI;F<G.PHD='I;)T%S:6$O2W5W86ET)UT@
M/2`G07-I82]+=7=A:70G.PHD='I;)T%S:6$O36%C86\G72`]("=!<VEA+TUA
M8V%O)SL*)'1Z6R=!<VEA+TUA9V%D86XG72`]("=!<VEA+TUA9V%D86XG.PHD
M='I;)T%S:6$O36%N:6QA)UT@/2`G07-I82]-86YI;&$G.PHD='I;)T%S:6$O
M375S8V%T)UT@/2`G07-I82]-=7-C870G.PHD='I;)T%S:6$O3FEC;W-I82==
M(#T@)T%S:6$O3FEC;W-I82<["B1T>ELG07-I82].;W9O<VEB:7)S:R==(#T@
M)T%S:6$O3F]V;W-I8FER<VLG.PHD='I;)T%S:6$O3VUS:R==(#T@)T%S:6$O
M3VUS:R<["B1T>ELG07-I82]0:&YO;5]096YH)UT@/2`G07-I82]0:&YO;2!0
M96YH)SL*)'1Z6R=!<VEA+U!Y;VYG>6%N9R==(#T@)T%S:6$O4'EO;F=Y86YG
M)SL*)'1Z6R=!<VEA+U%A=&%R)UT@/2`G07-I82]1871A<B<["B1T>ELG07-I
M82]286YG;V]N)UT@/2`G07-I82]286YG;V]N)SL*)'1Z6R=!<VEA+U)I>6%D
M:"==(#T@)T%S:6$O4FEY861H)SL*)'1Z6R=!<VEA+U-A:6=O;B==(#T@)T%S
M:6$O4V%I9V]N)SL*)'1Z6R=!<VEA+U-A;6%R:V%N9"==(#T@)T%S:6$O4V%M
M87)K86YD)SL*)'1Z6R=!<VEA+U-E;W5L)UT@/2`G07-I82]396]U;"<["B1T
M>ELG07-I82]3:&%N9VAA:2==(#T@)T%S:6$O4VAA;F=H86DG.PHD='I;)T%S
M:6$O4VEN9V%P;W)E)UT@/2`G07-I82]3:6YG87!O<F4G.PHD='I;)T%S:6$O
M5&%I<&5I)UT@/2`G07-I82]486EP96DG.PHD='I;)T%S:6$O5&%S:&ME;G0G
M72`]("=!<VEA+U1A<VAK96YT)SL*)'1Z6R=!<VEA+U1B:6QI<VDG72`]("=!
M<VEA+U1B:6QI<VDG.PHD='I;)T%S:6$O5&5H<F%N)UT@/2`G07-I82]496AR
M86XG.PHD='I;)T%S:6$O5&AI;7!H=2==(#T@)T%S:6$O5&AI;7!H=2<["B1T
M>ELG07-I82]4;VMY;R==(#T@)T%S:6$O5&]K>6\G.PHD='I;)T%S:6$O56IU
M;F=?4&%N9&%N9R==(#T@)T%S:6$O56IU;F<@4&%N9&%N9R<["B1T>ELG07-I
M82]5;&%A;F)A871A<B==(#T@)T%S:6$O56QA86YB86%T87(G.PHD='I;)T%S
M:6$O57)U;7%I)UT@/2`G07-I82]5<G5M<6DG.PHD='I;)T%S:6$O5FEE;G1I
M86YE)UT@/2`G07-I82]6:65N=&EA;F4G.PHD='I;)T%S:6$O5FQA9&EV;W-T
M;VLG72`]("=!<VEA+U9L861I=F]S=&]K)SL*)'1Z6R=!<VEA+UEA:W5T<VLG
M72`]("=!<VEA+UEA:W5T<VLG.PHD='I;)T%S:6$O665K871E<FEN8G5R9R==
M(#T@)T%S:6$O665K871E<FEN8G5R9R<["B1T>ELG07-I82]997)E=F%N)UT@
M/2`G07-I82]997)E=F%N)SL*)'1Z6R=!=&QA;G1I8R]!>F]R97,G72`]("=!
M=&QA;G1I8R]!>F]R97,G.PHD='I;)T%T;&%N=&EC+T)E<FUU9&$G72`]("=!
M=&QA;G1I8R]"97)M=61A)SL*)'1Z6R=!=&QA;G1I8R]#86YA<GDG72`]("=!
M=&QA;G1I8R]#86YA<GDG.PHD='I;)T%T;&%N=&EC+T-A<&5?5F5R9&4G72`]
M("=!=&QA;G1I8R]#87!E(%9E<F1E)SL*)'1Z6R=!=&QA;G1I8R]&865R;V4G
M72`]("=!=&QA;G1I8R]&865R;V4G.PHD='I;)T%T;&%N=&EC+TIA;E]-87EE
M;B==(#T@)T%T;&%N=&EC+TIA;B!-87EE;B<["B1T>ELG071L86YT:6,O36%D
M96ER82==(#T@)T%T;&%N=&EC+TUA9&5I<F$G.PHD='I;)T%T;&%N=&EC+U)E
M>6MJ879I:R==(#T@)T%T;&%N=&EC+U)E>6MJ879I:R<["B1T>ELG071L86YT
M:6,O4V]U=&A?1V5O<F=I82==(#T@)T%T;&%N=&EC+U-O=71H($=E;W)G:6$G
M.PHD='I;)T%T;&%N=&EC+U-T86YL97DG72`]("=!=&QA;G1I8R]3=&%N;&5Y
M)SL*)'1Z6R=!=&QA;G1I8R]3=%](96QE;F$G72`]("=!=&QA;G1I8R]3="!(
M96QE;F$G.PHD='I;)T%U<W1R86QI82]!9&5L86ED92==(#T@)T%U<W1R86QI
M82]!9&5L86ED92<["B1T>ELG075S=')A;&EA+T)R:7-B86YE)UT@/2`G075S
M=')A;&EA+T)R:7-B86YE)SL*)'1Z6R=!=7-T<F%L:6$O0G)O:V5N7TAI;&PG
M72`]("=!=7-T<F%L:6$O0G)O:V5N($AI;&PG.PHD='I;)T%U<W1R86QI82]$
M87)W:6XG72`]("=!=7-T<F%L:6$O1&%R=VEN)SL*)'1Z6R=!=7-T<F%L:6$O
M2&]B87)T)UT@/2`G075S=')A;&EA+TAO8F%R="<["B1T>ELG075S=')A;&EA
M+TQI;F1E;6%N)UT@/2`G075S=')A;&EA+TQI;F1E;6%N)SL*)'1Z6R=!=7-T
M<F%L:6$O3&]R9%](;W=E)UT@/2`G075S=')A;&EA+TQO<F0@2&]W92<["B1T
M>ELG075S=')A;&EA+TUE;&)O=7)N92==(#T@)T%U<W1R86QI82]-96QB;W5R
M;F4G.PHD='I;)T%U<W1R86QI82]097)T:"==(#T@)T%U<W1R86QI82]097)T
M:"<["B1T>ELG075S=')A;&EA+U-Y9&YE>2==(#T@)T%U<W1R86QI82]3>61N
M97DG.PHD='I;)T5U<F]P92]!;7-T97)D86TG72`]("=%=7)O<&4O06US=&5R
M9&%M)SL*)'1Z6R=%=7)O<&4O06YD;W)R82==(#T@)T5U<F]P92]!;F1O<G)A
M)SL*)'1Z6R=%=7)O<&4O071H96YS)UT@/2`G175R;W!E+T%T:&5N<R<["B1T
M>ELG175R;W!E+T)E;&9A<W0G72`]("=%=7)O<&4O0F5L9F%S="<["B1T>ELG
M175R;W!E+T)E;&=R861E)UT@/2`G175R;W!E+T)E;&=R861E)SL*)'1Z6R=%
M=7)O<&4O0F5R;&EN)UT@/2`G175R;W!E+T)E<FQI;B<["B1T>ELG175R;W!E
M+T)R871I<VQA=F$G72`]("=%=7)O<&4O0G)A=&ES;&%V82<["B1T>ELG175R
M;W!E+T)R=7-S96QS)UT@/2`G175R;W!E+T)R=7-S96QS)SL*)'1Z6R=%=7)O
M<&4O0G5C:&%R97-T)UT@/2`G175R;W!E+T)U8VAA<F5S="<["B1T>ELG175R
M;W!E+T)U9&%P97-T)UT@/2`G175R;W!E+T)U9&%P97-T)SL*)'1Z6R=%=7)O
M<&4O0VAI<VEN874G72`]("=%=7)O<&4O0VAI<VEN874G.PHD='I;)T5U<F]P
M92]#;W!E;FAA9V5N)UT@/2`G175R;W!E+T-O<&5N:&%G96XG.PHD='I;)T5U
M<F]P92]$=6)L:6XG72`]("=%=7)O<&4O1'5B;&EN)SL*)'1Z6R=%=7)O<&4O
M1VEB<F%L=&%R)UT@/2`G175R;W!E+T=I8G)A;'1A<B<["B1T>ELG175R;W!E
M+TAE;'-I;FMI)UT@/2`G175R;W!E+TAE;'-I;FMI)SL*)'1Z6R=%=7)O<&4O
M27-T86YB=6PG72`]("=%=7)O<&4O27-T86YB=6PG.PHD='I;)T5U<F]P92]+
M86QI;FEN9W)A9"==(#T@)T5U<F]P92]+86QI;FEN9W)A9"<["B1T>ELG175R
M;W!E+TMI978G72`]("=%=7)O<&4O2VEE=B<["B1T>ELG175R;W!E+TQI<V)O
M;B==(#T@)T5U<F]P92],:7-B;VXG.PHD='I;)T5U<F]P92],:G5B;&IA;F$G
M72`]("=%=7)O<&4O3&IU8FQJ86YA)SL*)'1Z6R=%=7)O<&4O3&]N9&]N)UT@
M/2`G175R;W!E+TQO;F1O;B<["B1T>ELG175R;W!E+TQU>&5M8F]U<F<G72`]
M("=%=7)O<&4O3'5X96UB;W5R9R<["B1T>ELG175R;W!E+TUA9')I9"==(#T@
M)T5U<F]P92]-861R:60G.PHD='I;)T5U<F]P92]-86QT82==(#T@)T5U<F]P
M92]-86QT82<["B1T>ELG175R;W!E+TUI;G-K)UT@/2`G175R;W!E+TUI;G-K
M)SL*)'1Z6R=%=7)O<&4O36]N86-O)UT@/2`G175R;W!E+TUO;F%C;R<["B1T
M>ELG175R;W!E+TUO<V-O=R==(#T@)T5U<F]P92]-;W-C;W<G.PHD='I;)T5U
M<F]P92]/<VQO)UT@/2`G175R;W!E+T]S;&\G.PHD='I;)T5U<F]P92]087)I
M<R==(#T@)T5U<F]P92]087)I<R<["B1T>ELG175R;W!E+U!R86=U92==(#T@
M)T5U<F]P92]0<F%G=64G.PHD='I;)T5U<F]P92]2:6=A)UT@/2`G175R;W!E
M+U)I9V$G.PHD='I;)T5U<F]P92]2;VUE)UT@/2`G175R;W!E+U)O;64G.PHD
M='I;)T5U<F]P92]386UA<F$G72`]("=%=7)O<&4O4V%M87)A)SL*)'1Z6R=%
M=7)O<&4O4V%N7TUA<FEN;R==(#T@)T5U<F]P92]386X@36%R:6YO)SL*)'1Z
M6R=%=7)O<&4O4V%R86IE=F\G72`]("=%=7)O<&4O4V%R86IE=F\G.PHD='I;
M)T5U<F]P92]3:6UF97)O<&]L)UT@/2`G175R;W!E+U-I;69E<F]P;VPG.PHD
M='I;)T5U<F]P92]3:V]P:F4G72`]("=%=7)O<&4O4VMO<&IE)SL*)'1Z6R=%
M=7)O<&4O4V]F:6$G72`]("=%=7)O<&4O4V]F:6$G.PHD='I;)T5U<F]P92]3
M=&]C:VAO;&TG72`]("=%=7)O<&4O4W1O8VMH;VQM)SL*)'1Z6R=%=7)O<&4O
M5&%L;&EN;B==(#T@)T5U<F]P92]486QL:6YN)SL*)'1Z6R=%=7)O<&4O5&ER
M86YE)UT@/2`G175R;W!E+U1I<F%N92<["B1T>ELG175R;W!E+U5Z:&=O<F]D
M)UT@/2`G175R;W!E+U5Z:&=O<F]D)SL*)'1Z6R=%=7)O<&4O5F%D=7HG72`]
M("=%=7)O<&4O5F%D=7HG.PHD='I;)T5U<F]P92]6871I8V%N)UT@/2`G175R
M;W!E+U9A=&EC86XG.PHD='I;)T5U<F]P92]6:65N;F$G72`]("=%=7)O<&4O
M5FEE;FYA)SL*)'1Z6R=%=7)O<&4O5FEL;FEU<R==(#T@)T5U<F]P92]6:6QN
M:75S)SL*)'1Z6R=%=7)O<&4O5V%R<V%W)UT@/2`G175R;W!E+U=A<G-A=R<[
M"B1T>ELG175R;W!E+UIA9W)E8B==(#T@)T5U<F]P92]:86=R96(G.PHD='I;
M)T5U<F]P92]:87!O<F]Z:'EE)UT@/2`G175R;W!E+UIA<&]R;WIH>64G.PHD
M='I;)T5U<F]P92]:=7)I8V@G72`]("=%=7)O<&4O6G5R:6-H)SL*)'1Z6R=)
M;F1I86XO06YT86YA;F%R:79O)UT@/2`G26YD:6%N+T%N=&%N86YA<FEV;R<[
M"B1T>ELG26YD:6%N+T-H86=O<R==(#T@)TEN9&EA;B]#:&%G;W,G.PHD='I;
M)TEN9&EA;B]#:')I<W1M87,G72`]("=);F1I86XO0VAR:7-T;6%S)SL*)'1Z
M6R=);F1I86XO0V]C;W,G72`]("=);F1I86XO0V]C;W,G.PHD='I;)TEN9&EA
M;B]#;VUO<F\G72`]("=);F1I86XO0V]M;W)O)SL*)'1Z6R=);F1I86XO2V5R
M9W5E;&5N)UT@/2`G26YD:6%N+TME<F=U96QE;B<["B1T>ELG26YD:6%N+TUA
M:&4G72`]("=);F1I86XO36%H92<["B1T>ELG26YD:6%N+TUA;&1I=F5S)UT@
M/2`G26YD:6%N+TUA;&1I=F5S)SL*)'1Z6R=);F1I86XO36%U<FET:75S)UT@
M/2`G26YD:6%N+TUA=7)I=&EU<R<["B1T>ELG26YD:6%N+TUA>6]T=&4G72`]
M("=);F1I86XO36%Y;W1T92<["B1T>ELG26YD:6%N+U)E=6YI;VXG72`]("=)
M;F1I86XO4F5U;FEO;B<["B1T>ELG4&%C:69I8R]!<&EA)UT@/2`G4&%C:69I
M8R]!<&EA)SL*)'1Z6R=086-I9FEC+T%U8VML86YD)UT@/2`G4&%C:69I8R]!
M=6-K;&%N9"<["B1T>ELG4&%C:69I8R]#:&%T:&%M)UT@/2`G4&%C:69I8R]#
M:&%T:&%M)SL*)'1Z6R=086-I9FEC+T5A<W1E<B==(#T@)U!A8VEF:6,O16%S
M=&5R)SL*)'1Z6R=086-I9FEC+T5F871E)UT@/2`G4&%C:69I8R]%9F%T92<[
M"B1T>ELG4&%C:69I8R]%;F1E<F)U<GDG72`]("=086-I9FEC+T5N9&5R8G5R
M>2<["B1T>ELG4&%C:69I8R]&86MA;V9O)UT@/2`G4&%C:69I8R]&86MA;V9O
M)SL*)'1Z6R=086-I9FEC+T9I:FDG72`]("=086-I9FEC+T9I:FDG.PHD='I;
M)U!A8VEF:6,O1G5N869U=&DG72`]("=086-I9FEC+T9U;F%F=71I)SL*)'1Z
M6R=086-I9FEC+T=A;&%P86=O<R==(#T@)U!A8VEF:6,O1V%L87!A9V]S)SL*
M)'1Z6R=086-I9FEC+T=A;6)I97(G72`]("=086-I9FEC+T=A;6)I97(G.PHD
M='I;)U!A8VEF:6,O1W5A9&%L8V%N86PG72`]("=086-I9FEC+T=U861A;&-A
M;F%L)SL*)'1Z6R=086-I9FEC+T=U86TG72`]("=086-I9FEC+T=U86TG.PHD
M='I;)U!A8VEF:6,O2&]N;VQU;'4G72`]("=086-I9FEC+TAO;F]L=6QU)SL*
M)'1Z6R=086-I9FEC+TIO:&YS=&]N)UT@/2`G4&%C:69I8R]*;VAN<W1O;B<[
M"B1T>ELG4&%C:69I8R]+:7)I=&EM871I)UT@/2`G4&%C:69I8R]+:7)I=&EM
M871I)SL*)'1Z6R=086-I9FEC+TMO<W)A92==(#T@)U!A8VEF:6,O2V]S<F%E
M)SL*)'1Z6R=086-I9FEC+TMW86IA;&5I;B==(#T@)U!A8VEF:6,O2W=A:F%L
M96EN)SL*)'1Z6R=086-I9FEC+TUA:G5R;R==(#T@)U!A8VEF:6,O36%J=7)O
M)SL*)'1Z6R=086-I9FEC+TUA<G%U97-A<R==(#T@)U!A8VEF:6,O36%R<75E
M<V%S)SL*)'1Z6R=086-I9FEC+TUI9'=A>2==(#T@)U!A8VEF:6,O36ED=V%Y
M)SL*)'1Z6R=086-I9FEC+TYA=7)U)UT@/2`G4&%C:69I8R].875R=2<["B1T
M>ELG4&%C:69I8R].:75E)UT@/2`G4&%C:69I8R].:75E)SL*)'1Z6R=086-I
M9FEC+TYO<F9O;&LG72`]("=086-I9FEC+TYO<F9O;&LG.PHD='I;)U!A8VEF
M:6,O3F]U;65A)UT@/2`G4&%C:69I8R].;W5M96$G.PHD='I;)U!A8VEF:6,O
M4&%G;U]086=O)UT@/2`G4&%C:69I8R]086=O(%!A9V\G.PHD='I;)U!A8VEF
M:6,O4&%L874G72`]("=086-I9FEC+U!A;&%U)SL*)'1Z6R=086-I9FEC+U!I
M=&-A:7)N)UT@/2`G4&%C:69I8R]0:71C86ER;B<["B1T>ELG4&%C:69I8R]0
M;VYA<&4G72`]("=086-I9FEC+U!O;F%P92<["B1T>ELG4&%C:69I8R]0;W)T
M7TUO<F5S8GDG72`]("=086-I9FEC+U!O<G0@36]R97-B>2<["B1T>ELG4&%C
M:69I8R]287)O=&]N9V$G72`]("=086-I9FEC+U)A<F]T;VYG82<["B1T>ELG
M4&%C:69I8R]386EP86XG72`]("=086-I9FEC+U-A:7!A;B<["B1T>ELG4&%C
M:69I8R]486AI=&DG72`]("=086-I9FEC+U1A:&ET:2<["B1T>ELG4&%C:69I
M8R]487)A=V$G72`]("=086-I9FEC+U1A<F%W82<["B1T>ELG4&%C:69I8R]4
M;VYG871A<'4G72`]("=086-I9FEC+U1O;F=A=&%P=2<["B1T>ELG4&%C:69I
M8R]4<G5K)UT@/2`G4&%C:69I8R]4<G5K)SL*)'1Z6R=086-I9FEC+U=A:V4G
M72`]("=086-I9FEC+U=A:V4G.PHD='I;)U!A8VEF:6,O5V%L;&ES)UT@/2`G
M4&%C:69I8R]786QL:7,G.PHD='I;)U!A8VEF:6,O66%P)UT@/2`G4&%C:69I
M8R]987`G.PH*)$=,3T)!3%-;)W1Z)UT@/2`F)'1Z.PH`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]E=&,O<'-A+6AO
M<F1E+VAO<F1E+W!R969S+G!H<```````````````````````````````````
M`````````````````````````````````````````#`P,#0T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#0Q,S0W(#$P-3$U-#,S-S4T(#`R,3(U-0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@)$AO<F1E.B!H;W)D92]C;VYF:6<O<')E9G,N<&AP+F1I<W0L=B`Q
M+C@U+C(N-R`R,#`V+S`V+S(R(#$X.C0W.C4U(&-H=6-K($5X<"`D"B`J"B`J
M(%!R969E<F5N8V5S($EN9F]R;6%T:6]N"B`J(#T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]"B`J($-H86YG97,@>6]U(&UA:V4@=&\@=&AE('!R969S+G!H<"!F
M:6QE*',I('=I;&P@;F]T(&)E(')E9FQE8W1E9"!U;G1I;"!T:&4*("H@=7-E
M<B!L;V=S(&]U="!A;F0@;&]G<R!I;B!A9V%I;BX*("H*("H@268@>6]U(&-H
M86YG92!T:&5S92!P<F5F97)E;F-E<R!I;B!A('!R;V1U8W1I;VX@<WES=&5M
M+"!Y;W4@=VEL;`H@*B!N965D('1O(&1E;&5T92!A;GD@:&]R9&5?<')E9G,@
M:6X@>6]U<B!P<F5F97)E;F-E<R!D871A8F%S92X*("H*("H@<')E9D=R;W5P
M<R!A<G)A>0H@*B`M+2TM+2TM+2TM+2TM+2TM"B`J("1P<F5F1W)O=7!S(&%R
M92!F;W(@9&ES<&QA>2!P=7)P;W-E<R!W:&5N('EO=2!P<F5S<R!T:&4@;W!T
M:6]N<R!B=71T;VXN"B`J(%1H92!O<'1I;VYS(&-H;VEC92!W:6QL(&%P<&5A
M<B!W:&5N('EO=2!S970@>6]U<B!P<F5F97)E;F-E<R!D<FEV97(*("H@:6X@
M=&AE(&AO<F1E+V-O;F9I9R]C;VYF+G!H<"!F:6QE+@H@*@H@*B`D<')E9D=R
M;W5P<R!A<G)A>2!D969I;FET:6]N.@H@*B`@("!C;VQU;6XZ("!7:&%T(&-O
M;'5M;B!H96%D('1H:7,@9W)O=7`@=VEL;"!G;R!U;F1E<@H@*B`@("`@;&%B
M96PZ("!,86)E;"!F;W(@=&AE(&=R;W5P(&]F('-E='1I;F=S"B`J("`@("`@
M9&5S8SH@($1E<V-R:7!T:6]N('1H870@=VEL;"!S:&]W('5N9&5R(&QA8F5L
M"B`J("`@;65M8F5R<SH@($QI<W0@;V8@<')E9F5R96YC97,@<W5P<&]R=&5D
M(&)Y('1H:7,@9W)O=7`*("H*("H@7W!R969S(&%R<F%Y"B`J("TM+2TM+2TM
M+2TM+0H@*B!4:&4@)%]P<F5F<R!A<G)A>2=S(&%R92!L:7-T960@:6X@=&AE
M('-A;64@;W)D97(@87,@;&ES=&5D(&EN('1H90H@*B!M96UB97)S(&5L96UE
M;G0@;V8@)'!R969'<F]U<',N"B`J"B`J("`@=F%L=64Z(%1H:7,@96YT<GD@
M=VEL;"!E:71H97(@:&]L9"!A(&YU;6)E<B!O<B!A('1E>'0@=F%L=64@8F%S
M960@;VX@=&AE"B`J("`@("`@("`@('!R969E<F5N8V4@='EP93H*("H@("`@
M("`@("`@("!I;7!L:6-I=#H@(%-E92!0<F5F97)E;F-E('1Y<&4*("H@("`@
M("`@("`@("`@("`@=&5X=#H@(%1E>'0@=F%L=64*("H@("`@("`@("`@("`@
M(&YU;6)E<CH@($YU;6)E<B!V86QU90H@*B`@("`@("`@("`@(&-H96-K8F]X
M.B`@5F%L=64@<VAO=6QD(&)E(#`@9F]R('5N8VAE8VME9"P@,2!F;W(@8VAE
M8VME9`H@*B`@("`@("`@("`@("`@<V5L96-T.B`@5F%L=64@87-S;V-I871E
M9"!W:71H('1H870@<V5L96-T:6]N(&QI<W0*("H*("H@(&QO8VME9#H@06QL
M;W<@<')E9F5R96YC92!T;R!B92!C:&%N9V5D(&9R;VT@54D*("H@("`@("`@
M("`@("`@=')U93H@($1O(&YO="!S:&]W('1H:7,@<')E9F5R96YC92!I;B!T
M:&4@54D*("H@("`@("`@("`@("!F86QS93H@(%-H;W<@=&AI<R!P<F5F97)E
M;F-E(&EN('1H92!522!A;F0@86QL;W<@8VAA;F=I;F<*("H*("H@('-H87)E
M9#H@4VAA<F4@=VET:"!O=&AE<B!H;W)D92!A<'!S"B`J("`@("`@("`@("`@
M('1R=64Z("!3:&%R92!T:&ES('!R968@=VET:"!O=&AE<B!(;W)D92!A<'!S
M"B`J("`@("`@("`@("`@9F%L<V4Z("!+965P('1H:7,@<')E9B!L;V-A;"!T
M;R!T:&4@8W5R<F5N="!A<'`*("H*("H@("`@='EP93H@4')E9F5R96YC92!T
M>7!E"B`J("`@("`@("`@("`@('-P96-I86PZ("!0<F]V:61E<R!A(%5)('=I
M9&=E=`H@*B`@("`@("`@("`@("`@<V5L96-T.B`@4')O=FED97,@82!S96QE
M8W1I;VX@;&ES="!I;B!T:&4@54D*("H@("`@("`@("`@("!C:&5C:V)O>#H@
M(%!R;W9I9&5S(&$@8VAE8VMB;W@*("H@("`@("`@("`@("!I;7!L:6-I=#H@
M(%!R;W9I9&5S('-T;W)A9V4@9F]R("=S<&5C:6%L)R!T>7!E<PH@*B`@("`@
M("`@("`@('!A<W-W;W)D.B`@4')O=FED97,@82!T97AT8F]X(&9O<B!P87-S
M=V]R9"!E;G1R>2X*("H@("`@("`@("`@("`@("`@96YU;3H@(%5S92!S=&%T
M:6,@;&ES="!O9B!E;&5M96YT<RXN+G-I;6EL87(@=&\@)W-E;&5C="<*("H*
M("H@("`@96YU;3H@4W1A=&EC(&QI<W0@;V8@96QE;65N=',N"B`J"B`J(&5S
M8V%P960Z($9O<B!A;B!E;G5M(&]R(&$@<V5L96-T+"!A<F4@=&AE(&ME>7,@
M86YD('9A;'5E<R!A;')E861Y(&AT;6PM97-C87!E9#\*("H@("`@("`@("`@
M1&5F875L=',@=&\@9F%L<V4@:68@;F]T('!R97-E;G0N"B`J"B`J("`@(&AO
M;VLZ($-A;&P@82!H;V]K(&9U;F-T:6]N(&9O<B!T:&4@=F%L=64@;V8@=&AI
M<R!P<F5F97)E;F-E"B`J("`@("`@("`@("`@('1R=64Z("!7:6QL(&-A;&P@
M=&AE(&9U;F-T:6]N(%]P<F5F<U]H;V]K7SQP<F5F;F%M93X*("H@("`@("`@
M("`@("`@("`@("`@('1O(&9I;&P@:6X@=&AE('9A;'5E(&]F('1H:7,@<')E
M9F5R96YC92X*("H@("`@("`@("`@("`@("`@("`@(%-E92!H;V]K<RYP:'`@
M9F]R(&UO<F4@9&5T86EL<RX*("H@("`@("`@("`@("!F86QS93H@($YO<FUA
M;"!B96AA=FEO=7(@+2!N;R!H;V]K(&ES(&-A;&QE9"X*("HO"@HD<')E9D=R
M;W5P<ULG:61E;G1I=&EE<R==(#T@87)R87DH"B`@("`G8V]L=6UN)R`]/B!?
M*")9;W5R($EN9F]R;6%T:6]N(BDL"B`@("`G;&%B96PG(#T^(%\H(E!E<G-O
M;F%L($EN9F]R;6%T:6]N(BDL"B`@("`G9&5S8R<@/3X@7R@B0VAA;F=E('1H
M92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@
M<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N(BDL"B`@("`G;65M8F5R
M<R<@/3X@87)R87DH)V1E9F%U;'1?:61E;G1I='DG+"`G:61E;G1I='ES96QE
M8W0G+"`G9&5L971E:61E;G1I='DG+`H@("`@("`@("`@("`@("`@("`@("`@
M("=I9"<L("=F=6QL;F%M92<L("=F<F]M7V%D9'(G*0HI.PH*)&%U=&@@/2`F
M075T:#HZ<VEN9VQE=&]N*"1'3$]"04Q36R=C;VYF)UU;)V%U=&@G75LG9')I
M=F5R)UTI.PII9B`H:7-?82@D875T:"P@)T%U=&@G*2`F)B`D875T:"T^:&%S
M0V%P86)I;&ET>2@G=7!D871E)RDI('L*("`@("1P<F5F1W)O=7!S6R=F;W)G
M;W1P87-S)UT@/2!A<G)A>2@*("`@("`@("`G8V]L=6UN)R`]/B!?*")9;W5R
M($EN9F]R;6%T:6]N(BDL"B`@("`@("`@)VQA8F5L)R`]/B!?*")!8V-O=6YT
M(%!A<W-W;W)D(BDL"B`@("`@("`@)V1E<V,G(#T^(%\H(E-E="!O<'1I;VYS
M('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E
M=F5R(&9O<F=E="!I="XB*2P*("`@("`@("`G;65M8F5R<R<@/3X@87)R87DH
M)W-E8W5R:71Y7W%U97-T:6]N)RP@)W-E8W5R:71Y7V%N<W=E<B<L("=A;'1E
M<FYA=&5?96UA:6PG*0H@("`@*3L*?0H*)'!R969'<F]U<'-;)VQA;F=U86=E
M)UT@/2!A<G)A>2@*("`@("=C;VQU;6XG(#T^(%\H(EEO=7(@26YF;W)M871I
M;VXB*2P*("`@("=L86)E;"<@/3X@7R@B3&]C86QE(&%N9"!4:6UE(BDL"B`@
M("`G9&5S8R<@/3X@7R@B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T
M:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(I+`H@("`@)VUE;6)E<G,G(#T^
M(&%R<F%Y*"=L86YG=6%G92<L("=T:6UE>F]N92<L("=T=V5N='E&;W5R)RP@
M)V1A=&5?9F]R;6%T)RD**3L*"B1P<F5F1W)O=7!S6R=C871E9V]R:65S)UT@
M/2!A<G)A>2@*("`@("=C;VQU;6XG(#T^(%\H(EEO=7(@26YF;W)M871I;VXB
M*2P*("`@("=L86)E;"<@/3X@7R@B0V%T96=O<FEE<R!A;F0@3&%B96QS(BDL
M"B`@("`G9&5S8R<@/3X@7R@B36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I
M97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A
M<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB*2P*("`@("=M96UB
M97)S)R`]/B!A<G)A>2@G8V%T96=O<GEM86YA9V5M96YT)RD**3L*"B1P<F5F
M1W)O=7!S6R=D:7-P;&%Y)UT@/2!A<G)A>2@*("`@("=C;VQU;6XG(#T^(%\H
M(D]T:&5R($EN9F]R;6%T:6]N(BDL"B`@("`G;&%B96PG(#T^(%\H(D1I<W!L
M87D@3W!T:6]N<R(I+`H@("`@)V1E<V,G(#T^(%\H(E-E="!Y;W5R('-T87)T
M=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG
M+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+B(I+`H@("`@)VUE;6)E<G,G
M(#T^(&%R<F%Y*"=I;FET:6%L7V%P<&QI8V%T:6]N)RP@)W-H;W=?;&%S=%]L
M;V=I;B<L("=T:&5M92<L"B`@("`@("`@("`@("`@("`@("`@("`@)W-U;6UA
M<GE?<F5F<F5S:%]T:6UE)RP@)W-H;W=?<VED96)A<B<L("=S:61E8F%R7W=I
M9'1H)RP*("`@("`@("`@("`@("`@("`@("`@("`G;6]Z7W-I9&5B87(G+"`G
M;65N=5]V:65W)RP@)VUE;G5?<F5F<F5S:%]T:6UE)RP*("`@("`@("`@("`@
M("`@("`@("`@("`G=VED9V5T7V%C8V5S<VME>2<L("=A;'!H85]F:6QT97(G
M*0HI.PH*)'!R969'<F]U<'-;)VQO9VEN=&%S:W,G72`](&%R<F%Y*`H@("`@
M)V-O;'5M;B<@/3X@7R@B3W1H97(@26YF;W)M871I;VXB*2P*("`@("=L86)E
M;"<@/3X@7R@B3&]G:6X@5&%S:W,B*2P*("`@("=D97-C)R`]/B!S<')I;G1F
M*%\H(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB
M*2P@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G;F%M92<I*2P*("`@("=M
M96UB97)S)R`]/B!A<G)A>2@G9&]?;6%I;G1E;F%N8V4G+"`G8V]N9FER;5]M
M86EN=&5N86YC92<I"BD["@HD<')E9D=R;W5P<ULG<F5M;W1E)UT@/2!A<G)A
M>2@*("`@("=C;VQU;6XG(#T^(%\H(D]T:&5R($EN9F]R;6%T:6]N(BDL"B`@
M("`G;&%B96PG(#T^(%\H(E)E;6]T92!397)V97)S(BDL"B`@("`G9&5S8R<@
M/3X@7R@B4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@
M86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(BDL"B`@("`G=7)L)R`]/B`G<V5R
M=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`G"BD["@HO+R!&;W(@86QT97)N871E
M($E-4U`@875T:&5N=&EC871I;VXN"FEF("@A96UP='DH)$=,3T)!3%-;)V-O
M;F8G75LG:6US<"==6R=E;F%B;&5D)UTI*2!["B`@("`D<')E9D=R;W5P<ULG
M:6US<&%U=&@G72`](&%R<F%Y*`H@("`@("`@("=C;VQU;6XG(#T^(%\H(D]T
M:&5R($EN9F]R;6%T:6]N(BDL"B`@("`@("`@)VQA8F5L)R`]/B!?*")!;'1E
M<FYA=&4@24U34"!,;V=I;B(I+`H@("`@("`@("=D97-C)R`]/B!?*")5<V4@
M:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R
M+B(I+`H@("`@("`@("=M96UB97)S)R`]/B!A<G)A>2@G:6US<%]A=71H7W5S
M97(G+"`G:6US<%]A=71H7W!A<W,G*0H@("`@*3L*?0H*+R\@1&5T97)M:6YE
M(&9U;F-T:6]N86QI='D@;V8@<FEC:'1E>'0@961I=&]R"B1P<F5F1W)O=7!S
M6R=R:6-H=&5X="==(#T@87)R87DH"B`@("`G8V]L=6UN)R`]/B!?*")/=&AE
M<B!);F9O<FUA=&EO;B(I+`H@("`@)VQA8F5L)R`]/B!?*")2:6-H(%1E>'0@
M161I=&]R($]P=&EO;G,B*2P*("`@("=D97-C)R`]/B!?*")7:&EC:"!P;'5G
M:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N(BDL"B`@
M("`G;65M8F5R<R<@/3X@87)R87DH)V-O;G1E>'1M96YU)RP@)W1A8FQE;W!E
M<F%T:6]N<R<L("=L:7-T='EP92<I+`HI.PII9B`H)')E9VES=')Y+3YH87-)
M;G1E<F9A8V4H)VEM86=E<R<I*2!["B`@("`D<')E9D=R;W5P<ULG<FEC:'1E
M>'0G75LG;65M8F5R<R==6UT@/2`G86YS96QI;6%G92<["GT*"B\O(%!E<G-O
M;F%L($EN9F]R;6%T:6]N('!R969E<F5N8V5S"@HO+R!D969A=6QT(&ED96YT
M:71Y"B\O(%-E="!L;V-K960@=&\@=')U92!I9B!Y;W4@9&]N)W0@=V%N="!T
M:&4@=7-E<G,@=&\@:&%V92!M=6QT:7!L92!I9&5N=&ET:65S+@HD7W!R969S
M6R=D969A=6QT7VED96YT:71Y)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@
M,"P*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@=')U
M92P*("`@("=T>7!E)R`]/B`G96YU;2<L"B`@("`G96YU;2<@/3X@*&ES<V5T
M*"1I9&5N=&ET>2D@)B8@:7-?;V)J96-T*"1I9&5N=&ET>2DI(#\@)&ED96YT
M:71Y+3YG971!;&PH)VED)RD@.B!A<G)A>2@I+`H@("`@)V1E<V,G(#T^(%\H
M(EEO=7(@9&5F875L="!I9&5N=&ET>3HB*0HI.PH*+R\@:61E;G1I=&EE<R!A
M<G)A>0HO+R!$;VXG="!C:&%N9V4@86YY=&AI;F<@:&5R92X*)%]P<F5F<ULG
M:61E;G1I=&EE<R==(#T@87)R87DH"B`@("`G=F%L=64G(#T^("=A.C`Z>WTG
M+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!T<G5E
M+`H@("`@)W1Y<&4G(#T^("=I;7!L:6-I="<**3L*"B\O(&ED96YT:71Y('-E
M;&5C=&EO;B!W:61G970*)%]P<F5F<ULG:61E;G1I='ES96QE8W0G72`](&%R
M<F%Y*`H@("`@)W-H87)E9"<@/3X@=')U92P*("`@("=T>7!E)R`]/B`G<W!E
M8VEA;"<**3L*"B\O(&1E;&5T92!B=71T;VX*)%]P<F5F<ULG9&5L971E:61E
M;G1I='DG72`](&%R<F%Y*`H@("`@)W1Y<&4G(#T^("=S<&5C:6%L)RP*("`@
M("=S:&%R960G(#T^('1R=64**3L*"B\O(&ED96YT:71Y(&YA;64*+R\@268@
M>6]U(&QO8VL@=&AI<R!P<F5F97)E;F-E+"!Y;W4@;75S="!S<&5C:69Y(&$@
M=F%L=64@;W(@82!H;V]K(&9O<B!I="!I;@HO+R!H;W)D92]C;VYF:6<O:&]O
M:W,N<&AP+@HD7W!R969S6R=I9"==(#T@87)R87DH"B`@("`G=F%L=64G(#T^
M("<G+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!T
M<G5E+`H@("`@)W1Y<&4G(#T^("=T97AT)RP*("`@("=D97-C)R`]/B!?*"))
M9&5N=&ET>2=S(&YA;64Z(BD**3L*"B\O('5S97(@9G5L;"!N86UE(&9O<B!&
M<F]M.B!L:6YE"B\O($EF('EO=2!L;V-K('1H:7,@<')E9F5R96YC92P@>6]U
M(&UU<W0@<W!E8VEF>2!A('9A;'5E(&]R(&$@:&]O:R!F;W(@:70@:6X*+R\@
M:&]R9&4O8V]N9FEG+VAO;VMS+G!H<"X*)%]P<F5F<ULG9G5L;&YA;64G72`]
M(&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`G)RP*("`@("=L;V-K960G(#T^(&9A
M;'-E+`H@("`@)W-H87)E9"<@/3X@=')U92P*("`@("=T>7!E)R`]/B`G=&5X
M="<L"B`@("`G9&5S8R<@/3X@7R@B66]U<B!F=6QL(&YA;64Z(BD**3L*"B\O
M('5S97(@<')E9F5R<F5D(&5M86EL(&%D9')E<W,@9F]R($9R;VTZ(&QI;F4*
M+R\@268@>6]U(&QO8VL@=&AI<R!P<F5F97)E;F-E+"!Y;W4@;75S="!S<&5C
M:69Y(&$@=F%L=64@;W(@82!H;V]K(&9O<B!I="!I;@HO+R!H;W)D92]C;VYF
M:6<O:&]O:W,N<&AP+@HD7W!R969S6R=F<F]M7V%D9'(G72`](&%R<F%Y*`H@
M("`@)W9A;'5E)R`]/B`G)RP*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@
M)W-H87)E9"<@/3X@=')U92P*("`@("=T>7!E)R`]/B`G=&5X="<L"B`@("`G
M9&5S8R<@/3X@(%\H(EEO=7(@1G)O;3H@861D<F5S<SHB*0HI.PH*+R\@=7-E
M<B!S96-U<FET>2!Q=65S=&EO;@HD7W!R969S6R=S96-U<FET>5]Q=65S=&EO
M;B==(#T@87)R87DH"B`@("`G=F%L=64G(#T^("<G+`H@("`@)VQO8VME9"<@
M/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!T<G5E+`H@("`@)W1Y<&4G(#T^
M("=T97AT)RP*("`@("=D97-C)R`]/B!?*")%;G1E<B!A('-E8W5R:71Y('%U
M97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O
M(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@
M;V8@>6]U<B!P970_)SHB*0HI.PH*+R\@=7-E<B!S96-U<FET>2!A;G-W97(*
M)%]P<F5F<ULG<V5C=7)I='E?86YS=V5R)UT@/2!A<G)A>2@*("`@("=V86QU
M92<@/3X@)R<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G
M(#T^('1R=64L"B`@("`G='EP92<@/3X@)W1E>'0G+`H@("`@)V1E<V,G(#T^
M(%\H(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET
M>2!Q=65S=&EO;CHB*0HI.PH*+R\@=7-E<B!A;'1E<FYA=&4@96UA:6P*)%]P
M<F5F<ULG86QT97)N871E7V5M86EL)UT@/2!A<G)A>2@*("`@("=V86QU92<@
M/3X@)R<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^
M('1R=64L"B`@("`G='EP92<@/3X@)W1E>'0G+`H@("`@)V1E<V,G(#T^(%\H
M(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C
M96EV92!T:&4@;F5W('!A<W-W;W)D.B(I"BD["@HO+R!U<V5R(&QA;F=U86=E
M"B1?<')E9G-;)VQA;F=U86=E)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@
M)R<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^('1R
M=64L"B`@("`G='EP92<@/3X@)W-E;&5C="<L"B`@("`G97-C87!E9"<@/3X@
M=')U92P*("`@("=D97-C)R`]/B!?*")396QE8W0@>6]U<B!P<F5F97)R960@
M;&%N9W5A9V4Z(BD**3L*"B\O('5S97(@=&EM92!Z;VYE"B1?<')E9G-;)W1I
M;65Z;VYE)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@)R<L"B`@("`G;&]C
M:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^('1R=64L"B`@("`G='EP
M92<@/3X@)W-E;&5C="<L"B`@("`G9&5S8R<@/3X@7R@B66]U<B!C=7)R96YT
M('1I;64@>F]N93HB*0HI.PH*+R\@=&EM92!F;W)M870*)%]P<F5F<ULG='=E
M;G1Y1F]U<B==(#T@87)R87DH"B`@("`G=F%L=64G(#T^(&9A;'-E+`H@("`@
M)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!T<G5E+`H@("`@
M)W1Y<&4G(#T^("=C:&5C:V)O>"<L"B`@("`G9&5S8R<@/3X@7R@B1&ES<&QA
M>2`R-"UH;W5R('1I;65S/R(I"BD["@HO+R!D871E(&9O<FUA=`HD7W!R969S
M6R=D871E7V9O<FUA="==(#T@87)R87DH"B`@("`G=F%L=64G(#T^("<E>"<L
M"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^('1R=64L
M"B`@("`G='EP92<@/3X@)V5N=6TG+`H@("`@)V5N=6TG(#T^(&%R<F%Y*`H@
M("`@("`@("<E>"<@/3X@<W1R9G1I;64H)R5X)RDL"B`@("`@("`@)R59+25M
M+25D)R`]/B!S=')F=&EM92@G)5DM)6TM)60G*2P*("`@("`@("`G)60O)6TO
M)5DG(#T^('-T<F9T:6UE*"<E9"\E;2\E62<I+`H@("`@("`@("<E02`E0B`E
M9"P@)5DG(#T^('-T<F9T:6UE*"<E02`E0B`E9"P@)5DG*2P*("`@("`@("`G
M)4$L("5D+B`E0B`E62<@/3X@<W1R9G1I;64H)R5!+"`E9"X@)4(@)5DG*2P*
M("`@("`@("`G)4$L("5D("5"("59)R`]/B!S=')F=&EM92@G)4$L("5D("5"
M("59)RDL"B`@("`@("`@)R5A+"`E8B`E92P@)5DG(#T^('-T<F9T:6UE*"<E
M82P@)6(@)64L("59)RDL"B`@("`@("`@)R5A+"`E8B`E92P@)7DG(#T^('-T
M<F9T:6UE*"<E82P@)6(@)64L("5Y)RDL"B`@("`@("`@)R5A+"`E8B`E92<@
M/3X@<W1R9G1I;64H)R5A+"`E8B`E92<I+`H@("`@("`@("<E82P@)64@)6(@
M)5DG(#T^('-T<F9T:6UE*"<E82P@)64@)6(@)5DG*2P*("`@("`@("`G)6$L
M("5E("5B("5Y)R`]/B!S=')F=&EM92@G)6$L("5E("5B("5Y)RDL"B`@("`@
M("`@)R5A("5D("5B("59)R`]/B!S=')F=&EM92`H)R5A("5D("5B("59)RDL
M"B`@("`@("`@)R5A("5X)R`]/B!S=')F=&EM92`H)R5A("5X)RDL"B`@("`@
M("`@)R5A("59+25M+25D)R`]/B!S=')F=&EM92`H)R5A("59+25M+25D)RDL
M"B`@("`@("`@)R5E("5B("59)R`]/B!S=')F=&EM92@G)64@)6(@)5DG*2P*
M("`@("`@("`G)64N("5B("59)R`]/B!S=')F=&EM92@G)64N("5B("59)RDL
M"B`@("`@("`@)R5E+B`E;2`E62<@/3X@<W1R9G1I;64H)R5E("5M("59)RDL
M"B`@("`@("`@)R5E+B`E;2XG(#T^('-T<F9T:6UE*"<E92X@)6TN)RDL"B`@
M("`@("`@)R5E+B`E0B<@/3X@<W1R9G1I;64H)R5E+B`E0B<I+`H@("`@("`@
M("<E92X@)4(@)5DG(#T^('-T<F9T:6UE*"<E92X@)4(@)5DG*2P*("`@("`@
M("`G)64N("5"("5Y)R`]/B!S=')F=&EM92@G)64N("5"("5Y)RDL"B`@("`@
M("`@)R5"("5E+"`E62<@/3X@<W1R9G1I;64H)R5"("5E+"`E62<I+`H@("`@
M*2P*("`@("=D97-C)R`]/B!?*")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T
M97,Z(BDI.PH*+R\@54D@=&AE;64*)%]P<F5F<ULG=&AE;64G72`](&%R<F%Y
M*`H@("`@)W9A;'5E)R`]/B`G8FQU97=H:71E)RP*("`@("=L;V-K960G(#T^
M(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@=')U92P*("`@("=T>7!E)R`]/B`G
M<V5L96-T)RP*("`@("=D97-C)R`]/B!?*")396QE8W0@>6]U<B!C;VQO<B!S
M8VAE;64N(BD**3L*"B\O(&-A=&5G;W)I97,*)%]P<F5F<ULG8V%T96=O<FEE
M<R==(#T@87)R87DH"B`@("`G=F%L=64G(#T^("<G+`H@("`@)VQO8VME9"<@
M/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!T<G5E+`H@("`@)W1Y<&4G(#T^
M("=I;7!L:6-I="<**3L*"B\O(&-A=&5G;W)Y(&-O;&]R<PHD7W!R969S6R=C
M871E9V]R>5]C;VQO<G,G72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`G)RP*
M("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@=')U92P*
M("`@("=T>7!E)R`]/B`G:6UP;&EC:70G"BD["@HO+R!522!F;W(@8V%T96=O
M<GD@;6%N86=E;65N="X*)%]P<F5F<ULG8V%T96=O<GEM86YA9V5M96YT)UT@
M/2!A<G)A>2@*("`@("=T>7!E)R`]/B`G<W!E8VEA;"<**3L*"B1?<')E9G-;
M)W-U;6UA<GE?<F5F<F5S:%]T:6UE)UT@/2!A<G)A>2@*("`@("=V86QU92<@
M/3X@,S`P+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]
M/B!F86QS92P*("`@("=T>7!E)R`]/B`G96YU;2<L"B`@("`G96YU;2<@/3X@
M87)R87DH,"`]/B!?*").979E<B(I+`H@("`@("`@("`@("`@("`@("`@(#,P
M(#T^(%\H(D5V97)Y(#,P('-E8V]N9',B*2P*("`@("`@("`@("`@("`@("`@
M("`V,"`]/B!?*")%=F5R>2!M:6YU=&4B*2P*("`@("`@("`@("`@("`@("`@
M("`S,#`@/3X@7R@B179E<GD@-2!M:6YU=&5S(BDL"B`@("`@("`@("`@("`@
M("`@("`@.3`P(#T^(%\H(D5V97)Y(#$U(&UI;G5T97,B*2P*("`@("`@("`@
M("`@("`@("`@("`Q.#`P(#T^(%\H(D5V97)Y(&AA;&8@:&]U<B(I*2P*("`@
M("=D97-C)R`]/B!?*")2969R97-H(%!O<G1A;"!6:65W.B(I"BD["@HD7W!R
M969S6R=S:&]W7W-I9&5B87(G72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B!T
M<G5E+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!T
M<G5E+`H@("`@)W1Y<&4G(#T^("=C:&5C:V)O>"<L"B`@("`G9&5S8R<@/3X@
M<W!R:6YT9BA?*")3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/R(I+"`D
M1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=N86UE)RP@)VAO<F1E)RDI"BD[
M"@HD7W!R969S6R=S:61E8F%R7W=I9'1H)UT@/2!A<G)A>2@*("`@("=V86QU
M92<@/3X@,3<U+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D
M)R`]/B!F86QS92P*("`@("=T>7!E)R`]/B`G;G5M8F5R)RP*("`@("=D97-C
M)R`]/B!S<')I;G1F*%\H(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L
M969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(I+"`D1TQ/0D%,
M4ULG<F5G:7-T<GDG72T^9V5T*"=N86UE)RP@)VAO<F1E)RDI"BD["@HD7W!R
M969S6R=M;WI?<VED96)A<B==(#T@87)R87DH"B`@("`G='EP92<@/3X@)VQI
M;FLG+`H@("`@)WAU<FPG(#T^('-P<FEN=&8H)VIA=F%S8W)I<'0Z:68@*'=I
M;F1O=RYS:61E8F%R("8F('=I;F1O=RYS:61E8F%R+F%D9%!A;F5L*2!W:6YD
M;W<N<VED96)A<BYA9&1086YE;"A<)R5S7"<L(%PG)7-<)RP@7"<E<UPG*3L@
M96QS92!A;&5R="A<)R5S7"<I.R<L"B`@("`@("`@("`@("`@("`@("`@("`D
M1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=N86UE)RP@)VAO<F1E)RDL"B`@
M("`@("`@("`@("`@("`@("`@("!5=&EL.CIA9&1087)A;65T97(H2&]R9&4Z
M.G5R;"@D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=W96)R;V]T)RP@)VAO
M<F1E)RD@+B`G+W-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<"<L('1R=64L
M("TQ*2P@)VUO>F)A<B<L("<Q)RDL"B`@("`@("`@("`@("`@("`@("`@("!(
M;W)D93HZ=7)L*"1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W=E8G)O;W0G
M+"`G:&]R9&4G*2`N("<O<')E9G,N<&AP)RP@=')U92P@+3$I+`H@("`@("`@
M("`@("`@("`@("`@("`@861D<VQA<VAE<RA?*")#;W5L9&XG="!F:6YD('1H
M92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O
M<&5N+B(I*2DL"B`@("`G9&5S8R<@/3X@<W!R:6YT9BA?*")!9&0@=&AE("5S
M($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(B*2P@)$=,3T)!3%-;)W)E9VES
M=')Y)UTM/F=E="@G;F%M92<L("=H;W)D92<I*0HI.PH*)%]P<F5F<ULG;65N
M=5]V:65W)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@)V)O=&@G+`H@("`@
M)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!T<G5E+`H@("`@
M)W1Y<&4G(#T^("=E;G5M)RP*("`@("=E;G5M)R`]/B!A<G)A>2@G=&5X="<@
M/3X@7R@B5&5X="!/;FQY(BDL"B`@("`@("`@("`@("`@("`@("`@)VEC;VXG
M(#T^(%\H(DEC;VYS($]N;'DB*2P*("`@("`@("`@("`@("`@("`@("`G8F]T
M:"<@/3X@7R@B26-O;G,@=VET:"!T97AT(BDI+`H@("`@)V1E<V,G(#T^(%\H
M(DUE;G4@;6]D93HB*0HI.PH*)%]P<F5F<ULG;65N=5]R969R97-H7W1I;64G
M72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`S,#`L"B`@("`G;&]C:V5D)R`]
M/B!F86QS92P*("`@("=S:&%R960G(#T^('1R=64L"B`@("`G='EP92<@/3X@
M)V5N=6TG+`H@("`@)V5N=6TG(#T^(&%R<F%Y*#`@/3X@7R@B3F5V97(B*2P*
M("`@("`@("`@("`@("`@("`@("`S,"`]/B!?*")%=F5R>2`S,"!S96-O;F1S
M(BDL"B`@("`@("`@("`@("`@("`@("`@-C`@/3X@7R@B179E<GD@;6EN=71E
M(BDL"B`@("`@("`@("`@("`@("`@("`@,3(P(#T^(%\H(D5V97)Y(#(@;6EN
M=71E<R(I+`H@("`@("`@("`@("`@("`@("`@(#,P,"`]/B!?*")%=F5R>2`U
M(&UI;G5T97,B*2DL"B`@("`G9&5S8R<@/3X@7R@B4F5F<F5S:"!$>6YA;6EC
M($UE;G4@16QE;65N=',Z(BD**3L*"@HO+R!,;V=I;B]-86EN=&5N86YC92!4
M87-K<R!P<F5F97)E;F-E<PH*+R\@5&\@9&ES86)L92!M86EN=&5N86YC92!E
M;G1I<F5L>2P@<V5T("=V86QU92<@/2!F86QS92!A;F0*+R\@)VQO8VME9"<@
M/2!T<G5E(&9O<B!A;&P@;V8@=&AE<V4N(%1O(&IU<W0@='5R;B!I="!O9F8@
M8GD@9&5F875L="P*+R\@<V5T("=V86QU92<@9F%L<V4@9F]R(&1O7VUA:6YT
M96YA;F-E+@HO+R!P97)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_"B1?
M<')E9G-;)V1O7VUA:6YT96YA;F-E)UT@/2!A<G)A>2@*("`@("=V86QU92<@
M/3X@=')U92P*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@
M/3X@=')U92P*("`@("=T>7!E)R`]/B`G8VAE8VMB;W@G+`H@("`@)V1E<V,G
M(#T^(%\H(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I
M;C\B*2P*("`@("=H96QP)R`]/B`G<')E9G,M9&]?;6%I;G1E;F%N8V4G*3L*
M"B\O(&QA<W0@=&EM92!M86EN=&5N86YC92!W87,@<G5N+@HO+R!V86QU92!I
M<R!A(%5.25@@=&EM97-T86UP(&]F('1H92!L87-T('1I;64@;6%I;G1E;F%N
M8V4@<F%N(&9O<B!T:&4@=7-E<BX*)%]P<F5F<ULG;&%S=%]M86EN=&5N86YC
M92==(#T@87)R87DH"B`@("`G=F%L=64G(#T^(#`L"B`@("`G;&]C:V5D)R`]
M/B!F86QS92P*("`@("=S:&%R960G(#T^('1R=64L"B`@("`G='EP92<@/3X@
M)VEM<&QI8VET)PHI.PH*+R\@8V]N9FER;2!W:&5N(&1O:6YG(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,_($EF(&9A;'-E+"!T:&5Y('=I;&P*+R\@8F4@<&5R
M9F]R;65D('=I=&@@;F\@:6YP=70@9G)O;2]C:&5C:R!W:71H('1H92!U<V5R
M+@HD7W!R969S6R=C;VYF:7)M7VUA:6YT96YA;F-E)UT@/2!A<G)A>2@*("`@
M("=V86QU92<@/3X@=')U92P*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@
M)W-H87)E9"<@/3X@=')U92P*("`@("=T>7!E)R`]/B`G8VAE8VMB;W@G+`H@
M("`@)V1E<V,G(#T^(%\H(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D
M;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(I+`H@("`@)VAE;'`G(#T^
M("=P<F5F<RUC;VYF:7)M7VUA:6YT96YA;F-E)RD["@HO+R!%;F0@3&]G:6XO
M36%I;G1E;F%N8V4@<')E9F5R96YC97,*"@HO+R!W:&%T(&%P<&QI8V%T:6]N
M('-H;W5L9"!W92!G;R!T;R!A9G1E<B!L;V=I;C\*)%]P<F5F<ULG:6YI=&EA
M;%]A<'!L:6-A=&EO;B==(#T@87)R87DH"B`@("`G=F%L=64G(#T^("=H;W)D
M92<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^('1R
M=64L"B`@("`G='EP92<@/3X@)W-E;&5C="<L"B`@("`G9&5S8R<@/3X@<W!R
M:6YT9BA?*")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F
M=&5R(&QO9VEN/R(I+"`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=N86UE
M)RDI"BD["@HO+R!S:&]U;&0@=V4@8W)E871E(&%C8V5S<R!K97ES/PHD7W!R
M969S6R=W:61G971?86-C97-S:V5Y)UT@/2!A<G)A>2@*("`@("=V86QU92<@
M/3X@=')U92P*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@
M/3X@=')U92P*("`@("=T>7!E)R`]/B`G8VAE8VMB;W@G+`H@("`@)V1E<V,G
M(#T^(%\H(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T
M(&QI;FMS/R(I"BD["@HO+R!S:&]U;&0@=V4@;F]T('5S92!T:&4@86QP:&$@
M:6UA9V4@;&]A9&5R(&9O<B!)13\*)%]P<F5F<ULG86QP:&%?9FEL=&5R)UT@
M/2!A<G)A>2@*("`@("=V86QU92<@/3X@9F%L<V4L"B`@("`G;&]C:V5D)R`]
M/B!T<G5E+`H@("`@)W-H87)E9"<@/3X@=')U92P*("`@("=T>7!E)R`]/B`G
M8VAE8VMB;W@G+`H@("`@)V1E<V,G(#T^(%\H(DEF('EO=2!D;VXG="!S964@
M86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE
M960@=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R
M96YC>2XB*0HI.PH*+R\@=&AE(&QA>6]U="!O9B!T:&4@<&]R=&%L('!A9V4N
M"B1?<')E9G-;)W!O<G1A;%]L87EO=70G72`](&%R<F%Y*`H@("`@)W9A;'5E
M)R`]/B`G83HP.GM])RP*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H
M87)E9"<@/3X@9F%L<V4L"B`@("`G='EP92<@/3X@)VEM<&QI8VET)PHI.PH*
M+R\@=&AE(')E;6]T92!S97)V97)S+@HD7W!R969S6R=R96UO=&5?<W5M;6%R
M:65S)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@)V$Z,#I[?2<L"B`@("`G
M;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@
M)W1Y<&4G(#T^("=I;7!L:6-I="<**3L*"B\O(&QA<W0@;&]G:6X@=&EM92!O
M9B!U<V5R"B\O('9A;'5E(&ES(&$@<V5R:6%L:7IE9"!A<G)A>2!O9B!T:&4@
M54Y)6"!T:6UE<W1A;7`@;V8@=&AE(&QA<W0*+R\@;&]G:6XL(&%N9"!T:&4@
M:&]S="!T:&%T('1H92!L87-T(&QO9VEN('=A<R!F<F]M+@HD7W!R969S6R=L
M87-T7VQO9VEN)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@)V$Z,#I[?2<L
M"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^('1R=64L
M"B`@("`G='EP92<@/3X@)VEM<&QI8VET)PHI.PH*+R\@<VAO=R!T:&4@;&%S
M="!L;V=I;B!T:6UE(&]F('5S97(*)%]P<F5F<ULG<VAO=U]L87-T7VQO9VEN
M)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@=')U92P*("`@("=L;V-K960G
M(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@=')U92P*("`@("=T>7!E)R`]
M/B`G8VAE8VMB;W@G+`H@("`@)V1E<V,G(#T^(%\H(E-H;W<@;&%S="!L;V=I
M;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B*0HI.PH*:68@*"%E;7!T>2@D1TQ/
M0D%,4ULG8V]N9B==6R=I;7-P)UU;)V5N86)L960G72DI('L*("`@("1?<')E
M9G-;)VEM<W!?875T:%]U<V5R)UT@/2!A<G)A>2@*("`@("`@("`G=F%L=64G
M(#T^("<G+`H@("`@("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@("`@("=S
M:&%R960G(#T^(&9A;'-E+`H@("`@("`@("=T>7!E)R`]/B`G=&5X="<L"B`@
M("`@("`@)V1E<V,G(#T^(%\H(D%L=&5R;F%T92!)35-0(%5S97)N86UE(BD*
M("`@("D["@H@("`@)%]P<F5F<ULG:6US<%]A=71H7W!A<W,G72`](&%R<F%Y
M*`H@("`@("`@("=V86QU92<@/3X@)R<L"B`@("`@("`@)VQO8VME9"<@/3X@
M9F%L<V4L"B`@("`@("`@)W-H87)E9"<@/3X@9F%L<V4L"B`@("`@("`@)W1Y
M<&4G(#T^("=P87-S=V]R9"<L"B`@("`@("`@)V1E<V,G(#T^(%\H(D%L=&5R
M;F%T92!)35-0(%!A<W-W;W)D(BD*("`@("D["GT*"B\O(%)I8V@@5&5X="!%
M9&ET;W(@<')E9F5R96YC97,N"@HD7W!R969S6R=C;VYT97AT;65N=2==(#T@
M87)R87DH"B`@("`G=F%L=64G(#T^('1R=64L"B`@("`G;&]C:V5D)R`]/B!F
M86QS92P*("`@("=S:&%R960G(#T^('1R=64L"B`@("`G='EP92<@/3X@)V-H
M96-K8F]X)RP*("`@("=D97-C)R`]/B!?*")%;F%B;&4@<FEG:'0@8VQI8VL@
M8V]N=&5X="!M96YU/R(I"BD["@HD7W!R969S6R=T86)L96]P97)A=&EO;G,G
M72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B!F86QS92P*("`@("=L;V-K960G
M(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@=')U92P*("`@("=T>7!E)R`]
M/B`G8VAE8VMB;W@G+`H@("`@)V1E<V,G(#T^(%\H(E-H;W<@=&%B;&4@;W!E
M<F%T:6]N<R!M96YU(&)A<C\B*0HI.PH*)%]P<F5F<ULG;&ES='1Y<&4G72`]
M(&%R<F%Y*`H@("`@)W9A;'5E)R`]/B!T<G5E+`H@("`@)VQO8VME9"<@/3X@
M9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!T<G5E+`H@("`@)W1Y<&4G(#T^("=C
M:&5C:V)O>"<L"B`@("`G9&5S8R<@/3X@7R@B06QL;W<@<V5T=&EN9R!O9B!O
M<F1E<F5D(&QI<W0@='EP93\B*0HI.PH*:68@*"1R96=I<W1R>2T^:&%S26YT
M97)F86-E*"=I;6%G97,G*2D@>PH@("`@)%]P<F5F<ULG86YS96QI;6%G92==
M(#T@87)R87DH"B`@("`@("`@)W9A;'5E)R`]/B!T<G5E+`H@("`@("`@("=L
M;V-K960G(#T^(&9A;'-E+`H@("`@("`@("=S:&%R960G(#T^('1R=64L"B`@
M("`@("`@)W1Y<&4G(#T^("=C:&5C:V)O>"<L"B`@("`@("`@)V1E<V,G(#T^
M(%\H(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L
M;&5R:65S(&EN('1E>'0_(BD*("`@("D["GT*"B\O($5N9"!2:6-H(%1E>'0@
M161I=&]R('!R969E<F5N8V5S+@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M971C+W!S82UH;W)D92]H;W)D92]R96=I<W1R>2YP:'``````````````````
M```````````````````````````````````````````````````````P,#`T
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-C<P-R`Q,#4Q-30S,S<U-"`P
M,C(P,#<`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J(')E9VES=')Y+G!H<"`M+2!(;W)D92!A<'!L:6-A
M=&EO;B!R96=I<W1R>2X*("H*("H@)$AO<F1E.B!H;W)D92]C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0L=B`Q+C(U-2XR+C$W(#(P,#8O,#<O,C$@,34Z-#DZ
M-#8@:F%N($5X<"`D"B`J"B`J(%1H:7,@8V]N9FEG=7)A=&EO;B!F:6QE(&ES
M('5S960@8GD@2&]R9&4@=&\@9&5T97)M:6YE('=H:6-H($AO<F1E"B`J(&%P
M<&QI8V%T:6]N<R!A<F4@:6YS=&%L;&5D(&%N9"!W:&5R92P@87,@=V5L;"!A
M<R!H;W<@=&AE>2!I;G1E<F%C="X*("H*("H@07!P;&EC871I;VX@<F5G:7-T
M<GD*("H@+2TM+2TM+2TM+2TM+2TM+2TM+2T*("H@5&AE(&9O;&QO=VEN9R!S
M971T:6YG<R!R96=I<W1E<B!I;G-T86QL960@2&]R9&4@87!P;&EC871I;VYS
M+@H@*B!">2!D969A=6QT+"!(;W)D92!A<W-U;65S('1H870@=&AE(&%P<&QI
M8V%T:6]N(&1I<F5C=&]R:65S(&QI=F4*("H@:6YS:61E('1H92!H;W)D92!D
M:7)E8W1O<GDN"B`J"B`J($%T=')I8G5T92`@("`@5'EP92`@("`@1&5S8W)I
M<'1I;VX*("H@+2TM+2TM+2TM("`@("`M+2TM("`@("`M+2TM+2TM+2TM+0H@
M*B!F:6QE<F]O="`@("`@('-T<FEN9R`@(%1H92!B87-E(&9I;&5S>7-T96T@
M<&%T:"!F;W(@=&AE(&UO9'5L92=S(&9I;&5S+@H@*B!W96)R;V]T("`@("`@
M('-T<FEN9R`@(%1H92!B87-E(%5222!F;W(@=&AE(&UO9'5L92X*("H@:G-U
M<FD@("`@("`@("!S=')I;F<@("!4:&4@8F%S92!54DD@9F]R('-T871I8R!J
M879A<V-R:7!T(&9I;&5S+@H@*B!J<V9S("`@("`@("`@('-T<FEN9R`@(%1H
M92!B87-E(&9I;&5S>7-T96T@<&%T:"!F;W(@<W1A=&EC(&IA=F%S8W)I<'0@
M9FEL97,N"B`J('1H96UE<W5R:2`@("`@<W1R:6YG("`@5&AE(&)A<V4@55))
M(&9O<B!T:&4@=&AE;65S+B!4:&ES(&-A;B!B92!U<V5D('1O"B`J("`@("`@
M("`@("`@("`@("`@("`@("`@<V5R=F4@86QL(&EC;VYS(&%N9"!S='EL92!S
M:&5E=',@9G)O;2!A('-E<&%R871E"B`J("`@("`@("`@("`@("`@("`@("`@
M("`@<V5R=F5R+@H@*B!T:&5M97-F<R`@("`@('-T<FEN9R`@(%1H92!B87-E
M(&9I;&4@<WES=&5M(&1I<F5C=&]R>2!F;W(@=&AE('1H96UE<RX*("H@:6-O
M;B`@("`@("`@("!S=')I;F<@("!4:&4@55))(&9O<B!A;B!I8V]N('1O('-H
M;W<@:6X@;65N=7,@9F]R('1H92!M;V1U;&4N"B`J("`@("`@("`@("`@("`@
M("`@("`@("`@4V5T=&EN9R!T:&ES('=I;&P@;W9E<G)I9&4@=&AE(&1E9F%U
M;'0@=&AE;64M8F%S960*("H@("`@("`@("`@("`@("`@("`@("`@("!L;V=I
M8R!I;B!T:&4@8V]D92X*("H@;F%M92`@("`@("`@("!S=')I;F<@("!4:&4@
M;F%M92!U<V5D(&EN(&UE;G5S(&%N9"!D97-C<FEP=&EO;G,@9F]R(&$@;6]D
M=6QE"B`J('-T871U<R`@("`@("`@<W1R:6YG("`@)VEN86-T:79E)RP@)VAI
M9&1E;B<L("=N;W1O;VQB87(G+"`G:&5A9&EN9R<L"B`J("`@("`@("`@("`@
M("`@("`@("`@("`@)V)L;V-K)RP@)V%D;6EN)RP@;W(@)V%C=&EV92<N"B`J
M('!R;W9I9&5S("`@("`@<W1R:6YG("`@4V5R=FEC92!T>7!E<R!T:&4@;6]D
M=6QE('!R;W9I9&5S+@H@*B!I;FET:6%L7W!A9V4@('-T<FEN9R`@(%1H92!I
M;FET:6%L("AD969A=6QT*2!P86=E("AF:6QE;F%M92D@9F]R('1H92!M;V1U
M;&4N"B`J('1E;7!L871E<R`@("`@<W1R:6YG("`@5&AE(&9I;&5S>7-T96T@
M<&%T:"!T;R!T:&4@=&5M<&QA=&5S(&1I<F5C=&]R>2X*("H@;65N=5]P87)E
M;G0@("!S=')I;F<@("!4:&4@;F%M92!O9B!T:&4@)VAE861I;F<G(&=R;W5P
M('1H870@=&AI<R!A<'`@<VAO=6QD"B`J("`@("`@("`@("`@("`@("`@("`@
M("`@<VAO=R!U<"!U;F1E<BX*("H@=&%R9V5T("`@("`@("!S=')I;F<@("!4
M:&4@*&]P=&EO;F%L*2!T87)G970@9G)A;64@9F]R('1H92!L:6YK+@H@*B!U
M<FP@("`@("`@("`@('-T<FEN9R`@(%1H92`H;W!T:6]N86PI(%523"!O9B`G
M:&5A9&EN9R<@96YT<FEE<RX*("HO"@HO+R!792!T<GD@=&\@875T;VUA=&EC
M86QL>2!D971E<FUI;F4@=&AE('!R;W!E<B!W96)R;V]T(&9O<B!(;W)D90HO
M+R!H97)E+B!4:&ES('-T:6QL(&%S<W5M97,@=&AA="!A<'!L:6-A=&EO;G,@
M;&EV92!U;F1E<B!H;W)D92\N($EF"B\O('1H:7,@<F5S=6QT<R!I;B!I;F-O
M<G)E8W0@<F5S=6QT<R!F;W(@>6]U+"!S:6UP;'D@8VAA;F=E('1H92!T=V\*
M+R\@=7-E<R!O9B!T:&4@)'=E8G)O;W0@=F%R:6%B;&4@:6X@=&AE("=H;W)D
M92<@<W1A;GIA(&)E;&]W+@HO+PHO+R!.;W1E(&9O<B!7:6YD;W=S('5S97)S
M.B!T:&4@8F5L;W<@87-S=6UE<R!T:&%T('EO=7(@4$A07U-%3$8*+R\@=F%R
M:6%B;&4@=7-E<R!F;W)W87)D('-L87-H97,N($EF(&ET(&1O97,@;F]T+"!Y
M;W4G;&P@:&%V92!T;R!T=V5A:PHO+R!T:&ES+@II9B`H:7-S970H)%]315)6
M15);)U!(4%]314Q&)UTI*2!["B`@("`D=V5B<F]O="`]('!R96=?<W!L:70H
M)SLO.R<L("1?4T525D526R=02%!?4T5,1B==+"`R+"!04D5'7U-03$E47TY/
M7T5-4%19*3L*("`@("1W96)R;V]T(#T@<W1R<W1R*&1I<FYA;64H7U]&24Q%
M7U\I+"!$25)%0U1/4EE?4T5005)!5$]2("X@87)R87E?<VAI9G0H)'=E8G)O
M;W0I*3L*("`@(&EF("@D=V5B<F]O="`A/3T@9F%L<V4I('L*("`@("`@("`D
M=V5B<F]O="`]('!R96=?<F5P;&%C92AA<G)A>2@G+UQ<7%PO)RP@)SLO8V]N
M9FEG)#LG*2P@87)R87DH)R\G+"`G)RDL("1W96)R;V]T*3L*("`@('T@96QS
M96EF("@D=V5B<F]O="`]/3T@9F%L<V4I('L*("`@("`@("`D=V5B<F]O="`]
M("<G.PH@("`@?2!E;'-E('L*("`@("`@("`D=V5B<F]O="`]("<O:&]R9&4G
M.PH@("`@?0I](&5L<V4@>PH@("`@)'=E8G)O;W0@/2`G+VAO<F1E)SL*?0H*
M)'1H:7,M/F%P<&QI8V%T:6]N<ULG:&]R9&4G72`](&%R<F%Y*`H@("`@)V9I
M;&5R;V]T)R`]/B`G+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E)RP*("`@("=W
M96)R;V]T)R`]/B`D=V5B<F]O="P*("`@("=I;FET:6%L7W!A9V4G(#T^("=L
M;V=I;BYP:'`G+`H@("`@)VYA;64G(#T^(%\H(DAO<F1E(BDL"B`@("`G<W1A
M='5S)R`]/B`G86-T:79E)RP*("`@("=T96UP;&%T97,G(#T^("<O=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S)RP*("`@("=P<F]V:61E<R<@
M/3X@)VAO<F1E)PHI.PH*+RH@"B`J($AA8VL@=&\@;6%K92!R96=I<W1E<FEN
M9R!O9B!P86-K86=E<R!E87-Y('=I=&AO=70@961I=&EN9PH@*B!C;VYF:6=U
M<F%T:6]N(&9I;&5S+"!S=&]L96X@9G)O;2!$96)I86X*("HO"@II9B`H)&0@
M/2!`;W!E;F1I<B@G+W5S<B]L;V-A;"]P<V$O971C+W!S82UH;W)D92]H;W)D
M92]R96=I<W1R>2YD)RDI('L*("`@('=H:6QE("@D9B`](')E861D:7(H)&0I
M*2![(`H@("`@("`@(&EF("AE<F5G*"(N<&AP)"(L("1F*2D@>PH@("`@("`@
M("`@("!I;F-L=61E7V]N8V4@)R\O=7-R+VQO8V%L+W!S82]E=&,O<'-A+6AO
M<F1E+VAO<F1E+W)E9VES=')Y+F0O)R`N("1F.PH@("`@("`@('T*("`@('T*
M("`@(&-L;W-E9&ER*"1D*3L*?0H`````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+V5T8R]P<V$M:&]R9&4O:&]R9&4O:&]O:W,N<&AP````````````````````
M````````````````````````````````````````````````````````,#`P
M-#0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`Q,C(S,C`@,3`U,34T,S,W-30@
M,#(Q,C4P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B!(;W)D92!(;V]K<R!C;VYF:6=U<F%T:6]N(&9I
M;&4N"B`J"B`J(%1(12!(3T]+4R!04D]6241%1"!)3B!42$E3($9)3$4@05)%
M($5804U03$53($].3%DN("!$3R!.3U0@14Y!0DQ%(%1(14T*("H@0DQ)3D1,
M62!)1B!93U4@1$\@3D]4($M.3U<@5TA!5"!93U4@05)%($1/24Y'+B`@64]5
M($A!5D4@5$\@0U535$]-25I%(%1(14T*("H@5$\@34%40T@@64]54B!34$5#
M249)0R!.145$4R!!3D0@4UE35$5-($5.5DE23TY-14Y4+@H@*@H@*B!4:&ES
M(&9I;&4@:7,@=VAE<F4@>6]U(&1E9FEN92!A;GD@:&]O:W,L(&9O<B!P<F5F
M97)E;F-E<R!O<B!G96YE<F%L($AO<F1E"B`J('5S92P@=&AA="!Y;W5R(&EN
M<W1A;&QA=&EO;B!U<V5S+B!4:&4@9G5N8W1I;VYS(&EN('1H:7,@9FEL92!C
M86X@=F%S=&QY"B`J(&-H86YG92!H;W<@>6]U<B!I;G-T86QL871I;VX@8F5H
M879E<RP@<V\@;6%K92!S=7)E('1O('1E<W0@;W5T(&%N>2!C:&%N9V5S"B`J
M(&AE<F4@8F5F;W)E(&1O:6YG('1H96T@:6X@82!P<F]D=6-T:6]N(&5N=FER
M;VYM96YT+@H@*@H@*B!(;V]K(&9U;F-T:6]N(&YA;65S(&%R92!A=71O;6%T
M:6-A;&QY(&1E=&5R;6EN960N(%1H92!F;W)M870@;V8@=&AE(&YA;64*("H@
M:7,Z"B`J"B`J(%\\='EP92!O9B!H;V]K/E]H;V]K7SQN86UE(&]F(&AO;VL^
M+@H@*@H@*B!4>7!E<R!O9B!H;V]K<R!T:&%T(&%R92!D969I;F5D(&EN('1H
M:7,@9FEL92!A<F4@)W!R969S)R`H:&]O:W,@=&\@<V5T('1H90H@*B!V86QU
M92!O9B!P<F5F97)E;F-E<RDL("=H;W)D92<@*&AO;VMS(&9O<B!T:&4@2&]R
M9&4@1G)A;65W;W)K('-C<FEP=',I(&%N9`H@*B`G87!P)R`H=VAE<F4@87!P
M(&ES(&%N>2!(;W)D92!A<'!L:6-A=&EO;B!N86UE+"!L:6ME("=I;7`G*2!H
M;V]K<R!T:&%T(&%R90H@*B!A<'!L:6-A=&EO;B!S<&5C:69I8RX*("H*("H@
M4V\L(&$@:&]O:R!T;R!S970@=&AE('!R969E<F5N8V4@)W1H96UE)R!W;W5L
M9"!B92!N86UE9`H@*B`B7W!R969S7VAO;VM?=&AE;64B+@H@*@H@*B!.3U1%
M(#$Z($AA=FEN9R!A(&AO;VL@9G5N8W1I;VX@:6X@=&AI<R!F:6QE(&1O97,@
M3D]4(&UE86X@=&AA="!T:&4@:&]O:PH@*B!W:6QL(&%U=&]M871I8V%L;'D@
M8F4@=7-E9"X@64]5($U54U0@96YA8FQE('1H92!H;V]K+B!&;W(@<')E9F5R
M96YC97,L('-E=`H@*B`G:&]O:R<@/3X@=')U92!I;B!T:&%T('!R969E<F5N
M8V5S(&%T=')I8G5T97,[(&9O<B!O=&AE<B!H;V]K<RP@=&AE<F4@=VEL;`H@
M*B!B92!A(&-O;F9I9W5R871I;VX@;W!T:6]N(&EN(&5A8V@@87!P;&EC871I
M;VXG<R!C;VYF+G!H<"!F:6QE('-U8V@@87,*("H@)&-O;F9;)VAO;VMS)UU;
M)VAO;VMN86UE)UT@=VAI8V@@;75S="!B92!S970@=&\@=')U92X*("H*("H@
M3D]412`R.B!0<F5F97)E;F-E<R!H;V]K<R!A<F4@3TY,62!E>&5C=71E9"!O
M;B!L;V=I;BX@4')E9F5R96YC97,@87)E"B`J(&-A8VAE9"!D=7)I;F<@82!U
M<V5R<R!S97-S:6]N(&%N9"P@=&\@879O:60@=6YN96-E<W-A<GD@;W9E<FAE
M860@979E<GD@=&EM90H@*B!A('!R969E<F5N8V4@:7,@86-C97-S960L('1H
M92!R97-U;'1S(&]F(&AO;VMS(&%R92!C86-H960@87,@=V5L;"X@5&AI<PH@
M*B!L96%D<R!T;R`N+BX*("H*("H@3D]412`S.B!!;GD@<')E9F5R96YC92!T
M:&%T(&ES($Y/5"!,3T-+140L('1H870@:7,@<V5T(&)Y(&$@:&]O:RP@5TE,
M3"!"10H@*B!3059%1"!7251((%1(050@5D%,544N(%1H:7,@;65A;G,@<V5V
M97)A;"!T:&EN9W,Z"B`J(#$I(%5S97)S('=I;&P@9V5T('1H92!R97-U;'1S
M(&]F('1H92!H;V]K('-E="!F;W(@=&AE;2!I;B!T:&5I<@H@*B`@("!P<F5F
M97)E;F-E<RX*("H@,BD@0GD@=FER='5E(&]F('1H:7,L('1H92!N97AT('1I
M;64@=&AE>2!L;V<@:6X@86YD(&QO860@=&AE:7(*("H@("`@<')E9F5R96YC
M97,L('1H92!H;V]K('=I;&P@3D]4(&)E(&-A;&QE9"P@8F5C875S92!I;B!T
M:&5I<B!L87-T('-E<W-I;VXL"B`J("`@('=E('-A=F5D('1H92!R97-U;'1S
M(&]F('1H92!H;V]K(&9O<B!T:&5M+B!(;W=E=F5R+"!I9B!T:&4@<')E9F5R
M96YC92!I<PH@*B`@("!L;V-K960L('1H92!R97-U;'0@;V8@=&AE(&AO;VL@
M=VEL;"!N979E<B!B92!S879E9"X*("H*("H@)$AO<F1E.B!H;W)D92]C;VYF
M:6<O:&]O:W,N<&AP+F1I<W0L=B`Q+C<S+C8N,3,@,C`P-B\P-2\R,R`P,CHQ
M,SHT,B!S96QS:WD@17AP("0*("HO"@HO+R!%>&%M<&QE('1H96UE(&AO;VL@
M9G5N8W1I;VXN(%1H:7,@<VAO=W,@:&]W('EO=2!C86X@86-C97-S('1H:6YG
M<R!L:6ME('1H90HO+R!C=7)R96YT;'D@;&]G9V5D(&EN('5S97(L(&=L;V)A
M;"!V87)I86)L97,L('-E<G9E<B!C;VYF:6<L(&5T8RX@270@:7-N)W0L"B\O
M(&AO=V5V97(L('-O;65T:&EN9R!Y;W4@<')O8F%B;'D@=V%N="!T;R!A8W1U
M86QL>2!U<V4@:6X@<')O9'5C=&EO;BP@8GD*+R\@=FER='5E(&]F(&1E;6]N
M<W1R871I;F<@86QL('1H;W-E+B`Z*0H*+R\@:68@*"%F=6YC=&EO;E]E>&ES
M=',H)U]P<F5F<U]H;V]K7W1H96UE)RDI('L*+R\@("`@(&9U;F-T:6]N(%]P
M<F5F<U]H;V]K7W1H96UE*"1U<V5R;F%M92`](&YU;&PI"B\O("`@("!["B\O
M("`@("`@("`@:68@*$%U=&@Z.F=E=$%U=&@H*2`A/2`G8VAU8VLG*2!["B\O
M("`@("`@("`@("`@(')E='5R;B`G;6]Z:6QL82<["B\O("`@("`@("`@?0HO
M+PHO+R`@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["B\O("`@("`@("`@<W=I
M=&-H("@D<F5G:7-T<GDM/F=E=$%P<"@I*2!["B\O("`@("`@("`@8V%S92`G
M:6UP)SH*+R\@("`@("`@("`@("`@<F5T=7)N("=B<F]W;B<["B\O"B\O("`@
M("`@("`@8V%S92`G='5R8F$G.@HO+R`@("`@("`@("`@("!R971U<FX@)V]R
M86YG92<["B\O"B\O("`@("`@("`@8V%S92`G:W)O;F]L:71H)SH*+R\@("`@
M("`@("`@("`@<F5T=7)N("=G<F5E;B<["B\O"B\O("`@("`@("`@9&5F875L
M=#H*+R\@("`@("`@("`@("`@<F5T=7)N("<G.PHO+R`@("`@("`@('T*+R\@
M("`@('T*+R\@?0H*+R\@17AA;7!L92!F<F]M7V%D9'(@:&]O:R!F=6YC=&EO
M;BX@5$A)4R!&54Y#5$E/3B!!4U-53453(%1(050@64]5($%212!54TE.1PHO
M+R!!3B!,1$%0(%-%4E9%4B!A;F0@=&AA="!Y;W5R("]E=&,O;&1A<"YC;VYF
M(&]R('=H97)E=F5R(&ET(&ES(&-O<G)E8W1L>2!S970*+R\@=&\@82!V86QI
M9"!H;W-T+@HO+PHO+R!9;W4@9V5T('!A<W-E9"!.3U1(24Y'.R!Y;W4@87)E
M(')E<W!O;G-I8FQE(&9O<B!B<FEN9VEN9R!I;B!T;R!S8V]P92!A;GD*+R\@
M:6YF;W)M871I;VX@>6]U(&YE960N(%EO=2!C86X@(F=L;V)A;"(@86YY=&AI
M;F<@96QS92!Y;W4@;F5E9"X@4F5T=7)N(&%N"B\O(&%D9')E<W,@+2!E:71H
M97(@:G5S="!T:&4@=7-E<D`@<VED92!O<B!A(&9U;&P@861D<F5S<R`M(&%N
M9"!I="!W:6QL(&)E"B\O('5S960N"B\O"B\O($EF('EO=2!W86YT('1O('5S
M92!T:&ES(&-O9&4@>6]U('=I;&P@;F5E9"!T;R!U;F-O;6UE;G0@:70@8F5L
M;W<N"@HO+R!I9B`H(69U;F-T:6]N7V5X:7-T<R@G7W!R969S7VAO;VM?9G)O
M;5]A9&1R)RDI('L*+R\@("`@(&9U;F-T:6]N(%]P<F5F<U]H;V]K7V9R;VU?
M861D<B@D;F%M92`](&YU;&PI"B\O("`@("!["B\O("`@("`@("`@:68@*&ES
M7VYU;&PH)&YA;64I*2!["B\O("`@("`@("`@("`@("1N86UE(#T@075T:#HZ
M9V5T075T:"@I.PHO+R`@("`@("`@('T*+R\@("`@("`@("!I9B`H(65M<'1Y
M*"1N86UE*2D@>PHO+R`@("`@("`@("`@("`D8F%S95]C;VYT97AT(#T@)V\]
M;7EO<F<G.PHO+R`@("`@("`@("`@("`D<V-O<&4@/2`G<W5B)SL*+R\*+R\@
M("`@("`@("`@("`@+R\@66]U('=I;&P@<')O8F%B;'D@;F5E9"!T;R!R97!L
M86-E(&-D/2!W:71H('5I9#T[('1H:7,*+R\@("`@("`@("`@("`@+R\@<WEN
M=&%X(&ES(&9O<B!.971W87)E(#4N,2!N;&1A<"X*+R\@("`@("`@("`@("`@
M)&-M9"`@/2`G+W5S<B]B:6XO;&1A<'-E87)C:"`M8B`G("X@)&)A<V5?8V]N
M=&5X="`N("<@+7,@)R`N("1S8V]P92`N("<@8VX])SL*+R\@("`@("`@("`@
M("`@)&-M9"`N/2!E<V-A<&53:&5L;$-M9"A!=71H.CIG971!=71H*"DI.PHO
M+R`@("`@("`@("`@("`D8VUD("X]("<@?"`O=7-R+V)I;B]G<F5P(&UA:6P@
M?"`O=7-R+V)I;B]A=VL@7"=[<')I;G0@)#)]7"<G.PHO+R`@("`@("`@("`@
M("`D;6%I;',@/2!@)&-M9&`["B\O("`@("`@("`@("`@("1M86EL7V%R<F%Y
M(#T@97AP;&]D92@B7&XB+"`D;6%I;',I.PHO+PHO+R`@("`@("`@("`@("`O
M+R!396YD(&)A8VL@=&AE(&9I<G-T(&5M86EL(&9O=6YD+"!N;W0@=&AE('=H
M;VQE(&QI<W0N"B\O("`@("`@("`@("`@("1M86EL(#T@)&UA:6Q?87)R87E;
M)S`G73L*+R\*+R\@("`@("`@("`@("`@+R\@268@;F\@96UA:6P@861D<F5S
M<R!I<R!F;W5N9"P@=&AE;B!T:&4@;&]G:6X@;F%M92!W:6QL"B\O("`@("`@
M("`@("`@("\O(&)E('5S960N"B\O("`@("`@("`@("`@(')E='5R;B`H96UP
M='DH)&UA:6PI(#\@)R<@.B`D;6%I;"D["B\O("`@("`@("`@?0HO+PHO+R`@
M("`@("`@(')E='5R;B`G)SL*+R\@("`@('T*+R\@?0H*+R\@2&5R92!I<R!A
M;F]T:&5R('=A>2!O9B!D;VEN9R!T:&4@<V%M92!T:&EN9RX*"B\O(&EF("@A
M9G5N8W1I;VY?97AI<W1S*"=?<')E9G-?:&]O:U]F<F]M7V%D9'(G*2D@>PHO
M+R`@("`@9G5N8W1I;VX@7W!R969S7VAO;VM?9G)O;5]A9&1R*"1U<V5R(#T@
M;G5L;"D*+R\@("`@('L*+R\@("`@("`@("`D;&1A<%-E<G9E<B`]("<Q-S(N
M,S$N,"XR,S8G.PHO+R`@("`@("`@("1L9&%P4&]R="`]("<S.#DG.PHO+R`@
M("`@("`@("1S96%R8VA"87-E(#T@)V\];7EO<F<G.PHO+PHO+R`@("`@("`@
M("1D<R`]($!L9&%P7V-O;FYE8W0H)&QD87!397)V97(L("1L9&%P4&]R="D[
M"B\O"B\O("`@("`@("`@:68@*&ES7VYU;&PH)'5S97(I*2!["B\O("`@("`@
M("`@("`@("1U<V5R(#T@075T:#HZ9V5T075T:"@I.PHO+R`@("`@("`@('T*
M+R\*+R\@("`@("`@("`O+R!9;W4@=VEL;"!P<F]B86)L>2!N965D('1O(')E
M<&QA8V4@8VX]('=I=&@@=6ED/3L@=&AI<PHO+R`@("`@("`@("\O('-Y;G1A
M>"!I<R!F;W(@3F5T=V%R92`U+C$@;FQD87`N"B\O("`@("`@("`@)'-E87)C
M:%)E<W5L="`]($!L9&%P7W-E87)C:"@D9',L("1S96%R8VA"87-E+"`G8VX]
M)R`N("1U<V5R*3L*+R\@("`@("`@("`D:6YF;W)M871I;VX@/2!`;&1A<%]G
M971?96YT<FEE<R@D9',L("1S96%R8VA297-U;'0I.PHO+R`@("`@("`@(&EF
M("@D:6YF;W)M871I;VY;,%U;)VUA:6PG75LP72`A/2`G)RD@>PHO+R`@("`@
M("`@("`@("`D;F%M92`]("1I;F9O<FUA=&EO;ELP75LG;6%I;"==6S!=.PHO
M+R`@("`@("`@('T@96QS92!["B\O("`@("`@("`@("`@("1N86UE(#T@)&EN
M9F]R;6%T:6]N6S!=6R=C;B==6S!=.PHO+R`@("`@("`@('T*+R\*+R\@("`@
M("`@("!L9&%P7V-L;W-E*"1D<RD["B\O"B\O("`@("`@("`@<F5T=7)N("AE
M;7!T>2@D;F%M92D@/R`D=7-E<B`Z("1N86UE*3L*+R\@("`@('T*+R\@?0H*
M+R\@2&5R92!I<R!A;B!E>&%M<&QE(&9U;&QN86UE(&AO;VL@9G5N8W1I;VX@
M=&\@<V5T('1H92!F=6QL;F%M92!F<F]M('1H92!'14-/4PHO+R!I;F9O<FUA
M=&EO;B!I;B!T:&4@<&%S<W=D(&9I;&4N"@HO+R!I9B`H(69U;F-T:6]N7V5X
M:7-T<R@G7W!R969S7VAO;VM?9G5L;&YA;64G*2D@>PHO+R`@("`@9G5N8W1I
M;VX@7W!R969S7VAO;VM?9G5L;&YA;64H)'5S97(@/2!N=6QL*0HO+R`@("`@
M>PHO+R`@("`@("`@(&EF("AI<U]N=6QL*"1U<V5R*2D@>PHO+R`@("`@("`@
M("`@("`D=7-E<B`]($%U=&@Z.F=E=$)A<F5!=71H*"D["B\O("`@("`@("`@
M?0HO+R`@("`@("`@("1A<G)A>2`]('!O<VEX7V=E='!W;F%M*"1U<V5R*3L*
M+R\@("`@("`@("`D9V5C;W-?87)R87D@/2!E>'!L;V1E*"<L)RP@)&%R<F%Y
M6R=G96-O<R==*3L*+R\@("`@("`@("!R971U<FX@*&5M<'1Y*"1G96-O<U]A
M<G)A>2D@/R`D=7-E<B`Z("1G96-O<U]A<G)A>5LP72D["B\O("`@("!]"B\O
M('T*"B\O(%1H:7,@:7,@86YO=&AE<B!E>&%M<&QE(&]F(&AO=R!T;R!G970@
M=&AE('5S97(G<R!F=6QL(&YA;64L(&EN('1H:7,@8V%S90HO+R!F<F]M(&%N
M(&QD87`@<V5R=F5R+B!);B!T:&ES(&5X86UP;&4@=V4@;&]O:R!I9B!A(%-P
M86YI<V@@;F%M92!E>&ES=',@86YD"B\O(')E='5R;B!T:&ES(&]R('1H92!S
M=&%N9&%R9"`G8VXG(&5N=')Y(&EF(&YO="X*"B\O(&EF("@A9G5N8W1I;VY?
M97AI<W1S*"=?<')E9G-?:&]O:U]F=6QL;F%M92<I*2!["B\O("`@("!F=6YC
M=&EO;B!?<')E9G-?:&]O:U]F=6QL;F%M92@D=7-E<B`](&YU;&PI"B\O("`@
M("!["B\O("`@("`@("`@)&QD87!397)V97(@/2`G;&1A<"YE>&%M<&QE+F-O
M;2<["B\O("`@("`@("`@)&QD87!0;W)T(#T@)S,X.2<["B\O("`@("`@("`@
M)'-E87)C:$)A<V4@/2`G;W4]<&5O<&QE+&\]97AA;7!L92YC;VTG.PHO+R`@
M("`@("`@("1L9&%P8VAA<G-E="`]("=U=&8M."<["B\O("`@("`@("`@)&]U
M='!U=&-H87)S970@/2!.3%,Z.F=E=$-H87)S970H*3L*+R\*+R\@("`@("`@
M("`D9',@/2!`;&1A<%]C;VYN96-T*"1L9&%P4V5R=F5R+"`D;&1A<%!O<G0I
M.PHO+PHO+R`@("`@("`@(&EF("AI<U]N=6QL*"1U<V5R*2D@>PHO+R`@("`@
M("`@("`@("`D=7-E<B`]($%U=&@Z.F=E=$%U=&@H*3L*+R\@("`@("`@("!]
M"B\O("`@("`@("`@)'-E87)C:%)E<W5L="`]($!L9&%P7W-E87)C:"@D9',L
M("1S96%R8VA"87-E+"`G=6ED/2<@+B`D=7-E<BD["B\O("`@("`@("`@)&EN
M9F]R;6%T:6]N(#T@0&QD87!?9V5T7V5N=')I97,H)&1S+"`D<V5A<F-H4F5S
M=6QT*3L*+R\@("`@("`@("!I9B`H)&EN9F]R;6%T:6]N6S!=6R=C;CML86YG
M+65S)UU;,%T@(3T@)R<I('L*+R\@("`@("`@("`@("`@)&YA;64@/2`D:6YF
M;W)M871I;VY;,%U;)V-N.VQA;F<M97,G75LP73L*+R\@("`@("`@("!](&5L
M<V4@>PHO+R`@("`@("`@("`@("`D;F%M92`]("1I;F9O<FUA=&EO;ELP75LG
M8VXG75LP73L*+R\@("`@("`@("!]"B\O"B\O("`@("`@("`@;&1A<%]C;&]S
M92@D9',I.PHO+PHO+R`@("`@("`@("1N86UE(#T@4W1R:6YG.CIC;VYV97)T
M0VAA<G-E="@D;F%M92P@)&QD87!C:&%R<V5T+"`D;W5T<'5T8VAA<G-E="D[
M"B\O("`@("`@("`@<F5T=7)N("AE;7!T>2@D;F%M92D@/R`D=7-E<B`Z("1N
M86UE*3L*+R\@("`@('T*+R\@?0H*+R\@2&5R92!I<R!A;B!E>&%M<&QE('-I
M9VYA='5R92!H;V]K(&9U;F-T:6]N('1O('-E="!T:&4@<VEG;F%T=7)E(&9R
M;VT@=&AE"B\O('-Y<W1E;2!T86=L:6YE<R!F:6QE.R!T:&4@<W1R:6YG("(E
M5$%')2(@*&EF('!R97-E;G0@:6X@82!U<V5R)W,@<VEG;F%T=7)E*0HO+R!W
M:6QL(&)E(')E<&QA8V5D(&)Y('1H92!C;VYT96YT(&]F('1H92!F:6QE("(O
M=7-R+W-H87)E+W1A9VQI;F4B("AG96YE<F%T960*+R\@8GD@=&AE(")485)4
M(B!U=&EL:71Y*2X*+R\*+R\@3F]T:6-E(&AO=R!W92!G;&]B86P@:6X@=&AE
M("1P<F5F<R!A<G)A>2!T;R!G970@=&AE('5S97(G<R!C=7)R96YT"B\O('-I
M9VYA='5R92X*"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?<')E9G-?:&]O
M:U]S:6=N871U<F4G*2D@>PHO+R`@("`@9G5N8W1I;VX@7W!R969S7VAO;VM?
M<VEG;F%T=7)E*"1U<V5R;F%M92`](&YU;&PI"B\O("`@("!["B\O("`@("`@
M("`@)'-I9R`]("1'3$]"04Q36R=P<F5F<R==+3YG971686QU92@G<VEG;F%T
M=7)E)RD["B\O("`@("`@("`@:68@*'!R96=?;6%T8V@H)R\E5$%')2\G+"`D
M<VEG*2D@>PHO+R`@("`@("`@("`@("`D=&%G(#T@8&-A="`O=7-R+W-H87)E
M+W1A9VQI;F5@.PHO+R`@("`@("`@("`@("`D<VEG(#T@<')E9U]R97!L86-E
M*"=\)51!1R5\)RP@)'1A9RP@)'-I9RD["B\O("`@("`@("`@?0HO+R`@("`@
M("`@(')E='5R;B`D<VEG.PHO+R`@("`@?0HO+R!]"@HO+R!)12!O;B!-86,@
M:&%N9W,@=VAE;B!T:&5R92!A<F4@<V5V97)A;"!I8V]N<R!T;R!B92!L;V%D
M960N($%T(&QE87-T(&]N('-O;64*+R\@<WES=&5M<RX@5&AI<R!H;V]K(&1I
M<V%B;&5S('1H92!S:&]W7VEC;VYS('!R969E<F5N8V4@9G)O;2!+<F]N;VYL
M:71H(&9O<@HO+R!T:&5S92!B<F]W<V5R<RX*"B\O(&EF("@A9G5N8W1I;VY?
M97AI<W1S*"=?<')E9G-?:&]O:U]S:&]W7VEC;VYS)RDI('L*+R\@("`@(&9U
M;F-T:6]N(%]P<F5F<U]H;V]K7W-H;W=?:6-O;G,H*0HO+R`@("`@>PHO+R`@
M("`@("`@(&=L;V)A;"`D8G)O=W-E<CL*+R\@("`@("`@("!I9B`H)&)R;W=S
M97(M/F=E=%!L871F;W)M*"D@/3T@)VUA8R<@)B8*+R\@("`@("`@("`@("`@
M)&)R;W=S97(M/F=E=$)R;W=S97(H*2`]/2`G;7-I92<I('L*+R\@("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PHO+R`@("`@("`@('T@96QS92!["B\O("`@
M("`@("`@("`@(')E='5R;B!T<G5E.PHO+R`@("`@("`@('T*+R\@("`@('T*
M+R\@?0H*+R\@5&AI<R!H;V]K(&ES(&-A;&QE9"!W:&5N(&$@=7-E<B!S=6)M
M:71S(&$@<VEG;G5P(')E<75E<W0N("!)="!A;&QO=W,*+R\@82!C:&%N8V4@
M=&\@86QT97(@;W(@=F%L:61A=&4@=&AE(&1A=&$@<W5B;6ET=&5D(&)Y(&$@
M=7-E<B!B969O<F4@86YY"B\O(&%T=&5M<'1S(&%R92!M861E('1O(&%D9"!T
M:&5M('1O('1H92!S>7-T96TN"@HO+R!I9B`H(69U;F-T:6]N7V5X:7-T<R@G
M7VAO<F1E7VAO;VM?<VEG;G5P7W!R97!R;V-E<W,G*2D@>PHO+R`@("`@9G5N
M8W1I;VX@7VAO<F1E7VAO;VM?<VEG;G5P7W!R97!R;V-E<W,H)&EN9F\I('L*
M+R\@("`@("`@("`D:6YF;ULG=7-E<E]N86UE)UT@/2!3=')I;F<Z.FQO=V5R
M*"1I;F9O6R=U<V5R7VYA;64G72D["B\O("`@("`@("`@<F5T=7)N("1I;F9O
M.PHO+R`@("`@?0HO+R!]"@HO+R!4:&ES(&AO;VL@:7,@8V%L;&5D('=H96X@
M82!S:6=N=7`@:7,@<75E=65D(&9O<B!A9&UI;FES=')A=&EV92!A<'!R;W9A
M;"X*+R\@5&AI<R!E>&%M<&QE('-E;F1S(&$@;F]T:69I8V%T:6]N(&UE<W-A
M9V4@=&\@=&AE('=E8B!S97)V97(*+R\@861M:6YI<W1R871O<B=S(&4M;6%I
M;"!A9&1R97-S+@H*+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]H;W)D95]H
M;V]K7W-I9VYU<%]Q=65U960G*2D@>PHO+R`@("`@9G5N8W1I;VX@7VAO<F1E
M7VAO;VM?<VEG;G5P7W%U975E9%]W86QK9&%T82@D9FEE;&1S+"`D9&%T82D*
M+R\@("`@('L*+R\@("`@("`@("`D;7-G(#T@)R<["B\O("`@("`@("`@9F]R
M96%C:"`H)&1A=&$@87,@)&9I96QD(#T^("1V86QU92D@>PHO+R`@("`@("`@
M("`@("!I9B`H)&9I96QD(#T]("=P87-S=V]R9"<@?'P@)&9I96QD(#T]("=U
M<FPG*2!["B\O("`@("`@("`@("`@("`@("!C;VYT:6YU93L*+R\@("`@("`@
M("`@("`@?0HO+PHO+R`@("`@("`@("`@("!I9B`H:7-?87)R87DH)'9A;'5E
M*2D@>PHO+R`@("`@("`@("`@("`@("`@)&US9R`N/2!?:&]R9&5?:&]O:U]S
M:6=N=7!?<75E=65D7W=A;&MD871A*"1F:65L9',L("1V86QU92D["B\O("`@
M("`@("`@("`@('T@96QS92!["B\O("`@("`@("`@("`@("`@("`D9FEE;&0@
M/2!I<W-E="@D9FEE;&1S6R1F:65L9%U;)VQA8F5L)UTI(#\*+R\@("`@("`@
M("`@("`@("`@("`@("`@("`@("1F:65L9'-;)&9I96QD75LG;&%B96PG72`Z
M("1F:65L9#L*+R\@("`@("`@("`@("`@("`@("1M<V<@+CT@(B1F:65L9#H@
M)'9A;'5E7&XB.PHO+R`@("`@("`@("`@("!]"B\O("`@("`@("`@?0HO+R`@
M("`@("`@(')E='5R;B`D;7-G.PHO+R`@("`@?0HO+PHO+R`@("`@9G5N8W1I
M;VX@7VAO<F1E7VAO;VM?<VEG;G5P7W%U975E9"@D=7-E<DE$+"`D9&%T82D*
M+R\@("`@('L*+R\@("`@("`@("!R97%U:7)E7V]N8V4@)TUA:6PN<&AP)SL*
M+R\@("`@("`@("!G;&]B86P@)&-O;F8L("1R96=I<W1R>3L*+R\*+R\@("`@
M("`@("`D:&5A9&5R<R`](&%R<F%Y*`HO+R`@("`@("`@("`@("`G5&\G("`@
M("`@/3X@)%]315)615);)U-%4E9%4E]!1$U)3B==+`HO+R`@("`@("`@("`@
M("`G1G)O;2<@("`@/3X@)%]315)615);)U-%4E9%4E]!1$U)3B==+`HO+R`@
M("`@("`@("`@("`G4W5B:F5C="<@/3X@)TYE=R`G("X@)')E9VES=')Y+3YG
M970H)VYA;64G+"`G:&]R9&4G*2`N("<@4VEG;G5P)PHO+R`@("`@("`@("D[
M"B\O"B\O("`@("`@("`@)&5X=')A1FEE;&1S(#T@2&]R9&4Z.F-A;&Q(;V]K
M*"=?:&]R9&5?:&]O:U]S:6=N=7!?9V5T97AT<F$G*3L*+R\*+R\@("`@("`@
M("`D;7-G("`](%\H(D$@;F5W('-I9VYU<"!H87,@8F5E;B!R96-E:79E9"!A
M;F0@:7,@87=A:71I;F<@>6]U<B!A<'!R;W9A;"XB*3L*+R\@("`@("`@("`D
M;7-G("X](")<;EQN(CL*+R\@("`@("`@("`D;7-G("X](%]H;W)D95]H;V]K
M7W-I9VYU<%]Q=65U961?=V%L:V1A=&$H)&5X=')A1FEE;&1S+"`D9&%T82D[
M"B\O("`@("`@("`@)&US9R`N/2`B7&XB.PHO+R`@("`@("`@("1M<V<@+CT@
M<W!R:6YT9BA?*")9;W4@8V%N(&%P<')O=F4@=&AI<R!S:6=N=7`@870@)7,B
M*2P@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=A9&UI;B]U<V5R+G!H<"<L('1R
M=64L("TQ*2D["B\O"B\O("`@("`@("`@)&UA:6QE<B`]($UA:6PZ.F9A8W1O
M<GDH)&-O;F9;)VUA:6QE<B==6R=T>7!E)UTL("1C;VYF6R=M86EL97(G75LG
M<&%R86US)UTI.PHO+R`@("`@("`@(')E='5R;B`D;6%I;&5R+3YS96YD*"1?
M4T525D526R=315)615)?041-24XG72P@)&AE861E<G,L("1M<V<I.PHO+R`@
M("`@?0HO+R!]"@HO+R!(97)E(&ES(&%N(&5X86UP;&4@7VAO<F1E7VAO;VM?
M<VEG;G5P7V=E=&5X=')A(&9U;F-T:6]N+B!)="!R971U<FYS(&%N>0HO+R!E
M>'1R82!F:65L9',@=VAI8V@@;F5E9"!T;R!B92!F:6QL960@:6X@=VAE;B!A
M(&YO;B!R96=I<W1E<F5D('5S97(@=VES:&5S"B\O('1O('-I9VX@=7`N"B\O
M(%1H92!E>&%M<&QE(&AE<F4@=&%K97,@=&AE(&AY<&]T:&5T:6-A;"!C87-E
M('=H97)E('=E('=O=6QD('=A;G0@=&\@<W1O<F4*+R\@97AT<F$@:6YF;W)M
M871I;VX@86)O=70@82!U<V5R(&EN=&\@82!T=7)B82!S<6P@861D<F5S<R!B
M;V]K+B!!;&P@=&AI<PHO+R!F=6YC=&EO;B!D;V5S('1H96X@:7,@=&\@:6YC
M;'5D92!T:&4@871T<FEB=71E<RYP:'`@9FEL92!F<F]M('1H92!T=7)B80HO
M+R!C;VYF:6<@9&ER96-T;W)Y(&%N9"!R971U<FX@=&AE("1A='1R:6)U=&5S
M(&%R<F%Y+@HO+R!/=&AE<G=I<V4@86YY('-T<G5C='5R92!T:&%T('=O=6QD
M(')E='5R;B!A;B!A<G)A>2!W:71H('1H92!F;VQL;W=I;F<*+R\@<WEN=&%X
M('=O=6QD(&)E('9A;&ED.@HO+R`@("1S;VUE87)R87E;)W-O;65F:65L9&YA
M;64G72`](&%R<F%Y*"XN+@HO+R`@("`@(&QA8F5L("`@("T@=&AE('1E>'0@
M=&AA="!T:&4@=7-E<B!W:6QL('-E92!A='1A8VAE9"!T;R!T:&ES(&9I96QD
M"B\O("`@("`@='EP92`@("`@+2!A;GD@86QL;W=E9"!(;W)D95]&;W)M(&9I
M96QD('1Y<&4*+R\@("`@("!P87)A;7,@("`M(&%N>2!A;&QO=V5D('!A<F%M
M971E<B!T;R!(;W)D95]&;W)M(&9I96QD('1Y<&5S"B\O("`@("`@<F5Q=6ER
M960@+2!B;V]L96%N+"!T<G5E(&]R(&9A;'-E('=H971H97(@=&AI<R!F:65L
M9"!I<R!M86YD871O<GD*+R\@("`@("!R96%D;VYL>2`M(&)O;VQE86XL('1R
M=64@;W(@9F%L<V4@=VAE=&AE<B!T:&ES(&5D:71A8FQE"B\O("`@("`@9&5S
M8R`@("`@+2!A;GD@:&5L<"!T97AT(&%T=&%C:&5D('1O('1H92!F:65L9`HO
M+R!.3U1%.B!9;W4@1$\@3D5%1"!4=7)B82!T;R!B92!C;W)R96-T;'D@:6YS
M=&%L;&5D(&)E9F]R92!Y;W4@8V%N('5S92!T:&ES"B\O(&5X86UP;&4@8F5L
M;W<N"@HO+R!I9B`H(69U;F-T:6]N7V5X:7-T<R@G7VAO<F1E7VAO;VM?<VEG
M;G5P7V=E=&5X=')A)RDI('L*+R\@("`@(&9U;F-T:6]N(%]H;W)D95]H;V]K
M7W-I9VYU<%]G971E>'1R82@I"B\O("`@("!["B\O("`@("`@("`@9VQO8F%L
M("1R96=I<W1R>3L*+R\@("`@("`@("!R97%U:7)E("1R96=I<W1R>2T^9V5T
M*"=F:6QE<F]O="<L("=T=7)B82<I("X@)R]C;VYF:6<O871T<FEB=71E<RYP
M:'`G.PHO+R`@("`@("`@(')E='5R;B`D871T<FEB=71E<SL*+R\@("`@('T*
M+R\@?0H*+R\@1F]L;&]W:6YG(&]N(&9R;VT@=&AE(&5X86UP;&4@:6X@=&AE
M(&%B;W9E(&9U;F-T:6]N+"!T:&ES(&ES(&AO=R!A('-A;7!L90HO+R!?:&]R
M9&5?:&]O:U]S:6=N=7!?861D97AT<F$@9G5N8W1I;VX@=V]U;&0@;&]O:R!L
M:6ME+@HO+R!(97)E('=E(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E('5S:6YG
M('1H92!S<6P@<&%R86UE=&5R<R!C;VYF:6=U<F5D(&EN"B\O("1C;VYF(&%N
M9"!S=&]R92!T:&4@97AT<F$@9FEE;&1S(&EN('1U<F)A7V]B:F5C=',L('5S
M:6YG('1H92`D=7-E<DED(&%S('1H90HO+R!K97D@9F]R('1H92!O8FIE8W0@
M86YD('9A;'5E<R!F<F]M('1H92`D97AT<F$@87)R87DN"B\O(%EO=2!C;W5L
M9"!C<F5A=&4@>6]U<B!O=VX@<W%L('-Y;G1A>"!O<B!C;V1E('1O('-T;W)E
M('1H:7,@:6X@=VAI8VAE=F5R"B\O(&)A8VME;F0@>6]U(')E<75I<F4N"B\O
M($Y/5$4Z(%EO=2!$3R!.145$(%1U<F)A('1O(&)E(&-O<G)E8W1L>2!I;G-T
M86QL960@8F5F;W)E('EO=2!C86X@=7-E('1H:7,*+R\@97AA;7!L92!B96QO
M=RX@270@86QS;R!A<W-U;65S('1H870@>6]U(&%R92!U<VEN9R!A;B!344P@
M8F%C:V5N9"X*"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?:&]R9&5?:&]O
M:U]S:6=N=7!?861D97AT<F$G*2D@>PHO+R`@("`@9G5N8W1I;VX@7VAO<F1E
M7VAO;VM?<VEG;G5P7V%D9&5X=')A*"1U<V5R240L("1E>'1R82D*+R\@("`@
M('L*+R\@("`@("`@("!G;&]B86P@)&-O;F8["B\O"B\O("`@("`@("`@<F5Q
M=6ER95]O;F-E("=$0BYP:'`G.PHO+R`@("`@("`@("1?9&(@/2`F1$(Z.F-O
M;FYE8W0H)&-O;F9;)W-Q;"==+"!T<G5E*3L*+R\*+R\@("`@("`@("`D9FEE
M;&1S(#T@87)R87DH*3L*+R\@("`@("`@("`D=F%L=65S(#T@87)R87DH*3L*
M+R\@("`@("`@("!F;W)E86-H("@D97AT<F$@87,@)&9I96QD(#T^("1V86QU
M92D@>PHO+R`@("`@("`@("`@("`D9FEE;&1S6UT@/2`G;V)J96-T7R<@+B!3
M=')I;F<Z.FQO=V5R*"1F:65L9"D["B\O("`@("`@("`@("`@("1V86QU97-;
M72`]("1?9&(M/G%U;W1E*%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'9A;'5E
M+"!.3%,Z.F=E=$-H87)S970H*2P@)&-O;F9;)W-Q;"==6R=C:&%R<V5T)UTI
M*3L*+R\@("`@("`@("!]"B\O("`@("`@("`@)&9I96QD<UM=(#T@)V]B:F5C
M=%]I9"<["B\O("`@("`@("`@)'9A;'5E<UM=(#T@)%]D8BT^<75O=&4H)'5S
M97))1"D["B\O"B\O("`@("`@("`@)'%U97)Y("`]("=)3E-%4E0@24Y43R!T
M=7)B85]O8FIE8W1S("@@;W=N97)?:60L("<@+B!I;7!L;V1E*"<L("<L("1F
M:65L9',I("X@)RDG.PHO+R`@("`@("`@("1Q=65R>2`N/2`G(%9!3%5%4R`H
M(%PG861M:6Y<)RP@)R`N(&EM<&QO9&4H)RP@)RP@)'9A;'5E<RD@+B`G*2<[
M"B\O("`@("`@("`@)')E<W5L="`]("1?9&(M/G%U97)Y*"1Q=65R>2D["B\O
M"B\O("`@("`@("`@<F5T=7)N(&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G
M*2`_("1R97-U;'0@.B!T<G5E.PHO+R`@("`@?0HO+R!]"@HO+R!(97)E(&ES
M(&%N(&5X86UP;&4@7VAO<F1E7VAO;VM?<')E875T:&5N=&EC871E('1H870@
M;6%K92!(;W)D92!R97-P96-T('1H90HO+R!5;FEX(&-O;G9E;G1I;VX@;V8@
M;F]T(&%L;&]W:6YG(&QO9VEN('=H96X@82!F:6QE(&YA;65D("]E=&,O;F]L
M;V=I;B!E>&ES="X*+R\@5&AI<R!F=6YC=&EO;B!G970@<&%S<V5D('1H92!U
M<V5R;F%M92P@8W)E9&5N=&EA;"!A;F0@<F5A;&T@:6YF;W)M871I;VX@8G5T
M"B\O('1H97D@87)E(&YO="!U<V5D(&EN('1H:7,@97AA;7!L92X*"B\O(&EF
M("@A9G5N8W1I;VY?97AI<W1S*"=?:&]R9&5?:&]O:U]P<F5A=71H96YT:6-A
M=&4G*2D@>PHO+R`@("`@9G5N8W1I;VX@7VAO<F1E7VAO;VM?<')E875T:&5N
M=&EC871E*"1U<V5R240L("1C<F5D96YT:6%L+"`D<F5A;&TI"B\O("`@("![
M"B\O("`@("`@("`@<F5T=7)N("%F:6QE7V5X:7-T<R@G+V5T8R]N;VQO9VEN
M)RD["B\O("`@("!]"B\O('T*"B\O($AE<F4@:7,@86X@97AA;7!L92!O9B!V
M86QI9&%T:6YG('1H92!U<V5R)W,@<FEG:'0@=&\@;&]G:6X@=&\@2&]R9&4@
M8GD*+R\@8V]N<W5L=&EN9R!G<F]U<"!M96UB97)S:&EP(&EN(&%N($Q$05`@
M9&ER96-T;W)Y+B`@5&AA="!W87DL(&EF('EO=7(@2&]R9&4*+R\@:6YS=&%L
M;&%T:6]N(&ES(&-O;F9I9W5R960@=&\@875T:&5N=&EC871E(&%G86EN<W0@
M24U0('=H:6-H(&EN('1U<FX*+R\@875T:&5N=&EC871E('9I82!)34%0+"!I
M="!I<R!S=&EL;"!P;W-S:6)L92!T;R!L:6UI="!A8V-E<W,@=&\@2&]R9&4@
M8GD*+R\@9W)O=7`@;65M8F5R<VAI<"X@(%1H92!F;VQL;W=I;F<@97AA;7!L
M92!H860@8F5E;B!M861E('=I=&@@86X@35,@06-T:79E"B\O($1I<F5C=&]R
M>2!I;B!M:6YD+B`@3F]T92!T:&%T(&EF('1H92!,1$%0(&1I<F5C=&]R>2!I
M<R!U;F%V86EL86)L92!O<B!S;VUE"B\O(&]T:&5R(&5R<F]R(&]C8W5R+"!A
M=71H96YT:6-A=&EO;B!W:6QL(&9A:6PN"@HO+R!I9B`H(69U;F-T:6]N7V5X
M:7-T<R@G7VAO<F1E7VAO;VM?<&]S=&%U=&AE;G1I8V%T92<I*2!["B\O("`@
M("!F=6YC=&EO;B!?:&]R9&5?:&]O:U]P;W-T875T:&5N=&EC871E*"1U<V5R
M240L("1C<F5D96YT:6%L+"`D<F5A;&TI"B\O("`@("!["B\O("`@("`@("`@
M)&QD87!397)V97(@/2`G860N97AA;7!L92YC;VTG.PHO+R`@("`@("`@("1L
M9&%P4&]R="`]("<S.#DG.PHO+R`@("`@("`@("\O($YO=&4@=&AA="!C<F5D
M96YT:6%L(&ES('-E;G0@<&QA:6XM=&5X="!I;B!T:&ES(&-A<V4L('-O(&1O
M;B=T('5S90HO+R`@("`@("`@("\O('!R:79I;&5G960@86-C;W5N="!H97)E
M(&]R('-E='5P(%-33"`H8GD@=7-I;F<@<&]R="`V,S8@86)O=F4I+@HO+R`@
M("`@("`@("1B:6YD9&X@/2`G8VX]5VET:&]U=%!R:79I;&5G92QD8SUU;&%V
M86PM9&5V+&1C/6-A)SL*+R\@("`@("`@("`D8FEN9'!W(#T@)U)E;65M8F5R
M('1H:7,@:7,@<V5N="!I;B!T:&4@8VQE87(@=6YL97-S(%-33"!I<R!U<V5D
M)SL*+R\@("`@("`@("`D<V5A<F-H0F%S92`]("=O=3U096]P;&4L9&,]97AA
M;7!L92QD8SUC;VTG.PHO+R`@("`@("`@("\O($%T=')I8G5T92!T;R!M871C
M:"`D=7-E<DE$(&%G86EN<W0@:6X@<V5A<F-H"B\O("`@("`@("`@)'5S97)!
M='1R(#T@)W-!34%C8V]U;G1.86UE)SL*+R\@("`@("`@("`O+R!'<F]U<"!M
M96UB97)S:&EP(&%T=')I8G5T92P@;F5E9"!T;R!B92!A;&P@;&]W97)C87-E
M"B\O("`@("`@("`@)&=R;W5P071T<B`]("=M96UB97)O9B<["B\O("`@("`@
M("`@+R\@071T<FEB=71E('1O(&-H96-K(&9O<B!R:6=H="!T;R!U<V4@2&]R
M9&4*+R\@("`@("`@("`D9W)O=7!D;B`]("=C;CU(;W)D955S97(L;W4]4&5O
M<&QE+&1C/65X86UP;&4L9&,]8V]M)SL*+R\@("`@("`@("`D<F5T(#T@=')U
M93L*+R\*+R\@("`@("`@("`D9',@/2!`;&1A<%]C;VYN96-T*"1L9&%P4V5R
M=F5R+"`D;&1A<%!O<G0I.PHO+PHO+R`@("`@("`@(&EF("A`;&1A<%]B:6YD
M*"1D<RP@)&)I;F1D;BP@)&)I;F1P=RDI('L*+R\@("`@("`@("`@("`@)'-E
M87)C:%)E<W5L="`]($!L9&%P7W-E87)C:"@D9',L("1S96%R8VA"87-E+"`D
M=7-E<D%T='(@+B`G/2<@+B`D=7-E<DE$+"!A<G)A>2@D9W)O=7!!='1R*2P@
M,"P@,2P@-2D["B\O("`@("`@("`@("`@(&EF("@D:6YF;W)M871I;VX@/2!`
M;&1A<%]G971?96YT<FEE<R@D9',L("1S96%R8VA297-U;'0I*2!["B\O("`@
M("`@("`@("`@("`@("`O+R!M86ME('!A='1E<FX@8V%S92UI;G-E;G-I=&EV
M90HO+R`@("`@("`@("`@("`@("`@)'!A='1E<FX@/2`G+R<@+B`D9W)O=7!D
M;B`N("<O:2<["B\O("`@("`@("`@("`@("`@("!F;W)E86-H("@D:6YF;W)M
M871I;VY;,%U;)&=R;W5P071T<ET@87,@)&=R;W5P*2!["B\O("`@("`@("`@
M("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)'!A='1E<FXL("1G<F]U<"DI
M('L*+R\@("`@("`@("`@("`@("`@("`@("`@("`@)')E="`]('1R=64["B\O
M("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PHO+R`@("`@("`@("`@
M("`@("`@("`@('T*+R\@("`@("`@("`@("`@("`@('T*+R\@("`@("`@("`@
M("`@?0HO+R`@("`@("`@('T*+R\*+R\@("`@("`@("!L9&%P7V-L;W-E*"1D
M<RD["B\O("`@("`@("`@<F5T=7)N("1R970["B\O("`@("!]"B\O('T*"B\O
M($AE<F4@:7,@86X@97AA;7!L92!O9B!C<F5A=&EN9R!C<F5D96YT:6%L<R!N
M965D960@8GD@=&AE($Q$05`@075T:"!D<FEV97(*+R\@9F]R(&%D9&EN9R]D
M96QE=&EN9R]U<&1A=&EN9R!U<V5R<RX*"B\O(&EF("@A9G5N8W1I;VY?97AI
M<W1S*"=?:&]R9&5?:&]O:U]A=71H;&1A<"<I*2!["B\O("`@("!F=6YC=&EO
M;B!?:&]R9&5?:&]O:U]A=71H;&1A<"@D=7-E<DE$+"`D8W)E9&5N=&EA;',@
M/2!N=6QL*0HO+R`@("`@>PHO+R`@("`@("`@("1E;G1R>5LG9&XG72`]("=U
M:60])R`N("1U<V5R240@+B`G+&]U/5!E;W!L92QD8SUE>&%M<&QE+F-O;2<[
M"B\O("`@("`@("`@:68@*&ES<V5T*"1C<F5D96YT:6%L<RD@)B8@:7-S970H
M)&-R961E;G1I86QS6R=U<V5R7V9U;&QN86UE)UTI*2!["B\O("`@("`@("`@
M("`@("1E;G1R>5LG8VXG72`]("1C<F5D96YT:6%L<ULG=7-E<E]F=6QL;F%M
M92==.PHO+R`@("`@("`@('T@96QS92!["B\O("`@("`@("`@("`@("1E;G1R
M>5LG8VXG72`]("1U<V5R240["B\O("`@("`@("`@?0HO+R`@("`@("`@("1E
M;G1R>5LG<VXG72`]("1U<V5R240["B\O("`@("`@("`@)&5N=')Y6R=O8FIE
M8W1C;&%S<R==6S!=(#T@)W1O<"<["B\O("`@("`@("`@)&5N=')Y6R=O8FIE
M8W1C;&%S<R==6S%=(#T@)W!E<G-O;B<["B\O("`@("`@("`@)&5N=')Y6R=O
M8FIE8W1C;&%S<R==6S)=(#T@)W%M86EL=7-E<B<["B\O("`@("`@("`@)&5N
M=')Y6R=O8FIE8W1C;&%S<R==6S-=(#T@)T-O=7)I97)-86EL04-C;W5N="<[
M"B\O("`@("`@("`@)&5N=')Y6R=M86EL:&]S="==(#T@)VUA:6PN97AA;7!L
M92YC;VTG.PHO+R`@("`@("`@("1E;G1R>5LG;6%I;$UE<W-A9V53=&]R92==
M(#T@)R]H;VUE+VUA:6PO)R`N("1U<V5R240["B\O("`@("`@("`@)&5N=')Y
M6R=H;VUE1&ER96-T;W)Y)UT@/2`G+VAO;64O;6%I;"\G("X@)'5S97))1#L*
M+R\@("`@("`@("`D96YT<GE;)VUA:6QB;W@G72`]("1E;G1R>5LG:&]M941I
M<F5C=&]R>2==("X@)R]-86EL9&ER)SL*+R\@("`@("`@("`D96YT<GE;)W5I
M9"==(#T@)'5S97))1#L*+R\@("`@("`@("`D96YT<GE;)V%C8V]U;G13=&%T
M=7,G72`]("=A8W1I=F4G.PHO+R`@("`@("`@("1E;G1R>5LG;6%I;%%U;W1A
M)UT@/2`G,3`T.#4W-C`P4R<["B\O("`@("`@("`@)&5N=')Y6R=M86EL)UT@
M/2`D=7-E<DE$.PHO+R`@("`@("`@("1E;G1R>5LG=6ED3G5M8F5R)UT@/2`U
M,#$["B\O("`@("`@("`@)&5N=')Y6R=G:61.=6UB97(G72`](#4P,3L*+R\*
M+R\@("`@("`@("`O+R!N965D('1O(&-H96-K(&9O<B!N97<@=7-E<G,@*'!A
M<W-W;W)D*2!A;F0@961I=&5D('5S97)S("AU<V5R7W!A<W-?,BD*+R\@("`@
M("`@("!I9B`H:7-S970H)&-R961E;G1I86QS*2`F)B!I<W-E="@D8W)E9&5N
M=&EA;'-;)W!A<W-W;W)D)UTI*2!["B\O("`@("`@("`@("`@("1E;G1R>5LG
M=7-E<E!A<W-W;W)D)UT@/2`@)WM-1#5])R`N(&)A<V4V-%]E;F-O9&4H;4AA
M<V@H34A!4TA?340U+"`D8W)E9&5N=&EA;'-;)W!A<W-W;W)D)UTI*3L*+R\@
M("`@("`@("!](&5L<V5I9B`H:7-S970H)&-R961E;G1I86QS*2`F)B!I<W-E
M="@D8W)E9&5N=&EA;'-;)W5S97)?<&%S<U\R)UTI*2!["B\O("`@("`@("`@
M("`@("1E;G1R>5LG=7-E<E!A<W-W;W)D)UT@/2`@)WM-1#5])R`N(&)A<V4V
M-%]E;F-O9&4H;4AA<V@H34A!4TA?340U+"`D8W)E9&5N=&EA;'-;)W5S97)?
M<&%S<U\R)UTI*3L*+R\@("`@("`@("!]"B\O("`@("`@("`@)&5N=')Y6R=D
M96QI=F5R>4UO9&4G72`]("=N;VQO8V%L)SL*+R\@("`@("`@("!R971U<FX@
M)&5N=')Y.PHO+R`@("`@?0HO+R!]"@HO+R!4:&ES(&9U;F-T:6]N(&ES(&-A
M;&QE9"!W:&5N(&$@2&]R9&5?4VAA<F4@;V)J96-T(&ES(&-R96%T960N($ET
M('1A:V5S(&$*+R\@<F5F97)E;F-E('1O('1H92!(;W)D95]3:&%R92!O8FIE
M8W0@=&AA="!I<R!B96EN9R!C<F5A=&5D(&%S('=E;&P@87,@=&@*+R\@;F%M
M92!O9B!T:&4@87!P;&EC871I;VX@9F]R('=H:6-H('1H92!(;W)D95]3:&%R
M92!O8FIE8W0@:7,@8F5I;F<@8W)E871E9"!A<PHO+R!P87)A;65T97)S+B!4
M:&4@<F5T=7)N('9A;'5E(&ES(&EG;F]R960N"@HO+R!I9B`H(69U;F-T:6]N
M7V5X:7-T<R@G7VAO<F1E7VAO;VM?<VAA<F5?:6YI="<I*2!["B\O("`@("!F
M=6YC=&EO;B!?:&]R9&5?:&]O:U]S:&%R95]I;FET*"8D<VAA<F5?;V)J96-T
M+"`D87!P*0HO+R`@("`@>PHO+R`@("`@("`@(&EF("@D1TQ/0D%,4ULG8V]N
M9B==6R=K;VQA8B==6R=E;F%B;&5D)UTI('L*+R\@("`@("`@("`@("`@<F5Q
M=6ER95]O;F-E("=(;W)D92]+;VQA8BYP:'`G.PHO+R`@("`@("`@("`@("!+
M;VQA8CHZ<WEN8VAR;VYI<V53:&%R97,H)'-H87)E7V]B:F5C="P@)&%P<"D[
M"B\O("`@("`@("`@?0HO+R`@("`@?0HO+R!]"@HO+R!4:&4@9F]L;&]W:6YG
M('1H<F5E(&9U;F-T:6]N<R!A<F4@97AA;7!L97,@;V8@=&AO<V4@=&AA="!C
M86X@8F4@8V%L;&5D('=H96X*+R\@861D:6YG+"!M;V1I9GEI;F<@86YD(')E
M;6]V:6YG('-H87)E<RP@<F5S<&5C=&EV96QY+B!4:&5Y(&%R92!C86QL960@
M=VET:`HO+R!T:&4@<VAA<F4@=&AA="!I<R!B96EN9R!A9&1E9"P@;6]D:69I
M960@;W(@<F5M;W9E9"!A<R!T:&5I<B!S:6YG;&4*+R\@<&%R86UE=&5R+B`@
M268@82!014%27T5R<F]R(&]B:F5C="!I<R!R971U<FYE9"!T:&4@<F5S<&5C
M=&EV92!S:&%R90HO+R!O<&5R871I;VX@=VEL;"!F86EL('=I=&@@=&AE(&5R
M<F]R(')E<W5L="X*"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?:&]R9&5?
M:&]O:U]S:&%R95]A9&0G*2D@>PHO+R`@("`@9G5N8W1I;VX@7VAO<F1E7VAO
M;VM?<VAA<F5?861D*"8D<VAA<F4I"B\O("`@("!["B\O("`@("`@("`@<F5Q
M=6ER95]O;F-E("=(;W)D92]+;VQA8BYP:'`G.PHO+R`@("`@("`@(')E='5R
M;B!+;VQA8CHZ=7!D871E4VAA<F4H)'-H87)E*3L*+R\@("`@('T*+R\@?0H*
M+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]H;W)D95]H;V]K7W-H87)E7VUO
M9&EF>2<I*2!["B\O("`@("!F=6YC=&EO;B!?:&]R9&5?:&]O:U]S:&%R95]M
M;V1I9GDH)B1S:&%R92D*+R\@("`@('L*+R\@("`@("`@("!R97%U:7)E7V]N
M8V4@)TAO<F1E+TMO;&%B+G!H<"<["B\O("`@("`@("`@<F5T=7)N($MO;&%B
M.CIU<&1A=&53:&%R92@D<VAA<F4I.PHO+R`@("`@?0HO+R!]"B\O"B\O(&EF
M("@A9G5N8W1I;VY?97AI<W1S*"=?:&]R9&5?:&]O:U]S:&%R95]R96UO=F4G
M*2D@>PHO+R`@("`@9G5N8W1I;VX@7VAO<F1E7VAO;VM?<VAA<F5?<F5M;W9E
M*"8D<VAA<F4I"B\O("`@("!["B\O("`@("`@("`@<F5Q=6ER95]O;F-E("=(
M;W)D92]+;VQA8BYP:'`G.PHO+R`@("`@("`@(')E='5R;B!+;VQA8CHZ<F5M
M;W9E4VAA<F4H)'-H87)E*3L*+R\@("`@('T*+R\@?0H*+R\@5&AI<R!E>&%M
M<&QE(&ES(&]F(&$@9G5N8W1I;VX@=&AA="!C86X@8F4@8V%L;&5D('=H96X@
M82!S:&%R92!L:7-T:6YG(&ES"B\O(')E<75E<W1E9"X@270@=&%K97,@82!U
M<V5R:60L(&$@<&5R;6ES<VEO;G,@;&5V96PL(&%N(&]P=&EO;F%L('-T<FEN
M9PHO+R!C;VYT86EN:6YG(&$@=7-E<FED('1O(')E<W1R:6-T('1H92!O=VYE
M<B!O9B!T:&4@<VAA<F5S(')E='5R;F5D+"!A;F0@=&AE"B\O(')E<W5L="!O
M9B!T:&4@8V]R<F5S<&]N9&EN9R!(;W)D95]3:&%R93HZ;&ES=%-H87)E<R@I
M(&-A;&P@87,@:71S"B\O('!A<F%M971E<G,N($%S(&ES('1H92!C87-E(&EN
M('1H92!P<F5V:6]U<R!T:')E92!F=6YC=&EO;G,L(&EF(&$@4$5!4E]%<G)O
M<@HO+R!R97-U;'0@:7,@<F5T=7)N960@=&AE($AO<F1E7U-H87)E.CIL:7-T
M4VAA<F5S*"D@8V%L;"!T:&%T('1R:6=G97)E9"!T:&ES"B\O(&AO;VL@=VEL
M;"!F86EL('=I=&@@=&AE(')E='5R;F5D(')E<W5L="X*"B\O(&EF("@A9G5N
M8W1I;VY?97AI<W1S*"=?:&]R9&5?:&]O:U]S:&%R95]L:7-T)RDI('L*+R\@
M("`@(&9U;F-T:6]N(%]H;W)D95]H;V]K7W-H87)E7VQI<W0H)'5S97)I9"P@
M)'!E<FTL("1O=VYE<BP@)B1S:&%R95]L:7-T*0HO+R`@("`@>PHO+R`@("`@
M("`@(&=L;V)A;"`D<F5G:7-T<GD["B\O("`@("`@("`@+R]E<G)O<E]L;V<H
M)TYU;6)E<B!O9B`G("X@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E=$%P<"@I
M("X@)R!S:&%R97,G("X@*"1O=VYE<B`_"B\O("`@("`@("`@+R\@("`@)R!O
M=VYE9"!B>2`G("X@)&]W;F5R(#H@)R<I("X@)R!A=F%I;&%B;&4@=&\@)R`N
M("1U<V5R:60@+B`G(&%T('!E<FUS(&QE=F5L("<@+@HO+R`@("`@("`@("\O
M("`@("1P97)M("X@)SH@)R`N("!C;W5N="@D<VAA<F5?;&ES="DI.PHO+R`@
M("`@("`@(')E='5R;B!T<G5E.PHO+R`@("`@?0HO+R!]"@HO+R!(97)E(&ES
M(&%N(&5X86UP;&4@7W5S97)N86UE7VAO;VM?9G)O;6)A8VME;F0@9G5N8W1I
M;VXN($ET(&%P<&5N9',@=&AE"B\O('9I<G1U86P@9&]M86EN('1O('1H92!U
M<V5R(&YA;64N"B\O"B\O(&5X+B`D2%144%](3U-4(#T@)VUA:6PN;7ED;VUA
M:6XN8V]M)RP@)'5S97))1"`]("=M>6YA;64G(')E='5R;G,Z"B\O("`@)VUY
M;F%M94!M>61O;6%I;BYC;VTG"@HO+R!I9B`H(69U;F-T:6]N7V5X:7-T<R@G
M7W5S97)N86UE7VAO;VM?9G)O;6)A8VME;F0G*2D@>PHO+R`@("`@9G5N8W1I
M;VX@7W5S97)N86UE7VAO;VM?9G)O;6)A8VME;F0H)'5S97))1"D*+R\@("`@
M('L*+R\@("`@("`@("`D=F1O;6%I;B`](&=E=&5N=B@G2%144%](3U-4)RD[
M"B\O("`@("`@("`@)'9D;VUA:6X@/2!P<F5G7W)E<&QA8V4H)WQ>;6%I;%PN
M?&DG+"`G)RP@)'9D;VUA:6XI.PHO+R`@("`@("`@("1V9&]M86EN(#T@4W1R
M:6YG.CIL;W=E<B@D=F1O;6%I;BD["B\O"B\O("`@("`@("`@<F5T=7)N("1U
M<V5R240@+B`G0"<@+B`D=F1O;6%I;CL*+R\@("`@('T*+R\@?0H*+R\@2&5R
M92!I<R!A;B!E>&%M<&QE(%]U<V5R;F%M95]H;V]K7W1O8F%C:V5N9"!F=6YC
M=&EO;B!A<R!A(&-O=6YT97)P87)T(&]F('1H90HO+R!P<F5V:6]U<R!E>&%M
M<&QE+B!)="!S=')I<',@=&AE('9I<G1U86P@9&]M86EN(&9R;VT@=&AE('5S
M97(@;F%M92X*+R\*+R\@97@N("1(5%107TA/4U0@/2`G;6%I;"YM>61O;6%I
M;BYC;VTG+"`D=7-E<DE$(#T@)VUY;F%M92<@<F5T=7)N<SH*+R\@("`G;7EN
M86UE0&UY9&]M86EN+F-O;2<*"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?
M=7-E<FYA;65?:&]O:U]T;V)A8VME;F0G*2D@>PHO+R`@("`@9G5N8W1I;VX@
M7W5S97)N86UE7VAO;VM?=&]B86-K96YD*"1U<V5R240I"B\O("`@("!["B\O
M("`@("`@("`@)'9D;VUA:6X@/2!G971E;G8H)TA45%!?2$]35"<I.PHO+R`@
M("`@("`@("1V9&]M86EN(#T@<')E9U]R97!L86-E*"=\7FUA:6Q<+GQI)RP@
M)R<L("1V9&]M86EN*3L*+R\@("`@("`@("`D=F1O;6%I;B`]("=`)R`N(%-T
M<FEN9SHZ;&]W97(H)'9D;VUA:6XI.PHO+PHO+R`@("`@("`@(&EF("AS=6)S
M='(H)'5S97))1"P@+7-T<FQE;B@D=F1O;6%I;BDI(#T]("1V9&]M86EN*2![
M"B\O("`@("`@("`@("`@("1U<V5R240@/2!S=6)S='(H)'5S97))1"P@,"P@
M+7-T<FQE;B@D=F1O;6%I;BDI.PHO+R`@("`@("`@('T*+R\*+R\@("`@("`@
M("!R971U<FX@)'5S97))1#L*+R\@("`@('T*+R\@?0H*+R\@2&5R92!I<R!A
M;B!E>&%M<&QE(%]U<V5R;F%M95]H;V]K7V9R;VUB86-K96YD(&9U;F-T:6]N
M+B!)="!C;VYV97)T<R!T:&4@=7-E<@HO+R!N86UE('1O(&%L;"!L;W=E<B!C
M87-E+B!4:&ES(&UI9VAT(&)E(&YE8V5S<V%R>2!I9B!A;B!A=71H96YT:6-A
M=&EO;B!B86-K96YD"B\O(&ES(&-A<V4@:6YS96YS:71I=F4@=&\@=&%K92!I
M;G1O(&%C8V]U;G0@=&AA="!(;W)D92=S('!R969E<F5N8V4@<WES=&5M(&ES
M"B\O(&-A<V4@<V5N<VET:79E+@HO+PHO+R!E>"X@)'5S97))1"`]("=->4YA
M;64G(')E='5R;G,Z("=M>6YA;64G"@HO+R!I9B`H(69U;F-T:6]N7V5X:7-T
M<R@G7W5S97)N86UE7VAO;VM?9G)O;6)A8VME;F0G*2D@>PHO+R`@("`@9G5N
M8W1I;VX@7W5S97)N86UE7VAO;VM?9G)O;6)A8VME;F0H)'5S97))1"D*+R\@
M("`@('L*+R\@("`@("`@("!R971U<FX@4W1R:6YG.CIL;W=E<B@D=7-E<DE$
M*3L*+R\@("`@('T*+R\@?0H*+R\@2&5R92!I<R!A;B!E>&%M<&QE(%]P97)M
M<U]H;V]K7V1E;FEE9"!F=6YC=&EO;BX@($ET(&ES(&-A;&QE9"!I9B!A('5S
M97(*+R\@=')I97,@=&\@;6%K92!A;B!A8W1I;VX@=&AA="!I<R!U;F1E<B!P
M97)M:7-S:6]N(&-O;G1R;VP@86YD('1H870@:&4*+R\@9&]E<VXG="!H879E
M('-U9F9I8VEE;G0@<&5R;6ES<VEO;G,@9F]R+B`@270@8V%N(&)E('5S960@
M=&\@<VAO=R!T:&4@=7-E<B!A"B\O(&-U<W1O;2!M97-S86=E(&EN8VQU9&EN
M9R!(5$U,(&-O9&4@*'EO=2!H879E('1O('1A:V4@8V%R92!A8F]U="!(5$U,
M"B\O(&5S8V%P:6YG(&]N('EO=7(@;W=N*2P@;W(@=&\@:6YT97)R=7!T('1H
M92!C;V1E(&9L;W<@86YD('-E;F0@=&AE('5S97(@=&\@80HO+R!D:69F97)E
M;G0@<&%G92!F;W(@97AA;7!L92X*"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S
M*"=?<&5R;7-?:&]O:U]D96YI960G*2D@>PHO+R`@("`@9G5N8W1I;VX@7W!E
M<FUS7VAO;VM?9&5N:65D*"1P97)M:7-S:6]N*0HO+R`@("`@>PHO+R`@("`@
M("`@(&EF("@H)'!O<R`]('-T<G!O<R@D<&5R;6ES<VEO;BP@)SHG*2D@/3T]
M(&9A;'-E*2!["B\O("`@("`@("`@("`@("1A<'`@/2`D<&5R;6ES<VEO;CL*
M+R\@("`@("`@("!](&5L<V4@>PHO+R`@("`@("`@("`@("`D87!P(#T@<W5B
M<W1R*"1P97)M:7-S:6]N+"`P+"`D<&]S*3L*+R\@("`@("`@("!]"B\O"B\O
M("`@("`@("`@<F5T=7)N('-P<FEN=&8H)U!E<FUI<W-I;VX@9&5N:65D+B!#
M;&EC:R`\82!H<F5F/2)H='1P.B\O=W=W+F5X86UP;&4N8V]M+W5P9W)A9&4N
M<&AP/V%P<#TE<R(^2$5213PO83X@=&\@=7!G<F%D92`E<RXG+`HO+R`@("`@
M("`@("`@("`@("`@("`@("`@("1A<'`L("1'3$]"04Q36R=R96=I<W1R>2==
M+3YG970H)VYA;64G*2D["B\O("`@("!]"B\O('T*"B\O(%1H:7,@:7,@86X@
M97AA;7!L92!O9B!A(&=R;W5P(&AO;VLN("!4;R!U<V4@:70@>6]U(&UU<W0@
M<V5T('1H92!G<F]U<`HO+R!D<FEV97(@=&\@:&]O:W,@:6X@8V]N9BYP:'`N
M("!4:&5N('EO=2!M=7-T(&-R96%T92!A($E47V1E<&%R=&UE;G0@9W)O=7`*
M+R\@*&)E8V%U<V4@=&AA="!I<R!H;W<@=V4@:VYO=R!W:&%T(&AO;VL@=&\@
M8V%L;"DN("!9;W4@8V%N(&%D9"!U<V5R<R!T;R!T:&4*+R\@9W)O=7`@87,@
M;F]R;6%L+"!A;F0@:6X@861D:71I;VX@=&AI<R!F=6YC=&EO;B!W:6QL(&)E
M(&-A;&QE9"!T;PHO+R!D>6YA;6EC86QL>2!I;F-L=61E('5S97)S(&EN('1H
M92!G<F]U<"X@($EN('1H:7,@97AA;7!L92!W92!W:6QL(&QO;VL@=7`*+R\@
M=VAE=&AE<B!O<B!N;W0@=&AI<R!U<V5R(&ES('!A<G0@;V8@=&AE($E4(&1E
M<&%R=&UE;G0@=7-I;F<@86X@97AT97)N86P*+R\@9&%T86)A<V4N"@HO+R!I
M9B`H(69U;F-T:6]N7V5X:7-T<R@G7V=R;W5P7VAO;VM?251?9&5P87)T;65N
M="<I*2!["B\O("`@("!F=6YC=&EO;B!?9W)O=7!?:&]O:U])5%]D97!A<G1M
M96YT*"1U<V5R3F%M92D*+R\@("`@('L*+R\@("`@("`@("!G;&]B86P@)&-O
M;F8["B\O"B\O("`@("`@("`@)&1E<'0@/2`G250G.PHO+R`@("`@("`@(&EN
M8VQU9&5?;VYC92`G1$(N<&AP)SL*+R\@("`@("`@("`D7V1B(#T@)D1".CIC
M;VYN96-T*"1C;VYF6R=S<6PG72P@=')U92D["B\O("`@("`@("`@)'%U97)Y
M(#T@)U-%3$5#5"!#3U5.5"@J*2!&4D]-(&1E<&%R=&UE;G1S(%=(15)%('5S
M97)?;F%M92`](#\@04Y$(&1E<&%R=&UE;G0@/2`_)SL*+R\@("`@("`@("`D
M=F%L=65S(#T@87)R87DH)'5S97).86UE+"`D9&5P="D["B\O("`@("`@("`@
M)')E<W5L="`]("1?9&(M/F=E=$]N92@D<75E<GDL("1V86QU97,I.PHO+R`@
M("`@("`@(&EF("@A:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I("8F("1R
M97-U;'0@/B`P*2!["B\O("`@("`@("`@("`@(')E='5R;B!T<G5E.PHO+R`@
M("`@("`@('T@96QS92!["B\O("`@("`@("`@("`@(')E='5R;B!F86QS93L*
M+R\@("`@("`@("!]"B\O("`@("!]"B\O('T*"B\O(%1H:7,@:7,@86X@97AA
M;7!L92!O9B!A('!O<W0M<'5S:"!H;V]K.R!I="!I<R!C86QL960@<FEG:'0@
M869T97(@86X*+R\@87!P;&EC871I;VX@:7,@<'5S:&5D('-U8V-E<W-F=6QL
M>2!O;G1O('1H92!A<'`@<W1A8VLN"@HO+R!I9B`H(69U;F-T:6]N7V5X:7-T
M<R@G7VAO<F1E7VAO;VM?<&]S=%]P=7-H87!P)RDI('L*+R\@("`@(&9U;F-T
M:6]N(%]H;W)D95]H;V]K7W!O<W1?<'5S:&%P<"@D87!P*0HO+R`@("`@>PHO
M+R`@("`@("`@(&EF("AI;E]A<G)A>2@D87!P+"!A<G)A>2@G:W)O;F]L:71H
M)RP@)W1U<F)A)RP@)VAO<F1E)RP@)VEN9V\G*2D@?'P*+R\@("`@("`@("`@
M("`@('-T<G!O<R@D7U-%4E9%4ELG4$A07U-%3$8G72P@)W!R969S+G!H<"<I
M("$]/2!F86QS92D@>PHO+R`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)$=,
M3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G9FEL97)O;W0G+"`G9&EM<"<I("X@
M)R]L:6(O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<T]V97)R:61E+G!H
M<"<["B\O("`@("`@("`@("`@("1'3$]"04Q36R=N;W1I9FEC871I;VXG72`]
M("9.;W1I9FEC871I;VXZ.G-I;F=L971O;B@I.PHO+R`@("`@("`@("`@("`D
M1TQ/0D%,4ULG;F]T:69I8V%T:6]N)UTM/F%T=&%C:"@G<W1A='5S)RP@;G5L
M;"P@)TYO=&EF:6-A=&EO;E],:7-T96YE<E]D:6UP7W-T871U<T]V97)R:61E
M)RD["B\O("`@("`@("`@?0HO+R`@("`@?0HO+R!]"@HO+R!(97)E(&ES(&%N
M(&5X86UP;&4@7VEM<%]H;V]K7W1R86EL97(@9G5N8W1I;VX@=&\@<V5T('1H
M92!T<F%I;&5R(&9R;VT@=&AE"B\O('-Y<W1E;2!T86=L:6YE<R!F:6QE.R!T
M:&4@<W1R:6YG(")`0%1!1T!`(B`H:68@<')E<V5N="!I;B!A('1R86EL97(I
M('=I;&P@8F4*+R\@<F5P;&%C960@8GD@=&AE(&-O;G1E;G0@;V8@=&AE(&9I
M;&4@(B]U<W(O<VAA<F4O=&%G;&EN92(@*&=E;F5R871E9"!B>2!T:&4*+R\@
M(E1A4E0B('5T:6QI='DI+@H*+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]I
M;7!?:&]O:U]T<F%I;&5R)RDI('L*+R\@("`@(&9U;F-T:6]N(%]I;7!?:&]O
M:U]T<F%I;&5R*"1T<F%I;&5R*0HO+R`@("`@>PHO+R`@("`@("`@(&EF("AP
M<F5G7VUA=&-H*"<O0$!404=`0"\G+"`D=')A:6QE<BDI('L*+R\@("`@("`@
M("`@("`@)'1A9R`](&!C870@+W5S<B]S:&%R92]T86=L:6YE8#L*+R\@("`@
M("`@("`@("`@)'1R86EL97(@/2!P<F5G7W)E<&QA8V4H)WQ`0%1!1T!`?"<L
M("1T86<L("1T<F%I;&5R*3L*+R\@("`@("`@("!]"B\O("`@("`@("`@<F5T
M=7)N("1T<F%I;&5R.PHO+R`@("`@?0HO+R!]"@HO+R!(97)E(&ES(&%N(&%N
M;W1H97(@97AA;7!L92!?:6UP7VAO;VM?=')A:6QE<B!F=6YC=&EO;B!T;R!S
M970@=&AE('1R86EL97(*+R\@9G)O;2!T:&4@3$1!4"!D:7)E8W1O<GD@9F]R
M(&5A8V@@9&]M86EN+B!4:&ES(&9U;F-T:6]N(')E<&QA8V5S('1H92!C=7)R
M96YT"B\O('1R86EL97(@=VET:"!T:&4@9&%T82!I="!G971S(&9R;VT@:7-P
M;6%N1&]M86EN4VEG;F%T=7)E+@H*+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H
M)U]I;7!?:&]O:U]T<F%I;&5R)RDI('L*+R\@("`@(&9U;F-T:6]N(%]I;7!?
M:&]O:U]T<F%I;&5R*"1T<F%I;&5R*0HO+R`@("`@>PHO+R`@("`@("`@("1V
M9&]M86EN(#T@9V5T96YV*"=(5%107TA/4U0G*3L*+R\@("`@("`@("`D=F1O
M;6%I;B`]('!R96=?<F5P;&%C92@G?%XN*C]<+GQI)RP@)R<L("1V9&]M86EN
M*3L*+R\@("`@("`@("`D=F1O;6%I;B`](%-T<FEN9SHZ;&]W97(H)'9D;VUA
M:6XI.PHO+R`@("`@("`@("1L9&%P4V5R=F5R(#T@)VQO8V%L:&]S="<["B\O
M("`@("`@("`@)&QD87!0;W)T(#T@)S,X.2<["B\O("`@("`@("`@)'-E87)C
M:$)A<V4@/2`G:7-P;6%N1&]M86EN/2<@+B`D=F1O;6%I;B`@+B`B+&\]:7-P
M;6%N(CL*+R\*+R\@("`@("`@("`D9',@/2!`;&1A<%]C;VYN96-T*"1L9&%P
M4V5R=F5R+"`D;&1A<%!O<G0I.PHO+R`@("`@("`@("1S96%R8VA297-U;'0@
M/2!`;&1A<%]S96%R8V@H)&1S+"`D<V5A<F-H0F%S92P@)W5I9#TG("X@)'9D
M;VUA:6XI.PHO+R`@("`@("`@("1I;F9O<FUA=&EO;B`]($!L9&%P7V=E=%]E
M;G1R:65S*"1D<RP@)'-E87)C:%)E<W5L="D["B\O("`@("`@("`@)'1R86EL
M97(]("1I;F9O<FUA=&EO;ELP75LG:7-P;6%N9&]M86EN<VEG;F%T=7)E)UU;
M,%T["B\O("`@("`@("`@;&1A<%]C;&]S92@D9',I.PHO+PHO+R`@("`@("`@
M(')E='5R;B`D=')A:6QE<CL*+R\@("`@('T*+R\@?0H*+R\@2&5R92!I<R!A
M;B!E>&%M<&QE(%]I;7!?:&]O:U]V:6YF;R!F=6YC=&EO;BX@268@)'1Y<&4@
M/3T@)W9D;VUA:6XG+"!T:&ES"B\O(&9U;F-T:6]N(')E='5R;G,@=&AE($A4
M5%!?2$]35"!V87)I86)L92!A9G1E<B!R96UO=FEN9R!T:&4@)VUA:6PN)PHO
M+R!S=6)D;VUA:6XN"B\O"B\O($EF("1T>7!E(#T]("=U<V5R;F%M92<L('1H
M:7,@9G5N8W1I;VX@<F5T=7)N<R!A('5N:7%U92!U<V5R;F%M92!C;VUP;W-E
M9"!O9@HO+R`D7U-%4U-)3TY;)VEM<"==6R=U<V5R)UT@*R!V9&]M86EN+@HO
M+PHO+R!E>"X@)$A45%!?2$]35"`]("=M86EL+FUY9&]M86EN+F-O;2<L("1?
M4T534TE/3ELG:6UP)UU;)W5S97(G72`]("=M>6YA;64G.@HO+R`@("1V9&]M
M86EN("`]("=M>61O;6%I;BYC;VTG"B\O("`@)'5S97)N86UE(#T@)VUY;F%M
M95]M>61O;6%I;E]C;VTG"@HO+R!I9B`H(69U;F-T:6]N7V5X:7-T<R@G7VEM
M<%]H;V]K7W9I;F9O)RDI('L*+R\@("`@(&9U;F-T:6]N(%]I;7!?:&]O:U]V
M:6YF;R@D='EP92`]("=U<V5R;F%M92<I"B\O("`@("!["B\O("`@("`@("`@
M)'9D;VUA:6X@/2!G971E;G8H)TA45%!?2$]35"<I.PHO+R`@("`@("`@("1V
M9&]M86EN(#T@<')E9U]R97!L86-E*"=\7FUA:6Q<+GQI)RP@)R<L("1V9&]M
M86EN*3L*+R\@("`@("`@("`D=F1O;6%I;B`](%-T<FEN9SHZ;&]W97(H)'9D
M;VUA:6XI.PHO+PHO+R`@("`@("`@(&EF("@D='EP92`]/2`G=7-E<FYA;64G
M*2!["B\O("`@("`@("`@("`@(')E='5R;B!P<F5G7W)E<&QA8V4H)WQ<+GPG
M+"`G7R<L("1?4T534TE/3ELG:6UP)UU;)W5S97(G72`N("=?)R`N("1V9&]M
M86EN*3L*+R\@("`@("`@("!](&5L<V5I9B`H)'1Y<&4@/3T@)W9D;VUA:6XG
M*2!["B\O("`@("`@("`@("`@(')E='5R;B`D=F1O;6%I;CL*+R\@("`@("`@
M("!](&5L<V4@>PHO+R`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@G:6YV86QI9"!T>7!E.B`G("X@)'1Y<&4I.PHO+R`@("`@("`@('T*
M+R\@("`@('T*+R\@?0H*+R\@2&5R92!I<R!A;B!E>&%M<&QE(&]F('1H92!?
M:6UP7VAO;VM?9F5T8VAM86EL7V9I;'1E<B!F=6YC=&EO;B!T;R!R=6X*+R\@
M4W!A;4%S<V%S<VEN(&]N(&5M86EL(&)E9F]R92!I="!I<R!W<FET=&5N('1O
M('1H92!M86EL8F]X+@HO+R!.;W1E.B!T;R!U<V4@=&AE('-P86UA<W-A<W-I
M;B!I;G-T96%D(&]F('-P86UD+"!C:&%N9V4@)W-P86UC)R!T;PHO+R`G<W!A
M;6%S<V%S<VEN("U0)R!A;F0@861D(&%N>2!O=&AE<B!I;7!O<G1A;G0@87)G
M=6UE;G1S+"!B=70@<F5A;&EZ92!S<&%M8PHO+R!I<R!-54-((&9A<W1E<B!T
M:&%N('-P86UA<W-A<W-I;BX*+R\@5T%23DE.1SH@36%K92!S=7)E('1O('5S
M92!T:&4@+2UN;V%D9"UF<F]M(&9I;'1E<B!O;B!S<&%M9"!O<B!S<&%M87-S
M87-S:6X*"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?:6UP7VAO;VM?9F5T
M8VAM86EL7V9I;'1E<B<I*2!["B\O("`@("!F=6YC=&EO;B!?:6UP7VAO;VM?
M9F5T8VAM86EL7V9I;'1E<B@D;65S<V%G92D*+R\@("`@('L*+R\@("`@("`@
M("`O+R!7:&5R92!D;V5S(%-P86U!<W-A<W-I;B!L:79E+"!A;F0@=VAA="!U
M<V5R;F%M92!S:&]U;&0@=V4@=7-E"B\O("`@("`@("`@+R\@9F]R('!R969E
M<F5N8V5S/PHO+R`@("`@("`@("1C;60@/2`G+W5S<B]L;V-A;"]B:6XO<W!A
M;6,G.PHO+R`@("`@("`@("1U<V5R;F%M92`]($%U=&@Z.F=E=$%U=&@H*3L*
M+R\@("`@("`@("`O+R!)9B!Y;W4@=7-E('1H92!?<V%M7VAO;VM?=7-E<FYA
M;64H*2!H;V]K+"!U;F-O;6UE;G0@=&AE(&YE>'0@;&EN90HO+R`@("`@("`@
M("\O)'5S97)N86UE(#T@7W-A;5]H;V]K7W5S97)N86UE*"1U<V5R;F%M92D[
M"B\O("`@("`@("`@)'5S97)N86UE(#T@97-C87!E<VAE;&QA<F<H)'5S97)N
M86UE*3L*+R\*+R\@("`@("`@("`O+R!!;'-O+"!W92!R96UO=F4@=&AE(&9I
M;&4@;W5R<V5L=F5S.R!T:&ES(&AO;VL@;6%Y(&)E(&-A;&QE9`HO+R`@("`@
M("`@("\O(&AU;F1R961S(&]F('1I;65S('!E<B!R=6X@9&5P96YD:6YG(&]N
M(&AO=R!M86YY(&UE<W-A9V5S('=E(&9E=&-H"B\O("`@("`@("`@)&9I;&4@
M/2!(;W)D93HZ9V5T5&5M<$9I;&4H)VAO<F1E)RP@9F%L<V4I.PHO+PHO+R`@
M("`@("`@("\O($-A;&P@4W!A;4%S<V%S<VEN.R!P:7!E('1H92!N97<@;65S
M<V%G92!T;R!O=7(@=&5M<&9I;&4*+R\@("`@("`@("`D9G`@/2!P;W!E;B@B
M)&-M9"`M=2`D=7-E<FYA;64@/B`D9FEL92(L("=W)RD["B\O("`@("`@("`@
M9G=R:71E*"1F<"P@)&UE<W-A9V4I.PHO+R`@("`@("`@('!C;&]S92@D9G`I
M.PHO+PHO+R`@("`@("`@("\O(%)E860@=&AE(&YE=R!M97-S86=E(&9R;VT@
M=&AE('1E;7!O<F%R>2!F:6QE"B\O("`@("`@("`@)&UE<W-A9V4@/2!F:6QE
M7V=E=%]C;VYT96YT<R@D9FEL92D["B\O("`@("`@("`@=6YL:6YK*"1F:6QE
M*3L*+R\@("`@("`@("!R971U<FX@)&UE<W-A9V4["B\O("`@("!]"B\O('T*
M"B\O($AE<F4@:7,@86X@97AA;7!L92!S:6=N871U<F4@:&]O:R!F=6YC=&EO
M;B!T;R!S970@=&AE('-I9VYA='5R92!F<F]M('1H90HO+R!S>7-T96T@=&%G
M;&EN97,@9FEL93L@=&AE('-T<FEN9R`B)51!1R4B("AI9B!P<F5S96YT(&EN
M(&$@=7-E<B=S('-I9VYA='5R92D*+R\@=VEL;"!B92!R97!L86-E9"!B>2!T
M:&4@8V]N=&5N="!O9B!T:&4@9FEL92`B+W5S<B]S:&%R92]T86=L:6YE(B`H
M9V5N97)A=&5D"B\O(&)Y('1H92`B5&%25"(@=71I;&ET>2DN"@HO+R!I9B`H
M(69U;F-T:6]N7V5X:7-T<R@G7VEM<%]H;V]K7W-I9VYA='5R92<I*2!["B\O
M("`@("!F=6YC=&EO;B!?:6UP7VAO;VM?<VEG;F%T=7)E*"1S:6<I"B\O("`@
M("!["B\O("`@("`@("`@:68@*'!R96=?;6%T8V@H)R\E5$%')2\G+"`D<VEG
M*2D@>PHO+R`@("`@("`@("`@("`D=&%G(#T@8&-A="`O=7-R+W-H87)E+W1A
M9VQI;F5@.PHO+R`@("`@("`@("`@("`D<VEG(#T@<')E9U]R97!L86-E*"<O
M)51!1R4O)RP@)'1A9RP@)'-I9RD["B\O("`@("`@("`@?0HO+PHO+R`@("`@
M("`@(')E='5R;B`D<VEG.PHO+R`@("`@?0HO+R!]"@HO+R!4:&ES(&ES(&%N
M(&5X86UP;&4@:&]O:R!F=6YC=&EO;B!F;W(@=&AE($E-4"!R961I<F5C=&EO
M;B!S8VAE;64N(%1H:7,*+R\@9G5N8W1I;VX@:7,@8V%L;&5D('=H96X@=&AE
M('5S97(@;W!E;G,@82!M86EL8F]X(&EN($E-4"P@86YD(&%L;&]W<R!T:&4*
M+R\@8VQI96YT('1O(&)E(')E9&ER96-T960@8F%S960@;VX@=&AE(&UA:6QB
M;W@@;F%M92X@5&AE(')E='5R;B!V86QU92!O9B!T:&ES"B\O(&9U;F-T:6]N
M('-H;W5L9"!B92!A('9A;&ED('!A9V4@=VET:&EN(&$@:&]R9&4@87!P;&EC
M871I;VX@=VAI8V@@=VEL;"!B90HO+R!P;&%C960@:6X@82`B3&]C871I;VXB
M(&AE861E<B!T;R!R961I<F5C="!T:&4@8VQI96YT+B`@5&AE(&]N;'D@<&%R
M86UE=&5R"B\O(&ES('1H92!N86UE(&]F('1H92!M86EL8F]X('=H:6-H('1H
M92!U<V5R(&AA<R!O<&5N960N("!)9B!A;B!E;7!T>2!S=')I;F<*+R\@:7,@
M<F5T=7)N960@=&AE('5S97(@:7,@;F]T(')E9&ER96-T960N"@HO+R!I9B`H
M(69U;F-T:6]N7V5X:7-T<R@G7VEM<%]H;V]K7VUB;WA?<F5D:7)E8W0G*2D@
M>PHO+R`@("`@9G5N8W1I;VX@7VEM<%]H;V]K7VUB;WA?<F5D:7)E8W0H)&UA
M:6QB;W@I"B\O("`@("!["B\O("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D
M92]+;VQA8BYP:'`G.PHO+PHO+R`@("`@("`@(&EF("AS=')P;W,H)&UA:6QB
M;W@L("))3D)/6"]#86QE;F1A<B(I("$]/2!F86QS90HO+R`@("`@("`@("`@
M("!\?"!P<F5G7VUA=&-H*"(A7G5S97(O6UXO72LO0V%L96YD87(A(BP@)&UA
M:6QB;W@I*2!["B\O("`@("`@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG<F5G
M:7-T<GDG72T^9V5T*"=W96)R;V]T)RP@)VMR;VYO;&ET:"<I.PHO+R`@("`@
M("`@('T@96QS96EF("AS=')P;W,H)&UA:6QB;W@L("))3D)/6"]487-K<R(I
M("$]/2!F86QS90HO+R`@("`@("`@("`@("!\?"!P<F5G7VUA=&-H*"(A7G5S
M97(O6UXO72LO5&%S:W,A(BP@)&UA:6QB;W@I*2!["B\O("`@("`@("`@("`@
M(')E='5R;B`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=W96)R;V]T)RP@
M)VYA9R<I.PHO+R`@("`@("`@('T@96QS96EF("AS=')P;W,H)&UA:6QB;W@L
M("))3D)/6"].;W1E<R(I("$]/2!F86QS90HO+R`@("`@("`@("`@("!\?"!P
M<F5G7VUA=&-H*"(A7G5S97(O6UXO72LO3F]T97,A(BP@)&UA:6QB;W@I*2![
M"B\O("`@("`@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^
M9V5T*"=W96)R;V]T)RP@)VUN96UO)RD["B\O("`@("`@("`@?2!E;'-E:68@
M*'-T<G!O<R@D;6%I;&)O>"P@(DE.0D]8+T-O;G1A8W1S(BD@(3T](&9A;'-E
M"B\O("`@("`@("`@("`@('Q\('!R96=?;6%T8V@H(B%>=7-E<B];7B]=*R]#
M;VYT86-T<R$B+"`D;6%I;&)O>"DI('L*+R\@("`@("`@("`@("`@<F5T=7)N
M("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W=E8G)O;W0G+"`G='5R8F$G
M*3L*+R\@("`@("`@("!]"B\O"B\O("`@("`@("`@<F5T=7)N("<G.PHO+R`@
M("`@?0HO+R!]"@HO+R!4:&ES(&ES(&%N(&5X86UP;&4@:&]O:R!F=6YC=&EO
M;B!F;W(@=&AE($E-4"!M86EL8F]X(&EC;VX@<V-H96UE+B!4:&ES"B\O(&9U
M;F-T:6]N(&ES(&-A;&QE9"!W:&5N('1H92!F;VQD97(@;&ES="!I<R!C<F5A
M=&5D(&%N9"!A(")S=&%N9&%R9"(@9F]L9&5R"B\O(&ES('1O(&)E(&1I<W!L
M87EE9"`M(&ET(&%L;&]W<R!C=7-T;VT@9F]L9&5R(&EC;VYS('1O(&)E('-P
M96-I9FEE9"X*+R\@*")3=&%N9&%R9"(@;65A;G,@86QL(&9O;&1E<G,@97AC
M97!T('1H92!)3D)/6"P@<V5N="UM86EL(&9O;&1E<G,@86YD"B\O('1R87-H
M(&9O;&1E<G,N*0HO+R!)9B!A(&UA:6QB;W@@;F%M92!D;V5S;B=T(&%P<&5A
M<B!I;B!T:&4@8F5L;W<@;&ES="P@=&AE(&1E9F%U;'0@;6%I;&)O>`HO+R!I
M8V]N(&ES(&1I<W!L87EE9"X*"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?
M:6UP7VAO;VM?;6)O>%]I8V]N<R<I*2!["B\O("`@("!F=6YC=&EO;B!?:6UP
M7VAO;VM?;6)O>%]I8V]N<R@I"B\O("`@("!["B\O("`@("`@("`@<W1A=&EC
M("1N97=M86EL8F]X97,["B\O"B\O("`@("`@("`@:68@*"%E;7!T>2@D;F5W
M;6%I;&)O>&5S*2D@>PHO+R`@("`@("`@("`@("!R971U<FX@)&YE=VUA:6QB
M;WAE<SL*+R\@("`@("`@("!]"B\O"B\O("`@("`@("`@<F5Q=6ER95]O;F-E
M("=(;W)D92]+;VQA8BYP:'`G.PHO+PHO+R`@("`@("`@("1K8R`](&YE=R!+
M;VQA8E]#>7)U<R@D1TQ/0D%,4ULG8V]N9B==6R=K;VQA8B==6R=S97)V97(G
M72D["B\O("`@("`@("`@)&UA:6QB;WAE<R`]("1K8RT^;&ES=$UA:6Q";WAE
M<R@I.PHO+R`@("`@("`@("1N97=M86EL8F]X97,@/2!A<G)A>2@I.PHO+PHO
M+R`@("`@("`@(&9O<F5A8V@@*"1M86EL8F]X97,@87,@)&)O>"D@>PHO+R`@
M("`@("`@("`@("`D8F]X(#T@<')E9U]R97!L86-E*"(O7GM;7GU=*WTO(BP@
M(B(L("1B;W@I.PHO+R`@("`@("`@("`@("!I9B`H<W1R<&]S*"1B;W@L("))
M3D)/6"]#86QE;F1A<B(I("$]/2!F86QS90HO+R`@("`@("`@("`@("`@("`@
M?'P@<')E9U]M871C:"@B(5YU<V5R+UM>+UTK+T-A;&5N9&%R(2(L("1B;W@I
M*2!["B\O("`@("`@("`@("`@("`@("`D;F5W;6%I;&)O>&5S6R1B;WA=(#T@
M2&]R9&4Z.FEM9R@*+R\@("`@("`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG
M<F5G:7-T<GDG72T^9V5T*"=I8V]N)RP@)VMR;VYO;&ET:"<I+`HO+R`@("`@
M("`@("`@("`@("`@("`@(%\H(D-A;&5N9&%R(BDL"B\O("`@("`@("`@("`@
M("`@("`@("`@)W=I9'1H/2(Q-B(@:&5I9VAT/2(Q-B(@<W1Y;&4](G9E<G1I
M8V%L+6%L:6=N.FUI9&1L92(G+`HO+R`@("`@("`@("`@("`@("`@("`@("<G
M"B\O("`@("`@("`@("`@("`@("`I.PHO+R`@("`@("`@("`@("!](&5L<V5I
M9B`H<W1R<&]S*"1B;W@L("))3D)/6"]487-K<R(I("$]/2!F86QS90HO+R`@
M("`@("`@("`@("`@("`@?'P@<')E9U]M871C:"@B(5YU<V5R+UM>+UTK+U1A
M<VMS(2(L("1B;W@I*2!["B\O("`@("`@("`@("`@("`@("`D;F5W;6%I;&)O
M>&5S6R1B;WA=(#T@2&]R9&4Z.FEM9R@*+R\@("`@("`@("`@("`@("`@("`@
M("`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=I8V]N)RP@)VYA9R<I+`HO
M+R`@("`@("`@("`@("`@("`@("`@(%\H(E1A<VMS(BDL"B\O("`@("`@("`@
M("`@("`@("`@("`@)W=I9'1H/2(Q-B(@:&5I9VAT/2(Q-B(@<W1Y;&4](G9E
M<G1I8V%L+6%L:6=N.FUI9&1L92(G+`HO+R`@("`@("`@("`@("`@("`@("`@
M("<G"B\O("`@("`@("`@("`@("`@("`I.PHO+R`@("`@("`@("`@("!](&5L
M<V5I9B`H<W1R<&]S*"1B;W@L("))3D)/6"].;W1E<R(I("$]/2!F86QS90HO
M+R`@("`@("`@("`@("`@("`@?'P@<')E9U]M871C:"@B(5YU<V5R+UM>+UTK
M+TYO=&5S(2(L("1B;W@I*2!["B\O("`@("`@("`@("`@("`@("`D;F5W;6%I
M;&)O>&5S6R1B;WA=(#T@2&]R9&4Z.FEM9R@*+R\@("`@("`@("`@("`@("`@
M("`@("`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=I8V]N)RP@)VUN96UO
M)RDL"B\O("`@("`@("`@("`@("`@("`@("`@7R@B3F]T97,B*2P*+R\@("`@
M("`@("`@("`@("`@("`@("`G=VED=&@](C$V(B!H96EG:'0](C$V(B!S='EL
M93TB=F5R=&EC86PM86QI9VXZ;6ED9&QE(B<L"B\O("`@("`@("`@("`@("`@
M("`@("`@)R<*+R\@("`@("`@("`@("`@("`@("D["B\O("`@("`@("`@("`@
M('T@96QS96EF("AS=')P;W,H)&)O>"P@(DE.0D]8+T-O;G1A8W1S(BD@(3T]
M(&9A;'-E"B\O("`@("`@("`@("`@("`@("!\?"!P<F5G7VUA=&-H*"(A7G5S
M97(O6UXO72LO0V]N=&%C=',A(BP@)&)O>"DI('L*+R\@("`@("`@("`@("`@
M("`@("1N97=M86EL8F]X97-;)&)O>%T@/2!(;W)D93HZ:6UG*`HO+R`@("`@
M("`@("`@("`@("`@("`@("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)VEC
M;VXG+"`G='5R8F$G*2P*+R\@("`@("`@("`@("`@("`@("`@("!?*")#;VYT
M86-T<R(I+`HO+R`@("`@("`@("`@("`@("`@("`@("=W:61T:#TB,38B(&AE
M:6=H=#TB,38B('-T>6QE/2)V97)T:6-A;"UA;&EG;CIM:61D;&4B)RP*+R\@
M("`@("`@("`@("`@("`@("`@("`G)PHO+R`@("`@("`@("`@("`@("`@*3L*
M+R\@("`@("`@("`@("`@?0HO+R`@("`@("`@('T*+R\*+R\@("`@("`@("!R
M971U<FX@)&YE=VUA:6QB;WAE<SL*+R\@("`@('T*+R\@?0H*+R\@5&AI<R!I
M<R!A;B!E>&%M<&QE(&AO;VL@9G5N8W1I;VX@9F]R('1H92!)35`@<W!A;2!R
M97!O<G1I;F<@8F]U8V4@;W!T:6]N+@HO+R!4:&ES(&9U;F-T:6]N(&ES(&-A
M;&QE9"!W:&5N('1H92!M97-S86=E(&ES(&%B;W5T('1O(&)E(&)O=6YC960@
M+2!I=`HO+R!W:6QL(')E='5R;B!T:&4@96UA:6P@861D<F5S<R!T;R!B;W5N
M8V4@=&\N("!4:&ES(&ES(&AA;F1Y(&9O<B!S<&%M"B\O(')E<&]R=&EN9R!S
M;V9T=V%R92`H92YG+B!$4U!!32D@=VAI8V@@:&%S(&1I9F9E<F5N="!E+6UA
M:6P@86QI87-E<R!F;W(*+R\@<W!A;2!R97!O<G1I;F<@9F]R(&5A8V@@=7-E
M<BX*"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?:6UP7VAO;VM?<W!A;5]B
M;W5N8V4G*2D@>PHO+R`@("`@9G5N8W1I;VX@7VEM<%]H;V]K7W-P86U?8F]U
M;F-E*"1A8W1I;VXI"B\O("`@("!["B\O("`@("`@("`@)'!R969I>"`]("@D
M86-T:6]N(#T]("=S<&%M)RD@/R`G<W!A;2TG(#H@)V9P+2<["B\O("`@("`@
M("`@<F5T=7)N("1P<F5F:7@@+B!!=71H.CIG971"87)E075T:"@I("X@)T!E
M>&%M<&QE+F-O;2<["B\O("`@("!]"B\O('T*"B\O($AE<F4@86X@97AA;7!L
M92!?<V%M7VAO;VM?=7-E<FYA;64@9G5N8W1I;VX@=&\@<V5T('1H92!U<V5R
M;F%M92!T:&%T"B\O(%-P86U!<W-A<W-I;B!S965S('1O(&]N92!D:69F97)E
M;G0@9G)O;2!T:&4@2&]R9&4@=7-E<FYA;64N"@HO+R!I9B`H(69U;F-T:6]N
M7V5X:7-T<R@G7W-A;5]H;V]K7W5S97)N86UE)RDI('L*+R\@("`@(&9U;F-T
M:6]N(%]S86U?:&]O:U]U<V5R;F%M92@D:&]R9&5?=6ED*0HO+R`@("`@>PHO
M+R`@("`@("`@(&EF("AS=')S='(H)&AO<F1E7W5I9"P@)T`G*2D@>PHO+R`@
M("`@("`@("`@("`D<&%R=',@/2!E>'!L;V1E*"=`)RP@)&AO<F1E7W5I9"D[
M"B\O("`@("`@("`@("`@(')E='5R;B`D<&%R='-;,%T["B\O("`@("`@("`@
M?2!E;'-E('L*+R\@("`@("`@("`@("`@<F5T=7)N("1H;W)D95]U:60["B\O
M("`@("`@("`@?0HO+R`@("`@?0HO+R!]"@HO+R!(97)E(&ES(&%N(&5X86UP
M;&4@7W1U<F)A7VAO;VM?96YC;V1E7W!A<W-W;W)D("AA;F0@9&5C;V1E*2X@
M96YC;V1E(&ES"B\O(&-A;&QE9"!W:&5N('=E('-T;W)E(&$@=F%L=64[(&1E
M8V]D92!W:&5N('=E(&1I<W!L87D@:70N("!087-S=V]R9',@<VAO=6QD"B\O
M(&)E($U$-2!E;F-O9&5D+"!B=70@;F]T(&1I<W!L87EE9"X*+R\*+R\@24U0
M3U)404Y4.B!4:&4@;&%S="!P87)A;65T97(@:6X@=&AE<V4@97AA;7!L97,@
M*"8D;V)J96-T*2!I<R!O;FQY"B\O('!A<W-E9"!B>2!4=7)B82`R+C$@86YD
M(&QA=&5R+B!)9B!Y;W4@87)E('5S:6YG(%1U<F)A(#(N,"P@=&AE;B!Y;W4*
M+R\@;75S="!R96UO=F4@=&AE("8D;V)J96-T('!A<F%M971E<BX*"B\O(&EF
M("@A9G5N8W1I;VY?97AI<W1S*"=?='5R8F%?:&]O:U]E;F-O9&5?<&%S<W=O
M<F0G*2D@>PHO+R`@("`@9G5N8W1I;VX@7W1U<F)A7VAO;VM?96YC;V1E7W!A
M<W-W;W)D*"1N97=?<&%S<W=O<F0L("1O;&1?<&%S<W=O<F0L("8D8V]N=&%C
M="D*+R\@("`@('L*+R\@("`@("`@("!I9B`H:7-?;G5L;"@D;F5W7W!A<W-W
M;W)D*2!\?"`D;F5W7W!A<W-W;W)D(#T]("<G('Q\"B\O("`@("`@("`@("`@
M("1N97=?<&%S<W=O<F0@/3T@)UM.;W0@1&ES<&QA>65D72<I('L*+R\@("`@
M("`@("`@("`@<F5T=7)N("1O;&1?<&%S<W=O<F0["B\O("`@("`@("`@?2!E
M;'-E('L*+R\@("`@("`@("`@("`@<F5T=7)N(&UD-2@D;F5W7W!A<W-W;W)D
M*3L*+R\@("`@("`@("!]"B\O("`@("!]"B\O("`@("!F=6YC=&EO;B!?='5R
M8F%?:&]O:U]D96-O9&5?<&%S<W=O<F0H)'!A<W-W;W)D+"`F)&-O;G1A8W0I
M"B\O("`@("!["B\O("`@("`@("`@:68@*'-T<G-T<B@D7U-%4E9%4ELG4$A0
M7U-%3$8G72P@)V5D:71O8FIE8W0G*2D@>PHO+R`@("`@("`@("`@("!R971U
M<FX@;G5L;#L*+R\@("`@("`@("!](&5L<V4@>PHO+R`@("`@("`@("`@("!R
M971U<FX@)UM.;W0@1&ES<&QA>65D72<["B\O("`@("`@("`@?0HO+R`@("`@
M?0HO+R!]"@HO+R!(97)E(&ES(&%N(&5X86UP;&4@7W!A<W-W9%]H;V]K7W5S
M97)N86UE(&9U;F-T:6]N('1O('1R86YS;&%T92!W:&%T('1H90HO+R!U<V5R
M(&5N=&5R<RP@:6X@=&AE('5S97)N86UE(&)O>"P@:6YT;R!W:&%T('1H92!B
M86-K96YD(&5X<&5C=',N($EF('=E('=A;G0*+R\@=&\@861D($!E>&%M<&QE
M+F-O;2!T;R!T:&4@96YD(&]F('1H92!U<V5R;F%M92!T:&5N(&5N86)L92!T
M:&4@:&]O:R!A;F0@=7-E"B\O('1H:7,@9G5N8W1I;VXN"@HO+R!I9B`H(69U
M;F-T:6]N7V5X:7-T<R@G7W!A<W-W9%]H;V]K7W5S97)N86UE)RDI('L*+R\@
M("`@(&9U;F-T:6]N(%]P87-S=V1?:&]O:U]U<V5R;F%M92@D=7-E<FED*0HO
M+R`@("`@>PHO+R`@("`@("`@(')E='5R;B`D=7-E<FED("X@)T!E>&%M<&QE
M+F-O;2<["B\O("`@("!]"B\O('T*"B\O($AE<F4@:7,@86X@97AA;7!L92!?
M<&%S<W=D7VAO;VM?9&5F875L=%]U<V5R;F%M92!F=6YC=&EO;B!T;R!S970@
M=&AE"B\O('5S97)N86UE('1H92!P87-S=V0@;6]D=6QE('-E97,@=VAE;B!R
M97-E='1I;F<@<&%S<W=O<F1S(&)A<V5D(&]N('5S97)I9`HO+R!A;F0@<F5A
M;&TN("!4:&4@9&5F875L="!I<R!T;R!T86ME(&$@=7-E<FYA;64@;V8@=7-E
M<D!D;VUA:6XN=&QD(&%N9"!C:&%N9V4*+R\@:70@=&\@=7-E<BX@($EF('=E
M('=A;G0@=&\@;&5A=F4@:70@=6YT;W5C:&5D+"!E;F%B;&4@=&AE(&AO;VL@
M86YD('5S92!T:&ES"B\O(&9U;F-T:6]N+@H*+R\@:68@*"%F=6YC=&EO;E]E
M>&ES=',H)U]P87-S=V1?:&]O:U]D969A=6QT7W5S97)N86UE)RDI('L*+R\@
M("`@(&9U;F-T:6]N(%]P87-S=V1?:&]O:U]D969A=6QT7W5S97)N86UE*"1U
M<V5R:60I"B\O("`@("!["B\O("`@("`@("`@<F5T=7)N("1U<V5R:60["B\O
M("`@("!]"B\O('T*"B\O($AE<F4@:7,@86X@97AA;7!L92!?<&%S<W=D7VAO
M;VM?=7-E<F1N(&9U;F-T:6]N('1H870@>6]U(&-A;B!U<V4@=&\@<')O=FED
M90HO+R!Y;W5R(&QD87`@<V5R=F5R('=I=&@@82!U<V5R9&X@<V\@=&AA="!Y
M;W4@9&\@;F]T(&AA=F4@=&\@<&5R9F]R;2!A;F]N>6UO=7,*+R\@8FEN9',N
M(%1H92!F=6YC=&EO;B!T86ME<R!!=71H.CIG971!=71H*"D@87,@82!P87)A
M;65T97(*"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?<&%S<W=D7VAO;VM?
M=7-E<F1N)RDI('L*+R\@("`@(&9U;F-T:6]N(%]P87-S=V1?:&]O:U]U<V5R
M9&XH)&%U=&@I"B\O("`@("!["B\O("`@("`@("`@<F5T=7)N("=U:60])R`N
M("1A=71H("X@)RQO/65X86UP;&4N8V]M)SL*+R\@("`@('T*+R\@?0H*+R\@
M5&AI<R!I<R!A;B!E>&%M<&QE(&]F(&$@:&]O:R!T;R!S970@8W5S=&]M('1A
M9W,@=&\@8F4@:6YC;'5D960@:6X@82!':6%P971O"B\O('!A9V4@=&5M<&QA
M=&4N($EN('1H:7,@97AA;7!L92!A('1A9R!C;VYT86EN:6YG('1H92!C=7)R
M96YT(&1A=&4@:7,@<V5T('1O"B\O('1H92`D=&5M<&QA=&4@;V)J96-T(&%N
M9"!W:&EC:"!I<R!T:&5N(&%V86EL86)L92!I;B!T:&4@<&%G92!T96UP;&%T
M92!A<SH*+R\@("`@(#QT86<Z9&%T92`O/@H*+R\@:68@*"%F=6YC=&EO;E]E
M>&ES=',H)U]G:6%P971O7VAO;VM?<V5T=&%G<R<I*2!["B\O("`@("!F=6YC
M=&EO;B!?9VEA<&5T;U]H;V]K7W-E='1A9W,H)B1T96UP;&%T92D*+R\@("`@
M('L*+R\@("`@("`@("`D=&5M<&QA=&4M/G-E="@G9&%T92<L('-T<F9T:6UE
M*"<E82P@)64@)6(@)5DG*2D["B\O("`@("!]"B\O('T*"B\O(%1H:7,@:7,@
M86X@97AA;7!L92!O9B!A(&=R;W5P(&AO;VLN("!4;R!U<V4@:70@>6]U(&UU
M<W0@<V5T('1H92!G<F]U<`HO+R!D<FEV97(@=&\@:&]O:W,@:6X@8V]N9BYP
M:'`N("!4:&5N('EO=2!M=7-T(&-R96%T92!A($E47V1E<&%R=&UE;G0@9W)O
M=7`*+R\@*&)E8V%U<V4@=&AA="!I<R!H;W<@=V4@:VYO=R!W:&%T(&AO;VL@
M=&\@8V%L;"DN("!9;W4@8V%N(&%D9"!U<V5R<R!T;R!T:&4*+R\@9W)O=7`@
M87,@;F]R;6%L+"!A;F0@:6X@861D:71I;VX@=&AI<R!F=6YC=&EO;B!W:6QL
M(&)E(&-A;&QE9"!T;PHO+R!D>6YA;6EC86QL>2!I;F-L=61E('5S97)S(&EN
M('1H92!G<F]U<"X@($EN('1H:7,@97AA;7!L92!W92!W:6QL(&QO;VL@=7`*
M+R\@=VAE=&AE<B!O<B!N;W0@=&AI<R!U<V5R(&ES('!A<G0@;V8@=&AE($E4
M(&1E<&%R=&UE;G0@=7-I;F<@86X@97AT97)N86P*+R\@9&%T86)A<V4N"@HO
M+R!$969A=6QT($MO;&%B(&AO;VMS.@II9B`H(65M<'1Y*"1'3$]"04Q36R=C
M;VYF)UU;)VMO;&%B)UU;)V5N86)L960G72DI('L*("`@(')E<75I<F5?;VYC
M92`G2&]R9&4O2V]L86(N<&AP)SL*("`@(&EF("@A9G5N8W1I;VY?97AI<W1S
M*"=?:&]R9&5?:&]O:U]S:&%R95]I;FET)RDI('L*("`@("`@("!F=6YC=&EO
M;B!?=7-E<FYA;65?:&]O:U]F<F]M8F%C:V5N9"@D=7-E<DE$*0H@("`@("`@
M('L*("`@("`@("`@("`@+R\@0V]N;F5C="!T;R!T:&4@3$1!4"!S97)V97(N
M"B`@("`@("`@("`@("1D<R`](&QD87!?8V]N;F5C="@*("`@("`@("`@("`@
M("`@("1'3$]"04Q36R=C;VYF)UU;)VMO;&%B)UU;)VQD87`G75LG<V5R=F5R
M)UTL"B`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG8V]N9B==6R=K;VQA8B==
M6R=L9&%P)UU;)W!O<G0G70H@("`@("`@("`@("`I.PH@("`@("`@("`@("!I
M9B`H(21D<RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1U<V5R240["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@;&1A<%]S971?;W!T:6]N*"1D<RP@
M3$1!4%]/4%1?4%)/5$]#3TQ?5D524TE/3BP@,RD["B`@("`@("`@("`@("\O
M($)I;F0@86YO;GEM;W5S;'DN"B`@("`@("`@("`@("1R97-U;'0@/2!`;&1A
M<%]B:6YD*"1D<RD["B`@("`@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1U<V5R240["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@+R\@1FEN9"!T:&4@=7-E<B=S($1.+@H@("`@("`@("`@("`D
M<F5S=6QT(#T@;&1A<%]S96%R8V@H"B`@("`@("`@("`@("`@("`D9',L"B`@
M("`@("`@("`@("`@("`D1TQ/0D%,4ULG8V]N9B==6R=K;VQA8B==6R=L9&%P
M)UU;)V)A<V5D;B==+`H@("`@("`@("`@("`@("`@)W5I9#TG("X@)'5S97))
M1`H@("`@("`@("`@("`I.PH@("`@("`@("`@("`D96YT<GD@/2!L9&%P7V9I
M<G-T7V5N=')Y*"1D<RP@)')E<W5L="D["B`@("`@("`@("`@(&EF("@D96YT
M<GD@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`O+R!4:&4@=7-E<B!A
M;')E861Y(&%U=&AE;G1I8V%T960@=VET:"!H:7,@96UA:6P@861D<F5S<RX*
M("`@("`@("`@("`@("`@(')E='5R;B`D=7-E<DE$.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1E;6%I;"`](&QD87!?9V5T7W9A;'5E<R@D9',L("1E
M;G1R>2P@)VUA:6PG*3L*("`@("`@("`@("`@<F5T=7)N("1E;6%I;%LP73L*
M("`@("`@("!]"B`@("`@("`@9G5N8W1I;VX@7VAO<F1E7VAO;VM?<VAA<F5?
M:6YI="@F)'-H87)E7V]B:F5C="P@)&%P<"D*("`@("`@("!["B`@("`@("`@
M("`@($MO;&%B.CIS>6YC:')O;FES95-H87)E<R@D<VAA<F5?;V)J96-T+"`D
M87!P*3L*("`@("`@("!]"B`@("`@("`@9G5N8W1I;VX@7VAO<F1E7VAO;VM?
M<VAA<F5?861D*"8D<VAA<F4I"B`@("`@("`@>PH@("`@("`@("`@("!R971U
M<FX@2V]L86(Z.G5P9&%T95-H87)E*"1S:&%R92D["B`@("`@("`@?0H@("`@
M("`@(&9U;F-T:6]N(%]H;W)D95]H;V]K7W-H87)E7VUO9&EF>2@F)'-H87)E
M*0H@("`@("`@('L*("`@("`@("`@("`@<F5T=7)N($MO;&%B.CIU<&1A=&53
M:&%R92@D<VAA<F4I.PH@("`@("`@('T*("`@("`@("!F=6YC=&EO;B!?:&]R
M9&5?:&]O:U]S:&%R95]R96UO=F4H)B1S:&%R92D*("`@("`@("!["B`@("`@
M("`@("`@(')E='5R;B!+;VQA8CHZ<F5M;W9E4VAA<F4H)'-H87)E*3L*("`@
M("`@("!]"B`@("`@("`@9G5N8W1I;VX@7VEM<%]H;V]K7VUB;WA?<F5D:7)E
M8W0H)&UA:6QB;W@I"B`@("`@("`@>PH@("`@("`@("`@("!S=VET8V@@*$MO
M;&%B.CIG971-86EL8F]X5'EP92@D;6%I;&)O>"DI('L*("`@("`@("`@("`@
M8V%S92`G979E;G0G.@H@("`@("`@("`@("`@("`@<F5T=7)N("1'3$]"04Q3
M6R=R96=I<W1R>2==+3YG970H)W=E8G)O;W0G+"`G:W)O;F]L:71H)RD["@H@
M("`@("`@("`@("!C87-E("=T87-K)SH*("`@("`@("`@("`@("`@(')E='5R
M;B`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=W96)R;V]T)RP@)VYA9R<I
M.PH*("`@("`@("`@("`@8V%S92`G;F]T92<Z"B`@("`@("`@("`@("`@("!R
M971U<FX@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B<F]O="<L("=M
M;F5M;R<I.PH*("`@("`@("`@("`@8V%S92`G8V]N=&%C="<Z"B`@("`@("`@
M("`@("`@("!R971U<FX@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B
M<F]O="<L("=T=7)B82<I.PH*("`@("`@("`@("`@9&5F875L=#H*("`@("`@
M("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@("`@("!F=6YC=&EO;B!?:6UP7VAO;VM?;6)O>%]I8V]N<R@I"B`@("`@
M("`@>PH@("`@("`@("`@("!S=&%T:6,@)&EC;VYS.PH*("`@("`@("`@("`@
M:68@*"%E;7!T>2@D:6-O;G,I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)&EC;VYS.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D9F]L9&5R<R`]
M($MO;&%B.CIL:7-T1F]L9&5R<R@I.PH*("`@("`@("`@("`@)&EC;VYS(#T@
M87)R87DH*3L*"B`@("`@("`@("`@(&9O<F5A8V@@*"1F;VQD97)S(&%S("1F
M;VQD97(I('L*("`@("`@("`@("`@("`@("1N86UE(#T@<')E9U]R97!L86-E
M*"<O7GM;7GU=*WTO)RP@)R<L("1F;VQD97);,%TI.PH*("`@("`@("`@("`@
M("`@('-W:71C:"`H)&9O;&1E<ELQ72D@>PH@("`@("`@("`@("`@("`@8V%S
M92`G979E;G0G.@H@("`@("`@("`@("`@("`@("`@("1I8V]N<ULD;F%M95T@
M/2!(;W)D93HZ:6UG*`H@("`@("`@("`@("`@("`@("`@("`@("`D1TQ/0D%,
M4ULG<F5G:7-T<GDG72T^9V5T*"=I8V]N)RP@)VMR;VYO;&ET:"<I+`H@("`@
M("`@("`@("`@("`@("`@("`@("!?*")#86QE;F1A<B(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`G=VED=&@](C$V(B!H96EG:'0](C$V(B!S='EL93TB
M=F5R=&EC86PM86QI9VXZ;6ED9&QE(B<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("<G"B`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=T87-K)SH*("`@
M("`@("`@("`@("`@("`@("`D:6-O;G-;)&YA;65=(#T@2&]R9&4Z.FEM9R@*
M("`@("`@("`@("`@("`@("`@("`@("`@)$=,3T)!3%-;)W)E9VES=')Y)UTM
M/F=E="@G:6-O;B<L("=N86<G*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M7R@B5&%S:W,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@)W=I9'1H/2(Q
M-B(@:&5I9VAT/2(Q-B(@<W1Y;&4](G9E<G1I8V%L+6%L:6=N.FUI9&1L92(G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`G)PH@("`@("`@("`@("`@("`@
M("`@("D["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("`@("`@8V%S92`G;F]T92<Z"B`@("`@("`@("`@("`@("`@("`@)&EC;VYS
M6R1N86UE72`]($AO<F1E.CII;6<H"B`@("`@("`@("`@("`@("`@("`@("`@
M("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)VEC;VXG+"`G;6YE;6\G*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@7R@B3F]T97,B*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@)W=I9'1H/2(Q-B(@:&5I9VAT/2(Q-B(@<W1Y;&4]
M(G9E<G1I8V%L+6%L:6=N.FUI9&1L92(G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`G)PH@("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G8V]N=&%C="<Z
M"B`@("`@("`@("`@("`@("`@("`@)&EC;VYS6R1N86UE72`]($AO<F1E.CII
M;6<H"B`@("`@("`@("`@("`@("`@("`@("`@("1'3$]"04Q36R=R96=I<W1R
M>2==+3YG970H)VEC;VXG+"`G='5R8F$G*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@7R@B0V]N=&%C=',B*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M)W=I9'1H/2(Q-B(@:&5I9VAT/2(Q-B(@<W1Y;&4](G9E<G1I8V%L+6%L:6=N
M.FUI9&1L92(G+`H@("`@("`@("`@("`@("`@("`@("`@("`G)PH@("`@("`@
M("`@("`@("`@("`@("D["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(')E
M='5R;B`D:6-O;G,["B`@("`@("`@?0H@("`@?0I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+V5T8R]P<V$M:&]R
M9&4O:&]R9&4O8V]N9BYX;6P`````````````````````````````````````
M````````````````````````````````````````,#`P-#0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`R,#0Q,C,@,3`U,34T,S,W-30@,#(Q,#8U`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_>&UL('9E
M<G-I;VX](C$N,"(_/@H\(2TM("1(;W)D93H@:&]R9&4O8V]N9FEG+V-O;F8N
M>&UL+'8@,2XW-"XR+C0Q(#(P,#8O,#@O,#0@,3<Z,3,Z,C4@:F%N($5X<"`D
M("TM/@H\8V]N9FEG=7)A=&EO;CX*(#QC;VYF:6=T86(@;F%M93TB9V5N97)A
M;"(@9&5S8STB1V5N97)A;"(^"B`@/&-O;F9I9VAE861E<CY'96YE<F%L($AO
M<F1E(%-E='1I;F=S/"]C;VYF:6=H96%D97(^"B`@/&-O;F9I9W!H<"!N86UE
M/2)D96)U9U]L979E;"(@9&5S8STB5&AE('9A;'5E('1O('-E=`H@(&5R<F]R
M7W)E<&]R=&EN9R@I('1O+@H@(%-E92!H='1P.B\O=W=W+G!H<"YN970O;6%N
M=6%L+V9U;F-T:6]N+F5R<F]R+7)E<&]R=&EN9RYP:'`@9F]R(&UO<F4*("!I
M;F9O<FUA=&EO;B!A;F0@<&]S<VEB;&4@=F%L=65S+B(^15]!3$P@)F%M<#L@
M?D5?3D]424-%/"]C;VYF:6=P:'`^"B`@/&-O;F9I9VEN=&5G97(@;F%M93TB
M;6%X7V5X96-?=&EM92(@9&5S8STB268@=V4@;F5E9"!T;R!P97)F;W)M(&$@
M;&]N9PH@(&]P97)A=&EO;BP@=VAA="!S:&]U;&0@=V4@<V5T(&UA>%]E>&5C
M=71I;VY?=&EM92!T;R`H:6X@<V5C;VYD<RD_(#`@;65A;G,@;F\*("!L:6UI
M=#L@:&]W979E<BP@82!V86QU92!O9B`P('=I;&P@8V%U<V4@82!W87)N:6YG
M(&EF('EO=2!A<F4@<G5N;FEN9R!I;B!S869E"B`@;6]D92X@4V5E(&AT='`Z
M+R]W=W<N<&AP+FYE="]M86YU86PO9G5N8W1I;VXN<V5T+71I;64M;&EM:70N
M<&AP(&9O<B!M;W)E"B`@:6YF;W)M871I;VXN(CXP/"]C;VYF:6=I;G1E9V5R
M/@H@(#QC;VYF:6=E;G5M(&YA;64](G5S95]S<VPB('%U;W1E/2)F86QS92(@
M9&5S8STB1&5T97)M:6YE<R!H;W<@=V4@9V5N97)A=&4*("!F=6QL(%523',@
M*&9O<B!L;V-A=&EO;B!H96%D97)S(&%N9"!S=6-H*2XF;'0[8G(@+R9G=#M.
M3U1%.B!)9B!Y;W4@8VAO;W-E('1O"B`@86QW87ES(&=E;F5R871E(&AT='!S
M(%523',L('EO=2!-55-4(&AA<F1C;V1E('1H92!C;W)R96-T($A45%!3('!O
M<G0@;G5M8F5R"B`@:6X@=&AE('-E<G9E<B!P;W)T('-E='1I;F<@8F5L;W<N
M($]T:&5R=VES92!(;W)D92!W:6QL(&)E('5N86)L92!T;R!G96YE<F%T90H@
M(&-O<G)E8W0@2%144%,@55),<R!W:&5N(&$@=7-E<B!T<FEE<R!T;R!A8V-E
M<W,@2&]R9&4@=FEA(&$@;F]N+4A45%!3('!O<G0N(CXR"B`@(#QV86QU97,^
M"B`@("`\=F%L=64@9&5S8STB07-S=6UE('1H870@=V4@87)E(&YO="!U<VEN
M9R!34TP@86YD(&YE=F5R(&=E;F5R871E(&AT='!S(%523',N(CXP/"]V86QU
M93X*("`@(#QV86QU92!D97-C/2)!<W-U;64@=&AA="!W92!A<F4@=7-I;F<@
M4U-,(&%N9"!A;'=A>7,@9V5N97)A=&4@:'1T<',@55),<RXB/C$\+W9A;'5E
M/@H@("`@/'9A;'5E(&1E<V,](D%T=&5M<'0@=&\@875T;RUD971E8W0L(&%N
M9"!G96YE<F%T92!54DQS(&%P<')O<')I871E;'DB/C(\+W9A;'5E/@H@("`@
M/'9A;'5E(&1E<V,](D%S<W5M92!T:&%T('=E(&%R92!N;W0@=7-I;F<@4U-,
M(&%N9"!G96YE<F%T92!H='1P<R!54DQS(&]N;'D*("`@(&9O<B!L;V=I;BXB
M/C,\+W9A;'5E/@H@("`\+W9A;'5E<SX*("`\+V-O;F9I9V5N=6T^"B`@/&-O
M;F9I9W-E8W1I;VX@;F%M93TB<V5R=F5R(CX*("`@/&-O;F9I9W!H<"!N86UE
M/2)N86UE(B!D97-C/2)7:&%T('-E<G9E<B!N86UE('-H;W5L9"!W92!U<V4_
M(%EO=2=L;"!P<F]B86)L>0H@("!K;F]W(&EF('EO=2!N965D('1O(&-H86YG
M92!T:&ES(&1E9F%U;'0[(&]N;'D@:6X@<VET=6%T:6]N<R!W:&5R92!Y;W4@
M;F5E9"!T;PH@("!O=F5R<FED92!W:&%T($%P86-H92!T:&EN:W,@=&AE('-E
M<G9E<B!N86UE"B`@(&ES+B(^)%]315)615);)U-%4E9%4E].04U%)UT\+V-O
M;F9I9W!H<#X*("`@/&-O;F9I9W!H<"!N86UE/2)P;W)T(B!D97-C/2)7:&%T
M('!O<G0@;G5M8F5R(&ES('1H92!W96)S97)V97(@<G5N;FEN9R!O;C\*("`@
M06=A:6XL('EO=2!S:&]U;&1N)W0@;F5E9"!T;R!C:&%N9V4@=&AE(&1E9F%U
M;'0L(&%N9"!Y;W4@<')O8F%B;'D@:VYO=R!I="!I9@H@("!Y;W4@9&\N(%1H
M92!E>&-E<'1I;VX@:7,@:68@>6]U(&AA=F4@8VAO<V5N('1O(&%L=V%Y<R!G
M96YE<F%T92!H='1P<R!54DQS+"!A<PH@("!D97-C<FEB960@86)O=F4N(CXD
M7U-%4E9%4ELG4T525D527U!/4E0G73PO8V]N9FEG<&AP/@H@(#PO8V]N9FEG
M<V5C=&EO;CX*("`\8V]N9FEG8F]O;&5A;B!N86UE/2)C;VUP<F5S<U]P86=E
M<R(@9&5S8STB268@=&AI<R!O<'1I;VX@:7,@<V5T('1O('1R=64L(&%N9`H@
M('EO=2!H879E('1H92!P:'`@>FQI8B!E>'1E;G-I;VXL('!A9V5S(&]V97(@
M82!C97)T86EN('-I>F4@=VEL;"!B92!C;VUP<F5S<V5D"B`@86YD('-E;G0@
M=&\@=&AE(&)R;W=S97(@87,@9WII<"UE;F-O9&5D(&1A=&$@:6X@;W)D97(@
M=&\@<V%V90H@(&)A;F1W:61T:"X@5&AE<F4@:7,@82!#4%4M=7-A9V4@<&5N
M86QT>2!T;R!P87D@9F]R('1H:7,L(&)U="!T:&4@9&5C<F5A<V4@:6X*("!P
M86=E('-I>F4@8V%N(&)E(&1R86UA=&EC("@W,&L@=&\@=6YD97(@,3!K(&9O
M<B!A(&9U;&P@;6%I;&)O>"!P86=E*2P@86YD(&ES"B`@;6]R92!T:&%N('=O
M<G1H(&ET(&]V97(@86YY=&AI;F<@8G5T(&%N(&5X=')E;65L>2!F87-T"B`@
M;&EN:RXB/G1R=64\+V-O;F9I9V)O;VQE86X^"B`@/&-O;F9I9VEN=&5G97(@
M;F%M93TB=6UA<VLB(&]C=&%L/2)T<G5E(B!D97-C/2)7:&%T('5M87-K('-H
M;W5L9"!W92!R=6X@=VET:#\@5&AI<R!W:6QL(&%F9F5C="!T:&4@<&5R;6ES
M<VEO;G,@;VX@86YY('1E;7!O<F%R>2!F:6QE<R!T:&%T(&%R92!C<F5A=&5D
M+B!4:&ES('9A;'5E(&ES(&%N(&EN=&5G97(N(CXP-S<\+V-O;F9I9VEN=&5G
M97(^"B`@/&-O;F9I9W-T<FEN9R!N86UE/2)T;7!D:7(B(')E<75I<F5D/2)F
M86QS92(@9&5S8STB268@>6]U('=A;G0@=&\@=7-E(&$*("!T96UP;W)A<GD@
M9&ER96-T;W)Y(&]T:&5R('1H86X@=&AE('-Y<W1E;2!D969A=6QT(&]R('1H
M92!O;F4@<W!E8VEF:65D(&EN"B`@<&AP)W,@=7!L;V%D7W1M<%]D:7(@=F%L
M=64L(&5N=&5R(&ET(&AE<F4N(B\^"B`@/&-O;F9I9W-E8W1I;VX@;F%M93TB
M<V5S<VEO;B(^"B`@(#QC;VYF:6=S=')I;F<@;F%M93TB;F%M92(@9&5S8STB
M5VAA="!N86UE('-H;W5L9"!W92!U<V4@9F]R('1H92!S97-S:6]N('1H870*
M("`@2&]R9&4@87!P<R!S:&%R93\@268@>6]U('=A;G0@=&\@<VAA<F4@<V5S
M<VEO;G,@=VET:"!O=&AE<B!A<'!L:6-A=&EO;G,@;VX*("`@>6]U<B!W96)S
M97)V97(L('EO=2!W:6QL(&YE960@=&\@;6%K92!S=7)E('1H870@=&AE>2!A
M<F4@=7-I;F<@=&AE('-A;64*("`@<V5S<VEO;B!N86UE+B`@3F]T93H@4V5S
M<VEO;B!N86UE<R!M=7-T(&-O;G-I<W0@;V8@;VYL>2!A;'!H86YU;65R:6,*
M("`@8VAA<F%C=&5R<RXB/DAO<F1E/"]C;VYF:6=S=')I;F<^"B`@(#QC;VYF
M:6=B;V]L96%N(&YA;64](G5S95]O;FQY7V-O;VMI97,B(&1E<V,](E-H;W5L
M9"!W92!O;FQY(&%L;&]W('-E<W-I;VX*("`@:6YF;W)M871I;VX@=&\@8F4@
M<W1O<F5D(&EN(&$@<V5S<VEO;B!C;V]K:64@86YD(&YO="!B92!P87-S960@
M8GD@55),("A'150I"B`@('!A<F%M971E<G,_(%1H:7,@:7,@;VX@8GD@9&5F
M875L="!B96-A=7-E('!A<W-I;F<@<V5S<VEO;B!I;F9O<FUA=&EO;B!I;@H@
M("!T:&4@55),(&ES(&$@<V5C=7)I='D@<FES:RX@0V]N<VED97(@8V%R969U
M;&QY(&)E9F]R92!T=7)N:6YG(&ET(&]F9BXB/@H@("!T<G5E/"]C;VYF:6=B
M;V]L96%N/@H@("`\8V]N9FEG<W1R:6YG(&YA;64](F-A8VAE7VQI;6ET97(B
M(&1E<V,](E=H870@8V%C:&EN9R!L979E;"!S:&]U;&0@=V4@=7-E"B`@(&9O
M<B!T:&4@<V5S<VEO;C\@1$\@3D]4($-(04Y'12!42$E3(%5.3$534R!93U4@
M)FQT.W-T<F]N9R9G=#M214%,3%DF;'0[+W-T<F]N9R9G=#L@2TY/5PH@("!7
M2$%4(%E/52!!4D4@1$])3D<N(%-E='1I;F<@=&AI<R!T;R!A;GET:&EN9R!O
M=&AE<B!T:&%N("=N;V-A8VAE)R!W:6QL(&%L;6]S=`H@("!C97)T86EN;'D@
M<F5S=6QT(&EN('-E=F5R96QY(&)R;VME;B!S8W)I<'0@8F5H879I;W(N(CYN
M;V-A8VAE/"]C;VYF:6=S=')I;F<^"B`@(#QC;VYF:6=I;G1E9V5R(&YA;64]
M(G1I;65O=70B(&1E<V,](DAO=R!L;VYG('-H;W5L9"!S97-S:6]N<R!L87-T
M("AI;B!S96-O;F1S*3\@,"!M96%N<PH@("!T:&%T('1H92!S97-S:6]N(&5N
M9',@=VAE;B!T:&4@=7-E<B!C;&]S97,@=&AE:7(@8G)O=W-E<BX@4V5T(&]T
M:&5R('9A;'5E<PH@("!W:71H(&-A<F4@+2!S964*("`@:'1T<#HO+W=W=RYP
M:'`N;F5T+VUA;G5A;"]E;B]F=6YC=&EO;BYS97-S:6]N+7-E="UC;V]K:64M
M<&%R86US+G!H<"XB/C`\+V-O;F9I9VEN=&5G97(^"B`@/"]C;VYF:6=S96-T
M:6]N/@H@(#QC;VYF:6=S96-T:6]N(&YA;64](F-O;VMI92(^"B`@(#QC;VYF
M:6=P:'`@;F%M93TB9&]M86EN(B!D97-C/2)7:&%T(&1O;6%I;B!S:&]U;&0@
M=V4@<V5T(&-O;VMI97,@9G)O;3\@268*("`@>6]U(&AA=F4@82!C;'5S=&5R
M('1H870@;F5E9',@=&\@<VAA<F4@8V]O:VEE<RP@=&AI<R!M:6=H="!B92`G
M+F5X86UP;&4N8V]M)PH@("`M('1H92!L96%D:6YG("<N)R!I<R!I;7!O<G1A
M;G0N($UO<W0@;&EK96QY+"!T:&]U9V@L('EO=2!W;VXG="!H879E('1O(&-H
M86YG90H@("!T:&4@9&5F875L="XB/B1?4T525D526R=315)615)?3D%-12==
M/"]C;VYF:6=P:'`^"B`@(#QC;VYF:6=S=')I;F<@;F%M93TB<&%T:"(@9&5S
M8STB5VAA="!P871H('-H;W5L9"!W92!S970@8V]O:VEE<R!T;S\@5&AI<PH@
M("!S:&]U;&0@;6%T8V@@=VAE<F4@2&]R9&4@:7,@;VX@>6]U<B!W96)S97)V
M97(@+2!I9B!I="!I<R!A="`O:&]R9&4L('1H96X@=&AI<PH@("!S:&]U;&0@
M8F4@)R]H;W)D92<N($EF($AO<F1E(&ES(&EN<W1A;&QE9"!A<R!T:&4@9&]C
M=6UE;G0@<F]O="P@=&AE;B!T:&ES"B`@(&YE961S('1O(&)E("<O)R`M($Y/
M5"`G)RXF;'0[8G(@+R9G=#LF;'0[<W1R;VYG)F=T.T)55"9L=#LO<W1R;VYG
M)F=T.RP@:68@244@=VEL;"!B90H@("!U<V5D('1O(&%C8V5S<R!(;W)D92!M
M;V1U;&5S+"!Y;W4@<VAO=6QD(')E860@=&AI<R!F:7)S="`H9&ES8W5S<VEN
M9R!I<W-U97,*("`@=VET:"!)12=S($-O;G1E;G0@061V:7-O<BDZ"B`@(&AT
M='`Z+R]L:7-T<RYH;W)D92YO<F<O87)C:&EV97,O:6UP+U=E96LM;V8M36]N
M+3(P,#,P,3$S+S`R.3$T.2YH=&UL(CXO:&]R9&4\+V-O;F9I9W-T<FEN9SX*
M("`\+V-O;F9I9W-E8W1I;VX^"B`\+V-O;F9I9W1A8CX*"B`\8V]N9FEG=&%B
M(&YA;64](G-Q;"(@9&5S8STB1&%T86)A<V4B/@H@(#QC;VYF:6=S96-T:6]N
M(&YA;64](G-Q;"(^"B`@(#QC;VYF:6=H96%D97(^2&]R9&4@1&%T86)A<V4@
M4V5T=&EN9W,\+V-O;F9I9VAE861E<CX*("`@/&-O;F9I9V1E<V-R:7!T:6]N
M/B9L=#MS=')O;F<F9W0[3D]413HF;'0[+W-T<F]N9R9G=#L@5&AE<V4@87)E
M(&]N;'D@=&AE"B`@("9L=#ME;29G=#MD969A=6QT)FQT.R]E;29G=#L@=F%L
M=65S(&9O<B!A;GD@9&%T86)A<V4@9')I=F5N(&)A8VME;F1S+B!9;W4*("`@
M<W1I;&P@;F5E9"!T;R!C;VYF:6=U<F4@=&AE(&1I9F9E<F5N="!S>7-T96US
M(&QI:V4@(E!R969E<F5N8V5S(B!O<@H@("`B1&%T851R964B('1O(&%C='5A
M;&QY("9L=#ME;29G=#MU<V4F;'0[+V5M)F=T.R!A(&1A=&%B87-E"B`@(&)A
M8VME;F0N/"]C;VYF:6=D97-C<FEP=&EO;CX*("`@/&-O;F9I9W-Q;"!S=VET
M8VAN86UE/2)P:'!T>7!E(B!B87-E8V]N9FEG/2)T<G5E(B`O/@H@(#PO8V]N
M9FEG<V5C=&EO;CX*(#PO8V]N9FEG=&%B/@H*(#QC;VYF:6=T86(@;F%M93TB
M875T:"(@9&5S8STB075T:&5N=&EC871I;VXB/@H@(#QC;VYF:6=S96-T:6]N
M(&YA;64](F%U=&@B/@H@("`\8V]N9FEG:&5A9&5R/DAO<F1E($%U=&AE;G1I
M8V%T:6]N/"]C;VYF:6=H96%D97(^"B`@(#QC;VYF:6=L:7-T(&YA;64](F%D
M;6EN<R(@9&5S8STB5VAI8V@@=7-E<G,@<VAO=6QD(&)E('1R96%T960@87,*
M("`@861M:6YI<W1R871O<G,@*')O;W0L('-U<&5R+75S97(I(&)Y($AO<F1E
M/R(@<F5Q=6ER960](F9A;'-E(B\^"B`@(#QC;VYF:6=B;V]L96%N(&YA;64]
M(F-H96-K:7`B(&1E<V,](E-H;W5L9"!W92!A;'=A>7,@<W1O<F4@86YD('9A
M;&ED871E"B`@('1H92!)4"!A9&1R97-S(&]F('1H92!C;&EE;G0@*&%S('-E
M96X@8GD@=&AE('=E8B!S97)V97(I(&EN('1H92!S97-S:6]N/PH@("!$;VEN
M9R!S;R!W:6QL(&AE;'`@:6YC<F5A<V4@<V5C=7)I='D@8GD@96YS=7)I;F<@
M=&AA="!A;B!A='1A8VME<B!F<F]M"B`@(&%N;W1H97(@:&]S="!C86YN;W0@
M=')Y('1O(&AI:F%C:R!T:&4@<V5S<VEO;BXB/G1R=64\+V-O;F9I9V)O;VQE
M86X^"B`@(#QC;VYF:6=B;V]L96%N(&YA;64](F-H96-K8G)O=W-E<B(@9&5S
M8STB4VAO=6QD('=E(&%L=V%Y<R!S=&]R92!A;F0@=F%L:61A=&4*("`@=&AE
M(&)R;W=S97(@<W1R:6YG(&]F('1H92!C;&EE;G0@*&%S('-E96X@8GD@=&AE
M('=E8B!S97)V97(I(&EN('1H92!S97-S:6]N/PH@("!$;VEN9R!S;R!W:6QL
M(&AE;'`@:6YC<F5A<V4@<V5C=7)I='D@8GD@96YS=7)I;F<@=&AA="!A;B!A
M='1A8VME<B!F<F]M"B`@(&%N;W1H97(@:&]S="!C86YN;W0@=')Y('1O(&AI
M:F%C:R!T:&4@<V5S<VEO;BXB/G1R=64\+V-O;F9I9V)O;VQE86X^"B`@(#QC
M;VYF:6=S=')I;F<@;F%M93TB86QT97)N871E7VQO9VEN(B!D97-C/2))9B!T
M:&ES(&ES(&YO="!F86QS92P@:70@:7,*("`@87-S=6UE9"!T;R!B92!T:&4@
M55),(&]F(&%N(&%L=&5R;F%T92!L;V=I;B!S8W)E96X@=VAI8V@@=VEL;"!B
M92!U<V5D(&EN"B`@('!L86-E(&]F(&AO<F1E)W,@9&5F875L="!L;V=I;B!S
M8W)E96XN(CYF86QS93PO8V]N9FEG<W1R:6YG/@H@("`\8V]N9FEG<W1R:6YG
M(&YA;64](G)E9&ER96-T7V]N7VQO9V]U="(@9&5S8STB268@=&AI<R!I<R!N
M;W0@9F%L<V4L(&ET(&ES"B`@(&%S<W5M960@=&\@8F4@=&AE(%523"!O9B!A
M;B!A;'1E<FYA=&4@;&]G;W5T('!A9V4@=VAI8V@@=7-E<G,@=VEL;"!B92!S
M96YT"B`@('1O('=H96X@=&AE>2!L;V<@;W5T+B(^9F%L<V4\+V-O;F9I9W-T
M<FEN9SX*("`@/&-O;F9I9W-W:71C:"!N86UE/2)D<FEV97(B(&1E<V,](E=H
M870@8F%C:V5N9"!S:&]U;&0@=V4@=7-E(&9O<@H@("!A=71H96YT:6-A=&EN
M9R!U<V5R<R!T;R!(;W)D93\B/@H*("`@(#QC87-E(&YA;64](F%P<&QI8V%T
M:6]N(B!D97-C/2),970@82!(;W)D92!A<'!L:6-A=&EO;B!H86YD;&4*("`@
M(&%U=&AE;G1I8V%T:6]N(CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P
M87)A;7,B/@H@("`@("`\8V]N9FEG96YU;2!N86UE/2)A<'`B(&1E<V,](E1H
M92!A<'!L:6-A=&EO;B!W:&EC:"!I<R!P<F]V:61I;F<*("`@("`@875T:&5N
M=&EC871I;VXB/FEM<`H@("`@("`@/'9A;'5E<SX*("`@("`@("`\8V]N9FEG
M<W!E8VEA;"!N86UE/2)L:7-T+6AO<F1E+6%P<',B+SX*("`@("`@(#PO=F%L
M=65S/@H@("`@("`\+V-O;F9I9V5N=6T^"B`@("`@/"]C;VYF:6=S96-T:6]N
M/@H@("`@/"]C87-E/@H*("`@(#QC87-E(&YA;64](F%U=&\B(&1E<V,](D%U
M=&]M871I8R!A=71H96YT:6-A=&EO;B!A<R!A(&-E<G1A:6X@=7-E<B(^"B`@
M("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I
M9W-T<FEN9R!N86UE/2)U<V5R;F%M92(@9&5S8STB5&AE('5S97)N86UE('1O
M(&%U=&AE;G1I8V%T92!E=F5R>6]N92!A<R(^:&]R9&5?=7-E<CPO8V]N9FEG
M<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G!A<W-W;W)D(B!D
M97-C/2)4:&4@<&%S<W=O<F0@=&\@=7-E(&9O<B!T:&4@=7-E<B=S(&-R961E
M;G1I86QS(B!R97%U:7)E9#TB9F%L<V4B+SX*("`@("`@/&-O;F9I9V)O;VQE
M86X@;F%M93TB<F5Q=65S='5S97(B(&1E<V,](D%L;&]W('5S97)N86UE('1O
M(&)E('!A<W-E9"!B>2!'150L(%!/4U0@;W(@8V]O:VEE/R(^9F%L<V4\+V-O
M;F9I9V)O;VQE86X^"B`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@/"]C87-E
M/@H*("`@(#QC87-E(&YA;64](F-O;7!O<VET92(@9&5S8STB0V]M<&]S:71E
M(&%U=&AE;G1I8V%T:6]N(CX*("`@("`\8V]N9FEG9&5S8W)I<'1I;VX^"B`@
M("`@(%1H:7,@875T:&5N=&EC871I;VX@9')I=F5R(&YE961S(&UA;G5A;"!C
M;VYF:6=U<F%T:6]N(&YO="!P;W-S:6)L90H@("`@("!T:')O=6=H('1H:7,@
M:6YT97)F86-E+B!!9&0@=&AE(&%P<')O<')I871E(&-O;F9I9W5R871I;VX@
M;&EN97,@870@=&AE"B`@("`@(&5N9"!O9B!T:&4@9V5N97)A=&5D(&-O;F9I
M9W5R871I;VX@9FEL92X*("`@("`\+V-O;F9I9V1E<V-R:7!T:6]N/@H@("`@
M/"]C87-E/@H*("`@(#QC87-E(&YA;64](F9T<"(@9&5S8STB1E10(&%U=&AE
M;G1I8V%T:6]N(CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B
M/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](FAO<W1S<&5C(B!D97-C/2)4
M:&4@:&]S=&YA;64@;W(@25`@861D<F5S<R!O9B!T:&4@1E10"B`@("`@('-E
M<G9E<B(^;&]C86QH;W-T/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=I
M;G1E9V5R(&YA;64](G!O<G0B(&1E<V,](E1H92!S97)V97(@<&]R="!T;R!C
M;VYN96-T"B`@("`@('1O(CXR,3PO8V]N9FEG:6YT96=E<CX*("`@("`\+V-O
M;F9I9W-E8W1I;VX^"B`@("`\+V-A<V4^"@H@("`@/&-A<V4@;F%M93TB:'1T
M<"(@9&5S8STB2%144"`H0F%S:6,@075T:&5N=&EC871I;VXO+FAT<&%S<W=D
M*0H@("`@875T:&5N=&EC871I;VXB/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA
M;64](G!A<F%M<R(^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB:'1P87-S
M=V1?9FEL92(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@;&]C871I;VX@
M;V8*("`@("`@=&AE(&AT<&%S<W=D(&9I;&4@8V]N=&%I;FEN9R!T:&4@=7-E
M<B!N86UE<R!A;F0@<&%S<W=O<F1S(B\^"B`@("`@(#QC;VYF:6=E;G5M(&YA
M;64](F5N8W)Y<'1I;VXB(&1E<V,](E-P96-I9FEE<R!W:&%T(&MI;F0@;V8@
M<&%S<W=O<F1S(&%R90H@("`@("!I;B!T:&4@:'1P87-S=V0@9FEL92(^9&5S
M"B`@("`@("`\=F%L=65S/@H@("`@("`@(#QV86QU93YA<')M9#4\+W9A;'5E
M/@H@("`@("`@(#QV86QU93YC<GEP=#PO=F%L=64^"B`@("`@("`@/'9A;'5E
M/F-R>7!T+6)L;W=F:7-H/"]V86QU93X*("`@("`@("`\=F%L=64^8W)Y<'0M
M9&5S/"]V86QU93X*("`@("`@("`\=F%L=64^8W)Y<'0M;60U/"]V86QU93X*
M("`@("`@("`\=F%L=64^;60U+6)A<V4V-#PO=F%L=64^"B`@("`@("`@/'9A
M;'5E/FUD-2UH97@\+W9A;'5E/@H@("`@("`@(#QV86QU93YP;&%I;CPO=F%L
M=64^"B`@("`@("`@/'9A;'5E/G-H83PO=F%L=64^"B`@("`@("`@/'9A;'5E
M/G-M9#4\+W9A;'5E/@H@("`@("`@(#QV86QU93YS<VAA/"]V86QU93X*("`@
M("`@(#PO=F%L=65S/@H@("`@("`\+V-O;F9I9V5N=6T^"B`@("`@/"]C;VYF
M:6=S96-T:6]N/@H@("`@/"]C87-E/@H*("`@(#QC87-E(&YA;64](FEM87`B
M(&1E<V,](DE-05`@875T:&5N=&EC871I;VXB/@H@("`@(#QC;VYF:6=S96-T
M:6]N(&YA;64](G!A<F%M<R(^"B`@("`@(#QC;VYF:6=S=VET8V@@;F%M93TB
M:6UA<&-O;F9I9R(@9&5S8STB0V]N9FEG=7)A=&EO;B!T>7!E(CX*("`@("`@
M(#QC87-E(&YA;64](F1S;B(@9&5S8STB1%-.(CX*("`@("`@("`\8V]N9FEG
M<W1R:6YG(&YA;64](F1S;B(@9&5S8STB5&AE(&9U;&P@24U!4"!C;VYN96-T
M:6]N"B`@("`@("`@<W1R:6YG(CY[;&]C86QH;W-T.C$T,R]I;6%P+VYO=&QS
M?3PO8V]N9FEG<W1R:6YG/@H@("`@("`@/"]C87-E/@H@("`@("`@/&-A<V4@
M;F%M93TB<V5P87)A=&4B(&1E<V,](E-E<&%R871E('9A;'5E<R(^"B`@("`@
M("`@/&-O;F9I9W-T<FEN9R!N86UE/2)H;W-T<W!E8R(@9&5S8STB5&AE(&AO
M<W1N86UE(&]R($E0(&%D9')E<W,@;V8@=&AE"B`@("`@("`@<V5R=F5R(CYL
M;V-A;&AO<W0\+V-O;F9I9W-T<FEN9SX*("`@("`@("`\8V]N9FEG:6YT96=E
M<B!N86UE/2)P;W)T(B!D97-C/2)4:&4@<V5R=F5R('!O<G0@=&\@=VAI8V@@
M=V4@=VEL;`H@("`@("`@(&-O;FYE8W0N($E-05`@:7,@9V5N97)A;&QY(#$T
M,RP@=VAI;&4@24U!4"U34TP@:7,@9V5N97)A;&QY"B`@("`@("`@.3DS+B(^
M,30S/"]C;VYF:6=I;G1E9V5R/@H@("`@("`@(#QC;VYF:6=E;G5M(&YA;64]
M(G!R;W1O8V]L(B!D97-C/2)4:&4@8V]N;F5C=&EO;B!P<F]T;V-O;"(^:6UA
M<"]N;W1L<PH@("`@("`@("`\=F%L=65S/@H@("`@("`@("`@/'9A;'5E/FEM
M87`\+W9A;'5E/@H@("`@("`@("`@/'9A;'5E/FEM87`O;F]V86QI9&%T92UC
M97)T/"]V86QU93X*("`@("`@("`@(#QV86QU93YI;6%P+VYO=&QS/"]V86QU
M93X*("`@("`@("`@(#QV86QU93YI;6%P+W1L<SPO=F%L=64^"B`@("`@("`@
M("`\=F%L=64^:6UA<"]T;',O;F]V86QI9&%T92UC97)T/"]V86QU93X*("`@
M("`@("`@(#QV86QU93YI;6%P+W-S;#PO=F%L=64^"B`@("`@("`@("`\=F%L
M=64^:6UA<"]S<VPO;F]V86QI9&%T92UC97)T/"]V86QU93X*("`@("`@("`@
M/"]V86QU97,^"B`@("`@("`@/"]C;VYF:6=E;G5M/@H@("`@("`@/"]C87-E
M/@H@("`@("`\+V-O;F9I9W-W:71C:#X*("`@("`\+V-O;F9I9W-E8W1I;VX^
M"B`@("`\+V-A<V4^"@H@("`@/&-A<V4@;F%M93TB:6US<"(@9&5S8STB24U3
M4"!S97)V97(@875T:&5N=&EC871I;VXB("\^"@H@("`@/&-A<V4@;F%M93TB
M:7!B87-I8R(@9&5S8STB4VEM<&QE($E0(&)A<V5D(&%U=&AE;G1I8V%T:6]N
M(CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`\
M8V]N9FEG;&ES="!N86UE/2)B;&]C:W,B(&1E<V,](D$@;&ES="!O9B!#2412
M(&UA<VMS('=H:6-H(&%R92!A;&QO=V5D"B`@("`@(&%C8V5S<R(O/@H@("`@
M(#PO8V]N9FEG<V5C=&EO;CX*("`@(#PO8V%S93X*"B`@("`\8V%S92!N86UE
M/2)I<&UA<"(@9&5S8STB25`@8F%S960@875T:&5N=&EC871I;VXB/@H@("`@
M(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@(#QC;VYF:6=L
M:7-T(&YA;64](F)L;V-K<R(@9&5S8STB02!L:7-T(&]F($-)1%(@;6%S:W,@
M=VAI8V@@87)E(&%L;&]W960*("`@("`@86-C97-S(B\^"B`@("`@/"]C;VYF
M:6=S96-T:6]N/@H@("`@/"]C87-E/@H*("`@(#QC87-E(&YA;64](FMR8C4B
M(&1E<V,](DME<F)E<F]S(&%U=&AE;G1I8V%T:6]N(B\^"@H@("`@/&-A<V4@
M;F%M93TB:V]L86(B(&1E<V,](DMO;&%B(&%U=&AE;G1I8V%T:6]N(CX*("`@
M("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`\8V]N9FEG
M8F]O;&5A;B!N86UE/2)L;V=I;E]B;&]C:R(@9&5S8STB4VAO=6QD('1H92!L
M;V=I;B!B92!B;&]C:V5D(&%F=&5R(&$@9VEV96X@;G5M8F5R(&]F(&9A:6QE
M9"!L;V=I;G,_(CX*("`@("`@9F%L<V4\+V-O;F9I9V)O;VQE86X^"B`@("`@
M(#QC;VYF:6=I;G1E9V5R(&YA;64](FQO9VEN7V)L;V-K7V-O=6YT(B!D97-C
M/2)!9G1E<B!H;W=M86YY(&9A:6QE9"!L;V=I;G,@=&AE(&QO9VEN('-H;W5L
M9"!B92!B;&]C:V5D/R(^,SPO8V]N9FEG:6YT96=E<CX*("`@("`@/&-O;F9I
M9VEN=&5G97(@;F%M93TB;&]G:6Y?8FQO8VM?=&EM92(@9&5S8STB2&]W;6%N
M>2!M:6YU=&5S('1H92!L;V=I;B!S:&]U;&0@8F4@8FQO8VME9#\B/C4\+V-O
M;F9I9VEN=&5G97(^"B`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@/"]C87-E
M/@H*("`@(#QC87-E(&YA;64](FQD87`B(&1E<V,](DQ$05`@875T:&5N=&EC
M871I;VXB/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@
M("`@(#QC;VYF:6=S=')I;F<@;F%M93TB:&]S='-P96,B(&1E<V,](E1H92!H
M;W-T;F%M92!O9B!T:&4@3$1!4"!S97)V97(B/FQO8V%L:&]S=#PO8V]N9FEG
M<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F)A<V5D;B(@9&5S
M8STB5&AE(&)A<V4@1$X@9F]R('1H92!,1$%0('-E<G9E<B(O/@H@("`@("`\
M8V]N9FEG<W1R:6YG(&YA;64](F)I;F1D;B(@<F5Q=6ER960](F9A;'-E(B!D
M97-C/2)4:&4@1$X@=7-E9"!T;R!B:6YD('1O('1H92!,1$%0('-E<G9E<B(O
M/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G!A<W-W;W)D(B!R97%U:7)E
M9#TB9F%L<V4B(&1E<V,](E1H92!P87-S=V]R9"!U<V5D('1O(&)I;F0@=&\@
M=&AE($Q$05`@<V5R=F5R(B\^"B`@("`@(#QC;VYF:6=E;G5M(&YA;64](G9E
M<G-I;VXB(&1E<V,](DQ$05`@4')O=&]C;VP@5F5R<VEO;B(^,PH@("`@("`@
M/'9A;'5E<SX*("`@("`@("`\=F%L=64@9&5S8STB3$1!4'8R("A$97!R96-A
M=&5D*2(^,CPO=F%L=64^"B`@("`@("`@/'9A;'5E(&1E<V,](DQ$05!V,R(^
M,SPO=F%L=64^"B`@("`@("`\+W9A;'5E<SX*("`@("`@/"]C;VYF:6=E;G5M
M/@H@("`@("`\8V]N9FEG8F]O;&5A;B!N86UE/2)A9"(@9&5S8STB27,@=&AI
M<R!A;B!!1"!S97)V97(_(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*("`@("`@
M/&-O;F9I9W-T<FEN9R!N86UE/2)U:60B(&1E<V,](E1H92!U<V5R;F%M92!S
M96%R8V@@:V5Y("AS970@=&\@<V%M86-C;W5N=&YA;64@9F]R($%$*2(O/@H@
M("`@("`\8V]N9FEG96YU;2!N86UE/2)E;F-R>7!T:6]N(B!D97-C/2)!;&=O
M<FET:&T@=&\@96YC<GEP="!P87-S=V]R9',B/FUD-2UH97@*("`@("`@(#QV
M86QU97,^"B`@("`@("`@/'9A;'5E(&1E<V,](F%P<FUD-2(^87!R;60U/"]V
M86QU93X*("`@("`@("`\=F%L=64@9&5S8STB8W)Y<'0B/F-R>7!T/"]V86QU
M93X*("`@("`@("`\=F%L=64@9&5S8STB8W)Y<'0M9&5S(CYC<GEP="UD97,\
M+W9A;'5E/@H@("`@("`@(#QV86QU92!D97-C/2)C<GEP="UM9#4B/F-R>7!T
M+6UD-3PO=F%L=64^"B`@("`@("`@/'9A;'5E(&1E<V,](F-R>7!T+6)L;W=F
M:7-H(CYC<GEP="UB;&]W9FES:#PO=F%L=64^"B`@("`@("`@/'9A;'5E(&1E
M<V,](FUD-2UB87-E-C0B/FUD-2UB87-E-C0\+W9A;'5E/@H@("`@("`@(#QV
M86QU92!D97-C/2)M9#4M:&5X(CYM9#4M:&5X/"]V86QU93X*("`@("`@("`\
M=F%L=64@9&5S8STB;7-A9"(^;7-A9#PO=F%L=64^"B`@("`@("`@/'9A;'5E
M(&1E<V,](G!L86EN(CYP;&%I;CPO=F%L=64^"B`@("`@("`@/'9A;'5E(&1E
M<V,](G-S:&$B/G-S:&$\+W9A;'5E/@H@("`@("`@(#QV86QU92!D97-C/2)S
M;60U(CYS;60U/"]V86QU93X*("`@("`@(#PO=F%L=65S/@H@("`@("`\+V-O
M;F9I9V5N=6T^"@H@("`@("`\8V]N9FEG;&ES="!N86UE/2)N97=U<V5R7V]B
M:F5C=&-L87-S(B!D97-C/2)7:&%T(&]B:F5C=&-L87-S97,@<VAO=6QD(&$@
M;F5W('5S97(@86-C;W5N="!B92!M96UB97(@;V8_(%1H97-E(&]B:F5C=&-L
M87-S97,@<VAO=6QD(&-O=F5R('1H92!C;BQS;BQU<V5R4&%S<W=O<F0@871T
M<FEB=71E<R!A<R!W96QL(&%S('1H92!U<V5R;F%M92!S96%R8V@@:V5Y(CYS
M:&%D;W=!8V-O=6YT+&EN971/<F=097)S;VX\+V-O;F9I9VQI<W0^"@H@("`@
M("`\8V]N9FEG<W=I=&-H(&YA;64](F9I;'1E<E]T>7!E(B!D97-C/2)(;W<@
M=&\@<W!E8VEF>2!A(&9I;'1E<B!F;W(@=&AE('5S97(@;&ES=',B/F]B:F5C
M=&-L87-S"B`@("`@("`\8V%S92!N86UE/2)O8FIE8W1C;&%S<R(@9&5S8STB
M3VYE(&]R(&UO<F4@;V)J96-T8VQA<W,@9FEL=&5R<R(^"B`@("`@("`@/&-O
M;F9I9VQI<W0@;F%M93TB;V)J96-T8VQA<W,B(&1E<V,](E1H92!O8FIE8W1C
M;&%S<R!F:6QT97(@=7-E9"!T;R!S96%R8V@@9F]R('5S97)S+B!#86X@8F4@
M82!S:6YG;&4@;V)J96-T8VQA<W,@;W(@82!L:7-T+B(O/@H@("`@("`@/"]C
M87-E/@H@("`@("`@/&-A<V4@;F%M93TB9G)E92(@9&5S8STB02!C;VUP;&5T
M92!,1$%0(&9I;'1E<B!E>'!R97-S:6]N(CX*("`@("`@("`\8V]N9FEG<W1R
M:6YG(&YA;64](F9I;'1E<B(@9&5S8STB5&AE($Q$05`@4D9#(&9O<FUA='1E
M9"!F:6QT97(@=7-E9"!T;R!S96%R8V@@9F]R('5S97)S+B(O/@H@("`@("`@
M/"]C87-E/@H@("`@("`\+V-O;F9I9W-W:71C:#X*"B`@("`@(#QC;VYF:6=S
M=VET8V@@;F%M93TB<&%S<W=O<F1?97AP:7)A=&EO;B(@9&5S8STB16YA8FQE
M('1H92!C<F5A=&EN9R!O9B!A8V-O=6YT<R!W:71H(&5X<&ER:6YG('!A<W-W
M;W)D<S\@*$YO=&4Z($YE=R!U<V5R<R!S:&]U;&0@:&%V92!T:&4@<VAA9&]W
M06-C;W5N="!O8FIE8W1C;&%S<RDB/FYO"B`@("`@("`\8V%S92!N86UE/2)N
M;R(@9&5S8STB;F\B("\^"B`@("`@("`\8V%S92!N86UE/2)Y97,B(&1E<V,]
M(GEE<R(^"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)M:6YA9V4B(&1E
M<V,](D%F=&5R(&AO=R!M86YY(&1A>7,@;6%Y(&$@<&%S<W=O<F0@8F4@8VAA
M;F=E9"!A9V%I;C\B/C4\+V-O;F9I9W-T<FEN9SX*("`@("`@("`\8V]N9FEG
M<W1R:6YG(&YA;64](FUA>&%G92(@9&5S8STB2&]W(&UA;GD@9&%Y<R!W:6QL
M(&$@<&%S<W=O<F0@<F5M86EN('9A;&ED/R(^,S`\+V-O;F9I9W-T<FEN9SX*
M("`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G=A<FYA9V4B(&1E<V,](DAO
M=R!M86YY(&1A>7,@8F5F;W)E(&5X<&ER97)Y('-H;W5L9"!A('5S97(@8F4@
M=V%R;F5D/R(^-3PO8V]N9FEG<W1R:6YG/@H@("`@("`@/"]C87-E/@H@("`@
M("`\+V-O;F9I9W-W:71C:#X*("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`\
M+V-A<V4^"@H@("`@/&-A<V4@;F%M93TB;&]G:6XB(&1E<V,](DQO9VEN("AS
M=2D@875T:&5N=&EC871I;VXB/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64]
M(G!A<F%M<R(^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB;&]C871I;VXB
M(&1E<V,](DQO8V%T:6]N(&]F('1H92!S=2!B:6YA<GDB/B]B:6XO<W4\+V-O
M;F9I9W-T<FEN9SX*("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`\+V-A<V4^
M"@H@("`@/&-A<V4@;F%M93TB;6-A;"(@9&5S8STB34-!3"!A=71H96YT:6-A
M=&EO;B(^"B`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@
M("`@/&-O;F9I9W-T<FEN9R!N86UE/2)C86QE;F1A<B(@9&5S8STB5&AE($U#
M04P@8V%L96YD87(@;F%M92(O/@H@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@
M(#PO8V%S93X*"B`@("`\8V%S92!N86UE/2)P86TB(&1E<V,](E!!32`H4&QU
M9V=A8FQE($%U=&AE;G1I8V%T:6]N($UO9'5L97,I(&%U=&AE;G1I8V%T:6]N
M(CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`\
M8V]N9FEG<W1R:6YG(&YA;64](G-E<G9I8V4B(&1E<V,](E1H92!N86UE(&]F
M('1H92!004T@<V5R=FEC92!T;R!U<V4@=VAE;B!A=71H96YT:6-A=&EN9R(^
M<&AP/"]C;VYF:6=S=')I;F<^"B`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@
M/"]C87-E/@H*("`@(#QC87-E(&YA;64](G!A<W-W9"(@9&5S8STB<&%S<W=D
M(&9I;&4@875T:&5N=&EC871I;VXB/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA
M;64](G!A<F%M<R(^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB9FEL96YA
M;64B(&1E<V,](E1H92!P87-S=V0@9FEL92!T;R!U<V4B/B]E=&,O<&%S<W=D
M/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=B;V]L96%N(&YA;64](FQO
M8VLB(&1E<V,](E-H;W5L9"!W92!L;V-K('1H92!P87-S=V0@9FEL93\B/F9A
M;'-E/"]C;VYF:6=B;V]L96%N/@H@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@
M(#PO8V%S93X*"B`@("`\8V%S92!N86UE/2)R861I=7,B(&1E<V,](E)A9&EU
M<R!A=71H96YT:6-A=&EO;B(^"B`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB
M<&%R86US(CX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)H;W-T(B!D97-C
M/2)4:&4@4D%$2553(&AO<W0@=&\@=7-E("A)4"!A9&1R97-S(&]R(&9U;&QY
M('%U86QI9FEE9"!H;W-T;F%M92DB/FQO8V%L:&]S=#PO8V]N9FEG<W1R:6YG
M/@H@("`@("`\8V]N9FEG:6YT96=E<B!N86UE/2)P;W)T(B!R97%U:7)E9#TB
M9F%L<V4B(&1E<V,](E1H92!P;W)T('1O('5S92!O;B!T:&4@4D%$2553('-E
M<G9E<B(O/@H@("`@("`\8V]N9FEG96YU;2!N86UE/2)M971H;V0B(&1E<V,]
M(E1H92!2041)55,@;65T:&]D('1O('5S92!F;W(@=F%L:61A=&EN9R!T:&4@
M<F5Q=65S="(^4$%0"B`@("`@("`\=F%L=65S/@H@("`@("`@(#QV86QU92!D
M97-C/2)005`B/E!!4#PO=F%L=64^"B`@("`@("`@/'9A;'5E(&1E<V,](D-(
M05!?340U("AN;W0@<W5P<&]R=&5D(&%T('1H92!M;VUE;G0I(CY#2$%07TU$
M-3PO=F%L=64^"B`@("`@("`@/'9A;'5E(&1E<V,](DU30TA!4'8Q("AN;W0@
M<W5P<&]R=&5D(&%T('1H92!M;VUE;G0I(CY-4T-(05!V,3PO=F%L=64^"B`@
M("`@("`@/'9A;'5E(&1E<V,](DU30TA!4'8R("AN;W0@<W5P<&]R=&5D(&%T
M('1H92!M;VUE;G0I(CY-4T-(05!V,CPO=F%L=64^"B`@("`@("`\+W9A;'5E
M<SX*("`@("`@/"]C;VYF:6=E;G5M/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA
M;64](FYA<R(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@4D%$2553($Y!
M4R!I9&5N=&EF:65R('1O('5S92XB("\^"B`@("`@(#QC;VYF:6=S=')I;F<@
M;F%M93TB<V5C<F5T(B!D97-C/2)4:&4@4D%$2553('-H87)E9"!S96-R970@
M<W1R:6YG(&9O<B!T:&4*("`@("`@:&]S="X@5&AE(%)!1$E54R!P<F]T;V-O
M;"!I9VYO<F5S(&%L;"!B=70@=&AE(&QE861I;F<@,3(X(&)Y=&5S(&]F('1H
M90H@("`@("!S:&%R960@<V5C<F5T+B(O/@H@("`@("`\8V]N9FEG:6YT96=E
M<B!N86UE/2)R971R:65S(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E1H92!M
M87AI;75M(&YU;6)E<@H@("`@("!O9B!R97!E871E9"!R97%U97-T<R!T;R!M
M86ME(&)E9F]R92!G:79I;F<@=7`@6S-=(B\^"B`@("`@(#QC;VYF:6=S=')I
M;F<@;F%M93TB<W5F9FEX(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E1H92!D
M;VUA:6X@;F%M92!T;R!A9&0*("`@("`@=&\@=6YQ=6%L:69I960@=7-E<B!N
M86UE<R(O/@H@("`@("`\8V]N9FEG:6YT96=E<B!N86UE/2)T:6UE;W5T(B!R
M97%U:7)E9#TB9F%L<V4B(&1E<V,](E1H92!T:6UE;W5T(&9O<@H@("`@("!R
M96-E:79I;F<@<F5P;&EE<R!F<F]M('1H92!S97)V97(@*&EN('-E8V]N9',I
M(%LS72(O/@H@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@(#PO8V%S93X*"B`@
M("`\8V%S92!N86UE/2)S87-L(B!D97-C/2)305-,(&%U=&AE;G1I8V%T:6]N
M(CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`\
M8V]N9FEG<W1R:6YG(&YA;64](F%P<"(@9&5S8STB5&AE(&YA;64@;V8@=&AE
M(&%U=&AE;G1I8V%T:6YG"B`@("`@(&%P<&QI8V%T:6]N(CYH;W)D93PO8V]N
M9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G-E<G9I8V4B
M(&1E<V,](E1H92!N86UE(&]F('1H92!305-,('-E<G9I8V4@=&\@=7-E"B`@
M("`@('=H96X@875T:&5N=&EC871I;F<B/G!H<#PO8V]N9FEG<W1R:6YG/@H@
M("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@(#PO8V%S93X*"B`@("`\8V%S92!N
M86UE/2)S;6(B(&1E<V,](E--0B!A=71H96YT:6-A=&EO;B(^"B`@("`@/&-O
M;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I9W-T<FEN
M9R!N86UE/2)H;W-T<W!E8R(@9&5S8STB25`L($1.4R!.86UE+"!O<B!.971"
M:6]S($YA;64@;V8@=&AE"B`@("`@(%--0B!S97)V97(@=&\@875T:&5N=&EC
M871E('=I=&@B/FQO8V%L:&]S=#PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N
M9FEG<W1R:6YG(&YA;64](F1O;6%I;B(@9&5S8STB5&AE(&1O;6%I;B!N86UE
M('1O(&%U=&AE;G1I8V%T92!W:71H(B\^"B`@("`@(#QC;VYF:6=S=')I;F<@
M;F%M93TB9W)O=7`B(')E<75I<F5D/2)F86QS92(@9&5S8STB3W!T:6]N86P@
M9W)O=7`@;F%M90H@("`@("!T:&%T('1H92!U<V5R(&UU<W0@8F4@82!M96UB
M97(@;V8B+SX*("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`\+V-A<V4^"@H@
M("`@/&-A<V4@;F%M93TB<W%L(B!D97-C/2)344P@875T:&5N=&EC871I;VXB
M/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@(#QC
M;VYF:6=S<6P@<W=I=&-H;F%M93TB9')I=F5R8V]N9FEG(B`O/@H@("`@("`\
M8V]N9FEG<W1R:6YG(&YA;64](G1A8FQE(B!R97%U:7)E9#TB9F%L<V4B(&1E
M<V,](E1H92!N86UE(&]F('1H92!A=71H"B`@("`@('1A8FQE(&EN('1H92!D
M871A8F%S92!;:&]R9&5?=7-E<G-=(B\^"B`@("`@(#QC;VYF:6=S=')I;F<@
M;F%M93TB=7-E<FYA;65?9FEE;&0B(')E<75I<F5D/2)F86QS92(@9&5S8STB
M5&AE(&YA;64@;V8@=&AE"B`@("`@('5S97)N86UE(&9I96QD(&EN('1H92!A
M=71H('1A8FQE(%MU<V5R7W5I9%TB+SX*("`@("`@/&-O;F9I9W-T<FEN9R!N
M86UE/2)P87-S=V]R9%]F:65L9"(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4
M:&4@;F%M92!O9B!T:&4*("`@("`@<&%S<W=O<F0@9FEE;&0@:6X@=&AE(&%U
M=&@@=&%B;&4@6W5S97)?<&%S<UTB+SX*("`@("`@/&-O;F9I9W-T<FEN9R!N
M86UE/2)S;V9T7V5X<&ER871I;VY?9FEE;&0B(')E<75I<F5D/2)F86QS92(@
M9&5S8STB5&AE"B`@("`@(&YA;64@;V8@82!F:65L9"!C;VYT86EN:6YG(&$@
M54Y)6"!T:6UE<W1A;7`N("!7:&5N(&$@=7-E<B!L;V=S(&EN(&%F=&5R"B`@
M("`@('1H92!S<&5C:69I960@=&EM92P@:68@)W!A<W-W9"<@:7,@:6YS=&%L
M;&5D+"!T:&%T('5S97(@=VEL;"!B92!A<VME9"!T;PH@("`@("!C:&%N9V4@
M:&ES(&]R(&AE<B!P87-S=V]R9"X@(%1H:7,@9F5A='5R92!I<R!D:7-A8FQE
M9"!B>2!D969A=6QT+B(O/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](FAA
M<F1?97AP:7)A=&EO;E]F:65L9"(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4
M:&4*("`@("`@;F%M92!O9B!A(&9I96QD(&-O;G1A:6YI;F<@82!53DE8('1I
M;65S=&%M<"X@($$@=7-E<B!W:6QL(&YO="!B92!A8FQE('1O"B`@("`@(&QO
M9R!I;B!A9G1E<B!T:&4@<W!E8VEF:65D('1I;64N("!4:&ES(&9E871U<F4@
M:7,@9&ES86)L960@8GD@9&5F875L="XB+SX*("`@("`@/&-O;F9I9VEN=&5G
M97(@;F%M93TB<V]F=%]E>'!I<F%T:6]N7W=I;F1O=R(@<F5Q=6ER960](F9A
M;'-E(@H@("`@("!D97-C/2)4:&ES(&ES(&AO=R!O9G1E;BP@:6X@9&%Y<RP@
M=&AE('5S97(@;75S="!C:&%N9V4@:&ES(&]R(&AE<@H@("`@("!P87-S=V]R
M9"X@(%=H96X@=&AE('5S97(G<R!P87-S=V]R9"!I<R!U<&1A=&5D+"!T:&4@
M)G%U;W0[<V]F="9Q=6]T.PH@("`@("!E>'!I<F%T:6]N(&ES('-E="!T:&ES
M(&UA;GD@9&%Y<R!I;B!T:&4@9G5T=7)E+B`@268@;F]T('!R;W9I9&5D+`H@
M("`@("!T:&4@=7-E<B=S('!A<W-W;W)D('=I;&P@;F]T(&5X<&ER92!B>2!D
M969A=6QT+B(O/@H@("`@("`\8V]N9FEG:6YT96=E<B!N86UE/2)H87)D7V5X
M<&ER871I;VY?=VEN9&]W(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E1H90H@
M("`@("!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@9W)A8V4@<&5R:6]D('1H92!U
M<V5R(&AA<R!T;R!C:&%N9V4@:&ES(&]R(&AE<@H@("`@("!P87-S=V]R9"!A
M9G1E<B!I="!H87,@97AP:7)E9"X@($EF(&YO="!P<F]V:61E9"P@=&AE(&=R
M86-E('!E<FEO9"!W:6QL"B`@("`@(&YO="!E>'!I<F4N(B\^"B`@("`@(#QC
M;VYF:6=E;G5M(&YA;64](F5N8W)Y<'1I;VXB(')E<75I<F5D/2)F86QS92(@
M9&5S8STB5&AE(&5N8W)Y<'1I;VX@=&\@=7-E"B`@("`@('1O('-T;W)E('1H
M92!P87-S=V]R9"!I;B!T:&4@=&%B;&4B/FUD-2UH97@*("`@("`@(#QV86QU
M97,^"B`@("`@("`@/'9A;'5E/F-R>7!T/"]V86QU93X*("`@("`@("`\=F%L
M=64^8W)Y<'0M8FQO=V9I<V@\+W9A;'5E/@H@("`@("`@(#QV86QU93YC<GEP
M="UD97,\+W9A;'5E/@H@("`@("`@(#QV86QU93YC<GEP="UM9#4\+W9A;'5E
M/@H@("`@("`@(#QV86QU93YM9#4M8F%S938T/"]V86QU93X*("`@("`@("`\
M=F%L=64^;60U+6AE>#PO=F%L=64^"B`@("`@("`@/'9A;'5E/G!L86EN/"]V
M86QU93X*("`@("`@("`\=F%L=64^<VAA/"]V86QU93X*("`@("`@("`\=F%L
M=64^<VUD-3PO=F%L=64^"B`@("`@("`@/'9A;'5E/G-S:&$\+W9A;'5E/@H@
M("`@("`@/"]V86QU97,^"B`@("`@(#PO8V]N9FEG96YU;3X*("`@("`@/&-O
M;F9I9V)O;VQE86X@;F%M93TB<VAO=U]E;F-R>7!T:6]N(B!R97%U:7)E9#TB
M9F%L<V4B(&1E<V,](E!R97!E;F0@=&AE"B`@("`@(&5N8W)Y<'1I;VX@:6X@
M=&AE('!A<W-W;W)D(&9I96QD/R(^9F%L<V4\+V-O;F9I9V)O;VQE86X^"B`@
M("`@/"]C;VYF:6=S96-T:6]N/@H@("`@/"]C87-E/@H*("`@(#QC87-E(&YA
M;64](F-U<W1O;7-Q;"(@9&5S8STB4U%,(&%U=&AE;G1I8V%T:6]N('<O8W5S
M=&]M+6UA9&4@<75E<FEE<R(^"B`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB
M<&%R86US(CX*("`@("`@/&-O;F9I9V5N=6T@;F%M93TB<&AP='EP92(@9&5S
M8STB5&AE(&YA;64@;V8@=&AE(&1A=&%B87-E(CYM>7-Q;`H@("`@("`@/'9A
M;'5E<SX*("`@("`@("`\=F%L=64@9&5S8STB36EC<F]S;V9T(%-13"!397)V
M97(B/FUS<W%L/"]V86QU93X*("`@("`@("`\=F%L=64@9&5S8STB37E344PB
M/FUY<W%L/"]V86QU93X*("`@("`@("`\=F%L=64@9&5S8STB3T1"0R(^;V1B
M8SPO=F%L=64^"B`@("`@("`@/'9A;'5E(&1E<V,](D]R86-L92`X(CYO8VDX
M/"]V86QU93X*("`@("`@("`\=F%L=64@9&5S8STB4&]S=&=R95-13"(^<&=S
M<6P\+W9A;'5E/@H@("`@("`@/"]V86QU97,^"B`@("`@(#PO8V]N9FEG96YU
M;3X*("`@("`@/&-O;F9I9W-W:71C:"!N86UE/2)P<F]T;V-O;"(@9&5S8STB
M5VAA="!P<F]T;V-O;"!W:6QL('=E('5S92!T;R!C;VYN96-T('1O('1H92!D
M871A8F%S93\B/G5N:7@*("`@("`@(#QC87-E(&YA;64](G5N:7@B(&1E<V,]
M(E5.25@@4V]C:V5T<R(^"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)S
M;V-K970B(')E<75I<F5D/2)F86QS92(@9&5S8STB3&]C871I;VX@;V8@54Y)
M6"!S;V-K970B/CPO8V]N9FEG<W1R:6YG/@H@("`@("`@/"]C87-E/@H@("`@
M("`@/&-A<V4@;F%M93TB=&-P(B!D97-C/2)40U`O25`B/@H@("`@("`@(#QC
M;VYF:6=I;G1E9V5R(&YA;64](G!O<G0B(')E<75I<F5D/2)F86QS92(@9&5S
M8STB4&]R="!T:&4@1$(@:7,@<G5N;FEN9R!O;BP@:68@;F]N+7-T86YD87)D
M(CXU-#,R/"]C;VYF:6=I;G1E9V5R/@H@("`@("`@/"]C87-E/@H@("`@("`\
M+V-O;F9I9W-W:71C:#X*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)H;W-T
M<W!E8R(@9&5S8STB5VAA="!H;W-T;F%M92!I<R!T:&4@9&%T86)A<V4@<V5R
M=F5R(')U;FYI;F<@;VXL(&]R('=H870@:7,@=&AE(&YA;64@;V8@=&AE('-Y
M<W1E;2!$4TX@=&\@=7-E/R(^;&]C86QH;W-T/"]C;VYF:6=S=')I;F<^"B`@
M("`@(#QC;VYF:6=S=')I;F<@;F%M93TB=7-E<FYA;64B(&1E<V,](E=H870@
M=7-E<FYA;64@9&\@=V4@875T:&5N=&EC871E('1O('1H92!D871A8F%S92!S
M97)V97(@87,_(CYH;W)D93PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG
M<W1R:6YG(&YA;64](G!A<W-W;W)D(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,]
M(E=H870@<&%S<W=O<F0@9&\@=V4@875T:&5N=&EC871E('1O('1H92!D871A
M8F%S92!S97)V97(@=VET:#\B+SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE
M/2)D871A8F%S92(@9&5S8STB5VAA="!D871A8F%S92!N86UE+W1A8FQE<W!A
M8V4@87)E('=E('5S:6YG/R(^:&]R9&4\+V-O;F9I9W-T<FEN9SX*("`@("`@
M/&-O;F9I9V1E<V-R:7!T:6]N/@H@("`@("`@4V]M92!S<&5C:6%L('1O:V5N
M<R!C86X@8F4@=7-E9"!I;B!T:&4@<W%L('%U97)Y+B!4:&5Y(&%R92!R97!L
M86-E9"!A=`H@("`@("`@=&AE('%U97)Y('-T86=E.B9L=#MU;"9G=#L*("`@
M("`@("9L=#ML:29G=#LB7$PB('=I;&P@8F4@<F5P;&%C960@8GD@=&AE('5S
M97(G<R!L;V=I;B9L=#LO;&DF9W0["B`@("`@("`F;'0[;&DF9W0[(EQ0(B!W
M:6QL(&)E(')E<&QA8V5D(&)Y('1H92!U<V5R)W,@<&%S<W=O<F0F;'0[+VQI
M)F=T.PH@("`@("`@)FQT.VQI)F=T.R)<3R(@=VEL;"!B92!R97!L86-E9"!B
M>2!T:&4@;VQD('5S97(G<R!L;V=I;B`H<F5Q=6ER960@9F]R"B`@("`@("!U
M<&1A=&4I)FQT.R]L:29G=#LF;'0[+W5L)F=T.PH@("`@("`@16<Z(")314Q%
M0U0@*B!&4D]-('5S97)S(%=(15)%('5I9"`](%Q,($%.1"!P87-S=V0@/2!<
M4"!!3D0@8FEL;&EN9R`]"B`@("`@("`G<&%I9"<B"B`@("`@(#PO8V]N9FEG
M9&5S8W)I<'1I;VX^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<75E<GE?
M875T:"(@9&5S8STB075T:&5N=&EC871E('1H92!U<V5R(B\^"B`@("`@(#QC
M;VYF:6=S=')I;F<@;F%M93TB<75E<GE?861D(B!D97-C/2)!9&0@=7-E<B(O
M/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G%U97)Y7W5P9&%T92(@9&5S
M8STB57!D871E('5S97(B+SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)Q
M=65R>5]R96UO=F4B(&1E<V,](E)E;6]V92!U<V5R(B\^"B`@("`@(#QC;VYF
M:6=S=')I;F<@;F%M93TB<75E<GE?;&ES="(@9&5S8STB3&ES="!U<V5R<R(O
M/@H@("`@("`\8V]N9FEG96YU;2!N86UE/2)E;F-R>7!T:6]N(B!D97-C/2)4
M:&4@96YC<GEP=&EO;B!T;R!U<V4@=&\@<W1O<F4@=&AE"B`@("`@('!A<W-W
M;W)D(&EN('1H92!T86)L92(^;60U+6AE>`H@("`@("`@/'9A;'5E<SX*("`@
M("`@("`\=F%L=64^87!R;60U/"]V86QU93X*("`@("`@("`\=F%L=64^8W)Y
M<'0\+W9A;'5E/@H@("`@("`@(#QV86QU93YC<GEP="UB;&]W9FES:#PO=F%L
M=64^"B`@("`@("`@/'9A;'5E/F-R>7!T+61E<SPO=F%L=64^"B`@("`@("`@
M/'9A;'5E/F-R>7!T+6UD-3PO=F%L=64^"B`@("`@("`@/'9A;'5E/FUD-2UB
M87-E-C0\+W9A;'5E/@H@("`@("`@(#QV86QU93YM9#4M:&5X/"]V86QU93X*
M("`@("`@("`\=F%L=64^<&QA:6X\+W9A;'5E/@H@("`@("`@(#QV86QU93YS
M:&$\+W9A;'5E/@H@("`@("`@(#QV86QU93YS;60U/"]V86QU93X*("`@("`@
M("`\=F%L=64^<W-H83PO=F%L=64^"B`@("`@("`\+W9A;'5E<SX*("`@("`@
M/"]C;VYF:6=E;G5M/@H@("`@("`\8V]N9FEG8F]O;&5A;B!N86UE/2)S:&]W
M7V5N8W)Y<'1I;VXB(&1E<V,](E!R97!E;F0@=&AE(&5N8W)Y<'1I;VX@:6X@
M=&AE"B`@("`@('!A<W-W;W)D(&9I96QD/R(^9F%L<V4\+V-O;F9I9V)O;VQE
M86X^"B`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@/"]C87-E/@H*("`@(#QC
M87-E(&YA;64](F-Y<G-Q;"(@9&5S8STB4U%,(&EM<&QE;65N=&%T:6]N(&9O
M<B!T:&4@0WER=7,@24U!4"!S97)V97(B/@H@("`@(#QC;VYF:6=S96-T:6]N
M(&YA;64](G!A<F%M<R(^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB8WER
M861M:6XB(&1E<V,](E1H92!U<V5R;F%M92!O9B!T:&4@8WER=7,*("`@("`@
M861M:6YI<W1R871O<B(O/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F-Y
M<G!A<W,B(&1E<V,](E1H92!P87-S=V]R9"!F;W(@=&AE(&-Y<G5S"B`@("`@
M(&%D;6EN:7-T<F%T;W(B+SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)I
M;6%P7V1S;B(@9&5S8STB5&AE(&9U;&P@24U!4"!$4TX*("`@("`@*&DN92X@
M>VQO8V%L:&]S=#HY.3,O:6UA<"]S<VPO;F]V86QI9&%T92UC97)T?2DB+SX*
M("`@("`@/&-O;F9I9V5N=6T@;F%M93TB<&AP='EP92(@9&5S8STB5&AE(&YA
M;64@;V8@=&AE(&1A=&%B87-E(CYM>7-Q;`H@("`@("`@/'9A;'5E<SX*("`@
M("`@("`\=F%L=64@9&5S8STB36EC<F]S;V9T(%-13"!397)V97(B/FUS<W%L
M/"]V86QU93X*("`@("`@("`\=F%L=64@9&5S8STB37E344PB/FUY<W%L/"]V
M86QU93X*("`@("`@("`\=F%L=64@9&5S8STB37E344P@*&UY<W%L:2DB/FUY
M<W%L:3PO=F%L=64^"B`@("`@("`@/'9A;'5E(&1E<V,](D]$0D,B/F]D8F,\
M+W9A;'5E/@H@("`@("`@(#QV86QU92!D97-C/2)/<F%C;&4@."(^;V-I.#PO
M=F%L=64^"B`@("`@("`@/'9A;'5E(&1E<V,](E!O<W1G<F5344PB/G!G<W%L
M/"]V86QU93X*("`@("`@(#PO=F%L=65S/@H@("`@("`\+V-O;F9I9V5N=6T^
M"B`@("`@(#QC;VYF:6=S=VET8V@@;F%M93TB<')O=&]C;VPB(&1E<V,](E=H
M870@<')O=&]C;VP@=VEL;"!W92!U<V4@=&\@8V]N;F5C="!T;R!T:&4@9&%T
M86)A<V4_(CYU;FEX"B`@("`@("`\8V%S92!N86UE/2)U;FEX(B!D97-C/2)5
M3DE8(%-O8VME=',B/@H@("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<V]C
M:V5T(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](DQO8V%T:6]N(&]F(%5.25@@
M<V]C:V5T(CX\+V-O;F9I9W-T<FEN9SX*("`@("`@(#PO8V%S93X*("`@("`@
M(#QC87-E(&YA;64](G1C<"(@9&5S8STB5$-0+TE0(CX*("`@("`@("`\8V]N
M9FEG:6YT96=E<B!N86UE/2)P;W)T(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,]
M(E!O<G0@=&AE($1"(&ES(')U;FYI;F<@;VXL(&EF(&YO;BUS=&%N9&%R9"(^
M-30S,CPO8V]N9FEG:6YT96=E<CX*("`@("`@(#PO8V%S93X*("`@("`@/"]C
M;VYF:6=S=VET8V@^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB:&]S='-P
M96,B(&1E<V,](E=H870@:&]S=&YA;64@:7,@=&AE(&1A=&%B87-E('-E<G9E
M<B!R=6YN:6YG(&]N+"!O<B!W:&%T(&ES('1H92!N86UE(&]F('1H92!S>7-T
M96T@1%-.('1O('5S93\B/FQO8V%L:&]S=#PO8V]N9FEG<W1R:6YG/@H@("`@
M("`\8V]N9FEG<W1R:6YG(&YA;64](G5S97)N86UE(B!D97-C/2)7:&%T('5S
M97)N86UE(&1O('=E(&%U=&AE;G1I8V%T92!T;R!T:&4@9&%T86)A<V4@<V5R
M=F5R(&%S/R(^:&]R9&4\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T
M<FEN9R!N86UE/2)P87-S=V]R9"(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)7
M:&%T('!A<W-W;W)D(&1O('=E(&%U=&AE;G1I8V%T92!T;R!T:&4@9&%T86)A
M<V4@<V5R=F5R('=I=&@_(B\^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB
M9&%T86)A<V4B(&1E<V,](E=H870@9&%T86)A<V4@;F%M92]T86)L97-P86-E
M(&%R92!W90H@("`@("!U<VEN9S\B/FAO<F1E/"]C;VYF:6=S=')I;F<^"B`@
M("`@(#QC;VYF:6=S=')I;F<@;F%M93TB=&%B;&4B(&1E<V,](E1H92!N86UE
M(&]F('1H92!A=71H('1A8FQE(&EN('1H90H@("`@("!D871A8F%S92(^:&]R
M9&5?=7-E<G,\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N
M86UE/2)U<V5R;F%M95]F:65L9"(@9&5S8STB5&AE(&YA;64@;V8@=&AE('5S
M97)N86UE(&9I96QD"B`@("`@(&EN('1H92!A=71H('1A8FQE(CYU<V5R7W5I
M9#PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G!A
M<W-W;W)D7V9I96QD(B!D97-C/2)4:&4@;F%M92!O9B!T:&4@<&%S<W=O<F0@
M9FEE;&0*("`@("`@:6X@=&AE(&%U=&@@=&%B;&4B/G5S97)?<&%S<SPO8V]N
M9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F1O;6%I;E]F
M:65L9"(@9&5S8STB268@<V5T('1O(&%N>71H:6YG(&]T:&5R('1H86X*("`@
M("`@)VYO;F4G('1H:7,@:7,@=7-E9"!A<R!F:65L9"!N86UE('=H97)E(&1O
M;6%I;B!I<PH@("`@("!S=&]R960B/FYO;F4\+V-O;F9I9W-T<FEN9SX*("`@
M("`@/&-O;F9I9V5N=6T@;F%M93TB96YC<GEP=&EO;B(@9&5S8STB5&AE(&5N
M8W)Y<'1I;VX@=&\@=7-E('1O('-T;W)E('1H90H@("`@("!P87-S=V]R9"!I
M;B!T:&4@=&%B;&4B/FUD-2UH97@*("`@("`@(#QV86QU97,^"B`@("`@("`@
M/'9A;'5E/F%P<FUD-3PO=F%L=64^"B`@("`@("`@/'9A;'5E/F-R>7!T/"]V
M86QU93X*("`@("`@("`\=F%L=64^8W)Y<'0M8FQO=V9I<V@\+W9A;'5E/@H@
M("`@("`@(#QV86QU93YC<GEP="UD97,\+W9A;'5E/@H@("`@("`@(#QV86QU
M93YC<GEP="UM9#4\+W9A;'5E/@H@("`@("`@(#QV86QU93YM9#4M8F%S938T
M/"]V86QU93X*("`@("`@("`\=F%L=64^;60U+6AE>#PO=F%L=64^"B`@("`@
M("`@/'9A;'5E/G!L86EN/"]V86QU93X*("`@("`@("`\=F%L=64^<VAA/"]V
M86QU93X*("`@("`@("`\=F%L=64^<VUD-3PO=F%L=64^"B`@("`@("`@/'9A
M;'5E/G-S:&$\+W9A;'5E/@H@("`@("`@/"]V86QU97,^"B`@("`@(#PO8V]N
M9FEG96YU;3X*("`@("`@/&-O;F9I9VQI<W0@;F%M93TB9F]L9&5R<R(@<F5Q
M=6ER960](F9A;'-E(B!D97-C/2)!(&QI<W0@;V8@9F]L9&5R<R!T;R!C<F5A
M=&4@=6YD97(*("`@("`@=7-E<FYA;64B+SX*("`@("`@/&-O;F9I9VEN=&5G
M97(@;F%M93TB<75O=&$B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE('%U
M;W1A("AI;@H@("`@("!K:6QO8GET97,I('1O(&=R86YT(&]N('1H92!M86EL
M8F]X(B\^"B`@("`@(#QC;VYF:6=B;V]L96%N(&YA;64](G5N:7AH:65R(B!D
M97-C/2)4:&4@=F%L=64@;V8@:6UA<&0N8V]N9B=S"B`@("`@('5N:7AH:65R
M87)C:'ES97`@<V5T=&EN9RX@0VAE8VL@=&AI<R!I9B!T:&4@=F%L=64@:7,@
M=')U92!I;@H@("`@("!I;6%P9"YC;VYF+B(^9F%L<V4\+V-O;F9I9V)O;VQE
M86X^"B`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@/"]C87-E/@H*("`@(#QC
M87-E(&YA;64](GEA:&]O(B!D97-C/2)986AO;R$@875T:&5N=&EC871I;VXB
M+SX*("`@/"]C;VYF:6=S=VET8V@^"B`@/"]C;VYF:6=S96-T:6]N/@H@/"]C
M;VYF:6=T86(^"@H@/&-O;F9I9W1A8B!N86UE/2)S:6=N=7`B(&1E<V,](E-I
M9VX@57`B/@H@(#QC;VYF:6=S96-T:6]N(&YA;64](G-I9VYU<"(^"B`@(#QC
M;VYF:6=H96%D97(^2&]R9&4@4VEG;B!5<#PO8V]N9FEG:&5A9&5R/@H@("`\
M8V]N9FEG<W=I=&-H(&YA;64](F%L;&]W(B!D97-C/2)!;&QO=R!N;VXM<F5G
M:7-T97)E9"!U<V5R<R!T;R!R96=I<W1E<B!A;F0*("`@<')O=FED92!A(&QI
M;FL@;VX@=&AE(&QO9VEN('-C<F5E;C\B/F9A;'-E"B`@("`\8V%S92!N86UE
M/2)T<G5E(B!D97-C/2)997,B/@H@("`@(#QC;VYF:6=B;V]L96%N(&YA;64]
M(F%P<')O=F4B(&1E<V,](D%D;6EN(&AA<R!T;R!A<'!R;W9E(&%N>2!U<V5R
M('-U8FUI='1E9`H@("`@(')E9VES=')A=&EO;B!R97%U97-T<S\@*%=!4DY)
M3D<Z(%-E='1I;F<@=&\@9F%L<V4@=V]U;&0@;65A;B!T:&%T(&5V97)Y('5S
M97(*("`@("!W:&\@<VEG;G,@=7`@=V]U;&0@:&%V92!A=71O;6%T:6,@86-C
M97-S('1O('EO=7(@:&]R9&4@<WES=&5M+BDB/G1R=64\+V-O;F9I9V)O;VQE
M86X^"B`@("`@/&-O;F9I9V)O;VQE86X@;F%M93TB<')E<')O8V5S<R(@9&5S
M8STB4&%S<R!T:&4@=7-E<B!S=6)M:71T960@:6YF;W)M871I;VX*("`@("!T
M:')O=6=H('1H92!?:&]R9&5?:&]O:U]S:6=N=7!?<')E<')O8V5S<R!F=6YC
M=&EO;B!I;B!H;V]K<RYP:'`@8F5F;W)E"B`@("`@<')O8V5S<VEN9R!T:&4@
M<F5Q=65S=#\B/F9A;'-E/"]C;VYF:6=B;V]L96%N/@H@("`@(#QC;VYF:6=B
M;V]L96%N(&YA;64](G%U975E(B!D97-C/2)087-S('1H92!U<V5R('-U8FUI
M='1E9"!I;F9O<FUA=&EO;@H@("`@('1H<F]U9V@@=&AE(%]H;W)D95]H;V]K
M7W-I9VYU<%]Q=65U92!F=6YC=&EO;B!I;B!H;V]K<RYP:'`@869T97(@<')O
M8V5S<VEN9PH@("`@('1H92!R97%U97-T(&)U="!B969O<F4@86-T=6%L;'D@
M<75E=65I;F<@:70_(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*("`@(#PO8V%S
M93X*("`@(#QC87-E(&YA;64](F9A;'-E(B!D97-C/2).;R(@+SX*("`@/"]C
M;VYF:6=S=VET8V@^"B`@/"]C;VYF:6=S96-T:6]N/@H@/"]C;VYF:6=T86(^
M"@H@/&-O;F9I9W1A8B!N86UE/2)L;V<B(&1E<V,](DQO9V=I;F<B/@H@(#QC
M;VYF:6=S96-T:6]N(&YA;64](FQO9R(^"B`@(#QC;VYF:6=H96%D97(^2&]R
M9&4@3&]G9VEN9SPO8V]N9FEG:&5A9&5R/@H@("`\8V]N9FEG<W=I=&-H(&YA
M;64](F5N86)L960B('%U;W1E/2)F86QS92(@9&5S8STB4VAO=6QD($AO<F1E
M(&QO9R!E<G)O<G,@86YD(&]T:&5R('5S969U;`H@("!I;F9O<FUA=&EO;C\B
M/G1R=64*("`@(#QC87-E(&YA;64](G1R=64B(&1E<V,](EEE<R(^"B`@("`@
M/&-O;F9I9V5N=6T@;F%M93TB<')I;W)I='DB('%U;W1E/2)F86QS92(@9&5S
M8STB5VAA="!L979E;"!O9B!M97-S86=E<PH@("`@('-H;W5L9"!W92!L;V<_
M($5A8V@@;&5V96P@;&]G<R!I='-E;&8@86YD(&%L;"!T:&]S92!T:&%T(&-O
M;64@8F5F;W)E(&ET.@H@("`@(%!%05)?3$]'7T%,15)4('=O=6QD(&]N;'D@
M;&]G(&%L97)T<R!A;F0@96UE<F=E;F-I97,L(&)U="!014%27TQ/1U]$14)5
M1PH@("`@('=O=6QD(&QO9R!E=F5R>71H:6YG+B(^4$5!4E],3T=?3D]424-%
M"B`@("`@(#QV86QU97,^"B`@("`@("`\=F%L=64@9&5S8STB4$5!4E],3T=?
M14U%4D<B/E!%05)?3$]'7T5-15)'/"]V86QU93X*("`@("`@(#QV86QU92!D
M97-C/2)014%27TQ/1U]!3$525"(^4$5!4E],3T=?04Q%4E0\+W9A;'5E/@H@
M("`@("`@/'9A;'5E(&1E<V,](E!%05)?3$]'7T-2250B/E!%05)?3$]'7T-2
M250\+W9A;'5E/@H@("`@("`@/'9A;'5E(&1E<V,](E!%05)?3$]'7T524B(^
M4$5!4E],3T=?15)2/"]V86QU93X*("`@("`@(#QV86QU92!D97-C/2)014%2
M7TQ/1U]705).24Y'(CY014%27TQ/1U]705).24Y'/"]V86QU93X*("`@("`@
M(#QV86QU92!D97-C/2)014%27TQ/1U].3U1)0T4B/E!%05)?3$]'7TY/5$E#
M13PO=F%L=64^"B`@("`@("`\=F%L=64@9&5S8STB4$5!4E],3T=?24Y&3R(^
M4$5!4E],3T=?24Y&3SPO=F%L=64^"B`@("`@("`\=F%L=64@9&5S8STB4$5!
M4E],3T=?1$5"54<B/E!%05)?3$]'7T1%0E5'/"]V86QU93X*("`@("`@/"]V
M86QU97,^"B`@("`@/"]C;VYF:6=E;G5M/@H@("`@(#QC;VYF:6=S=')I;F<@
M;F%M93TB:61E;G0B(&1E<V,](E=H870@:61E;G1I9FEE<B!S:&]U;&0@=V4@
M=7-E(&EN('1H90H@("`@(&QO9W,_(CY(3U)$13PO8V]N9FEG<W1R:6YG/@H*
M("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`\8V]N
M9FEG<&QA8V5H;VQD97(O/@H@("`@(#PO8V]N9FEG<V5C=&EO;CX*"B`@("`@
M/&-O;F9I9W-W:71C:"!N86UE/2)T>7!E(B!D97-C/2)7:&%T(&QO9R!D<FEV
M97(@<VAO=6QD('=E('5S93\B/F9I;&4*("`@("`@/&-A<V4@;F%M93TB8V]N
M<V]L92(@9&5S8STB0V]N<V]L92(^"B`@("`@("`\8V]N9FEG<V5C=&EO;B!N
M86UE/2)P87)A;7,B/@H@("`@("`@(#QC;VYF:6=P:'`@;F%M93TB<W1R96%M
M(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E1H92!O=71P=70@<W1R96%M('1O
M"B`@("`@("`@=7-E(B\^"B`@("`@("`@/&-O;F9I9V)O;VQE86X@;F%M93TB
M8G5F9F5R:6YG(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E-H;W5L9"!T:&4*
M("`@("`@("!O=71P=70@8F4@8G5F9F5R960@=6YT:6P@<VAU=&1O=VX_(CYF
M86QS93PO8V]N9FEG8F]O;&5A;CX*("`@("`@("`\8V]N9FEG<W1R:6YG(&YA
M;64](FQI;F5&;W)M870B(')E<75I<F5D/2)F86QS92(@9&5S8STB3&]G(&QI
M;F4@9F]R;6%T"B`@("`@("`@<W!E8VEF:6-A=&EO;B(O/@H@("`@("`@(#QC
M;VYF:6=S=')I;F<@;F%M93TB=&EM949O<FUA="(@<F5Q=6ER960](F9A;'-E
M(B!D97-C/2)4:6UE('-T86UP"B`@("`@("`@9F]R;6%T(B\^"B`@("`@("`\
M+V-O;F9I9W-E8W1I;VX^"B`@("`@(#PO8V%S93X*"B`@("`@(#QC87-E(&YA
M;64](F1I<W!L87DB(&1E<V,](D1I<W!L87DB/@H@("`@("`@/&-O;F9I9W-E
M8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@("`\8V]N9FEG<W1R:6YG(&YA
M;64](F5R<F]R7W!R97!E;F0B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AI
M<R!S=')I;F<*("`@("`@("!W:6QL(&)E('!R97!E;F1E9"!T;R!T:&4@;&]G
M(&]U='!U="(O/@H@("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB97)R;W)?
M87!P96YD(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E1H:7,@<W1R:6YG"B`@
M("`@("`@=VEL;"!B92!A<'!E;F1E9"!T;R!T:&4@;&]G(&]U='!U="(O/@H@
M("`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@("`\+V-A<V4^"@H@("`@("`\
M8V%S92!N86UE/2)E<G)O<E]L;V<B(&1E<V,](D5R<F]R($QO9R(^"B`@("`@
M("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`@(#QC;VYF
M:6=S=')I;F<@;F%M93TB9&5S=&EN871I;VXB(')E<75I<F5D/2)F86QS92(@
M9&5S8STB3W!T:6]N86P*("`@("`@("!D97-T:6YA=&EO;B!V86QU92!F;W(@
M97)R;W)?;&]G*"DN(%-E90H@("`@("`@(&AT='`Z+R]W=W<N:6YD96QI8FQE
M+F]R9R]P96%R+TQO9R]G=6ED92YH=&UL(V5R<F]R+6QO9RUT>7!E<R!F;W(@
M;6]R90H@("`@("`@(&1E=&%I;',N(B\^"B`@("`@("`@/&-O;F9I9W-T<FEN
M9R!N86UE/2)E>'1R85]H96%D97)S(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,]
M(D%D9&ET:6]N86P*("`@("`@("!H96%D97)S('1O('!A<W,@=&\@=&AE(&UA
M:6PH*2!F=6YC=&EO;B!W:&5N('1H92!014%27TQ/1U]465!%7TU!24P@='EP
M90H@("`@("`@(&ES('-P96-I9FEE9"(O/@H@("`@("`@/"]C;VYF:6=S96-T
M:6]N/@H@("`@("`\+V-A<V4^"@H@("`@("`\8V%S92!N86UE/2)F:6QE(B!D
M97-C/2)&:6QE(CX*("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB;F%M92(@
M9&5S8STB4&%T:"!T;R!T:&4@;&]G"B`@("`@("!F:6QE(CXO=&UP+VAO<F1E
M+FQO9SPO8V]N9FEG<W1R:6YG/@H@("`@("`@/&-O;F9I9W-E8W1I;VX@;F%M
M93TB<&%R86US(CX*("`@("`@("`\8V]N9FEG8F]O;&5A;B!N86UE/2)A<'!E
M;F0B(')E<75I<F5D/2)F86QS92(@9&5S8STB4VAO=6QD(&YE=R!L;V<*("`@
M("`@("!E;G1R:65S(&)E(&%P<&5N9&5D('1O(&%N(&5X:7-T:6YG(&QO9R!F
M:6QE/R!)9B!T:&ES(&ES(&9A;'-E+"!N97<@;&]G(&9I;&5S"B`@("`@("`@
M=VEL;"!O=F5R=W)I=&4@97AI<W1I;F<@;VYE<RXB/G1R=64\+V-O;F9I9V)O
M;VQE86X^"B`@("`@("`@/&-O;F9I9VEN=&5G97(@;F%M93TB;6]D92(@;V-T
M86P](G1R=64B(')E<75I<F5D/2)F86QS92(@9&5S8STB3V-T86P*("`@("`@
M("!R97!R97-E;G1A=&EO;B!O9B!T:&4@;&]G(&9I;&4G<R!P97)M:7-S:6]N
M<R!M;V1E(B\^"B`@("`@("`@/&-O;F9I9W!H<"!N86UE/2)E;VPB(')E<75I
M<F5D/2)F86QS92(@9&5S8STB5&AE(&5N9"UO9BUL:6YE(&-H87)A8W1E<@H@
M("`@("`@('-E<75E;F-E(B\^"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE
M/2)L:6YE1F]R;6%T(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](DQO9R!L:6YE
M(&9O<FUA=`H@("`@("`@('-P96-I9FEC871I;VXB+SX*("`@("`@("`\8V]N
M9FEG<W1R:6YG(&YA;64](G1I;65&;W)M870B(')E<75I<F5D/2)F86QS92(@
M9&5S8STB5&EM92!S=&%M<`H@("`@("`@(&9O<FUA="(O/@H@("`@("`@/"]C
M;VYF:6=S96-T:6]N/@H@("`@("`\+V-A<V4^"@H@("`@("`\8V%S92!N86UE
M/2)M86EL(B!D97-C/2)-86EL(CX*("`@("`@(#QC;VYF:6=S=')I;F<@;F%M
M93TB;F%M92(@9&5S8STB5&AE(')E8VEP:65N="!F;W(@=&AE(&UE<W-A9V4B
M+SX*("`@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@
M("`@/&-O;F9I9W-T<FEN9R!N86UE/2)F<F]M(B!R97%U:7)E9#TB9F%L<V4B
M(&1E<V,](E9A;'5E(&9O<B!T:&4*("`@("`@("!M97-S86=E)W,@1G)O;3H@
M:&5A9&5R(B\^"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)S=6)J96-T
M(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E9A;'5E(&9O<B!T:&4*("`@("`@
M("!M97-S86=E)W,@4W5B:F5C=#H@:&5A9&5R(B\^"B`@("`@("`@/&-O;F9I
M9W-T<FEN9R!N86UE/2)P<F5A;6)L92(@<F5Q=6ER960](F9A;'-E(B!D97-C
M/2)0<F5A;6)L92!F;W(@=&AE"B`@("`@("`@;65S<V%G92(O/@H@("`@("`@
M/"]C;VYF:6=S96-T:6]N/@H@("`@("`\+V-A<V4^"@H@("`@("`\8V%S92!N
M86UE/2)M8V%L(B!D97-C/2)-8V%L(CX*("`@("`@(#QC;VYF:6=S96-T:6]N
M(&YA;64](G!A<F%M<R(^"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)C
M86QE;F1A<B(@9&5S8STB5&AE($U#04P@8V%L96YD87(@;F%M92(O/@H@("`@
M("`@(#QC;VYF:6=S=')I;F<@;F%M93TB=7-E<FYA;64B(&1E<V,](D-O;FYE
M8W0@=&\@34-!3"!A<R(O/@H@("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB
M<&%S<W=O<F0B(&1E<V,](E!A<W-W;W)D('1O(&-O;FYE8W0@=VET:"(O/@H@
M("`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@("`\+V-A<V4^"@H@("`@("`\
M8V%S92!N86UE/2)N=6QL(B!D97-C/2).=6QL(B\^"@H@("`@("`\8V%S92!N
M86UE/2)S<6PB(&1E<V,](E-13"(^"B`@("`@("`\8V]N9FEG<W1R:6YG(&YA
M;64](FYA;64B(&1E<V,](E1H92!T86)L92!T;R!L;V<*("`@("`@('1O(CYL
M;V=?=&%B;&4\+V-O;F9I9W-T<FEN9SX*("`@("`@(#QC;VYF:6=S96-T:6]N
M(&YA;64](G!A<F%M<R(^"B`@("`@("`@/&-O;F9I9W!H<"!N86UE/2)D<VXB
M(&1E<V,](D$@1&%T82!3;W5R8V4*("`@("`@("!.86UE(CXD8V]N9ELG<W%L
M)UT\+V-O;F9I9W!H<#X*("`@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@("`@
M/"]C87-E/@H*("`@("`@/&-A<V4@;F%M93TB<W%L:71E(B!D97-C/2)344QI
M=&4B/@H@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)N86UE(B!D97-C/2)4
M:&4@=&%B;&4@=&\@;&]G"B`@("`@("!T;R(^;&]G7W1A8FQE/"]C;VYF:6=S
M=')I;F<^"B`@("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@
M("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB9FEL96YA;64B(&1E<V,](E!A
M=&@@=&\@86X@4W%L:71E(&1A=&%B87-E(B\^"B`@("`@("`@/&-O;F9I9VEN
M=&5G97(@;F%M93TB;6]D92(@;V-T86P](G1R=64B(')E<75I<F5D/2)F86QS
M92(@9&5S8STB3V-T86P*("`@("`@("!M;V1E('5S960@=&\@;W!E;B!T:&4@
M9&%T86)A<V4@6S`V-C9=(B\^"B`@("`@("`@/&-O;F9I9V)O;VQE86X@;F%M
M93TB<&5R<VES=&5N="(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)5<V4@80H@
M("`@("`@('!E<G-I<W1E;G0@8V]N;F5C=&EO;B(^9F%L<V4\+V-O;F9I9V)O
M;VQE86X^"B`@("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`@(#PO8V%S93X*
M"B`@("`@(#QC87-E(&YA;64](G-Y<VQO9R(@9&5S8STB4WES;&]G(CX*("`@
M("`@(#QC;VYF:6=P:'`@;F%M93TB;F%M92(@<75O=&4](F9A;'-E(B!D97-C
M/2)3>7-L;V<@9F%C:6QI='D@=&\@=7-E(B\^"B`@("`@(#PO8V%S93X*"B`@
M("`@(#QC87-E(&YA;64](G=I;B(@9&5S8STB5VEN9&]W(CX*("`@("`@(#QC
M;VYF:6=S=')I;F<@;F%M93TB;F%M92(@9&5S8STB3F%M92!O9B!T:&4@;W!E
M;F5D('=I;F1O=R(O/@H@("`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R
M86US(CX*("`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G1I=&QE(B!R97%U
M:7)E9#TB9F%L<V4B(&1E<V,](E1H92!T:71L92!O9B!T:&4*("`@("`@("!O
M=71P=70@=VEN9&]W(B\^"B`@("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`@
M(#PO8V%S93X*("`@("`\+V-O;F9I9W-W:71C:#X*"B`@("`\+V-A<V4^"B`@
M("`\8V%S92!N86UE/2)F86QS92(@9&5S8STB3F\B+SX*("`@/"]C;VYF:6=S
M=VET8V@^"B`@/"]C;VYF:6=S96-T:6]N/@H@(#QC;VYF:6=B;V]L96%N(&YA
M;64](FQO9U]A8V-E<W-K97ES(B!D97-C/2)3:&]U;&0@2&]R9&4@;&]G('-T
M871I<W1I8W,@86)O=70*("`@=7-E9"!A8V-E<W,@:V5Y<S\@5&AI<R!I<R!O
M;FQY('5S969U;"!F;W(@=')A;G-L871O<G,@;V8@=&AE"B`@(%5)+B!9;W4@
M86QS;R!N965D('1O('-E="!T:&4@;&]G(&QE=F5L('1O(&%T(&QE87-T"B`@
M(%!%05)?3$]'7TE.1D\N(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*(#PO8V]N
M9FEG=&%B/@H*(#QC;VYF:6=T86(@;F%M93TB<')E9G,B(&1E<V,](E!R969E
M<F5N8V4@4WES=&5M(CX*("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P<F5F<R(^
M"B`@(#QC;VYF:6=H96%D97(^4')E9F5R96YC92!3>7-T96T@4V5T=&EN9W,\
M+V-O;F9I9VAE861E<CX*("`@/&-O;F9I9VEN=&5G97(@;F%M93TB;6%X<VEZ
M92(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@<VEZ92!O9B!T:&4*("`@
M<')E9F5R96YC97,@9FEE;&0@:6X@>6]U<B!B86-K96YD(&EN(&)Y=&5S+B!(
M;W)D92!W:6QL(')E:F5C="!A;GD@=W)I=&4@=&\*("`@=&AE('!R969E<F5N
M8V5S(&)A8VME;F0@:68@:71S(&QE;F=T:"!E>&-E961S('1H:7,@=F%L=64N
M($QE879E(&5M<'1Y('1O"B`@('-K:7`@=&AI<R!C:&5C:VEN9RX@12YG+B!-
M>5-13"!S=&]R97,@=&AE('!R969E<F5N8V4@9&%T82!I;B!A($Q/3D=415A4
M"B`@(&9I96QD+B!4:&ES(&9I96QD(&-A;B!H;VQD(#0R.30Y-C<R.34@8GET
M97,@<V\@;6]S="!L:6ME;'D@8VAE8VMI;F<@:7,@;F]T"B`@(&YE961E9"X@
M2&]W979E<B!O=&AE<B!$0B!I;G-T86QL871I;VYS(&UA>2!O;FQY(&AA=F4@
M82!S=&]R86=E('-I>F4@;V8@-C0*("`@2T(@*#8U-3,U(&)Y=&5S*2X@5&AE
M<V4@:6YS=&%L;&%T:6]N<R!W;W5L9"!W86YT('1O('1U<FX@8VAE8VMI;F<@
M;VXN(B\^"B`@(#QC;VYF:6=S=VET8V@@;F%M93TB9')I=F5R(B!D97-C/2)7
M:&%T('!R969E<F5N8V5S(&1R:79E<B!S:&]U;&0@=V4@=7-E/R(^<V5S<VEO
M;@H@("`@(#QC87-E(&YA;64](G-Q;"(@9&5S8STB4U%,($1A=&%B87-E(CX*
M("`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@(#QC
M;VYF:6=S<6P@<W=I=&-H;F%M93TB9')I=F5R8V]N9FEG(CX*("`@("`@("`\
M8V]N9FEG<W1R:6YG(&YA;64](G1A8FQE(B!R97%U:7)E9#TB9F%L<V4B(&1E
M<V,](E1H92!N86UE(&]F('1H90H@("`@("`@('!R969E<F5N8V4@=&%B;&4@
M:6X@=&AE(&1A=&%B87-E(%MH;W)D95]P<F5F<UTB+SX*("`@("`@(#PO8V]N
M9FEG<W%L/@H@("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`@/"]C87-E/@H@
M("`@(#QC87-E(&YA;64](FQD87`B(&1E<V,](DQ$05`B/@H@("`@("`\8V]N
M9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`@/&-O;F9I9W-T<FEN
M9R!N86UE/2)H;W-T<W!E8R(@9&5S8STB5&AE(&AO<W1N86UE(&]F('1H92!,
M1$%0('-E<G9E<B(^;&]C86QH;W-T/"]C;VYF:6=S=')I;F<^"B`@("`@("`\
M8V]N9FEG:6YT96=E<B!N86UE/2)P;W)T(B!D97-C/2)4:&4@<&]R="!O9B!T
M:&4@3$1!4"!S97)V97(B/C,X.3PO8V]N9FEG:6YT96=E<CX*("`@("`@(#QC
M;VYF:6=E;G5M(&YA;64](G9E<G-I;VXB(&1E<V,](DQ$05`@4')O=&]C;VP@
M5F5R<VEO;B(^,PH@("`@("`@(#QV86QU97,^"B`@("`@("`@(#QV86QU92!D
M97-C/2),1$%0=C(@*$1E<')E8V%T960I(CXR/"]V86QU93X*("`@("`@("`@
M/'9A;'5E(&1E<V,](DQ$05!V,R(^,SPO=F%L=64^"B`@("`@("`@/"]V86QU
M97,^"B`@("`@("`\+V-O;F9I9V5N=6T^"B`@("`@("`\8V]N9FEG<W1R:6YG
M(&YA;64](F)A<V5D;B(@9&5S8STB5&AE(&)A<V4@1$X@9F]R('1H92!,1$%0
M('-E<G9E<B(O/@H@("`@("`@/&-O;F9I9V)O;VQE86X@;F%M93TB9F5T8VAD
M;B(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)3:&]U;&0@2&]R9&4@8FEN9`IA
M<R!E86-H('5S97(@9F]R('1H870@=7-E<B=S('=R:71E(&]P97)A=&EO;G,_
M(B\^"B`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G)O;W1D;B(@<F5Q=6ER
M960](F9A;'-E(B!D97-C/2))9B!N;W0L('!R;W9I9&4@=&AE"D1.(&]F('1H
M92!R;V]T("AA9&UI;FES=')A=&EV92D@86-C;W5N="!T;R!B:6YD(&9O<B!W
M<FET92!O<&5R871I;VYS(B\^"B`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64]
M(G!A<W-W;W)D(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E1H92!P87-S=V]R
M9"!O9B!T:&4@<F]O="!$3B!F;W(@8FEN9"!A=71H96YT:6-A=&EO;B(O/@H@
M("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)U:60B(&1E<V,](E1H92!U<V5R
M;F%M92!S96%R8V@@:V5Y(B\^"B`@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@
M("`\+V-A<V4^"B`@("`@/&-A<V4@;F%M93TB<V5S<VEO;B(@9&5S8STB4$A0
M(%-E<W-I;VYS(B\^"B`@("`@/&-A<V4@;F%M93TB:V]L86(B(&1E<V,](DMO
M;&%B("A,1$%0*2(@+SX*("`@("`\8V%S92!N86UE/2)I;7-P(B!D97-C/2))
M35-0(%-E<G9E<B(@+SX*("`@/"]C;VYF:6=S=VET8V@^"B`@/"]C;VYF:6=S
M96-T:6]N/@H@/"]C;VYF:6=T86(^"@H@/&-O;F9I9W1A8B!N86UE/2)D871A
M=')E92(@9&5S8STB1&%T851R964@4WES=&5M(CX*("`\8V]N9FEG<V5C=&EO
M;B!N86UE/2)D871A=')E92(^"B`@(#QC;VYF:6=H96%D97(^1&%T851R964@
M4WES=&5M(%-E='1I;F=S/"]C;VYF:6=H96%D97(^"B`@(#QC;VYF:6=S=VET
M8V@@;F%M93TB9')I=F5R(B!D97-C/2)7:&%T(&)A8VME;F0@<VAO=6QD('=E
M('5S92!F;W(@2&]R9&4*("`@1&%T851R964@<W1O<F%G93\B/FYU;&P*("`@
M("`\8V%S92!N86UE/2)N=6QL(B!D97-C/2).;VYE(B\^"B`@("`@/&-A<V4@
M;F%M93TB<W%L(B!D97-C/2)344P@1&%T86)A<V4B/@H@("`@("`\8V]N9FEG
M<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`@/&-O;F9I9W-Q;"!S=VET
M8VAN86UE/2)D<FEV97)C;VYF:6<B/@H@("`@("`@(#QC;VYF:6=S=')I;F<@
M;F%M93TB=&%B;&4B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE(&YA;64@
M;V8@=&AE"B`@("`@("`@9&%T82!T86)L92!I;B!T:&4@9&%T86)A<V4@6VAO
M<F1E7V1A=&%T<F5E72(O/@H@("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB
M=&%B;&5?871T<FEB=71E<R(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@
M;F%M90H@("`@("`@(&]F('1H92!D871A(&%T=')I8G5T97,@=&%B;&4@:6X@
M=&AE(&1A=&%B87-E"B`@("`@("`@6VAO<F1E7V1A=&%T<F5E7V%T=')I8G5T
M97-=(B\^"B`@("`@("`\+V-O;F9I9W-Q;#X*("`@("`@/"]C;VYF:6=S96-T
M:6]N/@H@("`@(#PO8V%S93X*("`@/"]C;VYF:6=S=VET8V@^"B`@/"]C;VYF
M:6=S96-T:6]N/@H@/"]C;VYF:6=T86(^"@H@/&-O;F9I9W1A8B!N86UE/2)G
M<F]U<"(@9&5S8STB1W)O=7!S(CX*("`\8V]N9FEG<V5C=&EO;B!N86UE/2)G
M<F]U<"(^"B`@(#QC;VYF:6=H96%D97(^1W)O=7!S(%-E='1I;F=S/"]C;VYF
M:6=H96%D97(^"B`@(#QC;VYF:6=D97-C<FEP=&EO;CX*("`@(%1H92!(;V]K
M<R!B86-K96YD(&5X=&5N9',@=&AE($1A=&%4<F5E(&)A8VME;F0@=&\@86QL
M;W<@:&]O:W,@=&\@97AT96YD(&$*("`@(&=R;W5P('1O(&1Y;F%M:6-A;&QY
M(&EN8VQU9&4@;65M8F5R<R!I;G1O(&$@9W)O=7`N("!3964@:&]O:W,N<&AP
M+F1I<W0@9F]R"B`@("!A;B!E>&%M<&QE+@H@("`\+V-O;F9I9V1E<V-R:7!T
M:6]N/@H@("`\8V]N9FEG<W=I=&-H(&YA;64](F1R:79E<B(@9&5S8STB5VAA
M="!B86-K96YD('-H;W5L9"!W92!U<V4@9F]R($AO<F1E"B`@($=R;W5P<S\B
M/F1A=&%T<F5E"B`@("`@/&-A<V4@;F%M93TB9&%T871R964B(&1E<V,](D1A
M=&%4<F5E(B\^"B`@("`@/&-A<V4@;F%M93TB:&]O:W,B(&1E<V,](DAO;VMS
M(B\^"@H@("`@(#QC87-E(&YA;64](FQD87`B(&1E<V,](DQ$05`B/@H@("`@
M("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@("`\8V]N
M9FEG<W1R:6YG(&YA;64](FAO<W1S<&5C(B!D97-C/2)4:&4@:&]S=&YA;64@
M;V8@=&AE($Q$05`@<V5R=F5R(CYL;V-A;&AO<W0\+V-O;F9I9W-T<FEN9SX*
M("`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F)A<V5D;B(@9&5S8STB5&AE
M(&)A<V4@1$X@9F]R('1H92!,1$%0('-E<G9E<B(O/@H@("`@("`@(#QC;VYF
M:6=S=')I;F<@;F%M93TB8FEN9&1N(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,]
M(E1H92!$3B!U<V5D('1O(&)I;F0@=&\@=&AE($Q$05`@<V5R=F5R(B\^"B`@
M("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)P87-S=V]R9"(@<F5Q=6ER960]
M(F9A;'-E(B!D97-C/2)4:&4@<&%S<W=O<F0@=7-E9"!T;R!B:6YD('1O('1H
M92!,1$%0('-E<G9E<B(O/@H@("`@("`@(#QC;VYF:6=E;G5M(&YA;64](G9E
M<G-I;VXB(&1E<V,](DQ$05`@4')O=&]C;VP@5F5R<VEO;B(^,PH@("`@("`@
M("`\=F%L=65S/@H@("`@("`@("`@/'9A;'5E(&1E<V,](DQ$05!V,B`H1&5P
M<F5C871E9"DB/C(\+W9A;'5E/@H@("`@("`@("`@/'9A;'5E(&1E<V,](DQ$
M05!V,R(^,SPO=F%L=64^"B`@("`@("`@(#PO=F%L=65S/@H@("`@("`@(#PO
M8V]N9FEG96YU;3X*("`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F=I9"(@
M9&5S8STB5&AE(&=R;W5P('-E87)C:"!K97DB/F-N/"]C;VYF:6=S=')I;F<^
M"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)M96UB97)U:60B(&1E<V,]
M(D=R;W5P(&UE;6)E<G-H:7`@9FEE;&0B/FUE;6)E<E5I9#PO8V]N9FEG<W1R
M:6YG/@H@("`@("`@(#QC;VYF:6=L:7-T(&YA;64](FYE=V=R;W5P7V]B:F5C
M=&-L87-S(B!D97-C/2)7:&%T(&]B:F5C=&-L87-S97,@<VAO=6QD(&$@;F5W
M(&=R;W5P(&)E(&UE;6)E<B!O9C\@5&AE<V4@;V)J96-T8VQA<W-E<R!S:&]U
M;&0@8V]V97(@=&AE(&UA:6P@86YD(&=I9&YU;6)E<B!A='1R:6)U=&5S(&%S
M('=E;&P@87,@=&AE(&=R;W5P('-E87)C:"!K97DB/G!O<VEX1W)O=7`L:&]R
M9&5'<F]U<#PO8V]N9FEG;&ES=#X*("`@("`@("`\8V]N9FEG<W=I=&-H(&YA
M;64](F9I;'1E<E]T>7!E(B!D97-C/2)(;W<@=&\@<W!E8VEF>2!A(&9I;'1E
M<B!F;W(@=&AE(&=R;W5P(&QI<W1S(CYO8FIE8W1C;&%S<PH@("`@("`@("`\
M8V%S92!N86UE/2)O8FIE8W1C;&%S<R(@9&5S8STB3VYE(&]R(&UO<F4@;V)J
M96-T8VQA<W,@9FEL=&5R<R(^"B`@("`@("`@("`\8V]N9FEG;&ES="!N86UE
M/2)O8FIE8W1C;&%S<R(@9&5S8STB5&AE(&]B:F5C=&-L87-S(&9I;'1E<B!U
M<V5D('1O('-E87)C:"!F;W(@9W)O=7!S+B!#86X@8F4@82!S:6YG;&4@;V)J
M96-T8VQA<W,@;W(@82!L:7-T+B(^<&]S:7A'<F]U<#PO8V]N9FEG;&ES=#X*
M("`@("`@("`@/"]C87-E/@H@("`@("`@("`\8V%S92!N86UE/2)F<F5E(B!D
M97-C/2)!(&-O;7!L971E($Q$05`@9FEL=&5R(&5X<')E<W-I;VXB/@H@("`@
M("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)F:6QT97(B(&1E<V,](E1H92!,
M1$%0(%)&0R!F;W)M871T960@9FEL=&5R('5S960@=&\@<V5A<F-H(&9O<B!G
M<F]U<',N(B\^"B`@("`@("`@(#PO8V%S93X*("`@("`@("`\+V-O;F9I9W-W
M:71C:#X*("`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@(#PO8V%S93X*"B`@
M(#PO8V]N9FEG<W=I=&-H/@H@(#PO8V]N9FEG<V5C=&EO;CX*(#PO8V]N9FEG
M=&%B/@H*(#QC;VYF:6=T86(@;F%M93TB8V%C:&4B(&1E<V,](D-A8VAE(%-Y
M<W1E;2(^"B`@/&-O;F9I9W-E8W1I;VX@;F%M93TB8V%C:&4B/@H@("`\8V]N
M9FEG:&5A9&5R/D-A8VAE(%-Y<W1E;2!3971T:6YG<SPO8V]N9FEG:&5A9&5R
M/@H@("`\8V]N9FEG:6YT96=E<B!N86UE/2)D969A=6QT7VQI9F5T:6UE(B!D
M97-C/2)(;W<@;&]N9RP@:6X@<V5C;VYD<RP@<VAO=6QD"B`@(&]B:F5C=',@
M8F4@8V%C:&5D(&)Y(&1E9F%U;'0_(CXQ.#`P/"]C;VYF:6=I;G1E9V5R/@H@
M("`\8V]N9FEG<W=I=&-H(&YA;64](F1R:79E<B(@9&5S8STB268@>6]U('=A
M;G0@=&\@96YA8FQE('1H92!(;W)D92!#86-H92P*("`@<V5L96-T(&$@9')I
M=F5R(&AE<F4N(%1H:7,@:7,@=7-E9"!T;R!S<&5E9"!U<"!P;W)T:6]N<R!O
M9B!(;W)D92!B>2!S=&]R:6YG"B`@(&-O;6UO;FQY('!R;V-E<W-E9"!O8FIE
M8W1S('1O(&1I<VLN(CYF:6QE"B`@("`\8V%S92!N86UE/2)N;VYE(B!D97-C
M/2)$;VXG="!C86-H92!A;GD@;V)J96-T<R(O/@H@("`@/&-A<V4@;F%M93TB
M9FEL92(@9&5S8STB4W1O<F4@;V)J96-T<R!I;B!F:6QE<WES=&5M(CX*("`@
M("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`\8V]N9FEG
M<&AP(&YA;64](F1I<B(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@;&]C
M871I;VX@=&\@<W1O<F4@=&AE"B`@("`@(&-A8VAE9"!F:6QE<R(^2&]R9&4Z
M.F=E=%1E;7!$:7(H*3PO8V]N9FEG<&AP/@H@("`@("`\8V]N9FEG<W1R:6YG
M(&YA;64](G!R969I>"(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@9FEL
M96YA;64@<')E9FEX('1O"B`@("`@('5S92!F;W(@=&AE(&-A8VAE(&9I;&5S
M+B(O/@H@("`@("`\8V]N9FEG:6YT96=E<B!N86UE/2)G8R(@<F5Q=6ER960]
M(F9A;'-E(B!D97-C/2)097)F;W)M(&=A<F)A9V4*("`@("`@8V]L;&5C=&EO
M;B!O;B!C86-H92!F:6QE<S\@26YP=70@=&AE(&YU;6)E<B!O9B!S96-O;F1S
M(&]L9"!T:&4@9FEL92!H87,*("`@("`@=&\@8F4@=VET:&]U="!M;V1I9FEC
M871I;VX@8F5F;W)E('1H92!C86-H92!S>7-T96T@8V%N(&1E;&5T92!T:&4@
M9FEL92X*("`@("`@26YP=70@,"!T;R!S:VEP(&=A<F)A9V4@8V]L;&5C=&EO
M;BXB/C@V-#`P/"]C;VYF:6=I;G1E9V5R/@H@("`@("!A9G1E<B!W:&EC:"!C
M86-H90H@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@(#PO8V%S93X*("`@(#QC
M87-E(&YA;64](GIP<S0B(&1E<V,](E5S92!T:&4@6F5N9"!097)F;W)M86YC
M92!3=6ET92!O=71P=70@8V%C:&4B+SX*("`@/"]C;VYF:6=S=VET8V@^"B`@
M/"]C;VYF:6=S96-T:6]N/@H@/"]C;VYF:6=T86(^"@H@/&-O;F9I9W1A8B!N
M86UE/2)T;VME;B(@9&5S8STB5&]K96X@4WES=&5M(CX*("`\8V]N9FEG<V5C
M=&EO;B!N86UE/2)T;VME;B(^"B`@(#QC;VYF:6=H96%D97(^5&]K96X@4WES
M=&5M(%-E='1I;F=S/"]C;VYF:6=H96%D97(^"B`@(#QC;VYF:6=I;G1E9V5R
M(&YA;64](G1I;65O=70B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE('!E
M<FEO9"`H:6X*("`@<V5C;VYD<RD@869T97(@=VAI8V@@86X@:60@:7,@<'5R
M9V5D(B\^"B`@(#QC;VYF:6=S=VET8V@@;F%M93TB9')I=F5R(B!D97-C/2))
M9B!Y;W4@=V%N="!T;R!E;F%B;&4@1F]R;2!4;VME;G,L('-E;&5C=`H@("!A
M(&1R:79E<B!H97)E+B!4:&ES(&ES('5S960@8GD@=&AE($AO<F1E.CI&;W)M
M.CH@05!)(&%N9"!S;VUE(&]T:&5R('!A<G1S"B`@(&]F($AO<F1E('1O(&5N
M<W5R92!T:&%T(&$@9F]R;2!C86X@;VYL>2!B92!S=6)M:71T960@;VYC92XB
M/FYO;F4*("`@(#QC87-E(&YA;64](FYO;F4B(&1E<V,](D1I<V%B;&4@1F]R
M;2!4;VME;G,B+SX*("`@(#QC87-E(&YA;64](F9I;&4B(&1E<V,](DQO8V%L
M(&9I;&5S>7-T96T@=&]K96X@<W1O<F%G92(^"B`@("`@/&-O;F9I9W-T<FEN
M9R!N86UE/2)T;VME;E]D:7(B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE
M(&1I<F5C=&]R>2!W:&5R90H@("`@('1O(&ME97`@=&]K96X@9FEL97,B+SX*
M("`@(#PO8V%S93X*("`@(#QC87-E(&YA;64](G-Q;"(@9&5S8STB4U%,+6)A
M<V5D('1O:V5N('-T;W)A9V4B/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64]
M(G!A<F%M<R(^"B`@("`@(#QC;VYF:6=S<6P@<W=I=&-H;F%M93TB9')I=F5R
M8V]N9FEG(CX*("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB=&%B;&4B(')E
M<75I<F5D/2)F86QS92(@9&5S8STB5&AE(&YA;64@;V8@=&AE"B`@("`@("!T
M;VME;G,@=&%B;&4@:6X@=&AE(&1A=&%B87-E(%MH;W)D95]T;VME;G-=(B\^
M"B`@("`@(#PO8V]N9FEG<W%L/@H@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@
M(#PO8V%S93X*("`@/"]C;VYF:6=S=VET8V@^"B`@/"]C;VYF:6=S96-T:6]N
M/@H@/"]C;VYF:6=T86(^"@H@/&-O;F9I9W1A8B!N86UE/2)M86EL97(B(&1E
M<V,](DUA:6QE<B(^"B`@/&-O;F9I9W-E8W1I;VX@;F%M93TB;6%I;&5R(CX*
M("`@/&-O;F9I9VAE861E<CY-86EL97(\+V-O;F9I9VAE861E<CX*("`@/&-O
M;F9I9W-W:71C:"!N86UE/2)T>7!E(B!D97-C/2)7:&%T(&UE=&AO9"!S:&]U
M;&0@=V4@=7-E(&9O<B!S96YD:6YG"B`@(&UA:6P_(CYS96YD;6%I;`H@("`@
M/&-A<V4@;F%M93TB;G5L;"(@9&5S8STB1&ES86)L92!M86EL:6YG(B`O/@H@
M("`@/&-A<V4@;F%M93TB<V5N9&UA:6PB(&1E<V,](E5S92!T:&4@;&]C86P@
M<V5N9&UA:6P@8FEN87)Y(CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P
M87)A;7,B/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G-E;F1M86EL7W!A
M=&@B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE(&QO8V%T:6]N"B`@("`@
M(&]F('1H92!S96YD;6%I;"!B:6YA<GD@;VX@=&AE(&9I;&5S>7-T96T*("`@
M("`@6R]U<W(O<V)I;B]S96YD;6%I;%TB/B]U<W(O;&EB+W-E;F1M86EL/"]C
M;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<V5N9&UA
M:6Q?87)G<R(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)!;GD@97AT<F$*("`@
M("`@<&%R86UE=&5R<R!T;R!P87-S('1O('1H92!S96YD;6%I;"!O<B!S96YD
M;6%I;"!W<F%P<&5R"B`@("`@(&)I;F%R>2(^+6]I/"]C;VYF:6=S=')I;F<^
M"B`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@/"]C87-E/@H@("`@/&-A<V4@
M;F%M93TB<VUT<"(@9&5S8STB57-E(&$@4TU44"!S97)V97(B/@H@("`@(#QC
M;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@(#QC;VYF:6=S=')I
M;F<@;F%M93TB:&]S="(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@<V5R
M=F5R('1O(&-O;FYE8W0*("`@("`@=&\@6VQO8V%L:&]S=%TB+SX*("`@("`@
M/&-O;F9I9VEN=&5G97(@;F%M93TB<&]R="(@<F5Q=6ER960](F9A;'-E(B!D
M97-C/2)4:&4@<&]R="!T;R!C;VYN96-T"B`@("`@('1O(%LR-5TB+SX*("`@
M("`@/&-O;F9I9W-T<FEN9R!N86UE/2)L;V-A;&AO<W0B(')E<75I<F5D/2)F
M86QS92(@9&5S8STB5&AE(&QO8V%L(&AO<W1N86UE"B`@("`@("\@9&]M86EN
M(%ML;V-A;&AO<W1=(B\^"B`@("`@(#QC;VYF:6=E;G5M(&YA;64](F%U=&@B
M(&1E<V,](E--5%`@875T:&5N=&EC871I;VXB/C`*("`@("`@(#QV86QU97,^
M"B`@("`@("`@/'9A;'5E(&1E<V,](DYO(&%U=&AE;G1I8V%T:6]N(CXP/"]V
M86QU93X*("`@("`@("`\=F%L=64@9&5S8STB0F5S="!A=F%I;&%B;&4@875T
M:&5N=&EC871I;VXB/C$\+W9A;'5E/@H@("`@("`@(#QV86QU93Y$24=%4U0M
M340U/"]V86QU93X*("`@("`@("`\=F%L=64^0U)!32U-1#4\+W9A;'5E/@H@
M("`@("`@(#QV86QU93Y,3T=)3CPO=F%L=64^"B`@("`@("`@/'9A;'5E/E!,
M04E./"]V86QU93X*("`@("`@(#PO=F%L=65S/@H@("`@("`\+V-O;F9I9V5N
M=6T^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB=7-E<FYA;64B(')E<75I
M<F5D/2)F86QS92(@9&5S8STB5&AE('5S97)N86UE('1O('5S92!F;W(@4TU4
M4"!A=71H(B\^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<&%S<W=O<F0B
M(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE('!A<W-W;W)D('1O('5S92!F
M;W(@4TU44"!A=71H(B\^"B`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@/"]C
M87-E/@H@("`\+V-O;F9I9W-W:71C:#X*("`\+V-O;F9I9W-E8W1I;VX^"B`\
M+V-O;F9I9W1A8CX*"B`\8V]N9FEG=&%B(&YA;64](G9F<R(@9&5S8STB5FER
M='5A;"!&:6QE(%-T;W)A9V4B/@H@(#QC;VYF:6=S96-T:6]N(&YA;64](G9F
M<R(^"B`@(#QC;VYF:6=H96%D97(^5FER='5A;"!&:6QE(%-T;W)A9V4\+V-O
M;F9I9VAE861E<CX*("`@/&-O;F9I9W-W:71C:"!N86UE/2)T>7!E(B!D97-C
M/2))9B!A(%9&4R`H=FER='5A;"!F:6QE<WES=&5M*2!B86-K96YD(&ES"B`@
M(')E<75I<F5D+"!W:&EC:"!O;F4@<VAO=6QD('=E('5S93\B/F9I;&4*("`@
M(#QC87-E(&YA;64](F9I;&4B(&1E<V,](D9I;&5S(&]N('1H92!L;V-A;"!S
M>7-T96TB/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@
M("`@(#QC;VYF:6=S=')I;F<@;F%M93TB=F9S<F]O="(@9&5S8STB5VAE<F4@
M;VX@=&AE(')E86P@9FEL97-Y<W1E;2!S:&]U;&0*("`@("`@2&]R9&4@=7-E
M(&%S(')O;W0@;V8@=&AE('9I<G1U86P@9FEL97-Y<W1E;3\B/B]T;7`\+V-O
M;F9I9W-T<FEN9SX*("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`\+V-A<V4^
M"B`@("`\8V%S92!N86UE/2)S<6PB(&1E<V,](E-13"!D871A8F%S92(^"B`@
M("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I
M9W-Q;"!S=VET8VAN86UE/2)D<FEV97)C;VYF:6<B/@H@("`@("`@/&-O;F9I
M9W-T<FEN9R!N86UE/2)V9G-?=&%B;&4B(&1E<V,](E1H92!N86UE(&]F('1H
M92!61E,@=&%B;&4@:6X@=&AE"B`@("`@("!D871A8F%S92!;:&]R9&5?=F9S
M72(@<F5Q=6ER960](F9A;'-E(B\^"B`@("`@(#PO8V]N9FEG<W%L/@H@("`@
M(#PO8V]N9FEG<V5C=&EO;CX*("`@(#PO8V%S93X*("`@/"]C;VYF:6=S=VET
M8V@^"B`@/"]C;VYF:6=S96-T:6]N/@H@/"]C;VYF:6=T86(^"@H@/&-O;F9I
M9W1A8B!N86UE/2)S97-S:6]N(B!D97-C/2)#=7-T;VT@4V5S<VEO;B!(86YD
M;&5R(CX*("`\8V]N9FEG<V5C=&EO;B!N86UE/2)S97-S:6]N:&%N9&QE<B(^
M"B`@(#QC;VYF:6=H96%D97(^0W5S=&]M(%-E<W-I;VX@2&%N9&QE<CPO8V]N
M9FEG:&5A9&5R/@H@("`\8V]N9FEG<W=I=&-H(&YA;64](G1Y<&4B(&1E<V,]
M(E=H870@<V5S<VEO;FAA;F1L97(@9')I=F5R('-H;W5L9"!W90H@("!U<V4_
M(CYN;VYE"B`@("`\8V%S92!N86UE/2)N;VYE(B!D97-C/2)5<V4@=&AE(&1E
M9F%U;'0@4$A0("AF:6QE+6)A<V5D*2!S97-S:6]N(&AA;F1L97(B+SX*("`@
M(#QC87-E(&YA;64](F5X=&5R;F%L(B!D97-C/2)5<V4@>6]U<B!O=VX@8W5S
M=&]M('-E<W-I;VX@:&%N9&QE<B(^"B`@("`@/&-O;F9I9W-E8W1I;VX@;F%M
M93TB<&%R86US(CX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)O<&5N(B!D
M97-C/2)9;W5R(&]P96XH*2!F=6YC=&EO;B(O/@H@("`@("`\8V]N9FEG<W1R
M:6YG(&YA;64](F-L;W-E(B!D97-C/2)9;W5R(&-L;W-E*"D@9G5N8W1I;VXB
M+SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)R96%D(B!D97-C/2)9;W5R
M(')E860H*2!F=6YC=&EO;B(O/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64]
M(G=R:71E(B!D97-C/2)9;W5R('=R:71E*"D@9G5N8W1I;VXB+SX*("`@("`@
M/&-O;F9I9W-T<FEN9R!N86UE/2)D97-T<F]Y(B!D97-C/2)9;W5R(&1E<W1R
M;WDH*2!F=6YC=&EO;B(O/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F=C
M(B!D97-C/2)9;W5R(&=C*"D@9G5N8W1I;VXB+SX*("`@("`\+V-O;F9I9W-E
M8W1I;VX^"B`@("`\+V-A<V4^"B`@("`\8V%S92!N86UE/2)D8FTB(&1E<V,]
M(D1"32!B87-E9"!S97-S:6]N<R(O/@H@("`@/&-A<V4@;F%M93TB;7ES<6PB
M(&1E<V,](DUY4U%,(&)A<V5D('-E<W-I;VYS(CX*("`@("`\8V]N9FEG<V5C
M=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`\8V]N9FEG8F]O;&5A;B!N86UE
M/2)P97)S:7-T96YT(B!D97-C/2)297%U97-T('!E<G-I<W1E;G0@8V]N;F5C
M=&EO;G,_(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*("`@("`@/&-O;F9I9V)O
M;VQE86X@;F%M93TB<F]W;&]C:VEN9R(@9&5S8STB4VAO=6QD('=E('5S92!R
M;W<M;&5V96P@;&]C:VEN9PH@("`@("!A;F0@=')A;G-A8W1I;VYS/R!4:&ES
M(&ES('-T<F]N9VQY(')E8V]M;65N9&5D+"!B=70@<F5Q=6ER97,@82!T86)L
M90H@("`@("!T>7!E('1H870@:7,@=')A;G-A8W1I;VXM<V%F92!A;F0@<W5P
M<&]R=',@<F]W+6QE=F5L(&QO8VMI;F<L(&QI:V4*("`@("`@26YN;T1"+B!)
M9B!Y;W4@9&]N)W0@:&%V92!S=6-H(&$@=&%B;&4@='EP92P@9&ES86)L92!T
M:&ES('-E='1I;F<@86YD('=E"B`@("`@('=I;&P@=7-E('1A8FQE+6QE=F5L
M(&QO8VMI;F<@86YD(&YO(&QO8VMI;F<*("`@("`@:6YS=&5A9"XB/G1R=64\
M+V-O;F9I9V)O;VQE86X^"B`@("`@(#QC;VYF:6=S=VET8V@@;F%M93TB<')O
M=&]C;VPB(&1E<V,](E=H870@<')O=&]C;VP@=VEL;"!W92!U<V4@=&\@8V]N
M;F5C="!T;R!T:&4@9&%T86)A<V4_(CYU;FEX"B`@("`@("`\8V%S92!N86UE
M/2)U;FEX(B!D97-C/2)53DE8(%-O8VME=',B/@H@("`@("`@(#QC;VYF:6=S
M=')I;F<@;F%M93TB<V]C:V5T(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](DQO
M8V%T:6]N(&]F(%5.25@@<V]C:V5T(CX\+V-O;F9I9W-T<FEN9SX*("`@("`@
M(#PO8V%S93X*("`@("`@(#QC87-E(&YA;64](G1C<"(@9&5S8STB5$-0+TE0
M(CX*("`@("`@("`\8V]N9FEG:6YT96=E<B!N86UE/2)P;W)T(B!R97%U:7)E
M9#TB9F%L<V4B(&1E<V,](E!O<G0@=&AE($1"(&ES(')U;FYI;F<@;VXL(&EF
M(&YO;BUS=&%N9&%R9"(^,S,P-CPO8V]N9FEG:6YT96=E<CX*("`@("`@(#PO
M8V%S93X*("`@("`@/"]C;VYF:6=S=VET8V@^"B`@("`@(#QC;VYF:6=S=')I
M;F<@;F%M93TB:&]S='-P96,B(&1E<V,](E=H870@:&]S=&YA;64@:7,@=&AE
M(&1A=&%B87-E('-E<G9E<B!R=6YN:6YG(&]N+"!O<B!W:&%T(&ES('1H92!N
M86UE(&]F('1H92!S>7-T96T@1%-.('1O('5S93\B/FQO8V%L:&]S=#PO8V]N
M9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G5S97)N86UE
M(B!D97-C/2)7:&%T('5S97)N86UE(&1O('=E(&%U=&AE;G1I8V%T92!T;R!T
M:&4@9&%T86)A<V4@<V5R=F5R(&%S/R(^:&]R9&4\+V-O;F9I9W-T<FEN9SX*
M("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)P87-S=V]R9"(@<F5Q=6ER960]
M(F9A;'-E(B!D97-C/2)7:&%T('!A<W-W;W)D(&1O('=E(&%U=&AE;G1I8V%T
M92!T;R!T:&4@9&%T86)A<V4@<V5R=F5R('=I=&@_(B\^"B`@("`@(#QC;VYF
M:6=S=')I;F<@;F%M93TB9&%T86)A<V4B(&1E<V,](E=H870@9&%T86)A<V4@
M;F%M92]T86)L97-P86-E(&%R92!W92!U<VEN9S\B/FAO<F1E/"]C;VYF:6=S
M=')I;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB=&%B;&4B(')E<75I
M<F5D/2)F86QS92(@9&5S8STB5&AE(&YA;64@;V8@=&AE('-E<W-I;VX@=&%B
M;&4@:6X@=&AE(&1A=&%B87-E(%MH;W)D95]S97-S:6]N:&%N9&QE<ETB+SX*
M("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`\+V-A<V4^"B`@("`\8V%S92!N
M86UE/2)O8VDX(B!D97-C/2)/<F%C;&4@8F%S960@<V5S<VEO;G,B/@H@("`@
M(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@(#QC;VYF:6=B
M;V]L96%N(&YA;64](G!E<G-I<W1E;G0B(&1E<V,](E)E<75E<W0@<&5R<VES
M=&5N="!C;VYN96-T:6]N<S\B/@H@("`@("!F86QS93PO8V]N9FEG8F]O;&5A
M;CX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)H;W-T<W!E8R(@9&5S8STB
M1&%T86)A<V4@;F%M92!O<B!%87-Y($-O;FYE8W0*("`@("`@<&%R86UE=&5R
M(CYH;W)D93PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA
M;64](G5S97)N86UE(B!D97-C/2)7:&%T('5S97)N86UE(&1O('=E(&%U=&AE
M;G1I8V%T92!T;PH@("`@("!T:&4@9&%T86)A<V4@<V5R=F5R(&%S/R(^:&]R
M9&4\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)P
M87-S=V]R9"(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)7:&%T('!A<W-W;W)D
M(&1O('=E"B`@("`@(&%U=&AE;G1I8V%T92!T;R!T:&4@9&%T86)A<V4@<V5R
M=F5R('=I=&@_(B\^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB=&%B;&4B
M(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE(&YA;64@;V8@=&AE('-E<W-I
M;VX*("`@("`@=&%B;&4@:6X@=&AE(&1A=&%B87-E(%MH;W)D95]S97-S:6]N
M:&%N9&QE<ETB+SX*("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`\+V-A<V4^
M"B`@("`\8V%S92!N86UE/2)P9W-Q;"(@9&5S8STB4&]S=&=R95-13"!B87-E
M9"!S97-S:6]N<R(^"B`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US
M(CX*("`@("`@/&-O;F9I9V)O;VQE86X@;F%M93TB<&5R<VES=&5N="(@9&5S
M8STB4F5Q=65S="!P97)S:7-T96YT(&-O;FYE8W1I;VYS/R(^9F%L<V4\+V-O
M;F9I9V)O;VQE86X^"B`@("`@(#QC;VYF:6=S=VET8V@@;F%M93TB<')O=&]C
M;VPB(&1E<V,](E=H870@<')O=&]C;VP@=VEL;"!W92!U<V4@=&\@8V]N;F5C
M="!T;R!T:&4@9&%T86)A<V4_(CYU;FEX"B`@("`@("`\8V%S92!N86UE/2)U
M;FEX(B!D97-C/2)53DE8(%-O8VME=',B/@H@("`@("`@(#QC;VYF:6=S=')I
M;F<@;F%M93TB<V]C:V5T(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](DQO8V%T
M:6]N(&]F(%5.25@@<V]C:V5T(CX\+V-O;F9I9W-T<FEN9SX*("`@("`@(#PO
M8V%S93X*("`@("`@(#QC87-E(&YA;64](G1C<"(@9&5S8STB5$-0+TE0(CX*
M("`@("`@("`\8V]N9FEG:6YT96=E<B!N86UE/2)P;W)T(B!R97%U:7)E9#TB
M9F%L<V4B(&1E<V,](E!O<G0@=&AE($1"(&ES(')U;FYI;F<@;VXL(&EF(&YO
M;BUS=&%N9&%R9"(^-30S,CPO8V]N9FEG:6YT96=E<CX*("`@("`@(#PO8V%S
M93X*("`@("`@/"]C;VYF:6=S=VET8V@^"B`@("`@(#QC;VYF:6=S=')I;F<@
M;F%M93TB:&]S='-P96,B(&1E<V,](E=H870@:&]S=&YA;64@:7,@=&AE(&1A
M=&%B87-E('-E<G9E<B!R=6YN:6YG(&]N+"!O<B!W:&%T(&ES('1H92!N86UE
M(&]F('1H92!S>7-T96T@1%-.('1O('5S93\B/FQO8V%L:&]S=#PO8V]N9FEG
M<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G5S97)N86UE(B!D
M97-C/2)7:&%T('5S97)N86UE(&1O('=E(&%U=&AE;G1I8V%T92!T;R!T:&4@
M9&%T86)A<V4@<V5R=F5R(&%S/R(^:&]R9&4\+V-O;F9I9W-T<FEN9SX*("`@
M("`@/&-O;F9I9W-T<FEN9R!N86UE/2)P87-S=V]R9"(@<F5Q=6ER960](F9A
M;'-E(B!D97-C/2)7:&%T('!A<W-W;W)D(&1O('=E(&%U=&AE;G1I8V%T92!T
M;R!T:&4@9&%T86)A<V4@<V5R=F5R('=I=&@_(B\^"B`@("`@(#QC;VYF:6=S
M=')I;F<@;F%M93TB9&%T86)A<V4B(&1E<V,](E=H870@9&%T86)A<V4@;F%M
M92]T86)L97-P86-E(&%R92!W92!U<VEN9S\B/FAO<F1E/"]C;VYF:6=S=')I
M;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB=&%B;&4B(')E<75I<F5D
M/2)F86QS92(@9&5S8STB5&AE(&YA;64@;V8@=&AE('-E<W-I;VX@=&%B;&4@
M:6X@=&AE(&1A=&%B87-E(%MH;W)D95]S97-S:6]N:&%N9&QE<ETB+SX*("`@
M("`\+V-O;F9I9W-E8W1I;VX^"B`@("`\+V-A<V4^"B`@("`\8V%S92!N86UE
M/2)S87!D8B(@9&5S8STB57-E(%!%05(G<R!$0B!A8G-T<F%C=&EO;B!L87EE
M<B!W+T]$0D,B/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^
M"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB:&]S='-P96,B(&1E<V,](E=H
M870@:&]S=&YA;64@:7,@=&AE(&1A=&%B87-E('-E<G9E<B!R=6YN:6YG(&]N
M+"!O<B!W:&%T(&ES('1H92!N86UE(&]F('1H92!S>7-T96T@1%-.('1O('5S
M93\B/FQO8V%L:&]S=#PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R
M:6YG(&YA;64](G5S97)N86UE(B!D97-C/2)7:&%T('5S97)N86UE(&1O('=E
M(&%U=&AE;G1I8V%T92!T;R!T:&4@9&%T86)A<V4@<V5R=F5R(&%S/R(^:&]R
M9&4\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)P
M87-S=V]R9"(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)7:&%T('!A<W-W;W)D
M(&1O('=E(&%U=&AE;G1I8V%T92!T;R!T:&4@9&%T86)A<V4@<V5R=F5R('=I
M=&@_(B\^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB9&%T86)A<V4B(&1E
M<V,](E=H870@9&%T86)A<V4@;F%M92]T86)L97-P86-E(&%R92!W92!U<VEN
M9S\B/FAO<F1E/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@
M;F%M93TB=&%B;&4B(&1E<V,](E1H92!N86UE(&]F('1H92!S97-S:6]N('1A
M8FQE(&EN('1H92!D871A8F%S92(O/@H@("`@(#PO8V]N9FEG<V5C=&EO;CX*
M("`@(#PO8V%S93X*("`@(#QC87-E(&YA;64](G-Q;"(@9&5S8STB57-E(%!%
M05(G<R!$0B!A8G-T<F%C=&EO;B!L87EE<B(^"B`@("`@/&-O;F9I9W-E8W1I
M;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I9V)O;VQE86X@;F%M93TB
M<&5R<VES=&5N="(@9&5S8STB4F5Q=65S="!P97)S:7-T96YT(&-O;FYE8W1I
M;VYS/R(^9F%L<V4\+V-O;F9I9V)O;VQE86X^"B`@("`@(#QC;VYF:6=S=VET
M8V@@;F%M93TB<')O=&]C;VPB(&1E<V,](E=H870@<')O=&]C;VP@=VEL;"!W
M92!U<V4@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4_(CYU;FEX"B`@("`@
M("`\8V%S92!N86UE/2)U;FEX(B!D97-C/2)53DE8(%-O8VME=',B/@H@("`@
M("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<V]C:V5T(B!R97%U:7)E9#TB9F%L
M<V4B(&1E<V,](DQO8V%T:6]N(&]F(%5.25@@<V]C:V5T(CX\+V-O;F9I9W-T
M<FEN9SX*("`@("`@(#PO8V%S93X*("`@("`@(#QC87-E(&YA;64](G1C<"(@
M9&5S8STB5$-0+TE0(CX*("`@("`@("`\8V]N9FEG:6YT96=E<B!N86UE/2)P
M;W)T(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E!O<G0@=&AE($1"(&ES(')U
M;FYI;F<@;VXL(&EF(&YO;BUS=&%N9&%R9"(^-30S,CPO8V]N9FEG:6YT96=E
M<CX*("`@("`@(#PO8V%S93X*("`@("`@/"]C;VYF:6=S=VET8V@^"B`@("`@
M(#QC;VYF:6=S=')I;F<@;F%M93TB:&]S='-P96,B(&1E<V,](E=H870@:&]S
M=&YA;64@:7,@=&AE(&1A=&%B87-E('-E<G9E<B!R=6YN:6YG(&]N+"!O<B!W
M:&%T(&ES('1H92!N86UE(&]F('1H92!S>7-T96T@1%-.('1O('5S93\B/FQO
M8V%L:&]S=#PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA
M;64](G5S97)N86UE(B!D97-C/2)7:&%T('5S97)N86UE(&1O('=E(&%U=&AE
M;G1I8V%T92!T;R!T:&4@9&%T86)A<V4@<V5R=F5R(&%S/R(^:&]R9&4\+V-O
M;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)P87-S=V]R
M9"(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)7:&%T('!A<W-W;W)D(&1O('=E
M(&%U=&AE;G1I8V%T92!T;R!T:&4@9&%T86)A<V4@<V5R=F5R('=I=&@_(B\^
M"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB9&%T86)A<V4B(&1E<V,](E=H
M870@9&%T86)A<V4@;F%M92]T86)L97-P86-E(&%R92!W92!U<VEN9S\B/FAO
M<F1E/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB
M=&%B;&4B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE(&YA;64@;V8@=&AE
M('-E<W-I;VX@=&%B;&4@:6X@=&AE(&1A=&%B87-E(%MH;W)D95]S97-S:6]N
M:&%N9&QE<ETB+SX*("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`\+V-A<V4^
M"B`@("`\8V%S92!N86UE/2)M96UC86-H92(@9&5S8STB365M8V%C:&4@<V5R
M=F5R(CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@
M("`\8V]N9FEG;&ES="!N86UE/2)H;W-T<W!E8R(@9&5S8STB5VAA="!H;W-T
M;F%M92!I<R!T:&4@;65M8V%C:&4@<V5R=F5R"B`@("`@(')U;FYI;F<@;VXL
M(&]R('=H870@:7,@=&AE(&YA;64@;V8@=&AE('-Y<W1E;2!$4TX@=&\@=7-E
M/R`@4W!E8VEF>0H@("`@("!M=6QT:7!L92!S97)V97)S('-E<&%R871E9"!B
M>2!C;VUM87,N(CYL;V-A;&AO<W0\+V-O;F9I9VQI<W0^"B`@("`@(#QC;VYF
M:6=L:7-T(&YA;64](G!O<G0B(')E<75I<F5D/2)F86QS92(@9&5S8STB4&]R
M="AS*2!T:&4@;65M8V%C:&4*("`@("`@<V5R=F5R(&ES(')U;FYI;F<@;VXN
M($EF(&UO<F4@=&AA;B!O;F4@:&]S="!I<R!U<V5D+"!S<&5C:69Y('!O<G1S
M(&9O<@H@("`@("!R97-P96-T:79E('-E<G9E<G,L('-E<&%R871E9"!B>2!C
M;VUM87,B/C$Q,C$Q/"]C;VYF:6=L:7-T/@H@("`@("`\8V]N9FEG8F]O;&5A
M;B!N86UE/2)P97)S:7-T96YT(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E)E
M<75E<W0*("`@("`@<&5R<VES=&5N="!C;VYN96-T:6]N('1O('-E<G9E<BXB
M/F9A;'-E/"]C;VYF:6=B;V]L96%N/@H@("`@("`\8V]N9FEG8F]O;&5A;B!N
M86UE/2)C;VUP<F5S<VEO;B(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)%;F%B
M;&4*("`@("`@8V]M<')E<W-I;VX@9F]R('-T;W)I;F<@96YT<FEE<R!O;B!S
M97)V97(N(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*("`@("`@/&-O;F9I9W-T
M<FEN9R!N86UE/2)L;V-K7V1I<B(@9&5S8STB4W!E8VEF>2!A(&1I<F5C=&]R
M>2!T;R!W:&EC:"!T:&4*("`@("`@<V5S<VEO;B!L;V-K<R!S:&]U;&0@8F4@
M=W)I='1E;B(^+W1M<#PO8V]N9FEG<W1R:6YG/@H@("`@(#PO8V]N9FEG<V5C
M=&EO;CX*("`@(#PO8V%S93X*("`@/"]C;VYF:6=S=VET8V@^"B`@/"]C;VYF
M:6=S96-T:6]N/@H@/"]C;VYF:6=T86(^"@H@/&-O;F9I9W1A8B!N86UE/2)I
M;6%G92(@9&5S8STB26UA9V4@36%N:7!U;&%T:6]N(CX*("`\8V]N9FEG<V5C
M=&EO;B!N86UE/2)I;6%G92(^"B`@(#QC;VYF:6=H96%D97(^26UA9V4@36%N
M:7!U;&%T:6]N/"]C;VYF:6=H96%D97(^"B`@(#QC;VYF:6=S=')I;F<@;F%M
M93TB8V]N=F5R="(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)(;W)D92!R97%U
M:7)E<R!E:71H97(*("`@1T0@<W5P<&]R="!B=6EL="UI;B!T;R!02%`@*"TM
M=VET:"UG9"D@;W(@=&AE($EM86=E36%G:6-K('-O9G1W87)E"B`@('!A8VMA
M9V4@*&AT='`Z+R]W=W<N:6UA9V5M86=I8VLN;W)G+RD@=&\@9&\@:6UA9V4*
M("`@;6%N:7!U;&%T:6]N+V-R96%T:6]N+B!)9B!U<VEN9R!);6%G94UA9VEC
M:RP@<W!E8VEF>2!T:&4@9G5L;"!P871H"B`@(&YA;64@=&\@=&AE("=C;VYV
M97)T)R!P<F]G<F%M+B!/;B!7:6YD;W=S+"!T:&ES('!A=&@@*F-A;FYO="H@
M:&%V90H@("!S<&%C97,@:6X@:70N(%5S92!$3U,M<W1Y;&4@86)B<F5V:6%T
M:6]N<R!I9B!N96-E<W-A<GDZ(%!R;V=R87XQ"B`@(&EN<W1E860@;V8@4')O
M9W)A;2!&:6QE<RP@9F]R(&EN<W1A;F-E+B!)9B!U<VEN9R!'1"P@;W(@=7-I
M;F<*("`@;F5I=&AE<BP@;&5A=F4@=&AI<R!F:65L9"!B;&%N:RXB+SX*("`\
M+V-O;F9I9W-E8W1I;VX^"B`\+V-O;F9I9W1A8CX*"B`\8V]N9FEG=&%B(&YA
M;64](FUI;64B(&1E<V,](DU)344@1&5T96-T:6]N(CX*("`\8V]N9FEG<V5C
M=&EO;B!N86UE/2)M:6UE(CX*("`@/&-O;F9I9VAE861E<CY-24U%($1E=&5C
M=&EO;CPO8V]N9FEG:&5A9&5R/@H@("`\8V]N9FEG<W1R:6YG(&YA;64](FUA
M9VEC7V1B(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](DQO8V%T:6]N(&]F('1H
M92!-24U%"B`@(&UA9VEC(&1A=&%B87-E+B!5<W5A;&QY("]U<W(O<VAA<F4O
M;6ES8R]M86=I8R!O<B`O971C+VUA9VEC+B(O/@H@(#PO8V]N9FEG<V5C=&EO
M;CX*(#PO8V]N9FEG=&%B/@H*(#QC;VYF:6=T86(@;F%M93TB9V5O:7`B(&1E
M<V,](DAO<W1N86UE+29G=#M#;W5N=')Y($QO;VMU<"(^"B`@/&-O;F9I9W-E
M8W1I;VX@;F%M93TB9V5O:7`B/@H@("`\8V]N9FEG:&5A9&5R/DAO<W1N86UE
M+29G=#M#;W5N=')Y($QO;VMU<#PO8V]N9FEG:&5A9&5R/@H@("`\8V]N9FEG
M<W1R:6YG(&YA;64](F1A=&%F:6QE(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,]
M(DAO<F1E+"!B>2!D969A=6QT+"!C86X*("`@9&\@2&]S=&YA;64@+29G=#L@
M0V]U;G1R>2!L;V]K=7`@=7-I;F<@=&AE('1O<"!L979E;"!D;VUA:6X@*&4N
M9RX@)W5K)RP*("`@)V1E)RD@;V8@=&AE(&AO<W1N86UE+B`@2&]W979E<BP@
M;6%N>2!P;W!U;&%R('1O<"!L979E;"!D;VUA:6YS"B`@("AE+F<N("=C;VTG
M+"`G;F5T)RD@<W!A;B!M;W)E('1H86X@;VYE(&-O=6YT<GDN("!);B!T:&5S
M92!I;G-T86YC97,L($AO<F1E"B`@(&-A;B!U<V4@=&AE($UA>$UI;F0@1V5O
M25`@2&]S=&YA;64@=&\@0V]U;G1R>2!L;V]K=7`@=&\@=')Y('1O(&1E=&5R
M;6EN90H@("!T:&4@8V]R<F5C="!C;W5N=')Y+B`@5&\@86-T:79A=&4@=&AI
M<R!F=6YC=&EO;F%L:71Y+"!T:&4@1V5O25`N9&%T(&-O=6YT<GD*("`@9&%T
M86)A<V4@;75S="!B92!P<F5S96YT(&]N('EO=7(@;&]C86P@<WES=&5M+B`@
M5&AI<R!F:6QE(&-A;B!B92!D;W=N;&]A9&5D"B`@(&9R964@;V8@8VAA<F=E
M(&9R;VT@:'1T<#HO+W=W=RYM87AM:6YD+F-O;2]D;W=N;&]A9"]G96]I<"]D
M871A8F%S92\N("!)9@H@("!T:&ES(&1A=&%B87-E(&ES('!R97-E;G0L('-P
M96-I9GD@=&AE(&9U;&P@<&%T:"!N86UE('1O('1H92!D871A8F%S92!B96QO
M=RX*("`@268@96UP='DL('1H92!'96])4"!L;V]K=7`@=VEL;"!N;W0@8F4@
M<&5R9F]R;65D+B(O/@H@(#PO8V]N9FEG<V5C=&EO;CX*(#PO8V]N9FEG=&%B
M/@H*(#QC;VYF:6=T86(@;F%M93TB<')O8FQE;7,B(&1E<V,](E!R;V)L96T@
M4F5P;W)T:6YG(CX*("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P<F]B;&5M<R(^
M"B`@(#QC;VYF:6=H96%D97(^4')O8FQE;2!297!O<G1I;F<\+V-O;F9I9VAE
M861E<CX*("`@/&-O;F9I9W-W:71C:"!N86UE/2)T:6-K971S(B!D97-C/2))
M9B!A('1I8VME="!S>7-T96T@=VET:"!A"B`@('1I8VME=',O861D5&EC:V5T
M($%022!M971H;V0@:7,@<')E<V5N="P@<VAO=6QD('=E(&-R96%T92!T:6-K
M971S(&9O<@H@("!P<F]B;&5M(')E<&]R=',@:6YS=&5A9"!O9B!E;6%I;&EN
M9R!T:&5M/R(^9F%L<V4*("`@(#QC87-E(&YA;64](G1R=64B(&1E<V,](EEE
M<R(^"B`@("`@/&-O;F9I9W!H<"!N86UE/2)T:6-K971?<&%R86US(B!D97-C
M/2)%;G1E<B!A<R!A(%!(4"!A<G)A>2!A;GD*("`@("!A9&1I=&EO;F%L(&%R
M9W5M96YT<R!F;W(@=&AE(&-R96%T960@=&EC:V5T("AQ=65U92P@<W1A=&4L
M('!R:6]R:71Y+`H@("`@(&5T8RDN($5X86UP;&4@9F]R(%=H=7!S.B!A<G)A
M>2@G<75E=64G(#T^(#(L("=S=&%T92<@/3X@,2P@)W!R:6]R:71Y)R`]/B`Q
M+`H@("`@("=T>7!E)R`]/B`Q*2X@66]U('=I;&P@;F5E9"!T;R!L;V]K('5P
M('1H92!A<'!R;W!R:6%T92!)1',@:6X@5VAU<',G<PH@("`@(&1A=&%B87-E
M+"!O<B!W:&%T979E<B!I<R!A<'!R;W!R:6%T92!F;W(@=&AE('1I8VME="!S
M>7-T96T@>6]U(&%R90H@("`@('5S:6YG+B(^87)R87DH*3PO8V]N9FEG<&AP
M/@H@("`@/"]C87-E/@H@("`@/&-A<V4@;F%M93TB9F%L<V4B(&1E<V,](DYO
M(CX*("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F5M86EL(B!D97-C/2)7:&5R
M92!S:&]U;&0@<')O8FQE;2!R97!O<G0@96UA:6QS(&)E('-E;G0_(CX*("`@
M("!W96)M87-T97)`97AA;7!L92YC;VT\+V-O;F9I9W-T<FEN9SX*("`@("`\
M8V]N9FEG<W1R:6YG(&YA;64](FUA:6QD;VUA:6XB(&1E<V,](DEF($AO<F1E
M(&-A;FYO="!D971E<FUI;F4@82!U<V5R)W,*("`@("!E;6%I;"!A9&1R97-S
M+"!T:&ES(&1O;6%I;B!W:6QL(&)E(&%P<&5N9&5D('1O('1H96ER"B`@("`@
M=7-E<FYA;64N(CYE>&%M<&QE+F-O;3PO8V]N9FEG<W1R:6YG/@H@("`@(#QC
M;VYF:6=S=')I;F<@;F%M93TB=7-E<FYA;64B(')E<75I<F5D/2)F86QS92(@
M9&5S8STB268@<F5Q=6ER:6YG(%--5%`*("`@("!A=71H96YT:6-A=&EO;B!W
M:71H;W5T(&$@9VQO8F%L(%--5%`@=7-E<B`H:6X@<V5C=&EO;B`F<75O=#M-
M86EL97(F<75O=#L*("`@("!A;F0@86QL;W=I;F<@<')O8FQE;2!R97!O<G1I
M;F<@9F]R(&YO="!A=71H96YT:6-A=&5D('5S97)S("AI;B!S96-T:6]N"B`@
M("`@)G%U;W0[365N=2!3971T:6YG<R9Q=6]T.RDL('=H870@=7-E<FYA;64@
M<VAO=6QD(&)E('5S92!F;W(@4TU44`H@("`@(&%U=&AE;G1I8V%T:6]N/R(O
M/@H@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<&%S<W=O<F0B(')E<75I<F5D
M/2)F86QS92(@9&5S8STB5&AE('!A<W-W;W)D('1O('5S92(O/@H@("`@/"]C
M87-E/@H@("`\+V-O;F9I9W-W:71C:#X*("`\+V-O;F9I9W-E8W1I;VX^"B`\
M+V-O;F9I9W1A8CX*"B`\8V]N9FEG=&%B(&YA;64](FUE;G4B(&1E<V,](DUE
M;G4@4V5T=&EN9W,B/@H@(#QC;VYF:6=H96%D97(^365N=2!3971T:6YG<SPO
M8V]N9FEG:&5A9&5R/@H@(#QC;VYF:6=S96-T:6]N(&YA;64](FUE;G4B/@H@
M("`\8V]N9FEG;75L=&EE;G5M(&YA;64](F%P<',B(&1E<V,](E-E;&5C="!A
M;GD@87!P;&EC871I;VYS('1H870@<VAO=6QD(&)E"B`@(&QI;FME9"!I;B!(
M;W)D92=S(&UE;G4B/@H@("`@/'9A;'5E<SX*("`@("`\8V]N9FEG<W!E8VEA
M;"!N86UE/2)L:7-T+6AO<F1E+6%P<',B("\^"B`@("`\+W9A;'5E<SX*("`@
M/"]C;VYF:6=M=6QT:65N=6T^"@H@("`\8V]N9FEG8F]O;&5A;B!N86UE/2)A
M;'=A>7,B(&1E<V,](E-H;W5L9"!W90H@("`F;'0[<W1R;VYG)F=T.V%L=V%Y
M<R9L=#LO<W1R;VYG)F=T.R!D:7-P;&%Y('1H92!(;W)D90H@("!F<F%M97-E
M=#\B/F9A;'-E/"]C;VYF:6=B;V]L96%N/@H*("`@/&-O;F9I9W-E8W1I;VX@
M;F%M93TB;&EN:W,B/@H@("`@/&-O;F9I9V5N=6T@;F%M93TB:&5L<"(@9&5S
M8STB4VAO=6QD('=E(&1I<W!L87D@:&5L<"!L:6YK<R!I;B!T:&4*("`@(&UE
M;G4_(CYA;&P*("`@("`\=F%L=65S/@H@("`@("`\=F%L=64@9&5S8STB06QL
M('5S97)S(CYA;&P\+W9A;'5E/@H@("`@("`\=F%L=64@9&5S8STB075T:&5N
M=&EC871E9"!U<V5R<R(^875T:&5N=&EC871E9#PO=F%L=64^"B`@("`@(#QV
M86QU92!D97-C/2).979E<B(^;F5V97(\+W9A;'5E/@H@("`@(#PO=F%L=65S
M/@H@("`@/"]C;VYF:6=E;G5M/@H@("`@/&-O;F9I9V)O;VQE86X@;F%M93TB
M:&5L<%]A8F]U="(@9&5S8STB4VAO=6QD('=E(&1I<W!L87D@=&AE(&%B;W5T
M(&QI;FL@:6X*("`@('1H92!H96QP(&UE;G4_(CYT<G5E/"]C;VYF:6=B;V]L
M96%N/@H@("`@/&-O;F9I9V5N=6T@;F%M93TB;W!T:6]N<R(@9&5S8STB4VAO
M=6QD('=E(&1I<W!L87D@;W!T:6]N<R!L:6YK<R!I;B!T:&4*("`@(&UE;G4_
M(%EO=2!S=&EL;"!N965D('1O(&-O;F9I9W5R92!A('!R969E<F5N8V4@8F%C
M:V5N9"!I;B!T:&4*("`@("9Q=6]T.U!R969E<F5N8V4@4WES=&5M)G%U;W0[
M('-E8W1I;VXN(CYA=71H96YT:6-A=&5D"B`@("`@/'9A;'5E<SX*("`@("`@
M/'9A;'5E(&1E<V,](D%L;"!U<V5R<R(^86QL/"]V86QU93X*("`@("`@/'9A
M;'5E(&1E<V,](D%U=&AE;G1I8V%T960@=7-E<G,B/F%U=&AE;G1I8V%T960\
M+W9A;'5E/@H@("`@("`\=F%L=64@9&5S8STB3F5V97(B/FYE=F5R/"]V86QU
M93X*("`@("`\+W9A;'5E<SX*("`@(#PO8V]N9FEG96YU;3X*("`@(#QC;VYF
M:6=E;G5M(&YA;64](G!R;V)L96TB(&1E<V,](E-H;W5L9"!W92!D:7-P;&%Y
M('!R;V)L96T@<F5P;W)T:6YG(&QI;FMS"B`@("!I;B!T:&4@;65N=3\B/F%L
M;`H@("`@(#QV86QU97,^"B`@("`@(#QV86QU92!D97-C/2)!;&P@=7-E<G,B
M/F%L;#PO=F%L=64^"B`@("`@(#QV86QU92!D97-C/2)!=71H96YT:6-A=&5D
M('5S97)S(CYA=71H96YT:6-A=&5D/"]V86QU93X*("`@("`@/'9A;'5E(&1E
M<V,](DYE=F5R(CYN979E<CPO=F%L=64^"B`@("`@/"]V86QU97,^"B`@("`\
M+V-O;F9I9V5N=6T^"B`@("`\8V]N9FEG96YU;2!N86UE/2)L;V=I;B(@9&5S
M8STB4VAO=6QD('=E(&1I<W!L87D@82!L;V=I;B!L:6YK(&EN('1H92!M96YU
M"B`@("!W:&5N(&YO="!L;V=G960@:6X_(CYA;&P*("`@("`\=F%L=65S/@H@
M("`@("`\=F%L=64@9&5S8STB06QL('5S97)S(CYA;&P\+W9A;'5E/@H@("`@
M("`\=F%L=64@9&5S8STB3F5V97(B/FYE=F5R/"]V86QU93X*("`@("`\+W9A
M;'5E<SX*("`@(#PO8V]N9FEG96YU;3X*("`@(#QC;VYF:6=E;G5M(&YA;64]
M(FQO9V]U="(@9&5S8STB4VAO=6QD('=E(&1I<W!L87D@82!L;V=O=70@;&EN
M:R!I;B!T:&4*("`@(&UE;G4@=VAE;B!L;V=G960@:6X_(CYA=71H96YT:6-A
M=&5D"B`@("`@/'9A;'5E<SX*("`@("`@/'9A;'5E(&1E<V,](D%U=&AE;G1I
M8V%T960@=7-E<G,B/F%U=&AE;G1I8V%T960\+W9A;'5E/@H@("`@("`\=F%L
M=64@9&5S8STB3F5V97(B/FYE=F5R/"]V86QU93X*("`@("`\+W9A;'5E<SX*
M("`@(#PO8V]N9FEG96YU;3X*("`@(#QC;VYF:6=E;G5M(&YA;64](FQO9VEN
M(B!D97-C/2)3:&]U;&0@=V4@9&ES<&QA>2!A(&QO9VEN(&QI;FL@:6X@=&AE
M(&UE;G4*("`@('=H96X@;F]T(&QO9V=E9"!I;C\B/F%L;`H@("`@(#QV86QU
M97,^"B`@("`@(#QV86QU92!D97-C/2)!;&P@=7-E<G,B/F%L;#PO=F%L=64^
M"B`@("`@(#QV86QU92!D97-C/2).979E<B(^;F5V97(\+W9A;'5E/@H@("`@
M(#PO=F%L=65S/@H@("`@/"]C;VYF:6=E;G5M/@H@("`@/&-O;F9I9V5N=6T@
M;F%M93TB;&]G;W5T(B!D97-C/2)3:&]U;&0@=V4@9&ES<&QA>2!A(&QO9V]U
M="!L:6YK(&EN('1H90H@("`@;65N=2!W:&5N(&QO9V=E9"!I;C\B/F%U=&AE
M;G1I8V%T960*("`@("`\=F%L=65S/@H@("`@("`\=F%L=64@9&5S8STB075T
M:&5N=&EC871E9"!U<V5R<R(^875T:&5N=&EC871E9#PO=F%L=64^"B`@("`@
M(#QV86QU92!D97-C/2).979E<B(^;F5V97(\+W9A;'5E/@H@("`@(#PO=F%L
M=65S/@H@("`@/"]C;VYF:6=E;G5M/@H@("`\+V-O;F9I9W-E8W1I;VX^"B`@
M/"]C;VYF:6=S96-T:6]N/@H*("`\8V]N9FEG<V5C=&EO;B!N86UE/2)L;V=O
M(CX*("`@/&-O;F9I9W-T<FEN9R!N86UE/2)I;6%G92(@<F5Q=6ER960](F9A
M;'-E(B!D97-C/2)4:&4@55),(&]F(&%N(&EM86=E(&9O<@H@("!T:&4@=&]P
M(&]F('1H92!(;W)D92!M96YU+B!4:&4@:6UA9V4@<VAO=6QD(&)E(&YO(&QA
M<F=E<B!T:&%N(#$T,"!P:7AE;',*("`@=VED92!B>2`T,"!P:7AE;',@:&EG
M:"!T;R!P<F5V96YT('1H92!F<F%M92!F<F]M('-C<F]L;&EN9RXB+SX*("`@
M/&-O;F9I9W-T<FEN9R!N86UE/2)L:6YK(B!R97%U:7)E9#TB9F%L<V4B(&1E
M<V,](DEF(&$@;&]G;R!I<R!D:7-P;&%Y960@:6X*("`@=&AE($AO<F1E(&UE
M;G4L('=H870@55),("AI9B!A;GDI('-H;W5L9"!I="!L:6YK('1O/R(O/@H@
M(#PO8V]N9FEG<V5C=&EO;CX*(#PO8V]N9FEG=&%B/@H*(#QC;VYF:6=T86(@
M;F%M93TB:&]O:W,B(&1E<V,](D-U<W1O;2!&=6YC=&EO;B!(;V]K<R(^"B`@
M/&-O;F9I9W-E8W1I;VX@;F%M93TB:&]O:W,B/@H@("`\8V]N9FEG:&5A9&5R
M/D-U<W1O;2!&=6YC=&EO;B!(;V]K<SPO8V]N9FEG:&5A9&5R/@H@("`\8V]N
M9FEG9&5S8W)I<'1I;VX^"B`@("!4:&5R92!A<F4@97AA;7!L92!F=6YC=&EO
M;G,@9F]R(&%L;"!H;V]K<R!I;B!H;W)D92]C;VYF:6<O:&]O:W,N<&AP+F1I
M<W0N"B`@(#PO8V]N9FEG9&5S8W)I<'1I;VX^"B`@(#QC;VYF:6=B;V]L96%N
M(&YA;64](G!E<FUS9&5N:65D(B!D97-C/2))9B!T:&ES(&ES(&-H96-K960L
M('1H90H@("!F=6YC=&EO;B!?<&5R;7-?:&]O:U]D96YI960H*2!W:6QL(&)E
M(&-A;&QE9"!T;R!R971U<FX@86X@97)R;W(@;65S<V%G92!I9@H@("!A('!E
M<FUI<W-I;VX@:&%S(&)E96X@9&5N:65D+B!/=&AE<G=I<V4@82!S=&%N9&%R
M9"!M97-S86=E('=I;&P@8F4@<VAO=VX*("`@86YD('1H92!U<V5R('=O;B=T
M('-E92!A;GD@86-T:6]N('=I9&=E=',@=&AA="!H92!D;V5S;B=T(&AA=F4@
M86-C97-S"B`@('1O+B(^9F%L<V4\+V-O;F9I9V)O;VQE86X^"B`@(#QC;VYF
M:6=B;V]L96%N(&YA;64](G5S97)N86UE(B!D97-C/2))9B!T:&ES(&ES(&-H
M96-K960L('1H92!F=6YC=&EO;@H@("!?=7-E<FYA;65?:&]O:U]F<F]M8F%C
M:V5N9"@I('=I;&P@8F4@=7-E9"!T;R!S970@=&AE('5S97(@;F%M92!A="!L
M;V=I;@H@("!T:6UE+B!4:&4@8V]U;G1E<G!A<G0@9G5N8W1I;VX@7W5S97)N
M86UE7VAO;VM?=&]B86-K96YD*"D@=VEL;"!B92!U<V5D('1O"B`@(&-O;G9E
M<G0@=7-E<B!N86UE<R!B86-K+"!F;W(@97AA;7!L92!W:&5N('-H;W=I;F<@
M;F%M92!L:7-T<R!T;R!T:&4*("`@=7-E<BXB/F9A;'-E/"]C;VYF:6=B;V]L
M96%N/@H@("`\8V]N9FEG8F]O;&5A;B!N86UE/2)P<F5A=71H96YT:6-A=&4B
M(&1E<V,](DEF('1H:7,@:7,@8VAE8VME9"!A;F0@=&AE"B`@(&9U;F-T:6]N
M(%]H;W)D95]H;V]K7W!R96%U=&AE;G1I8V%T92@I(')E='5R;G,@9F%L<V4L
M(&%U=&AE;G1I8V%T:6]N('=I;&P*("`@9F%I;"XB/F9A;'-E/"]C;VYF:6=B
M;V]L96%N/@H@("`\8V]N9FEG8F]O;&5A;B!N86UE/2)P;W-T875T:&5N=&EC
M871E(B!D97-C/2))9B!T:&ES(&ES(&-H96-K960@86YD('1H90H@("!F=6YC
M=&EO;B!?:&]R9&5?:&]O:U]P;W-T875T:&5N=&EC871E*"D@<F5T=7)N<R!F
M86QS92P@875T:&5N=&EC871I;VX@=VEL;`H@("!F86EL+B(^9F%L<V4\+V-O
M;F9I9V)O;VQE86X^"B`@(#QC;VYF:6=B;V]L96%N(&YA;64](F%U=&AL9&%P
M(B!D97-C/2))9B!T:&ES(&ES(&-H96-K960L('1H92!F=6YC=&EO;@H@("!?
M:&]R9&5?:&]O:U]A=71H;&1A<"@I('=I;&P@8F4@=7-E9"!T;R!C<F5A=&4@
M86YD('-E="!T:&4@871T<FEB=71E<R!N965D960*("`@=&\@861D+V5D:70O
M9&5L971E('5S97)S(&)Y('1H92!,1$%0($%U=&@@9')I=F5R+B(^9F%L<V4\
M+V-O;F9I9V)O;VQE86X^"B`@/"]C;VYF:6=S96-T:6]N/@H@/"]C;VYF:6=T
M86(^"@H@/&-O;F9I9W1A8B!N86UE/2)B;&]C:R(@9&5S8STB4&]R=&%L($)L
M;V-K($-O;F9I9W5R871I;VXB/@H@(#QC;VYF:6=S96-T:6]N(&YA;64](G!O
M<G1A;"(^"B`@(#QC;VYF:6=H96%D97(^1FEX960@0FQO8VMS/"]C;VYF:6=H
M96%D97(^"B`@(#QC;VYF:6=M=6QT:65N=6T@;F%M93TB9FEX961?8FQO8VMS
M(B!M=6QD97-C/2)7:&EC:"!B;&]C:W,@<VAO=6QD(&%L=V%Y<R!B90H@("`@
M9&ES<&QA>65D(&EN('1H92!P;W)T86P_(CX*("`@(#QV86QU97,^"B`@("`@
M/&-O;F9I9W-P96-I86P@;F%M93TB;&ES="UB;&]C:W,B("\^"B`@("`\+W9A
M;'5E<SX*("`@/"]C;VYF:6=M=6QT:65N=6T^"B`@/"]C;VYF:6=S96-T:6]N
M/@H@(#QC;VYF:6=H96%D97(^=V5A=&AE<BYC;VT@0V]N9FEG=7)A=&EO;CPO
M8V]N9FEG:&5A9&5R/@H@(#QC;VYF:6=S96-T:6]N(&YA;64](G=E871H97)D
M;W1C;VTB/@H@("`\8V]N9FEG9&5S8W)I<'1I;VX^"B`@("!5<V4@;V8@=&AE
M('=E871H97(N8V]M(&)L;V-K(')E<75I<F5S(&9R964@<F5G:7-T<F%T:6]N
M(&9O<B!T:&4@6$U,"B`@("!F965D(&%T(&AT='`Z+R]W=W<N=V5A=&AE<BYC
M;VTO<V5R=FEC97,O>&UL;V%P+FAT;6PN"B`@("!!9G1E<B!R96=I<W1R871I
M;VXL(&%N(&5M86EL('=I;&P@8F4@<F5T=7)N960@=VET:"!T:&4@4&%R=&YE
M<B!)1"!A;F0*("`@(&QI8V5N<V4@:V5Y+B9L=#MB<B`O)F=T.PH@("`@3D]4
M13H@=V5A=&AE<BYC;VT@9W5I9&5L:6YE<R!R97%U:7)E(')E9VES=')A=&EO
M;B!A;F0@=7-E(&]F('1H92!R971U<FYE9`H@("`@=F%L=65S+"!B=70@=&AE
M(&%P<&QI8V%T:6]N(&%P<&5A<G,@=&\@9G5N8W1I;VX@=VET:"!A;GD@<W1R
M:6YG('9A;'5E<RX*("`@/"]C;VYF:6=D97-C<FEP=&EO;CX*("`@/&-O;F9I
M9W-T<FEN9R!N86UE/2)P87)T;F5R7VED(B!R97%U:7)E9#TB9F%L<V4B(&1E
M<V,](E1H92!P87)T;F5R($DN1"X*("`@9G)O;2!W96%T:&5R+F-O;2(O/@H@
M("`\8V]N9FEG<W1R:6YG(&YA;64](FQI8V5N<V5?:V5Y(B!R97%U:7)E9#TB
M9F%L<V4B(&1E<V,](E1H92!L:6-E;G-E(&ME>0H@("!F<F]M('=E871H97(N
M8V]M(B\^"B`@/"]C;VYF:6=S96-T:6]N/@H*("`\8V]N9FEG:&5A9&5R/D9O
M<G1U;F4@0V]N9FEG=7)A=&EO;CPO8V]N9FEG:&5A9&5R/@H@(#QC;VYF:6=S
M96-T:6]N(&YA;64](F9O<G1U;F4B/@H@("`\8V]N9FEG<W1R:6YG(&YA;64]
M(F5X96-?<&%T:"(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)0871H('1O(&9O
M<G1U;F4*("`@97AE8W5T86)L92P@92YG+B`O=7-R+V=A;65S+V9O<G1U;F4B
M+SX*("`\+V-O;F9I9W-E8W1I;VX^"@H@(#QC;VYF:6=H96%D97(^06-C;W5N
M="!);F9O($-O;F9I9W5R871I;VX\+V-O;F9I9VAE861E<CX*("`\8V]N9FEG
M<V5C=&EO;B!N86UE/2)A8V-O=6YT<R(^"B`@(#QC;VYF:6=S=VET8V@@;F%M
M93TB9')I=F5R(B!D97-C/2)7:&%T("!D<FEV97(@<VAO=6QD('=E('5S93\B
M/FYU;&P*("`@(#QC87-E(&YA;64](FYU;&PB(&1E<V,](FYU;&PB+SX*("`@
M(#QC87-E(&YA;64](FQO8V%L:&]S="(@9&5S8STB;&]C86QH;W-T(CX*("`@
M("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`\8V]N9FEG
M<W1R:6YG(&YA;64](G%U;W1A7W!A=&@B(&1E<V,](E!A=&@@=&\@=&AE('%U
M;W1A('!R;V=R86TB/B]U<W(O8FEN+W%U;W1A/"]C;VYF:6=S=')I;F<^"B`@
M("`@(#QC;VYF:6=S=')I;F<@;F%M93TB9W)E<%]P871H(B!D97-C/2)0871H
M('1O('1H92!G<F5P('!R;V=R86TB/B]B:6XO9W)E<#PO8V]N9FEG<W1R:6YG
M/@H@("`@("`\8V]N9FEG8F]O;&5A;B!N86UE/2)T<F%N<VQA=&5-;W5N=%!O
M:6YT(B!D97-C/2)3:&]U;&0@=V4@=')A;G-L871E(&AO;64@9&ER96-T;W)I
M97,@=&\@;6]U;G0@<&]I;G0@9&5V:6-E(&YA;65S/R(^9F%L<V4\+V-O;F9I
M9V)O;VQE86X^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB=')A;G-L871I
M;VY486)L92(@9&5S8STB1FEL92!T;R!T<F%N<VQA=&4@9&ER96-T;W)Y(&YA
M;65S('1O(&UO=6YT('!O:6YT(&1E=FEC92!N86UE<S\B/B]E=&,O;71A8CPO
M8V]N9FEG<W1R:6YG/@H@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@(#PO8V%S
M93X*("`@(#QC87-E(&YA;64](FQD87`B(&1E<V,](DQ$05`B/@H@("`@(#QC
M;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@(#QC;VYF:6=S=')I
M;F<@;F%M93TB:&]S="(@9&5S8STB3$1!4"!S97)V97(O:&]S="(^;&]C86QH
M;W-T/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=I;G1E9V5R(&YA;64]
M(G!O<G0B(')E<75I<F5D/2)F86QS92(@9&5S8STB4&]R="!,1$%0(&ES(')U
M;FYI;F<@;VXL(&EF(&YO;BUS=&%N9&%R9"(^,S@Y/"]C;VYF:6=I;G1E9V5R
M/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F)A<V5D;B(@9&5S8STB8F%S
M961N('-T<FEN9R(^;SUE>&%M<&QE+F-O;2QC/553/"]C;VYF:6=S=')I;F<^
M"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB871T<B(@9&5S8STB3$1!4"!A
M='1R:6)U=&4@=&\@<V5A<F-H(&]N(CYU:60\+V-O;F9I9W-T<FEN9SX*("`@
M("`@/&-O;F9I9V5N=6T@;F%M93TB=F5R<VEO;B(@9&5S8STB3$1!4"!0<F]T
M;V-O;"!697)S:6]N(CXS"B`@("`@("`\=F%L=65S/@H@("`@("`@(#QV86QU
M92!D97-C/2),1$%0=C(@*$1E<')E8V%T960I(CXR/"]V86QU93X*("`@("`@
M("`\=F%L=64@9&5S8STB3$1!4'8S(CXS/"]V86QU93X*("`@("`@(#PO=F%L
M=65S/@H@("`@("`\+V-O;F9I9V5N=6T^"B`@("`@/"]C;VYF:6=S96-T:6]N
M/@H@("`@/"]C87-E/@H@("`\+V-O;F9I9W-W:71C:#X*("`\+V-O;F9I9W-E
M8W1I;VX^"B`\+V-O;F9I9W1A8CX*(#QC;VYF:6=T86(@;F%M93TB:6US<"(@
M9&5S8STB24U34"!S97)V97(@<V5T=&EN9W,B/@H@(#QC;VYF:6=S96-T:6]N
M(&YA;64](FEM<W`B/@H@("`\8V]N9FEG9&5S8W)I<'1I;VX^"B`@(`E)9B!Y
M;W4@<&QA;B!T;R!U<V4@86YY(&]F($AO<F1E)W,@24U34"!S97)V97(@<W5P
M<&]R="P@96YA8FQE('1H:7,@;W!T:6]N(&%N9`H@("`)8V]N9FEG=7)E('1H
M92!S97)V97(@<V5T=&EN9W,@8F5L;W<N("!.;W1E('1H870@>6]U(&UU<W0@
M<W1I;&P@8V]N9FEG=7)E+V5N86)L90H@("`)<W!E8VEF:6,@24U34"!S=7!P
M;W)T(&EN('1H92!A<'!R;W!R:6%T92!S96-T:6]N+@H@("`\+V-O;F9I9V1E
M<V-R:7!T:6]N/@H@("`\8V]N9FEG<W=I=&-H(&YA;64](F5N86)L960B/F9A
M;'-E"B`@("`\8V%S92!N86UE/2)F86QS92(@9&5S8STB1&ES86)L960B("\^
M"B`@("`\8V%S92!N86UE/2)T<G5E(B!D97-C/2)%;F%B;&5D(CX*("`@("`\
M8V]N9FEG:&5A9&5R/DE-4U`@4V5R=F5R(%-E='1I;F=S/"]C;VYF:6=H96%D
M97(^"B`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)S97)V97(B(&1E<V,](E-E
M<G9E<B!!9&1R97-S.B(^;&]C86QH;W-T/"]C;VYF:6=S=')I;F<^"B`@("`@
M/&-O;F9I9W-T<FEN9R!N86UE/2)P;W)T(B!D97-C/2)397)V97(@<&]R=#HB
M/C0P-CPO8V]N9FEG<W1R:6YG/@H@("`@(#QC;VYF:6=S=VET8V@@;F%M93TB
M875T:%]M971H;V0B(&1E<V,](E1H92!A=71H96YT:6-A=&EO;B!M971H;V0@
M=&\@=7-E(CYP;&%I;G1E>'0*("`@("`@/&-A<V4@;F%M93TB<&QA:6YT97AT
M(B!D97-C/2)0;&%I;G1E>'0B("\^"B`@("`@(#QC87-E(&YA;64](F-R86U?
M;60U(B!D97-C/2)#4D%-+4U$-2(@+SX*("`@("`@/&-A<V4@;F%M93TB:6UT
M97-T(B!D97-C/2)#>7)U<R!I;71E<W0B/@H@("`@("`@/&-O;F9I9W-T<FEN
M9R!N86UE/2)S;V-K970B(&1E<V,](E!A=&@@=&\@=&AE(&1I<F5C=&]R>2!T
M:&%T('=I;&P@:&]L9"!T:&4@<V]C:V5T+@H@("`@("`@*%1H92!S;V-K970@
M=VEL;"!B92!N86UE9"`G:6US<%]U<V5R;F%M92YS8VLG*2XB/B]T;7`O/"]C
M;VYF:6=S=')I;F<^"B`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F-O;6UA
M;F0B(&1E<V,](E!A=&@@=&\@:6UT97-T(&)I;F%R>2(^+V-Y<G5S+W5S<B]C
M>7)U<R]B:6XO:6UT97-T/"]C;VYF:6=S=')I;F<^"B`@("`@("`\8V]N9FEG
M96YU;2!N86UE/2)A=71H7VUE8VAA;FES;2(@9&5S8W)I<'1I;VX](E=H870@
M875T:&5N=&EC871I;VX@;65T:&]D(&1O('EO=2!W86YT"B`@("`@("!T;R!U
M<V4@=VET:"!T:&4@:6UT97-T('5T:6QI='D_(CX*("`@("`@("`\=F%L=65S
M/@H@("`@("`@("`\=F%L=64@9&5S8STB4&QA:6YT97AT("A,3T=)3BDB/DQ/
M1TE./"]V86QU93X*("`@("`@("`@/'9A;'5E(&1E<V,](D=34T%022(^9W-S
M87!I/"]V86QU93X*("`@("`@("`\+W9A;'5E<SX*("`@("`@(#PO8V]N9FEG
M96YU;3X*("`@("`@/"]C87-E/@H@("`@(#PO8V]N9FEG<W=I=&-H/@H@("`@
M/"]C87-E/@H@("`\+V-O;F9I9W-W:71C:#X*("`\+V-O;F9I9W-E8W1I;VX^
M"B`\+V-O;F9I9W1A8CX*"B`\8V]N9FEG=&%B(&YA;64](FMO;&%B(B!D97-C
M/2)+;VQA8B!'<F]U<'=A<F4@4V5R=F5R(CX*("`\8V]N9FEG<V5C=&EO;B!N
M86UE/2)K;VQA8B(^"B`@(#QC;VYF:6=D97-C<FEP=&EO;CX*("`@("9L=#MS
M=')O;F<F9W0[*BHJ($E&(%E/52!(059%($Y/($E$14$@5TA!5"!+3TQ!0B!)
M4R!42$5.(%E/52!#04X@4T%&14Q9"B`@("!)1TY/4D4@5$A)4R!404(@*BHJ
M)FQT.R]S=')O;F<F9W0[)FQT.V)R("\F9W0["B`@("!+;VQA8B!I<R!I;B!N
M;R!W87D@<F5Q=6ER960@9F]R(&YO<FUA;"!(;W)D92!U<V%G92X@268L(&AO
M=V5V97(L('EO=0H@("`@:6YT96YD('1O('5S92!(;W)D92!A<R!A('=E8F-L
M:65N="!F;W(@2V]L86(@=&AE;B!Y;W4@=VEL;"!N965D('1O(&5N<W5R90H@
M("`@=&AA="!T:&4@9F]L;&]W:6YG(&9I96QD<R!C;W)R97-P;VYD('1O('1H
M;W-E(')E<75I<F5D(&)Y('EO=7(@2V]L86(*("`@(&EN<W1A;&QA=&EO;BX@
M(%EO=2!C86X@9FEN9"!S;VUE(&]F('1H92!R97%U:7)E9"!V86QU97,@:6X@
M=&AE"B`@("`F;'0[8V]D929G=#L@)$M/3$%"7U)/3U0O971C+VMO;&%B+VMO
M;&%B+F-O;F8F;'0[+V-O9&4F9W0[(&-O;F9I9W5R871I;VX*("`@(&9I;&4N
M(%!L96%S92!N;W1E('1H870@=&AE(&]L9"!I0V%L+W9#87)D('-T;W)A9V4@
M9F]R;6%T(&AA<R!B965N(&1R;W!P960*("`@(&EN(&9A=F]U<B!O9B!T:&4@
M;F5W(%A-3"!S=&]R86=E(&9O<FUA="`F86UP.V%M<#L@24U!4"!F;VQD97(@
M86YN;W1A=&EO;G,["B`@("!S=6)S97%U96YT;'D@=&AE($AO<F1E($MO;&%B
M(&UO9'5L97,@=VEL;"!O;FQY('=O<FL@=VET:"!V97)S:6]N(#(@;V8@=&AE
M"B`@("!+;VQA8B!S97)V97(N)FQT.V)R("\F9W0["B`@("!)9B!Y;W4@=V]U
M;&0@;&EK92!T;R!F:6YD(&]U="!M;W)E(&%B;W5T($MO;&%B('1H96X@<&QE
M87-E('9I<VET('1H92!+;VQA8@H@("`@8V]M;75N:71Y('=E8G-I=&4@870@
M:'1T<#HO+W=W=RYK;VQA8BYO<F<O"B`@(#PO8V]N9FEG9&5S8W)I<'1I;VX^
M"B`@(#QC;VYF:6=S=VET8V@@;F%M93TB96YA8FQE9"(@<75O=&4](F9A;'-E
M(B!D97-C/2)(;W)D92]+;VQA8B!I;G1E9W)A=&EO;@H@("`@<W1A='5S(CYF
M86QS90H@("`@/&-A<V4@;F%M93TB9F%L<V4B(&1E<V,](D1I<V%B;&5D(B`O
M/@H@("`@/&-A<V4@;F%M93TB=')U92(@9&5S8STB16YA8FQE9"(^"B`@("`@
M/&-O;F9I9VAE861E<CY+;VQA8B!,1$%0(%-E<G9E<B!3971T:6YG<SPO8V]N
M9FEG:&5A9&5R/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](FQD87`B/@H@
M("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G-E<G9E<B(@9&5S8STB4V5R=F5R
M"B`@("`@(&%D9')E<W,Z(CYL;V-A;&AO<W0\+V-O;F9I9W-T<FEN9SX*("`@
M("`@/&-O;F9I9VEN=&5G97(@;F%M93TB<&]R="(@9&5S8STB4V5R=F5R('!O
M<G0Z(CXS.#D\+V-O;F9I9VEN=&5G97(^"B`@("`@(#QC;VYF:6=S=')I;F<@
M;F%M93TB8F%S961N(B!D97-C/2)"87-E($1..B(^9&,]97AA;7!L92P*("`@
M("`@9&,]8V]M/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@
M;F%M93TB8FEN9&1N(B!D97-C/2)":6YD($1..B(^8VX];6%N86=E<BP@8VX]
M:6YT97)N86PL"B`@("`@(&1C/65X86UP;&4L(&1C/6-O;3PO8V]N9FEG<W1R
M:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F)I;F1P=R(@9&5S8STB
M0FEN9"!087-S=V]R9#HB/G!A<W-W;W)D/"]C;VYF:6=S=')I;F<^"B`@("`@
M(#QC;VYF:6=S=')I;F<@;F%M93TB<&AP9&XB(&1E<V,](E-E87)C:"!$3CHB
M/F-N/6YO8F]D>2P@8VX]:6YT97)N86PL"B`@("`@(&1C/65X86UP;&4L(&1C
M/6-O;3PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64]
M(G!H<'!W(B!D97-C/2)396%R8V@*("`@("`@4&%S<W=O<F0Z(CYP87-S=V]R
M9#PO8V]N9FEG<W1R:6YG/@H@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@("`\
M8V]N9FEG:&5A9&5R/DMO;&%B($-Y<G5S($E-05`@4V5R=F5R(%-E='1I;F=S
M/"]C;VYF:6=H96%D97(^"B`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB:6UA
M<"(^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<V5R=F5R(B!D97-C/2)3
M97)V97(*("`@("`@861D<F5S<SHB/FUA:6PN97AA;7!L92YC;VT\+V-O;F9I
M9W-T<FEN9SX*("`@("`@/&-O;F9I9VEN=&5G97(@;F%M93TB<&]R="(@9&5S
M8STB4V5R=F5R('!O<G0Z(CXQ-#,\+V-O;F9I9VEN=&5G97(^"B`@("`@(#QC
M;VYF:6=I;G1E9V5R(&YA;64](G-I979E<&]R="(@9&5S8STB4VEE=F4@<&]R
M=#HB/C(P,#`\+V-O;F9I9VEN=&5G97(^"B`@("`@(#QC;VYF:6=S=')I;F<@
M;F%M93TB;6%I;&1O;6%I;B(@9&5S8STB1&5F875L=`H@("`@("!M86EL9&]M
M86EN.B(^97AA;7!L92YC;VT\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I
M9W-T<FEN9R!N86UE/2)A9&UI;G5S97(B(&1E<V,](D%D;6EN:7-T<F%T;W(*
M("`@("`@=7-E<CHB/FUA;F%G97(\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O
M;F9I9W-T<FEN9R!N86UE/2)A9&UI;G!W(B!D97-C/2)!9&UI;FES=')A=&]R
M"B`@("`@('!A<W-W;W)D.B(^<&%S<W=O<F0\+V-O;F9I9W-T<FEN9SX*("`@
M("`@/&-O;F9I9V)O;VQE86X@;F%M93TB=FER=&1O;6%I;G,B(&1E<V,](E9I
M<G1U86P*("`@("`@9&]M86EN<SHB/G1R=64\+V-O;F9I9V)O;VQE86X^"B`@
M("`@/"]C;VYF:6=S96-T:6]N/@H@("`\8V]N9FEG8F]O;&5A;B!N86UE/2)G
M<F]U<&QD87`B(&1E<V,](DEF('1H:7,@:7,@8VAE8VME9"P@=&AE(&9U;F-T
M:6]N"B`@(%]H;W)D95]H;V]K7V=R;W5P;&1A<"@I('=I;&P@8F4@=7-E9"!T
M;R!C<F5A=&4@86YD('-E="!T:&4@871T<FEB=71E<R!N965D960*("`@=&\@
M861D+V5D:70O9&5L971E(&=R;W5P<R!B>2!T:&4@3$1!4"!'<F]U<"!D<FEV
M97(N(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*("`@("`\8V]N9FEG:&5A9&5R
M/DMO;&%B(%--5%`@4V5R=F5R(%-E='1I;F=S/"]C;VYF:6=H96%D97(^"B`@
M("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<VUT<"(^"B`@("`@(#QC;VYF:6=S
M=')I;F<@;F%M93TB<V5R=F5R(B!D97-C/2)397)V97(*("`@("`@861D<F5S
M<SHB/FQO8V%L:&]S=#PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG:6YT
M96=E<B!N86UE/2)P;W)T(B!D97-C/2)397)V97(@<&]R=#HB/C(U/"]C;VYF
M:6=I;G1E9V5R/@H@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@(#PO8V%S93X*
M("`@/"]C;VYF:6=S=VET8V@^"B`@/"]C;VYF:6=S96-T:6]N/@H@/"]C;VYF
M:6=T86(^"CPO8V]N9FEG=7)A=&EO;CX*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]E=&,O<'-A+6AO<F1E+VAO<F1E+RYH=&%C8V5S
M<P``````````````````````````````````````````````````````````
M`````````````````#`P,#0T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M,#$V(#$P-3$U-#,S-S4T(#`R,3(P-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!$96YY(&9R;VT@86QL"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O=&UP````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S
M,S<U-"`P,30T,#$`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]T;7`O:&]T9FEX+3@P,#8Q,#$X+C(P
M````````````````````````````````````````````````````````````
M`````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,#`P(#$P-3$U-#,S-S4T(#`Q-S`R-P`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W1M<"]H
M;W1F:7@M.#`P-C$P,3@N,C`O9FEL96QI<W0`````````````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`T,S$U,#,@,3`U,34T,S,W-30@,#(P-C4R
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"1[
M4%)/1%5#5%]23T]47T1]+V%D;6EN+VAT9&]C<R]S:VEN<R]A<75A+F-O;7!A
M8W0O8W-S+VEE+F-S<R!R;V]T(#`@,#8T-`HD>U!23T150U1?4D]/5%]$?2]A
M9&UI;B]H=&1O8W,O<VMI;G,O<&QE<VLN<V5A+V-S<R]I92YC<W,@<F]O="`P
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO861M:6XO:'1D;V-S+W-K:6YS+V%Q
M=6$O8W-S+VEE+F-S<R!R;V]T(#`@,#8T-`HD>U!23T150U1?4D]/5%]$?2]A
M9&UI;B]H=&1O8W,O<VMI;G,O<&QE<VLN<VEL=F5R+V-S<R]I92YC<W,@<F]O
M="`P(#`V-#0*)'M04D]$54-47U)/3U1?1'TO861M:6XO:'1D;V-S+W-K:6YS
M+VQO;F=H;W)N+F%E<F\O8W-S+VEE+F-S<R!R;V]T(#`@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]A9&UI;B]H=&1O8W,O<VMI;G,O<&QE<VLN=FEO;&5T+V-S
M<R]I92YC<W,@<F]O="`P(#`V-#0*)'M04D]$54-47U)/3U1?1'TO861M:6XO
M:'1D;V-S+W-K:6YS+VQO;F=H;W)N+F)L86-K+V-S<R]I92YC<W,@(')O;W0@
M,"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+V%D;6EN+VAT9&]C<R]S:VEN<R]W
M:6YX<"YB;'5E+V-S<R]I92YC<W,@("`@("!R;V]T(#`@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]A9&UI;B]H=&1O8W,O<VMI;G,O;&]N9VAO<FXN>65L;&]W
M+V-S<R]I92YC<W,@<F]O="`P(#`V-#0*)'M04D]$54-47U)/3U1?1'TO861M
M:6XO:'1D;V-S+W-K:6YS+W=I;GAP+FYE=RYC;VUP86-T+V-S<R]I92YC<W,@
M("`@("`@<F]O="`P(#`V-#0*)'M04D]$54-47U)/3U1?1'TO861M:6XO:'1D
M;V-S+W-K:6YS+W!L97-K."YN97<O8W-S+VEE+F-S<R`@("`@(')O;W0@,"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+V%D;6EN+VAT9&]C<R]S:VEN<R]W:6YX
M<"YN97<O8W-S+VEE+F-S<R`@("`@("!R;V]T(#`@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]A9&UI;B]H=&1O8W,O<VMI;G,O<&QE<VLN8FQU92]C<W,O:64N
M8W-S("`@("`@<F]O="`P(#`V-#0*)'M04D]$54-47U)/3U1?1'TO861M:6XO
M:'1D;V-S+W-K:6YS+W=I;GAP+F]L:79E9W)E96XO8W-S+VEE+F-S<R`@("`@
M("`@<F]O="`P(#`V-#0*)'M04D]$54-47U)/3U1?1'TO861M:6XO:'1D;V-S
M+W-K:6YS+W!L97-K+F-L87-S:6,N<VEL=F5R+V-S<R]I92YC<W,@(')O;W0@
M,"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+V%D;6EN+VAT9&]C<R]S:VEN<R]W
M:6YX<"YS:6QV97(O8W-S+VEE+F-S<R`@("!R;V]T(#`@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]A9&UI;B]H=&1O8W,O<VMI;G,O<&QE<VLN;F%T=7)E+V-S
M<R]I92YC<W,@("`@<F]O="`P(#`V-#0*)'M04D]$54-47U)/3U1?1'TO861M
M:6XO<&QI8B]C;VUM;VY?9G5N8RYP:'`S(')O;W0@,"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+V%D;6EN+W-B:6XO9FEL96UN9R!R;V]T('!S86%D;2`P-34P
M"B1[4%)/1%5#5%]23T]47T1]+V%D;6EN+W!L:6(O8VQA<W,N0VAE8VME<BYP
M:'`@<F]O="`P(#`V-#0*)'M04D]$54-47U)/3U1?1'TO861M:6XO<&QI8B]C
M;&%S<RY&:6QE36%N86=E<BYP:'`@<F]O="`P(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO861M:6XO<&QI8B]L;V-A;&5S+V5N+553+VUE<W-A9V5S7V5N+553
M+G!H<"!R;V]T(#`@,#8T-`HD>U!23T150U1?4D]/5%]$?2]A9&UI;B]H=&1O
M8W,O9FEL96UA;F%G97(O9FEL96UA;F%G97(N<&AP(')O;W0@,"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U-E<G9I8V5S+U=E871H
M97(O16IS92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+U-E<G9I8V5S+U=E871H97(O1VQO8F%L=V5A=&AE
M<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+U-E<G9I8V5S+U=E871H97(O365T87(N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]397)V
M:6-E<R]796%T:&5R+U=E871H97)D;W1C;VTN<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]397)V:6-E<R]7
M96%T:&5R+T-O;6UO;BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+U-E<G9I8V5S+U=E871H97(N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A
M<B]!<F-H:79E+U1A<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+T%U=&@O4T%33"]#;VUM;VXN<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A
M<B]!=71H+U-!4TPO0W)A;4U$-2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+T%U=&@O4T%33"]$:6=E<W1-
M1#4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]!=71H+U-!4TPO3&]G:6XN<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]!=71H+U-!4TPO
M4&QA:6XN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]!=71H+U-!4TPO06YO;GEM;W5S+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O075T
M:"]305-,+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O0V%C:&4O0V]N=&%I;F5R+V1B+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O0V%C
M:&4O0V]N=&%I;F5R+VUD8BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+T-A8VAE+T-O;G1A:6YE<B]F:6QE
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O0V%C:&4O0V]N=&%I;F5R+VUS97-S:6]N+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O0V%C
M:&4O0V]N=&%I;F5R+W!H<&QI8BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+T-A8VAE+T-O;G1A:6YE<B]S
M:&TN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]#86-H92]#;VYT86EN97(O=')I9FEL92YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+T-A
M8VAE+T-O;G1A:6YE<B]D8G@N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]#86-H92]%<G)O<BYP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+T-A8VAE+T9U;F-T:6]N+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O0V%C:&4O1W)A<&AI8W,N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A
M<B]#86-H92](5%107U)E<75E<W0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]#86-H92]/=71P=70N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]#86-H92]/=71P=71#;VUP<F5S<VEO;BYP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+T-A8VAE+T-O
M;G1A:6YE<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+T-A8VAE+T%P<&QI8V%T:6]N+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O0V]N
M<V]L92]'971O<'0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+TA45%!?4F5Q=65S="]D;V-S+V5X
M86UP;&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]D;V-S+TA45%!?4F5Q=65S="]D;V-S+V1O=VYL;V%D
M+7!R;V=R97-S+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]$0B]D;V,O34%)3E1!24Y%4E,)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+V1O8W,O1$(O9&]C+U-405154PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]$0B]D;V,O5$535$524PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O9&]C<R]$0B]D;V,O241%05,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O3F5T7U--5%`O9&]C<R]E
M>&%M<&QE<R]B87-I8RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O3F5T7U--5%`O9&]C<R]G=6ED
M92YT>'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+V1O8W,O6$U,7U!A<G-E<B]E>&%M<&QE<R]X;6Q?<&%R<V5R
M7V9I;&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]087)S97(O97AA;7!L97,O>&UL7W!A
M<G-E<E]H86YD;&5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4&%R<V5R+V5X86UP;&5S
M+WAM;%]P87)S97)?<VEM<&QE,2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U!A<G-E<B]E
M>&%M<&QE<R]X;6Q?<&%R<V5R7W-I;7!L93$N>&UL"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]0
M87)S97(O97AA;7!L97,O>&UL7W!A<G-E<E]S:6UP;&4R+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C
M<R]834Q?4&%R<V5R+V5X86UP;&5S+WAM;%]P87)S97)?<VEM<&QE,BYX;6P)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+V1O8W,O6$U,7U!A<G-E<B]E>&%M<&QE<R]X;6Q?<&%R<V5R7W-I;7!L
M95]H86YD;&5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4&%R<V5R+V5X86UP;&5S+WAM
M;%]P87)S97)?9FEL92YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O3&]G+V1O8W,O97AA;7!L97,O
M8V]M<&]S:71E+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O9&]C<R],;V<O9&]C<R]E>&%M<&QE<R]D:7-P
M;&%Y+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O9&]C<R],;V<O9&]C<R]E>&%M<&QE<R]E<G)O<E]L;V<N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<&5A<B]D;V-S+TQO9R]D;V-S+V5X86UP;&5S+V9I;&4N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D
M;V-S+TQO9R]D;V-S+V5X86UP;&5S+VUA:6PN<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO9R]D
M;V-S+V5X86UP;&5S+VYU;&PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO9R]D;V-S+V5X86UP
M;&5S+V]B<V5R=F5R7VUA:6PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO9R]D;V-S+V5X86UP
M;&5S+W!E87)?97)R;W)?:&%N9&QE<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O3&]G+V1O8W,O
M97AA;7!L97,O<&AP7V5R<F]R7VAA;F1L97(N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO9R]D
M;V-S+V5X86UP;&5S+W-Q;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O3&]G+V1O8W,O97AA;7!L
M97,O<W%L:71E+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O9&]C<R],;V<O9&]C<R]E>&%M<&QE<R]S>7-L
M;V<N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]D;V-S+TQO9R]D;V-S+V5X86UP;&5S+W=I;BYP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+V1O8W,O3&]G+V1O8W,O97AA;7!L97,O8V]N<V]L92YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O
M3&]G+V1O8W,O9W5I9&4N='AT"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+T1A=&4O3$E#14Y310ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M9&]C<R]$871E+U1/1$\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]P96%R+V1O8W,O3F5T7U523"]D;V-S+V5X86UP;&4N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<&5A<B]D;V-S+T%R8VAI=F5?5&%R+V1O8W,O07)C:&EV95]487(N='AT
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]D;V-S+U-E<G9I8V5S7U=E871H97(O97AA;7!L97,O;65T87(M8F%S
M:6,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]D;V-S+U-E<G9I8V5S7U=E871H97(O97AA;7!L97,O;65T
M87(M97AT96YS:79E+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]397)V:6-E<U]796%T:&5R+V5X
M86UP;&5S+W=E871H97(N8V]M+6)A<VEC+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]397)V:6-E
M<U]796%T:&5R+V5X86UP;&5S+W=E871H97(N8V]M+65X=&5N<VEV92YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+V1O8W,O4V5R=FEC97-?5V5A=&AE<B]E>&%M<&QE<R]E:G-E+6)A<VEC
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O9&]C<R]397)V:6-E<U]796%T:&5R+V5X86UP;&5S+V=L;V)A
M;'=E871H97(M8F%S:6,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]5=&EL+V5X86UP;&5S
M+V5X86UP;&4R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?571I;"]E>&%M<&QE<R]E>&%M
M<&QE+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S97)I
M86QI>F5!;F1%;F-O9&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X
M86UP;&5S+W-E<FEA;&EZ94%R<F%Y5VET:$]B:F5C=',N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S
M+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W-E<FEA;&EZ94-$871A+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S97)I86QI>F5%;7!T
M>4%R<F%Y+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S
M97)I86QI>F5);F1E>&5D07)R87DN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI
M>F5R+V5X86UP;&5S+W-E<FEA;&EZ94EN9&5X961!<G)A>5=I=&A#;VYT97AT
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S97)I86QI
M>F5.=6QL4')O<&5R=&EE<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O
M97AA;7!L97,O<V5R:6%L:7IE3V)J96-T+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R
M:6%L:7IE<B]E>&%M<&QE<R]S97)I86QI>F521$8N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-
M3%]397)I86QI>F5R+V5X86UP;&5S+W-E<FEA;&EZ95-E;&5C=&EV94%T=')I
M8G5T97,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W-E
M<FEA;&EZ95=I=&A!='1R:6)U=&5S+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L
M:7IE<B]E>&%M<&QE<R]S97)I86QI>F57:71H071T<FEB=71E<S(N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A
M<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W-E<FEA;&EZ95=I=&A#
M;VUM96YT+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]E
M>&%M<&QE+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S
M97)I86QI>F57:71H1'1D+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E
M>&%M<&QE<R]S97)I86QI>F57:71H26YD96YT961!='1R:6)U=&5S+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S97)I86QI>F57:71H
M3F%M97-P86-E+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE
M<R]S97)I86QI>F57:71H5&%G36%P+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L
M:7IE<B]E>&%M<&QE<R]U;G-E<FEA;&EZ94%N>5A-3"YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O
M6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O=6YS97)I86QI>F5#;&%S<TYA;65S
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]U;G-E<FEA
M;&EZ945N8V]D960N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP
M;&5S+W5N<V5R:6%L:7IE16YU;2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ
M97(O97AA;7!L97,O=6YS97)I86QI>F5/8FIE8W0N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-
M3%]397)I86QI>F5R+V5X86UP;&5S+W5N<V5R:6%L:7IE4D1&+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]U;G-E<FEA;&EZ95=H:71E
M<W!A8V4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W5N
M<V5R:6%L:7IE5VET:$%T=')I8G5T97,N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I
M86QI>F5R+V5X86UP;&5S+W5N<V5R:6%L:7IE5VET:%1A9TUA<"YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O=6YS97)I86QI>F57:71H
M5'EP94=U97-S:6YG+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M
M<&QE<R]S97)I86QI>F5!;F12971U<FXN<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA
M;7!L92]A='1A8VAM96YT+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]33T%0+V5X86UP;&4O8V]M
M7V-L:65N="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+V1O8W,O4T]!4"]E>&%M<&QE+V1I<V-O7W-E<G9E
M<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+V1O8W,O4T]!4"]E>&%M<&QE+V5M86EL7V-L:65N="YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+V1O8W,O4T]!4"]E>&%M<&QE+V5M86EL7V=A=&5W87DN<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D
M;V-S+U-/05`O97AA;7!L92]E;6%I;%]P;W!?9V%T97=A>2YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O
M8W,O4T]!4"]E>&%M<&QE+V5M86EL7W!O<%]S97)V97(N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S
M+U-/05`O97AA;7!L92]E;6%I;%]S97)V97(N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+U-/05`O
M97AA;7!L92]E>&%M<&QE7W-E<G9E<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O4T]!4"]E>&%M
M<&QE+V5X86UP;&5?='EP97,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L92]S
M97)V97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L92]S97)V97(R+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O9&]C<R]33T%0+V5X86UP;&4O<VUT<"YP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O4T]!4"]E
M>&%M<&QE+W-T;V-K<75O=&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L92]T
M8W!?8VQI96YT+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]33T%0+V5X86UP;&4O=&-P7V1A96UO
M;BYP;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O9&]C<R]33T%0+V5X86UP;&4O=&-P7W-E<G9E<BYP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+V1O8W,O4T]!4"]E>&%M<&QE+W=S9&Q?8VQI96YT+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]3
M3T%0+V5X86UP;&4O8VQI96YT+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R].971?1E10+V5X86UP
M;&4O:6YD97@N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]D;V-S+TYE=%]&5%`O97AA;7!L92]O8G-E<G9E
M<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+V1O8W,O3F5T7T944"]E>&%M<&QE+V5X=&5N<VEO;G,N:6YI
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]D871A+U!%05(O=&5M<&QA=&4N<W!E8PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&%T82]014%2+W!A
M8VMA9V4N9'1D"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]D871A+TUA:6Q?36EM92]X;6%I;"YX<VP)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1A
M=&$O36%I;%]-:6UE+WAM86EL+F1T9`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&%T82],;V<O;6ES8R]L;V<N
M<W%L"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<&5A<B]D871A+U-E<G9I8V5S7U=E871H97(O:6UA9V5S+W-U;G-E="YG
M:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+V1A=&$O4V5R=FEC97-?5V5A=&AE<B]I;6%G97,O<W5N<FES92YG
M:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+V1A=&$O4V5R=FEC97-?5V5A=&AE<B]B=6EL9$UE=&%R1$(N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]D871A+UA-3%]397)I86QI>F5R+V1O8R]T;V1O+G1X=`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&%T
M82]#86-H92]#;VYT86EN97(O;61B7V-A8VAE7W-C:&5M82YX;6P)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+UA-
M3"]24$,O4V5R=F5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!E87(O6$U,+U)00R]$=6UP+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O6$U,
M+U!A<G-E<B]3:6UP;&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]834PO4&%R<V5R+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O6$U,
M+U5T:6PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]834PO56YS97)I86QI>F5R+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O6$U,+U-E
M<FEA;&EZ97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]834PO4E!#+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O1$(O8V]M;6]N+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O1$(O9F)S<6PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]$0B]I8F%S92YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+T1"+VEF
M>"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+T1"+VUS<6PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]$0B]M<W-Q;"YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+T1"
M+VUY<W%L+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O1$(O;7ES<6QI+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O1$(O;V-I."YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+T1"+V]D8F,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]$0B]P9W-Q;"YP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+T1"+W-Y8F%S
M92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+T1"+W-T;W)A9V4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]$0B]S<6QI=&4N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A
M<B]$0B]D8F%S92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]P96%R+TQO9R]C;VUP;W-I=&4N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B],;V<O
M9&%E;6]N+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O3&]G+V1I<W!L87DN<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B],;V<O97)R;W)?
M;&]G+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O3&]G+V9I;&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B],;V<O;6%I;"YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+TQO9R]M8V%L+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O3&]G+VUD8C(N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B],;V<O;G5L;"YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+TQO9R]O8G-E<G9E<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+TQO9R]S<6PN<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B],
M;V<O<W%L:71E+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O3&]G+W-Y<VQO9RYP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+TQO9R]W:6XN
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<&5A<B],;V<O8V]N<V]L92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U-/05`O5')A;G-P;W)T+U--
M5%`N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]33T%0+U1R86YS<&]R="]40U`N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]33T%0+U1R
M86YS<&]R="](5%10+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!E87(O4T]!4"]397)V97(O5$-0+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M4T]!4"]397)V97(O16UA:6PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]33T%0+U-E<G9E<B]%;6%I;%]'
M871E=V%Y+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O4T]!4"]4>7!E+V1U<F%T:6]N+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4T]!
M4"]4>7!E+VAE>$)I;F%R>2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+U-/05`O5'EP92]D871E5&EM92YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+U-/05`O=&]O;',O9V5N<')O>'DN<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]33T%0+U-E<G9E
M<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+U-/05`O5')A;G-P;W)T+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4T]!4"]686QU92YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+U-/05`O5U-$3"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+U-/05`O0VQI96YT+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M4T]!4"]"87-E+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O4T]!4"]$:7-C;RYP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U-/05`O1F%U
M;'0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]33T%0+U!A<G-E<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+T1A=&4O2'5M86XN<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]$871E+U-P86XN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]$871E+U1I;65:;VYE+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M1&%T92]#86QC+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O4$A056YI="]'54DO2%1-3"YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!(
M4%5N:70O1U5)+TA434PN='!L"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]02%!5;FET+T=522]3971U<$1E8V]R
M871O<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+U!(4%5N:70O1U5)+T=T:RYP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!(4%5N:70O
M4F5P96%T961497-T+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!E87(O4$A056YI="]3:V5L971O;BYP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+U!(4%5N:70O5&5S=$-A<V4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]02%!5;FET+U1E<W1$96-O<F%T
M;W(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]02%!5;FET+U1E<W1&86EL=7)E+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$A056YI
M="]497-T3&ES=&5N97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]02%!5;FET+U1E<W1297-U;'0N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]02%!5;FET+U1E<W13=6ET92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!(4%5N:70O07-S97)T
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O1FEL92]#4U8N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]&:6QE+U5T:6PN<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]0
M14%2+T1O=VYL;V%D97(O4&%C:V%G92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O5&%S:R]5;FEX
M96]L+W)W+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O4$5!4B]487-K+U=I;F1O=W-E;VPO<G<N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A
M<B]014%2+U1A<VLO4F5P;&%C92]R=RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O5&%S:R]0;W-T
M:6YS=&%L;'-C<FEP="]R=RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O5&%S:R]#;VUM;VXN<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]014%2+U1A<VLO4&]S=&EN<W1A;&QS8W)I<'0N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2
M+U1A<VLO4F5P;&%C92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O5&%S:R]5;FEX96]L+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O4$5!4B]487-K+U=I;F1O=W-E;VPN<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+U9A;&ED871O
M<B]014-,+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+U!A8VMA9V4N<&AP+F]R:6<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+U!%05(O0V]M;6%N9"]"=6EL9"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]"
M=6EL9"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]#:&%N;F5L<RYX;6P)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%
M05(O0V]M;6%N9"]#:&%N;F5L<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]#;VUM
M;VXN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O0V]N9FEG+GAM;`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]#
M;VUM86YD+T-O;F9I9RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]);G-T86QL+GAM
M;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O4$5!4B]#;VUM86YD+TEN<W1A;&PN<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA
M;F0O4&%C:V%G92YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]086-K86=E+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O4$5!4B]#;VUM86YD+U!I8VML92YX;6P)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]0
M:6-K;&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O4F5G:7-T<GDN>&UL"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]0
M14%2+T-O;6UA;F0O4F5G:7-T<GDN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O4F5M
M;W1E+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+U)E;6]T92YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O
M0V]M;6%N9"]-:7)R;W(N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O36ER<F]R+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O4$5!4B]#;VUM86YD+U1E<W0N>&UL"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O
M5&5S="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]!=71H+GAM;`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]#
M;VUM86YD+T%U=&@N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+U)%4U0O,3$N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2
M+U)%4U0O,3`N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]014%2+T9R;VYT96YD+T-,22YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%
M05(O26YS=&%L;&5R+U)O;&4O0V]M;6]N+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]);G-T86QL
M97(O4F]L92]$871A+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]);G-T86QL97(O4F]L92]$;V,N
M>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<&5A<B]014%2+TEN<W1A;&QE<B]2;VQE+T1O8RYP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O
M26YS=&%L;&5R+U)O;&4O17AT+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]);G-T86QL97(O4F]L
M92]%>'0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]014%2+TEN<W1A;&QE<B]2;VQE+U!H<"YX;6P)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+U!%05(O26YS=&%L;&5R+U)O;&4O4&AP+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]);G-T86QL
M97(O4F]L92]38W)I<'0N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+TEN<W1A;&QE<B]2;VQE+U-C
M<FEP="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+U!%05(O26YS=&%L;&5R+U)O;&4O4W)C+GAM;`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M4$5!4B]);G-T86QL97(O4F]L92]3<F,N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+TEN<W1A;&QE
M<B]2;VQE+U1E<W0N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+TEN<W1A;&QE<B]2;VQE+U1E<W0N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<&5A<B]014%2+TEN<W1A;&QE<B]2;VQE+T1A=&$N>&UL"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2
M+TEN<W1A;&QE<B]2;VQE+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]086-K86=E1FEL92]'96YE
M<F%T;W(O=C(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]014%2+U!A8VMA9V5&:6QE+T=E;F5R871O<B]V
M,2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+U!%05(O4&%C:V%G949I;&4O4&%R<V5R+W8R+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M4$5!4B]086-K86=E1FEL92]087)S97(O=C$N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+U!A8VMA
M9V5&:6QE+W8R+W)W+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]086-K86=E1FEL92]V,B]686QI
M9&%T;W(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]014%2+U!A8VMA9V5&:6QE+W8R+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!
M4B]086-K86=E1FEL92]V,2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O0VAA;FYE;$9I;&4O4&%R
M<V5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O4$5!4B]$;W=N;&]A9&5R+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]%<G)O
M<E-T86-K+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O4$5!4B]%>&-E<'1I;VXN<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+T9R
M;VYT96YD+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O4$5!4B]);G-T86QL97(N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+U)E
M;6]T92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+U!%05(O4&%C:V%G97(N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+U!A8VMA
M9V5&:6QE+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O4$5!4B]296=I<W1R>2YP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O4D53
M5"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+U!%05(O4G5N5&5S="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O5F%L:61A=&4N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<&5A<B]014%2+UA-3%!A<G-E<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O0G5I;&1E<BYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+U!%05(O075T;VQO861E<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O0VAA;FYE;$9I
M;&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UO;BYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+U!%05(O0V]N9FEG+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]$97!E;F1E;F-Y+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O4$5!4B]$97!E;F1E;F-Y1$(N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+T1E<&5N9&5N
M8WDR+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O3U,O1W5E<W,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]834Q?4&%R<V5R
M+W1E<W1S+S`P-2YP:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]834Q?4&%R<V5R+W1E<W1S+S`P
M,RYP:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]T97-T<R]834Q?4&%R<V5R+W1E<W1S+S`P-"YP:'!T"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A
M<B]T97-T<R]834Q?4&%R<V5R+W1E<W1S+S`P,BYP:'!T"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]8
M34Q?4&%R<V5R+W1E<W1S+W1E<W0R+GAM;`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O6$U,7U!A<G-E
M<B]T97-T<R]T97-T,RYX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+UA-3%]087)S97(O=&5S=',O
M,#`Q+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<B]S971U<"YI;F,N
M8W9S+F]R:6<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<B\P,W-I;7!L97%U
M97)Y+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<B\P-&YU;6-O;',N
M<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R+S`U<V5Q=65N8V5S+G!H
M<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<B\P-G!R97!E>&5C+G!H<'0)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<B\P.&%F9F5C=&5D<F]W<RYP:'!T
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O,#EN=6UR;W=S+G!H<'0)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+W1E<W1S+T1"+W1E<W1S+V1R:79E<B\Q,&5R<F]R;6%P+G!H<'0)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E
M<W1S+T1"+W1E<W1S+V1R:79E<B\Q,71R86YS86-T:6]N<RYP:'!T"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T
M97-T<R]$0B]T97-T<R]D<FEV97(O,3-L:6UI="YP:'!T"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$
M0B]T97-T<R]D<FEV97(O,31F971C:&UO9&5?;V)J96-T+G!H<'0)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E
M<W1S+T1"+W1E<W1S+V1R:79E<B\Q-7%U;W1E+G!H<'0)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1"
M+W1E<W1S+V1R:79E<B\Q-G1A8FQE:6YF;RYP:'!T"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T
M97-T<R]D<FEV97(O,3=Q=65R>2YP:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D
M<FEV97(O,3AG970N<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R+S$Y
M9V5T;&ES=&]F+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<B]C;VYN
M96-T+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R+VUK=&%B;&4N:6YC
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O;75L=&EC;VYN96-T+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O=&5S=',O1$(O=&5S=',O9')I=F5R+W)U;BYC=G,)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1"
M+W1E<W1S+V1R:79E<B]S971U<"YI;F,N8W9S"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T
M<R]D<FEV97(O<VMI<&EF+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R
M+S`Q8V]N;F5C="YP:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O,#)F
M971C:"YP:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D8E]F86-T;W)Y+G!H<'0)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+W1E<W1S+T1"+W1E<W1S+V1B7VES;6%N:7`N<&AP=`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O
M1$(O=&5S=',O9&)?97)R;W(R+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V5R
M<F]R<RYI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V9E=&-H;6]D95]O8FIE8W0N
M:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<&5A<B]T97-T<R]$0B]T97-T<R]F971C:&UO9&5S+FEN8PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S
M=',O1$(O=&5S=',O:6YC;'5D92YI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+VQI
M;6ET+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O;G5M8V]L<RYI;F,)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E
M<W1S+T1"+W1E<W1S+VYU;7)O=W,N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]P
M<F5P97AE+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O<G5N+F-V<PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S
M=',O1$(O=&5S=',O<V5Q=65N8V5S+FEN8PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O
M<VEM<&QE<75E<GDN:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]T<F%N<V%C=&EO
M;G,N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]S:VEP:68N:6YC"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T
M<R]$0B]T97-T<R]D8E]E<G)O<BYP:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D
M8E]P87)S961S;BYP:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]I;F-L=61E+FEN
M8RYO<FEG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]T97-T<R].971?4TU44"]T97-T<R]B87-I8RYP:'!T"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A
M<B]T97-T<R].971?4TU44"]T97-T<R]C;VYF:6<N<&AP+F1I<W0)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E
M<W1S+TYE=%]33510+W1E<W1S+W%U;W1E9&%T82YP:'!T"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R].
M971?4TU44"]T97-T<R]A=71H+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+TUA:6PO=&5S=',O
M<VUT<%]E<G)O<BYP:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]-86EL+W1E<W1S+W)F8S@R,BYP
M:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<&5A<B]T97-T<R]834Q?4E!#+W1E<W1S+W1E<W1?1'5M<"YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+W1E<W1S+UA-3%]24$,O=&5S=',O97AT<F$M;&EN97,N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T
M<R]834Q?4E!#+W1E<W1S+W!R;W1O<&]R="YP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+UA-3%]2
M4$,O=&5S=',O96UP='DM=F%L=64N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]834Q?4E!#+W1E
M<W1S+W1Y<&5S+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O6$U,7U)00R]T97-T<R]A;&QG;W0N
M:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<&5A<B]T97-T<R]834Q?4E!#+W1E<W1S+V5M<'1Y+79A;'5E+7-T<G5C
M="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+W1E<W1S+TQO9R]T97-T<R]C;VUP;W-I=&4N<&AP=`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M=&5S=',O3&]G+W1E<W1S+V1I<W!L87DN<&AP=`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O3&]G+W1E
M<W1S+V5R<F]R7VQO9RYP:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R],;V<O=&5S=',O97AT<F%C
M="YP:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]T97-T<R],;V<O=&5S=',O97AT<F%C=#(N<&AP=`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M=&5S=',O3&]G+W1E<W1S+V9A8W1O<GDN<&AP=`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O3&]G+W1E
M<W1S+V9I;&4N<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O3&]G+W1E<W1S+VQE=F5L<RYP:'!T
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]T97-T<R],;V<O=&5S=',O;G5L;"YP:'!T"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R],;V<O
M=&5S=',O<')I;W)I='DN<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O3&]G+W1E<W1S+W-I;F=L
M971O;BYP:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]T97-T<R],;V<O=&5S=',O<W%L:71E+G!H<'0)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+W1E<W1S+TQO9R]T97-T<R]S<6Q?:61E;G0N<&AP=`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O3&]G
M+W1E<W1S+V-O;G-O;&4N<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1&%T92]T97-T<R]C86QC
M+G!H<"YO<FEG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E<W1S+V)U9S<R-U\R+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O=&5S=',O1&%T92]T97-T<R]B=6<W,C=?,RYP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1A
M=&4O=&5S=',O8G5G-S(W7S0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E<W1S+V)U
M9SDV-RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+W1E<W1S+T1A=&4O=&5S=',O8V%L8RYP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E
M<W1S+T1A=&4O=&5S=',O=&5S='5N:70N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E
M<W1S+W1E<W1U;FET7V1A=&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E<W1S+W1E
M<W1U;FET7V1A=&5?<W!A;BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1A=&4O=&5S=',O=&5S
M=%]C86QC+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O=&5S=',O1&%T92]T97-T<R]T97-T7V1A=&5?;65T
M:&]D<U]S<&%N+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1&%T92]T97-T<R]W965K<VEN;6]N
M=&A?-%]M;VYD87DN='AT"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E<W1S+W=E96MS:6YM
M;VYT:%\T7W-U;F1A>2YT>'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1A=&4O=&5S=',O=V5E:W-I
M;FUO;G1H7W)D;5]M;VYD87DN='AT"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E<W1S+W=E
M96MS:6YM;VYT:%]R9&U?<W5N9&%Y+G1X=`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1&%T92]T97-T
M<R]W:VYO=&5S="YT>'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1A=&4O=&5S=',O8G5G-C<T+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O=&5S=',O1&%T92]T97-T<R]B=6<W,C=?,2YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S
M+T9I;&4O=&5S=',O0U-6+S`P,2YP:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]&:6QE+W1E<W1S
M+T-35B\P,#(N<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1FEL92]T97-T<R]#4U8O,#`R+F-S
M=@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O=&5S=',O1FEL92]T97-T<R]#4U8O,#`S+G!H<'0)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S
M+T9I;&4O=&5S=',O0U-6+S`P,RYC<W8)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T9I;&4O=&5S=',O
M0U-6+S`P-"YP:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]&:6QE+W1E<W1S+T-35B\P,#0N8W-V
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]T97-T<R]&:6QE+W1E<W1S+T-35B\P,#4N<&AP=`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O
M1FEL92]T97-T<R]#4U8O,#`U+F-S=@ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1FEL92]T97-T<R]#
M4U8O,#`V+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+W1E<W1S+T9I;&4O=&5S=',O0U-6+S`P-BYC<W8)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+W1E<W1S+T9I;&4O=&5S=',O0U-6+W1E<W1S+G1X=`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O
M1FEL92]T97-T<R]#4U8O,#`Q+F-S=@ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1FEL92]T97-T<R]T
M97-T+F-S=@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O=&5S=',O1FEL92]T97-T<R]&:6QE5&5S="YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+W1E<W1S+T9I;&4O=&5S=',O<&%R<V5R+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O2%144"]297%U97-T
M+TQI<W1E;F5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O2%144"]297%U97-T+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O36%I;"]M
M:6UE1&5C;V1E+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O36%I;"]S96YD;6%I;"YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+TUA:6PO
M<VUT<"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+TUA:6PO4D9#.#(R+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O36%I;"]M:6UE4&%R
M="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+TUA:6PO;6EM92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+TUA:6PO;6%I;"YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+TUA:6PO;G5L;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]P96%R+TYE="]&5%`O3V)S97)V97(N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B].
M970O4V]C:V5T+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O3F5T+U--5%`N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B].970O55),+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O3F5T+T944"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+W!E8VQC;60N<&AP+F]R:6<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+TUA
M:6PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]&:6QE+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4BYP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+T1A=&4N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]02%!5;FET+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!E87(O1$(N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]3>7-T96TN<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A
M<B]P96%R8VUD+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O0V%C:&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]P96%R8VUD+G!H<"YO
M<FEG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<&5A<B]P96-L8VUD+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O3&]G+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+V1O8W,O0T]064E.1PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+V1O
M8W,O4D5!1$U%"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O9&]C<R]#2$%.1T53"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O9&]C<R]#3T1)3D=?4U1!3D1!4D13"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O9&]C
M<R]#3TY44DE"551)3D<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]D;V-S+T-2141)5%,)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]D;V-S+TA!0TM)3D<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]D;V-S+TE.
M4U1!3$P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]D;V-S+U!%4D9/4DU!3D-%"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O9&]C<R]314-54DE460ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+V1O8W,O5$]$3PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+V1O
M8W,O5%)!3E-,051)3TY3"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O9&]C<R]54$=2041)3D<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T97-T+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-I9VYU<"YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]R<&,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&]G:6XN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O:6YD97@N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O861M:6XO;&]C86QE+V5N7U53
M+VAE;'`N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O861M:6XO;&]C86QE+V9I7T9)+VAE;'`N>&UL"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O861M:6XO;&]C
M86QE+VAU7TA5+VAE;'`N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O861M:6XO<&5R;7,O961I="YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]A9&UI;B]P97)M<R]I;F1E>"YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]A9&UI;B]P
M97)M<R]D96QE=&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O861M:6XO<V5T=7`O9&EF9BYP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]A9&UI;B]S971U
M<"]C;VYF:6<N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O861M:6XO<V5T=7`O:6YD97@N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]A9&UI;B]P:'!S:&5L;"YP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]A9&UI;B]I;F1E>"YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]A
M9&UI;B]U<V5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+V%D;6EN+V-M9'-H96QL+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+V%D;6EN+V1A=&%T<F5E
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+V%D;6EN+W-E<W-I;VYS+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+V%D;6EN+W-Q;'-H96QL+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+V%D;6EN
M+W1E;7!L871E<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]A9&UI;B]G<F]U<',N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O:G,O=&%B;&5S+FIS"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O:G,O
M<W1R:7!E+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O:G,O:&]R9&4N:64N:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]J<R]S;W)T97(N:G,)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]J<R]F;W)M7VAE
M;'!E<G,N:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]J<R]H='1P8VQI96YT+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O:G,O:65%<V-'=6%R9"YJ<PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VIS+V9O
M<FU?<V5C=&EO;G,N:G,)"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]J
M<R]E;G1E<E]K97E?=')A<"YJ<PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VIS+VAI9&5A8FQE+FIS"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O:G,O=&]O;'1I<"YJ
M<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VIS+W!O<'5P+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O:G,O9F]R;5]A<W-I9VXN:G,)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]J<R]A;'!H84EM86=E3&]A
M9&5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VIS+VAO<F1E+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O:G,O;W!E;E]C;VQO<G!I8VME<BYJ<PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VIS+VEM
M86=E+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O:G,O861D179E;G0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U-Y;F--3"]$979I8V4O4WEN8S1J
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQI8B]3>6YC34PO1&5V:6-E+U`X,#`N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U-Y;F--3"]$979I
M8V4O4WEN=&AE<VES+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B]3>6YC34PO1&5V:6-E+TYO:VEA+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI
M8B]3>6YC34PO0V]M;6%N9"]&:6YA;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O4WEN8TU,+T-O;6UA;F0O
M4'5T+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B]3>6YC34PO0V]M;6%N9"]297-U;'1S+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]3>6YC
M34PO0V]M;6%N9"]-87`N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U-Y;F--3"]#;VUM86YD+U-Y;F-%;&5M
M96YT+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B]3>6YC34PO0V]M;6%N9"]3=&%T=7,N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U-Y;F--
M3"]#;VUM86YD+T%L97)T+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]3>6YC34PO0V]M;6%N9"]'970N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+U-Y;F--3"]#;VUM86YD+U-Y;F,N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U-Y;F--3"]3=&%T92YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O4WEN8TU,+T)A8VME;F0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U-Y;F--3"]$979I8V4N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+U-Y;F--3"]3>6YC+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]3>6YC34PO0V]N<W1A;G1S+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI
M8B]3>6YC34PO1&5V:6-E26YF;RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O4WEN8TU,+T-O;6UA;F0N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+T9I;&4O4$1&+V9O;G1S+V-O=7)I97(N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+T9I;&4O4$1&+V9O
M;G1S+VAE;'9E=&EC86)I+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]&:6QE+U!$1B]F;VYT<R]T:6UE<RYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O1FEL92]01$8O9F]N=',O>F%P9F1I;F=B871S+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]&:6QE
M+U!$1B]F;VYT<R]T:6UE<V(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+T9I;&4O4$1&+V9O;G1S+W1I;65S
M:2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L:6(O1FEL92]01$8O9F]N=',O:&5L=F5T:6-A8BYP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O1FEL
M92]01$8O9F]N=',O:&5L=F5T:6-A:2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O1FEL92]01$8O9F]N=',O
M=&EM97-B:2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O1FEL92]01$8O9F]N=',O:&5L=F5T:6-A+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI
M8B]&:6QE+U!$1B]F;VYT<R]S>6UB;VPN<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+T9I;&4O4$1&+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI
M8B]&:6QE+T-35BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O5&5X="]R95-4+T9O<FUA='1E<B]H=&UL+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQI8B]497AT+W)E4U0O4&%R<V5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]497AT+W)E4U0O1F]R;6%T
M=&5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B]497AT+T1I9F8O4F5N9&5R97(O:6YL:6YE+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]4
M97AT+T1I9F8O4F5N9&5R97(O=6YI9FEE9"YP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O5&5X="]$:69F+U)E
M;F1E<F5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B]497AT+T1I9F8N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U1E>'0O1FQO=V5D+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQI8B]497AT+T1I9F8S+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]497AT+W)E4U0N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+UA-3"]7
M0EA-3"]$5$0O4WEN8TU,1&5V26YF+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]834PO5T)834PO1%1$+U-Y
M;F--3$UE=$EN9BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O6$U,+U="6$U,+T141"]3>6YC34PN<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB
M+UA-3"]70EA-3"]#;VYT96YT2&%N9&QE<BYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O6$U,+U="6$U,+T14
M1"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L:6(O6$U,+U="6$U,+T141$UA;F%G97(N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+UA-3"]70EA-
M3"]%;F-O9&5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B]834PO5T)834PO1&5C;V1E<BYP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O6$U,
M+U-61RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L:6(O6$U,+U="6$U,+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]61E,O25-/5W)I=&5R+U)E
M86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]61E,O25-/5W)I=&5R+U)E
M86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U9&4R])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O5D93+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2]D:7)E8W0N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U9&4R])4T]7<FET97(O
M4F5A;$]U='!U=%-T<F%T96=Y+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]61E,O25-/5W)I=&5R+VUK:7-O
M9G,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+U9&4R])4T]7<FET97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U9&4R]/8FIE8W0N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U9&
M4R]S;6(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+U9&4R]'0RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O5D93+W-Q;"YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O5D93
M+VUU<W%L+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B]61E,O9G1P+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]61E,O0G)O=W-E<BYP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O5D93+W-Q;%]F:6QE+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]61E,O9FEL92YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O5D93+TQI
M<W1)=&5M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B]";&]C:R]T:6UE+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B]";&]C:R]A8V-O=6YT+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]";&]C:R]G;V]G
M;&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+T)L;V-K+W-U;G)I<V4N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+T)L;V-K+VUO;VXN<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O0FQO8VLO:69R86UE+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]";&]C:R]M971A
M<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L:6(O0FQO8VLO8V]L;W(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TUO8FEL92]296YD
M97)E<B]H=&UL+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-;V)I;&4O4F5N9&5R97(O=VUL+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQI8B](;W)D92]-;V)I;&4O4F5N9&5R97(N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T1A=&$O
M;W5T;&]O:V-S=BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O1&%T82]V8V%R9"YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R
M9&4O1&%T82]V=&]D;RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O1&%T82]T<W8N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO
M<F1E+T1A=&$O:6-A;&5N9&%R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]$871A+W9N;W1E+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQI8B](;W)D92]$871A+VEM8RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O1&%T82]C<W8N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+T=R87!H+U!L;W0O8F%R9W)O=7!E9"YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O
M1W)A<&@O4&QO="]B87(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T=R87!H+U!L;W0O8F%R<W1A
M8VME9"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L:6(O2&]R9&4O1W)A<&@O4&QO="]L:6YE+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D
M92]'<F%P:"]0;&]T+W-C871T97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T=R87!H+T-H87)T
M+W!I93-D+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B](;W)D92]'<F%P:"]#:&%R="]P:64N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO
M<F1E+T=R;W5P+VQD87`N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T=R;W5P+VAO;VMS+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI
M8B](;W)D92]);6%G92]R9V(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TEM86=E+W-V9RYP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O2&]R9&4O26UA9V4O<W=F+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]);6%G92]G9"YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O2&]R9&4O26UA9V4O:6TN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TEM86=E+W!N9RYP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U!E<FUS+V1A=&%T<F5E
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQI8B](;W)D92]397-S:6]N2&%N9&QE<B]M>7-Q;"YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R
M9&4O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O4V5S<VEO;DAA
M;F1L97(O;&1A<"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(O<V%P9&(N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+W-Q;"YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O
M4V5S<VEO;DAA;F1L97(O;65M8V%C:&4N<&AP"0HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+V]C:3@N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+W!G<W%L+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]3
M97-S:6]N2&%N9&QE<B]D8FTN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]M;V)I;&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]A=61I;RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+VIA=F%S8W)I<'0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]S=&%T=7,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B]%=F5N="YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92])
M34%0+T%#3"]R9F,T,S$T+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQI8B](;W)D92])34%0+T%D;6EN+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92])34%0+T%#
M3"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L:6(O2&]R9&4O24U!4"]396%R8V@N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TE-05`O
M5')E92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L:6(O2&]R9&4O24U!4"]4:')E860N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TE-
M05`O4V]R="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O2&]R9&4O24U!4"]#86-H92YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O
M4')E9G,O<W%L+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B](;W)D92]0<F5F<R]522YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O
M4')E9G,O:V]L86(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U!R969S+VQD87`N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO
M<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O4')E9G,O
M<V5S<VEO;BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O2&]R9&4O4')E9G,O:6US<"YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O
M1F]R;2]4>7!E+W1A8FQE<V5T+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]&;W)M+T%C=&EO;B]C
M;VYD:71I;VYA;%]E;F%B;&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T9O<FTO06-T:6]N+W)E
M;&]A9"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L:6(O2&]R9&4O1F]R;2]!8W1I;VXO8V]N9&ET:6]N86Q?<V5T
M=F%L=64N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+TAO<F1E+T9O<FTO06-T:6]N+W-U8FUI="YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M2&]R9&4O1F]R;2]!8W1I;VXO=7!D871E9FEE;&0N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T9O
M<FTO06-T:6]N+W-U;5]F:65L9',N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T9O<FTO06-T:6]N
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQI8B](;W)D92]&;W)M+U)E;F1E<F5R+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]4;VME
M;B]F:6QE+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B](;W)D92]4;VME;B]S<6PN<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)
M344O5FEE=V5R+V]O;R]T86)L95]C96QL<RYX<VP)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6
M:65W97(O;V]O+VUA:6Y?:'1M;"YX<VP)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O
M;V]O+W!A;&TN>'-L"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+V]O;R]S='EL95]M
M87!P:6YG+GAS;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]O;V\O9VQO8F%L7V1O
M8W5M96YT+GAS;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]O;V\O=&%B;&5?<F]W
M<RYX<VP)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O;V]O+W-T>6QE7VEN;&EN960N
M>'-L"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+V]O;R]T86)L95]C;VQU;6YS+GAS
M;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQI8B](;W)D92]-24U%+U9I97=E<B]O;V\O8V]M;6]N+GAS;`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D
M92]-24U%+U9I97=E<B]O;V\O=&%B;&4N>'-L"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE
M=V5R+V]O;R]S='EL95]H96%D97(N>'-L"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R
M+V1E8BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D
M92]-24U%+U9I97=E<B]R9F,X,C(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W!L86EN+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]C<W,N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO
M<F1E+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I
M97=E<B]I;6%G97,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS<&]W97)P
M;VEN="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O;7-W;W)D+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](
M;W)D92]-24U%+U9I97=E<B]H=&UL+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E
M<B]D969A=6QT+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O2&]R9&4O34E-12]6:65W97(O<G!M+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I
M97=E<B]R97!O<G0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+W=E8F-P<"YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%
M+U9I97=E<B]T9WHN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+W-O=7)C92YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O2&]R9&4O34E-12]6:65W97(O=&YE9BYP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-
M12]6:65W97(O<W)C:&EG:&QI=&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W!D9BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O;V]O+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D
M92]-24U%+U9I97=E<B]S96-U<FET>2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W
M97(O<&AP+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]R:6-H=&5X="YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O2&]R9&4O34E-12]6:65W97(O96YR:6-H960N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)
M344O5FEE=V5R+VUS97AC96PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+W-I
M;7!L92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L:6(O2&]R9&4O34E-12]087)T+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%
M+TUA9VEC+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+TU$3BYP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-
M12]#;VYT96YT<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12](96%D97)S+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](
M;W)D92]-24U%+U-T<G5C='5R92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]M
M:6UE+FUA<'!I;F<N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O;6EM92YM86=I8RYP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O2&]R9&4O5&5X="]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](
M;W)D92]497AT+T9I;'1E<B]X<W,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R
M+V-L96%N87-C:6DN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R+W=O<F1S+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQI8B](;W)D92]497AT+T9I;'1E<B]R<W0N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O
M1FEL=&5R+W-P86-E,FAT;6PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R+W-I
M;7!L96UA<FMU<"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O5&5X="]&:6QT97(O9&EM<VEG;F%T
M=7)E+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B](;W)D92]497AT+T9I;'1E<B]B8F-O9&4N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO
M<F1E+U1E>'0O1FEL=&5R+VQI;FMU<FQS+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]497AT+T9I
M;'1E<B]E;6%I;',N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5N=FER;VYM
M96YT+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B](;W)D92]497AT+T9I;'1E<B]H=&UL,G1E>'0N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB
M+TAO<F1E+U1E>'0O1FEL=&5R+V5M;W1I8V]N<RYP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O5&5X
M="]&:6QT97(O=&%B<S)S<&%C97,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R
M+W1E>'0R:'1M;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O5&5X="]&:6QT97(N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO
M<F1E+U1R964O:'1M;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O5')E92]S96QE8W0N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB
M+TAO<F1E+U1R964O:F%V87-C<FEP="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O0V]M<')E
M<W,O9&)X+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E
M+T-O;7!R97-S+W1A<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O0V]M<')E<W,O9WII<"YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O2&]R9&4O0V]M<')E<W,O=&YE9BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O5D,O<F-S+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQI8B](;W)D92]60R]C=G,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U9#+W-V;BYP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M2&]R9&4O3DQ3+V-O;W)D:6YA=&5S+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92].3%,O8V%R<VEG
M;G,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+TY,4R]T;&0N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+TAO<F1E+TY,4R]'96])4"YP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O1&%T
M851R964O<W%L+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B](;W)D92]$871A5')E92]N=6QL+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](
M;W)D92]#:7!H97(O0FQO8VM-;V1E+V5C8BYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O0VEP:&5R
M+T)L;V-K36]D92]O9F(V-"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O0VEP:&5R+T)L;V-K36]D
M92]C9F(V-"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O2&]R9&4O0VEP:&5R+T)L;V-K36]D92]C8F,N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+T-I<&AE<B]B;&]W9FES:"YP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O0VEP:&5R
M+T)L;V-K36]D92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O0VEP:&5R+V1E<RYP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R
M9&4O0VEP:&5R+V-A<W0Q,C@N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T-I<&AE<B]R8S(N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+T-I<&AE<B]R8S0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U)00R]R97-T+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQI8B](;W)D92]24$,O>&UL<G!C+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]24$,O=V5B9&%V
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQI8B](;W)D92]24$,O<WEN8VUL7W=B>&UL+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]2
M4$,O<WEN8VUL+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B](;W)D92]24$,O<V]A<"YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O
M4U%,+T%T=')I8G5T97,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O2&]R9&4O0G)O=W-E<B]I;6]D92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O161I=&]R+VAT
M;6QA<F5A+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B](;W)D92]#86-H92]F:6QE+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]#
M86-H92]Z<',T+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B](;W)D92]";&]C:R],87EO=70O5FEE=RYP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T)L
M;V-K+U5)+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](
M;W)D92]!=71H+W!A<W-W9"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O075T:"]I<&)A<VEC+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQI8B](;W)D92]!=71H+VQD87`N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O8WER=7,N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+VEP
M;6%P+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B](;W)D92]!=71H+W-A<VPN<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O
M8V]M<&]S:71E+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+V%U=&\N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E
M+T%U=&@O:'1T<"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O075T:"]S;6(N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E
M+T%U=&@O;&]G:6XN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O8W5S=&]M<W%L+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI
M8B](;W)D92]!=71H+VMO;&%B+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+W-Q;"YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O2&]R9&4O075T:"]K<F(U+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+VUC86PN<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+T%U=&@O9G1P+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+VEM87`N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+WEA:&]O
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQI8B](;W)D92]!=71H+W!A;2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O075T:"]I;7-P
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQI8B](;W)D92]!=71H+W)A9&EU<RYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O075T:"]A
M<'!L:6-A=&EO;BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O:4-A;&5N9&%R+W9N;W1E+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI
M8B](;W)D92]I0V%L96YD87(O=FIO=7)N86PN<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+VE#86QE
M;F1A<B]V=&]D;RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O:4-A;&5N9&%R+W9E=F5N="YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O2&]R9&4O:4-A;&5N9&%R+W9T:6UE>F]N92YP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O:4-A
M;&5N9&%R+W9F<F5E8G5S>2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O:4-A;&5N9&%R+W9A;&%R
M;2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L:6(O2&]R9&4O:4-A;&5N9&%R+W9C87)D+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]3
M8VAE9'5L97(O8W)O;BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O=&%B;&5S971?:'1M;"YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O2&]R9&4O54DO5VED9V5T+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]522]486)S+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQI8B](;W)D92]522],86YG=6%G92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+TAO<F1E+U5)+U!A9V5R+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92](96QP
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQI8B](;W)D92]5=&EL+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]38VAE9'5L97(N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+T5D:71O<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O365N=2YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R
M9&4O5')E92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O2&]R9&4O4V5R:6%L:7IE+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]$
M871A+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B](;W)D92]$871E+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]396-R970N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+T-,22YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O0V%C:&4N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E
M+U!R969S+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92](:7-T;W)Y
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQI8B](;W)D92]-86EN=&5N86YC92YP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O4V5S<VEO
M;DAA;F1L97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T9O<FTN<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TMO;&%B
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQI8B](;W)D92]$871A5')E92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O4&5R;7,N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+TUO8FEL92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O4E!#+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D
M92]497AT+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B](;W)D92]3:&%R92YP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O2&]R9&4O07)R87DN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U1O:V5N+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](
M;W)D92]);6%G92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O:4-A;&5N9&%R+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D
M92]496UP;&%T92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O5D,N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T=R87!H
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQI8B](;W)D92]344PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U-T<FEN9RYP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M2&]R9&4O3F]T:69I8V%T:6]N+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]687)I86)L97,N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+T-O;F9I9RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O1W)O=7`N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO
M<F1E+T-I<&AE<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O4F5G:7-T<GDN<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E
M+T-O;7!R97-S+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B](;W)D92].3%,N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T-R>7!T
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQI8B](;W)D92]";&]C:RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O3$1!4"YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M2&]R9&4O261E;G1I='DN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U-E<W-I;VY/8FIE8W1S+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQI8B](;W)D92]"<F]W<V5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TYE="]335,O9V5N97)I
M8U]S;71P+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B].970O4TU3+W=I;E]H='1P+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B].970O24U3
M4"]!=71H+VEM=&5S="YP:'`)<F]O="!W:&5E;"`P-S4U"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O3F5T+TE-4U`O075T:"]C<F%M7VUD-2YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O3F5T+TE-4U`O075T:"]P;&%I;G1E>'0N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TYE="])35-0
M+T)O;VLN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+TYE="])35-0+U5T:6QS+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B].970O24U34"]/
M<'1I;VYS+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B].970O24U34"]!=71H+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B].970O4TU3+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQI8B].970O24U34"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O8F%S92YP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O5&5S="YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M2&]R9&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+W!R969S+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]3>6YC34PN<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+RYH=&%C
M8V5S<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQI8B]V97)S:6]N+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]C;W)E+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]61E,N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB
M+V%P:2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L;V-A;&4O:VU?2T@O3$-?34534T%'15,O:&]R9&4N;6\)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A
M;&4O87)?4UDO3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O8V%?15,O3$-?
M34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L;V-A;&4O8G-?0D$O3$-?34534T%'15,O:&]R
M9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L;V-A;&4O9&%?1$LO3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O
M9&%?1$LO:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L;V-A;&4O9&5?1$4O3$-?34534T%'15,O:&]R9&4N
M;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L;V-A;&4O9&5?1$4O:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O8W-?0UHO3$-?34534T%'
M15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L;V-A;&4O8W-?0UHO:&5L<"YX;6P)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O96Q?1U(O
M3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O96Q?1U(O:&5L<"YX;6P)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A
M;&4O9F%?25(O3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O9F%?25(O:&5L
M<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L;V-A;&4O96Y?55,O:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O97-?15,O3$-?3453
M4T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L;V-A;&4O97-?15,O:&5L<"YX;6P)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O9FE?
M1DDO3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O9FE?1DDO:&5L<"YX;6P)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M;V-A;&4O971?144O3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O971?144O
M:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L;V-A;&4O9G)?1E(O3$-?34534T%'15,O:&]R9&4N;6\)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A
M;&4O9G)?1E(O:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L;V-A;&4O9VQ?15,O3$-?34534T%'15,O:&]R
M9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L;V-A;&4O:&5?24PO3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O
M:61?240O3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O:'5?2%4O3$-?3453
M4T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L;V-A;&4O:'5?2%4O:&5L<"YX;6P)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O:F%?
M2E`O3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O:F%?2E`O:&5L<"YX;6P)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M;V-A;&4O:7-?25,O3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O:71?250O
M3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O:71?250O:&5L<"YX;6P)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A
M;&4O8F=?0D<O3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O8F=?0D<O:&5L
M<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L;V-A;&4O:V]?2U(O3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O
M:V]?2U(O:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L;V-A;&4O;'1?3%0O3$-?34534T%'15,O:&]R9&4N
M;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L;V-A;&4O;'1?3%0O:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O;6M?34LO3$-?34534T%'
M15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L;V-A;&4O;'9?3%8O3$-?34534T%'15,O:&]R9&4N;6\)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M;V-A;&4O;F)?3D\O3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O;F)?3D\O
M:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L;V-A;&4O;FQ?3DPO3$-?34534T%'15,O:&]R9&4N;6\)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A
M;&4O;FQ?3DPO:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L;V-A;&4O;FY?3D\O3$-?34534T%'15,O:&]R
M9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L;V-A;&4O;FY?3D\O:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O<&Q?4$PO3$-?3453
M4T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L;V-A;&4O<&Q?4$PO:&5L<"YX;6P)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O<'1?
M0E(O3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O<'1?0E(O:&5L<"YX;6P)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M;V-A;&4O<'1?4%0O3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O<'1?4%0O
M:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L;V-A;&4O<F]?4D\O3$-?34534T%'15,O:&]R9&4N;6\)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A
M;&4O<G5?4E4O3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O<G5?4E4O:&5L
M<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L;V-A;&4O<VM?4TLO3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O
M<VM?4TLO:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L;V-A;&4O<VQ?4TDO3$-?34534T%'15,O:&]R9&4N
M;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L;V-A;&4O<VQ?4TDO:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O<W9?4T4O3$-?34534T%'
M15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L;V-A;&4O<W9?4T4O:&5L<"YX;6P)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O=')?5%(O
M3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O=')?5%(O:&5L<"YX;6P)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A
M;&4O=6M?54$O3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O=6M?54$O:&5L
M<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L;V-A;&4O>FA?0TXO3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O
M>FA?0TXO:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L;V-A;&4O>FA?5%<O3$-?34534T%'15,O:&]R9&4N
M;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L;V-A;&4O>FA?5%<O:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O+FAT86-C97-S"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O9F%?
M25(N<&\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P;R]E<U]%4RYP;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!O+WIH7T-.+G!O"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O>FA?5%<N<&\)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P;R]H=5](
M52YP;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!O+V9I7T9)+G!O"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&\O971?144N<&\)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P;R]214%$344)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P;R]R=5]252YP
M;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!O+V=L7T53+G!O"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&\O8V%?15,N<&\)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P;R]B<U]"02YP;PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!O+VED7TE$+G!O
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&\O<F]?4D\N<&\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P;R]S:U]32RYP;PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!O+RYH=&%C8V5S<PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!O+VQT7TQ4+G!O
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&\O9&5?1$4N<&\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P;R]N;%].3"YP;PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!O+VIA7TI0+G!O"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O=')A;G-L871I
M;VXN<&AP"7)O;W0@=VAE96P@,#<U-0HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&\O:7-?25,N<&\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P;R]S;%]322YP;PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!O+V)G7T)'+G!O"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O9G)?
M1E(N<&\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P;R]A<E]362YP;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!O+W5K7U5!+G!O"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O:71?250N<&\)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P;R]H;W)D
M92YP;W0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P;R]M:U]-2RYP;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!O+VQV7TQ6+G!O"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O;FY?3D\N<&\)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P;R]P;%]0
M3"YP;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!O+VMM7TM(+G!O"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&\O:&5?24PN<&\)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P;R]D85]$2RYP;PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!O+V-S7T-:
M+G!O"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<&\O<'1?0E(N<&\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]P;R]P=%]05"YP;PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!O+VYB7TY/+G!O"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O<W9?4T4N
M<&\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P;R]T<E]44BYP;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!O+V5L7T=2+G!O"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O:V]?2U(N<&\)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S+VQD
M87`O:&]R9&4N<V-H96UA"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]U<&=R861E<R]M;W9E7VAI<W1O<GE?
M;W5T7V]F7V1A=&%T<F5E+G!H<`ER;V]T('=H965L(#`W-34*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O=7!G<F%D97,O,C`P-BTP-BTR
M.5]H;W)D95]P<F5F<U]I;F1E>&5S+G-Q;`D*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W-C<FEP=',O=7!G<F%D97,O,BXR7W1O7S,N,"YP9W-Q;"YS
M<6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]S8W)I<'1S+W5P9W)A9&5S+S(N,E]T;U\S+C`N;7ES<6PN<W%L"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T
M<R]U<&=R861E<R\R+C)?=&]?,RXP+F]C:3@N<W%L"0HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]U<&=R861E<R\S+C!?=&]?,RXQ+FUY
M<W%L+G-Q;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W-C<FEP=',O=7!G<F%D97,O,RXP7W1O7S,N,2YO8VDX+G-Q;`D*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O=7!G<F%D97,O
M,C`P-2TP.2TR,E]H;W)D95]P<F5F<U]V87)C:&%R,BYO8VDX+G-Q;`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP
M=',O=7!G<F%D97,O,RXP7W1O7S,N,2YS<6P)"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]C<F5A=&4N;V-I."YS<6P)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S
M+W-Q;"]C<F5A=&4N;7ES<6PN<W%L"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?<V5S<VEO
M;FAA;F1L97(N<W%L"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO8W)E871E+FUS9&4N<W%L"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T
M<R]S<6PO4D5!1$U%"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO<V-R:7!T+FEN:71I86Q?:&]R9&5?
M=7-E<BYS<6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]H:7-T;W)I97,N;7-S<6PN<W%L
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<V-R:7!T<R]S<6PO8W)E871E+G-Q;`D*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W-C<FEP=',O<W%L+V-R96%T92YX;6P)"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]S97-S:6]N:&%N9&QE
M<BYP9W-Q;"YS<6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]D871A=')E92YS<6P)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I
M<'1S+W-Q;"]H;W)D95]S97-S:6]N:&%N9&QE<BYM>7-Q;"YS<6P)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S
M+W-Q;"]H;W)D95]D871A=')E92YM<W-Q;"YS<6P)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D
M95]M=79F<RYS<6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]V9G,N<&=S<6PN<W%L"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R
M:7!T<R]S<6PO:&]R9&5?;&]G+G-Q;`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O<W%L+U)%041-12Y/0TDX
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<V-R:7!T<R]S<6PO:&]R9&5?=7-E<G,N<W%L"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?
M:&ES=&]R:65S+G-Q;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7W-E<W-I;VYH86YD;&5R
M+F]C:3@N<W%L"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?=F9S+F]C:3@N<W%L"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T
M<R]S<6PO:&]R9&5?<')E9G,N;7-S<6PN<W%L"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?
M=&]K96YS+G-Q;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7W-E<W-I;VYH86YD;&5R+FUS
M<W%L+G-Q;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7VQO9RYM<W-Q;"YS<6P)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S
M+W-Q;"]H;W)D95]S97-S:6]N:&%N9&QE<BYS87!D8BYS<6P)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S+W-Q
M;"]H;W)D95]M=79F<RYM<W-Q;"YS<6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]C<F5A=&4N<WEB
M87-E+G-Q;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7W9F<RYS<6P)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H
M;W)D95]V9G,N;7-S<6PN<W%L"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?<')E9G,N<W%L
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<V-R:7!T<R]S<6PO:&]R9&5?9&%T871R964N;7ES<6PN<W%L"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]S
M<6PO8W)E871E+G!G<W%L+G-Q;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O8W)O;F0)<F]O="!W:&5E;"`P
M-S4U"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S+W1H96UE
M<U]C:&5C:RYP:'`)<F]O="!W:&5E;"`P-S4U"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]S8W)I<'1S+V-O=6YT7W-E<W-I;VYS+G!H<`ER;V]T('=H
M965L(#`W-34*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O
M+FAT86-C97-S"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<V-R:7!T<R]H='1P7VQO9VEN7W)E9F5R+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O
M;6EG<F%T95]U<V5R7V-A=&5G;W)I97,N<&AP"7)O;W0@=VAE96P@,#<U-0HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]R96UO=F5?<')E
M9G,N<&AP"7)O;W0@=VAE96P@,#<U-0HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<V-R:7!T<R]S971U<"YP:'`)<F]O="!W:&5E;"`P-S4U"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S+W1E;7`M8VQE86YU<"YC
M<F]N"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<V-R:7!T<R]S971?<&5R;7,N<V@)<F]O="!W:&5E;"`P-S4U"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S+V-R96%T92US>6UL:6YK
M<RYP:'`)<F]O="!W:&5E;"`P-S4U"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]S8W)I<'1S+V-O;VMI95]L;V=I;BYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S+U-#4DE05%,)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S
M8W)I<'1S+V=E=%]L;V=I;BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O
M;&%N9R]E;BYJ<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+T%N
M<V5L26UA9V4O;&%N9R]E;BYJ<PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P
M;'5G:6YS+T%N<V5L26UA9V4O86YS96PM:6UA9V4N:G,)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET
M;W(O:'1M;&%R96$O<&QU9VEN<R]!;G-E;$EM86=E+VEN<V5R=%]I;6%G92YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]!;G-E;$EM86=E
M+W-H;W=I;6%G92YH=&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I
M;G,O0V]N=&5X=$UE;G4O;&%N9R]E;BYJ<PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL
M87)E82]P;'5G:6YS+T-O;G1E>'1-96YU+VUE;G4N8W-S"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I
M=&]R+VAT;6QA<F5A+W!L=6=I;G,O0V]N=&5X=$UE;G4O8V]N=&5X="UM96YU
M+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R
M871I;VYS+VEM9R]C96QL+61E;&5T92YG:68)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M
M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO;G,O:6UG+V-O;"US<&QI="YG
M:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A
M=&EO;G,O:6UG+V-E;&PM;65R9V4N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA
M<F5A+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS+VEM9R]R;W<M:6YS97)T+6%B
M;W9E+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE
M3W!E<F%T:6]N<R]I;6<O<F]W+61E;&5T92YG:68)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O
M:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO;G,O:6UG+V-E;&PM:6YS
M97)T+6)E9F]R92YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN
M<R]486)L94]P97)A=&EO;G,O:6UG+V-E;&PM:6YS97)T+6%F=&5R+F=I9@ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E
M<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N
M<R]I;6<O8V5L;"US<&QI="YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O
M<&QU9VEN<R]486)L94]P97)A=&EO;G,O:6UG+V-O;"UI;G-E<G0M869T97(N
M9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R
M871I;VYS+VEM9R]C;VPM:6YS97)T+6)E9F]R92YG:68)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET
M;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO;G,O:6UG+W)O=RUP
M<F]P+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE
M3W!E<F%T:6]N<R]I;6<O8V]L+61E;&5T92YG:68)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O
M:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO;G,O:6UG+V-E;&PM<')O
M<"YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P
M97)A=&EO;G,O:6UG+W1A8FQE+7!R;W`N9VEF"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT
M;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS+VEM9R]R;W<M<W!L:70N
M9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R
M871I;VYS+VEM9R]R;W<M:6YS97)T+75N9&5R+F=I9@ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O
M<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]L86YG+V5N+FIS
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R871I
M;VYS+W1A8FQE+6]P97)A=&EO;G,N:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R
M96$O<&QU9VEN<R],:7-T5'EP92]L86YG+V5N+FIS"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R
M+VAT;6QA<F5A+W!L=6=I;G,O3&ES=%1Y<&4O;&ES="UT>7!E+FIS"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC
M97,O961I=&]R+VAT;6QA<F5A+W!O<'5P<R]F=6QL<V-R965N+FAT;6P)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V
M:6-E<R]E9&ET;W(O:'1M;&%R96$O<&]P=7!S+W!O<'5P+FIS"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O
M961I=&]R+VAT;6QA<F5A+W!O<'5P<R]A8F]U="YH=&UL"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I
M=&]R+VAT;6QA<F5A+W!O<'5P<R]S96QE8W1?8V]L;W(N:'1M;`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S
M+V5D:71O<B]H=&UL87)E82]P;W!U<',O:6YS97)T7W1A8FQE+FAT;6P)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V
M:6-E<R]E9&ET;W(O:'1M;&%R96$O<&]P=7!S+VQI;FLN:'1M;`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S
M+V5D:71O<B]H=&UL87)E82]P;W!U<',O8FQA;FLN:'1M;`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D
M:71O<B]H=&UL87)E82]P;W!U<',O:6YS97)T7VEM86=E+FAT;6P)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E
M<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7V%L:6=N7VQE9G0N9VEF"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R
M=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]K:6QL=V]R9"YG:68)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S
M97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7V-U<W1O;2YG:68)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S
M97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7V)L86YK+F=I9@ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E
M<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?:6YD96YT7VQE<W,N
M9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]I;F1E;G1?
M;6]R92YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7V%L
M:6=N7VIU<W1I9GDN9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E
M<R]E9%]F;W)M871?:71A;&EC+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E
M82]I;6%G97,O961?8VAA<FUA<"YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R
M96$O:6UA9V5S+V9U;&QS8W)E96Y?;6EN:6UI>F4N9VEF"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I
M=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]P87-T92YG:68)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET
M;W(O:'1M;&%R96$O:6UA9V5S+V5D7V-U="YG:68)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O
M:'1M;&%R96$O:6UA9V5S+V5D7W-H;W=?8F]R9&5R+F=I9@ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D
M:71O<B]H=&UL87)E82]I;6%G97,O961?<F5D;RYG:68)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET
M;W(O:'1M;&%R96$O:6UA9V5S+V5D7VQI;FLN9VEF"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R
M+VAT;6QA<F5A+VEM86=E<R]E9%]H96QP+F=I9@ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H
M=&UL87)E82]I;6%G97,O961?9F]R;6%T7V)O;&0N9VEF"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I
M=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]L969T7W1O7W)I9VAT+F=I9@ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I
M8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?=6YD;RYG:68)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E
M<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7V9O<FUA=%]S=6(N9VEF"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R
M=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]I;G-E<G1?=&%B;&4N9VEF
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]F;W)M871?<W5P
M+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?:6UA9V4N
M9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]H<BYG:68)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S
M97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7W)I9VAT7W1O7VQE
M9G0N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]H=&UL
M+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?<V%V92YG
M:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7V9O<FUA=%]S
M=')I:V4N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]D
M96QE=&4N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]C
M;VQO<E]B9RYG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D
M7V%B;W5T+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?
M;&ES=%]B=6QL970N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E
M<R]E9%]C;VQO<E]F9RYG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA
M9V5S+V5D7V%L:6=N7W)I9VAT+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E
M82]I;6%G97,O961?9F]R;6%T7W5N9&5R;&EN92YG:68)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET
M;W(O:'1M;&%R96$O:6UA9V5S+V9U;&QS8W)E96Y?;6%X:6UI>F4N9VEF"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R
M=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]R;69O<FUA="YG:68)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S
M97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7V%L:6=N7V-E;G1E
M<BYG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7V-O<'DN
M9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]L:7-T7VYU
M;2YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7W-P;&ET
M8V5L+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]D:6%L;V<N:G,)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V
M:6-E<R]E9&ET;W(O:'1M;&%R96$O<&]P=7!W:6XN:G,)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET
M;W(O:'1M;&%R96$O<&]P=7!D:78N:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R
M96$O:'1M;&%R96$N:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:'1M;&%R
M96$N8W-S"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O<&]R=&%L
M+VUO8FEL92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S
M+W!O<G1A;"]S:61E8F%R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+W-H87)E<R]E9&ET
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W-E<G9I8V5S+V1O=VYL;V%D+VEN9&5X+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V]B<F]W
M<V5R+VEN9&5X+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S
M97)V:6-E<R]I;6%G97,O<&EX96PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O:6UA9V5S+W9I97<N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]S97)V:6-E<R]L86YG=6%G92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]S97)V:6-E<R]J879A<V-R:7!T+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+VME>6)O
M87)D+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W-E<G9I8V5S+V-A8VAE=FEE=RYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W-E<G9I8V5S+W!R969S+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V=O+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E
M<G9I8V5S+W!R;V)L96TN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+VAE;'`O;65N=2YI
M;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O:&5L<"]A8F]U
M="YI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T96UP;&%T97,O;65N=2]M96YU+FEN8PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]T97-T+W9E
M<G-I;VXN:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&5M<&QA=&5S+W1E<W0O<&AP7W9E<G-I;VXN:6YC"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA
M=&5S+W1E<W0O97AT96YS:6]N<RYI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O=&5S="]F;V]T97(N
M:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&5M<&QA=&5S+W1E<W0O:&5A9&5R+FEN8PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]M86EN=&5N
M86YC92]M86EN=&5N86YC92YH=&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN+W5S97(O861D
M+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S
M+V%D;6EN+W5S97(O8VQE87(N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;F]A9&0N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN
M8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN
M+W-E='5P+VEN9&5X+FAT;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG
M+FAT;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]E9&ET+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]A9&UI;B]G<F]U<',O
M861D8VAI;&0N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+VEN
M9&5X+V9R86UE<U]I;F1E>"YI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&5M<&QA=&5S+W!R969S+VUU;'1I96YU;2YI;F,)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]P<F5F<R]P87-S=V]R
M9"YI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T96UP;&%T97,O<')E9G,O96YD+FEN8PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]P<F5F<R]O
M=F5R=FEE=RYI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T96UP;&%T97,O<')E9G,O<V5L96-T+FEN8PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E
M<R]P<F5F<R]T97AT+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]P<F5F<R]N=6UB97(N:6YC"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M
M<&QA=&5S+W!R969S+V1E;&5T96ED96YT:71Y+FEN8PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]P<F5F
M<R]T97AT87)E82YI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T96UP;&%T97,O<')E9G,O8VAE8VMB;W@N:6YC"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M
M<&QA=&5S+W!R969S+V5N=6TN:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+W!R969S+V)E9VEN+FEN
M8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1E;7!L871E<R]P<F5F<R]A<'`N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+W!R969S+VQI;FLN
M:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E
M;7!L871E<R]D871A+V1A=&5M87`N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T96UP;&%T97,O9&%T82]T:6UE+FEN8PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&5M<&QA=&5S+V1A=&$O9&%T971I;64N:6YC"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+V-O
M;G1E;G1S+V]P96Y?=FEE=U]W:6XN:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]G;V]G;&5?=VEN+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]J879A<V-R:7!T+W1R964N
M:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E82YJ<PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]J
M879A<V-R:7!T+W!R:6YT+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]H
M=&UL7VAE;'!E<BYJ<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T96UP;&%T97,O:F%V87-C<FEP="]K97EB:6YD:6YG<RYJ<PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L
M871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]P;W)T86PO;65N=2YI
M;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+W!O<G1A;"]S
M:61E8F%R+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1E;7!L871E<R]P;W)T86PO861D+FEN8PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]P
M;W)T86PO;&%Y;W5T+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]P;W)T86PO8FQO8VLN:6YC"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T96UP;&%T97,O8V]M;6]N+69O;W1E<BYI;F,)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O
M8V]M;6]N+6AE861E<BYI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O+FAT86-C97-S"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=E
M;FYE=FEL;&EE<G,O:6YF;RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9V5N;F5V:6QL:65R<R]S8W)E
M96XN8W-S"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V%Z=7(O:6YF;RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O87IU<B]S8W)E96XN
M8W-S"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R97DO:6YF;RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)E>2]S8W)E96XN8W-S
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+TYE6%1G<F5Y+VEN9F\N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+TYE6%1G<F5Y+W-C<F5E
M;BYC<W,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O8V]R;F9L;W=E<B]G<F%P:&EC<R]T86)?8F]T=&]M+F=I
M9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]C;W)N9FQO=V5R+V=R87!H:6-S+W1A8E]R:6=H="YG:68)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O8V]R;F9L;W=E<B]G<F%P:&EC<R]T86)?;&5F="YG:68)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O8V]R
M;F9L;W=E<B]I;F9O+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]C;W)N9FQO=V5R+W-C<F5E;BYC<W,)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O8G)O=VXO:6YF;RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O8G)O=VXO<V-R965N+F-S<PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F5E;B]I;F9O+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F5E;B]S8W)E96XN8W-S"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+VED96%S+V=R87!H:6-S+V)A8VMG<F]U;F0N<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+VED96%S
M+V=R87!H:6-S+VUE;G5?=&]P+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]I9&5A<R]G<F%P:&EC<R]L
M969T7VUE;G5?=&]P+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]I9&5A<R]G<F%P:&EC<R]L969T7VUE
M;G5?8F]T=&]M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]I9&5A<R]I;F9O+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]I9&5A
M<R]S8W)E96XN8W-S"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+VMO;&%B+V=R87!H:6-S+VMO;&%B+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]K;VQA8B]G<F%P:&EC<R]B9RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O:V]L86(O9W)A<&AI
M8W,O:V]L86)L;V=O+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]K;VQA8B]I;F9O+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]K
M;VQA8B]S8W)E96XN8W-S"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+VQA=F%N9&5R+VEN9F\N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+VQA=F%N9&5R+W-C<F5E;BYC<W,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O>G<N
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V%L+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]F;&%G<R]B82YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O86TN<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+V)B+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]A;BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O86\N<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+V)D+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B92YP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8F8N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V9L86=S+V)G+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]A<BYP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O8F@N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+V)I+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]A="YP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O8FHN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V%U+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]C82YP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M9FQA9W,O87<N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V)M+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]B;BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M8F\N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V%Z+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]C9BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8V<N<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+V)R+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]C:"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8G,N<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+V-I+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B
M="YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8VLN<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V9L86=S+V-L+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B=RYP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O8VTN<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L
M86=S+V-N+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B>2YP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O8V\N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V)Z
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]D92YP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O9FQA9W,O8W(N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V-U+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]D:RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O8W8N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V5C+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]C>2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8WHN
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V5E+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]F;&%G<R]E9RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O9'HN<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+V5R+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]E<RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O9FDN<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+V5T+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]F:BYP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O9V$N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V9L86=S+V9O+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]G92YP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O9G(N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+V=I+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]G;"YP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O9W`N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V=R+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]G="YP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M9FQA9W,O9W4N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VAK+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]G>2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M:60N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VEE+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]H<BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O:'0N<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+VAU+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]I;"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O:6XN<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+VEQ+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]I
M<BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O:7,N<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V9L86=S+VET+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]J;2YP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O:F\N<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L
M86=S+VME+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]J<"YP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O:V<N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VMH
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]K:2YP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O9FQA9W,O;&(N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VQC+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]K<"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O:W(N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VQK+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]M82YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;6,N
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VMY+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]F;&%G<R]M9"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O:WHN<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+VUG+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]L="YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;'4N<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+VQV+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]N82YP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;6XN<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V9L86=S+VYC+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]L>2YP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O;6\N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+VUP+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]N9BYP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O;7,N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VUT+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]N;"YP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M9FQA9W,O;7@N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VUY+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]N;RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M;7HN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VYP+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]N<BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<&$N<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+V]M+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]N>BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<&4N<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+W!F+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]P
M:"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<&LN<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V9L86=S+W!L+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]Q82YP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O<&TN<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L
M86=S+W!R+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]P="YP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O<'DN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W-A
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]S8BYP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O9FQA9W,O<F\N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W-D+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]S92YP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O<V<N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W-I+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]R=2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<VLN
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W-L+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]F;&%G<R]T8RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<V\N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+W1G+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]S<BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O=&@N<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+W5A+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]T;BYP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<WDN<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V9L86=S+W1O+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]T<"YP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O=6<N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+W1R+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]T="YP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O=6LN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W1V+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]V82YP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M9FQA9W,O='<N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W1Z+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]V92YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M=F<N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W5S+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]V:2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O=FXN<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+W5Y+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]W<RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O>64N<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+WIA+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]Y
M=2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O868N<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+VUI;64O;7-E>&-E;"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]O;V]?
M=W)I=&5R+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+W9I9&5O+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]M:6UE+WAM;"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]O
M;V]?:6UP<F5S<RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]S;W5R8V4M<'ET
M:&]N+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+VUS<&]W97)P;VEN="YP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O;6EM92]M<W=O<F0N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+VUI;64O8FEN87)Y+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+VAT;6PN<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+VUI;64O=F-A<F0N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+VUI;64O;V]O7V1R87<N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O<G!M+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]M:6UE+V]O;U]C86QC+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]M:6UE+V5N8W)Y<'1I;VXN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O
M;V]O7VUA=&@N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O;6%I;"YP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O;6EM92]A=61I;RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM
M92]C;VUP<F5S<V5D+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+W1E>'0N<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+VUI;64O<V]U<F-E+6,N<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+VUI;64O<V]U<F-E+6@N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O<V]U
M<F-E+6IA=F$N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O:6UA9V4N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+VUI;64O<V]U<F-E+6-P<"YP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O;6EM92]I8V%L96YD87(N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O<&1F
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+W!H<"YP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O;6EM92]S8W)I<'0M:G,N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O9&5B
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]M;V]N+V9U;&QM;V]N+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]B;&]C:R]M;V]N+VQA<W1Q=6%R=&5R+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]B;&]C:R]M;V]N+VYE=VUO;VXN<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V)L;V-K+VUO;VXO9FER<W1Q=6%R=&5R+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S0W+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S$N<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,BYP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\S+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S0N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O-2YP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\V+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S<N
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O
M."YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R
M,R\Y+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S
M>#(S+VYA+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M
M+S(S>#(S+S$P+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T
M8V]M+S(S>#(S+S$Q+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R
M9&]T8V]M+S(S>#(S+S$R+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T
M:&5R9&]T8V]M+S(S>#(S+S$S+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W
M96%T:&5R9&]T8V]M+S(S>#(S+S$T+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]W96%T:&5R9&]T8V]M+S(S>#(S+S$U+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B
M;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S$V+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S$W+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S$X+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S$Y+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S(P+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S(Q+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S(R
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S
M+S(S+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S
M>#(S+S(T+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M
M+S(S>#(S+S(U+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T
M8V]M+S(S>#(S+S(V+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R
M9&]T8V]M+S(S>#(S+S(W+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T
M:&5R9&]T8V]M+S(S>#(S+S(X+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W
M96%T:&5R9&]T8V]M+S(S>#(S+S(Y+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]W96%T:&5R9&]T8V]M+S(S>#(S+S,P+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B
M;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S,Q+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S,R+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S,S+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S,T+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S,U+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S,V+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S,W
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S
M+S,X+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S
M>#(S+S,Y+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M
M+S(S>#(S+S0P+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T
M8V]M+S(S>#(S+S0Q+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R
M9&]T8V]M+S(S>#(S+S0R+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T
M:&5R9&]T8V]M+S(S>#(S+S0S+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W
M96%T:&5R9&]T8V]M+S(S>#(S+S0T+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]W96%T:&5R9&]T8V]M+S(S>#(S+S0U+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B
M;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S0V+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S`N<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O-#<N<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,2YP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\R+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S,N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O-"YP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\U+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S8N
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O
M-RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S
M,B\X+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R
M>#,R+SDN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO
M,S)X,S(O;F$N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C
M;VTO,S)X,S(O5%=#;&]G;U\S,G!X+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]W96%T:&5R9&]T8V]M+S,R>#,R+S$P+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B
M;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S$Q+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S$R+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S$S+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S$T+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S$U+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S$V+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S$W
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R
M+S$X+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R
M>#,R+S$Y+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M
M+S,R>#,R+S(P+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T
M8V]M+S,R>#,R+S(Q+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R
M9&]T8V]M+S,R>#,R+S(R+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T
M:&5R9&]T8V]M+S,R>#,R+S(S+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W
M96%T:&5R9&]T8V]M+S,R>#,R+S(T+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]W96%T:&5R9&]T8V]M+S,R>#,R+S(U+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B
M;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S(V+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S(W+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S(X+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S(Y+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S,P+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S,Q+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S,R
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R
M+S,S+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R
M>#,R+S,T+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M
M+S,R>#,R+S,U+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T
M8V]M+S,R>#,R+S,V+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R
M9&]T8V]M+S,R>#,R+S,W+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T
M:&5R9&]T8V]M+S,R>#,R+S,X+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W
M96%T:&5R9&]T8V]M+S,R>#,R+S,Y+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]W96%T:&5R9&]T8V]M+S,R>#,R+S0P+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B
M;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S0Q+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S0R+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S0S+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S0T+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S0U+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S0V+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S`N
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W-U;G)I<V4O<W5N<FES92YP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O8FQO8VLO<W5N<FES92]S=6YS970N<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V)L;V-K+VQA<F=E7VQE9G0N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V)L;V-K+VQE9G0N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+V1O=VXN<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V)L;V-K+VQA<F=E7W)I9VAT+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]B;&]C:R]U<"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO;&%R
M9V5?=7`N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+VQA<F=E7V1O=VXN<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V)L;V-K+W)I9VAT+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]A=F%T87)S+VQI;G5X+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V9R
M86YC+FIP9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V1E=FEL+F=I9@ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]A=F%T87)S+VQI<V$N9VEF"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V
M871A<G,O96QM97)F=61D+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V=A
M<F9I96QD+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W)E:2YJ<&<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O879A=&%R<R]G<F]V97(N:G!G"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V%V871A<G,O<'5F9BYJ<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]T<FEN
M+FIP9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+VMI9"YG:68)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O879A=&%R<R]M87)G92YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R
M<R]P:6-A<F0N:G!G"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O9F5M86QE,2YJ
M<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]F96UA;&4R+FIP9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]A=F%T87)S+VUA;&4Q+FIP9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T
M87)S+VUA;&4R+FIP9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V1O9RYG:68)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O879A=&%R<R]S>6QV97-T97(N9VEF"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V%V871A<G,O<VUI;&5Y+F=I9@ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T
M87)S+V1I;F\N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O8G)E="YJ<&<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O879A=&%R<R]W:6YN:64N9VEF"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V%V871A<G,O96QM;RYJ<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]G
M<F5E;FAE860N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O=&EG9V5R+F=I
M9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V)O>6%N9&UO=V5R+F=I9@ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]A=F%T87)S+VIE<FDN:G!G"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V
M871A<G,O=&AO;6%S+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V)O8F%F
M971T+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+VUA;BYJ<&<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O879A=&%R<R]H=6UP+FIP9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T
M87)S+W-M=7)F<RYG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]R>74N9VEF
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V%V871A<G,O86YG<GEB;WDN9VEF"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V%V871A<G,O8F5R=#(N:G!G"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A
M<G,O9&EG:6UO;BYG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]M:6(N9VEF
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V%V871A<G,O=F%M<&ER93(N:G!G"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V%V871A<G,O874N:G!G"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O
M:VER:RYJ<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]R961C<F5A='5R92YG
M:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]S;VYI8RYG:68)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O879A=&%R<R]B=6YN>2YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R
M<R]W;VUA;BYJ<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]F<F5D9FQI;G-T
M;VYE+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W!A:6YT:6YG8FER9"YG
M:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]B97)T+FIP9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]A=F%T87)S+VEC97-K871E:VED+F=I9@ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A
M=F%T87)S+VYE;RYJ<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]M875L+F=I
M9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W=O;'9E<FEN92YJ<&<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O879A=&%R<R]A;&EE;BYJ<&<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A
M=&%R<R]S<&5E9'DN9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O8F%R8F%R
M:6%N+FIP9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+VUO;FME>2YJ<&<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O879A=&%R<R]E=FEL+FIP9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A
M=F%T87)S+V)O>6%N9'!C+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+WAE
M;F$N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O=F%M<&ER92YJ<&<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O879A=&%R<R]S=&%N+FIP9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A
M=F%T87)S+W5S+FIP9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V-O8VMY+FIP
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V)A8GDN9VEF"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V%V871A<G,O=VEZ87)D+FIP9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S
M+V%L>2YJ<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]C:&%R;&EE7V)R;W=N
M+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V%P92YJ<&<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O879A=&%R<R]M96QO;BYJ<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R
M<R]W;V]D:64N:G!G"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O=V%C:V\N9VEF
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V%V871A<G,O8VQO=VXN:G!G"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V%V871A<G,O9'5C:RYG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]E
M:6YS=&5I;BYJ<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]B871M86XN9VEF
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V%V871A<G,O<V5X>2YG:68)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O879A=&%R<R]L;W9E8FER9"YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R
M<R]B;V\N:G!G"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O:&]M97(N9VEF"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V%V871A<G,O8F%R="YG:68)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M879A=&%R<R]N:6YJ82YJ<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]S=7!E
M<FUA;BYG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]D:6QB97)T+F=I9@ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]A=F%T87)S+W)E:3(N:G!G"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V%V871A<G,O9W)E;6QI;BYJ<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]G
M;W!H97(N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O:W)Y=&]N+FIP9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O86YG96QW:6YK+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]E;6]T:6-O;G,O=VEN:W1O;F=U96]U="YP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O96UO=&EC;VYS+V1E=FEL+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T
M:6-O;G,O<F%S<&)E<G)Y+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O
M8FQU<V@N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]E;6)A<G)A<W-E
M9"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+W!U;FMM;VAA=VLN<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]F<G5S=')A=&5D+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]E;6]T:6-O;G,O8V]N9G5S960N<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V5M;W1I8V]N<R]H:7!P:65T;VYG=64N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V5M;W1I8V]N<R]D87IE9"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS
M+W-A9"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+V9R;W=N+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O8V]O;&=R:6XN<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V5M;W1I8V]N<R]P=6YK+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T
M:6-O;G,O9W)I;BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+VUA9"YP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+V1E=FEL=&]N9W5E+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O<'5N:W1O;F=U92YP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O96UO=&EC;VYS+V-O;VQT;VYG=64N<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V5M;W1I8V]N<R]B:6=G<FEN+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T
M:6-O;G,O:'5R="YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+V%N9V5L
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O8V]O;"YP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O96UO=&EC;VYS+VUR="YP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO
M=&EC;VYS+W-M:6QE+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O<VAO
M=70N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]A;FYO>65D+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O=VEN:W1O;F=U92YP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O96UO=&EC;VYS+V%N9W)Y+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E
M;6]T:6-O;G,O=VEN:RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+W9A
M;7!I<F4N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]H86YG;W9E<BYP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+V)I9V9R;W=N+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]E;6]T:6-O;G,O=VEN:V=R:6XN<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V5M;W1I8V]N<R]H:7!P:65G<FEN+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E
M;6]T:6-O;G,O=&]N9W5E;W5T+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O
M;G,O8VQO=VXN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]I;F1I9F9E
M<F5N="YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+V1I<V%P<&]I;G1E
M9"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+W=O<G)I960N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V5M;W1I8V]N<R]A<VQE97`N<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V5M;W1I8V]N<R]E;G)A9V5D+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T
M:6-O;G,O;&]V92YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+W1I<F5D
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O:&EP<&EE+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]M;V)I;&4O9&ES<&QA>2YJ<&<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M;6]B:6QE+W)I9VAT+FIP9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M;V)I;&4O;&5F="YJ
M<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O;6]B:6QE+W1O<"YJ<&<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O;6]B:6QE+V)O='1O;2YJ<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O86QE<G1S+W=A
M<FYI;F<N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%L97)T<R]M97-S86=E+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]A;&5R=',O<W5C8V5S<RYP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O86QE<G1S+V5R<F]R+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]I;6%G92]A<G)O
M=RUD;W=N+F=I9@D*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]I;6%G92]R871I;RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:6UA
M9V4O<F]T871E+3$X,"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:6UA9V4O<F]T871E
M+3(W,"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:6UA9V4O9FQI<"YP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O:6UA9V4O;6ER<F]R+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]I;6%G
M92]G<F%Y<V-A;&4N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VEM86=E+V-R;W`N<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+VEM86=E+W)O=&%T92TY,"YP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O:6UA9V4O<F5F<F5S:"YG:68)"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:6UA9V4O87)R;W<M=7`N9VEF"0HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VEM
M86=E+W)E9G)E<V@N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O<F5V+6IO:6XN
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+W1R964O<&QU<RYP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O=')E92]F;VQD97)O<&5N+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+V)L
M86YK+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+W!L=7-B;W1T;VTN<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+W1R964O<F5V+6UI;G5S;VYL>2YP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O=')E92]R978M:F]I;F)O='1O;2UD;W=N+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]T<F5E+VQE868N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O:F]I;F)O
M='1O;2UD;W=N+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+W)E=BUP;'5S;VYL
M>2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]N=6QL;VYL>2YP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O=')E92]J;VEN8F]T=&]M+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T
M<F5E+W)E=BUL:6YE+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+W)E=BUM:6YU
M<V)O='1O;2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]R978M<&QU<RYP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O=')E92]R978M<&QU<V)O='1O;2YP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O=')E92]M:6YU<RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]M
M:6YU<W1O<"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]M:6YU<V]N;'DN<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+W1R964O:F]I;BYP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M=')E92]M:6YU<V)O='1O;2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]R978M
M;&5A9BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]R978M:F]I;F)O='1O;2YP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O=')E92]F;VQD97(N<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+W1R964O<F5V+6YU;&QO;FQY+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E
M+W)E=BUM:6YU<RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]P;'5S;VYL>2YP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O=')E92]R978M<&QU<W1O<"YP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O=')E92]R978M;6EN=7-T;W`N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+W1R964O;&EN92YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]P;'5S=&]P+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]N878O8F]T=&]M+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]N878O9&]W;BUG<F5Y+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]N878O;&%S="UG
M<F5Y+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]N878O;&5F="UG<F5Y+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]N878O9&]W;BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;F%V+V9I
M<G-T+6=R97DN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VYA=B]R:6=H="UG<F5Y+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]N878O<FEG:'0N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+VYA=B]L969T+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]N878O8F]T=&]M+6=R97DN
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+VYA=B]T;W`N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+VYA=B]U<"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;F%V+W5P+6=R97DN<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+VYA=B]T;W`M9W)E>2YP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M;F%V+VQA<W0N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VYA=B]F:7)S="YP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O8V%L96YD87(N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1A8E]B
M;W1T;VTN9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W!R969S+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]M87`N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V]R9V%N:7II;F<N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+VQO9VEN+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]L:&%N9"YP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O<W%L+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]C;VYF
M:6<N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+W!E<FUS+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]A>BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=6YL;V-K960N<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+VAI9&5?<&%N96PN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V1E;&5T92US
M;6%L;"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O<')O8FQE;2YP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O8V]L;W)S8V%L92YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;7EA8V-O=6YT
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]S:&%D;W<N9VEF"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+W-H861O=RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8V]L;W)P:6-K97(N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+W)E;&]A9"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:&]R9&4M
M<&]W97(Q+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]H;W)D92UP;W=E<C(N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+W-H;W=?<&%N96PN<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VAO
M<F1E+7!O=V5R,RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:&5L<%]I;F1E>"YP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O:&]R9&4N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W-E87)C
M:"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9W)O=7`N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V-L;W-E+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]Z82YP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O;&]C:V5D+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]D96QE=&4N<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+W5S97(N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VEN9F\N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+VQA>6]U="YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O<FAA;F0N
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V]F9FEC92YP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M9&%T871R964N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5D:70M<VUA;&PN<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+W)E<75I<F5D+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]I;F9O
M7VEC;VXN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V1O=VYL;V%D+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]L;V=O=70N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]D979E;"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=V5B<VET
M92YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O<')I;G0N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+VAE;'`N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W-H96QL+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]E9&ET+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]K97EB;V%R9"YP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9F%V:6-O;BYI8V\)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQA;FLN
M9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V1A=&$N<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%D
M;6EN:7-T<F%T:6]N+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M87!?974N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V=O;V=L92YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O<V%V92YP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O<')I;G0O<V-R965N+F-S<PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]H:2UC;VYT<F%S="]I
M;F9O+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]H:2UC;VYT<F%S="]S8W)E96XN8W-S"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V)L
M=65W:&ET92]I;F9O+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]B;'5E=VAI=&4O<V-R965N+F-S<PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]S:6UP;&5X+V=R87!H:6-S+V)A8VMG<F]U;F0N<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+W-I
M;7!L97@O:6YF;RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O<VEM<&QE>"]S8W)E96XN8W-S"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V-A;6]U9FQA9V4O9W)A<&AI8W,O;65N=2YP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O8V%M;W5F;&%G
M92]I;F9O+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]C86UO=69L86=E+W-C<F5E;BYC<W,)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M;'5C+V=R87!H:6-S+W1A8E]B;W1T;VTN9VEF"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+VQU8R]G<F%P:&EC
M<R]T86)?<FEG:'0N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+VQU8R]G<F%P:&EC<R]T86)?;&5F="YG
M:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O;'5C+V=R87!H:6-S+V-U<G)E;G1486)?<FEG:'0N9VEF"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+VQU8R]G<F%P:&EC<R]C=7)R96YT5&%B7VQE9G0N9VEF"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+VQU
M8R]I;F9O+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]L=6,O<V-R965N+F-S<PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]L=6-B;'5E
M+VEN9F\N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+VQU8V)L=64O<V-R965N+F-S<PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]P;W-T
M;G5K92]I;F9O+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]P;W-T;G5K92]S8W)E96XN8W-S"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V)A<F)I92]I;F9O+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]B87)B:64O<V-R965N+F-S<PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]M;WII;&QA+V=R87!H:6-S+VUE;G4N<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+VUO>FEL;&$O9W)A
M<&AI8W,O;65N=2UA8W1I=F4N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+VUO>FEL;&$O9W)A<&AI8W,O
M:&5A9&5R+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]M;WII;&QA+VEN9F\N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+VUO>FEL
M;&$O<V-R965N+F-S<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]B;'5E;6]O;B]I;F9O+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]B
M;'5E;6]O;B]S8W)E96XN8W-S"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+VQI9VAT8FQU92]G<F%P:&EC<R]M
M96YU+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]L:6=H=&)L=64O:6YF;RYP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O;&EG:'1B
M;'5E+W-C<F5E;BYC<W,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O;6]B:6QE+W-C<F5E;BYC<W,)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M<'5R<&QE+VEN9F\N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+W!U<G!L92]S8W)E96XN8W-S"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V)U<FYT;W)A;F=E+VEN9F\N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V)U<FYT;W)A;F=E+W-C<F5E
M;BYC<W,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O<G1L+F-S<PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]I935M86,N8W-S"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+VUO
M>C$T+F-S<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]O<&5R82YC<W,)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O<V%F87)I+F-S<PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]S8W)E96XN8W-S"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+VEE-E]O<E]L97-S+F-S<PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W5T:6PO:6-O;E]B
M<F]W<V5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W5T:6PO8F%R8V]D92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]U=&EL+W)E9V5X7W1E<W0N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]E=&,O<'-A+6AO
M<F1E+VAO<F1E+V-O;F8N<&AP"7)O;W0@=VAE96P@,#0T-`HD>U!23T150U1?
M4D]/5%]$?2]E=&,O<'-A+6AO<F1E+VAO<F1E+VUI;65?9')I=F5R<RYP:'`)
M<F]O="!W:&5E;"`P-#0T"B1[4%)/1%5#5%]23T]47T1]+V5T8R]P<V$M:&]R
M9&4O:&]R9&4O;6]T9"YP:'`)<F]O="!W:&5E;"`P-#0T"B1[4%)/1%5#5%]2
M3T]47T1]+V5T8R]P<V$M:&]R9&4O:&]R9&4O;FQS+G!H<`ER;V]T('=H965L
M(#`T-#0*)'M04D]$54-47U)/3U1?1'TO971C+W!S82UH;W)D92]H;W)D92]P
M<F5F<RYP:'`)<F]O="!W:&5E;"`P-#0T"B1[4%)/1%5#5%]23T]47T1]+V5T
M8R]P<V$M:&]R9&4O:&]R9&4O<F5G:7-T<GDN<&AP"7)O;W0@=VAE96P@,#0T
M-`HD>U!23T150U1?4D]/5%]$?2]E=&,O<'-A+6AO<F1E+VAO<F1E+VAO;VMS
M+G!H<`ER;V]T('=H965L(#`T-#0*)'M04D]$54-47U)/3U1?1'TO971C+W!S
M82UH;W)D92]H;W)D92]C;VYF+GAM;`ER;V]T('=H965L(#`T-#0*)'M04D]$
M54-47U)/3U1?1'TO971C+W!S82UH;W)D92]H;W)D92\N:'1A8V-E<W,)<F]O
M="!W:&5E;"`P-#0T"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
`
end
